// Note: For maximum-speed code, see "Optimizing Code" on the Emscripten wiki, https://github.com/kripken/emscripten/wiki/Optimizing-Code
// Note: Some Emscripten settings may limit the speed of the generated code.
// The Module object: Our interface to the outside world. We import
// and export values on it, and do the work to get that through
// closure compiler if necessary. There are various ways Module can be used:
// 1. Not defined. We create it here
// 2. A function parameter, function(Module) { ..generated code.. }
// 3. pre-run appended it, var Module = {}; ..generated code..
// 4. External script tag defines var Module.
// We need to do an eval in order to handle the closure compiler
// case, where this code here is minified but Module was defined
// elsewhere (e.g. case 4 above). We also need to check if Module
// already exists (e.g. case 3 above).
// Note that if you want to run closure, and also to use Module
// after the generated code, you will need to define   var Module = {};
// before the code. Then that object will be used in the code, and you
// can continue to use Module afterwards as well.
var Module;
if (!Module) Module = eval('(function() { try { return Module || {} } catch(e) { return {} } })()');
// Sometimes an existing Module object exists with properties
// meant to overwrite the default module functionality. Here
// we collect those properties and reapply _after_ we configure
// the current environment's defaults to avoid having to be so
// defensive during initialization.
var moduleOverrides = {};
for (var key in Module) {
  if (Module.hasOwnProperty(key)) {
    moduleOverrides[key] = Module[key];
  }
}
// The environment setup code below is customized to use Module.
// *** Environment setup code ***
var ENVIRONMENT_IS_NODE = typeof process === 'object' && typeof require === 'function';
var ENVIRONMENT_IS_WEB = typeof window === 'object';
var ENVIRONMENT_IS_WORKER = typeof importScripts === 'function';
var ENVIRONMENT_IS_SHELL = !ENVIRONMENT_IS_WEB && !ENVIRONMENT_IS_NODE && !ENVIRONMENT_IS_WORKER;
if (ENVIRONMENT_IS_NODE) {
  // Expose functionality in the same simple way that the shells work
  // Note that we pollute the global namespace here, otherwise we break in node
  Module['print'] = function print(x) {
    process['stdout'].write(x + '\n');
  };
  Module['printErr'] = function printErr(x) {
    process['stderr'].write(x + '\n');
  };
  var nodeFS = require('fs');
  var nodePath = require('path');
  Module['read'] = function read(filename, binary) {
    filename = nodePath['normalize'](filename);
    var ret = nodeFS['readFileSync'](filename);
    // The path is absolute if the normalized version is the same as the resolved.
    if (!ret && filename != nodePath['resolve'](filename)) {
      filename = path.join(__dirname, '..', 'src', filename);
      ret = nodeFS['readFileSync'](filename);
    }
    if (ret && !binary) ret = ret.toString();
    return ret;
  };
  Module['readBinary'] = function readBinary(filename) { return Module['read'](filename, true) };
  Module['load'] = function load(f) {
    globalEval(read(f));
  };
  Module['arguments'] = process['argv'].slice(2);
  module['exports'] = Module;
}
else if (ENVIRONMENT_IS_SHELL) {
  Module['print'] = print;
  if (typeof printErr != 'undefined') Module['printErr'] = printErr; // not present in v8 or older sm
  if (typeof read != 'undefined') {
    Module['read'] = read;
  } else {
    Module['read'] = function read() { throw 'no read() available (jsc?)' };
  }
  Module['readBinary'] = function readBinary(f) {
    return read(f, 'binary');
  };
  if (typeof scriptArgs != 'undefined') {
    Module['arguments'] = scriptArgs;
  } else if (typeof arguments != 'undefined') {
    Module['arguments'] = arguments;
  }
  this['Module'] = Module;
}
else if (ENVIRONMENT_IS_WEB || ENVIRONMENT_IS_WORKER) {
  Module['read'] = function read(url) {
    var xhr = new XMLHttpRequest();
    xhr.open('GET', url, false);
    xhr.send(null);
    return xhr.responseText;
  };
  if (typeof arguments != 'undefined') {
    Module['arguments'] = arguments;
  }
  if (typeof console !== 'undefined') {
    Module['print'] = function print(x) {
      console.log(x);
    };
    Module['printErr'] = function printErr(x) {
      console.log(x);
    };
  } else {
    // Probably a worker, and without console.log. We can do very little here...
    var TRY_USE_DUMP = false;
    Module['print'] = (TRY_USE_DUMP && (typeof(dump) !== "undefined") ? (function(x) {
      dump(x);
    }) : (function(x) {
      // self.postMessage(x); // enable this if you want stdout to be sent as messages
    }));
  }
  if (ENVIRONMENT_IS_WEB) {
    this['Module'] = Module;
  } else {
    Module['load'] = importScripts;
  }
}
else {
  // Unreachable because SHELL is dependant on the others
  throw 'Unknown runtime environment. Where are we?';
}
function globalEval(x) {
  eval.call(null, x);
}
if (!Module['load'] == 'undefined' && Module['read']) {
  Module['load'] = function load(f) {
    globalEval(Module['read'](f));
  };
}
if (!Module['print']) {
  Module['print'] = function(){};
}
if (!Module['printErr']) {
  Module['printErr'] = Module['print'];
}
if (!Module['arguments']) {
  Module['arguments'] = [];
}
// *** Environment setup code ***
// Closure helpers
Module.print = Module['print'];
Module.printErr = Module['printErr'];
// Callbacks
Module['preRun'] = [];
Module['postRun'] = [];
// Merge back in the overrides
for (var key in moduleOverrides) {
  if (moduleOverrides.hasOwnProperty(key)) {
    Module[key] = moduleOverrides[key];
  }
}
// === Auto-generated preamble library stuff ===
//========================================
// Runtime code shared with compiler
//========================================
var Runtime = {
  stackSave: function () {
    return STACKTOP;
  },
  stackRestore: function (stackTop) {
    STACKTOP = stackTop;
  },
  forceAlign: function (target, quantum) {
    quantum = quantum || 4;
    if (quantum == 1) return target;
    if (isNumber(target) && isNumber(quantum)) {
      return Math.ceil(target/quantum)*quantum;
    } else if (isNumber(quantum) && isPowerOfTwo(quantum)) {
      return '(((' +target + ')+' + (quantum-1) + ')&' + -quantum + ')';
    }
    return 'Math.ceil((' + target + ')/' + quantum + ')*' + quantum;
  },
  isNumberType: function (type) {
    return type in Runtime.INT_TYPES || type in Runtime.FLOAT_TYPES;
  },
  isPointerType: function isPointerType(type) {
  return type[type.length-1] == '*';
},
  isStructType: function isStructType(type) {
  if (isPointerType(type)) return false;
  if (isArrayType(type)) return true;
  if (/<?{ ?[^}]* ?}>?/.test(type)) return true; // { i32, i8 } etc. - anonymous struct types
  // See comment in isStructPointerType()
  return type[0] == '%';
},
  INT_TYPES: {"i1":0,"i8":0,"i16":0,"i32":0,"i64":0},
  FLOAT_TYPES: {"float":0,"double":0},
  or64: function (x, y) {
    var l = (x | 0) | (y | 0);
    var h = (Math.round(x / 4294967296) | Math.round(y / 4294967296)) * 4294967296;
    return l + h;
  },
  and64: function (x, y) {
    var l = (x | 0) & (y | 0);
    var h = (Math.round(x / 4294967296) & Math.round(y / 4294967296)) * 4294967296;
    return l + h;
  },
  xor64: function (x, y) {
    var l = (x | 0) ^ (y | 0);
    var h = (Math.round(x / 4294967296) ^ Math.round(y / 4294967296)) * 4294967296;
    return l + h;
  },
  getNativeTypeSize: function (type) {
    switch (type) {
      case 'i1': case 'i8': return 1;
      case 'i16': return 2;
      case 'i32': return 4;
      case 'i64': return 8;
      case 'float': return 4;
      case 'double': return 8;
      default: {
        if (type[type.length-1] === '*') {
          return Runtime.QUANTUM_SIZE; // A pointer
        } else if (type[0] === 'i') {
          var bits = parseInt(type.substr(1));
          assert(bits % 8 === 0);
          return bits/8;
        } else {
          return 0;
        }
      }
    }
  },
  getNativeFieldSize: function (type) {
    return Math.max(Runtime.getNativeTypeSize(type), Runtime.QUANTUM_SIZE);
  },
  dedup: function dedup(items, ident) {
  var seen = {};
  if (ident) {
    return items.filter(function(item) {
      if (seen[item[ident]]) return false;
      seen[item[ident]] = true;
      return true;
    });
  } else {
    return items.filter(function(item) {
      if (seen[item]) return false;
      seen[item] = true;
      return true;
    });
  }
},
  set: function set() {
  var args = typeof arguments[0] === 'object' ? arguments[0] : arguments;
  var ret = {};
  for (var i = 0; i < args.length; i++) {
    ret[args[i]] = 0;
  }
  return ret;
},
  STACK_ALIGN: 8,
  getAlignSize: function (type, size, vararg) {
    // we align i64s and doubles on 64-bit boundaries, unlike x86
    if (type == 'i64' || type == 'double' || vararg) return 8;
    if (!type) return Math.min(size, 8); // align structures internally to 64 bits
    return Math.min(size || (type ? Runtime.getNativeFieldSize(type) : 0), Runtime.QUANTUM_SIZE);
  },
  calculateStructAlignment: function calculateStructAlignment(type) {
    type.flatSize = 0;
    type.alignSize = 0;
    var diffs = [];
    var prev = -1;
    var index = 0;
    type.flatIndexes = type.fields.map(function(field) {
      index++;
      var size, alignSize;
      if (Runtime.isNumberType(field) || Runtime.isPointerType(field)) {
        size = Runtime.getNativeTypeSize(field); // pack char; char; in structs, also char[X]s.
        alignSize = Runtime.getAlignSize(field, size);
      } else if (Runtime.isStructType(field)) {
        if (field[1] === '0') {
          // this is [0 x something]. When inside another structure like here, it must be at the end,
          // and it adds no size
          // XXX this happens in java-nbody for example... assert(index === type.fields.length, 'zero-length in the middle!');
          size = 0;
          if (Types.types[field]) {
            alignSize = Runtime.getAlignSize(null, Types.types[field].alignSize);
          } else {
            alignSize = type.alignSize || QUANTUM_SIZE;
          }
        } else {
          size = Types.types[field].flatSize;
          alignSize = Runtime.getAlignSize(null, Types.types[field].alignSize);
        }
      } else if (field[0] == 'b') {
        // bN, large number field, like a [N x i8]
        size = field.substr(1)|0;
        alignSize = 1;
      } else if (field[0] === '<') {
        // vector type
        size = alignSize = Types.types[field].flatSize; // fully aligned
      } else if (field[0] === 'i') {
        // illegal integer field, that could not be legalized because it is an internal structure field
        // it is ok to have such fields, if we just use them as markers of field size and nothing more complex
        size = alignSize = parseInt(field.substr(1))/8;
        assert(size % 1 === 0, 'cannot handle non-byte-size field ' + field);
      } else {
        assert(false, 'invalid type for calculateStructAlignment');
      }
      if (type.packed) alignSize = 1;
      type.alignSize = Math.max(type.alignSize, alignSize);
      var curr = Runtime.alignMemory(type.flatSize, alignSize); // if necessary, place this on aligned memory
      type.flatSize = curr + size;
      if (prev >= 0) {
        diffs.push(curr-prev);
      }
      prev = curr;
      return curr;
    });
    if (type.name_[0] === '[') {
      // arrays have 2 elements, so we get the proper difference. then we scale here. that way we avoid
      // allocating a potentially huge array for [999999 x i8] etc.
      type.flatSize = parseInt(type.name_.substr(1))*type.flatSize/2;
    }
    type.flatSize = Runtime.alignMemory(type.flatSize, type.alignSize);
    if (diffs.length == 0) {
      type.flatFactor = type.flatSize;
    } else if (Runtime.dedup(diffs).length == 1) {
      type.flatFactor = diffs[0];
    }
    type.needsFlattening = (type.flatFactor != 1);
    return type.flatIndexes;
  },
  generateStructInfo: function (struct, typeName, offset) {
    var type, alignment;
    if (typeName) {
      offset = offset || 0;
      type = (typeof Types === 'undefined' ? Runtime.typeInfo : Types.types)[typeName];
      if (!type) return null;
      if (type.fields.length != struct.length) {
        printErr('Number of named fields must match the type for ' + typeName + ': possibly duplicate struct names. Cannot return structInfo');
        return null;
      }
      alignment = type.flatIndexes;
    } else {
      var type = { fields: struct.map(function(item) { return item[0] }) };
      alignment = Runtime.calculateStructAlignment(type);
    }
    var ret = {
      __size__: type.flatSize
    };
    if (typeName) {
      struct.forEach(function(item, i) {
        if (typeof item === 'string') {
          ret[item] = alignment[i] + offset;
        } else {
          // embedded struct
          var key;
          for (var k in item) key = k;
          ret[key] = Runtime.generateStructInfo(item[key], type.fields[i], alignment[i]);
        }
      });
    } else {
      struct.forEach(function(item, i) {
        ret[item[1]] = alignment[i];
      });
    }
    return ret;
  },
  dynCall: function (sig, ptr, args) {
    if (args && args.length) {
      if (!args.splice) args = Array.prototype.slice.call(args);
      args.splice(0, 0, ptr);
      return Module['dynCall_' + sig].apply(null, args);
    } else {
      return Module['dynCall_' + sig].call(null, ptr);
    }
  },
  functionPointers: [],
  addFunction: function (func) {
    for (var i = 0; i < Runtime.functionPointers.length; i++) {
      if (!Runtime.functionPointers[i]) {
        Runtime.functionPointers[i] = func;
        return 2*(1 + i);
      }
    }
    throw 'Finished up all reserved function pointers. Use a higher value for RESERVED_FUNCTION_POINTERS.';
  },
  removeFunction: function (index) {
    Runtime.functionPointers[(index-2)/2] = null;
  },
  warnOnce: function (text) {
    if (!Runtime.warnOnce.shown) Runtime.warnOnce.shown = {};
    if (!Runtime.warnOnce.shown[text]) {
      Runtime.warnOnce.shown[text] = 1;
      Module.printErr(text);
    }
  },
  funcWrappers: {},
  getFuncWrapper: function (func, sig) {
    assert(sig);
    if (!Runtime.funcWrappers[func]) {
      Runtime.funcWrappers[func] = function dynCall_wrapper() {
        return Runtime.dynCall(sig, func, arguments);
      };
    }
    return Runtime.funcWrappers[func];
  },
  UTF8Processor: function () {
    var buffer = [];
    var needed = 0;
    this.processCChar = function (code) {
      code = code & 0xFF;
      if (buffer.length == 0) {
        if ((code & 0x80) == 0x00) {        // 0xxxxxxx
          return String.fromCharCode(code);
        }
        buffer.push(code);
        if ((code & 0xE0) == 0xC0) {        // 110xxxxx
          needed = 1;
        } else if ((code & 0xF0) == 0xE0) { // 1110xxxx
          needed = 2;
        } else {                            // 11110xxx
          needed = 3;
        }
        return '';
      }
      if (needed) {
        buffer.push(code);
        needed--;
        if (needed > 0) return '';
      }
      var c1 = buffer[0];
      var c2 = buffer[1];
      var c3 = buffer[2];
      var c4 = buffer[3];
      var ret;
      if (buffer.length == 2) {
        ret = String.fromCharCode(((c1 & 0x1F) << 6)  | (c2 & 0x3F));
      } else if (buffer.length == 3) {
        ret = String.fromCharCode(((c1 & 0x0F) << 12) | ((c2 & 0x3F) << 6)  | (c3 & 0x3F));
      } else {
        // http://mathiasbynens.be/notes/javascript-encoding#surrogate-formulae
        var codePoint = ((c1 & 0x07) << 18) | ((c2 & 0x3F) << 12) |
                        ((c3 & 0x3F) << 6)  | (c4 & 0x3F);
        ret = String.fromCharCode(
          Math.floor((codePoint - 0x10000) / 0x400) + 0xD800,
          (codePoint - 0x10000) % 0x400 + 0xDC00);
      }
      buffer.length = 0;
      return ret;
    }
    this.processJSString = function processJSString(string) {
      string = unescape(encodeURIComponent(string));
      var ret = [];
      for (var i = 0; i < string.length; i++) {
        ret.push(string.charCodeAt(i));
      }
      return ret;
    }
  },
  stackAlloc: function (size) { var ret = STACKTOP;STACKTOP = (STACKTOP + size)|0;STACKTOP = (((STACKTOP)+7)&-8); return ret; },
  staticAlloc: function (size) { var ret = STATICTOP;STATICTOP = (STATICTOP + size)|0;STATICTOP = (((STATICTOP)+7)&-8); return ret; },
  dynamicAlloc: function (size) { var ret = DYNAMICTOP;DYNAMICTOP = (DYNAMICTOP + size)|0;DYNAMICTOP = (((DYNAMICTOP)+7)&-8); if (DYNAMICTOP >= TOTAL_MEMORY) enlargeMemory();; return ret; },
  alignMemory: function (size,quantum) { var ret = size = Math.ceil((size)/(quantum ? quantum : 8))*(quantum ? quantum : 8); return ret; },
  makeBigInt: function (low,high,unsigned) { var ret = (unsigned ? ((+((low>>>0)))+((+((high>>>0)))*(+4294967296))) : ((+((low>>>0)))+((+((high|0)))*(+4294967296)))); return ret; },
  GLOBAL_BASE: 8,
  QUANTUM_SIZE: 4,
  __dummy__: 0
}
//========================================
// Runtime essentials
//========================================
var __THREW__ = 0; // Used in checking for thrown exceptions.
var ABORT = false; // whether we are quitting the application. no code should run after this. set in exit() and abort()
var EXITSTATUS = 0;
var undef = 0;
// tempInt is used for 32-bit signed values or smaller. tempBigInt is used
// for 32-bit unsigned values or more than 32 bits. TODO: audit all uses of tempInt
var tempValue, tempInt, tempBigInt, tempInt2, tempBigInt2, tempPair, tempBigIntI, tempBigIntR, tempBigIntS, tempBigIntP, tempBigIntD;
var tempI64, tempI64b;
var tempRet0, tempRet1, tempRet2, tempRet3, tempRet4, tempRet5, tempRet6, tempRet7, tempRet8, tempRet9;
function assert(condition, text) {
  if (!condition) {
    abort('Assertion failed: ' + text);
  }
}
var globalScope = this;
// C calling interface. A convenient way to call C functions (in C files, or
// defined with extern "C").
//
// Note: LLVM optimizations can inline and remove functions, after which you will not be
//       able to call them. Closure can also do so. To avoid that, add your function to
//       the exports using something like
//
//         -s EXPORTED_FUNCTIONS='["_main", "_myfunc"]'
//
// @param ident      The name of the C function (note that C++ functions will be name-mangled - use extern "C")
// @param returnType The return type of the function, one of the JS types 'number', 'string' or 'array' (use 'number' for any C pointer, and
//                   'array' for JavaScript arrays and typed arrays; note that arrays are 8-bit).
// @param argTypes   An array of the types of arguments for the function (if there are no arguments, this can be ommitted). Types are as in returnType,
//                   except that 'array' is not possible (there is no way for us to know the length of the array)
// @param args       An array of the arguments to the function, as native JS values (as in returnType)
//                   Note that string arguments will be stored on the stack (the JS string will become a C string on the stack).
// @return           The return value, as a native JS value (as in returnType)
function ccall(ident, returnType, argTypes, args) {
  return ccallFunc(getCFunc(ident), returnType, argTypes, args);
}
Module["ccall"] = ccall;
// Returns the C function with a specified identifier (for C++, you need to do manual name mangling)
function getCFunc(ident) {
  try {
    var func = Module['_' + ident]; // closure exported function
    if (!func) func = eval('_' + ident); // explicit lookup
  } catch(e) {
  }
  assert(func, 'Cannot call unknown function ' + ident + ' (perhaps LLVM optimizations or closure removed it?)');
  return func;
}
// Internal function that does a C call using a function, not an identifier
function ccallFunc(func, returnType, argTypes, args) {
  var stack = 0;
  function toC(value, type) {
    if (type == 'string') {
      if (value === null || value === undefined || value === 0) return 0; // null string
      value = intArrayFromString(value);
      type = 'array';
    }
    if (type == 'array') {
      if (!stack) stack = Runtime.stackSave();
      var ret = Runtime.stackAlloc(value.length);
      writeArrayToMemory(value, ret);
      return ret;
    }
    return value;
  }
  function fromC(value, type) {
    if (type == 'string') {
      return Pointer_stringify(value);
    }
    assert(type != 'array');
    return value;
  }
  var i = 0;
  var cArgs = args ? args.map(function(arg) {
    return toC(arg, argTypes[i++]);
  }) : [];
  var ret = fromC(func.apply(null, cArgs), returnType);
  if (stack) Runtime.stackRestore(stack);
  return ret;
}
// Returns a native JS wrapper for a C function. This is similar to ccall, but
// returns a function you can call repeatedly in a normal way. For example:
//
//   var my_function = cwrap('my_c_function', 'number', ['number', 'number']);
//   alert(my_function(5, 22));
//   alert(my_function(99, 12));
//
function cwrap(ident, returnType, argTypes) {
  var func = getCFunc(ident);
  return function() {
    return ccallFunc(func, returnType, argTypes, Array.prototype.slice.call(arguments));
  }
}
Module["cwrap"] = cwrap;
// Sets a value in memory in a dynamic way at run-time. Uses the
// type data. This is the same as makeSetValue, except that
// makeSetValue is done at compile-time and generates the needed
// code then, whereas this function picks the right code at
// run-time.
// Note that setValue and getValue only do *aligned* writes and reads!
// Note that ccall uses JS types as for defining types, while setValue and
// getValue need LLVM types ('i8', 'i32') - this is a lower-level operation
function setValue(ptr, value, type, noSafe) {
  type = type || 'i8';
  if (type.charAt(type.length-1) === '*') type = 'i32'; // pointers are 32-bit
    switch(type) {
      case 'i1': HEAP8[(ptr)]=value; break;
      case 'i8': HEAP8[(ptr)]=value; break;
      case 'i16': HEAP16[((ptr)>>1)]=value; break;
      case 'i32': HEAP32[((ptr)>>2)]=value; break;
      case 'i64': (tempI64 = [value>>>0,(tempDouble=value,(+(Math_abs(tempDouble))) >= (+1) ? (tempDouble > (+0) ? ((Math_min((+(Math_floor((tempDouble)/(+4294967296)))), (+4294967295)))|0)>>>0 : (~~((+(Math_ceil((tempDouble - +(((~~(tempDouble)))>>>0))/(+4294967296))))))>>>0) : 0)],HEAP32[((ptr)>>2)]=tempI64[0],HEAP32[(((ptr)+(4))>>2)]=tempI64[1]); break;
      case 'float': HEAPF32[((ptr)>>2)]=value; break;
      case 'double': HEAPF64[((ptr)>>3)]=value; break;
      default: abort('invalid type for setValue: ' + type);
    }
}
Module['setValue'] = setValue;
// Parallel to setValue.
function getValue(ptr, type, noSafe) {
  type = type || 'i8';
  if (type.charAt(type.length-1) === '*') type = 'i32'; // pointers are 32-bit
    switch(type) {
      case 'i1': return HEAP8[(ptr)];
      case 'i8': return HEAP8[(ptr)];
      case 'i16': return HEAP16[((ptr)>>1)];
      case 'i32': return HEAP32[((ptr)>>2)];
      case 'i64': return HEAP32[((ptr)>>2)];
      case 'float': return HEAPF32[((ptr)>>2)];
      case 'double': return HEAPF64[((ptr)>>3)];
      default: abort('invalid type for setValue: ' + type);
    }
  return null;
}
Module['getValue'] = getValue;
var ALLOC_NORMAL = 0; // Tries to use _malloc()
var ALLOC_STACK = 1; // Lives for the duration of the current function call
var ALLOC_STATIC = 2; // Cannot be freed
var ALLOC_DYNAMIC = 3; // Cannot be freed except through sbrk
var ALLOC_NONE = 4; // Do not allocate
Module['ALLOC_NORMAL'] = ALLOC_NORMAL;
Module['ALLOC_STACK'] = ALLOC_STACK;
Module['ALLOC_STATIC'] = ALLOC_STATIC;
Module['ALLOC_DYNAMIC'] = ALLOC_DYNAMIC;
Module['ALLOC_NONE'] = ALLOC_NONE;
// allocate(): This is for internal use. You can use it yourself as well, but the interface
//             is a little tricky (see docs right below). The reason is that it is optimized
//             for multiple syntaxes to save space in generated code. So you should
//             normally not use allocate(), and instead allocate memory using _malloc(),
//             initialize it with setValue(), and so forth.
// @slab: An array of data, or a number. If a number, then the size of the block to allocate,
//        in *bytes* (note that this is sometimes confusing: the next parameter does not
//        affect this!)
// @types: Either an array of types, one for each byte (or 0 if no type at that position),
//         or a single type which is used for the entire block. This only matters if there
//         is initial data - if @slab is a number, then this does not matter at all and is
//         ignored.
// @allocator: How to allocate memory, see ALLOC_*
function allocate(slab, types, allocator, ptr) {
  var zeroinit, size;
  if (typeof slab === 'number') {
    zeroinit = true;
    size = slab;
  } else {
    zeroinit = false;
    size = slab.length;
  }
  var singleType = typeof types === 'string' ? types : null;
  var ret;
  if (allocator == ALLOC_NONE) {
    ret = ptr;
  } else {
    ret = [_malloc, Runtime.stackAlloc, Runtime.staticAlloc, Runtime.dynamicAlloc][allocator === undefined ? ALLOC_STATIC : allocator](Math.max(size, singleType ? 1 : types.length));
  }
  if (zeroinit) {
    var ptr = ret, stop;
    assert((ret & 3) == 0);
    stop = ret + (size & ~3);
    for (; ptr < stop; ptr += 4) {
      HEAP32[((ptr)>>2)]=0;
    }
    stop = ret + size;
    while (ptr < stop) {
      HEAP8[((ptr++)|0)]=0;
    }
    return ret;
  }
  if (singleType === 'i8') {
    if (slab.subarray || slab.slice) {
      HEAPU8.set(slab, ret);
    } else {
      HEAPU8.set(new Uint8Array(slab), ret);
    }
    return ret;
  }
  var i = 0, type, typeSize, previousType;
  while (i < size) {
    var curr = slab[i];
    if (typeof curr === 'function') {
      curr = Runtime.getFunctionIndex(curr);
    }
    type = singleType || types[i];
    if (type === 0) {
      i++;
      continue;
    }
    if (type == 'i64') type = 'i32'; // special case: we have one i32 here, and one i32 later
    setValue(ret+i, curr, type);
    // no need to look up size unless type changes, so cache it
    if (previousType !== type) {
      typeSize = Runtime.getNativeTypeSize(type);
      previousType = type;
    }
    i += typeSize;
  }
  return ret;
}
Module['allocate'] = allocate;
function Pointer_stringify(ptr, /* optional */ length) {
  // TODO: use TextDecoder
  // Find the length, and check for UTF while doing so
  var hasUtf = false;
  var t;
  var i = 0;
  while (1) {
    t = HEAPU8[(((ptr)+(i))|0)];
    if (t >= 128) hasUtf = true;
    else if (t == 0 && !length) break;
    i++;
    if (length && i == length) break;
  }
  if (!length) length = i;
  var ret = '';
  if (!hasUtf) {
    var MAX_CHUNK = 1024; // split up into chunks, because .apply on a huge string can overflow the stack
    var curr;
    while (length > 0) {
      curr = String.fromCharCode.apply(String, HEAPU8.subarray(ptr, ptr + Math.min(length, MAX_CHUNK)));
      ret = ret ? ret + curr : curr;
      ptr += MAX_CHUNK;
      length -= MAX_CHUNK;
    }
    return ret;
  }
  var utf8 = new Runtime.UTF8Processor();
  for (i = 0; i < length; i++) {
    t = HEAPU8[(((ptr)+(i))|0)];
    ret += utf8.processCChar(t);
  }
  return ret;
}
Module['Pointer_stringify'] = Pointer_stringify;
// Given a pointer 'ptr' to a null-terminated UTF16LE-encoded string in the emscripten HEAP, returns
// a copy of that string as a Javascript String object.
function UTF16ToString(ptr) {
  var i = 0;
  var str = '';
  while (1) {
    var codeUnit = HEAP16[(((ptr)+(i*2))>>1)];
    if (codeUnit == 0)
      return str;
    ++i;
    // fromCharCode constructs a character from a UTF-16 code unit, so we can pass the UTF16 string right through.
    str += String.fromCharCode(codeUnit);
  }
}
Module['UTF16ToString'] = UTF16ToString;
// Copies the given Javascript String object 'str' to the emscripten HEAP at address 'outPtr', 
// null-terminated and encoded in UTF16LE form. The copy will require at most (str.length*2+1)*2 bytes of space in the HEAP.
function stringToUTF16(str, outPtr) {
  for(var i = 0; i < str.length; ++i) {
    // charCodeAt returns a UTF-16 encoded code unit, so it can be directly written to the HEAP.
    var codeUnit = str.charCodeAt(i); // possibly a lead surrogate
    HEAP16[(((outPtr)+(i*2))>>1)]=codeUnit
  }
  // Null-terminate the pointer to the HEAP.
  HEAP16[(((outPtr)+(str.length*2))>>1)]=0
}
Module['stringToUTF16'] = stringToUTF16;
// Given a pointer 'ptr' to a null-terminated UTF32LE-encoded string in the emscripten HEAP, returns
// a copy of that string as a Javascript String object.
function UTF32ToString(ptr) {
  var i = 0;
  var str = '';
  while (1) {
    var utf32 = HEAP32[(((ptr)+(i*4))>>2)];
    if (utf32 == 0)
      return str;
    ++i;
    // Gotcha: fromCharCode constructs a character from a UTF-16 encoded code (pair), not from a Unicode code point! So encode the code point to UTF-16 for constructing.
    if (utf32 >= 0x10000) {
      var ch = utf32 - 0x10000;
      str += String.fromCharCode(0xD800 | (ch >> 10), 0xDC00 | (ch & 0x3FF));
    } else {
      str += String.fromCharCode(utf32);
    }
  }
}
Module['UTF32ToString'] = UTF32ToString;
// Copies the given Javascript String object 'str' to the emscripten HEAP at address 'outPtr', 
// null-terminated and encoded in UTF32LE form. The copy will require at most (str.length+1)*4 bytes of space in the HEAP,
// but can use less, since str.length does not return the number of characters in the string, but the number of UTF-16 code units in the string.
function stringToUTF32(str, outPtr) {
  var iChar = 0;
  for(var iCodeUnit = 0; iCodeUnit < str.length; ++iCodeUnit) {
    // Gotcha: charCodeAt returns a 16-bit word that is a UTF-16 encoded code unit, not a Unicode code point of the character! We must decode the string to UTF-32 to the heap.
    var codeUnit = str.charCodeAt(iCodeUnit); // possibly a lead surrogate
    if (codeUnit >= 0xD800 && codeUnit <= 0xDFFF) {
      var trailSurrogate = str.charCodeAt(++iCodeUnit);
      codeUnit = 0x10000 + ((codeUnit & 0x3FF) << 10) | (trailSurrogate & 0x3FF);
    }
    HEAP32[(((outPtr)+(iChar*4))>>2)]=codeUnit
    ++iChar;
  }
  // Null-terminate the pointer to the HEAP.
  HEAP32[(((outPtr)+(iChar*4))>>2)]=0
}
Module['stringToUTF32'] = stringToUTF32;
function demangle(func) {
  try {
    if (typeof func === 'number') func = Pointer_stringify(func);
    if (func[0] !== '_') return func;
    if (func[1] !== '_') return func; // C function
    if (func[2] !== 'Z') return func;
    var i = 3;
    // params, etc.
    var basicTypes = {
      'v': 'void',
      'b': 'bool',
      'c': 'char',
      's': 'short',
      'i': 'int',
      'l': 'long',
      'f': 'float',
      'd': 'double',
      'w': 'wchar_t',
      'a': 'signed char',
      'h': 'unsigned char',
      't': 'unsigned short',
      'j': 'unsigned int',
      'm': 'unsigned long',
      'x': 'long long',
      'y': 'unsigned long long',
      'z': '...'
    };
    function dump(x) {
      //return;
      if (x) Module.print(x);
      Module.print(func);
      var pre = '';
      for (var a = 0; a < i; a++) pre += ' ';
      Module.print (pre + '^');
    }
    var subs = [];
    function parseNested() {
      i++;
      if (func[i] === 'K') i++;
      var parts = [];
      while (func[i] !== 'E') {
        if (func[i] === 'S') { // substitution
          i++;
          var next = func.indexOf('_', i);
          var num = func.substring(i, next) || 0;
          parts.push(subs[num] || '?');
          i = next+1;
          continue;
        }
        var size = parseInt(func.substr(i));
        var pre = size.toString().length;
        if (!size || !pre) { i--; break; } // counter i++ below us
        var curr = func.substr(i + pre, size);
        parts.push(curr);
        subs.push(curr);
        i += pre + size;
      }
      i++; // skip E
      return parts;
    }
    function parse(rawList, limit, allowVoid) { // main parser
      limit = limit || Infinity;
      var ret = '', list = [];
      function flushList() {
        return '(' + list.join(', ') + ')';
      }
      var name;
      if (func[i] !== 'N') {
        // not namespaced
        if (func[i] === 'K') i++;
        var size = parseInt(func.substr(i));
        if (size) {
          var pre = size.toString().length;
          name = func.substr(i + pre, size);
          i += pre + size;
        }
      } else {
        // namespaced N-E
        name = parseNested().join('::');
        limit--;
        if (limit === 0) return rawList ? [name] : name;
      }
      if (func[i] === 'I') {
        i++;
        var iList = parse(true);
        var iRet = parse(true, 1, true);
        ret += iRet[0] + ' ' + name + '<' + iList.join(', ') + '>';
      } else {
        ret = name;
      }
      paramLoop: while (i < func.length && limit-- > 0) {
        //dump('paramLoop');
        var c = func[i++];
        if (c in basicTypes) {
          list.push(basicTypes[c]);
        } else {
          switch (c) {
            case 'P': list.push(parse(true, 1, true)[0] + '*'); break; // pointer
            case 'R': list.push(parse(true, 1, true)[0] + '&'); break; // reference
            case 'L': { // literal
              i++; // skip basic type
              var end = func.indexOf('E', i);
              var size = end - i;
              list.push(func.substr(i, size));
              i += size + 2; // size + 'EE'
              break;
            }
            case 'A': { // array
              var size = parseInt(func.substr(i));
              i += size.toString().length;
              if (func[i] !== '_') throw '?';
              i++; // skip _
              list.push(parse(true, 1, true)[0] + ' [' + size + ']');
              break;
            }
            case 'E': break paramLoop;
            default: ret += '?' + c; break paramLoop;
          }
        }
      }
      if (!allowVoid && list.length === 1 && list[0] === 'void') list = []; // avoid (void)
      return rawList ? list : ret + flushList();
    }
    return parse();
  } catch(e) {
    return func;
  }
}
function demangleAll(text) {
  return text.replace(/__Z[\w\d_]+/g, function(x) { var y = demangle(x); return x === y ? x : (x + ' [' + y + ']') });
}
function stackTrace() {
  var stack = new Error().stack;
  return stack ? demangleAll(stack) : '(no stack trace available)'; // Stack trace is not available at least on IE10 and Safari 6.
}
// Memory management
var PAGE_SIZE = 4096;
function alignMemoryPage(x) {
  return (x+4095)&-4096;
}
var HEAP;
var HEAP8, HEAPU8, HEAP16, HEAPU16, HEAP32, HEAPU32, HEAPF32, HEAPF64;
var STATIC_BASE = 0, STATICTOP = 0, staticSealed = false; // static area
var STACK_BASE = 0, STACKTOP = 0, STACK_MAX = 0; // stack area
var DYNAMIC_BASE = 0, DYNAMICTOP = 0; // dynamic area handled by sbrk
function enlargeMemory() {
  abort('Cannot enlarge memory arrays in asm.js. Either (1) compile with -s TOTAL_MEMORY=X with X higher than the current value ' + TOTAL_MEMORY + ', or (2) set Module.TOTAL_MEMORY before the program runs.');
}
var TOTAL_STACK = Module['TOTAL_STACK'] || 5242880;
var TOTAL_MEMORY = Module['TOTAL_MEMORY'] || 201326592;
var FAST_MEMORY = Module['FAST_MEMORY'] || 2097152;
// Initialize the runtime's memory
// check for full engine support (use string 'subarray' to avoid closure compiler confusion)
assert(typeof Int32Array !== 'undefined' && typeof Float64Array !== 'undefined' && !!(new Int32Array(1)['subarray']) && !!(new Int32Array(1)['set']),
       'Cannot fallback to non-typed array case: Code is too specialized');
var buffer = new ArrayBuffer(TOTAL_MEMORY);
HEAP8 = new Int8Array(buffer);
HEAP16 = new Int16Array(buffer);
HEAP32 = new Int32Array(buffer);
HEAPU8 = new Uint8Array(buffer);
HEAPU16 = new Uint16Array(buffer);
HEAPU32 = new Uint32Array(buffer);
HEAPF32 = new Float32Array(buffer);
HEAPF64 = new Float64Array(buffer);
// Endianness check (note: assumes compiler arch was little-endian)
HEAP32[0] = 255;
assert(HEAPU8[0] === 255 && HEAPU8[3] === 0, 'Typed arrays 2 must be run on a little-endian system');
Module['HEAP'] = HEAP;
Module['HEAP8'] = HEAP8;
Module['HEAP16'] = HEAP16;
Module['HEAP32'] = HEAP32;
Module['HEAPU8'] = HEAPU8;
Module['HEAPU16'] = HEAPU16;
Module['HEAPU32'] = HEAPU32;
Module['HEAPF32'] = HEAPF32;
Module['HEAPF64'] = HEAPF64;
function callRuntimeCallbacks(callbacks) {
  while(callbacks.length > 0) {
    var callback = callbacks.shift();
    if (typeof callback == 'function') {
      callback();
      continue;
    }
    var func = callback.func;
    if (typeof func === 'number') {
      if (callback.arg === undefined) {
        Runtime.dynCall('v', func);
      } else {
        Runtime.dynCall('vi', func, [callback.arg]);
      }
    } else {
      func(callback.arg === undefined ? null : callback.arg);
    }
  }
}
var __ATPRERUN__  = []; // functions called before the runtime is initialized
var __ATINIT__    = []; // functions called during startup
var __ATMAIN__    = []; // functions called when main() is to be run
var __ATEXIT__    = []; // functions called during shutdown
var __ATPOSTRUN__ = []; // functions called after the runtime has exited
var runtimeInitialized = false;
function preRun() {
  // compatibility - merge in anything from Module['preRun'] at this time
  if (Module['preRun']) {
    if (typeof Module['preRun'] == 'function') Module['preRun'] = [Module['preRun']];
    while (Module['preRun'].length) {
      addOnPreRun(Module['preRun'].shift());
    }
  }
  callRuntimeCallbacks(__ATPRERUN__);
}
function ensureInitRuntime() {
  if (runtimeInitialized) return;
  runtimeInitialized = true;
  callRuntimeCallbacks(__ATINIT__);
}
function preMain() {
  callRuntimeCallbacks(__ATMAIN__);
}
function exitRuntime() {
  callRuntimeCallbacks(__ATEXIT__);
}
function postRun() {
  // compatibility - merge in anything from Module['postRun'] at this time
  if (Module['postRun']) {
    if (typeof Module['postRun'] == 'function') Module['postRun'] = [Module['postRun']];
    while (Module['postRun'].length) {
      addOnPostRun(Module['postRun'].shift());
    }
  }
  callRuntimeCallbacks(__ATPOSTRUN__);
}
function addOnPreRun(cb) {
  __ATPRERUN__.unshift(cb);
}
Module['addOnPreRun'] = Module.addOnPreRun = addOnPreRun;
function addOnInit(cb) {
  __ATINIT__.unshift(cb);
}
Module['addOnInit'] = Module.addOnInit = addOnInit;
function addOnPreMain(cb) {
  __ATMAIN__.unshift(cb);
}
Module['addOnPreMain'] = Module.addOnPreMain = addOnPreMain;
function addOnExit(cb) {
  __ATEXIT__.unshift(cb);
}
Module['addOnExit'] = Module.addOnExit = addOnExit;
function addOnPostRun(cb) {
  __ATPOSTRUN__.unshift(cb);
}
Module['addOnPostRun'] = Module.addOnPostRun = addOnPostRun;
// Tools
// This processes a JS string into a C-line array of numbers, 0-terminated.
// For LLVM-originating strings, see parser.js:parseLLVMString function
function intArrayFromString(stringy, dontAddNull, length /* optional */) {
  var ret = (new Runtime.UTF8Processor()).processJSString(stringy);
  if (length) {
    ret.length = length;
  }
  if (!dontAddNull) {
    ret.push(0);
  }
  return ret;
}
Module['intArrayFromString'] = intArrayFromString;
function intArrayToString(array) {
  var ret = [];
  for (var i = 0; i < array.length; i++) {
    var chr = array[i];
    if (chr > 0xFF) {
      chr &= 0xFF;
    }
    ret.push(String.fromCharCode(chr));
  }
  return ret.join('');
}
Module['intArrayToString'] = intArrayToString;
// Write a Javascript array to somewhere in the heap
function writeStringToMemory(string, buffer, dontAddNull) {
  var array = intArrayFromString(string, dontAddNull);
  var i = 0;
  while (i < array.length) {
    var chr = array[i];
    HEAP8[(((buffer)+(i))|0)]=chr
    i = i + 1;
  }
}
Module['writeStringToMemory'] = writeStringToMemory;
function writeArrayToMemory(array, buffer) {
  for (var i = 0; i < array.length; i++) {
    HEAP8[(((buffer)+(i))|0)]=array[i];
  }
}
Module['writeArrayToMemory'] = writeArrayToMemory;
function writeAsciiToMemory(str, buffer, dontAddNull) {
  for (var i = 0; i < str.length; i++) {
    HEAP8[(((buffer)+(i))|0)]=str.charCodeAt(i)
  }
  if (!dontAddNull) HEAP8[(((buffer)+(str.length))|0)]=0
}
Module['writeAsciiToMemory'] = writeAsciiToMemory;
function unSign(value, bits, ignore, sig) {
  if (value >= 0) {
    return value;
  }
  return bits <= 32 ? 2*Math.abs(1 << (bits-1)) + value // Need some trickery, since if bits == 32, we are right at the limit of the bits JS uses in bitshifts
                    : Math.pow(2, bits)         + value;
}
function reSign(value, bits, ignore, sig) {
  if (value <= 0) {
    return value;
  }
  var half = bits <= 32 ? Math.abs(1 << (bits-1)) // abs is needed if bits == 32
                        : Math.pow(2, bits-1);
  if (value >= half && (bits <= 32 || value > half)) { // for huge values, we can hit the precision limit and always get true here. so don't do that
                                                       // but, in general there is no perfect solution here. With 64-bit ints, we get rounding and errors
                                                       // TODO: In i64 mode 1, resign the two parts separately and safely
    value = -2*half + value; // Cannot bitshift half, as it may be at the limit of the bits JS uses in bitshifts
  }
  return value;
}
if (!Math['imul']) Math['imul'] = function imul(a, b) {
  var ah  = a >>> 16;
  var al = a & 0xffff;
  var bh  = b >>> 16;
  var bl = b & 0xffff;
  return (al*bl + ((ah*bl + al*bh) << 16))|0;
};
Math.imul = Math['imul'];
var Math_abs = Math.abs;
var Math_cos = Math.cos;
var Math_sin = Math.sin;
var Math_tan = Math.tan;
var Math_acos = Math.acos;
var Math_asin = Math.asin;
var Math_atan = Math.atan;
var Math_atan2 = Math.atan2;
var Math_exp = Math.exp;
var Math_log = Math.log;
var Math_sqrt = Math.sqrt;
var Math_ceil = Math.ceil;
var Math_floor = Math.floor;
var Math_pow = Math.pow;
var Math_imul = Math.imul;
var Math_toFloat32 = Math.toFloat32;
var Math_min = Math.min;
// A counter of dependencies for calling run(). If we need to
// do asynchronous work before running, increment this and
// decrement it. Incrementing must happen in a place like
// PRE_RUN_ADDITIONS (used by emcc to add file preloading).
// Note that you can add dependencies in preRun, even though
// it happens right before run - run will be postponed until
// the dependencies are met.
var runDependencies = 0;
var runDependencyWatcher = null;
var dependenciesFulfilled = null; // overridden to take different actions when all run dependencies are fulfilled
function addRunDependency(id) {
  runDependencies++;
  if (Module['monitorRunDependencies']) {
    Module['monitorRunDependencies'](runDependencies);
  }
}
Module['addRunDependency'] = addRunDependency;
function removeRunDependency(id) {
  runDependencies--;
  if (Module['monitorRunDependencies']) {
    Module['monitorRunDependencies'](runDependencies);
  }
  if (runDependencies == 0) {
    if (runDependencyWatcher !== null) {
      clearInterval(runDependencyWatcher);
      runDependencyWatcher = null;
    }
    if (dependenciesFulfilled) {
      var callback = dependenciesFulfilled;
      dependenciesFulfilled = null;
      callback(); // can add another dependenciesFulfilled
    }
  }
}
Module['removeRunDependency'] = removeRunDependency;
Module["preloadedImages"] = {}; // maps url to image data
Module["preloadedAudios"] = {}; // maps url to audio data
var memoryInitializer = null;
// === Body ===
STATIC_BASE = 8;
STATICTOP = STATIC_BASE + 14170360;
var _stdout;
var _stdout=_stdout=allocate([0,0,0,0,0,0,0,0], "i8", ALLOC_STATIC);
var _stdin;
var _stdin=_stdin=allocate([0,0,0,0,0,0,0,0], "i8", ALLOC_STATIC);
var _stderr;
var _stderr=_stderr=allocate([0,0,0,0,0,0,0,0], "i8", ALLOC_STATIC);
/* global initializers */ __ATINIT__.push({ func: function() { runPostSets() } },{ func: function() { __GLOBAL__I_a() } },{ func: function() { __GLOBAL__I_a5035() } });
var ___fsmu8;
var ___dso_handle;
var __ZTVN10__cxxabiv120__si_class_type_infoE;
__ZTVN10__cxxabiv120__si_class_type_infoE=allocate([0,0,0,0,88,145,9,0,50,0,0,0,134,2,0,0,198,2,0,0,136,3,0,0,90,39,0,0,98,0,0,0,32,0,0,0,22,0,0,0,0,0,0,0,0,0,0,0], "i8", ALLOC_STATIC);
var __ZTVN10__cxxabiv117__class_type_infoE;
__ZTVN10__cxxabiv117__class_type_infoE=allocate([0,0,0,0,104,145,9,0,50,0,0,0,128,5,0,0,198,2,0,0,136,3,0,0,90,39,0,0,68,0,0,0,22,0,0,0,160,0,0,0,0,0,0,0,0,0,0,0], "i8", ALLOC_STATIC);
/* memory initializer */ allocate([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,57,0,0,0,57,0,0,0,57,0,0,0,57,0,0,0,77,0,0,0,102,0,0,0,128,0,0,0,153,0,0,0,57,0,0,0,57,0,0,0,57,0,0,0,57,0,0,0,77,0,0,0,102,0,0,0,128,0,0,0,153,0,0,0,1,0,0,0,3,0,0,0,5,0,0,0,7,0,0,0,9,0,0,0,11,0,0,0,13,0,0,0,15,0,0,0,255,255,255,255,253,255,255,255,251,255,255,255,249,255,255,255,247,255,255,255,245,255,255,255,243,255,255,255,241,255,255,255,0,39,0,0,10,0,0,0,68,5,0,0,214,7,0,0,220,4,0,0,202,7,0,0,98,2,0,0,192,157,6,0,150,41,0,0,158,5,0,0,228,7,0,0,146,46,0,0,110,9,0,0,90,2,0,0,0,0,0,0,0,0,128,63,0,0,128,63,0,0,128,63,0,0,0,0,0,0,0,0,0,0,128,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,63,0,0,0,0,0,0,0,0,0,0,128,63,0,0,128,63,0,0,128,63,11,0,0,0,10,0,0,0,9,0,0,0,8,0,0,0,7,0,0,0,6,0,0,0,5,0,0,0,4,0,0,0,3,0,0,0,2,0,0,0,1,0,0,0,0,0,0,0,192,186,141,0,128,195,141,0,0,0,0,0,0,0,0,0,0,0,128,63,0,0,0,0,0,0,0,0,0,0,128,63,0,0,128,63,0,0,128,63,73,76,76,18,0,0,0,0,97,97,30,23,240,120,0,23,19,65,30,13,215,247,19,19,19,1,153,4,242,244,17,35,33,97,27,7,175,100,64,39,34,33,30,6,240,117,8,24,49,34,22,5,144,113,0,19,33,97,29,7,130,128,16,23,35,33,45,22,192,112,7,7,97,97,27,6,100,101,16,23,97,97,12,24,133,240,112,7,35,1,7,17,240,164,0,34,151,193,36,7,255,248,34,18,97,16,12,5,242,244,64,68,1,1,85,3,243,146,243,243,97,65,137,3,241,244,240,19,1,1,22,0,253,248,47,109,1,1,0,0,216,216,249,248,5,1,0,0,248,186,73,85,168,127,9,0,0,0,0,0,136,127,9,0,1,0,0,0,216,183,1,0,2,0,0,0,0,202,1,0,3,0,0,0,208,239,2,0,4,0,0,0,128,196,2,0,5,0,0,0,96,165,2,0,6,0,0,0,184,139,2,0,7,0,0,0,176,127,9,0,8,0,0,0,144,127,9,0,9,0,0,0,160,127,9,0,10,0,0,0,24,11,1,0,11,0,0,0,208,246,2,0,12,0,0,0,80,223,2,0,13,0,0,0,216,201,2,0,14,0,0,0,56,183,2,0,15,0,0,0,64,170,2,0,24,0,0,0,168,155,2,0,16,0,0,0,56,143,2,0,17,0,0,0,224,131,2,0,18,0,0,0,72,119,2,0,19,0,0,0,200,104,2,0,20,0,0,0,136,92,2,0,21,0,0,0,216,76,2,0,22,0,0,0,208,64,2,0,23,0,0,0,152,47,2,0,25,0,0,0,232,36,2,0,26,0,0,0,208,26,2,0,27,0,0,0,200,16,2,0,28,0,0,0,240,7,2,0,29,0,0,0,152,0,2,0,30,0,0,0,216,242,1,0,31,0,0,0,96,232,1,0,32,0,0,0,232,218,1,0,33,0,0,0,232,204,1,0,34,0,0,0,120,193,1,0,35,0,0,0,104,186,1,0,36,0,0,0,40,185,3,0,37,0,0,0,160,172,1,0,38,0,0,0,128,164,1,0,39,0,0,0,152,157,1,0,40,0,0,0,176,145,1,0,41,0,0,0,8,134,1,0,42,0,0,0,168,120,1,0,43,0,0,0,88,107,1,0,44,0,0,0,232,95,1,0,45,0,0,0,72,89,1,0,46,0,0,0,128,82,1,0,47,0,0,0,72,75,1,0,48,0,0,0,40,68,1,0,49,0,0,0,232,62,1,0,50,0,0,0,232,54,1,0,51,0,0,0,56,46,1,0,52,0,0,0,224,38,1,0,53,0,0,0,56,29,1,0,54,0,0,0,80,18,1,0,55,0,0,0,16,0,0,0,17,0,0,0,19,0,0,0,21,0,0,0,23,0,0,0,25,0,0,0,28,0,0,0,31,0,0,0,34,0,0,0,37,0,0,0,41,0,0,0,45,0,0,0,50,0,0,0,55,0,0,0,60,0,0,0,66,0,0,0,73,0,0,0,80,0,0,0,88,0,0,0,97,0,0,0,107,0,0,0,118,0,0,0,130,0,0,0,143,0,0,0,157,0,0,0,173,0,0,0,190,0,0,0,209,0,0,0,230,0,0,0,253,0,0,0,23,1,0,0,51,1,0,0,81,1,0,0,115,1,0,0,152,1,0,0,193,1,0,0,238,1,0,0,32,2,0,0,86,2,0,0,146,2,0,0,212,2,0,0,28,3,0,0,108,3,0,0,195,3,0,0,36,4,0,0,142,4,0,0,2,5,0,0,131,5,0,0,16,6,0,0,0,0,0,0,240,255,255,255,240,255,255,255,240,255,255,255,240,255,255,255,32,0,0,0,80,0,0,0,112,0,0,0,144,0,0,0,12,0,8,0,140,0,8,0,76,0,8,0,204,0,8,0,44,0,8,0,172,0,8,0,108,0,8,0,236,0,8,0,28,0,8,0,156,0,8,0,92,0,8,0,220,0,8,0,60,0,8,0,188,0,8,0,124,0,8,0,252,0,8,0,2,0,8,0,130,0,8,0,66,0,8,0,194,0,8,0,34,0,8,0,162,0,8,0,98,0,8,0,226,0,8,0,18,0,8,0,146,0,8,0,82,0,8,0,210,0,8,0,50,0,8,0,178,0,8,0,114,0,8,0,242,0,8,0,10,0,8,0,138,0,8,0,74,0,8,0,202,0,8,0,42,0,8,0,170,0,8,0,106,0,8,0,234,0,8,0,26,0,8,0,154,0,8,0,90,0,8,0,218,0,8,0,58,0,8,0,186,0,8,0,122,0,8,0,250,0,8,0,6,0,8,0,134,0,8,0,70,0,8,0,198,0,8,0,38,0,8,0,166,0,8,0,102,0,8,0,230,0,8,0,22,0,8,0,150,0,8,0,86,0,8,0,214,0,8,0,54,0,8,0,182,0,8,0,118,0,8,0,246,0,8,0,14,0,8,0,142,0,8,0,78,0,8,0,206,0,8,0,46,0,8,0,174,0,8,0,110,0,8,0,238,0,8,0,30,0,8,0,158,0,8,0,94,0,8,0,222,0,8,0,62,0,8,0,190,0,8,0,126,0,8,0,254,0,8,0,1,0,8,0,129,0,8,0,65,0,8,0,193,0,8,0,33,0,8,0,161,0,8,0,97,0,8,0,225,0,8,0,17,0,8,0,145,0,8,0,81,0,8,0,209,0,8,0,49,0,8,0,177,0,8,0,113,0,8,0,241,0,8,0,9,0,8,0,137,0,8,0,73,0,8,0,201,0,8,0,41,0,8,0,169,0,8,0,105,0,8,0,233,0,8,0,25,0,8,0,153,0,8,0,89,0,8,0,217,0,8,0,57,0,8,0,185,0,8,0,121,0,8,0,249,0,8,0,5,0,8,0,133,0,8,0,69,0,8,0,197,0,8,0,37,0,8,0,165,0,8,0,101,0,8,0,229,0,8,0,21,0,8,0,149,0,8,0,85,0,8,0,213,0,8,0,53,0,8,0,181,0,8,0,117,0,8,0,245,0,8,0,13,0,8,0,141,0,8,0,77,0,8,0,205,0,8,0,45,0,8,0,173,0,8,0,109,0,8,0,237,0,8,0,29,0,8,0,157,0,8,0,93,0,8,0,221,0,8,0,61,0,8,0,189,0,8,0,125,0,8,0,253,0,8,0,19,0,9,0,19,1,9,0,147,0,9,0,147,1,9,0,83,0,9,0,83,1,9,0,211,0,9,0,211,1,9,0,51,0,9,0,51,1,9,0,179,0,9,0,179,1,9,0,115,0,9,0,115,1,9,0,243,0,9,0,243,1,9,0,11,0,9,0,11,1,9,0,139,0,9,0,139,1,9,0,75,0,9,0,75,1,9,0,203,0,9,0,203,1,9,0,43,0,9,0,43,1,9,0,171,0,9,0,171,1,9,0,107,0,9,0,107,1,9,0,235,0,9,0,235,1,9,0,27,0,9,0,27,1,9,0,155,0,9,0,155,1,9,0,91,0,9,0,91,1,9,0,219,0,9,0,219,1,9,0,59,0,9,0,59,1,9,0,187,0,9,0,187,1,9,0,123,0,9,0,123,1,9,0,251,0,9,0,251,1,9,0,7,0,9,0,7,1,9,0,135,0,9,0,135,1,9,0,71,0,9,0,71,1,9,0,199,0,9,0,199,1,9,0,39,0,9,0,39,1,9,0,167,0,9,0,167,1,9,0,103,0,9,0,103,1,9,0,231,0,9,0,231,1,9,0,23,0,9,0,23,1,9,0,151,0,9,0,151,1,9,0,87,0,9,0,87,1,9,0,215,0,9,0,215,1,9,0,55,0,9,0,55,1,9,0,183,0,9,0,183,1,9,0,119,0,9,0,119,1,9,0,247,0,9,0,247,1,9,0,15,0,9,0,15,1,9,0,143,0,9,0,143,1,9,0,79,0,9,0,79,1,9,0,207,0,9,0,207,1,9,0,47,0,9,0,47,1,9,0,175,0,9,0,175,1,9,0,111,0,9,0,111,1,9,0,239,0,9,0,239,1,9,0,31,0,9,0,31,1,9,0,159,0,9,0,159,1,9,0,95,0,9,0,95,1,9,0,223,0,9,0,223,1,9,0,63,0,9,0,63,1,9,0,191,0,9,0,191,1,9,0,127,0,9,0,127,1,9,0,255,0,9,0,255,1,9,0,0,0,7,0,64,0,7,0,32,0,7,0,96,0,7,0,16,0,7,0,80,0,7,0,48,0,7,0,112,0,7,0,8,0,7,0,72,0,7,0,40,0,7,0,104,0,7,0,24,0,7,0,88,0,7,0,56,0,7,0,120,0,7,0,4,0,7,0,68,0,7,0,36,0,7,0,100,0,7,0,20,0,7,0,84,0,7,0,52,0,7,0,116,0,7,0,3,0,8,0,131,0,8,0,67,0,8,0,195,0,8,0,35,0,8,0,163,0,8,0,99,0,8,0,227,0,8,0,168,4,0,0,16,201,0,0,1,1,0,0,30,1,0,0,15,0,0,0,0,0,0,0,0,0,5,0,16,0,5,0,8,0,5,0,24,0,5,0,4,0,5,0,20,0,5,0,12,0,5,0,28,0,5,0,2,0,5,0,18,0,5,0,10,0,5,0,26,0,5,0,6,0,5,0,22,0,5,0,14,0,5,0,30,0,5,0,1,0,5,0,17,0,5,0,9,0,5,0,25,0,5,0,5,0,5,0,21,0,5,0,13,0,5,0,29,0,5,0,3,0,5,0,19,0,5,0,11,0,5,0,27,0,5,0,7,0,5,0,23,0,5,0,64,9,0,0,136,201,0,0,0,0,0,0,30,0,0,0,15,0,0,0,0,0,0,0,0,0,0,0,0,202,0,0,0,0,0,0,19,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,210,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,98,47,0,0,0,0,0,0,0,0,0,0,2,0,0,0,4,0,0,0,1,0,0,0,3,0,0,0,5,0,0,0,255,255,255,255,255,255,255,255,6,0,0,0,8,0,0,0,10,0,0,0,7,0,0,0,9,0,0,0,11,0,0,0,255,255,255,255,255,255,255,255,12,0,0,0,14,0,0,0,16,0,0,0,13,0,0,0,15,0,0,0,17,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,0,32,0,0,0,64,0,0,0,96,0,0,0,128,0,0,0,160,0,0,0,192,0,0,0,224,0,0,0,0,1,0,0,32,1,0,0,64,1,0,0,96,1,0,0,128,1,0,0,160,1,0,0,192,1,0,0,224,3,0,0,0,0,0,0,16,0,0,0,32,0,0,0,48,0,0,0,64,0,0,0,80,0,0,0,96,0,0,0,112,0,0,0,128,0,0,0,144,0,0,0,160,0,0,0,176,0,0,0,192,0,0,0,208,0,0,0,224,0,0,0,240,1,0,0,2,0,0,0,132,6,0,0,206,5,0,0,128,225,7,0,93,144,198,144,144,144,42,58,144,144,144,134,144,34,144,243,144,144,144,144,144,56,247,66,4,144,144,31,75,144,144,88,87,46,144,144,83,144,185,144,144,144,144,144,32,85,144,61,160,144,144,12,3,144,131,144,144,144,138,0,144,170,144,144,144,144,144,144,144,144,144,144,144,65,10,38,139,86,94,144,144,116,144,144,144,144,6,144,144,137,91,199,67,144,144,144,144,182,144,59,144,144,144,144,144,54,234,128,144,144,144,95,144,15,144,144,144,70,144,144,60,142,144,163,135,144,144,144,43,251,71,11,144,252,2,144,144,144,144,144,144,144,114,44,51,144,144,144,144,144,157,189,144,178,144,120,117,184,144,144,144,144,144,144,207,90,136,144,144,144,195,144,235,250,144,50,144,144,144,82,180,144,144,144,144,188,144,144,144,177,89,80,144,144,181,144,8,162,191,187,30,156,144,115,144,208,144,144,144,144,144,144,129,144,121,144,144,36,35,144,144,176,7,255,144,186,246,81,144,144,144,254,144,146,144,144,144,144,233,144,144,144,144,144,144,144,232,210,144,24,144,144,144,209,144,144,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,78,111,114,109,97,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,57,48,32,100,101,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,56,48,32,100,101,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,55,48,32,100,101,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,26,7,0,32,126,145,0,208,131,8,0,40,126,145,0,240,152,6,0,224,125,145,0,240,28,5,0,176,125,145,0,248,237,3,0,208,125,145,0,248,15,3,0,144,125,145,0,144,106,2,0,8,126,145,0,80,244,1,0,160,125,145,0,56,147,1,0,152,125,145,0,16,56,1,0,80,126,145,0,232,242,8,0,96,126,145,0,192,177,8,0,88,126,145,0,8,115,8,0,24,126,145,0,128,57,8,0,104,126,145,0,40,5,8,0,48,126,145,0,248,207,7,0,16,126,145,0,248,157,7,0,216,125,145,0,40,113,7,0,64,126,145,0,144,62,7,0,56,126,145,0,232,17,7,0,72,126,145,0,64,230,6,0,0,126,145,0,64,188,6,0,168,125,145,0,96,142,6,0,184,125,145,0,104,98,6,0,200,125,145,0,0,52,6,0,248,125,145,0,32,11,6,0,192,125,145,0,0,219,5,0,240,125,145,0,80,181,5,0,232,125,145,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,248,175,7,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,1,0,0,0,200,171,7,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,2,0,0,0,248,167,7,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,3,0,0,0,184,163,7,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,4,0,0,0,24,135,6,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,5,0,0,0,176,129,6,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,6,0,0,0,240,124,6,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,7,0,0,0,248,119,6,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,8,0,0,0,176,136,7,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,9,0,0,0,176,132,7,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,10,0,0,0,16,129,7,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,11,0,0,0,56,126,7,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,12,0,0,0,232,122,7,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,13,0,0,0,240,118,7,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,14,0,0,0,248,113,7,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,15,0,0,0,112,108,7,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,16,0,0,0,128,102,7,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,17,0,0,0,152,95,7,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,18,0,0,0,32,89,7,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,19,0,0,0,0,83,7,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,20,0,0,0,72,79,7,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,21,0,0,0,24,76,7,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,22,0,0,0,112,72,7,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,23,0,0,0,200,67,7,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,24,0,0,0,80,63,7,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,0,0,0,0,248,175,7,0,122,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,1,0,0,0,200,171,7,0,97,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,2,0,0,0,248,167,7,0,47,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,3,0,0,0,184,163,7,0,13,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,4,0,0,0,24,135,6,0,17,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,5,0,0,0,176,129,6,0,18,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,6,0,0,0,240,124,6,0,20,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,7,0,0,0,248,119,6,0,19,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,8,0,0,0,176,136,7,0,120,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,9,0,0,0,176,132,7,0,115,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,10,0,0,0,16,129,7,0,113,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,11,0,0,0,56,126,7,0,119,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,12,0,0,0,232,122,7,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,13,0,0,0,240,118,7,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,14,0,0,0,248,113,7,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,15,0,0,0,112,108,7,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,16,0,0,0,128,102,7,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,17,0,0,0,152,95,7,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,18,0,0,0,32,89,7,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,19,0,0,0,0,83,7,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,20,0,0,0,72,79,7,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,21,0,0,0,24,76,7,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,22,0,0,0,112,72,7,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,23,0,0,0,200,67,7,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,24,0,0,0,80,63,7,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,25,0,0,0,128,58,7,0,32,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,26,0,0,0,216,51,7,0,108,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,27,0,0,0,208,249,8,0,29,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,28,0,0,0,208,254,8,0,27,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,29,0,0,0,24,36,7,0,102,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,30,0,0,0,152,33,7,0,27,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,31,0,0,0,80,29,7,0,32,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,32,0,0,0,152,26,7,0,31,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,33,0,0,0,104,76,2,0,114,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,34,0,0,0,208,18,7,0,111,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,35,0,0,0,208,13,7,0,112,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,36,0,0,0,136,18,1,0,107,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,37,0,0,0,88,212,3,0,104,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,38,0,0,0,216,251,6,0,109,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,39,0,0,0,104,248,6,0,110,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,40,0,0,0,16,245,6,0,121,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,41,0,0,0,192,240,6,0,116,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,42,0,0,0,168,238,6,0,117,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,43,0,0,0,128,235,6,0,33,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,44,0,0,0,48,231,6,0,99,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,45,0,0,0,200,74,1,0,34,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,46,0,0,0,72,222,6,0,105,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,47,0,0,0,96,217,6,0,101,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,48,0,0,0,16,212,6,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,49,0,0,0,136,67,2,0,14,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,50,0,0,0,8,66,2,0,13,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,51,0,0,0,192,200,6,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,52,0,0,0,128,197,6,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,53,0,0,0,104,194,6,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,54,0,0,0,232,171,8,0,36,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,55,0,0,0,192,183,6,0,26,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,37,0,0,0,20,1,0,0,39,0,0,0,19,1,0,0,38,0,0,0,17,1,0,0,40,0,0,0,18,1,0,0,13,0,0,0,13,0,0,0,9,0,0,0,9,0,0,0,45,0,0,0,21,1,0,0,46,0,0,0,127,0,0,0,16,0,0,0,47,1,0,0,16,0,0,0,48,1,0,0,17,0,0,0,50,1,0,0,35,0,0,0,23,1,0,0,36,0,0,0,22,1,0,0,34,0,0,0,25,1,0,0,33,0,0,0,24,1,0,0,18,0,0,0,52,1,0,0,32,0,0,0,32,0,0,0,27,0,0,0,27,0,0,0,8,0,0,0,8,0,0,0,13,0,0,0,15,1,0,0,107,0,0,0,14,1,0,0,109,0,0,0,13,1,0,0,106,0,0,0,12,1,0,0,111,0,0,0,11,1,0,0,192,0,0,0,96,0,0,0,19,0,0,0,19,0,0,0,96,0,0,0,0,1,0,0,97,0,0,0,1,1,0,0,98,0,0,0,2,1,0,0,99,0,0,0,3,1,0,0,100,0,0,0,4,1,0,0,101,0,0,0,5,1,0,0,102,0,0,0,6,1,0,0,103,0,0,0,7,1,0,0,104,0,0,0,8,1,0,0,105,0,0,0,9,1,0,0,48,0,0,0,48,0,0,0,49,0,0,0,49,0,0,0,50,0,0,0,50,0,0,0,51,0,0,0,51,0,0,0,52,0,0,0,52,0,0,0,53,0,0,0,53,0,0,0,54,0,0,0,54,0,0,0,55,0,0,0,55,0,0,0,56,0,0,0,56,0,0,0,57,0,0,0,57,0,0,0,112,0,0,0,26,1,0,0,113,0,0,0,27,1,0,0,114,0,0,0,28,1,0,0,115,0,0,0,29,1,0,0,116,0,0,0,30,1,0,0,117,0,0,0,31,1,0,0,118,0,0,0,32,1,0,0,119,0,0,0,33,1,0,0,120,0,0,0,34,1,0,0,121,0,0,0,35,1,0,0,122,0,0,0,36,1,0,0,123,0,0,0,37,1,0,0,65,0,0,0,97,0,0,0,66,0,0,0,98,0,0,0,67,0,0,0,99,0,0,0,68,0,0,0,100,0,0,0,69,0,0,0,101,0,0,0,70,0,0,0,102,0,0,0,71,0,0,0,103,0,0,0,72,0,0,0,104,0,0,0,73,0,0,0,105,0,0,0,74,0,0,0,106,0,0,0,75,0,0,0,107,0,0,0,76,0,0,0,108,0,0,0,77,0,0,0,109,0,0,0,78,0,0,0,110,0,0,0,79,0,0,0,111,0,0,0,80,0,0,0,112,0,0,0,81,0,0,0,113,0,0,0,82,0,0,0,114,0,0,0,83,0,0,0,115,0,0,0,84,0,0,0,116,0,0,0,85,0,0,0,117,0,0,0,86,0,0,0,118,0,0,0,87,0,0,0,119,0,0,0,88,0,0,0,120,0,0,0,89,0,0,0,121,0,0,0,90,0,0,0,122,0,0,0,0,0,0,0,0,0,0,0,32,132,7,0,96,82,7,0,96,35,7,0,136,204,6,0,48,207,6,0,128,160,6,0,112,119,6,0,96,68,6,0,96,29,6,0,192,237,5,0,216,211,5,0,48,237,4,0,72,125,5,0,208,95,5,0,136,65,5,0,240,33,5,0,144,144,144,138,144,170,144,144,144,32,35,85,144,181,10,144,144,70,144,182,144,116,139,144,144,186,1,144,144,90,134,251,178,144,176,144,66,6,30,8,34,157,144,144,144,144,144,115,144,144,95,144,144,208,144,255,144,144,189,144,3,144,185,144,144,144,144,81,94,36,144,144,144,144,144,88,89,144,144,144,82,144,144,144,160,144,144,2,210,144,121,38,58,15,207,180,243,144,144,80,144,117,177,144,209,71,144,144,144,144,144,144,198,144,144,144,144,144,188,144,144,144,144,144,83,65,144,144,144,144,144,144,144,144,4,144,144,144,144,44,144,191,144,144,144,144,232,144,144,120,144,187,144,144,31,43,135,144,75,86,54,51,144,144,144,156,195,144,144,129,144,233,144,250,144,144,144,114,144,162,144,144,199,144,144,146,144,144,136,144,144,144,59,144,12,144,128,144,144,144,144,46,144,144,144,87,144,142,7,144,163,144,144,144,61,144,254,144,144,252,234,144,56,144,60,246,144,144,144,24,144,144,184,144,144,144,42,93,91,144,144,67,50,144,144,144,235,144,144,144,144,144,131,137,144,144,0,0,0,0,0,0,36,64,0,0,0,0,0,0,89,64,0,0,0,0,0,136,195,64,0,0,0,0,132,215,151,65,0,128,224,55,121,195,65,67,23,110,5,181,181,184,147,70,245,249,63,233,3,79,56,77,50,29,48,249,72,119,130,90,60,191,115,127,221,79,21,117,0,0,0,0,73,69,78,68,0,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,4,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,8,0,0,0,2,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,4,0,0,0,1,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,1,0,0,0,2,0,0,0,4,0,0,0,8,0,0,0,1,0,0,0,2,0,0,0,4,0,0,0,8,0,0,0,16,0,0,0,0,0,0,0,137,80,78,71,13,10,26,10,19,5,20,5,21,5,22,5,23,5,24,5,25,5,26,5,28,5,29,5,30,5,31,5,33,5,34,5,35,5,36,5,38,5,39,5,40,5,41,5,42,5,43,5,44,5,45,5,47,5,48,5,49,5,50,5,52,5,53,5,54,5,55,5,57,5,58,5,59,5,60,5,61,5,62,5,63,5,64,5,66,5,67,5,68,5,69,5,71,5,72,5,73,5,74,5,76,5,77,5,78,5,79,5,81,5,82,5,83,5,84,5,86,5,87,5,88,5,89,5,91,5,92,5,93,5,94,5,96,5,97,5,98,5,99,5,101,5,102,5,103,5,104,5,106,5,107,5,108,5,109,5,111,5,112,5,113,5,114,5,116,5,117,5,118,5,119,5,121,5,122,5,123,5,124,5,126,5,127,5,128,5,129,5,131,5,132,5,133,5,134,5,136,5,137,5,138,5,139,5,141,5,142,5,143,5,144,5,146,5,147,5,149,5,150,5,151,5,152,5,154,5,155,5,157,5,158,5,159,5,160,5,162,5,163,5,164,5,165,5,167,5,168,5,169,5,170,5,172,5,173,5,174,5,175,5,178,5,179,5,180,5,181,5,183,5,184,5,185,5,186,5,188,5,189,5,191,5,192,5,193,5,194,5,196,5,197,5,199,5,200,5,201,5,202,5,204,5,205,5,206,5,207,5,209,5,210,5,212,5,213,5,214,5,215,5,217,5,218,5,221,5,222,5,223,5,224,5,226,5,227,5,229,5,230,5,232,5,233,5,234,5,235,5,237,5,238,5,240,5,241,5,243,5,244,5,245,5,246,5,248,5,249,5,251,5,252,5,254,5,255,5,0,6,1,6,3,6,4,6,6,6,7,6,9,6,10,6,11,6,12,6,14,6,15,6,17,6,18,6,20,6,21,6,22,6,23,6,25,6,26,6,28,6,29,6,31,6,32,6,33,6,34,6,36,6,37,6,39,6,40,6,42,6,43,6,44,6,45,6,47,6,48,6,50,6,51,6,54,6,55,6,56,6,57,6,59,6,60,6,62,6,63,6,65,6,66,6,68,6,69,6,71,6,72,6,73,6,74,6,77,6,78,6,79,6,80,6,82,6,83,6,85,6,86,6,88,6,89,6,91,6,92,6,94,6,95,6,96,6,97,6,101,6,102,6,103,6,104,6,106,6,107,6,109,6,110,6,112,6,113,6,115,6,116,6,118,6,119,6,120,6,121,6,124,6,125,6,127,6,128,6,130,6,131,6,133,6,134,6,136,6,137,6,139,6,140,6,142,6,143,6,145,6,146,6,149,6,150,6,152,6,153,6,155,6,156,6,158,6,159,6,161,6,162,6,164,6,165,6,167,6,168,6,170,6,171,6,173,6,174,6,176,6,177,6,179,6,180,6,182,6,183,6,185,6,186,6,188,6,189,6,191,6,192,6,194,6,195,6,198,6,199,6,201,6,202,6,204,6,205,6,207,6,208,6,210,6,212,6,213,6,215,6,216,6,218,6,219,6,221,6,223,6,224,6,226,6,227,6,229,6,230,6,232,6,233,6,235,6,237,6,238,6,240,6,241,6,243,6,244,6,246,6,249,6,250,6,252,6,253,6,255,6,1,7,2,7,4,7,6,7,7,7,9,7,10,7,12,7,14,7,15,7,17,7,19,7,20,7,22,7,23,7,25,7,27,7,28,7,30,7,32,7,33,7,35,7,36,7,38,7,40,7,41,7,43,7,45,7,46,7,48,7,49,7,51,7,53,7,54,7,56,7,58,7,59,7,61,7,62,7,64,7,66,7,67,7,69,7,72,7,73,7,75,7,76,7,78,7,80,7,81,7,83,7,85,7,87,7,88,7,90,7,92,7,93,7,95,7,96,7,99,7,100,7,102,7,103,7,105,7,107,7,108,7,110,7,112,7,114,7,115,7,117,7,119,7,120,7,122,7,123,7,126,7,127,7,129,7,131,7,133,7,134,7,136,7,138,7,140,7,141,7,143,7,145,7,147,7,148,7,150,7,152,7,154,7,155,7,157,7,159,7,161,7,162,7,164,7,166,7,168,7,169,7,171,7,173,7,175,7,176,7,178,7,180,7,183,7,184,7,186,7,188,7,190,7,191,7,193,7,195,7,197,7,198,7,200,7,202,7,204,7,205,7,207,7,209,7,211,7,212,7,214,7,216,7,218,7,219,7,221,7,223,7,225,7,227,7,229,7,230,7,232,7,234,7,236,7,237,7,240,7,241,7,243,7,245,7,247,7,249,7,251,7,252,7,255,7,0,8,2,8,4,8,6,8,8,8,10,8,11,8,14,8,15,8,17,8,19,8,21,8,23,8,25,8,26,8,29,8,30,8,32,8,34,8,36,8,38,8,40,8,41,8,44,8,45,8,47,8,49,8,51,8,53,8,55,8,56,8,59,8,60,8,62,8,64,8,66,8,68,8,70,8,71,8,74,8,75,8,77,8,79,8,81,8,83,8,85,8,86,8,89,8,91,8,93,8,94,8,97,8,98,8,100,8,102,8,105,8,106,8,108,8,110,8,112,8,114,8,116,8,117,8,120,8,122,8,124,8,125,8,128,8,129,8,131,8,133,8,137,8,138,8,140,8,142,8,144,8,146,8,148,8,149,8,152,8,154,8,156,8,157,8,160,8,161,8,163,8,165,8,168,8,170,8,172,8,174,8,175,8,178,8,179,8,182,8,184,8,186,8,188,8,190,8,191,8,194,8,195,8,198,8,201,8,203,8,205,8,207,8,208,8,211,8,212,8,215,8,217,8,219,8,221,8,223,8,224,8,227,8,228,8,231,8,233,8,235,8,237,8,239,8,240,8,243,8,244,8,247,8,249,8,251,8,253,8,255,8,0,9,3,9,4,9,7,9,11,9,13,9,15,9,17,9,18,9,21,9,22,9,25,9,27,9,29,9,31,9,33,9,34,9,37,9,38,9,41,9,44,9,46,9,48,9,50,9,51,9,54,9,55,9,58,9,60,9,62,9,64,9,66,9,67,9,70,9,71,9,74,9,78,9,80,9,82,9,84,9,85,9,88,9,89,9,92,9,94,9,96,9,98,9,100,9,103,9,106,9,107,9,110,9,113,9,115,9,117,9,119,9,120,9,123,9,124,9,127,9,129,9,131,9,133,9,135,9,138,9,141,9,142,9,145,9,148,9,150,9,152,9,154,9,155,9,158,9,159,9,162,9,164,9,166,9,168,9,170,9,173,9,176,9,177,9,180,9,184,9,186,9,188,9,190,9,191,9,194,9,195,9,198,9,200,9,202,9,204,9,206,9,209,9,212,9,213,9,216,9,220,9,222,9,224,9,226,9,227,9,230,9,231,9,234,9,236,9,238,9,240,9,242,9,245,9,248,9,249,9,252,9,1,10,3,10,5,10,7,10,8,10,11,10,12,10,15,10,17,10,19,10,21,10,23,10,26,10,29,10,30,10,33,10,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,3,3,3,3,3,3,3,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,153,153,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,23,0,0,0,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,144,87,144,144,144,144,144,144,191,67,144,144,144,144,252,144,144,144,144,144,144,82,163,38,144,199,144,15,144,12,144,144,144,144,255,144,144,2,144,144,46,144,95,144,144,144,115,80,178,58,144,144,187,144,144,144,144,144,144,144,144,144,144,144,144,144,142,60,66,144,144,185,144,144,42,144,71,160,43,3,181,31,144,170,144,251,144,144,144,144,144,144,56,144,144,144,44,144,144,198,144,144,177,144,144,144,144,144,144,144,162,144,233,232,144,144,134,144,139,144,144,144,144,144,91,114,144,144,144,144,93,10,144,144,137,144,176,136,144,144,144,135,117,189,144,81,144,144,144,144,144,144,144,144,144,90,88,144,144,86,144,138,144,85,144,144,144,180,8,144,246,144,144,157,144,188,11,144,144,94,144,144,144,34,54,144,30,144,182,186,35,144,32,144,144,144,89,83,144,4,129,144,144,243,144,144,59,6,144,121,131,156,144,24,128,144,195,144,144,144,50,144,207,144,235,144,144,51,144,250,144,144,210,144,36,144,116,65,184,144,144,144,208,7,144,144,144,144,144,70,144,234,254,120,144,144,1,2,4,6,8,10,12,14,16,18,20,20,24,24,30,30,0,0,0,0,0,0,0,0,4,0,0,0,5,0,0,0,8,0,0,0,0,0,0,0,55,0,0,0,30,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,2,0,0,0,1,1,0,0,4,1,0,0,4,2,0,0,4,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,186,141,0,0,0,0,0,120,10,0,0,166,10,0,0,182,0,0,0,130,10,0,0,18,2,0,0,0,0,0,0,0,0,0,0,128,120,7,0,144,134,10,144,50,1,129,190,234,144,187,144,144,144,165,246,93,140,243,196,66,90,34,38,144,88,144,253,89,83,128,9,144,30,72,226,80,144,195,35,144,144,233,144,64,131,163,70,73,180,169,144,211,139,232,184,160,144,144,144,132,144,144,144,144,144,144,144,20,144,37,144].concat([144,94,144,135,86,185,74,57,137,144,144,144,144,31,164,144,248,95,33,179,91,144,141,144,144,197,124,7,144,136,186,71,53,251,144,127,144,144,198,235,144,199,144,144,210,161,114,121,254,36,171,42,188,13,143,126,144,125,144,231,45,144,144,87,11,162,144,157,144,144,116,133,175,47,138,230,8,144,255,144,144,28,144,144,2,144,144,144,67,4,144,144,191,59,147,56,144,144,144,119,144,176,144,58,252,144,181,144,144,144,144,5,82,118,43,229,189,144,14,177,115,144,144,69,146,153,144,247,61,208,182,54,249,250,15,144,117,144,170,156,144,17,144,144,39,75,144,44,81,46,77,144,85,60,144,183,144,209,142,144,178,144,120,144,18,144,41,12,51,144,242,144,144,144,144,144,144,3,6,168,144,144,207,144,135,144,120,170,144,144,144,44,50,10,15,144,94,144,198,138,51,144,144,144,144,234,144,114,144,144,144,144,144,144,36,85,144,144,144,137,251,144,89,2,144,144,93,144,144,144,54,144,144,6,121,144,144,30,7,144,144,144,131,144,144,144,144,144,157,144,144,116,144,144,144,12,88,144,144,144,144,144,144,144,60,144,3,144,144,250,67,144,191,144,144,117,144,136,144,128,144,163,144,254,144,144,144,144,144,144,144,144,58,144,144,144,43,144,144,144,144,233,95,144,70,144,65,144,24,184,144,144,180,90,177,144,144,80,232,32,144,178,144,144,144,144,144,81,144,144,144,86,144,144,144,144,144,207,144,144,144,195,144,144,144,144,144,144,11,144,144,181,87,144,144,199,59,144,144,144,144,144,144,144,182,144,235,144,56,144,160,8,144,134,176,144,66,31,115,144,246,144,144,144,83,144,82,144,4,189,144,144,38,255,46,144,129,144,71,144,144,144,144,208,34,144,144,185,35,144,243,144,144,144,144,144,144,210,139,186,144,144,144,91,144,144,156,144,144,144,144,252,188,162,42,144,144,142,187,144,0,128,192,224,240,248,252,254,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,192,0,0,0,224,0,0,0,240,0,0,0,248,0,0,0,252,0,0,0,254,0,0,0,255,0,0,128,255,0,0,192,255,0,0,224,255,0,0,240,255,0,0,248,255,0,0,252,255,0,0,254,255,0,0,255,255,0,128,255,255,0,192,255,255,0,224,255,255,0,240,255,255,0,248,255,255,0,252,255,255,0,254,255,255,0,255,255,255,128,255,255,255,192,255,255,255,224,255,255,255,240,255,255,255,248,255,255,255,252,255,255,255,254,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,0,0,0,0,128,0,192,0,224,0,240,0,248,0,252,0,254,0,255,128,255,192,255,224,255,240,255,248,255,252,255,254,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,0,0,0,4,4,50,50,34,38,40,34,34,34,4,4,4,4,4,44,4,4,4,4,4,4,4,4,44,44,44,44,44,44,44,44,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,34,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,126,126,38,44,44,34,38,38,4,4,4,4,4,44,4,4,4,4,4,4,4,4,46,46,46,46,46,46,46,46,38,38,38,38,38,38,38,38,38,38,38,38,38,38,38,38,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,50,50,20,38,40,20,34,25,20,20,4,4,4,30,4,4,4,4,4,4,4,4,30,30,30,30,30,30,30,30,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,7,7,0,5,7,7,0,5,7,7,0,5,7,7,2,7,9,9,0,7,9,9,0,7,9,9,0,7,9,9,6,11,13,13,0,11,13,13,0,11,13,13,0,11,13,13,96,43,0,0,0,240,0,0,0,160,0,0,4,4,4,0,212,19,0,0,0,240,0,0,0,240,0,0,4,4,4,0,62,25,0,0,0,241,0,0,0,112,0,0,4,4,2,0,60,48,0,0,128,241,0,0,128,240,0,0,0,0,4,0,196,12,0,0,192,241,0,0,0,240,0,0,0,0,4,0,164,31,0,0,192,241,0,0,64,240,0,0,0,0,4,0,122,31,0,0,0,255,0,0,0,96,0,0,10,10,10,0,100,32,0,0,0,255,0,0,0,97,0,0,18,18,7,0,218,1,0,0,0,255,0,0,0,98,0,0,8,8,6,0,192,36,0,0,0,255,0,0,0,99,0,0,8,8,6,0,206,16,0,0,0,255,0,0,0,100,0,0,8,8,6,0,136,27,0,0,0,255,0,0,0,101,0,0,8,8,6,0,144,12,0,0,0,255,0,0,0,102,0,0,8,8,6,0,14,36,0,0,0,255,0,0,0,103,0,0,8,8,6,0,206,49,0,0,0,255,0,0,0,104,0,0,8,8,6,0,250,12,0,0,0,255,0,0,0,105,0,0,8,8,6,0,116,7,0,0,0,255,0,0,0,106,0,0,8,8,6,0,64,38,0,0,0,255,0,0,0,107,0,0,8,8,6,0,210,40,0,0,0,255,0,0,0,108,0,0,8,8,6,0,200,18,0,0,0,255,0,0,0,109,0,0,8,8,6,0,48,28,0,0,0,255,0,0,0,110,0,0,8,8,6,0,132,44,0,0,0,255,0,0,0,111,0,0,8,8,6,0,234,7,0,0,248,241,0,0,0,1,0,0,6,6,4,0,210,36,0,0,248,241,0,0,8,1,0,0,16,16,12,0,246,36,0,0,248,241,0,0,16,1,0,0,8,8,8,0,76,1,0,0,248,241,0,0,24,1,0,0,8,8,8,0,80,1,0,0,248,241,0,0,32,1,0,0,10,10,9,0,162,29,0,0,248,241,0,0,40,1,0,0,12,12,9,0,184,38,0,0,248,241,0,0,48,1,0,0,14,14,11,0,170,8,0,0,248,241,0,0,64,1,0,0,8,8,4,0,210,33,0,0,248,241,0,0,72,1,0,0,24,24,18,0,52,16,0,0,248,241,0,0,80,1,0,0,12,12,8,0,52,0,0,0,248,241,0,0,88,1,0,0,12,12,8,0,54,0,0,0,248,241,0,0,96,1,0,0,14,14,9,0,184,21,0,0,248,241,0,0,104,1,0,0,16,16,9,0,224,17,0,0,248,241,0,0,112,1,0,0,18,18,11,0,238,11,0,0,248,241,0,0,128,1,0,0,10,10,4,0,20,39,0,0,248,241,0,0,136,1,0,0,16,16,11,0,190,47,0,0,248,241,0,0,144,1,0,0,12,14,8,0,4,20,0,0,248,241,0,0,152,1,0,0,12,14,8,0,6,20,0,0,248,241,0,0,160,1,0,0,14,16,9,0,6,39,0,0,248,241,0,0,168,1,0,0,16,18,9,0,138,49,0,0,248,241,0,0,176,1,0,0,18,20,11,0,44,31,0,0,248,241,0,0,192,1,0,0,8,8,4,0,34,10,0,0,248,241,0,0,200,1,0,0,24,24,17,0,124,39,0,0,248,241,0,0,208,1,0,0,12,12,8,0,56,17,0,0,248,241,0,0,216,1,0,0,12,12,8,0,54,17,0,0,248,241,0,0,224,1,0,0,14,14,9,0,218,44,0,0,248,241,0,0,232,1,0,0,16,16,9,0,106,37,0,0,248,241,0,0,240,1,0,0,18,18,11,0,186,18,0,0,248,241,0,0,0,16,0,0,4,4,2,0,66,39,0,0,248,241,0,0,16,16,0,0,8,8,6,0,192,3,0,0,248,241,0,0,24,16,0,0,8,8,6,0,122,20,0,0,248,241,0,0,32,16,0,0,10,10,7,0,88,33,0,0,248,241,0,0,40,16,0,0,12,12,7,0,228,40,0,0,248,241,0,0,48,16,0,0,14,14,9,0,24,37,0,0,248,241,0,0,128,16,0,0,8,8,4,0,8,28,0,0,248,241,0,0,144,16,0,0,12,12,8,0,6,43,0,0,248,241,0,0,152,16,0,0,12,12,8,0,8,43,0,0,248,241,0,0,160,16,0,0,14,14,9,0,110,22,0,0,248,241,0,0,168,16,0,0,16,16,9,0,88,26,0,0,248,241,0,0,176,16,0,0,18,18,11,0,40,29,0,0,248,241,0,0,192,16,0,0,8,8,4,0,30,34,0,0,248,241,0,0,208,16,0,0,12,12,8,0,38,19,0,0,248,241,0,0,216,16,0,0,12,12,8,0,36,19,0,0,248,241,0,0,224,16,0,0,14,14,9,0,166,41,0,0,248,241,0,0,232,16,0,0,16,16,9,0,222,35,0,0,248,241,0,0,240,16,0,0,18,18,11,0,232,22,0,0,248,241,0,0,0,17,0,0,8,8,5,0,134,20,0,0,248,241,0,0,16,17,0,0,12,12,9,0,130,9,0,0,248,241,0,0,24,17,0,0,12,12,9,0,134,9,0,0,248,241,0,0,32,17,0,0,14,14,10,0,242,29,0,0,248,241,0,0,40,17,0,0,16,16,10,0,82,39,0,0,248,241,0,0,48,17,0,0,18,18,12,0,48,37,0,0,248,241,0,0,64,17,0,0,12,12,5,0,22,4,0,0,248,241,0,0,80,17,0,0,16,16,9,0,172,39,0,0,248,241,0,0,88,17,0,0,16,16,9,0,170,39,0,0,248,241,0,0,96,17,0,0,18,18,10,0,16,10,0,0,248,241,0,0,104,17,0,0,20,20,10,0,20,2,0,0,248,241,0,0,112,17,0,0,22,22,12,0,86,46,0,0,248,241,0,0,128,17,0,0,14,14,7,0,184,20,0,0,248,241,0,0,144,17,0,0,18,18,11,0,78,5,0,0,248,241,0,0,152,17,0,0,18,18,11,0,74,5,0,0,248,241,0,0,160,17,0,0,20,20,12,0,0,28,0,0,248,241,0,0,168,17,0,0,22,22,12,0,214,8,0,0,248,241,0,0,176,17,0,0,24,24,14,0,124,23,0,0,248,241,0,0,0,32,0,0,4,4,2,0,126,23,0,0,248,241,0,0,8,32,0,0,4,4,2,0,208,42,0,0,248,241,0,0,16,32,0,0,12,12,6,0,208,27,0,0,248,241,0,0,24,32,0,0,12,12,6,0,210,27,0,0,248,241,0,0,32,32,0,0,14,14,7,0,104,46,0,0,248,241,0,0,40,32,0,0,16,16,7,0,26,41,0,0,248,241,0,0,48,32,0,0,18,18,9,0,196,38,0,0,248,241,0,0,64,32,0,0,4,4,2,0,194,38,0,0,248,241,0,0,72,32,0,0,4,4,2,0,100,14,0,0,248,241,0,0,80,32,0,0,12,12,6,0,72,42,0,0,248,241,0,0,88,32,0,0,12,12,6,0,70,42,0,0,248,241,0,0,96,32,0,0,14,14,7,0,186,21,0,0,248,241,0,0,104,32,0,0,16,16,7,0,198,41,0,0,248,241,0,0,112,32,0,0,18,18,9,0,2,49,0,0,248,241,0,0,128,32,0,0,12,12,4,0,4,49,0,0,248,241,0,0,136,32,0,0,12,12,4,0,204,34,0,0,248,241,0,0,144,32,0,0,20,20,8,0,230,12,0,0,248,241,0,0,152,32,0,0,20,20,8,0,232,12,0,0,248,241,0,0,160,32,0,0,22,22,9,0,94,42,0,0,248,241,0,0,168,32,0,0,24,24,9,0,154,36,0,0,248,241,0,0,176,32,0,0,26,26,11,0,84,46,0,0,248,241,0,0,192,32,0,0,12,12,4,0,82,46,0,0,248,241,0,0,200,32,0,0,12,12,4,0,4,0,0,0,248,241,0,0,208,32,0,0,20,20,8,0,12,23,0,0,248,241,0,0,216,32,0,0,20,20,8,0,10,23,0,0,248,241,0,0,224,32,0,0,22,22,9,0,120,43,0,0,248,241,0,0,232,32,0,0,24,24,9,0,238,48,0,0,248,241,0,0,240,32,0,0,26,26,11,0,78,35,0,0,248,241,0,0,0,33,0,0,12,14,5,0,84,35,0,0,248,241,0,0,8,33,0,0,12,14,5,0,96,22,0,0,248,241,0,0,16,33,0,0,20,22,9,0,24,50,0,0,248,241,0,0,24,33,0,0,20,22,9,0,26,50,0,0,248,241,0,0,32,33,0,0,22,24,10,0,170,29,0,0,248,241,0,0,40,33,0,0,24,26,10,0,94,19,0,0,248,241,0,0,48,33,0,0,26,28,12,0,228,10,0,0,248,241,0,0,64,33,0,0,16,16,5,0,230,10,0,0,248,241,0,0,72,33,0,0,16,16,5,0,0,49,0,0,248,241,0,0,80,33,0,0,24,24,9,0,110,21,0,0,248,241,0,0,88,33,0,0,24,24,9,0,54,23,0,0,248,241,0,0,96,33,0,0,26,26,10,0,150,43,0,0,248,241,0,0,104,33,0,0,28,28,10,0,22,0,0,0,248,241,0,0,112,33,0,0,30,30,12,0,14,26,0,0,248,241,0,0,128,33,0,0,18,18,7,0,18,26,0,0,248,241,0,0,136,33,0,0,18,18,7,0,90,16,0,0,248,241,0,0,144,33,0,0,26,26,11,0,198,32,0,0,248,241,0,0,152,33,0,0,26,26,11,0,248,30,0,0,248,241,0,0,160,33,0,0,28,28,12,0,182,10,0,0,248,241,0,0,168,33,0,0,30,30,12,0,12,18,0,0,248,241,0,0,176,33,0,0,32,32,14,0,138,29,0,0,248,241,0,0,0,48,0,0,4,4,2,0,136,29,0,0,248,241,0,0,8,48,0,0,4,4,2,0,24,0,0,0,248,241,0,0,16,48,0,0,8,8,6,0,218,35,0,0,248,241,0,0,24,48,0,0,8,8,6,0,220,35,0,0,248,241,0,0,32,48,0,0,10,10,7,0,92,6,0,0,248,241,0,0,40,48,0,0,12,12,7,0,8,49,0,0,248,241,0,0,48,48,0,0,14,14,9,0,106,6,0,0,248,241,0,0,64,48,0,0,4,4,2,0,108,6,0,0,248,241,0,0,72,48,0,0,4,4,2,0,206,30,0,0,248,241,0,0,80,48,0,0,8,8,6,0,228,8,0,0,248,241,0,0,88,48,0,0,8,8,6,0,232,8,0,0,248,241,0,0,96,48,0,0,10,10,7,0,140,36,0,0,248,241,0,0,104,48,0,0,12,12,7,0,66,29,0,0,248,241,0,0,112,48,0,0,14,14,9,0,120,2,0,0,248,241,0,0,128,48,0,0,8,8,4,0,118,2,0,0,248,241,0,0,136,48,0,0,8,8,4,0,96,21,0,0,248,241,0,0,144,48,0,0,12,12,8,0,180,32,0,0,248,241,0,0,152,48,0,0,12,12,8,0,188,32,0,0,248,241,0,0,160,48,0,0,14,14,9,0,228,26,0,0,248,241,0,0,168,48,0,0,16,16,9,0,30,23,0,0,248,241,0,0,176,48,0,0,18,18,11,0,22,31,0,0,248,241,0,0,192,48,0,0,8,8,4,0,112,39,0,0,248,241,0,0,200,48,0,0,8,8,4,0,158,0,0,0,248,241,0,0,208,48,0,0,12,12,8,0,142,23,0,0,248,241,0,0,216,48,0,0,12,12,8,0,144,23,0,0,248,241,0,0,224,48,0,0,14,14,9,0,232,43,0,0,248,241,0,0,232,48,0,0,16,16,9,0,118,49,0,0,248,241,0,0,240,48,0,0,18,18,11,0,2,29,0,0,248,241,0,0,0,49,0,0,8,8,5,0,16,47,0,0,248,241,0,0,8,49,0,0,8,8,5,0,22,11,0,0,248,241,0,0,16,49,0,0,12,12,9,0,50,39,0,0,248,241,0,0,24,49,0,0,12,12,9,0,52,39,0,0,248,241,0,0,32,49,0,0,14,14,10,0,114,18,0,0,248,241,0,0,40,49,0,0,16,16,10,0,244,12,0,0,248,241,0,0,48,49,0,0,18,18,12,0,72,36,0,0,248,241,0,0,64,49,0,0,12,12,5,0,74,36,0,0,248,241,0,0,72,49,0,0,12,12,5,0,244,23,0,0,248,241,0,0,80,49,0,0,16,16,9,0,252,38,0,0,248,241,0,0,88,49,0,0,16,16,9,0,250,38,0,0,248,241,0,0,96,49,0,0,18,18,10,0,96,18,0,0,248,241,0,0,104,49,0,0,20,20,10,0,230,25,0,0,248,241,0,0,112,49,0,0,22,22,12,0,6,37,0,0,248,241,0,0,128,49,0,0,14,14,7,0,4,37,0,0,248,241,0,0,136,49,0,0,14,14,7,0,146,46,0,0,248,241,0,0,144,49,0,0,18,18,11,0,202,11,0,0,248,241,0,0,152,49,0,0,18,18,11,0,204,11,0,0,248,241,0,0,160,49,0,0,20,20,12,0,164,39,0,0,248,241,0,0,168,49,0,0,22,22,12,0,114,48,0,0,248,241,0,0,176,49,0,0,24,24,14,0,158,11,0,0,248,241,0,0,0,65,0,0,0,0,8,0,136,13,0,0,248,241,0,0,16,65,0,0,0,0,12,0,62,48,0,0,248,241,0,0,24,65,0,0,0,0,12,0,64,48,0,0,248,241,0,0,32,65,0,0,0,0,13,0,86,9,0,0,248,241,0,0,40,65,0,0,0,0,13,0,70,15,0,0,248,241,0,0,48,65,0,0,0,0,15,0,180,10,0,0,248,241,0,0,128,65,0,0,10,8,8,0,94,30,0,0,248,241,0,0,144,65,0,0,14,12,12,0,90,8,0,0,248,241,0,0,152,65,0,0,14,12,12,0,88,8,0,0,248,241,0,0,160,65,0,0,16,14,13,0,158,37,0,0,248,241,0,0,168,65,0,0,18,16,13,0,192,28,0,0,248,241,0,0,176,65,0,0,20,18,15,0,96,42,0,0,248,241,0,0,208,65,0,0,4,4,6,0,170,31,0,0,248,241,0,0,232,65,0,0,8,8,7,0,172,22,0,0,248,241,0,0,240,65,0,0,12,12,9,0,126,22,0,0,248,241,0,0,0,80,0,0,4,4,2,0,206,9,0,0,248,241,0,0,16,80,0,0,12,12,8,0,62,49,0,0,248,241,0,0,24,80,0,0,12,12,8,0,64,49,0,0,248,241,0,0,32,80,0,0,14,14,9,0,222,15,0,0,248,241,0,0,40,80,0,0,16,16,9,0,208,25,0,0,248,241,0,0,48,80,0,0,18,18,11,0,56,9,0,0,248,241,0,0,64,80,0,0,4,4,2,0,58,9,0,0,248,241,0,0,72,80,0,0,4,4,2,0,224,8,0,0,248,241,0,0,80,80,0,0,12,12,8,0,204,36,0,0,248,241,0,0,88,80,0,0,12,12,8,0,202,36,0,0,248,241,0,0,96,80,0,0,14,14,9,0,146,14,0,0,248,241,0,0,104,80,0,0,16,16,9,0,238,6,0,0,248,241,0,0,112,80,0,0,18,18,11,0,84,27,0,0,248,241,0,0,128,80,0,0,8,8,2,0,242,8,0,0,248,241,0,0,136,80,0,0,8,8,2,0,26,18,0,0,248,241,0,0,144,80,0,0,20,20,8,0,154,2,0,0,248,241,0,0,152,80,0,0,20,20,8,0,152,2,0,0,248,241,0,0,160,80,0,0,22,22,9,0,18,48,0,0,248,241,0,0,168,80,0,0,24,24,9,0,106,16,0,0,248,241,0,0,176,80,0,0,26,26,11,0,120,6,0,0,248,241,0,0,0,81,0,0,4,4,2,0,232,15,0,0,248,241,0,0,16,81,0,0,12,12,8,0,224,49,0,0,248,241,0,0,24,81,0,0,12,12,8,0,124,50,0,0,248,241,0,0,32,81,0,0,14,14,9,0,56,23,0,0,248,241,0,0,40,81,0,0,16,16,9,0,28,14,0,0,248,241,0,0,48,81,0,0,18,18,11,0,210,39,0,0,248,241,0,0,64,81,0,0,4,4,2,0,212,39,0,0,248,241,0,0,72,81,0,0,8,4,2,0,22,28,0,0,248,241,0,0,80,81,0,0,12,12,8,0,248,49,0,0,248,241,0,0,88,81,0,0,12,12,8,0,252,49,0,0,248,241,0,0,96,81,0,0,14,14,9,0,228,20,0,0,248,241,0,0,104,81,0,0,16,16,9,0,132,26,0,0,248,241,0,0,112,81,0,0,18,18,11,0,68,5,0,0,248,241,0,0,128,81,0,0,8,8,2,0,72,5,0,0,248,241,0,0,136,81,0,0,8,8,2,0,84,9,0,0,248,241,0,0,144,81,0,0,20,20,8,0,78,31,0,0,248,241,0,0,152,81,0,0,20,20,8,0,74,31,0,0,248,241,0,0,160,81,0,0,22,22,9,0,72,1,0,0,248,241,0,0,168,81,0,0,24,24,9,0,134,7,0,0,248,241,0,0,176,81,0,0,26,26,11,0,98,15,0,0,248,241,0,0,0,128,0,0,4,4,2,0,50,25,0,0,248,241,0,0,16,128,0,0,8,8,6,0,138,2,0,0,248,241,0,0,24,128,0,0,8,8,6,0,140,2,0,0,248,241,0,0,32,128,0,0,10,10,7,0,54,32,0,0,248,241,0,0,40,128,0,0,12,12,7,0,118,35,0,0,248,241,0,0,48,128,0,0,14,14,9,0,76,44,0,0,248,241,0,0,64,128,0,0,4,4,2,0,174,35,0,0,248,241,0,0,80,128,0,0,8,8,6,0,150,50,0,0,248,241,0,0,88,128,0,0,8,8,6,0,148,50,0,0,248,241,0,0,96,128,0,0,10,10,7,0,98,28,0,0,248,241,0,0,104,128,0,0,12,12,7,0,108,37,0,0,248,241,0,0,112,128,0,0,14,14,9,0,100,45,0,0,248,241,0,0,128,128,0,0,8,6,2,0,146,9,0,0,248,241,0,0,144,128,0,0,14,14,6,0,144,31,0,0,248,241,0,0,152,128,0,0,14,14,6,0,146,31,0,0,248,241,0,0,160,128,0,0,16,16,7,0,166,3,0,0,248,241,0,0,168,128,0,0,18,18,7,0,200,7,0,0,248,241,0,0,176,128,0,0,20,20,9,0,38,32,0,0,248,241,0,0,192,128,0,0,140,108,44,0,226,30,0,0,248,241,0,0,208,128,0,0,144,112,48,0,180,33,0,0,248,241,0,0,216,128,0,0,144,112,48,0,252,15,0,0,248,241,0,0,224,128,0,0,146,114,49,0,90,13,0,0,248,241,0,0,232,128,0,0,148,116,49,0,30,9,0,0,248,241,0,0,240,128,0,0,150,118,51,0,4,14,0,0,248,241,0,0,0,129,0,0,6,6,4,0,224,35,0,0,248,241,0,0,8,129,0,0,18,18,16,0,92,11,0,0,248,241,0,0,16,129,0,0,12,12,8,0,56,46,0,0,248,241,0,0,24,129,0,0,12,12,8,0,58,46,0,0,248,241,0,0,32,129,0,0,14,14,9,0,176,18,0,0,248,241,0,0,40,129,0,0,16,16,9,0,50,13,0,0,248,241,0,0,48,129,0,0,18,18,11,0,98,45,0,0,248,241,0,0,64,129,0,0,0,0,6,0,114,12,0,0,248,241,0,0,72,129,0,0,0,0,13,0,44,43,0,0,248,241,0,0,80,129,0,0,12,12,8,0,36,8,0,0,248,241,0,0,88,129,0,0,12,12,8,0,38,8,0,0,248,241,0,0,96,129,0,0,14,14,9,0,124,37,0,0,248,241,0,0,104,129,0,0,16,16,9,0,94,44,0,0,248,241,0,0,112,129,0,0,18,18,11,0,62,26,0,0,248,241,0,0,128,129,0,0,0,0,8,0,118,7,0,0,248,241,0,0,136,129,0,0,0,0,13,0,108,19,0,0,248,241,0,0,144,129,0,0,20,20,8,0,154,41,0,0,248,241,0,0,152,129,0,0,20,20,8,0,152,41,0,0,248,241,0,0,160,129,0,0,22,22,9,0,236,13,0,0,248,241,0,0,168,129,0,0,24,24,9,0,100,21,0,0,248,241,0,0,176,129,0,0,26,26,11,0,54,29,0,0,248,241,0,0,192,129,0,0,158,122,56,0,26,13,0,0,248,241,0,0,208,129,0,0,162,126,60,0,0,48,0,0,248,241,0,0,216,129,0,0,162,126,60,0,254,47,0,0,248,241,0,0,224,129,0,0,164,128,61,0,102,20,0,0,248,241,0,0,232,129,0,0,166,130,61,0,64,11,0,0,248,241,0,0,240,129,0,0,168,132,63,0,222,2,0,0,248,241,0,0,0,144,0,0,4,4,2,0,228,49,0,0,248,241,0,0,16,144,0,0,8,8,6,0,250,48,0,0,248,241,0,0,24,144,0,0,8,8,6,0,244,48,0,0,248,241,0,0,32,144,0,0,10,10,7,0,120,28,0,0,248,241,0,0,40,144,0,0,12,12,7,0,210,35,0,0,248,241,0,0,48,144,0,0,14,14,9,0,80,42,0,0,248,241,0,0,64,144,0,0,4,4,2,0,78,42,0,0,248,241,0,0,72,144,0,0,4,4,2,0,210,19,0,0,248,241,0,0,80,144,0,0,8,8,6,0,142,47,0,0,248,241,0,0,88,144,0,0,8,8,6,0,144,47,0,0,248,241,0,0,96,144,0,0,10,10,7,0,122,25,0,0,248,241,0,0,104,144,0,0,12,12,7,0,14,18,0,0,248,241,0,0,112,144,0,0,14,14,9,0,186,23,0,0,248,241,0,0,128,144,0,0,8,6,2,0,188,23,0,0,248,241,0,0,136,144,0,0,8,6,2,0,172,5,0,0,248,241,0,0,144,144,0,0,14,14,6,0,234,40,0,0,248,241,0,0,152,144,0,0,14,14,6,0,236,40,0,0,248,241,0,0,160,144,0,0,16,16,7,0,84,13,0,0,248,241,0,0,168,144,0,0,18,18,7,0,196,3,0,0,248,241,0,0,176,144,0,0,20,20,9,0,4,39,0,0,248,241,0,0,192,144,0,0,8,8,2,0,106,29,0,0,248,241,0,0,200,144,0,0,8,8,2,0,26,35,0,0,248,241,0,0,208,144,0,0,12,12,6,0,32,50,0,0,248,241,0,0,216,144,0,0,12,12,6,0,36,50,0,0,248,241,0,0,224,144,0,0,14,14,7,0,116,13,0,0,248,241,0,0,232,144,0,0,16,16,7,0,84,33,0,0,248,241,0,0,240,144,0,0,18,18,9,0,44,14,0,0,248,241,0,0,0,145,0,0,4,4,2,0,42,45,0,0,248,241,0,0,8,145,0,0,18,18,12,0,92,35,0,0,248,241,0,0,16,145,0,0,12,12,8,0,168,48,0,0,248,241,0,0,24,145,0,0,12,12,8,0,170,48,0,0,248,241,0,0,32,145,0,0,14,14,9,0,96,19,0,0,248,241,0,0,40,145,0,0,16,16,9,0,142,28,0,0,248,241,0,0,48,145,0,0,18,18,11,0,14,17,0,0,248,241,0,0,64,145,0,0,4,4,2,0,200,44,0,0,248,241,0,0,72,145,0,0,18,18,12,0,172,38,0,0,248,241,0,0,80,145,0,0,12,12,8,0,198,16,0,0,248,241,0,0,88,145,0,0,12,12,8,0,194,16,0,0,248,241,0,0,96,145,0,0,14,14,9,0,212,45,0,0,248,241,0,0,104,145,0,0,16,16,9,0,144,40,0,0,248,241,0,0,112,145,0,0,18,18,11,0,60,7,0,0,248,241,0,0,128,145,0,0,8,6,2,0,10,20,0,0,248,241,0,0,136,145,0,0,30,30,12,0,236,24,0,0,248,241,0,0,144,145,0,0,20,20,8,0,22,2,0,0,248,241,0,0,152,145,0,0,20,20,8,0,24,2,0,0,248,241,0,0,160,145,0,0,22,22,9,0,6,32,0,0,248,241,0,0,168,145,0,0,24,24,9,0,180,26,0,0,248,241,0,0,176,145,0,0,26,26,11,0,186,31,0,0,248,241,0,0,192,145,0,0,8,6,2,0,190,31,0,0,248,241,0,0,200,145,0,0,8,6,2,0,18,1,0,0,248,241,0,0,208,145,0,0,14,14,6,0,218,16,0,0,248,241,0,0,216,145,0,0,14,14,6,0,216,16,0,0,248,241,0,0,224,145,0,0,16,16,7,0,90,44,0,0,248,241,0,0,232,145,0,0,18,18,7,0,210,49,0,0,248,241,0,0,240,145,0,0,20,20,9,0,208,39,0,0,248,241,0,0,0,176,0,0,4,4,2,0,204,45,0,0,248,241,0,0,16,176,0,0,8,8,6,0,248,10,0,0,248,241,0,0,24,176,0,0,8,8,6,0,250,10,0,0,248,241,0,0,32,176,0,0,10,10,7,0,118,38,0,0,248,241,0,0,40,176,0,0,12,12,7,0,158,47,0,0,248,241,0,0,48,176,0,0,14,14,9,0,2,16,0,0,248,241,0,0,64,176,0,0,4,4,2,0,4,16,0,0,248,241,0,0,72,176,0,0,4,4,2,0,210,45,0,0,248,241,0,0,80,176,0,0,8,8,6,0,22,24,0,0,248,241,0,0,88,176,0,0,8,8,6,0,24,24,0,0,248,241,0,0,96,176,0,0,10,10,7,0,0,1,0,0,248,241,0,0,104,176,0,0,12,12,7,0,44,44,0,0,248,241,0,0,112,176,0,0,14,14,9,0,216,47,0,0,248,241,0,0,128,176,0,0,6,6,2,0,214,47,0,0,248,241,0,0,136,176,0,0,6,6,2,0,74,29,0,0,248,241,0,0,144,176,0,0,14,14,6,0,18,7,0,0,248,241,0,0,152,176,0,0,14,14,6,0,16,7,0,0,248,241,0,0,160,176,0,0,16,16,7,0,156,36,0,0,248,241,0,0,168,176,0,0,18,18,7,0,212,30,0,0,248,241,0,0,176,176,0,0,20,20,9,0,160,50,0,0,248,241,0,0,192,176,0,0,6,6,4,0,158,50,0,0,248,241,0,0,200,176,0,0,6,6,4,0,132,16,0,0,248,241,0,0,208,176,0,0,10,10,8,0,46,31,0,0,248,241,0,0,216,176,0,0,10,10,8,0,232,33,0,0,248,241,0,0,224,176,0,0,12,12,9,0,224,10,0,0,248,241,0,0,232,176,0,0,14,14,9,0,196,14,0,0,248,241,0,0,240,176,0,0,16,16,11,0,188,7,0,0,248,241,0,0,0,177,0,0,4,4,2,0,198,33,0,0,248,241,0,0,8,177,0,0,12,12,9,0,32,0,0,0,248,241,0,0,16,177,0,0,12,12,8,0,38,16,0,0,248,241,0,0,24,177,0,0,12,12,8,0,40,16,0,0,248,241,0,0,32,177,0,0,14,14,9,0,86,18,0,0,248,241,0,0,40,177,0,0,16,16,9,0,24,49,0,0,248,241,0,0,48,177,0,0,18,18,11,0,192,30,0,0,248,241,0,0,64,177,0,0,4,4,2,0,194,33,0,0,248,241,0,0,72,177,0,0,12,12,9,0,148,29,0,0,248,241,0,0,80,177,0,0,12,12,8,0,186,14,0,0,248,241,0,0,88,177,0,0,12,12,8,0,182,14,0,0,248,241,0,0,96,177,0,0,14,14,9,0,18,35,0,0,248,241,0,0,104,177,0,0,16,16,9,0,212,27,0,0,248,241,0,0,112,177,0,0,18,18,11,0,180,48,0,0,248,241,0,0,128,177,0,0,8,6,2,0,162,46,0,0,248,241,0,0,136,177,0,0,20,20,9,0,94,2,0,0,248,241,0,0,144,177,0,0,20,20,8,0,184,30,0,0,248,241,0,0,152,177,0,0,20,20,8,0,180,30,0,0,248,241,0,0,160,177,0,0,22,22,9,0,70,10,0,0,248,241,0,0,168,177,0,0,24,24,9,0,90,0,0,0,248,241,0,0,176,177,0,0,26,26,11,0,10,39,0,0,248,241,0,0,192,177,0,0,6,6,4,0,8,39,0,0,248,241,0,0,200,177,0,0,6,6,4,0,188,3,0,0,248,241,0,0,208,177,0,0,14,14,8,0,80,26,0,0,248,241,0,0,216,177,0,0,14,14,8,0,76,26,0,0,248,241,0,0,224,177,0,0,16,16,9,0,92,48,0,0,248,241,0,0,232,177,0,0,18,18,9,0,160,5,0,0,248,241,0,0,240,177,0,0,20,20,11,0,22,40,0,0,248,241,0,0,0,192,0,0,4,4,2,0,210,0,0,0,248,241,0,0,16,192,0,0,8,8,6,0,114,36,0,0,248,241,0,0,24,192,0,0,8,8,6,0,116,36,0,0,248,241,0,0,32,192,0,0,10,10,7,0,2,7,0,0,248,241,0,0,40,192,0,0,12,12,7,0,100,15,0,0,248,241,0,0,48,192,0,0,14,14,9,0,212,29,0,0,248,241,0,0,64,192,0,0,4,4,2,0,120,27,0,0,248,241,0,0,80,192,0,0,8,8,6,0,122,42,0,0,248,241,0,0,88,192,0,0,8,8,6,0,120,42,0,0,248,241,0,0,96,192,0,0,10,10,7,0,232,21,0,0,248,241,0,0,104,192,0,0,12,12,7,0,36,29,0,0,248,241,0,0,112,192,0,0,14,14,9,0,50,33,0,0,248,241,0,0,128,192,0,0,8,6,2,0,62,28,0,0,248,241,0,0,144,192,0,0,14,14,6,0,222,10,0,0,248,241,0,0,152,192,0,0,14,14,6,0,220,10,0,0,248,241,0,0,160,192,0,0,16,16,7,0,82,31,0,0,248,241,0,0,168,192,0,0,18,18,7,0,198,17,0,0,248,241,0,0,176,192,0,0,20,20,9,0,24,14,0,0,248,241,0,0,192,192,0,0,54,30,27,0,122,8,0,0,248,241,0,0,208,192,0,0,58,34,31,0,154,23,0,0,248,241,0,0,216,192,0,0,58,34,31,0,152,23,0,0,248,241,0,0,224,192,0,0,60,36,32,0,118,0,0,0,248,241,0,0,232,192,0,0,62,38,32,0,66,10,0,0,248,241,0,0,240,192,0,0,64,40,34,0,70,32,0,0,248,241,0,0,0,193,0,0,6,6,4,0,118,43,0,0,248,241,0,0,8,193,0,0,18,18,16,0,96,25,0,0,248,241,0,0,16,193,0,0,12,12,8,0,174,2,0,0,248,241,0,0,24,193,0,0,12,12,8,0,176,2,0,0,248,241,0,0,32,193,0,0,14,14,9,0,138,30,0,0,248,241,0,0,40,193,0,0,16,16,9,0,142,24,0,0,248,241,0,0,48,193,0,0,18,18,11,0,74,48,0,0,248,241,0,0,64,193,0,0,6,6,2,0,6,41,0,0,248,241,0,0,72,193,0,0,6,6,2,0,110,29,0,0,248,241,0,0,80,193,0,0,12,12,8,0,220,0,0,0,248,241,0,0,88,193,0,0,12,12,8,0,222,0,0,0,248,241,0,0,96,193,0,0,14,14,9,0,42,22,0,0,248,241,0,0,104,193,0,0,16,16,9,0,122,33,0,0,248,241,0,0,112,193,0,0,18,18,11,0,76,48,0,0,248,241,0,0,136,193,0,0,6,6,2,0,10,12,0,0,248,241,0,0,144,193,0,0,20,20,8,0,0,34,0,0,248,241,0,0,152,193,0,0,20,20,8,0,252,33,0,0,248,241,0,0,160,193,0,0,22,22,9,0,58,4,0,0,248,241,0,0,168,193,0,0,24,24,9,0,222,13,0,0,248,241,0,0,176,193,0,0,26,26,11,0,120,10,0,0,248,241,0,0,192,193,0,0,54,32,27,0,166,23,0,0,248,241,0,0,208,193,0,0,58,36,31,0,114,45,0,0,248,241,0,0,216,193,0,0,58,36,31,0,112,45,0,0,248,241,0,0,224,193,0,0,60,38,32,0,20,18,0,0,248,241,0,0,232,193,0,0,62,40,32,0,126,25,0,0,248,241,0,0,240,193,0,0,64,42,34,0,2,6,0,0,248,241,0,0,0,208,0,0,4,4,2,0,210,31,0,0,248,241,0,0,16,208,0,0,8,8,6,0,216,9,0,0,248,241,0,0,24,208,0,0,8,8,6,0,74,4,0,0,248,241,0,0,32,208,0,0,10,10,7,0,82,37,0,0,248,241,0,0,40,208,0,0,12,12,7,0,134,33,0,0,248,241,0,0,48,208,0,0,14,14,9,0,118,5,0,0,248,241,0,0,64,208,0,0,4,4,2,0,116,5,0,0,248,241,0,0,72,208,0,0,4,4,2,0,182,17,0,0,248,241,0,0,80,208,0,0,8,8,6,0,128,32,0,0,248,241,0,0,88,208,0,0,8,8,6,0,132,32,0,0,248,241,0,0,96,208,0,0,10,10,7,0,102,10,0,0,248,241,0,0,104,208,0,0,12,12,7,0,92,19,0,0,248,241,0,0,112,208,0,0,14,14,9,0,202,47,0,0,248,241,0,0,128,208,0,0,8,6,2,0,204,47,0,0,248,241,0,0,136,208,0,0,8,6,2,0,40,26,0,0,248,241,0,0,144,208,0,0,14,14,6,0,22,41,0,0,248,241,0,0,152,208,0,0,14,14,6,0,106,43,0,0,248,241,0,0,160,208,0,0,16,16,7,0,124,20,0,0,248,241,0,0,168,208,0,0,18,18,7,0,70,24,0,0,248,241,0,0,176,208,0,0,20,20,9,0,104,0,0,0,248,241,0,0,192,208,0,0,8,8,2,0,106,0,0,0,248,241,0,0,200,208,0,0,8,8,2,0,226,33,0,0,248,241,0,0,208,208,0,0,12,12,6,0,238,18,0,0,248,241,0,0,216,208,0,0,12,12,6,0,234,18,0,0,248,241,0,0,224,208,0,0,14,14,7,0,230,39,0,0,248,241,0,0,232,208,0,0,16,16,7,0,20,32,0,0,248,241,0,0,240,208,0,0,18,18,9,0,230,19,0,0,248,241,0,0,0,209,0,0,4,4,2,0,138,25,0,0,248,241,0,0,8,209,0,0,18,18,12,0,180,8,0,0,248,241,0,0,16,209,0,0,12,12,8,0,176,43,0,0,248,241,0,0,24,209,0,0,12,12,8,0,178,43,0,0,248,241,0,0,32,209,0,0,14,14,9,0,70,16,0,0,248,241,0,0,40,209,0,0,16,16,9,0,214,6,0,0,248,241,0,0,48,209,0,0,18,18,11,0,236,5,0,0,248,241,0,0,64,209,0,0,4,4,2,0,222,29,0,0,248,241,0,0,72,209,0,0,18,18,12,0,20,29,0,0,248,241,0,0,80,209,0,0,12,12,8,0,110,0,0,0,248,241,0,0,88,209,0,0,12,12,8,0,112,0,0,0,248,241,0,0,96,209,0,0,14,14,9,0,214,21,0,0,248,241,0,0,104,209,0,0,16,16,9,0,106,27,0,0,248,241,0,0,112,209,0,0,18,18,11,0,114,22,0,0,248,241,0,0,128,209,0,0,8,6,2,0,110,20,0,0,248,241,0,0,136,209,0,0,30,30,12,0,210,2,0,0,248,241,0,0,144,209,0,0,20,20,8,0,116,47,0,0,248,241,0,0,152,209,0,0,20,20,8,0,110,47,0,0,248,241,0,0,160,209,0,0,22,22,9,0,164,45,0,0,248,241,0,0,168,209,0,0,24,24,9,0,198,0,0,0,248,241,0,0,176,209,0,0,26,26,11,0,0,19,0,0,248,241,0,0,192,209,0,0,8,6,2,0,254,18,0,0,248,241,0,0,200,209,0,0,8,6,2,0,38,7,0,0,248,241,0,0,208,209,0,0,14,14,6,0,34,35,0,0,248,241,0,0,216,209,0,0,14,14,6,0,32,35,0,0,248,241,0,0,224,209,0,0,16,16,7,0,200,14,0,0,248,241,0,0,232,209,0,0,18,18,7,0,178,36,0,0,248,241,0,0,240,209,0,0,20,20,9,0,226,37,0,0,248,241,0,0,0,224,0,0,6,6,6,0,102,5,0,0,248,241,0,0,8,224,0,0,6,6,4,0,100,5,0,0,248,241,0,0,16,224,0,0,6,6,12,0,30,42,0,0,248,241,0,0,24,224,0,0,6,6,8,0,136,23,0,0,248,241,0,0,32,224,0,0,6,6,6,0,104,5,0,0,248,241,0,0,40,224,0,0,6,6,6,0,98,5,0,0,248,241,0,0,48,224,0,0,6,6,12,0,32,42,0,0,248,241,0,0,56,224,0,0,6,6,8,0,28,2,0,0,248,241,0,0,64,224,0,0,6,6,6,0,208,47,0,0,248,241,0,0,72,224,0,0,6,6,4,0,242,42,0,0,248,241,0,0,80,224,0,0,6,6,12,0,208,14,0,0,248,241,0,0,88,224,0,0,6,6,8,0,26,2,0,0,248,241,0,0,96,224,0,0,6,6,6,0,210,47,0,0,248,241,0,0,104,224,0,0,6,6,6,0,16,3,0,0,248,241,0,0,112,224,0,0,6,6,12,0,210,14,0,0,248,241,0,0,120,224,0,0,6,6,8,0,194,20,0,0,248,241,0,0,128,224,0,0,8,8,6,0,130,45,0,0,248,241,0,0,136,224,0,0,8,8,4,0,142,43,0,0,248,241,0,0,144,224,0,0,8,8,12,0,210,21,0,0,248,241,0,0,152,224,0,0,8,8,8,0,132,19,0,0,248,241,0,0,160,224,0,0,8,8,6,0,132,45,0,0,248,241,0,0,168,224,0,0,8,8,6,0,140,43,0,0,248,241,0,0,176,224,0,0,8,8,12,0,212,21,0,0,248,241,0,0,184,224,0,0,8,8,8,0,140,21,0,0,248,241,0,0,0,225,0,0,6,6,8,0,150,8,0,0,248,241,0,0,8,225,0,0,6,6,4,0])
.concat([92,29,0,0,248,241,0,0,16,225,0,0,6,6,12,0,26,22,0,0,248,241,0,0,24,225,0,0,6,6,8,0,136,9,0,0,248,241,0,0,32,225,0,0,6,6,8,0,152,8,0,0,248,241,0,0,40,225,0,0,6,6,6,0,194,21,0,0,248,241,0,0,48,225,0,0,6,6,12,0,228,45,0,0,248,241,0,0,56,225,0,0,6,6,8,0,190,6,0,0,248,241,0,0,64,225,0,0,6,6,8,0,224,42,0,0,248,241,0,0,72,225,0,0,6,6,4,0,242,38,0,0,248,241,0,0,80,225,0,0,6,6,12,0,46,15,0,0,248,241,0,0,88,225,0,0,6,6,8,0,188,6,0,0,248,241,0,0,96,225,0,0,6,6,8,0,226,42,0,0,248,241,0,0,104,225,0,0,6,6,6,0,240,38,0,0,248,241,0,0,112,225,0,0,6,6,12,0,48,15,0,0,248,241,0,0,120,225,0,0,6,6,8,0,218,29,0,0,248,241,0,0,128,225,0,0,8,8,8,0,140,45,0,0,248,241,0,0,136,225,0,0,8,8,4,0,40,27,0,0,248,241,0,0,144,225,0,0,8,8,12,0,136,15,0,0,248,241,0,0,152,225,0,0,8,8,8,0,36,39,0,0,248,241,0,0,160,225,0,0,8,8,8,0,208,49,0,0,248,241,0,0,168,225,0,0,8,8,6,0,246,7,0,0,248,241,0,0,176,225,0,0,8,8,12,0,138,15,0,0,248,241,0,0,184,225,0,0,8,8,8,0,52,36,0,0,248,241,0,0,72,240,0,0,0,0,4,0,82,18,0,0,248,241,0,0,120,240,0,0,0,0,4,0,244,38,0,0,240,255,0,0,192,6,0,0,0,0,19,0,76,39,0,0,240,255,0,0,64,78,0,0,4,4,4,0,116,8,0,0,255,241,0,0,31,1,0,0,8,8,8,0,96,2,0,0,255,241,0,0,39,1,0,0,10,10,9,0,0,37,0,0,255,241,0,0,56,1,0,0,12,12,8,0,250,36,0,0,255,241,0,0,57,1,0,0,16,16,8,0,0,26,0,0,255,241,0,0,58,1,0,0,12,12,9,0,136,18,0,0,255,241,0,0,59,1,0,0,14,14,11,0,192,24,0,0,255,241,0,0,60,1,0,0,8,8,6,0,236,34,0,0,255,241,0,0,95,1,0,0,12,12,8,0,52,50,0,0,255,241,0,0,103,1,0,0,14,14,9,0,50,16,0,0,255,241,0,0,120,1,0,0,16,16,8,0,54,16,0,0,255,241,0,0,121,1,0,0,20,20,8,0,20,14,0,0,255,241,0,0,159,1,0,0,12,14,8,0,56,39,0,0,255,241,0,0,167,1,0,0,14,16,9,0,186,47,0,0,255,241,0,0,184,1,0,0,16,18,8,0,192,47,0,0,255,241,0,0,185,1,0,0,20,22,8,0,34,20,0,0,255,241,0,0,223,1,0,0,12,12,8,0,98,16,0,0,255,241,0,0,231,1,0,0,14,14,9,0,128,39,0,0,255,241,0,0,248,1,0,0,16,16,8,0,126,39,0,0,255,241,0,0,249,1,0,0,20,20,8,0,132,2,0,0,255,241,0,0,31,16,0,0,8,8,6,0,206,43,0,0,255,241,0,0,39,16,0,0,10,10,7,0,68,39,0,0,255,241,0,0,56,16,0,0,12,12,6,0,62,39,0,0,255,241,0,0,57,16,0,0,16,16,6,0,82,24,0,0,255,241,0,0,58,16,0,0,12,12,7,0,238,16,0,0,255,241,0,0,59,16,0,0,14,14,9,0,188,18,0,0,255,241,0,0,60,16,0,0,8,8,4,0,20,44,0,0,255,241,0,0,159,16,0,0,12,12,8,0,122,38,0,0,255,241,0,0,167,16,0,0,14,14,9,0,10,28,0,0,255,241,0,0,184,16,0,0,16,16,8,0,6,28,0,0,255,241,0,0,185,16,0,0,20,20,8,0,194,15,0,0,255,241,0,0,186,16,0,0,16,16,9,0,212,11,0,0,255,241,0,0,187,16,0,0,18,18,11,0,22,37,0,0,255,241,0,0,188,16,0,0,12,12,6,0,226,34,0,0,255,241,0,0,223,16,0,0,12,12,8,0,182,40,0,0,255,241,0,0,231,16,0,0,14,14,9,0,0,17,0,0,255,241,0,0,248,16,0,0,16,16,8,0,28,34,0,0,255,241,0,0,249,16,0,0,20,20,8,0,48,32,0,0,255,241,0,0,250,16,0,0,16,16,9,0,252,39,0,0,255,241,0,0,251,16,0,0,18,18,11,0,44,29,0,0,255,241,0,0,252,16,0,0,12,12,6,0,2,37,0,0,255,241,0,0,31,17,0,0,12,12,9,0,52,31,0,0,255,241,0,0,39,17,0,0,14,14,10,0,84,37,0,0,255,241,0,0,56,17,0,0,16,16,9,0,86,37,0,0,255,241,0,0,57,17,0,0,20,20,9,0,56,32,0,0,255,241,0,0,58,17,0,0,16,16,10,0,172,17,0,0,255,241,0,0,59,17,0,0,18,18,12,0,234,22,0,0,255,241,0,0,60,17,0,0,12,12,7,0,232,14,0,0,255,241,0,0,95,17,0,0,16,16,9,0,116,40,0,0,255,241,0,0,103,17,0,0,18,18,10,0,20,4,0,0,255,241,0,0,120,17,0,0,20,20,9,0,24,4,0,0,255,241,0,0,121,17,0,0,24,24,9,0,142,5,0,0,255,241,0,0,122,17,0,0,20,20,10,0,114,11,0,0,255,241,0,0,123,17,0,0,22,22,12,0,102,15,0,0,255,241,0,0,124,17,0,0,16,16,7,0,178,12,0,0,255,241,0,0,159,17,0,0,18,18,11,0,70,18,0,0,255,241,0,0,167,17,0,0,20,20,12,0,186,20,0,0,255,241,0,0,184,17,0,0,22,22,11,0,84,19,0,0,255,241,0,0,185,17,0,0,26,26,11,0,204,26,0,0,255,241,0,0,186,17,0,0,22,22,12,0,178,35,0,0,255,241,0,0,187,17,0,0,24,24,14,0,46,25,0,0,255,241,0,0,188,17,0,0,18,18,9,0,4,2,0,0,255,241,0,0,56,32,0,0,16,16,6,0,246,1,0,0,255,241,0,0,57,32,0,0,20,20,6,0,184,13,0,0,255,241,0,0,58,32,0,0,16,16,7,0,126,17,0,0,255,241,0,0,59,32,0,0,18,18,9,0,122,23,0,0,255,241,0,0,60,32,0,0,12,12,6,0,102,14,0,0,255,241,0,0,120,32,0,0,16,16,6,0,98,14,0,0,255,241,0,0,121,32,0,0,20,20,6,0,24,32,0,0,255,241,0,0,122,32,0,0,16,16,7,0,202,39,0,0,255,241,0,0,123,32,0,0,18,18,9,0,200,38,0,0,255,241,0,0,124,32,0,0,12,12,6,0,208,34,0,0,255,241,0,0,184,32,0,0,24,24,8,0,206,34,0,0,255,241,0,0,185,32,0,0,28,28,8,0,190,7,0,0,255,241,0,0,186,32,0,0,24,24,9,0,228,5,0,0,255,241,0,0,187,32,0,0,26,26,11,0,6,49,0,0,255,241,0,0,188,32,0,0,20,20,8,0,2,0,0,0,255,241,0,0,248,32,0,0,24,24,8,0,6,0,0,0,255,241,0,0,249,32,0,0,28,28,8,0,228,29,0,0,255,241,0,0,250,32,0,0,24,24,9,0,78,26,0,0,255,241,0,0,251,32,0,0,26,26,11,0,6,25,0,0,255,241,0,0,252,32,0,0,20,20,8,0,92,22,0,0,255,241,0,0,56,33,0,0,24,26,9,0,94,22,0,0,255,241,0,0,57,33,0,0,28,30,9,0,34,15,0,0,255,241,0,0,58,33,0,0,24,26,10,0,216,18,0,0,255,241,0,0,59,33,0,0,26,28,12,0,76,35,0,0,255,241,0,0,60,33,0,0,20,22,9,0,252,48,0,0,255,241,0,0,120,33,0,0,28,28,9,0,254,48,0,0,255,241,0,0,121,33,0,0,32,32,9,0,16,6,0,0,255,241,0,0,122,33,0,0,28,28,10,0,0,47,0,0,255,241,0,0,123,33,0,0,30,30,12,0,232,10,0,0,255,241,0,0,124,33,0,0,24,24,9,0,92,16,0,0,255,241,0,0,184,33,0,0,30,30,11,0,88,16,0,0,255,241,0,0,185,33,0,0,34,34,11,0,4,18,0,0,255,241,0,0,186,33,0,0,30,30,12,0,156,10,0,0,255,241,0,0,187,33,0,0,32,32,14,0,20,26,0,0,255,241,0,0,188,33,0,0,26,26,11,0,16,0,0,0,255,241,0,0,56,48,0,0,12,12,6,0,20,0,0,0,255,241,0,0,57,48,0,0,16,16,6,0,216,15,0,0,255,241,0,0,58,48,0,0,12,12,7,0,134,19,0,0,255,241,0,0,59,48,0,0,14,14,9,0,134,29,0,0,255,241,0,0,60,48,0,0,8,8,4,0,208,30,0,0,255,241,0,0,120,48,0,0,12,12,6,0,204,30,0,0,255,241,0,0,121,48,0,0,16,16,6,0,150,15,0,0,255,241,0,0,122,48,0,0,12,12,7,0,66,19,0,0,255,241,0,0,123,48,0,0,14,14,9,0,104,6,0,0,255,241,0,0,124,48,0,0,8,8,4,0,94,21,0,0,255,241,0,0,184,48,0,0,16,16,8,0,98,21,0,0,255,241,0,0,185,48,0,0,20,20,8,0,130,46,0,0,255,241,0,0,186,48,0,0,16,16,9,0,162,5,0,0,255,241,0,0,187,48,0,0,18,18,11,0,122,2,0,0,255,241,0,0,188,48,0,0,12,12,6,0,156,0,0,0,255,241,0,0,248,48,0,0,16,16,8,0,160,0,0,0,255,241,0,0,249,48,0,0,20,20,8,0,12,4,0,0,255,241,0,0,250,48,0,0,16,16,9,0,16,45,0,0,255,241,0,0,251,48,0,0,18,18,11,0,110,39,0,0,255,241,0,0,252,48,0,0,12,12,6,0,26,11,0,0,255,241,0,0,56,49,0,0,16,16,9,0,24,11,0,0,255,241,0,0,57,49,0,0,20,20,9,0,230,18,0,0,255,241,0,0,58,49,0,0,16,16,10,0,136,24,0,0,255,241,0,0,59,49,0,0,18,18,12,0,18,47,0,0,255,241,0,0,60,49,0,0,12,12,7,0,246,23,0,0,255,241,0,0,120,49,0,0,20,20,9,0,242,23,0,0,255,241,0,0,121,49,0,0,24,24,9,0,242,5,0,0,255,241,0,0,122,49,0,0,20,20,10,0,182,48,0,0,255,241,0,0,123,49,0,0,22,22,12,0,76,36,0,0,255,241,0,0,124,49,0,0,16,16,7,0,152,46,0,0,255,241,0,0,184,49,0,0,22,22,11,0,148,46,0,0,255,241,0,0,185,49,0,0,26,26,11,0,66,20,0,0,255,241,0,0,186,49,0,0,22,22,12,0,226,12,0,0,255,241,0,0,187,49,0,0,24,24,14,0,8,37,0,0,255,241,0,0,188,49,0,0,18,18,9,0,132,13,0,0,255,241,0,0,56,65,0,0,0,0,12,0,134,13,0,0,255,241,0,0,57,65,0,0,0,0,12,0,166,50,0,0,255,241,0,0,58,65,0,0,0,0,13,0,228,9,0,0,255,241,0,0,59,65,0,0,0,0,15,0,72,19,0,0,255,241,0,0,60,65,0,0,0,0,12,0,88,30,0,0,255,241,0,0,184,65,0,0,18,16,12,0,92,30,0,0,255,241,0,0,185,65,0,0,22,20,12,0,246,31,0,0,255,241,0,0,186,65,0,0,18,16,13,0,42,41,0,0,255,241,0,0,187,65,0,0,20,18,15,0,178,10,0,0,255,241,0,0,188,65,0,0,14,12,10,0,126,24,0,0,255,241,0,0,248,65,0,0,8,8,6,0,122,24,0,0,255,241,0,0,249,65,0,0,12,12,6,0,146,23,0,0,255,241,0,0,250,65,0,0,8,8,7,0,108,32,0,0,255,241,0,0,251,65,0,0,12,12,9,0,154,18,0,0,255,241,0,0,31,80,0,0,12,12,8,0,112,31,0,0,255,241,0,0,39,80,0,0,14,14,9,0,190,9,0,0,255,241,0,0,56,80,0,0,16,16,8,0,110,27,0,0,255,241,0,0,57,80,0,0,20,20,8,0,226,8,0,0,255,241,0,0,120,80,0,0,16,16,8,0,222,8,0,0,255,241,0,0,121,80,0,0,20,20,8,0,28,18,0,0,255,241,0,0,184,80,0,0,24,24,8,0,24,18,0,0,255,241,0,0,185,80,0,0,28,28,8,0,96,28,0,0,255,241,0,0,31,81,0,0,12,12,8,0,238,33,0,0,255,241,0,0,39,81,0,0,14,14,9,0,234,15,0,0,255,241,0,0,56,81,0,0,16,16,8,0,230,15,0,0,255,241,0,0,57,81,0,0,20,20,8,0,92,14,0,0,255,241,0,0,120,81,0,0,16,16,8,0,20,28,0,0,255,241,0,0,121,81,0,0,20,20,8,0,80,9,0,0,255,241,0,0,184,81,0,0,24,24,8,0,82,9,0,0,255,241,0,0,185,81,0,0,28,28,8,0,240,46,0,0,255,241,0,0,31,128,0,0,8,8,6,0,28,6,0,0,255,241,0,0,39,128,0,0,10,10,7,0,48,25,0,0,255,241,0,0,56,128,0,0,12,12,6,0,52,25,0,0,255,241,0,0,57,128,0,0,16,16,6,0,6,27,0,0,255,241,0,0,58,128,0,0,12,12,7,0,130,30,0,0,255,241,0,0,59,128,0,0,14,14,9,0,96,15,0,0,255,241,0,0,60,128,0,0,8,8,4,0,172,35,0,0,255,241,0,0,120,128,0,0,12,12,6,0,176,35,0,0,255,241,0,0,121,128,0,0,16,16,6,0,162,41,0,0,255,241,0,0,122,128,0,0,12,12,7,0,242,35,0,0,255,241,0,0,123,128,0,0,14,14,9,0,82,44,0,0,255,241,0,0,124,128,0,0,8,8,4,0,152,9,0,0,255,241,0,0,184,128,0,0,18,18,6,0,144,9,0,0,255,241,0,0,185,128,0,0,22,22,6,0,32,27,0,0,255,241,0,0,186,128,0,0,18,18,7,0,138,21,0,0,255,241,0,0,187,128,0,0,20,20,9,0,96,45,0,0,255,241,0,0,188,128,0,0,16,14,6,0,174,5,0,0,255,241,0,0,248,128,0,0,148,116,48,0,178,5,0,0,255,241,0,0,249,128,0,0,152,120,48,0,242,41,0,0,255,241,0,0,250,128,0,0,148,116,49,0,116,45,0,0,255,241,0,0,251,128,0,0,150,118,51,0,130,38,0,0,255,241,0,0,252,128,0,0,144,112,46,0,168,33,0,0,255,241,0,0,15,129,0,0,18,18,16,0,128,43,0,0,255,241,0,0,31,129,0,0,12,12,8,0,160,33,0,0,255,241,0,0,39,129,0,0,14,14,9,0,86,11,0,0,255,241,0,0,56,129,0,0,16,16,8,0,50,14,0,0,255,241,0,0,57,129,0,0,20,20,8,0,202,16,0,0,255,241,0,0,79,129,0,0,0,0,13,0,40,43,0,0,255,241,0,0,120,129,0,0,16,16,8,0,42,43,0,0,255,241,0,0,121,129,0,0,20,20,8,0,92,28,0,0,255,241,0,0,143,129,0,0,0,0,13,0,100,19,0,0,255,241,0,0,184,129,0,0,24,24,8,0,106,19,0,0,255,241,0,0,185,129,0,0,28,28,8,0,32,13,0,0,255,241,0,0,248,129,0,0,166,130,60,0,24,13,0,0,255,241,0,0,249,129,0,0,170,134,60,0,194,8,0,0,255,241,0,0,250,129,0,0,166,130,61,0,220,17,0,0,255,241,0,0,251,129,0,0,168,132,63,0,48,29,0,0,255,241,0,0,252,129,0,0,162,126,58,0,138,26,0,0,255,241,0,0,31,144,0,0,8,8,6,0,52,17,0,0,255,241,0,0,39,144,0,0,10,10,7,0,6,34,0,0,255,241,0,0,56,144,0,0,12,12,6,0,2,34,0,0,255,241,0,0,57,144,0,0,16,16,6,0,250,45,0,0,255,241,0,0,58,144,0,0,12,12,7,0,104,9,0,0,255,241,0,0,59,144,0,0,14,14,9,0,224,2,0,0,255,241,0,0,60,144,0,0,8,8,4,0,214,19,0,0,255,241,0,0,120,144,0,0,12,12,6,0,64,14,0,0,255,241,0,0,121,144,0,0,16,16,6,0,58,39,0,0,255,241,0,0,122,144,0,0,12,12,7,0,172,2,0,0,255,241,0,0,123,144,0,0,14,14,9,0,74,42,0,0,255,241,0,0,124,144,0,0,8,8,4,0,180,5,0,0,255,241,0,0,184,144,0,0,18,18,6,0,170,5,0,0,255,241,0,0,185,144,0,0,22,22,6,0,46,6,0,0,255,241,0,0,186,144,0,0,18,18,7,0,58,10,0,0,255,241,0,0,187,144,0,0,20,20,9,0,184,23,0,0,255,241,0,0,188,144,0,0,16,14,6,0,28,35,0,0,255,241,0,0,248,144,0,0,16,16,6,0,24,35,0,0,255,241,0,0,249,144,0,0,20,20,6,0,180,40,0,0,255,241,0,0,250,144,0,0,16,16,7,0,96,31,0,0,255,241,0,0,251,144,0,0,18,18,9,0,2,39,0,0,255,241,0,0,252,144,0,0,12,12,4,0,112,49,0,0,255,241,0,0,15,145,0,0,18,18,12,0,102,24,0,0,255,241,0,0,31,145,0,0,12,12,8,0,204,18,0,0,255,241,0,0,39,145,0,0,14,14,9,0,236,26,0,0,255,241,0,0,56,145,0,0,16,16,8,0,238,26,0,0,255,241,0,0,57,145,0,0,20,20,8,0,174,38,0,0,255,241,0,0,120,145,0,0,16,16,8,0,170,38,0,0,255,241,0,0,121,145,0,0,20,20,8,0,240,24,0,0,255,241,0,0,184,145,0,0,24,24,8,0,238,24,0,0,255,241,0,0,185,145,0,0,28,28,8,0,22,1,0,0,255,241,0,0,248,145,0,0,18,18,6,0,16,1,0,0,255,241,0,0,249,145,0,0,22,22,6,0,58,12,0,0,255,241,0,0,250,145,0,0,18,18,7,0,176,45,0,0,255,241,0,0,251,145,0,0,20,20,9,0,184,31,0,0,255,241,0,0,252,145,0,0,16,14,6,0,28,46,0,0,255,241,0,0,31,176,0,0,8,8,6,0,194,40,0,0,255,241,0,0,39,176,0,0,10,10,7,0,164,21,0,0,255,241,0,0,56,176,0,0,12,12,6,0,202,45,0,0,255,241,0,0,57,176,0,0,16,16,6,0,74,50,0,0,255,241,0,0,58,176,0,0,12,12,7,0,16,43,0,0,255,241,0,0,59,176,0,0,14,14,9,0,184,40,0,0,255,241,0,0,60,176,0,0,8,8,4,0,220,45,0,0,255,241,0,0,120,176,0,0,12,12,6,0,214,45,0,0,255,241,0,0,121,176,0,0,16,16,6,0,242,25,0,0,255,241,0,0,122,176,0,0,12,12,7,0,152,29,0,0,255,241,0,0,123,176,0,0,14,14,9,0,0,16,0,0,255,241,0,0,124,176,0,0,8,8,4,0,78,29,0,0,255,241,0,0,184,176,0,0,18,18,6,0,76,29,0,0,255,241,0,0,185,176,0,0,22,22,6,0,168,42,0,0,255,241,0,0,186,176,0,0,18,18,7,0,186,49,0,0,255,241,0,0,187,176,0,0,20,20,9,0,218,47,0,0,255,241,0,0,188,176,0,0,14,14,6,0,130,16,0,0,255,241,0,0,248,176,0,0,14,14,8,0,134,16,0,0,255,241,0,0,249,176,0,0,18,18,8,0,150,6,0,0,255,241,0,0,250,176,0,0,14,14,9,0,84,0,0,0,255,241,0,0,251,176,0,0,16,16,11,0,156,50,0,0,255,241,0,0,252,176,0,0,10,10,6,0,78,48,0,0,255,241,0,0,15,177,0,0,12,12,9,0,162,17,0,0,255,241,0,0,31,177,0,0,12,12,8,0,22,12,0,0,255,241,0,0,39,177,0,0,14,14,9,0,38,0,0,0,255,241,0,0,56,177,0,0,16,16,8,0,34,0,0,0,255,241,0,0,57,177,0,0,20,20,8,0,142,29,0,0,255,241,0,0,120,177,0,0,16,16,8,0,70,23,0,0,255,241,0,0,121,177,0,0,20,20,8,0,90,2,0,0,255,241,0,0,184,177,0,0,24,24,8,0,92,2,0,0,255,241,0,0,185,177,0,0,28,28,8,0,186,3,0,0,255,241,0,0,248,177,0,0,18,18,8,0,190,3,0,0,255,241,0,0,249,177,0,0,22,22,8,0,70,36,0,0,255,241,0,0,250,177,0,0,18,18,9,0,248,18,0,0,255,241,0,0,251,177,0,0,20,20,11,0,12,39,0,0,255,241,0,0,252,177,0,0,14,14,8,0,92,45,0,0,255,241,0,0,31,192,0,0,8,8,6,0,106,2,0,0,255,241,0,0,39,192,0,0,10,10,7,0,208,0,0,0,255,241,0,0,56,192,0,0,12,12,6,0,212,0,0,0,255,241,0,0,57,192,0,0,16,16,6,0,232,19,0,0,255,241,0,0,58,192,0,0,12,12,7,0,248,28,0,0,255,241,0,0,59,192,0,0,14,14,9,0,26,40,0,0,255,241,0,0,60,192,0,0,8,8,4,0,122,27,0,0,255,241,0,0,120,192,0,0,12,12,6,0,118,27,0,0,255,241,0,0,121,192,0,0,16,16,6,0,164,5,0,0,255,241,0,0,122,192,0,0,12,12,7,0,98,48,0,0,255,241,0,0,123,192,0,0,14,14,9,0,214,29,0,0,255,241,0,0,124,192,0,0,8,8,4,0,180,38,0,0,255,241,0,0,184,192,0,0,18,18,6,0,186,38,0,0,255,241,0,0,185,192,0,0,22,22,6,0,176,14,0,0,255,241,0,0,186,192,0,0,18,18,7,0,204,10,0,0,255,241,0,0,187,192,0,0,20,20,9,0,208,45,0,0,255,241,0,0,188,192,0,0,16,14,6,0,118,8,0,0,255,241,0,0,248,192,0,0,62,38,31,0,100,46,0,0,255,241,0,0,249,192,0,0,66,42,31,0,46,1,0,0,255,241,0,0,250,192,0,0,62,38,32,0,4,46,0,0,255,241,0,0,251,192,0,0,64,40,34,0,30,14,0,0,255,241,0,0,252,192,0,0,58,34,29,0,130,17,0,0,255,241,0,0,15,193,0,0,18,18,16,0,56,34,0,0,255,241,0,0,31,193,0,0,12,12,8,0,176,41,0,0,255,241,0,0,39,193,0,0,14,14,9,0,98,25,0,0,255,241,0,0,56,193,0,0,16,16,8,0,92,25,0,0,255,241,0,0,57,193,0,0,20,20,8,0,148,22,0,0,255,241,0,0,120,193,0,0,16,16,8,0,114,29,0,0,255,241,0,0,121,193,0,0,20,20,8,0,16,12,0,0,255,241,0,0,184,193,0,0,24,24,8,0,12,12,0,0,255,241,0,0,185,193,0,0,28,28,8,0,164,23,0,0,255,241,0,0,248,193,0,0,62,40,31,0,168,23,0,0,255,241,0,0,249,193,0,0,66,44,31,0,36,38,0,0,255,241,0,0,250,193,0,0,62,40,32,0,26,29,0,0,255,241,0,0,251,193,0,0,64,42,34,0,122,10,0,0,255,241,0,0,252,193,0,0,58,36,29,0,250,19,0,0,255,241,0,0,31,208,0,0,8,8,6,0,144,37,0,0,255,241,0,0,39,208,0,0,10,10,7,0,206,31,0,0,255,241,0,0,56,208,0,0,12,12,6,0,208,31,0,0,255,241,0,0,57,208,0,0,16,16,6,0,136,32,0,0,255,241,0,0,58,208,0,0,12,12,7,0,66,40,0,0,255,241,0,0,59,208,0,0,14,14,9,0,156,37,0,0,255,241,0,0,60,208,0,0,8,8,4,0,186,17,0,0,255,241,0,0,120,208,0,0,12,12,6,0,184,17,0,0,255,241,0,0,121,208,0,0,16,16,6,0,242,26,0,0,255,241,0,0,122,208,0,0,12,12,7,0,144,19,0,0,255,241,0,0,123,208,0,0,14,14,9,0,120,5,0,0,255,241,0,0,124,208,0,0,8,8,4,0,42,26,0,0,255,241,0,0,184,208,0,0,18,18,6,0,36,26,0,0,255,241,0,0,185,208,0,0,22,22,6,0,214,28,0,0,255,241,0,0,186,208,0,0,18,18,7,0,38,25,0,0,255,241,0,0,187,208,0,0,20,20,9,0,200,47,0,0,255,241,0,0,188,208,0,0,16,14,6,0,214,33,0,0,255,241,0,0,248,208,0,0,16,16,6,0,222,33,0,0,255,241,0,0,249,208,0,0,20,20,6,0,148,15,0,0,255,241,0,0,250,208,0,0,16,16,7,0,74,21,0,0,255,241,0,0,251,208,0,0,18,18,9,0,102,0,0,0,255,241,0,0,252,208,0,0,12,12,4,0,246,9,0,0,255,241,0,0,15,209,0,0,18,18,12,0,40,36,0,0,255,241,0,0,31,209,0,0,12,12,8,0,28,45,0,0,255,241,0,0,39,209,0,0,14,14,9,0,184,8,0,0,255,241,0,0,56,209,0,0,16,16,8,0,178,8,0,0,255,241,0,0,57,209,0,0,20,20,8,0,18,29,0,0,255,241,0,0,120,209,0,0,16,16,8,0,22,29,0,0,255,241,0,0,121,209,0,0,20,20,8,0,208,2,0,0,255,241,0,0,184,209,0,0,24,24,8,0,212,2,0,0,255,241,0,0,185,209,0,0,28,28,8,0,34,7,0,0,255,241,0,0,248,209,0,0,18,18,6,0,36,7,0,0,255,241,0,0,249,209,0,0,22,22,6,0,224,48,0,0,255,241,0,0,250,209,0,0,18,18,7,0,50,8,0,0,255,241,0,0,251,209,0,0,20,20,9,0,252,18,0,0,255,241,0,0,252,209,0,0,16,14,6,0,136,43,0,0,248,255,0,0,0,0,0,0,8,8,2,0,20,19,0,0,248,255,0,0,16,0,0,0,16,16,8,0,34,34,0,0,248,255,0,0,24,0,0,0,16,16,8,0,32,34,0,0,248,255,0,0,32,0,0,0,18,18,9,0,122,4,0,0,248,255,0,0,40,0,0,0,20,20,9,0,254,7,0,0,248,255,0,0,48,0,0,0,22,22,11,0,184,43,0,0,248,255,0,0,64,0,0,0,8,8,2,0,172,29,0,0,248,255,0,0,80,0,0,0,16,16,8,0,154,7,0,0,248,255,0,0,88,0,0,0,16,16,8,0,150,7,0,0,248,255,0,0,96,0,0,0,18,18,9,0,40,35,0,0,248,255,0,0,104,0,0,0,20,20,9,0,100,31,0,0,248,255,0,0,112,0,0,0,22,22,11,0,250,41,0,0,248,255,0,0,128,0,0,0,16,14,2,0,232,49,0,0,248,255,0,0,144,0,0,0,28,28,8,0,246,34,0,0,248,255,0,0,152,0,0,0,28,28,8,0,248,34,0,0,248,255,0,0,160,0,0,0,30,30,9,0,110,7,0,0,248,255,0,0,168,0,0,0,32,32,9,0,66,48,0,0,248,255,0,0,176,0,0,0,34,34,11,0,106,40,0,0,248,255,0,0,208,0,0,0,0,0,22,0,170,34,0,0,248,255,0,0,232,0,0,0,0,0,23,0,46,42,0,0,248,255,0,0,240,0,0,0,0,0,25,0,0,21,0,0,248,255,0,0,0,2,0,0,8,8,2,0,190,11,0,0,248,255,0,0,16,2,0,0,16,16,8,0,184,33,0,0,248,255,0,0,24,2,0,0,16,16,8,0,186,33,0,0,248,255,0,0,32,2,0,0,18,18,9,0,6,6,0,0,248,255,0,0,40,2,0,0,20,20,9,0,252,9,0,0,248,255,0,0,48,2,0,0,22,22,11,0,138,17,0,0,248,255,0,0,64,2,0,0,8,8,2,0,228,7,0,0,248,255,0,0,80,2,0,0,16,16,8,0,184,35,0,0,248,255,0,0,88,2,0,0,16,16,8,0,188,35,0,0,248,255,0,0,96,2,0,0,18,18,9,0,112,15,0,0,248,255,0,0,104,2,0,0,20,20,9,0,172,9,0,0,248,255,0,0,112,2,0,0,22,22,11,0,74,12,0,0,248,255,0,0,128,2,0,0,14,14,2,0,10,48,0,0,248,255,0,0,144,2,0,0,28,28,8,0,34,26,0,0,248,255,0,0,152,2,0,0,28,28,8,0,32,26,0,0,248,255,0,0,160,2,0,0,30,30,9,0,70,3,0,0,248,255,0,0,168,2,0,0,32,32,9,0,44,46,0,0,248,255,0,0,176,2,0,0,34,34,11,0,166,2,0,0,248,255,0,0,208,2,0,0,0,0,22,0,144,10,0,0,248,255,0,0,232,2,0,0,0,0,23,0,162,0,0,0,248,255,0,0,240,2,0,0,0,0,25,0,202,18,0,0,248,255,0,0,0,4,0,0,8,8,2,0,130,25,0,0,248,255,0,0,16,4,0,0,16,16,8,0,90,10,0,0,248,255,0,0,24,4,0,0,16,16,8,0,92,10,0,0,248,255,0,0,32,4,0,0,18,18,9,0,140,32,0,0,248,255,0,0,40,4,0,0,20,20,9,0,42,27,0,0,248,255,0,0,48,4,0,0,22,22,11,0,208,19,0,0,248,255,0,0,64,4,0,0,8,8,2,0,16,41,0,0,248,255,0,0,80,4,0,0,16,16,8,0,40,13,0,0,248,255,0,0,88,4,0,0,16,16,8,0,38,13,0,0,248,255,0,0,96,4,0,0,18,18,9,0,124,33,0,0,248,255,0,0,104,4,0,0,20,20,9,0,196,42,0,0,248,255,0,0,112,4,0,0,22,22,11,0,98,20,0,0,248,255,0,0,128,4,0,0,16,14,2,0,62,31,0,0,248,255,0,0,144,4,0,0,28,28,8,0,22,3,0,0,248,255,0,0,152,4,0,0,28,28,8,0,24,3,0,0,248,255,0,0,160,4,0,0,30,30,9,0,158,40,0,0,248,255,0,0,168,4,0,0,32,32,9,0,24,33,0,0,248,255,0,0,176,4,0,0,34,34,11,0,4,36,0,0,248,255,0,0,208,4,0,0,0,0,22,0,194,41,0,0,248,255,0,0,232,4,0,0,0,0,23,0,222,43,0,0,248,255,0,0,240,4,0,0,0,0,25,0,86,25,0,0,248,255,0,0,0,6,0,0,8,8,2,0,106,31,0,0,248,255,0,0,16,6,0,0,16,16,8,0,62,3,0,0,248,255,0,0,24,6,0,0,16,16,8,0,58,3,0,0,248,255,0,0,32,6,0,0,18,18,9,0,114,0,0,0,248,255,0,0,40,6,0,0,20,20,9,0,32,33,0,0,248,255,0,0,48,6,0,0,22,22,11,0,194,17,0,0,248,255,0,0,64,6,0,0,8,8,2,0,234,47,0,0,248,255,0,0,80,6,0,0,16,16,8,0,44,26,0,0,248,255,0,0,88,6,0,0,16,16,8,0,46,26,0,0,248,255,0,0,96,6,0,0,18,18,9,0,74,3,0,0,248,255,0,0,104,6,0,0,20,20,9,0,182,49,0,0,248,255,0,0,112,6,0,0,22,22,11,0,132,35,0,0,248,255,0,0,128,6,0,0,16,14,2,0,26,7,0,0,248,255,0,0,144,6,0,0,28,28,8,0,102,42,0,0,248,255,0,0,152,6,0,0,28,28,8,0,104,42,0,0,248,255,0,0,160,6,0,0,30,30,9,0,188,14,0,0,248,255,0,0,168,6,0,0,32,32,9,0,246,8,0,0,248,255,0,0,176,6,0,0,34,34,11,0,186,0,0,0,248,255,0,0,208,6,0,0,0,0,64,0,152,45,0,0,248,255,0,0,232,6,0,0,0,0,65,0,136,49,0,0,248,255,0,0,240,6,0,0,0,0,67,0,240,5,0,0,248,255,0,0,0,8,0,0,10,10,4,0,166,46,0,0,248,255,0,0,16,8,0,0,12,12,8,0,232,24,0,0,248,255,0,0,24,8,0,0,12,12,8,0,230,24,0,0,248,255,0,0,32,8,0,0,14,14,9,0,250,9,0,0,248,255,0,0,40,8,0,0,16,16,9,0,2,45,0,0,248,255,0,0,48,8,0,0,18,18,11,0,122,3,0,0,248,255,0,0,64,8,0,0,12,12,4,0,104,20,0,0,248,255,0,0,80,8,0,0,16,16,8,0,52,35,0,0,248,255,0,0,88,8,0,0,16,16,8,0,50,35,0,0,248,255,0,0,96,8,0,0,18,18,9,0,30,13,0,0,248,255,0,0,104,8,0,0,20,20,9,0,142,18,0,0,248,255,0,0,112,8,0,0,22,22,11,0,46,10,0,0,248,255,0,0,128,8,0,0,14,14,4,0,144,7,0,0,248,255,0,0,144,8,0,0,16,16,8,0,184,42,0,0,248,255,0,0,152,8,0,0,16,16,8,0,182,42,0,0,248,255,0,0,160,8,0,0,18,18,9,0,72,13,0,0,248,255,0,0,168,8,0,0,20,20,9,0,182,5,0,0,248,255,0,0,176,8,0,0,22,22,11,0,144,4,0,0,248,255,0,0,192,8,0,0,12,12,4,0,230,17,0,0,248,255,0,0,208,8,0,0,16,16,8,0,202,32,0,0,248,255,0,0,216,8,0,0,16,16,8,0,204,32,0,0,248,255,0,0,224,8,0,0,18,18,9,0,158,10,0,0,248,255,0,0,232,8,0,0,20,20,9,0,202,19,0,0,248,255,0,0,240,8,0,0,22,22,11,0,132,40,0,0,248,255,0,0,0,10,0,0,8,8,2,0,234,39,0,0,248,255,0,0,16,10,0,0,16,16,8,0,186,24,0,0,248,255,0,0,24,10,0,0,16,16,8,0,184,24,0,0,248,255,0,0,32,10,0,0,18,18,9,0,204,16,0,0,248,255,0,0,40,10,0,0,20,20,9,0,120,41,0,0,248,255,0,0,48,10,0,0,22,22,11,0,48,45,0,0,248,255,0,0,64,10,0,0,8,8,2,0,192,1,0,0,248,255,0,0,80,10,0,0,16,16,8,0,118,24,0,0,248,255,0,0,88,10,0,0,16,16,8,0,120,24,0,0,248,255,0,0,96,10,0,0,18,18,9,0,150,46,0,0,248,255,0,0,104,10,0,0,20,20,9,0,234,32,0,0,248,255,0,0,112,10,0,0,22,22,11,0,80,8,0,0,248,255,0,0,128,10,0,0,16,14,2,0,10,43,0,0,248,255,0,0,144,10,0,0,28,28,8,0,226,44,0,0,248,255,0,0,152,10,0,0,28,28,8,0,16,34,0,0,248,255,0,0,160,10,0,0,30,30,9,0,112,30,0,0,248,255,0,0,168,10,0,0,32,32,9,0,204,37,0,0,248,255,0,0,176,10,0,0,34,34,11,0,46,16,0,0,248,255,0,0,208,10,0,0,0,0,16,0,16,9,0,0,248,255,0,0,216,10,0,0,0,0,16,0,208,43,0,0,248,255,0,0,224,10,0,0,0,0,17,0,114,23,0,0,248,255,0,0,232,10,0,0,0,0,17,0,192,17,0,0,248,255,0,0,240,10,0,0,0,0,19,0,56,8,0,0,248,255,0,0,0,12,0,0,8,8,2,0,28,49,0,0,248,255,0,0,16,12,0,0,12,12,6,0,76,27,0,0,248,255,0,0,24,12,0,0,12,12,6,0,78,27,0,0,248,255,0,0,32,12,0,0,14,14,7,0,114,4,0,0,248,255,0,0,40,12,0,0,16,16,7,0,60,0,0,0,248,255,0,0,48,12,0,0,18,18,9,0,142,30,0,0,248,255,0,0,64,12,0,0,8,8,2,0,78,22,0,0,248,255,0,0,80,12,0,0,12,12,6,0,204,20,0,0,248,255,0,0,88,12,0,0,12,12,6,0,202,20,0,0,248,255,0,0,96,12,0,0,14,14,7,0,254,42,0,0,248,255,0,0,104,12,0,0,16,16,7,0,64,50,0,0,248,255,0,0,112,12,0,0,18,18,9,0,50,11,0,0,248,255,0,0,128,12,0,0,14,12,2,0,170,26,0,0,248,255,0,0,144,12,0,0,20,20,6,0,122,48,0,0,248,255,0,0,152,12,0,0,20,20,6,0,124,48,0,0,248,255,0,0,160,12,0,0,22,22,7,0,16,21,0,0,248,255,0,0,168,12,0,0,24,24,7,0,218,24,0,0,248,255,0,0,176,12,0,0,26,26,9,0,194,18,0,0,248,255,0,0,208,12,0,0,0,0,16,0,158,33,0,0,248,255,0,0,216,12,0,0,0,0,16,0,156,33,0,0,248,255,0,0,224,12,0,0,0,0,17,0,112,11,0,0,248,255,0,0,232,12,0,0,0,0,17,0,140,20,0,0,248,255,0,0,240,12,0,0,0,0,19,0,70,0,0,0,248,255,0,0,16,14,0,0,0,18,9,0,62,16,0,0,248,255,0,0,24,14,0,0,0,18,9,0,60,16,0,0,248,255,0,0,32,14,0,0,0,20,10,0,162,43,0,0,248,255,0,0,40,14,0,0,0,26,10,0,60,2,0,0,248,255,0,0,48,14,0,0,0,30,12,0,90,17,0,0,248,255,0,0,80,14,0,0,0,18,9,0,30,45,0,0,248,255,0,0,88,14,0,0,0,18,9,0,34,45,0,0,248,255,0,0,96,14,0,0,0,20,10,0,154,43,0,0,248,255,0,0,104,14,0,0,0,26,10,0,176,15,0,0,248,255,0,0,112,14,0,0,0,30,12,0,70,27,0,0,248,255,0,0,144,14,0,0,0,22,9,0,78,18,0,0,248,255,0,0,152,14,0,0,0,22,9,0,40,12,0,0,248,255,0,0,160,14,0,0,0,28,10,0,144,32,0,0,248,255,0,0,168,14,0,0,0,32,10,0,140,25,0,0,248,255,0,0,176,14,0,0,0,36,12,0,106,28,0,0,248,255,0,0,208,14,0,0,0,0,16,0,102,43,0,0,248,255,0,0,216,14,0,0,0,0,16,0,104,43,0,0,248,255,0,0,224,14,0,0,0,0,17,0,68,21,0,0,248,255,0,0,232,14,0,0,0,0,17,0,18,30,0,0,248,255,0,0,240,14,0,0,0,0,19,0,42,2,0,0,248,255,0,0,192,17,0,0,12,12,4,0,14,21,0,0,248,255,0,0,208,17,0,0,16,16,8,0,210,42,0,0,248,255,0,0,216,17,0,0,16,16,8,0,204,42,0,0,248,255,0,0,224,17,0,0,18,18,9,0,78,15,0,0,248,255,0,0,232,17,0,0,20,20,9,0,152,22,0,0,248,255,0,0,240,17,0,0,22,22,11,0,106,38,0,0,248,255,0,0,192,19,0,0,16,16,6,0,52,49,0,0,248,255,0,0,208,19,0,0,20,20,10,0,96,27,0,0,248,255,0,0,216,19,0,0,20,20,10,0,98,27,0,0,248,255,0,0,224,19,0,0,22,22,11,0,142,4,0,0,248,255,0,0,232,19,0,0,24,24,11,0,124,47,0,0,248,255,0,0,240,19,0,0,26,26,13,0,148,16,0,0,248,255,0,0,192,30,0,0,8,8,4,0,2,14,0,0,248,255,0,0,208,30,0,0,12,12,8,0,228,35,0,0,248,255,0,0,216,30,0,0,12,12,8,0,226,35,0,0,248,255,0,0,224,30,0,0,14,14,9,0,68,8,0,0,248,255,0,0,232,30,0,0,16,16,9,0,202,15,0,0,248,255,0,0,240,30,0,0,18,18,11,0,96,47,0,0,248,255,0,0,0,31,0,0,8,8,5,0,170,19,0,0,248,255,0,0,16,31,0,0,12,12,9,0,102,47,0,0,248,255,0,0,24,31,0,0,12,12,9,0,104,47,0,0,248,255,0,0,32,31,0,0,14,14,10,0,254,26,0,0,248,255,0,0,40,31,0,0,16,16,10,0,202,17,0,0,248,255,0,0,48,31,0,0,18,18,12,0,8,15,0,0,248,255,0,0,192,33,0,0,16,16,4,0,10,15,0,0,248,255,0,0,200,33,0,0,16,16,4,0,84,41,0,0,248,255,0,0,208,33,0,0,24,24,8,0,194,10,0,0,248,255,0,0,216,33,0,0,24,24,8,0,198,10,0,0,248,255,0,0,224,33,0,0,26,26,9,0,140,48,0,0,248,255,0,0,232,33,0,0,28,28,9,0,186,39,0,0,248,255,0,0,240,33,0,0,30,30,11,0,78,10,0,0,248,255,0,0,192,35,0,0,20,20,6,0,76,10,0,0,248,255,0,0,200,35,0,0,20,20,6,0,146,13,0,0,248,255,0,0,208,35,0,0,28,28,10,0,106,35,0,0,248,255,0,0,216,35,0,0,28,28,10,0,102,35,0,0,248,255,0,0,224,35,0,0,30,30,11,0,220,5,0,0,248,255,0,0,232,35,0,0,32,32,11,0,82,15,0,0,248,255,0,0,240,35,0,0,34,34,13,0,36,5,0,0,248,255,0,0,192,49,0,0,12,12,4,0,88,18,0,0,248,255,0,0,200,49,0,0,12,12,4,0,122,32,0,0,248,255,0,0,208,49,0,0,16,16,8,0,174,17,0,0,248,255,0,0,216,49,0,0,16,16,8,0,170,17,0,0,248,255,0,0,224,49,0,0,18,18,9,0,24,38,0,0,248,255,0,0,232,49,0,0,20,20,9,0,76,34,0,0,248,255,0,0,240,49,0,0,22,22,11,0,100,7,0,0,248,255,0,0,192,51,0,0,16,16,6,0,102,7,0,0,248,255,0,0,200,51,0,0,16,16,6,0,184,25,0,0,248,255,0,0,208,51,0,0,20,20,10,0,146,40,0,0,248,255,0,0,216,51,0,0,20,20,10,0,148,40,0,0,248,255,0,0,224,51,0,0,22,22,11,0,242,19,0,0,248,255,0,0,232,51,0,0,24,24,11,0,220,23,0,0,248,255,0,0,240,51,0,0,26,26,13,0,94,14,0,0,248,255,0,0,0,64,0,0,4,4,2,0,240,22,0,0,248,255,0,0,16,64,0,0,12,12,8,0,190,37,0,0,248,255,0,0,24,64,0,0,12,12,8,0,192,37,0,0,248,255,0,0,32,64,0,0,14,14,9,0,164,15,0,0,248,255,0,0,40,64,0,0,16,16,9,0,80,21,0,0,248,255,0,0,48,64,0,0,18,18,11,0,124,9,0,0,248,255,0,0,64,64,0,0,4,4,2,0,0,12,0,0,248,255,0,0,80,64,0,0,12,12,8,0,216,46,0,0,248,255,0,0,88,64,0,0,12,12,8,0,214,46,0,0,248,255,0,0,96,64,0,0,14,14,9,0,74,19,0,0,248,255,0,0,104,64,0,0,16,16,9,0,220,13,0,0,248,255,0,0,112,64,0,0,18,18,11,0,12,15,0,0,248,255,0,0,128,64,0,0,6,6,2,0,70,35,0,0,248,255,0,0,144,64,0,0,20,20,8,0,102,13,0,0,248,255,0,0,152,64,0,0,20,20,8,0,100,13,0,0,248,255,0,0,160,64,0,0,22,22,9,0,246,40,0,0,248,255,0,0,168,64,0,0,24,24,9,0,36,37,0,0,248,255,0,0,176,64,0,0,26,26,11,0,250,40,0,0,248,255,0,0,192,64,0,0,6,4,8,0,172,36,0,0,248,255,0,0,208,64,0,0,12,12,12,0,20,1,0,0,248,255,0,0,216,64,0,0,12,12,12,0,26,1,0,0,248,255,0,0,224,64,0,0,14,14,13,0,2,22,0,0,248,255,0,0,232,64,0,0,16,16,13,0,112,38,0,0,248,255,0,0,240,64,0,0,18,18,15,0,12,42,0,0,248,255,0,0,0,66,0,0,4,4,2,0,196,27,0,0,248,255,0,0,16,66,0,0,12,8,8,0,112,5,0,0,248,255,0,0,24,66,0,0,12,8,8,0,114,5,0,0,248,255,0,0,32,66,0,0,14,10,9,0,60,33,0,0,248,255,0,0,40,66,0,0,16,12,9,0,122,29,0,0,248,255,0,0,48,66,0,0,18,14,11,0,194,0,0,0,248,255,0,0,64,66,0,0,4,4,2,0,164,28,0,0,248,255,0,0,80,66,0,0,12,8,8,0,134,50,0,0,248,255,0,0,88,66,0,0,12,8,8,0,132,50,0,0,248,255,0,0,96,66,0,0,14,10,9,0,36,23,0,0,248,255,0,0,104,66,0,0,16,12,9,0,74,30,0,0,248,255,0,0,112,66,0,0,18,14,11,0,40,10,0,0,248,255,0,0,128,66,0,0,6,6,2,0,226,25,0,0,248,255,0,0,144,66,0,0,20,12,8,0,168,47,0,0,248,255,0,0,152,66,0,0,20,12,8,0,170,47,0,0,248,255,0,0,160,66,0,0,22,14,9,0,54,20,0,0,248,255,0,0,168,66,0,0,24,16,9,0,2,40,0,0,248,255,0,0,176,66,0,0,26,20,11,0,66,8,0,0,248,255,0,0,192,66,0,0,0,4,4,0,28,5,0,0,248,255,0,0,208,66,0,0,0,12,8,0,140,27,0,0,248,255,0,0,216,66,0,0,0,12,8,0])
.concat([142,27,0,0,248,255,0,0,224,66,0,0,0,14,9,0,28,48,0,0,248,255,0,0,232,66,0,0,0,16,9,0,12,7,0,0,248,255,0,0,240,66,0,0,0,18,11,0,226,3,0,0,248,255,0,0,0,68,0,0,4,4,2,0,48,17,0,0,248,255,0,0,16,68,0,0,12,12,8,0,106,39,0,0,248,255,0,0,24,68,0,0,12,12,8,0,104,39,0,0,248,255,0,0,32,68,0,0,14,14,9,0,156,11,0,0,248,255,0,0,40,68,0,0,16,16,9,0,240,18,0,0,248,255,0,0,48,68,0,0,18,18,11,0,22,34,0,0,248,255,0,0,64,68,0,0,4,4,2,0,106,11,0,0,248,255,0,0,80,68,0,0,12,12,8,0,146,39,0,0,248,255,0,0,88,68,0,0,12,12,8,0,192,31,0,0,248,255,0,0,96,68,0,0,14,14,9,0,10,17,0,0,248,255,0,0,104,68,0,0,16,16,9,0,68,13,0,0,248,255,0,0,112,68,0,0,18,18,11,0,58,8,0,0,248,255,0,0,128,68,0,0,6,6,2,0,196,20,0,0,248,255,0,0,144,68,0,0,20,20,8,0,46,5,0,0,248,255,0,0,152,68,0,0,20,20,8,0,48,5,0,0,248,255,0,0,160,68,0,0,22,22,9,0,234,27,0,0,248,255,0,0,168,68,0,0,24,24,9,0,104,22,0,0,248,255,0,0,176,68,0,0,26,26,11,0,34,24,0,0,248,255,0,0,192,68,0,0,12,12,4,0,182,4,0,0,248,255,0,0,208,68,0,0,16,16,8,0,228,32,0,0,248,255,0,0,216,68,0,0,16,16,8,0,222,32,0,0,248,255,0,0,224,68,0,0,18,18,9,0,116,12,0,0,248,255,0,0,232,68,0,0,20,20,9,0,176,6,0,0,248,255,0,0,240,68,0,0,22,22,11,0,24,43,0,0,248,255,0,0,0,70,0,0,4,4,2,0,172,18,0,0,248,255,0,0,16,70,0,0,12,12,8,0,44,3,0,0,248,255,0,0,24,70,0,0,12,12,8,0,46,3,0,0,248,255,0,0,32,70,0,0,14,14,9,0,26,26,0,0,248,255,0,0,40,70,0,0,16,16,9,0,126,20,0,0,248,255,0,0,48,70,0,0,18,18,11,0,216,43,0,0,248,255,0,0,64,70,0,0,4,4,2,0,88,49,0,0,248,255,0,0,80,70,0,0,12,12,8,0,172,21,0,0,248,255,0,0,88,70,0,0,12,12,8,0,170,21,0,0,248,255,0,0,96,70,0,0,14,14,9,0,84,42,0,0,248,255,0,0,104,70,0,0,16,16,9,0,152,0,0,0,248,255,0,0,112,70,0,0,18,18,11,0,36,0,0,0,248,255,0,0,128,70,0,0,6,6,2,0,230,21,0,0,248,255,0,0,144,70,0,0,20,20,8,0,212,43,0,0,248,255,0,0,152,70,0,0,20,20,8,0,214,43,0,0,248,255,0,0,160,70,0,0,22,22,9,0,142,14,0,0,248,255,0,0,168,70,0,0,24,24,9,0,182,23,0,0,248,255,0,0,176,70,0,0,26,26,11,0,132,41,0,0,248,255,0,0,192,70,0,0,12,12,8,0,54,30,0,0,248,255,0,0,208,70,0,0,16,16,12,0,122,15,0,0,248,255,0,0,216,70,0,0,16,16,12,0,120,15,0,0,248,255,0,0,224,70,0,0,18,18,13,0,6,22,0,0,248,255,0,0,232,70,0,0,20,20,13,0,28,38,0,0,248,255,0,0,240,70,0,0,22,22,15,0,18,21,0,0,248,255,0,0,0,72,0,0,6,6,6,0,216,39,0,0,248,255,0,0,8,72,0,0,0,0,6,0,90,5,0,0,248,255,0,0,16,72,0,0,12,12,10,0,188,40,0,0,248,255,0,0,24,72,0,0,12,12,10,0,248,39,0,0,248,255,0,0,32,72,0,0,14,14,11,0,62,11,0,0,248,255,0,0,40,72,0,0,16,16,11,0,12,19,0,0,248,255,0,0,48,72,0,0,18,18,13,0,212,18,0,0,248,255,0,0,64,72,0,0,4,4,4,0,26,28,0,0,248,255,0,0,72,72,0,0,0,10,10,0,158,18,0,0,248,255,0,0,80,72,0,0,12,12,9,0,92,24,0,0,248,255,0,0,104,72,0,0,16,16,10,0,250,16,0,0,248,255,0,0,112,72,0,0,20,20,12,0,158,3,0,0,248,255,0,0,128,72,0,0,4,4,4,0,100,17,0,0,248,255,0,0,144,72,0,0,8,8,8,0,200,1,0,0,248,255,0,0,160,72,0,0,8,8,4,0,26,23,0,0,248,255,0,0,168,72,0,0,12,12,9,0,44,19,0,0,248,255,0,0,176,72,0,0,14,14,11,0,196,5,0,0,248,255,0,0,192,72,0,0,4,4,4,0,154,42,0,0,248,255,0,0,208,72,0,0,8,8,8,0,160,20,0,0,248,255,0,0,224,72,0,0,8,8,4,0,130,34,0,0,248,255,0,0,232,72,0,0,12,12,9,0,66,44,0,0,248,255,0,0,240,72,0,0,14,14,11,0,32,22,0,0,248,255,0,0,192,73,0,0,0,0,4,0,166,13,0,0,248,255,0,0,0,74,0,0,4,4,2,0,4,9,0,0,248,255,0,0,16,74,0,0,8,8,6,0,250,43,0,0,248,255,0,0,24,74,0,0,8,8,6,0,246,43,0,0,248,255,0,0,32,74,0,0,10,10,7,0,142,16,0,0,248,255,0,0,40,74,0,0,12,12,7,0,210,10,0,0,248,255,0,0,48,74,0,0,14,14,9,0,58,47,0,0,248,255,0,0,64,74,0,0,4,4,2,0,60,47,0,0,248,255,0,0,72,74,0,0,0,0,2,0,116,17,0,0,248,255,0,0,80,74,0,0,8,8,6,0,240,31,0,0,248,255,0,0,88,74,0,0,8,8,6,0,162,39,0,0,248,255,0,0,96,74,0,0,10,10,7,0,252,25,0,0,248,255,0,0,104,74,0,0,12,12,7,0,190,15,0,0,248,255,0,0,112,74,0,0,14,14,9,0,150,37,0,0,248,255,0,0,128,74,0,0,4,4,2,0,152,37,0,0,248,255,0,0,136,74,0,0,0,0,2,0,238,17,0,0,248,255,0,0,144,74,0,0,12,12,6,0,42,35,0,0,248,255,0,0,152,74,0,0,12,12,6,0,32,40,0,0,248,255,0,0,160,74,0,0,14,14,7,0,162,10,0,0,248,255,0,0,168,74,0,0,16,16,7,0,124,42,0,0,248,255,0,0,176,74,0,0,18,18,9,0,208,40,0,0,248,255,0,0,192,74,0,0,4,4,4,0,220,3,0,0,248,255,0,0,208,74,0,0,18,18,16,0,38,11,0,0,248,255,0,0,216,74,0,0,18,18,16,0,54,19,0,0,248,255,0,0,224,74,0,0,20,20,17,0,178,46,0,0,248,255,0,0,232,74,0,0,22,22,17,0,212,10,0,0,248,255,0,0,240,74,0,0,24,24,19,0,192,27,0,0,248,255,0,0,0,76,0,0,0,0,43,0,122,46,0,0,248,255,0,0,16,76,0,0,0,0,47,0,168,24,0,0,248,255,0,0,24,76,0,0,0,0,47,0,164,24,0,0,248,255,0,0,32,76,0,0,0,0,48,0,178,3,0,0,248,255,0,0,40,76,0,0,0,0,48,0,212,44,0,0,248,255,0,0,48,76,0,0,0,0,50,0,74,34,0,0,248,255,0,0,64,76,0,0,0,0,84,0,216,31,0,0,248,255,0,0,80,76,0,0,0,0,88,0,188,46,0,0,248,255,0,0,88,76,0,0,0,0,88,0,192,46,0,0,248,255,0,0,96,76,0,0,0,0,89,0,110,26,0,0,248,255,0,0,104,76,0,0,0,0,89,0,240,29,0,0,248,255,0,0,112,76,0,0,0,0,91,0,92,34,0,0,248,255,0,0,144,76,0,0,12,12,12,0,100,12,0,0,248,255,0,0,152,76,0,0,12,12,8,0,64,40,0,0,248,255,0,0,168,76,0,0,16,16,13,0,134,32,0,0,248,255,0,0,176,76,0,0,18,18,15,0,138,39,0,0,248,255,0,0,208,76,0,0,12,12,12,0,178,49,0,0,248,255,0,0,216,76,0,0,12,12,8,0,60,26,0,0,248,255,0,0,232,76,0,0,16,16,13,0,68,41,0,0,248,255,0,0,240,76,0,0,18,18,15,0,202,26,0,0,248,255,0,0,80,78,0,0,16,16,5,0,218,15,0,0,248,255,0,0,88,78,0,0,12,12,6,0,88,1,0,0,248,255,0,0,96,78,0,0,4,6,2,0,130,24,0,0,248,255,0,0,104,78,0,0,4,6,2,0,128,2,0,0,248,255,0,0,144,78,0,0,16,16,4,0,74,47,0,0,248,255,0,0,168,78,0,0,18,18,5,0,110,4,0,0,248,255,0,0,176,78,0,0,22,22,7,0,130,13,0,0,248,255,0,0,208,78,0,0,8,8,4,0,204,5,0,0,248,255,0,0,232,78,0,0,10,10,5,0,162,11,0,0,248,255,0,0,240,78,0,0,14,14,7,0,212,31,0,0,248,255,0,0,192,80,0,0,6,4,4,0,108,42,0,0,248,255,0,0,200,80,0,0,12,12,6,0,50,50,0,0,248,255,0,0,208,80,0,0,12,12,10,0,62,35,0,0,248,255,0,0,216,80,0,0,12,12,10,0,64,35,0,0,248,255,0,0,224,80,0,0,14,14,11,0,228,30,0,0,248,255,0,0,232,80,0,0,16,16,11,0,108,1,0,0,248,255,0,0,240,80,0,0,18,18,13,0,8,38,0,0,248,255,0,0,192,81,0,0,4,4,4,0,48,42,0,0,248,255,0,0,200,81,0,0,14,14,6,0,98,3,0,0,248,255,0,0,208,81,0,0,12,12,10,0,192,38,0,0,248,255,0,0,216,81,0,0,12,12,10,0,190,38,0,0,248,255,0,0,224,81,0,0,14,14,11,0,66,9,0,0,248,255,0,0,232,81,0,0,16,16,11,0,38,5,0,0,248,255,0,0,240,81,0,0,18,18,13,0,88,41,0,0,248,255,0,0,192,82,0,0,4,4,4,0,184,2,0,0,248,255,0,0,200,82,0,0,12,12,6,0,42,40,0,0,248,255,0,0,208,82,0,0,12,12,10,0,254,11,0,0,248,255,0,0,216,82,0,0,12,12,10,0,250,11,0,0,248,255,0,0,224,82,0,0,14,14,11,0,102,49,0,0,248,255,0,0,232,82,0,0,16,16,11,0,204,41,0,0,248,255,0,0,240,82,0,0,18,18,13,0,132,31,0,0,248,255,0,0,192,83,0,0,4,4,4,0,236,46,0,0,248,255,0,0,200,83,0,0,12,12,6,0,54,12,0,0,248,255,0,0,208,83,0,0,12,12,10,0,38,34,0,0,248,255,0,0,216,83,0,0,12,12,10,0,30,48,0,0,248,255,0,0,224,83,0,0,14,14,11,0,128,4,0,0,248,255,0,0,232,83,0,0,16,16,11,0,36,14,0,0,248,255,0,0,240,83,0,0,18,18,13,0,248,27,0,0,248,255,0,0,192,84,0,0,4,4,4,0,6,14,0,0,248,255,0,0,200,84,0,0,12,12,6,0,46,21,0,0,248,255,0,0,208,84,0,0,12,12,10,0,186,48,0,0,248,255,0,0,216,84,0,0,12,12,10,0,188,48,0,0,248,255,0,0,224,84,0,0,14,14,11,0,178,26,0,0,248,255,0,0,232,84,0,0,16,16,11,0,186,22,0,0,248,255,0,0,240,84,0,0,18,18,13,0,138,6,0,0,248,255,0,0,192,85,0,0,4,4,4,0,8,18,0,0,248,255,0,0,200,85,0,0,12,12,6,0,202,4,0,0,248,255,0,0,208,85,0,0,12,12,10,0,80,40,0,0,248,255,0,0,216,85,0,0,12,12,10,0,82,40,0,0,248,255,0,0,224,85,0,0,14,14,11,0,218,10,0,0,248,255,0,0,232,85,0,0,16,16,11,0,202,6,0,0,248,255,0,0,240,85,0,0,18,18,13,0,240,0,0,0,248,255,0,0,192,86,0,0,4,4,4,0,188,12,0,0,248,255,0,0,200,86,0,0,12,12,6,0,86,29,0,0,248,255,0,0,208,86,0,0,12,12,10,0,176,0,0,0,248,255,0,0,216,86,0,0,12,12,10,0,180,0,0,0,248,255,0,0,224,86,0,0,14,14,11,0,224,23,0,0,248,255,0,0,232,86,0,0,16,16,11,0,150,27,0,0,248,255,0,0,240,86,0,0,18,18,13,0,16,24,0,0,248,255,0,0,192,87,0,0,4,4,4,0,200,35,0,0,248,255,0,0,200,87,0,0,12,12,6,0,44,33,0,0,248,255,0,0,208,87,0,0,12,12,10,0,96,11,0,0,248,255,0,0,216,87,0,0,12,12,10,0,94,11,0,0,248,255,0,0,224,87,0,0,14,14,11,0,32,39,0,0,248,255,0,0,232,87,0,0,16,16,11,0,136,31,0,0,248,255,0,0,240,87,0,0,18,18,13,0,52,40,0,0,248,255,0,0,192,88,0,0,4,4,4,0,36,48,0,0,248,255,0,0,200,88,0,0,12,12,6,0,152,30,0,0,248,255,0,0,208,88,0,0,12,12,10,0,84,2,0,0,248,255,0,0,216,88,0,0,12,12,10,0,80,2,0,0,248,255,0,0,224,88,0,0,14,14,11,0,128,23,0,0,248,255,0,0,232,88,0,0,16,16,11,0,84,32,0,0,248,255,0,0,240,88,0,0,18,18,13,0,14,23,0,0,248,255,0,0,192,89,0,0,4,4,4,0,86,32,0,0,248,255,0,0,200,89,0,0,12,12,6,0,182,24,0,0,248,255,0,0,208,89,0,0,12,12,10,0,226,39,0,0,248,255,0,0,216,89,0,0,12,12,10,0,224,39,0,0,248,255,0,0,224,89,0,0,14,14,11,0,58,17,0,0,248,255,0,0,232,89,0,0,16,16,11,0,140,26,0,0,248,255,0,0,240,89,0,0,18,18,13,0,30,8,0,0,248,255,0,0,192,90,0,0,4,4,4,0,74,17,0,0,248,255,0,0,200,90,0,0,12,12,6,0,144,3,0,0,248,255,0,0,208,90,0,0,12,12,10,0,246,38,0,0,248,255,0,0,216,90,0,0,12,12,10,0,248,38,0,0,248,255,0,0,224,90,0,0,14,14,11,0,110,9,0,0,248,255,0,0,232,90,0,0,16,16,11,0,128,1,0,0,248,255,0,0,240,90,0,0,18,18,13,0,22,35,0,0,248,255,0,0,192,91,0,0,4,4,4,0,0,15,0,0,248,255,0,0,200,91,0,0,12,12,6,0,160,24,0,0,248,255,0,0,208,91,0,0,12,12,10,0,148,9,0,0,248,255,0,0,216,91,0,0,12,12,10,0,142,9,0,0,248,255,0,0,224,91,0,0,14,14,11,0,250,29,0,0,248,255,0,0,232,91,0,0,16,16,11,0,218,22,0,0,248,255,0,0,240,91,0,0,18,18,13,0,24,28,0,0,248,255,0,0,192,92,0,0,4,4,4,0,114,2,0,0,248,255,0,0,200,92,0,0,12,12,6,0,148,11,0,0,248,255,0,0,208,92,0,0,12,12,10,0,198,39,0,0,248,255,0,0,216,92,0,0,12,12,10,0,196,39,0,0,248,255,0,0,224,92,0,0,14,14,11,0,64,17,0,0,248,255,0,0,232,92,0,0,16,16,11,0,122,13,0,0,248,255,0,0,240,92,0,0,18,18,13,0,84,31,0,0,248,255,0,0,192,93,0,0,4,4,4,0,160,6,0,0,248,255,0,0,200,93,0,0,12,12,6,0,214,32,0,0,248,255,0,0,208,93,0,0,12,12,10,0,16,18,0,0,248,255,0,0,216,93,0,0,12,12,10,0,68,3,0,0,248,255,0,0,224,93,0,0,14,14,11,0,90,40,0,0,248,255,0,0,232,93,0,0,16,16,11,0,148,34,0,0,248,255,0,0,240,93,0,0,18,18,13,0,210,16,0,0,248,255,0,0,192,94,0,0,4,4,4,0,210,38,0,0,248,255,0,0,200,94,0,0,12,12,6,0,36,45,0,0,248,255,0,0,208,94,0,0,12,12,10,0,94,17,0,0,248,255,0,0,216,94,0,0,12,12,10,0,92,17,0,0,248,255,0,0,224,94,0,0,14,14,11,0,206,37,0,0,248,255,0,0,232,94,0,0,16,16,11,0,230,46,0,0,248,255,0,0,240,94,0,0,18,18,13,0,54,47,0,0,248,255,0,0,192,95,0,0,4,4,4,0,26,31,0,0,248,255,0,0,200,95,0,0,12,12,6,0,230,32,0,0,248,255,0,0,208,95,0,0,12,12,10,0,104,21,0,0,248,255,0,0,216,95,0,0,12,12,10,0,102,21,0,0,248,255,0,0,224,95,0,0,14,14,11,0,96,50,0,0,248,255,0,0,232,95,0,0,16,16,11,0,248,7,0,0,248,255,0,0,240,95,0,0,18,18,13,0,178,1,0,0,248,255,0,0,8,143,0,0,18,18,16,0,14,35,0,0,248,255,0,0,72,143,0,0,0,0,13,0,220,9,0,0,248,255,0,0,136,143,0,0,0,0,13,0,50,18,0,0,248,255,0,0,8,159,0,0,18,18,12,0,252,23,0,0,248,255,0,0,8,191,0,0,12,12,9,0,240,35,0,0,248,255,0,0,8,207,0,0,18,18,16,0,142,41,0,0,248,255,0,0,8,223,0,0,18,18,12,0,176,27,0,0,248,255,0,0,208,224,0,0,12,12,9,0,202,23,0,0,248,255,0,0,216,224,0,0,12,12,9,0,200,23,0,0,248,255,0,0,224,224,0,0,14,14,10,0,46,44,0,0,248,255,0,0,232,224,0,0,16,16,10,0,230,36,0,0,248,255,0,0,240,224,0,0,18,18,12,0,88,22,0,0,248,255,0,0,208,225,0,0,12,12,10,0,20,50,0,0,248,255,0,0,216,225,0,0,12,12,10,0,22,50,0,0,248,255,0,0,224,225,0,0,14,14,11,0,254,27,0,0,248,255,0,0,232,225,0,0,16,16,11,0,182,20,0,0,248,255,0,0,240,225,0,0,18,18,13,0,230,1,0,0,248,255,0,0,208,226,0,0,12,12,9,0,150,17,0,0,248,255,0,0,216,226,0,0,12,12,9,0,148,17,0,0,248,255,0,0,224,226,0,0,14,14,10,0,204,46,0,0,248,255,0,0,232,226,0,0,16,16,10,0,238,3,0,0,248,255,0,0,240,226,0,0,18,18,12,0,48,41,0,0,248,255,0,0,208,227,0,0,12,12,9,0,230,5,0,0,248,255,0,0,216,227,0,0,12,12,9,0,30,32,0,0,248,255,0,0,224,227,0,0,14,14,10,0,178,33,0,0,248,255,0,0,232,227,0,0,16,16,10,0,176,44,0,0,248,255,0,0,240,227,0,0,18,18,12,0,44,48,0,0,248,255,0,0,208,228,0,0,12,12,9,0,94,20,0,0,248,255,0,0,216,228,0,0,12,12,9,0,92,20,0,0,248,255,0,0,224,228,0,0,14,14,10,0,226,40,0,0,248,255,0,0,232,228,0,0,16,16,10,0,204,49,0,0,248,255,0,0,240,228,0,0,18,18,12,0,58,18,0,0,248,255,0,0,208,229,0,0,12,12,9,0,2,33,0,0,248,255,0,0,216,229,0,0,12,12,9,0,4,33,0,0,248,255,0,0,224,229,0,0,14,14,10,0,174,12,0,0,248,255,0,0,232,229,0,0,16,16,10,0,136,16,0,0,248,255,0,0,240,229,0,0,18,18,12,0,44,7,0,0,248,255,0,0,208,230,0,0,12,12,11,0,74,22,0,0,248,255,0,0,216,230,0,0,12,12,11,0,70,22,0,0,248,255,0,0,224,230,0,0,14,14,12,0,184,49,0,0,248,255,0,0,232,230,0,0,16,16,12,0,44,5,0,0,248,255,0,0,240,230,0,0,18,18,14,0,176,32,0,0,248,255,0,0,208,231,0,0,12,12,11,0,194,47,0,0,248,255,0,0,216,231,0,0,12,12,11,0,188,47,0,0,248,255,0,0,224,231,0,0,14,14,12,0,104,27,0,0,248,255,0,0,232,231,0,0,16,16,12,0,124,34,0,0,248,255,0,0,240,231,0,0,18,18,14,0,236,30,0,0,248,255,0,0,192,232,0,0,0,0,6,0,126,0,0,0,248,255,0,0,208,232,0,0,0,0,17,0,210,43,0,0,248,255,0,0,232,232,0,0,0,0,18,0,78,49,0,0,248,255,0,0,240,232,0,0,0,0,20,0,162,20,0,0,248,255,0,0,192,233,0,0,0,0,8,0,252,32,0,0,248,255,0,0,208,233,0,0,0,0,19,0,160,38,0,0,248,255,0,0,232,233,0,0,0,0,20,0,192,34,0,0,248,255,0,0,240,233,0,0,0,0,22,0,70,43,0,0,248,255,0,0,192,234,0,0,0,0,12,0,164,13,0,0,248,255,0,0,208,234,0,0,0,0,24,0,26,21,0,0,248,255,0,0,232,234,0,0,0,0,25,0,188,11,0,0,248,255,0,0,240,234,0,0,0,0,27,0,12,50,0,0,248,255,0,0,192,235,0,0,0,0,8,0,134,3,0,0,248,255,0,0,208,235,0,0,0,0,19,0,108,9,0,0,248,255,0,0,232,235,0,0,0,0,20,0,118,1,0,0,248,255,0,0,240,235,0,0,0,0,22,0,38,3,0,0,248,255,0,0,192,236,0,0,0,0,12,0,8,9,0,0,248,255,0,0,208,236,0,0,0,0,24,0,18,3,0,0,248,255,0,0,232,236,0,0,0,0,25,0,40,7,0,0,248,255,0,0,240,236,0,0,0,0,27,0,182,37,0,0,248,255,0,0,192,237,0,0,0,0,18,0,12,22,0,0,248,255,0,0,208,237,0,0,0,0,32,0,226,14,0,0,248,255,0,0,232,237,0,0,0,0,33,0,86,20,0,0,248,255,0,0,240,237,0,0,0,0,35,0,40,45,0,0,248,255,0,0,192,238,0,0,0,0,12,0,52,29,0,0,248,255,0,0,208,238,0,0,0,0,24,0,136,12,0,0,248,255,0,0,232,238,0,0,0,0,25,0,118,3,0,0,248,255,0,0,240,238,0,0,0,0,27,0,228,33,0,0,248,255,0,0,192,239,0,0,0,0,10,0,122,36,0,0,248,255,0,0,208,239,0,0,0,0,21,0,226,43,0,0,248,255,0,0,232,239,0,0,0,0,22,0,78,38,0,0,248,255,0,0,240,239,0,0,0,0,24,0,8,23,0,0,255,255,0,0,31,0,0,0,16,16,8,0,240,13,0,0,255,255,0,0,39,0,0,0,18,18,9,0,82,12,0,0,255,255,0,0,56,0,0,0,20,20,8,0,84,12,0,0,255,255,0,0,57,0,0,0,24,24,8,0,146,6,0,0,255,255,0,0,60,0,0,0,20,16,12,0,168,29,0,0,255,255,0,0,120,0,0,0,20,20,8,0,174,29,0,0,255,255,0,0,121,0,0,0,24,24,8,0,148,6,0,0,255,255,0,0,124,0,0,0,20,16,12,0,236,49,0,0,255,255,0,0,184,0,0,0,32,32,8,0,234,49,0,0,255,255,0,0,185,0,0,0,36,36,8,0,110,40,0,0,255,255,0,0,248,0,0,0,0,0,22,0,104,40,0,0,255,255,0,0,249,0,0,0,0,0,22,0,26,12,0,0,255,255,0,0,250,0,0,0,0,0,23,0,58,13,0,0,255,255,0,0,251,0,0,0,0,0,23,0,198,15,0,0,255,255,0,0,31,2,0,0,16,16,8,0,84,16,0,0,255,255,0,0,39,2,0,0,18,18,9,0,196,11,0,0,255,255,0,0,56,2,0,0,20,20,8,0,192,11,0,0,255,255,0,0,57,2,0,0,24,24,8,0,224,1,0,0,255,255,0,0,60,2,0,0,20,16,12,0,230,7,0,0,255,255,0,0,120,2,0,0,20,20,8,0,226,7,0,0,255,255,0,0,121,2,0,0,24,24,8,0,222,1,0,0,255,255,0,0,124,2,0,0,20,16,12,0,14,48,0,0,255,255,0,0,184,2,0,0,32,32,8,0,8,48,0,0,255,255,0,0,185,2,0,0,36,36,8,0,130,14,0,0,255,255,0,0,248,2,0,0,0,0,22,0,168,2,0,0,255,255,0,0,249,2,0,0,0,0,22,0,26,3,0,0,255,255,0,0,250,2,0,0,0,0,23,0,54,27,0,0,255,255,0,0,251,2,0,0,0,0,23,0,8,25,0,0,255,255,0,0,31,4,0,0,16,16,8,0,222,49,0,0,255,255,0,0,39,4,0,0,18,18,9,0,124,25,0,0,255,255,0,0,56,4,0,0,20,20,8,0,128,25,0,0,255,255,0,0,57,4,0,0,24,24,8,0,18,41,0,0,255,255,0,0,120,4,0,0,20,20,8,0,14,41,0,0,255,255,0,0,121,4,0,0,24,24,8,0,60,31,0,0,255,255,0,0,184,4,0,0,32,32,8,0,58,34,0,0,255,255,0,0,185,4,0,0,36,36,8,0,2,36,0,0,255,255,0,0,248,4,0,0,0,0,22,0,10,36,0,0,255,255,0,0,249,4,0,0,0,0,22,0,170,36,0,0,255,255,0,0,250,4,0,0,0,0,23,0,184,45,0,0,255,255,0,0,251,4,0,0,0,0,23,0,170,30,0,0,255,255,0,0,31,6,0,0,16,16,8,0,202,21,0,0,255,255,0,0,39,6,0,0,18,18,9,0,104,31,0,0,255,255,0,0,56,6,0,0,20,20,8,0,108,31,0,0,255,255,0,0,57,6,0,0,24,24,8,0,238,47,0,0,255,255,0,0,120,6,0,0,20,20,8,0,232,47,0,0,255,255,0,0,121,6,0,0,24,24,8,0,20,7,0,0,255,255,0,0,184,6,0,0,32,32,8,0,24,7,0,0,255,255,0,0,185,6,0,0,36,36,8,0,182,0,0,0,255,255,0,0,248,6,0,0,0,0,64,0,184,0,0,0,255,255,0,0,249,6,0,0,0,0,64,0,182,7,0,0,255,255,0,0,250,6,0,0,0,0,65,0,154,3,0,0,255,255,0,0,251,6,0,0,0,0,67,0,102,23,0,0,255,255,0,0,31,8,0,0,12,12,8,0,50,27,0,0,255,255,0,0,39,8,0,0,14,14,9,0,170,46,0,0,255,255,0,0,56,8,0,0,16,16,8,0,168,46,0,0,255,255,0,0,57,8,0,0,20,20,8,0,94,41,0,0,255,255,0,0,58,8,0,0,16,16,9,0,156,46,0,0,255,255,0,0,59,8,0,0,18,18,11,0,184,19,0,0,255,255,0,0,95,8,0,0,16,16,8,0,154,10,0,0,255,255,0,0,103,8,0,0,18,18,9,0,108,20,0,0,255,255,0,0,120,8,0,0,20,20,8,0,106,20,0,0,255,255,0,0,121,8,0,0,24,24,8,0,126,9,0,0,255,255,0,0,159,8,0,0,16,16,8,0,98,13,0,0,255,255,0,0,167,8,0,0,18,18,9,0,142,7,0,0,255,255,0,0,184,8,0,0,20,20,8,0,146,7,0,0,255,255,0,0,185,8,0,0,24,24,8,0,180,25,0,0,255,255,0,0,223,8,0,0,16,16,8,0,2,20,0,0,255,255,0,0,231,8,0,0,18,18,9,0,240,17,0,0,255,255,0,0,248,8,0,0,20,20,8,0,66,2,0,0,255,255,0,0,249,8,0,0,24,24,8,0,242,39,0,0,255,255,0,0,31,10,0,0,16,16,8,0,112,43,0,0,255,255,0,0,39,10,0,0,18,18,9,0,238,39,0,0,255,255,0,0,56,10,0,0,20,20,8,0,236,39,0,0,255,255,0,0,57,10,0,0,24,24,8,0,126,29,0,0,255,255,0,0,60,10,0,0,20,16,12,0,190,1,0,0,255,255,0,0,120,10,0,0,20,20,8,0,194,1,0,0,255,255,0,0,121,10,0,0,24,24,8,0,132,29,0,0,255,255,0,0,124,10,0,0,20,16,12,0,26,36,0,0,255,255,0,0,184,10,0,0,32,32,8,0,30,36,0,0,255,255,0,0,185,10,0,0,36,36,8,0,52,15,0,0,255,255,0,0,223,10,0,0,0,0,16,0,76,24,0,0,255,255,0,0,231,10,0,0,0,0,17,0,48,16,0,0,255,255,0,0,248,10,0,0,0,0,16,0,44,16,0,0,255,255,0,0,249,10,0,0,0,0,16,0,230,34,0,0,255,255,0,0,31,12,0,0,12,12,6,0,60,50,0,0,255,255,0,0,39,12,0,0,14,14,7,0,124,41,0,0,255,255,0,0,56,12,0,0,16,16,6,0,26,49,0,0,255,255,0,0,57,12,0,0,20,20,6,0,96,16,0,0,255,255,0,0,58,12,0,0,0,0,7,0,144,25,0,0,255,255,0,0,59,12,0,0,0,0,9,0,142,48,0,0,255,255,0,0,120,12,0,0,16,16,6,0,148,48,0,0,255,255,0,0,121,12,0,0,20,20,6,0,164,19,0,0,255,255,0,0,122,12,0,0,0,0,7,0,130,10,0,0,255,255,0,0,123,12,0,0,0,0,9,0,168,26,0,0,255,255,0,0,184,12,0,0,24,24,6,0,172,26,0,0,255,255,0,0,185,12,0,0,28,28,6,0,58,1,0,0,255,255,0,0,186,12,0,0,0,0,7,0,20,48,0,0,255,255,0,0,187,12,0,0,0,0,9,0,190,18,0,0,255,255,0,0,248,12,0,0,0,0,16,0,192,18,0,0,255,255,0,0,249,12,0,0,0,0,16,0,138,28,0,0,255,255,0,0,252,12,0,0,0,0,12,0,214,35,0,0,255,255,0,0,31,14,0,0,0,18,9,0,38,17,0,0,255,255,0,0,39,14,0,0,0,20,10,0,62,0,0,0,255,255,0,0,56,14,0,0,0,26,9,0,68,0,0,0,255,255,0,0,57,14,0,0,0,30,9,0,86,17,0,0,255,255,0,0,120,14,0,0,0,26,9,0,88,17,0,0,255,255,0,0,121,14,0,0,0,30,9,0,66,27,0,0,255,255,0,0,184,14,0,0,0,32,9,0,68,27,0,0,255,255,0,0,185,14,0,0,0,36,9,0,108,28,0,0,255,255,0,0,248,14,0,0,0,0,16,0,104,28,0,0,255,255,0,0,249,14,0,0,0,0,16,0,206,15,0,0,255,255,0,0,252,14,0,0,0,0,12,0,228,22,0,0,255,255,0,0,223,17,0,0,16,16,8,0,160,15,0,0,255,255,0,0,231,17,0,0,18,18,9,0,6,21,0,0,255,255,0,0,248,17,0,0,20,20,8,0,12,21,0,0,255,255,0,0,249,17,0,0,24,24,8,0,130,31,0,0,255,255,0,0,250,17,0,0,20,20,9,0,124,22,0,0,255,255,0,0,251,17,0,0,22,22,11,0,76,12,0,0,255,255,0,0,252,17,0,0,16,16,6,0,162,28,0,0,255,255,0,0,223,19,0,0,20,20,10,0,254,35,0,0,255,255,0,0,231,19,0,0,22,22,11,0,56,49,0,0,255,255,0,0,248,19,0,0,24,24,10,0,8,42,0,0,255,255,0,0,249,19,0,0,28,28,10,0,26,37,0,0,255,255,0,0,250,19,0,0,24,24,11,0,230,40,0,0,255,255,0,0,251,19,0,0,26,26,13,0,104,38,0,0,255,255,0,0,252,19,0,0,20,20,8,0,194,39,0,0,255,255,0,0,223,30,0,0,12,12,8,0,66,30,0,0,255,255,0,0,231,30,0,0,14,14,9,0,254,13,0,0,255,255,0,0,248,30,0,0,16,16,8,0,0,14,0,0,255,255,0,0,249,30,0,0,20,20,8,0,190,17,0,0,255,255,0,0,250,30,0,0,16,16,9,0,116,10,0,0,255,255,0,0,251,30,0,0,18,18,11,0,150,16,0,0,255,255,0,0,252,30,0,0,12,12,6,0,172,37,0,0,255,255,0,0,31,31,0,0,12,12,9,0,74,27,0,0,255,255,0,0,39,31,0,0,14,14,10,0,162,19,0,0,255,255,0,0,56,31,0,0,16,16,9,0,168,19,0,0,255,255,0,0,57,31,0,0,20,20,9,0,154,27,0,0,255,255,0,0,58,31,0,0,16,16,10,0,50,31,0,0,255,255,0,0,59,31,0,0,18,18,12,0,94,47,0,0,255,255,0,0,60,31,0,0,12,12,7,0,80,41,0,0,255,255,0,0,248,33,0,0,28,28,8,0,82,41,0,0,255,255,0,0,249,33,0,0,32,32,8,0,212,34,0,0,255,255,0,0,250,33,0,0,28,28,9,0,188,38,0,0,255,255,0,0,251,33,0,0,30,30,11,0,6,15,0,0,255,255,0,0,252,33,0,0,24,24,8,0,150,13,0,0,255,255,0,0,248,35,0,0,32,32,10,0,148,13,0,0,255,255,0,0,249,35,0,0,36,36,10,0,170,2,0,0,255,255,0,0,250,35,0,0,32,32,11,0,118,47,0,0,255,255,0,0,251,35,0,0,34,34,13,0,80,10,0,0,255,255,0,0,252,35,0,0,28,28,10,0,126,32,0,0,255,255,0,0,248,49,0,0,20,20,8,0,118,32,0,0,255,255,0,0,249,49,0,0,24,24,8,0,220,34,0,0,255,255,0,0,250,49,0,0,20,20,9,0,114,42,0,0,255,255,0,0,251,49,0,0,22,22,11,0,94,18,0,0,255,255,0,0,252,49,0,0,16,16,6,0,178,25,0,0,255,255,0,0,248,51,0,0,24,24,10,0,182,25,0,0,255,255,0,0,249,51,0,0,28,28,10,0,34,32,0,0,255,255,0,0,250,51,0,0,24,24,11,0,212,26,0,0,255,255,0,0,251,51,0,0,26,26,13,0,98,7,0,0,255,255,0,0,252,51,0,0,20,20,8,0,240,10,0,0,255,255,0,0,31,64,0,0,12,12,8,0,246,6,0,0,255,255,0,0,39,64,0,0,14,14,9,0,246,22,0,0,255,255,0,0,56,64,0,0,16,16,8,0,238,22,0,0,255,255,0,0,57,64,0,0,20,20,8,0,252,11,0,0,255,255,0,0,120,64,0,0,16,16,8,0,2,12,0,0,255,255,0,0,121,64,0,0,20,20,8,0,68,35,0,0,255,255,0,0,184,64,0,0,24,24,8,0,72,35,0,0,255,255,0,0,185,64,0,0,28,28,8,0,184,36,0,0,255,255,0,0,248,64,0,0,16,16,12,0,174,36,0,0,255,255,0,0,249,64,0,0,20,20,12,0,120,38,0,0,255,255,0,0,31,66,0,0,12,8,8,0,180,45,0,0,255,255,0,0,39,66,0,0,14,10,9,0,202,27,0,0,255,255,0,0,56,66,0,0,16,12,8,0,194,27,0,0,255,255,0,0,57,66,0,0,20,14,8,0,158,28,0,0,255,255,0,0,120,66,0,0,16,12,8,0,166,28,0,0,255,255,0,0,121,66,0,0,20,14,8,0,224,25,0,0,255,255,0,0,184,66,0,0,24,16,8,0,170,49,0,0,255,255,0,0,185,66,0,0,28,20,8,0,26,5,0,0,255,255,0,0,248,66,0,0,0,16,8,0,118,28,0,0,255,255,0,0,249,66,0,0,0,20,8,0,138,4,0,0,255,255,0,0,31,68,0,0,12,12,8,0,156,45,0,0,255,255,0,0,39,68,0,0,14,14,9,0,46,17,0,0,255,255,0,0,56,68,0,0,16,16,8,0,50,17,0,0,255,255,0,0,57,68,0,0,20,20,8,0,110,11,0,0,255,255,0,0,120,68,0,0,16,16,8,0,104,11,0,0,255,255,0,0,121,68,0,0,20,20,8,0,188,20,0,0,255,255,0,0,184,68,0,0,24,24,8,0,192,20,0,0,255,255,0,0,185,68,0,0,28,28,8,0,184,4,0,0,255,255,0,0,248,68,0,0,20,20,8,0,180,4,0,0,255,255,0,0,249,68,0,0,24,24,8,0,148,24,0,0,255,255,0,0,250,68,0,0,20,20,9,0,178,31,0,0,255,255,0,0,251,68,0,0,22,22,11,0,36,24,0,0,255,255,0,0,252,68,0,0,16,16,6,0,112,37,0,0,255,255,0,0,31,70,0,0,12,12,8,0,134,46,0,0,255,255,0,0,39,70,0,0,14,14,9,0,168,18,0,0,255,255,0,0,56,70,0,0,16,16,8,0,170,18,0,0,255,255,0,0,57,70,0,0,20,20,8,0,90,49,0,0,255,255,0,0,120,70,0,0,16,16,8,0,86,49,0,0,255,255,0,0,121,70,0,0,20,20,8,0,226,21,0,0,255,255,0,0,184,70,0,0,24,24,8,0,228,21,0,0,255,255,0,0,185,70,0,0,28,28,8,0,50,30,0,0,255,255,0,0,248,70,0,0,20,20,12,0,52,30,0,0,255,255,0,0,249,70,0,0,24,24,12,0,126,16,0,0,255,255,0,0,250,70,0,0,20,20,13,0,218,23,0,0,255,255,0,0,251,70,0,0,22,22,15,0,134,41,0,0,255,255,0,0,252,70,0,0,16,16,10,0,192,9,0,0,255,255,0,0,15,72,0,0,0,0,6,0,74,43,0,0,255,255,0,0,31,72,0,0,12,12,10,0,248,46,0,0,255,255,0,0,39,72,0,0,14,14,11,0,86,5,0,0,255,255,0,0,56,72,0,0,16,16,10,0,88,5,0,0,255,255,0,0,57,72,0,0,20,20,10,0,156,18,0,0,255,255,0,0,120,72,0,0,16,16,9,0,160,18,0,0,255,255,0,0,121,72,0,0,20,20,9,0,176,37,0,0,255,255,0,0,122,72,0,0,16,16,10,0,212,41,0,0,255,255,0,0,123,72,0,0,20,20,12,0,188,49,0,0,255,255,0,0,184,72,0,0,12,12,8,0,98,17,0,0,255,255,0,0,185,72,0,0,16,16,8,0,160,42,0,0,255,255,0,0,248,72,0,0,12,12,8,0,156,42,0,0,255,255,0,0,249,72,0,0,16,16,8,0,104,25,0,0,255,255,0,0,31,74,0,0,8,8,6,0,164,30,0,0,255,255,0,0,39,74,0,0,10,10,7,0,0,9,0,0,255,255,0,0,56,74,0,0,12,12,6,0,10,9,0,0,255,255,0,0,57,74,0,0,16,16,6,0,156,49,0,0,255,255,0,0,58,74,0,0,0,0,7,0,254,6,0,0,255,255,0,0,59,74,0,0,0,0,9,0,168,13,0,0,255,255,0,0,60,74,0,0,0,0,6,0,230,4,0,0,255,255,0,0,120,74,0,0,12,12,6,0,114,17,0,0,255,255,0,0,121,74,0,0,16,16,6,0,108,38,0,0,255,255,0,0,122,74,0,0,0,0,7,0,152,36,0,0,255,255,0,0,123,74,0,0,0,0,9,0,56,47,0,0,255,255,0,0,124,74,0,0,0,0,6,0,70,2,0,0,255,255,0,0,184,74,0,0,16,16,6,0,236,17,0,0,255,255,0,0,185,74,0,0,20,20,6,0,218,33,0,0,255,255,0,0,186,74,0,0,0,0,7,0,12,25,0,0,255,255,0,0,187,74,0,0,0,0,9,0,148,37,0,0,255,255,0,0,188,74,0,0,0,0,6,0,244,46,0,0,255,255,0,0,223,74,0,0,18,18,16,0,240,37,0,0,255,255,0,0,231,74,0,0,20,20,17,0,222,3,0,0,255,255,0,0,248,74,0,0,22,22,16,0,218,3,0,0,255,255,0,0,249,74,0,0,26,26,16,0,10,29,0,0,255,255,0,0,252,74,0,0,4,4,4,0,118,46,0,0,255,255,0,0,56,76,0,0,0,0,47,0,120,46,0,0,255,255,0,0,57,76,0,0,0,0,47,0,158,2,0,0,255,255,0,0,58,76,0,0,0,0,48,0,68,12,0,0,255,255,0,0,59,76,0,0,0,0,50,0,190,27,0,0,255,255,0,0,60,76,0,0,0,0,47,0,214,31,0,0,255,255,0,0,120,76,0,0,0,0,88,0,218,31,0,0,255,255,0,0,121,76,0,0,0,0,88,0,252,1,0,0,255,255,0,0,122,76,0,0,0,0,89,0,222,46,0,0,255,255,0,0,123,76,0,0,0,0,91,0,72,34,0,0,255,255,0,0,124,76,0,0,0,0,88,0,88,34,0,0,255,255,0,0,184,76,0,0,16,16,12,0,142,1,0,0,255,255,0,0,185,76,0,0,20,20,12,0,10,38,0,0,255,255,0,0,186,76,0,0,16,16,9,0,188,43,0,0,255,255,0,0,187,76,0,0,18,18,11,0,140,39,0,0,255,255,0,0,248,76,0,0,16,16,12,0,162,31,0,0,255,255,0,0,249,76,0,0,20,20,12,0,156,29,0,0,255,255,0,0,250,76,0,0,16,16,9,0,8,35,0,0,255,255,0,0,251,76,0,0,18,18,11,0,142,19,0,0,255,255,0,0,87,78,0,0,16,16,5,0,86,42,0,0,255,255,0,0,95,78,0,0,12,12,6,0,152,1,0,0,255,255,0,0,112,78,0,0,0,0,0,0,100,16,0,0,255,255,0,0,113,78,0,0,4,4,2,0,236,10,0,0,255,255,0,0,114,78,0,0,4,4,8,0,132,21,0,0,255,255,0,0,115,78,0,0,20,24,20,0,150,35,0,0,255,255,0,0,116,78,0,0,0,16,10,0,34,43,0,0,255,255,0,0,117,78,0,0,16,16,10,0,186,16,0,0,255,255,0,0,118,78,0,0,4,4,4,0,178,45,0,0,255,255,0,0,119,78,0,0,20,20,14,0,126,47,0,0,255,255,0,0,122,78,0,0,0,12,6,0,190,25,0,0,255,255,0,0,123,78,0,0,0,10,12,0,134,2,0,0,255,255,0,0,184,78,0,0,18,18,4,0,130,2,0,0,255,255,0,0,185,78,0,0,20,20,4,0,12,43,0,0,255,255,0,0,186,78,0,0,18,18,5,0,168,35,0,0,255,255,0,0,187,78,0,0,22,22,7,0,138,13,0,0,255,255,0,0,248,78,0,0,10,10,4,0,58,26,0,0,255,255,0,0,249,78,0,0,12,12,4,0,200,24,0,0,255,255,0,0,250,78,0,0,10,10,5,0,182,15,0,0,255,255,0,0,251,78,0,0,14,14,7,0,56,24,0,0,255,255,0,0,223,80,0,0,12,12,10,0,66,31,0,0,255,255,0,0,231,80,0,0,14,14,11,0,44,50,0,0,255,255,0,0,248,80,0,0,16,16,10,0,48,50,0,0,255,255,0,0,249,80,0,0,20,20,10,0,208,13,0,0,255,255,0,0,250,80,0,0,0,0,6,0,122,50,0,0,255,255,0,0,251,80,0,0,0,0,8,0,184,16,0,0,255,255,0,0,252,80,0,0,0,0,4,0,24,31,0,0,255,255,0,0,223,81,0,0,12,12,10,0,98,6,0,0,255,255,0,0,231,81,0,0,14,14,11,0,102,3,0,0,255,255,0,0,248,81,0,0,16,16,10,0,100,3,0,0,255,255,0,0,249,81,0,0,20,20,10,0,250,6,0,0,255,255,0,0,250,81,0,0,0,0,6,0,40,20,0,0,255,255,0,0,251,81,0,0,0,0,8,0,180,16,0,0,255,255,0,0,252,81,0,0,0,0,4,0,252,43,0,0,255,255,0,0,223,82,0,0,12,12,10,0,210,34,0,0,255,255,0,0,231,82,0,0,14,14,11,0,38,40,0,0,255,255,0,0,248,82,0,0,16,16,10,0,44,40,0,0,255,255,0,0,249,82,0,0,20,20,10,0,14,15,0,0,255,255,0,0,250,82,0,0,0,0,6,0,222,27,0,0,255,255,0,0,251,82,0,0,0,0,8,0,138,5,0,0,255,255,0,0,252,82,0,0,0,0,4,0,56,28,0,0,255,255,0,0,223,83,0,0,12,12,10,0,166,22,0,0,255,255,0,0,231,83,0,0,14,14,11,0,48,12,0,0,255,255,0,0,248,83,0,0,16,16,10,0,52,12,0,0,255,255,0,0,249,83,0,0,20,20,10,0,172,3,0,0,255,255,0,0,250,83,0,0,0,0,6,0,76,42,0,0,255,255,0,0,251,83,0,0,0,0,8,0,140,31,0,0,255,255,0,0,252,83,0,0,0,0,4,0,116,37,0,0,255,255,0,0,223,84,0,0,12,12,10,0,236,44,0,0,255,255,0,0,231,84,0,0,14,14,11,0,48,21,0,0,255,255,0,0,248,84,0,0,16,16,10,0,44,21,0,0,255,255,0,0,249,84,0,0,20,20,10,0,242,36,0,0,255,255,0,0,250,84,0,0,0,0,6,0,44,24,0,0,255,255,0,0,251,84,0,0,0,0,8,0,36,13,0,0,255,255,0,0,252,84,0,0,0,0,4,0,30,16,0,0,255,255,0,0,223,85,0,0,12,12,10,0,98,23,0,0,255,255,0,0,231,85,0,0,14,14,11,0,198,4,0,0,255,255,0,0,248,85,0,0,16,16,10,0,200,4,0,0,255,255,0,0,249,85,0,0,20,20,10,0,212,47,0,0,255,255,0,0,250,85,0,0,0,0,6,0])
.concat([30,20,0,0,255,255,0,0,251,85,0,0,0,0,8,0,34,13,0,0,255,255,0,0,252,85,0,0,0,0,4,0,84,43,0,0,255,255,0,0,223,86,0,0,12,12,10,0,180,39,0,0,255,255,0,0,231,86,0,0,14,14,11,0,96,29,0,0,255,255,0,0,248,86,0,0,16,16,10,0,88,29,0,0,255,255,0,0,249,86,0,0,20,20,10,0,72,20,0,0,255,255,0,0,250,86,0,0,0,0,6,0,54,7,0,0,255,255,0,0,251,86,0,0,0,0,8,0,184,18,0,0,255,255,0,0,252,86,0,0,0,0,4,0,24,41,0,0,255,255,0,0,223,87,0,0,12,12,10,0,218,14,0,0,255,255,0,0,231,87,0,0,14,14,11,0,48,33,0,0,255,255,0,0,248,87,0,0,16,16,10,0,42,33,0,0,255,255,0,0,249,87,0,0,20,20,10,0,198,46,0,0,255,255,0,0,250,87,0,0,0,0,6,0,174,20,0,0,255,255,0,0,251,87,0,0,0,0,8,0,70,1,0,0,255,255,0,0,252,87,0,0,0,0,4,0,236,48,0,0,255,255,0,0,223,88,0,0,12,12,10,0,216,41,0,0,255,255,0,0,231,88,0,0,14,14,11,0,154,30,0,0,255,255,0,0,248,88,0,0,16,16,10,0,148,30,0,0,255,255,0,0,249,88,0,0,20,20,10,0,194,48,0,0,255,255,0,0,250,88,0,0,0,0,6,0,230,11,0,0,255,255,0,0,251,88,0,0,0,0,8,0,168,22,0,0,255,255,0,0,252,88,0,0,0,0,4,0,236,33,0,0,255,255,0,0,223,89,0,0,12,12,10,0,200,26,0,0,255,255,0,0,231,89,0,0,14,14,11,0,176,24,0,0,255,255,0,0,248,89,0,0,16,16,10,0,180,24,0,0,255,255,0,0,249,89,0,0,20,20,10,0,60,14,0,0,255,255,0,0,250,89,0,0,0,0,6,0,22,27,0,0,255,255,0,0,251,89,0,0,0,0,8,0,20,24,0,0,255,255,0,0,252,89,0,0,0,0,4,0,26,25,0,0,255,255,0,0,223,90,0,0,12,12,10,0,42,32,0,0,255,255,0,0,231,90,0,0,14,14,11,0,142,3,0,0,255,255,0,0,248,90,0,0,16,16,10,0,146,3,0,0,255,255,0,0,249,90,0,0,20,20,10,0,166,37,0,0,255,255,0,0,250,90,0,0,0,0,6,0,144,50,0,0,255,255,0,0,251,90,0,0,0,0,8,0,14,11,0,0,255,255,0,0,252,90,0,0,0,0,4,0,144,41,0,0,255,255,0,0,223,91,0,0,12,12,10,0,22,45,0,0,255,255,0,0,231,91,0,0,14,14,11,0,154,24,0,0,255,255,0,0,248,91,0,0,16,16,10,0,158,24,0,0,255,255,0,0,249,91,0,0,20,20,10,0,220,2,0,0,255,255,0,0,250,91,0,0,0,0,6,0,100,37,0,0,255,255,0,0,251,91,0,0,0,0,8,0,244,49,0,0,255,255,0,0,252,91,0,0,0,0,4,0,42,23,0,0,255,255,0,0,223,92,0,0,12,12,10,0,244,26,0,0,255,255,0,0,231,92,0,0,14,14,11,0,144,11,0,0,255,255,0,0,248,92,0,0,16,16,10,0,150,11,0,0,255,255,0,0,249,92,0,0,20,20,10,0,90,32,0,0,255,255,0,0,250,92,0,0,0,0,6,0,80,45,0,0,255,255,0,0,251,92,0,0,0,0,8,0,34,39,0,0,255,255,0,0,252,92,0,0,0,0,4,0,126,19,0,0,255,255,0,0,223,93,0,0,12,12,10,0,46,24,0,0,255,255,0,0,231,93,0,0,14,14,11,0,210,32,0,0,255,255,0,0,248,93,0,0,16,16,10,0,212,32,0,0,255,255,0,0,249,93,0,0,20,20,10,0,254,10,0,0,255,255,0,0,250,93,0,0,0,0,6,0,2,24,0,0,255,255,0,0,251,93,0,0,0,0,8,0,142,31,0,0,255,255,0,0,252,93,0,0,0,0,4,0,58,20,0,0,255,255,0,0,223,94,0,0,12,12,10,0,74,38,0,0,255,255,0,0,231,94,0,0,14,14,11,0,38,45,0,0,255,255,0,0,248,94,0,0,16,16,10,0,32,45,0,0,255,255,0,0,249,94,0,0,20,20,10,0,0,8,0,0,255,255,0,0,250,94,0,0,0,0,6,0,42,21,0,0,255,255,0,0,251,94,0,0,0,0,8,0,38,39,0,0,255,255,0,0,252,94,0,0,0,0,4,0,220,47,0,0,255,255,0,0,223,95,0,0,12,12,10,0,230,38,0,0,255,255,0,0,231,95,0,0,14,14,11,0,14,6,0,0,255,255,0,0,248,95,0,0,16,16,10,0,10,6,0,0,255,255,0,0,249,95,0,0,20,20,10,0,62,17,0,0,255,255,0,0,250,95,0,0,0,0,6,0,16,30,0,0,255,255,0,0,251,95,0,0,0,0,8,0,148,31,0,0,255,255,0,0,252,95,0,0,0,0,4,0,154,32,0,0,255,255,0,0,0,96,0,0,10,10,10,0,128,45,0,0,255,255,0,0,255,96,0,0,0,0,10,0,148,44,0,0,255,255,0,0,0,97,0,0,18,18,7,0,132,7,0,0,255,255,0,0,255,97,0,0,0,0,7,0,226,4,0,0,255,255,0,0,0,98,0,0,10,10,6,0,116,42,0,0,255,255,0,0,255,98,0,0,0,0,6,0,160,43,0,0,255,255,0,0,0,99,0,0,10,10,6,0,96,6,0,0,255,255,0,0,255,99,0,0,0,0,6,0,180,19,0,0,255,255,0,0,0,100,0,0,10,10,6,0,60,41,0,0,255,255,0,0,255,100,0,0,0,0,6,0,44,35,0,0,255,255,0,0,0,101,0,0,10,10,6,0,48,48,0,0,255,255,0,0,255,101,0,0,0,0,6,0,58,25,0,0,255,255,0,0,0,102,0,0,10,10,6,0,248,37,0,0,255,255,0,0,255,102,0,0,0,0,6,0,250,0,0,0,255,255,0,0,0,103,0,0,10,10,6,0,184,14,0,0,255,255,0,0,255,103,0,0,0,0,6,0,168,43,0,0,255,255,0,0,0,104,0,0,10,10,6,0,146,30,0,0,255,255,0,0,255,104,0,0,0,0,6,0,174,47,0,0,255,255,0,0,0,105,0,0,10,10,6,0,182,34,0,0,255,255,0,0,255,105,0,0,0,0,6,0,188,41,0,0,255,255,0,0,0,106,0,0,10,10,6,0,184,28,0,0,255,255,0,0,255,106,0,0,0,0,6,0,212,33,0,0,255,255,0,0,0,107,0,0,10,10,6,0,194,46,0,0,255,255,0,0,255,107,0,0,0,0,6,0,140,35,0,0,255,255,0,0,0,108,0,0,10,10,6,0,204,22,0,0,255,255,0,0,255,108,0,0,0,0,6,0,64,15,0,0,255,255,0,0,0,109,0,0,10,10,6,0,136,1,0,0,255,255,0,0,255,109,0,0,0,0,6,0,62,10,0,0,255,255,0,0,0,110,0,0,10,10,6,0,40,47,0,0,255,255,0,0,255,110,0,0,0,0,6,0,30,37,0,0,255,255,0,0,0,111,0,0,10,10,6,0,66,24,0,0,255,255,0,0,255,111,0,0,0,0,6,0,74,2,0,0,255,255,0,0,15,143,0,0,18,18,16,0,236,38,0,0,255,255,0,0,79,143,0,0,0,0,13,0,38,24,0,0,255,255,0,0,143,143,0,0,0,0,13,0,190,46,0,0,255,255,0,0,15,159,0,0,18,18,12,0,126,12,0,0,255,255,0,0,15,191,0,0,12,12,9,0,188,17,0,0,255,255,0,0,15,207,0,0,18,18,16,0,32,4,0,0,255,255,0,0,15,223,0,0,18,18,12,0,146,38,0,0,255,255,0,0,248,224,0,0,16,16,9,0,152,38,0,0,255,255,0,0,249,224,0,0,20,20,9,0,100,22,0,0,255,255,0,0,248,225,0,0,16,16,10,0,90,22,0,0,255,255,0,0,249,225,0,0,20,20,10,0,236,1,0,0,255,255,0,0,248,226,0,0,16,16,9,0,232,1,0,0,255,255,0,0,249,226,0,0,20,20,9,0,50,41,0,0,255,255,0,0,248,227,0,0,16,16,9,0,46,41,0,0,255,255,0,0,249,227,0,0,20,20,9,0,46,48,0,0,255,255,0,0,248,228,0,0,16,16,9,0,42,48,0,0,255,255,0,0,249,228,0,0,20,20,9,0,56,18,0,0,255,255,0,0,248,229,0,0,16,16,9,0,60,18,0,0,255,255,0,0,249,229,0,0,20,20,9,0,50,7,0,0,255,255,0,0,248,230,0,0,16,16,11,0,42,7,0,0,255,255,0,0,249,230,0,0,20,20,11,0,178,32,0,0,255,255,0,0,248,231,0,0,16,16,11,0,216,42,0,0,255,255,0,0,249,231,0,0,20,20,11,0,124,0,0,0,255,255,0,0,248,232,0,0,0,0,17,0,130,0,0,0,255,255,0,0,249,232,0,0,0,0,17,0,118,40,0,0,255,255,0,0,250,232,0,0,0,0,18,0,30,31,0,0,255,255,0,0,251,232,0,0,0,0,20,0,254,32,0,0,255,255,0,0,248,233,0,0,0,0,19,0,248,32,0,0,255,255,0,0,249,233,0,0,0,0,19,0,8,27,0,0,255,255,0,0,250,233,0,0,0,0,20,0,42,34,0,0,255,255,0,0,251,233,0,0,0,0,22,0,170,13,0,0,255,255,0,0,248,234,0,0,0,0,24,0,162,13,0,0,255,255,0,0,249,234,0,0,0,0,24,0,132,3,0,0,255,255,0,0,248,235,0,0,0,0,19,0,26,19,0,0,255,255,0,0,249,235,0,0,0,0,19,0,134,44,0,0,255,255,0,0,250,235,0,0,0,0,20,0,2,50,0,0,255,255,0,0,251,235,0,0,0,0,22,0,254,8,0,0,255,255,0,0,248,236,0,0,0,0,24,0,6,9,0,0,255,255,0,0,249,236,0,0,0,0,24,0,16,22,0,0,255,255,0,0,248,237,0,0,0,0,32,0,14,22,0,0,255,255,0,0,249,237,0,0,0,0,32,0,248,26,0,0,255,255,0,0,250,237,0,0,0,0,33,0,48,23,0,0,255,255,0,0,251,237,0,0,0,0,35,0,56,5,0,0,255,255,0,0,248,238,0,0,0,0,24,0,58,5,0,0,255,255,0,0,249,238,0,0,0,0,24,0,124,36,0,0,255,255,0,0,248,239,0,0,0,0,21,0,120,36,0,0,255,255,0,0,249,239,0,0,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,255,0,0,0,2,1,0,255,254,255,0,1,3,1,0,255,253,255,0,1,4,2,0,254,252,254,0,2,5,2,0,254,251,254,0,2,6,3,0,253,250,253,0,3,7,3,0,253,249,253,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,255,0,0,0,1,0,0,0,255,0,0,0,2,1,0,255,254,255,0,1,1,0,0,0,255,0,0,0,3,1,0,255,253,255,0,1,2,1,0,255,254,255,0,1,4,2,0,254,252,254,0,2,2,1,0,255,254,255,0,1,5,2,0,254,251,254,0,2,3,1,0,255,253,255,0,1,6,3,0,253,250,253,0,3,3,1,0,255,253,255,0,1,7,3,0,253,249,253,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,0,0,1,1,2,2,2,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,1,1,1,1,0,0,1,1,2,2,2,3,0,0,2,3,4,4,5,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,1,1,1,1,0,0,0,1,1,1,1,2,0,0,1,1,2,2,2,3,0,0,2,3,4,4,5,6,0,0,4,6,8,8,10,12,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,0,0,0,1,1,1,2,2,0,0,1,1,2,2,3,3,0,0,1,2,2,2,3,4,0,0,2,3,4,4,5,6,0,0,4,6,8,8,10,12,0,0,8,12,16,16,20,24,0,0,0,0,0,0,0,0,0,0,0,0,2,2,2,2,0,0,0,2,2,2,4,4,0,0,2,2,4,4,6,6,0,0,2,4,4,4,6,8,0,0,4,6,8,8,10,12,0,0,8,12,16,16,20,24,0,0,16,24,32,32,40,48,0,0,0,0,0,0,0,0,0,0,0,0,4,4,4,4,0,0,0,4,4,4,8,8,0,0,4,4,8,8,12,12,0,0,4,8,8,8,12,16,0,0,8,12,16,16,20,24,0,0,16,24,32,32,40,48,0,0,32,48,64,64,80,96,255,238,211,128,88,218,127,148,158,227,250,0,77,250,255,106,122,222,73,246,0,51,187,99,145,96,81,255,0,216,127,222,220,115,33,133,178,156,93,36,205,145,158,118,127,32,251,243,0,166,62,66,39,105,174,51,69,68,17,65,114,115,223,162,50,189,126,168,19,235,211,21,221,251,201,157,97,47,190,157,35,101,81,106,132,249,201,215,35,191,101,25,220,3,243,36,51,182,30,87,92,172,37,137,77,197,156,153,21,7,207,186,197,155,21,77,141,42,30,31,234,43,47,100,169,80,61,171,80,119,233,192,172,109,63,202,207,113,125,128,166,253,255,181,189,111,36,123,0,153,93,177,72,176,40,127,128,236,191,111,110,57,144,66,217,78,46,18,102,200,207,59,63,16,125,121,0,211,31,33,147,52,215,25,34,162,8,32,185,185,239,81,153,222,191,212,9,117,233,138,238,253,228,78,48,23,223,206,17,178,40,53,194,124,100,235,145,95,50,12,110,0,249,146,25,219,143,171,174,214,18,196,38,98,206,204,10,3,231,221,226,77,138,166,70,149,15,143,245,21,151,50,212,40,30,85,8,3,1,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,2,2,2,2,3,3,3,3,4,4,4,4,5,5,5,5,6,6,6,6,7,7,7,7,8,8,8,8,9,9,9,9,10,10,10,10,11,11,11,11,12,12,12,12,13,13,13,13,14,14,14,14,15,15,15,15,16,16,16,16,17,17,17,17,18,18,18,18,19,19,19,19,20,20,20,20,21,21,21,21,22,22,22,22,23,23,23,23,24,24,24,24,25,25,25,25,26,26,26,25,25,25,25,24,24,24,24,23,23,23,23,22,22,22,22,21,21,21,21,20,20,20,20,19,19,19,19,18,18,18,18,17,17,17,17,16,16,16,16,15,15,15,15,14,14,14,14,13,13,13,13,12,12,12,12,11,11,11,11,10,10,10,10,9,9,9,9,8,8,8,8,7,7,7,7,6,6,6,6,5,5,5,5,4,4,4,4,3,3,3,3,2,2,2,2,1,1,1,1,0,0,0,0,0,0,127,38,93,144,186,144,30,94,184,144,188,232,1,144,74,37,144,189,144,34,16,144,2,87,112,144,126,144,231,82,144,169,144,144,198,6,160,254,207,142,67,143,45,144,212,133,117,162,61,144,144,56,124,137,209,128,59,114,7,144,66,55,10,24,136,180,152,139,185,156,173,14,43,144,191,144,85,144,86,176,147,145,144,235,144,80,65,41,71,144,144,96,144,171,144,144,195,226,208,178,17,121,144,8,144,251,144,44,35,144,40,13,144,144,144,131,60,144,27,52,91,144,64,144,144,4,252,205,177,243,138,144,144,135,144,144,144,144,144,144,190,132,31,230,255,144,18,144,181,54,144,179,144,144,144,210,78,144,144,144,165,144,144,199,144,39,11,144,32,144,144,144,144,144,97,125,144,144,134,15,144,183,144,79,144,144,192,253,144,57,144,119,5,58,144,72,146,118,62,3,144,248,144,89,168,95,249,187,129,250,157,233,46,161,193,51,144,120,144,12,144,36,170,172,144,182,144,234,144,115,229,88,0,247,144,116,144,118,144,163,144,90,246,50,70,42,144,144,83,75,144,13,81,104,153,19,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,6,0,0,0,8,0,0,0,10,0,0,0,12,0,0,0,14,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,10,0,0,0,14,0,0,0,16,0,0,0,20,0,0,0,22,0,0,0,24,0,0,0,26,0,0,0,28,0,0,0,30,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,0,0,16,0,0,0,22,0,0,0,26,0,0,0,30,0,0,0,32,0,0,0,36,0,0,0,38,0,0,0,40,0,0,0,42,0,0,0,44,0,0,0,46,0,0,0,48,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,26,0,0,0,32,0,0,0,38,0,0,0,42,0,0,0,46,0,0,0,48,0,0,0,52,0,0,0,54,0,0,0,56,0,0,0,58,0,0,0,60,0,0,0,62,0,0,0,64,0,0,0,0,0,0,0,16,0,0,0,32,0,0,0,42,0,0,0,48,0,0,0,54,0,0,0,58,0,0,0,62,0,0,0,64,0,0,0,68,0,0,0,70,0,0,0,72,0,0,0,74,0,0,0,76,0,0,0,78,0,0,0,80,0,0,0,0,0,0,0,32,0,0,0,48,0,0,0,58,0,0,0,64,0,0,0,70,0,0,0,74,0,0,0,78,0,0,0,80,0,0,0,84,0,0,0,86,0,0,0,88,0,0,0,90,0,0,0,92,0,0,0,94,0,0,0,96,0,0,0,0,0,0,0,48,0,0,0,64,0,0,0,74,0,0,0,80,0,0,0,86,0,0,0,90,0,0,0,94,0,0,0,96,0,0,0,100,0,0,0,102,0,0,0,104,0,0,0,106,0,0,0,108,0,0,0,110,0,0,0,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,12,0,0,0,16,0,0,0,20,0,0,0,24,0,0,0,28,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,20,0,0,0,28,0,0,0,32,0,0,0,40,0,0,0,44,0,0,0,48,0,0,0,52,0,0,0,56,0,0,0,60,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,0,0,0,32,0,0,0,44,0,0,0,52,0,0,0,60,0,0,0,64,0,0,0,72,0,0,0,76,0,0,0,80,0,0,0,84,0,0,0,88,0,0,0,92,0,0,0,96,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,52,0,0,0,64,0,0,0,76,0,0,0,84,0,0,0,92,0,0,0,96,0,0,0,104,0,0,0,108,0,0,0,112,0,0,0,116,0,0,0,120,0,0,0,124,0,0,0,128,0,0,0,0,0,0,0,32,0,0,0,64,0,0,0,84,0,0,0,96,0,0,0,108,0,0,0,116,0,0,0,124,0,0,0,128,0,0,0,136,0,0,0,140,0,0,0,144,0,0,0,148,0,0,0,152,0,0,0,156,0,0,0,160,0,0,0,0,0,0,0,64,0,0,0,96,0,0,0,116,0,0,0,128,0,0,0,140,0,0,0,148,0,0,0,156,0,0,0,160,0,0,0,168,0,0,0,172,0,0,0,176,0,0,0,180,0,0,0,184,0,0,0,188,0,0,0,192,0,0,0,0,0,0,0,96,0,0,0,128,0,0,0,148,0,0,0,160,0,0,0,172,0,0,0,180,0,0,0,188,0,0,0,192,0,0,0,200,0,0,0,204,0,0,0,208,0,0,0,212,0,0,0,216,0,0,0,220,0,0,0,224,0,0,0,31,144,187,80,144,88,66,87,144,144,233,144,144,144,144,11,144,144,157,156,144,144,30,144,144,180,91,144,144,144,144,144,144,144,120,199,144,144,131,144,144,12,176,4,144,144,144,144,144,144,144,144,59,195,181,71,144,144,144,144,89,144,144,144,144,144,144,56,144,144,144,144,95,163,250,144,232,54,117,144,136,51,144,144,144,144,67,144,144,135,144,144,144,144,144,144,144,144,144,144,142,243,86,144,144,144,144,38,255,144,144,144,144,144,144,42,144,138,144,24,144,144,3,137,36,144,144,144,10,144,235,144,134,144,144,144,121,58,144,144,144,144,160,144,234,144,144,144,144,144,44,144,198,144,144,70,144,170,182,94,144,144,144,144,139,144,144,144,144,144,186,144,185,83,162,144,144,7,144,144,144,60,50,144,43,144,184,144,144,144,144,144,189,144,144,144,144,129,144,208,8,144,85,6,207,144,144,252,144,144,144,177,191,144,144,81,82,144,93,144,90,144,178,144,254,144,144,34,32,114,246,128,2,46,144,116,15,144,144,144,144,144,144,144,188,65,144,251,115,144,144,144,35,210,144,144,192,186,141,0,128,195,141,0,64,204,141,0,0,213,141,0,192,221,141,0,128,230,141,0,64,239,141,0,0,248,141,0,104,3,0,0,238,1,0,0,6,0,0,0,192,8,0,0,12,5,0,0,0,0,0,0,0,0,0,0,72,10,0,0,200,196,8,0,246,12,0,0,0,0,0,0,0,0,0,0,96,165,2,0,20,1,0,0,184,139,2,0,19,1,0,0,208,239,2,0,17,1,0,0,128,196,2,0,18,1,0,0,176,147,8,0,13,0,0,0,224,141,8,0,15,1,0,0,232,193,8,0,9,0,0,0,200,131,8,0,21,1,0,0,184,125,8,0,127,0,0,0,72,125,8,0,23,1,0,0,224,121,8,0,22,1,0,0,120,114,8,0,47,1,0,0,64,107,8,0,48,1,0,0,240,99,8,0,50,1,0,0,192,91,8,0,52,1,0,0,144,167,8,0,32,0,0,0,192,79,8,0,27,0,0,0,216,74,8,0,14,1,0,0,224,69,8,0,13,1,0,0,232,66,8,0,14,1,0,0,128,63,8,0,13,1,0,0,0,57,8,0,26,1,0,0,208,50,8,0,27,1,0,0,120,43,8,0,28,1,0,0,16,36,8,0,29,1,0,0,128,30,8,0,30,1,0,0,72,27,8,0,31,1,0,0,224,22,8,0,32,1,0,0,240,18,8,0,33,1,0,0,64,16,8,0,34,1,0,0,8,12,8,0,35,1,0,0,184,4,8,0,36,1,0,0,200,254,7,0,37,1,0,0,176,247,7,0,48,0,0,0,80,239,7,0,49,0,0,0,48,233,7,0,50,0,0,0,248,228,7,0,51,0,0,0,120,225,7,0,52,0,0,0,192,221,7,0,53,0,0,0,128,217,7,0,54,0,0,0,40,214,7,0,55,0,0,0,104,207,7,0,56,0,0,0,152,201,7,0,57,0,0,0,8,195,7,0,24,1,0,0,232,186,7,0,25,1,0,0,184,181,7,0,0,1,0,0,248,177,7,0,1,1,0,0,80,175,7,0,2,1,0,0,232,170,7,0,3,1,0,0,216,166,7,0,4,1,0,0,200,162,7,0,5,1,0,0,128,157,7,0,6,1,0,0,56,152,7,0,7,1,0,0,24,147,7,0,8,1,0,0,0,140,7,0,9,1,0,0,112,51,1,0,46,0,0,0,192,131,7,0,45,1,0,0,80,128,7,0,44,1,0,0,176,63,3,0,8,0,0,0,104,79,6,0,12,1,0,0,224,36,6,0,11,1,0,0,160,112,7,0,60,1,0,0,112,106,7,0,46,1,0,0,248,183,8,0,96,0,0,0,48,93,7,0,96,0,0,0,136,86,7,0,19,0,0,0,8,24,5,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,168,127,9,0,184,72,3,0,0,0,0,0,1,0,0,0,0,0,0,0,136,127,9,0,168,18,2,0,1,0,0,0,1,0,0,0,0,0,0,0,216,183,1,0,64,76,1,0,2,0,0,0,1,0,0,0,0,0,0,0,0,202,1,0,88,197,8,0,3,0,0,0,1,0,0,0,0,0,0,0,208,239,2,0,40,70,8,0,4,0,0,0,1,0,0,0,0,0,0,0,128,196,2,0,40,222,7,0,5,0,0,0,1,0,0,0,0,0,0,0,96,165,2,0,232,125,7,0,6,0,0,0,1,0,0,0,0,0,0,0,184,139,2,0,184,28,7,0,7,0,0,0,1,0,0,0,0,0,0,0,176,127,9,0,80,200,6,0,8,0,0,0,1,0,0,0,0,0,0,0,144,127,9,0,240,111,6,0,9,0,0,0,1,0,0,0,0,0,0,0,160,127,9,0,128,22,6,0,10,0,0,0,1,0,0,0,0,0,0,0,24,11,1,0,32,191,5,0,11,0,0,0,1,0,0,0,0,0,0,0,208,246,2,0,248,120,5,0,12,0,0,0,1,0,0,0,0,0,0,0,80,223,2,0,112,60,5,0,13,0,0,0,1,0,0,0,0,0,0,0,216,201,2,0,128,253,4,0,14,0,0,0,1,0,0,0,0,0,0,0,56,183,2,0,248,182,4,0,15,0,0,0,1,0,0,0,0,0,0,0,168,155,2,0,224,121,4,0,16,0,0,0,1,0,0,0,0,0,0,0,56,143,2,0,8,70,4,0,17,0,0,0,1,0,0,0,0,0,0,0,224,131,2,0,216,14,4,0,18,0,0,0,1,0,0,0,0,0,0,0,72,119,2,0,144,204,3,0,19,0,0,0,1,0,0,0,0,0,0,0,200,104,2,0,56,153,3,0,20,0,0,0,1,0,0,0,0,0,0,0,136,92,2,0,120,104,3,0,21,0,0,0,1,0,0,0,0,0,0,0,216,76,2,0,48,71,3,0,22,0,0,0,1,0,0,0,0,0,0,0,208,64,2,0,80,40,3,0,23,0,0,0,1,0,0,0,0,0,0,0,64,170,2,0,144,250,2,0,24,0,0,0,1,0,0,0,1,0,0,0,152,47,2,0,80,205,2,0,25,0,0,0,1,0,0,0,2,0,0,0,232,36,2,0,96,172,2,0,26,0,0,0,1,0,0,0,1,0,0,0,208,26,2,0,168,144,2,0,27,0,0,0,1,0,0,0,1,0,0,0,200,16,2,0,240,120,2,0,28,0,0,0,1,0,0,0,2,0,0,0,240,7,2,0,240,94,2,0,29,0,0,0,1,0,0,0,2,0,0,0,152,0,2,0,88,196,8,0,30,0,0,0,1,0,0,0,2,0,0,0,216,242,1,0,88,38,2,0,31,0,0,0,1,0,0,0,2,0,0,0,96,232,1,0,40,18,2,0,32,0,0,0,1,0,0,0,1,0,0,0,232,218,1,0,104,76,2,0,33,0,0,0,1,0,0,0,2,0,0,0,232,204,1,0,248,233,1,0,34,0,0,0,1,0,0,0,2,0,0,0,120,193,1,0,200,206,1,0,35,0,0,0,1,0,0,0,2,0,0,0,104,186,1,0,160,187,1,0,36,0,0,0,1,0,0,0,2,0,0,0,40,185,3,0,112,173,1,0,37,0,0,0,1,0,0,0,2,0,0,0,160,172,1,0,248,158,1,0,38,0,0,0,1,0,0,0,2,0,0,0,128,164,1,0,48,136,1,0,39,0,0,0,1,0,0,0,2,0,0,0,152,157,1,0,176,108,1,0,40,0,0,0,1,0,0,0,2,0,0,0,176,145,1,0,40,90,1,0,41,0,0,0,1,0,0,0,2,0,0,0,8,134,1,0,16,76,1,0,42,0,0,0,1,0,0,0,2,0,0,0,168,120,1,0,224,63,1,0,43,0,0,0,1,0,0,0,2,0,0,0,88,107,1,0,88,48,1,0,44,0,0,0,1,0,0,0,2,0,0,0,232,95,1,0,240,30,1,0,45,0,0,0,1,0,0,0,2,0,0,0,72,89,1,0,152,13,1,0,46,0,0,0,1,0,0,0,2,0,0,0,128,82,1,0,216,2,1,0,47,0,0,0,1,0,0,0,2,0,0,0,72,75,1,0,0,251,8,0,48,0,0,0,1,0,0,0,2,0,0,0,40,68,1,0,0,236,8,0,49,0,0,0,1,0,0,0,2,0,0,0,232,62,1,0,80,220,8,0,50,0,0,0,1,0,0,0,2,0,0,0,232,54,1,0,88,206,8,0,51,0,0,0,1,0,0,0,2,0,0,0,56,46,1,0,48,197,8,0,52,0,0,0,1,0,0,0,2,0,0,0,224,38,1,0,120,187,8,0,53,0,0,0,1,0,0,0,2,0,0,0,56,29,1,0,232,171,8,0,54,0,0,0,1,0,0,0,1,0,0,0,80,18,1,0,240,153,8,0,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,16,0,17,0,17,0,17,0,17,0,18,0,18,0,18,0,18,0,19,0,19,0,19,0,19,0,20,0,20,0,20,0,20,0,21,0,21,0,21,0,21,0,16,0,72,0,78,0,0,0,3,0,4,0,5,0,6,0,7,0,8,0,9,0,10,0,11,0,13,0,15,0,17,0,19,0,23,0,27,0,31,0,35,0,43,0,51,0,59,0,67,0,83,0,99,0,115,0,131,0,163,0,195,0,227,0,2,1,0,0,0,0,0,0,16,0,16,0,16,0,16,0,17,0,17,0,18,0,18,0,19,0,19,0,20,0,20,0,21,0,21,0,22,0,22,0,23,0,23,0,24,0,24,0,25,0,25,0,26,0,26,0,27,0,27,0,28,0,28,0,29,0,29,0,64,0,64,0,1,0,2,0,3,0,4,0,5,0,7,0,9,0,13,0,17,0,25,0,33,0,49,0,65,0,97,0,129,0,193,0,1,1,129,1,1,2,1,3,1,4,1,6,1,8,1,12,1,16,1,24,1,32,1,48,1,64,1,96,0,0,0,0,16,0,17,0,18,0,0,0,8,0,7,0,9,0,6,0,10,0,5,0,11,0,4,0,12,0,3,0,13,0,2,0,14,0,1,0,15,0,0,0,182,32,34,144,15,87,89,198,235,144,176,187,59,144,144,144,54,144,144,144,144,144,144,144,144,254,144,144,144,144,144,160,46,144,11,144,144,88,144,144,144,144,144,144,144,128,144,144,51,144,144,191,85,144,144,144,83,144,144,144,144,144,144,144,71,116,144,177,180,144,144,136,144,144,56,207,144,142,144,144,144,199,144,50,144,82,60,144,144,144,144,144,144,144,131,114,144,115,144,90,144,67,144,144,144,144,65,233,189,144,178,210,144,170,162,144,144,144,144,144,144,144,144,38,144,144,138,144,144,144,144,144,144,144,144,24,144,157,144,144,144,93,144,70,144,144,144,246,195,163,30,7,95,129,144,12,144,184,144,117,144,144,144,144,144,144,144,144,144,144,144,144,144,144,144,121,144,94,144,144,6,144,255,144,91,36,144,43,144,144,144,2,134,144,144,251,144,144,80,252,8,144,144,144,3,144,185,144,144,188,232,31,250,66,144,144,137,144,35,135,144,42,144,144,139,144,243,234,4,44,181,144,10,144,81,144,144,58,144,156,144,144,120,144,186,144,144,144,144,144,144,144,208,86,144,144,99,144,144,54,144,82,177,91,104,205,144,144,144,168,144,144,144,144,117,36,8,131,50,233,144,121,144,143,34,144,172,144,93,165,17,81,10,41,144,144,248,152,145,64,40,0,3,95,38,144,144,139,47,2,144,144,142,171,144,144,188,144,179,144,9,144,198,144,144,58,144,144,144,116,97,144,51,144,144,144,144,83,160,192,195,65,252,231,144,44,124,43,144,79,186,42,176,144,33,125,144,144,181,7,185,144,39,70,249,144,144,144,144,234,114,115,173,209,59,94,229,87,144,13,253,144,146,60,144,134,120,127,48,37,45,144,154,235,4,11,162,184,246,144,144,144,157,144,187,144,144,203,169,207,144,96,67,86,144,144,144,163,144,144,18,144,250,180,144,129,230,72,128,140,212,144,66,144,132,182,119,61,62,144,144,12,75,144,164,144,144,144,144,255,71,144,85,30,144,89,147,144,144,144,136,193,1,178,133,46,6,199,5,144,138,90,88,190,144,78,144,31,35,144,232,144,137,161,208,144,144,226,56,254,80,156,144,144,144,73,251,32,243,144,144,15,144,144,144,118,247,189,57,126,191,144,255,144,144,44,144,144,67,136,144,19,10,189,186,96,234,144,144,144,242,41,179,34,144,12,169,95,157,7,144,144,11,187,138,144,144,144,58,60,90,56,153,144,248,137,144,145,144,85,172,64,115,144,89,144,252,144,80,250,144,37,144,52,71,183,144,144,144,73,144,15,139,5,195,165,191,131,134,197,144,144,40,119,36,180,144,146,144,59,94,182,128,13,46,171,231,144,72,144,173,192,144,27,198,163,4,144,144,144,22,176,125,152,135,70,140,144,144,254,144,207,144,104,132,144,210,144,24,81,118,164,54,82,251,144,185,144,144,177,28,33,230,181,23,39,61,69,190,174,144,74,14,229,144,88,31,97,243,2,144,232,144,144,144,247,86,150,144,188,79,144,144,121,208,144,42,18,78,184,144,65,144,144,211,144,45,51,246,144,144,20,144,50,93,168,83,38,43,32,129,117,127,62,144,144,0,147,144,178,87,144,160,144,57,144,144,114,144,1,66,116,156,30,144,91,144,249,144,47,133,144,235,162,144,226,17,144,75,126,144,120,144,144,9,161,3,144,35,193,142,233,209,124,144,144,199,6,176,123,145,0,216,82,5,0,0,0,0,0,0,0,0,0,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,2,0,0,0,216,5,0,0,112,0,0,0,160,61,7,0,0,0,0,0,12,10,0,0,82,23,0,0,154,2,0,0,212,1,0,0,2,0,0,0,34,0,0,0,92,0,0,0,122,10,0,0,0,0,0,0,48,10,0,0,40,26,0,0,4,0,0,0,2,0,0,0,12,8,0,0,4,0,0,0,204,12,0,0,12,8,0,0,4,0,0,0,40,4,0,0,4,12,0,0,70,15,0,0,76,6,0,0,124,8,0,0,98,5,0,0,16,7,0,0,252,19,0,0,2,0,0,0,0,0,0,0,0,0,0,0,152,48,0,0,2,0,0,0,56,48,0,0,0,0,0,0,36,48,0,0,8,0,0,0,35,48,0,0,8,0,0,0,34,48,0,0,8,0,0,0,33,48,0,0,8,0,0,0,51,48,0,0,4,0,0,0,56,48,0,0,0,0,0,0,136,4,0,0,114,44,0,0,128,23,0,0,200,2,0,0,190,29,0,0,248,7,0,0,2,0,0,0,134,28,0,0,18,0,0,0,76,12,0,0,114,19,0,0,208,4,0,0,10,0,0,0,208,7,0,0,2,4,0,0,2,0,0,0,0,0,0,0,200,56,7,0,0,0,0,0,0,0,0,0,96,7,0,0,0,8,80,0,0,8,16,0,20,8,115,0,18,7,31,0,0,8,112,0,0,8,48,0,0,9,192,0,16,7,10,0,0,8,96,0,0,8,32,0,0,9,160,0,0,8,0,0,0,8,128,0,0,8,64,0,0,9,224,0,16,7,6,0,0,8,88,0,0,8,24,0,0,9,144,0,19,7,59,0,0,8,120,0,0,8,56,0,0,9,208,0,17,7,17,0,0,8,104,0,0,8,40,0,0,9,176,0,0,8,8,0,0,8,136,0,0,8,72,0,0,9,240,0,16,7,4,0,0,8,84,0,0,8,20,0,21,8,227,0,19,7,43,0,0,8,116,0,0,8,52,0,0,9,200,0,17,7,13,0,0,8,100,0,0,8,36,0,0,9,168,0,0,8,4,0,0,8,132,0,0,8,68,0,0,9,232,0,16,7,8,0,0,8,92,0,0,8,28,0,0,9,152,0,20,7,83,0,0,8,124,0,0,8,60,0,0,9,216,0,18,7,23,0,0,8,108,0,0,8,44,0,0,9,184,0,0,8,12,0,0,8,140,0,0,8,76,0,0,9,248,0,16,7,3,0,0,8,82,0,0,8,18,0,21,8,163,0,19,7,35,0,0,8,114,0,0,8,50,0,0,9,196,0,17,7,11,0,0,8,98,0,0,8,34,0,0,9,164,0,0,8,2,0,0,8,130,0,0,8,66,0,0,9,228,0,16,7,7,0,0,8,90,0,0,8,26,0,0,9,148,0,20,7,67,0,0,8,122,0,0,8,58,0,0,9,212,0,18,7,19,0,0,8,106,0,0,8,42,0,0,9,180,0,0,8,10,0,0,8,138,0,0,8,74,0,0,9,244,0,16,7,5,0,0,8,86,0,0,8,22,0,64,8,0,0,19,7,51,0,0,8,118,0,0,8,54,0,0,9,204,0,17,7,15,0,0,8,102,0,0,8,38,0,0,9,172,0,0,8,6,0,0,8,134,0,0,8,70,0,0,9,236,0,16,7,9,0,0,8,94,0,0,8,30,0,0,9,156,0,20,7,99,0,0,8,126,0,0,8,62,0,0,9,220,0,18,7,27,0,0,8,110,0,0,8,46,0,0,9,188,0,0,8,14,0,0,8,142,0,0,8,78,0,0,9,252,0,96,7,0,0,0,8,81,0,0,8,17,0,21,8,131,0,18,7,31,0,0,8,113,0,0,8,49,0,0,9,194,0,16,7,10,0,0,8,97,0,0,8,33,0,0,9,162,0,0,8,1,0,0,8,129,0,0,8,65,0,0,9,226,0,16,7,6,0,0,8,89,0,0,8,25,0,0,9,146,0,19,7,59,0,0,8,121,0,0,8,57,0,0,9,210,0,17,7,17,0,0,8,105,0,0,8,41,0,0,9,178,0,0,8,9,0,0,8,137,0,0,8,73,0,0,9,242,0,16,7,4,0,0,8,85,0,0,8,21,0,16,8,2,1,19,7,43,0,0,8,117,0,0,8,53,0,0,9,202,0,17,7,13,0,0,8,101,0,0,8,37,0,0,9,170,0,0,8,5,0,0,8,133,0,0,8,69,0,0,9,234,0,16,7,8,0,0,8,93,0,0,8,29,0,0,9,154,0,20,7,83,0,0,8,125,0,0,8,61,0,0,9,218,0,18,7,23,0,0,8,109,0,0,8,45,0,0,9,186,0,0,8,13,0,0,8,141,0,0,8,77,0,0,9,250,0,16,7,3,0,0,8,83,0,0,8,19,0,21,8,195,0,19,7,35,0,0,8,115,0,0,8,51,0,0,9,198,0,17,7,11,0,0,8,99,0,0,8,35,0,0,9,166,0,0,8,3,0,0,8,131,0,0,8,67,0,0,9,230,0,16,7,7,0,0,8,91,0,0,8,27,0,0,9,150,0,20,7,67,0,0,8,123,0,0,8,59,0,0,9,214,0,18,7,19,0,0,8,107,0,0,8,43,0,0,9,182,0,0,8,11,0,0,8,139,0,0,8,75,0,0,9,246,0,16,7,5,0,0,8,87,0,0,8,23,0,64,8,0,0,19,7,51,0,0,8,119,0,0,8,55,0,0,9,206,0,17,7,15,0,0,8,103,0,0,8,39,0,0,9,174,0,0,8,7,0,0,8,135,0,0,8,71,0,0,9,238,0,16,7,9,0,0,8,95,0,0,8,31,0,0,9,158,0,20,7,99,0,0,8,127,0,0,8,63,0,0,9,222,0,18,7,27,0,0,8,111,0,0,8,47,0,0,9,190,0,0,8,15,0,0,8,143,0,0,8,79,0,0,9,254,0,96,7,0,0,0,8,80,0,0,8,16,0,20,8,115,0,18,7,31,0,0,8,112,0,0,8,48,0,0,9,193,0,16,7,10,0,0,8,96,0,0,8,32,0,0,9,161,0,0,8,0,0,0,8,128,0,0,8,64,0,0,9,225,0,16,7,6,0,0,8,88,0,0,8,24,0,0,9,145,0,19,7,59,0,0,8,120,0,0,8,56,0,0,9,209,0,17,7,17,0,0,8,104,0,0,8,40,0,0,9,177,0,0,8,8,0,0,8,136,0,0,8,72,0,0,9,241,0,16,7,4,0,0,8,84,0,0,8,20,0,21,8,227,0,19,7,43,0,0,8,116,0,0,8,52,0,0,9,201,0,17,7,13,0,0,8,100,0,0,8,36,0,0,9,169,0,0,8,4,0,0,8,132,0,0,8,68,0,0,9,233,0,16,7,8,0,0,8,92,0,0,8,28,0,0,9,153,0,20,7,83,0,0,8,124,0,0,8,60,0,0,9,217,0,18,7,23,0,0,8,108,0,0,8,44,0,0,9,185,0,0,8,12,0,0,8,140,0,0,8,76,0,0,9,249,0,16,7,3,0,0,8,82,0,0,8,18,0,21,8,163,0,19,7,35,0,0,8,114,0,0,8,50,0,0,9,197,0,17,7,11,0,0,8,98,0,0,8,34,0,0,9,165,0,0,8,2,0,0,8,130,0,0,8,66,0,0,9,229,0,16,7,7,0,0,8,90,0,0,8,26,0,0,9,149,0,20,7,67,0,0,8,122,0,0,8,58,0,0,9,213,0,18,7,19,0,0,8,106,0,0,8,42,0,0,9,181,0,0,8,10,0,0,8,138,0,0,8,74,0,0,9,245,0,16,7,5,0,0,8,86,0,0,8,22,0,64,8,0,0,19,7,51,0,0,8,118,0,0,8,54,0,0,9,205,0,17,7,15,0,0,8,102,0,0,8,38,0,0,9,173,0,0,8,6,0,0,8,134,0,0,8,70,0,0,9,237,0,16,7,9,0,0,8,94,0,0,8,30,0,0,9,157,0,20,7,99,0,0,8,126,0,0,8,62,0,0,9,221,0,18,7,27,0,0,8,110,0,0,8,46,0,0,9,189,0,0,8,14,0,0,8,142,0,0,8,78,0,0,9,253,0,96,7,0,0,0,8,81,0,0,8,17,0,21,8,131,0,18,7,31,0,0,8,113,0,0,8,49,0,0,9,195,0,16,7,10,0,0,8,97,0,0,8,33,0,0,9,163,0,0,8,1,0,0,8,129,0,0,8,65,0,0,9,227,0,16,7,6,0,0,8,89,0,0,8,25,0,0,9,147,0,19,7,59,0,0,8,121,0,0,8,57,0,0,9,211,0,17,7,17,0,0,8,105,0,0,8,41,0,0,9,179,0,0,8,9,0,0,8,137,0,0,8,73,0,0,9,243,0,16,7,4,0,0,8,85,0,0,8,21,0,16,8,2,1,19,7,43,0,0,8,117,0,0,8,53,0,0,9,203,0,17,7,13,0,0,8,101,0,0,8,37,0,0,9,171,0,0,8,5,0,0,8,133,0,0,8,69,0,0,9,235,0,16,7,8,0,0,8,93,0,0,8,29,0,0,9,155,0,20,7,83,0,0,8,125,0,0,8,61,0,0,9,219,0,18,7,23,0,0,8,109,0,0,8,45,0,0,9,187,0,0,8,13,0,0,8,141,0,0,8,77,0,0,9,251,0,16,7,3,0,0,8,83,0,0,8,19,0,21,8,195,0,19,7,35,0,0,8,115,0,0,8,51,0,0,9,199,0,17,7,11,0,0,8,99,0,0,8,35,0,0,9,167,0,0,8,3,0,0,8,131,0,0,8,67,0,0,9,231,0,16,7,7,0,0,8,91,0,0,8,27,0,0,9,151,0,20,7,67,0,0,8,123,0,0,8,59,0,0,9,215,0,18,7,19,0,0,8,107,0,0,8,43,0,0,9,183,0,0,8,11,0,0,8,139,0,0,8,75,0,0,9,247,0,16,7,5,0,0,8,87,0])
.concat([0,8,23,0,64,8,0,0,19,7,51,0,0,8,119,0,0,8,55,0,0,9,207,0,17,7,15,0,0,8,103,0,0,8,39,0,0,9,175,0,0,8,7,0,0,8,135,0,0,8,71,0,0,9,239,0,16,7,9,0,0,8,95,0,0,8,31,0,0,9,159,0,20,7,99,0,0,8,127,0,0,8,63,0,0,9,223,0,18,7,27,0,0,8,111,0,0,8,47,0,0,9,191,0,0,8,15,0,0,8,143,0,0,8,79,0,0,9,255,0,16,5,1,0,23,5,1,1,19,5,17,0,27,5,1,16,17,5,5,0,25,5,1,4,21,5,65,0,29,5,1,64,16,5,3,0,24,5,1,2,20,5,33,0,28,5,1,32,18,5,9,0,26,5,1,8,22,5,129,0,64,5,0,0,16,5,2,0,23,5,129,1,19,5,25,0,27,5,1,24,17,5,7,0,25,5,1,6,21,5,97,0,29,5,1,96,16,5,4,0,24,5,1,3,20,5,49,0,28,5,1,48,18,5,13,0,26,5,1,12,22,5,193,0,64,5,0,0,176,150,7,0,168,95,1,0,120,53,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,3,0,0,0,4,0,0,0,4,0,0,0,5,0,0,0,5,0,0,0,6,0,0,0,6,0,0,0,7,0,0,0,7,0,0,0,8,0,0,0,8,0,0,0,9,0,0,0,9,0,0,0,10,0,0,0,10,0,0,0,11,0,0,0,11,0,0,0,12,0,0,0,12,0,0,0,13,0,0,0,13,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,3,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,11,11,11,10,10,10,10,9,9,9,9,8,8,8,8,7,7,7,7,6,6,6,6,5,5,5,5,4,4,4,4,3,3,3,3,2,2,2,2,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,13,13,13,13,12,12,12,12,11,11,11,11,10,10,10,10,9,9,9,9,8,8,8,8,7,7,7,7,6,6,6,6,5,5,5,5,4,4,4,4,3,3,3,3,2,2,2,2,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,12,12,12,11,11,11,11,10,10,10,10,9,9,9,9,8,8,8,8,7,7,7,7,6,6,6,6,5,5,5,5,4,4,4,4,3,3,3,3,2,2,2,2,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,144,144,144,144,144,144,144,144,144,144,144,144,144,144,144,144,144,144,144,144,144,144,144,144,144,144,144,144,144,144,144,144,144,0,0,0,0,16,16,0,8,16,24,0,8,16,24,0,8,16,24,0,8,16,24,0,8,16,24,0,8,16,24,0,8,16,24,0,8,16,24,0,8,16,24,0,8,16,24,32,40,48,56,64,72,80,88,96,104,112,120,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,144,144,144,144,144,144,144,144,144,144,144,144,144,144,144,144,144,144,144,144,144,144,144,144,144,144,144,144,144,144,144,144,0,8,16,24,0,8,16,24,0,8,16,24,0,8,16,24,0,8,16,24,0,8,16,24,0,8,16,24,0,8,16,24,0,8,16,24,0,8,16,24,0,8,16,24,0,8,16,24,32,40,48,56,64,72,80,88,96,104,112,120,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,112,0,8,16,24,0,8,16,24,0,8,16,24,0,8,16,24,0,8,16,24,0,8,16,24,0,8,16,24,0,8,16,24,0,8,16,24,0,8,16,24,0,8,16,24,0,8,16,24,0,8,16,24,32,40,48,56,64,72,80,88,96,96,96,96,96,96,96,96,96,96,96,96,96,96,96,96,96,96,96,96,0,1,0,1,0,1,0,1,0,1,0,1,1,1,0,1,0,1,1,1,0,1,1,1,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,1,1,1,2,1,2,1,2,1,2,1,2,1,2,2,2,1,2,2,2,2,2,2,2,2,2,2,2,2,2,2,4,2,2,2,4,2,4,2,4,2,4,2,4,2,4,4,4,2,4,4,4,4,4,4,4,4,4,4,4,4,4,4,8,4,4,4,8,4,8,4,8,4,8,4,8,4,8,8,8,4,8,8,8,8,8,8,8,8,8,8,8,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,0,1,0,1,0,1,0,1,0,1,0,1,1,1,0,1,0,1,1,1,0,1,1,1,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,1,1,1,2,1,2,1,2,1,2,1,2,1,2,2,2,1,2,2,2,2,2,2,2,2,2,2,2,2,2,2,4,2,2,2,4,2,4,2,4,2,4,2,4,2,4,4,4,2,4,4,4,4,4,4,4,4,4,4,4,8,8,8,8,8,8,8,8,0,0,0,0,0,0,0,0,31,81,132,144,61,9,13,144,144,87,144,144,144,50,17,144,144,156,144,144,75,144,144,3,144,144,144,137,176,144,144,144,144,187,24,190,83,33,85,124,144,144,71,88,246,144,144,178,6,144,43,144,47,11,252,145,144,144,250,129,131,64,56,144,144,144,73,133,209,245,7,226,94,30,144,4,144,144,144,177,199,144,150,242,182,210,195,144,135,186,203,136,144,185,208,181,154,128,162,114,144,180,144,170,38,125,82,51,46,188,8,121,72,144,118,54,2,144,91,18,139,231,144,144,144,171,144,79,144,144,168,229,57,14,169,144,144,20,144,255,127,144,144,39,144,1,144,144,230,138,211,144,144,142,86,165,146,144,144,249,34,144,95,144,144,161,144,116,184,144,70,5,235,207,191,93,36,144,157,144,144,144,144,144,89,141,60,248,197,144,243,78,144,144,80,198,233,254,10,144,153,134,144,144,175,140,66,247,144,65,144,163,144,58,42,67,144,179,232,144,196,53,120,37,117,144,183,144,35,144,144,143,144,144,44,144,119,126,144,15,12,160,189,144,144,45,41,234,144,59,115,144,251,32,144,90,0,0,0,0,128,1,0,0,244,1,0,0,96,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,2,2,2,2,2,3,3,3,4,4,4,5,5,6,6,7,8,8,8,8,1,1,1,1,2,2,2,2,2,3,3,3,4,4,4,5,5,6,6,7,8,8,9,10,11,12,13,14,16,16,16,16,2,2,2,2,2,3,3,3,4,4,4,5,5,6,6,7,8,8,9,10,11,12,13,14,16,17,19,20,22,22,22,22,144,209,144,144,144,121,46,144,144,144,90,15,144,144,67,144,144,144,232,80,144,144,144,160,93,34,144,144,178,58,144,144,246,138,65,144,144,129,144,144,144,144,43,88,144,144,144,198,144,144,185,144,144,42,144,60,144,128,38,144,176,144,71,144,144,144,10,85,144,144,144,136,144,144,135,144,144,180,12,144,115,83,144,144,59,31,144,144,144,144,144,144,144,144,144,144,1,144,144,144,144,30,144,144,195,144,163,116,144,50,66,117,252,144,184,144,51,144,94,144,144,170,144,144,4,144,156,186,144,144,36,137,144,144,234,144,35,144,144,144,187,144,144,199,144,142,144,82,144,24,144,114,144,144,144,144,182,144,144,144,250,144,144,144,144,144,144,144,177,144,144,144,144,87,120,162,144,61,81,144,144,191,70,44,144,144,251,144,144,144,144,56,86,144,207,144,8,144,144,144,91,7,144,144,144,32,157,144,3,144,144,144,144,144,188,134,89,144,2,144,255,210,139,144,144,208,144,144,144,144,144,233,6,144,95,243,144,181,144,144,235,144,144,144,144,144,131,144,54,144,144,144,144,189,254,144,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,150,48,7,119,44,97,14,238,186,81,9,153,25,196,109,7,143,244,106,112,53,165,99,233,163,149,100,158,50,136,219,14,164,184,220,121,30,233,213,224,136,217,210,151,43,76,182,9,189,124,177,126,7,45,184,231,145,29,191,144,100,16,183,29,242,32,176,106,72,113,185,243,222,65,190,132,125,212,218,26,235,228,221,109,81,181,212,244,199,133,211,131,86,152,108,19,192,168,107,100,122,249,98,253,236,201,101,138,79,92,1,20,217,108,6,99,99,61,15,250,245,13,8,141,200,32,110,59,94,16,105,76,228,65,96,213,114,113,103,162,209,228,3,60,71,212,4,75,253,133,13,210,107,181,10,165,250,168,181,53,108,152,178,66,214,201,187,219,64,249,188,172,227,108,216,50,117,92,223,69,207,13,214,220,89,61,209,171,172,48,217,38,58,0,222,81,128,81,215,200,22,97,208,191,181,244,180,33,35,196,179,86,153,149,186,207,15,165,189,184,158,184,2,40,8,136,5,95,178,217,12,198,36,233,11,177,135,124,111,47,17,76,104,88,171,29,97,193,61,45,102,182,144,65,220,118,6,113,219,1,188,32,210,152,42,16,213,239,137,133,177,113,31,181,182,6,165,228,191,159,51,212,184,232,162,201,7,120,52,249,0,15,142,168,9,150,24,152,14,225,187,13,106,127,45,61,109,8,151,108,100,145,1,92,99,230,244,81,107,107,98,97,108,28,216,48,101,133,78,0,98,242,237,149,6,108,123,165,1,27,193,244,8,130,87,196,15,245,198,217,176,101,80,233,183,18,234,184,190,139,124,136,185,252,223,29,221,98,73,45,218,21,243,124,211,140,101,76,212,251,88,97,178,77,206,81,181,58,116,0,188,163,226,48,187,212,65,165,223,74,215,149,216,61,109,196,209,164,251,244,214,211,106,233,105,67,252,217,110,52,70,136,103,173,208,184,96,218,115,45,4,68,229,29,3,51,95,76,10,170,201,124,13,221,60,113,5,80,170,65,2,39,16,16,11,190,134,32,12,201,37,181,104,87,179,133,111,32,9,212,102,185,159,228,97,206,14,249,222,94,152,201,217,41,34,152,208,176,180,168,215,199,23,61,179,89,129,13,180,46,59,92,189,183,173,108,186,192,32,131,184,237,182,179,191,154,12,226,182,3,154,210,177,116,57,71,213,234,175,119,210,157,21,38,219,4,131,22,220,115,18,11,99,227,132,59,100,148,62,106,109,13,168,90,106,122,11,207,14,228,157,255,9,147,39,174,0,10,177,158,7,125,68,147,15,240,210,163,8,135,104,242,1,30,254,194,6,105,93,87,98,247,203,103,101,128,113,54,108,25,231,6,107,110,118,27,212,254,224,43,211,137,90,122,218,16,204,74,221,103,111,223,185,249,249,239,190,142,67,190,183,23,213,142,176,96,232,163,214,214,126,147,209,161,196,194,216,56,82,242,223,79,241,103,187,209,103,87,188,166,221,6,181,63,75,54,178,72,218,43,13,216,76,27,10,175,246,74,3,54,96,122,4,65,195,239,96,223,85,223,103,168,239,142,110,49,121,190,105,70,140,179,97,203,26,131,102,188,160,210,111,37,54,226,104,82,149,119,12,204,3,71,11,187,185,22,2,34,47,38,5,85,190,59,186,197,40,11,189,178,146,90,180,43,4,106,179,92,167,255,215,194,49,207,208,181,139,158,217,44,29,174,222,91,176,194,100,155,38,242,99,236,156,163,106,117,10,147,109,2,169,6,9,156,63,54,14,235,133,103,7,114,19,87,0,5,130,74,191,149,20,122,184,226,174,43,177,123,56,27,182,12,155,142,210,146,13,190,213,229,183,239,220,124,33,223,219,11,212,210,211,134,66,226,212,241,248,179,221,104,110,131,218,31,205,22,190,129,91,38,185,246,225,119,176,111,119,71,183,24,230,90,8,136,112,106,15,255,202,59,6,102,92,11,1,17,255,158,101,143,105,174,98,248,211,255,107,97,69,207,108,22,120,226,10,160,238,210,13,215,84,131,4,78,194,179,3,57,97,38,103,167,247,22,96,208,77,71,105,73,219,119,110,62,74,106,209,174,220,90,214,217,102,11,223,64,240,59,216,55,83,174,188,169,197,158,187,222,127,207,178,71,233,255,181,48,28,242,189,189,138,194,186,202,48,147,179,83,166,163,180,36,5,54,208,186,147,6,215,205,41,87,222,84,191,103,217,35,46,122,102,179,184,74,97,196,2,27,104,93,148,43,111,42,55,190,11,180,161,142,12,195,27,223,5,90,141,239,2,45,0,0,0,0,65,49,27,25,130,98,54,50,195,83,45,43,4,197,108,100,69,244,119,125,134,167,90,86,199,150,65,79,8,138,217,200,73,187,194,209,138,232,239,250,203,217,244,227,12,79,181,172,77,126,174,181,142,45,131,158,207,28,152,135,81,18,194,74,16,35,217,83,211,112,244,120,146,65,239,97,85,215,174,46,20,230,181,55,215,181,152,28,150,132,131,5,89,152,27,130,24,169,0,155,219,250,45,176,154,203,54,169,93,93,119,230,28,108,108,255,223,63,65,212,158,14,90,205,162,36,132,149,227,21,159,140,32,70,178,167,97,119,169,190,166,225,232,241,231,208,243,232,36,131,222,195,101,178,197,218,170,174,93,93,235,159,70,68,40,204,107,111,105,253,112,118,174,107,49,57,239,90,42,32,44,9,7,11,109,56,28,18,243,54,70,223,178,7,93,198,113,84,112,237,48,101,107,244,247,243,42,187,182,194,49,162,117,145,28,137,52,160,7,144,251,188,159,23,186,141,132,14,121,222,169,37,56,239,178,60,255,121,243,115,190,72,232,106,125,27,197,65,60,42,222,88,5,79,121,240,68,126,98,233,135,45,79,194,198,28,84,219,1,138,21,148,64,187,14,141,131,232,35,166,194,217,56,191,13,197,160,56,76,244,187,33,143,167,150,10,206,150,141,19,9,0,204,92,72,49,215,69,139,98,250,110,202,83,225,119,84,93,187,186,21,108,160,163,214,63,141,136,151,14,150,145,80,152,215,222,17,169,204,199,210,250,225,236,147,203,250,245,92,215,98,114,29,230,121,107,222,181,84,64,159,132,79,89,88,18,14,22,25,35,21,15,218,112,56,36,155,65,35,61,167,107,253,101,230,90,230,124,37,9,203,87,100,56,208,78,163,174,145,1,226,159,138,24,33,204,167,51,96,253,188,42,175,225,36,173,238,208,63,180,45,131,18,159,108,178,9,134,171,36,72,201,234,21,83,208,41,70,126,251,104,119,101,226,246,121,63,47,183,72,36,54,116,27,9,29,53,42,18,4,242,188,83,75,179,141,72,82,112,222,101,121,49,239,126,96,254,243,230,231,191,194,253,254,124,145,208,213,61,160,203,204,250,54,138,131,187,7,145,154,120,84,188,177,57,101,167,168,75,152,131,59,10,169,152,34,201,250,181,9,136,203,174,16,79,93,239,95,14,108,244,70,205,63,217,109,140,14,194,116,67,18,90,243,2,35,65,234,193,112,108,193,128,65,119,216,71,215,54,151,6,230,45,142,197,181,0,165,132,132,27,188,26,138,65,113,91,187,90,104,152,232,119,67,217,217,108,90,30,79,45,21,95,126,54,12,156,45,27,39,221,28,0,62,18,0,152,185,83,49,131,160,144,98,174,139,209,83,181,146,22,197,244,221,87,244,239,196,148,167,194,239,213,150,217,246,233,188,7,174,168,141,28,183,107,222,49,156,42,239,42,133,237,121,107,202,172,72,112,211,111,27,93,248,46,42,70,225,225,54,222,102,160,7,197,127,99,84,232,84,34,101,243,77,229,243,178,2,164,194,169,27,103,145,132,48,38,160,159,41,184,174,197,228,249,159,222,253,58,204,243,214,123,253,232,207,188,107,169,128,253,90,178,153,62,9,159,178,127,56,132,171,176,36,28,44,241,21,7,53,50,70,42,30,115,119,49,7,180,225,112,72,245,208,107,81,54,131,70,122,119,178,93,99,78,215,250,203,15,230,225,210,204,181,204,249,141,132,215,224,74,18,150,175,11,35,141,182,200,112,160,157,137,65,187,132,70,93,35,3,7,108,56,26,196,63,21,49,133,14,14,40,66,152,79,103,3,169,84,126,192,250,121,85,129,203,98,76,31,197,56,129,94,244,35,152,157,167,14,179,220,150,21,170,27,0,84,229,90,49,79,252,153,98,98,215,216,83,121,206,23,79,225,73,86,126,250,80,149,45,215,123,212,28,204,98,19,138,141,45,82,187,150,52,145,232,187,31,208,217,160,6,236,243,126,94,173,194,101,71,110,145,72,108,47,160,83,117,232,54,18,58,169,7,9,35,106,84,36,8,43,101,63,17,228,121,167,150,165,72,188,143,102,27,145,164,39,42,138,189,224,188,203,242,161,141,208,235,98,222,253,192,35,239,230,217,189,225,188,20,252,208,167,13,63,131,138,38,126,178,145,63,185,36,208,112,248,21,203,105,59,70,230,66,122,119,253,91,181,107,101,220,244,90,126,197,55,9,83,238,118,56,72,247,177,174,9,184,240,159,18,161,51,204,63,138,114,253,36,147,0,0,0,0,55,106,194,1,110,212,132,3,89,190,70,2,220,168,9,7,235,194,203,6,178,124,141,4,133,22,79,5,184,81,19,14,143,59,209,15,214,133,151,13,225,239,85,12,100,249,26,9,83,147,216,8,10,45,158,10,61,71,92,11,112,163,38,28,71,201,228,29,30,119,162,31,41,29,96,30,172,11,47,27,155,97,237,26,194,223,171,24,245,181,105,25,200,242,53,18,255,152,247,19,166,38,177,17,145,76,115,16,20,90,60,21,35,48,254,20,122,142,184,22,77,228,122,23,224,70,77,56,215,44,143,57,142,146,201,59,185,248,11,58,60,238,68,63,11,132,134,62,82,58,192,60,101,80,2,61,88,23,94,54,111,125,156,55,54,195,218,53,1,169,24,52,132,191,87,49,179,213,149,48,234,107,211,50,221,1,17,51,144,229,107,36,167,143,169,37,254,49,239,39,201,91,45,38,76,77,98,35,123,39,160,34,34,153,230,32,21,243,36,33,40,180,120,42,31,222,186,43,70,96,252,41,113,10,62,40,244,28,113,45,195,118,179,44,154,200,245,46,173,162,55,47,192,141,154,112,247,231,88,113,174,89,30,115,153,51,220,114,28,37,147,119,43,79,81,118,114,241,23,116,69,155,213,117,120,220,137,126,79,182,75,127,22,8,13,125,33,98,207,124,164,116,128,121,147,30,66,120,202,160,4,122,253,202,198,123,176,46,188,108,135,68,126,109,222,250,56,111,233,144,250,110,108,134,181,107,91,236,119,106,2,82,49,104,53,56,243,105,8,127,175,98,63,21,109,99,102,171,43,97,81,193,233,96,212,215,166,101,227,189,100,100,186,3,34,102,141,105,224,103,32,203,215,72,23,161,21,73,78,31,83,75,121,117,145,74,252,99,222,79,203,9,28,78,146,183,90,76,165,221,152,77,152,154,196,70,175,240,6,71,246,78,64,69,193,36,130,68,68,50,205,65,115,88,15,64,42,230,73,66,29,140,139,67,80,104,241,84,103,2,51,85,62,188,117,87,9,214,183,86,140,192,248,83,187,170,58,82,226,20,124,80,213,126,190,81,232,57,226,90,223,83,32,91,134,237,102,89,177,135,164,88,52,145,235,93,3,251,41,92,90,69,111,94,109,47,173,95,128,27,53,225,183,113,247,224,238,207,177,226,217,165,115,227,92,179,60,230,107,217,254,231,50,103,184,229,5,13,122,228,56,74,38,239,15,32,228,238,86,158,162,236,97,244,96,237,228,226,47,232,211,136,237,233,138,54,171,235,189,92,105,234,240,184,19,253,199,210,209,252,158,108,151,254,169,6,85,255,44,16,26,250,27,122,216,251,66,196,158,249,117,174,92,248,72,233,0,243,127,131,194,242,38,61,132,240,17,87,70,241,148,65,9,244,163,43,203,245,250,149,141,247,205,255,79,246,96,93,120,217,87,55,186,216,14,137,252,218,57,227,62,219,188,245,113,222,139,159,179,223,210,33,245,221,229,75,55,220,216,12,107,215,239,102,169,214,182,216,239,212,129,178,45,213,4,164,98,208,51,206,160,209,106,112,230,211,93,26,36,210,16,254,94,197,39,148,156,196,126,42,218,198,73,64,24,199,204,86,87,194,251,60,149,195,162,130,211,193,149,232,17,192,168,175,77,203,159,197,143,202,198,123,201,200,241,17,11,201,116,7,68,204,67,109,134,205,26,211,192,207,45,185,2,206,64,150,175,145,119,252,109,144,46,66,43,146,25,40,233,147,156,62,166,150,171,84,100,151,242,234,34,149,197,128,224,148,248,199,188,159,207,173,126,158,150,19,56,156,161,121,250,157,36,111,181,152,19,5,119,153,74,187,49,155,125,209,243,154,48,53,137,141,7,95,75,140,94,225,13,142,105,139,207,143,236,157,128,138,219,247,66,139,130,73,4,137,181,35,198,136,136,100,154,131,191,14,88,130,230,176,30,128,209,218,220,129,84,204,147,132,99,166,81,133,58,24,23,135,13,114,213,134,160,208,226,169,151,186,32,168,206,4,102,170,249,110,164,171,124,120,235,174,75,18,41,175,18,172,111,173,37,198,173,172,24,129,241,167,47,235,51,166,118,85,117,164,65,63,183,165,196,41,248,160,243,67,58,161,170,253,124,163,157,151,190,162,208,115,196,181,231,25,6,180,190,167,64,182,137,205,130,183,12,219,205,178,59,177,15,179,98,15,73,177,85,101,139,176,104,34,215,187,95,72,21,186,6,246,83,184,49,156,145,185,180,138,222,188,131,224,28,189,218,94,90,191,237,52,152,190,0,0,0,0,101,103,188,184,139,200,9,170,238,175,181,18,87,151,98,143,50,240,222,55,220,95,107,37,185,56,215,157,239,40,180,197,138,79,8,125,100,224,189,111,1,135,1,215,184,191,214,74,221,216,106,242,51,119,223,224,86,16,99,88,159,87,25,80,250,48,165,232,20,159,16,250,113,248,172,66,200,192,123,223,173,167,199,103,67,8,114,117,38,111,206,205,112,127,173,149,21,24,17,45,251,183,164,63,158,208,24,135,39,232,207,26,66,143,115,162,172,32,198,176,201,71,122,8,62,175,50,160,91,200,142,24,181,103,59,10,208,0,135,178,105,56,80,47,12,95,236,151,226,240,89,133,135,151,229,61,209,135,134,101,180,224,58,221,90,79,143,207,63,40,51,119,134,16,228,234,227,119,88,82,13,216,237,64,104,191,81,248,161,248,43,240,196,159,151,72,42,48,34,90,79,87,158,226,246,111,73,127,147,8,245,199,125,167,64,213,24,192,252,109,78,208,159,53,43,183,35,141,197,24,150,159,160,127,42,39,25,71,253,186,124,32,65,2,146,143,244,16,247,232,72,168,61,88,20,155,88,63,168,35,182,144,29,49,211,247,161,137,106,207,118,20,15,168,202,172,225,7,127,190,132,96,195,6,210,112,160,94,183,23,28,230,89,184,169,244,60,223,21,76,133,231,194,209,224,128,126,105,14,47,203,123,107,72,119,195,162,15,13,203,199,104,177,115,41,199,4,97,76,160,184,217,245,152,111,68,144,255,211,252,126,80,102,238,27,55,218,86,77,39,185,14,40,64,5,182,198,239,176,164,163,136,12,28,26,176,219,129,127,215,103,57,145,120,210,43,244,31,110,147,3,247,38,59,102,144,154,131,136,63,47,145,237,88,147,41,84,96,68,180,49,7,248,12,223,168,77,30,186,207,241,166,236,223,146,254,137,184,46,70,103,23,155,84,2,112,39,236,187,72,240,113,222,47,76,201,48,128,249,219,85,231,69,99,156,160,63,107,249,199,131,211,23,104,54,193,114,15,138,121,203,55,93,228,174,80,225,92,64,255,84,78,37,152,232,246,115,136,139,174,22,239,55,22,248,64,130,4,157,39,62,188,36,31,233,33,65,120,85,153,175,215,224,139,202,176,92,51,59,182,89,237,94,209,229,85,176,126,80,71,213,25,236,255,108,33,59,98,9,70,135,218,231,233,50,200,130,142,142,112,212,158,237,40,177,249,81,144,95,86,228,130,58,49,88,58,131,9,143,167,230,110,51,31,8,193,134,13,109,166,58,181,164,225,64,189,193,134,252,5,47,41,73,23,74,78,245,175,243,118,34,50,150,17,158,138,120,190,43,152,29,217,151,32,75,201,244,120,46,174,72,192,192,1,253,210,165,102,65,106,28,94,150,247,121,57,42,79,151,150,159,93,242,241,35,229,5,25,107,77,96,126,215,245,142,209,98,231,235,182,222,95,82,142,9,194,55,233,181,122,217,70,0,104,188,33,188,208,234,49,223,136,143,86,99,48,97,249,214,34,4,158,106,154,189,166,189,7,216,193,1,191,54,110,180,173,83,9,8,21,154,78,114,29,255,41,206,165,17,134,123,183,116,225,199,15,205,217,16,146,168,190,172,42,70,17,25,56,35,118,165,128,117,102,198,216,16,1,122,96,254,174,207,114,155,201,115,202,34,241,164,87,71,150,24,239,169,57,173,253,204,94,17,69,6,238,77,118,99,137,241,206,141,38,68,220,232,65,248,100,81,121,47,249,52,30,147,65,218,177,38,83,191,214,154,235,233,198,249,179,140,161,69,11,98,14,240,25,7,105,76,161,190,81,155,60,219,54,39,132,53,153,146,150,80,254,46,46,153,185,84,38,252,222,232,158,18,113,93,140,119,22,225,52,206,46,54,169,171,73,138,17,69,230,63,3,32,129,131,187,118,145,224,227,19,246,92,91,253,89,233,73,152,62,85,241,33,6,130,108,68,97,62,212,170,206,139,198,207,169,55,126,56,65,127,214,93,38,195,110,179,137,118,124,214,238,202,196,111,214,29,89,10,177,161,225,228,30,20,243,129,121,168,75,215,105,203,19,178,14,119,171,92,161,194,185,57,198,126,1,128,254,169,156,229,153,21,36,11,54,160,54,110,81,28,142,167,22,102,134,194,113,218,62,44,222,111,44,73,185,211,148,240,129,4,9,149,230,184,177,123,73,13,163,30,46,177,27,72,62,210,67,45,89,110,251,195,246,219,233,166,145,103,81,31,169,176,204,122,206,12,116,148,97,185,102,241,6,5,222,0,0,0,0,119,7,48,150,238,14,97,44,153,9,81,186,7,109,196,25,112,106,244,143,233,99,165,53,158,100,149,163,14,219,136,50,121,220,184,164,224,213,233,30,151,210,217,136,9,182,76,43,126,177,124,189,231,184,45,7,144,191,29,145,29,183,16,100,106,176,32,242,243,185,113,72,132,190,65,222,26,218,212,125,109,221,228,235,244,212,181,81,131,211,133,199,19,108,152,86,100,107,168,192,253,98,249,122,138,101,201,236,20,1,92,79,99,6,108,217,250,15,61,99,141,8,13,245,59,110,32,200,76,105,16,94,213,96,65,228,162,103,113,114,60,3,228,209,75,4,212,71,210,13,133,253,165,10,181,107,53,181,168,250,66,178,152,108,219,187,201,214,172,188,249,64,50,216,108,227,69,223,92,117,220,214,13,207,171,209,61,89,38,217,48,172,81,222,0,58,200,215,81,128,191,208,97,22,33,180,244,181,86,179,196,35,207,186,149,153,184,189,165,15,40,2,184,158,95,5,136,8,198,12,217,178,177,11,233,36,47,111,124,135,88,104,76,17,193,97,29,171,182,102,45,61,118,220,65,144,1,219,113,6,152,210,32,188,239,213,16,42,113,177,133,137,6,182,181,31,159,191,228,165,232,184,212,51,120,7,201,162,15,0,249,52,150,9,168,142,225,14,152,24,127,106,13,187,8,109,61,45,145,100,108,151,230,99,92,1,107,107,81,244,28,108,97,98,133,101,48,216,242,98,0,78,108,6,149,237,27,1,165,123,130,8,244,193,245,15,196,87,101,176,217,198,18,183,233,80,139,190,184,234,252,185,136,124,98,221,29,223,21,218,45,73,140,211,124,243,251,212,76,101,77,178,97,88,58,181,81,206,163,188,0,116,212,187,48,226,74,223,165,65,61,216,149,215,164,209,196,109,211,214,244,251,67,105,233,106,52,110,217,252,173,103,136,70,218,96,184,208,68,4,45,115,51,3,29,229,170,10,76,95,221,13,124,201,80,5,113,60,39,2,65,170,190,11,16,16,201,12,32,134,87,104,181,37,32,111,133,179,185,102,212,9,206,97,228,159,94,222,249,14,41,217,201,152,176,208,152,34,199,215,168,180,89,179,61,23,46,180,13,129,183,189,92,59,192,186,108,173,237,184,131,32,154,191,179,182,3,182,226,12,116,177,210,154,234,213,71,57,157,210,119,175,4,219,38,21,115,220,22,131,227,99,11,18,148,100,59,132,13,109,106,62,122,106,90,168,228,14,207,11,147,9,255,157,10,0,174,39,125,7,158,177,240,15,147,68,135,8,163,210,30,1,242,104,105,6,194,254,247,98,87,93,128,101,103,203,25,108,54,113,110,107,6,231,254,212,27,118,137,211,43,224,16,218,122,90,103,221,74,204,249,185,223,111,142,190,239,249,23,183,190,67,96,176,142,213,214,214,163,232,161,209,147,126,56,216,194,196,79,223,242,82,209,187,103,241,166,188,87,103,63,181,6,221,72,178,54,75,216,13,43,218,175,10,27,76,54,3,74,246,65,4,122,96,223,96,239,195,168,103,223,85,49,110,142,239,70,105,190,121,203,97,179,140,188,102,131,26,37,111,210,160,82,104,226,54,204,12,119,149,187,11,71,3,34,2,22,185,85,5,38,47,197,186,59,190,178,189,11,40,43,180,90,146,92,179,106,4,194,215,255,167,181,208,207,49,44,217,158,139,91,222,174,29,155,100,194,176,236,99,242,38,117,106,163,156,2,109,147,10,156,9,6,169,235,14,54,63,114,7,103,133,5,0,87,19,149,191,74,130,226,184,122,20,123,177,43,174,12,182,27,56,146,210,142,155,229,213,190,13,124,220,239,183,11,219,223,33,134,211,210,212,241,212,226,66,104,221,179,248,31,218,131,110,129,190,22,205,246,185,38,91,111,176,119,225,24,183,71,119,136,8,90,230,255,15,106,112,102,6,59,202,17,1,11,92,143,101,158,255,248,98,174,105,97,107,255,211,22,108,207,69,160,10,226,120,215,13,210,238,78,4,131,84,57,3,179,194,167,103,38,97,208,96,22,247,73,105,71,77,62,110,119,219,174,209,106,74,217,214,90,220,64,223,11,102,55,216,59,240,169,188,174,83,222,187,158,197,71,178,207,127,48,181,255,233,189,189,242,28,202,186,194,138,83,179,147,48,36,180,163,166,186,208,54,5,205,215,6,147,84,222,87,41,35,217,103,191,179,102,122,46,196,97,74,184,93,104,27,2,42,111,43,148,180,11,190,55,195,12,142,161,90,5,223,27,45,2,239,141,0,0,0,0,25,27,49,65,50,54,98,130,43,45,83,195,100,108,197,4,125,119,244,69,86,90,167,134,79,65,150,199,200,217,138,8,209,194,187,73,250,239,232,138,227,244,217,203,172,181,79,12,181,174,126,77,158,131,45,142,135,152,28,207,74,194,18,81,83,217,35,16,120,244,112,211,97,239,65,146,46,174,215,85,55,181,230,20,28,152,181,215,5,131,132,150,130,27,152,89,155,0,169,24,176,45,250,219,169,54,203,154,230,119,93,93,255,108,108,28,212,65,63,223,205,90,14,158,149,132,36,162,140,159,21,227,167,178,70,32,190,169,119,97,241,232,225,166,232,243,208,231,195,222,131,36,218,197,178,101,93,93,174,170,68,70,159,235,111,107,204,40,118,112,253,105,57,49,107,174,32,42,90,239,11,7,9,44,18,28,56,109,223,70,54,243,198,93,7,178,237,112,84,113,244,107,101,48,187,42,243,247,162,49,194,182,137,28,145,117,144,7,160,52,23,159,188,251,14,132,141,186,37,169,222,121,60,178,239,56,115,243,121,255,106,232,72,190,65,197,27,125,88,222,42,60,240,121,79,5,233,98,126,68,194,79,45,135,219,84,28,198,148,21,138,1,141,14,187,64,166,35,232,131,191,56,217,194,56,160,197,13,33,187,244,76,10,150,167,143,19,141,150,206,92,204,0,9,69,215,49,72,110,250,98,139,119,225,83,202,186,187,93,84,163,160,108,21,136,141,63,214,145,150,14,151,222,215,152,80,199,204,169,17,236,225,250,210,245,250,203,147,114,98,215,92,107,121,230,29,64,84,181,222,89,79,132,159,22,14,18,88,15,21,35,25,36,56,112,218,61,35,65,155,101,253,107,167,124,230,90,230,87,203,9,37,78,208,56,100,1,145,174,163,24,138,159,226,51,167,204,33,42,188,253,96,173,36,225,175,180,63,208,238,159,18,131,45,134,9,178,108,201,72,36,171,208,83,21,234,251,126,70,41,226,101,119,104,47,63,121,246,54,36,72,183,29,9,27,116,4,18,42,53,75,83,188,242,82,72,141,179,121,101,222,112,96,126,239,49,231,230,243,254,254,253,194,191,213,208,145,124,204,203,160,61,131,138,54,250,154,145,7,187,177,188,84,120,168,167,101,57,59,131,152,75,34,152,169,10,9,181,250,201,16,174,203,136,95,239,93,79,70,244,108,14,109,217,63,205,116,194,14,140,243,90,18,67,234,65,35,2,193,108,112,193,216,119,65,128,151,54,215,71,142,45,230,6,165,0,181,197,188,27,132,132,113,65,138,26,104,90,187,91,67,119,232,152,90,108,217,217,21,45,79,30,12,54,126,95,39,27,45,156,62,0,28,221,185,152,0,18,160,131,49,83,139,174,98,144,146,181,83,209,221,244,197,22,196,239,244,87,239,194,167,148,246,217,150,213,174,7,188,233,183,28,141,168,156,49,222,107,133,42,239,42,202,107,121,237,211,112,72,172,248,93,27,111,225,70,42,46,102,222,54,225,127,197,7,160,84,232,84,99,77,243,101,34,2,178,243,229,27,169,194,164,48,132,145,103,41,159,160,38,228,197,174,184,253,222,159,249,214,243,204,58,207,232,253,123,128,169,107,188,153,178,90,253,178,159,9,62,171,132,56,127,44,28,36,176,53,7,21,241,30,42,70,50,7,49,119,115,72,112,225,180,81,107,208,245,122,70,131,54,99,93,178,119,203,250,215,78,210,225,230,15,249,204,181,204,224,215,132,141,175,150,18,74,182,141,35,11,157,160,112,200,132,187,65,137,3,35,93,70,26,56,108,7,49,21,63,196,40,14,14,133,103,79,152,66,126,84,169,3,85,121,250,192,76,98,203,129,129,56,197,31,152,35,244,94,179,14,167,157,170,21,150,220,229,84,0,27,252,79,49,90,215,98,98,153,206,121,83,216,73,225,79,23,80,250,126,86,123,215,45,149,98,204,28,212,45,141,138,19,52,150,187,82,31,187,232,145,6,160,217,208,94,126,243,236,71,101,194,173,108,72,145,110,117,83,160,47,58,18,54,232,35,9,7,169,8,36,84,106,17,63,101,43,150,167,121,228,143,188,72,165,164,145,27,102,189,138,42,39,242,203,188,224,235,208,141,161,192,253,222,98,217,230,239,35,20,188,225,189,13,167,208,252,38,138,131,63,63,145,178,126,112,208,36,185,105,203,21,248,66,230,70,59,91,253,119,122,220,101,107,181,197,126,90,244,238,83,9,55,247,72,56,118,184,9,174,177,161,18,159,240,138,63,204,51,147,36,253,114,0,0,0,0,1,194,106,55,3,132,212,110,2,70,190,89,7,9,168,220,6,203,194,235,4,141,124,178,5,79,22,133,14,19,81,184,15,209,59,143,13,151,133,214,12,85,239,225,9,26,249,100,8,216,147,83,10,158,45,10,11,92,71,61,28,38,163,112,29,228,201,71,31,162,119,30,30,96,29,41,27,47,11,172,26,237,97,155,24,171,223,194,25,105,181,245,18,53,242,200,19,247,152,255,17,177,38,166,16,115,76,145,21,60,90,20,20,254,48,35,22,184,142,122,23,122,228,77,56,77,70,224,57,143,44,215,59,201,146,142,58,11,248,185,63,68,238,60,62,134,132,11,60,192,58,82,61,2,80,101,54,94,23,88,55,156,125,111,53,218,195,54,52,24,169,1,49,87,191,132,48,149,213,179,50,211,107,234,51,17,1,221,36,107,229,144,37,169,143,167,39,239,49,254,38,45,91,201,35,98,77,76,34,160,39,123,32,230,153,34,33,36,243,21,42,120,180,40,43,186,222,31,41,252,96,70,40,62,10,113,45,113,28,244,44,179,118,195,46,245,200,154,47,55,162,173,112,154,141,192,113,88,231,247,115,30,89,174,114,220,51,153,119,147,37,28,118,81,79,43,116,23,241,114,117,213,155,69,126,137,220,120,127,75,182,79,125,13,8,22,124,207,98,33,121,128,116,164,120,66,30,147,122,4,160,202,123,198,202,253,108,188,46,176,109,126,68,135,111,56,250,222,110,250,144,233,107,181,134,108,106,119,236,91,104,49,82,2,105,243,56,53,98,175,127,8,99,109,21,63,97,43,171,102,96,233,193,81,101,166,215,212,100,100,189,227,102,34,3,186,103,224,105,141,72,215,203,32,73,21,161,23,75,83,31,78,74,145,117,121,79,222,99,252,78,28,9,203,76,90,183,146,77,152,221,165,70,196,154,152,71,6,240,175,69,64,78,246,68,130,36,193,65,205,50,68,64,15,88,115,66,73,230,42,67,139,140,29,84,241,104,80,85,51,2,103,87,117,188,62,86,183,214,9,83,248,192,140,82,58,170,187,80,124,20,226,81,190,126,213,90,226,57,232,91,32,83,223,89,102,237,134,88,164,135,177,93,235,145,52,92,41,251,3,94,111,69,90,95,173,47,109,225,53,27,128,224,247,113,183,226,177,207,238,227,115,165,217,230,60,179,92,231,254,217,107,229,184,103,50,228,122,13,5,239,38,74,56,238,228,32,15,236,162,158,86,237,96,244,97,232,47,226,228,233,237,136,211,235,171,54,138,234,105,92,189,253,19,184,240,252,209,210,199,254,151,108,158,255,85,6,169,250,26,16,44,251,216,122,27,249,158,196,66,248,92,174,117,243,0,233,72,242,194,131,127,240,132,61,38,241,70,87,17,244,9,65,148,245,203,43,163,247,141,149,250,246,79,255,205,217,120,93,96,216,186,55,87,218,252,137,14,219,62,227,57,222,113,245,188,223,179,159,139,221,245,33,210,220,55,75,229,215,107,12,216,214,169,102,239,212,239,216,182,213,45,178,129,208,98,164,4,209,160,206,51,211,230,112,106,210,36,26,93,197,94,254,16,196,156,148,39,198,218,42,126,199,24,64,73,194,87,86,204,195,149,60,251,193,211,130,162,192,17,232,149,203,77,175,168,202,143,197,159,200,201,123,198,201,11,17,241,204,68,7,116,205,134,109,67,207,192,211,26,206,2,185,45,145,175,150,64,144,109,252,119,146,43,66,46,147,233,40,25,150,166,62,156,151,100,84,171,149,34,234,242,148,224,128,197,159,188,199,248,158,126,173,207,156,56,19,150,157,250,121,161,152,181,111,36,153,119,5,19,155,49,187,74,154,243,209,125,141,137,53,48,140,75,95,7,142,13,225,94,143,207,139,105,138,128,157,236,139,66,247,219,137,4,73,130,136,198,35,181,131,154,100,136,130,88,14,191,128,30,176,230,129,220,218,209,132,147,204,84,133,81,166,99,135,23,24,58,134,213,114,13,169,226,208,160,168,32,186,151,170,102,4,206,171,164,110,249,174,235,120,124,175,41,18,75,173,111,172,18,172,173,198,37,167,241,129,24,166,51,235,47,164,117,85,118,165,183,63,65,160,248,41,196,161,58,67,243,163,124,253,170,162,190,151,157,181,196,115,208,180,6,25,231,182,64,167,190,183,130,205,137,178,205,219,12,179,15,177,59,177,73,15,98,176,139,101,85,187,215,34,104,186,21,72,95,184,83,246,6,185,145,156,49,188,222,138,180,189,28,224,131,191,90,94,218,190,152,52,237,0,0,0,0,184,188,103,101,170,9,200,139,18,181,175,238,143,98,151,87,55,222,240,50,37,107,95,220,157,215,56,185,197,180,40,239,125,8,79,138,111,189,224,100,215,1,135,1,74,214,191,184,242,106,216,221,224,223,119,51,88,99,16,86,80,25,87,159,232,165,48,250,250,16,159,20,66,172,248,113,223,123,192,200,103,199,167,173,117,114,8,67,205,206,111,38,149,173,127,112,45,17,24,21,63,164,183,251,135,24,208,158,26,207,232,39,162,115,143,66,176,198,32,172,8,122,71,201,160,50,175,62,24,142,200,91,10,59,103,181,178,135,0,208,47,80,56,105,151,236,95,12,133,89,240,226,61,229,151,135,101,134,135,209,221,58,224,180,207,143,79,90,119,51,40,63,234,228,16,134,82,88,119,227,64,237,216,13,248,81,191,104,240,43,248,161,72,151,159,196,90,34,48,42,226,158,87,79,127,73,111,246,199,245,8,147,213,64,167,125,109,252,192,24,53,159,208,78,141,35,183,43,159,150,24,197,39,42,127,160,186,253,71,25,2,65,32,124,16,244,143,146,168,72,232,247,155,20,88,61,35,168,63,88,49,29,144,182,137,161,247,211,20,118,207,106,172,202,168,15,190,127,7,225,6,195,96,132,94,160,112,210,230,28,23,183,244,169,184,89,76,21,223,60,209,194,231,133,105,126,128,224,123,203,47,14,195,119,72,107,203,13,15,162,115,177,104,199,97,4,199,41,217,184,160,76,68,111,152,245,252,211,255,144,238,102,80,126,86,218,55,27,14,185,39,77,182,5,64,40,164,176,239,198,28,12,136,163,129,219,176,26,57,103,215,127,43,210,120,145,147,110,31,244,59,38,247,3,131,154,144,102,145,47,63,136,41,147,88,237,180,68,96,84,12,248,7,49,30,77,168,223,166,241,207,186,254,146,223,236,70,46,184,137,84,155,23,103,236,39,112,2,113,240,72,187,201,76,47,222,219,249,128,48,99,69,231,85,107,63,160,156,211,131,199,249,193,54,104,23,121,138,15,114,228,93,55,203,92,225,80,174,78,84,255,64,246,232,152,37,174,139,136,115,22,55,239,22,4,130,64,248,188,62,39,157,33,233,31,36,153,85,120,65,139,224,215,175,51,92,176,202,237,89,182,59,85,229,209,94,71,80,126,176,255,236,25,213,98,59,33,108,218,135,70,9,200,50,233,231,112,142,142,130,40,237,158,212,144,81,249,177,130,228,86,95,58,88,49,58,167,143,9,131,31,51,110,230,13,134,193,8,181,58,166,109,189,64,225,164,5,252,134,193,23,73,41,47,175,245,78,74,50,34,118,243,138,158,17,150,152,43,190,120,32,151,217,29,120,244,201,75,192,72,174,46,210,253,1,192,106,65,102,165,247,150,94,28,79,42,57,121,93,159,150,151,229,35,241,242,77,107,25,5,245,215,126,96,231,98,209,142,95,222,182,235,194,9,142,82,122,181,233,55,104,0,70,217,208,188,33,188,136,223,49,234,48,99,86,143,34,214,249,97,154,106,158,4,7,189,166,189,191,1,193,216,173,180,110,54,21,8,9,83,29,114,78,154,165,206,41,255,183,123,134,17,15,199,225,116,146,16,217,205,42,172,190,168,56,25,17,70,128,165,118,35,216,198,102,117,96,122,1,16,114,207,174,254,202,115,201,155,87,164,241,34,239,24,150,71,253,173,57,169,69,17,94,204,118,77,238,6,206,241,137,99,220,68,38,141,100,248,65,232,249,47,121,81,65,147,30,52,83,38,177,218,235,154,214,191,179,249,198,233,11,69,161,140,25,240,14,98,161,76,105,7,60,155,81,190,132,39,54,219,150,146,153,53,46,46,254,80,38,84,185,153,158,232,222,252,140,93,113,18,52,225,22,119,169,54,46,206,17,138,73,171,3,63,230,69,187,131,129,32,227,224,145,118,91,92,246,19])
.concat([73,233,89,253,241,85,62,152,108,130,6,33,212,62,97,68,198,139,206,170,126,55,169,207,214,127,65,56,110,195,38,93,124,118,137,179,196,202,238,214,89,29,214,111,225,161,177,10,243,20,30,228,75,168,121,129,19,203,105,215,171,119,14,178,185,194,161,92,1,126,198,57,156,169,254,128,36,21,153,229,54,160,54,11,142,28,81,110,134,102,22,167,62,218,113,194,44,111,222,44,148,211,185,73,9,4,129,240,177,184,230,149,163,13,73,123,27,177,46,30,67,210,62,72,251,110,89,45,233,219,246,195,81,103,145,166,204,176,169,31,116,12,206,122,102,185,97,148,222,5,6,241,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,85,0,0,0,0,0,0,0,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,118,8,0,0,4,0,4,0,8,0,4,0,68,21,0,0,4,0,5,0,16,0,8,0,68,21,0,0,4,0,6,0,32,0,32,0,68,21,0,0,4,0,4,0,16,0,16,0,182,51,0,0,8,0,16,0,32,0,32,0,182,51,0,0,8,0,16,0,128,0,128,0,182,51,0,0,8,0,32,0,128,0,0,1,182,51,0,0,32,0,128,0,2,1,0,4,182,51,0,0,32,0,2,1,2,1,0,16,182,51,0,0,88,106,2,0,2,0,0,0,0,236,3,0,3,0,0,0,8,244,1,0,5,0,0,0,192,146,1,0,4,0,0,0,192,186,141,0,128,195,141,0,64,204,141,0,0,213,141,0,192,221,141,0,128,230,141,0,64,239,141,0,0,248,141,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,144,144,121,144,157,72,144,144,144,144,46,144,144,165,114,144,70,91,177,58,195,144,53,144,144,35,144,153,144,5,144,60,59,118,17,144,144,75,144,146,144,50,93,144,247,90,156,144,38,64,137,144,144,144,144,87,144,144,144,144,144,186,83,187,66,89,47,144,119,144,144,79,191,74,203,134,98,125,144,184,144,52,144,95,144,127,248,128,160,132,18,82,144,144,144,71,144,43,136,249,144,163,131,144,117,135,144,171,235,144,254,144,144,175,208,44,209,230,144,67,162,231,133,226,73,34,41,144,124,144,144,154,144,144,185,144,20,207,51,2,144,144,144,115,144,197,144,144,144,243,246,36,144,86,211,144,9,1,144,144,3,45,27,144,245,190,144,144,251,142,33,141,11,144,144,178,252,250,198,144,232,210,144,8,10,168,120,255,144,181,144,144,199,6,24,144,144,30,126,176,14,15,144,144,12,170,85,144,144,116,61,144,144,56,39,80,144,182,94,139,7,229,57,234,189,144,129,183,144,138,13,144,88,161,169,54,144,196,144,143,140,31,81,4,242,144,179,180,233,42,144,144,144,37,144,188,16,17,18,0,8,7,9,6,10,5,11,4,12,3,13,2,14,1,15,0,0,0,0,0,2,0,0,0,124,0,0,0,156,1,0,0,128,2,0,0,80,16,0,0,240,230,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,16,66,8,32,0,0,74,41,0,0,0,0,0,0,168,175,212,87,0,0,128,248,226,232,35,0,0,0,136,170,168,138,0,0,192,164,100,82,116,0,0,132,16,0,0,0,0,0,136,8,33,132,32,8,0,130,32,132,16,34,2,0,0,144,234,42,1,0,0,0,16,242,9,1,0,0,0,0,0,0,32,2,0,0,0,240,1,0,0,0,0,0,0,0,32,0,0,16,34,68,136,16,1,0,192,197,88,99,116,0,0,128,24,66,8,113,0,0,192,69,200,68,248,0,0,192,69,200,96,116,0,0,0,49,149,62,66,0,0,224,135,240,96,116,0,0,128,137,240,98,116,0,0,224,67,132,8,17,0,0,192,197,232,98,116,0,0,192,197,232,33,50,0,0,0,0,2,0,1,0,0,0,0,2,0,17,0,0,0,64,54,24,4,0,0,0,128,15,62,0,0,0,0,4,131,77,0,0,0,192,69,136,8,32,0,0,192,135,214,122,240,0,0,128,16,165,92,140,0,0,224,197,248,98,124,0,0,192,197,16,66,116,0,0,224,164,24,99,58,0,0,224,135,240,66,248,0,0,224,135,240,66,8,0,0,192,197,144,99,244,0,0,32,198,248,99,140,0,0,192,17,66,8,113,0,0,128,67,8,33,124,0,0,32,166,50,74,138,0,0,32,132,16,66,248,0,0,32,198,189,107,141,0,0,96,206,90,107,206,0,0,192,197,24,99,116,0,0,224,197,248,66,8,0,0,192,197,24,99,246,0,0,224,197,248,98,140,0,0,192,197,224,96,116,0,0,224,19,66,8,33,0,0,32,198,24,99,116,0,0,32,198,168,20,33,0,0,32,214,90,149,82,0,0,32,70,69,84,140,0,0,32,198,232,8,33,0,0,224,67,68,68,248,0,0,78,8,33,132,16,14,0,33,8,65,8,66,16,0,14,33,132,16,66,14,0,128,168,8,0,0,0,0,0,0,0,0,0,31,0,128,32,0,0,0,0,0,0,0,7,125,244,0,0,33,132,23,99,124,0,0,0,0,31,66,240,0,0,16,66,31,99,244,0,0,0,0,23,127,240,0,0,92,136,39,132,16,0,0,0,0,23,99,244,208,1,33,132,23,99,140,0,0,128,0,67,8,33,0,0,0,1,134,16,66,232,0,66,8,169,140,146,0,0,134,16,66,8,33,0,0,0,128,85,107,173,0,0,0,128,23,99,140,0,0,0,0,23,99,116,0,0,0,128,23,99,124,33,0,0,0,31,99,244,16,2,0,128,54,67,8,0,0,0,0,31,28,124,0,0,64,8,39,132,224,0,0,0,128,24,99,244,0,0,0,128,24,149,34,0,0,0,128,88,171,82,0,0,0,128,168,136,138,0,0,0,128,24,99,244,208,1,0,128,143,136,248,0,0,136,16,34,8,33,8,0,132,16,66,8,33,4,0,130,16,130,8,33,2,0,0,0,96,50,0,0,0,0,0,0,0,0,0,0,63,132,16,66,8,225,3,0,0,0,0,0,0,0,0,0,0,0,64,4,0,152,16,71,8,33,68,0,0,0,0,0,80,10,0,0,0,0,0,168,0,0,132,124,66,8,33,4,0,132,124,242,9,33,4,0,68,1,0,0,0,0,0,0,72,69,84,2,0,0,138,0,31,62,124,0,0,0,0,68,4,65,0,0,192,166,148,83,178,0,0,0,0,0,0,0,0,0,138,128,143,136,248,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,132,32,0,0,0,0,0,8,17,0,0,0,0,0,74,81,0,0,0,0,0,148,42,0,0,0,0,0,0,0,192,24,0,0,0,0,0,0,62,0,0,0,0,0,0,62,0,0,0,0,0,64,21,0,0,0,0,128,175,149,2,0,0,138,0,31,28,124,0,0,0,0,130,32,34,0,0,0,0,155,114,178,0,0,0,0,0,0,0,0,0,138,128,143,136,248,0,0,10,196,24,29,33,0,0,0,0,0,0,0,0,0,128,0,66,8,33,0,0,0,32,174,20,71,0,0,152,16,79,68,248,0,0,0,4,47,165,15,0,0,32,70,71,62,33,0,0,132,16,2,8,33,4,0,152,16,23,163,35,100,0,64,1,0,0,0,0,0,192,135,86,90,240,0,0,4,49,197,0,0,0,0,0,0,34,147,36,0,0,0,0,224,33,132,0,0,0,0,0,0,0,0,0,192,135,84,74,240,0,0,224,3,0,0,0,0,0,128,56,2,0,0,0,0,0,16,242,9,249,0,0,6,17,225,0,0,0,0,6,25,100,0,0,0,0,136,0,0,0,0,0,0,0,0,41,165,116,34,0,192,223,107,41,165,148,2,0,0,64,0,0,0,0,0,0,0,0,96,136,0,196,16,226,0,0,0,0,68,41,2,0,0,0,0,0,128,36,137,76,0,0,48,166,68,168,22,1,0,48,166,68,137,148,1,0,81,46,85,168,22,1,0,128,0,130,96,116,0,0,130,0,226,92,140,0,0,68,0,226,92,140,0,0,68,1,226,92,140,0,0,84,1,226,92,140,0,0,64,1,226,92,140,0,0,196,17,226,92,140,0,0,128,59,231,83,202,0,0,192,197,16,66,116,68,0,130,128,31,94,248,0,0,68,128,31,94,248,0,0,68,129,31,94,248,0,0,64,129,31,94,248,0,0,130,0,71,8,113,0,0,68,0,71,8,113,0,0,68,1,71,8,113,0,0,64,1,71,8,113,0,0,192,73,241,132,116,0,0,84,129,89,107,206,0,0,130,0,23,99,116,0,0,68,0,23,99,116,0,0,68,1,23,99,116,0,0,84,1,23,99,116,0,0,64,1,23,99,116,0,0,0,68,69,84,4,0,0,0,48,169,173,108,0,0,130,128,24,99,116,0,0,68,128,24,99,116,0,0,68,129,24,99,116,0,0,64,129,24,99,116,0,0,136,196,24,29,33,0,0,64,8,39,165,19,2,0,192,73,233,164,116,1,0,130,0,7,125,244,0,0,68,0,7,125,244,0,0,68,1,7,125,244,0,0,84,1,7,125,244,0,0,64,1,7,125,244,0,0,196,17,7,125,244,0,0,0,0,139,124,178,0,0,0,0,31,66,240,68,0,130,0,23,127,240,0,0,68,0,23,127,240,0,0,68,1,23,127,240,0,0,64,1,23,127,240,0,0,130,0,67,8,33,0,0,68,0,67,8,33,0,0,68,1,67,8,33,0,0,64,1,67,8,33,0,0,192,34,232,99,116,0,0,84,129,23,99,140,0,0,130,0,23,99,116,0,0,68,0,23,99,116,0,0,68,1,23,99,116,0,0,170,0,23,99,116,0,0,64,1,23,99,116,0,0,0,16,240,1,1,0,0,0,48,169,173,108,0,0,130,128,24,99,244,0,0,68,128,24,99,244,0,0,68,129,24,99,244,0,0,64,129,24,99,244,0,0,68,128,24,99,244,208,1,32,132,23,99,124,33,0,64,129,24,99,244,208,1,144,11,7,0,64,6,7,0,160,255,6,0,40,250,6,0,144,247,6,0,16,244,6,0,40,240,6,0,104,237,6,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,10,0,0,0,12,0,0,0,14,0,0,0,16,0,0,0,20,0,0,0,24,0,0,0,28,0,0,0,32,0,0,0,40,0,0,0,48,0,0,0,56,0,0,0,64,0,0,0,80,0,0,0,96,0,0,0,112,0,0,0,128,0,0,0,160,0,0,0,192,0,0,0,224,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,6,0,0,0,8,0,0,0,12,0,0,0,16,0,0,0,24,0,0,0,32,0,0,0,48,0,0,0,64,0,0,0,96,0,0,0,128,0,0,0,192,0,0,0,0,1,0,0,128,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,6,0,0,0,8,0,0,0,12,0,0,0,16,0,0,0,24,0,0,0,32,0,0,0,48,0,0,0,64,0,0,0,96,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,35,0,0,26,2,0,0,216,11,0,0,72,9,0,0,108,6,0,0,76,1,0,0,234,11,0,0,136,134,8,0,142,1,0,0,112,7,0,0,176,33,0,0,122,45,0,0,192,11,0,0,132,10,0,0,232,12,0,0,34,3,0,0,136,12,0,0,192,222,7,0,0,0,0,0,0,0,0,0,40,251,0,0,80,251,0,0,0,0,0,0,0,0,0,0,52,58,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,147,169,170,63,49,54,58,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,243,142,227,63,49,54,58,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,205,204,204,63,49,54,58,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,137,136,136,63,67,111,110,102,105,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,83,113,117,97,114,101,32,112,105,120,101,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,63,67,111,114,101,32,112,114,111,118,105,100,101,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,63,67,117,115,116,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,53,32,66,117,116,116,111,110,32,51,0,0,0,0,0,107,101,121,32,119,0,0,0,67,114,121,115,116,97,108,39,115,32,80,111,110,121,32,84,97,108,101,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,55,49,51,41,0,0,116,100,112,103,97,108,0,0,112,53,32,102,105,114,101,32,50,0,0,0,0,0,0,0,109,100,95,99,114,121,115,116,108,112,116,112,48,49,0,0,71,97,108,83,111,117,110,100,76,97,116,99,104,50,0,0,68,101,99,114,121,112,116,105,110,103,32,54,56,48,48,48,32,82,79,77,115,32,119,105,116,104,32,107,101,121,32,37,100,32,37,115,0,0,0,0,80,53,32,66,117,116,116,111,110,32,50,0,0,0,0,0,107,101,121,32,113,0,0,0,105,56,55,53,49,95,99,111,109,109,97,110,100,95,113,117,101,117,101,0,0,0,0,0,67,114,121,115,116,97,108,39,115,32,80,111,110,121,32,84,97,108,101,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,55,49,50,41,0,0,71,97,108,67,111,117,110,116,101,114,0,0,0,0,0,0,112,53,32,102,105,114,101,32,49,0,0,0,0,0,0,0,115,97,118,97,103,101,114,101,0,0,0,0,0,0,0,0,80,50,32,65,117,116,111,0,109,100,95,99,114,121,115,116,108,112,116,112,48,50,0,0,100,114,118,73,110,112,117,116,0,0,0,0,0,0,0,0,113,99,114,97,121,111,110,0,115,97,118,101,115,116,97,116,101,95,97,117,116,111,95,108,111,97,100,0,0,0,0,0,80,53,32,66,117,116,116,111,110,32,49,0,0,0,0,0,107,101,121,32,116,97,98,0,102,114,101,101,122,101,0,0,70,97,107,101,32,87,105,100,101,115,99,114,101,101,110,32,68,73,80,0,0,0,0,0,70,97,110,116,97,115,121,32,90,111,110,101,32,84,105,109,101,32,65,116,116,97,99,107,32,40,83,121,115,116,101,109,32,49,54,66,44,32,80,83,50,32,100,97,116,97,32,102,105,108,101,41,0,0,0,0,67,114,121,115,116,97,108,39,115,32,80,111,110,121,32,84,97,108,101,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,55,49,50,45,66,41,0,0,0,0,0,0,0,0,116,101,100,100,121,98,98,111,0,0,0,0,0,0,0,0,80,49,32,85,112,47,68,111,119,110,0,0,0,0,0,0,53,48,107,44,32,49,48,48,107,44,32,50,48,48,107,32,97,110,100,32,53,48,48,107,0,0,0,0,0,0,0,0,84,105,109,101,32,67,111,110,116,114,111,108,0,0,0,0,84,101,99,109,111,0,0,0,112,53,32,114,105,103,104,116,0,0,0,0,0,0,0,0,50,48,32,72,105,116,112,111,105,110,116,115,0,0,0,0,109,100,95,99,114,121,115,116,108,112,116,112,48,51,0,0,65,116,104,101,110,97,32,47,32,65,98,108,101,0,0,0,69,120,116,101,110,100,32,78,111,32,69,120,116,101,110,100,0,0,0,0,0,0,0,0,112,97,108,101,116,116,101,95,49,0,0,0,0,0,0,0,99,114,117,115,104,52,0,0,80,53,32,82,105,103,104,116,0,0,0,0,0,0,0,0,77,97,104,106,111,110,103,32,99,111,110,116,114,111,108,32,112,97,110,101,108,0,0,0,97,118,101,110,103,101,114,115,95,115,111,117,110,100,108,97,116,99,104,50,0,0,0,0,67,112,115,90,82,97,109,70,48,0,0,0,0,0,0,0,74,117,108,0,0,0,0,0,67,114,121,115,116,97,108,39,115,32,80,111,110,121,32,84,97,108,101,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,55,48,51,41,0,0,75,121,117,103,111,73,82,81,69,110,97,98,108,101,0,0,78,111,32,99,111,110,116,105,110,117,97,116,105,111,110,0,49,32,67,111,105,110,32,32,55,32,80,108,97,121,115,0,80,0,0,0,117,0,0,0,122,0,0,0,122,0,0,0,108,0,0,0,101,0,0,0,32,0,0,0,83,0,0,0,116,0,0,0,97,0,0,0,114,0,0,0,0,0,0,0,209,48,0,0,186,48,0,0,235,48,0,0,185,48,0,0,191,48,0,0,252,48,0,0,0,0,0,0,84,155,0,0,123,94,0,0,31,102,0,0,167,94,0,0,32,0,0,0,40,0,0,0,86,0,0,0,49,0,0,0,48,0,0,0,48,0,0,0,77,0,0,0,71,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,67,97,100,97,115,104,0,0,102,102,105,103,104,116,0,0,112,53,32,108,101,102,116,0,107,111,116,109,50,112,0,0,109,100,95,99,114,121,115,116,108,112,116,112,48,52,0,0,109,100,95,112,115,116,97,114,50,0,0,0,0,0,0,0,68,114,105,118,101,114,115,0,115,105,122,101,0,0,0,0,100,100,116,111,100,0,0,0,86,82,65,77,32,67,104,97,114,97,99,116,101,114,32,67,104,101,99,107,0,0,0,0,80,53,32,76,101,102,116,0,112,117,110,107,115,104,111,116,50,0,0,0,0,0,0,0,67,114,121,115,116,97,108,39,115,32,80,111,110,121,32,84,97,108,101,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,55,48,50,41,0,0,112,53,32,100,111,119,110,0,109,100,95,99,114,121,115,116,108,112,116,112,48,53,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,117,110,109,117,116,101,32,97,117,100,105,111,46,10,0,0,0,83,108,111,119,32,109,111,116,105,111,110,0,0,0,0,0,80,53,32,68,111,119,110,0,67,114,121,115,116,97,108,39,115,32,80,111,110,121,32,84,97,108,101,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,55,48,49,41,0,0,83,117,98,101,108,101,99,116,114,111,0,0,0,0,0,0,112,53,32,117,112,0,0,0,68,101,102,97,117,108,116,32,99,97,114,100,32,116,121,112,101,0,0,0,0,0,0,0,109,100,95,99,114,121,115,116,108,112,116,112,48,54,0,0,80,53,32,85,112,0,0,0,105,56,55,53,49,95,99,111,105,110,95,112,101,110,100,105,110,103,0,0,0,0,0,0,67,114,121,115,116,97,108,39,115,32,80,111,110,121,32,84,97,108,101,32,40,85,83,65,41,0,0,0,0,0,0,0,37,100,0,0,0,0,0,0,112,53,32,115,101,108,101,99,116,0,0,0,0,0,0,0,65,69,83,32,115,121,115,116,101,109,0,0,0,0,0,0,80,50,32,66,117,116,116,111,110,32,52,0,0,0,0,0,109,100,95,99,114,121,115,116,108,112,116,0,0,0,0,0,110,84,101,120,116,82,79,77,83,116,97,116,117,115,0,0,80,117,76,105,82,117,76,97,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,115,97,118,101,115,116,97,116,101,95,97,117,116,111,95,115,97,118,101,0,0,0,0,0,80,53,32,83,101,108,101,99,116,0,0,0,0,0,0,0,77,86,83,32,115,121,115,116,101,109,0,0,0,0,0,0,70,114,101,101,122,101,0,0,88,88,88,88,88,88,0,0,102,97,110,116,122,110,116,97,0,0,0,0,0,0,0,0,84,119,105,115,116,101,100,32,70,108,105,112,112,101,114,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,0,0,74,117,110,0,0,0,0,0,84,101,100,100,121,66,111,121,32,66,108,117,101,115,32,40,51,49,53,45,53,49,49,53,44,32,78,101,119,32,86,101,114,46,41,0,0,0,0,0,50,48,107,44,32,53,48,107,44,32,49,48,48,107,44,32,50,48,48,107,32,97,110,100,32,53,48,48,107,0,0,0,87,104,101,101,108,105,101,0,77,97,99,104,105,110,101,32,52,0,0,0,0,0,0,0,78,111,117,114,121,111,107,117,32,75,111,117,106,111,117,32,73,105,110,107,97,105,0,0,112,53,32,115,116,97,114,116,0,0,0,0,0,0,0,0,109,115,108,117,103,120,95,99,111,117,110,116,101,114,0,0,83,99,114,101,101,110,32,82,101,118,101,114,115,101,0,0,73,110,100,105,118,105,100,117,97,108,97,0,0,0,0,0,109,100,95,116,119,105,115,116,101,100,102,0,0,0,0,0,74,46,32,74,46,32,83,113,117,97,119,107,101,114,115,0,0,0,0,0,0,0,0,0,68,114,118,80,97,108,101,116,116,101,82,97,109,66,97,110,107,0,0,0,0,0,0,0,75,117,114,97,108,32,69,108,101,99,116,114,105,99,0,0,53,48,107,32,116,104,101,110,32,101,118,101,114,121,32,55,48,107,0,0,0,0,0,0,80,53,32,83,116,97,114,116,0,0,0,0,0,0,0,0,109,115,108,117,103,120,95,99,111,109,109,97,110,100,0,0,97,118,101,110,103,101,114,115,95,112,97,108,101,116,116,101,95,112,101,110,0,0,0,0,50,32,67,111,105,110,115,32,50,32,67,114,101,100,105,116,0,0,0,0,0,0,0,0,78,97,109,99,111,32,40,77,105,100,119,97,121,32,108,105,99,101,110,115,101,41,0,0,67,114,117,101,32,66,97,108,108,32,40,74,112,110,41,0,0,0,0,0,0,0,0,0,75,121,117,103,111,73,110,112,117,116,0,0,0,0,0,0,67,111,110,116,105,110,117,97,116,105,111,110,32,109,97,120,32,115,116,97,103,101,0,0,73,110,99,111,109,112,108,101,116,101,32,100,117,109,112,0,112,99,101,95,99,97,100,97,115,104,0,0,0,0,0,0,41,89,0,0,48,87,0,0,146,48,0,0,176,85,0,0,137,48,0,0,70,48,0,0,0,0,0,0,84,0,0,0,101,0,0,0,110,0,0,0,99,0,0,0,104,0,0,0,105,0,0,0,32,0,0,0,119,0,0,0,111,0,0,0,32,0,0,0,75,0,0,0,117,0,0,0,114,0,0,0,97,0,0,0,117,0,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,32,0,0,0,82,0,0,0,101,0,0,0,115,0,0,0,97,0,0,0,108,0,0,0,101,0,0,0,32,0,0,0,86,0,0,0,101,0,0,0,114,0,0,0,46,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,112,52,32,102,105,114,101,32,54,0,0,0,0,0,0,0,69,120,116,114,97,32,82,65,77,32,66,0,0,0,0,0,75,105,110,103,32,111,102,32,116,104,101,32,77,111,110,115,116,101,114,115,32,50,32,45,32,84,104,101,32,78,101,120,116,32,84,104,105,110,103,32,40,78,71,77,45,48,51,57,41,40,78,71,72,45,48,51,57,41,0,0,0,0,0,0,109,100,95,99,114,117,101,98,97,108,108,106,0,0,0,0,80,101,116,101,32,83,97,109,112,114,97,115,32,84,101,110,110,105,115,32,40,69,117,114,111,44,32,85,83,65,44,32,74,45,67,97,114,116,41,0,0,0,0,0,0,0,0,0,83,101,116,116,105,110,103,115,0,0,0,0,0,0,0,0,115,99,97,108,101,95,121,0,68,117,110,103,101,111,110,115,32,38,32,68,114,97,103,111,110,115,32,45,32,115,104,97,100,111,119,32,111,118,101,114,32,109,121,115,116,97,114,97,32,40,57,54,48,50,48,57,32,85,83,65,41,0,0,0,80,52,32,66,117,116,116,111,110,32,54,0,0,0,0,0,69,120,116,114,97,32,82,65,77,32,65,0,0,0,0,0,71,88,57,48,55,0,0,0,65,110,121,32,66,117,116,116,111,110,32,116,111,32,83,116,97,114,116,0,0,0,0,0,67,114,117,101,32,66,97,108,108,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,106,111,101,109,97,99,0,0,112,52,32,102,105,114,101,32,53,0,0,0,0,0,0,0,109,100,95,99,114,117,101,98,97,108,108,0,0,0,0,0,65,117,100,105,111,32,117,110,109,117,116,101,100,46,0,0,67,104,97,105,110,32,82,101,97,99,116,105,111,110,32,40,87,111,114,108,100,44,32,86,101,114,115,105,111,110,32,50,46,50,44,32,49,57,57,53,46,48,57,46,50,53,41,0,0,0,0,0,0,0,0,0,80,52,32,66,117,116,116,111,110,32,53,0,0,0,0,0,65,115,105,97,32,47,32,69,117,114,111,112,101,0,0,0,83,117,112,101,114,32,65,105,114,119,111,108,102,32,40,74,112,110,41,0,0,0,0,0,69,120,111,100,117,115,32,40,98,111,111,116,108,101,103,63,41,0,0,0,0,0,0,0,116,114,105,111,116,104,101,112,0,0,0,0,0,0,0,0,109,100,95,115,117,112,101,114,97,105,114,0,0,0,0,0,105,56,55,53,49,95,110,101,101,100,115,95,97,99,107,0,75,121,117,103,111,32,66,111,117,101,107,105,0,0,0,0,67,104,97,110,45,62,115,116,101,112,0,0,0,0,0,0,67,114,111,115,115,32,70,105,114,101,32,40,85,83,65,41,0,0,0,0,0,0,0,0,102,97,116,102,117,114,115,112,0,0,0,0,0,0,0,0,80,50,32,66,117,116,116,111,110,32,51,0,0,0,0,0,84,104,114,111,116,116,108,101,32,71,97,109,101,32,83,112,101,101,100,0,0,0,0,0,110,73,82,81,80,101,110,100,105,110,103,0,0,0,0,0,116,119,111,99,114,117,100,101,0,0,0,0,0,0,0,0,112,117,108,105,114,117,108,97,106,0,0,0,0,0,0,0,115,97,118,101,115,116,97,116,101,95,97,117,116,111,95,105,110,100,101,120,0,0,0,0,52,32,98,97,114,115,0,0,109,100,95,120,102,105,114,101,0,0,0,0,0,0,0,0,70,97,110,116,97,115,121,32,90,111,110,101,32,73,73,32,45,32,84,104,101,32,84,101,97,114,115,32,111,102,32,79,112,97,45,79,112,97,32,40,83,121,115,116,101,109,32,49,54,67,44,32,80,83,50,32,100,97,116,97,32,102,105,108,101,41,0,0,0,0,0,0,99,104,105,112,45,62,108,102,111,95,112,109,95,105,110,99,0,0,0,0,0,0,0,0,65,112,114,0,0,0,0,0,116,101,100,100,121,98,98,0,80,49,32,76,101,102,116,47,82,105,103,104,116,0,0,0,80,108,97,121,32,77,117,115,105,99,0,0,0,0,0,0,77,97,99,104,105,110,101,32,51,0,0,0,0,0,0,0,80,50,32,66,117,116,116,111,110,32,55,0,0,0,0,0,110,111,117,114,121,111,107,117,0,0,0,0,0,0,0,0,72,97,110,100,32,71,117,110,0,0,0,0,0,0,0,0,71,102,120,32,86,105,101,119,101,114,0,0,0,0,0,0,114,0,0,0,0,0,0,0,77,97,45,66,97,0,0,0,53,32,80,111,105,110,116,115,0,0,0,0,0,0,0,0,51,32,98,97,114,115,0,0,106,106,115,113,117,97,119,107,0,0,0,0,0,0,0,0,71,97,109,101,32,68,105,102,102,105,99,117,108,116,121,32,68,0,0,0,0,0,0,0,115,97,109,112,108,101,95,111,102,102,115,0,0,0,0,0,67,112,117,49,32,86,105,100,101,111,32,82,65,77,0,0,67,114,117,115,104,32,82,111,108,108,101,114,32,40,75,117,114,97,108,32,45,32,98,111,111,116,108,101,103,63,41,0,0,0,0,0,0,0,0,0,50,48,107,32,116,104,101,110,32,101,118,101,114,121,32,55,48,107,0,0,0,0,0,0,67,114,97,121,111,110,32,83,104,105,110,45,99,104,97,110,32,45,32,65,114,97,115,104,105,32,111,32,89,111,98,117,32,69,110,106,105,32,40,74,112,110,41,0,0,0,0,0,42,40,40,85,73,78,84,51,50,42,41,97,118,101,110,103,101,114,115,95,112,97,114,97,109,41,0,0,0,0,0,0,51,32,67,111,105,110,115,32,51,32,67,114,101,100,105,116,0,0,0,0,0,0,0,0,73,110,105,116,105,116,97,108,32,86,105,116,97,108,105,116,121,0,0,0,0,0,0,0,75,121,117,103,111,68,105,112,0,0,0,0,0,0,0,0,52,48,107,32,97,110,100,32,101,118,101,114,121,32,56,48,107,0,0,0,0,0,0,0,80,117,122,122,108,101,32,83,116,97,114,32,40,86,49,48,48,77,71,41,0,0,0,0,84,101,110,99,104,105,32,119,111,32,75,117,114,97,117,32,40,74,97,112,97,110,32,82,101,115,97,108,101,32,86,101,114,46,41,0,0,0,0,0,109,100,95,99,114,97,121,111,110,0,0,0,0,0,0,0,116,104,110,100,122,111,110,101,106,0,0,0,0,0,0,0,109,100,95,115,97,109,112,114,97,115,0,0,0,0,0,0,67,111,114,101,32,79,112,116,105,111,110,115,0,0,0,0,115,99,97,108,101,95,120,0,100,100,115,111,109,117,114,49,0,0,0,0,0,0,0,0,83,97,103,101,39,115,32,67,114,101,97,116,105,111,110,0,80,117,110,107,32,83,104,111,116,32,40,85,83,32,52,32,80,108,97,121,101,114,115,41,0,0,0,0,0,0,0,0,52,32,74,111,121,115,116,105,99,107,115,0,0,0,0,0,66,117,108,108,101,116,39,115,32,83,112,101,101,100,0,0,104,111,112,112,101,114,0,0,67,114,97,99,107,32,68,111,119,110,32,40,85,83,65,41,0,0,0,0,0,0,0,0,77,111,114,101,32,81,117,105,99,107,108,121,0,0,0,0,65,117,100,105,111,32,109,117,116,101,100,46,0,0,0,0,78,101,116,112,108,97,121,32,102,108,105,112,32,112,108,97,121,101,114,115,0,0,0,0,72,111,112,112,101,114,32,79,117,116,0,0,0,0,0,0,109,100,95,99,114,107,100,111,119,110,117,0,0,0,0,0,81,117,105,99,107,108,121,0,101,120,111,100,117,115,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,82,79,84,65,84,73,79,78,58,32,37,117,10,0,0,0,0,99,108,101,97,114,32,99,114,101,100,105,116,0,0,0,0,67,114,97,99,107,32,68,111,119,110,32,40,69,117,114,111,44,32,74,112,110,41,0,0,83,108,111,119,108,121,0,0,67,108,101,97,114,32,67,114,101,100,105,116,0,0,0,0,109,100,95,99,114,107,100,111,119,110,49,0,0,0,0,0,105,56,55,53,49,95,114,101,116,117,114,110,0,0,0,0,77,111,114,101,32,83,108,111,119,108,121,0,0,0,0,0,111,112,32,109,101,110,117,0,67,114,97,99,107,32,68,111,119,110,32,40,69,117,114,111,44,32,74,112,110,44,32,82,101,118,46,32,65,41,0,0,80,50,32,66,117,116,116,111,110,32,50,0,0,0,0,0,76,101,118,101,108,32,85,112,32,84,105,109,101,114,0,0,110,67,117,114,114,101,110,116,66,97,110,107,0,0,0,0,71,97,108,76,97,115,116,80,111,114,116,50,0,0,0,0,42,49,48,48,49,49,120,120,120,120,120,120,120,0,0,0,83,111,109,101,32,112,114,105,111,114,105,116,121,32,112,114,111,98,108,101,109,115,0,0,98,108,111,99,107,95,115,114,97,109,95,111,118,101,114,119,114,105,116,101,0,0,0,0,49,67,32,53,67,0,0,0,68,105,115,97,98,108,101,32,80,101,100,97,108,0,0,0,79,112,101,114,97,116,111,114,32,77,101,110,117,0,0,0,109,100,95,99,114,107,100,111,119,110,0,0,0,0,0,0,79,99,101,97,110,105,97,0,102,97,110,116,122,110,50,120,112,115,50,0,0,0,0,0,115,102,97,98,99,104,0,0,77,97,114,0,0,0,0,0,83,87,65,84,32,40,51,49,53,45,53,48,52,56,41,0,0,0,0,0,0,0,0,0,77,97,99,104,105,110,101,32,50,0,0,0,0,0,0,0,66,111,109,98,106,97,99,107,32,84,119,105,110,32,40,115,101,116,32,50,41,0,0,0,80,117,109,112,32,65,99,116,105,111,110,0,0,0,0,0,100,101,99,111,49,54,95,109,97,115,107,0,0,0,0,0,80,49,32,83,116,97,114,116,47,67,111,108,108,101,99,116,0,0,0,0,0,0,0,0,67,111,115,109,105,99,32,83,112,97,99,101,104,101,97,100,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,49,48,32,80,111,105,110,116,115,0,0,0,0,0,0,0,83,97,109,109,121,32,73,110,100,117,115,116,114,105,101,115,0,0,0,0,0,0,0,0,71,97,109,101,32,68,105,102,102,105,99,117,108,116,121,32,67,0,0,0,0,0,0,0,67,112,117,48,32,86,105,100,101,111,32,82,65,77,0,0,99,114,117,115,104,51,0,0,53,48,107,32,116,104,101,110,32,101,118,101,114,121,32,52,48,107,0,0,0,0,0,0,80,49,32,68,111,117,98,108,101,32,85,112,0,0,0,0,109,100,95,99,111,115,109,105,99,0,0,0,0,0,0,0,52,32,67,111,105,110,115,32,52,32,67,114,101,100,105,116,0,0,0,0,0,0,0,0,68,114,118,90,56,48,82,111,109,66,97,110,107,0,0,0,51,48,107,32,97,110,100,32,101,118,101,114,121,32,54,48,107,0,0,0,0,0,0,0,112,117,122,108,115,116,97,114,0,0,0,0,0,0,0,0,66,117,115,111,117,32,75,101,105,106,105,32,45,32,67,121,98,101,114,32,67,114,111,115,115,0,0,0,0,0,0,0,100,121,110,119,97,114,106,114,0,0,0,0,0,0,0,0,112,52,32,115,101,108,101,99,116,0,0,0,0,0,0,0,80,49,32,83,109,97,108,108,0,0,0,0,0,0,0,0,70,111,111,116,98,97,108,108,32,70,114,101,110,122,121,32,40,78,71,77,45,48,51,52,41,40,78,71,72,45,48,51,52,41,0,0,0,0,0,0,67,121,98,101,114,45,67,111,112,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,67,104,105,112,45,62,70,101,101,100,98,97,99,107,77,97,115,107,0,0,0,0,0,0,114,97,103,116,105,109,101,97,0,0,0,0,0,0,0,0,77,105,99,114,111,32,77,97,99,104,105,110,101,115,32,84,117,114,98,111,32,84,111,117,114,110,97,109,101,110,116,32,57,54,32,40,69,117,114,111,44,32,118,49,46,49,44,32,74,45,67,97,114,116,41,0,0,0,0,0,0,0,0,0,76,111,97,100,32,71,97,109,101,32,40,37,115,41,0,0,115,99,97,108,101,0,0,0,68,117,110,103,101,111,110,115,32,38,32,68,114,97,103,111,110,115,32,45,32,115,104,97,100,111,119,32,111,118,101,114,32,109,121,115,116,97,114,97,32,40,57,54,48,54,49,57,32,85,83,65,41,0,0,0,109,97,104,114,101,116,115,117,0,0,0,0,0,0,0,0,109,101,110,117,95,116,111,103,103,108,101,0,0,0,0,0,80,49,32,66,105,103,0,0,109,100,95,99,121,98,101,114,99,111,112,0,0,0,0,0,112,117,110,107,115,104,111,116,0,0,0,0,0,0,0,0,70,114,97,109,101,32,65,100,118,97,110,99,101,0,0,0,82,46,83,84,65,67,75,91,48,93,0,0,0,0,0,0,99,104,105,112,45,62,98,97,110,107,95,111,102,102,115,101,116,0,0,0,0,0,0,0,37,48,56,120,58,32,71,98,32,85,110,100,101,102,105,110,101,100,32,84,104,117,109,98,32,105,110,115,116,114,117,99,116,105,111,110,58,32,37,48,52,120,10,0,0,0,0,0,80,49,32,80,97,121,111,117,116,0,0,0,0,0,0,0,67,111,114,112,111,114,97,116,105,111,110,32,40,69,117,114,111,41,0,0,0,0,0,0,80,117,122,122,108,101,32,71,97,109,101,32,76,101,118,101,108,0,0,0,0,0,0,0,86,111,108,117,109,101,58,32,37,46,49,102,32,100,66,0,114,111,104,103,97,104,0,0,82,45,62,105,99,95,101,100,100,103,101,0,0,0,0,0,70,97,108,99,111,110,0,0,67,111,99,107,116,97,105,108,0,0,0,0,0,0,0,0,98,97,116,114,105,100,101,114,106,0,0,0,0,0,0,0,78,101,111,45,80,86,67,32,54,56,75,32,82,65,77,0,102,105,120,101,105,103,104,116,104,116,0,0,0,0,0,0,109,100,95,99,111,114,112,111,114,97,116,0,0,0,0,0,71,114,105,110,100,32,83,116,111,114,109,101,114,32,40,111,108,100,101,114,32,115,101,116,41,0,0,0,0,0,0,0,80,117,122,122,108,101,32,76,105,118,101,115,0,0,0,0,116,105,103,101,114,104,98,50,0,0,0,0,0,0,0,0,80,105,112,105,32,38,32,66,105,98,105,115,32,47,32,87,104,111,111,112,101,101,33,33,32,40,84,101,107,105,32,80,97,107,105,32,104,97,114,100,119,97,114,101,41,0,0,0,68,101,102,101,110,100,32,116,104,101,32,84,101,114,114,97,32,65,116,116,97,99,107,32,111,110,32,116,104,101,32,82,101,100,32,85,70,79,32,40,98,111,111,116,108,101,103,41,0,0,0,0,0,0,0,0,98,97,116,115,117,103,117,110,97,0,0,0,0,0,0,0,112,51,32,102,105,114,101,32,54,0,0,0,0,0,0,0,68,101,98,117,103,32,68,105,112,32,50,0,0,0,0,0,67,111,111,108,32,83,112,111,116,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,83,104,111,111,116,105,110,103,32,71,97,109,101,32,76,101,118,101,108,0,0,0,0,0,68,0,0,0,111,0,0,0,103,0,0,0,121,0,0,0,117,0,0,0,117,0,0,0,110,0,0,0,32,0,0,0,40,0,0,0,76,0,0,0,105,0,0,0,99,0,0,0,101,0,0,0,110,0,0,0,115,0,0,0,101,0,0,0,100,0,0,0,32,0,0,0,116,0,0,0,111,0,0,0,32,0,0,0,85,0,0,0,110,0,0,0,105,0,0,0,116,0,0,0,101,0,0,0,32,0,0,0,84,0,0,0,114,0,0,0,97,0,0,0,100,0,0,0,105,0,0,0,110,0,0,0,103,0,0,0,32,0,0,0,70,0,0,0,111,0,0,0,114,0,0,0,32,0,0,0,75,0,0,0,111,0,0,0,114,0,0,0,101,0,0,0,97,0,0,0,41,0,0,0,0,0,0,0,68,0,0,0,111,0,0,0,103,0,0,0,121,0,0,0,117,0,0,0,117,0,0,0,110,0,0,0,32,0,0,0,201,48,0,0,173,48,0,0,229,48,0,0,252,48,0,0,243,48,0,0,1,255,0,0,1,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,100,105,101,116,103,111,106,0,98,103,97,114,101,103,103,97,110,118,0,0,0,0,0,0,102,105,114,101,115,104,114,107,100,104,0,0,0,0,0,0,85,110,117,115,101,100,0,0,80,51,32,66,117,116,116,111,110,32,54,0,0,0,0,0,68,101,98,117,103,32,68,105,112,32,49,0,0,0,0,0,109,100,95,99,111,111,108,115,112,111,116,117,112,0,0,0,118,105,109,97,110,97,106,0,83,104,111,111,116,105,110,103,32,76,105,118,101,115,0,0,111,117,116,122,111,110,101,99,0,0,0,0,0,0,0,0,114,101,115,101,116,95,108,105,110,101,0,0,0,0,0,0,104,101,108,108,102,105,114,101,51,0,0,0,0,0,0,0,65,99,116,105,111,110,32,71,97,109,101,32,76,101,118,101,108,0,0,0,0,0,0,0,68,101,109,111,110,39,115,32,87,111,114,108,100,32,47,32,72,111,114,114,111,114,32,83,116,111,114,121,32,40,115,101,116,32,51,41,0,0,0,0,112,51,32,102,105,114,101,32,53,0,0,0,0,0,0,0,83,108,111,116,115,0,0,0,67,111,111,108,32,83,112,111,116,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,119,104,50,0,0,0,0,0,80,50,32,66,117,116,116,111,110,32,49,0,0,0,0,0,83,111,114,99,101,114,32,83,116,114,105,107,101,114,32,40,87,111,114,108,100,44,32,97,108,116,41,0,0,0,0,0,110,80,115,110,100,90,66,97,110,107,0,0,0,0,0,0,82,101,116,117,114,110,32,111,102,32,116,104,101,32,73,110,118,97,100,101,114,115,32,40,98,111,111,116,108,101,103,32,115,101,116,32,50,41,0,0,42,49,48,48,48,48,120,120,120,120,120,120,120,0,0,0,80,117,76,105,82,117,76,97,32,40,87,111,114,108,100,41,0,0,0,0,0,0,0,0,99,104,101,97,116,95,115,101,116,116,105,110,103,115,95,112,97,116,104,0,0,0,0,0,49,67,32,51,67,0,0,0,68,114,97,103,111,110,110,105,110,106,97,32,40,98,111,111,116,108,101,103,32,115,101,116,32,49,41,0,0,0,0,0,99,97,109,101,108,116,114,121,106,0,0,0,0,0,0,0,80,51,32,66,117,116,116,111,110,32,53,0,0,0,0,0,83,121,115,116,101,109,0,0,109,100,95,99,111,111,108,115,112,111,116,117,0,0,0,0,66,114,97,122,105,108,0,0,108,107,97,103,101,98,0,0,70,97,110,116,97,115,121,32,90,111,110,101,32,73,73,32])
.concat([45,32,84,104,101,32,84,101,97,114,115,32,111,102,32,79,112,97,45,79,112,97,32,40,83,121,115,116,101,109,32,49,54,67,44,32,112,114,111,116,111,116,121,112,101,41,0,0,65,99,116,105,111,110,32,76,105,118,101,115,0,0,0,0,115,117,112,101,114,99,104,115,106,0,0,0,0,0,0,0,70,101,98,0,0,0,0,0,115,119,97,116,0,0,0,0,69,99,111,110,32,85,112,114,105,103,104,116,0,0,0,0,79,112,101,114,97,116,105,111,110,32,84,104,117,110,100,101,114,98,111,108,116,32,40,85,83,44,32,111,108,100,101,114,41,0,0,0,0,0,0,0,77,97,99,104,105,110,101,32,49,0,0,0,0,0,0,0,69,120,116,101,114,109,105,110,97,116,105,111,110,32,40,85,83,41,0,0,0,0,0,0,98,106,116,119,105,110,97,0,71,117,110,32,84,121,112,101,0,0,0,0,0,0,0,0,65,114,107,97,110,111,105,100,32,40,85,83,44,32,111,108,100,101,114,41,0,0,0,0,103,97,116,101,100,111,111,109,0,0,0,0,0,0,0,0,83,99,114,111,108,108,50,89,0,0,0,0,0,0,0,0,67,111,111,108,32,83,112,111,116,32,40,74,112,110,44,32,75,111,114,41,0,0,0,0,76,105,102,101,32,82,101,115,116,111,114,97,116,105,111,110,0,0,0,0,0,0,0,0,52,32,80,108,97,121,101,114,0,0,0,0,0,0,0,0,75,101,114,111,32,75,101,114,111,32,75,101,114,111,112,112,105,32,110,111,32,73,115,115,121,111,110,105,32,65,115,111,98,111,117,32,40,74,97,112,97,110,41,0,0,0,0,0,71,97,109,101,32,68,105,102,102,105,99,117,108,116,121,32,66,0,0,0,0,0,0,0,109,97,115,116,101,114,119,106,0,0,0,0,0,0,0,0,79,112,101,114,97,116,105,111,110,32,87,111,108,102,32,51,32,40,85,83,41,0,0,0,75,117,114,97,108,32,69,115,99,111,32,69,108,101,99,116,114,105,99,0,0,0,0,0,73,110,105,116,105,97,108,32,72,105,103,104,32,83,99,111,114,101,0,0,0,0,0,0,50,48,107,32,116,104,101,110,32,101,118,101,114,121,32,52,48,107,0,0,0,0,0,0,65,113,117,97,106,97,99,107,32,40,85,83,41,0,0,0,99,104,105,110,97,116,119,110,0,0,0,0,0,0,0,0,109,100,95,99,111,111,108,115,112,111,116,106,0,0,0,0,67,67,104,105,112,67,114,101,100,105,116,115,70,111,114,67,111,105,110,0,0,0,0,0,52,32,67,111,105,110,115,32,51,32,67,114,101,100,105,116,0,0,0,0,0,0,0,0,67,111,110,116,101,115,116,0,78,117,109,98,101,114,32,111,102,32,115,116,97,114,116,32,99,111,117,110,116,114,105,101,115,0,0,0,0,0,0,0,115,115,95,98,97,110,107,95,98,97,115,101,0,0,0,0,68,97,114,105,117,115,32,40,74,97,112,97,110,32,111,108,100,32,118,101,114,115,105,111,110,41,0,0,0,0,0,0,118,100,99,95,115,112,114,105,116,101,95,114,97,109,91,105,93,0,0,0,0,0,0,0,67,97,100,97,115,104,32,40,85,83,41,0,0,0,0,0,234,48,0,0,162,48,0,0,235,48,0,0,162,48,0,0,243,48,0,0,201,48,0,0,32,0,0,0,213,48,0,0,167,48,0,0,164,48,0,0,175,48,0,0,0,0,0,0,80,0,0,0,104,0,0,0,111,0,0,0,116,0,0,0,111,0,0,0,32,0,0,0,89,0,0,0,50,0,0,0,75,0,0,0,0,0,0,0,39,89,0,0,182,91,0,0,101,103,0,0,32,0,0,0,126,98,0,0,180,120,0,0,0,0,0,0,133,141,0,0,167,126,0,0,32,0,0,0,212,107,0,0,0,78,0,0,212,107,0,0,32,0,0,0,40,0,0,0,86,0,0,0,49,0,0,0,48,0,0,0,50,0,0,0,44,0,0,0,32,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,99,101,95,99,121,98,101,114,120,0,0,0,0,0,0,41,89,0,0,48,87,0,0,146,48,0,0,176,85,0,0,137,48,0,0,70,48,0,0,0,0,0,0,84,0,0,0,101,0,0,0,110,0,0,0,99,0,0,0,104,0,0,0,105,0,0,0,32,0,0,0,119,0,0,0,111,0,0,0,32,0,0,0,75,0,0,0,117,0,0,0,114,0,0,0,97,0,0,0,117,0,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,67,111,111,108,32,83,112,111,116,32,40,69,117,114,111,41,0,0,0,0,0,0,0,0,71,105,103,97,110,100,101,115,32,40,101,97,114,108,105,101,114,41,0,0,0,0,0,0,109,99,117,95,114,101,112,111,114,116,99,111,105,110,0,0,84,67,48,49,48,48,83,67,78,71,102,120,66,97,110,107,0,0,0,0,0,0,0,0,110,105,110,106,97,119,0,0,109,100,95,109,105,99,114,111,109,57,54,0,0,0,0,0,76,111,97,100,32,71,97,109,101,32,40,68,101,116,101,99,116,32,67,111,114,101,41,0,111,110,110,97,51,52,114,111,97,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,88,77,76,58,32,73,110,118,97,108,105,100,32,112,114,111,112,101,114,116,121,32,102,111,114,32,102,105,108,116,101,114,46,10,0,0,100,100,115,111,109,117,0,0,111,117,116,114,117,110,114,97,0,0,0,0,0,0,0,0,103,114,97,98,95,109,111,117,115,101,95,116,111,103,103,108,101,0,0,0,0,0,0,0,109,100,95,99,111,111,108,115,112,111,116,0,0,0,0,0,175,48,0,0,164,48,0,0,186,48,0,0,32,0,0,0,102,91,0,0,79,85,0,0,206,48,0,0,185,48,0,0,185,48,0,0,225,48,0,0,32,0,0,0,71,0,0,0,97,0,0,0,107,0,0,0,117,0,0,0,109,0,0,0,111,0,0,0,110,0,0,0,32,0,0,0,110,0,0,0,111,0,0,0,32,0,0,0,83,0,0,0,117,0,0,0,115,0,0,0,117,0,0,0,109,0,0,0,101,0,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,32,0,0,0,118,0,0,0,101,0,0,0,114,0,0,0,46,0,0,0,32,0,0,0,74,0,0,0,65,0,0,0,49,0,0,0,32,0,0,0,84,0,0,0,121,0,0,0,112,0,0,0,101,0,0,0,32,0,0,0,72,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,83,116,111,112,32,77,111,100,101,32,40,67,104,101,97,116,41,0,0,0,0,0,0,0,78,117,109,98,101,114,32,111,102,32,74,111,121,115,116,105,99,107,115,0,0,0,0,0,65,108,105,101,110,32,83,121,110,100,114,111,109,101,32,40,115,101,116,32,51,44,32,83,121,115,116,101,109,32,49,54,66,44,32,70,68,49,48,56,57,65,32,51,49,55,45,48,48,51,51,41,0,0,0,0,115,102,105,105,105,110,0,0,83,121,115,116,101,109,49,54,83,99,114,111,108,108,88,0,67,111,110,103,111,32,40,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,0,68,105,102,102,105,99,117,108,116,121,32,40,80,108,97,121,101,114,115,32,115,116,114,101,110,103,116,104,41,0,0,0,65,117,100,105,111,32,109,117,116,101,32,116,111,103,103,108,101,0,0,0,0,0,0,0,98,114,97,105,110,0,0,0,97,115,116,111,114,109,117,0,84,101,115,116,32,50,0,0,109,100,95,99,111,110,103,111,0,0,0,0,0,0,0,0,103,108,111,99,0,0,0,0,68,105,102,102,105,99,117,108,116,121,32,40,69,110,101,109,121,115,32,115,116,114,101,110,103,116,104,41,0,0,0,0,65,102,116,101,114,32,66,117,114,110,101,114,32,73,73,0,0,0,0,0,0,0,0,0,53,32,67,111,105,110,115,32,49,32,67,114,101,100,105,116,115,32,0,0,0,0,0,0,117,110,115,117,112,112,111,114,116,101,100,32,108,111,99,97,108,101,32,102,111,114,32,115,116,97,110,100,97,114,100,32,105,110,112,117,116,0,0,0,86,100,112,72,83,99,114,111,108,108,83,105,122,101,0,0,114,101,100,117,102,111,98,0,67,111,109,105,120,32,90,111,110,101,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,65,108,101,120,32,75,105,100,100,58,32,84,104,101,32,76,111,115,116,32,83,116,97,114,115,32,40,115,101,116,32,50,44,32,117,110,112,114,111,116,101,99,116,101,100,41,0,0,69,83,80,32,82,97,46,68,101,46,32,40,74,97,112,97,110,44,32,118,101,114,46,32,57,56,47,48,52,47,49,52,41,0,0,0,0,0,0,0,65,116,108,117,115,0,0,0,109,100,95,99,111,109,105,120,117,112,0,0,0,0,0,0,72,101,97,100,32,80,97,110,105,99,32,40,118,101,114,46,32,48,49,49,55,44,32,49,55,47,48,49,47,50,48,48,48,41,0,0,0,0,0,0,109,115,112,117,122,122,108,101,0,0,0,0,0,0,0,0,68,114,97,119,32,83,70,46,0,0,0,0,0,0,0,0,85,108,116,114,97,32,66,97,108,108,111,111,110,0,0,0,67,111,109,105,120,32,90,111,110,101,32,40,85,83,65,41,0,0,0,0,0,0,0,0,80,50,32,83,104,111,116,0,61,61,61,32,67,111,110,102,105,103,32,61,61,61,10,0,87,111,114,108,100,0,0,0,112,108,101,103,101,110,100,115,0,0,0,0,0,0,0,0,122,101,114,111,112,110,116,97,0,0,0,0,0,0,0,0,112,117,108,105,114,117,108,97,0,0,0,0,0,0,0,0,108,111,103,105,99,112,114,50,0,0,0,0,0,0,0,0,99,104,101,97,116,95,100,97,116,97,98,97,115,101,95,112,97,116,104,0,0,0,0,0,73,109,112,101,114,102,101,99,116,32,83,78,68,44,32,102,114,101,101,122,101,115,32,111,110,32,102,105,114,115,116,32,98,111,115,115,0,0,0,0,84,101,115,116,32,49,0,0,109,100,95,99,111,109,105,120,117,0,0,0,0,0,0,0,72,105,115,112,97,110,105,99,0,0,0,0,0,0,0,0,87,97,116,101,114,32,66,97,108,108,115,0,0,0,0,0,102,97,110,116,122,110,50,120,112,0,0,0,0,0,0,0,68,105,102,102,105,99,117,108,116,121,32,50,0,0,0,0,74,97,110,0,0,0,0,0,100,114,103,110,109,115,116,95,115,110,100,95,102,108,97,103,0,0,0,0,0,0,0,0,83,116,97,114,32,74,97,99,107,101,114,32,40,83,116,101,114,110,41,0,0,0,0,0,72,105,103,104,32,83,99,111,114,101,32,67,104,97,114,97,99,116,101,114,115,0,0,0,66,111,109,98,106,97,99,107,32,84,119,105,110,32,40,115,101,116,32,49,41,0,0,0,83,101,105,98,117,32,75,97,105,104,97,116,115,117,32,40,76,105,97,110,103,32,72,87,65,32,69,108,101,99,116,114,111,110,105,99,115,32,108,105,99,101,110,115,101,41,0,0,80,114,105,109,101,116,101,99,32,73,110,118,101,115,116,109,101,110,116,115,0,0,0,0,83,99,114,111,108,108,50,88,0,0,0,0,0,0,0,0,67,111,109,105,120,32,90,111,110,101,32,40,83,101,103,97,32,67,104,97,110,110,101,108,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,54,49,50,41,0,0,52,48,32,72,105,116,112,111,105,110,116,115,0,0,0,0,77,97,98,111,114,111,115,104,105,32,87,97,114,101,0,0,70,99,114,97,115,104,90,56,48,82,97,109,0,0,0,0,107,101,114,111,112,112,105,0,71,97,109,101,32,68,105,102,102,105,99,117,108,116,121,32,65,0,0,0,0,0,0,0,68,101,98,117,103,32,116,101,115,116,32,109,101,110,117,0,172,48,0,0,243,48,0,0,192,48,0,0,224,48,0,0,32,0,0,0,181,48,0,0,164,48,0,0,179,48,0,0,181,48,0,0,233,48,0,0,222,48,0,0,3,243,0,0,192,48,0,0,252,48,0,0,110,48,0,0,5,129,0,0,1,90,0,0,0,0,0,0,83,0,0,0,68,0,0,0,32,0,0,0,71,0,0,0,117,0,0,0,110,0,0,0,100,0,0,0,97,0,0,0,109,0,0,0,32,0,0,0,80,0,0,0,115,0,0,0,121,0,0,0,99,0,0,0,104,0,0,0,111,0,0,0,32,0,0,0,83,0,0,0,97,0,0,0,108,0,0,0,97,0,0,0,109,0,0,0,97,0,0,0,110,0,0,0,100,0,0,0,101,0,0,0,114,0,0,0,32,0,0,0,110,0,0,0,111,0,0,0,32,0,0,0,75,0,0,0,121,0,0,0,111,0,0,0,117,0,0,0,105,0,0,0,0,0,0,0,0,0,0,0,80,97,112,97,114,97,122,122,105,0,0,0,0,0,0,0,67,114,117,115,104,32,82,111,108,108,101,114,32,40,75,117,114,97,108,32,69,115,99,111,32,45,32,98,111,111,116,108,101,103,63,41,0,0,0,0,109,100,95,99,111,109,105,120,115,99,0,0,0,0,0,0,65,114,99,97,100,101,0,0,78,0,0,0,105,0,0,0,110,0,0,0,106,0,0,0,97,0,0,0,32,0,0,0,22,89,0,0,29,79,0,0,32,0,0,0,71,0,0,0,97,0,0,0,105,0,0,0,100,0,0,0,101,0,0,0,110,0,0,0,32,0,0,0,40,0,0,0,85,0,0,0,83,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,78,111,32,98,117,121,45,105,110,0,0,0,0,0,0,0,50,32,67,111,105,110,115,32,53,32,80,108,97,121,115,0,87,87,70,32,87,114,101,115,116,108,101,70,101,115,116,32,40,85,83,32,98,111,111,116,108,101,103,41,0,0,0,0,82,101,97,108,32,97,110,100,32,70,97,107,101,0,80,104,111,116,111,32,89,50,75,32,40,86,49,48,50,44,32,74,97,112,97,110,41,0,0,0,102,97,110,116,97,115,105,97,97,0,0,0,0,0,0,0,67,111,109,97,100,32,40,65,109,101,114,105,99,97,110,32,83,97,109,109,121,32,108,105,99,101,110,115,101,41,0,0,66,117,114,110,105,110,103,32,65,110,103,101,108,115,0,0,84,101,110,99,104,105,32,119,111,32,75,117,114,97,117,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,82,111,98,111,32,65,114,109,121,0,0,0,0,0,0,0,67,111,109,105,120,32,90,111,110,101,32,40,75,111,114,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,54,48,57,41,0,0,0,98,105,111,109,116,111,121,0,116,107,100,101,110,115,104,111,97,0,0,0,0,0,0,0,77,105,121,97,115,117,32,78,111,110,107,105,32,110,111,32,81,117,105,122,32,49,56,45,75,105,110,0,0,0,0,0,77,105,99,114,111,32,77,97,99,104,105,110,101,115,32,50,32,45,32,84,117,114,98,111,32,84,111,117,114,110,97,109,101,110,116,32,40,69,117,114,111,44,32,74,45,67,97,114,116,41,0,0,0,0,0,0,115,97,105,108,111,114,109,110,106,0,0,0,0,0,0,0,76,111,97,100,32,71,97,109,101,32,40,72,105,115,116,111,114,121,41,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,88,77,76,58,32,83,104,97,100,101,114,32,102,111,114,99,101,115,32,71,76,95,76,73,78,69,65,82,46,10,0,0,0,0,0,0,0,110,111,115,116,0,0,0,0,68,117,110,103,101,111,110,115,32,38,32,68,114,97,103,111,110,115,32,45,32,115,104,97,100,111,119,32,111,118,101,114,32,109,121,115,116,97,114,97,32,40,57,54,48,50,48,54,32,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,53,48,75,32,49,48,48,75,0,0,0,0,0,0,0,0,80,111,119,101,114,32,73,110,115,116,105,110,99,116,32,40,85,83,65,44,32,98,111,111,116,108,101,103,32,115,101,116,32,49,41,0,0,0,0,0,100,105,115,107,95,110,101,120,116,0,0,0,0,0,0,0,80,52,32,66,117,116,116,111,110,32,68,0,0,0,0,0,109,100,95,99,111,109,105,120,107,112,0,0,0,0,0,0,71,88,50,52,56,0,0,0,97,108,105,101,110,99,104,97,99,0,0,0,0,0,0,0,69,120,116,101,110,100,101,100,32,84,101,115,116,32,77,111,100,101,0,0,0,0,0,0,75,97,114,97,116,101,32,66,108,97,122,101,114,115,32,40,87,111,114,108,100,63,41,0,0,0,0,0,0,0,0,0,69,120,99,101,108,115,105,111,114,32,40,115,101,116,32,50,41,0,0,0,0,0,0,0,67,111,109,105,120,32,90,111,110,101,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,53,51,48,41,0,0,0,0,0,0,0,0,100,100,114,97,103,111,110,51,98,0,0,0,0,0,0,0,68,114,118,73,110,112,117,116,115,91,49,93,0,0,0,0,80,52,32,66,117,116,116,111,110,32,67,0,0,0,0,0,109,100,95,99,111,109,105,120,117,112,48,57,0,0,0,0,100,111,110,112,97,99,104,105,107,114,0,0,0,0,0,0,119,101,115,116,115,116,114,121,0,0,0,0,0,0,0,0,65,114,116,105,99,0,0,0,67,111,111,107,105,101,32,38,32,66,105,98,105,32,50,0,0,0,0,0,0,0,0,0,112,51,32,115,101,108,101,99,116,0,0,0,0,0,0,0,67,111,109,105,120,32,90,111,110,101,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,53,50,54,41,0,0,0,0,0,0,0,0,100,100,111,110,112,97,99,104,106,104,0,0,0,0,0,0,81,215,0,0,32,193,0,0,49,188,0,0,172,192,0,0,32,0,0,0,40,0,0,0,75,0,0,0,111,0,0,0,114,0,0,0,101,0,0,0,97,0,0,0,41,0,0,0,0,0,0,0,72,0,0,0,101,0,0,0,117,0,0,0,107,0,0,0,32,0,0,0,83,0,0,0,117,0,0,0,110,0,0,0,32,0,0,0,66,0,0,0,97,0,0,0,101,0,0,0,107,0,0,0,32,0,0,0,83,0,0,0,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,100,114,105,118,101,114,46,99,0,0,0,0,0,0,0,0,68,97,114,97,107,117,32,84,101,110,115,104,105,32,45,32,84,104,101,32,70,97,108,108,101,110,32,65,110,103,101,108,115,0,0,0,0,0,0,0,80,52,32,66,117,116,116,111,110,32,66,0,0,0,0,0,109,100,95,99,111,109,105,120,117,112,49,48,0,0,0,0,84,105,103,101,114,32,82,111,97,100,32,40,85,83,32,98,111,111,116,108,101,103,41,0,0,0,0,0,0,0,0,0,83,101,97,116,111,110,103,114,111,118,101,32,76,116,100,32,40,77,97,103,105,99,32,69,108,101,116,114,111,110,105,99,115,32,85,83,65,32,108,105,99,101,110,115,101,41,0,0,99,99,108,105,109,98,114,50,97,0,0,0,0,0,0,0,67,111,109,105,120,32,90,111,110,101,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,54,48,51,41,0,0,0,97,111,102,50,0,0,0,0,80,50,32,83,112,101,99,105,97,108,0,0,0,0,0,0,68,105,112,32,67,0,0,0,67,104,105,110,97,0,0,0,77,97,104,106,111,110,103,32,71,97,107,117,101,110,32,50,32,71,97,107,117,101,110,45,99,104,111,117,32,110,111,32,70,117,107,117,115,104,117,117,0,0,0,0,0,0,0,0,84,104,101,32,78,105,110,106,97,32,75,105,100,115,32,40,85,83,41,0,0,0,0,0,69,103,103,115,0,0,0,0,97,117,116,111,115,97,118,101,95,105,110,116,101,114,118,97,108,0,0,0,0,0,0,0,119,119,102,115,115,116,97,114,106,0,0,0,0,0,0,0,75,97,110,103,97,114,111,111,32,40,65,116,97,114,105,41,0,0,0,0,0,0,0,0,80,52,32,66,117,116,116,111,110,32,65,0,0,0,0,0,109,100,95,99,111,109,105,120,117,112,48,50,0,0,0,0,80,114,101,104,105,115,116,111,114,105,99,32,73,115,108,101,32,105,110,32,49,57,51,48,32,40,75,111,114,101,97,41,0,0,0,0,0,0,0,0,112,50,32,102,105,114,101,32,54,0,0,0,0,0,0,0,83,121,115,116,101,109,32,49,54,67,0,0,0,0,0,0,97,103,114,101,115,115,0,0,68,101,99,101,109,98,101,114,0,0,0,0,0,0,0,0,115,116,97,114,106,97,99,107,115,0,0,0,0,0,0,0,68,114,118,90,56,48,66,97,110,107,48,0,0,0,0,0,67,111,109,109,117,110,105,99,97,116,105,111,110,0,0,0,98,106,116,119,105,110,0,0,56,48,0,0,0,0,0,0,80,117,99,107,77,97,110,32,40,115,112,101,101,100,117,112,32,104,97,99,107,41,0,0,83,99,114,111,108,108,49,89,0,0,0,0,0,0,0,0,67,111,109,105,120,32,90,111,110,101,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,54,48,50,41,0,0,0,51,50,32,72,105,116,112,111,105,110,116,115,0,0,0,0,103,97,117,110,116,108,101,116,103,0,0,0,0,0,0,0,79,114,98,115,32,40,49,48,47,55,47,57,52,32,112,114,111,116,111,116,121,112,101,63,41,0,0,0,0,0,0,0,100,101,112,111,115,105,116,115,50,0,0,0,0,0,0,0,84,101,104,107,97,110,32,40,84,101,99,102,114,105,32,76,105,99,101,110,115,101,41,0,85,83,65,32,47,32,67,97,110,97,100,97,32,40,74,97,108,101,99,111,32,108,105,99,101,110,115,101,41,0,0,0,116,111,112,115,101,99,114,116,0,0,0,0,0,0,0,0,112,97,99,108,97,110,100,106,111,50,0,0,0,0,0,0,99,114,117,115,104,50,0,0,68,73,80,56,0,0,0,0,77,114,46,32,68,111,33,32,40,98,117,103,102,105,120,101,100,41,0,0,0,0,0,0,109,100,95,99,111,109,105,120,117,112,48,51,0,0,0,0,76,97,100,121,32,66,117,103,32,40,98,111,111,116,108,101,103,32,115,101,116,32,50,41,0,0,0,0,0,0,0,0,52,32,67,111,105,110,115,32,50,32,67,114,101,100,105,116,0,0,0,0,0,0,0,0,83,111,108,111,109,111,110,73,114,113,70,105,114,101,0,0,49,115,116,0,0,0,0,0,67,97,112,99,111,109,32,40,82,111,109,115,116,97,114,32,76,105,99,101,110,115,101,41,0,0,0,0,0,0,0,0,46,46,0,0,0,0,0,0,112,104,111,116,111,121,50,107,49,48,50,0,0,0,0,0,116,101,114,114,97,99,114,101,110,0,0,0,0,0,0,0,112,99,101,95,98,117,114,110,97,110,103,108,0,0,0,0,100,121,110,119,97,114,106,0,84,97,100,32,40,70,97,98,116,101,107,32,108,105,99,101,110,115,101,41,0,0,0,0,112,111,114,116,55,48,0,0,67,111,109,105,120,32,90,111,110,101,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,54,48,50,45,66,41,0,0,0,0,0,0,0,0,0,65,108,108,32,67,80,85,32,35,48,32,82,97,109,0,0,80,97,121,32,83,119,105,116,99,104,0,0,0,0,0,0,49,57,52,50,98,0,0,0,83,112,114,105,116,101,32,82,97,109,0,0,0,0,0,0,109,100,95,109,105,99,114,111,109,99,50,0,0,0,0,0,73,110,112,117,116,32,100,114,105,118,101,114,0,0,0,0,103,98,101,114,101,116,95,115,112,114,105,116,101,98,97,110,107,0,0,0,0,0,0,0,109,101,116,114,111,99,114,115,97,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,88,77,76,58,32,83,104,97,100,101,114,32,102,111,114,99,101,115,32,71,76,95,78,69,65,82,69,83,84,46,10,0,0,0,0,0,0,100,100,115,111,109,106,114,49,0,0,0,0,0,0,0,0,51,48,75,32,56,48,75,0,100,105,115,107,95,101,106,101,99,116,95,116,111,103,103,108,101,0,0,0,0,0,0,0,76,101,103,101,110,100,97,114,121,32,87,105,110,103,115,32,40,85,83,32,115,101,116,32,49,41,0,0,0,0,0,0,109,100,95,99,111,109,105,120,117,112,48,52,0,0,0,0,81,117,105,122,32,71,97,107,117,109,111,110,32,110,111,32,83,117,115,117,109,101,32,40,74,97,112,97,110,32,118,101,114,46,32,74,65,49,32,84,121,112,101,32,72,41,0,0,84,101,116,114,105,115,32,40,98,111,111,116,108,101,103,32,115,101,116,32,49,41,0,0,83,104,111,119,32,83,119,105,116,99,104,0,0,0,0,0,116,114,101,97,104,117,110,116,0,0,0,0,0,0,0,0,83,65,82,32,45,32,83,101,97,114,99,104,32,65,110,100,32,82,101,115,99,117,101,32,40,87,111,114,108,100,41,0,0,0,0,0,0,0,0,0,86,101,99,116,111,114,32,82,65,77,0,0,0,0,0,0,83,101,110,106,111,117,32,110,111,32,79,111,107,97,109,105,0,0,0,0,0,0,0,0,67,111,109,105,120,32,90,111,110,101,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,54,48,49,41,0,0,0,49,0,0,0,57,0,0,0,52,0,0,0,51,0,0,0,58,0,0,0,32,0,0,0,223,48,0,0,195,48,0,0,201,48,0,0,166,48,0,0,167,48,0,0,164,48,0,0,119,109,0,0,38,98,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,44,0,0,0,32,0,0,0,82,0,0,0,101,0,0,0,118,0,0,0,32,0,0,0,66,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,82,105,103,104,116,32,83,119,105,116,99,104,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,71,114,97,98,32,109,111,117,115,101,32,115,116,97,116,101,58,32,37,115,46,10,0,0,0,0,0,0,0,100,121,110,100,117,107,101,117,0,0,0,0,0,0,0,0,78,101,107,107,101,116,115,117,32,75,111,117,104,97,32,75,117,110,105,111,45,107,117,110,32,40,74,97,112,97,110,32,98,111,111,116,108,101,103,41,0,0,0,0,0,0,0,0,68,83,80,32,99,111,110,102,105,103,0,0,0,0,0,0,109,100,95,99,111,109,105,120,117,112,48,53,0,0,0,0,108,97,115,116,100,117,101,108,98,0,0,0,0,0,0,0,76,101,102,116,32,83,119,105,116,99,104,0,0,0,0,0,115,102,106,0,0,0,0,0,67,97,112,99,111,109,32,40,84,101,99,102,114,105,32,108,105,99,101,110,115,101,41,0,115,107,121,107,105,100,115,0,87,99,57,48,98,49,83,111,117,110,100,76,97,116,99,104,0,0,0,0,0,0,0,0,68,101,102,101,110,100,32,116,104,101,32,84,101,114,114,97,32,65,116,116,97,99,107,32,111,110,32,116,104,101,32,82,101,100,32,85,70,79,0,0,109,114,102,108,101,97,95,115,116,97,116,117,115,0,0,0,67,111,109,105,120,32,90,111,110,101,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,54,48,49,45,68,41,0,0,0,0,0,0,0,0,0,78,97,109,99,111,32,40,77,105,100,119,97,121,32,76,105,99,101,110,115,101,41,0,0,119,99,57,48,116,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,115,97,118,101,32,83,82,65,77,46,10,0,0,0,0,0,0,65,109,98,117,115,104,32,40,104,97,99,107,63,41,0,0,109,100,95,99,111,109,105,120,117,112,48,54,0,0,0,0,114,121,103,97,114,106,0,0,97,100,100,114,95,65,49,0,68,111,117,98,108,101,32,68,114,97,103,111,110,32,40,87,111,114,108,100,32,115,101,116,32,50,41,0,0,0,0,0,109,95,111,108,100,115,95,112,114,111,116,95,104,105,108,111,95,115,101,108,101,99,116,0,67,111,109,105,120,32,90,111,110,101,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,54,48,49,45,67,41,0,0,0,0,0,0,0,0,0,80,50,32,75,105,99,107,0,68,105,112,32,66,0,0,0,75,111,114,101,97,0,0,0,116,105,108,116,0,0,0,0,111,114,108,101,103,101,110,100,101,0,0,0,0,0,0,0,110,105,110,106,97,107,117,0,112,97,117,115,101,95,110,111,110,97,99,116,105,118,101,0,51,50,55,54,56,0,0,0,109,100,95,99,111,109,105,120,117,112,48,55,0,0,0,0,69,117,114,111,0,0,0,0,83,101,103,97,32,47,32,77,50,0,0,0,0,0,0,0,84,101,115,116,32,77,111,100,101,32,68,105,115,112,108,97,121,0,0,0,0,0,0,0,78,111,118,101,109,98,101,114,0,0,0,0,0,0,0,0,83,116,97,114,32,74,97,99,107,101,114,32,40,83,101,103,97,41,0,0,0,0,0,0,108,97,121,101,114,95,99,116,114,108,0,0,0,0,0,0,67,97,99,116,117,115,32,40,98,111,111,116,108,101,103,32,111,102,32,83,97,98,111,116,101,110,32,66,111,109,98,101,114,115,41,0,0,0,0,0,83,99,114,111,108,108,49,88,0,0,0,0,0,0,0,0,67,111,109,105,120,32,90,111,110,101,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,54,48,49,45,66,41,0,0,0,0,0,0,0,0,0,85,112,114,105,103,104,116,32,50,32,80,108,97,121,101,114,115,0,0,0,0,0,0,0,112,101,114,105,111,100,0,0,72,101,97,108,116,104,32,80,97,99,107,0,0,0,0,0,111,114,98,115,0,0,0,0,112,99,101,95,97,100,118,105,115,108,110,100,0,0,0,0,112,99,101,95,115,102,50,95,98,97,110,107,0,0,0,0,69,110,97,98,108,101,32,100,101,98,117,103,32,100,105,112,0,0,0,0,0,0,0,0,67,114,117,115,104,32,82,111,108,108,101,114,32,40,98,111,111,116,108,101,103,32,115,101,116,32,51,41,0,0,0,0,109,100,95,99,111,109,105,120,117,112,48,56,0,0,0,0,69,110,101,109,121,32,70,105,114,101,32,82,97,116,101,0,80,0,0,0,104,0,0,0,111,0,0,0,116,0,0,0,111,0,0,0,32,0,0,0,89,0,0,0,50,0,0,0,75,0,0,0,0,0,0,0,234,48,0,0,162,48,0,0,235,48,0,0,162,48,0,0,243,48,0,0,201,48,0,0,32,0,0,0,213,48,0,0,167,48,0,0,164,48,0,0,175,48,0,0,0,0,0,0,39,89,0,0,182,91,0,0,101,103,0,0,32,0,0,0,126,98,0,0,180,120,0,0,0,0,0,0,133,141,0,0,167,126,0,0,32,0,0,0,212,107,0,0,0,78,0,0,212,107,0,0,32,0,0,0,40,0,0,0,86,0,0,0,49,0,0,0,48,0,0,0,52,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,67,114,101,97,109,0,0,0,67,108,101,97,114,32,82,65,77,0,0,0,0,0,0,0,68,121,110,97,115,116,121,32,87,97,114,115,32,40,85,83,32,115,101,116,32,50,41,0,0,0,0,0,0,0,0,0,70,0,0,0,97,0,0,0,116,0,0,0,97,0,0,0,108,0,0,0,32,0,0,0,70,0,0,0,117,0,0,0,114,0,0,0,121,0,0,0,32,0,0,0,45,0,0,0,32,0,0,0,75,0,0,0,105,0,0,0,110,0,0,0,103,0,0,0,32,0,0,0,111,0,0,0,102,0,0,0,32,0,0,0,70,0,0,0,105,0,0,0,103,0,0,0,104,0,0,0,116,0,0,0,101,0,0,0,114,0,0,0,115,0,0,0,0,0,0,0,19,153,0,0,252,114,0,0,29,79,0,0,172,138,0,0,32,0,0,0,45,0,0,0,32,0,0,0,191,91,0,0,125,84,0,0,110,48,0,0,216,149,0,0,68,48,0,0,32,0,0,0,40,0,0,0,78,0,0,0,71,0,0,0,77,0,0,0,45,0,0,0,48,0,0,0,51,0,0,0,51,0,0,0,41,0,0,0,40,0,0,0,78,0,0,0,71,0,0,0,72,0,0,0,45,0,0,0,48,0,0,0,51,0,0,0,51,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,67,111,109,105,120,32,90,111,110,101,32,40,69,117,114,111,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,55,49,50,41,0,0,67,112,115,82,111,109,0,0,69,120,116,114,97,32,78,86,82,65,77,0,0,0,0,0,49,57,52,49,106,0,0,0,77,101,103,97,32,71,97,109,101,115,32,54,32,86,111,108,46,32,51,32,40,69,117,114,111,41,0,0,0,0,0,0,65,117,100,105,111,32,100,114,105,118,101,114,0,0,0,0,103,98,101,114,101,116,98,95,115,99,114,111,108,108,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,73,110,118,97,108,105,100,32,76,85,84,32,102,105,108,116,101,114,32,116,121,112,101,46,10,0,0,68,117,110,103,101,111,110,115,32,38,32,68,114,97,103,111,110,115,32,45,32,115,104,97,100,111,119,32,111,118,101,114,32,109,121,115,116,97,114,97,32,40,57,54,48,54,49,57,32,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,111,118,101,114,108,97,121,95,110,101,120,116,0,0,0,0,109,100,95,99,111,109,105,120,117,112,48,49,0,0,0,0,74,111,121,115,116,105,99,107,32,67,111,110,102,105,103,117,114,97,116,105,111,110,0,0,69,118,101,114,121,32,116,104,105,114,100,32,115,111,117,110,100,0,0,0,0,0,0,0,67,111,109,105,120,32,90,111,110,101,32,40,74,112,110,41,0,0,0,0,0,0,0,0,69,118,101,114,121,32,115,101,99,111,110,100,32,115,111,117,110,100,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,114,101,115,117,109,101,32,97,117,100,105,111,32,100,114,105,118,101,114,46,32,87,105,108,108,32,99,111,110,116,105,110,117,101,32,119,105,116,104,111,117,116,32,97,117,100,105,111,46,10,0,0,0,0,0,0,0,68,101,108,116,97,84,46,97,100,112,99,109,108,0,0,0,105,110,118,97,108,105,100,32,99,111,100,101,32,108,101,110,103,116,104,115,32,115,101,116,0,0,0,0,0,0,0,0,80,51,32,66,117,116,116,111,110,32,68,0,0,0,0,0,109,100,95,99,111,109,105,120,106,0,0,0,0,0,0,0,103,108,67,111,112,121,84,101,120,83,117,98,73,109,97,103,101,51,68,79,69,83,0,0,83,76,79,84,45,62,70,66,0,0,0,0,0,0,0,0,117,110,105,102,111,114,109,32,115,97,109,112,108,101,114,50,68,32,84,101,120,116,117,114,101,59,10,105,110,32,118,101,99,50,32,116,101,120,95,99,111,111,114,100,59,10,105,110,32,118,101,99,52,32,99,111,108,111,114,59,10,111,117,116,32,118,101,99,52,32,70,114,97,103,67,111,108,111,114,59,10,118,111,105,100,32,109,97,105,110,40,41,32,123,10,32,32,32,70,114,97,103,67,111,108,111,114,32,61,32,99,111,108,111,114,32,42,32,116,101,120,116,117,114,101,40,84,101,120,116,117,114,101,44,32,116,101,120,95,99,111,111,114,100,41,59,10,125,0,0,0,0,114,101,100,117,102,111,0,0,67,111,109,105,120,32,90,111,110,101,32,40,69,117,114,111,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,54,50,56,41,0,0,68,101,109,111,32,83,111,117,110,100,32,83,101,116,117,112,0,0,0,0,0,0,0,0,65,32,49,67,47,50,80,32,50,67,47,53,80,32,32,66,32,49,67,47,53,80,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,71,76,93,58,32,70,97,105,108,101,100,32,116,111,32,99,114,101,97,116,101,32,72,87,32,114,101,110,100,101,114,32,70,66,79,32,35,37,117,44,32,101,114,114,111,114,58,32,48,120,37,117,46,10,0,0,0,0,80,51,32,66,117,116,116,111,110,32,67,0,0,0,0,0,109,100,95,99,111,109,105,120,112,0,0,0,0,0,0,0,65,32,49,67,47,50,80,32,50,67,47,52,80,32,32,66,32,49,67,47,52,80,0,0,109,100,95,106,98,48,48,55,0,0,0,0,0,0,0,0,67,111,109,105,120,32,90,111,110,101,32,40,69,117,114,111,41,0,0,0,0,0,0,0,75,48,53,50,49,48,57,67,104,97,114,82,111,109,66,97,110,107,91,49,93,0,0,0,80,50,32,80,117,110,99,104,0,0,0,0,0,0,0,0,65,32,49,67,47,49,80,32,50,67,47,51,80,32,32,66,32,49,67,47,51,80,0,0,100,105,112,0,0,0,0,0,72,111,110,103,75,111,110,103,0,0,0,0,0,0,0,0,84,105,108,116,0,0,0,0,97,107,117,109,97,106,111,117,0,0,0,0,0,0,0,0,114,105,110,103,111,104,106,97,0,0,0,0,0,0,0,0,84,104,101,32,78,105,110,106,97,32,75,105,100,115,32,40,74,97,112,97,110,41,0,0,97,108,105,101,110,115,117,0,102,97,115,116,102,111,114,119,97,114,100,95,114,97,116,105,111,0,0,0,0,0,0,0,80,51,32,66,117,116,116,111,110,32,66,0,0,0,0,0,109,100,95,99,111,109,105,120,0,0,0,0,0,0,0,0,112,97,114,111,100,105,117,115,106,0,0,0,0,0,0,0,78,47,65,32,40,115,116,111,99,107,41,0,0,0,0,0,70,97,110,116,97,115,121,32,90,111,110,101,32,73,73,32,45,32,84,104,101,32,84,101,97,114,115,32,111,102,32,79,112,97,45,79,112,97,32,40,83,121,115,116,101,109,32,49,54,67,41,0,0,0,0,0,98,97,110,107,50,0,0,0,79,99,116,111,98,101,114,0,115,116,97,114,106,97,99,107,0,0,0,0,0,0,0,0,65,32,49,67,47,49,80,32,50,67,47,51,80,32,32,66,32,49,67,47,50,80,0,0,116,120,98,97,110,107,0,0,77,0,0,0,97,0,0,0,105,0,0,0,110,0,0,0,32,0,0,0,83,0,0,0,116,0,0,0,97,0,0,0,100,0,0,0,105,0,0,0,117,0,0,0,109,0,0,0,0,0,0,0,225,48,0,0,164,48,0,0,243,48,0,0,185,48,0,0,191,48,0,0,184,48,0,0,162,48,0,0,224,48,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,32,0,0,0,118,0,0,0,101,0,0,0,114,0,0,0,46,0,0,0,32,0,0,0,52,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,114,97,109,98,97,110,107,0,84,104,117,110,100,101,114,32,67,114,111,115,115,32,40,115,101,116,32,49,41,0,0,0,99,97,99,116,117,115,0,0,84,121,112,101,32,50,0,0,112,50,32,115,101,108,101,99,116,0,0,0,0,0,0,0,67,111,109,98,97,116,32,67,97,114,115,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,0,0,0,85,112,114,105,103,104,116,32,49,32,80,108,97,121,101,114,0,0,0,0,0,0,0,0,65,106,97,120,32,40,74,97,112,97,110,41,0,0,0,0,65,110,97,108,111,103,0,0,80,108,97,121,101,114,32,66,117,108,108,101,116,32,83,112,101,101,100,0,0,0,0,0,80,97,105,114,115,32,76,111,118,101,0,0,0,0,0,0,99,111,110,116,114,97,106,0,85,83,65,32,47,32,67,97,110,97,100,97,0,0,0,0,120,109,101,110,101,0,0,0,99,114,117,115,104,98,108,51,0,0,0,0,0,0,0,0,115,116,121,108,101,0,0,0,68,97,114,107,32,65,100,118,101,110,116,117,114,101,0,0,80,51,32,66,117,116,116,111,110,32,65,0,0,0,0,0,109,100,95,99,111,109,98,97,116,99,97,0,0,0,0,0,71,114,97,100,105,117,115,32,73,73,73,32,40,65,115,105,97,41,0,0,0,0,0,0,51,48,48,48,48,44,32,70,97,115,116,101,115,116,0,0,51,114,100,0,0,0,0,0,68,114,118,51,102,57,48,111,108,100,0,0,0,0,0,0,71,121,114,117,115,115,32,40,98,111,111,116,108,101,103,41,0,0,0,0,0,0,0,0,80,104,111,116,111,32,89,50,75,32,47,32,82,101,97,108,32,97,110,100,32,70,97,107,101,32,40,86,49,48,52,41,0,0,0,0,0,0,0,0,49,57,120,120,104,0,0,0,118,101,110,100,101,116,116,97,50,112,117,0,0,0,0,0,66,117,108,108,32,70,105,103,104,116,32,45,32,82,105,110,103,32,110,111,32,72,97,106,97,0,0,0,0,0,0,0,100,121,110,119,97,114,97,0,70,97,116,97,108,32,70,117,114,121,32,45,32,75,105,110,103,32,111,102,32,70,105,103,104,116,101,114,115,32,47,32,71,97,114,111,117,32,68,101,110,115,101,116,115,117,32,45,32,115,104,117,107,117,109,101,105,32,110,111,32,116,97,116,97,107,97,105,32,40,78,71,77,45,48,51,51,41,40,78,71,72,45,48,51,51,41,0,0,0,0,0,0,0,0,0,67,111,109,98,97,116,32,65,99,101,115,32,40,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,0,0,0,115,105,109,112,115,111,110,115,50,112,50,0,0,0,0,0,80,111,111,116,97,110,0,0,50,48,48,48,48,44,32,70,97,115,116,0,0,0,0,0,111,118,101,114,108,97,121,37,117,95,110,97,109,101,0,0,109,100,95,109,101,103,97,103,97,54,51,0,0,0,0,0,116,109,104,116,0,0,0,0,86,105,100,101,111,32,100,114,105,118,101,114,0,0,0,0,109,114,103,111,101,109,111,110,95,98,97,110,107,0,0,0,110,101,97,114,101,115,116,0,100,100,115,111,109,106,0,0,60,33,45,45,0,0,0,0,66,111,109,98,101,114,32,77,97,110,32,40,74,97,112,97,110,41,0,0,0,0,0,0,118,111,108,117,109,101,95,100,111,119,110,0,0,0,0,0,109,100,95,99,111,109,98,97,116,0,0,0,0,0,0,0,113,103,97,107,117,109,111,110,0,0,0,0,0,0,0,0,83,112,97,114,116,97,110,32,88,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,49,50,48,48,48,44,32,77,101,100,105,117,109,0,0,0,73,114,101,109,32,40,68,97,116,97,32,69,97,115,116,32,85,83,65,32,76,105,99,101,110,115,101,41,0,0,0,0,97,116,111,109,98,111,121,97,0,0,0,0,0,0,0,0,104,111,111,107,106,0,0,0,67,111,108,117,109,110,115,32,73,73,73,32,45,32,84,97,105,107,101,116,115,117,33,32,67,111,108,117,109,110,115,32,87,111,114,108,100,32,40,74,112,110,44,32,75,111,114,41,0,0,0,0,0,0,0,0,114,116,121,112,101,117,0,0,82,101,116,114,111,65,114,99,104,58,32,85,110,112,97,117,115,101,100,46,10,0,0,0,78,111,110,101,44,32,83,108,111,119,0,0,0,0,0,0,84,97,107,101,32,115,99,114,101,101,110,115,104,111,116,0,109,100,95,99,111,108,117,109,110,115,51,106,0,0,0,0,80,97,121,111,117,116,32,82])
.concat([97,116,101,32,83,101,116,117,112,0,0,0,0,0,0,0,66,111,110,117,115,32,76,105,102,101,32,47,32,69,110,101,109,121,32,66,117,108,108,101,116,32,83,112,101,101,100,0,87,97,114,32,111,102,32,116,104,101,32,66,117,103,115,32,111,114,32,77,111,110,115,116,101,114,111,117,115,32,77,97,110,111,117,118,101,114,115,32,105,110,32,97,32,77,117,115,104,114,111,111,109,32,77,97,122,101,32,40,85,83,41,0,0,0,0,0,0,0,0,0,67,111,108,117,109,110,115,32,73,73,73,32,45,32,82,101,118,101,110,103,101,32,111,102,32,67,111,108,117,109,110,115,32,40,85,83,65,41,0,0,80,97,121,111,117,116,32,77,111,100,101,0,0,0,0,0,55,48,48,48,48,48,0,0,109,100,95,99,111,108,117,109,110,115,51,0,0,0,0,0,67,114,101,100,105,116,32,77,111,100,101,0,0,0,0,0,65,32,49,67,47,50,80,32,32,66,32,49,67,47,49,50,80,0,0,0,0,0,0,0,67,111,108,117,109,110,115,32,40,87,111,114,108,100,41,0,0,0,0,0,0,0,0,0,80,50,32,82,111,116,97,116,101,32,82,105,103,104,116,0,80,97,121,111,117,116,32,83,101,116,117,112,0,0,0,0,83,116,97,114,116,32,49,32,47,32,70,105,114,101,32,50,0,0,0,0,0,0,0,0,68,105,112,32,65,0,0,0,84,97,105,119,97,110,0,0,90,56,48,66,117,115,82,81,0,0,0,0,0,0,0,0,110,105,110,106,97,107,106,0,115,108,111,119,109,111,116,105,111,110,95,114,97,116,105,111,0,0,0,0,0,0,0,0,109,100,95,99,111,108,117,109,110,115,49,0,0,0,0,0,102,97,110,116,122,110,50,120,0,0,0,0,0,0,0,0,49,48,32,89,101,110,32,83,101,116,117,112,0,0,0,0,83,101,112,116,101,109,98,101,114,0,0,0,0,0,0,0,83,97,110,114,105,110,32,83,97,110,32,67,104,97,110,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,65,32,50,67,47,49,80,32,32,66,32,49,67,47,50,80,0,0,0,0,0,0,0,0,98,103,98,111,116,115,99,114,111,108,108,0,0,0,0,0,83,97,98,111,116,101,110,32,66,111,109,98,101,114,115,32,40,115,101,116,32,50,41,0,0,0,0,0,0,0,0,0,67,111,108,117,109,110,115,32,40,87,111,114,108,100,44,32,118,49,46,49,41,0,0,0,68,105,103,105,116,97,108,0,80,101,114,99,101,110,116,97,103,101,32,116,111,32,82,101,118,101,97,108,0,0,0,0,78,111,32,99,104,97,110,103,101,0,0,0,0,0,0,0,65,32,51,67,47,49,80,32,32,66,32,49,67,47,51,80,0,0,0,0,0,0,0,0,112,97,105,114,108,111,118,101,0,0,0,0,0,0,0,0,67,114,117,115,104,32,82,111,108,108,101,114,32,40,98,111,111,116,108,101,103,32,115,101,116,32,50,41,0,0,0,0,109,100,95,99,111,108,117,109,110,115,0,0,0,0,0,0,52,48,48,48,48,32,97,110,100,32,101,118,101,114,121,32,49,48,48,48,48,48,0,0,65,32,52,67,47,49,80,32,32,66,32,49,67,47,52,80,0,0,0,0,0,0,0,0,52,32,67,111,105,110,115,32,51,32,80,108,97,121,115,0,112,104,111,116,111,121,50,107,49,48,52,0,0,0,0,0,112,99,101,95,98,117,108,108,102,103,104,116,0,0,0,0,68,121,110,97,115,116,121,32,87,97,114,115,32,40,85,83,32,115,101,116,32,49,41,0,0,0,0,0,0,0,0,0,102,97,116,102,117,114,121,49,0,0,0,0,0,0,0,0,67,111,108,108,101,103,101,32,83,108,97,109,32,40,85,83,65,41,0,0,0,0,0,0,65,32,50,67,47,50,80,32,32,66,32,49,67,47,51,80,0,0,0,0,0,0,0,0,77,101,103,97,32,66,111,109,98,101,114,109,97,110,32,40,69,117,114,111,44,32,75,111,114,41,0,0,0,0,0,0,49,32,67,111,105,110,32,57,57,32,67,114,101,100,105,116,115,0,0,0,0,0,0,0,82,97,116,101,32,67,111,110,116,114,111,108,32,68,101,108,116,97,0,0,0,0,0,0,108,105,110,101,97,114,0,0,68,117,110,103,101,111,110,115,32,38,32,68,114,97,103,111,110,115,32,45,32,115,104,97,100,111,119,32,111,118,101,114,32,109,121,115,116,97,114,97,32,40,57,54,48,50,50,51,32,72,105,115,112,97,110,105,99,41,0,0,0,0,0,0,118,111,108,117,109,101,95,117,112,0,0,0,0,0,0,0,109,100,95,99,111,108,108,115,108,97,109,0,0,0,0,0,84,101,101,110,97,103,101,32,77,117,116,97,110,116,32,78,105,110,106,97,32,84,117,114,116,108,101,115,32,45,32,84,117,114,116,108,101,115,32,105,110,32,84,105,109,101,32,40,52,32,80,108,97,121,101,114,115,32,118,101,114,46,32,65,68,65,41,0,0,0,0,0,49,32,67,111,105,110,32,32,57,32,67,114,101,100,105,116,115,0,0,0,0,0,0,0,65,32,50,67,47,49,80,32,32,66,32,49,67,47,50,80,32,50,67,47,53,80,0,0,67,111,108,108,101,103,101,32,70,111,111,116,98,97,108,108,39,115,32,78,97,116,105,111,110,97,108,32,67,104,97,109,112,105,111,110,115,104,105,112,32,73,73,32,40,85,83,65,41,0,0,0,0,0,0,0,67,104,97,110,103,101,32,83,101,116,117,112,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,80,97,117,115,101,100,46,10,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,109,101,109,111,114,121,32,102,111,114,32,114,101,119,105,110,100,32,98,117,102,102,101,114,46,10,0,0,0,0,0,0,65,32,49,67,47,50,80,32,32,66,32,49,67,47,54,80,0,0,0,0,0,0,0,0,109,100,95,99,111,108,108,110,99,50,0,0,0,0,0,0,49,48,32,89,101,110,0,0,49,67,47,52,67,44,32,49,67,47,50,67,0,0,0,0,119,97,114,111,102,98,117,103,117,0,0,0,0,0,0,0,67,111,108,108,101,103,101,32,70,111,111,116,98,97,108,108,39,115,32,78,97,116,105,111,110,97,108,32,67,104,97,109,112,105,111,110,115,104,105,112,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,53,51,49,41,0,0,71,97,108,83,111,117,110,100,76,97,116,99,104,0,0,0,49,48,48,32,89,101,110,0,49,67,47,50,67,44,32,49,67,47,49,67,0,0,0,0,56,48,48,48,48,48,0,0,67,111,105,110,32,83,101,116,117,112,0,0,0,0,0,0,109,100,95,99,111,108,108,110,99,112,48,57,0,0,0,0,110,81,115,110,100,90,66,97,110,107,0,0,0,0,0,0,71,97,108,86,111,108,0,0,67,111,108,108,101,103,101,32,70,111,111,116,98,97,108,108,39,115,32,78,97,116,105,111,110,97,108,32,67,104,97,109,112,105,111,110,115,104,105,112,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,53,50,53,41,0,0,107,111,102,57,52,0,0,0,80,50,32,82,111,116,97,116,101,32,76,101,102,116,0,0,68,111,110,39,116,32,117,115,101,0,0,0,0,0,0,0,52,48,48,48,48,32,54,48,48,48,48,0,0,0,0,0,100,105,97,103,0,0,0,0,78,101,119,32,90,101,97,108,97,110,100,0,0,0,0,0,66,114,105,110,107,32,84,105,109,101,0,0,0,0,0,0,110,83,111,117,110,100,68,97,116,97,0,0,0,0,0,0,84,104,101,32,78,105,110,106,97,32,75,105,100,115,32,40,87,111,114,108,100,41,0,0,114,101,119,105,110,100,95,103,114,97,110,117,108,97,114,105,116,121,0,0,0,0,0,0,109,100,95,99,111,108,108,110,99,112,49,48,0,0,0,0,69,120,99,105,116,101,32,76,101,97,103,117,101,32,40,70,68,49,48,57,52,32,51,49,55,45,48,48,55,57,41,0,0,0,0,0,0,0,0,0,49,32,77,101,100,97,108,32,49,32,67,114,101,100,105,116,0,0,0,0,0,0,0,0,65,117,103,117,115,116,0,0,115,115,97,110,99,104,97,110,0,0,0,0,0,0,0,0,98,103,116,111,112,115,99,114,111,108,108,0,0,0,0,0,115,97,98,111,116,101,110,98,97,0,0,0,0,0,0,0,66,108,111,111,100,32,67,111,108,111,114,0,0,0,0,0,70,115,116,97,114,102,114,99,68,105,112,0,0,0,0,0,67,111,108,108,101,103,101,32,70,111,111,116,98,97,108,108,39,115,32,78,97,116,105,111,110,97,108,32,67,104,97,109,112,105,111,110,115,104,105,112,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,53,50,48,41,0,0,77,97,110,121,32,80,108,97,121,101,114,0,0,0,0,0,76,101,118,101,114,32,84,121,112,101,0,0,0,0,0,0,77,105,110,105,109,117,109,32,67,114,101,100,105,116,115,32,116,111,32,83,116,97,114,116,0,0,0,0,0,0,0,0,77,101,100,97,108,32,83,101,116,117,112,0,0,0,0,0,71,97,109,101,32,83,101,108,101,99,116,32,83,119,105,116,99,104,0,0,0,0,0,0,69,118,101,114,121,32,56,48,48,44,48,48,48,32,112,111,105,110,116,115,0,0,0,0,87,111,114,108,100,32,40,68,111,101,115,32,78,111,116,32,83,104,111,119,32,86,101,114,115,105,111,110,32,78,117,109,98,101,114,41,0,0,0,0,99,114,117,115,104,98,108,50,0,0,0,0,0,0,0,0,109,100,95,99,111,108,108,110,99,112,49,49,0,0,0,0,51,48,48,48,48,32,97,110,100,32,101,118,101,114,121,32,56,48,48,48,48,0,0,0,69,82,71,0,0,0,0,0,67,112,115,90,82,97,109,67,48,0,0,0,0,0,0,0,52,48,107,44,32,55,48,107,32,97,110,100,32,101,118,101,114,121,32,56,48,107,0,0,71,88,32,68,105,112,32,50,0,0,0,0,0,0,0,0,68,114,118,65,68,80,67,77,68,97,116,97,0,0,0,0,80,0,0,0,104,0,0,0,111,0,0,0,116,0,0,0,111,0,0,0,32,0,0,0,89,0,0,0,50,0,0,0,75,0,0,0,0,0,0,0,234,48,0,0,162,48,0,0,235,48,0,0,162,48,0,0,243,48,0,0,201,48,0,0,32,0,0,0,213,48,0,0,167,48,0,0,164,48,0,0,175,48,0,0,0,0,0,0,39,89,0,0,182,91,0,0,101,103,0,0,32,0,0,0,126,98,0,0,180,120,0,0,0,0,0,0,133,141,0,0,167,126,0,0,32,0,0,0,212,107,0,0,0,78,0,0,212,107,0,0,32,0,0,0,40,0,0,0,86,0,0,0,49,0,0,0,48,0,0,0,53,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,66,117,98,98,108,101,103,117,109,32,67,114,97,115,104,33,32,45,32,75,110,105,103,104,116,32,83,97,98,101,114,115,32,50,48,51,52,0,0,0,83,111,99,99,101,114,32,66,114,97,119,108,32,40,78,71,72,45,48,51,49,41,0,0,67,111,108,108,101,103,101,32,70,111,111,116,98,97,108,108,39,115,32,78,97,116,105,111,110,97,108,32,67,104,97,109,112,105,111,110,115,104,105,112,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,53,49,55,45,65,41,0,0,0,0,0,0,0,0,51,48,107,44,32,54,48,107,32,97,110,100,32,101,118,101,114,121,32,55,48,107,0,0,71,88,32,68,105,112,32,49,0,0,0,0,0,0,0,0,109,100,95,109,101,103,97,98,111,109,98,0,0,0,0,0,77,117,116,101,32,65,117,100,105,111,0,0,0,0,0,0,105,114,113,95,101,110,97,98,108,101,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,32,110,111,116,32,102,105,110,100,32,102,105,108,101,110,97,109,101,32,105,110,32,116,101,120,116,117,114,101,46,10,0,0,0,0,0,0,0,100,100,115,111,109,104,0,0,50,48,107,44,32,53,48,107,32,97,110,100,32,101,118,101,114,121,32,55,48,107,0,0,101,110,97,98,108,101,95,104,111,116,107,101,121,0,0,0,109,100,95,99,111,108,108,110,99,112,49,50,0,0,0,0,116,109,110,116,50,97,0,0,71,77,32,68,105,112,32,51,0,0,0,0,0,0,0,0,67,111,108,108,101,103,101,32,70,111,111,116,98,97,108,108,39,115,32,78,97,116,105,111,110,97,108,32,67,104,97,109,112,105,111,110,115,104,105,112,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,53,49,49,45,65,41,0,0,0,0,0,0,0,0,49,48,107,44,32,51,48,107,32,97,110,100,32,101,118,101,114,121,32,51,48,107,0,0,82,101,97,99,104,101,100,32,101,110,100,32,111,102,32,114,101,119,105,110,100,32,98,117,102,102,101,114,46,0,0,0,71,77,32,68,105,112,32,50,0,0,0,0,0,0,0,0,67,104,101,97,116,32,116,111,103,103,108,101,0,0,0,0,109,100,95,99,111,108,108,110,99,112,49,51,0,0,0,0,71,104,111,115,116,32,77,117,110,99,104,101,114,0,0,0,83,101,108,101,99,116,32,98,117,116,116,111,110,0,0,0,67,111,108,108,101,103,101,32,70,111,111,116,98,97,108,108,39,115,32,78,97,116,105,111,110,97,108,32,67,104,97,109,112,105,111,110,115,104,105,112,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,53,48,54,41,0,0,109,100,95,99,111,108,108,110,99,112,49,52,0,0,0,0,51,80,0,0,0,0,0,0,71,88,32,45,32,76,105,118,101,115,0,0,0,0,0,0,67,111,108,108,101,103,101,32,70,111,111,116,98,97,108,108,39,115,32,78,97,116,105,111,110,97,108,32,67,104,97,109,112,105,111,110,115,104,105,112,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,53,48,51,41,0,0,80,50,32,83,116,114,111,110,103,32,75,105,99,107,0,0,50,80,0,0,0,0,0,0,71,88,32,45,32,66,111,110,117,115,32,76,105,102,101,0,68,105,97,103,110,111,115,116,105,99,115,0,0,0,0,0,65,117,115,116,114,97,108,105,97,0,0,0,0,0,0,0,112,51,32,102,105,114,101,32,50,0,0,0,0,0,0,0,66,111,110,117,115,32,83,116,97,103,101,32,69,110,101,114,103,121,0,0,0,0,0,0,110,105,110,106,97,107,0,0,114,101,119,105,110,100,95,98,117,102,102,101,114,95,115,105,122,101,0,0,0,0,0,0,69,110,101,109,121,115,32,65,116,116,97,99,107,32,80,111,119,101,114,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,77,111,118,105,101,32,102,111,114,109,97,116,32,115,101,101,109,115,32,116,111,32,104,97,118,101,32,97,32,100,105,102,102,101,114,101,110,116,32,115,101,114,105,97,108,105,122,101,114,32,118,101,114,115,105,111,110,46,32,87,105,108,108,32,109,111,115,116,32,108,105,107,101,108,121,32,102,97,105,108,46,10,0,0,109,100,95,99,111,108,108,110,99,112,49,53,0,0,0,0,87,0,0,0,97,0,0,0,114,0,0,0,45,0,0,0,90,0,0,0,97,0,0,0,114,0,0,0,100,0,0,0,0,0,0,0,82,0,0,0,101,0,0,0,100,0,0,0,32,0,0,0,69,0,0,0,97,0,0,0,114,0,0,0,116,0,0,0,104,0,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,32,0,0,0,57,0,0,0,54,0,0,0,49,0,0,0,48,0,0,0,50,0,0,0,51,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,101,120,99,116,108,101,97,103,0,0,0,0,0,0,0,0,81,67,104,97,110,0,0,0,74,117,108,121,0,0,0,0,83,112,97,116,116,101,114,0,0,0,0,0,0,0,0,0,71,88,32,45,32,67,111,105,110,97,103,101,0,0,0,0,73,110,100,105,118,105,100,117,97,108,0,0,0,0,0,0,69,114,114,111,114,0,0,0,98,103,98,111,116,98,97,110,107,0,0,0,0,0,0,0,50,67,32,51,67,0,0,0,78,77,75,32,47,32,84,101,99,109,111,0,0,0,0,0,65,114,99,97,100,101,32,67,97,114,100,0,0,0,0,0,70,115,116,97,114,102,114,99,73,110,112,117,116,0,0,0,67,111,108,108,101,103,101,32,70,111,111,116,98,97,108,108,39,115,32,78,97,116,105,111,110,97,108,32,67,104,97,109,112,105,111,110,115,104,105,112,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,54,50,48,41,0,0,77,111,110,111,32,80,108,97,121,101,114,0,0,0,0,0,69,110,101,109,121,115,32,65,116,116,97,99,107,32,70,114,101,113,117,101,110,99,121,0,71,88,32,45,32,83,101,114,118,105,99,101,32,77,111,100,101,0,0,0,0,0,0,0,84,114,105,112,108,101,32,70,117,110,0,0,0,0,0,0,69,118,101,114,121,32,54,48,48,44,48,48,48,32,112,111,105,110,116,115,0,0,0,0,74,97,112,97,110,32,40,83,104,111,119,115,32,86,101,114,115,105,111,110,32,78,117,109,98,101,114,41,0,0,0,0,80,97,114,116,105,97,108,32,73,110,118,117,108,110,101,114,97,98,105,108,105,116,121,32,40,67,104,101,97,116,41,0,67,114,117,115,104,32,82,111,108,108,101,114,32,40,98,111,111,116,108,101,103,32,115,101,116,32,49,41,0,0,0,0,74,111,121,115,116,105,99,107,32,84,121,112,101,32,80,108,97,121,101,114,32,53,0,0,109,100,95,99,111,108,108,110,99,112,48,49,0,0,0,0,51,48,48,48,48,32,97,110,100,32,101,118,101,114,121,32,55,48,48,48,48,0,0,0,82,111,116,97,116,105,111,110,0,0,0,0,0,0,0,0,71,97,108,97,120,105,97,110,32,40,77,105,100,119,97,121,32,115,101,116,32,49,41,0,0,0,0,0,0,0,0,0,71,88,32,45,32,67,97,98,105,110,101,116,0,0,0,0,66,117,121,45,105,110,32,109,97,120,32,115,116,97,103,101,0,0,0,0,0,0,0,0,68,114,118,65,68,80,67,77,69,110,100,0,0,0,0,0,80,104,111,116,111,32,89,50,75,32,47,32,82,101,97,108,32,97,110,100,32,70,97,107,101,32,40,86,49,48,53,41,0,0,0,0,0,0,0,0,112,99,101,95,98,117,98,98,108,101,103,109,0,0,0,0,100,121,110,119,97,114,0,0,74,111,121,115,116,105,99,107,32,84,121,112,101,32,80,108,97,121,101,114,32,52,0,0,115,111,99,98,114,97,119,108,104,0,0,0,0,0,0,0,67,111,108,108,101,103,101,32,70,111,111,116,98,97,108,108,39,115,32,78,97,116,105,111,110,97,108,32,67,104,97,109,112,105,111,110,115,104,105,112,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,54,49,56,41,0,0,50,48,48,107,32,97,110,100,32,101,118,101,114,121,32,52,53,48,107,0,0,0,0,0,71,77,32,45,32,76,105,118,101,115,0,0,0,0,0,0,77,97,114,118,101,108,32,76,97,110,100,32,40,74,112,110,41,0,0,0,0,0,0,0,82,71,85,73,32,77,101,110,117,32,84,111,103,103,108,101,0,0,0,0,0,0,0,0,110,109,105,95,101,110,97,98,108,101,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,32,110,111,116,32,102,105,110,100,32,73,68,32,105,110,32,116,101,120,116,117,114,101,46,10,0,0,0,0,0,68,117,110,103,101,111,110,115,32,38,32,68,114,97,103,111,110,115,32,45,32,115,104,97,100,111,119,32,111,118,101,114,32,109,121,115,116,97,114,97,32,40,57,54,48,50,50,51,32,66,114,97,122,105,108,41,0,0,0,0,0,0,0,0,115,108,111,119,109,111,116,105,111,110,0,0,0,0,0,0,74,111,121,115,116,105,99,107,32,84,121,112,101,32,80,108,97,121,101,114,32,51,0,0,109,100,95,99,111,108,108,110,99,112,48,50,0,0,0,0,84,101,101,110,97,103,101,32,77,117,116,97,110,116,32,72,101,114,111,32,84,117,114,116,108,101,115,32,45,32,84,117,114,116,108,101,115,32,105,110,32,84,105,109,101,32,40,50,32,80,108,97,121,101,114,115,32,118,101,114,46,32,69,66,65,41,0,0,0,0,0,0,71,105,118,101,110,32,72,111,108,101,115,47,77,97,116,99,104,32,111,114,32,83,107,105,110,115,0,0,0,0,0,0,49,54,48,107,32,97,110,100,32,101,118,101,114,121,32,52,53,48,107,0,0,0,0,0,71,77,32,45,32,67,111,105,110,97,103,101,0,0,0,0,67,97,118,101,109,97,110,32,78,105,110,106,97,32,40,85,83,32,118,101,114,32,52,41,0,0,0,0,0,0,0,0,74,111,121,115,116,105,99,107,32,84,121,112,101,32,80,108,97,121,101,114,32,50,0,0,67,111,108,108,101,103,101,32,70,111,111,116,98,97,108,108,39,115,32,78,97,116,105,111,110,97,108,32,67,104,97,109,112,105,111,110,115,104,105,112,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,54,49,53,41,0,0,56,48,107,32,97,110,100,32,101,118,101,114,121,32,52,48,48,107,0,0,0,0,0,0,82,101,119,105,110,100,105,110,103,46,0,0,0,0,0,0,71,77,32,45,32,66,111,110,117,115,32,76,105,102,101,0,54,45,98,117,116,116,111,110,115,0,0,0,0,0,0,0,109,100,95,99,111,108,108,110,99,112,48,51,0,0,0,0,71,77,32,45,32,67,97,98,105,110,101,116,0,0,0,0,50,45,98,117,116,116,111,110,115,0,0,0,0,0,0,0,65,99,116,45,70,97,110,99,101,114,32,67,121,98,101,114,110,101,116,105,99,107,32,72,121,112,101,114,32,87,101,97,112,111,110,32,40,74,97,112,97,110,32,114,101,118,105,115,105,111,110,32,49,41,0,0,67,111,108,108,101,103,101,32,70,111,111,116,98,97,108,108,39,115,32,78,97,116,105,111,110,97,108,32,67,104,97,109,112,105,111,110,115,104,105,112,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,54,49,52,41,0,0,71,67,32,68,105,112,32,52,0,0,0,0,0,0,0,0,74,111,121,115,116,105,99,107,32,84,121,112,101,32,80,108,97,121,101,114,32,49,0,0,109,100,95,99,111,108,108,110,99,112,48,52,0,0,0,0,71,88,32,68,105,112,32,51,0,0,0,0,0,0,0,0,83,105,100,101,32,80,111,99,107,101,116,32,40,98,111,111,116,108,101,103,32,115,101,116,32,49,41,0,0,0,0,0,67,104,97,110,45,62,97,100,100,114,0,0,0,0,0,0,77,97,100,111,117,32,79,117,32,71,114,97,110,122,111,114,116,0,0,0,0,0,0,0,67,111,108,108,101,103,101,32,70,111,111,116,98,97,108,108,39,115,32,78,97,116,105,111,110,97,108,32,67,104,97,109,112,105,111,110,115,104,105,112,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,54,48,56,41,0,0,80,50,32,77,101,100,105,117,109,32,75,105,99,107,0,0,83,67,32,68,105,112,32,50,0,0,0,0,0,0,0,0,83,119,105,116,122,101,114,108,97,110,100,0,0,0,0,0,67,114,117,100,101,32,66,117,115,116,101,114,32,40,74,97,112,97,110,41,0,0,0,0,77,97,104,106,111,110,103,32,81,117,101,115,116,32,40,78,111,32,78,117,100,105,116,121,41,0,0,0,0,0,0,0,114,101,119,105,110,100,95,101,110,97,98,108,101,0,0,0,115,103,120,95,103,114,97,110,122,111,114,116,0,0,0,0,109,100,95,99,111,108,108,110,99,112,48,53,0,0,0,0,87,97,114,45,90,97,114,100,32,47,32,82,101,100,32,69,97,114,116,104,32,40,74,97,112,97,110,32,57,54,49,48,50,51,41,0,0,0,0,0,69,45,83,119,97,116,32,45,32,67,121,98,101,114,32,80,111,108,105,99,101,32,40,98,111,111,116,108,101,103,41,0,0,0,0,0,0,0,0,0,74,117,110,101,0,0,0,0,115,112,97,116,116,101,114,0,71,77,32,68,105,112,32,49,0,0,0,0,0,0,0,0,67,111,109,109,111,110,0,0,55,32,103,105,118,101,115,32,49,32,109,111,114,101,0,0,98,103,116,111,112,98,97,110,107,0,0,0,0,0,0,0,86,97,112,111,114,32,84,114,97,105,108,32,45,32,72,121,112,101,114,32,79,102,102,101,110,99,101,32,70,111,114,109,97,116,105,111,110,32,40,85,83,41,0,0,0,0,0,0,83,97,98,111,116,101,110,32,66,111,109,98,101,114,115,32,40,115,101,116,32,49,41,0,0,0,0,0,0,0,0,0,68,97,105,32,77,97,107,97,105,109,117,114,97,0,0,0,70,115,116,97,114,102,114,99,83,111,117,110,100,76,97,116,99,104,0,0,0,0,0,0,67,111,108,108,101,103,101,32,70,111,111,116,98,97,108,108,39,115,32,78,97,116,105,111,110,97,108,32,67,104,97,109,112,105,111,110,115,104,105,112,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,54,48,55,41,0,0,54,32,84,105,109,101,115,0,99,104,105,112,45,62,108,102,111,95,112,109,95,99,110,116,0,0,0,0,0,0,0,0,70,105,114,101,32,40,67,111,99,107,116,97,105,108,41,0,116,114,105,112,108,102,117,110,0,0,0,0,0,0,0,0,69,120,116,101,110,100,32,102,105,103,104,116,101,114,115,0,99,114,117,115,104,98,108,0,115,103,120,95,100,97,105,109,97,107,97,105,0,0,0,0,109,100,95,99,111,108,108,110,99,112,48,54,0,0,0,0,51,48,48,48,48,32,97,110,100,32,101,118,101,114,121,32,54,48,48,48,48,0,0,0,68,114,118,65,68,80,67,77,80,111,115,0,0,0,0,0,112,104,111,116,111,121,50,107,0,0,0,0,0,0,0,0,66,114,101,97,107,32,73,110,0,0,0,0,0,0,0,0,67,97,100,105,108,108,97,99,115,32,97,110,100,32,68,105,110,111,115,97,117,114,115,32,40,67,104,105,110,101,115,101,32,98,111,111,116,108,101,103,44,32,57,51,48,50,50,51,32,65,115,105,97,32,84,87,41,0,0,0,0,0,0,0,66,97,116,116,108,101,32,65,99,101,0,0,0,0,0,0,83,111,99,99,101,114,32,66,114,97,119,108,32,40,78,71,77,45,48,51,49,41,0,0,67,111,108,108,101,103,101,32,70,111,111,116,98,97,108,108,39,115,32,78,97,116,105,111,110,97,108,32,67,104,97,109,112,105,111,110,115,104,105,112,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,54,48,51,41,0,0,84,104,117,110,100,101,114,32,90,111,110,101,32,40,87,111,114,108,100,32,52,32,80,108,97,121,101,114,115,41,0,0,67,111,105,110,97,103,101,32,40,71,97,108,97,99,116,105,99,32,67,111,110,118,111,121,41,0,0,0,0,0,0,0,109,100,95,109,97,114,118,108,97,110,100,106,0,0,0,0,68,101,102,97,117,108,116,32,65,108,108,32,40,82,101,116,114,111,80,97,100,41,0,0,102,105,108,116,101,114,0,0,100,100,115,111,109,98,0,0,110,101,116,112,108,97,121,95,102,108,105,112,95,112,108,97,121,101,114,115,0,0,0,0,115,103,120,95,98,97,116,116,108,97,99,101,0,0,0,0,109,100,95,99,111,108,108,110,99,112,48,55,0,0,0,0,116,109,104,116,50,50,112,101,0,0,0,0,0,0,0,0,66,111,110,117,115,32,76,105,102,101,32,40,71,97,108,97,99,116,105,99,32,67,111,110,118,111,121,41,0,0,0,0,65,108,100,121,110,101,115,0,0,0,0,0,0,0,0,0,67,111,108,108,101,103,101,32,70,111,111,116,98,97,108,108,39,115,32,78,97,116,105,111,110,97,108,32,67,104,97,109,112,105,111,110,115,104,105,112,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,54,48,49,41,0,0,83,108,111,119,32,109,111,116,105,111,110,46,0,0,0,0,67,111,105,110,97,103,101,32,40,71,97,108,97,120,105,97,110,41,0,0,0,0,0,0,67,104,101,97,116,32,105,110,100,101,120,32,45,0,0,0,115,103,120,95,97,108,100,121,110,101,115,0,0,0,0,0,75,97,114,110,111,118,32,40,74,97,112,97,110,41,0,0,109,100,95,99,111,108,108,110,99,112,48,56,0,0,0,0,66,111,110,117,115,32,76,105,102,101,32,40,71,97,108,97,120,105,97,110,41,0,0,0,65,114,109,101,110,105,97,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,77,69,83,83,65,71,69,58,32,37,115,10,0,0,0,0,0,83,117,112,101,114,71,114,97,102,120,0,0,0,0,0,0,67,111,108,108,101,103,101,32,70,111,111,116,98,97,108,108,39,115,32,78,97,116,105,111,110,97,108,32,67,104,97,109,112,105,111,110,115,104,105,112,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,52,50,57,41,0,0,50,44,32,73,110,100,105,118,105,100,117,97,108,0,0,0,67,111,105,110,97,103,101,32,40,83,99,114,97,109,98,108,101,41,0,0,0,0,0,0,49,57,52,49,32,45,32,67,111,117,110,116,101,114,32,65,116,116,97,99,107,0,0,0,50,44,32,67,111,109,109,111,110,0,0,0,0,0,0,0,109,100,95,99,111,108,108,110,99,112,49,54,0,0,0,0,37,115,32,124,124,32,70,80,83,58,32,37,54,46,49,102,32,124,124,32,70,114,97,109,101,115,58,32,37,100,0,0,77,101,105,107,121,117,117,32,72,117,110,116,101,114,32,71,32,40,74,97,112,97,110,44,32,115,101,116,32,49,41,0,0,0,0,0,0,0,0,0,115,103,120,95,49,57,52,49,0,0,0,0,0,0,0,0,67,111,108,108,101,103,101,32,70,111,111,116,98,97,108,108,39,115,32,78,97,116,105,111,110,97,108,32,67,104,97,109,112,105,111,110,115,104,105,112,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,52,49,57,41,0,0,80,50,32,87,101,97,107,32,75,105,99,107,0,0,0,0,49,44,32,67,111,109,109,111,110,0,0,0,0,0,0,0,83,119,101,100,101,110,0,0,112,51,32,102,105,114,101,32,49,0,0,0,0,0,0,0,109,106,110,113,117,101,115,116,98,0,0,0,0,0,0,0,105,110,112,117,116,95,111,118,101,114,108,97,121,95,115,99,97,108,101,0,0,0,0,0,115,111,116,115,117,103,121,111,0,0,0,0,0,0,0,0,109,100,95,99,111,108,108,110,99,112,49,55,0,0,0,0,119,97,114,122,97,114,100,114,49,0,0,0,0,0,0,0,101,115,119,97,116,98,108,0,50,32,67,111,105,110,115,32,83,116,97,114,116,32,49,32,67,111,105,110,32,67,111,110,116,105,110,117,101,0,0,0,77,97,121,0,0,0,0,0,78,105,110,106,97,32,80,114,105,110,99,101,115,115,32,40,51,49,53,45,53,48,53,49,63,44,32,49,50,56,107,32,86,101,114,46,32,98,111,111,116,108,101,103,63,41,0,0,65,108,108,111,119,32,67,111,110,116,105,110,117,101,32,40,83,99,114,97,109,98,108,101,41,0,0,0,0,0,0,0,67,111,105,110,32,67,104,117,116,101,0,0,0,0,0,0,54,32,103,105,118,101,115,32,49,32,109,111,114,101,0,0,115,97,98,111,116,101,110,98,0,0,0,0,0,0,0,0,100,101,99,111,49,54,95,120,111,114,0,0,0,0,0,0,67,111,108,108,101,103,101,32,70,111,111,116,98,97,108,108,39,115,32,78,97,116,105,111,110,97,108,32,67,104,97,109,112,105,111,110,115,104,105,112,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,52,49,56,41,0,0,57,32,67,111,105,110,115,32,49,32,67,114,101,100,105,116,0,0,0,0,0,0,0,0,83,117,110,115,111,102,116,32,43,32,65,116,108,117,115,0,65,100,118,101,114,116,105,115,101,32,83,111,117,110,100,32,79,110,0,0,0,0,0,0,78,117,109,98,101,114,32,111,102,32,102,105,103,104,116,101,114,115,0,0,0,0,0,0,54,48,107,32,111,110,108,121,0,0,0,0,0,0,0,0,75,117,114,97,108,32,83,97,109,110,111,32,69,108,101,99,116,114,105,99,0,0,0,0,109,100,95,99,111,108,108,110,99,112,49,56,0,0,0,0,50,48,48,48,48,32,97,110,100,32,101,118,101,114,121,32,55,48,48,48,48,0,0,0,56,32,67,111,105,110,115,32,49,32,67,114,101,100,105,116,0,0,0,0,0,0,0,0,67,111,105,110,97,103,101,32,40,71,104,111,115,116,32,77,117,110,99,104,101,114,41,0,68,114,118,65,68,80,67,77,73,100,108,101,0,0,0,0,75,110,105,103,104,116,115,32,111,102,32,86,97,108,111,117,114,32,83,117,112,101,114,104,101,114,111,101,115,32,47,32,83,97,110,103,111,107,117,32,83,101,110,107,105,32,83,117,112,101,114,104,101,114,111,101,115,32,40,86,49,48,49,41,0,0,0,0,0,0,0,0,112,99,101,95,98,114,101,97,107,105,110,0,0,0,0,0,100,105,110,111,104,99,0,0,67,111,108,108,101,103,101,32,70,111,111,116,98,97,108,108,39,115,32,78,97,116,105,111,110,97,108,32,67,104,97,109,112,105,111,110,115,104,105,112,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,52,49,51,41,0,0,55,32,67,111,105,110,115,32,49,32,67,114,101,100,105,116,0,0,0,0,0,0,0,0,66,111,110,117,115,32,76,105,102,101,32,40,71,104,111,115,116,32,77,117,110,99,104,101,114,41,0,0,0,0,0,0,84,104,101,32,71,114,101,97,116,32,82,97,103,116,105,109,101,32,83,104,111,119,32,40,74,97,112,97,110,32,118,49,46,53,44,32,57,50,46,49,50,46,48,55,41,0,0,0,67,104,105,112,45,62,78,111,105,115,101,77,111,100,101,0,67,111,110,102,105,103,117,114,101,32,65,108,108,32,40,82,101,116,114,111,80,97,100,41,0,0,0,0,0,0,0,0,102,105,108,101,0,0,0,0,68,117,110,103,101,111,110,115,32,38,32,68,114,97,103,111,110,115,32,45,32,115,104,97,100,111,119,32,111,118,101,114,32,109,121,115,116,97,114,97,32,40,57,54,48,54,49,57,32,65,115,105,97,41,0,0,97,117,100,105,111,95,109,117,116,101,0,0,0,0,0,0,89,111,44,32,66,114,111,0,0,0,0,0,0,0,0,0,109,100,95,99,111,108,108,110,99,112,49,57,0,0,0,0,84,101,101,110,97,103,101,32,77,117,116,97,110,116,32,78,105,110,106,97,32,84,117,114,116,108,101,115,32,45,32,84,117,114,116,108,101,115,32,105,110,32,84,105,109,101,32,40,50,32,80,108,97,121,101,114,115,32,118,101,114,46,32,85,68,65,41,0,0,0,0,0,105,115,111,124,122,105,112,0,82,46,84,82,73,83,67,0,37,48,56,120,58,32,71,53,32,85,110,100,101,102,105,110,101,100,32,84,104,117,109,98,32,105,110,115,116,114,117,99,116,105,111,110,58,32,37,48,52,120,10,0,0,0,0,0,116,103,95,121,111,98,114,111,0,0,0,0,0,0,0,0,99,104,105,112,45,62,114,101,112,101,97,116,0,0,0,0,67,111,108,108,101,103,101,32,70,111,111,116,98,97,108,108,39,115,32,78,97,116,105,111,110,97,108,32,67,104,97,109,112,105,111,110,115,104,105,112,32,40,85,83,65,41,0,0,83,108,111,119,32,109,111,116,105,111,110,32,114,101,119,105,110,100,46,0,0,0,0,0,52,32,67,111,105,110,115,32,53,32,80,108,97,121,115,0,82,111,104,103,97,32,65,114,109,111,114,32,70,111,114,99,101,32,40,65,115,105,97,47,69,117,114,111,112,101,32,118,51,46,48,32,83,101,116,32,50,41,0,0,0,0,0,0,82,45,62,105,114,113,95,115,116,97,116,101,0,0,0,0,67,114,97,122,121,32,75,111,110,103,32,80,97,114,116,32,73,73,32,40,115,101,116,32,49,41,0,0,0,0,0,0,85,112,114,105,103,104,116,0,65,114,109,101,100,32,80,111,108,105,99,101,32,66,97,116,114,105,100,101,114,32,40,67,104,105,110,97,41,32,40,70,114,105,32,70,101,98,32,49,51,32,49,57,57,56,41,0,0,0,0,0,0,0,0,0,87,111,114,108,100,32,83,112,111,114,116,115,32,67,111,109,112,101,116,105,116,105,111,110,0,0,0,0,0,0,0,0,70,105,120,69,105,103,104,116,32,40,75,111,114,101,97,41,0,0,0,0,0,0,0,0,109,100,95,99,111,108,108,110,99,0,0,0,0,0,0,0,103,114,105,110,100,115,116,109,97,0,0,0,0,0,0,0,80,108,97,121,101,114,115,32,66,117,108,108,101,116,32,83,112,101,101,100,0,0,0,0,84,105,103,101,114,32,72,101,108,105,32,40,98,111,111,116,108,101,103,44,32,115,101,116,32,49,41,0,0,0,0,0,112,105,112,105,98,105,98,115,0,0,0,0,0,0,0,0,80,105,112,105,32,38,32,66,105,98,105,115,32,47,32,87,104,111,111,112,101,101,33,33,32,40,112,114,111,116,111,116,121,112,101,41,0,0,0,0,87,97,114,32,111,102,32,116,104,101,32,66,117,103,115,32,111,114,32,77,111,110,115,116,101,114,111,117,115,32,77,97,110,111,117,118,101,114,115,32,105,110,32,97,32,77,117,115,104,114,111,111,109,32,77,97,122,101,0,0,0,0,0,0,116,103,95,119,115,99,111,109,112,0,0,0,0,0,0,0,67,111,108,108,101,103,101,32,70,111,111,116,98,97,108,108,32,85,83,65,32,57,55,32,40,85,83,65,41,0,0,0,67,111,110,116,105,110,117,101,32,77,111,100,101,0,0,0,52,67,32,49,80,44,32,52,67,32,49,51,80,0,0,0,68,111,103,121,117,117,110,32,40,76,105,99,101,110,115,101,100,32,116,111,32,85,110,105,116,101,32,84,114,97,100,105,110,103,32,70,111,114,32,75,111,114,101,97,41,0,0,0,68,105,101,116,32,71,111,32,71,111,32,40,69,117,114,111,32,118,49,46,49,32,49,57,57,50,46,48,57,46,50,54,41,0,0,0,0,0,0,0,66,97,116,116,108,101,32,71,97,114,101,103,103,97,32,45,32,84,121,112,101,32,50,32,40,87,111,114,108,100,41,32,40,83,97,116,32,77,97,114,32,50,32,49,57,57,54,41,0,0,0,0,0,0,0,0,84,111,97,112,108,97,110,32,40,68,111,111,121,111,110,103,32,108,105,99,101,110,115,101,41,0,0,0,0,0,0,0,87,111,114,108,100,32,67,111,117,114,116,32,84,101,110,110,105,115,0,0,0,0,0,0,109,100,95,99,111,108,108,101,103,57,55,0,0,0,0,0,67,111,110,116,105,110,117,101,32,100,105,115,99,111,117,110,116,0,0,0,0,0,0,0,84,111,97,112,108,97,110,32,40,78,111,118,97,32,65,112,112,97,114,97,116,101,32,71,77,66,72,32,38,32,67,111,32,108,105,99,101,110,115,101,41,0,0,0,0,0,0,0,51,67,32,49,80,44,32,51,67,32,49,48,80,0,0,0,79,117,116,32,90,111,110,101,32,40,115,101,116,32,51,44,32,112,114,111,116,111,116,121,112,101,63,41,0,0,0,0,66,97,116,116,108,101,32,66,97,107,114,97,105,100,32,40,74,97,112,97,110,41,32,40,87,101,100,32,65,112,114,32,55,32,49,57,57,57,41,0,0,0,0,0,0,0,0,0,72,101,108,108,102,105,114,101,32,40,50,80,32,86,101,114,46,44,32,102,105,114,115,116,32,101,100,105,116,105,111,110,41,0,0,0,0,0,0,0,100,101,109,111,110,119,108,100,50,0,0,0,0,0,0,0,116,103,95,119,99,116,101,110,110,105,115,0,0,0,0,0,67,111,108,108,101,103,101,32,70,111,111,116,98,97,108,108,32,85,83,65,32,57,54,32,40,85,83,65,41,0,0,0,119,104,49,0,0,0,0,0,80,50,32,83,116,114,111,110,103,32,80,117,110,99,104,0,115,115,116,114,105,107,101,114,97,0,0,0,0,0,0,0,112,50,32,102,105,114,101,32,50,0,0,0,0,0,0,0,50,67,32,49,80,44,32,50,67,32,55,80,0,0,0,0,83,112,97,105,110,0,0,0,114,101,116,111,102,105,110,118,50,0,0,0,0,0,0,0,77,97,104,106,111,110,103,32,81,117,101,115,116,32,40,74,97,112,97,110,41,0,0,0,100,114,103,110,105,110,106,97,98,0,0,0,0,0,0,0,105,110,112,117,116,95,111,118,101,114,108,97,121,95,111,112,97,99,105,116,121,0,0,0,67,97,109,101,108,116,114,121,32,40,85,83,44,32,89,77,50,50,48,51,32,43,32,77,54,50,57,53,41,0,0,0,87,111,114,108,100,32,67,108,97,115,115,32,66,97,115,101,98,97,108,108,0,0,0,0,109,100,95,99,111,108,108,101,103,57,54,0,0,0,0,0,82,0,0,0,101,0,0,0,100,0,0,0,32,0,0,0,69,0,0,0,97,0,0,0,114,0,0,0,116,0,0,0,104,0,0,0,0,0,0,0,87,0,0,0,97,0,0,0,114,0,0,0,45,0,0,0,90,0,0,0,97,0,0,0,114,0,0,0,100,0,0,0,32,0,0,0,40,0,0,0,69,0,0,0,117,0,0,0,114,0,0,0,111,0,0,0,32,0,0,0,57,0,0,0,54,0,0,0,49,0,0,0,48,0,0,0,50,0,0,0,51,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,84,104,101,32,76,101,103,101,110,100,32,111,102,32,75,97,103,101,32,40,111,108,100,101,115,116,41,0,0,0,0,0,69,45,83,119,97,116,32,45,32,67,121,98,101,114,32,80,111,108,105,99,101,32,40,115,101,116,32,50,44,32,85,83,44,32,70,68,49,48,57,52,32,51,49,55,45,48,49,50,57,41,0,0,0,0,0,0,80,51,32,83,112,101,99,105,97,108,0,0,0,0,0,0,65,112,114,105,108,0,0,0,110,112,114,105,110,99,101,115,98,0,0,0,0,0,0,0,49,67,32,49,80,44,32,49,67,32,52,80,0,0,0,0,53,32,103,105,118,101,115,32,49,32,109,111,114,101,0,0,111,116,104,117,110,100,101,114,117,111,0,0,0,0,0,0,101,120,116,114,109,97,116,110,117,0,0,0,0,0,0,0,84,119,105,110,32,65,99,116,105,111,110,0,0,0,0,0,97,114,107,97,110,111,105,100,117,111,0,0,0,0,0,0,116,103,95,119,99,98,97,115,101,98,108,0,0,0,0,0,68,97,114,107,32,83,101,97,108,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,67,111,97,99,104,32,75,32,67,111,108,108,101,103,101,32,66,97,115,107,101,116,98,97,108,108,32,40,85,83,65,41,0,0,0,0,0,0,0,0,109,99,117,95,115,101,108,101,99,116,0,0,0,0,0,0,49,48,48,37,0,0,0,0,80,51,32,83,104,111,116,0,52,67,32,49,80,44,32,52,67,32,57,80,0,0,0,0,79,105,115,104,105,105,32,80,117,122,122,108,101,32,72,97,32,73,114,105,109,97,115,101,110,107,97,0,0,0,0,0,65,100,118,101,114,116,105,115,101,32,83,111,117,110,100,32,79,102,102,0,0,0,0,0,77,111,114,101,32,68,105,102])
.concat([102,105,99,117,108,116,0,0,111,112,119,111,108,102,51,117,0,0,0,0,0,0,0,0,67,114,117,115,104,32,82,111,108,108,101,114,32,40,75,117,114,97,108,32,83,97,109,110,111,41,0,0,0,0,0,0,116,103,95,118,105,103,105,108,97,110,116,0,0,0,0,0,49,32,77,101,103,97,98,105,116,0,0,0,0,0,0,0,97,113,117,97,106,97,99,107,117,0,0,0,0,0,0,0,83,117,112,101,114,32,66,117,114,103,101,114,32,84,105,109,101,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,109,100,95,99,111,97,99,104,107,0,0,0,0,0,0,0,50,48,48,48,48,32,97,110,100,32,101,118,101,114,121,32,54,48,48,48,48,0,0,0,67,67,104,105,112,67,111,105,110,115,70,111,114,67,114,101,100,105,116,0,0,0,0,0,70,117,101,108,32,67,111,110,115,117,109,112,116,105,111,110,0,0,0,0,0,0,0,0,51,67,32,49,80,44,32,51,67,32,55,80,0,0,0,0,69,118,101,114,121,32,55,48,48,48,48,0,0,0,0,0,67,112,115,51,73,110,112,117,116,0,0,0,0,0,0,0,100,97,114,105,117,115,111,0,118,100,99,95,115,116,97,116,117,115,91,105,93,0,0,0,68,114,118,83,99,114,111,108,108,89,76,111,0,0,0,0,99,97,100,97,115,104,117,0,107,111,118,115,104,49,48,49,0,0,0,0,0,0,0,0,112,111,114,116,67,95,111,117,116,0,0,0,0,0,0,0,73,77,97,120,0,0,0,0,67,97,100,105,108,108,97,99,115,32,97,110,100,32,68,105,110,111,115,97,117,114,115,32,40,104,97,99,107,44,32,57,51,48,50,48,49,32,101,116,99,41,0,0,0,0,0,0,116,103,95,118,105,99,116,111,114,121,114,0,0,0,0,0,78,101,119,32,99,97,114,100,32,116,121,112,101,0,0,0,50,48,50,48,32,83,117,112,101,114,32,66,97,115,101,98,97,108,108,32,40,115,101,116,32,51,41,0,0,0,0,0,80,97,114,107,101,114,32,66,114,111,116,104,101,114,115,0,66,117,98,98,108,101,32,66,111,98,98,108,101,32,40,85,83,32,119,105,116,104,32,109,111,100,101,32,115,101,108,101,99,116,41,0,0,0,0,0,51,32,80,108,97,121,101,114,0,0,0,0,0,0,0,0,103,105,103,97,110,100,101,115,97,0,0,0,0,0,0,0,50,67,32,49,80,44,32,50,67,32,53,80,0,0,0,0,109,99,117,95,99,114,101,100,105,116,115,0,0,0,0,0,84,67,48,49,48,48,83,67,78,70,108,105,112,0,0,0,68,97,114,105,117,115,32,73,73,32,40,100,117,97,108,32,115,99,114,101,101,110,41,32,40,74,97,112,97,110,32,111,108,100,32,118,101,114,115,105,111,110,41,0,0,0,0,0,84,97,108,109,105,116,39,115,32,65,100,118,101,110,116,117,114,101,32,40,69,117,114,111,41,0,0,0,0,0,0,0,68,101,118,105,99,101,32,84,121,112,101,0,0,0,0,0,79,110,110,97,32,83,97,110,115,105,114,111,117,32,45,32,84,121,112,104,111,111,110,32,71,97,108,32,40,115,101,116,32,49,41,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,84,111,111,32,109,97,110,121,32,116,101,120,116,117,114,101,32,105,109,97,103,101,115,46,32,73,103,110,111,114,105,110,103,32,46,46,46,10,0,0,0,0,0,0,100,100,115,111,109,97,0,0,79,117,116,32,82,117,110,32,40,100,101,108,117,120,101,32,115,105,116,100,111,119,110,41,0,0,0,0,0,0,0,0,100,115,112,95,99,111,110,102,105,103,0,0,0,0,0,0,116,103,95,118,101,105,103,117,101,115,0,0,0,0,0,0,87,114,105,116,101,45,112,114,111,116,101,99,116,101,100,0,67,108,117,101,32,40,85,83,65,41,0,0,0,0,0,0,116,109,110,116,50,50,112,117,0,0,0,0,0,0,0,0,71,105,118,101,110,32,72,111,108,101,115,47,83,116,114,111,107,101,32,80,108,97,121,0,49,67,32,49,80,44,32,49,67,32,51,80,0,0,0,0,97,108,105,101,110,115,121,110,51,0,0,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,73,58,32,78,101,119,32,71,101,110,101,114,97,116,105,111,110,32,40,72,105,115,112,97,110,105,99,32,57,55,48,50,48,52,41,0,0,0,0,83,121,115,116,101,109,49,54,83,99,114,101,101,110,70,108,105,112,0,0,0,0,0,0,116,103,95,116,118,104,111,99,107,101,121,0,0,0,0,0,87,114,105,116,97,98,108,101,0,0,0,0,0,0,0,0,109,100,95,99,108,117,101,0,83,101,103,97,32,47,32,83,97,110,114,105,116,115,117,0,110,89,77,50,50,48,51,80,111,115,105,116,105,111,110,0,82,101,116,114,111,65,114,99,104,58,32,77,111,118,105,101,32,112,108,97,121,98,97,99,107,32,101,110,100,101,100,46,10,0,0,0,0,0,0,0,52,67,32,49,80,44,32,52,67,32,53,80,0,0,0,0,67,104,101,97,116,32,105,110,100,101,120,32,43,0,0,0,83,101,103,97,32,47,32,86,105,99,32,84,111,107,97,105,0,0,0,0,0,0,0,0,65,108,105,101,110,32,83,116,111,114,109,32,40,115,101,116,32,49,44,32,74,97,112,97,110,32,82,101,118,32,66,44,32,50,32,80,108,97,121,101,114,115,44,32,70,68,49,48,57,52,32,51,49,55,45,48,49,52,54,41,0,0,0,0,116,103,95,116,118,102,111,111,116,98,108,0,0,0,0,0,77,101,109,111,114,121,32,99,97,114,100,0,0,0,0,0,67,108,105,102,102,104,97,110,103,101,114,32,40,85,83,65,41,0,0,0,0,0,0,0,110,85,110,107,110,111,119,110,73,82,81,0,0,0,0,0,71,97,108,97,120,121,32,70,111,114,99,101,32,50,32,40,74,97,112,97,110,44,32,82,101,118,32,65,41,0,0,0,52,32,40,51,32,119,104,101,110,32,99,111,110,116,105,110,117,101,41,0,0,0,0,0,51,67,32,49,80,44,32,51,67,32,52,80,0,0,0,0,83,101,103,97,32,47,32,78,97,115,99,111,0,0,0,0,86,100,112,72,83,99,114,111,108,108,77,97,115,107,0,0,119,97,114,111,102,98,117,103,0,0,0,0,0,0,0,0,116,103,95,116,118,98,97,115,107,101,116,0,0,0,0,0,78,101,111,79,112,101,110,32,66,73,79,83,32,118,48,46,49,32,98,101,116,97,0,0,109,100,95,99,108,105,102,102,104,117,0,0,0,0,0,0,97,108,101,120,107,105,100,100,0,0,0,0,0,0,0,0,51,32,40,50,32,119,104,101,110,32,99,111,110,116,105,110,117,101,41,0,0,0,0,0,101,115,112,114,97,100,101,106,111,0,0,0,0,0,0,0,50,67,32,49,80,44,32,50,67,32,51,80,0,0,0,0,69,110,100,117,114,111,32,82,97,99,101,114,32,40,98,111,111,116,108,101,103,32,115,101,116,32,49,41,0,0,0,0,66,108,97,122,101,32,79,110,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,66,97,108,108,105,115,116,105,99,0,0,0,0,0,0,0,85,110,105,118,101,114,115,101,32,66,73,79,83,32,118,101,114,46,32,49,46,48,0,0,67,108,105,102,102,104,97,110,103,101,114,32,40,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,0,0,0,77,105,115,115,32,66,105,110,103,111,0,0,0,0,0,0,80,48,0,0,143,48,0,0,147,48,0,0,82,48,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,44,0,0,0,32,0,0,0,83,0,0,0,112,0,0,0,101,0,0,0,99,0,0,0,105,0,0,0,97,0,0,0,108,0,0,0,32,0,0,0,86,0,0,0,101,0,0,0,114,0,0,0,46,0,0,0,32,0,0,0,48,0,0,0,48,0,0,0,47,0,0,0,48,0,0,0,55,0,0,0,47,0,0,0,48,0,0,0,55,0,0,0,41,0,0,0,0,0,0,0,71,0,0,0,117,0,0,0,119,0,0,0,97,0,0,0,110,0,0,0,103,0,0,0,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,67,32,49,80,44,32,49,67,32,50,80,0,0,0,0,83,97,109,101,0,0,0,0,84,117,114,114,105,99,97,110,0,0,0,0,0,0,0,0,85,110,105,118,101,114,115,101,32,66,73,79,83,32,118,101,114,46,32,49,46,49,0,0,109,100,95,99,108,105,102,102,104,112,0,0,0,0,0,0,115,101,97,114,99,104,101,121,0,0,0,0,0,0,0,0,80,50,32,77,101,100,105,117,109,32,80,117,110,99,104,0,80,108,97,121,101,114,39,115,32,66,117,108,108,101,116,32,83,112,101,101,100,0,0,0,80,111,114,116,117,103,97,108,0,0,0,0,0,0,0,0,112,51,32,114,105,103,104,116,0,0,0,0,0,0,0,0,106,140,0,0,64,136,0,0,250,91,0,0,0,78,0,0,207,101,0,0,32,0,0,0,18,255,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,44,0,0,0,32,0,0,0,118,0,0,0,101,0,0,0,114,0,0,0,46,0,0,0,32,0,0,0,57,0,0,0,52,0,0,0,47,0,0,0,48,0,0,0,52,0,0,0,47,0,0,0,48,0,0,0,56,0,0,0,41,0,0,0,0,0,0,0,71,0,0,0,111,0,0,0,117,0,0,0,107,0,0,0,101,0,0,0,116,0,0,0,115,0,0,0,117,0,0,0,106,0,0,0,105,0,0,0,32,0,0,0,73,0,0,0,99,0,0,0,104,0,0,0,105,0,0,0,122,0,0,0,111,0,0,0,107,0,0,0,117,0,0,0,32,0,0,0,50,0,0,0,0,0,0,0,0,0,0,0,90,101,114,111,32,80,111,105,110,116,32,40,74,97,112,97,110,41,0,0,0,0,0,0,83,104,97,100,111,119,32,70,111,114,99,101,32,40,74,97,112,97,110,32,86,101,114,115,105,111,110,32,50,41,0,0,109,106,110,113,117,101,115,116,0,0,0,0,0,0,0,0,75,97,114,105,97,110,32,67,114,111,115,115,32,40,82,101,118,46,32,49,46,48,41,0,0,0,0,0,0,0,0,0,112,50,32,121,45,97,120,105,115,0,0,0,0,0,0,0,65,115,117,114,97,32,66,117,115,116,101,114,32,45,32,69,116,101,114,110,97,108,32,87,97,114,114,105,111,114,115,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,105,110,112,117,116,95,111,118,101,114,108,97,121,0,0,0,116,103,95,116,117,114,114,105,99,97,110,0,0,0,0,0,85,110,105,118,101,114,115,101,32,66,73,79,83,32,118,101,114,46,32,49,46,50,32,40,97,108,116,41,0,0,0,0,67,108,105,102,102,104,97,110,103,101,114,32,40,69,117,114,111,41,0,0,0,0,0,0,82,101,100,32,69,97,114,116,104,32,47,32,87,97,114,45,90,97,114,100,32,40,69,117,114,111,32,57,54,49,48,50,51,41,0,0,0,0,0,0,101,115,119,97,116,117,0,0,80,108,97,121,101,114,115,32,118,105,116,97,108,105,116,121,32,99,111,110,115,117,109,112,116,105,111,110,0,0,0,0,100,114,103,110,109,115,116,95,115,110,100,95,99,111,109,109,97,110,100,0,0,0,0,0,77,97,114,99,104,0,0,0,78,105,110,106,97,32,80,114,105,110,99,101,115,115,32,40,54,52,107,32,86,101,114,46,32,110,111,116,32,101,110,99,114,121,112,116,101,100,41,0,0,0,0,0,0,0,0,0,52,32,103,105,118,101,115,32,49,32,109,111,114,101,0,0,66,111,110,117,115,32,66,97,114,32,76,101,118,101,108,0,109,97,110,121,98,108,111,99,0,0,0,0,0,0,0,0,82,97,105,100,101,110,32,40,84,97,105,119,97,110,41,0,0,0,0,0,0,0,0,0,84,104,117,110,100,101,114,32,72,101,114,111,101,115,0,0,84,114,105,99,107,121,32,75,105,99,107,0,0,0,0,0,80,117,108,108,32,79,112,116,105,111,110,0,0,0,0,0,85,110,105,118,101,114,115,101,32,66,73,79,83,32,118,101,114,46,32,49,46,50,0,0,109,100,95,99,108,105,102,102,104,0,0,0,0,0,0,0,49,32,67,114,101,100,105,116,32,49,32,72,101,97,108,116,104,32,80,97,99,107,0,0,87,97,107,97,107,117,115,97,109,111,110,111,103,97,116,97,114,105,32,77,97,104,106,111,110,103,32,89,111,110,115,104,105,109,97,105,32,40,74,97,112,97,110,41,0,0,0,0,111,105,115,105,112,117,122,108,0,0,0,0,0,0,0,0,65,105,114,32,66,117,115,116,101,114,58,32,84,114,111,117,98,108,101,32,83,112,101,99,105,97,108,116,121,32,82,97,105,100,32,85,110,105,116,32,40,98,111,111,116,108,101,103,41,0,0,0,0,0,0,0,66,97,110,112,114,101,115,116,111,32,47,32,66,97,110,100,97,105,0,0,0,0,0,0,54,48,107,32,97,110,100,32,49,51,48,107,0,0,0,0,99,114,117,115,104,0,0,0,76,0,0,0,101,0,0,0,116,0,0,0,104,0,0,0,97,0,0,0,108,0,0,0,32,0,0,0,67,0,0,0,114,0,0,0,97,0,0,0,115,0,0,0,104,0,0,0,32,0,0,0,82,0,0,0,97,0,0,0,99,0,0,0,101,0,0,0,0,0,0,0,6,114,0,0,200,112,0,0,32,0,0,0,175,48,0,0,233,48,0,0,195,48,0,0,183,48,0,0,229,48,0,0,32,0,0,0,236,48,0,0,252,48,0,0,185,48,0,0,32,0,0,0,40,0,0,0,115,0,0,0,101,0,0,0,116,0,0,0,32,0,0,0,50,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,116,103,95,116,114,105,99,107,121,0,0,0,0,0,0,0,85,110,105,118,101,114,115,101,32,66,73,79,83,32,118,101,114,46,32,49,46,51,0,0,67,108,97,121,32,70,105,103,104,116,101,114,32,40,85,83,65,41,0,0,0,0,0,0,50,48,48,48,48,32,97,110,100,32,101,118,101,114,121,32,53,48,48,48,48,0,0,0,78,105,110,106,97,32,71,97,105,100,101,110,32,40,85,83,41,0,0,0,0,0,0,0,51,32,67,97,114,115,44,32,72,97,114,100,0,0,0,0,119,119,102,119,102,101,115,116,98,0,0,0,0,0,0,0,68,114,118,83,99,114,111,108,108,88,76,111,0,0,0,0,75,110,105,103,104,116,115,32,111,102,32,86,97,108,111,117,114,32,83,117,112,101,114,104,101,114,111,101,115,32,47,32,83,97,110,103,111,107,117,32,83,101,110,107,105,32,83,117,112,101,114,104,101,114,111,101,115,32,40,86,49,48,50,41,0,0,0,0,0,0,0,0,67,111,109,97,100,32,47,32,78,101,119,32,74,97,112,97,110,32,83,121,115,116,101,109,0,0,0,0,0,0,0,0,80,117,115,104,109,97,110,32,40,65,109,101,114,105,99,97,110,32,83,97,109,109,121,32,108,105,99,101,110,115,101,41,0,0,0,0,0,0,0,0,66,97,100,32,115,111,117,110,100,0,0,0,0,0,0,0,77,105,110,105,109,117,109,0,100,105,110,111,101,104,0,0,84,105,109,101,98,97,108,108,0,0,0,0,0,0,0,0,85,110,105,118,101,114,115,101,32,66,73,79,83,32,118,101,114,46,32,50,46,48,0,0,50,48,50,48,98,98,104,0,109,100,95,99,108,97,121,102,103,104,116,117,0,0,0,0,77,97,110,105,97,99,32,83,113,117,97,114,101,32,40,112,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,0,70,105,110,97,108,32,83,116,97,114,32,70,111,114,99,101,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,83,65,65,32,100,97,116,97,0,0,0,0,0,0,0,0,67,111,109,97,100,32,38,32,78,101,119,32,74,97,112,97,110,32,83,121,115,116,101,109,0,0,0,0,0,0,0,0,84,111,117,107,105,100,101,110,115,104,111,117,32,45,32,65,110,103,101,108,32,69,121,101,115,32,40,86,69,82,46,32,57,54,48,54,49,52,41,0,0,0,0,0,0,0,0,0,109,100,95,116,97,108,109,105,116,0,0,0,0,0,0,0,80,0,0,0,114,0,0,0,101,0,0,0,116,0,0,0,116,0,0,0,121,0,0,0,32,0,0,0,83,0,0,0,111,0,0,0,108,0,0,0,100,0,0,0,105,0,0,0,101,0,0,0,114,0,0,0,32,0,0,0,83,0,0,0,97,0,0,0,105,0,0,0,108,0,0,0,111,0,0,0,114,0,0,0,32,0,0,0,77,0,0,0,111,0,0,0,111,0,0,0,110,0,0,0,0,0,0,0,142,127,0,0,17,92,0,0,115,89,0,0,38,98,0,0,235,88,0,0,32,0,0,0,187,48,0,0,252,48,0,0,233,48,0,0,252,48,0,0,224,48,0,0,252,48,0,0,243,48,0,0,32,0,0,0,40,0,0,0,118,0,0,0,101,0,0,0,114,0,0,0,46,0,0,0,32,0,0,0,57,0,0,0,53,0,0,0,47,0,0,0,48,0,0,0,51,0,0,0,47,0,0,0,50,0,0,0,50,0,0,0,66,0,0,0,44,0,0,0,32,0,0,0,85,0,0,0,83,0,0,0,65,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,68,101,118,105,99,101,0,0,67,97,116,116,32,40,74,97,112,97,110,41,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,78,111,32,82,65,77,32,97,100,100,114,101,115,115,32,115,112,101,99,105,102,105,99,101,100,32,102,111,114,32,105,109,112,111,114,116,32,118,97,108,117,101,46,10,0,0,0,0,0,0,0,68,117,110,103,101,111,110,115,32,38,32,68,114,97,103,111,110,115,32,45,32,115,104,97,100,111,119,32,111,118,101,114,32,109,121,115,116,97,114,97,32,40,57,54,48,50,48,56,32,69,117,114,111,41,0,0,112,111,119,101,114,105,110,115,97,0,0,0,0,0,0,0,115,99,114,101,101,110,115,104,111,116,0,0,0,0,0,0,116,103,95,116,105,109,101,98,97,108,108,0,0,0,0,0,85,110,105,118,101,114,115,101,32,66,73,79,83,32,118,101,114,46,32,50,46,49,0,0,114,97,109,95,98,97,110,107,0,0,0,0,0,0,0,0,67,108,97,121,32,70,105,103,104,116,101,114,32,40,69,117,114,111,41,0,0,0,0,0,71,88,48,54,51,0,0,0,84,104,101,32,73,114,101,109,32,83,107,105,110,115,32,71,97,109,101,32,40,85,83,32,115,101,116,32,50,41,0,0,77,97,106,111,114,32,84,105,116,108,101,32,40,74,97,112,97,110,41,0,0,0,0,0,76,105,102,101,32,66,97,114,0,0,0,0,0,0,0,0,49,32,67,111,105,110,32,49,32,80,108,97,121,32,40,50,32,116,111,32,115,116,97,114,116,41,0,0,0,0,0,0,107,97,114,97,116,98,108,122,0,0,0,0,0,0,0,0,69,120,99,101,108,108,101,110,116,32,83,121,115,116,101,109,32,40,78,101,119,32,87,97,121,115,32,84,114,97,100,105,110,103,32,67,111,46,32,108,105,99,101,110,115,101,41,0,101,120,99,101,108,115,114,97,0,0,0,0,0,0,0,0,84,105,109,101,32,67,114,117,105,115,101,0,0,0,0,0,85,110,105,118,101,114,115,101,32,66,73,79,83,32,118,101,114,46,32,50,46,50,0,0,109,100,95,99,108,97,121,102,103,104,116,0,0,0,0,0,68,111,117,98,108,101,32,68,114,97,103,111,110,32,51,32,45,32,84,104,101,32,82,111,115,101,116,116,97,32,83,116,111,110,101,32,40,112,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,0,0,0,77,111,118,105,101,32,112,108,97,121,98,97,99,107,32,101,110,100,101,100,46,0,0,0,70,114,101,110,99,104,0,0,68,114,118,73,110,112,117,116,115,91,48,93,0,0,0,0,116,103,95,116,105,109,99,114,117,115,0,0,0,0,0,0,85,110,105,118,101,114,115,101,32,66,73,79,83,32,118,101,114,46,32,50,46,51,32,40,97,108,116,41,0,0,0,0,67,108,97,115,115,105,99,32,67,111,108,108,101,99,116,105,111,110,32,40,69,117,114,111,41,0,0,0,0,0,0,0,65,32,49,67,47,49,80,32,32,66,32,49,67,47,50,80,0,0,0,0,0,0,0,0,150,153,0,0,24,152,0,0,2,135,0,0,32,0,0,0,68,0,0,0,111,0,0,0,110,0,0,0,80,0,0,0,97,0,0,0,99,0,0,0,104,0,0,0,105,0,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,44,0,0,0,32,0,0,0,118,0,0,0,101,0,0,0,114,0,0,0,46,0,0,0,32,0,0,0,49,0,0,0,46,0,0,0,48,0,0,0,49,0,0,0,44,0,0,0,32,0,0,0,57,0,0,0,53,0,0,0,47,0,0,0,48,0,0,0,53,0,0,0,47,0,0,0,49,0,0,0,49,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,108,111,111,100,32,66,114,111,115,46,32,40,115,101,116,32,51,41,0,0,0,0,0,102,49,103,112,50,0,0,0,78,97,110,97,109,101,32,100,101,32,77,97,103,105,99,33,0,0,0,0,0,0,0,0,84,105,103,101,114,32,82,111,97,100,0,0,0,0,0,0,85,110,105,118,101,114,115,101,32,66,73,79,83,32,118,101,114,46,32,50,46,51,0,0,109,100,95,99,108,97,115,115,105,99,99,0,0,0,0,0,106,117,109,112,107,105,100,115,0,0,0,0,0,0,0,0,65,32,50,67,47,49,80,32,32,66,32,49,67,47,49,80,0,0,0,0,0,0,0,0,18,96,0,0,150,153,0,0,24,152,0,0,2,135,0,0,32,0,0,0,68,0,0,0,111,0,0,0,68,0,0,0,111,0,0,0,110,0,0,0,80,0,0,0,97,0,0,0,99,0,0,0,104,0,0,0,105,0,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,44,0,0,0,32,0,0,0,109,0,0,0,97,0,0,0,115,0,0,0,116,0,0,0,101,0,0,0,114,0,0,0,32,0,0,0,118,0,0,0,101,0,0,0,114,0,0,0,46,0,0,0,32,0,0,0,57,0,0,0,55,0,0,0,47,0,0,0,48,0,0,0,50,0,0,0,47,0,0,0,48,0,0,0,53,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,79,107,115,97,110,32,47,32,70,50,32,83,121,115,116,101,109,0,0,0,0,0,0,0,103,117,110,98,105,114,100,0,104,111,116,103,109,99,107,51,0,0,0,0,0,0,0,0,116,103,95,116,105,103,101,114,114,111,100,0,0,0,0,0,85,110,105,118,101,114,115,101,32,66,73,79,83,32,118,101,114,46,32,51,46,48,0,0,67,104,117,99,107,39,115,32,69,120,99,101,108,108,101,110,116,32,65,114,116,32,84,111,111,108,32,65,110,105,109,97,116,111,114,32,40,85,83,65,41,0,0,0,0,0,0,0,115,107,121,108,97,110,99,114,0,0,0,0,0,0,0,0,116,105,103,101,114,111,97,100,98,0,0,0,0,0,0,0,69,105,103,104,116,32,66,97,108,108,32,65,99,116,105,111,110,32,40,80,97,99,45,77,97,110,32,99,111,110,118,101,114,115,105,111,110,41,0,0,82,111,117,116,101,32,49,54,32,40,98,111,111,116,108,101,103,41,0,0,0,0,0,0,84,97,108,101,83,112,105,110,0,0,0,0,0,0,0,0,68,101,99,107,32,118,101,114,46,32,54,32,40,71,105,116,32,86,101,114,32,49,46,51,41,0,0,0,0,0,0,0,67,114,97,122,121,32,67,108,105,109,98,101,114,32,50,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,109,100,95,101,120,99,101,108,97,114,116,0,0,0,0,0,115,115,105,100,101,107,105,0,80,50,32,87,101,97,107,32,80,117,110,99,104,0,0,0,112,50,32,102,105,114,101,32,49,0,0,0,0,0,0,0,78,111,114,119,97,121,0,0,50,52,48,32,40,99,104,101,97,116,41,0,0,0,0,0,80,108,97,121,101,114,32,69,110,101,114,103,121,0,0,0,77,101,116,97,108,32,66,108,97,99,107,32,40,74,97,112,97,110,41,0,0,0,0,0,101,103,103,115,0,0,0,0,80,50,32,71,117,110,32,89,0,0,0,0,0,0,0,0,49,48,48,107,32,52,48,48,107,32,51,48,48,107,43,0,87,87,70,32,83,117,112,101,114,115,116,97,114,115,32,40,85,83,41,0,0,0,0,0,83,111,110,105,99,32,66,108,97,115,116,32,77,97,110,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,111,118,101,114,108,97,121,95,100,105,114,101,99,116,111,114,121,0,0,0,0,0,0,0,107,97,110,103,97,114,111,111,97,0,0,0,0,0,0,0,116,103,95,116,97,108,101,115,112,105,110,0,0,0,0,0,68,101,118,101,108,111,112,109,101,110,116,32,75,105,116,0,77,0,0,0,97,0,0,0,122,0,0,0,105,0,0,0,110,0,0,0,103,0,0,0,101,0,0,0,114,0,0,0,32,0,0,0,90,0,0,0,0,0,0,0,222,48,0,0,184,48,0,0,243,48,0,0,172,48,0,0,252,48,0,0,32,0,0,0,58,255,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,44,0,0,0,32,0,0,0,118,0,0,0,101,0,0,0,114,0,0,0,46,0,0,0,32,0,0,0,57,0,0,0,52,0,0,0,47,0,0,0,48,0,0,0,54,0,0,0,47,0,0,0,50,0,0,0,55,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,67,104,117,99,107,32,82,111,99,107,32,73,73,32,45,32,83,111,110,32,111,102,32,67,104,117,99,107,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,112,114,101,104,105,115,108,101,107,0,0,0,0,0,0,0,114,101,100,101,97,114,116,104,114,49,0,0,0,0,0,0,69,45,83,119,97,116,32,45,32,67,121,98,101,114,32,80,111,108,105,99,101,32,40,115,101,116,32,49,44,32,74,97,112,97,110,44,32,70,68,49,48,57,52,32,51,49,55,45,48,49,50,56,41,0,0,0,66,108,111,99,107,32,79,117,116,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,110,89,77,50,54,48,56,80,111,115,105,116,105,111,110,0,110,112,114,105,110,99,101,115,117,0,0,0,0,0,0,0,70,101,98,114,117,97,114,121,0,0,0,0,0,0,0,0,67,111,105,110,32,77,117,108,116,105,112,108,105,101,114,0,51,32,103,105,118,101,115,32,49,32,109,111,114,101,0,0,72,101,108,112,115,0,0,0,116,119,105,110,97,99,116,110,0,0,0,0,0,0,0,0,112,117,99,107,109,97,110,102,0,0,0,0,0,0,0,0,84,97,107,105,110,39,32,73,116,32,116,111,32,116,104,101,32,72,111,111,112,0,0,0,68,101,98,117,103,32,77,111,100,101,32,40,67,104,101,97,116,41,0,0,0,0,0,0,65,69,83,32,65,115,105,97,0,0,0,0,0,0,0,0,66,108,97,99,107,32,84,105,103,101,114,32,40,98,111,111,116,108,101,103,32,115,101,116,32,49,41,0,0,0,0,0,109,100,95,99,104,117,107,114,99,107,50,117,112,0,0,0,49,32,67,114,101,100,105,116,32,50,32,72,101,97,108,116,104,32,80,97,99,107,115,0,71,97,117,110,116,108,101,116,32,40,74,97,112,97,110,101,115,101,44,32,114,101,118,32,49,51,41,0,0,0,0,0,55,53,48,48,48,48,0,0,66,108,97,110,100,105,97,32,40,112,114,111,116,111,116,121,112,101,41,0,0,0,0,0,100,101,112,111,115,105,116,115,49,0,0,0,0,0,0,0,66,111,109,98,32,74,97,99,107,32,40,84,101,99,102,114,105,44,32,83,112,97,105,110,41,0,0,0,0,0,0,0,66,105,111,110,105,99,32,67,111,109,109,97,110,100,111,32,40,85,83,32,115,101,116,32,50,41,0,0,0,0,0,0,77,111,114,101,32,79,102,116,101,110,0,0,0,0,0,0,51,48,75,32,97,110,100,32,49,48,48,107,0,0,0,0,80,97,99,45,76,97,110,100,32,40,74,97,112,97,110,32,111,108,100,41,0,0,0,0,77,115,46,32,80,97,99,109,97,110,32,67,104,97,109,112,105,111,110,32,69,100,105,116,105,111,110,32,47,32,83,117,112,101,114,32,90,111,108,97,32,80,97,99,32,71,97,108,0,0,0,0,0,0,0,0,117,110,107,110,111,119,110,0,109,114,100,111,102,105,120,0,116,103,95,116,97,107,110,104,111,111,112,0,0,0,0,0,65,69,83,32,74,97,112,97,110,0,0,0,0,0,0,0,67,104,117,99,107,32,82,111,99,107,32,73,73,32,45,32,83,111,110,32,111,102,32,67,104,117,99,107,32,40,85,83,65,41,0,0,0,0,0,0,108,97,100,121,98,103,98,50,0,0,0,0,0,0,0,0,53,48,48,48,48,48,0,0,100,107,111,110,103,0,0,0,51,32,67,97,114,115,44,32,77,101,100,105,117,109,0,0,68,114,118,83,99,114,111,108,108,89,72,105,0,0,0,0,71,117,110,46,32,83,109,111,107,101,32,40,85,83,32,115,101,116,32,49,41,0,0,0,107,111,118,115,104,49,48,50,0,0,0,0,0,0,0,0,84,101,114,114,97,32,67,114,101,115,116,97,32,40,89,77,51,53,50,54,32,115,101,116,32,51,41,0,0,0,0,0,66,111,117,107,101,110,32,68,97,110,115,104,97,107,117,32,68,111,110,32,45,32,84,104,101,32,76,111,115,116,32,83,117,110,104,101,97,114,116,0,0,0,0,0,0,0,0,0,68,0,0,0,105,0,0,0,110,0,0,0,111,0,0,0,115,0,0,0,97,0,0,0,117,0,0,0,114,0,0,0,32,0,0,0,72,0,0,0,117,0,0,0,110,0,0,0,116,0,0,0,101,0,0,0,114,0,0,0,32,0,0,0,80,96,0,0,141,159,0,0,117,115,0,0,186,78,0,0,32,0,0,0,40,0,0,0,67,0,0,0,104,0,0,0,105,0,0,0,110,0,0,0,101,0,0,0,115,0,0,0,101,0,0,0,32,0,0,0,98,0,0,0,111,0,0,0,111,0,0,0,116,0,0,0,108,0,0,0,101,0,0,0,103,0,0,0,44,0,0,0,32,0,0,0,57,0,0,0,51,0,0,0,48,0,0,0,50,0,0,0,50,0,0,0,51,0,0,0,32,0,0,0,65,0,0,0,115,0,0,0,105,0,0,0,97,0,0,0,32,0,0,0,84,0,0,0,87,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,84,111,107,105,32,40,85,83,41,0,0,0,0,0,0,0,116,103,95,99,104,97,115,101,104,113,0,0,0,0,0,0,77,86,83,32,74,97,112,97,110,32,40,74,51,41,0,0,50,48,50,48,32,83,117,112,101,114,32,66,97,115,101,98,97,108,108,32,40,115,101,116,32,50,41,0,0,0,0,0,112,111,114,116,54,48,0,0,109,100,95,99,104,117,107,114,99,107,50,117,0,0,0,0,67,97,112,99,111,109,32,40,77,101,109,101,116,114,111,110,32,108,105,99,101,110,115,101,41,0,0,0,0,0,0,0,55,32,71,97,109,101,115,32,77,97,116,99,104,0,0,0,86,117,108,103,117,115,32,40,74,97,112,97,110,63,41,0,0,0,0,0,0,0,0,0,84,111,117,114,110,97,109,101,110,116,32,40,72,97,114,100,101,114,41,0,0,0,0,0,49,57,52,50,32,40,82,101,118,105,115,105,111,110,32,65,44,32,98,111,111,116,108,101,103,41,0,0,0,0,0,0,54,56,107,32,35,48,32,82,97,109,0,0,0,0,0,0,74,111,101,32,77,111,110,116,97,110,97,32,73,73,32,83,112,111,114,116,115,32,84,97,108,107,32,70,111,111,116,98,97,108,108,32,40,87,111,114,108,100,41,0,0,0,0,0,110,65,110,97,108,111,103,65,120,105,115,0,0,0,0,0,80,108,97,121,101,114,0,0,77,101,116,114,111,45,67,114,111,115,115,32,40,115,101,116,32,49,41,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,73,110,118,97,108,105,100,32,105,110,112,117,116,32,115,108,111,116,32,102,111,114,32,105,109,112,111,114,116,46,10,0,0,0,0,100,100,115,111,109,114,51,0,99,104,101,97,116,95,116,111,103,103,108,101,0,0,0,0,116,103,95,115,118,111,108,108,101,121,0,0,0,0,0,0,78,69,79,45,77,86,72,32,77,86,49,67,0,0,0,0,67,104,117,99,107,32,82,111,99,107,32,73,73,32,40,74,112,110,41,0,0,0,0,0,84,101,101,110,97,103,101,32,77,117,116,97,110,116,32,78,105,110,106,97,32,84,117,114,116,108,101,115,32,45,32,84,117,114,116,108,101,115,32,105,110,32,84,105,109,101,32,40,52,32,80,108,97,121,101,114,115,32,118,101,114,46,32,85,65,65,41,0,0,0,0,0,77,121,115,116,101,114,105,111,117,115,32,83,116,111,110,101,115,32,45,32,68,114,46,32,75,105,99,107,32,105,110,32,65,100,118,101,110,116,117,114,101,32,40,73,116,105,115,97,32,80,67,66,41,0,0,0,115,107,105,110,103,97,109,101,50,0,0,0,0,0,0,0,109,97,106,116,105,116,108,101,106,0,0,0,0,0,0,0,97,116,101,116,114,105,115,98,0,0,0,0,0,0,0,0,53,32,71,97,109,101,115,32,77,97,116,99,104,0,0,0,74,97,99,107,32,116,104,101,32,71,105,97,110,116,107,105,108,108,101,114,32,40,115,101,116,32,51,41,0,0,0,0,116,103,95,115,115,115,111,108,100,114,0,0,0,0,0,0,77,86,83,32,74,97,112,97,110,32,118,101,114,46,32,51,32,40,52,32,115,108,111,116,41,0,0,0,0,0,0,0,99,111,109,109,97,110,100,111,106,0,0,0,0,0,0,0,109,100,95,99,104,117,107,114,99,107,50,106,0,0,0,0,49,57,52,51,58,32,77,105,100,119,97,121,32,75,97,105,115,101,110,32,40,74,97,112,97,110,44,32,82,101,118,32,66,41,0,0,0,0,0,0,51,32,71,97,109,101,115,32,77,97,116,99,104,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,115,116,97,114,116,32,109,111,118,105,101,32,114,101,99,111,114,100,46,10,0,0,0,0,0,57,57,32,77,101,110,47,77,97,120,32,84,105,109,101,114,0,0,0,0,0,0,0,0,68,121,110,97,109,105,116,101,32,68,117,107,101,32,40,74,97,112,97,110,41,0,0,0,107,117,110,105,111,107,117,110,98,0,0,0,0,0,0,0,80,114,101,118,105,111,117,115,32,115,104,97,100,101,114,0,115,97,116,117,114,110,122,105,0,0,0,0,0,0,0,0,83,107,121,32,87,111,108,102,32,40,115,101,116,32,49,41,0,0,0,0,0,0,0,0,49,32,71,97,109,101,32,32,77,97,116,99,104,0,0,0,103,97,108,97,120,105,97,110,0,0,0,0,0,0,0,0,116,103,95,115,112,108,97,116,116,104,0,0,0,0,0,0,77,86,83,32,74,97,112,97,110,32,118,101,114,46,32,53,32,40,63,32,115,108,111,116,41,0,0,0,0,0,0,0,67,104,117,99,107,32,82,111,99,107,32,73,73,32,45,32,83,111,110,32,111,102,32,67,104,117,99,107,32,40,69,117,114,111,41,0,0,0,0,0,76,97,115,116,32,68,117,101,108,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,85,80,68,55,55,53,57,32,37,100,0,0,0,0,0,0,51,48,48,48,48,32,49,50,48,48,48,48,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,40,85,83,32,115,101,116,32,50,41,0,0,0,0,0,0,0,84,104,101,32,83,112,101,101,100,32,82,117,109,98,108,101,114,32,40,115,101,116,32,51,41,0,0,0,0,0,0,0,83,107,121,32,75,105,100,32,40,67,85,83,54,48,32,118,101,114,115,105,111,110,41,0,0,0,0,0,0,0,0,0,79,109,101,103,97,0,0,0,71,104,111,115,116,115,39,110,32,71,111,98,108,105,110,115,32,40,98,111,111,116,108,101,103,32,119,105,116,104,32,67,114,111,115,115,41,0,0,0,116,103,95,115,104,97,114,114,105,101,114,0,0,0,0,0,77,86,83,32,74,97,112,97,110,32,118,101,114,46,32,54,32,40,63,32,115,108,111,116,41,0,0,0,0,0,0,0,109,114,102,108,101,97,95,109,97,105,110,0,0,0,0,0,71,97,109,101,32,79,118,101,114,32,77,101,115,115,97,103,101,0,0,0,0,0,0,0,109,100,95,99,104,117,107,114,99,107,50,0,0,0,0,0,86,115,46,32,80,108,97,121,32,77,111,100,101,0,0,0,50,48,48,48,48,32,49,50,48,48,48,48,0,0,0,0,71,97,108,97,103,97,32,40,77,105,100,119,97,121,32,115,101,116,32,49,41,0,0,0,87,111,114,108,100,32,67,117,112,32,39,57,48,32,40,69,117,114,111,32,115,101,116,32,50,41,0,0,0,0,0,0,82,97,108,108,121,32,88,32,40,77,105,100,119,97,121,41,0,0,0,0,0,0,0,0,115,118,111,108,108,101,121,0,83,111,110,105,99,32,83,112,105,107,101,32,45,32,87,111,114,108,100,32,67,104,97,109,112,105,111,110,115,104,105,112,32,66,101,97,99,104,32,86,111,108,108,101,121,98,97,108,108,0,0,0,0,0,0,0,77,86,83,32,85,83,65,32,118,101,114,46,32,53,32,40,54,32,115,108,111,116,41,0,97,109,98,117,115,104,104,0,67,104,117,99,107,32,82,111,99,107,32,40,85,83,65,41,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,83,82,65,77,32,105,115,32,108,97,114,103,101,114,32,116,104,97,110,32,105,109,112,108,101,109,101,110,116,97,116,105,111,110,32,101,120,112,101,99,116,115,44,32,100,111,105,110,103,32,112,97,114,116,105,97,108,32,108,111,97,100,32,40,116,114,117,110,99,97,116,105,110,103,32,37,117,32,98,121,116,101,115,32,116,111,32,37,117,41,46,10,0,0,0,0,0,0,0,0,82,121,103,97,114,32,40,85,83,32,115,101,116,32,51,44,32,111,108,100,32,118,101,114,115,105,111,110,41,0,0,0,80,117,110,105,112,105,99,80,114,105,111,114,105,116,121,86,97,108,117,101,0,0,0,0,100,100,114,97,103,111,110,119,49,0,0,0,0,0,0,0,128,146,0,0,179,108,0,0,251,78,0,0,160,79,0,0,29,79,0,0,0,0,0,0,71,0,0,0,105,0,0,0,110,0,0,0,103,0,0,0,97,0,0,0,32,0,0,0,78,0,0,0,105,0,0,0,110,0,0,0,107,0,0,0,121,0,0,0,111,0,0,0,117,0,0,0,68,0,0,0,101,0,0,0,110,0,0,0,32,0,0,0,40,0,0,0,115,0,0,0,101,0,0,0,116,0,0,0,32,0,0,0,50,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,109,95,111,108,100,115,95,112,114,111,116,95,104,105,108,111,0,0,0,0,0,0,0,0,116,103,95,119,98,101,97,99,104,0,0,0,0,0,0,0,77,86,83,32,85,83,65,32,118,101,114,46,32,53,32,40,50,32,115,108,111,116,41,0,109,100,95,99,104,117,99,107,114,99,107,117,0,0,0,0,80,50,32,85,115,101,0,0,115,108,111,116,51,107,99,0,73,116,97,108,121,0,0,0,112,51,32,108,101,102,116,0,79,0,0,0,114,0,0,0,105,0,0,0,101,0,0,0,110,0,0,0,116,0,0,0,97,0,0,0,108,0,0,0,32,0,0,0,76,0,0,0,101,0,0,0,103,0,0,0,101,0,0,0,110,0,0,0,100,0,0,0,0,0,0,0,127,137,0,0,56,110,0,0,202,145,0,0,132,83,0,0,32,79,0,0,32,0,0,0,40,0,0,0,86,0,0,0,49,0,0,0,50,0,0,0,54,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,109,101,116,97,108,98,106,0,49,48,48,107,32,51,48,48,107,32,50,48,48,107,43,0,115,98,109,0,0,0,0,0,114,103,117,105,95,115,104,111,119,95,115,116,97,114,116,95,115,99,114,101,101,110,0,0,83,111,109,101,114,32,65,115,115,97,117,108,116,0,0,0,77,86,83,32,65,115,105,97,47,69,117,114,111,112,101,32,118,101,114,46,32,51,32,40,52,32,115,108,111,116,41,0,67,104,117,99,107,32,82,111,99,107,32,40,69,117,114,111,41,0,0,0,0,0,0,0,87,0,0,0,97,0,0,0,114,0,0,0,45,0,0,0,90,0,0,0,97,0,0,0,114,0,0,0,100,0,0,0,0,0,0,0,82,0,0,0,101,0,0,0,100,0,0,0,32,0,0,0,69,0,0,0,97,0,0,0,114,0,0,0,116,0,0,0,104,0,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,32,0,0,0,57,0,0,0,54,0,0,0,49,0,0,0,49,0,0,0,50,0,0,0,49,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,101,115,119,97,116,106,0,0,83,101,103,97,80,67,77,108,111,119,0,0,0,0,0,0,78,105,110,106,97,32,80,114,105,110,99,101,115,115,32,40,51,49,53,45,53,48,57,56,44,32,49,50,56,107,32,86,101,114,46,41,0,0,0,0,74,97,110,117,97,114,121,0,50,32,103,105,118,101,115,32,49,32,109,111,114,101,0,0,100,98,108,112,111,105,110,0,89,79,78,65,32,84,101,99,104,0,0,0,0,0,0,0,72,111,114,105,122,46,32,70,108,105,112,32,83,99,114,101,101,110,0,0,0,0,0,0,116,103,95,115,111,109,101,114,97,115,115,0,0,0,0,0,108,97,116,99,104,0,0,0,77,86,83,32,65,115,105,97,47,69,117,114,111,112,101,32,118,101,114,46,32,53,32,40,49,32,115,108,111,116,41,0,109,100,95,99,104,117,99,107,114,99,107,0,0,0,0,0,119,97,116,99,104,100,111,103,0,0,0,0,0,0,0,0,49,32,67,114,101,100,105,116,32,51,32,72,101,97,108,116,104,32,80,97,99,107,115,0,78,111,32,69,120,116,101,110,100,0,0,0,0,0,0,0,98,108,97,110,100,105,97,112,0,0,0,0,0,0,0,0,78,69,67,32,72,111,109,101,32,69,108,101,99,116,114,111,110,105,99,115,0,0,0,0,98,114,97,109,95,108,111,99,107,101,100,0,0,0,0,0,76,101,115,115,32,79,102,116,101,110,0,0,0,0,0,0,82,111,116,97,116,101,32,66,117,116,116,111,110,115,0,0,109,115,99,104,97,109,112,115,0,0,0,0,0,0,0,0,116,103,95,115,111,108,100,98,108,97,100,0,0,0,0,0,77,86,83,32,65,115,105,97,47,69,117,114,111,112,101,32,118,101,114,46,32,54,32,40,49,32,115,108,111,116,41,0,67,104,105,110,101,115,101,32,67,104,101,115,115,0,0,0,50,56,48,48,48,48,48,0,51,32,67,111,105,110,115,32,52,32,80,108,97,121,115,0,51,32,67,97,114,115,44,32,69,97,115,121,0,0,0,0])
.concat([68,114,118,83,99,114,111,108,108,88,72,105,0,0,0,0,75,110,105,103,104,116,115,32,111,102,32,86,97,108,111,117,114,32,83,117,112,101,114,104,101,114,111,101,115,32,47,32,83,97,110,103,111,107,117,32,83,101,110,107,105,32,83,117,112,101,114,104,101,114,111,101,115,32,40,86,49,48,51,41,0,0,0,0,0,0,0,0,112,99,101,95,108,111,115,116,115,117,110,104,0,0,0,0,68,105,110,111,115,97,117,114,32,72,117,110,116,101,114,32,40,67,104,105,110,101,115,101,32,98,111,111,116,108,101,103,44,32,57,51,48,50,50,51,32,65,115,105,97,32,84,87,41,0,0,0,0,0,0,0,83,105,110,105,115,116,114,111,110,0,0,0,0,0,0,0,66,73,79,83,0,0,0,0,50,48,50,48,98,98,97,0,109,100,95,99,104,105,110,101,115,101,99,0,0,0,0,0,110,101,111,99,100,122,0,0,49,56,48,48,48,48,48,0,78,86,82,65,77,0,0,0,49,57,52,49,32,45,32,67,111,117,110,116,101,114,32,65,116,116,97,99,107,32,40,57,48,48,50,50,55,32,85,83,65,41,0,0,0,0,0,0,109,100,95,106,111,101,109,111,110,116,50,0,0,0,0,0,79,118,101,114,108,97,121,32,83,99,97,108,101,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,73,110,118,97,108,105,100,32,115,101,109,97,110,116,105,99,32,102,111,114,32,105,109,112,111,114,116,32,118,97,108,117,101,46,10,0,0,0,0,0,0,0,0,68,117,110,103,101,111,110,115,32,38,32,68,114,97,103,111,110,115,32,45,32,115,104,97,100,111,119,32,111,118,101,114,32,109,121,115,116,97,114,97,32,40,57,54,48,50,48,57,32,69,117,114,111,41,0,0,99,104,101,97,116,95,105,110,100,101,120,95,109,105,110,117,115,0,0,0,0,0,0,0,116,103,95,115,105,110,105,115,116,114,110,0,0,0,0,0,67,104,105,107,105,32,67,104,105,107,105,32,66,111,121,115,32,40,74,112,110,44,32,75,111,114,41,0,0,0,0,0,116,109,110,116,50,0,0,0,84,104,101,32,73,114,101,109,32,83,107,105,110,115,32,71,97,109,101,32,40,85,83,32,115,101,116,32,49,41,0,0,77,97,106,111,114,32,84,105,116,108,101,32,40,87,111,114,108,100,41,0,0,0,0,0,69,120,116,101,110,100,101,100,32,66,111,110,117,115,32,76,105,102,101,0,0,0,0,0,116,103,95,115,105,108,101,110,116,100,0,0,0,0,0,0,109,100,95,99,104,105,107,105,106,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,116,97,114,116,105,110,103,32,109,111,118,105,101,32,114,101,99,111,114,100,32,116,111,32,34,37,115,34,46,10,0,0,0,0,0,0,50,53,53,32,76,105,118,101,115,0,0,0,0,0,0,0,68,101,108,116,97,84,46,97,100,112,99,109,100,0,0,0,80,76,84,69,0,0,0,0,82,97,100,105,97,110,99,101,32,83,111,102,116,119,97,114,101,0,0,0,0,0,0,0,83,101,116,116,105,110,103,32,55,0,0,0,0,0,0,0,116,111,111,32,109,97,110,121,32,108,101,110,103,116,104,32,111,114,32,100,105,115,116,97,110,99,101,32,115,121,109,98,111,108,115,0,0,0,0,0,67,104,105,107,105,32,67,104,105,107,105,32,66,111,121,115,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,103,108,84,101,120,83,117,98,73,109,97,103,101,51,68,79,69,83,0,0,0,0,0,0,55,32,40,72,97,114,100,101,115,116,41,0,0,0,0,0,35,105,102,100,101,102,32,71,76,95,69,83,10,112,114,101,99,105,115,105,111,110,32,109,101,100,105,117,109,112,32,102,108,111,97,116,59,10,35,101,110,100,105,102,10,117,110,105,102,111,114,109,32,115,97,109,112,108,101,114,50,68,32,84,101,120,116,117,114,101,59,10,118,97,114,121,105,110,103,32,118,101,99,50,32,116,101,120,95,99,111,111,114,100,59,10,118,97,114,121,105,110,103,32,118,101,99,52,32,99,111,108,111,114,59,10,118,111,105,100,32,109,97,105,110,40,41,32,123,10,32,32,32,103,108,95,70,114,97,103,67,111,108,111,114,32,61,32,99,111,108,111,114,32,42,32,116,101,120,116,117,114,101,50,68,40,84,101,120,116,117,114,101,44,32,116,101,120,95,99,111,111,114,100,41,59,10,125,0,0,0,0,116,104,101,101,110,100,0,0,51,32,40,78,111,114,109,97,108,41,0,0,0,0,0,0,116,103,95,115,105,100,101,97,114,109,115,0,0,0,0,0,83,101,116,116,105,110,103,32,54,0,0,0,0,0,0,0,69,110,101,109,121,32,87,101,97,112,111,110,32,83,112,101,101,100,0,0,0,0,0,0,109,100,95,99,104,105,107,105,0,0,0,0,0,0,0,0,83,76,79,84,45,62,67,110,116,0,0,0,0,0,0,0,79,69,83,95,112,97,99,107,101,100,95,100,101,112,116,104,95,115,116,101,110,99,105,108,0,0,0,0,0,0,0,0,83,104,111,99,107,109,97,110,0,0,0,0,0,0,0,0,83,101,116,116,105,110,103,32,53,0,0,0,0,0,0,0,67,104,105,98,105,32,77,97,114,117,107,111,45,99,104,97,110,32,45,32,87,97,107,117,119,97,107,117,32,83,104,111,112,112,105,110,103,32,40,74,112,110,41,0,0,0,0,0,48,32,40,69,97,115,105,101,115,116,41,0,0,0,0,0,116,103,95,115,104,111,99,107,109,97,110,0,0,0,0,0,70,73,70,65,32,57,55,32,71,111,108,100,32,69,100,105,116,105,111,110,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,0,0,83,101,116,116,105,110,103,32,52,0,0,0,0,0,0,0,109,100,95,99,104,105,98,105,109,0,0,0,0,0,0,0,75,48,53,50,49,48,57,67,104,97,114,82,111,109,66,97,110,107,91,48,93,0,0,0,80,50,32,83,101,108,101,99,116,0,0,0,0,0,0,0,77,111,110,97,117,114,97,108,0,0,0,0,0,0,0,0,67,114,105,109,101,32,70,105,103,104,116,101,114,115,32,40,87,111,114,108,100,32,50,32,80,108,97,121,101,114,115,41,0,0,0,0,0,0,0,0,112,50,32,114,105,103,104,116,0,0,0,0,0,0,0,0,72,111,108,108,97,110,100,0,78,117,109,98,101,114,32,111,102,32,104,101,114,111,101,115,0,0,0,0,0,0,0,0,72,97,117,110,116,101,100,32,67,97,115,116,108,101,32,40,118,101,114,46,32,69,41,0,0,0,0,0,0,0,0,0,84,104,101,32,77,97,105,110,32,69,118,101,110,116,32,40,50,32,80,108,97,121,101,114,115,32,118,101,114,46,32,88,41,0,0,0,0,0,0,0,77,101,116,97,108,32,66,108,97,99,107,32,40,87,111,114,108,100,41,0,0,0,0,0,80,50,32,71,117,110,32,88,0,0,0,0,0,0,0,0,53,48,107,32,50,53,48,107,32,50,48,48,107,43,0,0,65,108,105,101,110,115,32,40,87,111,114,108,100,32,115,101,116,32,51,41,0,0,0,0,83,112,97,99,101,32,73,110,118,97,100,101,114,115,32,68,88,32,40,74,97,112,97,110,44,32,118,50,46,48,41,0,0,0,0,0,0,0,0,0,114,103,117,105,95,99,111,110,102,105,103,95,100,105,114,101,99,116,111,114,121,0,0,0,71,114,101,101,110,32,66,101,114,101,116,32,40,98,111,111,116,108,101,103,41,0,0,0,83,97,109,117,114,97,105,45,71,104,111,115,116,0,0,0,83,101,116,116,105,110,103,32,51,0,0,0,0,0,0,0,67,104,105,32,67,104,105,39,115,32,80,114,111,32,67,104,97,108,108,101,110,103,101,32,71,111,108,102,32,40,85,83,65,41,0,0,0,0,0,0,87,97,114,45,90,97,114,100,32,47,32,82,101,100,32,69,97,114,116,104,32,40,74,97,112,97,110,32,57,54,49,49,50,49,41,0,0,0,0,0,80,0,0,0,97,0,0,0,114,0,0,0,111,0,0,0,100,0,0,0,105,0,0,0,117,0,0,0,115,0,0,0,32,0,0,0,209,48,0,0,237,48,0,0,199,48,0,0,163,48,0,0,166,48,0,0,185,48,0,0,96,48,0,0,1,255,0,0,32,0,0,0,13,255,0,0,94,121,0,0,113,138,0,0,75,48,0,0,137,48,0,0,74,48,0,0,17,123,0,0,68,48,0,0,120,48,0,0,13,255,0,0,32,0,0,0,40,0,0,0,87,0,0,0,111,0,0,0,114,0,0,0,108,0,0,0,100,0,0,0,44,0,0,0,32,0,0,0,115,0,0,0,101,0,0,0,116,0,0,0,32,0,0,0,50,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,101,116,116,105,110,103,32,82,71,85,73,32,115,104,97,100,101,114,58,32,37,115,46,10,0,0,0,0,69,45,83,119,97,116,32,45,32,67,121,98,101,114,32,80,111,108,105,99,101,32,40,115,101,116,32,51,44,32,87,111,114,108,100,44,32,70,68,49,48,57,52,32,51,49,55,45,48,49,51,48,41,0,0,0,122,105,112,0,0,0,0,0,81,32,83,111,117,110,100,0,98,97,110,107,49,0,0,0,110,112,114,105,110,99,101,115,111,0,0,0,0,0,0,0,57,32,67,111,105,110,115,32,49,32,80,108,97,121,0,0,98,97,115,105,99,95,115,116,114,105,110,103,0,0,0,0,48,32,115,101,99,0,0,0,77,97,105,110,32,83,116,97,100,105,117,109,32,40,74,97,112,97,110,32,118,101,114,46,32,52,41,0,0,0,0,0,98,97,110,107,99,116,114,108,0,0,0,0,0,0,0,0,68,105,97,103,110,111,115,116,105,99,0,0,0,0,0,0,116,104,117,110,100,101,114,120,0,0,0,0,0,0,0,0,83,112,101,99,116,114,117,109,32,50,48,48,48,32,40,69,117,114,111,41,0,0,0,0,86,101,114,116,46,32,70,108,105,112,32,83,99,114,101,101,110,0,0,0,0,0,0,0,87,105,115,100,111,109,32,111,102,32,69,110,101,109,121,0,72,121,112,101,114,32,83,112,111,114,116,115,32,83,112,101,99,105,97,108,32,40,74,97,112,97,110,41,0,0,0,0,116,103,95,115,97,109,117,114,97,105,103,0,0,0,0,0,110,101,119,95,108,97,116,99,104,0,0,0,0,0,0,0,83,101,116,116,105,110,103,32,50,0,0,0,0,0,0,0,109,100,95,99,104,105,99,104,105,0,0,0,0,0,0,0,97,106,97,120,106,0,0,0,49,32,67,114,101,100,105,116,32,52,32,72,101,97,108,116,104,32,80,97,99,107,115,0,114,101,97,100,122,111,111,109,114,111,109,115,0,0,0,0,37,115,37,99,115,97,109,112,108,101,115,0,0,0,0,0,66,108,97,110,100,105,97,0,0,0,0,0,0,0,0,0,67,111,110,116,114,97,32,40,98,111,111,116,108,101,103,41,0,0,0,0,0,0,0,0,88,45,77,101,110,32,40,52,32,80,108,97,121,101,114,115,32,118,101,114,32,65,68,65,41,0,0,0,0,0,0,0,65,115,116,114,111,110,97,117,116,115,32,75,105,100,110,97,112,112,101,100,0,0,0,0,83,117,114,112,114,105,115,101,32,65,116,116,97,99,107,32,40,74,97,112,97,110,32,118,101,114,46,32,77,41,0,0,49,32,67,111,105,110,32,116,111,32,67,111,110,116,105,110,117,101,0,0,0,0,0,0,77,115,46,32,80,97,99,109,97,110,32,67,104,97,109,112,105,111,110,32,69,100,105,116,105,111,110,32,47,32,90,111,108,97,45,80,117,99,32,71,97,108,0,0,0,0,0,0,71,76,83,76,0,0,0,0,100,97,114,107,97,100,118,0,116,103,95,114,97,105,100,101,110,0,0,0,0,0,0,0,83,101,116,116,105,110,103,32,49,0,0,0,0,0,0,0,67,104,101,115,116,101,114,32,67,104,101,101,116,97,104,32,45,32,87,105,108,100,32,87,105,108,100,32,81,117,101,115,116,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,50,67,95,52,67,0,0,0,57,48,107,32,51,53,48,107,0,0,0,0,0,0,0,0,103,114,97,100,105,117,115,51,97,0,0,0,0,0,0,0,65,32,50,67,47,49,80,32,32,66,32,50,67,47,49,80,0,0,0,0,0,0,0,0,115,112,121,95,118,105,100,101,111,95,101,110,97,98,108,101,0,0,0,0,0,0,0,0,50,32,67,97,114,115,44,32,72,97,114,100,0,0,0,0,103,121,114,117,115,115,98,0,107,111,118,115,104,49,48,51,0,0,0,0,0,0,0,0,86,101,110,100,101,116,116,97,32,40,87,111,114,108,100,32,50,32,80,108,97,121,101,114,115,32,118,101,114,46,32,87,41,0,0,0,0,0,0,0,49,57,88,88,32,45,32,116,104,101,32,119,97,114,32,97,103,97,105,110,115,116,32,100,101,115,116,105,110,121,32,40,57,53,49,50,49,56,32,66,114,97,122,105,108,41,0,0,66,111,109,98,101,114,109,97,110,32,45,32,85,115,101,114,115,32,66,97,116,116,108,101,0,0,0,0,0,0,0,0,100,105,110,111,104,117,110,116,0,0,0,0,0,0,0,0,67,114,97,122,121,32,67,111,112,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,82,45,84,121,112,101,0,0,50,48,50,48,32,83,117,112,101,114,32,66,97,115,101,98,97,108,108,32,40,115,101,116,32,49,41,0,0,0,0,0,109,100,95,99,104,101,115,116,101,114,119,0,0,0,0,0,84,104,101,32,83,105,109,112,115,111,110,115,32,40,50,32,80,108,97,121,101,114,115,32,87,111,114,108,100,44,32,115,101,116,32,49,41,0,0,0,112,111,111,116,97,110,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,105,109,97,103,101,58,32,37,115,46,10,0,0,0,0,0,0,109,100,95,106,111,101,109,111,110,116,50,97,0,0,0,0,84,101,101,110,97,103,101,32,77,117,116,97,110,116,32,78,105,110,106,97,32,84,117,114,116,108,101,115,32,40,85,83,32,52,32,80,108,97,121,101,114,115,44,32,115,101,116,32,50,41,0,0,0,0,0,0,79,118,101,114,108,97,121,32,79,112,97,99,105,116,121,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,78,111,32,115,101,109,97,110,116,105,99,32,111,114,32,73,68,32,102,111,114,32,105,109,112,111,114,116,32,118,97,108,117,101,46,10,0,0,0,0,0,0,0,100,100,115,111,109,114,50,0,61,34,0,0,0,0,0,0,98,111,109,98,114,109,97,110,0,0,0,0,0,0,0,0,99,104,101,97,116,95,105,110,100,101,120,95,112,108,117,115,0,0,0,0,0,0,0,0,116,103,95,114,116,121,112,101,0,0,0,0,0,0,0,0,67,111,109,109,109,117,110,105,99,97,116,111,110,0,0,0,67,104,101,115,116,101,114,32,67,104,101,101,116,97,104,32,45,32,84,111,111,32,67,111,111,108,32,116,111,32,70,111,111,108,32,40,85,83,65,41,0,0,0,0,0,0,0,0,84,114,105,103,111,110,32,40,74,97,112,97,110,41,0,0,115,112,97,114,116,97,110,120,0,0,0,0,0,0,0,0,115,107,105,110,103,97,109,101,0,0,0,0,0,0,0,0,109,97,106,116,105,116,108,101,0,0,0,0,0,0,0,0,83,116,97,114,116,32,50,47,80,49,32,70,105,114,101,32,50,0,0,0,0,0,0,0,86,105,103,105,108,97,110,116,101,32,40,85,83,41,0,0,73,114,101,109,32,40,77,101,109,101,116,114,111,110,32,108,105,99,101,110,115,101,41,0,80,115,121,99,104,111,115,105,115,0,0,0,0,0,0,0,109,100,95,99,104,101,115,116,101,114,0,0,0,0,0,0,82,45,84,121,112,101,32,40,74,97,112,97,110,32,112,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,115,116,97,114,116,32,109,111,118,105,101,32,114,101,99,111,114,100,46,0,0,0,83,116,97,114,116,32,49,47,80,49,32,70,105,114,101,32,49,0,0,0,0,0,0,0,78,101,120,116,32,115,104,97,100,101,114,0,0,0,0,0,116,103,95,112,115,121,99,104,111,115,0,0,0,0,0,0,67,104,101,101,115,101,32,67,97,116,45,65,115,116,114,111,112,104,101,32,83,116,97,114,114,105,110,103,32,83,112,101,101,100,121,32,71,111,110,122,97,108,101,115,32,40,69,117,114,111,41,0,0,0,0,0,68,105,102,102,105,99,117,108,116,121,32,105,110,99,114,101,97,115,101,115,32,97,116,32,108,101,118,101,108,0,0,0,111,109,101,103,97,0,0,0,116,103,95,112,103,111,108,102,0,0,0,0,0,0,0,0,109,100,95,99,104,101,101,115,101,0,0,0,0,0,0,0,99,110,105,110,106,97,0,0,116,103,95,112,97,114,97,115,111,108,0,0,0,0,0,0,83,117,112,101,114,32,72,46,81,46,32,40,74,112,110,41,0,0,0,0,0,0,0,0,83,112,101,101,99,104,0,0,80,97,110,122,97,32,75,105,99,107,32,66,111,120,105,110,103,0,0,0,0,0,0,0,83,101,116,116,105,110,103,32,109,111,100,101,0,0,0,0,109,100,95,115,117,112,101,114,104,113,0,0,0,0,0,0,118,105,101,119,112,111,105,110,0,0,0,0,0,0,0,0,80,50,32,80,105,110,0,0,49,50,48,48,48,0,0,0,71,114,101,101,99,101,0,0,112,51,32,100,111,119,110,0,85,46,83,46,65,46,32,40,70,97,98,116,101,107,32,108,105,99,101,110,115,101,41,0,109,101,116,97,108,98,0,0,67,111,105,110,32,83,108,111,116,115,0,0,0,0,0,0,109,111,117,115,101,32,98,117,116,116,111,110,32,50,0,0,53,48,107,32,50,48,48,107,32,49,53,48,107,43,0,0,115,112,97,99,101,100,120,111,0,0,0,0,0,0,0,0,114,103,117,105,95,98,114,111,119,115,101,114,95,100,105,114,101,99,116,111,114,121,0,0,55,48,107,32,50,56,48,107,32,49,52,48,48,107,0,0,116,103,95,112,97,110,122,97,107,98,0,0,0,0,0,0,67,104,97,115,101,32,72,46,81,46,32,73,73,32,40,85,83,65,41,0,0,0,0,0,119,97,114,122,97,114,100,0,101,115,119,97,116,0,0,0,98,111,111,116,108,101,103,63,0,0,0,0,0,0,0,0,68,0,0,0,101,0,0,0,99,0,0,0,0,0,0,0,66,111,110,117,115,32,65,100,100,101,114,0,0,0,0,0,51,48,32,115,101,99,0,0,53,53,37,0,0,0,0,0,115,112,101,99,50,107,0,0,80,97,99,45,76,97,110,100,0,0,0,0,0,0,0,0,109,100,95,99,104,97,115,101,104,113,50,0,0,0,0,0,49,32,67,114,101,100,105,116,32,53,32,72,101,97,108,116,104,32,80,97,99,107,115,0,65,32,49,67,47,49,80,32,32,66,32,49,67,47,54,80,32,32,67,32,49,67,47,49,80,0,0,0,0,0,0,0,98,108,97,110,100,105,97,0,78,111,114,109,97,108,32,83,99,114,101,101,110,0,0,0,66,97,99,107,103,114,111,117,110,100,32,84,121,112,101,0,116,103,95,112,97,99,108,97,110,100,0,0,0,0,0,0,65,117,116,111,102,105,114,101,0,0,0,0,0,0,0,0,84,104,101,32,67,104,97,111,115,32,69,110,103,105,110,101,32,50,32,40,69,117,114,111,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,55,48,107,32,50,55,48,107,0,0,0,0,0,0,0,0,65,32,49,67,47,49,80,32,32,66,32,49,67,47,49,80,32,32,67,32,49,67,47,49,80,0,0,0,0,0,0,0,50,32,67,97,114,115,44,32,77,101,100,105,117,109,0,0,68,114,118,83,117,98,67,80,85,66,117,115,121,0,0,0,75,0,0,0,110,0,0,0,105,0,0,0,103,0,0,0,104,0,0,0,116,0,0,0,115,0,0,0,32,0,0,0,111,0,0,0,102,0,0,0,32,0,0,0,86,0,0,0,97,0,0,0,108,0,0,0,111,0,0,0,117,0,0,0,114,0,0,0,32,0,0,0,83,0,0,0,117,0,0,0,112,0,0,0,101,0,0,0,114,0,0,0,104,0,0,0,101,0,0,0,114,0,0,0,111,0,0,0,101,0,0,0,115,0,0,0,0,0,0,0,9,78,0,0,253,86,0,0,24,98,0,0,170,126,0,0,0,0,0,0,206,152,0,0,145,78,0,0,141,81,0,0,119,141,0,0,32,0,0,0,40,0,0,0,86,0,0,0,49,0,0,0,48,0,0,0,52,0,0,0,44,0,0,0,32,0,0,0,67,0,0,0,104,0,0,0,105,0,0,0,110,0,0,0,97,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,32,67,114,101,100,105,116,115,47,87,105,110,110,101,114,32,67,111,110,116,105,110,117,101,0,0,0,0,0,0,0,67,97,100,105,108,108,97,99,115,32,97,110,100,32,68,105,110,111,115,97,117,114,115,32,84,117,114,98,111,32,40,98,111,111,116,108,101,103,32,115,101,116,32,50,32,40,119,105,116,104,32,80,73,67,49,54,99,53,55,41,44,32,57,51,48,50,48,49,32,101,116,99,41,0,0,0,0,0,0,0,116,103,95,111,114,100,121,110,101,0,0,0,0,0,0,0,105,111,99,101,114,111,109,46,99,111,109,0,0,0,0,0,109,100,95,99,104,97,111,115,101,110,50,0,0,0,0,0,110,66,117,114,110,67,117,114,114,101,110,116,89,77,50,49,53,49,82,101,103,105,115,116,101,114,0,0,0,0,0,0,65,32,50,67,47,49,80,32,32,66,32,49,67,47,51,80,32,32,67,32,50,67,47,49,80,0,0,0,0,0,0,0,72,111,109,101,32,65,108,111,110,101,32,40,69,117,114,111,44,32,85,83,65,41,0,0,79,118,101,114,108,97,121,32,80,114,101,115,101,116,0,0,101,113,117,97,108,0,0,0,68,117,110,103,101,111,110,115,32,38,32,68,114,97,103,111,110,115,32,45,32,115,104,97,100,111,119,32,111,118,101,114,32,109,121,115,116,97,114,97,32,40,57,54,48,50,50,51,32,69,117,114,111,41,0,0,115,104,97,100,101,114,95,112,114,101,118,0,0,0,0,0,79,114,100,101,114,32,111,102,32,116,104,101,32,71,114,105,102,102,111,110,0,0,0,0,80,114,105,109,111,32,68,101,109,111,0,0,0,0,0,0,83,111,108,100,105,101,114,115,32,111,102,32,70,111,114,116,117,110,101,32,40,85,83,65,41,0,0,0,0,0,0,0,116,114,105,103,111,110,0,0,77,97,106,111,114,32,84,105,116,108,101,32,50,32,40,74,97,112,97,110,41,0,0,0,49,32,67,114,101,100,105,116,47,78,111,32,67,111,110,116,105,110,117,101,0,0,0,0,65,32,50,67,47,49,80,32,32,66,32,50,67,47,49,80,32,32,67,32,50,67,47,49,80,0,0,0,0,0,0,0,116,103,95,103,114,105,102,102,111,110,0,0,0,0,0,0,110,101,111,112,114,105,109,111,0,0,0,0,0,0,0,0,109,100,95,115,111,108,100,102,111,114,116,0,0,0,0,0,83,116,97,114,116,105,110,103,32,109,111,118,105,101,32,114,101,99,111,114,100,32,116,111,32,34,37,115,34,46,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,73,109,112,108,101,109,101,110,116,97,116,105,111,110,32,100,111,101,115,32,110,111,116,32,115,117,112,112,111,114,116,32,115,97,118,101,32,115,116,97,116,101,115,46,32,67,97,110,110,111,116,32,117,115,101,32,114,101,119,105,110,100,46,10,0,0,0,78,105,110,106,97,32,83,112,105,114,105,116,0,0,0,0,67,114,105,109,47,83,116,101,112,104,101,110,0,0,0,0,77,105,99,114,111,112,114,111,115,101,0,0,0,0,0,0,77,84,77,32,71,97,109,101,115,0,0,0,0,0,0,0,116,103,95,110,115,112,105,114,105,116,0,0,0,0,0,0,78,101,111,71,101,111,32,50,45,80,108,97,121,101,114,32,84,101,116,114,105,115,0,0,69,110,101,109,121,32,83,116,114,101,110,103,116,104,0,0,84,104,101,32,67,104,97,111,115,32,69,110,103,105,110,101,32,40,69,117,114,111,41,0,0,0,0,0,0,0,0,0,90,105,103,122,97,103,65,89,76,97,116,99,104,0,0,0,84,117,114,98,111,32,77,111,100,101,0,0,0,0,0,0,49,50,54,0,0,0,0,0,99,111,110,116,114,111,108,95,115,101,108,101,99,116,0,0,78,105,103,104,116,32,67,114,101,97,116,117,114,101,115,0,0,0,0,0,0,0,0,0,110,101,111,116,101,116,0,0,109,100,95,99,104,97,111,115,101,110,103,0,0,0,0,0,71,97,108,80,105,116,99,104,0,0,0,0,0,0,0,0,116,103,95,110,105,103,104,116,99,114,0,0,0,0,0,0,71,97,108,97,103,97,32,68,101,109,111,32,40,115,101,116,32,50,41,0,0,0,0,0,71,97,109,101,116,101,99,63,0,0,0,0,0,0,0,0,80,50,32,74,117,109,112,0,112,50,32,108,101,102,116,0,53,48,48,48,48,32,53,48,48,48,48,0,0,0,0,0,71,114,101,97,116,32,66,114,105,116,97,105,110,0,0,0,53,48,48,48,48,32,38,32,49,53,48,48,48,48,0,0,69,117,114,111,112,101,32,40,71,101,114,109,97,110,32,84,117,110,105,110,103,32,108,105,99,101,110,115,101,0,0,0,77,101,103,97,32,66,108,97,115,116,32,40,85,83,41,0,0,0,0,0,0,0,0,0,77,67,77,76,88,88,88,73,86,0,0,0,0,0,0,0,83,112,97,99,101,32,73,110,118,97,100,101,114,115,32,68,88,32,40,74,97,112,97,110,44,32,118,50,46,49,41,0,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,115,99,114,101,101,110,115,104,111,116,95,100,105,114,101,99,116,111,114,121,32,105,115,32,110,111,116,32,97,110,32,101,120,105,115,116,105,110,103,32,100,105,114,101,99,116,111,114,121,44,32,105,103,110,111,114,105,110,103,32,46,46,46,10,0,0,0,0,53,48,107,32,49,53,48,107,32,54,48,48,107,32,51,48,48,48,107,0,0,0,0,0,78,101,119,32,65,100,118,101,110,116,117,114,101,32,73,115,108,97,110,100,0,0,0,0,110,101,111,103,97,108,97,103,97,0,0,0,0,0,0,0,67,104,97,111,32,74,105,32,68,97,32,70,117,32,87,101,110,103,32,40,67,104,105,41,0,0,0,0,0,0,0,0,82,0,0,0,101,0,0,0,100,0,0,0,32,0,0,0,69,0,0,0,97,0,0,0,114,0,0,0,116,0,0,0,104,0,0,0,0,0,0,0,87,0,0,0,97,0,0,0,114,0,0,0,45,0,0,0,90,0,0,0,97,0,0,0,114,0,0,0,100,0,0,0,32,0,0,0,40,0,0,0,69,0,0,0,117,0,0,0,114,0,0,0,111,0,0,0,32,0,0,0,57,0,0,0,54,0,0,0,49,0,0,0,49,0,0,0,50,0,0,0,49,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,70,99,114,97,115,104,83,111,117,110,100,80,111,115,0,0,68,117,110,107,32,83,104,111,116,32,40,70,68,49,48,56,57,32,51,49,55,45,48,48,50,50,41,0,0,0,0,0,78,105,110,106,97,32,80,114,105,110,99,101,115,115,32,40,51,49,53,45,53,48,53,49,44,32,54,52,107,32,86,101,114,46,32,98,111,111,116,108,101,103,63,41,0,0,0,0,78,0,0,0,111,0,0,0,118,0,0,0,0,0,0,0,51,48,48,48,48,32,53,48,48,48,48,0,0,0,0,0,120,54,0,0,0,0,0,0,76,101,102,116,32,67,111,117,110,116,0,0,0,0,0,0,68,105,112,32,68,0,0,0,54,48,37,0,0,0,0,0,106,111,101,109,97,99,114,0,116,103,95,97,100,118,105,115,108,110,100,0,0,0,0,0,67,114,105,115,116,105,97,110,111,32,66,101,105,47,119,119,119,46,105,111,99,101,114,111,109,46,99,111,109,0,0,0,67,111,110,116,105,110,117,101,32,80,108,117,115,32,49,117,112,0,0,0,0,0,0,0,109,100,95,99,106,102,117,119,101,110,103,0,0,0,0,0,49,32,67,114,101,100,105,116,32,54,32,72,101,97,108,116,104,32,80,97,99,107,115,0,68,105,115,97,98,108,101,32,65,108,108,32,67,111,105,110,115,0,0,0,0,0,0,0,71,117,110,100,104,97,114,97,0,0,0,0,0,0,0,0,73,110,118,101,114,116,32,83,99,114,101,101,110,0,0,0,80,105,99,116,117,114,101,32,86,105,101,119,101,114,0,0,51,32,84,105,109,101,115,0,109,115,99,104,97,109,112,0,116,103,95,110,101,117,116,111,112,105,50,0,0,0,0,0,71,97,108,97,103,97,32,68,101,109,111,32,40,115,101,116,32,49,41,0,0,0,0,0,67,104,97,109,112,105,111,110,115,104,105,112,32,80,114,111,45,65,109,32,40,85,83,65,41,0,0,0,0,0,0,0,67,112,115,82,101,103,0,0,50,32,67,97,114,115,44,32,69,97,115,121,0,0,0,0,75,110,105,103,104,116,115,32,111,102,32,86,97,108,111,117,114,32,83,117,112,101,114,104,101,114,111,101,115,32,47,32,83,97,110,103,111,107,117,32,83,101,110,107,105,32,83,117,112,101,114,104,101,114,111,101,115,32,40,86,49,48,52,44,32,67,104,105,110,97,41,0,0,0,0,0,0,0,0,0,112,99,101,95,98,111,109,98,109,110,117,98,0,0,0,0,100,105,110,111,116,112,105,99,0,0,0,0,0,0,0,0,116,103,95,110,101,117,116,111,112,105,97,0,0,0,0,0,50,48,49,51,0,0,0,0,76,0,0,0,101,0,0,0,103,0,0,0,101,0,0,0,110,0,0,0,100,0,0,0,32,0,0,0,111,0,0,0,102,0,0,0,32,0,0,0,83,0,0,0,117,0,0,0,99,0,0,0,99,0,0,0,101,0,0,0,115,0,0,0,115,0,0,0,32,0,0,0,74,0,0,0,111,0,0,0,101,0,0,0,32,0,0,0,47,0,0,0,32,0,0,0,65,0,0,0,115,0,0,0,104,0,0,0,105,0,0,0,116,0,0,0,97,0,0,0,110,0,0,0,111,0,0,0,32,0,0,0,74,0,0,0,111,0,0,0,101,0,0,0,32,0,0,0,68,0,0,0,101,0,0,0,110,0,0,0,115,0,0,0,101,0,0,0,116,0,0,0,115,0,0,0,117,0,0,0,0,0,0,0,66,48,0,0,87,48,0,0,95,48,0,0,110,48,0,0,184,48,0,0,231,48,0,0,252,48,0,0,29,79,0,0,172,138,0,0,0,0,0,0,0,0,0,0,0,0,0,0,109,100,95,99,112,114,111,97,109,0,0,0,0,0,0,0,109,100,95,104,111,109,101,97,0,0,0,0,0,0,0,0,83,99,114,101,101,110,115,104,111,116,32,68,105,114,101,99,116,111,114,121,0,0,0,0,109,97,115,107,0,0,0,0,100,100,115,111,109,114,49,0,115,104,97,100,101,114,95,110,101,120,116,0,0,0,0,0,116,103,95,109,111,116,111,114,111,97,100,0,0,0,0,0,110,101,111,103,97,108,97,103,0,0,0,0,0,0,0,0,67,104,97,109,112,105,111,110,115,104,105,112,32,80,111,111,108,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,76,105,103,104,116,110,105,110,103,32,70,105,103,104,116,101,114,115,32,40,65,115,105,97,41,0,0,0,0,0,0,0,109,97,106,116,105,116,108,50,106,0,0,0,0,0,0,0,77,105,108,105,116,97,114,121,32,77,97,100,110,101,115,115,0,0,0,0,0,0,0,0,78,71,70,32,68,101,118,46,32,73,110,99,46,0,0,0,109,100,95,99,104,97,109,112,111,111,108,0,0,0,0,0,37,115,46,98,115,118,0,0,53,48,48,48,48,32,56,48,48,48,48,0,0,0,0,0,82,101,115,101,116,32,103,97,109,101,0,0,0,0,0,0,116,103,95,109,105,108,116,114,121,109,100,0,0,0,0,0,84,105,109,101,39,115,32,85,112,32,68,101,109,111,0,0,66,97,100,32,67,111,108,111,117,114,115,0,0,0,0,0,116,103,95,109,97,103,99,104,97,115,101,0,0,0,0,0,116,105,109,101,115,117,112,0,66,111,111,103,105,101,32,87,111,111,103,105,101,32,66,111,119,108,105,110,103,32,40,74,112,110,41,0,0,0,0,0,80,50,32,80,97,117,115,101,0,0,0,0,0,0,0,0,84,104,101,32,76,101,103,101,110,100,97,114,121,32,65,120,101,0,0,0,0,0,0,0,67,104,97,114,108,101,115,32,68,79,84,89,47,82,97,115,116,101,114,83,111,102,116,32,40,85,83,65,41,0,0,0,109,100,95,98,111,111,103,105,101,0,0,0,0,0,0,0,116,103,95,108,101,103,97,120,101,0,0,0,0,0,0,0,87,87,50,32,68,101,109,111,32,45,32,65,114,99,97,100,101,32,68,101,118,101,108,111,112,109,101,110,116,32,80,114,111,106,101,99,116,0,0,0,67,104,97,109,112,105,111,110,115,104,105,112,32,66,111,119,108,105,110,103,32,40,85,83,65,41,0,0,0,0,0,0,110,99,111,109,109,97,110,100,0,0,0,0,0,0,0,0,80,50,32,84,117,114,110,0,76,101,118,101,108,32,80,114,111,103,114,101,115,115,105,111,110,0,0,0,0,0,0,0,70,114,97,110,99,101,0,0,112,51,32,117,112,0,0,0,51,48,48,48,48,32,38,32,49,48,48,48,48,48,0,0,109,101,103,97,98,108,115,116,117,0,0,0,0,0,0,0,109,111,117,115,101,32,98,117,116,116,111,110,32,49,0,0,115,112,97,99,101,100,120,106,0,0,0,0,0,0,0,0,50,48,107,32,52,48,107,32,49,50,48,107,32,52,56,48,107,32,50,52,48,48,107,0,115,99,114,101,101,110,115,104,111,116,95,100,105,114,101,99,116,111,114,121,0,0,0,0,84,104,101,32,76,101,103,101,110,100,97,114,121,32,65,120,101,32,73,73,0,0,0,0,110,101,111,119,119,50,0,0,109,100,95,99,104,97,109,112,98,119,108,0,0,0,0,0,82,101,100,32,69,97,114,116,104,32,47,32,87,97,114,45,90,97,114,100,32,40,69,117,114,111,32,57,54,49,49,50,49,41,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,114,101,97,100,32,115,116,97,116,101,32,102,114,111,109,32,109,111,118,105,101,46,10,0,0,0,110,112,114,105,110,99,101,115,0,0,0,0,0,0,0,0,79,0,0,0,99,0,0,0,116,0,0,0,0,0,0,0,65,32,49,67,47,52,80,32,32,66,32,52,67,47,49,80,32,32,67,32,49,67,47,52,80,0,0,0,0,0,0,0,120,53,0,0,0,0,0,0,67,111,105,110,97,103,101,32,84,121,112,101,0,0,0,0,54,53,37,0,0,0,0,0,70,105,114,101,32,72,97,119,107,0,0,0,0,0,0,0,116,103,95,108,101,103,97,120,101,50,0,0,0,0,0,0,79,120,121,103,101,110,101,0,67,111,105,110,32,83,87,32,50,0,0,0,0,0,0,0,67,104,97,109,112,105,111,110,115,32,87,111,114,108,100,32,67,108,97,115,115,32,83,111,99,99,101,114,32,40,87,111,114,108,100,41,0,0,0,0,50,32,67,114,101,100,105,116,115,32,49,32,72,101,97,108,116,104,32,80,97,99,107,0,65,32,49,67,47,51,80,32,32,66,32,51,67,47,49,80,32,32,67,32,49,67,47,51,80,0,0,0,0,0,0,0,103,117,110,100,104,97,114,97,0,0,0,0,0,0,0,0,50,32,65,116,116,97,99,107,101,114,115,32,65,116,32,87,97,118,101,0,0,0,0,0,77,115,46,32,80,97,99,45,77,97,110,32,40,39,77,97,100,101,32,105,110,32,71,114,101,101,99,101,39,32,98,111,111,116,108,101,103,41,0,0,68,105,112,32,83,119,40,50,41,0,0,0,0,0,0,0,42,49,48,48,49,49,120,120,120,120,120,0,0,0,0,0,116,103,95,108,111,104,116,0,78,101,111,71,101,111,32,51,68,33,32,68,101,109,111,0,0,0,0,0,0,0,0,0,109,100,95,99,104,97,109,112,119,99,115,0,0,0,0,0,83,116,97,114,116,105,110,103,32,76,101,118,101,108,0,0,103,97,108,97,120,105,97,110,109,0,0,0,0,0,0,0,65,32,49,67,47,50,80,32,32,66,32,49,67,47,49,80,32,32,67,32,49,67,47,50,80,0,0,0,0,0,0,0,49,32,67,97,114,44,32,32,72,97,114,100,0,0,0,0,107,111,118,115,104,0,0,0,66,111,109,98,101,114,109,97,110,0,0,0,0,0,0,0,67,97,100,105,108,108,97,99,115,32,97,110,100,32,68,105,110,111,115,97,117,114,115,32,84,117,114,98,111,32,40,98,111,111,116,108,101,103,32,115,101,116,32,49,44,32,57,51,48,50,50,51,32,65,115,105,97,32,84,87,41,0,0,0,116,103,95,107,108,97,120,0,110,101,111,51,100,100,109,111,0,0,0,0,0,0,0,0,76,101,103,101,110,100,32,111,102,32,83,117,99,99,101,115,115,32,74,111,101,32,47,32,65,115,104,105,116,97,110,111,32,74,111,101,32,68,101,110,115,101,116,115,117,0,0,0,107,50,107,51,112,99,98,100,0,0,0,0,0,0,0,0,67,104,97,107,97,110,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,65,32,49,67,47,49,80,32,32,66,32,50,67,47,49,80,32,32,67,32,49,67,47,49,80,0,0,0,0,0,0,0,67,111,100,101,109,97,115,116,101,114,115,0,0,0,0,0,83,121,115,116,101,109,32,68,105,114,101,99,116,111,114,121,0,0,0,0,0,0,0,0,105,110,112,117,116,95,115,108,111,116,0,0,0,0,0,0,68,117,110,103,101,111,110,115,32,38,32,68,114,97,103,111,110,115,32,45,32,115,104,97,100,111,119,32,111,118,101,114,32,109,121,115,116,97,114,97,32,40,57,54,48,54,49,57,32,69,117,114,111,41,0,0,116,103,95,107,105,110,103,99,97,115,110,0,0,0,0,0,66,97,114,102,47,66,97,114,102,72,97,112,112,121,0,0,97,99,116,102,97,110,99,114,0,0,0,0,0,0,0,0,109,100,95,99,104,97,107,97,110,0,0,0,0,0,0,0,108,103,116,110,102,103,104,116,97,0,0,0,0,0,0,0,120,49,46,54,0,0,0,0,77,97,106,111,114,32,84,105,116,108,101,32,50,32,40,87,111,114,108,100,41,0,0,0,65,32,49,67,47,53,80,32,32,66,32,49,67,47,49,80,32,32,67,32,49,67,47,53,80,0,0,0,0,0,0,0,99,110,105,110,106,97,117,0,75,101,105,116,104,32,67,111,117,114,97,103,101,32,105,110,32,65,108,112,104,97,32,90,111,110,101,115,0,0,0,0,78,101,111,32,67,97,115,116,108,101,86,97,110,105,97,32,68,101,109,111,0,0,0,0,67,101,110,116,117,114,105,111,110,32,45,32,68,101,102,101,110,100,101,114,32,111,102,32,82,111,109,101,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,0,0,80,49,32,83,104,111,116,51,0,0,0,0,0,0,0,0,37,115,37,117,46,98,115,118,0,0,0,0,0,0,0,0,65,32,49,67,47,52,80,32,32,66,32,51,67,47,49,80,32,32,67,32,49,67,47,52,80,0,0,0,0,0,0,0,99,104,97,105,110,114,101,99,0,0,0,0,0,0,0,0,116,103,95,107,101,105,116,104,99,111,114,0,0,0,0,0,110,101,111,99,115,116,108,118,0,0,0,0,0,0,0,0,109,100,95,99,101,110,116,117,114,0,0,0,0,0,0,0,65,32,49,67,47,51,80,32,32,66,32,50,67,47,49,80,32,32,67,32,49,67,47,51,80,0,0,0,0,0,0,0,67,97,116,97,99,111,109,98,0,0,0,0,0,0,0,0,74,97,99,107,105,101,32,67,104,97,110,39,115,32,65,99,116,105,111,110,32,75,117,110,103,32,70,117,0,0,0,0,97,99,116,102,97,110,99,114,106,0,0,0,0,0,0,0,67,101,76,0,0,0,0,0,65,107,117,109,97,106,111,117,32,68,114,97,99,117,108,97,32,45,32,86,97,109,112,105,114,101,32,75,105,108,108,101,114,32,40,74,112,110,41,0,0,0,0,0,0,0,0,0,110,84,105,109,101,114,67,111,117,110,116,0,0,0,0,0,65,32,49,67,47,50,80,32,32,66,32,52,67,47,49,80,32,32,67,32,49,67,47,50,80,0,0,0,0,0,0,0,80,49,32,80,97,117,115,101,0,0,0,0,0,0,0,0,116,103,95,106,99,104,97,110,0,0,0,0,0,0,0,0,114,101,100,97,114,109,111,114,46,110,101,116,0,0,0,0,109,100,95,97,107,117,109,97,106,111,0,0,0,0,0,0,115,105,100,101,112,99,107,116,98,0,0,0,0,0,0,0,67,104,97,110,45,62,115,116,97,114,116,0,0,0,0,0,65,99,99,111,108,97,100,101,0,0,0,0,0,0,0,0,78,71,70,32,84,114,97,110,115,112,97,114,101,110,99,121,32,68,101,109,111,0,0,0,67,97,115,116,108,101,118,97,110,105,97,32,45,32,66,108,111,111,100,108,105,110,101,115,32,40,85,83,65,41,0,0,80,50,32,65,116,116,97,99,107,0,0,0,0,0,0,0,112,50,32,100,111,119,110,0,70,105,110,108,97,110,100,0,70,114,101,101,32,112,108,97,121,0,0,0,0,0,0,0,99,98,117,115,116,101,114,106,0,0,0,0,0,0,0,0,77,101,103,97,32,66,108,97,115,116,32,40,74,97,112,97,110,41,0,0,0,0,0,0,73,110,115,101,114,116,32,67,111,105,110,0,0,0,0,0,83,112,97,99,101,32,73,110,118,97,100,101,114,115,32,68,88,32,40,85,83,44,32,118,50,46,49,41,0,0,0,0,99,111,114,101,95,111,112,116,105,111,110,115,95,112,97,116,104,0,0,0,0,0,0,0,74,97,99,107,32,78,105,99,107,108,97,117,115,39,32,84,117,114,98,111,32,71,111,108,102,0,0,0,0,0,0,0,110,103,102,116,100,101,109,111,0,0,0,0,0,0,0,0,109,100,95,99,118,97,110,105,97,117,0,0,0,0,0,0,100,117,110,107,115,104,111,116,0,0,0,0,0,0,0,0,78,105,110,106,97,32,40,51,49,53,45,53,49,48,50,41,0,0,0,0,0,0,0,0,83,0,0,0,101,0,0,0,112,0,0,0,0,0,0,0,120,52,0,0,0,0,0,0,101,115,100,49,54,95,122,56,48,95,98,97,110,107,0,0,80,108,97,121,32,83,112,101,101,100,0,0,0,0,0,0,55,48,37,0,0,0,0,0,118,97,112,111,114,116,114,97,117,0,0,0,0,0,0,0,116,103,95,110,105,99,107,108,97,117,115,0,0,0,0,0,78,101,111,32,71,101,111,0,67,111,105,110,32,83,87,32,49,0,0,0,0,0,0,0,67,97,115,116,108,101,118,97,110,105,97,32,45,32,84,104,101,32,78,101,119,32,71,101,110,101,114,97,116,105,111,110,32,40,69,117,114,111,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,51,32,67,114,101,100,105,116,115,32,49,32,72,101,97,108,116,104,32,80,97,99,107,0,115,101,108,101,99,116,0,0,65,109,101,114,105,99,97,110,32,83,97,109,109,121,0,0,84,97,98,108,101,32,84,121,112,101,0,0,0,0,0,0,70,97,107,101,84,114,97,99])
.concat([107,66,97,108,108,89,0,0,109,115,112,97,99,109,97,110,98,103,0,0,0,0,0,0,42,49,48,48,48,48,120,120,120,120,120,0,0,0,0,0,74,46,74,46,32,38,32,74,101,102,102,0,0,0,0,0,83,101,98,97,115,116,105,97,110,32,77,105,104,97,105,0,109,100,95,99,118,97,110,105,97,112,0,0,0,0,0,0,82,111,116,97,114,121,0,0,99,104,105,112,45,62,108,102,111,95,97,109,95,105,110,99,0,0,0,0,0,0,0,0,65,32,49,67,47,57,57,80,32,32,66,32,49,67,47,57,57,80,0,0,0,0,0,0,49,32,67,97,114,44,32,32,77,101,100,105,117,109,0,0,75,0,0,0,110,0,0,0,105,0,0,0,103,0,0,0,104,0,0,0,116,0,0,0,115,0,0,0,32,0,0,0,111,0,0,0,102,0,0,0,32,0,0,0,86,0,0,0,97,0,0,0,108,0,0,0,111,0,0,0,117,0,0,0,114,0,0,0,32,0,0,0,80,0,0,0,108,0,0,0,117,0,0,0,115,0,0,0,0,0,0,0,9,78,0,0,253,86,0,0,38,98,0,0,0,125,0,0,32,0,0,0,80,0,0,0,108,0,0,0,117,0,0,0,115,0,0,0,0,0,0,0,9,78,0,0,253,86,0,0,24,98,0,0,170,126,0,0,32,0,0,0,80,0,0,0,108,0,0,0,117,0,0,0,115,0,0,0,32,0,0,0,40,0,0,0,86,0,0,0,49,0,0,0,49,0,0,0,57,0,0,0,32,0,0,0,97,0,0,0,108,0,0,0,116,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,99,101,95,98,111,109,98,109,97,110,0,0,0,0,0,100,105,110,111,116,0,0,0,116,103,95,106,106,110,106,101,102,102,0,0,0,0,0,0,115,101,98,97,115,116,105,97,110,109,105,104,97,105,46,99,111,109,0,0,0,0,0,0,108,101,103,101,110,100,111,115,0,0,0,0,0,0,0,0,67,97,115,116,108,101,118,97,110,105,97,32,45,32,84,104,101,32,78,101,119,32,71,101,110,101,114,97,116,105,111,110,32,40,69,117,114,111,41,0,0,0,0,0,0,0,0,0,116,104,110,100,122,111,110,101,52,0,0,0,0,0,0,0,65,32,49,67,47,54,80,32,32,66,32,49,67,47,49,80,0,0,0,0,0,0,0,0,67,97,112,116,39,110,32,72,97,118,111,99,32,40,69,117,114,111,41,0,0,0,0,0,79,118,101,114,108,97,121,32,68,105,114,101,99,116,111,114,121,0,0,0,0,0,0,0,119,114,97,109,0,0,0,0,102,114,97,109,101,95,97,100,118,97,110,99,101,0,0,0,73,109,112,111,115,115,97,109,111,108,101,0,0,0,0,0,78,101,111,32,84,104,117,110,100,101,114,0,0,0,0,0,109,100,95,99,118,97,110,105,97,0,0,0,0,0,0,0,76,105,103,104,116,110,105,110,103,32,70,105,103,104,116,101,114,115,32,40,85,83,41,0,0,0,0,0,0,0,0,0,109,97,106,116,105,116,108,50,0,0,0,0,0,0,0,0,65,32,49,67,47,51,80,32,32,66,32,50,67,47,49,80,0,0,0,0,0,0,0,0,80,111,99,107,101,116,32,71,97,108,32,68,101,108,117,120,101,32,40,74,97,112,97,110,32,118,51,46,48,48,41,0,0,0,0,0,0,0,0,0,118,111,105,99,101,45,62,118,111,108,117,109,101,0,0,0,116,103,95,105,109,112,111,115,115,97,109,0,0,0,0,0,50,48,49,50,0,0,0,0,67,97,115,116,108,101,32,111,102,32,73,108,108,117,115,105,111,110,32,45,32,70,117,115,104,105,103,105,32,110,111,32,79,115,104,105,114,111,32,68,97,105,98,111,117,107,101,110,32,40,74,112,110,41,0,0,82,101,116,114,111,65,114,99,104,58,32,83,116,111,112,112,105,110,103,32,109,111,118,105,101,32,114,101,99,111,114,100,46,10,0,0,0,0,0,0,70,114,97,109,101,97,100,118,97,110,99,101,0,0,0,0,116,103,95,104,105,116,105,99,101,0,0,0,0,0,0,0,107,97,114,110,111,118,106,0,110,101,111,116,104,110,100,114,0,0,0,0,0,0,0,0,109,100,95,99,97,115,116,108,105,108,108,106,0,0,0,0,80,50,32,82,103,104,116,32,83,116,105,99,107,32,82,105,103,104,116,0,0,0,0,0,115,105,100,101,112,99,107,116,0,0,0,0,0,0,0,0,71,117,110,98,111,97,116,0,0,0,0,0,0,0,0,0,84,101,101,110,97,103,101,32,77,117,116,97,110,116,32,78,105,110,106,97,32,84,117,114,116,108,101,115,32,40,73,110,116,114,111,32,100,101,109,111,44,32,97,108,116,41,0,0,46,114,101,116,114,111,97,114,99,104,45,99,111,114,101,45,111,112,116,105,111,110,115,46,99,102,103,0,0,0,0,0,67,97,115,116,108,101,32,111,102,32,73,108,108,117,115,105,111,110,32,83,116,97,114,114,105,110,103,32,77,105,99,107,101,121,32,77,111,117,115,101,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,116,103,95,103,117,110,98,111,97,116,0,0,0,0,0,0,116,109,110,116,105,97,0,0,109,100,95,99,97,115,116,108,105,108,108,0,0,0,0,0,80,50,32,82,103,104,116,32,83,116,105,99,107,32,76,101,102,116,0,0,0,0,0,0,89,77,90,50,56,48,66,67,104,97,110,110,101,108,73,110,102,111,91,106,93,0,0,0,109,101,105,107,121,117,104,0,71,104,111,115,116,32,77,97,110,111,114,0,0,0,0,0,84,101,101,110,97,103,101,32,77,117,116,97,110,116,32,78,105,110,106,97,32,84,117,114,116,108,101,115,32,40,73,110,116,114,111,32,100,101,109,111,41,0,0,0,0,0,0,0,67,97,112,116,97,105,110,32,80,108,97,110,101,116,32,97,110,100,32,116,104,101,32,80,108,97,110,101,116,101,101,114,115,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,80,50,32,82,105,103,104,116,0,0,0,0,0,0,0,0,68,101,110,109,97,114,107,0,112,51,32,115,116,97,114,116,0,0,0,0,0,0,0,0,110,83,111,117,110,100,67,111,109,109,97,110,100,0,0,0,109,101,103,97,98,108,115,116,106,0,0,0,0,0,0,0,67,111,105,110,115,47,67,114,101,100,105,116,115,0,0,0,109,111,117,115,101,32,121,45,97,120,105,115,0,0,0,0,115,112,97,99,101,100,120,0,108,105,98,114,101,116,114,111,95,105,110,102,111,95,112,97,116,104,0,0,0,0,0,0,116,103,95,103,104,111,115,116,109,97,110,0,0,0,0,0,116,109,110,116,105,0,0,0,109,100,95,99,97,112,116,112,108,97,110,117,0,0,0,0,114,101,100,101,97,114,116,104,0,0,0,0,0,0,0,0,110,105,110,106,97,0,0,0,65,0,0,0,117,0,0,0,103,0,0,0,0,0,0,0,80,50,32,82,103,104,116,32,83,116,105,99,107,32,68,111,119,110,0,0,0,0,0,0,67,111,105,110,32,35,50,32,109,117,108,105,116,112,108,105,101,114,0,0,0,0,0,0,103,97,109,101,95,115,101,108,101,99,116,0,0,0,0,0,80,108,97,121,32,76,101,118,101,108,0,0,0,0,0,0,55,53,37,0,0,0,0,0,102,105,114,101,104,97,119,107,0,0,0,0,0,0,0,0,49,32,67,111,105,110,32,54,32,67,114,101,100,105,116,115,44,32,49,32,67,114,101,100,105,116,32,83,116,97,114,116,32,38,32,67,111,110,116,105,110,117,101,0,0,0,0,0,100,101,99,111,49,54,95,98,117,102,102,101,114,95,114,97,109,95,115,101,108,101,99,116,101,100,0,0,0,0,0,0,49,50,48,32,83,101,99,0,71,97,108,97,103,97,32,39,57,48,0,0,0,0,0,0,83,112,105,100,101,114,109,97,110,32,40,73,110,116,114,111,32,100,101,109,111,41,0,0,67,97,112,116,97,105,110,32,80,108,97,110,101,116,32,97,110,100,32,116,104,101,32,80,108,97,110,101,116,101,101,114,115,32,40,69,117,114,111,41,0,0,0,0,0,0,0,0,52,32,67,114,101,100,105,116,115,32,49,32,72,101,97,108,116,104,32,80,97,99,107,0,99,111,105,110,0,0,0,0,90,111,109,98,105,101,32,82,97,105,100,32,40,85,83,41,0,0,0,0,0,0,0,0,85,112,45,82,105,103,104,116,32,84,121,112,101,0,0,0,77,115,46,32,80,97,99,45,77,97,110,32,80,108,117,115,0,0,0,0,0,0,0,0,68,105,112,32,83,119,40,49,41,0,0,0,0,0,0,0,116,103,95,103,97,108,97,103,97,57,48,0,0,0,0,0,115,112,105,100,101,114,109,105,0,0,0,0,0,0,0,0,109,100,95,99,97,112,116,112,108,97,110,0,0,0,0,0,52,48,48,48,48,32,56,48,48,48,48,0,0,0,0,0,80,50,32,82,103,104,116,32,83,116,105,99,107,32,85,112,0,0,0,0,0,0,0,0,73,79,67,104,105,112,67,117,115,116,111,109,91,105,93,0,75,110,105,103,104,116,115,32,111,102,32,86,97,108,111,117,114,32,80,108,117,115,32,45,32,83,97,110,103,111,107,117,32,83,101,110,107,105,32,80,108,117,115,32,40,86,49,49,57,32,97,108,116,41,0,0,66,111,109,98,101,114,109,97,110,32,39,57,52,0,0,0,67,97,100,105,108,108,97,99,115,32,97,110,100,32,68,105,110,111,115,97,117,114,115,32,40,98,111,111,116,108,101,103,32,115,101,116,32,51,44,32,57,51,48,50,50,51,32,65,115,105,97,32,84,87,41,0,0,0,0,0,0,0,0,0,116,103,95,102,105,110,97,108,108,97,112,0,0,0,0,0,82,111,98,111,99,111,112,32,40,73,110,116,114,111,32,100,101,109,111,41,0,0,0,0,83,78,75,32,47,32,80,97,108,108,97,115,0,0,0,0,67,97,112,116,97,105,110,32,76,97,110,103,32,40,74,112,110,41,0,0,0,0,0,0,114,97,103,116,105,109,101,0,67,104,105,112,45,62,82,78,71,0,0,0,0,0,0,0,109,100,95,104,97,118,111,99,0,0,0,0,0,0,0,0,83,97,118,101,102,105,108,101,32,68,105,114,101,99,116,111,114,121,0,0,0,0,0,0,115,101,109,97,110,116,105,99,0,0,0,0,0,0,0,0,100,100,115,111,109,0,0,0,116,112,103,111,108,102,0,0,112,97,117,115,101,95,116,111,103,103,108,101,0,0,0,0,116,103,95,102,97,110,116,122,111,110,101,0,0,0,0,0,114,111,98,111,99,111,112,105,0,0,0,0,0,0,0,0,109,100,95,99,97,112,116,108,97,110,103,0,0,0,0,0,108,103,116,110,102,103,104,116,117,0,0,0,0,0,0,0,120,49,46,50,0,0,0,0,80,101,114,102,101,99,116,32,83,111,108,100,105,101,114,115,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,118,48,46,50,46,57,55,46,51,48,0,0,0,0,0,0,82,46,84,82,73,83,65,0,37,48,56,120,58,32,71,52,45,121,32,85,110,100,101,102,105,110,101,100,32,84,104,117,109,98,32,105,110,115,116,114,117,99,116,105,111,110,58,32,37,48,52,120,10,0,0,0,70,97,108,99,111,110,0,0,71,104,111,115,116,32,66,117,115,116,101,114,115,32,40,73,110,116,114,111,32,100,101,109,111,41,0,0,0,0,0,0,67,97,112,116,97,105,110,32,65,109,101,114,105,99,97,32,97,110,100,32,116,104,101,32,65,118,101,110,103,101,114,115,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,0,99,104,105,112,45,62,101,110,100,0,0,0,0,0,0,0,83,116,111,112,112,105,110,103,32,109,111,118,105,101,32,114,101,99,111,114,100,46,0,0,114,111,104,103,97,50,0,0,82,45,62,110,109,105,95,115,116,97,116,101,0,0,0,0,49,57,56,49,0,0,0,0,91,84,111,97,112,108,97,110,93,32,87,105,108,108,105,97,109,115,32,69,108,101,99,116,114,111,110,105,99,115,32,71,97,109,101,115,44,32,73,110,99,0,0,0,0,0,0,0,98,97,116,114,105,100,101,114,99,0,0,0,0,0,0,0,116,103,95,102,97,108,99,111,110,0,0,0,0,0,0,0,103,104,111,115,116,98,105,0,102,105,120,101,105,103,104,116,107,0,0,0,0,0,0,0,109,100,95,99,97,112,116,97,118,101,110,117,112,0,0,0,71,114,105,110,100,32,83,116,111,114,109,101,114,0,0,0,116,105,103,101,114,104,98,49,0,0,0,0,0,0,0,0,119,104,111,111,112,101,101,0,112,105,112,105,98,105,98,115,112,0,0,0,0,0,0,0,99,97,116,97,99,111,109,98,0,0,0,0,0,0,0,0,68,117,97,108,32,84,111,97,112,108,97,110,0,0,0,0,116,103,95,100,117,110,103,101,120,112,108,0,0,0,0,0,68,117,99,107,32,84,97,108,101,115,32,40,73,110,116,114,111,32,100,101,109,111,41,0,0,0,0,0,0,0,0,0,69,110,101,109,121,32,77,111,118,101,109,101,110,116,0,0,67,97,112,116,97,105,110,32,65,109,101,114,105,99,97,32,97,110,100,32,116,104,101,32,65,118,101,110,103,101,114,115,32,40,85,83,65,41,0,0,83,101,105,98,117,83,111,117,110,100,66,97,110,107,0,0,100,111,103,121,117,117,110,97,0,0,0,0,0,0,0,0,68,105,101,116,32,71,111,32,71,111,32,40,69,117,114,111,32,118,49,46,49,32,49,57,57,50,46,48,56,46,48,52,41,0,0,0,0,0,0,0,98,103,97,114,101,103,103,97,116,50,0,0,0,0,0,0,70,105,114,101,32,83,104,97,114,107,32,40,75,111,114,101,97,44,32,115,101,116,32,49,44,32,101,97,115,105,101,114,41,0,0,0,0,0,0,0,71,104,111,120,32,40,106,111,121,115,116,105,99,107,41,0,0,0,0,0,0,0,0,0,68,114,111,112,46,79,102,102,0,0,0,0,0,0,0,0,100,117,99,107,105,0,0,0,109,100,95,99,97,112,116,97,118,101,110,117,0,0,0,0,68,105,115,99,111,117,110,116,32,111,102,102,0,0,0,0,86,105,109,97,110,97,32,40,87,111,114,108,100,44,32,115,101,116,32,50,41,0,0,0,111,117,116,122,111,110,101,98,0,0,0,0,0,0,0,0,98,98,97,107,114,97,105,100,106,97,0,0,0,0,0,0,101,101,112,114,111,109,95,99,108,111,99,107,95,99,111,117,110,116,0,0,0,0,0,0,104,101,108,108,102,105,114,101,50,0,0,0,0,0,0,0,99,98,117,115,116,101,114,0,68,101,109,111,110,39,115,32,87,111,114,108,100,32,47,32,72,111,114,114,111,114,32,83,116,111,114,121,32,40,84,97,105,116,111,32,108,105,99,101,110,115,101,44,32,115,101,116,32,50,41,0,0,0,0,0,116,103,95,100,114,111,112,111,102,102,0,0,0,0,0,0,68,97,114,107,87,105,110,103,32,68,117,99,107,32,40,73,110,116,114,111,32,100,101,109,111,44,32,97,108,116,41,0,0,0,0,0,0,0,0,0,67,97,112,116,97,105,110,32,65,109,101,114,105,99,97,32,97,110,100,32,116,104,101,32,65,118,101,110,103,101,114,115,32,40,69,117,114,111,41,0,0,0,0,0,0,0,0,0,106,97,110,115,104,105,110,0,75,105,110,103,100,111,109,32,71,114,97,110,100,112,114,105,120,32,40,87,111,114,108,100,41,0,0,0,0,0,0,0,80,50,32,76,101,102,116,0,83,111,114,99,101,114,32,83,116,114,105,107,101,114,32,40,87,111,114,108,100,41,0,0,82,70,53,67,54,56,80,67,77,68,97,116,97,0,0,0,112,50,32,117,112,0,0,0,66,101,108,103,105,117,109,0,50,32,99,111,105,110,115,32,51,32,99,114,101,100,105,116,115,0,0,0,0,0,0,0,77,101,103,97,32,66,108,97,115,116,32,40,87,111,114,108,100,41,0,0,0,0,0,0,67,111,105,110,97,103,101,32,68,105,115,112,108,97,121,0,80,49,32,71,117,110,32,89,0,0,0,0,0,0,0,0,80,117,122,122,108,101,32,66,111,98,98,108,101,32,40,74,97,112,97,110,44,32,66,45,83,121,115,116,101,109,41,0,0,0,0,0,0,0,0,0,65,108,119,97,121,115,32,104,97,118,101,32,103,117,110,115,105,103,104,116,32,112,111,119,101,114,32,117,112,0,0,0,99,97,109,101,108,116,114,121,97,0,0,0,0,0,0,0,102,112,115,95,115,104,111,119,0,0,0,0,0,0,0,0,68,114,97,103,111,110,39,115,32,67,117,114,115,101,0,0,100,119,105,97,0,0,0,0,109,100,95,99,97,112,116,97,118,101,110,0,0,0,0,0,74,0,0,0,111,0,0,0,74,0,0,0,111,0,0,0,39,0,0,0,115,0,0,0,32,0,0,0,66,0,0,0,105,0,0,0,122,0,0,0,97,0,0,0,114,0,0,0,114,0,0,0,101,0,0,0,32,0,0,0,65,0,0,0,100,0,0,0,118,0,0,0,101,0,0,0,110,0,0,0,116,0,0,0,117,0,0,0,114,0,0,0,101,0,0,0,0,0,0,0,184,48,0,0,231,48,0,0,184,48,0,0,231,48,0,0,110,48,0,0,32,0,0,0,71,89,0,0,153,89,0,0,106,48,0,0,146,81,0,0,122,150,0,0,58,0,0,0,32,0,0,0,42,103,0,0,101,103,0,0,120,48,0,0,110,48,0,0,122,144,0,0,35,117,0,0,32,0,0,0,40,0,0,0,69,0,0,0,117,0,0,0,114,0,0,0,111,0,0,0,32,0,0,0,57,0,0,0,57,0,0,0,48,0,0,0,57,0,0,0,49,0,0,0,51,0,0,0,44,0,0,0,32,0,0,0,78,0,0,0,79,0,0,0,32,0,0,0,67,0,0,0,68,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,108,107,97,103,101,111,111,0,68,121,110,97,109,105,116,101,32,68,117,120,32,40,98,111,111,116,108,101,103,41,0,0,83,117,112,101,114,32,67,104,97,115,101,32,45,32,67,114,105,109,105,110,97,108,32,84,101,114,109,105,110,97,116,105,111,110,32,40,85,83,41,0,0,0,0,0,0,0,0,0,83,101,103,97,32,78,105,110,106,97,32,40,110,111,116,32,101,110,99,114,121,112,116,101,100,41,0,0,0,0,0,0,74,0,0,0,117,0,0,0,108,0,0,0,0,0,0,0,120,50,0,0,0,0,0,0,83,116,97,110,100,105,110,103,0,0,0,0,0,0,0,0,104,101,97,100,112,97,110,105,99,95,112,108,97,116,102,111,114,109,95,121,0,0,0,0,67,104,97,110,99,101,32,67,111,117,110,116,0,0,0,0,56,48,37,0,0,0,0,0,77,97,110,103,45,67,104,105,0,0,0,0,0,0,0,0,49,32,67,111,105,110,32,53,32,67,114,101,100,105,116,115,44,32,49,32,67,114,101,100,105,116,32,83,116,97,114,116,32,38,32,67,111,110,116,105,110,117,101,0,0,0,0,0,51,48,107,32,38,32,54,48,107,32,111,110,108,121,0,0,49,48,48,32,83,101,99,0,116,103,95,100,114,97,103,99,114,115,101,0,0,0,0,0,65,115,104,105,116,97,32,110,111,32,74,111,101,32,40,74,97,112,97,110,41,0,0,0,68,97,114,107,87,105,110,103,32,68,117,99,107,32,40,73,110,116,114,111,32,100,101,109,111,41,0,0,0,0,0,0,100,97,114,107,115,101,97,108,106,0,0,0,0,0,0,0,67,97,110,110,111,110,32,70,111,100,100,101,114,32,40,69,117,114,111,41,0,0,0,0,109,99,117,95,114,101,115,117,108,116,0,0,0,0,0,0,53,32,67,114,101,100,105,116,115,32,49,32,72,101,97,108,116,104,32,80,97,99,107,0,115,116,97,114,116,0,0,0,85,46,83,46,65,46,32,38,32,67,97,110,97,100,97,0,77,97,115,116,101,114,32,111,102,32,87,101,97,112,111,110,32,40,85,83,41,0,0,0,100,105,112,32,51,0,0,0,82,101,112,108,101,110,105,115,104,32,65,115,116,114,111,110,97,117,116,115,0,0,0,0,69,118,101,114,121,32,57,48,107,0,0,0,0,0,0,0,109,115,112,97,99,112,108,115,0,0,0,0,0,0,0,0,50,48,107,32,38,32,54,48,107,32,111,110,108,121,0,0,116,103,95,100,115,112,105,114,105,116,0,0,0,0,0,0,100,119,105,0,0,0,0,0,109,100,95,99,102,111,100,100,101,114,0,0,0,0,0,0,115,117,112,98,116,105,109,101,106,0,0,0,0,0,0,0,51,48,48,48,48,32,56,48,48,48,48,0,0,0,0,0,67,67,104,105,112,76,97,115,116,95,48,53,0,0,0,0,78,97,109,99,111,83,111,117,110,100,82,101,103,115,0,0,83,112,114,105,116,101,32,82,79,77,0,0,0,0,0,0,68,114,118,83,116,97,114,67,111,110,116,114,111,108,91,105,93,0,0,0,0,0,0,0,118,100,99,95,100,118,115,115,114,95,119,114,105,116,101,91,105,93,0,0,0,0,0,0,107,111,118,112,108,117,115,97,0,0,0,0,0,0,0,0,112,111,114,116,66,95,111,117,116,0,0,0,0,0,0,0,112,99,101,95,98,111,109,98,109,110,57,52,0,0,0,0,51,48,107,44,32,53,48,107,32,97,110,100,32,101,118,101,114,121,32,55,48,107,0,0,100,105,110,111,104,0,0,0,116,103,95,100,100,117,110,103,119,0,0,0,0,0,0,0,83,101,114,103,105,0,0,0,69,105,103,104,116,32,77,97,110,32,40,78,71,77,45,48,50,53,41,40,78,71,72,45,48,50,53,41,0,0,0,0,67,97,108,105,102,111,114,110,105,97,32,71,97,109,101,115,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,98,117,98,108,98,111,98,108,114,0,0,0,0,0,0,0,71,105,103,97,110,100,101,115,0,0,0,0,0,0,0,0,109,99,117,95,99,111,105,110,115,66,0,0,0,0,0,0,65,32,49,67,47,50,80,32,32,66,32,49,67,47,49,80,0,0,0,0,0,0,0,0,67,104,97,114,83,99,114,111,108,108,89,0,0,0,0,0,100,97,114,105,117,115,50,100,111,0,0,0,0,0,0,0,71,114,101,97,116,101,115,116,32,72,101,97,118,121,119,101,105,103,104,116,115,32,40,69,117,114,111,41,0,0,0,0,111,110,110,97,51,52,114,111,0,0,0,0,0,0,0,0,83,97,118,101,115,116,97,116,101,32,68,105,114,101,99,116,111,114,121,0,0,0,0,0,105,100,0,0,0,0,0,0,67,121,98,101,114,98,111,116,115,32,45,32,102,117,108,108,109,101,116,97,108,32,109,97,100,110,101,115,115,32,40,57,53,48,52,50,52,32,85,83,65,41,0,0,0,0,0,0,50,48,107,44,32,52,48,107,32,97,110,100,32,101,118,101,114,121,32,54,48,107,0,0,71,101,111,114,103,101,0,0,111,117,116,114,117,110,100,120,0,0,0,0,0,0,0,0,109,111,118,105,101,95,114,101,99,111,114,100,95,116,111,103,103,108,101,0,0,0,0,0,68,101,118,105,108,39,115,32,67,114,117,115,104,32,45,32,78,97,120,97,116,32,80,105,110,98,97,108,108,0,0,0,89,111,117,32,109,117,115,116,32,117,115,101,32,116,104,101,32,85,110,105,118,101,114,115,101,32,66,73,79,83,32,97,110,100,32,115,101,116,32,114,101,103,105,111,110,32,116,111,32,74,97,112,97,110,32,65,69,83,0,0,0,0,0,0,109,100,95,99,97,108,103,97,109,101,115,0,0,0,0,0,71,88,57,51,57,0,0,0,51,32,67,111,105,110,115,32,53,32,80,108,97,121,115,0,112,115,111,108,100,105,101,114,0,0,0,0,0,0,0,0,65,32,49,67,47,49,80,32,32,66,32,50,67,47,49,80,0,0,0,0,0,0,0,0,65,108,105,101,110,32,83,121,110,100,114,111,109,101,32,40,115,101,116,32,52,44,32,83,121,115,116,101,109,32,49,54,66,44,32,117,110,112,114,111,116,101,99,116,101,100,41,0,0,0,0,0,0,0,0,0,115,102,105,105,105,104,0,0,83,121,115,116,101,109,49,54,86,105,100,101,111,69,110,97,98,108,101,0,0,0,0,0,116,103,95,100,101,118,108,99,114,115,104,0,0,0,0,0,67,104,105,112,32,110,32,68,97,108,101,32,40,73,110,116,114,111,32,100,101,109,111,41,0,0,0,0,0,0,0,0,77,101,110,116,114,105,120,32,83,111,102,116,119,97,114,101,0,0,0,0,0,0,0,0,67,97,118,101,84,105,108,101,82,101,103,91,105,93,91,50,93,0,0,0,0,0,0,0,67,111,109,98,97,116,32,72,97,119,107,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,97,112,112,108,121,32,115,104,97,100,101,114,46,10,0,0,0,0,66,108,111,99,107,32,71,97,108,32,40,77,67,45,56,49,50,51,66,44,32,51,49,55,45,48,48,50,57,41,0,0,80,97,117,115,101,32,116,111,103,103,108,101,0,0,0,0,97,115,116,111,114,109,106,0,68,101,101,112,32,66,108,117,101,0,0,0,0,0,0,0,67,97,108,46,53,48,32,45,32,67,97,108,105,98,101,114,32,70,105,102,116,121,32,40,85,83,65,41,0,0,0,0,110,83,111,117,110,100,73,82,81,0,0,0,0,0,0,0,103,102,111,114,99,101,50,106,97,0,0,0,0,0,0,0,73,67,83,32,50,49,49,53,0,0,0,0,0,0,0,0,97,98,117,114,110,101,114,50,0,0,0,0,0,0,0,0,83,112,97,99,101,32,80,111,115,105,116,105,111,110,32,40,74,97,112,97,110,41,0,0,86,100,112,83,112,114,105,116,101,66,97,115,101,0,0,0,70,108,105,112,0,0,0,0,116,103,95,100,101,101,112,98,108,117,101,0,0,0,0,0,99,110,100,105,0,0,0,0,109,100,95,99,97,108,53,48,0,0,0,0,0,0,0,0,65,99,116,105,111,110,32,70,105,103,104,116,101,114,44,32,70,68,49,48,56,57,65,32,51,49,55,45,48,48,49,56,0,0,0,0,0,0,0,0,69,0,0,0,83,0,0,0,80,0,0,0,32,0,0,0,82,0,0,0,97,0,0,0,46,0,0,0,68,0,0,0,101,0,0,0,46,0,0,0,32,0,0,0,168,48,0,0,185,48,0,0,215,48,0,0,236,48,0,0,164,48,0,0,201,48,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,44,0,0,0,32,0,0,0,118,0,0,0,101,0,0,0,114,0,0,0,46,0,0,0,32,0,0,0,57,0,0,0,56,0,0,0,47,0,0,0,48,0,0,0,52,0,0,0,47,0,0,0,50,0,0,0,49,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,101,110,100,117,114,111,98,108,0,0,0,0,0,0,0,0,67,111,109,97,100,32,73,110,100,117,115,116,114,121,32,67,111,32,76,116,100,0,0,0,98,108,97,122,101,111,110,0,68,101,97,100,32,77,111,111,110,0,0,0,0,0,0,0,78,101,111,32,83,121,115,116,101,109,32,67,104,101,99,107,32,40,118,101,114,32,49,46,48,98,41,0,0,0,0,0,77,105,110,100,115,99,97,112,101,0,0,0,0,0,0,0,104,101,100,112,97,110,105,99,0,0,0,0,0,0,0,0,109,115,98,105,110,103,111,0,112,116,114,45,62,79,117,116,112,117,116,0,0,0,0,0,71,117,119,97,110,103,101,32,40,74,97,112,97,110,44,32,83,112,101,99,105,97,108,32,86,101,114,46,32,48,48,47,48,49,47,48,49,41,0,0,117,98,97,108,108,111,111,110,0,0,0,0,0,0,0,0,67,111,105,110,32,83,108,111,116,0,0,0,0,0,0,0,116,103,95,100,101,97,100,109,111,111,110,0,0,0,0,0,115,121,115,99,104,101,99,107,0,0,0,0,0,0,0,0,67,97,108,32,82,105,112,107,101,110,32,74,114,46,32,66,97,115,101,98,97,108,108,32,40,85,83,65,41,0,0,0,77,117,108,116,105,32,53,32,47,32,78,101,119,32,77,117,108,116,105,32,71,97,109,101,32,53,32,40,101,97,114,108,105,101,114,41,0,0,0,0,80,50,32,68,111,119,110,0,65,32,49,67,47,49,80,32,32,66,32,49,67,47,54,80,0,0,0,0,0,0,0,0,65,117,115,116,114,105,97,0,112,51,32,99,111,105,110,0,71,111,117,107,101,116,115,117,106,105,32,73,99,104,105,122,111,107,117,32,50,32,40,74,97,112,97,110,44,32,118,101,114,46,32,57,52,47,48,52,47,48,56,41,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,97,112,112,101,110,100,32,99,111,110,102,105,103,32,34,37,115,34,10,0,0,0,0,0,0,122,101,114,111,112,110,116,106,0,0,0,0,0,0,0,0,115,104,97,100,102,114,99,101,106,118,50,0,0,0,0,0,49,52,32,98,97,114,115,0,109,101,103,97,98,108,115,116,0,0,0,0,0,0,0,0,107,97,114,105,97,110,120,0,109,111,117,115,101,32,120,45,97,120,105,115,0,0,0,0,68,97,118,105,115,32,67,117,112,32,84,101,110,110,105,115,0,0,0,0,0,0,0,0,108,105,98,114,101,116,114,111,95,112,97,116,104,0,0,0,80,111,107,101,114,32,78,105,103,104,116,0,0,0,0,0,109,100,95,99,97,108,114,105,112,107,110,0,0,0,0,0,74,111,74,111,39,115,32,66,105,122,97,114,114,101,32,65,100,118,101,110,116,117,114,101,58,32,72,101,114,105,116,97,103,101,32,102,111,114,32,116,104,101,32,70,117,116,117,114,101,32,47,32,74,111,74,111,32,110,111,32,75,105,109,121,111,117,32,110,97,32,66,111,117,107,101,110,58,32,77,105,114,97,105,32,101,32,110,111,32,73,115,97,110,32,40,69,117,114,111,32,57,57,48,57,49,51,44,32,78,79,32,67,68,41,0,0,0,0,0,0,77,105,110,105,32,85,112,0,119,97,116,114,98,97,108,108,0,0,0,0,0,0,0,0,100,100,117,120,98,108,0,0,100,114,103,110,109,115,116,95,111,107,105,95,99,111,110,116,114,111,108,0,0,0,0,0,115,101,103,97,110,105,110,106,117,0,0,0,0,0,0,0,74,0,0,0,117,0,0,0,110,0,0,0,0,0,0,0,120,49,0,0,0,0,0,0,87,111,110,100,101,114,32,66,111,121,32,73,73,73,32,45,32,77,111,110,115,116,101,114,32,76,97,105,114,32,40,115,101,116,32,53,44,32,74,97,112,97,110,44,32,83,121,115,116,101,109,32,49,54,65,44,32,70,68,49,48,56,57,65,32,51,49,55,45,48,48,56,54,41,0,0,0,0,0,0,104,101,97,100,112,97,110,105,99,95,112,108,97,116,102,111,114,109,95,120,0,0,0,0,86,105,101,119,32,83,116,97,102,102,32,67,114,101,100,105,116,115,0,0,0,0,0,0,56,53,37,0,0,0,0,0,85,80,76,32,40,65,109,101,114,105,99,97,110,32,83,97,109,109,121,32,108,105,99,101,110,115,101,41,0,0,0,0,49,32,67,111,105,110,32,52,32,67,114,101,100,105,116,115,44,32,49,32,67,114,101,100,105,116,32,83,116,97,114,116,32,38,32,67,111,110,116,105,110,117,101,0,0,0,0,0,114,97,105,100,101,110,116,0,56,48,32,83,101,99,0,0,116,103,95,100,97,118,105,115,99,117,112,0,0,0,0,0,112,111,107,110,105,103,104,116,0,0,0,0,0,0,0,0,49,45,49,44,32,50,45,51,0,0,0,0,0,0,0,0,86,105,114,103,105,110,32,73,110,116,101,114,97,99,116,105,118,101,0,0,0,0,0,0,118,97,112,111,114,116,114,97,0,0,0,0,0,0,0,0,50,32,67,114,101,100,105,116,115,32,50,32,72,101,97,108,116,104,32,80,97,99,107,115,0,0,0,0,0,0,0,0,121,45,97,120,105,115,0,0,65,32,49,67,47,52,80,32,32,66,32,52,67,47,49,80,32,32,67,32,49,67,47,52,67,0,0,0,0,0,0,0,122,111,109,98,114,97,105,100,0,0,0,0,0,0,0,0,76,97,115,32,86,101,103,97,115,32,71,105,114,108,32,40,71,105,114,108,32,39,57,52,41,0,0,0,0,0,0,0,83,110,111,119,98,114,111,51,77,117,115,105,99,80,108,97,121,105,110,103,0,0,0,0,97,105,114,98,117,115,116,114,98,0,0,0,0,0,0,0,83,68,32,71,117,110,100,97,109,32,80,115,121,99,104,111,32,83,97,108,97,109,97,110,100,101,114,32,110,111,32,75,121,111,117,105,0,0,0,0,69,118,101,114,121,32,54,48,107,0,0,0,0,0,0,0,112,97,112,114,97,122,122,105,0,0,0,0,0,0,0,0,80,97,99,45,71,97,108,0,0,0,0,0,0,0,0,0,62,95,0,0,131,146,0,0,32,0,0,0,70,0,0,0,101,0,0,0,118,0,0,0,101,0,0,0,114,0,0,0,111,0,0,0,110,0,0,0,32,0,0,0,96,48,0,0,147,48,0,0,76,48,0,0,147,48,0,0,213,48,0,0,163,48,0,0,252,48,0,0,208,48,0,0,237,48,0,0,243,48,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,44,0,0,0,32,0,0,0,118,0,0,0,101,0,0,0,114,0,0,0,46,0,0,0,32,0,0,0,57,0,0,0,56,0,0,0,47,0,0,0,48,0,0,0,57,0,0,0,47,0,0,0,49,0,0,0,55,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,76,101,116,104,97,108,32,67,114,97,115,104,32,82,97,99,101,32,40,115,101,116,32,50,41,0,0,0,0,0,0,0,68,114,97,107,116,111,110,32,40,68,75,74,114,32,99,111,110,118,101,114,115,105,111,110,41,0,0,0,0,0,0,0,80,111,98,121,32,47,32,74,101,97,110,115,111,108,101,0,68,97,114,107,119,105,110,103,32,68,117,99,107,0,0,0,82,97,115,116,101,114,115,111,102,116,0,0,0,0,0,0,67,97,101,115,97,114,115,32,80,97,108,97,99,101,32,40,85,83,65,41,0,0,0,0,103,97,105,100,101,110,0,0,65,32,49,67,47,49,80,32,32,66,32,50,67,47,49,80,32,32,67,32,49,67,47,49,67,0,0,0,0,0,0,0,80,114,101,118,73,110,86,97,108,117,101,0,0,0,0,0,84,101,99,104,110,111,115,32,74,97,112,97,110,32,40,84,101,99,109,111,32,76,105,99,101,110,115,101,41,0,0,0,54,53,0,0,0,0,0,0,75,0,0,0,110,0,0,0,105,0,0,0,103,0,0,0,104,0,0,0,116,0,0,0,115,0,0,0,32,0,0,0,111,0,0,0,102,0,0,0,32,0,0,0,86,0,0,0,97,0,0,0,108,0,0,0,111,0,0,0,117,0,0,0,114,0,0,0,32,0,0,0,80,0,0,0,108,0,0,0,117,0,0,0,115,0,0,0,0,0,0,0,9,78,0,0,253,86,0,0,38,98,0,0,0,125,0,0,32,0,0,0,80,0,0,0,108,0,0,0,117,0,0,0,115,0,0,0,0,0,0,0,9,78,0,0,253,86,0,0,24,98,0,0,170,126,0,0,32,0,0,0,80,0,0,0,108,0,0,0,117,0,0,0,115,0,0,0,32,0,0,0,40,0,0,0,86,0,0,0,49,0,0,0,49,0,0,0,57,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,70,97,110,116,97,115,105,97,32,40,57,52,48,52,50,57,32,80,67,66,41,0,0,0,112,117,115,104,109,97,110,115,0,0,0,0,0,0,0,0,66,111,109,98,101,114,109,97,110,32,39,57,51,32,40,83,112,101,99,105,97,108,32,86,101,114,115,105,111,110,41,0,0,0,0,0,0,0,0,0,67,97,100,105,108,108,97,99,115,32,97,110,100,32,68,105,110,111,115,97,117,114,115,32,40,98,111,111,116,108,101,103,32,115,101,116,32,51,32,40,119,105,116,104,32,80,73,67,49,54,99,53,55,41,44,32,57,51,48,50,48,49,32,101,116,99,41,0,0,0,0,0,116,103,95,100,97,114,107,119,105,110,103,0,0,0,0,0,70,114,111,103,32,70,101,97,115,116,32,40,78,101,111,32,71,101,111,41,0,0,0,0,101,105,103,104,116,109,97,110,0,0,0,0,0,0,0,0,109,100,95,99,97,101,115,97,114,115,0,0,0,0,0,0,102,115,116,97,114,102,114,99,106,0,0,0,0,0,0,0,65,32,49,67,47,51,80,32,32,66,32,51,67,47,49,80,32,32,67,32,49,67,47,51,67,0,0,0,0,0,0,0,72,111,116,32,80,105,110,98,97,108,108,0,0,0,0,0,113,117,105,122,49,56,107,0,109,100,95,103,104,119,0,0,80,114,101,116,116,121,32,83,111,108,100,105,101,114,32,83,97,105,108,111,114,32,77,111,111,110,32,40,118,101,114,46,32,57,53,47,48,51,47,50,50,66,44,32,85,83,65,41,0,0,0,0,0,0,0,0,49,32,99,111,105,110,32,32,49,32,99,114,101,100,105,116,0,0,0,0,0,0,0,0,83,104,97,100,101,114,32,68,105,114,101,99,116,111,114,121,0,0,0,0,0,0,0,0,99,97,116,116,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,84,111,111,32,109,97,110,121,32,105,109,112,111,114,116,32,118,97,114,105,97,98,108,101,115,32,46,46,46,10,0,0,0,0,0,99,121,98,111,116,115,117,0,74,111,104,110,115,111,110,0,106,140,0,0,64,136,0,0,250,91,0,0,0,78,0,0,207,101,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,71,0,0,0,111,0,0,0,117,0,0,0,107,0,0,0,101,0,0,0,116,0,0,0,115,0,0,0,117,0,0,0,106,0,0,0,105,0,0,0,32,0,0,0,73,0,0,0,99,0,0,0,104,0,0,0,105,0,0,0,122,0,0,0,111,0,0,0,107,0,0,0,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,114,101,119,105,110,100,0,0,116,103,95,99,121,98,114,99,111,114,101,0,0,0,0,0,110,103,102,114,111,103,0,0,76,105,103,104,116,110,105,110,103,32,70,105,103,104,116,101,114,115,32,40,87,111,114,108,100,41,0,0,0,0,0,0,66,111,110,117,115,32,80,111,105,110,116,115,32,82,97,116,101,0,0,0,0,0,0,0,83,117,112,101,114,105,111,114,32,83,111,108,100,105,101,114,115,32,40,85,83,41,0,0,65,108,105,101,110,32,67,104,97,108,108,101,110,103,101,32,40,87,111,114,108,100,41,0,0,0,0,0,0,0,0,0,65,32,49,67,47,50,80,32,32,66,32,49,67,47,49,80,32,32,67,32,49,67,47,50,67,0,0,0,0,0,0,0,84,117,114,98,111,32,70,111,114,99,101,0,0,0,0,0,86,97,114,105,97,32,77,101,116,97,108,32,40,78,101,119,32,87,97,121,115,32,84,114,97,100,105,110,103,32,67,111,46,41,0,0,0,0,0,0,69,120,99,101,108,115,105,111,114,32,40,115,101,116,32,49,41,0,0,0,0,0,0,0,67,114,97,116,101,114,109,97,122,101,0,0,0,0,0,0,78,71,69,77,50,75,32,40,98,101,116,97,32,50,48,48,54,45,48,49,45,49,56,41,0,0,0,0,0,0,0,0,67,97,100,97,115,104,32,40,85,83,65,44,32,65,115,105,97,44,32,75,111,114,41,0,0,0,0,0,0,0,0,0,100,100,114,97,103,111,110,51,112,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,65,112,112,108,121,105,110,103,32,115,104,97,100,101,114,32,34,37,115,34,46,10,0,0,0,0,0,0,0,116,103,95,99,114,97,116,101,114,109,122,0,0,0,0,0,110,103,101,109,50,107,0,0,109,100,95,99,97,100,97,115,104,0,0,0,0,0,0,0,68,111,110,80,97,99,104,105,32,40,74,97,112,97,110,44,32,118,101,114,46,32,49,46,48,49,44,32,57,53,47,48,53,47,49,49,41,0,0,0,98,108,111,111,100,98,114,111,98,0,0,0,0,0,0,0,99,111,111,107,98,105,98,50,0,0,0,0,0,0,0,0,67,104,101,119,105,110,103,32,71,117,109,0,0,0,0,0,67,104,105,110,97,32,87,97,114,114,105,111,114,0,0,0,78,101,111,32,80,111,110,103,32,40,118,101,114,32,49,46,48,41,0,0,0,0,0,0,66,117,114,110,105,110,103,32,70,111,114,99,101,32,40,85,83,65,41,0,0,0,0,0,84,117,109,98,108,101,32,80,111,112,32,40,98,111,111,116,108,101,103,32,115,101,116,32,50,41,0,0,0,0,0,0,65,32,49,67,47,49,80,32,32,66,32,49,67,47,51,80,0,0,0,0,0,0,0,0,72,101,117,107,32,83,117,110,32,66,97,101,107,32,83,97,32,40,75,111,114,101,97,41,0,0,0,0,0,0,0,0,68,111,68,111,110,80,97,99,104,105,32,40,74,97,112,97,110,44,32,109,97,115,116,101,114,32,118,101,114,46,32,57,55,47,48,50,47,48,53,41,0,0,0,0,0,0,0,0,38,98,0,0,253,86,0,0,168,48,0,0,252,48,0,0,185,48,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,83,0,0,0,101,0,0,0,110,0,0,0,103,0,0,0,111,0,0,0,107,0,0,0,117,0,0,0,32,0,0,0,65,0,0,0,99,0,0,0,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,97,105,115,101,110,32,72,111,116,32,71,105,109,109,105,99,107,32,75,97,105,114,97,107,117,116,101,110,32,40,74,97,112,97,110,41,0,0,0,116,103,95,99,104,105,110,97,119,97,114,0,0,0,0,0,110,101,111,112,111,110,103,97,0,0,0,0,0,0,0,0,109,100,95,98,117,114,110,102,111,114,99,117,0,0,0,0,66,97,110,107,32,82,97,109,0,0,0,0,0,0,0,0,79,122,0,0,205,95,0,0,32,0,0,0,45,0,0,0,32,0,0,0,84,0,0,0,104,0,0,0,101,0,0,0,32,0,0,0,78,0,0,0,105,0,0,0,110,0,0,0,106,0,0,0,97,0,0,0,32,0,0,0,77,0,0,0,97,0,0,0,115,0,0,0,116,0,0,0,101,0,0,0,114,0,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,65,32,49,67,47,49,80,32,32,66,32,49,67,47,49,80,0,0,0,0,0,0,0,0,74,97,108,101,99,111,0,0,114,111,117,116,101,49,54,98,0,0,0,0,0,0,0,0,50,48,48,48,107,32,111,110,108,121,0,0,0,0,0,0,67,104,101,119,32,77,97,110,32,70,117,0,0,0,0,0,78,101,111,32,68,101,118,32,67,111,114,112,111,114,97,116,105,111,110,0,0,0,0,0,99,99,108,105,109,98,114,50,0,0,0,0,0,0,0,0,66,117,114,110,105,110,103,32,70,111,114,99,101,32,40,74,112,110,41,0,0,0,0,0,102,97,116,102,117,114,121,50,0,0,0,0,0,0,0,0,80,50,32,85,112,0,0,0,209,48,0,0,186,48,0,0,235,48,0,0,32,0,0,0,90,155,0,0,221,48,0,0,179,48,0,0,32,0,0,0,70,48,0,0,74,48,0,0,125,48,0,0,83,48,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,44,0,0,0])
.concat([32,0,0,0,118,0,0,0,101,0,0,0,114,0,0,0,46,0,0,0,32,0,0,0,57,0,0,0,56,0,0,0,47,0,0,0,48,0,0,0,50,0,0,0,47,0,0,0,48,0,0,0,54,0,0,0,41,0,0,0,0,0,0,0,80,0,0,0,117,0,0,0,122,0,0,0,122,0,0,0,108,0,0,0,101,0,0,0,32,0,0,0,85,0,0,0,111,0,0,0,32,0,0,0,80,0,0,0,111,0,0,0,107,0,0,0,111,0,0,0,0,0,0,0,0,0,0,0,112,50,32,115,116,97,114,116,0,0,0,0,0,0,0,0,83,116,97,114,116,32,50,32,47,32,70,105,114,101,32,50,0,0,0,0,0,0,0,0,71,101,114,109,97,110,0,0,109,103,97,107,117,101,110,50,0,0,0,0,0,0,0,0,49,50,32,98,97,114,115,0,223,48,0,0,186,48,0,0,208,48,0,0,175,48,0,0,32,0,0,0,39,89,0,0,146,81,0,0,122,150,0,0,32,0,0,0,162,48,0,0,201,48,0,0,217,48,0,0,243,48,0,0,193,48,0,0,227,48,0,0,252,48,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,77,0,0,0,105,0,0,0,122,0,0,0,117,0,0,0,98,0,0,0,97,0,0,0,107,0,0,0,117,0,0,0,32,0,0,0,68,0,0,0,97,0,0,0,105,0,0,0,98,0,0,0,111,0,0,0,117,0,0,0,107,0,0,0,101,0,0,0,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,83,99,114,97,109,98,108,101,100,32,69,103,103,0,0,0,80,49,32,71,117,110,32,88,0,0,0,0,0,0,0,0,119,119,102,115,115,116,97,114,117,97,0,0,0,0,0,0,112,98,111,98,98,108,101,0,49,50,48,48,107,44,32,51,53,48,48,107,0,0,0,0,75,97,110,103,97,114,111,111,0,0,0,0,0,0,0,0,116,103,95,99,104,101,119,109,97,110,0,0,0,0,0,0,105,110,112,117,116,95,106,111,121,112,97,100,95,100,114,105,118,101,114,0,0,0,0,0,78,101,111,32,80,111,110,103,32,40,118,101,114,32,49,46,49,41,0,0,0,0,0,0,77,97,122,105,110,103,101,114,32,90,32,40,74,97,112,97,110,44,32,118,101,114,46,32,57,52,47,48,54,47,50,55,41,0,0,0,0,0,0,0,109,100,95,98,117,114,110,102,111,114,99,106,0,0,0,0,83,78,75,32,111,102,32,65,109,101,114,105,99,97,0,0,106,111,106,111,98,97,110,101,114,49,0,0,0,0,0,0,67,111,99,107,112,105,116,32,67,111,110,118,101,114,115,105,111,110,0,0,0,0,0,0,68,121,110,97,109,105,116,101,32,68,117,120,32,40,115,101,116,32,49,44,32,56,55,53,49,32,51,49,55,45,48,48,57,53,41,0,0,0,0,0,98,108,111,99,107,111,117,116,106,0,0,0,0,0,0,0,49,48,48,75,32,52,48,48,75,32,56,48,48,75,46,46,46,0,0,0,0,0,0,0,83,101,103,97,32,78,105,110,106,97,32,40,51,49,53,45,53,49,48,50,41,0,0,0,77,0,0,0,97,0,0,0,121,0,0,0,0,0,0,0,83,116,97,114,116,32,49,32,47,32,70,105,114,101,32,49,0,0,0,0,0,0,0,0,67,111,105,110,32,35,49,32,109,117,108,105,116,112,108,105,101,114,0,0,0,0,0,0,119,98,51,53,0,0,0,0,104,101,97,100,95,108,97,121,101,114,115,105,122,101,0,0,57,48,37,0,0,0,0,0,109,97,110,103,99,104,105,0,49,32,67,111,105,110,32,51,32,67,114,101,100,105,116,115,44,32,49,32,67,114,101,100,105,116,32,83,116,97,114,116,32,38,32,67,111,110,116,105,110,117,101,0,0,0,0,0,54,48,48,107,44,32,50,48,48,48,107,32,97,110,100,32,101,118,101,114,121,32,52,53,48,48,107,0,0,0,0,0,55,48,32,83,101,99,0,0,67,104,97,109,112,105,111,110,115,32,70,111,114,101,118,101,114,32,66,111,120,105,110,103,0,0,0,0,0,0,0,0,110,101,111,112,111,110,103,0,98,108,107,116,105,103,101,114,98,49,0,0,0,0,0,0,49,45,49,44,32,50,45,50,44,32,51,45,51,44,32,52,45,52,44,32,53,45,54,0,66,117,114,110,105,110,103,32,70,111,114,99,101,32,40,69,117,114,111,41,0,0,0,0,50,45,49,45,49,67,32,32,49,45,49,45,49,32,72,80,115,0,0,0,0,0,0,0,120,45,97,120,105,115,0,0,103,97,117,110,116,108,101,116,106,0,0,0,0,0,0,0,83,110,111,119,98,114,111,51,77,117,115,105,99,0,0,0,98,111,109,98,106,97,99,107,116,0,0,0,0,0,0,0,100,105,112,32,50,0,0,0,108,101,109,109,105,110,103,115,0,0,0,0,0,0,0,0,98,105,111,110,105,99,99,50,0,0,0,0,0,0,0,0,112,97,99,108,97,110,100,106,111,0,0,0,0,0,0,0,112,97,99,103,97,108,0,0,117,110,107,110,111,119,110,32,80,97,99,45,77,97,110,32,103,97,109,98,108,105,110,103,32,103,97,109,101,0,0,0,54,48,48,107,32,97,110,100,32,101,118,101,114,121,32,49,52,48,48,107,0,0,0,0,85,110,105,118,101,114,115,97,108,32,40,84,97,105,116,111,32,108,105,99,101,110,115,101,41,0,0,0,0,0,0,0,100,114,107,116,110,106,114,0,116,103,95,102,111,114,101,118,98,111,120,0,0,0,0,0,78,101,111,32,78,111,32,80,97,110,101,112,111,110,32,40,98,101,116,97,41,0,0,0,109,100,95,98,117,114,110,102,111,114,99,0,0,0,0,0,80,50,32,71,117,110,32,85,45,68,0,0,0,0,0,0,51,48,48,48,48,32,54,48,48,48,48,0,0,0,0,0,57,48,48,48,48,32,43,32,68,105,102,102,105,99,117,108,116,121,32,42,32,49,48,48,48,48,0,0,0,0,0,0,83,0,0,0,111,0,0,0,108,0,0,0,111,0,0,0,109,0,0,0,111,0,0,0,110,0,0,0,39,0,0,0,115,0,0,0,32,0,0,0,75,0,0,0,101,0,0,0,121,0,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,83,0,0,0,111,0,0,0,108,0,0,0,111,0,0,0,109,0,0,0,111,0,0,0,110,0,0,0,39,0,0,0,115,0,0,0,32,0,0,0,75,0,0,0,101,0,0,0,121,0,0,0,32,0,0,0,189,48,0,0,237,48,0,0,226,48,0,0,243,48,0,0,110,48,0,0,117,147,0,0,0,0,0,0,0,0,0,0,73,79,67,104,105,112,67,114,101,100,105,116,80,101,114,67,111,105,110,0,0,0,0,0,103,117,110,115,109,111,107,101,117,0,0,0,0,0,0,0,75,110,105,103,104,116,115,32,111,102,32,86,97,108,111,117,114,32,80,108,117,115,32,45,32,83,97,110,103,111,107,117,32,83,101,110,107,105,32,80,108,117,115,32,40,86,49,49,57,41,0,0,0,0,0,0,116,101,114,114,97,99,114,101,97,0,0,0,0,0,0,0,112,99,101,95,98,111,109,98,109,110,57,51,115,0,0,0,100,105,110,111,112,105,99,51,0,0,0,0,0,0,0,0,116,111,107,105,117,0,0,0,87,111,114,107,105,110,103,32,68,101,115,105,103,110,115,0,110,101,111,110,111,112,111,110,0,0,0,0,0,0,0,0,76,97,115,116,32,82,101,115,111,114,116,0,0,0,0,0,77,97,105,110,32,82,97,109,0,0,0,0,0,0,0,0,66,117,108,108,115,32,86,115,32,76,97,107,101,114,115,32,97,110,100,32,116,104,101,32,78,66,65,32,80,108,97,121,111,102,102,115,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,0,0,83,97,118,97,103,101,32,66,101,101,115,0,0,0,0,0,118,117,108,103,117,115,106,0,49,57,52,50,97,98,108,0,90,56,48,32,82,79,77,32,40,67,80,85,32,35,50,41,0,0,0,0,0,0,0,0,71,104,111,117,108,115,39,110,32,71,104,111,115,116,115,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,67,111,114,101,32,73,110,102,111,32,68,105,114,101,99,116,111,114,121,0,0,0,0,0,109,101,116,114,111,99,114,115,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,97,110,110,111,116,32,102,105,110,100,32,80,121,116,104,111,110,32,115,99,114,105,112,116,46,10,0,0,0,0,0,0,0,0,48,49,48,48,49,49,48,48,48,48,48,48,48,0,0,0,67,121,98,101,114,98,111,116,115,32,45,32,102,117,108,108,109,101,116,97,108,32,109,97,100,110,101,115,115,32,40,57,53,48,52,50,48,32,74,97,112,97,110,41,0,0,0,0,50,67,32,116,111,32,83,116,97,114,116,44,32,49,32,116,111,32,67,111,110,116,0,0,76,101,119,105,115,0,0,0,115,116,97,116,101,95,115,108,111,116,95,100,101,99,114,101,97,115,101,0,0,0,0,0,116,103,95,99,97,100,97,115,104,0,0,0,0,0,0,0,67,104,97,111,115,0,0,0,108,119,105,110,103,115,0,0,109,100,95,98,117,108,108,118,115,108,97,0,0,0,0,0,108,103,116,110,102,103,104,116,0,0,0,0,0,0,0,0,109,121,115,116,115,116,111,110,111,105,0,0,0,0,0,0,115,115,111,108,100,105,101,114,0,0,0,0,0,0,0,0,76,101,103,101,110,100,32,111,102,32,72,101,114,111,32,84,111,110,109,97,32,40,98,111,111,116,108,101,103,44,32,115,101,116,32,50,41,0,0,0,84,101,116,114,105,115,32,40,115,101,116,32,50,41,0,0,106,97,99,107,51,0,0,0,115,101,97,114,99,104,97,114,0,0,0,0,0,0,0,0,66,114,97,118,111,109,97,110,0,0,0,0,0,0,0,0,67,104,97,111,115,32,68,101,109,111,32,40,78,101,111,32,71,101,111,41,0,0,0,0,67,97,112,99,111,109,32,40,68,97,116,97,32,69,97,115,116,32,85,83,65,32,108,105,99,101,110,115,101,41,0,0,66,117,108,108,115,32,118,101,114,115,117,115,32,66,108,97,122,101,114,115,32,97,110,100,32,116,104,101,32,78,66,65,32,80,108,97,121,111,102,102,115,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,83,104,97,100,101,114,32,35,37,117,58,32,34,37,115,34,46,0,0,0,0,0,0,0,49,57,52,51,106,0,0,0,100,121,110,100,117,107,101,106,0,0,0,0,0,0,0,0,91,90,105,108,101,99,32,69,108,101,99,116,114,111,110,105,99,115,93,32,74,97,108,101,99,111,0,0,0,0,0,0,77,111,118,105,101,32,114,101,99,111,114,100,32,116,111,103,103,108,101,0,0,0,0,0,115,107,121,119,111,108,102,0,116,103,95,98,114,97,118,111,109,97,110,0,0,0,0,0,110,101,111,100,101,109,111,0,109,100,95,98,117,108,108,118,115,98,108,0,0,0,0,0,108,97,115,116,100,117,101,108,106,0,0,0,0,0,0,0,115,102,117,97,0,0,0,0,115,114,117,109,98,108,101,114,51,0,0,0,0,0,0,0,115,107,121,107,105,100,100,0,87,111,114,108,100,32,67,117,112,32,39,57,48,32,40,98,111,111,116,108,101,103,41,0,0,0,0,0,0,0,0,0,99,104,101,119,105,110,103,0,103,110,103,98,108,0,0,0,66,111,120,121,98,111,121,0,0,0,0,0,0,0,0,0,78,101,111,32,50,53,48,48,32,68,101,109,111,0,0,0,109,114,102,108,101,97,95,105,111,0,0,0,0,0,0,0,66,117,103,115,32,66,117,110,110,121,32,105,110,32,68,111,117,98,108,101,32,84,114,111,117,98,108,101,32,40,85,83,65,41,0,0,0,0,0,0,103,97,108,97,103,97,109,119,0,0,0,0,0,0,0,0,119,99,57,48,98,0,0,0,114,97,108,108,121,120,109,0,86,45,83,121,115,116,101,109,32,67,111,46,32,40,66,97,108,108,121,47,77,105,100,119,97,121,47,83,101,110,116,101,32,108,105,99,101,110,115,101,41,0,0,0,0,0,0,0,116,103,95,98,111,120,121,98,111,121,0,0,0,0,0,0,110,101,111,50,53,48,48,0,78,105,112,112,111,110,32,65,109,117,115,101,32,67,111,45,76,116,100,0,0,0,0,0,109,100,95,98,117,103,115,98,117,110,117,0,0,0,0,0,114,121,103,97,114,51,0,0,82,101,116,114,111,65,114,99,104,58,32,66,108,111,99,107,105,110,103,32,83,82,65,77,32,111,118,101,114,119,114,105,116,101,46,10,0,0,0,0,91,84,101,99,104,110,111,115,93,32,40,84,97,105,116,111,32,108,105,99,101,110,115,101,41,0,0,0,0,0,0,0,71,105,110,103,97,32,78,105,110,107,121,111,117,68,101,110,32,40,115,101,116,32,50,41,0,0,0,0,0,0,0,0,86,105,100,101,111,32,82,101,103,115,0,0,0,0,0,0,109,95,111,108,100,115,95,112,114,111,116,95,104,111,108,100,0,0,0,0,0,0,0,0,66,111,110,107,39,115,32,82,101,118,101,110,103,101,0,0,74,111,110,97,115,32,73,110,100,105,97,110,97,32,97,110,100,32,116,104,101,32,76,111,115,116,32,84,101,109,112,108,101,32,111,102,32,82,65,32,40,50,48,48,53,48,55,49,55,41,0,0,0,0,0,0,66,117,100,111,107,97,110,32,45,32,84,104,101,32,77,97,114,116,105,97,108,32,83,112,105,114,105,116,32,40,85,83,65,41,0,0,0,0,0,0,80,50,32,83,116,97,114,116,0,0,0,0,0,0,0,0,65,115,105,97,0,0,0,0,49,48,32,98,97,114,115,0,79,114,105,101,110,116,97,108,32,76,101,103,101,110,100,32,45,32,88,105,32,89,111,32,71,105,32,83,104,105,32,82,101,32,90,117,97,110,103,32,40,86,49,50,54,41,0,0,77,105,122,117,98,97,107,117,32,68,97,105,98,111,117,107,101,110,32,40,74,97,112,97,110,41,0,0,0,0,0,0,81,117,105,122,32,83,101,107,97,105,32,119,97,32,83,72,79,87,32,98,121,32,115,104,111,98,97,105,32,40,74,97,112,97,110,41,0,0,0,0,116,103,95,98,111,110,107,50,0,0,0,0,0,0,0,0,108,116,111,114,98,49,0,0,109,100,95,98,117,100,111,107,97,110,117,0,0,0,0,0,184,48,0,0,231,48,0,0,184,48,0,0,231,48,0,0,110,48,0,0,32,0,0,0,71,89,0,0,153,89,0,0,106,48,0,0,146,81,0,0,122,150,0,0,58,0,0,0,32,0,0,0,42,103,0,0,101,103,0,0,120,48,0,0,110,48,0,0,122,144,0,0,35,117,0,0,0,0,0,0,74,0,0,0,111,0,0,0,74,0,0,0,111,0,0,0,39,0,0,0,115,0,0,0,32,0,0,0,66,0,0,0,105,0,0,0,122,0,0,0,97,0,0,0,114,0,0,0,114,0,0,0,101,0,0,0,32,0,0,0,65,0,0,0,100,0,0,0,118,0,0,0,101,0,0,0,110,0,0,0,116,0,0,0,117,0,0,0,114,0,0,0,101,0,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,32,0,0,0,57,0,0,0,57,0,0,0,48,0,0,0,57,0,0,0,49,0,0,0,51,0,0,0,44,0,0,0,32,0,0,0,78,0,0,0,79,0,0,0,32,0,0,0,67,0,0,0,68,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,85,115,101,32,115,116,97,114,116,32,98,117,116,116,111,110,0,0,0,0,0,0,0,0,100,100,117,120,49,0,0,0,55,48,75,32,50,48,48,75,32,53,48,48,75,46,46,46,0,0,0,0,0,0,0,0,115,108,111,116,51,102,104,0,115,101,103,97,110,105,110,106,0,0,0,0,0,0,0,0,65,0,0,0,112,0,0,0,114,0,0,0,0,0,0,0,50,32,67,111,105,110,115,32,56,32,80,108,97,121,115,0,49,32,67,111,105,110,115,32,49,32,67,114,101,100,105,116,0,0,0,0,0,0,0,0,101,115,100,49,54,95,116,105,108,101,109,97,112,48,95,99,111,108,111,114,0,0,0,0,80,97,121,111,117,116,32,37,0,0,0,0,0,0,0,0,80,97,110,100,111,114,97,0,49,32,67,111,105,110,32,50,32,67,114,101,100,105,116,115,44,32,49,32,67,114,101,100,105,116,32,83,116,97,114,116,32,38,32,67,111,110,116,105,110,117,101,0,0,0,0,0,80,50,32,83,99,111,114,101,32,76,105,110,101,32,40,99,104,101,97,116,41,0,0,0,80,108,97,121,32,116,105,109,101,0,0,0,0,0,0,0,66,111,110,107,39,115,32,65,100,118,101,110,116,117,114,101,0,0,0,0,0,0,0,0,104,111,109,101,98,114,101,119,0,0,0,0,0,0,0,0,49,45,49,44,32,50,45,50,44,32,51,45,51,44,32,52,45,53,0,0,0,0,0,0,66,117,100,111,107,97,110,32,45,32,84,104,101,32,77,97,114,116,105,97,108,32,83,112,105,114,105,116,32,40,69,117,114,111,41,0,0,0,0,0,50,45,50,67,32,49,45,50,32,72,80,115,0,0,0,0,102,105,114,101,32,57,0,0,98,117,102,102,101,114,32,101,114,114,111,114,0,0,0,0,50,32,67,111,105,110,115,32,55,32,80,108,97,121,115,0,66,108,111,99,107,32,67,97,114,110,105,118,97,108,32,47,32,84,104,117,110,100,101,114,32,38,32,76,105,103,104,116,110,105,110,103,32,50,0,0,72,121,112,101,114,112,97,99,68,105,112,0,0,0,0,0,50,49,32,69,109,111,110,32,45,32,77,101,122,97,115,101,32,72,111,116,101,108,32,111,117,33,33,0,0,0,0,0,106,111,121,115,116,105,99,107,95,54,98,95,115,101,108,101,99,116,91,52,93,0,0,0,80,50,32,73,110,118,117,108,110,101,114,97,98,105,108,105,116,121,32,40,67,104,101,97,116,41,0,0,0,0,0,0,77,115,46,32,80,97,99,45,77,97,110,32,40,98,111,111,116,108,101,103,44,32,101,110,99,114,121,112,116,101,100,41,0,0,0,0,0,0,0,0,116,103,95,98,111,110,107,0,67,111,108,117,109,110,115,32,40,78,101,111,32,71,101,111,41,0,0,0,0,0,0,0,109,100,95,98,117,100,111,107,97,110,0,0,0,0,0,0,49,48,48,48,48,32,43,32,68,105,102,102,105,99,117,108,116,121,32,42,32,49,48,48,48,48,0,0,0,0,0,0,54,48,48,107,32,56,48,48,107,0,0,0,0,0,0,0,65,116,116,114,97,99,116,32,77,117,115,105,99,0,0,0,73,79,67,104,105,112,67,111,105,110,80,101,114,67,114,101,100,105,116,0,0,0,0,0,107,111,118,112,108,117,115,0,66,111,109,98,101,114,109,97,110,32,39,57,51,0,0,0,67,97,100,105,108,108,97,99,115,32,97,110,100,32,68,105,110,111,115,97,117,114,115,32,40,98,111,111,116,108,101,103,32,115,101,116,32,50,32,40,119,105,116,104,32,80,73,67,49,54,99,53,55,41,44,32,57,51,48,50,48,49,32,101,116,99,41,0,0,0,0,0,84,84,73,0,0,0,0,0,99,111,108,117,109,110,115,110,0,0,0,0,0,0,0,0,66,117,99,107,32,82,111,103,101,114,115,32,45,32,67,111,117,110,116,100,111,119,110,32,116,111,32,68,111,111,109,115,100,97,121,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,0,0,0,83,121,115,116,101,109,32,45,32,99,97,114,116,114,105,100,103,101,115,32,115,101,108,101,99,116,101,100,32,115,101,112,101,114,97,116,101,108,121,0,50,32,67,111,105,110,115,32,54,32,80,108,97,121,115,0,49,57,52,49,117,0,0,0,83,102,50,109,100,116,83,111,117,110,100,80,111,115,0,0,109,100,95,103,104,111,117,108,115,49,0,0,0,0,0,0,67,111,110,102,105,103,32,68,105,114,101,99,116,111,114,121,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,83,99,114,105,112,116,32,108,97,110,103,117,97,103,101,32,105,115,32,110,111,116,32,80,121,116,104,111,110,46,10,0,0,0,0,48,49,48,48,48,48,48,48,48,48,48,48,48,0,0,0,99,121,98,111,116,115,106,0,86,105,116,97,108,105,116,121,0,0,0,0,0,0,0,0,115,116,97,116,101,95,115,108,111,116,95,105,110,99,114,101,97,115,101,0,0,0,0,0,66,111,110,107,32,73,73,73,32,45,32,66,111,110,107,39,115,32,66,105,103,32,65,100,118,101,110,116,117,114,101,0,0,0,0,0,0,0,0,0,109,100,95,98,117,99,107,114,111,103,0,0,0,0,0,0,84,104,117,110,100,101,114,32,67,114,111,115,115,32,73,73,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,68,114,101,97,109,32,83,111,99,99,101,114,32,39,57,52,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,108,111,104,116,98,50,0,0,116,103,95,98,111,110,107,51,0,0,0,0,0,0,0,0,67,111,100,101,110,97,109,101,32,45,32,66,108,117,116,32,69,110,103,101,108,32,40,50,48,48,54,45,48,49,45,49,57,41,0,0,0,0,0,0,66,117,98,115,121,32,73,73,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,68,101,108,116,97,84,46,112,114,101,118,95,97,99,99,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,111,112,101,110,32,97,114,99,104,105,118,101,58,32,37,115,46,10,0,0,0,0,0,0,0,73,69,78,68,0,0,0,0,116,103,95,98,111,109,98,109,97,110,0,0,0,0,0,0,109,100,95,98,117,98,115,121,50,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,115,116,111,114,101,100,32,98,108,111,99,107,32,108,101,110,103,116,104,115,0,0,0,0,103,108,84,101,120,73,109,97,103,101,51,68,79,69,83,0,116,104,110,100,122,111,110,101,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,105,110,105,116,32,115,116,97,116,101,32,116,114,97,99,107,101,114,46,10,0,0,0,0,0,0,83,116,97,103,101,32,77,97,103,105,99,32,67,111,110,116,105,110,117,101,0,0,0,0,116,103,95,98,111,109,98,109,110,57,51,0,0,0,0,0,99,110,98,101,0,0,0,0,76,101,97,115,116,0,0,0,66,117,98,115,121,32,105,110,32,67,108,97,119,115,32,69,110,99,111,117,110,116,101,114,115,32,111,102,32,116,104,101,32,70,117,114,114,101,100,32,75,105,110,100,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,71,76,93,58,32,77,97,120,32,116,101,120,116,117,114,101,32,115,105,122,101,58,32,37,100,32,112,120,44,32,114,101,110,100,101,114,98,117,102,102,101,114,32,115,105,122,101,58,32,37,117,32,112,120,46,10,0,0,0,0,66,108,111,111,100,121,32,87,111,108,102,0,0,0,0,0,74,101,102,102,32,75,117,114,116,122,0,0,0,0,0,0,109,100,95,98,117,98,115,121,0,0,0,0,0,0,0,0,83,76,79,84,45,62,109,117,108,0,0,0,0,0,0,0,116,103,95,98,108,111,100,119,111,108,102,0,0,0,0,0,83,104,97,100,111,119,32,111,102,32,116,104,101,32,66,101,97,115,116,32,40,78,101,111,32,71,101,111,32,100,101,109,111,41,0,0,0,0,0,0,66,117,98,98,108,101,32,97,110,100,32,83,113,117,101,97,107,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,75,48,53,50,49,48,57,83,99,114,111,108,108,67,116,114,108,0,0,0,0,0,0,0,116,111,112,104,117,110,116,114,0,0,0,0,0,0,0,0,80,50,32,67,111,105,110,0,99,114,105,109,102,103,104,116,50,0,0,0,0,0,0,0,112,50,32,99,111,105,110,0,104,99,97,115,116,108,101,101,0,0,0,0,0,0,0,0,68,101,110,109,97,114,107,32,40,71,101,114,109,97,110,32,84,117,110,105,110,103,32,108,105,99,101,110,115,101,41,0,56,32,98,97,114,115,0,0,109,97,105,110,101,118,116,50,112,0,0,0,0,0,0,0,109,105,122,117,98,97,107,117,0,0,0,0,0,0,0,0,69,97,115,105,101,115,116,0,97,108,105,101,110,115,51,0,113,122,115,104,111,119,98,121,0,0,0,0,0,0,0,0,103,98,101,114,101,116,98,0,66,108,97,122,105,110,103,32,76,97,122,101,114,115,0,0,97,117,100,105,111,95,100,115,112,95,112,108,117,103,105,110,0,0,0,0,0,0,0,0,109,100,95,98,117,98,98,108,101,115,113,117,0,0,0,0,74,111,74,111,39,115,32,66,105,122,97,114,114,101,32,65,100,118,101,110,116,117,114,101,58,32,72,101,114,105,116,97,103,101,32,102,111,114,32,116,104,101,32,70,117,116,117,114,101,32,47,32,74,111,74,111,32,110,111,32,75,105,109,121,111,117,32,110,97,32,66,111,117,107,101,110,58,32,77,105,114,97,105,32,101,32,110,111,32,73,115,97,110,32,40,74,97,112,97,110,32,57,57,48,57,49,51,44,32,78,79,32,67,68,41,0,0,0,0,0,77,111,118,105,110,103,0,0,80,97,114,111,100,105,117,115,32,68,65,33,32,40,87,111,114,108,100,44,32,115,101,116,32,50,41,0,0,0,0,0,99,103,0,0,0,0,0,0,68,121,110,97,109,105,116,101,32,68,117,120,32,40,115,101,116,32,50,44,32,70,68,49,48,57,52,32,51,49,55,45,48,48,57,54,41,0,0,0,98,97,110,107,48,0,0,0,82,101,103,117,108,117,115,32,40,110,111,116,32,101,110,99,114,121,112,116,101,100,41,0,0,0,0,0,0,0,0,0,77,0,0,0,97,0,0,0,114,0,0,0,0,0,0,0,67,111,105,110,32,116,111,32,67,114,101,100,105,116,0,0,109,115,116,97,100,105,117,109,0,0,0,0,0,0,0,0,87,111,110,100,101,114,32,66,111,121,32,73,73,73,32,45,32,77,111,110,115,116,101,114,32,76,97,105,114,32,40,115,101,116,32,49,44,32,74,97,112,97,110,44,32,83,121,115,116,101,109,32,49,54,65,44,32,70,68,49,48,57,52,32,51,49,55,45,48,48,56,52,41,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,66,105,116,32,100,101,112,116,104,32,111,102,32,84,71,65,32,105,109,97,103,101,32,105,115,32,119,114,111,110,103,46,32,79,110,108,121,32,51,50,45,98,105,116,32,97,110,100,32,50,52,45,98,105,116,32,115,117,112,112,111,114,116,101,100,46,10,0,0,0,0,0,0,0,0,99,112,117,98,97,110,107,0,120,51,46,48,0,0,0,0,83,0,0,0,117,0,0,0,112,0,0,0,101,0,0,0,114,0,0,0,32,0,0,0,66,155,0,0,151,101,0,0,133,127,0,0,32,0,0,0,168,48,0,0,164,48,0,0,234,48,0,0,162,48,0,0,243,48,0,0,32,0,0,0,110,48,0,0,6,144,0,0,114,137,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,49,32,66,117,116,116,111,110,32,55,0,0,0,0,0,72,111,116,32,66,117,98,98,108,101,0,0,0,0,0,0,49,32,67,111,105,110,32,83,116,97,114,116,44,32,49,32,67,111,105,110,32,67,111,110,116,105,110,117,101,0,0,0,78,97,110,100,111,32,83,112,101,101,100,0,0,0,0,0,104,121,112,115,112,116,115,112,0,0,0,0,0,0,0,0,116,103,95,98,108,97,122,108,97,122,114,0,0,0,0,0,98,101,97,115,116,0,0,0,66,117,98,98,108,101,32,97,110,100,32,83,113,117,101,97,107,32,40,69,117,114,111,41,0,0,0,0,0,0,0,0,84,121,112,104,111,111,110,0,0,0,0,0,0,0,0,0,49,45,49,45,49,45,49,45,49,67,32,49,45,49,45,49,45,49,45,50,32,72,80,115,0,0,0,0,0,0,0,0,102,105,114,101,32,56,0,0,73,110,118,117,108,101,114,97,98,105,108,105,116,121,0,0,98,108,111,99,107,99,97,114,0,0,0,0,0,0,0,0,99,111,110,116,114,97,98,0,72,121,112,101,114,112,97,99,73,110,112,117,116,0,0,0,56,48,48,75,0,0,0,0,100,105,112,32,49,0,0,0,120,109,101,110,97,97,0,0,80,49,32,73,110,118,117,108,110,101,114,97,98,105,108,105,116,121,32,40,67,104,101,97,116,41,0,0,0,0,0,0,115,117,114,97,116,107,106,0,109,115,112,97,99,109,98,101,0,0,0,0,0,0,0,0,108,97,110,103,117,97,103,101,0,0,0,0,0,0,0,0,68,114,97,107,116,111,110,32,40,68,75,32,99,111,110,118,101,114,115,105,111,110,41,0,0,0,0,0,0,0,0,0,84,155,0,0,99,115,0,0,110,48,0,0,139,115,0,0,253,86,0,0,0,0,0,0,77,0,0,0,97,0,0,0,106,0,0,0,117,0,0,0,117,0,0,0,32,0,0,0,110,0,0,0,111,0,0,0,32,0,0,0,79,0,0,0,104,0,0,0,107,0,0,0,111,0,0,0,107,0,0,0,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,97,116,116,108,101,32,82,111,121,97,108,101,0,0,0,52,32,112,108,97,121,101,114,32,32,105,110,112,117,116,32,116,101,115,116,32,99,97,114,116,114,105,100,103,101,0,0,109,100,95,98,117,98,98,108,101,115,113,0,0,0,0,0,80,50,32,71,117,110,32,76,45,82,0,0,0,0,0,0,81,0,0,0,117,0,0,0,97,0,0,0,114,0,0,0,116,0,0,0,104,0,0,0,0,0,0,0,175,48,0,0,169,48,0,0,252,48,0,0,185,48,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,52,48,48,107,32,53,48,48,107,0,0,0,0,0,0,0,71,0,0,0,114,0,0,0,97,0,0,0,100,0,0,0,105,0,0,0,117,0,0,0,115,0,0,0,32,0,0,0,73,0,0,0,73,0,0,0,73,0,0,0,32,0,0,0,29,79,0,0,172,138,0,0,75,48,0,0,137,48,0,0,94,121,0,0,113,138,0,0,120,48,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,51,114,100,32,77,97,122,101,0,0,0,0,0,0,0,0,51,32,67,111,105,110,115,32,50,32,80,108,97,121,115,0,49,32,67,111,105,110,32,57,57,32,80,108,97,121,115,0,73,79,67,104,105,112,67,114,101,100,105,116,115,0,0,0,75,111,110,97,109,105,32,40,67,101,110,116,117,114,105,32,108,105,99,101,110,115,101,41,0,0,0,0,0,0,0,0,75,0,0,0,110,0,0,0,105,0,0,0,103,0,0,0,104,0,0,0,116,0,0,0,115,0,0,0,32,0,0,0,111,0,0,0,102,0,0,0,32,0,0,0,86,0,0,0,97,0,0,0,108,0,0,0,111,0,0,0,117,0,0,0,114,0,0,0,0,0,0,0,9,78,0,0,253,86,0,0,38,98,0,0,0,125,0,0,0,0,0,0,9,78,0,0,253,86,0,0,24,98,0,0,170,126,0,0,32,0,0,0,40,0,0,0,86,0,0,0,49,0,0,0,48,0,0,0,48,0,0,0,44,0,0,0,32,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,118,101,110,100,101,116,116,97,50,112,0,0,0,0,0,0,49,57,120,120,98,0,0,0,112,99,101,95,98,111,109,98,109,110,57,51,0,0,0,0,100,105,110,111,112,105,99,50,0,0,0,0,0,0,0,0,99,114,97,122,121,99,111,112,0,0,0,0,0,0,0,0,116,103,95,98,97,116,108,114,111,121,108,0,0,0,0,0,52,32,112,108,97,121,101,114,32,105,110,112,117,116,32,116,101,115,116,0,0,0,0,0,175,48,0,0,164,48,0,0,186,48,0,0,39,89,0,0,92,99,0,0,251,103,0,0,218,125,0,0,32,0,0,0,45,0,0,0,32,0,0,0,84,0,0,0,104,0,0,0,101,0,0,0,32,0,0,0,76,0,0,0,97,0,0,0,115,0,0,0,116,0,0,0,32,0,0,0,67,0,0,0,111,0,0,0,117,0,0,0,110,0,0,0,116,0,0,0,32,0,0,0,68,0,0,0,111,0,0,0,119,0,0,0,110,0,0,0,0,0,0,0,81,0,0,0,117,0,0,0,105,0,0,0,122,0,0,0,32,0,0,0,68,0,0,0,97,0,0,0,105,0,0,0,115,0,0,0,111,0,0,0,117,0,0,0,115,0,0,0,97,0,0,0,32,0,0,0,83,0,0,0,101,0,0,0,110,0,0,0,32,0,0,0,45,0,0,0,32,0,0,0,84,0,0,0,104,0,0,0,101,0,0,0,32,0,0,0,76,0,0,0,97,0,0,0,115,0,0,0,116,0,0,0,32,0,0,0,67,0,0,0,111,0,0,0,117,0,0,0,110,0,0,0,116,0,0,0,32,0,0,0,68,0,0,0,111,0,0,0,119,0,0,0,110,0,0,0,32,0,0,0,40,0,0,0,75,0,0,0,111,0,0,0,114,0,0,0,101,0,0,0,97,0,0,0,110,0,0,0,32,0,0,0,114,0,0,0,101,0,0,0,108,0,0,0,101,0,0,0,97,0,0,0,115,0,0,0,101,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,66,117,98,98,97,39,110,39,83,116,105,120,32,40,85,83,65,41,0,0,0,0,0,0,115,105,109,112,115,111,110,115,50,112,0,0,0,0,0,0,91,75,111,110,97,109,105,93,32,40,83,116,101,114,110,32,108,105,99,101,110,115,101,41,0,0,0,0,0,0,0,0,111,118,101,114,108,97,121,37,117,95,111,118,101,114,108,97,121,0,0,0,0,0,0,0,71,104,111,117,108,115,39,110,32,71,104,111,115,116,115,32,40,69,117,114,111,44,32,85,83,65,44,32,75,111,114,44,32,82,101,118,46,32,65,41,0,0,0,0,0,0,0,0,116,109,110,116,117,97,0,0,66,114,111,119,115,101,114,32,68,105,114,101,99,116,111,114,121,0,0,0,0,0,0,0,99,108,97,115,115,0,0,0,110,66,97,110,107,68,97,116,97,0,0,0,0,0,0,0,48,49,49,49,48,48,0,0,67,121,98,101,114,98,111,116,115,32,45,32,102,117,108,108,109,101,116,97,108,32,109,97,100,110,101,115,115,32,40,57,53,48,52,50,52,32,69,117,114,111,41,0,0,0,0,0,32,10,9,12,11,13,0,0,73,114,101,109,32,40,108,105,99,101,110,115,101,100,32,102,114,111,109,32,72,117,100,115,111,110,32,83,111,102,116,41,0,0,0,0,0,0,0,0,77,97,99,104,105,110,101,32,78,97,109,101,0,0,0,0,101,120,105,116,95,101,109,117,108,97,116,111,114,0,0,0,116,103,95,98,97,108,108,105,115,116,120,0,0,0,0,0,63,63,63,0,0,0,0,0,109,100,95,98,117,98,98,97,117,0,0,0,0,0,0,0,116,104,110,100,114,120,50,106,0,0,0,0,0,0,0,0,83,104,105,115,101,110,115,104,111,32,73,73,0,0,0,0,73,114,101,109,32,40,68,97,116,97,32,69,97,115,116,32,76,105,99,101,110,115,101,41,0,0,0,0,0,0,0,0,100,115,111,99,99,114,57,52,106,0,0,0,0,0,0,0,76,101,103,101,110,100,32,111,102,32,72,101,114,111,32,84,111,110,109,97,32,40,98,111,111,116,108,101,103,44,32,115,101,116,32,49,41,0,0,0,82,101,116,114,111,65,114,99,104,58,32,9,9,37,115,10,0,0,0,0,0,0,0,0,118,105,103,105,108,97,110,116,117,0,0,0,0,0,0,0,65,116,111,109,105,99,32,66,111,121,32,40,114,101,118,105,115,105,111,110,32,66,41,0,0,0,0,0,0,0,0,0,72,111,111,107,32,40,85,83,41,0,0,0,0,0,0,0,116,103,95,97,99,114,117,115,104,0,0,0,0,0,0,0,52,112,108,97,121,0,0,0,66,117,98,98,97,39,110,39,83,116,105,120,32,40,69,117,114,111,44,32,80,114,111,116,111,116,121,112,101,41,0,0,114,116,121,112,101,106,112,0,46,99,103,0,0,0,0,0,82,105,103,104,116,32,82,105,103,104,116,0,0,0,0,0,72,117,100,115,111,110,32,83,111,102,116,0,0,0,0,0,90,0,0,0,105,0,0,0,110,0,0,0,116,0,0,0,114,0,0,0,105,0,0,0,99,0,0,0,107,0,0,0,0,0,0,0,188,98,0,0,87,48,0,0,250,81,0,0,87,48,0,0,184,48,0,0,243,48,0,0,200,48,0,0,234,48,0,0,195,48,0,0,175,48,0,0,32,0,0,0,40,0,0,0,78,0,0,0,101,0,0,0,111,0,0,0,32,0,0,0,67,0,0,0,68,0,0,0,32,0,0,0,99,0,0,0,111,0,0,0,110,0,0,0,118,0,0,0,101,0,0,0,114,0,0,0,115,0,0,0,105,0,0,0,111,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,109,100,95,98,117,98,98,97,112,0,0,0,0,0,0,0,82,105,103,104,116,32,76,101,102,116,0,0,0,0,0,0,66,97,100,32,99,111,108,111,117,114,115,0,0,0,0,0,103,117,110,95,105,110,112,117,116,95,115,114,99,0,0,0,90,105,110,116,114,105,99,107,32,47,32,79,115,104,105,100,97,115,104,105,32,90,101,110,116,114,105,120,32,40,78,101,111,32,67,68,32,99,111,110,118,101,114,115,105,111,110,41,0,0,0,0,0,0,0,0,67,111,114,101,32,68,101,115,105,103,110,0,0,0,0,0,82,105,103,104,116,32,68,111,119,110,0,0,0,0,0,0,103,117,110,95,105,110,112,117,116,95,98,105,116,0,0,0,112,107,116,103,97,108,100,120,0,0,0,0,0,0,0,0,122,105,110,116,114,107,99,100,0,0,0,0,0,0,0,0,66,117,98,98,97,39,110,39,83,116,105,120,32,40,69,117,114,111,41,0,0,0,0,0,82,105,103,104,116,32,85,112,0,0,0,0,0,0,0,0,116,110,100,114,99,97,100,101,95,105,110,105,116,95,115,105,109,0,0,0,0,0,0,0,84,117,114,98,111,71,114,97,102,120,32,49,54,0,0,0,77,101,116,97,108,32,83,108,117,103,32,53,32,40,98,111,111,116,108,101,103,41,0,0,109,100,95,98,117,98,98,97,0,0,0,0,0,0,0,0,49,57,57,51,0,0,0,0,80,49,32,66,117,116,116,111,110,32,68,0,0,0,0,0,76,101,102,116,32,82,105,103,104,116,0,0,0,0,0,0,85,46,83,46,65,46,0,0,67,111,105,110,97,103,101,0,72,111,110,103,32,75,111,110,103,32,40,109,101,116,114,111,116,97,105,110,109,101,110,116,32,108,105,99,101,110,115,101,0,0,0,0,0,0,0,0,76,105,113,117,105,100,32,75,105,100,115,32,40,85,83,41,0,0,0,0,0,0,0,0,117,115,99,108,115,115,105,99,95,112,111,114,116,95,115,101,108,101,99,116,0,0,0,0,82,121,117,32,74,105,110,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,116,103,95,97,101,114,111,98,108,115,116,0,0,0,0,0,109,115,108,117,103,53,98,0,97,117,100,105,111,95,100,114,105,118,101,114,0,0,0,0,50,32,67,111,105,110,115,32,51,32,67,114,101,100,105,116,0,0,0,0,0,0,0,0,66,114,117,116,97,108,32,45,32,80,97,119,115,32,111,102,32,70,117,114,121,32,40,85,83,65,41,0,0,0,0,0,106,111,106,111,98,97,110,114,49,0,0,0,0,0,0,0,100,100,117,120,0,0,0,0,67,111,105,110,32,67,0,0,114,101,103,117,108,117,115,117,0,0,0,0,0,0,0,0,70,0,0,0,101,0,0,0,98,0,0,0,0,0,0,0,108,101,102,116,32,76,101,102,116,0,0,0,0,0,0,0,84,119,105,110,0,0,0,0,120,50,46,48,0,0,0,0,104,111,116,98,117,98,108,0,50,32,67,111,105,110,115,32,83,116,97,114,116,44,32,49,32,67,111,105,110,32,67,111,110,116,105,110,117,101,0,0,115,101,116,97,95,115,97,109,112,108,101,115,95,98,97,110,107,0,0,0,0,0,0,0,85,112,114,105,103,104,116,32,50,80,0,0,0,0,0,0,78,71,58,68,101,118,46,84,101,97,109,0,0,0,0,0,50,45,49,44,32,52,45,51,0,0,0,0,0,0,0,0,109,100,95,98,114,117,116,97,108,117,0,0,0,0,0,0,49,45,49,45,49,45,49,67,32,49,45,49,45,49,45,50,32,72,80,115,0,0,0,0,102,105,114,101,32,55,0,0,76,101,102,116,32,68,111,119,110,0,0,0,0,0,0,0,65,116,104,101,110,97,32,110,111,32,72,97,116,101,110,97,32,63,0,0,0,0,0,0,72,121,112,101,114,112,97,99,83,111,117,110,100,76,97,116,99,104,0,0,0,0,0,0,77,83,32,80,97,99,109,97,110,32,40,98,111,111,116,108,101,103,41,0,0,0,0,0,85,112,114,105,103,104,116,32,49,80,0,0,0,0,0,0,100,114,97,107,116,111,110,0,66,114,117,116,97,108,32,45,32,80,97,119,115,32,111,102,32,70,117,114,121,32,40,69,117,114,111,41,0,0,0,0,50,48,48,107,32,52,48,48,107,0,0,0,0,0,0,0,50,110,100,32,77,97,122,101,0,0,0,0,0,0,0,0,76,101,102,116,32,85,112,0,73,79,67,104,105,112,77,111,100,101,0,0,0,0,0,0,72,117,114,114,105,99,97,110,101,32,75,105,99,107,0,0,73,71,83,32,40,65,108,116,97,32,67,111,46,44,32,76,84,68,32,76,105,99,101,110,115,101,41,0,0,0,0,0,66,111,100,121,32,67,111,110,113,117,101,115,116,32,73,73,0,0,0,0,0,0,0,0,76,97,115,116,32,72,111,112,101,32,67,68,32,66,101,116,97,32,40,78,101,111,32,67,68,32,99,111,110,118,101,114,115,105,111,110,41,0,0,0,81,117,105,122,32,68,97,105,115,111,117,115,97,32,83,101,110,32,45,32,84,104,101,32,76,97,115,116,32,67,111,117,110,116,32,68,111,119,110,32,40,75,111,114,101,97,110,32,114,101,108,101,97,115,101,41,0,0,0,0,0,0,0,0,109,100,95,98,114,117,116,97,108,0,0,0,0,0,0,0,68,105,115,107,32,73,109,97,103,101,32,65,112,112,101,110,100,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,83,99,114,105,112,116,32,97,108,114,101,97,100,121,32,105,109,112,111,114,116,101,100,46,10,0,0,83,101,116,97,32,85,83,65,32,47,32,82,111,109,115,116,97,114,0,0,0,0,0,0,48,49,49,48,48,48,0,0,99,121,98,111,116,115,0,0,116,111,103,103,108,101,95,102,117,108,108,115,99,114,101,101,110,0,0,0,0,0,0,0])
.concat([108,104,99,100,98,0,0,0,66,114,105,97,110,32,76,97,114,97,32,67,114,105,99,107,101,116,32,57,54,32,40,69,117,114,111,44,32,49,57,57,54,48,51,41,0,0,0,0,84,104,117,110,100,101,114,32,67,114,111,115,115,32,73,73,32,40,65,115,105,97,41,0,0,0,0,0,0,0,0,0,77,97,116,99,104,32,73,116,32,73,73,0,0,0,0,0,77,49,48,55,0,0,0,0,108,111,104,116,98,0,0,0,83,101,116,97,32,85,83,65,32,47,32,84,97,105,116,111,32,65,109,101,114,105,99,97,0,0,0,0,0,0,0,0,84,104,101,32,75,105,110,103,32,111,102,32,70,105,103,104,116,101,114,115,32,39,57,56,32,40,65,110,110,105,118,101,114,115,97,114,121,32,69,100,105,116,105,111,110,44,32,69,71,72,84,32,104,97,99,107,41,0,0,0,0,0,0,0,109,100,95,98,114,105,97,110,108,57,54,97,0,0,0,0,118,111,105,99,101,45,62,100,97,116,97,0,0,0,0,0,46,115,104,97,100,101,114,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,73,109,112,108,101,109,101,110,116,97,116,105,111,110,32,117,115,101,115,32,116,104,114,101,97,100,101,100,32,97,117,100,105,111,46,32,67,97,110,110,111,116,32,117,115,101,32,114,101,119,105,110,100,46,10,0,0,0,0,65,116,104,101,110,97,32,47,32,84,97,105,116,111,32,40,74,97,112,97,110,41,0,0,50,32,67,111,105,110,115,32,49,32,67,114,101,100,105,116,32,40,49,32,116,111,32,99,111,110,116,41,0,0,0,0,107,111,102,57,56,97,101,0,66,114,105,97,110,32,76,97,114,97,32,67,114,105,99,107,101,116,32,57,54,32,40,69,117,114,111,44,32,49,57,57,54,48,52,41,0,0,0,0,76,117,99,107,121,32,84,111,100,97,121,0,0,0,0,0,65,116,104,101,110,97,32,40,74,97,112,97,110,41,0,0,84,104,101,32,75,105,110,103,32,111,102,32,70,105,103,104,116,101,114,115,32,39,57,55,32,45,32,70,105,110,97,108,32,66,97,116,116,108,101,32,40,104,97,99,107,41,0,0,109,100,95,98,114,105,97,110,108,57,54,0,0,0,0,0,110,71,97,108,67,121,99,108,101,115,83,101,103,109,101,110,116,0,0,0,0,0,0,0,40,67,41,32,47,32,76,105,99,101,110,115,101,0,0,0,107,111,102,57,55,120,116,0,66,114,105,97,110,32,76,97,114,97,32,67,114,105,99,107,101,116,32,40,69,117,114,111,44,32,49,57,57,53,48,51,41,0,0,0,0,0,0,0,71,97,108,76,102,111,87,97,118,101,80,111,115,0,0,0,67,97,115,116,108,101,32,111,102,32,68,114,97,103,111,110,0,0,0,0,0,0,0,0,84,104,101,32,75,105,110,103,32,111,102,32,70,105,103,104,116,101,114,115,32,39,57,55,32,111,114,111,115,104,105,32,112,108,117,115,32,50,48,48,51,0,0,0,0,0,0,0,109,100,95,98,114,105,97,110,108,97,114,49,0,0,0,0,80,49,32,66,117,116,116,111,110,32,67,0,0,0,0,0,112,49,32,102,105,114,101,32,50,0,0,0,0,0,0,0,78,105,112,112,111,110,0,0,84,97,98,108,101,0,0,0,65,117,115,116,114,105,97,32,40,71,101,114,109,97,110,32,84,117,110,105,110,103,32,108,105,99,101,110,115,101,0,0,108,105,113,117,105,100,107,117,0,0,0,0,0,0,0,0,87,105,110,116,101,114,0,0,68,114,97,103,111,110,32,85,110,105,116,0,0,0,0,0,83,112,97,99,101,32,71,117,110,32,40,87,111,114,108,100,41,0,0,0,0,0,0,0,51,32,67,111,105,110,115,32,50,32,67,114,101,100,105,116,0,0,0,0,0,0,0,0,118,105,100,101,111,95,103,108,95,99,111,110,116,101,120,116,0,0,0,0,0,0,0,0,66,114,105,97,110,32,76,97,114,97,32,67,114,105,99,107,101,116,32,40,69,117,114,111,44,32,49,57,57,53,48,54,41,0,0,0,0,0,0,0,184,48,0,0,231,48,0,0,184,48,0,0,231,48,0,0,110,48,0,0,32,0,0,0,71,89,0,0,153,89,0,0,106,48,0,0,146,81,0,0,122,150,0,0,58,0,0,0,32,0,0,0,42,103,0,0,101,103,0,0,120,48,0,0,110,48,0,0,122,144,0,0,35,117,0,0,0,0,0,0,74,0,0,0,111,0,0,0,74,0,0,0,111,0,0,0,39,0,0,0,115,0,0,0,32,0,0,0,66,0,0,0,105,0,0,0,122,0,0,0,97,0,0,0,114,0,0,0,114,0,0,0,101,0,0,0,32,0,0,0,65,0,0,0,100,0,0,0,118,0,0,0,101,0,0,0,110,0,0,0,116,0,0,0,117,0,0,0,114,0,0,0,101,0,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,32,0,0,0,57,0,0,0,57,0,0,0,48,0,0,0,57,0,0,0,49,0,0,0,51,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,67,111,116,116,111,110,32,40,115,101,116,32,49,44,32,74,97,112,97,110,44,32,82,101,118,32,65,44,32,70,68,49,48,57,52,32,51,49,55,45,48,49,55,57,97,41,41,0,0,0,0,0,0,0,0,0,51,67,32,49,67,0,0,0,70,99,114,97,115,104,83,97,109,112,108,101,83,101,108,101,99,116,50,0,0,0,0,0,82,101,103,117,108,117,115,32,40,51,49,53,45,53,48,51,51,41,0,0,0,0,0,0,74,0,0,0,97,0,0,0,110,0,0,0,0,0,0,0,119,98,51,49,0,0,0,0,120,49,46,52,0,0,0,0,84,117,110,105,110,103,0,0,50,32,67,111,105,110,115,32,83,116,97,114,116,44,32,50,32,67,111,105,110,115,32,67,111,110,116,105,110,117,101,0,49,32,111,102,32,56,32,83,99,101,110,101,115,0,0,0,90,105,112,97,110,103,0,0,84,104,101,32,75,105,110,103,32,111,102,32,70,105,103,104,116,101,114,115,32,39,57,55,32,80,108,117,115,32,50,48,48,51,32,40,98,111,111,116,108,101,103,32,47,32,104,97,99,107,41,0,0,0,0,0,50,45,49,44,32,52,45,50,44,32,53,45,51,44,32,54,45,52,0,0,0,0,0,0,109,100,95,98,114,105,97,110,108,97,114,0,0,0,0,0,49,45,49,67,32,49,45,50,32,72,80,115,0,0,0,0,51,215,32,75,105,99,107,0,97,116,101,104,97,116,101,0,66,111,110,117,115,32,108,105,102,101,0,0,0,0,0,0,109,115,112,97,99,109,97,98,0,0,0,0,0,0,0,0,49,32,111,102,32,52,32,83,99,101,110,101,115,0,0,0,72,101,114,111,32,105,110,32,116,104,101,32,67,97,115,116,108,101,32,111,102,32,68,111,111,109,32,40,68,75,32,99,111,110,118,101,114,115,105,111,110,32,110,111,116,32,101,110,99,114,121,112,116,101,100,41,0,0,0,0,0,0,0,0,112,99,101,95,122,105,112,97,110,103,0,0,0,0,0,0,107,111,102,57,55,112,108,97,0,0,0,0,0,0,0,0,66,114,101,116,116,32,72,117,108,108,32,72,111,99,107,101,121,32,39,57,53,32,40,85,83,65,41,0,0,0,0,0,65,32,50,47,49,32,66,32,49,47,50,0,0,0,0,0,77,97,122,101,32,77,111,110,115,116,101,114,32,65,112,112,101,97,114,115,32,73,110,0,67,112,115,82,97,109,70,70,0,0,0,0,0,0,0,0,73,79,67,104,105,112,67,80,85,49,70,105,114,101,73,82,81,0,0,0,0,0,0,0,75,110,105,103,104,116,115,32,111,102,32,86,97,108,111,117,114,32,45,32,83,97,110,103,111,107,117,32,83,101,110,107,105,32,40,86,49,48,48,44,32,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,52,48,48,75,32,79,110,108,121,0,0,0,0,0,0,0,112,99,101,95,98,111,100,121,99,111,110,50,0,0,0,0,67,97,100,105,108,108,97,99,115,32,97,110,100,32,68,105,110,111,115,97,117,114,115,32,40,98,111,111,116,108,101,103,32,115,101,116,32,49,32,40,119,105,116,104,32,80,73,67,49,54,99,53,55,41,44,32,57,51,48,50,48,49,32,101,116,99,41,0,0,0,0,0,90,101,114,111,32,52,32,67,104,97,109,112,32,40,118,49,46,53,41,0,0,0,0,0,84,104,101,32,75,105,110,103,32,111,102,32,70,105,103,104,116,101,114,115,32,39,57,55,32,40,49,48,116,104,32,65,110,110,105,118,101,114,115,97,114,121,32,67,104,105,110,101,115,101,32,69,100,105,116,105,111,110,44,32,69,71,72,84,32,104,97,99,107,41,0,0,113,117,105,122,100,97,105,115,107,0,0,0,0,0,0,0,109,100,95,98,114,101,116,116,104,0,0,0,0,0,0,0,109,100,95,103,104,111,117,108,115,0,0,0,0,0,0,0,68,105,115,107,32,73,110,100,101,120,0,0,0,0,0,0,51,48,48,75,44,32,69,118,101,114,121,32,53,48,48,75,0,0,0,0,0,0,0,0,75,48,48,55,49,50,49,95,102,108,105,112,115,99,114,101,101,110,91,49,93,0,0,0,105,110,105,116,95,101,101,112,114,111,109,95,99,111,117,110,116,0,0,0,0,0,0,0,67,97,112,99,111,109,32,83,112,111,114,116,115,32,67,108,117,98,32,40,57,55,48,55,50,50,32,74,97,112,97,110,44,32,82,101,110,116,32,118,101,114,115,105,111,110,41,0,0,0,0,0,0,0,0,0,115,97,118,101,95,115,116,97,116,101,0,0,0,0,0,0,90,101,114,111,32,52,32,67,104,97,109,112,0,0,0,0,107,111,102,57,55,99,110,0,107,97,114,110,111,118,0,0,66,114,97,109,32,83,116,111,107,101,114,39,115,32,68,114,97,99,117,108,97,32,40,85,83,65,41,0,0,0,0,0,116,104,110,100,114,120,50,97,0,0,0,0,0,0,0,0,84,105,116,108,101,32,83,99,114,101,101,110,0,0,0,0,73,114,101,109,32,40,68,97,116,97,32,69,97,115,116,32,67,111,114,112,111,114,97,116,105,111,110,32,108,105,99,101,110,115,101,41,0,0,0,0,76,101,103,101,110,100,32,111,102,32,72,101,114,111,32,84,111,110,109,97,32,40,74,97,112,97,110,41,0,0,0,0,50,48,48,75,44,32,69,118,101,114,121,32,52,48,48,75,0,0,0,0,0,0,0,0,112,99,101,95,122,101,114,111,52,99,0,0,0,0,0,0,84,104,101,32,75,105,110,103,32,111,102,32,70,105,103,104,116,101,114,115,32,39,57,54,32,40,98,111,111,116,108,101,103,32,47,32,104,97,99,107,41,0,0,0,0,0,0,0,109,100,95,100,114,97,99,117,108,97,117,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,71,111,116,32,105,110,118,97,108,105,100,32,100,105,115,107,32,105,110,100,101,120,32,102,114,111,109,32,108,105,98,114,101,116,114,111,46,10,0,0,0,0,0,83,97,118,101,115,116,97,116,101,32,115,108,111,116,32,45,0,0,0,0,0,0,0,0,49,53,48,75,44,32,69,118,101,114,121,32,51,48,48,75,0,0,0,0,0,0,0,0,80,51,32,70,105,114,101,0,112,99,101,95,122,101,114,111,52,99,97,0,0,0,0,0,107,111,102,57,54,101,112,0,66,114,97,109,32,83,116,111,107,101,114,39,115,32,68,114,97,99,117,108,97,32,40,69,117,114,111,41,0,0,0,0,108,117,99,116,111,100,97,121,0,0,0,0,0,0,0,0,89,32,98,117,116,116,111,110,32,40,108,101,102,116,41,0,89,117,117,32,89,117,117,32,74,105,110,115,101,105,32,45,32,86,105,99,116,111,114,121,32,76,105,102,101,0,0,0,84,104,101,32,75,105,110,103,32,111,102,32,70,105,103,104,116,101,114,115,32,39,57,54,32,40,67,104,105,110,101,115,101,32,69,100,105,116,105,111,110,32,118,101,114,32,49,46,48,44,32,104,97,99,107,41,0,0,0,0,0,0,0,0,109,100,95,100,114,97,99,117,108,97,0,0,0,0,0,0,83,107,105,112,32,82,101,97,108,32,68,65,84,32,82,111,109,32,67,104,101,99,107,63,0,0,0,0,0,0,0,0,112,99,101,95,121,117,121,117,0,0,0,0,0,0,0,0,50,48,48,63,0,0,0,0,65,109,101,114,105,99,97,110,32,83,111,102,116,119,111,114,107,115,0,0,0,0,0,0,68,105,97,108,32,40,67,111,99,107,116,97,105,108,41,0,72,105,103,104,108,105,103,104,116,32,82,105,103,104,116,32,65,110,115,119,101,114,0,0,89,111,117,107,97,105,32,68,111,117,99,104,117,117,107,105,0,0,0,0,0,0,0,0,107,111,102,57,54,99,110,0,67,104,97,118,101,122,32,73,73,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,115,97,109,115,104,111,0,0,80,49,32,66,117,116,116,111,110,32,66,0,0,0,0,0,85,46,83,46,65,46,32,40,70,97,98,116,101,107,32,108,105,99,101,110,115,101,41,32,91,105,108,108,101,103,97,108,32,115,101,116,116,105,110,103,93,0,0,0,0,0,0,0,76,105,113,117,105,100,32,75,105,100,115,32,40,87,111,114,108,100,41,0,0,0,0,0,83,112,114,105,110,103,0,0,114,121,117,106,105,110,0,0,115,112,97,99,101,103,117,110,0,0,0,0,0,0,0,0,112,99,101,95,121,111,117,107,97,105,100,0,0,0,0,0,84,104,101,32,75,105,110,103,32,111,102,32,70,105,103,104,116,101,114,115,32,39,57,54,32,40,65,110,110,105,118,101,114,115,97,114,121,32,69,100,105,116,105,111,110,44,32,69,71,72,84,32,104,97,99,107,41,0,0,0,0,0,0,0,118,105,100,101,111,95,100,114,105,118,101,114,0,0,0,0,109,100,95,99,104,97,118,101,122,50,0,0,0,0,0,0,74,111,74,111,39,115,32,66,105,122,97,114,114,101,32,65,100,118,101,110,116,117,114,101,58,32,72,101,114,105,116,97,103,101,32,102,111,114,32,116,104,101,32,70,117,116,117,114,101,32,47,32,74,111,74,111,32,110,111,32,75,105,109,121,111,117,32,110,97,32,66,111,117,107,101,110,58,32,77,105,114,97,105,32,101,32,110,111,32,73,115,97,110,32,40,74,97,112,97,110,32,57,57,48,57,49,51,41,0,0,0,0,99,111,116,116,111,110,106,97,0,0,0,0,0,0,0,0,67,111,105,110,32,65,47,66,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,67,82,67,51,50,32,99,104,101,99,107,115,117,109,32,109,105,115,109,97,116,99,104,32,98,101,116,119,101,101,110,32,82,79,77,32,102,105,108,101,32,97,110,100,32,115,97,118,101,100,32,82,79,77,32,99,104,101,99,107,115,117,109,32,105,110,32,114,101,112,108,97,121,32,102,105,108,101,32,104,101,97,100,101,114,59,32,114,101,112,108,97,121,32,104,105,103,104,108,121,32,108,105,107,101,108,121,32,116,111,32,100,101,115,121,110,99,32,111,110,32,112,108,97,121,98,97,99,107,46,10,0,114,101,103,117,108,117,115,111,0,0,0,0,0,0,0,0,68,0,0,0,101,0,0,0,99,0,0,0,101,0,0,0,109,0,0,0,98,0,0,0,101,0,0,0,114,0,0,0,0,0,0,0,0,0,0,0,68,105,97,108,0,0,0,0,84,105,109,101,32,83,99,97,110,110,101,114,32,40,115,101,116,32,49,44,32,83,121,115,116,101,109,32,49,54,65,44,32,70,68,49,48,56,57,66,32,51,49,55,45,48,48,50,52,41,0,0,0,0,0,0,84,105,109,101,32,77,111,100,101,0,0,0,0,0,0,0,120,49,46,48,0,0,0,0,66,117,98,98,108,101,32,50,48,48,48,0,0,0,0,0,51,32,67,111,105,110,115,32,83,116,97,114,116,44,32,49,32,67,111,105,110,32,67,111,110,116,105,110,117,101,0,0,83,116,97,114,116,32,52,32,67,111,110,116,105,110,117,101,32,51,0,0,0,0,0,0,83,111,117,110,100,76,97,116,99,104,82,101,112,108,121,77,97,120,0,0,0,0,0,0,88,101,118,105,111,117,115,32,45,32,70,97,114,100,114,97,117,116,32,68,101,110,115,101,116,115,117,0,0,0,0,0,107,111,102,57,54,97,101,0,83,111,117,110,100,32,84,121,112,101,0,0,0,0,0,0,66,111,120,105,110,103,32,76,101,103,101,110,100,115,32,111,102,32,116,104,101,32,82,105,110,103,32,40,85,83,65,41,0,0,0,0,0,0,0,0,51,215,32,80,117,110,99,104,0,0,0,0,0,0,0,0,72,121,112,101,114,32,70,108,105,112,32,47,32,70,105,114,101,32,50,32,40,67,111,99,107,116,97,105,108,41,0,0,84,104,117,110,100,101,114,32,38,32,76,105,103,104,116,110,105,110,103,0,0,0,0,0,66,97,108,108,32,66,111,121,0,0,0,0,0,0,0,0,104,97,99,107,32,40,84,119,111,45,66,105,116,32,83,99,111,114,101,41,0,0,0,0,86,97,108,117,101,32,55,0,104,101,114,111,100,107,117,0,112,99,101,95,120,101,118,105,111,117,115,0,0,0,0,0,84,104,101,32,75,105,110,103,32,111,102,32,70,105,103,104,116,101,114,115,32,83,112,101,99,105,97,108,32,69,100,105,116,105,111,110,32,50,48,48,52,32,80,108,117,115,32,40,98,111,111,116,108,101,103,41,0,0,0,0,0,0,0,0,109,100,95,98,111,120,105,110,103,108,103,0,0,0,0,0,65,32,51,47,49,32,66,32,49,47,51,0,0,0,0,0,71,97,108,97,120,105,97,110,32,40,78,97,109,99,111,32,115,101,116,32,50,41,0,0,73,79,67,104,105,112,67,117,115,116,111,109,67,111,109,109,97,110,100,0,0,0,0,0,107,111,118,49,48,48,0,0,74,97,112,97,110,32,40,50,32,98,117,116,116,111,110,115,41,0,0,0,0,0,0,0,66,108,111,100,105,97,0,0,86,97,108,117,101,32,54,0,100,105,110,111,112,105,99,0,87,111,114,108,100,32,74,111,99,107,101,121,0,0,0,0,107,102,50,107,52,112,108,115,0,0,0,0,0,0,0,0,175,48,0,0,164,48,0,0,186,48,0,0,39,89,0,0,92,99,0,0,251,103,0,0,218,125,0,0,32,0,0,0,45,0,0,0,32,0,0,0,116,0,0,0,104,0,0,0,101,0,0,0,32,0,0,0,108,0,0,0,97,0,0,0,115,0,0,0,116,0,0,0,32,0,0,0,99,0,0,0,111,0,0,0,117,0,0,0,110,0,0,0,116,0,0,0,32,0,0,0,100,0,0,0,111,0,0,0,119,0,0,0,110,0,0,0,0,0,0,0,81,0,0,0,117,0,0,0,105,0,0,0,122,0,0,0,32,0,0,0,68,0,0,0,97,0,0,0,105,0,0,0,115,0,0,0,111,0,0,0,117,0,0,0,115,0,0,0,97,0,0,0,32,0,0,0,83,0,0,0,101,0,0,0,110,0,0,0,32,0,0,0,45,0,0,0,32,0,0,0,84,0,0,0,104,0,0,0,101,0,0,0,32,0,0,0,76,0,0,0,97,0,0,0,115,0,0,0,116,0,0,0,32,0,0,0,67,0,0,0,111,0,0,0,117,0,0,0,110,0,0,0,116,0,0,0,32,0,0,0,68,0,0,0,111,0,0,0,119,0,0,0,110,0,0,0,32,0,0,0,40,0,0,0,78,0,0,0,71,0,0,0,77,0,0,0,45,0,0,0,48,0,0,0,50,0,0,0,51,0,0,0,41,0,0,0,40,0,0,0,78,0,0,0,71,0,0,0,72,0,0,0,45,0,0,0,48,0,0,0,50,0,0,0,51,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,66,111,111,103,101,114,109,97,110,32,45,32,65,32,80,105,99,107,32,97,110,100,32,70,108,105,99,107,32,65,100,118,101,110,116,117,114,101,32,40,85,83,65,41,0,0,0,0,71,97,109,101,32,84,111,115,104,111,107,97,110,32,40,74,112,110,44,32,82,101,118,46,32,65,41,0,0,0,0,0,83,104,111,119,32,70,114,97,109,101,114,97,116,101,0,0,109,105,114,114,111,114,101,100,95,114,101,112,101,97,116,0,85,83,65,32,40,54,32,98,117,116,116,111,110,115,41,0,75,48,48,55,49,50,49,95,102,108,105,112,115,99,114,101,101,110,91,48,93,0,0,0,99,115,99,108,117,98,106,114,0,0,0,0,0,0,0,0,86,97,108,117,101,32,53,0,108,111,97,100,95,115,116,97,116,101,0,0,0,0,0,0,112,99,101,95,119,106,111,99,107,101,121,0,0,0,0,0,84,104,101,32,75,105,110,103,32,111,102,32,70,105,103,104,116,101,114,115,32,50,48,48,50,32,40,80,108,97,121,83,116,97,116,105,111,110,32,50,32,118,101,114,32,48,46,52,44,32,69,71,72,84,32,104,97,99,107,41,0,0,0,0,109,100,95,98,111,111,103,101,114,117,0,0,0,0,0,0,71,88,48,55,51,0,0,0,65,108,112,104,97,45,78,117,109,101,114,105,99,0,0,0,56,32,67,111,105,110,115,32,49,32,80,108,97,121,0,0,115,97,109,112,108,101,95,115,101,108,0,0,0,0,0,0,68,114,101,97,109,32,83,111,99,99,101,114,32,39,57,52,0,0,0,0,0,0,0,0,108,111,104,116,106,0,0,0,67,97,118,101,109,97,110,32,78,105,110,106,97,32,40,87,111,114,108,100,32,118,101,114,32,49,41,0,0,0,0,0,49,48,48,48,107,32,79,110,108,121,0,0,0,0,0,0,86,97,108,117,101,32,52,0,87,111,114,108,100,32,67,105,114,99,117,105,116,0,0,0,50,48,48,55,0,0,0,0,73,110,116,101,114,112,108,97,121,0,0,0,0,0,0,0,77,83,77,54,50,57,53,91,110,67,104,105,112,93,0,0,82,101,116,114,111,65,114,99,104,58,32,66,83,82,77,58,32,37,115,10,0,0,0,0,74,111,101,32,38,32,77,97,99,32,82,101,116,117,114,110,115,32,40,87,111,114,108,100,44,32,86,101,114,115,105,111,110,32,49,46,48,44,32,49,57,57,52,46,48,53,46,49,57,41,0,0,0,0,0,0,56,48,48,107,32,97,110,100,32,50,48,48,48,107,32,111,110,108,121,0,0,0,0,0,86,97,108,117,101,32,51,0,112,99,101,95,119,99,105,114,99,117,105,116,0,0,0,0,107,102,50,107,50,112,115,50,0,0,0,0,0,0,0,0,66,111,111,103,101,114,109,97,110,32,45,32,65,32,80,105,99,107,32,97,110,100,32,70,108,105,99,107,32,65,100,118,101,110,116,117,114,101,32,40,69,117,114,111,41,0,0,0,50,53,53,0,0,0,0,0,83,105,103,110,97,116,114,111,110,32,85,83,65,0,0,0,53,48,48,107,32,97,110,100,32,101,118,101,114,121,32,49,48,48,48,107,0,0,0,0,86,97,108,117,101,32,50,0,87,111,114,108,100,32,66,101,97,99,104,32,86,111,108,108,101,121,0,0,0,0,0,0,84,104,101,32,75,105,110,103,32,111,102,32,70,105,103,104,116,101,114,115,32,50,48,48,50,32,83,117,112,101,114,32,40,98,111,111,116,108,101,103,41,0,0,0,0,0,0,0,65,99,116,45,70,97,110,99,101,114,32,67,121,98,101,114,110,101,116,105,99,107,32,72,121,112,101,114,32,87,101,97,112,111,110,32,40,87,111,114,108,100,32,114,101,118,105,115,105,111,110,32,49,41,0,0,109,100,95,98,111,111,103,101,114,0,0,0,0,0,0,0,51,48,48,107,32,97,110,100,32,101,118,101,114,121,32,56,48,48,107,0,0,0,0,0,86,97,108,117,101,32,49,0,112,99,101,95,119,98,101,97,99,104,0,0,0,0,0,0,107,102,50,107,50,112,108,99,0,0,0,0,0,0,0,0,66,111,110,107,101,114,115,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,49,48,50,57,41,0,0,0,0,0,0,83,105,100,101,32,80,111,99,107,101,116,32,40,74,97,112,97,110,41,0,0,0,0,0,65,117,116,111,32,83,104,111,116,0,0,0,0,0,0,0,86,97,108,117,101,32,48,0,87,111,110,100,101,114,32,77,111,109,111,0,0,0,0,0,84,104,101,32,75,105,110,103,32,111,102,32,70,105,103,104,116,101,114,115,32,50,48,48,50,32,80,108,117,115,32,40,98,111,111,116,108,101,103,32,115,101,116,32,51,41,0,0,67,104,97,110,45,62,112,97,110,0,0,0,0,0,0,0,109,100,95,98,111,110,107,101,114,115,112,49,0,0,0,0,80,49,32,66,117,116,116,111,110,32,65,0,0,0,0,0,112,49,32,102,105,114,101,32,49,0,0,0,0,0,0,0,69,118,101,114,121,116,105,109,101,0,0,0,0,0,0,0,83,112,101,99,105,97,108,32,67,111,117,114,115,101,0,0,67,97,98,105,110,101,116,0,74,97,112,97,110,32,91,105,108,108,101,103,97,108,32,115,101,116,116,105,110,103,93,0,67,114,117,100,101,32,66,117,115,116,101,114,32,40,87,111,114,108,100,32,70,85,32,118,101,114,115,105,111,110,41,0,0,0,0,0,0,0,0,0,108,105,113,117,105,100,107,0,73,110,105,116,105,97,108,32,83,101,97,115,111,110,0,0,80,111,98,121,115,0,0,0,84,97,105,116,111,32,76,111,103,111,0,0,0,0,0,0,83,105,108,101,110,116,32,68,114,97,103,111,110,32,40,85,83,41,0,0,0,0,0,0,78,101,103,114,111,0,0,0,112,99,101,95,119,111,110,100,101,114,109,0,0,0,0,0,107,102,50,107,50,112,108,98,0,0,0,0,0,0,0,0,97,117,100,105,111,95,118,111,108,117,109,101,0,0,0,0,66,111,110,107,101,114,115,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,49,48,50,53,41,0,0,0,0,0,0,106,111,106,111,98,97,114,49,0,0,0,0,0,0,0,0,67,111,116,116,111,110,32,40,115,101,116,32,50,44,32,74,97,112,97,110,44,32,82,101,118,32,66,44,32,70,68,49,48,57,52,32,51,49,55,45,48,49,55,57,98,41,41,0,0,0,0,0,0,0,0,0,105,110,116,101,114,114,117,112,116,95,101,110,97,98,108,101,0,0,0,0,0,0,0,0,82,101,103,117,108,117,115,32,40,51,49,53,45,53,48,51,51,44,32,114,101,118,46,32,65,41,0,0,0,0,0,0,78,0,0,0,111,0,0,0,118,0,0,0,101,0,0,0,109,0,0,0,98,0,0,0,101,0,0,0,114,0,0,0,0,0,0,0,0,0,0,0,79,110,99,101,0,0,0,0,77,101,100,97,108,115,32,84,97,98,108,101,0,0,0,0,86,97,112,111,114,32,84,114,97,105,108,32,45,32,72,121,112,101,114,32,79,102,102,101,110,99,101,32,70,111,114,109,97,116,105,111,110,32,40,87,111,114,108,100,32,114,101,118,105,115,105,111,110,32,51,41,0,0,0,0,0,0,0,0,98,117,98,108,50,48,48,48,0,0,0,0,0,0,0,0,51,32,67,111,105,110,115,32,83,116,97,114,116,44,32,50,32,67,111,105,110,115,32,67,111,110,116,105,110,117,101,0,85,112,114,105,103,104,116,32,50,32,67,111,110,116,114,111,108,108,101,114,115,0,0,0,83,111,117,110,100,76,97,116,99,104,82,101,112,108,121,73,110,100,101,120,0,0,0,0,87,105,110,110,105,110,103,32,83,104,111,116,0,0,0,0,84,104,101,32,75,105,110,103,32,111,102,32,70,105,103,104,116,101,114,115,32,50,48,48,49,32,80,108,117,115,32,40,115,101,116,32,49,44,32,98,111,111,116,108,101,103,32,47,32,104,97,99,107,41,0,0,109,100,95,98,111,110,107,101,114,115,112,50,0,0,0,0,102,105,114,101,32,54,0,0,66,111,110,117,115,32,79,99,99,117,114,114,101,110,99,101,0,0,0,0,0,0,0,0,50,48,48,51,0,0,0,0,70,97,107,101,84,114,97,99,107,66,97,108,108,88,0,0,77,115,46,32,80,97,99,45,77,97,110,32,72,101,97,114,116,32,66,117,114,110,0,0,85,112,114,105,103,104,116,32,49,32,67,111,110,116,114,111,108,108,101,114,0,0,0,0,83,101,97,116,111,110,103,114,111,118,101,32,76,116,100,32,40,67,114,111,119,110,32,108,105,99,101,110,115,101,41,0,112,99,101,95,119,105,110,115,104,111,116,0,0,0,0,0,107,102,50,107,49,112,108,115,0,0,0,0,0,0,0,0,66,111,110,107,101,114,115,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,49,48,48,52,41,0,0,0,0,0,0,65,32,52,47,49,32,66,32,49,47,52,0,0,0,0,0,110,89,77,50,54,49,50,80,111,115,105,116,105,111,110,0,80,49,32,82,103,104,116,32,83,116,105,99,107,32,82,105,103,104,116,0,0,0,0,0,68,114,118,83,116,97,114,83,99,114,111,108,108,89,0,0,75,0,0,0,110,0,0,0,105,0,0,0,103,0,0,0,104,0,0,0,116,0,0,0,115,0,0,0,32,0,0,0,111,0,0,0,102,0,0,0,32,0,0,0,86,0,0,0,97,0,0,0,108,0,0,0,111,0,0,0,117,0,0,0,114,0,0,0,0,0,0,0,9,78,0,0,253,86,0,0,38,98,0,0,0,125,0,0,0,0,0,0,9,78,0,0,253,86,0,0,24,98,0,0,170,126,0,0,32,0,0,0,40,0,0,0,86,0,0,0,49,0,0,0,49,0,0,0,53,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,112,99,101,95,98,108,111,100,105,97,0,0,0,0,0,0,67,97,100,105,108,108,97,99,115,32,38,32,68,105,110,111,115,97,117,114,115,32,40,57,51,48,50,48,49,32,85,83,65,41,0,0,0,0,0,0,87,97,108,108,97,98,121,33,33,32,45,32,85,115,97,103,105,32,110,111,32,75,117,110,105,32,110,111,32,75,97,110,103,97,114,111,111,32,82,97,99,101,0,0,0,0,0,0,84,104,101,32,75,105,110,103,32,111,102,32,70,105,103,104,116,101,114,115,32,50,48,48,49,32,80,108,117,115,32,40,115,101,116,32,50,44,32,98,111,111,116,108,101,103,32,47,32,104,97,99,107,41,0,0,81,117,105,122,32,68,97,105,115,111,117,115,97,32,83,101,110,32,45,32,84,104,101,32,76,97,115,116,32,67,111,117,110,116,32,68,111,119,110,32,40,78,71,77,45,48,50,51,41,40,78,71,72,45,48,50,51,41,0,0,0,0,0,0,109,100,95,98,111,110,107,101,114,115,112,51,0,0,0,0,99,104,105,112,45,62,108,102,111,95,97,109,95,99,110,116,0,0,0,0,0,0,0,0,84,104,117,110,100,101,114,32,90,111,110,101,32,40,87,111,114,108,100,41,0,0,0,0,80,49,32,82,103,104,116,32,83,116,105,99,107,32,76,101,102,116,0,0,0,0,0,0,109,100,95,103,97,109,101,116,111,0,0,0,0,0,0,0,67,111,110,102,105,103,32,83,97,118,101,32,79,110,32,69,120,105,116,0,0,0,0,0,83,104,97,114,101,100,32,67,114,101,100,105,116,115,0,0,114,101,112,101,97,116,0,0,75,48,48,55,49,50,49,32,67,111,110,116,114,111,108,32,82,65,77,0,0,0,0,0,67,97,112,99,111,109,32,83,112,111,114,116,115,32,67,108,117,98,32,40,57,55,48,55,50,50,32,74,97,112,97,110,41,0,0,0,0,0,0,0,51,32,80,108,97,121,101,114,115,32,51,32,83,104,111,111,116,101,114,115,0,0,0,0,104,111,108,100,95,102,97,115,116,95,102,111,114,119,97,114,100,0,0,0,0,0,0,0,112,99,101,95,119,97,108,108,97,98,121,0,0,0,0,0,107,102,50,107,49,112,97,0,66,111,110,107,101,114,115,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,53,48,51,41,0,0,0,0,0,0,84,104,117,110,100,101,114,32,67,114,111,115,115,32,73,73,32,40,87,111,114,108,100,41,0,0,0,0,0,0,0,0,77,97,104,106,111,110,103,0,115,97,109,112,108,101,95,112,111,115,0,0,0,0,0,0,100,115,111,99,99,114,57,52,0,0,0,0,0,0,0,0,80,49,32,82,103,104,116,32,83,116,105,99,107,32,68,111,119,110,0,0,0,0,0,0,118,111,105,99,101,45,62,115,116,101,112,0,0,0,0,0,83,116,97,103,101,32,38,32,87,101,97,112,111,110,32,83,101,108,101,99,116,0,0,0,51,32,80,108,97,121,101,114,115,32,49,32,83,104,111,111,116,101,114,0,0,0,0,0,87,97,108,107,117,101,114,101,32,110,111,32,68,101,110,115,101,116,115,117,0,0,0,0,70,65,67,69,32,67,111,114,112,111,114,97,116,105,111,110,0,0,0,0,0,0,0,0,109,100,95,98,111,110,107,101,114,115,112,52,0,0,0,0,37,48,50,120,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,65,83,82,77,58,32,37,115,10,0,0,0,0,80,49,32,82,103,104,116,32,83,116,105,99,107,32,85,112,0,0,0,0,0,0,0,0,83,97,118,101,115,116,97,116,101,32,115,108,111,116,32,43,0,0,0,0,0,0,0,0,77,101,109,111,114,121,32,67,104,101,99,107,0,0,0,0,50,32,80,108,97,121,101,114,115,32,49,32,83,104,111,111,116,101,114,0,0,0,0,0,112,99,101,95,118,97,108,107,121,114,105,101,0,0,0,0,84,114,101,97,115,117,114,101,32,111,102,32,116,104,101,32,67,97,114,114,105,98,101,97,110,32,40,80,114,111,116,111,116,121,112,101,41,0,0,0,75,97,114,110,111,118,32,40,85,83,44,32,114,101,118,32,53,41,0,0,0,0,0,0,66,111,110,107,101,114,115,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,51,50,56,41,0,0,0,0,0,0,79,114,98,105,116,114,111,110,0,0,0,0,0,0,0,0,87,97,105,32,87,97,105,32,77,97,104,106,111,110,103,32,45,32,89,117,107,97,105,110,97,32,74,97,110,121,117,117,32,84,97,99,104,105,0,0,116,111,116,99,97,114,105,98,0,0,0,0,0,0,0,0,51,51,0,0,0,0,0,0,109,100,95,98,111,110,107,101,114,115,112,53,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,86,65,82,73,65,66,76,69,83,46,10,0,0,0,0,0,0,73,110,116,114,111,32,77,117,115,105,99,0,0,0,0,0,83,116,97,114,116,32,49,32,67,111,110,116,105,110,117,101,32,49,0,0,0,0,0,0,112,99,101,95,119,97,105,119,97,105,109,106,0,0,0,0,66,97,110,103,32,50,32,66,117,115,116,101,114,115,32,40,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,66,111,110,107,101,114,115,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,80,50,32,72,111,108,100,0,110,82,97,109,82,101,97,100,65,100,100,114,101,115,115,0,84,104,101,32,82,101,97,108,32,71,104,111,115,116,98,117,115,116,101,114,115,32,40,85,83,32,51,32,80,108,97,121,101,114,115,41,0,0,0,0,49,53,48,48,107,32,51,48,48,48,107,0,0,0,0,0,83,116,97,114,116,32,50,32,67,111,110,116,105,110,117,101,32,50,0,0,0,0,0,0,87,45,114,105,110,103,32,45,32,84,104,101,32,68,111,117,98,108,101,32,82,105,110,103,115,0,0,0,0,0,0,0,98,50,98,117,115,116,101,114,0,0,0,0,0,0,0,0,109,100,95,98,111,110,107,101,114,115,0,0,0,0,0,0,97,111,102,0,0,0,0,0,67,111,105,110,32,49,0,0,80,108,97,121,101,114,32,115,101,108,101,99,116,0,0,0,68,73,80,32,115,119,105,116,99,104,32,116,101,115,116,0,84,97,105,119,97,110,32,40,76,105,97,110,103,32,72,119,97,32,108,105,99,101,110,115,101,41,0,0,0,0,0,0,50,117,0,0,80,91,0,0,18,87,0,0,32,0,0,0,4,104,0,0,73,81,0,0,110,48,0,0,32,0,0,0,218,85,0,0,124,84,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,65,0,0,0,104,0,0,0,32,0,0,0,69,0,0,0,105,0,0,0,107,0,0,0,111,0,0,0,117,0,0,0,32,0,0,0,110,0,0,0,111,0,0,0,32,0,0,0,75,0,0,0,111,0,0,0,115,0,0,0,104,0,0,0,105,0,0,0,101,0,0,0,110,0,0,0,0,0,0,0,0,0,0,0,72,97,114,100,101,115,116,63,0,0,0,0,0,0,0,0,115,105,108,101,110,116,100,117,0,0,0,0,0,0,0,0,83,112,101,99,105,97,108,32,67,114,105,109,105,110,97,108,32,73,110,118,101,115,116,105,103,97,116,105,111,110,32,40,78,101,103,114,111,32,98,111,111,116,108,101,103,41,0,0,83,116,97,114,116,32,51,32,67,111,110,116,105,110,117,101,32,51,0,0,0,0,0,0,112,99,101,95,119,114,105,110,103,0,0,0,0,0,0,0,67,104,111,117,116,101,116,115,117,32,66,114,105,107,105,110,39,103,101,114,32,45,32,73,114,111,110,32,99,108,97,100,32,40,80,114,111,116,111,116,121,112,101,44,32,111,108,100,101,114,41,0,0,0,0,0,57,57,32,40,67,104,101,97,116,41,0,0,0,0,0,0,70,117,110,107,121,32,74,101,116,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,66,111,110,97,110,122,97,32,66,114,111,115,46,32,40,85,83,65,44,32,75,111,114,41,0,0,0,0,0,0,0,0,97,117,100,105,111,95,114,97,116,101,95,99,111,110,116,114,111,108,95,100,101,108,116,97,0,0,0,0,0,0,0,0,74,0,0,0,111,0,0,0,74,0,0,0,111,0,0,0,39,0,0,0,115,0,0,0,32,0,0,0,66,0,0,0,105,0,0,0,122,0,0,0,97,0,0,0,114,0,0,0,114,0,0,0,101,0,0,0,32,0,0,0,65,0,0,0,100,0,0,0,118,0,0,0,101,0,0,0,110,0,0,0,116,0,0,0,117,0,0,0,114,0,0,0,101,0,0,0,0,0,0,0,184,48,0,0,231,48,0,0,184,48,0,0,231,48,0,0,110,48,0,0,32,0,0,0,71,89,0,0,153,89,0,0,106,48,0,0,146,81,0,0,122,150,0,0,58,0,0,0,32,0,0,0,42,103,0,0,101,103,0,0,120,48,0,0,110,48,0,0,122,144,0,0,35,117,0,0,32,0,0,0,40,0,0,0,69,0,0,0,117,0,0,0,114,0,0,0,111,0,0,0,32,0,0,0,57,0,0,0,57,0,0,0,48,0,0,0,57,0,0,0,50,0,0,0,55,0,0,0,44,0,0,0,32,0,0,0,78,0,0,0,79,0,0,0,32,0,0,0,67,0,0,0,68,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,99,111,116,116,111,110,106,0,102,108,105,112,115,99,114,101,101,110,0,0,0,0,0,0,65,32,49,67,47,52,80,32,32,66,32,52,67,47,49,80,0,0,0,0,0,0,0,0,116,105,109,101,115,99,97,110,49,0,0,0,0,0,0,0,67,114,101,100,105,116,115,32,111,110,108,121,0,0,0,0,80,111,112,39,115,32,80,111,112,39,115,0,0,0,0,0,51,32,67,111,105,110,115,32,83,116,97,114,116,44,32,51,32,67,111,105,110,115,32,67,111,110,116,105,110,117,101,0,83,116,97,114,116,32,52,32,67,111,110,116,105,110,117,101,32,52,0,0,0,0,0,0,83,111,117,110,100,76,97,116,99,104,82,101,112,108,121,0,86,111,108,102,105,101,100,0,0,0,0,0,0,0,0,0,105,114,111,110,99,108,97,100,111,0,0,0,0,0,0,0,70,114,101,101,32,80,108,97,121,32,40,105,102,32,67,111,105,110,32,65,32,116,111,111,41,0,0,0,0,0,0,0,100,101,99,111,49,54,95,115,111,117,110,100,108,97,116,99,104,0,0,0,0,0,0,0,109,100,95,98,110,122,97,98,114,111,115,117,0,0,0,0,102,105,114,101,32,53,0,0,65,32,49,67,47,51,80,32,32,66,32,51,67,47,49,80,0,0,0,0,0,0,0,0,116,104,117,110,100,101,114,108,0,0,0,0,0,0,0,0,98,97,108,108,98,111,121,0,66,108,111,99,107,32,66,108,111,99,107,32,40,98,111,111,116,108,101,103,41,0,0,0,109,115,104,101,97,114,116,98,0,0,0,0,0,0,0,0,103,104,111,115,116,98,0,0,83,116,97,114,116,32,49,32,67,111,110,116,105,110,117,101,32,50,0,0,0,0,0,0,72,101,114,111,32,105,110,32,116,104,101,32,67,97,115,116,108,101,32,111,102,32,68,111,111,109,32,40,68,75,32,99,111,110,118,101,114,115,105,111,110,41,0,0,0,0,0,0,112,99,101,95,118,111,108,102,105,101,100,0,0,0,0,0,67,104,111,117,116,101,116,115,117,32,66,114,105,107,105,110,39,103,101,114,32,45,32,73,114,111,110,32,99,108,97,100,32,40,80,114,111,116,111,116,121,112,101,41,0,0,0,0,66,111,110,97,110,122,97,32,66,114,111,115,46,32,40,69,117,114,111,44,32,74,112,110,41,0,0,0,0,0,0,0,79,0,0,0,99,0,0,0,116,0,0,0,111,0,0,0,98,0,0,0,101,0,0,0,114,0,0,0,0,0,0,0,84,117,109,98,108,101,32,80,111,112,32,40,74,97,112,97,110,41,0,0,0,0,0,0,51,48,107,32,97,110,100,32,57,48,107,0,0,0,0,0,68,114,118,83,116,97,114,83,99,114,111,108,108,88,0,0,51,48,48,48,48,48,32,112,111,105,110,116,115,0,0,0,75,110,105,103,104,116,115,32,111,102,32,86,97,108,111,117,114,32,45,32,83,97,110,103,111,107,117,32,83,101,110,107,105,32,40,86,49,49,53,41,0,0,0,0,0,0,0,0,66,105,107,107,117,114,105,109,97,110,32,87,111,114,108,100,32,40,65,108,116,41,0,0,83,116,97,114,116,32,50,32,67,111,110,116,105,110,117,101,32,51,0,0,0,0,0,0,100,105,110,111,117,0,0,0,86,105,111,108,101,110,116,32,83,111,108,100,105,101,114,0,0,0,0,0,0,0,0,0,113,117,105,122,100,97,105,115,0,0,0,0,0,0,0,0,109,100,95,98,110,122,97,98,114,111,115,49,0,0,0,0,99,104,105,112,45,62,105,110,115,116,118,111,108,95,114,0,66,111,111,103,105,101,32,87,105,110,103,115,32,40,65,115,105,97,32,118,49,46,53,44,32,57,50,46,49,50,46,48,55,41,0,0,0,0,0,0,70,108,121,105,110,103,32,69,100,103,101,0,0,0,0,0,67,104,105,112,45,62,76,97,115,116,82,101,103,105,115,116,101,114,0,0,0,0,0,0,71,80,85,32,83,99,114,101,101,110,115,104,111,116,115,0,99,108,97,109,112,95,116,111,95,101,100,103,101,0,0,0,99,115,99,108,117,98,106,0,83,116,97,114,116,32,51,32,67,111,110,116,105,110,117,101,32,52,0,0,0,0,0,0,49,57,57,49,0,0,0,0,116,111,103,103,108,101,95,102,97,115,116,95,102,111,114,119,97,114,100,0,0,0,0,0,112,99,101,95,118,105,111,108,101,110,116,115,0,0,0,0,66,111,110,97,110,122,97,32,66,114,111,115,46,32,40,69,117,114,111,44,32,74,112,110,44,32,82,101,118,46,32,65,41,0,0,0,0,0,0,0,116,104,110,100,114,120,50,0,67,104,105,110,97,32,84,105,108,101,115,0,0,0,0,0,56,48,107,32,97,110,100,32])
.concat([101,118,101,114,121,32,49,50,48,107,0,0,0,0,0,0,115,111,117,110,100,95,105,114,113,0,0,0,0,0,0,0,84,104,117,110,100,101,114,32,66,108,97,115,116,101,114,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,108,111,104,116,0,0,0,0,70,66,32,65,108,112,104,97,0,0,0,0,0,0,0,0,82,46,87,68,84,0,0,0,83,116,97,114,116,32,52,32,67,111,110,116,105,110,117,101,32,53,0,0,0,0,0,0,37,48,56,120,58,32,71,52,45,120,32,85,110,100,101,102,105,110,101,100,32,84,104,117,109,98,32,105,110,115,116,114,117,99,116,105,111,110,58,32,37,48,52,120,10,0,0,0,86,105,103,105,108,97,110,116,101,0,0,0,0,0,0,0,73,100,111,108,32,77,97,104,106,111,110,103,32,45,32,102,105,110,97,108,32,114,111,109,97,110,99,101,32,50,32,40,67,68,32,116,111,32,77,86,83,32,67,111,110,118,101,114,115,105,111,110,41,0,0,0,80,49,32,72,111,108,100,0,109,100,95,98,110,122,97,98,114,111,115,0,0,0,0,0,99,104,105,112,45,62,115,116,97,114,116,0,0,0,0,0,110,89,77,90,50,56,48,66,83,116,97,116,117,115,0,0,82,101,116,114,111,65,114,99,104,58,32,83,97,118,105,110,103,32,83,117,102,97,109,105,32,116,117,114,98,111,32,65,47,66,32,82,65,77,46,10,0,0,0,0,0,0,0,0,82,111,104,103,97,32,65,114,109,111,114,32,70,111,114,99,101,32,40,65,115,105,97,47,69,117,114,111,112,101,32,118,51,46,48,32,83,101,116,32,49,41,0,0,0,0,0,0,82,45,62,119,97,105,95,115,116,97,116,101,0,0,0,0,99,107,111,110,103,0,0,0,90,101,114,111,32,87,105,110,103,32,40,50,32,112,108,97,121,101,114,32,115,105,109,117,108,116,97,110,101,111,117,115,32,118,101,114,46,41,0,0,65,114,109,101,100,32,80,111,108,105,99,101,32,66,97,116,114,105,100,101,114,32,40,85,46,83,46,65,46,41,32,40,70,114,105,32,70,101,98,32,49,51,32,49,57,57,56,41,0,0,0,0,0,0,0,0,112,99,101,95,118,105,103,105,108,97,110,116,0,0,0,0,102,114,50,99,104,0,0,0,70,105,120,69,105,103,104,116,32,40,75,111,114,101,97,44,32,84,97,105,116,111,32,108,105,99,101,110,115,101,41,0,0,0,0,0,0,0,0,0,66,111,100,121,32,67,111,117,110,116,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,51,48,56,41,0,0,0,105,110,102,111,45,62,99,117,114,95,108,105,109,105,116,0,84,105,103,101,114,32,72,101,108,105,32,40,74,97,112,97,110,41,0,0,0,0,0,0,84,0,0,0,101,0,0,0,107,0,0,0,105,0,0,0,32,0,0,0,80,0,0,0,97,0,0,0,107,0,0,0,105,0,0,0,0,0,0,0,23,109,0,0,51,129,0,0,178,48,0,0,252,48,0,0,224,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,105,112,105,32,38,32,66,105,98,105,115,32,47,32,87,104,111,111,112,101,101,33,33,32,40,90,56,48,32,115,111,117,110,100,32,99,112,117,44,32,115,101,116,32,50,41,0,0,0,0,0,0,0,0,0,66,97,116,115,117,103,117,110,32,40,83,112,101,99,105,97,108,32,86,101,114,46,41,0,0,0,0,0,0,0,0,0,86,105,99,116,111,114,121,32,82,117,110,0,0,0,0,0,67,0,0,0,114,0,0,0,111,0,0,0,117,0,0,0,99,0,0,0,104,0,0,0,105,0,0,0,110,0,0,0,103,0,0,0,32,0,0,0,84,0,0,0,105,0,0,0,103,0,0,0,101,0,0,0,114,0,0,0,32,0,0,0,72,0,0,0,105,0,0,0,100,0,0,0,100,0,0,0,101,0,0,0,110,0,0,0,32,0,0,0,68,0,0,0,114,0,0,0,97,0,0,0,103,0,0,0,111,0,0,0,110,0,0,0,32,0,0,0,50,0,0,0,48,0,0,0,48,0,0,0,51,0,0,0,32,0,0,0,40,0,0,0,115,0,0,0,101,0,0,0,116,0,0,0,32,0,0,0,50,0,0,0,41,0,0,0,0,0,0,0,229,129,0,0,78,134,0,0,207,133,0,0,141,159,0,0,0,0,0,0,0,0,0,0,0,0,0,0,109,100,95,98,111,100,121,99,111,112,50,0,0,0,0,0,75,48,53,49,54,52,57,32,67,104,97,110,110,101,108,32,108,105,115,116,0,0,0,0,65,32,49,67,47,50,80,32,32,66,32,50,67,47,49,80,0,0,0,0,0,0,0,0,68,0,0,0,111,0,0,0,103,0,0,0,121,0,0,0,117,0,0,0,117,0,0,0,110,0,0,0,0,0,0,0,68,0,0,0,111,0,0,0,103,0,0,0,121,0,0,0,117,0,0,0,117,0,0,0,110,0,0,0,32,0,0,0,201,48,0,0,173,48,0,0,229,48,0,0,252,48,0,0,243,48,0,0,1,255,0,0,1,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,110,80,114,101,118,105,111,117,115,79,107,105,66,97,110,107,0,0,0,0,0,0,0,0,100,105,101,116,103,111,101,0,66,97,116,116,108,101,32,71,97,114,101,103,103,97,32,45,32,84,121,112,101,32,50,32,40,67,104,105,110,97,32,47,32,68,101,110,109,97,114,107,63,41,32,40,84,117,101,32,65,112,114,32,50,32,49,57,57,54,41,0,0,0,0,0,102,105,114,101,115,104,114,107,100,0,0,0,0,0,0,0,69,120,116,114,97,32,72,97,114,100,0,0,0,0,0,0,103,104,111,120,106,0,0,0,112,99,101,95,118,105,99,116,111,114,121,114,0,0,0,0,67,114,111,117,99,104,105,110,103,32,84,105,103,101,114,32,72,105,100,100,101,110,32,68,114,97,103,111,110,32,50,48,48,51,32,40,115,101,116,32,50,41,0,0,0,0,0,0,66,111,100,121,32,67,111,117,110,116,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,51,48,51,41,0,0,0,118,105,109,97,110,97,110,0,79,117,116,32,90,111,110,101,32,40,115,101,116,32,50,41,0,0,0,0,0,0,0,0,66,97,116,116,108,101,32,66,97,107,114,97,105,100,32,45,32,85,110,108,105,109,105,116,101,100,32,86,101,114,115,105,111,110,32,40,74,97,112,97,110,41,32,40,84,117,101,32,74,117,110,32,56,32,49,57,57,57,41,0,0,0,0,0,101,101,112,114,111,109,95,114,101,97,100,95,97,100,100,114,101,115,115,0,0,0,0,0,72,101,108,108,102,105,114,101,32,40,49,80,32,86,101,114,46,41,0,0,0,0,0,0,86,101,105,103,117,101,115,32,45,32,84,97,99,116,105,99,97,108,32,71,108,97,100,105,97,116,111,114,0,0,0,0,99,116,104,100,50,107,51,97,0,0,0,0,0,0,0,0,109,100,95,98,111,100,121,99,111,112,51,0,0,0,0,0,190,117,0,0,168,152,0,0,84,155,0,0,213,108,0,0,39,89,0,0,92,79,0,0,38,98,0,0,32,0,0,0,45,0,0,0,32,0,0,0,107,0,0,0,105,0,0,0,110,0,0,0,103,0,0,0,100,0,0,0,111,0,0,0,109,0,0,0,32,0,0,0,103,0,0,0,114,0,0,0,97,0,0,0,110,0,0,0,100,0,0,0,112,0,0,0,114,0,0,0,105,0,0,0,120,0,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,83,0,0,0,104,0,0,0,105,0,0,0,112,0,0,0,112,0,0,0,117,0,0,0,32,0,0,0,77,0,0,0,97,0,0,0,104,0,0,0,111,0,0,0,117,0,0,0,32,0,0,0,68,0,0,0,97,0,0,0,105,0,0,0,115,0,0,0,97,0,0,0,107,0,0,0,117,0,0,0,115,0,0,0,101,0,0,0,110,0,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,49,32,70,105,114,101,32,51,0,0,0,0,0,0,0,84,155,0,0,213,108,0,0,39,89,0,0,92,79,0,0,38,98,0,0,0,0,0,0,77,0,0,0,97,0,0,0,104,0,0,0,111,0,0,0,117,0,0,0,32,0,0,0,68,0,0,0,97,0,0,0,105,0,0,0,115,0,0,0,97,0,0,0,107,0,0,0,117,0,0,0,115,0,0,0,101,0,0,0,110,0,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,112,49,32,114,105,103,104,116,0,0,0,0,0,0,0,0,71,117,101,115,116,32,80,108,97,121,101,114,115,0,0,0,68,73,80,45,115,119,105,116,99,104,32,100,105,115,112,108,97,121,0,0,0,0,0,0,82,101,116,117,114,110,32,111,102,32,116,104,101,32,73,110,118,97,100,101,114,115,32,40,98,111,111,116,108,101,103,32,115,101,116,32,49,41,0,0,71,101,114,109,97,110,121,32,40,71,101,114,109,97,110,32,84,117,110,105,110,103,32,108,105,99,101,110,115,101,41,0,65,104,32,69,105,107,111,117,32,110,111,32,75,111,115,104,105,101,110,32,40,74,97,112,97,110,41,0,0,0,0,0,67,111,105,110,95,66,0,0,78,105,99,115,0,0,0,0,72,97,114,100,63,0,0,0,83,105,108,101,110,116,32,68,114,97,103,111,110,32,40,74,97,112,97,110,41,0,0,0,115,99,105,110,101,103,114,111,0,0,0,0,0,0,0,0,68,114,97,103,111,110,110,105,110,106,97,32,40,74,97,112,97,110,41,0,0,0,0,0,67,97,109,101,108,116,114,121,32,40,87,111,114,108,100,44,32,89,77,50,50,48,51,32,43,32,77,54,50,57,53,41,0,0,0,0,0,0,0,0,112,99,101,95,118,101,105,103,117,101,115,0,0,0,0,0,66,97,110,103,32,66,101,97,100,32,40,80,114,111,116,111,116,121,112,101,63,41,0,0,66,111,100,121,32,67,111,117,110,116,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,49,50,55,41,0,0,0,97,117,100,105,111,95,114,97,116,101,95,99,111,110,116,114,111,108,0,0,0,0,0,0,50,32,116,111,32,115,116,97,114,116,47,50,32,116,111,32,99,111,110,116,105,110,117,101,0,0,0,0,0,0,0,0,74,111,74,111,39,115,32,66,105,122,97,114,114,101,32,65,100,118,101,110,116,117,114,101,58,32,72,101,114,105,116,97,103,101,32,102,111,114,32,116,104,101,32,70,117,116,117,114,101,32,47,32,74,111,74,111,32,110,111,32,75,105,109,121,111,117,32,110,97,32,66,111,117,107,101,110,58,32,77,105,114,97,105,32,101,32,110,111,32,73,115,97,110,32,40,69,117,114,111,32,57,57,48,57,50,55,44,32,78,79,32,67,68,41,0,0,0,0,0,0,84,104,101,32,76,101,103,101,110,100,32,111,102,32,75,97,103,101,32,40,111,108,100,101,114,41,0,0,0,0,0,0,84,67,48,50,50,48,73,79,67,80,111,114,116,0,0,0,67,111,116,116,111,110,32,40,115,101,116,32,50,44,32,85,83,44,32,70,68,49,48,57,52,32,51,49,55,45,48,49,56,48,41,0,0,0,0,0,112,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,115,117,112,101,114,99,104,115,117,0,0,0,0,0,0,0,114,101,103,117,108,117,115,0,83,0,0,0,101,0,0,0,112,0,0,0,116,0,0,0,101,0,0,0,109,0,0,0,98,0,0,0,101,0,0,0,114,0,0,0,0,0,0,0,79,112,101,114,97,116,105,111,110,32,84,104,117,110,100,101,114,98,111,108,116,32,40,85,83,41,0,0,0,0,0,0,84,101,116,114,105,115,32,40,115,101,116,32,51,44,32,74,97,112,97,110,44,32,83,121,115,116,101,109,32,49,54,65,44,32,70,68,49,48,57,52,32,51,49,55,45,48,48,57,51,97,41,0,0,0,0,0,77,101,100,97,108,115,32,97,110,100,32,67,114,101,100,105,116,115,0,0,0,0,0,0,69,120,116,101,114,109,105,110,97,116,105,111,110,32,40,87,111,114,108,100,41,0,0,0,52,32,67,111,105,110,115,32,83,116,97,114,116,44,32,49,32,67,111,105,110,32,67,111,110,116,105,110,117,101,0,0,65,114,107,97,110,111,105,100,32,40,85,83,41,0,0,0,83,111,117,110,100,76,97,116,99,104,83,116,97,116,117,115,0,0,0,0,0,0,0,0,85,83,65,32,80,114,111,32,66,97,115,107,101,116,98,97,108,108,0,0,0,0,0,0,97,115,104,110,111,106,111,101,0,0,0,0,0,0,0,0,98,97,110,103,98,101,100,112,0,0,0,0,0,0,0,0,109,100,95,98,111,100,121,99,111,112,53,0,0,0,0,0,68,97,114,107,32,83,101,97,108,32,40,87,111,114,108,100,32,114,101,118,105,115,105,111,110,32,49,41,0,0,0,0,109,99,117,95,115,101,101,100,0,0,0,0,0,0,0,0,102,105,114,101,32,52,0,0,65,116,104,101,110,97,32,40,86,105,115,99,111,32,108,105,99,101,110,115,101,41,0,0,83,110,111,119,32,66,114,111,116,104,101,114,115,32,51,32,45,32,77,97,103,105,99,97,108,32,65,100,118,101,110,116,117,114,101,0,0,0,0,0,109,97,115,116,101,114,119,117,0,0,0,0,0,0,0,0,79,112,101,114,97,116,105,111,110,32,87,111,108,102,32,51,32,40,87,111,114,108,100,41,0,0,0,0,0,0,0,0,98,108,111,99,107,98,108,0,77,115,46,32,80,97,99,32,65,116,116,97,99,107,0,0,112,99,101,95,117,115,97,112,114,111,98,115,0,0,0,0,65,113,117,97,106,97,99,107,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,84,67,48,54,52,48,70,73,79,82,101,103,115,0,0,0,66,111,100,121,32,67,111,117,110,116,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,50,48,56,41,0,0,0,80,49,32,65,99,99,101,108,0,0,0,0,0,0,0,0,83,117,112,101,114,32,66,117,114,103,101,114,32,84,105,109,101,32,40,87,111,114,108,100,44,32,115,101,116,32,50,41,0,0,0,0,0,0,0,0,67,67,104,105,112,76,97,115,116,95,48,52,0,0,0,0,49,32,67,111,105,110,32,53,32,80,108,97,121,115,0,0,51,48,107,32,101,118,101,114,121,32,57,48,107,0,0,0,67,114,101,100,105,116,115,32,66,0,0,0,0,0,0,0,68,97,114,105,117,115,32,40,74,97,112,97,110,41,0,0,99,114,116,99,95,116,105,109,101,114,0,0,0,0,0,0,67,97,100,97,115,104,32,40,74,97,112,97,110,41,0,0,102,114,97,109,101,98,117,102,102,101,114,95,112,97,103,101,0,0,0,0,0,0,0,0,107,111,118,49,49,53,0,0,118,100,99,95,105,110,99,91,105,93,0,0,0,0,0,0,112,111,114,116,65,95,111,117,116,0,0,0,0,0,0,0,112,99,101,95,98,105,107,107,117,114,105,49,0,0,0,0,67,0,0,0,97,0,0,0,100,0,0,0,105,0,0,0,108,0,0,0,108,0,0,0,97,0,0,0,99,0,0,0,115,0,0,0,32,0,0,0,80,96,0,0,220,122,0,0,176,101,0,0,22,78,0,0,0,125,0,0,0,0,0,0,67,0,0,0,97,0,0,0,100,0,0,0,105,0,0,0,108,0,0,0,108,0,0,0,97,0,0,0,99,0,0,0,115,0,0,0,32,0,0,0,75,0,0,0,121,0,0,0,111,0,0,0,117,0,0,0,114,0,0,0,121,0,0,0,117,0,0,0,117,0,0,0,45,0,0,0,83,0,0,0,104,0,0,0,105,0,0,0,110,0,0,0,115,0,0,0,101,0,0,0,105,0,0,0,107,0,0,0,105,0,0,0,32,0,0,0,40,0,0,0,67,0,0,0,97,0,0,0,100,0,0,0,105,0,0,0,108,0,0,0,108,0,0,0,97,0,0,0,99,0,0,0,115,0,0,0,32,0,0,0,57,0,0,0,51,0,0,0,48,0,0,0,50,0,0,0,48,0,0,0,49,0,0,0,32,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,86,32,83,112,111,114,116,115,32,72,111,99,107,101,121,0,0,0,0,0,0,0,0,80,117,122,122,108,101,100,32,47,32,74,111,121,32,74,111,121,32,75,105,100,32,40,78,71,77,45,48,50,49,41,40,78,71,72,45,48,50,49,41,0,0,0,0,0,0,0,0,109,100,95,98,111,100,121,99,111,112,52,0,0,0,0,0,66,117,98,98,108,101,32,66,111,98,98,108,101,32,40,111,108,100,101,114,41,0,0,0,109,99,117,95,99,111,105,110,115,65,0,0,0,0,0,0,67,104,97,114,83,99,114,111,108,108,88,0,0,0,0,0,84,67,48,52,56,48,83,67,80,80,114,105,82,101,103,0,68,97,114,105,117,115,32,73,73,32,40,100,117,97,108,32,115,99,114,101,101,110,41,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,70,101,114,114,97,114,105,32,71,114,97,110,100,32,80,114,105,120,32,67,104,97,108,108,101,110,103,101,32,40,69,117,114,111,44,32,82,101,118,46,32,65,41,0,0,0,0,0,84,104,101,32,70,97,105,114,121,76,97,110,100,32,83,116,111,114,121,32,40,74,97,112,97,110,41,0,0,0,0,0,82,101,119,105,110,100,32,71,114,97,110,117,108,97,114,105,116,121,0,0,0,0,0,0,99,108,97,109,112,95,116,111,95,98,111,114,100,101,114,0,67,97,112,99,111,109,32,83,112,111,114,116,115,32,67,108,117,98,32,40,57,55,48,55,50,50,32,72,105,115,112,97,110,105,99,41,0,0,0,0,69,120,116,114,97,32,69,97,115,121,0,0,0,0,0,0,79,117,116,32,82,117,110,32,40,115,105,116,100,111,119,110,47,117,112,114,105,103,104,116,41,0,0,0,0,0,0,0,114,95,121,95,109,105,110,117,115,0,0,0,0,0,0,0,112,99,101,95,116,118,104,111,99,107,101,121,0,0,0,0,115,98,112,0,0,0,0,0,66,111,100,121,32,67,111,117,110,116,32,40,69,117,114,111,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,109,54,51,95,115,111,117,110,100,95,112,50,0,0,0,0,116,104,110,100,98,108,115,116,0,0,0,0,0,0,0,0,71,97,108,108,111,112,32,45,32,65,114,109,101,100,32,112,111,108,105,99,101,32,85,110,105,116,32,40,74,97,112,97,110,41,0,0,0,0,0,0,102,117,110,107,121,106,101,116,0,0,0,0,0,0,0,0,83,121,115,116,101,109,49,54,68,105,112,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,73,58,32,78,101,119,32,71,101,110,101,114,97,116,105,111,110,32,40,74,97,112,97,110,32,57,55,48,50,48,52,41,0,0,0,0,0,0,0,84,86,32,83,112,111,114,116,115,32,70,111,111,116,98,97,108,108,0,0,0,0,0,0,75,121,108,101,32,72,111,100,103,101,116,116,115,0,0,0,109,100,95,98,111,100,121,99,111,112,0,0,0,0,0,0,67,97,118,101,84,105,108,101,82,101,103,91,105,93,91,49,93,0,0,0,0,0,0,0,86,111,108,117,109,101,32,68,111,119,110,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,80,83,82,77,58,32,37,115,10,0,0,0,0,65,108,105,101,110,32,83,116,111,114,109,32,40,115,101,116,32,51,44,32,87,111,114,108,100,44,32,51,32,80,108,97,121,101,114,115,44,32,70,68,49,48,57,52,32,51,49,55,45,48,49,52,56,41,0,0,112,99,101,95,116,118,102,111,111,116,98,108,0,0,0,0,68,111,116,116,111,114,105,32,75,117,110,32,40,111,108,100,32,118,101,114,115,105,111,110,41,0,0,0,0,0,0,0,68,105,103,103,101,114,32,77,97,110,0,0,0,0,0,0,84,101,99,32,84,111,121,0,110,86,105,100,101,111,73,82,81,0,0,0,0,0,0,0,71,97,108,97,120,121,32,70,111,114,99,101,32,50,32,40,74,97,112,97,110,41,0,0,65,46,66,46,32,67,111,112,32,40,74,97,112,97,110,44,32,70,68,49,48,57,52,32,51,49,55,45,48,49,54,57,98,41,0,0,0,0,0,0,83,117,112,101,114,32,76,111,99,111,109,111,116,105,118,101,0,0,0,0,0,0,0,0,86,100,112,87,105,110,100,111,119,66,97,115,101,0,0,0,111,114,98,105,116,114,111,110,0,0,0,0,0,0,0,0,84,86,32,83,112,111,114,116,115,32,66,97,115,107,101,116,98,97,108,108,0,0,0,0,100,105,103,103,101,114,109,97,0,0,0,0,0,0,0,0,66,111,100,121,32,67,111,117,110,116,32,40,66,114,97,41,0,0,0,0,0,0,0,0,97,102,105,103,104,116,101,114,0,0,0,0,0,0,0,0,86,111,108,117,109,101,32,85,112,0,0,0,0,0,0,0,69,83,80,32,82,97,46,68,101,46,32,40,74,97,112,97,110,44,32,118,101,114,46,32,57,56,47,48,52,47,50,49,41,0,0,0,0,0,0,0,69,110,100,117,114,111,32,82,97,99,101,114,32,40,89,77,50,50,48,51,44,32,70,68,49,48,56,57,66,32,51,49,55,45,48,48,49,51,65,41,0,0,0,0,0,0,0,0,70,117,110,110,121,32,66,117,98,98,108,101,32,40,67,111,109,97,100,32,118,101,114,115,105,111,110,41,0,0,0,0,84,104,101,32,66,101,114,108,105,110,32,87,97,108,108,32,40,98,111,111,116,108,101,103,32,63,41,0,0,0,0,0,112,99,101,95,116,118,98,97,115,107,101,116,0,0,0,0,86,45,76,105,110,101,114,32,40,115,101,116,32,50,41,0,0,0,0,0,0,0,0,0,109,100,95,98,111,100,121,99,111,98,0,0,0,0,0,0,77,117,108,116,105,32,67,104,97,109,112,32,40,75,111,114,101,97,41,0,0,0,0,0,77,105,115,115,32,80,117,122,122,108,101,32,40,67,108,111,110,101,32,111,102,32,71,117,109,98,111,41,0,0,0,0,103,117,119,97,110,103,101,115,0,0,0,0,0,0,0,0,67,111,108,111,114,32,84,101,115,116,0,0,0,0,0,0,83,117,110,65,32,81,117,105,122,32,54,48,48,48,32,65,99,97,100,101,109,121,32,40,57,52,48,54,50,48,45,54,41,0,0,0,0,0,0,0,84,97,111,32,84,97,105,100,111,32,40,115,101,116,32,50,41,0,0,0,0,0,0,0,84,115,117,114,117,32,84,101,114,117,104,105,116,111,32,110,111,32,74,105,115,115,101,110,32,75,97,98,117,115,104,105,107,105,32,66,97,105,32,66,97,105,32,71,97,109,101,0,0,0,0,0,0,0,0,0,118,108,105,110,101,114,111,0,66,111,100,121,32,67,111,117,110,116,32,40,69,117,114,111,41,0,0,0,0,0,0,0,51,99,111,117,110,116,98,0,80,49,32,70,105,114,101,32,50,0,0,0,0,0,0,0,73,110,118,105,110,99,105,98,108,101,0,0,0,0,0,0,112,119,114,105,110,115,116,50,106,0,0,0,0,0,0,0,90,101,114,111,32,80,111,105,110,116,32,40,115,101,116,32,49,41,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,65,112,112,101,110,100,105,110,103,32,99,111,110,102,105,103,32,34,37,115,34,10,0,0,0,0,0,0,0,83,104,97,100,111,119,32,70,111,114,99,101,32,40,74,97,112,97,110,32,86,101,114,115,105,111,110,32,51,41,0,0,65,32,111,110,108,121,0,0,107,111,115,104,105,101,110,0,67,111,105,110,95,65,0,0,67,114,111,113,117,105,115,32,40,71,101,114,109,97,110,121,41,0,0,0,0,0,0,0,74,117,109,112,105,110,103,32,80,111,112,32,40,78,105,99,115,44,32,75,111,114,101,97,110,32,98,111,111,116,108,101,103,32,111,102,32,80,108,117,109,112,32,80,111,112,41,0,0,0,0,0,0,0,0,0,77,101,100,105,117,109,63,0,115,105,108,101,110,116,100,106,0,0,0,0,0,0,0,0,97,115,117,114,97,98,117,115,0,0,0,0,0,0,0,0,83,112,101,99,105,97,108,32,67,114,105,109,105,110,97,108,32,73,110,118,101,115,116,105,103,97,116,105,111,110,32,40,85,83,41,0,0,0,0,0,74,97,99,107,105,101,32,67,104,97,110,32,105,110,32,70,105,115,116,115,32,111,102,32,70,105,114,101,0,0,0,0,112,99,101,95,98,97,105,98,97,105,0,0,0,0,0,0,68,121,110,97,32,47,32,66,114,101,101,122,97,83,111,102,116,0,0,0,0,0,0,0,109,100,95,98,111,100,121,99,111,0,0,0,0,0,0,0,97,117,100,105,111,95,115,121,110,99,0,0,0,0,0,0,49,32,116,111,32,115,116,97,114,116,47,49,32,116,111,32,99,111,110,116,105,110,117,101,0,0,0,0,0,0,0,0,106,111,106,111,98,97,110,101,0,0,0,0,0,0,0,0,66,108,111,109,98,121,32,67,97,114,32,40,110,111,116,32,101,110,99,114,121,112,116,101,100,41,0,0,0,0,0,0,99,111,116,116,111,110,117,0,115,99,114,111,108,108,95,120,0,0,0,0,0,0,0,0,112,105,99,49,54,99,53,120,95,112,111,114,116,48,0,0,82,97,102,102,108,101,115,105,97,32,40,51,49,53,45,53,49,54,50,41,0,0,0,0,65,0,0,0,117,0,0,0,103,0,0,0,117,0,0,0,115,0,0,0,116,0,0,0,0,0,0,0,0,0,0,0,85,110,105,111,110,32,74,97,99,107,0,0,0,0,0,0,116,101,116,114,105,115,51,0,87,105,110,110,105,110,103,115,0,0,0,0,0,0,0,0,84,97,115,107,32,70,111,114,99,101,32,72,97,114,114,105,101,114,32,40,85,83,63,41,0,0,0,0,0,0,0,0,112,111,112,115,112,111,112,115,0,0,0,0,0,0,0,0,52,32,67,111,105,110,115,32,83,116,97,114,116,44,32,50,32,67,111,105,110,115,32,67,111,110,116,105,110,117,101,0,82,97,105,100,101,110,32,40,115,101,116,32,50,41,0,0,116,104,101,114,111,101,115,0,84,115,117,112,112,97,114,105,32,79,111,122,117,109,111,117,32,45,32,72,101,105,115,101,105,32,66,97,110,0,0,0,86,45,76,105,110,101,114,32,40,115,101,116,32,49,41,0,0,0,0,0,0,0,0,0,75,111,100,97,110,115,104,97,0,0,0,0,0,0,0,0,109,106,52,115,105,109,97,105,0,0,0,0,0,0,0,0,71,97,109,101,32,84,101,115,116,32,77,111,100,101,0,0,102,105,114,101,32,51,0,0,87,105,116,39,115,32,40,74,97,112,97,110,41,0,0,0,115,110,111,119,98,114,111,51,0,0,0,0,0,0,0,0,65,105,114,32,66,117,115,116,101,114,58,32,84,114,111,117,98,108,101,32,83,112,101,99,105,97,108,116,121,32,82,97,105,100,32,85,110,105,116,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,65,108,108,111,119,32,73,110,118,117,108,110,101,114,97,98,105,108,105,116,121,32,40,67,104,101,97,116,41,0,0,0,66,108,111,99,107,32,66,108,111,99,107,32,40,87,111,114,108,100,32,57,49,49,49,49,54,32,74,111,121,115,116,105,99,107,41,0,0,0,0,0,77,97,103,105,99,32,66,117,98,98,108,101,32,40,65,100,117,108,116,32,118,101,114,115,105,111,110,41,0,0,0,0,109,115,112,97,99,109,97,116,0,0,0,0,0,0,0,0,68,97,110,103,117,110,32,70,101,118,101,114,111,110,32,40,74,97,112,97,110,44,32,118,101,114,46,32,57,56,47,48,57,47,49,55,41,0,0,0,99,114,115,104,114,97,99,101,50,0,0,0,0,0,0,0,104,101,114,111,100,107,0,0,78,101,119,115,32,40,115,101,116,32,50,41,0,0,0,0,112,99,101,95,116,115,117,112,112,97,114,105,0,0,0,0,118,108,105,110,101,114,0,0,66,108,117,101,32,65,108,109,97,110,97,99,32,40,74,112,110,41,0,0,0,0,0,0,78,117,109,98,101,114,32,111,102,32,81,117,101,115,116,105,111,110,115,0,0,0,0,0,83,104,97,100,111,119,32,87,97,114,114,105,111,114,115,32,40,87,111,114,108,100,44,32,115,101,116,32,50,41,0,0,49,32,67,111,105,110,32,52,32,80,108,97,121,115,0,0,50,48,107,32,97,110,100,32,56,48,107,0,0,0,0,0,68,114,118,67,80,85,51,72,97,108,116,0,0,0,0,0,87,87,70,32,87,114,101,115,116,108,101,70,101,115,116,32,40,85,83,32,84,101,99,109,111,41,0,0,0,0,0,0,99,114,116,99,95,114,101,103,105,115,116,101,114,0,0,0,75,0,0,0,110,0,0,0,105,0,0,0,103,0,0,0,104,0,0,0,116,0,0,0,115,0,0,0,32,0,0,0,111,0,0,0,102,0,0,0,32,0,0,0,86,0,0,0,97,0,0,0,108,0,0,0,111,0,0,0,117,0,0,0,114,0,0,0,0,0,0,0,9,78,0,0,253,86,0,0,38,98,0,0,0,125,0,0,0,0,0,0,9,78,0,0,253,86,0,0,24,98,0,0,170,126,0,0,32,0,0,0,40,0,0,0,86,0,0,0,49,0,0,0,49,0,0,0,55,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,80,117,115,104,109,97,110,32,40,75,111,114,101,97,44,32,115,101,116,32,50,41,0,0,66,105,107,107,117,114,105,109,97,110,32,87,111,114,108,100,0,0,0,0,0,0,0,0,80,97,115,104,97,32,80,97,115,104,97,32,67,104,97,109,112,32,77,105,110,105,32,71,97,109,101,32,70,101,115,116,105,118,97,108,0,0,0,0,67,97,100,105,108,108,97,99,115,32,75,121,111,117,114,121,117,117,45,83,104,105,110,115,101,105,107,105,32,40,67,97,100,105,108,108,97,99,115,32,57,51,48,50,48,49,32,74,97,112,97,110,41,0,0,0,84,114,105,99,107,121,0,0,74,111,99,107,101,121,32,71,114,97,110,100,32,80,114,105,120,32,40,115,101,116,32,50,41,0,0,0,0,0,0,0,109,100,95,98,108,117,101,97,108,109,97,0,0,0,0,0,116,107,100,101,110,115,104,111,0,0,0,0,0,0,0,0,87,101,108,108,116,114,105,115,32,45,32,65,108,101,120,101,121,32,80,97,106,105,116,110,111,118,39,115,32,40,74,97,112,97,110,44,32,50,32,112,108,97,121,101,114,115,41,0,0,0,0,0,0,0,0,0,109,100,95,102,101,114,114,97,114,105,0,0,0,0,0,0,115,97,105,108,111,114,109,110,117,0,0,0,0,0,0,0,82,101,119,105,110,100,0,0,77,97,103,105,99,97,108,32,67,97,116,32,65,100,118,101,110,116,117,114,101,32,40,74,97,112,97,110,41,0,0,0,97,98,115,111,108,117,116,101,0,0,0,0,0,0,0,0,99,115,99,108,117,98,104,0,68,101,99,111,49,54,105,99,32,82,65,77,32,37,100,0,71,111,117,107,101,116,115,117,106,105,32,73,99,104,105,122,111,107,117,32,40,74,97,112,97,110,41,0,0,0,0,0,114,95,121,95,112,108,117,115,0,0,0,0,0,0,0,0,112,99,101,95,116,114,105,99,107,121,0,0,0,0,0,0,106,111,99,107,101,121,103,112,97,0,0,0,0,0,0,0,66,108,111,111,100,115,104,111,116,32,126,32,66,97,116,116,108,101,32,70,114,101,110,122,121,32,40,69,117,114,111,41,0,0,0,0,0,0,0,0,109,54,51,95,115,111,117,110,100,95,112,49,0,0,0,0,76,101,116,104,97,108,32,84,104,117,110,100,101,114,32,40,87,111,114,108,100,41,0,0,103,97,108,108,111,112,0,0,97,108,105,101,110,99,104,97,0,0,0,0,0,0,0,0,109,54,50,57,53,98,97,110,107,0,0,0,0,0,0,0,71,101,110,105,120,32,70,97,109,105,108,121,0,0,0,0,67,114,117,115,104,101,114,32,77,97,107,111,99,104,97,110,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,49,50,55,0,0,0,0,0,118,109,101,116,97,108,110,0,86,105,99,116,111,114,0,0,83,117,110,32,65,109,117,115,101,109,101,110,116,32,47,32,66,114,101,122,122,97,83,111,102,116,0,0,0,0,0,0,109,100,95,98,108,111,111,100,115,104,116,0,0,0,0,0,68,111,117,98,108,101,32,68,114,97,103,111,110,32,51,32,45,32,84,104,101,32,82,111,115,101,116,116,97,32,83,116,111,110,101,32,40,74,97,112,97,110,41,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,82,77,58,32,32,37,115,10,0,0,0,0,84,104,101,32,76,101,103,101,110,100,32,111,102,32,83,105,108,107,114,111,97,100,32,40,108,97,114,103,101,114,32,114,111,109,115,41,0,0,0,0,65,116,111,109,105,99,32,80,111,105,110,116,0,0,0,0,84,111,121,32,83,104,111,112,32,66,111,121,115,0,0,0,74,111,99,107,101,121,32,71,114,97,110,100,32,80,114,105,120,32,40,115,101,116,32,49,41,0,0,0,0,0,0,0,66,108,111,99,107,111,117,116,32,40,87,111,114,108,100,41,0,0,0,0,0,0,0,0,83,101,99,111,110,100,32,67,111,105,110,32,67,111,117,110,116,101,114,0,0,0,0,0,66,108,111,111,100,32,66,114,111,115,46,32,40,115,101,116,32,50,41,0,0,0,0,0,100,111,110,112,97,99,104,105,106,0,0,0,0,0,0,0,110,97,110,97,109,101,0,0,78,111,114,109,97,108,32,84,101,116,114,105,115,0,0,0,72,121,112,101,114,32,80,97,99,109,97,110,32,40,98,111,111,116,108,101,103,41,0,0,84,68,83,0,0,0,0,0,112,99,101,95,116,111,121,115,104,111,112,98,0,0,0,0,106,111,99,107,101,121,103,112,0,0,0,0,0,0,0,0,72,101,97,108,116,104,0,0,109,100,95,98,108,111,99,107,111,117,116,0,0,0,0,0,116,117,109,98,108,101,98,50,0,0,0,0,0,0,0,0,100,100,111,110,112,97,99,104,106,0,0,0,0,0,0,0,83,101,110,103,111,107,117,32,65,99,101,32,40,74,97,112,97,110,41,0,0,0,0,0,71,97,109,101,32,77,111,100,101,0,0,0,0,0,0,0,83,116,114,105,107,101,114,115,32,49,57,52,53,32,73,73,0,0,0,0,0,0,0,0,84,104,101,32,84,111,119,101,114,32,111,102,32,68,114,117,97,103,97,0,0,0,0,0,176,101,0,0,106,140,0,0,64,136,0,0,250,91,0,0,0,78,0,0,207,101,0,0,32,0,0,0,45,0,0,0,32,0,0,0,216,149,0,0,90,90,0,0,0,0,0,0,77,0,0,0,97,0,0,0,116,0,0,0,114,0,0,0,105,0,0,0,109,0,0,0,101,0,0,0,108,0,0,0,101,0,0,0,101,0,0,0,32,0,0,0,40,0,0,0,98,0,0,0,111,0,0,0,111,0,0,0,116,0,0,0,108,0,0,0,101,0,0,0,103,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,83,101,116,116,105,110,103,32,114,101,102,114,101,115,104,32,114,97,116,101,32,116,111,58,32,37,46,51,102,32,72,122,46,0,0,0,0,0,0,0,66,108,111,99,107,98,117,115,116,101,114,32,87,111,114,108,100,32,86,105,100,101,111,32,71,97,109,101,32,67,104,97,109,112,105,111,110,115,104,105,112,32,73,73,32,40,85,83,65,41,0,0,0,0,0,0,70,117,110,107,121,32,66,101,101,32,40,98,111,111,116,108,101,103,44,32,104,97,114,100,101,114,41,0,0,0,0,0,86,105,100,101,111,32,82,97,109,0,0,0,0,0,0,0,79,110,105,32,45,32,84,104,101,32,78,105,110,106,97,32,77,97,115,116,101,114,32,40,74,97,112,97,110,41,0,0,84,111,114,97,32,101,32,110,111,32,77,105,99,104,105,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,82,111,109,66,97,110,107,0,69,120,101,114,105,122,101,114,32,40,74,97,112,97,110,41,32,40,98,111,111,116,108,101,103,41,0,0,0,0,0,0,76,101,118,101,108,32,83,101,108,101,99,116,0,0,0,0,82,111,117,116,101,32,49,54,32,40,115,101,116,32,50,41,0,0,0,0,0,0,0,0,112,99,101,95,100,114,117,97,103,97,0,0,0,0,0,0,77,97,116,114,105,109,101,108,101,101,32,47,32,83,104,105,110,32,71,111,117,107,101,116,115,117,106,105,32,73,99,104,105,122,111,107,117,32,84,111,117,107,111,110,32,40,98,111,111,116,108,101,103,41,0,0,65,114,109,101,100,32,70,111,114,109,97,116,105,111,110,32,40,70,105,108,108,109,111,114,101,32,108,105,99,101,110,115,101,41,0,0,0,0,0,0,109,100,95,98,108,111,99,107,98,0,0,0,0,0,0,0,80,101,110,103,117,105,110,45,75,117,110,32,87,97,114,115,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,70,105,114,101,32,51,0,0,80,117,122,122,108,101,32,85,111,32,80,111,107,111,32,40,74,97,112,97,110,44,32,118,101,114,46,32,57,56,47,48,50,47,48,54,41,0,0,0,112,49,32,108,101,102,116,0,67,111,110,116,105,110,117,101,32,112,108,97,121,0,0,0,85,46,83,46,65,46,32,40,65,116,97,114,105,32,71,97,109,101,115,32,67,111,114,112,46,41,0,0,0,0,0,0,67,104,105,45,84,111,105,116,115,117,0,0,0,0,0,0,65,32,97,110,100,32,66,0,71,117,110,32,70,114,111,110,116,105,101,114,32,40,74,97,112,97,110,41,0,0,0,0,70,114,101,101,95,80,108,97,121,0,0,0,0,0,0,0,83,112,101,99,105,97,108,32,70,117,110,99,116,105,111,110,32,77,111,100,101,0,0,0,106,112,111,112,110,105,99,115,0,0,0,0,0,0,0,0,69,97,115,121,63,0,0,0,87,87,70,32,83,117,112,101,114,115,116,97,114,115,32,40,85,83,44,32,110,101,119,101,114,41,0,0,0,0,0,0,65,116,104,101,110,97,32,40,74,97,112,97,110,32,79,110,108,121,41,0,0,0,0,0,83,105,108,101,110,116,32,68,114,97,103,111,110,32,40,87,111,114,108,100,41,0,0,0,115,99,105,117,0,0,0,0,86,111,108,102,105,101,100,32,40,85,83,44,32,114,101,118,105,115,105,111,110,32,49,41,0,0,0,0,0,0,0,0,84,111,115,104,105,32,84,101,110,115,111,117,32,75,101,105,107,97,107,117,32,45,32,69,116,101,114,110,97,108,32,67,105,116,121,0,0,0,0,0,109,97,116,114,105,109,98,108,0,0,0,0,0,0,0,0,109,97,122,105,110,103,101,114,106,0,0,0,0,0,0,0,66,108,97,115,116,101,114,32,77,97,115,116,101,114,32,50,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,0,80,114,101,104,105,115,116,111,114,105,99,32,73,115,108,101,32,105,110,32,49,57,51,48,32,40,85,83,41,0,0,0,97,117,100,105,111,95,108,97,116,101,110,99,121,0,0,0,50,32,116,111,32,115,116,97,114,116,47,49,32,116,111,32,99,111,110,116,105,110,117,101,0,0,0,0,0,0,0,0,184,48,0,0,231,48,0,0,184,48,0,0,231,48,0,0,110,48,0,0,32,0,0,0,71,89,0,0,153,89,0,0,106,48,0,0,146,81,0,0,122,150,0,0,58,0,0,0,32,0,0,0,42,103,0,0,101,103,0,0,120,48,0,0,110,48,0,0,122,144,0,0,35,117,0,0,0,0,0,0,74,0,0,0,111,0,0,0,74,0,0,0,111,0,0,0,39,0,0,0,115,0,0,0,32,0,0,0,66,0,0,0,105,0,0,0,122,0,0,0,97,0,0,0,114,0,0,0,114,0,0,0,101,0,0,0,32,0,0,0,65,0,0,0,100,0,0,0,118,0,0,0,101,0,0,0,110,0,0,0,116,0,0,0,117,0,0,0,114,0,0,0,101,0,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,32,0,0,0,57,0,0,0,57,0,0,0,48,0,0,0,57,0,0,0,50,0,0,0,55,0,0,0,44,0,0,0,32,0,0,0,78,0,0,0,79,0,0,0,32,0,0,0,67,0,0,0,68,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,83,117,99,99,101,115,115,32,47,32,83,101,103,97,0,0,66,108,111,99,107,32,79,117,116,32,40,115,101,116,32,50,41,0,0,0,0,0,0,0,114,97,102,108,101,115,105,97,0,0,0,0,0,0,0,0,67,108,101,97,114,32,83,119,101,97,114,32,87,111,114,100,115,0,0,0,0,0,0,0,84,101,116,114,105,115,32,40,115,101,116,32,52,44,32,74,97,112,97,110,44,32,83,121,115,116,101,109,32,49,54,65,44,32,70,68,49,48,57,52,32,51,49,55,45,48,48,57,51,41,0,0,0,0,0,0,68,105,112,0,0,0,0,0,49,32,67,111,105,110,32,49,48,48,48,32,67,114,101,100,105,116,115,0,0,0,0,0,50,32,80,108,97,121,101,114,115,32,83,105,100,101,0,0,5,125,0,0,100,91,0,0,48,98,0,0,95,106,0,0,73,0,0,0,73,0,0,0,0,0,0,0,82,0,0,0,101,0,0,0,100,0,0,0,32,0,0,0,70,0,0,0,111,0,0,0,120,0,0,0,32,0,0,0,87,0,0,0,97,0,0,0,114,0,0,0,32,0,0,0,80,0,0,0,108,0,0,0,97,0,0,0,110,0,0,0,101,0,0,0,115,0,0,0,32,0,0,0,73,0,0,0,73,0,0,0,32,0,0,0,40,0,0,0,67,0,0,0,104,0,0,0,105,0,0,0,110,0,0,0,97,0,0,0,44,0,0,0,32,0,0,0,115,0,0,0,101,0,0,0,116,0,0,0,32,0,0,0,50,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,52,32,67,111,105,110,115,32,83,116,97,114,116,44,32,51,32,67,111,105,110,115,32,67,111,110,116,105,110,117,101,0,86,105,115,99,111,32,40,74,97,112,97,110,32,79,110,108,121,41,0,0,0,0,0,0,80,117,99,107,32,77,97,110,32,40,66,111,111,116,108,101,103,32,115,101,116,32,49,41,0,0,0,0,0,0,0,0,49,48,48,107,32,51,48,48,107,0,0,0,0,0,0,0,112,99,101,95,101,116,101,114,99,105,116,121,0,0,0,0,176,101,0,0,106,140,0,0,64,136,0,0,250,91,0,0,0,78,0,0,207,101,0,0,32,0,0,0,45,0,0,0,32,0,0,0,216,149,0,0,90,90,0,0,0,0,0,0,77,0,0,0,97,0,0,0,116,0,0,0,114,0,0,0,105,0,0,0,109,0,0,0,101,0,0,0,108,0,0,0,101,0,0,0,101,0,0,0,32,0,0,0,40,0,0,0,78,0,0,0,71,0,0,0,77,0,0,0,45,0,0,0,50,0,0,0,54,0,0,0,54,0,0,0,48,0,0,0,41,0,0,0,32,0,0,0,40,0,0,0,78,0,0,0,71,0,0,0,72,0,0,0,45,0,0,0,50,0,0,0,54,0,0,0,54,0,0,0,48,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,66,108,97,99,107,32,84,105,103,101,114,32,40,111,108,100,101,114,41,0,0,0,0,0])
.concat([109,100,95,98,109,97,115,116,101,114,50,112,0,0,0,0,71,97,117,110,116,108,101,116,32,40,83,112,97,110,105,115,104,44,32,114,101,118,32,49,53,41,0,0,0,0,0,0,102,105,114,101,32,50,0,0,119,105,116,115,0,0,0,0,83,110,111,119,32,66,114,111,115,46,32,45,32,78,105,99,107,32,38,32,84,111,109,32,40,84,104,101,32,87,105,110,116,101,114,32,66,111,98,98,108,101,32,104,97,114,100,119,97,114,101,32,98,111,111,116,108,101,103,41,0,0,0,0,66,111,109,98,32,74,97,99,107,32,40,115,101,116,32,50,41,0,0,0,0,0,0,0,66,105,111,110,105,99,32,67,111,109,109,97,110,100,111,32,40,85,83,32,115,101,116,32,49,41,0,0,0,0,0,0,98,108,111,99,107,106,111,121,0,0,0,0,0,0,0,0,80,97,99,45,76,97,110,100,32,40,74,97,112,97,110,32,110,101,119,41,0,0,0,0,49,32,80,108,97,121,101,114,32,83,105,100,101,0,0,0,77,105,100,119,97,121,0,0,83,101,116,97,32,85,46,83,46,65,0,0,0,0,0,0,68,105,112,32,83,119,105,116,99,104,101,115,0,0,0,0,77,114,46,32,68,111,33,32,40,84,97,105,116,111,32,108,105,99,101,110,115,101,41,0,0,0,0,0,0,0,0,0,86,105,99,116,111,114,32,69,110,116,101,114,116,97,105,110,109,101,110,116,0,0,0,0,78,111,105,115,101,32,70,97,99,116,111,114,121,32,47,32,65,116,108,117,115,0,0,0,66,108,97,115,116,101,114,32,77,97,115,116,101,114,32,50,32,40,85,83,65,41,0,0,80,49,32,72,97,110,100,108,101,0,0,0,0,0,0,0,76,97,100,121,32,66,117,103,32,40,98,111,111,116,108,101,103,32,115,101,116,32,49,41,0,0,0,0,0,0,0,0,78,117,109,98,101,114,32,111,102,32,87,114,111,110,103,32,65,110,115,119,101,114,0,0,74,0,0,0,117,0,0,0,108,0,0,0,121,0,0,0,0,0,0,0,0,0,0,0,83,111,108,111,109,111,110,39,115,32,75,101,121,32,40,74,97,112,97,110,41,0,0,0,49,32,67,111,105,110,32,51,32,80,108,97,121,115,0,0,50,48,107,32,101,118,101,114,121,32,56,48,107,0,0,0,43,55,32,70,97,115,116,101,114,0,0,0,0,0,0,0,68,114,118,67,80,85,50,72,97,108,116,0,0,0,0,0,82,97,100,97,114,32,83,99,111,112,101,32,40,84,82,83,48,49,41,0,0,0,0,0,71,117,110,46,32,83,109,111,107,101,32,40,74,97,112,97,110,41,0,0,0,0,0,0,75,110,105,103,104,116,115,32,111,102,32,86,97,108,111,117,114,32,45,32,83,97,110,103,111,107,117,32,83,101,110,107,105,32,40,86,49,49,55,41,0,0,0,0,0,0,0,0,67,111,110,116,114,111,108,108,101,114,32,83,101,108,101,99,116,0,0,0,0,0,0,0,84,101,114,114,97,32,67,114,101,115,116,97,32,40,89,77,51,53,50,54,32,115,101,116,32,50,41,0,0,0,0,0,100,105,110,111,106,0,0,0,84,111,107,105,32,40,87,111,114,108,100,32,115,101,116,32,50,41,0,0,0,0,0,0,84,111,114,97,32,101,32,110,111,32,77,105,99,104,105,0,0,0,0,0,0,0,0,0,77,97,116,114,105,109,101,108,101,101,32,47,32,83,104,105,110,32,71,111,117,107,101,116,115,117,106,105,32,73,99,104,105,122,111,107,117,32,84,111,117,107,111,110,32,40,78,71,77,45,50,54,54,48,41,32,40,78,71,72,45,50,54,54,48,41,0,0,0,0,0,0,71,104,111,115,116,32,80,105,108,111,116,115,32,40,78,71,72,45,48,50,48,41,40,85,83,41,0,0,0,0,0,0,109,100,95,98,109,97,115,116,101,114,50,0,0,0,0,0,115,97,118,103,98,101,101,115,0,0,0,0,0,0,0,0,86,117,108,103,117,115,32,40,115,101,116,32,50,41,0,0,49,57,52,50,32,40,82,101,118,105,115,105,111,110,32,65,41,0,0,0,0,0,0,0,54,56,75,32,35,49,32,82,79,77,32,40,67,80,85,32,35,49,41,0,0,0,0,0,66,97,116,109,97,110,32,40,69,117,114,111,41,0,0,0,87,97,108,108,32,67,114,97,115,104,32,40,115,101,116,32,50,41,0,0,0,0,0,0,68,105,115,107,32,79,112,116,105,111,110,115,0,0,0,0,49,48,48,107,44,32,51,48,48,107,44,32,55,48,48,107,44,32,49,48,48,48,107,0,48,48,0,0,0,0,0,0,66,97,114,97,100,117,107,101,0,0,0,0,0,0,0,0,69,118,101,114,121,32,55,116,104,32,76,111,111,112,0,0,118,105,101,119,112,111,114,116,0,0,0,0,0,0,0,0,67,97,112,99,111,109,32,83,112,111,114,116,115,32,67,108,117,98,32,40,57,55,48,55,50,50,32,65,115,105,97,41,0,0,0,0,0,0,0,0,114,95,120,95,109,105,110,117,115,0,0,0,0,0,0,0,112,99,101,95,116,111,114,97,109,105,99,104,0,0,0,0,109,97,116,114,105,109,0,0,83,101,99,116,105,111,110,32,90,32,40,115,101,116,32,50,41,0,0,0,0,0,0,0,66,108,97,100,101,115,32,111,102,32,86,101,110,103,101,97,110,99,101,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,0,0,0,83,117,110,115,101,116,32,82,105,100,101,114,115,32,40,50,32,80,108,97,121,101,114,115,32,118,101,114,46,32,74,66,68,41,0,0,0,0,0,0,49,48,48,32,97,110,100,32,56,48,107,0,0,0,0,0,77,121,115,116,101,114,105,111,117,115,32,83,116,111,110,101,115,32,45,32,68,114,46,32,75,105,99,107,32,105,110,32,65,100,118,101,110,116,117,114,101,0,0,0,0,0,0,0,108,101,116,104,97,108,116,104,0,0,0,0,0,0,0,0,77,56,52,0,0,0,0,0,97,116,101,116,114,105,115,97,0,0,0,0,0,0,0,0,74,97,99,107,32,116,104,101,32,71,105,97,110,116,107,105,108,108,101,114,32,40,115,101,116,32,50,41,0,0,0,0,56,48,107,44,32,50,48,48,107,44,32,53,48,48,107,44,32,49,48,48,48,107,0,0,68,97,116,115,117,103,111,107,117,32,45,32,80,114,105,115,111,110,101,114,115,32,111,102,32,87,97,114,32,40,74,97,112,97,110,41,0,0,0,0,69,118,101,114,121,32,51,114,100,32,76,111,111,112,0,0,84,111,105,108,101,116,32,75,105,100,115,0,0,0,0,0,69,118,111,103,97,32,47,32,80,108,97,121,109,111,114,101,0,0,0,0,0,0,0,0,67,111,109,109,97,110,100,111,32,40,85,83,41,0,0,0,109,100,95,98,108,97,100,101,118,101,110,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,97,118,105,110,103,32,66,83,88,32,40,80,41,82,65,77,46,10,0,0,49,57,52,51,58,32,84,104,101,32,66,97,116,116,108,101,32,111,102,32,77,105,100,119,97,121,32,40,85,83,41,0,0,0,0,0,0,0,0,0,68,121,110,97,109,105,116,101,32,68,117,107,101,32,40,69,117,114,111,112,101,32,115,101,116,32,50,41,0,0,0,0,78,101,107,107,101,116,115,117,32,75,111,117,104,97,32,75,117,110,105,111,45,107,117,110,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,66,108,117,101,32,80,114,105,110,116,32,40,74,97,108,101,99,111,41,0,0,0,0,0,112,51,32,114,105,103,104,116,32,50,0,0,0,0,0,0,70,117,108,108,115,99,114,101,101,110,32,116,111,103,103,108,101,0,0,0,0,0,0,0,67,80,85,32,80,108,97,121,101,114,32,68,117,114,105,110,103,32,77,117,108,116,105,45,80,108,97,121,101,114,32,71,97,109,101,0,0,0,0,0,75,121,117,103,111,32,40,85,65,32,84,104,101,97,116,114,101,32,108,105,99,101,110,115,101,41,0,0,0,0,0,0,83,112,114,105,110,103,101,114,0,0,0,0,0,0,0,0,112,99,101,95,116,111,105,108,101,116,107,0,0,0,0,0,82,97,103,101,32,111,102,32,116,104,101,32,68,114,97,103,111,110,115,32,40,78,71,77,45,50,54,52,63,41,0,0,67,114,121,105,110,103,32,45,32,65,115,101,105,109,101,105,32,83,101,110,115,111,117,32,40,74,112,110,41,0,0,0,76,97,115,116,32,68,117,101,108,32,40,85,83,32,79,108,100,32,86,101,114,46,41,0,0,0,0,0,0,0,0,0,68,65,67,32,35,37,100,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,40,85,83,32,115,101,116,32,49,41,0,0,0,0,0,0,0,84,104,101,32,83,112,101,101,100,32,82,117,109,98,108,101,114,32,40,115,101,116,32,50,41,0,0,0,0,0,0,0,83,107,121,32,75,105,100,32,40,111,108,100,32,118,101,114,115,105,111,110,41,0,0,0,119,99,57,48,98,50,0,0,80,51,32,82,105,103,104,116,32,50,0,0,0,0,0,0,66,108,97,99,107,32,72,111,108,101,0,0,0,0,0,0,71,104,111,115,116,115,39,110,32,71,111,98,108,105,110,115,32,40,87,111,114,108,100,63,32,115,101,116,32,50,41,0,0,0,0,0,0,0,0,0,84,105,116,97,110,0,0,0,114,111,116,100,0,0,0,0,49,48,48,32,83,101,99,111,110,100,115,0,0,0,0,0,109,100,95,99,114,121,105,110,103,0,0,0,0,0,0,0,65,114,97,98,105,97,110,32,40,65,116,97,114,105,41,0,0,0,0,0,0,0,0,0,70,97,114,109,101,114,115,32,82,101,98,101,108,108,105,111,110,0,0,0,0,0,0,0,71,97,108,97,103,97,32,40,78,97,109,99,111,41,0,0,87,111,114,108,100,32,67,117,112,32,39,57,48,32,40,69,117,114,111,32,115,101,116,32,49,41,0,0,0,0,0,0,83,111,110,32,83,111,110,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,112,51,32,108,101,102,116,32,50,0,0,0,0,0,0,0,82,97,108,108,121,32,88,0,0,0,0,0,0,0,0,0,82,97,98,98,105,116,32,80,117,110,99,104,32,40,85,83,41,0,0,0,0,0,0,0,112,99,101,95,116,105,116,97,110,0,0,0,0,0,0,0,77,101,116,97,108,32,83,108,117,103,32,52,32,80,108,117,115,32,40,98,111,111,116,108,101,103,41,0,0,0,0,0,65,109,98,117,115,104,32,40,74,97,112,97,110,41,0,0,66,105,111,32,72,97,122,97,114,100,32,66,97,116,116,108,101,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,82,121,103,97,114,32,40,85,83,32,115,101,116,32,50,41,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,116,97,116,101,32,115,105,122,101,58,32,37,117,32,98,121,116,101,115,46,10,0,0,0,0,0,0,0,68,111,117,98,108,101,32,68,114,97,103,111,110,32,40,87,111,114,108,100,32,115,101,116,32,49,41,0,0,0,0,0,103,105,110,103,97,110,105,110,97,0,0,0,0,0,0,0,80,51,32,76,101,102,116,32,50,0,0,0,0,0,0,0,80,114,111,116,82,65,77,0,84,105,109,101,32,67,114,117,105,115,101,32,73,73,0,0,109,115,52,112,108,117,115,0,109,100,95,98,105,111,104,97,122,114,98,112,0,0,0,0,98,115,116,97,114,115,50,0,70,105,114,101,32,50,0,0,69,110,97,98,108,101,0,0,74,97,112,97,110,32,40,84,97,105,116,111,32,67,111,114,112,32,108,105,99,101,110,115,101,0,0,0,0,0,0,0,111,114,108,101,103,101,110,100,0,0,0,0,0,0,0,0,103,117,110,102,114,111,110,116,106,0,0,0,0,0,0,0,50,48,48,48,48,32,53,48,48,48,48,0,0,0,0,0,112,51,32,100,111,119,110,32,50,0,0,0,0,0,0,0,73,110,115,101,99,116,111,114,32,88,32,40,87,111,114,108,100,41,0,0,0,0,0,0,68,105,102,102,105,99,117,108,116,121,63,0,0,0,0,0,52,48,48,107,0,0,0,0,83,112,101,99,105,97,108,32,67,114,105,109,105,110,97,108,32,73,110,118,101,115,116,105,103,97,116,105,111,110,32,40,74,97,112,97,110,41,0,0,118,111,108,102,105,101,100,117,0,0,0,0,0,0,0,0,56,48,107,32,50,53,48,107,0,0,0,0,0,0,0,0,112,99,101,95,116,105,109,99,114,117,115,50,0,0,0,0,77,101,116,97,108,32,83,108,117,103,32,52,32,40,78,71,72,45,50,54,51,48,41,0,0,0,0,0,0,0,0,0,53,48,107,32,111,110,108,121,0,0,0,0,0,0,0,0,66,105,111,32,72,97,122,97,114,100,32,66,97,116,116,108,101,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,51,32,116,111,32,115,116,97,114,116,47,50,32,116,111,32,99,111,110,116,105,110,117,101,0,0,0,0,0,0,0,0,97,117,100,105,111,95,100,101,118,105,99,101,0,0,0,0,74,111,74,111,39,115,32,66,105,122,97,114,114,101,32,65,100,118,101,110,116,117,114,101,58,32,72,101,114,105,116,97,103,101,32,102,111,114,32,116,104,101,32,70,117,116,117,114,101,32,47,32,74,111,74,111,32,110,111,32,75,105,109,121,111,117,32,110,97,32,66,111,117,107,101,110,58,32,77,105,114,97,105,32,101,32,110,111,32,73,115,97,110,32,40,74,97,112,97,110,32,57,57,48,57,50,55,44,32,78,79,32,67,68,41,0,0,0,0,0,67,111,116,116,111,110,32,40,115,101,116,32,51,44,32,87,111,114,108,100,44,32,70,68,49,48,57,52,32,51,49,55,45,48,49,56,49,97,41,0,0,0,0,0,0,0,0,0,80,105,116,102,97,108,108,32,73,73,32,40,110,111,116,32,101,110,99,114,121,112,116,101,100,41,0,0,0,0,0,0,74,0,0,0,117,0,0,0,110,0,0,0,101,0,0,0,0,0,0,0,0,0,0,0,87,119,97,108,108,121,76,97,115,116,89,0,0,0,0,0,49,32,67,111,105,110,32,53,48,48,32,67,114,101,100,105,116,115,0,0,0,0,0,0,80,51,32,68,111,119,110,32,50,0,0,0,0,0,0,0,82,101,100,32,70,111,120,32,87,97,114,32,80,108,97,110,101,115,32,73,73,32,40,67,104,105,110,97,44,32,115,101,116,32,50,41,0,0,0,0,49,48,48,48,48,48,48,32,53,48,48,48,48,48,48,0,52,32,67,111,105,110,115,32,83,116,97,114,116,44,32,52,32,67,111,105,110,115,32,67,111,110,116,105,110,117,101,0,51,48,48,107,44,32,54,48,48,107,0,0,0,0,0,0,53,48,107,32,50,48,48,107,0,0,0,0,0,0,0,0,83,101,114,118,105,99,101,32,109,111,100,101,0,0,0,0,84,104,117,110,100,101,114,32,66,108,97,100,101,0,0,0,109,115,108,117,103,52,104,0,78,117,109,98,101,114,32,111,102,32,70,97,117,108,116,115,0,0,0,0,0,0,0,0,109,100,95,98,105,111,104,97,122,114,98,0,0,0,0,0,115,108,111,116,51,102,99,0,77,97,100,32,83,104,97,114,107,0,0,0,0,0,0,0,102,105,114,101,32,49,0,0,105,110,115,117,102,102,105,99,105,101,110,116,32,109,101,109,111,114,121,0,0,0,0,0,115,110,111,119,98,114,111,115,119,98,0,0,0,0,0,0,69,109,97,103,32,83,111,102,116,0,0,0,0,0,0,0,106,111,121,115,116,105,99,107,95,54,98,95,115,101,108,101,99,116,91,51,93,0,0,0,51,48,107,32,84,104,101,110,32,69,118,101,114,121,32,49,48,48,107,0,0,0,0,0,66,108,111,99,107,32,66,108,111,99,107,32,40,74,97,112,97,110,32,57,49,48,57,49,48,41,0,0,0,0,0,0,112,51,32,117,112,32,50,0,77,115,46,32,80,97,99,45,77,97,110,32,40,119,105,116,104,32,115,112,101,101,100,117,112,32,104,97,99,107,41,0,0,0,0,0,0,0,0,0,50,48,48,107,44,32,53,48,48,107,0,0,0,0,0,0,112,99,101,95,116,98,108,97,100,101,0,0,0,0,0,0,77,101,103,97,0,0,0,0,78,117,118,105,115,105,111,110,32,69,110,116,101,114,116,97,105,110,109,101,110,116,0,0,71,97,109,105,110,103,32,79,112,116,105,111,110,115,0,0,110,89,77,50,54,49,48,80,111,115,105,116,105,111,110,0,43,54,32,70,97,115,116,101,114,0,0,0,0,0,0,0,68,114,118,67,80,85,51,70,105,114,101,73,82,81,0,0,107,111,118,0,0,0,0,0,80,51,32,85,112,32,50,0,49,53,48,107,44,32,51,53,48,107,0,0,0,0,0,0,112,99,101,95,98,105,107,107,117,114,105,0,0,0,0,0,67,80,83,49,32,47,32,81,83,111,117,110,100,0,0,0,84,101,114,114,97,32,67,114,101,115,116,97,32,73,73,32,45,32,77,97,110,100,111,114,97,97,32,110,111,32,71,121,97,107,117,115,104,117,117,0,0,0,0,0,0,0,0,0,77,101,116,97,108,32,83,108,117,103,32,52,32,40,78,71,77,45,50,54,51,48,41,0,0,0,0,0,0,0,0,0,103,112,105,108,111,116,115,104,0,0,0,0,0,0,0,0,66,105,109,105,110,105,32,82,117,110,32,40,85,83,65,41,0,0,0,0,0,0,0,0,78,101,111,32,71,101,111,32,77,86,83,32,115,121,115,116,101,109,0,0,0,0,0,0,88,49,45,48,49,48,0,0,68,101,108,116,97,45,84,32,82,79,77,0,0,0,0,0,49,57,52,49,32,45,32,67,111,117,110,116,101,114,32,65,116,116,97,99,107,32,40,87,111,114,108,100,41,0,0,0,83,102,50,109,100,116,83,97,109,112,108,101,83,101,108,101,99,116,50,0,0,0,0,0,109,100,95,98,97,116,109,97,110,0,0,0,0,0,0,0,80,97,116,104,32,79,112,116,105,111,110,115,0,0,0,0,80,51,32,82,105,103,104,116,32,49,0,0,0,0,0,0,66,111,110,117,115,32,84,105,109,101,0,0,0,0,0,0,83,101,116,97,32,40,86,105,115,99,111,32,76,105,99,101,110,115,101,41,0,0,0,0,115,111,117,114,99,101,0,0,99,115,99,108,117,98,97,0,112,99,101,95,116,101,114,114,97,99,114,50,0,0,0,0,114,95,120,95,112,108,117,115,0,0,0,0,0,0,0,0,109,115,108,117,103,52,0,0,109,100,95,98,105,109,105,110,105,0,0,0,0,0,0,0,115,115,114,105,100,101,114,115,106,98,100,0,0,0,0,0,67,111,115,109,105,99,32,67,111,112,32,40,87,111,114,108,100,41,0,0,0,0,0,0,80,51,32,76,101,102,116,32,49,0,0,0,0,0,0,0,83,101,116,97,32,40,82,111,109,115,116,97,114,32,76,105,99,101,110,115,101,41,0,0,84,101,110,115,101,105,114,121,117,117,32,45,32,83,97,105,110,116,32,68,114,97,103,111,110,0,0,0,0,0,0,0,66,97,110,103,32,66,101,97,100,0,0,0,0,0,0,0,66,105,108,108,32,87,97,108,115,104,32,67,111,108,108,101,103,101,32,70,111,111,116,98,97,108,108,32,57,53,32,40,85,83,65,41,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,97,118,105,110,103,32,71,97,109,101,98,111,121,32,83,82,65,77,46,10,0,0,0,0,0,0,0,0,68,101,108,116,97,84,46,97,99,99,0,0,0,0,0,0,80,51,32,68,111,119,110,32,49,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,68,105,100,110,39,116,32,102,105,110,100,32,97,110,121,32,82,79,77,83,32,116,104,97,116,32,109,97,116,99,104,101,100,32,118,97,108,105,100,32,101,120,116,101,110,115,105,111,110,115,32,102,111,114,32,108,105,98,114,101,116,114,111,32,105,109,112,108,101,109,101,110,116,97,116,105,111,110,46,10,0,0,0,70,111,114,99,101,32,49,32,76,105,102,101,0,0,0,0,73,72,68,82,0,0,0,0,112,99,101,95,115,100,114,97,103,111,110,0,0,0,0,0,98,97,110,103,98,101,97,100,0,0,0,0,0,0,0,0,109,100,95,98,105,108,108,119,108,57,53,0,0,0,0,0,103,108,71,101,116,66,117,102,102,101,114,80,111,105,110,116,101,114,118,79,69,83,0,0,105,110,118,97,108,105,100,32,98,108,111,99,107,32,116,121,112,101,0,0,0,0,0,0,80,51,32,85,112,32,49,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,71,76,93,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,76,85,84,115,46,10,0,0,0,0,0,0,0,0,71,0,0,0,97,0,0,0,110,0,0,0,114,0,0,0,121,0,0,0,117,0,0,0,0,0,0,0,102,107,0,0,53,133,0,0,204,93,0,0,65,109,0,0,24,138,0,0,0,0,0,0,0,0,0,0,50,48,48,32,83,101,99,111,110,100,115,0,0,0,0,0,66,105,108,108,32,87,97,108,115,104,32,67,111,108,108,101,103,101,32,70,111,111,116,98,97,108,108,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,71,76,93,58,32,73,110,105,116,105,97,108,105,122,105,110,103,32,72,87,32,114,101,110,100,101,114,32,40,37,117,32,120,32,37,117,41,46,10,0,0,0,0,0,112,50,32,114,105,103,104,116,32,50,0,0,0,0,0,0,51,32,67,111,105,110,115,32,51,32,67,114,101,100,105,116,115,0,0,0,0,0,0,0,71,97,110,114,121,117,32,47,32,77,117,115,97,115,104,105,32,71,97,110,114,121,117,107,105,0,0,0,0,0,0,0,109,100,95,98,105,108,108,119,108,115,104,0,0,0,0,0,105,56,55,53,49,95,118,97,108,117,101,0,0,0,0,0,98,111,111,103,119,105,110,103,0,0,0,0,0,0,0,0,80,50,32,82,105,103,104,116,32,50,0,0,0,0,0,0,79,70,70,0,0,0,0,0,84,97,116,115,117,32,78,111,32,75,111,32,70,105,103,104,116,101,114,0,0,0,0,0,109,100,95,102,105,102,97,57,55,0,0,0,0,0,0,0,103,97,110,114,121,117,0,0,75,48,53,49,57,54,48,95,115,112,114,105,116,101,102,108,105,112,0,0,0,0,0,0,87,105,115,100,111,109,32,84,114,101,101,0,0,0,0,0,75,48,53,50,49,48,57,83,99,114,111,108,108,89,91,50,93,0,0,0,0,0,0,0,70,105,114,101,32,49,0,0,83,76,79,84,45,62,107,115,108,0,0,0,0,0,0,0,67,114,105,109,101,32,70,105,103,104,116,101,114,115,32,40,74,97,112,97,110,32,50,32,80,108,97,121,101,114,115,41,0,0,0,0,0,0,0,0,112,49,32,100,111,119,110,0,68,105,115,97,98,108,101,0,72,97,117,110,116,101,100,32,67,97,115,116,108,101,32,40,118,101,114,46,32,75,41,0,0,0,0,0,0,0,0,0,72,111,110,103,32,75,111,110,103,32,40,72,111,110,101,115,116,32,84,114,97,100,105,110,103,32,76,105,99,101,110,115,101,41,0,0,0,0,0,0,84,104,101,32,77,97,105,110,32,69,118,101,110,116,32,40,52,32,80,108,97,121,101,114,115,32,118,101,114,46,32,70,41,0,0,0,0,0,0,0,73,110,118,117,108,110,101,114,97,98,105,108,105,116,121,32,40,67,104,101,97,116,41,0,79,114,105,101,110,116,97,116,105,111,110,0,0,0,0,0,71,117,110,32,38,32,70,114,111,110,116,105,101,114,32,40,87,111,114,108,100,41,0,0,50,48,48,48,48,32,55,48,48,48,48,0,0,0,0,0,112,50,32,108,101,102,116,32,50,0,0,0,0,0,0,0,65,108,105,101,110,115,32,40,87,111,114,108,100,32,115,101,116,32,50,41,0,0,0,0,115,105,108,101,110,116,100,0,115,99,105,106,0,0,0,0,86,111,108,102,105,101,100,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,82,117,115,104,39,110,32,65,116,116,97,99,107,32,40,85,83,41,0,0,0,0,0,0,54,48,107,32,50,48,48,107,0,0,0,0,0,0,0,0,112,99,101,95,116,97,116,115,117,110,111,107,0,0,0,0,67,97,112,116,97,105,110,32,84,111,109,97,100,97,121,0,0,0,0,0,0,0,0,0,52,48,48,75,32,52,48,48,75,0,0,0,0,0,0,0,66,105,98,108,101,32,65,100,118,101,110,116,117,114,101,115,32,40,85,83,65,41,0,0,112,97,114,111,100,105,117,115,101,0,0,0,0,0,0,0,106,111,106,111,98,97,110,0,97,117,100,105,111,95,98,108,111,99,107,95,102,114,97,109,101,115,0,0,0,0,0,0,124,122,105,112,0,0,0,0,112,105,116,102,97,108,108,50,117,0,0,0,0,0,0,0,87,119,97,108,108,121,76,97,115,116,88,0,0,0,0,0,66,111,116,116,111,109,32,111,102,32,116,104,101,32,78,105,110,116,104,32,40,118,101,114,46,32,78,41,0,0,0,0,83,0,0,0,117,0,0,0,107,0,0,0,101,0,0,0,98,0,0,0,97,0,0,0,110,0,0,0,32,0,0,0,74,0,0,0,97,0,0,0,110,0,0,0,115,0,0,0,105,0,0,0,32,0,0,0,82,0,0,0,121,0,0,0,117,0,0,0,107,0,0,0,111,0,0,0,32,0,0,0,40,0,0,0,115,0,0,0,101,0,0,0,116,0,0,0,32,0,0,0,49,0,0,0,44,0,0,0,32,0,0,0,83,0,0,0,121,0,0,0,115,0,0,0,116,0,0,0,101,0,0,0,109,0,0,0,32,0,0,0,49,0,0,0,54,0,0,0,65,0,0,0,44,0,0,0,32,0,0,0,70,0,0,0,68,0,0,0,49,0,0,0,48,0,0,0,56,0,0,0,57,0,0,0,66,0,0,0,32,0,0,0,51,0,0,0,49,0,0,0,55,0,0,0,45,0,0,0,53,0,0,0,48,0,0,0,50,0,0,0,49,0,0,0,41,0,0,0,0,0,0,0,185,48,0,0,177,48,0,0,208,48,0,0,243,48,0,0,192,150,0,0,235,88,0,0,32,0,0,0,220,122,0,0,80,91,0,0,0,0,0,0,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,84,71,65,32,112,105,120,101,108,115,46,10,0,0,0,0,49,32,67,111,105,110,32,49,48,48,32,67,114,101,100,105,116,115,0,0,0,0,0,0,83,117,112,101,114,32,67,111,110,116,114,97,32,40,74,97,112,97,110,41,0,0,0,0,80,50,32,76,101,102,116,32,50,0,0,0,0,0,0,0,114,101,100,102,111,120,119,112,50,97,0,0,0,0,0,0,51,48,48,48,48,48,32,49,48,48,48,48,48,48,0,0,226,48,0,0,176,48,0,0,233,48,0,0,199,48,0,0,195,48,0,0,187,48,0,0,0,0,0,0,77,0,0,0,111,0,0,0,103,0,0,0,117,0,0,0,114,0,0,0,97,0,0,0,32,0,0,0,68,0,0,0,101,0,0,0,115,0,0,0,115,0,0,0,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,51,48,75,44,32,69,118,101,114,121,32,52,48,75,0,0,75,111,110,97,109,105,32,39,56,56,0,0,0,0,0,0,84,97,116,115,117,106,105,110,32,40,80,114,111,116,111,116,121,112,101,41,0,0,0,0,99,116,111,109,97,100,97,121,0,0,0,0,0,0,0,0,109,100,95,98,105,98,108,101,97,100,118,0,0,0,0,0,116,121,112,104,111,111,110,0,68,114,118,70,103,83,99,114,111,108,108,89,0,0,0,0,82,111,108,108,101,114,103,97,109,101,115,32,40,74,97,112,97,110,41,0,0,0,0,0,109,97,100,115,104,97,114,107,0,0,0,0,0,0,0,0,102,105,114,101,32,0,0,0,67,111,110,116,114,97,32,40,85,83,44,32,83,101,116,32,50,41,0,0,0,0,0,0,74,117,109,112,105,110,103,32,80,111,112,32,40,115,101,116,32,50,41,0,0,0,0,0,88,45,77,101,110,32,40,52,32,80,108,97,121,101,114,115,32,118,101,114,32,65,69,65,41,0,0,0,0,0,0,0,98,108,111,99,107,106,0,0,83,117,114,112,114,105,115,101,32,65,116,116,97,99,107,32,40,65,115,105,97,32,118,101,114,46,32,76,41,0,0,0,112,50,32,100,111,119,110,32,50,0,0,0,0,0,0,0,109,115,112,97,99,109,110,102,0,0,0,0,0,0,0,0,50,48,75,44,32,69,118,101,114,121,32,51,48,75,0,0,115,104,97,100,101,114,0,0,77,97,106,117,117,32,110,111,32,79,104,107,111,107,117,0,0,0,0,0,0,0,0,0,112,99,101,95,116,97,116,115,117,106,105,110,112,0,0,0,66,97,116,116,108,101,32,70,108,105,112,32,83,104,111,116,0,0,0,0,0,0,0,0,66,101,121,111,110,100,32,90,101,114,111,32,84,111,108,101,114,97,110,99,101,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,41,0,0,81,117,97,114,116,104,32,40,74,97,112,97,110,41,0,0,110,97,109,49,57,55,53,0,71,114,97,100,105,117,115,32,73,73,73,32,40,74,97,112,97,110,41,0,0,0,0,0,43,53,32,70,97,115,116,101,114,0,0,0,0,0,0,0,83,46,80,46,89,46,32,45,32,83,112,101,99,105,97,108,32,80,114,111,106,101,99,116,32,89,32,40,85,83,32,118,101,114,46,32,77,41,0,0,68,114,118,67,80,85,50,70,105,114,101,73,82,81,0,0,71,121,114,117,115,115,32,40,67,101,110,116,117,114,105,41,0,0,0,0,0,0,0,0,79,0,0,0,114,0,0,0,105,0,0,0,101,0,0,0,110,0,0,0,116,0,0,0,97,0,0,0,108,0,0,0,32,0,0,0,76,0,0,0,101,0,0,0,103,0,0,0,101,0,0,0,110,0,0,0,100,0,0,0,32,0,0,0,83,0,0,0,117,0,0,0,112,0,0,0,101,0,0,0,114,0,0,0,0,0,0,0,127,137,0,0,56,110,0,0,202,145,0,0,132,83,0,0,32,79,0,0,32,0,0,0,83,0,0,0,117,0,0,0,112,0,0,0,101,0,0,0,114,0,0,0,32,0,0,0,40,0,0,0,86,0,0,0,49,0,0,0,48,0,0,0,51,0,0,0,44,0,0,0,32,0,0,0,67,0,0,0,104,0,0,0,105,0,0,0,110,0,0,0,97,0,0,0,44,0,0,0,32,0,0,0,84,0,0,0,101,0,0,0,110,0,0,0,99,0,0,0,101,0,0,0,110,0,0,0,116,0,0,0,41,0,0,0,32,0,0,0,40,0,0,0,117,0,0,0,110,0,0,0,112,0,0,0,114,0,0,0,111,0,0,0,116,0,0,0,101,0,0,0,99,0,0,0,116,0,0,0,101,0,0,0,100,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,86,101,110,100,101,116,116,97,32,40,87,111,114,108,100,32,52,32,80,108,97,121,101,114,115,32,118,101,114,46,32,82,41,0,0,0,0,0,0,0,80,50,32,68,111,119,110,32,50,0,0,0,0,0,0,0,49,57,88,88,32,45,32,116,104,101,32,119,97,114,32,97,103,97,105,110,115,116,32,100,101,115,116,105,110,121,32,40,57,53,49,50,48,55,32,65,115,105,97,41,0,0,0,0,50,48,75,32,79,110,108,121,0,0,0,0,0,0,0,0,67,97,100,105,108,108,97,99,115,32,38,32,68,105,110,111,115,97,117,114,115,32,40,57,51,48,50,48,49,32,101,116,99,41,0,0,0,0,0,0,71,97,110,103,32,66,117,115,116,101,114,115,32,40,115,101,116,32,50,41,0,0,0,0,84,97,116,115,117,106,105,110,0,0,0,0,0,0,0,0,102,108,105,112,115,104,111,116,0,0,0,0,0,0,0,0,71,104,111,115,116,32,80,105,108,111,116,115,32,40,78,71,77,45,48,50,48,41,40,78,71,72,45,48,50,48,41,0,0,0,0,0,0,0,0,0,109,100,95,98,101,121,111,110,100,122,116,0,0,0,0,0,84,104,101,32,83,105,109,112,115,111,110,115,32,40,52,32,80,108,97,121,101,114,115,32,87,111,114,108,100,44,32,115,101,116,32,50,41,0,0,0,80,111,111,121,97,110,32,40,83,116,101,114,110,41,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,67,111,117,108,100,110,39,116,32,102,105,110,100,32,111,118,101,114,108,97,121,32,99,97,108,108,101,100,58,32,34,37,115,34,46,10,0,0,0,0,83,116,114,101,101,116,115,32,111,102,32,82,97,103,101,32,40,69,117,114,111,44,32,85,83,65,41,32,126,32,66,97,114,101,32,75,110,117,99,107,108,101,32,45,32,73,107,97,114,105,32,110,111,32,84,101,116,115,117,107,101,110,32,40,74,112,110,41,0,0,0,0,84,101,101,110,97,103,101,32,77,117,116,97,110,116,32,78,105,110,106,97,32,84,117,114,116,108,101,115,32,40,85,83,32,52,32,80,108,97,121,101,114,115,44,32,115,101,116,32,49,41,0,0,0,0,0,0,73,110,112,117,116,32,79,112,116,105,111,110,115,0,0,0,67,104,101,97,116,58,32,35,37,117,32,91,37,115,93,58,32,37,115,0,0,0,0,0,53,48,75,32,50,48,48,75,32,50,48,48,75,43,0,0,112,50,32,117,112,32,50,0,50,39,49,48,0,0,0,0,66,108,111,99,107,32,67,97,114,110,105,118,97,108,0,0,115,99,97,108,101,95,37,115,37,117,0,0,0,0,0,0,60,47,0,0,0,0,0,0,67,97,112,99,111,109,32,83,112,111,114,116,115,32,67,108,117,98,32,40,57,55,48,55,50,50,32,69,117,114,111,41,0,0,0,0,0,0,0,0,68,121,110,97,98,108,97,115,116,101,114,32,47,32,66,111,109,98,101,114,32,77,97,110,0,0,0,0,0,0,0,0,112,99,101,95,116,97,116,115,117,106,105,110,0,0,0,0,108,95,121,95,109,105,110,117,115,0,0,0,0,0,0,0,66,114,101,97,107,101,114,115,32,82,101,118,101,110,103,101,0,0,0,0,0,0,0,0,77,105,99,114,111,32,87,111,114,108,100,0,0,0,0,0,83,117,110,115,101,116,32,82,105,100,101,114,115,32,40,52,32,80,108,97,121,101,114,115,32,118,101,114,46,32,74,65,67,41,0,0,0,0,0,0,75,117,110,103,45,70,117,32,77,97,115,116,101,114,32,40,68,97,116,97,32,69,97,115,116,41,0,0,0,0,0,0,99,111,115,109,99,99,111,112,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,9,80,111,115,115,105,98,108,101,32,118,97,108,117,101,115,58,10,0,0,0,86,105,103,105,108,97,110,116,101,32,40,87,111,114,108,100,44,32,115,101,116,32,50,41,0,0,0,0,0,0,0,0,80,50,32,85,112,32,50,0,104,111,111,107,117,0,0,0,84,104,117,110,100,101,114,32,38,32,76,105,103,104,116,110,105,110,103,32,50,0,0,0,84,97,107,101,100,97,32,83,104,105,110,103,101,110,32,40,65,108,116,41,0,0,0,0,98,114,101,97,107,114,101,118,0,0,0,0,0,0,0,0,84,104,101,32,75,105,99,107,32,66,111,120,105,110,103,32,40,74,112,110,44,32,75,111,114,41,0,0,0,0,0,0,82,45,84,121,112,101,32,40,74,97,112,97,110,41,0,0,67,104,105,112,37,105,86,111,108,84,97,98,108,101,0,0,82,101,116,114,111,65,114,99,104,58,32,82,84,67,58,32,37,115,10,0,0,0,0,0,102,98,97,45,100,105,97,103,110,111,115,116,105,99,115,0,80,50,32,82,105,103,104,116,32,49,0,0,0,0,0,0,51,48,75,44,32,69,118,101,114,121,32,57,48,75,0,0,83,97,118,101,32,115,116,97,116,101,0,0,0,0,0,0,112,99,101,95,115,104,105,110,103,101,110,49,0,0,0,0,80,117,122,122,108,101,32,68,101,32,80,111,110,33,32,82,33,0,0,0,0,0,0,0,109,100,95,107,105,99,107,98,111,120,0,0,0,0,0,0,71,105,103,97,109,97,110,50,68,117,109,109,121,81,115,110,100,82,97,109,0,0,0,0,83,104,50,69,120,116,91,105,93,46,115,117,115,112,101,110,100,0,0,0,0,0,0,0,65,108,108,32,82,97,109,0,80,50,32,76,101,102,116,32,49,0,0,0,0,0,0,0,51,48,75,44,32,69,118,101,114,121,32,54,48,75,0,0,98,108,107,104,111,108,101,0,82,46,80,67,0,0,0,0,84,97,107,101,100,97,32,83,104,105,110,103,101,110,0,0,112,117,122,122,108,100,112,114,0,0,0,0,0,0,0,0,51,48,48,32,83,101,99,111,110,100,115,0,0,0,0,0,66,101,115,116,32,111,102,32,116,104,101,32,66,101,115,116,32,45,32,67,104,97,109,112,105,111,110,115,104,105,112,32,75,97,114,97,116,101,32,40,69,117,114,111,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,0,0,78,111,32,83,111,117,110,100,32,40,77,67,85,32,110,111,116,32,100,117,109,112,101,100,41,0,0,0,0,0,0,0,80,50,32,68,111,119,110,32,49,0,0,0,0,0,0,0,50,48,75,44,32,69,118,101,114,121,32,55,48,75,0,0,109,54,56,48,53,32,82,101,103,105,115,116,101,114,115,0,112,99,101,95,115,104,105,110,103,101,110,0,0,0,0,0,66,114,101,97,107,101,114,115,0,0,0,0,0,0,0,0,71,105,103,97,109,97,110,32,50,58,32,84,104,101,32,80,111,119,101,114,32,70,105,103,104,116,101,114,115,32,40,98,111,111,116,108,101,103,41,0,0,0,0,0,0,0,0,0,109,100,95,98,101,115,116,111,102,112,0,0,0,0,0,0,107,48,53,51,50,54,48,32,114,101,103,115,32,37,100,0,80,50,32,85,112,32,49,0,50,48,75,44,32,69,118,101,114,121,32,53,48,75,0,0,84,97,107,97,104,97,115,104,105,32,77,101,105,106,105,110,32,110,111,32,83,104,105,110,32,66,111,117,107,101,110,106,105,109,97,0,0,0,0,0,69,108,101,99,116,114,111,32,66,114,97,105,110,0,0,0,115,101,110,103,111,107,117,50,0,0,0,0,0,0,0,0,80,49,32,70,105,114,101,32,49,0,0,0,0,0,0,0,103,105,103,97,109,97,110,50,0,0,0,0,0,0,0,0,83,116,97,103,101,32,101,100,105,116,0,0,0,0,0,0,70,105,103,104,116,101,114,32,99,111,117,110,116,115,0,0,85,46,83,46,65,32,40,84,97,105,116,111,32,67,111,114,112,32,108,105,99,101,110,115,101,41,0,0,0,0,0,0,89,101,97,114,32,68,105,115,112,108,97,121,0,0,0,0,103,117,110,102,114,111,110,116,0,0,0,0,0,0,0,0,51,48,48,48,48,32,55,48,48,48,48,0,0,0,0,0,112,49,32,114,105,103,104,116,32,50,0,0,0,0,0,0,105,110,115,101,99,116,120,0,69,97,115,116,32,84,101,99,104,110,111,108,111,103,121,0,83,112,101,99,105,97,108,32,67,114,105,109,105,110,97,108,32,73,110,118,101,115,116,105,103,97,116,105,111,110,32,40,87,111,114,108,100,32,115,101,116,32,50,41,0,0,0,0,118,111,108,102,105,101,100,106,111,0,0,0,0,0,0,0,112,99,101,95,116,97,107,97,109,101,105,98,0,0,0,0,78,101,111,32,68,114,105,102,116,32,79,117,116,32,45,32,78,101,119,32,84,101,99,104,110,111,108,111,103,121,0,0,51,48,48,75,32,52,48,48,75,0,0,0,0,0,0,0,66,101,115,116,32,111,102,32,116,104,101,32,66,101,115,116,32,45,32,67,104,97,109,112,105,111,110,115,104,105,112,32,75,97,114,97,116,101,32,40,85,83,65,41,0,0,0,0,85,115,101,32,116,117,114,98,111,32,115,104,105,102,116,101,114,0,0,0,0,0,0,0,184,48,0,0,231,48,0,0,184,48,0,0,231,48,0,0,110,48,0,0,32,0,0,0,71,89,0,0,153,89,0,0,106,48,0,0,146,81,0,0,122,150,0,0,58,0,0,0,32,0,0,0,42,103,0,0,101,103,0,0,120,48,0,0,110,48,0,0,122,144,0,0,35,117,0,0,0,0,0,0,74,0,0,0,111,0,0,0,74,0,0,0,111,0,0,0,39,0,0,0,115,0,0,0,32,0,0,0,66,0,0,0,105,0,0,0,122,0,0,0,97,0,0,0,114,0,0,0,114,0,0,0,101,0,0,0,32,0,0,0,65,0,0,0,100,0,0,0,118,0,0,0,101,0,0,0,110,0,0,0,116,0,0,0,117,0,0,0,114,0,0,0,101,0,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,32,0,0,0,57,0,0,0,57,0,0,0,48,0,0,0,57,0,0,0,50,0,0,0,55,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,97,117,100,105,111,95,111,117,116,95,114,97,116,101,0,0,99,111,116,116,111,110,0,0,215,48,0,0,237,48,0,0,174,48,0,0,162,48,0,0,110,48,0,0,80,93,0,0,32,0,0,0,40,0,0,0,80,0,0,0,114,0,0,0,111,0,0,0,103,0,0,0,101,0,0,0,97,0,0,0,114,0,0,0,32,0,0,0,78,0,0,0,111,0,0,0,32,0,0,0,65,0,0,0,114,0,0,0,97,0,0,0,115,0,0,0,104,0,0,0,105,0,0,0,32,0,0,0,48,0,0,0,49,0,0,0,48,0,0,0,49,0,0,0,49,0,0,0,55,0,0,0,32,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,44,0,0,0,32,0,0,0,100,0,0,0,101,0,0,0,99,0,0,0,114,0,0,0,121,0,0,0,112,0,0,0,116,0,0,0,101,0,0,0,100,0,0,0,32,0,0,0,115,0,0,0,101,0,0,0,116,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,80,105,116,102,97,108,108,32,73,73,32,40,51,49,53,45,53,48,57,51,44,32,70,108,105,99,107,121,32,67,111,110,118,101,114,115,105,111,110,41,0,0,0,0,0,0,0,0,65,0,0,0,112,0,0,0,114,0,0,0,105,0,0,0,108,0,0,0,0,0,0,0,87,119,97,108,108,121,84,114,97,99,107,50,89,0,0,0,84,114,105,97,108,32,84,105,109,101,0,0,0,0,0,0,49,32,67,111,105,110,32,53,48,32,67,114,101,100,105,116,115,0,0,0,0,0,0,0,80,49,32,82,105,103,104,116,32,50,0,0,0,0,0,0,110,86,66,108,97,110,107,0,5,125,0,0,100,91,0,0,48,98,0,0,95,106,0,0,73,0,0,0,73,0,0,0,0,0,0,0,82,0,0,0,101,0,0,0,100,0,0,0,32,0,0,0,70,0,0,0,111,0,0,0,120,0,0,0,32,0,0,0,87,0,0,0,97,0,0,0,114,0,0,0,32,0,0,0,80,0,0,0,108,0,0,0,97,0,0,0,110,0,0,0,101,0,0,0,115,0,0,0,32,0,0,0,73,0,0,0,73,0,0,0,32,0,0,0,40,0,0,0,67,0,0,0,104,0,0,0,105,0,0,0,110,0,0,0,97,0,0,0,44,0,0,0,32,0,0,0,115,0,0,0,101,0,0,0,116,0,0,0,32,0,0,0,49,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,48,48,48,48,32,51,48,48,48,48,48,0,0,0,0,65,108,108,32,82,101,103,105])
.concat([115,116,101,114,115,0,0,0,84,97,105,116,111,32,67,104,97,115,101,32,72,46,81,46,0,0,0,0,0,0,0,0,49,32,67,114,101,100,105,116,32,47,32,51,32,71,97,109,101,115,0,0,0,0,0,0,109,100,95,98,101,115,116,111,102,0,0,0,0,0,0,0,68,114,118,70,103,83,99,114,111,108,108,88,0,0,0,0,80,114,111,103,101,97,114,32,78,111,32,65,114,97,115,104,105,32,40,48,49,48,49,49,55,32,74,97,112,97,110,44,32,100,101,99,114,121,112,116,101,100,32,115,101,116,41,0,0,0,0,0,0,0,0,0,84,111,101,105,32,47,32,66,97,110,112,114,101,115,116,111,0,0,0,0,0,0,0,0,120,45,97,120,105,115,45,112,111,115,0,0,0,0,0,0,84,104,101,32,87,105,110,116,101,114,32,66,111,98,98,108,101,32,40,98,111,111,116,108,101,103,41,0,0,0,0,0,106,117,109,112,112,111,112,101,0,0,0,0,0,0,0,0,73,56,48,51,57,82,101,103,115,0,0,0,0,0,0,0,51,48,48,48,48,32,57,48,48,48,48,32,57,48,48,48,48,0,0,0,0,0,0,0,79,110,108,121,32,53,32,84,105,109,101,115,0,0,0,0,66,108,111,99,107,32,66,108,111,99,107,32,40,87,111,114,108,100,32,57,49,48,57,49,48,41,0,0,0,0,0,0,112,49,32,108,101,102,116,32,50,0,0,0,0,0,0,0,77,83,32,80,97,99,109,97,110,0,0,0,0,0,0,0,112,99,101,95,99,104,97,115,101,104,113,0,0,0,0,0,71,111,97,108,33,32,71,111,97,108,33,32,71,111,97,108,33,0,0,0,0,0,0,0,84,104,101,32,66,101,114,101,110,115,116,97,105,110,32,66,101,97,114,115,39,32,67,97,109,112,105,110,103,32,65,100,118,101,110,116,117,114,101,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,53,51,48,41,0,0,0,51,48,107,32,56,48,107,0,112,114,111,103,101,97,114,106,98,108,0,0,0,0,0,0,83,108,111,119,32,77,111,116,105,111,110,0,0,0,0,0,43,52,32,70,97,115,116,101,114,0,0,0,0,0,0,0,68,114,118,67,80,85,49,70,105,114,101,73,82,81,0,0,37,48,56,120,58,32,71,49,32,85,110,100,101,102,105,110,101,100,32,84,104,117,109,98,32,105,110,115,116,114,117,99,116,105,111,110,58,32,37,48,52,120,10,0,0,0,0,0,53,48,48,48,48,48,32,112,111,105,110,116,115,0,0,0,65,82,77,32,82,101,103,105,115,116,101,114,115,0,0,0,79,114,105,101,110,116,97,108,32,76,101,103,101,110,100,32,83,112,101,99,105,97,108,32,45,32,88,105,32,89,111,32,71,105,32,83,104,105,32,82,101,32,90,117,97,110,103,32,83,117,112,101,114,32,40,86,49,48,51,44,32,67,104,105,110,97,44,32,84,101,110,99,101,110,116,41,32,40,117,110,112,114,111,116,101,99,116,101,100,41,0,0,0,0,0,0,80,49,32,76,101,102,116,32,50,0,0,0,0,0,0,0,83,117,115,97,110,111,111,32,68,101,110,115,101,116,115,117,0,0,0,0,0,0,0,0,103,111,97,108,120,51,0,0,109,100,95,98,101,114,101,110,115,112,49,49,0,0,0,0,88,45,77,101,110,32,118,115,32,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,40,57,54,49,48,48,52,32,85,83,65,32,80,104,111,101,110,105,120,32,69,100,105,116,105,111,110,41,0,0,0,0,72,68,54,51,48,57,67,80,85,67,111,110,116,101,120,116,91,105,93,46,110,67,121,99,108,101,115,84,111,116,97,108,0,0,0,0,0,0,0,0,109,100,95,115,111,114,97,0,65,117,100,105,111,32,79,112,116,105,111,110,115,0,0,0,53,48,75,32,49,48,48,75,32,49,48,48,75,43,0,0,112,49,32,100,111,119,110,32,50,0,0,0,0,0,0,0,50,39,48,48,0,0,0,0,67,111,110,116,105,110,117,101,32,76,105,109,105,116,0,0,115,99,97,108,101,95,116,121,112,101,95,37,115,37,117,0,99,115,99,108,117,98,49,0,112,99,101,95,115,117,115,97,110,111,0,0,0,0,0,0,108,95,121,95,112,108,117,115,0,0,0,0,0,0,0,0,78,101,111,32,77,114,46,32,68,111,33,0,0,0,0,0,84,104,101,32,66,101,114,101,110,115,116,97,105,110,32,66,101,97,114,115,39,32,67,97,109,112,105,110,103,32,65,100,118,101,110,116,117,114,101,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,53,50,54,41,0,0,0,115,115,114,105,100,101,114,115,106,97,99,0,0,0,0,0,120,109,118,115,102,117,49,100,0,0,0,0,0,0,0,0,80,49,32,68,111,119,110,32,50,0,0,0,0,0,0,0,110,83,101,107,67,80,85,84,121,112,101,91,105,93,0,0,83,117,112,101,114,32,86,111,108,108,101,121,98,97,108,108,0,0,0,0,0,0,0,0,110,101,111,109,114,100,111,0,109,100,95,98,101,114,101,110,115,112,49,50,0,0,0,0,88,45,77,101,110,32,45,32,99,104,105,108,100,114,101,110,32,111,102,32,116,104,101,32,97,116,111,109,32,40,57,53,48,49,48,53,32,69,117,114,111,32,80,104,111,101,110,105,120,32,69,100,105,116,105,111,110,41,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,82,77,58,32,37,115,10,0,0,0,0,0,114,101,116,114,111,97,114,99,104,46,99,0,0,0,0,0,112,49,32,117,112,32,50,0,90,56,48,69,65,91,105,93,0,0,0,0,0,0,0,0,112,99,101,95,115,118,111,108,108,101,121,0,0,0,0,0,84,97,105,116,111,32,40,86,105,115,99,111,32,108,105,99,101,110,115,101,41,0,0,0,84,104,101,32,66,101,114,101,110,115,116,97,105,110,32,66,101,97,114,115,39,32,67,97,109,112,105,110,103,32,65,100,118,101,110,116,117,114,101,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,53,50,51,41,0,0,0,120,109,99,111,116,97,114,49,100,0,0,0,0,0,0,0,112,116,114,45,62,110,67,121,99,108,101,115,84,111,116,97,108,0,0,0,0,0,0,0,80,49,32,85,112,32,50,0,83,117,112,101,114,32,83,116,97,114,32,83,111,108,100,105,101,114,0,0,0,0,0,0,80,117,122,122,108,101,32,68,101,32,80,111,110,33,0,0,52,48,48,32,83,101,99,111,110,100,115,0,0,0,0,0,109,100,95,98,101,114,101,110,115,112,49,51,0,0,0,0,110,71,97,108,67,121,99,108,101,115,68,111,110,101,0,0,82,45,62,112,112,99,0,0,86,97,109,112,105,114,101,32,83,97,118,105,111,114,32,50,32,45,32,116,104,101,32,108,111,114,100,32,111,102,32,118,97,109,112,105,114,101,32,40,57,55,48,57,49,51,32,74,97,112,97,110,32,80,104,111,101,110,105,120,32,69,100,105,116,105,111,110,41,0,0,0,104,54,50,56,48,32,82,101,103,105,115,116,101,114,115,32,102,111,114,32,67,104,105,112,32,35,37,100,0,0,0,0,114,111,104,103,97,0,0,0,80,49,32,82,105,103,104,116,32,49,0,0,0,0,0,0,112,99,101,95,115,115,115,111,108,100,114,0,0,0,0,0,112,117,122,122,108,101,100,112,0,0,0,0,0,0,0,0,84,104,101,32,66,101,114,101,110,115,116,97,105,110,32,66,101,97,114,115,39,32,67,97,109,112,105,110,103,32,65,100,118,101,110,116,117,114,101,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,53,49,57,41,0,0,0,118,115,97,118,50,100,0,0,71,97,108,78,111,105,115,101,87,97,118,101,80,111,115,0,80,49,32,76,101,102,116,32,49,0,0,0,0,0,0,0,83,117,112,101,114,32,77,111,109,111,116,97,114,111,117,32,68,101,110,116,101,116,115,117,32,73,73,0,0,0,0,0,109,100,95,98,101,114,101,110,115,112,49,52,0,0,0,0,49,57,57,50,0,0,0,0,98,97,103,109,97,110,0,0,80,49,32,70,105,114,101,0,86,97,109,112,105,114,101,32,72,117,110,116,101,114,32,50,32,45,32,100,97,114,107,115,116,97,108,107,101,114,115,32,114,101,118,101,110,103,101,32,40,57,55,48,57,49,51,32,74,97,112,97,110,32,80,104,111,101,110,105,120,32,69,100,105,116,105,111,110,41,0,0,112,49,32,117,112,0,0,0,68,101,109,111,32,115,111,117,110,100,0,0,0,0,0,0,49,48,48,48,48,48,32,111,110,108,121,0,0,0,0,0,78,111,32,101,120,116,114,97,0,0,0,0,0,0,0,0,78,111,32,115,97,118,101,0,67,111,105,110,32,80,101,114,32,80,108,97,121,32,68,105,115,112,108,97,121,0,0,0,82,117,110,97,114,107,32,40,74,97,112,97,110,41,0,0,51,48,48,48,48,32,49,48,48,48,48,48,0,0,0,0,80,49,32,68,111,119,110,32,49,0,0,0,0,0,0,0,50,32,87,97,121,0,0,0,83,101,108,32,70,101,101,110,97,0,0,0,0,0,0,0,115,99,105,97,0,0,0,0,86,111,108,102,105,101,100,32,40,74,97,112,97,110,44,32,114,101,118,105,115,105,111,110,32,49,41,0,0,0,0,0,52,48,107,32,49,48,48,107,0,0,0,0,0,0,0,0,112,99,101,95,115,109,111,109,111,50,0,0,0,0,0,0,65,110,100,114,111,32,68,117,110,111,115,32,40,78,71,77,45,48,52,57,41,40,78,71,72,45,48,52,57,41,0,0,50,48,48,75,32,52,48,48,75,0,0,0,0,0,0,0,84,104,101,32,66,101,114,101,110,115,116,97,105,110,32,66,101,97,114,115,39,32,67,97,109,112,105,110,103,32,65,100,118,101,110,116,117,114,101,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,53,49,55,41,0,0,0,74,111,74,111,39,115,32,66,105,122,97,114,114,101,32,65,100,118,101,110,116,117,114,101,58,32,72,101,114,105,116,97,103,101,32,102,111,114,32,116,104,101,32,70,117,116,117,114,101,32,47,32,74,111,74,111,32,110,111,32,75,105,109,121,111,117,32,110,97,32,66,111,117,107,101,110,58,32,77,105,114,97,105,32,101,32,110,111,32,73,115,97,110,32,40,74,97,112,97,110,32,57,57,48,57,50,55,41,0,0,0,0,97,117,100,105,111,95,101,110,97,98,108,101,0,0,0,0,66,117,108,108,101,116,32,40,70,68,49,48,57,52,32,51,49,55,45,48,48,52,49,41,0,0,0,0,0,0,0,0,118,104,117,110,116,50,100,0,112,105,116,102,97,108,108,50,97,0,0,0,0,0,0,0,77,0,0,0,97,0,0,0,114,0,0,0,99,0,0,0,104,0,0,0,0,0,0,0,122,101,114,111,119,105,110,103,0,0,0,0,0,0,0,0,87,119,97,108,108,121,84,114,97,99,107,50,88,0,0,0,70,99,114,97,115,104,83,97,109,112,108,101,83,101,108,101,99,116,49,0,0,0,0,0,83,117,107,101,98,97,110,32,74,97,110,115,105,32,82,121,117,107,111,32,40,115,101,116,32,49,44,32,83,121,115,116,101,109,32,49,54,65,44,32,70,68,49,48,56,57,66,32,51,49,55,45,53,48,50,49,41,0,0,0,0,0,0,0,55,48,48,48,48,48,48,0,50,48,48,32,67,114,101,100,105,116,115,0,0,0,0,0,80,49,32,85,112,32,49,0,82,101,100,32,70,111,120,32,87,97,114,32,80,108,97,110,101,115,32,73,73,32,40,67,104,105,110,97,44,32,115,101,116,32,49,41,0,0,0,0,49,53,48,48,48,48,32,52,48,48,48,48,48,0,0,0,72,111,114,105,122,111,110,116,97,108,32,83,99,114,101,101,110,32,70,108,105,112,0,0,53,116,104,0,0,0,0,0,83,117,112,101,114,32,77,111,109,111,116,97,114,111,117,32,68,101,110,116,101,116,115,117,0,0,0,0,0,0,0,0,97,110,100,114,111,100,117,110,0,0,0,0,0,0,0,0,50,32,67,114,101,100,105,116,115,32,47,32,53,32,71,97,109,101,115,0,0,0,0,0,86,97,109,112,105,114,101,32,83,97,118,105,111,114,32,45,32,116,104,101,32,108,111,114,100,32,111,102,32,118,97,109,112,105,114,101,32,40,57,55,48,53,49,57,32,69,117,114,111,32,80,104,111,101,110,105,120,32,69,100,105,116,105,111,110,41,0,0,0,0,0,0,109,100,95,98,101,114,101,110,115,112,49,53,0,0,0,0,68,114,118,66,103,83,99,114,111,108,108,89,0,0,0,0,99,104,105,112,45,62,112,108,97,121,105,110,103,0,0,0,77,97,115,107,101,100,32,82,105,100,101,114,115,32,67,108,117,98,32,66,97,116,116,108,101,32,82,97,99,101,0,0,114,105,103,104,116,0,0,0,119,105,110,116,98,111,98,0,80,50,32,98,117,116,116,111,110,32,57,0,0,0,0,0,51,48,48,48,48,32,56,48,48,48,48,32,56,48,48,48,48,0,0,0,0,0,0,0,79,110,108,121,32,51,32,84,105,109,101,115,0,0,0,0,98,108,111,99,107,0,0,0,109,115,112,97,99,109,97,110,0,0,0,0,0,0,0,0,86,101,114,116,105,99,97,108,32,83,99,114,101,101,110,32,70,108,105,112,0,0,0,0,112,99,101,95,115,109,111,109,111,0,0,0,0,0,0,0,80,0,0,0,111,0,0,0,112,0,0,0,32,0,0,0,39,0,0,0,110,0,0,0,32,0,0,0,66,0,0,0,111,0,0,0,117,0,0,0,110,0,0,0,99,0,0,0,101,0,0,0,0,0,0,0,172,48,0,0,195,48,0,0,221,48,0,0,234,48,0,0,243,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,98,97,116,114,105,100,101,114,0,0,0,0,0,0,0,0,84,104,101,32,66,101,114,101,110,115,116,97,105,110,32,66,101,97,114,115,39,32,67,97,109,112,105,110,103,32,65,100,118,101,110,116,117,114,101,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,53,49,49,41,0,0,0,50,48,107,32,56,48,107,0,118,115,97,118,100,0,0,0,69,118,101,114,121,32,55,48,48,48,48,32,47,32,89,101,115,0,0,0,0,0,0,0,43,51,32,70,97,115,116,101,114,0,0,0,0,0,0,0,69,120,116,101,110,100,101,100,32,80,108,97,121,0,0,0,67,112,115,82,97,109,57,48,0,0,0,0,0,0,0,0,107,111,118,115,104,95,99,111,117,110,116,101,114,0,0,0,100,105,110,111,0,0,0,0,83,117,112,101,114,32,77,101,116,97,108,32,67,114,117,115,104,101,114,0,0,0,0,0,80,111,112,32,39,110,32,66,111,117,110,99,101,32,47,32,71,97,112,112,111,114,105,110,0,0,0,0,0,0,0,0,76,101,97,103,117,101,32,66,111,119,108,105,110,103,32,40,78,71,77,45,48,49,57,41,40,78,71,72,45,48,49,57,41,0,0,0,0,0,0,0,109,100,95,98,101,114,101,110,115,112,49,54,0,0,0,0,83,117,112,101,114,32,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,32,88,32,45,32,103,114,97,110,100,32,109,97,115,116,101,114,32,99,104,97,108,108,101,110,103,101,32,40,115,117,112,101,114,32,115,116,114,101,101,116,32,102,105,103,104,116,101,114,32,50,32,88,32,57,52,48,50,50,51,32,74,97,112,97,110,32,80,104,111,101,110,105,120,32,69,100,105,116,105,111,110,41,0,0,0,0,0,0,102,105,120,101,105,103,104,116,0,0,0,0,0,0,0,0,83,116,114,101,101,116,115,32,111,102,32,82,97,103,101,32,40,69,117,114,111,44,32,85,83,65,44,32,82,101,118,46,32,65,41,32,126,32,66,97,114,101,32,75,110,117,99,107,108,101,32,45,32,73,107,97,114,105,32,110,111,32,84,101,116,115,117,107,101,110,32,40,74,112,110,44,32,82,101,118,46,32,65,41,0,0,0,0,86,105,100,101,111,32,79,112,116,105,111,110,115,0,0,0,52,48,75,32,56,48,75,32,56,48,75,43,0,0,0,0,52,48,48,48,48,48,0,0,49,39,53,48,0,0,0,0,116,104,117,110,100,101,114,120,95,49,102,57,56,95,100,97,116,97,0,0,0,0,0,0,50,48,48,75,44,32,69,118,101,114,121,32,50,48,48,75,0,0,0,0,0,0,0,0,67,97,112,99,111,109,32,83,112,111,114,116,115,32,67,108,117,98,32,40,57,55,49,48,49,55,32,69,117,114,111,41,0,0,0,0,0,0,0,0,112,99,101,95,115,109,99,114,117,115,104,0,0,0,0,0,108,95,120,95,109,105,110,117,115,0,0,0,0,0,0,0,112,111,112,98,111,117,110,99,0,0,0,0,0,0,0,0,84,104,101,32,66,101,114,101,110,115,116,97,105,110,32,66,101,97,114,115,39,32,67,97,109,112,105,110,103,32,65,100,118,101,110,116,117,114,101,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,53,48,54,41,0,0,0,83,117,110,115,101,116,32,82,105,100,101,114,115,32,40,52,32,80,108,97,121,101,114,115,32,118,101,114,46,32,65,68,68,41,0,0,0,0,0,0,115,115,102,50,120,106,100,0,51,48,48,48,48,48,0,0,118,102,105,118,101,0,0,0,83,116,114,105,112,32,70,105,103,104,116,101,114,32,73,73,0,0,0,0,0,0,0,0,65,101,114,111,32,70,105,103,104,116,101,114,115,32,51,32,47,32,83,111,110,105,99,32,87,105,110,103,115,32,51,0,0,0,0,0,0,0,0,0,109,100,95,98,101,114,101,110,115,112,49,55,0,0,0,0,83,117,112,101,114,32,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,32,84,117,114,98,111,32,40,115,117,112,101,114,32,115,116,114,101,101,116,32,102,105,103,104,116,101,114,32,50,32,88,32,57,52,48,50,50,51,32,65,115,105,97,32,80,104,111,101,110,105,120,32,69,100,105,116,105,111,110,41,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,97,118,105,110,103,32,114,101,103,117,108,97,114,32,83,82,65,77,46,10,0,0,0,0,0,0,0,0,76,111,97,100,32,115,116,97,116,101,0,0,0,0,0,0,112,99,101,95,115,116,114,105,112,102,50,0,0,0,0,0,84,104,101,32,66,101,114,101,110,115,116,97,105,110,32,66,101,97,114,115,39,32,67,97,109,112,105,110,103,32,65,100,118,101,110,116,117,114,101,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,51,50,51,41,0,0,0,115,115,102,50,116,97,100,0,116,105,103,101,114,104,0,0,49,53,48,48,48,48,0,0,71,97,108,97,120,105,97,110,32,40,82,101,99,114,101,97,116,105,118,111,115,32,70,114,97,110,99,111,32,83,46,65,46,32,83,112,97,110,105,115,104,32,98,111,111,116,108,101,103,41,0,0,0,0,0,0,67,112,115,66,111,111,116,108,101,103,83,112,114,105,116,101,82,97,109,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,39,32,45,32,67,104,97,109,112,105,111,110,32,69,100,105,116,105,111,110,0,0,0,65,101,114,111,32,70,105,103,104,116,101,114,115,32,50,32,47,32,83,111,110,105,99,32,87,105,110,103,115,32,50,0,0,0,0,0,0,0,0,0,109,100,95,98,101,114,101,110,115,112,50,48,0,0,0,0,83,117,112,101,114,32,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,32,84,117,114,98,111,32,40,115,117,112,101,114,32,115,116,114,101,101,116,32,102,105,103,104,116,101,114,32,50,32,88,32,57,52,48,50,50,51,32,101,116,99,32,80,104,111,101,110,105,120,32,69,100,105,116,105,111,110,41,0,0,0,0,0,98,97,99,107,102,105,114,101,0,0,0,0,0,0,0,0,67,80,85,32,115,116,97,114,116,115,32,119,105,116,104,32,43,54,32,112,116,115,0,0,112,99,101,95,115,102,50,99,101,0,0,0,0,0,0,0,84,104,101,32,66,101,114,101,110,115,116,97,105,110,32,66,101,97,114,115,39,32,67,97,109,112,105,110,103,32,65,100,118,101,110,116,117,114,101,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,54,49,48,41,0,0,0,116,101,107,105,112,97,107,105,0,0,0,0,0,0,0,0,115,115,102,50,116,100,0,0,65,32,49,67,47,49,80,32,32,66,32,49,67,47,53,80,0,0,0,0,0,0,0,0,83,110,100,82,111,109,66,97,110,107,0,0,0,0,0,0,50,80,32,51,58,48,48,32,124,32,51,80,32,51,58,51,48,32,124,32,52,80,32,52,58,48,48,0,0,0,0,0,115,102,122,104,99,104,0,0,83,116,114,97,116,101,103,111,0,0,0,0,0,0,0,0,109,100,95,98,101,114,101,110,115,112,48,57,0,0,0,0,80,49,32,66,111,109,98,0,83,117,112,101,114,32,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,32,45,32,116,104,101,32,116,111,117,114,110,97,109,101,110,116,32,98,97,116,116,108,101,32,40,57,51,49,49,49,57,32,101,116,99,32,80,104,111,101,110,105,120,32,69,100,105,116,105,111,110,41,0,0,0,0,83,99,114,101,101,110,32,102,108,105,112,0,0,0,0,0,65,32,50,67,47,49,80,32,32,66,32,49,67,47,51,80,0,0,0,0,0,0,0,0,85,46,83,46,65,0,0,0,53,48,48,48,48,32,111,110,108,121,0,0,0,0,0,0,116,114,117,120,116,111,110,50,0,0,0,0,0,0,0,0,69,117,114,111,112,101,32,40,84,97,105,116,111,32,67,111,114,112,32,108,105,99,101,110,115,101,41,0,0,0,0,0,83,97,118,101,0,0,0,0,80,117,115,104,32,83,116,97,114,116,32,116,111,32,83,107,105,112,32,83,116,97,103,101,32,40,67,104,101,97,116,41,0,0,0,0,0,0,0,0,114,117,110,97,114,107,0,0,66,111,110,117,115,95,76,105,102,101,0,0,0,0,0,0,50,80,32,50,58,51,48,32,124,32,51,80,32,51,58,48,48,32,124,32,52,80,32,51,58,51,48,0,0,0,0,0,48,49,48,48,49,49,49,49,49,49,0,0,0,0,0,0,78,97,117,103,104,116,121,32,80,105,99,115,0,0,0,0,49,32,87,97,121,0,0,0,83,112,101,99,105,97,108,32,67,114,105,109,105,110,97,108,32,73,110,118,101,115,116,105,103,97,116,105,111,110,32,40,87,111,114,108,100,32,115,101,116,32,49,41,0,0,0,0,118,111,108,102,105,101,100,106,0,0,0,0,0,0,0,0,112,99,101,95,115,116,114,97,116,101,103,111,0,0,0,0,80,111,119,101,114,32,83,112,105,107,101,115,32,73,73,32,40,78,71,77,45,48,54,56,41,0,0,0,0,0,0,0,49,48,48,75,32,52,48,48,75,0,0,0,0,0,0,0,115,115,102,50,116,98,100,0,84,104,101,32,66,101,114,101,110,115,116,97,105,110,32,66,101,97,114,115,39,32,67,97,109,112,105,110,103,32,65,100,118,101,110,116,117,114,101,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,54,48,50,41,0,0,0,106,111,106,111,98,97,0,0,105,110,112,117,116,95,108,105,98,114,101,116,114,111,95,100,101,118,105,99,101,95,112,37,117,0,0,0,0,0,0,0,98,117,108,108,101,116,0,0,75,48,53,52,53,51,57,32,76,97,116,99,104,32,37,100,0,0,0,0,0,0,0,0,80,105,116,102,97,108,108,32,73,73,32,40,51,49,53,45,53,48,57,51,41,0,0,0,70,0,0,0,101,0,0,0,98,0,0,0,114,0,0,0,117,0,0,0,97,0,0,0,114,0,0,0,121,0,0,0,0,0,0,0,0,0,0,0,87,119,97,108,108,121,84,114,97,99,107,49,89,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,77,111,118,105,101,32,102,105,108,101,32,105,115,32,110,111,116,32,97,32,118,97,108,105,100,32,66,83,86,49,32,102,105,108,101,46,10,0,0,0,0,0,0,53,48,48,48,48,48,48,0,49,53,48,32,67,114,101,100,105,116,115,0,0,0,0,0,50,80,32,50,58,48,48,32,124,32,51,80,32,50,58,51,48,32,124,32,52,80,32,51,58,48,48,0,0,0,0,0,114,101,100,102,111,120,119,112,50,0,0,0,0,0,0,0,115,102,122,101,99,104,0,0,52,116,104,0,0,0,0,0,83,112,108,97,116,116,101,114,104,111,117,115,101,0,0,0,50,32,80,108,97,121,101,114,32,67,111,110,116,105,110,117,101,0,0,0,0,0,0,0,109,100,95,98,101,114,101,110,115,112,49,48,0,0,0,0,68,114,118,66,103,83,99,114,111,108,108,88,0,0,0,0,83,117,112,101,114,32,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,32,45,32,116,104,101,32,110,101,119,32,99,104,97,108,108,101,110,103,101,114,115,32,40,115,117,112,101,114,32,115,116,114,101,101,116,32,102,105,103,104,116,101,114,32,50,32,57,51,48,57,49,49,32,85,83,65,32,80,104,111,101,110,105,120,32,69,100,105,116,105,111,110,41,0,0,0,0,0,0,0,107,97,109,101,110,114,105,100,0,0,0,0,0,0,0,0,120,45,97,120,105,115,45,110,101,103,0,0,0,0,0,0,74,117,109,112,105,110,103,32,80,111,112,32,40,115,101,116,32,49,41,0,0,0,0,0,69,110,97,98,108,101,100,0,81,117,105,122,32,83,97,110,103,111,107,117,115,104,105,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,50,80,32,49,58,51,48,32,124,32,51,80,32,50,58,48,48,32,124,32,52,80,32,50,58,51,48,0,0,0,0,0,78,101,119,112,117,99,50,98,0,0,0,0,0,0,0,0,50,32,67,114,101,100,105,116,115,0,0,0,0,0,0,0,98,97,116,115,117,103,117,110,0,0,0,0,0,0,0,0,72,101,114,98,105,101,32,97,116,32,116,104,101,32,79,108,121,109,112,105,99,115,32,40,68,75,32,99,111,110,118,101,114,115,105,111,110,41,0,0,68,101,109,111,0,0,0,0,112,99,101,95,115,112,108,97,116,116,104,0,0,0,0,0,70,0,0,0,105,0,0,0,103,0,0,0,104,0,0,0,116,0,0,0,32,0,0,0,70,0,0,0,101,0,0,0,118,0,0,0,101,0,0,0,114,0,0,0,0,0,0,0,85,198,0,0,17,201,0,0,85,198,0,0,32,0,0,0,40,0,0,0,115,0,0,0,101,0,0,0,116,0,0,0,32,0,0,0,50,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,115,115,102,50,117,100,0,0,84,104,101,32,66,101,114,101,110,115,116,97,105,110,32,66,101,97,114,115,39,32,67,97,109,112,105,110,103,32,65,100,118,101,110,116,117,114,101,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,55,50,48,41,0,0,0,50,48,107,32,55,48,107,0,68,101,109,111,32,83,111,117,110,100,115,32,79,110,0,0,103,97,108,97,120,105,97,110,97,0,0,0,0,0,0,0,75,48,48,55,50,51,50,32,67,104,105,112,32,35,32,37,100,0,0,0,0,0,0,0,69,118,101,114,121,32,53,48,48,48,48,32,47,32,78,111,0,0,0,0,0,0,0,0,43,50,32,70,97,115,116,101,114,0,0,0,0,0,0,0,83,101,109,105,45,65,117,116,111,109,97,116,105,99,0,0,107,111,118,115,104,95,108,111,119,108,97,116,99,104,95,54,56,107,95,119,0,0,0,0,111,108,100,115,49,48,51,116,0,0,0,0,0,0,0,0,86,83,32,84,105,109,101,0,50,32,80,108,97,121,101,114,32,71,97,109,101,0,0,0,115,102,122,98,99,104,0,0,114,97,108,108,121,98,105,107,0,0,0,0,0,0,0,0,67,0,0,0,97,0,0,0,112,0,0,0,99,0,0,0,111,0,0,0,109,0,0,0,32,0,0,0,87,0,0,0,111,0,0,0,114,0,0,0,108,0,0,0,100,0,0,0,32,0,0,0,50,0,0,0,32,0,0,0,40,0,0,0,175,48,0,0,164,48,0,0,186,48,0,0,21,255,0,0,32,0,0,0,66,48,0,0,105,48,0,0,121,48,0,0,147,48,0,0,97,48,0,0,131,48,0,0,252,48,0,0,79,48,0,0,68,48,0,0,90,48,0,0,32,0,0,0,75,48,0,0,119,48,0,0,83,48,0,0,147,48,0,0,143,48,0,0,252,48,0,0,139,48,0,0,105,48,0,0,18,255,0,0,32,0,0,0,57,0,0,0,50,0,0,0,48,0,0,0,54,0,0,0,49,0,0,0,49,0,0,0,32,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,83,112,105,114,97,108,32,87,97,118,101,0,0,0,0,0,70,105,103,104,116,32,70,101,118,101,114,32,40,115,101,116,32,50,41,0,0,0,0,0,109,115,53,112,99,98,110,100,0,0,0,0,0,0,0,0,109,100,95,98,101,114,101,110,115,112,48,54,0,0,0,0,83,117,112,101,114,32,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,32,45,32,116,104,101,32,110,101,119,32,99,104,97,108,108,101,110,103,101,114,115,32,40,115,117,112,101,114,32,115,116,114,101,101,116,32,102,105,103,104,116,101,114,32,50,32,57,51,48,57,49,49,32,101,116,99,32,80,104,111,101,110,105,120,32,69,100,105,116,105,111,110,41,0,0,0,0,0,0,0,109,100,95,115,111,114,0,0,78,111,32,111,112,116,105,111,110,115,32,97,118,97,105,108,97,98,108,101,46,0,0,0,51,48,75,32,55,48,75,32,55,48,75,43,0,0,0,0,68,117,110,107,115,104,111,116,84,114,97,99,107,52,89,0,49,39,52,48,0,0,0,0,50,32,67,111,105,110,115,32,54,32,67,114,101,100,105,116,115,0,0,0,0,0,0,0,99,115,99,108,117,98,0,0,112,99,101,95,115,112,105,114,119,97,118,101,0,0,0,0,108,95,120,95,112,108,117,115,0,0,0,0,0,0,0,0,102,105,103,104,116,102,101,118,97,0,0,0,0,0,0,0,115,115,102,50,100,0,0,0,84,104,101,32,66,101,114,101,110,115,116,97,105,110,32,66,101,97,114,115,39,32,67,97,109,112,105,110,103,32,65,100,118,101,110,116,117,114,101,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,55,49,54,41,0,0,0,115,115,114,105,100,101,114,115,97,100,100,0,0,0,0,0,99,54,50,56,48,32,67,104,105,112,32,35,48,0,0,0,99,110,105,110,106,97,49,0,115,110,111,119,98,114,111,50,0,0,0,0,0,0,0,0,68,117,110,107,115,104,111,116,84,114,97,99,107,52,88,0,51,32,67,111,105,110,115,47,55,32,67,114,101,100,105,116,115,0,0,0,0,0,0,0,83,112,105,110,32,80,97,105,114,0,0,0,0,0,0,0,70,0,0,0,105,0,0,0,103,0,0,0,104,0,0,0,116,0,0,0,32,0,0,0,70,0,0,0,101,0,0,0,118,0,0,0,101,0,0,0,114,0,0,0,0,0,0,0,85,198,0,0,17,201,0,0,85,198,0,0,32,0,0,0,40,0,0,0,115,0,0,0,101,0,0,0,116,0,0,0,32,0,0,0,49,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,109,100,95,98,101,114,101,110,115,112,48,55,0,0,0,0,83,117,112,101,114,32,80,117,122,122,108,101,32,70,105,103,104,116,101,114,32,73,73,32,88,32,40,83,117,112,101,114,32,80,117,122,122,108,101,32,70,105,103,104,116,101,114,32,50,32,88,32,57,54,48,53,51,49,32,74,97,112,97,110,32,80,104,111,101,110,105,120,32,69,100,105,116,105,111,110,41,0,0,0,0,0,0,0,102,97,105,108,101,100,0,0,72,117,110,99,104,98,97,99,107,32,79,108,121,109,112,105,99,32,40,83,99,114,97,109,98,108,101,32,104,97,114,100,119,97,114,101,41,0,0,0,106,111,101,109,97,99,114,97,0,0,0,0,0,0,0,0,68,117,110,107,115,104,111,116,84,114,97,99,107,51,89,0,50,32,67,111,105,110,115,32,52,32,67,114,101,100,105,116,115,0,0,0,0,0,0,0,65,116,116,101,109,112,116,32,116,111,32,119,114,105,116,101,32,119,111,114,100,32,118,97,108,117,101,32,37,120,32,116,111,32,108,111,99,97,116,105,111,110,32,37,120,10,0,0,112,99,101,95,115,112,105,110,112,97,105,114,0,0,0,0,86,105,99,99,111,109,0,0,84,104,101,32,66,101,114,101,110,115,116,97,105,110,32,66,101,97,114,115,39,32,67,97,109,112,105,110,103,32,65,100,118,101,110,116,117,114,101,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,55,48,57,41,0,0,0,115,112,102,50,120,106,100,0,68,117,110,107,115,104,111,116,84,114,97,99,107,51,88,0,103,97,108,97,120,114,102,0,115,102,97,99,104,0,0,0,83,112,101,99,105,97,108,32,67,114,105,109,105,110,97,108,32,73,110,118,101,115,116,105,103,97,116,105,111,110,0,0,70,105,103,104,116,32,70,101,118,101,114,32,40,115,101,116,32,49,41,0,0,0,0,0,97,99,116,102,97,110,99,114,49,0,0,0,0,0,0,0,109,100,95,98,101,114,101,110,115,112,48,56,0,0,0,0,83,117,112,101,114,32,80,117,122,122,108,101,32,70,105,103,104,116,101,114,32,73,73,32,84,117,114,98,111,32,40,83,117,112,101,114,32,80,117,122,122,108,101,32,70,105,103,104,116,101,114,32,50,32,84,117,114,98,111,32,57,54,48,54,50,48,32,85,83,65,32,80,104,111,101,110,105,120,32,69,100,105,116,105,111,110,41,0,0,0,0,0,0,0,0,0,104,110,99,104,111,108,109,115,0,0,0,0,0,0,0,0,68,117,110,107,115,104,111,116,84,114,97,99,107,50,89,0,112,99,101,95,115,99,105,0,102,105,103,104,116,102,101,118,0,0,0,0,0,0,0,0,84,104,101,32,66,101,114,101,110,115,116,97,105,110,32,66,101,97,114,115,39,32,67,97,109,112,105,110,103,32,65,100,118,101,110,116,117,114,101,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,56,48,56,41,0,0,0,107,98,97,115,104,50,0,0,115,112,102,50,116,100,0,0,72,117,110,99,104,98,97,99,107,32,40,83,99,114,97,109,98,108,101,32,104,97,114,100,119,97,114,101,41,0,0,0,115,105,100,101,112,99,107,116,106,0,0,0,0,0,0,0,84,111,103,103,108,101,0,0,68,117,110,107,115,104,111,116,84,114,97,99,107,50,88,0,70,111,114,99,101,32,67,111,105,110,97,103,101,32,40,72,97,108,102,41,0,0,0,0,119,111,102,102,114,0,0,0,83,112,97,99,101,32,73,110,118,97,100,101,114,115,32,45,32,70,117,107,107,97,116,115,117,32,110,111,32,72,105,0,0,0,0,0,0,0,0,0,100,105,101,116,103,111,117,0,109,100,95,98,101,114,101,110,115,112,48,49,0,0,0,0,107,111,116,109,50,0,0,0,80,49,32,83,104,111,116,32,50,0,0,0,0,0,0,0,67,104,97,110,45,62,101,110,118,0,0,0,0,0,0,0,83,117,112,101,114,32,71,101,109,32,70,105,103,104,116,101,114,32,77,105,110,105,32,77,105,120,32,40,57,55,48,57,48,52,32,85,83,65,32,80,104,111,101,110,105,120,32,69,100,105,116,105,111,110,41,0,0,0,0,0,0,0,0,0,112,49,32,115,116,97,114,116,0,0,0,0,0,0,0,0,78,111,32,101,120,116,114,97,32,112,108,97,121,101,114,0,104,117,110,99,104,98,107,115,0,0,0,0,0,0,0,0,85,46,83,46,65,32,40,65,109,101,114,105,99,97,110,32,83,97,109,109,121,32,99,111,114,112,46,41,0,0,0,0,53,48,48,48,48,44,32,50,48,48,48,48,48,0,0,0,49,48,48,48,48,48,48,32,50,48,48,48,48,48,48,0,99,98,117,115,116,101,114,119,0,0,0,0,0,0,0,0,83,99,111,114,101,32,114,97,110,107,105,110,103,0,0,0,71,114,111,119,108,32,40,85,83,41,0,0,0,0,0,0,112,101,110,100,105,110,103,95,110,109,105,0,0,0,0,0,68,117,110,107,115,104,111,116,84,114,97,99,107,49,89,0,73,109,112,101,114,102,101,99,116,32,103,114,97,112,104,105,99,115,0,0,0,0,0,0,115,101,108,102,101,101,110,97,0,0,0,0,0,0,0,0,115,99,105,0,0,0,0,0,86,111,108,102,105,101,100,32,40,87,111,114,108,100,44,32,114,101,118,105,115,105,111,110,32,49,41,0,0,0,0,0,112,99,101,95,115,112,97,99,101,105,110,118,0,0,0,0,84,101,99,109,111,32,87,111,114,108,100,32,83,111,99,99,101,114,32,39,57,54,0,0,98,103,97,114,101,103,103,97,0,0,0,0,0,0,0,0,84,104,101,32,66,101,114,101,110,115,116,97,105,110,32,66,101,97,114,115,39,32,67,97,109,112,105,110,103,32,65,100,118,101,110,116,117,114,101,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,56,48,53,41,0,0,0,74,0,0,0,111,0,0,0,74,0,0,0,111,0,0,0,39,0,0,0,115,0,0,0,32,0,0,0,86,0,0,0,101,0,0,0,110,0,0,0,116,0,0,0,117,0,0,0,114,0,0,0,101,0,0,0,0,0,0,0,184,48,0,0,231,48,0,0,184,48,0,0,231,48,0,0,110,48,0,0,32,0,0,0,71,89,0,0,153,89,0,0,106,48,0,0,146,81,0,0,122,150,0,0,32,0,0,0,40,0,0,0,65,0,0,0,115,0,0,0,105,0,0,0,97,0,0,0,32,0,0,0,57,0,0,0,56,0,0,0,49,0,0,0,50,0,0,0,48,0,0,0,50,0,0,0,44,0,0,0,32,0,0,0,78,0,0,0,79,0,0,0,32,0,0,0,67,0,0,0,68,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,105,110,112,117,116,95,112,108,97,121,101,114,37,117,95,106,111,121,112,97,100,95,105,110,100,101,120,0,0,0,0,0,66,108,111,120,101,101,100,32,40,83,121,115,116,101,109,32,49,54,66,44,32,80,83,50,32,100,97,116,97,32,102,105,108,101,41,0,0,0,0,0,115,103,101,109,102,100,0,0,112,105,116,102,97,108,108,50,0,0,0,0,0,0,0,0,74,0,0,0,97,0,0,0,110,0,0,0,117,0,0,0,97,0,0,0,114,0,0,0,121,0,0,0,0,0,0,0,87,119,97,108,108,121,84,114,97,99,107,49,88,0,0,0,83,101,110,107,111,0,0,0,115,106,114,121,117,107,111,49,0,0,0,0,0,0,0,0,49,48,48,32,67,114,101,100,105,116,115,0,0,0,0,0,68,117,110,107,115,104,111,116,84,114,97,99,107,49,88,0,118,97,112,111,114,116,114,97,51,0,0,0,0,0,0,0,71,117,97,114,100,105,97,110,32,83,116,111,114,109,32,40,71,101,114,109,97,110,121,41,0,0,0,0,0,0,0,0,84,105,109,101,114,32,115,112,101,101,100,0,0,0,0,0,115,102,50,99,101,104,0,0,67,104,97,109,112,105,111,110,115,104,105,112,32,71,97,109,101,0,0,0,0,0,0,0,83,112,97,99,101,32,72,97,114,114,105,101,114,0,0,0,65,0,0,0,105,0,0,0,114,0,0,0,32,0,0,0,71,0,0,0,97,0,0,0,108,0,0,0,108,0,0,0,101,0,0,0,116,0,0,0,0,0,0,0,162,48,0,0,239,48,0,0,166,48,0,0,174,48,0,0,227,48,0,0,236,48,0,0,195,48,0,0,200,48,0,0,32,0,0,0,40,0,0,0,72,0,0,0,111,0,0,0,110,0,0,0,103,0,0,0,32,0,0,0,75,0,0,0,111,0,0,0,110,0,0,0,103,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,116,119,115,57,54,0,0,0,109,100,95,98,101,114,101,110,115,112,48,50,0,0,0,0,68,114,118,66,103,84,105,108,101,66,97,115,101,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,90,101,114,111,32,51,32,40,57,56,48,54,50,57,32,74,97,112,97,110,32,80,104,111,101,110,105,120,32,69,100,105,116,105,111,110,41,0,0,0,0,72,101,120,32,80,111,111,108,32,40,83,101,110,107,111,41,0,0,0,0,0,0,0,0,84,115,117,98,117,114,97,121,97,32,80,114,111,100,46,32,47,32,66,97,110,112,114,101,115,116,111,0,0,0,0,0,108,101,102,116,0,0,0,0,83,110,111,119,32,66,114,111,115,46,32,45,32,78,105,99,107,32,38,32,84,111,109,32,40,68,111,111,121,111,110,103,32,108,105,99,101,110,115,101,41,0,0,0,0,0,0,0,102,105,114,101,115,104,114,107,0,0,0,0,0,0,0,0,68,105,115,97,98,108,101,100,0,0,0,0,0,0,0,0,80,50,32,98,117,116,116,111,110,32,56,0,0,0,0,0,113,115,97,110,103,111,107,117,0,0,0,0,0,0,0,0,110,101,119,112,117,99,50,98,0,0,0,0,0,0,0,0,103,117,110,115,109,111,107,101,95,115,99,114,111,108,108,121,0,0,0,0,0,0,0,0,112,99,101,95,115,104,97,114,114,105,101,114,0,0,0,0,55,48,48,48,48,32,49,52,48,48,48,48,32,50,49,48,48,48,48,0,0,0,0,0,83,0,0,0,117,0,0,0,112,0,0,0,101,0,0,0,114,0,0,0,32,0,0,0,68,0,0,0,111,0,0,0,100,0,0,0,103,0,0,0,101,0,0,0,32,0,0,0,66,0,0,0,97,0,0,0,108,0,0,0,108,0,0,0,0,0,0,0,79,48,0,0,107,48,0,0,74,48,0,0,110,48,0,0,177,113,0,0,64,136,0,0,216,149,0,0,3,116,0,0,29,79,0,0,172,138,0,0,0,0,0,0,0,0,0,0,0,0,0,0,115,102,122,51,106,114,50,100,0,0,0,0,0,0,0,0,83,99,114,101,101,110,32,83,116,111,112,0,0,0,0,0,84,104,101,32,66,101,114,101,110,115,116,97,105,110,32,66,101,97,114,115,39,32,67,97,109,112,105,110,103,32,65,100,118,101,110,116,117,114,101,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,56,48,51,41,0,0,0,50,48,107,32,54,48,107,0,68,101,109,111,32,83,111,117,110,100,115,32,79,102,102,0,66,111,110,117,115,32,76,105,102,101,32,47,32,67,111,110,116,105,110,117,101,0,0,0,104,101,120,112,111,111,108,97,0,0,0,0,0,0,0,0,52,48,107,32,97,110,100,32,57,48,107,0,0,0,0,0,43,49,32,70,97,115,116,101,114,0,0,0,0,0,0,0,107,111,118,115,104,95,104,105,103,104,108,97,116,99,104,95,54,56,107,95,119,0,0,0,103,104,111,120,0,0,0,0,79,0,0,0,114,0,0,0,105,0,0,0,101,0,0,0,110,0,0,0,116,0,0,0,97,0,0,0,108,0,0,0,32,0,0,0,76,0,0,0,101,0,0,0,103,0,0,0,101,0,0,0,110,0,0,0,100,0,0,0,32,0,0,0,83,0,0,0,117,0,0,0,112,0,0,0,101,0,0,0,114,0,0,0,0,0,0,0,127,137,0,0,56,110,0,0,202,145,0,0,132,83,0,0,32,79,0,0,32,0,0,0,83,0,0,0,117,0,0,0,112,0,0,0,101,0,0,0,114,0,0,0,32,0,0,0])
.concat([40,0,0,0,86,0,0,0,49,0,0,0,48,0,0,0,48,0,0,0,32,0,0,0,97,0,0,0,108,0,0,0,116,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,112,50,32,102,105,114,101,32,49,49,0,0,0,0,0,0,83,116,111,99,107,0,0,0,66,101,32,66,97,108,108,0,0,0,0,0,0,0,0,0,115,102,50,99,101,98,114,0,67,97,112,99,111,109,32,87,111,114,108,100,32,50,32,40,57,50,48,54,49,49,32,74,97,112,97,110,41,0,0,0,77,101,100,105,97,32,82,105,110,103,115,32,67,111,114,112,111,114,97,116,105,111,110,0,83,117,112,101,114,32,68,111,100,103,101,32,66,97,108,108,32,47,32,75,117,110,105,111,32,110,111,32,78,101,107,107,101,116,115,117,32,84,111,117,107,121,117,117,32,68,101,110,115,101,116,115,117,0,0,0,66,117,114,110,105,110,103,32,70,105,103,104,116,32,40,112,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,65,108,112,104,97,32,51,32,40,57,56,48,57,48,52,32,85,83,65,32,80,104,111,101,110,105,120,32,69,100,105,116,105,111,110,41,0,0,0,0,0,109,100,95,98,101,114,101,110,115,112,48,51,0,0,0,0,84,105,109,101,32,75,101,101,112,101,114,32,82,65,77,0,116,104,110,100,122,111,110,101,97,0,0,0,0,0,0,0,83,104,105,110,107,97,105,0,65,114,116,32,65,108,105,118,101,32,40,87,111,114,108,100,41,0,0,0,0,0,0,0,69,115,116,105,109,97,116,101,100,32,77,111,110,105,116,111,114,32,70,80,83,0,0,0,80,50,32,67,104,97,115,101,0,0,0,0,0,0,0,0,49,39,51,48,0,0,0,0,102,108,111,97,116,95,102,114,97,109,101,98,117,102,102,101,114,37,117,0,0,0,0,0,119,149,0,0,95,108,0,0,32,0,0,0,40,0,0,0,67,0,0,0,104,0,0,0,111,0,0,0,107,0,0,0,111,0,0,0,32,0,0,0,48,0,0,0,49,0,0,0,48,0,0,0,56,0,0,0,50,0,0,0,48,0,0,0,32,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,83,111,107,111,98,97,110,32,87,111,114,108,100,0,0,0,116,117,114,98,111,0,0,0,115,100,111,100,103,101,98,0,107,98,97,115,104,0,0,0,115,102,97,51,117,100,0,0,84,104,101,32,66,101,114,101,110,115,116,97,105,110,32,66,101,97,114,115,39,32,67,97,109,112,105,110,103,32,65,100,118,101,110,116,117,114,101,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,56,48,50,41,0,0,0,83,117,110,115,101,116,32,82,105,100,101,114,115,32,40,50,32,80,108,97,121,101,114,115,32,118,101,114,46,32,65,66,68,41,0,0,0,0,0,0,99,104,105,112,45,62,114,104,121,116,104,109,0,0,0,0,72,101,120,32,80,111,111,108,32,40,83,104,105,110,107,97,105,41,0,0,0,0,0,0,112,107,116,103,97,108,100,120,106,0,0,0,0,0,0,0,112,50,32,102,105,114,101,32,49,48,0,0,0,0,0,0,118,111,105,99,101,45,62,115,105,103,110,97,108,0,0,0,78,111,46,32,49,44,51,0,109,98,111,109,98,114,100,117,0,0,0,0,0,0,0,0,112,99,101,95,115,111,107,111,98,97,110,0,0,0,0,0,86,0,0,0,111,0,0,0,108,0,0,0,116,0,0,0,97,0,0,0,103,0,0,0,101,0,0,0,32,0,0,0,70,0,0,0,105,0,0,0,103,0,0,0,104,0,0,0,116,0,0,0,101,0,0,0,114,0,0,0,32,0,0,0,45,0,0,0,32,0,0,0,71,0,0,0,111,0,0,0,119,0,0,0,99,0,0,0,97,0,0,0,105,0,0,0,122,0,0,0,101,0,0,0,114,0,0,0,0,0,0,0,133,141,0,0,186,78,0,0,102,91,0,0,18,87,0,0,180,48,0,0,166,48,0,0,171,48,0,0,164,48,0,0,182,48,0,0,252,48,0,0,0,0,0,0,0,0,0,0,109,100,95,98,101,114,101,110,115,112,48,52,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,90,101,114,111,32,50,32,65,108,112,104,97,32,40,57,54,48,56,50,54,32,65,115,105,97,32,80,104,111,101,110,105,120,32,69,100,105,116,105,111,110,41,0,0,0,0,0,0,0,115,117,99,99,101,101,100,101,100,0,0,0,0,0,0,0,104,101,120,112,111,111,108,0,118,105,109,97,110,97,0,0,78,111,46,32,50,0,0,0,70,97,115,116,32,102,111,114,119,97,114,100,32,104,111,108,100,0,0,0,0,0,0,0,83,111,110,32,83,111,110,32,73,73,0,0,0,0,0,0,86,111,108,116,97,103,101,32,70,105,103,104,116,101,114,32,45,32,71,111,119,99,97,105,122,101,114,32,47,32,67,104,111,117,106,105,110,32,71,97,107,117,101,110,32,71,111,119,99,97,105,122,101,114,0,0,107,97,114,110,111,118,97,0,84,104,101,32,66,101,114,101,110,115,116,97,105,110,32,66,101,97,114,115,39,32,67,97,109,112,105,110,103,32,65,100,118,101,110,116,117,114,101,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,56,48,49,41,0,0,0,115,102,122,50,97,108,100,0,83,116,97,116,117,115,32,40,83,104,105,110,107,97,105,32,76,105,99,101,110,115,101,41,0,0,0,0,0,0,0,0,112,50,32,102,105,114,101,32,57,0,0,0,0,0,0,0,78,111,46,32,49,44,50,0,84,101,115,116,32,82,79,77,0,0,0,0,0,0,0,0,111,117,116,122,111,110,101,0,109,98,111,109,98,114,100,104,0,0,0,0,0,0,0,0,112,99,101,95,115,111,110,115,111,110,50,0,0,0,0,0,109,100,95,98,101,114,101,110,115,112,48,53,0,0,0,0,110,83,112,114,105,116,101,66,117,102,102,101,114,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,90,101,114,111,32,50,32,40,57,54,48,50,50,55,32,74,97,112,97,110,32,80,104,111,101,110,105,120,32,69,100,105,116,105,111,110,41,0,0,0,0,82,97,99,107,32,43,32,82,111,108,108,0,0,0,0,0,80,50,32,67,104,97,110,103,101,0,0,0,0,0,0,0,78,111,46,32,51,0,0,0,83,111,108,100,105,101,114,32,66,108,97,100,101,32,83,112,101,99,105,97,108,32,45,32,67,97,114,97,118,97,110,32,83,116,97,103,101,0,0,0,84,104,101,32,66,101,114,101,110,115,116,97,105,110,32,66,101,97,114,115,39,32,67,97,109,112,105,110,103,32,65,100,118,101,110,116,117,114,101,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,52,50,57,41,0,0,0,115,102,122,50,106,100,0,0,116,114,117,120,116,111,110,0,77,83,77,53,50,48,53,78,101,120,116,0,0,0,0,0,112,50,32,102,105,114,101,32,56,0,0,0,0,0,0,0,110,89,77,90,50,56,48,66,73,82,81,83,116,97,116,117,115,0,0,0,0,0,0,0,103,104,111,115,116,98,51,0,78,111,46,32,50,44,51,0,109,98,111,109,98,114,100,97,0,0,0,0,0,0,0,0,112,99,101,95,115,111,108,100,98,108,97,115,0,0,0,0,68,111,117,98,108,101,32,68,114,97,103,111,110,32,40,78,101,111,45,71,101,111,41,0,0,0,0,0,0,0,0,0,109,100,95,98,101,114,101,110,115,112,49,56,0,0,0,0,80,49,32,83,104,111,116,32,49,0,0,0,0,0,0,0,83,104,111,116,32,66,117,116,116,111,110,32,116,111,32,83,116,97,114,116,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,90,101,114,111,32,50,32,40,57,54,48,50,50,55,32,65,115,105,97,32,80,104,111,101,110,105,120,32,69,100,105,116,105,111,110,41,0,0,0,0,0,50,48,48,48,48,48,48,32,101,97,99,104,0,0,0,0,114,97,99,107,110,114,111,108,0,0,0,0,0,0,0,0,51,48,48,48,48,44,32,49,48,48,48,48,48,0,0,0,83,111,117,116,104,32,69,97,115,116,32,65,115,105,97,32,40,84,97,105,116,111,32,67,111,114,112,32,108,105,99,101,110,115,101,41,0,0,0,0,85,75,32,40,74,80,32,76,101,105,115,117,114,101,32,76,116,100,41,0,0,0,0,0,78,111,32,87,97,114,110,105,110,103,32,115,99,114,101,101,110,0,0,0,0,0,0,0,49,32,67,111,105,110,32,32,56,32,67,114,101,100,105,116,115,0,0,0,0,0,0,0,103,114,111,119,108,117,0,0,68,114,118,78,109,105,69,110,97,98,108,101,0,0,0,0,80,50,32,72,105,0,0,0,73,110,102,105,110,105,116,101,32,40,67,104,101,97,116,41,0,0,0,0,0,0,0,0,78,111,46,32,49,0,0,0,77,105,100,119,97,121,47,84,97,105,116,111,32,67,111,114,112,111,114,97,116,105,111,110,0,0,0,0,0,0,0,0,82,97,99,105,110,103,32,66,101,97,116,32,40,87,111,114,108,100,41,0,0,0,0,0,118,111,108,102,105,101,100,0,83,111,108,100,105,101,114,32,66,108,97,100,101,0,0,0,69,110,101,109,121,32,83,104,111,116,115,0,0,0,0,0,84,104,101,32,66,101,114,101,110,115,116,97,105,110,32,66,101,97,114,115,39,32,67,97,109,112,105,110,103,32,65,100,118,101,110,116,117,114,101,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,52,50,56,41,0,0,0,102,117,110,107,121,106,101,116,106,0,0,0,0,0,0,0,74,111,74,111,39,115,32,86,101,110,116,117,114,101,32,47,32,74,111,74,111,32,110,111,32,75,105,109,121,111,117,32,110,97,32,66,111,117,107,101,110,32,40,65,115,105,97,32,57,56,49,50,48,50,44,32,78,79,32,67,68,41,0,0,110,101,116,112,108,97,121,95,99,108,105,101,110,116,95,115,119,97,112,95,105,110,112,117,116,0,0,0,0,0,0,0,98,98,97,107,114,97,105,100,0,0,0,0,0,0,0,0,50,48,48,56,0,0,0,0,115,102,122,50,97,100,0,0,87,97,108,108,121,32,119,111,32,83,97,103,97,115,101,33,32,40,114,101,118,32,65,44,32,74,97,112,97,110,44,32,70,68,49,48,57,52,32,51,49,55,45,48,49,57,55,65,41,0,0,0,0,0,0,0,98,111,111,116,108,101,103,32,40,69,108,115,121,115,32,83,111,102,116,119,97,114,101,41,0,0,0,0,0,0,0,0,83,104,105,110,111,98,105,32,40,98,101,116,97,32,98,111,111,116,108,101,103,44,32,83,121,115,116,101,109,32,49,54,65,41,0,0,0,0,0,0,53,48,32,67,114,101,100,105,116,115,0,0,0,0,0,0,112,50,32,102,105,114,101,32,55,0,0,0,0,0,0,0,103,114,100,110,115,116,114,109,103,0,0,0,0,0,0,0,78,111,46,32,49,44,50,44,51,0,0,0,0,0,0,0,80,49,32,83,99,111,114,101,32,76,105,110,101,32,40,99,104,101,97,116,41,0,0,0,109,98,111,109,98,100,106,101,0,0,0,0,0,0,0,0,51,50,0,0,0,0,0,0,112,99,101,95,115,111,108,100,98,108,97,100,0,0,0,0,65,105,114,32,71,97,108,108,101,116,32,40,72,111,110,103,32,75,111,110,103,41,0,0,97,48,0,0,115,48,0,0,126,48,0,0,139,48,0,0,80,91,0,0,97,48,0,0,131,48,0,0,147,48,0,0,32,0,0,0,126,48,0,0,139,48,0,0,80,91,0,0,199,48,0,0,233,48,0,0,195,48,0,0,175,48,0,0,185,48,0,0,175,48,0,0,164,48,0,0,186,48,0,0,0,0,0,0,67,0,0,0,104,0,0,0,105,0,0,0,98,0,0,0,105,0,0,0,32,0,0,0,77,0,0,0,97,0,0,0,114,0,0,0,117,0,0,0,107,0,0,0,111,0,0,0,99,0,0,0,104,0,0,0,97,0,0,0,110,0,0,0,32,0,0,0,68,0,0,0,101,0,0,0,108,0,0,0,117,0,0,0,120,0,0,0,101,0,0,0,32,0,0,0,81,0,0,0,117,0,0,0,105,0,0,0,122,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,100,101,99,111,49,54,95,118,98,108,97,110,107,0,0,0,109,100,95,98,101,114,101,110,115,112,49,57,0,0,0,0,82,111,117,110,100,32,72,111,117,115,101,32,82,117,109,98,108,101,0,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,65,108,112,104,97,32,45,32,119,97,114,114,105,111,114,115,39,32,100,114,101,97,109,115,32,40,57,53,48,55,50,55,32,85,83,65,32,80,104,111,101,110,105,120,32,69,100,105,116,105,111,110,41,0,0,0,0,68,114,105,118,105,110,103,32,70,111,114,99,101,32,40,71,97,108,97,120,105,97,110,32,99,111,110,118,101,114,115,105,111,110,32,98,111,111,116,108,101,103,41,0,0,0,0,0,85,108,116,114,97,109,97,110,32,67,108,117,98,32,45,32,84,97,116,97,107,97,101,33,32,85,108,116,114,97,109,97,110,32,75,121,111,117,100,97,105,33,33,0,0,0,0,0,115,110,111,119,98,114,111,115,100,0,0,0,0,0,0,0,121,45,97,120,105,115,45,112,111,115,0,0,0,0,0,0,106,117,109,112,112,111,112,0,104,101,108,108,102,105,114,101,0,0,0,0,0,0,0,0,81,117,105,122,32,84,111,110,111,115,97,109,97,32,110,111,32,89,97,98,111,117,32,40,74,97,112,97,110,41,0,0,80,50,32,77,105,100,0,0,78,101,119,112,117,99,50,0,0,0,0,0,0,0,0,0,104,101,114,98,105,101,100,107,0,0,0,0,0,0,0,0,103,117,110,115,109,111,107,101,95,115,99,114,111,108,108,120,91,49,93,0,0,0,0,0,83,107,119,101,101,107,0,0,84,97,107,97,114,97,0,0,84,104,101,32,66,101,114,101,110,115,116,97,105,110,32,66,101,97,114,115,39,32,67,97,109,112,105,110,103,32,65,100,118,101,110,116,117,114,101,32,40,85,83,65,41,0,0,0,116,117,109,98,108,101,112,106,0,0,0,0,0,0,0,0,115,102,97,117,100,0,0,0,100,114,105,118,102,114,99,98,0,0,0,0,0,0,0,0,52,48,107,32,101,118,101,114,121,32,57,48,107,0,0,0,107,111,118,115,104,95,108,111,119,108,97,116,99,104,95,97,114,109,95,119,0,0,0,0,79,114,105,101,110,116,97,108,32,76,101,103,101,110,100,32,83,112,101,99,105,97,108,32,45,32,88,105,32,89,111,32,71,105,32,83,104,105,32,82,101,32,90,117,97,110,103,32,83,117,112,101,114,32,40,86,49,48,48,32,97,108,116,41,0,0,0,0,0,0,0,0,100,101,109,111,110,119,108,100,0,0,0,0,0,0,0,0,112,99,101,95,98,101,98,97,108,108,0,0,0,0,0,0,115,108,97,109,109,97,115,104,0,0,0,0,0,0,0,0,112,99,101,95,115,107,119,101,101,107,0,0,0,0,0,0,67,104,105,98,105,32,77,97,114,117,107,111,99,104,97,110,32,68,101,108,117,120,101,32,81,117,105,122,0,0,0,0,98,117,114,110,105,110,103,102,112,0,0,0,0,0,0,0,115,118,99,112,99,98,110,100,0,0,0,0,0,0,0,0,109,100,95,98,101,114,101,110,115,0,0,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,65,108,112,104,97,32,45,32,119,97,114,114,105,111,114,115,39,32,100,114,101,97,109,115,32,40,57,53,48,55,50,55,32,69,117,114,111,32,80,104,111,101,110,105,120,32,69,100,105,116,105,111,110,41,0,0,0,98,111,111,116,108,101,103,32,40,69,77,84,32,71,101,114,109,97,110,121,41,0,0,0,98,111,111,103,119,105,110,103,97,0,0,0,0,0,0,0,109,100,95,97,114,116,97,108,105,118,101,0,0,0,0,0,67,114,111,112,32,79,118,101,114,115,99,97,110,32,40,114,101,108,111,97,100,41,0,0,80,50,32,76,111,119,0,0,67,104,105,112,37,105,79,117,116,112,117,116,0,0,0,0,49,39,50,48,0,0,0,0,63,0,0,0,0,0,0,0,115,104,105,112,112,117,109,100,0,0,0,0,0,0,0,0,83,105,110,100,105,98,97,100,32,67,104,105,116,101,105,32,110,111,32,68,97,105,32,77,97,107,121,117,117,0,0,0,114,51,0,0,0,0,0,0,109,97,114,117,107,111,100,113,0,0,0,0,0,0,0,0,66,101,97,118,105,115,32,97,110,100,32,66,117,116,116,45,72,101,97,100,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,115,115,114,105,100,101,114,115,97,98,100,0,0,0,0,0,72,111,114,105,122,111,110,0,0,0,0,0,0,0,0,0,71,101,111,115,116,111,114,109,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,68,97,105,107,117,32,110,111,32,71,101,110,115,97,110,32,40,74,97,112,97,110,44,32,77,55,50,41,0,0,0,0,115,102,97,100,0,0,0,0,67,80,85,32,83,112,101,101,100,32,79,118,101,114,99,108,111,99,107,59,32,49,48,48,124,49,49,48,124,49,50,48,124,49,51,48,124,49,52,48,124,49,53,48,124,49,54,48,124,49,55,48,124,49,56,48,124,49,57,48,124,50,48,48,0,0,0,0,0,0,0,0,84,111,112,32,82,97,99,101,114,32,40,98,111,111,116,108,101,103,32,111,102,32,68,114,105,118,105,110,103,32,70,111,114,99,101,41,0,0,0,0,82,46,65,76,85,0,0,0,75,79,78,65,77,73,58,32,105,108,108,101,103,97,108,32,111,112,99,111,100,101,32,97,116,32,37,48,52,120,10,0,55,48,75,44,32,50,48,48,75,32,79,110,108,121,0,0,115,108,97,109,109,97,115,97,0,0,0,0,0,0,0,0,37,48,56,120,58,32,71,52,45,51,32,85,110,100,101,102,105,110,101,100,32,84,104,117,109,98,32,105,110,115,116,114,117,99,116,105,111,110,58,32,37,48,52,120,10,0,0,0,112,99,101,95,115,105,110,100,105,98,97,100,0,0,0,0,80,0,0,0,111,0,0,0,99,0,0,0,104,0,0,0,105,0,0,0,32,0,0,0,97,0,0,0,110,0,0,0,100,0,0,0,32,0,0,0,78,0,0,0,121,0,0,0,97,0,0,0,97,0,0,0,0,0,0,0,221,48,0,0,193,48,0,0,195,48,0,0,104,48,0,0,107,48,0,0,131,48,0,0,94,255,0,0,0,0,0,0,0,0,0,0,109,100,95,98,101,97,118,105,115,117,112,0,0,0,0,0,109,97,104,111,117,100,97,105,0,0,0,0,0,0,0,0,82,105,110,103,32,111,102,32,68,101,115,116,114,117,99,116,105,111,110,32,45,32,115,108,97,109,109,97,115,116,101,114,115,32,73,73,32,40,57,52,48,57,48,50,32,69,117,114,111,32,80,104,111,101,110,105,120,32,69,100,105,116,105,111,110,41,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,65,117,116,111,32,115,97,118,101,32,115,116,97,116,101,32,116,111,32,34,37,115,34,32,37,115,46,10,0,100,114,105,118,102,114,99,116,0,0,0,0,0,0,0,0,99,104,105,112,45,62,115,116,101,112,0,0,0,0,0,0,114,111,104,103,97,49,0,0,82,45,62,99,99,0,0,0,77,105,115,99,101,108,108,97,110,101,111,117,115,0,0,0,80,50,32,83,119,105,110,103,49,0,0,0,0,0,0,0,122,101,114,111,119,105,110,103,50,0,0,0,0,0,0,0,53,48,75,44,32,69,118,101,114,121,32,50,48,48,75,0,98,97,116,114,105,100,101,114,117,0,0,0,0,0,0,0,83,105,108,101,110,116,32,68,101,98,117,103,103,101,114,115,0,0,0,0,0,0,0,0,65,105,107,121,32,47,32,84,97,105,116,111,0,0,0,0,102,105,120,101,105,103,104,116,107,116,0,0,0,0,0,0,66,101,97,118,105,115,32,97,110,100,32,66,117,116,116,45,72,101,97,100,32,40,85,83,65,41,0,0,0,0,0,0,105,110,102,111,45,62,99,117,114,95,112,116,114,0,0,0,114,105,110,103,100,115,116,100,0,0,0,0,0,0,0,0,83,104,105,110,107,97,105,32,73,110,99,46,32,40,77,97,103,105,99,32,69,108,101,116,114,111,110,105,99,115,32,85,83,65,32,108,105,99,101,110,99,101,41,0,0,0,0,0,116,105,103,101,114,104,106,0,114,101,116,111,102,105,110,118,0,0,0,0,0,0,0,0,84,0,0,0,114,0,0,0,117,0,0,0,120,0,0,0,116,0,0,0,111,0,0,0,110,0,0,0,32,0,0,0,73,0,0,0,73,0,0,0,0,0,0,0,84,144,0,0,186,78,0,0,139,115,0,0,0,0,0,0,0,0,0,0,80,50,32,83,119,105,110,103,48,0,0,0,0,0,0,0,112,105,112,105,98,105,98,115,97,0,0,0,0,0,0,0,50,48,75,44,32,69,118,101,114,121,32,49,48,48,75,0,71,97,108,97,120,105,97,110,32,84,101,115,116,32,82,79,77,0,0,0,0,0,0,0,98,97,116,115,117,103,117,110,115,112,0,0,0,0,0,0,112,110,105,99,107,117,0,0,112,99,101,95,115,105,108,101,110,116,100,0,0,0,0,0,80,111,99,104,105,32,97,110,100,32,78,121,97,97,0,0,215,48,0,0,237,48,0,0,174,48,0,0,162,48,0,0,110,48,0,0,80,93,0,0,32,0,0,0,40,0,0,0,80,0,0,0,114,0,0,0,111,0,0,0,103,0,0,0,101,0,0,0,97,0,0,0,114,0,0,0,32,0,0,0,78,0,0,0,111,0,0,0,32,0,0,0,65,0,0,0,114,0,0,0,97,0,0,0,115,0,0,0,104,0,0,0,105,0,0,0,32,0,0,0,48,0,0,0,49,0,0,0,48,0,0,0,49,0,0,0,49,0,0,0,55,0,0,0,32,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,32,0,0,0,80,0,0,0,104,0,0,0,111,0,0,0,101,0,0,0,110,0,0,0,105,0,0,0,120,0,0,0,32,0,0,0,69,0,0,0,100,0,0,0,105,0,0,0,116,0,0,0,105,0,0,0,111,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,109,100,95,98,101,97,118,105,115,117,0,0,0,0,0,0,83,0,0,0,110,0,0,0,111,0,0,0,119,0,0,0,32,0,0,0,66,0,0,0,114,0,0,0,111,0,0,0,115,0,0,0,46,0,0,0,32,0,0,0,50,0,0,0,32,0,0,0,45,0,0,0,32,0,0,0,119,0,0,0,105,0,0,0,116,0,0,0,104,0,0,0,32,0,0,0,110,0,0,0,101,0,0,0,119,0,0,0,32,0,0,0,101,0,0,0,108,0,0,0,118,0,0,0,101,0,0,0,115,0,0,0,0,0,0,0,74,48,0,0,102,48,0,0,147,48,0,0,77,48,0,0,209,48,0,0,233,48,0,0,192,48,0,0,164,48,0,0,185,48,0,0,0,0,0,0,234,150,0,0,186,78,0,0,68,81,0,0,31,95,0,0,18,255,0,0,0,0,0,0,8,178,0,0,172,192,0,0,140,183,0,0,21,214,0,0,28,200,0,0,18,255,0,0,0,0,0,0,0,0,0,0,37,115,37,99,37,115,46,110,118,0,0,0,0,0,0,0,68,114,105,118,105,110,103,32,70,111,114,99,101,32,40,71,97,108,97,120,105,97,110,32,99,111,110,118,101,114,115,105,111,110,41,0,0,0,0,0,98,103,97,114,101,103,103,97,99,110,0,0,0,0,0,0,80,50,32,66,97,110,116,50,0,0,0,0,0,0,0,0,82,97,115,116,101,114,115,111,102,116,32,40,72,111,109,101,98,114,101,119,41,0,0,0,83,105,100,101,97,114,109,115,32,45,32,72,121,112,101,114,32,68,121,110,101,0,0,0,112,110,121,97,97,0,0,0,66,101,97,118,105,115,32,97,110,100,32,66,117,116,116,45,72,101,97,100,32,40,69,117,114,111,41,0,0,0,0,0,75,0,0,0,110,0,0,0,117,0,0,0,99,0,0,0,107,0,0,0,108,0,0,0,101,0,0,0,32,0,0,0,66,0,0,0,97,0,0,0,115,0,0,0,104,0,0,0,0,0,0,0,75,0,0,0,110,0,0,0,117,0,0,0,99,0,0,0,107,0,0,0,108,0,0,0,101,0,0,0,32,0,0,0,66,0,0,0,97,0,0,0,115,0,0,0,104,0,0,0,32,0,0,0,202,48,0,0,195,48,0,0,175,48,0,0,235,48,0,0,208,48,0,0,195,48,0,0,183,48,0,0,229,48,0,0,0,0,0,0,0,0,0,0,80,114,111,103,101,97,114,32,78,111,32,65,114,97,115,104,105,32,40,48,49,48,49,49,55,32,74,97,112,97,110,32,80,104,111,101,110,105,120,32,69,100,105,116,105,111,110,41,0,0,0,0,0,0,0,0,111,117,116,122,111,110,101,97,0,0,0,0,0,0,0,0,67,97,112,116,97,105,110,32,83,105,108,118,101,114,32,40,74,97,112,97,110,41,0,0,98,98,97,107,114,97,105,100,106,0,0,0,0,0,0,0,80,50,32,66,97,110,116,49,0,0,0,0,0,0,0,0,104,101,108,108,102,105,114,101,49,0,0,0,0,0,0,0,70,114,111,103,32,70,101,97,115,116,32,40,67,80,83,45,49,41,0,0,0,0,0,0,101,101,112,114,111,109,95,100,97,116,97,95,98,105,116,115,0,0,0,0,0,0,0,0,100,101,109,111,110,119,108,100,49,0,0,0,0,0,0,0,112,99,101,95,115,105,100,101,97,114,109,115,0,0,0,0,84,97,105,116,111,32,40,83,78,75,32,108,105,99,101,110,115,101,41,0,0,0,0,0,109,100,95,98,101,97,118,105,115,0,0,0,0,0,0,0,80,49,32,65,110,115,119,101,114,32,52,0,0,0,0,0,112,114,111,103,101,97,114,106,100,0,0,0,0,0,0,0,112,49,32,99,111,105,110,0,49,48,48,48,48,48,48,32,101,97,99,104,0,0,0,0,100,114,105,118,102,114,99,103,0,0,0,0,0,0,0,0,83,111,117,116,104,32,69,97,115,116,32,65,115,105,97,0,114,101,116,111,102,105,110,118,49,0,0,0,0,0,0,0,73,116,97,108,121,32,40,83,116,97,114,32,69,108,101,99,116,114,111,110,105,99,97,32,83,82,76,41,0,0,0,0,98,105,116,95,120,111,114,0,72,111,110,103,32,75,111,110,103,32,38,32,67,104,105,110,97,32,40,72,111,110,101,115,116,32,84,114,97,100,105,110,103,32,76,105,99,101,110,115,101,41,0,0,0,0,0,0,83,101,99,114,101,116,32,65,103,101,110,116,32,40,87,111,114,108,100,41,0,0,0,0,49,32,67,111,105,110,32,32,55,32,67,114,101,100,105,116,115,0,0,0,0,0,0,0,71,114,111,119,108,32,40,87,111,114,108,100,41,0,0,0,102,108,105,112,115,99,114,101,101,110,95,121,0,0,0,0,80,50,32,66,97,110,116,48,0,0,0,0,0,0,0,0,107,97,98,117,107,105,122,0,83,104,111,119,32,89,101,97,114,0,0,0,0,0,0,0,72,105,116,32,116,104,101,32,73,99,101,32,40,74,97,112,97,110,41,0,0,0,0,0,114,97,99,105,110,103,98,0,99,97,109,101,108,116,114,121,97,117,0,0,0,0,0,0,100,114,103,110,105,110,106,97,0,0,0,0,0,0,0,0,70,117,108,108,32,84,104,114,111,116,116,108,101,32,40,74,97,112,97,110,41,0,0,0,83,104,111,117,103,105,32,83,104,111,115,104,105,110,115,104,97,32,77,117,121,111,117,0,0,0,0,0,0,0,0,0,80,117,122,122,108,101,32,66,111,98,98,108,101,32,50,32,47,32,66,117,115,116,45,65,45,77,111,118,101,32,65,103,97,105,110,32,40,78,101,111,45,71,101,111,41,0,0,0,77,97,110,121,32,40,72,97,114,100,41,0,0,0,0,0,76,111,110,103,32,40,49,52,41,0,0,0,0,0,0,0,68,105,115,110,101,121,39,115,32,66,101,97,117,116,121,32,97,110,100,32,116,104,101,32,66,101,97,115,116,32,45,32,82,111,97,114,32,111,102,32,116,104,101,32,66,101,97,115,116,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,106,111,106,111,110,114,50,0,108,107,97,103,101,111,0,0,84,67,48,50,50,48,73,79,67,82,101,103,115,0,0,0,105,110,112,117,116,95,97,120,105,115,95,116,104,114,101,115,104,111,108,100,0,0,0,0,98,108,111,120,101,101,100,0,80,114,111,103,101,97,114,40,48,49,48,49,49,55,32,85,83,65,32,80,104,111,101,110,105,120,32,69,100,105,116,105,111,110,41,0,0,0,0,0,84,97,105,116,111,32,77,105,115,99,0,0,0,0,0,0,78,111,98,111,114,97,110,107,97,32,40,74,97,112,97,110,44,32,98,111,111,116,108,101,103,41,0,0,0,0,0,0,80,77,0,0,0,0,0,0,119,119,97,108,108,121,106,97,0,0,0,0,0,0,0,0,111,116,104,117,110,100,101,114,117,0,0,0,0,0,0,0,115,104,105,110,111,98,108,98,0,0,0,0,0,0,0,0,66,101,116,0,0,0,0,0,101,120,116,114,109,97,116,110,0,0,0,0,0,0,0,0,112,49,32,102,105,114,101,32,49,49,0,0,0,0,0,0,71,117,97,114,100,105,97,110,32,83,116,111,114,109,32,40,118,101,114,116,105,99,97,108,41,0,0,0,0,0,0,0,84,114,111,112,104,121,32,72,117,110,116,105,110,103,32,45,32,66,101,97,114,32,38,32,77,111,111,115,101,32,86,49,46,48,0,0,0,0,0,0,83,101,114,118,105,99,101,32,77,111,100,101,32,40,78,111,32,84,111,103,103,108,101,41,0,0,0,0,0,0,0,0,97,114,107,97,110,111,105,100,117,0,0,0,0,0,0,0,99,112,115,49,102,114,111,103,0,0,0,0,0,0,0,0,50,52,0,0,0,0,0,0,83,101,108,101,99,116,32,112,108,97,121,101,114,32,109,111,100,101,0,0,0,0,0,0,112,99,101,95,115,104,111,103,105,115,109,0,0,0,0,0,97,103,97,108,108,101,116,104,0,0,0,0,0,0,0,0,112,98,111,98,98,108,50,110,0,0,0,0,0,0,0,0,109,100,95,98,101,97,117,116,121,114,98,0,0,0,0,0,100,97,114,107,115,101,97,108,49,0,0,0,0,0,0,0,65,108,105,101,110,32,67,104,97,108,108,101,110,103,101,0,112,114,111,103,101,97,114,117,100,0,0,0,0,0,0,0,72,117,110,99,104,98,97,99,107,32,40,71,97,108,97,120,105,97,110,32,104,97,114,100,119,97,114,101,41,0,0,0,117,109,97,110,99,108,117,98,0,0,0,0,0,0,0,0,83,110,111,119,32,66,114,111,115,46,32,45,32,78,105,99,107,32,38,32,84,111,109,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,100,111,119,110,0,0,0,0,68,97,116,101,32,81,117,105,122,32,71,111,32,71,111,32,40,75,111,114,101,97,41,0,0,0,0,0,0,0,0,0,84,97,105,116,111,32,66,32,83,121,115,116,101,109,0,0,80,50,32,98,117,116,116,111,110,32,55,0,0,0,0,0,65,108,108,111,119,32,76,101,118,101,108,32,83,101,108,101,99,116,0,0,0,0,0,0,115,50,54,53,48,95,98,97,110,107,0,0,0,0,0,0,111,112,119,111,108,102,51,0,84,67,48,53,49,48,78,73,79,82,101,103,115,0,0,0,70,103,83,99,114,111,108,108,89,91,105,93,0,0,0,0,80,49,32,67,104,97,115,101,0,0,0,0,0,0,0,0,110,101,119,112,117,99,50,0,83,101,109,105,45,70,105,110,97,108,115,32,38,32,70,105,110,97,108,115,0,0,0,0,9,78,0,0,253,86,0,0,215,95,0,0,73,0,0,0,73,0,0,0,0,0,0,0,83,0,0,0,97,0,0,0,110,0,0,0,103,0,0,0,111,0,0,0,107,0,0,0,117,0,0,0,115,0,0,0,104,0,0,0,105,0,0,0,32,0,0,0,73,0,0,0,73,0,0,0,32,0,0,0,40,0,0,0,104,0,0,0,97,0,0,0,99,0,0,0,107,0,0,0,32,0,0,0,115,0,0,0,101,0,0,0,116,0,0,0,32,0,0,0,51,0,0,0,44,0,0,0,32,0,0,0,57,0,0,0,50,0,0,0,49,0,0,0,48,0,0,0,48,0,0,0,53,0,0,0,32,0,0,0,65,0,0,0,115,0,0,0,105,0,0,0,97,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,111,110,107,101,121,32,75,111,110,103,32,51,32,40,98,111,111,116,108,101,103,32,111,110,32,68,111,110,107,101,121,32,75,111,110,103,32,74,114,46,32,104,97,114,100,119,97,114,101,41,0,0,0,0,0,103,117,110,115,109,111,107,101,95,115,99,114,111,108,108,120,91,48,93,0,0,0,0,0,72,111,109,101,32,68,97,116,97,0,0,0,0,0,0,0,80,117,122,122,108,101,32,66,111,98,98,108,101,32,47,32,66,117,115,116,45,65,45,77,111,118,101,32,40,78,101,111,45,71,101,111,41,32,40,98,111,111,116,108,101,103,41,0,0,0,0,0,0,0,0,0,97,113,117,97,106,97,99,107,106,0,0,0,0,0,0,0,68,105,115,110,101,121,39,115,32,66,101,97,117,116,121,32,97,110,100,32,116,104,101,32,66,101,97,115,116,32,45,32,66,101,108,108,101,39,115,32,81,117,101,115,116,32,40,85,83,65,41,0,0,0,0,0,99,97,109,101,108,116,114,121,0,0,0,0,0,0,0,0,115,117,112,98,116,105,109,101,97,0,0,0,0,0,0,0,67,67,104,105,112,76,97,115,116,95,55,97,0,0,0,0,78,105,103,104,116,32,87,97,114,114,105,111,114,115,32,45,32,100,97,114,107,115,116,97,108,107,101,114,115,39,32,114,101,118,101,110,103,101,32,40,57,53,48,52,48,54,32,85,83,65,32,80,104,111,101,110,105,120,32,69,100,105,116,105,111,110,41,0,0,0,0,0,51,48,107,32,97,110,100,32,56,48,107,0,0,0,0,0,45,49,32,83,108,111,119,101,114,0,0,0,0,0,0,0,100,97,114,105,117,115,106,0,82,65,77,32,67,48,48,48,0,0,0,0,0,0,0,0,116,99,48,49,52,48,115,121,116,0,0,0,0,0,0,0,107,111,118,115,104,95,104,105,103,104,108,97,116,99,104,95,97,114,109,95,119,0,0,0,99,97,100,97,115,104,106,0,67,111,110,116,114,111,108,32,82,65,77,0,0,0,0,0,112,49,32,102,105,114,101,32,49,48,0,0,0,0,0,0,98,97,100,100,117,100,101,115,0,0,0,0,0,0,0,0,100,100,114,67,0,0,0,0,118,100,99,95,104,101,105,103,104,116,91,105,93,0,0,0,70,105,110,97,108,115,32,79,110,108,121,0,0,0,0,0,66,97,116,116,108,101,32,76,111,100,101,32,82,117,110,110,101,114,0,0,0,0,0,0,83,97,110,103,111,107,117,115,104,105,32,73,73,32,40,104,97,99,107,32,115,101,116,32,51,44,32,57,50,49,48,48,53,32,65,115,105,97,41,0,0,0,0,0,0,0,0,0,99,119,111,114,108,100,50,106,0,0,0,0,0,0,0,0,83,104,111,117,103,105,32,83,104,111,100,97,110,32,73,99,99,104,111,107,117,115,101,110,0,0,0,0,0,0,0,0,112,98,111,98,98,108,101,110,98,0,0,0,0,0,0,0,78,101,111,32,71,101,111,32,65,69,83,0,0,0,0,0,110,119,97,114,114,117,100,0,109,100,95,98,101,97,117,116,121,0,0,0,0,0,0,0,98,117,98,108,98,111,98,108,49,0,0,0,0,0,0,0,115,116,97,116,101,0,0,0,103,105,103,97,110,100,101,115,0,0,0,0,0,0,0,0,109,99,117,95,99,111,105,110,97,103,101,91,51,93,0,0,70,103,83,99,114,111,108,108,89,0,0,0,0,0,0,0,104,117,110,99,104,98,107,103,0,0,0,0,0,0,0,0,100,97,114,105,117,115,50,100,0,0,0,0,0,0,0,0,65,114,99,97,100,101,32,67,108,97,115,115,105,99,115,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,102,108,115,116,111,114,121,106,0,0,0,0,0,0,0,0,87,105,110,100,111,119,101,100,32,83,99,97,108,101,32,40,89,41,0,0,0,0,0,0,49,39,49,48,0,0,0,0,112,121,116,104,111,110,0,0,67,104,111,107,111,32,40,48,49,48,56,50,48,32,74,97,112,97,110,41,0,0,0,0,119,111,102,97,104,98,0,0,111,117,116,114,117,110,111,0,52,48,107,32,49,49,48,107,32,55,48,107,43,0,0,0,112,99,101,95,115,104,111,103,105,115,105,0,0,0,0,0,108,51,0,0,0,0,0,0,75,48,53,51,50,52,54,73,114,113,0,0,0,0,0,0,82,105,111,116,0,0,0,0,83,117,110,115,101,116,32,82,105,100,101,114,115,32,40,50,32,80,108,97,121,101,114,115,32,118,101,114,46,32,85,66,67,41,0,0,0,0,0,0,50,32,67,111,105,110,115,32,116,111,32,83,116,97,114,116,47,49,32,116,111,32,67,111,110,116,105,110,117,101,0,0,104,111,114,105,122,111,110,0,108,107,97,103,101,0,0,0,103,101,111,115,116,111,114,109,0,0,0,0,0,0,0,0,100,107,103,101,110,115,97,110,109,55,50,0,0,0,0,0,77,97,114,118,101,108,32,118,115,32,67,97,112,99,111,109,32,45,32,99,108,97,115,104,32,111,102,32,115,117,112,101,114,32,104,101,114,111,101,115,32,40,57,56,48,49,50,51,32,85,83,65,32,80,104,111,101,110,105,120,32,69,100,105,116,105,111,110,41,0,0,0,68,97,109,98,117,115,116,101,114,115,32,40,85,75,41,0,0,0,0,0,0,0,0,0,84,67,48,50,50,48,73,79,67,73,110,112,117,116,80,111,114,116,48,0,0,0,0,0,43,0,0,0,0,0,0,0,112,49,32,102,105,114,101,32,57,0,0,0,0,0,0,0,97,108,105,101,110,115,121,110,0,0,0,0,0,0,0,0,72,97,108,102,32,67,111,110,116,105,110,117,101,58,32,83,116,97,114,116,32,50,67,32,47,32,67,111,110,116,105,110,117,101,32,49,67,0,0,0,84,67,48,49,49,48,80,67,82,32,82,97,109,0,0,0,9,78,0,0,253,86,0,0,215,95,0,0,73,0,0,0,73,0,0,0,0,0,0,0,83,0,0,0,97,0,0,0,110,0,0,0,103,0,0,0,111,0,0,0,107,0,0,0,117,0,0,0,115,0,0,0,104,0,0,0,105,0,0,0,32,0,0,0,73,0,0,0,73,0,0,0,32,0,0,0,40,0,0,0,104,0,0,0,97,0,0,0,99,0,0,0,107,0,0,0,32,0,0,0,115,0,0,0,101,0,0,0,116,0,0,0,32,0,0,0,50,0,0,0,44,0,0,0,32,0,0,0,57,0,0,0,50,0,0,0,49,0,0,0,48,0,0,0,48,0,0,0,53,0,0,0,32,0,0,0,65,0,0,0,115,0,0,0,105,0,0,0,97,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,83,121,115,116,101,109,49,54,73,110,112,117,116,0,0,0,115,102,105,105,105,106,0,0,83,104,105,114,121,111,117,32,83,101,110,115,101,110,0,0,80,117,122,122,108,101,32,66,111,98,98,108,101,32,47,32,66,117,115,116,45,65,45,77,111,118,101,32,40,78,101,111,45,71,101,111,41,32,40,78,71,77,45,48,56,51,41,0,0,0,0,0,0,0,0,0,66,101,97,115,116,32,87,97,114,114,105,111,114,115,32,40,74,112,110,41,0,0,0,0,67,97,118,101,84,105,108,101,82,101,103,91,105,93,91,48,93,0,0,0,0,0,0,0,99,111,109,98,104,0,0,0,109,118,115,99,117,100,0,0,46,97,117,116,111,0,0,0,100,97,109,98,117,115,116,114,117,107,0,0,0,0,0,0,115,117,112,101,114,99,104,115,0,0,0,0,0,0,0,0,98,108,111,99,107,103,97,108,0,0,0,0,0,0,0,0,80,49,32,67,104,97,110,103,101,0,0,0,0,0,0,0,109,105,110,105,118,97,100,114,0,0,0,0,0,0,0,0,78,111,114,109,97,108,58,32,83,116,97,114,116,32,49,67,32,47,32,67,111,110,116,105,110,117,101,32,49,67,0,0,83,97,110,103,111,107,117,115,104,105,32,73,73,32,40,104,97,99,107,32,115,101,116,32,50,44,32,57,50,49,48,48,53,32,65,115,105,97,41,0,0,0,0,0,0,0,0,0,70,97,115,116,32,102,111,114,119,97,114,100,32,116,111,103,103,108,101,0,0,0,0,0,97,115,116,111,114,109,51,0,100,111,116,114,105,107,117,110,50,0,0,0,0,0,0,0,112,99,101,95,115,104,105,114,121,111,0,0,0,0,0,0,109,100,95,98,101,97,115,116,119,106,0,0,0,0,0,0,103,102,111,114,99,101,50,106,0,0,0,0,0,0,0,0,77,97,114,118,101,108,32,83,117,112,101,114,32,72,101,114,111,101,115,32,118,115,32,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,40,57,55,48,54,50,53,32,85,83,65,32,80,104,111,101,110,105,120,32,69,100,105,116,105,111,110,41,0,0,0,0,0,0,68,97,109,98,117,115,116,101,114,115,32,40,85,83,44,32,115,101,116,32,50,41,0,0,97,98,99,111,112,106,0,0,115,117,112,114,108,111,99,111,111,0,0,0,0,0,0,0,115,112,99,112,111,115,116,110,0,0,0,0,0,0,0,0,86,100,112,83,99,114,111,108,108,66,66,97,115,101,0,0,116,115,116,95,103,97,108,120,0,0,0,0,0,0,0,0,119,111,102,97,104,97,0,0,111,116,104,117,110,100,101,114,0,0,0,0,0,0,0,0,83,104,105,110,111,98,105,0,0,0,0,0,0,0,0,0,87,0,0,0,97,0,0,0,107,0,0,0,117,0,0,0,32,0,0,0,87,0,0,0,97,0,0,0,107,0,0,0,117,0,0,0,32,0,0,0,55,0,0,0,0,0,0,0,143,48,0,0,79,48,0,0,143,48,0,0,79,48,0,0,23,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,109,115,104,118,115,102,117,49,100,0,0,0,0,0,0,0,66,101,97,115,116,32,87,114,101,115,116,108,101,114,32,40,85,83,65,41,0,0,0,0,83,121,115,116,101,109,32,49,54,65,0,0,0,0,0,0,67,97,108,86,97,108,0,0,100,97,109,98,117,115,116,114,97,0,0,0,0,0,0,0,101,115,112,114,97,100,101,106,0,0,0,0,0,0,0,0,101,110,100,117,114,111,114,49,0,0,0,0,0,0,0,0,102,117,110,121,98,117,98,108,99,0,0,0,0,0,0,0,80,49,32,72,105,0,0,0,9,78,0,0,253,86,0,0,215,95,0,0,73,0,0,0,73,0,0,0,0,0,0,0,83,0,0,0,97,0,0,0,110,0,0,0,103,0,0,0,111,0,0,0,107,0,0,0,117,0,0,0,115,0,0,0,104,0,0,0,105,0,0,0,32,0,0,0,73,0,0,0,73,0,0,0,32,0,0,0,40,0,0,0,104,0,0,0,97,0,0,0,99,0,0,0,107,0,0,0,32,0,0,0,115,0,0,0,101,0,0,0,116,0,0,0,32,0,0,0,49,0,0,0,44,0,0,0,32,0,0,0,57,0,0,0,50,0,0,0,49,0,0,0,48,0,0,0,48,0,0,0,53,0,0,0,32,0,0,0,65,0,0,0,115,0,0,0,105,0,0,0,97,0,0,0])
.concat([41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,98,101,114,108,119,97,108,108,116,0,0,0,0,0,0,0,112,99,101,95,115,104,105,110,111,98,105,0,0,0,0,0,87,97,107,117,32,87,97,107,117,32,55,0,0,0,0,0,109,100,95,98,101,97,115,116,119,0,0,0,0,0,0,0,109,117,108,116,99,104,109,112,107,0,0,0,0,0,0,0,109,115,112,117,122,122,108,101,103,0,0,0,0,0,0,0,77,97,114,118,101,108,32,83,117,112,101,114,32,72,101,114,111,101,115,32,40,57,53,49,48,50,52,32,85,83,65,32,80,104,111,101,110,105,120,32,69,100,105,116,105,111,110,41,0,0,0,0,0,0,0,0,80,48,0,0,143,48,0,0,147,48,0,0,82,48,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,44,0,0,0,32,0,0,0,77,0,0,0,97,0,0,0,115,0,0,0,116,0,0,0,101,0,0,0,114,0,0,0,32,0,0,0,86,0,0,0,101,0,0,0,114,0,0,0,46,0,0,0,32,0,0,0,57,0,0,0,57,0,0,0,47,0,0,0,48,0,0,0,54,0,0,0,47,0,0,0,50,0,0,0,52,0,0,0,41,0,0,0,0,0,0,0,71,0,0,0,117,0,0,0,119,0,0,0,97,0,0,0,110,0,0,0,103,0,0,0,101,0,0,0,0,0,0,0,0,0,0,0,83,111,117,116,104,32,87,101,115,116,32,82,101,115,101,97,114,99,104,0,0,0,0,0,99,115,105,108,118,101,114,106,0,0,0,0,0,0,0,0,115,117,110,97,113,0,0,0,67,104,101,97,112,32,67,111,110,116,105,110,117,101,0,0,116,97,111,116,97,105,100,111,97,0,0,0,0,0,0,0,83,97,110,103,111,107,117,115,104,105,32,73,73,32,40,104,97,99,107,32,115,101,116,32,49,44,32,57,50,49,48,48,53,32,65,115,105,97,41,0,0,0,0,0,0,0,0,0,83,104,97,110,103,104,97,105,0,0,0,0,0,0,0,0,119,97,107,117,119,97,107,55,0,0,0,0,0,0,0,0,83,112,101,99,116,114,117,109,32,72,111,108,111,98,121,116,101,0,0,0,0,0,0,0,110,109,103,53,101,0,0,0,80,49,32,65,110,115,119,101,114,32,51,0,0,0,0,0,83,112,108,105,116,32,67,111,105,110,32,67,104,117,116,101,115,0,0,0,0,0,0,0,109,115,104,117,100,0,0,0,49,53,48,48,48,48,48,32,101,97,99,104,0,0,0,0,68,97,109,98,117,115,116,101,114,115,32,40,85,83,44,32,115,101,116,32,49,41,0,0,83,111,117,116,104,32,69,97,115,116,32,65,115,105,97,32,40,67,104,97,114,116,101,114,102,105,101,108,100,41,0,0,84,97,105,119,97,110,32,40,84,97,105,116,111,32,67,111,114,112,32,108,105,99,101,110,115,101,41,0,0,0,0,0,83,112,97,105,110,32,38,32,80,111,114,116,117,103,97,108,32,40,65,80,77,32,69,108,101,99,116,114,111,110,105,99,115,32,83,65,41,0,0,0,112,108,117,109,112,112,111,112,0,0,0,0,0,0,0,0,115,104,97,100,102,114,99,101,106,0,0,0,0,0,0,0,115,101,99,114,101,116,97,103,0,0,0,0,0,0,0,0,44,0,0,0,0,0,0,0,103,114,111,119,108,0,0,0,99,114,111,113,117,105,115,0,102,108,105,112,115,99,114,101,101,110,95,120,0,0,0,0,80,49,32,77,105,100,0,0,84,104,101,32,78,101,119,90,101,97,108,97,110,100,32,83,116,111,114,121,32,40,87,111,114,108,100,44,32,112,114,111,116,111,116,121,112,101,63,41,32,40,111,108,100,101,114,32,80,67,66,41,0,0,0,0,67,114,101,100,105,116,32,73,110,102,111,0,0,0,0,0,104,105,116,105,99,101,106,0,70,71,45,51,0,0,0,0,78,105,103,104,116,32,83,116,114,105,107,101,114,32,40,85,83,41,0,0,0,0,0,0,119,111,102,97,104,0,0,0,102,117,108,108,116,104,114,108,0,0,0,0,0,0,0,0,106,99,104,97,110,50,0,0,112,99,101,95,115,104,97,110,103,104,97,105,0,0,0,0,70,101,119,32,40,69,97,115,121,41,0,0,0,0,0,0,78,111,114,109,97,108,32,40,49,48,45,49,52,44,32,100,101,112,101,110,100,115,32,111,110,32,115,107,105,108,108,0,66,101,97,115,116,98,97,108,108,32,40,80,114,111,116,111,116,121,112,101,41,0,0,0,98,108,109,98,121,99,97,114,117,0,0,0,0,0,0,0,184,48,0,0,231,48,0,0,184,48,0,0,231,48,0,0,110,48,0,0,32,0,0,0,71,89,0,0,153,89,0,0,106,48,0,0,146,81,0,0,122,150,0,0,0,0,0,0,74,0,0,0,111,0,0,0,74,0,0,0,111,0,0,0,39,0,0,0,115,0,0,0,32,0,0,0,86,0,0,0,101,0,0,0,110,0,0,0,116,0,0,0,117,0,0,0,114,0,0,0,101,0,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,32,0,0,0,57,0,0,0,56,0,0,0,49,0,0,0,50,0,0,0,48,0,0,0,50,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,98,108,111,120,49,54,98,0,100,101,102,97,117,108,116,0,77,97,114,115,32,77,97,116,114,105,120,32,40,48,48,48,52,49,50,32,85,83,65,32,80,104,111,101,110,105,120,32,69,100,105,116,105,111,110,41,0,0,0,0,0,0,0,0,110,111,98,98,0,0,0,0,65,77,0,0,0,0,0,0,87,97,108,108,121,32,119,111,32,83,97,103,97,115,101,33,32,40,114,101,118,32,66,44,32,74,97,112,97,110,44,32,70,68,49,48,57,52,32,51,49,55,45,48,49,57,55,66,41,0,0,0,0,0,0,0,100,97,109,98,117,115,116,114,0,0,0,0,0,0,0,0,116,104,97,114,114,105,101,114,117,0,0,0,0,0,0,0,84,105,108,101,32,108,97,121,101,114,32,50,0,0,0,0,103,114,100,110,115,116,114,109,118,0,0,0,0,0,0,0,114,97,105,100,101,110,97,0,41,89,0,0,48,87,0,0,146,48,0,0,176,85,0,0,137,48,0,0,70,48,0,0,73,0,0,0,73,0,0,0,32,0,0,0,45,0,0,0,32,0,0,0,100,141,0,0,193,88,0,0,110,48,0,0,38,98,0,0,68,48,0,0,0,0,0,0,84,0,0,0,101,0,0,0,110,0,0,0,99,0,0,0,104,0,0,0,105,0,0,0,32,0,0,0,119,0,0,0,111,0,0,0,32,0,0,0,75,0,0,0,117,0,0,0,114,0,0,0,97,0,0,0,117,0,0,0,32,0,0,0,73,0,0,0,73,0,0,0,32,0,0,0,45,0,0,0,32,0,0,0,83,0,0,0,101,0,0,0,107,0,0,0,105,0,0,0,104,0,0,0,101,0,0,0,107,0,0,0,105,0,0,0,32,0,0,0,110,0,0,0,111,0,0,0,32,0,0,0,84,0,0,0,97,0,0,0,116,0,0,0,97,0,0,0,107,0,0,0,97,0,0,0,105,0,0,0,32,0,0,0,40,0,0,0,104,0,0,0,97,0,0,0,99,0,0,0,107,0,0,0,44,0,0,0,32,0,0,0,57,0,0,0,50,0,0,0,49,0,0,0,48,0,0,0,51,0,0,0,49,0,0,0,32,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,71,0,0,0,97,0,0,0,105,0,0,0,97,0,0,0,32,0,0,0,67,0,0,0,114,0,0,0,117,0,0,0,115,0,0,0,97,0,0,0,100,0,0,0,101,0,0,0,114,0,0,0,115,0,0,0,32,0,0,0,129,95,0,0,38,98,0,0,5,128,0,0,0,0,0,0,71,0,0,0,97,0,0,0,105,0,0,0,97,0,0,0,32,0,0,0,67,0,0,0,114,0,0,0,117,0,0,0,115,0,0,0,97,0,0,0,100,0,0,0,101,0,0,0,114,0,0,0,115,0,0,0,32,0,0,0,172,48,0,0,164,48,0,0,162,48,0,0,175,48,0,0,235,48,0,0,187,48,0,0,164,48,0,0,192,48,0,0,252,48,0,0,186,48,0,0,0,0,0,0,0,0,0,0,83,101,110,103,111,107,117,32,77,97,104,106,111,110,103,0,0,0,0,0,0,0,0,0,65,0,0,0,105,0,0,0,114,0,0,0,32,0,0,0,71,0,0,0,97,0,0,0,108,0,0,0,108,0,0,0,101,0,0,0,116,0,0,0,0,0,0,0,162,48,0,0,239,48,0,0,166,48,0,0,174,48,0,0,227,48,0,0,236,48,0,0,195,48,0,0,200,48,0,0,32,0,0,0,40,0,0,0,84,0,0,0,97,0,0,0,105,0,0,0,119,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,71,97,108,97,120,121,32,70,105,103,104,116,32,45,32,85,110,105,118,101,114,115,97,108,32,87,97,114,114,105,111,114,115,0,0,0,0,0,0,0,109,100,95,98,101,97,115,116,98,97,108,0,0,0,0,0,71,0,0,0,117,0,0,0,97,0,0,0,114,0,0,0,100,0,0,0,105,0,0,0,97,0,0,0,110,0,0,0,115,0,0,0,0,0,0,0,251,150,0,0,94,121,0,0,84,155,0,0,74,88,0,0,32,0,0,0,41,255,0,0,41,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,109,109,97,116,114,105,120,100,0,0,0,0,0,0,0,0,77,105,103,104,116,121,32,77,111,110,107,101,121,32,40,98,111,111,116,108,101,103,32,111,110,32,83,117,112,101,114,32,67,111,98,114,97,32,104,97,114,100,119,97,114,101,41,0,0,0,0,0,0,0,0,0,66,97,110,112,114,101,115,116,111,32,47,32,83,111,116,115,117,32,65,103,101,110,99,121,46,32,83,117,110,114,105,115,101,0,0,0,0,0,0,0,108,118,103,105,114,108,57,52,0,0,0,0,0,0,0,0,115,110,111,119,98,114,111,115,106,0,0,0,0,0,0,0,121,45,97,120,105,115,45,110,101,103,0,0,0,0,0,0,97,105,114,98,117,115,116,114,106,0,0,0,0,0,0,0,50,48,48,48,48,32,56,48,48,48,48,32,56,48,48,48,48,0,0,0,0,0,0,0,115,100,103,110,100,109,112,115,0,0,0,0,0,0,0,0,113,116,111,110,111,49,0,0,80,49,32,76,111,119,0,0,109,97,103,105,99,98,117,98,97,0,0,0,0,0,0,0,80,97,99,45,77,97,110,32,80,108,117,115,0,0,0,0,97,114,107,97,110,111,105,100,0,0,0,0,0,0,0,0,100,102,101,118,101,114,111,110,0,0,0,0,0,0,0,0,84,101,110,99,104,105,32,119,111,32,75,117,114,97,117,32,73,73,32,45,32,83,101,107,105,104,101,107,105,32,110,111,32,84,97,116,97,107,97,105,32,40,104,97,99,107,44,32,57,50,49,48,51,49,32,74,97,112,97,110,41,0,0,0,76,0,0,0,101,0,0,0,116,0,0,0,104,0,0,0,97,0,0,0,108,0,0,0,32,0,0,0,67,0,0,0,114,0,0,0,97,0,0,0,115,0,0,0,104,0,0,0,32,0,0,0,82,0,0,0,97,0,0,0,99,0,0,0,101,0,0,0,0,0,0,0,6,114,0,0,200,112,0,0,32,0,0,0,175,48,0,0,233,48,0,0,195,48,0,0,183,48,0,0,229,48,0,0,32,0,0,0,236,48,0,0,252,48,0,0,185,48,0,0,32,0,0,0,40,0,0,0,115,0,0,0,101,0,0,0,116,0,0,0,32,0,0,0,49,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,111,98,106,111,110,0,0,0,110,101,119,115,97,0,0,0,112,99,101,95,115,101,110,103,111,107,109,106,0,0,0,0,66,97,116,116,108,101,116,111,97,100,115,32,40,87,111,114,108,100,41,0,0,0,0,0,115,104,97,100,111,119,119,97,0,0,0,0,0,0,0,0,54,48,107,32,49,53,48,107,0,0,0,0,0,0,0,0,77,101,103,97,32,77,97,110,32,50,32,45,32,116,104,101,32,112,111,119,101,114,32,102,105,103,104,116,101,114,115,32,40,57,54,48,55,48,56,32,85,83,65,32,80,104,111,101,110,105,120,32,69,100,105,116,105,111,110,41,0,0,0,0,109,105,109,111,110,115,99,111,0,0,0,0,0,0,0,0,51,48,107,32,101,118,101,114,121,32,56,48,107,0,0,0,45,50,32,83,108,111,119,101,114,0,0,0,0,0,0,0,119,119,102,119,102,101,115,116,97,0,0,0,0,0,0,0,49,48,48,48,48,48,32,53,48,48,48,48,48,0,0,0,65,82,77,32,83,72,65,82,69,32,82,65,77,0,0,0,79,0,0,0,114,0,0,0,105,0,0,0,101,0,0,0,110,0,0,0,116,0,0,0,97,0,0,0,108,0,0,0,32,0,0,0,76,0,0,0,101,0,0,0,103,0,0,0,101,0,0,0,110,0,0,0,100,0,0,0,32,0,0,0,83,0,0,0,117,0,0,0,112,0,0,0,101,0,0,0,114,0,0,0,0,0,0,0,127,137,0,0,56,110,0,0,202,145,0,0,132,83,0,0,32,79,0,0,32,0,0,0,83,0,0,0,117,0,0,0,112,0,0,0,101,0,0,0,114,0,0,0,32,0,0,0,40,0,0,0,86,0,0,0,49,0,0,0,48,0,0,0,48,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,102,97,110,116,97,115,105,97,0,0,0,0,0,0,0,0,112,117,115,104,109,97,110,97,0,0,0,0,0,0,0,0,115,99,101,115,115,106,111,101,0,0,0,0,0,0,0,0,119,111,102,106,104,0,0,0,112,112,99,104,97,109,112,0,83,101,107,105,103,97,104,97,114,97,0,0,0,0,0,0,76,97,110,115,113,117,101,110,101,116,32,50,48,48,52,32,40,83,104,111,99,107,32,84,114,111,111,112,101,114,115,32,45,32,50,110,100,32,83,113,117,97,100,32,98,111,111,116,108,101,103,41,0,0,0,0,66,117,114,110,105,110,103,32,70,105,103,104,116,32,40,78,71,72,45,48,49,56,41,40,85,83,41,0,0,0,0,0,109,100,95,98,116,111,97,100,115,0,0,0,0,0,0,0,109,97,110,105,97,99,115,112,0,0,0,0,0,0,0,0,109,101,103,97,109,110,50,100,0,0,0,0,0,0,0,0,85,110,105,118,101,114,115,97,108,32,86,105,100,101,111,32,71,97,109,101,115,0,0,0,104,111,116,112,105,110,98,108,0,0,0,0,0,0,0,0,119,101,108,108,116,114,105,115,106,0,0,0,0,0,0,0,109,100,95,97,114,99,97,100,101,99,108,0,0,0,0,0,87,105,110,100,111,119,101,100,32,83,99,97,108,101,32,40,88,41,0,0,0,0,0,0,80,0,0,0,114,0,0,0,101,0,0,0,116,0,0,0,116,0,0,0,121,0,0,0,32,0,0,0,83,0,0,0,111,0,0,0,108,0,0,0,100,0,0,0,105,0,0,0,101,0,0,0,114,0,0,0,32,0,0,0,83,0,0,0,97,0,0,0,105,0,0,0,108,0,0,0,111,0,0,0,114,0,0,0,32,0,0,0,77,0,0,0,111,0,0,0,111,0,0,0,110,0,0,0,0,0,0,0,142,127,0,0,17,92,0,0,115,89,0,0,38,98,0,0,235,88,0,0,32,0,0,0,187,48,0,0,252,48,0,0,233,48,0,0,252,48,0,0,224,48,0,0,252,48,0,0,243,48,0,0,32,0,0,0,40,0,0,0,118,0,0,0,101,0,0,0,114,0,0,0,46,0,0,0,32,0,0,0,57,0,0,0,53,0,0,0,47,0,0,0,48,0,0,0,51,0,0,0,47,0,0,0,50,0,0,0,50,0,0,0,66,0,0,0,44,0,0,0,32,0,0,0,69,0,0,0,117,0,0,0,114,0,0,0,111,0,0,0,112,0,0,0,101,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,49,32,83,119,105,110,103,49,0,0,0,0,0,0,0,49,39,48,48,0,0,0,0,109,99,97,116,97,100,118,106,0,0,0,0,0,0,0,0,116,114,97,110,115,105,116,105,111,110,95,112,114,101,118,105,111,117,115,0,0,0,0,0,87,97,114,114,105,111,114,115,32,111,102,32,70,97,116,101,32,40,98,111,111,116,108,101,103,44,32,57,50,49,48,48,50,32,101,116,99,41,0,0,112,111,119,101,114,105,110,115,106,0,0,0,0,0,0,0,51,48,107,32,57,48,107,32,54,48,107,43,0,0,0,0,112,99,101,95,115,101,107,105,103,97,104,97,0,0,0,0,114,50,0,0,0,0,0,0,108,97,110,115,50,48,48,52,0,0,0,0,0,0,0,0,115,105,109,112,115,111,110,115,95,102,105,114,113,95,101,110,97,98,108,101,100,0,0,0,84,114,97,100,101,119,101,115,116,0,0,0,0,0,0,0,115,115,114,105,100,101,114,115,117,98,99,0,0,0,0,0,89,111,117,106,121,117,100,101,110,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,71,117,110,102,111,114,99,101,32,50,32,40,85,83,41,0,0,0,0,0,0,0,0,0,68,97,105,107,117,32,110,111,32,71,101,110,115,97,110,32,40,74,97,112,97,110,44,32,77,56,50,41,0,0,0,0,72,121,112,101,114,32,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,50,58,32,84,104,101,32,65,110,110,105,118,101,114,115,97,114,121,32,69,100,105,116,105,111,110,32,40,48,52,48,50,48,50,32,65,115,105,97,32,80,104,111,101,110,105,120,32,69,100,105,116,105,111,110,44,32,97,108,116,41,0,0,0,0,0,0,99,104,97,107,110,112,111,112,0,0,0,0,0,0,0,0,77,105,103,104,116,121,32,77,111,110,107,101,121,0,0,0,100,97,114,107,115,101,97,108,0,0,0,0,0,0,0,0,116,117,114,98,111,102,114,99,0,0,0,0,0,0,0,0,103,101,110,105,120,0,0,0,80,49,32,83,119,105,110,103,48,0,0,0,0,0,0,0,99,114,117,115,104,101,114,109,0,0,0,0,0,0,0,0,119,111,102,98,0,0,0,0,101,120,99,101,108,115,114,0,83,97,108,97,109,97,110,100,101,114,0,0,0,0,0,0,83,104,111,99,107,32,84,114,111,111,112,101,114,115,32,45,32,50,110,100,32,83,113,117,97,100,0,0,0,0,0,0,66,97,116,116,108,101,116,111,97,100,115,32,38,32,68,111,117,98,108,101,32,68,114,97,103,111,110,32,45,32,84,104,101,32,85,108,116,105,109,97,116,101,32,84,101,97,109,32,40,85,83,65,41,0,0,0,100,100,114,97,103,111,110,51,106,0,0,0,0,0,0,0,104,115,102,50,100,97,0,0,45,118,0,0,0,0,0,0,115,105,108,107,114,111,97,100,97,0,0,0,0,0,0,0,86,105,100,101,111,32,72,117,115,116,108,101,114,32,40,98,111,111,116,108,101,103,41,0,0,0,0,0,0,0,0,0,80,49,32,66,97,110,116,50,0,0,0,0,0,0,0,0,9,78,0,0,253,86,0,0,215,95,0,0,73,0,0,0,73,0,0,0,58,0,0,0,32,0,0,0,35,87,0,0,81,82,0,0,9,78,0,0,0,0,0,0,83,0,0,0,97,0,0,0,110,0,0,0,103,0,0,0,111,0,0,0,107,0,0,0,117,0,0,0,115,0,0,0,104,0,0,0,105,0,0,0,32,0,0,0,73,0,0,0,73,0,0,0,58,0,0,0,32,0,0,0,83,0,0,0,104,0,0,0,101,0,0,0,110,0,0,0,103,0,0,0,32,0,0,0,74,0,0,0,105,0,0,0,97,0,0,0,110,0,0,0,32,0,0,0,83,0,0,0,97,0,0,0,110,0,0,0,103,0,0,0,117,0,0,0,111,0,0,0,32,0,0,0,40,0,0,0,67,0,0,0,104,0,0,0,105,0,0,0,110,0,0,0,101,0,0,0,115,0,0,0,101,0,0,0,32,0,0,0,98,0,0,0,111,0,0,0,111,0,0,0,116,0,0,0,108,0,0,0,101,0,0,0,103,0,0,0,32,0,0,0,115,0,0,0,101,0,0,0,116,0,0,0,32,0,0,0,51,0,0,0,44,0,0,0,32,0,0,0,57,0,0,0,50,0,0,0,49,0,0,0,48,0,0,0,48,0,0,0,53,0,0,0,32,0,0,0,65,0,0,0,115,0,0,0,105,0,0,0,97,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,112,99,101,95,115,97,108,97,109,97,110,100,0,0,0,0,115,104,111,99,107,116,114,50,0,0,0,0,0,0,0,0,109,100,95,98,116,111,97,100,115,100,100,0,0,0,0,0,83,101,116,97,0,0,0,0,72,121,112,101,114,32,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,50,58,32,84,104,101,32,65,110,110,105,118,101,114,115,97,114,121,32,69,100,105,116,105,111,110,32,40,48,52,48,50,48,50,32,65,115,105,97,32,80,104,111,101,110,105,120,32,69,100,105,116,105,111,110,41,0,0,0,98,108,111,111,100,98,114,111,97,0,0,0,0,0,0,0,104,117,115,116,108,101,114,98,0,0,0,0,0,0,0,0,150,153,0,0,24,152,0,0,2,135,0,0,32,0,0,0,68,0,0,0,111,0,0,0,110,0,0,0,80,0,0,0,97,0,0,0,99,0,0,0,104,0,0,0,105,0,0,0,32,0,0,0,40,0,0,0,85,0,0,0,83,0,0,0,65,0,0,0,44,0,0,0,32,0,0,0,118,0,0,0,101,0,0,0,114,0,0,0,46,0,0,0,32,0,0,0,49,0,0,0,46,0,0,0,49,0,0,0,50,0,0,0,44,0,0,0,32,0,0,0,57,0,0,0,53,0,0,0,47,0,0,0,48,0,0,0,53,0,0,0,47,0,0,0,50,0,0,0,120,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,79,0,0,0,104,0,0,0,32,0,0,0,109,0,0,0,121,0,0,0,32,0,0,0,71,0,0,0,111,0,0,0,100,0,0,0,33,0,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,79,0,0,0,104,0,0,0,32,0,0,0,109,0,0,0,121,0,0,0,32,0,0,0,103,0,0,0,111,0,0,0,100,0,0,0,33,0,0,0,32,0,0,0,170,48,0,0,252,48,0,0,222,48,0,0,164,48,0,0,172,48,0,0,161,48,0,0,252,48,0,0,1,255,0,0,0,0,0,0,0,0,0,0,80,49,32,66,97,110,116,49,0,0,0,0,0,0,0,0,104,121,112,101,114,112,97,99,98,0,0,0,0,0,0,0,83,97,110,103,111,107,117,115,104,105,32,73,73,58,32,83,104,101,110,103,32,74,105,97,110,32,83,97,110,103,117,111,32,40,67,104,105,110,101,115,101,32,98,111,111,116,108,101,103,32,115,101,116,32,51,44,32,57,50,49,48,48,53,32,65,115,105,97,41,0,0,0,83,97,105,103,111,32,110,111,32,78,105,110,100,111,117,32,45,32,78,105,110,106,97,32,83,112,105,114,105,116,0,0,83,104,111,99,107,32,84,114,111,111,112,101,114,115,32,40,115,101,116,32,50,41,0,0,69,120,116,114,101,109,101,32,69,110,116,101,114,116,97,105,110,109,101,110,116,32,71,114,111,117,112,0,0,0,0,0,104,115,102,50,100,0,0,0,104,101,117,107,115,117,110,0,84,104,101,32,66,105,108,108,105,97,114,100,115,0,0,0,18,96,0,0,150,153,0,0,24,152,0,0,2,135,0,0,32,0,0,0,68,0,0,0,111,0,0,0,68,0,0,0,111,0,0,0,110,0,0,0,80,0,0,0,97,0,0,0,99,0,0,0,104,0,0,0,105,0,0,0,32,0,0,0,40,0,0,0,73,0,0,0,110,0,0,0,116,0,0,0,101,0,0,0,114,0,0,0,110,0,0,0,97,0,0,0,116,0,0,0,105,0,0,0,111,0,0,0,110,0,0,0,97,0,0,0,108,0,0,0,44,0,0,0,32,0,0,0,109,0,0,0,97,0,0,0,115,0,0,0,116,0,0,0,101,0,0,0,114,0,0,0,32,0,0,0,118,0,0,0,101,0,0,0,114,0,0,0,46,0,0,0,32,0,0,0,57,0,0,0,55,0,0,0,47,0,0,0,48,0,0,0,50,0,0,0,47,0,0,0,48,0,0,0,53,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,115,110,103,107,97,99,101,0,80,49,32,66,97,110,116,48,0,0,0,0,0,0,0,0,109,97,115,116,101,114,119,0,119,111,102,115,106,98,0,0,104,103,107,97,105,114,97,107,0,0,0,0,0,0,0,0,112,99,101,95,115,97,105,103,111,110,105,110,0,0,0,0,115,104,111,99,107,116,114,111,97,0,0,0,0,0,0,0,66,97,116,116,108,101,84,101,99,104,32,40,85,83,65,41,0,0,0,0,0,0,0,0,102,117,110,107,121,98,101,101,98,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,102,105,110,100,32,97,110,121,32,110,101,120,116,32,105,110,112,117,116,32,100,114,105,118,101,114,32,40,99,117,114,114,101,110,116,32,111,110,101,58,32,34,37,115,34,41,46,10,0,0,71,105,103,97,32,87,105,110,103,32,40,57,57,48,50,50,51,32,74,97,112,97,110,32,80,104,111,101,110,105,120,32,69,100,105,116,105,111,110,41,0,0,0,0,0,0,0,0,110,109,97,115,116,101,114,0,98,105,108,108,105,97,114,100,0,0,0,0,0,0,0,0,116,111,114,97,109,105,99,104,0,0,0,0,0,0,0,0,67,97,112,116,97,105,110,32,83,105,108,118,101,114,32,40,87,111,114,108,100,41,0,0,56,98,112,109,0,0,0,0,101,120,101,114,105,122,101,114,98,0,0,0,0,0,0,0,83,116,97,114,116,105,110,103,32,80,111,105,110,116,115,0,114,111,117,116,101,49,54,97,0,0,0,0,0,0,0,0,49,53,48,107,0,0,0,0,115,108,97,112,115,104,111,116,0,0,0,0,0,0,0,0,9,78,0,0,253,86,0,0,215,95,0,0,73,0,0,0,73,0,0,0,58,0,0,0,32,0,0,0,35,87,0,0,81,82,0,0,9,78,0,0,0,0,0,0,83,0,0,0,97,0,0,0,110,0,0,0,103,0,0,0,111,0,0,0,107,0,0,0,117,0,0,0,115,0,0,0,104,0,0,0,105,0,0,0,32,0,0,0,73,0,0,0,73,0,0,0,58,0,0,0,32,0,0,0,83,0,0,0,104,0,0,0,101,0,0,0,110,0,0,0,103,0,0,0,32,0,0,0,74,0,0,0,105,0,0,0,97,0,0,0,110,0,0,0,32,0,0,0,83,0,0,0,97,0,0,0,110,0,0,0,103,0,0,0,117,0,0,0,111,0,0,0,32,0,0,0,40,0,0,0,67,0,0,0,104,0,0,0,105,0,0,0,110,0,0,0,101,0,0,0,115,0,0,0,101,0,0,0,32,0,0,0,98,0,0,0,111,0,0,0,111,0,0,0,116,0,0,0,108,0,0,0,101,0,0,0,103,0,0,0,32,0,0,0,115,0,0,0,101,0,0,0,116,0,0,0,32,0,0,0,50,0,0,0,44,0,0,0,32,0,0,0,57,0,0,0,50,0,0,0,49,0,0,0,48,0,0,0,48,0,0,0,53,0,0,0,32,0,0,0,65,0,0,0,115,0,0,0,105,0,0,0,97,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,83,97,100,97,107,105,99,104,105,32,55,32,83,101,114,105,101,115,32,45,32,72,105,100,101,121,111,115,104,105,32,110,111,32,79,117,103,111,110,0,0,0,0,0,0,0,0,0,83,104,111,99,107,32,84,114,111,111,112,101,114,115,32,40,115,101,116,32,49,41,0,0,97,114,109,101,100,102,102,0,109,100,95,98,116,101,99,104,0,0,0,0,0,0,0,0,84,67,48,53,49,48,78,73,79,73,110,112,117,116,80,111,114,116,48,0,0,0,0,0,112,107,117,110,119,97,114,106,0,0,0,0,0,0,0,0,80,49,32,65,110,115,119,101,114,32,50,0,0,0,0,0,103,105,103,97,119,105,110,103,106,100,0,0,0,0,0,0,117,111,112,111,107,111,106,0,69,117,114,111,112,101,0,0,69,120,116,114,97,32,112,108,97,121,101,114,0,0,0,0,80,67,48,57,48,79,74,32,82,97,109,0,0,0,0,0,86,105,100,101,111,32,72,117,115,116,108,101,114,0,0,0,72,105,103,104,44,32,98,117,116,32,99,101,110,115,111,114,101,100,0,0,0,0,0,0,52,48,48,44,48,48,48,112,116,115,32,111,110,108,121,0,55,116,111,105,116,115,117,0,77,117,108,116,105,112,108,101,0,0,0,0,0,0,0,0,84,97,105,119,97,110,32,40,83,112,97,99,121,32,67,111,32,76,105,99,101,110,115,101,41,0,0,0,0,0,0,0,83,108,121,32,83,112,121,32,40,85,83,32,114,101,118,105,115,105,111,110,32,50,41,0,0,0,0,0,0,0,0,0,49,32,67,111,105,110,32,32,53,32,67,114,101,100,105,116,115,0,0,0,0,0,0,0,69,117,114,111,32,67,104,97,109,112,32,39,57,50,32,40,87,111,114,108,100,41,0,0,115,99,114,101,103,103,0,0,80,67,48,56,48,83,78,32,82,97,109,0,0,0,0,0,115,111,117,110,100,108,97,116,99,104,0,0,0,0,0,0,69,120,99,116,108,101,97,103,84,114,97,99,107,50,89,0,116,110,122,115,111,112,0,0,69,110,100,108,101,115,115,32,40,67,104,101,97,116,41,0,119,119,102,115,115,116,97,114,117,0,0,0,0,0,0,0,87,105,108,108,105,97,109,115,0,0,0,0,0,0,0,0,110,105,103,104,116,115,116,114,117,0,0,0,0,0,0,0,83,97,110,103,111,107,117,115,104,105,32,73,73,58,32,83,104,101,110,103,32,74,105,97,110,32,83,97,110,103,117,111,32,40,67,104,105,110,101,115,101,32,98,111,111,116,108,101,103,32,115,101,116,32,50,44,32,57,50,49,48,48,53,32,65,115,105,97,41,0,0,0,107,97,110,103,97,114,111,111,0,0,0,0,0,0,0,0,112,99,101,95,115,97,100,97,107,105,55,0,0,0,0,0,115,104,111,99,107,116,114,111,0,0,0,0,0,0,0,0,69,110,101,109,105,101,115,0,82,111,117,110,100,115,0,0,77,0,0,0,97,0,0,0,122,0,0,0,105,0,0,0,110,0,0,0,103,0,0,0,101,0,0,0,114,0,0,0,32,0,0,0,90,0,0,0,0,0,0,0,222,48,0,0,184,48,0,0,243,48,0,0,172,48,0,0,252,48,0,0,32,0,0,0,58,255,0,0,32,0,0,0,40,0,0,0,87,0,0,0,111,0,0,0,114,0,0,0,108,0,0,0,100,0,0,0,44,0,0,0,32,0,0,0,118,0,0,0,101,0,0,0,114,0,0,0,46,0,0,0,32,0,0,0,57,0,0,0,52,0,0,0,47,0,0,0,48,0,0,0,54,0,0,0,47,0,0,0,50,0,0,0,55,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,97,116,116,108,101,109,97,115,116,101,114,32,40,85,83,65,41,0,0,0,0,0,0,112,114,101,104,105,115,108,101,117,0,0,0,0,0,0,0,70,114,101,101,32,80,108,97,121,32,40,105,102,32,99,111,105,110,32,65,32,116,111,111,41,32,111,114,32,49,67,47,49,67,0,0,0,0,0,0,74,111,74,111,39,115,32,86,101,110,116,117,114,101,32,47,32,74,111,74,111,32,110,111,32,75,105,109,121,111,117,32,110,97,32,66,111,117,107,101,110,32,40,74,97,112,97,110,32,57,56,49,50,48,50,41,0,0,0,0,0,0,0,0,78,111,32,83,111,117,110,100,44,32,77,105,115,115,105,110,103,32,90,56,48,32,80,114,111,103,114,97,109,32,82,79,77,0,0,0,0,0,0,0,98,108,111,99,107,111,117,116,50,0,0,0,0,0,0,0,118,105,100,101,111,95,115,104,97,100,101,114,95,100,105,114,0,0,0,0,0,0,0,0,71,105,103,97,32,87,105,110,103,32,40,57,57,48,50,50,50,32,85,83,65,32,80,104,111,101,110,105,120,32,69,100,105,116,105,111,110,41,0,0,68,97,116,97,32,69,97,115,116,32,67,111,114,112,111,114,97,116,105,111,110,0,0,0,119,119,97,108,108,121,106,0,77,105,110,101,102,105,101,108,100,0,0,0,0,0,0,0,84,104,117,110,100,101,114,32,66,108,97,100,101,32,40,100,101,108,117,120,101,47,115,116,97,110,100,105,110,103,44,32,117,110,112,114,111,116,101,99,116,101,100,41,0,0,0,0,83,104,105,110,111,98,105,32,40,83,116,97,114,32,98,111,111,116,108,101,103,44,32,83,121,115,116,101,109,32,49,54,65,41,0,0,0,0,0,0,69,120,99,116,108,101,97,103,84,114,97,99,107,50,88,0,83,101,110,32,74,105,110,32,45,32,71,117,97,114,100,105,97,110,32,83,116,111,114,109,32,40,75,111,114,101,97,41,0,0,0,0,0,0,0,0,116,114,111,112,104,121,104,0,112,117,99,107,109,97,110,98,0,0,0,0,0,0,0,0,119,111,102,115,106,97,0,0,82,121,117,117,107,121,117,117,0,0,0,0,0,0,0,0,65,105,114,32,71,97,108,108,101,116,32,40,84,97,105,119,97,110,41,0,0,0,0,0,83,116,97,107,101,115,32,87,105,110,110,101,114,32,50,0,0,0,0,0,0,0,0,0,98,108,107,116,105,103,101,114,97,0,0,0,0,0,0,0,109,100,95,98,97,116,116,108,101,109,115,0,0,0,0,0,76,97,110,103,117,97,103,101,32,40,99,104,97,114,32,110,97,109,101,115,41,0,0,0,103,105,103,97,119,105,110,103,100,0,0,0,0,0,0,0,103,97,117,110,116,108,101,116,115,0,0,0,0,0,0,0,109,105,110,101,102,108,100,0,83,68,32,71,117,110,100,97,109,32,78,101,111,32,66,97,116,116,108,105,110,103,32,40,74,97,112,97,110,41,0,0,50,48,48,75,32,79,110,108,121,0,0,0,0,0,0,0,13,84,0,0,186,78,0,0,38,98,0,0,0,0,0,0,77,0,0,0,101,0,0,0,105,0,0,0,106,0,0,0,105,0,0,0,110,0,0,0,115,0,0,0,101,0,0,0,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,83,110,111,119,32,66,114,111,115,46,32,45,32,78,105,99,107,32,38,32,84,111,109,32,40,115,101,116,32,52,41,0,0,0,0,0,0,0,0,0,100,113,117,105,122,103,111,0,117,112,0,0,0,0,0,0,98,111,109,98,106,97,99,107,50,0,0,0,0,0,0,0,67,111,110,116,105,110,117,101,32,109,111,100,101,0,0,0,80,50,32,98,117,116,116,111,110,32,54,0,0,0,0,0,50,48,48,48,48,32,55,48,48,48,48,32,55,48,48,48,48,0,0,0,0,0,0,0,98,105,111,110,105,99,99,49,0,0,0,0,0,0,0,0,83,117,112,101,114,32,77,97,114,117,107,105,110,45,66,97,110,32,40,74,97,112,97,110,32,57,48,49,48,49,55,41,0,0,0,0,0,0,0,0,78,111,32,66,111,110,117,115,0,0,0,0,0,0,0,0,112,97,99,108,97,110,100,106,0,0,0,0,0,0,0,0,69,120,99,116,108,101,97,103,84,114,97,99,107,49,89,0,112,97,99,112,108,117,115,0,117,110,107,112,97,99,103,0,71,97,117,110,116,108,101,116,32,73,73,32,40,50,32,80,108,97,121,101,114,115,44,32,71,101,114,109,97,110,41,0,0,0,0,0,0,0,0,0,9,78,0,0,253,86,0,0,215,95,0,0,73,0,0,0,73,0,0,0,58,0,0,0,32,0,0,0,35,87,0,0,81,82,0,0,9,78,0,0,0,0,0,0,83,0,0,0,97,0,0,0,110,0,0,0,103,0,0,0,111,0,0,0,107,0,0,0,117,0,0,0,115,0,0,0,104,0,0,0,105,0,0,0,32,0,0,0,73,0,0,0,73,0,0,0,58,0,0,0,32,0,0,0,83,0,0,0,104,0,0,0,101,0,0,0,110,0,0,0,103,0,0,0,32,0,0,0,74,0,0,0,105,0,0,0,97,0,0,0,110,0,0,0,32,0,0,0,83,0,0,0,97,0,0,0,110,0,0,0,103,0,0,0,117,0,0,0,111,0,0,0,32,0,0,0,40,0,0,0,67,0,0,0,104,0,0,0,105,0,0,0,110,0,0,0,101,0,0,0,115,0,0,0,101,0,0,0,32,0,0,0,98,0,0,0,111,0,0,0,111,0,0,0,116,0,0,0,108,0,0,0,101,0,0,0,103,0,0,0,32,0,0,0,115,0,0,0,101,0,0,0,116,0,0,0,32,0,0,0,49,0,0,0,44,0,0,0,32,0,0,0,57,0,0,0,50,0,0,0,49,0,0,0,48,0,0,0,48,0,0,0,53,0,0,0,32,0,0,0,65,0,0,0,115,0,0,0,105,0,0,0,97,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,109,114,100,111,116,0,0,0,100,107,111,110,103,51,98,0,98,103,111,110,0,0,0,0,112,99,101,95,114,121,117,107,121,117,0,0,0,0,0,0,115,116,97,107,119,105,110,50,0,0,0,0,0,0,0,0,66,97,116,116,108,101,32,83,113,117,97,100,114,111,110,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,108,97,100,121,98,117,103,98,0,0,0,0,0,0,0,0,52,48,107,32,32,49,48,48,107,43,0,0,0,0,0,0,115,111,108,111,109,111,110,106,0,0,0,0,0,0,0,0,69,99,111,32,70,105,103,104,116,101,114,115,32,40,57,51,49,50,48,51,32,87,111,114,108,100,32,80,104,111,101,110,105,120,32,69,100,105,116,105,111,110,41,0,0,0,0,0,65,112,111,99,97,108,106,112,115,101,32,78,111,119,0,0,52,58,48,48,0,0,0,0,45,51,32,83,108,111,119,101,114,0,0,0,0,0,0,0,114,97,100,97,114,115,99,112,49,0,0,0,0,0,0,0,53,48,48,48,48,32,51,48,48,48,48,48,0,0,0,0,115,118,103,95,114,97,109,95,115,101,108,0,0,0,0,0,103,117,110,115,109,111,107,101,106,0,0,0,0,0,0,0,79,114,105,101,110,116,97,108,32,76,101,103,101,110,100,32,83,112,101,99,105,97,108,32,45,32,88,105,32,89,111,32,71,105,32,83,104,105,32,82,101,32,90,117,97,110,103,32,83,117,112,101,114,32,40,86,49,48,48,41,0,0,0,0,69,120,99,116,108,101,97,103,84,114,97,99,107,49,88,0,116,101,114,114,97,99,114,101,111,0,0,0,0,0,0,0,112,99,101,95,98,97,116,108,111,100,101,114,0,0,0,0,83,97,110,103,111,107,117,115,104,105,32,73,73,58,32,83,104,101,110,103,32,74,105,97,110,32,83,97,110,103,117,111,32,40,67,104,105,110,101,115,101,32,98,111,111,116,108,101,103,32,115,101,116,32,49,44,32,57,50,49,48,48,53,32,65,115,105,97,41,0,0,0,67,104,97,111,115,32,68,101,109,111,32,40,67,80,83,45,49,41,0,0,0,0,0,0,116,111,107,105,97,0,0,0,82,111,99,107,45,111,110,0,0,0,0,0,0,0,0,0,80,108,101,97,115,117,114,101,32,71,111,97,108,32,47,32,70,117,116,115,97,108,32,45,32,53,32,111,110,32,53,32,77,105,110,105,32,83,111,99,99,101,114,32,40,78,71,77,45,50,49,57,41,0,0,0,98,117,114,110,105,110,103,102,104,0,0,0,0,0,0,0,52,208,0,0,136,201,0,0,44,198,0,0,188,185,0,0,61,213,0,0,0,0,0,0,81,0,0,0,117,0,0,0,105,0,0,0,122,0,0,0,32,0,0,0,79,0,0,0,108,0,0,0,121,0,0,0,109,0,0,0,112,0,0,0,105,0,0,0,99,0,0,0,0,0,0,0,0,0,0,0,97,113,117,97,106,97,99,107,0,0,0,0,0,0,0,0,109,100,95,98,97,116,116,108,101,115,113,0,0,0,0,0,69,0,0,0,120,0,0,0,101,0,0,0,100,0,0,0,32,0,0,0,69,0,0,0,120,0,0,0,101,0,0,0,115,0,0,0,0,0,0,0,168,48,0,0,176,48,0,0,188,48,0,0,201,48,0,0,32,0,0,0,168,48,0,0,176,48,0,0,188,48,0,0,185,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,67,48,54,52,48,70,73,79,73,110,112,117,116,80,111,114,116,48,0,0,0,0,0,101,99,111,102,103,104,116,114,100,0,0,0,0,0,0,0,84,67,48,49,53,48,82,79,68,32,82,97,109,0,0,0,118,117,108,103,117,115,97,0,97,112,111,110,111,119,0,0,105,110,32,118,101,99,50,32,84,101,120,67,111,111,114,100,59,10,105,110,32,118,101,99,50,32,86,101,114,116,101,120,67,111,111,114,100,59,10,105,110,32,118,101,99,52,32,67,111,108,111,114,59,10,117,110,105,102,111,114,109,32,109,97,116,52,32,77,86,80,77,97,116,114,105,120,59,10,111,117,116,32,118,101,99,50,32,116,101,120,95,99,111,111,114,100,59,10,118,111,105,100,32,109,97,105,110,40,41,32,123,10,32,32,32,103,108,95,80,111,115,105,116,105,111,110,32,61,32,77,86,80,77,97,116,114,105,120,32,42,32,118,101,99,52,40,86,101,114,116,101,120,67,111,111,114,100,44,32,48,46,48,44,32,49,46,48,41,59,10,32,32,32,116,101,120,95,99,111,111,114,100,32,61,32,84,101,120,67,111,111,114,100,59,10,125,0,0,0,0,49,57,52,50,97,0,0,0,54,56,75,32,35,48,32,82,79,77,0,0,0,0,0,0,86,105,114,103,105,110,32,71,97,109,101,115,0,0,0,0,119,97,108,108,99,97,0,0,86,83,121,110,99,32,83,119,97,112,32,73,110,116,101,114,118,97,108,0,0,0,0,0,67,101,108,108,32,77,111,118,101,0,0,0,0,0,0,0,98,97,114,97,100,117,107,101,0,0,0,0,0,0,0,0,99,97,112,116,117,114,101,95,112,114,101,118,105,111,117,115,0,0,0,0,0,0,0,0,99,104,111,107,111,0,0,0,119,111,102,115,106,0,0,0,112,99,101,95,114,111,99,107,111,110,0,0,0,0,0,0,108,50,0,0,0,0,0,0,115,101,99,116,105,111,110,122,97,0,0,0,0,0,0,0,86,105,99,32,84,111,107,97,105,0,0,0,0,0,0,0,83,117,110,115,101,116,32,82,105,100,101,114,115,32,40,52,32,80,108,97,121,101,114,115,32,118,101,114,46,32,85,65,67,41,0,0,0,0,0,0,121,111,117,106,121,117,100,110,0,0,0,0,0,0,0,0,109,121,115,116,115,116,111,110,111,0,0,0,0,0,0,0,100,107,103,101,110,115,97,110,0,0,0,0,0,0,0,0,68,97,114,107,115,116,97,108,107,101,114,115,32,45,32,116,104,101,32,110,105,103,104,116,32,119,97,114,114,105,111,114,115,32,40,57,52,48,55,48,53,32,85,83,65,32,80,104,111,101,110,105,120,32,69,100,105,116,105,111,110,41,0,0,82,101,115,99,117,101,0,0,67,117,114,114,101,110,116,66,97,110,107,0,0,0,0,0,106,97,99,107,50,0,0,0,115,117,112,98,116,105,109,101,0,0,0,0,0,0,0,0,67,108,101,97,114,32,82,111,117,110,100,32,65,108,108,111,119,101,100,0,0,0,0,0,112,111,119,106,0,0,0,0,9,78,0,0,253,86,0,0,215,95,0,0,73,0,0,0,73,0,0,0,58,0,0,0,32,0,0,0,9,78,0,0,35,87,0,0,81,82,0,0])
.concat([0,0,0,0,83,0,0,0,97,0,0,0,110,0,0,0,103,0,0,0,111,0,0,0,107,0,0,0,117,0,0,0,115,0,0,0,104,0,0,0,105,0,0,0,32,0,0,0,73,0,0,0,73,0,0,0,58,0,0,0,32,0,0,0,83,0,0,0,97,0,0,0,110,0,0,0,32,0,0,0,83,0,0,0,104,0,0,0,101,0,0,0,110,0,0,0,103,0,0,0,32,0,0,0,74,0,0,0,105,0,0,0,97,0,0,0,110,0,0,0,32,0,0,0,40,0,0,0,67,0,0,0,104,0,0,0,105,0,0,0,110,0,0,0,101,0,0,0,115,0,0,0,101,0,0,0,32,0,0,0,98,0,0,0,111,0,0,0,111,0,0,0,116,0,0,0,108,0,0,0,101,0,0,0,103,0,0,0,32,0,0,0,115,0,0,0,101,0,0,0,116,0,0,0,32,0,0,0,50,0,0,0,44,0,0,0,32,0,0,0,57,0,0,0,50,0,0,0,49,0,0,0,48,0,0,0,48,0,0,0,53,0,0,0,32,0,0,0,65,0,0,0,115,0,0,0,105,0,0,0,97,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,82,97,115,116,97,110,32,83,97,103,97,32,73,73,0,0,79,0,0,0,112,0,0,0,101,0,0,0,114,0,0,0,97,0,0,0,116,0,0,0,105,0,0,0,111,0,0,0,110,0,0,0,32,0,0,0,82,0,0,0,97,0,0,0,103,0,0,0,110,0,0,0,97,0,0,0,103,0,0,0,97,0,0,0,114,0,0,0,100,0,0,0,0,0,0,0,94,121,0,0,240,81,0,0,243,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,99,111,109,109,97,110,100,111,117,0,0,0,0,0,0,0,66,97,116,116,108,101,32,77,97,110,105,97,32,68,97,105,103,105,110,106,111,117,32,40,74,112,110,44,32,75,111,114,41,0,0,0,0,0,0,0,100,115,116,108,107,117,49,100,0,0,0,0,0,0,0,0,45,99,0,0,0,0,0,0,49,57,52,51,117,0,0,0,114,101,115,99,117,101,0,0,100,121,110,100,117,107,101,97,0,0,0,0,0,0,0,0,107,117,110,105,111,107,117,110,0,0,0,0,0,0,0,0,98,108,117,101,112,114,110,116,106,0,0,0,0,0,0,0,69,110,101,114,103,121,32,77,101,116,101,114,0,0,0,0,65,105,114,119,111,108,102,32,40,85,83,41,0,0,0,0,83,97,110,103,111,107,117,115,104,105,32,73,73,58,32,83,97,110,32,83,104,101,110,103,32,74,105,97,110,32,40,67,104,105,110,101,115,101,32,98,111,111,116,108,101,103,32,115,101,116,32,50,44,32,57,50,49,48,48,53,32,65,115,105,97,41,0,0,0,0,0,0,84,117,114,98,111,32,101,110,97,98,108,101,0,0,0,0,115,112,114,105,110,103,101,114,0,0,0,0,0,0,0,0,112,99,101,95,114,97,115,116,97,110,50,0,0,0,0,0,82,97,103,110,97,103,97,114,100,32,47,32,83,104,105,110,45,79,104,45,75,101,110,0,0,0,0,0,0,0,0,0,109,100,95,98,116,108,109,97,110,105,100,0,0,0,0,0,108,97,115,116,100,117,101,108,111,0,0,0,0,0,0,0,68,105,109,97,104,111,111,32,40,48,48,48,49,50,49,32,85,83,65,32,80,104,111,101,110,105,120,32,69,100,105,116,105,111,110,41,0,0,0,0,115,102,117,0,0,0,0,0,68,105,97,108,32,100,111,101,115,110,39,116,32,119,111,114,107,32,118,101,114,121,32,119,101,108,108,0,0,0,0,0,115,114,117,109,98,108,101,114,50,0,0,0,0,0,0,0,115,107,121,107,105,100,111,0,67,114,101,100,105,116,115,32,110,101,101,100,101,100,0,0,119,111,102,51,115,106,97,0,103,110,103,97,0,0,0,0,82,97,105,100,101,110,0,0,66,97,116,116,108,101,32,71,111,108,102,101,114,32,89,117,105,32,40,74,112,110,41,0,0,0,0,0,0,0,0,0,97,114,97,98,105,97,110,97,0,0,0,0,0,0,0,0,100,97,114,105,117,115,0,0,102,97,114,109,101,114,0,0,100,105,109,97,104,111,117,100,0,0,0,0,0,0,0,0,68,97,114,107,32,80,108,97,110,101,116,0,0,0,0,0,103,97,108,97,103,97,111,0,119,99,57,48,97,0,0,0,115,111,110,115,111,110,106,0,69,69,80,82,79,77,32,82,65,77,0,0,0,0,0,0,114,97,108,108,121,120,97,0,9,78,0,0,253,86,0,0,215,95,0,0,73,0,0,0,73,0,0,0,58,0,0,0,32,0,0,0,9,78,0,0,35,87,0,0,81,82,0,0,0,0,0,0,83,0,0,0,97,0,0,0,110,0,0,0,103,0,0,0,111,0,0,0,107,0,0,0,117,0,0,0,115,0,0,0,104,0,0,0,105,0,0,0,32,0,0,0,73,0,0,0,73,0,0,0,58,0,0,0,32,0,0,0,83,0,0,0,97,0,0,0,110,0,0,0,32,0,0,0,83,0,0,0,104,0,0,0,101,0,0,0,110,0,0,0,103,0,0,0,32,0,0,0,74,0,0,0,105,0,0,0,97,0,0,0,110,0,0,0,32,0,0,0,40,0,0,0,67,0,0,0,104,0,0,0,105,0,0,0,110,0,0,0,101,0,0,0,115,0,0,0,101,0,0,0,32,0,0,0,98,0,0,0,111,0,0,0,111,0,0,0,116,0,0,0,108,0,0,0,101,0,0,0,103,0,0,0,32,0,0,0,115,0,0,0,101,0,0,0,116,0,0,0,32,0,0,0,49,0,0,0,44,0,0,0,32,0,0,0,57,0,0,0,50,0,0,0,49,0,0,0,48,0,0,0,48,0,0,0,53,0,0,0,32,0,0,0,65,0,0,0,115,0,0,0,105,0,0,0,97,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,114,112,117,110,99,104,0,0,112,99,101,95,114,97,105,100,101,110,0,0,0,0,0,0,83,116,97,107,101,115,32,87,105,110,110,101,114,32,47,32,83,116,97,107,101,115,32,87,105,110,110,101,114,32,45,32,71,73,32,107,105,110,122,101,110,32,115,101,105,104,97,32,101,32,110,111,32,109,105,99,104,105,0,0,0,0,0,0,97,109,98,117,115,104,106,0,109,100,95,98,97,116,116,108,121,117,105,0,0,0,0,0,68,117,110,103,101,111,110,115,32,38,32,68,114,97,103,111,110,115,32,45,32,116,111,119,101,114,32,111,102,32,100,111,111,109,32,40,57,52,48,52,49,50,32,69,117,114,111,32,80,104,111,101,110,105,120,32,69,100,105,116,105,111,110,41,0,0,0,0,0,0,0,0,114,121,103,97,114,50,0,0,100,97,114,107,112,108,110,116,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,115,116,97,116,101,32,102,114,111,109,32,34,37,115,34,46,10,0,0,0,99,115,105,108,118,101,114,0,100,100,114,97,103,111,110,119,0,0,0,0,0,0,0,0,128,146,0,0,179,108,0,0,251,78,0,0,160,79,0,0,29,79,0,0,0,0,0,0,71,0,0,0,105,0,0,0,110,0,0,0,103,0,0,0,97,0,0,0,32,0,0,0,78,0,0,0,105,0,0,0,110,0,0,0,107,0,0,0,121,0,0,0,111,0,0,0,117,0,0,0,68,0,0,0,101,0,0,0,110,0,0,0,32,0,0,0,40,0,0,0,115,0,0,0,101,0,0,0,116,0,0,0,32,0,0,0,49,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,82,111,119,32,83,99,114,111,108,108,0,0,0,0,0,0,111,108,100,115,49,48,48,97,0,0,0,0,0,0,0,0,83,97,110,103,111,107,117,115,104,105,32,73,73,58,32,83,97,110,32,83,104,101,110,103,32,74,105,97,110,32,40,67,104,105,110,101,115,101,32,98,111,111,116,108,101,103,32,115,101,116,32,49,44,32,57,50,49,48,48,53,32,65,115,105,97,41,0,0,0,0,0,0,82,97,99,105,110,103,32,68,97,109,97,115,104,105,105,0,0,0,0,0,0,0,0,0,66,97,116,109,97,110,32,70,111,114,101,118,101,114,32,40,87,111,114,108,100,41,0,0,80,49,32,65,110,115,119,101,114,32,49,0,0,0,0,0,100,100,116,111,100,100,0,0,99,97,100,97,115,104,0,0,85,83,0,0,0,0,0,0,49,0,0,0,0,0,0,0,83,116,114,111,110,103,32,88,0,0,0,0,0,0,0,0,84,97,105,119,97,110,32,40,65,110,97,109,111,116,111,32,73,110,116,101,114,110,97,116,105,111,110,97,108,32,105,110,99,46,41,0,0,0,0,0,70,114,97,109,101,98,117,102,102,101,114,32,48,0,0,0,72,111,110,103,32,75,111,110,103,32,40,84,97,105,116,111,32,67,111,114,112,32,108,105,99,101,110,115,101,41,0,0,50,48,48,44,48,48,48,32,101,118,101,114,121,32,109,97,120,32,51,0,0,0,0,0,54,0,0,0,0,0,0,0,115,108,121,115,112,121,50,0,80,111,108,121,71,97,109,101,77,97,115,116,101,114,0,0,101,117,114,111,99,104,57,50,0,0,0,0,0,0,0,0,65,108,108,32,82,65,77,0,84,104,101,32,78,101,119,90,101,97,108,97,110,100,32,83,116,111,114,121,32,40,87,111,114,108,100,44,32,111,108,100,32,118,101,114,115,105,111,110,41,32,40,111,108,100,101,114,32,80,67,66,41,0,0,0,68,46,32,82,46,32,75,111,114,101,97,0,0,0,0,0,49,115,116,32,67,104,97,110,99,101,0,0,0,0,0,0,72,105,116,32,116,104,101,32,73,99,101,32,40,85,83,41,0,0,0,0,0,0,0,0,78,105,103,104,116,32,83,116,114,105,107,101,114,32,40,74,97,112,97,110,41,0,0,0,119,111,102,51,115,106,0,0,37,115,0,0,0,0,0,0,84,111,112,32,83,112,101,101,100,32,40,85,83,41,0,0,112,99,101,95,114,97,99,105,110,100,97,109,0,0,0,0,175,48,0,0,164,48,0,0,186,48,0,0,173,48,0,0,243,48,0,0,176,48,0,0,170,48,0,0,214,48,0,0,213,48,0,0,161,48,0,0,164,48,0,0,191,48,0,0,252,48,0,0,186,48,0,0,0,0,0,0,81,0,0,0,117,0,0,0,105,0,0,0,122,0,0,0,32,0,0,0,75,0,0,0,105,0,0,0,110,0,0,0,103,0,0,0,32,0,0,0,111,0,0,0,102,0,0,0,32,0,0,0,70,0,0,0,105,0,0,0,103,0,0,0,104,0,0,0,116,0,0,0,101,0,0,0,114,0,0,0,115,0,0,0,32,0,0,0,40,0,0,0,75,0,0,0,111,0,0,0,114,0,0,0,101,0,0,0,97,0,0,0,110,0,0,0,32,0,0,0,114,0,0,0,101,0,0,0,108,0,0,0,101,0,0,0,97,0,0,0,115,0,0,0,101,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,109,100,95,98,97,116,109,97,110,102,0,0,0,0,0,0,106,111,106,111,106,114,50,0,66,97,121,32,82,111,117,116,101,32,40,115,101,116,32,49,44,32,85,83,44,32,117,110,112,114,111,116,101,99,116,101,100,41,0,0,0,0,0,0,118,105,100,101,111,95,103,112,117,95,115,99,114,101,101,110,115,104,111,116,0,0,0,0,68,117,110,103,101,111,110,115,32,38,32,68,114,97,103,111,110,115,32,45,32,115,104,97,100,111,119,32,111,118,101,114,32,109,121,115,116,97,114,97,32,40,57,54,48,54,49,57,32,85,83,65,32,80,104,111,101,110,105,120,32,69,100,105,116,105,111,110,41,0,0,0,78,111,98,111,114,97,110,107,97,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,80,0,0,0,77,0,0,0,0,0,0,0,0,0,0,0,115,116,114,111,110,103,120,0,116,104,110,100,114,98,108,100,49,0,0,0,0,0,0,0,115,104,105,110,111,98,108,115,0,0,0,0,0,0,0,0,76,101,102,116,47,82,105,103,104,116,0,0,0,0,0,0,103,114,100,110,115,116,114,109,107,0,0,0,0,0,0,0,87,105,110,103,32,83,104,111,111,116,105,110,103,32,67,104,97,109,112,105,111,110,115,104,105,112,32,86,49,46,48,48,0,0,0,0,0,0,0,0,87,111,114,108,100,32,76,105,99,101,110,115,101,0,0,0,9,78,0,0,253,86,0,0,215,95,0,0,73,0,0,0,73,0,0,0,58,0,0,0,32,0,0,0,9,78,0,0,141,82,0,0,86,128,0,0,0,0,0,0,83,0,0,0,97,0,0,0,110,0,0,0,103,0,0,0,111,0,0,0,107,0,0,0,117,0,0,0,115,0,0,0,104,0,0,0,105,0,0,0,32,0,0,0,73,0,0,0,73,0,0,0,58,0,0,0,32,0,0,0,83,0,0,0,97,0,0,0,110,0,0,0,32,0,0,0,74,0,0,0,105,0,0,0,97,0,0,0,110,0,0,0,32,0,0,0,83,0,0,0,104,0,0,0,101,0,0,0,110,0,0,0,103,0,0,0,32,0,0,0,40,0,0,0,67,0,0,0,104,0,0,0,105,0,0,0,110,0,0,0,101,0,0,0,115,0,0,0,101,0,0,0,32,0,0,0,98,0,0,0,111,0,0,0,111,0,0,0,116,0,0,0,108,0,0,0,101,0,0,0,103,0,0,0,32,0,0,0,115,0,0,0,101,0,0,0,116,0,0,0,32,0,0,0,50,0,0,0,44,0,0,0,32,0,0,0,57,0,0,0,50,0,0,0,49,0,0,0,48,0,0,0,48,0,0,0,53,0,0,0,32,0,0,0,65,0,0,0,115,0,0,0,105,0,0,0,97,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,67,108,101,97,114,32,83,116,97,103,101,32,80,111,119,101,114,32,85,112,0,0,0,0,97,103,97,108,108,101,116,116,0,0,0,0,0,0,0,0,81,117,105,122,32,75,105,110,103,32,111,102,32,70,105,103,104,116,101,114,115,32,40,75,111,114,101,97,110,32,114,101,108,101,97,115,101,41,0,0,66,97,116,109,97,110,32,45,32,82,101,118,101,110,103,101,32,111,102,32,116,104,101,32,74,111,107,101,114,32,40,85,83,65,41,0,0,0,0,0,99,104,105,112,45,62,118,111,105,99,101,0,0,0,0,0,100,100,115,111,109,117,100,0,112,111,114,116,65,95,105,110,0,0,0,0,0,0,0,0,75,111,110,97,109,105,32,40,83,116,101,114,110,32,76,105,99,101,110,115,101,41,0,0,110,101,111,98,97,116,116,108,0,0,0,0,0,0,0,0,50,53,48,75,44,32,50,53,48,75,32,69,118,101,114,121,0,0,0,0,0,0,0,0,79,104,109,121,103,111,100,83,99,114,111,108,108,121,0,0,115,110,111,119,98,114,111,115,99,0,0,0,0,0,0,0,33,113,0,0,80,150,0,0,221,82,0,0,160,140,0,0,0,0,0,0,4,200,0,0,208,198,0,0,32,0,0,0,109,173,0,0,28,200,0,0,172,185,0,0,248,173,0,0,32,0,0,0,4,200,0,0,32,0,0,0,40,0,0,0,83,0,0,0,101,0,0,0,109,0,0,0,105,0,0,0,67,0,0,0,111,0,0,0,109,0,0,0,32,0,0,0,66,0,0,0,97,0,0,0,115,0,0,0,101,0,0,0,98,0,0,0,97,0,0,0,108,0,0,0,108,0,0,0,41,0,0,0,32,0,0,0,40,0,0,0,75,0,0,0,111,0,0,0,114,0,0,0,101,0,0,0,97,0,0,0,41,0,0,0,0,0,0,0,77,0,0,0,117,0,0,0,72,0,0,0,97,0,0,0,110,0,0,0,83,0,0,0,101,0,0,0,117,0,0,0,110,0,0,0,103,0,0,0,66,0,0,0,117,0,0,0,0,0,0,0,0,0,0,0,45,112,111,115,0,0,0,0,112,99,101,95,50,49,101,109,111,110,0,0,0,0,0,0,106,111,121,115,116,105,99,107,95,54,98,95,115,101,108,101,99,116,91,50,93,0,0,0,109,97,114,117,107,105,110,0,51,48,48,48,48,48,47,53,48,48,48,48,48,0,0,0,80,117,99,107,32,77,97,110,32,40,83,112,97,110,105,115,104,44,32,39,77,97,100,101,32,105,110,32,71,114,101,101,99,101,39,32,98,111,111,116,108,101,103,41,0,0,0,0,103,97,117,110,116,50,50,112,103,0,0,0,0,0,0,0,53,48,75,32,79,110,108,121,0,0,0,0,0,0,0,0,49,67,95,53,67,0,0,0,83,97,110,103,111,107,117,115,104,105,32,73,73,58,32,83,97,110,32,74,105,97,110,32,83,104,101,110,103,32,40,67,104,105,110,101,115,101,32,98,111,111,116,108,101,103,32,115,101,116,32,50,44,32,57,50,49,48,48,53,32,65,115,105,97,41,0,0,0,0,0,0,68,111,110,107,101,121,32,75,111,110,103,32,51,32,40,74,97,112,97,110,41,0,0,0,99,104,111,110,0,0,0,0,82,97,98,105,111,32,76,101,112,117,115,32,83,112,101,99,105,97,108,0,0,0,0,0,113,117,105,122,107,111,102,107,0,0,0,0,0,0,0,0,67,121,98,101,114,98,111,116,115,32,45,32,102,117,108,108,109,101,116,97,108,32,109,97,100,110,101,115,115,32,40,74,97,112,97,110,32,57,53,48,52,50,52,41,32,40,100,101,99,114,121,112,116,101,100,32,98,111,111,116,108,101,103,41,0,0,0,0,0,0,0,0,109,100,95,98,97,116,109,97,110,114,106,0,0,0,0,0,51,48,107,32,32,56,48,107,43,0,0,0,0,0,0,0,114,101,103,115,0,0,0,0,83,116,114,97,116,101,103,121,32,88,32,40,83,116,101,114,110,41,0,0,0,0,0,0,65,108,108,111,119,32,66,117,121,32,73,110,0,0,0,0,45,52,32,83,108,111,119,101,114,0,0,0,0,0,0,0,53,48,48,48,48,32,50,48,48,48,48,48,0,0,0,0,97,115,105,99,50,55,97,95,116,111,95,54,56,107,0,0,111,108,100,115,49,48,48,0,83,116,97,114,116,32,76,101,118,101,108,32,83,101,108,101,99,116,0,0,0,0,0,0,119,111,102,51,106,115,97,0,112,99,101,95,114,97,98,105,111,108,101,112,0,0,0,0,175,48,0,0,164,48,0,0,186,48,0,0,173,48,0,0,243,48,0,0,176,48,0,0,170,48,0,0,214,48,0,0,213,48,0,0,161,48,0,0,164,48,0,0,191,48,0,0,252,48,0,0,186,48,0,0,0,0,0,0,81,0,0,0,117,0,0,0,105,0,0,0,122,0,0,0,32,0,0,0,75,0,0,0,105,0,0,0,110,0,0,0,103,0,0,0,32,0,0,0,111,0,0,0,102,0,0,0,32,0,0,0,70,0,0,0,105,0,0,0,103,0,0,0,104,0,0,0,116,0,0,0,101,0,0,0,114,0,0,0,115,0,0,0,32,0,0,0,40,0,0,0,83,0,0,0,65,0,0,0,77,0,0,0,45,0,0,0,48,0,0,0,56,0,0,0,48,0,0,0,41,0,0,0,40,0,0,0,83,0,0,0,65,0,0,0,72,0,0,0,45,0,0,0,48,0,0,0,56,0,0,0,48,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,117,114,110,105,110,103,32,70,105,103,104,116,32,40,78,71,77,45,48,49,56,41,40,78,71,72,45,48,49,56,41,0,0,0,0,0,0,0,0,66,97,116,109,97,110,32,40,85,83,65,41,0,0,0,0,78,101,111,32,71,101,111,32,77,86,83,0,0,0,0,0,99,121,98,111,116,115,106,100,0,0,0,0,0,0,0,0,65,68,80,67,77,32,82,79,77,0,0,0,0,0,0,0,115,116,114,97,116,103,121,115,0,0,0,0,0,0,0,0,97,116,116,114,105,98,117,116,101,32,118,101,99,50,32,84,101,120,67,111,111,114,100,59,10,97,116,116,114,105,98,117,116,101,32,118,101,99,50,32,86,101,114,116,101,120,67,111,111,114,100,59,10,97,116,116,114,105,98,117,116,101,32,118,101,99,52,32,67,111,108,111,114,59,10,117,110,105,102,111,114,109,32,109,97,116,52,32,77,86,80,77,97,116,114,105,120,59,10,118,97,114,121,105,110,103,32,118,101,99,50,32,116,101,120,95,99,111,111,114,100,59,10,118,111,105,100,32,109,97,105,110,40,41,32,123,10,32,32,32,103,108,95,80,111,115,105,116,105,111,110,32,61,32,77,86,80,77,97,116,114,105,120,32,42,32,118,101,99,52,40,86,101,114,116,101,120,67,111,111,114,100,44,32,48,46,48,44,32,49,46,48,41,59,10,32,32,32,116,101,120,95,99,111,111,114,100,32,61,32,84,101,120,67,111,111,114,100,59,10,125,0,0,0,49,57,52,49,114,49,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,70,66,79,32,116,101,120,116,117,114,101,115,32,101,120,99,101,101,100,101,100,32,109,97,120,105,109,117,109,32,115,105,122,101,32,111,102,32,71,80,85,32,40,37,117,120,37,117,41,46,32,82,101,115,105,122,105,110,103,32,116,111,32,102,105,116,46,10,0,0,0,0,0,0,0,0,83,102,50,109,100,116,83,97,109,112,108,101,83,101,108,101,99,116,49,0,0,0,0,0,65,110,111,116,104,101,114,32,87,111,114,108,100,32,40,69,117,114,111,41,0,0,0,0,50,48,48,32,79,110,108,121,0,0,0,0,0,0,0,0,66,108,97,99,107,32,70,114,97,109,101,32,73,110,115,101,114,116,105,111,110,0,0,0,72,119,99,104,97,109,112,73,110,112,117,116,86,97,108,0,75,48,53,50,49,48,57,95,115,101,108,101,99,116,101,100,0,0,0,0,0,0,0,0,67,111,110,116,114,111,108,32,105,110,32,51,68,32,83,116,97,103,101,115,0,0,0,0,74,97,112,97,110,32,79,110,108,121,0,0,0,0,0,0,116,114,97,110,115,105,116,105,111,110,95,99,111,117,110,116,0,0,0,0,0,0,0,0,66,97,116,116,108,101,32,67,105,114,99,117,105,116,32,40,57,55,48,51,49,57,32,74,97,112,97,110,41,0,0,0,98,117,98,108,98,111,98,108,0,0,0,0,0,0,0,0,9,78,0,0,253,86,0,0,215,95,0,0,73,0,0,0,73,0,0,0,58,0,0,0,32,0,0,0,9,78,0,0,141,82,0,0,86,128,0,0,0,0,0,0,83,0,0,0,97,0,0,0,110,0,0,0,103,0,0,0,111,0,0,0,107,0,0,0,117,0,0,0,115,0,0,0,104,0,0,0,105,0,0,0,32,0,0,0,73,0,0,0,73,0,0,0,58,0,0,0,32,0,0,0,83,0,0,0,97,0,0,0,110,0,0,0,32,0,0,0,74,0,0,0,105,0,0,0,97,0,0,0,110,0,0,0,32,0,0,0,83,0,0,0,104,0,0,0,101,0,0,0,110,0,0,0,103,0,0,0,32,0,0,0,40,0,0,0,67,0,0,0,104,0,0,0,105,0,0,0,110,0,0,0,101,0,0,0,115,0,0,0,101,0,0,0,32,0,0,0,98,0,0,0,111,0,0,0,111,0,0,0,116,0,0,0,108,0,0,0,101,0,0,0,103,0,0,0,32,0,0,0,115,0,0,0,101,0,0,0,116,0,0,0,32,0,0,0,49,0,0,0,44,0,0,0,32,0,0,0,57,0,0,0,50,0,0,0,49,0,0,0,48,0,0,0,48,0,0,0,53,0,0,0,32,0,0,0,65,0,0,0,115,0,0,0,105,0,0,0,97,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,82,45,84,121,112,101,32,80,97,114,116,45,50,0,0,0,84,67,48,51,54,48,80,82,73,82,101,103,115,0,0,0,109,100,95,98,97,116,109,97,110,117,0,0,0,0,0,0,115,115,114,105,100,101,114,115,117,97,99,0,0,0,0,0,83,112,101,108,117,110,107,101,114,32,73,73,0,0,0,0,73,110,118,105,110,99,105,98,105,108,116,121,0,0,0,0,103,117,110,102,111,114,99,50,0,0,0,0,0,0,0,0,67,121,98,101,114,98,111,116,115,32,45,32,102,117,108,108,109,101,116,97,108,32,109,97,100,110,101,115,115,32,40,57,53,48,52,50,52,32,85,83,65,32,80,104,111,101,110,105,120,32,69,100,105,116,105,111,110,41,0,0,0,0,0,0,83,116,114,97,116,101,103,121,32,88,0,0,0,0,0,0,69,97,115,121,32,51,0,0,83,97,108,101,115,0,0,0,83,97,110,103,111,107,117,115,104,105,32,73,73,58,32,83,97,110,32,74,105,97,110,32,83,104,101,110,103,32,40,67,104,105,110,101,115,101,32,98,111,111,116,108,101,103,32,115,101,116,32,49,44,32,57,50,49,48,48,53,32,65,115,105,97,41,0,0,0,0,0,0,112,99,101,95,114,116,121,112,101,112,50,0,0,0,0,0,81,117,105,122,32,75,105,110,103,32,111,102,32,70,105,103,104,116,101,114,115,32,40,83,65,77,45,48,56,48,41,40,83,65,72,45,48,56,48,41,0,0,0,0,0,0,0,0,66,97,116,109,97,110,32,40,74,112,110,41,0,0,0,0,99,121,98,111,116,115,117,100,0,0,0,0,0,0,0,0,45,83,0,0,0,0,0,0,115,116,114,97,116,103,121,120,0,0,0,0,0,0,0,0,98,97,108,108,98,114,111,115,0,0,0,0,0,0,0,0,68,101,108,116,97,84,46,115,116,101,112,0,0,0,0,0,69,97,115,121,32,50,0,0,109,99,117,95,105,110,105,116,105,97,108,105,122,105,110,103,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,80,97,114,115,105,110,103,32,90,73,80,32,102,97,105,108,101,100,46,10,0,0,0,0,0,0,0,119,111,102,51,106,115,0,0,82,45,84,121,112,101,32,80,97,114,116,45,49,0,0,0,84,67,48,49,48,48,83,67,78,32,82,97,109,0,0,0,67,97,112,99,111,109,32,83,112,111,114,116,115,32,67,108,117,98,32,40,57,55,48,55,50,50,32,69,117,114,111,32,80,104,111,101,110,105,120,32,69,100,105,116,105,111,110,41,0,0,0,0,0,0,0,0,109,100,95,98,97,116,109,97,110,106,0,0,0,0,0,0,103,108,85,110,109,97,112,66,117,102,102,101,114,79,69,83,0,0,0,0,0,0,0,0,84,67,48,50,56,48,71,82,68,32,82,97,109,0,0,0,118,100,99,95,114,101,103,105,115,116,101,114,91,105,93,0,84,67,48,52,56,48,83,67,80,32,82,97,109,0,0,0,77,111,111,110,119,97,114,32,40,111,108,100,101,114,41,0,0,0,0,0,0,0,0,0,104,101,97,100,101,114,32,99,114,99,32,109,105,115,109,97,116,99,104,0,0,0,0,0,84,105,109,101,32,76,105,109,105,116,115,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,71,76,83,76,32,115,116,111,99,107,32,112,114,111,103,114,97,109,115,32,102,97,105,108,101,100,32,116,111,32,99,111,109,112,105,108,101,46,10,0,0,0,0,9,78,0,0,253,86,0,0,215,95,0,0,73,0,0,0,73,0,0,0,58,0,0,0,32,0,0,0,9,78,0,0,11,87,0,0,241,130,0,0,196,150,0,0,179,80,0,0,0,0,0,0,83,0,0,0,97,0,0,0,110,0,0,0,103,0,0,0,111,0,0,0,107,0,0,0,117,0,0,0,115,0,0,0,104,0,0,0,105,0,0,0,32,0,0,0,73,0,0,0,73,0,0,0,58,0,0,0,32,0,0,0,83,0,0,0,97,0,0,0,110,0,0,0,103,0,0,0,117,0,0,0,111,0,0,0,32,0,0,0,89,0,0,0,105,0,0,0,110,0,0,0,103,0,0,0,88,0,0,0,105,0,0,0,111,0,0,0,110,0,0,0,103,0,0,0,90,0,0,0,104,0,0,0,117,0,0,0,97,0,0,0,110,0,0,0,32,0,0,0,40,0,0,0,67,0,0,0,104,0,0,0,105,0,0,0,110,0,0,0,101,0,0,0,115,0,0,0,101,0,0,0,32,0,0,0,98,0,0,0,111,0,0,0,111,0,0,0,116,0,0,0,108,0,0,0,101,0,0,0,103,0,0,0,32,0,0,0,115,0,0,0,101,0,0,0,116,0,0,0,32,0,0,0,51,0,0,0,44,0,0,0,32,0,0,0,57,0,0,0,50,0,0,0,49,0,0,0,48,0,0,0,48,0,0,0,53,0,0,0,32,0,0,0,65,0,0,0,115,0,0,0,105,0,0,0,97,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,112,99,101,95,114,116,121,112,101,112,49,0,0,0,0,0,84,72,81,0,0,0,0,0,99,115,99,108,117,98,49,100,0,0,0,0,0,0,0,0,109,111,111,110,119,97,114,97,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,71,76,58,32,85,115,105,110,103,32,37,117,32,116,101,120,116,117,114,101,115,46,10,0,0,0,0,0,0,43,50,32,67,114,101,100,105,116,115,32,51,32,73,110,110,105,110,103,115,0,0,0,0,100,97,114,105,117,115,50,0,83,97,110,103,111,107,117,115,104,105,32,73,73,58,32,83,97,110,103,117,111,32,89,105,110,103,120,105,111,110,103,32,90,104,117,97,110,32,40,67,104,105,110,101,115,101,32,98,111,111,116,108,101,103,32,115,101,116,32,51,44,32,57,50,49,48,48,53,32,65,115,105,97,41,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,85,78,83,85,80,80,79,82,84,69,68,32,40,35,37,117,41,46,10,0,0,81,117,105,122,32,84,111,117,107,111,117,32,83,104,97,115,104,105,110,0,0,0,0,0,83,116,114,105,107,101,114,115,32,49,57,52,53,32,80,108,117,115,0,0,0,0,0,0,66,65,83,83,32,77,97,115,116,101,114,115,32,67,108,97,115,115,105,99,32,45,32,80,114,111,32,69,100,105,116,105,111,110,32,40,85,83,65,41,0,0,0,0,0,0,0,0,68,73,83,75,32,65,80,80,69,78,68,32,37,115,0,0,66,97,116,116,108,101,32,67,105,114,99,117,105,116,32,40,57,55,48,51,49,57,32,69,117,114,111,32,80,104,111,101,110,105,120,32,69,100,105,116,105,111,110,41,0,0,0,0,77,111,111,110,119,97,114,0,0,0,0,0,0,0,0,0,66,114,101,121,119,111,111,100,32,40,74,97,112,97,110,32,114,101,118,105,115,105,111,110,32,50,41,0,0,0,0,0,49,32,67,114,101,100,105,116,32,49,32,73,110,110,105,110,103,32,79,110,108,121,0,0,79,78,0,0,0,0,0,0,115,103,121,120,122,0,0,0,112,99,101,95,113,117,105,122,116,115,0,0,0,0,0,0,83,101,103,97,32,77,101,103,97,100,114,105,118,101,0,0,115,49,57,52,53,112,0,0,75,48,53,49,57,54,48,95,110,109,105,95,101,110,97,98,108,101,100,0,0,0,0,0,109,100,95,98,97,115,115,109,112,114,111,0,0,0,0,0,75,48,53,50,49,48,57,83,99,114,111,108,108,89,91,49,93,0,0,0,0,0,0,0,102,98,102,114,101,110,122,121,0,0,0,0,0,0,0,0,80,49,32,83,117,112,101,114,0,0,0,0,0,0,0,0,98,97,116,99,105,114,100,0,99,114,105,109,102,103,104,116,106,0,0,0,0,0,0,0,74,97,112,97,110,0,0,0,109,111,111,110,119,97,114,0,72,111,110,103,32,75,111,110,103,0,0,0,0,0,0,0,78,117,100,105,116,121,0,0,104,99,97,115,116,108,101,107,0,0,0,0,0,0,0,0,83,104,111,119,32,65,108,108,32,82,105,103,104,116,115,32,82,101,115,101,114,118,101,100,0,0,0,0,0,0,0,0,102,108,115,116,111,114,121,0,109,97,105,110,101,118,116,111,0,0,0,0,0,0,0,0,83,108,121,32,83,112,121,32,40,85,83,32,114,101,118,105,115,105,111,110,32,51,41,0,0,0,0,0,0,0,0,0,72,97,116,32,84,114,105,99,107,32,72,101,114,111,32,40,74,97,112,97,110,41,0,0,73,110,110,105,110,103,115,0,116,110,122,115,111,0,0,0,72,101,120,97,0,0,0,0,112,105,0,0,0,0,0,0,97,108,105,101,110,115,50,0,104,105,116,105,99,101,0,0,84,67,48,54,52,48,70,73,79,73,110,112,117,116,0,0,110,105,103,104,116,115,116,114,106,0,0,0,0,0,0,0,9,78,0,0,253,86,0,0,215,95,0,0,73,0,0,0,73,0,0,0,58,0,0,0,32,0,0,0,9,78,0,0,11,87,0,0,241,130,0,0,196,150,0,0,179,80,0,0,0,0,0,0,83,0,0,0,97,0,0,0,110,0,0,0,103,0,0,0,111,0,0,0,107,0,0,0,117,0,0,0,115,0,0,0,104,0,0,0,105,0,0,0,32,0,0,0,73,0,0,0,73,0,0,0,58,0,0,0,32,0,0,0,83,0,0,0,97,0,0,0,110,0,0,0,103,0,0,0,117,0,0,0,111,0,0,0,32,0,0,0,89,0,0,0,105,0,0,0,110,0,0,0,103,0,0,0,88,0,0,0,105,0,0,0,111,0,0,0,110,0,0,0,103,0,0,0,90,0,0,0,104,0,0,0,117,0,0,0,97,0,0,0,110,0,0,0,32,0,0,0,40,0,0,0,67,0,0,0,104,0,0,0,105,0,0,0,110,0,0,0,101,0,0,0,115,0,0,0,101,0,0,0,32,0,0,0,98,0,0,0,111,0,0,0,111,0,0,0,116,0,0,0,108,0,0,0,101,0,0,0,103,0,0,0,32,0,0,0,115,0,0,0,101,0,0,0,116,0,0,0,32,0,0,0,50,0,0,0,44,0,0,0,32,0,0,0,57,0,0,0,50,0,0,0,49,0,0,0,48,0,0,0,48,0,0,0,53,0,0,0,32,0,0,0,65,0,0,0,115,0,0,0,105,0,0,0,97,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,116,111,112,115,112,101,101,100,117,0,0,0,0,0,0,0,114,117,115,104,97,116,99,107,0,0,0,0,0,0,0,0,80,117,122,122,110,105,99,0,0,0,0,0,0,0,0,0,90,0,0,0,101,0,0,0,100,0,0,0,32,0,0,0,66,0,0,0,108,0,0,0,97,0,0,0,100,0,0,0,101,0,0,0,0,0,0,0,79,0,0,0,112,0,0,0,101,0,0,0,114,0,0,0,97,0,0,0,116,0,0,0,105,0,0,0,111,0,0,0,110,0,0,0,32,0,0,0,82,0,0,0,97,0,0,0,103,0,0,0,110,0,0,0,97,0,0,0,114,0,0,0,111,0,0,0,107,0,0,0,0,0,0,0,92,79,0,0,38,98,0,0,13,84,0,0,2,255,0,0,233,48,0,0,176,48,0,0,202,48,0,0,237,48,0,0,175,48,0,0,2,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,48,107,32,97,110,100,32,101,118,101,114,121,32,50,48,48,107,0,0,0,0,0,0,65,108,105,101,110,32,118,115,32,80,114,101,100,97,116,111,114,32,40,57,52,48,53,50,48,32,69,117,114,111,32,80,104,111,101,110,105,120,32,69,100,105,116,105,111,110,41,0,0,0,0,0,0,0,0,0,65,108,119,97,121,115,0,0,66,108,97,99,107,32,80,101,97,114,108,0,0,0,0,0,70,114,101,101,32,80,108,97,121,32,40,105,102,32,99,111,105,110,32,66,32,116,111,111,41,32,111,114,32,49,67,47,49,67,0,0,0,0,0,0,80,0,0,0,97,0,0,0,114,0,0,0,111,0,0,0,100,0,0,0,105,0,0,0,117,0,0,0,115,0,0,0,32,0,0,0,209,48,0,0,237,48,0,0,199,48,0,0,163,48,0,0,166,48,0,0,185,48,0,0,96,48,0,0,1,255,0,0,32,0,0,0,13,255,0,0,94,121,0,0,113,138,0,0,75,48,0,0,137,48,0,0,74,48,0,0,17,123,0,0,68,48,0,0,120,48,0,0,13,255,0,0,32,0,0,0,40,0,0,0,87,0,0,0,111,0,0,0,114,0,0,0,108,0,0,0,100,0,0,0,44,0,0,0,32,0,0,0,115,0,0,0,101,0,0,0,116,0,0,0,32,0,0,0,49,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,48,0,0,231,48,0,0,184,48,0,0,231,48,0,0,110,48,0,0,32,0,0,0,71,89,0,0,153,89,0,0,106,48,0,0,146,81,0,0,122,150,0,0,0,0,0,0,74,0,0,0,111,0,0,0,74,0,0,0,111,0,0,0,39,0,0,0,115,0,0,0,32,0,0,0,86,0,0,0,101,0,0,0,110,0,0,0,116,0,0,0,117,0,0,0,114,0,0,0,101,0,0,0,32,0,0,0,40,0,0,0,85,0,0,0,83,0,0,0,65,0,0,0,32,0,0,0,57,0,0,0,56,0,0,0,49,0,0,0,50,0,0,0,48,0,0,0,50,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,99,103,112,0,0,0,0,0,98,97,121,114,111,117,116,101,49,0,0,0,0,0,0,0,118,105,100,101,111,95,103,112,117,95,114,101,99,111,114,100,0,0,0,0,0,0,0,0,83,76,79,84,45,62,75,83,82,0,0,0,0,0,0,0,255,254,0,0,166,48,0,0,235,48,0,0,200,48,0,0,233,48,0,0,222,48,0,0,243,48,0,0,32,0,0,0,32,0,0,0,122,122,0,0,243,96,0,0,121,114,0,0,174,100,0,0,183,48,0,0,234,48,0,0,252,48,0,0,186,48,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,85,0,0,0,108,0,0,0,116,0,0,0,114,0,0,0,97,0,0,0,109,0,0,0,97,0,0,0,110,0,0,0,0,0,0,0,0,0,0,0,97,117,116,104,111,114,115,0,110,111,98,0,0,0,0,0,65,0,0,0,77,0,0,0,0,0,0,0,0,0,0,0,67,97,108,105,112,115,111,0,0,0,0,0,0,0,0,0,84,104,117,110,100,101,114,32,66,108,97,100,101,32,40,117,112,114,105,103,104,116,44,32,70,68,49,48,57,52,32,51,49,55,45,48,48,53,54,41,0,0,0,0,0,0,0,0,98,111,116,116,111,109,57,110,0,0,0,0,0,0,0,0,83,104,105,110,111,98,105,32,40,115,101,116,32,49,44,32,83,121,115,116,101,109,32,49,54,65,44,32,70,68,49,48,57,52,32,51,49,55,45,48,48,53,48,41,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,76,111,97,100,101,100,32,84,71,65,58,32,40,37,117,120,37,117,32,64,32,37,117,32,98,112,112,41,10,0,0,0,0,0,0,0,0,72,0,0,0,101,0,0,0,120,0,0,0,105,0,0,0,111,0,0,0,110,0,0,0,0,0,0,0,216,48,0,0,175,48,0,0,183,48,0,0,170,48,0,0,243,48,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,32,0,0,0,118,0,0,0,101,0,0,0,114,0,0,0,46,0,0,0,32,0,0,0,74,0,0,0,65,0,0,0,66,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,115,99,111,110,116,114,97,106,0,0,0,0,0,0,0,0,50,32,116,111,32,115,116,97,114,116,44,32,49,32,116,111,32,99,111,110,116,105,110,117,101,0,0,0,0,0,0,0,65,102,101,103,97,32,40,65,112,112,108,101,115,32,73,110,100,117,115,116,114,105,101,115,32,108,105,99,101,110,115,101,41,0,0,0,0,0,0,0,119,115,99,104,97,109,112,98,0,0,0,0,0,0,0,0,83,97,110,103,111,107,117,115,104,105,32,73,73,58,32,83,97,110,103,117,111,32,89,105,110,103,120,105,111,110,103,32,90,104,117,97,110,32,40,67,104,105,110,101,115,101,32,98,111,111,116,108,101,103,32,115,101,116,32,50,44,32,57,50,49,48,48,53,32,65,115,105,97,41,0,0,0,0,0,0,107,111,110,97,109,105,56,56,0,0,0,0,0,0,0,0,112,99,101,95,112,117,122,122,110,105,99,0,0,0,0,0,65,0,0,0,105,0,0,0,114,0,0,0,32,0,0,0,71,0,0,0,97,0,0,0,108,0,0,0,108,0,0,0,101,0,0,0,116,0,0,0,0,0,0,0,162,48,0,0,239,48,0,0,166,48,0,0,174,48,0,0,227,48,0,0,236,48,0,0,195,48,0,0,200,48,0,0,32,0,0,0,40,0,0,0,75,0,0,0,111,0,0,0,114,0,0,0,101,0,0,0,97,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,65,83,83,32,77,97,115,116,101,114,115,32,67,108,97,115,115,105,99,32,40,85,83,65,41,0,0,0,0,0,0,65,0,0,0,106,0,0,0,97,0,0,0,120,0,0,0,0,0,0,0,168,48,0,0,252,48,0,0,184,48,0,0,227,48,0,0,195,48,0,0,175,48,0,0,185,48,0,0,0,0,0,0,0,0,0,0,50,51,48,0,0,0,0,0,114,111,108,108,101,114,103,106,0,0,0,0,0,0,0,0,97,118,115,112,100,0,0,0,99,97,108,105,112,115,111,0,77,111,98,105,108,101,32,83,117,105,116,32,71,117,110,100,97,109,32,40,74,97,112,97,110,41,0,0,0,0,0,0,50,48,48,75,44,32,50,48,48,75,32,69,118,101,114,121,0,0,0,0,0,0,0,0,79,104,109,121,103,111,100,83,99,114,111,108,108,120,0,0,99,111,110,116,114,97,49,0,83,110,111,119,32,66,114,111,115,46,32,45,32,78,105,99,107,32,38,32,84,111,109,32,40,115,101,116,32,51,41,0,0,0,0,0,0,0,0,0,75,48,53,51,50,53,49,80,97,108,73,110,100,101,120,91,52,93,0,0,0,0,0,0,77,117,72,97,110,83,101,117,110,103,66,117,32,40,83,101,109,105,67,111,109,32,66,97,115,101,98,97,108,108,41,32,40,75,111,114,101,97,41,0,0,0,0,0,0,0,0,0,45,110,101,103,0,0,0,0,80,50,32,98,117,116,116,111,110,32,53,0,0,0,0,0,120,109,101,110,97,0,0,0,115,117,114,97,116,107,97,0,49,53,48,48,48,48,47,51,48,48,48,48,48,0,0,0,49,32,116,111,32,115,116,97,114,116,44,32,49,32,116,111,32,99,111,110,116,105,110,117,101,0,0,0,0,0,0,0,71,97,117,110,116,108,101,116,32,73,73,32,40,50,32,80,108,97,121,101,114,115,44,32,114,101,118,32,49,41,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,112,97,114,115,101,32,88,77,76,32,102,105,108,101,58,32,37,115,10,0,0,0,0,0,0,49,67,95,52,67,0,0,0,119,111,102,104,97,0,0,0,100,107,111,110,103,51,106,0,115,112,114,105,116,101,51,98,97,110,107,0,0,0,0,0,109,97,106,117,117,0,0,0,80,117,122,122,108,101,32,66,111,121,0,0,0,0,0,0,90,101,100,32,66,108,97,100,101,32,47,32,79,112,101,114,97,116,105,111,110,32,82,97,103,110,97,114,111,107,0,0,109,100,95,98,97,115,115,109,99,0,0,0,0,0,0,0,113,117,97,114,116,104,0,0,111,117,116,114,117,110,0,0,51,48,107,32,32,55,48,107,43,0,0,0,0,0,0,0,50,32,67,114,101,100,105,116,115,32,47,32,50,32,80,108,97,121,101,114,115,0,0,0,65,114,109,111,114,101,100,32,87,97,114,114,105,111,114,115,32,40,57,52,49,48,49,49,32,69,117,114,111,112,101,32,80,104,111,101,110,105,120,32,69,100,105,116,105,111,110,41])
.concat([0,0,0,0,0,0,0,0,103,114,97,100,105,117,115,51,106,0,0,0,0,0,0,0,70,45,88,32,40,97,108,116,101,114,110,97,116,101,32,115,101,116,41,0,0,0,0,0,83,105,103,110,97,116,111,110,32,85,83,65,0,0,0,0,115,116,100,58,58,98,97,100,95,99,97,115,116,0,0,0,45,53,32,83,108,111,119,101,114,0,0,0,0,0,0,0,115,112,121,117,0,0,0,0,103,121,114,117,115,115,99,101,0,0,0,0,0,0,0,0,97,115,105,99,50,55,97,95,116,111,95,97,114,109,0,0,73,109,112,101,114,102,101,99,116,32,80,114,111,116,101,99,116,105,111,110,32,69,109,117,108,97,116,105,111,110,0,0,118,101,110,100,101,116,116,97,114,0,0,0,0,0,0,0,67,114,101,100,105,116,115,32,78,101,101,100,101,100,0,0,49,57,120,120,97,0,0,0,49,48,48,75,32,79,110,108,121,0,0,0,0,0,0,0,66,97,116,109,97,110,0,0,9,78,0,0,253,86,0,0,215,95,0,0,73,0,0,0,73,0,0,0,58,0,0,0,32,0,0,0,9,78,0,0,11,87,0,0,241,130,0,0,196,150,0,0,179,80,0,0,0,0,0,0,83,0,0,0,97,0,0,0,110,0,0,0,103,0,0,0,111,0,0,0,107,0,0,0,117,0,0,0,115,0,0,0,104,0,0,0,105,0,0,0,32,0,0,0,73,0,0,0,73,0,0,0,58,0,0,0,32,0,0,0,83,0,0,0,97,0,0,0,110,0,0,0,103,0,0,0,117,0,0,0,111,0,0,0,32,0,0,0,89,0,0,0,105,0,0,0,110,0,0,0,103,0,0,0,88,0,0,0,105,0,0,0,111,0,0,0,110,0,0,0,103,0,0,0,90,0,0,0,104,0,0,0,117,0,0,0,97,0,0,0,110,0,0,0,32,0,0,0,40,0,0,0,67,0,0,0,104,0,0,0,105,0,0,0,110,0,0,0,101,0,0,0,115,0,0,0,101,0,0,0,32,0,0,0,98,0,0,0,111,0,0,0,111,0,0,0,116,0,0,0,108,0,0,0,101,0,0,0,103,0,0,0,32,0,0,0,115,0,0,0,101,0,0,0,116,0,0,0,32,0,0,0,49,0,0,0,44,0,0,0,32,0,0,0,57,0,0,0,50,0,0,0,49,0,0,0,48,0,0,0,48,0,0,0,53,0,0,0,32,0,0,0,65,0,0,0,115,0,0,0,105,0,0,0,97,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,103,98,117,115,116,101,114,115,97,0,0,0,0,0,0,0,99,112,115,49,100,101,109,111,0,0,0,0,0,0,0,0,112,99,101,95,112,117,122,122,108,98,111,121,0,0,0,0,122,101,100,98,108,97,100,101,0,0,0,0,0,0,0,0,67,111,112,121,114,105,103,104,116,32,98,121,32,83,78,75,0,0,0,0,0,0,0,0,66,97,114,118,101,114,32,66,97,116,116,108,101,32,83,97,103,97,32,45,32,84,97,105,32,75,111,110,103,32,90,104,97,110,32,83,104,105,32,40,67,104,105,41,0,0,0,0,115,105,109,112,115,111,110,115,52,112,97,0,0,0,0,0,112,111,111,121,97,110,115,0,115,108,45,62,119,97,118,101,116,97,98,108,101,0,0,0,97,114,109,119,97,114,49,100,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,70,97,105,108,101,100,32,116,111,32,114,101,115,111,108,118,101,32,110,101,120,116,32,116,97,114,103,101,116,115,46,10,0,0,0,0,0,0,0,0,65,103,101,110,116,32,83,117,112,101,114,32,66,111,110,100,32,40,115,99,111,98,114,97,32,104,97,114,100,119,97,114,101,41,0,0,0,0,0,0,117,110,105,102,111,114,109,32,115,97,109,112,108,101,114,50,68,32,84,101,120,116,117,114,101,59,10,105,110,32,118,101,99,50,32,116,101,120,95,99,111,111,114,100,59,10,111,117,116,32,118,101,99,52,32,70,114,97,103,67,111,108,111,114,59,10,118,111,105,100,32,109,97,105,110,40,41,32,123,10,32,32,32,70,114,97,103,67,111,108,111,114,32,61,32,118,101,99,52,40,116,101,120,116,117,114,101,40,84,101,120,116,117,114,101,44,32,116,101,120,95,99,111,111,114,100,41,46,114,103,98,44,32,49,46,48,41,59,10,125,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,70,66,79,32,112,97,115,115,32,35,37,100,32,105,115,32,102,108,111,97,116,105,110,103,45,112,111,105,110,116,46,10,0,0,0,0,0,109,100,95,97,110,111,116,104,101,114,119,0,0,0,0,0,116,109,110,116,117,0,0,0,49,53,48,32,79,110,108,121,0,0,0,0,0,0,0,0,72,97,114,100,32,71,80,85,32,83,121,110,99,32,70,114,97,109,101,115,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,68,105,100,32,110,111,116,32,102,105,110,100,32,97,110,121,32,99,104,101,97,116,115,32,105,110,32,88,77,76,32,102,105,108,101,58,32,37,115,10,0,0,0,122,111,111,109,114,101,97,100,114,111,109,115,0,0,0,0,116,114,97,110,115,105,116,105,111,110,0,0,0,0,0,0,93,93,62,0,0,0,0,0,100,121,110,97,98,108,115,116,0,0,0,0,0,0,0,0,98,97,116,99,105,114,106,0,83,97,110,103,111,107,117,115,104,105,32,73,73,58,32,83,97,110,103,117,111,32,89,105,110,103,120,105,111,110,103,32,90,104,117,97,110,32,40,67,104,105,110,101,115,101,32,98,111,111,116,108,101,103,32,115,101,116,32,49,44,32,57,50,49,48,48,53,32,65,115,105,97,41,0,0,0,0,0,0,80,115,121,99,104,111,32,67,104,97,115,101,114,0,0,0,77,101,116,97,108,32,83,108,117,103,32,45,32,83,117,112,101,114,32,86,101,104,105,99,108,101,45,48,48,49,0,0,56,32,40,72,97,114,100,41,0,0,0,0,0,0,0,0,109,100,95,98,97,114,118,101,114,0,0,0,0,0,0,0,83,117,110,115,101,116,32,82,105,100,101,114,115,32,40,52,32,80,108,97,121,101,114,115,32,118,101,114,46,32,85,65,66,41,0,0,0,0,0,0,115,112,101,108,117,110,107,50,0,0,0,0,0,0,0,0,107,117,110,103,102,117,109,100,0,0,0,0,0,0,0,0,85,110,100,101,114,99,111,118,101,114,32,67,111,112,115,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,72,97,109,109,101,114,105,110,39,32,72,97,114,114,121,32,40,85,83,41,0,0,0,0,49,57,52,52,32,45,32,116,104,101,32,108,111,111,112,32,109,97,115,116,101,114,32,40,48,48,48,54,50,48,32,85,83,65,32,80,104,111,101,110,105,120,32,69,100,105,116,105,111,110,44,32,97,108,116,41,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,9,67,117,114,114,101,110,116,32,118,97,108,117,101,58,32,37,115,10,0,0,118,105,103,105,108,97,110,116,49,0,0,0,0,0,0,0,97,116,111,109,98,111,121,0,80,52,32,70,105,114,101,32,52,0,0,0,0,0,0,0,77,57,50,0,0,0,0,0,53,48,75,44,32,69,118,101,114,121,32,49,53,48,75,0,119,111,102,104,0,0,0,0,112,99,101,95,112,115,121,99,104,97,115,0,0,0,0,0,66,97,114,110,101,121,39,115,32,72,105,100,101,32,38,32,83,101,101,107,32,71,97,109,101,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,114,116,121,112,101,106,0,0,49,57,52,52,97,100,0,0,45,115,0,0,0,0,0,0,115,117,112,101,114,98,111,110,0,0,0,0,0,0,0,0,9,78,0,0,253,86,0,0,215,95,0,0,73,0,0,0,73,0,0,0,58,0,0,0,32,0,0,0,107,112,0,0,243,156,0,0,240,81,0,0,0,0,0,0,83,0,0,0,97,0,0,0,110,0,0,0,103,0,0,0,111,0,0,0,107,0,0,0,117,0,0,0,115,0,0,0,104,0,0,0,105,0,0,0,32,0,0,0,73,0,0,0,73,0,0,0,58,0,0,0,32,0,0,0,72,0,0,0,117,0,0,0,111,0,0,0,32,0,0,0,70,0,0,0,101,0,0,0,110,0,0,0,103,0,0,0,32,0,0,0,72,0,0,0,117,0,0,0,97,0,0,0,110,0,0,0,103,0,0,0,32,0,0,0,40,0,0,0,67,0,0,0,104,0,0,0,105,0,0,0,110,0,0,0,101,0,0,0,115,0,0,0,101,0,0,0,32,0,0,0,98,0,0,0,111,0,0,0,111,0,0,0,116,0,0,0,108,0,0,0,101,0,0,0,103,0,0,0,44,0,0,0,32,0,0,0,57,0,0,0,50,0,0,0,49,0,0,0,48,0,0,0,48,0,0,0,53,0,0,0,32,0,0,0,65,0,0,0,115,0,0,0,105,0,0,0,97,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,82,105,103,104,116,32,97,110,97,108,111,103,32,89,45,32,40,117,112,41,0,0,0,0,80,114,111,32,89,97,107,121,117,117,32,87,111,114,108,100,32,83,116,97,100,105,117,109,0,0,0,0,0,0,0,0,109,100,95,98,97,114,110,101,121,0,0,0,0,0,0,0,49,57,52,52,32,45,32,116,104,101,32,108,111,111,112,32,109,97,115,116,101,114,32,40,48,48,48,54,50,48,32,85,83,65,32,80,104,111,101,110,105,120,32,69,100,105,116,105,111,110,41,0,0,0,0,0,83,112,101,101,100,32,67,111,105,110,32,40,112,114,111,116,111,116,121,112,101,41,0,0,51,48,48,107,32,38,32,54,48,48,107,0,0,0,0,0,83,97,110,103,111,107,117,115,104,105,32,73,73,58,32,72,117,111,32,70,101,110,103,104,117,97,110,103,32,40,67,104,105,110,101,115,101,32,98,111,111,116,108,101,103,44,32,57,50,49,48,48,53,32,65,115,105,97,41,0,0,0,0,0,112,99,101,95,112,114,111,121,97,107,0,0,0,0,0,0,78,101,111,32,84,117,114,102,32,77,97,115,116,101,114,115,32,47,32,66,105,103,32,84,111,117,114,110,97,109,101,110,116,32,71,111,108,102,0,0,49,57,52,52,100,0,0,0,66,97,114,107,108,101,121,32,83,104,117,116,32,85,112,32,97,110,100,32,74,97,109,33,32,50,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,115,112,100,99,111,105,110,0,54,48,48,107,32,79,110,108,121,0,0,0,0,0,0,0,119,111,102,104,102,104,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,40,80,114,105,118,97,116,101,41,32,69,88,69,67,46,10,0,0,0,0,0,80,114,111,32,89,97,107,121,117,117,32,87,111,114,108,100,32,83,116,97,100,105,117,109,32,39,57,49,0,0,0,0,109,100,95,98,97,114,107,108,101,121,50,112,0,0,0,0,99,104,105,112,115,0,0,0,70,114,101,101,32,69,110,116,101,114,112,114,105,115,101,32,71,97,109,101,115,0,0,0,98,114,101,121,119,111,111,100,0,0,0,0,0,0,0,0,51,48,48,107,32,79,110,108,121,0,0,0,0,0,0,0,41,89,0,0,48,87,0,0,146,48,0,0,176,85,0,0,137,48,0,0,70,48,0,0,73,0,0,0,73,0,0,0,32,0,0,0,45,0,0,0,32,0,0,0,100,141,0,0,193,88,0,0,110,48,0,0,38,98,0,0,68,48,0,0,0,0,0,0,84,0,0,0,101,0,0,0,110,0,0,0,99,0,0,0,104,0,0,0,105,0,0,0,32,0,0,0,119,0,0,0,111,0,0,0,32,0,0,0,75,0,0,0,117,0,0,0,114,0,0,0,97,0,0,0,117,0,0,0,32,0,0,0,73,0,0,0,73,0,0,0,32,0,0,0,45,0,0,0,32,0,0,0,83,0,0,0,101,0,0,0,107,0,0,0,105,0,0,0,104,0,0,0,101,0,0,0,107,0,0,0,105,0,0,0,32,0,0,0,110,0,0,0,111,0,0,0,32,0,0,0,84,0,0,0,97,0,0,0,116,0,0,0,97,0,0,0,107,0,0,0,97,0,0,0,105,0,0,0,32,0,0,0,40,0,0,0,67,0,0,0,80,0,0,0,83,0,0,0,32,0,0,0,67,0,0,0,104,0,0,0,97,0,0,0,110,0,0,0,103,0,0,0,101,0,0,0,114,0,0,0,44,0,0,0,32,0,0,0,57,0,0,0,50,0,0,0,49,0,0,0,48,0,0,0,51,0,0,0,49,0,0,0,32,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,99,101,95,112,114,111,121,97,107,57,49,0,0,0,0,208,48,0,0,171,48,0,0,191,107,0,0,216,105,0,0,32,0,0,0,187,158,0,0,192,150,0,0,43,111,0,0,74,144,0,0,24,138,0,0,0,0,0,0,66,0,0,0,97,0,0,0,107,0,0,0,97,0,0,0,116,0,0,0,111,0,0,0,110,0,0,0,111,0,0,0,115,0,0,0,97,0,0,0,109,0,0,0,97,0,0,0,32,0,0,0,77,0,0,0,97,0,0,0,104,0,0,0,106,0,0,0,111,0,0,0,110,0,0,0,103,0,0,0,32,0,0,0,77,0,0,0,97,0,0,0,110,0,0,0,121,0,0,0,117,0,0,0,107,0,0,0,105,0,0,0,32,0,0,0,40,0,0,0,77,0,0,0,79,0,0,0,77,0,0,0,45,0,0,0,48,0,0,0,48,0,0,0,50,0,0,0,41,0,0,0,40,0,0,0,77,0,0,0,79,0,0,0,72,0,0,0,45,0,0,0,48,0,0,0,48,0,0,0,50,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,66,97,114,107,108,101,121,32,83,104,117,116,32,85,112,32,97,110,100,32,74,97,109,33,32,50,32,40,85,83,65,41,0,0,0,0,0,0,0,0,80,49,32,65,117,116,111,0,49,57,88,88,32,45,32,116,104,101,32,119,97,114,32,97,103,97,105,110,115,116,32,100,101,115,116,105,110,121,32,40,57,53,49,50,48,55,32,85,83,65,32,80,104,111,101,110,105,120,32,69,100,105,116,105,111,110,41,0,0,0,0,0,82,101,103,105,111,110,0,0,84,104,101,32,65,110,116,101,97,116,101,114,32,40,85,75,41,0,0,0,0,0,0,0,72,111,110,103,32,75,111,110,103,32,40,67,104,97,114,116,101,114,102,105,101,108,100,41,0,0,0,0,0,0,0,0,75,111,114,101,97,32,40,85,110,105,116,101,32,84,114,97,100,105,110,103,32,108,105,99,101,110,115,101,41,0,0,0,75,111,114,101,97,32,40,85,110,105,116,101,32,108,105,99,101,110,115,101,41,0,0,0,100,101,109,111,110,119,108,100,95,104,97,99,107,0,0,0,115,108,121,115,112,121,0,0,104,116,104,101,114,111,0,0,84,104,101,32,78,101,119,90,101,97,108,97,110,100,32,83,116,111,114,121,32,40,74,97,112,97,110,44,32,111,108,100,32,118,101,114,115,105,111,110,41,32,40,111,108,100,101,114,32,80,67,66,41,0,0,0,49,57,57,63,0,0,0,0,83,117,112,101,114,32,67,104,97,99,107,39,110,0,0,0,65,115,104,117,114,97,32,66,108,97,115,116,101,114,32,40,85,83,41,0,0,0,0,0,78,105,103,104,116,32,83,116,114,105,107,101,114,32,40,87,111,114,108,100,41,0,0,0,84,101,110,99,104,105,32,119,111,32,75,117,114,97,117,32,73,73,32,45,32,83,101,107,105,104,101,107,105,32,110,111,32,84,97,116,97,107,97,105,32,40,67,80,83,32,67,104,97,110,103,101,114,44,32,57,50,49,48,51,49,32,74,97,112,97,110,41,0,0,0,0,84,111,112,32,83,112,101,101,100,32,40,87,111,114,108,100,41,0,0,0,0,0,0,0,80,114,111,32,84,101,110,110,105,115,32,87,111,114,108,100,32,67,111,117,114,116,0,0,66,97,107,97,116,111,110,111,115,97,109,97,32,77,97,104,106,111,110,103,32,77,97,110,121,117,117,107,105,32,40,77,79,77,45,48,48,50,41,40,77,79,72,45,48,48,50,41,0,0,0,0,0,0,0,0,53,48,107,32,97,110,100,32,101,118,101,114,121,32,49,53,48,107,0,0,0,0,0,0,87,104,101,110,32,121,111,117,32,103,101,116,32,97,32,99,114,121,115,116,97,108,0,0,109,100,95,98,97,114,107,108,101,121,50,0,0,0,0,0,74,111,74,111,39,115,32,86,101,110,116,117,114,101,32,47,32,74,111,74,111,32,110,111,32,75,105,109,121,111,117,32,110,97,32,66,111,117,107,101,110,32,40,85,83,65,32,57,56,49,50,48,50,41,0,0,66,97,121,32,82,111,117,116,101,32,40,115,101,116,32,50,44,32,74,97,112,97,110,44,32,70,68,49,48,57,52,32,51,49,55,45,48,49,49,53,41,0,0,0,0,0,0,0,118,105,100,101,111,95,112,111,115,116,95,102,105,108,116,101,114,95,114,101,99,111,114,100,0,0,0,0,0,0,0,0,49,57,120,120,100,0,0,0,77,121,32,72,101,114,111,32,40,75,111,114,101,97,41,0,0,0,0,0,0,0,0,0,83,104,97,100,111,119,32,68,97,110,99,101,114,32,40,115,101,116,32,50,44,32,74,97,112,97,110,41,0,0,0,0,97,110,116,101,97,116,101,114,117,107,0,0,0,0,0,0,116,104,110,100,114,98,108,100,0,0,0,0,0,0,0,0,115,104,105,110,111,98,105,49,0,0,0,0,0,0,0,0,97,99,101,97,116,116,97,99,0,0,0,0,0,0,0,0,67,114,101,100,105,116,32,76,105,109,105,116,0,0,0,0,71,117,97,114,100,105,97,110,32,83,116,111,114,109,32,40,104,111,114,105,122,111,110,116,97,108,44,32,110,111,116,32,101,110,99,114,121,112,116,101,100,41,0,0,0,0,0,0,87,105,110,103,32,83,104,111,111,116,105,110,103,32,67,104,97,109,112,105,111,110,115,104,105,112,32,86,49,46,48,49,0,0,0,0,0,0,0,0,57,48,75,32,79,110,108,121,0,0,0,0,0,0,0,0,119,111,102,99,104,0,0,0,112,99,101,95,112,116,101,110,110,119,99,0,0,0,0,0,65,105,114,32,71,97,108,108,101,116,32,40,75,111,114,101,97,41,0,0,0,0,0,0,98,97,107,97,116,111,110,111,0,0,0,0,0,0,0,0,76,97,117,110,99,104,32,66,97,108,108,32,47,32,84,105,108,116,0,0,0,0,0,0,66,97,114,107,108,101,121,32,83,104,117,116,32,85,112,32,97,110,100,32,74,97,109,33,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,76,97,110,103,117,97,103,101,32,40,116,101,120,116,41,0,88,45,77,101,110,32,118,115,32,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,40,57,54,49,48,48,52,32,85,83,65,41,0,0,0,0,84,86,45,84,117,110,105,110,103,32,40,70,46,69,46,71,46,32,108,105,99,101,110,115,101,41,0,0,0,0,0,0,109,115,103,117,110,100,97,109,49,0,0,0,0,0,0,0,49,50,48,75,44,32,50,48,48,75,32,69,118,101,114,121,0,0,0,0,0,0,0,0,66,117,116,116,111,110,32,51,0,0,0,0,0,0,0,0,79,104,109,121,103,111,100,83,112,114,105,116,101,66,97,110,107,0,0,0,0,0,0,0,115,110,111,119,98,114,111,115,98,0,0,0,0,0,0,0,115,101,109,105,98,97,115,101,0,0,0,0,0,0,0,0,77,111,110,115,116,101,114,115,32,87,111,114,108,100,0,0,49,48,48,48,48,48,47,50,48,48,48,48,48,0,0,0,112,97,99,109,97,110,115,112,0,0,0,0,0,0,0,0,103,97,117,110,116,50,50,112,49,0,0,0,0,0,0,0,54,48,107,32,38,32,57,48,107,0,0,0,0,0,0,0,9,78,0,0,253,86,0,0,215,95,0,0,73,0,0,0,73,0,0,0,0,0,0,0,83,0,0,0,97,0,0,0,110,0,0,0,103,0,0,0,111,0,0,0,107,0,0,0,117,0,0,0,115,0,0,0,104,0,0,0,105,0,0,0,32,0,0,0,73,0,0,0,73,0,0,0,32,0,0,0,40,0,0,0,57,0,0,0,50,0,0,0,49,0,0,0,48,0,0,0,48,0,0,0,53,0,0,0,32,0,0,0,65,0,0,0,115,0,0,0,105,0,0,0,97,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,111,110,107,101,121,32,75,111,110,103,32,51,32,40,85,83,41,0,0,0,0,0,0,110,71,117,110,115,109,111,107,101,66,97,110,107,0,0,0,127,48,0,0,106,48,0,0,85,48,0,0,147,48,0,0,110,48,0,0,74,48,0,0,75,48,0,0,82,48,0,0,85,48,0,0,126,48,0,0,103,48,0,0,89,48,0,0,1,255,0,0,0,0,0,0,77,0,0,0,105,0,0,0,110,0,0,0,110,0,0,0,97,0,0,0,115,0,0,0,97,0,0,0,110,0,0,0,110,0,0,0,111,0,0,0,32,0,0,0,79,0,0,0,107,0,0,0,97,0,0,0,103,0,0,0,101,0,0,0,115,0,0,0,97,0,0,0,109,0,0,0,97,0,0,0,100,0,0,0,101,0,0,0,115,0,0,0,117,0,0,0,32,0,0,0,40,0,0,0,77,0,0,0,79,0,0,0,77,0,0,0,45,0,0,0,48,0,0,0,48,0,0,0,49,0,0,0,41,0,0,0,40,0,0,0,77,0,0,0,79,0,0,0,72,0,0,0,45,0,0,0,48,0,0,0,48,0,0,0,49,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,109,100,95,98,97,114,107,108,101,121,0,0,0,0,0,0,50,48,107,32,32,55,48,107,43,0,0,0,0,0,0,0,49,32,67,114,101,100,105,116,32,47,32,50,32,80,108,97,121,101,114,115,0,0,0,0,120,109,118,115,102,117,114,49,0,0,0,0,0,0,0,0,102,120,97,0,0,0,0,0,65,109,101,105,115,101,110,98,97,101,114,32,40,71,101,114,109,97,110,41,0,0,0,0,50,32,80,108,97,121,101,114,115,32,71,97,109,101,32,84,105,109,101,0,0,0,0,0,45,54,32,83,108,111,119,101,114,0,0,0,0,0,0,0,66,97,99,107,117,112,32,82,97,109,32,49,0,0,0,0,51,48,107,32,49,50,48,107,32,49,50,48,107,0,0,0,65,82,77,32,82,65,77,32,50,0,0,0,0,0,0,0,79,114,105,101,110,116,97,108,32,76,101,103,101,110,100,32,83,117,112,101,114,32,40,86,49,48,49,44,32,75,111,114,101,97,41,0,0,0,0,0,54,48,75,32,79,110,108,121,0,0,0,0,0,0,0,0,112,99,101,95,98,97,116,109,97,110,0,0,0,0,0,0,83,97,110,103,111,107,117,115,104,105,32,73,73,32,40,57,50,49,48,48,53,32,65,115,105,97,41,0,0,0,0,0,67,97,114,114,105,101,114,32,65,105,114,32,87,105,110,103,32,40,98,111,111,116,108,101,103,32,115,101,116,32,50,32,40,119,105,116,104,32,50,120,89,77,50,50,48,51,32,43,32,50,120,77,83,77,53,50,48,53,41,44,32,85,46,83,46,32,110,97,118,121,32,57,48,49,48,49,50,32,101,116,99,41,0,0,0,0,0,0,77,111,110,111,108,105,116,104,32,67,111,114,112,46,0,0,83,0,0,0,101,0,0,0,110,0,0,0,103,0,0,0,111,0,0,0,107,0,0,0,117,0,0,0,32,0,0,0,47,0,0,0,32,0,0,0,83,0,0,0,101,0,0,0,110,0,0,0,103,0,0,0,111,0,0,0,107,0,0,0,117,0,0,0,32,0,0,0,68,0,0,0,101,0,0,0,110,0,0,0,115,0,0,0,104,0,0,0,111,0,0,0,117,0,0,0,32,0,0,0,40,0,0,0,78,0,0,0,71,0,0,0,72,0,0,0,45,0,0,0,48,0,0,0,49,0,0,0,55,0,0,0,41,0,0,0,40,0,0,0,85,0,0,0,83,0,0,0,41,0,0,0,0,0,0,0,38,98,0,0,253,86,0,0,29,79,0,0,127,98,0,0,0,0,0,0,0,0,0,0,110,76,69,68,91,51,93,0,66,97,114,98,105,101,32,86,97,99,97,116,105,111,110,32,65,100,118,101,110,116,117,114,101,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,115,108,45,62,118,105,98,0,88,45,77,101,110,32,118,115,32,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,40,57,54,49,48,50,51,32,85,83,65,41,0,0,0,0,97,110,116,101,97,116,101,114,103,0,0,0,0,0,0,0,115,102,105,105,105,0,0,0,35,105,102,100,101,102,32,71,76,95,69,83,10,112,114,101,99,105,115,105,111,110,32,109,101,100,105,117,109,112,32,102,108,111,97,116,59,10,35,101,110,100,105,102,10,117,110,105,102,111,114,109,32,115,97,109,112,108,101,114,50,68,32,84,101,120,116,117,114,101,59,10,118,97,114,121,105,110,103,32,118,101,99,50,32,116,101,120,95,99,111,111,114,100,59,10,118,111,105,100,32,109,97,105,110,40,41,32,123,10,32,32,32,103,108,95,70,114,97,103,67,111,108,111,114,32,61,32,118,101,99,52,40,116,101,120,116,117,114,101,50,68,40,84,101,120,116,117,114,101,44,32,116,101,120,95,99,111,111,114,100,41,46,114,103,98,44,32,49,46,48,41,59,10,125,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,79,69,83,95,116,101,120,116,117,114,101,95,102,108,111,97,116,95,108,105,110,101,97,114,32,101,120,116,101,110,115,105,111,110,32,110,111,116,32,102,111,117,110,100,46,10,0,0,0,0,0,84,101,99,77,97,103,105,107,0,0,0,0,0,0,0,0,49,53,48,32,97,110,100,32,101,118,101,114,121,32,50,53,48,0,0,0,0,0,0,0,72,97,114,100,32,71,80,85,32,83,121,110,99,0,0,0,98,111,116,116,111,109,57,95,118,105,100,101,111,95,101,110,97,98,108,101,0,0,0,0,74,111,114,100,97,110,0,0,99,97,112,116,117,114,101,0,66,97,116,116,108,101,32,67,105,114,99,117,105,116,32,40,57,55,48,51,49,57,32,65,115,105,97,41,0,0,0,0,119,111,102,97,0,0,0,0,80,111,119,101,114,32,83,112,111,114,116,115,0,0,0,0,77,105,110,97,115,97,110,110,111,32,79,107,97,103,101,115,97,109,97,100,101,115,117,33,32,68,97,105,115,117,103,111,114,111,107,117,116,97,105,107,97,105,32,40,77,79,77,45,48,48,49,41,40,77,79,72,45,48,48,49,41,0,0,0,109,100,95,98,97,114,98,118,97,99,0,0,0,0,0,0,115,115,114,105,100,101,114,115,117,97,98,0,0,0,0,0,83,112,101,108,117,110,107,101,114,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,117,99,99,111,112,115,106,0,104,104,97,114,114,121,117,0,120,109,118,115,102,117,0,0,83,116,101,114,110,32,40,84,97,103,111,32,108,105,99,101,110,115,101,41,0,0,0,0,110,67,97,118,101,88,79,102,102,115,101,116,0,0,0,0,98,97,110,107,112,0,0,0,102,100,49,48,57,52,95,115,101,108,101,99,116,101,100,95,115,116,97,116,101,0,0,0,41,89,0,0,48,87,0,0,146,48,0,0,176,85,0,0,137,48,0,0,70,48,0,0,73,0,0,0,73,0,0,0,32,0,0,0,45,0,0,0,32,0,0,0,100,141,0,0,193,88,0,0,110,48,0,0,38,98,0,0,68,48,0,0,0,0,0,0,84,0,0,0,101,0,0,0,110,0,0,0,99,0,0,0,104,0,0,0,105,0,0,0,32,0,0,0,119,0,0,0,111,0,0,0,32,0,0,0,75,0,0,0,117,0,0,0,114,0,0,0,97,0,0,0,117,0,0,0,32,0,0,0,73,0,0,0,73,0,0,0,32,0,0,0,45,0,0,0,32,0,0,0,83,0,0,0,101,0,0,0,107,0,0,0,105,0,0,0,104,0,0,0,101,0,0,0,107,0,0,0,105,0,0,0,32,0,0,0,110,0,0,0,111,0,0,0,32,0,0,0,84,0,0,0,97,0,0,0,116,0,0,0,97,0,0,0,107,0,0,0,97,0,0,0,105,0,0,0,32,0,0,0,40,0,0,0,57,0,0,0,50,0,0,0,49,0,0,0,48,0,0,0,51,0,0,0,49,0,0,0,32,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,112,99,101,95,112,115,112,111,114,116,115,0,0,0,0,0,109,105,110,97,115,97,110,0,72,105,32,84,101,99,104,32,69,120,112,114,101,115,115,105,111,110,115,0,0,0,0,0,88,45,77,101,110,32,118,115,32,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,40,57,54,48,57,48,57,32,74,97,112,97,110,41,0,0,45,45,109,101,110,117,0,0,65,110,116,101,97,116,101,114,0,0,0,0,0,0,0,0,84,101,110,99,104,105,32,119,111,32,75,117,114,97,117,32,73,73,32,45,32,83,101,107,105,104,101,107,105,32,110,111,32,84,97,116,97,107,97,105,32,40,57,50,49,48,51,49,32,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,80,111,119,101,114,32,76,101,97,103,117,101,32,86,0,0,78,101,111,32,66,111,109,98,101,114,109,97,110,0,0,0,66,97,114,98,105,101,32,83,117,112,101,114,32,77,111,100,101,108,32,40,85,83,65,41,0,0,0,0,0,0,0,0,120,109,118,115,102,106,114,50,0,0,0,0,0,0,0,0,97,110,116,101,97,116,101,114,0,0,0,0,0,0,0,0,99,97,110,110,111,110,98,95,98,105,116,95,116,111,95,114,101,97,100,0,0,0,0,0,119,111,102,106,0,0,0,0,112,99,101,95,112,108,101,97,103,53,0,0,0,0,0,0,110,101,111,98,111,109,98,101,0,0,0,0,0,0,0,0,109,100,95,98,97,114,98,105,101,115,109,0,0,0,0,0,71,97,108,73,114,113,70,105,114,101,0,0,0,0,0,0,88,45,77,101,110,32,118,115,32,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,40,57,54,48,57,49,48,32,74,97,112,97,110,41,0,0,84,97,122,122,45,77,97,110,105,97,32,40,115,101,116,32,50,41,0,0,0,0,0,0,109,115,99,104,97,109,112,95,99,111,117,110,116,101,114,0,87,97,114,114,105,111,114,115,32,111,102,32,70,97,116,101,32,40,57,50,49,48,51,49,32,85,83,65,41,0,0,0,80,111,119,101,114,32,76,101,97,103,117,101,32,73,86,0,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,40,80,114,105,118,97,116,101,41,32,69,88,69,67,95,69,83,67,65,80,69,46,10,0,0,0,0,0,0,75,0,0,0,97,0,0,0,98,0,0,0,117,0,0,0,107,0,0,0,105,0,0,0,32,0,0,0,75,0,0,0,108,0,0,0,97,0,0,0,115,0,0,0,104,0,0,0,32,0,0,0,45,0,0,0,32,0,0,0,102,0,0,0,97,0,0,0,114,0,0,0,32,0,0,0,101,0,0,0,97,0,0,0,115,0,0,0,116,0,0,0,32,0,0,0,111,0,0,0,102,0,0,0,32,0,0,0,101,0,0,0,100,0,0,0,101,0,0,0,110,0,0,0,0,0,0,0,41,89,0,0,22,89,0,0,84,155,0,0,131,88,0,0,32,0,0,0,45,0,0,0,32,0,0,0,31,119,0,0,29,79,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,97,108,108,122,32,51,68,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,120,109,118,115,102,106,114,49,0,0,0,0,0,0,0,0,116,97,122,109,97,110,105,50,0,0,0,0,0,0,0,0,83,104,97,99,107,108,101,100,32,40,85,83,41,0,0,0,71,97,108,83,104,111,111,116,87,97,118,101,80,111,115,0,101,112,111,115,95,104,97,114,100,119,97,114,101,95,99,111,117,110,116,101,114,0,0,0,119,111,102,117,0,0,0,0,112,99,101,95,112,108,101,97,103,52,0,0,0,0,0,0,109,100,95,98,97,108,108,122,51,100,0,0,0,0,0,0,80,49,32,66,117,116,116,111,110,32,52,0,0,0,0,0,88,45,77,101,110,32,118,115,32,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,40,57,54,49,48,48,52,32,74,97,112,97,110,41,0,0,110,67,121,99,108,101,115,68,111,110,101,0,0,0,0,0,84,97,122,122,45,77,97,110,105,97,32,40,115,101,116,32,49,41,0,0,0,0,0,0,52,100,119,97,114,114,105,111,0,0,0,0,0,0,0,0,72,111,110,103,32,75,111,110,103,32,40,72,111,110,101,115,116,32,84,114,97,100,105,110,103,32,67,111,46,41,0,0,85,83,65,32,40,84,97,105,116,111,32,67,111,114,112,111,114,97,116,105,111,110,32,74,97,112,97,110,41,0,0,0,82,111,98,111,99,111,112,32,40,87,111,114,108,100,32,98,111,111,116,108,101,103,41,0,0,0,0,0,0,0,0,0,70,111,111,116,98,97,108,108,32,67,104,97,109,112,32,40,87,111,114,108,100,41,0,0,116,110,122,115,106,111,0,0,104,101,120,97,0,0,0,0,97,115,104,117,114,97,117,0,97,108,105,98,97,98,97,95,109,121,115,116,101,114,121,0,110,105,103,104,116,115,116,114,0,0,0,0,0,0,0,0,87,97,114,114,105,111,114,115,32,111,102,32,70,97,116,101,32,40,57,50,49,48,48,50,32,101,116,99,41,0,0,0,116,111,112,115,112,101,101,100,0,0,0,0,0,0,0,0,80,111,119,101,114,32,76,101,97,103,117,101,32,73,73,73,0,0,0,0,0,0,0,0,70,97,114,32,69,97,115,116,32,111,102,32,69,100,101,110,32,45,32,75,97,98,117,107,105,32,75,108,97,115,104,32,47,32,84,101,110,103,97,105,32,77,97,107,121,111,117,32,45,32,83,104,105,110,32,68,101,110,0,0,0,0,0,0,77,97,103,105,99,105,97,110,32,97,112,112,101,97,114,115,0,0,0,0,0,0,0,0,66,97,108,108,32,74,97,99,107,115,32,40,69,117,114,111,44,32,74,112,110,41,0,0,106,111,106,111,114,50,0,0,98,97,121,114,111,117,116,101,106,0,0,0,0,0,0,0,98,97,99,107,115,112,97,99,101,0,0,0,0,0,0,0,118,105,100,101,111,95,109,101,115,115,97,103,101,95,99,111,108,111,114,0,0,0,0,0,120,109,118,115,102,106,0,0,109,121,104,101,114,111,107,0,115,104,100,97,110,99,101,114,106,0,0,0,0,0,0,0,65,114,109,111,114,101,100,32,67,97,114,32,40,115,101,116,32,50,41,0,0,0,0,0,83,117,112,101,114,32,77,111,110,97,99,111,32,71,80,32,40,74,97,112,97,110,44,32,82,101,118,32,65,44,32,70,68,49,48,57,52,32,51,49,55,45,48,49,50,52,97,41,0,0,0,0,0,0,0,0,83,104,105,110,111,98,105,32,40,115,101,116,32,54,44,32,83,121,115,116,101,109,32,49,54,65,44,32,117,110,112,114,111,116,101,99,116,101,100,41,0,0,0,0,0,0,0,0,70,99,114,97,115,104,83,97,109,112,108,101,66,117,102,102,101,114,50,0,0,0,0,0,80,51,32,70,105,114,101,32,52,0,0,0,0,0,0,0,43,51,0,0,0,0,0,0,103,114,100,110,115,116,114,109,0,0,0,0,0,0,0,0,119,115,99,104,97,109,112,97,0,0,0,0,0,0,0,0,99,104,97,114,98,97,110,107,0,0,0,0,0,0,0,0,119,111,102,114,49,0,0,0,112,99,101,95,112,108,101,97,103,51,0,0,0,0,0,0,97,103,97,108,108,101,116,107,0,0,0,0,0,0,0,0,109,100,95,98,97,108,108,106,97,99,107,0,0,0,0,0,88,45,77,101,110,32,118,115,32,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,40,57,54,49,48,48,52,32,72,105,115,112,97,110,105,99,41,0,0,0,0,0,0,0,97,114,109,111,114,99,97,114,50,0,0,0,0,0,0,0,119,97,116,99,104,95,116,105,99,107,0,0,0,0,0,0,83,110,111,119,32,66,114,111,115,46,32,45,32,78,105,99,107,32,38,32,84,111,109,32,40,115,101,116,32,50,41,0,0,0,0,0,0,0,0,0,66,46,67,46,32,83,116,111,114,121,32,40,115,101,116,32,50,41,0,0,0,0,0,0,80,50,32,98,117,116,116,111,110,32,52,0,0,0,0,0,66,111,110,117,115,32,49,115,116,47,50,110,100,0,0,0,67,97,116,101,114,112,105,108,108,97,114,32,80,97,99,109,97,110,32,72,97,99,107,0,0,0,0,0,0,0,0,0,67,111,105,110,32,76,111,99,107,111,117,116,32,80,114,101,115,101,110,116,63,0,0,0,71,97,117,110,116,108,101,116,32,73,73,32,40,50,32,80,108,97,121,101,114,115,44,32,114,101,118,32,50,41,0,0,115,112,114,105,116,101,98,97,110,107,0,0,0,0,0,0,87,97,114,114,105,111,114,115,32,111,102,32,70,97,116,101,32,40,57,50,49,48,51,49,32,101,116,99,41,0,0,0,100,107,111,110,103,51,0,0,80,111,119,101,114,32,76,101,97,103,117,101,32,73,73,0,0,0,0,0,0,0,0,0,80,0,0,0,97,0,0,0,110,0,0,0,105,0,0,0,99,0,0,0,32,0,0,0,66,0,0,0,111,0,0,0,109,0,0,0,98,0,0,0,101,0,0,0,114,0,0,0,0,0,0,0,113,48,0,0,107,48,0,0,99,48,0,0,79,48,0,0,220,48,0,0,243,48,0,0,208,48,0,0,252,48,0,0,32,0,0,0,220,48,0,0,243,48,0,0,208,48,0,0,252,48,0,0,222,48,0,0,243,48,0,0,0,0,0,0,0,0,0,0,66,97,104,97,109,117,116,32,83,101,110,107,105,32,40,74,112,110,41,0,0,0,0,0,68,105,112,115,0,0,0,0,71,97,109,105,110,103,32,79,112,116,105,111,110,32,78,117,109,98,101,114,0,0,0,0,50,48,107,32,32,54,48,107,43,0,0,0,0,0,0,0,120,109,118,115,102,104,0,0,70,45,88,0,0,0,0,0,65,114,109,111,114,101,100,32,67,97,114,32,40,115,101,116,32,49,41,0,0,0,0,0,97,115,116,111,114,109,0,0,50,58,51,48,0,0,0,0,51,48,107,32,55,48,107,32,52,48,107,43,0,0,0,0,51,48,107,32,49,48,48,107,32,49,48,48,107,0,0,0,65,82,77,32,82,65,77,32,49,0,0,0,0,0,0,0,110,67,112,115,49,76,97,121,101,114,79,102,102,115,0,0,100,111,116,114,105,107,117,110,0,0,0,0,0,0,0,0,78,97,109,99,111,116,0,0,112,97,108,101,116,116,101,98,97,110,107,0,0,0,0,0,119,111,102,0,0,0,0,0,99,97,119,105,110,103,98,50,0,0,0,0,0,0,0,0,112,99,101,95,112,108,101,97,103,50,0,0,0,0,0,0,69,105,103,104,116,105,110,103,32,47,32,72,117,100,115,111,110,0,0,0,0,0,0,0,83,101,110,103,111,107,117,32,47,32,83,101,110,103,111,107,117,32,68,101,110,115,104,111,117,32,40,78,71,72,45,48,49,55,41,40,85,83,41,0,0,0,0,0,0,0,0,0,110,76,69,68,76,97,116,99,104,0,0,0,0,0,0,0,109,100,95,98,97,104,97,109,117,116,115,0,0,0,0,0,115,108,45,62,65,77,109,97,115,107,0,0,0,0,0,0,88,45,77,101,110,32,118,115,32,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,40,57,54,49,48,50,51,32,66,114,97,122,105,108,41,0,0,0,0,0,0,0,0,0,97,114,109,111,114,99,97,114,0,0,0,0,0,0,0,0,79,69,83,95,116,101,120,116,117,114,101,95,102,108,111,97,116,95,108,105,110,101,97,114,0,0,0,0,0,0,0,0,65,110,100,114,101,32,65,103,97,115,115,105,32,84,101,110,110,105,115,32,40,69,117,114,111,41,0,0,0,0,0,0,49,53,48,32,97,110,100,32,101,118,101,114,121,32,50,48,48,0,0,0,0,0,0,0,86,83,121,110,99,0,0,0,37,115,95,101,113,117,97,108,0,0,0,0,0,0,0,0,99,111,108,111,114,116,97,98,108,101,98,97,110,107,0,0,98,97,116,99,105,114,97,0,87,105,108,108,111,119,32,40,74,97,112,97,110,44,32,74,97,112,97,110,101,115,101,41,0,0,0,0,0,0,0,0,80,111,119,101,114,32,76,101,97,103,117,101,0,0,0,0,80,97,110,105,99,32,66,111,109,98,101,114,0,0,0,0,120,109,118,115,102,98,0,0,66,97,99,107,32,116,111,32,116,104,101,32,70,117,116,117,114,101,32,80,97,114,116,32,73,73,73,32,40,85,83,65,41,0,0,0,0,0,0,0,83,117,110,115,101,116,32,82,105,100,101,114,115,32,40,52,32,80,108,97,121,101,114,115,32,118,101,114,46,32,69,65,65,41,0,0,0,0,0,0,115,112,101,108,117,110,107,114,106,0,0,0,0,0,0,0,85,110,100,101,114,99,111,118,101,114,32,67,111,112,115,32,40,65,108,112,104,97,32,82,101,110,101,119,97,108,32,86,101,114,115,105,111,110,41,0,0,0,0,0,0,0,0,0,72,97,109,109,101,114,105,110,39,32,72,97,114,114,121,32,40,87,111,114,108,100,41,0,0,0,0,0,0,0,0,0,76,111,115,116,32,84,111,109,98,32,40,72,97,114,100,41,0,0,0,0,0,0,0,0,103,102,111,114,99,101,50,0,105,110,116,101,114,114,117,112,116,95,109,97,115,107,0,0,119,105,108,108,111,119,106,0,104,111,116,100,111,103,115,116,0,0,0,0,0,0,0,0,112,99,101,95,112,108,101,97,103,117,101,0,0,0,0,0,112,97,110,105,99,98,111,109,0,0,0,0,0,0,0,0,109,100,95,98,97,99,107,116,111,102,51,117,0,0,0,0,88,45,77,101,110,32,118,115,32,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,40,57,54,48,57,49,48,32,65,115,105,97,41,0,0,0,82,101,116,114,111,65,114,99,104,58,32,78,111,32,82,79,77,44,32,115,116,97,114,116,105,110,103,32,100,117,109,109,121,32,99,111,114,101,46,10,0,0,0,0,0,0,0,0,108,111,115,116,116,111,109,98,104,0,0,0,0,0,0,0,105,110,116,101,114,114,117,112,116,95,109,111,100,101,0,0,87,105,108,108,111,119,32,40,85,83,32,111,108,100,32,118,101,114,46,41,0,0,0,0,82,105,103,104,116,32,97,110,97,108,111,103,32,89,43,32,40,100,111,119,110,41,0,0,80,111,119,101,114,32,76,101,97,103,117,101,32,40,65,108,108,32,83,116,97,114,32,86,101,114,115,105,111,110,41,0,0,0,0,0,0,0,0,0,77,0,0,0,111,0,0,0,110,0,0,0,101,0,0,0,121,0,0,0,32,0,0,0,80,0,0,0,117,0,0,0,122,0,0,0,122,0,0,0,108,0,0,0,101,0,0,0,32,0,0,0,69,0,0,0,120,0,0,0,99,0,0,0,104,0,0,0,97,0,0,0,110,0,0,0,103,0,0,0,101,0,0,0,114,0,0,0,0,0,0,0,222,48,0,0,205,48,0,0,252,48,0,0,162,48,0,0,164,48,0,0,201,48,0,0,235,48,0,0,168,48,0,0,175,48,0,0,185,48,0,0,193,48,0,0,167,48,0,0,243,48,0,0,184,48,0,0,227,48,0,0])
.concat([252,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,73,109,97,103,101,119,111,114,107,115,0,0,0,0,0,0,120,109,118,115,102,97,114,50,0,0,0,0,0,0,0,0,83,116,101,114,110,0,0,0,75,97,109,97,107,97,122,105,32,73,73,73,32,40,115,117,112,101,114,103,32,104,97,99,107,41,0,0,0,0,0,0,110,80,97,99,66,97,110,107,0,0,0,0,0,0,0,0,119,105,108,108,111,119,111,0,112,99,101,95,112,108,101,97,103,97,115,0,0,0,0,0,77,111,110,101,121,32,80,117,122,122,108,101,32,69,120,99,104,97,110,103,101,114,32,47,32,77,111,110,101,121,32,73,100,111,108,32,69,120,99,104,97,110,103,101,114,0,0,0,66,32,98,117,116,116,111,110,32,40,100,111,119,110,41,0,66,97,99,107,32,116,111,32,116,104,101,32,70,117,116,117,114,101,32,80,97,114,116,32,73,73,73,32,40,69,117,114,111,41,0,0,0,0,0,0,88,45,77,101,110,32,118,115,32,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,40,57,54,48,57,49,57,32,65,115,105,97,41,0,0,0,97,98,99,111,112,0,0,0,76,111,115,116,32,84,111,109,98,32,40,69,97,115,121,41,0,0,0,0,0,0,0,0,87,105,108,108,111,119,32,40,85,83,41,0,0,0,0,0,80,111,119,101,114,32,76,101,97,103,117,101,32,39,57,51,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,40,80,114,105,118,97,116,101,41,32,83,69,84,95,76,73,66,82,69,84,82,79,95,80,65,84,72,46,10,0,0,0,0,0,0,0,0,109,105,101,120,99,104,110,103,0,0,0,0,0,0,0,0,109,100,95,98,97,99,107,116,111,102,51,0,0,0,0,0,120,109,118,115,102,97,114,49,0,0,0,0,0,0,0,0,108,111,115,116,116,111,109,98,0,0,0,0,0,0,0,0,115,117,112,114,108,111,99,111,0,0,0,0,0,0,0,0,115,104,97,99,107,108,101,100,0,0,0,0,0,0,0,0,119,105,108,108,111,119,0,0,112,99,101,95,112,108,101,97,103,57,51,0,0,0,0,0,80,48,0,0,139,48,0,0,138,48,0,0,147,48,0,0,0,0,0,0,71,0,0,0,117,0,0,0,114,0,0,0,117,0,0,0,114,0,0,0,105,0,0,0,110,0,0,0,0,0,0,0,0,0,0,0,66,97,98,121,39,115,32,68,97,121,32,79,117,116,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,69,97,114,108,105,101,114,41,0,0,0,0,0,0,0,0,80,49,32,66,117,116,116,111,110,32,51,0,0,0,0,0,88,45,77,101,110,32,118,115,32,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,40,57,54,49,48,50,51,32,65,115,105,97,41,0,0,0,68,114,118,73,110,112,117,116,0,0,0,0,0,0,0,0,80,108,97,121,101,114,32,99,111,117,110,116,115,0,0,0,83,117,112,101,114,32,72,101,108,105,32,40,83,117,112,101,114,32,67,111,98,114,97,32,98,111,111,116,108,101,103,41,0,0,0,0,0,0,0,0,75,111,114,101,97,32,40,85,110,105,116,101,32,84,114,97,100,105,110,103,41,0,0,0,85,83,65,32,40,84,97,105,116,111,32,65,109,101,114,105,99,97,32,67,111,114,112,111,114,97,116,105,111,110,41,0,52,48,48,48,48,48,48,32,101,97,99,104,0,0,0,0,114,111,98,111,99,111,112,98,0,0,0,0,0,0,0,0,83,97,109,101,32,97,115,32,83,116,97,114,116,0,0,0,84,104,101,32,78,101,119,90,101,97,108,97,110,100,32,83,116,111,114,121,32,40,74,97,112,97,110,44,32,110,101,119,32,118,101,114,115,105,111,110,44,32,110,101,119,101,114,32,80,67,66,41,0,0,0,0,68,46,82,46,32,75,111,114,101,97,0,0,0,0,0,0,65,115,104,117,114,97,32,66,108,97,115,116,101,114,32,40,74,97,112,97,110,41,0,0,71,104,111,115,116,32,78,97,109,101,115,0,0,0,0,0,69,110,102,111,114,99,101,32,40,74,97,112,97,110,44,32,65,110,97,108,111,103,32,67,111,110,116,114,111,108,115,41,0,0,0,0,0,0,0,0,82,97,115,116,97,110,32,83,97,103,97,32,40,74,97,112,97,110,41,0,0,0,0,0,80,111,119,101,114,32,71,111,108,102,0,0,0,0,0,0,70,117,108,108,0,0,0,0,109,100,95,98,97,98,121,100,111,0,0,0,0,0,0,0,74,0,0,0,111,0,0,0,74,0,0,0,111,0,0,0,39,0,0,0,115,0,0,0,32,0,0,0,86,0,0,0,101,0,0,0,110,0,0,0,116,0,0,0,117,0,0,0,114,0,0,0,101,0,0,0,0,0,0,0,184,48,0,0,231,48,0,0,184,48,0,0,231,48,0,0,110,48,0,0,32,0,0,0,71,89,0,0,153,89,0,0,106,48,0,0,146,81,0,0,122,150,0,0,32,0,0,0,40,0,0,0,65,0,0,0,115,0,0,0,105,0,0,0,97,0,0,0,32,0,0,0,57,0,0,0,57,0,0,0,48,0,0,0,49,0,0,0,48,0,0,0,56,0,0,0,44,0,0,0,32,0,0,0,78,0,0,0,79,0,0,0,32,0,0,0,67,0,0,0,68,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,97,110,103,101,108,107,100,115,0,0,0,0,0,0,0,0,83,117,110,115,111,102,116,32,47,32,83,101,103,97,0,0,120,109,118,115,102,97,0,0,99,117,115,116,111,109,95,118,105,101,119,112,111,114,116,95,104,101,105,103,104,116,0,0,83,101,105,115,104,117,110,32,83,99,97,110,100,97,108,32,40,51,49,53,45,53,49,51,50,44,32,74,97,112,97,110,41,0,0,0,0,0,0,0,83,104,97,100,111,119,32,68,97,110,99,101,114,32,40,115,101,116,32,49,41,0,0,0,115,117,112,114,104,101,108,105,0,0,0,0,0,0,0,0,80,52,32,77,111,100,101,0,115,109,103,112,106,97,0,0,71,101,110,86,68,80,32,86,82,65,77,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,114,101,97,100,32,109,111,118,105,101,32,104,101,97,100,101,114,46,10,0,0,0,0,0,0,0,80,52,32,66,117,116,116,111,110,32,90,0,0,0,0,0,51,48,48,0,0,0,0,0,67,114,101,100,105,116,115,32,116,111,32,83,116,97,114,116,0,0,0,0,0,0,0,0,80,52,32,66,117,116,116,111,110,32,89,0,0,0,0,0,43,50,0,0,0,0,0,0,87,105,110,103,32,83,104,111,111,116,105,110,103,32,67,104,97,109,112,105,111,110,115,104,105,112,32,86,50,46,48,48,0,0,0,0,0,0,0,0,49,67,32,49,67,44,32,49,67,32,50,67,0,0,0,0,86,97,114,116,104,32,45,32,111,112,101,114,97,116,105,111,110,32,116,104,117,110,100,101,114,115,116,111,114,109,32,40,57,50,48,54,49,50,32,85,83,65,41,0,0,0,0,0,80,52,32,66,117,116,116,111,110,32,88,0,0,0,0,0,112,99,101,95,112,103,111,108,102,0,0,0,0,0,0,0,71,117,114,117,114,105,110,0,0,0,0,0,0,0,0,0,65,0,0,0,105,0,0,0,114,0,0,0,32,0,0,0,71,0,0,0,97,0,0,0,108,0,0,0,108,0,0,0,101,0,0,0,116,0,0,0,0,0,0,0,162,48,0,0,239,48,0,0,166,48,0,0,174,48,0,0,227,48,0,0,236,48,0,0,195,48,0,0,200,48,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,82,105,103,104,116,32,70,108,105,112,112,101,114,115,0,0,66,97,98,121,39,115,32,68,97,121,32,79,117,116,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,0,0,0,86,115,46,32,82,111,117,110,100,115,0,0,0,0,0,0,80,108,97,121,101,114,32,118,115,32,80,108,97,121,101,114,32,68,97,109,97,103,101,0,88,45,77,101,110,32,118,115,32,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,40,57,54,48,57,49,48,32,69,117,114,111,41,0,0,0,77,111,98,105,108,101,32,83,117,105,116,32,71,117,110,100,97,109,0,0,0,0,0,0,83,117,112,101,114,32,67,111,98,114,97,32,40,98,111,111,116,108,101,103,41,0,0,0,66,117,116,116,111,110,32,50,0,0,0,0,0,0,0,0,115,110,111,119,98,114,111,115,97,0,0,0,0,0,0,0,98,99,115,116,114,121,97,0,49,32,99,111,105,110,32,61,32,54,32,99,114,101,100,105,116,115,0,0,0,0,0,0,73,110,116,101,114,110,97,116,105,111,110,97,108,32,86,101,114,32,66,46,0,0,0,0,109,115,116,119,111,114,108,100,0,0,0,0,0,0,0,0,65,32,49,67,47,50,67,32,66,32,49,67,47,49,50,67,0,0,0,0,0,0,0,0,78,101,118,101,114,32,70,105,110,105,115,104,0,0,0,0,99,116,114,112,108,108,114,112,0,0,0,0,0,0,0,0,103,97,117,110,116,50,50,112,0,0,0,0,0,0,0,0,49,67,32,50,67,44,32,49,67,32,52,67,0,0,0,0,50,67,95,51,67,0,0,0,118,97,114,116,104,117,0,0,80,101,115,116,32,80,108,97,99,101,0,0,0,0,0,0,80,111,119,101,114,32,71,97,116,101,0,0,0,0,0,0,70,108,105,112,95,83,99,114,101,101,110,0,0,0,0,0,103,117,114,117,114,105,110,0,109,100,95,98,97,98,121,100,0,0,0,0,0,0,0,0,86,101,114,116,105,99,97,108,0,0,0,0,0,0,0,0,49,48,107,32,32,54,48,107,43,0,0,0,0,0,0,0,49,54,32,40,68,105,102,102,105,99,117,108,116,41,0,0,120,109,118,115,102,114,49,0,71,97,108,97,120,105,97,110,0,0,0,0,0,0,0,0,102,120,0,0,0,0,0,0,115,99,111,98,114,97,98,0,69,110,101,114,103,121,32,76,111,115,115,0,0,0,0,0,99,117,115,116,111,109,95,99,112,117,95,98,117,115,121,0,51,48,107,32,32,56,48,107,0,0,0,0,0,0,0,0,50,32,67,111,105,110,115,32,52,32,80,108,97,121,115,0,65,82,77,32,82,65,77,32,48,0,0,0,0,0,0,0,111,108,100,115,0,0,0,0,80,51,32,77,111,100,101,0,66,97,114,117,110,98,97,0,0,0,0,0,0,0,0,0,49,67,32,50,67,44,32,49,67,32,51,67,0,0,0,0,86,97,114,116,104,32,45,32,111,112,101,114,97,116,105,111,110,32,116,104,117,110,100,101,114,115,116,111,114,109,32,40,57,50,48,55,49,52,32,74,97,112,97,110,41,0,0,0,80,51,32,66,117,116,116,111,110,32,90,0,0,0,0,0,67,97,114,114,105,101,114,32,65,105,114,32,87,105,110,103,32,40,98,111,111,116,108,101,103,32,115,101,116,32,49,32,40,119,105,116,104,32,50,120,89,77,50,50,48,51,32,43,32,50,120,77,83,77,53,50,48,53,41,44,32,85,46,83,46,32,110,97,118,121,32,57,48,49,48,49,50,32,101,116,99,41,0,0,0,0,0,0,112,99,101,95,112,111,119,101,114,103,97,116,0,0,0,0,78,105,103,104,116,109,97,114,101,32,105,110,32,116,104,101,32,68,97,114,107,32,40,98,111,111,116,108,101,103,41,0,0,0,0,0,0,0,0,0,115,101,110,103,111,107,117,104,0,0,0,0,0,0,0,0,78,101,111,54,56,75,70,105,120,91,110,78,101,111,65,99,116,105,118,101,83,108,111,116,93,0,0,0,0,0,0,0,66,97,98,121,32,66,111,111,109,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,54,48,54,41,0,0,0,0,0,0,0,0,0,80,51,32,66,117,116,116,111,110,32,89,0,0,0,0,0,115,108,45,62,107,101,121,0,88,45,77,101,110,32,118,115,32,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,40,57,54,49,48,48,52,32,69,117,114,111,41,0,0,0,83,117,112,101,114,32,67,111,98,114,97,32,40,83,101,103,97,41,0,0,0,0,0,0,80,51,32,66,117,116,116,111,110,32,88,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,115,101,116,32,117,112,32,102,114,97,109,101,32,98,117,102,102,101,114,32,111,98,106,101,99,116,115,46,32,77,117,108,116,105,45,112,97,115,115,32,115,104,97,100,105,110,103,32,119,105,108,108,32,110,111,116,32,119,111,114,107,46,10,0,0,109,100,95,97,103,97,115,115,105,0,0,0,0,0,0,0,37,115,95,109,97,115,107,0,69,120,99,101,112,116,0,0,50,67,32,49,67,44,32,49,67,32,49,67,0,0,0,0,66,97,116,116,108,101,32,67,105,114,99,117,105,116,32,40,57,55,48,51,49,57,32,69,117,114,111,41,0,0,0,0,118,97,114,116,104,106,0,0,80,111,119,101,114,32,69,108,101,118,101,110,0,0,0,0,110,105,116,100,98,108,0,0,109,100,95,98,97,98,121,98,111,111,109,50,0,0,0,0,115,115,114,105,100,101,114,115,101,97,97,0,0,0,0,0,83,112,101,108,117,110,107,101,114,0,0,0,0,0,0,0,117,99,99,111,112,115,97,114,0,0,0,0,0,0,0,0,104,104,97,114,114,121,0,0,120,109,118,115,102,0,0,0,115,99,111,98,114,97,115,101,0,0,0,0,0,0,0,0,68,69,67,79,32,73,67,49,54,0,0,0,0,0,0,0,83,117,112,101,114,32,90,111,108,97,32,80,97,99,32,71,97,108,0,0,0,0,0,0,86,97,114,116,104,32,45,32,111,112,101,114,97,116,105,111,110,32,116,104,117,110,100,101,114,115,116,111,114,109,32,40,57,50,48,54,49,50,32,101,116,99,41,0,0,0,0,0,112,99,101,95,112,111,119,101,114,49,49,0,0,0,0,0,69,108,101,118,101,110,32,47,32,71,97,118,97,107,105,110,103,0,0,0,0,0,0,0,66,97,98,121,32,66,111,111,109,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,54,48,51,41,0,0,0,0,0,0,0,0,0,80,50,32,77,111,100,101,0,88,45,77,101,110,32,45,32,99,104,105,108,100,114,101,110,32,111,102,32,116,104,101,32,97,116,111,109,32,40,57,53,48,49,48,53,32,85,83,65,41,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,85,115,105,110,103,32,82,79,77,58,32,37,115,46,10,0,0,0,0,0,0,97,99,101,97,116,116,97,99,97,0,0,0,0,0,0,0,83,117,112,101,114,32,67,111,98,114,97,32,40,83,116,101,114,110,41,0,0,0,0,0,80,50,32,66,117,116,116,111,110,32,90,0,0,0,0,0,80,50,32,66,117,116,116,111,110,32,89,0,0,0,0,0,83,105,109,112,108,101,32,49,53,54,0,0,0,0,0,0,80,50,32,66,117,116,116,111,110,32,88,0,0,0,0,0,67,104,97,109,112,105,111,110,32,69,100,105,116,105,111,110,0,0,0,0,0,0,0,0,118,97,114,116,104,114,49,0,80,111,119,101,114,32,68,114,105,102,116,32,40,65,108,116,41,0,0,0,0,0,0,0,78,105,103,104,116,109,97,114,101,32,105,110,32,116,104,101,32,68,97,114,107,0,0,0,109,100,95,98,97,98,121,98,111,111,109,49,0,0,0,0,120,109,99,111,116,97,117,0,115,99,111,98,114,97,115,0,101,110,100,117,114,111,114,0,110,89,77,51,53,50,54,80,111,115,105,116,105,111,110,0,101,115,112,114,97,100,101,0,107,97,109,97,107,97,122,105,51,0,0,0,0,0,0,0,86,97,114,116,104,32,45,32,111,112,101,114,97,116,105,111,110,32,116,104,117,110,100,101,114,115,116,111,114,109,32,40,57,50,48,55,49,52,32,101,116,99,41,0,0,0,0,0,112,99,101,95,112,100,114,105,102,116,49,0,0,0,0,0,110,105,116,100,0,0,0,0,66,97,98,121,32,66,111,111,109,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,56,49,49,41,0,0,0,0,0,0,0,0,0,88,45,77,101,110,32,45,32,99,104,105,108,100,114,101,110,32,111,102,32,116,104,101,32,97,116,111,109,32,40,57,52,49,50,48,56,32,74,97,112,97,110,44,32,114,101,110,116,32,118,101,114,115,105,111,110,41,0,0,0,0,0,0,0,83,117,112,101,114,32,67,111,98,114,97,0,0,0,0,0,100,105,118,101,114,98,111,121,0,0,0,0,0,0,0,0,49,67,32,56,67,0,0,0,118,97,114,116,104,0,0,0,65,115,109,105,107,0,0,0,77,0,0,0,97,0,0,0,103,0,0,0,105,0,0,0,99,0,0,0,97,0,0,0,108,0,0,0,32,0,0,0,68,0,0,0,114,0,0,0,111,0,0,0,112,0,0,0,32,0,0,0,73,0,0,0,73,0,0,0,73,0,0,0,0,0,0,0,222,48,0,0,184,48,0,0,171,48,0,0,235,48,0,0,201,48,0,0,237,48,0,0,195,48,0,0,215,48,0,0,73,0,0,0,73,0,0,0,73,0,0,0,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,71,69,84,95,83,69,78,83,79,82,95,73,78,84,69,82,70,65,67,69,46,10,0,0,0,0,0,0,0,109,100,95,98,97,98,121,98,111,111,109,0,0,0,0,0,120,109,99,111,116,97,106,114,0,0,0,0,0,0,0,0,115,99,111,98,114,97,0,0,102,117,110,121,98,117,98,108,0,0,0,0,0,0,0,0,76,97,115,116,32,77,105,115,115,105,111,110,32,40,74,97,112,97,110,41,0,0,0,0,49,67,32,55,67,0,0,0,168,48,0,0,234,48,0,0,162,48,0,0,24,255,0,0,24,255,0,0,0,0,0,0,65,0,0,0,114,0,0,0,101,0,0,0,97,0,0,0,32,0,0,0,56,0,0,0,56,0,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,32,0,0,0,82,0,0,0,101,0,0,0,115,0,0,0,97,0,0,0,108,0,0,0,101,0,0,0,32,0,0,0,118,0,0,0,101,0,0,0,114,0,0,0,46,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,111,119,101,114,32,68,114,105,102,116,0,0,0,0,0,77,97,103,105,99,97,108,32,68,114,111,112,32,73,73,73,0,0,0,0,0,0,0,0,69,108,101,99,116,114,111,110,105,99,32,65,114,116,115,32,86,105,99,116,111,114,0,0,114,111,98,111,97,114,109,121,0,0,0,0,0,0,0,0,80,49,32,66,117,116,116,111,110,32,50,0,0,0,0,0,67,104,97,110,45,62,101,110,97,98,108,101,0,0,0,0,88,45,77,101,110,32,45,32,99,104,105,108,100,114,101,110,32,111,102,32,116,104,101,32,97,116,111,109,32,40,57,52,49,50,49,55,32,74,97,112,97,110,41,0,0,0,0,0,82,65,77,0,0,0,0,0,72,105,103,104,101,115,116,0,115,105,108,118,109,105,108,0,87,111,114,108,100,47,84,97,105,116,111,32,65,109,101,114,105,99,97,0,0,0,0,0,51,48,48,48,48,48,48,32,101,97,99,104,0,0,0,0,82,111,98,111,99,111,112,32,40,85,83,32,114,101,118,105,115,105,111,110,32,48,41,0,0,0,0,0,0,0,0,0,102,111,111,116,99,104,109,112,0,0,0,0,0,0,0,0,116,110,122,115,106,0,0,0,87,114,111,110,103,32,99,111,108,111,114,115,0,0,0,0,73,110,110,101,114,32,90,111,111,109,0,0,0,0,0,0,97,115,104,117,114,97,106,0,101,110,102,111,114,99,101,106,97,0,0,0,0,0,0,0,65,114,101,97,32,56,56,32,40,74,97,112,97,110,32,82,101,115,97,108,101,32,118,101,114,46,41,0,0,0,0,0,67,101,110,116,101,114,0,0,114,97,115,116,115,97,103,97,97,0,0,0,0,0,0,0,112,99,101,95,112,100,114,105,102,116,0,0,0,0,0,0,109,97,103,100,114,111,112,51,0,0,0,0,0,0,0,0,78,111,32,67,104,97,110,103,101,0,0,0,0,0,0,0,80,108,97,121,101,114,32,83,116,97,114,116,105,110,103,32,83,116,114,101,110,103,116,104,0,0,0,0,0,0,0,0,83,112,97,99,101,32,70,117,110,107,121,32,66,46,79,46,66,46,32,40,74,112,110,41,0,0,0,0,0,0,0,0,74,111,74,111,39,115,32,86,101,110,116,117,114,101,32,47,32,74,111,74,111,32,110,111,32,75,105,109,121,111,117,32,110,97,32,66,111,117,107,101,110,32,40,65,115,105,97,32,57,57,48,49,48,56,44,32,78,79,32,67,68,41,0,0,51,50,45,67,111,108,32,77,111,100,101,32,68,114,97,119,0,0,0,0,0,0,0,0,66,97,121,32,82,111,117,116,101,32,40,115,101,116,32,51,44,32,87,111,114,108,100,44,32,70,68,49,48,57,52,32,51,49,55,45,48,49,49,54,41,0,0,0,0,0,0,0,120,109,99,111,116,97,106,51,0,0,0,0,0,0,0,0,99,117,115,116,111,109,95,118,105,101,119,112,111,114,116,95,119,105,100,116,104,0,0,0,115,115,99,97,110,100,97,108,0,0,0,0,0,0,0,0,115,104,100,97,110,99,101,114,49,0,0,0,0,0,0,0,83,117,112,101,114,32,77,111,110,97,99,111,32,71,80,32,40,74,97,112,97,110,44,32,82,101,118,32,66,44,32,70,68,49,48,57,52,32,51,49,55,45,48,49,50,52,97,41,0,0,0,0,0,0,0,0,83,68,73,32,45,32,83,116,114,97,116,101,103,105,99,32,68,101,102,101,110,115,101,32,73,110,105,116,105,97,116,105,118,101,32,40,74,97,112,97,110,44,32,111,108,100,44,32,83,121,115,116,101,109,32,49,54,65,44,32,70,68,49,48,56,57,66,32,51,49,55,45,48,48,50,55,41,0,0,0,67,68,45,82,79,77,0,0,77,105,110,105,109,117,109,32,67,114,101,100,105,116,115,0,75,111,114,101,97,110,32,76,97,110,103,117,97,103,101,0,74,97,112,97,110,32,80,65,76,0,0,0,0,0,0,0,43,49,0,0,0,0,0,0,86,105,110,99,101,32,40,82,101,100,104,97,119,107,32,98,111,111,116,108,101,103,41,0,0,0,0,0,0,0,0,0,56,32,99,111,105,110,115,32,51,32,99,114,101,100,105,116,115,0,0,0,0,0,0,0,119,115,99,104,97,109,112,0,74,97,112,97,110,32,78,84,83,67,0,0,0,0,0,0,97,114,101,97,56,56,114,0,65,117,116,111,32,68,101,116,101,99,116,0,0,0,0,0,80,111,112,117,108,111,117,115,32,40,65,108,116,41,0,0,77,0,0,0,97,0,0,0,103,0,0,0,105,0,0,0,99,0,0,0,97,0,0,0,108,0,0,0,32,0,0,0,68,0,0,0,114,0,0,0,111,0,0,0,112,0,0,0,32,0,0,0,73,0,0,0,73,0,0,0,0,0,0,0,222,48,0,0,184,48,0,0,171,48,0,0,235,48,0,0,201,48,0,0,237,48,0,0,195,48,0,0,215,48,0,0,18,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,65,105,114,32,71,97,108,108,101,116,32,40,74,97,112,97,110,41,0,0,0,0,0,0,72,97,114,100,119,97,114,101,0,0,0,0,0,0,0,0,109,100,95,115,112,97,99,101,98,111,98,0,0,0,0,0,50,32,99,104,117,116,101,115,0,0,0,0,0,0,0,0,83,111,110,105,99,32,38,32,75,110,117,99,107,108,101,115,32,43,32,83,111,110,105,99,32,116,104,101,32,72,101,100,103,101,104,111,103,32,51,32,40,87,111,114,108,100,41,0,0,0,0,0,0,0,0,0,109,100,95,115,107,115,51,0,88,45,77,101,110,32,45,32,99,104,105,108,100,114,101,110,32,111,102,32,116,104,101,32,97,116,111,109,32,40,57,52,49,50,49,57,32,74,97,112,97,110,41,0,0,0,0,0,109,115,103,117,110,100,97,109,0,0,0,0,0,0,0,0,83,111,110,105,99,32,38,32,75,110,117,99,107,108,101,115,32,43,32,83,111,110,105,99,32,116,104,101,32,72,101,100,103,101,104,111,103,32,50,32,40,87,111,114,108,100,41,0,0,0,0,0,0,0,0,0,65,100,112,99,109,66,97,110,107,83,104,105,102,116,0,0,66,46,67,46,32,83,116,111,114,121,32,40,115,101,116,32,49,41,0,0,0,0,0,0,109,100,95,115,107,115,50,0,45,97,120,105,115,0,0,0,49,32,99,111,105,110,32,61,32,53,32,99,114,101,100,105,116,115,0,0,0,0,0,0,73,110,116,101,114,110,97,116,105,111,110,97,108,32,86,101,114,32,65,46,0,0,0,0,80,50,32,98,117,116,116,111,110,32,51,0,0,0,0,0,83,111,110,105,99,32,38,32,75,110,117,99,107,108,101,115,32,43,32,83,111,110,105,99,32,116,104,101,32,72,101,100,103,101,104,111,103,32,40,87,111,114,108,100,41,0,0,0,73,110,116,101,114,110,97,116,105,111,110,97,108,0,0,0,109,100,95,115,107,115,49,0,77,105,116,99,104,101,108,108,32,43,32,67,97,112,99,111,109,0,0,0,0,0,0,0,65,32,49,67,47,50,67,32,66,32,49,67,47,49,49,67,0,0,0,0,0,0,0,0,83,116,111,112,32,86,105,100,101,111,0,0,0,0,0,0,65,114,116,32,84,111,111,108,0,0,0,0,0,0,0,0,66,117,99,99,97,110,101,101,114,0,0,0,0,0,0,0,71,97,117,110,116,108,101,116,32,73,73,32,40,71,101,114,109,97,110,41,0,0,0,0,109,100,95,97,114,116,116,111,111,108,0,0,0,0,0,0,50,67,32,56,67,0,0,0,80,105,101,99,101,115,0,0,168,48,0,0,234,48,0,0,162,48,0,0,24,255,0,0,24,255,0,0,0,0,0,0,65,0,0,0,114,0,0,0,101,0,0,0,97,0,0,0,32,0,0,0,56,0,0,0,56,0,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,83,111,117,110,100,32,84,111,111,108,32,118,50,46,50,63,0,0,0,0,0,0,0,0,112,99,101,95,112,111,112,117,108,111,117,115,49,0,0,0,77,97,103,105,99,97,108,32,68,114,111,112,32,73,73,0,0,0,0,0,0,0,0,0,49,32,67,111,105,110,32,32,53,32,80,108,97,121,115,0,109,100,95,115,110,100,116,111,111,108,0,0,0,0,0,0,66,46,79,46,66,46,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,0,0,0,98,101,114,108,119,97,108,108,0,0,0,0,0,0,0,0,71,69,77,83,32,118,50,46,56,0,0,0,0,0,0,0,72,111,114,105,122,111,110,116,97,108,0,0,0,0,0,0,49,48,107,32,32,53,48,107,43,0,0,0,0,0,0,0,109,100,95,103,101,109,115,0,120,109,99,111,116,97,106,50,0,0,0,0,0,0,0,0,110,89,77,51,56,49,50,80,111,115,105,116,105,111,110,0,99,117,115,116,111,109,95,99,112,117,95,114,101,115,101,116,0,0,0,0,0,0,0,0,50,48,107,32,32,56,48,107,32,32,56,48,107,0,0,0,65,82,77,32,83,72,65,82,69,32,82,65,77,32,35,49,0,0,0,0,0,0,0,0,112,99,101,95,98,97,114,117,110,98,97,0,0,0,0,0,50,67,32,55,67,0,0,0,65,114,101,97,32,56,56,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,80,114,111,32,65,99,116,105,111,110,32,82,101,112,108,97,121,32,50,32,40,69,117,114,111,44,32,65,108,116,41,0,0,0,0,0,0,0,0,0,99,97,119,105,110,103,98,108,0,0,0,0,0,0,0,0,80,111,112,117,108,111,117,115,0,0,0,0,0,0,0,0,83,0,0,0,101,0,0,0,110,0,0,0,103,0,0,0,111,0,0,0,107,0,0,0,117,0,0,0,32,0,0,0,47,0,0,0,32,0,0,0,83,0,0,0,101,0,0,0,110,0,0,0,103,0,0,0,111,0,0,0,107,0,0,0,117,0,0,0,32,0,0,0,68,0,0,0,101,0,0,0,110,0,0,0,115,0,0,0,104,0,0,0,111,0,0,0,117,0,0,0,32,0,0,0,40,0,0,0,78,0,0,0,71,0,0,0,77,0,0,0,45,0,0,0,48,0,0,0,49,0,0,0,55,0,0,0,41,0,0,0,40,0,0,0,78,0,0,0,71,0,0,0,72,0,0,0,45,0,0,0,48,0,0,0,49,0,0,0,55,0,0,0,41,0,0,0,0,0,0,0,38,98,0,0,253,86,0,0,29,79,0,0,127,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,110,117,80,68,52,57,57,48,65,84,105,99,107,115,0,0,109,100,95,112,97,114,50,97,0,0,0,0,0,0,0,0,109,100,95,98,111,98,112,0,80,114,111,32,65,99,116,105,111,110,32,82,101,112,108,97,121,32,50,32,40,69,117,114,111,41,0,0,0,0,0,0,115,108,45,62,101,103,95,115,101,108,95,114,115,0,0,0,109,100,95,112,97,114,50,0,88,45,77,101,110,32,45,32,99,104,105,108,100,114,101,110,32,111,102,32,116,104,101,32,97,116,111,109,32,40,57,52,49,50,50,50,32,74,97,112,97,110,41,0,0,0,0,0,80,114,111,32,65,99,116,105,111,110,32,82,101,112,108,97,121,32,40,69,117,114,111,41,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,104,97,100,101,114,32,108,111,103,58,32,37,115,10,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,68,105,100,110,39,116,32,102,105,110,100,32,71,76,32,99,111,110,116,101,120,116,58,32,37,115,46,10,0,0,0,0,0,0,0,109,100,95,112,97,114,0,0,71,97,109,101,32,71,101,110,105,101,32,40,69,117,114,111,44,32,85,83,65,41,0,0,65,108,105,115,105,97,32,68,114,97,103,111,111,110,32,40,69,117,114,111,41,0,0,0,109,100,95,103,103,101,110,105,101,49,0,0,0,0,0,0,109,117,108,116,99,104,109,112,0,0,0,0,0,0,0,0,84,111,103,103,108,101,32,70,117,108,108,115,99,114,101,101,110,0,0,0,0,0,0,0,71,97,109,101,32,71,101,110,105,101,32,40,69,117,114,111,44,32,85,83,65,44,32,82,101,118,46,32,65,41,0,0,70,105,101,108,100,101,114,32,67,111,110,116,114,111,108,0,109,100,95,103,103,101,110,105,101,0,0,0,0,0,0,0,37,115,95,105,110,112,117,116,95,115,108,111,116,0,0,0,73,110,99,108,117,100,101,0,50,67,32,54,67,0,0,0,97,114,101,97,56,56,0,0,65,99,116,105,111,110,32,82,101,112,108,97,121,32,40,69,117,114,111,41,0,0,0,0,112,99,101,95,112,111,112,117,108,111,117,115,0,0,0,0,71,0,0,0,104,0,0,0,111,0,0,0,115,0,0,0,116,0,0,0,108,0,0,0,111,0,0,0,112,0,0,0,32,0,0,0,180,48,0,0,252,48,0,0,185,48,0,0,200,48,0,0,237,48,0,0,195,48,0,0,215,48,0,0,32,0,0,0,40,0,0,0,112,0,0,0,114,0,0,0,111,0,0,0,116,0,0,0,111,0,0,0,116,0,0,0,121,0,0,0,112,0,0,0,101,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,109,100,95,97,114,0,0,0,66,46,79,46,66,46,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,83,117,110,115,101,116,32,82,105,100,101,114,115,32,40,52,32,80,108,97,121,101,114,115,32,118,101,114,46,32,85,68,65,41,0,0,0,0,0,0,115,112,101,108,117,110,107,114,0,0,0,0,0,0,0,0,87,105,110,120,32,51,68,32,86,111,108,115,104,101,98,110,111,101,32,80,114,105,107,108,121,117,99,104,101,110,105,101,32,40,82,117,115,41,0,0,85,110,100,101,114,99,111,118,101,114,32,67,111,112,115,32,40,85,83,41,0,0,0,0,82,45,84,121,112,101,32,73,73,32,40,74,97,112,97,110,44,32,114,101,118,105,115,105,111,110,32,67,41,0,0,0,109,100,95,119,105,110,120,51,100,0,0,0,0,0,0,0,120,109,99,111,116,97,106,49,0,0,0,0,0,0,0,0,87,105,110,120,32,45,32,83,104,107,111,108,97,32,86,111,108,115,104,121,101,98,110,105,116,115,32,40,82,117,115,41,0,0,0,0,0,0,0,0,109,100,95,119,105,110,120,0,87,97,114,105,111,32,76,97,110,100,32,51,32,40,82,117,115,41,0,0,0,0,0,0,109,100,95,119,97,114,105,111,51,0,0,0,0,0,0,0,84,114,97,110,115,102,111,114,109,101,114,115,32,51,32,40,82,117,115,41,0,0,0,0,109,100,95,116,114,97,110,115,102,51,0,0,0,0,0,0,118,111,105,99,101,45,62,98,105,116,119,105,100,116,104,0,68,97,105,112,114,111,32,47,32,67,97,112,99,111,109,0,84,101,101,110,97,103,101,32,77,117,116,97,110,116,32,78,105,110,106,97,32,84,117,114,116,108,101,115,32,45,32,86,111,122,118,114,97,115,104,99,104,101,110,105,101,32,76,101,103,101,110,100,121,32,40,82,117,115,41,0,0,0,0,0,103,117,109,98,111,0,0,0,80,67,32,80,97,99,104,105,45,115,108,111,116,0,0,0,71,104,111,115,116,108,111,112,32,40,112,114,111,116,111,116,121,112,101,41,0,0,0,0,109,100,95,116,109,110,116,114,117,0,0,0,0,0,0,0,88,45,77,101,110,32,45,32,99,104,105,108,100,114,101,110,32,111,102,32,116,104,101,32,97,116,111,109,32,40,57,53,48,49,48,53,32,74,97,112,97,110,41,0,0,0,0,0,109,100,95,98,111,98,0,0,71,97,109,116,101,99,63,0,84,105,110,121,32,84,111,111,110,32,65,100,118,101,110,116,117,114,101,115,32,51,32,40,84,119,44,32,67,114,97,99,107,101,100,41,0,0,0,0,99,104,105,112,45,62,101,103,95,116,105,109,101,114,95,111,118,101,114,102,108,111,119,0,114,101,116,114,111,97,114,99,104,0,0,0,0,0,0,0,83,70,45,88,0,0,0,0,109,100,95,116,116,111,111,110,51,0,0,0,0,0,0,0,84,97,110,107,105,32,50,48,49,49,32,40,82,117,115,41,0,0,0,0,0,0,0,0,109,100,95,116,97,110,107,50,48,49,49,0,0,0,0,0,84,97,99,104,107,105,32,50,32,40,82,117,115,41,0,0,109,100,95,99,97,114,115,50,0,0,0,0,0,0,0,0,84,97,99,104,107,105,32,40,82,117,115,41,0,0,0,0,50,67,32,52,67,0,0,0,85,46,78,46,32,83,113,117,97,100,114,111,110,32,40,85,83,41,0,0,0,0,0,0,109,100,95,99,97,114,115,0,112,99,101,95,112,99,112,97,99,104,105,0,0,0,0,0,82,105,103,104,116,32,97,110,97,108,111,103,32,88,45,32,40,108,101,102,116,41,0,0,103,104,111,115,116,108,111,112,0,0,0,0,0,0,0,0,84,51,32,45,32,84,104,101,32,65,114,99,97,100,101,32,71,97,109,101,32,40,82,117,115,41,0,0,0,0,0,0,65,121,114,116,111,110,32,83,101,110,110,97,39,115,32,83,117,112,101,114,32,77,111,110,97,99,111,32,71,80,32,73,73,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,109,117,103,115,109,97,115,104,0,0,0,0,0,0,0,0,109,100,95,116,51,97,103,0,83,117,112,101,114,32,82,111,98,111,116,32,87,97,114,115,32,40,82,117,115,41,0,0,103,117,119,97,110,103,101,0,120,109,99,111,116,97,106,0,115,102,120,0,0,0,0,0,109,100,95,115,114,111,98,111,119,114,115,0,0,0,0,0,83,117,112,101,114,32,77,97,114,105,111,32,66,114,111,115,46,32,43,32,66,97,116,116,108,101,32,67,105,116,121,32,40,82,117,115,41,0,0,0,109,100,95,115,109,98,98,99,0,0,0,0,0,0,0,0,83,116,97,114,32,87,97,114,115,32,74,101,100,105,32,40,82,117,115,41,0,0,0,0,109,100,95,115,116,97,114,106,101,100,105,0,0,0,0,0,83,116,97,114,32,87,97,114,115,32,40,82,117,115,41,0,0,0,0,0,0,0,0,0,71,97,108,97,120,105,97,110,32,40,98,111,111,116,108,101,103,44,32,115,101,116,32,50,41,0,0,0,0,0,0,0,117,110,115,113,117,97,100,0,109,100,95,115,116,97,114,119,97,114,115,0,0,0,0,0,80,67,32,71,101,110,106,105,110,32,51,32,45,32,80,105,116,104,101,99,97,110,116,104,114,111,112,117,115,32,67,111,109,112,117,116,101,114,117,114,117,115,32,40,84,97,105,107,101,110,98,97,110,41,0,0,83,116,114,101,101,116,32,72,111,111,112,32,47,32,83,116,114,101,101,116,32,83,108,97,109,32,47,32,68,117,110,107,32,68,114,101,97,109,32,40,68,69,77,45,48,48,52,41,32,40,68,69,72,45,48,48,52,41,0,0,0,0,0,0,83,112,121,32,75,105,100,115,32,52,32,45,32,65,108,108,32,84,104,101,32,84,105,109,101,32,73,110,32,84,104,101,32,87,111,114,108,100,32,40,82,117,115,41,0,0,0,0,109,100,95,115,109,103,112,50,117,0,0,0,0,0,0,0,109,100,95,115,112,121,107,105,100,115,52,0,0,0,0,0,83,112,111,110,103,101,32,66,111,98,32,40,82,117,115,41,0,0,0,0,0,0,0,0,88,45,77,101,110,32,45,32,99,104,105,108,100,114,101,110,32,111,102,32,116,104,101,32,97,116,111,109,32,40,57,53,48,49,48,53,32,72,105,115,112,97,110,105,99,41,0,0,109,100,95,115,112,111,110,103,98,111,98,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,9,37,115,10,0,83,110,101,122,104,110,97,121,97,32,75,111,114,111,108,101,118,97,32,40,82,117,115,41,0,0,0,0,0,0,0,0,109,100,95,115,110,101,122,107,111,114,111,0,0,0,0,0,83,101,122,111,110,32,79,104,111,116,121,32,51,32,40,82,117,115,41,0,0,0,0,0,80,111,105,110,116,32,84,97,98,108,101,0,0,0,0,0,109,100,95,111,112,101,110,115,101,97,51,0,0,0,0,0,83,101,122,111,110,32,79,104,111,116,121,32,40,82,117,115,41,0,0,0,0,0,0,0,120,111,114,119,111,114,108,100,0,0,0,0,0,0,0,0,50,67,32,50,67,0,0,0,185,48,0,0,200,48,0,0,233,48,0,0,164,48,0,0,192,48,0,0,252,48,0,0,219,152,0,0,220,122,0,0,0,0,0,0,83,0,0,0,116,0,0,0,114,0,0,0,105,0,0,0,100,0,0,0,101,0,0,0,114,0,0,0,32,0,0,0,72,0,0,0,105,0,0,0,114,0,0,0,121,0,0,0,117,0,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,109,100,95,111,112,101,110,115,101,97,0,0,0,0,0,0,112,99,101,95,112,99,103,101,110,106,51,116,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,71,69,84,95,73,78,80,85,84,95,68,69,86,73,67,69,95,67,65,80,65,66,73,76,73,84,73,69,83,46,10,0,0,0,0,0,0,83,104,114,101,107,32,50,32,40,82,117,115,41,0,0,0,65,121,114,116,111,110,32,83,101,110,110,97,39,115,32,83,117,112,101,114,32,77,111,110,97,99,111,32,71,80,32,73,73,32,40,69,117,114,111,44,32,74,112,110,41,0,0,0,109,100,95,115,104,114,101,107,50,0,0,0,0,0,0,0,83,104,114,101,107,32,40,82,117,115,41,0,0,0,0,0,120,109,99,111,116,97,104,114,49,0,0,0,0,0,0,0,65,46,68,46,32,50,48,56,51,0,0,0,0,0,0,0,109,100,95,115,104,114,101,107,0,0,0,0,0,0,0,0,82,105,99,107,32,68,97,110,103,101,114,111,117,115,32,40,82,117,115,41,0,0,0,0,108,97,115,116,109,105,115,110,106,0,0,0,0,0,0,0,78,101,119,71,97,109,101,0,82,72,76,32,50,48,48,55,32,40,82,117,115,41,0,0,57,48,48,48,0,0,0,0,109,100,95,114,104,108,50,107,55,0,0,0,0,0,0,0,80,111,107,101,109,111,110,32,67,114,97,122,121,32,68,114,117,109,109,101,114,32,40,65,108,116,41,0,0,0,0,0,110,89,77,90,50,56,48,66,73,82,81,77,97,115,107,0,68,69,67,56,0,0,0,0,84,101,108,101,112,111,114,116,32,72,111,108,101,115,0,0,83,116,114,105,100,101,114,32,72,105,114,121,117,32,40,74,97,112,97,110,41,0,0,0,109,100,95,112,111,107,101,99,100,97,0,0,0,0,0,0,80,67,32,71,101,110,106,105,110,32,51,32,45,32,80,105,116,104,101,99,97,110,116,104,114,111,112,117,115,32,67,111,109,112,117,116,101,114,117,114,117,115,0,0,0,0,0,0,75,97,114,110,111,118,39,115,32,82,101,118,101,110,103,101,32,47,32,70,105,103,104,116,101,114,39,115,32,72,105,115,116,111,114,121,32,68,121,110,97,109,105,116,101,0,0,0,80,105,114,97,116,121,32,75,97,114,105,98,115,107,111,103,111,32,77,111,114,121,97,32,45,32,78,97,32,83,116,114,97,110,110,121,104,32,66,101,114,101,103,97,104,32,126,32,80,105,114,97,116,101,115,32,111,102,32,116,104,101,32,67,97,114,105,98,98,101,97,110,32,45,32,79,110,32,83,116,114,97,110,103,101,114,32,84,105,100,101,115,32,40,82,117,115,41,0,0,0,0,0,0,109,100,95,115,109,103,112,50,0,0,0,0,0,0,0,0,80,49,32,66,117,116,116,111,110,32,49,0,0,0,0,0,109,100,95,112,99,97,114,105,98,50,0,0,0,0,0,0,80,105,114,97,116,101,115,32,111,102,32,116,104,101,32,67,97,114,105,98,98,101,97,110,32,40,82,117,115,41,0,0,88,45,77,101,110,32,45,32,99,104,105,108,100,114,101,110,32,111,102,32,116,104,101,32,97,116,111,109,32,40,57,53,48,51,51,49,32,72,105,115,112,97,110,105,99,41,0,0,78,111,0,0,0,0,0,0,72,105,103,104,0,0,0,0,97,100,50,48,56,51,0,0,67,111,110,116,105,110,117,101,0,0,0,0,0,0,0,0,109,100,95,112,99,97,114,105,98,0,0,0,0,0,0,0,85,83,65,32,40,82,111,109,115,116,97,114,41,0,0,0,78,72,76,80,65,32,50,48,48,51,32,40,82,117,115,41,0,0,0,0,0,0,0,0,118,105,109,97,110,97,95,108,97,116,99,104,0,0,0,0,109,100,95,110,104,108,112,97,50,107,51,0,0,0,0,0,85,83,47,84,97,105,116,111,32,65,109,101,114,105,99,97,0,0,0,0,0,0,0,0,114,111,98,111,99,111,112,117,48,0,0,0,0,0,0,0,78,101,101,100,32,102,111,114,32,83,112,101,101,100,32,85,110,100,101,114,99,111,118,101,114,32,40,82,117,115,41,0,0,0,0,0,0,0,0,0])
.concat([70,105,110,97,108,32,66,108,111,119,32,40,85,83,41,0,0,0,0,0,0,0,0,0,56,48,48,48,0,0,0,0,109,100,95,110,102,115,117,0,67,111,110,116,105,110,117,101,32,80,114,105,99,101,0,0,84,104,101,32,78,101,119,90,101,97,108,97,110,100,32,83,116,111,114,121,32,40,87,111,114,108,100,44,32,110,101,119,101,114,41,0,0,0,0,0,84,101,116,114,105,115,32,40,68,46,82,46,32,75,111,114,101,97,41,0,0,0,0,0,76,97,110,103,117,97,103,101,0,0,0,0,0,0,0,0,78,66,65,32,50,48,48,53,32,40,82,117,115,41,0,0,65,115,104,117,114,97,32,66,108,97,115,116,101,114,32,40,87,111,114,108,100,41,0,0,70,105,114,115,116,32,80,97,116,116,101,114,110,0,0,0,69,110,102,111,114,99,101,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,115,116,114,105,100,101,114,106,0,0,0,0,0,0,0,0,109,100,95,110,98,97,50,107,53,0,0,0,0,0,0,0,98,101,115,116,98,101,115,116,0,0,0,0,0,0,0,0,82,97,115,116,97,110,32,83,97,103,97,32,40,74,97,112,97,110,32,82,101,118,32,49,41,0,0,0,0,0,0,0,112,99,101,95,112,99,103,101,110,106,51,0,0,0,0,0,78,66,65,32,50,48,48,48,32,40,82,117,115,41,0,0,80,108,97,121,101,114,32,111,114,32,77,97,103,105,99,105,97,110,0,0,0,0,0,0,65,83,67,73,73,32,69,110,116,101,114,116,97,105,110,109,101,110,116,0,0,0,0,0,106,111,106,111,110,114,49,0,109,100,95,110,98,97,50,107,0,0,0,0,0,0,0,0,78,97,114,117,116,111,32,40,82,117,115,41,0,0,0,0,120,109,99,111,116,97,104,0,99,117,115,116,111,109,95,118,105,101,119,112,111,114,116,95,121,0,0,0,0,0,0,0,77,121,32,72,101,114,111,32,40,85,83,44,32,110,111,116,32,101,110,99,114,121,112,116,101,100,41,0,0,0,0,0,83,104,97,100,111,119,32,68,97,110,99,101,114,32,40,115,101,116,32,51,44,32,85,83,41,0,0,0,0,0,0,0,65,114,97,99,110,105,115,32,40,98,111,111,116,108,101,103,32,111,102,32,83,99,111,114,112,105,111,110,32,111,110,32,77,111,111,110,32,67,114,101,115,116,97,32,104,97,114,100,119,97,114,101,41,0,0,0,109,100,95,110,97,114,117,116,111,0,0,0,0,0,0,0,115,109,103,112,106,0,0,0,78,97,114,110,105,97,32,51,32,40,82,117,115,41,0,0,110,89,56,57,53,48,80,111,115,105,116,105,111,110,0,0,109,100,95,110,97,114,110,105,97,51,0,0,0,0,0,0,76,111,115,101,32,65,108,108,0,0,0,0,0,0,0,0,77,111,110,115,116,101,114,115,44,32,73,110,99,46,32,40,82,117,115,41,0,0,0,0,55,48,48,48,0,0,0,0,109,100,95,109,111,110,115,116,105,110,99,0,0,0,0,0,43,48,0,0,0,0,0,0,114,101,100,104,97,119,107,98,0,0,0,0,0,0,0,0,53,32,99,111,105,110,115,32,51,32,99,114,101,100,105,116,115,0,0,0,0,0,0,0,84,117,114,107,101,121,32,72,117,110,116,105,110,103,32,85,83,65,32,86,49,46,48,0,0,0,0,0,0,0,0,0,77,105,103,104,116,121,32,77,111,114,112,104,105,110,32,80,111,119,101,114,32,82,97,110,103,101,114,115,32,45,32,84,104,101,32,70,105,103,104,116,105,110,103,32,69,100,105,116,105,111,110,32,40,82,117,115,41,0,0,0,0,0,0,0,52,32,77,105,110,117,116,101,115,0,0,0,0,0,0,0,69,110,101,114,103,121,0,0,185,48,0,0,200,48,0,0,233,48,0,0,164,48,0,0,192,48,0,0,252,48,0,0,219,152,0,0,220,122,0,0,0,0,0,0,83,0,0,0,116,0,0,0,114,0,0,0,105,0,0,0,100,0,0,0,101,0,0,0,114,0,0,0,32,0,0,0,72,0,0,0,105,0,0,0,114,0,0,0,121,0,0,0,117,0,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,32,0,0,0,82,0,0,0,101,0,0,0,115,0,0,0,97,0,0,0,108,0,0,0,101,0,0,0,32,0,0,0,86,0,0,0,101,0,0,0,114,0,0,0,46,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,109,100,95,109,109,112,114,102,101,0,0,0,0,0,0,0,80,67,32,71,101,110,106,105,110,32,50,32,45,32,80,105,116,104,101,99,97,110,116,104,114,111,112,117,115,32,67,111,109,112,117,116,101,114,117,114,117,115,0,0,0,0,0,0,87,105,110,100,106,97,109,109,101,114,115,32,47,32,70,108,121,105,110,103,32,80,111,119,101,114,32,68,105,115,99,0,0,0,0,0,0,0,0,0,97,103,97,108,108,101,116,106,0,0,0,0,0,0,0,0,77,101,116,97,108,32,71,101,97,114,32,83,111,108,105,100,32,40,82,117,115,41,0,0,76,101,102,116,32,70,108,105,112,112,101,114,115,0,0,0,65,87,83,32,80,114,111,32,77,111,118,101,115,32,83,111,99,99,101,114,32,40,85,83,65,41,0,0,0,0,0,0,100,101,99,111,49,54,95,112,114,105,111,114,105,116,121,0,49,32,99,104,117,116,101,0,109,100,95,109,103,115,0,0,83,117,112,101,114,32,77,97,114,105,111,32,87,111,114,108,100,32,54,52,32,40,72,97,99,107,101,100,32,80,114,111,116,101,99,116,105,111,110,41,0,0,0,0,0,0,0,0,88,45,77,101,110,32,45,32,99,104,105,108,100,114,101,110,32,111,102,32,116,104,101,32,97,116,111,109,32,40,57,52,49,50,49,55,32,65,115,105,97,41,0,0,0,0,0,0,65,108,108,117,109,101,114,32,43,32,84,101,99,109,111,0,97,114,97,99,110,105,115,0,109,100,95,115,109,97,114,105,111,54,52,104,0,0,0,0,66,117,116,116,111,110,32,49,0,0,0,0,0,0,0,0,79,104,109,121,103,111,100,68,105,112,0,0,0,0,0,0,83,110,111,119,32,66,114,111,115,46,32,45,32,78,105,99,107,32,38,32,84,111,109,32,40,115,101,116,32,49,41,0,0,0,0,0,0,0,0,0,83,117,112,101,114,32,77,97,114,105,111,32,87,111,114,108,100,32,54,52,0,0,0,0,116,97,111,116,97,105,100,111,0,0,0,0,0,0,0,0,49,32,99,111,105,110,32,61,32,52,32,99,114,101,100,105,116,115,0,0,0,0,0,0,109,100,95,115,109,97,114,105,111,54,52,0,0,0,0,0,86,101,114,115,105,111,110,0,77,97,114,105,111,32,52,32,45,32,75,111,115,109,105,99,104,101,115,107,97,121,97,32,79,100,105,115,115,121,101,121,97,32,40,82,117,115,41,0,0,0,0,0,0,0,0,0,83,117,112,101,114,32,66,117,115,116,101,114,32,66,114,111,115,46,32,40,85,83,32,57,48,49,48,48,49,41,0,0,65,32,49,67,47,50,67,32,66,32,49,67,47,49,48,67,0,0,0,0,0,0,0,0,68,101,109,111,32,83,111,117,110,100,32,79,110,0,0,0,54,48,48,48,0,0,0,0,109,100,95,109,97,114,105,111,52,0,0,0,0,0,0,0,103,97,117,110,116,50,103,0,77,97,114,105,111,32,51,32,45,32,86,111,107,114,117,103,32,83,118,101,116,97,32,40,82,117,115,41,0,0,0,0,51,32,77,105,110,117,116,101,115,0,0,0,0,0,0,0,51,67,95,50,67,0,0,0,83,116,114,105,100,101,114,32,72,105,114,121,117,32,40,74,97,112,97,110,32,82,101,115,97,108,101,32,86,101,114,46,41,0,0,0,0,0,0,0,109,100,95,109,97,114,105,111,51,0,0,0,0,0,0,0,112,99,101,95,112,99,103,101,110,106,50,0,0,0,0,0,50,48,48,48,48,32,56,48,48,48,48,0,0,0,0,0,77,97,102,105,97,32,40,82,117,115,41,0,0,0,0,0,109,100,95,97,119,115,112,114,111,0,0,0,0,0,0,0,109,100,95,109,97,102,105,97,0,0,0,0,0,0,0,0,77,111,110,105,116,111,114,0,77,97,100,97,103,97,115,99,97,114,32,51,32,40,82,117,115,41,0,0,0,0,0,0,120,109,99,111,116,97,97,114,49,0,0,0,0,0,0,0,83,46,82,46,68,46,32,77,105,115,115,105,111,110,0,0,53,32,67,111,105,110,115,32,51,32,80,108,97,121,115,0,68,111,114,110,101,101,114,0,109,100,95,109,97,100,97,103,115,99,51,0,0,0,0,0,83,112,117,114,116,32,84,105,109,101,0,0,0,0,0,0,49,58,48,48,0,0,0,0,77,97,100,97,103,97,115,99,97,114,32,45,32,79,112,101,114,97,116,115,105,121,97,32,80,105,110,103,118,105,110,32,40,82,117,115,41,0,0,0,109,100,95,109,97,100,97,103,111,112,112,0,0,0,0,0,65,82,77,32,83,72,65,82,69,32,82,65,77,32,35,48,32,40,97,100,100,114,101,115,115,32,53,48,48,48,48,48,41,0,0,0,0,0,0,0,76,111,114,100,32,111,102,32,116,104,101,32,82,105,110,103,115,32,45,32,84,104,101,32,82,101,116,117,114,110,32,111,102,32,116,104,101,32,75,105,110,103,32,40,82,117,115,41,0,0,0,0,0,0,0,0,52,48,48,48,0,0,0,0,109,100,95,108,111,116,114,103,115,0,0,0,0,0,0,0,76,111,114,100,32,111,102,32,116,104,101,32,82,105,110,103,115,32,40,82,117,115,44,32,72,97,99,107,32,111,102,32,83,116,111,114,109,108,111,114,100,41,0,0,0,0,0,0,50,32,77,105,110,117,116,101,115,0,0,0,0,0,0,0,115,116,114,105,100,101,114,106,114,0,0,0,0,0,0,0,109,100,95,108,111,116,114,0,85,46,83,46,32,78,97,118,121,32,40,57,48,49,48,49,50,32,74,97,112,97,110,41,0,0,0,0,0,0,0,0,80,67,32,71,101,110,106,105,110,32,45,32,80,105,116,104,101,99,97,110,116,104,114,111,112,117,115,32,67,111,109,112,117,116,101,114,117,114,117,115,32,40,65,108,116,41,0,0,83,101,110,103,111,107,117,32,47,32,83,101,110,103,111,107,117,32,68,101,110,115,104,111,117,32,40,78,71,77,45,48,49,55,41,40,78,71,72,45,48,49,55,41,0,0,0,0,75,117,122,121,97,32,45,32,69,107,111,108,111,103,105,121,97,32,86,32,79,112,97,115,110,111,115,116,105,32,40,82,117,115,41,0,0,0,0,0,65,119,111,114,103,32,40,74,112,110,44,32,83,101,103,97,78,101,116,41,0,0,0,0,109,100,95,107,117,122,121,97,101,111,0,0,0,0,0,0,115,108,45,62,101,103,95,115,104,95,114,115,0,0,0,0,75,117,122,121,97,32,45,32,86,32,77,105,114,101,32,68,105,110,111,122,97,118,114,111,118,32,40,82,117,115,41,0,0,0,0,0,0,0,0,0,88,45,77,101,110,32,45,32,99,104,105,108,100,114,101,110,32,111,102,32,116,104,101,32,97,116,111,109,32,40,57,53,48,49,48,53,32,65,115,105,97,41,0,0,0,0,0,0,83,99,111,114,112,105,111,110,32,40,77,111,111,110,32,67,114,101,115,116,97,32,104,97,114,100,119,97,114,101,41,0,0,0,0,0,0,0,0,0,109,100,95,107,117,122,121,97,109,100,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,71,76,93,58,32,85,115,105,110,103,32,71,76,83,76,32,118,101,114,115,105,111,110,32,37,117,46,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,105,110,105,116,32,71,76,32,99,111,110,116,101,120,116,58,32,37,115,46,10,0,0,0,0,75,117,110,103,32,70,117,32,80,97,110,100,97,32,50,32,40,82,117,115,41,0,0,0,109,100,95,107,102,112,97,110,100,97,50,0,0,0,0,0,109,100,95,97,108,105,115,105,97,100,0,0,0,0,0,0,75,111,108,111,98,111,107,32,126,32,80,121,114,97,109,105,100,32,40,82,117,115,41,0,0,0,0,0,0,0,0,0,67,117,115,116,111,109,32,82,97,116,105,111,0,0,0,0,51,48,48,48,0,0,0,0,109,100,95,107,111,108,111,98,111,107,0,0,0,0,0,0,73,114,97,113,32,87,97,114,32,50,48,48,51,32,40,65,108,116,41,0,0,0,0,0,67,104,105,112,37,105,67,111,117,110,116,0,0,0,0,0,37,115,95,119,114,97,109,0,66,111,110,117,115,32,81,117,105,122,0,0,0,0,0,0,110,109,103,53,0,0,0,0,98,97,116,99,105,114,0,0,83,116,114,105,100,101,114,32,40,85,83,32,115,101,116,32,50,41,0,0,0,0,0,0,98,115,116,97,114,115,0,0,109,100,95,105,114,97,113,119,97,114,97,0,0,0,0,0,112,99,101,95,112,99,103,101,110,106,97,0,0,0,0,0,83,112,105,110,32,77,97,115,116,101,114,32,47,32,77,105,114,97,99,108,101,32,65,100,118,101,110,116,117,114,101,0,0,0,0,0,0,0,0,0,73,114,97,113,32,87,97,114,32,50,48,48,51,0,0,0,109,100,95,97,119,111,114,103,0,0,0,0,0,0,0,0,115,115,114,105,100,101,114,115,117,100,97,0,0,0,0,0,76,105,116,116,108,101,32,72,101,114,111,0,0,0,0,0,109,100,95,105,114,97,113,119,97,114,0,0,0,0,0,0,117,99,99,111,112,115,117,0,114,116,121,112,101,50,106,99,0,0,0,0,0,0,0,0,73,110,100,105,97,110,97,32,74,111,110,101,115,32,45,32,75,111,114,105,100,111,114,121,32,86,114,101,109,101,110,105,32,40,82,117,115,41,0,0,120,109,99,111,116,97,97,0,102,98,97,45,99,112,117,45,115,112,101,101,100,45,97,100,106,117,115,116,0,0,0,0,115,99,111,114,112,105,111,110,109,99,0,0,0,0,0,0,109,100,95,114,105,99,107,100,97,110,103,0,0,0,0,0,82,46,67,79,78,70,73,71,0,0,0,0,0,0,0,0,109,100,95,105,110,100,121,114,117,115,0,0,0,0,0,0,84,104,101,32,73,110,99,114,101,100,105,98,108,101,115,32,40,82,117,115,41,0,0,0,109,100,95,105,110,99,114,101,100,105,98,0,0,0,0,0,73,99,101,32,65,103,101,32,52,32,40,82,117,115,41,0,0,0,0,0,0,0,0,0,75,79,78,65,77,73,58,32,85,110,107,110,111,119,110,47,73,110,118,97,108,105,100,32,112,111,115,116,98,121,116,101,32,97,116,32,80,67,32,61,32,37,48,52,120,10,0,0,109,100,95,105,99,101,97,103,101,52,0,0,0,0,0,0,112,97,115,115,0,0,0,0,115,116,114,105,100,101,114,117,97,0,0,0,0,0,0,0,73,99,101,32,65,103,101,32,51,32,40,82,117,115,41,0,0,0,0,0,0,0,0,0,37,48,56,120,58,32,71,52,45,50,32,85,110,100,101,102,105,110,101,100,32,84,104,117,109,98,32,105,110,115,116,114,117,99,116,105,111,110,58,32,37,48,52,120,32,40,37,120,41,10,0,0,0,0,0,0,80,67,32,71,101,110,106,105,110,32,45,32,80,105,116,104,101,99,97,110,116,104,114,111,112,117,115,32,67,111,109,112,117,116,101,114,117,114,117,115,0,0,0,0,0,0,0,0,115,112,105,110,109,97,115,116,0,0,0,0,0,0,0,0,109,100,95,105,99,101,97,103,101,51,0,0,0,0,0,0,110,72,68,54,51,48,57,67,121,99,108,101,115,84,111,116,97,108,0,0,0,0,0,0,65,119,101,115,111,109,101,32,80,111,115,115,117,109,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,0,0,0,73,99,101,32,65,103,101,32,40,82,117,115,41,0,0,0,109,100,95,105,99,101,97,103,101,0,0,0,0,0,0,0,88,45,77,101,110,32,45,32,99,104,105,108,100,114,101,110,32,111,102,32,116,104,101,32,97,116,111,109,32,40,57,53,48,49,48,53,32,69,117,114,111,41,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,114,101,109,111,118,101,32,116,101,109,112,111,114,97,114,121,32,102,105,108,101,58,32,37,115,46,10,0,0,0,0,0,0,83,99,111,114,112,105,111,110,32,40,115,101,116,32,51,41,0,0,0,0,0,0,0,0,72,101,114,99,117,108,101,115,32,50,0,0,0,0,0,0,109,100,95,104,101,114,99,117,108,115,50,0,0,0,0,0,82,45,62,100,0,0,0,0,99,104,105,112,45,62,115,105,103,110,97,108,0,0,0,0,72,97,114,114,121,32,80,111,116,116,101,114,32,97,110,100,32,116,104,101,32,67,104,97,109,98,101,114,32,111,102,32,83,101,99,114,101,116,115,32,40,82,117,115,41,0,0,0,86,97,108,97,100,111,110,32,65,117,116,111,109,97,116,105,111,110,0,0,0,0,0,0,109,100,95,104,112,111,116,116,101,114,50,0,0,0,0,0,73,110,105,116,105,97,108,32,80,111,105,110,116,0,0,0,72,97,114,114,121,32,80,111,116,116,101,114,32,40,82,117,115,41,0,0,0,0,0,0,84,111,97,112,108,97,110,32,66,67,85,45,50,32,47,32,70,67,85,45,50,32,98,97,115,101,100,0,0,0,0,0,109,100,95,104,112,111,116,116,101,114,0,0,0,0,0,0,84,111,97,112,108,97,110,32,71,80,57,48,48,49,32,98,97,115,101,100,0,0,0,0,83,116,114,105,100,101,114,32,40,85,83,32,115,101,116,32,49,41,0,0,0,0,0,0,71,114,97,110,32,84,117,114,105,115,109,111,32,53,32,40,82,117,115,41,0,0,0,0,97,113,117,97,114,105,117,109,0,0,0,0,0,0,0,0,112,99,101,95,112,99,103,101,110,106,0,0,0,0,0,0,80,114,101,104,105,115,116,111,114,105,99,32,73,115,108,101,32,50,0,0,0,0,0,0,109,100,95,103,116,53,0,0,109,100,95,97,119,101,112,111,115,115,109,112,0,0,0,0,70,111,114,115,97,122,104,32,53,32,66,121,115,116,114,97,121,97,32,126,32,70,97,115,116,32,97,110,100,32,116,104,101,32,70,117,114,105,111,117,115,32,53,32,81,117,105,99,107,32,40,82,117,115,41,0,0,0,0,0,0,0,0,0,109,100,95,102,97,115,116,102,117,114,53,0,0,0,0,0,120,109,99,111,116,97,114,49,0,0,0,0,0,0,0,0,70,105,110,100,105,110,103,32,78,101,109,111,32,40,82,117,115,41,0,0,0,0,0,0,115,99,111,114,112,105,111,110,98,0,0,0,0,0,0,0,105,110,102,111,45,62,114,101,118,101,114,98,95,112,111,115,0,0,0,0,0,0,0,0,69,97,114,108,121,32,84,111,97,112,108,97,110,0,0,0,109,100,95,110,101,109,111,0,70,73,70,65,32,87,111,114,108,100,32,67,117,112,32,45,32,83,111,117,116,104,32,65,102,114,105,99,97,32,50,48,49,48,32,40,82,117,115,41,0,0,0,0,0,0,0,0,109,100,95,102,105,102,97,50,107,49,48,0,0,0,0,0,65,116,116,97,99,107,32,98,117,116,116,111,110,32,116,111,32,115,116,97,114,116,0,0,70,73,70,65,32,50,48,48,51,32,40,82,117,115,41,0,0,0,0,0,0,0,0,0,109,100,95,102,105,102,97,50,107,51,0,0,0,0,0,0,103,97,108,97,120,105,97,110,98,108,0,0,0,0,0,0,68,117,97,108,32,84,111,97,112,108,97,110,32,71,80,57,48,48,49,32,98,97,115,101,100,0,0,0,0,0,0,0,115,116,114,105,100,101,114,0,70,73,70,65,32,87,111,114,108,100,32,67,117,112,32,50,48,48,50,32,40,82,117,115,41,0,0,0,0,0,0,0,112,114,101,105,115,108,101,50,0,0,0,0,0,0,0,0,109,100,95,102,105,102,97,50,107,50,0,0,0,0,0,0,65,119,101,115,111,109,101,32,80,111,115,115,117,109,32,40,85,83,65,41,0,0,0,0,68,111,109,105,110,111,32,40,82,117,115,41,0,0,0,0,109,100,95,100,111,109,105,110,111,0,0,0,0,0,0,0,88,45,77,101,110,32,45,32,99,104,105,108,100,114,101,110,32,111,102,32,116,104,101,32,97,116,111,109,32,40,57,53,48,51,51,49,32,69,117,114,111,41,0,0,0,0,0,0,83,99,111,114,112,105,111,110,32,40,115,101,116,32,50,41,0,0,0,0,0,0,0,0,68,105,97,98,108,111,32,40,82,117,115,41,0,0,0,0,109,100,95,100,105,97,98,108,111,0,0,0,0,0,0,0,77,97,116,104,80,97,114,97,109,0,0,0,0,0,0,0,68,101,101,114,32,72,117,110,116,101,114,32,40,82,117,115,41,0,0,0,0,0,0,0,115,117,98,50,109,97,105,110,91,49,93,0,0,0,0,0,98,117,114,103,108,97,114,120,0,0,0,0,0,0,0,0,109,100,95,100,101,101,114,104,117,110,116,0,0,0,0,0,84,111,109,115,111,102,116,0,50,32,67,114,101,100,105,116,115,32,116,111,32,83,116,97,114,116,0,0,0,0,0,0,112,119,114,105,110,115,116,50,0,0,0,0,0,0,0,0,68,101,97,116,104,32,67,97,108,105,98,101,114,32,40,82,117,115,41,0,0,0,0,0,68,97,114,107,101,114,0,0,109,100,95,100,101,97,116,104,99,97,108,0,0,0,0,0,89,117,109,101,107,111,98,111,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,71,69,84,95,82,85,77,66,76,69,95,73,78,84,69,82,70,65,67,69,46,10,0,0,0,0,0,0,0,67,114,97,115,104,32,66,97,110,100,105,99,111,111,116,32,40,82,117,115,41,0,0,0,109,100,95,97,119,101,112,111,115,115,109,0,0,0,0,0,109,100,95,99,114,97,115,104,0,0,0,0,0,0,0,0,71,108,111,114,121,115,117,110,0,0,0,0,0,0,0,0,120,109,99,111,116,97,0,0,115,99,111,114,112,105,111,110,97,0,0,0,0,0,0,0,67,111,117,110,116,101,114,32,83,116,114,105,107,101,32,40,82,117,115,41,0,0,0,0,109,100,95,99,115,116,114,105,107,101,0,0,0,0,0,0,76,97,115,116,32,77,105,115,115,105,111,110,32,40,85,83,32,114,101,118,105,115,105,111,110,32,53,41,0,0,0,0,67,111,109,109,97,110,100,111,115,32,40,82,117,115,41,0,0,0,0,0,0,0,0,0,109,100,95,99,111,109,109,97,110,100,115,0,0,0,0,0,79,109,105,107,117,106,105,32,68,105,102,102,105,99,117,108,116,121,0,0,0,0,0,0,67,111,109,109,97,110,100,32,38,32,67,111,110,113,117,101,114,32,40,80,114,111,116,111,116,121,112,101,41,0,0,0,109,100,95,99,111,109,109,99,111,110,113,0,0,0,0,0,115,104,97,100,102,114,99,101,0,0,0,0,0,0,0,0,76,105,103,104,116,101,114,0,83,97,116,117,114,100,97,121,32,78,105,103,104,116,32,83,108,97,109,32,77,97,115,116,101,114,115,32,40,98,111,111,116,108,101,103,32,40,119,105,116,104,32,80,73,67,49,54,99,53,55,41,44,32,57,51,48,55,49,51,32,101,116,99,41,0,0,0,0,0,0,0,67,104,101,115,115,32,40,82,117,115,44,32,118,49,46,48,53,41,0,0,0,0,0,0,66,108,97,122,105,110,103,32,83,116,97,114,0,0,0,0,109,100,95,99,104,101,115,115,98,0,0,0,0,0,0,0,115,101,114,105,97,108,95,99,111,117,110,116,0,0,0,0,86,97,109,112,105,114,101,32,83,97,118,105,111,114,32,50,32,45,32,116,104,101,32,108,111,114,100,32,111,102,32,118,97,109,112,105,114,101,32,40,57,55,48,57,49,51,32,74,97,112,97,110,41,0,0,0,65,117,115,116,114,97,108,105,97,110,32,82,117,103,98,121,32,76,101,97,103,117,101,32,40,69,117,114,111,41,0,0,115,111,99,98,114,97,119,108,0,0,0,0,0,0,0,0,80,49,32,83,104,111,116,32,40,97,117,116,111,41,0,0,67,104,101,115,115,32,40,82,117,115,44,32,65,108,116,41,0,0,0,0,0,0,0,0,82,97,105,122,105,110,103,0,109,100,95,99,104,101,115,115,97,0,0,0,0,0,0,0,37,115,58,37,115,32,37,105,0,0,0,0,0,0,0,0,89,101,115,0,0,0,0,0,76,111,119,0,0,0,0,0,68,101,98,117,103,32,109,111,100,101,0,0,0,0,0,0,90,97,99,99,97,114,105,97,0,0,0,0,0,0,0,0,66,83,67,111,109,112,0,0,85,83,65,0,0,0,0,0,67,104,101,115,115,32,40,82,117,115,41,0,0,0,0,0,69,117,114,111,112,101,32,40,84,97,105,116,111,32,67,111,114,112,111,114,97,116,105,111,110,32,74,97,112,97,110,41,0,0,0,0,0,0,0,0,118,105,109,97,110,97,95,99,114,101,100,105,116,115,0,0,109,100,95,99,104,101,115,115,0,0,0,0,0,0,0,0,87,111,114,108,100,47,84,97,105,116,111,32,67,111,114,112,0,0,0,0,0,0,0,0,85,83,47,84,111,97,112,108,97,110,0,0,0,0,0,0,84,101,99,84,111,121,0,0,82,111,98,111,99,111,112,32,40,85,83,32,114,101,118,105,115,105,111,110,32,49,41,0,0,0,0,0,0,0,0,0,97,100,100,95,98,97,110,107,0,0,0,0,0,0,0,0,53,32,67,111,105,110,115,32,49,32,67,114,101,100,105,116,115,0,0,0,0,0,0,0,102,105,110,97,108,98,117,0,80,67,77,32,86,111,105,99,101,0,0,0,0,0,0,0,66,111,109,98,101,114,0,0,116,110,122,115,0,0,0,0,49,57,56,63,0,0,0,0,80,108,97,121,101,114,32,83,107,105,110,32,84,111,110,101,0,0,0,0,0,0,0,0,101,110,102,111,114,99,101,106,0,0,0,0,0,0,0,0,84,97,105,116,111,45,70,50,0,0,0,0,0,0,0,0,115,108,97,109,112,105,99,0,109,100,95,98,111,109,98,101,114,0,0,0,0,0,0,0,68,69,67,48,0,0,0,0,114,97,115,116,115,97,103,97,0,0,0,0,0,0,0,0,98,108,97,122,115,116,97,114,0,0,0,0,0,0,0,0,66,101,110,32,49,48,32,40,82,117,115,41,0,0,0,0,65,108,119,97,121,115,32,80,108,97,121,101,114,0,0,0,109,100,95,97,117,115,116,114,97,114,108,0,0,0,0,0,108,111,103,105,99,112,114,111,0,0,0,0,0,0,0,0,109,100,95,98,101,110,49,48,0,0,0,0,0,0,0,0,184,48,0,0,231,48,0,0,184,48,0,0,231,48,0,0,110,48,0,0,32,0,0,0,71,89,0,0,153,89,0,0,106,48,0,0,146,81,0,0,122,150,0,0,0,0,0,0,74,0,0,0,111,0,0,0,74,0,0,0,111,0,0,0,39,0,0,0,115,0,0,0,32,0,0,0,86,0,0,0,101,0,0,0,110,0,0,0,116,0,0,0,117,0,0,0,114,0,0,0,101,0,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,32,0,0,0,57,0,0,0,57,0,0,0,48,0,0,0,49,0,0,0,48,0,0,0,56,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,67,48,50,50,48,73,79,67,73,110,112,117,116,0,0,98,97,121,114,111,117,116,101,0,0,0,0,0,0,0,0,65,118,97,116,97,114,32,40,82,117,115,41,0,0,0,0,118,115,97,118,50,0,0,0,109,121,104,101,114,111,0,0,99,117,115,116,111,109,95,118,105,101,119,112,111,114,116,95,120,0,0,0,0,0,0,0,77,105,110,105,118,97,100,101,114,0,0,0,0,0,0,0,83,99,111,114,112,105,111,110,32,40,115,101,116,32,49,41,0,0,0,0,0,0,0,0,109,100,95,97,118,97,116,97,114,0,0,0,0,0,0,0,83,117,112,101,114,32,77,111,110,97,99,111,32,71,80,32,40,85,83,44,32,82,101,118,32,65,44,32,70,68,49,48,57,52,32,51,49,55,45,48,49,50,53,97,41,0,0,0,81,117,97,114,116,101,116,32,50,32,40,117,110,112,114,111,116,101,99,116,101,100,41,0,0,0,0,0,0,0,0,0,65,115,115,97,115,115,105,110,115,32,67,114,101,101,100,32,40,82,117,115,41,0,0,0,109,100,95,97,115,115,99,114,101,101,100,0,0,0,0,0,45,53,48,48,0,0,0,0,68,121,110,111,32,66,108,97,122,101,32,40,69,97,114,108,121,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,51,48,32,115,101,99,111,110,100,115,0,0,0,0,0,0,109,100,95,100,121,110,111,98,108,97,122,0,0,0,0,0,65,102,101,103,97,32,40,72,101,97,32,68,111,110,103,32,67,111,114,112,32,108,105,99,101,110,115,101,41,0,0,0,51,32,99,111,105,110,115,32,50,32,99,114,101,100,105,116,115,0,0,0,0,0,0,0,86,111,105,110,97,32,73,114,97,107,32,40,80,105,114,97,116,101,41,0,0,0,0,0,65,98,111,118,101,32,65,118,101,114,97,103,101,0,0,0,65,114,107,97,110,111,105,100,0,0,0,0,0,0,0,0,77,117,115,99,108,101,32,66,111,109,98,101,114,32,68,117,111,32,45,32,104,101,97,116,32,117,112,32,119,97,114,114,105,111,114,115,32,40,57,51,49,50,48,54,32,74,97,112,97,110,41,0,0,0,0,0,109,100,95,118,105,114,97,107,0,0,0,0,0,0,0,0,80,97,114,111,100,105,117,115,32,100,97,33,32,45,32,83,104,105,110,119,97,32,75,97,114,97,32,79,119,97,114,97,105,32,72,101,0,0,0,0,84,97,105,116,111,32,67,111,114,112,111,114,97,116,105,111,110,32,47,32,87,97,118,101,0,0,0,0,0,0,0,0,80,117,108,115,116,97,114,0,0,0,0,0,0,0,0,0,65,0,0,0,105,0,0,0,114,0,0,0,32,0,0,0,71,0,0,0,97,0,0,0,108,0,0,0,108,0,0,0,101,0,0,0,116,0,0,0,0,0,0,0,162,48,0,0,239,48,0,0,166,48,0,0,174,48,0,0,227,48,0,0,236,48,0,0,195,48,0,0,200,48,0,0,32,0,0,0,40,0,0,0,85,0,0,0,83,0,0,0,65,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,101,116,114,105,115,32,40,80,105,114,97,116,101,63,41,0,0,0,0,0,0,0,0,65,84,80,32,84,111,117,114,32,67,104,97,109,112,105,111,110,115,104,105,112,32,84,101,110,110,105,115,32,40,85,83,65,41,0,0,0,0,0,0,67,111,105,110,32,99,104,117,116,101,115,0,0,0,0,0,102,105,110,100,95,97,117,100,105,111,95,100,114,105,118,101,114,40,41,0,0,0,0,0,66,117,116,116,111,110,115,0,109,100,95,116,101,116,114,105,115,49,0,0,0,0,0,0,83,117,112,101,114,32,77,97,114,105,111,32,50,32,40,65,108,116,63,41,0,0,0,0,86,97,109,112,105,114,101,32,83,97,118,105,111,114,32,45,32,116,104,101,32,108,111,114,100,32,111,102,32,118,97,109,112,105,114,101,32,40,57,55,48,53,49,57,32,85,83,65,41,0,0,0,0,0,0,0,90,105,110,103,32,90,105,110,103,32,90,105,112,0,0,0,115,99,111,114,112,105,111,110,0,0,0,0,0,0,0,0,109,100,95,115,109,97,114,105,111,50,97,0,0,0,0,0,79,104,109,121,103,111,100,73,110,112,117,116,0,0,0,0,98,99,115,116,114,121,0,0,83,111,117,108,32,69,100,103,101,32,118,115,32,83,97,109,117,114,97,105,32,83,112,105,114,105,116,115,32,40,80,105,114,97,116,101,44,32,67,114,97,99,107,101,100,41,0,0,49,32,99,111,105,110,32,61,32,51,32,99,114,101,100,105,116,115,0,0,0,0,0,0,80,50,32,98,117,116,116,111,110,32,50,0,0,0,0,0,109,100,95,115,111,117,108,101,100,103,101,97,0,0,0,0,97,115,117,114,97,98,108,100,0,0,0,0,0,0,0,0,53,48,107,32,116,104,101,110,32,101,118,101,114,121,32,57,48,107,0,0,0,0,0,0,84,67,48,53,49,48,78,73,79,73,110,112,117,116,0,0,83,111,117,108,32,69,100,103,101,32,118,115,32,83,97,109,117,114,97,105,32,83,112,105,114,105,116,115,32,40,80,105,114,97,116,101,41,0,0,0,115,98,98,114,111,115,0,0,70,103,83,99,114,111,108,108,88,91,105,93,0,0,0,0,65,32,49,67,47,50,67,32,66,32,49,67,47,54,67,0,68,101,109,111,32,83,111,117,110,100,32,79,102,102,0,0,109,100,95,115,111,117,108,101,100,103,101,0,0,0,0,0,98,117,99,97,110,101,114,0,71,97,117,110,116,108,101,116,32,73,73,0,0,0,0,0,83,111,110,105,99,32,74,97,109,32,54,32,40,72,97,99,107,101,100,63,41,0,0,0,83,112,101,99,105,97,108,32,99,111,105,110,0,0,0,0,51,48,75,32,97,110,100,32,55,48,75,32,111,110,108,121,0,0,0,0,0,0,0,0,53,48,75,32,49,53,48,75,32,101,118,101,114,121,32,50,48,48,75,0,0,0,0,0,109,98,111,109,98,114,100,106,0,0,0,0,0,0,0,0,109,100,95,115,111,110,105,99,106,97,109,50,0,0,0,0,112,101,115,116,112,108,99,101,0,0,0,0,0,0,0,0,68,105,97,103,110,111,115,116,105,99,115,32,50,0,0,0,112,99,101,95,112,97,114,111,100,105,117,115,0,0,0,0,84,97,105,116,111,45,90,0,84,67,48,54,52,48,70,73,79,73,110,112,117,116,80,111,114,116,52,0,0,0,0,0,77,97,103,105,115,116,114,32,49,54,32,40,82,117,115,41,0,0,0,0,0,0,0,0,109,100,95,97,116,112,116,111,117,114,117,0,0,0,0,0,49,67,95,54,67,0,0,0,80,50,32,66,117,116,116,111,110,0,0,0,0,0,0,0,109,100,95,109,97,103,105,115,116,49,54,0,0,0,0,0,67,117,114,114,101,110,116,67,109,100,0,0,0,0,0,0,83,117,112,101,114,32,84,114,105,118,32,40,115,101,116,32,50,41,0,0,0,0,0,0,77,97,103,105,99,32,66,117,98,98,108,101,32,40,80,105,114,97,116,101,41,0,0,0,118,115,97,118,117,0,0,0,49,50,48,75,32,49,50,48,75,43,0,0,0,0,0,0,115,114,100,109,105,115,115,110,0,0,0,0,0,0,0,0,65,109,101,110,105,112,32,40,85,83,32,66,105,108,108,105,97,114,100,115,32,73,110,99,46,32,108,105,99,101,110,115,101,41,0,0,0,0,0,0,109,100,95,109,98,117,98,98,108,101,0,0,0,0,0,0,49,32,80,108,97,121,101,114,32,71,97,109,101,32,84,105,109,101,0,0,0,0,0,0,76,105,111,110,32,75,105,110,103,32,51,32,40,65,108,116,32,50,63,41,0,0,0,0,50,48,107,32,32,54,48,107,0,0,0,0,0,0,0,0,86,105,100,101,111,32,82,69,71,0,0,0,0,0,0,0,51,48,48,48,48,32,57,48,48,48,48,32,49,50,48,48,48,48,0,0,0,0,0,0,109,100,95,108,105,111,110,107,105,110,51,98,0,0,0,0,97,115,105,99,51,95,104,111,108,100,0,0,0,0,0,0,76,105,111,110,32,75,105,110,103,32,51,32,40,65,108,116,63,41,0,0,0,0,0,0,70,114,97,109,101,98,117,102,102,101,114,32,82,65,77,0,109,100,95,108,105,111,110,107,105,110,51,97,0,0,0,0,106,99,104,97,110,0,0,0,100,100,114,66,0,0,0,0,75,46,79,46,70,32,50,48,48,48,0,0,0,0,0,0,66,97,114,105,32,66,97,114,105,32,68,101,110,115,101,116,115,117,0,0,0,0,0,0,109,100,95,107,111,102,50,107,0,0,0,0,0,0,0,0,77,117,115,99,108,101,32,66,111,109,98,101,114,32,68,117,111,32,45,32,117,108,116,105,109,97,116,101,32,116,101,97,109,32,98,97,116,116,108,101,32,40,57,51,49,50,48,54,32,101,116,99,41,0,0,0,118,100,99,95,119,105,100,116,104,91,105,93,0,0,0,0,99,97,119,105,110,103,106,0,80,97,114,97,115,111,108,32,83,116,97,114,115,32,45,32,84,104,101,32,83,116,111,114,121,32,111,102,32,66,117,98,98,108,101,32,66,111,98,98,108,101,32,73,73,73,0,0,192,150,0,0,94,121,0,0,29,79,0,0,172,138,0,0,32,0,0,0,45,0,0,0,32,0,0,0,113,0,0,0,117,0,0,0,101,0,0,0,115,0,0,0,116,0,0,0,32,0,0,0,111,0,0,0,102,0,0,0,32,0,0,0,106,0,0,0,111,0,0,0,110,0,0,0,103,0,0,0,109,0,0,0,97,0,0,0,115,0,0,0,116,0,0,0,101,0,0,0,114,0,0,0,0,0,0,0,74,0,0,0,121,0,0,0,97,0,0,0,110,0,0,0,115,0,0,0,104,0,0,0,105,0,0,0,110,0,0,0,32,0,0,0,68,0,0,0,101,0,0,0,110,0,0,0,115,0,0,0,101,0,0,0,116,0,0,0,115,0,0,0,117,0,0,0,0,0,0,0,0,0,0,0,78,101,111,73,110,112,117,116,66,97,110,107,0,0,0,0,68,117,107,101,32,78,117,107,101,109,32,51,68,32,40,80,105,114,97,116,101,41,0,0,65,84,80,32,84,111,117,114,32,67,104,97,109,112,105,111,110,115,104,105,112,32,84,101,110,110,105,115,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,57,48,56,41,0,0,0,0,0,0,109,100,95,100,117,107,101,110,107,51,100,97,0,0,0,0,85,108,116,105,109,97,116,101,32,83,111,99,99,101,114,32,40,69,117,114,111,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,0,86,97,109,112,105,114,101,32,83,97,118,105,111,114,32,45,32,116,104,101,32,108,111,114,100,32,111,102,32,118,97,109,112,105,114,101,32,40,57,55,48,53,49,57,32,74,97,112,97,110,41,0,0,0,0,0,79,80,76,45,62,109,111,100,101,0,0,0,0,0,0,0,84,97,105,116,111,45,88,0,109,99,117,95,99,111,105,110,97,103,101,91,50,93,0,0,70,103,83,99,114,111,108,108,88,0,0,0,0,0,0,0,56,48,48,32,70,97,116,104,111,109,115,0,0,0,0,0,109,100,95,117,108,116,115,111,99,99,114,112,0,0,0,0,35,118,101,114,115,105,111,110,32,37,117,10,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,98,105,110,100,32,65,80,73,32,37,115,32,116,111,32,99,111,110,116,101,120,116,32,37,115,46,10,0,0,0,0,0,0,85,110,107,110,111,119,110,32,71,97,109,101,32,50,32,40,82,111,99,107,109,97,110,45,114,101,108,97,116,101,100,63,41,0,0,0,0,0,0,0,109,100,95,117,110,107,110,111,119,110,50,0,0,0,0,0,65,108,101,120,32,75,105,100,100,32,105,110,32,116,104,101,32,69,110,99,104,97,110,116,101,100,32,67,97,115,116,108,101,32,40,69,117,114,111,44,32,82,101,118,46,32,65,41,0,0,0,0,0,0,0,0,84,67,32,50,48,48,48,32,40,65,114,103,41,0,0,0,65,115,112,101,99,116,32,82,97,116,105,111,0,0,0,0,67,97,110,99,101,108,32,112,101,114,32,99,114,101,100,105,116,0,0,0,0,0,0,0,109,100,95,116,99,50,48,48,48,0,0,0,0,0,0,0,51,48,48,48,48,32,50,48,48,48,48,48,0,0,0,0,77,105,107,121,0,0,0,0,37,115,95,115,101,109,97,110,116,105,99,0,0,0,0,0,65,108,105,101,110,32,118,115,32,80,114,101,100,97,116,111,114,32,40,57,52,48,53,50,48,32,85,83,65,41,0,0,79,117,116,32,82,117,110,0,109,98,111,109,98,114,100,0,84,114,117,99,111,32,39,57,54,32,40,65,114,103,41,0,0,0,0,0,0,0,0,0,53,32,40,65,118,101,114,97,103,101,41,0,0,0,0,0,68,105,97,103,110,111,115,116,105,99,115,32,49,0,0,0,112,99,101,95,112,97,114,97,115,111,108,0,0,0,0,0,109,100,95,116,114,117,99,111,57,54,0,0,0,0,0,0,109,100,95,97,116,112,116,111,117,114,112,49,0,0,0,0,83,117,110,115,101,116,32,82,105,100,101,114,115,32,40,50,32,80,108,97,121,101,114,115,32,118,101,114,46,32,69,66,67,41,0,0,0,0,0,0,98,108,109,98,121,99,97,114,0,0,0,0,0,0,0,0,115,108,45,62,101,103,95,115,101,108,95,114,114,0,0,0,71,97,109,116,101,99,0,0,85,110,100,101,114,99,111,118,101,114,32,67,111,112,115,32,40,87,111,114,108,100,41,0,0,0,0,0,0,0,0,0,82,45,84,121,112,101,32,73,73,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,66,111,109,98,111,121,32,40,84,119,41,0,0,0,0,0,118,115,97,118,106,0,0,0,56,48,48,102,97,116,104,0,109,100,95,98,111,109,98,111,121,0,0,0,0,0,0,0,83,117,112,101,114,32,68,111,110,107,101,121,32,75,111,110,103,32,57,57,32,40,85,110,112,114,111,116,101,99,116,101,100,41,0,0,0,0,0,0,109,100,95,115,100,107,111,110,103,57,57,97,0,0,0,0,83,104,105,32,90,105,32,87,97,110,103,32,73,73,32,45,32,76,105,111,110,32,75,105,110,103,32,73,73,32,40,80,105,114,97,116,101,44,32,72,97,99,107,101,100,63,41,0,0,0,0,0,0,0,0,0,109,100,95,108,105,111,110,107,105,110,50,97,0,0,0,0,83,121,115,116,101,109,32,49,54,66,0,0,0,0,0,0,75,46,79,46,70,32,57,56,39,32,40,85,110,112,114,111,116,101,99,116,101,100,63,41,0,0,0,0,0,0,0,0,80,49,32,89,32,65,120,105,115,0,0,0,0,0,0,0,77,117,115,99,108,101,32,66,111,109,98,101,114,32,45,32,116,104,101,32,98,111,100,121,32,101,120,112,108,111,115,105,111,110,32,40,57,51,48,55,49,51,32,74,97,112,97,110,41,0,0,0,0,0,0,0,109,100,95,107,111,102,57,56,97,0,0,0,0,0,0,0,83,121,115,116,101,109,49,54,83,111,117,110,100,76,97,116,99,104,0,0,0,0,0,0,80,97,114,97,110,111,105,97,0,0,0,0,0,0,0,0,67,80,83,45,51,0,0,0,74,121,97,110,115,104,105,110,32,68,101,110,115,101,116,115,117,32,45,32,81,117,101,115,116,32,111,102,32,74,111,110,103,109,97,115,116,101,114,0,0,0,0,0,0,0,0,0,67,104,105,110,101,115,101,32,70,105,103,104,116,101,114,32,73,73,73,32,40,67,104,105,44,32,85,110,112,114,111,116,101,99,116,101,100,63,41,0,0,0,0,0,0,0,0,0,65,84,80,32,84,111,117,114,32,67,104,97,109,112,105,111,110,115,104,105,112,32,84,101,110,110,105,115,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,53,48,57,41,0,0,0,0,0,0,110,67,97,118,101,83,112,114,105,116,101,66,97,110,107,68,101,108,97,121,0,0,0,0,109,100,95,99,104,105,110,102,51,97,0,0,0,0,0,0,82,97,100,105,99,97,32,71,97,109,101,115,32,126,32,67,97,112,99,111,109,0,0,0,86,97,109,112,105,114,101,32,83,97,118,105,111,114,32,45,32,116,104,101,32,108,111,114,100,32,111,102,32,118,97,109,112,105,114,101,32,40,57,55])
.concat([48,53,49,57,32,72,105,115,112,97,110,105,99,41,0,0,82,101,116,114,111,65,114,99,104,58,32,82,101,109,111,118,105,110,103,32,116,101,109,112,111,114,97,114,121,32,82,79,77,32,102,105,108,101,58,32,37,115,46,10,0,0,0,0,65,114,109,101,110,105,112,0,82,97,100,105,99,97,58,32,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,80,97,99,107,32,40,69,117,114,111,41,0,0,0,0,0,0,109,100,95,114,97,100,105,99,97,115,102,0,0,0,0,0,82,97,100,105,99,97,32,71,97,109,101,115,32,126,32,83,101,103,97,0,0,0,0,0,100,114,103,110,109,115,116,0,82,97,100,105,99,97,58,32,86,111,108,117,109,101,32,49,32,40,85,83,65,41,0,0,83,121,115,116,101,109,32,49,0,0,0,0,0,0,0,0,109,100,95,114,97,100,105,99,97,118,49,0,0,0,0,0,109,98,111,109,98,101,114,106,0,0,0,0,0,0,0,0,87,104,97,99,45,97,45,67,114,105,116,116,101,114,32,40,85,83,65,41,0,0,0,0,83,121,115,116,101,109,32,49,56,0,0,0,0,0,0,0,112,99,101,95,112,97,114,97,110,111,105,97,0,0,0,0,84,101,115,116,32,72,97,114,100,119,97,114,101,0,0,0,82,105,103,104,116,32,97,110,97,108,111,103,32,88,43,32,40,114,105,103,104,116,41,0,109,100,95,119,104,97,99,97,99,114,105,0,0,0,0,0,109,100,95,97,116,112,116,111,117,114,112,55,0,0,0,0,84,111,112,32,70,105,103,104,116,101,114,32,50,48,48,53,0,0,0,0,0,0,0,0,67,97,118,101,0,0,0,0,89,45,66,111,97,114,100,0,109,100,95,116,111,112,102,50,107,53,0,0,0,0,0,0,118,115,97,118,104,0,0,0,77,97,114,105,110,101,114,0,0,0,0,0,0,0,0,0,84,111,112,32,70,105,103,104,116,101,114,32,50,48,48,48,32,77,75,32,86,73,73,73,0,0,0,0,0,0,0,0,109,100,95,116,111,112,102,105,103,104,116,0,0,0,0,0,88,45,66,111,97,114,100,0,84,104,101,32,66,97,116,116,108,101,32,111,102,32,82,101,100,32,67,108,105,102,102,115,32,45,32,82,111,109,97,110,99,101,32,111,102,32,116,104,101,32,84,104,114,101,101,32,75,105,110,103,100,111,109,115,32,40,72,97,99,107,101,100,32,111,117,116,32,80,114,111,116,101,99,116,105,111,110,63,41,0,0,0,0,0,0,0,109,100,95,114,101,100,99,108,105,102,102,97,0,0,0,0,84,104,101,32,66,97,116,116,108,101,32,111,102,32,82,101,100,32,67,108,105,102,102,115,32,45,32,82,111,109,97,110,99,101,32,111,102,32,116,104,101,32,84,104,114,101,101,32,75,105,110,103,100,111,109,115,0,0,0,0,0,0,0,0,86,100,112,83,99,114,111,108,108,65,66,97,115,101,0,0,109,100,95,114,101,100,99,108,105,102,102,0,0,0,0,0,80,49,32,88,32,65,120,105,115,0,0,0,0,0,0,0,83,97,116,117,114,100,97,121,32,78,105,103,104,116,32,83,108,97,109,32,77,97,115,116,101,114,115,32,40,115,108,97,109,32,109,97,115,116,101,114,115,32,57,51,48,55,49,51,32,85,83,65,41,0,0,0,83,117,112,101,114,32,77,97,114,105,111,32,87,111,114,108,100,32,126,32,83,117,112,101,114,32,77,97,114,105,111,32,66,114,111,115,46,32,40,80,105,114,97,116,101,41,0,0,80,97,99,104,105,111,32,75,117,110,32,45,32,74,117,117,98,97,110,32,83,104,111,117,98,117,0,0,0,0,0,0,83,97,109,109,121,32,47,32,65,105,99,111,109,0,0,0,83,117,112,101,114,32,77,97,114,105,111,32,50,32,49,57,57,56,0,0,0,0,0,0,65,84,80,32,84,111,117,114,32,67,104,97,109,112,105,111,110,115,104,105,112,32,84,101,110,110,105,115,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,55,50,51,41,0,0,0,0,0,0,109,100,95,115,109,97,114,105,111,50,0,0,0,0,0,0,83,117,112,101,114,32,75,105,110,103,32,75,111,110,103,32,57,57,0,0,0,0,0,0,86,97,109,112,105,114,101,32,83,97,118,105,111,114,32,45,32,116,104,101,32,108,111,114,100,32,111,102,32,118,97,109,112,105,114,101,32,40,57,55,48,53,49,57,32,65,115,105,97,41,0,0,0,0,0,0,109,97,114,105,110,101,114,0,109,100,95,115,107,107,111,110,103,57,57,0,0,0,0,0,72,97,110,103,45,79,110,0,83,117,112,101,114,32,68,111,110,107,101,121,32,75,111,110,103,32,57,57,32,40,80,114,111,116,101,99,116,101,100,41,0,0,0,0,0,0,0,0,73,110,77,97,116,104,0,0,109,100,95,115,100,107,111,110,103,57,57,0,0,0,0,0,109,105,115,99,0,0,0,0,83,117,112,101,114,32,66,117,98,98,108,101,32,66,111,98,98,108,101,32,77,68,32,40,67,104,105,41,0,0,0,0,109,100,95,115,117,112,114,98,117,98,108,0,0,0,0,0,83,117,112,101,114,32,49,57,32,105,110,32,49,32,40,80,105,114,97,116,101,41,0,0,75,97,110,101,107,111,49,54,0,0,0,0,0,0,0,0,115,108,97,109,109,97,115,116,117,0,0,0,0,0,0,0,109,100,95,115,49,57,105,110,49,0,0,0,0,0,0,0,112,99,101,95,112,97,99,104,105,107,117,110,0,0,0,0,86,105,101,119,112,111,105,110,116,0,0,0,0,0,0,0,118,115,97,118,97,0,0,0,83,117,112,101,114,32,49,53,32,105,110,32,49,32,40,80,105,114,97,116,101,41,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,70,82,65,77,69,95,84,73,77,69,95,67,65,76,76,66,65,67,75,46,10,0,0,0,0,109,100,95,97,116,112,116,111,117,114,112,53,0,0,0,0,109,100,95,115,49,53,105,110,49,0,0,0,0,0,0,0,83,113,117,105,114,114,101,108,32,75,105,110,103,32,40,67,104,105,41,0,0,0,0,0,75,110,111,99,107,32,79,117,116,33,33,0,0,0,0,0,109,100,95,115,113,117,105,114,114,101,108,0,0,0,0,0,83,111,117,108,32,66,108,97,100,101,32,40,65,108,116,41,0,0,0,0,0,0,0,0,108,97,115,116,109,105,115,110,111,0,0,0,0,0,0,0,109,100,95,115,111,117,108,98,108,97,100,97,0,0,0,0,83,111,117,108,32,66,108,97,100,101,0,0,0,0,0,0,109,100,95,115,111,117,108,98,108,97,100,0,0,0,0,0,82,111,99,107,109,97,110,32,88,51,0,0,0,0,0,0,83,97,116,117,114,100,97,121,32,78,105,103,104,116,32,83,108,97,109,32,77,97,115,116,101,114,115,32,40,83,108,97,109,32,77,97,115,116,101,114,115,32,57,51,48,55,49,51,32,101,116,99,41,0,0,0,109,100,95,114,111,99,107,109,110,120,51,0,0,0,0,0,80,97,99,45,108,97,110,100,0,0,0,0,0,0,0,0,66,101,103,105,110,110,105,110,103,32,111,102,32,83,116,97,103,101,0,0,0,0,0,0,80,111,107,101,109,111,110,32,83,116,97,100,105,117,109,0,0,0,0,0,0,0,0,0,65,84,80,32,84,111,117,114,32,67,104,97,109,112,105,111,110,115,104,105,112,32,84,101,110,110,105,115,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,55,49,57,41,0,0,0,0,0,0,80,49,32,83,104,111,116,0,109,100,95,112,111,107,101,115,116,97,100,0,0,0,0,0,77,97,32,74,105,97,110,103,32,81,105,110,103,32,82,101,110,32,45,32,74,105,32,77,97,32,74,105,97,110,103,32,90,104,105,32,40,67,104,105,44,32,65,108,116,41,0,0,86,97,109,112,105,114,101,32,83,97,118,105,111,114,32,45,32,116,104,101,32,108,111,114,100,32,111,102,32,118,97,109,112,105,114,101,32,40,57,55,48,53,49,57,32,69,117,114,111,41,0,0,0,0,0,0,65,108,108,111,119,32,67,111,110,116,105,110,117,101,0,0,84,105,109,101,114,32,114,97,110,107,0,0,0,0,0,0,78,111,114,109,97,108,32,103,97,109,101,0,0,0,0,0,107,110,111,99,107,111,117,116,0,0,0,0,0,0,0,0,109,100,95,109,97,106,105,97,110,97,0,0,0,0,0,0,69,117,114,111,112,101,32,40,78,111,118,97,32,65,112,112,97,114,97,116,101,32,71,77,66,72,32,38,32,67,111,41,0,0,0,0,0,0,0,0,70,111,114,0,0,0,0,0,77,97,32,74,105,97,110,103,32,81,105,110,103,32,82,101,110,32,45,32,74,105,32,77,97,32,74,105,97,110,103,32,90,104,105,32,40,67,104,105,41,0,0,0,0,0,0,0,122,101,114,111,112,110,116,0,83,104,111,119,32,84,101,114,114,105,116,111,114,121,32,78,111,116,105,99,101,0,0,0,109,100,95,109,97,106,105,97,110,0,0,0,0,0,0,0,85,83,47,82,111,109,115,116,97,114,0,0,0,0,0,0,87,111,114,108,100,47,84,97,105,116,111,32,74,97,112,97,110,0,0,0,0,0,0,0,114,111,98,111,99,111,112,117,0,0,0,0,0,0,0,0,76,105,111,110,32,75,105,110,103,32,51,0,0,0,0,0,54,32,67,111,105,110,115,32,49,32,67,114,101,100,105,116,115,0,0,0,0,0,0,0,70,105,110,97,108,32,66,108,111,119,32,40,74,97,112,97,110,41,0,0,0,0,0,0,109,100,95,108,105,111,110,107,105,110,51,0,0,0,0,0,68,101,110,105,97,109,45,49,54,98,32,72,97,114,100,119,97,114,101,0,0,0,0,0,115,101,116,116,105,110,103,115,46,99,0,0,0,0,0,0,67,104,117,107,97,32,84,97,105,115,101,110,32,40,74,97,112,97,110,41,0,0,0,0,116,101,116,114,115,97,114,107,0,0,0,0,0,0,0,0,83,104,105,32,90,105,32,87,97,110,103,32,73,73,32,45,32,76,105,111,110,32,75,105,110,103,32,73,73,0,0,0,97,115,104,117,114,97,0,0,70,117,117,107,105,0,0,0,69,110,102,111,114,99,101,32,40,87,111,114,108,100,41,0,0,0,0,0,0,0,0,0,115,108,97,109,109,97,115,116,0,0,0,0,0,0,0,0,109,100,95,108,105,111,110,107,105,110,50,0,0,0,0,0,82,97,115,116,97,110,32,40,85,83,44,32,69,97,114,108,105,101,114,32,99,111,100,101,32,98,97,115,101,41,0,0,112,99,101,95,112,97,99,108,97,110,100,0,0,0,0,0,90,0,0,0,105,0,0,0,110,0,0,0,116,0,0,0,114,0,0,0,105,0,0,0,99,0,0,0,107,0,0,0,0,0,0,0,188,98,0,0,87,48,0,0,250,81,0,0,87,48,0,0,184,48,0,0,243,48,0,0,200,48,0,0,234,48,0,0,195,48,0,0,175,48,0,0,32,0,0,0,40,0,0,0,104,0,0,0,97,0,0,0,99,0,0,0,107,0,0,0,32,0,0,0,47,0,0,0,32,0,0,0,98,0,0,0,111,0,0,0,111,0,0,0,116,0,0,0,108,0,0,0,101,0,0,0,103,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,116,104,97,114,114,105,101,114,0,0,0,0,0,0,0,0,76,105,110,103,104,117,97,110,32,68,97,111,115,104,105,32,83,117,112,101,114,32,77,97,103,105,99,105,97,110,32,40,67,104,105,41,0,0,0,0,77,97,103,105,99,32,69,110,101,114,103,121,32,76,111,115,115,0,0,0,0,0,0,0,109,100,95,97,116,112,116,111,117,114,112,54,0,0,0,0,49,32,67,111,105,110,32,32,49,32,67,114,101,100,105,116,32,53,47,54,0,0,0,0,109,100,95,115,117,112,109,97,103,105,99,0,0,0,0,0,74,111,74,111,39,115,32,86,101,110,116,117,114,101,32,47,32,74,111,74,111,32,110,111,32,75,105,109,121,111,117,32,110,97,32,66,111,117,107,101,110,32,40,74,97,112,97,110,32,57,57,48,49,48,56,41,0,0,0,0,0,0,0,0,65,117,114,97,105,108,32,40,115,101,116,32,49,44,32,74,97,112,97,110,44,32,70,68,49,48,56,57,65,32,51,49,55,45,48,49,54,55,41,0,0,0,0,0,0,0,0,0,84,104,101,32,75,105,110,103,32,111,102,32,70,105,103,104,116,101,114,115,32,39,57,57,32,40,65,108,116,41,0,0,118,115,97,118,0,0,0,0,77,105,115,99,0,0,0,0,77,105,115,116,101,114,32,86,105,107,105,110,103,32,40,51,49,53,45,53,48,52,49,44,32,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,115,104,100,97,110,99,101,114,0,0,0,0,0,0,0,0,52,32,116,111,32,115,116,97,114,116,44,32,51,32,116,111,32,99,111,110,116,105,110,117,101,0,0,0,0,0,0,0,75,75,75,0,0,0,0,0,109,100,95,107,111,102,57,57,97,0,0,0,0,0,0,0,115,109,103,112,117,50,0,0,113,117,97,114,116,101,116,50,97,0,0,0,0,0,0,0,84,104,101,32,75,105,110,103,32,111,102,32,70,105,103,104,116,101,114,115,32,39,57,57,0,0,0,0,0,0,0,0,109,100,95,107,111,102,57,57,0,0,0,0,0,0,0,0,72,105,103,104,45,76,111,119,32,69,114,114,111,114,0,0,75,46,79,46,70,32,57,56,39,0,0,0,0,0,0,0,78,77,75,49,54,0,0,0,71,114,101,121,0,0,0,0,109,100,95,107,111,102,57,56,0,0,0,0,0,0,0,0,52,32,112,108,97,121,101,114,115,0,0,0,0,0,0,0,82,101,100,32,72,97,119,107,32,40,73,116,97,108,121,41,0,0,0,0,0,0,0,0,116,117,114,107,104,117,110,116,0,0,0,0,0,0,0,0,72,117,97,110,32,76,101,32,84,97,111,32,81,105,32,83,104,117,32,45,32,83,109,97,114,116,32,77,111,117,115,101,32,40,67,104,105,41,0,0,67,80,83,32,67,104,97,110,103,101,114,0,0,0,0,0,109,100,95,104,117,97,110,108,101,0,0,0,0,0,0,0,104,97,99,107,32,47,32,98,111,111,116,108,101,103,0,0,65,105,114,32,71,97,108,108,101,116,32,40,85,83,65,41,0,0,0,0,0,0,0,0,72,117,97,32,77,117,32,76,97,110,32,45,32,77,117,108,97,110,32,40,67,104,105,41,0,0,0,0,0,0,0,0,65,84,80,32,84,111,117,114,32,67,104,97,109,112,105,111,110,115,104,105,112,32,84,101,110,110,105,115,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,56,48,56,41,0,0,0,0,0,0,65,118,97,105,108,97,98,108,101,32,97,117,100,105,111,32,100,114,105,118,101,114,115,32,97,114,101,58,10,0,0,0,109,100,95,104,117,97,109,117,108,0,0,0,0,0,0,0,49,32,99,111,105,110,115,32,54,32,99,114,101,100,105,116,0,0,0,0,0,0,0,0,77,111,114,101,32,83,116,97,103,101,32,67,108,101,97,114,32,69,110,101,114,103,121,0,78,101,119,101,114,32,83,101,116,97,0,0,0,0,0,0,71,111,108,100,101,110,32,49,48,32,105,110,32,49,32,40,73,110,99,111,109,112,108,101,116,101,32,68,117,109,112,41,0,0,0,0,0,0,0,0,86,97,109,112,105,114,101,32,72,117,110,116,101,114,32,50,32,45,32,100,97,114,107,115,116,97,108,107,101,114,115,32,114,101,118,101,110,103,101,32,40,57,55,48,57,49,51,32,74,97,112,97,110,41,0,0,122,105,110,103,122,105,112,0,84,114,105,112,108,101,32,80,117,110,99,104,32,40,115,101,116,32,50,41,0,0,0,0,109,100,95,103,111,108,100,101,110,49,48,0,0,0,0,0,115,110,111,119,98,114,111,115,0,0,0,0,0,0,0,0,51,255,0,0,36,255,0,0,32,0,0,0,12,211,0,0,116,199,0,0,48,209,0,0,136,201,0,0,32,0,0,0,40,0,0,0,75,0,0,0,111,0,0,0,114,0,0,0,101,0,0,0,97,0,0,0,41,0,0,0,0,0,0,0,83,0,0,0,68,0,0,0,32,0,0,0,70,0,0,0,105,0,0,0,103,0,0,0,104,0,0,0,116,0,0,0,101,0,0,0,114,0,0,0,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,70,117,110,110,121,32,87,111,114,108,100,32,38,32,66,97,108,108,111,111,110,32,66,111,121,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,49,32,99,111,105,110,32,61,32,50,32,99,114,101,100,105,116,115,0,0,0,0,0,0,109,100,95,102,117,110,110,121,119,108,100,0,0,0,0,0,114,97,105,100,101,110,0,0,53,48,107,32,116,104,101,110,32,101,118,101,114,121,32,54,48,107,0,0,0,0,0,0,82,101,97,108,116,101,99,0,83,117,112,101,114,32,80,97,110,103,32,40,74,97,112,97,110,32,57,48,49,48,50,51,41,0,0,0,0,0,0,0,65,32,49,67,47,50,67,32,66,32,49,67,47,53,67,0,84,104,101,32,69,97,114,116,104,32,68,101,102,101,110,115,101,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,89,117,110,32,83,117,110,103,32,49,54,32,66,105,116,0,74,111,121,109,97,110,0,0,109,100,95,101,97,114,116,104,100,101,102,0,0,0,0,0,69,110,101,109,105,101,115,32,110,117,109,98,101,114,32,38,32,115,112,101,101,100,0,0,50,48,75,32,97,110,100,32,54,48,75,32,111,110,108,121,0,0,0,0,0,0,0,0,51,48,107,32,32,50,48,48,107,0,0,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,90,101,114,111,32,40,67,80,83,32,67,104,97,110,103,101,114,44,32,57,53,49,48,50,48,32,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,67,104,105,110,101,115,101,32,70,105,103,104,116,101,114,32,73,73,73,32,40,67,104,105,41,0,0,0,0,0,0,0,80,45,52,55,32,45,32,84,104,101,32,70,114,101,101,100,111,109,32,70,105,103,104,116,101,114,0,0,0,0,0,0,90,105,110,116,114,105,99,107,32,47,32,79,115,104,105,100,97,115,104,105,32,90,101,110,116,114,105,120,32,40,104,97,99,107,32,47,32,98,111,111,116,108,101,103,41,0,0,0,50,48,48,48,48,32,54,48,48,48,48,0,0,0,0,0,109,100,95,99,104,105,110,102,51,0,0,0,0,0,0,0,109,100,95,97,116,112,116,111,117,114,112,50,0,0,0,0,65,32,66,117,103,39,115,32,76,105,102,101,32,40,65,108,116,63,41,0,0,0,0,0,115,116,114,105,118,50,0,0,109,100,95,98,117,103,115,108,105,102,101,97,0,0,0,0,118,104,117,110,116,50,114,49,0,0,0,0,0,0,0,0,49,50,48,75,32,49,48,48,75,43,0,0,0,0,0,0,39,57,57,58,32,84,104,101,32,76,97,115,116,32,87,97,114,32,40,75,121,117,103,111,41,0,0,0,0,0,0,0,56,32,67,111,105,110,115,32,51,32,80,108,97,121,115,0,116,114,105,112,108,101,112,97,0,0,0,0,0,0,0,0,65,32,66,117,103,39,115,32,76,105,102,101,0,0,0,0,52,48,107,32,111,110,108,121,0,0,0,0,0,0,0,0,109,100,95,98,117,103,115,108,105,102,101,0,0,0,0,0,50,48,48,48,48,32,56,48,48,48,48,32,49,48,48,48,48,48,0,0,0,0,0,0,52,32,105,110,32,49,32,40,80,105,114,97,116,101,41,0,0,0,0,0,0,0,0,0,50,32,67,111,105,110,115,32,50,32,80,108,97,121,115,0,97,115,105,99,51,95,104,50,0,0,0,0,0,0,0,0,109,100,95,52,105,110,49,112,98,0,0,0,0,0,0,0,49,50,32,105,110,32,49,0,0,0,0,0,0,0,0,0,109,100,95,49,50,105,110,49,0,0,0,0,0,0,0,0,115,102,122,99,104,0,0,0,83,101,103,97,32,67,104,97,110,110,101,108,32,68,101,109,111,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,67,97,114,114,105,101,114,32,65,105,114,32,87,105,110,103,32,40,85,46,83,46,32,110,97,118,121,32,57,48,49,48,49,50,32,85,83,65,41,0,0,0,0,0,0,0,0,0,112,99,101,95,112,52,55,0,122,105,110,116,114,99,107,98,0,0,0,0,0,0,0,0,75,105,110,103,32,111,102,32,116,104,101,32,77,111,110,115,116,101,114,115,32,40,115,101,116,32,50,41,0,0,0,0,110,73,110,112,117,116,83,101,108,101,99,116,0,0,0,0,109,100,95,115,101,103,97,99,104,100,0,0,0,0,0,0,65,84,80,32,84,111,117,114,32,67,104,97,109,112,105,111,110,115,104,105,112,32,84,101,110,110,105,115,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,56,48,53,41,0,0,0,0,0,0,83,101,103,97,32,67,104,97,110,110,101,108,32,40,71,101,110,101,114,97,108,32,73,110,115,116,114,117,109,101,110,116,41,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,109,100,95,115,101,103,97,99,104,110,108,97,0,0,0,0,70,105,110,97,108,32,83,116,97,114,32,70,111,114,99,101,32,40,85,83,41,0,0,0,103,97,105,97,0,0,0,0,86,97,109,112,105,114,101,32,72,117,110,116,101,114,32,50,32,45,32,100,97,114,107,115,116,97,108,107,101,114,115,32,114,101,118,101,110,103,101,32,40,57,55,48,57,50,57,32,74,97,112,97,110,41,0,0,79,80,76,45,62,115,116,97,116,117,115,109,97,115,107,0,75,75,73,0,0,0,0,0,83,99,105,101,110,116,105,102,105,99,32,65,116,108,97,110,116,97,0,0,0,0,0,0,35,118,101,114,115,105,111,110,0,0,0,0,0,0,0,0,79,112,101,110,71,76,32,69,83,0,0,0,0,0,0,0,83,101,103,97,32,67,104,97,110,110,101,108,32,40,83,99,105,101,110,116,105,102,105,99,32,65,116,108,97,110,116,97,41,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,109,100,95,115,101,103,97,99,104,110,108,0,0,0,0,0,77,101,103,97,78,101,116,32,40,66,114,97,41,0,0,0,73,110,116,101,103,101,114,32,83,99,97,108,101,0,0,0,53,48,75,32,57,48,75,43,0,0,0,0,0,0,0,0,109,100,95,109,101,103,97,110,101,116,0,0,0,0,0,0,76,73,78,68,65,0,0,0,77,101,103,97,32,65,110,115,101,114,32,40,74,112,110,41,0,0,0,0,0,0,0,0,65,117,116,111,0,0,0,0,97,118,115,112,117,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,39,32,45,32,67,104,97,109,112,105,111,110,32,69,100,105,116,105,111,110,32,40,84,117,32,76,111,110,103,32,98,111,111,116,108,101,103,32,115,101,116,32,51,44,32,56,49,49,49,48,50,32,48,48,49,41,0,0,0,0,0,0,0,109,100,95,109,101,103,97,110,115,101,114,0,0,0,0,0,79,118,101,114,114,105,100,101,0,0,0,0,0,0,0,0,84,0,0,0,119,0,0,0,105,0,0,0,110,0,0,0,107,0,0,0,108,0,0,0,101,0,0,0,83,0,0,0,116,0,0,0,97,0,0,0,114,0,0,0,32,0,0,0,83,0,0,0,112,0,0,0,114,0,0,0,105,0,0,0,116,0,0,0,101,0,0,0,115,0,0,0,0,0,0,0,198,48,0,0,163,48,0,0,243,48,0,0,175,48,0,0,235,48,0,0,185,48,0,0,191,48,0,0,252,48,0,0,185,48,0,0,215,48,0,0,233,48,0,0,164,48,0,0,196,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,53,48,75,32,56,48,75,43,0,0,0,0,0,0,0,0,70,108,117,120,32,40,69,117,114,111,41,0,0,0,0,0,109,100,95,97,116,112,116,111,117,114,112,51,0,0,0,0,115,115,114,105,100,101,114,115,101,98,99,0,0,0,0,0,108,105,116,104,101,114,111,0,115,108,45,62,101,103,95,115,104,95,114,114,0,0,0,0,109,100,95,102,108,117,120,0,117,99,99,111,112,115,0,0,114,116,121,112,101,50,106,0,90,111,111,112,32,40,85,83,65,41,0,0,0,0,0,0,118,104,117,110,116,50,0,0,73,71,83,0,0,0,0,0,84,114,105,112,108,101,32,80,117,110,99,104,32,40,115,101,116,32,49,41,0,0,0,0,109,100,95,122,111,111,112,117,0,0,0,0,0,0,0,0,90,111,111,112,32,40,69,117,114,111,41,0,0,0,0,0,109,100,95,122,111,111,112,0,90,111,111,108,32,40,85,83,65,41,0,0,0,0,0,0,109,100,95,122,111,111,108,117,0,0,0,0,0,0,0,0,90,111,111,108,32,40,69,117,114,111,41,0,0,0,0,0,65,118,101,114,97,103,101,0,115,102,50,116,108,111,110,99,0,0,0,0,0,0,0,0,109,100,95,122,111,111,108,0,112,99,101,95,111,118,101,114,114,105,100,101,0,0,0,0,84,119,105,110,107,108,101,32,83,116,97,114,32,83,112,114,105,116,101,115,0,0,0,0,90,111,109,98,105,101,115,32,65,116,101,32,77,121,32,78,101,105,103,104,98,111,114,115,32,40,85,83,65,41,0,0,65,84,80,32,84,111,117,114,32,67,104,97,109,112,105,111,110,115,104,105,112,32,84,101,110,110,105,115,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,56,48,50,41,0,0,0,0,0,0,109,100,95,122,111,109,98,105,101,115,117,0,0,0,0,0,90,111,109,98,105,101,115,32,40,69,117,114,111,41,0,0,83,117,112,101,114,32,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,32,88,32,45,32,103,114,97,110,100,32,109,97,115,116,101,114,32,99,104,97,108,108,101,110,103,101,32,40,115,117,112,101,114,32,115,116,114,101,101,116,32,102,105,103,104,116,101,114,32,50,32,88,32,57,52,48,50,50,51,32,74,97,112,97,110,32,114,101,110,116,32,118,101,114,115,105,111,110,41,0,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,82,65,77,32,119,105,108,108,32,110,111,116,32,98,101,32,115,97,118,101,100,46,10,0,0,0,0,0,103,114,100,105,97,110,115,0,116,114,105,112,108,101,112,0,109,100,95,122,111,109,98,105,101,115,0,0,0,0,0,0,90,111,109,98,105,101,32,72,105,103,104,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,109,100,95,122,111,109,98,104,105,103,104,0,0,0,0,0,83,104,101,110,99,104,105,32,84,101,99,104,110,111,108,111,103,121,0,0,0,0,0,0,90,104,117,111,32,71,117,105,32,68,97,32,83,104,105,32,45,32,71,104,111,115,116,32,72,117,110,116,101,114,32,40,67,104,105,41,0,0,0,0,109,100,95,122,104,117,111,103,117,0,0,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,39,32,45,32,67,104,97,109,112,105,111,110,32,69,100,105,116,105,111,110,32,40,84,117,32,76,111,110,103,32,98,111,111,116,108,101,103,32,115,101,116,32,50,44,32,56,49,49,49,48,50,32,48,48,49,41,0,0,0,0,0,0,0,90,101,114,111,32,87,105,110,103,32,40,74,112,110,41,0,0,0,0,0,0,0,0,0,79,117,116,32,82,117,110,0,0,0,0,0,0,0,0,0,109,100,95,122,101,114,111,119,105,110,103,106,0,0,0,0,109,100,95,97,116,112,116,111,117,114,112,52,0,0,0,0,90,101,114,111,32,87,105,110,103,32,40,69,117,114,111,41,0,0,0,0,0,0,0,0,109,100,95,122,101,114,111,119,105,110,103,0,0,0,0,0,115,115,102,50,120,106,114,0,77,105,103,104,116,121,32,77,111,110,107,101,121,32,40,98,111,111,116,108,101,103,32,111,110,32,83,99,114,97,109,98,108,101,32,104,97,114,100,119,97,114,101,41,0,0,0,0,90,101,114,111,32,116,104,101,32,75,97,109,105,107,97,122,101,32,83,113,117,105,114,114,101,108,32,40,85,83,65,41,0,0,0,0,0,0,0,0,109,100,95,122,101,114,111,117,0,0,0,0,0,0,0,0,122,101,114,111,122,111,110,101,0,0,0,0,0,0,0,0,83,117,110,83,111,102,116,0,90,101,114,111,32,116,104,101,32,75,97,109,105,107,97,122,101,32,83,113,117,105,114,114,101,108,32,40,69,117,114,111,41,0,0,0,0,0,0,0,109,100,95,122,101,114,111,0,75,97,110,101,107,111,32,80,97,110,100,111,114,97,32,98,97,115,101,100,0,0,0,0,90,97,110,121,32,71,111,108,102,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,71,97,108,97,120,105,97,110,32,40,98,111,111,116,108,101,103,44,32,115,101,116,32,49,41,0,0,0,0,0,0,0,115,102,50,116,108,111,110,98,0,0,0,0,0,0,0,0,109,100,95,122,97,110,121,103,111,108,102,49,0,0,0,0,112,99,101,95,111,117,116,114,117,110,0,0,0,0,0,0,78,0,0,0,105,0,0,0,110,0,0,0,106,0,0,0,97,0,0,0,32,0,0,0,109,0,0,0,97,0,0,0,115,0,0,0,116,0,0,0,101,0,0,0,114,0,0,0,39,0,0,0,115,0,0,0,32,0,0,0,135,137,0,0,139,115,0,0,205,95,0,0,213,108,0,0,22,94,0,0,0,0,0,0,78,0,0,0,105,0,0,0,110,0,0,0,106,0,0,0,97,0,0,0,32,0,0,0,77,0,0,0,97,0,0,0,115,0,0,0,116,0,0,0,101,0,0,0,114,0,0,0,39,0,0,0,115,0,0,0,32,0,0,0,104,0,0,0,97,0,0,0,111,0,0,0,104,0,0,0,32,0,0,0,110,0,0,0,105,0,0,0,110,0,0,0,112,0,0,0,111,0,0,0,32,0,0,0,99,0,0,0,104,0,0,0,111,0,0,0,0,0,0,0,0,0,0,0,90,97,110,32,89,97,115,104,97,32,69,110,98,117,107,121,111,107,117,32,40,74,112,110,41,0,0,0,0,0,0,0,65,84,80,32,84,111,117,114,32,67,104,97,109,112,105,111,110,115,104,105,112,32,84,101,110,110,105,115,32,40,69,117,114,111,41,0,0,0,0,0,109,100,95,122,97,110,121,97,115,104,97,0,0,0,0,0,65,110,100,97,109,105,114,111,32,77,105,100,97,115,0,0,89,117,32,89,117,32,72,97,107,117,115,104,111,32,71,97,105,100,101,110,32,40,74,112,110,41,0,0,0,0,0,0,83,117,112,101,114,32,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,32,88,32,45,32,103,114,97,110,100,32,109,97,115,116,101,114,32,99,104,97,108,108,101,110,103,101,32,40,115,117,112,101,114,32,115,116,114,101,101,116,32,102,105,103,104,116,101,114,32,50,32,88,32,57,52,48,50,50,51,32,74,97,112,97,110,41,0,0,0,0,0,0,109,105,109,111,110,107,101,121,0,0,0,0,0,0,0,0,109,100,95,121,117,121,117,103,0,0,0,0,0,0,0,0,89,117,32,89,117,32,72,97,107,117,115,104,111,32,45,32,83,117,110,115,101,116,32,70,105,103,104,116,101,114,115,32,40,66,114,97,41,0,0,0,67,117,114,114,101,110,116,84,97,98,108,101,0,0,0,0,89,117,32,89,117,32,72,97,107,117,115,104,111,32,45,32,77,97,107,121,111,117,32,84,111,105,116,115,117,115,101,110,32,40,74,112,110,41,0,0,109,100,95,121,117,121,117,115,102,0,0,0,0,0,0,0,80,115,105,107,121,111,32,54,56,69,67,48,50,48,0,0,97,105,114,98,117,115,116,114,0,0,0,0,0,0,0,0,109,100,95,121,117,121,117,109,116,0,0,0,0,0,0,0,80,83,51,45,86,49,0,0,89,115,32,45,32,87,97,110,100,101,114,101,114,115,32,102,114,111,109,32,89,115,32,40,74,112,110,41,0,0,0,0,80,114,111,103,114,101,115,115,105,111,110,32,66,97,114,115,32,111,110,108,121,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,39,32,45,32,67,104,97,109,112,105,111,110,32,69,100,105,116,105,111,110,32,40,84,117,32,76,111,110,103,32,98,111,111,116,108,101,103,32,115,101,116,32,49,44,32,56,49,49,49,48,50,32,48,48,49,41,0,0,0,0,0,0,0,109,100,95,121,115,51,106,0,80,83,52,0,0,0,0,0,79,117,116,32,76,105,118,101,0,0,0,0,0,0,0,0,78,105,110,106,97,32,77,97,115,116,101,114,39,115,32,45,32,104,97,111,104,45,110,105,110,112,111,45,99,104,111,0,0,0,0,0,0,0,0,0,89,115,32,73,73,73,32,40,85,83,65,41,0,0,0,0,110,111,0,0,0,0,0,0,109,100,95,97,116,112,116,111,117,114,0,0,0,0,0,0,109,100,95,121,115,51,0,0,84,104,101,32,89,111,117,110,103,32,73,110,100,105,97,110,97,32,74,111,110,101,115,32,67,104,114,111,110,105,99,108,101,115,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,102,105,110,100,32,97,110,121,32,112,114,101,118,105,111,117,115,32,105,110,112,117,116,32,100,114,105,118,101,114,32,40,99,117,114,114,101,110,116,32,111,110,101,58,32,34,37,115,34,41,46,10,0,0,0,0,0,0,115,115,102,50,120,106,0,0,109,105,109,111,110,115,99,114,0,0,0,0,0,0,0,0,109,100,95,121,111,117,110,103,105,110,100,0,0,0,0,0,69,109,112,105,114,101,32,73,110,116,101,114,97,99,116,105,118,101,0,0,0,0,0,0,76,97,115,116,32,77,105,115,115,105,111,110,32,40,85,83,32,114,101,118,105,115,105,111,110,32,54,41,0,0,0,0,89,111,103,105,32,66,101,97,114,39,115,32,67,97,114,116,111,111,110,32,67,97,112,101,114,115,32,40,69,117,114,111,41,0,0,0,0,0,0,0,80,97,99,45,109,97,110,0,109,100,95,121,111,103,105,98,101,97,114,0,0,0,0,0,84,97,114,103,101,116,32,85,112,47,68,111,119,110,0,0,89,97,110,103,32,74,105,97,32,74,105,97,110,103,32,45,32,89,97,110,103,32,87,97,114,114,105,111,114,32,70,97,109,105,108,121,32,40,67,104,105,41,0,0,0,0,0,0,82,111,117,116,101,32,49,54,0,0,0,0,0,0,0,0,109,100,95,121,97,110,103,106,105,0,0,0,0,0,0,0,53,48,48,75,44,32,69,118,101,114,121,32,49,53,48,48,75,0,0,0,0,0,0,0,83,99,111,114,101,115,32,111,110,108,121,0,0,0,0,0,115,102,50,116,108,111,110,97,0,0,0,0,0,0,0,0,89,97,32,83,101,32,67,104,117,97,110,32,83,104,117,111,32,40,67,104,105,41,0,0,112,99,101,95,111,117,116,108,105,118,101,0,0,0,0,0,80,111,105,110,116,32,111,102,32,84,101,114,109,105,110,97,116,105,111,110,0,0,0,0,100,99,111,110,0,0,0,0,109,100,95,121,97,115,101,99,104,0,0,0,0,0,0,0,67,104,101,108,110,111,118,32,40,74,112,110,41,0,0,0,50,48,50,48,98,98,0,0,80,49,32,83,112,101,99,105,97,108,0,0,0,0,0,0,88,105,110,32,81,105,32,71,97,105,32,87,97,110,103,32,90,105,32,40,67,104,105,41,0,0,0,0,0,0,0,0,50,32,67,114,101,100,105,116,115,32,116,111,32,83,116,97,114,116,44,32,49,32,116,111,32,67,111,110,116,105,110,117,101,0,0,0,0,0,0,0,88,105,110,32,81,105,32,71,97,105,32,87,97,110,103,32,90,105,32,40,67,104,105,44,32,65,108,116,41,0,0,0,83,117,112,101,114,32,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,32,84,117,114,98,111,32,40,115,117,112,101,114,32,115,116,114,101,101,116,32,102,105,103,104,116,101,114,32,50,32,88,32,57,52,48,50,50,51,32,85,83,65,41,0,0,0,0,0,114,101,115,101,116,0,0,0,78,111,32,100,101,97,116,104,32,38,32,115,116,111,112,32,109,111,100,101,0,0,0,0,86,101,114,121,32,104,97,114,100,0,0,0,0,0,0,0,67,97,118,101,108,111,110,0,0,0,0,0,0,0,0,0,109,100,95,120,105,110,113,105,103,0,0,0,0,0,0,0,84,101,114,114,105,116,111,114,121,0,0,0,0,0,0,0,109,100,95,120,105,110,113,105,103,49,0,0,0,0,0,0,88,105,97,111,32,77,111,110,118,32,45,32,77,97,103,105,99,32,71,105,114,108,32,40,67,104,105,41,0,0,0,0,82,111,98,111,99,111,112,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,109,100,95,120,105,97,111,109,111,0,0,0,0,0,0,0,55,32,67,111,105,110,115,32,49,32,67,114,101,100,105,116,115,0,0,0,0,0,0,0,102,105,110,97,108,98,106,0,88,101,110,111,110,32,50,32,45,32,77,101,103,97,98,108,97,115,116,32,40,69,117,114,111,41,0,0,0,0,0,0,77,97,120,105,109,117,109,0,99,104,117,107,97,116,97,105,106,0,0,0,0,0,0,0,65,114,107,97,110,111,105,100,32,40,84,97,121,116,111,32,98,111,111,116,108,101,103,44,32,104,97,114,100,101,114,41,0,0,0,0,0,0,0,0,109,100,95,120,101,110,111,110,50,0,0,0,0,0,0,0,49,48,48,48,75,32,79,110,108,121,0,0,0,0,0,0,86,105,111,108,101,110,99,101,32,70,105,103,104,116,32,40,74,97,112,97,110,41,0,0,83,99,111,114,101,115,32,97,110,100,32,80,114,111,103,114,101,115,115,105,111,110,32,66,97,114,115,0,0,0,0,0,101,110,102,111,114,99,101,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,39,32,45,32,67,104,97,109,112,105,111,110,32,69,100,105,116,105,111,110,32,40,57,50,48,56,48,51,32,85,83,65,32,98,111,111,116,108,101,103,41,0,0,0,0,0,0,85,110,105,112,97,99,0,0,114,97,115,116,97,110,117,98,0,0,0,0,0,0,0,0,75,97,110,103,97,114,111,111,0,0,0,0,0,0,0,0,48,87,0,0,68,115,0,0,129,48,0,0,80,48,0,0,138,48,0,0,0,0,0,0,74,0,0,0,105,0,0,0,103,0,0,0,111,0,0,0,107,0,0,0,117,0,0,0,32,0,0,0,77,0,0,0,101,0,0,0,103,0,0,0,117,0,0,0,114,0,0,0,105,0,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,79,114,100,121,110,101,0,0,79,118,101,114,32,84,111,112,0,0,0,0,0,0,0,0,88,68,82,32,45,32,88,32,68,97,122,101,100,108,121,32,82,97,121,32,40,74,112,110,41,0,0,0,0,0,0,0,53,48,107,44,32,116,104,101,110,32,101,118,101,114,121,32,55,48,107,0,0,0,0,0,109,100,95,99,104,101,108,110,111,118,0,0,0,0,0,0,80,114,101,104,105,115,116,111,114,105,99,32,73,115,108,101,32,40,83,78,75,41,0,0,49,32,67,111,105,110,32,32,49,32,67,114,101,100,105,116,32,52,47,53,0,0,0,0,109,100,95,120,100,114,0,0,106,111,106,111,106,114,49,0,97,117,114,97,105,108,106,0,88,45,112,101,114,116,115,32,40,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,115,115,102,50,116,117,114,49,0,0,0,0,0,0,0,0,109,114,118,105,107,105,110,103,106,0,0,0,0,0,0,0,115,116,97,116,101,95,115,108,111,116,0,0,0,0,0,0,51,32,116,111,32,115,116,97,114,116,44,32,50,32,116,111,32,99,111,110,116,105,110,117,101,0,0,0,0,0,0,0,99,97,118,101,108,111,110,0,109,100,95,120,112,101,114,116,115,112,0,0,0,0,0,0,83,117,112,101,114,32,77,111,110,97,99,111,32,71,80,32,40,85,83,44,32,82,101,118,32,66,44,32,70,68,49,48,57,52,32,51,49,55,45,48,49,50,53,97,41,0,0,0,81,117,97,114,116,101,116,32,50,32,40,56,55,53,49,32,51,49,55,45,48,48,49,48,41,0,0,0,0,0,0,0,88,45,112,101,114,116,115,32,40,85,83,65,41,0,0,0,109,100,95,120,112,101,114,116,115,0,0,0,0,0,0,0,109,97,103,105,99,98,117,98,0,0,0,0,0,0,0,0,88,45,77,101,110,32,50,32,45,32,67,108,111,110,101,32,87,97,114,115,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,49,48,49,56,41,0,0,0,0,0,0,74,111,121,115,116,105,99,107,115,0,0,0,0,0,0,0,84,97,114,103,101,116,32,76,101,102,116,47,82,105,103,104,116,0,0,0,0,0,0,0,83,112,105,116,32,67,111,108,111,114,0,0,0,0,0,0,109,100,95,120,109,101,110,50,112,49,55,0,0,0,0,0,51,32,112,108,97,121,101,114,115,0,0,0,0,0,0,0,114,101,100,104,97,119,107,105,0,0,0,0,0,0,0,0,49,32,99,111,105,110,32,54,32,99,114,101,100,105,116,115,0,0,0,0,0,0,0,0,68,101,101,114,32,72,117,110,116,105,110,103,32,85,83,65,32,86,49,0,0,0,0,0,88,45,77,101,110,32,50,32,45,32,67,108,111,110,101,32,87,97,114,115,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,49,49,51,48,41,0,0,0,0,0,0,53,48,48,75,32,79,110,108,121,0,0,0,0,0,0,0,72,111,110,103,32,75,111,110,103,32,38,32,84,97,105,119,97,110,0,0,0,0,0,0,115,102,50,99,101,117,99,98,108,0,0,0,0,0,0,0,109,100,95,120,109,101,110,50,112,49,51,0,0,0,0,0,112,99,101,95,111,114,100,121,110,101,0,0,0,0,0,0,97,103,97,108,108,101,116,117,0,0,0,0,0,0,0,0,88,45,77,101,110,32,50,32,45,32,67,108,111,110,101,32,87,97,114,115,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,49,49,50,56,41,0,0,0,0,0,0,65,116,111,109,105,99,32,82,117,110,110,101,114,32,40,85,83,65,41,0,0,0,0,0,116,105,108,101,95,98,97,110,107,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,102,105,110,100,32,97,110,121,32,97,117,100,105,111,32,100,114,105,118,101,114,32,110,97,109,101,100,32,34,37,115,34,10,0,109,100,95,120,109,101,110,50,112,49,52,0,0,0,0,0,49,32,99,111,105,110,115,32,53,32,99,114,101,100,105,116,0,0,0,0,0,0,0,0,88,45,77,101,110,32,50,32,45,32,67,108,111,110,101,32,87,97,114,115,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,49,49,50,51,41,0,0,0,0,0,0,83,117,112,101,114,32,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,32,84,117,114,98,111,32,40,115,117,112,101,114,32,115,116,114,101,101,116,32,102,105,103,104,116,101,114,32,50,32,88,32,57,52,48,51,50,51,32,85,83,65,41,0,0,0,0,0,65,116,97,114,105,32,71,97,117,110,116,108,101,116,0,0,89,97,110,103,32,67,104,101,110,103,0,0,0,0,0,0,109,100,95,120,109,101,110,50])
.concat([112,49,53,0,0,0,0,0,72,111,110,101,121,32,68,111,108,108,115,0,0,0,0,0,83,68,32,70,105,103,104,116,101,114,115,32,40,75,111,114,101,97,41,0,0,0,0,0,88,45,77,101,110,32,50,32,45,32,67,108,111,110,101,32,87,97,114,115,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,49,49,49,55,41,0,0,0,0,0,0,66,111,109,98,32,74,97,99,107,0,0,0,0,0,0,0,51,32,99,111,105,110,115,32,61,32,49,32,99,114,101,100,105,116,0,0,0,0,0,0,68,101,98,117,103,0,0,0,109,111,117,115,101,0,0,0,80,50,32,98,117,116,116,111,110,32,49,0,0,0,0,0,109,100,95,120,109,101,110,50,112,49,54,0,0,0,0,0,50,48,107,32,116,104,101,110,32,101,118,101,114,121,32,57,48,107,0,0,0,0,0,0,88,45,77,101,110,32,50,32,45,32,67,108,111,110,101,32,87,97,114,115,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,53,49,48,41,0,0,0,0,0,0,115,112,97,110,103,106,0,0,65,32,49,67,47,50,67,32,66,32,49,67,47,52,67,0,52,32,40,68,105,102,102,105,99,117,108,116,41,0,0,0,109,100,95,120,109,101,110,50,112,49,56,0,0,0,0,0,103,97,117,110,116,50,0,0,88,45,77,101,110,32,50,32,45,32,67,108,111,110,101,32,87,97,114,115,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,53,48,54,41,0,0,0,0,0,0,51,48,75,44,32,53,48,75,44,32,101,118,101,114,121,32,55,48,75,0,0,0,0,0,52,48,75,32,49,48,48,75,32,50,48,48,75,0,0,0,68,105,112,32,83,119,105,116,99,104,101,115,32,49,32,0,52,67,95,49,67,0,0,0,49,48,48,107,32,51,48,48,107,32,56,48,48,107,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,39,32,45,32,67,104,97,109,112,105,111,110,32,69,100,105,116,105,111,110,32,40,57,50,48,51,49,51,32,85,83,65,32,98,111,111,116,108,101,103,32,115,101,116,32,54,41,0,0,0,0,0,0,0,0,109,100,95,120,109,101,110,50,112,49,57,0,0,0,0,0,79,112,101,114,97,116,105,111,110,32,87,111,108,102,0,0,6,92,0,0,203,104,0,0,110,48,0,0,84,144,0,0,186,78,0,0,0,0,0,0,77,0,0,0,97,0,0,0,115,0,0,0,116,0,0,0,101,0,0,0,114,0,0,0,32,0,0,0,111,0,0,0,102,0,0,0,32,0,0,0,83,0,0,0,121,0,0,0,111,0,0,0,117,0,0,0,103,0,0,0,105,0,0,0,0,0,0,0,0,0,0,0,49,48,48,48,48,32,55,48,48,48,48,0,0,0,0,0,88,45,77,101,110,32,50,32,45,32,67,108,111,110,101,32,87,97,114,115,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,49,50,49,54,41,0,0,0,0,0,0,109,100,95,97,116,111,109,114,117,110,117,0,0,0,0,0,109,100,95,120,109,101,110,50,112,48,49,0,0,0,0,0,99,114,115,104,114,97,99,101,0,0,0,0,0,0,0,0,83,117,112,101,114,32,84,114,105,118,0,0,0,0,0,0,66,108,111,111,100,0,0,0,88,45,77,101,110,32,50,32,45,32,67,108,111,110,101,32,87,97,114,115,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,49,50,49,53,41,0,0,0,0,0,0,115,115,102,50,116,117,0,0,49,48,48,75,32,49,48,48,75,43,0,0,0,0,0,0,57,57,108,115,116,119,97,114,107,0,0,0,0,0,0,0,109,100,95,120,109,101,110,50,112,48,50,0,0,0,0,0,76,101,118,101,108,32,111,102,32,77,111,110,115,116,101,114,0,0,0,0,0,0,0,0,50,48,107,32,111,110,108,121,0,0,0,0,0,0,0,0,88,45,77,101,110,32,50,32,45,32,67,108,111,110,101,32,87,97,114,115,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,49,50,49,52,41,0,0,0,0,0,0,109,100,95,120,109,101,110,50,112,48,51,0,0,0,0,0,51,32,67,111,105,110,115,32,51,32,80,108,97,121,115,0,97,115,105,99,51,95,104,49,0,0,0,0,0,0,0,0,88,45,77,101,110,32,50,32,45,32,67,108,111,110,101,32,87,97,114,115,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,49,50,49,49,41,0,0,0,0,0,0,102,101,118,101,114,115,111,115,0,0,0,0,0,0,0,0,109,100,95,120,109,101,110,50,112,48,52,0,0,0,0,0,110,101,119,115,0,0,0,0,88,45,77,101,110,32,50,32,45,32,67,108,111,110,101,32,87,97,114,115,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,49,50,49,49,45,65,41,0,0,0,0,112,99,101,95,98,97,114,105,98,97,114,105,0,0,0,0,115,102,50,99,101,117,97,98,54,0,0,0,0,0,0,0,109,100,95,120,109,101,110,50,112,48,53,0,0,0,0,0,99,97,119,105,110,103,117,0,112,99,101,95,111,112,119,111,108,102,0,0,0,0,0,0,83,121,111,117,103,105,32,78,111,32,84,97,116,115,117,106,105,110,32,45,32,77,97,115,116,101,114,32,111,102,32,83,121,111,117,103,105,0,0,0,107,111,116,109,104,0,0,0,110,83,111,117,110,100,80,114,101,118,82,101,112,108,121,0,88,45,77,101,110,32,50,32,45,32,67,108,111,110,101,32,87,97,114,115,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,49,50,49,48,41,0,0,0,0,0,0,65,116,111,109,105,99,32,82,117,110,110,101,114,32,40,69,117,114,111,41,0,0,0,0,109,100,95,120,109,101,110,50,112,48,54,0,0,0,0,0,88,45,77,101,110,32,50,32,45,32,67,108,111,110,101,32,87,97,114,115,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,49,50,48,57,41,0,0,0,0,0,0,83,117,112,101,114,32,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,32,84,117,114,98,111,32,40,115,117,112,101,114,32,115,116,114,101,101,116,32,102,105,103,104,116,101,114,32,50,32,88,32,57,52,48,50,50,51,32,65,115,105,97,41,0,0,0,0,79,80,76,45,62,115,116,97,116,117,115,0,0,0,0,0,109,100,95,120,109,101,110,50,112,48,55,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,76,105,110,107,101,114,32,108,111,103,58,32,37,115,10,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,71,76,93,58,32,69,120,116,101,110,115,105,111,110,32,71,76,95,69,88,84,95,117,110,112,97,99,107,95,115,117,98,105,109,97,103,101,44,32,99,97,110,32,99,111,112,121,32,116,101,120,116,117,114,101,115,32,102,97,115,116,101,114,32,117,115,105,110,103,32,85,78,80,65,67,75,95,82,79,87,95,76,69,78,71,84,72,46,10,0,0,0,88,45,77,101,110,32,50,32,45,32,67,108,111,110,101,32,87,97,114,115,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,49,50,48,56,41,0,0,0,0,0,0,109,100,95,120,109,101,110,50,112,48,56,0,0,0,0,0,109,100,95,97,108,101,120,107,105,100,100,0,0,0,0,0,88,45,77,101,110,32,50,32,45,32,67,108,111,110,101,32,87,97,114,115,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,49,50,48,55,41,0,0,0,0,0,0,83,104,97,100,101,114,32,79,112,116,105,111,110,115,0,0,52,48,75,32,56,48,75,43,0,0,0,0,0,0,0,0,109,100,95,120,109,101,110,50,112,48,57,0,0,0,0,0,88,45,77,101,110,32,50,32,45,32,67,108,111,110,101,32,87,97,114,115,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,49,50,48,54,41,0,0,0,0,0,0,71,88,57,48,51,0,0,0,65,108,105,101,110,32,118,115,32,80,114,101,100,97,116,111,114,32,40,57,52,48,53,50,48,32,74,97,112,97,110,41,0,0,0,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,39,32,45,32,67,104,97,109,112,105,111,110,32,69,100,105,116,105,111,110,32,40,57,50,48,51,49,51,32,85,83,65,32,98,111,111,116,108,101,103,32,115,101,116,32,53,41,0,0,0,0,0,0,0,0,109,100,95,120,109,101,110,50,112,49,48,0,0,0,0,0,79,98,111,99,99,104,97,109,97,45,107,117,110,0,0,0,88,45,77,101,110,32,50,32,45,32,67,108,111,110,101,32,87,97,114,115,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,49,50,48,51,41,0,0,0,0,0,0,109,100,95,97,116,111,109,114,117,110,0,0,0,0,0,0,83,117,110,115,101,116,32,82,105,100,101,114,115,32,40,50,32,80,108,97,121,101,114,115,32,118,101,114,46,32,69,66,68,41,0,0,0,0,0,0,75,97,105,107,101,116,115,117,32,89,97,110,99,104,97,109,97,114,117,32,40,74,97,112,97,110,41,0,0,0,0,0,109,100,95,120,109,101,110,50,112,49,49,0,0,0,0,0,115,108,45,62,101,103,95,115,101,108,95,100,114,0,0,0,71,117,110,102,111,114,99,101,32,45,32,66,97,116,116,108,101,32,70,105,114,101,32,69,110,103,117,108,102,101,100,32,84,101,114,114,111,114,32,73,115,108,97,110,100,32,40,85,83,41,0,0,0,0,0,0,77,56,50,0,0,0,0,0,88,45,77,101,110,32,50,32,45,32,67,108,111,110,101,32,87,97,114,115,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,49,50,48,50,41,0,0,0,0,0,0,115,115,102,50,116,97,0,0,72,111,116,32,83,104,111,99,107,101,114,32,40,98,111,111,116,108,101,103,41,0,0,0,109,100,95,120,109,101,110,50,112,49,50,0,0,0,0,0,88,45,77,101,110,32,50,32,45,32,67,108,111,110,101,32,87,97,114,115,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,0,0,74,97,99,107,32,116,104,101,32,71,105,97,110,116,107,105,108,108,101,114,0,0,0,0,109,100,95,120,109,101,110,50,0,0,0,0,0,0,0,0,69,80,79,83,32,84,114,105,115,116,97,114,0,0,0,0,88,45,77,101,110,32,40,85,83,65,41,0,0,0,0,0,115,104,97,100,111,119,119,0,69,118,101,114,121,32,53,48,48,48,48,0,0,0,0,0,109,100,95,120,109,101,110,117,0,0,0,0,0,0,0,0,88,45,77,101,110,32,40,69,117,114,111,41,0,0,0,0,84,97,105,116,111,32,65,109,101,114,105,99,97,32,40,82,111,109,115,116,97,114,32,108,105,99,101,110,115,101,41,0,67,101,110,116,117,114,105,0,49,50,53,48,48,48,0,0,109,100,95,120,109,101,110,0,115,102,50,99,101,117,97,98,53,0,0,0,0,0,0,0,112,99,101,95,111,98,111,99,99,104,97,0,0,0,0,0,87,111,114,108,100,32,72,101,114,111,101,115,32,80,101,114,102,101,99,116,0,0,0,0,87,87,70,32,87,114,101,115,116,108,101,77,97,110,105,97,32,45,32,84,104,101,32,65,114,99,97,100,101,32,71,97,109,101,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,65,116,111,109,105,99,32,82,111,98,111,45,75,105,100,32,40,74,112,110,41,0,0,0,109,100,95,119,119,102,97,103,112,0,0,0,0,0,0,0,87,87,70,32,87,114,101,115,116,108,101,77,97,110,105,97,32,45,32,84,104,101,32,65,114,99,97,100,101,32,71,97,109,101,32,40,69,117,114,111,44,32,85,83,65,41,0,0,83,117,112,101,114,32,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,32,84,117,114,98,111,32,40,115,117,112,101,114,32,115,116,114,101,101,116,32,102,105,103,104,116,101,114,32,50,32,88,32,57,52,48,50,50,51,32,101,116,99,41,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,107,105,112,112,105,110,103,32,83,82,65,77,32,108,111,97,100,46,10,0,104,111,116,115,104,111,99,107,98,0,0,0,0,0,0,0,109,100,95,119,119,102,97,103,0,0,0,0,0,0,0,0,87,87,70,32,83,117,112,101,114,32,87,114,101,115,116,108,101,77,97,110,105,97,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,109,100,95,119,119,102,115,117,112,0,0,0,0,0,0,0,87,87,70,32,82,111,121,97,108,32,82,117,109,98,108,101,32,40,87,111,114,108,100,41,0,0,0,0,0,0,0,0,109,100,95,119,119,102,114,111,121,97,108,0,0,0,0,0,87,87,70,32,82,97,119,32,40,87,111,114,108,100,41,0,0,0,0,0,0,0,0,0,97,105,114,119,111,108,102,97,0,0,0,0,0,0,0,0,115,112,101,101,100,115,112,110,0,0,0,0,0,0,0,0,109,100,95,119,119,102,114,97,119,0,0,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,39,32,45,32,67,104,97,109,112,105,111,110,32,69,100,105,116,105,111,110,32,40,57,50,48,51,49,51,32,85,83,65,32,98,111,111,116,108,101,103,32,115,101,116,32,52,41,0,0,0,0,0,0,0,0,84,104,101,32,78,105,110,106,97,32,87,97,114,114,105,111,114,115,0,0,0,0,0,0,76,101,102,116,32,97,110,97,108,111,103,32,89,45,32,40,117,112,41,0,0,0,0,0,77,105,110,103,0,0,0,0,109,100,95,97,116,111,109,114,111,98,111,106,0,0,0,0,87,117,32,75,111,110,103,32,87,97,105,32,90,104,117,97,110,32,40,67,104,105,41,0,0,0,0,0,0,0,0,0,109,100,95,119,117,107,111,110,103,0,0,0,0,0,0,0,115,115,102,50,116,0,0,0,69,46,71,46,32,70,101,108,97,99,111,32,40,68,111,109,105,110,111,32,108,105,99,101,110,115,101,41,0,0,0,0,87,114,101,115,116,108,101,32,87,97,114,32,40,74,112,110,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,109,100,95,119,114,101,115,116,119,97,114,112,0,0,0,0,87,114,101,115,116,108,101,32,87,97,114,32,40,69,117,114,111,44,32,74,112,110,41,0,0,0,0,0,0,0,0,0,109,100,95,119,114,101,115,116,119,97,114,0,0,0,0,0,83,100,105,84,114,97,99,107,50,89,0,0,0,0,0,0,87,111,114,109,115,32,40,69,117,114,111,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,0,0,0,109,100,95,119,111,114,109,115,112,0,0,0,0,0,0,0,103,97,108,97,120,98,115,102,0,0,0,0,0,0,0,0,55,53,48,48,48,0,0,0,87,111,114,109,115,32,40,69,117,114,111,41,0,0,0,0,115,102,50,99,101,117,97,98,52,0,0,0,0,0,0,0,112,99,101,95,110,105,110,106,97,119,97,114,0,0,0,0,65,0,0,0,103,0,0,0,103,0,0,0,114,0,0,0,101,0,0,0,115,0,0,0,115,0,0,0,111,0,0,0,114,0,0,0,115,0,0,0,32,0,0,0,111,0,0,0,102,0,0,0,32,0,0,0,68,0,0,0,97,0,0,0,114,0,0,0,107,0,0,0,32,0,0,0,75,0,0,0,111,0,0,0,109,0,0,0,98,0,0,0,97,0,0,0,116,0,0,0,0,0,0,0,219,117,0,0,235,95,0,0,39,255,0,0,65,255,0,0,78,255,0,0,71,255,0,0,65,255,0,0,78,255,0,0,76,136,0,0,50,144,0,0,242,102,0,0,32,0,0,0,40,0,0,0,65,0,0,0,68,0,0,0,77,0,0,0,45,0,0,0,48,0,0,0,48,0,0,0,56,0,0,0,41,0,0,0,40,0,0,0,65,0,0,0,68,0,0,0,72,0,0,0,45,0,0,0,48,0,0,0,48,0,0,0,56,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,109,100,95,119,111,114,109,115,0,0,0,0,0,0,0,0,83,117,112,101,114,32,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,32,45,32,116,104,101,32,116,111,117,114,110,97,109,101,110,116,32,98,97,116,116,108,101,32,40,57,51,49,48,48,53,32,72,105,115,112,97,110,105,99,41,0,0,0,0,0,0,0,84,114,101,99,111,0,0,0,87,111,114,108,100,32,83,101,114,105,101,115,32,66,97,115,101,98,97,108,108,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,51,49,48,48,49,41,0,0,0,0,0,0,0,0,109,100,95,119,115,98,112,49,48,0,0,0,0,0,0,0,66,117,114,110,71,117,110,88,0,0,0,0,0,0,0,0,72,111,116,32,83,104,111,99,107,101,114,0,0,0,0,0,87,111,114,108,100,32,83,101,114,105,101,115,32,66,97,115,101,98,97,108,108,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,53,50,55,41,0,0,0,0,0,0,0,0,109,100,95,119,115,98,112,48,49,0,0,0,0,0,0,0,67,117,114,114,101,110,116,80,116,114,0,0,0,0,0,0,87,111,114,108,100,32,83,101,114,105,101,115,32,66,97,115,101,98,97,108,108,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,51,48,52,41,0,0,0,0,0,0,0,0,109,100,95,119,115,98,112,48,50,0,0,0,0,0,0,0,83,100,105,84,114,97,99,107,50,88,0,0,0,0,0,0,87,111,114,108,100,32,83,101,114,105,101,115,32,66,97,115,101,98,97,108,108,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,49,49,54,41,0,0,0,0,0,0,0,0,119,119,102,119,102,101,115,116,0,0,0,0,0,0,0,0,109,100,95,119,115,98,112,48,52,0,0,0,0,0,0,0,87,111,114,108,100,32,83,101,114,105,101,115,32,66,97,115,101,98,97,108,108,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,49,48,54,41,0,0,0,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,39,32,45,32,67,104,97,109,112,105,111,110,32,69,100,105,116,105,111,110,32,40,57,50,48,51,49,51,32,85,83,65,32,98,111,111,116,108,101,103,32,115,101,116,32,51,41,0,0,0,0,0,0,0,0,78,105,110,106,97,32,82,121,117,107,101,110,100,101,110,0,0,0,0,0,0,0,0,0,65,103,103,114,101,115,115,111,114,115,32,111,102,32,68,97,114,107,32,75,111,109,98,97,116,32,47,32,84,115,117,117,107,97,105,32,71,65,78,71,65,78,32,75,111,117,115,104,105,110,107,121,111,107,117,32,40,65,68,77,45,48,48,56,41,40,65,68,72,45,48,48,56,41,0,0,0,0,0,0,109,100,95,119,115,98,112,48,53,0,0,0,0,0,0,0,115,115,102,50,116,98,104,0,65,116,111,109,105,99,32,82,111,98,111,45,75,105,100,32,40,85,83,65,41,0,0,0,121,101,115,0,0,0,0,0,87,111,114,108,100,32,83,101,114,105,101,115,32,66,97,115,101,98,97,108,108,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,49,48,51,41,0,0,0,0,0,0,0,0,109,100,95,119,115,98,112,48,54,0,0,0,0,0,0,0,104,111,116,115,104,111,99,107,0,0,0,0,0,0,0,0,87,111,114,108,100,32,83,101,114,105,101,115,32,66,97,115,101,98,97,108,108,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,50,49,56,41,0,0,0,0,0,0,0,0,109,100,95,119,115,98,112,48,51,0,0,0,0,0,0,0,87,111,114,108,100,32,83,101,114,105,101,115,32,66,97,115,101,98,97,108,108,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,51,49,50,50,57,41,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,76,111,97,100,105,110,103,32,115,116,97,116,101,58,32,34,37,115,34,46,10,0,0,0,0,0,0,0,0,109,100,95,119,115,98,112,48,55,0,0,0,0,0,0,0,83,100,105,84,114,97,99,107,49,89,0,0,0,0,0,0,84,120,32,82,65,77,0,0,87,111,114,108,100,32,83,101,114,105,101,115,32,66,97,115,101,98,97,108,108,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,51,49,50,50,54,41,0,0,0,0,0,0,0,0,112,50,32,102,105,114,101,32,49,51,0,0,0,0,0,0,109,100,95,119,115,98,112,48,56,0,0,0,0,0,0,0,100,114,103,119,50,106,0,0,87,111,114,108,100,32,83,101,114,105,101,115,32,66,97,115,101,98,97,108,108,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,51,49,50,50,50,41,0,0,0,0,0,0,0,0,115,102,50,99,101,117,97,98,51,0,0,0,0,0,0,0,112,99,101,95,110,114,121,117,107,101,110,100,0,0,0,0,83,116,97,103,101,32,82,101,115,101,116,0,0,0,0,0,109,100,95,119,115,98,112,48,57,0,0,0,0,0,0,0,83,117,112,101,114,32,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,32,45,32,116,104,101,32,116,111,117,114,110,97,109,101,110,116,32,98,97,116,116,108,101,32,40,57,51,48,57,49,49,32,74,97,112,97,110,41,0,0,109,100,95,97,116,111,109,114,111,98,111,0,0,0,0,0,80,49,32,75,105,99,107,0,87,111,114,108,100,32,83,101,114,105,101,115,32,66,97,115,101,98,97,108,108,32,40,85,83,65,41,0,0,0,0,0,109,100,95,119,115,98,0,0,82,101,115,101,116,0,0,0,78,111,114,109,97,108,32,71,97,109,101,0,0,0,0,0,72,97,114,100,0,0,0,0,77,114,46,32,75,111,117,103,97,114,32,40,98,111,111,116,108,101,103,32,115,101,116,32,50,41,0,0,0,0,0,0,87,111,114,108,100,32,83,101,114,105,101,115,32,66,97,115,101,98,97,108,108,32,39,57,56,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,78,111,45,100,101,97,116,104,32,38,32,115,116,111,112,32,109,111,100,101,0,0,0,0,77,97,120,32,80,108,97,121,101,114,115,0,0,0,0,0,109,100,95,119,115,98,57,56,0,0,0,0,0,0,0,0,72,111,110,103,32,75,111,110,103,32,40,72,111,110,101,115,116,32,84,114,97,100,105,110,103,32,67,111,46,32,76,105,99,101,110,115,101,41,0,0,87,111,114,108,100,32,83,101,114,105,101,115,32,66,97,115,101,98,97,108,108,32,39,57,54,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,109,100,95,119,115,98,57,54,0,0,0,0,0,0,0,0,114,111,98,111,99,111,112,106,0,0,0,0,0,0,0,0,56,32,67,111,105,110,115,32,49,32,67,114,101,100,105,116,115,0,0,0,0,0,0,0,70,105,110,97,108,32,66,108,111,119,32,40,87,111,114,108,100,41,0,0,0,0,0,0,83,100,105,84,114,97,99,107,49,88,0,0,0,0,0,0,103,97,108,112,97,110,105,99,0,0,0,0,0,0,0,0,68,105,97,103,110,111,115,105,99,115,0,0,0,0,0,0,87,111,114,108,100,32,83,101,114,105,101,115,32,66,97,115,101,98,97,108,108,32,39,57,53,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,49,51,48,41,0,0,0,0,83,116,101,114,101,111,32,83,101,112,101,114,97,116,105,111,110,0,0,0,0,0,0,0,80,50,32,65,116,116,97,99,107,32,80,111,119,50,0,0,67,104,117,107,97,32,84,97,105,115,101,110,32,40,85,83,41,0,0,0,0,0,0,0,97,114,107,116,97,121,116,50,0,0,0,0,0,0,0,0,79,110,47,69,118,101,114,121,32,55,32,77,105,110,46,0,109,100,95,119,115,98,57,53,112,49,48,0,0,0,0,0,118,105,111,102,105,103,104,116,106,0,0,0,0,0,0,0,65,32,49,47,50,32,66,32,49,47,50,0,0,0,0,0,80,111,119,101,114,32,87,104,101,101,108,115,32,40,74,97,112,97,110,41,0,0,0,0,87,111,114,108,100,32,83,101,114,105,101,115,32,66,97,115,101,98,97,108,108,32,39,57,53,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,49,50,53,41,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,39,32,45,32,67,104,97,109,112,105,111,110,32,69,100,105,116,105,111,110,32,40,57,50,48,51,49,51,32,85,83,65,32,98,111,111,116,108,101,103,32,115,101,116,32,50,41,0,0,0,0,0,0,0,0,82,97,115,116,97,110,32,40,85,83,41,0,0,0,0,0,74,105,103,111,107,117,32,77,101,103,117,114,105,32,40,74,97,112,97,110,41,0,0,0,65,68,75,32,47,32,83,78,75,0,0,0,0,0,0,0,109,100,95,119,115,98,57,53,112,49,49,0,0,0,0,0,65,0,0,0,115,0,0,0,116,0,0,0,233,0,0,0,114,0,0,0,105,0,0,0,120,0,0,0,32,0,0,0,97,0,0,0,110,0,0,0,100,0,0,0,32,0,0,0,116,0,0,0,104,0,0,0,101,0,0,0,32,0,0,0,80,0,0,0,111,0,0,0,119,0,0,0,101,0,0,0,114,0,0,0,32,0,0,0,111,0,0,0,102,0,0,0,32,0,0,0,116,0,0,0,104,0,0,0,101,0,0,0,32,0,0,0,71,0,0,0,111,0,0,0,100,0,0,0,115,0,0,0,32,0,0,0,40,0,0,0,69,0,0,0,117,0,0,0,114,0,0,0,111,0,0,0,44,0,0,0,32,0,0,0,80,0,0,0,114,0,0,0,111,0,0,0,116,0,0,0,111,0,0,0,116,0,0,0,121,0,0,0,112,0,0,0,101,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,32,67,111,105,110,32,32,49,32,67,114,101,100,105,116,32,50,47,51,0,0,0,0,87,111,114,108,100,32,83,101,114,105,101,115,32,66,97,115,101,98,97,108,108,32,39,57,53,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,49,50,48,41,0,0,0,0,184,48,0,0,231,48,0,0,184,48,0,0,231,48,0,0,110,48,0,0,32,0,0,0,71,89,0,0,153,89,0,0,106,48,0,0,146,81,0,0,122,150,0,0,0,0,0,0,74,0,0,0,111,0,0,0,74,0,0,0,111,0,0,0,39,0,0,0,115,0,0,0,32,0,0,0,86,0,0,0,101,0,0,0,110,0,0,0,116,0,0,0,117,0,0,0,114,0,0,0,101,0,0,0,32,0,0,0,40,0,0,0,85,0,0,0,83,0,0,0,65,0,0,0,32,0,0,0,57,0,0,0,57,0,0,0,48,0,0,0,49,0,0,0,48,0,0,0,56,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,65,117,114,97,105,108,32,40,115,101,116,32,50,44,32,87,111,114,108,100,44,32,70,68,49,48,56,57,66,32,51,49,55,45,48,49,54,56,41,0,0,0,0,0,0,0,0,0,109,100,95,119,115,98,57,53,112,49,50,0,0,0,0,0,115,115,102,50,116,98,106,0,77,105,115,116,101,114,32,86,105,107,105,110,103,32,40,51,49,53,45,53,48,52,49,41,0,0,0,0,0,0,0,0,77,105,99,104,97,101,108,32,74,97,99,107,115,111,110,39,115,32,77,111,111,110,119,97,108,107,101,114,32,40,98,111,111,116,108,101,103,41,0,0,118,105,100,101,111,95,114,111,116,97,116,105,111,110,0,0,109,114,107,111,117,103,98,50,0,0,0,0,0,0,0,0,87,111,114,108,100,32,83,101,114,105,101,115,32,66,97,115,101,98,97,108,108,32,39,57,53,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,49,49,56,45,82,77,41,0,0,0,0,0,0,0,0,0,115,109,103,112,117,49,0,0,113,117,97,114,116,101,116,50,0,0,0,0,0,0,0,0,109,100,95,119,115,98,57,53,112,49,51,0,0,0,0,0,87,111,114,108,100,32,83,101,114,105,101,115,32,66,97,115,101,98,97,108,108,32,39,57,53,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,49,49,54,41,0,0,0,0,109,100,95,119,115,98,57,53,112,49,52,0,0,0,0,0,54,32,67,111,105,110,115,32,49,32,67,114,101,100,105,116,115,32,0,0,0,0,0,0,68,114,118,84,111,103,103,108,101,0,0,0,0,0,0,0,83,116,97,103,101,32,83,107,105,112,0,0,0,0,0,0,87,111,114,108,100,32,83,101,114,105,101,115,32,66,97,115,101,98,97,108,108,32,39,57,53,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,49,49,52,45,82,77,41,0,0,0,0,0,0,0,0,0,112,50,32,102,105,114,101,32,49,50,0,0,0,0,0,0,50,32,112,108,97,121,101,114,115,0,0,0,0,0,0,0,65,102,101,103,97,32,40,69,120,99,101,108,108,101,110,116,32,67,111,46,32,108,105,99,101,110,115,101,41,0,0,0,49,32,99,111,105,110,32,53,32,99,114,101,100,105,116,115,0,0,0,0,0,0,0,0,100,101,101,114,104,117,110,116,101,0,0,0,0,0,0,0,109,100,95,119,115,98,57,53,112,49,53,0,0,0,0,0,65,32,49,47,49,32,66,32,49,47,54,0,0,0,0,0,87,111,114,108,100,32,83,101,114,105,101,115,32,66,97,115,101,98,97,108,108,32,39,57,53,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,49,49,48,41,0,0,0,0,115,102,50,99,101,117,97,98,50,0,0,0,0,0,0,0,70,66,73,32,76,111,103,111,0,0,0,0,0,0,0,0,65,100,100,105,116,105,111,110,97,108,32,111,98,115,116,105,99,97,108,115,0,0,0,0,87,111,114,108,100,32,72,101,114,111,101,115,32,50,32,74,101,116,32,40,65,68,77,45,48,48,55,41,40,65,68,72,45,48,48,55,41,0,0,0,65,0,0,0,105,0,0,0,114,0,0,0,32,0,0,0,71,0,0,0,97,0,0,0,108,0,0,0,108,0,0,0,101,0,0,0,116,0,0,0,0,0,0,0,162,48,0,0,239,48,0,0,166,48,0,0,174,48,0,0,227,48,0,0,236,48,0,0,195,48,0,0,200,48,0,0,32,0,0,0,40,0,0,0,69,0,0,0,117,0,0,0,114,0,0,0,111,0,0,0,112,0,0,0,101,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,109,100,95,119,115,98,57,53,112,49,54,0,0,0,0,0,65,115,116,101,114,105,120,32,97,110,100,32,116,104,101,32,80,111,119,101,114,32,111,102,32,116,104,101,32,71,111,100,115,32,40,69,117,114,111,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,111,107,105,95,98,97,110,107,0,0,0,0,0,0,0,0,112,117,115,104,109,97,110,0,102,105,110,100,95,118,105,100,101,111,95,100,114,105,118,101,114,40,41,0,0,0,0,0,87,111,114,108,100,32,83,101,114,105,101,115,32,66,97,115,101,98,97,108,108,32,39,57,53,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,49,48,57,45,84,83,84,41,0,0,0,0,0,0,0,0,49,32,99,111,105,110,115,32,52,32,99,114,101,100,105,116,0,0,0,0,0,0,0,0,109,100,95,119,115,98,57,53,112,49,55,0,0,0,0,0,83,117,112,101,114,32,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,32,45,32,116,104,101,32,116,111,117,114,110,97,109,101,110,116,32,98,97,116,116,108,101,32,40,57,51,48,57,49,49,32,101,116,99,41,0,0,0,0,87,97,114,32,111,102,32,65,101,114,111,32,45,32,80,114,111,106,101,99,116,32,77,69,73,79,85,0,0,0,0,0,77,114,46,32,75,111,117,103,97,114,32,40,98,111,111,116,108,101,103,32,115,101,116,32,49,41,0,0,0,0,0,0,87,111,114,108,100,32,83,101,114,105,101,115,32,66,97,115,101,98,97,108,108,32,39,57,53,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,49,48,53,41,0,0,0,0,83,116,97,114,116,105,110,103,32,67,111,105,110,0,0,0,104,111,110,101,121,100,111,108,0,0,0,0,0,0,0,0,115,100,102,105,103,104,116,0,109,100,95,119,115,98,57,53,112,49,56,0,0,0,0,0,80,67,32,69,110,103,105,110,101,0,0,0,0,0,0,0,106,111,121,115,116,105,99,107,95,54,98,95,115,101,108,101,99,116,91,49,93,0,0,0,50,32,99,111,105,110,115,32,61,32,49,32,99,114,101,100,105,116,0,0,0,0,0,0,87,111,114,108,100,32,83,101,114,105,101,115,32,66,97,115,101,98,97,108,108,32,39,57,53,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,49,48,51,45,84,83,84,41,0,0,0,0,0,0,0,0,115,116,114,101,97,109,32,101,114,114,111,114,0,0,0,0,50,48,107,32,116,104,101,110,32,101,118,101,114,121,32,54,48,107,0,0,0,0,0,0,109,100,95,119,115,98,57,53,112,49,57,0,0,0,0,0,83,117,112,101,114,32,80,97,110,103,32,40,87,111,114,108,100,32,57,48,48,57,49,52,41,0,0,0,0,0,0,0,51,32,40,77,105,100,100,108,101,41,0,0,0,0,0,0,87,111,114,108,100,32,83,101,114,105,101,115,32,66,97,115,101,98,97,108,108,32,39,57,53,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,49,48,49,45,84,83,84,41,0,0,0,0,0,0,0,0,80,50,32,65,116,116,97,99,107,32,80,111,119,49,0,0,106,111,121,109,97,110,0,0,71,97,117,110,116,108,101,116,32,40,50,32,80,108,97,121,101,114,115,44,32,71,101,114,109,97,110,44,32,114,101,118,32,49,41,0,0,0,0,0,109,100,95,119,115,98,57,53,112,50,48,0,0,0,0,0,50,48,75,44,32,52,48,75,44,32,101,118,101,114,121,32,54,48,75,0,0,0,0,0,52,48,75,32,49,48,48,75,32,49,56,48,75,32,51,48,48,75,32,53,48,48,75,32,49,77,0,0,0,0,0,0,65,32,49,47,49,32,66,32,49,47,53,0,0,0,0,0,78,86,32,82,65,77,0,0,51,48,107,32,32,50,48,48,107,32,53,48,48,107,0,0,87,111,114,108,100,32,83,101,114,105,101,115,32,66,97,115,101,98,97,108,108,32,39,57,53,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,50,49,52,41,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,39,32,45,32,67,104,97,109,112,105,111,110,32,69,100,105,116,105,111,110,32,40,57,50,48,51,49,51,32,85,83,65,32,98,111,111,116,108,101,103,32,115,101,116,32,49,41,0,0,0,0,0,0,0,0,68,111,110,107,101,121,32,75,105,110,103,32,74,114,46,32,40,98,111,111,116,108,101,103,32,111,102,32,68,111,110,107,101,121,32,75,111,110,103,32,74,114,46,41,0,0,0,0,115,115,102,50,116,98,114,49,0,0,0,0,0,0,0,0,49,48,48,48,48,32,54,48,48,48,48,0,0,0,0,0,109,100,95,119,115,98,57,53,112,48,49,0,0,0,0,0,109,100,95,97,115,116,101,114,112,103,112,0,0,0,0,0,87,111,114,108,100,32,83,101,114,105,101,115,32,66,97,115,101,98,97,108,108,32,39,57,53,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,50,49,51,41,0,0,0,0,103,111,116,99,104,97,0,0,49,115,116,32,38,32,101,118,101,114,121,32,50,110,100,0,46,98,114,97,109,0,0,0,109,100,95,119,115,98,57,53,112,48,50,0,0,0,0,0,56,48,75,32,49,48,48,75,43,0,0,0,0,0,0,0,39,57,57,58,32,84,104,101,32,76,97,115,116,32,87,97,114,32,40,97,108,116,101,114,110,97,116,101,41,0,0,0,109,114,107,111,117,103,98,0,87,111,114,108,100,32,83,101,114,105,101,115,32,66,97,115,101,98,97,108,108,32,39,57,53,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,50,49,50,41,0,0,0,0,57,54,0,0,0,0,0,0,50,48,107,32,53,48,107,32,49,53,48,107,32,49,48,48,107,43,0,0,0,0,0,0,109,100,95,119,115,98,57,53,112,48,51,0,0,0,0,0,49,49,45,49,49,0,0,0,87,111,114,108,100,32,83,101,114,105,101,115,32,66,97,115,101,98,97,108,108,32,39,57,53,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,50,49,49,41,0,0,0,0,52,32,67,111,105,110,115,32,52,32,80,108,97,121,115,0,70,114,101,101,122,101,32,40,67,104,101,97,116,41,0,0,97,115,105,99,51,95,122,0,109,100,95,119,115,98,57,53,112,48,52,0,0,0,0,0,87,111,114,108,100,32,83,101,114,105,101,115,32,66,97,115,101,98,97,108,108,32,39,57,53,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,50,48,57,41,0,0,0,0,109,100,95,119,115,98,57,53,112,48,53,0,0,0,0,0,67,111,99,111,110,117,116,115,32,74,97,112,97,110,0,0,65,32,49,47,49,32,66,32,49,47,51,0,0,0,0,0,87,111,114,108,100,32,83,101,114,105,101,115,32,66,97,115,101,98,97,108,108,32,39,57,53,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,50,48,57,45,66,41,0,0,115,102,50,99,101,117,97,98,108,0,0,0,0,0,0,0,67,97,114,114,105,101,114,32,65,105,114,32,87,105,110,103,32,40,85,46,83,46,32,110,97,118,121,32,57,48,49,48,48,57,32,101,116,99,41,0,0,0,0,0,0,0,0,0,78,72,75,32,69,110,116,101,114,112,114,105,115,101,0,0,75,105,110,103,32,111,102,32,116,104,101,32,77,111,110,115,116,101,114,115,32,40,115,101,116,32,49,41,0,0,0,0,110,83,111,117,110,100,83,116,97,116,117,115,0,0,0,0,109,100,95,119,115,98,57,53,112,48,54,0,0,0,0,0,76,105,110,107,117,112,32,102,101,97,116,117,114,101,32,110,111,116,32,105,109,112,108,101,109,101,110,116,101,100,0,0,65,0,0,0,115,0,0,0,116,0,0,0,233,0,0,0,114,0,0,0,105,0,0,0,120,0,0,0,32,0,0,0,97,0,0,0,110,0,0,0,100,0,0,0,32,0,0,0,116,0,0,0,104,0,0,0,101,0,0,0,32,0,0,0,80,0,0,0,111,0,0,0,119,0,0,0,101,0,0,0,114,0,0,0,32,0,0,0,111,0,0,0,102,0,0,0,32,0,0,0,116,0,0,0,104,0,0,0,101,0,0,0,32,0,0,0,71,0,0,0,111,0,0,0,100,0,0,0,115,0,0,0,32,0,0,0,40,0,0,0,69,0,0,0,117,0,0,0,114,0,0,0,111,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,87,111,114,108,100,32,83,101,114,105,101,115,32,66,97,115,101,98,97,108,108,32,39,57,53,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,50,48,55,41,0,0,0,0,109,100,95,119,115,98,57,53,112,48,55,0,0,0,0,0,79,80,76,45,62,97,100,100,114,101,115,115,0,0,0,0,77,114,46,32,75,111,117,103,97,114,32,40,101,97,114,108,105,101,114,41,0,0,0,0,87,111,114,108,100,32,83,101,114,105,101,115,32,66,97,115,101,98,97,108,108,32,39,57,53,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,50,48,51,41,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,108,105,110,107,32,112,114,111,103,114,97,109,32,35,37,117,46,10,0,0,0,0,0,0,0,67,80,83,49,0,0,0,0,71,76,95,69,88,84,95,117,110,112,97,99,107,95,115,117,98,105,109,97,103,101,0,0,109,100,95,119,115,98,57,53,112,48,56,0,0,0,0,0,83,102,50,109,100,116,83,97,109,112,108,101,66,117,102,102,101,114,50,0,0,0,0,0,87,111,114,108,100,32,83,101,114,105,101,115,32,66,97,115,101,98,97,108,108,32,39,57,53,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,50,48,50,41,0,0,0,0,79,99,101,97,110,0,0,0,109,100,95,119,115,98,57,53,112,48,57,0,0,0,0,0,83,104,97,100,101,114,32,35,37,117,32,83,99,97,108,101,0,0,0,0,0,0,0,0,51,48,75,32,55,48,75,43,0,0,0,0,0,0,0,0,87,111,114,108,100,32,83,101,114,105,101,115,32,66,97,115,101,98,97,108,108,32,39,57,53,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,49,50,50,56,45,83,66,41,0,0,0,0,0,0,0,0,0,80,50,32,65,116,116,97,99,107,32,80,111,119,48,0,0,98,105,103,107,97,114,110,107,0,0,0,0,0,0,0,0,109,100,95,119,115,98,57,53,112,50,49,0,0,0,0,0,65,32,49,47,49,32,66,32,50,47,51,0,0,0,0,0,67,117,101,32,66,114,105,99,107,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,97,118,115,112,106,0,0,0,87,111,114,108,100,32,83,101,114,105,101,115,32,66,97,115,101,98,97,108,108,32,39,57,53,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,49,50,49,52,41,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,39,32,45,32,67,104,97,109,112,105,111,110,32,69,100,105,116,105,111,110,32,40,57,50,48,51,50,50,32,74,97,112,97,110,32,98,111,111,116,108,101,103,32,115,101,116,32,50,41,0,0,0,0,0,0,78,72,75,32,84,97,105,103,97,32,68,114,97,109,97,32,45,32,84,97,105,104,101,105,107,105,0,0,0,0,0,0,87,111,114,108,100,32,72,101,114,111,101,115,32,50,32,40,65,76,77,45,48,48,54,41,40,65,76,72,45,48,48,54,41,0,0,0,0,0,0,0,109,100,95,119,115,98,57,53,112,50,50,0,0,0,0,0,65,115,116,101,114,105,120,32,97,110,100,32,116,104,101,32,80,111,119,101,114,32,111,102,32,116,104,101,32,71,111,100,115,32,40,69,117,114,111,41,0,0,0,0,0,0,0,0])
.concat([115,115,114,105,100,101,114,115,101,98,100,0,0,0,0,0,121,97,110,99,104,97,109,114,0,0,0,0,0,0,0,0,87,111,114,108,100,32,83,101,114,105,101,115,32,66,97,115,101,98,97,108,108,32,39,57,53,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,49,50,48,56,41,0,0,0,0,115,108,45,62,101,103,95,115,104,95,100,114,0,0,0,0,103,117,110,102,111,114,99,101,117,0,0,0,0,0,0,0,82,45,84,121,112,101,32,73,73,0,0,0,0,0,0,0,109,100,95,119,115,98,57,53,112,50,51,0,0,0,0,0,83,117,112,101,114,32,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,32,45,32,116,104,101,32,116,111,117,114,110,97,109,101,110,116,32,98,97,116,116,108,101,32,40,57,51,49,49,49,57,32,101,116,99,41,0,0,0,0,109,114,107,111,117,103,97,114,50,0,0,0,0,0,0,0,87,111,114,108,100,32,83,101,114,105,101,115,32,66,97,115,101,98,97,108,108,32,39,57,53,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,109,100,95,119,115,98,57,53,0,0,0,0,0,0,0,0,87,111,114,108,100,32,111,102,32,73,108,108,117,115,105,111,110,32,83,116,97,114,114,105,110,103,32,77,105,99,107,101,121,32,77,111,117,115,101,32,97,110,100,32,68,111,110,97,108,100,32,68,117,99,107,32,40,85,83,65,44,32,75,111,114,41,0,0,0,0,0,0,109,100,95,119,111,114,108,100,105,108,108,117,0,0,0,0,87,111,114,108,100,32,111,102,32,73,108,108,117,115,105,111,110,32,45,32,70,117,115,104,105,103,105,32,110,97,32,77,97,103,105,99,32,66,111,120,32,40,74,112,110,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,0,109,100,95,119,111,114,108,100,105,108,108,106,112,0,0,0,65,32,49,47,49,32,66,32,52,47,53,0,0,0,0,0,87,111,114,108,100,32,111,102,32,73,108,108,117,115,105,111,110,32,45,32,70,117,115,104,105,103,105,32,110,97,32,77,97,103,105,99,32,66,111,120,32,40,74,112,110,41,0,0,115,102,50,99,101,106,97,98,50,0,0,0,0,0,0,0,112,99,101,95,110,104,107,116,97,105,100,114,0,0,0,0,109,100,95,119,111,114,108,100,105,108,108,106,0,0,0,0,109,100,95,97,115,116,101,114,112,103,0,0,0,0,0,0,87,111,114,108,100,32,111,102,32,73,108,108,117,115,105,111,110,32,83,116,97,114,114,105,110,103,32,77,105,99,107,101,121,32,77,111,117,115,101,32,97,110,100,32,68,111,110,97,108,100,32,68,117,99,107,32,40,69,117,114,111,41,0,0,103,105,110,107,117,110,0,0,109,100,95,119,111,114,108,100,105,108,108,0,0,0,0,0,115,115,102,50,116,98,0,0,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,10,0,0,0,0,0,0,65,84,87,0,0,0,0,0,87,111,114,108,100,32,72,101,114,111,101,115,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,51,51,48,41,0,0,0,0,0,0,0,0,0,109,100,95,119,104,112,48,51,0,0,0,0,0,0,0,0,87,111,114,108,100,32,72,101,114,111,101,115,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,51,50,52,41,0,0,0,0,0,0,0,0,0,109,100,95,119,104,112,48,52,0,0,0,0,0,0,0,0,68,101,108,116,97,84,46,97,100,100,114,101,115,115,0,0,69,110,101,109,121,32,66,117,108,108,101,116,32,83,112,101,101,100,0,0,0,0,0,0,87,111,114,108,100,32,72,101,114,111,101,115,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,51,50,51,41,0,0,0,0,0,0,0,0,0,80,50,32,65,116,116,97,99,107,32,68,105,114,55,0,0,124,0,0,0,0,0,0,0,109,100,95,119,104,112,48,53,0,0,0,0,0,0,0,0,65,32,49,47,49,32,66,32,49,47,49,0,0,0,0,0,73,68,65,84,0,0,0,0,87,111,114,108,100,32,72,101,114,111,101,115,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,51,50,50,44,32,98,114,111,107,101,110,32,45,32,67,48,55,32,109,105,115,115,105,110,103,41,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,39,32,45,32,67,104,97,109,112,105,111,110,32,69,100,105,116,105,111,110,32,40,57,50,48,51,50,50,32,74,97,112,97,110,32,98,111,111,116,108,101,103,32,115,101,116,32,49,41,0,0,0,0,0,0,84,104,101,32,78,101,119,32,90,101,97,108,97,110,100,32,83,116,111,114,121,0,0,0,87,111,114,108,100,32,72,101,114,111,101,115,32,40,115,101,116,32,51,41,0,0,0,0,109,100,95,119,104,112,48,54,0,0,0,0,0,0,0,0,83,117,112,101,114,32,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,32,45,32,116,104,101,32,110,101,119,32,99,104,97,108,108,101,110,103,101,114,115,32,40,115,117,112,101,114,32,115,116,114,101,101,116,32,102,105,103,104,116,101,114,32,50,32,57,51,48,57,49,49,32,85,83,65,41,0,0,0,0,0,0,0,65,0,0,0,115,0,0,0,116,0,0,0,233,0,0,0,114,0,0,0,105,0,0,0,120,0,0,0,32,0,0,0,97,0,0,0,110,0,0,0,100,0,0,0,32,0,0,0,116,0,0,0,104,0,0,0,101,0,0,0,32,0,0,0,71,0,0,0,114,0,0,0,101,0,0,0,97,0,0,0,116,0,0,0,32,0,0,0,82,0,0,0,101,0,0,0,115,0,0,0,99,0,0,0,117,0,0,0,101,0,0,0,32,0,0,0,40,0,0,0,85,0,0,0,83,0,0,0,65,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,103,97,108,115,112,110,98,108,0,0,0,0,0,0,0,0,87,111,114,108,100,32,72,101,114,111,101,115,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,51,49,56,41,0,0,0,0,0,0,0,0,0,103,108,77,97,112,66,117,102,102,101,114,79,69,83,0,0,109,100,95,119,104,112,48,55,0,0,0,0,0,0,0,0,77,114,46,32,75,111,117,103,97,114,0,0,0,0,0,0,87,111,114,108,100,32,72,101,114,111,101,115,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,51,49,54,41,0,0,0,0,0,0,0,0,0,109,100,95,119,104,112,48,56,0,0,0,0,0,0,0,0,117,110,107,110,111,119,110,32,104,101,97,100,101,114,32,102,108,97,103,115,32,115,101,116,0,0,0,0,0,0,0,0,87,111,114,108,100,32,72,101,114,111,101,115,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,51,49,53,41,0,0,0,0,0,0,0,0,0,109,100,95,119,104,112,48,57,0,0,0,0,0,0,0,0,87,111,114,108,100,32,72,101,114,111,101,115,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,51,48,57,41,0,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,71,76,93,58,32,71,76,69,83,32,99,111,110,116,101,120,116,32,105,115,32,117,115,101,100,44,32,98,117,116,32,115,104,97,100,101,114,32,105,115,32,110,111,116,32,109,111,100,101,114,110,46,32,67,97,110,110,111,116,32,117,115,101,32,105,116,46,10,0,0,0,0,0,0,109,100,95,119,104,112,49,48,0,0,0,0,0,0,0,0,74,117,101,116,101,108,0,0,65,32,50,47,49,32,66,32,49,47,54,0,0,0,0,0,87,111,114,108,100,32,72,101,114,111,101,115,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,51,48,55,41,0,0,0,0,0,0,0,0,0,115,102,50,99,101,106,97,98,108,0,0,0,0,0,0,0,112,99,101,95,116,110,122,115,0,0,0,0,0,0,0,0,119,104,49,104,97,0,0,0,109,100,95,119,104,112,49,49,0,0,0,0,0,0,0,0,65,115,116,101,114,105,120,32,97,110,100,32,116,104,101,32,71,114,101,97,116,32,82,101,115,99,117,101,32,40,85,83,65,41,0,0,0,0,0,0,87,111,114,108,100,32,72,101,114,111,101,115,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,51,48,51,41,0,0,0,0,0,0,0,0,0,109,100,95,119,104,112,49,50,0,0,0,0,0,0,0,0,115,115,102,50,117,0,0,0,100,101,114,111,111,110,0,0,109,114,107,111,117,103,97,114,0,0,0,0,0,0,0,0,87,111,114,108,100,32,72,101,114,111,101,115,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,50,50,51,41,0,0,0,0,0,0,0,0,0,109,100,95,119,104,112,49,51,0,0,0,0,0,0,0,0,73,56,55,53,49,82,101,116,117,114,110,0,0,0,0,0,87,111,114,108,100,32,72,101,114,111,101,115,32,40,74,112,110,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,51,51,48,41,0,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,91,71,76,93,58,32,70,97,105,108,101,100,32,116,111,32,115,101,116,32,109,117,108,116,105,112,97,115,115,32,115,104,97,100,101,114,46,32,70,97,108,108,105,110,103,32,98,97,99,107,32,116,111,32,115,116,111,99,107,46,10,0,0,0,0,0,0,0,109,100,95,119,104,106,112,53,0,0,0,0,0,0,0,0,87,111,114,108,100,32,72,101,114,111,101,115,32,40,74,112,110,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,52,50,48,44,32,98,114,111,107,101,110,32,45,32,67,48,53,32,109,105,115,115,105,110,103,41,0,0,0,80,50,32,65,116,116,97,99,107,32,68,105,114,54,0,0,109,100,95,119,104,106,112,49,0,0,0,0,0,0,0,0,65,32,50,47,49,32,66,32,49,47,53,0,0,0,0,0,87,111,114,108,100,32,72,101,114,111,101,115,32,40,74,112,110,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,52,50,48,45,66,41,0,0,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,39,32,45,32,67,104,97,109,112,105,111,110,32,69,100,105,116,105,111,110,32,40,57,50,48,51,49,51,32,101,116,99,32,98,111,111,116,108,101,103,32,115,101,116,32,50,41,0,0,0,0,0,0,0,0,78,101,117,116,111,112,105,97,32,73,73,0,0,0,0,0,87,111,114,108,100,32,72,101,114,111,101,115,32,40,65,76,72,45,48,48,53,0,0,0,109,100,95,119,104,106,112,50,0,0,0,0,0,0,0,0,83,117,112,101,114,32,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,32,45,32,116,104,101,32,110,101,119,32,99,104,97,108,108,101,110,103,101,114,115,32,40,115,117,112,101,114,32,115,116,114,101,101,116,32,102,105,103,104,116,101,114,32,50,32,57,51,48,57,49,48,32,74,97,112,97,110,41,0,0,0,0,0,109,100,95,97,115,116,101,114,103,114,101,117,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,83,85,80,80,79,82,84,95,78,79,95,71,65,77,69,58,32,37,115,46,10,0,0,0,0,87,111,114,108,100,32,72,101,114,111,101,115,32,40,74,112,110,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,52,49,53,41,0,0,0,0,0,0,0,0,0,67,79,78,70,73,71,32,37,115,0,0,0,0,0,0,0,109,100,95,119,104,106,112,51,0,0,0,0,0,0,0,0,86,101,99,116,111,114,32,84,97,98,108,101,0,0,0,0,65,84,87,32,85,83,65,44,32,73,110,99,46,0,0,0,87,111,114,108,100,32,72,101,114,111,101,115,32,40,74,112,110,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,52,48,56,41,0,0,0,0,0,0,0,0,0,109,100,95,119,104,106,112,52,0,0,0,0,0,0,0,0,108,97,115,116,109,105,115,110,0,0,0,0,0,0,0,0,87,111,114,108,100,32,72,101,114,111,101,115,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,51,51,49,41,0,0,0,0,0,0,0,0,0,119,101,108,108,116,114,105,115,0,0,0,0,0,0,0,0,109,100,95,119,104,112,48,49,0,0,0,0,0,0,0,0,87,111,114,108,100,32,72,101,114,111,101,115,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,51,51,49,45,66,41,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,115,97,118,101,32,115,104,97,100,101,114,32,112,114,101,115,101,116,46,32,77,97,107,101,32,115,117,114,101,32,99,111,110,102,105,103,32,100,105,114,101,99,116,111,114,121,32,97,110,100,47,111,114,32,115,104,97,100,101,114,32,100,105,114,32,97,114,101,32,119,114,105,116,97,98,108,101,46,10,0,0,109,100,95,119,104,112,48,50,0,0,0,0,0,0,0,0,65,32,50,47,49,32,66,32,49,47,51,0,0,0,0,0,87,111,114,108,100,32,72,101,114,111,101,115,32,40,74,112,110,41,0,0,0,0,0,0,115,102,50,99,101,101,97,98,50,0,0,0,0,0,0,0,112,99,101,95,110,101,117,116,111,112,105,50,0,0,0,0,69,108,101,99,116,114,111,110,105,99,32,65,114,116,115,0,119,104,49,104,0,0,0,0,109,100,95,119,104,106,0,0,75,48,53,49,57,54,48,95,105,114,113,95,101,110,97,98,108,101,100,0,0,0,0,0,65,0,0,0,115,0,0,0,116,0,0,0,233,0,0,0,114,0,0,0,105,0,0,0,120,0,0,0,32,0,0,0,97,0,0,0,110,0,0,0,100,0,0,0,32,0,0,0,116,0,0,0,104,0,0,0,101,0,0,0,32,0,0,0,71,0,0,0,114,0,0,0,101,0,0,0,97,0,0,0,116,0,0,0,32,0,0,0,82,0,0,0,101,0,0,0,115,0,0,0,99,0,0,0,117,0,0,0,101,0,0,0,32,0,0,0,40,0,0,0,69,0,0,0,117,0,0,0,114,0,0,0,111,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,75,48,53,50,49,48,57,83,99,114,111,108,108,89,91,48,93,0,0,0,0,0,0,0,108,114,101,115,111,114,116,0,80,49,32,80,117,110,99,104,0,0,0,0,0,0,0,0,87,111,114,108,100,32,72,101,114,111,101,115,32,40,85,83,65,41,0,0,0,0,0,0,109,100,95,119,104,0,0,0,115,115,102,50,106,114,50,0,84,97,105,116,111,0,0,0,53,0,0,0,0,0,0,0,69,97,115,121,0,0,0,0,87,111,114,108,100,32,67,117,112,32,85,83,65,32,57,52,32,40,69,117,114,111,44,32,85,83,65,44,32,75,111,114,41,0,0,0,0,0,0,0,78,101,119,32,83,105,110,98,97,100,32,55,0,0,0,0,73,110,118,117,108,110,101,114,97,98,105,108,105,116,121,0,78,111,32,68,101,97,116,104,32,38,32,83,116,111,112,32,77,111,100,101,0,0,0,0,109,100,95,119,99,117,112,57,52,0,0,0,0,0,0,0,85,83,32,40,82,111,109,115,116,97,114,32,76,105,99,101,110,115,101,41,0,0,0,0,87,111,114,108,100,32,67,104,97,109,112,105,111,110,115,104,105,112,32,83,111,99,99,101,114,32,40,85,83,65,41,32,126,32,87,111,114,108,100,32,67,117,112,32,83,111,99,99,101,114,32,40,74,112,110,41,0,0,0,0,0,0,0,0,71,88,55,57,57,0,0,0,67,111,110,116,105,110,117,101,32,105,109,112,111,115,115,105,98,108,101,0,0,0,0,0,49,57,52,53,107,105,105,105,0,0,0,0,0,0,0,0,109,100,95,119,99,115,98,0,82,111,98,111,99,111,112,32,40,87,111,114,108,100,32,114,101,118,105,115,105,111,110,32,51,41,0,0,0,0,0,0,57,32,67,111,105,110,115,32,49,32,67,114,101,100,105,116,115,0,0,0,0,0,0,0,71,88,56,48,48,0,0,0,87,111,114,108,100,32,67,104,97,109,112,105,111,110,115,104,105,112,32,83,111,99,99,101,114,32,40,85,83,65,44,32,118,49,46,50,41,32,126,32,87,111,114,108,100,32,67,117,112,32,83,111,99,99,101,114,32,40,74,112,110,44,32,118,49,46,50,41,0,0,0,0,74,97,112,97,110,101,115,101,0,0,0,0,0,0,0,0,80,50,32,65,116,116,97,99,107,32,68,105,114,53,0,0,99,104,117,107,97,116,97,105,117,0,0,0,0,0,0,0,65,114,107,97,110,111,105,100,32,40,84,97,121,116,111,32,98,111,111,116,108,101,103,41,0,0,0,0,0,0,0,0,79,102,102,47,69,118,101,114,121,32,49,48,32,77,105,110,46,0,0,0,0,0,0,0,71,88,56,55,53,0,0,0,109,100,95,119,99,115,97,0,86,105,111,108,101,110,99,101,32,70,105,103,104,116,32,40,85,83,41,0,0,0,0,0,65,32,50,47,49,32,66,32,49,47,49,0,0,0,0,0,112,119,104,101,101,108,115,106,0,0,0,0,0,0,0,0,87,111,114,108,100,32,67,104,97,109,112,105,111,110,115,104,105,112,32,83,111,99,99,101,114,32,40,85,83,65,44,32,82,101,118,46,32,66,41,32,126,32,87,111,114,108,100,32,67,117,112,32,83,111,99,99,101,114,32,40,74,112,110,44,32,82,101,118,46,32,66,41,0,0,0,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,39,32,45,32,67,104,97,109,112,105,111,110,32,69,100,105,116,105,111,110,32,40,57,50,48,51,49,51,32,101,116,99,32,98,111,111,116,108,101,103,32,115,101,116,32,49,41,0,0,0,0,0,0,0,0,114,97,115,116,97,110,117,97,0,0,0,0,0,0,0,0,106,105,103,107,109,103,114,105,0,0,0,0,0,0,0,0,78,101,117,116,111,112,105,97,0,0,0,0,0,0,0,0,87,111,114,108,100,32,72,101,114,111,101,115,32,40,65,76,77,45,48,48,53,41,0,0,109,100,95,119,99,115,0,0,71,111,108,100,32,83,104,101,101,112,32,97,116,0,0,0,65,115,116,101,114,105,120,32,97,110,100,32,116,104,101,32,71,114,101,97,116,32,82,101,115,99,117,101,32,40,69,117,114,111,41,0,0,0,0,0,71,88,57,53,53,0,0,0,87,111,114,108,100,32,67,117,112,32,73,116,97,108,105,97,32,39,57,48,32,40,69,117,114,111,41,0,0,0,0,0,74,111,74,111,39,115,32,86,101,110,116,117,114,101,32,47,32,74,111,74,111,32,110,111,32,75,105,109,121,111,117,32,110,97,32,66,111,117,107,101,110,32,40,85,83,65,32,57,57,48,49,48,56,41,0,0,97,117,114,97,105,108,49,0,109,100,95,119,99,117,112,57,48,0,0,0,0,0,0,0,115,97,105,108,111,114,109,110,0,0,0,0,0,0,0,0,83,117,112,101,114,32,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,32,45,32,116,104,101,32,110,101,119,32,99,104,97,108,108,101,110,103,101,114,115,32,40,115,117,112,101,114,32,115,116,114,101,101,116,32,102,105,103,104,116,101,114,32,50,32,57,51,48,57,49,49,32,74,97,112,97,110,41,0,0,0,0,0,71,88,57,49,48,0,0,0,109,114,118,105,107,105,110,103,0,0,0,0,0,0,0,0,109,119,97,108,107,98,108,0,118,105,100,101,111,95,109,101,115,115,97,103,101,95,112,111,115,95,121,0,0,0,0,0,110,101,119,115,105,110,55,0,87,111,114,108,100,32,67,108,97,115,115,32,76,101,97,100,101,114,98,111,97,114,100,32,71,111,108,102,32,40,85,83,65,41,0,0,0,0,0,0,83,117,112,101,114,32,77,111,110,97,99,111,32,71,80,32,40,85,83,44,32,82,101,118,32,67,44,32,70,68,49,48,57,52,32,51,49,55,45,48,49,50,53,97,41,0,0,0,71,88,56,57,49,0,0,0,81,117,97,114,116,101,116,32,40,56,55,53,49,32,51,49,53,45,53,49,57,52,41,0,0,0,0,0,0,0,0,0,109,100,95,119,99,108,101,97,100,117,0,0,0,0,0,0,75,97,110,101,107,111,32,40,65,116,108,117,115,32,108,105,99,101,110,115,101,41,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,84,71,65,32,105,109,97,103,101,32,105,115,32,110,111,116,32,117,110,99,111,109,112,114,101,115,115,101,100,32,82,71,66,46,10,0,0,0,0,0,0,0,0,71,88,49,50,50,0,0,0,87,111,114,108,100,32,67,108,97,115,115,32,76,101,97,100,101,114,98,111,97,114,100,32,71,111,108,102,32,40,69,117,114,111,41,0,0,0,0,0,65,108,108,32,82,105,103,104,116,115,32,82,101,115,101,114,118,101,100,0,0,0,0,0,109,100,95,119,99,108,101,97,100,0,0,0,0,0,0,0,55,32,67,111,105,110,115,32,49,32,67,114,101,100,105,116,115,32,0,0,0,0,0,0,71,88,55,55,53,0,0,0,109,97,104,32,102,102,0,0,83,104,111,114,116,0,0,0,87,111,114,108,100,32,67,104,97,109,112,105,111,110,115,104,105,112,32,83,111,99,99,101,114,32,73,73,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,49,32,112,108,97,121,101,114,0,0,0,0,0,0,0,0,82,101,100,32,72,97,119,107,32,40,69,120,99,101,108,108,101,110,116,32,67,111,46,44,32,76,116,100,41,0,0,0,68,101,101,114,32,72,117,110,116,105,110,103,32,85,83,65,32,86,50,0,0,0,0,0,109,100,95,119,99,115,50,117,112,0,0,0,0,0,0,0,65,32,50,47,49,32,66,32,50,47,49,0,0,0,0,0,87,111,114,108,100,32,67,104,97,109,112,105,111,110,115,104,105,112,32,83,111,99,99,101,114,32,73,73,32,40,80,114,111,116,111,116,121,112,101,32,89,44,32,49,57,57,52,48,51,49,56,41,0,0,0,0,115,102,50,99,101,101,97,98,108,0,0,0,0,0,0,0,71,88,56,54,49,0,0,0,66,97,114,107,111,32,67,111,114,112,0,0,0,0,0,0,112,99,101,95,110,101,117,116,111,112,105,97,0,0,0,0,65,105,114,32,71,97,108,108,101,116,32,40,69,117,114,111,112,101,41,0,0,0,0,0,109,100,95,119,99,115,50,112,48,57,0,0,0,0,0,0,115,115,102,50,106,114,49,0,109,100,95,97,115,116,101,114,103,114,101,0,0,0,0,0,71,88,55,55,48,0,0,0,65,108,108,111,119,32,74,111,105,110,0,0,0,0,0,0,87,111,114,108,100,32,67,104,97,109,112,105,111,110,115,104,105,112,32,83,111,99,99,101,114,32,73,73,32,40,80,114,111,116,111,116,121,112,101,32,85,44,32,49,57,57,52,48,51,49,52,41,0,0,0,0,65,118,97,105,108,97,98,108,101,32,118,105,100,101,111,32,100,114,105,118,101,114,115,32,97,114,101,58,10,0,0,0,49,32,99,111,105,110,115,32,51,32,99,114,101,100,105,116,0,0,0,0,0,0,0,0,109,99,97,116,97,100,118,0,83,116,97,103,101,32,67,108,101,97,114,32,69,110,101,114,103,121,0,0,0,0,0,0,71,88,57,57,57,0,0,0,109,100,95,119,99,115,50,112,49,48,0,0,0,0,0,0,83,76,79,84,45,62,114,114,0,0,0,0,0,0,0,0,119,114,111,102,97,101,114,111,0,0,0,0,0,0,0,0,68,101,118,105,108,32,70,105,115,104,0,0,0,0,0,0,87,111,114,108,100,32,67,104,97,109,112,105,111,110,115,104,105,112,32,83,111,99,99,101,114,32,73,73,32,40,80,114,111,116,111,116,121,112,101,32,82,44,32,49,57,57,52,48,51,48,57,41,0,0,0,0,71,88,54,51,51,0,0,0,84,119,105,110,32,65,100,118,101,110,116,117,114,101,32,40,75,111,114,101,97,41,0,0,75,48,53,51,50,53,49,80,97,108,73,110,100,101,120,91,51,93,0,0,0,0,0,0,70,0,0,0,97,0,0,0,110,0,0,0,99,0,0,0,121,0,0,0,32,0,0,0,87,0,0,0,111,0,0,0,114,0,0,0,108,0,0,0,100,0,0,0,32,0,0,0,45,0,0,0,32,0,0,0,69,0,0,0,97,0,0,0,114,0,0,0,116,0,0,0,104,0,0,0,32,0,0,0,111,0,0,0,102,0,0,0,32,0,0,0,67,0,0,0,114,0,0,0,105,0,0,0,115,0,0,0,105,0,0,0,115,0,0,0,0,0,0,0,156,211,0,0,220,194,0,0,212,198,0,0,220,180,0,0,32,0,0,0,88,214,0,0,193,192,0,0,88,199,0,0,32,0,0,0,56,193,0,0,196,172,0,0,32,0,0,0,45,0,0,0,32,0,0,0,69,0,0,0,97,0,0,0,114,0,0,0,116,0,0,0,104,0,0,0,32,0,0,0,111,0,0,0,102,0,0,0,32,0,0,0,67,0,0,0,114,0,0,0,105,0,0,0,115,0,0,0,105,0,0,0,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,109,100,95,119,99,115,50,112,49,49,0,0,0,0,0,0,49,32,99,111,105,110,32,61,32,49,32,99,114,101,100,105,116,0,0,0,0,0,0,0,80,49,32,98,117,116,116,111,110,32,57,0,0,0,0,0,87,111,114,108,100,32,67,104,97,109,112,105,111,110,115,104,105,112,32,83,111,99,99,101,114,32,73,73,32,40,80,114,111,116,111,116,121,112,101,32,80,44,32,49,57,57,52,48,51,48,52,41,0,0,0,0,49,56,0,0,0,0,0,0,71,88,48,54,53,0,0,0,75,48,53,49,51,49,54,87,114,97,112,91,50,93,0,0,109,100,95,119,99,115,50,112,49,51,0,0,0,0,0,0,115,112,97,110,103,0,0,0,72,101,97,108,116,104,32,70,111,114,32,87,105,110,110,105,110,103,0,0,0,0,0,0,71,88,57,49,49,0,0,0,65,32,49,67,47,49,67,32,66,32,49,67,47,54,67,0,50,32,40,83,116,97,110,100,97,114,100,41,0,0,0,0,77,97,104,106,111,110,103,32,70,108,105,112,32,70,108,111,112,0,0,0,0,0,0,0,75,48,53,51,50,52,52,66,97,110,107,91,49,93,0,0,87,111,114,108,100,32,67,104,97,109,112,105,111,110,115,104,105,112,32,83,111,99,99,101,114,32,73,73,32,40,80,114,111,116,111,116,121,112,101,32,79,44,32,49,57,57,52,48,51,48,51,41,0,0,0,0,80,50,32,65,116,116,97,99,107,32,68,105,114,52,0,0,80,97,99,45,77,97,110,32,40,72,101,97,114,116,115,41,0,0,0,0,0,0,0,0,103,97,117,110,116,108,101,116,50,112,103,49,0,0,0,0,109,100,95,119,99,115,50,112,49,52,0,0,0,0,0,0,51,48,75,32,49,48,48,75,32,50,48,48,75,32,52,48,48,75,32,54,48,48,75,32,49,77,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,76,111,97,100,105,110,103,32,88,77,76,32,115,104,97,100,101,114,58,32,37,115,10,0,0,0,0,0,0,65,32,51,47,49,32,66,32,49,47,52,0,0,0,0,0,87,111,114,108,100,32,67,104,97,109,112,105,111,110,115,104,105,112,32,83,111,99,99,101,114,32,73,73,32,40,80,114,111,116,111,116,121,112,101,32,78,44,32,49,57,57,52,48,51,48,51,41,0,0,0,0,100,107,105,110,103,106,114,0,71,88,54,56,55,0,0,0,78,101,107,107,101,116,115,117,32,75,111,117,107,111,117,32,68,111,100,103,101,98,97,108,108,32,66,117,32,45,32,83,111,99,99,101,114,32,80,67,32,72,101,110,0,0,0,0,78,105,110,106,97,32,67,111,109,109,97,110,100,111,0,0,49,48,48,48,48,32,53,48,48,48,48,0,0,0,0,0,109,100,95,119,99,115,50,112,49,53,0,0,0,0,0,0,82,121,117,117,107,111,32,110,111,32,75,101,110,32,40,74,112,110,41,0,0,0,0,0,71,88,57,55,51,0,0,0,75,48,53,51,50,52,55,95,119,114,97,112,97,114,111,117,110,100,0,0,0,0,0,0,87,111,114,108,100,32,67,104,97,109,112,105,111,110,115,104,105,112,32,83,111,99,99,101,114,32,73,73,32,40,80,114,111,116,111,116,121,112,101,32,74,44,32,49,57,57,52,48,50,50,56,41,0,0,0,0,115,116,114,105,118,0,0,0,49,115,116,32,38,32,50,110,100,32,111,110,108,121,0,0,46,97,114,97,109,0,0,0,109,100,95,119,99,115,50,112,49,54,0,0,0,0,0,0,83,117,112,101,114,32,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,32,45,32,116,104,101,32,110,101,119,32,99,104,97,108,108,101,110,103,101,114,115,32,40,115,117,112,101,114,32,115,116,114,101,101,116,32,102,105,103,104,116,101,114,32,50,32,57,51,49,48,48,53,32,74,97,112,97,110,41,0,0,0,0,0,71,88,57,52,53,0,0,0,57,57,108,115,116,119,97,114,97,0,0,0,0,0,0,0,77,97,114,115,0,0,0,0,87,111,114,108,100,32,67,104,97,109,112,105,111,110,115,104,105,112,32,83,111,99,99,101,114,32,73,73,32,40,80,114,111,116,111,116,121,112,101,32,71,44,32,49,57,57,52,48,50,50,50,41,0,0,0,0,49,50,56,0,0,0,0,0,71,88,56,53,55,0,0,0,109,100,95,119,99,115,50,112,49,56,0,0,0,0,0,0,112,111,119,101,114,105,110,115,0,0,0,0,0,0,0,0,49,48,45,49,49,0,0,0,87,111,114,108,100,32,67,104,97,109,112,105,111,110,115,104,105,112,32,83,111,99,99,101,114,32,73,73,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,51,51,48,41,0,0,0,0,0,0,97,115,105,99,51,95,121,0,109,100,95,119,99,115,50,112,48,49,0,0,0,0,0,0,71,88,48,56,49,0,0,0,109,97,104,32,115,99,111,114,101,0,0,0,0,0,0,0,87,111,114,108,100,32,67,104,97,109,112,105,111,110,115,104,105,112,32,83,111,99,99,101,114,32,73,73,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,51,50,57,41,0,0,0,0,0,0,67,80,83,50,0,0,0,0,109,100,95,119,99,115,50,112,48,50,0,0,0,0,0,0,66,97,108,108,105,115,116,105,120,0,0,0,0,0,0,0,65,32,51,47,49,32,66,32,49,47,50,0,0,0,0,0,87,111,114,108,100,32,67,104,97,109,112,105,111,110,115,104,105,112,32,83,111,99,99,101,114,32,73,73,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,51,50,57,45,66,41,0,0,0,0,115,102,50,97,110,121,0,0,71,88,56,55,56,0,0,0,99,97,119,105,110,103,114,49,0,0,0,0,0,0,0,0,112,99,101,95,110,101,107,115,111,99,99,114,0,0,0,0,107,111,116,109,0,0,0,0,110,83,111,117,110,100,82,101,112,108,121,0,0,0,0,0,109,100,95,119,99,115,50,112,48,51,0,0,0,0,0,0,109,100,95,114,121,117,107,111,107,101,110,0,0,0,0,0,71,88,48,55,50,0,0,0,87,111,114,108,100,32,67,104,97,109,112,105,111,110,115,104,105,112,32,83,111,99,99,101,114,32,73,73,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,51,50,55,41,0,0,0,0,0,0,109,100,95,119,99,115,50,112,48,52,0,0,0,0,0,0,115,115,102,50,106,0,0,0,79,80,76,45,62,112,111,114,116,76,97,116,99,104,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,111,118,101,114,108,97,121,32,35,37,117,46,10,0,0,0,0,109,97,114,115,0,0,0,0,87,111,114,108,100,32,67,104,97,109,112,105,111,110,115,104,105,112,32,83,111,99,99,101,114,32,73,73,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,51,50,54,41,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,76,105,110,107,105,110,103,32,71,76,83,76,32,112,114,111,103,114,97,109,46,10,0,0,0,0,0,0,0,101,103,103,104,117,110,116,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,91,71,76,93,58,32,71,76,69,83,32,105,109,112,108,101,109,101,110,116,97,116,105,111,110,32,100,111,101,115,32,110,111,116,32,104,97,118,101,32,66,71,82,65,56,56,56,56,32,101,120,116,101,110,115,105,111,110,46,10,51,50,45,98,105,116,32,112,97,116,104,32,119,105,108,108,32,114,101,113,117,105,114,101,32,99,111,110,118,101,114,115,105,111,110,46,10,0,0,0,109,100,95,119,99,115,50,112,48,53,0,0,0,0,0,0,87,111,114,108,100,32,67,104,97,109,112,105,111,110,115,104,105,112,32,83,111,99,99,101,114,32,73,73,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,51,50,53,41,0,0,0,0,0,0,84,104,101,32,65,100,118,101,110,116,117,114,101,115,32,111,102,32,77,105,103,104,116,121,32,77,97,120,32,40,69,117,114,111,41,0,0,0,0,0,71,88,57,54,51,0,0,0,109,100,95,119,99,115,50,112,48,54,0,0,0,0,0,0,112,50,32,120,45,97,120,105,115,0,0,0,0,0,0,0,83,104,97,100,101,114,32,35,37,117,32,70,105,108,116,101,114,0,0,0,0,0,0,0,50,48,75,32,54,48,75,43,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,103,114,97,98,32,99,104,101,97,116,115,46,32,84,104,105,115,32,115,104,111,117,108,100,32,110,111,116,32,104,97,112,112,101,110,46,10,0,0,0,0,77,97,104,106,111,110,103,32,83,99,111,114,101,0,0,0,87,111,114,108,100,32,67,104,97,109,112,105,111,110,115,104,105,112,32,83,111,99,99,101,114,32,73,73,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,51,50,52,41,0,0,0,0,0,0,80,50,32,65,116,116,97,99,107,32,68,105,114,51,0,0,65,119,97,114,100,32,66,111,110,117,115,32,76,105,102,101,0,0,0,0,0,0,0,0,109,100,95,119,99,115,50,112,48,55,0,0,0,0,0,0,65,32,51,47,49,32,66,32,51,47,49,0,0,0,0,0,77,57,48,0,0,0,0,0,60,33,91,67,68,65,84,65,91,0,0,0,0,0,0,0,99,117,101,98,114,105,99,107,0,0,0,0,0,0,0,0,65,108,105,101,110,32,118,115,32,80,114,101,100,97,116,111,114,32,40,57,52,48,53,50,48,32,72,105,115,112,97,110,105,99,41,0,0,0,0,0,49,48,48,48,48,48,32,97,110,100,32,101,118,101,114,121,32,49,48,48,48,48,48,0,87,111,114,108,100,32,67,104,97,109,112,105,111,110,115,104,105,112,32,83,111,99,99,101,114,32,73,73,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,51,50,51,41,0,0,0,0,0,0,66,97,100,32,103,114,97,112,104,105,99,115,32,114,111,109,32,100,117,109,112,0,0,0,54,48,107,32,49,52,48,107,32,56,48,107,43,0,0,0,78,101,107,107,101,116,115,117,32,75,111,117,107,111,117,32,68,111,100,103,101,98,97,108,108,32,66,117,32,45,32,80,67,32,66,97,110,103,97,105,32,72,101,110,0,0,0,0,84,104,114,97,115,104,32,82,97,108,108,121,32,40,65,76,77,45,48,48,51,41,40,65,76,72,45,48,48,51,41,0,0,0,0,0,0,0,0,0,109,100,95,119,99,115,50,112,48,56,0,0,0,0,0,0,65,114,116,32,111,102,32,70,105,103,104,116,105,110,103,32,40,85,83,65,41,0,0,0,71,88,48,54,52,0,0,0,73,114,101,109,32,40,68,97,116,97,32,69,97,115,116,32,85,83,65,32,108,105,99,101,110,115,101,41,0,0,0,0,87,111,114,108,100,32,67,104,97,109,112,105,111,110,115,104,105,112,32,83,111,99,99,101,114,32,73,73,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,51,48,57,41,0,0,0,0,0,0,73,114,101,109,32,77,54,50,0,0,0,0,0,0,0,0,115,108,45,62,101,103,95,115,101,108,95,97,114,0,0,0,71,117,110,102,111,114,99,101,32,45,32,66,97,116,116,108,101,32,70,105,114,101,32,69,110,103,117,108,102,101,100,32,84,101,114,114,111,114,32,73,115,108,97,110,100,32,40,74,97,112,97,110,41,0,0,0,114,116,121,112,101,50,0,0,109,100,95,119,99,115,50,112,49,50,0,0,0,0,0,0,83,117,112,101,114,32,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,32,45,32,116,104,101,32,110,101,119,32,99,104,97,108,108,101,110,103,101,114,115,32,40,115,117,112,101,114,32,115,116,114,101,101,116,32,102,105,103,104,116,101,114,32,50,32,57,51,48,57,49,49,32,72,105,115,112,97,110,105,99,41,0,0,82,101,116,114,111,65,114,99,104,58,32,9,75,101,121,58,32,37,115,10,0,0,0,0,67,114,97,122,121,32,75,111,110,103,32,40,83,99,114,97,109,98,108,101,32,104,97,114,100,119,97,114,101,41,0,0,87,111,114,108,100,32,67,104,97,109,112,105,111,110,115,104,105,112,32,83,111,99,99,101,114,32,73,73,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,50,50,51,41,0,0,0,0,0,0,109,100,95,119,99,115,50,112,49,55,0,0,0,0,0,0,77,54,51,0,0,0,0,0,87,111,114,108,100,32,67,104,97,109,112,105,111,110,115,104,105,112,32,83,111,99,99,101,114,32,73,73,32,40,85,83,65,41,0,0,0,0,0,0,109,100,95,119,99,115,50,117,0,0,0,0,0,0,0,0,80,50,32,80,97,100,100,108,101,0,0,0,0,0,0,0,109,97,104,32,108,99,0,0,87,111,114,108,100,32,67,104,97,109,112,105,111,110,115,104,105,112,32,83,111,99,99,101,114,32,73,73,32,40,69,117,114,111,41,0,0,0,0,0,80,50,32,65,116,116,97,99,107,32,68,105,114,50,0,0,109,100,95,119,99,115,50,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,39,32,45,32,77,97,103,105,99,32,68,101,108,116,97,32,84,117,114,98,111,32,40,98,111,111,116,108,101,103,32,115,101,116,32,50,32,40,119,105,116,104,32,89,77,50,49,53,49,32,43,32,50,120,77,83,77,53,50,48,53,41,44,32,57,50,48,51,49,51,32,101,116,99,41,0,0,0,0,112,99,101,95,110,101,107,100,111,100,103,101,0,0,0,0,116,114,97,108,108,121,0,0,87,111,110,100,101,114,32,76,105,98,114,97,114,121,32,40,74,112,110,41,0,0,0,0,109,100,95,97,111,102,117,0,109,100,95,119,111,110,100,108,105,98,0,0,0,0,0,0,77,55,50,0,0,0,0,0,84,117,114,109,97,32,100,97,32,77,244,110,105,99,97,32,110,97,32,84,101,114,114,97,32,100,111,115,32,77,111,110,115,116,114,111,115,32,40,66,114,97,41,0,0,0,0,0,115,115,102,50,104,0,0,0,61,61,61,32,66,117,105,108,100,32,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,0,0,0,0,0,0,0,108,111,114,100,103,117,110,0,99,107,111,110,103,115,0,0,109,100,95,116,117,114,109,97,109,111,110,0,0,0,0,0,87,111,110,100,101,114,32,66,111,121,32,86,32,45,32,77,111,110,115,116,101,114,32,87,111,114,108,100,32,73,73,73,32,40,74,112,110,44,32,75,111,114,41,0,0,0,0,0,109,100,95,119,98,111,121,53,0,0,0,0,0,0,0,0,87,111,110,100,101,114,32,66,111,121,32,105,110,32,77,111,110,115,116,101,114,32,87,111,114,108,100,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,0,0,0,112,49,32,120,45,97,120,105,115,0,0,0,0,0,0,0,77,97,104,106,111,110,103,32,76,97,115,116,32,67,104,97,110,99,101,0,0,0,0,0,109,100,95,119,98,111,121,109,119,0,0,0,0,0,0,0,80,50,32,65,116,116,97,99,107,32,68,105,114,49,0,0,87,111,110,100,101,114,32,66,111,121,32,73,73,73,32,45,32,77,111,110,115,116,101,114,32,76,97,105,114,32,40,69,117,114,111,41,32,126,32,77,111,110,115,116,101,114,32,76,97,105,114,32,40,74,112,110,41,0,0,0,0,0,0,0,109,100,95,119,98,111,121,51,0,0,0,0,0,0,0,0,115,102,50,109,100,116,97,0,78,101,99,116,97,114,105,115,0,0,0,0,0,0,0,0,67,114,111,115,115,101,100,32,83,119,111,114,100,115,32,40,65,76,77,45,48,48,50,41,40,65,76,72,45,48,48,50,41,0,0,0,0,0,0,0,87,111,108,118,101,114,105,110,101,32,45,32,65,100,97,109,97,110,116,105,117,109,32,82,97,103,101,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,0,0,0,76,101,102,116,32,97,110,97,108,111,103,32,89,43,32,40,100,111,119,110,41,0,0,0,65,114,116,32,111,102,32,70,105,103,104,116,105,110,103,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,55,49,49,41,0,0,0,109,100,95,119,111,108,118,101,114,105,110,0,0,0,0,0,74,86,67,32,77,117,115,105,99,97,108,32,73,110,100,117,115,116,114,105,101,115,0,0,83,117,112,101,114,32,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,32,45,32,116,104,101,32,110,101,119,32,99,104,97,108,108,101,110,103,101,114,115,32,40,115,117,112,101,114,32,115,116,114,101,101,116,32,102,105,103,104,116,101,114,32,50,32,57,51,48,57,49,52,32,65,115,105,97,41,0,0,0,0,0,0,66,97,116,116,108,101,32,111,102,32,65,116,108,97,110,116,105,115,32,40,115,101,116,32,50,41,0,0,0,0,0,0,87,111,108,102,99,104,105,108,100,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,109,100,95,119,111,108,102,99,104,108,100,0,0,0,0,0,87,105,122,39,110,39,76,105,122,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,109,100,95,119,105,122,110,108,105,122,117,0,0,0,0,0])
.concat([80,49,32,80,97,100,100,108,101,0,0,0,0,0,0,0,109,97,104,32,98,101,116,0,87,105,122,39,110,39,76,105,122,32,45,32,84,104,101,32,70,114,97,110,116,105,99,32,87,97,98,98,105,116,32,87,101,115,99,117,101,32,40,69,117,114,111,41,0,0,0,0,80,50,32,65,116,116,97,99,107,32,68,105,114,48,0,0,109,100,95,119,105,122,110,108,105,122,0,0,0,0,0,0,83,116,97,114,32,70,105,103,104,116,101,114,0,0,0,0,87,105,110,116,101,114,32,79,108,121,109,112,105,99,32,71,97,109,101,115,32,40,85,83,65,41,0,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,39,32,45,32,77,97,103,105,99,32,68,101,108,116,97,32,84,117,114,98,111,32,40,98,111,111,116,108,101,103,32,115,101,116,32,49,32,40,119,105,116,104,32,89,77,50,49,53,49,32,43,32,50,120,77,83,77,53,50,48,53,41,44,32,57,50,48,51,49,51,32,101,116,99,41,0,0,0,0,112,99,101,95,110,101,99,116,97,114,105,115,0,0,0,0,99,114,115,119,111,114,100,0,109,100,95,119,105,110,116,111,108,117,0,0,0,0,0,0,109,100,95,97,111,102,112,0,87,105,110,116,101,114,32,79,108,121,109,112,105,99,115,32,40,74,112,110,41,0,0,0,109,100,95,119,105,110,116,111,108,106,0,0,0,0,0,0,115,115,102,50,97,114,49,0,97,116,108,97,110,116,105,115,50,0,0,0,0,0,0,0,87,105,110,116,101,114,32,79,108,121,109,112,105,99,115,32,40,69,117,114,111,41,0,0,109,100,95,119,105,110,116,111,108,0,0,0,0,0,0,0,87,105,110,116,101,114,32,67,104,97,108,108,101,110,103,101,32,40,80,114,111,116,111,116,121,112,101,41,0,0,0,0,109,100,95,119,105,110,116,99,104,97,108,112,0,0,0,0,68,114,105,118,101,111,117,116,79,107,105,66,97,110,107,0,77,97,104,106,111,110,103,32,66,101,116,0,0,0,0,0,84,104,101,32,71,97,109,101,115,58,32,87,105,110,116,101,114,32,67,104,97,108,108,101,110,103,101,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,0,0,0,109,100,95,119,105,110,116,99,104,97,108,49,0,0,0,0,87,105,110,116,101,114,32,67,104,97,108,108,101,110,103,101,32,40,69,117,114,111,44,32,85,83,65,44,32,82,101,118,46,32,49,41,0,0,0,0,115,102,50,109,100,116,0,0,78,101,99,114,111,115,32,110,111,32,89,111,117,115,97,105,0,0,0,0,0,0,0,0,97,101,114,111,102,103,116,0,66,108,117,101,39,115,32,74,111,117,114,110,101,121,32,47,32,82,97,103,117,121,32,40,65,76,77,45,48,48,49,41,40,65,76,72,45,48,48,49,41,0,0,0,0,0,0,0,109,100,95,119,105,110,116,99,104,97,108,0,0,0,0,0,65,114,116,32,111,102,32,70,105,103,104,116,105,110,103,32,40,69,117,114,111,41,0,0,82,101,116,114,111,65,114,99,104,58,32,82,101,113,117,101,115,116,105,110,103,32,117,110,107,110,111,119,110,32,99,111,110,116,101,120,116,46,10,0,87,105,109,98,108,101,100,111,110,32,67,104,97,109,112,105,111,110,115,104,105,112,32,84,101,110,110,105,115,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,41,0,0,109,100,95,119,105,109,98,108,101,100,117,112,0,0,0,0,83,117,112,101,114,32,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,32,45,32,116,104,101,32,110,101,119,32,99,104,97,108,108,101,110,103,101,114,115,32,40,115,117,112,101,114,32,115,116,114,101,101,116,32,102,105,103,104,116,101,114,32,50,32,57,51,49,48,48,53,32,65,115,105,97,41,0,0,0,0,0,0,87,105,109,98,108,101,100,111,110,32,67,104,97,109,112,105,111,110,115,104,105,112,32,84,101,110,110,105,115,32,40,85,83,65,41,0,0,0,0,0,67,111,109,115,111,102,116,0,109,100,95,119,105,109,98,108,101,100,117,0,0,0,0,0,80,115,121,99,104,111,45,78,105,99,115,32,79,115,99,97,114,32,40,74,97,112,97,110,32,114,101,118,105,115,105,111,110,32,50,41,0,0,0,0,87,105,109,98,108,101,100,111,110,32,67,104,97,109,112,105,111,110,115,104,105,112,32,84,101,110,110,105,115,32,40,74,112,110,41,0,0,0,0,0,109,100,95,119,105,109,98,108,101,100,106,0,0,0,0,0,68,114,105,118,101,111,117,116,83,111,117,110,100,78,105,98,98,108,101,0,0,0,0,0,87,105,109,98,108,101,100,111,110,32,67,104,97,109,112,105,111,110,115,104,105,112,32,84,101,110,110,105,115,32,40,69,117,114,111,41,0,0,0,0,80,50,32,66,108,111,99,107,0,0,0,0,0,0,0,0,109,100,95,119,105,109,98,108,101,100,0,0,0,0,0,0,87,105,108,108,105,97,109,115,32,65,114,99,97,100,101,39,115,32,71,114,101,97,116,101,115,116,32,72,105,116,115,32,40,85,83,65,41,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,39,32,45,32,67,104,97,109,112,105,111,110,32,69,100,105,116,105,111,110,32,40,77,101,103,97,32,67,111,32,98,111,111,116,108,101,103,32,115,101,116,32,50,44,32,57,50,48,51,49,51,32,101,116,99,41,0,0,0,0,0,0,0,112,99,101,95,110,101,99,114,111,115,0,0,0,0,0,0,100,114,116,111,109,121,0,0,109,100,95,97,114,99,97,100,101,103,104,117,0,0,0,0,109,100,95,97,111,102,0,0,80,49,32,82,111,116,97,116,101,32,82,105,103,104,116,0,66,117,108,108,101,116,45,80,114,111,111,102,32,83,111,102,116,119,97,114,101,0,0,0,87,105,108,100,32,83,110,97,107,101,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,115,115,102,50,97,0,0,0,84,104,101,32,80,105,116,0,0,0,0,0,0,0,0,0,52,0,0,0,0,0,0,0,83,116,97,114,116,32,114,97,110,107,0,0,0,0,0,0,109,100,95,119,105,108,100,115,110,97,107,0,0,0,0,0,66,97,116,116,108,101,32,111,102,32,65,116,108,97,110,116,105,115,32,40,115,101,116,32,49,41,0,0,0,0,0,0,71,97,109,101,32,84,121,112,101,0,0,0,0,0,0,0,87,104,105,112,32,82,117,115,104,32,45,32,87,97,107,117,115,101,105,32,86,111,108,116,101,103,97,115,32,110,111,32,78,97,122,111,32,40,74,112,110,41,0,0,0,0,0,0,84,97,105,119,97,110,32,40,83,112,97,99,121,32,76,105,99,101,110,115,101,41,0,0,109,100,95,119,104,105,112,114,117,115,104,106,0,0,0,0,78,117,109,98,101,114,32,111,102,32,104,101,114,111,115,0,87,104,105,112,32,82,117,115,104,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,114,111,98,111,99,111,112,119,0,0,0,0,0,0,0,0,77,106,110,113,117,101,115,116,73,110,112,117,116,0,0,0,102,105,110,97,108,98,0,0,109,100,95,119,104,105,112,114,117,115,104,0,0,0,0,0,69,110,103,108,105,115,104,0,112,50,32,102,105,114,101,32,49,53,0,0,0,0,0,0,67,104,117,107,97,32,84,97,105,115,101,110,32,40,87,111,114,108,100,41,0,0,0,0,97,114,107,97,116,97,121,116,0,0,0,0,0,0,0,0,84,114,97,105,110,105,110,103,47,68,105,102,102,105,99,117,108,116,121,0,0,0,0,0,112,105,114,97,116,101,115,0,87,104,101,114,101,32,105,110,32,84,105,109,101,32,73,115,32,67,97,114,109,101,110,32,83,97,110,100,105,101,103,111,63,32,40,66,114,97,41,0,0,0,0,0,0,0,0,0,118,105,111,102,105,103,104,116,117,0,0,0,0,0,0,0,67,111,105,110,0,0,0,0,68,111,117,98,108,101,32,65,120,108,101,32,40,85,83,32,101,97,114,108,105,101,114,41,0,0,0,0,0,0,0,0,109,100,95,99,97,114,109,110,116,105,109,98,0,0,0,0,115,102,50,109,101,103,97,50,0,0,0,0,0,0,0,0,82,97,115,116,97,110,32,40,85,83,32,82,101,118,32,49,41,0,0,0,0,0,0,0,66,111,110,122,101,32,65,100,118,101,110,116,117,114,101,32,40,85,83,41,0,0,0,0,78,101,99,114,111,109,97,110,99,101,114,0,0,0,0,0,78,105,110,106,97,32,67,111,109,98,97,116,32,40,78,71,72,45,48,48,57,41,0,0,87,104,101,114,101,32,105,110,32,84,105,109,101,32,73,115,32,67,97,114,109,101,110,32,83,97,110,100,105,101,103,111,63,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,65,114,114,111,119,32,70,108,97,115,104,32,40,87,111,114,108,100,44,32,65,108,116,41,0,0,0,0,0,0,0,0,50,32,67,111,105,110,115,32,49,32,67,114,101,100,105,116,32,52,47,51,0,0,0,0,109,100,95,99,97,114,109,110,116,105,109,0,0,0,0,0,106,111,106,111,114,49,0,0,83,101,103,97,32,47,32,87,101,115,116,111,110,101,0,0,87,104,101,114,101,32,105,110,32,116,104,101,32,87,111,114,108,100,32,73,115,32,67,97,114,109,101,110,32,83,97,110,100,105,101,103,111,63,32,40,66,114,97,41,0,0,0,0,83,117,112,101,114,32,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,32,45,32,116,104,101,32,110,101,119,32,99,104,97,108,108,101,110,103,101,114,115,32,40,115,117,112,101,114,32,115,116,114,101,101,116,32,102,105,103,104,116,101,114,32,50,32,57,51,48,57,49,49,32,101,116,99,41,0,0,0,0,0,0,0,71,111,110,98,101,101,32,110,111,32,73,39,109,32,83,111,114,114,121,32,40,51,49,53,45,53,49,49,48,44,32,74,97,112,97,110,41,0,0,0,77,105,99,104,97,101,108,32,74,97,99,107,115,111,110,39,115,32,77,111,111,110,119,97,108,107,101,114,32,40,115,101,116,32,51,44,32,87,111,114,108,100,44,32,70,68,49,48,57,52,47,56,55,53,49,32,51,49,55,45,48,49,53,57,41,0,0,0,0,0,0,0,118,105,100,101,111,95,109,101,115,115,97,103,101,95,112,111,115,95,120,0,0,0,0,0,109,100,95,99,97,114,109,110,119,108,100,98,0,0,0,0,66,111,109,98,101,114,32,40,98,111,111,116,108,101,103,32,111,102,32,83,99,114,97,109,98,108,101,41,0,0,0,0,115,109,103,112,117,0,0,0,113,117,97,114,116,101,116,97,0,0,0,0,0,0,0,0,87,104,101,114,101,32,105,110,32,116,104,101,32,87,111,114,108,100,32,73,115,32,67,97,114,109,101,110,32,83,97,110,100,105,101,103,111,63,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,77,97,103,105,99,97,108,32,67,114,121,115,116,97,108,115,32,40,74,97,112,97,110,44,32,57,50,47,48,49,47,49,51,41,0,0,0,0,0,0,109,100,95,99,97,114,109,110,119,108,100,0,0,0,0,0,68,105,115,116,114,105,98,117,116,101,114,32,85,110,105,99,111,0,0,0,0,0,0,0,87,104,101,101,108,32,111,102,32,70,111,114,116,117,110,101,32,40,85,83,65,41,0,0,89,101,115,110,111,68,105,112,0,0,0,0,0,0,0,0,56,32,67,111,105,110,115,32,49,32,67,114,101,100,105,116,115,32,0,0,0,0,0,0,66,108,109,98,121,80,111,116,87,104,101,101,108,0,0,0,109,100,95,119,104,101,101,108,102,111,114,0,0,0,0,0,80,50,32,68,105,97,108,32,82,105,103,104,116,0,0,0,76,105,102,101,0,0,0,0,114,101,100,104,97,119,107,101,0,0,0,0,0,0,0,0,87,101,97,112,111,110,108,111,114,100,32,40,85,83,65,41,0,0,0,0,0,0,0,0,100,101,101,114,104,117,110,116,100,0,0,0,0,0,0,0,107,111,114,111,107,111,114,111,0,0,0,0,0,0,0,0,49,67,95,51,67,0,0,0,85,83,65,32,38,32,67,97,110,97,100,97,0,0,0,0,109,100,95,119,101,97,112,111,110,108,100,0,0,0,0,0,77,101,103,97,32,67,111,0,118,109,101,116,97,108,0,0,73,109,112,101,114,102,101,99,116,32,71,70,88,115,44,32,78,111,32,83,111,117,110,100,0,0,0,0,0,0,0,0,71,114,97,112,104,105,99,115,0,0,0,0,0,0,0,0,112,99,101,95,110,101,99,114,111,109,99,114,0,0,0,0,110,99,111,109,98,97,116,104,0,0,0,0,0,0,0,0,87,97,121,110,101,39,115,32,87,111,114,108,100,32,40,85,83,65,41,0,0,0,0,0,109,100,95,97,114,114,111,119,49,0,0,0,0,0,0,0,109,54,50,57,53,115,105,122,101,0,0,0,0,0,0,0,109,100,95,119,97,121,110,101,119,108,100,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,102,105,110,100,32,97,110,121,32,118,105,100,101,111,32,100,114,105,118,101,114,32,110,97,109,101,100,32,34,37,115,34,10,0,56,32,67,111,105,110,115,32,51,32,67,114,101,100,105,116,115,0,0,0,0,0,0,0,87,97,121,110,101,32,71,114,101,116,122,107,121,32,97,110,100,32,116,104,101,32,78,72,76,80,65,32,65,108,108,45,83,116,97,114,115,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,0,115,115,102,50,0,0,0,0,69,105,103,104,116,32,70,111,114,99,101,115,0,0,0,0,109,100,95,119,97,121,110,101,103,0,0,0,0,0,0,0,98,111,109,98,101,114,0,0,66,97,108,108,115,32,72,97,118,101,32,69,121,101,115,0,116,119,105,110,97,100,118,107,0,0,0,0,0,0,0,0,87,97,116,101,114,87,111,114,108,100,32,40,69,117,114,111,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,49,57,57,53,63,0,0,0,49,54,0,0,0,0,0,0,109,100,95,119,97,116,101,114,119,108,100,0,0,0,0,0,65,100,118,101,110,116,117,114,101,32,81,117,105,122,32,50,32,72,97,116,101,110,97,32,72,97,116,101,110,97,32,110,111,32,68,97,105,45,66,111,117,107,101,110,32,40,74,97,112,97,110,32,57,48,48,50,50,56,41,0,0,0,0,0,50,48,48,48,48,44,32,69,118,101,114,121,32,56,48,48,48,48,0,0,0,0,0,0,110,84,97,105,116,111,67,121,99,108,101,115,83,101,103,109,101,110,116,0,0,0,0,0,45,53,58,48,48,0,0,0,65,32,49,67,47,49,67,32,66,32,49,67,47,53,67,0,49,32,40,69,97,115,121,41,0,0,0,0,0,0,0,0,87,97,114,115,111,110,103,32,40,85,83,65,41,0,0,0,112,50,32,102,105,114,101,32,49,52,0,0,0,0,0,0,112,97,99,104,101,97,114,116,0,0,0,0,0,0,0,0,71,97,117,110,116,108,101,116,32,40,50,32,80,108,97,121,101,114,115,44,32,74,97,112,97,110,101,115,101,32,114,101,118,32,50,41,0,0,0,0,67,97,101,115,97,114,32,110,111,32,89,97,98,111,117,32,73,73,32,40,74,112,110,41,0,0,0,0,0,0,0,0,51,48,75,32,56,48,75,32,49,53,48,75,0,0,0,0,49,99,95,50,67,0,0,0,109,100,95,99,97,101,115,97,114,50,0,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,39,32,45,32,67,104,97,109,112,105,111,110,32,69,100,105,116,105,111,110,32,40,77,101,103,97,32,67,111,32,98,111,111,116,108,101,103,32,115,101,116,32,49,44,32,57,50,48,51,49,51,32,101,116,99,41,0,0,0,0,0,0,0,74,117,110,105,111,114,32,75,105,110,103,32,40,98,111,111,116,108,101,103,32,111,102,32,68,111,110,107,101,121,32,75,111,110,103,32,74,114,46,41,0,0,0,0,0,0,0,0,78,97,122,111,32,110,111,32,77,97,115,113,117,101,114,97,100,101,0,0,0,0,0,0,65,32,53,47,49,32,66,32,49,47,54,0,0,0,0,0,78,105,110,106,97,32,67,111,109,98,97,116,32,40,78,71,77,45,48,48,57,41,0,0,87,97,114,114,105,111,114,32,111,102,32,82,111,109,101,32,73,73,32,40,85,83,65,41,0,0,0,0,0,0,0,0,51,48,107,32,32,56,48,107,32,32,56,48,107,43,0,0,65,114,114,111,119,32,70,108,97,115,104,32,40,87,111,114,108,100,41,0,0,0,0,0,109,100,95,119,97,114,114,105,111,114,50,0,0,0,0,0,71,46,84,32,69,110,116,101,114,112,114,105,115,101,32,73,110,99,0,0,0,0,0,0,66,111,110,117,115,32,79,99,117,114,114,101,110,99,101,0,46,112,114,97,109,0,0,0,56,32,40,78,111,114,109,97,108,41,0,0,0,0,0,0,67,97,101,115,97,114,32,110,111,32,89,97,98,111,117,32,40,74,112,110,41,0,0,0,83,117,112,101,114,32,80,117,122,122,108,101,32,70,105,103,104,116,101,114,32,73,73,32,84,117,114,98,111,32,40,83,117,112,101,114,32,80,117,122,122,108,101,32,70,105,103,104,116,101,114,32,50,32,84,117,114,98,111,32,57,54,48,53,51,49,32,72,105,115,112,97,110,105,99,41,0,0,0,0,80,114,111,109,97,0,0,0,54,32,67,111,105,110,115,32,49,32,80,108,97,121,0,0,109,100,95,99,97,101,115,97,114,0,0,0,0,0,0,0,69,120,112,108,111,114,101,114,0,0,0,0,0,0,0,0,67,111,117,110,116,100,111,119,110,32,83,112,101,101,100,0,87,97,114,114,105,111,114,32,111,102,32,82,111,109,101,32,40,85,83,65,41,0,0,0,49,48,45,49,48,0,0,0,98,105,103,116,119,105,110,0,109,100,95,119,97,114,114,105,111,114,0,0,0,0,0,0,97,115,105,99,51,95,120,0,87,97,114,112,115,112,101,101,100,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,110,84,97,105,116,111,67,121,99,108,101,115,68,111,110,101,0,0,0,0,0,0,0,0,109,100,95,119,97,114,112,115,112,101,100,0,0,0,0,0,80,50,32,68,105,97,108,32,76,101,102,116,0,0,0,0,87,97,114,108,111,99,107,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,0,0,112,99,101,95,98,97,108,108,105,115,116,120,0,0,0,0,109,100,95,119,97,114,108,111,99,107,112,0,0,0,0,0,115,102,50,109,101,103,97,0,67,97,114,114,105,101,114,32,65,105,114,32,87,105,110,103,32,40,85,46,83,46,32,110,97,118,121,32,57,48,49,48,49,50,32,101,116,99,41,0,0,0,0,0,0,0,0,0,112,99,101,95,110,97,122,111,109,97,115,113,0,0,0,0,77,117,116,97,116,105,111,110,32,78,97,116,105,111,110,32,40,78,71,77,45,48,49,52,41,40,78,71,72,45,48,49,52,41,0,0,0,0,0,0,110,83,111,117,110,100,76,97,116,99,104,0,0,0,0,0,87,97,114,108,111,99,107,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,109,100,95,97,114,114,111,119,0,0,0,0,0,0,0,0,109,100,95,119,97,114,108,111,99,107,0,0,0,0,0,0,87,97,114,100,110,101,114,32,110,111,32,77,111,114,105,32,83,112,101,99,105,97,108,32,40,74,112,110,41,0,0,0,115,112,102,50,116,104,0,0,79,80,76,45,62,112,111,114,116,68,105,114,101,99,116,105,111,110,0,0,0,0,0,0,109,100,95,119,97,114,100,110,101,114,106,0,0,0,0,0,101,120,112,108,111,114,101,114,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,99,111,109,112,105,108,101,32,102,114,97,103,109,101,110,116,32,115,104,97,100,101,114,32,35,37,117,10,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,71,76,93,58,32,66,71,82,65,56,56,56,56,32,101,120,116,101,110,115,105,111,110,32,102,111,117,110,100,32,102,111,114,32,71,76,69,83,46,10,0,0,0,0,87,97,114,100,110,101,114,32,40,85,83,65,41,0,0,0,109,100,95,119,97,114,100,110,101,114,0,0,0,0,0,0,109,100,95,109,105,103,104,116,109,97,120,0,0,0,0,0,87,97,110,105,32,87,97,110,105,32,87,111,114,108,100,32,40,74,112,110,41,0,0,0,84,97,105,116,111,70,50,83,112,114,105,116,101,66,97,110,107,66,117,102,102,101,114,101,100,0,0,0,0,0,0,0,83,104,97,100,101,114,32,35,37,117,0,0,0,0,0,0,109,100,95,119,97,110,105,119,97,110,105,0,0,0,0,0,112,49,32,102,105,114,101,32,49,51,0,0,0,0,0,0,87,97,99,107,121,32,87,111,114,108,100,115,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,56,49,57,41,0,0,0,0,0,0,105,109,112,111,114,116,115,0,50,99,95,49,99,0,0,0,99,117,101,98,114,105,99,107,106,0,0,0,0,0,0,0,97,118,115,112,104,0,0,0,109,100,95,119,119,111,114,108,100,115,112,49,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,32,45,32,67,104,97,109,112,105,111,110,32,69,100,105,116,105,111,110,32,40,65,108,112,104,97,32,77,97,103,105,99,45,70,32,98,111,111,116,108,101,103,32,115,101,116,32,55,44,32,57,50,48,51,49,51,32,101,116,99,41,0,0,53,48,107,32,49,50,48,107,32,55,48,107,43,0,0,0,78,97,120,97,116,32,83,116,97,100,105,117,109,0,0,0,77,97,103,105,99,105,97,110,32,76,111,114,100,32,40,78,71,72,45,48,48,53,41,0,0,0,0,0,0,0,0,0,111,118,101,114,108,97,121,37,117,95,100,101,115,99,37,117,95,114,97,110,103,101,95,109,111,100,0,0,0,0,0,0,87,97,99,107,121,32,87,111,114,108,100,115,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,56,49,55,41,0,0,0,0,0,0,78,97,111,109,105,99,104,105,32,79,122,97,107,105,32,110,111,32,83,117,112,101,114,32,77,97,115,116,101,114,115,32,40,74,112,110,41,0,0,0,83,117,110,115,101,116,32,82,105,100,101,114,115,32,40,52,32,80,108,97,121,101,114,115,32,118,101,114,46,32,69,65,67,41,0,0,0,0,0,0,75,105,100,32,78,105,107,105,32,45,32,82,97,100,105,99,97,108,32,78,105,110,106,97,32,40,85,83,41,0,0,0,109,100,95,119,119,111,114,108,100,115,112,50,0,0,0,0,115,108,45,62,101,103,95,115,104,95,97,114,0,0,0,0,103,117,110,102,111,114,99,101,106,0,0,0,0,0,0,0,65,105,114,32,68,117,101,108,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,87,97,99,107,121,32,87,111,114,108,100,115,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,56,48,56,41,0,0,0,0,0,0,83,117,112,101,114,32,80,117,122,122,108,101,32,70,105,103,104,116,101,114,32,73,73,32,84,117,114,98,111,32,40,83,117,112,101,114,32,80,117,122,122,108,101,32,70,105,103,104,116,101,114,32,50,32,84,117,114,98,111,32,57,54,48,53,50,57,32,65,115,105,97,41,0,0,0,0,0,0,0,0,109,100,95,119,119,111,114,108,100,115,112,51,0,0,0,0,79,109,110,105,0,0,0,0,87,97,99,107,121,32,87,111,114,108,100,115,32,40,85,83,65,41,0,0,0,0,0,0,109,100,95,119,119,111,114,108,100,115,0,0,0,0,0,0,100,100,114,97,103,111,110,51,0,0,0,0,0,0,0,0,87,97,99,107,121,32,82,97,99,101,115,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,84,97,105,116,111,70,50,83,112,114,105,116,101,66,97,110,107,0,0,0,0,0,0,0,109,100,95,119,97,99,107,121,114,97,99,0,0,0,0,0,80,49,32,65,116,116,97,99,107,32,80,111,119,50,0,0,86,82,32,84,114,111,111,112,101,114,115,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,0,0,0,55,48,107,32,97,110,100,32,50,48,48,107,0,0,0,0,109,100,95,118,114,116,114,111,111,112,0,0,0,0,0,0,115,102,50,97,109,102,55,0,112,99,101,95,110,97,120,115,116,97,100,0,0,0,0,0,109,97,103,108,111,114,100,104,0,0,0,0,0,0,0,0,86,105,120,101,110,32,51,53,55,32,40,74,112,110,41,0,0,0,0,0,0,0,0,0,109,100,95,115,109,97,115,116,101,114,115,0,0,0,0,0,109,100,95,118,105,120,101,110,51,53,55,0,0,0,0,0,86,105,114,116,117,97,108,32,80,105,110,98,97,108,108,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,115,112,102,50,116,97,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,116,97,108,32,101,114,114,111,114,32,114,101,99,101,105,118,101,100,32,105,110,58,32,34,37,115,34,10,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,116,97,107,101,32,115,99,114,101,101,110,115,104,111,116,46,0,0,0,0,0,0,109,100,95,118,112,105,110,98,97,108,108,0,0,0,0,0,83,116,114,97,102,101,32,66,111,109,98,0,0,0,0,0,86,105,114,116,117,97,108,32,66,97,114,116,32,40,87,111,114,108,100,41,0,0,0,0,109,100,95,118,98,97,114,116,0,0,0,0,0,0,0,0,86,105,114,116,117,97,32,70,105,103,104,116,101,114,32,50,32,118,115,32,84,101,107,107,101,110,32,50,0,0,0,0,84,97,105,116,111,90,56,48,66,97,110,107,0,0,0,0,109,100,95,118,102,50,116,101,107,0,0,0,0,0,0,0,112,49,32,102,105,114,101,32,49,50,0,0,0,0,0,0,86,105,114,116,117,97,32,70,105,103,104,116,101,114,32,50,32,45,32,71,101,110,101,115,105,115,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,54,48,57,50,55,41,0,0,0,0,0,0,0,0,115,105,108,107,114,111,97,100,0,0,0,0,0,0,0,0,52,48,107,32,97,110,100,32,49,52,48,107,0,0,0,0,109,100,95,118,102,50,112,49,0,0,0,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,32,45,32,67,104,97,109,112,105,111,110,32,69,100,105,116,105,111,110,32,40,65,108,112,104,97,32,77,97,103,105,99,45,70,32,98,111,111,116,108,101,103,32,115,101,116,32,54,44,32,57,50,48,51,49,51,32,101,116,99,41,0,0,78,97,120,97,116,32,79,112,101,110,0,0,0,0,0,0,65,108,112,104,97,32,68,101,110,115,104,105,32,67,111,46,0,0,0,0,0,0,0,0,86,105,114,116,117,97,32,70,105,103,104,116,101,114,32,50,32,45,32,71,101,110,101,115,105,115,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,54,48,57,50,48,41,0,0,0,0,0,0,0,0,65,114,110,111,108,100,32,80,97,108,109,101,114,32,84,111,117,114,110,97,109,101,110,116,32,71,111,108,102,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,0,109,100,95,118,102,50,112,50,0,0,0,0,0,0,0,0,86,105,114,116,117,97,32,70,105,103,104,116,101,114,32,50,32,45,32,71,101,110,101,115,105,115,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,54,48,57,49,51,41,0,0,0,0,0,0,0,0,83,117,112,101,114,32,80,117,122,122,108,101,32,70,105,103,104,116,101,114,32,73,73,32,88,32,40,83,117,112,101,114,32,80,117,122,122,108,101,32,70,105,103,104,116,101,114,32,50,32,88,32,57,54,48,53,51,49,32,74,97,112,97,110,41,0,0,0,0,0,0,0,109,100,95,118,102,50,112,51,0,0,0,0,0,0,0,0,115,116,114,102,98,111,109,98,0,0,0,0,0,0,0,0,86,105,114,116,117,97,32,70,105,103,104,116,101,114,32,50,32,45,32,71,101,110,101,115,105,115,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,54,48,56,51,48,41,0,0,0,0,0,0,0,0,109,100,95,118,102,50,112,52,0,0,0,0,0,0,0,0,86,105,114,116,117,97,32,70,105,103,104,116,101,114,32,50,32,45,32,71,101,110,101,115,105,115,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,54,48,56,49,57,41,0,0,0,0,0,0,0,0,84,97,105,116,111,73,110,112,117,116,0,0,0,0,0,0,109,100,95,118,102,50,112,53,0,0,0,0,0,0,0,0,80,49,32,65,116,116,97,99,107,32,80,111,119,49,0,0,86,105,114,116,117,97,32,70,105,103,104,116,101,114,32,50,32,45,32,71,101,110,101,115,105,115,32,40,75,111,114,41,0,0,0,0,0,0,0,0,115,116,97,114,102,103,104,116,0,0,0,0,0,0,0,0,50,48,107,32,97,110,100,32,49,48,48,107,0,0,0,0,109,100,95,118,102,50,107,0,115,102,50,97,109,102,54,0,112,99,101,95,110,97,120,111,112,101,110,0,0,0,0,0,77,97,103,105,99,105,97,110,32,76,111,114,100,32,40,78,71,77,45,48,48,53,41,0,0,0,0,0,0,0,0,0,86,105,114,116,117,97,32,70,105,103,104,116,101,114,32,50,32,45,32,71,101,110,101,115,105,115,32,40,69,117,114,111,44,32,85,83,65,41,0,0,109,100,95,97,114,110,111,108,100,112,0,0,0,0,0,0,82,111,98,111,99,111,112,32,50,32,40,74,97,112,97,110,32,118,48,46,49,49,41,0,0,0,0,0,0,0,0,0,71,97,108,65,110,97,108,111,103,80,111,114,116,49,0,0,109,100,95,118,102,50,0,0,86,105,101,119,112,111,105,110,116,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,115,112,102,50,120,106,0,0,109,100,95,118,105,101,119,112,111,105,110,112,0,0,0,0,83,99,114,97,109,98,108,101,32,40,98,111,111,116,108,101,103,63,41,0,0,0,0,0,51,48,107,32,56,48,107,32,53,48,107,43,0,0,0,0,86,105,101,119,112,111,105,110,116,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,109,100,95,118,105,101,119,112,111,105,110,0,0,0,0,0,86,101,114,121,116,101,120,32,40,74,112,110,41,0,0,0,109,100,95,118,101,114,121,116,101,120,0,0,0,0,0,0,86,101,99,116,111,114,109,97,110,32,50,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,54,48,56,50,55,41,0,0,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,32,45,32,67,104,97,109,112,105,111,110,32,69,100,105,116,105,111,110,32,40,65,108,112,104,97,32,77,97,103,105,99,45,70,32,98,111,111,116,108,101,103,32,115,101,116,32,53,44,32,57,50,48,51,49,51,32,101,116,99,41,0,0,78,97,114,97,122,117,109,111,110,111,32,83,101,110,116,97,105,32,66,117,116,97,105,32,45,32,66,108,111,111,100,121,32,87,111,108,102,0,0,0,109,100,95,118,101,99,109,97,110,50,112,50,0,0,0,0,68,105,115,110,101,121,39,115,32,65,114,105,101,108,32,116,104,101,32,76,105,116,116,108,101,32,77,101,114,109,97,105,100,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,82,101,113,117,101,115,116,105,110,103,32,79,112,101,110,71,76,32,99,111,110,116,101,120,116,44,32,98,117,116,32,82,101,116,114,111,65,114,99,104,32,105,115,32,99,111,109,112,105,108,101,100,32,97,103,97,105,110,115,116,32,79,112,101,110,71,76,69,83,50,46,32,67,97,110,110,111,116,32,117,115,101,32,72,87,32,99,111,110,116,101,120,116,46,10,0,0,0,0,86,101,99,116,111,114,109,97,110,32,50,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,54,48,56,50,54,41,0,0,0,0,0,0,0,109,100,95,118,101,99,109,97,110,50,112,51,0,0,0,0,83,117,112,101,114,32,80,117,122,122,108,101,32,70,105,103,104,116,101,114,32,73,73,32,84,117,114,98,111,32,40,83,117,112,101,114,32,80,117,122,122,108,101,32,70,105,103,104,116,101,114,32,50,32,84,117,114,98,111,32,57,54,48,54,50,48,32,85,83,65,41,0,0,0,0,0,0,0,0,0,86,101,99,116,111,114,109,97,110,32,50,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,54,48,56,49,57,41,0,0,0,0,0,0,0,115,99,114,97,109,98,108,101,98,98,0,0,0,0,0,0,109,100,95,118,101,99,109,97,110,50,112,52,0,0,0,0,111,115,99,97,114,106,50,0,86,101,99,116,111,114,109,97,110,32,50,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,54,48,56,49,54,41,0,0,0,0,0,0,0,71,97,108,78,111,105,115,101,86,111,108,117,109,101,0,0,109,100,95,118,101,99,109,97,110,50,112,53,0,0,0,0,43,52,48,0,0,0,0,0,86,101,99,116,111,114,109,97,110,32,50,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,54,48,56,49,53,41,0,0,0,0,0,0,0,80,49,32,65,116,116,97,99,107,32,80,111,119,48,0,0,109,100,95,118,101,99,109,97,110,50,112,54,0,0,0,0,86,101,99,116,111,114,109,97,110,32,50,32,40,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,0,0,0,115,102,50,97,109,102,53,0,112,99,101,95,98,108,111,100,119,111,108,102,0,0,0,0,83,0,0,0,97,0,0,0,109,0,0,0,117,0,0,0,114,0,0,0,97,0,0,0,105,0,0,0,32,0,0,0,83,0,0,0,104,0,0,0,111,0,0,0,100,0,0,0,111,0,0,0,119,0,0,0,110,0,0,0,32,0,0,0,86,0,0,0,32,0,0,0,83,0,0,0,112,0,0,0,101,0,0,0,99,0,0,0,105,0,0,0,97,0,0,0,108,0,0,0,0,0,0,0,181,48,0,0,224,48,0,0,233,48,0,0,164,48,0,0,185,48,0,0,212,48,0,0,234,48,0,0,195,48,0,0,196,48,0,0,246,150,0,0,32,0,0,0,83,0,0,0,112,0,0,0,101,0,0,0,99,0,0,0,105,0,0,0,97,0,0,0,108,0,0,0,32,0,0,0,40,0,0,0,78,0,0,0,71,0,0,0,72,0,0,0,45,0,0,0,50,0,0,0,55,0,0,0,50,0,0,0,48,0,0,0,41,0,0,0,32,0,0,0,40,0,0,0,49,0,0,0,115,0,0,0,116,0,0,0,32,0,0,0,114,0,0,0,101,0,0,0,108,0,0,0,101,0,0,0,97,0,0,0,115,0,0,0,101,0,0,0,44,0,0,0,32,0,0,0,99,0,0,0,101,0,0,0,110,0,0,0,115,0,0,0,111,0,0,0,114,0,0,0,101,0,0,0,100,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,109,100,95,118,101,99,109,97,110,50,112,49,0,0,0,0,109,100,95,97,114,105,101,108,0,0,0,0,0,0,0,0,98,106,111,117,114,110,101,121,0,0,0,0,0,0,0,0,80,49,32,82,111,116,97,116,101,32,76,101,102,116,0,0,86,101,99,116,111,114,109,97,110,32,50,32,40,85,83,65,41,0,0,0,0,0,0,0,109,100,95,118,101,99,109,97,110,50,0,0,0,0,0,0,115,112,102,50,116,0,0,0,51,0,0,0,0,0,0,0,77,117,115,105,99,0,0,0,86,101,99,116,111,114,109,97,110,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,55,50,52,41,0,0,0,0,0,0,0,0,0,83,99,114,97,109,98,108,101,32,40,80,101,116,97,99,111,32,83,46,65,46,44,32,83,112,97,110,105,115,104,32,98,111,111,116,108,101,103,41,0,0,0,0,0,0,0,0,0,49,44,53,48,48,44,48,48,48,112,116,115,32,111,110,108,121,0,0,0,0,0,0,0,109,100,95,118,101,99,109,97,110,112,51,0,0,0,0,0,86,101,99,116,111,114,109,97,110,32,40,80,114,111,116,111,116,121,112,101,44,32,65,108,116,41,0,0,0,0,0,0,109,100,95,118,101,99,109,97,110,112,50,0,0,0,0,0,82,111,98,111,99,111,112,32,40,87,111,114,108,100,32,114,101,118,105,115,105,111,110,32,52,41,0,0,0,0,0,0,43,51,48,0,0,0,0,0,86,101,99,116,111,114,109,97,110,32,40,80,114,111,116,111,116,121,112,101,41,0,0,0,50,46,53,0,0,0,0,0,99,104,117,107,97,116,97,105,0,0,0,0,0,0,0,0,80,97,100,100,108,101,32,50,32,40,98,111,111,116,108,101,103,32,111,110,32,66,108,111,99,107,32,104,97,114,100,119,97,114,101,41,0,0,0,0,109,100,95,118,101,99,109,97,110,112,49,0,0,0,0,0,86,105,111,108,101,110,99,101,32,70,105,103,104,116,32,40,87,111,114,108,100,41,0,0,112,50,32,102,105,114,101,32,0,0,0,0,0,0,0,0,100,98,108,97,120,108,101,117,0,0,0,0,0,0,0,0,86,101,99,116,111,114,109,97,110,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,32,45,32,67,104,97,109,112,105,111,110,32,69,100,105,116,105,111,110,32,40,65,108,112,104,97,32,77,97,103,105,99,45,70,32,98,111,111,116,108,101,103,32,115,101,116,32,52,44,32,57,50,48,51,49,51,32,101,116,99,41,0,0,114,97,115,116,97,110,117,0,98,111,110,122,101,97,100,118,117,0,0,0,0,0,0,0,77,114,46,32,72,101,108,105,32,110,111,32,68,97,105,98,111,117,107,101,110,32,40,65,108,116,41,0,0,0,0,0,83,97,109,117,114,97,105,32,83,104,111,100,111,119,110,32,86,32,83,112,101,99,105,97,108,32,47,32,83,97,109,117,114,97,105,32,83,112,105,114,105,116,115,32,90,101,114,111,32,83,112,101,99,105,97,108,32,40,78,71,72,45,50,55,50,48,41,32,40,49,115,116,32,114,101,108,101,97,115,101,44,32,99,101,110,115,111,114,101,100,41,0,0,0,0,0,109,100,95,118,101,99,109,97,110,0,0,0,0,0,0,0,87,111,108,102,32,84,101,97,109,0,0,0,0,0,0,0,50,32,67,111,105,110,115,32,49,32,67,114,101,100,105,116,32,53,47,51,32,54,47,52,0,0,0,0,0,0,0,0,75,117,117,103,97,32,45,32,79,112,101,114,97,116,105,111,110,32,67,111,100,101,32,39,86,97,112,111,114,32,84,114,97,105,108,39,32,40,74,112,110,41,0,0,0,0,0,0,74,0,0,0,111,0,0,0,74,0,0,0,111,0,0,0,39,0,0,0,115,0,0,0,32,0,0,0,86,0,0,0,101,0,0,0,110,0,0,0,116,0,0,0,117,0,0,0,114,0,0,0,101,0,0,0,0,0,0,0,184,48,0,0,231,48,0,0,184,48,0,0,231,48,0,0,110,48,0,0,32,0,0,0,71,89,0,0,153,89,0,0,106,48,0,0,146,81,0,0,122,150,0,0,32,0,0,0,40,0,0,0,65,0,0,0,115,0,0,0,105,0,0,0,97,0,0,0,32,0,0,0,57,0,0,0,57,0,0,0,48,0,0,0,49,0,0,0,50,0,0,0,56,0,0,0,44,0,0,0,32,0,0,0,78,0,0,0,79,0,0,0,32,0,0,0,67,0,0,0,68,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,65,117,114,97,105,108,32,40,115,101,116,32,51,44,32,85,83,44,32,117,110,112,114,111,116,101,99,116,101,100,41,0,0,0,0,0,0,0,0,0,109,100,95,107,117,117,103,97,0,0,0,0,0,0,0,0,83,117,112,101,114,32,71,101,109,32,70,105,103,104,116,101,114,32,77,105,110,105,32,77,105,120,32,40,57,55,48,57,48,52,32,72,105,115,112,97,110,105,99,41,0,0,0,0,105,109,115,111,114,114,121,106,0,0,0,0,0,0,0,0,109,119,97,108,107,0,0,0,118,105,100,101,111,95,102,111,110,116,95,115,99,97,108,101,0,0,0,0,0,0,0,0,86,97,112,111,114,32,84,114,97,105,108,32,40,85,83,65,41,0,0,0,0,0,0,0,115,99,114,97,109,112,116,0,83,117,112,101,114,32,77,111,110,97,99,111,32,71,80,32,40,87,111,114,108,100,44,32,70,68,49,48,57,52,32,51,49,55,45,48,49,50,54,41,0,0,0,0,0,0,0,0,80,111,119,101,114,32,68,111,119,110,0,0,0,0,0,0,81,117,97,114,116,101,116,32,40,82,101,118,32,65,44,32,56,55,53,49,32,51,49,55,45,117,110,107,110,111,119,110,41,0,0,0,0,0,0,0,109,100,95,118,97,112,111,114,116,114,0,0,0,0,0,0,109,103,99,114,121,115,116,108,106,0,0,0,0,0,0,0,86,97,108,105,115,32,73,73,73,32,40,74,112,110,44,32,82,101,118,46,32,65,41,0,0,0,0,0,0,0,0,0,70,99,114,97,115,104,83,97,109,112,108,101,66,117,102,102,101,114,49,0,0,0,0,0,72,111,110,103,45,75,111,110,103,47,84,97,105,119,97,110,0,0,0,0,0,0,0,0,109,100,95,118,97,108,105,115,51,106,0,0,0,0,0,0,53,32,67,111,105,110,115,32,49,32,67,114,101,100,105,116,0,0,0,0,0,0,0,0,43,50,53,0,0,0,0,0,86,97,108,105,115,32,73,73,73,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,80,49,32,65,116,116,97,99,107,32,68,105,114,55,0,0,50,48,48,44,48,48,48,47,53,48,48,44,48,48,48,0,65,102,101,103,97,32,40,78,101,119,32,86,105,115,105,111,110,32,69,110,116,46,32,108,105,99,101,110,115,101,41,0,68,101,101,114,32,72,117,110,116,105,110,103,32,85,83,65,32,86,51,46,48,0,0,0,109,100,95,118,97,108,105,115,51,0,0,0,0,0,0,0,103,102,120,95,101,110,97,98,108,101,0,0,0,0,0,0,77,117,103,101,110,32,83,101,110,115,104,105,32,86,97,108,105,115,32,40,74,112,110,41,0,0,0,0,0,0,0,0,115,102,50,97,109,102,52,0,90,105,112,32,38,32,90,97,112,0,0,0,0,0,0,0,73,110,112,117,116,115,47,79,117,116,112,117,116,115,0,0,112,99,101,95,109,114,104,101,108,105,49,0,0,0,0,0,115,97,109,115,104,53,115,112,104,111,0,0,0,0,0,0,80,108,97,121,101,114,32,67,111,110,116,114,111,108,115,0,97,103,97,108,108,101,116,0,109,100,95,118,97,108,105,115,106,0,0,0,0,0,0,0,65,114,99,117,115,32,79,100,121,115,115,101,121,32,40,74,112,110,41,0,0,0,0,0,86,97,108,105,115,32,40,85,83,65,41,0,0,0,0,0,51,32,99,111,105,110,32,49,32,99,114,101,100,105,116,0,82,101,116,114,111,65,114,99,104,58,32,85,115,105,110,103,32,72,87,32,114,101,110,100,101,114,44,32,79,112,101,110,71,76,32,100,114,105,118,101])
.concat([114,32,102,111,114,99,101,100,46,10,0,0,0,0,0,0,109,100,95,118,97,108,105,115,0,0,0,0,0,0,0,0,115,103,101,109,102,104,0,0,85,122,117,32,75,101,111,98,117,107,115,101,111,110,32,40,75,111,114,41,0,0,0,0,98,111,111,116,108,101,103,32,40,66,105,108,108,112,111,114,116,32,83,46,65,46,41,0,70,97,110,99,121,32,87,111,114,108,100,32,45,32,69,97,114,116,104,32,111,102,32,67,114,105,115,105,115,0,0,0,109,100,95,117,122,117,107,101,111,0,0,0,0,0,0,0,80,49,32,98,117,116,116,111,110,32,56,0,0,0,0,0,85,114,98,97,110,32,83,116,114,105,107,101,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,0,0,109,100,95,117,115,116,114,105,107,101,0,0,0,0,0,0,104,97,116,101,110,97,0,0,50,48,48,48,48,44,32,69,118,101,114,121,32,53,48,48,48,48,0,0,0,0,0,0,43,50,48,0,0,0,0,0,45,50,58,51,48,0,0,0,65,32,49,67,47,49,67,32,66,32,49,67,47,52,67,0,76,101,118,101,108,0,0,0,85,110,110,101,99,101,115,115,97,114,121,32,82,111,117,103,104,110,101,115,115,32,57,53,32,40,85,83,65,41,0,0,78,101,119,32,80,117,99,107,45,88,0,0,0,0,0,0,53,32,40,78,111,114,109,97,108,41,0,0,0,0,0,0,103,97,117,110,116,108,101,116,50,112,106,50,0,0,0,0,109,100,95,117,110,110,101,99,101,115,115,0,0,0,0,0,66,105,114,100,32,115,112,101,101,100,0,0,0,0,0,0,51,48,75,32,56,48,75,32,101,118,101,114,121,32,49,48,48,75,0,0,0,0,0,0,110,111,110,101,0,0,0,0,100,105,112,115,0,0,0,0,85,110,105,118,101,114,115,97,108,32,83,111,108,100,105,101,114,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,32,45,32,67,104,97,109,112,105,111,110,32,69,100,105,116,105,111,110,32,40,65,108,112,104,97,32,77,97,103,105,99,45,70,32,98,111,111,116,108,101,103,32,115,101,116,32,51,44,32,57,50,48,51,49,51,32,101,116,99,41,0,0,106,114,107,105,110,103,0,0,77,114,46,32,72,101,108,105,32,110,111,32,68,97,105,98,111,117,107,101,110,0,0,0,65,32,51,47,49,32,66,32,49,47,53,0,0,0,0,0,83,0,0,0,97,0,0,0,109,0,0,0,117,0,0,0,114,0,0,0,97,0,0,0,105,0,0,0,32,0,0,0,83,0,0,0,104,0,0,0,111,0,0,0,100,0,0,0,111,0,0,0,119,0,0,0,110,0,0,0,32,0,0,0,86,0,0,0,32,0,0,0,83,0,0,0,112,0,0,0,101,0,0,0,99,0,0,0,105,0,0,0,97,0,0,0,108,0,0,0,0,0,0,0,181,48,0,0,224,48,0,0,233,48,0,0,164,48,0,0,185,48,0,0,212,48,0,0,234,48,0,0,195,48,0,0,196,48,0,0,246,150,0,0,32,0,0,0,83,0,0,0,112,0,0,0,101,0,0,0,99,0,0,0,105,0,0,0,97,0,0,0,108,0,0,0,32,0,0,0,40,0,0,0,78,0,0,0,71,0,0,0,72,0,0,0,45,0,0,0,50,0,0,0,55,0,0,0,50,0,0,0,48,0,0,0,41,0,0,0,32,0,0,0,40,0,0,0,50,0,0,0,110,0,0,0,100,0,0,0,32,0,0,0,114,0,0,0,101,0,0,0,108,0,0,0,101,0,0,0,97,0,0,0,115,0,0,0,101,0,0,0,44,0,0,0,32,0,0,0,108,0,0,0,101,0,0,0,115,0,0,0,115,0,0,0,32,0,0,0,99,0,0,0,101,0,0,0,110,0,0,0,115,0,0,0,111,0,0,0,114,0,0,0,101,0,0,0,100,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,109,100,95,117,110,105,118,115,111,108,100,0,0,0,0,0,50,48,107,32,49,48,48,107,32,49,48,48,107,43,0,0,109,100,95,97,114,99,117,115,106,0,0,0,0,0,0,0,85,110,100,101,97,100,32,76,105,110,101,32,40,74,112,110,41,0,0,0,0,0,0,0,108,111,99,97,108,101,32,110,111,116,32,115,117,112,112,111,114,116,101,100,0,0,0,0,46,114,116,99,0,0,0,0,109,100,95,117,110,100,101,97,100,0,0,0,0,0,0,0,83,117,112,101,114,32,71,101,109,32,70,105,103,104,116,101,114,32,77,105,110,105,32,77,105,120,32,40,57,55,48,57,48,52,32,65,115,105,97,41,0,0,0,0,0,0,0,0,39,57,57,58,32,84,104,101,32,76,97,115,116,32,87,97,114,0,0,0,0,0,0,0,68,97,105,107,111,117,107,97,105,32,74,105,100,97,105,32,73,73,32,40,74,112,110,41,0,0,0,0,0,0,0,0,73,109,112,97,99,116,111,32,40,66,105,108,108,112,111,114,116,32,83,46,65,46,44,32,83,112,97,110,105,115,104,32,98,111,111,116,108,101,103,32,111,102,32,83,99,114,97,109,98,108,101,41,0,0,0,0,83,116,97,114,116,105,110,103,32,86,105,116,97,108,105,116,121,0,0,0,0,0,0,0,109,100,95,100,97,105,107,111,107,50,0,0,0,0,0,0,57,45,49,49,0,0,0,0,78,101,119,32,72,111,114,105,122,111,110,115,32,40,85,83,65,41,0,0,0,0,0,0,97,115,105,99,51,95,108,97,116,99,104,91,50,93,0,0,109,100,95,110,101,119,104,111,114,105,122,0,0,0,0,0,84,0,0,0,104,0,0,0,101,0,0,0,32,0,0,0,75,0,0,0,105,0,0,0,108,0,0,0,108,0,0,0,105,0,0,0,110,0,0,0,103,0,0,0,32,0,0,0,66,0,0,0,108,0,0,0,97,0,0,0,100,0,0,0,101,0,0,0,0,0,0,0,178,80,0,0,81,82,0,0,194,114,0,0,0,82,0,0,0,0,0,0,178,80,0,0,141,82,0,0,194,114,0,0,0,82,0,0,32,0,0,0,40,0,0,0,86,0,0,0,49,0,0,0,48,0,0,0,52,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,67,111,110,116,105,110,117,101,32,112,108,97,121,32,116,105,109,101,0,0,0,0,0,0,68,97,105,107,111,117,107,97,105,32,74,105,100,97,105,32,40,74,112,110,41,0,0,0,110,67,112,115,49,76,97,121,101,114,115,0,0,0,0,0,80,49,32,65,116,116,97,99,107,32,68,105,114,54,0,0,109,100,95,100,97,105,107,111,107,97,105,0,0,0,0,0,71,97,109,101,115,32,69,120,112,114,101,115,115,0,0,0,85,110,99,104,97,114,116,101,100,32,87,97,116,101,114,115,32,40,85,83,65,41,0,0,115,102,50,97,109,102,51,0,99,97,119,105,110,103,0,0,112,99,101,95,109,114,104,101,108,105,0,0,0,0,0,0,83,97,109,117,114,97,105,32,83,104,111,100,111,119,110,32,86,32,83,112,101,99,105,97,108,32,47,32,83,97,109,117,114,97,105,32,83,112,105,114,105,116,115,32,90,101,114,111,32,83,112,101,99,105,97,108,32,40,78,71,72,45,50,55,50,48,41,32,40,50,110,100,32,114,101,108,101,97,115,101,44,32,108,101,115,115,32,99,101,110,115,111,114,101,100,41,0,0,0,0,0,0,0,0,110,78,101,111,80,97,108,101,116,116,101,66,97,110,107,0,109,100,95,117,110,99,104,97,114,116,100,0,0,0,0,0,82,101,110,111,118,97,116,105,111,110,0,0,0,0,0,0,85,108,116,114,97,109,97,110,32,40,74,112,110,41,0,0,109,100,95,117,108,116,114,97,109,97,110,0,0,0,0,0,115,103,101,109,102,97,0,0,79,80,76,45,62,100,101,108,116,97,116,45,62,97,100,112,99,109,108,0,0,0,0,0,85,108,116,105,109,97,116,101,32,83,111,99,99,101,114,32,40,69,117,114,111,41,0,0,115,99,114,97,109,98,112,0,35,100,101,102,105,110,101,32,70,82,65,71,77,69,78,84,10,0,0,0,0,0,0,0,66,71,82,65,56,56,56,56,0,0,0,0,0,0,0,0,109,100,95,117,108,116,115,111,99,99,114,0,0,0,0,0,86,111,108,102,105,101,100,32,40,74,112,110,41,0,0,0,109,100,95,118,111,108,102,105,101,100,0,0,0,0,0,0,54,48,0,0,0,0,0,0,83,104,97,100,101,114,32,80,97,115,115,101,115,0,0,0,85,108,116,105,109,97,116,101,32,81,105,120,32,40,85,83,65,41,0,0,0,0,0,0,109,100,95,117,108,116,113,105,120,0,0,0,0,0,0,0,105,109,112,111,114,116,95,115,99,114,105,112,116,95,99,108,97,115,115,0,0,0,0,0,71,88,56,48,56,0,0,0,65,108,105,101,110,32,118,115,32,80,114,101,100,97,116,111,114,32,40,57,52,48,53,50,48,32,65,115,105,97,41,0,0,0,0,0,0,0,0,0,85,108,116,105,109,97,116,101,32,77,111,114,116,97,108,32,75,111,109,98,97,116,32,51,32,40,85,83,65,41,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,32,45,32,67,104,97,109,112,105,111,110,32,69,100,105,116,105,111,110,32,40,65,108,112,104,97,32,77,97,103,105,99,45,70,32,98,111,111,116,108,101,103,32,115,101,116,32,50,44,32,57,50,48,51,49,51,32,101,116,99,41,0,0,77,111,116,111,32,82,111,97,100,101,114,32,73,73,32,40,65,108,116,41,0,0,0,0,115,97,109,115,104,53,115,112,104,0,0,0,0,0,0,0,111,118,101,114,108,97,121,37,117,95,100,101,115,99,37,117,95,97,108,112,104,97,95,109,111,100,0,0,0,0,0,0,50,53,54,0,0,0,0,0,109,100,95,117,109,107,51,117,0,0,0,0,0,0,0,0,65,114,99,117,115,32,79,100,121,115,115,101,121,32,40,85,83,65,41,0,0,0,0,0,115,115,114,105,100,101,114,115,0,0,0,0,0,0,0,0,107,105,100,110,105,107,105,117,0,0,0,0,0,0,0,0,85,108,116,105,109,97,116,101,32,77,111,114,116,97,108,32,75,111,109,98,97,116,32,51,32,40,69,117,114,111,41,0,0,0,0,0,0,0,0,0,115,108,45,62,101,103,95,115,101,108,95,100,112,0,0,0,71,117,110,102,111,114,99,101,32,45,32,66,97,116,116,108,101,32,70,105,114,101,32,69,110,103,117,108,102,101,100,32,84,101,114,114,111,114,32,73,115,108,97,110,100,32,40,87,111,114,108,100,41,0,0,0,109,100,95,117,109,107,51,0,80,111,99,107,101,116,32,70,105,103,104,116,101,114,32,40,57,55,48,57,48,52,32,74,97,112,97,110,41,0,0,0,87,65,76,84,90,48,0,0,84,119,111,32,84,114,105,98,101,115,32,45,32,80,111,112,117,108,111,117,115,32,73,73,32,40,69,117,114,111,41,0,0,0,0,0,0,0,0,0,75,97,114,97,116,101,107,111,32,40,98,111,111,116,108,101,103,41,0,0,0,0,0,0,101,102,102,101,99,116,115,32,99,104,97,110,110,101,108,32,37,100,32,117,110,115,117,112,112,111,114,116,101,100,32,116,111,107,101,110,32,37,48,50,120,0,0,0,0,0,0,0,109,100,95,116,119,111,116,114,105,98,101,0,0,0,0,0,67,114,117,100,101,32,66,117,115,116,101,114,32,40,74,112,110,41,0,0,0,0,0,0,109,100,95,99,114,117,100,101,98,0,0,0,0,0,0,0,53,48,0,0,0,0,0,0,84,119,111,32,67,114,117,100,101,32,68,117,100,101,115,32,40,85,83,65,41,0,0,0,80,49,32,65,116,116,97,99,107,32,68,105,114,53,0,0,109,100,95,116,119,111,99,114,117,100,101,117,0,0,0,0,84,119,111,32,67,114,117,100,101,32,68,117,100,101,115,32,40,69,117,114,111,41,0,0,115,102,50,97,109,102,50,0,112,99,101,95,109,111,116,111,114,111,100,50,97,0,0,0,83,0,0,0,97,0,0,0,109,0,0,0,117,0,0,0,114,0,0,0,97,0,0,0,105,0,0,0,32,0,0,0,83,0,0,0,104,0,0,0,111,0,0,0,100,0,0,0,111,0,0,0,119,0,0,0,110,0,0,0,32,0,0,0,86,0,0,0,32,0,0,0,83,0,0,0,112,0,0,0,101,0,0,0,99,0,0,0,105,0,0,0,97,0,0,0,108,0,0,0,0,0,0,0,181,48,0,0,224,48,0,0,233,48,0,0,164,48,0,0,185,48,0,0,212,48,0,0,234,48,0,0,195,48,0,0,196,48,0,0,246,150,0,0,32,0,0,0,83,0,0,0,112,0,0,0,101,0,0,0,99,0,0,0,105,0,0,0,97,0,0,0,108,0,0,0,32,0,0,0,32,0,0,0,40,0,0,0,78,0,0,0,71,0,0,0,77,0,0,0,45,0,0,0,50,0,0,0,55,0,0,0,50,0,0,0,48,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,109,100,95,116,119,111,99,114,117,100,101,0,0,0,0,0,109,100,95,97,114,99,117,115,0,0,0,0,0,0,0,0,84,119,105,110,32,72,97,119,107,32,40,69,117,114,111,41,32,126,32,68,97,105,115,101,110,112,117,117,32,40,74,112,110,41,0,0,0,0,0,0,109,100,95,116,119,105,110,104,97,119,107,0,0,0,0,0,112,102,103,104,116,106,0,0,90,73,80,124,122,105,112,0,84,111,121,111,32,82,101,99,111,114,100,115,0,0,0,0,83,99,114,97,109,98,108,101,32,40,75,97,114,97,116,101,107,111,44,32,70,114,101,110,99,104,32,98,111,111,116,108,101,103,41,0,0,0,0,0,52,105,110,49,0,0,0,0,84,119,105,110,107,108,101,32,84,97,108,101,32,40,74,112,110,41,0,0,0,0,0,0,109,100,95,116,119,105,110,107,108,101,116,0,0,0,0,0,75,121,117,117,107,121,111,107,117,32,84,105,103,101,114,32,40,74,112,110,41,0,0,0,52,48,0,0,0,0,0,0,109,100,95,107,116,105,103,101,114,0,0,0,0,0,0,0,84,119,105,110,32,67,111,98,114,97,32,40,85,83,65,41,0,0,0,0,0,0,0,0,80,115,110,100,70,97,100,101,0,0,0,0,0,0,0,0,109,100,95,116,119,105,110,99,111,98,114,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,32,45,32,67,104,97,109,112,105,111,110,32,69,100,105,116,105,111,110,32,40,65,108,112,104,97,32,77,97,103,105,99,45,70,32,98,111,111,116,108,101,103,32,115,101,116,32,49,44,32,57,50,48,51,49,51,32,101,116,99,41,0,0,98,108,111,111,100,98,114,111,0,0,0,0,0,0,0,0,77,111,116,111,32,82,111,97,100,101,114,32,73,73,0,0,83,97,109,117,114,97,105,32,83,104,111,100,111,119,110,32,86,32,83,112,101,99,105,97,108,32,47,32,83,97,109,117,114,97,105,32,83,112,105,114,105,116,115,32,90,101,114,111,32,83,112,101,99,105,97,108,32,40,78,71,77,45,50,55,50,48,41,0,0,0,0,0,84,117,114,114,105,99,97,110,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,65,114,99,104,32,82,105,118,97,108,115,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,0,0,0,76,101,102,116,32,97,110,97,108,111,103,32,88,45,32,40,108,101,102,116,41,0,0,0,109,100,95,116,117,114,114,105,99,97,110,0,0,0,0,0,84,117,114,98,111,32,79,117,116,82,117,110,32,40,69,117,114,111,44,32,74,112,110,41,0,0,0,0,0,0,0,0,83,117,112,101,114,32,71,101,109,32,70,105,103,104,116,101,114,32,77,105,110,105,32,77,105,120,32,40,57,55,48,57,48,52,32,85,83,65,41,0,0,0,0,0,0,0,0,0,109,100,95,116,111,117,116,114,117,110,0,0,0,0,0,0,115,99,114,97,109,98,108,101,98,102,0,0,0,0,0,0,84,117,110,32,83,104,105,32,84,105,97,110,32,68,105,32,73,73,73,32,40,67,104,105,41,0,0,0,0,0,0,0,109,100,95,116,117,110,115,104,105,49,0,0,0,0,0,0,84,117,110,32,83,104,105,32,84,105,97,110,32,68,105,32,73,73,73,32,40,67,104,105,110,97,44,32,83,105,109,112,108,101,32,67,104,105,110,101,115,101,41,0,0,0,0,0,51,53,0,0,0,0,0,0,109,100,95,116,117,110,115,104,105,0,0,0,0,0,0,0,100,111,110,112,97,99,104,105,0,0,0,0,0,0,0,0,80,49,32,65,116,116,97,99,107,32,68,105,114,52,0,0,84,114,117,101,32,76,105,101,115,32,40,87,111,114,108,100,41,0,0,0,0,0,0,0,80,101,116,97,99,111,32,83,46,65,0,0,0,0,0,0,109,100,95,116,114,117,101,108,105,101,115,0,0,0,0,0,115,102,50,97,109,102,0,0,112,99,101,95,109,111,116,111,114,111,100,50,0,0,0,0,115,97,109,115,104,53,115,112,0,0,0,0,0,0,0,0,102,49,103,112,0,0,0,0,84,114,111,121,32,65,105,107,109,97,110,32,78,70,76,32,70,111,111,116,98,97,108,108,32,40,85,83,65,41,0,0,109,100,95,97,114,99,104,114,105,118,108,0,0,0,0,0,114,111,98,111,99,111,112,50,106,0,0,0,0,0,0,0,109,100,95,116,114,111,121,97,105,107,0,0,0,0,0,0,66,97,116,116,108,101,32,77,97,110,105,97,32,40,74,112,110,41,0,0,0,0,0,0,115,103,101,109,102,0,0,0,109,100,95,98,116,108,109,97,110,105,97,0,0,0,0,0,83,99,114,97,109,98,108,101,32,40,83,116,101,114,110,41,0,0,0,0,0,0,0,0,84,114,111,117,98,108,101,32,83,104,111,111,116,101,114,32,40,85,83,65,41,0,0,0,50,48,107,32,55,48,107,32,53,48,107,43,0,0,0,0,109,100,95,116,114,111,117,98,115,104,116,0,0,0,0,0,84,114,105,112,108,101,32,80,108,97,121,32,71,111,108,100,32,40,85,83,65,44,32,65,108,116,41,0,0,0,0,0,83,116,97,114,116,32,114,101,109,97,105,110,32,116,105,109,101,0,0,0,0,0,0,0,109,100,95,116,112,108,97,121,103,108,100,97,0,0,0,0,84,114,105,112,108,101,32,80,108,97,121,32,71,111,108,100,32,40,85,83,65,41,0,0,109,100,95,116,112,108,97,121,103,108,100,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,39,32,45,32,88,105,97,110,103,32,76,111,110,103,32,40,98,111,111,116,108,101,103,32,115,101,116,32,51,44,32,56,49,49,49,48,50,32,48,48,49,41,0,0,0,0,0,77,111,116,111,32,82,111,97,100,101,114,0,0,0,0,0,84,104,101,32,75,105,110,103,32,111,102,32,70,105,103,104,116,101,114,115,32,50,48,48,52,32,85,108,116,114,97,32,80,108,117,115,32,40,98,111,111,116,108,101,103,41,0,0,84,114,105,112,108,101,32,80,108,97,121,32,39,57,54,32,40,85,83,65,41,0,0,0,37,117,58,37,117,32,40,49,58,49,32,80,65,82,41,0,84,104,101,32,65,113,117,97,116,105,99,32,71,97,109,101,115,32,83,116,97,114,114,105,110,103,32,74,97,109,101,115,32,80,111,110,100,32,97,110,100,32,116,104,101,32,65,113,117,97,98,97,116,115,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,82,101,113,117,101,115,116,105,110,103,32,79,112,101,110,71,76,69,83,50,32,99,111,110,116,101,120,116,46,10,0,0,0,0,0,0,0,109,100,95,116,112,108,97,121,57,54,0,0,0,0,0,0,111,104,109,121,103,111,100,0,77,105,110,97,116,111,32,110,111,32,84,114,97,121,115,105,97,32,40,74,112,110,41,0,0,0,0,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,90,101,114,111,32,51,32,40,57,56,48,54,50,57,32,74,97,112,97,110,41,0,0,0,0,109,100,95,116,114,97,121,115,105,97,106,0,0,0,0,0,115,99,114,97,109,98,108,101,115,0,0,0,0,0,0,0,84,114,97,121,115,105,97,32,40,85,83,65,41,0,0,0,80,115,121,99,104,111,45,78,105,99,115,32,79,115,99,97,114,32,40,74,97,112,97,110,32,114,101,118,105,115,105,111,110,32,49,41,0,0,0,0,109,100,95,116,114,97,121,115,105,97,0,0,0,0,0,0,84,114,97,109,112,111,108,105,110,101,32,84,101,114,114,111,114,33,32,40,85,83,65,41,0,0,0,0,0,0,0,0,66,101,115,116,32,111,102,32,51,0,0,0,0,0,0,0,109,100,95,116,114,97,109,112,116,101,114,0,0,0,0,0,80,49,32,65,116,116,97,99,107,32,68,105,114,51,0,0,84,111,121,115,32,40,85,83,65,41,0,0,0,0,0,0,109,100,95,116,111,121,115,0,115,102,50,107,111,114,121,117,51,0,0,0,0,0,0,0,112,99,101,95,109,111,116,111,114,111,97,100,0,0,0,0,107,102,50,107,51,117,112,108,0,0,0,0,0,0,0,0,84,111,121,32,83,116,111,114,121,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,109,100,95,97,113,117,97,103,97,109,101,0,0,0,0,0,80,49,32,83,116,114,111,110,103,32,75,105,99,107,0,0,109,100,95,116,111,121,115,116,111,114,121,117,0,0,0,0,84,111,121,32,83,116,111,114,121,32,40,69,117,114,111,41,0,0,0,0,0,0,0,0,115,102,122,51,106,114,50,0,116,104,101,112,105,116,0,0,50,0,0,0,0,0,0,0,83,111,117,110,100,32,101,102,102,101,99,116,0,0,0,0,83,101,114,118,105,99,101,32,77,111,100,101,0,0,0,0,78,111,32,101,120,116,101,110,100,0,0,0,0,0,0,0,109,100,95,116,111,121,115,116,111,114,121,0,0,0,0,0,83,99,114,97,109,98,108,101,0,0,0,0,0,0,0,0,53,48,48,44,48,48,48,32,54,48,48,44,48,48,48,32,101,118,101,114,121,0,0,0,84,111,120,105,99,32,67,114,117,115,97,100,101,114,115,32,40,85,83,65,41,0,0,0,109,100,95,116,111,120,105,99,99,0,0,0,0,0,0,0,51,48,48,48,48,48,32,111,110,108,121,0,0,0,0,0,84,111,117,103,104,109,97,110,32,67,111,110,116,101,115,116,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,114,111,98,111,99,111,112,0,77,97,116,99,104,32,84,121,112,101,0,0,0,0,0,0,68,114,105,118,101,32,79,117,116,0,0,0,0,0,0,0,109,100,95,116,111,117,103,104,109,97,110,0,0,0,0,0,80,49,32,65,116,116,97,99,107,32,68,105,114,50,0,0,75,97,103,101,107,105,32,40,104,97,99,107,41,0,0,0,112,97,100,100,108,101,50,0,84,111,116,97,108,32,70,111,111,116,98,97,108,108,32,40,69,117,114,111,41,0,0,0,84,97,105,116,111,32,65,109,101,114,105,99,97,0,0,0,118,105,111,102,105,103,104,116,0,0,0,0,0,0,0,0,68,111,117,98,108,101,32,65,120,108,101,32,40,85,83,41,0,0,0,0,0,0,0,0,109,100,95,116,111,116,108,102,111,111,116,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,39,32,45,32,88,105,97,110,103,32,76,111,110,103,32,40,98,111,111,116,108,101,103,32,115,101,116,32,50,44,32,56,49,49,49,48,50,32,48,48,49,41,0,0,0,0,0,82,97,115,116,97,110,32,40,87,111,114,108,100,41,0,0,66,111,110,122,101,32,65,100,118,101,110,116,117,114,101,32,40,87,111,114,108,100,44,32,79,108,100,101,114,41,0,0,77,111,114,105,116,97,32,83,104,111,117,103,105,32,80,67,0,0,0,0,0,0,0,0,84,104,101,32,75,105,110,103,32,111,102,32,70,105,103,104,116,101,114,115,32,50,48,48,52,32,80,108,117,115,32,47,32,72,101,114,111,32,40,98,111,111,116,108,101,103,41,0,0,0,0,0,0,0,0,0,84,111,107,105,111,32,47,32,83,99,114,97,109,98,108,101,32,70,111,114,109,97,116,105,111,110,32,40,98,111,111,116,108,101,103,41,0,0,0,0,84,111,112,32,80,114,111,32,71,111,108,102,32,50,32,40,74,112,110,41,0,0,0,0,67,38,69,0,0,0,0,0,112,49,32,115,101,108,101,99,116,0,0,0,0,0,0,0,109,100,95,116,111,112,103,111,108,102,50,0,0,0,0,0,74,111,74,111,39,115,32,86,101,110,116,117,114,101,32,47,32,74,111,74,111,32,110,111,32,75,105,109,121,111,117,32,110,97,32,66,111,117,107,101,110,32,40,65,115,105,97,32,57,57,48,49,50,56,44,32,78,79,32,67,68,41,0,0,97,117,114,97,105,108,0,0,84,111,112,32,80,114,111,32,71,111,108,102,32,40,74,112,110,41,0,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,90,101,114,111,32,51,32,40,57,56,48,55,50,55,32,74,97,112,97,110,41,0,0,0,0,73,39,109,32,83,111,114,114,121,32,40,51,49,53,45,53,49,49,48,44,32,85,83,41,0,0,0,0,0,0,0,0,76,97,115,101,114,32,71,104,111,115,116,32,40,115,101,116,32,49,44,32,85,83,44,32,51,49,55,45,48,49,54,53,41,0,0,0,0,0,0,0,109,100,95,116,111,112,103,111,108,102,0,0,0,0,0,0,84,104,101,32,69,110,100,32,40,83,116,101,114,110,41,0,0,0,0,0,0,0,0,0,118,105,100,101,111,95,102,111,110,116,95,101,110,97,98,108,101,0,0,0,0,0,0,0,115,109,103,112,53,0,0,0,49,58,52,48,0,0,0,0,113,117,97,114,116,101,116,0,84,111,112,32,71,101,97,114,32,50,32,40,85,83,65,41,0,0,0,0,0,0,0,0,77,97,103,105,99,97,108,32,67,114,121,115,116,97,108,115,32,40,87,111,114,108,100,44,32,57,49,47,49,50,47,49,48,41,0,0,0,0,0,0,109,100,95,116,111,112,103,101,97,114,50,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,111,112,101,110,32,66,83,86,32,102,105,108,101,32,34,37,115,34,32,102,111,114,32,112,108,97,121,98,97,99,107,46,10,0,80,108,97,121,32,84,105,109,101,32,80,52,0,0,0,0,84,111,110,121,32,76,97,32,82,117,115,115,97,32,66,97,115,101,98,97,108,108,32,40,85,83,65,44,32,79,99,101,97,110,105,97,41,0,0,0,77,97,120,32,82,111,117,110,100,115,0,0,0,0,0,0,109,100,95,108,97,114,117,115,115,97,0,0,0,0,0,0,80,49,32,65,116,116,97,99,107,32,68,105,114,49,0,0,49,53,48,44,48,48,48,47,52,48,48,44,48,48,48,0,82,101,100,32,72,97,119,107,32,40,85,83,41,0,0,0,54,32,99,111,105,110,115,32,49,32,99,114,101,100,105,116,0,0,0,0,0,0,0,0,100,101,101,114,104,117,110,116,99,0,0,0,0,0,0,0,84,111,109,32,97,110,100,32,74,101,114,114,121,32,45,32,70,114,97,110,116,105,99,32,65,110,116,105,99,115,32,40,85,83,65,44,32,49,57,57,52,41,0,0,0,0,0,0,69,114,97,115,101,32,66,97,99,107,117,112,32,82,97,109,0,0,0,0,0,0,0,0,109,100,95,116,111,109,106,101,114,114,121,49,0,0,0,0,115,102,50,107,111,114,121,117,50,0,0,0,0,0,0,0,122,105,112,122,97,112,0,0,112,99,101,95,109,111,114,105,116,97,115,104,0,0,0,0,107,102,50,107,51,112,108,0,80,0,0,0,114,0,0,0,101,0,0,0,116,0,0,0,116,0,0,0,121,0,0,0,32,0,0,0,83,0,0,0,111,0,0,0,108,0,0,0,100,0,0,0,105,0,0,0,101,0,0,0,114,0,0,0,32,0,0,0,83,0,0,0,97,0,0,0,105,0,0,0,108,0,0,0,111,0,0,0,114,0,0,0,32,0,0,0,77,0,0,0,111,0,0,0,111,0,0,0,110,0,0,0,0,0,0,0,142,127,0,0,17,92,0,0,115,89,0,0,38,98,0,0,235,88,0,0,32,0,0,0,187,48,0,0,252,48,0,0,233,48,0,0,252,48,0,0,224,48,0,0,252,48,0,0,243,48,0,0,32,0,0,0,40,0,0,0,118,0,0,0,101,0,0,0,114,0,0,0,46,0,0,0,32,0,0,0,57,0,0,0,53,0,0,0,47,0,0,0,48,0,0,0,51,0,0,0,47,0,0,0,50,0,0,0,50,0,0,0,44,0,0,0,32,0,0,0,72,0,0,0,111,0,0,0,110,0,0,0,103,0,0,0,32,0,0,0,75,0,0,0,111,0,0,0,110,0,0,0,103,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,111,109,32,97,110,100,32,74,101,114,114,121,32,45,32,70,114,97,110,116,105,99,32,65,110,116,105,99,115,32,40,85,83,65,44,32,49,57,57,51,41,0,0,0,0,0,0,65,113,32,82,101,110,107,97,110,32,65,119,97,32,40,67,104,105,41,0,0,0,0,0,104,121,112,101,114,112,97,99,0,0,0,0,0,0,0,0,52,48,32,115,0,0,0,0,109,100,95,116,111,109,106,101,114,114,121,0,0,0,0,0,50,32,99,111,105,110,32,49,32,99,114,101,100,105,116,115,0,0,0,0,0,0,0,0,102,105,110,100,95,105,110,112,117,116,95,100,114,105,118,101,114,40,41,0,0,0,0,0,84,111,107,105,32,45,32,71,111,105,110,103,32,65,112,101,32,83,112,105,116,32,126,32,74,117,74,117,32,68,101,110,115,101,116,115,117,32,40,87,111,114,108,100,41,0,0,0,115,102,122,51,106,114,49,0,101,105,103,104,116,102,114,99,0,0,0,0,0,0,0,0,109,100,95,116,111,107,105,49,0,0,0,0,0,0,0,0,116,104,101,101,110,100,115,0,84,119,105,110,32,65,100,118,101,110,116,117,114,101,32,40,87,111,114,108,100,41,0,0,84,111,107,105,32,45,32,71,111,105,110,103,32,65,112,101,32,83,112,105,116,32,126,32,74,117,74,117,32,68,101,110,115,101,116,115,117,32,40,87,111,114,108,100,44,32,82,101,118,46,32,65,41,0,0,0,109,100,95,116,111,107,105,0,70,49,32,85,112,32,80,111,105,110,116,0,0,0,0,0,50,110,100,32,66,111,110,117,115,32,76,105,102,101,0,0,84,111,101,32,74,97,109,32,38,32,69,97,114,108,32,105,110,32,80,97,110,105,99,32,111,110,32,70,117,110,107,111,116,114,111,110,32,40,85,83,65,41,0,0,0,0,0,0,67,97,112,99,111,109,32,87,111,114,108,100,32,40,74,97,112,97,110,41,0,0,0,0,84,105,109,101,114,32,83,112,101,101,100,0,0,0,0,0,65,32,49,67,47,49,67,32,66,32,49,67,47,51,67,0,109,100,95,116,111,101,106,97,109,50,117,0,0,0,0,0,80,49,32,65,116,116,97,99,107,32,68,105,114,48,0,0,110,101,119,112,117,99,107,120,0,0,0,0,0,0,0,0,71,97,117,110,116,108,101,116,32,40,50,32,80,108,97,121,101,114,115,44,32,114,101,118,32,51,41,0,0,0,0,0,84,111,101,32,74,97,109,32,38,32,69,97,114,108,32,105,110,32,80,97,110,105,99,32,111,110,32,70,117,110,107,111,116,114,111,110,32,40,74,112,110,41,0,0,0,0,0,0,68,105,115,112,108,97,121,32,83,99,111,114,101,0,0,0,51,48,75,32,56,48,75,32,49,51,48,75,32,51,48,48,75,32,53,48,48,75,32,49,77,0,0,0,0,0,0,0,109,100,95,116,111,101,106,97,109,50,106,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,39,32,45,32,88,105,97,110,103,32,76,111,110,103,32,40,98,111,111,116,108,101,103,32,115,101,116,32,49,44,32,56,49,49,49,48,50,32,48,48,49,41,0,0,0,0,0,65,83,75,0,0,0,0,0,84,104,101,32,75,105,110,103,32,111,102,32,70,105,103,104,116,101,114,115,32,50,48,48,51,32,40,98,111,111,116,108,101,103,32,115,101,116,32,50,41,0,0,0,0,0,0,0,84,111,101,32,74,97,109,32,38,32,69,97,114,108,32,105,110,32,80,97,110,105,99,32,97,117,102,32,70,117,110,107,111,116,114,111,110,32,40,71,101,114,41,0,0,0,0,0,50,48,107,32,32,56,48,107,32,32,56,48,107,43,0,0,83,97,109,101,32,86,97,108,117,101,32,97,115,32,67,111,105,110,32,65,0,0,0,0,109,100,95,97,113,114,101,110,107,0,0,0,0,0,0,0,49,48,107,32,65,110,100,32,69,118,101,114,121,32,50,48,107,0,0,0,0,0,0,0,109,100,95,116,111,101,106,97,109,50,103,0,0,0,0,0,76,111,118,101,114,32,66,111,121,0,0,0,0,0,0,0,70,105,114,115,116,32,49,67,95,50,67,44,32,116,104,101,110,32,49,67,95,49,67,0,84,111,101,32,74,97,109,32,38,32,69,97,114,108,32,105,110,32,80,97,110,105,99,32,111,110,32,70,117,110,107,111,116,114,111,110,32,40,69,117,114,111,41,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,90,101,114,111,32,51,32,40,57,56,48,57,48,52,32,74,97,112,97,110,41,0,0,0,0,57,57,108,115,116,119,97,114,0,0,0,0,0,0,0,0,66,97,99,107,103,114,111,117,110,100,32,77,117,115,105,99,0,0,0,0,0,0,0,0,109,100,95,116,111,101,106,97,109,50,0,0,0,0,0,0,84,104,101,32,69,110,100,0,0,0,0,0,0,0,0,0,120,51,0,0,0,0,0,0,84,111,101,32,74,97,109,32,38,32,69,97,114,108,32,40,87,111,114,108,100,41,0,0,49,80,32,83,116,97,114,116,105,110,103,32,83,99,111,114,101,0,0,0,0,0,0,0,66,117,121,32,105,110,32,68,117,114,105,110,103,32,70,105,110,97,108,32,82,111,117,110,100,0,0,0,0,0,0,0,109,100,95,116,111,101,106,97,109,97,0,0,0,0,0,0,52,32,67,111,105,110,115,32,50,32,80,108,97,121,115,0,97,115,105,99,51,95,108,97,116,99,104,91,49,93,0,0,84,111,101,32,74,97,109,32,38,32,69,97,114,108,32,40,87,111,114,108,100,44,32,82,101,118,46,32,65,41,0,0,84,104,101,32,75,105,108,108,105,110,103,32,66,108,97,100,101,32,40,86,49,48,52,41,0,0,0,0,0,0,0,0,66,105,103,103,101,115,116,0,109,100,95,116,111,101,106,97,109,0,0,0,0,0,0,0,83,108,105,109,101,32,87,111,114,108,100,32,40,74,112,110,41,0,0,0,0,0,0,0,65,86,32,80,111,107,101,114,0,0,0,0,0,0,0,0,109,100,95,115,108,105,109,101,119,106,0,0,0,0,0,0,115,102,50,107,111,114,121,117,0,0,0,0,0,0,0,0,67,97,112,116,97,105,110,32,67,111,109,109,97,110,100,111,32,40,98,111,111,116,108,101,103,32,115,101,116,32,50,32,40,119,105,116,104,32,89,77,50,49,53,49,32,43,32,50,120,77,83,77,53,50,48,53,41,44,32,57,49,49,48,49,52,32,111,116,104,101,114,32,99,111,117,110,116,114,121,41,0,0,0,0,0,0,0,0,77,111,110,115,116,101,114,32,80,114,111,32,87,114,101,115,0,0,0,0,0,0,0,0,107,102,50,107,51,98,108,97,0,0,0,0,0,0,0,0,110,83,112,114,105,116,101,70,114,97,109,101,84,105,109,101,114,0,0,0,0,0,0,0,84,111,100,100,39,115,32,65,100,118,101,110,116,117,114,101,115,32,105,110,32,83,108,105,109,101,32,87,111,114,108,100,32,40,85,83,65,41,0,0,79,117,116,32,111,102,32,116,104,105,115,32,87,111,114,108,100,32,40,80,114,111,116,111,116,121,112,101,41,0,0,0,109,100,95,115,108,105,109,101,119,0,0,0,0,0,0,0,84,78,78,32,79,117,116,100,111,111,114,115,32,66,97,115,115,32,84,111,117,114,110,97,109,101,110,116,32,39,57,54,32,40,85,83,65,41,0,0,115,102,122,51,106,0,0,0,79,80,76,45,62,100,101,108,116,97,116,45,62,97,100,112,99,109,100,0,0,0,0,0,109,100,95,116,110,110,111,117,116,0,0,0,0,0,0,0,65,109,105,100,97,114,32,40,83,99,114,97,109,98,108,101,32,104,97,114,100,119,97,114,101,41,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,70,111,117,110,100,32,71,76,83,76,32,102,114,97,103,109,101,110,116,32,115,104,97,100,101,114,46,10,0,84,78,78,32,66,97,115,115,32,84,111,117,114,110,97,109,101,110,116,32,111,102,32,67,104,97,109,112,105,111,110,115,32,40,85,83,65,41,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,71,76,93,58,32,70,97,105,108,101,100,32,116,111,32,105,110,105,116,32,115,104,97,100,101,114,44,32,102,97,108,108,105,110,103,32,98,97,99,107,32,116,111,32,115,116,111,99,107,46,10,0,0,0,0,0,0,0,10,0,0,0,0,0,0,0,109,100,95,116,110,110,98,97,115,115,0,0,0,0,0,0,37,115,37,115,0,0,0,0,84,104,101,32,65,100,118,101,110,116,117,114,101,115,32,111,102,32,66,97,116,109,97,110,32,38,32,82,111,98,105,110,32,40,69,117,114,111,41,0,0,0,0,0,0,0,0,0,84,105,110,121,32,84,111,111,110,32,65,100,118,101,110,116,117,114,101,115,32,45,32,66,117,115,116,101,114,39,115,32,72,105,100,100,101,110,32,84,114,101,97,115,117,114,101,32,40,85,83,65,41,0,0,0,66,105,103,0,0,0,0,0,76,111,97,100,32,83,104,97,100,101,114,32,80,114,101,115,101,116,0,0,0,0,0,0,109,100,95,116,116,111,111,110,98,104,116,117,0,0,0,0,80,49,32,66,108,111,99,107,0,0,0,0,0,0,0,0,84,105,110,121,32,84,111,111,110,32,65,100,118,101,110,116,117,114,101,115,32,40,75,111,114,41,0,0,0,0,0,0,105,109,112,111,114,116,95,115,99,114,105,112,116,0,0,0,77,46,73,46,65,46,32,45,32,77,105,115,115,105,110,103,32,105,110,32,65,99,116,105,111,110,32,40,74,97,112,97,110,41,0,0,0,0,0,0,97,118,115,112,97,0,0,0,109,100,95,116,116,111,111,110,98,104,116,107,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,39,32,45,32,67,104,97,109,112,105,111,110,32,69,100,105,116,105,111,110,32,40,89,89,67,32,98,111,111,116,108,101,103,32,115,101,116,32,50,44,32,57,50,48,51,49,51,32,101,116,99,41,0,0,0,112,99,101,95,109,110,115,116,112,114,111,119,0,0,0,0,55,48,107,44,32,50,53,48,107,32,38,32,53,48,48,107,0,0,0,0,0,0,0,0,84,104,101,32,75,105,110,103,32,111,102,32,70,105,103,104,116,101,114,115,32,50,48,48,51,32,40,98,111,111,116,108,101,103,32,115,101,116,32,49,41,0,0,0,0,0,0,0,111,118,101,114,108,97,121,37,117,95,100,101,115,99,37,117,95,115,97,116,117,114,97,116,101,95,112,99,116,0,0,0,84,105,110,121,32,84,111,111,110,32,65,100,118,101,110,116,117,114,101,115,32,45,32,66,117,115,116,101,114,39,115,32,72,105,100,100,101,110,32,84,114,101,97,115,117,114,101,32,40,69,117,114,111,41,0,0,109,100,95,111,111,116,119,112,0,0,0,0,0,0,0,0,250,81,0,0,95,48,0,0,106,48,0,0,33,0,0,0,33,0,0,0,32,0,0,0,84,0,0,0,119,0,0,0,105,0,0,0,110,0,0,0,32,0,0,0,66,0,0,0,101,0,0,0,101,0,0,0,32,0,0,0,196,48,0,0,164,48,0,0,243,48,0,0,211,48,0,0,252,48,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,32,0,0,0,118,0,0,0,101,0,0,0,114,0,0,0,46,0,0,0,32,0,0,0,74,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,116,117,109,98,108,101,98,0,75,105,100,32,78,105,107,105,32,45,32,82,97,100,105,99,97,108,32,78,105,110,106,97,32,40,87,111,114,108,100,41,0,0,0,0,0,0,0,0,109,100,95,116,116,111,111,110,98,104,116,0,0,0,0,0,103,117,110,102,111,114,99,101,0,0,0,0,0,0,0,0,115,108,45,62,101,103,95,115,104,95,100,112,0,0,0,0,97,105,114,100,117,101,108,0,84,105,110,121,32,84,111,111,110,32,65,100,118,101,110,116,117,114,101,115,32,45,32,65,99,109,101,32,65,108,108,45,83,116,97,114,115,32,40,85,83,65,44,32,75,111,114,41,0,0,0,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,90,101,114,111,32,51,32,40,57,56,48,55,48,49,32,65,115,105,97,41,0,0,0,0,0,109,100,95,116,116,97,99,109,101,117,0,0,0,0,0,0,97,109,105,100,97,114,115,0,84,105,110,121,32,84,111,111,110,32,65,100,118,101,110,116,117,114,101,115,32,45,32,65,99,109,101,32,65,108,108,45,83,116,97,114,115,32,40,69,117,114,111,41,0,0,0,0,109,100,95,116,116,97,99,109,101,0,0,0,0,0,0,0,84,105,110,116,105,110,32,97,117,32,84,105,98,101,116,32,40,69,117,114,111,41,0,0,83,109,97,108,108,0,0,0,109,100,95,116,105,110,116,105,110,0,0,0,0,0,0,0,112,49,32,102,105,114,101,32,49,53,0,0,0,0,0,0,84,105,110,72,101,97,100,32,40,85,83,65,41,0,0,0,109,100,95,116,105,110,104,101,97,100,0,0,0,0,0,0,115,102,50,121,121,99,50,0,108,105,118,101,113,117,105,122,0,0,0,0,0,0,0,0,77,111,109,111,116,97,114,111,117,32,75,97,116,115,117,103,101,107,105,0,0,0,0,0,107,102,50,107,51,98,108,0,84,105,109,101,32,75,105,108,108,101,114,115,32,40,85,83,65,41,0,0,0,0,0,0,79,117,116,32,111,102,32,84,104,105,115,32,87,111,114,108,100,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,109,100,95,116,105,109,101,107,105,108,108,117,0,0,0,0,84,105,109,101,32,75,105,108,108,101,114,115,32,40,69,117,114,111,41,0,0,0,0,0,115,102,122,51,97,114,49,0,82,101,116,114,111,65,114,99,104,32,58,32,37,115,32,37,115,0,0,0,0,0,0,0,109,100,95,116,105,109,101,107,105,108,108,0,0,0,0,0,65,109,105,103,111,0,0,0,71,97,108,86,66,108,97,110,107,0,0,0,0,0,0,0,84,104,101,32,84,105,99,107,32,40,85,83,65,41,0,0,109,100,95,116,105,99,107,0,68,97,109,97,103,101,0,0,84,104,117,110,100,101,114,32,80,114,111,32,87,114,101,115,116,108,105,110,103,32,82,101,116,115,117,100,101,110,32,40,74,112,110,41,0,0,0,0,80,49,32,68,105,97,108,32,82,105,103,104,116,0,0,0,109,100,95,116,112,119,114,101,115,0,0,0,0,0,0,0,83,99,111,114,101,32,68,105,103,105,116,115,0,0,0,0,83,101,114,118,105,99,101,32,77,111,100,101,32,50,0,0,84,104,117,110,100,101,114,32,70,111,120,32,40,74,112,110,41,0,0,0,0,0,0,0,83,116,114,101,101,116,32,70])
.concat([105,103,104,116,101,114,32,73,73,39,32,45,32,67,104,97,109,112,105,111,110,32,69,100,105,116,105,111,110,32,40,89,89,67,32,98,111,111,116,108,101,103,32,115,101,116,32,49,44,32,57,50,48,51,49,51,32,101,116,99,41,0,0,0,99,114,111,115,112,97,110,103,0,0,0,0,0,0,0,0,112,99,101,95,109,111,109,111,107,116,115,103,0,0,0,0,84,104,101,32,75,105,110,103,32,111,102,32,70,105,103,104,116,101,114,115,32,50,48,48,51,32,40,78,71,72,45,50,55,49,48,41,0,0,0,0,109,100,95,116,102,111,120,106,0,0,0,0,0,0,0,0,109,100,95,111,111,116,119,0,84,104,117,110,100,101,114,32,70,111,120,32,40,85,83,65,41,0,0,0,0,0,0,0,109,100,95,116,102,111,120,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,90,101,114,111,32,51,32,40,57,56,48,57,48,52,32,65,115,105,97,41,0,0,0,0,0,76,105,103,104,116,101,110,105,110,103,32,70,111,114,99,101,32,45,32,81,117,101,115,116,32,102,111,114,32,116,104,101,32,68,97,114,107,115,116,97,114,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,97,109,105,103,111,0,0,0,109,100,95,108,105,103,104,116,102,111,114,0,0,0,0,0,84,104,117,110,100,101,114,32,70,111,114,99,101,32,73,86,32,40,74,112,110,41,0,0,109,100,95,116,102,52,106,0,49,48,107,32,97,110,100,32,51,53,48,107,0,0,0,0,84,104,117,110,100,101,114,32,70,111,114,99,101,32,73,86,32,40,69,117,114,111,41,0,0,0,0,0,0,0,0,0,112,49,32,102,105,114,101,32,49,52,0,0,0,0,0,0,109,100,95,116,102,52,0,0,100,100,111,110,112,97,99,104,0,0,0,0,0,0,0,0,90,101,114,111,32,84,105,109,101,0,0,0,0,0,0,0,83,101,114,118,105,99,101,32,77,111,100,101,32,49,0,0,84,104,117,110,100,101,114,32,70,111,114,99,101,32,73,73,73,32,40,74,112,110,44,32,85,83,65,41,0,0,0,0,115,102,50,121,121,99,0,0,77,111,109,111,116,97,114,111,117,32,68,101,110,115,101,116,115,117,32,84,117,114,98,111,0,0,0,0,0,0,0,0,107,111,102,50,48,48,51,104,0,0,0,0,0,0,0,0,109,100,95,116,102,51,0,0,65,110,105,109,97,110,105,97,99,115,32,40,85,83,65,41,0,0,0,0,0,0,0,0,82,111,98,111,99,111,112,32,50,32,40,85,83,32,118,48,46,48,53,41,0,0,0,0,84,104,117,110,100,101,114,32,70,111,114,99,101,32,73,73,32,77,68,32,40,74,112,110,41,0,0,0,0,0,0,0,110,84,105,99,107,115,68,111,110,101,0,0,0,0,0,0,109,100,95,116,102,50,106,0,115,102,122,51,97,0,0,0,84,104,111,109,97,115,32,116,104,101,32,84,97,110,107,32,69,110,103,105,110,101,32,38,32,70,114,105,101,110,100,115,32,40,85,83,65,41,0,0,65,109,105,100,97,114,32,40,98,111,111,116,108,101,103,41,0,0,0,0,0,0,0,0,109,100,95,116,104,111,109,97,115,0,0,0,0,0,0,0,49,48,107,32,54,48,107,32,53,48,107,43,0,0,0,0,84,104,101,32,78,101,119,32,90,101,97,108,97,110,100,32,83,116,111,114,121,32,40,74,112,110,41,0,0,0,0,0,109,100,95,116,110,122,115,0,49,48,107,32,97,110,100,32,50,53,48,107,0,0,0,0,84,104,101,109,101,32,80,97,114,107,32,40,69,117,114,111,44,32,85,83,65,41,0,0,80,49,32,68,105,97,108,32,76,101,102,116,0,0,0,0,109,100,95,116,104,101,109,101,112,114,107,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,39,32,84,117,114,98,111,32,45,32,72,121,112,101,114,32,70,105,103,104,116,105,110,103,32,40,98,111,111,116,108,101,103,32,115,101,116,32,50,44,32,57,50,49,50,48,57,32,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,112,99,101,95,109,111,109,111,116,114,98,111,0,0,0,0,84,104,101,32,75,105,110,103,32,111,102,32,70,105,103,104,116,101,114,115,32,50,48,48,51,32,40,78,71,77,45,50,55,49,48,41,0,0,0,0,84,101,116,114,105,115,32,40,74,112,110,41,0,0,0,0,109,100,95,97,110,105,109,97,110,105,97,117,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,82,101,113,117,101,115,116,105,110,103,32,110,111,32,72,87,32,99,111,110,116,101,120,116,46,10,0,0,0,109,100,95,116,101,116,114,105,115,0,0,0,0,0,0,0,84,101,115,116,32,68,114,105,118,101,32,73,73,32,45,32,84,104,101,32,68,117,101,108,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,65,108,112,104,97,32,51,32,40,57,56,48,54,50,57,32,85,83,65,41,0,0,0,0,0,109,100,95,116,100,50,0,0,97,109,105,100,97,114,98,0,84,104,101,32,84,101,114,109,105,110,97,116,111,114,32,40,85,83,65,41,0,0,0,0,111,115,99,97,114,106,49,0,109,100,95,116,101,114,109,105,110,116,114,117,0,0,0,0,84,104,101,32,84,101,114,109,105,110,97,116,111,114,32,40,69,117,114,111,41,0,0,0,49,48,107,32,97,110,100,32,49,53,48,107,0,0,0,0,109,100,95,116,101,114,109,105,110,116,114,0,0,0,0,0,65,99,101,97,116,116,97,99,97,68,105,97,108,50,0,0,84,101,108,101,98,114,97,100,101,115,99,111,32,82,101,115,105,100,101,110,99,105,97,32,40,66,114,97,41,0,0,0,109,100,95,116,101,108,101,98,114,97,100,0,0,0,0,0,115,102,50,104,102,106,98,50,0,0,0,0,0,0,0,0,77,111,109,111,116,97,114,111,117,32,68,101,110,115,101,116,115,117,32,73,73,0,0,0,107,111,102,50,48,48,51,0,84,101,108,45,84,101,108,32,83,116,97,100,105,117,109,32,40,74,112,110,41,0,0,0,106,111,121,106,111,121,0,0,80,49,32,77,101,100,105,117,109,32,75,105,99,107,0,0,109,100,95,116,101,108,115,116,97,100,0,0,0,0,0,0,84,101,108,45,84,101,108,32,77,97,104,106,111,110,103,32,40,74,112,110,41,0,0,0,115,102,97,51,117,114,49,0,65,109,115,116,97,114,0,0,72,101,114,111,32,99,111,117,110,116,115,0,0,0,0,0,115,97,109,117,114,97,105,97,0,0,0,0,0,0,0,0,83,104,97,114,101,100,32,82,65,77,0,0,0,0,0,0,109,100,95,116,101,108,109,97,104,0,0,0,0,0,0,0,50,48,48,44,48,48,48,112,116,115,32,111,110,108,121,0,99,104,105,112,45,62,101,110,97,98,108,101,0,0,0,0,75,111,110,97,109,105,32,40,79,108,121,109,112,105,97,32,108,105,99,101,110,115,101,41,0,0,0,0,0,0,0,0,49,44,48,48,48,44,48,48,48,112,116,115,32,111,110,108,121,0,0,0,0,0,0,0,84,101,107,107,101,110,32,51,32,83,112,101,99,105,97,108,0,0,0,0,0,0,0,0,110,111,45,100,101,97,116,104,44,32,115,116,111,112,32,109,111,100,101,0,0,0,0,0,109,100,95,116,101,107,107,110,51,115,112,0,0,0,0,0,50,48,48,48,48,48,32,38,32,53,48,48,48,48,48,32,112,116,115,0,0,0,0,0,49,48,48,48,48,48,44,32,101,118,101,114,121,32,50,53,48,48,48,48,0,0,0,0,84,101,101,110,97,103,101,32,77,117,116,97,110,116,32,78,105,110,106,97,32,84,117,114,116,108,101,115,32,45,32,84,111,117,114,110,97,109,101,110,116,32,70,105,103,104,116,101,114,115,32,40,85,83,65,41,0,0,0,0,0,0,0,0,77,105,100,110,105,103,104,116,32,82,101,115,105,115,116,97,110,99,101,32,40,74,97,112,97,110,41,0,0,0,0,0,49,48,107,32,97,110,100,32,49,48,48,107,0,0,0,0,100,114,105,118,101,111,117,116,0,0,0,0,0,0,0,0,109,100,95,116,109,110,116,116,102,117,0,0,0,0,0,0,65,99,101,97,116,116,97,99,97,68,105,97,108,49,0,0,65,114,107,97,110,111,105,100,32,40,98,111,111,116,108,101,103,32,111,110,32,66,108,111,99,107,32,104,97,114,100,119,97,114,101,41,0,0,0,0,84,101,101,110,97,103,101,32,77,117,116,97,110,116,32,78,105,110,106,97,32,84,117,114,116,108,101,115,32,45,32,84,111,117,114,110,97,109,101,110,116,32,70,105,103,104,116,101,114,115,32,40,74,112,110,41,0,0,0,0,0,0,0,0,84,101,116,114,105,115,32,40,74,97,112,97,110,44,32,66,45,83,121,115,116,101,109,44,32,89,77,50,50,48,51,41,0,0,0,0,0,0,0,0,109,100,95,116,109,110,116,116,102,106,0,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,39,32,84,117,114,98,111,32,45,32,72,121,112,101,114,32,70,105,103,104,116,105,110,103,32,40,98,111,111,116,108,101,103,32,115,101,116,32,49,44,32,57,50,49,50,48,57,32,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,114,97,115,116,97,110,97,0,98,111,110,122,101,97,100,118,111,0,0,0,0,0,0,0,112,99,101,95,109,111,109,111,50,0,0,0,0,0,0,0,100,101,100,105,99,97,116,101,100,32,78,101,111,32,71,101,111,32,80,67,66,0,0,0,116,111,107,105,111,98,0,0,84,101,101,110,97,103,101,32,77,117,116,97,110,116,32,72,101,114,111,32,84,117,114,116,108,101,115,32,45,32,84,111,117,114,110,97,109,101,110,116,32,70,105,103,104,116,101,114,115,32,40,69,117,114,111,41,0,0,0,0,0,0,0,0,65,110,105,109,97,110,105,97,99,115,32,40,69,117,114,111,41,0,0,0,0,0,0,0,80,49,32,77,111,100,101,0,109,100,95,116,109,104,116,116,102,0,0,0,0,0,0,0,106,111,106,111,110,0,0,0,80,104,105,108,99,111,0,0,84,101,101,110,97,103,101,32,77,117,116,97,110,116,32,78,105,110,106,97,32,84,117,114,116,108,101,115,32,45,32,84,104,101,32,72,121,112,101,114,115,116,111,110,101,32,72,101,105,115,116,32,40,85,83,65,41,0,0,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,65,108,112,104,97,32,51,32,40,57,56,48,57,48,52,32,85,83,65,41,0,0,0,0,0,105,109,115,111,114,114,121,0,108,103,104,111,115,116,117,0,109,100,95,116,109,110,116,104,104,0,0,0,0,0,0,0,65,109,105,100,97,114,32,40,79,108,121,109,112,105,97,41,0,0,0,0,0,0,0,0,83,117,112,101,114,32,77,111,110,97,99,111,32,71,80,32,40,87,111,114,108,100,44,32,82,101,118,32,65,44,32,70,68,49,48,57,52,32,51,49,55,45,48,49,50,54,97,41,0,0,0,0,0,0,0,0,118,105,100,101,111,95,102,111,110,116,95,115,105,122,101,0,49,58,51,48,0,0,0,0,80,97,115,115,105,110,103,32,83,104,111,116,32,40,74,97,112,97,110,44,32,52,32,80,108,97,121,101,114,115,44,32,83,121,115,116,101,109,32,49,54,65,44,32,70,68,49,48,57,52,32,51,49,55,45,48,48,55,49,41,0,0,0,0,84,101,101,110,97,103,101,32,77,117,116,97,110,116,32,78,105,110,106,97,32,84,117,114,116,108,101,115,32,45,32,82,101,116,117,114,110,32,111,102,32,116,104,101,32,83,104,114,101,100,100,101,114,32,40,74,112,110,41,0,0,0,0,0,109,103,99,114,121,115,116,108,111,0,0,0,0,0,0,0,109,100,95,116,109,110,116,115,104,106,0,0,0,0,0,0,80,108,97,121,32,84,105,109,101,32,80,51,0,0,0,0,84,101,101,110,97,103,101,32,77,117,116,97,110,116,32,72,101,114,111,32,84,117,114,116,108,101,115,32,45,32,84,104,101,32,72,121,112,101,114,115,116,111,110,101,32,72,101,105,115,116,32,40,69,117,114,111,41,0,0,0,0,0,0,0,83,116,101,101,114,105,110,103,32,87,104,101,101,108,0,0,109,100,95,116,109,104,116,104,104,0,0,0,0,0,0,0,65,99,101,97,116,116,97,99,97,84,114,97,99,107,50,89,0,0,0,0,0,0,0,0,49,53,48,44,48,48,48,47,51,48,48,44,48,48,48,0,53,32,99,111,105,110,115,32,49,32,99,114,101,100,105,116,0,0,0,0,0,0,0,0,68,101,101,114,32,72,117,110,116,105,110,103,32,85,83,65,32,86,52,46,48,0,0,0,84,101,100,100,121,32,66,111,121,32,66,108,117,101,115,32,40,74,112,110,44,32,83,101,103,97,78,101,116,41,0,0,109,100,95,116,101,100,100,121,98,111,121,0,0,0,0,0,115,102,50,104,102,106,98,0,65,67,69,32,73,110,116,101,114,110,97,116,105,111,110,97,108,0,0,0,0,0,0,0,77,111,109,111,116,97,114,111,117,32,68,101,110,115,101,116,115,117,32,71,97,105,100,101,110,32,68,97,105,32,49,32,83,104,117,117,0,0,0,0,80,108,97,121,109,111,114,101,32,47,32,67,97,112,99,111,109,0,0,0,0,0,0,0,80,114,101,116,116,121,32,83,111,108,100,105,101,114,32,83,97,105,108,111,114,32,77,111,111,110,32,40,118,101,114,46,32,57,53,47,48,51,47,50,50,44,32,72,111,110,103,32,75,111,110,103,41,0,0,0,84,101,99,109,111,32,87,111,114,108,100,32,67,117,112,32,40,85,83,65,41,0,0,0,109,100,95,97,110,105,109,97,110,105,97,0,0,0,0,0,51,50,32,115,0,0,0,0,109,100,95,116,101,99,109,111,119,99,0,0,0,0,0,0,49,32,99,111,105,110,32,49,32,99,114,101,100,105,116,115,0,0,0,0,0,0,0,0,9,37,115,10,0,0,0,0,84,101,99,109,111,32,87,111,114,108,100,32,67,117,112,32,39,57,50,32,40,74,112,110,41,0,0,0,0,0,0,0,115,102,97,51,117,0,0,0,65,108,108,117,109,101,114,32,40,84,97,105,116,111,32,108,105,99,101,110,115,101,41,0,109,100,95,116,101,99,109,111,119,57,50,0,0,0,0,0,97,109,105,100,97,114,111,0,65,116,116,114,97,99,116,32,83,111,117,110,100,0,0,0,116,119,105,110,97,100,118,0,102,110,99,121,119,108,100,0,84,101,99,109,111,32,83,117,112,101,114,32,78,66,65,32,66,97,115,107,101,116,98,97,108,108,32,40,74,112,110,41,0,0,0,0,0,0,0,0,67,111,105,110,32,115,108,111,116,0,0,0,0,0,0,0,42,49,49,49,120,0,0,0,80,49,32,98,117,116,116,111,110,32,55,0,0,0,0,0,109,100,95,116,101,99,109,111,110,98,97,106,0,0,0,0,84,101,99,109,111,32,83,117,112,101,114,32,78,66,65,32,66,97,115,107,101,116,98,97,108,108,32,40,85,83,65,41,0,0,0,0,0,0,0,0,80,97,100,100,108,101,0,0,43,50,58,51,48,0,0,0,65,32,49,67,47,49,67,32,66,32,49,67,47,50,67,0,109,100,95,116,101,99,109,111,110,98,97,0,0,0,0,0,65,99,101,97,116,116,97,99,97,84,114,97,99,107,50,88,0,0,0,0,0,0,0,0,80,97,99,45,77,97,110,32,40,77,105,100,119,97,121,44,32,104,97,114,100,101,114,41,0,0,0,0,0,0,0,0,103,97,117,110,116,108,101,116,50,112,114,51,0,0,0,0,84,101,99,109,111,32,83,117,112,101,114,32,72,111,99,107,101,121,32,40,85,83,65,41,0,0,0,0,0,0,0,0,109,100,95,116,101,99,109,111,104,99,107,0,0,0,0,0,68,111,110,107,101,121,32,75,111,110,103,32,74,114,46,32,40,98,111,111,116,108,101,103,41,0,0,0,0,0,0,0,112,99,101,95,109,111,109,111,103,100,110,0,0,0,0,0,65,32,49,47,49,32,66,32,49,47,50,0,0,0,0,0,100,101,100,105,99,97,116,101,100,32,80,67,66,32,118,101,114,115,105,111,110,44,32,74,97,112,97,110,32,114,101,103,105,111,110,0,0,0,0,0,84,101,99,109,111,32,83,117,112,101,114,32,66,111,119,108,32,73,73,73,32,45,32,70,105,110,97,108,32,69,100,105,116,105,111,110,32,40,85,83,65,41,0,0,0,0,0,0,83,101,116,32,98,121,32,68,105,112,115,119,105,116,99,104,101,115,0,0,0,0,0,0,65,110,100,114,101,32,65,103,97,115,115,105,32,84,101,110,110,105,115,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,69,118,101,114,121,32,49,48,107,0,0,0,0,0,0,0,109,100,95,116,101,99,109,111,115,98,51,0,0,0,0,0,37,0,0,0,73,0,0,0,58,0,0,0,37,0,0,0,77,0,0,0,58,0,0,0,37,0,0,0,83,0,0,0,32,0,0,0,37,0,0,0,112,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,70,97,105,108,101,100,32,46,46,46,32,67,97,110,110,111,116,32,114,101,99,111,118,101,114,32,115,97,118,101,32,102,105,108,101,46,10,0,0,0,0,0,0,0,84,101,99,109,111,32,83,117,112,101,114,32,66,111,119,108,32,73,73,32,45,32,83,112,101,99,105,97,108,32,69,100,105,116,105,111,110,32,40,74,112,110,41,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,65,108,112,104,97,32,51,32,40,57,56,48,54,50,57,32,72,105,115,112,97,110,105,99,41,0,0,0,0,0,0,0,0,82,101,112,117,108,115,101,0,0,0,0,0,0,0,0,0,109,100,95,116,101,99,109,111,115,98,50,106,0,0,0,0,65,109,105,100,97,114,32,40,83,116,101,114,110,41,0,0,51,48,107,32,56,48,107,32,97,110,100,32,101,118,101,114,121,32,56,48,107,0,0,0,51,50,47,54,52,0,0,0,67,111,105,110,32,67,111,117,110,116,101,114,115,0,0,0,84,101,99,109,111,32,83,117,112,101,114,32,66,111,119,108,32,73,73,32,40,85,83,65,41,0,0,0,0,0,0,0,57,45,57,0,0,0,0,0,109,100,95,116,101,99,109,111,115,98,50,0,0,0,0,0,97,115,105,99,51,95,108,97,116,99,104,91,48,93,0,0,84,101,99,109,111,32,83,117,112,101,114,32,66,111,119,108,32,40,74,112,110,41,0,0,107,105,108,108,98,108,100,49,48,52,0,0,0,0,0,0,67,111,110,116,114,111,108,0,109,100,95,116,101,99,109,111,115,98,119,106,0,0,0,0,65,99,101,97,116,116,97,99,97,84,114,97,99,107,49,89,0,0,0,0,0,0,0,0,104,111,116,103,109,99,107,0,84,101,99,109,111,32,83,117,112,101,114,32,66,111,119,108,32,40,85,83,65,44,32,49,57,57,51,48,57,41,0,0,109,100,95,116,101,99,109,111,115,98,119,97,0,0,0,0,115,102,50,104,102,117,98,0,99,97,112,116,99,111,109,109,98,50,0,0,0,0,0,0,77,105,122,117,98,97,107,117,32,68,97,105,32,66,111,117,107,101,110,0,0,0,0,0,84,104,101,32,75,105,110,103,32,111,102,32,70,105,103,104,116,101,114,115,32,50,48,48,51,0,0,0,0,0,0,0,84,104,101,32,83,117,112,101,114,32,83,112,121,32,40,78,71,77,45,48,49,49,41,40,78,71,72,45,48,49,49,41,0,0,0,0,0,0,0,0,110,83,112,114,105,116,101,70,114,97,109,101,83,112,101,101,100,0,0,0,0,0,0,0,84,101,99,109,111,32,83,117,112,101,114,32,66,111,119,108,32,40,85,83,65,44,32,49,57,57,51,49,48,41,0,0,109,100,95,97,103,97,115,115,105,117,112,0,0,0,0,0,109,100,95,116,101,99,109,111,115,98,119,0,0,0,0,0,115,102,97,51,104,114,49,0,79,80,76,45,62,100,101,108,116,97,116,45,62,112,114,101,118,95,97,99,99,0,0,0,84,101,99,109,111,32,83,117,112,101,114,32,66,97,115,101,98,97,108,108,32,40,85,83,65,41,0,0,0,0,0,0,97,109,105,100,97,114,117,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,99,111,109,112,105,108,101,32,118,101,114,116,101,120,32,115,104,97,100,101,114,32,35,37,117,10,0,0,0,0,0,0,0,109,100,95,116,101,99,109,111,98,98,0,0,0,0,0,0,37,99,32,37,45,42,46,42,115,32,37,45,42,115,0,0,84,101,99,109,111,32,67,117,112,32,40,74,112,110,44,32,80,114,111,116,111,116,121,112,101,63,41,0,0,0,0,0,60,112,105,114,97,116,101,62,0,0,0,0,0,0,0,0,65,108,116,101,114,110,97,116,101,32,67,111,110,116,114,111,108,115,0,0,0,0,0,0,68,101,102,97,117,108,116,32,70,105,108,116,101,114,0,0,66,111,121,32,83,111,99,99,101,114,32,84,101,97,109,32,73,73,73,32,40,74,112,110,44,32,80,105,114,97,116,101,41,0,0,0,0,0,0,0,49,50,32,77,105,110,0,0,65,99,101,97,116,116,97,99,97,84,114,97,99,107,49,88,0,0,0,0,0,0,0,0,109,100,95,116,101,99,109,111,99,117,112,0,0,0,0,0,37,115,95,119,114,97,112,95,109,111,100,101,0,0,0,0,65,108,105,101,110,32,118,115,32,80,114,101,100,97,116,111,114,32,40,57,52,48,53,50,48,32,69,117,114,111,41,0,0,0,0,0,0,0,0,0,102,117,110,107,121,98,101,101,0,0,0,0,0,0,0,0,109,100,95,98,115,116,101,97,109,51,0,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,39,32,84,117,114,98,111,32,45,32,72,121,112,101,114,32,70,105,103,104,116,105,110,103,32,40,115,116,114,101,101,116,32,102,105,103,104,116,101,114,32,50,39,32,84,32,57,50,49,50,48,57,32,74,97,112,97,110,41,0,0,0,0,112,99,101,95,109,105,122,117,98,97,107,117,0,0,0,0,53,48,107,44,32,50,48,48,107,32,38,32,52,48,48,107,0,0,0,0,0,0,0,0,107,102,50,107,51,112,99,98,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,65,110,97,108,111,103,32,104,105,116,98,111,120,32,116,121,112,101,32,109,117,115,116,32,98,101,32,34,114,97,100,105,97,108,34,46,10,0,0,0,84,101,99,104,110,111,99,111,112,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,65,110,100,114,101,32,65,103,97,115,115,105,32,84,101,110,110,105,115,32,40,85,83,65,41,0,0,0,0,0,0,0,68,101,116,97,110,97,33,33,32,84,119,105,110,32,66,101,101,32,40,74,97,112,97,110,32,118,101,114,46,32,74,41,0,0,0,0,0,0,0,0,107,105,100,110,105,107,105,0,109,100,95,116,101,99,110,111,99,111,112,0,0,0,0,0,77,121,115,116,105,99,32,82,105,100,101,114,115,32,40,98,111,111,116,108,101,103,63,41,0,0,0,0,0,0,0,0,115,108,45,62,115,108,0,0,73,109,97,103,101,32,70,105,103,104,116,32,40,74,97,112,97,110,41,0,0,0,0,0,84,101,99,104,110,111,32,67,108,97,115,104,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,65,108,112,104,97,32,51,32,40,57,56,48,57,48,52,32,72,105,115,112,97,110,105,99,41,0,0,0,0,0,0,0,0,109,100,95,116,101,99,104,110,111,99,108,0,0,0,0,0,65,109,105,100,97,114,32,40,111,108,100,101,114,41,0,0,85,83,65,32,66,97,115,107,101,116,98,97,108,108,32,87,111,114,108,100,32,67,104,97,108,108,101,110,103,101,32,40,74,112,110,41,0,0,0,0,109,100,95,100,114,101,97,109,116,101,97,109,0,0,0,0,85,83,65,32,66,97,115,107,101,116,98,97,108,108,32,87,111,114,108,100,32,67,104,97,108,108,101,110,103,101,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,115,101,114,118,105,99,101,32,51,0,0,0,0,0,0,0,109,100,95,116,101,97,109,117,115,97,0,0,0,0,0,0,52,48,48,48,48,32,45,32,56,48,48,48,48,0,0,0,109,111,108,101,0,0,0,0,84,97,122,45,77,97,110,105,97,32,40,87,111,114,108,100,41,0,0,0,0,0,0,0,78,111,110,101,32,40,74,97,112,97,110,41,0,0,0,0,109,100,95,116,97,122,109,97,110,105,97,0,0,0,0,0,118,111,105,99,101,45,62,112,114,101,115,99,97,108,101,114,0,0,0,0,0,0,0,0,115,102,50,104,102,106,0,0,77,101,116,97,108,32,83,116,111,107,101,114,0,0,0,0,83,0,0,0,97,0,0,0,109,0,0,0,117,0,0,0,114,0,0,0,97,0,0,0,105,0,0,0,32,0,0,0,83,0,0,0,104,0,0,0,111,0,0,0,100,0,0,0,111,0,0,0,119,0,0,0,110,0,0,0,32,0,0,0,86,0,0,0,0,0,0,0,181,48,0,0,224,48,0,0,233,48,0,0,164,48,0,0,185,48,0,0,212,48,0,0,234,48,0,0,195,48,0,0,196,48,0,0,246,150,0,0,32,0,0,0,40,0,0,0,98,0,0,0,111,0,0,0,111,0,0,0,116,0,0,0,108,0,0,0,101,0,0,0,103,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,84,114,117,120,116,111,110,32,40,69,117,114,111,44,32,85,83,65,41,32,126,32,84,97,116,115,117,106,105,110,32,40,74,112,110,41,0,0,0,0,109,100,95,97,103,97,115,115,105,117,0,0,0,0,0,0,109,100,95,116,114,117,120,116,111,110,0,0,0,0,0,0,84,97,115,107,32,70,111,114,99,101,32,72,97,114,114,105,101,114,32,69,88,32,40,74,112,110,41,0,0,0,0,0,115,102,97,51,104,0,0,0,118,48,0,0,0,0,0,0,109,100,95,116,97,115,107,102,104,101,120,106,0,0,0,0,97,109,105,100,97,114,49,0,71,97,108,83,116,97,114,115,66,108,105,110,107,83,116,97,116,101,0,0,0,0,0,0,84,97,115,107,32,70,111,114,99,101,32,72,97,114,114,105,101,114,32,69,88,32,40,85,83,65,41,0,0,0,0,0,109,100,95,116,97,115,107,102,104,101,120,0,0,0,0,0,65,115,115,97,117,108,116,32,83,117,105,116,32,76,101,121,110,111,115,32,40,74,112,110,41,0,0,0,0,0,0,0,83,101,114,118,105,99,101,32,51,0,0,0,0,0,0,0,109,100,95,108,101,121,110,111,115,0,0,0,0,0,0,0,51,48,48,48,48,32,45,32,54,48,48,48,48,0,0,0,84,97,114,103,101,116,32,69,97,114,116,104,32,40,85,83,65,41,0,0,0,0,0,0,82,111,109,115,116,97,114,0,104,105,103,101,109,97,114,117,0,0,0,0,0,0,0,0,109,100,95,116,114,103,101,97,114,116,104,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,39,32,45,32,72,121,112,101,114,32,70,105,103,104,116,105,110,103,32,40,115,116,114,101,101,116,32,102,105,103,104,116,101,114,32,50,39,32,84,32,57,50,49,50,48,57,32,85,83,65,41,0,0,0,0,112,99,101,95,109,101,116,108,115,116,111,107,0,0,0,0,83,97,109,117,114,97,105,32,83,104,111,100,111,119,110,32,86,32,47,32,83,97,109,117,114,97,105,32,83,112,105,114,105,116,115,32,90,101,114,111,32,40,98,111,111,116,108,101,103,41,0,0,0,0,0,0,77,97,114,118,101,108,32,76,97,110,100,32,40,85,83,65,41,0,0,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,65,108,112,104,97,32,51,32,40,57,56,48,54,50,57,32,66,114,97,122,105,108,41,0,0,71,97,109,101,84,101,107,0,76,101,102,116,32,97,110,97,108,111,103,32,88,43,32,40,114,105,103,104,116,41,0,0,109,100,95,109,97,114,118,108,97,110,100,0,0,0,0,0,84,97,108,101,83,112,105,110,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,99,104,105,112,45,62,101,103,95,116,105,109,101,114,95,97,100,100,0,0,0,0,0,0,109,100,95,116,97,108,101,115,112,105,110,0,0,0,0,0,65,109,105,100,97,114,0,0,84,97,105,119,97,110,32,68,97,104,101,110,103,32,40,67,104,105,41,0,0,0,0,0,109,100,95,116,97,105,119,97,110,0,0,0,0,0,0,0,84,97,105,107,111,117,32,82,105,115,115,104,105,100,101,110,32,40,74,112,110,41,0,0,109,101,116,109,113,115,116,114,0,0,0,0,0,0,0,0,69,117,114,111,112,101,97,110,0,0,0,0,0,0,0,0,109,100,95,116,97,105,107,111,114,105,115,0,0,0,0,0,50,48,48,48,48,32,45,32,52,48,48,48,48,0,0,0,84,50,32,45,32,84,104,101,32,65,114,99,97,100,101,32,71,97,109,101,32,40,74,112,110,41,0,0,0,0,0,0,76,105,99,101,110,115,101,100,32,84,111,0,0,0,0,0,122,101,114,111,116,105,109,101,0,0,0,0,0,0,0,0,109,100,95,116,50,97,103,106,0,0,0,0,0,0,0,0,77,83,77,54,50,57,53,83,97,109,112,108,101,68,97,116,97,91,110,67,104,105,112,93,91,105,93,0,0,0,0,0,115,102,50,104,102,117,0,0,68,105,115,97,98,108,101,32,66,97,45,67,104,105,101,104,0,0,0,0,0,0,0,0,115,97,109,115,104,111,53,98,0,0,0,0,0,0,0,0,84,50,32,45,32,84,104,101,32,65,114,99,97,100,101,32,71,97,109,101,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,65,109,101,114,105,99,97,110,32,71,108,97,100,105,97,116,111,114,115,32,40,85,83,65,41,0,0,0,0,0,0,0,114,111,98,111,99,111,112,50,117,0,0,0,0,0,0,0,109,100,95,116,50,97,103,112,0,0,0,0,0,0,0,0,84,50,32,45,32,84,104,101,32,65,114,99,97,100,101,32,71,97,109,101,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,0,0,115,102,97,51,98,0,0,0,109,100,95,116,50,97,103,0,97,109,105,100,97,114,0,0,116,105,103,101,114,111,97,100,0,0,0,0,0,0,0,0,84,50,32,45,32,84,101,114,109,105,110,97,116,111,114,32,50,32,45,32,74,117,100,103,109,101,110,116,32,68,97,121,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,71,69,84,95,86,65,82,73,65,66,76,69,32,37,115,58,10,0,0,0,0,109,100,95,116,101,114,109,50,0,0,0,0,0,0,0,0,83,121,110,100,105,99,97,116,101,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,71,97,109,101,32,86,101,114,115,105,111,110,0,0,0,0,109,100,95,115,121,110,100,105,99,97,116,0,0,0,0,0,49,48,48,48,48,32,45,32,50,48,48,48,48,0,0,0,83,121,108,118,101,115,116,101,114,32,97,110,100,32,84,119,101,101,116,121,32,105,110,32,67,97,103,101,121,32,67,97,112,101,114,115,32,40,85,83,65,41,0,0,0,0,0,0,109,100,95,115,121,108,118,101,115,116,114,117,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,39,32,45,32,72,121,112,101,114,32,70,105,103,104,116,105,110,103,32,40,115,116,114,101,101,116,32,102,105,103,104,116,101,114,32,50,39,32,84,32,57,50,49,50,48,57,32,69,84,67,41,0,0,0,0,83,105,110,103,97,112,111,114,101,32,47,32,77,97,108,97,121,115,105,97,0,0,0,0,77,101,115,111,112,111,116,97,109,105,97,0,0,0,0,0,83,0,0,0,97,0,0,0,109,0,0,0,117,0,0,0,114,0,0,0,97,0,0,0,105,0,0,0,32,0,0,0,83,0,0,0,104,0,0,0,111,0,0,0,100,0,0,0,111,0,0,0,119,0,0,0,110,0,0,0,32,0,0,0,86,0,0,0,0,0,0,0,181,48,0,0,224,48,0,0,233,48,0,0,164,48,0,0,185,48,0,0,212,48,0,0,234,48,0,0,195,48,0,0,196,48,0,0,246,150,0,0,32,0,0,0,40,0,0,0,78,0,0,0,71,0,0,0,72,0,0,0,45,0,0,0,50,0,0,0,55,0,0,0,48,0,0,0,48,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,83,121,108,118,101,115,116,101,114,32,38,32,84,119,101,101,116,121,32,105,110,32,67,97,103,101,121,32,67,97,112,101,114,115,32,40,69,117,114,111,41,0,0,0,0,0,0,0,109,100,95,97,109,101,114,103,108,97,100,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,72,87,95,82,69,78,68,69,82,46,10,0,0,0,0,0,0,109,100,95,115,121,108,118,101,115,116,114,0,0,0,0,0,86,101,114,109,105,108,105,111,110,32,40,74,112,110,41,0,0,0,0,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,65,108,112,104,97,32,51,32,40,57,56,48,57,48,52,32,69,117,114,111,41,0,0,0,0,109,100,95,118,101,114,109,105,108,106,0,0,0,0,0,0,84,117,114,112,105,110,32,40,98,111,111,116,108,101,103,32,111,110,32,83,99,114,97,109,98,108,101,32,104,97,114,100,119,97,114,101,41,0,0,0,100,114,105,118,102,114,99,112,0,0,0,0,0,0,0,0,83,119,111,114,100,32,111,102,32,86,101,114,109,105,108,105,111,110,32,40,69,117,114,111,44,32,85,83,65,41,0,0,109,100,95,118,101,114,109,105,108,0,0,0,0,0,0,0,80,115,121,99,104,111,45,78,105,99,115,32,79,115,99,97,114,32,40,85,83,41,0,0,76,97,115,101,114,32,83,111,102,116,0,0,0,0,0,0,51,32,109,105,110,117,116,101,115,0,0,0,0,0,0,0,77,97,104,106,111,110,103,73,110,112,117,116,78,117,109,0,83,68,32,86,97,108,105,115,32,40,74,112,110,41,0,0,109,100,95,115,100,118,97,108,105,115,0,0,0,0,0,0,80,49,32,98,111,116,116,111,109,45,114,105,103,104,116,0,49,55,0,0,0,0,0,0,83,121,100,32,111,102,32,86,97,108,105,115,32,40,85,83,65,41,0,0,0,0,0,0,98,89,77,90,50,56,48,66,73,82,81,69,110,97,98,108,101,0,0,0,0,0,0,0,115,102,50,104,102,0,0,0,112,99,101,95,109,101,115,111,112,111,116,0,0,0,0,0,83,97,109,117,114,97,105,32,83,104,111,100,111,119,110,32,86,32,47,32,83,97,109,117,114,97,105,32,83,112,105,114,105,116,115,32,90,101,114,111,32,40,78,71,72,45,50,55,48,48,41,0,0,0,0,0,115,102,97,51,0,0,0,0,109,100,95,115,121,100,118,97,108,105,115,0,0,0,0,0,74,117,117,111,117,107,105,32,40,74,112,110,41,0,0,0,80,49,32,87,101,97,107,32,75,105,99,107,0,0,0,0,83,119,111,114,100,32,111,102,32,83,111,100,97,110,32,40,74,112,110,41,0,0,0,0,109,100,95,115,119,111,114,100,115,111,100,106,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,67,111,117,108,100,110,39,116,32,102,105,110,100,32,97,110,121,32,112,114,101,118,105,111,117,115,32,97,117,100,105,111,32,100,114,105,118,101,114,32,40,99,117,114,114,101,110,116,32,111,110,101,58,32,34,37,115,34,41,46,10,0,0,0,0,0,0,0,80,104,111,101,110,105,120,32,40,65,109,115,116,97,114,41,0,0,0,0,0,0,0,0,78,101,118,101,114,0,0,0,115,107,121,102,111,120,0,0,51,48,48,44,48,48,48,32,56,48,48,44,48,48,48,32,101,118,101,114,121,0,0,0,83,119,111,114,100,32,111,102,32,83,111,100,97,110,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,116,117,114,112,105,110,115,0,76,105,118,101,115,0,0,0,109,100,95,115,119,111,114,100,115,111,100,0,0,0,0,0,69,102,102,101,99,116,0,0,69,117,114,111,112,101,32,40,78,111,118,97,32,65,112,112,97,114,97,116,101,32,71,77,66,72,32,76,105,99,101,110,115,101,41,0,0,0,0,0,78,117,86,105,115,105,111,110,0,0,0,0,0,0,0,0,51,48,48,48,48,48,32,112,116,115,32,101,118,101,114,121,0,0,0,0,0,0,0,0,83,119,97,109,112,32,84,104,105,110,103,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,109,105,100,114,101,115,106,0,50,32,109,105,110,117,116,101,115,32,51,48,32,115,101,99,111,110,100,115,0,0,0,0,86,105,115,99,111,32,40,74,97,112,97,110,41,0,0,0,109,100,95,115,119,97,109,112,0,0,0,0,0,0,0,0,107,97,103,101,107,105,104,0,97,114,107,103,99,98,108,0,83,117,114,103,105,110,103,32,65,117,114,97,32,40,74,112,110,41,0,0,0,0,0,0,97,95,111,117,116,0,0,0,116,101,116,114,105,115,116,97,0,0,0,0,0,0,0,0,100,98,108,97,120,108,101,0,109,100,95,115,117,114,103,105,110,103,0,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,39,32,45,32,67,104,97,109,112,105,111,110,32,69,100,105,116,105,111,110,32,40,72,117,110,103,104,45,72,115,105,32,98,111,111,116,108,101,103,44,32,57,50,48,51,49,51,32,84,97,105,119,97,110,41,0,0,0,0,0,0,0,0,82,97,115,116,97,110,32,40,87,111,114,108,100,32,82,101,118,32,49,41,0,0,0,0,66,111,110,122,101,32,65,100,118,101,110,116,117,114,101,32,40,87,111,114,108,100,44,32,78,101,119,101,114,41,0,0,78,101,119,101,114,32,40,110,111,32,105,110,116,114,111,41,0,0,0,0,0,0,0,0,77,97,110,105,97,99,32,80,114,111,32,87,114,101,115,32,45,32,65,115,117,32,101,32,110,111,32,84,97,116,97,107,97,105,0,0,0,0,0,0,115,97,109,115,104,111,53,104,0,0,0,0,0,0,0,0,83,117,112,101,114,109,97,110,32,40,85,83,65,41,0,0,109,100,95,106,117,117,111,117,107,105,49,0,0,0,0,0,91,68,97,116,97,32,69,97,115,116,93,32,40,77,105,116,99,104,101,108,108,32,108,105,99,101,110,115,101,41,0,0,109,100,95,115,117,112,101,114,109,97,110,117,0,0,0,0,184,48,0,0,231,48,0,0,184,48,0,0,231,48,0,0,110,48,0,0,32,0,0,0,71,89,0,0,153,89,0,0,106,48,0,0,146,81,0,0,122,150,0,0,0,0,0,0,74,0,0,0,111,0,0,0,74,0,0,0,111,0,0,0,39,0,0,0,115,0,0,0,32,0,0,0,86,0,0,0,101,0,0,0,110,0,0,0,116,0,0,0,117,0,0,0,114,0,0,0,101,0,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,32,0,0,0,57,0,0,0,57,0,0,0,48,0,0,0,49,0,0,0,50,0,0,0,56,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,65,116,111,109,105,99,32,80,111,105,110,116,32,40,75,111,114,101,97,41,0,0,0,0,83,117,112,101,114,109,97,110,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,90,101,114,111,32,50,32,65,108,112,104,97,32,40,57,54,48,56,48,53,32,74,97,112,97,110,41,0,0,0,0,0,0,72,101,97,118,121,32,77,101,116,97,108,32,40,51,49,53,45,53,49,51,53,41,0,0,37,73,58,37,77,58,37,83,32,37,112,0,0,0,0,0,76,97,115,101,114,32,71,104,111,115,116,32,40,115,101,116,32,50,44,32,87,111,114,108,100,44,32,51,49,55,45,48,49,54,54,41,0,0,0,0,109,100,95,115,117,112,101,114,109,97,110,112,0,0,0,0,54,48,48,0,0,0,0,0,115,109,103,112,54,0,0,0,118,105,100,101,111,95,102,111,110,116,95,112,97,116,104,0,49,58,50,48,0,0,0,0,83,117,112,101,114,109,97,110,32,45,32,84,104,101,32,77,97,110,32,111,102,32,83,116,101,101,108,32,40,69,117,114,111,41,0,0,0,0,0,0,77,97,103,105,99,97,108,32,67,114,121,115,116,97,108,115,32,40,87,111,114,108,100,44,32,57,50,47,48,49,47,49,48,41,0,0,0,0,0,0,109,100,95,115,117,112,101,114,109,97,110,0,0,0,0,0,80,108,97,121,32,84,105,109,101,32,80,50,0,0,0,0,67,111,117,110,116,114,121,0,83,117,112,101,114,32,86,111,108,108,101,121,32,66,97,108,108,32,40,74,112,110,41,0,0,0,0,0,0,0,0,0,50,32,109,105,110,117,116,101,115,0,0,0,0,0,0,0,109,100,95,115,118,111,108,108,101,121,106,0,0,0,0,0,49,53,48,44,48,48,48,47,51,53,48,44,48,48,48,0,114,101,100,104,97,119,107,0,52,32,99,111,105,110,115,32,49,32,99,114,101,100,105,116,115,0,0,0,0,0,0,0,83,117,112,101,114,32,86,111,108,108,101,121,32,66,97,108,108,32,40,85,83,65,44,32,65,108,116,41,0,0,0,0,100,101,101,114,104,117,110,116,98,0,0,0,0,0,0,0,80,49,32,116,111,112,45,114,105,103,104,116,0,0,0,0,109,100,95,115,118,111,108,108,101,121,49,0,0,0,0,0,115,102,50,98,104,104,0,0,82,101,103,97,105,110,32,80,111,119,101,114,32,80,114,105,99,101,0,0,0,0,0,0,78,101,119,101,114,32,40,110,111,32,105,110,116,114,111,44,32,99,97,108,101,110,100,97,114,41,0,0,0,0,0,0,71,97,108,115,32,72,117,115,116,108,101,114,0,0,0,0,112,99,101,95,109,97,110,105,97,99,112,119,0,0,0,0,83,0,0,0,97,0,0,0,109,0,0,0,117,0,0,0,114,0,0,0,97,0,0,0,105,0,0,0,32,0,0,0,83,0,0,0,104,0,0,0,111,0,0,0,100,0,0,0,111,0,0,0,119,0,0,0,110,0,0,0,32,0,0,0,86,0,0,0,0,0,0,0,181,48,0,0,224,48,0,0,233,48,0,0,164,48,0,0,185,48,0,0,212,48,0,0,234,48,0,0,195,48,0,0,196,48,0,0,246,150,0,0,32,0,0,0,40,0,0,0,78,0,0,0,71,0,0,0,77,0,0,0,45,0,0,0,50,0,0,0,55,0,0,0,48,0,0,0,48,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,114,111,117,116,101,49,54,0,115,97,105,108,111,114,109,110,111,104,0,0,0,0,0,0,74,117,117,111,117,107,105,32,40,74,112,110,44,32,118,49,46,49,41,0,0,0,0,0,68,101,99,111,49,54,105,99,32,67,111,110,116,114,111,108,32,49,0,0,0,0,0,0,83,117,112,101,114,32,86,111,108,108,101,121,32,66,97,108])
.concat([108,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,69,118,101,114,121,32,54,48,48,48,48,0,0,0,0,0,65,118,97,105,108,97,98,108,101,32,105,110,112,117,116,32,100,114,105,118,101,114,115,32,97,114,101,58,10,0,0,0,109,100,95,115,118,111,108,108,101,121,0,0,0,0,0,0,115,102,122,50,97,108,106,0,82,101,122,111,110,32,40,84,97,105,116,111,41,0,0,0,83,117,112,101,114,32,84,104,117,110,100,101,114,32,66,108,97,100,101,32,40,74,112,110,44,32,76,97,117,110,99,104,32,67,97,114,116,41,0,0,54,48,48,0,0,0,0,0,51,32,71,97,109,101,32,77,97,116,99,104,0,0,0,0,70,0,0,0,105,0,0,0,110,0,0,0,97,0,0,0,108,0,0,0,32,0,0,0,84,0,0,0,101,0,0,0,116,0,0,0,114,0,0,0,105,0,0,0,115,0,0,0,0,0,0,0,12,211,0,0,116,199,0,0,16,177,0,0,32,0,0,0,76,209,0,0,184,210,0,0,172,185,0,0,164,194,0,0,0,0,0,0,0,0,0,0,0,0,0,0,87,111,110,100,101,114,32,76,101,97,103,117,101,32,39,57,54,32,40,75,111,114,101,97,41,0,0,0,0,0,0,0,109,100,95,115,116,98,108,97,100,106,0,0,0,0,0,0,84,0,0,0,101,0,0,0,110,0,0,0,103,0,0,0,97,0,0,0,105,0,0,0,0,0,0,0,38,98,0,0,253,86,0,0,214,48,0,0,236,48,0,0,252,48,0,0,201,48,0,0,32,0,0,0,45,0,0,0,32,0,0,0,115,0,0,0,101,0,0,0,110,0,0,0,103,0,0,0,111,0,0,0,107,0,0,0,117,0,0,0,32,0,0,0,97,0,0,0,99,0,0,0,101,0,0,0,32,0,0,0,101,0,0,0,112,0,0,0,105,0,0,0,115,0,0,0,111,0,0,0,100,0,0,0,101,0,0,0,32,0,0,0,73,0,0,0,73,0,0,0,0,0,0,0,0,0,0,0,42,49,48,49,120,0,0,0,83,117,112,101,114,32,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,32,45,32,84,104,101,32,78,101,119,32,67,104,97,108,108,101,110,103,101,114,115,32,40,85,83,65,41,0,0,0,0,0,109,100,95,115,115,102,50,117,0,0,0,0,0,0,0,0,99,119,111,114,108,100,0,0,49,32,109,105,110,117,116,101,32,32,51,48,32,115,101,99,111,110,100,115,0,0,0,0,83,117,112,101,114,32,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,32,45,32,84,104,101,32,78,101,119,32,67,104,97,108,108,101,110,103,101,114,115,32,40,74,112,110,41,0,0,0,0,0,112,97,99,109,111,100,0,0,71,97,117,110,116,108,101,116,32,40,50,32,80,108,97,121,101,114,115,44,32,71,101,114,109,97,110,44,32,114,101,118,32,52,41,0,0,0,0,0,109,100,95,115,115,102,50,106,0,0,0,0,0,0,0,0,68,32,40,86,101,114,121,32,72,97,114,100,41,0,0,0,49,52,0,0,0,0,0,0,83,117,112,101,114,32,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,32,45,32,84,104,101,32,78,101,119,32,67,104,97,108,108,101,110,103,101,114,115,32,40,69,117,114,111,41,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,39,58,32,67,104,97,109,112,105,111,110,32,69,100,105,116,105,111,110,32,40,68,111,110,103,102,97,110,103,32,66,117,98,97,105,32,112,114,111,116,101,99,116,105,111,110,32,98,111,111,116,108,101,103,44,32,101,116,99,32,57,50,48,51,49,51,41,0,0,0,0,100,107,111,110,103,106,114,98,0,0,0,0,0,0,0,0,78,101,119,101,114,0,0,0,77,97,107,121,111,117,32,68,101,110,115,101,116,115,117,0,0,0,0,0,0,0,0,0,89,117,107,105,32,69,110,116,101,114,112,114,105,115,101,32,47,32,83,78,75,32,80,108,97,121,109,111,114,101,0,0,109,100,95,115,115,102,50,0,67,111,105,110,32,66,32,86,97,108,117,101,0,0,0,0,83,117,112,101,114,32,83,107,105,100,109,97,114,107,115,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,0,0,108,111,118,101,114,98,111,121,0,0,0,0,0,0,0,0,70,105,114,115,116,32,50,67,95,49,67,44,32,116,104,101,110,32,49,67,95,49,67,0,109,100,95,115,115,107,105,100,112,0,0,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,90,101,114,111,32,50,32,65,108,112,104,97,32,40,57,54,48,56,49,51,32,72,105,115,112,97,110,105,99,41,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,83,117,99,99,101,101,100,101,100,32,105,110,32,115,97,118,105,110,103,32,82,65,77,32,100,97,116,97,32,116,111,32,34,37,115,34,46,10,0,0,0,0,0,0,65,115,115,111,99,105,97,116,101,100,32,79,118,101,114,115,101,97,115,32,77,70,82,44,32,73,110,99,0,0,0,0,83,117,112,101,114,32,83,107,105,100,109,97,114,107,115,32,40,69,117,114,111,44,32,74,45,67,97,114,116,41,0,0,84,117,114,112,105,110,0,0,50,48,107,32,55,48,107,32,97,110,100,32,101,118,101,114,121,32,55,48,107,0,0,0,52,56,47,54,52,0,0,0,49,32,40,78,111,114,109,97,108,41,0,0,0,0,0,0,109,100,95,115,115,107,105,100,0,0,0,0,0,0,0,0,55,45,55,0,0,0,0,0,82,111,117,110,100,32,55,0,80,97,116,32,82,105,108,101,121,32,66,97,115,107,101,116,98,97,108,108,32,40,85,83,65,41,0,0,0,0,0,0,97,115,105,99,51,95,114,101,103,0,0,0,0,0,0,0,109,100,95,112,97,116,114,105,108,101,121,0,0,0,0,0,84,0,0,0,104,0,0,0,101,0,0,0,32,0,0,0,75,0,0,0,105,0,0,0,108,0,0,0,108,0,0,0,105,0,0,0,110,0,0,0,103,0,0,0,32,0,0,0,66,0,0,0,108,0,0,0,97,0,0,0,100,0,0,0,101,0,0,0,0,0,0,0,178,80,0,0,81,82,0,0,194,114,0,0,0,82,0,0,0,0,0,0,178,80,0,0,141,82,0,0,194,114,0,0,0,82,0,0,32,0,0,0,40,0,0,0,86,0,0,0,49,0,0,0,48,0,0,0,57,0,0,0,44,0,0,0,32,0,0,0,67,0,0,0,104,0,0,0,105,0,0,0,110,0,0,0,97,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,71,97,109,101,32,84,105,109,101,0,0,0,0,0,0,0,83,117,112,101,114,32,82,101,97,108,32,66,97,115,107,101,116,98,97,108,108,32,40,74,112,110,44,32,75,111,114,41,0,0,0,0,0,0,0,0,55,48,0,0,0,0,0,0,109,100,95,115,114,101,97,108,98,97,115,106,0,0,0,0,80,49,32,98,111,116,116,111,109,45,108,101,102,116,0,0,112,99,101,95,97,118,112,111,107,101,114,0,0,0,0,0,49,51,0,0,0,0,0,0,83,117,112,101,114,32,82,101,97,108,32,66,97,115,107,101,116,98,97,108,108,32,40,69,117,114,111,41,0,0,0,0,115,102,50,100,111,110,103,98,0,0,0,0,0,0,0,0,79,108,100,101,114,0,0,0,112,99,101,95,109,97,107,121,111,100,101,110,0,0,0,0,83,97,109,117,114,97,105,32,83,104,111,100,111,119,110,32,86,32,47,32,83,97,109,117,114,97,105,32,83,112,105,114,105,116,115,32,90,101,114,111,32,40,78,71,77,45,50,55,48,48,41,0,0,0,0,0,110,78,101,111,83,112,114,105,116,101,70,114,97,109,101,0,109,100,95,115,114,101,97,108,98,97,115,0,0,0,0,0,109,100,95,106,117,117,111,117,107,105,0,0,0,0,0,0,83,117,112,101,114,32,79,102,102,32,82,111,97,100,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,109,100,95,115,117,112,101,114,111,102,102,0,0,0,0,0,115,102,122,50,97,108,104,0,79,80,76,45,62,100,101,108,116,97,116,45,62,97,99,99,0,0,0,0,0,0,0,0,83,117,112,101,114,32,77,111,110,97,99,111,32,71,80,32,40,85,83,65,41,0,0,0,116,117,114,112,105,110,0,0,97,114,109,101,100,102,0,0,35,100,101,102,105,110,101,32,86,69,82,84,69,88,10,0,109,100,95,115,109,103,112,117,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,71,76,93,58,32,68,105,100,110,39,116,32,102,105,110,100,32,118,97,108,105,100,32,115,104,97,100,101,114,32,98,97,99,107,101,110,100,46,32,67,111,110,116,105,110,117,105,110,103,32,119,105,116,104,111,117,116,32,115,104,97,100,101,114,115,46,10,0,0,0,0,0,0,0,83,117,112,101,114,32,77,111,110,97,99,111,32,71,80,32,40,74,112,110,41,0,0,0,109,100,95,97,100,118,98,97,116,114,0,0,0,0,0,0,109,100,95,115,109,103,112,106,0,0,0,0,0,0,0,0,76,111,115,105,110,103,32,84,101,97,109,39,115,32,71,97,109,101,32,105,115,32,79,118,101,114,0,0,0,0,0,0,78,111,32,67,114,101,100,105,116,115,0,0,0,0,0,0,65,112,112,108,121,32,83,104,97,100,101,114,32,67,104,97,110,103,101,115,0,0,0,0,83,117,112,101,114,32,77,111,110,97,99,111,32,71,80,32,40,69,117,114,111,44,32,74,112,110,41,0,0,0,0,0,49,48,32,77,105,110,0,0,84,105,109,101,114,32,65,100,106,117,115,116,0,0,0,0,49,47,52,32,102,111,114,32,67,121,99,108,101,32,87,105,110,110,101,114,0,0,0,0,109,100,95,115,109,103,112,97,0,0,0,0,0,0,0,0,37,115,95,108,105,110,101,97,114,0,0,0,0,0,0,0,109,105,97,0,0,0,0,0,83,117,112,101,114,32,77,97,114,105,111,32,87,111,114,108,100,32,126,32,83,117,112,101,114,32,77,97,114,105,111,32,66,114,111,115,46,32,40,80,105,114,97,116,101,44,32,65,108,116,32,50,41,0,0,0,83,78,75,0,0,0,0,0,67,104,105,112,37,105,80,101,114,105,111,100,0,0,0,0,50,48,107,32,97,110,100,32,101,118,101,114,121,32,51,48,107,0,0,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,39,32,45,32,67,104,97,109,112,105,111,110,32,69,100,105,116,105,111,110,32,40,86,48,48,52,32,98,111,111,116,108,101,103,32,115,101,116,32,51,44,32,57,50,48,51,49,51,32,101,116,99,41,0,0,66,105,111,115,32,115,101,108,101,99,116,32,40,70,97,107,101,41,0,0,0,0,0,0,77,97,107,97,105,32,80,114,105,110,99,101,32,68,111,114,97,98,111,99,99,104,97,110,0,0,0,0,0,0,0,0,115,97,109,115,104,111,53,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,72,105,116,98,111,120,32,116,121,112,101,32,40,37,115,41,32,105,115,32,105,110,118,97,108,105,100,46,32,85,115,101,32,34,114,97,100,105,97,108,34,32,111,114,32,34,114,101,99,116,34,46,10,0,0,0,109,100,95,115,109,98,98,0,65,108,116,101,114,101,100,32,66,101,97,115,116,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,0,100,101,116,97,116,119,105,110,0,0,0,0,0,0,0,0,73,114,101,109,32,40,108,105,99,101,110,115,101,100,32,102,114,111,109,32,84,111,107,117,109,97,32,83,104,111,116,101,110,41,0,0,0,0,0,0,83,117,112,101,114,32,77,97,114,105,111,32,87,111,114,108,100,32,126,32,83,117,112,101,114,32,77,97,114,105,111,32,66,114,111,115,46,32,40,80,105,114,97,116,101,44,32,65,108,116,41,0,0,0,0,0,112,107,117,110,119,97,114,0,109,121,115,116,105,99,114,105,98,0,0,0,0,0,0,0,115,108,45,62,118,111,108,117,109,101,0,0,0,0,0,0,105,109,103,102,105,103,104,116,106,0,0,0,0,0,0,0,109,100,95,115,109,98,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,90,101,114,111,32,50,32,65,108,112,104,97,32,40,57,54,48,56,49,51,32,66,114,97,122,105,108,41,0,0,0,0,0,78,101,111,32,71,101,111,32,85,110,105,66,73,79,83,59,32,100,105,115,97,98,108,101,100,124,101,110,97,98,108,101,100,0,0,0,0,0,0,0,109,100,95,115,109,98,97,0,75,111,110,97,109,105,32,40,83,116,101,114,110,32,108,105,99,101,110,115,101,41,0,0,82,46,79,80,84,73,79,78,0,0,0,0,0,0,0,0,84,111,109,109,121,32,76,97,115,111,114,100,97,32,66,97,115,101,98,97,108,108,32,40,85,83,65,41,0,0,0,0,109,100,95,108,97,115,111,114,100,97,0,0,0,0,0,0,83,117,112,101,114,32,76,101,97,103,117,101,32,40,74,112,110,41,0,0,0,0,0,0,66,111,116,104,32,84,101,97,109,115,39,32,71,97,109,101,115,32,79,118,101,114,0,0,109,100,95,115,117,112,114,108,101,97,103,106,0,0,0,0,85,110,107,110,111,119,110,32,84,70,82,47,69,88,71,32,105,100,120,32,97,116,32,80,67,58,37,48,52,120,10,0,83,117,112,101,114,32,76,101,97,103,117,101,32,40,69,117,114,111,41,0,0,0,0,0,80,49,32,116,111,112,45,108,101,102,116,0,0,0,0,0,49,49,0,0,0,0,0,0,109,100,95,115,117,112,114,108,101,97,103,0,0,0,0,0,115,102,50,118,48,48,52,51,0,0,0,0,0,0,0,0,37,48,56,120,58,32,71,52,45,49,32,85,110,100,101,102,105,110,101,100,32,84,104,117,109,98,32,105,110,115,116,114,117,99,116,105,111,110,58,32,37,48,52,120,32,37,120,10,0,0,0,0,0,0,0,0,112,99,101,95,109,97,107,97,105,112,114,105,0,0,0,0,83,78,75,32,118,115,46,32,67,97,112,99,111,109,32,45,32,83,86,67,32,67,104,97,111,115,32,83,117,112,101,114,32,80,108,117,115,32,40,98,111,111,116,108,101,103,41,0,0,0,0,0,0,0,0,0,83,117,112,101,114,32,75,105,99,107,32,79,102,102,32,40,69,117,114,111,41,0,0,0,110,72,68,54,51,48,57,67,121,99,108,101,115,68,111,110,101,91,105,93,0,0,0,0,109,100,95,97,108,116,98,101,97,115,116,0,0,0,0,0,109,100,95,115,107,105,99,107,111,102,102,0,0,0,0,0,83,117,112,101,114,32,72,121,100,108,105,100,101,32,40,85,83,65,41,0,0,0,0,0,115,102,122,50,97,108,98,0,110,90,101,116,67,121,99,108,101,115,84,111,116,97,108,0,109,100,95,115,117,112,104,121,100,108,117,0,0,0,0,0,84,117,114,116,108,101,115,0,0,0,0,0,0,0,0,0,71,97,108,83,116,97,114,115,83,99,114,111,108,108,80,111,115,0,0,0,0,0,0,0,82,45,62,120,0,0,0,0,83,117,112,101,114,32,72,121,100,108,105,100,101,32,40,74,112,110,41,0,0,0,0,0,109,100,95,115,117,112,104,121,100,108,106,0,0,0,0,0,99,104,105,112,45,62,99,111,117,110,116,0,0,0,0,0,80,97,114,101,110,116,32,115,101,116,32,102,111,114,32,119,111,114,107,105,110,103,32,100,114,105,118,101,114,115,0,0,83,117,112,101,114,32,72,121,100,108,105,100,101,32,40,69,117,114,111,41,0,0,0,0,71,97,109,101,32,79,118,101,114,32,84,121,112,101,0,0,109,100,95,115,117,112,104,121,100,108,0,0,0,0,0,0,84,111,97,112,108,97,110,0,83,117,112,101,114,32,72,105,103,104,32,73,109,112,97,99,116,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,82,97,105,122,105,110,103,32,47,32,56,105,110,103,0,0,109,100,95,115,104,105,109,112,97,99,116,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,39,32,45,32,67,104,97,109,112,105,111,110,32,69,100,105,116,105,111,110,32,40,86,48,48,52,32,98,111,111,116,108,101,103,32,115,101,116,32,50,44,32,57,50,48,51,49,51,32,101,116,99,41,0,0,77,97,107,97,105,32,72,97,107,107,101,110,32,68,101,110,32,83,104,97,100,97,0,0,115,118,99,115,112,108,117,115,0,0,0,0,0,0,0,0,83,117,112,101,114,32,72,97,110,103,45,79,110,32,40,87,111,114,108,100,41,0,0,0,65,108,105,115,105,97,32,68,114,97,103,111,111,110,32,40,85,83,65,41,0,0,0,0,109,100,95,115,104,97,110,103,111,110,49,0,0,0,0,0,86,45,70,105,118,101,32,40,74,97,112,97,110,41,0,0,83,117,112,101,114,32,72,97,110,103,45,79,110,32,40,87,111,114,108,100,44,32,82,101,118,46,32,65,41,0,0,0,117,111,112,111,107,111,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,90,101,114,111,32,50,32,65,108,112,104,97,32,40,57,54,48,56,50,54,32,65,115,105,97,41,0,0,0,0,0,0,0,109,100,95,115,104,97,110,103,111,110,0,0,0,0,0,0,116,117,114,116,108,101,115,0,83,117,112,101,114,32,70,97,110,116,97,115,121,32,90,111,110,101,32,40,74,112,110,41,0,0,0,0,0,0,0,0,105,110,102,111,45,62,107,48,53,52,53,51,57,95,102,108,97,103,115,0,0,0,0,0,78,111,32,115,111,117,110,100,32,40,115,111,117,110,100,32,77,67,85,32,110,111,116,32,100,117,109,112,101,100,41,0,109,100,95,115,102,122,111,110,101,106,0,0,0,0,0,0,83,117,112,101,114,32,70,97,110,116,97,115,121,32,90,111,110,101,32,40,69,117,114,111,41,0,0,0,0,0,0,0,112,52,32,102,105,114,101,32,51,0,0,0,0,0,0,0,109,100,95,115,102,122,111,110,101,0,0,0,0,0,0,0,79,110,108,121,32,98,101,102,111,114,101,32,108,101,118,101,108,32,53,0,0,0,0,0,83,117,112,101,114,32,68,97,105,115,101,110,114,121,97,107,117,32,40,74,112,110,41,0,0,0,0,0,0,0,0,0,80,49,32,98,111,116,116,111,109,45,99,101,110,116,101,114,0,0,0,0,0,0,0,0,66,71,86,32,76,116,100,0,72,97,110,100,115,32,80,101,114,32,71,97,109,101,0,0,109,100,95,115,117,112,100,97,105,115,110,97,0,0,0,0,115,102,50,118,48,48,52,50,0,0,0,0,0,0,0,0,112,99,101,95,109,97,107,97,105,104,97,107,0,0,0,0,91,84,111,97,112,108,97,110,93,32,84,97,105,116,111,32,67,111,114,112,111,114,97,116,105,111,110,0,0,0,0,0,83,78,75,32,118,115,46,32,67,97,112,99,111,109,32,45,32,83,86,67,32,67,104,97,111,115,32,80,108,117,115,32,40,98,111,111,116,108,101,103,32,115,101,116,32,50,41,0,0,0,0,0,0,0,0,0,83,117,112,101,114,32,68,97,105,115,101,110,114,121,97,107,117,32,40,74,112,110,44,32,82,101,118,46,32,48,50,41,0,0,0,0,0,0,0,0,109,100,95,97,108,105,115,105,97,100,117,0,0,0,0,0,82,111,98,111,99,111,112,32,50,32,40,69,117,114,111,47,65,115,105,97,32,118,48,46,49,48,41,0,0,0,0,0,109,100,95,115,117,112,100,97,105,115,110,0,0,0,0,0,91,84,111,97,112,108,97,110,93,32,72,97,110,97,102,114,97,109,0,0,0,0,0,0,71,97,114,114,121,32,75,105,116,99,104,101,110,39,115,32,83,117,112,101,114,32,66,97,116,116,108,101,116,97,110,107,32,45,32,87,97,114,32,105,110,32,116,104,101,32,71,117,108,102,32,40,85,83,65,41,0,0,0,0,0,0,0,0,115,102,122,50,97,108,0,0,68,111,103,121,117,117,110,0,0,0,0,0,0,0,0,0,109,100,95,115,98,116,97,110,107,0,0,0,0,0,0,0,67,111,105,110,32,77,117,115,105,99,0,0,0,0,0,0,83,117,112,101,114,32,66,97,116,116,108,101,115,104,105,112,32,40,85,83,65,41,0,0,98,111,111,116,108,101,103,0,109,103,97,107,117,101,110,0,109,100,95,115,98,115,104,105,112,0,0,0,0,0,0,0,68,105,101,116,32,71,111,32,71,111,32,40,85,83,65,32,118,49,46,49,32,49,57,57,50,46,48,57,46,50,54,41,0,0,0,0,0,0,0,0,50,48,50,48,32,84,111,115,104,105,32,83,117,112,101,114,32,66,97,115,101,98,97,108,108,32,40,74,112,110,41,0,0,0,0,0,0,0,0,0,115,117,98,50,109,97,105,110,91,48,93,0,0,0,0,0,109,100,95,50,48,50,48,98,98,106,0,0,0,0,0,0,83,117,112,101,114,32,66,97,115,101,98,97,108,108,32,50,48,50,48,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,0,0,0,78,111,32,115,111,117,110,100,0,0,0,0,0,0,0,0,83,104,111,119,32,99,111,114,114,101,99,116,32,97,110,115,119,101,114,0,0,0,0,0,109,100,95,50,48,50,48,98,98,0,0,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,39,32,45,32,67,104,97,109,112,105,111,110,32,69,100,105,116,105,111,110,32,40,86,48,48,52,32,98,111,111,116,108,101,103,32,115,101,116,32,49,44,32,49,48,50,48,57,50,32,85,83,65,41,0,0,78,111,32,83,111,117,110,100,32,40,117,110,100,117,109,112,101,100,32,77,67,85,41,0,77,97,106,105,110,32,69,105,121,117,117,32,68,101,110,32,87,97,116,97,114,117,0,0,115,118,99,112,108,117,115,97,0,0,0,0,0,0,0,0,83,117,110,115,101,116,32,82,105,100,101,114,115,32,40,85,83,65,41,0,0,0,0,0,71,97,109,101,32,65,114,116,115,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,68,73,83,75,95,67,79,78,84,82,79,76,95,73,78,84,69,82,70,65,67,69,46,10,0,109,100,95,115,115,114,105,100,101,114,115,117,0,0,0,0,83,117,110,115,101,116,32,82,105,100,101,114,115,32,40,69,117,114,111,41,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,90,101,114,111,32,50,32,40,57,54,48,50,50,57,32,79,99,101,97,110,105,97,41,0,0,109,100,95,115,115,114,105,100,101,114,115,0,0,0,0,0,70,114,111,103,103,101,114,32,40,83,99,114,97,109,98,108,101,32,104,97,114,100,119,97,114,101,41,0,0,0,0,0,71,80,57,48,48,49,84,105,108,101,66,97,110,107,0,0,83,117,109,109,101,114,32,67,104,97,108,108,101,110,103,101,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,109,100,95,115,117,109,109,101,114,0,0,0,0,0,0,0,111,115,99,97,114,117,0,0,83,117,98,84,101,114,114,97,110,105,97,32,40,85,83,65,41,0,0,0,0,0,0,0,112,51,32,102,105,114,101,32,51,0,0,0,0,0,0,0,69,105,103,104,116,105,110,103,0,0,0,0,0,0,0,0,109,100,95,115,117,98,116,101,114,114,117,0,0,0,0,0,109,97,114,107,104,97,109,0,83,117,98,84,101,114,114,97,110,105,97,32,40,74,112,110,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,50,48,50,41,0,0,80,49,32,116,111,112,45,99,101,110,116,101,114,0,0,0,84,111,97,112,108,97,110,32,40,84,97,105,116,111,32,76,105,99,101,110,115,101,41,0,67,111,110,116,105,110,117,101,32,105,102,32,112,108,97,121,101,114,32,98,117,115,116,115,0,0,0,0,0,0,0,0,109,100,95,115,117,98,116,101,114,114,112,51,0,0,0,0,115,102,50,118,48,48,52,0,112,99,101,95,119,97,116,97,114,117,0,0,0,0,0,0,83,78,75,32,118,115,46,32,67,97,112,99,111,109,32,45,32,83,86,67,32,67,104,97,111,115,32,80,108,117,115,32,40,98,111,111,116,108,101,103,32,115,101,116,32,49,41,0,0,0,0,0,0,0,0,0,83,117,98,84,101,114,114,97,110,105,97,32,40,74,112,110,41,0,0,0,0,0,0,0,65,108,105,115,105,97,32,68,114,97,103,111,111,110,32,40,74,112,110,41,0,0,0,0,103,112,105,108,111,116,115,0,83,104,105,112,112,117,32,77,97,104,111,117,32,68,97,105,115,97,107,117,115,101,110,32,45,32,107,105,110,103,100,111,109,32,103,114,97,110,100,112,114,105,120,0,0,0,0,0,109,100,95,115,117,98,116,101,114,114,106,0,0,0,0,0,80,49,32,83,116,114,111,110,103,32,80,117,110,99,104,0,83,101,114,105,97,108,32,66,117,102,102,101,114,0,0,0,77,97,104,111,117,32,68,97,105,115,97,107,117,115,101,110,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,83,117,98,84,101,114,114,97,110,105,97,32,40,80,114,111,116,111,116,121,112,101,44,32,69,97,114,108,105,101,114,41,0,0,0,0,0,0,0,0,115,102,122,50,110,0,0,0,49,57,56,48,0,0,0,0,53,48,48,48,48,48,32,111,110,108,121,0,0,0,0,0,72,105,116,32,115,99,111,114,101,0,0,0,0,0,0,0,42,49,48,48,49,49,120,120,120,120,0,0,0,0,0,0,51,48,48,44,48,48,48,112,116,115,32,56,48,48,44,48,48,48,112,116,115,0,0,0,109,100,95,115,117,98,116,101,114,114,112,50,0,0,0,0,85,112,45,114,105,103,104,116,32,116,121,112,101,0,0,0,102,114,111,103,103,114,115,0,49,53,48,107,32,97,110,100,32,101,118,101,114,121,32,50,48,48,107,0,0,0,0,0,50,48,48,48,48,48,0,0,83,117,98,84,101,114,114,97,110,105,97,32,40,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,0,0,0,49,48,48,107,32,97,110,100,32,52,48,48,107,0,0,0,49,48,48,107,32,97,110,100,32,101,118,101,114,121,32,50,48,48,107,0,0,0,0,0,109,100,95,115,117,98,116,101,114,114,112,49,0,0,0,0,83,117,98,84,101,114,114,97,110,105,97,32,40,69,117,114,111,41,0,0,0,0,0,0,77,105,100,110,105,103,104,116,32,82,101,115,105,115,116,97,110,99,101,32,40,85,83,41,0,0,0,0,0,0,0,0,68,114,105,102,116,32,79,117,116,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,109,100,95,115,117,98,116,101,114,114,0,0,0,0,0,0,98,105,116,95,98,97,110,107,0,0,0,0,0,0,0,0,51,48,0,0,0,0,0,0,75,97,103,101,107,105,32,40,74,97,112,97,110,41,0,0,66,108,111,99,107,32,40,71,97,109,101,32,67,111,114,112,111,114,97,116,105,111,110,32,98,111,111,116,108,101,103,44,32,115,101,116,32,50,41,0,0,0,0,0,0,0,0,0,83,116,114,105,107,101,114,32,40,69,117,114,111,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,0,83,101,103,97,0,0,0,0,50,48,32,115,101,99,46,32,47,32,49,53,32,115,101,99,46,0,0,0,0,0,0,0,67,111,110,116,105,110,101,110,116,97,108,32,67,105,114,99,117,115,32,40,74,97,112,97,110,41,0,0,0,0,0,0,109,100,95,115,116,114,105,107,101,114,112,0,0,0,0,0,100,111,109,109,121,0,0,0,84,97,105,116,111,32,65,109,101,114,105,99,97,32,67,111,114,112,111,114,97,116,105,111,110,0,0,0,0,0,0,0,97,95,115,116,101,112,0,0,114,97,115,116,97,110,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,39,32,45,32,67,104,97,109,112,105,111,110,32,69,100,105,116,105,111,110,32,40,82,101,100,32,87,97,118,101,32,98,111,111,116,108,101,103,32,115,101,116,32,50,44,32,57,50,48,51,49,51,32,101,116,99,41,0,0,0,0,0,0,98,111,110,122,101,97,100,118,0,0,0,0,0,0,0,0,77,105,99,114,111,32,67,97,98,105,110,0,0,0,0,0,115,118,99,112,108,117,115,0,83,116,114,105,107,101,114,32,40,69,117,114,111,41,0,0,109,100,95,97,108,105,115,105,97,100,106,0,0,0,0,0,80,49,32,66,117,116,116,111,110,32,90,0,0,0,0,0,109,100,95,115,116,114,105,107,101,114,0,0,0,0,0,0,67,97,108,67,110,116,0,0,74,111,74,111,39,115,32,86,101,110,116,117,114,101,32,47,32,74,111,74,111,32,110,111,32,75,105,109,121,111,117,32,110,97,32,66,111,117,107,101,110,32,40,74,97,112,97,110,32,57,57,48,49,50,56,41,0,0,0,0,0,0,0,0,84,67,48,50,50,48,73,79,67,68,105,112,0,0,0,0,83,116,114,105,100,101,114,32,82,101,116,117,114,110,115,32,45,32,74,111,117,114,110,101,121,32,102,114,111,109,32,68,97,114,107,110,101,115,115,32,40,85,83,65,41,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,90,101,114,111,32,50,32,40,57,54,48,50,50,55,32,74,97,112,97,110,41,0,0,0,0,78,111,32,83,111,117,110,100,0,0,0,0,0,0,0,0,104,118,121,109,101,116,97,108,0,0,0,0,0,0,0,0,37,0,0,0,97,0,0,0,32,0,0,0,37,0,0,0,98,0,0,0,32,0,0,0,37,0,0,0,100,0,0,0,32,0,0,0,37,0,0,0,72,0,0,0,58,0,0,0,37,0,0,0,77,0,0,0,58,0,0,0,37,0,0,0,83,0,0,0,32,0,0,0,37,0,0,0,89,0,0,0,0,0,0,0,0,0,0,0,108,103,104,111,115,116,0,0,109,100,95,115,116,114,105,100,101,114,50,117,0,0,0,0,70,114,111,103,32,40,71,97,108,97,120,105,97,110,32,104,97,114,100,119,97,114,101,41,0,0,0,0,0,0,0,0,83,117,112,101,114,32,77,111,110,97,99,111,32,71,80,32,40,87,111,114,108,100,44,32,82,101,118,32,66,44,32,70,68,49,48,57,52,32,51,49,55,45,48,49,50,54,97,41,0,0,0,0,0,0,0,0,73,110,105,116,105,97,108,32,69,110,116,114,121,0,0,0,118,105,100,101,111,95,97,108,108,111,119,95,114,111,116,97,116,101,0,0,0,0,0,0,49,58,49,48,0,0,0,0,83,116,114,105,100,101,114,32,73,73,32,40,69,117,114,111,41,0,0,0,0,0,0,0,109,103,99,114,121,115,116,108,0,0,0,0,0,0,0,0,109,100,95,115,116,114,105,100,101,114,50,0,0,0,0,0,68,114,97,119,32,79,98,106,101,99,116,115,0,0,0,0,50,58,49,53,0,0,0,0,83,116,114,105,100,101,114,32,72,105,114,121,117,117,32,40,74,112,110,44,32,75,111,114,41,0,0,0,0,0,0,0,70,105,110,97,108,32,66,111,115,115,32,67,111,110,116,105,110,117,101,0,0,0,0,0,76,111,119,101,115,116,0,0,109,100,95,115,116,114,105,100,101,114,106,0,0,0,0,0,78,111,116,104,105,110,103,0,65,102,101,103,97,0,0,0,68,101,101,114,32,72,117,110,116,105,110,103,32,85,83,65,32,86,52,46,50,0,0,0,83,116,114,105,100,101,114,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,66,111,110,117,115,63,0,0,65,99,116,105,118,97,116,101,32,39,83,99,111,114,101,32,76,105,110,101,39,63,32,40,67,104,101,97,116,41,0,0,49,53,32,115,101,99,46,32,47,32,49,48,32,115,101,99,46,0,0,0,0,0,0,0,82,101,115,101,116,32,111,110,32,80,46,79,46,83,46,84,46,32,69,114,114,111,114,0,109,100,95,115,116,114,105,100,101,114,0,0,0,0,0,0,115,102,50,114,101,100,50,0,65,115,32,83,116,97,114,116,32,80,114,105,99,101,0,0,82,101,103,105,111,110,32,40,70,97,107,101,41,0,0,0,103,97,108,104,117,115,116,108,0,0,0,0,0,0,0,0,68,105,115,112,108,97,121,32,78,101,120,116,32,66,97,108,108,0,0,0,0,0,0,0,77,97,105,115,111,110,32,73,107,107,111,107,117,0,0,0,73,110,99,111,109,112,108,101,116,101,32,115,111,117,110,100,0,0,0,0,0,0,0,0,83,78,75,32,118,115,46,32,67,97,112,99,111,109,32,45,32,83,86,67,32,67,104,97,111,115,32,40,98,111,111,116,108,101,103,41,0,0,0,0,80,0,0,0,114,0,0,0,101,0,0,0,116,0,0,0,116,0,0,0,121,0,0,0,32,0,0,0,83,0,0,0,111,0,0,0,108,0,0,0,100,0,0,0,105,0,0,0,101,0,0,0,114,0,0,0,32,0,0,0,83,0,0,0,97,0,0,0,105,0,0,0,108,0,0,0,111,0,0,0,114,0,0,0,32,0,0,0,77,0,0,0,111,0,0,0,111,0,0,0,110,0,0,0,0,0,0,0,142,127,0,0,17,92,0,0,115,89,0,0,38,98,0,0,235,88,0,0,32,0,0,0,187,48,0,0,252,48,0,0,233,48,0,0,252,48,0,0,224,48,0,0,252,48,0,0,243,48,0,0,32,0,0,0,40,0,0,0,118,0,0,0,101,0,0,0,114,0,0,0,46,0,0,0,32,0,0,0,57,0,0,0,53,0,0,0,47,0,0,0,48,0,0,0,51,0,0,0,47,0,0,0,50,0,0,0,50,0,0,0,44,0,0,0,32,0,0,0,84,0,0,0,97,0,0,0,105,0,0,0,119,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,66,97,114,101,32,75,110,117,99,107,108,101,32,73,73,73,32,40,74,112,110,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,0,66,97,108,108,115,0,0,0,112,114,111,116,101,99,116,105,111,110,95,118,97,108,117,101,0,0,0,0,0,0,0,0,65,108,105,101,110,32,83,116,111,114,109,32,40,87,111,114,108,100,41,0,0,0,0,0,109,100,95,98,107,51,112,0,69,118,101,114,121,32,51,48,48,48,48,0,0,0,0,0,67,111,105,110,97,103,101,32,77,111,100,101,32,49,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,102,105,110,100,32,97,110,121,32,105,110,112,117,116,32,100,114,105,118,101,114,32,110,97,109,101,100,32,34,37,115,34,10,0,119,119,102,115,115,116,97,114,0,0,0,0,0,0,0,0,66,97,114,101,32,75,110,117,99,107,108,101,32,73,73,73,32,40,74,112,110,41,0,0,115,102,122,50,106,114,49,0,114,101,122,111,110,116,0,0,109,100,95,98,107,51,0,0,102,114,111,103,103,0,0,0,49,32,71,97,109,101,32,77,97,116,99,104,0,0,0,0,74,101,105,108,32,67,111,109,112,117,116,101,114,32,83,121,115,116,101,109,0,0,0,0,119,111,110,100,108,57,54,0,83,116,114,101,101,116,115,32,111,102,32,82,97,103,101,32,51,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,84,101,110,103,97,105,0,83,101,110,103,111,107,117,32,66,108,97,100,101,32,45,32,115,101,110,103,111,107,117,32,97,99,101,32,101,112,105,115,111,100,101,32,73,73,0,0,0,42,49,49,48,120,0,0,0,80,49,32,98,117,116,116,111,110,32,54,0,0,0,0,0,109,100,95,115,111,114,51,117,0,0,0,0,0,0,0,0,52,48,107,32,49,48,48,107,32,49,48,48,107,0,0,0,49,115,116,32,66,111,110,117,115,32,76,105,102,101,0,0,84,67,48,53,49,48,78,73,79,68,105,112,0,0,0,0,83,116,114,101,101,116,115,32,111,102,32,82,97,103,101,32,51,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,51,50,56,41,0,0,0,0,0,0,0,0,0,80,97,110,103,32,40,98,111,111,116,108,101,103,44,32,115,101,116,32,52,41,0,0,0,52,32,80,108,97,121,101,114,115,32,47,32,50,32,67,111,105,110,32,83,108,111,116,115,0,0,0,0,0,0,0,0,66,103,83,99,114,111,108,108,89,91,105,93,0,0,0,0,83,117,112,101,114,32,84,101,99,104,110,105,113,117,101,115,0,0,0,0,0,0,0,0,65,32,50,67,47,49,67,32,66,32,49,67,47,51,67,0,109,100,95,115,111,114,51,117,112,48,55,0,0,0,0,0,98,111,111,116,108,101,103,32,40,82,101,110,101,45,80,105,101,114,114,101,41,0,0,0,103,97,117,110,116,108,101,116,50,112,103,0,0,0,0,0,83,116,114,101,101,116,115,32,111,102,32,82,97,103,101,32,51,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,51,49,56,41,0,0,0,0,0,0,0,0,0,67,32,40,72,97,114,100,41,0,0,0,0,0,0,0,0,84,105,109,101,32,116,111,32,98,101,116,32,47,32,97,110,115,119,101,114,0,0,0,0,109,100,95,115,111,114,51,117,112,48,56,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,39,32,45,32,67,104,97,109,112,105,111,110,32,69,100,105,116,105,111,110,32,40,82,101,100,32,87,97,118,101,32,98,111,111,116,108,101,103,32,115,101,116,32,49,44,32,57,50,48,51,49,51,32,101,116,99,41,0,0,0,0,0,0,68,111,110,107,101,121,32,75,111,110,103,32,74,117,110,105,111,114,32,40,74,97,112,97,110,63,41,0,0,0,0,0,112,99,101,95,109,105,107,107,111,107,117,0,0,0,0,0,115,118,99,98,111,111,116,0,84,67,48,54,52,48,70,73,79,73,110,112,117,116,80,111,114,116,51,0,0,0,0,0,83,116,114,101,101,116,115,32,111,102,32,82,97,103,101,32,51,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,51,49,55,41,0,0,0,0,0,0,0,0,0,109,100,95,97,115,116,111,114,109,0,0,0,0,0,0,0,80,49,32,66,117,116,116,111,110,0,0,0,0,0,0,0,109,100,95,115,111,114,51,117,112,48,57,0,0,0,0,0,67,45,67,104,105,112,32,82,97,109,0,0,0,0,0,0,71,108,111,98,97,108,32,67,111,114,112,111,114,97,116,105,111,110,0,0,0,0,0,0,67,111,105,110,32,65,32,38,32,66,0,0,0,0,0,0,83,116,114,101,101,116,115,32,111,102,32,82,97,103,101,32,51,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,51,48,56,41,0,0,0,0,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,90,101,114,111,32,50,32,40,57,54,48,52,51,48,32,74,97,112,97,110,41,0,0,0,0,37,89,45,37,109,45,37,100,45,37,72,45,37,77,45,37,83,0,0,0,0,0,0,0,83,111,110,32,111,102,32,80,104,111,101,110,105,120,0,0,85,112,114,105,103,104,116,32,40,84,119,111,32,80,108,97,121,101,114,115,41,0,0,0,109,100,95,115,111,114,51,117,112,49,48,0,0,0,0,0,70,114,111,103,32,40,70,97,108,99,111,110,32,98,111,111,116,108,101,103,41,0,0,0,67,114,101,100,105,116,115,32,65,0,0,0,0,0,0,0,102,110,107,121,102,105,115,104,0,0,0,0,0,0,0,0,65,32,49,47,50,32,66,32,49,47,49,50,0,0,0,0,83,116,114,101,101,116,115,32,111,102,32,82,97,103,101,32,51,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,52,49,51,41,0,0,0,0,0,0,0,0,0,67,104,97,114,32,82,79,77,0,0,0,0,0,0,0,0,53,45,53,0,0,0,0,0,82,111,117,110,100,32,54,0,109,100,95,115,111,114,51,117,112,48,49,0,0,0,0,0,109,95,107,98,95,115,119,97,112,0,0,0,0,0,0,0,83,116,114,101,101,116,115,32,111,102,32,82,97,103,101,32,51,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,52,49,50,41,0,0,0,0,0,0,0,0,0,83,99,114,111,108,108,32,82,65,77,0,0,0,0,0,0,84,104,101,32,75,105,108,108,105,110,103,32,66,108,97,100,101,32,40,86,49,48,57,44,32,67,104,105,110,97,41,0,0,0,0,0,0,0,0,0,52,32,80,108,97,121,101,114,115,32,47,32,50,32,67,97,98,105,110,101,116,115,32,67,111,109,98,105,110,101,100,0,109,100,95,115,111,114,51,117,112,48,50,0,0,0,0,0,100,100,114,65,0,0,0,0,83,116,114,101,101,116,115,32,111,102,32,82,97,103,101,32,51,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,52,49,49,41,0,0,0,0,0,0,0,0,0,52,56,0,0,0,0,0,0,69,110,97,98,108,101,32,65,100,117,108,116,32,65,102,102,97,105,114,115,32,67,97,116,101,103,111,114,121,0,0,0,109,100,95,115,111,114,51,117,112,48,51,0,0,0,0,0,115,102,50,114,101,100,0,0,77,97,104,106,111,110,103,32,83,104,105,107,121,97,107,117,32,82,101,116,115,117,100,101,110,32,45,32,77,97,104,106,111,110,103,32,87,97,114,115,0,0,0,0,0,0,0,0,67,97,112,116,97,105,110,32,67,111,109,109,97,110,100,111,32,40,98,111,111,116,108,101,103,32,115,101,116,32,49,44,32,57,49,49,48,49,52,32,111,116,104,101,114,32,99,111,117,110,116,114,121,41,0,0,83,78,75,32,118,115,46,32,67,97,112,99,111,109,32,45,32,83,86,67,32,67,104,97,111,115,32,40,78,71,77,45,50,54,57,48,41,40,78,71,72,45,50,54,57,48,41,0,0,0,0,0,0,0,0,0,83,116,114,101,101,116,115,32,111,102,32,82,97,103,101,32,51,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,52,48,56,41,0,0,0,0,0,0,0,0,0,67,121,98,101,114,45,76,105,112,32,40,78,71,77,45,48,49,48,41,0,0,0,0,0,78,101,111,71,114,97,112,104,105,99,115,82,65,77,66,97,110,107,0,0,0,0,0,0,118,100,99,95,121,115,99,114,111,108,108,91,105,93,0,0,65,108,105,101,110,32,83,111,108,100,105,101,114,32,40,74,112,110,41,0,0,0,0,0,109,100,95,115,111,114,51,117,112,48,52,0,0,0,0,0,83,116,114,101,101,116,115,32,111,102,32,82,97,103,101,32,51,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,52,48,52,41,0,0,0,0,0,0,0,0,0,115,102,122,50,106,0,0,0,79,80,76,45,62,100,101,108,116,97,116,45,62,110,111,119,95,115,116,101,112,0,0,0,109,99,117,95,99,111,105,110,97,103,101,91,49,93,0,0,66,103,83,99,114,111,108,108,89,0,0,0,0,0,0,0,109,100,95,115,111,114,51,117,112,48,53,0,0,0,0,0,102,114,111,103,102,0,0,0,82,101,116,114,111,65,114,99,104,58,32,70,111,117,110,100,32,71,76,83,76,32,118,101,114,116,101,120,32,115,104,97,100,101,114,46,10,0,0,0,83,116,114,101,101,116,115,32,111,102,32,82,97,103,101,32,51,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,52,48,49,41,0,0,0,0,0,0,0,0,0])
.concat([82,101,116,114,111,65,114,99,104,58,32,91,71,76,93,58,32,85,115,105,110,103,32,71,76,83,76,32,115,104,97,100,101,114,32,98,97,99,107,101,110,100,46,10,0,0,0,0,109,100,95,115,111,114,51,117,112,48,54,0,0,0,0,0,112,114,101,104,105,115,108,101,0,0,0,0,0,0,0,0,83,116,114,101,101,116,115,32,111,102,32,82,97,103,101,32,51,32,40,69,117,114,111,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,52,50,53,41,0,0,0,52,32,80,108,97,121,101,114,115,32,47,32,52,32,67,111,105,110,32,83,108,111,116,115,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,97,110,110,111,116,32,112,111,108,108,32,114,97,119,32,106,111,121,112,97,100,32,115,116,97,116,101,46,0,0,0,0,0,0,109,100,95,115,111,114,51,112,49,0,0,0,0,0,0,0,48,56,32,77,105,110,0,0,77,101,100,105,117,109,32,72,97,114,100,0,0,0,0,0,115,116,100,58,58,98,97,100,95,97,108,108,111,99,0,0,78,105,110,116,101,110,100,111,0,0,0,0,0,0,0,0,49,47,52,32,102,111,114,32,83,116,97,103,101,32,87,105,110,110,101,114,0,0,0,0,83,116,114,101,101,116,115,32,111,102,32,82,97,103,101,32,51,32,40,69,117,114,111,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,52,50,48,41,0,0,0,116,101,120,116,117,114,101,115,0,0,0,0,0,0,0,0,109,105,97,106,0,0,0,0,109,100,95,115,111,114,51,112,50,0,0,0,0,0,0,0,80,111,119,101,114,101,100,32,71,101,97,114,32,45,32,115,116,114,97,116,101,103,105,99,32,118,97,114,105,97,110,116,32,97,114,109,111,114,32,101,113,117,105,112,109,101,110,116,32,40,57,52,48,57,49,54,32,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,109,97,122,105,110,103,101,114,0,0,0,0,0,0,0,0,49,48,107,32,97,110,100,32,101,118,101,114,121,32,50,48,107,0,0,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,39,32,45,32,67,104,97,109,112,105,111,110,32,69,100,105,116,105,111,110,32,40,82,97,105,110,98,111,119,32,98,111,111,116,108,101,103,32,115,101,116,32,54,44,32,57,50,48,51,49,51,32,101,116,99,41,0,0,0,0,0,0,0,86,111,105,99,101,0,0,0,112,99,101,95,109,106,119,97,114,115,0,0,0,0,0,0,115,118,99,0,0,0,0,0,114,101,99,116,0,0,0,0,83,116,114,101,101,116,115,32,111,102,32,82,97,103,101,32,51,32,40,69,117,114,111,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,52,49,53,41,0,0,0,109,100,95,97,108,105,101,110,115,111,108,106,0,0,0,0,71,88,48,54,48,0,0,0,109,100,95,115,111,114,51,112,51,0,0,0,0,0,0,0,76,111,116,32,76,111,116,0,0,0,0,0,0,0,0,0,71,117,110,32,72,111,104,107,105,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,73,109,97,103,101,32,70,105,103,104,116,32,40,74,97,112,97,110,44,32,114,101,118,105,115,105,111,110,32,65,41,0,0,0,0,0,0,0,0,0,115,108,45,62,84,76,76,0,83,116,114,101,101,116,115,32,111,102,32,82,97,103,101,32,51,32,40,69,117,114,111,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,52,49,51,41,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,90,101,114,111,32,50,32,40,57,54,48,51,48,52,32,72,105,115,112,97,110,105,99,41,0,0,0,0,0,0,0,0,0,109,100,95,115,111,114,51,112,52,0,0,0,0,0,0,0,70,114,111,103,0,0,0,0,83,116,114,101,101,116,115,32,111,102,32,82,97,103,101,32,51,32,40,69,117,114,111,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,52,49,50,41,0,0,0,109,100,95,115,111,114,51,112,53,0,0,0,0,0,0,0,83,116,114,101,101,116,115,32,111,102,32,82,97,103,101,32,51,32,40,75,111,114,41,0,0,0,0,0,0,0,0,0,109,100,95,115,111,114,51,107,0,0,0,0,0,0,0,0,83,116,114,101,101,116,115,32,111,102,32,82,97,103,101,32,51,32,40,69,117,114,111,41,0,0,0,0,0,0,0,0,98,108,111,99,107,111,117,116,0,0,0,0,0,0,0,0,109,100,95,115,111,114,51,0,115,102,50,114,98,54,0,0,77,97,104,106,111,110,103,32,72,97,111,117,32,68,101,110,32,45,32,75,97,105,115,101,114,39,115,32,81,117,101,115,116,0,0,0,0,0,0,0,83,78,75,32,118,115,46,32,67,97,112,99,111,109,32,45,32,83,86,67,32,67,104,97,111,115,32,40,74,65,77,77,65,32,80,67,66,44,32,115,101,116,32,50,41,0,0,0,66,97,114,101,32,75,110,117,99,107,108,101,32,73,73,32,40,74,112,110,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,0,0,65,108,105,101,110,32,83,111,108,100,105,101,114,32,40,69,117,114,111,41,0,0,0,0,110,67,97,118,101,83,112,114,105,116,101,66,97,110,107,0,109,100,95,98,107,50,112,0,91,83,97,110,114,105,116,115,117,93,32,83,101,103,97,0,83,116,114,101,101,116,115,32,111,102,32,82,97,103,101,32,50,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,115,102,122,50,104,0,0,0,70,97,105,108,101,100,32,116,111,32,114,101,109,111,118,101,32,100,105,115,107,32,102,114,111,109,32,116,114,97,121,46,0,0,0,0,0,0,0,0,109,100,95,115,111,114,50,117,0,0,0,0,0,0,0,0,102,114,111,103,103,101,114,115,0,0,0,0,0,0,0,0,71,97,108,83,116,97,114,115,69,110,97,98,108,101,0,0,83,116,114,101,101,116,115,32,111,102,32,82,97,103,101,32,73,73,32,40,69,117,114,111,41,32,126,32,66,97,114,101,32,75,110,117,99,107,108,101,32,73,73,32,45,32,83,104,105,116,111,117,32,101,32,110,111,32,67,104,105,110,103,111,110,107,97,32,40,74,112,110,41,0,0,0,0,0,0,0,109,100,95,115,111,114,50,0,83,116,114,101,101,116,32,83,109,97,114,116,32,40,74,112,110,44,32,85,83,65,41,0,0,0,0,0,0,0,0,0,67,111,114,101,108,97,110,100,32,47,32,83,101,103,97,0,54,48,107,32,97,110,100,32,101,118,101,114,121,32,56,48,107,0,0,0,0,0,0,0,109,100,95,115,115,109,97,114,116,0,0,0,0,0,0,0,85,98,105,32,83,111,102,116,0,0,0,0,0,0,0,0,83,116,114,101,101,116,32,82,97,99,101,114,32,40,69,117,114,111,41,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,39,32,45,32,67,104,97,109,112,105,111,110,32,69,100,105,116,105,111,110,32,40,82,97,105,110,98,111,119,32,98,111,111,116,108,101,103,32,115,101,116,32,53,44,32,57,50,48,51,50,50,32,74,97,112,97,110,41,0,0,0,0,0,112,99,101,95,109,106,107,97,105,115,101,114,0,0,0,0,115,118,99,112,99,98,97,0,109,100,95,115,114,97,99,101,114,0,0,0,0,0,0,0,109,100,95,97,108,105,101,110,115,111,108,0,0,0,0,0,82,51,32,98,117,116,116,111,110,32,40,116,104,117,109,98,41,0,0,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,39,32,45,32,83,112,101,99,105,97,108,32,67,104,97,109,112,105,111,110,32,69,100,105,116,105,111,110,32,40,85,83,65,41,0,0,0,0,0,77,97,114,98,108,101,32,47,32,65,67,69,32,73,110,116,101,114,110,97,116,105,111,110,97,108,0,0,0,0,0,0,109,100,95,115,102,50,117,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,90,101,114,111,32,50,32,40,57,54,48,51,48,52,32,66,114,97,122,105,108,41,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,39,32,84,117,114,98,111,32,40,80,105,114,97,116,101,41,0,0,0,0,0,0,0,49,57,57,51,63,0,0,0,109,100,95,115,102,50,112,105,114,0,0,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,39,32,80,108,117,115,32,40,74,112,110,44,32,65,115,105,97,44,32,75,111,114,41,0,0,0,0,0,0,0,0,51,48,107,32,97,110,100,32,101,118,101,114,121,32,56,48,107,0,0,0,0,0,0,0,83,101,103,97,32,47,32,78,97,115,99,111,63,0,0,0,109,100,95,115,102,50,106,0,86,100,112,66,103,67,111,108,111,117,114,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,39,32,45,32,83,112,101,99,105,97,108,32,67,104,97,109,112,105,111,110,32,69,100,105,116,105,111,110,32,40,69,117,114,111,41,0,0,0,0,65,115,116,114,105,97,110,115,32,40,99,108,111,110,101,32,111,102,32,83,119,97,114,109,41,0,0,0,0,0,0,0,54,50,53,48,48,0,0,0,109,100,95,115,102,50,0,0,115,102,50,114,98,53,0,0,77,97,104,106,111,110,103,32,71,111,107,117,117,32,83,112,101,99,105,97,108,0,0,0,83,78,75,32,118,115,46,32,67,97,112,99,111,109,32,45,32,83,86,67,32,67,104,97,111,115,32,40,74,65,77,77,65,32,80,67,66,44,32,115,101,116,32,49,41,0,0,0,66,101,121,111,110,100,32,79,97,115,105,115,32,40,85,83,65,41,0,0,0,0,0,0,65,0,0,0,108,0,0,0,105,0,0,0,101,0,0,0,110,0,0,0,179,0,0,0,32,0,0,0,40,0,0,0,69,0,0,0,117,0,0,0,114,0,0,0,111,0,0,0,44,0,0,0,32,0,0,0,85,0,0,0,83,0,0,0,65,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,114,111,98,111,99,111,112,50,0,0,0,0,0,0,0,0,109,100,95,98,101,121,111,97,115,105,115,0,0,0,0,0,65,99,101,32,65,116,116,97,99,107,101,114,32,40,74,97,112,97,110,44,32,83,121,115,116,101,109,32,49,54,65,44,32,70,68,49,48,57,52,32,51,49,55,45,48,48,54,48,41,0,0,0,0,0,0,0,84,104,101,32,83,116,111,114,121,32,111,102,32,84,104,111,114,32,40,83,112,97,41,0,0,0,0,0,0,0,0,0,115,102,122,50,98,114,49,0,109,100,95,116,104,111,114,115,0,0,0,0,0,0,0,0,70,114,111,103,103,101,114,32,40,77,111,111,110,32,67,114,101,115,116,97,32,104,97,114,100,119,97,114,101,41,0,0,65,116,108,117,115,32,47,32,67,97,118,101,0,0,0,0,66,101,121,111,110,100,32,79,97,115,105,115,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,49,49,48,49,41,0,0,0,0,0,0,0,0,0,69,108,101,99,116,114,111,110,105,99,32,68,101,118,105,99,101,115,32,73,116,97,108,121,0,0,0,0,0,0,0,0,109,100,95,98,101,121,111,97,115,105,115,112,0,0,0,0,73,110,32,67,104,97,110,103,32,69,108,101,99,116,114,111,110,105,99,32,67,111,0,0,84,104,101,32,83,116,111,114,121,32,111,102,32,84,104,111,114,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,49,48,49,55,41,0,0,0,0,80,97,114,97,0,0,0,0,50,48,107,32,97,110,100,32,101,118,101,114,121,32,56,48,107,0,0,0,0,0,0,0,109,100,95,116,104,111,114,112,49,0,0,0,0,0,0,0,112,50,32,122,45,97,120,105,115,0,0,0,0,0,0,0,84,104,101,32,83,116,111,114,121,32,111,102,32,84,104,111,114,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,49,48,48,52,41,0,0,0,0,53,53,48,48,48,0,0,0,75,97,110,101,107,111,0,0,109,100,95,116,104,111,114,112,50,0,0,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,39,32,45,32,67,104,97,109,112,105,111,110,32,69,100,105,116,105,111,110,32,40,82,97,105,110,98,111,119,32,98,111,111,116,108,101,103,32,115,101,116,32,52,44,32,57,50,48,51,50,50,32,74,97,112,97,110,41,0,0,0,0,0,112,99,101,95,109,106,103,111,107,117,115,112,0,0,0,0,115,118,99,112,99,98,0,0,84,104,101,32,83,116,111,114,121,32,111,102,32,84,104,111,114,32,40,75,111,114,41,0,0,0,0,0,0,0,0,0,65,108,105,101,110,51,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,69,83,68,0,0,0,0,0,109,100,95,116,104,111,114,107,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,75,69,89,66,79,65,82,68,95,67,65,76,76,66,65,67,75,46,10,0,0,0,0,0,0,77,105,110,32,67,111,114,112,46,0,0,0,0,0,0,0,84,104,101,32,83,116,111,114,121,32,111,102,32,84,104,111,114,32,40,74,112,110,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,90,101,114,111,32,50,32,40,57,54,48,53,51,49,32,66,114,97,122,105,108,41,0,0,0,69,108,101,99,116,114,111,110,105,99,32,68,101,118,105,99,101,115,32,73,116,97,108,121,32,47,32,51,68,32,71,97,109,101,115,32,69,110,103,108,97,110,100,0,0,0,0,0,109,100,95,116,104,111,114,106,112,0,0,0,0,0,0,0,102,114,111,103,103,101,114,109,99,0,0,0,0,0,0,0,84,104,101,32,83,116,111,114,121,32,111,102,32,84,104,111,114,32,45,32,72,105,107,97,114,105,32,111,32,84,115,117,103,117,109,111,110,111,32,40,74,112,110,41,0,0,0,0,109,100,95,116,104,111,114,106,0,0,0,0,0,0,0,0,80,115,121,99,104,111,45,78,105,99,115,32,79,115,99,97,114,32,40,87,111,114,108,100,32,114,101,118,105,115,105,111,110,32,48,41,0,0,0,0,84,104,101,32,83,116,111,114,121,32,111,102,32,84,104,111,114,32,40,71,101,114,41,0,0,0,0,0,0,0,0,0,49,48,107,32,97,110,100,32,101,118,101,114,121,32,56,48,107,0,0,0,0,0,0,0,83,117,110,65,0,0,0,0,109,100,95,116,104,111,114,103,0,0,0,0,0,0,0,0,80,50,32,66,97,116,32,83,119,105,110,103,0,0,0,0,84,104,101,32,83,116,111,114,121,32,111,102,32,84,104,111,114,32,40,69,117,114,111,41,0,0,0,0,0,0,0,0,86,105,100,101,111,32,83,121,115,116,101,109,32,67,111,46,0,0,0,0,0,0,0,0,52,55,53,48,48,0,0,0,83,116,111,114,109,108,111,114,100,32,40,74,112,110,41,0,0,0,0,0,0,0,0,0,115,102,50,114,98,52,0,0,77,97,104,106,111,110,103,32,71,97,107,117,101,110,32,77,105,108,100,32,45,32,84,111,117,109,97,32,83,111,117,115,104,105,114,111,117,32,84,111,117,106,111,117,32,40,65,108,116,41,0,0,0,0,0,0,77,101,116,97,108,32,83,108,117,103,32,53,32,80,108,117,115,32,40,98,111,111,116,108,101,103,41,0,0,0,0,0,109,100,95,115,116,114,109,108,111,114,100,106,0,0,0,0,109,100,95,97,108,105,101,110,51,97,0,0,0,0,0,0,89,117,110,32,83,117,110,103,0,0,0,0,0,0,0,0,80,49,32,77,101,100,105,117,109,32,80,117,110,99,104,0,82,97,122,111,114,83,111,102,116,0,0,0,0,0,0,0,79,107,115,97,110,0,0,0,83,116,111,114,109,108,111,114,100,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,115,102,122,50,98,0,0,0,112,104,111,101,110,105,120,0,53,48,48,48,48,48,44,32,101,118,101,114,121,32,49,48,48,48,48,48,48,0,0,0,69,120,99,101,108,108,101,110,116,32,83,121,115,116,101,109,0,0,0,0,0,0,0,0,42,49,48,48,48,48,120,120,120,120,0,0,0,0,0,0,69,120,116,101,110,100,0,0,109,100,95,115,116,114,109,108,111,114,100,0,0,0,0,0,83,108,97,112,32,70,105,103,104,116,32,40,98,111,111,116,108,101,103,32,115,101,116,32,51,41,0,0,0,0,0,0,70,114,111,103,103,101,114,32,40,83,101,103,97,32,115,101,116,32,50,41,0,0,0,0,50,48,48,107,32,97,110,100,32,101,118,101,114,121,32,51,48,48,107,0,0,0,0,0,49,48,48,48,48,48,0,0,83,116,111,110,101,32,80,114,111,116,101,99,116,111,114,115,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,0,66,97,100,32,77,117,115,105,99,32,102,114,111,109,32,102,105,114,115,116,32,77,83,77,54,50,57,53,0,0,0,0,49,48,48,107,32,111,110,108,121,0,0,0,0,0,0,0,85,110,105,99,111,0,0,0,49,48,48,107,32,97,110,100,32,51,48,48,107,0,0,0,74,97,112,97,110,32,40,68,105,115,116,114,105,98,117,116,101,100,32,98,121,32,84,101,99,109,111,41,0,0,0,0,109,100,95,115,116,111,110,112,114,111,116,0,0,0,0,0,84,101,99,104,110,111,115,32,74,97,112,97,110,0,0,0,49,48,48,75,32,111,110,108,121,0,0,0,0,0,0,0,83,116,101,101,108,32,84,97,108,111,110,115,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,109,105,100,114,101,115,117,0,53,48,107,32,97,110,100,32,51,53,48,107,0,0,0,0,100,114,105,102,116,111,117,116,106,0,0,0,0,0,0,0,68,101,110,105,97,109,0,0,109,100,95,115,116,101,101,108,116,97,108,112,0,0,0,0,66,117,108,108,101,116,115,32,112,101,114,32,77,97,103,97,122,105,110,101,0,0,0,0,107,97,103,101,107,105,106,0,97,114,107,98,108,111,99,50,0,0,0,0,0,0,0,0,83,116,101,101,108,32,84,97,108,111,110,115,32,40,74,112,110,44,32,75,111,114,41,0,0,0,0,0,0,0,0,0,84,101,116,114,105,115,32,40,74,97,112,97,110,44,32,66,45,83,121,115,116,101,109,44,32,89,77,50,54,49,48,41,0,0,0,0,0,0,0,0,73,109,112,101,114,102,101,99,116,32,71,70,88,0,0,0,99,111,110,116,99,105,114,99,106,0,0,0,0,0,0,0,109,100,95,115,116,101,101,108,116,97,108,106,0,0,0,0,74,117,109,112,105,110,103,0,0,0,0,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,39,32,45,32,67,104,97,109,112,105,111,110,32,69,100,105,116,105,111,110,32,40,82,97,105,110,98,111,119,32,98,111,111,116,108,101,103,32,115,101,116,32,51,44,32,57,50,48,51,50,50,32,101,116,99,41,0,0,0,0,0,0,0,85,46,78,46,32,68,101,102,101,110,115,101,32,70,111,114,99,101,58,32,69,97,114,116,104,32,74,111,107,101,114,0,0,0,0,0,0,0,0,0,112,99,101,95,109,106,103,97,107,109,108,100,49,0,0,0,109,115,53,112,108,117,115,0,83,116,101,101,108,32,84,97,108,111,110,115,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,0,0,97,95,97,99,99,0,0,0,65,0,0,0,108,0,0,0,105,0,0,0,101,0,0,0,110,0,0,0,179,0,0,0,32,0,0,0,40,0,0,0,69,0,0,0,117,0,0,0,114,0,0,0,111,0,0,0,44,0,0,0,32,0,0,0,85,0,0,0,83,0,0,0,65,0,0,0,44,0,0,0,32,0,0,0,82,0,0,0,101,0,0,0,118,0,0,0,46,0,0,0,32,0,0,0,65,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,84,117,114,98,111,32,79,117,116,32,82,117,110,32,40,99,111,99,107,112,105,116,44,32,70,68,49,48,57,52,32,51,49,55,45,48,49,48,55,41,0,0,0,0,0,0,0,0,65,66,77,32,38,32,71,101,99,97,115,0,0,0,0,0,109,100,95,115,116,101,101,108,116,97,108,0,0,0,0,0,106,111,106,111,106,0,0,0,97,116,111,109,105,99,112,0,115,104,97,110,103,117,112,98,0,0,0,0,0,0,0,0,83,116,97,114,103,97,116,101,32,40,69,117,114,111,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,90,101,114,111,32,50,32,40,57,54,48,50,50,55,32,65,115,105,97,41,0,0,0,0,0,83,101,103,97,32,47,32,67,111,114,101,108,97,110,100,0,37,97,32,37,98,32,37,100,32,37,72,58,37,77,58,37,83,32,37,89,0,0,0,0,68,101,115,101,114,116,32,66,114,101,97,107,101,114,32,40,74,97,112,97,110,44,32,70,68,49,48,57,52,32,51,49,55,45,48,49,57,52,41,0,0,0,0,0,0,0,0,0,109,100,95,115,116,97,114,103,97,116,101,112,0,0,0,0,102,114,111,103,103,101,114,115,50,0,0,0,0,0,0,0,115,109,103,112,0,0,0,0,73,110,102,105,110,105,116,101,32,76,105,118,101,115,32,40,67,104,101,97,116,41,0,0,84,105,109,101,32,76,105,109,105,116,0,0,0,0,0,0,118,105,100,101,111,95,115,104,97,100,101,114,95,101,110,97,98,108,101,0,0,0,0,0,112,97,115,115,115,104,116,49,54,97,0,0,0,0,0,0,83,116,97,114,103,97,116,101,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,83,101,109,105,0,0,0,0,71,114,101,97,116,32,49,48,48,48,32,77,105,108,101,115,32,82,97,108,108,121,32,50,32,85,83,65,32,40,57,53,47,48,53,47,49,56,41,0,0,0,0,0,0,0,0,0,109,100,95,115,116,97,114,103,97,116,101,0,0,0,0,0,86,101,114,121,95,72,97,114,100,0,0,0,0,0,0,0,50,58,48,48,0,0,0,0,83,116,97,114,102,108,105,103,104,116,32,40,69,117,114,111,44,32,85,83,65,41,0,0,70,97,99,116,111,114,121,32,83,101,116,116,105,110,103,0,51,67,95,49,67,0,0,0,53,48,107,32,97,110,100,32,50,53,48,107,0,0,0,0,85,80,76,0,0,0,0,0,109,100,95,115,116,97,114,102,108,49,0,0,0,0,0,0,83,116,97,103,103,101,114,32,73,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,100,101,101,114,104,117,110,116,97,0,0,0,0,0,0,0,83,116,97,114,102,108,105,103,104,116,32,40,69,117,114,111,44,32,85,83,65,44,32,118,49,46,49,41,0,0,0,0,77,111,100,101,32,50,0,0,83,101,105,98,117,32,75,97,105,104,97,116,115,117,0,0,51,50,53,48,48,0,0,0,109,100,95,115,116,97,114,102,108,0,0,0,0,0,0,0,50,49,32,80,111,105,110,116,115,32,97,110,100,32,50,32,65,100,118,46,0,0,0,0,115,102,50,114,98,51,0,0,87,79,87,32,78,101,119,32,70,97,110,116,97,115,105,97,0,0,0,0,0,0,0,0,90,97,112,115,0,0,0,0,77,97,104,106,111,110,103,32,71,97,107,117,101,110,32,77,105,108,100,32,45,32,84,111,117,109,97,32,83,111,117,115,104,105,114,111,117,32,84,111,117,106,111,117,0,0,0,0,78,111,105,115,101,32,70,97,99,116,111,114,121,0,0,0,77,101,116,97,108,32,83,108,117,103,32,53,32,40,74,65,77,77,65,32,80,67,66,41,0,0,0,0,0,0,0,0,80,114,101,116,116,121,32,83,111,108,100,105,101,114,32,83,97,105,108,111,114,32,77,111,111,110,32,40,118,101,114,46,32,57,53,47,48,51,47,50,50,44,32,84,97,105,119,97,110,41,0,0,0,0,0,0,83,116,97,114,32,84,114,101,107,32,45,32,84,104,101,32,78,101,120,116,32,71,101,110,101,114,97,116,105,111,110,32,45,32,69,99,104,111,101,115,32,102,114,111,109,32,116,104,101,32,80,97,115,116,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,49,50,53,41,0,0,0,0,112,114,111,116,101,99,116,105,111,110,95,115,116,97,116,117,115,0,0,0,0,0,0,0,65,114,101,110,97,32,69,110,116,101,114,116,97,105,110,109,101,110,116,0,0,0,0,0,109,100,95,115,116,116,110,103,112,48,49,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,101,116,32,97,117,100,105,111,32,105,110,112,117,116,32,114,97,116,101,32,116,111,58,32,37,46,50,102,32,72,122,46,10,0,0,0,83,116,97,114,32,84,114,101,107,32,45,32,84,104,101,32,78,101,120,116,32,71,101,110,101,114,97,116,105,111,110,32,45,32,69,99,104,111,101,115,32,102,114,111,109,32,116,104,101,32,80,97,115,116,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,49,49,56,41,0,0,0,0,115,102,122,50,97,0,0,0,65,108,108,117,109,101,114,0,109,100,95,115,116,116,110,103,112,48,50,0,0,0,0,0,75,111,110,97,109,105,32,40,83,101,103,97,32,108,105,99,101,110,115,101,41,0,0,0,86,83,32,77,97,116,99,104,101,115,47,67,114,101,100,105,116,0,0,0,0,0,0,0,70,105,110,97,108,32,84,101,116,114,105,115,0,0,0,0,208,198,0,0,84,179,0,0,172,185,0,0,248,173,0,0,164,194,0,0,192,208,0,0,32,0,0,0,45,0,0,0,32,0,0,0,141,193,0,0,32,0,0,0,228,185,0,0,193,201,0,0,252,188,0,0,32,0,0,0,12,211,0,0,116,199,0,0,5,211,0,0,32,0,0,0,40,0,0,0,75,0,0,0,111,0,0,0,114,0,0,0,101,0,0,0,97,0,0,0,41,0,0,0,0,0,0,0,87,0,0,0,111,0,0,0,110,0,0,0,100,0,0,0,101,0,0,0,114,0,0,0,32,0,0,0,76,0,0,0,101,0,0,0,97,0,0,0,103,0,0,0,117,0,0,0,101,0,0,0,32,0,0,0,83,0,0,0,116,0,0,0,97,0,0,0,114,0,0,0,32,0,0,0,45,0,0,0,32,0,0,0,83,0,0,0,111,0,0,0,107,0,0,0,45,0,0,0,77,0,0,0,97,0,0,0,103,0,0,0,105,0,0,0,99,0,0,0,98,0,0,0,97,0,0,0,108,0,0,0,108,0,0,0,32,0,0,0,70,0,0,0,105,0,0,0,103,0,0,0,104,0,0,0,116,0,0,0,105,0,0,0,110,0,0,0,103,0,0,0,0,0,0,0,0,0,0,0,83,116,97,114,32,84,114,101,107,32,45,32,84,104,101,32,78,101,120,116,32,71,101,110,101,114,97,116,105,111,110,32,45,32,69,99,104,111,101,115,32,102,114,111,109,32,116,104,101,32,80,97,115,116,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,49,49,48,41,0,0,0,0,116,101,110,103,97,105,106,0,75,97,110,101,107,111,32,40,78,97,109,99,111,32,108,105,99,101,110,115,101,41,0,0,84,101,116,114,105,115,32,116,104,101,32,65,98,115,111,108,117,116,101,32,84,104,101,32,71,114,97,110,100,32,77,97,115,116,101,114,32,50,32,80,108,117,115,0,0,0,0,0,109,100,95,115,116,116,110,103,112,48,51,0,0,0,0,0,51,48,107,32,32,56,48,107,32,32,56,48,107,0,0,0,83,117,99,99,101,115,115,0,83,116,97,114,32,84,114,101,107,32,45,32,84,104,101,32,78,101,120,116,32,71,101,110,101,114,97,116,105,111,110,32,45,32,69,99,104,111,101,115,32,102,114,111,109,32,116,104,101,32,80,97,115,116,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,49,48,51,41,0,0,0,0,112,97,110,103,98,50,0,0,49,67,32,50,67,32,47,32,49,67,32,54,67,0,0,0,51,48,107,32,97,110,100,32,49,53,48,107,0,0,0,0,72,101,114,111,0,0,0,0,109,100,95,115,116,116,110,103,112,48,52,0,0,0,0,0,67,114,111,99,107,45,77,97,110,32,40,98,111,111,116,108,101,103,44,32,82,101,110,101,45,80,105,101,114,114,101,41,0,0,0,0,0,0,0,0,71,97,117,110,116,108,101,116,32,40,50,32,80,108,97,121,101,114,115,44,32,74,97,112,97,110,101,115,101,44,32,114,101,118,32,53,41,0,0,0,83,116,97,114,32,84,114,101,107,32,45,32,84,104,101,32,78,101,120,116,32,71,101,110,101,114,97,116,105,111,110,32,45,32,69,99,104,111,101,115,32,102,114,111,109,32,116,104,101,32,80,97,115,116,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,49,50,50,57,41,0,0,0,0,49,53,0,0,0,0,0,0,73,110,105,116,105,97,108,32,104,105,103,104,32,115,99,111,114,101,0,0,0,0,0,0,65,32,40,65,118,101,114,97,103,101,41,0,0,0,0,0,50,53,48,48,48,0,0,0,109,100,95,115,116,116,110,103,112,48,53,0,0,0,0,0,67,97,118,101,32,47,32,78,105,104,111,110,32,83,121,115,116,101,109,32,105,110,99,46,0,0,0,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,39,32,45,32,67,104,97,109,112,105,111,110,32,69,100,105,116,105,111,110,32,40,82,97,105,110,98,111,119,32,98,111,111,116,108,101,103,32,115,101,116,32,50,44,32,57,50,48,51,50,50,32,101,116,99,41,0,0,0,0,0,0,0,100,107,111,110,103,106,110,114,106,0,0,0,0,0,0,0,112,117,99,107,109,97,110,0,75,0,0,0,110,0,0,0,105,0,0,0,103,0,0,0,104,0,0,0,116,0,0,0,115,0,0,0,32,0,0,0,111,0,0,0,102,0,0,0,32,0,0,0,86,0,0,0,97,0,0,0,108,0,0,0,111,0,0,0,117,0,0,0,114,0,0,0,32,0,0,0,83,0,0,0,117,0,0,0,112,0,0,0,101,0,0,0,114,0,0,0,104,0,0,0,101,0,0,0,114,0,0,0,111,0,0,0,101,0,0,0,115,0,0,0,0,0,0,0,9,78,0,0,253,86,0,0,24,98,0,0,170,126,0,0,0,0,0,0,206,152,0,0,145,78,0,0,141,81,0,0,119,141,0,0,32,0,0,0,40,0,0,0,98,0,0,0,111,0,0,0,111,0,0,0,116,0,0,0,108,0,0,0,101,0,0,0,103,0,0,0,44,0,0,0,32,0,0,0,86,0,0,0,49,0,0,0,48,0,0,0,52,0,0,0,44,0,0,0,32,0,0,0,67,0,0,0,104,0,0,0,105,0,0,0,110,0,0,0,97,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,80,111,98,121,32,47,32,86,105,114,117,115,0,0,0,0,112,99,101,95,109,106,103,97,107,109,108,100,0,0,0,0,109,115,53,112,99,98,0,0,83,116,97,114,32,84,114,101,107,32,45,32,84,104,101,32,78,101,120,116,32,71,101,110,101,114,97,116,105,111,110,32,45,32,69,99,104,111,101,115,32,102,114,111,109,32,116,104,101,32,80,97,115,116,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,49,50,50,56,41,0,0,0,0,65,108,105,101,110,51,32,40,69,117,114,111,44,32,85,83,65,44,32,82,101,118,46,32,65,41,0,0,0,0,0,0,109,100,95,115,116,116,110,103,112,48,54,0,0,0,0,0,74,111,105,110,101,109,0,0,83,116,97,114,32,84,114,101,107,32,45,32,84,104,101,32,78,101,120,116,32,71,101,110,101,114,97,116,105,111,110,32,45,32,69,99,104,111,101,115,32,102,114,111,109,32,116,104,101,32,80,97,115,116,32,40,85,83,65,41,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,65,108,112,104,97,32,50,32,40,57,54,48,51,48,54,32,85,83,65,41,0,0,0,0,0,88,32,50,0,0,0,0,0,37,115,47,82,101,116,114,111,65,114,99,104,45,114,101,99,111,118,101,114,121,45,0,0,114,101,112,117,108,115,101,0,84,67,72,0,0,0,0,0,85,112,114,105,103,104,116,32,40,79,110,101,32,80,108,97,121,101,114,41,0,0,0,0,109,100,95,115,116,116,110,103,97,0,0,0,0,0,0,0,70,114,111,103,103,101,114,32,40,83,101,103,97,32,115,101,116,32,49,41,0,0,0,0,66,111,110,117,115,32,86,105,116,97,108,105,116,121,0,0,32,49,32,67,111,105,110,32,32,54,32,67,114,101,100,105,116,115,0,0,0,0,0,0,65,32,49,47,50,32,66,32,49,47,49,49,0,0,0,0,83,116,97,114,32,84,114,101,107,32,45,32,84,104,101,32,78,101,120,116,32,71,101,110,101,114,97,116,105,111,110,32,45,32,69,99,104,111,101,115,32,102,114,111,109,32,116,104,101,32,80,97,115,116,32,40,85,83,65,44,32,118,49,46,49,41,0,0,0,0,0,0,70,105,110,97,108,32,82,111,117,110,100,32,67,111,110,116,105,110,117,97,116,105,111,110,0,0,0,0,0,0,0,0,109,100,95,115,116,116,110,103,0,0,0,0,0,0,0,0,68,97,114,107,32,84,111,119,101,114,0,0,0,0,0,0,109,95,107,98,95,112,116,114,0,0,0,0,0,0,0,0,83,116,97,114,32,84,114,101,107,32,45,32,68,101,101,112,32,83,112,97,99,101,32,78,105,110,101,32,45,32,67,114,111,115,115,114,111,97,100,115,32,111,102,32,84,105,109,101,32,40,85,83,65,41,0,0,51,48,107,32,97,110,100,32,49,48,48,107,0,0,0,0,109,100,95,115,116,100,115,57,117,0,0,0,0,0,0,0,80,49,32,66,97,116,32,83,119,105,110,103,0,0,0,0,83,116,97,114,32,84,114,101,107,32,45,32,68,101,101,112,32,83,112,97,99,101,32,78,105,110,101,32,45,32,67,114,111,115,115,114,111,97,100,115,32,111,102,32,84,105,109,101,32,40,69,117,114,111,41,0,0,0,0,0,0,0,0,0,65,116,111,109,105,99,32,82,111,98,111,45,107,105,100,32,83,112,101,99,105,97,108,0,0,0,0,0,0,0,0,0,49,55,53,48,48,0,0,0,68,111,110,103,115,117,110,103,0,0,0,0,0,0,0,0,109,100,95,115,116,100,115,57,0,0,0,0,0,0,0,0,115,102,50,114,98,50,0,0,75,110,105,103,104,116,115,32,111,102,32,86,97,108,111,117,114,32,83,117,112,101,114,104,101,114,111,101,115,32,47,32,83,97,110,103,111,107,117,32,83,101,110,107,105,32,83,117,112,101,114,104,101,114,111,101,115,32,40,98,111,111,116,108,101,103,44,32,86,49,48,52,44,32,67,104,105,110,97,41,0,0,0,0,0,0,0,0,77,97,104,106,111,110,103,32,71,97,107,117,101,110,32,45,32,84,111,117,109,97,32,83,111,117,115,104,105,114,111,117,32,84,111,117,106,111,117,0,0,0,0,0,0,0,0,0,99,97,112,116,99,111,109,109,98,0,0,0,0,0,0,0,77,101,116,97,108,32,83,108,117,103,32,53,32,40,78,71,72,45,50,54,56,48,41,0,0,0,0,0,0,0,0,0,110,78,101,111,54,56,75,82,79,77,66,97,110,107,0,0,83,116,97,114,32,67,114,117,105,115,101,114,32,40,74,112,110,41,0,0,0,0,0,0,109,100,95,97,108,105,101,110,51,0,0,0,0,0,0,0,109,100,95,115,116,97,114,99,114,117,115,0,0,0,0,0,79,80,76,45,62,100,101,108,116,97,116,45,62,110,111,119,95,97,100,100,114,0,0,0,83,116,97,114,32,67,111,110,116,114,111,108,32,40,85,83,65,41,0,0,0,0,0,0,115,102,97,50,117,114,49,0,68,101,108,116,97,84,46,112,111,114,116,115,116,97,116,101,0,0,0,0,0,0,0,0,109,100,95,115,116,97,114,99,116,114,108,0,0,0,0,0,102,114,111,103,103,101,114,115,49,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,99,114,101,97,116,101,32,71,76,32,112,114,111,103,114,97,109,32,35,37,117,46,10,0,0,83,112,111,116,32,71,111,101,115,32,116,111,32,72,111,108,108,121,119,111,111,100,32,40,85,83,65,41,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,71,76,93,58,32,78,111,116,32,108,111,97,100,105,110,103,32,97,110,121,32,115,104,97,100,101,114,46,10,0,0,0,0,0,0,0,98,108,107,116,105,103,101,114,0,0,0,0,0,0,0,0,78,101,97,114,101,115,116,0,109,100,95,115,112,111,116,103,111,117,0,0,0,0,0,0,83,117,112,101,114,83,99,111,112,101,0,0,0,0,0,0,90,101,114,111,32,84,111,108,101,114,97,110,99,101,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,83,112,111,116,32,71,111,101,115,32,116,111,32,72,111,108,108,121,119,111,111,100,32,40,69,117,114,111,41,0,0,0,79,114,105,101,110,116,97,108,0,0,0,0,0,0,0,0,70,97,105,108,101,100,32,115,97,118,105,110,103,32,99,111,110,102,105,103,32,116,111,32,34,37,115,34,46,0,0,0,66,97,110,80,114,101,115,116,111,32,47,32,71,97,122,101,108,108,101,0,0,0,0,0,54,48,48,48,48,0,0,0,109,100,95,115,112,111,116,103,111,0,0,0,0,0,0,0,48,54,32,77,105,110,0,0,87,105,110,116,101,99,104,110,111,0,0,0,0,0,0,0,49,47,50,32,102,111,114,32,83,116,97,103,101,32,87,105,110,110,101,114,0,0,0,0,83,112,111,114,116,115,32,84,97,108,107,32,66,97,115,101,98,97,108,108,32,40,85,83,65,41,0,0,0,0,0,0,59,0,0,0,0,0,0,0,72,0,0,0,97,0,0,0,114,0,0,0,100,0,0,0,32,0,0,0,80,0,0,0,117,0,0,0,110,0,0,0,99,0,0,0,104,0,0,0,101,0,0,0,114,0,0,0,32,0,0,0,13,255,0,0,64,136,0,0,126,48,0,0,127,48,0,0,140,48,0,0,110,48,0,0,4,104,0,0,73,81,0,0,13,255,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,112,103,101,97,114,114,49,0,109,100,95,115,112,111,114,116,116,98,98,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,39,32,45,32,67,104,97,109,112,105,111,110,32,69,100,105,116,105,111,110,32,40,82,97,105,110,98,111,119,32,98,111,111,116,108,101,103,32,115,101,116,32,49,44,32,57,50,48,51,50,50,32,101,116,99,41,0,0,0,0,0,0,0,107,111,118,115,104,98,0,0,112,99,101,95,109,106,103,97,107,117,101,110,0,0,0,0,109,115,108,117,103,53,104,0,114,97,100,105,97,108,0,0,83,112,111,114,116,32,71,97,109,101,115,32,40,66,114,97,41,0,0,0,0,0,0,0,73,110,118,105,32,73,109,97,103,101,0,0,0,0,0,0,65,108,101,120,32,75,105,100,100,32,105,110,32,116,104,101,32,69,110,99,104,97,110,116,101,100,32,67,97,115,116,108,101,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,66,101,108,108,115,32,38,32,87,104,105,115,116,108,101,115,32,40,118,101,114,46,32,76,41,0,0,0,0,0,0,0,71,105,114,108,115,32,77,111,100,101,0,0,0,0,0,0,108,111,116,108,111,116,0,0,109,100,95,115,112,111,114,116,103,0,0,0,0,0,0,0,103,117,110,104,111,104,107,105,0,0,0,0,0,0,0,0,105,109,103,102,105,103,104,116,0,0,0,0,0,0,0,0,115,108,45,62,84,76,0,0,83,112,108,97,116,116,101,114,104,111,117,115,101,32,80,97,114,116,32,51,32,40,74,112,110,44,32,75,111,114,41,0,0,0,0,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,65,108,112,104,97,32,50,32,40,57,54,48,52,51,48,32,85,83,65,41,0,0,0,0,0,73,109,112,101,114,102,101,99,116,32,103,114,97,112,104,105,99,115,32,97,110,100,32,115,111,117,110,100,0,0,0,0,109,100,95,115,112,108,97,116,116,104,51,106,0,0,0,0,83,112,108,97,116,116,101,114,104,111,117,115,101,32,51,32,40,85,83,65,41,0,0,0,109,100,95,115,112,108,97,116,116,104,51,0,0,0,0,0,80,108,97,121,109,97,114,107,0,0,0,0,0,0,0,0,83,112,108,97,116,116,101,114,104,111,117,115,101,32,50,32,40,85,83,65,41,0,0,0,49,53,48,107,32,111,110,108,121,0,0,0,0,0,0,0,78,73,88,0,0,0,0,0,109,100,95,115,112,108,97,116,116,104,50,117,0,0,0,0,84,97,107,117,109,105,0,0,83,112,108,97,116,116,101,114,104,111,117,115,101,32,50,32,40,69,117,114,111,41,0,0,83,112,105,114,111,117,32,40,69,117,114,111,41,0,0,0,115,102,50,114,98,0,0,0,75,0,0,0,110,0,0,0,105,0,0,0,103,0,0,0,104,0,0,0,116,0,0,0,115,0,0,0,32,0,0,0,111,0,0,0,102,0,0,0,32,0,0,0,86,0,0,0,97,0,0,0,108,0,0,0,111,0,0,0,117,0,0,0,114,0,0,0,58,0,0,0,32,0,0,0,83,0,0,0,97,0,0,0,110,0,0,0,71,0,0,0,117,0,0,0,111,0,0,0,32,0,0,0,81,0,0,0,117,0,0,0,110,0,0,0,89,0,0,0,105,0,0,0,110,0,0,0,103,0,0,0,90,0,0,0,104,0,0,0,117,0,0,0,97,0,0,0,110,0,0,0,0,0,0,0,9,78,0,0,253,86,0,0,24,98,0,0,170,126,0,0,0,0,0,0,9,78,0,0,253,86,0,0,164,127,0,0,241,130,0,0,32,79,0,0,32,0,0,0,40,0,0,0,115,0,0,0,101,0,0,0,116,0,0,0,32,0,0,0,52,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,97,108,115,111,102,116,0,83,78,75,32,80,108,97,121,109,111,114,101,0,0,0,0,109,100,95,115,112,105,114,111,117,0,0,0,0,0,0,0,109,100,95,97,108,101,120,107,105,100,100,117,0,0,0,0,83,112,105,114,105,116,117,97,108,32,87,97,114,102,97,114,101,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,109,100,95,115,112,105,114,105,116,119,102,0,0,0,0,0,115,102,97,50,117,0,0,0,70,97,105,108,101,100,32,116,111,32,115,101,116,32,100,105,115,107,32,37,117,32,111,102,32,37,117,46,0,0,0,0,86,101,110,111,109,32,38,32,83,112,105,100,101,114,45,77,97,110,32,45,32,83,101,112,97,114,97,116,105,111,110,32,65,110,120,105,101,116,121,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,115,108,45,62,115,116,97,116,101,0,0,0,0,0,0,0,70,114,111,103,103,101,114,0,0,0,0,0,0,0,0,0,82,111,99,107,99,108,105,109])
.concat([83,99,114,111,108,108,89,0,109,100,95,118,101,110,111,109,0,0,0,0,0,0,0,0,103,97,117,110,116,108,101,116,0,0,0,0,0,0,0,0,83,112,105,100,101,114,45,77,97,110,32,38,32,86,101,110,111,109,32,45,32,77,97,120,105,109,117,109,32,67,97,114,110,97,103,101,32,40,87,111,114,108,100,41,0,0,0,0,109,100,95,115,112,105,100,109,97,120,99,0,0,0,0,0,52,48,48,48,48,0,0,0,83,112,105,100,101,114,45,77,97,110,32,118,115,46,32,116,104,101,32,75,105,110,103,112,105,110,32,40,87,111,114,108,100,41,0,0,0,0,0,0,84,101,97,109,32,83,101,108,101,99,116,0,0,0,0,0,109,100,95,115,112,105,100,107,105,110,103,0,0,0,0,0,75,46,79,46,32,83,119,105,116,99,104,0,0,0,0,0,83,112,105,100,101,114,45,77,97,110,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,69,97,114,108,105,101,114,41,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,39,32,45,32,67,104,97,109,112,105,111,110,32,69,100,105,116,105,111,110,32,40,68,111,117,98,108,101,32,75,46,79,46,32,84,117,114,98,111,32,73,73,32,98,111,111,116,108,101,103,44,32,57,48,50,49,52,48,32,85,83,65,41,0,0,0,0,0,0,0,0,75,110,105,103,104,116,115,32,111,102,32,86,97,108,111,117,114,58,32,83,97,110,71,117,111,32,81,117,110,89,105,110,103,90,104,117,97,110,32,47,32,83,97,110,103,111,107,117,32,83,101,110,107,105,58,32,83,97,110,71,117,111,32,81,117,110,89,105,110,103,90,104,117,97,110,32,40,115,101,116,32,52,41,0,0,0,0,0,77,97,103,105,99,97,108,32,67,104,97,115,101,0,0,0,77,101,116,97,108,32,83,108,117,103,32,53,32,40,78,71,77,45,50,54,56,48,41,0,0,0,0,0,0,0,0,0,109,100,95,115,112,105,100,101,114,109,110,112,50,0,0,0,83,97,109,115,117,110,103,0,83,112,105,100,101,114,45,77,97,110,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,109,100,95,115,112,105,100,101,114,109,110,112,49,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,65,108,112,104,97,32,50,32,40,57,54,48,50,50,57,32,69,117,114,111,41,0,0,0,0,84,97,100,0,0,0,0,0,83,112,105,100,101,114,45,77,97,110,32,40,69,117,114,111,44,32,85,83,65,41,0,0,102,114,111,103,103,101,114,0,109,100,95,115,112,105,100,101,114,109,110,0,0,0,0,0,109,101,105,106,105,110,115,110,0,0,0,0,0,0,0,0,83,112,101,101,100,98,97,108,108,32,50,32,45,32,66,114,117,116,97,108,32,68,101,108,117,120,101,32,40,85,83,65,41,0,0,0,0,0,0,0,109,100,95,115,112,101,101,100,98,108,50,117,0,0,0,0,83,112,101,101,100,98,97,108,108,32,50,32,40,74,112,110,41,0,0,0,0,0,0,0,83,101,109,105,67,111,109,0,109,100,95,115,112,101,101,100,98,108,50,106,0,0,0,0,97,115,116,114,105,97,110,115,0,0,0,0,0,0,0,0,83,112,101,101,100,98,97,108,108,32,50,32,40,69,117,114,111,41,0,0,0,0,0,0,115,102,50,100,107,111,116,50,0,0,0,0,0,0,0,0,107,111,118,115,103,113,121,122,99,0,0,0,0,0,0,0,112,99,101,95,109,97,103,99,104,97,115,101,0,0,0,0,109,115,108,117,103,53,0,0,109,100,95,115,112,101,101,100,98,108,50,0,0,0,0,0,65,108,101,120,32,75,105,100,100,32,45,32,67,104,101,111,110,103,111,110,103,32,77,97,115,101,111,110,103,32,40,75,111,114,41,0,0,0,0,0,84,104,101,32,67,108,105,102,102,104,97,110,103,101,114,32,45,32,69,100,119,97,114,100,32,82,97,110,100,121,32,40,74,97,112,97,110,32,118,101,114,32,51,41,0,0,0,0,84,117,109,98,108,101,32,80,111,112,32,40,98,111,111,116,108,101,103,32,115,101,116,32,49,41,0,0,0,0,0,0,83,112,97,114,107,115,116,101,114,32,40,74,112,110,41,0,0,0,0,0,0,0,0,0,65,110,100,97,109,105,114,111,32,69,110,116,101,114,116,97,105,110,109,101,110,116,32,67,111,46,32,76,116,100,46,0,109,100,95,115,112,97,114,107,115,116,114,106,0,0,0,0,115,102,97,50,0,0,0,0,70,50,32,83,121,115,116,101,109,0,0,0,0,0,0,0,83,112,97,114,107,115,116,101,114,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,75,105,110,103,32,38,32,66,97,108,108,111,111,110,32,40,74,97,112,97,110,41,0,0,109,100,95,115,112,97,114,107,115,116,114,117,0,0,0,0,98,111,109,98,106,97,99,107,0,0,0,0,0,0,0,0,83,112,97,114,107,115,116,101,114,32,40,69,117,114,111,41,0,0,0,0,0,0,0,0,109,100,95,115,112,97,114,107,115,116,114,0,0,0,0,0,80,115,105,107,121,111,32,47,32,66,97,110,112,114,101,115,116,111,0,0,0,0,0,0,56,48,107,32,97,110,100,32,101,118,101,114,121,32,49,54,48,107,0,0,0,0,0,0,72,97,114,100,32,53,0,0,83,112,97,99,101,32,73,110,118,97,100,101,114,115,32,57,48,32,40,74,112,110,41,0,0,0,0,0,0,0,0,0,109,100,95,115,105,110,118,57,48,0,0,0,0,0,0,0,65,109,117,115,101,109,101,110,116,0,0,0,0,0,0,0,83,112,97,99,101,32,73,110,118,97,100,101,114,115,32,57,49,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,39,32,45,32,67,104,97,109,112,105,111,110,32,69,100,105,116,105,111,110,32,40,65,99,99,101,108,101,114,97,116,111,114,32,80,116,46,73,73,32,98,111,111,116,108,101,103,44,32,57,50,48,51,49,51,32,84,101,115,116,114,111,110,41,0,0,0,0,0,0,0,75,0,0,0,110,0,0,0,105,0,0,0,103,0,0,0,104,0,0,0,116,0,0,0,115,0,0,0,32,0,0,0,111,0,0,0,102,0,0,0,32,0,0,0,86,0,0,0,97,0,0,0,108,0,0,0,111,0,0,0,117,0,0,0,114,0,0,0,58,0,0,0,32,0,0,0,83,0,0,0,97,0,0,0,110,0,0,0,71,0,0,0,117,0,0,0,111,0,0,0,32,0,0,0,81,0,0,0,117,0,0,0,110,0,0,0,89,0,0,0,105,0,0,0,110,0,0,0,103,0,0,0,90,0,0,0,104,0,0,0,117,0,0,0,97,0,0,0,110,0,0,0,0,0,0,0,9,78,0,0,253,86,0,0,24,98,0,0,170,126,0,0,0,0,0,0,9,78,0,0,253,86,0,0,164,127,0,0,241,130,0,0,32,79,0,0,32,0,0,0,40,0,0,0,115,0,0,0,101,0,0,0,116,0,0,0,32,0,0,0,51,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,77,228,114,99,104,101,110,32,77,97,122,101,0,0,0,0,84,104,101,32,75,105,110,103,32,111,102,32,70,105,103,104,116,101,114,115,32,83,112,101,99,105,97,108,32,69,100,105,116,105,111,110,32,50,48,48,52,32,40,98,111,111,116,108,101,103,41,0,0,0,0,0,109,100,95,115,105,110,118,57,49,0,0,0,0,0,0,0,109,100,95,97,108,101,120,107,105,100,100,107,0,0,0,0,79,114,99,97,0,0,0,0,83,112,97,99,101,32,72,97,114,114,105,101,114,32,73,73,32,40,74,112,110,44,32,76,97,117,110,99,104,32,67,97,114,116,41,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,9,82,101,116,114,111,80,97,100,44,32,80,108,97,121,101,114,32,37,117,44,32,66,117,116,116,111,110,32,34,37,115,34,32,61,62,32,34,37,115,34,10,0,0,0,89,97,99,104,105,121,111,32,69,108,101,99,116,114,111,110,105,99,115,44,32,76,116,100,46,0,0,0,0,0,0,0,109,100,95,115,104,97,114,114,105,101,114,106,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,90,101,114,111,32,40,57,53,48,54,48,53,32,74,97,112,97,110,41,0,0,0,0,0,0,67,97,112,99,111,109,0,0,83,111,114,99,101,114,105,97,110,32,40,74,112,110,41,0,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,67,111,117,108,100,110,39,116,32,102,105,110,100,32,97,110,121,32,110,101,120,116,32,118,105,100,101,111,32,100,114,105,118,101,114,32,40,99,117,114,114,101,110,116,32,111,110,101,58,32,34,37,115,34,41,46,10,0,0,0,66,97,110,112,114,101,115,116,111,32,47,32,80,97,110,100,111,114,97,98,111,120,0,0,107,105,110,103,98,97,108,108,106,0,0,0,0,0,0,0,109,100,95,115,111,114,99,101,114,0,0,0,0,0,0,0,67,97,112,99,111,109,32,40,82,111,109,115,116,97,114,32,108,105,99,101,110,115,101,41,0,0,0,0,0,0,0,0,83,111,114,99,101,114,32,75,105,110,103,100,111,109,32,40,74,112,110,41,0,0,0,0,111,115,99,97,114,0,0,0,83,104,105,110,107,97,105,32,73,110,99,46,32,40,77,97,103,105,99,32,69,108,101,116,114,111,110,105,99,115,32,73,110,99,46,32,108,105,99,101,110,115,101,41,0,0,0,0,109,100,95,115,111,114,99,101,114,107,106,0,0,0,0,0,74,97,108,101,99,111,32,40,78,105,99,104,105,98,117,116,115,117,32,85,83,65,32,108,105,99,101,110,115,101,41,0,55,48,107,32,97,110,100,32,101,118,101,114,121,32,49,53,48,107,0,0,0,0,0,0,72,97,114,100,32,52,0,0,83,111,114,99,101,114,101,114,39,115,32,75,105,110,103,100,111,109,32,40,85,83,65,41,0,0,0,0,0,0,0,0,77,106,108,101,97,103,117,101,66,97,116,50,0,0,0,0,84,101,104,107,97,110,47,83,117,110,32,40,67,101,110,116,117,114,105,32,108,105,99,101,110,115,101,41,0,0,0,0,98,105,111,110,105,99,99,0,109,100,95,115,111,114,99,101,114,107,49,0,0,0,0,0,83,111,114,99,101,114,101,114,39,115,32,75,105,110,103,100,111,109,32,40,85,83,65,44,32,118,49,46,49,41,0,0,115,102,50,97,99,99,112,50,0,0,0,0,0,0,0,0,75,110,105,103,104,116,115,32,111,102,32,86,97,108,111,117,114,58,32,83,97,110,71,117,111,32,81,117,110,89,105,110,103,90,104,117,97,110,32,47,32,83,97,110,103,111,107,117,32,83,101,110,107,105,58,32,83,97,110,71,117,111,32,81,117,110,89,105,110,103,90,104,117,97,110,32,40,115,101,116,32,51,41,0,0,0,0,0,112,99,101,95,109,97,114,99,104,101,110,0,0,0,0,0,107,111,102,50,107,52,115,101,0,0,0,0,0,0,0,0,109,100,95,115,111,114,99,101,114,107,0,0,0,0,0,0,78,105,99,104,105,98,117,116,115,117,0,0,0,0,0,0,65,108,101,120,32,75,105,100,100,32,105,110,32,116,104,101,32,69,110,99,104,97,110,116,101,100,32,67,97,115,116,108,101,32,40,74,112,110,41,0,0,0,0,0,0,0,0,0,108,98,111,119,108,105,110,103,0,0,0,0,0,0,0,0,80,49,32,87,101,97,107,32,80,117,110,99,104,0,0,0,83,111,110,105,99,32,116,104,101,32,72,101,100,103,101,104,111,103,32,51,32,40,85,83,65,41,0,0,0,0,0,0,109,100,95,115,111,110,105,99,51,117,0,0,0,0,0,0,115,102,122,106,114,50,0,0,78,105,110,116,101,110,100,111,32,111,102,32,65,109,101,114,105,99,97,0,0,0,0,0,50,48,48,48,48,48,44,32,101,118,101,114,121,32,53,48,48,48,48,48,0,0,0,0,70,114,101,101,32,80,108,97,121,0,0,0,0,0,0,0,67,97,118,101,32,47,32,74,97,108,101,99,111,0,0,0,42,49,49,49,0,0,0,0,68,32,40,118,101,114,121,32,104,97,114,100,41,0,0,0,83,111,110,105,99,32,116,104,101,32,72,101,100,103,101,104,111,103,32,51,32,40,80,105,114,97,116,101,41,0,0,0,115,108,97,112,102,105,103,104,98,51,0,0,0,0,0,0,75,105,110,103,32,38,32,66,97,108,108,111,111,110,32,40,85,83,41,0,0,0,0,0,50,48,48,107,32,111,110,108,121,0,0,0,0,0,0,0,49,48,48,48,48,48,44,32,50,53,48,48,48,48,0,0,50,48,48,48,48,48,32,111,110,108,121,0,0,0,0,0,49,57,57,52,63,0,0,0,89,117,103,97,0,0,0,0,49,48,48,75,0,0,0,0,84,101,114,114,105,116,111,114,121,32,47,32,76,105,99,101,110,115,101,0,0,0,0,0,109,100,95,115,111,110,105,99,51,112,105,114,0,0,0,0,53,48,75,32,97,110,100,32,49,48,48,75,0,0,0,0,83,111,110,105,99,32,116,104,101,32,72,101,100,103,101,104,111,103,32,50,32,40,87,111,114,108,100,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,0,0,0,53,32,40,114,101,116,111,102,105,110,50,32,52,41,0,0,77,105,100,110,105,103,104,116,32,82,101,115,105,115,116,97,110,99,101,32,40,87,111,114,108,100,41,0,0,0,0,0,53,48,107,32,97,110,100,32,101,118,101,114,121,32,49,50,48,107,0,0,0,0,0,0,86,105,115,99,111,32,40,69,117,114,111,112,101,41,0,0,72,97,114,100,32,51,0,0,66,108,111,99,107,103,97,108,68,105,97,108,50,0,0,0,109,100,95,115,111,110,105,99,50,112,49,0,0,0,0,0,56,47,54,0,0,0,0,0,77,106,108,101,97,103,117,101,66,97,116,49,0,0,0,0,73,109,112,101,114,102,101,99,116,32,83,111,117,110,100,0,66,108,111,99,107,32,40,71,97,109,101,32,67,111,114,112,111,114,97,116,105,111,110,32,98,111,111,116,108,101,103,44,32,115,101,116,32,49,41,0,0,0,0,0,0,0,0,0,83,111,110,105,99,32,116,104,101,32,72,101,100,103,101,104,111,103,32,50,32,40,87,111,114,108,100,44,32,82,101,118,46,32,83,67,48,50,41,0,0,0,0,0,0,0,0,0,116,101,116,114,105,115,0,0,70,114,101,101,122,101,32,73,109,97,103,101,0,0,0,0,67,111,110,116,105,110,101,110,116,97,108,32,67,105,114,99,117,115,32,40,85,83,32,115,101,116,32,50,41,0,0,0,109,100,95,115,111,110,105,99,50,99,0,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,39,32,45,32,67,104,97,109,112,105,111,110,32,69,100,105,116,105,111,110,32,40,65,99,99,101,108,101,114,97,116,111,114,33,32,98,111,111,116,108,101,103,32,115,101,116,32,50,44,32,57,50,48,51,49,48,32,65,99,99,101,108,101,114,97,116,111,114,33,41,0,0,0,0,0,0,0,0,0,107,111,118,115,103,113,121,122,98,0,0,0,0,0,0,0,76,111,100,101,32,82,117,110,110,101,114,32,45,32,76,111,115,116,32,76,97,98,121,114,105,110,116,104,0,0,0,0,84,104,101,32,75,105,110,103,32,111,102,32,70,105,103,104,116,101,114,115,32,49,48,116,104,32,65,110,110,105,118,101,114,115,97,114,121,32,50,48,48,53,32,85,110,105,113,117,101,32,40,98,111,111,116,108,101,103,41,0,0,0,0,0,83,111,110,105,99,32,116,104,101,32,72,101,100,103,101,104,111,103,32,50,32,40,87,111,114,108,100,44,32,82,101,118,46,32,48,49,97,41,0,0,109,100,95,97,108,101,120,107,105,100,100,106,0,0,0,0,66,97,110,112,114,101,115,116,111,32,47,32,68,121,110,97,109,105,99,32,80,108,46,32,84,111,101,105,32,65,110,105,109,97,116,105,111,110,0,0,80,49,32,66,117,116,116,111,110,32,89,0,0,0,0,0,116,111,117,116,114,117,110,51,0,0,0,0,0,0,0,0,109,100,95,115,111,110,105,99,50,98,0,0,0,0,0,0,112,97,99,108,97,110,100,0,115,116,101,112,0,0,0,0,184,48,0,0,231,48,0,0,184,48,0,0,231,48,0,0,110,48,0,0,32,0,0,0,71,89,0,0,153,89,0,0,106,48,0,0,146,81,0,0,122,150,0,0,0,0,0,0,74,0,0,0,111,0,0,0,74,0,0,0,111,0,0,0,39,0,0,0,115,0,0,0,32,0,0,0,86,0,0,0,101,0,0,0,110,0,0,0,116,0,0,0,117,0,0,0,114,0,0,0,101,0,0,0,32,0,0,0,40,0,0,0,85,0,0,0,83,0,0,0,65,0,0,0,32,0,0,0,57,0,0,0,57,0,0,0,48,0,0,0,49,0,0,0,50,0,0,0,56,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,98,111,111,116,108,101,103,32,40,68,97,116,115,117,41,0,84,101,99,104,110,111,115,32,43,32,67,97,108,105,102,111,114,110,105,97,32,68,114,101,97,109,115,0,0,0,0,0,104,97,110,103,111,110,0,0,83,111,110,105,99,32,116,104,101,32,72,101,100,103,101,104,111,103,32,50,32,40,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,90,101,114,111,32,40,57,53,48,54,50,55,32,74,97,112,97,110,41,0,0,0,0,0,0,37,0,0,0,72,0,0,0,58,0,0,0,37,0,0,0,77,0,0,0,58,0,0,0,37,0,0,0,83,0,0,0,0,0,0,0,0,0,0,0,100,101,115,101,114,116,98,114,106,0,0,0,0,0,0,0,109,100,95,115,111,110,105,99,50,112,50,0,0,0,0,0,107,105,110,103,98,97,108,108,0,0,0,0,0,0,0,0,63,63,63,63,0,0,0,0,118,105,100,101,111,95,115,104,97,100,101,114,0,0,0,0,77,97,106,111,114,32,76,101,97,103,117,101,0,0,0,0,83,111,110,105,99,32,116,104,101,32,72,101,100,103,101,104,111,103,32,50,32,40,66,101,116,97,32,56,44,32,49,57,57,50,48,57,50,52,44,32,49,57,46,50,55,41,0,0,103,116,109,114,50,117,0,0,109,100,95,115,111,110,105,99,50,112,51,0,0,0,0,0,49,58,52,53,0,0,0,0,66,117,121,32,73,110,0,0,83,111,110,105,99,32,116,104,101,32,72,101,100,103,101,104,111,103,32,50,32,40,66,101,116,97,32,55,44,32,49,57,57,50,48,57,50,52,44,32,48,57,46,50,54,41,0,0,50,67,95,49,67,0,0,0,110,67,121,99,108,101,115,68,111,110,101,91,49,93,0,0,72,97,114,100,32,50,0,0,66,108,111,99,107,103,97,108,68,105,97,108,49,0,0,0,109,100,95,115,111,110,105,99,50,112,52,0,0,0,0,0,77,106,108,101,97,103,117,101,84,114,97,99,107,50,89,0,83,97,109,109,121,32,85,83,65,32,67,111,114,112,111,114,97,116,105,111,110,0,0,0,83,111,110,105,99,32,116,104,101,32,72,101,100,103,101,104,111,103,32,50,32,40,66,101,116,97,32,54,44,32,49,57,57,50,48,57,50,50,44,32,49,57,46,52,50,41,0,0,77,111,100,101,32,49,0,0,83,117,112,101,114,32,45,32,80,114,111,0,0,0,0,0,109,100,95,115,111,110,105,99,50,112,53,0,0,0,0,0,50,49,32,80,111,105,110,116,115,32,97,110,100,32,49,32,65,100,118,46,0,0,0,0,66,117,121,32,73,110,32,80,114,105,99,101,0,0,0,0,115,102,50,97,99,99,97,0,75,0,0,0,110,0,0,0,105,0,0,0,103,0,0,0,104,0,0,0,116,0,0,0,115,0,0,0,32,0,0,0,111,0,0,0,102,0,0,0,32,0,0,0,86,0,0,0,97,0,0,0,108,0,0,0,111,0,0,0,117,0,0,0,114,0,0,0,58,0,0,0,32,0,0,0,83,0,0,0,97,0,0,0,110,0,0,0,71,0,0,0,117,0,0,0,111,0,0,0,32,0,0,0,81,0,0,0,117,0,0,0,110,0,0,0,89,0,0,0,105,0,0,0,110,0,0,0,103,0,0,0,90,0,0,0,104,0,0,0,117,0,0,0,97,0,0,0,110,0,0,0,0,0,0,0,9,78,0,0,253,86,0,0,24,98,0,0,170,126,0,0,0,0,0,0,9,78,0,0,253,86,0,0,164,127,0,0,241,130,0,0,32,79,0,0,32,0,0,0,40,0,0,0,115,0,0,0,101,0,0,0,116,0,0,0,32,0,0,0,50,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,99,101,95,108,100,114,117,110,0,0,0,0,0,0,0,115,97,105,108,111,114,109,110,111,116,0,0,0,0,0,0,83,111,110,105,99,32,116,104,101,32,72,101,100,103,101,104,111,103,32,50,32,40,66,101,116,97,32,54,44,32,49,57,57,50,48,57,50,50,44,32,49,56,46,52,55,41,0,0,112,114,111,116,101,99,116,105,111,110,95,114,101,97,100,95,112,111,105,110,116,101,114,0,65,108,101,120,32,75,105,100,100,32,105,110,32,116,104,101,32,69,110,99,104,97,110,116,101,100,32,67,97,115,116,108,101,32,40,69,117,114,111,41,0,0,0,0,0,0,0,0,109,100,95,115,111,110,105,99,50,112,54,0,0,0,0,0,52,101,110,114,97,121,97,0,82,101,116,114,111,65,114,99,104,58,32,71,97,109,101,32,70,80,83,32,62,32,77,111,110,105,116,111,114,32,70,80,83,46,32,67,97,110,110,111,116,32,114,101,108,121,32,111,110,32,86,83,121,110,99,46,10,0,0,0,0,0,0,0,83,111,110,105,99,32,116,104,101,32,72,101,100,103,101,104,111,103,32,50,32,40,66,101,116,97,32,53,44,32,49,57,57,50,48,57,50,49,44,32,49,50,46,48,54,41,0,0,115,102,122,106,114,49,0,0,65,116,97,114,105,32,71,97,109,101,115,0,0,0,0,0,82,101,122,111,110,0,0,0,109,100,95,115,111,110,105,99,50,112,55,0,0,0,0,0,77,111,111,110,32,83,104,117,116,116,108,101,32,40,74,97,112,97,110,32,115,101,116,32,50,41,0,0,0,0,0,0,83,78,75,32,69,108,101,99,116,114,111,110,105,99,115,32,99,111,114,112,46,0,0,0,72,97,114,100,32,74,97,107,101,0,0,0,0,0,0,0,77,105,106,105,110,0,0,0,83,111,110,105,99,32,116,104,101,32,72,101,100,103,101,104,111,103,32,50,32,40,66,101,116,97,32,52,44,32,49,57,57,50,48,57,49,56,44,32,49,54,46,50,54,41,0,0,84,101,104,107,97,110,0,0,84,101,110,103,97,105,32,40,119,111,114,108,100,41,0,0,80,49,32,98,117,116,116,111,110,32,53,0,0,0,0,0,109,100,95,115,111,110,105,99,50,112,56,0,0,0,0,0,51,48,107,32,32,55,48,107,32,32,55,48,107,0,0,0,82,0,0,0,0,0,0,0,83,111,110,105,99,32,116,104,101,32,72,101,100,103,101,104,111,103,32,50,32,40,87,111,114,108,100,41,0,0,0,0,80,97,110,103,32,40,98,111,111,116,108,101,103,44,32,115,101,116,32,50,41,0,0,0,49,67,32,50,67,32,47,32,49,67,32,49,50,67,0,0,109,97,104,32,114,111,110,0,65,32,52,45,49,32,66,32,49,45,52,0,0,0,0,0,109,100,95,115,111,110,105,99,50,97,0,0,0,0,0,0,72,97,114,100,32,49,0,0,78,111,98,111,114,97,110,98,73,110,112,50,51,83,116,101,112,0,0,0,0,0,0,0,77,106,108,101,97,103,117,101,84,114,97,99,107,50,88,0,99,114,111,99,107,109,97,110,0,0,0,0,0,0,0,0,73,68,83,65,0,0,0,0,103,97,117,110,116,108,101,116,50,112,106,0,0,0,0,0,83,111,110,105,99,32,116,104,101,32,72,101,100,103,101,104,111,103,32,50,32,40,87,111,114,108,100,44,32,82,101,118,46,32,65,41,0,0,0,0,68,105,112,32,69,0,0,0,66,32,40,69,97,115,121,41,0,0,0,0,0,0,0,0,80,114,111,102,101,115,115,105,111,110,97,108,0,0,0,0,69,120,116,114,97,0,0,0,109,100,95,115,111,110,105,99,50,0,0,0,0,0,0,0,85,110,105,118,101,114,115,97,108,0,0,0,0,0,0,0,68,111,110,107,101,121,32,75,111,110,103,32,74,114,46,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,39,32,45,32,67,104,97,109,112,105,111,110,32,69,100,105,116,105,111,110,32,40,65,99,99,101,108,101,114,97,116,111,114,33,32,98,111,111,116,108,101,103,32,115,101,116,32,49,44,32,57,50,48,51,49,51,32,85,83,65,41,0,0,75,110,105,103,104,116,115,32,111,102,32,86,97,108,111,117,114,58,32,83,97,110,71,117,111,32,81,117,110,89,105,110,103,90,104,117,97,110,32,47,32,83,97,110,103,111,107,117,32,83,101,110,107,105,58,32,83,97,110,71,117,111,32,81,117,110,89,105,110,103,90,104,117,97,110,32,40,115,101,116,32,50,41,0,0,0,0,0,76,101,103,101,110,100,32,111,102,32,72,101,114,111,32,84,111,110,109,97,0,0,0,0,107,102,50,107,53,117,110,105,0,0,0,0,0,0,0,0,78,111,114,109,97,108,63,0,83,111,110,105,99,32,116,104,101,32,72,101,100,103,101,104,111,103,32,40,80,105,114,97,116,101,44,32,82,105,112,112,101,100,32,102,114,111,109,32,71,111,108,100,101,110,32,49,48,32,105,110,32,49,41,0,0,0,0,0,0,0,0,0,109,100,95,97,108,101,120,107,105,100,100,49,0,0,0,0,49,57,57,49,63,0,0,0,109,100,95,115,111,110,105,99,112,105,114,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,90,101,114,111,32,40,57,53,48,55,50,55,32,74,97,112,97,110,41,0,0,0,0,0,0,115,111,110,111,102,112,104,120,0,0,0,0,0,0,0,0,83,111,110,105,99,32,116,104,101,32,72,101,100,103,101,104,111,103,32,40,74,112,110,44,32,75,111,114,41,0,0,0,109,115,104,117,116,116,108,101,106,50,0,0,0,0,0,0,80,97,114,116,105,97,108,0,32,49,32,67,111,105,110,32,32,53,32,67,114,101,100,105,116,115,0,0,0,0,0,0,109,114,100,111,0,0,0,0,65,32,49,47,50,32,66,32,49,47,49,48,0,0,0,0,109,100,95,115,111,110,105,99,106,0,0,0,0,0,0,0,50,80,32,83,116,97,114,116,105,110,103,32,83,99,111,114,101,0,0,0,0,0,0,0,49,50,48,48,48,48,0,0,83,111,110,105,99,32,83,112,105,110,98,97,108,108,32,40,85,83,65,44,32,65,108,116,41,0,0,0,0,0,0,0,100,97,114,107,116,111,119,114,0,0,0,0,0,0,0,0,109,95,107,98,95,114,101,103,0,0,0,0,0,0,0,0,109,100,95,115,115,112,105,110,117,97,0,0,0,0,0,0,77,97,104,106,111,110,103,32,82,111,110,0,0,0,0,0,50,48,48,48,48,48,48,32,80,111,105,110,116,115,0,0,78,111,98,111,114,97,110,98,73,110,112,49,55,83,116,101,112,0,0,0,0,0,0,0,83,111,110,105,99,32,83,112,105,110,98,97,108,108,32,40,85,83,65,41,0,0,0,0,77,106,108,101,97,103,117,101,84,114,97,99,107,49,89,0,109,100,95,115,115,112,105,110,117,0,0,0,0,0,0,0,112,99,101,95,97,116,111,109,114,111,98,111,0,0,0,0,73,110,116,101,114,109,101,100,105,97,116,101,0,0,0,0,83,111,110,105,99,32,83,112,105,110,98,97,108,108,32,40,74,112,110,41,0,0,0,0,115,102,50,97,99,99,0,0,107,111,118,115,103,113,121,122,97,0,0,0,0,0,0,0,112,99,101,95,108,111,104,116,0,0,0,0,0,0,0,0,67,97,112,116,97,105,110,32,67,111,109,109,97,110,100,111,32,40,57,49,48,57,50,56,32,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,84,104,101,32,75,105,110,103,32,111,102,32,70,105,103,104,116,101,114,115,32,49,48,116,104,32,65,110,110,105,118,101,114,115,97,114,121,32,69,120,116,114,97,32,80,108,117,115,32,40,98,111,111,116,108,101,103,41,0,0,0,0,0,0,65,108,112,104,97,32,77,105,115,115,105,111,110,32,73,73,32,47,32,65,83,79,32,73,73,32,45,32,76,97,115,116,32,71,117,97,114,100,105,97,110,32,40,112,114,111,116,111,116,121,112,101,41,0,0,0,83,101,111,117,108,32,67,111,105,110,32,67,111,114,112,46,0,0,0,0,0,0,0,0,110,90,56,48,66,97,110,107,51,0,0,0,0,0,0,0,109,100,95,115,115,112,105,110,106,0,0,0,0,0,0,0,115,102,122,106,0,0,0,0,65,108,97,100,100,105,110,32,73,73,0,0,0,0,0,0,83,111,110,105,99,32,83,112,105,110,98,97,108,108,32,40,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,109,100,95,115,115,112,105,110,112,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,68,105,100,110,39,116,32,114,101,97,100,32,119,104,111,108,101,32,102,105,108,101,46,10,0,0,0,0,79,80,76,45,62,100,101,108,116,97,116,45,62,112,111,114,116,115,116,97,116,101,0,0,83,111,110,105,99,32,74,97,109,32,54,32,40,65,108,116,41,0,0,0,0,0,0,0,77,111,111,110,32,83,104,117,116,116,108,101,32,40,74,97,112,97,110,41,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,71,76,83,76,32,115,104,97,100,101,114,58,32,37,115,46,10,0,0,0,109,100,95,115,111,110,105,99,106,97,109,49,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,78,111,110,32,115,112,101,99,105,102,105,101,100,32,71,76,32,101,114,114,111,114,46,10,0,0,0,76,105,110,101,97,114,0,0,83,111,110,105,99,32,74,97,109,32,54,0,0,0,0,0,74,117,115,116,105,102,105,101,114,115,0,0,0,0,0,0,67,111,114,101,108,97,110,100,0,0,0,0,0,0,0,0,109,100,95,122,101,114,111,116,111,108,0,0,0,0,0,0,109,100,95,115,111,110,105,99,106,97,109,0,0,0,0,0,77,105,100,99,111,105,110,0,109,97,104,32,114,101,97,99,104,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,37,115,10,0,0,49,32,67,114,101,100,105,116,0,0,0,0,0,0,0,0,78,111,98,111,114,97,110,98,73,110,112,49,54,83,116,101,112,0,0,0,0,0,0,0,83,111,110,105,99,32,69,114,97,115,101,114,32,40,74,112,110,44,32,83,101,103,97,78,101,116,41,0,0,0,0,0,80,108,97,121,32,73,110,110,105,110,103,32,84,105,109,101,0,0,0,0,0,0,0,0,77,106,108,101,97,103,117,101,84,114,97,99,107,49,88,0,109,100,95,115,111,110,105,99,101,114,0,0,0,0,0,0,102,114,97,109,101,95,99,111,117,110,116,95,109,111,100,37,117,0,0,0,0,0,0,0,66,101,103,105,110,110,101,114,0,0,0,0,0,0,0,0,72,97,114,100,32,80,117,110,99,104,101,114,32,40,74,97,112,97,110,41,0,0,0,0,80,111,119,101,114,101,100,32,71,101,97,114,32,45,32,115,116,114,97,116,101,103,105,99,32,118,97,114,105,97,110,116,32,97,114,109,111,114,32,101,113,117,105,112,109,101,110,116,32,40,57,52,49,48,50,52,32,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,83,111,110,105,99,32,67,114,97,99,107,101,114,115,32,40,74,112,110,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,39,32,45,32,67,104,97,109,112,105,111,110,32,69,100,105,116,105,111,110,32,40,115,116,114,101,101,116,32,102,105,103,104,116,101,114,32,50,39,32,57,50,48,56,48,51,32,85,83,65,41,0,0,0,0,75,0,0,0,110,0,0,0,105,0,0,0,103,0,0,0,104,0,0,0,116,0,0,0,115,0,0,0,32,0,0,0,111,0,0,0,102,0,0,0,32,0,0,0,86,0,0,0,97,0,0,0,108,0,0,0,111,0,0,0,117,0,0,0,114,0,0,0,58,0,0,0,32,0,0,0,83,0,0,0,97,0,0,0,110,0,0,0,71,0,0,0,117,0,0,0,111,0,0,0,32,0,0,0,81,0,0,0,117,0,0,0,110,0,0,0,89,0,0,0,105,0,0,0,110,0,0,0,103,0,0,0,90,0,0,0,104,0,0,0,117,0,0,0,97,0,0,0,110,0,0,0,0,0,0,0,9,78,0,0,253,86,0,0,24,98,0,0,170,126,0,0,0,0,0,0,9,78,0,0,253,86,0,0,164,127,0,0,241,130,0,0,32,79,0,0,32,0,0,0,40,0,0,0,115,0,0,0,101,0,0,0,116,0,0,0,32,0,0,0,49,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,76,97,100,121,32,83,119,111,114,100,32,40,65,108,116,41,0,0,0,0,0,0,0,0,66,117,108,108,101,116,115,0,111,118,101,114,108,97,121,37,117,95,100,101,115,99,37,117,95,110,101,120,116,95,116,97,114,103,101,116,0,0,0,0,109,100,95,115,99,114,97,99,107,0,0,0,0,0,0,0,108,97,100,121,98,117,103,0,109,100,95,97,108,97,100,100,105,110,50,0,0,0,0,0,83,104,105,115,101,110,115,104,111,32,73,73,0,0,0,0,76,111,100,101,32,82,117,110,110,101,114,32,73,86,32,45,32,84,101,105,107,111,107,117,32,75,97,114,97,110,111,32,68,97,115,115,104,117,116,115,117,0,0,0,0,0,0,0,83,111,110,105,99,32,67,111,109,112,105,108,97,116,105,111,110,32,40,69,117,114,111,41,32,126,32,83,111,110,105,99,32,67,108,97,115,115,105,99,115,32,40,85,83,65,44,32,75,111,114,41,0,0,0,0,77,121,115,116,105,99,32,82,105,100,101,114,115,32,40,87,111,114,108,100,41,0,0,0,83,97,105,103,111,32,110,111,32,78,105,110,100,111,117,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,83,111,110,105,99,32,51,68,32,66,108,97,115,116,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,90,101,114,111,32,40,57,53,48,54,50,55,32,72,105,115,112,97,110,105,99,41,0,0,0,109,100,95,115,111,110,105,99,51,100,112,49,0,0,0,0,109,115,104,117,116,116,108,101,106,0,0,0,0,0,0,0,83,111,110,105,99,32,51,68,32,66,108,97,115,116,32,40,80,114,111,116,111,116,121,112,101,32,57,52,44,32,49,57,57,54,48,57,48,52,44,32,49,50,46,48,49,41,0,0,67,105,110,101,109,97,116,114,111,110,105,99,115,0,0,0,109,100,95,115,111,110,105,99,51,100,112,50,0,0,0,0,69,112,111,115,32,67,111,114,112,111,114,97,116,105,111,110,32,40,80,104,111,116,97,114,32,73,110,100,117,115,116,114,105,101,115,32,76,105,99,101,110,115,101,41,0,0,0,0,83,111,110,105,99,32,51,68,32,66,108,97,115,116,32,40,80,114,111,116,111,116,121,112,101,32,56,51,49,44,32,49,57,57,54,48,57,48,51,44,32,49,48,46,48,55,41,0,0,0,0,0,0,0,0,0,77,97,104,106,111,110,103,32,82,101,97,99,104,0,0,0,51,32,67,114,101,100,105,116,115,0,0,0,0,0,0,0,83,121,115,116,101,109,49,82,111,109,66,97,110,107,0,0,109,100,95,115,111,110,105,99,51,100,112,51,0,0,0,0,83,111,110,105,99,32,51,68,32,66,108,97,115,116,32,40,80,114,111,116,111,116,121,112,101,32,56,51,48,44,32,49,57,57,54,48,56,51,49,44,32,48,56,46,49,57,41,0,0,0,0,0,0,0,0,0,86,101,99,116,111,114,32,103,114,97,112,104,105,99,115,0,67,108,111,99,107,32,83,112,101,101,100,0,0,0,0,0,109,100,95,115,111,110,105,99,51,100,112,52,0,0,0,0,115,102,50,99,101,117,99,0,75,110,105,103,104,116,115,32,111,102,32,86,97,108,111,117,114,58,32,83,97,110,71,117,111,32,81,117,110,89,105,110,103,90,104,117,97,110,32,47,32,83,97,110,103,111,107,117,32,83,101,110,107,105,58,32,83,97,110,71,117,111,32,81,117,110,89,105,110,103,90,104,117,97,110,32,40,115,101,116,32,49,41,0,0,0,0,0,112,99,101,95,108,97,100,121,115,119,114,100,49,0,0,0,107,102,49,48,116,104,101,112,0,0,0,0,0,0,0,0,83,111,110,105,99,32,51,68,32,66,108,97,115,116,32,40,80,114,111,116,111,116,121,112,101,32,56,50,53,44,32,49,57,57,54,48,56,50,54,44,32,49,53,46,52,54,41,0,0,0,0,0,0,0,0,0,115,111,108,111,109,111,110,0,68,105,115,110,101,121,39,115,32,65,108,97,100,100,105,110,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,0,109,100,95,115,111,110,105,99,51,100,112,53,0,0,0,0,83,111,110,105,99,32,51,68,32,66,108,97,115,116,32,40,80,114,111,116,111,116,121,112,101,32,56,49,57,44,32,49,57,57,54,48,56,49,57,44,32,49,57,46,52,57,41,0,0,0,0,0,0,0,0,0,115,102,122,104,114,49,0,0,82,101,109,111,118,101,100,32,100,105,115,107,32,102,114,111,109,32,116,114,97,121,46,0,109,100,95,115,111,110,105,99,51,100,112,54,0,0,0,0,77,111,111,110,32,83,104,117,116,116,108,101,32,40,85,83,63,32,115,101,116,32,50,41,0,0,0,0,0,0,0,0,82,111,99,107,99,108,105,109,83,99,114,111,108,108,88,0,83,111,110,105,99,32,51,68,32,66,108,97,115,116,32,40,80,114,111,116,111,116,121,112,101,32,56,49,52,44,32,49,57,57,54,48,56,49,53,44,32,48,55,46,53,53,41,0,0,0,0,0,0,0,0,0,115,108,45,62,101,103,95,116,121,112,101,0,0,0,0,0,84,101,99,104,110,111,115,32,40,84,97,105,116,111,32,65,109,101,114,105,99,97,32,108,105,99,101,110,115,101,41,0,109,100,95,115,111,110,105,99,51,100,112,55,0,0,0,0,83,111,110,105,99,32,51,68,32,66,108,97,115,116,32,40,80,114,111,116,111,116,121,112,101,32,55,51,44,32,49,57,57,54,48,55,48,51,44,32,49,51,46,53,56,41,0,0,91,90,105,108,101,99,32,69,108,101,99,116,114,111,110,105,99,115,93,32,66,97,108,108,121,32,77,105,100,119,97,121,0,0,0,0,0,0,0,0,109,97,104,32,99,104,105,0,55,32,67,114,101,100,105,116,115,0,0,0,0,0,0,0,83,121,115,116,101,109,49,83,111,117,110,100,76,97,116,99,104,0,0,0,0,0,0,0,109,100,95,115,111,110,105,99,51,100,112,56,0,0,0,0,83,111,110,105,99,32,51,68,32,45,32,70,108,105,99,107,105,101,115,39,32,73,115,108,97,110,100,32,40,69,117,114,111,41,32,126,32,83,111,110,105,99,32,51,68,32,66,108,97,115,116,32,40,85,83,65,44,32,75,111,114,41,0,0,75,121,117,103,111,0,0,0,109,100,95,115,111,110,105,99,51,100,0,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,39,32,45,32,67,104,97,109,112,105,111,110,32,69,100,105,116,105,111,110,32,40,115,116,114,101,101,116,32,102,105,103,104,116,101,114,32,50,39,32,57,50,48,53,49,51,32,85,83,65,41,0,0,0,0,107,111,118,115,103,113,121,122,0,0,0,0,0,0,0,0,76,97,100,121,32,83,119,111,114,100,0,0,0,0,0,0,84,104,101,32,75,105,110,103,32,111,102,32,70,105,103,104,116,101,114,115,32,49,48,116,104,32,65,110,110,105,118,101,114,115,97,114,121,32,40,98,111,111,116,108,101,103,41,0,0,0,0,0,0,0,0,0,83,111,110,105,99,32,51,67,32,40,80,114,111,116,111,116,121,112,101,32,48,53,49,55,44,32,49,57,57,52,48,53,49,55,44,32,49,55,46,48,56,41,0,0,0,0,0,0,109,100,95,97,108,97,100,100,105,110,117,112,0,0,0,0,76,51,32,98,117,116,116,111,110,32,40,116,104,117,109,98,41,0,0,0,0,0,0,0,109,100,95,115,111,110,105,99,51,99,97,0,0,0,0,0,83,111,110,105,99,32,51,67,32,40,80,114,111,116,111,116,121,112,101,32,48,52,48,56,44,32,49,57,57,52,48,52,48,56,44,32,49,55,46,50,57,41,0,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,90,101,114,111,32,40,57,53,48,55,49,56,32,72,105,115,112,97,110,105,99,41,0,0,0,109,100,95,115,111,110,105,99,51,99,0,0,0,0,0,0,109,115,104,117,116,116,108,101,50,0,0,0,0,0,0,0,83,111,110,105,99,32,38,32,75,110,117,99,107,108,101,115,32,40,80,114,111,116,111,116,121,112,101,32,48,53,50,53,44,32,49,57,57,52,48,53,50,53,44,32,49,53,46,50,56,41,0,0,0,0,0,0,109,100,95,115,107,112,49,50,0,0,0,0,0,0,0,0,75,110,117,99,107,108,101,115,32,105,110,32,83,111,110,105,99,32,50,32,40,80,114,111,116,111,116,121,112,101,32,48,53,50,52,44,32,49,57,57,52,48,53,50,55,44,32,49,48,46,52,54,41,0,0,0,77,97,104,106,111,110,103,32,67,104,105,0,0,0,0,0,69,117,114,111,32,76,101,97,103,117,101,32,40,73,116,97,108,105,97,110,32,104,97,99,107,32,111,102,32,84,101,99,109,111,32,87,111,114,108,100,32,67,117,112,32,39,57,48,41,0,0,0,0,0,0,0,83,121,115,116,101,109,49,70,108,105,112,83,99,114,101,101,110,0,0,0,0,0,0,0,109,100,95,107,110,117,99,107,108,112,0,0,0,0,0,0,83,111,110,105,99,32,38,32,75,110,117,99,107,108,101,115,32,40,80,114,111,116,111,116,121,112,101,32,48,54,49,56,44,32,49,57,57,52,48,54,49,56,44,32,57,46,48,55,44,32,83,50,75,32,99,104,105,112,41,0,0,0,0,0,83,101,98,101,108,101,99,116,114,111,0,0,0,0,0,0,109,100,95,115,107,112,48,51,0,0,0,0,0,0,0,0,115,102,50,99,101,117,98,0,75,0,0,0,110,0,0,0,105,0,0,0,103,0,0,0,104,0,0,0,116,0,0,0,115,0,0,0,32,0,0,0,111,0,0,0,102,0,0,0,32,0,0,0,86,0,0,0,97,0,0,0,108,0,0,0,111,0,0,0,117,0,0,0,114,0,0,0,58,0,0,0,32,0,0,0,65,0,0,0,111,0,0,0,32,0,0,0,83,0,0,0,104,0,0,0,105,0,0,0,32,0,0,0,83,0,0,0,97,0,0,0,110,0,0,0,32,0,0,0,71,0,0,0,117,0,0,0,111,0,0,0,0,0,0,0,9,78,0,0,253,86,0,0])
.concat([24,98,0,0,170,126,0,0,0,0,0,0,178,80,0,0,198,137,0,0,9,78,0,0,253,86,0,0,32,0,0,0,40,0,0,0,118,0,0,0,101,0,0,0,114,0,0,0,46,0,0,0,32,0,0,0,50,0,0,0,48,0,0,0,50,0,0,0,67,0,0,0,78,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,112,99,101,95,108,97,100,121,115,119,114,100,0,0,0,0,107,111,102,49,48,116,104,0,80,97,99,105,102,105,99,32,78,111,118,101,108,116,121,0,83,111,110,105,99,32,38,32,75,110,117,99,107,108,101,115,32,40,80,114,111,116,111,116,121,112,101,32,48,54,49,50,44,32,49,57,57,52,48,54,49,50,44,32,49,56,46,49,56,44,32,83,50,75,32,99,104,105,112,41,0,0,0,0,115,102,122,104,0,0,0,0,68,105,115,110,101,121,39,115,32,65,108,97,100,100,105,110,32,40,85,83,65,41,0,0,101,100,114,97,110,100,121,106,0,0,0,0,0,0,0,0,109,100,95,115,107,112,48,53,0,0,0,0,0,0,0,0,83,111,110,105,99,32,38,32,75,110,117,99,107,108,101,115,32,40,80,114,111,116,111,116,121,112,101,32,48,54,49,48,44,32,49,57,57,52,48,54,49,48,44,32,48,51,46,49,49,44,32,83,50,75,32,99,104,105,112,41,0,0,0,0,109,100,95,115,107,112,48,55,0,0,0,0,0,0,0,0,73,110,99,111,109,112,108,101,116,101,32,83,111,117,110,100,0,0,0,0,0,0,0,0,66,111,110,117,115,32,76,105,118,101,115,0,0,0,0,0,83,111,110,105,99,32,38,32,75,110,117,99,107,108,101,115,32,40,80,114,111,116,111,116,121,112,101,32,48,54,48,56,44,32,49,57,57,52,48,54,48,56,44,32,48,51,46,51,53,44,32,83,50,75,32,99,104,105,112,41,0,0,0,0,109,100,95,115,107,112,48,57,0,0,0,0,0,0,0,0,114,97,100,97,114,115,99,112,0,0,0,0,0,0,0,0,83,111,110,105,99,32,38,32,75,110,117,99,107,108,101,115,32,40,80,114,111,116,111,116,121,112,101,32,48,54,48,54,44,32,49,57,57,52,48,54,48,53,44,32,50,50,46,50,53,44,32,83,50,75,32,99,104,105,112,41,0,0,0,0,109,97,104,32,112,111,110,0,70,97,114,0,0,0,0,0,83,121,115,116,101,109,49,86,105,100,101,111,77,111,100,101,0,0,0,0,0,0,0,0,109,100,95,115,107,112,49,49,0,0,0,0,0,0,0,0,83,111,110,105,99,32,38,32,75,110,117,99,107,108,101,115,32,40,80,114,111,116,111,116,121,112,101,32,48,54,49,57,44,32,49,57,57,52,48,54,49,57,44,32,48,56,46,49,56,41,0,0,0,0,0,0,109,100,95,115,107,112,48,49,0,0,0,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,39,32,45,32,67,104,97,109,112,105,111,110,32,69,100,105,116,105,111,110,32,40,115,116,114,101,101,116,32,102,105,103,104,116,101,114,32,50,39,32,57,50,48,51,49,51,32,85,83,65,41,0,0,0,0,75,110,105,103,104,116,115,32,111,102,32,86,97,108,111,117,114,58,32,65,111,32,83,104,105,32,83,97,110,32,71,117,111,32,47,32,83,97,110,103,111,107,117,32,83,101,110,107,105,58,32,65,111,32,115,104,105,32,83,97,110,32,71,117,111,32,40,118,101,114,46,32,50,48,50,67,78,41,0,0,75,121,117,117,107,121,111,107,117,32,84,105,103,101,114,0,0,0,0,0,0,0,0,0,84,104,101,32,75,105,110,103,32,111,102,32,70,105,103,104,116,101,114,115,32,50,48,48,50,32,77,97,103,105,99,32,80,108,117,115,32,73,73,32,40,98,111,111,116,108,101,103,41,0,0,0,0,0,0,0,83,111,110,105,99,32,38,32,75,110,117,99,107,108,101,115,32,40,80,114,111,116,111,116,121,112,101,32,48,54,49,56,44,32,49,57,57,52,48,54,49,56,44,32,48,57,46,49,53,41,0,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,90,101,114,111,32,40,57,53,48,55,50,55,32,66,114,97,122,105,108,41,0,0,0,0,0,84,101,99,102,114,105,0,0,109,100,95,97,108,97,100,100,105,110,117,0,0,0,0,0,109,100,95,115,107,112,48,50,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,73,78,80,85,84,95,68,69,83,67,82,73,80,84,79,82,83,58,10,0,0,0,0,0,0,83,111,110,105,99,32,38,32,75,110,117,99,107,108,101,115,32,40,80,114,111,116,111,116,121,112,101,32,48,54,49,50,44,32,49,57,57,52,48,54,49,50,44,32,49,56,46,50,55,41,0,0,0,0,0,0,37,115,46,122,105,112,0,0,109,100,95,115,107,112,48,52,0,0,0,0,0,0,0,0,77,111,111,110,32,83,104,117,116,116,108,101,32,40,85,83,63,41,0,0,0,0,0,0,83,111,110,105,99,32,38,32,75,110,117,99,107,108,101,115,32,40,80,114,111,116,111,116,121,112,101,32,48,54,49,48,44,32,49,57,57,52,48,54,49,48,44,32,48,55,46,52,57,41,0,0,0,0,0,0,109,100,95,115,107,112,48,54,0,0,0,0,0,0,0,0,71,97,114,121,111,32,82,101,116,115,117,100,101,110,32,40,74,97,112,97,110,41,0,0,83,111,110,105,99,32,38,32,75,110,117,99,107,108,101,115,32,40,80,114,111,116,111,116,121,112,101,32,48,54,48,56,44,32,49,57,57,52,48,54,48,56,44,32,48,53,46,48,51,41,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,115,97,118,101,32,115,116,97,116,101,32,116,111,32,34,37,115,34,46,10,0,0,0,0,0,77,97,104,106,111,110,103,32,80,111,110,0,0,0,0,0,78,101,97,114,0,0,0,0,66,103,32,82,65,77,0,0,83,121,115,116,101,109,49,66,103,83,99,114,111,108,108,89,0,0,0,0,0,0,0,0,109,100,95,115,107,112,48,56,0,0,0,0,0,0,0,0,83,111,110,105,99,32,38,32,75,110,117,99,107,108,101,115,32,40,80,114,111,116,111,116,121,112,101,32,48,54,48,54,44,32,49,57,57,52,48,54,48,54,44,32,49,48,46,48,50,41,0,0,0,0,0,0,100,114,103,119,50,99,0,0,109,100,95,115,107,112,49,48,0,0,0,0,0,0,0,0,115,102,50,99,101,117,97,0,107,111,118,115,104,120,97,115,0,0,0,0,0,0,0,0,112,99,101,95,107,116,105,103,101,114,0,0,0,0,0,0,107,102,50,107,50,109,112,50,0,0,0,0,0,0,0,0,83,111,110,105,99,32,38,32,75,110,117,99,107,108,101,115,32,40,87,111,114,108,100,41,0,0,0,0,0,0,0,0,103,117,110,115,109,111,107,101,0,0,0,0,0,0,0,0,115,102,122,98,114,49,0,0,68,105,115,110,101,121,39,115,32,65,108,97,100,100,105,110,32,40,74,112,110,41,0,0,80,49,32,85,115,101,0,0,109,100,95,115,107,0,0,0,82,97,103,110,97,99,101,110,116,121,32,40,75,111,114,41,0,0,0,0,0,0,0,0,110,77,54,56,48,48,67,121,99,108,101,115,84,111,116,97,108,0,0,0,0,0,0,0,77,97,114,105,111,32,66,114,111,115,46,32,40,85,83,44,32,82,101,118,105,115,105,111,110,32,70,41,0,0,0,0,69,120,116,101,110,100,32,98,111,110,117,115,0,0,0,0,52,32,99,111,105,110,115,32,49,32,99,114,101,100,105,116,0,0,0,0,0,0,0,0,42,49,48,49,0,0,0,0,67,32,40,104,97,114,100,41,0,0,0,0,0,0,0,0,109,100,95,114,97,103,110,97,99,101,110,107,0,0,0,0,83,108,97,112,32,70,105,103,104,116,32,40,98,111,111,116,108,101,103,32,115,101,116,32,50,41,0,0,0,0,0,0,109,115,104,117,116,116,108,101,0,0,0,0,0,0,0,0,78,111,110,101,0,0,0,0,55,48,48,48,48,44,32,50,48,48,48,48,48,0,0,0,83,104,105,110,32,83,111,117,115,101,105,107,105,32,82,97,103,110,97,99,101,110,116,121,32,40,74,112,110,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,0,55,48,75,44,32,101,118,101,114,121,32,50,48,48,75,0,109,100,95,114,97,103,110,97,99,101,110,112,0,0,0,0,51,48,75,44,32,101,118,101,114,121,32,49,48,48,75,0,83,104,105,110,32,83,111,117,115,101,105,107,105,32,82,97,103,110,97,99,101,110,116,121,32,40,74,112,110,41,0,0,109,105,100,114,101,115,0,0,109,97,104,32,107,97,110,0,68,114,105,102,116,32,79,117,116,32,40,69,117,114,111,112,101,41,0,0,0,0,0,0,79,117,116,32,76,97,110,101,32,80,105,110,0,0,0,0,83,121,115,116,101,109,49,66,103,83,99,114,111,108,108,88,0,0,0,0,0,0,0,0,109,100,95,114,97,103,110,97,99,101,110,0,0,0,0,0,55,47,53,0,0,0,0,0,75,97,103,101,107,105,32,40,85,83,41,0,0,0,0,0,97,114,107,98,108,111,99,107,0,0,0,0,0,0,0,0,67,114,117,115,97,100,101,114,32,111,102,32,67,101,110,116,121,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,116,101,116,114,105,115,116,0,81,117,101,115,116,105,111,110,115,32,80,101,114,32,71,97,109,101,0,0,0,0,0,0,99,111,110,116,99,105,114,99,117,97,0,0,0,0,0,0,109,100,95,99,114,117,115,97,100,101,114,0,0,0,0,0,106,117,109,112,105,110,103,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,39,32,45,32,67,104,97,109,112,105,111,110,32,69,100,105,116,105,111,110,32,40,115,116,114,101,101,116,32,102,105,103,104,116,101,114,32,50,39,32,57,50,48,56,48,51,32,74,97,112,97,110,41,0,0,101,97,114,116,104,106,107,114,0,0,0,0,0,0,0,0,75,121,117,117,107,121,111,107,117,32,77,97,104,106,111,110,103,32,73,73,0,0,0,0,84,104,101,32,75,105,110,103,32,111,102,32,70,105,103,104,116,101,114,115,32,50,48,48,50,32,77,97,103,105,99,32,80,108,117,115,32,40,98,111,111,116,108,101,103,41,0,0,84,111,107,105,111,32,47,32,83,99,114,97,109,98,108,101,32,70,111,114,109,97,116,105,111,110,32,40,110,101,119,101,114,41,0,0,0,0,0,0,83,111,108,101,105,108,32,40,69,117,114,111,41,0,0,0,109,100,95,97,108,97,100,100,105,110,106,0,0,0,0,0,83,111,108,45,68,101,97,99,101,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,74,111,74,111,39,115,32,86,101,110,116,117,114,101,32,47,32,74,111,74,111,32,110,111,32,75,105,109,121,111,117,32,110,97,32,66,111,117,107,101,110,32,40,85,83,65,32,57,57,48,49,50,56,41,0,0,110,111,32,83,111,117,110,100,0,0,0,0,0,0,0,0,83,121,115,116,101,109,49,54,90,56,48,69,110,97,98,108,101,0,0,0,0,0,0,0,109,100,95,115,111,108,100,101,97,99,101,0,0,0,0,0,97,100,100,114,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,90,101,114,111,32,40,57,53,49,49,48,57,32,66,114,97,122,105,108,41,0,0,0,0,0,68,101,115,101,114,116,32,66,114,101,97,107,101,114,32,40,87,111,114,108,100,44,32,70,68,49,48,57,52,32,51,49,55,45,48,49,57,54,41,0,0,0,0,0,0,0,0,0,84,105,109,101,32,68,111,109,105,110,97,116,111,114,32,49,115,116,32,40,74,112,110,44,32,75,111,114,41,0,0,0,118,105,100,101,111,95,114,101,102,114,101,115,104,95,114,97,116,101,0,0,0,0,0,0,109,100,95,116,105,109,101,100,111,109,0,0,0,0,0,0,77,105,108,108,101,32,77,105,103,108,105,97,32,50,58,32,71,114,101,97,116,32,49,48,48,48,32,77,105,108,101,115,32,82,97,108,108,121,32,40,57,53,47,48,52,47,48,52,41,0,0,0,0,0,0,0,80,105,99,116,117,114,101,32,86,105,101,119,0,0,0,0,83,111,99,107,101,116,32,40,85,83,65,41,0,0,0,0,74,111,105,110,32,73,110,32,40,49,32,67,114,101,100,105,116,41,0,0,0,0,0,0,109,100,95,115,111,99,107,101,116,0,0,0,0,0,0,0,49,67,95,50,67,0,0,0,77,97,104,106,111,110,103,32,75,97,110,0,0,0,0,0,110,67,121,99,108,101,115,68,111,110,101,91,48,93,0,0,83,121,115,116,101,109,49,83,99,114,111,108,108,89,0,0,83,110,111,119,32,66,114,111,115,46,32,45,32,78,105,99,107,32,38,32,84,111,109,32,40,74,112,110,41,0,0,0,115,116,97,103,103,101,114,49,0,0,0,0,0,0,0,0,77,101,100,105,117,109,32,104,97,114,100,0,0,0,0,0,68,101,101,114,32,72,117,110,116,105,110,103,32,85,83,65,32,86,52,46,51,0,0,0,109,100,95,115,110,111,119,98,114,111,115,0,0,0,0,0,66,111,110,117,115,32,72,101,108,112,0,0,0,0,0,0,83,112,101,99,105,97,108,32,80,111,119,101,114,115,0,0,68,105,112,32,83,119,105,116,99,104,101,115,32,52,0,0,83,110,97,107,101,32,82,97,116,116,108,101,32,110,39,32,82,111,108,108,32,40,69,117,114,111,41,0,0,0,0,0,49,49,32,80,111,105,110,116,115,32,97,110,100,32,50,32,65,100,118,46,0,0,0,0,116,101,114,114,97,99,114,101,0,0,0,0,0,0,0,0,115,102,50,99,101,106,99,0,119,111,119,110,102,97,110,116,0,0,0,0,0,0,0,0,112,99,101,95,107,121,117,107,121,111,109,50,0,0,0,0,107,102,50,107,50,109,112,0,80,0,0,0,114,0,0,0,101,0,0,0,116,0,0,0,116,0,0,0,121,0,0,0,32,0,0,0,83,0,0,0,111,0,0,0,108,0,0,0,100,0,0,0,105,0,0,0,101,0,0,0,114,0,0,0,32,0,0,0,83,0,0,0,97,0,0,0,105,0,0,0,108,0,0,0,111,0,0,0,114,0,0,0,32,0,0,0,77,0,0,0,111,0,0,0,111,0,0,0,110,0,0,0,0,0,0,0,142,127,0,0,17,92,0,0,115,89,0,0,38,98,0,0,235,88,0,0,32,0,0,0,187,48,0,0,252,48,0,0,233,48,0,0,252,48,0,0,224,48,0,0,252,48,0,0,243,48,0,0,32,0,0,0,40,0,0,0,118,0,0,0,101,0,0,0,114,0,0,0,46,0,0,0,32,0,0,0,57,0,0,0,53,0,0,0,47,0,0,0,48,0,0,0,51,0,0,0,47,0,0,0,50,0,0,0,50,0,0,0,44,0,0,0,32,0,0,0,75,0,0,0,111,0,0,0,114,0,0,0,101,0,0,0,97,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,109,100,95,115,110,97,107,101,114,110,114,0,0,0,0,0,49,32,67,111,105,110,47,49,32,67,114,101,100,105,116,32,53,47,54,0,0,0,0,0,67,56,48,48,48,48,32,82,101,103,105,115,116,101,114,115,0,0,0,0,0,0,0,0,68,105,115,110,101,121,39,115,32,65,108,97,100,100,105,110,32,40,69,117,114,111,41,0,0,0,0,0,0,0,0,0,49,48,48,48,107,32,50,48,48,48,107,0,0,0,0,0,71,97,109,101,32,116,105,109,101,0,0,0,0,0,0,0,84,104,101,32,83,109,117,114,102,115,32,84,114,97,118,101,108,32,116,104,101,32,87,111,114,108,100,32,40,69,117,114,111,41,0,0,0,0,0,0,83,111,110,105,99,32,87,105,110,103,115,32,40,74,97,112,97,110,41,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,84,105,109,105,110,103,115,32,100,101,118,105,97,116,101,32,116,111,111,32,109,117,99,104,46,32,87,105,108,108,32,110,111,116,32,97,100,106,117,115,116,46,32,40,68,105,115,112,108,97,121,32,61,32,37,46,50,102,32,72,122,44,32,71,97,109,101,32,61,32,37,46,50,102,32,72,122,41,10,0,0,0,0,0,0,109,100,95,115,109,117,114,102,115,116,119,0,0,0,0,0,115,102,122,98,0,0,0,0,114,101,122,111,110,0,0,0,83,97,110,114,105,116,115,117,32,68,101,110,107,105,0,0,78,111,114,109,97,108,32,74,97,107,101,0,0,0,0,0,102,105,110,97,108,116,116,114,0,0,0,0,0,0,0,0,87,111,110,100,101,114,32,76,101,97,103,117,101,32,83,116,97,114,32,45,32,83,111,107,45,77,97,103,105,99,98,97,108,108,32,70,105,103,104,116,105,110,103,32,40,75,111,114,101,97,41,0,0,0,0,0,70,97,116,109,97,110,32,40,74,112,110,41,0,0,0,0,78,97,120,97,116,0,0,0,106,111,121,115,116,105,99,107,95,54,98,95,115,101,108,101,99,116,91,48,93,0,0,0,65,114,105,107,97,0,0,0,52,48,48,48,48,32,55,48,48,48,48,0,0,0,0,0,109,100,95,102,97,116,109,97,110,0,0,0,0,0,0,0,50,48,107,32,32,55,48,107,32,32,55,48,107,0,0,0,83,108,97,117,103,104,116,101,114,32,83,112,111,114,116,32,40,85,83,65,41,0,0,0,112,97,110,103,98,111,108,100,0,0,0,0,0,0,0,0,49,67,32,50,67,32,47,32,49,67,32,49,49,67,0,0,109,97,104,32,110,0,0,0,65,32,51,45,49,32,66,32,49,45,51,0,0,0,0,0,65,32,76,105,116,116,108,101,0,0,0,0,0,0,0,0,83,121,115,116,101,109,49,73,110,112,117,116,0,0,0,0,109,100,95,115,108,97,117,103,104,116,114,0,0,0,0,0,98,111,111,116,108,101,103,32,40,82,101,99,114,101,97,116,105,118,111,115,32,70,114,97,110,99,111,32,83,46,65,46,41,0,0,0,0,0,0,0,71,97,117,110,116,108,101,116,32,40,50,32,80,108,97,121,101,114,115,44,32,114,101,118,32,54,41,0,0,0,0,0,83,108,97,112,32,70,105,103,104,116,32,77,68,32,40,74,112,110,41,0,0,0,0,0,68,105,112,32,83,119,105,116,99,104,101,115,32,51,0,0,109,100,95,115,108,97,112,102,105,103,104,0,0,0,0,0,100,107,111,110,103,106,114,106,0,0,0,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,39,32,45,32,67,104,97,109,112,105,111,110,32,69,100,105,116,105,111,110,32,40,115,116,114,101,101,116,32,102,105,103,104,116,101,114,32,50,39,32,57,50,48,53,49,51,32,74,97,112,97,110,41,0,0,75,121,117,117,107,121,111,107,117,32,77,97,104,106,111,110,103,32,45,32,73,100,111,108,32,71,114,97,112,104,105,99,115,0,0,0,0,0,0,0,84,104,101,32,75,105,110,103,32,111,102,32,70,105,103,104,116,101,114,115,32,50,48,48,50,32,80,108,117,115,32,40,98,111,111,116,108,101,103,32,115,101,116,32,50,41,0,0,83,108,97,109,32,45,32,83,104,97,113,32,118,115,46,32,116,104,101,32,76,101,103,101,110,100,115,32,40,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,0,0,0,109,100,95,97,108,97,100,100,105,110,0,0,0,0,0,0,72,105,115,115,97,116,115,117,32,66,117,114,97,105,107,101,110,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,109,100,95,115,108,97,109,115,104,97,113,0,0,0,0,0,106,111,105,110,101,109,0,0,54,32,40,70,111,114,101,115,116,32,50,41,0,0,0,0,70,114,111,109,32,84,86,32,65,110,105,109,97,116,105,111,110,32,83,108,97,109,32,68,117,110,107,32,45,32,75,121,111,117,103,111,117,32,77,97,107,107,111,117,32,84,97,105,107,101,116,115,117,33,32,40,74,112,110,41,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,90,101,114,111,32,40,57,53,48,54,48,53,32,65,115,105,97,41,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,78,111,32,82,79,77,32,105,115,32,117,115,101,100,44,32,98,117,116,32,108,105,98,114,101,116,114,111,32,99,111,114,101,32,100,111,101,115,32,110,111,116,32,115,117,112,112,111,114,116,32,116,104,105,115,46,10,0,0,109,100,95,115,108,97,109,100,117,110,107,0,0,0,0,0,32,49,32,67,111,105,110,32,32,52,32,67,114,101,100,105,116,115,0,0,0,0,0,0,65,32,49,47,50,32,66,32,49,47,54,0,0,0,0,0,49,32,67,111,105,110,32,32,50,32,67,114,101,100,105,116,115,32,47,32,49,32,67,111,105,110,32,32,54,32,32,67,114,101,100,105,116,115,0,0,83,107,101,108,101,116,111,110,32,75,114,101,119,32,40,85,83,65,41,0,0,0,0,0,51,32,109,105,110,47,49,46,53,32,109,105,110,0,0,0,109,100,95,115,107,101,108,107,114,101,119,117,0,0,0,0,71,97,109,101,32,82,111,111,109,0,0,0,0,0,0,0,116,111,107,105,0,0,0,0,109,95,107,98,95,99,109,100,0,0,0,0,0,0,0,0,83,107,101,108,101,116,111,110,32,75,114,101,119,32,40,69,117,114,111,41,0,0,0,0,68,114,97,103,111,110,32,87,111,114,108,100,32,73,73,32,40,86,49,48,48,88,44,32,87,111,114,108,100,41,0,0,77,97,104,106,111,110,103,32,78,0,0,0,0,0,0,0,87,101,108,108,0,0,0,0,83,121,115,116,101,109,49,68,105,112,0,0,0,0,0,0,109,100,95,115,107,101,108,107,114,101,119,0,0,0,0,0,84,104,101,32,83,105,109,112,115,111,110,115,32,45,32,66,97,114,116,39,115,32,78,105,103,104,116,109,97,114,101,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,80,50,32,67,97,110,99,101,108,0,0,0,0,0,0,0,65,114,116,105,115,116,32,84,111,111,108,0,0,0,0,0,68,105,112,32,83,119,105,116,99,104,101,115,32,50,0,0,109,100,95,98,97,114,116,110,105,103,104,0,0,0,0,0,115,102,50,99,101,106,98,0,112,99,101,95,107,121,117,107,121,111,109,106,0,0,0,0,99,97,112,116,99,111,109,109,106,114,49,0,0,0,0,0,107,102,50,107,50,112,108,97,0,0,0,0,0,0,0,0,84,104,101,32,83,105,109,112,115,111,110,115,32,45,32,66,97,114,116,32,86,115,32,84,104,101,32,83,112,97,99,101,32,77,117,116,97,110,116,115,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,97,108,112,104,97,109,50,112,0,0,0,0,0,0,0,0,110,90,56,48,66,97,110,107,50,0,0,0,0,0,0,0,65,115,109,105,107,32,65,99,101,0,0,0,0,0,0,0,109,100,95,98,97,114,116,118,115,115,109,49,0,0,0,0,113,117,105,122,111,0,0,0,84,104,101,32,83,105,109,112,115,111,110,115,32,45,32,66,97,114,116,32,86,115,32,84,104,101,32,83,112,97,99,101,32,77,117,116,97,110,116,115,32,40,69,117,114,111,44,32,85,83,65,44,32,82,101,118,46,32,65,41,0,0,0,0,115,102,122,97,114,49,0,0,79,80,76,45,62,115,116,0,90,56,48,32,66,73,79,83,0,0,0,0,0,0,0,0,109,100,95,98,97,114,116,118,115,115,109,0,0,0,0,0,65,115,104,98,121,32,67,111,109,112,117,116,101,114,115,32,97,110,100,32,71,114,97,112,104,105,99,115,32,76,84,68,46,32,40,74,97,108,101,99,111,32,108,105,99,101,110,115,101,41,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,116,101,120,116,117,114,101,32,105,109,97,103,101,32,102,114,111,109,58,32,34,37,115,34,10,0,0,0,83,105,100,101,32,80,111,99,107,101,116,32,40,74,112,110,41,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,71,76,58,32,79,117,116,32,111,102,32,109,101,109,111,114,121,46,10,0,0,0,0,0,0,0,0,83,102,50,109,100,116,83,97,109,112,108,101,66,117,102,102,101,114,49,0,0,0,0,0,109,100,95,115,105,100,101,112,111,99,107,106,0,0,0,0,74,117,115,116,105,102,105,101,114,0,0,0,0,0,0,0,83,105,100,101,32,80,111,99,107,101,116,32,40,69,117,114,111,41,0,0,0,0,0,0,109,97,104,32,109,0,0,0,83,97,118,101,100,32,110,101,119,32,99,111,110,102,105,103,32,116,111,32,34,37,115,34,46,0,0,0,0,0,0,0,80,105,110,32,82,101,98,111,117,110,100,0,0,0,0,0,83,104,117,114,97,32,110,111,32,77,111,110,32,40,74,112,110,41,0,0,0,0,0,0,52,32,73,110,110,105,110,103,0,0,0,0,0,0,0,0,109,100,95,115,104,117,114,97,109,111,110,0,0,0,0,0,119,114,97,112,95,109,111,100,101,37,117,0,0,0,0,0,68,105,112,32,83,119,105,116,99,104,101,115,32,49,0,0,104,112,117,110,99,104,101,114,0,0,0,0,0,0,0,0,83,104,117,105,32,72,117,32,90,104,117,97,110,32,40,67,104,105,41,0,0,0,0,0,112,103,101,97,114,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,39,32,45,32,67,104,97,109,112,105,111,110,32,69,100,105,116,105,111,110,32,40,115,116,114,101,101,116,32,102,105,103,104,116,101,114,32,50,39,32,57,50,48,51,50,50,32,74,97,112,97,110,41,0,0,84,104,101,32,75,117,110,103,32,70,117,0,0,0,0,0,84,104,101,32,75,105,110,103,32,111,102,32,70,105,103,104,116,101,114,115,32,50,48,48,50,32,80,108,117,115,32,40,98,111,111,116,108,101,103,32,115,101,116,32,49,41,0,0,110,117,108,0,0,0,0,0,109,100,95,115,104,117,105,104,117,122,104,0,0,0,0,0,65,105,114,32,68,105,118,101,114,32,40,74,112,110,41,0,0,0,0,0,0,0,0,0,98,108,115,119,104,115,116,108,0,0,0,0,0,0,0,0,115,104,105,115,101,110,50,0,78,101,118,101,114,32,69,110,100,105,110,103,32,83,111,102,116,32,84,101,97,109,0,0,109,121,115,116,105,99,114,105,0,0,0,0,0,0,0,0,110,115,112,105,114,105,116,106,0,0,0,0,0,0,0,0,83,104,117,105,32,72,117,32,45,32,70,101,110,103,32,89,117,110,32,90,104,117,97,110,32,40,67,104,105,41,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,90,101,114,111,32,40,57,53,48,54,50,55,32,65,115,105,97,41,0,0,0,0,0,0,0,68,105,110,103,111,0,0,0,109,100,95,115,104,117,105,104,117,0,0,0,0,0,0,0,101,120,101,100,101,120,101,115,0,0,0,0,0,0,0,0,83,0,0,0,104,0,0,0,111,0,0,0,119,0,0,0,32,0,0,0,100,0,0,0,111,0,0,0,32,0,0,0,77,0,0,0,105,0,0,0,108,0,0,0,104,0,0,0,227,0,0,0,111,0,0,0,32,0,0,0,86,0,0,0,111,0,0,0,108,0,0,0,117,0,0,0,109,0,0,0,101,0,0,0,32,0,0,0,50,0,0,0,32,0,0,0,40,0,0,0,66,0,0,0,114,0,0,0,97,0,0,0,44,0,0,0,32,0,0,0,65,0,0,0,108,0,0,0,116,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,83,104,111,119,32,100,111,32,77,105,108,104,97,111,32,86,111,108,117,109,101,32,50,32,40,66,114,97,44,32,65,108,116,41,0,0,0,0,0,0,77,97,104,106,111,110,103,32,77,0,0,0,0,0,0,0,77,97,116,99,104,0,0,0,109,100,95,115,100,109,105,108,104,97,50,97,0,0,0,0,83,0,0,0,104,0,0,0,111,0,0,0,119,0,0,0,32,0,0,0,100,0,0,0,111,0,0,0,32,0,0,0,77,0,0,0,105,0,0,0,108,0,0,0,104,0,0,0,227,0,0,0,111,0,0,0,32,0,0,0,86,0,0,0,111,0,0,0,108,0,0,0,117,0,0,0,109,0,0,0,101,0,0,0,32,0,0,0,50,0,0,0,32,0,0,0,40,0,0,0,66,0,0,0,114,0,0,0,97,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,83,104,111,119,32,100,111,32,77,105,108,104,97,111,32,86,111,108,117,109,101,32,50,32,40,66,114,97,41,0,0,0,115,102,50,99,101,106,97,0,112,99,101,95,107,117,110,103,102,117,0,0,0,0,0,0,107,102,50,107,50,112,108,115,0,0,0,0,0,0,0,0,109,100,95,97,105,114,100,105,118,101,114,106,0,0,0,0,109,100,95,115,100,109,105,108,104,97,50,0,0,0,0,0,83,0,0,0,104,0,0,0,111,0,0,0,119,0,0,0,32,0,0,0,100,0,0,0,111,0,0,0,32,0,0,0,77,0,0,0,105,0,0,0,108,0,0,0,104,0,0,0,227,0,0,0,111,0,0,0,32,0,0,0,40,0,0,0,66,0,0,0,114,0,0,0,97,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,115,102,122,97,0,0,0,0,83,101,116,116,105,110,103,32,100,105,115,107,32,37,117,32,111,102,32,37,117,32,105,110,32,116,114,97,121,46,0,0,83,104,111,119,32,100,111,32,77,105,108,104,97,111,32,40,66,114,97,41,0,0,0,0,100,105,110,103,111,0,0,0,68,97,109,98,117,115,116,114,66,103,83,112,108,105,116,76,105,110,101,0,0,0,0,0,109,100,95,115,100,109,105,108,104,97,111,0,0,0,0,0,115,108,45,62,111,112,49,95,111,117,116,0,0,0,0,0,83,104,105,106,111,117,32,83,97,105,100,97,105,32,110,111,32,83,111,117,107,111,98,97,110,32,40,74,112,110,41,0,0,0,0,0,0,0,0,0,109,97,104,32,108,0,0,0,118,117,108,103,117,115,0,0,69,120,116,114,97,32,66,97,108,108,32,55,48,48,48,48,48,0,0,0,0,0,0,0,83,99,114,111,108,108,88,0,109,100,95,115,111,107,111,98,97,110,0,0,0,0,0,0,83,104,111,118,101,32,73,116,33,32,46,46,46,84,104,101,32,87,97,114,101,104,111,117,115,101,32,71,97,109,101,32,40,85,83,65,41,0,0,0,109,100,95,115,104,111,118,101,105,116,0,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,39,32,45,32,67,104,97,109,112,105,111,110,32,69,100,105,116,105,111,110,32,40,115,116,114,101,101,116,32,102,105,103,104,116,101,114,32,50,39,32,57,50,48,51,49,51,32,101,116,99,41,0,0,0,0,75,111,114,101,32,71,97,32,80,114,111,32,89,97,107,121,117,117,32,39,57,48,0,0,84,104,101,32,75,105,110,103,32,111,102,32,70,105,103,104,116,101,114,115,32,50,48,48,50,32,40,98,111,111,116,108,101,103,41,0,0,0,0,0,83,104,111,117,103,105,32,110,111,32,72,111,115,104,105,32,40,74,112,110,41,0,0,0,83,101,105,115,109,105,99,0,109,100,95,115,104,111,117,103,105,0,0,0,0,0,0,0,103,108,80,114,111,103,114,97,109,66,105,110,97,114,121,79,69,83,0,0,0,0,0,0,84,101,99,104,110,111,112,111,112,0,0,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,65,108,112,104,97,32,45,32,119,97,114,114,105,111,114,115,39,32,100,114,101,97,109,115,32,40,57,53,48,54,50,55,32,85,83,65,41,0,0,0,0,83,104,105,112,32,40,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,0,0,109,100,95,115,104,105,112,0,84,104,101,32,83,117,112,101,114,32,83,104,105,110,111,98,105,32,73,73,32,40,74,112,110,44,32,80,114,111,116,111,116,121,112,101,44,32,69,97,114,108,105,101,114,41,0,0,105,110,118,97,108,105,100,32,119,105,110,100,111,119,32,115,105,122,101,0,0,0,0,0,109,100,95,115,117,112,115,104,105,110,50,112,50,0,0,0,77,97,104,106,111,110,103,32,76,0,0,0,0,0,0,0,69,120,116,114,97,32,66,97,108,108,32,54,48,48,48,48,48,0,0,0,0,0,0,0,84,104,101,32,83,117,112,101,114,32,83,104,105,110,111,98,105,32,73,73,32,40,74,112,110,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,91,71,76,93,58,32,83,116,111,99,107,32,71,76,83,76,32,115,104,97,100,101,114,115,32,119,105,108,108,32,98,101,32,117,115,101,100,46,10,0,0,0,0,0,109,100,95,115,117,112,115,104,105,110,50,112,49,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,69,77,83,67,82,73,80,84,69,78,47,69,71,76,93,58,32,68,105,109,101,110,115,105,111,110,115,58,32,37,117,120,37,117,10,0,83,119,97,114,109,32,40,98,111,111,116,108,101,103,63,41,0,0,0,0,0,0,0,0,84,104,101,32,83,117,112,101,114,32,83,104,105,110,111,98,105,32,73,73,32,40,74,112,110,44,32,75,111,114,41,0,0,0,0,0,0,0,0,0,115,102,50,99,101,101,97,0,112,99,101,95,112,114,111,121,97,107,57,48,0,0,0,0,107,111,102,50,48,48,50,98,0,0,0,0,0,0,0,0,109,100,95,115,117,112,115,104,105,110,50,0,0,0,0,0,65,105,114,32,68,105,118,101,114,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,84,104,101,32,67,108,105,102,102,104,97,110,103,101,114,32,45,32,69,100,119,97,114,100,32,82,97,110,100,121,32,40,87,111,114,108,100,32,118,101,114,32,49,41,0,0,0,0,83,104,105,110,111,98,105,32,73,73,73,32,45,32,82,101,116,117,114,110,32,111,102,32,116,104,101,32,78,105,110,106,97,32,77,97,115,116,101,114,32,40,85,83,65,41,0,0,109,100,95,115,104,105,110,111,98,105,51,117,0,0,0,0,115,102,97,117,0,0,0,0,83,104,105,110,105,110,103,32,97,110,100,32,116,104,101,32,68,97,114,107,110,101,115,115,32,40,74,112,110,41,0,0,67,104,101,99,107,32,77,97,110,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,72,97,114,100,101,115,116,32,40,54,48,41,0,0,0,0,49,57,52,50,0,0,0,0,109,100,95,115,104,105,110,100,97,114,107,106,0,0,0,0,83,104,105,110,105,110,103,32,105,110,32,116,104,101,32,68,97,114,107,110,101,115,115,32,40,66,114,97,41,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,71,76,93,58,32,67,97,110,110,111,116,32,102,105,110,100,32,115,104,97,100,101,114,32,99,111,114,101,32,102,111,114,32,112,97,116,104,58,32,37,115,46,10,0,0,0,0,0,0,0,109,100,95,115,104,105,110,100,97,114,107,98,114,0,0,0,109,97,104,32,107,0,0,0,69,120,116,114,97,32,66,97,108,108,32,53,48,48,48,48,48,0,0,0,0,0,0,0,83,104,105,110,105,110,103,32,105,110,32,116,104,101,32,68,97,114,107,110,101,115,115,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,109,100,95,115,104,105,110,100,97,114,107,0,0,0,0,0,83,104,105,110,105,110,103,32,70,111,114,99,101,32,73,73,32,40,85,83,65,41,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,39,32,45,32,67,104,97,109,112,105,111,110,32,69,100,105,116,105,111,110,32,40,115,116,114,101,101,116,32,102,105,103,104,116,101,114,32,50,39,32,57,50,48,53,49,51,32,101,116,99,41,0,0,0,0,73,110,116,101,99,0,0,0,69,111,108,105,116,104,32,47,32,80,108,97,121,109,111,114,101,0,0,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,65,108,112,104,97,32,45,32,119,97,114,114,105,111,114,115,39,32,100,114,101,97,109,115,32,40,57,53,48,54,48,53,32,69,117,114,111,41,0,0,0,109,100,95,115,104,105,110,102,114,99,50,117,0,0,0,0,109,100,95,97,105,114,100,105,118,101,114,0,0,0,0,0,83,104,105,110,105,110,103,32,70,111,114,99,101,32,73,73,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,54,48,55,41,0,0,0,0,0,68,69,84,69,67,84,69,68,32,67,79,82,69,83,32,37,115,0,0,0,0,0,0,0,82,51,0,0,0,0,0,0,109,100,95,115,104,105,110,102,114,99,50,112,49,0,0,0,83,104,105,110,105,110,103,32,70,111,114,99,101,32,73,73,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,52,48,52,41,0,0,0,0,0,99,104,101,99,107,109,97,110,106,0,0,0,0,0,0,0,109,100,95,115,104,105,110,102,114,99,50,112,50,0,0,0,83,104,105,110,105,110,103,32,70,111,114,99,101,32,73,73,32,45,32,75,111,101,32,110,111,32,70,117,117,105,110,32,40,74,112,110,41,0,0,0,103,97,114,121,111,114,101,116,0,0,0,0,0,0,0,0,109,100,95,115,104,105,110,102,114,99,50,106,0,0,0,0,77,97,104,106,111,110,103,32,75,0,0,0,0,0,0,0,69,120,116,114,97,32,66,97,108,108,32,52,48,48,48,48,48,0,0,0,0,0,0,0,51,48,107,32,53,48,107,32,49,48,48,107,32,50,48,48,107,32,51,48,48,107,0,0,83,104,105,110,105,110,103,32,70,111,114,99,101,32,45,32,75,97,109,105,103,97,109,105,32,110,111,32,73,115,97,110,32,40,74,112,110,41,0,0,82,101,116,114,111,65,114,99,104,58,32,70,97,105,108,101,100,32,119,114,105,116,105,110,103,32,115,104,97,100,101,114,32,112,114,101,115,101,116,32,116,111,32,37,115,46,10,0,99,121,98,101,114,116,110,107,0,0,0,0,0,0,0,0,109,100,95,115,104,105,110,102,114,99,101,106,0,0,0,0,83,104,105,110,105,110,103,32,70,111,114,99,101,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,41,0,0,115,102,50,99,101,0,0,0,75,111,114,101,32,71,97,32,80,114,111,32,89,97,107,121,117,117,32,39,56,57,0,0,70,45,50,50,32,73,110,116,101,114,99,101,112,116,111,114,32,40,69,117,114,111,44,32,85,83,65,44,32,49,57,57,49,48,57,41,0,0,0,0,84,104,101,32,75,105,110,103,32,111,102,32,70,105,103,104,116,101,114,115,32,50,48,48,50,32,40,78,71,77,45,50,54,53,48,41,40,78,71,72,45,50,54,53,48,41,0,0,109,100,95,115,104,105,110,102,114,99,101,112,0,0,0,0,75,48,53,49,57,54,48,82,111,109,79,102,102,115,101,116,0,0,0,0,0,0,0,0,65,101,114,111,32,66,108,97,115,116,101,114,115,58,32,84,114,111,117,98,108,101,32,83,112,101,99,105,97,108,116,121,32,82,97,105,100,32,85,110,105,116,32,40,74,112,110,41,0,0,0,0,0,0,0,0,75,48,53,50,49,48,57,83,99,114,111,108,108,88,91,50,93,0,0,0,0,0,0,0,98,117,114,110,105,110,103,102,0,0,0,0,0,0,0,0,80,49,32,83,101,108,101,99,116,0,0,0,0,0,0,0,83,104,105,110,105,110,103,32,70,111,114,99,101,32,40,85,83,65,41,0,0,0,0,0,109,100,95,115,104,105,110,102,114,99,101,0,0,0,0,0,115,102,97,114,51,0,0,0,110,77,54,56,48,48,67,121,99,108,101,115,68,111,110,101,91,105,93,0,0,0,0,0,109,97,114,105,111,0,0,0,51,32,99,111,105,110,115,32,49,32,99,114,101,100,105,116,0,0,0,0,0,0,0,0,42,49,49,48,0,0,0,0,65,32,40,101,97,115,121,41,0,0,0,0,0,0,0,0,83,104,105,107,105,110,106,111,104,32,40,74,112,110,41,0,0,0,0,0,0,0,0,0,115,108,97,112,102,105,103,104,98,50,0,0,0,0,0,0,90,105,108,101,120,45,90,101,110,105,116,111,110,101,0,0,66,111,110,117,115,32,76,105,102,101,0,0,0,0,0,0,109,100,95,115,104,105,107,105,110,106,111,0,0,0,0,0,49,48,48,48,48,48,32,47,32,53,48,48,48,48,48,0,53,48,75,44,32,101,118,101,114,121,32,49,53,48,75,0,83,104,105,32,74,105,101,32,90,104,105,32,66,97,110,103,32,90,104,101,110,103,32,66,97,32,90,104,97,110,32,45,32,87,111,114,108,100,32,80,114,111,32,66,97,115,101,98,97,108,108,32,57,52,32,40,67,104,105,41,0,0,0,0,109,100,95,115,104,105,106,105,101,0,0,0,0,0,0,0,119,97,108,108,99,0,0,0,70,105,103,104,116,105,110,103,32,70,97,110,116,97,115,121,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,109,97,104,32,106,0,0,0,69,120,116,114,97,32,66,97,108,108,32,51,48,48,48,48,48,0,0,0,0,0,0,0,49,48,107,32,51,48,107,32,54,48,107,32,49,48,48,107,32,49,53,48,107,0,0,0,83,104,97,113,32,70,117,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,54,47,52,0,0,0,0,0,65,114,107,97,110,111,105,100,32,40,71,97,109,101,32,67,111,114,112,111,114,97,116,105,111,110,32,98,111,111,116,108,101,103,44,32,115,101,116,32,50,41,0,0,0,0,0,0,50,48,107,32,97,110,100,32,101,118,101,114,121,32,49,48,48,107,0,0,0,0,0,0,109,100,95,115,104,97,113,102,117,0,0,0,0,0,0,0,67,114,105,109,101,32,67,105,116,121,32,40,74,97,112,97,110,41,0,0,0,0,0,0,67,111,110,116,105,110,101,110,116,97,108,32,67,105,114,99,117,115,32,40,85,83,32,115,101,116,32,49,41,0,0,0,83,104,97,110,103,104,97,105,32,73,73,32,45,32,68,114,97,103,111,110,39,115,32,69,121,101,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,65,108,116,41,0,0,0,0,0,0,0,0,82,97,105,110,98,111,119,32,73,115,108,97,110,100,115,32,40,69,120,116,114,97,41,0,0,0,0,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,32,45,32,84,104,101,32,87,111,114,108,100,32,87,97,114,114,105,111,114,32,40,98,111,111,116,108,101,103,44,32,57,49,48,50,49,52,32,101,116,99,44,32,115,101,116,32,50,41,0,0,0,0,0,0,71,97,108,109,101,100,101,115,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,112,99,101,95,112,114,111,121,97,107,56,57,0,0,0,0,116,111,107,105,111,0,0,0,109,100,95,115,104,97,110,103,104,50,112,49,0,0,0,0,109,100,95,97,101,114,111,98,108,115,116,0,0,0,0,0,80,49,32,66,117,116,116,111,110,32,88,0,0,0,0,0,83,104,97,110,103,104,97,105,32,73,73,32,45,32,68,114,97,103,111,110,39,115,32,69,121,101,32,40,85,83,65,44,32,80,114,111,116,111,116,121])
.concat([112,101,41,0,0,0,0,0,65,108,116,101,114,101,100,32,66,101,97,115,116,32,40,68,97,116,115,117,32,98,111,111,116,108,101,103,41,0,0,0,114,103,117,105,46,99,103,112,0,0,0,0,0,0,0,0,82,70,53,67,54,56,80,67,77,66,97,110,107,65,100,100,114,101,115,115,0,0,0,0,109,100,95,115,104,97,110,103,104,50,112,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,65,108,112,104,97,32,45,32,119,97,114,114,105,111,114,115,39,32,100,114,101,97,109,115,32,40,57,53,48,54,50,55,32,69,117,114,111,41,0,0,0,71,97,114,100,105,97,32,40,51,49,55,45,48,48,48,54,41,0,0,0,0,0,0,0,115,117,112,112,111,114,116,101,100,95,101,120,116,101,110,115,105,111,110,115,0,0,0,0,37,0,0,0,109,0,0,0,47,0,0,0,37,0,0,0,100,0,0,0,47,0,0,0,37,0,0,0,121,0,0,0,0,0,0,0,0,0,0,0,83,104,97,110,103,104,97,105,32,73,73,32,45,32,68,114,97,103,111,110,39,115,32,69,121,101,32,40,85,83,65,41,0,0,0,0,0,0,0,0,100,97,116,97,0,0,0,0,49,57,63,63,0,0,0,0,67,104,101,99,107,32,77,97,110,0,0,0,0,0,0,0,79,98,115,116,114,117,99,116,105,111,110,32,67,97,114,0,118,105,100,101,111,95,97,115,112,101,99,116,95,114,97,116,105,111,95,97,117,116,111,0,109,106,108,101,97,103,117,101,0,0,0,0,0,0,0,0,109,100,95,115,104,97,110,103,104,50,0,0,0,0,0,0,103,116,109,114,50,97,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,114,101,97,100,32,105,109,97,103,101,58,32,37,115,46,10,0,83,104,97,110,101,32,87,97,114,110,101,32,67,114,105,99,107,101,116,32,40,65,117,115,41,0,0,0,0,0,0,0,80,108,97,121,32,84,105,109,101,32,80,49,0,0,0,0,109,100,95,115,104,97,110,101,119,97,114,0,0,0,0,0,71,117,110,32,82,101,108,111,97,100,105,110,103,0,0,0,49,67,95,49,67,0,0,0,77,97,104,106,111,110,103,32,74,0,0,0,0,0,0,0,69,120,116,114,97,32,66,97,108,108,32,50,48,48,48,48,48,0,0,0,0,0,0,0,52,48,107,32,49,52,48,107,32,50,56,48,107,0,0,0,83,104,97,100,111,119,114,117,110,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,49,50,53,41,0,0,0,0,66,105,103,32,66,97,110,103,32,40,57,116,104,32,78,111,118,46,32,49,57,57,51,41,0,0,0,0,0,0,0,0,75,111,110,97,109,105,32,116,101,115,116,32,98,111,97,114,100,0,0,0,0,0,0,0,100,101,101,114,104,117,110,116,0,0,0,0,0,0,0,0,109,100,95,115,104,97,100,111,119,114,110,112,49,0,0,0,97,108,105,101,110,115,101,99,0,0,0,0,0,0,0,0,68,114,97,103,111,110,32,66,111,119,108,0,0,0,0,0,83,104,97,100,111,119,114,117,110,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,49,50,53,45,67,41,0,0,49,49,32,80,111,105,110,116,115,32,97,110,100,32,49,32,65,100,118,46,0,0,0,0,115,102,50,98,50,0,0,0,70,97,110,116,97,115,105,97,32,73,73,32,40,76,101,115,115,32,69,120,112,108,105,99,105,116,41,0,0,0,0,0,75,110,105,103,104,116,32,82,105,100,101,114,32,83,112,101,99,105,97,108,0,0,0,0,107,111,102,50,48,48,50,0,50,32,67,114,46,32,83,116,97,114,116,44,32,49,32,67,111,110,116,105,110,117,101,0,109,100,95,115,104,97,100,111,119,114,110,112,50,0,0,0,80,114,101,116,116,121,32,83,111,108,100,105,101,114,32,83,97,105,108,111,114,32,77,111,111,110,32,40,118,101,114,46,32,57,53,47,48,51,47,50,50,44,32,75,111,114,101,97,41,0,0,0,0,0,0,0,49,32,67,111,105,110,47,49,32,67,114,101,100,105,116,32,50,47,51,0,0,0,0,0,67,48,48,48,48,48,32,82,101,103,105,115,116,101,114,115,0,0,0,0,0,0,0,0,56,48,48,107,32,49,53,48,48,107,0,0,0,0,0,0,83,104,97,100,111,119,114,117,110,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,51,49,50,51,49,41,0,0,0,0,115,111,110,105,99,119,105,0,67,108,101,97,114,32,77,101,109,111,114,121,0,0,0,0,109,100,95,115,104,97,100,111,119,114,110,112,51,0,0,0,115,102,97,114,50,0,0,0,82,101,116,114,111,65,114,99,104,58,32,65,109,111,117,110,116,32,111,102,32,116,105,109,101,32,115,112,101,110,116,32,99,108,111,115,101,32,116,111,32,117,110,100,101,114,114,117,110,58,32,37,46,50,102,32,37,37,46,32,67,108,111,115,101,32,116,111,32,98,108,111,99,107,105,110,103,58,32,37,46,50,102,32,37,37,46,10,0,0,0,0,0,0,0,0,68,97,105,111,104,32,40,115,101,116,32,50,41,0,0,0,83,104,97,100,111,119,114,117,110,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,51,49,50,50,56,41,0,0,0,0,99,104,101,99,107,109,97,110,0,0,0,0,0,0,0,0,86,83,32,68,105,102,102,105,99,117,108,116,121,0,0,0,75,49,32,83,111,102,116,0,75,48,53,51,50,53,49,80,97,108,73,110,100,101,120,91,50,93,0,0,0,0,0,0,119,108,115,116,97,114,0,0,109,100,95,115,104,97,100,111,119,114,110,112,52,0,0,0,116,101,110,103,97,105,0,0,84,101,116,114,105,115,32,116,104,101,32,65,98,115,111,108,117,116,101,32,84,104,101,32,71,114,97,110,100,32,77,97,115,116,101,114,32,50,0,0,80,49,32,98,117,116,116,111,110,32,52,0,0,0,0,0,83,104,97,100,111,119,114,117,110,32,40,74,112,110,41,0,0,0,0,0,0,0,0,0,50,48,107,32,32,54,48,107,32,32,54,48,107,0,0,0,75,48,53,49,51,49,54,87,114,97,112,91,49,93,0,0,109,100,95,115,104,97,100,111,119,114,110,106,0,0,0,0,49,67,32,50,67,32,47,32,49,67,32,49,48,67,0,0,55,48,48,48,48,0,0,0,109,97,104,32,105,0,0,0,65,32,50,45,49,32,66,32,49,45,50,0,0,0,0,0,69,120,116,114,97,32,66,97,108,108,32,49,48,48,48,48,48,0,0,0,0,0,0,0,75,48,53,51,50,52,52,66,97,110,107,91,48,93,0,0,52,48,107,32,49,50,48,107,32,50,52,48,107,0,0,0,83,104,97,100,111,119,114,117,110,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,80,97,99,117,45,77,97,110,32,40,83,112,97,110,105,115,104,32,98,111,111,116,108,101,103,32,111,102,32,80,117,99,107,32,77,97,110,41,0,0,103,97,117,110,116,108,101,116,50,112,0,0,0,0,0,0,109,100,95,115,104,97,100,111,119,114,110,0,0,0,0,0,83,104,97,100,111,119,32,111,102,32,116,104,101,32,66,101,97,115,116,32,73,73,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,68,111,110,107,101,121,32,75,111,110,103,32,74,117,110,105,111,114,32,40,85,83,41,0,0,0,0,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,32,45,32,84,104,101,32,87,111,114,108,100,32,87,97,114,114,105,111,114,32,40,98,111,111,116,108,101,103,44,32,57,49,48,50,49,52,32,101,116,99,44,32,115,101,116,32,49,41,0,0,0,0,0,0,112,99,101,95,107,110,105,103,104,116,114,115,0,0,0,0,67,0,0,0,114,0,0,0,111,0,0,0,117,0,0,0,99,0,0,0,104,0,0,0,105,0,0,0,110,0,0,0,103,0,0,0,32,0,0,0,84,0,0,0,105,0,0,0,103,0,0,0,101,0,0,0,114,0,0,0,32,0,0,0,72,0,0,0,105,0,0,0,100,0,0,0,100,0,0,0,101,0,0,0,110,0,0,0,32,0,0,0,68,0,0,0,114,0,0,0,97,0,0,0,103,0,0,0,111,0,0,0,110,0,0,0,32,0,0,0,50,0,0,0,48,0,0,0,48,0,0,0,51,0,0,0,32,0,0,0,83,0,0,0,117,0,0,0,112,0,0,0,101,0,0,0,114,0,0,0,32,0,0,0,80,0,0,0,108,0,0,0,117,0,0,0,115,0,0,0,32,0,0,0,40,0,0,0,97,0,0,0,108,0,0,0,116,0,0,0,101,0,0,0,114,0,0,0,110,0,0,0,97,0,0,0,116,0,0,0,101,0,0,0,32,0,0,0,115,0,0,0,101,0,0,0,116,0,0,0,41,0,0,0,0,0,0,0,229,129,0,0,78,134,0,0,207,133,0,0,141,159,0,0,0,0,0,0,0,0,0,0,109,100,95,98,101,97,115,116,50,0,0,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,65,108,112,104,97,32,45,32,119,97,114,114,105,111,114,115,39,32,100,114,101,97,109,115,32,40,57,53,48,55,49,56,32,69,117,114,111,41,0,0,0,65,105,114,32,66,117,115,116,101,114,58,32,84,114,111,117,98,108,101,32,83,112,101,99,105,97,108,116,121,32,82,97,105,100,32,85,110,105,116,32,40,85,83,65,41,0,0,0,98,117,114,97,105,107,101,110,0,0,0,0,0,0,0,0,75,48,53,51,50,52,54,95,79,66,74,67,72,65,95,108,105,110,101,0,0,0,0,0,83,104,97,100,111,119,32,111,102,32,116,104,101,32,66,101,97,115,116,32,45,32,77,97,115,104,111,117,32,110,111,32,79,107,105,116,101,32,40,74,112,110,41,0,0,0,0,0,78,111,109,97,32,40,67,111,115,116,97,108,32,71,97,109,101,115,32,108,105,99,101,110,115,101,41,0,0,0,0,0,52,32,40,70,111,114,101,115,116,32,50,41,0,0,0,0,68,114,118,67,104,97,114,115,79,110,0,0,0,0,0,0,109,100,95,98,101,97,115,116,106,0,0,0,0,0,0,0,83,76,79,84,45,62,100,114,0,0,0,0,0,0,0,0,76,101,103,101,110,100,0,0,82,101,116,114,111,65,114,99,104,58,32,70,111,117,110,100,32,88,77,76,32,109,101,109,111,114,121,32,109,97,112,32,105,110,32,34,37,115,34,10,0,0,0,0,0,0,0,0,83,104,97,100,111,119,32,111,102,32,116,104,101,32,66,101,97,115,116,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,0,0,0,74,101,116,115,111,102,116,0,66,111,110,117,115,32,76,101,118,101,108,0,0,0,0,0,32,49,32,67,111,105,110,32,32,51,32,67,114,101,100,105,116,115,0,0,0,0,0,0,65,32,49,47,50,32,66,32,49,47,53,0,0,0,0,0,49,32,67,111,105,110,32,32,50,32,67,114,101,100,105,116,115,32,47,32,49,32,67,111,105,110,32,32,49,50,32,67,114,101,100,105,116,115,0,0,109,100,95,98,101,97,115,116,0,0,0,0,0,0,0,0,50,32,109,105,110,47,49,32,109,105,110,0,0,0,0,0,83,104,97,100,111,119,32,68,97,110,99,101,114,32,45,32,84,104,101,32,83,101,99,114,101,116,32,111,102,32,83,104,105,110,111,98,105,32,40,87,111,114,108,100,41,0,0,0,70,114,101,101,32,80,108,97,121,32,38,32,73,110,118,117,108,110,101,114,97,98,105,108,105,116,121,0,0,0,0,0,109,95,107,98,95,112,114,111,116,95,104,105,108,111,95,115,101,108,101,99,116,0,0,0,109,100,95,115,104,100,97,110,99,101,114,0,0,0,0,0,77,97,104,106,111,110,103,32,73,0,0,0,0,0,0,0,82,101,112,108,97,121,32,49,56,48,48,48,48,48,0,0,51,48,107,32,49,48,48,107,32,50,48,48,107,0,0,0,83,104,105,116,101,110,32,77,121,111,117,111,117,32,40,74,112,110,41,0,0,0,0,0,109,100,95,115,104,105,116,101,110,0,0,0,0,0,0,0,112,99,101,95,97,114,116,116,111,111,108,0,0,0,0,0,83,104,97,100,111,119,32,66,108,97,115,116,101,114,115,32,40,85,83,65,41,0,0,0,115,102,50,98,0,0,0,0,75,108,97,120,0,0,0,0,67,97,112,116,97,105,110,32,67,111,109,109,97,110,100,111,32,40,57,49,49,50,48,50,32,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,67,114,111,117,99,104,105,110,103,32,84,105,103,101,114,32,72,105,100,100,101,110,32,68,114,97,103,111,110,32,50,48,48,51,32,83,117,112,101,114,32,80,108,117,115,32,97,108,116,101,114,110,97,116,101,0,0,0,0,0,0,0,0,0,65,108,112,104,97,32,77,105,115,115,105,111,110,32,73,73,32,47,32,65,83,79,32,73,73,32,45,32,76,97,115,116,32,71,117,97,114,100,105,97,110,32,40,78,71,77,45,48,48,55,41,40,78,71,72,45,48,48,55,41,0,0,0,0,109,100,95,115,104,97,100,111,119,0,0,0,0,0,0,0,110,90,56,48,66,97,110,107,49,0,0,0,0,0,0,0,109,100,95,97,105,114,98,117,115,116,114,0,0,0,0,0,115,101,99,116,105,111,110,122,0,0,0,0,0,0,0,0,83,101,115,97,109,101,32,83,116,114,101,101,116,32,67,111,117,110,116,105,110,103,32,67,97,102,101,32,40,85,83,65,41,0,0,0,0,0,0,0,109,100,95,115,101,115,97,109,101,0,0,0,0,0,0,0,115,102,97,114,49,0,0,0,79,80,76,45,62,84,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,111,118,101,114,108,97,121,115,32,118,97,114,105,97,98,108,101,32,110,111,116,32,100,101,102,105,110,101,100,32,105,110,32,99,111,110,102,105,103,46,10,0,0,83,101,110,115,105,98,108,101,32,83,111,99,99,101,114,32,45,32,73,110,116,101,114,110,97,116,105,111,110,97,108,32,69,100,105,116,105,111,110,32,40,69,117,114,111,41,0,0,66,111,110,103,111,0,0,0,82,101,116,114,111,65,114,99,104,58,32,76,111,97,100,105,110,103,32,116,101,120,116,117,114,101,32,105,109,97,103,101,32,102,114,111,109,58,32,34,37,115,34,32,46,46,46,10,0,0,0,0,0,0,0,0,109,100,95,115,101,110,115,105,98,105,101,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,71,76,58,32,73,110,118,97,108,105,100,32,111,112,101,114,97,116,105,111,110,46,10,0,0,0,0,83,101,110,115,105,98,108,101,32,83,111,99,99,101,114,32,40,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,77,111,117,115,101,0,0,0,83,112,108,97,116,116,101,114,104,111,117,115,101,32,80,97,114,116,32,50,32,40,74,112,110,41,0,0,0,0,0,0,109,100,95,115,101,110,115,105,98,108,101,112,0,0,0,0,109,97,104,32,104,0,0,0,99,102,103,0,0,0,0,0,115,104,97,50,53,54,0,0,82,101,112,108,97,121,32,49,53,48,48,48,48,48,0,0,51,48,107,32,32,56,48,107,32,49,54,48,107,0,0,0,82,101,110,101,103,97,100,101,0,0,0,0,0,0,0,0,51,32,73,110,110,105,110,103,0,0,0,0,0,0,0,0,83,101,110,115,105,98,108,101,32,83,111,99,99,101,114,32,40,69,117,114,111,41,0,0,102,105,108,116,101,114,95,108,105,110,101,97,114,37,117,0,84,104,101,32,70,105,110,97,108,32,82,111,117,110,100,32,40,118,101,114,46,32,76,41,0,0,0,0,0,0,0,0,60,47,37,115,62,0,0,0,109,100,95,115,101,110,115,105,98,108,101,0,0,0,0,0,65,114,109,111,114,101,100,32,87,97,114,114,105,111,114,115,32,40,57,52,48,57,50,48,32,85,83,65,41,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,32,45,32,84,104,101,32,87,111,114,108,100,32,87,97,114,114,105,111,114,32,40,84,104,117,110,100,101,114,32,69,100,105,116,105,111,110,32,98,111,111,116,108,101,103,44,32,57,49,48,50,49,52,32,101,116,99,41,0,0,0,0,0,52,48,75,32,57,48,75,0,112,99,101,95,107,108,97,120,0,0,0,0,0,0,0,0,99,116,50,107,51,115,97,0,83,101,103,97,32,84,111,112,32,70,105,118,101,32,40,66,114,97,41,0,0,0,0,0,68,101,110,112,97,32,83,104,105,110,98,117,110,115,104,97,0,0,0,0,0,0,0,0,84,97,109,116,101,120,0,0,108,100,114,117,110,52,0,0,109,100,95,115,101,103,97,116,111,112,0,0,0,0,0,0,53,32,67,111,105,110,115,32,50,32,80,108,97,121,115,0,67,114,111,115,115,32,66,108,97,100,101,115,33,32,40,74,97,112,97,110,41,0,0,0,109,121,115,116,115,116,111,110,0,0,0,0,0,0,0,0,83,101,103,97,32,83,112,111,114,116,115,32,49,32,40,69,117,114,111,41,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,65,108,112,104,97,32,45,32,119,97,114,114,105,111,114,115,39,32,100,114,101,97,109,115,32,40,57,53,48,55,50,55,32,69,117,114,111,41,0,0,0,82,101,116,114,111,65,114,99,104,58,32,9,68,101,115,99,114,105,112,116,105,111,110,58,32,37,115,10,0,0,0,0,109,100,95,115,101,103,97,115,112,114,116,0,0,0,0,0,98,111,110,103,111,0,0,0,84,104,101,32,83,101,99,111,110,100,32,83,97,109,117,114,97,105,32,40,69,117,114,111,41,0,0,0,0,0,0,0,109,100,95,115,101,99,111,110,100,115,0,0,0,0,0,0,83,101,97,81,117,101,115,116,32,68,83,86,32,40,85,83,65,41,0,0,0,0,0,0,77,97,104,106,111,110,103,32,72,0,0,0,0,0,0,0,82,101,112,108,97,121,32,49,50,48,48,48,48,48,0,0,49,53,107,32,51,48,107,32,54,48,107,0,0,0,0,0,109,100,95,115,101,97,113,117,101,115,116,117,0,0,0,0,83,101,97,81,117,101,115,116,32,68,83,86,32,40,69,117,114,111,41,0,0,0,0,0,73,109,112,101,114,102,101,99,116,32,115,111,117,110,100,32,97,110,100,32,103,114,97,112,104,105,99,115,0,0,0,0,109,100,95,115,101,97,113,117,101,115,116,0,0,0,0,0,115,102,50,116,104,110,100,114,0,0,0,0,0,0,0,0,50,48,48,57,0,0,0,0,75,105,110,103,32,111,102,32,67,97,115,105,110,111,0,0,67,0,0,0,114,0,0,0,111,0,0,0,117,0,0,0,99,0,0,0,104,0,0,0,105,0,0,0,110,0,0,0,103,0,0,0,32,0,0,0,84,0,0,0,105,0,0,0,103,0,0,0,101,0,0,0,114,0,0,0,32,0,0,0,72,0,0,0,105,0,0,0,100,0,0,0,100,0,0,0,101,0,0,0,110,0,0,0,32,0,0,0,68,0,0,0,114,0,0,0,97,0,0,0,103,0,0,0,111,0,0,0,110,0,0,0,32,0,0,0,50,0,0,0,48,0,0,0,48,0,0,0,51,0,0,0,32,0,0,0,83,0,0,0,117,0,0,0,112,0,0,0,101,0,0,0,114,0,0,0,32,0,0,0,80,0,0,0,108,0,0,0,117,0,0,0,115,0,0,0,0,0,0,0,229,129,0,0,78,134,0,0,207,133,0,0,141,159,0,0,0,0,0,0,0,0,0,0,83,99,114,97,98,98,108,101,32,40,69,117,114,111,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,65,102,116,101,114,32,66,117,114,110,101,114,32,73,73,32,40,74,112,110,41,0,0,0,109,100,95,115,99,114,97,98,98,108,101,0,0,0,0,0,97,116,101,116,114,105,115,0,83,99,111,111,98,121,45,68,111,111,32,77,121,115,116,101,114,121,32,40,85,83,65,41,0,0,0,0,0,0,0,0,115,102,97,0,0,0,0,0,109,100,95,115,99,111,111,98,121,0,0,0,0,0,0,0,76,101,118,101,114,115,0,0,68,97,109,98,117,115,116,114,66,103,80,114,105,111,114,105,116,121,0,0,0,0,0,0,83,97,116,117,114,100,97,121,32,78,105,103,104,116,32,83,108,97,109,109,97,115,116,101,114,115,32,40,85,83,65,41,0,0,0,0,0,0,0,0,109,100,95,115,108,97,109,109,97,115,116,117,0,0,0,0,83,97,116,117,114,100,97,121,32,78,105,103,104,116,32,83,108,97,109,109,97,115,116,101,114,115,32,40,69,117,114,111,41,0,0,0,0,0,0,0,115,108,45,62,102,98,95,115,104,105,102,116,0,0,0,0,109,97,104,32,103,0,0,0,82,101,112,108,97,121,32,49,48,48,48,48,48,48,0,0,49,48,107,32,50,53,107,32,53,48,107,0,0,0,0,0,109,100,95,115,108,97,109,109,97,115,116,0,0,0,0,0,83,97,110,103,111,107,117,115,104,105,32,82,101,116,115,117,100,101,110,32,45,32,82,97,110,115,101,105,32,110,111,32,69,105,121,117,117,116,97,99,104,105,32,40,74,112,110,41,0,0,0,0,0,0,0,0,83,97,110,32,83,97,110,32,67,111,46,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,32,45,32,84,104,101,32,87,111,114,108,100,32,87,97,114,114,105,111,114,32,40,81,117,105,99,107,101,110,32,80,116,45,73,32,98,111,111,116,108,101,103,44,32,57,49,48,50,49,52,32,85,83,65,41,0,0,0,0,0,0,0,0,112,99,101,95,107,105,110,103,99,97,115,110,0,0,0,0,67,114,111,117,99,104,105,110,103,32,84,105,103,101,114,32,72,105,100,100,101,110,32,68,114,97,103,111,110,32,50,48,48,51,32,83,117,112,101,114,32,80,108,117,115,0,0,0,83,97,110,32,83,97,110,32,40,74,112,110,41,0,0,0,109,100,95,97,98,117,114,110,101,114,50,106,0,0,0,0,109,100,95,115,97,110,115,97,110,0,0,0,0,0,0,0,82,50,32,98,117,116,116,111,110,32,40,116,114,105,103,103,101,114,41,0,0,0,0,0,83,75,79,66,0,0,0,0,82,105,110,103,32,111,102,32,68,101,115,116,114,117,99,116,105,111,110,32,45,32,115,108,97,109,109,97,115,116,101,114,115,32,73,73,32,40,57,52,48,56,51,49,32,65,115,105,97,41,0,0,0,0,0,0,83,97,110,32,71,117,111,32,90,104,105,32,86,32,40,67,104,105,41,0,0,0,0,0,108,101,118,101,114,115,0,0,109,100,95,115,97,110,103,117,111,53,0,0,0,0,0,0,83,97,110,32,71,117,111,32,90,104,105,32,76,105,101,32,90,104,117,97,110,32,45,32,76,117,97,110,32,83,104,105,32,81,117,110,32,89,105,110,103,32,40,67,104,105,41,0,0,0,0,0,0,0,0,0,109,100,95,115,97,110,103,111,114,101,116,0,0,0,0,0,77,97,104,106,111,110,103,32,71,0,0,0,0,0,0,0,82,101,112,108,97,121,32,50,48,48,48,48,48,48,47,52,48,48,48,48,48,48,0,0,32,53,107,32,50,48,107,32,51,48,107,0,0,0,0,0,109,100,95,115,97,110,103,117,111,0,0,0,0,0,0,0,83,97,109,117,114,97,105,32,83,112,105,114,105,116,115,32,40,74,112,110,41,0,0,0,115,119,97,114,109,0,0,0,109,100,95,115,97,109,115,112,105,114,0,0,0,0,0,0,115,102,50,113,112,49,0,0,75,0,0,0,110,0,0,0,105,0,0,0,103,0,0,0,104,0,0,0,116,0,0,0,115,0,0,0,32,0,0,0,111,0,0,0,102,0,0,0,32,0,0,0,86,0,0,0,97,0,0,0,108,0,0,0,111,0,0,0,117,0,0,0,114,0,0,0,58,0,0,0,32,0,0,0,81,0,0,0,117,0,0,0,97,0,0,0,110,0,0,0,32,0,0,0,72,0,0,0,117,0,0,0,97,0,0,0,110,0,0,0,103,0,0,0,32,0,0,0,83,0,0,0,97,0,0,0,110,0,0,0,32,0,0,0,71,0,0,0,117,0,0,0,111,0,0,0,32,0,0,0,83,0,0,0,112,0,0,0,101,0,0,0,99,0,0,0,105,0,0,0,97,0,0,0,108,0,0,0,0,0,0,0,9,78,0,0,253,86,0,0,24,98,0,0,170,126,0,0,0,0,0,0,243,98,0,0,135,118,0,0,9,78,0,0,253,86,0,0,121,114,0,0,43,82,0,0,72,114,0,0,32,0,0,0,40,0,0,0,97,0,0,0,108,0,0,0,116,0,0,0,32,0,0,0,118,0,0,0,101,0,0,0,114,0,0,0,46,0,0,0,32,0,0,0,51,0,0,0,48,0,0,0,51,0,0,0,67,0,0,0,78,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,75,105,107,105,32,75,97,105,75,97,105,0,0,0,0,0,99,116,50,107,51,115,112,0,83,97,109,117,114,97,105,32,83,104,111,100,111,119,110,32,40,85,83,65,41,0,0,0,65,102,116,101,114,32,66,117,114,110,101,114,32,73,73,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,101,100,114,97,110,100,121,49,0,0,0,0,0,0,0,0,109,100,95,115,97,109,115,104,111,117,0,0,0,0,0,0,83,97,109,117,114,97,105,32,83,104,111,100,111,119,110,32,40,69,117,114,111,41,0,0,114,105,110,103,100,101,115,116,97,0,0,0,0,0,0,0,109,100,95,115,97,109,115,104,111,0,0,0,0,0,0,0,74,117,109,112,32,66,117,103,32,40,98,111,111,116,108,101,103,41,0,0,0,0,0,0,72,97,114,100,32,40,55,48,41,0,0,0,0,0,0,0,80,101,116,101,32,83,97,109,112,114,97,115,32,84,101,110,110,105,115,32,39,57,54,32,40,69,117,114,111,44,32,74,45,67,97,114,116,41,0,0,109,100,95,115,97,109,112,114,97,57,54,0,0,0,0,0,106,97,99,107,0,0,0,0,83,97,105,110,116,32,83,119,111,114,100,32,40,74,112,110,41,0,0,0,0,0,0,0,109,97,104,32,102,0,0,0,82,101,112,108,97,121,32,49,53,48,48,48,48,48,47,51,48,48,48,48,48,48,0,0,109,100,95,115,115,119,111,114,100,106,0,0,0,0,0,0,83,97,105,110,116,32,83,119,111,114,100,32,40,85,83,65,41,0,0,0,0,0,0,0,109,100,95,115,115,119,111,114,100,0,0,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,32,45,32,84,104,101,32,87,111,114,108,100,32,87,97,114,114,105,111,114,32,40,57,50,48,51,49,50,32,74,97,112,97,110,41,0,0,0,0,75,110,105,103,104,116,115,32,111,102,32,86,97,108,111,117,114,58,32,81,117,97,110,32,72,117,97,110,103,32,83,97,110,32,71,117,111,32,83,112,101,99,105,97,108,32,47,32,83,97,110,103,111,107,117,32,83,101,110,107,105,58,32,81,117,97,110,32,72,117,97,110,103,32,83,97,110,32,71,117,111,32,83,112,101,99,105,97,108,32,40,97,108,116,32,118,101,114,46,32,51,48,51,67,78,41,0,0,0,0,0,0,112,99,101,95,107,105,107,105,107,97,105,0,0,0,0,0,80,104,101,110,105,120,115,111,102,116,0,0,0,0,0,0,66,105,115,104,111,117,106,111,32,83,101,110,115,104,105,32,83,97,105,108,111,114,32,77,111,111,110,32,40,74,112,110,41,0,0,0,0,0,0,0,109,100,95,97,98,117,114,110,101,114,50,0,0,0,0,0,109,100,95,115,97,105,108,111,114,109,110,0,0,0,0,0,76,51,0,0,0,0,0,0,68,97,114,105,117,115,32,73,73,32,40,74,112,110,41,0,0,0,0,0,0,0,0,0,83,117,112,101,114,32,77,117,115,99,108,101,32,66,111,109,98,101,114,32,45,32,116,104,101,32,105,110,116,101,114,110,97,116,105,111,110,97,108,32,98,108,111,119,111,117,116,32,40,57,52,48,56,48,56,32,74,97,112,97,110,41,0,0,109,100,95,100,97,114,105,117,115,50,0,0,0,0,0,0,106,117,109,112,98,117,103,98,0,0,0,0,0,0,0,0,83,97,103,97,105,97,32,40,85,83,65,41,0,0,0,0,109,100,95,115,97,103,97,105,97,0,0,0,0,0,0,0,82,117,103,98,121,32,87,111,114,108,100,32,67,117,112,32,49,57,57,53,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,0,0,77,97,104,106,111,110,103,32,70,0,0,0,0,0,0,0,82,101,112,108,97,121,32,49,50,48,48,48,48,48,47,50,53,48,48,48,48,48,0,0,55,48,107,44,32,49,53,48,107,0,0,0,0,0,0,0,109,100,95,114,117,103,98,121,119,99,0,0,0,0,0,0,83,97,110,103,111,107,117,115,104,105,32,73,73,73,32,40,74,112,110,41,0,0,0,0,109,100,95,115,97,110,103,111,107,117,51,0,0,0,0,0,115,102,50,106,108,0,0,0,75,105,99,107,98,97,108,108,0,0,0,0,0,0,0,0,109,101,103,97,100,111,110,0,72,97,99,107,32,111,102,32,34,84,104,101,32,75,105,110,103,32,111,102,32,70,105,103,104,116,101,114,115,32,50,48,48,49,34,0,0,0,0,0,82,111,109,97,110,99,101,32,111,102,32,116,104,101,32,84,104,114,101,101,32,75,105,110,103,100,111,109,115,32,73,73,73,32,45,32,68,114,97,103,111,110,32,111,102,32,68,101,115,116,105,110,121,32,40,85,83,65,41,0,0,0,0,0,65,105,114,32,77,97,110,97,103,101,109,101,110,116,32,73,73,32,45,32,75,111,117,107,117,117,111,117,32,111,32,77,101,122,97,115,101,32,40,74,112,110,41,0,0,0,0,0,80,49,32,80,105,110,0,0,109,100,95,114,111,109,97,110,51,107,51,0,0,0,0,0,83,97,110,103,111,107,117,115,104,105,32,73,73,32,40,74,112,110,41,0,0,0,0,0,115,109,98,111,109,98,114,49,0,0,0,0,0,0,0,0,77,54,56,48,48,67,80,85,67,111,110,116,101,120,116,91,105,93,46,110,67,121,99,108,101,115,76,101,102,116,0,0,71,97,101,108,99,111,0,0,50,32,99,111,105,110,115,32,49,32,99,114,101,100,105,116,0,0,0,0,0,0,0,0,70,105,120,69,105,103,104,116,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,66,32,40,110,111,114,109,97,108,41,0,0,0,0,0,0,109,100,95,115,97,110,103,111,107,117,50,0,0,0,0,0,83,108,97,112,32,70,105,103,104,116,32,40,98,111,111,116,108,101,103,32,115,101,116,32,49,41,0,0,0,0,0,0,82,111,99,107,45,111,108,97,0,0,0,0,0,0,0,0,68,105,112,32,83,119,105,116,99,104,32,68,105,115,112,108,97,121,0,0,0,0,0,0,82,111,109,97,110,99,101,32,111,102,32,116,104,101,32,84,104,114,101,101,32,75,105,110,103,100,111,109,115,32,73,73,32,40,85,83,65,41,0,0,109,100,95,114,111,109,97,110,51,107,50,0,0,0,0,0,53,48,48,48,48,44,32,101,118,101,114,121,32,49,53,48,48,48,48,0,0,0,0,0,90,111,117,33,32,90,111,117,33,32,90,111,117,33,32,82,101,115,99,117,101,32,68,97,105,115,97,107,117,115,101,110,32,40,74,112,110,41,0,0,102,102,97,110,116,97,115,121,97,0,0,0,0,0,0,0,109,97,104,32,101,0,0,0,100,114,105,102,116,111,117,116,0,0,0,0,0,0,0,0,82,101,112,108,97,121,32,49,48,48,48,48,48,48,47,50,48,48,48,48,48,48,0,0,54,48,107,44,32,49,50,48,107,0,0,0,0,0,0,0,109,100,95,122,111,117,122,111,117,0,0,0,0,0,0,0,53,47,51,0,0,0,0,0,107,97,103,101,107,105,0,0,97,114,107,97,110,103,99,50,0,0,0,0,0,0,0,0,52,48,107,32,97,110,100,32,101,118,101,114,121,32,49,48,48,107,0,0,0,0,0,0,82,111,108,111,32,116,111,32,116,104,101,32,82,101,115,99,117,101,32,40,69,117,114,111,44,32,85,83,65,41,0,0,99,114,105,109,101,99,106,0,99,111,110,116,99,105,114,99,117,0,0,0,0,0,0,0,109,100,95,114,111,108,111,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,32,45,32,84,104,101,32,87,111,114,108,100,32,87,97,114,114,105,111,114,32,40,57,49,48,53,50,50,32,74,97,112,97,110,41,0,0,0,0,75,0,0,0,110,0,0,0,105,0,0,0,103,0,0,0,104,0,0,0,116,0,0,0,115,0,0,0,32,0,0,0,111,0,0,0,102,0,0,0,32,0,0,0,86,0,0,0,97,0,0,0,108,0,0,0,111,0,0,0,117,0,0,0,114,0,0,0,58,0,0,0,32,0,0,0,81,0,0,0,117,0,0,0,97,0,0,0,110,0,0,0,32,0,0,0,72,0,0,0,117,0,0,0,97,0,0,0,110,0,0,0,103,0,0,0,32,0,0,0,83,0,0,0,97,0,0,0,110,0,0,0,32,0,0,0,71,0,0,0,117,0,0,0,111,0,0,0,32,0,0,0,83,0,0,0,112,0,0,0,101,0,0,0,99,0,0,0,105,0,0,0,97,0,0,0,108,0,0,0,0,0,0,0,9,78,0,0,253,86,0,0,24,98,0,0,170,126,0,0,0,0,0,0,243,98,0,0,135,118,0,0,9,78,0,0,253,86,0,0,121,114,0,0,43,82,0,0,72,114,0,0,32,0,0,0,40,0,0,0,118,0,0,0,101,0,0,0,114,0,0,0,46,0,0,0,32,0,0,0,51,0,0,0,48,0,0,0,51,0,0,0,67,0,0,0,78,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,99,101,95,107,105,99,107,98,97,108,108,0,0,0,0,67,114,111,117,99,104,105,110,103,32,84,105,103,101,114,32,72,105,100,100,101,110,32,68,114,97,103,111,110,32,50,48,48,51,32,40,115,101,116,32,49,41,0,0,0,0,0,0,66,117,98,98,108,101,32,66,111,98,98,108,101,32,76,111,115,116,32,67,97,118,101,32,40,118,49,46,48,41,0,0,82,111,108,108,105,110,103,32,84,104,117,110,100,101,114,32,51,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,109,100,95,97,105,114,109,97,110,103,50,0,0,0,0,0,84,117,114,98,111,32,79,117,116,32,82,117,110,32,40,100,101,108,117,120,101,32,99,111,99,107,112,105,116,44,32,70,68,49,48,57,52,32,51,49,55,45,48,49,48,57,41,0,0,0,0,0,0,0,0,0,109,100,95,114,116,104,117,110,51,0,0,0,0,0,0,0,106,111,106,111,0,0,0,0,97,108,116,98,101,97,115,116,98,108,0,0,0,0,0,0,83,121,115,116,101,109,49,56,86,100,112,69,110,97,98,108,101,0,0,0,0,0,0,0,82,111,108,108,105,110,103,32,84,104,117,110,100,101,114,32,50,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,83,117,112,101,114,32,77,117,115,99,108,101,32,66,111,109,98,101,114,32,45,32,116,104,101,32,105,110,116,101,114,110,97,116,105,111,110,97,108,32,98,108,111,119,111,117,116,32,40,57,52,48,56,51,49,32,74,97,112,97,110,41,0,0,103,97,114,100,105,97,0,0,100,101,115,101,114,116,98,114,0,0,0,0,0,0,0,0,109,100,95,114,116,104,117,110,50,117,0,0,0,0,0,0,74,117,109,112,32,66,117,103,0,0,0,0,0,0,0,0,82,111,108,108,105,110,103,32,84,104,117,110,100,101,114,32,50,32,40,74,112,110,41,0,0,0,0,0,0,0,0,0,97,115,112,101,99,116,95,114,97,116,105,111,95,105,110,100,101,120,0,0,0,0,0,0,70,97,110,116,97,115,121,32,90,111,110,101,32,40,51,49,55,45,53,48,48,48,41,0,0,0,0,0,0,0,0,0,102,108,97,103,0,0,0,0,68,101,109,111,95,83,111,117,110,100,115,0,0,0,0,0,77,105,108,108,101,32,77,105,103,108,105,97,32,50,58,32,71,114,101,97,116,32,49,48,48,48,32,77,105,108,101,115,32,82,97,108,108,121,32,40,57,53,47,48,53,47,50,52,41,0,0,0,0,0,0,0,109,100,95,114,116,104,117,110,50,106,0,0,0,0,0,0,82,111,108,108,105,110,103,32,84,104,117,110,100,101,114,32,50,32,40,69,117,114,111,41,0,0,0,0,0,0,0,0,77,97,104,106,111,110,103,32,69,0,0,0,0,0,0,0,54,32,67,111,105,110,115,32,49,32,67,114,101,100,105,116,0,0,0,0,0,0,0,0,66,111,110,117,115,0,0,0,53,48,107,44,32,49,48,48,107,0,0,0,0,0,0,0,109,100,95,114,116,104,117,110,50,0,0,0,0,0,0,0,98,105,103,98,97,110,103,0,86,101,114,121,32,101,97,115,121,0,0,0,0,0,0,0,77,111,98,105,108,101,32,83,117,105,116,32,71,117,110,100,97,109,32,69,88,32,82,101,118,117,101,0,0,0,0,0,82,111,103,101,114,32,67,108,101,109,101,110,116,115,32,77,86,80,32,66,97,115,101,98,97,108,108,32,40,85,83,65,41,0,0,0,0,0,0,0,109,100,95,109,118,112,98,98,0,0,0,0,0,0,0,0,80,111,105,110,116,115,32,116,111,32,87,105,110,0,0,0,115,102,50,106,104,0,0,0,75,110,105,103,104,116,115,32,111,102,32,86,97,108,111,117,114,58,32,81,117,97,110,32,72,117,97,110,103,32,83,97,110,32,71,117,111,32,83,112,101,99,105,97,108,32,47,32,83,97,110,103,111,107,117,32,83,101,110,107,105,58,32,81,117,97,110,32,72,117,97,110,103,32,83,97,110,32,71,117,111,32,83,112,101,99,105,97,108,32,40,118,101,114,46,32,51,48,51,67,78,41,0,0,102,97,110,116,115,105,97,50,97,0,0,0,0,0,0,0,75,97,116,116,111,98,105,33,32,84,97,107,117,104,97,105,32,75,117,110,0,0,0,0,70,114,101,101,32,80,108,97,121,32,40,105,102,32,67,111,105,110,32,66,32,116,111,111,41,0,0,0,0,0,0,0,112,111,119,0,0,0,0,0,82,111,99,107,101,116,32,75,110,105,103,104,116,32,65,100,118,101,110,116,117,114,101,115,32,40,85,83,65,41,0,0,115,97,105,108,111,114,109,110,111,107,0,0,0,0,0,0,66,48,48,48,48,48,32,82,101,103,105,115,116,101,114,115,0,0,0,0,0,0,0,0,65,101,114,111,98,105,122,32,83,117,112,101,114,115,111,110,105,99,32,40,85,83,65,41,0,0,0,0,0,0,0,0,53,48,48,107,32,49,48,48,48,107,0,0,0,0,0,0,109,100,95,114,111,99,107,101,116,117,0,0,0,0,0,0,65,101,114,111,32,70,105,103,104,116,101,114,115,32,40,84,117,114,98,111,32,70,111,114,99,101,32,104,97,114,100,119,97,114,101,32,115,101,116,32,50,41,0,0,0,0,0,0,69,114,111,103,97,116,111,114,101,32,84,105,99,107,101,116,0,0,0,0,0,0,0,0,67,111,110,116,105,110,117,101,32,68,105,115,99,111,117,110,116,0,0,0,0,0,0,0,82,111,99,107,101,116,32,75,110,105,103,104,116,32,65,100,118,101,110,116,117,114,101,115,32,40,74,112,110,41,0,0,115,109,98,111,109,98,0,0,82,101,116,114,111,65,114,99,104,58,32,65,118,101,114,97,103,101,32,97,117,100,105,111,32,98,117,102,102,101,114,32,115,97,116,117,114,97,116,105,111,110,58,32,37,46,50,102,32,37,37,44,32,115,116,97,110,100,97,114,100,32,100,101,118,105,97,116,105,111,110,32,40,112,101,114,99,101,110,116,97,103,101,32,112,111,105,110,116,115,41,58,32,37,46,50,102,32,37,37,46,10,0,0,100,97,105,111,104,97,0,0,109,100,95,114,111,99,107,101,116,106,0,0,0,0,0,0,77,111,100,101,32,83,101,108,101,99,116,0,0,0,0,0,106,117,109,112,98,117,103,0,80,117,122,122,108,101,32,75,105,110,103,0,0,0,0,0,67,104,111,107,121,33,32,67,104,111,107,121,33,0,0,0,82,111,99,107,101,116,32,75,110,105,103,104,116,32,65,100,118,101,110,116,117,114,101,115,32,40,69,117,114,111,41,0,0,0,0,0,0,0,0,0,83,116,114,105,107,101,114,115,32,49,57,52,53,32,40,65,108,116,41,0,0,0,0,0,109,100,95,114,111,99,107,101,116,0,0,0,0,0,0,0,49,48,107,32,32,54,48,107,32,32,54,48,107,0,0,0,97,122,116,97,114,97,99,0,82,111,99,107,32,110,39,32,82,111,108,108,32,82,97,99,105,110,103,32,40,85,83,65,41,0,0,0,0,0,0,0,80,97,110,103,32,40,98,111,111,116,108,101,103,44,32,115,101,116,32,49,41,0,0,0,49,67,32,50,67,32,47,32,49,67,32,53,67,0,0,0,109,97,104,32,100,0,0,0,50,48,48,48,48,32,52,48,48,48,48,0,0,0,0,0,65,32,49,45,49,32,66,32,49,45,49,0,0,0,0,0,72,97,114,100,43,53,0,0,80,108,97,121,101,114,115,0,109,100,95,114,110,114,114,97,99,105,110,117,0,0,0,0,112,97,99,117,109,97,110,0,71,97,117,110,116,108,101,116,32,40,114,101,118,32,49,41,0,0,0,0,0,0,0,0,82,111,99,107,32,110,39,32,82,111,108,108,32,82,97,99,105,110,103,32,40,69,117,114,111,41,0,0,0,0,0,0,109,100,95,114,110,114,114,97,99,105,110,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,32,45,32,84,104,101,32,87,111,114,108,100,32,87,97,114,114,105,111,114,32,40,57,49,48,52,49,49,32,74,97,112,97,110,41,0,0,0,0,112,99,101,95,107,97,116,116,111,98,105,0,0,0,0,0,99,116,104,100,50,48,48,51,0,0,0,0,0,0,0,0,82,111,98,111,116,32,87,114,101,99,107,97,103,101,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,0,0,0,109,100,95,97,101,114,111,98,105,122,115,0,0,0,0,0,65,118,101,110,103,101,114,115,32,40,85,83,32,115,101,116,32,50,41,0,0,0,0,0,109,100,95,114,111,98,111,119,114,101,107,0,0,0,0,0,84,114,105,45,80,111,111,108,32,40,67,111,115,116,97,108,32,71,97,109,101,115,41,0,0,0,0,0,0,0,0,0,50,32,40,70,111,114,101,115,116,32,49,41,0,0,0,0,68,114,118,83,112,114,105,116,101,115,79,110,0,0,0,0,82,111,98,111,116,32,66,97,116,116,108,101,114,32,40,74,112,110,44,32,83,101,103,97,78,101,116,41,0,0,0,0,82,105,110,103,32,111,102,32,68,101,115,116,114,117,99,116,105,111,110,32,45,32,115,108,97,109,109,97,115,116,101,114,115,32,73,73,32,40,57,52,48,57,48,50,32,69,117,114,111,41,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,112,97,116,99,104,32,37,115,58,32,69,114,114,111,114,32,35,37,117,10,0,0,0,0,0,109,100,95,114,111,98,111,116,98,97,116,0,0,0,0,0,32,49,32,67,111,105,110,32,32,50,32,67,114,101,100,105,116,115,0,0,0,0,0,0,65,32,49,47,50,32,66,32,49,47,52,0,0,0,0,0,49,32,67,111,105,110,32,32])
.concat([50,32,67,114,101,100,105,116,115,32,47,32,49,32,67,111,105,110,32,32,49,49,32,67,114,101,100,105,116,115,0,0,82,111,98,111,67,111,112,32,118,101,114,115,117,115,32,84,104,101,32,84,101,114,109,105,110,97,116,111,114,32,40,85,83,65,41,0,0,0,0,0,109,100,95,114,111,98,111,116,101,114,109,117,0,0,0,0,109,95,107,98,95,112,114,111,116,95,104,105,108,111,0,0,82,111,98,111,99,111,112,32,86,101,114,115,117,115,32,84,104,101,32,84,101,114,109,105,110,97,116,111,114,32,40,80,114,111,116,111,116,121,112,101,44,32,65,108,116,41,0,0,45,78,0,0,11,87,0,0,141,159,0,0,32,0,0,0,73,0,0,0,73,0,0,0,32,0,0,0,40,0,0,0,86,0,0,0,49,0,0,0,48,0,0,0,48,0,0,0,74,0,0,0,44,0,0,0,32,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,77,97,104,106,111,110,103,32,68,0,0,0,0,0,0,0,72,97,114,100,43,52,0,0,77,97,120,105,109,117,109,32,67,114,101,100,105,116,0,0,109,100,95,114,111,98,111,116,101,114,109,112,49,0,0,0,82,111,98,111,67,111,112,32,118,101,114,115,117,115,32,84,104,101,32,84,101,114,109,105,110,97,116,111,114,32,40,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,0,80,97,99,107,45,73,110,45,86,105,100,101,111,0,0,0,109,100,95,114,111,98,111,116,101,114,109,112,0,0,0,0,115,102,50,106,102,0,0,0,98,108,97,115,116,97,114,64,103,109,120,46,110,101,116,0,75,97,116,111,32,67,104,97,110,32,38,32,75,101,110,32,67,104,97,110,0,0,0,0,99,97,112,116,99,111,109,109,106,0,0,0,0,0,0,0,84,104,101,32,75,105,110,103,32,111,102,32,70,105,103,104,116,101,114,115,32,50,48,48,49,32,40,78,71,72,45,50,54,50,49,41,0,0,0,0,82,111,98,111,67,111,112,32,118,101,114,115,117,115,32,84,104,101,32,84,101,114,109,105,110,97,116,111,114,32,40,74,112,110,44,32,75,111,114,41,0,0,0,0,0,0,0,0,110,90,56,48,66,97,110,107,48,0,0,0,0,0,0,0,65,105,114,32,77,97,110,97,103,101,109,101,110,116,32,45,32,79,111,122,111,114,97,32,110,105,32,75,97,107,101,114,117,32,40,74,112,110,41,0,0,0,0,0,0,0,0,0,109,100,95,114,111,98,111,116,101,114,109,106,0,0,0,0,82,111,98,111,67,111,112,32,118,101,114,115,117,115,32,84,104,101,32,84,101,114,109,105,110,97,116,111,114,32,40,69,117,114,111,41,0,0,0,0,114,105,110,103,100,101,115,116,0,0,0,0,0,0,0,0,79,80,76,45,62,119,97,118,101,115,101,108,0,0,0,0,109,100,95,114,111,98,111,116,101,114,109,0,0,0,0,0,82,111,99,107,32,67,108,105,109,98,101,114,0,0,0,0,114,117,98,121,0,0,0,0,82,111,98,111,67,111,112,32,51,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,71,76,58,32,73,110,118,97,108,105,100,32,118,97,108,117,101,46,10,0,0,0,0,0,0,0,0,99,111,109,109,97,110,100,111,0,0,0,0,0,0,0,0,109,100,95,114,111,98,111,99,111,112,51,0,0,0,0,0,77,117,108,116,105,116,97,112,0,0,0,0,0,0,0,0,109,100,95,115,112,108,97,116,116,104,50,0,0,0,0,0,82,111,97,100,66,108,97,115,116,101,114,115,32,40,74,112,110,41,0,0,0,0,0,0,109,97,104,32,99,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,67,97,110,110,111,116,32,105,110,102,101,114,32,110,101,119,32,99,111,110,102,105,103,32,112,97,116,104,46,32,85,115,101,32,99,117,114,114,101,110,116,32,116,105,109,101,46,10,0,0,0,0,72,97,114,100,43,51,0,0,52,48,107,44,32,116,104,101,110,32,101,118,101,114,121,32,51,48,107,0,0,0,0,0,109,100,95,114,111,97,100,98,108,115,116,106,0,0,0,0,50,32,73,110,110,105,110,103,0,0,0,0,0,0,0,0,82,111,97,100,66,108,97,115,116,101,114,115,32,40,85,83,65,41,0,0,0,0,0,0,115,104,97,100,101,114,37,117,0,0,0,0,0,0,0,0,102,114,111,117,110,100,108,0,109,100,95,114,111,97,100,98,108,115,116,0,0,0,0,0,97,114,109,119,97,114,117,49,0,0,0,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,32,45,32,84,104,101,32,87,111,114,108,100,32,87,97,114,114,105,111,114,32,40,57,49,48,51,48,54,32,74,97,112,97,110,41,0,0,0,0,80,45,71,101,77,101,110,105,32,40,48,54,48,49,50,51,41,0,0,0,0,0,0,0,112,99,101,95,107,97,116,111,99,104,97,110,0,0,0,0,107,111,102,50,48,48,49,104,0,0,0,0,0,0,0,0,97,110,97,108,111,103,95,114,105,103,104,116,0,0,0,0,82,111,97,100,32,51,32,82,97,115,104,32,45,32,87,111,114,108,100,32,87,97,114,114,105,111,114,115,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,109,100,95,97,105,114,109,97,110,97,103,0,0,0,0,0,67,117,101,32,66,114,105,99,107,32,40,87,111,114,108,100,32,118,101,114,46,32,68,41,0,0,0,0,0,0,0,0,77,97,116,99,104,32,73,116,32,73,73,0,0,0,0,0,76,111,100,101,32,82,117,110,110,101,114,32,73,73,73,32,45,32,77,97,106,105,110,32,78,111,32,70,117,107,107,97,116,115,117,0,0,0,0,0,109,100,95,114,114,97,115,104,51,112,0,0,0,0,0,0,99,114,111,115,115,98,108,100,0,0,0,0,0,0,0,0,82,111,97,100,32,51,32,82,97,115,104,32,45,32,84,111,117,114,32,100,101,32,70,111,114,99,101,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,0,0,0,81,0,0,0,117,0,0,0,105,0,0,0,122,0,0,0,32,0,0,0,106,48,0,0,106,48,0,0,68,48,0,0,141,48,0,0,32,0,0,0,68,0,0,0,114,0,0,0,101,0,0,0,97,0,0,0,109,0,0,0,115,0,0,0,32,0,0,0,45,0,0,0,32,0,0,0,121,134,0,0,114,130,0,0,58,117,0,0,110,48,0,0,71,89,0,0,225,141,0,0,32,0,0,0,40,0,0,0,78,0,0,0,97,0,0,0,110,0,0,0,97,0,0,0,105,0,0,0,114,0,0,0,111,0,0,0,32,0,0,0,68,0,0,0,114,0,0,0,101,0,0,0,97,0,0,0,109,0,0,0,115,0,0,0,32,0,0,0,57,0,0,0,54,0,0,0,48,0,0,0,56,0,0,0,50,0,0,0,54,0,0,0,32,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,81,0,0,0,117,0,0,0,105,0,0,0,122,0,0,0,32,0,0,0,78,0,0,0,97,0,0,0,110,0,0,0,97,0,0,0,105,0,0,0,114,0,0,0,111,0,0,0,32,0,0,0,68,0,0,0,114,0,0,0,101,0,0,0,97,0,0,0,109,0,0,0,115,0,0,0,32,0,0,0,45,0,0,0,32,0,0,0,110,0,0,0,105,0,0,0,106,0,0,0,105,0,0,0,105,0,0,0,114,0,0,0,111,0,0,0,99,0,0,0,104,0,0,0,111,0,0,0,117,0,0,0,32,0,0,0,110,0,0,0,111,0,0,0,32,0,0,0,107,0,0,0,105,0,0,0,115,0,0,0,101,0,0,0,107,0,0,0,105,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,109,100,95,114,114,97,115,104,51,0,0,0,0,0,0,0,114,111,99,107,99,108,105,109,0,0,0,0,0,0,0,0,82,111,97,100,32,82,97,115,104,32,73,73,32,40,74,112,110,41,0,0,0,0,0,0,109,100,95,114,114,97,115,104,50,106,0,0,0,0,0,0,82,111,97,100,32,82,97,115,104,32,73,73,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,0,0,77,97,104,106,111,110,103,32,67,0,0,0,0,0,0,0,72,97,114,100,43,50,0,0,51,48,107,44,32,116,104,101,110,32,101,118,101,114,121,32,51,48,107,0,0,0,0,0,109,100,95,114,114,97,115,104,50,97,0,0,0,0,0,0,82,111,97,100,32,82,97,115,104,32,73,73,32,40,69,117,114,111,44,32,85,83,65,44,32,118,49,46,50,41,0,0,109,100,95,114,114,97,115,104,50,0,0,0,0,0,0,0,115,102,50,106,99,0,0,0,112,103,101,109,101,110,105,0,75,97,105,122,111,117,32,67,104,111,117,106,105,110,32,83,104,117,98,105,98,105,110,109,97,110,32,50,32,45,32,65,114,97,116,97,110,97,114,117,32,84,101,107,105,0,0,0,83,78,75,32,47,32,69,111,108,105,116,104,0,0,0,0,82,111,97,100,32,82,97,115,104,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,75,111,101,105,0,0,0,0,109,100,95,114,111,97,100,114,97,115,104,0,0,0,0,0,82,105,115,116,97,114,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,55,49,56,41,0,0,0,0,81,117,105,122,32,78,97,110,97,105,114,111,32,68,114,101,97,109,115,32,45,32,110,105,106,105,105,114,111,99,104,111,117,32,110,111,32,107,105,115,101,107,105,32,40,110,97,110,97,105,114,111,32,100,114,101,97,109,115,32,57,54,48,56,50,54,32,74,97,112,97,110,41,0,0,0,0,0,0,0,99,108,111,115,101,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,116,97,107,101,32,115,99,114,101,101,110,115,104,111,116,32,46,46,46,10,0,0,0,0,0,0,109,100,95,114,105,115,116,97,114,112,51,0,0,0,0,0,84,105,109,101,32,70,105,103,104,116,101,114,32,40,84,105,109,101,32,80,105,108,111,116,32,99,111,110,118,101,114,115,105,111,110,32,111,110,32,71,97,108,97,120,105,97,110,32,104,97,114,100,119,97,114,101,41,0,0,0,0,0,0,0,49,57,52,51,0,0,0,0,68,97,109,98,117,115,116,114,66,103,67,111,108,111,117,114,50,0,0,0,0,0,0,0,82,105,115,116,97,114,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,55,48,49,41,0,0,0,0,109,100,95,114,105,115,116,97,114,112,52,0,0,0,0,0,82,105,115,116,97,114,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,56,50,54,41,0,0,0,0,109,97,104,32,98,0,0,0,109,100,95,114,105,115,116,97,114,112,49,0,0,0,0,0,72,97,114,100,43,49,0,0,50,48,107,44,32,52,48,107,32,116,104,101,110,32,101,118,101,114,121,32,51,48,107,0,115,108,45,62,102,114,101,113,0,0,0,0,0,0,0,0,68,101,110,106,105,110,32,77,97,107,97,105,32,73,73,0,82,105,115,116,97,114,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,56,49,50,41,0,0,0,0,109,100,95,114,105,115,116,97,114,112,50,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,32,45,32,84,104,101,32,87,111,114,108,100,32,87,97,114,114,105,111,114,32,40,57,49,48,50,49,52,32,74,97,112,97,110,41,0,0,0,0,82,97,115,116,101,114,83,111,102,116,0,0,0,0,0,0,112,99,101,95,115,104,117,98,105,98,105,50,0,0,0,0,84,104,101,32,75,105,110,103,32,111,102,32,70,105,103,104,116,101,114,115,32,50,48,48,49,32,40,78,71,77,45,50,54,50,63,41,0,0,0,0,82,105,115,116,97,114,32,45,32,84,104,101,32,83,104,111,111,116,105,110,103,32,83,116,97,114,32,40,74,112,110,44,32,75,111,114,41,0,0,0,65,101,114,111,98,105,122,32,40,85,83,65,41,0,0,0,109,100,95,114,105,115,116,97,114,106,0,0,0,0,0,0,82,105,115,116,97,114,32,40,69,117,114,111,44,32,85,83,65,44,32,49,57,57,52,48,56,41,0,0,0,0,0,0,113,110,100,114,101,97,109,0,109,100,95,114,105,115,116,97,114,49,0,0,0,0,0,0,116,105,109,101,102,103,116,114,0,0,0,0,0,0,0,0,82,105,115,116,97,114,32,40,69,117,114,111,44,32,85,83,65,44,32,49,57,57,52,48,57,41,0,0,0,0,0,0,109,100,95,114,105,115,116,97,114,0,0,0,0,0,0,0,74,97,115,104,105,110,32,68,114,97,120,111,115,32,40,74,112,110,44,32,75,111,114,41,0,0,0,0,0,0,0,0,77,97,104,106,111,110,103,32,66,0,0,0,0,0,0,0,86,83,45,77,111,100,101,32,66,97,116,116,108,101,0,0,49,48,107,44,32,51,48,107,32,116,104,101,110,32,101,118,101,114,121,32,51,48,107,0,109,100,95,100,114,97,120,111,115,0,0,0,0,0,0,0,71,117,97,114,100,105,97,110,115,0,0,0,0,0,0,0,100,121,110,100,117,107,101,0,82,105,115,107,121,32,87,111,111,100,115,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,0,0,0,71,46,71,46,73,0,0,0,109,100,95,114,105,115,107,121,119,0,0,0,0,0,0,0,115,102,50,106,97,0,0,0,70,114,111,103,32,70,101,97,115,116,32,40,80,71,77,41,0,0,0,0,0,0,0,0,75,97,105,122,111,117,32,67,104,111,117,106,105,110,32,83,104,117,98,105,98,105,110,109,97,110,0,0,0,0,0,0,107,111,102,50,48,48,49,0,82,105,115,107,32,40,85,83,65,41,0,0,0,0,0,0,109,100,95,97,101,114,111,98,105,122,0,0,0,0,0,0,84,104,101,32,67,108,105,102,102,104,97,110,103,101,114,32,45,32,69,100,119,97,114,100,32,82,97,110,100,121,32,40,87,111,114,108,100,32,118,101,114,32,50,41,0,0,0,0,71,97,108,65,110,97,108,111,103,80,111,114,116,48,0,0,109,100,95,114,105,115,107,0,82,105,110,103,115,32,111,102,32,80,111,119,101,114,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,80,117,122,122,32,76,111,111,112,32,50,32,40,48,49,48,50,48,53,32,74,97,112,97,110,41,0,0,0,0,0,0,109,100,95,114,105,110,103,115,112,111,119,0,0,0,0,0,70,97,110,116,97,115,116,105,99,32,40,71,97,108,97,103,97,32,99,111,110,118,101,114,115,105,111,110,32,111,110,32,71,97,108,97,120,105,97,110,32,104,97,114,100,119,97,114,101,41,0,0,0,0,0,0,78,111,114,109,97,108,32,40,49,48,48,41,0,0,0,0,82,105,100,100,108,101,32,87,105,114,101,100,32,40,74,112,110,44,32,83,101,103,97,78,101,116,41,0,0,0,0,0,109,100,95,114,105,100,100,108,101,0,0,0,0,0,0,0,82,105,99,104,97,114,100,32,83,99,97,114,114,121,39,115,32,66,117,115,121,116,111,119,110,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,55,50,49,41,0,0,0,0,0,0,0,0,0,109,97,104,32,97,0,0,0,54,48,107,44,32,49,50,48,107,44,32,49,56,48,107,0,109,100,95,114,115,98,116,112,55,0,0,0,0,0,0,0,84,105,116,108,101,0,0,0,82,105,99,104,97,114,100,32,83,99,97,114,114,121,39,115,32,66,117,115,121,116,111,119,110,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,56,50,54,41,0,0,0,0,0,0,0,0,0,109,100,95,114,115,98,116,112,49,0,0,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,32,45,32,84,104,101,32,87,111,114,108,100,32,87,97,114,114,105,111,114,32,40,57,49,49,50,49,48,32,74,97,112,97,110,41,0,0,0,0,112,99,101,95,115,104,117,98,105,98,105,0,0,0,0,0,83,0,0,0,101,0,0,0,110,0,0,0,103,0,0,0,111,0,0,0,107,0,0,0,117,0,0,0,32,0,0,0,51,0,0,0,0,0,0,0,38,98,0,0,253,86,0,0,29,79,0,0,127,98,0,0,18,255,0,0,16,255,0,0,16,255,0,0,17,255,0,0,0,0,0,0,0,0,0,0,82,105,99,104,97,114,100,32,83,99,97,114,114,121,39,115,32,66,117,115,121,116,111,119,110,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,56,50,53,41,0,0,0,0,0,0,0,0,0,65,101,114,111,32,116,104,101,32,65,99,114,111,45,66,97,116,32,50,32,40,85,83,65,41,0,0,0,0,0,0,0,109,100,95,114,115,98,116,112,50,0,0,0,0,0,0,0,82,50,0,0,0,0,0,0,114,101,110,101,103,97,100,101,0,0,0,0,0,0,0,0,82,105,99,104,97,114,100,32,83,99,97,114,114,121,39,115,32,66,117,115,121,116,111,119,110,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,56,49,55,41,0,0,0,0,0,0,0,0,0,112,122,108,111,111,112,50,106,114,49,0,0,0,0,0,0,109,100,95,114,115,98,116,112,51,0,0,0,0,0,0,0,102,97,110,116,97,115,116,99,0,0,0,0,0,0,0,0,82,105,99,104,97,114,100,32,83,99,97,114,114,121,39,115,32,66,117,115,121,116,111,119,110,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,56,49,54,45,66,41,0,0,0,0,0,0,0,109,100,95,114,115,98,116,112,52,0,0,0,0,0,0,0,82,105,99,104,97,114,100,32,83,99,97,114,114,121,39,115,32,66,117,115,121,116,111,119,110,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,56,49,53,41,0,0,0,0,0,0,0,0,0,71,97,108,78,111,105,115,101,69,110,97,98,108,101,0,0,77,97,104,106,111,110,103,32,65,0,0,0,0,0,0,0,66,111,110,117,115,32,69,110,101,114,103,121,0,0,0,0,53,48,107,44,32,49,48,48,107,44,32,49,53,48,107,0,109,100,95,114,115,98,116,112,53,0,0,0,0,0,0,0,116,109,112,54,56,51,48,49,95,105,114,113,95,118,101,99,116,111,114,0,0,0,0,0,82,105,99,104,97,114,100,32,83,99,97,114,114,121,39,115,32,66,117,115,121,116,111,119,110,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,56,48,57,41,0,0,0,0,0,0,0,0,0,109,100,95,114,115,98,116,112,54,0,0,0,0,0,0,0,115,102,50,106,0,0,0,0,112,103,109,102,114,111,103,0,74,117,117,111,117,107,105,32,40,65,108,116,41,0,0,0,83,78,75,32,47,32,78,111,105,115,101,32,70,97,99,116,111,114,121,0,0,0,0,0,82,105,99,104,97,114,100,32,83,99,97,114,114,121,39,115,32,66,117,115,121,84,111,119,110,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,109,100,95,97,101,114,111,50,117,0,0,0,0,0,0,0,115,101,110,103,111,107,117,0,80,49,32,74,117,109,112,0,109,100,95,114,115,98,116,0,71,117,110,32,66,97,108,108,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,82,101,118,111,108,117,116,105,111,110,32,88,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,0,0,80,117,122,122,32,76,111,111,112,32,50,32,40,48,49,48,50,50,54,32,74,97,112,97,110,41,0,0,0,0,0,0,77,54,56,48,48,67,80,85,67,111,110,116,101,120,116,91,105,93,46,110,67,121,99,108,101,115,83,101,103,109,101,110,116,0,0,0,0,0,0,0,77,97,110,105,97,99,32,83,113,117,97,114,101,32,40,117,110,112,114,111,116,101,99,116,101,100,41,0,0,0,0,0,49,32,99,111,105,110,32,52,32,99,114,101,100,105,116,115,0,0,0,0,0,0,0,0,102,105,120,101,105,103,104,116,106,0,0,0,0,0,0,0,109,100,95,114,101,118,120,0,115,108,97,112,102,105,103,104,98,49,0,0,0,0,0,0,84,97,105,116,111,32,100,111,32,66,114,97,115,105,108,0,85,83,65,47,84,97,105,116,111,32,65,109,101,114,105,99,97,32,40,82,111,109,115,116,97,114,41,0,0,0,0,0,86,101,114,121,32,72,97,114,100,0,0,0,0,0,0,0,84,104,101,32,83,117,112,101,114,32,83,104,105,110,111,98,105,32,40,74,112,110,41,0,0,0,0,0,0,0,0,0,98,108,117,101,112,114,110,116,0,0,0,0,0,0,0,0,109,100,95,115,117,112,115,104,105,110,0,0,0,0,0,0,55,48,48,48,48,44,32,101,118,101,114,121,32,50,48,48,48,48,48,0,0,0,0,0,84,104,101,32,82,101,118,101,110,103,101,32,111,102,32,83,104,105,110,111,98,105,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,68,97,116,97,32,69,97,115,116,32,67,111,114,112,111,116,97,116,105,111,110,0,0,0,115,101,114,118,105,99,101,32,50,0,0,0,0,0,0,0,68,111,110,32,68,111,107,111,32,68,111,110,32,40,85,83,41,0,0,0,0,0,0,0,56,0,0,0,0,0,0,0,52,48,107,44,32,32,56,48,107,44,32,49,50,48,107,44,32,49,54,48,107,0,0,0,109,100,95,114,101,118,115,104,105,110,50,0,0,0,0,0,77,97,103,97,122,105,110,101,115,47,82,111,99,107,101,116,115,0,0,0,0,0,0,0,68,114,46,32,84,111,112,112,101,108,39,115,32,84,97,110,107,101,110,116,97,105,32,40,74,97,112,97,110,41,0,0,116,109,112,54,56,51,48,49,95,116,105,109,101,114,95,99,111,117,110,116,101,114,0,0,65,114,107,97,110,111,105,100,32,40,71,97,109,101,32,67,111,114,112,111,114,97,116,105,111,110,32,98,111,111,116,108,101,103,44,32,115,101,116,32,49,41,0,0,0,0,0,0,54,48,107,32,97,110,100,32,101,118,101,114,121,32,49,48,48,107,0,0,0,0,0,0,84,104,101,32,82,101,118,101,110,103,101,32,111,102,32,83,104,105,110,111,98,105,32,40,69,117,114,111,44,32,85,83,65,44,32,82,101,118,46,32,65,41,0,0,0,0,0,0,67,114,105,109,101,32,67,105,116,121,32,40,85,83,41,0,0,0,0,0,0,0,0,0,67,111,110,116,105,110,101,110,116,97,108,32,67,105,114,99,117,115,32,40,87,111,114,108,100,41,0,0,0,0,0,0,109,100,95,114,101,118,115,104,105,110,49,0,0,0,0,0,114,98,105,115,108,97,110,100,101,0,0,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,32,45,32,84,104,101,32,87,111,114,108,100,32,87,97,114,114,105,111,114,32,40,57,49,49,49,48,49,32,85,83,65,41,0,0,0,0,0,0,103,97,108,109,101,100,101,115,0,0,0,0,0,0,0,0,82,97,115,116,101,114,0,0,112,99,101,95,106,117,117,111,117,107,105,49,0,0,0,0,83,101,110,103,111,107,117,32,51,32,47,32,83,101,110,103,111,107,117,32,68,101,110,115,104,111,32,50,48,48,49,0,0,0,0,0,0,0,0,0,98,117,98,108,99,97,118,101,49,48,0,0,0,0,0,0,39,89,0,0,203,101,0,0,168,152,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,68,0,0,0,97,0,0,0,105,0,0,0,115,0,0,0,101,0,0,0,110,0,0,0,112,0,0,0,117,0,0,0,0,0,0,0,0,0,0,0,84,104,101,32,82,101,118,101,110,103,101,32,111,102,32,83,104,105,110,111,98,105,32,40,69,117,114,111,44,32,85,83,65,44,32,82,101,118,46,32,66,41,0,0,0,0,0,0,65,101,114,111,32,116,104,101,32,65,99,114,111,45,66,97,116,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,116,111,117,116,114,117,110,49,0,0,0,0,0,0,0,0,109,100,95,114,101,118,115,104,105,110,0,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,73,32,51,114,100,32,83,116,114,105,107,101,58,32,70,105,103,104,116,32,102,111,114,32,116,104,101,32,70,117,116,117,114,101,32,40,74,97,112,97,110,32,57,57,48,53,49,50,44,32,78,79,32,67,68,41,0,0,0,0,0,0,0,65,108,116,101,114,101,100,32,66,101,97,115,116,32,40,115,101,116,32,54,44,32,56,55,53,49,32,51,49,55,45,48,48,55,54,41,0,0,0,0,83,121,115,116,101,109,49,56,86,100,112,77,105,120,105,110,103,0,0,0,0,0,0,0,82,101,115,113,32,40,69,117,114,111,44,32,80,114,111,116,111,116,121,112,101,41,0,0,112,122,108,111,111,112,50,106,0,0,0,0,0,0,0,0,70,108,105,99,107,121,32,40,54,52,107,32,86,101,114,115,105,111,110,44,32,83,121,115,116,101,109,32,49,44,32,51,49,53,45,53,48,53,49,44,32,115,101,116,32,49,41,0,0,0,0,0,0,0,0,0,68,46,32,68,46,32,67,114,101,119,32,40,115,101,116,32,51,44,32,85,83,44,32,52,32,80,108,97,121,101,114,115,44,32,70,68,49,48,57,52,32,51,49,55,45,48,49,56,54,41,0,0,0,0,0,0,109,100,95,114,101,115,113,0,82,97,99,105,110,103,32,72,101,114,111,32,40,70,68,49,48,57,52,32,51,49,55,45,48,49,52,52,41,0,0,0,75,111,110,103,32,40,68,111,110,107,101,121,32,75,111,110,103,32,99,111,110,118,101,114,115,105,111,110,32,111,110,32,71,97,108,97,120,105,97,110,32,104,97,114,100,119,97,114,101,41,0,0,0,0,0,0,102,97,110,116,122,111,110,101,112,0,0,0,0,0,0,0,118,105,100,101,111,95,97,115,112,101,99,116,95,114,97,116,105,111,0,0,0,0,0,0,82,101,110,116,32,97,32,72,101,114,111,32,40,74,112,110,41,0,0,0,0,0,0,0,109,100,95,114,101,110,116,104,101,114,111,0,0,0,0,0,83,111,117,110,100,32,84,101,115,116,0,0,0,0,0,0,97,114,114,105,118,101,100,70,108,97,103,0,0,0,0,0,83,116,105,109,112,121,39,115,32,73,110,118,101,110,116,105,111,110,32,83,116,97,114,114,105,110,103,32,83,116,97,114,114,105,110,103,32,82,101,110,32,72,111,235,107,32,38,32,83,116,105,109,112,121,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,0,0,0,70,99,114,97,115,104,83,111,117,110,100,76,97,116,99,104,0,0,0,0,0,0,0,0,48,37,0,0,0,0,0,0,83,101,114,118,105,99,101,32,50,0,0,0,0,0,0,0,109,100,95,114,101,110,115,116,105,109,117,112,0,0,0,0,115,101,114,118,105,99,101,52,0,0,0,0,0,0,0,0,84,104,117,110,100,101,114,32,68,114,97,103,111,110,32,50,32,40,49,115,116,32,79,99,116,46,32,49,57,57,51,41,0,0,0,0,0,0,0,0,116,109,112,54,56,51,48,49,95,116,105,109,101,114,0,0,83,116,105,109,112,121,39,115,32,73,110,118,101,110,116,105,111,110,32,83,116,97,114,114,105,110,103,32,83,116,97,114,114,105,110,103,32,82,101,110,32,72,111,235,107,32,38,32,83,116,105,109,112,121,32,40,85,83,65,41,0,0,0,0,100,114,103,110,98,111,119,108,0,0,0,0,0,0,0,0,109,100,95,114,101,110,115,116,105,109,117,0,0,0,0,0,77,97,110,117,97,108,0,0,115,102,50,117,107,0,0,0,68,101,109,111,32,71,97,109,101,0,0,0,0,0,0,0,70,97,110,116,97,115,105,97,32,73,73,32,40,69,120,112,108,105,99,105,116,41,0,0,74,117,117,111,117,107,105,0,0,0,0,0,0,0,0,0,115,101,110,103,111,107,117,51,0,0,0,0,0,0,0,0,83,116,105,109,112,121,39,115,32,73,110,118,101,110,116,105,111,110,32,83,116,97,114,114,105,110,103,32,83,116,97,114,114,105,110,103,32,82,101,110,32,72,111,235,107,32,38,32,83,116,105,109,112,121,32,40,69,117,114,111,41,0,0,0,50,32,67,111,105,110,115,47,49,32,67,114,101,100,105,116,32,51,47,50,0,0,0,0,80,0,0,0,114,0,0,0,101,0,0,0,116,0,0,0,116,0,0,0,121,0,0,0,32,0,0,0,83,0,0,0,111,0,0,0,108,0,0,0,100,0,0,0,105,0,0,0,101,0,0,0,114,0,0,0,32,0,0,0,83,0,0,0,97,0,0,0,105,0,0,0,108,0,0,0,111,0,0,0,114,0,0,0,32,0,0,0,77,0,0,0,111,0,0,0,111,0,0,0,110,0,0,0,0,0,0,0,142,127,0,0,17,92,0,0,115,89,0,0,38,98,0,0,235,88,0,0,32,0,0,0,187,48,0,0,252,48,0,0,233,48,0,0,252,48,0,0,224,48,0,0,252,48,0,0,243,48,0,0,32,0,0,0,40,0,0,0,118,0,0,0,101,0,0,0,114,0,0,0,46,0,0,0,32,0,0,0,57,0,0,0,53,0,0,0,47,0,0,0,48,0,0,0,51,0,0,0,47,0,0,0,50,0,0,0,50,0,0,0,44,0,0,0,32,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,65,56,48,48,48,48,32,82,101,103,105,115,116,101,114,115,0,0,0,0,0,0,0,0,109,100,95,97,101,114,111,117,0,0,0,0,0,0,0,0,66,108,111,111,100,32,99,111,108,111,114,0,0,0,0,0,109,100,95,114,101,110,115,116,105,109,0,0,0,0,0,0,97,101,114,111,102,103,116,99,0,0,0,0,0,0,0,0,69,114,111,103,97,116,111,114,101,32,71,101,116,116,111,110,105,0,0,0,0,0,0,0,82,101,100,32,90,111,110,101,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,77,105,116,99,104,101,108,108,44,32,100,105,115,116,114,105,116,117,101,100,32,98,121,32,67,97,112,99,111,109,0,0,82,101,116,114,111,65,114,99,104,58,32,70,111,117,110,100,32,115,104,97,100,101,114,32,34,37,115,34,10,0,0,0,65,116,104,101,110,97,0,0,109,100,95,114,101,100,122,111,110,101,0,0,0,0,0,0,107,111,110,103,0,0,0,0,99,104,111,107,99,104,111,107,0,0,0,0,0,0,0,0,82,97,115,116,97,110,32,83,97,103,97,32,73,73,32,40,74,112,110,41,0,0,0,0,115,49,57,52,53,97,0,0,77,97,104,106,111,110,103,32,71,45,84,97,115,116,101,0,0,0,0,0,0,0,0,0,54,52,0,0,0,0,0,0,80,49,32,98,117,116,116,111,110,32,51,0,0,0,0,0,109,100,95,114,97,115,116,97,110,50,106,0,0,0,0,0,49,48,107,32,32,53,48,107,32,32,53,48,107,0,0,0,84,101,114,114,97,32,70,111,114,99,101,32,40,98,111,111,116,108,101,103,32,115,101,116,32,50,41,0,0,0,0,0,97,105,114,119,111,108,102,0,82,97,115,116,97,110,32,83,97,103,97,32,73,73,32,40,85,83,65,41,0,0,0,0,112,97,110,103,98,0,0,0,49,67,32,50,67,32,47,32,49,67,32,52,67,0,0,0,49,48,48,48,48,32,51,48,48,48,48,0,0,0,0,0,83,116,97,114,116,105,110,103,32,69,110,101,114,103,121,0,109,100,95,114,97,115,116,97,110,50,0,0,0,0,0,0,83,101,114,118,105,99,101,32,52,0,0,0,0,0,0,0,80,111,112,101,121,101,45,77,97,110,0,0,0,0,0,0,103,97,117,110,116,108,101,116,114,49,0,0,0,0,0,0,82,97,110,115,101,105,32,110,111,32,72,97,115,104,97,32,40,74,112,110,41,0,0,0,84,114,105,112,32,83,101,108,101,99,116,0,0,0,0,0,82,97,99,107,32,84,101,115,116,32,40,99,104,101,97,116,41,0,0,0,0,0,0,0,49,48,32,76,101,116,116,101,114,115,0,0,0,0,0,0,49,32,67,111,105,110,32,32,51,32,80,108,97,121,0,0,109,100,95,114,97,110,115,101,105,0,0,0,0,0,0,0,100,107,111,110,103,106,114,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,32,45,32,84,104,101,32,87,111,114,108,100,32,87,97,114,114,105,111,114,32,40,57,49,48,53,50,50,32,85,83,65,44,32,114,101,118,32,73,41,0,0,0,0,0,0,0,67,104,97,111,115,32,40,80,71,77,32,68,101,109,111,41,0,0,0,0,0,0,0,0,112,99,101,95,106,117,117,111,117,107,105,0,0,0,0,0,90,117,112,97,112,97,33,0,0,0,0,0,0,0,0,0,69,120,45,82,97,110,122,97,32,40,74,112,110,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,0,65,101,114,111,32,116,104,101,32,65,99,114,111,45,66,97,116,32,40,80,114,111,116,111,116,121,112,101,41,0,0,0,97,118,101,110,103,101,114,115,50,0,0,0,0,0,0,0,53,48,107,32,49,48,48,107,0,0,0,0,0,0,0,0,109,100,95,101,120,114,97,110,122,97,112,0,0,0,0,0,116,114,105,112,111,111,108,97,0,0,0,0,0,0,0,0,73,107,97,114,105,32,73,73,73,32,45,32,84,104,101,32,82,101,115,99,117,101,32,40,75,111,114,101,97,44,32,56,45,87,97,121,32,74,111,121,115,116,105,99,107,41,0,0,65,105,109,32,82,105,103,104,116,0,0,0,0,0,0,0,48,32,40,70,111,114,101,115,116,32,49,41,0,0,0,0,68,114,118,66,103,49,79,110,0,0,0,0,0,0,0,0,69,120,45,82,97,110,122,97,32,40,74,112,110,41,0,0,80,117,122,122,32,76,111,111,112,32,50,32,40,48,49,48,51,48,50,32,69,117,114,111,41,0,0,0,0,0,0,0,108,101,103,101,110,100,0,0,82,101,116,114,111,65,114,99,104,58,32,82,79,77,32,112,97,116,99,104,101,100,32,115,117,99,99,101,115,115,102,117,108,108,121,32,40,37,115,41,46,10,0,0,0,0,0,0,109,100,95,101,120,114,97,110,122,97,0,0,0,0,0,0,78,111,118,97,32,71,97,109,101,115,32,76,116,100,0,0,32,49,32,67,111,105,110,32,32,49,32,67,114,101,100,105,116,0,0,0,0,0,0,0,75,72,32,86,105,100,101,111,0,0,0,0,0,0,0,0,49,32,67,111,105,110,32,32,50,32,67,114,101,100,105,116,115,32,47,32,49,32,67,111,105,110,32,32,49,48,32,67,114,101,100,105,116,115,0,0,82,97,110,103,101,114,45,88,32,40,85,83,65,41,0,0,109,97,114,105,110,101,98,0,109,100,95,114,97,110,103,101,114,120,117,0,0,0,0,0,109,95,107,98,95,112,114,111,116,95,104,111,108,100,0,0,82,97,110,103,101,114,45,88,32,40,69,117,114,111,41,0,0,0,0,0,0,0,0,0,67,104,117,117,103,111,107,117,114,121,117,117,32,73,73,32,40,86,49,48,48,74,44,32,74,97,112,97,110,41,0,0,85,110,108,105,109,105,116,101,100,0,0,0,0,0,0,0,109,100,95,114,97,110,103,101,114,120,0,0,0,0,0,0,82,97,109,112,97,114,116,32,40,74,112,110,44,32,75,111,114,41,0,0,0,0,0,0,67,112,115,82,97,109,54,54,48,0,0,0,0,0,0,0,65,114,109,101,100,32,70,111,114,109,97,116,105,111,110,32,70,0,0,0,0,0,0,0,109,100,95,114,97,109,112,97,114,116,106,0,0,0,0,0,115,102,50,117,105,0,0,0,112,103,109,100,101,109,111,0,74,105,110,109,117,32,68,101,110,115,104,111,117,32,40,65,108,116,41,0,0,0,0,0,67,97,112,116,97,105,110,32,67,111,109,109,97,110,100,111,32,40,57,49,48,57,50,56,32,85,83,65,41,0,0,0,82,97,109,112,97,114,116,32,40,85,83,65,41,0,0,0,98,66,73,79,83,84,101,120,116,82,79,77,69,110,97,98,108,101,100,0,0,0,0,0,109,100,95,97,101,114,111,112,0,0,0,0,0,0,0,0,109,100,95,114,97,109,112,97,114,116,0,0,0,0,0,0,82,97,109,98,111,32,73,73,73,32,40,87,111,114,108,100,41,0,0,0,0,0,0,0,112,122,108,111,111,112,50,0,79,80,76,45,62,110,111,105,115,101,95,112,0,0,0,0,109,100,95,114,97,109,98,111,51,97,0,0,0,0,0,0,80,111,114,116,32,77,97,110,32,40,98,111,111,116,108,101,103,32,111,110,32,77,111,111,110,32,67,114,101,115,116,97,32,104,97,114,100,119,97,114,101,41,0,0,0,0,0,0,82,97,109,98,111,32,73,73,73,32,40,87,111,114,108,100,44,32,118,49,46,49,41,0,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,71,76,58,32,73,110,118,97,108,105,100,32,101,110,117,109,46,10,0,48,46,57,46,57,46,54,0,109,100,95,114,97,109,98,111,51,0,0,0,0,0,0,0,74,111,121,112,97,100,32,119,47,32,65,110,97,108,111,103,0,0,0,0,0,0,0,0,109,100,95,115,112,108,97,116,116,104,50,106,0,0,0,0,82,97,105,110,98,111,119,32,73,115,108,97,110,100,115,32,69,120,116,114,97,32,40,74,112,110,41,0,0,0,0,0,49,32,67,111,105,110,32,55,32,67,114,101,100,105,116,115,0,0,0,0,0,0,0,0,109,100,95,114,98,105,115,108,97,110,100,0,0,0,0,0,49,32,73,110,110,105,110,103,0,0,0,0,0,0,0,0,109,97,104,32,115,109,97,108,108,0,0,0,0,0,0,0,82,97,105,100,101,110,32,84,114,97,100,32,40,85,83,65,41,32,126,32,82,97,105,100,101,110,32,68,101,110,115,101,116,115,117,32,40,74,112,110,41,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,88,77,76,32,115,104,97,100,101,114,32,46,46,46,10,0,0,0,0,0,71,88,56,55,48,0,0,0,109,100,95,114,97,105,100,101,110,0,0,0,0,0,0,0,65,114,109,111,114,101,100,32,87,97,114,114,105,111,114,115,32,40,57,52,49,48,50,52,32,85,83,65,41,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,32,45,32,84,104,101,32,87,111,114,108,100,32,87,97,114,114,105,111,114,32,40,57,49,48,53,50,50,32,85,83,65,44,32,114,101,118,32,71,41,0,0,0,0,0,0,0,112,99,101,95,106,105,110,109,117,49,0,0,0,0,0,0,122,117,112,97,112,97,0,0,97,110,97,108,111,103,95,108,101,102,116,0,0,0,0,0,82,97,100,105,99,97,108,32,82,101,120,32,40,85,83,65,41,0,0,0,0,0,0,0,65,101,114,111,32,116,104,101,32,65,99,114,111,45,66,97,116,32,40,69,117,114,111,41,0,0,0,0,0,0,0,0,109,97,116,99,104,105,116,50,0,0,0,0,0,0,0,0,67,117,101,98,114,105,99,107,83,110,100,73,114,113,70,105,114,101,0,0,0,0,0,0,108,100,114,117,110,51,106,0,109,100,95,114,97,100,114,101,120,117,0,0,0,0,0,0,66,108,97,100,101,32,77,97,115,116,101,114,32,40,87,111,114,108,100,41,0,0,0,0,110,115,112,105,114,105,116,0,82,97,100,105,99,97,108,32,82,101,120,32,40,69,117,114,111,41,0,0,0,0,0,0,215,48,0,0,237,48,0,0,174,48,0,0,162,48,0,0,110,48,0,0,80,93,0,0,32,0,0,0,40,0,0,0,80,0,0,0,114,0,0,0,111,0,0,0,103,0,0,0,101,0,0,0,97,0,0,0,114,0,0,0,32,0,0,0,78,0,0,0,111,0,0,0,32,0,0,0,65,0,0,0,114,0,0,0,97,0,0,0,115,0,0,0,104,0,0,0,105,0,0,0,32,0,0,0,48,0,0,0,49,0,0,0,48,0,0,0,49,0,0,0,49,0,0,0,55,0,0,0,32,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,109,100,95,114,97,100,114,101,120,0,0,0,0,0,0,0,108,97,115,116,100,117,101,108,0,0,0,0,0,0,0,0,82,97,99,101,32,68,114,105,118,105,110,39,32,40,85,83,65,41,0,0,0,0,0,0,109,100,95,114,97,99,101,100,114,105,118,0,0,0,0,0,82,46,66,46,73,46,32,66,97,115,101,98,97,108,108,32,52,32,40,74,112,110,41,0,0,0,0,0,0,0,0,0,67,111,110,116,105,110,117,101,115,0,0,0,0,0,0,0,109,100,95,114,98,105,98,98,52,106,0,0,0,0,0,0,83,116,97,114,116,105,110,103,32,83,116,97,103,101,0,0,83,109,97,105,108,108,0,0,82,46,66,46,73,46,32,66,97,115,101,98,97,108,108,32,52,32,40,80,114,111,116,111,116,121,112,101,41,0,0,0,109,100,95,114,98,105,98,98,52,112,0,0,0,0,0,0,115,102,50,117,103,0,0,0,66,105,103,32,67,108,117,98,0,0,0,0,0,0,0,0,84,104,101,32,75,105,110,103,32,111,102,32,70,105,103,104,116,101,114,115,32,50,48,48,48,32,40,110,111,116,32,101,110,99,114,121,112,116,101,100,41,0,0,0,0,0,0,0,82,46,66,46,73,46,32,66,97,115,101,98,97,108,108,32,52,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,109,100,95,97,101,114,111,0,109,100,95,114,98,105,98,98,52,0,0,0,0,0,0,0,82,46,66,46,73,46,32,66,97,115,101,98,97,108,108,32,51,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,80,114,111,103,101,97,114,32,78,111,32,65,114,97,115,104,105,32,40,48,49,48,49,49,55,32,74,97,112,97,110,41,0,0,0,0,0,0,0,0,101,106,101,99,116,0,0,0,109,100,95,114,98,105,98,98,51,0,0,0,0,0,0,0,112,111,114,116,101,114,0,0,68,97,109,98,117,115,116,114,66,103,67,111,108,111,117,114,49,0,0,0,0,0,0,0,82,46,66,46,73,46,32,66,97,115,101,98,97,108,108,32,39,57,52,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,0,0,0,109,100,95,114,98,105,98,98,57,52,0,0,0,0,0,0,82,46,66,46,73,46,32,66,97,115,101,98,97,108,108,32,39,57,51,32,40,85,83,65,41,0,0,0,0,0,0,0,73,110,118,105,110,99,105,98,108,101,32,77,111,100,101,0,109,100,95,114,98,105,98,98,57,51,0,0,0,0,0,0,53,48,107,44,32,49,48,48,107,32,97,110,100,32,50,48,48,107,0,0,0,0,0,0,50,48,48,107,44,32,53,48,48,107,32,38,32,49,44,50,44,51,44,53,32,77,105,108,0,0,0,0,0,0,0,0,109,97,104,32,98,105,103,0,83,97,99,104,101,110,0,0])
.concat([115,108,45,62,112,104,97,115,101,0,0,0,0,0,0,0,81,117,101,101,110,32,111,102,32,80,111,107,101,114,32,67,108,117,98,32,40,84,119,41,0,0,0,0,0,0,0,0,115,102,0,0,0,0,0,0,80,115,110,100,67,111,100,101,0,0,0,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,32,45,32,84,104,101,32,87,111,114,108,100,32,87,97,114,114,105,111,114,32,40,57,49,48,52,49,49,32,85,83,65,41,0,0,0,0,0,0,74,105,110,109,117,32,68,101,110,115,104,111,117,0,0,0,107,111,102,50,48,48,48,110,0,0,0,0,0,0,0,0,109,100,95,113,112,111,107,101,114,0,0,0,0,0,0,0,65,100,118,101,110,116,117,114,111,117,115,32,66,111,121,32,45,32,77,97,111,32,88,105,97,110,32,88,105,97,111,32,90,105,32,40,67,104,105,41,0,0,0,0,0,0,0,0,77,101,103,97,84,114,97,120,32,40,74,112,110,41,0,0,76,50,32,98,117,116,116,111,110,32,40,116,114,105,103,103,101,114,41,0,0,0,0,0,109,100,95,109,101,103,97,116,114,97,120,0,0,0,0,0,112,114,111,103,101,97,114,106,0,0,0,0,0,0,0,0,81,117,97,100,32,67,104,97,108,108,101,110,103,101,32,40,85,83,65,41,0,0,0,0,67,114,97,122,121,32,75,111,110,103,32,40,98,111,111,116,108,101,103,32,111,110,32,77,111,111,110,32,67,114,101,115,116,97,32,104,97,114,100,119,97,114,101,41,0,0,0,0,109,100,95,113,117,97,100,99,104,97,108,0,0,0,0,0,81,117,97,99,107,83,104,111,116,32,83,116,97,114,114,105,110,103,32,68,111,110,97,108,100,32,68,117,99,107,32,126,32,81,117,97,99,107,83,104,111,116,32,45,32,71,117,114,117,122,105,97,32,79,117,32,110,111,32,72,105,104,111,117,32,40,87,111,114,108,100,44,32,65,108,116,41,0,0,0,109,100,95,113,117,97,99,107,115,104,116,49,0,0,0,0,53,107,44,32,49,53,107,44,32,51,48,107,0,0,0,0,80,121,114,97,109,105,100,32,77,97,103,105,99,32,83,112,101,99,105,97,108,32,40,74,112,110,44,32,83,101,103,97,78,101,116,41,0,0,0,0,51,48,107,44,32,32,56,48,107,32,97,110,100,32,49,53,48,107,0,0,0,0,0,0,83,101,114,118,105,99,101,32,49,0,0,0,0,0,0,0,50,48,48,107,32,97,110,100,32,49,32,77,105,108,0,0,109,100,95,112,121,114,97,109,105,100,115,0,0,0,0,0,71,97,108,97,120,105,97,110,32,80,97,114,116,32,52,32,40,104,97,99,107,41,0,0,80,121,114,97,109,105,100,32,77,97,103,105,99,32,73,73,73,32,40,74,112,110,44,32,83,101,103,97,78,101,116,41,0,0,0,0,0,0,0,0,115,102,50,117,102,0,0,0,112,99,101,95,106,105,110,109,117,0,0,0,0,0,0,0,84,104,101,32,75,105,110,103,32,111,102,32,70,105,103,104,116,101,114,115,32,50,48,48,48,32,40,78,71,77,45,50,53,55,48,41,32,40,78,71,72,45,50,53,55,48,41,0,0,0,0,0,0,0,0,0,109,100,95,112,121,114,97,109,105,100,51,0,0,0,0,0,109,100,95,97,100,118,101,98,111,121,0,0,0,0,0,0,101,100,114,97,110,100,121,50,0,0,0,0,0,0,0,0,73,110,105,116,69,69,80,82,79,77,67,111,117,110,116,0,80,121,114,97,109,105,100,32,77,97,103,105,99,32,73,73,32,40,74,112,110,44,32,83,101,103,97,78,101,116,41,0,0,0,0,0,0,0,0,0,109,100,95,112,121,114,97,109,105,100,50,0,0,0,0,0,80,114,111,103,101,97,114,32,40,48,49,48,49,49,55,32,65,115,105,97,41,0,0,0,115,114,117,109,98,108,101,114,0,0,0,0,0,0,0,0,80,121,114,97,109,105,100,32,77,97,103,105,99,32,40,74,112,110,44,32,71,97,109,101,32,110,111,32,75,97,110,100,117,109,101,32,77,101,103,97,67,68,32,82,105,112,41,0,0,0,0,0,0,0,0,0,99,107,111,110,103,109,99,0,69,97,115,121,32,40,49,51,48,41,0,0,0,0,0,0,109,100,95,112,121,114,97,109,105,100,103,110,107,0,0,0,80,121,114,97,109,105,100,32,77,97,103,105,99,32,40,74,112,110,44,32,83,101,103,97,78,101,116,41,0,0,0,0,109,100,95,112,121,114,97,109,105,100,0,0,0,0,0,0,53,107,44,32,49,48,107,44,32,49,56,107,44,32,51,48,107,0,0,0,0,0,0,0,80,117,122,122,108,101,32,38,32,65,99,116,105,111,110,32,45,32,84,97,110,116,45,82,32,40,74,112,110,41,0,0,50,48,107,44,32,32,55,48,107,32,97,110,100,32,49,50,48,107,0,0,0,0,0,0,50,48,48,107,0,0,0,0,109,100,95,116,97,110,116,114,0,0,0,0,0,0,0,0,80,117,122,122,108,101,32,38,32,65,99,116,105,111,110,32,45,32,73,99,104,105,100,97,110,116,45,82,32,40,74,112,110,41,0,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,32,45,32,84,104,101,32,87,111,114,108,100,32,87,97,114,114,105,111,114,32,40,57,49,48,50,50,56,32,85,83,65,41,0,0,0,0,0,0,74,105,103,111,107,117,32,77,101,103,117,114,105,0,0,0,107,111,102,50,48,48,48,0,109,100,95,105,99,104,105,114,0,0,0,0,0,0,0,0,65,98,115,111,108,117,116,101,32,69,110,116,101,114,116,97,105,110,109,101,110,116,0,0,80,117,121,111,32,80,117,121,111,32,50,32,40,74,112,110,41,0,0,0,0,0,0,0,76,50,0,0,0,0,0,0,109,100,95,112,117,121,111,112,117,121,50,97,0,0,0,0,112,114,111,103,101,97,114,97,0,0,0,0,0,0,0,0,80,117,121,111,32,80,117,121,111,32,50,32,40,74,112,110,44,32,118,49,46,49,41,0,0,0,0,0,0,0,0,0,67,114,97,122,121,32,75,111,110,103,32,40,98,111,111,116,108,101,103,32,111,110,32,71,97,108,97,120,105,97,110,32,104,97,114,100,119,97,114,101,41,0,0,0,0,0,0,0,109,100,95,112,117,121,111,112,117,121,50,0,0,0,0,0,80,117,121,111,32,80,117,121,111,32,40,74,112,110,41,0,0,0,0,0,0,0,0,0,109,100,95,112,117,121,111,112,117,121,111,0,0,0,0,0,80,117,116,116,101,114,32,71,111,108,102,32,40,74,112,110,44,32,71,97,109,101,32,110,111,32,75,97,110,100,117,109,101,32,77,101,103,97,67,68,32,82,105,112,41,0,0,0,66,101,115,116,0,0,0,0,70,108,105,112,70,108,111,112,0,0,0,0,0,0,0,0,115,107,121,107,105,100,0,0,109,100,95,112,117,116,116,101,114,103,110,107,0,0,0,0,80,117,116,116,101,114,32,71,111,108,102,32,40,74,112,110,44,32,83,101,103,97,78,101,116,41,0,0,0,0,0,0,115,102,50,117,101,0,0,0,112,99,101,95,106,105,103,111,109,101,103,117,0,0,0,0,50,32,83,116,97,114,116,47,49,32,67,111,110,116,105,110,117,101,0,0,0,0,0,0,77,101,116,97,108,32,83,108,117,103,32,54,32,40,77,101,116,97,108,32,83,108,117,103,32,51,32,98,111,111,116,108,101,103,41,0,0,0,0,0,109,100,95,112,117,116,116,101,114,0,0,0,0,0,0,0,84,104,101,32,65,100,118,101,110,116,117,114,101,115,32,111,102,32,82,111,99,107,121,32,97,110,100,32,66,117,108,108,119,105,110,107,108,101,32,97,110,100,32,70,114,105,101,110,100,115,32,40,85,83,65,41,0,0,0,0,0,0,0,0,49,57,57,53,0,0,0,0,80,49,32,84,117,114,110,0,84,104,101,32,80,117,110,105,115,104,101,114,32,40,85,83,65,41,0,0,0,0,0,0,103,117,110,98,97,108,108,0,109,100,95,112,117,110,105,115,104,101,114,117,0,0,0,0,67,97,112,99,111,109,32,47,32,67,97,118,101,0,0,0,77,54,56,48,48,67,80,85,67,111,110,116,101,120,116,91,105,93,46,110,67,121,99,108,101,115,84,111,116,97,108,0,49,32,99,111,105,110,32,51,32,99,114,101,100,105,116,115,0,0,0,0,0,0,0,0,70,105,120,69,105,103,104,116,32,40,74,97,112,97,110,44,32,84,97,105,116,111,32,108,105,99,101,110,115,101,41,0,0,0,0,0,0,0,0,0,49,32,99,111,105,110,32,54,32,112,108,97,121,115,0,0,84,104,101,32,80,117,110,105,115,104,101,114,32,40,69,117,114,111,41,0,0,0,0,0,83,108,97,112,32,70,105,103,104,116,32,40,74,97,112,97,110,32,115,101,116,32,49,41,0,0,0,0,0,0,0,0,74,97,112,97,110,47,84,97,105,116,111,32,67,111,114,112,0,0,0,0,0,0,0,0,109,100,95,112,117,110,105,115,104,101,114,0,0,0,0,0,49,48,48,48,48,48,44,32,52,48,48,48,48,48,0,0,80,117,108,115,101,109,97,110,32,40,74,112,110,41,0,0,68,32,40,109,111,114,101,32,104,97,114,100,41,0,0,0,68,73,80,32,115,119,105,116,99,104,101,115,32,111,102,102,115,101,116,58,32,37,100,46,10,0,0,0,0,0,0,0,109,100,95,112,117,108,115,101,109,97,110,0,0,0,0,0,70,105,103,104,116,105,110,103,32,70,97,110,116,97,115,121,32,40,74,97,112,97,110,32,114,101,118,105,115,105,111,110,32,50,41,0,0,0,0,0,100,111,110,100,111,107,111,100,117,0,0,0,0,0,0,0,50,53,53,32,40,67,104,101,97,116,41,0,0,0,0,0,80,49,32,65,99,99,101,108,101,114,97,116,101,0,0,0,80,117,103,103,115,121,32,40,85,83,65,41,0,0,0,0,86,80,67,32,80,114,105,111,114,105,116,121,32,77,97,112,0,0,0,0,0,0,0,0,100,114,116,111,112,112,101,108,106,0,0,0,0,0,0,0,66,101,116,116,101,114,0,0,109,97,104,32,100,117,0,0,97,114,107,97,110,103,99,0,56,48,107,32,97,110,100,32,101,118,101,114,121,32,49,48,48,107,0,0,0,0,0,0,109,100,95,112,117,103,103,115,121,117,0,0,0,0,0,0,99,114,105,109,101,99,117,0,80,117,103,103,115,121,32,40,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,82,97,105,110,98,111,119,32,73,115,108,97,110,100,115,32,40,111,108,100,32,118,101,114,115,105,111,110,41,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,32,45,32,84,104,101,32,87,111,114,108,100,32,87,97,114,114,105,111,114,32,40,57,49,48,51,49,56,32,85,83,65,41,0,0,0,0,0,0,77,97,122,101,32,111,102,32,70,108,111,116,116,32,40,74,97,112,97,110,41,0,0,0,74,97,99,107,105,101,32,67,104,97,110,0,0,0,0,0,109,115,108,117,103,51,98,54,0,0,0,0,0,0,0,0,66,105,115,98,111,99,104,32,97,110,100,32,65,108,97,100,97,114,0,0,0,0,0,0,68,97,105,115,101,110,112,117,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,109,100,95,112,117,103,103,115,121,112,0,0,0,0,0,0,119,99,57,48,98,49,0,0,109,100,95,114,111,99,107,121,98,119,0,0,0,0,0,0,84,117,114,98,111,32,79,117,116,32,82,117,110,32,40,74,97,112,97,110,44,32,79,117,116,32,82,117,110,32,117,112,103,114,97,100,101,44,32,70,68,49,48,57,52,32,51,49,55,45,48,49,49,55,41,0,0,0,0,0,0,0,0,0,80,117,103,103,115,121,32,40,69,117,114,111,41,0,0,0,115,102,105,105,105,51,110,114,49,0,0,0,0,0,0,0,97,108,116,98,101,97,115,116,54,0,0,0,0,0,0,0,85,80,68,55,55,53,57,66,97,110,107,65,100,100,114,101,115,115,0,0,0,0,0,0,57,48,32,85,110,105,116,115,0,0,0,0,0,0,0,0,109,100,95,112,117,103,103,115,121,0,0,0,0,0,0,0,80,114,111,103,101,97,114,32,40,48,49,48,49,49,55,32,85,83,65,41,0,0,0,0,102,108,105,99,107,121,111,0,100,100,99,114,101,119,117,0,102,0,0,0,97,0,0,0,108,0,0,0,115,0,0,0,101,0,0,0,0,0,0,0,83,116,114,105,107,101,32,70,105,103,104,116,101,114,32,40,74,97,112,97,110,41,0,0,83,105,103,109,97,0,0,0,114,97,99,104,101,114,111,0,99,107,111,110,103,103,0,0,70,97,110,116,97,115,121,32,90,111,110,101,32,40,117,110,112,114,111,116,101,99,116,101,100,41,0,0,0,0,0,0,80,115,121,45,79,45,66,108,97,100,101,32,40,74,112,110,41,0,0,0,0,0,0,0,118,105,100,101,111,95,99,114,111,112,95,111,118,101,114,115,99,97,110,0,0,0,0,0,103,116,109,114,50,0,0,0,109,100,95,112,115,121,111,98,108,97,100,0,0,0,0,0,83,111,117,110,100,76,97,116,99,104,0,0,0,0,0,0,67,111,110,116,114,97,32,45,32,84,104,101,32,72,97,114,100,32,67,111,114,112,115,32,40,74,112,110,41,0,0,0,84,73,77,69,82,32,66,99,110,116,0,0,0,0,0,0,50,48,48,0,0,0,0,0,67,111,105,110,115,32,116,111,32,67,111,110,116,105,110,117,101,0,0,0,0,0,0,0,53,48,37,0,0,0,0,0,78,86,32,82,97,109,0,0,109,100,95,99,111,110,116,114,97,106,0,0,0,0,0,0,53,48,107,32,49,48,48,107,32,49,53,48,107,32,50,48,48,107,0,0,0,0,0,0,116,100,114,97,103,111,110,50,97,0,0,0,0,0,0,0,66,97,100,0,0,0,0,0,68,111,117,98,108,101,85,112,0,0,0,0,0,0,0,0,122,56,48,95,105,114,113,50,0,0,0,0,0,0,0,0,103,117,110,100,97,109,101,120,0,0,0,0,0,0,0,0,67,111,110,116,114,97,32,45,32,72,97,114,100,32,67,111,114,112,115,32,40,85,83,65,44,32,75,111,114,41,0,0,86,105,114,117,115,0,0,0,247,150,0,0,89,114,0,0,32,0,0,0,83,0,0,0,116,0,0,0,114,0,0,0,97,0,0,0,116,0,0,0,111,0,0,0,32,0,0,0,70,0,0,0,105,0,0,0,103,0,0,0,104,0,0,0,116,0,0,0,101,0,0,0,114,0,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,109,100,95,99,111,110,116,114,97,0,0,0,0,0,0,0,65,117,116,111,109,97,116,105,99,0,0,0,0,0,0,0,115,102,50,117,100,0,0,0,77,117,115,105,99,32,40,65,116,116,114,97,99,116,32,77,111,100,101,41,0,0,0,0,112,99,101,95,106,99,104,97,110,0,0,0,0,0,0,0,71,97,109,101,32,83,101,108,101,99,116,105,111,110,0,0,77,101,116,97,108,32,83,108,117,103,32,51,32,40,78,71,72,45,50,53,54,48,41,0,0,0,0,0,0,0,0,0,80,114,111,98,111,116,101,99,116,111,114,32,40,69,117,114,111,41,0,0,0,0,0,0,80,114,101,116,116,121,32,83,111,108,100,105,101,114,32,83,97,105,108,111,114,32,77,111,111,110,32,40,118,101,114,46,32,57,53,47,48,51,47,50,50,44,32,74,97,112,97,110,41,0,0,0,0,0,0,0,76,97,121,101,114,32,80,97,108,101,116,116,101,32,82,65,77,0,0,0,0,0,0,0,84,104,101,32,65,100,118,101,110,116,117,114,101,115,32,111,102,32,77,105,103,104,116,121,32,77,97,120,32,40,85,83,65,41,0,0,0,0,0,0,109,100,95,112,114,111,98,111,116,0,0,0,0,0,0,0,65,101,114,111,32,70,105,103,104,116,101,114,115,32,40,84,117,114,98,111,32,70,111,114,99,101,32,104,97,114,100,119,97,114,101,32,115,101,116,32,49,41,0,0,0,0,0,0,80,114,111,32,89,97,107,121,117,117,32,83,117,112,101,114,32,76,101,97,103,117,101,32,39,57,49,32,40,74,112,110,41,0,0,0,0,0,0,0,112,114,111,103,101,97,114,0,115,104,97,100,101,114,124,99,103,124,99,103,112,124,103,108,115,108,124,103,108,115,108,112,0,0,0,0,0,0,0,0,68,97,105,111,104,32,40,115,101,116,32,49,41,0,0,0,109,100,95,112,114,111,121,97,107,121,117,0,0,0,0,0,86,105,100,101,111,32,80,111,111,108,32,40,98,111,111,116,108,101,103,32,111,110,32,77,111,111,110,32,67,114,101,115,116,97,32,104,97,114,100,119,97,114,101,41,0,0,0,0,52,105,110,49,98,111,111,116,0,0,0,0,0,0,0,0,67,111,111,107,105,101,32,38,32,66,105,98,105,0,0,0,80,114,111,32,81,117,97,114,116,101,114,98,97,99,107,32,40,85,83,65,41,0,0,0,77,105,110,105,109,117,109,32,66,97,108,108,115,32,112,101,114,32,82,111,119,0,0,0,83,116,114,105,107,101,114,115,32,49,57,52,53,32,40,75,111,114,101,97,41,0,0,0,109,100,95,112,114,111,113,98,0,0,0,0,0,0,0,0,116,101,114,114,97,102,98,0,49,57,48,0,0,0,0,0,80,114,105,110,99,101,32,111,102,32,80,101,114,115,105,97,32,50,32,45,32,84,104,101,32,83,104,97,100,111,119,32,97,110,100,32,116,104,101,32,70,108,97,109,101,32,40,69,117,114,111,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,0,0,0,80,111,109,112,105,110,103,32,87,111,114,108,100,32,40,74,97,112,97,110,41,0,0,0,49,67,32,50,67,32,47,32,49,67,32,50,67,0,0,0,78,0,0,0,0,0,0,0,109,100,95,112,112,101,114,115,105,97,50,0,0,0,0,0,69,118,101,114,121,0,0,0,82,101,116,114,111,65,114,99,104,58,32,82,101,97,100,106,117,115,116,101,100,32,114,101,119,105,110,100,32,98,117,102,102,101,114,32,115,105,122,101,32,116,111,32,37,117,32,77,105,66,10,0,0,0,0,0,50,48,107,32,32,55,48,107,32,49,50,48,107,32,49,55,48,107,0,0,0,0,0,0,80,108,97,116,101,32,80,114,111,98,97,98,105,108,105,116,121,0,0,0,0,0,0,0,112,111,112,101,121,101,109,97,110,0,0,0,0,0,0,0,71,97,117,110,116,108,101,116,32,40,114,101,118,32,50,41,0,0,0,0,0,0,0,0,80,114,105,110,99,101,32,111,102,32,80,101,114,115,105,97,32,40,85,83,65,41,0,0,51,32,76,101,116,116,101,114,115,0,0,0,0,0,0,0,49,32,67,111,105,110,32,32,50,32,80,108,97,121,0,0,109,100,95,112,112,101,114,115,105,97,117,0,0,0,0,0,68,111,110,107,101,121,32,75,111,110,103,32,73,73,32,45,32,74,117,109,112,109,97,110,32,82,101,116,117,114,110,115,32,40,86,49,46,49,41,32,40,104,97,99,107,41,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,32,45,32,84,104,101,32,87,111,114,108,100,32,87,97,114,114,105,111,114,32,40,57,49,48,51,48,54,32,85,83,65,41,0,0,0,0,0,0,74,97,99,107,32,78,105,99,107,108,97,117,115,39,32,71,114,101,97,116,101,115,116,32,49,56,32,72,111,108,101,115,32,111,102,32,77,97,106,111,114,32,67,104,97,109,112,105,111,110,115,104,105,112,32,71,111,108,102,0,0,0,0,0,53,32,67,111,105,110,115,32,51,32,67,114,101,100,105,116,115,32,0,0,0,0,0,0,109,115,108,117,103,51,104,0,80,114,105,110,99,101,32,111,102,32,80,101,114,115,105,97,32,40,80,114,111,116,111,116,121,112,101,44,32,69,97,114,108,105,101,114,41,0,0,0,109,100,95,109,105,103,104,116,109,97,120,117,0,0,0,0,65,118,101,110,103,101,114,115,32,40,85,83,32,115,101,116,32,49,41,0,0,0,0,0,109,100,95,112,112,101,114,115,105,97,112,49,0,0,0,0,78,111,109,97,32,40,67,97,115,105,110,111,32,84,101,99,104,32,108,105,99,101,110,115,101,41,0,0,0,0,0,0,105,107,97,114,105,51,107,0,83,116,97,114,116,105,110,103,32,65,114,101,97,0,0,0,68,114,118,66,103,50,79,110,0,0,0,0,0,0,0,0,103,110,103,0,0,0,0,0,80,114,105,110,99,101,32,111,102,32,80,101,114,115,105,97,32,40,80,114,111,116,111,116,121,112,101,41,0,0,0,0,86,97,109,112,105,114,101,32,72,117,110,116,101,114,32,45,32,100,97,114,107,115,116,97,108,107,101,114,115,39,32,114,101,118,101,110,103,101,32,40,57,53,48,51,48,50,32,74,97,112,97,110,41,0,0,0,71,97,108,97,120,105,97,110,32,40,78,97,109,99,111,32,115,101,116,32,49,41,0,0,66,117,122,122,97,114,100,0,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,109,101,109,111,114,121,32,102,111,114,32,112,97,116,99,104,101,100,32,82,79,77,32,46,46,46,10,0,0,0,0,0,109,100,95,112,112,101,114,115,105,97,112,0,0,0,0,0,104,117,115,116,108,101,114,0,32,50,32,67,111,105,110,115,32,49,32,67,114,101,100,105,116,0,0,0,0,0,0,0,68,105,97,109,111,110,100,32,82,117,110,0,0,0,0,0,49,32,67,111,105,110,32,32,50,32,67,114,101,100,105,116,115,32,47,32,49,32,67,111,105,110,32,32,53,32,32,67,114,101,100,105,116,115,0,0,80,114,105,110,99,101,32,111,102,32,80,101,114,115,105,97,32,40,69,117,114,111,41,0,0,0,0,0,0,0,0,0,87,99,57,48,90,56,48,66,97,110,107,65,100,100,114,101,115,115,50,0,0,0,0,0,109,100,95,112,112,101,114,115,105,97,0,0,0,0,0,0,68,111,117,98,108,101,32,68,114,97,103,111,110,32,73,73,32,45,32,84,104,101,32,82,101,118,101,110,103,101,32,40,85,83,41,0,0,0,0,0,80,114,111,116,101,99,116,105,111,110,32,82,101,103,105,115,116,101,114,115,0,0,0,0,49,56,48,0,0,0,0,0,80,114,105,109,101,32,84,105,109,101,32,78,70,76,32,83,116,97,114,114,105,110,103,32,68,101,105,111,110,32,83,97,110,100,101,114,115,32,40,85,83,65,41,0,0,0,0,0,109,100,95,112,114,105,109,101,116,105,109,0,0,0,0,0,83,99,111,114,101,0,0,0,80,114,105,109,97,108,32,82,97,103,101,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,0,0,0,112,99,101,95,97,114,109,101,100,102,0,0,0,0,0,0,109,100,95,112,114,105,109,97,108,0,0,0,0,0,0,0,115,102,50,117,99,0,0,0,69,0,0,0,115,0,0,0,112,0,0,0,103,0,0,0,97,0,0,0,108,0,0,0,117,0,0,0,100,0,0,0,97,0,0,0,0,0,0,0,168,48,0,0,185,48,0,0,215,48,0,0,172,48,0,0,235,48,0,0,252,48,0,0,192,48,0,0,32,0,0,0,40,0,0,0,86,0,0,0,49,0,0,0,48,0,0,0,48,0,0,0,44,0,0,0,32,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,99,101,95,110,105,99,107,108,97,117,115,0,0,0,0,99,97,112,116,99,111,109,109,117,0,0,0,0,0,0,0,77,101,116,97,108,32,83,108,117,103,32,51,32,40,78,71,77,45,50,53,54,48,41,0,0,0,0,0,0,0,0,0,82,105,100,105,110,103,32,72,101,114,111,32,40,115,101,116,32,50,41,0,0,0,0,0,80,114,101,109,105,101,114,32,77,97,110,97,103,101,114,32,57,55,32,40,69,117,114,111,41,0,0,0,0,0,0,0,98,54,56,75,66,111,97,114,100,82,79,77,66,97,110,107,101,100,73,110,0,0,0,0,109,114,102,108,101,97,0,0,84,104,101,32,65,100,118,101,110,116,117,114,101,115,32,111,102,32,66,97,116,109,97,110,32,38,32,82,111,98,105,110,32,40,85,83,65,41,0,0,109,100,95,112,114,101,109,114,109,57,55,0,0,0,0,0,80,114,101,109,105,101,114,32,77,97,110,97,103,101,114,32,40,69,117,114,111,41,0,0,118,104,117,110,116,106,114,50,0,0,0,0,0,0,0,0,79,80,76,45,62,110,111,105,115,101,95,114,110,103,0,0,109,100,95,112,114,101,109,105,101,114,109,0,0,0,0,0,118,112,111,111,108,0,0,0,84,101,120,116,117,114,101,0,80,114,101,100,97,116,111,114,32,50,32,40,69,117,114,111,44,32,85,83,65,41,0,0,82,101,116,114,111,65,114,99,104,58,32,71,76,58,32,76,111,97,100,101,100,32,37,117,32,112,114,111,103,114,97,109,40,115,41,46,10,0,0,0,37,115,32,45,32,37,115,32,37,115,0,0,0,0,0,0,109,100,95,112,114,101,100,97,116,114,50,0,0,0,0,0,74,111,121,112,97,100,0,0,65,99,99,108,97,105,109,32,69,110,116,101,114,116,97,105,110,109,101,110,116,0,0,0,87,114,101,115,116,108,101,98,97,108,108,32,40,74,112,110,41,0,0,0,0,0,0,0,49,55,48,0,0,0,0,0,114,98,0,0,0,0,0,0,72,111,118,101,114,32,67,121,99,108,101,0,0,0,0,0,45,37,117,46,99,102,103,0,78,111,32,67,111,105,110,32,66,0,0,0,0,0,0,0,109,100,95,119,114,115,116,98,97,108,108,0,0,0,0,0,80,108,97,121,32,73,110,110,105,110,103,0,0,0,0,0,80,111,119,101,114,98,97,108,108,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,102,105,110,100,32,118,101,114,116,101,120,32,115,104,97,100,101,114,32,110,111,114,32,102,114,97,103,109,101,110,116,32,115,104,97,100,101,114,32,105,110,32,88,77,76,32,102,105,108,101,46,10,0,0,0,0,0,0,84,104,101,32,70,105,110,97,108,32,82,111,117,110,100,32,40,118,101,114,46,32,77,41,0,0,0,0,0,0,0,0,109,100,95,112,111,119,101,114,98,97,108,0,0,0,0,0,97,114,109,119,97,114,117,0,49,32,67,111,105,110,32,32,55,32,67,114,101,100,105,116,115,32,0,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,32,45,32,84,104,101,32,87,111,114,108,100,32,87,97,114,114,105,111,114,32,40,57,49,48,50,49,52,32,85,83,65,41,0,0,0,0,0,0,69,115,112,103,97,108,117,100,97,32,40,86,49,48,48,44,32,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,74,46,32,76,101,97,103,117,101,32,71,114,101,97,116,101,115,116,32,69,108,101,118,101,110,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,79,118,101,114,108,97,121,32,100,101,115,99,32,105,115,32,105,110,118,97,108,105,100,46,32,82,101,113,117,105,114,101,115,32,97,116,32,108,101,97,115,116,32,54,32,116,111,107,101,110,115,46,10,0,0,0,80,111,119,101,114,32,77,111,110,103,101,114,32,40,74,112,110,44,32,75,111,114,41,0,0,0,0,0,0,0,0,0,109,100,95,97,100,118,98,97,116,114,117,0,0,0,0,0,77,46,73,46,65,46,32,45,32,77,105,115,115,105,110,103,32,105,110,32,65,99,116,105,111,110,32,40,118,101,114,46,32,83,41,0,0,0,0,0,71,117,115,115,117,110,32,79,121,111,121,111,32,40,74,97,112,97,110,41,0,0,0,0,76,111,100,101,32,82,117,110,110,101,114,32,73,73,73,32,45,32,84,104,101,32,71,111,108,100,101,110,32,76,97,98,121,114,105,110,116,104,0,0,109,100,95,112,109,111,110,103,101,114,106,0,0,0,0,0,97,114,97,98,105,97,110,0,77,114,46,32,72,69,76,73,32,110,111,32,68,97,105,45,66,111,117,107,101,110,0,0,80,111,119,101,114,32,77,111,110,103,101,114,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,0,0,86,97,109,112,105,114,101,32,72,117,110,116,101,114,32,45,32,100,97,114,107,115,116,97,108,107,101,114,115,39,32,114,101,118,101,110,103,101,32,40,57,53,48,51,48,55,32,74,97,112,97,110,41,0,0,0,109,100,95,112,109,111,110,103,101,114,0,0,0,0,0,0,68,111,110,107,101,121,32,75,111,110,103,32,74,114,46,32,40,77,111,111,110,32,67,114,101,115,116,97,32,104,97,114,100,119,97,114,101,41,0,0,67,97,118,101,109,97,110,32,78,105,110,106,97,32,40,87,111,114,108,100,32,118,101,114,32,52,41,0,0,0,0,0,80,111,119,101,114,32,68,114,105,118,101,32,40,69,117,114,111,41,0,0,0,0,0,0,109,100,95,112,100,114,105,118,101,0,0,0,0,0,0,0,49,54,48,0,0,0,0,0,80,111,112,117,108,111,117,115,32,40,85,83,65,41,0,0,83,112,97,99,101,32,83,104,105,112,0,0,0,0,0,0,109,100,95,112,111,112,117,108,111,117,115,117,0,0,0,0,76,97,115,116,67,104,97,110,103,101,0,0,0,0,0,0,80,111,112,117,108,111,117,115,32,40,74,112,110,41,0,0,109,100,95,112,111,112,117,108,111,117,115,106,0,0,0,0,115,102,50,117,98,0,0,0,101,115,112,103,97,108,0,0,112,99,101,95,106,108,101,97,103,49,49,0,0,0,0,0,109,115,108,117,103,51,0,0,80,111,112,117,108,111,117,115,32,40,69,117,114,111,41,0,0,0,0,0,0,0,0,0,84,104,101,32,65,100,118,101,110,116,117,114,101,115,32,111,102,32,66,97,116,109,97,110,32,38,32,82,111,98,105,110,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,53,48,49,41,0,0,109,100,95,112,111,112,117,108,111,117,115,0,0,0,0,0,80,111,107,101,109,111,110,32,67,114,97,122,121,32,68,114,117,109,109,101,114,0,0,0,118,104,117,110,116,106,114,49,0,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,37,115,32,118,105,114,116,117,97,108,32,100,105,115,107,32,116,114,97,121,46,0,105,107,107,105,0,0,0,0,109,100,95,112,111,107,101,99,100,0,0,0,0,0,0,0,68,97,114,107,112,108,110,116,66,117,108,108,101,116,67,111,108,111,117,114,0,0,0,0,80,111,99,107,101,116,32,77,111,110,115,116,101,114,115,32,50,0,0,0,0,0,0,0,109,100,95,112,111,107,101,109,111,110,50,0,0,0,0,0,49,53,48,0,0,0,0,0,80,111,99,107,101,116,32,77,111,110,115,116,101,114,115,32,40,65,108,116,41,0,0,0,83,104,105,112,32,84,121,112,101,0,0,0,0,0,0,0,109,100,95,112,111,107,101,109,111,110,97,0,0,0,0,0,82,101,115,101,116,32,84,105,109,101,114,47,79,98,106,101,99,116,115,32,111,110,32,76,105,102,101,32,76,111,115,115,0,0,0,0,0,0,0,0,74,111,101,32,38,32,77,97,99,32,82,101,116,117,114,110,115,32,40,87,111,114,108,100,44,32,86,101,114,115,105,111,110,32,49,46,49,44,32,49,57,57,52,46,48,53,46,50,55,41,0,0,0,0,0,0,69,120,112,108,97,110,97,116,105,111,110,0,0,0,0,0,80,111,99,107,101,116,32,77,111,110,115,116,101,114,115,0,0,0,0,0,0,0,0,0,109,100,95,112,111,107,101,109,111,110,0,0,0,0,0,0,115,108,45,62,109,117,108,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,32,45,32,84,104,101,32,87,111,114,108,100,32,87,97,114,114,105,111,114,32,40,57,49,48,50,48,54,32,85,83,65,41,0,0,0,0,0,0,75,0,0,0,101,0,0,0,116,0,0,0,115,0,0,0,117,0,0,0,105,0,0,0,32,0,0,0,75,0,0,0,105,0,0,0,122,0,0,0,117,0,0,0,110,0,0,0,97,0,0,0,32,0,0,0,74,0,0,0,105,0,0,0,103,0,0,0,111,0,0,0,107,0,0,0,117,0,0,0,32,0,0,0,84,0,0,0,97,0,0,0,99,0,0,0,104,0,0,0,105,0,0,0,0,0,0,0,177,48,0,0,196,48,0,0,164,48,0,0,126,0,0,0,70,125,0,0,48,87,0,0,68,115,0,0,95,48,0,0,97,48,0,0,32,0,0,0,40,0,0,0,77,0,0,0,82,0,0,0,46,0,0,0,32,0,0,0,83,0,0,0,116,0,0,0,111,0,0,0,105,0,0,0,99,0,0,0,32,0,0,0,118,0,0,0,101,0,0,0,114,0,0,0,115,0,0,0,105,0,0,0,111,0,0,0,110,0,0,0,44,0,0,0,32,0,0,0,104,0,0,0,97,0,0,0,99,0,0,0,107,0,0,0,32,0,0,0,98,0,0,0,121,0,0,0,32,0,0,0,84,0,0,0,114,0,0,0,97,0,0,0,112,0,0,0,49,0,0,0,53,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,73,109,97,103,101,32,70,105,103,104,116,0,0,0,0,0,71,0,0,0,97,0,0,0,114,0,0,0,111,0,0,0,117,0,0,0,0,0,0,0,19,153,0,0,252,114,0,0,32,0,0,0,45,0,0,0,32,0,0,0,109,0,0,0,97,0,0,0,114,0,0,0,107,0,0,0,32,0,0,0,111,0,0,0,102,0,0,0,32,0,0,0,116,0,0,0,104,0,0,0,101,0,0,0,32,0,0,0,119,0,0,0,111,0,0,0,108,0,0,0,118,0,0,0,101,0,0,0,115,0,0,0,32,0,0,0,40,0,0,0,98,0,0,0,111,0,0,0,111,0,0,0,116,0,0,0,108,0,0,0,101,0,0,0,103,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,111,99,97,104,111,110,116,97,115,32,40,85,83,65,41,0,0,0,0,0,0,0,0,109,100,95,97,100,118,98,97,116,114,112,48,49,0,0,0,109,100,95,112,111,99,97,104,111,110,116,117,0,0,0,0,80,111,99,97,104,111,110,116,97,115,32,40,69,117,114,111,41,0,0,0,0,0,0,0,86,97,109,112,105,114,101,32,72,117,110,116,101,114,32,45,32,100,97,114,107,115,116,97,108,107,101,114,115,39,32,114,101,118,101,110,103,101,32,40,57,53,48,51,48,55,32,74,97,112,97,110,32,115,116,111,112,32,118,101,114,115,105,111,110,41,0,0,0,0,0,0,109,100,95,112,111,99,97,104,111,110,116,0,0,0,0,0,100,107,111,110,103,106,114,109,0,0,0,0,0,0,0,0,80,105,116,102,97,108,108,32,45,32,84,104,101,32,77,97,121,97,110,32,65,100,118,101,110,116,117,114,101,32,40,85,83,65,41,0,0,0,0,0,109,100,95,112,105,116,102,97,108,108,117,0,0,0,0,0,49,52,48,0,0,0,0,0,65,99,116,105,118,105,115,105,111,110,0,0,0,0,0,0,53,48,48,107,32,111,110,108,121,0,0,0,0,0,0,0,80,105,116,102,97,108,108,32,45,32,84,104,101,32,77,97,121,97,110,32,65,100,118,101,110,116,117,114,101,32,40,69,117,114,111,41,0,0,0,0,83,108,111,116,32,83,121,115,116,101,109,0,0,0,0,0,80,111,110,0,0,0,0,0,109,100,95,112,105,116,102,97,108,108,0,0,0,0,0,0,103,97,108,97,112,52,0,0,80,105,116,45,70,105,103,104,116,101,114,32,40,87,111,114,108,100,41,0,0,0,0,0,103,97,108,97,103,97,0,0,115,102,50,117,97,0,0,0,75,101,116,115,117,105,32,75,105,122,117,110,97,32,74,105,103,111,107,117,32,84,97,99,104,105,32,40,77,82,46,32,83,116,111,105,99,32,118,101,114,115,105,111,110,44,32,104,97,99,107,32,98,121,32,84,114,97,112,49,53,41,0,0,112,99,101,95,105,109,97,103,101,102,103,116,0,0,0,0,71,97,114,111,117,32,45,32,77,97,114,107,32,111,102,32,116,104,101,32,87,111,108,118,101,115,32,40,98,111,111,116,108,101,103,41,0,0,0,0,109,100,95,112,105,116,102,105,103,104,116,49,0,0,0,0,84,104,101,32,65,100,118,101,110,116,117,114,101,115,32,111,102,32,66,97,116,109,97,110,32,38,32,82,111,98,105,110,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,52,50,56,41,0,0,65,99,116,45,70,97,110,99,101,114,32,67,121,98,101,114,110,101,116,105,99,107,32,72,121,112,101,114,32,87,101,97,112,111,110,32,40,87,111,114,108,100,32,114,101,118,105,115,105,111,110,32,50,41,0,0,84,104,101,32,67,108,105,102,102,104,97,110,103,101,114,32,45,32,69,100,119,97,114,100,32,82,97,110,100,121,32,40,87,111,114,108,100,32,118,101,114,32,51,41,0,0,0,0,80,105,116,45,70,105,103,104,116,101,114,32,40,87,111,114,108,100,44,32,82,101,118,46,32,65,41,0,0,0,0,0,109,100,95,112,105,116,102,105,103,104,116,0,0,0,0,0,100,84,105,109,101,89,77,51,53,50,54,0,0,0,0,0,118,104,117,110,116,106,114,49,115,0,0,0,0,0,0,0,80,105,114,97,116,101,115,33,32,71,111,108,100,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,41,0,0,68,105,102,102,105,99,117,108,116,121,32,40,84,105,109,101,41,0,0,0,0,0,0,0,109,100,95,112,105,114,97,116,101,115,112,0,0,0,0,0,80,105,114,97,116,101,115,33,32,71,111,108,100,32,40,85,83,65,41,0,0,0,0,0,49,51,48,0,0,0,0,0,109,100,95,112,105,114,97,116,101,115,0,0,0,0,0,0,53,48,48,107,32,97,110,100,32,49,48,48,48,107,0,0,84,104,101,32,80,105,114,97,116,101,115,32,111,102,32,68,97,114,107,32,87,97,116,101,114,32,40,69,117,114,111,44,32,85,83,65,44,32,77,97,121,32,49,57,57,52,41,0,0,0,0,0,0,0,0,0,53,48,107,32,97,110,100,32,50,48,48,107,0,0,0,0,109,100,95,112,105,114,97,116,101,100,119,49,0,0,0,0,84,104,101,32,80,105,114,97,116,101,115,32,111,102,32,68,97,114,107,32,87,97,116,101,114,32,40,85,83,65,44,32,74,97,110,117,97,114,121,32,49,57,57,52,41,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,32,45,32,84,104,101,32,87,111,114,108,100,32,87,97,114,114,105,111,114,32,40,83,84,84,44,32,84,65,66,32,65,117,115,116,114,105,97,32,98,111,111,116,108,101,103,44,32,57,49,48,50,49,52,32,101,116,99,41,0,0,0,0,107,101,116,115,116,111,105,99,117,0,0,0,0,0,0,0,71,97,109,101,32,69,120,112,114,101,115,115,0,0,0,0,103,97,114,111,117,98,108,0,109,100,95,112,105,114,97,116,101,100,119,0,0,0,0,0,109,100,95,97,100,118,98,97,116,114,112,48,50,0,0,0,80,105,110,111,99,99,104,105,111,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,109,100,95,112,105,110,111,99,117,0,0,0,0,0,0,0,86,97,109,112,105,114,101,32,72,117,110,116,101,114,32,45,32,100,97,114,107,115,116,97,108,107,101,114,115,39,32,114,101,118,101,110,103,101,32,40,57,53,48,51,49,54,32,74,97,112,97,110,41,0,0,0,80,105,110,111,99,99,104,105,111,32,40,69,117,114,111,41,0,0,0,0,0,0,0,0,66,97,103,109,97,110,32,40,98,111,111,116,108,101,103,32,111,110,32,77,111,111,110,32,67,114,101,115,116,97,32,104,97,114,100,119,97,114,101,32,115,101,116,32,50,41,0,0,83,105,100,101,32,80,111,99,107,101,116,32,40,87,111,114,108,100,41,0,0,0,0,0,109,100,95,112,105,110,111,99,0,0,0,0,0,0,0,0,80,105,110,107,32,71,111,101,115,32,116,111,32,72,111,108,108,121,119,111,111,100,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,0,0,0,49,50,48,0,0,0,0,0,109,100,95,112,105,110,107,112,0,0,0,0,0,0,0,0,53,48,48,107,44,32,49,48,48,48,107,32,97,110,100,32,49,53,48,48,107,0,0,0,80,104,101,108,105,111,115,32,40,85,83,65,41,0,0,0,52,48,107,44,32,49,50,48,107,32,97,110,100,32,52,56,48,107,0,0,0,0,0,0,37,112,0,0,0,0,0,0,109,100,95,112,104,101,108,105,111,115,117,0,0,0,0,0,80,104,101,108,105,111,115,32,40,74,112,110,41,0,0,0,115,102,50,115,116,116,0,0,75,0,0,0,101,0,0,0,116,0,0,0,115,0,0,0,117,0,0,0,105,0,0,0,32,0,0,0,75,0,0,0,105,0,0,0,122,0,0,0,117,0,0,0,110,0,0,0,97,0,0,0,32,0,0,0,74,0,0,0,105,0,0,0,103,0,0,0,111,0,0,0,107,0,0,0,117,0,0,0,32,0,0,0,84,0,0,0,97,0,0,0,99,0,0,0,104,0,0,0,105,0,0,0,0,0,0,0,177,48,0,0,196,48,0,0,164,48,0,0,126,0,0,0,70,125,0,0,48,87,0,0,68,115,0,0,95,48,0,0,97,48,0,0,32,0,0,0,40,0,0,0,65,0,0,0,114,0,0,0,114,0,0,0,97,0,0,0,110,0,0,0,103,0,0,0,101,0,0,0,32,0,0,0,77,0,0,0,111,0,0,0,100,0,0,0,101,0,0,0,32,0,0,0,118,0,0,0,101,0,0,0,114,0,0,0,115,0,0,0,105,0,0,0,111,0,0,0,110,0,0,0,32,0,0,0,49,0,0,0,46,0,0,0,53,0,0,0,49,0,0,0,44,0,0,0,32,0,0,0,104,0,0,0,97,0,0,0,99,0,0,0,107,0,0,0,32,0,0,0,98,0,0,0,121,0,0,0,32,0,0,0,84,0,0,0,114,0,0,0,97,0,0,0,112,0,0,0,49,0,0,0,53,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,73,100,111,108,32,72,97,110,97,102,117,100,97,32,70,97,110,32,67,108,117,98,0,0,78,111,114,109,97,108,32,67,111,105,110,32,67,114,101,100,105,116,0,0,0,0,0,0,71,0,0,0,97,0,0,0,114,0,0,0,111,0,0,0,117,0,0,0,0,0,0,0,19,153,0,0,252,114,0,0,32,0,0,0,45,0,0,0,32,0,0,0,109,0,0,0,97,0,0,0,114,0,0,0,107,0,0,0,32,0,0,0,111,0,0,0,102,0,0,0,32,0,0,0,116,0,0,0,104,0,0,0,101,0,0,0,32,0,0,0,119,0,0,0,111,0,0,0,108,0,0,0,118,0,0,0,101,0,0,0,115,0,0,0,32,0,0,0,40,0,0,0,112,0,0,0,114,0,0,0,111,0,0,0,116,0,0,0,111,0,0,0,116,0,0,0,121,0,0,0,112,0,0,0,101,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,109,100,95,112,104,101,108,105,111,115,106,0,0,0,0,0,84,104,101,32,65,100,118,101,110,116,117,114,101,115,32,111,102,32,66,97,116,109,97,110,32,38,32,82,111,98,105,110])
.concat([32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,52,50,55,41,0,0,71,101,97,114,0,0,0,0,80,104,101,108,105,111,115,32,40,69,117,114,111,41,0,0,78,105,116,114,111,32,66,97,108,108,32,40,85,83,41,0,0,0,0,0,0,0,0,0,109,100,95,112,104,101,108,105,111,115,0,0,0,0,0,0,118,104,117,110,116,106,0,0,82,45,62,116,105,109,101,114,95,111,118,101,114,0,0,0,109,97,110,105,97,99,115,113,0,0,0,0,0,0,0,0,71,97,109,101,32,100,105,102,102,105,99,117,108,116,121,0,49,32,99,111,105,110,32,50,32,99,114,101,100,105,116,115,0,0,0,0,0,0,0,0,102,105,120,101,105,103,104,116,106,116,0,0,0,0,0,0,80,104,97,110,116,111,109,32,50,48,52,48,32,40,85,83,65,41,0,0,0,0,0,0,115,108,97,112,102,105,103,104,0,0,0,0,0,0,0,0,98,97,103,109,97,110,109,50,0,0,0,0,0,0,0,0,72,97,114,100,101,115,116,0,85,83,65,47,84,97,105,116,111,32,65,109,101,114,105,99,97,0,0,0,0,0,0,0,109,100,95,112,104,97,110,116,111,109,117,0,0,0,0,0,99,104,105,112,45,62,119,98,97,110,107,0,0,0,0,0,115,111,110,115,111,110,0,0,80,104,97,110,116,111,109,32,50,48,52,48,32,40,69,117,114,111,41,0,0,0,0,0,67,114,117,100,101,32,66,117,115,116,101,114,32,40,87,111,114,108,100,32,70,88,32,118,101,114,115,105,111,110,41,0,0,0,0,0,0,0,0,0,49,49,48,0,0,0,0,0,109,100,95,112,104,97,110,116,111,109,0,0,0,0,0,0,102,102,97,110,116,97,115,121,0,0,0,0,0,0,0,0,84,97,105,116,111,87,97,116,99,104,100,111,103,0,0,0,68,111,110,32,68,111,107,111,32,68,111,110,32,40,74,97,112,97,110,41,0,0,0,0,80,104,97,110,116,97,115,121,32,83,116,97,114,32,45,32,84,104,101,32,69,110,100,32,111,102,32,116,104,101,32,77,105,108,108,101,110,110,105,117,109,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,49,48,50,55,41,0,0,0,0,0,0,0,0,0,50,48,107,44,32,116,104,101,110,32,101,118,101,114,121,32,51,48,107,0,0,0,0,0,118,112,99,95,118,100,99,49,95,101,110,97,98,108,101,100,91,105,93,0,0,0,0,0,65,114,107,97,110,111,105,100,32,40,98,111,111,116,108,101,103,32,119,105,116,104,32,77,67,85,44,32,104,97,114,100,101,114,44,32,97,108,116,41,0,0,0,0,0,0,0,0,78,117,109,98,101,114,32,111,102,32,99,111,110,116,114,111,108,108,101,114,0,0,0,0,109,100,95,112,115,116,97,114,52,112,50,0,0,0,0,0,67,114,105,109,101,32,67,105,116,121,32,40,87,111,114,108,100,41,0,0,0,0,0,0,99,111,110,116,99,105,114,99,0,0,0,0,0,0,0,0,80,104,97,110,116,97,115,121,32,83,116,97,114,32,45,32,84,104,101,32,69,110,100,32,111,102,32,116,104,101,32,77,105,108,108,101,110,110,105,117,109,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,49,49,48,55,41,0,0,0,0,0,0,0,0,0,114,98,105,115,108,97,110,100,111,0,0,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,32,45,32,84,104,101,32,87,111,114,108,100,32,87,97,114,114,105,111,114,32,40,84,65,66,32,65,117,115,116,114,105,97,32,98,111,111,116,108,101,103,44,32,57,49,48,50,49,52,32,101,116,99,41,0,0,0,0,0,0,0,0,0,109,111,102,102,108,111,116,116,0,0,0,0,0,0,0,0,75,101,116,115,117,105,32,75,105,122,117,110,97,32,74,105,103,111,107,117,32,84,97,99,104,105,32,40,65,114,114,97,110,103,101,32,77,111,100,101,32,118,101,114,115,105,111,110,32,49,46,53,49,44,32,104,97,99,107,32,98,121,32,84,114,97,112,49,53,41,0,0,112,99,101,95,105,100,111,108,104,97,110,97,0,0,0,0,71,97,114,111,117,32,45,32,77,97,114,107,32,111,102,32,116,104,101,32,87,111,108,118,101,115,32,40,112,114,111,116,111,116,121,112,101,41,0,0,66,117,98,98,108,101,32,66,111,98,98,108,101,32,76,111,115,116,32,67,97,118,101,32,40,118,49,46,49,41,0,0,100,97,105,115,101,110,112,117,0,0,0,0,0,0,0,0,109,100,95,112,115,116,97,114,52,112,49,0,0,0,0,0,109,100,95,97,100,118,98,97,116,114,112,48,51,0,0,0,116,111,117,116,114,117,110,106,0,0,0,0,0,0,0,0,80,104,97,110,116,97,115,121,32,83,116,97,114,32,45,32,84,104,101,32,69,110,100,32,111,102,32,116,104,101,32,77,105,108,108,101,110,110,105,117,109,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,53,51,48,41,0,0,0,0,0,0,0,0,0,98,83,111,117,110,100,108,97,116,99,104,82,101,97,100,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,73,32,51,114,100,32,83,116,114,105,107,101,58,32,70,105,103,104,116,32,102,111,114,32,116,104,101,32,70,117,116,117,114,101,32,40,85,83,65,32,57,57,48,53,49,50,41,0,0,0,0,0,0,0,0,65,108,116,101,114,101,100,32,66,101,97,115,116,32,40,115,101,116,32,53,44,32,70,68,49,48,57,52,32,51,49,55,45,48,48,54,57,41,0,0,78,55,55,53,49,82,111,109,65,100,100,114,101,115,115,0,49,50,48,32,85,110,105,116,115,0,0,0,0,0,0,0,109,100,95,112,115,116,97,114,52,112,53,0,0,0,0,0,78,105,103,104,116,32,87,97,114,114,105,111,114,115,32,45,32,100,97,114,107,115,116,97,108,107,101,114,115,39,32,114,101,118,101,110,103,101,32,40,57,53,48,52,48,54,32,85,83,65,41,0,0,0,0,0,70,108,105,99,107,121,32,40,49,50,56,107,32,86,101,114,115,105,111,110,44,32,83,121,115,116,101,109,32,50,44,32,110,111,116,32,101,110,99,114,121,112,116,101,100,44,32,97,108,116,32,103,114,97,112,104,105,99,115,41,0,0,0,0,68,46,32,68,46,32,67,114,101,119,32,40,115,101,116,32,54,44,32,74,97,112,97,110,44,32,50,32,80,108,97,121,101,114,115,44,32,70,68,49,48,57,52,32,51,49,55,45,48,49,56,50,41,0,0,0,115,116,114,107,102,103,116,114,0,0,0,0,0,0,0,0,80,104,97,110,116,97,115,121,32,83,116,97,114,32,45,32,84,104,101,32,69,110,100,32,111,102,32,116,104,101,32,77,105,108,108,101,110,110,105,117,109,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,54,48,56,41,0,0,0,0,0,0,0,0,0,76,105,110,101,32,111,102,32,70,105,114,101,32,47,32,66,97,107,117,100,97,110,32,89,97,114,111,117,32,40,85,83,44,32,70,68,49,48,57,52,32,51,49,55,45,48,49,51,53,41,0,0,0,0,0,0,102,97,110,116,122,111,110,101,49,0,0,0,0,0,0,0,109,100,95,112,115,116,97,114,52,112,52,0,0,0,0,0,118,105,100,101,111,95,115,99,97,108,101,95,105,110,116,101,103,101,114,0,0,0,0,0,71,114,101,97,116,32,49,48,48,48,32,77,105,108,101,115,32,82,97,108,108,121,58,32,85,46,83,46,65,32,86,101,114,115,105,111,110,33,32,40,57,52,47,48,57,47,48,54,41,0,0,0,0,0,0,0,80,104,97,110,116,97,115,121,32,83,116,97,114,32,45,32,84,104,101,32,69,110,100,32,111,102,32,116,104,101,32,77,105,108,108,101,110,110,105,117,109,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,56,49,53,41,0,0,0,0,0,0,0,0,0,49,48,48,0,0,0,0,0,109,100,95,112,115,116,97,114,52,112,51,0,0,0,0,0,49,48,37,0,0,0,0,0,68,101,109,111,32,77,117,115,105,99,0,0,0,0,0,0,101,110,97,98,108,101,95,115,117,98,95,105,114,113,0,0,80,104,97,110,116,97,115,121,32,83,116,97,114,32,45,32,83,101,110,110,101,110,107,105,32,110,111,32,79,119,97,114,105,32,110,105,32,40,74,112,110,41,0,0,0,0,0,0,71,97,109,101,32,80,97,117,115,101,0,0,0,0,0,0,84,73,77,69,82,32,66,0,69,118,101,114,121,32,53,48,107,0,0,0,0,0,0,0,78,77,75,0,0,0,0,0,66,111,109,98,115,0,0,0,122,56,48,95,105,114,113,49,0,0,0,0,0,0,0,0,86,97,112,111,114,32,84,114,97,105,108,32,45,32,72,121,112,101,114,32,79,102,102,101,110,99,101,32,70,111,114,109,97,116,105,111,110,32,40,87,111,114,108,100,32,114,101,118,105,115,105,111,110,32,49,41,0,0,0,0,0,0,0,0,218,48,0,0,243,48,0,0,174,48,0,0,243,48,0,0,32,0,0,0,214,48,0,0,233,48,0,0,182,48,0,0,252,48,0,0,186,48,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,80,0,0,0,101,0,0,0,110,0,0,0,103,0,0,0,117,0,0,0,105,0,0,0,110,0,0,0,32,0,0,0,66,0,0,0,114,0,0,0,111,0,0,0,116,0,0,0,104,0,0,0,101,0,0,0,114,0,0,0,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,109,100,95,112,115,116,97,114,52,106,0,0,0,0,0,0,114,97,108,108,121,120,0,0,80,111,98,121,0,0,0,0,82,97,105,103,97,32,45,32,83,116,114,97,116,111,32,70,105,103,104,116,101,114,32,40,74,97,112,97,110,41,0,0,80,104,97,110,116,97,115,121,32,83,116,97,114,32,45,32,84,104,101,32,69,110,100,32,111,102,32,116,104,101,32,77,105,108,108,101,110,110,105,117,109,32,40,69,117,114,111,41,0,0,0,0,0,0,0,0,66,97,99,107,104,97,110,100,0,0,0,0,0,0,0,0,68,114,118,86,82,101,103,0,115,102,50,101,98,98,108,0,107,101,116,97,114,114,49,53,49,0,0,0,0,0,0,0,102,97,110,116,115,105,97,50,0,0,0,0,0,0,0,0,72,111,110,111,111,32,110,111,32,84,111,117,107,121,117,117,106,105,32,45,32,68,111,100,103,101,32,68,97,110,112,101,105,0,0,0,0,0,0,0,69,120,112,108,97,110,101,32,84,121,112,101,0,0,0,0,103,97,114,111,117,112,0,0,80,104,97,110,116,97,115,121,32,83,116,97,114,32,45,32,84,104,101,32,69,110,100,32,111,102,32,116,104,101,32,77,105,108,108,101,110,110,105,117,109,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,115,97,105,108,111,114,109,110,111,106,0,0,0,0,0,0,83,112,114,105,116,101,32,80,97,108,101,116,116,101,32,82,65,77,0,0,0,0,0,0,84,104,101,32,65,100,118,101,110,116,117,114,101,115,32,111,102,32,66,97,116,109,97,110,32,38,32,82,111,98,105,110,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,52,50,54,41,0,0,109,100,95,112,115,116,97,114,52,0,0,0,0,0,0,0,97,101,114,111,102,103,116,98,0,0,0,0,0,0,0,0,109,100,95,112,115,116,97,114,52,117,0,0,0,0,0,0,110,119,97,114,114,117,0,0,67,104,117,116,101,32,84,121,112,101,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,48,82,71,66,49,53,53,53,32,112,105,120,101,108,32,102,111,114,109,97,116,32,105,115,32,100,101,112,114,101,99,97,116,101,100,44,32,97,110,100,32,119,105,108,108,32,98,101,32,115,108,111,119,101,114,46,32,70,111,114,32,49,53,47,49,54,45,98,105,116,44,32,82,71,66,53,54,53,32,102,111,114,109,97,116,32,105,115,32,112,114,101,102,101,114,114,101,100,46,10,0,0,0,0,0,0,0,0,100,97,105,111,104,0,0,0,80,104,97,110,116,97,115,121,32,83,116,97,114,32,73,73,73,32,45,32,84,111,107,105,32,110,111,32,75,101,105,115,104,111,117,115,104,97,32,40,74,112,110,41,0,0,0,0,80,117,122,122,108,101,32,66,114,101,97,107,0,0,0,0,99,111,111,107,98,105,98,0,109,100,95,112,115,116,97,114,51,106,0,0,0,0,0,0,115,49,57,52,53,107,0,0,80,49,32,98,117,116,116,111,110,32,50,0,0,0,0,0,80,104,97,110,116,97,115,121,32,83,116,97,114,32,73,73,73,32,45,32,71,101,110,101,114,97,116,105,111,110,115,32,111,102,32,68,111,111,109,32,40,66,114,97,41,0,0,0,100,105,115,97,98,108,101,100,0,0,0,0,0,0,0,0,109,100,95,112,115,116,97,114,51,98,114,0,0,0,0,0,112,111,109,112,105,110,103,119,0,0,0,0,0,0,0,0,49,67,32,49,67,32,47,32,49,67,32,54,67,0,0,0,77,0,0,0,0,0,0,0,50,110,100,0,0,0,0,0,80,104,97,110,116,97,115,121,32,83,116,97,114,32,73,73,73,32,45,32,71,101,110,101,114,97,116,105,111,110,115,32,111,102,32,68,111,111,109,32,40,69,117,114,111,44,32,85,83,65,44,32,75,111,114,41,0,0,0,0,0,0,0,0,69,118,101,114,121,32,52,48,107,0,0,0,0,0,0,0,49,53,48,48,107,0,0,0,72,97,110,103,108,121,45,77,97,110,32,40,115,101,116,32,51,41,0,0,0,0,0,0,103,97,117,110,116,108,101,116,114,50,0,0,0,0,0,0,109,100,95,112,115,116,97,114,51,0,0,0,0,0,0,0,76,101,109,109,105,110,103,115,32,40,85,83,32,112,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,0,0,0,72,105,103,104,32,83,99,111,114,101,32,78,97,109,101,115,0,0,0,0,0,0,0,0,80,104,97,110,116,97,115,121,32,83,116,97,114,32,73,73,32,45,32,89,117,115,104,105,115,39,115,32,65,100,118,101,110,116,117,114,101,32,40,74,112,110,44,32,83,101,103,97,78,101,116,41,0,0,0,0,100,107,111,110,103,120,49,49,0,0,0,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,32,45,32,84,104,101,32,87,111,114,108,100,32,87,97,114,114,105,111,114,32,40,57,49,48,50,50,56,32,101,116,99,41,0,0,0,0,0,0,75,0,0,0,101,0,0,0,116,0,0,0,115,0,0,0,117,0,0,0,105,0,0,0,32,0,0,0,75,0,0,0,105,0,0,0,122,0,0,0,117,0,0,0,110,0,0,0,97,0,0,0,32,0,0,0,74,0,0,0,105,0,0,0,103,0,0,0,111,0,0,0,107,0,0,0,117,0,0,0,32,0,0,0,84,0,0,0,97,0,0,0,99,0,0,0,104,0,0,0,105,0,0,0,0,0,0,0,177,48,0,0,196,48,0,0,164,48,0,0,126,0,0,0,70,125,0,0,48,87,0,0,68,115,0,0,95,48,0,0,97,48,0,0,32,0,0,0,40,0,0,0,65,0,0,0,114,0,0,0,114,0,0,0,97,0,0,0,110,0,0,0,103,0,0,0,101,0,0,0,32,0,0,0,77,0,0,0,111,0,0,0,100,0,0,0,101,0,0,0,32,0,0,0,118,0,0,0,101,0,0,0,114,0,0,0,115,0,0,0,105,0,0,0,111,0,0,0,110,0,0,0,32,0,0,0,49,0,0,0,46,0,0,0,53,0,0,0,44,0,0,0,32,0,0,0,104,0,0,0,97,0,0,0,99,0,0,0,107,0,0,0,32,0,0,0,98,0,0,0,121,0,0,0,32,0,0,0,84,0,0,0,114,0,0,0,97,0,0,0,112,0,0,0,49,0,0,0,53,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,99,101,95,100,100,97,110,112,101,105,0,0,0,0,0,71,0,0,0,97,0,0,0,114,0,0,0,111,0,0,0,117,0,0,0,0,0,0,0,19,153,0,0,252,114,0,0,32,0,0,0,45,0,0,0,32,0,0,0,109,0,0,0,97,0,0,0,114,0,0,0,107,0,0,0,32,0,0,0,111,0,0,0,102,0,0,0,32,0,0,0,116,0,0,0,104,0,0,0,101,0,0,0,32,0,0,0,119,0,0,0,111,0,0,0,108,0,0,0,118,0,0,0,101,0,0,0,115,0,0,0,32,0,0,0,40,0,0,0,78,0,0,0,71,0,0,0,77,0,0,0,45,0,0,0,50,0,0,0,53,0,0,0,51,0,0,0,48,0,0,0,41,0,0,0,32,0,0,0,40,0,0,0,78,0,0,0,71,0,0,0,72,0,0,0,45,0,0,0,50,0,0,0,53,0,0,0,51,0,0,0,48,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,109,100,95,112,115,50,97,104,0,0,0,0,0,0,0,0,109,100,95,97,100,118,98,97,116,114,112,48,52,0,0,0,70,114,101,101,32,80,108,97,121,32,97,110,100,32,76,101,118,101,108,32,83,101,108,101,99,116,0,0,0,0,0,0,80,104,97,110,116,97,115,121,32,83,116,97,114,32,73,73,32,45,32,83,104,105,108,107,97,39,115,32,65,100,118,101,110,116,117,114,101,32,40,74,112,110,44,32,83,101,103,97,78,101,116,41,0,0,0,0,84,114,105,45,80,111,111,108,32,40,67,97,115,105,110,111,32,84,101,99,104,41,0,0,73,107,97,114,105,32,84,104,114,101,101,32,45,32,84,104,101,32,82,101,115,99,117,101,32,40,74,97,112,97,110,44,32,82,111,116,97,114,121,32,74,111,121,115,116,105,99,107,41,0,0,0,0,0,0,0,65,105,109,32,76,101,102,116,0,0,0,0,0,0,0,0,102,97,108,115,101,0,0,0,109,100,95,112,115,50,97,103,0,0,0,0,0,0,0,0,78,105,103,104,116,32,87,97,114,114,105,111,114,115,32,45,32,100,97,114,107,115,116,97,108,107,101,114,115,39,32,114,101,118,101,110,103,101,32,40,57,53,48,52,48,51,32,72,105,115,112,97,110,105,99,41,0,0,0,0,0,0,0,0,98,117,122,122,97,114,100,0,82,101,116,114,111,65,114,99,104,58,32,70,111,117,110,100,32,37,115,32,102,105,108,101,32,105,110,32,34,37,115,34,44,32,97,116,116,101,109,112,116,105,110,103,32,116,111,32,112,97,116,99,104,32,46,46,46,10,0,0,0,0,0,0,80,104,97,110,116,97,115,121,32,83,116,97,114,32,73,73,32,45,32,82,117,100,103,101,114,39,115,32,65,100,118,101,110,116,117,114,101,32,40,74,112,110,44,32,83,101,103,97,78,101,116,41,0,0,0,0,114,97,98,105,111,108,101,112,0,0,0,0,0,0,0,0,32,50,32,67,111,105,110,115,32,51,32,67,114,101,100,105,116,115,0,0,0,0,0,0,100,105,97,109,111,110,100,0,49,32,67,111,105,110,32,32,50,32,67,114,101,100,105,116,115,32,47,32,49,32,67,111,105,110,32,32,52,32,32,67,114,101,100,105,116,115,0,0,109,100,95,112,115,50,97,102,0,0,0,0,0,0,0,0,87,99,57,48,90,56,48,66,97,110,107,65,100,100,114,101,115,115,49,0,0,0,0,0,70,114,101,101,32,80,108,97,121,32,47,32,83,101,114,118,105,99,101,0,0,0,0,0,80,104,97,110,116,97,115,121,32,83,116,97,114,32,73,73,32,45,32,78,101,105,39,115,32,65,100,118,101,110,116,117,114,101,32,40,74,112,110,44,32,83,101,103,97,78,101,116,41,0,0,0,0,0,0,0,100,100,114,97,103,111,110,50,117,0,0,0,0,0,0,0,97,115,105,99,50,55,97,95,115,105,109,95,105,110,116,101,114,110,97,108,95,115,108,111,116,0,0,0,0,0,0,0,109,100,95,112,115,50,97,101,0,0,0,0,0,0,0,0,45,78,0,0,11,87,0,0,141,159,0,0,32,0,0,0,73,0,0,0,73,0,0,0,32,0,0,0,40,0,0,0,86,0,0,0,49,0,0,0,48,0,0,0,48,0,0,0,67,0,0,0,44,0,0,0,32,0,0,0,67,0,0,0,104,0,0,0,105,0,0,0,110,0,0,0,97,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,53,48,107,32,111,110,108,121,0,0,0,0,0,0,0,80,104,97,110,116,97,115,121,32,83,116,97,114,32,73,73,32,45,32,75,105,110,100,115,39,115,32,65,100,118,101,110,116,117,114,101,32,40,74,112,110,44,32,83,101,103,97,78,101,116,41,0,0,0,0,0,69,118,101,114,121,32,51,48,107,0,0,0,0,0,0,0,49,48,48,48,107,0,0,0,109,100,95,112,115,50,97,100,0,0,0,0,0,0,0,0,65,112,112,97,114,101,33,32,71,97,116,101,98,97,108,108,0,0,0,0,0,0,0,0,80,104,97,110,116,97,115,121,32,83,116,97,114,32,73,73,32,45,32,72,117,101,121,39,115,32,65,100,118,101,110,116,117,114,101,32,40,74,112,110,44,32,83,101,103,97,78,101,116,41,0,0,0,0,0,0,115,102,50,101,101,0,0,0,75,101,116,115,117,105,32,75,105,122,117,110,97,32,74,105,103,111,107,117,32,84,97,99,104,105,32,40,65,114,114,97,110,103,101,32,77,111,100,101,32,118,101,114,115,105,111,110,32,49,46,53,44,32,104,97,99,107,32,98,121,32,84,114,97,112,49,53,41,0,0,0,72,105,116,32,116,104,101,32,73,99,101,32,45,32,86,72,76,32,45,32,84,104,101,32,79,102,102,105,99,105,97,108,32,86,105,100,101,111,32,72,111,99,107,101,121,32,76,101,97,103,117,101,0,0,0,0,67,97,112,116,97,105,110,32,67,111,109,109,97,110,100,111,32,40,57,49,49,48,49,52,32,111,116,104,101,114,32,99,111,117,110,116,114,121,41,0,0,0,0,0,0,0,0,0,71,97,114,111,117,32,45,32,77,97,114,107,32,111,102,32,116,104,101,32,87,111,108,118,101,115,32,40,78,71,77,45,50,53,51,48,41,32,40,78,71,72,45,50,53,51,48,41,0,0,0,0,0,0,0,0,109,100,95,112,115,50,97,99,0,0,0,0,0,0,0,0,114,105,100,104,101,114,111,104,0,0,0,0,0,0,0,0,100,84,105,109,101,89,77,51,56,49,50,0,0,0,0,0,110,78,101,111,87,97,116,99,104,100,111,103,0,0,0,0,84,104,101,32,65,100,118,101,110,116,117,114,101,115,32,111,102,32,66,97,116,109,97,110,32,38,32,82,111,98,105,110,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,52,50,52,41,0,0,80,104,97,110,116,97,115,121,32,83,116,97,114,32,73,73,32,45,32,65,110,110,101,39,115,32,65,100,118,101,110,116,117,114,101,32,40,74,112,110,44,32,83,101,103,97,78,101,116,41,0,0,0,0,0,0,109,100,95,112,115,50,97,98,0,0,0,0,0,0,0,0,110,119,97,114,114,104,0,0,79,80,76,45,62,108,102,111,95,112,109,95,99,110,116,0,103,108,71,101,116,80,111,105,110,116,101,114,118,0,0,0,80,104,97,110,116,97,115,121,32,83,116,97,114,32,73,73,32,45,32,65,109,105,97,39,115,32,65,100,118,101,110,116,117,114,101,32,40,74,112,110,44,32,83,101,103,97,78,101,116,41,0,0,0,0,0,0,84,104,117,110,100,101,114,32,90,111,110,101,32,40,87,111,114,108,100,44,32,82,101,118,32,49,41,0,0,0,0,0,79,109,111,114,105,32,69,108,101,99,116,114,105,99,32,67,111,46,32,76,116,100,0,0,109,100,95,112,115,50,97,97,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,71,76,93,58,32,83,104,97,100,101,114,32,105,110,105,116,32,102,97,105,108,101,100,46,10,0,97,109,98,117,115,104,0,0,80,104,97,110,116,97,115,121,32,83,116,97,114,32,73,73,32,45,32,75,97,101,114,97,122,97,114,117,32,84,111,107,105,32,110,111,32,79,119,97,114,105,32,110,105,32,40,74,112,110,41,0,0,0,0,0,82,105,115,101,32,111,102,32,116,104,101,32,82,111,98,111,116,115,32,40,69,117,114,111,41,0,0,0,0,0,0,0,78,111,116,32,85,115,101,0,109,100,95,112,115,116,97,114,50,106,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,37,115,10,0,0,0,0,0,0,0,0,80,104,97,110,116,97,115,121,32,83,116,97,114,32,73,73,32,40,66,114,97,41,0,0,69,118,101,114,121,32,50,48,107,0,0,0,0,0,0,0,56,48,48,107,0,0,0,0,109,100,95,112,115,116,97,114,50,98,114,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,83,99,114,105,112,116,32,105,115,32,105,110,118,97,108,105,100,46,10,0,0,0,0,0,0,0,0,102,114,111,117,110,100,0,0,80,104,97,110,116,97,115,121,32,83,116,97,114,32,73,73,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,65,114,109,111,114,101,100,32,87,97,114,114,105,111,114,115,32,40,57,52,48,57,50,48,32,65,115,105,97,41,0,0,49,32,67,111,105,110,32,32,54,32,67,114,101,100,105,116,115,32,0,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,32,45,32,84,104,101,32,87,111,114,108,100,32,87,97,114,114,105,111,114,32,40,57,49,48,50,49,52,32,101,116,99,41,0,0,0,0,0,0,107,101,116,97,114,114,49,53,0,0,0,0,0,0,0,0,112,99,101,95,104,105,116,105,99,101,0,0,0,0,0,0,103,97,114,111,117,104,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,70,97,105,108,101,100,32,116,111,32,115,112,108,105,116,32,111,118,101,114,108,97,121,32,100,101,115,99,46,10,0,0,109,100,95,112,115,116,97,114,50,97,0,0,0,0,0,0,109,100,95,97,100,118,98,97,116,114,112,48,53,0,0,0,109,105,97,50,0,0,0,0,103,117,115,115,117,110,0,0,80,71,65,32,84,111,117,114,32,71,111,108,102,32,73,73,73,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,98,109,97,115,116,101,114,0,109,114,104,101,108,105,0,0,109,100,95,112,103,97,51,0,78,105,103,104,116,32,87,97,114,114,105,111,114,115,32,45,32,100,97,114,107,115,116,97,108,107,101,114,115,39,32,114,101,118,101,110,103,101,32,40,57,53,48,52,48,51,32,66,114,97,122,105,108,41,0,0,80,71,65,32,84,111,117,114,32,71,111,108,102,32,73,73,32,40,74,112,110,41,0,0,83,107,121,32,66,97,115,101,0,0,0,0,0,0,0,0,109,100,95,112,103,97,50,106,0,0,0,0,0,0,0,0,80,111,99,107,101,116,32,71,97,108,32,68,101,108,117,120,101,32,40,69,117,114,111,32,118,51,46,48,48,41,0,0,80,71,65,32,84,111,117,114,32,71,111,108,102,32,73,73,32,40,69,117,114,111,44,32,85,83,65,44,32,118,49,46,49,41,0,0,0,0,0,0,91,70,66,65,93,32,82,79,77,32,105,110,100,101,120,32,37,105,32,119,97,115,32,110,111,116,32,102,111,117,110,100,32,46,46,46,32,67,82,67,58,32,48,120,37,48,56,120,10,0,0,0,0,0,0,0,80,71,65,32,84,111,117,114,32,71,111,108,102,32,40,69,117,114,111,44,32,85,83,65,44,32,118,49,46,49,41,0,0,0,0,0,0,0,0,0,109,100,95,112,103,97,97,0,54,48,107,44,32,116,104,101,110,32,101,118,101,114,121,32,55,48,107,0,0,0,0,0,53,48,48,107,0,0,0,0,82,111,110,0,0,0,0,0,80,71,65,32,84,111,117,114,32,71,111,108,102,32,40,69,117,114,111,44,32,85,83,65,44,32,118,49,46,50,41,0,0,0,0,0,0,0,0,0,109,100,95,112,103,97,0,0,115,102,50,101,98,0,0,0,75,0,0,0,101,0,0,0,116,0,0,0,115,0,0,0,117,0,0,0,105,0,0,0,32,0,0,0,75,0,0,0,105,0,0,0,122,0,0,0,117,0,0,0,110,0,0,0,97,0,0,0,32,0,0,0,74,0,0,0,105,0,0,0,103,0,0,0,111,0,0,0,107,0,0,0,117,0,0,0,32,0,0,0,84,0,0,0,97,0,0,0,99,0,0,0,104,0,0,0,105,0,0,0,0,0,0,0,177,48,0,0,196,48,0,0,164,48,0,0,126,0,0,0,70,125,0,0,48,87,0,0,68,115,0,0,95,48,0,0,97,48,0,0,32,0,0,0,40,0,0,0,65,0,0,0,114,0,0,0,114,0,0,0,97,0,0,0,110,0,0,0,103,0,0,0,101,0,0,0,32,0,0,0,77,0,0,0,111,0,0,0,100,0,0,0,101,0,0,0,32,0,0,0,118,0,0,0,101,0,0,0,114,0,0,0,115,0,0,0,105,0,0,0,111,0,0,0,110,0,0,0,32,0,0,0,49,0,0,0,46,0,0,0,48,0,0,0,44,0,0,0,32,0,0,0,104,0,0,0,97,0,0,0,99,0,0,0,107,0,0,0,32,0,0,0,98,0,0,0,121,0,0,0,32,0,0,0,84,0,0,0,114,0,0,0,97,0,0,0,112,0,0,0,49,0,0,0,53,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,71,0,0,0,97,0,0,0,114,0,0,0,111,0,0,0,117,0,0,0,0,0,0,0,19,153,0,0,252,114,0,0,32,0,0,0,45,0,0,0,32,0,0,0,109,0,0,0,97,0,0,0,114,0,0,0,107,0,0,0,32,0,0,0,111,0,0,0,102,0,0,0,32,0,0,0,116,0,0,0,104,0,0,0,101,0,0,0,32,0,0,0,119,0,0,0,111,0,0,0,108,0,0,0,118,0,0,0,101,0,0,0,115,0,0,0,32,0,0,0,40,0,0,0,78,0,0,0,71,0,0,0,77,0,0,0,45,0,0,0,50,0,0,0,53,0,0,0,51,0,0,0,48,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,80,71,65,32,84,111,117,114,32,57,54,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,0,0,0,118,111,105,99,101,45,62,114,101,115,101,116,0,0,0,0,84,104,101,32,65,100,118,101,110,116,117,114,101,115,32,111,102,32,66,97,116,109,97,110,32,38,32,82,111,98,105,110,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,52,50,50,41,0,0,109,100,95,112,103,97,57,54,0,0,0,0,0,0,0,0,80,71,65,32,69,117,114,111,112,101,97,110,32,84,111,117,114,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,110,119,97,114,114,98,0,0,67,108,111,115,101,100,0,0,109,100,95,112,103,97,101,117,114,111,0,0,0,0,0,0,114,121,103,97,114,0,0,0,115,107,121,98,97,115,101,0,71,97,108,66,97,99,107,103,114,111,117,110,100,69,110,97,98,108,101,0,0,0,0,0,80,101,116,101,32,83,97,109,112,114,97,115,32,84,101,110,110,105,115,32,40,69,117,114,111,44,32,85,83,65,44,32,74,45,67,97,114,116,44,32,65,108,116,32,50,41,0,0,109,100,95,115,97,109,112,114,97,115,50,0,0,0,0,0,117,110,105,45,98,105,111,115,95,49,95,48,46,114,111,109,0,0,0,0,0,0,0,0,80,101,116,101,32,83,97,109,112,114,97,115,32,84,101,110,110,105,115,32,40,69,117,114,111,44,32,85,83,65,44,32,74,45,67,97,114,116,44,32,65,108,116,41,0,0,0,0,80,50,32,84,114,97,99,107,98,97,108,108,32,89,0,0,109,100,95,115,97,109,112,114,97,115,49,0,0,0,0,0,53,48,107,44,32,116,104,101,110,32,101,118,101,114,121,32,54,48,107,0,0,0,0,0,67,114,101,100,105,116,0,0,70,114,101,101,32,67,114,101,100,105,116,0,0,0,0,0,80,101,112,101,110,103,97,32,80,101,110,103,111,32,40,74,112,110,41,0,0,0,0,0,109,100,95,112,112,101,110,103,111,0,0,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,32,45,32,84,104,101,32,87,111,114,108,100,32,87,97,114,114,105,111,114,32,40,57,49,48,53,50,50,32,101,116,99,41,0,0,0,0,0,0,104,97,99,107,32,47,32,84,114,97,112,49,53,0,0,0,71,97,114,111,117,32,45,32,77,97,114,107,32,111,102,32,116,104,101,32,87,111,108,118,101,115,32,40,78,71,77,45,50,53,51,48,41,0,0,0,80,0,0,0,101,0,0,0,108,0,0,0,233,0,0,0,33,0,0,0,32,0,0,0,40,0,0,0,69,0,0,0,117,0,0,0,114,0,0,0,111,0,0,0,44,0,0,0,32,0,0,0,85,0,0,0,83,0,0,0,65,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,115,108,45,62,107,115,114,0,78,105,103,104,116,32,87,97,114,114,105,111,114,115,32,45,32,100,97,114,107,115,116,97,108,107,101,114,115,39,32,114,101,118,101,110,103,101,32,40,57,53,48,51,48,50,32,65,115,105,97,41,0,0,0,0,109,100,95,97,100,118,98,97,116,114,112,48,54,0,0,0,75,97,114,110,111,118,32,40,85,83,44,32,114,101,118,32,54,41,0,0,0,0,0,0,80,114,105,111,114,105,116,121,70,108,97,103,0,0,0,0,80,101,108,101,33,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,0,82,32,98,117,116,116,111,110,32,40,115,104,111,117,108,100,101,114,41,0,0,0,0,0,109,100,95,112,101,108,101,0,80,0,0,0,101,0,0,0,108,0,0,0,233,0,0,0,39,0,0,0,115,0,0,0,32,0,0,0,87,0,0,0,111,0,0,0,114,0,0,0,108,0,0,0,100,0,0,0,32,0,0,0,84,0,0,0,111,0,0,0,117,0,0,0,114,0,0,0,110,0,0,0,97,0,0,0,109,0,0,0,101,0,0,0,110,0,0,0,116,0,0,0,32,0,0,0,83,0,0,0,111,0,0,0,99,0,0,0,99,0,0,0,101,0,0,0,114,0,0,0,32,0,0,0,40,0,0,0,69,0,0,0,117,0,0,0,114,0,0,0,111,0,0,0,44,0,0,0,32,0,0,0,85,0,0,0,83,0,0,0,65,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,98,111,111,116,108,101,103,32,40,75,90,72,41,0,0,0,80,101,108,101,39,115,32,87,111,114,108,100,32,84,111,117,114,110,97,109,101,110,116,32,83,111,99,99,101,114,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,109,111,109,111,107,111,0,0,109,100,95,112,101,108,101,50,0,0,0,0,0,0,0,0,117,110,105,45,98,105,111,115,95,49,95,49,46,114,111,109,0,0,0,0,0,0,0,0,78,101,119,32,51,68,32,71,111,108,102,32,83,105,109,117,108,97,116,105,111,110,32,45,32,80,101,98,98,108,101,32,66,101,97,99,104,32,110,111,32,72,97,116,111,117,32,40,74,112,110,41,0,0,0,0,109,100,95,110,51,100,103,112,101,98,98,0,0,0,0,0,52,48,107,44,32,116,104,101,110,32,101,118,101,114,121,32,53,48,107,0,0,0,0,0,80,111,119,101,114,0,0,0,86,115,32,82,111,117,110,100,115,0,0,0,0,0,0,0,67,104,105,0,0,0,0,0,80,101,98,98,108,101,32,66,101,97,99,104,32,71,111,108,102,32,76,105,110,107,115,32,40,85,83,65,41,0,0,0,80,49,32,67,97,110,99,101,108,0,0,0,0,0,0,0,83,112,97,99,101,32,73,110,118,97,100,101,114,115,32,71,97,108,97,99,116,105,99,97,32,40,103,97,108,97,120,105,97,106,32,104,97,99,107,41,0,0,0,0,0,0,0,0,109,100,95,112,101,98,98,108,101,117,0,0,0,0,0,0,115,102,50,0,0,0,0,0,75,101,116,115,117,105,32,75,105,122,117,110,97,32,74,105,103,111,107,117,32,84,97,99,104,105,32,40,65,114,114,97,110,103,101,32,77,111,100,101,32,118,101,114,115,105,111,110,32,49,46,48,44,32,104,97,99,107,32,98,121,32,84,114,97,112,49,53,41,0,0,0,72,101,97,118,121,32,85,110,105,116,0,0,0,0,0,0,103,97,114,111,117,0,0,0,80,101,98,98,108,101,32,66,101,97,99,104,32,71,111,108,102,32,76,105,110,107,115,32,40,69,117,114,111,41,0,0,77,83,77,54,50,57,53,83,97,109,112,108,101,73,110,102,111,91,110,67,104,105,112,93,91,105,93,0,0,0,0,0,110,119,97,114,114,97,0,0,84,104,101,32,65,100,118,101,110,116,117,114,101,115,32,111,102,32,66,97,116,109,97,110,32,38,32,82,111,98,105,110,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,52,50,49,41,0,0,84,105,116,108,101,83,97,109,112,108,101,80,111,115,0,0,109,100,95,112,101,98,98,108,101,0,0,0,0,0,0,0,80,97,114,116,121,32,81,117,105,122,32,77,101,103,97,32,81,32,40,74,112,110,41,0,0,0,0,0,0,0,0,0,99,104,105,112,45,62,101,103,95,116,105,109,101,114,0,0,77,105,116,99,104,101,108,108,32,40,65,116,108,117,115,32,108,105,99,101,110,115,101,41,0,0,0,0,0,0,0,0,109,100,95,112,97,114,116,121,113,0,0,0,0,0,0,0,84,104,101,32,80,105,116,32,40,98,111,111,116,108,101,103,32,111,110,32,77,111,111,110,32,81,117,97,115,97,114,32,104,97,114,100,119,97,114,101,41,0,0,0,0,0,0,0,80,97,112,101,114,98,111,121,32,40,74,112,110,41,0,0,83,116,111,112,112,101,100,0,109,100,95,112,97,112,101,114,98,111,121,106,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,71,69,84,95,67,65,78,95,68,85,80,69,58,32,116,114,117,101,10,0,0,117,110,105,45,98,105,111,115,95,49,95,50,46,114,111,109,0,0,0,0,0,0,0,0,80,97,112,101,114,98,111,121,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,112,52,32,99,111,105,110,0,80,50,32,84,114,97,99,107,98,97,108,108,32,88,0,0,109,100,95,112,97,112,101,114,98,111,121,0,0,0,0,0,51,48,107,44,32,116,104,101,110,32,101,118,101,114,121,32,52,48,107,0,0,0,0,0,67,111,105,110,32,68,117,114,105,110,103,32,71,97,109,101,0,0,0,0,0,0,0,0,68,83,87,83,0,0,0,0,80,97,110,111,114,97,109,97,32,67,111,116,116,111,110,32,40,74,112,110,41,0,0,0,109,100,95,112,99,111,116,116,111,110,0,0,0,0,0,0,175,48,0,0,164,48,0,0,186,48,0,0,191,107,0,0,216,105,0,0,110,48,0,0,206,145,0,0,27,103,0,0,18,255,0,0,32,0,0,0,40,0,0,0,104,48,0,0,110,48,0,0,85,48,0,0,126,48,0,0,110,48,0,0,132,48,0,0,124,48,0,0,70,48,0,0,32,0,0,0,50,0,0,0,41,0,0,0,0,0,0,0,81,0,0,0,117,0,0,0,105,0,0,0,122,0,0,0,32,0,0,0,84,0,0,0,111,0,0,0,110,0,0,0,111,0,0,0,115,0,0,0,97,0,0,0,109,0,0,0,97,0,0,0,32,0,0,0,110,0,0,0,111,0,0,0,32,0,0,0,89,0,0,0,97,0,0,0,98,0,0,0,111,0,0,0,117,0,0,0,32,0,0,0,50,0,0,0,32,0,0,0,90,0,0,0,101,0,0,0,110,0,0,0,107,0,0,0,111,0,0,0,107,0,0,0,117,0,0,0,45,0,0,0,98,0,0,0,97,0,0,0,110,0,0,0,32,0,0,0,40,0,0,0,116,0,0,0,111,0,0,0,110,0,0,0,111,0,0,0,115,0,0,0,97,0,0,0,109,0,0,0,97,0,0,0,32,0,0,0,50,0,0,0,32,0,0,0,57,0,0,0,53,0,0,0,48,0,0,0,49,0,0,0,50,0,0,0,51,0,0,0,32,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,107,101,116,97,114,114,0,0,112,99,101,95,104,118,121,117,110,105,116,0,0,0,0,0,84,104,101,32,75,105,110,103,32,111,102,32,70,105,103,104,116,101,114,115,32,39,57,57,32,45,32,77,105,108,108,101,110,110,105,117,109,32,66,97,116,116,108,101,32,40,112,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,0,0,84,104,101,32,80,97,103,101,109,97,115,116,101,114,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,0,0,0,109,100,95,97,100,118,98,97,116,114,112,48,55,0,0,0,80,108,97,121,84,105,116,108,101,83,97,109,112,108,101,0,109,100,95,112,97,103,101,109,115,116,114,117,112,0,0,0,84,104,101,32,80,97,103,101,109,97,115,116,101,114,32,40,85,83,65,41,0,0,0,0,78,105,103,104,116,32,87,97,114,114,105,111,114,115,32,45,32,100,97,114,107,115,116,97,108,107,101,114,115,39,32,114,101,118,101,110,103,101,32,40,57,53,48,51,49,54,32,69,117,114,111,41,0,0,0,0,109,100,95,112,97,103,101,109,115,116,114,117,0,0,0,0,70,111,120,32,73,110,116,101,114,97,99,116,105,118,101,0,84,104,101,32,80,97,103,101,109,97,115,116,101,114,32,40,69,117,114,111,41,0,0,0,117,110,105,45,98,105,111,115,95,49,95,50,111,46,114,111,109,0,0,0,0,0,0,0,100,100,114,97,103,111,110,0,109,100,95,112,97,103,101,109,115,116,114,0,0,0,0,0,112,49,32,121,45,97,120,105,115,0,0,0,0,0,0,0,80,97,100,100,108,101,32,70,105,103,104,116,101,114,32,40,74,112,110,44,32,71,97,109,101,32,110,111,32,75,97,110,100,117,109,101,32,77,101,103,97,67,68,32,82,105,112,41,0,0,0,0,0,0,0,0,77,117,108,116,105,0,0,0,52,32,67,111,105,110,115,0,109,100,95,112,97,100,100,108,101,103,110,107,0,0,0,0,84,104,101,32,82,101,97,108,32,71,104,111,115,116,98,117,115,116,101,114,115,32,40,85,83,32,50,32,80,108,97,121,101,114,115,44,32,114,101,118,105,115,105,111,110,32,50,41,0,0,0,0,0,0,0,0,80,97,100,100,108,101,32,70,105,103,104,116,101,114,32,40,74,112,110,44,32,83,101,103,97,78,101,116,41,0,0,0,81,117,105,122,32,84,111,110,111,115,97,109,97,32,110,111,32,89,97,98,111,117,32,50,32,90,101,110,107,111,107,117,45,98,97,110,32,40,116,111,110,111,115,97,109,97,32,50,32,57,53,48,49,50,51,32,74,97,112,97,110,41,0,0,75,0,0,0,101,0,0,0,116,0,0,0,115,0,0,0,117,0,0,0,105,0,0,0,32,0,0,0,75,0,0,0,105,0,0,0,122,0,0,0,117,0,0,0,110,0,0,0,97,0,0,0,32,0,0,0,74,0,0,0,105,0,0,0,103,0,0,0,111,0,0,0,107,0,0,0,117,0,0,0])
.concat([32,0,0,0,84,0,0,0,97,0,0,0,99,0,0,0,104,0,0,0,105,0,0,0,0,0,0,0,177,48,0,0,196,48,0,0,164,48,0,0,126,0,0,0,70,125,0,0,48,87,0,0,68,115,0,0,95,48,0,0,97,48,0,0,32,0,0,0,40,0,0,0,79,0,0,0,114,0,0,0,105,0,0,0,103,0,0,0,105,0,0,0,110,0,0,0,97,0,0,0,108,0,0,0,63,0,0,0,44,0,0,0,32,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,101,110,103,101,110,0,0,107,111,102,57,57,112,0,0,109,100,95,112,97,100,100,108,101,0,0,0,0,0,0,0,98,89,77,90,50,56,48,66,69,110,97,98,108,101,0,0,84,104,101,32,65,100,118,101,110,116,117,114,101,115,32,111,102,32,66,97,116,109,97,110,32,38,32,82,111,98,105,110,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,52,49,57,41,0,0,109,117,116,110,97,116,0,0,84,105,116,108,101,83,111,117,110,100,76,97,116,99,104,0,66,114,97,107,101,0,0,0,84,101,105,116,111,107,117,32,110,111,32,75,101,116,115,117,100,97,110,32,40,74,112,110,41,0,0,0,0,0,0,0,37,48,56,120,58,32,68,101,99,111,100,101,115,104,105,102,116,32,101,114,114,111,114,10,0,0,0,0,0,0,0,0,110,105,116,114,111,98,97,108,0,0,0,0,0,0,0,0,109,100,95,116,101,105,107,101,116,115,117,0,0,0,0,0,110,119,97,114,114,0,0,0,82,45,62,105,110,112,117,116,95,99,97,112,116,117,114,101,0,0,0,0,0,0,0,0,83,101,97,116,111,110,103,114,111,118,101,32,76,116,100,0,49,32,99,111,105,110,32,54,32,112,108,97,121,0,0,0,49,32,99,111,105,110,32,49,32,99,114,101,100,105,116,0,70,105,120,69,105,103,104,116,32,40,85,83,65,41,0,0,49,32,99,111,105,110,32,51,32,112,108,97,121,115,0,0,80,46,84,46,79,46,32,45,32,80,97,99,105,102,105,99,32,84,104,101,97,116,101,114,32,111,102,32,79,112,101,114,97,116,105,111,110,115,32,40,85,83,65,41,0,0,0,0,84,97,105,116,111,32,65,109,101,114,105,99,97,32,67,111,114,112,46,0,0,0,0,0,116,104,101,112,105,116,109,0,68,105,102,102,105,99,117,108,116,121,0,0,0,0,0,0,87,111,114,108,100,47,84,97,105,116,111,32,67,111,114,112,32,74,97,112,97,110,0,0,49,32,83,116,97,114,116,47,49,32,67,111,110,116,105,110,117,101,0,0,0,0,0,0,109,100,95,112,116,111,0,0,67,111,105,110,32,112,108,97,121,0,0,0,0,0,0,0,83,111,102,116,32,86,105,115,105,111,110,32,73,110,116,101,114,110,97,116,105,111,110,97,108,0,0,0,0,0,0,0,117,110,105,45,98,105,111,115,95,49,95,51,46,114,111,109,0,0,0,0,0,0,0,0,80,97,99,104,105,110,107,111,32,75,117,117,110,121,97,110,32,40,74,112,110,41,0,0,72,105,112,112,111,100,114,111,109,101,32,40,85,83,41,0,0,0,0,0,0,0,0,0,80,49,32,84,114,97,99,107,98,97,108,108,32,89,0,0,100,111,110,100,111,107,111,100,106,0,0,0,0,0,0,0,109,100,95,112,97,99,104,105,110,107,111,0,0,0,0,0,68,114,46,32,84,111,112,112,101,108,39,115,32,65,100,118,101,110,116,117,114,101,32,40,85,83,41,0,0,0,0,0,118,112,99,95,118,100,99,48,95,101,110,97,98,108,101,100,91,105,93,0,0,0,0,0,51,32,67,111,105,110,115,0,97,114,107,49,98,97,108,108,97,0,0,0,0,0,0,0,80,97,99,45,80,97,110,105,99,32,40,69,117,114,111,41,0,0,0,0,0,0,0,0,103,105,110,103,97,110,105,110,0,0,0,0,0,0,0,0,99,114,105,109,101,99,0,0,49,32,67,111,105,110,47,50,32,67,114,101,100,105,116,115,32,52,47,57,0,0,0,0,67,104,97,115,101,32,72,46,81,46,32,40,85,83,41,0,0,0,0,0,0,0,0,0,80,97,99,45,77,97,110,105,97,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,82,97,105,110,98,111,119,32,73,115,108,97,110,100,115,32,40,110,101,119,32,118,101,114,115,105,111,110,41,0,0,0,113,116,111,110,111,50,106,0,65,115,117,107,97,32,38,32,65,115,117,107,97,32,40,74,97,112,97,110,41,0,0,0,75,101,116,115,117,105,32,75,105,122,117,110,97,32,74,105,103,111,107,117,32,84,97,99,104,105,32,40,79,114,105,103,105,110,97,108,63,44,32,74,97,112,97,110,41,0,0,0,72,97,116,114,105,115,0,0,84,104,101,32,75,105,110,103,32,111,102,32,70,105,103,104,116,101,114,115,32,39,57,57,32,45,32,77,105,108,108,101,110,110,105,117,109,32,66,97,116,116,108,101,32,40,75,111,114,101,97,110,32,114,101,108,101,97,115,101,41,0,0,0,98,117,98,108,99,97,118,101,0,0,0,0,0,0,0,0,109,100,95,112,97,99,109,97,110,105,97,0,0,0,0,0,109,100,95,97,100,118,98,97,116,114,112,48,56,0,0,0,84,117,114,98,111,32,79,117,116,32,82,117,110,32,40,79,117,116,32,82,117,110,32,117,112,103,114,97,100,101,44,32,70,68,49,48,57,52,32,51,49,55,45,48,49,49,56,41,0,0,0,0,0,0,0,0,70,117,110,107,121,32,74,101,116,32,40,87,111,114,108,100,41,0,0,0,0,0,0,0,80,97,99,45,77,97,110,32,50,32,45,32,84,104,101,32,78,101,119,32,65,100,118,101,110,116,117,114,101,115,32,40,85,83,65,41,0,0,0,0,115,102,105,105,105,51,117,114,49,0,0,0,0,0,0,0,97,108,116,98,101,97,115,116,53,0,0,0,0,0,0,0,78,55,55,53,49,67,111,109,109,97,110,100,0,0,0,0,100,109,110,102,114,110,116,0,70,117,101,108,0,0,0,0,109,100,95,112,97,99,109,97,110,50,0,0,0,0,0,0,77,97,114,118,101,108,32,118,115,32,67,97,112,99,111,109,32,45,32,99,108,97,115,104,32,111,102,32,115,117,112,101,114,32,104,101,114,111,101,115,32,40,57,56,48,49,50,51,32,74,97,112,97,110,44,32,115,105,110,103,108,101,32,80,67,66,41,0,0,0,0,0,102,108,105,99,107,121,115,50,103,0,0,0,0,0,0,0,100,100,99,114,101,119,106,50,0,0,0,0,0,0,0,0,82,97,105,108,32,67,104,97,115,101,32,40,74,97,112,97,110,41,0,0,0,0,0,0,80,97,99,45,65,116,116,97,99,107,32,40,85,83,65,41,0,0,0,0,0,0,0,0,108,111,102,102,105,114,101,117,0,0,0,0,0,0,0,0,77,111,111,110,32,65,108,105,101,110,32,80,97,114,116,32,50,32,40,111,108,100,101,114,32,118,101,114,115,105,111,110,41,0,0,0,0,0,0,0,70,97,110,116,97,115,121,32,90,111,110,101,32,40,82,101,118,32,65,44,32,117,110,112,114,111,116,101,99,116,101,100,41,0,0,0,0,0,0,0,109,100,95,112,97,99,112,97,110,105,99,0,0,0,0,0,83,112,97,99,101,32,72,97,114,114,105,101,114,32,40,56,55,53,49,32,51,49,53,45,53,49,54,51,41,0,0,0,118,105,100,101,111,95,102,111,114,99,101,95,97,115,112,101,99,116,0,0,0,0,0,0,103,116,109,114,117,115,97,0,109,100,95,112,97,99,97,116,116,97,107,0,0,0,0,0,117,110,105,45,98,105,111,115,95,50,95,48,46,114,111,109,0,0,0,0,0,0,0,0,79,117,116,82,117,110,110,101,114,115,32,40,74,112,110,41,0,0,0,0,0,0,0,0,50,53,37,0,0,0,0,0,109,100,95,111,114,117,110,110,101,114,115,106,0,0,0,0,83,104,105,112,0,0,0,0,49,48,48,48,0,0,0,0,84,104,117,110,100,101,114,32,68,114,97,103,111,110,32,50,32,40,57,116,104,32,78,111,118,46,32,49,57,57,51,41,0,0,0,0,0,0,0,0,50,32,99,111,105,110,115,32,49,32,99,114,101,100,105,116,32,49,32,99,111,110,116,105,110,117,101,0,0,0,0,0,50,32,67,111,105,110,115,0,115,117,98,50,109,97,105,110,95,112,101,110,100,105,110,103,0,0,0,0,0,0,0,0,79,117,116,82,117,110,110,101,114,115,32,40,85,83,65,41,0,0,0,0,0,0,0,0,83,117,98,115,105,110,111,0,84,73,77,69,82,32,65,99,110,116,0,0,0,0,0,0,49,32,67,111,105,110,47,50,32,67,114,101,100,105,116,115,32,53,47,49,49,0,0,0,109,100,95,111,114,117,110,110,101,114,115,0,0,0,0,0,114,97,105,103,97,0,0,0,100,84,105,109,101,89,56,57,53,48,0,0,0,0,0,0,68,114,118,66,103,49,83,99,114,111,108,108,89,0,0,0,81,117,105,122,32,38,32,68,114,97,103,111,110,115,32,40,57,52,48,57,50,49,32,74,97,112,97,110,32,82,101,115,97,108,101,32,86,101,114,46,41,0,0,0,0,0,0,0,107,101,116,98,0,0,0,0,77,105,115,115,32,77,105,115,116,101,114,32,87,111,114,108,100,32,39,57,54,32,40,78,117,100,101,41,0,0,0,0,112,99,101,95,104,97,116,114,105,115,0,0,0,0,0,0,73,110,102,111,0,0,0,0,107,111,102,57,57,107,0,0,83,116,97,114,116,105,110,103,32,67,111,105,110,115,0,0,74,117,110,107,101,114,39,115,32,72,105,103,104,32,40,74,112,110,44,32,80,114,111,116,111,116,121,112,101,41,0,0,80,0,0,0,114,0,0,0,101,0,0,0,116,0,0,0,116,0,0,0,121,0,0,0,32,0,0,0,83,0,0,0,111,0,0,0,108,0,0,0,100,0,0,0,105,0,0,0,101,0,0,0,114,0,0,0,32,0,0,0,83,0,0,0,97,0,0,0,105,0,0,0,108,0,0,0,111,0,0,0,114,0,0,0,32,0,0,0,77,0,0,0,111,0,0,0,111,0,0,0,110,0,0,0,0,0,0,0,142,127,0,0,17,92,0,0,115,89,0,0,38,98,0,0,235,88,0,0,32,0,0,0,187,48,0,0,252,48,0,0,233,48,0,0,252,48,0,0,224,48,0,0,252,48,0,0,243,48,0,0,32,0,0,0,40,0,0,0,118,0,0,0,101,0,0,0,114,0,0,0,46,0,0,0,32,0,0,0,57,0,0,0,53,0,0,0,47,0,0,0,48,0,0,0,51,0,0,0,47,0,0,0,50,0,0,0,50,0,0,0,44,0,0,0,32,0,0,0,85,0,0,0,83,0,0,0,65,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,56,48,48,48,48,32,82,101,103,105,115,116,101,114,115,0,0,0,0,0,0,0,0,84,104,101,32,65,100,118,101,110,116,117,114,101,115,32,111,102,32,66,97,116,109,97,110,32,38,32,82,111,98,105,110,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,52,49,56,41,0,0,68,101,99,111,49,54,105,99,32,67,111,110,116,114,111,108,32,48,0,0,0,0,0,0,74,111,105,110,32,73,110,32,109,111,100,101,0,0,0,0,98,73,114,113,69,110,97,98,108,101,0,0,0,0,0,0,109,100,95,106,117,110,107,101,114,0,0,0,0,0,0,0,79,117,116,82,117,110,32,50,48,49,57,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,109,118,115,99,106,115,105,110,103,0,0,0,0,0,0,0,81,117,105,122,32,75,111,107,111,108,111,103,121,32,50,0,0,0,0,0,0,0,0,0,109,100,95,111,117,116,114,50,48,49,57,117,112,0,0,0,49,80,32,68,105,102,102,105,99,117,108,116,121,0,0,0,109,111,111,110,97,108,50,98,0,0,0,0,0,0,0,0,112,122,108,98,114,101,97,107,0,0,0,0,0,0,0,0,79,117,116,82,117,110,32,50,48,49,57,32,40,85,83,65,41,0,0,0,0,0,0,0,83,116,114,105,107,101,114,115,32,49,57,52,53,32,40,74,97,112,97,110,41,0,0,0,71,117,110,98,97,114,105,99,104,0,0,0,0,0,0,0,109,100,95,111,117,116,114,50,48,49,57,117,0,0,0,0,84,101,114,114,97,32,70,111,114,99,101,32,40,74,97,112,97,110,32,98,111,111,116,108,101,103,32,115,101,116,32,49,44,32,119,105,116,104,32,97,100,100,105,116,105,111,110,97,108,32,90,56,48,41,0,0,117,110,105,45,98,105,111,115,95,50,95,49,46,114,111,109,0,0,0,0,0,0,0,0,83,105,109,115,0,0,0,0,49,67,32,49,67,32,47,32,49,67,32,53,67,0,0,0,80,49,32,84,114,97,99,107,98,97,108,108,32,88,0,0,76,0,0,0,0,0,0,0,79,117,116,82,117,110,32,50,48,49,57,32,40,74,112,110,41,0,0,0,0,0,0,0,57,48,107,0,0,0,0,0,49,32,67,111,105,110,0,0,104,97,110,103,108,121,51,0,71,97,117,110,116,108,101,116,32,40,71,101,114,109,97,110,44,32,114,101,118,32,51,41,0,0,0,0,0,0,0,0,109,100,95,111,117,116,114,50,48,49,57,106,0,0,0,0,71,97,109,101,32,116,105,109,101,32,40,116,115,117,109,101,115,104,111,117,103,105,41,0,79,117,116,82,117,110,32,50,48,49,57,32,40,69,117,114,111,41,0,0,0,0,0,0,68,111,110,107,101,121,32,75,111,110,103,32,73,73,32,45,32,74,117,109,112,109,97,110,32,82,101,116,117,114,110,115,32,40,86,49,46,50,41,32,40,104,97,99,107,41,0,0,113,97,100,106,114,0,0,0,75,0,0,0,101,0,0,0,116,0,0,0,115,0,0,0,117,0,0,0,105,0,0,0,32,0,0,0,75,0,0,0,105,0,0,0,122,0,0,0,117,0,0,0,110,0,0,0,97,0,0,0,32,0,0,0,74,0,0,0,105,0,0,0,103,0,0,0,111,0,0,0,107,0,0,0,117,0,0,0,32,0,0,0,84,0,0,0,97,0,0,0,99,0,0,0,104,0,0,0,105,0,0,0,0,0,0,0,177,48,0,0,196,48,0,0,164,48,0,0,126,0,0,0,70,125,0,0,48,87,0,0,68,115,0,0,95,48,0,0,97,48,0,0,32,0,0,0,40,0,0,0,82,0,0,0,101,0,0,0,118,0,0,0,105,0,0,0,115,0,0,0,105,0,0,0,111,0,0,0,110,0,0,0,32,0,0,0,49,0,0,0,63,0,0,0,44,0,0,0,32,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,107,105,108,108,98,108,100,0,72,97,110,105,105,32,111,110,32,116,104,101,32,82,111,97,100,0,0,0,0,0,0,0,56,32,67,111,105,110,115,32,51,32,67,114,101,100,105,116,115,32,0,0,0,0,0,0,84,104,101,32,75,105,110,103,32,111,102,32,70,105,103,104,116,101,114,115,32,39,57,57,32,45,32,77,105,108,108,101,110,110,105,117,109,32,66,97,116,116,108,101,32,40,101,97,114,108,105,101,114,41,0,0,77,97,114,118,101,108,32,118,115,32,67,97,112,99,111,109,32,45,32,99,108,97,115,104,32,111,102,32,115,117,112,101,114,32,104,101,114,111,101,115,32,40,57,55,49,50,50,50,32,85,83,65,41,0,0,0,109,100,95,111,117,116,114,50,48,49,57,0,0,0,0,0,109,100,95,97,100,118,98,97,116,114,112,48,57,0,0,0,97,118,101,110,103,101,114,115,0,0,0,0,0,0,0,0,110,118,114,97,109,95,101,110,97,98,108,101,0,0,0,0,79,117,116,82,117,110,32,40,74,112,110,41,0,0,0,0,105,107,97,114,105,51,106,0,116,0,0,0,114,0,0,0,117,0,0,0,101,0,0,0,0,0,0,0,0,0,0,0,68,114,118,66,103,83,99,114,111,108,108,88,91,49,93,0,109,100,95,111,117,116,114,117,110,106,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,97,118,105,110,103,32,115,116,97,116,101,58,32,34,37,115,34,46,10,0,84,117,109,98,108,101,32,80,111,112,32,40,87,111,114,108,100,41,0,0,0,0,0,0,67,114,117,120,32,40,84,97,105,116,111,32,67,111,114,112,111,114,97,116,105,111,110,32,108,105,99,101,110,115,101,41,0,0,0,0,0,0,0,0,79,117,116,82,117,110,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,68,105,100,32,110,111,116,32,102,105,110,100,32,97,32,118,97,108,105,100,32,82,79,77,32,112,97,116,99,104,46,10,0,0,0,0,0,77,111,111,110,32,65,108,105,101,110,32,80,97,114,116,32,50,0,0,0,0,0,0,0,32,51,32,67,111,105,110,115,32,49,32,67,114,101,100,105,116,0,0,0,0,0,0,0,77,97,107,97,105,45,77,117,114,97,32,40,74,97,112,97,110,32,114,101,118,105,115,105,111,110,32,71,41,0,0,0,65,32,49,47,49,32,66,32,49,47,52,0,0,0,0,0,49,32,67,111,105,110,32,32,50,32,67,114,101,100,105,116,115,32,47,32,49,32,67,111,105,110,32,32,50,32,32,67,114,101,100,105,116,115,0,0,109,100,95,111,117,116,114,117,110,0,0,0,0,0,0,0,87,99,57,48,83,99,114,111,108,108,50,88,72,105,0,0,49,67,95,55,67,0,0,0,79,117,116,108,97,110,100,101,114,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,68,111,117,98,108,101,32,68,114,97,103,111,110,32,73,73,32,45,32,84,104,101,32,82,101,118,101,110,103,101,32,40,87,111,114,108,100,41,0,0,97,115,105,99,50,55,97,95,115,105,109,95,114,101,115,112,111,110,115,101,0,0,0,0,117,110,105,45,98,105,111,115,95,50,95,50,46,114,111,109,0,0,0,0,0,0,0,0,109,100,95,111,117,116,108,97,110,100,114,117,0,0,0,0,90,104,111,110,103,32,71,117,111,32,76,111,110,103,32,73,73,32,40,86,49,48,48,67,44,32,67,104,105,110,97,41,0,0,0,0,0,0,0,0,56,32,119,97,121,32,74,111,121,115,116,105,99,107,0,0,79,117,116,108,97,110,100,101,114,32,40,69,117,114,111,41,0,0,0,0,0,0,0,0,56,48,107,0,0,0,0,0,67,114,101,100,105,116,32,80,111,119,101,114,0,0,0,0,67,111,110,116,105,110,117,101,32,67,111,105,110,115,0,0,109,100,95,111,117,116,108,97,110,100,114,0,0,0,0,0,112,99,101,95,97,112,112,103,97,116,101,98,0,0,0,0,84,104,101,32,79,116,116,105,102,97,110,116,115,32,40,71,101,114,44,32,80,114,111,116,111,116,121,112,101,41,0,0,81,117,105,122,32,38,32,68,114,97,103,111,110,115,32,40,99,97,112,99,111,109,32,113,117,105,122,32,103,97,109,101,32,57,50,48,55,48,49,32,85,83,65,41,0,0,0,0,75,101,116,115,117,105,32,75,105,122,117,110,97,32,74,105,103,111,107,117,32,84,97,99,104,105,32,40,82,101,118,105,115,105,111,110,32,49,63,44,32,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,112,99,101,95,104,97,110,105,105,114,111,100,0,0,0,0,107,111,102,57,57,101,0,0,99,97,112,116,99,111,109,109,114,49,0,0,0,0,0,0,109,118,115,99,117,114,49,0,82,105,100,105,110,103,32,72,101,114,111,32,40,78,71,77,45,48,48,54,41,40,78,71,72,45,48,48,54,41,0,0,109,100,95,111,116,116,105,102,97,110,116,103,0,0,0,0,98,83,82,65,77,87,114,105,116,97,98,108,101,0,0,0,84,104,101,32,65,100,118,101,110,116,117,114,101,115,32,111,102,32,66,97,116,109,97,110,32,38,32,82,111,98,105,110,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,52,49,49,41,0,0,84,104,101,32,79,116,116,105,102,97,110,116,115,32,40,69,117,114,111,41,0,0,0,0,109,100,95,111,116,116,105,102,97,110,116,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,65,117,100,105,111,32,98,97,99,107,101,110,100,32,102,97,105,108,101,100,32,116,111,32,119,114,105,116,101,46,32,87,105,108,108,32,99,111,110,116,105,110,117,101,32,119,105,116,104,111,117,116,32,115,111,117,110,100,46,10,0,0,0,0,0,0,0,79,80,76,45,62,108,102,111,95,97,109,95,99,110,116,0,103,108,71,101,116,79,98,106,101,99,116,80,116,114,76,97,98,101,108,0,0,0,0,0,79,115,111,109,97,116,115,117,45,107,117,110,32,72,97,99,104,97,109,101,99,104,97,32,71,101,107,105,106,111,117,32,40,74,112,110,41,0,0,0,109,111,111,110,97,108,50,0,80,114,101,118,37,117,0,0,109,100,95,111,115,111,109,97,116,115,117,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,71,76,58,32,85,115,105,110,103,32,114,101,115,111,108,117,116,105,111,110,32,37,117,120,37,117,10,0,0,71,65,77,69,32,40,37,115,41,32,37,115,0,0,0,0,69,117,114,111,112,97,32,83,101,110,115,101,110,32,40,74,112,110,41,0,0,0,0,0,66,111,111,103,105,101,32,87,105,110,103,115,32,40,69,117,114,111,32,118,49,46,53,44,32,57,50,46,49,50,46,48,55,41,0,0,0,0,0,0,117,110,105,45,98,105,111,115,95,50,95,51,46,114,111,109,0,0,0,0,0,0,0,0,109,100,95,101,117,114,111,115,101,110,115,0,0,0,0,0,77,117,108,116,105,112,108,97,121,101,114,0,0,0,0,0,67,111,110,102,105,103,32,100,105,114,101,99,116,111,114,121,32,110,111,116,32,115,101,116,46,32,67,97,110,110,111,116,32,115,97,118,101,32,110,101,119,32,99,111,110,102,105,103,46,0,0,0,0,0,0,0,79,112,101,114,97,116,105,111,110,32,69,117,114,111,112,101,32,45,32,80,97,116,104,32,116,111,32,86,105,99,116,111,114,121,32,49,57,51,57,45,52,53,32,40,85,83,65,41,0,0,0,0,0,0,0,0,54,48,48,107,0,0,0,0,109,100,95,111,112,101,117,114,111,112,101,0,0,0,0,0,115,99,114,105,112,116,0,0,49,32,67,111,105,110,47,49,32,67,114,101,100,105,116,32,52,47,53,0,0,0,0,0,71,0,0,0,114,0,0,0,97,0,0,0,100,0,0,0,105,0,0,0,117,0,0,0,115,0,0,0,32,0,0,0,73,0,0,0,73,0,0,0,32,0,0,0,45,0,0,0,32,0,0,0,71,0,0,0,79,0,0,0,70,0,0,0,69,0,0,0,82,0,0,0,32,0,0,0,110,48,0,0,206,145,0,0,27,103,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,32,0,0,0,79,0,0,0,108,0,0,0,100,0,0,0,101,0,0,0,114,0,0,0,32,0,0,0,118,0,0,0,101,0,0,0,114,0,0,0,46,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,57,57,48,0,0,0,0,84,104,101,32,79,111,122,101,32,40,80,114,111,116,111,116,121,112,101,32,49,49,50,44,32,49,57,57,53,48,54,50,54,41,0,0,0,0,0,0,97,114,109,119,97,114,97,0,49,32,67,111,105,110,32,32,53,32,67,114,101,100,105,116,115,32,0,0,0,0,0,0,113,97,100,0,0,0,0,0,107,101,116,97,0,0,0,0,72,97,110,105,105,32,105,110,32,116,104,101,32,83,107,121,0,0,0,0,0,0,0,0,84,104,101,32,75,105,110,103,32,111,102,32,70,105,103,104,116,101,114,115,32,39,57,57,32,45,32,77,105,108,108,101,110,110,105,117,109,32,66,97,116,116,108,101,32,40,78,71,72,45,50,53,49,48,41,0,0,0,0,0,0,0,0,0,77,97,114,118,101,108,32,118,115,32,67,97,112,99,111,109,32,45,32,99,108,97,115,104,32,111,102,32,115,117,112,101,114,32,104,101,114,111,101,115,32,40,57,56,48,49,50,51,32,85,83,65,41,0,0,0,109,100,95,111,111,122,101,112,48,52,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,68,105,100,110,39,116,32,102,105,110,100,32,107,101,121,58,32,37,115,46,10,0,0,0,67,104,105,112,37,105,86,111,108,117,109,101,0,0,0,0,109,100,95,97,100,118,98,97,116,114,112,49,48,0,0,0,85,110,101,109,117,108,97,116,101,100,32,67,80,85,32,102,117,110,99,116,105,111,110,115,0,0,0,0,0,0,0,0,108,100,114,117,110,51,0,0,84,104,101,32,79,111,122,101,32,40,80,114,111,116,111,116,121,112,101,32,49,48,52,44,32,49,57,57,53,48,54,50,50,41,0,0,0,0,0,0,82,45,84,121,112,101,32,76,101,111,32,40,74,97,112,97,110,41,0,0,0,0,0,0,66,97,116,116,108,101,32,67,104,111,112,112,101,114,0,0,109,100,95,111,111,122,101,112,48,53,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,67,111,110,110,101,99,116,105,110,103,32,115,99,111,112,101,32,116,111,32,112,111,114,116,32,37,117,46,10,0,0,0,0,0,0,0,0,102,98,97,45,117,110,105,98,105,111,115,0,0,0,0,0,84,104,101,32,79,111,122,101,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,54,50,57,41,0,0,105,99,45,62,109,111,100,101,0,0,0,0,0,0,0,0,77,111,111,110,32,81,117,97,115,97,114,0,0,0,0,0,82,46,87,0,0,0,0,0,109,100,95,111,111,122,101,112,48,50,0,0,0,0,0,0,84,104,101,32,79,111,122,101,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,54,50,57,45,66,41,0,0,0,0,0,0,0,0,117,110,105,45,98,105,111,115,95,50,95,51,111,46,114,111,109,0,0,0,0,0,0,0,109,100,95,111,111,122,101,112,48,51,0,0,0,0,0,0,49,32,80,108,97,121,101,114,32,79,110,108,121,0,0,0,83,97,109,101,32,97,115,32,83,116,97,114,116,32,111,114,32,49,67,47,49,67,32,40,105,102,32,67,111,105,110,97,103,101,32,52,67,47,51,67,41,0,0,0,0,0,0,0,84,104,101,32,79,111,122,101,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,54,49,57,41,0,0,52,48,48,107,32,56,48,48,107,0,0,0,0,0,0,0,101,97,46,100,0,0,0,0,109,100,95,111,111,122,101,112,48,54,0,0,0,0,0,0,105,56,48,51,57,95,73,67,111,117,110,116,0,0,0,0,84,104,101,32,79,111,122,101,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,54,49,53,41,0,0,37,48,56,120,58,32,71,52,45,49,45,48,32,85,110,100,101,102,105,110,101,100,32,84,104,117,109,98,32,105,110,115,116,114,117,99,116,105,111,110,58,32,37,48,52,120,32,37,120,10,0,0,0,0,0,0,255,254,0,0,198,152,0,0,168,152,0,0,48,98,0,0,102,139,0,0,0,0,0,0,84,0,0,0,104,0,0,0,101,0,0,0,32,0,0,0,80,0,0,0,117,0,0,0,110,0,0,0,105,0,0,0,115,0,0,0,104,0,0,0,101,0,0,0,114,0,0,0,58,0,0,0,32,0,0,0,66,0,0,0,105,0,0,0,97,0,0,0,111,0,0,0,102,0,0,0,101,0,0,0,110,0,0,0,103,0,0,0,32,0,0,0,90,0,0,0,104,0,0,0,97,0,0,0,110,0,0,0,106,0,0,0,105,0,0,0,110,0,0,0,103,0,0,0,32,0,0,0,40,0,0,0,67,0,0,0,104,0,0,0,105,0,0,0,110,0,0,0,101,0,0,0,115,0,0,0,101,0,0,0,32,0,0,0,98,0,0,0,111,0,0,0,111,0,0,0,116,0,0,0,108,0,0,0,101,0,0,0,103,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,75,0,0,0,101,0,0,0,116,0,0,0,115,0,0,0,117,0,0,0,105,0,0,0,32,0,0,0,75,0,0,0,105,0,0,0,122,0,0,0,117,0,0,0,110,0,0,0,97,0,0,0,32,0,0,0,74,0,0,0,105,0,0,0,103,0,0,0,111,0,0,0,107,0,0,0,117,0,0,0,32,0,0,0,84,0,0,0,97,0,0,0,99,0,0,0,104,0,0,0,105,0,0,0,0,0,0,0,177,48,0,0,196,48,0,0,164,48,0,0,126,0,0,0,70,125,0,0,48,87,0,0,68,115,0,0,95,48,0,0,97,48,0,0,32,0,0,0,40,0,0,0,82,0,0,0,101,0,0,0,118,0,0,0,105,0,0,0,115,0,0,0,105,0,0,0,111,0,0,0,110,0,0,0,32,0,0,0,50,0,0,0,63,0,0,0,44,0,0,0,32,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,99,101,95,104,97,110,105,105,115,107,121,0,0,0,0,107,111,102,57,57,104,0,0,109,118,115,99,117,0,0,0,109,100,95,111,111,122,101,112,48,55,0,0,0,0,0,0,72,68,54,51,48,57,67,80,85,67,111,110,116,101,120,116,91,105,93,46,110,67,121,99,108,101,115,76,101,102,116,0,84,104,101,32,65,100,118,101,110,116,117,114,101,115,32,111,102,32,66,97,116,109,97,110,32,38,32,82,111,98,105,110,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,52,49,48,41,0,0,84,104,101,32,79,111,122,101,32,40,69,117,114,111,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,55,50,56,41,0,0,0,0,109,100,95,111,111,122,101,112,48,49,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,67,111,110,110,101,99,116,105,110,103,32,77,117,108,116,105,116,97,112,32,116,111,32,112,111,114,116,32,37,117,46,10,0,0,0,0,0,69,106,101,99,116,101,100,0,110,90,101,116,67,121,99,108,101,115,68,111,110,101,91,105,93,0,0,0,0,0,0,0,84,104,101,32,79,111,122,101,32,40,74,112,110,44,32,85,83,65,41,0,0,0,0,0,112,116,114,45,62,110,67,121,99,108,101,115,76,101,102,116,0,0,0,0,0,0,0,0,109,111,111,110,113,115,114,0,71,97,108,66,97,99,107,103,114,111,117,110,100,66,108,117,101,0,0,0,0,0,0,0,82,45,62,115,0,0,0,0,109,100,95,111,111,122,101,106,117,0,0,0,0,0,0,0,82,111,104,103,97,32,65,114,109,111,114,32,70,111,114,99,101,32,40,65,115,105,97,47,69,117,114,111,112,101,32,118,53,46,48,41,0,0,0,0,84,104,101,32,79,111,122,101,32,40,69,117,114,111,41,0,0,0,0,0,0,0,0,0,109,100,95,111,111,122,101,0,66,97,103,109,97,110,0,0,117,110,105,45,98,105,111,115,95,51,95,48,46,114,111,109,0,0,0,0,0,0,0,0,99,104,105,112,45,62,115,97,109,112,108,101,0,0,0,0,52,32,67,111,105,110,115,32,51,32,67,114,101,100,105,116,115,0,0,0,0,0,0,0,74,117,109,112,0,0,0,0,79,110,115,108,97,117,103,104,116,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,50,48,48,107,32,54,48,48,107,0,0,0,0,0,0,0,90,101,114,111,32,87,105,110,103,0,0,0,0,0,0,0,109,100,95,111,110,115,108,97,117,0,0,0,0,0,0,0,65,114,109,101,100,32,80,111,108,105,99,101,32,66,97,116,114,105,100,101,114,32,40,69,117,114,111,112,101,41,32,40,70,114,105,32,70,101,98,32,49,51,32,49,57,57,56,41,0,0,0,0,0,0,0,0,79,108,121,109,112,105,99,32,83,117,109,109,101,114,32,71,97,109,101,115,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,0,0,66,105,97,111,102,101,110,103,32,90,104,97,110,106,105,110,103,32,40,67,104,105,110,101,115,101,32,98,111,111,116,108,101,103,41,0,0,0,0,0,80,111,108,121,71,97,109,101,77,97,115,116,101,114,32,98,97,115,101,100,0,0,0,0,72,97,110,97,32,84,97,97,107,97,32,68,97,107,97,33,63,0,0,0,0,0,0,0,84,104,101,32,75,105,110,103,32,111,102,32,70,105,103,104,116,101,114,115,32,39,57,57,32,45,32,77,105,108,108,101,110,110,105,117,109,32,66,97,116,116,108,101,32,40,78,71,77,45,50,53,49,48,41,0,0,0,0,0,0,0,0,0,77,97,114,118,101,108,32,118,115,32,67,97,112,99,111,109,32,45,32,99,108,97,115,104,32,111,102,32,115,117,112,101,114,32,104,101,114,111,101,115,32,40,57,56,48,49,49,50,32,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,109,100,95,111,108,121,109,112,115,117,109,0,0,0,0,0,70,105,120,69,105,103,104,116,32,40,69,117,114,111,112,101,41,0,0,0,0,0,0,0,109,100,95,97,100,118,98,97,116,114,112,49,49,0,0,0,79,108,121,109,112,105,99,32,71,111,108,100,32,40,85,83,65,44,32,65,108,116,41,0,0,0,0,0,0,0,0,0,115,108,45,62,107,115,108,0,109,100,95,111,108,121,109,112,103,108,100,117,49,0,0,0,82,101,116,114,111,65,114,99,104,58,32,67,111,110,110,101,99,116,105,110,103,32,74,117,115,116,105,102,105,101,114,115,32,116,111,32,112,111,114,116,32,37,117,46,10,0,0,0,79,108,121,109,112,105,99,32,71,111,108,100,32,40,85,83,65,41,0,0,0,0,0,0,77,111,111,110,32,67,114,101,115,116,97,32,40,71,97,108,97,120,105,97,110,32,104,97,114,100,119,97,114,101,41,0,0,0,0,0,0,0,0,0,84,105,103,101,114,32,72,101,108,105,32,40,85,83,41,0,0,0,0,0,0,0,0,0,109,100,95,111,108,121,109,112,103,108,100,117,0,0,0,0,66,97,99,107,102,105,114,101,33,32,40,115,101,116,32,49,41,0,0,0,0,0,0,0,79,108,121,109,112,105,99,32,71,111,108,100,32,40,74,112,110,44,32,75,111,114,41,0,0,0,0,0,0,0,0,0,84,101,107,105,32,80,97,107,105,0,0,0,0,0,0,0,75,48,53,52,53,51,57,32,82,97,109,32,35,32,37,100,0,0,0,0,0,0,0,0,97,115,105,97,45,115,51,46,114,111,109,0,0,0,0,0,109,100,95,111,108,121,109,112,103,108,100,106,0,0,0,0,84,114,117,120,116,111,110,32,73,73,0,84,97,116,115,117,106,105,110,32,79,104,0,0,89,77,78,84,32,40,52,32,80,108,97,121,101,114,115,32,47,32,52,32,67,111,105,110,32,83,108,111,116,115,0,0,82,111,117,110,100,32,84,105,109,101,0,0,0,0,0,0,79,108,121,109,112,105,99,32,71,111,108,100,32,40,69,117,114,111,41,0,0,0,0,0,80,105,112,105,32,38,32,66,105,98,105,115,32,47,32,87,104,111,111,112,101,101,33,33,32,40,90,56,48,32,115,111,117,110,100,32,99,112,117,44,32,115,101,116,32,49,41,0,0,0,0,0,0,0,0,0,67,111,112,121,114,105,103,104,116,32,78,111,116,105,99,101,0,0,0,0,0,0,0,0,82,101,97,99,104,0,0,0,109,100,95,111,108,121,109,112,103,108,100,0,0,0,0,0,50,32,67,111,105,110,115,47,49,32,67,114,101,100,105,116,32,52,47,51,0,0,0,0,66,97,116,115,117,103,117,110,32,40,115,101,116,32,49,41,0,0,0,0,0,0,0,0,103,97,108,97,112,49,0,0,78,111,114,109,121,39,115,32,66,101,97,99,104,32,66,97,98,101,45,79,45,82,97,109,97,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,112,117,110,105,115,104,101,114,98,122,0,0,0,0,0,0,67,65,86,69,32,47,32,65,77,73,0,0,0,0,0,0,112,99,101,95,104,97,110,97,116,97,107,97,0,0,0,0,82,97,108,108,121,32,66,105,107,101,32,47,32,68,97,115,104,32,89,97,114,111,117,0,0,0,0,0,0,0,0,0,109,118,115,99,106,114,49,0,109,100,95,110,111,114,109,121,0,0,0,0,0,0,0,0,84,104,101,32,65,100,118,101,110,116,117,114,101,115,32,111,102,32,66,97,116,109,97,110,32,38,32,82,111,98,105,110,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,52,48,54,41,0,0,101,100,114,97,110,100,121,0,78,111,98,117,110,97,103,97,32,110,111,32,89,97,98,111,117,32,45,32,90,101,110,107,111,107,117,98,97,110,32,40,74,112,110,41,0,0,0,0,83,110,111,119,32,66,114,111,115,46,32,50,32,45,32,119,105,116,104,32,110,101,119,32,101,108,118,101,115,0,0,0,109,100,95,110,111,98,117,122,101,110,107,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,67,111,110,110,101,99,116,105,110,103,32,74,117,115,116,105,102,105,101,114,32,116,111,32,112,111,114,116,32,37,117,46,10,0,0,0,0,67,97,110,110,111,110,32,68,97,110,99,101,114,32,40,74,97,112,97,110,41,0,0,0,78,111,98,117,110,97,103,97,39,115,32,65,109,98,105,116,105,111,110,32,40,85,83,65,41,0,0,0,0,0,0,0,109,111,111,110,99,114,103,120,0,0,0,0,0,0,0,0,109,100,95,110,111,98,117,97,109,98,0,0,0,0,0,0,75,110,117,99,107,108,101,32,66,97,115,104,32,50,32,40,98,111,111,116,108,101,103,41,0,0,0,0,0,0,0,0,78,111,98,117,110,97,103,97,32,110,111,32,89,97,98,111,117,32,45,32,72,97,111,117,100,101,110,32,40,74,112,110,41,0,0,0,0,0,0,0,91,70,66,65,93,32,70,97,105,108,101,100,32,116,111,32,111,112,101,110,32,97,114,99,104,105,118,101,32,37,115,10,0,0,0,0,0,0,0,0,109,100,95,110,111,98,117,104,97,111,0,0,0,0,0,0,77,84,88,50,32,40,52,32,80,108,97,121,101,114,115,32,47,32,50,32,67,97,98,105,110,101,116,115,0,0,0,0,56,32,84,105,109,101,115,0,66,97,116,116,108,101,32,71,97,114,101,103,103,97,32,40,87,111,114,108,100,41,32,40,83,97,116,32,70,101,98,32,51,32,49,57,57,54,41,0,0,0,0,0,0,0,0,0,78,111,98,117,110,97,103,97,32,110,111,32,89,97,98,111,117,32,45,32,66,117,115,104,111,117,32,70,117,117,117,110,114,111,107,117,32,40,74,112,110,41,0,0,0,0,0,0,109,97,105,110,50,115,117,98,91,49,93,0,0,0,0,0,50,53,50,0,0,0,0,0,50,48,48,107,32,97,110,100,32,54,48,48,107,0,0,0,78,117,109,98,101,114,32,111,102,32,66,111,109,98,115,0,109,100,95,110,111,98,117,98,117,102,117,0,0,0,0,0,70,105,114,101,32,83,104,97,114,107,0,0,0,0,0,0,50,32,67,111,105,110,115,47,49,32,67,114,101,100,105,116,32,53,47,51,0,0,0,0,78,111,32,69,115,99,97,112,101,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,84,104,101,32,80,117,110,105,115,104,101,114,32,40,98,111,111,116,108,101,103,32,115,101,116,32,51,32,40,119,105,116,104,32,80,73,67,49,54,99,53,55,41,44,32,57,51,48,52,50,50,32,101,116,99,41,0,0,0,0,0,0,0,0,71,104,111,120,32,40,115,112,105,110,110,101,114,41,0,0,75,101,116,115,117,105,32,75,105,122,117,110,97,32,74,105,103,111,107,117,32,84,97,99,104,105,32,40,82,101,118,105,115,105,111,110,32,50,63,44,32,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,71,117,110,72,101,100,32,45,32,72,117,100,115,111,110,32,71,117,110,72,101,100,32,84,97,105,107,97,105,0,0,0,77,101,116,97,108,32,83,108,117,103,32,88,32,45,32,83,117,112,101,114,32,86,101,104,105,99,108,101,45,48,48,49,32,40,78,71,77,45,50,53,48,48,41,40,78,71,72,45,50,53,48,48,41,0,0,0,77,97,114,118,101,108,32,118,115,32,67,97,112,99,111,109,32,45,32,99,108,97,115,104,32,111,102,32,115,117,112,101,114,32,104,101,114,111,101,115,32,40,57,56,48,49,50,51,32,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,109,100,95,110,111,101,115,99,97,112,101,0,0,0,0,0,109,100,95,97,100,118,98,97,116,114,112,49,50,0,0,0,75,110,117,99,107,108,101,32,66,97,115,104,0,0,0,0,78,105,110,106,97,32,71,97,105,100,101,110,32,40,74,112,110,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,88,32,40,117,112,41,0,0,109,100,95,110,103,97,105,100,101,110,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,67,111,110,110,101,99,116,105,110,103,32,109,111,117,115,101,32,116,111,32,112,111,114,116,32,37,117,46,10,0,0,0,0,0,0,0,0,86,105,109,97,110,97,32,40,87,111,114,108,100,44,32,115,101,116,32,49,41,0,0,0,78,105,110,106,97,32,66,117,114,97,105,32,68,101,110,115,101,116,115,117,32,40,74,112,110,41,0,0,0,0,0,0,83,116,101,114,97,114,97,110,103,101,114,32,40,77,111,111,110,32,67,114,101,115,116,97,32,98,111,111,116,108,101,103,41,0,0,0,0,0,0,0,79,117,116,32,90,111,110,101,32,40,115,101,116,32,49,41,0,0,0,0,0,0,0,0,71,80,57,48,48,49,82,101,103,110,117,109,0,0,0,0,109,100,95,110,105,110,106,97,98,0,0,0,0,0,0,0,78,105,107,107,97,110,32,83,112,111,114,116,115,32,80,114,111,32,89,97,107,121,117,117,32,86,97,110,32,40,74,112,110,41,0,0,0,0,0,0,84,114,117,120,116,111,110,0,84,97,116,115,117,106,105,110,0,0,0,0,0,0,0,0,83,117,112,101,114,32,82,101,97,108,32,68,97,114,119,105,110,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,91,70,66,65,93,32,70,97,105,108,101,100,32,116,111,32,102,105,110,100,32,97,114,99,104,105,118,101,58,32,37,115,10,0,0,0,0,0,0,0,109,100,95,110,105,107,107,97,110,0,0,0,0,0,0,0,84,82,79,71,32,40,52,32,80,108,97,121,101,114,115,32,47,32,50,32,67,111,105,110,32,83,108,111,116,115,0,0,53,32,84,105,109,101,115,0,84,97,105,116,111,82,111,97,100,80,97,108,66,97,110,107,0,0,0,0,0,0,0,0,66,97,116,116,108,101,32,66,97,107,114,97,105,100,32,45,32,85,110,108,105,109,105,116,101,100,32,86,101,114,115,105,111,110,32,40,85,46,83,46,65,46,41,32,40,84,117,101,32,74,117,110,32,56,32,49,57,57,57,41,0,0,0,0,78,105,103,104,116,109,97,114,101,32,67,105,114,99,117,115,32,40,80,114,111,116,111,116,121,112,101,41,0,0,0,0,109,100,95,110,99,105,114,99,112,0,0,0,0,0,0,0,72,101,108,108,102,105,114,101,32,40,50,80,32,86,101,114,46,41,0,0,0,0,0,0,78,105,103,104,116,109,97,114])
.concat([101,32,67,105,114,99,117,115,32,40,66,114,97,44,32,65,108,116,41,0,0,0,0,0,112,117,110,105,112,105,99,51,0,0,0,0,0,0,0,0,107,101,116,0,0,0,0,0,68,101,109,111,110,39,115,32,87,111,114,108,100,32,47,32,72,111,114,114,111,114,32,83,116,111,114,121,32,40,115,101,116,32,49,41,0,0,0,0,112,99,101,95,103,117,110,104,101,100,104,116,0,0,0,0,109,118,115,99,106,0,0,0,109,100,95,110,99,105,114,99,49,0,0,0,0,0,0,0,65,100,118,97,110,99,101,100,32,68,97,105,115,101,110,114,121,97,107,117,32,45,32,68,101,117,116,115,99,104,32,68,101,110,103,101,107,105,32,83,97,107,117,115,101,110,32,40,74,112,110,44,32,82,101,118,46,32,65,41,0,0,0,0,112,103,109,0,0,0,0,0,65,99,99,101,108,101,114,97,116,101,0,0,0,0,0,0,78,105,103,104,116,109,97,114,101,32,67,105,114,99,117,115,32,40,66,114,97,41,0,0,37,48,56,120,58,32,32,82,101,103,105,115,116,101,114,87,114,105,116,101,98,97,99,107,68,101,99,114,101,109,101,110,116,32,37,100,32,37,100,32,37,100,10,0,0,0,0,0,72,111,116,32,66,0,0,0,109,100,95,110,99,105,114,99,0,0,0,0,0,0,0,0,119,98,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,67,111,110,110,101,99,116,105,110,103,32,100,117,97,108,97,110,97,108,111,103,32,116,111,32,112,111,114,116,32,37,117,46,10,0,0,0,82,45,62,111,117,116,112,117,116,95,99,111,109,112,97,114,101,0,0,0,0,0,0,0,72,117,110,99,104,98,97,99,107,32,79,108,121,109,112,105,99,0,0,0,0,0,0,0,49,32,99,111,105,110,32,52,32,112,108,97,121,0,0,0,102,105,120,101,105,103,104,116,117,0,0,0,0,0,0,0,51,32,99,111,105,110,115,32,49,32,112,108,97,121,0,0,78,105,103,101,108,32,77,97,110,115,101,108,108,39,115,32,87,111,114,108,100,32,67,104,97,109,112,105,111,110,115,104,105,112,32,82,97,99,105,110,103,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,65,108,99,111,110,32,40,85,83,41,0,0,0,0,0,0,49,32,67,111,105,110,32,32,54,32,67,114,101,100,105,116,115,0,0,0,0,0,0,0,115,116,101,114,97,0,0,0,82,101,116,117,114,110,32,111,102,32,116,104,101,32,73,110,118,97,100,101,114,115,0,0,84,101,114,114,105,116,111,114,121,47,67,111,112,121,114,105,103,104,116,0,0,0,0,0,109,100,95,109,97,110,115,101,108,108,117,0,0,0,0,0,74,97,112,97,110,32,40,84,97,105,116,111,32,67,111,114,112,32,108,105,99,101,110,115,101,41,0,0,0,0,0,0,78,105,103,101,108,32,77,97,110,115,101,108,108,39,115,32,87,111,114,108,100,32,67,104,97,109,112,105,111,110,115,104,105,112,32,82,97,99,105,110,103,32,40,69,117,114,111,41,0,0,0,0,0,0,0,0,37,115,47,37,115,0,0,0,109,100,95,109,97,110,115,101,108,108,0,0,0,0,0,0,50,32,80,108,97,121,101,114,115,0,0,0,0,0,0,0,68,111,110,32,68,111,107,111,32,68,111,110,32,40,87,111,114,108,100,41,0,0,0,0,83,99,105,83,112,114,105,116,101,70,114,97,109,101,0,0,78,72,76,80,65,32,72,111,99,107,101,121,32,57,51,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,100,114,116,111,112,112,101,108,117,0,0,0,0,0,0,0,118,112,99,95,112,114,105,111,91,105,93,0,0,0,0,0,65,114,107,97,110,111,105,100,32,40,98,111,111,116,108,101,103,32,119,105,116,104,32,77,67,85,44,32,104,97,114,100,101,114,41,0,0,0,0,0,109,100,95,110,104,108,112,97,57,51,97,0,0,0,0,0,97,108,116,95,98,97,110,107,0,0,0,0,0,0,0,0,82,97,109,98,111,32,73,73,73,32,40,69,117,114,111,112,101,44,32,80,114,111,116,105,63,41,0,0,0,0,0,0,99,104,97,115,101,104,113,117,0,0,0,0,0,0,0,0,67,97,109,101,108,116,114,121,32,40,85,83,44,32,89,77,50,54,49,48,41,0,0,0,78,72,76,80,65,32,72,111,99,107,101,121,32,57,51,32,40,69,117,114,111,44,32,85,83,65,44,32,118,49,46,49,41,0,0,0,0,0,0,0,114,98,105,115,108,97,110,100,0,0,0,0,0,0,0,0,66,97,100,32,68,117,100,101,115,32,118,115,46,32,68,114,97,103,111,110,110,105,110,106,97,32,40,85,83,41,0,0,84,104,101,32,80,117,110,105,115,104,101,114,32,40,98,111,111,116,108,101,103,32,115,101,116,32,50,32,40,119,105,116,104,32,80,73,67,49,54,99,53,55,41,44,32,57,51,48,52,50,50,32,101,116,99,41,0,0,0,0,0,0,0,0,97,115,117,107,97,106,0,0,68,0,0,0,111,0,0,0,68,0,0,0,111,0,0,0,110,0,0,0,80,0,0,0,97,0,0,0,99,0,0,0,104,0,0,0,105,0,0,0,32,0,0,0,68,0,0,0,97,0,0,0,105,0,0,0,45,0,0,0,79,0,0,0,117,0,0,0,45,0,0,0,74,0,0,0,111,0,0,0,117,0,0,0,32,0,0,0,66,0,0,0,108,0,0,0,97,0,0,0,99,0,0,0,107,0,0,0,32,0,0,0,76,0,0,0,97,0,0,0,98,0,0,0,101,0,0,0,108,0,0,0,0,0,0,0,18,96,0,0,150,153,0,0,24,152,0,0,2,135,0,0,32,0,0,0,39,89,0,0,128,95,0,0,31,117,0,0,32,0,0,0,66,0,0,0,108,0,0,0,97,0,0,0,99,0,0,0,107,0,0,0,32,0,0,0,76,0,0,0,97,0,0,0,98,0,0,0,101,0,0,0,108,0,0,0,32,0,0,0,40,0,0,0,86,0,0,0,49,0,0,0,48,0,0,0,48,0,0,0,32,0,0,0,40,0,0,0,50,0,0,0,48,0,0,0,48,0,0,0,50,0,0,0,46,0,0,0,49,0,0,0,48,0,0,0,46,0,0,0,48,0,0,0,55,0,0,0,32,0,0,0,66,0,0,0,108,0,0,0,97,0,0,0,99,0,0,0,107,0,0,0,32,0,0,0,86,0,0,0,101,0,0,0,114,0,0,0,41,0,0,0,44,0,0,0,32,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,71,117,110,72,101,100,0,0,109,115,108,117,103,120,0,0,77,97,114,118,101,108,32,118,115,32,67,97,112,99,111,109,32,45,32,99,108,97,115,104,32,111,102,32,115,117,112,101,114,32,104,101,114,111,101,115,32,40,57,56,48,49,50,51,32,72,105,115,112,97,110,105,99,41,0,0,0,0,0,0,68,114,101,97,109,32,76,97,110,100,32,47,32,83,117,112,101,114,32,68,114,101,97,109,32,76,97,110,100,32,40,98,111,111,116,108,101,103,32,111,102,32,66,117,98,98,108,101,32,66,111,98,98,108,101,41,0,0,0,0,0,0,0,0,84,119,105,110,32,72,97,119,107,32,40,85,83,41,0,0,109,100,95,110,104,108,112,97,57,51,0,0,0,0,0,0,77,111,115,116,0,0,0,0,109,100,95,97,100,118,100,97,105,115,110,0,0,0,0,0,84,104,101,32,76,101,103,101,110,100,32,111,102,32,75,97,103,101,0,0,0,0,0,0,78,72,76,32,65,108,108,45,83,116,97,114,32,72,111,99,107,101,121,32,39,57,53,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,57,50,57,41,0,0,0,84,67,48,50,50,48,73,79,67,73,110,112,117,116,80,111,114,116,50,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,73,32,51,114,100,32,83,116,114,105,107,101,58,32,70,105,103,104,116,32,102,111,114,32,116,104,101,32,70,117,116,117,114,101,32,40,69,117,114,111,32,57,57,48,53,49,50,41,0,0,0,0,0,0,0,65,108,116,101,114,101,100,32,66,101,97,115,116,32,40,115,101,116,32,52,44,32,77,67,45,56,49,50,51,66,32,51,49,55,45,48,48,54,54,41,0,0,0,0,0,0,0,0,84,67,48,49,49,48,80,67,82,65,100,100,114,91,48,93,0,0,0,0,0,0,0,0,99,111,109,112,97,114,101,95,116,105,109,101,114,0,0,0,109,100,95,110,104,108,97,115,112,49,53,0,0,0,0,0,67,97,108,67,111,109,0,0,82,101,116,114,111,65,114,99,104,58,32,68,105,115,99,111,110,110,101,99,116,105,110,103,32,100,101,118,105,99,101,32,102,114,111,109,32,112,111,114,116,32,37,117,46,10,0,0,83,117,112,101,114,32,67,104,97,115,101,32,45,32,67,114,105,109,105,110,97,108,32,84,101,114,109,105,110,97,116,105,111,110,32,40,87,111,114,108,100,41,0,0,0,0,0,0,70,108,105,99,107,121,32,40,49,50,56,107,32,86,101,114,115,105,111,110,44,32,83,121,115,116,101,109,32,50,44,32,110,111,116,32,101,110,99,114,121,112,116,101,100,41,0,0,77,105,110,105,118,97,100,101,114,0,0,0,0,0,0,0,68,46,32,68,46,32,67,114,101,119,32,40,115,101,116,32,53,44,32,74,97,112,97,110,44,32,52,32,80,108,97,121,101,114,115,44,32,70,68,49,48,57,52,32,51,49,55,45,48,49,56,53,41,0,0,0,114,99,104,97,115,101,106,0,78,72,76,32,65,108,108,45,83,116,97,114,32,72,111,99,107,101,121,32,39,57,53,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,57,49,52,41,0,0,0,76,0,0,0,105,0,0,0,110,0,0,0,101,0,0,0,32,0,0,0,111,0,0,0,102,0,0,0,32,0,0,0,70,0,0,0,105,0,0,0,114,0,0,0,101,0,0,0,32,0,0,0,47,0,0,0,32,0,0,0,66,0,0,0,97,0,0,0,107,0,0,0,117,0,0,0,100,0,0,0,97,0,0,0,110,0,0,0,32,0,0,0,89,0,0,0,97,0,0,0,114,0,0,0,111,0,0,0,117,0,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,44,0,0,0,32,0,0,0,70,0,0,0,68,0,0,0,49,0,0,0,48,0,0,0,57,0,0,0,52,0,0,0,32,0,0,0,51,0,0,0,49,0,0,0,55,0,0,0,45,0,0,0,48,0,0,0,49,0,0,0,51,0,0,0,52,0,0,0,41,0,0,0,0,0,0,0,6,114,0,0,62,95,0,0,206,145,0,0,206,144,0,0,0,0,0,0,0,0,0,0,98,111,111,116,108,101,103,32,40,76,97,103,117,110,97,32,83,46,65,46,41,0,0,0,79,112,101,114,97,116,105,111,110,32,84,104,117,110,100,101,114,98,111,108,116,32,40,87,111,114,108,100,41,0,0,0,102,97,110,116,122,111,110,101,0,0,0,0,0,0,0,0,109,100,95,110,104,108,97,115,112,49,54,0,0,0,0,0,115,104,97,114,114,105,101,114,49,0,0,0,0,0,0,0,118,105,100,101,111,95,115,109,111,111,116,104,0,0,0,0,71,114,101,97,116,32,49,48,48,48,32,77,105,108,101,115,32,82,97,108,108,121,58,32,69,118,111,108,117,116,105,111,110,32,77,111,100,101,108,33,33,33,32,40,57,52,47,48,57,47,48,54,41,0,0,0,78,72,76,32,65,108,108,45,83,116,97,114,32,72,111,99,107,101,121,32,39,57,53,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,49,48,50,49,41,0,0,0,87,111,110,100,101,114,32,83,116,105,99,107,0,0,0,0,91,70,66,65,93,32,65,114,99,104,105,118,101,58,32,37,115,10,0,0,0,0,0,0,109,100,95,110,104,108,97,115,112,49,51,0,0,0,0,0,80,108,117,109,112,32,80,111,112,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,83,116,97,103,101,32,67,108,101,97,114,32,69,110,101,114,103,121,32,82,101,103,97,105,110,0,0,0,0,0,0,0,67,97,98,105,110,101,116,32,84,121,112,101,0,0,0,0,67,111,109,112,117,116,101,114,32,76,101,118,101,108,0,0,49,54,48,107,32,111,110,108,121,0,0,0,0,0,0,0,71,97,109,101,82,111,109,77,97,112,112,101,100,0,0,0,84,119,111,32,99,114,101,100,105,116,115,32,116,111,32,115,116,97,114,116,0,0,0,0,78,72,76,32,65,108,108,45,83,116,97,114,32,72,111,99,107,101,121,32,39,57,53,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,49,48,48,49,41,0,0,0,116,100,114,97,103,111,110,50,0,0,0,0,0,0,0,0,69,110,103,108,97,110,100,0,109,97,105,110,50,115,117,98,95,112,101,110,100,105,110,103,0,0,0,0,0,0,0,0,80,101,110,103,117,105,110,32,66,114,111,116,104,101,114,115,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,109,100,95,110,104,108,97,115,112,49,52,0,0,0,0,0,65,114,107,97,110,111,105,100,32,40,87,111,114,108,100,41,0,0,0,0,0,0,0,0,66,103,80,105,99,0,0,0,78,72,76,32,65,108,108,45,83,116,97,114,32,72,111,99,107,101,121,32,39,57,53,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,49,49,50,57,41,0,0,0,247,150,0,0,89,114,0,0,32,0,0,0,83,0,0,0,116,0,0,0,114,0,0,0,97,0,0,0,116,0,0,0,111,0,0,0,32,0,0,0,70,0,0,0,105,0,0,0,103,0,0,0,104,0,0,0,116,0,0,0,101,0,0,0,114,0,0,0,32,0,0,0,40,0,0,0,85,0,0,0,83,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,84,73,77,69,82,32,65,0,68,114,118,66,103,49,83,99,114,111,108,108,88,0,0,0,112,117,110,105,112,105,99,50,0,0,0,0,0,0,0,0,68,111,68,111,110,80,97,99,104,105,32,68,97,105,45,79,117,45,74,111,117,32,66,108,97,99,107,32,76,97,98,101,108,32,40,86,49,48,48,32,40,50,48,48,50,46,49,48,46,48,55,32,66,108,97,99,107,32,86,101,114,41,44,32,74,97,112,97,110,41,0,0,109,105,115,115,109,119,57,54,0,0,0,0,0,0,0,0,77,117,115,105,99,32,40,73,110,45,103,97,109,101,41,0,112,99,101,95,103,117,110,104,101,100,0,0,0,0,0,0,83,117,99,99,101,115,115,32,74,111,101,32,40,87,111,114,108,100,41,0,0,0,0,0,49,32,67,111,105,110,47,57,57,32,67,114,101,100,105,116,115,0,0,0,0,0,0,0,78,101,111,45,71,101,111,32,67,117,112,32,39,57,56,32,45,32,84,104,101,32,82,111,97,100,32,116,111,32,116,104,101,32,86,105,99,116,111,114,121,0,0,0,0,0,0,0,109,118,115,99,104,0,0,0,109,100,95,110,104,108,97,115,112,48,52,0,0,0,0,0,80,114,101,116,116,121,32,83,111,108,100,105,101,114,32,83,97,105,108,111,114,32,77,111,111,110,32,40,118,101,114,46,32,57,53,47,48,51,47,50,50,44,32,85,83,65,41,0,0,0,0,0,0,0,0,0,83,112,114,105,116,101,32,82,65,77,0,0,0,0,0,0,84,104,101,32,65,100,100,97,109,115,32,70,97,109,105,108,121,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,65,108,116,41,0,0,0,0,0,0,0,0,0,109,115,109,54,50,57,53,95,98,97,110,107,0,0,0,0,68,97,114,107,32,83,101,97,108,32,40,87,111,114,108,100,32,114,101,118,105,115,105,111,110,32,51,41,0,0,0,0,78,72,76,32,65,108,108,45,83,116,97,114,32,72,111,99,107,101,121,32,39,57,53,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,49,49,50,56,41,0,0,0,67,104,97,99,107,39,110,32,80,111,112,0,0,0,0,0,65,116,116,101,109,112,116,32,116,111,32,119,114,105,116,101,32,98,121,116,101,32,118,97,108,117,101,32,37,120,32,116,111,32,108,111,99,97,116,105,111,110,32,37,120,10,0,0,109,100,95,110,104,108,97,115,112,48,53,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,82,101,100,105,114,101,99,116,105,110,103,32,115,97,118,101,32,115,116,97,116,101,32,116,111,32,34,37,115,34,46,10,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,65,118,101,114,97,103,101,32,109,111,110,105,116,111,114,32,72,122,58,32,37,46,54,102,32,72,122,46,32,40,37,46,51,102,32,37,37,32,102,114,97,109,101,32,116,105,109,101,32,100,101,118,105,97,116,105,111,110,44,32,98,97,115,101,100,32,111,110,32,37,117,32,108,97,115,116,32,115,97,109,112,108,101,115,41,46,10,0,0,0,0,0,0,113,122,107,107,108,103,121,50,0,0,0,0,0,0,0,0,78,72,76,32,65,108,108,45,83,116,97,114,32,72,111,99,107,101,121,32,39,57,53,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,49,49,50,55,41,0,0,0,67,114,101,115,116,97,32,77,117,110,100,111,32,40,76,97,103,117,110,97,32,83,46,65,46,32,83,112,97,110,105,115,104,32,77,111,111,110,32,67,114,101,115,116,97,32,98,111,111,116,108,101,103,41,0,0,84,119,105,110,107,108,101,0,0,0,0,0,0,0,0,0,72,97,116,99,104,32,67,97,116,99,104,0,0,0,0,0,109,100,95,110,104,108,97,115,112,48,54,0,0,0,0,0,69,120,116,114,97,32,66,97,108,108,115,0,0,0,0,0,115,49,57,52,53,106,0,0,77,97,115,116,101,114,32,111,102,32,87,101,97,112,111,110,32,40,87,111,114,108,100,41,0,0,0,0,0,0,0,0,80,49,32,98,117,116,116,111,110,32,49,0,0,0,0,0,78,72,76,32,65,108,108,45,83,116,97,114,32,72,111,99,107,101,121,32,39,57,53,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,49,49,50,51,41,0,0,0,83,108,97,112,32,83,104,111,116,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,116,101,114,114,97,102,106,98,0,0,0,0,0,0,0,0,84,67,48,53,49,48,78,73,79,73,110,112,117,116,80,111,114,116,50,0,0,0,0,0,101,110,97,98,108,101,100,0,109,100,95,110,104,108,97,115,112,48,55,0,0,0,0,0,66,117,115,116,101,114,32,66,114,111,115,46,32,40,85,83,41,0,0,0,0,0,0,0,49,67,32,49,67,32,47,32,49,67,32,52,67,0,0,0,77,97,103,105,99,0,0,0,66,103,83,99,114,111,108,108,88,91,105,93,0,0,0,0,56,48,107,32,111,110,108,121,0,0,0,0,0,0,0,0,84,97,105,116,111,67,112,117,65,67,116,114,108,0,0,0,75,0,0,0,0,0,0,0,73,115,103,115,109,82,108,101,66,121,116,101,0,0,0,0,46,0,0,0,0,0,0,0,78,72,76,32,65,108,108,45,83,116,97,114,32,72,111,99,107,101,121,32,39,57,53,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,49,49,50,50,41,0,0,0,72,97,110,103,108,121,45,77,97,110,32,40,115,101,116,32,50,41,0,0,0,0,0,0,103,97,117,110,116,108,101,116,103,114,51,0,0,0,0,0,109,100,95,110,104,108,97,115,112,48,56,0,0,0,0,0,50,67,0,0,0,0,0,0,78,72,76,32,65,108,108,45,83,116,97,114,32,72,111,99,107,101,121,32,39,57,53,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,49,49,50,49,41,0,0,0,84,104,101,32,80,117,110,105,115,104,101,114,32,40,98,111,111,116,108,101,103,32,115,101,116,32,49,32,40,119,105,116,104,32,80,73,67,49,54,99,53,55,41,44,32,57,51,48,52,50,50,32,101,116,99,41,0,0,0,0,0,0,0,0,100,100,112,100,111,106,98,108,107,97,0,0,0,0,0,0,71,114,97,100,105,117,115,0,0,0,0,0,0,0,0,0,110,101,111,99,117,112,57,56,0,0,0,0,0,0,0,0,77,97,114,118,101,108,32,118,115,32,67,97,112,99,111,109,32,45,32,99,108,97,115,104,32,111,102,32,115,117,112,101,114,32,104,101,114,111,101,115,32,40,57,56,48,49,50,51,32,66,114,97,122,105,108,41,0,0,0,0,0,0,0,0,65,113,117,97,106,97,99,107,32,40,87,111,114,108,100,41,0,0,0,0,0,0,0,0,84,67,48,54,52,48,70,73,79,73,110,112,117,116,80,111,114,116,50,0,0,0,0,0,109,100,95,110,104,108,97,115,112,48,57,0,0,0,0,0,68,114,118,83,99,114,111,108,108,50,91,50,93,0,0,0,109,100,95,97,100,100,102,97,109,112,50,0,0,0,0,0,83,117,112,101,114,32,70,97,115,116,0,0,0,0,0,0,84,97,116,97,107,97,105,32,110,111,32,66,97,110,107,97,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,49,53,48,48,48,48,32,53,48,48,48,48,48,0,0,0,109,57,50,95,115,112,114,105,116,101,95,98,117,102,102,101,114,95,116,105,109,101,114,0,78,72,76,32,65,108,108,45,83,116,97,114,32,72,111,99,107,101,121,32,39,57,53,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,49,49,49,57,41,0,0,0,67,67,104,105,112,32,82,97,109,0,0,0,0,0,0,0,116,114,105,112,111,111,108,0,83,117,112,101,114,32,66,117,114,103,101,114,32,84,105,109,101,32,40,87,111,114,108,100,44,32,115,101,116,32,49,41,0,0,0,0,0,0,0,0,73,107,97,114,105,32,73,73,73,32,45,32,84,104,101,32,82,101,115,99,117,101,32,40,85,83,44,32,82,111,116,97,114,121,32,74,111,121,115,116,105,99,107,41,0,0,0,0,68,114,118,66,103,83,99,114,111,108,108,88,91,48,93,0,109,100,95,110,104,108,97,115,112,49,48,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,82,101,100,105,114,101,99,116,105,110,103,32,115,97,118,101,32,102,105,108,101,32,116,111,32,34,37,115,34,46,10,0,0,0,0,0,0,71,121,114,111,100,105,110,101,32,40,84,97,105,116,111,32,67,111,114,112,111,114,97,116,105,111,110,32,108,105,99,101,110,115,101,41,0,0,0,0,78,72,76,32,65,108,108,45,83,116,97,114,32,72,111,99,107,101,121,32,39,57,53,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,49,49,48,57,41,0,0,0,73,80,83,0,0,0,0,0,109,111,111,110,99,114,115,108,0,0,0,0,0,0,0,0,32,52,32,67,111,105,110,115,32,49,32,67,114,101,100,105,116,0,0,0,0,0,0,0,109,97,107,97,105,109,117,114,103,0,0,0,0,0,0,0,68,97,114,105,117,115,32,40,87,111,114,108,100,41,0,0,49,32,67,111,105,110,32,32,49,32,67,114,101,100,105,116,32,32,47,32,49,32,67,111,105,110,32,32,54,32,32,67,114,101,100,105,116,115,0,0,109,100,95,110,104,108,97,115,112,49,49,0,0,0,0,0,87,99,57,48,83,99,114,111,108,108,50,88,76,111,0,0,78,72,76,32,65,108,108,45,83,116,97,114,32,72,111,99,107,101,121,32,39,57,53,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,49,49,48,55,41,0,0,0,97,115,105,99,50,55,97,95,115,105,109,95,107,101,121,0,70,114,111,110,116,101,110,100,32,115,117,112,112,111,114,116,115,32,82,71,66,53,54,53,32,45,32,119,105,108,108,32,117,115,101,32,116,104,97,116,32,105,110,115,116,101,97,100,32,111,102,32,88,82,71,66,49,53,53,53,46,10,0,0,67,97,100,97,115,104,32,40,87,111,114,108,100,41,0,0,109,100,95,110,104,108,97,115,112,49,50,0,0,0,0,0,84,105,108,101,109,97,112,32,82,65,77,0,0,0,0,0,56,32,115,101,99,111,110,100,115,0,0,0,0,0,0,0,101,118,101,114,121,32,56,48,107,0,0,0,0,0,0,0,79,108,100,83,116,101,101,114,0,0,0,0,0,0,0,0,73,115,103,115,109,82,108,101,76,97,116,99,104,101,100,0,78,72,76,32,65,108,108,45,83,116,97,114,32,72,111,99,107,101,121,32,39,57,53,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,49,50,48,50,41,0,0,0,109,100,95,110,104,108,97,115,112,48,49,0,0,0,0,0,112,111,114,116,67,95,105,110,0,0,0,0,0,0,0,0,65,111,105,32,66,108,105,110,107,0,0,0,0,0,0,0,78,72,76,32,65,108,108,45,83,116,97,114,32,72,111,99,107,101,121,32,39,57,53,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,49,50,48,49,41,0,0,0,112,117,110,105,112,105,99,0,68,0,0,0,111,0,0,0,68,0,0,0,111,0,0,0,110,0,0,0,80,0,0,0,97,0,0,0,99,0,0,0,104,0,0,0,105,0,0,0,32,0,0,0,68,0,0,0,97,0,0,0,105,0,0,0,45,0,0,0,79,0,0,0,117,0,0,0,45,0,0,0,74,0,0,0,111,0,0,0,117,0,0,0,32,0,0,0,66,0,0,0,108,0,0,0,97,0,0,0,99,0,0,0,107,0,0,0,32,0,0,0,76,0,0,0,97,0,0,0,98,0,0,0,101,0,0,0,108,0,0,0,0,0,0,0,18,96,0,0,150,153,0,0,24,152,0,0,2,135,0,0,32,0,0,0,39,89,0,0,128,95,0,0,31,117,0,0,32,0,0,0,66,0,0,0,108,0,0,0,97,0,0,0,99,0,0,0,107,0,0,0,32,0,0,0,76,0,0,0,97,0,0,0,98,0,0,0,101,0,0,0,108,0,0,0,32,0,0,0,40,0,0,0,86,0,0,0,49,0,0,0,48,0,0,0,48,0,0,0,32,0,0,0,40,0,0,0,50,0,0,0,48,0,0,0,48,0,0,0,50,0,0,0,46,0,0,0,49,0,0,0,48,0,0,0,46,0,0,0,48,0,0,0,55,0,0,0,46,0,0,0,66,0,0,0,108,0,0,0,97,0,0,0,99,0,0,0,107,0,0,0,32,0,0,0,86,0,0,0,101,0,0,0,114,0,0,0,41,0,0,0,44,0,0,0,32,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,99,101,95,103,114,97,100,105,117,115,0,0,0,0,0,84,0,0,0,104,0,0,0,101,0,0,0,32,0,0,0,76,0,0,0,97,0,0,0,115,0,0,0,116,0,0,0,32,0,0,0,66,0,0,0,108,0,0,0,97,0,0,0,100,0,0,0,101,0,0,0,32,0,0,0,50,0,0,0,0,0,0,0,85,94,0,0,43,103,0,0,106,109,0,0,43,111,0,0,44,123,0,0,140,78,0,0,85,94,0,0,32,0,0,0,45,0,0,0,32,0,0,0,8,103,0,0,239,131,0,0,110,48,0,0,99,82,0,0,235,88,0,0,32,0,0,0,45,0,0,0,32,0,0,0,8,103,0,0,107,48,0,0,178,84,0,0,79,48,0,0,239,131,0,0,1,48,0,0,99,101,0,0,138,48,0,0,134,48,0,0,79,48,0,0,177,130,0,0,32,0,0,0,40,0,0,0,78,0,0,0,71,0,0,0,77,0,0,0,45,0,0,0,50,0,0,0,52,0,0,0,51,0,0,0,48,0,0,0,41,0,0,0,40,0,0,0,78,0,0,0,71,0,0,0,72,0,0,0,45,0,0,0,50,0,0,0,52,0,0,0,51,0,0,0,48,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,109,118,115,99,98,0,0,0,67,97,112,116,97,105,110,32,67,111,109,109,97,110,100,111,32,40,57,49,49,50,48,50,32,111,116,104,101,114,32,99,111,117,110,116,114,121,41,0,0,0,0,0,0,0,0,0,109,100,95,110,104,108,97,115,112,48,50,0,0,0,0,0,110,73,82,81,67,121,99,108,101,115,0,0,0,0,0,0,84,104,101,32,65,100,100,97,109,115,32,70,97,109,105,108,121,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,66,117,98,98,108,101,32,66,111,98,98,108,101,0,0,0,49,48,48,48,48,48,32,52,48,48,48,48,48,0,0,0,78,72,76,32,65,108,108,45,83,116,97,114,32,72,111,99,107,101,121,32,39,57,53,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,49,50,48,49,45,66,41,0,0,0,0,0,0,0,0,0,109,57,50,95,115,112,114,105,116,101,95,98,117,102,102,101,114,95,98,117,115,121,0,0,118,100,99,95,108,97,116,99,104,91,105,93,0,0,0,0,109,100,95,110,104,108,97,115,112,48,51,0,0,0,0,0,46,120,109,108,0,0,0,0,79,80,76,45,62,108,102,111,95,112,109,95,100,101,112,116,104,95,114,97,110,103,101,0,66,97,108,108,111,111,110,32,66,114,111,116,104,101,114,115,0,0,0,0,0,0,0,0,109,99,117,95,99,111,105,110,97,103,101,91,48,93,0,0,66,103,83,99,114,111,108,108,88,0,0,0,0,0,0,0,103,108,79,98,106,101,99,116,80,116,114,76,97,98,101,108,0,0,0,0,0,0,0,0,84,67,48,50,56,48,71,82,68,66,97,115,101,67,111,108,111,117,114,0,0,0,0,0,78,72,76,32,65,108,108,45,83,116,97,114,32,72,111,99,107,101,121,32,39,57,53,32,40,85,83,65,41,0,0,0,77,111,111,110,32,67,114,101,115,116,97,32,40,69,108,101,99,116,114,111,103,97,109,101,32,83,46,65,46,32,83,112,97,110,105,115,104,32,98,111,111,116,108,101,103,41,0,0,80,114,101,118,0,0,0,0,109,100,95,110,104,108,97,115,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,71,76,93,58,32,86,101,114,115,105,111,110,58,32,37,115,46,10,0,0,68,97,114,105,117,115,32,73,73,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,78,111,32,67,111,114,101,0,78,72,76,32,57,56,32,40,85,83,65,41,0,0,0,0,78,47,65,32,40,112,111,114,116,32,35,37,117,41,0,0,109,100,95,114,105,115,101,114,111,98,111,0,0,0,0,0,70,114,111,110,116,101,110,100,32,115,117,112,112,111,114,116,115,32,88,82,71,66,56,56,56,32,45,32,119,105,108,108,32,117,115,101,32,116,104,97,116,32,105,110,115,116,101,97,100,32,111,102,32,88,82,71,66,49,53,53,53,46,10,0,109,100,95,110,104,108,57,56,0,0,0,0,0,0,0,0,84,104,101,32,70,97,105,114,121,76,97,110,100,32,83,116,111,114,121,0,0,0,0,0,55,32,115,101,99,111,110,100,115,0,0,0,0,0,0,0,51,32,67,104,97,114,97,99,116,101,114,115,0,0,0,0,111,102,102,0,0,0,0,0,73,115,103,115,109,82,108,101,67,111,110,116,114,111,108,66,121,116,101,0,0,0,0,0,78,72,76,32,57,55,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,78,101,118,97,100,97,0,0,109,100,95,110,104,108,57,55,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,73,109,112,111,114,116,32,118,97,108,117,101,32,105,115,32,105,110,118,97,108,105,100,46,10,0,0,71,114,97,100,105,117,115,32,73,73,32,45,32,71,79,70,69,82,32,110,111,32,89,97,98,111,117,32,40,74,97,112,97,110,32,79,108,100,101,114,32,118,101,114,46,41,0,0,79,117,116,32,82,117,110,32,40,115,105,116,100,111,119,110,47,117,112,114,105,103,104,116,44,32,82,101,118,32,66,41,0,0,0,0,0,0,0,0,78,72,76,32,57,54,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,65,114,109,111,114,101,100,32,87,97,114,114,105,111,114,115,32,40,57,52,49,48,49,49,32,69,117,114,111,112,101,41,0,0,0,0,0,0,0,0,84,104,101,32,80,117,110,105,115,104,101,114,32,40,57,51,48,52,50,50,32,72,105,115,112,97,110,105,99,41,0,0,68,111,68,111,110,80,97,99,104,105,32,68,97,105,45,79,117,45,74,111,117,32,66,108,97,99,107,32,76,97,98,101,108,32,40,86,49,48,48,44,32,40,50,48,48,50,46,49,48,46,48,55,46,66,108,97,99,107,32,86,101,114,41,44,32,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,71,111,109,111,108,97,32,83,112,101,101,100,0,0,0,0,84,104,101,32,76,97,115,116,32,66,108,97,100,101,32,50,32,47,32,66,97,107,117,109,97,116,115,117,32,82,111,109,97,110,32,45,32,68,97,105,32,78,105,32,77,97,107,117,32,71,101,107,107,97,32,110,111,32,75,101,110,115,104,105,32,40,78,71,77,45,50,52,51,48,41,40,78,71,72,45,50,52,51,48,41,0,0,0,77,97,114,118,101,108,32,118,115,32,67,97,112,99,111,109,32,45,32,99,108,97,115,104,32,111,102,32,115,117,112,101,114,32,104,101,114,111,101,115,32,40,57,56,48,49,49,50,32,65,115,105,97,41,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,66,97,115,101,32,111,118,101,114,108,97,121,32,105,115,32,110,111,116,32,115,101,116,32,97,110,100,32,110,111,116,32,117,115,105,110,103,32,110,111,114,109,97,108,105,122,101,100,32,99,111,111,114,100,105,110,97,116,101,115,46,10,0,0,109,100,95,110,104,108,57,54,0,0,0,0,0,0,0,0,109,100,95,97,100,100,102,97,109,112,49,0,0,0,0,0,77,46,73,46,65,46,32,45,32,77,105,115,115,105,110,103,32,105,110,32,65,99,116,105,111,110,32,40,118,101,114,46,32,84,41,0,0,0,0,0,82,105,115,107,121,32,67,104,97,108,108,101,110,103,101,0,0,0,0,0,0,0,0,0,76,111,100,101,32,82,117,110,110,101,114,32,73,73,32,45,32,84,104,101,32,66,117,110,103,101,108,105,110,103,32,83,116,114,105,107,101,115,32,66,97,99,107,0,0,0,0,0,109,57,50,95,115,112,114,105,116,101,95,108,105,115,116,0,78,72,76,32,57,53,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,114,116,121,112,101,108,101,111,106,0,0,0,0,0,0,0,109,100,95,110,104,108,57,53,0,0,0,0,0,0,0,0,98,99,104,111,112,112,101,114,0,0,0,0,0,0,0,0,46,105,112,115,0,0,0,0,78,72,75,32,84,97,105,103,97,32,68,114,97,109,97,32,45,32,84,97,105,104,101,105,107,105,32,40,74,112,110,41,0,0,0,0,0,0,0,0,109,111,111,110,99,114,101,103,0,0,0,0,0,0,0,0,109,100,95,110,104,107,116,97,105,100,114,0,0,0,0,0,78,70,76,32,83,112,111,114,116,115,32,84,97,108,107,32,70,111,111,116,98,97,108,108,32,39,57,51,32,83,116,97,114,114,105,110,103,32,74,111,101,32,77,111,110,116,97,110,97,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,71,97,109,101,58,32,37,115,10,0,0,0,0,0,0,0,109,100,95,110,102,108,115,112,111,114,116,0,0,0,0,0,54,32,115,101,99,111,110,100,115,0,0,0,0,0,0,0,83,99,114,105,98,98,108,101,0,0,0,0,0,0,0,0,84,97,105,116,111,65,110,97,108,111,103,80,111,114,116,51,0,0,0,0,0,0,0,0,73,115,103,115,109,82,108,101,67,111,110,116,114,111,108,80,111,115,105,116,105,111,110,0,78,70,76,32,81,117,97,114,116,101,114,98,97,99,107,32,67,108,117,98,32,57,54,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,65,99,101,32,65,116,116,97,99,107,101,114,32,40,70,68,49,48,57,52,32,51,49,55,45,48,48,53,57,41,0,0,84,104,97,105,108,97,110,100,0,0,0,0,0,0,0,0,109,100,95,110,102,108,113,98,57,54,0,0,0,0,0,0,78,70,76,32,81,117,97,114,116,101,114,98,97,99,107,32,67,108,117,98,32,40,87,111,114,108,100,41,0,0,0,0,87,111,114,107,32,82,97,109,0,0,0,0,0,0,0,0,112,117,110,105,115,104,101,114,104,0,0,0,0,0,0,0,100,100,112,100,111,106,98,108,107,0,0,0,0,0,0,0,112,99,101,95,103,111,109,111,108,97,0,0,0,0,0,0,109,118,115,99,97,114,49,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,73,58,32,78,101,119,32,71,101,110,101,114,97,116,105,111,110,32,40,85,83,65,32,57,55,48,50,48,52,41,0,0,0,0,0,0,0,0,0,109,100,95,110,102,108,113,98,0,0,0,0,0,0,0,0,65,100,100,97,109,115,32,70,97,109,105,108,121,32,86,97,108,117,101,115,32,40,69,117,114,111,41,0,0,0,0,0,115,112,114,105,116,101,95,101,120,116,101,110,116,0,0,0,78,70,76,32,70,111,111,116,98,97,108,108,32,39,57,52,32,83,116,97,114,114,105,110,103,32,74,111,101,32,77,111,110,116,97,110,97,32,40,74,112,110,41,0,0,0,0,0,110,67,97,118,101,84,105,108,101,66,97,110,107,0,0,0,66,97,110,107,32,80,97,110,105,99,0,0,0,0,0,0,109,100,95,110,102,108,57,52,106,0,0,0,0,0,0,0,46,98,112,115,0,0,0,0,37,115,32,118,105,114,116,117,97,108,32,100,105,115,107,32,116,114,97,121,46,0,0,0,78,70,76,32,70,111,111,116,98,97,108,108,32,39,57,52,32,83,116,97,114,114,105,110,103,32,74,111,101,32,77,111,110,116,97,110,97,32,40,85,83,65,41,0,0,0,0,0,83,112,97,99,101,32,68,114,97,103,111,110,32,40,77,111,111,110,32,67,114,101,115,116,97,32,98,111,111,116,108,101,103,44,32,115,101,116,32,50,41,0,0,0,0,0,0,0,71,97,108,66,97,99,107,103,114,111,117,110,100,71,114,101,101,110,0,0,0,0,0,0,109,100,95,110,102,108,57,52,0,0,0,0,0,0,0,0,78,70,76,32,57,56,32,40,85,83,65,41,0,0,0,0,115,98,111,109,98,101,114,97,0,0,0,0,0,0,0,0,109,100,95,110,102,108,57,56,0,0,0,0,0,0,0,0,52,45,68,32,87,97,114,114,105,111,114,115,32,40,51,49,53,45,53,49,54,50,41,0,0,0,0,0,0,0,0,0,68,101,102,97,117,108,116,32,84,105,109,101,0,0,0,0,72,105,32,83,99,111,114,101,0,0,0,0,0,0,0,0,84,97,105,116,111,65,110,97,108,111,103,80,111,114,116,50,0,0,0,0,0,0,0,0,73,115,103,115,109,83,101,99,117,114,105,116,121,76,97,116,99,104,0,0,0,0,0,0,78,70,76,32,39,57,53,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,57,49,49,41,0,0,0,55,48,107,0,0,0,0,0,109,100,95,110,102,108,57,53,112,48,49,0,0,0,0,0,78,70,76,32,39,57,53,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,57,49,49,45,66,41,0,0,0,0,0,0,0,0,0,100,84,105,109,101,0,0,0,65,108,105,101,110,32,83,116,111,114,109,32,40,115,101,116,32,52,44,32,87,111,114,108,100,44,32,50,32,80,108,97,121,101,114,115,44,32,70,68,49,48,57,52,32,51,49,55,45,48,49,53,52,41,0,0,84,104,101,32,80,117,110,105,115,104,101,114,32,40,57,51,48,52,50,50,32,74,97,112,97,110,41,0,0,0,0,0,68,111,68,111,110,80,97,99,104,105,32,68,97,105,45,79,117,45,74,111,117,32,40,86,49,48,48,32,40,102,105,114,115,116,32,118,101,114,115,105,111,110,41,44,32,74,97,112,97,110,41,0,0,0,0,0,68,111,116,116,111,114,105,32,75,117,110,32,40,110,101,119,32,118,101,114,115,105,111,110,41,0,0,0,0,0,0,0,71,111,107,117,114,97,107,117,33,32,67,104,117,107,97,32,84,97,105,115,101,110,0,0,84,104,101,32,75,105,110,103,32,111,102,32,70,105,103,104,116,101,114,115,32,39,57,56,32,45,32,84,104,101,32,83,108,117,103,102,101,115,116,32,47,32,75,105,110,103,32,111,102,32,70,105,103,104,116,101,114,115,32,39,57,56,32,45,32,100,114,101,97,109,32,109,97,116,99,104,32,110,101,118,101,114,32,101,110,100,115,32,40,78,71,72,45,50,52,50,48,41,0,0,0,0,0,0,77,97,114,118,101,108,32,118,115,32,67,97,112,99,111,109,32,45,32,99,108,97,115,104,32,111,102,32,115,117,112,101,114,32,104,101,114,111,101,115,32,40,57,56,48,49,50,51,32,65,115,105,97,41,0,0,109,100,95,110,102,108,57,53,112,48,50,0,0,0,0,0,109,100,95,97,100,100,102,97,109,118,0,0,0,0,0,0,109,57,50,95,114,97,115,116,101,114,95,105,114,113,95,112,111,115,105,116,105,111,110,0,78,70,76,32,39,57,53,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,57,48,57,41,0,0,0,71,97,108,97,120,121,32,70,111,114,99,101,32,50,0,0,72,111,116,100,111,103,32,83,116,111,114,109,32,45,32,84,104,101,32,70,105,114,115,116,32,83,117,112,101,114,115,111,110,105,99,115,32,40,73,110,116,101,114,110,97,116,105,111,110,97,108,41,0,0,0,0,76,32,98,117,116,116,111,110,32,40,115,104,111,117,108,100,101,114,41,0,0,0,0,0,109,100,95,110,102,108,57,53,112,48,51,0,0,0,0,0,115,108,45,62,75,83,82,0,46,117,112,115,0,0,0,0,78,70,76,32,39,57,53,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,57,48,56,41,0,0,0,115,112,99,100,114,97,103,97,0,0,0,0,0,0,0,0,109,100,95,110,102,108,57,53,112,48,52,0,0,0,0,0,65,46,66,46,32,67,111,112,32,40,87,111,114,108,100,44,32,70,68,49,48,57,52,32,51,49,55,45,48,49,54,57,98,41,0,0,0,0,0,0,78,70,76,32,39,57,53,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,57,48,55,41,0,0,0,83,117,112,101,114,32,76,111,99,111,109,111,116,105,118,101,32,40,82,101,118,46,65,41,0,0,0,0,0,0,0,0,115,98,111,109,98,101,114,0,109,100,95,110,102,108,57,53,112,48,53,0,0,0,0,0,52,32,66,117,116,116,111,110,115,0,0,0,0,0,0,0,84,97,105,116,111,65,110,97,108,111,103,80,111,114,116,49,0,0,0,0,0,0,0,0,65,110,103,101,108,32,75,105,100,115,32,40,74,97,112,97,110,41,0,0,0,0,0,0,73,115,103,115,109,83,101,99,117,114,105,116,121,0,0,0,78,70,76,32,39,57,53,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,57,48,54,41,0,0,0,54,48,107,0,0,0,0,0,71,101,110,86,68,80,32,82,101,103,115,0,0,0,0,0,83,116,97,114,116,105,110,103])
.concat([32,108,101,118,101,108,0,0,75,97,110,0,0,0,0,0,109,100,95,110,102,108,57,53,112,48,54,0,0,0,0,0,71,97,108,97,120,105,97,110,32,80,97,114,116,32,88,32,40,109,111,111,110,97,108,110,32,104,97,99,107,41,0,0,78,70,76,32,39,57,53,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,57,48,53,41,0,0,0,112,117,110,105,115,104,101,114,106,0,0,0,0,0,0,0,100,100,112,100,111,106,98,0,112,99,101,95,99,104,117,107,97,116,97,105,0,0,0,0,107,111,102,57,56,104,0,0,109,100,95,110,102,108,57,53,112,48,55,0,0,0,0,0,109,118,115,99,97,0,0,0,65,99,116,105,111,110,32,53,50,32,40,85,83,65,44,32,65,108,116,41,0,0,0,0,68,101,97,116,104,32,66,114,97,100,101,32,40,74,97,112,97,110,32,118,101,114,32,74,77,45,51,41,0,0,0,0,80,97,108,66,97,110,107,0,78,70,76,32,39,57,53,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,57,48,53,45,66,41,0,0,0,0,0,0,0,0,0,109,100,95,110,102,108,57,53,112,48,56,0,0,0,0,0,99,97,110,100,97,110,99,101,0,0,0,0,0,0,0,0,78,70,76,32,39,57,53,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,57,48,52,41,0,0,0,69,110,100,117,114,111,32,82,97,99,101,114,32,40,89,77,50,49,53,49,44,32,70,68,49,48,56,57,66,32,51,49,55,45,48,48,49,51,65,41,0,0,0,0,0,0,0,0,83,112,97,99,101,32,68,114,97,103,111,110,32,40,77,111,111,110,32,67,114,101,115,116,97,32,98,111,111,116,108,101,103,44,32,115,101,116,32,49,41,0,0,0,0,0,0,0,69,83,80,32,82,97,46,68,101,46,32,45,32,65,46,68,46,50,48,49,56,32,84,111,107,121,111,32,40,73,110,116,101,114,110,97,116,105,111,110,97,108,44,32,118,101,114,46,32,57,56,47,48,52,47,50,50,41,0,0,0,0,0,0,109,100,95,110,102,108,57,53,112,48,57,0,0,0,0,0,68,105,118,101,114,32,66,111,121,0,0,0,0,0,0,0,78,70,76,32,39,57,53,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,57,48,50,41,0,0,0,70,117,110,110,121,32,66,117,98,98,108,101,0,0,0,0,100,97,114,97,107,117,0,0,109,100,95,110,102,108,57,53,112,49,48,0,0,0,0,0,83,105,108,118,101,114,32,77,105,108,108,101,110,110,105,117,109,0,0,0,0,0,0,0,74,111,121,115,116,105,99,107,0,0,0,0,0,0,0,0,84,97,105,116,111,65,110,97,108,111,103,80,111,114,116,48,0,0,0,0,0,0,0,0,73,115,103,115,109,65,100,100,114,76,97,116,99,104,0,0,78,70,76,32,39,57,53,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,57,48,49,41,0,0,0,53,48,107,0,0,0,0,0,49,53,48,107,44,32,51,48,48,107,32,97,110,100,32,54,48,48,107,0,0,0,0,0,109,100,95,110,102,108,57,53,112,49,49,0,0,0,0,0,72,101,108,112,32,77,111,100,101,0,0,0,0,0,0,0,82,97,99,107,32,84,101,115,116,32,40,67,104,101,97,116,41,0,0,0,0,0,0,0,84,104,101,32,66,101,114,108,105,110,32,87,97,108,108,0,0,0,0,0,0,0,0,0,78,70,76,32,39,57,53,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,56,51,49,41,0,0,0,84,104,101,32,80,117,110,105,115,104,101,114,32,40,57,51,48,52,50,50,32,85,83,65,41,0,0,0,0,0,0,0,68,111,68,111,110,80,97,99,104,105,32,68,97,105,45,79,117,45,74,111,117,32,40,86,49,48,48,32,40,115,101,99,111,110,100,32,118,101,114,115,105,111,110,41,44,32,74,97,112,97,110,41,0,0,0,0,71,101,110,112,101,105,32,84,111,117,109,97,100,101,110,32,110,105,32,110,111,32,77,97,107,105,0,0,0,0,0,0,84,104,101,32,75,105,110,103,32,111,102,32,70,105,103,104,116,101,114,115,32,39,57,56,32,45,32,84,104,101,32,83,108,117,103,102,101,115,116,32,47,32,75,105,110,103,32,111,102,32,70,105,103,104,116,101,114,115,32,39,57,56,32,45,32,100,114,101,97,109,32,109,97,116,99,104,32,110,101,118,101,114,32,101,110,100,115,32,40,75,111,114,101,97,110,32,98,111,97,114,100,32,50,41,0,0,0,0,0,0,0,0,109,100,95,110,102,108,57,53,112,49,50,0,0,0,0,0,77,97,114,118,101,108,32,118,115,32,67,97,112,99,111,109,32,45,32,99,108,97,115,104,32,111,102,32,115,117,112,101,114,32,104,101,114,111,101,115,32,40,57,56,48,49,49,50,32,69,117,114,111,41,0,0,109,100,95,97,99,116,105,111,110,53,50,97,0,0,0,0,77,117,108,116,105,32,67,104,97,109,112,32,40,87,111,114,108,100,41,0,0,0,0,0,78,70,76,32,39,57,53,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,56,51,48,41,0,0,0,71,117,109,98,111,0,0,0,109,100,95,110,102,108,57,53,112,49,51,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,83,117,102,97,109,105,32,84,117,114,98,111,32,83,82,65,77,32,112,97,116,104,115,32,119,105,108,108,32,98,101,32,105,110,102,101,114,114,101,100,32,102,114,111,109,32,116,104,101,105,114,32,114,101,115,112,101,99,116,105,118,101,32,112,97,116,104,115,32,116,111,32,97,118,111,105,100,32,99,111,110,102,108,105,99,116,115,46,10,0,0,0,65,32,40,114,105,103,104,116,41,0,0,0,0,0,0,0,71,117,119,97,110,103,101,32,40,74,97,112,97,110,44,32,77,97,115,116,101,114,32,86,101,114,46,32,57,57,47,48,54,47,50,52,41,0,0,0,77,117,103,32,83,109,97,115,104,101,114,115,0,0,0,0,78,70,76,32,39,57,53,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,56,50,50,41,0,0,0,115,112,99,100,114,97,103,0,109,100,95,110,102,108,57,53,112,49,52,0,0,0,0,0,88,111,114,32,87,111,114,108,100,32,40,112,114,111,116,111,116,121,112,101,41,0,0,0,78,70,76,32,39,57,53,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,56,49,55,41,0,0,0,115,114,100,97,114,119,105,110,106,0,0,0,0,0,0,0,115,111,108,100,105,118,105,100,0,0,0,0,0,0,0,0,109,100,95,110,102,108,57,53,112,49,53,0,0,0,0,0,71,97,109,101,32,67,111,110,116,114,111,108,0,0,0,0,66,101,115,116,32,79,102,32,66,101,115,116,0,0,0,0,73,115,103,115,109,77,111,100,101,0,0,0,0,0,0,0,78,70,76,32,39,57,53,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,56,49,55,45,66,41,0,0,0,0,0,0,0,0,0,52,48,107,0,0,0,0,0,109,105,115,99,95,105,111,95,100,97,116,97,0,0,0,0,109,100,95,110,102,108,57,53,112,49,54,0,0,0,0,0,84,97,111,32,84,97,105,100,111,32,40,115,101,116,32,49,41,0,0,0,0,0,0,0,78,70,76,32,39,57,53,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,56,49,50,44,32,65,108,116,41,0,0,0,0,0,0,112,117,110,105,115,104,101,114,117,0,0,0,0,0,0,0,100,100,112,100,111,106,97,0,112,99,101,95,103,101,110,112,101,109,97,107,0,0,0,0,107,111,102,57,56,107,97,0,109,118,115,99,114,49,0,0,109,100,95,110,102,108,57,53,112,49,55,0,0,0,0,0,65,99,116,105,118,101,32,69,110,116,101,114,112,114,105,115,101,115,0,0,0,0,0,0,77,117,108,116,105,32,53,32,47,32,78,101,119,32,77,117,108,116,105,32,71,97,109,101,32,53,0,0,0,0,0,0,115,117,112,101,114,115,112,121,0,0,0,0,0,0,0,0,80,49,32,65,116,116,97,99,107,0,0,0,0,0,0,0,78,70,76,32,39,57,53,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,56,49,50,41,0,0,0,80,97,115,115,0,0,0,0,37,48,56,120,58,32,32,82,101,103,105,115,116,101,114,87,114,105,116,101,98,97,99,107,73,110,99,114,101,109,101,110,116,32,37,100,32,37,100,32,37,100,10,0,0,0,0,0,83,99,104,109,101,105,115,101,114,32,82,111,98,111,32,40,74,97,112,97,110,41,0,0,109,100,95,110,102,108,57,53,112,49,56,0,0,0,0,0,82,45,62,99,111,117,110,116,101,114,0,0,0,0,0,0,104,117,110,99,104,111,108,121,0,0,0,0,0,0,0,0,49,32,99,111,105,110,32,51,32,112,108,97,121,0,0,0,83,112,101,99,105,97,108,0,65,113,117,97,114,105,117,109,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,70,105,120,69,105,103,104,116,32,40,85,83,65,44,32,84,97,105,116,111,32,108,105,99,101,110,115,101,41,0,0,0,78,70,76,32,39,57,53,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,56,49,48,41,0,0,0,97,108,99,111,110,0,0,0,49,32,67,111,105,110,32,32,52,32,67,114,101,100,105,116,115,0,0,0,0,0,0,0,98,111,111,116,108,101,103,32,40,83,97,109,121,114,97,32,69,110,103,105,110,101,101,114,105,110,103,41,0,0,0,0,109,100,95,110,102,108,57,53,112,49,57,0,0,0,0,0,85,83,65,32,40,70,97,98,116,101,107,32,108,105,99,101,110,115,101,41,0,0,0,0,80,111,119,101,114,32,73,110,115,116,105,110,99,116,32,50,32,40,85,83,65,44,32,118,101,114,46,32,57,52,47,48,52,47,48,56,41,0,0,0,66,117,114,103,108,97,114,32,88,0,0,0,0,0,0,0,78,70,76,32,39,57,53,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,56,48,53,41,0,0,0,52,32,99,111,105,110,32,49,32,112,108,97,121,0,0,0,83,104,97,100,111,119,32,70,111,114,99,101,32,40,85,83,32,86,101,114,115,105,111,110,32,50,41,0,0,0,0,0,116,103,109,50,112,0,0,0,109,100,95,110,102,108,57,53,112,50,48,0,0,0,0,0,51,48,107,0,0,0,0,0,104,105,112,112,111,100,114,109,0,0,0,0,0,0,0,0,83,104,111,119,32,67,111,114,114,101,99,116,32,65,110,115,119,101,114,0,0,0,0,0,100,111,110,100,111,107,111,100,0,0,0,0,0,0,0,0,76,111,103,105,99,32,80,114,111,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,73,115,103,115,109,65,100,100,114,0,0,0,0,0,0,0,78,70,76,32,39,57,53,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,56,48,49,41,0,0,0,68,114,46,32,84,111,112,112,101,108,39,115,32,65,100,118,101,110,116,117,114,101,32,40,87,111,114,108,100,41,0,0,97,114,107,49,98,97,108,108,0,0,0,0,0,0,0,0,118,112,99,95,112,114,105,111,114,105,116,121,0,0,0,0,109,100,95,110,102,108,57,53,112,50,49,0,0,0,0,0,114,97,109,98,111,51,112,0,65,115,117,114,97,32,66,108,97,100,101,32,45,32,83,119,111,114,100,32,111,102,32,68,121,110,97,115,116,121,32,40,74,97,112,97,110,41,0,0,80,108,97,121,101,114,32,50,32,83,107,105,108,108,0,0,67,104,97,115,101,32,72,46,81,46,32,40,74,97,112,97,110,41,0,0,0,0,0,0,78,70,76,32,39,57,53,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,65,115,117,107,97,32,38,32,65,115,117,107,97,32,40,87,111,114,108,100,41,0,0,0,84,104,101,32,80,117,110,105,115,104,101,114,32,40,57,51,48,52,50,50,32,101,116,99,41,0,0,0,0,0,0,0,67,97,118,101,32,47,32,65,77,73,0,0,0,0,0,0,74,97,99,107,105,101,32,67,104,97,110,32,45,32,84,104,101,32,75,117,110,103,45,70,117,32,77,97,115,116,101,114,0,0,0,0,0,0,0,0,71,101,110,112,101,105,32,84,111,117,109,97,100,101,110,0,0,0,0,0,0,0,0,0,84,104,101,32,75,105,110,103,32,111,102,32,70,105,103,104,116,101,114,115,32,39,57,56,32,45,32,84,104,101,32,83,108,117,103,102,101,115,116,32,47,32,75,105,110,103,32,111,102,32,70,105,103,104,116,101,114,115,32,39,57,56,32,45,32,100,114,101,97,109,32,109,97,116,99,104,32,110,101,118,101,114,32,101,110,100,115,32,40,75,111,114,101,97,110,32,98,111,97,114,100,41,0,0,77,97,114,118,101,108,32,118,115,32,67,97,112,99,111,109,32,45,32,99,108,97,115,104,32,111,102,32,115,117,112,101,114,32,104,101,114,111,101,115,32,40,57,56,48,49,50,51,32,69,117,114,111,41,0,0,116,119,105,110,104,97,119,107,117,0,0,0,0,0,0,0,109,100,95,110,102,108,57,53,0,0,0,0,0,0,0,0,65,99,116,105,111,110,32,53,50,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,116,111,117,116,114,117,110,0,48,49,48,49,48,48,0,0,66,108,111,109,98,121,32,67,97,114,0,0,0,0,0,0,78,101,119,32,51,68,32,71,111,108,102,32,83,105,109,117,108,97,116,105,111,110,32,45,32,87,97,105,97,108,97,101,32,110,111,32,75,105,115,101,107,105,32,40,74,112,110,41,0,0,0,0,0,0,0,0,115,102,105,105,105,51,114,49,0,0,0,0,0,0,0,0,97,108,116,98,101,97,115,116,52,0,0,0,0,0,0,0,100,105,118,105,100,101,0,0,109,100,95,110,51,100,103,119,97,105,97,0,0,0,0,0,46,112,115,114,109,0,0,0,68,114,97,103,111,110,32,77,97,115,116,101,114,0,0,0,102,108,105,99,107,121,115,50,0,0,0,0,0,0,0,0,100,100,99,114,101,119,106,0,84,32,38,32,69,32,83,111,102,116,0,0,0,0,0,0,82,97,105,108,32,67,104,97,115,101,32,40,87,111,114,108,100,41,0,0,0,0,0,0,76,105,110,101,32,111,102,32,70,105,114,101,32,47,32,66,97,107,117,100,97,110,32,89,97,114,111,117,32,40,74,97,112,97,110,44,32,70,68,49,48,57,52,32,51,49,55,45,48,49,51,52,41,0,0,0,83,116,97,114,32,70,105,103,104,116,101,114,32,40,77,111,111,110,32,67,114,101,115,116,97,32,98,111,111,116,108,101,103,41,0,0,0,0,0,0,68,0,0,0,117,0,0,0,109,0,0,0,112,0,0,0,32,0,0,0,77,0,0,0,97,0,0,0,116,0,0,0,115,0,0,0,117,0,0,0,109,0,0,0,111,0,0,0,116,0,0,0,111,0,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,44,0,0,0,32,0,0,0,56,0,0,0,55,0,0,0,53,0,0,0,49,0,0,0,32,0,0,0,51,0,0,0,49,0,0,0,55,0,0,0,45,0,0,0,117,0,0,0,110,0,0,0,107,0,0,0,110,0,0,0,111,0,0,0,119,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,192,48,0,0,243,48,0,0,215,48,0,0,126,103,0,0,44,103,0,0,0,0,0,0,0,0,0,0,78,101,119,32,51,68,32,71,111,108,102,32,83,105,109,117,108,97,116,105,111,110,32,45,32,72,97,114,117,107,97,110,97,114,117,32,65,117,103,117,115,116,97,32,40,74,112,110,41,0,0,0,0,0,0,0,83,112,97,99,101,32,72,97,114,114,105,101,114,32,40,82,101,118,32,65,44,32,56,55,53,49,32,51,49,53,45,53,49,54,51,65,41,0,0,0,118,105,100,101,111,95,116,104,114,101,97,100,101,100,0,0,103,116,109,114,101,0,0,0,109,100,95,110,51,100,103,97,117,103,117,0,0,0,0,0,116,103,109,50,0,0,0,0,78,101,119,32,51,68,32,71,111,108,102,32,83,105,109,117,108,97,116,105,111,110,32,45,32,68,101,118,105,108,39,115,32,67,111,117,114,115,101,32,40,74,112,110,41,0,0,0,49,32,67,111,105,110,32,32,52,32,67,114,101,100,105,116,115,32,0,0,0,0,0,0,74,111,105,110,116,0,0,0,101,118,101,114,121,32,50,53,48,107,0,0,0,0,0,0,50,43,50,0,0,0,0,0,84,97,115,107,32,70,111,114,99,101,32,72,97,114,114,105,101,114,0,0,0,0,0,0,73,115,103,115,109,84,121,112,101,0,0,0,0,0,0,0,109,100,95,110,51,100,103,100,101,118,105,0,0,0,0,0,50,48,107,0,0,0,0,0,66,97,110,112,114,101,115,116,111,0,0,0,0,0,0,0,115,117,98,50,109,97,105,110,0,0,0,0,0,0,0,0,78,101,107,107,101,116,115,117,32,75,111,117,107,111,117,32,68,111,100,103,101,98,97,108,108,32,66,117,32,45,32,83,111,99,99,101,114,32,72,101,110,32,77,68,32,40,74,112,110,41,0,0,0,0,0,0,82,97,105,100,101,110,32,40,115,101,116,32,49,41,0,0,86,101,114,121,32,83,116,114,111,110,103,0,0,0,0,0,78,101,119,115,68,105,112,0,82,97,105,103,97,32,45,32,83,116,114,97,116,111,32,70,105,103,104,116,101,114,32,40,85,83,41,0,0,0,0,0,109,100,95,110,101,107,115,111,99,99,114,0,0,0,0,0,87,111,114,108,100,32,67,117,112,0,0,0,0,0,0,0,68,114,118,66,103,48,83,99,114,111,108,108,89,0,0,0,112,117,110,105,115,104,101,114,0,0,0,0,0,0,0,0,68,111,68,111,110,80,97,99,104,105,32,68,97,105,45,79,117,45,74,111,117,32,40,86,49,48,49,44,32,74,97,112,97,110,41,0,0,0,0,0,112,99,101,95,103,101,110,112,101,105,0,0,0,0,0,0,107,111,102,57,56,107,0,0,71,97,105,97,32,67,114,117,115,97,100,101,114,115,0,0,78,67,65,65,32,70,111,111,116,98,97,108,108,32,40,85,83,65,41,0,0,0,0,0,102,114,101,113,32,108,97,116,99,104,0,0,0,0,0,0,115,97,105,108,111,114,109,110,111,117,0,0,0,0,0,0,84,101,120,116,32,82,65,77,0,0,0,0,0,0,0,0,109,100,95,97,99,116,105,111,110,53,50,0,0,0,0,0,50,48,48,48,48,32,53,48,48,48,48,32,57,48,48,48,48,0,0,0,0,0,0,0,109,100,95,110,99,97,97,102,111,111,116,0,0,0,0,0,65,116,116,101,109,112,116,32,116,111,32,114,101,97,100,32,119,111,114,100,32,118,97,108,117,101,32,111,102,32,108,111,99,97,116,105,111,110,32,37,120,10,0,0,0,0,0,0,86,101,114,121,32,72,97,114,100,32,53,0,0,0,0,0,78,67,65,65,32,70,105,110,97,108,32,70,111,117,114,32,66,97,115,107,101,116,98,97,108,108,32,40,85,83,65,41,0,0,0,0,0,0,0,0,71,117,97,114,100,105,97,110,115,0,68,101,110,106,105,110,32,77,97,107,97,105,32,73,73,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,68,111,101,115,32,110,111,116,32,104,97,118,101,32,101,110,111,117,103,104,32,115,97,109,112,108,101,115,32,102,111,114,32,109,111,110,105,116,111,114,32,114,101,102,114,101,115,104,32,114,97,116,101,32,101,115,116,105,109,97,116,105,111,110,46,32,82,101,113,117,105,114,101,115,32,116,111,32,114,117,110,32,102,111,114,32,97,116,32,108,101,97,115,116,32,37,117,32,102,114,97,109,101,115,46,10,0,0,0,65,116,104,101,110,97,32,47,32,84,101,99,109,111,0,0,109,100,95,110,99,97,97,98,97,115,107,0,0,0,0,0,90,101,114,111,32,90,111,110,101,0,0,0,0,0,0,0,115,116,97,114,102,103,109,99,0,0,0,0,0,0,0,0,116,119,105,110,107,108,101,0,78,66,65,32,83,104,111,119,100,111,119,110,32,39,57,52,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,72,97,99,107,101,100,41,0,0,0,0,0,0,0,83,116,114,105,107,101,114,115,32,49,57,52,53,0,0,0,65,105,114,32,66,117,115,116,101,114,58,32,84,114,111,117,98,108,101,32,83,112,101,99,105,97,108,116,121,32,82,97,105,100,32,85,110,105,116,32,40,87,111,114,108,100,41,0,0,0,0,0,0,0,0,0,109,100,95,110,98,97,115,104,111,119,112,0,0,0,0,0,77,97,104,106,111,110,103,0,0,0,0,0,0,0,0,0,68,45,67,111,110,0,0,0,78,105,99,104,105,98,117,116,115,117,32,85,83,65,0,0,109,106,103,116,97,115,116,101,0,0,0,0,0,0,0,0,78,66,65,32,83,104,111,119,100,111,119,110,32,39,57,52,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,98,98,114,111,115,0,0,0,49,67,32,49,67,32,47,32,49,67,32,51,67,0,0,0,50,48,32,115,101,99,111,110,100,115,0,0,0,0,0,0,101,118,101,114,121,32,50,48,48,107,0,0,0,0,0,0,56,48,48,48,48,0,0,0,74,0,0,0,0,0,0,0,73,115,103,115,109,67,97,114,116,65,100,100,114,0,0,0,109,100,95,110,98,97,115,104,111,119,0,0,0,0,0,0,49,48,107,0,0,0,0,0,77,97,103,105,99,32,66,117,98,98,108,101,0,0,0,0,76,105,102,101,32,68,101,99,114,101,97,115,101,32,83,112,101,101,100,0,0,0,0,0,104,97,110,103,108,121,50,0,71,97,117,110,116,108,101,116,32,40,114,101,118,32,52,41,0,0,0,0,0,0,0,0,78,66,65,32,80,114,111,32,66,97,115,107,101,116,98,97,108,108,32,39,57,52,32,40,74,112,110,41,0,0,0,0,49,67,0,0,0,0,0,0,76,101,116,104,97,108,32,67,114,97,115,104,32,82,97,99,101,32,40,115,101,116,32,49,41,0,0,0,0,0,0,0,109,100,95,110,98,97,112,114,111,57,52,0,0,0,0,0,100,107,111,110,103,120,0,0,70,101,118,101,114,32,83,79,83,32,40,73,110,116,101,114,110,97,116,105,111,110,97,108,44,32,118,101,114,46,32,57,56,47,48,57,47,50,53,41,0,0,0,0,0,0,0,0,67,111,109,112,105,108,101,32,40,67,97,112,99,111,109,32,108,105,99,101,110,115,101,41,0,0,0,0,0,0,0,0,100,100,112,100,111,106,0,0,78,101,119,115,32,40,115,101,116,32,49,41,0,0,0,0,71,101,110,106,105,32,84,115,117,117,115,104,105,110,32,65,103,101,100,97,109,97,0,0,84,104,101,32,75,105,110,103,32,111,102,32,70,105,103,104,116,101,114,115,32,39,57,56,32,45,32,84,104,101,32,83,108,117,103,102,101,115,116,32,47,32,75,105,110,103,32,111,102,32,70,105,103,104,116,101,114,115,32,39,57,56,32,45,32,100,114,101,97,109,32,109,97,116,99,104,32,110,101,118,101,114,32,101,110,100,115,32,40,78,71,77,45,50,52,50,48,41,0,0,0,0,0,0,109,118,115,99,0,0,0,0,78,66,65,32,80,114,111,32,66,97,115,107,101,116,98,97,108,108,32,45,32,66,117,108,108,115,32,86,115,32,76,97,107,101,114,115,32,40,74,112,110,41,0,0,0,0,0,0,68,114,118,83,99,114,111,108,108,50,91,48,93,0,0,0,65,65,65,72,72,33,33,33,32,82,101,97,108,32,77,111,110,115,116,101,114,115,32,40,85,83,65,41,0,0,0,0,116,114,111,106,97,110,106,0,49,53,48,48,48,32,51,53,48,48,48,32,54,48,48,48,48,0,0,0,0,0,0,0,78,111,110,118,111,108,97,116,105,108,101,32,82,65,77,0,109,100,95,98,117,108,108,118,115,108,97,106,0,0,0,0,68,97,116,97,32,65,109,117,115,101,109,101,110,116,0,0,84,104,101,32,68,101,97,108,101,114,0,0,0,0,0,0,83,104,97,100,111,119,32,87,97,114,114,105,111,114,115,32,40,87,111,114,108,100,44,32,115,101,116,32,49,41,0,0,105,107,97,114,105,51,117,0,68,114,118,66,103,50,83,99,114,111,108,108,88,91,49,93,0,0,0,0,0,0,0,0,78,66,65,32,80,108,97,121,111,102,102,115,32,45,32,66,117,108,108,115,32,86,115,32,66,108,97,122,101,114,115,32,40,74,112,110,44,32,65,108,116,41,0,0,0,0,0,0,9,45,68,47,45,45,100,101,116,97,99,104,58,32,68,101,116,97,99,104,32,82,101,116,114,111,65,114,99,104,32,102,114,111,109,32,116,104,101,32,114,117,110,110,105,110,103,32,99,111,110,115,111,108,101,46,32,78,111,116,32,114,101,108,101,118,97,110,116,32,102,111,114,32,97,108,108,32,112,108,97,116,102,111,114,109,115,46,10,0,0,0,0,0,0,0,103,121,114,111,100,105,110,101,116,0,0,0,0,0,0,0,83,112,101,101,100,32,83,112,105,110,0,0,0,0,0,0,109,100,95,98,117,108,108,118,115,98,108,106,49,0,0,0,77,111,111,110,32,87,97,114,32,40,77,111,111,110,32,67,114,101,115,116,97,32,98,111,111,116,108,101,103,41,0,0,66,80,83,0,0,0,0,0,82,111,117,110,100,32,83,107,105,112,0,0,0,0,0,0,32,53,32,67,111,105,110,115,32,49,32,67,114,101,100,105,116,0,0,0,0,0,0,0,77,97,107,97,105,45,77,117,114,97,32,40,74,97,112,97,110,32,114,101,118,105,115,105,111,110,32,67,41,0,0,0,49,32,67,111,105,110,32,32,49,32,67,114,101,100,105,116,32,32,47,32,49,32,67,111,105,110,32,32,53,32,32,67,114,101,100,105,116,115,0,0,78,66,65,32,80,108,97,121,111,102,102,115,32,45,32,66,117,108,108,115,32,86,115,32,66,108,97,122,101,114,115,32,40,74,112,110,41,0,0,0,87,99,57,48,83,99,114,111,108,108,50,89,72,105,0,0,87,87,70,32,87,114,101,115,116,108,101,70,101,115,116,32,40,85,83,32,115,101,116,32,49,41,0,0,0,0,0,0,71,101,109,105,110,105,32,87,105,110,103,0,0,0,0,0,109,100,95,98,117,108,108,118,115,98,108,106,0,0,0,0,100,100,114,97,103,111,110,50,0,0,0,0,0,0,0,0,97,115,105,99,50,55,97,95,115,105,109,95,118,97,108,117,101,0,0,0,0,0,0,0,103,110,98,97,114,105,99,104,0,0,0,0,0,0,0,0,78,66,65,32,76,105,118,101,32,57,56,32,40,85,83,65,41,0,0,0,0,0,0,0,68,114,97,103,111,110,32,87,111,114,108,100,32,73,73,32,40,86,49,49,48,88,44,32,87,111,114,108,100,41,0,0,49,53,32,115,101,99,111,110,100,115,0,0,0,0,0,0,71,97,108,115,32,80,97,110,105,99,32,40,85,110,112,114,111,116,101,99,116,101,100,41,0,0,0,0,0,0,0,0,101,118,101,114,121,32,49,53,48,107,0,0,0,0,0,0,53,48,48,48,48,0,0,0,109,100,95,110,98,97,108,105,118,57,56,0,0,0,0,0,73,115,103,115,109,67,97,114,116,65,100,100,114,76,97,116,99,104,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,67,111,110,102,105,103,93,58,32,81,117,101,114,121,105,110,103,32,97,112,112,108,105,99,97,116,105,111,110,32,112,97,116,104,58,32,37,115,46,10,0,0,0,0,73,110,102,105,110,105,116,101,0,0,0,0,0,0,0,0,78,66,65,32,76,105,118,101,32,57,55,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,0,0,0,80,117,115,104,109,97,110,32,40,75,111,114,101,97,44,32,115,101,116,32,49,41,0,0,112,99,101,95,97,111,105,98,108,105,110,107,0,0,0,0,71,111,116,45,99,104,97,32,77,105,110,105,32,71,97,109,101,32,70,101,115,116,105,118,97,108,0,0,0,0,0,0,109,100,95,110,98,97,108,105,118,57,55,0,0,0,0,0,80,110,105,99,107,105,101,115,32,40,57,52,48,54,48,56,32,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,112,99,101,95,103,101,110,106,105,116,115,117,0,0,0,0,99,97,112,116,99,111,109,109,0,0,0,0,0,0,0,0,187,158,0,0,192,150,0,0,194,114,0,0,23,82,0,0,29,79,0,0,0,0,0,0,77,0,0,0,97,0,0,0,104,0,0,0,106,0,0,0,111,0,0,0,110,0,0,0,103,0,0,0,32,0,0,0,75,0,0,0,121,0,0,0,111,0,0,0,32,0,0,0,82,0,0,0,101,0,0,0,116,0,0,0,115,0,0,0,117,0,0,0,100,0,0,0,101,0,0,0,110,0,0,0,32,0,0,0,40,0,0,0,78,0,0,0,71,0,0,0,77,0,0,0,45,0,0,0,48,0,0,0,48,0,0,0,52,0,0,0,41,0,0,0,40,0,0,0,78,0,0,0,71,0,0,0,72,0,0,0,45,0,0,0,48,0,0,0,48,0,0,0,52,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,78,66,65,32,76,105,118,101,32,57,54,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,0,0,0,110,73,82,81,79,102,102,115,101,116,0,0,0,0,0,0,77,97,114,118,101,108,32,83,117,112,101,114,32,72,101,114,111,101,115,32,118,115,32,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,40,57,55,48,54,50,53,32,85,83,65,41,0,0,0,0,0,0,109,100,95,97,97,97,104,104,114,109,117,0,0,0,0,0,66,105,103,32,75,97,114,110,97,107,0,0,0,0,0,0,109,100,95,110,98,97,108,105,118,57,54,0,0,0,0,0,102,115,116,97,114,102,114,99,0,0,0,0,0,0,0,0,78,66,65,32,76,105,118,101,32,57,53,32,40,75,111,114,41,0,0,0,0,0,0,0,9,45,88,47,45,45,120,109,108,58,32,83,112,101,99,105,102,105,101,115,32,112,97,116,104,32,116,111,32,88,77,76,32,109,101,109,111,114,121,32,109,97,112,46,0,0,0,0,79,80,76,45,62,108,102,111,95,97,109,95,100,101,112,116,104,0,0,0,0,0,0,0,103,108,71,101,116,79,98,106,101,99,116,76,97,98,101,108,0,0,0,0,0,0,0,0,71,97,108,115,32,80,105,110,98,97,108,108,0,0,0,0,109,100,95,110,98,97,108,105,118,57,53,107,0,0,0,0,80,97,115,115,37,117,0,0,68,101,114,111,111,110,32,68,101,114,111,68,101,114,111,0,0,0,0,0,0,0,0,0,78,66,65,32,76,105,118,101,32,57,53,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,71,76,93,58,32,86,101,110,100,111,114,58,32,37,115,44,32,82,101,110,100,101,114,101,114,58,32,37,115,46,10,0,0,0,0,0,71,65,77,69,32,37,115,0,109,100,95,110,98,97,108,105,118,57,53,0,0,0,0,0,87,101,108,108,116,114,105,115,32,45,32,65,108,101,120,101,121,32,80,97,106,105,116,110,111,118,39,115,32,40,87,111,114,108,100,63,44,32,50,32,112,108,97,121,101,114,115,41,0,0,0,0,0,0,0,0,35,37,100,0,0,0,0,0,80,71,65,32,84,111,117,114,32,71,111,108,102,32,73,73,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,100,114,97,103,110,98,108,122,0,0,0,0,0,0,0,0,78,66,65,32,74,97,109,32,84,111,117,114,110,97,109,101,110,116,32,69,100,105,116,105,111,110,32,40,87,111,114,108,100,44,32,50,48,48,50,32,70,105,120,32,82,101,108,101,97,115,101,41,0,0,0,0,49,57,52,53,107,32,73,73,73,0,0,0,0,0,0,0,49,48,32,115,101,99,111,110,100,115,0,0,0,0,0,0,101,118,101,114,121,32,49,48,48,107,0,0,0,0,0,0,51,48,48,48,48,0,0,0,80,114,101,116,116,121,32,83,111,108,100,105,101,114,32,83,97,105,108,111,114,32,77,111,111,110,32,40,118,101,114,46,32,57,53,47,48,51,47,50,50,66,44,32,69,117,114,111,112,101,41,0,0,0,0,0,71,97,109,101,82,79,77,0,50,48,48,50,63,0,0,0,67,111,105,110,32,67,104,117,116,101,115,0,0,0,0,0,77,97,103,105,99,97,108,32,67,97,116,32,65,100,118,101,110,116,117,114,101,0,0,0,109,100,95,110,98,97,106,97,109,116,101,102,0,0,0,0,80,108,97,121,101,114,32,49,32,83,107,105,108,108,0,0,105,109,112,111,114,116,0,0,103,114,97,100,105,117,115,50,98,0,0,0,0,0,0,0,78,66,65,32,74,97,109,32,84,111,117,114,110,97,109,101,110,116,32,69,100,105,116,105,111,110,32,40,87,111,114,108,100,41,0,0,0,0,0,0,97,114,109,119,97,114,114,49,0,0,0,0,0,0,0,0,80,111,119,101,114,32,73,110,115,116,105,110,99,116,32,40,85,83,65,41,0,0,0,0,73,114,101,109,0,0,0,0,77,101,116,97,108,32,83,108,117,103,32,50,32,45,32,83,117,112,101,114,32,86,101,104,105,99,108,101,45,48,48,49,47,73,73,32,40,78,71,77,45,50,52,49,48,41,32,40,78,71,72,45,50,52,49,48,41,0,0,0,0,0,0,0,111,118,101,114,108,97,121,37,117,95,100,101,115,99,37,117,95,110,111,114,109,97,108,105,122,101,100,0,0,0,0,0,109,100,95,110,98,97,106,97,109,116,101,0,0,0,0,0,69,103,103,32,72,117,110,116,0,0,0,0,0,0,0,0,109,115,104,118,115,102,117,49,0,0,0,0,0,0,0,0,86,105,97,99,111,109,32,78,101,119,32,77,101,100,105,97,0,0,0,0,0,0,0,0,80,50,32,80,117,115,104,0,108,100,114,117,110,50,0,0,78,66,65,32,74,97,109,32,40,74,112,110,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,0,0,66,117,99,99,97,110,101,101,114,115,32,40,115,101,116,32,50,41,0,0,0,0,0,0,84,111,111,32,70,97,115,116,0,0,0,0,0,0,0,0,82,45,84,121,112,101,32,76,101,111,32,40,87,111,114,108,100,41,0,0,0,0,0,0,68,114,97,103,111,110,32,66,114,101,101,100,32,40,77,55,50,32,80,67,66,32,118,101,114,115,105,111,110,41,0,0,109,100,95,110,98,97,106,97,109,106,112,0,0,0,0,0,9,45,45,110,111,45,112,97,116,99,104,58,32,68,105,115,97,98,108,101,115,32,97,108,108,32,102,111,114,109,115,32,111,102,32,114,111,109,32,112,97,116,99,104,105,110,103,46,0,0,0,0,0,0,0,0,76,111,114,100,32,111,102,32,71,117,110,32,40,85,83,65,41,0,0,0,0,0,0,0,65,99,99,108,97,105,109,32,74,97,112,97,110,0,0,0,109,111,111,110,99,109,119,0,78,66,65,32,74,97,109,32,40,74,112,110,41,0,0,0,65,101,114,111,32,70,105,103,104,116,101,114,115,0,0,0,109,100,95,110,98,97,106,97,109,106,0,0,0,0,0,0,68,114,46,32,84,111,109,121,0,0,0,0,0,0,0,0,115,49,57,52,53,105,105,105,0,0,0,0,0,0,0,0,78,66,65,32,74,97,109,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,53,32,115,101,99,111,110,100,115,0,0,0,0,0,0,0,80,105,114,97,116,101,115,0,0,0,0,0,0,0,0,0,90,56,48,82,79,77,0,0,109,100,95,110,98,97,106,97,109,49,0,0,0,0,0,0,75,111,114,111,32,75,111,114,111,32,81,117,101,115,116,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,86,97,114,105,97,32,77,101,116,97,108,0,0,0,0,0,78,66,65,32,74,97,109,32,40,69,117,114,111,44,32,85,83,65,44,32,118,49,46,49,41,0,0,0,0,0,0,0,109,100,95,110,98,97,106,97,109,0,0,0,0,0,0,0,66,105,103,32,84,119,105,110,0,0,0,0,0,0,0,0,112,110,105,99,107,106,0,0,71,101,107,105,115,104,97,32,66,111,121,0,0,0,0,0,78,66,65,32,72,97,110,103,32,84,105,109,101,32,40,85,83,65,41,0,0,0,0,0,77,97,114,118,101,108,32,83,117,112,101,114,32,72,101,114,111,101,115,32,118,115,32,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,40,57,55,48,56,50,55,32,85,83,65,41,0,0,0,0,0,0,65,65,65,72,72,33,33,33,32,82,101,97,108,32,77,111,110,115,116,101,114,115,32,40,69,117,114,111,41,0,0,0,109,100,95,110,98,97,104,97,110,103,117,0,0,0,0,0,68,111,117,98,108,101,32,68,114,97,103,111,110,32,51,32,45,32,84,104,101,32,82,111,115,101,116,116,97,32,83,116,111,110,101,32,40,85,83,41,0,0,0,0,0,0,0,0,78,66,65,32,72,97,110,103,32,84,105,109,101,32,40,69,117,114,111,41,0,0,0,0,9,45,45,105,112,115,58,32,83,112,101,99,105,102,105,101,115,32,112,97,116,104,32,102,111,114,32,73,80,83,32,112,97,116,99,104,32,116,104,97,116,32,119,105,108,108,32,98,101,32,97,112,112,108,105,101,100,32,116,111,32,82,79,77,46,0,0,0,0,0,0,0,65,112,112,101,110,100,101,100,32,100,105,115,107,58,32,37,115,0,0,0,0,0,0,0,84,104,101,32,76,101,103,101,110,100,32,111,102,32,83,105,108,107,114,111,97,100,0,0,109,100,95,110,98,97,104,97,110,103,0,0,0,0,0,0,78,105,99,104,105,98,117,116,115,117,32,40,84,97,105,116,111,32,100,111,32,66,114,97,115,105,108,32,108,105,99,101,110,115,101,41,0,0,0,0,71,97,108,66,97,99,107,103,114,111,117,110,100,82,101,100,0,0,0,0,0,0,0,0,78,66,65,32,65,108,108,45,83,116,97,114,32,67,104,97,108,108,101,110,103,101,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,109,100,95,110,98,97,97,108,108,115,116,0,0,0,0,0,115,49,57,52,53,105,105,0,78,66,65,32,65,99,116,105,111,110,32,39,57,53,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,49,49,50,51,45,65,41,0,0,84,105,109,101,0,0,0,0,67,114,111,115,115,104,97,105,114,32,89,0,0,0,0,0,84,105,108,101,82,79,77,0,109,100,95,110,98,97,97,99,116,57,53,112,50,52,0,0,50,67,32,54,79,67,32,56,77,32,47,32,52,67,32,49,56,79,67,32,49,54,77,0,67,111,109,32,112,117,116,0,78,66,65,32,65,99,116,105,111,110,32,39,57,53,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,49,49,49,56,41,0,0,0,0,109,100,95,110,98,97,97,99,116,57,53,112,50,53,0,0,80,97,110,103,33,32,51,58,32,75,97,105,116,111,117,32,84,97,99,104,105,32,110,111,32,75,97,114,101,105,32,110,97,32,71,111,103,111,32,40,57,53,48,53,49,49,32,74,97,112,97,110,41,0,0,0,112,99,101,95,103,101,107,105,115,98,111,121,0,0,0,0,82,101,97,108,32,66,111,117,116,32,70,97,116,97,108,32,70,117,114,121,32,50,32,45,32,84,104,101,32,78,101,119,99,111,109,101,114,115,32,40,75,111,114,101,97,110,32,114,101,108,101,97,115,101,41,0,0,0,0,0,0,0,0,0,78,66,65,32,65,99,116,105,111,110,32,39,57,53,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,49,51,48,41,0,0,0,0,109,115,104,118,115,102,117,0,109,100,95,97,97,97,104,104,114,109,0,0,0,0,0,0,109,100,95,110,98,97,97,99,116,57,53,112,48,52,0,0,78,66,65,32,65,99,116,105,111,110,32,39,57,53,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,49,50,56,41,0,0,0,0,9,45,45,98,112,115,58,32,83,112,101,99,105,102,105,101,115,32,112,97,116,104,32,102,111,114,32,66,80,83,32,112,97,116,99,104,32,116,104,97,116,32,119,105,108,108,32,98,101,32,97,112,112,108,105,101,100,32,116,111,32,82,79,77,46,0,0,0,0,0,0,0,66,108,111,111,100,32,66,114,111,115,46,32,40,115,101,116,32,49,41,0,0,0,0,0,109,100,95,110,98,97,97,99,116,57,53,112,48,53,0,0,115,108,45,62,114,114,0,0,68,111,110,80,97,99,104,105,32,40,85,83,65,44,32,118,101,114,46,32,49,46,49,50,44,32,57,53,47,48,53,47,50,120,41,0,0,0,0,0,83,117,112,101,114,32,83,116,97,114,32,67,114,101,115,116,0,0,0,0,0,0,0,0,70,45,49,32,71,114,97,110,100,32,80,114,105,120,0,0,78,66,65,32,65,99,116,105,111,110,32,39,57,53,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,49,50,56,45,65,41,0,0,79,104,32,77,121,32,71,111,100,33,0,0,0,0,0,0,109,100,95,110,98,97,97,99,116,57,53,112,48,54,0,0,103,117,110,98,105,114,100,50,0,0,0,0,0,0,0,0,78,66,65,32,65,99,116,105,111,110,32,39,57,53,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,49,50,55,45,66,41,0,0,78,111,116,32,65,108,108,111,119,101,100,0,0,0,0,0,57,0,0,0,0,0,0,0,67,114,111,115,115,104,97,105,114,32,88,0,0,0,0,0,83,112,114,105,116,101,82,79,77,0,0,0,0,0,0,0,109,100,95,110,98,97,97,99,116,57,53,112,48,55,0,0,50,32,67,114,101,100,105,116,115,32,49,50,32,79,117,116,99,111,117,110,116,115,32,49,52,32,77,105,110,0,0,0,83,101,108,101,99,116,32,103,105,114,108,0,0,0,0,0,72,121,112,101,114,32,80,97,99,109,97,110,0,0,0,0,78,66,65,32,65,99,116,105,111,110,32,39,57,53,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,49,50,55,45,65,41,0,0,103,97,108,97,112,120,0,0,109,100,95,110,98,97,97,99,116,57,53,112,48,56,0,0,112,97,110,103,51,106,0,0,50,48,48,53,0,0,0,0,71,97,110,98,97,114,101,33,32,71,111,108,102,32,66,111,121,115,0,0,0,0,0,0,114,98,102,102,50,107,0,0,78,66,65,32,65,99,116,105,111,110,32,39,57,53,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,49,50,52,45,66,41,0,0,77,97,114,118,101,108,32,83,117,112,101,114,32,72,101,114,111,101,115,32,118,115,32,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,40,57,55,48,54,50,53,32,74,97,112,97,110,41,0,0,0,0,65,97,32,72,97,114,105,109,97,110,97,100,97,32,40,74,112,110,41,0,0,0,0,0,100,101,97,116,104,98,114,100,0,0,0,0,0,0,0,0,109,100,95,110,98,97,97,99,116,57,53,112,48,57,0,0,76,105,118,101,32,81,117,105,122,32,83,104,111,119,0,0,78,66,65,32,65,99,116,105,111,110,32,39,57,53,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,49,50,50,45,66,41,0,0])
.concat([9,45,85,47,45,45,117,112,115,58,32,83,112,101,99,105,102,105,101,115,32,112,97,116,104,32,102,111,114,32,85,80,83,32,112,97,116,99,104,32,116,104,97,116,32,119,105,108,108,32,98,101,32,97,112,112,108,105,101,100,32,116,111,32,82,79,77,46,0,0,0,0,79,115,109,97,110,32,40,87,111,114,108,100,41,0,0,0,67,114,111,115,115,32,80,97,110,103,0,0,0,0,0,0,109,100,95,110,98,97,97,99,116,57,53,112,49,48,0,0,115,115,116,97,114,99,114,115,0,0,0,0,0,0,0,0,68,111,68,111,110,80,97,99,104,105,32,40,73,110,116,101,114,110,97,116,105,111,110,97,108,44,32,109,97,115,116,101,114,32,118,101,114,46,32,57,55,47,48,50,47,48,53,41,0,0,0,0,0,0,0,0,112,99,101,95,49,57,52,51,107,97,105,0,0,0,0,0,78,66,65,32,65,99,116,105,111,110,32,39,57,53,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,49,50,49,41,0,0,0,0,109,100,95,110,98,97,97,99,116,57,53,112,49,49,0,0,68,73,80,32,115,119,105,116,99,104,32,111,112,116,105,111,110,58,32,37,115,46,10,0,78,66,65,32,65,99,116,105,111,110,32,39,57,53,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,49,49,53,45,65,41,0,0,83,97,109,117,114,97,105,32,65,99,101,115,32,40,87,111,114,108,100,41,0,0,0,0,65,108,116,101,114,110,97,116,101,44,32,68,117,97,108,0,57,57,0,0,0,0,0,0,70,97,115,116,101,115,116,0,70,90,45,50,48,48,54,32,71,97,109,101,32,73,73,0,109,100,95,110,98,97,97,99,116,57,53,112,49,50,0,0,50,32,67,114,101,100,105,116,115,32,32,54,32,79,117,116,99,111,117,110,116,115,32,56,32,77,105,110,0,0,0,0,83,111,108,32,68,105,118,105,100,101,32,45,32,84,104,101,32,83,119,111,114,100,32,79,102,32,68,97,114,107,110,101,115,115,0,0,0,0,0,0,78,66,65,32,65,99,116,105,111,110,32,39,57,53,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,49,49,50,41,0,0,0,0,82,111,121,97,108,32,77,97,104,106,111,110,103,0,0,0,109,100,95,110,98,97,97,99,116,57,53,112,49,51,0,0,80,97,110,103,33,32,51,32,40,98,111,111,116,108,101,103,32,115,101,116,32,51,44,32,57,53,48,54,48,49,32,69,117,114,111,41,0,0,0,0,84,97,105,115,101,110,32,72,111,116,32,71,105,109,109,105,99,107,32,40,74,97,112,97,110,41,0,0,0,0,0,0,112,99,101,95,103,97,110,98,103,111,108,102,0,0,0,0,82,0,0,0,101,0,0,0,97,0,0,0,108,0,0,0,32,0,0,0,66,0,0,0,111,0,0,0,117,0,0,0,116,0,0,0,32,0,0,0,70,0,0,0,97,0,0,0,116,0,0,0,97,0,0,0,108,0,0,0,32,0,0,0,70,0,0,0,117,0,0,0,114,0,0,0,121,0,0,0,32,0,0,0,50,0,0,0,32,0,0,0,45,0,0,0,32,0,0,0,84,0,0,0,104,0,0,0,101,0,0,0,32,0,0,0,78,0,0,0,101,0,0,0,119,0,0,0,99,0,0,0,111,0,0,0,109,0,0,0,101,0,0,0,114,0,0,0,115,0,0,0,0,0,0,0,82,0,0,0,101,0,0,0,97,0,0,0,108,0,0,0,32,0,0,0,66,0,0,0,111,0,0,0,117,0,0,0,116,0,0,0,32,0,0,0,19,153,0,0,252,114,0,0,29,79,0,0,172,138,0,0,18,255,0,0,32,0,0,0,40,0,0,0,78,0,0,0,71,0,0,0,72,0,0,0,45,0,0,0,50,0,0,0,52,0,0,0,48,0,0,0,48,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,78,66,65,32,65,99,116,105,111,110,32,39,57,53,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,49,48,56,41,0,0,0,0,109,115,104,118,115,102,106,50,0,0,0,0,0,0,0,0,109,100,95,97,97,104,97,114,105,109,97,0,0,0,0,0,70,117,110,107,121,32,66,101,101,0,0,0,0,0,0,0,109,100,95,110,98,97,97,99,116,57,53,112,49,52,0,0,77,111,108,101,32,65,116,116,97,99,107,0,0,0,0,0,78,66,65,32,65,99,116,105,111,110,32,39,57,53,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,49,48,51,41,0,0,0,0,9,45,118,47,45,45,118,101,114,98,111,115,101,58,32,86,101,114,98,111,115,101,32,108,111,103,103,105,110,103,46,0,68,45,80,97,100,32,82,105,103,104,116,0,0,0,0,0,80,105,114,97,116,101,32,83,104,105,112,32,72,105,103,101,109,97,114,117,0,0,0,0,109,100,95,110,98,97,97,99,116,57,53,112,49,53,0,0,77,101,116,97,109,111,113,101,115,116,101,114,32,40,73,110,116,101,114,110,97,116,105,111,110,97,108,41,0,0,0,0,98,111,111,116,108,101,103,32,40,80,101,116,97,99,111,32,83,46,65,46,41,0,0,0,78,66,65,32,65,99,116,105,111,110,32,39,57,53,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,50,48,50,41,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,67,111,117,108,100,110,39,116,32,102,105,110,100,32,97,110,121,32,112,114,101,118,105,111,117,115,32,118,105,100,101,111,32,100,114,105,118,101,114,32,40,99,117,114,114,101,110,116,32,111,110,101,58,32,34,37,115,34,41,46,10,0,0,0,0,0,0,0,84,105,103,101,114,32,82,111,97,100,32,40,85,83,41,0,0,0,0,0,0,0,0,0,109,100,95,110,98,97,97,99,116,57,53,112,48,49,0,0,68,114,105,118,105,110,103,32,70,111,114,99,101,32,40,80,97,99,45,77,97,110,32,99,111,110,118,101,114,115,105,111,110,41,0,0,0,0,0,0,83,117,112,101,114,32,82,101,97,108,32,68,97,114,119,105,110,32,40,87,111,114,108,100,41,0,0,0,0,0,0,0,68,73,80,32,115,119,105,116,99,104,32,108,97,98,101,108,58,32,37,115,46,10,0,0,78,66,65,32,65,99,116,105,111,110,32,39,57,53,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,50,48,49,41,0,0,0,0,83,107,121,32,70,111,120,0,0,0,0,0,0,0,0,0,65,108,116,101,114,110,97,116,101,44,32,83,105,110,103,108,101,0,0,0,0,0,0,0,77,97,120,105,109,117,109,32,99,114,101,100,105,116,115,0,70,90,45,50,48,48,54,32,71,97,109,101,32,73,0,0,109,100,95,110,98,97,97,99,116,57,53,112,48,50,0,0,52,32,67,114,101,100,105,116,115,32,49,56,32,79,117,116,99,111,117,110,116,115,32,49,54,32,77,105,110,0,0,0,82,111,117,116,101,32,49,54,0,0,0,0,0,0,0,0,78,66,65,32,65,99,116,105,111,110,32,39,57,53,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,50,48,49,44,32,65,108,116,41,0,0,0,0,0,0,0,77,97,120,32,86,115,32,82,111,117,110,100,0,0,0,0,71,101,110,101,114,105,99,0,109,100,95,110,98,97,97,99,116,57,53,112,48,51,0,0,112,97,110,103,51,98,51,0,79,0,0,0,114,0,0,0,105,0,0,0,101,0,0,0,110,0,0,0,116,0,0,0,97,0,0,0,108,0,0,0,32,0,0,0,76,0,0,0,101,0,0,0,103,0,0,0,101,0,0,0,110,0,0,0,100,0,0,0,32,0,0,0,83,0,0,0,112,0,0,0,101,0,0,0,99,0,0,0,105,0,0,0,97,0,0,0,108,0,0,0,32,0,0,0,80,0,0,0,108,0,0,0,117,0,0,0,115,0,0,0,0,0,0,0,127,137,0,0,56,110,0,0,202,145,0,0,132,83,0,0,32,79,0,0,32,0,0,0,80,0,0,0,108,0,0,0,117,0,0,0,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,71,97,108,97,103,97,32,39,56,56,0,0,0,0,0,0,82,101,97,108,32,66,111,117,116,32,70,97,116,97,108,32,70,117,114,121,32,50,32,45,32,84,104,101,32,78,101,119,99,111,109,101,114,115,32,47,32,82,101,97,108,32,66,111,117,116,32,71,97,114,111,117,32,68,101,110,115,101,116,115,117,32,50,32,45,32,116,104,101,32,110,101,119,99,111,109,101,114,115,32,40,78,71,72,45,50,52,48,48,41,0,0,78,66,65,32,65,99,116,105,111,110,32,39,57,53,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,49,50,51,49,41,0,0,0,0,65,114,109,101,100,32,70,111,114,109,97,116,105,111,110,0,0,0,0,0,0,0,0,0,77,97,114,118,101,108,32,83,117,112,101,114,32,72,101,114,111,101,115,32,118,115,32,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,40,57,55,48,55,48,50,32,74,97,112,97,110,41,0,0,0,0,65,32,82,101,115,115,104,97,32,100,101,32,73,107,111,117,32,77,68,32,45,32,84,97,107,101,32,116,104,101,32,39,65,39,32,84,114,97,105,110,32,40,74,112,110,41,0,0,80,101,110,103,117,105,110,45,75,117,110,32,87,97,114,115,32,40,85,83,41,0,0,0,80,49,32,82,105,103,104,116,0,0,0,0,0,0,0,0,109,100,95,110,98,97,97,99,116,57,53,112,49,54,0,0,37,48,56,120,58,32,32,73,108,108,101,103,97,108,32,76,68,82,77,32,119,114,105,116,101,98,97,99,107,32,116,111,32,114,49,53,10,0,0,0,78,66,65,32,65,99,116,105,111,110,32,39,57,53,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,49,50,51,48,41,0,0,0,0,9,9,68,111,32,110,111,116,101,32,116,104,97,116,32,110,111,108,111,97,100,45,115,97,118,101,32,105,109,112,108,105,101,115,32,116,104,97,116,32,115,97,118,101,32,102,105,108,101,115,32,119,105,108,108,32,98,101,32,100,101,108,101,116,101,100,32,97,110,100,32,111,118,101,114,119,114,105,116,116,101,110,46,0,0,0,0,0,82,45,62,114,97,109,95,99,116,114,108,0,0,0,0,0,67,101,110,116,117,114,121,32,69,108,101,99,116,114,111,110,105,99,115,0,0,0,0,0,49,32,99,111,105,110,32,50,32,112,108,97,121,0,0,0,83,116,105,99,107,32,109,111,100,101,0,0,0,0,0,0,102,105,120,101,105,103,104,116,117,116,0,0,0,0,0,0,80,117,122,122,108,101,32,85,111,32,80,111,107,111,32,40,73,110,116,101,114,110,97,116,105,111,110,97,108,44,32,118,101,114,46,32,57,56,47,48,50,47,48,54,41,0,0,0,50,32,99,111,105,110,115,32,51,32,112,108,97,121,115,0,109,100,95,110,98,97,97,99,116,57,53,112,49,55,0,0,71,101,116,32,83,116,97,114,32,40,98,111,111,116,108,101,103,44,32,115,101,116,32,49,41,0,0,0,0,0,0,0,49,32,67,111,105,110,32,32,51,32,67,114,101,100,105,116,115,0,0,0,0,0,0,0,77,111,111,110,32,67,114,101,115,116,97,32,40,80,101,116,97,99,111,32,83,46,65,46,32,83,112,97,110,105,115,104,32,98,111,111,116,108,101,103,41,0,0,0,0,0,0,0,78,66,65,32,65,99,116,105,111,110,32,39,57,53,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,49,50,50,57,41,0,0,0,0,75,111,114,101,97,32,40,74,67,32,84,114,97,100,105,110,103,32,67,111,114,112,46,32,108,105,99,101,110,115,101,41,0,0,0,0,0,0,0,0,77,97,104,106,111,110,103,32,71,97,107,117,101,110,0,0,50,48,48,75,0,0,0,0,109,100,95,110,98,97,97,99,116,57,53,112,49,56,0,0,77,97,114,107,104,97,109,0,0,0,0,0,0,0,0,0,78,111,32,107,110,111,119,110,32,108,97,98,101,108,0,0,78,66,65,32,65,99,116,105,111,110,32,39,57,53,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,49,50,50,52,45,65,41,0,0,51,48,107,44,32,56,48,107,0,0,0,0,0,0,0,0,72,101,97,118,121,32,66,97,114,114,101,108,32,40,87,111,114,108,100,41,0,0,0,0,83,105,109,117,108,116,97,110,101,111,117,115,0,0,0,0,49,32,115,101,99,32,61,32,52,53,47,54,48,0,0,0,68,105,110,111,32,82,101,120,32,40,85,83,41,0,0,0,68,111,109,109,121,0,0,0,83,104,105,110,111,98,105,32,78,105,110,106,97,32,71,97,109,101,0,0,0,0,0,0,109,100,95,110,98,97,97,99,116,57,53,112,49,57,0,0,71,97,109,101,32,84,105,109,101,32,80,50,0,0,0,0,100,114,116,111,112,112,101,108,0,0,0,0,0,0,0,0,65,114,107,97,110,111,105,100,32,40,98,111,111,116,108,101,103,32,119,105,116,104,32,77,67,85,44,32,97,108,116,41,0,0,0,0,0,0,0,0,118,112,99,95,118,100,99,95,115,101,108,101,99,116,0,0,87,87,70,32,83,117,112,101,114,115,116,97,114,115,32,40,69,117,114,111,112,101,41,0,0,0,0,0,0,0,0,0,78,66,65,32,65,99,116,105,111,110,32,39,57,53,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,49,50,50,50,45,65,41,0,0,76,101,118,101,108,32,56,0,82,97,109,98,111,32,73,73,73,32,40,85,83,41,0,0,72,97,114,110,101,115,115,32,84,121,112,101,0,0,0,0,99,104,97,115,101,104,113,106,0,0,0,0,0,0,0,0,109,100,95,110,98,97,97,99,116,57,53,112,50,48,0,0,70,117,110,107,121,32,70,105,115,104,0,0,0,0,0,0,79,112,101,114,97,116,105,111,110,32,66,101,97,114,0,0,80,97,110,103,33,32,51,32,40,98,111,111,116,108,101,103,32,115,101,116,32,50,44,32,57,53,48,53,49,49,32,69,117,114,111,41,0,0,0,0,79,114,105,101,110,116,97,108,32,76,101,103,101,110,100,32,83,112,101,99,105,97,108,32,80,108,117,115,32,47,32,88,105,32,89,111,117,32,83,104,105,32,69,32,90,104,117,97,110,32,83,117,112,101,114,32,80,108,117,115,32,40,118,101,114,46,32,50,48,53,41,0,0,0,0,0,0,0,0,0,112,99,101,95,103,97,108,97,103,97,56,56,0,0,0,0,114,98,102,102,50,104,0,0,100,108,97,110,100,0,0,0,78,66,65,32,65,99,116,105,111,110,32,39,57,53,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,49,50,49,53,41,0,0,0,0,109,115,104,118,115,102,106,49,0,0,0,0,0,0,0,0,109,100,95,97,114,101,115,115,104,109,100,0,0,0,0,0,80,114,101,104,105,115,116,111,114,105,99,32,73,115,108,101,32,105,110,32,49,57,51,48,32,40,87,111,114,108,100,41,0,0,0,0,0,0,0,0,77,97,122,105,110,103,101,114,32,90,32,40,87,111,114,108,100,44,32,118,101,114,46,32,57,52,47,48,54,47,50,55,41,0,0,0,0,0,0,0,76,105,109,105,116,101,100,32,69,100,105,116,105,111,110,32,72,97,110,103,45,79,110,0,0,0,0,0,0,0,0,0,80,49,32,80,117,115,104,0,109,100,95,110,98,97,97,99,116,57,53,112,50,49,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,73,32,51,114,100,32,83,116,114,105,107,101,58,32,70,105,103,104,116,32,102,111,114,32,116,104,101,32,70,117,116,117,114,101,32,40,74,97,112,97,110,32,57,57,48,54,48,56,44,32,78,79,32,67,68,41,0,0,0,0,0,0,0,74,0,0,0,117,0,0,0,117,0,0,0,111,0,0,0,107,0,0,0,105,0,0,0,32,0,0,0,40,0,0,0,115,0,0,0,101,0,0,0,116,0,0,0,32,0,0,0,51,0,0,0,44,0,0,0,32,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,44,0,0,0,32,0,0,0,70,0,0,0,68,0,0,0,49,0,0,0,48,0,0,0,57,0,0,0,52,0,0,0,32,0,0,0,51,0,0,0,49,0,0,0,55,0,0,0,45,0,0,0,48,0,0,0,48,0,0,0,54,0,0,0,56,0,0,0,41,0,0,0,0,0,0,0,99,115,0,0,139,115,0,0,24,138,0,0,0,0,0,0,0,0,0,0,66,108,111,99,107,32,79,117,116,32,40,115,101,116,32,49,41,0,0,0,0,0,0,0,109,117,108,116,105,112,108,121,0,0,0,0,0,0,0,0,78,66,65,32,65,99,116,105,111,110,32,39,57,53,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,49,50,48,57,41,0,0,0,0,9,9,123,110,111,44,125,108,111,97,100,45,123,110,111,44,125,115,97,118,101,32,100,101,115,99,114,105,98,101,115,32,105,102,32,83,82,65,77,32,115,104,111,117,108,100,32,98,101,32,108,111,97,100,101,100,44,32,97,110,100,32,105,102,32,83,82,65,77,32,115,104,111,117,108,100,32,98,101,32,115,97,118,101,100,46,0,0,70,108,105,99,107,121,32,40,54,52,107,32,86,101,114,115,105,111,110,44,32,83,121,115,116,101,109,32,49,44,32,51,49,53,45,53,48,53,49,44,32,115,101,116,32,50,41,0,0,0,0,0,0,0,0,0,68,46,32,68,46,32,67,114,101,119,32,40,115,101,116,32,50,44,32,87,111,114,108,100,44,32,50,32,80,108,97,121,101,114,115,44,32,70,68,49,48,57,52,32,51,49,55,45,48,49,56,52,41,0,0,0,109,100,95,110,98,97,97,99,116,57,53,112,50,50,0,0,108,111,102,102,105,114,101,106,0,0,0,0,0,0,0,0,49,57,56,48,63,0,0,0,68,117,109,112,32,77,97,116,115,117,109,111,116,111,32,40,74,97,112,97,110,44,32,56,55,53,49,32,51,49,55,45,117,110,107,110,111,119,110,41,0,0,0,0,0,0,0,0,78,66,65,32,65,99,116,105,111,110,32,39,57,53,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,49,50,48,50,45,66,41,0,0,115,104,97,114,114,105,101,114,0,0,0,0,0,0,0,0,86,101,114,121,95,69,97,115,121,0,0,0,0,0,0,0,118,105,100,101,111,95,115,119,97,112,95,105,110,116,101,114,118,97,108,0,0,0,0,0,49,48,48,48,32,77,105,103,108,105,97,58,32,71,114,101,97,116,32,49,48,48,48,32,77,105,108,101,115,32,82,97,108,108,121,32,40,57,52,47,48,54,47,49,51,41,0,0,83,87,65,84,32,80,111,108,105,99,101,0,0,0,0,0,109,100,95,110,98,97,97,99,116,57,53,112,50,51,0,0,119,111,110,100,115,116,99,107,0,0,0,0,0,0,0,0,82,101,116,114,111,80,97,100,32,66,117,116,116,111,110,32,82,51,0,0,0,0,0,0,78,66,65,32,65,99,116,105,111,110,32,39,57,53,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,49,32,67,111,105,110,32,32,51,32,67,114,101,100,105,116,115,32,0,0,0,0,0,0,50,32,80,108,97,121,101,114,32,77,111,100,101,0,0,0,83,112,108,105,116,0,0,0,49,32,115,101,99,32,61,32,54,50,47,54,48,0,0,0,83,108,111,119,0,0,0,0,51,43,49,0,0,0,0,0,109,100,95,110,98,97,97,99,116,57,53,0,0,0,0,0,69,110,100,108,101,115,115,32,71,97,109,101,0,0,0,0,49,67,32,54,79,67,32,56,77,32,47,32,50,67,32,49,56,79,67,32,49,52,77,0,32,10,9,12,13,11,0,0,83,117,112,101,114,32,83,112,97,99,101,102,111,114,116,114,101,115,115,32,77,97,99,114,111,115,115,32,73,73,32,47,32,67,104,111,117,45,74,105,107,117,117,32,89,111,117,115,97,105,32,77,97,99,114,111,115,115,32,73,73,0,0,0,109,97,105,110,50,115,117,98,0,0,0,0,0,0,0,0,112,101,110,98,114,111,115,0,78,66,65,32,65,99,116,105,111,110,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,49,50,55,44,32,66,114,111,107,101,110,32,45,32,67,48,56,32,109,105,115,115,105,110,103,41,0,0,83,112,101,101,100,0,0,0,76,101,118,101,108,32,55,0,75,97,110,115,97,105,0,0,80,117,99,107,32,77,97,110,32,40,74,97,112,97,110,32,115,101,116,32,49,41,0,0,78,101,119,115,73,110,112,117,116,0,0,0,0,0,0,0,109,100,95,110,98,97,97,99,116,112,49,0,0,0,0,0,68,114,118,66,103,48,83,99,114,111,108,108,88,0,0,0,112,97,110,103,51,98,50,0,111,108,100,115,112,108,117,115,0,0,0,0,0,0,0,0,77,105,115,115,32,87,111,114,108,100,32,39,57,54,32,40,78,117,100,101,41,0,0,0,71,97,105,97,32,110,111,32,77,111,110,115,104,111,117,0,0,0,0,0,0,0,0,0,82,0,0,0,101,0,0,0,97,0,0,0,108,0,0,0,32,0,0,0,66,0,0,0,111,0,0,0,117,0,0,0,116,0,0,0,32,0,0,0,70,0,0,0,97,0,0,0,116,0,0,0,97,0,0,0,108,0,0,0,32,0,0,0,70,0,0,0,117,0,0,0,114,0,0,0,121,0,0,0,32,0,0,0,50,0,0,0,32,0,0,0,45,0,0,0,32,0,0,0,84,0,0,0,104,0,0,0,101,0,0,0,32,0,0,0,78,0,0,0,101,0,0,0,119,0,0,0,99,0,0,0,111,0,0,0,109,0,0,0,101,0,0,0,114,0,0,0,115,0,0,0,0,0,0,0,82,0,0,0,101,0,0,0,97,0,0,0,108,0,0,0,32,0,0,0,66,0,0,0,111,0,0,0,117,0,0,0,116,0,0,0,32,0,0,0,19,153,0,0,252,114,0,0,29,79,0,0,172,138,0,0,18,255,0,0,32,0,0,0,40,0,0,0,78,0,0,0,71,0,0,0,77,0,0,0,45,0,0,0,50,0,0,0,52,0,0,0,48,0,0,0,48,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,37,105,32,66,117,116,116,111,110,115,32,49,50,51,52,0,0,0,0,0,0,0,0,78,66,65,32,65,99,116,105,111,110,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,49,49,54,41,0,0,0,0,0,0,0,0,80,0,0,0,114,0,0,0,101,0,0,0,116,0,0,0,116,0,0,0,121,0,0,0,32,0,0,0,83,0,0,0,111,0,0,0,108,0,0,0,100,0,0,0,105,0,0,0,101,0,0,0,114,0,0,0,32,0,0,0,83,0,0,0,97,0,0,0,105,0,0,0,108,0,0,0,111,0,0,0,114,0,0,0,32,0,0,0,77,0,0,0,111,0,0,0,111,0,0,0,110,0,0,0,0,0,0,0,142,127,0,0,17,92,0,0,115,89,0,0,38,98,0,0,235,88,0,0,32,0,0,0,187,48,0,0,252,48,0,0,233,48,0,0,252,48,0,0,224,48,0,0,252,48,0,0,243,48,0,0,32,0,0,0,40,0,0,0,118,0,0,0,101,0,0,0,114,0,0,0,46,0,0,0,32,0,0,0,57,0,0,0,53,0,0,0,47,0,0,0,48,0,0,0,51,0,0,0,47,0,0,0,50,0,0,0,50,0,0,0,44,0,0,0,32,0,0,0,69,0,0,0,117,0,0,0,114,0,0,0,111,0,0,0,112,0,0,0,101,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,70,111,114,101,103,114,111,117,110,100,32,83,99,114,111,108,108,32,82,65,77,0,0,0,66,108,97,99,107,32,84,105,103,101,114,0,0,0,0,0,77,97,114,118,101,108,32,83,117,112,101,114,32,72,101,114,111,101,115,32,118,115,32,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,40,57,55,48,55,48,55,32,74,97,112,97,110,41,0,0,0,0,54,56,56,32,65,116,116,97,99,107,32,83,117,98,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,50,32,99,111,105,110,115,32,116,111,32,115,116,97,114,116,44,32,49,32,116,111,32,99,111,110,116,105,110,117,101,0,109,100,95,110,98,97,97,99,116,112,50,0,0,0,0,0,112,114,101,115,99,97,108,101,114,0,0,0,0,0,0,0,65,116,116,101,109,112,116,32,116,111,32,114,101,97,100,32,98,121,116,101,32,118,97,108,117,101,32,111,102,32,108,111,99,97,116,105,111,110,32,37,120,10,0,0,0,0,0,0,78,117,109,98,101,114,32,111,102,32,86,105,114,117,115,0,86,101,114,121,32,72,97,114,100,32,52,0,0,0,0,0,78,66,65,32,65,99,116,105,111,110,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,49,48,52,41,0,0,0,0,0,0,0,0,9,45,77,47,45,45,115,114,97,109,45,109,111,100,101,58,32,84,97,107,101,115,32,97,110,32,97,114,103,117,109,101,110,116,32,116,101,108,108,105,110,103,32,104,111,119,32,83,82,65,77,32,115,104,111,117,108,100,32,98,101,32,104,97,110,100,108,101,100,32,105,110,32,116,104,101,32,115,101,115,115,105,111,110,46,0,0,0,71,97,117,110,116,108,101,116,32,40,114,101,118,32,49,52,41,0,0,0,0,0,0,0,83,116,114,105,107,101,32,71,117,110,110,101,114,32,83,46,84,46,71,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,77,111,110,105,116,111,114,32,70,80,83,32,101,115,116,105,109,97,116,105,111,110,32,105,115,32,100,105,115,97,98,108,101,100,32,102,111,114,32,116,104,114,101,97,100,101,100,32,118,105,100,101,111,46,10,0,0,0,0,0,0,109,100,95,110,98,97,97,99,116,112,51,0,0,0,0,0,77,101,105,106,105,110,115,101,110,0,0,0,0,0,0,0,49,32,67,111,105,110,45,54,32,80,108,97,121,0,0,0,109,111,111,110,99,112,116,99,0,0,0,0,0,0,0,0,84,111,112,112,121,32,38,32,82,97,112,112,121,0,0,0,104,116,99,104,99,116,99,104,0,0,0,0,0,0,0,0,78,66,65,32,65,99,116,105,111,110,32,40,85,83,65,41,0,0,0,0,0,0,0,0,66,111,109,98,32,74,97,99,107,32,40,115,101,116,32,49,41,0,0,0,0,0,0,0,83,116,114,105,107,101,114,115,32,49,57,52,53,32,40,74,97,112,97,110,44,32,117,110,112,114,111,116,101,99,116,101,100,41,0,0,0,0,0,0,80,83,53,86,50,0,0,0,80,115,105,107,121,111,32,47,32,77,111,115,115,0,0,0,109,100,95,110,98,97,97,99,116,0,0,0,0,0,0,0,116,116,109,97,104,106,110,103,0,0,0,0,0,0,0,0,66,105,111,110,105,99,32,67,111,109,109,97,110,100,111,32,40,69,117,114,111,41,0,0,84,101,114,114,97,32,70,111,114,99,101,32,40,85,83,41,0,0,0,0,0,0,0,0,82,101,116,114,111,80,97,100,32,66,117,116,116,111,110,32,76,51,0,0,0,0,0,0,78,97,107,97,106,105,109,97,32,83,97,116,111,114,117,32,75,97,110,115,104,117,117,32,70,49,32,83,117,112,101,114,32,76,105,99,101,110,115,101,32,40,74,112,110,41,0,0,80,97,110,103,32,40,87,111,114,108,100,41,0,0,0,0,49,67,32,49,67,32,47,32,49,67,32,50,67,0,0,0,49,32,115,101,99,32,61,32,53,54,47,54,48,0,0,0,83,112,101,101,100,32,111,102,32,83,105,103,104,116,0,0,80,97,99,45,76,97,110,100,32,40,87,111,114,108,100,41,0,0,0,0,0,0,0,0,73,0,0,0,0,0,0,0,109,100,95,110,97,107,97,102,49,115,108,0,0,0,0,0,84,101,115,116,32,77,111,100,101,0,0,0,0,0,0,0,49,32,67,114,101,100,105,116,32,32,49,50,32,79,117,116,99,111,117,110,116,115,32,49,50,32,77,105,110,0,0,0,84,117,109,111,32,112,105,110,0,0,0,0,0,0,0,0,72,97,110,103,108,121,45,77,97,110,32,40,115,101,116,32,49,41,0,0,0,0,0,0,78,97,107,97,106,105,109,97,32,83,97,116,111,114,117,32,75,97,110,115,104,117,117,32,70,49,32,72,101,114,111,32,77,68,32,40,74,112,110,41,0,0,0,0,0,0,0,0,52,32,69,110,32,82,97,121,97,0,0,0,0,0,0,0,103,97,117,110,116,108,101,116,114,52,0,0,0,0,0,0,50,32,80,108,97,121,101,114,0,0,0,0,0,0,0,0,76,101,118,101,108,32,54,0,49,32,67,111,105,110,32,32,49,32,67,114,101,100,105,116,32,0,0,0,0,0,0,0,75,97,110,116,111,117,0,0,115,99,114,111,108,108,95,121,0,0,0,0,0,0,0,0,80,37,105,32,66,117,116,116,111,110,115,32,50,51,52,0,109,100,95,102,49,104,101,114,111,109,100,0,0,0,0,0,77,114,46,32,68,111,33,0,0,0,0,0,0,0,0,0,80,97,110,103,33,32,51,32,40,98,111,111,116,108,101,103,32,115,101,116,32,49,44,32,57,53,48,53,49,49,32,69,117,114,111,41,0,0,0,0,75,0,0,0,110,0,0,0,105,0,0,0,103,0,0,0,104,0,0,0,116,0,0,0,115,0,0,0,32,0,0,0,111,0,0,0,102,0,0,0,32,0,0,0,86,0,0,0,97,0,0,0,108,0,0,0,111,0,0,0,117,0,0,0,114,0,0,0,58,0,0,0,32,0,0,0,89,0,0,0,105,0,0,0,32,0,0,0,84,0,0,0,111,0,0,0,110,0,0,0,103,0,0,0,32,0,0,0,90,0,0,0,104,0,0,0,111,0,0,0,110,0,0,0,103,0,0,0,32,0,0,0,89,0,0,0,117,0,0,0,97,0,0,0,110,0,0,0,0,0,0,0,9,78,0,0,253,86,0,0,24,98,0,0,170,126,0,0,0,0,0,0,0,78,0,0,223,126,0,0,45,78,0,0,159,83,0,0,32,0,0,0,40,0,0,0,118,0,0,0,101,0,0,0,114,0,0,0,46,0,0,0,32,0,0,0,50,0,0,0,48,0,0,0,49,0,0,0,44,0,0,0,32,0,0,0,67,0,0,0,104,0,0,0,105,0,0,0,110,0,0,0,97,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,111,111,98,121,32,75,105,100,115,32,40,73,116,97,108,105,97,110,32,109,97,110,117,102,97,99,116,117,114,101,100,32,103,114,97,112,104,105,99,32,104,97,99,107,32,47,32,98,111,111,116,108,101,103,32,111,102,32,75,105,100,32,110,111,32,72,111,114,101,32,72,111,114,101,32,68,97,105,115,97,107,117,115,101,110,32,40,98,111,111,116,108,101,103,41,41,0,0,0,0,0,0,0,112,99,101,95,103,97,105,97,109,111,110,115,0,0,0,0,82,101,97,108,32,66,111,117,116,32,70,97,116,97,108,32,70,117,114,121,32,50,32,45,32,84,104,101,32,78,101,119,99,111,109,101,114,115,32,47,32,82,101,97,108,32,66,111,117,116,32,71,97,114,111,117,32,68,101,110,115,101,116,115,117,32,50,32,45,32,116,104,101,32,110,101,119,99,111,109,101,114,115,32,40,78,71,77,45,50,52,48,48,41,0,0,86,97,114,105,101,0,0,0,109,115,104,118,115,102,106,0,68,114,118,83,99,114,111,108,108,49,91,50,93,0,0,0,109,100,95,54,56,56,97,116,115,117,98,0,0,0,0,0,76,97,100,121,32,66,117,103,0,0,0,0,0,0,0,0,78,97,107,97,106,105,109,97,32,83,97,116,111,114,117,32,75,97,110,115,104,117,117,32,70,49,32,71,114,97,110,100,32,80,114,105,120,32,40,74,112,110,41,0,0,0,0,0,83,117,112,101,114,32,67,97,115,105,110,111,0,0,0,0,73,107,97,114,105,32,73,73,73,32,45,32,84,104,101,32,82,101,115,99,117,101,32,40,56,45,87,97,121,32,74,111,121,115,116,105,99,107,41,0,0,0,0,0,0,0,0,0,83,111,108,111,109,111,110,39,115,32,75,101,121,32,40,85,83,41,0,0,0,0,0,0,109,100,95,110,97,107,97,102,49,103,112,0,0,0,0,0,68,114,118,66,103,50,83,99,114,111,108,108,88,91,48,93,0,0,0,0,0,0,0,0,9,45,82,47,45,45,98,115,118,114,101,99,111,114,100,58,32,83,116,97,114,116,32,114,101,99,111,114,100,105,110,103,32,97,32,66,83,86,32,109,111,118,105,101,32,102,105,108,101,32,102,114,111,109,32,116,104,101,32,98,101,103,105,110,110,105,110,103,46,0,0,0,67,114,117,120,0,0,0,0,70,117,115,104,105,103,105,32,110,111,32,85,109,105,32,110,111,32,78,97,100,105,97,32,40,74,112,110,41,0,0,0,78,105,99,104,105,98,117,116,115,117,32,40,71,114,101,109,108,105,110,32,108,105,99,101,110,115,101,41,0,0,0,0,85,80,83,0,0,0,0,0,32,54,32,67,111,105,110,115,32,49,32,67,114,101,100,105,116,0,0,0,0,0,0,0,109,97,107,97,105,109,117,114,99,0,0,0,0,0,0,0,49,32,67,111,105,110,32,32,49,32,67,114,101,100,105,116,32,32,47,32,49,32,67,111,105,110,32,32,52,32,32,67,114,101,100,105,116,115,0,0,109,100,95,110,97,100,105,97,0,0,0,0,0,0,0,0,87,99,57,48,83,99,114,111,108,108,50,89,76,111,0,0,82,97,100,97,114,32,83,99,111,112,101,0,0,0,0,0,77,97,111,117,32,82,101,110,106,105,115,104,105,32,40,74,112,110,41,0,0,0,0,0,68,111,117,98,108,101,32,68,114,97,103,111,110,32,40,98,111,111,116,108,101,103,32,119,105,116,104,32,77,54,56,48,51,41,0,0,0,0,0,0,65,83,73,67,50,55,97,32,82,101,103,115,0,0,0,0,71,117,110,46,32,83,109,111,107,101,32,40,87,111,114,108,100,41,0,0,0,0,0,0,82,101,116,114,111,80,97,100,32,66,117,116,116,111,110,32,82,50,0,0,0,0,0,0,109,100,95,109,97,111,117,114,101,110,0,0,0,0,0,0,49,32,115,101,99,32,61,32,53,56,47,54,48,0,0,0,77,105,114,114,111,114,32,83,99,114,101,101,110,0,0,0,68,114,101,97,109,119,111,114,107,115,0,0,0,0,0,0,49,32,67,114,101,100,105,116,32,32,32,54,32,79,117,116,99,111,117,110,116,115,32,55,32,77,105,110,0,0,0,0,84,101,114,114,97,32,67,114,101,115,116,97,32,40,89,77,51,53,50,54,32,115,101,116,32,49,41,0,0,0,0,0,77,121,115,116,105,99,97,108,32,70,105,103,104,116,101,114,32,40,85,83,65,41,0,0,76,101,118,101,108,32,53,0,86,105,99,116,111,114,32,73,110,116,101,114,97,99,116,105,118,101,32,83,111,102,116,119,97,114,101,0,0,0,0,0,82,117,108,101,115,0,0,0,109,100,95,109,121,115,116,105,99,102,0,0,0,0,0,0,84,111,107,105,32,40,87,111,114,108,100,32,115,101,116,32,49,41,0,0,0,0,0,0,112,97,110,103,51,98,0,0,75,110,105,103,104,116,115,32,111,102,32,86,97,108,111,117,114,58,32,89,105,32,84,111,110,103,32,90,104,111,110,103,32,89,117,97,110,32,47,32,83,97,110,103,111,107,117,32,83,101,110,107,105,58,32,89,105,32,84,111,110,103,32,90,104,111,110,103,32,89,117,97,110,32,40,118,101,114,46,32,50,48,49,44,32,67,104,105,110,97,41,0,0,0,0,0,71,97,105,32,70,108,97,109,101,0,0,0,0,0,0,0,80,37,105,32,66,117,116,116,111,110,115,32,49,51,52,0,84,104,114,101,101,32,87,111,110,100,101,114,115,32,40,98,111,111,116,108,101,103,32,115,101,116,32,50,44,32,119,111,110,100,101,114,32,51,32,57,49,48,53,50,48,32,101,116,99,41,0,0,0,0,0,0,77,97,104,106,111,110,103,32,75,121,111,32,82,101,116,115,117,100,101,110,32,40,78,71,77,45,48,48,52,41,40,78,71,72,45,48,48,52,41,0,0,0,0,0,0,0,0,0,81,117,105,122,32,79,108,121,109,112,105,99,0,0,0,0,79,110,32,68,97,108,32,74,97,110,103,32,71,111,111,110,32,40,75,111,114,41,0,0,110,73,82,81,67,111,110,116,114,111,108,0,0,0,0,0,77,97,114,118,101,108,32,83,117,112,101,114,32,72,101,114,111,101,115,32,118,115,32,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,40,57,55,48,54,50,53,32,72,105,115,112,97,110,105,99,41,0,0,0,0,0,0,0,0,0,54,45,80,97,107,32,40,85,83,65,41,0,0,0,0,0,69,120,101,100,32,69,120,101,115,0,0,0,0,0,0,0,109,100,95,111,110,100,97,108,0,0,0,0,0,0,0,0,9,45,80,47,45,45,98,115,118,112,108,97,121,58,32,80,108,97,121,98,97,99,107,32,97,32,66,83,86,32,109,111,118,105,101,32,102,105,108,101,46,0,0,0,0,0,0,0,79,80,76,45,62,114,104,121,116,104,109,0,0,0,0,0,86,117,108,103,117,115,32,40,115,101,116,32,49,41,0,0,75,117,106,97,107,117,32,79,117,32,50,32,45,32,71,101,110,101,105,106,111,117,32,40,74,112,110,41,0,0,0,0,103,108,79,98,106,101,99,116,76,97,98,101,108,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,97,108,108,111,99,97,116,101,32,109,101,109,111,114,121,46,10,0,83,117,112,101,114,32,77,111,111,110,32,67,114,101,115,116,97,0,0,0,0,0,0,0,80,97,115,115,80,114,101,118,37,117,0,0,0,0,0,0,109,100,95,107,117,106,97,107,117,50,0,0,0,0,0,0,49,57,52,50,32,40,82,101,118,105,115,105,111,110,32,66,41,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,68,101,116,101,99,116,105,110,103,32,115,99,114,101,101,110,32,114,101,115,111,108,117,116,105,111,110,32,37,117,120,37,117,46,10,0,0,83,89,83,84,69,77,32,68,73,82,32,37,115,0,0,0,77,121,115,116,105,99,32,68,101,102,101,110,100,101,114,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,37,46,50,102,0,0,0,0,67,121,98,101,114,32,84,97,110,107,32,40,118,49,46,52,41,0,0,0,0,0,0,0,109,100,95,112,103,97,50,0,82,101,116,114,111,80,97,100,32,66,117,116,116,111,110,32,76,50,0,0,0,0,0,0,109,100,95,109,121,115,116,100,101,102,97,0,0,0,0,0,87,97,108,108,32,67,114,97,115,104,32,40,115,101,116,32,49,41,0,0,0,0,0,0,83,104,105,101,108,100,115,0,84,105,109,101,114,32,99,111,117,110,116,0,0,0,0,0,68,105,115,99,111,117,110,116,101,100,32,67,111,110,116,105,110,117,101,32,80,108,97,121,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,32,110,111,116,32,105,110,105,116,105,97,108,105,122,101,32,109,101,110,117,46,10,0,0,0,0,0,0,0,0,77,121,115,116,105,99,32,68,101,102,101,110,100,101,114,32,40,69,117,114,111,44,32,85,83,65,44,32,82,101,118,46,32,65,41,0,0,0,0,0,50,32,67,114,101,100,105,116,115,32,49,56,32,79,117,116,99,111,117,110,116,115,32,49,52,32,77,105,110,0,0,0,80,117,115,104,32,115,116,97,114,116,32,116,111,32,102,114,101,101,122,101,32,40,99,104,101,97,116,41,0,0,0,0,65,108,105,101,110,32,83,101,99,116,111,114,0,0,0,0,109,100,95,109,121,115,116,100,101,102,0,0,0,0,0,0,76,101,118,101,108,32,52,0,49,32,67,111,105,110,32,32,54,32,80,108,97,121,115,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,84,101,120,116,117,114,101,32,105,109,97,103,101,32,102,97,105,108,101,100,32,116,111,32,108,111,97,100,46,10,0,0,0,0,0,80,101,110,116,97,0,0,0,71,0,0,0,114,0,0,0,97,0,0,0,100,0,0,0,105,0,0,0,117,0,0,0,115,0,0,0,32,0,0,0,73,0,0,0,73,0,0,0,32,0,0,0,45,0,0,0,32,0,0,0,71,0,0,0,79,0,0,0,70,0,0,0,69,0,0,0,82,0,0,0,32,0,0,0,110,48,0,0,206,145,0,0,27,103,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,32,0,0,0,79,0,0,0,108,0,0,0,100,0,0,0,32,0,0,0,118,0,0,0,101,0,0,0,114,0,0,0,46,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,77,117,116,97,110,116,32,76,101,97,103,117,101,32,72,111,99,107,101,121,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,0,0,65,114,109,111,114,101,100,32,87,97,114,114,105,111,114,115,32,40,57,52,49,48,50,52,32,69,117,114,111,112,101,41,0,0,0,0,0,0,0,0,80,97,110,103,33,32,51,32,40,57,53,48,53,49,49,32,69,117,114,111,44,32,97,108,116,41,0,0,0,0,0,0,107,111,118,121,116,122,121,0,112,99,101,95,103,97,105,102,108,97,109,101,0,0,0,0,80,37,105,32,66,117,116,116,111,110,115,32,49,50,52,0,83,101,99,116,105,111,110,32,90,32,40,115,101,116,32,49,41,0,0,0,0,0,0,0,111,118,101,114,108,97,121,37,117,95,100,101,115,99,37,117,95,111,118,101,114,108,97,121,0,0,0,0,0,0,0,0,109,100,95,109,108,104,111,99,107,101,121,0,0,0,0,0,109,115,104,118,115,102,104,0,109,100,95,54,112,97,107,0,84,101,101,110,97,103,101,32,77,117,116,97,110,116,32,78,105,110,106,97,32,84,117,114,116,108,101,115,32,40,79,99,101,97,110,105,97,32,50,32,80,108,97,121,101,114,115,41,0,0,0,0,0,0,0,0,114,105,115,107,99,104,97,108,0,0,0,0,0,0,0,0,76,111,100,101,32,82,117,110,110,101,114,32,40,115,101,116,32,50,41,0,0,0,0,0,77,121,115,116,101,114,105,111,117,115,32,83,116,111,110,101,115,32,45,32,68,114,46,32,74,111,104,110,39,115,32,65,100,118,101,110,116,117,114,101,0,0,0,0,0,0,0,0,77,117,116,97,110,116,32,76,101,97,103,117,101,32,70,111,111,116,98,97,108,108,32,40,74,112,110,41,0,0,0,0,98,117,99,99,97,110,114,115,97,0,0,0,0,0,0,0,114,116,121,112,101,108,101,111,0,0,0,0,0,0,0,0,100,98,114,101,101,100,109,55,50,0,0,0,0,0,0,0,84,101,116,114,105,115,32,40,115,101,116,32,49,41,0,0,109,100,95,109,108,102,111,111,116,98,106,0,0,0,0,0,9,45,52,47,45,45,109,117,108,116,105,116,97,112,58,32,67,111,110,110,101,99,116,32,97,32,83,78,69,83,32,109,117,108,116,105,116,97,112,32,116,111,32,112,111,114,116,32,50,46,32,40,83,78,69,83,32,115,112,101,99,105,102,105,99,41,46,0,0,0,0,0,77,117,115,104,97,32,65,108,101,115,116,101,32,45,32,70,117,108,108,32,77,101,116,97])
.concat([108,32,70,105,103,104,116,101,114,32,69,108,108,105,110,111,114,32,40,74,112,110,41,0,0,0,0,0,0,0,0,0,115,109,111,111,110,99,114,115,0,0,0,0,0,0,0,0,109,100,95,109,117,115,104,97,106,0,0,0,0,0,0,0,74,97,99,107,32,116,104,101,32,71,105,97,110,116,107,105,108,108,101,114,32,40,115,101,116,32,49,41,0,0,0,0,77,85,83,72,65,32,45,32,77,101,116,97,108,108,105,99,32,85,110,105,102,114,97,109,101,32,83,117,112,101,114,32,72,121,98,114,105,100,32,65,114,109,111,114,32,40,85,83,65,41,0,0,0,0,0,0,77,101,103,97,100,111,110,0,0,0,0,0,0,0,0,0,82,101,116,114,111,80,97,100,32,66,117,116,116,111,110,32,82,0,0,0,0,0,0,0,109,100,95,109,117,115,104,97,0,0,0,0,0,0,0,0,52,32,80,108,97,121,101,114,115,0,0,0,0,0,0,0,70,117,108,108,32,84,104,114,111,116,116,108,101,32,67,111,110,118,101,114,116,44,32,68,101,108,117,120,101,0,0,0,77,117,104,97,109,109,97,100,32,65,108,105,32,72,101,97,118,121,119,101,105,103,104,116,32,66,111,120,105,110,103,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,0,0,71,97,109,101,32,84,105,109,101,32,80,49,0,0,0,0,68,101,109,111,32,115,111,117,110,100,115,0,0,0,0,0,80,46,79,46,87,46,32,45,32,80,114,105,115,111,110,101,114,115,32,111,102,32,87,97,114,32,40,85,83,32,118,101,114,115,105,111,110,32,49,41,0,0,0,0,0,0,0,0,109,100,95,109,117,104,97,109,109,97,100,117,112,0,0,0,76,101,118,101,108,32,51,0,65,122,116,97,114,97,99,0,0,0,0,0,0,0,0,0,49,32,67,111,105,110,32,32,52,32,80,108,97,121,115,0,112,101,110,116,97,0,0,0,77,117,104,97,109,109,97,100,32,65,108,105,32,72,101,97,118,121,119,101,105,103,104,116,32,66,111,120,105,110,103,32,40,85,83,65,41,0,0,0,112,97,110,103,51,114,49,97,0,0,0,0,0,0,0,0,75,0,0,0,110,0,0,0,105,0,0,0,103,0,0,0,104,0,0,0,116,0,0,0,115,0,0,0,32,0,0,0,111,0,0,0,102,0,0,0,32,0,0,0,86,0,0,0,97,0,0,0,108,0,0,0,111,0,0,0,117,0,0,0,114,0,0,0,32,0,0,0,83,0,0,0,117,0,0,0,112,0,0,0,101,0,0,0,114,0,0,0,32,0,0,0,72,0,0,0,101,0,0,0,114,0,0,0,111,0,0,0,101,0,0,0,115,0,0,0,32,0,0,0,80,0,0,0,108,0,0,0,117,0,0,0,115,0,0,0,0,0,0,0,9,78,0,0,253,86,0,0,24,98,0,0,170,126,0,0,0,0,0,0,113,78,0,0,22,78,0,0,173,103,0,0,196,150,0,0,32,0,0,0,40,0,0,0,118,0,0,0,101,0,0,0,114,0,0,0,46,0,0,0,32,0,0,0,49,0,0,0,48,0,0,0,48,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,70,117,115,104,105,103,105,32,110,111,32,89,117,109,101,32,110,111,32,65,108,105,99,101,0,0,0,0,0,0,0,0,84,0,0,0,104,0,0,0,101,0,0,0,32,0,0,0,73,0,0,0,114,0,0,0,114,0,0,0,105,0,0,0,116,0,0,0,97,0,0,0,116,0,0,0,105,0,0,0,110,0,0,0,103,0,0,0,32,0,0,0,77,0,0,0,97,0,0,0,122,0,0,0,101,0,0,0,0,0,0,0,166,48,0,0,235,48,0,0,200,48,0,0,233,48,0,0,251,150,0,0,65,109,0,0,164,48,0,0,233,48,0,0,164,48,0,0,233,48,0,0,210,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,37,105,32,66,117,116,116,111,110,115,32,49,50,51,0,109,100,95,109,117,104,97,109,109,97,100,117,0,0,0,0,67,111,109,109,97,110,100,111,32,40,87,111,114,108,100,41,0,0,0,0,0,0,0,0,77,97,114,118,101,108,32,83,117,112,101,114,32,72,101,114,111,101,115,32,118,115,32,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,40,57,55,48,54,50,53,32,66,114,97,122,105,108,41,0,0,0,51,32,105,110,32,49,32,82,111,97,100,32,82,97,115,104,32,45,32,77,115,46,32,80,97,99,45,77,97,110,32,45,32,66,108,111,99,107,32,79,117,116,32,40,80,105,114,97,116,101,41,0,0,0,0,0,77,117,104,97,109,109,97,100,32,65,108,105,32,72,101,97,118,121,119,101,105,103,104,116,32,66,111,120,105,110,103,32,40,69,117,114,111,41,0,0,109,100,95,109,117,104,97,109,109,97,100,0,0,0,0,0,9,45,74,47,45,45,106,117,115,116,105,102,105,101,114,115,58,32,68,97,105,115,121,32,99,104,97,105,110,32,116,119,111,32,118,105,114,116,117,97,108,32,75,111,110,97,109,105,32,74,117,115,116,105,102,105,101,114,115,32,105,110,116,111,32,112,111,114,116,32,50,46,32,40,83,78,69,83,32,115,112,101,99,105,102,105,99,41,46,0,0,0,0,0,0,0,82,101,115,101,116,46,0,0,49,57,52,51,58,32,84,104,101,32,66,97,116,116,108,101,32,111,102,32,77,105,100,119,97,121,32,40,69,117,114,111,41,0,0,0,0,0,0,0,77,115,46,32,80,97,99,45,77,97,110,32,40,80,105,114,97,116,101,44,32,82,105,112,112,101,100,32,102,114,111,109,32,71,111,108,100,101,110,32,49,48,32,105,110,32,49,41,0,0,0,0,0,0,0,0,98,111,111,116,108,101,103,63,32,40,70,111,114,116,114,101,107,41,0,0,0,0,0,0,68,121,110,97,109,105,116,101,32,68,117,107,101,32,40,69,117,114,111,112,101,32,115,101,116,32,49,41,0,0,0,0,71,97,108,80,97,108,101,116,116,101,66,97,110,107,0,0,109,100,95,109,115,112,97,99,109,97,110,112,105,114,0,0,82,101,110,101,103,97,100,101,32,40,85,83,41,0,0,0,84,101,110,103,101,110,32,126,32,84,105,109,101,32,87,97,114,110,101,114,32,73,110,116,101,114,97,99,116,105,118,101,0,0,0,0,0,0,0,0,82,101,116,114,111,80,97,100,32,66,117,116,116,111,110,32,76,0,0,0,0,0,0,0,77,115,46,32,80,97,99,45,77,97,110,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,0,0,0,66,108,117,101,32,80,114,105,110,116,32,40,77,105,100,119,97,121,41,0,0,0,0,0,52,48,48,107,32,111,110,108,121,0,0,0,0,0,0,0,70,117,108,108,32,84,104,114,111,116,116,108,101,32,67,111,110,118,101,114,116,44,32,67,111,99,107,112,105,116,0,0,50,48,48,48,48,0,0,0,109,100,95,109,115,112,97,99,109,97,110,0,0,0,0,0,73,110,99,114,101,97,115,101,32,108,105,118,101,115,32,119,104,105,108,101,32,112,108,97,121,105,110,103,0,0,0,0,77,114,46,32,78,117,116,122,32,45,32,72,111,112,112,105,110,39,32,77,97,100,32,40,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,76,101,118,101,108,32,50,0,65,105,114,119,111,108,102,0,0,0,0,0,0,0,0,0,109,100,95,109,114,110,117,116,122,50,0,0,0,0,0,0,77,97,114,105,110,101,32,66,111,121,0,0,0,0,0,0,80,97,110,103,33,32,51,32,40,57,53,48,53,49,49,32,69,117,114,111,41,0,0,0,75,110,105,103,104,116,115,32,111,102,32,86,97,108,111,117,114,32,83,117,112,101,114,32,72,101,114,111,101,115,32,80,108,117,115,32,47,32,83,97,110,103,111,107,117,32,83,101,110,107,105,32,83,117,112,101,114,32,72,101,114,111,101,115,32,80,108,117,115,32,40,118,101,114,46,32,49,48,48,41,0,0,0,0,0,0,0,0,112,99,101,95,97,108,105,99,101,0,0,0,0,0,0,0,83,78,75,32,47,32,83,97,117,114,117,115,0,0,0,0,80,37,105,32,66,117,116,116,111,110,115,32,51,52,0,0,77,114,46,32,78,117,116,122,32,40,69,117,114,111,41,0,0,0,0,0,0,0,0,0,109,115,104,118,115,102,98,49,0,0,0,0,0,0,0,0,109,100,95,51,105,110,49,114,109,98,0,0,0,0,0,0,109,100,95,109,114,110,117,116,122,0,0,0,0,0,0,0,76,97,115,116,32,68,117,101,108,32,40,85,83,32,78,101,119,32,86,101,114,46,41,0,0,0,0,0,0,0,0,0,88,32,98,117,116,116,111,110,32,40,116,111,112,41,0,0,9,45,106,47,45,45,106,117,115,116,105,102,105,101,114,58,32,67,111,110,110,101,99,116,32,97,32,118,105,114,116,117,97,108,32,75,111,110,97,109,105,32,74,117,115,116,105,102,105,101,114,32,105,110,116,111,32,112,111,114,116,32,50,46,32,40,83,78,69,83,32,115,112,101,99,105,102,105,99,41,46,0,0,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,40,87,111,114,108,100,41,0,0,77,111,114,116,97,108,32,75,111,109,98,97,116,32,51,32,40,85,83,65,41,0,0,0,83,112,97,99,101,32,84,104,117,110,100,101,114,98,105,114,100,0,0,0,0,0,0,0,109,100,95,109,107,51,117,0,84,104,101,32,83,112,101,101,100,32,82,117,109,98,108,101,114,32,40,115,101,116,32,49,41,0,0,0,0,0,0,0,115,108,45,62,100,114,0,0,77,111,114,116,97,108,32,75,111,109,98,97,116,32,51,32,40,69,117,114,111,41,0,0,83,107,121,32,75,105,100,32,40,110,101,119,32,118,101,114,115,105,111,110,41,0,0,0,82,101,116,114,111,80,97,100,32,66,117,116,116,111,110,32,88,0,0,0,0,0,0,0,109,100,95,109,107,51,0,0,51,48,48,107,32,111,110,108,121,0,0,0,0,0,0,0,85,112,114,105,103,104,116,32,47,32,78,111,32,83,116,101,101,114,105,110,103,32,76,111,99,107,0,0,0,0,0,0,49,53,48,48,48,0,0,0,77,111,114,116,97,108,32,75,111,109,98,97,116,32,73,73,32,40,87,111,114,108,100,41,0,0,0,0,0,0,0,0,51,32,67,111,105,110,115,32,50,32,67,114,101,100,105,116,115,0,0,0,0,0,0,0,74,111,105,110,32,73,110,0,109,100,95,109,107,50,0,0,76,101,118,101,108,32,49,0,80,101,110,103,111,32,40,98,111,111,116,108,101,103,41,0,0,0,0,0,0,0,0,0,71,97,108,97,120,105,97,110,32,84,117,114,98,111,32,40,115,117,112,101,114,103,32,104,97,99,107,41,0,0,0,0,80,37,105,32,66,117,116,116,111,110,115,32,50,52,0,0,71,104,111,115,116,115,39,110,32,71,111,98,108,105,110,115,32,40,87,111,114,108,100,63,32,115,101,116,32,49,41,0,0,0,0,0,0,0,0,0,77,111,114,116,97,108,32,75,111,109,98,97,116,32,40,87,111,114,108,100,41,0,0,0,112,97,110,103,51,114,49,0,107,111,118,115,104,112,97,0,70,111,114,109,97,116,105,111,110,32,83,111,99,99,101,114,32,45,32,79,110,32,74,46,32,76,101,97,103,117,101,0,0,0,0,0,0,0,0,0,84,104,101,32,73,114,114,105,116,97,116,105,110,103,32,77,97,122,101,32,47,32,85,108,116,114,97,32,68,101,110,114,121,117,32,73,114,97,105,114,97,32,66,111,117,0,0,0,84,104,101,32,65,109,97,122,105,110,103,32,65,100,118,101,110,116,117,114,101,115,32,111,102,32,77,114,46,32,70,46,32,76,101,97,0,0,0,0,105,110,118,97,108,105,100,32,100,105,115,116,97,110,99,101,32,116,111,111,32,102,97,114,32,98,97,99,107,0,0,0,109,100,95,109,107,97,0,0,77,97,114,118,101,108,32,83,117,112,101,114,32,72,101,114,111,101,115,32,118,115,32,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,40,57,55,48,56,50,55,32,66,114,97,122,105,108,41,0,0,0,60,117,110,107,110,111,119,110,62,0,0,0,0,0,0,0,77,117,116,97,110,116,32,70,105,103,104,116,101,114,32,40,87,111,114,108,100,32,118,101,114,32,69,77,45,51,41,0,0,0,0,0,0,0,0,0,65,114,97,98,105,97,110,0,0,0,0,0,0,0,0,0,65,114,101,110,97,0,0,0,77,111,114,116,97,108,32,75,111,109,98,97,116,32,40,87,111,114,108,100,44,32,118,49,46,49,41,0,0,0,0,0,9,45,112,47,45,45,115,99,111,112,101,58,32,67,111,110,110,101,99,116,32,97,32,118,105,114,116,117,97,108,32,83,117,112,101,114,83,99,111,112,101,32,105,110,116,111,32,112,111,114,116,32,50,46,32,40,83,78,69,83,32,115,112,101,99,105,102,105,99,41,46,0,73,107,107,105,32,40,74,97,112,97,110,41,0,0,0,0,109,100,95,109,107,0,0,0,49,57,56,49,63,0,0,0,71,97,108,97,103,97,32,40,78,97,109,99,111,32,114,101,118,46,32,66,41,0,0,0,77,111,110,115,116,101,114,32,87,111,114,108,100,32,73,86,32,40,74,112,110,41,0,0,109,100,95,109,119,111,114,108,100,52,0,0,0,0,0,0,87,111,114,108,100,32,67,117,112,32,39,57,48,32,40,87,111,114,108,100,41,0,0,0,82,101,116,114,111,80,97,100,32,66,117,116,116,111,110,32,65,0,0,0,0,0,0,0,77,111,110,111,112,111,108,121,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,0,83,111,110,32,83,111,110,0,0,0,0,0,0,0,0,0,85,112,114,105,103,104,116,32,47,32,83,116,101,101,114,105,110,103,32,76,111,99,107,0,49,48,48,48,48,0,0,0,109,100,95,109,111,110,111,112,111,108,121,112,0,0,0,0,52,32,67,111,105,110,115,32,50,32,67,114,101,100,105,116,115,0,0,0,0,0,0,0,82,97,108,108,121,32,88,32,40,51,50,107,32,86,101,114,46,63,41,41,0,0,0,0,77,111,110,111,112,111,108,121,32,40,85,83,65,41,0,0,73,110,116,101,114,110,97,108,32,84,101,115,116,0,0,0,112,101,110,103,111,98,0,0,109,100,95,109,111,110,111,112,111,108,121,0,0,0,0,0,82,97,98,105,111,32,76,101,112,117,115,32,40,74,97,112,97,110,41,0,0,0,0,0,75,0,0,0,110,0,0,0,105,0,0,0,103,0,0,0,104,0,0,0,116,0,0,0,115,0,0,0,32,0,0,0,111,0,0,0,102,0,0,0,32,0,0,0,86,0,0,0,97,0,0,0,108,0,0,0,111,0,0,0,117,0,0,0,114,0,0,0,32,0,0,0,83,0,0,0,117,0,0,0,112,0,0,0,101,0,0,0,114,0,0,0,32,0,0,0,72,0,0,0,101,0,0,0,114,0,0,0,111,0,0,0,101,0,0,0,115,0,0,0,32,0,0,0,80,0,0,0,108,0,0,0,117,0,0,0,115,0,0,0,0,0,0,0,9,78,0,0,253,86,0,0,24,98,0,0,170,126,0,0,0,0,0,0,113,78,0,0,22,78,0,0,173,103,0,0,196,150,0,0,32,0,0,0,40,0,0,0,118,0,0,0,101,0,0,0,114,0,0,0,46,0,0,0,32,0,0,0,49,0,0,0,48,0,0,0,49,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,112,99,101,95,102,115,111,99,99,101,114,0,0,0,0,0,105,114,114,109,97,122,101,0,80,37,105,32,66,117,116,116,111,110,115,32,50,51,0,0,77,76,66,80,65,32,66,97,115,101,98,97,108,108,32,40,85,83,65,41,0,0,0,0,65,109,98,117,115,104,0,0,109,115,104,118,115,102,98,0,51,32,105,110,32,49,32,70,108,97,115,104,98,97,99,107,32,45,32,87,111,114,108,100,32,67,104,97,109,112,105,111,110,115,104,105,112,32,83,111,99,99,101,114,32,45,32,84,101,99,109,111,32,87,111,114,108,100,32,67,117,112,32,57,50,32,40,80,105,114,97,116,101,41,0,0,0,0,0,0,109,100,95,109,108,98,112,97,0,0,0,0,0,0,0,0,77,75,32,53,32,45,32,77,111,114,116,97,108,32,67,111,109,98,97,116,32,45,32,83,117,98,90,101,114,111,32,40,80,105,114,97,116,101,41,0,0,0,0,0,0,0,0,0,9,45,109,47,45,45,109,111,117,115,101,58,32,67,111,110,110,101,99,116,32,97,32,109,111,117,115,101,32,105,110,116,111,32,112,111,114,116,32,111,102,32,116,104,101,32,100,101,118,105,99,101,32,40,49,32,116,111,32,37,100,41,46,10,0,0,0,0,0,0,0,0,82,121,103,97,114,32,40,85,83,32,115,101,116,32,49,41,0,0,0,0,0,0,0,0,68,45,80,97,100,32,76,101,102,116,0,0,0,0,0,0,109,100,95,109,107,53,97,0,77,111,109,111,107,111,32,49,50,48,37,0,0,0,0,0,115,112,99,116,98,105,114,100,0,0,0,0,0,0,0,0,77,75,32,53,32,45,32,77,111,114,116,97,108,32,67,111,109,98,97,116,32,45,32,83,117,98,90,101,114,111,0,0,109,100,95,109,107,53,0,0,115,114,100,97,114,119,105,110,0,0,0,0,0,0,0,0,68,111,117,98,108,101,32,68,114,97,103,111,110,32,40,74,97,112,97,110,41,0,0,0,82,101,116,114,111,80,97,100,32,68,45,80,97,100,32,82,105,103,104,116,0,0,0,0,83,111,102,116,119,97,114,101,32,84,111,111,108,119,111,114,107,115,0,0,0,0,0,0,71,105,110,103,97,32,78,105,110,107,121,111,117,68,101,110,32,40,115,101,116,32,49,41,0,0,0,0,0,0,0,0,112,49,32,102,105,114,101,32,55,0,0,0,0,0,0,0,84,104,101,32,77,105,114,97,99,108,101,32,80,105,97,110,111,32,84,101,97,99,104,105,110,103,32,83,121,115,116,101,109,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,53,48,48,48,0,0,0,0,66,73,79,83,32,82,79,77,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,116,97,116,101,32,115,105,122,101,58,32,37,100,32,98,121,116,101,115,46,10,0,0,0,0,0,0,0,109,100,95,109,105,114,97,99,108,101,112,0,0,0,0,0,71,111,100,32,77,111,100,101,0,0,0,0,0,0,0,0,80,101,110,103,111,32,40,115,101,116,32,52,41,0,0,0,100,119,50,118,49,48,48,120,0,0,0,0,0,0,0,0,67,104,111,117,32,75,121,117,117,107,97,105,32,77,105,114,97,99,108,101,32,78,105,110,101,32,40,74,112,110,41,0,0,0,0,0,0,0,0,0,80,97,110,103,33,32,51,32,40,57,53,48,54,48,49,32,69,117,114,111,41,0,0,0,75,110,105,103,104,116,115,32,111,102,32,86,97,108,111,117,114,32,83,117,112,101,114,32,72,101,114,111,101,115,32,80,108,117,115,32,47,32,83,97,110,103,111,107,117,32,83,101,110,107,105,32,83,117,112,101,114,32,72,101,114,111,101,115,32,80,108,117,115,32,40,118,101,114,46,32,49,48,49,41,0,0,0,0,0,0,0,0,70,111,114,109,97,116,105,111,110,32,83,111,99,99,101,114,32,45,32,72,117,109,97,110,32,67,117,112,32,39,57,48,0,0,0,0,0,0,0,0,84,104,101,32,76,97,115,116,32,83,111,108,100,105,101,114,32,40,75,111,114,101,97,110,32,114,101,108,101,97,115,101,32,111,102,32,84,104,101,32,76,97,115,116,32,66,108,97,100,101,41,0,0,0,0,0,80,37,105,32,66,117,116,116,111,110,115,32,49,52,0,0,109,100,95,109,105,114,97,99,108,101,57,0,0,0,0,0,77,97,114,118,101,108,32,83,117,112,101,114,32,72,101,114,111,101,115,32,118,115,32,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,40,57,55,48,54,50,48,32,65,115,105,97,41,0,0,0,0,0,109,100,95,51,105,110,49,102,119,116,0,0,0,0,0,0,99,121,98,101,114,108,105,112,0,0,0,0,0,0,0,0,50,48,48,48,48,32,52,48,48,48,48,32,57,48,48,48,48,32,49,53,48,48,48,48,0,0,0,0,0,0,0,0,80,49,32,76,101,102,116,0,77,105,110,110,101,115,111,116,97,32,70,97,116,115,32,45,32,80,111,111,108,32,76,101,103,101,110,100,32,40,85,83,65,41,0,0,0,0,0,0,37,48,56,120,58,32,85,115,101,114,32,66,97,110,107,32,84,114,97,110,115,102,101,114,32,110,111,116,32,102,117,108,108,121,32,116,101,115,116,101,100,32,45,32,112,108,101,97,115,101,32,99,104,101,99,107,32,105,102,32,119,111,114,107,105,110,103,32,112,114,111,112,101,114,108,121,33,10,0,0,115,99,104,109,101,105,115,114,0,0,0,0,0,0,0,0,109,100,95,109,102,112,111,111,108,0,0,0,0,0,0,0,9,45,65,47,45,45,100,117,97,108,97,110,97,108,111,103,58,32,67,111,110,110,101,99,116,32,97,32,68,117,97,108,65,110,97,108,111,103,32,99,111,110,116,114,111,108,108,101,114,32,116,111,32,112,111,114,116,32,40,49,32,116,111,32,37,100,41,46,10,0,0,0,82,45,62,105,114,113,50,0,72,117,110,99,104,98,97,99,107,32,40,115,101,116,32,49,41,0,0,0,0,0,0,0,67,111,105,110,32,66,0,0,50,32,99,114,101,100,105,116,115,0,0,0,0,0,0,0,70,105,120,69,105,103,104,116,32,40,69,117,114,111,112,101,44,32,84,97,105,116,111,32,108,105,99,101,110,115,101,41,0,0,0,0,0,0,0,0,50,32,99,111,105,110,115,32,49,32,112,108,97,121,0,0,77,105,107,101,32,68,105,116,107,97,32,80,111,119,101,114,32,70,111,111,116,98,97,108,108,32,40,69,117,114,111,44,32,85,83,65,44,32,65,108,116,41,0,0,0,0,0,0,103,116,115,116,97,114,98,49,0,0,0,0,0,0,0,0,78,105,99,104,105,98,117,116,115,117,32,40,67,101,110,116,117,114,105,32,108,105,99,101,110,115,101,41,0,0,0,0,77,101,100,105,117,109,0,0,109,100,95,100,105,116,107,97,112,102,49,0,0,0,0,0,72,111,110,103,32,75,111,110,103,32,97,110,100,32,67,104,105,110,97,32,40,72,111,110,101,115,116,32,84,114,97,100,105,110,103,32,67,111,46,32,108,105,99,101,110,115,101,41,0,0,0,0,0,0,0,0,77,105,107,101,32,68,105,116,107,97,32,80,111,119,101,114,32,70,111,111,116,98,97,108,108,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,80,71,77,32,40,80,111,108,121,103,97,109,101,32,77,97,115,116,101,114,41,32,83,121,115,116,101,109,32,66,73,79,83,0,0,0,0,0,0,0,82,101,116,114,111,80,97,100,32,68,45,80,97,100,32,76,101,102,116,0,0,0,0,0,109,100,95,100,105,116,107,97,112,102,0,0,0,0,0,0,51,48,107,44,32,56,48,107,32,38,32,101,118,101,114,121,32,56,48,107,0,0,0,0,104,98,97,114,114,101,108,119,0,0,0,0,0,0,0,0,52,32,80,108,97,121,101,114,115,47,50,32,77,97,99,104,105,110,101,115,0,0,0,0,100,105,110,111,114,101,120,117,0,0,0,0,0,0,0,0,69,120,116,114,97,32,83,104,105,112,32,67,111,115,116,0,77,105,103,104,116,121,32,77,111,114,112,104,105,110,32,80,111,119,101,114,32,82,97,110,103,101,114,115,32,45,32,84,104,101,32,77,111,118,105,101,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,55,50,52,41,0,0,0,0,0,65,108,108,111,119,32,99,111,110,116,105,110,117,101,0,0,97,114,107,97,110,111,105,100,106,98,97,0,0,0,0,0,118,112,99,95,119,105,110,100,111,119,50,0,0,0,0,0,109,100,95,109,109,112,114,116,109,112,49,0,0,0,0,0,114,97,109,98,111,51,117,0,112,101,110,103,111,52,0,0,67,104,97,115,101,32,72,46,81,46,32,40,87,111,114,108,100,41,0,0,0,0,0,0,118,111,108,102,105,101,100,95,99,117,114,114,101,110,116,95,99,109,100,0,0,0,0,0,77,105,103,104,116,121,32,77,111,114,112,104,105,110,32,80,111,119,101,114,32,82,97,110,103,101,114,115,32,45,32,84,104,101,32,77,111,118,105,101,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,55,50,50,41,0,0,0,0,0,111,112,119,111,108,102,98,0,97,115,117,107,97,0,0,0,112,97,110,103,51,0,0,0,107,111,118,115,104,112,0,0,112,99,101,95,102,115,111,99,99,114,57,48,0,0,0,0,108,97,115,116,115,111,108,100,0,0,0,0,0,0,0,0,80,37,105,32,66,117,116,116,111,110,115,32,49,51,0,0,66,117,98,98,108,101,32,66,111,98,98,108,101,32,40,98,111,111,108,116,101,103,32,119,105,116,104,32,54,56,55,48,53,41,0,0,0,0,0,0,84,119,105,110,32,72,97,119,107,32,40,87,111,114,108,100,41,0,0,0,0,0,0,0,109,100,95,109,109,112,114,116,109,112,50,0,0,0,0,0,109,115,104,118,115,102,97,49,0,0,0,0,0,0,0,0,80,115,121,103,110,111,115,105,115,0,0,0,0,0,0,0,49,53,48,48,48,32,51,53,48,48,48,32,55,53,48,48,48,32,49,50,48,48,48,48,0,0,0,0,0,0,0,0,77,105,103,104,116,121,32,77,111,114,112,104,105,110,32,80,111,119,101,114,32,82,97,110,103,101,114,115,32,45,32,84,104,101,32,77,111,118,105,101,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,55,49,55,41,0,0,0,0,0,115,102,105,105,105,51,110,0,74,117,117,111,117,107,105,32,40,115,101,116,32,51,44,32,74,97,112,97,110,44,32,70,68,49,48,57,52,32,51,49,55,45,48,48,54,56,41,0,0,0,0,0,0,0,0,0,83,121,115,116,101,109,49,54,82,111,97,100,67,111,110,116,114,111,108,0,0,0,0,0,109,100,95,109,109,112,114,116,109,112,51,0,0,0,0,0,9,45,78,47,45,45,110,111,100,101,118,105,99,101,58,32,68,105,115,99,111,110,110,101,99,116,115,32,99,111,110,116,114,111,108,108,101,114,32,100,101,118,105,99,101,32,99,111,110,110,101,99,116,101,100,32,116,111,32,112,111,114,116,32,40,49,32,116,111,32,37,100,41,46,10,0,0,0,0,0,102,108,105,99,107,121,115,49,0,0,0,0,0,0,0,0,100,100,99,114,101,119,50,0,114,99,104,97,115,101,0,0,77,105,103,104,116,121,32,77,111,114,112,104,105,110,32,80,111,119,101,114,32,82,97,110,103,101,114,115,32,45,32,84,104,101,32,77,111,118,105,101,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,55,49,51,41,0,0,0,0,0,76,105,110,101,32,111,102,32,70,105,114,101,32,47,32,66,97,107,117,100,97,110,32,89,97,114,111,117,32,40,87,111,114,108,100,44,32,70,68,49,48,57,52,32,51,49,55,45,48,49,51,54,41,0,0,0,69,97,103,108,101,32,40,115,101,116,32,51,41,0,0,0,100,117,109,112,109,116,109,116,0,0,0,0,0,0,0,0,109,100,95,109,109,112,114,116,109,112,52,0,0,0,0,0,67,111,105,110,32,66,111,120,0,0,0,0,0,0,0,0,103,116,109,114,97,0,0,0,118,105,100,101,111,95,98,108,97,99,107,95,102,114,97,109,101,95,105,110,115,101,114,116,105,111,110,0,0,0,0,0,50,48,48,49,0,0,0,0,77,105,103,104,116,121,32,77,111,114,112,104,105,110,32,80,111,119,101,114,32,82,97,110,103,101,114,115,32,45,32,84,104,101,32,77,111,118,105,101,32,40,85,83,65,41,0,0,55,32,79,114,100,105,32,40,75,111,114,101,97,41,0,0,82,101,116,114,111,80,97,100,32,68,45,80,97,100,32,68,111,119,110,0,0,0,0,0,109,100,95,109,109,112,114,116,109,117,0,0,0,0,0,0,49,32,67,111,105,110,32,32,50,32,67,114,101,100,105,116,115,32,0,0,0,0,0,0,67,111,105,110,97,103,101,32,77,111,100,101,0,0,0,0,52,32,80,108,97,121,101,114,115,47,49,32,77,97,99,104,105,110,101,0,0,0,0,0,66,117,116,116,111,110,115,32,76,97,121,111,117,116,0,0,50,52,48,0,0,0,0,0,77,105,103,104,116,121,32,77,111,114,112,104,105,110,32,80,111,119,101,114,32,82,97,110,103,101,114,115,32,45,32,84,104,101,32,77,111,118,105,101,32,40,69,117,114,111,41,0,0,0,0,0,0,0,0,0,34,0,0,0,0,0,0,0,80,0,0,0,117,0,0,0,122,0,0,0,122,0,0,0,108,0,0,0,101,0,0,0,32,0,0,0,68,0,0,0,101,0,0,0,32,0,0,0,66,0,0,0,111,0,0,0,119,0,0,0,108,0,0,0,105,0,0,0,110,0,0,0,103,0,0,0,0,0,0,0,209,48,0,0,186,48,0,0,235,48,0,0,32,0,0,0,36,255,0,0,37,255,0,0,32,0,0,0,220,48,0,0,252,48,0,0,234,48,0,0,243,48,0,0,176,48,0,0,0,0,0,0,0,0,0,0,109,100,95,109,109,112,114,116,109,0,0,0,0,0,0,0,65,108,119,97,121,115,32,72,97,114,100,0,0,0,0,0,80,101,110,103,111,32,40,115,101,116,32,51,32,110,111,116,32,101,110,99,114,121,112,116,101,100,41,0,0,0,0,0,80,97,108,101,116,116,101,0,115,116,114,97,116,111,102,0,77,105,103,104,116,121,32,77,111,114,112,104,105,110,32,80,111,119,101,114,32,82,97,110,103,101,114,115,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,55,49,56,41,0,0,0,0,0,0,78,101,109,111,32,40,57,48,32,49,49,32,50,48,32,74,97,112,97,110,41,0,0,0,70,105,114,101,32,80,114,111,32,87,114,101,115,116,108,105,110,103,32,51,32,45,32,76,101,103,101,110,100,32,66,111,117,116,0,0,0,0,0,0,84,0,0,0,104,0,0,0,101,0,0,0,32,0,0,0,76,0,0,0,97,0,0,0,115,0,0,0,116,0,0,0,32,0,0,0,66,0,0,0,108,0,0,0,97,0,0,0,100,0,0,0,101,0,0,0,0,0,0,0,85,94,0,0,43,103,0,0,106,109,0,0,43,111,0,0,32,0,0,0,8,103,0,0,239,131,0,0,110,48,0,0,99,82,0,0,235,88,0,0,32,0,0,0,40,0,0,0,78,0,0,0,71,0,0,0,72,0,0,0,45,0,0,0,50,0,0,0,51,0,0,0,52,0,0,0,48,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,80,37,105,32,66,117,116,116,111,110,115,32,49,50,0,0,109,100,95,109,109,112,114,112,53,0,0,0,0,0,0,0,70,111,114,101,103,114,111,117,110,100,32,82,65,77,0,0,80,114,101,116,116,121,32,83,111,108,100,105,101,114,32,83,97,105,108,111,114,32,77,111,111,110,32,40,118,101,114,46,32,57,53,47,48,51,47,50,50,44,32,69,117,114,111,112,101,41,0,0,0,0,0,0,77,97,114,118,101,108,32,83,117,112,101,114,32,72,101,114,111,101,115,32,118,115,32,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,40,57,55,48,54,50,53,32,65,115,105,97,41,0,0,0,0,0,51,32,78,105,110,106,97,115,32,75,105,99,107,32,66,97,99,107,32,40,85,83,65,41,0,0,0,0,0,0,0,0,77,105,103,104,116,121,32,77,111,114,112,104,105,110,32,80,111,119,101,114,32,82,97,110,103,101,114,115,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,55,48,56,41,0,0,0,0,0,0,83,112,105,110,97,108,32,66,114,101,97,107,101,114,115,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,86,101,114,121,32,72,97,114,100,32,51,0,0,0,0,0,109,100,95,109,109,112,114,112,54,0,0,0,0,0,0,0,109,111,100,101,0,0,0,0,9,45,45,115,117,102,97,109,105,66,58,32,80,97,116,104,32,116,111,32,66,32,115,108,111,116,32,111,102,32,83,117,102,97,109,105,32,84,117,114,98,111,46,0,0,0,0,0,77,105,103,104,116,121,32,77,111,114,112,104,105,110,32,80,111,119,101,114,32,82,97,110,103,101,114,115,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,56,49,48,41,0,0,0,0,0,0,49,32,67,111,105,110,45,53,32,80,108,97,121,0,0,0,101,97,103,108,101,51,0,0,116,111,112,112,121,114,97,112,0,0,0,0,0,0,0,0,71,97,109,101,97,99,101,0,109,100,95,109,109,112,114,112,49,0,0,0,0,0,0,0,78,117,109,98,101,114,32,111,102,32,80,111,119,101,114,115,0,0,0,0,0,0,0,0,49,57,52,51,32,75,97,105,0,0,0,0,0,0,0,0,106,111,121,115,116,105,99,107,95,100,97,116,97,95,115,101,108,101,99,116,0,0,0,0,68,114,97,103,111,110,32,66,108,97,122,101,0,0,0,0,81,117,105,122,32,100,101,32,73,100,111,108,33,32,72,111,116,32,68,101,98,117,116,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,77,105,103,104,116,121,32,77,111,114,112,104,105,110,32,80,111,119,101,114,32,82,97,110,103,101,114,115,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,56,48,57,41,0,0,0,0,0,0,83,112,97,99,101,32,69,99,104,111,32,40,98,111,111,116,108,101,103,41,0,0,0,0,116,101,114,114,97,102,117,0,102,97,116,102,117,114,121,51,0,0,0,0,0,0,0,0,82,101,116,114,111,80,97,100,32,68,45,80,97,100,32,85,112,0,0,0,0,0,0,0,109,100,95,109,109,112,114,112,50,0,0,0,0,0,0,0,112,97,110,103,0,0,0,0,50,67,32,49,67,32,47,32,49,67,32,51,67,0,0,0,73,110,118,101,114,115,101,0,77,105,103,104,116,121,32,77,111,114,112,104,105,110,32,80,111,119,101,114,32,82,97,110,103,101,114,115,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,56,48,56,41,0,0,0,0,0,0,0,0,0,69,110,101,114,103,121,32,67,111,110,115,117,109,112,116,105,111,110,0,0,0,0,0,0,72,0,0,0,0,0,0,0,52,32,99,111,105,110,115,32,51,32,99,114,101,100,105,116,115,0,0,0,0,0,0,0,104,97,110,103,108,121,0,0,65,110,121,0,0,0,0,0,71,97,117,110,116,108,101,116,32,40,114,101,118,32,53,41,0,0,0,0,0,0,0,0,109,100,95,109,109,112,114,112,51,0,0,0,0,0,0,0,65,32,49,67,47,50,67,32,66,32,50,67,47,49,67,0,50,32,67,111,105,110,115,32,49,32,67,114,101,100,105,116,32,0,0,0,0,0,0,0,112,101,110,103,111,51,117,0,77,105,103,104,116,121,32,77,111,114,112,104,105,110,32,80,111,119,101,114,32,82,97,110,103,101,114,115,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,56,48,52,41,0,0,0,0,0,0,0,0,0,68,111,110,107,101,121,32,75,111,110,103,32,70,111,117,110,100,114,121,32,40,104,97,99,107,41,0,0,0,0,0,0,110,101,109,111,106,0,0,0,98,111,111,98,104,97,99,107,0,0,0,0,0,0,0,0,112,99,101,95,102,105,114,101,112,114,119,51,0,0,0,0,84,104,101,32,76,97,115,116,32,66,108,97,100,101,32,47,32,66,97,107,117,109,97,116,115,117,32,82,111,109,97,110,32,45,32,71,101,107,107,97,32,110,111,32,75,101,110,115,104,105,32,40,78,71,72,45,50,51,52,48,41,0,0,0,80,37,105,32,66,117,116,116,111,110,115,32,65,66,67,68,0,0,0,0,0,0,0,0,109,100,95,109,109,112,114,112,52,0,0,0,0,0,0,0,68,114,118,83,99,114,111,108,108,49,91,48,93,0,0,0,109,115,104,118,115,102,97,0,109,100,95,51,110,105,110,106,97,0,0,0,0,0,0,0,84,114,111,106,97,110,32,40,82,111,109,115,116,97,114,41,0,0,0,0,0,0,0,0,49,77,32,38,32,50,77,0,70,108,105,112,32,67,111,110,116,114,111,108,115,0,0,0,77,105,103,104,116,121,32,77,111,114,112,104,105,110,32,80,111,119,101,114,32,82,97,110,103,101,114,115,32,40,85,83,65,41,0,0,0,0,0,0,115,117,99,97,115,105,110,111,0,0,0,0,0,0,0,0,100,101,97,108,101,114,0,0,105,107,97,114,105,51,0,0,109,100,95,109,109,112,114,117,0,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,108,105,116,101,114,97,108,47,108,101,110,103,116,104,32,99,111,100,101,0,0,0,0,0,9,45,45,115,117,102,97,109,105,65,58,32,80,97,116,104,32,116,111,32,65,32,115,108,111,116,32,111,102,32,83,117,102,97,109,105,32,84,117,114,98,111,46,32,76,111,97,100,32,83,117,102,97,109,105,32,98,97,115,101,32,99,97,114,116,32,97,115,32,114,101,103,117,108,97,114,32,114,111,109,46,0,0,0,0,0,0,0,71,121,114,111,100,105,110,101,0,0,0,0,0,0,0,0,77,105,103,104,116,121,32,77,111,114,112,104,105,110,32,80,111,119,101,114,32,82,97,110,103,101,114,115,32,40,69,117,114,111,41,0,0,0,0,0,69,97,103,108,101,32,40,115,101,116,32,50,41,0,0,0,32,55,32,67,111,105,110,115,32,49,32,67,114,101,100,105,116,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,83,101,118,101,114,97,108,32,112,97,116,99,104,101,115,32,97,114,101,32,101,120,112,108,105,99,105,116,108,121,32,100,101,102,105,110,101,100,44,32,105,103,110,111,114,105,110,103,32,97,108,108,32,46,46,46,10,0,0,0,77,97,107,97,105,45,77,117,114,97,32,40,74,97,112,97,110,41,0,0,0,0,0,0,49,32,67,111,105,110,32,32,49,32,67,114,101,100,105,116,32,32,47,32,49,32,67,111,105,110,32,32,51,32,32,67,114,101,100,105,116,115,0,0,109,100,95,109,109,112,114,0,87,99,57,48,83,99,114,111,108,108,49,88,72,105,0,0,103,101,109,105,110,105,0,0,70,67,73,63,0,0,0,0,100,100,114,97,103,111,110,98,97,0,0,0,0,0,0,0,65,83,73,67,50,55,97,32,83,108,111,116,115,0,0,0,49,57,57,57,0,0,0,0,82,101,116,114,111,80,97,100,32,66,117,116,116,111,110,32,83,116,97,114,116,0,0,0,77,105,103,104,116,32,97,110,100,32,77,97,103,105,99,32,73,73,73,32,45,32,73,115,108,101,115,32,111,102,32,84,101,114,114,97,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,79,114,105,101,110,116,97,108,32,76,101,103,101,110,100,32,40,86,49,48,53,44,32,75,111,114,101,97,41,0,0,0,51,32,80,108,97,121,101,114,115,0,0,0,0,0,0,0,109,100,95,109,105,103,104,116,109,103,51,0,0,0,0,0,77,105,103,104,116,32,97,110,100,32,77,97,103,105,99,32,45,32,71,97,116,101,115,32,116,111,32,65,110,111,116,104,101,114,32,87,111,114,108,100,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,65,110,107,111,107,117,32,68,101,110,115,101,116,115,117,0,0,0,0,0,0,0,0,0,68,114,118,77,97,104,106,111,110,103,75,101,121,77,97,116,114,105,120,0,0,0,0,0,80,101,110,103,111,32,40,115,101,116,32,50,32,110,111,116,32,101,110,99,114,121,112,116,101,100,41,0,0,0,0,0,109,100,95,109,105,103,104,116,109,97,103,0,0,0,0,0,78,101,109,111,32,40,57,48,32,49,49,32,51,48,32,101,116,99,41,0,0,0,0,0,70,105,114,101,32,80,114,111,32,87,114,101,115,116,108,105,110,103,32,50,32,45,32,50,110,100,32,66,111,117,116,0,0,0,0,0,0,0,0,0,108,97,115,116,98,108,97,100,104,0,0,0,0,0,0,0,80,37,105,32,66,117,116,116,111,110,115,32,66,67,68,0,51,119,111,110,100,101,114,115,98,0,0,0,0,0,0,0,77,105,103,45,50,57,32,70,105,103,104,116,101,114,32,80,105,108,111,116,32,40,85,83,65,41,0,0,0,0,0,0,110,73,82,81,65,99,107,110,111,119,108,101,100,103,101,0,77,97,114,118,101,108,32,83,117,112,101,114,32,72,101,114,111,101,115,32,118,115,32,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,40,57,55,48,54,50,53,32,69,117,114,111,41,0,0,0,0,0,60,117,110,108,105,99,101,110,115,101,100,62,0,0,0,0,109,100,95,109,105,103,50,57,117,0,0,0,0,0,0,0,55,48,48,75,44,32,49,46,53,77,44,32,51,77,32,38,32,52,46,53,77,0,0,0,78,101,111,32,71,101,111,0,0,0,0,0,0,0,0,0,77,105,103,45,50,57,32,70,105,103,104,116,101,114,32,80,105,108,111,116,32,40,74,112,110,41,0,0,0,0,0,0,9,45,66,47,45,45,98,115,120,115,108,111,116,58,32,80,97,116,104,32,116,111,32,66,83,88,32,115,108,111,116,116,101,100,32,114,111,109,46,32,76,111,97,100,32,66,83,88,32,66,73,79,83,32,97,115,32,116,104,101,32,114,101,103,117,108,97,114,32,114,111,109,46,0,0,0,0,0,0,0,79,80,76,45,62,101,103,95,116,105,109,101,114,0,0,0,103,108,80,111,112,68,101,98,117,103,71,114,111,117,112,0,109,100,95,109,105,103,50,57,106,0,0,0,0,0,0,0,101,97,103,108,101,50,0,0,79,114,105,103,0,0,0,0,77,105,103,45,50,57,32,70,105,103,104,116,101,114,32,80,105,108,111,116,32,40,69,117,114,111,41,0,0,0,0,0,49,57,52,49,32,45,32,67,111,117,110,116,101,114,32,65,116,116,97,99,107,32,40,57,48,48,50,50,55,32,87,111,114,108,100,41,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,70,111,117,110,100,32,71,76,32,99,111,110,116,101,120,116,58,32,37,115,10,0,0,0,0,0,0,0,0,79,86,69,82,76,65,89,32,68,73,82,32,37,115,0,0,83,102,50,109,100,116,83,111,117,110,100,76,97,116,99,104,0,0,0,0,0,0,0,0,109,100,95,109,105,103,50,57,0,0,0,0,0,0,0,0,46,46,46,0,0,0,0,0,109,100,95,112,103,97,50,97,0,0,0,0,0,0,0,0,82,101,116,114,111,80,97,100,32,66,117,116,116,111,110,32,83,101,108,101,99,116,0,0,67,97,98,105,110,101,116,32,83,116,121,108,101,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,114,97,114,99,104,95,109,97,105,110,95,105,110,105,116,95,119,114,97,112,40,41,32,102,97,105,108,101,100,46,10,0,0,0,0,65,114,99,97,100,101,39,115,32,71,114,101,97,116,101,115,116,32,72,105,116,115,32,40,69,117,114,111,41,0,0,0,51,48,107,32,49,50,48,107,32,50,49,48,107,32,51,48,48,107,0,0,0,0,0,0,51,32,99,111,105,110,115,32,52,32,99,114,101,100,105,116,115,0,0,0,0,0,0,0,109,100,95,97,114,99,97,100])
.concat([101,103,104,0,0,0,0,0,80,108,97,121,101,114,32,67,111,117,110,116,0,0,0,0,68,114,118,68,105,97,108,50,0,0,0,0,0,0,0,0,116,101,120,116,117,114,101,0,112,101,110,103,111,50,117,0,71,114,97,100,105,117,115,32,73,73,32,45,32,71,79,70,69,82,32,110,111,32,89,97,98,111,117,32,40,74,97,112,97,110,32,79,108,100,32,118,101,114,46,41,0,0,0,0,77,105,100,110,105,103,104,116,32,82,101,115,105,115,116,97,110,99,101,32,40,74,112,110,41,0,0,0,0,0,0,0,110,101,109,111,0,0,0,0,112,99,101,95,102,105,114,101,112,114,119,50,0,0,0,0,84,0,0,0,104,0,0,0,101,0,0,0,32,0,0,0,76,0,0,0,97,0,0,0,115,0,0,0,116,0,0,0,32,0,0,0,66,0,0,0,108,0,0,0,97,0,0,0,100,0,0,0,101,0,0,0,0,0,0,0,85,94,0,0,43,103,0,0,106,109,0,0,43,111,0,0,32,0,0,0,8,103,0,0,239,131,0,0,110,48,0,0,99,82,0,0,235,88,0,0,32,0,0,0,40,0,0,0,78,0,0,0,71,0,0,0,77,0,0,0,45,0,0,0,50,0,0,0,51,0,0,0,52,0,0,0,48,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,80,37,105,32,66,117,116,116,111,110,115,32,65,67,68,0,111,118,101,114,108,97,121,37,117,95,100,101,115,99,37,117,0,0,0,0,0,0,0,0,109,100,95,109,105,100,114,101,115,106,0,0,0,0,0,0,109,115,104,118,115,102,0,0,49,54,32,90,104,97,110,103,32,77,97,32,74,105,97,110,103,32,40,67,104,105,41,0,0,0,0,0,0,0,0,0,116,109,110,116,50,112,111,0,81,117,105,122,32,70,49,32,49,45,50,32,70,105,110,105,115,104,32,40,74,97,112,97,110,41,0,0,0,0,0,0,108,100,114,117,110,97,0,0,55,48,48,75,32,38,32,49,46,53,77,0,0,0,0,0,77,105,100,110,105,103,104,116,32,82,101,115,105,115,116,97,110,99,101,32,40,85,83,65,41,0,0,0,0,0,0,0,68,117,105,110,116,114,111,110,105,99,0,0,0,0,0,0,84,105,109,101,32,67,111,117,110,116,32,68,111,119,110,0,75,0,0,0,97,0,0,0,105,0,0,0,116,0,0,0,101,0,0,0,105,0,0,0,32,0,0,0,68,0,0,0,97,0,0,0,105,0,0,0,115,0,0,0,101,0,0,0,110,0,0,0,115,0,0,0,111,0,0,0,117,0,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,109,119,0,0,94,149,0,0,89,39,0,0,98,38,0,0,78,137,0,0,0,0,0,0,0,0,0,0,68,114,97,103,111,110,32,66,114,101,101,100,32,40,77,56,49,32,80,67,66,32,118,101,114,115,105,111,110,41,0,0,109,100,95,109,105,100,114,101,115,0,0,0,0,0,0,0,9,45,98,47,45,45,98,115,120,58,32,80,97,116,104,32,116,111,32,66,83,88,32,114,111,109,46,32,76,111,97,100,32,66,83,88,32,66,73,79,83,32,97,115,32,116,104,101,32,114,101,103,117,108,97,114,32,114,111,109,46,0,0,0,77,105,99,114,111,32,77,97,99,104,105,110,101,115,32,77,105,108,105,116,97,114,121,32,40,69,117,114,111,44,32,74,45,67,97,114,116,41,0,0,109,100,95,109,105,99,114,111,109,109,0,0,0,0,0,0,77,105,99,114,111,32,77,97,99,104,105,110,101,115,32,50,32,45,32,84,117,114,98,111,32,84,111,117,114,110,97,109,101,110,116,32,40,69,117,114,111,44,32,74,45,67,97,114,116,44,32,65,108,116,41,0,0,0,0,0,0,0,0,0,107,111,102,57,57,0,0,0,82,101,116,114,111,80,97,100,32,66,117,116,116,111,110,32,89,0,0,0,0,0,0,0,109,100,95,109,105,99,114,111,109,99,50,97,0,0,0,0,83,101,112,97,114,97,116,101,0,0,0,0,0,0,0,0,68,105,102,102,105,99,117,108,116,121,32,50,32,40,111,116,104,101,114,32,99,97,114,115,41,0,0,0,0,0,0,0,77,105,99,114,111,32,77,97,99,104,105,110,101,115,32,84,117,114,98,111,32,84,111,117,114,110,97,109,101,110,116,32,57,54,32,40,69,117,114,111,44,32,74,45,67,97,114,116,41,0,0,0,0,0,0,0,51,48,107,32,49,48,48,107,32,49,55,48,107,32,50,52,48,107,0,0,0,0,0,0,109,100,95,109,105,99,114,111,109,57,54,97,0,0,0,0,84,117,109,98,108,101,98,50,77,117,115,105,99,73,115,80,108,97,121,105,110,103,0,0,68,114,118,68,105,97,108,49,0,0,0,0,0,0,0,0,80,101,110,103,111,32,40,115,101,116,32,50,41,0,0,0,77,105,99,114,111,32,77,97,99,104,105,110,101,115,32,40,67,97,110,41,0,0,0,0,67,104,105,107,105,32,67,104,105,107,105,32,66,111,121,115,32,40,57,48,48,54,49,57,32,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,70,105,114,101,32,80,114,111,32,87,114,101,115,116,108,105,110,103,32,45,32,67,111,109,98,105,110,97,116,105,111,110,32,84,97,103,0,0,0,0,84,104,101,32,76,97,115,116,32,66,108,97,100,101,32,47,32,66,97,107,117,109,97,116,115,117,32,82,111,109,97,110,32,45,32,71,101,107,107,97,32,110,111,32,75,101,110,115,104,105,32,40,78,71,77,45,50,51,52,48,41,0,0,0,80,37,105,32,66,117,116,116,111,110,115,32,65,66,68,0,109,100,95,109,105,99,114,111,109,97,99,99,0,0,0,0,77,97,114,118,101,108,32,83,117,112,101,114,32,72,101,114,111,101,115,32,40,57,53,49,48,50,52,32,85,83,65,41,0,0,0,0,0,0,0,0,53,48,48,75,32,38,32,49,77,0,0,0,0,0,0,0,77,105,99,114,111,32,77,97,99,104,105,110,101,115,32,40,69,117,114,111,44,32,85,83,65,44,32,65,108,116,32,50,41,0,0,0,0,0,0,0,109,100,95,109,105,99,114,111,109,97,99,98,0,0,0,0,9,45,103,47,45,45,103,97,109,101,98,111,121,58,32,80,97,116,104,32,116,111,32,71,97,109,101,98,111,121,32,82,79,77,46,32,76,111,97,100,32,83,117,112,101,114,71,97,109,101,66,111,121,32,97,115,32,116,104,101,32,114,101,103,117,108,97,114,32,114,111,109,46,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,82,101,115,101,116,116,105,110,103,32,103,97,109,101,46,10,0,0,0,0,0,77,105,99,114,111,32,77,97,99,104,105,110,101,115,32,40,69,117,114,111,44,32,85,83,65,44,32,65,108,116,41,0,0,0,0,0,0,0,0,0,69,97,103,108,101,32,40,115,101,116,32,49,41,0,0,0,71,97,108,70,108,105,112,83,99,114,101,101,110,89,0,0,109,100,95,109,105,99,114,111,109,97,99,97,0,0,0,0,77,105,99,107,101,121,39,115,32,85,108,116,105,109,97,116,101,32,67,104,97,108,108,101,110,103,101,32,40,85,83,65,41,0,0,0,0,0,0,0,110,66,73,79,83,0,0,0,82,101,116,114,111,80,97,100,32,66,117,116,116,111,110,32,66,0,0,0,0,0,0,0,109,100,95,109,105,99,107,101,121,117,99,0,0,0,0,0,117,80,68,52,57,57,48,65,0,0,0,0,0,0,0,0,67,111,109,98,105,110,101,100,0,0,0,0,0,0,0,0,68,105,102,102,105,99,117,108,116,121,32,49,32,40,116,105,109,101,47,115,112,101,101,100,41,0,0,0,0,0,0,0,77,105,99,107,101,121,32,77,97,110,105,97,32,45,32,84,104,101,32,84,105,109,101,108,101,115,115,32,65,100,118,101,110,116,117,114,101,115,32,111,102,32,77,105,99,107,101,121,32,77,111,117,115,101,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,0,0,0,70,114,101,101,112,108,97,121,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,70,105,108,101,32,67,82,67,32,100,105,102,102,101,114,115,32,102,114,111,109,32,90,73,80,32,67,82,67,46,32,70,105,108,101,58,32,48,120,37,120,44,32,90,73,80,58,32,48,120,37,120,46,10,0,0,0,0,0,0,110,65,101,114,111,102,103,116,90,56,48,66,97,110,107,0,109,100,95,109,109,97,110,105,97,117,112,0,0,0,0,0,53,32,58,32,49,0,0,0,84,117,109,98,108,101,98,50,77,117,115,105,99,66,97,110,107,0,0,0,0,0,0,0,68,114,118,68,105,97,108,91,49,93,0,0,0,0,0,0,112,101,110,103,111,50,0,0,80,37,105,32,66,117,116,116,111,110,115,32,65,66,67,0,77,105,99,107,101,121,32,77,97,110,105,97,32,45,32,84,104,101,32,84,105,109,101,108,101,115,115,32,65,100,118,101,110,116,117,114,101,115,32,111,102,32,77,105,99,107,101,121,32,77,111,117,115,101,32,40,85,83,65,41,0,0,0,0,99,104,105,107,105,106,0,0,112,99,101,95,102,105,114,101,112,114,111,119,0,0,0,0,109,100,95,109,109,97,110,105,97,117,0,0,0,0,0,0,109,100,95,49,54,122,104,97,110,0,0,0,0,0,0,0,109,115,104,117,0,0,0,0,77,105,99,107,101,121,32,77,97,110,105,97,32,45,32,84,104,101,32,84,105,109,101,108,101,115,115,32,65,100,118,101,110,116,117,114,101,115,32,111,102,32,77,105,99,107,101,121,32,77,111,117,115,101,32,40,74,112,110,41,0,0,0,0,103,108,71,101,116,80,114,111,103,114,97,109,66,105,110,97,114,121,79,69,83,0,0,0,109,100,95,109,109,97,110,105,97,106,0,0,0,0,0,0,9,9,77,117,108,116,105,112,108,101,32,99,111,110,102,105,103,115,32,97,114,101,32,100,101,108,105,109,105,116,101,100,32,98,121,32,39,44,39,46,0,0,0,0,0,0,0,0,77,105,99,107,101,121,32,77,97,110,105,97,32,45,32,84,104,101,32,84,105,109,101,108,101,115,115,32,65,100,118,101,110,116,117,114,101,115,32,111,102,32,77,105,99,107,101,121,32,77,111,117,115,101,32,40,69,117,114,111,41,0,0,0,101,97,103,108,101,0,0,0,109,100,95,109,109,97,110,105,97,0,0,0,0,0,0,0,77,105,99,104,97,101,108,32,74,97,99,107,115,111,110,39,115,32,77,111,111,110,119,97,108,107,101,114,32,40,87,111,114,108,100,41,0,0,0,0,115,108,45,62,97,114,0,0,109,100,95,109,119,97,108,107,49,0,0,0,0,0,0,0,108,97,115,116,98,108,100,50,0,0,0,0,0,0,0,0,87,65,82,78,73,78,71,33,32,66,117,116,116,111,110,32,117,110,97,99,99,111,117,110,116,101,100,32,102,111,114,58,32,91,37,115,93,46,10,0,117,110,107,110,111,119,110,32,99,111,109,112,114,101,115,115,105,111,110,32,109,101,116,104,111,100,0,0,0,0,0,0,67,114,101,100,105,116,115,0,78,105,116,114,111,0,0,0,77,105,99,104,97,101,108,32,74,97,99,107,115,111,110,39,115,32,77,111,111,110,119,97,108,107,101,114,32,40,87,111,114,108,100,44,32,82,101,118,46,32,65,41,0,0,0,0,50,32,99,111,105,110,115,32,53,32,99,114,101,100,105,116,115,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,71,76,93,58,32,70,97,105,108,101,100,32,116,111,32,112,97,114,115,101,32,71,76,83,76,32,115,104,97,100,101,114,46,10,0,0,0,0,0,0,0,0,109,100,95,109,119,97,108,107,0,0,0,0,0,0,0,0,84,117,109,98,108,101,98,50,77,117,115,105,99,67,111,109,109,97,110,100,0,0,0,0,68,114,118,68,105,97,108,91,48,93,0,0,0,0,0,0,80,101,110,103,111,32,40,115,101,116,32,49,32,114,101,118,32,99,41,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,69,77,83,67,82,73,80,84,69,78,47,69,71,76,93,58,32,65,116,116,101,109,112,116,101,100,32,116,111,32,114,101,45,105,110,105,116,105,97,108,105,122,101,32,100,114,105,118,101,114,46,10,0,0,0,0,0,0,0,0,103,97,108,116,117,114,98,111,0,0,0,0,0,0,0,0,77,101,103,97,32,84,119,105,110,115,32,40,99,104,105,107,105,32,99,104,105,107,105,32,98,111,121,115,32,57,48,48,54,49,57,32,101,116,99,41,0,0,0,0,0,0,0,0,70,105,110,97,108,32,83,111,108,100,105,101,114,32,40,83,112,101,99,105,97,108,32,86,101,114,115,105,111,110,41,0,0,0,0,0,0,0,0,0,75,105,110,103,32,111,102,32,71,108,97,100,105,97,116,111,114,32,80,108,117,115,32,40,84,104,101,32,75,105,110,103,32,111,102,32,70,105,103,104,116,101,114,115,32,39,57,55,32,98,111,111,116,108,101,103,41,0,0,0,0,0,0,0,80,37,105,32,66,117,116,116,111,110,115,32,67,68,0,0,77,101,116,97,108,32,70,97,110,103,115,32,40,74,112,110,41,0,0,0,0,0,0,0,49,54,32,84,111,110,32,40,74,112,110,44,32,71,97,109,101,32,110,111,32,75,97,110,100,117,109,101,32,77,101,103,97,67,68,32,82,105,112,41,0,0,0,0,0,0,0,0,77,97,114,118,101,108,32,83,117,112,101,114,32,72,101,114,111,101,115,32,40,57,53,49,48,50,52,32,74,97,112,97,110,41,0,0,0,0,0,0,109,117,116,97,110,116,102,51,0,0,0,0,0,0,0,0,109,100,95,109,101,116,97,108,102,110,103,0,0,0,0,0,77,101,114,99,115,32,40,69,117,114,111,44,32,85,83,65,41,32,126,32,83,101,110,106,111,117,32,110,111,32,79,111,107,97,109,105,32,73,73,32,40,74,112,110,41,0,0,0,9,45,45,97,112,112,101,110,100,99,111,110,102,105,103,58,32,69,120,116,114,97,32,99,111,110,102,105,103,32,102,105,108,101,115,32,97,114,101,32,108,111,97,100,101,100,32,105,110,44,32,97,110,100,32,116,97,107,101,32,112,114,105,111,114,105,116,121,32,111,118,101,114,32,99,111,110,102,105,103,32,115,101,108,101,99,116,101,100,32,105,110,32,45,99,32,40,111,114,32,100,101,102,97,117,108,116,41,46,0,0,0,111,115,109,97,110,0,0,0,109,100,95,109,101,114,99,115,0,0,0,0,0,0,0,0,83,117,98,69,108,101,99,116,114,111,0,0,0,0,0,0,77,101,110,103,32,72,117,97,110,32,83,104,117,105,32,71,117,111,32,80,97,110,32,45,32,55,55,55,32,67,97,115,105,110,111,32,40,67,104,105,41,0,0,0,0,0,0,0,109,100,95,109,101,110,103,104,117,0,0,0,0,0,0,0,49,57,52,49,0,0,0,0,103,108,0,0,0,0,0,0,37,115,32,45,32,104,97,115,32,110,83,119,105,116,99,104,46,110,67,111,100,101,58,32,37,120,46,10,0,0,0,0,77,101,110,97,99,101,114,32,54,45,71,97,109,101,32,67,97,114,116,114,105,100,103,101,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,82,101,103,97,105,110,32,80,111,119,101,114,0,0,0,0,82,101,118,101,114,115,101,0,109,100,95,109,101,110,97,99,101,114,0,0,0,0,0,0,37,115,10,37,115,10,37,115,10,0,0,0,0,0,0,0,77,101,103,97,80,97,110,101,108,32,40,74,112,110,41,0,0,0,0,0,0,0,0,0,68,114,118,68,105,97,108,83,101,108,101,99,116,101,100,0,112,101,110,103,111,0,0,0,109,100,95,109,101,103,97,112,97,110,108,0,0,0,0,0,109,116,119,105,110,115,0,0,112,99,101,95,102,105,110,97,108,115,111,108,115,0,0,0,107,111,103,112,108,117,115,0,80,37,105,32,66,117,116,116,111,110,115,32,66,68,0,0,77,101,103,97,77,105,110,100,32,40,74,112,110,44,32,83,101,103,97,78,101,116,41,0,0,0,0,0,0,0,0,0,109,100,95,49,54,116,111,110,103,110,107,0,0,0,0,0,109,115,104,106,114,49,0,0,67,111,110,116,105,110,117,111,117,115,32,80,108,97,121,0,109,100,95,109,101,103,97,109,105,110,100,0,0,0,0,0,67,79,82,69,32,83,69,76,69,67,84,73,79,78,32,37,115,0,0,0,0,0,0,0,84,121,114,97,110,116,115,32,45,32,70,105,103,104,116,32,116,104,114,111,117,103,104,32,84,105,109,101,32,40,85,83,65,41,0,0,0,0,0,0,9,45,99,47,45,45,99,111,110,102,105,103,58,32,80,97,116,104,32,102,111,114,32,99,111,110,102,105,103,32,102,105,108,101,46,10,9,9,66,121,32,100,101,102,97,117,108,116,32,108,111,111,107,115,32,102,111,114,32,99,111,110,102,105,103,32,105,110,32,36,88,68,71,95,67,79,78,70,73,71,95,72,79,77,69,47,114,101,116,114,111,97,114,99,104,47,114,101,116,114,111,97,114,99,104,46,99,102,103,44,10,9,9,36,72,79,77,69,47,46,99,111,110,102,105,103,47,114,101,116,114,111,97,114,99,104,47,114,101,116,114,111,97,114,99,104,46,99,102,103,44,10,9,9,97,110,100,32,36,72,79,77,69,47,46,114,101,116,114,111,97,114,99,104,46,99,102,103,46,10,9,9,73,102,32,97,32,100,101,102,97,117,108,116,32,99,111,110,102,105,103,32,105,115,32,110,111,116,32,102,111,117,110,100,44,32,82,101,116,114,111,65,114,99,104,32,119,105,108,108,32,97,116,116,101,109,112,116,32,116,111,32,99,114,101,97,116,101,32,111,110,101,32,98,97,115,101,100,32,111,110,32,116,104,101,32,115,107,101,108,101,116,111,110,32,99,111,110,102,105,103,32,40,47,101,116,99,47,114,101,116,114,111,97,114,99,104,46,99,102,103,41,46,0,68,45,80,97,100,32,68,111,119,110,0,0,0,0,0,0,109,100,95,116,121,114,97,110,116,0,0,0,0,0,0,0,83,102,50,109,100,116,90,56,48,82,97,109,0,0,0,0,70,97,110,116,97,122,105,97,32,40,98,111,111,116,108,101,103,63,41,0,0,0,0,0,77,101,103,97,45,76,111,45,77,97,110,105,97,32,40,74,112,110,41,0,0,0,0,0,109,100,95,109,101,103,97,108,111,106,0,0,0,0,0,0,107,111,102,57,56,0,0,0,37,115,32,45,32,97,115,115,105,103,110,101,100,32,116,111,32,107,101,121,58,32,37,115,44,32,112,111,114,116,58,32,37,100,46,10,0,0,0,0,77,101,103,97,45,76,111,45,77,97,110,105,97,32,40,70,114,97,41,0,0,0,0,0,80,111,119,101,114,45,85,112,32,66,111,110,117,115,0,0,80,108,97,121,101,114,32,84,114,117,99,107,0,0,0,0,84,101,116,114,105,115,32,84,117,114,98,111,0,0,0,0,109,100,95,109,101,103,97,108,111,102,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,97,118,101,100,32,115,104,97,100,101,114,32,112,114,101,115,101,116,32,116,111,32,37,115,46,10,0,0,82,97,109,71,102,120,66,97,110,107,0,0,0,0,0,0,77,101,103,97,45,76,111,45,77,97,110,105,97,32,40,69,117,114,111,41,0,0,0,0,68,114,118,84,105,108,101,66,97,110,107,0,0,0,0,0,68,114,118,73,110,112,117,116,53,84,111,103,103,108,101,0,77,97,109,97,32,84,111,112,0,0,0,0,0,0,0,0,109,100,95,109,101,103,97,108,111,49,0,0,0,0,0,0,77,97,103,105,99,32,83,119,111,114,100,32,45,32,104,101,114,111,105,99,32,102,97,110,116,97,115,121,32,40,50,53,46,48,55,46,49,57,57,48,32,85,83,65,41,0,0,0,70,105,110,97,108,32,83,111,108,100,105,101,114,0,0,0,75,105,110,103,32,111,102,32,71,108,97,100,105,97,116,111,114,32,40,84,104,101,32,75,105,110,103,32,111,102,32,70,105,103,104,116,101,114,115,32,39,57,55,32,98,111,111,116,108,101,103,41,0,0,0,0,80,37,105,32,66,117,116,116,111,110,115,32,66,67,0,0,77,101,103,97,45,76,111,45,77,97,110,105,97,32,40,69,117,114,111,44,32,118,49,46,49,41,0,0,0,0,0,0,75,48,53,49,57,54,48,82,101,97,100,82,111,109,115,0,49,54,32,84,111,110,32,40,74,112,110,44,32,83,101,103,97,78,101,116,41,0,0,0,77,97,114,118,101,108,32,83,117,112,101,114,32,72,101,114,111,101,115,32,40,57,53,49,49,49,55,32,74,97,112,97,110,41,0,0,0,0,0,0,75,48,53,50,49,48,57,83,99,114,111,108,108,88,91,49,93,0,0,0,0,0,0,0,80,49,32,68,111,119,110,0,109,100,95,109,101,103,97,108,111,0,0,0,0,0,0,0,37,48,56,120,58,32,67,111,45,80,114,111,99,101,115,115,101,114,32,68,97,116,97,32,84,114,97,110,115,102,101,114,32,101,120,101,99,117,116,101,100,44,32,98,117,116,32,110,111,32,87,82,73,84,69,32,99,97,108,108,98,97,99,107,32,100,101,102,105,110,101,100,33,10,0,0,0,0,0,0,77,101,103,97,32,84,117,114,114,105,99,97,110,32,40,85,83,65,41,0,0,0,0,0,68,97,114,107,32,83,101,97,108,32,50,32,40,74,97,112,97,110,32,118,50,46,49,41,0,0,0,0,0,0,0,0,9,45,83,47,45,45,115,97,118,101,115,116,97,116,101,58,32,80,97,116,104,32,116,111,32,117,115,101,32,102,111,114,32,115,97,118,101,32,115,116,97,116,101,115,46,32,73,102,32,110,111,116,32,115,101,108,101,99,116,101,100,44,32,42,46,115,116,97,116,101,32,119,105,108,108,32,98,101,32,97,115,115,117,109,101,100,46,0,82,45,62,112,101,110,100,105,110,103,95,116,99,115,114,0,67,114,105,109,101,32,70,105,103,104,116,101,114,115,32,40,85,83,32,52,32,112,108,97,121,101,114,115,41,0,0,0,49,57,56,51,0,0,0,0,52,32,99,111,105,110,32,49,9,32,112,108,97,121,0,0,49,32,99,114,101,100,105,116,0,0,0,0,0,0,0,0,102,105,120,101,105,103,104,116,116,0,0,0,0,0,0,0,49,32,99,111,105,110,32,50,32,112,108,97,121,115,0,0,109,100,95,109,101,103,97,116,117,114,114,117,0,0,0,0,71,101,116,32,83,116,97,114,32,40,98,111,111,116,108,101,103,44,32,115,101,116,32,50,41,0,0,0,0,0,0,0,49,32,67,111,105,110,32,32,50,32,67,114,101,100,105,116,115,0,0,0,0,0,0,0,102,97,110,116,97,122,105,97,0,0,0,0,0,0,0,0,72,97,117,110,116,101,100,32,67,97,115,116,108,101,32,40,118,101,114,46,32,77,41,0,0,0,0,0,0,0,0,0,77,101,103,97,32,84,117,114,114,105,99,97,110,32,40,69,117,114,111,41,0,0,0,0,85,83,65,32,40,82,111,109,115,116,97,114,32,108,105,99,101,110,115,101,41,0,0,0,109,100,95,109,101,103,97,116,117,114,114,0,0,0,0,0,49,48,48,75,32,97,110,100,32,50,53,48,75,0,0,0,50,32,99,111,105,110,32,51,32,112,108,97,121,0,0,0,84,104,101,32,77,97,105,110,32,69,118,101,110,116,32,40,52,32,80,108,97,121,101,114,115,32,118,101,114,46,32,89,41,0,0,0,0,0,0,0,97,118,115,112,0,0,0,0,77,101,103,97,32,83,87,73,86,32,40,69,117,114,111,44,32,80,105,114,97,116,101,41,0,0,0,0,0,0,0,0,72,101,97,118,121,32,66,97,114,114,101,108,32,40,85,83,41,0,0,0,0,0,0,0,75,111,110,97,109,105,32,84,101,115,116,32,66,111,97,114,100,32,40,71,88,56,48,48,44,32,74,97,112,97,110,41,0,0,0,0,0,0,0,0,77,117,108,116,105,45,109,97,99,104,105,110,101,32,104,111,111,107,117,112,0,0,0,0,68,105,110,111,32,82,101,120,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,84,101,116,114,105,115,32,73,73,32,40,66,108,111,120,41,0,0,0,0,0,0,0,0,109,100,95,109,101,103,97,115,119,105,118,98,0,0,0,0,65,114,107,97,110,111,105,100,32,45,32,82,101,118,101,110,103,101,32,111,102,32,68,79,72,32,40,74,97,112,97,110,32,98,111,111,116,108,101,103,41,0,0,0,0,0,0,0,49,32,99,111,105,110,32,55,32,99,114,101,100,105,116,115,0,0,0,0,0,0,0,0,98,111,111,116,108,101,103,32,40,66,101,116,97,41,0,0,65,108,105,101,110,115,32,40,87,111,114,108,100,32,115,101,116,32,49,41,0,0,0,0,118,112,99,95,119,105,110,100,111,119,49,0,0,0,0,0,77,101,103,97,32,83,87,73,86,32,40,69,117,114,111,41,0,0,0,0,0,0,0,0,49,32,58,32,51,0,0,0,68,114,118,90,56,48,66,97,110,107,0,0,0,0,0,0,84,97,105,116,111,32,69,117,114,111,112,101,32,67,111,114,112,111,114,97,116,105,111,110,0,0,0,0,0,0,0,0,66,105,114,100,105,121,0,0,118,111,108,102,105,101,100,95,99,99,95,112,111,114,116,0,109,100,95,109,101,103,97,115,119,105,118,0,0,0,0,0,71,114,101,101,110,32,66,101,114,101,116,0,0,0,0,0,228,83,0,0,202,78,0,0,113,103,0,0,127,137,0,0,114,94,0,0,47,101,0,0,105,114,0,0,158,138,0,0,0,0,0,0,75,0,0,0,111,0,0,0,107,0,0,0,111,0,0,0,110,0,0,0,116,0,0,0,111,0,0,0,117,0,0,0,122,0,0,0,97,0,0,0,105,0,0,0,32,0,0,0,69,0,0,0,116,0,0,0,111,0,0,0,32,0,0,0,77,0,0,0,111,0,0,0,110,0,0,0,111,0,0,0,103,0,0,0,97,0,0,0,116,0,0,0,97,0,0,0,114,0,0,0,105,0,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,73,110,99,111,109,112,108,101,116,101,32,68,117,109,112,0,109,115,119,111,114,100,117,0,112,99,101,95,102,105,110,97,108,115,111,108,0,0,0,0,107,111,103,0,0,0,0,0,80,37,105,32,66,117,116,116,111,110,115,32,65,68,0,0,98,117,98,54,56,55,48,53,0,0,0,0,0,0,0,0,116,119,105,110,104,97,119,107,0,0,0,0,0,0,0,0,82,111,99,107,109,97,110,32,77,101,103,97,32,87,111,114,108,100,32,40,74,112,110,44,32,65,108,116,41,0,0,0,86,105,116,97,108,105,116,121,32,82,101,99,111,118,101,114,121,0,0,0,0,0,0,0,109,100,95,49,54,116,111,110,0,0,0,0,0,0,0,0,109,115,104,106,0,0,0,0,115,104,97,110,103,111,110,108,101,0,0,0,0,0,0,0,80,97,114,111,100,105,117,115,32,68,65,33,32,40,87,111,114,108,100,44,32,115,101,116,32,49,41,0,0,0,0,0,109,100,95,114,111,99,107,109,97,110,49,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,73,32,51,114,100,32,83,116,114,105,107,101,58,32,70,105,103,104,116,32,102,111,114,32,116,104,101,32,70,117,116,117,114,101,32,40,85,83,65,32,57,57,48,54,48,56,41,0,0,0,0,0,0,0,0,97,108,116,98,101,97,115,116,106,51,0,0,0,0,0,0,114,103,117,105,46,103,108,115,108,112,0,0,0,0,0,0,110,67,121,99,108,101,115,83,101,103,109,101,110,116,0,0,82,111,99,107,109,97,110,32,77,101,103,97,32,87,111,114,108,100,32,40,74,112,110,41,0,0,0,0,0,0,0,0,9,45,102,47,45,45,102,117,108,108,115,99,114,101,101,110,58,32,83,116,97,114,116,32,82,101,116,114,111,65,114,99,104,32,105,110,32,102,117,108,108,115,99,114,101,101,110,32,114,101,103,97,114,100,108,101,115,115,32,111,102,32,99,111,110,102,105,103,32,115,101,116,116,105,110,103,115,46,0,0,85,108,116,114,97,109,97,110,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,70,108,105,99,107,121,32,40,49,50,56,107,32,86,101,114,115,105,111,110,44,32,83,121,115,116,101,109,32,50,44,32,51,49,53,45,53,48,53,49,44,32,97,108,116,32,103,114,97,112,104,105,99,115,41,0,0,0,0,0,0,0,0,0,100,105,115,112,108,97,121,95,110,97,109,101,0,0,0,0,68,46,32,68,46,32,67,114,101,119,32,40,115,101,116,32,49,44,32,87,111,114,108,100,44,32,52,32,80,108,97,121,101,114,115,44,32,70,68,49,48,57,52,32,51,49,55,45,63,41,0,0,0,0,0,0,80,111,119,101,114,32,68,114,105,102,116,32,40,74,97,112,97,110,41,0,0,0,0,0,109,100,95,114,111,99,107,109,97,110,0,0,0,0,0,0,83,71,45,70,108,111,114,101,110,99,101,0,0,0,0,0,86,100,112,65,100,100,114,101,115,115,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,73,78,67,32,112,97,114,97,109,115,32,40,37,117,32,112,104,97,115,101,32,98,105,116,115,44,32,37,117,32,116,97,112,115,41,46,10,0,0,0,0,0,0,0,66,111,116,116,111,109,32,111,102,32,116,104,101,32,78,105,110,116,104,32,40,118,101,114,46,32,84,41,0,0,0,0,66,111,100,121,32,83,108,97,109,32,40,56,55,53,49,32,51,49,55,45,48,48,49,53,41,0,0,0,0,0,0,0,77,101,103,97,32,77,97,110,32,45,32,84,104,101,32,87,105,108,121,32,87,97,114,115,32,40,69,117,114,111,41,0,0,0,0,0,0,0,0,0,49,48,48,48,32,77,105,103,108,105,97,58,32,71,114,101,97,116,32,49,48,48,48,32,77,105,108,101,115,32,82,97,108,108,121,32,40,57,52,47,48,55,47,49,56,41,0,0,118,105,100,101,111,95,104,97,114,100,95,115,121,110,99,95,102,114,97,109,101,115,0,0,115,119,97,116,112,111,108,99,0,0,0,0,0,0,0,0,72,101,120,105,111,110,32,40,74,97,112,97,110,32,118,101,114,46,32,74,65,66,41,0,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,82,80,78,71,93,58,32,85,115,105,110,103,32,82,80,78,71,32,108,111,97,100,101,114,46,10,0,0,109,100,95,109,101,103,97,109,97,110,0,0,0,0,0,0,50,32,67,111,105,110,115,32,116,111,32,83,116,97,114,116,44,32,49,32,116,111,32,67,111,110,116,105,110,117,101,0,50,48,48,50,0,0,0,0,109,115,108,117,103,50,0,0,110,101,111,103,101,111,0,0,77,101,103,97,32,71,97,109,101,115,32,49,48,32,40,66,114,97,41,0,0,0,0,0,49,32,67,111,105,110,32,32,49,32,67,114,101,100,105,116,115,32,0,0,0,0,0,0,86,101,114,121,32,70,97,115,116,0,0,0,0,0,0,0,73,110,118,101,114,116,101,100,0,0,0,0,0,0,0,0,68,97,114,105,117,115,67,111,105,110,87,111,114,100,0,0,83,117,112,101,114,32,67,111,110,116,114,97,0,0,0,0,84,101,116,114,105,115,0,0,109,100,95,109,101,103,97,103,97,49,48,0,0,0,0,0,109,97,99,114,111,115,115,50,0,0,0,0,0,0,0,0,99,98,97,110,107,0,0,0,33,33,33,32,35,105,110,99,108,117,100,101,32,100,101,112,116,104,32,101,120,99,101,101,100,101,100,32,102,111,114,32,99,111,110,102,105,103,46,32,77,105,103,104,116,32,98,101,32,97,32,99,121,99,108,101,46,10,0,0,0,0,0,0,56,32,40,72,97,114,100,101,115,116,41,0,0,0,0,0,77,111,103,117,114,97,32,68,101,115,115,101,0,0,0,0,78,105,104,111,110,32,83,121,115,116,101,109,32,47,32,77,111,115,115,0,0,0,0,0,77,101,103,97,32,71,97,109,101,115,32,54,32,86,111,108,46,32,50,32,40,69,117,114,111,41,0,0,0,0,0,0,73,110,32,71,97,109,101,32,68,101,102,97,117,108,116,0,50,32,58,32,52,0,0,0,80,50,32,70,108,105,112,32,70,108,111,112,0,0,0,0,98,105,114,100,105,121,0,0,84,101,99,109,111,32,75,110,105,103,104,116,0,0,0,0,109,100,95,109,101,103,97,103,97,54,50,0,0,0,0,0,39,56,56,32,71,97,109,101,115,0,0,0,0,0,0,0,109,105,115,115,119,57,54,0,77,0,0,0,97,0,0,0,103,0,0,0,105,0,0,0,99,0,0,0,32,0,0,0,83,0,0,0,119,0,0,0,111,0,0,0,114,0,0,0,100,0,0,0,32,0,0,0,40,0,0,0,50,0,0,0,51,0,0,0,46,0,0,0,48,0,0,0,54,0,0,0,46,0,0,0,49,0,0,0,57,0,0,0,57,0,0,0,48,0,0,0,32,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,77,0,0,0,97,0,0,0,103,0,0,0,105,0,0,0,99,0,0,0,32,0,0,0,83,0,0,0,119,0,0,0,111,0,0,0,114,0,0,0,100,0,0,0,222,48,0,0,184,48,0,0,195,48,0,0,175,48,0,0,101,255,0,0,189,48,0,0,252,48,0,0,201,48,0,0,0,0,0,0,0,0,0,0,70,105,110,97,108,32,77,97,116,99,104,32,84,101,110,110,105,115,0,0,0,0,0,0,80,37,105,32,66,117,116,116,111,110,115,32,65,67,0,0,77,101,103,97,32,71,97,109,101,115,32,54,32,86,111,108,46,32,49,32,40,69,117,114,111,41,0,0,0,0,0,0,83,108,105,100,101,32,83,104,111,119,0,0,0,0,0,0,77,105,100,103,114,111,117,110,100,32,83,99,114,111,108,108,32,82,65,77,0,0,0,0,115,97,105,108,111,114,109,110,111,0,0,0,0,0,0,0,66,66,68,0,0,0,0,0,77,97,114,118,101,108,32,83,117,112,101,114,32,72,101,114,111,101,115,32,40,57,53,49,49,49,55,32,72,105,115,112,97,110,105,99,41,0,0,0,65,106,97,120,0,0,0,0,109,100,95,109,101,103,97,103,97,54,49,0,0,0,0,0,115,112,105,110,108,98,114,107,106,0,0,0,0,0,0,0,86,101,114,121,32,72,97,114,100,32,50,0,0,0,0,0,84,104,101,32,67,111,109,98,97,116,114,105,98,101,115,32,40,98,111,111,116,108,101,103,32,115,101,116,32,50,41,0,0,0,0,0,0,0,0,0,82,111,108,108,101,114,103,97,109,101,115,32,40,85,83,41,0,0,0,0,0,0,0,0,77,101,103,97,32,71,97,109,101,115,32,51,32,40,69,117,114,111,44,32,65,115,105,97,41,0,0,0,0,0,0,0,9,45,115,47,45,45,115,97,118,101,58,32,80,97,116,104,32,102,111,114,32,115,97,118,101,32,102,105,108,101,32,40,42,46,115,114,109,41,46,0,109,100,95,109,101,103,97,103,97,51,0,0,0,0,0,0,115,116,103,0,0,0,0,0,115,116,97,116,117,115,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,97,110,110,111,116,32,102,105,110,100,32,105,110,112,117,116,32,100,114,105,118,101,114,46,32,69,120,105,116,105,110,103,32,46,46,46,10,0,0,0,0,0,49,32,67,111,105,110,45,52,32,80,108,97,121,0,0,0,77,111,111,110,32,67,114,101,115,116,0,0,0,0,0,0,67,111,110,116,114,97,32,40,85,83,44,32,83,101,116,32,49,41,0,0,0,0,0,0,88,69,83,83,32,45,32,84,104,101,32,78,101,119,32,82,101,118,111,108,117,116,105,111,110,32,40,83,101,109,105,67,111,109,32,51,45,105,110,45,49,41,0,0,0,0,0,0,75,48,53,51,50,53,49,80,97,108,73,110,100,101,120,91,49,93,0,0,0,0,0,0,83,117,112,101,114,32,84,114,105,111,0,0,0,0,0,0,77,101,103,97,32,71,97,109,101,115,32,50,32,40,69,117,114,111,41,0,0,0,0,0,115,49,57,52,53,0,0,0,104,111,116,100,101,98,117,116,0,0,0,0,0,0,0,0,49,67,32,54,67,0,0,0,109,100,95,109,101,103,97,103,97,50,0,0,0,0,0,0,88,45,77,101,110,32,40,52,32,80,108,97,121,101,114,115,32,118,101,114,32,85,66,66,41,0,0,0,0,0,0,0,75,48,53,49,51,49,54,87,114,97,112,91,48,93,0,0,115,112,97,99,101,99,104,111,0,0,0,0,0,0,0,0,105,109,112,101,114,102,101,99,116,32,103,114,97,112,104,105,99,115,0,0,0,0,0,0,49,57,57,56,0,0,0,0,80,50,32,66,117,116,116,111,110,32,54,0,0,0,0,0,77,101,103,97,32,71,97,109,101,115,32,73,32,40,69,117,114,111,41,0,0,0,0,0,68,111,107,97,98,101,110,0,50,67,32,49,67,32,47,32,50,67,32,49,67,0,0,0,105,111,115,95,98,97,115,101,58,58,99,108,101,97,114,0,83,117,114,112,114,105,115,101,32,65,116,116,97,99,107,32,40,87,111,114,108,100,32,118,101,114,46,32,75,41,0,0,71,101,97,114,32,83,104,105,102,116,0,0,0,0,0,0,68,97,114,105,117,115,78,109,105,69,110,97,98,108,101,0,71,97,109,101,32,83,101,108,101,99,116,0,0,0,0,0,79,112,101,110,105,110,103,32,67,117,116,0,0,0,0,0,75,48,53,51,50,52,52,32,82,101,103,105,115,116,101,114,115,0,0,0,0,0,0,0,109,100,95,109,101,103,97,103,97,49,0,0,0,0,0,0,51,47,52,0,0,0,0,0,71,0,0,0,0,0,0,0,80,97,99,45,77,97,110,32,40,77,105,100,119,97,121,44,32,119,105,116,104,32,115,112,101,101,100,117,112,32,104,97,99,107,41,0,0,0,0,0,49,32,67,111,105,110,32,49,32,67,114,101,100,105,116,115,0,0,0,0,0,0,0,0,103,97,117,110,116,108,101,116,114,53,0,0,0,0,0,0,77,101,103,97,32,66,111,109,98,101,114,109,97,110,32,45,32,56,32,80,108,97,121,101,114,32,68,101,109,111,0,0,51,32,58,32,52,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,109,107,100,105,114,40,37,115,41,32,101,114,114,111,114,58,32,37,115,46,10,0,0,0,0,0,0,51,32,67,111,105,110,115,32,49,32,67,114,101,100,105,116,32,0,0,0,0,0,0,0,80,50,32,82,101,97,99,104,0,0,0,0,0,0,0,0,77,117,115,116,97,102,97,32,97,110,100,32,52,48,32,84,104,105,101,118,101,115,32,40,98,111,111,116,108,101,103,41,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,78,101,101,100,32,116,111,32,100,101,102,105,110,101,32,97,116,32,108,101,97,115,116,32,49,32,115,104,97,100,101,114,46,10,0,83,112,97,99,101,32,82,97,105,100,101,114,0,0,0,0,109,100,95,109,101,103,97,98,109,56,0,0,0,0,0,0,50,48,48,52,0,0,0,0,77,97,103,105,99,32,83,119,111,114,100,32,40,50,51,46,48,54,46,49,57,57,48,32,74,97,112,97,110,41,0,0,68,101,118,105,108,32,87,111,114,108,100,0,0,0,0,0,112,99,101,95,102,105,110,97,108,109,116,0,0,0,0,0,84,104,101,32,75,105,110,103,32,111,102,32,70,105,103,104,116,101,114,115,32,39,57,55,32,80,108,117,115,32,40,98,111,111,116,108,101,103,41,0,0,0,0,0,0,0,0,0,112,49,32,99,111,105,110,50,0,0,0,0,0,0,0,0,80,37,105,32,66,117,116,116,111,110,115,32,65,66,0,0,77,101,103,97,32,66,111,109,98,101,114,109,97,110,32,40,85,83,65,41,0,0,0,0,68,114,118,66,103,83,99,114,111,108,108,0,0,0,0,0,68,114,118,83,99,114,111,108,108,48,91,50,93,0,0,0,49,51,32,77,97,32,74,105,97,110,103,32,45,32,57,56,32,77,101,105,32,83,104,97,111,32,78,117,32,80,105,97,110,32,40,67,104,105,41,0,0,0,0,0,0,0,0,0,109,115,104,104,0,0,0,0,66,108,111,99,107,32,72,111,108,101,0,0,0,0,0,0,116,114,111,106,97,110,114,0,70,114,101,101,122,101,32,83,116,101,112,0,0,0,0,0,109,100,95,109,101,103,97,98,111,109,98,117,0,0,0,0,75,48,53,51,50,52,54,32,82,101,103,115,0,0,0,0,70,114,101,101,122,101,0,0,73,110,99,111,114,114,101,99,116,32,67,111,108,111,114,115,0,0,0,0,0,0,0,0,83,116,114,101,101,116,32,83,109,97,114,116,32,40,74,97,112,97,110,32,118,101,114,115,105,111,110,32,49,41,0,0,77,101,100,97,108,32,67,105,116,121,32,40,74,112,110,44,32,83,101,103,97,78,101,116,41,0,0,0,0,0,0,0,9,45,45,102,101,97,116,117,114,101,115,58,32,80,114,105,110,116,115,32,97,118,97,105,108,97,98,108,101,32,102,101,97,116,117,114,101,115,32,99,111,109,112,105,108,101,100,32,105,110,116,111,32,82,101,116,114,111,65,114,99,104,46,0,71,114,97,100,105,117,115,32,73,73,73,32,40,87,111,114,108,100,41,0,0,0,0,0,109,100,95,109,101,100,97,108,99,0,0,0,0,0,0,0,109,111,111,110,99,114,115,52,0,0,0,0,0,0,0,0,32,56,32,67,111,105,110,115,32,49,32,67,114,101,100,105,116,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,67,82,67,51,50,58,32,48,120,37,120,44,32,83,72,65,50,53,54,58,32,37,115,10,0,0,0,0,0,109,97,107,97,105,109,117,114,0,0,0,0,0,0,0,0,83,46,80,46,89,46,32,45,32,83,112,101,99,105,97,108,32,80,114,111,106,101,99,116,32,89,32,40,87,111,114,108,100,32,118,101,114,46,32,78,41,0,0,0,0,0,0,0,49,32,67,111,105,110,32,32,49,32,67,114,101,100,105,116,32,32,47,32,49,32,67,111,105,110,32,32,50,32,32,67,114,101,100,105,116,115,0,0,77,99,68,111,110,97,108,100,39,115,32,84,114,101,97,115,117,114,101,32,76,97,110,100,32,65,100,118,101,110,116,117,114,101,32,40,85,83,65,41,0,0,0,0,0,0,0,0,49,32,80,108,97,121,101,114,0,0,0,0,0,0,0,0,87,99,57,48,83,99,114,111,108,108,49,88,76,111,0,0,50,67,95,53,67,0,0,0,53,32,67,111,105,110,115,47,54,32,67,114,101,100,105,116,115,0,0,0,0,0,0,0,66,97,99,107,32,70,105,114,101,32,40,84,101,99,109,111,41,32,40,74,97,112,97,110,44,32,66,111,111,116,108,101,103,44,32,80,114,111,116,111,116,121,112,101,63,41,0,0,109,100,95,109,99,100,111,110,97,108,100,117,0,0,0,0,71,121,114,117,115,115,32,40,75,111,110,97,109,105,41,0,0,0,0,0,0,0,0,0,68,111,117,98,108,101,32,68,114,97,103,111,110,32,40,98,111,111,116,108,101,103,32,119,105,116,104,32,72,68,54,51,48,57,41,0,0,0,0,0,77,101,110,117,32,116,111,103,103,108,101,0,0,0,0,0,80,50,32,66,117,116,116,111,110,32,53,0,0,0,0,0,77,99,68,111,110,97,108,100,39,115,32,84,114,101,97,115,117,114,101,32,76,97,110,100,32,65,100,118,101,110,116,117,114,101,32,40,74,112,110,44])
.concat([32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,111,114,108,101,103,101,110,100,49,48,53,107,0,0,0,0,112,52,32,102,105,114,101,32,52,0,0,0,0,0,0,0,66,111,109,98,0,0,0,0,68,97,114,105,117,115,65,68,80,67,77,67,111,109,109,97,110,100,0,0,0,0,0,0,86,101,110,100,101,116,116,97,32,40,87,111,114,108,100,32,52,32,80,108,97,121,101,114,115,32,118,101,114,46,32,84,41,0,0,0,0,0,0,0,84,101,116,114,105,115,32,47,32,66,108,111,120,101,101,100,32,40,75,111,114,101,97,110,32,83,121,115,116,101,109,32,49,54,32,98,111,111,116,108,101,103,41,32,40,73,83,71,32,83,101,108,101,99,116,105,111,110,32,77,97,115,116,101,114,32,84,121,112,101,32,50,48,48,54,41,0,0,0,0,109,100,95,109,99,100,111,110,97,108,100,106,112,0,0,0,50,47,50,0,0,0,0,0,84,101,115,116,109,111,100,101,0,0,0,0,0,0,0,0,49,57,88,88,32,45,32,116,104,101,32,119,97,114,32,97,103,97,105,110,115,116,32,100,101,115,116,105,110,121,32,40,57,53,49,50,48,55,32,85,83,65,41,0,0,0,0,0,83,99,111,111,116,101,114,32,83,104,111,111,116,101,114,0,0,0,0,0,0,0,0,0,77,99,68,111,110,97,108,100,39,115,32,84,114,101,97,115,117,114,101,32,76,97,110,100,32,65,100,118,101,110,116,117,114,101,32,40,74,112,110,41,0,0,0,0,0,0,0,0,50,32,58,32,50,0,0,0,112,99,101,95,97,110,107,111,107,117,0,0,0,0,0,0,80,50,32,82,111,110,0,0,97,108,105,98,97,98,97,98,0,0,0,0,0,0,0,0,80,37,105,32,51,215,32,75,105,99,107,0,0,0,0,0,109,100,95,109,99,100,111,110,97,108,100,106,0,0,0,0,71,97,110,103,32,66,117,115,116,101,114,115,32,40,115,101,116,32,49,41,0,0,0,0,68,0,0,0,101,0,0,0,109,0,0,0,111,0,0,0,110,0,0,0,32,0,0,0,70,0,0,0,114,0,0,0,111,0,0,0,110,0,0,0,116,0,0,0,0,0,0,0,84,155,0,0,223,87,0,0,24,98,0,0,191,126,0,0,0,0,0,0,84,155,0,0,223,87,0,0,48,98,0,0,218,125,0,0,32,0,0,0,40,0,0,0,86,0,0,0,49,0,0,0,48,0,0,0,50,0,0,0,44,0,0,0,32,0,0,0,67,0,0,0,104,0,0,0,105,0,0,0,110,0,0,0,97,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,109,115,119,111,114,100,106,0,70,105,110,97,108,32,76,97,112,32,84,119,105,110,0,0,107,111,102,57,55,112,108,115,0,0,0,0,0,0,0,0,84,104,114,101,101,32,87,111,110,100,101,114,115,32,40,98,111,111,116,108,101,103,32,115,101,116,32,49,44,32,119,111,110,100,101,114,32,51,32,57,49,48,53,50,48,32,101,116,99,41,0,0,0,0,0,0,84,111,112,32,80,108,97,121,101,114,39,115,32,71,111,108,102,32,40,78,71,77,45,48,48,51,41,40,78,71,72,45,48,48,51,41,0,0,0,0,77,99,68,111,110,97,108,100,39,115,32,84,114,101,97,115,117,114,101,32,76,97,110,100,32,65,100,118,101,110,116,117,114,101,32,40,69,117,114,111,41,0,0,0,0,0,0,0,98,78,101,111,69,110,97,98,108,101,71,114,97,112,104,105,99,115,0,0,0,0,0,0,83,76,79,84,45,62,97,114,0,0,0,0,0,0,0,0,77,97,114,118,101,108,32,83,117,112,101,114,32,72,101,114,111,101,115,32,40,57,53,49,49,49,55,32,66,114,97,122,105,108,41,0,0,0,0,0,84,104,101,32,83,105,109,112,115,111,110,115,32,40,52,32,80,108,97,121,101,114,115,32,87,111,114,108,100,44,32,115,101,116,32,49,41,0,0,0,109,100,95,109,99,100,111,110,97,108,100,0,0,0,0,0,80,111,111,121,97,110,0,0,77,97,122,105,110,32,83,97,103,97,32,40,85,83,65,41,0,0,0,0,0,0,0,0,9,9,73,102,32,110,111,32,97,114,103,117,109,101,110,116,115,32,97,114,101,32,112,97,115,115,101,100,32,116,111,32,82,101,116,114,111,65,114,99,104,44,32,105,116,32,105,115,32,101,113,117,105,118,97,108,101,110,116,32,116,111,32,117,115,105,110,103,32,45,45,109,101,110,117,32,97,115,32,111,110,108,121,32,97,114,103,117,109,101,110,116,46,0,0,0,79,80,76,45,62,101,103,95,99,110,116,0,0,0,0,0,103,108,80,117,115,104,68,101,98,117,103,71,114,111,117,112,0,0,0,0,0,0,0,0,109,100,95,109,97,122,105,110,115,97,103,117,0,0,0,0,111,118,101,114,108,97,121,115,0,0,0,0,0,0,0,0,77,111,111,110,32,67,114,101,115,116,97,32,40,98,111,111,116,108,101,103,32,115,101,116,32,51,41,0,0,0,0,0,70,114,97,109,101,68,105,114,101,99,116,105,111,110,0,0,77,97,122,105,110,32,83,97,103,97,32,40,74,112,110,44,32,75,111,114,41,0,0,0,82,101,116,114,111,65,114,99,104,58,32,82,101,99,114,101,97,116,105,110,103,32,70,66,79,32,116,101,120,116,117,114,101,32,35,37,100,58,32,37,117,120,37,117,10,0,0,0,83,65,86,69,70,73,76,69,32,68,73,82,32,37,115,0,109,100,95,109,97,122,105,110,115,97,103,106,0,0,0,0,78,72,76,32,39,57,52,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,114,98,102,102,50,0,0,0,84,101,101,110,97,103,101,32,77,117,116,97,110,116,32,78,105,110,106,97,32,84,117,114,116,108,101,115,32,40,87,111,114,108,100,32,52,32,80,108,97,121,101,114,115,41,0,0,80,49,32,66,117,116,116,111,110,32,54,0,0,0,0,0,77,97,122,105,110,32,83,97,103,97,32,40,65,115,105,97,41,0,0,0,0,0,0,0,19,153,0,0,65,109,0,0,141,121,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,32,0,0,0,118,0,0,0,101,0,0,0,114,0,0,0,46,0,0,0,32,0,0,0,87,0,0,0,41,0,0,0,0,0,0,0,71,0,0,0,97,0,0,0,114,0,0,0,117,0,0,0,107,0,0,0,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,32,67,111,105,110,32,54,32,67,114,101,100,105,116,115,0,0,0,0,0,0,0,0,76,97,115,101,114,0,0,0,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,37,115,46,10,0,0,0,0,0,116,101,116,114,98,120,0,0,99,97,114,116,114,105,100,103,101,0,0,0,0,0,0,0,109,100,95,109,97,122,105,110,115,97,103,97,0,0,0,0,50,47,51,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,116,97,107,101,32,115,99,114,101,101,110,115,104,111,116,46,10,0,0,0,0,0,0,0,0,77,97,122,105,110,32,87,97,114,115,32,40,69,117,114,111,41,0,0,0,0,0,0,0,51,32,58,32,51,0,0,0,80,50,32,75,97,110,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,88,77,76,32,115,104,97,100,101,114,32,97,116,116,114,105,98,117,116,101,115,32,100,111,32,110,111,116,32,99,111,109,112,108,121,32,119,105,116,104,32,115,112,101,99,105,102,105,99,97,116,105,111,110,115,46,10,0,0,72,97,115,97,109,117,32,40,74,97,112,97,110,41,0,0,103,114,97,100,105,117,115,50,97,0,0,0,0,0,0,0,80,37,105,32,51,215,32,80,117,110,99,104,0,0,0,0,47,62,0,0,0,0,0,0,109,100,95,109,97,122,105,110,119,97,114,0,0,0,0,0,97,114,109,119,97,114,0,0,68,101,109,111,110,32,70,114,111,110,116,32,40,86,49,48,50,44,32,67,104,105,110,97,41,0,0,0,0,0,0,0,77,97,103,105,99,32,83,119,111,114,100,32,45,32,104,101,114,111,105,99,32,102,97,110,116,97,115,121,32,40,50,51,46,48,54,46,49,57,57,48,32,111,116,104,101,114,32,99,111,117,110,116,114,121,41,0,0,0,0,0,0,0,0,0,112,99,101,95,102,105,110,97,108,108,97,112,0,0,0,0,84,104,101,32,75,105,110,103,32,111,102,32,70,105,103,104,116,101,114,115,32,39,57,55,32,40,75,111,114,101,97,110,32,114,101,108,101,97,115,101,41,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,108,111,97,100,95,105,109,97,103,101,115,46,10,0,0,0,0,0,0,0,0,68,97,118,105,100,115,111,110,32,38,32,65,115,115,111,99,105,97,116,101,115,0,0,0,109,100,95,49,51,109,97,104,106,97,110,0,0,0,0,0,84,101,101,110,97,103,101,32,77,117,116,97,110,116,32,78,105,110,106,97,32,84,117,114,116,108,101,115,32,40,74,97,112,97,110,32,50,32,80,108,97,121,101,114,115,41,0,0,109,115,104,98,0,0,0,0,113,117,105,122,102,49,0,0,73,114,101,109,32,40,108,105,99,101,110,115,101,100,32,102,114,111,109,32,66,114,111,100,101,114,98,117,110,100,41,0,77,97,116,104,32,66,108,97,115,116,101,114,32,45,32,69,112,105,115,111,100,101,32,49,32,40,85,83,65,41,0,0,66,117,99,99,97,110,101,101,114,115,32,40,115,101,116,32,49,41,0,0,0,0,0,0,75,117,110,103,45,70,117,32,77,97,115,116,101,114,0,0,57,57,32,67,114,101,100,105,116,115,32,47,32,83,111,117,110,100,32,84,101,115,116,0,75,97,105,116,101,105,32,68,97,105,115,101,110,115,111,117,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,100,98,114,101,101,100,0,0,109,100,95,109,97,116,104,98,108,115,116,0,0,0,0,0,9,45,45,109,101,110,117,58,32,68,111,32,110,111,116,32,114,101,113,117,105,114,101,32,82,79,77,32,111,114,32,108,105,98,114,101,116,114,111,32,99,111,114,101,32,116,111,32,98,101,32,108,111,97,100,101,100,44,32,115,116,97,114,116,115,32,100,105,114,101,99,116,108,121,32,105,110,32,109,101,110,117,46,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,67,111,114,101,32,111,112,116,105,111,110,58,10,0,0,0,0,0,0,0,0,86,105,103,105,108,97,110,116,101,32,40,87,111,114,108,100,44,32,115,101,116,32,49,41,0,0,0,0,0,0,0,0,77,97,116,101,110,32,110,111,32,83,111,117,109,101,116,115,117,32,40,74,112,110,41,0,0,0,0,0,0,0,0,0,109,111,111,110,99,114,115,51,0,0,0,0,0,0,0,0,109,100,95,109,97,116,101,110,0,0,0,0,0,0,0,0,87,105,108,121,32,84,111,119,101,114,0,0,0,0,0,0,77,97,115,116,101,114,32,111,102,32,87,101,97,112,111,110,32,40,74,112,110,41,0,0,68,105,115,107,32,83,119,97,112,32,78,101,120,116,0,0,80,49,32,66,117,116,116,111,110,32,53,0,0,0,0,0,109,100,95,109,119,101,97,112,111,110,0,0,0,0,0,0,49,32,67,111,105,110,32,52,32,67,114,101,100,105,116,115,0,0,0,0,0,0,0,0,112,51,32,102,105,114,101,32,52,0,0,0,0,0,0,0,83,104,105,110,111,98,105,32,47,32,70,90,45,50,48,48,54,32,40,75,111,114,101,97,110,32,83,121,115,116,101,109,32,49,54,32,98,111,111,116,108,101,103,41,32,40,73,83,71,32,83,101,108,101,99,116,105,111,110,32,77,97,115,116,101,114,32,84,121,112,101,32,50,48,48,54,41,0,0,0,84,111,115,104,105,98,97,32,69,77,73,0,0,0,0,0,51,47,51,0,0,0,0,0,76,97,115,116,115,117,114,118,77,117,120,0,0,0,0,0,84,101,115,116,109,111,100,101,32,83,119,105,116,99,104,0,52,32,40,78,111,114,109,97,108,41,0,0,0,0,0,0,77,97,115,116,101,114,32,111,102,32,77,111,110,115,116,101,114,115,32,40,74,112,110,41,0,0,0,0,0,0,0,0,72,111,111,107,32,40,87,111,114,108,100,41,0,0,0,0,52,32,58,32,52,0,0,0,80,50,32,67,104,105,0,0,65,108,105,32,66,97,98,97,32,97,110,100,32,52,48,32,84,104,105,101,118,101,115,0,0,0,0,0,0,0,0,0,109,100,95,109,97,115,116,101,114,109,106,0,0,0,0,0,100,109,110,102,114,110,116,97,0,0,0,0,0,0,0,0,109,115,119,111,114,100,114,49,0,0,0,0,0,0,0,0,70,105,110,97,108,32,66,108,97,115,116,101,114,0,0,0,107,111,102,57,55,107,0,0,32,66,117,116,116,111,110,32,52,0,0,0,0,0,0,0,77,97,115,116,101,114,32,111,102,32,77,111,110,115,116,101,114,115,32,40,85,83,65,41,0,0,0,0,0,0,0,0,50,32,105,110,32,49,32,45,32,80,115,121,99,104,111,32,80,105,110,98,97,108,108,32,38,32,77,105,99,114,111,32,77,97,99,104,105,110,101,115,32,40,69,117,114,111,41,0,0,0,0,0,0,0,0,0,77,97,114,118,101,108,32,83,117,112,101,114,32,72,101,114,111,101,115,32,40,57,53,49,48,50,52,32,65,115,105,97,41,0,0,0,0,0,0,0,109,100,95,109,97,115,116,101,114,109,0,0,0,0,0,0,82,45,84,121,112,101,32,40,87,111,114,108,100,41,0,0,100,101,97,100,0,0,0,0,77,97,114,115,117,112,105,108,97,109,105,32,40,85,83,65,41,0,0,0,0,0,0,0,9,45,104,47,45,45,104,101,108,112,58,32,83,104,111,119,32,116,104,105,115,32,104,101,108,112,32,109,101,115,115,97,103,101,46,0,0,0,0,0,83,97,118,101,32,115,116,97,116,101,47,109,111,118,105,101,32,115,108,111,116,58,32,37,117,0,0,0,0,0,0,0,109,100,95,109,97,114,115,117,112,117,0,0,0,0,0,0,77,111,111,110,32,67,114,101,115,116,97,32,40,98,111,111,116,108,101,103,32,115,101,116,32,50,41,0,0,0,0,0,71,97,108,70,108,105,112,83,99,114,101,101,110,88,0,0,77,97,114,115,117,112,105,108,97,109,105,32,40,69,117,114,111,41,0,0,0,0,0,0,109,100,95,109,97,114,115,117,112,0,0,0,0,0,0,0,68,105,115,107,32,69,106,101,99,116,32,84,111,103,103,108,101,0,0,0,0,0,0,0,108,97,115,116,98,108,97,100,0,0,0,0,0,0,0,0,80,50,32,65,116,116,97,99,107,32,82,105,103,104,116,0,77,97,114,107,111,32,40,85,83,65,41,0,0,0,0,0,49,32,67,111,105,110,32,51,32,67,114,101,100,105,116,115,0,0,0,0,0,0,0,0,79,112,119,111,108,102,65,68,80,67,77,68,97,116,97,0,115,104,105,110,102,122,0,0,109,100,95,109,97,114,107,111,117,0,0,0,0,0,0,0,80,108,97,121,101,114,32,83,116,97,114,116,47,67,111,110,116,105,110,117,101,0,0,0,76,97,115,116,115,117,114,118,80,111,115,105,116,105,111,110,0,0,0,0,0,0,0,0,80,97,117,115,101,32,77,111,100,101,0,0,0,0,0,0,49,32,40,69,97,115,105,101,115,116,41,0,0,0,0,0,77,97,114,107,111,39,115,32,77,97,103,105,99,32,70,111,111,116,98,97,108,108,32,40,69,117,114,111,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,0,0,52,32,58,32,51,0,0,0,80,50,32,80,111,110,0,0,97,108,105,98,97,98,97,0,109,100,95,109,97,114,107,111,112,0,0,0,0,0,0,0,68,0,0,0,101,0,0,0,109,0,0,0,111,0,0,0,110,0,0,0,32,0,0,0,70,0,0,0,114,0,0,0,111,0,0,0,110,0,0,0,116,0,0,0,0,0,0,0,84,155,0,0,223,87,0,0,24,98,0,0,191,126,0,0,0,0,0,0,84,155,0,0,223,87,0,0,48,98,0,0,218,125,0,0,32,0,0,0,40,0,0,0,86,0,0,0,49,0,0,0,48,0,0,0,51,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,77,97,103,105,99,32,83,119,111,114,100,32,45,32,104,101,114,111,105,99,32,102,97,110,116,97,115,121,32,40,50,53,46,48,55,46,49,57,57,48,32,111,116,104,101,114,32,99,111,117,110,116,114,121,41,0,0,0,0,0,0,0,0,0,112,99,101,95,102,105,110,108,98,108,115,116,0,0,0,0,84,104,101,32,75,105,110,103,32,111,102,32,70,105,103,104,116,101,114,115,32,39,57,55,32,40,78,71,72,45,50,51,50,48,41,0,0,0,0,0,32,66,117,116,116,111,110,32,51,0,0,0,0,0,0,0,77,97,114,107,111,39,115,32,77,97,103,105,99,32,70,111,111,116,98,97,108,108,32,40,69,117,114,111,41,0,0,0,109,100,95,50,112,115,121,109,109,97,99,0,0,0,0,0,109,115,104,97,0,0,0,0,109,100,95,109,97,114,107,111,0,0,0,0,0,0,0,0,77,97,114,105,111,32,76,101,109,105,101,117,120,32,72,111,99,107,101,121,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,0,0,85,115,97,103,101,58,32,114,101,116,114,111,97,114,99,104,32,91,114,111,109,32,102,105,108,101,93,32,91,111,112,116,105,111,110,115,46,46,46,93,0,0,0,0,0,0,0,0,65,32,98,117,116,116,111,110,32,40,114,105,103,104,116,41,0,0,0,0,0,0,0,0,109,100,95,109,97,114,105,111,108,104,0,0,0,0,0,0,109,111,111,110,99,114,115,50,0,0,0,0,0,0,0,0,77,97,114,105,111,32,65,110,100,114,101,116,116,105,32,82,97,99,105,110,103,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,0,109,100,95,97,110,100,114,101,116,116,105,0,0,0,0,0,78,101,120,116,32,79,118,101,114,108,97,121,0,0,0,0,77,97,114,98,108,101,32,77,97,100,110,101,115,115,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,80,50,32,65,116,116,97,99,107,32,76,101,102,116,0,0,99,104,45,62,115,117,115,0,49,32,67,111,105,110,32,50,32,67,114,101,100,105,116,115,0,0,0,0,0,0,0,0,79,112,119,111,108,102,65,68,80,67,77,69,110,100,0,0,73,83,71,32,83,101,108,101,99,116,105,111,110,32,77,97,115,116,101,114,32,84,121,112,101,32,50,48,48,54,0,0,109,100,95,109,97,114,98,108,101,0,0,0,0,0,0,0,65,116,116,97,99,107,0,0,105,111,99,104,105,112,95,114,101,103,115,0,0,0,0,0,71,101,114,109,97,110,121,0,78,101,119,109,97,110,32,72,97,97,115,32,73,110,100,121,67,97,114,32,70,101,97,116,117,114,105,110,103,32,78,105,103,101,108,32,77,97,110,115,101,108,108,32,126,32,78,105,103,101,108,32,77,97,110,115,101,108,108,32,73,110,100,121,32,67,97,114,32,40,87,111,114,108,100,41,0,0,0,0,51,32,58,32,50,0,0,0,80,50,32,78,0,0,0,0,84,114,105,117,109,112,104,32,83,111,102,116,119,97,114,101,32,73,110,99,46,0,0,0,109,100,95,110,101,119,109,97,110,104,0,0,0,0,0,0,68,101,109,111,110,32,70,114,111,110,116,32,40,86,49,48,51,41,0,0,0,0,0,0,109,115,119,111,114,100,0,0,70,105,103,104,116,105,110,103,32,82,117,110,0,0,0,0,107,111,102,57,55,104,0,0,32,66,117,116,116,111,110,32,50,0,0,0,0,0,0,0,83,46,83,46,32,76,117,99,105,102,101,114,32,45,32,77,97,110,32,79,118,101,114,98,111,97,114,100,33,32,40,69,117,114,111,41,0,0,0,0,77,105,99,114,111,32,77,97,99,104,105,110,101,115,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,77,97,114,118,101,108,32,83,117,112,101,114,32,72,101,114,111,101,115,32,40,57,53,49,48,50,52,32,69,117,114,111,41,0,0,0,0,0,0,0,77,117,116,97,110,116,32,70,105,103,104,116,101,114,32,40,87,111,114,108,100,32,118,101,114,32,69,77,45,52,41,0,0,0,0,0,0,0,0,0,80,108,97,121,101,114,32,80,111,119,101,114,0,0,0,0,109,100,95,109,97,110,111,118,101,114,0,0,0,0,0,0,77,97,109,111,110,111,32,72,117,110,116,101,114,32,89,111,117,107,111,32,45,32,68,97,105,32,55,32,110,111,32,75,101,105,115,104,111,117,32,40,74,112,110,41,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,70,114,111,110,116,101,110,100,32,102,111,114,32,108,105,98,114,101,116,114,111,32,45,45,32,118,48,46,57,46,57,46,54,32,45,45,0,71,97,110,98,97,114,101,33,32,71,111,110,116,97,33,33,32,50,32,47,32,80,97,114,116,121,32,84,105,109,101,58,32,71,111,110,116,97,32,116,104,101,32,68,105,118,101,114,32,73,73,32,40,74,97,112,97,110,32,82,101,108,101,97,115,101,41,0,0,0,0,0,109,100,95,109,97,109,111,110,111,0,0,0,0,0,0,0,77,111,111,110,32,67,114,101,115,116,97,32,40,98,111,111,116,108,101,103,32,115,101,116,32,49,41,0,0,0,0,0,77,97,104,106,111,110,103,32,67,111,112,32,82,121,117,117,32,45,32,83,104,105,114,111,32,79,111,107,97,109,105,32,110,111,32,89,97,98,111,117,32,40,74,112,110,41,0,0,109,100,95,109,97,104,106,111,110,103,99,0,0,0,0,0,107,111,102,57,55,0,0,0,80,49,32,65,116,116,97,99,107,32,82,105,103,104,116,0,77,97,103,105,99,97,108,32,84,97,114,117,114,117,117,116,111,45,107,117,110,32,40,74,112,110,41,0,0,0,0,0,68,117,97,108,0,0,0,0,79,112,119,111,108,102,65,68,80,67,77,80,111,115,0,0,73,83,71,0,0,0,0,0,109,100,95,109,116,97,114,117,114,117,0,0,0,0,0,0,83,116,97,114,116,0,0,0,77,97,103,105,99,97,108,32,72,97,116,32,110,111,32,66,117,116,116,111,98,105,32,84,117,114,98,111,33,32,68,97,105,98,111,117,107,101,110,32,40,74,112,110,41,0,0,0,52,32,58,32,50,0,0,0,56,48,32,83,101,99,111,110,100,115,0,0,0,0,0,0,80,50,32,77,0,0,0,0,77,84,86,32,82,111,99,107,45,78,45,82,111,108,108,32,84,114,105,118,105,97,32,40,80,97,114,116,32,50,41,0,0,0,0,0,0,0,0,0,109,100,95,109,97,103,105,99,104,97,116,0,0,0,0,0,100,109,110,102,114,110,116,98,0,0,0,0,0,0,0,0,38,98,0,0,52,88,0,0,110,48,0,0,252,114,0,0,32,0,0,0,73,0,0,0,73,0,0,0,0,0,0,0,83,0,0,0,101,0,0,0,110,0,0,0,106,0,0,0,111,0,0,0,32,0,0,0,110,0,0,0,111,0,0,0,32,0,0,0,79,0,0,0,111,0,0,0,107,0,0,0,97,0,0,0,109,0,0,0,105,0,0,0,32,0,0,0,73,0,0,0,73,0,0,0,32,0,0,0,40,0,0,0,79,0,0,0,111,0,0,0,107,0,0,0,97,0,0,0,109,0,0,0,105,0,0,0,32,0,0,0,50,0,0,0,32,0,0,0,57,0,0,0,48,0,0,0,48,0,0,0,51,0,0,0,48,0,0,0,50,0,0,0,32,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,112,99,101,95,102,105,103,104,116,114,117,110,0,0,0,0,84,104,101,32,75,105,110,103,32,111,102,32,70,105,103,104,116,101,114,115,32,39,57,55,32,40,78,71,77,45,50,51,50,48,41,0,0,0,0,0,32,66,117,116,116,111,110,32,49,0,0,0,0,0,0,0,83,99,104,111,108,97,115,116,105,99,39,115,32,84,104,101,32,77,97,103,105,99,32,83,99,104,111,111,108,32,66,117,115,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,53,48,53,41,0,0,0,0,0,0,0,0,0,109,100,95,109,105,99,114,111,109,97,99,0,0,0,0,0,109,115,104,0,0,0,0,0,109,100,95,109,115,98,112,48,49,0,0,0,0,0,0,0,83,99,104,111,108,97,115,116,105,99,39,115,32,84,104,101,32,77,97,103,105,99,32,83,99,104,111,111,108,32,66,117,115,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,51,51,49,41,0,0,0,0,0,0,0,0,0,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,0,0,0,0,0,68,45,80,97,100,32,85,112,0,0,0,0,0,0,0,0,109,100,95,109,115,98,112,48,54,0,0,0,0,0,0,0,109,111,111,110,99,114,115,98,0,0,0,0,0,0,0,0,84,104,101,32,77,97,103,105,99,32,83,99,104,111,111,108,32,66,117,115,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,51,50,55,41,0,0,0,0,0,0,109,100,95,109,115,98,112,48,55,0,0,0,0,0,0,0,67,111,98,114,97,45,67,111,109,109,97,110,100,32,40,73,116,97,108,105,97,110,32,98,111,111,116,108,101,103,41,0,0,0,0,0,0,0,0,0,80,49,32,65,116,116,97,99,107,32,76,101,102,116,0,0,84,104,101,32,77,97,103,105,99,32,83,99,104,111,111,108,32,66,117,115,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,51,49,52,41,0,0,0,0,0,0,83,105,110,103,108,101,0,0,83,101,114,118,105,99,101,32,77,111,100,101,32,0,0,0,79,112,119,111,108,102,65,68,80,67,77,95,67,0,0,0,66,73,79,83,32,111,110,108,121,0,0,0,0,0,0,0,109,100,95,109,115,98,112,48,56,0,0,0,0,0,0,0,83,119,105,116,99,104,32,116,111,32,83,116,97,114,116,0,83,104,105,112,32,73,110,99,114,101,97,115,101,0,0,0,87,105,110,110,105,110,103,32,114,111,117,110,100,115,32,40,112,108,97,121,101,114,32,118,115,32,112,108,97,121,101,114,41,0,0,0,0,0,0,0,84,104,101,32,77,97,103,105,99,32,83,99,104,111,111,108,32,66,117,115,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,51,48,55,41,0,0,0,0,0,0,52,48,32,83,101,99,111,110,100,115,0,0,0,0,0,0,80,50,32,76,0,0,0,0,114,111,99,107,116,114,118,50,0,0,0,0,0,0,0,0,109,100,95,109,115,98,112,48,57,0,0,0,0,0,0,0,68,0,0,0,101,0,0,0,109,0,0,0,111,0,0,0,110,0,0,0,32,0,0,0,70,0,0,0,114,0,0,0,111,0,0,0,110,0,0,0,116,0,0,0,0,0,0,0,84,155,0,0,223,87,0,0,24,98,0,0,191,126,0,0,0,0,0,0,84,155,0,0,223,87,0,0,48,98,0,0,218,125,0,0,32,0,0,0,40,0,0,0,86,0,0,0,49,0,0,0,48,0,0,0,53,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,83,101,110,106,111,32,110,111,32,79,111,107,97,109,105,32,73,73,32,40,79,111,107,97,109,105,32,50,32,57,48,48,51,48,50,32,74,97,112,97,110,41,0,0,0,0,0,0,70,97,110,116,97,115,121,32,90,111,110,101,0,0,0,0,32,66,117,116,116,111,110,32,68,0,0,0,0,0,0,0,84,104,101,32,77,97,103,105,99,32,83,99,104,111,111,108,32,66,117,115,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,49,49,50,41,0,0,0,0,0,0,80,115,121,99,104,111,32,80,105,110,98,97,108,108,32,40,69,117,114,111,44,32,49,57,57,52,48,57,41,0,0,0,77,105,103,104,116,121,33,32,80,97,110,103,32,40,48,48,49,48,49,49,32,74,97,112,97,110,41,0,0,0,0,0,80,49,32,85,112,0,0,0,109,100,95,109,115,98,112,49,50,0,0,0,0,0,0,0,37,48,56,120,58,32,67,111,45,80,114,111,99,101,115,115,101,114,32,68,97,116,97,32,84,114,97,110,115,102,101,114,32,101,120,101,99,117,116,101,100,44,32,98,117,116,32,110,111,32,82,69,65,68,32,99,97,108,108,98,97,99,107,32,100,101,102,105,110,101,100,33,10,0,0,0,0,0,0,0,100,97,114,107,115,101,97,108,50,0,0,0,0,0,0,0,84,104,101,32,77,97,103,105,99,32,83,99,104,111,111,108,32,66,117,115,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,50,49,55,41,0,0,0,0,0,0,83,99,114,105,112,116,32,115,117,112,112,111,114,116,32,105,110,32,115,104,97,100,101,114,115,0,0,0,0,0,0,0,82,45,62,114,109,99,114,0,104,117,110,99,104,98,97,107,0,0,0,0,0,0,0,0,51,32,99,111,105,110,32,49,32,112,108,97,121,0,0,0,83,116,97,114,116,105,110,103,32,99,111,105,110,0,0,0,70,105,120,69,105,103,104,116,32,40,83,111,117,116,104,101,97,115,116,32,65,115,105,97,41,0,0,0,0,0,0,0,109,100,95,109,115,98,112,49,48,0,0,0,0,0,0,0,103,116,115,116,97,114,98,50,0,0,0,0,0,0,0,0,50,32,67,111,105,110,115,32,51,32,67,114,101,100,105,116,115,0,0,0,0,0,0,0,71,114,101,109,108,105,110,0,84,104,101,32,77,97,103,105,99,32,83,99,104,111,111,108,32,66,117,115,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,50,48,50,41,0,0,0,0,0,0,83,111,117,116,104,32,69,97,115,116,32,65,115,105,97,32,40,67,104,97,114,116,101,114,102,105,101,108,100,32,108,105,99,101,110,115,101,41,0,0,55,48,75,32,97,110,100,32,50,48,48,75,0,0,0,0,109,100,95,109,115,98,112,49,49,0,0,0,0,0,0,0,69,110,97,98,108,101,32,72,111,116,107,101,121,0,0,0,98,114,101,97,107,101,114,115,0,0,0,0,0,0,0,0,80,50,32,83,104,111,116,50,0,0,0,0,0,0,0,0,83,99,104,111,108,97,115,116,105,99,39,115,32,84,104,101,32,77,97,103,105,99,32,83,99,104,111,111,108,32,66,117,115,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,52,50,56,41,0,0,0,0,0,0,0,0,0,114,101,116,111,102,105,110,51,0,0,0,0,0,0,0,0,85,112,114,105,103,104,116,32,67,111,110,116,114,111,108,115,0,0,0,0,0,0,0,0,100,105,110,111,114,101,120,106,0,0,0,0,0,0,0,0,79,112,119,111,108,102,65,68,80,67,77,95,66,0,0,0,73,109,112,101,114,102,101,99,116,32,115,111,117,110,100,0,73,83,71,32,83,101,108,101,99,116,105,111,110,32,77,97,115,116,101,114,32,84,121,112,101,32,50,48,48,54,32,83,121,115,116,101,109,32,66,73,79,83,0,0,0,0,0,0,109,100,95,109,115,98,112,48,50,0,0,0,0,0,0,0,84,104,114,111,116,116,108,101,32,76,101,118,101,114,0,0,76,97,110,103,117,97,103,101,32,84,121,112,101,0,0,0,97,114,107,110,111,105,100,50,98,0,0,0,0,0,0,0,65,114,107,97,110,111,105,100,32,40,98,111,111,116,108,101,103,32,119,105,116,104,32,77,67,85,32,115,101,116,32,50,41,0,0,0,0,0,0,0,83,99,104,111,108,97,115,116,105,99,39,115,32,84,104,101,32,77,97,103,105,99,32,83,99,104,111,111,108,32,66,117,115,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,52,50,53,41,0,0,0,0,0,0,0,0,0,118,99,101,95,99,117,114,114,101,110,116,95,98,105,116,109,97,112,95,108,105,110,101,0,49,53,48,32,115,101,99,111,110,100,115,0,0,0,0,0,51,48,32,83,101,99,111,110,100,115,0,0,0,0,0,0,82,97,109,98,111,32,73,73,73,32,40,69,117,114,111,112,101,41,0,0,0,0,0,0,80,50,32,75,0,0,0,0,68,121,110,97,115,111,102,116,32,73,110,99,46,0,0,0,99,104,97,115,101,104,113,0,118,111,108,102,105,101,100,95,99,117,114,114,101,110,116,95,102,108,97,103,0,0,0,0,109,100,95,109,115,98,112,48,51,0,0,0,0,0,0,0,99,112,115,95,105,110,116,49,48,95,99,110,116,0,0,0,79,112,101,114,97,116,105,111,110,32,87,111,108,102,32,40,85,83,41,0,0,0,0,0,68,101,109,111,110,32,70,114,111,110,116,32,40,86,49,48,53,41,0,0,0,0,0,0,109,101,114,99,115,106,0,0,112,99,101,95,102,97,110,116,122,111,110,101,0,0,0,0,32,66,117,116,116,111,110,32,67,0,0,0,0,0,0,0,83,117,112,101,114,32,66,111,98,98,108,101,32,66,111,98,98,108,101,32,40,115,101,116,32,50,41,0,0,0,0,0,83,99,104,111,108,97,115,116,105,99,39,115,32,84,104,101,32,77,97,103,105,99,32,83,99,104,111,111,108,32,66,117,115,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,52,50,49,41,0,0,0,0,0,0,0,0,0,83,117,112,101,114,109,97,110,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,87,97,114,114,105,111,114,32,66,108,97,100,101,32,45,32,82,97,115,116,97,110,32,83,97,103,97,32,69,112,105,115,111,100,101,32,73,73,73,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,109,100,95,112,115,121,99,104,111,49,0,0,0,0,0,0,109,112,97,110,103,106,0,0,83,117,112,101,114,32,72,97,110,103,45,79,110,32,40,115,105,116,100,111,119,110,47,117,112,114,105,103,104,116,44,32,70,68,49,48,56,57,66,32,51,49,55,45,48,48,51,52,41,0,0,0,0,0,0,0,109,100,95,109,115,98,112,48,52,0,0,0,0,0,0,0,115,102,105,105,105,51,117,0,65,108,116,101,114,101,100,32,66,101,97,115,116,32,40,115,101,116,32,50,44,32,77,67,45,56,49,50,51,66,32,51,49,55,45,48,48,54,54,41,0,0,0,0,0,0,0,0,110,83,121,115,116,101,109,49,54,67,121,99,108,101,115,68,111,110,101,0,0,0,0,0,83,99,104,111,108,97,115,116,105,99,39,115,32,84,104,101,32,77,97,103,105,99,32,83,99,104,111,111,108,32,66,117,115,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,52,49,49,41,0,0,0,0,0,0,0,0,0,80,121,116,104,111,110,0,0,102,108,105,99,107,121,103,0,100,100,99,114,101,119,49,0,112,100,114,105,102,116,106,0,109,100,95,109,115,98,112,48,53,0,0,0,0,0,0,0,108,111,102,102,105,114,101,0,77,111,111,110,32,67,114,101,115,116,97,32,40,71,114,101,109,108,105,110,41,0,0,0,86,100,112,67,111,100,101,0,98,111,100,121,115,108,97,109,0,0,0,0,0,0,0,0,83,99,104,111,108,97,115,116,105,99,39,115,32,84,104,101,32,77,97,103,105,99,32,83,99,104,111,111,108,32,66,117,115,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,50,32,67,111,105,110,115,32,50,32,67,114,101,100,105,116,115,0,0,0,0,0,0,0,103,116,109,114,0,0,0,0,84,97,110,103,32,84,97,110,103,32,40,118,101,114,46,32,48,53,50,54,44,32,50,54,47,48,53,47,50,48,48,48,41,0,0,0,0,0,0,0,118,105,100,101,111,95,104,97,114,100,95,115,121,110,99,0,109,100,95,109,115,98,0,0,65,108,108,111,119,95,67,111,110,116,105,110,117,101,0,0,49,67,32,52,67,0,0,0,83,108,111,119,109,111,116,105,111,110,0,0,0,0,0,0,55,111,114,100,105,0,0,0,80,50,32,83,104,111,116,49,0,0,0,0,0,0,0,0,67,111,109,112,105,108,101,0,82,97,115,116,97,110,65,68,80,67,77,68,97,116,97,0,50,48,48,54,0,0,0,0,77,97,100,111,117,32,77,111,110,111,103,97,116,97,114,105,32,73,32,40,74,112,110,41,0,0,0,0,0,0,0,0,51,32,120,32,99,114,101,100,105,116,115,0,0,0,0,0,65,105,114,32,65,116,116,97,99,107,32,40,115,101,116,32,50,41,0,0,0,0,0,0,105,110,99,108,117,100,101,32,0,0,0,0,0,0,0,0,80,117,122,122,108,101,32,68,101,32,66,111,119,108,105,110,103,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,109,100,95,109,97,100,111,117,109,111,110,0,0,0,0,0,49,50,48,32,115,101,99,111,110,100,115,0,0,0,0,0,49,54,54,37,0,0,0,0,80,50,32,74,0,0,0,0,66,105,103,32,66,117,99,107,115,0,0,0,0,0,0,0,116,107,110,105,103,104,116,0,77,97,100,100,101,110,32,78,70,76,32,57,56,32,40,85,83,65,41,0,0,0,0,0,68,114,118,86,66,108,97,110,107,0,0,0,0,0,0,0,72,105,45,109,97,120,32,84,101,99,104,110,111,108,111,103,121,32,73,110,99,46,0,0,77,101,114,99,115,32,40,57,48,48,51,48,50,32,85,83,65,41,0,0,0,0,0,0,72,117,109,97,110,0,0,0,82,101,97,108,32,66,111,117,116,32,70,97,116,97,108,32,70,117,114,121,32,83,112,101,99,105,97,108,32,47,32,82,101,97,108,32,66,111,117,116,32,71,97,114,111,117,32,68,101,110,115,101,116,115,117,32,83,112,101,99,105,97,108,32,40,75,111,114,101,97,110,32,114,101,108,101,97,115,101,41,0,0,0,0,0,0,0,0,32,66,117,116,116,111,110,32,66,0,0,0,0,0,0,0,109,100,95,109,97,100,100,101,110,57,56,0,0,0,0,0,72,105,116,32,68,105,102,102,105,99,117,108,116,121,0,0,77,105,100,103,114,111,117,110,100,32,82,65,77,0,0,0,80,0,0,0,114,0,0,0,101,0,0,0,116,0,0,0,116,0,0,0,121,0,0,0,32,0,0,0,83,0,0,0,111,0,0,0,108,0,0,0,100,0,0,0,105,0,0,0,101,0,0,0,114,0,0,0,32,0,0,0,83,0,0,0,97,0,0,0,105,0,0,0,108,0,0,0,111,0,0,0,114,0,0,0,32,0,0,0,77,0,0,0,111,0,0,0,111,0,0,0,110,0,0,0,0,0,0,0,142,127,0,0,17,92,0,0,115,89,0,0,38,98,0,0,235,88,0,0,32,0,0,0,187,48,0,0,252,48,0,0,233,48,0,0,252,48,0,0,224,48,0,0,252,48,0,0,243,48,0,0,32,0,0,0,40,0,0,0,118,0,0,0,101,0,0,0,114,0,0,0,46,0,0,0,32,0,0,0,57,0,0,0,53,0,0,0,47,0,0,0,48,0,0,0,51,0,0,0,47,0,0,0,50,0,0,0,50,0,0,0,66,0,0,0,44,0,0,0,32,0,0,0,72,0,0,0,111,0,0,0,110,0,0,0,103,0,0,0,32,0,0,0,75,0,0,0,111,0,0,0,110,0,0,0,103,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,80,115,121,99,104,111,32,80,105,110,98,97,108,108,32,40,69,117,114,111,44,32,49,57,57,52,49,48,41,0,0,0,77,105,103,104,116,121,33,32,80,97,110,103,32,40,48,48,49,48,49,48,32,85,83,65,41,0,0,0,0,0,0,0,77,97,100,100,101,110,32,78,70,76,32,57,55,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,0,83,112,105,110,97,108,32,66,114,101,97,107,101,114,115,32,40,85,83,41,0,0,0,0,86,101,114,121,32,72,97,114,100,32,49,0,0,0,0,0,99,116,114,105,98,101,98,50,0,0,0,0,0,0,0,0,109,100,95,109,97,100,100,101,110,57,55,0,0,0,0,0,80,101,101,114,45,116,111,45,112,101,101,114,32,110,101,116,112,108,97,121,0,0,0,0,77,97,100,100,101,110,32,78,70,76,32,57,54,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,97,110,110,111,116,32,105,110,105,116,32,105,110,112,117,116,32,100,114,105,118,101,114,46,32,69,120,105,116,105,110,103,32,46,46,46,10,0,0,0,0,0,49,32,67,111,105,110,45,51,32,80,108,97,121,0,0,0,109,111,111,110,99,114,115,116,103,0,0,0,0,0,0,0,51,105,110,49,115,101,109,105,0,0,0,0,0,0,0,0,109,100,95,109,97,100,100,101,110,57,54,0,0,0,0,0,115,117,112,114,116,114,105,111,0,0,0,0,0,0,0,0,73,82,81,32,77,65,83,75,0,0,0,0,0,0,0,0,115,49,57,52,53,106,110,0,76,111,100,101,32,82,117,110,110,101,114,32,45,32,84,104,101,32,68,105,103,32,70,105,103,104,116,32,40,118,101,114,46,32,65,41,0,0,0,0,77,97,100,100,101,110,32,78,70,76,32,57,53,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,0,78,101,116,112,108,97,121,32,70,108,105,112,32,80,108,97,121,101,114,115,0,0,0,0,83,116,114,97,116,111,118,111,120,32,40,98,111,111,116,108,101,103,41,0,0,0,0,0,84,101,114,114,97,32,70,111,114,99,101,0,0,0,0,0,80,49,32,83,104,111,116,50,0,0,0,0,0,0,0,0,109,100,95,109,97,100,100,101,110,57,53,0,0,0,0,0,68,111,107,97,98,101,110,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,49,67,32,49,67,32,47,32,49,67,32,49,67,0,0,0,82,97,115,116,97,110,65,68,80,67,77,80,111,115,0,0,68,105,115,112,108,97,121,0,105,115,103,115,109,0,0,0,77,97,100,100,101,110,32,78,70,76,32,39,57,52,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,85,112,114,105,103,104,116,32,50,0,0,0,0,0,0,0,70,0,0,0,0,0,0,0,112,97,99,109,97,110,102,0,50,32,67,111,105,110,32,49,32,67,114,101,100,105,116,115,0,0,0,0,0,0,0,0,49,32,99,111,105,110,115,32,49,32,99,114,101,100,105,116,0,0,0,0,0,0,0,0,71,97,117,110,116,108,101,116,32,40,71,101,114,109,97,110,44,32,114,101,118,32,54,41,0,0,0,0,0,0,0,0,109,100,95,109,97,100,100,101,110,57,52,0,0,0,0,0,57,48,32,115,101,99,111,110,100,115,0,0,0,0,0,0,49,51,51,37,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,97,110,110,111,116,32,114,101,115,111,108,118,101,32,97,112,112,108,105,99,97,116,105,111,110,32,112,97,116,104,33,32,84,104,105,115,32,115,104,111,117,108,100,32,110,111,116,32,104,97,112,112,101,110,46,10,0,0,52,32,67,111,105,110,115,32,49,32,67,114,101,100,105,116])
.concat([32,0,0,0,0,0,0,0,80,50,32,73,0,0,0,0,115,114,97,105,100,101,114,0,77,97,32,81,105,97,111,32,69,32,77,111,32,84,97,32,45,32,68,101,118,105,108,105,115,104,32,77,97,104,106,111,110,103,32,84,111,119,101,114,32,40,67,104,105,41,0,0,100,107,111,110,103,102,0,0,109,101,114,99,115,117,114,49,0,0,0,0,0,0,0,0,75,105,100,32,110,111,32,72,111,114,101,32,72,111,114,101,32,68,97,105,115,97,107,117,115,101,110,32,40,98,111,111,116,108,101,103,41,0,0,0,70,49,32,84,114,105,112,108,101,32,66,97,116,116,108,101,0,0,0,0,0,0,0,0,114,98,102,102,115,112,101,99,107,0,0,0,0,0,0,0,32,66,117,116,116,111,110,32,65,0,0,0,0,0,0,0,109,100,95,109,97,113,105,97,111,0,0,0,0,0,0,0,68,114,118,83,99,114,111,108,108,48,91,48,93,0,0,0,109,100,95,112,115,121,99,104,111,0,0,0,0,0,0,0,109,112,97,110,103,117,0,0,84,114,111,106,97,110,32,40,85,83,32,115,101,116,32,50,41,0,0,0,0,0,0,0,83,116,97,114,116,105,110,103,32,66,117,116,116,111,110,0,77,45,49,32,65,98,114,97,109,115,32,66,97,116,116,108,101,32,84,97,110,107,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,73,71,77,79,0,0,0,0,115,116,114,101,101,116,115,109,106,0,0,0,0,0,0,0,109,100,95,109,49,97,98,114,97,109,115,0,0,0,0,0,78,101,116,112,108,97,121,0,103,121,114,111,100,105,110,101,0,0,0,0,0,0,0,0,76,101,100,32,83,116,111,114,109,32,82,97,108,108,121,32,50,48,49,49,32,40,85,83,41,0,0,0,0,0,0,0,76,111,116,117,115,32,73,73,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,0,77,111,111,110,32,67,114,101,115,116,97,32,40,78,105,99,104,105,98,117,116,115,117,44,32,111,108,100,32,114,101,118,41,0,0,0,0,0,0,0,32,57,32,67,111,105,110,115,32,49,32,67,114,101,100,105,116,0,0,0,0,0,0,0,71,104,111,115,116,115,39,110,32,71,111,98,108,105,110,115,32,40,87,111,114,108,100,32,82,101,118,105,115,105,111,110,32,67,41,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,103,97,109,101,46,10,0,0,0,0,0,0,50,32,67,111,105,110,115,32,49,32,67,114,101,100,105,116,32,32,47,32,49,32,67,111,105,110,32,32,51,32,32,67,114,101,100,105,116,115,0,0,109,100,95,108,111,116,117,115,50,112,0,0,0,0,0,0,50,32,67,114,101,100,105,116,115,32,71,97,109,101,0,0,87,99,57,48,83,99,114,111,108,108,49,89,72,105,0,0,98,97,99,107,102,105,114,116,0,0,0,0,0,0,0,0,76,111,116,117,115,32,73,73,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,100,100,114,97,103,111,110,98,0,0,0,0,0,0,0,0,112,103,109,51,105,110,49,0,112,117,122,122,108,105,50,0,80,49,32,83,104,111,116,49,0,0,0,0,0,0,0,0,109,100,95,108,111,116,117,115,50,0,0,0,0,0,0,0,79,0,0,0,114,0,0,0,105,0,0,0,101,0,0,0,110,0,0,0,116,0,0,0,97,0,0,0,108,0,0,0,32,0,0,0,76,0,0,0,101,0,0,0,103,0,0,0,101,0,0,0,110,0,0,0,100,0,0,0,0,0,0,0,127,137,0,0,56,110,0,0,202,145,0,0,132,83,0,0,32,79,0,0,32,0,0,0,40,0,0,0,86,0,0,0,49,0,0,0,49,0,0,0,49,0,0,0,44,0,0,0,32,0,0,0,67,0,0,0,104,0,0,0,105,0,0,0,110,0,0,0,97,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,67,114,97,122,121,32,83,99,111,108,108,105,110,103,0,0,84,97,105,116,111,83,111,117,110,100,76,97,116,99,104,0,87,114,101,115,116,108,101,32,87,97,114,32,40,115,101,116,32,50,44,32,87,111,114,108,100,44,32,70,68,49,48,57,52,32,51,49,55,45,48,49,48,50,41,0,0,0,0,0,84,104,101,32,76,111,115,116,32,87,111,114,108,100,32,45,32,74,117,114,97,115,115,105,99,32,80,97,114,107,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,80,50,32,82,105,103,104,116,32,82,105,103,104,116,0,0,85,112,114,105,103,104,116,32,49,0,0,0,0,0,0,0,70,108,105,112,32,115,99,114,101,101,110,0,0,0,0,0,109,100,95,108,111,115,116,119,114,108,100,0,0,0,0,0,65,108,105,101,110,32,67,114,117,115,104,0,0,0,0,0,80,50,32,72,0,0,0,0,98,105,103,98,117,99,107,115,0,0,0,0,0,0,0,0,84,104,101,32,76,111,115,116,32,86,105,107,105,110,103,115,32,40,85,83,65,41,0,0,68,114,97,103,111,110,32,87,111,114,108,100,32,80,114,101,116,116,121,32,67,104,97,110,99,101,32,40,86,49,48,49,44,32,74,97,112,97,110,41,0,0,0,0,0,0,0,0,77,101,114,99,115,32,40,57,48,48,54,48,56,32,85,83,65,41,0,0,0,0,0,0,112,99,101,95,102,49,116,98,0,0,0,0,0,0,0,0,82,101,97,108,32,66,111,117,116,32,70,97,116,97,108,32,70,117,114,121,32,83,112,101,99,105,97,108,32,47,32,82,101,97,108,32,66,111,117,116,32,71,97,114,111,117,32,68,101,110,115,101,116,115,117,32,83,112,101,99,105,97,108,0,0,0,0,0,0,0,0,0,32,83,116,114,111,110,103,32,75,105,99,107,0,0,0,0,51,119,111,110,100,101,114,115,104,0,0,0,0,0,0,0,109,100,95,108,111,115,116,118,105,107,117,0,0,0,0,0,110,67,121,99,108,101,115,69,120,116,114,97,0,0,0,0,77,105,103,104,116,121,33,32,80,97,110,103,32,40,48,48,48,57,50,53,32,69,117,114,111,41,0,0,0,0,0,0,80,111,119,101,114,32,77,111,100,101,0,0,0,0,0,0,84,104,101,32,76,111,115,116,32,86,105,107,105,110,103,115,32,40,69,117,114,111,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,109,100,95,108,111,115,116,118,105,107,112,0,0,0,0,0,84,84,70,32,102,111,110,116,32,114,101,110,100,101,114,105,110,103,32,119,105,116,104,32,70,114,101,101,84,121,112,101,0,0,0,0,0,0,0,0,83,76,79,84,45,62,119,97,118,101,116,97,98,108,101,0,103,108,71,101,116,68,101,98,117,103,77,101,115,115,97,103,101,76,111,103,0,0,0,0,84,104,101,32,76,111,115,116,32,86,105,107,105,110,103,115,32,40,69,117,114,111,41,0,0,0,0,0,0,0,0,0,109,111,111,110,99,114,115,116,111,0,0,0,0,0,0,0,70,114,97,109,101,67,111,117,110,116,0,0,0,0,0,0,109,100,95,108,111,115,116,118,105,107,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,114,101,105,110,105,116,32,70,66,79,32,116,101,120,116,117,114,101,46,10,0,0,0,0,0,0,67,79,78,70,73,71,32,68,73,82,32,37,115,0,0,0,76,111,114,100,32,77,111,110,97,114,99,104,32,45,32,84,111,107,111,116,111,110,32,83,101,110,116,111,117,32,68,101,110,115,101,116,115,117,32,40,74,112,110,41,0,0,0,0,60,67,111,114,101,32,100,105,114,62,0,0,0,0,0,0,68,83,80,32,67,111,110,102,105,103,0,0,0,0,0,0,109,100,95,110,104,108,57,52,0,0,0,0,0,0,0,0,104,97,115,95,101,120,116,114,97,95,118,105,100,101,111,95,114,97,109,0,0,0,0,0,116,119,105,110,115,112,114,105,0,0,0,0,0,0,0,0,65,99,99,101,108,101,114,97,116,101,32,51,0,0,0,0,109,100,95,108,111,114,100,109,111,110,0,0,0,0,0,0,71,97,114,117,107,97,32,40,74,97,112,97,110,32,118,101,114,46,32,87,41,0,0,0,67,114,97,122,121,32,83,99,114,111,108,108,105,110,103,0,82,101,116,114,111,65,114,99,104,58,32,114,97,114,99,104,95,109,97,105,110,95,105,110,105,116,95,119,114,97,112,40,41,32,115,117,99,99,101,101,100,101,100,46,10,0,0,0,119,114,101,115,116,119,97,114,50,0,0,0,0,0,0,0,76,111,110,103,32,40,67,104,105,41,0,0,0,0,0,0,77,111,118,105,110,103,32,83,116,97,110,100,97,114,100,0,71,97,109,101,32,76,101,118,101,108,0,0,0,0,0,0,49,48,48,107,32,97,110,100,32,50,48,48,107,0,0,0,109,100,95,108,111,110,103,0,54,54,37,0,0,0,0,0,80,50,32,71,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,77,111,100,101,114,110,32,71,76,83,76,32,119,97,115,32,99,104,111,115,101,110,32,97,110,100,32,118,101,114,116,101,120,32,115,104,97,100,101,114,32,119,97,115,32,110,111,116,32,112,114,111,118,105,100,101,100,46,32,84,104,105,115,32,105,115,32,97,110,32,101,114,114,111,114,46,10,0,0,0,0,0,0,65,116,108,97,110,116,105,99,32,67,105,116,121,32,65,99,116,105,111,110,0,0,0,0,71,0,0,0,114,0,0,0,97,0,0,0,100,0,0,0,105,0,0,0,117,0,0,0,115,0,0,0,32,0,0,0,73,0,0,0,73,0,0,0,32,0,0,0,45,0,0,0,32,0,0,0,71,0,0,0,79,0,0,0,70,0,0,0,69,0,0,0,82,0,0,0,32,0,0,0,110,48,0,0,206,145,0,0,27,103,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,32,0,0,0,78,0,0,0,101,0,0,0,119,0,0,0,32,0,0,0,118,0,0,0,101,0,0,0,114,0,0,0,46,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,76,111,98,111,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,49,57,52,52,32,45,32,116,104,101,32,108,111,111,112,32,109,97,115,116,101,114,32,40,48,48,48,54,50,48,32,74,97,112,97,110,41,0,0,0,51,32,67,111,105,110,115,32,52,32,67,114,101,100,105,116,115,32,0,0,0,0,0,0,100,119,112,99,0,0,0,0,109,101,114,99,115,117,0,0,70,49,32,67,105,114,99,117,115,32,40,65,108,116,41,0,0,0,0,0,0,0,0,0,32,77,101,100,105,117,109,32,75,105,99,107,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,111,118,101,114,108,97,121,32,100,101,115,99,115,32,102,111,114,32,111,118,101,114,108,97,121,32,35,37,117,46,10,0,0,109,100,95,108,111,98,111,0,83,105,100,101,32,80,111,99,107,101,116,32,40,85,83,65,41,0,0,0,0,0,0,0,116,109,110,116,50,112,106,0,109,112,97,110,103,114,49,0,73,114,101,109,32,65,109,101,114,105,99,97,0,0,0,0,76,111,100,101,32,82,117,110,110,101,114,32,40,115,101,116,32,49,41,0,0,0,0,0,77,97,116,99,104,32,77,111,100,101,0,0,0,0,0,0,84,104,101,32,76,105,111,110,32,75,105,110,103,32,40,87,111,114,108,100,41,0,0,0,107,97,105,116,101,105,100,115,0,0,0,0,0,0,0,0,88,32,77,117,108,116,105,112,108,121,32,40,74,97,112,97,110,44,32,77,55,50,41,0,0,0,0,0,0,0,0,0,109,100,95,108,105,111,110,107,105,110,103,0,0,0,0,0,70,114,101,101,84,121,112,101,0,0,0,0,0,0,0,0,76,105,103,104,116,32,67,114,117,115,97,100,101,114,32,40,85,83,65,41,0,0,0,0,109,100,95,108,105,103,104,116,99,117,0,0,0,0,0,0,76,105,103,104,116,32,67,114,117,115,97,100,101,114,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,53,48,54,48,56,41,0,0,0,0,83,99,114,101,101,110,115,104,111,116,0,0,0,0,0,0,65,99,99,101,108,101,114,97,116,101,32,50,0,0,0,0,109,100,95,108,105,103,104,116,99,112,0,0,0,0,0,0,66,97,99,107,103,114,111,117,110,100,32,83,99,101,110,101,114,121,0,0,0,0,0,0,87,114,101,115,116,108,101,32,87,97,114,32,40,115,101,116,32,49,44,32,74,97,112,97,110,44,32,70,68,49,48,57,52,32,51,49,55,45,48,48,57,48,41,0,0,0,0,0,76,105,103,104,116,32,67,114,117,115,97,100,101,114,32,40,75,111,114,41,0,0,0,0,80,50,32,82,105,103,104,116,32,76,101,102,116,0,0,0,77,111,118,105,110,103,32,68,101,108,117,120,101,0,0,0,49,48,48,107,32,97,110,100,32,49,48,48,107,0,0,0,109,100,95,108,105,103,104,116,99,107,0,0,0,0,0,0,49,32,58,32,52,0,0,0,76,105,102,101,32,77,101,116,101,114,0,0,0,0,0,0,80,50,32,70,0,0,0,0,97,99,105,116,121,97,0,0,76,105,103,104,116,32,67,114,117,115,97,100,101,114,32,40,74,112,110,41,0,0,0,0,66,97,100,32,115,111,117,110,100,63,0,0,0,0,0,0,77,101,114,99,115,32,40,57,48,48,51,48,50,32,101,116,99,41,0,0,0,0,0,0,112,99,101,95,102,49,99,105,114,99,117,115,49,0,0,0,80,97,101,32,87,97,110,103,32,74,101,111,110,32,83,101,111,108,32,47,32,76,101,103,101,110,100,32,111,102,32,97,32,87,97,114,114,105,111,114,32,40,75,111,114,101,97,110,32,99,101,110,115,111,114,101,100,32,83,97,109,117,114,97,105,32,83,104,111,100,111,119,110,32,73,86,41,0,0,0,32,87,101,97,107,32,75,105,99,107,0,0,0,0,0,0,109,100,95,108,105,103,104,116,99,106,0,0,0,0,0,0,109,100,95,115,105,100,101,112,111,99,107,0,0,0,0,0,77,105,103,104,116,121,33,32,80,97,110,103,32,40,48,48,49,48,49,48,32,69,117,114,111,41,0,0,0,0,0,0,105,110,112,117,116,95,112,108,97,121,101,114,56,0,0,0,76,105,98,101,114,116,121,32,111,114,32,68,101,97,116,104,32,40,85,83,65,41,0,0,109,100,95,108,105,98,101,114,116,121,0,0,0,0,0,0,79,110,45,116,104,101,45,102,108,121,32,114,101,99,111,114,100,105,110,103,32,111,102,32,103,97,109,101,112,108,97,121,32,119,105,116,104,32,108,105,98,97,118,99,111,100,101,99,0,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,115,97,118,101,32,115,116,97,116,101,32,116,111,32,34,37,115,34,46,0,0,0,84,97,107,105,110,103,32,115,99,114,101,101,110,115,104,111,116,46,0,0,0,0,0,0,76,72,88,32,65,116,116,97,99,107,32,67,104,111,112,112,101,114,32,40,74,112,110,41,0,0,0,0,0,0,0,0,37,0,0,0,0,0,0,0,77,111,111,110,32,67,114,101,115,116,97,32,40,78,105,99,104,105,98,117,116,115,117,32,85,83,65,44,32,117,110,101,110,99,114,121,112,116,101,100,41,0,0,0,0,0,0,0,67,97,118,101,108,111,110,66,97,110,107,83,119,105,116,99,104,0,0,0,0,0,0,0,109,100,95,108,104,120,106,0,76,72,88,32,65,116,116,97,99,107,32,67,104,111,112,112,101,114,32,40,69,117,114,111,44,32,85,83,65,41,0,0,67,104,101,97,116,32,84,111,103,103,108,101,0,0,0,0,114,98,102,102,115,112,101,99,0,0,0,0,0,0,0,0,66,114,97,107,101,32,51,0,109,100,95,108,104,120,0,0,84,105,109,101,114,0,0,0,73,110,32,71,97,109,101,32,79,110,108,121,0,0,0,0,119,114,101,115,116,119,97,114,49,0,0,0,0,0,0,0,76,101,116,104,97,108,32,69,110,102,111,114,99,101,114,115,32,73,73,32,45,32,71,117,110,32,70,105,103,104,116,101,114,115,32,40,85,83,65,41,0,0,0,0,0,0,0,0,53,48,107,32,97,110,100,32,49,48,48,107,0,0,0,0,77,97,116,99,104,32,99,111,117,110,116,0,0,0,0,0,109,100,95,108,101,50,117,0,50,32,58,32,51,0,0,0,69,80,79,83,32,67,111,114,112,111,114,97,116,105,111,110,0,0,0,0,0,0,0,0,76,101,116,104,97,108,32,69,110,102,111,114,99,101,114,115,32,73,73,32,45,32,71,117,110,32,70,105,103,104,116,101,114,115,32,40,69,117,114,111,41,0,0,0,0,0,0,0,68,114,97,103,111,110,32,87,111,114,108,100,32,50,48,48,49,32,40,86,49,48,48,44,32,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,109,101,114,99,115,0,0,0,70,49,32,67,105,114,99,117,115,0,0,0,0,0,0,0,115,97,109,115,104,111,52,107,0,0,0,0,0,0,0,0,32,83,116,114,111,110,103,32,80,117,110,99,104,0,0,0,109,100,95,108,101,50,0,0,109,100,95,115,105,100,101,112,111,99,107,117,0,0,0,0,109,112,97,110,103,0,0,0,105,110,112,117,116,95,112,108,97,121,101,114,55,0,0,0,76,101,116,104,97,108,32,69,110,102,111,114,99,101,114,115,32,40,85,83,65,41,0,0,109,100,95,108,101,116,104,97,108,101,110,117,0,0,0,0,70,70,109,112,101,103,0,0,76,101,116,104,97,108,32,69,110,102,111,114,99,101,114,115,32,40,74,112,110,41,0,0,109,111,111,110,99,114,115,116,117,0,0,0,0,0,0,0,109,100,95,108,101,116,104,97,108,101,110,106,0,0,0,0,76,101,116,104,97,108,32,69,110,102,111,114,99,101,114,115,32,40,69,117,114,111,41,0,0,0,0,0,0,0,0,0,67,104,101,97,116,32,73,110,100,101,120,32,77,105,110,117,115,0,0,0,0,0,0,0,66,114,97,107,101,32,50,0,109,100,95,108,101,116,104,97,108,101,110,0,0,0,0,0,83,97,109,101,32,97,115,32,115,116,97,114,116,0,0,0,51,68,32,69,102,102,101,99,116,115,0,0,0,0,0,0,76,101,109,109,105,110,103,115,32,50,32,45,32,84,104,101,32,84,114,105,98,101,115,32,40,85,83,65,41,0,0,0,87,114,101,115,116,108,101,32,87,97,114,32,40,115,101,116,32,51,44,32,87,111,114,108,100,44,32,56,55,53,49,32,51,49,55,45,48,49,48,51,41,0,0,0,0,0,0,0,99,104,45,62,107,99,111,100,101,0,0,0,0,0,0,0,80,50,32,82,105,103,104,116,32,68,111,119,110,0,0,0,77,97,105,110,0,0,0,0,67,111,105,110,32,83,108,111,116,32,66,0,0,0,0,0,109,100,95,108,101,109,109,105,110,103,50,117,0,0,0,0,52,32,58,32,49,0,0,0,80,49,32,70,108,105,112,32,70,108,111,112,0,0,0,0,66,111,97,114,100,119,97,108,107,32,67,97,115,105,110,111,0,0,0,0,0,0,0,0,83,117,112,101,114,32,71,97,108,97,120,105,97,110,115,32,40,103,97,108,97,120,105,97,106,32,104,97,99,107,41,0,0,0,0,0,0,0,0,0,76,101,109,109,105,110,103,115,32,50,32,45,32,84,104,101,32,84,114,105,98,101,115,32,40,69,117,114,111,41,0,0,100,119,50,48,48,49,0,0,82,111,99,107,109,97,110,32,45,32,116,104,101,32,112,111,119,101,114,32,98,97,116,116,108,101,32,40,57,53,48,57,50,50,32,74,97,112,97,110,41,0,0,0,0,0,0,0,112,99,101,95,102,49,99,105,114,99,117,115,0,0,0,0,83,0,0,0,97,0,0,0,109,0,0,0,117,0,0,0,114,0,0,0,97,0,0,0,105,0,0,0,32,0,0,0,83,0,0,0,104,0,0,0,111,0,0,0,100,0,0,0,111,0,0,0,119,0,0,0,110,0,0,0,32,0,0,0,73,0,0,0,86,0,0,0,32,0,0,0,45,0,0,0,32,0,0,0,65,0,0,0,109,0,0,0,97,0,0,0,107,0,0,0,117,0,0,0,115,0,0,0,97,0,0,0,39,0,0,0,115,0,0,0,32,0,0,0,82,0,0,0,101,0,0,0,118,0,0,0,101,0,0,0,110,0,0,0,103,0,0,0,101,0,0,0,0,0,0,0,181,48,0,0,224,48,0,0,233,48,0,0,164,48,0,0,185,48,0,0,212,48,0,0,234,48,0,0,195,48,0,0,196,48,0,0,32,0,0,0,45,0,0,0,32,0,0,0,41,89,0,0,73,131,0,0,77,150,0,0,232,129,0,0,32,0,0,0,40,0,0,0,78,0,0,0,71,0,0,0,77,0,0,0,45,0,0,0,50,0,0,0,50,0,0,0,50,0,0,0,41,0,0,0,40,0,0,0,78,0,0,0,71,0,0,0,72,0,0,0,45,0,0,0,50,0,0,0,50,0,0,0,50,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,32,77,101,100,105,117,109,32,80,117,110,99,104,0,0,0,109,100,95,108,101,109,109,105,110,103,50,0,0,0,0,0,74,101,119,101,108,32,77,97,115,116,101,114,32,40,69,117,114,111,44,32,85,83,65,44,32,82,101,118,46,32,65,41,0,0,0,0,0,0,0,0,77,97,114,115,32,77,97,116,114,105,120,32,40,48,48,48,52,49,50,32,74,97,112,97,110,41,0,0,0,0,0,0,109,117,116,97,110,116,102,52,0,0,0,0,0,0,0,0,105,110,112,117,116,95,112,108,97,121,101,114,54,0,0,0,76,101,109,109,105,110,103,115,32,40,74,112,110,44,32,85,83,65,41,0,0,0,0,0,71,97,108,73,110,112,117,116,0,0,0,0,0,0,0,0,109,100,95,108,101,109,109,105,110,103,115,106,117,49,0,0,68,121,110,97,109,105,99,32,114,117,110,45,116,105,109,101,32,108,111,97,100,105,110,103,32,111,102,32,108,105,98,114,101,116,114,111,32,108,105,98,114,97,114,121,0,0,0,0,103,97,110,103,111,110,116,97,0,0,0,0,0,0,0,0,76,101,109,109,105,110,103,115,32,40,74,112,110,44,32,85,83,65,44,32,75,111,114,44,32,118,49,46,49,41,0,0,77,111,111,110,32,67,114,101,115,116,97,32,40,78,105,99,104,105,98,117,116,115,117,32,85,75,44,32,117,110,101,110,99,114,121,112,116,101,100,41,0,0,0,0,0,0,0,0,109,100,95,108,101,109,109,105,110,103,115,106,117,0,0,0,76,101,109,109,105,110,103,115,32,40,69,117,114,111,41,0,0,0,0,0,0,0,0,0,67,104,101,97,116,32,73,110,100,101,120,32,80,108,117,115,0,0,0,0,0,0,0,0,115,97,109,115,104,111,52,0,80,50,32,115,116,97,114,116,0,0,0,0,0,0,0,0,109,100,95,108,101,109,109,105,110,103,115,0,0,0,0,0,49,32,67,111,105,110,32,49,32,67,114,101,100,105,116,0,119,114,101,115,116,119,97,114,0,0,0,0,0,0,0,0,71,97,108,97,104,97,100,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,73,68,32,78,117,109,98,101,114,0,0,0,0,0,0,0,50,53,48,48,48,48,32,101,118,101,114,121,0,0,0,0,109,100,95,103,97,108,97,104,97,100,0,0,0,0,0,0,98,119,99,97,115,105,110,111,0,0,0,0,0,0,0,0,112,49,32,85,112,0,0,0,84,104,101,32,76,97,119,110,109,111,119,101,114,32,77,97,110,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,66,0,0,0,101,0,0,0,101,0,0,0,32,0,0,0,83,0,0,0,116,0,0,0,111,0,0,0,114,0,0,0,109,0,0,0,32,0,0,0,45,0,0,0,32,0,0,0,68,0,0,0,111,0,0,0,68,0,0,0,111,0,0,0,110,0,0,0,80,0,0,0,97,0,0,0,116,0,0,0,99,0,0,0,104,0,0,0,105,0,0,0,32,0,0,0,73,0,0,0,73,0,0,0,0,0,0,0,18,96,0,0,150,153,0,0,134,152,0,0,2,135,0,0,13,255,0,0,2,135,0,0,180,102,0,0,32,0,0,0,40,0,0,0,86,0,0,0,49,0,0,0,48,0,0,0,48,0,0,0,44,0,0,0,32,0,0,0,67,0,0,0,104,0,0,0,105,0,0,0,110,0,0,0,97,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,114,111,99,107,109,97,110,106,0,0,0,0,0,0,0,0,70,49,32,67,105,114,99,117,115,32,39,57,50,32,45,32,84,104,101,32,83,112,101,101,100,32,111,102,32,83,111,117,110,100,0,0,0,0,0,0,83,97,109,117,114,97,105,32,83,104,111,100,111,119,110,32,73,86,32,45,32,65,109,97,107,117,115,97,39,115,32,82,101,118,101,110,103,101,32,47,32,83,97,109,117,114,97,105,32,83,112,105,114,105,116,115,32,45,32,65,109,97,107,117,115,97,32,75,111,117,114,105,110,32,40,78,71,77,45,50,50,50,41,40,78,71,72,45,50,50,50,41,0,0,0,0,32,87,101,97,107,32,80,117,110,99,104,0,0,0,0,0,109,100,95,108,97,119,110,109,111,119,114,0,0,0,0,0,109,100,95,106,101,119,101,108,109,115,0,0,0,0,0,0,109,109,97,116,114,105,120,106,0,0,0,0,0,0,0,0,105,110,112,117,116,95,112,108,97,121,101,114,53,0,0,0,72,111,107,117,116,111,32,110,111,32,75,101,110,32,45,32,83,104,105,110,32,83,101,105,107,105,109,97,116,115,117,32,75,121,117,117,115,101,105,115,104,117,32,68,101,110,115,101,116,115,117,32,40,74,112,110,41,0,0,0,0,0,0,0,109,100,95,104,111,107,117,116,111,0,0,0,0,0,0,0,68,121,110,97,109,105,99,0,76,97,115,116,32,66,97,116,116,108,101,32,40,69,117,114,111,44,32,85,83,65,44,32,75,111,114,41,0,0,0,0,109,111,111,110,99,114,115,116,117,107,117,0,0,0,0,0,109,100,95,108,97,115,116,98,116,108,101,0,0,0,0,0,76,97,115,116,32,65,99,116,105,111,110,32,72,101,114,111,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,99,111,98,114,97,99,111,109,98,0,0,0,0,0,0,0,80,114,101,118,105,111,117,115,32,83,104,97,100,101,114,0,80,49,32,115,116,97,114,116,0,0,0,0,0,0,0,0,109,100,95,108,97,115,116,97,99,116,0,0,0,0,0,0,71,97,108,83,104,111,111,116,69,110,97,98,108,101,0,0,80,114,105,99,101,32,116,111,32,67,111,110,116,105,110,117,101,0,0,0,0,0,0,0,56,48,48,107,32,111,110,108,121,0,0,0,0,0,0,0,76,97,110,103,114,105,115,115,101,114,32,73,73,32,40,74,112,110,41,0,0,0,0,0,80,50,32,82,105,103,104,116,32,85,112,0,0,0,0,0,82,105,100,101,32,79,110,0,50,48,48,48,48,48,44,32,55,48,48,48,48,48,112,116,115,0,0,0,0,0,0,0,109,100,95,108,97,110,103,114,105,115,50,98,0,0,0,0,84,105,99,107,101,116,32,77,111,100,101,32,50,0,0,0,80,49,32,82,101,97,99,104,0,0,0,0,0,0,0,0,68,114,101,97,109,32,83,104,111,112,112,101,114,0,0,0,106,111,105,110,101,109,95,115,110,100,95,98,105,116,0,0,76,97,110,103,114,105,115,115,101,114,32,73,73,32,40,74,112,110,44,32,118,49,46,49,41,0,0,0,0,0,0,0,66,101,101,32,83,116,111,114,109,32,45,32,68,111,68,111,110,80,97,99,104,105,32,73,73,32,40,86,49,48,48,44,32,67,104,105,110,97,41,0,0,0,0,0,0,0,0,0,77,101,103,97,32,77,97,110,32,45,32,116,104,101,32,112,111,119,101,114,32,98,97,116,116,108,101,32,40,57,53,49,48,48,54,32,65,115,105,97,41,0,0,0,0,0,0,0,112,99,101,95,102,49,99,105,114,99,57,50,0,0,0,0,32,102,105,114,101,0,0,0,109,100,95,108,97,110,103,114,105,115,50,97,0,0,0,0,67,97,112,99,111,109,32,47,32,84,97,107,117,109,105,0,110,99,111,109,98,97,116,0,105,110,112,117,116,95,112,108,97,121,101,114,52,0,0,0,83,116,97,114,116,32,49,0,76,97,110,103,114,105,115,115,101,114,32,73,73,32,40,74,112,110,44,32,118,49,46,50,41,0,0,0,0,0,0,0,37,48,56,120,58,32,67,111,45,80,114,111,99,101,115,115,111,114,32,82,101,103,105,115,116,101,114,32,84,114,97,110,115,102,101,114,32,101,120,101,99,117,116,101,100,44,32,98,117,116,32,110,111,32,82,84,32,87,114,105,116,101,32,99,97,108,108,98,97,99,107,32,100,101,102,105,110,101,100,33,10,0,0,0,0,0,0,0,87,105,122,97,114,100,32,70,105,114,101,32,40,85,83,32,118,49,46,49,41,0,0,0,109,100,95,108,97,110,103,114,105,115,50,0,0,0,0,0,79,112,101,110,71,76,32,114,101,110,100,101,114,45,116,111,45,116,101,120,116,117,114,101,32,40,109,117,108,116,105,45,112,97,115,115,32,115,104,97,100,101,114,115,41,0,0,0,82,45,62,116,99,115,114,0,67,101,110,116,117,114,121,32,69,108,101,99,116,114,111,110,105,99,115,32,47,32,83,101,97,116,111,110,103,114,111,118,101,32,76,116,100,0,0,0,50,32,99,111,105,110,32,49,32,112,108,97,121,0,0,0,84,101,115,116,0,0,0,0,102,105,120,101,105,103,104,116,97,0,0,0,0,0,0,0,76,97,110,103,114,105,115,115,101,114,32,40,74,112,110,41,0,0,0,0,0,0,0,0,84,111,97,112,108,97,110,32,47,32,84,97,105,116,111,0,49,32,67,111,105,110,32,32,49,32,67,114,101,100,105,116,115,0,0,0,0,0,0,0,78,105,99,104,105,98,117,116,115,117,32,85,75,0,0,0,109,100,95,119,97,114,115,111,110,103,0,0,0,0,0,0,109,100,95,108,97,110,103,114,105,115,115,0,0,0,0,0,78,101,120,116,32,83,104,97,100,101,114,0,0,0,0,0,109,97,103,100,114,111,112,50,0,0,0,0,0,0,0,0,80,50,32,84,117,114,110,32,50,0,0,0,0,0,0,0,76,97,110,100,115,116,97,108,107,101,114,32,45,32,84,114,101,97,115,117,114,101,32,111,102,32,75,105,110,103,32,78,111,108,101,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,109,97,105,110,95,115,101,110,116,0,0,0,0,0,0,0,52,32,67,111,105,110,115,32,49,32,67,114,101,100,105,116,0,0,0,0,0,0,0,0,104,98,97,114,114,101,108,0,68,105,110,111,32,82,101,120,32,40,87,111,114,108,100,41,0,0,0,0,0,0,0,0,54,48,48,107,32,111,110,108,121,0,0,0,0,0,0,0,66,121,103,111,110,101,0,0,109,100,95,108,97,110,100,115,116,108,107,117,112,0,0,0,85,115,101,0,0,0,0,0,50,32,67,111,105,110,32,32,51,32,67,114,101,100,105,116,115,0,0,0,0,0,0,0,65,114,107,97,110,111,105,100,32,45,32,82,101,118,101,110,103,101,32,111,102,32,68,79,72,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,49,53,48,48,48,48,44,32,53,48,48,48,48,48,112,116,115,0,0,0,0,0,0,0,97,114,107,97,110,111,105,100,106,98,50,0,0,0,0,0,76,97,110,100,115,116,97,108,107,101,114,32,45,32,84,104,101,32,84,114,101,97,115,117,114,101,115,32,111,102,32,75,105,110,103,32,78,111,108,101,32,40,85,83,65,41,0,0,84,105,99,107,101,116,32,77,111,100,101,32,49,0,0,0,118,99,101,95,99,111,110,116,114,111,108,0,0,0,0,0,114,97,109,98,111,51,0,0,100,114,101,109,115,104,112,114,0,0,0,0,0,0,0,0,118,111,108,102,105,101,100,95,99,117,114,114,101,110,116,95,98,97,110,107,0,0,0,0,109,100,95,108,97,110,100,115,116,108,107,117,0,0,0,0,99,104,97,114,100,109,97,95,116,97,98,108,101,95,97,100,100,114,101,115,115,0,0,0,111,112,119,111,108,102,117,0,75,111,107,111,110,116,111,117,122,97,105,32,69,116,111,32,77,111,110,111,103,97,116,97,114,105,32,40,74,97,112,97,110,41,0,0,0,0,0,0,100,100,112,50,49,48,48,99,0,0,0,0,0,0,0,0,109,101,103,97,109,97,110,97,0,0,0,0,0,0,0,0,78,105,104,111,110,32,66,117,115,115,97,110,0,0,0,0,75,0,0,0,105,0,0,0,122,0,0,0,117,0,0,0,110,0,0,0,97,0,0,0,32,0,0,0,69,0,0,0,110,0,0,0,99,0,0,0,111,0,0,0,117,0,0,0,110,0,0,0,116,0,0,0,101,0,0,0,114,0,0,0,32,0,0,0,45,0,0,0,32,0,0,0,83,0,0,0,117,0,0,0,112,0,0,0,101,0,0,0,114,0,0,0,32,0,0,0,84,0,0,0,97,0,0,0,103,0,0,0,32,0,0,0,66,0,0,0,97,0,0,0,116,0,0,0,116,0,0,0,108,0,0,0,101,0,0,0,0,0,0,0,168,152,0,0,242,150,0,0,32,0,0,0,83,0,0,0,117,0,0,0,112,0,0,0,101,0,0,0,114,0,0,0,32,0,0,0,84,0,0,0,97,0,0,0,103,0,0,0,32,0,0,0,66,0,0,0,97,0,0,0,116,0,0,0,116,0,0,0,108,0,0,0,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,76,97,110,100,115,116,97,108,107,101,114,32,45,32,75,111,117,116,101,105,32,110,111,32,90,97,105,104,111,117,32,40,74,112,110,41,0,0,0,0,115,98,111,98,108,98,111,98,0,0,0,0,0,0,0,0,115,117,112,101,114,109,97,110,106,0,0,0,0,0,0,0,80,97,112,101,114,98,111,121,32,50,32,40,69,117,114,111,44,32,85,83,65,41,0,0,77,97,114,115,32,77,97,116,114,105,120,32,40,48,48,48,52,49,50,32,85,83,65,41,0,0,0,0,0,0,0,0,115,104,97,110,103,111,110,51,0,0,0,0,0,0,0,0,105,110,112,117,116,95,112,108,97,121,101,114,51,0,0,0,109,100,95,108,97,110,100,115,116,108,107,106,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,73,32,51,114,100,32,83,116,114,105,107,101,58,32,70,105,103,104,116,32,102,111,114,32,116,104,101,32,70,117,116,117,114,101,32,40,69,117,114,111,32,57,57,48,54,48,56,41,0,0,0,0,0,0,0,97,108,116,98,101,97,115,116,50,0,0,0,0,0,0,0,83,121,115,116,101,109,49,54,76,97,115,116,71,101,97,114,0,0,0,0,0,0,0,0,76,97,110,100,115,116,97,108,107,101,114,32,45,32,68,105,101,32,83,99,104,228,116,122,101,32,118,111,110,32,75,246,110,105,103,32,78,111,108,111,32,40,71,101,114,41,0,0,70,66,79,0,0,0,0,0,68,46,32,68,46,32,67,114,101,119,32,40,115,101,116,32,52,44,32,87,111,114,108,100,44,32,51,32,80,108,97,121,101,114,115,44,32,70,68,49,48,57,52,32,51,49,55,45,48,49,57,48,41,0,0,0,80,111,119,101,114,32,68,114,105,102,116,32,40,87,111,114,108,100,44,32,69,97,114,108,105,101,114,41,0,0,0,0,109,100,95,108,97,110,100,115,116,108,107,103,0,0,0,0,76,97,115,116,32,83,117,114,118,105,118,111,114,32,40,70,68,49,48,57,52,32,51,49,55,45,48,48,56,51,41,0,0,0,0,0,0,0,0,0,77,111,111,110,32,67,114,101,115,116,97,32,40,78,105,99,104,105,98,117,116,115,117,32,85,75,41,0,0,0,0,0,50,32,67,111,105,110,115,32,53,32,67,114,101,100,105,116,115,0,0,0,0,0,0,0,86,100,112,67,109,100,80,97,114,116,0,0,0,0,0,0,65,108,105,101,110,32,83,121,110,100,114,111,109,101,32,40,115,101,116,32,53,44,32,83,121,115,116,101,109,32,49,54,65,44,32,70,68,49,48,56,57,66,32,51,49,55,45,48,48,51,55,41,0,0,0,0,76,97,110,100,115,116,97,108,107,101,114,32,45,32,84,104,101,32,84,114,101,97,115,117,114,101,115,32,111,102,32,75,105,110,103,32,78,111,108,101,32,40,69,117,114,111,41,0,0,0,0,0,0,0,0,0,66,97,107,117,114,101,116,115,117,32,66,114,101,97,107,101,114,0,0,0,0,0,0,0,116,97,110,103,116,97,110,103,0,0,0,0,0,0,0,0,118,105,100,101,111,95,118,115,121,110,99,0,0,0,0,0,76,97,107,101,114,115,32,118,101,114,115,117,115,32,67,101,108,116,105,99,115,32,97,110,100,32,116,104,101,32,78,66,65,32,80,108,97,121,111,102,102,115,32,40,85,83,65,41,0,0,0,0,0,0,0,0,71,97,114,111,103,117,110,32,83,101,114,111,121,97,110,103,32,40,75,111,114,101,97,41,0,0,0,0,0,0,0,0,80,49,32,84,117,114,110,32,50,0,0,0,0,0,0,0,109,100,95,108,97,107,101,114,115,0,0,0,0,0,0,0,83,116,105,99,107,32,89,0,69,118,101,114,121,32,54,48,48,107,0,0,0,0,0,0,83,112,101,99,105,97,108,32,80,114,105,122,101,32,65,118,97,105,108,97,98,108,101,0,76,97,32,82,117,115,115,97,32,66,97,115,101,98,97,108,108,32,57,53,32,40,85,83,65,44,32,79,99,101,97,110,105,97,41,0,0,0,0,0,87,111,110,100,101,114,32,66,111,121,32,73,73,73,32,45,32,77,111,110,115,116,101,114,32,76,97,105,114,32,40,115,101,116,32,52,44,32,74,97,112,97,110,44,32,83,121,115,116,101,109,32,49,54,66,44,32,70,68,49,48,57,52,32,51,49,55,45,48,48,56,55,41,0,0,0,0,0,0,0,70,99,114,97,115,104,90,56,48,66,97,110,107,65,100,100,114,101,115,115,0,0,0,0,80,50,32,76,101,102,116,32,82,105,103,104,116,0,0,0,83,116,97,114,116,32,66,117,116,116,111,110,0,0,0,0,97,105,114,97,116,116,99,107,97,0,0,0,0,0,0,0,82,97,105,100,101,110,32,40,85,83,44,32,115,101,116,32,50,44,32,83,69,73,56,57,48,52,32,43,32,83,69,73,57,48,48,56,32,80,67,66,115,41,0,0,0,0,0,0,109,100,95,108,97,114,117,115,115,57,53,0,0,0,0,0,49,32,58,32,50,0,0,0,83,116,97,114,116,105,110,103,32,66,97,108,108,115,0,0,80,49,32,82,111,110,0,0,65,109,101,110,105,112,32,78,111,118,97,32,71,97,109,101,115,32,76,116,100,46,0,0,113,117,101,115,116,105,111,110,95,114,111,109,0,0,0,0,87,0,0,0,105,0,0,0,108,0,0,0,100,0,0,0,32,0,0,0,70,0,0,0,97,0,0,0,110,0,0,0,103,0,0,0,0,0,0,0,84,0,0,0,101,0,0,0,99,0,0,0,109,0,0,0,111,0,0,0,32,0,0,0,75,0,0,0,110,0,0,0,105,0,0,0,103,0,0,0,104,0,0,0,116,0,0,0,0,0,0,0,0,0,0,0,75,121,117,117,107,97,105,32,68,111,117,99,104,117,117,107,105,32,40,74,112,110,41,0,0,0,0,0,0,0,0,0,66,0,0,0,101,0,0,0,101,0,0,0,32,0,0,0,83,0,0,0,116,0,0,0,111,0,0,0,114,0,0,0,109,0,0,0,32,0,0,0,45,0,0,0,32,0,0,0,68,0,0,0,111,0,0,0,68,0,0,0,111,0,0,0,110,0,0,0,80,0,0,0,97,0,0,0,116,0,0,0,99,0,0,0,104,0,0,0,105,0,0,0,32,0,0,0,73,0,0,0,73,0,0,0,0,0,0,0,18,96,0,0,150,153,0,0,134,152,0,0,2,135,0,0,13,255,0,0,2,135,0,0,180,102,0,0,32,0,0,0,40,0,0,0,86,0,0,0,49,0,0,0,48,0,0,0,49,0,0,0,44,0,0,0,32,0,0,0,67,0,0,0,104,0,0,0,105,0,0,0,110,0,0,0,97,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,70,97,110,116,97,115,121,32,39,57,53,0,0,0,0,0,77,101,103,97,32,77,97,110,32,45,32,116,104,101,32,112,111,119,101,114,32,98,97,116,116,108,101,32,40,57,53,49,48,48,54,32,85,83,65,41,0,0,0,0,0,0,0,0,70,49,32,67,105,114,99,117,115,32,39,57,49,32,45,32,87,111,114,108,100,32,67,104,97,109,112,105,111,110,115,104,105,112,0,0,0,0,0,0,75,105,122,117,110,97,32,69,110,99,111,117,110,116,101,114,32,45,32,83,117,112,101,114,32,84,97,103,32,66,97,116,116,108,101,32,47,32,70,117,39,117,110,32,83,117,112,101,114,32,84,97,103,32,66,97,116,116,108,101,0,0,0,0,109,100,95,107,121,117,107,97,105,100,107,0,0,0,0,0,66,97,99,107,103,114,111,117,110,100,32,83,99,114,111,108,108,32,82,65,77,0,0,0,80,114,101,116,116,121,32,83,111,108,100,105,101,114,32,83,97,105,108,111,114,32,77,111,111,110,32,40,118,101,114,46,32,57,53,47,48,51,47,50,50,66,44,32,72,111,110,103,32,75,111,110,103,41,0,0,109,100,95,112,97,112,101,114,98,111,50,0,0,0,0,0,109,109,97,116,114,105,120,0,105,110,112,117,116,95,112,108,97,121,101,114,50,0,0,0,75,114,117,115,116,121,39,115,32,83,117,112,101,114,32,70,117,110,32,72,111,117,115,101,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,115,112,105,110,108,98,114,107,117,0,0,0,0,0,0,0,109,100,95,107,114,117,115,116,121,49,0,0,0,0,0,0,84,104,101,32,67,111,109,98,97,116,114,105,98,101,115,32,40,98,111,111,116,108,101,103,32,115,101,116,32,49,41,0,0,0,0,0,0,0,0,0,83,68,76,95,105,109,97,103,101,32,105,109,97,103,101,32,108,111,97,100,105,110,103,0,81,117,105,122,32,75,111,107,111,108,111,103,121,0,0,0,75,114,117,115,116,121,39,115,32,83,117,112,101,114,32,70,117,110,32,72,111,117,115,101,32,40,69,117,114,111,44,32,85,83,65,44,32,118,49,46,49,41,0,0,0,0,0,0,49,32,67,111,105,110,45,50,32,80,108,97,121,0,0,0,82,101,116,114,111,65,114,99,104,58,32,71,114,97,112,104,105,99,115,32,100,114,105,118,101,114,32,100,105,100,32,110,111,116,32,105,110,105,116,105,97,108,105,122,101,32,97,110,32,105,110,112,117,116,32,100,114,105,118,101,114,46,32,65,116,116,101,109,112,116,105,110,103,32,116,111,32,112,105,99,107,32,97,32,115,117,105,116,97,98,108,101,32,100,114,105,118,101,114,46,10,0,0,0,109,111,111,110,99,114,115,116,117,107,0,0,0,0,0,0,77,111,114,101,32,77,111,114,101,32,80,108,117,115,0,0,68,111,110,103,32,71,117,101,32,76,97,32,77,105,32,76,116,100,46,0,0,0,0,0,109,100,95,107,114,117,115,116,121,0,0,0,0,0,0,0,66,0,0,0,97,0,0,0,116,0,0,0,116,0,0,0,108,0,0,0,101,0,0,0,32,0,0,0,75,0,0,0,45,0,0,0,82,0,0,0,111,0,0,0,97,0,0,0])
.concat([100,0,0,0,0,0,0,0,66,0,0,0,97,0,0,0,116,0,0,0,116,0,0,0,108,0,0,0,101,0,0,0,32,0,0,0,75,0,0,0,45,0,0,0,82,0,0,0,111,0,0,0,97,0,0,0,100,0,0,0,32,0,0,0,208,48,0,0,200,48,0,0,235,48,0,0,175,48,0,0,237,48,0,0,252,48,0,0,201,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,83,116,114,105,107,101,114,115,32,49,57,52,53,32,73,73,73,32,40,87,111,114,108,100,41,32,47,32,83,116,114,105,107,101,114,115,32,49,57,57,57,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,108,111,100,101,114,110,100,102,97,0,0,0,0,0,0,0,75,108,97,120,32,40,74,112,110,41,0,0,0,0,0,0,68,114,118,79,107,105,66,97,110,107,50,95,50,0,0,0,73,82,81,0,0,0,0,0,115,116,114,97,116,118,111,120,98,0,0,0,0,0,0,0,116,101,114,114,97,102,0,0,105,114,111,110,99,108,97,100,0,0,0,0,0,0,0,0,80,50,32,84,117,114,110,32,49,0,0,0,0,0,0,0,109,100,95,107,108,97,120,106,0,0,0,0,0,0,0,0,100,111,107,97,98,101,110,0,67,111,105,110,49,32,47,32,67,111,105,110,50,0,0,0,83,116,105,99,107,32,88,0,119,98,51,52,0,0,0,0,75,108,97,120,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,0,0,49,32,67,111,105,110,115,32,52,32,67,114,101,100,105,116,115,0,0,0,0,0,0,0,69,0,0,0,0,0,0,0,91,78,97,109,99,111,93,32,40,77,105,100,119,97,121,32,108,105,99,101,110,115,101,41,0,0,0,0,0,0,0,0,51,32,67,111,105,110,32,49,32,67,114,101,100,105,116,115,0,0,0,0,0,0,0,0,103,97,117,110,116,108,101,116,103,114,54,0,0,0,0,0,109,100,95,107,108,97,120,0,48,48,58,51,48,0,0,0,49,32,58,32,49,0,0,0,57,48,32,83,101,99,111,110,100,115,0,0,0,0,0,0,47,112,114,111,99,47,37,117,47,37,115,0,0,0,0,0,78,97,117,103,104,116,121,32,77,111,117,115,101,32,40,115,101,116,32,50,41,0,0,0,48,45,55,0,0,0,0,0,68,111,114,111,100,111,110,32,40,115,101,116,32,50,41,0,0,0,0,0,0,0,0,0,113,117,101,115,116,105,111,110,95,97,100,100,114,101,115,115,0,0,0,0,0,0,0,0,75,105,115,115,32,83,104,111,116,32,40,74,112,110,44,32,83,101,103,97,78,101,116,41,0,0,0,0,0,0,0,0,68,111,110,107,101,121,32,75,111,110,103,32,40,74,97,112,97,110,32,115,101,116,32,51,41,0,0,0,0,0,0,0,66,101,101,32,83,116,111,114,109,32,45,32,68,111,68,111,110,80,97,99,104,105,32,73,73,32,40,86,49,48,49,44,32,67,104,105,110,97,41,0,0,0,0,0,0,0,0,0,104,111,114,101,107,105,100,98,0,0,0,0,0,0,0,0,112,99,101,95,102,49,99,105,114,99,57,49,0,0,0,0,84,111,107,105,32,40,98,111,111,116,108,101,103,41,0,0,107,105,122,117,110,97,0,0,109,100,95,107,105,115,115,115,104,111,116,0,0,0,0,0,68,114,118,80,97,108,101,116,116,101,66,97,110,107,0,0,115,111,117,110,100,108,97,116,99,104,91,48,93,0,0,0,83,107,105,116,99,104,105,110,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,82,111,99,107,109,97,110,58,32,84,104,101,32,80,111,119,101,114,32,66,97,116,116,108,101,32,40,57,53,48,57,50,50,32,74,97,112,97,110,41,0,0,0,0,0,0,0,0,67,117,114,118,101,32,69,102,102,101,99,116,0,0,0,0,116,114,111,106,97,110,97,0,105,110,112,117,116,95,112,108,97,121,101,114,49,0,0,0,75,105,115,104,105,32,68,101,110,115,101,116,115,117,32,40,74,112,110,41,0,0,0,0,83,116,114,101,101,116,32,83,109,97,114,116,32,40,87,111,114,108,100,32,118,101,114,115,105,111,110,32,49,41,0,0,49,0,0,0,57,0,0,0,52,0,0,0,51,0,0,0,32,0,0,0,57,101,0,0,58,0,0,0,32,0,0,0,223,48,0,0,195,48,0,0,201,48,0,0,166,48,0,0,167,48,0,0,164,48,0,0,119,109,0,0,38,98,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,109,100,95,107,105,115,104,105,100,101,110,0,0,0,0,0,83,68,76,95,105,109,97,103,101,0,0,0,0,0,0,0,70,108,97,115,104,103,97,108,32,40,115,101,116,32,50,41,0,0,0,0,0,0,0,0,108,101,100,115,116,111,114,109,50,0,0,0,0,0,0,0,75,105,110,103,39,115,32,66,111,117,110,116,121,32,45,32,84,104,101,32,67,111,110,113,117,101,114,111,114,39,115,32,81,117,101,115,116,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,0,77,111,111,110,32,67,114,101,115,116,97,32,40,78,105,99,104,105,98,117,116,115,117,41,0,0,0,0,0,0,0,0,49,48,32,67,111,105,110,115,32,49,32,67,114,101,100,105,116,0,0,0,0,0,0,0,103,110,103,99,0,0,0,0,109,100,95,107,105,110,103,115,98,116,121,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,32,110,111,116,32,114,101,97,100,32,82,79,77,32,102,105,108,101,58,32,34,37,115,34,46,10,0,0,0,0,50,32,67,111,105,110,115,32,49,32,67,114,101,100,105,116,32,32,47,32,50,32,67,111,105,110,115,32,49,32,32,67,114,101,100,105,116,32,0,0,87,99,57,48,83,99,114,111,108,108,49,89,76,111,0,0,54,32,67,111,105,110,115,47,52,32,67,114,101,100,105,116,115,0,0,0,0,0,0,0,83,105,108,107,32,87,111,114,109,32,40,98,111,111,116,108,101,103,41,0,0,0,0,0,75,105,110,103,32,83,97,108,109,111,110,32,40,74,112,110,41,0,0,0,0,0,0,0,107,111,118,50,0,0,0,0,80,97,117,115,101,32,84,111,103,103,108,101,0,0,0,0,109,95,100,114,103,119,50,95,99,109,100,0,0,0,0,0,80,49,32,84,117,114,110,32,49,0,0,0,0,0,0,0,109,100,95,107,105,110,103,115,97,108,106,0,0,0,0,0,79,114,105,101,110,116,97,108,32,76,101,103,101,110,100,32,45,32,88,105,32,89,111,32,71,105,32,83,104,105,32,82,101,32,90,117,97,110,103,32,40,86,49,49,49,44,32,67,104,105,110,97,41,0,0,0,82,101,115,117,108,116,115,32,80,114,105,110,116,101,114,0,49,48,32,115,104,111,116,115,32,47,32,115,101,99,111,110,100,115,0,0,0,0,0,0,87,111,110,100,101,114,32,66,111,121,32,73,73,73,32,45,32,77,111,110,115,116,101,114,32,76,97,105,114,32,40,115,101,116,32,51,44,32,87,111,114,108,100,44,32,83,121,115,116,101,109,32,49,54,66,44,32,70,68,49,48,57,52,32,51,49,55,45,48,48,56,57,41,0,0,0,0,0,0,0,75,105,110,103,32,83,97,108,109,111,110,32,45,32,84,104,101,32,66,105,103,32,67,97,116,99,104,32,40,85,83,65,41,0,0,0,0,0,0,0,80,50,32,76,101,102,116,32,76,101,102,116,0,0,0,0,80,50,32,84,117,114,110,32,82,105,103,104,116,0,0,0,49,32,67,111,105,110,115,32,51,32,67,114,101,100,105,116,115,0,0,0,0,0,0,0,80,108,97,121,101,114,32,115,116,111,99,107,0,0,0,0,109,100,95,107,105,110,103,115,97,108,0,0,0,0,0,0,50,32,58,32,49,0,0,0,80,49,32,75,97,110,0,0,110,109,111,117,115,101,98,0,75,105,110,103,32,111,102,32,116,104,101,32,77,111,110,115,116,101,114,115,32,50,32,40,85,83,65,41,0,0,0,0,115,116,114,105,118,32,113,117,101,115,116,105,111,110,32,97,100,100,114,101,115,115,101,115,0,0,0,0,0,0,0,0,67,112,115,90,82,111,109,0,100,100,112,50,49,48,49,99,0,0,0,0,0,0,0,0,109,101,103,97,109,97,110,0,70,45,49,32,80,105,108,111,116,32,45,32,89,111,117,39,114,101,32,75,105,110,103,32,111,102,32,75,105,110,103,115,0,0,0,0,0,0,0,0,84,0,0,0,104,0,0,0,101,0,0,0,32,0,0,0,85,0,0,0,108,0,0,0,116,0,0,0,105,0,0,0,109,0,0,0,97,0,0,0,116,0,0,0,101,0,0,0,32,0,0,0,49,0,0,0,49,0,0,0,32,0,0,0,45,0,0,0,32,0,0,0,83,0,0,0,78,0,0,0,75,0,0,0,32,0,0,0,70,0,0,0,111,0,0,0,111,0,0,0,116,0,0,0,98,0,0,0,97,0,0,0,108,0,0,0,108,0,0,0,32,0,0,0,67,0,0,0,104,0,0,0,97,0,0,0,109,0,0,0,112,0,0,0,105,0,0,0,111,0,0,0,110,0,0,0,115,0,0,0,104,0,0,0,105,0,0,0,112,0,0,0,0,0,0,0,151,95,0,0,185,112,0,0,139,115,0,0,32,0,0,0,45,0,0,0,32,0,0,0,142,112,0,0,110,48,0,0,234,48,0,0,217,48,0,0,237,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,87,111,110,100,101,114,32,51,32,40,57,49,48,53,50,48,32,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,66,97,115,101,98,97,108,108,32,83,116,97,114,115,32,80,114,111,102,101,115,115,105,111,110,97,108,32,40,78,71,72,45,48,48,50,41,0,0,0,109,100,95,107,111,116,109,50,0,0,0,0,0,0,0,0,65,68,80,67,77,32,115,97,109,112,108,101,32,82,65,77,0,0,0,0,0,0,0,0,109,100,95,115,107,105,116,99,104,105,110,0,0,0,0,0,114,109,97,110,99,112,50,106,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,70,111,117,110,100,32,105,110,118,97,108,105,100,32,104,97,116,32,105,110,32,99,111,110,102,105,103,33,10,0,0,0,0,0,0,0,75,105,110,103,32,111,102,32,116,104,101,32,77,111,110,115,116,101,114,115,32,40,74,112,110,41,0,0,0,0,0,0,109,100,95,107,111,116,109,106,0,0,0,0,0,0,0,0,108,105,98,120,109,108,50,32,88,77,76,32,112,97,114,115,105,110,103,0,0,0,0,0,83,76,79,84,45,62,118,105,98,0,0,0,0,0,0,0,103,108,68,101,98,117,103,77,101,115,115,97,103,101,67,97,108,108,98,97,99,107,0,0,75,105,110,103,32,111,102,32,116,104,101,32,77,111,110,115,116,101,114,115,32,40,85,83,65,41,0,0,0,0,0,0,109,111,111,110,99,114,115,116,0,0,0,0,0,0,0,0,84,101,120,116,117,114,101,83,105,122,101,0,0,0,0,0,109,100,95,107,111,116,109,117,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,71,76,93,58,32,70,97,105,108,101,100,32,116,111,32,99,114,101,97,116,101,32,69,71,76,32,105,109,97,103,101,46,10,0,83,65,86,69,83,84,65,84,69,32,68,73,82,32,37,115,0,0,0,0,0,0,0,0,75,105,110,103,32,111,102,32,116,104,101,32,77,111,110,115,116,101,114,115,32,40,69,117,114,111,41,0,0,0,0,0,60,82,79,77,32,100,105,114,62,0,0,0,0,0,0,0,77,111,118,105,101,32,82,101,99,111,114,100,32,84,111,103,103,108,101,0,0,0,0,0,76,111,116,117,115,32,84,117,114,98,111,32,67,104,97,108,108,101,110,103,101,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,0,75,48,53,50,49,48,57,95,105,114,113,95,101,110,97,98,108,101,100,0,0,0,0,0,112,103,111,97,108,0,0,0,83,116,97,114,116,32,52,0,109,100,95,107,111,116,109,0,103,97,114,117,107,97,0,0,55,32,115,104,111,116,115,32,47,32,115,101,99,111,110,100,115,0,0,0,0,0,0,0,65,117,116,111,32,70,105,114,101,0,0,0,0,0,0,0,73,78,70,79,32,45,32,76,111,97,100,105,110,103,32,37,115,32,46,46,46,0,0,0,119,98,51,51,0,0,0,0,84,111,117,103,105,111,117,32,75,105,110,103,32,67,111,108,111,115,115,117,115,32,40,74,112,110,41,0,0,0,0,0,112,51,32,121,45,97,120,105,115,0,0,0,0,0,0,0,80,50,32,84,117,114,110,32,76,101,102,116,0,0,0,0,109,100,95,107,105,110,103,99,111,108,0,0,0,0,0,0,51,32,58,32,49,0,0,0,87,105,110,110,105,110,103,32,82,111,117,110,100,115,32,40,118,115,32,109,111,100,101,41,0,0,0,0,0,0,0,0,102,114,97,103,109,101,110,116,0,0,0,0,0,0,0,0,78,97,117,103,104,116,121,32,77,111,117,115,101,32,40,115,101,116,32,49,41,0,0,0,71,114,97,100,105,117,115,32,73,73,32,45,32,71,79,70,69,82,32,110,111,32,89,97,98,111,117,32,40,74,97,112,97,110,32,78,101,119,32,118,101,114,46,41,0,0,0,0,75,105,100,111,117,32,75,101,105,115,97,116,115,117,32,80,97,116,108,97,98,111,114,32,45,32,57,56,45,115,104,105,107,105,32,75,105,100,111,117,32,83,101,121,111,33,32,40,74,112,110,41,0,0,0,0,49,57,52,52,106,0,0,0,66,0,0,0,101,0,0,0,101,0,0,0,32,0,0,0,83,0,0,0,116,0,0,0,111,0,0,0,114,0,0,0,109,0,0,0,32,0,0,0,45,0,0,0,32,0,0,0,68,0,0,0,111,0,0,0,68,0,0,0,111,0,0,0,110,0,0,0,80,0,0,0,97,0,0,0,116,0,0,0,99,0,0,0,104,0,0,0,105,0,0,0,32,0,0,0,73,0,0,0,73,0,0,0,0,0,0,0,18,96,0,0,150,153,0,0,134,152,0,0,2,135,0,0,13,255,0,0,2,135,0,0,180,102,0,0,32,0,0,0,40,0,0,0,86,0,0,0,49,0,0,0,48,0,0,0,50,0,0,0,44,0,0,0,32,0,0,0,67,0,0,0,104,0,0,0,105,0,0,0,110,0,0,0,97,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,69,115,99,97,112,101,32,75,105,100,115,32,40,74,97,112,97,110,44,32,50,32,80,108,97,121,101,114,115,41,0,0,84,104,101,32,75,105,110,103,32,111,102,32,68,114,97,103,111,110,115,32,40,80,104,111,101,110,105,120,32,98,111,111,116,108,101,103,44,32,57,49,48,55,51,49,32,101,116,99,41,0,0,0,0,0,0,0,112,99,101,95,102,49,112,105,108,111,116,0,0,0,0,0,84,104,101,32,85,108,116,105,109,97,116,101,32,49,49,32,45,32,84,104,101,32,83,78,75,32,70,111,111,116,98,97,108,108,32,67,104,97,109,112,105,111,110,115,104,105,112,32,47,32,84,111,107,117,116,101,110,32,79,117,32,45,32,72,111,110,111,111,32,110,111,32,76,105,98,101,114,111,0,0,111,118,101,114,108,97,121,37,117,95,114,97,110,103,101,95,109,111,100,0,0,0,0,0,109,100,95,112,97,116,108,97,98,111,114,0,0,0,0,0,70,73,70,65,32,83,111,99,99,101,114,32,57,53,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,84,101,101,110,97,103,101,32,77,117,116,97,110,116,32,72,101,114,111,32,84,117,114,116,108,101,115,32,40,85,75,32,50,32,80,108,97,121,101,114,115,44,32,115,101,116,32,50,41,0,0,0,0,0,0,0,77,101,103,97,32,77,97,110,32,45,32,84,104,101,32,80,111,119,101,114,32,66,97,116,116,108,101,32,40,57,53,49,48,48,54,32,85,83,65,44,32,83,65,77,80,76,69,32,86,101,114,115,105,111,110,41,0,0,0,0,0,0,0,0,78,101,119,32,65,116,111,109,105,99,32,80,117,110,107,32,45,32,71,108,111,98,97,108,32,81,117,101,115,116,32,40,85,83,41,0,0,0,0,0,108,100,114,117,110,0,0,0,67,104,97,109,101,108,101,111,110,32,75,105,100,32,40,74,112,110,41,0,0,0,0,0,98,117,99,99,97,110,114,115,0,0,0,0,0,0,0,0,73,110,32,84,104,101,32,72,117,110,116,32,40,85,83,41,0,0,0,0,0,0,0,0,120,109,117,108,116,105,112,108,109,55,50,0,0,0,0,0,109,100,95,107,105,100,99,104,97,109,106,0,0,0,0,0,108,105,98,120,109,108,50,0,75,105,99,107,32,79,102,102,32,51,32,45,32,69,117,114,111,112,101,97,110,32,67,104,97,108,108,101,110,103,101,32,40,69,117,114,111,41,0,0,65,114,109,101,110,105,97,32,47,32,70,111,111,100,32,97,110,100,32,70,117,110,0,0,109,100,95,107,105,99,107,111,102,102,51,0,0,0,0,0,75,97,119,97,115,97,107,105,32,83,117,112,101,114,98,105,107,101,32,67,104,97,108,108,101,110,103,101,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,83,116,97,114,116,32,51,0,109,100,95,107,97,119,97,115,97,107,105,112,0,0,0,0,84,114,105,103,103,101,114,32,84,117,114,98,111,0,0,0,87,111,110,100,101,114,32,66,111,121,32,73,73,73,32,45,32,77,111,110,115,116,101,114,32,76,97,105,114,32,40,115,101,116,32,50,44,32,74,97,112,97,110,44,32,83,121,115,116,101,109,32,49,54,66,44,32,70,68,49,48,57,52,32,51,49,55,45,48,48,56,53,41,0,0,0,0,0,0,0,75,97,119,97,115,97,107,105,32,83,117,112,101,114,98,105,107,101,32,67,104,97,108,108,101,110,103,101,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,0,0,80,50,32,76,101,102,116,32,68,111,119,110,0,0,0,0,80,51,32,89,45,65,120,105,115,0,0,0,0,0,0,0,53,32,67,111,105,110,115,32,51,32,67,114,101,100,105,116,115,0,0,0,0,0,0,0,109,100,95,107,97,119,97,115,97,107,105,0,0,0,0,0,67,111,105,110,32,58,32,67,114,101,100,105,116,0,0,0,80,49,32,67,104,105,0,0,110,109,111,117,115,101,0,0,75,97,45,71,101,45,75,105,32,40,74,112,110,41,0,0,66,101,101,32,83,116,111,114,109,32,45,32,68,111,68,111,110,80,97,99,104,105,32,73,73,32,40,86,49,48,50,44,32,67,104,105,110,97,41,0,0,0,0,0,0,0,0,0,107,111,100,100,97,0,0,0,78,69,67,0,0,0,0,0,115,115,105,100,101,107,105,52,0,0,0,0,0,0,0,0,109,100,95,107,97,103,101,107,105,106,0,0,0,0,0,0,83,117,112,101,114,32,84,104,117,110,100,101,114,32,66,108,97,100,101,32,40,87,111,114,108,100,41,0,0,0,0,0,75,97,45,71,101,45,75,105,32,45,32,70,105,115,116,115,32,111,102,32,83,116,101,101,108,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,109,100,95,107,97,103,101,107,105,0,0,0,0,0,0,0,67,103,32,112,105,120,101,108,32,115,104,97,100,101,114,115,0,0,0,0,0,0,0,0,83,97,118,101,100,32,115,116,97,116,101,32,116,111,32,115,108,111,116,32,35,37,117,46,0,0,0,0,0,0,0,0,74,117,115,116,105,99,101,32,76,101,97,103,117,101,32,84,97,115,107,32,70,111,114,99,101,32,40,87,111,114,108,100,41,0,0,0,0,0,0,0,52,32,70,117,110,32,105,110,32,49,0,0,0,0,0,0,70,111,117,114,105,110,49,66,97,110,107,0,0,0,0,0,109,100,95,106,108,101,97,103,117,101,0,0,0,0,0,0,74,117,114,97,115,115,105,99,32,80,97,114,107,32,45,32,82,97,109,112,97,103,101,32,69,100,105,116,105,111,110,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,54,51,48,41,0,0,0,83,116,97,116,101,32,83,108,111,116,32,77,105,110,117,115,0,0,0,0,0,0,0,0,109,100,95,106,112,97,114,107,114,101,112,55,0,0,0,0,114,97,103,110,97,103,114,100,0,0,0,0,0,0,0,0,84,117,114,98,111,0,0,0,103,108,69,71,76,73,109,97,103,101,84,97,114,103,101,116,84,101,120,116,117,114,101,50,68,79,69,83,0,0,0,0,119,98,51,50,0,0,0,0,74,117,114,97,115,115,105,99,32,80,97,114,107,32,45,32,82,97,109,112,97,103,101,32,69,100,105,116,105,111,110,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,54,50,50,41,0,0,0,112,51,32,120,45,97,120,105,115,0,0,0,0,0,0,0,67,111,105,110,32,83,108,111,116,32,65,0,0,0,0,0,109,100,95,106,112,97,114,107,114,101,112,56,0,0,0,0,77,97,120,32,118,115,32,82,111,117,110,100,0,0,0,0,86,97,110,45,86,97,110,32,67,97,114,32,40,115,101,116,32,51,41,0,0,0,0,0,74,117,114,97,115,115,105,99,32,80,97,114,107,32,45,32,82,97,109,112,97,103,101,32,69,100,105,116,105,111,110,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,54,50,48,41,0,0,0,100,100,112,50,99,0,0,0,84,104,101,32,75,105,110,103,32,111,102,32,68,114,97,103,111,110,115,32,40,104,97,99,107,41,0,0,0,0,0,0,84,104,101,32,75,105,110,103,32,111,102,32,70,105,103,104,116,101,114,115,32,39,57,54,32,40,78,71,72,45,50,49,52,41,0,0,0,0,0,0,109,100,95,106,112,97,114,107,114,101,112,57,0,0,0,0,110,83,121,110,99,78,101,120,116,0,0,0,0,0,0,0,109,100,95,115,116,98,108,97,100,0,0,0,0,0,0,0,109,109,97,110,99,112,50,117,0,0,0,0,0,0,0,0,105,110,112,117,116,95,100,114,105,118,101,114,0,0,0,0,74,117,114,97,115,115,105,99,32,80,97,114,107,32,45,32,82,97,109,112,97,103,101,32,69,100,105,116,105,111,110,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,55,49,56,41,0,0,0,109,100,95,106,112,97,114,107,114,101,112,49,0,0,0,0,67,103,0,0,0,0,0,0,82,105,103,104,116,32,68,45,112,97,100,0,0,0,0,0,74,117,114,97,115,115,105,99,32,80,97,114,107,32,45,32,82,97,109,112,97,103,101,32,69,100,105,116,105,111,110,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,55,49,55,41,0,0,0,109,100,95,106,112,97,114,107,114,101,112,50,0,0,0,0,74,117,114,97,115,115,105,99,32,80,97,114,107,32,45,32,82,97,109,112,97,103,101,32,69,100,105,116,105,111,110,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,55,49,53,41,0,0,0,85,112,32,49,46,53,37,0,83,116,97,116,101,32,83,108,111,116,32,80,108,117,115,0,80,50,32,83,104,111,111,116,32,51,0,0,0,0,0,0,109,100,95,106,112,97,114,107,114,101,112,51,0,0,0,0,87,111,110,100,101,114,32,66,111,121,32,73,73,73,32,45,32,77,111,110,115,116,101,114,32,76,97,105,114,32,40,115,101,116,32,54,44,32,87,111,114,108,100,44,32,83,121,115,116,101,109,32,49,54,66,44,32,56,55,53,49,32,51,49,55,45,48,48,57,56,41,0,0,0,0,0,0,0,0,0,74,117,114,97,115,115,105,99,32,80,97,114,107,32,45,32,82,97,109,112,97,103,101,32,69,100,105,116,105,111,110,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,55,49,52,41,0,0,0,80,50,32,76,101,102,116,32,85,112,0,0,0,0,0,0,80,51,32,88,45,65,120,105,115,0,0,0,0,0,0,0,51,48,48,107,32,97,110,100,32,101,118,101,114,121,32,51,48,48,107,0,0,0,0,0,109,100,95,106,112,97,114,107,114,101,112,52,0,0,0,0,99,104,45,62,107,115,108,95,98,97,115,101,0,0,0,0,76,97,115,116,32,73,110,110,105,110,103,0,0,0,0,0,80,49,32,80,111,110,0,0,118,97,110,118,97,110,98,0,115,117,112,101,114,103,0,0,74,117,114,97,115,115,105,99,32,80,97,114,107,32,45,32,82,97,109,112,97,103,101,32,69,100,105,116,105,111,110,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,55,49,51,41,0,0,0,66,0,0,0,101,0,0,0,101,0,0,0,32,0,0,0,83,0,0,0,116,0,0,0,111,0,0,0,114,0,0,0,109,0,0,0,32,0,0,0,45,0,0,0,32,0,0,0,68,0,0,0,111,0,0,0,68,0,0,0,111,0,0,0,110,0,0,0,80,0,0,0,97,0,0,0,116,0,0,0,99,0,0,0,104,0,0,0,105,0,0,0,32,0,0,0,73,0,0,0,73,0,0,0,0,0,0,0,18,96,0,0,150,153,0,0,134,152,0,0,2,135,0,0,13,255,0,0,2,135,0,0,180,102,0,0,32,0,0,0,40,0,0,0,86,0,0,0,49,0,0,0,48,0,0,0,48,0,0,0,44,0,0,0,32,0,0,0,84,0,0,0,97,0,0,0,105,0,0,0,119,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,99,101,95,102,49,100,114,101,97,109,0,0,0,0,0,107,111,102,57,54,104,0,0,109,100,95,106,112,97,114,107,114,101,112,53,0,0,0,0,66,97,116,109,97,110,32,82,101,116,117,114,110,115,32,40,87,111,114,108,100,41,0,0,82,111,99,107,109,97,110,32,50,32,45,32,116,104,101,32,112,111,119,101,114,32,102,105,103,104,116,101,114,115,32,40,57,54,48,55,48,56,32,74,97,112,97,110,41,0,0,0,116,119,105,110,49,54,95,67,80,85,66,95,114,101,103,105,115,116,101,114,0,0,0,0,77,117,116,97,110,116,32,70,105,103,104,116,101,114,32,40,87,111,114,108,100,32,118,101,114,32,69,77,45,53,41,0,0,0,0,0,0,0,0,0,74,117,114,97,115,115,105,99,32,80,97,114,107,32,45,32,82,97,109,112,97,103,101,32,69,100,105,116,105,111,110,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,55,48,56,41,0,0,0,109,100,95,106,112,97,114,107,114,101,112,54,0,0,0,0,69,120,116,101,114,110,97,108,32,102,105,108,116,101,114,32,97,110,100,32,112,108,117,103,105,110,32,115,117,112,112,111,114,116,0,0,0,0,0,0,80,97,114,116,121,32,84,105,109,101,58,32,71,111,110,116,97,32,116,104,101,32,68,105,118,101,114,32,73,73,32,47,32,71,97,110,98,97,114,101,33,32,71,111,110,116,97,33,33,32,50,32,40,87,111,114,108,100,32,82,101,108,101,97,115,101,41,0,0,0,0,0,74,117,114,97,115,115,105,99,32,80,97,114,107,32,45,32,82,97,109,112,97,103,101,32,69,100,105,116,105,111,110,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,71,104,111,115,116,109,117,110,99,104,101,114,32,71,97,108,97,120,105,97,110,32,40,98,111,111,116,108,101,103,41,0,0,0,0,0,0,0,0,0,109,100,95,106,112,97,114,107,114,101,0,0,0,0,0,0,74,117,114,97,115,115,105,99,32,80,97,114,107,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,41,0,0,66,101,97,109,32,69,110,101,114,103,121,32,80,105,99,107,117,112,0,0,0,0,0,0,81,117,105,116,32,75,101,121,0,0,0,0,0,0,0,0,80,50,32,83,104,111,111,116,32,50,0,0,0,0,0,0,109,100,95,106,112,97,114,107,117,112,0,0,0,0,0,0,119,98,51,0,0,0,0,0,74,117,114,97,115,115,105,99,32,80,97,114,107,32,40,85,83,65,41,0,0,0,0,0,67,111,105,110,32,82,97,116,101,32,83,108,111,116,32,66,0,0,0,0,0,0,0,0,50,48,48,107,32,97,110,100,32,101,118,101,114,121,32,50,48,48,107,0,0,0,0,0,109,100,95,106,112,97,114,107,117,0,0,0,0,0,0,0,75,97,114,97,116,101,99,111,0,0,0,0,0,0,0,0,74,117,114,97,115,115,105,99,32,80,97,114,107,32,40,74,112,110,41,0,0,0,0,0,66,101,101,32,83,116,111,114,109,32,45,32,68,111,68,111,110,80,97,99,104,105,32,73,73,32,40,86,49,48,48,44,32,84,97,105,119,97,110,41,0,0,0,0,0,0,0,0,107,111,100,104,0,0,0,0,69,110,101,114,103,121,0,0,84,104,101,32,75,105,110,103,32,111,102,32,70,105,103,104,116,101,114,115,32,39,57,54,32,40,78,71,77,45,50,49,52,41,0,0,0,0,0,0,109,100,95,106,112,97,114,107,106,0,0,0,0,0,0,0,109,100,95,98,97,116,109,97,110,114,110,0,0,0,0,0,114,111,99,107,109,97,110,50,106,0,0,0,0,0,0,0,116,119,105,110,49,54,95,67,80,85,65,95,114,101,103,105,115,116,101,114,0,0,0,0,74,117,114,97,115,115,105,99,32,80,97,114,107,32,40,69,117,114,111,41,0,0,0,0,109,100,95,106,112,97,114,107,0,0,0,0,0,0,0,0,69,120,116,101,114,110,97,108,0,0,0,0,0,0,0,0,67,104,101,108,110,111,118,32,45,32,65,116,111,109,105,99,32,82,117,110,110,101,114,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,83,101,108,101,99,116,0,0,74,117,110,103,108,101,32,83,116,114,105,107,101,32,45,32,85,107,101,116,115,117,103,97,114,101,116,97,32,75,121,111,117,107,105,32,40,74,112,110,41,0,0,0,0,0,0,0,103,109,103,97,108,97,120,0,109,100,95,106,115,116,114,105,107,101,106,0,0,0,0,0,70,80,83,58,32,37,54,46,49,102,32,124,124,32,70,114,97,109,101,115,58,32,37,100,0,0,0,0,0,0,0,0,74,117,110,103,108,101,32,83,116,114,105,107,101,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,41,0,0,54,46,48,48,0,0,0,0,67,111,98,114,97,45,67,111,109,109,97,110,100,32,40,74,97,112,97,110,63,44,32,115,101,116,32,50,41,0,0,0,70,117,108,108,115,99,114,101,101,110,32,84,111,103,103,108,101,0,0,0,0,0,0,0,110,105,110,106,97,109,97,115,0,0,0,0,0,0,0,0,80,50,32,83,104,111,111,116,32,49,0,0,0,0,0,0,109,100,95,106,115,116,114,105,107,101,112,0,0,0,0,0,107,97,103,101,107,105,95,115,97,109,112,108,101,95,115,101,108,101,99,116,0,0,0,0,84,111,117,103,104,32,84,117,114,102,32,40,115,101,116,32,49,44,32,85,83,44,32,56,55,53,49,32,51,49,55,45,48,48,57,57,41,0,0,0,74,117,110,103,108,101,32,83,116,114,105,107,101,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,0,80,50,32,89,45,65,120,105,115,0,0,0,0,0,0,0,49,32,67,111,105,110,32,50,32,80,108,97,121,0,0,0,67,111,105,110,32,84,121,112,101,0,0,0,0,0,0,0,109,100,95,106,115,116,114,105,107,101,0,0,0,0,0,0,80,49,32,78,0,0,0,0,86,97,110,45,86,97,110,32,67,97,114,32,40,75,97,114,97,116,101,99,111,41,0,0,83,116,97,114,116,32,111,110,32,76,101,118,101,108,32,49,51,0,0,0,0,0,0,0,68,105,115,110,101,121,39,115,32,84,104,101,32,74,117,110,103,108,101,32,66,111,111,107,32,40,85,83,65,41,0,0,100,100,112,50,49,48,48,116,0,0,0,0,0,0,0,0,84,104,101,32,75,105,110,103,32,111,102,32,68,114,97,103,111,110,115,32,40,98,111,111,116,108,101,103,44,32,57,49,48,55,51,49,32,101,116,99,41,0,0,0,0,0,0,0,112,99,101,95,101,110,101,114,103,121,0,0,0,0,0,0,109,100,95,106,117,110,103,108,101,117,0,0,0,0,0,0,77,101,103,97,32,77,97,110,32,50,32,45,32,116,104,101,32,112,111,119,101,114,32,102,105,103,104,116,101,114,115,32,40,57,54,48,55,49,50,32,72,105,115,112,97,110,105,99,41,0,0,0,0,0,0,0,118,105,100,101,111,95,114,101,103,105,115,116,101,114,0,0,49,57,57,52,0,0,0,0,37,115,95,37,115,95,97,120,105,115,0,0,0,0,0,0,80,49,32,83,116,97,114,116,0,0,0,0,0,0,0,0,68,105,115,110,101,121,39,115,32,84,104,101,32,74,117,110,103,108,101,32,66,111,111,107,32,40,69,117,114,111,41,0,0,0,0,0,0,0,0,0,37,48,56,120,58,32,67,111,45,80,114,111,99,101,115,115,111,114,32,82,101,103,105,115,116,101,114,32,84,114,97,110,115,102,101,114,32,101,120,101,99,117,116,101,100,44,32,98,117,116,32,110,111,32,82,84,32,82,101,97,100,32,99,97,108,108,98,97,99,107,32,100,101,102,105,110,101,100,33,10,0,0,0,0,0,0,0,0,119,105,122,100,102,105,114,101,117,0,0,0,0,0,0,0,109,100,95,106,117,110,103,108,101,0,0,0,0,0,0,0,79,112,101,110,65,76,0,0,82,45,62,112,111,114,116,52,95,100,97,116,97,0,0,0,72,101,114,111,0,0,0,0,49,32,99,111,105,110,32,49,32,112,108,97,121,0,0,0,78,111,114,109,97,108,0,0,70,105,120,69,105,103,104,116,32,40,83,111,117,116,104,101,97,115,116,32,65,115,105,97,44,32,84,97,105,116,111,32,108,105,99,101,110,115,101,41,0,0,0,0,0,0,0,0,74,117,110,99,116,105,111,110,32,40,74,112,110,44,32,85,83,65,41,0,0,0,0,0,71,101,116,32,83,116,97,114,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,50,32,67,111,105,110,115,32,49,32,67,114,101,100,105,116,115,0,0,0,0,0,0,0,109,100,95,106,117,110,99,116,105,111,110,0,0,0,0,0,49,0,0,0,57,0,0,0,52,0,0,0,53,0,0,0,32,0,0,0,80,0,0,0,97,0,0,0,114,0,0,0,116,0,0,0,32,0,0,0,50,0,0,0,0,0,0,0,17,255,0,0,25,255,0,0,20,255,0,0,21,255,0,0,140,78,0,0,227,78,0,0,32,0,0,0,40,0,0,0,66,0,0,0,97,0,0,0,116,0,0,0,116,0,0,0,108,0,0,0,101,0,0,0,32,0,0,0,71,0,0,0,97,0,0,0,114,0,0,0,114,0,0,0,101,0,0,0,103,0,0,0,97,0,0,0,32,0,0,0,67,0,0,0,104,0,0,0,105,0,0,0,110,0,0,0,101,0,0,0,115,0,0,0,101,0,0,0,32,0,0,0,104,0,0,0,97,0,0,0,99,0,0,0,107,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,74,117,100,103,101,32,68,114,101,100,100,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,53,46,48,48,0,0,0,0,80,49,32,83,104,111,111,116,32,51,0,0,0,0,0,0,109,100,95,106,100,114,101,100,100,112,49,0,0,0,0,0,109,99,117,95,115,101,110,116,0,0,0,0,0,0,0,0,66,111,117,108,100,101,114,32,68,97,115,104,32,47,32,66,111,117,108,100,101,114,32,68,97,115,104,32,80,97,114,116,32,50,32,40,74,97,112,97,110,41,0,0,0,0,0,0,107,97,103,101,107,105,95,115,97,109,112,108,101,95,112,111,115,0,0,0,0,0,0,0,100,105,110,111,114,101,120,0,116,116,117,114,102,117,0,0,74,117,100,103,101,32,68,114,101,100,100,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,65,108,116,41,0,0,0,0,0,0,0,49,32,67,111,105,110,32,51,32,80,108,97,121,0,0,0,97,114,107,110,111,105,100,50,106,0,0,0,0,0,0,0,109,100,95,106,100,114,101,100,100,112,50,0,0,0,0,0,50,32,80,108,97,121,101,114,115,32,71,97,109,101,0,0,78,97,115,116,97,114,32,87,97,114,114,105,111,114,32,40,85,83,41,0,0,0,0,0,118,99,101,95,97,100,100,114,101,115,115,0,0,0,0,0,118,97,110,118,97,110,107,0,66,97,116,116,108,101,32,83,104,97,114,107,32,40,85,83,41,0,0,0,0,0,0,0,114,101,115,116,97,114,116,95,115,116,97,116,117,115,0,0,74,117,100,103,101,32,68,114,101,100,100,32,40,87,111,114,108,100,41,0,0,0,0,0,99,104,97,114,100,109,97,95,115,111,117,114,99,101,0,0,79,112,101,114,97,116,105,111,110,32,87,111,108,102,32,40,74,97,112,97,110,41,0,0,66,0,0,0,101,0,0,0,101,0,0,0,32,0,0,0,83,0,0,0,116,0,0,0,111,0,0,0,114,0,0,0,109,0,0,0,32,0,0,0,45,0,0,0,32,0,0,0,68,0,0,0,111,0,0,0,68,0,0,0,111,0,0,0,110,0,0,0,80,0,0,0,97,0,0,0,116,0,0,0,99,0,0,0,104,0,0,0,105,0,0,0,32,0,0,0,73,0,0,0,73,0,0,0,0,0,0,0,18,96,0,0,150,153,0,0,134,152,0,0,2,135,0,0,13,255,0,0,2,135,0,0,180,102,0,0,32,0,0,0,40,0,0,0,86,0,0,0,49,0,0,0,48,0,0,0,49,0,0,0,44,0,0,0,32,0,0,0,84,0,0,0,97,0,0,0,105,0,0,0,119,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,107,111,100,98,0,0,0,0,68,117,110,103,101,111,110,32,69,120,112,108,111,114,101,114,0,0,0,0,0,0,0,0,65,114,116,32,111,102,32,70,105,103,104,116,105,110,103,32,51,32,45,32,84,104,101,32,80,97,116,104,32,111,102,32,116,104,101,32,87,97,114,114,105,111,114,32,40,75,111,114,101,97,110,32,114,101,108,101,97,115,101,41,0,0,0,0,83,117,112,101,114,32,66,111,98,98,108,101,32,66,111,98,98,108,101,32,40,115,101,116,32,49,41,0,0,0,0,0,109,100,95,106,100,114,101,100,100,0,0,0,0,0,0,0,83,117,112,101,114,109,97,110,32,40,85,83,41,0,0,0,119,97,114,114,105,111,114,98,0,0,0,0,0,0,0,0,65,101,114,111,32,116,104,101,32,65,99,114,111,45,66,97,116,32,50,32,40,69,117,114,111,41,0,0,0,0,0,0,109,101,103,97,109,97,110,50,104,0,0,0,0,0,0,0,83,117,112,101,114,32,72,97,110,103,45,79,110,32,40,109,105,110,105,32,114,105,100,101,45,111,110,44,32,82,101,118,32,65,44,32,70,68,49,48,56,57,66,32,51,49,55,45,48,48,51,52,41,0,0,0,74,111,115,104,117,97,32,38,32,84,104,101,32,66,97,116,116,108,101,32,111,102,32,74,101,114,105,99,104,111,32,40,85,83,65,41,0,0,0,0,37,115,95,37,115,95,98,116,110,0,0,0,0,0,0,0,49,48,48,75,32,50,48,48,75,32,51,53,48,75,32,53,48,48,75,32,55,48,48,75,0,0,0,0,0,0,0,0,110,65,89,56,57,49,48,80,111,115,105,116,105,111,110,0,74,0,0,0,117,0,0,0,117,0,0,0,111,0,0,0,107,0,0,0,105,0,0,0,32,0,0,0,40,0,0,0,115,0,0,0,101,0,0,0,116,0,0,0,32,0,0,0,55,0,0,0,44,0,0,0,32,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,44,0,0,0,32,0,0,0,56,0,0,0,55,0,0,0,53,0,0,0,49,0,0,0,32,0,0,0,51,0,0,0,49,0,0,0,55,0,0,0,45,0,0,0,48,0,0,0,48,0,0,0,55,0,0,0,55,0,0,0,41,0,0,0,0,0,0,0,99,115,0,0,139,115,0,0,24,138,0,0,0,0,0,0,0,0,0,0,83,121,115,116,101,109,49,54,65,110,97,108,111,103,83,101,108,101,99,116,0,0,0,0,109,100,95,106,111,115,104,117,97,0,0,0,0,0,0,0,80,78,71,32,101,110,99,111,100,101,47,100,101,99,111,100,101,32,97,110,100,32,46,122,105,112,32,101,120,116,114,97,99,116,105,111,110,0,0,0,70,108,105,99,107,121,32,40,49,50,56,107,32,86,101,114,115,105,111,110,44,32,83,121,115,116,101,109,32,50,44,32,51,49,53,45,53,48,53,49,41,0,0,0,0,0,0,0,100,100,99,114,101,119,0,0,112,100,114,105,102,116,101,0,83,117,112,101,114,32,79,110,101,32,111,110,32,79,110,101,32,45,32,74,111,114,100,97,110,32,86,115,32,66,105,114,100,32,40,74,112,110,41,0,0,0,0,0,0,0,0,0,108,97,115,116,115,117,114,118,0,0,0,0,0,0,0,0,79,122,111,110,32,73,0,0,86,100,112,87,105,110,100,111,119,86,80,111,115,0,0,0,97,108,105,101,110,115,121,110,53,0,0,0,0,0,0,0,109,100,95,106,111,114,100,97,110,98,106,0,0,0,0,0,68,105,115,112,108,97,121,32,67,111,112,121,114,105,103,104,116,0,0,0,0,0,0,0,50,32,67,111,105,110,115,32,51,32,67,114,101,100,105,116,115,32,0,0,0,0,0,0,98,97,107,117,98,114,107,114,0,0,0,0,0,0,0,0,77,117,108,116,105,32,67,104,97,109,112,32,68,101,108,117,120,101,32,40,118,101,114,46,32,49,49,50,54,44,32,50,54,47,49,49,47,49,57,57,57,41,0,0,0,0,0,0,68,111,110,103,32,66,97,110,103,32,69,108,101,99,116,114,111,110,0,0,0,0,0,0,83,117,112,101,114,32,79,110,101,32,111,110,32,79,110,101,32,45,32,74,111,114,100,97,110,32,86,115,32,66,105,114,100,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,49,32,67,111,105,110,32,52,32,67,114,101,100,105,116,115,32,0,0,0,0,0,0,0,118,105,100,101,111,95,100,105,115,97,98,108,101,95,99,111,109,112,111,115,105,116,105,111,110,0,0,0,0,0,0,0,52,46,51,48,0,0,0,0,103,97,114,111,103,117,110,0,107,111,102,57,54,0,0,0,80,49,32,83,104,111,111,116,32,50,0,0,0,0,0,0,109,100,95,106,111,114,100,97,110,98,49,0,0,0,0,0,107,97,103,101,107,105,95,99,115,112,111,114,116,95,115,101,108,0,0,0,0,0,0,0,55,0,0,0,0,0,0,0,83,117,112,101,114,32,79,110,101,32,111,110,32,79,110,101,32,45,32,74,111,114,100,97,110,32,86,115,32,66,105,114,100,32,40,69,117,114,111,44,32,85,83,65,44,32,118,49,46,49,41,0,0,0,0,0,83,101,103,97,32,47,32,83,117,110,115,111,102,116,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,111,112,101,110,32,66,83,86,32,34,37,115,34,32,102,111,114,32,114,101,99,111,114,100,105,110,103,46,10,0,0,0,0,0,80,49,32,82,105,103,104,116,32,82,105,103,104,116,0,0,80,50,32,88,45,65,120,105,115,0,0,0,0,0,0,0,49,32,67,111,105,110,32,52,32,80,108,97,121,0,0,0,65,105,114,32,65,116,116,97])
.concat([99,107,32,40,115,101,116,32,49,41,0,0,0,0,0,0,114,97,105,100,101,110,117,97,0,0,0,0,0,0,0,0,112,122,108,98,111,119,108,0,109,100,95,106,111,114,100,97,110,98,0,0,0,0,0,0,80,49,32,77,0,0,0,0,83,97,110,114,105,116,115,117,0,0,0,0,0,0,0,0,87,105,108,100,32,70,97,110,103,32,47,32,84,101,99,109,111,32,75,110,105,103,104,116,0,0,0,0,0,0,0,0,74,111,104,110,32,77,97,100,100,101,110,32,70,111,111,116,98,97,108,108,32,45,32,80,114,111,32,70,111,111,116,98,97,108,108,32,40,74,112,110,41,0,0,0,0,0,0,0,66,101,101,32,83,116,111,114,109,32,45,32,68,111,68,111,110,80,97,99,104,105,32,73,73,32,40,86,49,48,49,44,32,84,97,105,119,97,110,41,0,0,0,0,0,0,0,0,102,97,110,116,115,121,57,53,0,0,0,0,0,0,0,0,84,104,101,32,75,105,110,103,32,111,102,32,68,114,97,103,111,110,115,32,40,74,97,112,97,110,32,57,49,48,56,48,53,44,32,66,45,66,111,97,114,100,32,56,57,54,50,53,66,45,49,41,0,0,0,0,112,99,101,95,100,117,110,103,101,120,112,108,0,0,0,0,97,111,102,51,107,0,0,0,84,104,117,110,100,101,114,32,72,111,111,112,32,40,86,101,114,46,32,49,41,0,0,0,109,100,95,109,97,100,100,101,110,106,0,0,0,0,0,0,50,48,48,75,32,111,110,108,121,0,0,0,0,0,0,0,66,97,99,107,103,114,111,117,110,100,32,82,65,77,0,0,115,97,105,108,111,114,109,110,104,0,0,0,0,0,0,0,109,100,95,97,101,114,111,50,0,0,0,0,0,0,0,0,77,101,103,97,32,77,97,110,32,50,32,45,32,116,104,101,32,112,111,119,101,114,32,102,105,103,104,116,101,114,115,32,40,57,54,48,55,48,56,32,65,115,105,97,41,0,0,0,67,117,101,32,66,114,105,99,107,32,78,86,32,82,65,77,0,0,0,0,0,0,0,0,105,110,112,117,116,0,0,0,53,48,75,32,49,53,48,75,32,50,53,48,75,32,52,48,48,75,32,54,48,48,75,0,74,111,104,110,32,77,97,100,100,101,110,32,70,111,111,116,98,97,108,108,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,0,0,107,111,114,111,107,111,114,111,95,104,111,112,112,101,114,0,86,45,83,121,115,116,101,109,0,0,0,0,0,0,0,0,99,116,114,105,98,101,98,0,109,100,95,109,97,100,100,101,110,0,0,0,0,0,0,0,122,108,105,98,0,0,0,0,74,111,104,110,32,77,97,100,100,101,110,32,70,111,111,116,98,97,108,108,32,39,57,51,32,45,32,67,104,97,109,112,105,111,110,115,104,105,112,32,69,100,105,116,105,111,110,32,40,85,83,65,41,0,0,0,49,32,67,111,105,110,45,49,32,80,108,97,121,0,0,0,111,122,111,110,49,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,97,110,110,111,116,32,111,112,101,110,32,118,105,100,101,111,32,100,114,105,118,101,114,32,46,46,46,32,69,120,105,116,105,110,103,32,46,46,46,10,0,0,109,111,114,101,109,111,114,112,0,0,0,0,0,0,0,0,109,100,95,109,97,100,100,57,51,99,101,0,0,0,0,0,80,97,110,103,32,80,97,110,103,0,0,0,0,0,0,0,103,108,115,108,0,0,0,0,66,97,116,116,108,101,32,75,45,82,111,97,100,0,0,0,76,111,100,101,32,82,117,110,110,101,114,32,45,32,84,104,101,32,68,105,103,32,70,105,103,104,116,32,40,118,101,114,46,32,66,41,0,0,0,0,74,111,104,110,32,77,97,100,100,101,110,32,70,111,111,116,98,97,108,108,32,39,57,51,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,68,114,118,79,107,105,66,97,110,107,50,95,49,0,0,0,52,46,48,48,0,0,0,0,91,83,117,110,32,69,108,101,99,116,114,111,110,105,99,115,93,32,40,84,97,105,116,111,32,108,105,99,101,110,115,101,41,0,0,0,0,0,0,0,70,97,115,116,32,70,111,114,119,97,114,100,32,72,111,108,100,0,0,0,0,0,0,0,67,104,111,117,106,105,32,77,101,105,107,121,117,117,32,76,101,103,105,111,110,32,40,118,101,114,32,49,46,48,53,41,0,0,0,0,0,0,0,0,109,100,95,109,97,100,100,101,110,57,51,0,0,0,0,0,86,105,115,99,111,0,0,0,80,49,32,83,104,111,111,116,32,49,0,0,0,0,0,0,97,100,100,114,101,115,115,0,80,111,107,101,114,32,76,97,100,105,101,115,32,40,76,101,112,114,101,99,104,97,117,110,32,118,101,114,46,32,52,48,49,41,0,0,0,0,0,0,110,65,110,97,108,111,103,65,120,105,115,91,49,93,0,0,66,111,110,117,115,32,83,104,105,101,108,100,115,0,0,0,65,109,109,111,32,77,97,103,97,122,105,110,101,115,32,97,116,32,83,116,97,114,116,0,86,105,100,67,111,110,116,114,111,108,0,0,0,0,0,0,78,111,32,83,111,117,110,100,44,32,77,105,115,115,105,110,103,32,90,56,48,32,80,114,111,103,114,97,109,0,0,0,74,111,104,110,32,77,97,100,100,101,110,32,70,111,111,116,98,97,108,108,32,39,57,50,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,49,32,67,111,105,110,32,53,32,80,108,97,121,0,0,0,68,0,0,0,0,0,0,0,80,97,99,45,77,97,110,32,40,77,105,100,119,97,121,41,0,0,0,0,0,0,0,0,52,32,67,111,105,110,32,49,32,67,114,101,100,105,116,115,0,0,0,0,0,0,0,0,109,100,95,109,97,100,100,101,110,57,50,0,0,0,0,0,71,97,117,110,116,108,101,116,32,40,114,101,118,32,55,41,0,0,0,0,0,0,0,0,50,48,58,48,48,0,0,0,112,97,116,104,47,97,46,111,117,116,0,0,0,0,0,0,86,97,110,45,86,97,110,32,67,97,114,0,0,0,0,0,48,45,54,0,0,0,0,0,89,97,110,107,101,101,32,68,79,33,0,0,0,0,0,0,100,111,114,111,100,111,110,50,0,0,0,0,0,0,0,0,74,111,101,32,77,111,110,116,97,110,97,32,73,73,32,83,112,111,114,116,115,32,84,97,108,107,32,70,111,111,116,98,97,108,108,32,40,87,111,114,108,100,44,32,82,101,118,46,32,65,41,0,0,0,0,0,100,107,111,110,103,106,111,49,0,0,0,0,0,0,0,0,76,105,102,101,115,0,0,0,100,100,112,50,49,48,49,116,0,0,0,0,0,0,0,0,107,111,100,106,97,0,0,0,75,105,100,32,110,111,32,72,111,114,101,32,72,111,114,101,32,68,97,105,115,97,107,117,115,101,110,0,0,0,0,0,68,114,111,112,32,82,111,99,107,32,72,111,114,97,32,72,111,114,97,32,40,65,108,116,41,0,0,0,0,0,0,0,116,111,107,105,98,0,0,0,65,0,0,0,114,0,0,0,116,0,0,0,32,0,0,0,111,0,0,0,102,0,0,0,32,0,0,0,70,0,0,0,105,0,0,0,103,0,0,0,104,0,0,0,116,0,0,0,105,0,0,0,110,0,0,0,103,0,0,0,32,0,0,0,51,0,0,0,32,0,0,0,45,0,0,0,32,0,0,0,84,0,0,0,104,0,0,0,101,0,0,0,32,0,0,0,80,0,0,0,97,0,0,0,116,0,0,0,104,0,0,0,32,0,0,0,111,0,0,0,102,0,0,0,32,0,0,0,116,0,0,0,104,0,0,0,101,0,0,0,32,0,0,0,87,0,0,0,97,0,0,0,114,0,0,0,114,0,0,0,105,0,0,0,111,0,0,0,114,0,0,0,0,0,0,0,65,0,0,0,114,0,0,0,116,0,0,0,32,0,0,0,111,0,0,0,102,0,0,0,32,0,0,0,70,0,0,0,105,0,0,0,103,0,0,0,104,0,0,0,116,0,0,0,105,0,0,0,110,0,0,0,103,0,0,0,32,0,0,0,45,0,0,0,32,0,0,0,141,159,0,0,78,134,0,0,110,48,0,0,243,98,0,0,22,89,0,0,29,79,0,0,0,0,0,0,0,0,0,0,101,120,101,100,101,120,101,115,95,98,103,95,120,115,99,114,111,108,108,0,0,0,0,0,74,111,101,32,77,111,110,116,97,110,97,32,70,111,111,116,98,97,108,108,32,40,87,111,114,108,100,41,0,0,0,0,109,117,120,95,100,97,116,97,0,0,0,0,0,0,0,0,83,111,110,105,99,32,116,104,101,32,72,101,100,103,101,104,111,103,32,40,69,117,114,111,44,32,85,83,65,41,0,0,109,101,103,97,109,97,110,50,97,0,0,0,0,0,0,0,84,114,111,106,97,110,32,40,85,83,32,115,101,116,32,49,41,0,0,0,0,0,0,0,37,115,95,37,115,0,0,0,85,112,114,105,103,104,116,32,40,100,111,117,98,108,101,41,32,77,111,100,101,0,0,0,109,100,95,106,111,101,109,111,110,116,0,0,0,0,0,0,66,114,105,120,0,0,0,0,105,103,109,111,0,0,0,0,115,116,114,101,101,116,115,109,119,0,0,0,0,0,0,0,74,111,101,32,38,32,77,97,99,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,83,112,97,99,101,32,73,110,118,97,115,105,111,110,32,40,98,111,111,116,108,101,103,41,0,0,0,0,0,0,0,0,49,57,52,51,32,75,97,105,58,32,77,105,100,119,97,121,32,75,97,105,115,101,110,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,101,109,115,99,114,105,112,116,101,110,0,0,0,0,0,0,88,65,117,100,105,111,50,0,49,57,55,57,0,0,0,0,102,108,97,115,104,103,97,108,97,0,0,0,0,0,0,0,76,101,100,32,83,116,111,114,109,32,40,85,83,41,0,0,109,100,95,106,111,101,109,97,99,0,0,0,0,0,0,0,90,105,103,32,90,97,103,32,40,71,97,108,97,120,105,97,110,32,104,97,114,100,119,97,114,101,44,32,115,101,116,32,50,41,0,0,0,0,0,0,67,97,112,99,111,109,32,40,84,97,105,116,111,32,65,109,101,114,105,99,97,32,76,105,99,101,110,115,101,41,0,0,82,101,116,114,111,65,114,99,104,58,32,82,79,77,32,108,111,97,100,105,110,103,32,115,107,105,112,112,101,100,46,32,73,109,112,108,101,109,101,110,116,97,116,105,111,110,32,119,105,108,108,32,108,111,97,100,32,105,116,32,111,110,32,105,116,115,32,111,119,110,46,10,0,0,0,0,0,0,0,0,49,32,67,111,105,110,32,32,49,32,67,114,101,100,105,116,32,32,47,32,49,32,67,111,105,110,32,32,49,32,32,67,114,101,100,105,116,32,0,0,74,105,117,32,74,105,32,77,97,32,74,105,97,110,103,32,73,73,32,45,32,89,101,32,89,97,110,32,66,105,97,110,32,40,67,104,105,41,0,0,87,99,57,48,83,99,114,111,108,108,48,88,72,105,0,0,51,67,95,52,67,0,0,0,115,105,108,107,119,111,114,109,98,0,0,0,0,0,0,0,109,100,95,106,105,117,106,105,109,0,0,0,0,0,0,0,83,99,101,110,101,32,84,105,109,101,0,0,0,0,0,0,68,111,117,98,108,101,32,68,114,97,103,111,110,32,40,98,111,111,116,108,101,103,41,0,0,0,0,0,0,0,0,0,107,111,118,97,115,115,103,0,109,95,100,114,103,119,50,95,112,116,114,0,0,0,0,0,70,97,115,116,32,70,111,114,119,97,114,100,0,0,0,0,74,105,109,109,121,32,87,104,105,116,101,39,115,32,87,104,105,114,108,119,105,110,100,32,83,110,111,111,107,101,114,32,40,69,117,114,111,41,0,0,70,105,114,101,32,53,32,40,67,111,99,107,116,97,105,108,41,0,0,0,0,0,0,0,83,101,103,97,80,67,77,82,65,77,0,0,0,0,0,0,111,114,108,101,103,101,110,100,49,49,49,99,0,0,0,0,112,50,32,102,105,114,101,32,53,0,0,0,0,0,0,0,110,65,110,97,108,111,103,65,120,105,115,91,48,93,0,0,80,105,116,32,73,110,0,0,84,111,117,103,104,32,84,117,114,102,32,40,115,101,116,32,50,44,32,74,97,112,97,110,44,32,56,55,53,49,32,51,49,55,45,48,49,48,52,41,0,0,0,0,0,0,0,0,109,100,95,106,105,109,109,121,119,119,115,0,0,0,0,0,80,49,32,82,105,103,104,116,32,76,101,102,116,0,0,0,49,32,67,111,105,110,32,54,32,80,108,97,121,0,0,0,49,80,32,86,115,32,50,80,32,82,111,117,110,100,115,32,40,66,117,98,98,108,101,32,71,117,109,41,0,0,0,0,76,111,114,105,99,105,101,108,0,0,0,0,0,0,0,0,112,99,101,95,97,99,114,117,115,104,0,0,0,0,0,0,80,49,32,76,0,0,0,0,118,97,110,118,97,110,0,0,50,53,53,32,76,105,118,101,115,32,40,67,104,101,97,116,41,0,0,0,0,0,0,0,74,105,109,32,80,111,119,101,114,32,45,32,84,104,101,32,65,114,99,97,100,101,32,71,97,109,101,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,66,0,0,0,101,0,0,0,101,0,0,0,32,0,0,0,83,0,0,0,116,0,0,0,111,0,0,0,114,0,0,0,109,0,0,0,32,0,0,0,45,0,0,0,32,0,0,0,68,0,0,0,111,0,0,0,68,0,0,0,111,0,0,0,110,0,0,0,80,0,0,0,97,0,0,0,116,0,0,0,99,0,0,0,104,0,0,0,105,0,0,0,32,0,0,0,73,0,0,0,73,0,0,0,0,0,0,0,18,96,0,0,150,153,0,0,134,152,0,0,2,135,0,0,13,255,0,0,2,135,0,0,180,102,0,0,32,0,0,0,40,0,0,0,86,0,0,0,49,0,0,0,48,0,0,0,50,0,0,0,44,0,0,0,32,0,0,0,84,0,0,0,97,0,0,0,105,0,0,0,119,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,104,101,32,75,105,110,103,32,111,102,32,68,114,97,103,111,110,115,32,40,74,97,112,97,110,32,57,49,48,56,48,53,44,32,66,45,66,111,97,114,100,32,57,48,54,50,57,66,45,51,41,0,0,0,0,112,99,101,95,100,114,111,112,114,111,99,107,49,0,0,0,65,114,116,32,111,102,32,70,105,103,104,116,105,110,103,32,51,32,45,32,84,104,101,32,80,97,116,104,32,111,102,32,116,104,101,32,87,97,114,114,105,111,114,32,47,32,65,114,116,32,111,102,32,70,105,103,104,116,105,110,103,32,45,32,82,121,117,117,107,111,32,110,111,32,75,101,110,32,71,97,105,100,101,110,0,0,0,0,109,100,95,106,105,109,112,111,119,101,114,0,0,0,0,0,98,115,116,97,114,115,104,0,119,111,110,100,101,114,51,0,71,76,32,114,97,115,116,101,114,0,0,0,0,0,0,0,84,101,120,116,32,108,97,121,101,114,32,116,105,108,101,32,82,65,77,0,0,0,0,0,109,100,95,115,111,110,105,99,0,0,0,0,0,0,0,0,77,101,103,97,32,77,97,110,32,50,32,45,32,116,104,101,32,112,111,119,101,114,32,102,105,103,104,116,101,114,115,32,40,57,54,48,55,48,56,32,85,83,65,41,0,0,0,0,40,75,101,121,58,32,37,115,41,0,0,0,0,0,0,0,85,112,114,105,103,104,116,32,40,100,111,117,98,108,101,41,32,79,102,102,0,0,0,0,74,101,119,101,108,32,77,97,115,116,101,114,32,40,74,112,110,41,0,0,0,0,0,0,105,110,99,111,114,114,101,99,116,32,108,101,110,103,116,104,32,99,104,101,99,107,0,0,109,100,95,106,101,119,101,108,109,115,106,0,0,0,0,0,68,105,114,101,99,116,83,111,117,110,100,0,0,0,0,0,83,76,79,84,45,62,65,77,109,97,115,107,0,0,0,0,103,108,68,101,98,117,103,77,101,115,115,97,103,101,73,110,115,101,114,116,0,0,0,0,74,101,114,114,121,32,71,108,97,110,118,105,108,108,101,39,115,32,80,105,103,115,107,105,110,32,70,111,111,116,98,114,97,119,108,32,40,85,83,65,41,0,0,0,0,0,0,0,122,105,103,122,97,103,50,0,79,117,116,112,117,116,83,105,122,101,0,0,0,0,0,0,109,100,95,112,105,103,115,107,105,110,102,0,0,0,0,0,83,72,65,68,69,82,32,68,73,82,32,37,115,0,0,0,74,101,111,112,97,114,100,121,33,32,83,112,111,114,116,115,32,69,100,105,116,105,111,110,32,40,85,83,65,41,0,0,49,48,48,107,44,32,50,48,48,107,0,0,0,0,0,0,60,100,101,102,97,117,108,116,62,0,0,0,0,0,0,0,84,117,114,98,111,32,69,110,97,98,108,101,0,0,0,0,109,100,95,108,111,116,117,115,116,0,0,0,0,0,0,0,75,48,53,50,49,48,57,70,108,105,112,69,110,97,98,108,101,0,0,0,0,0,0,0,110,101,111,100,114,105,102,116,0,0,0,0,0,0,0,0,70,105,114,101,32,52,32,40,67,111,99,107,116,97,105,108,41,0,0,0,0,0,0,0,109,100,95,106,101,111,112,97,114,100,115,0,0,0,0,0,68,101,118,97,115,116,97,116,111,114,115,32,40,118,101,114,46,32,86,41,0,0,0,0,80,50,32,70,105,114,101,32,53,0,0,0,0,0,0,0,99,112,117,49,95,114,101,115,101,116,0,0,0,0,0,0,89,101,108,108,111,119,0,0,49,48,48,107,0,0,0,0,73,67,53,50,61,50,53,54,107,98,44,32,73,67,53,51,61,50,53,54,107,98,0,0,74,101,111,112,97,114,100,121,33,32,68,101,108,117,120,101,32,40,85,83,65,41,0,0,116,116,117,114,102,0,0,0,37,115,37,115,46,122,105,112,0,0,0,0,0,0,0,0,80,49,32,84,117,114,110,32,82,105,103,104,116,0,0,0,50,32,67,111,105,110,32,49,32,80,108,97,121,0,0,0,109,100,95,106,101,111,112,97,114,100,100,0,0,0,0,0,71,114,121,122,111,114,32,40,83,101,116,32,50,41,0,0,115,49,57,52,53,95,109,99,117,95,98,99,116,114,108,0,88,45,77,101,110,32,40,50,32,80,108,97,121,101,114,115,32,118,101,114,32,74,65,65,41,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,83,104,97,100,101,114,32,115,111,117,114,99,101,32,102,105,108,101,32,119,97,115,32,112,114,111,118,105,100,101,100,44,32,98,117,116,32,102,97,105,108,101,100,32,116,111,32,114,101,97,100,46,10,0,0,0,0,0,0,66,101,97,115,116,105,101,32,70,101,97,115,116,105,101,0,0,0,0,0,0,0,0,0,103,114,97,100,105,117,115,50,0,0,0,0,0,0,0,0,74,101,111,112,97,114,100,121,33,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,52,32,67,111,105,110,115,32,51,32,67,114,101,100,105,116,115,32,0,0,0,0,0,0,67,97,112,99,111,109,32,47,32,56,105,110,103,32,47,32,82,97,105,122,105,110,103,0,66,101,101,32,83,116,111,114,109,32,45,32,68,111,68,111,110,80,97,99,104,105,32,73,73,32,40,86,49,48,50,44,32,84,97,105,119,97,110,41,0,0,0,0,0,0,0,0,101,115,99,107,105,100,115,106,0,0,0,0,0,0,0,0,107,111,100,106,0,0,0,0,111,118,101,114,108,97,121,37,117,95,97,108,112,104,97,95,109,111,100,0,0,0,0,0,109,100,95,106,101,111,112,97,114,100,121,0,0,0,0,0,99,111,100,101,0,0,0,0,76,0,0,0,97,0,0,0,110,0,0,0,100,0,0,0,115,0,0,0,116,0,0,0,97,0,0,0,108,0,0,0,107,0,0,0,101,0,0,0,114,0,0,0,32,0,0,0,45,0,0,0,32,0,0,0,76,0,0,0,101,0,0,0,32,0,0,0,84,0,0,0,114,0,0,0,233,0,0,0,115,0,0,0,111,0,0,0,114,0,0,0,32,0,0,0,100,0,0,0,117,0,0,0,32,0,0,0,82,0,0,0,111,0,0,0,105,0,0,0,32,0,0,0,78,0,0,0,111,0,0,0,108,0,0,0,101,0,0,0,32,0,0,0,40,0,0,0,70,0,0,0,114,0,0,0,97,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,116,109,104,116,50,112,97,0,109,101,103,97,109,97,110,50,0,0,0,0,0,0,0,0,110,101,119,97,112,117,110,107,0,0,0,0,0,0,0,0,77,97,112,32,66,117,116,116,111,110,0,0,0,0,0,0,84,104,101,32,66,97,116,116,108,101,45,82,111,97,100,0,0,0,0,0,0,0,0,0,37,99,37,117,32,40,97,120,105,115,41,32,0,0,0,0,85,112,114,105,103,104,116,32,40,100,111,117,98,108,101,41,32,79,110,0,0,0,0,0,74,101,108,108,121,32,66,111,121,32,40,69,117,114,111,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,105,110,116,104,117,110,116,117,0,0,0,0,0,0,0,0,77,56,49,0,0,0,0,0,109,100,95,106,101,108,108,121,98,111,121,0,0,0,0,0,80,117,108,115,101,65,117,100,105,111,0,0,0,0,0,0,82,101,110,111,0,0,0,0,76,65,88,0,0,0,0,0,74,97,110,116,101,105,32,77,111,110,111,103,97,116,97,114,105,32,40,74,112,110,41,0,0,0,0,0,0,0,0,0,109,100,95,106,97,110,116,101,105,0,0,0,0,0,0,0,53,48,107,44,32,49,53,48,107,0,0,0,0,0,0,0,82,105,103,104,116,32,65,110,97,108,111,103,32,89,32,45,0,0,0,0,0,0,0,0,70,105,114,101,32,51,32,40,67,111,99,107,116,97,105,108,41,0,0,0,0,0,0,0,74,97,110,111,117,32,84,111,117,114,121,117,117,109,111,110,32,40,74,112,110,41,0,0,112,50,32,102,105,114,101,32,52,0,0,0,0,0,0,0,116,110,122,115,95,98,97,110,107,115,91,50,93,0,0,0,71,114,101,101,110,0,0,0,49,32,85,112,0,0,0,0,73,67,53,50,61,53,49,50,107,98,44,32,73,67,53,51,61,110,111,110,101,0,0,0,84,0,0,0,111,0,0,0,114,0,0,0,121,0,0,0,117,0,0,0,109,0,0,0,111,0,0,0,110,0,0,0,0,0,0,0,123,118,0,0,141,159,0,0,128,149,0,0,0,0,0,0,0,0,0,0,109,100,95,106,97,110,111,117,116,0,0,0,0,0,0,0,80,49,32,82,105,103,104,116,32,68,111,119,110,0,0,0,80,49,32,89,45,65,120,105,115,0,0,0,0,0,0,0,80,49,32,84,117,114,110,32,76,101,102,116,0,0,0,0,51,32,67,111,105,110,32,49,32,80,108,97,121,0,0,0,78,111,118,97,32,71,97,109,101,115,0,0,0,0,0,0,74,97,109,109,105,116,32,40,85,83,65,41,0,0,0,0,115,49,57,52,53,95,109,99,117,95,99,111,110,116,114,111,108,0,0,0,0,0,0,0,80,49,32,75,0,0,0,0,109,100,95,106,97,109,109,105,116,0,0,0,0,0,0,0,66,117,114,110,89,77,50,49,53,49,82,101,103,105,115,116,101,114,115,0,0,0,0,0,100,100,112,50,116,0,0,0,84,104,101,32,75,105,110,103,32,111,102,32,68,114,97,103,111,110,115,32,40,85,83,32,57,49,48,57,49,48,41,0,0,0,0,0,0,0,0,0,68,114,111,112,32,82,111,99,107,32,72,111,114,97,32,72,111,114,97,0,0,0,0,0,82,0,0,0,101,0,0,0,97,0,0,0,108,0,0,0,32,0,0,0,66,0,0,0,111,0,0,0,117,0,0,0,116,0,0,0,32,0,0,0,70,0,0,0,97,0,0,0,116,0,0,0,97,0,0,0,108,0,0,0,32,0,0,0,70,0,0,0,117,0,0,0,114,0,0,0,121,0,0,0,0,0,0,0,82,0,0,0,101,0,0,0,97,0,0,0,108,0,0,0,32,0,0,0,66,0,0,0,111,0,0,0,117,0,0,0,116,0,0,0,32,0,0,0,19,153,0,0,252,114,0,0,29,79,0,0,172,138,0,0,32,0,0,0,40,0,0,0,98,0,0,0,117,0,0,0,103,0,0,0,32,0,0,0,102,0,0,0,105,0,0,0,120,0,0,0,32,0,0,0,114,0,0,0,101,0,0,0,118,0,0,0,105,0,0,0,115,0,0,0,105,0,0,0,111,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,74,97,109,101,115,32,80,111,110,100,32,51,32,45,32,79,112,101,114,97,116,105,111,110,32,83,116,97,114,102,105,115,104,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,76,97,110,100,115,116,97,108,107,101,114,32,45,32,76,101,32,84,114,101,115,111,114,32,100,117,32,82,111,105,32,78,111,108,101,32,40,70,114,97,41,0,0,0,0,0,0,0,192,150,0,0,11,87,0,0,215,95,0,0,32,0,0,0,45,0,0,0,135,137,0,0,139,115,0,0,110,48,0,0,199,145,0,0,76,114,0,0,45,0,0,0,32,0,0,0,40,0,0,0,74,0,0,0,121,0,0,0,97,0,0,0,110,0,0,0,103,0,0,0,111,0,0,0,107,0,0,0,117,0,0,0,115,0,0,0,104,0,0,0,105,0,0,0,32,0,0,0,57,0,0,0,57,0,0,0,48,0,0,0,53,0,0,0,50,0,0,0,55,0,0,0,32,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,37,117,32,40,98,116,110,41,32,0,0,0,0,0,0,0,85,112,114,105,103,104,116,32,40,115,105,110,103,108,101,41,0,0,0,0,0,0,0,0,109,100,95,106,112,111,110,100,51,0,0,0,0,0,0,0,74,97,109,101,115,32,80,111,110,100,32,73,73,32,45,32,67,111,100,101,110,97,109,101,32,82,111,98,111,67,111,100,32,40,74,112,110,44,32,75,111,114,41,0,0,0,0,0,82,111,97,114,65,117,100,105,111,0,0,0,0,0,0,0,109,100,95,114,111,98,111,99,111,100,106,0,0,0,0,0,90,105,103,32,90,97,103,32,40,71,97,108,97,120,105,97,110,32,104,97,114,100,119,97,114,101,44,32,115,101,116,32,49,41,0,0,0,0,0,0,71,109,103,97,108,97,120,83,101,108,101,99,116,101,100,71,97,109,101,0,0,0,0,0,74,97,109,101,115,32,66,111,110,100,32,48,48,55,32,45,32,84,104,101,32,68,117,101,108,32,40,74,112,110,41,0,0,0,0,0,0,0,0,0,109,100,95,106,98,48,48,55,106,0,0,0,0,0,0,0,82,105,103,104,116,32,65,110,97,108,111,103,32,89,32,43,0,0,0,0,0,0,0,0,111,118,101,114,116,111,112,0,70,105,114,101,32,50,32,40,67,111,99,107,116,97,105,108,41,0,0,0,0,0,0,0,74,97,109,101,115,32,66,111,110,100,32,48,48,55,32,45,32,84,104,101,32,68,117,101,108,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,80,50,32,70,105,114,101,32,52,0,0,0,0,0,0,0,116,110,122,115,95,98,97,110,107,115,91,49,93,0,0,0,66,108,117,101,0,0,0,0,67,111,109,112,108,101,116,101,32,66,111,110,117,115,0,0,82,79,77,32,84,121,112,101,0,0,0,0,0,0,0,0,84,111,114,121,117,109,111,110,0,0,0,0,0,0,0,0,109,100,95,106,98,48,48,55,117,0,0,0,0,0,0,0,52,32,67,111,105,110,32,49,32,80,108,97,121,0,0,0,66,78,83,32,69,110,116,101,114,112,114,105,115,101,115,0,70,105,110,97,108,32,66,108,111,119,32,40,74,112,110,41,0,0,0,0,0,0,0,0,115,49,57,52,53,95,109,99,117,95,109,111,100,101,0,0,98,101,97,115,116,102,0,0,66,117,108,108,101,116,115,32,112,101,114,32,66,101,97,110,32,67,111,108,108,101,99,116,101,100,0,0,0,0,0,0,109,100,95,102,105,110,97,108,98,0,0,0,0,0,0,0,66,0,0,0,101,0,0,0,101,0,0,0,32,0,0,0,83,0,0,0,116,0,0,0,111,0,0,0,114,0,0,0,109,0,0,0,32,0,0,0,45,0,0,0,32,0,0,0,68,0,0,0,111,0,0,0,68,0,0,0,111,0,0,0,110,0,0,0,80,0,0,0,97,0,0,0,116,0,0,0,99,0,0,0,104,0,0,0,105,0,0,0,32,0,0,0,73,0,0,0,73,0,0,0,0,0,0,0,18,96,0,0,150,153,0,0,134,152,0,0,2,135,0,0,13,255,0,0,2,135,0,0,180,102,0,0,32,0,0,0,40,0,0,0,86,0,0,0,49,0,0,0,48,0,0,0,48,0,0,0,44,0,0,0,32,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,107,111,100,117,0,0,0,0,112,99,101,95,100,114,111,112,114,111,99,107,0,0,0,0,82,101,97,108,32,66,111,117,116,32,70,97,116,97,108,32,70,117,114,121,32,47,32,82,101,97,108,32,66,111,117,116,32,71,97,114,111,117,32,68,101,110,115,101,116,115,117,32,40,98,117,103,32,102,105,120,32,114,101,118,105,115,105,111,110,41,0,0,0,0,0,0,74,97,109,101,115,32,39,66,117,115,116,101,114,39,32,68,111,117,103,108,97,115,32,75,110,111,99,107,111,117,116,32,66,111,120,105,110,103,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,109,100,95,108,97,110,100,115,116,108,107,0,0,0,0,0,74,121,97,110,103,111,107,117,115,104,105,32,32,45,72,97,111,104,32,110,111,32,83,97,105,104,97,105,45,32,40,57,57,48,53,50,55,32,74,97,112,97,110,41,0,0,0,0,72,97,116,32,35,37,117,32,37,115,32,0,0,0,0,0,49,48,48,75,32,50,53,48,75,32,52,48,48,75,0,0,109,100,95,106,98,100,111,117,103,107,111,0,0,0,0,0,74,97,99,107,32,78,105,99,107,108,97,117,115,39,32,80,111,119,101,114,32,67,104,97,108,108,101,110,103,101,32,71,111,108,102,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,0,0,0,82,83,111,117,110,100,0,0,109,100,95,110,105,99,107,108,97,117,115,0,0,0,0,0,122,105,103,122,97,103,0,0,74,46,32,76,101,97,103,117,101,32,80,114,111,32,83,116,114,105,107,101,114,32,80,101,114,102,101,99,116,32,40,74,112,110,41,0,0,0,0,0,109,100,95,106,108,112,115,112,0,0,0,0,0,0,0,0,82,105,103,104,116,32,65,110,97,108,111,103,32,88,32,45,0,0,0,0,0,0,0,0,70,105,114,101,32,49,32,40,67,111,99,107,116,97,105,108,41,0,0,0,0,0,0,0,80,114,111,32,83,116,114,105,107,101,114,32,70,105,110,97,108,32,83,116,97,103,101,32,40,74,112,110,41,0,0,0,116,110,122,115,95,98,97,110,107,115,91,48,93,0,0,0,82,101,100,0,0,0,0,0,84,101,115,116,32,40,82,65,77,32,97,110,100,32,83,111,117,110,100,41,47,80,97,117,115,101,0,0,0,0,0,0,109,100,95,112,114,111,115,116,114,102,115,0,0,0,0,0,80,49,32,82,105,103,104,116,32,85,112,0,0,0,0,0,80,49,32,88,45,65,120,105,115,0,0,0,0,0,0,0,54,32,67,111,105,110,32,51,32,80,108,97,121,0,0,0,78,101,119,32,73,109,112,101,117,114,111,112,101,120,32,67,111,114,112,46,32,83,46,82,46,76,46,0,0,0,0,0,74,46,32,76,101,97,103,117,101,32,80,114,111,32,83,116,114,105,107,101,114,32,50,32,40,74,112,110,41,0,0,0,115,49,57,52,53,95,109,99,117,95,108,97,116,99,104,105,110,103,0,0,0,0,0,0,80,49,32,74,0,0,0,0,83,117,112,101,114,32,71,108,111,98,32,40,80,97,99,45,77,97,110,32,104,97,114,100,119,97,114,101,41,32,71,101,114,109,97,110,0,0,0,0,78,105,99,104,105,98,117,116,115,117,32,40,75,97,114,97,116,101,99,111,32,108,105,99,101,110,115,101,41,0,0,0,109,100,95,106,108,112,115,50,0,0,0,0,0,0,0,0,83,116,97,114,116,32,111,110,32,76,101,118,101,108,32,54,0,0,0,0,0,0,0,0,99,104,45,62,102,99,0,0,66,101,101,32,83,116,111,114,109,32,45,32,68,111,68,111,110,80,97,99,104,105,32,73,73,32,40,86,49,48,48,44,32,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,84,104,101,32,75,105,110,103,32,111,102,32,68,114,97,103,111,110,115,32,40,57,49,48,55,49,49,32,101,116,99,41,0,0,0,0,0,0,0,0,68,114,97,103,111,110,32,83,112,105,114,105,116,0,0,0,114,98,102,102,49,97,0,0,74,46,32,76,101,97,103,117,101,32,80,114,111,32,83,116,114,105,107,101,114,32,39,57,51,32,40,74,112,110,44,32,118,49,46,48,41,0,0,0,109,100,95,108,97,110,100,115,116,108,107,102,0,0,0,0,106,121,97,110,103,111,107,117,0,0,0,0,0,0,0,0,56,48,75,32,50,48,48,75,32,51,53,48,75,0,0,0,109,100,95,106,108,112,115,97,0,0,0,0,0,0,0,0,74,46,32,76,101,97,103,117,101,32,80,114,111,32,83,116,114,105,107,101,114,32,39,57,51,32,40,74,112,110,44,32,118,49,46,51,41,0,0,0,74,97,99,107,0,0,0,0,112,114,116,121,116,105,109,101,0,0,0,0,0,0,0,0,109,100,95,106,108,112,115,0,110,84,105,109,101,114,83,116,97,114,116,0,0,0,0,0,86,105,115,105,111,110,32,47,32,65,114,116,105,99,0,0,73,122,122,121,39,115,32,81,117,101,115,116,32,102,111,114,32,116,104,101,32,79,108,121,109,112,105,99,32,82,105,110,103,115,32,40,69,117,114,111,44,32,85,83,65,41,0,0,109,100,95,105,122,122,121,113,115,116,0,0,0,0,0,0,50,56,32,40,67,104,101,97,116,41,0,0,0,0,0,0,82,105,103,104,116,32,65,110,97,108,111,103,32,88,32,43,0,0,0,0,0,0,0,0,82,105,103,104,116,32,40,67,111,99,107,116,97,105,108,41,0,0,0,0,0,0,0,0,84,104,101,32,73,116,99,104,121,32,97,110,100,32,83,99,114,97,116,99,104,121,32,71,97,109,101,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,80,108,97,121,101,114,32,67,97,114,0,0,0,0,0,0,49,48,48,107,44,32,49,48,48,48,107,0,0,0,0,0,109,99,117,95,97,100,100,114,101,115,115,0,0,0,0,0,116,111,114,121,117,109,111,110,0,0,0,0,0,0,0,0,109,100,95,105,116,99,104,121,0,0,0,0,0,0,0,0,52,32,67,111,105,110,32,51,32,80,108,97,121,0,0,0,76,105,99,101,110,115,101,0,73,116,32,67,97,109,101,32,102,114,111,109,32,116,104,101,32,68,101,115,101,114,116,32,40,85,83,65,41,0,0,0,67,114,101,100,105,116,115,32,102,111,114,32,67,111,110,116,105,110,117,101,0,0,0,0,115,49,57,52,53,95,109,99,117,95,105,110,100,101,120,0,115,112,114,103,108,98,112,103,0,0,0,0,0,0,0,0,83,116,97,114,116,32,111,110,32,76,101,118,101,108,32,49,0,0,0,0,0,0,0,0,109,100,95,105,116,99,97,109,101,0,0,0,0,0,0,0,100,100,112,50,49,48,48,106,0,0,0,0,0,0,0,0,107,111,100,114,49,0,0,0,112,99,101,95,100,115,112,105,114,105,116,0,0,0,0,0,82,0,0,0,101,0,0,0,97,0,0,0,108,0,0,0,32,0,0,0,66,0,0,0,111,0,0,0,117,0,0,0,116,0,0,0,32,0,0,0,70,0,0,0,97,0,0,0,116,0,0,0,97,0,0,0,108,0,0,0,32,0,0,0,70,0,0,0,117,0,0,0,114,0,0,0,121,0,0,0,0,0,0,0,82,0,0,0,101,0,0,0,97,0,0,0,108,0,0,0,32,0,0,0,66,0,0,0,111,0,0,0,117,0,0,0,116,0,0,0,32,0,0,0,19,153,0,0,252,114,0,0,29,79,0,0,172,138,0,0,32,0,0,0,40,0,0,0,78,0,0,0,71,0,0,0,77,0,0,0,45,0,0,0,48,0,0,0,57,0,0,0,53,0,0,0,41,0,0,0,40,0,0,0,78,0,0,0,71,0,0,0,72,0,0,0,45,0,0,0,48,0,0,0,57,0,0,0,53,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,73,115,104,105,100,111,32,45,32,84,104,101,32,87,97,121,32,111,102,32,83,116,111,110,101,115,32,40,85,83,65,41,0,0,0,0,0,0,0,0,72,101,114,122,111,103,32,90,119,101,105,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,0,0,0,72,121,112,101,114,32,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,50,58,32,84,104,101,32,65,110,110,105,118,101,114,115,97,114,121,32,69,100,105,116,105,111,110,32,40,48,51,49,50,50,50,32,74,97,112,97,110,41,0,0,109,100,95,105,115,104,105,100,111,0,0,0,0,0,0,0,82,111,110,97,108,100,105,110,104,111,32,57,56,32,40,80,105,114,97,116,101,41,0,0,79,83,83,0,0,0,0,0,99,104,101,108,110,111,118,106,0,0,0,0,0,0,0,0,89,32,40,108,101,102,116,41,0,0,0,0,0,0,0,0,109,100,95,100,105,110,104,111,57,56,0,0,0,0,0,0,68,101,118,105,108,32,70,105,115,104,32,40,71,97,108,97,120,105,97,110,32,104,97,114,100,119,97,114,101,44,32,98,111,111,116,108,101,103,63,41,0,0,0,0,0,0,0,0,73,110,116,101,114,110,97,116,105,111,110,97,108,32,83,117,112,101,114,115,116,97,114,32,83,111,99,99,101,114,32,68,101,108,117,120,101,32,40,69,117,114,111,41,0,0,0,0,109,100,95,105,115,115,100,120,0,0,0,0,0,0,0,0,99,111,98,114,97,99,111,109,106,97,0,0,0,0,0,0,76,101,102,116,32,65,110,97,108,111,103,32,89,32,45,0,76,101,102,116,32,40,67,111,99,107,116,97,105,108,41,0,73,110,116,101,114,110,97,116,105,111,110,97,108,32,82,117,103,98,121,32,40,69,117,114,111,41,0,0,0,0,0,0,42,51,0,0,0,0,0,0,78,101,116,119,111,114,107,0,109,99,117,95,108,97,116,99,104,0,0,0,0,0,0,0,84,105,109,101,32,83,99,97,110,110,101,114,32,40,115,101,116,32,50,44,32,83,121,115,116,101,109,32,49,54,66,41,0,0,0,0,0,0,0,0,109,100,95,105,110,116,114,117,103,98,121,0,0,0,0,0,80,49,32,76,101,102,116,32,82,105,103,104,116,0,0,0,69,120,116,114,97,32,72,97,114,100,101,115,116,0,0,0,53,32,67,111,105,110,32,54,32,80,108,97,121,0,0,0,80,97,116,116,101,114,110,32,52,0,0,0,0,0,0,0,73,110,115,116,114,117,109,101,110,116,115,32,111,102,32,67,104,97,111,115,32,83,116,97,114,114,105,110,103,32,89,111,117,110,103,32,73,110,100,105,97,110,97,32,74,111,110,101,115,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,51,49,50,50,56,41,0,0,0,0,0,0,0,0,0,83,108,105,100,101,32,115,104,111,119,32,111,110,32,98,111,111,116,0,0,0,0,0,0,86,101,114,115,117,115,32,71,97,109,101,0,0,0,0,0,115,49,57,52,53,95,109,99,117,95,105,110,108,97,116,99,104,0,0,0,0,0,0,0,80,49,32,73,0,0,0,0,83,117,112,101,114,32,71,108,111,98,32,40,80,97,99,45,77,97,110,32,104,97,114,100,119,97,114,101,41,0,0,0,49,48,48,48,48,32,79,78,108,121,0,0,0,0,0,0,109,100,95,105,110,115,116,99,104,112,57,0,0,0,0,0,66,0,0,0,101,0,0,0,101,0,0,0,32,0,0,0,83,0,0,0,116,0,0,0,111,0,0,0,114,0,0,0,109,0,0,0,32,0,0,0,45,0,0,0,32,0,0,0,68,0,0,0,111,0,0,0,68,0,0,0,111,0,0,0,110,0,0,0,80,0,0,0,97,0,0,0,116,0,0,0,99,0,0,0,104,0,0,0,105,0,0,0,32,0,0,0,73,0,0,0,73,0,0,0,0,0,0,0,18,96,0,0,150,153,0,0,134,152,0,0,2,135,0,0,13,255,0,0,2,135,0,0,180,102,0,0,32,0,0,0,40,0,0,0,86,0,0,0,49,0,0,0,48,0,0,0,49,0,0,0,44,0,0,0,32,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,84,104,101,32,75,105,110,103,32,111,102,32,68,114,97,103,111,110,115,32,40,57,49,48,56,48,53,32,101,116,99,41,0,0,0,0,0,0,0,0,68,114,97,103,111,110,32,83,97,98,101,114,32,45,32,65,102,116,101,114,32,83,116,111,114,121,32,111,102,32,68,114,97,103,111,110,32,83,112,105,114,105,116,32,40,65,108,116,41,0,0,0,0,0,0,0,82,101,97,108,32,66,111,117,116,32,70,97,116,97,108,32,70,117,114,121,32,47,32,82,101,97,108,32,66,111,117,116,32,71,97,114,111,117,32,68,101,110,115,101,116,115,117,32,40,78,71,77,45,48,57,53,41,40,78,71,72,45,48,57,53,41,0,0,0,0,0,0,73,110,115,116,114,117,109,101,110,116,115,32,111,102,32,67,104,97,111,115,32,83,116,97,114,114,105,110,103,32,89,111,117,110,103,32,73,110,100,105,97,110,97,32,74,111,110,101,115,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,57,50,51,45,65,41,0,0,0,0,0,0,0,109,100,95,104,101,114,122,111,103,0,0,0,0,0,0,0,104,115,102,50,106,0,0,0,112,97,117,115,101,0,0,0,68,101,98,117,103,32,77,111,100,101,32,50,32,108,97,112,0,0,0,0,0,0,0,0,80,49,32,67,111,105,110,0,109,100,95,105,110,115,116,99,104,112,52,0,0,0,0,0,37,48,56,120,58,32,67,111,45,80,114,111,99,101,115,115,111,114,32,68,97,116,97,32,79,112,101,114,97,116,105,111,110,32,101,120,101,99,117,116,101,100,44,32,98,117,116,32,110,111,32,99,97,108,108,98,97,99,107,32,100,101,102,105,110,101,100,33,10,0,0,0,73,110,115,116,114,117,109,101,110,116,115,32,111,102,32,67,104,97,111,115,32,83,116,97,114,114,105,110,103,32,89,111,117,110,103,32,73,110,100,105,97,110,97,32,74,111,110,101,115,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,49,50,55,41,0,0,0,0,0,0,0,0,0,87,105,122,97,114,100,32,70,105,114,101,32,40,79,118,101,114,32,83,101,97,32,118,50,46,49,41,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,67,114,101,97,116,105,110,103,32,70,66,79,32,37,100,32,64,32,37,117,120,37,117,10,0,0,0,0,0,97,117,100,105,111,32,100,114,105,118,101,114,0,0,0,0,82,45,62,112,111,114,116,51,95,100,97,116,97,0,0,0,104,101,114,111,0,0,0,0,67,111,105,110,32,65,0,0,84,101,115,116,32,109,111,100,101,0,0,0,0,0,0,0,102,105,120,101,105,103,104,116,97,116,0,0,0,0,0,0,83,105,110,103,108,101,32,83,99,114,101,101,110,32,40,72,97,99,107,41,0,0,0,0])
.concat([109,100,95,105,110,115,116,99,104,112,53,0,0,0,0,0,103,101,116,115,116,97,114,106,0,0,0,0,0,0,0,0,51,32,67,111,105,110,115,32,49,32,67,114,101,100,105,116,115,0,0,0,0,0,0,0,73,110,115,116,114,117,109,101,110,116,115,32,111,102,32,67,104,97,111,115,32,83,116,97,114,114,105,110,103,32,89,111,117,110,103,32,73,110,100,105,97,110,97,32,74,111,110,101,115,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,49,50,54,41,0,0,0,0,0,0,0,0,0,104,97,99,107,0,0,0,0,171,155,0,0,33,0,0,0,171,155,0,0,33,0,0,0,171,155,0,0,33,0,0,0,0,0,0,0,83,0,0,0,97,0,0,0,109,0,0,0,101,0,0,0,33,0,0,0,32,0,0,0,83,0,0,0,97,0,0,0,109,0,0,0,101,0,0,0,33,0,0,0,32,0,0,0,83,0,0,0,97,0,0,0,109,0,0,0,101,0,0,0,33,0,0,0,0,0,0,0,0,0,0,0,109,100,95,105,110,115,116,99,104,112,54,0,0,0,0,0,99,104,105,112,45,62,99,98,97,110,107,0,0,0,0,0,76,101,102,116,32,65,110,97,108,111,103,32,89,32,43,0,68,111,119,110,32,40,67,111,99,107,116,97,105,108,41,0,73,110,115,116,114,117,109,101,110,116,115,32,111,102,32,67,104,97,111,115,32,83,116,97,114,114,105,110,103,32,89,111,117,110,103,32,73,110,100,105,97,110,97,32,74,111,110,101,115,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,49,48,51,41,0,0,0,0,0,0,0,0,0,102,114,111,109,95,109,99,117,0,0,0,0,0,0,0,0,80,97,114,116,32,50,0,0,98,111,117,108,100,97,115,104,106,0,0,0,0,0,0,0,42,50,0,0,0,0,0,0,76,111,99,107,101,100,0,0,68,101,97,100,32,67,111,110,110,101,99,116,105,111,110,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,112,111,114,116,52,95,111,117,116,0,0,0,0,0,0,0,98,121,103,111,110,101,0,0,116,105,109,101,115,99,97,110,0,0,0,0,0,0,0,0,48,49,48,48,49,49,48,48,48,48,0,0,0,0,0,0,109,100,95,105,110,115,116,99,104,112,55,0,0,0,0,0,72,97,114,100,101,114,0,0,52,32,67,111,105,110,32,53,32,80,108,97,121,0,0,0,80,97,116,116,101,114,110,32,51,0,0,0,0,0,0,0,84,97,105,116,111,32,65,109,101,114,105,99,97,32,67,111,114,112,111,114,97,116,105,111,110,32,40,82,111,109,115,116,97,114,32,108,105,99,101,110,115,101,41,0,0,0,0,0,65,114,107,97,110,111,105,100,32,40,98,111,111,116,108,101,103,32,119,105,116,104,32,77,67,85,32,115,101,116,32,49,41,0,0,0,0,0,0,0,73,110,115,116,114,117,109,101,110,116,115,32,111,102,32,67,104,97,111,115,32,83,116,97,114,114,105,110,103,32,89,111,117,110,103,32,73,110,100,105,97,110,97,32,74,111,110,101,115,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,49,48,49,41,0,0,0,0,0,0,0,0,0,86,101,114,115,117,115,32,67,80,85,32,71,97,109,101,32,69,110,100,115,0,0,0,0,115,49,57,52,53,95,109,99,117,95,108,97,116,99,104,50,0,0,0,0,0,0,0,0,110,97,115,116,97,114,119,0,86,68,67,32,68,65,84,65,0,0,0,0,0,0,0,0,115,112,114,103,108,111,98,112,0,0,0,0,0,0,0,0,98,115,104,97,114,107,117,0,99,99,95,112,111,114,116,0,69,118,101,114,121,32,49,48,48,48,48,0,0,0,0,0,109,100,95,105,110,115,116,99,104,112,56,0,0,0,0,0,112,97,108,100,109,97,95,108,101,110,103,116,104,0,0,0,111,112,119,111,108,102,106,0,101,116,111,0,0,0,0,0,66,101,101,32,83,116,111,114,109,32,45,32,68,111,68,111,110,80,97,99,104,105,32,73,73,32,40,86,49,48,49,44,32,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,107,111,100,0,0,0,0,0,112,99,101,95,100,115,97,98,101,114,49,0,0,0,0,0,115,98,111,98,108,98,111,97,0,0,0,0,0,0,0,0,73,110,115,116,114,117,109,101,110,116,115,32,111,102,32,67,104,97,111,115,32,83,116,97,114,114,105,110,103,32,89,111,117,110,103,32,73,110,100,105,97,110,97,32,74,111,110,101,115,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,49,50,50,56,45,65,41,0,0,0,0,0,0,0,115,117,112,101,114,109,97,110,117,0,0,0,0,0,0,0,84,97,105,116,111,32,67,111,114,112,111,114,97,116,105,111,110,32,65,109,101,114,105,99,97,32,40,108,105,99,101,110,115,101,100,32,116,111,32,82,111,109,115,116,97,114,41,0,81,117,97,99,107,83,104,111,116,32,83,116,97,114,114,105,110,103,32,68,111,110,97,108,100,32,68,117,99,107,32,126,32,81,117,97,99,107,83,104,111,116,32,45,32,71,117,114,117,122,105,97,32,79,117,32,110,111,32,72,105,104,111,117,32,40,87,111,114,108,100,41,0,0,0,0,0,0,0,0,72,121,112,101,114,32,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,50,58,32,84,104,101,32,65,110,110,105,118,101,114,115,97,114,121,32,69,100,105,116,105,111,110,32,40,48,52,48,50,48,50,32,65,115,105,97,41,0,0,0,115,104,97,110,103,111,110,50,0,0,0,0,0,0,0,0,98,97,99,107,113,117,111,116,101,0,0,0,0,0,0,0,109,100,95,105,110,115,116,99,104,112,51,0,0,0,0,0,115,102,105,105,105,51,0,0,74,117,117,111,117,107,105,32,40,115,101,116,32,55,44,32,74,97,112,97,110,44,32,56,55,53,49,32,51,49,55,45,48,48,55,55,41,0,0,0,66,111,111,116,108,101,103,70,103,80,97,103,101,0,0,0,73,110,115,116,114,117,109,101,110,116,115,32,111,102,32,67,104,97,111,115,32,83,116,97,114,114,105,110,103,32,89,111,117,110,103,32,73,110,100,105,97,110,97,32,74,111,110,101,115,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,49,50,50,57,41,0,0,0,0,0,0,0,0,0,65,76,83,65,0,0,0,0,102,108,105,99,107,121,0,0,67,108,117,116,99,104,32,72,105,116,116,101,114,32,40,115,101,116,32,49,44,32,74,97,112,97,110,44,32,70,68,49,48,57,52,32,51,49,55,45,48,49,55,53,41,0,0,0,80,111,119,101,114,32,68,114,105,102,116,32,40,87,111,114,108,100,41,0,0,0,0,0,109,100,95,105,110,115,116,99,104,112,50,0,0,0,0,0,71,80,32,82,105,100,101,114,32,40,85,83,44,32,70,68,49,48,57,52,32,51,49,55,45,48,49,54,50,41,0,0,100,101,118,105,108,102,115,104,0,0,0,0,0,0,0,0,86,100,112,87,105,110,100,111,119,72,80,111,115,0,0,0,65,108,105,101,110,32,83,121,110,100,114,111,109,101,32,40,115,101,116,32,50,44,32,83,121,115,116,101,109,32,49,54,65,44,32,70,68,49,48,56,57,65,32,51,49,55,45,48,48,51,51,41,0,0,0,0,73,110,115,116,114,117,109,101,110,116,115,32,111,102,32,67,104,97,111,115,32,83,116,97,114,114,105,110,103,32,89,111,117,110,103,32,73,110,100,105,97,110,97,32,74,111,110,101,115,32,40,80,114,111,116,111,116,121,112,101,41,0,0,0,69,120,112,108,111,115,105,118,101,32,66,114,101,97,107,101,114,0,0,0,0,0,0,0,109,99,104,97,109,112,100,120,97,0,0,0,0,0,0,0,68,111,117,98,108,101,32,80,111,105,110,116,32,40,68,111,110,103,32,66,97,110,103,32,69,108,101,99,116,114,111,110,44,32,98,111,111,116,108,101,103,63,41,0,0,0,0,0,109,100,95,105,110,115,116,99,104,112,49,0,0,0,0,0,118,105,100,101,111,95,109,111,110,105,116,111,114,95,105,110,100,101,120,0,0,0,0,0,49,32,67,111,105,110,32,53,32,67,114,101,100,105,116,115,0,0,0,0,0,0,0,0,76,101,102,116,32,65,110,97,108,111,103,32,88,32,45,0,73,110,115,116,114,117,109,101,110,116,115,32,111,102,32,67,104,97,111,115,32,83,116,97,114,114,105,110,103,32,89,111,117,110,103,32,73,110,100,105,97,110,97,32,74,111,110,101,115,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,80,117,122,122,108,101,32,67,108,117,98,32,40,89,117,110,32,83,117,110,103,44,32,115,101,116,32,50,41,0,0,0,85,112,32,40,67,111,99,107,116,97,105,108,41,0,0,0,68,114,118,68,105,112,0,0,80,97,114,116,32,49,0,0,83,101,114,118,105,99,101,49,0,0,0,0,0,0,0,0,42,49,46,53,0,0,0,0,70,114,101,101,0,0,0,0,50,53,48,107,44,32,53,48,48,107,44,32,49,48,48,48,107,44,32,49,53,48,48,107,44,32,50,48,48,48,107,0,112,111,114,116,51,95,111,117,116,0,0,0,0,0,0,0,84,101,116,114,105,115,32,40,98,111,111,116,108,101,103,41,0,0,0,0,0,0,0,0,109,100,95,105,110,115,116,99,104,0,0,0,0,0,0,0,80,49,32,76,101,102,116,32,76,101,102,116,0,0,0,0,50,32,67,111,105,110,32,51,32,80,108,97,121,0,0,0,80,97,116,116,101,114,110,32,50,0,0,0,0,0,0,0,82,97,105,100,101,110,32,40,115,101,116,32,51,44,32,65,108,116,101,114,110,97,116,101,32,104,97,114,100,119,97,114,101,41,0,0,0,0,0,0,80,91,0,0,178,128,0,0,102,48,0,0,175,48,0,0,164,48,0,0,186,48,0,0,32,0,0,0,222,48,0,0,164,48,0,0,32,0,0,0,168,48,0,0,243,48,0,0,184,48,0,0,167,48,0,0,235,48,0,0,32,0,0,0,18,255,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,75,0,0,0,111,0,0,0,115,0,0,0,111,0,0,0,100,0,0,0,97,0,0,0,116,0,0,0,101,0,0,0,32,0,0,0,81,0,0,0,117,0,0,0,105,0,0,0,122,0,0,0,32,0,0,0,77,0,0,0,121,0,0,0,32,0,0,0,65,0,0,0,110,0,0,0,103,0,0,0,101,0,0,0,108,0,0,0,32,0,0,0,50,0,0,0,0,0,0,0,0,0,0,0,40,105,110,99,108,117,100,101,100,41,0,0,0,0,0,0,73,110,115,101,99,116,111,114,32,88,32,40,74,112,110,44,32,75,111,114,41,0,0,0,115,49,57,52,53,95,109,99,117,95,108,97,116,99,104,49,0,0,0,0,0,0,0,0,80,49,32,72,0,0,0,0,66,111,109,98,32,75,105,99,107,32,40,115,101,116,32,50,41,0,0,0,0,0,0,0,69,112,111,115,32,67,111,114,112,111,114,97,116,105,111,110,0,0,0,0,0,0,0,0,112,50,32,85,112,0,0,0,119,105,108,100,102,97,110,103,0,0,0,0,0,0,0,0,109,100,95,105,110,115,101,99,116,120,106,0,0,0,0,0,100,100,112,50,49,48,49,106,0,0,0,0,0,0,0,0,78,101,119,32,70,97,110,116,97,115,105,97,32,40,115,101,116,32,50,41,0,0,0,0,75,110,105,103,104,116,115,32,111,102,32,116,104,101,32,82,111,117,110,100,32,40,104,97,99,107,32,115,101,116,32,50,44,32,57,49,49,49,50,55,32,101,116,99,41,0,0,0,68,114,97,103,111,110,32,83,97,98,101,114,32,45,32,65,102,116,101,114,32,83,116,111,114,121,32,111,102,32,68,114,97,103,111,110,32,83,112,105,114,105,116,0,0,0,0,0,70,105,103,104,116,101,114,115,32,83,119,111,114,100,115,32,40,75,111,114,101,97,110,32,114,101,108,101,97,115,101,32,111,102,32,83,97,109,117,114,97,105,32,83,104,111,100,111,119,110,32,73,73,73,41,0,0,0,0,0,0,0,0,0,116,104,111,111,112,0,0,0,73,110,115,101,99,116,111,114,32,88,32,40,85,83,65,41,0,0,0,0,0,0,0,0,50,48,48,75,32,56,48,48,75,0,0,0,0,0,0,0,54,56,75,32,82,65,77,0,80,0,0,0,114,0,0,0,101,0,0,0,116,0,0,0,116,0,0,0,121,0,0,0,32,0,0,0,83,0,0,0,111,0,0,0,108,0,0,0,100,0,0,0,105,0,0,0,101,0,0,0,114,0,0,0,32,0,0,0,83,0,0,0,97,0,0,0,105,0,0,0,108,0,0,0,111,0,0,0,114,0,0,0,32,0,0,0,77,0,0,0,111,0,0,0,111,0,0,0,110,0,0,0,0,0,0,0,142,127,0,0,17,92,0,0,115,89,0,0,38,98,0,0,235,88,0,0,32,0,0,0,187,48,0,0,252,48,0,0,233,48,0,0,252,48,0,0,224,48,0,0,252,48,0,0,243,48,0,0,32,0,0,0,40,0,0,0,118,0,0,0,101,0,0,0,114,0,0,0,46,0,0,0,32,0,0,0,57,0,0,0,53,0,0,0,47,0,0,0,48,0,0,0,51,0,0,0,47,0,0,0,50,0,0,0,50,0,0,0,66,0,0,0,44,0,0,0,32,0,0,0,84,0,0,0,97,0,0,0,105,0,0,0,119,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,109,100,95,113,117,97,99,107,115,104,116,0,0,0,0,0,104,115,102,50,97,0,0,0,67,101,110,115,111,114,32,80,105,99,116,117,114,101,115,0,109,100,95,105,110,115,101,99,116,120,0,0,0,0,0,0,86,45,83,121,115,116,101,109,32,67,111,46,0,0,0,0,84,104,101,32,67,111,109,98,97,116,114,105,98,101,115,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,73,110,100,105,97,110,97,32,74,111,110,101,115,32,97,110,100,32,116,104,101,32,76,97,115,116,32,67,114,117,115,97,100,101,32,40,85,83,65,41,0,0,0,0,0,0,0,0,88,86,105,100,101,111,32,111,117,116,112,117,116,0,0,0,113,122,107,107,108,111,103,121,0,0,0,0,0,0,0,0,109,100,95,105,110,100,121,99,114,117,115,117,0,0,0,0,50,32,67,111,105,110,45,51,32,80,108,97,121,0,0,0,100,101,118,105,108,102,115,103,0,0,0,0,0,0,0,0,105,110,105,116,95,118,105,100,101,111,95,105,110,112,117,116,40,41,0,0,0,0,0,0,77,0,0,0,111,0,0,0,114,0,0,0,101,0,0,0,32,0,0,0,77,0,0,0,111,0,0,0,114,0,0,0,101,0,0,0,0,0,0,0,168,186,0,0,68,197,0,0,168,186,0,0,68,197,0,0,32,0,0,0,77,0,0,0,111,0,0,0,114,0,0,0,101,0,0,0,32,0,0,0,77,0,0,0,111,0,0,0,114,0,0,0,101,0,0,0,0,0,0,0,0,0,0,0,112,97,110,103,112,97,110,103,0,0,0,0,0,0,0,0,73,110,100,105,97,110,97,32,74,111,110,101,115,32,97,110,100,32,116,104,101,32,76,97,115,116,32,67,114,117,115,97,100,101,32,40,69,117,114,111,41,0,0,0,0,0,0,0,98,116,108,107,114,111,97,100,0,0,0,0,0,0,0,0,108,111,100,101,114,110,100,102,0,0,0,0,0,0,0,0,68,114,118,79,107,105,66,97,110,107,49,95,50,0,0,0,109,100,95,105,110,100,121,99,114,117,115,0,0,0,0,0,49,32,67,111,105,110,32,32,51,32,80,108,97,121,115,0,83,116,114,97,116,111,118,111,120,0,0,0,0,0,0,0,76,101,102,116,32,65,110,97,108,111,103,32,88,32,43,0,108,101,103,105,111,110,111,0,70,105,114,101,32,53,0,0,84,104,101,32,73,110,99,114,101,100,105,98,108,101,32,72,117,108,107,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,0,0,0,112,107,108,97,100,105,101,115,108,97,0,0,0,0,0,0,71,97,109,101,32,67,104,97,110,103,101,32,77,111,100,101,0,0,0,0,0,0,0,0,42,49,0,0,0,0,0,0,83,116,101,101,114,105,110,103,32,87,104,101,101,108,32,84,121,112,101,0,0,0,0,0,50,48,48,107,44,32,52,48,48,107,44,32,32,56,48,48,107,44,32,49,50,48,48,107,44,32,49,54,48,48,107,0,112,111,114,116,50,95,111,117,116,0,0,0,0,0,0,0,67,111,110,116,114,111,108,115,73,110,118,101,114,116,0,0,109,100,95,104,117,108,107,0,116,101,116,114,105,115,98,108,0,0,0,0,0,0,0,0,66,117,115,121,69,120,112,105,114,101,0,0,0,0,0,0,69,97,115,105,101,114,0,0,49,32,67,111,105,110,32,49,32,80,108,97,121,0,0,0,80,97,116,116,101,114,110,32,49,0,0,0,0,0,0,0,67,0,0,0,0,0,0,0,112,97,99,109,97,110,0,0,103,97,117,110,116,108,101,116,114,55,0,0,0,0,0,0,84,104,101,32,73,110,99,114,101,100,105,98,108,101,32,67,114,97,115,104,32,68,117,109,109,105,101,115,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,49,48,58,48,48,0,0,0,83,104,111,119,32,71,105,114,108,115,0,0,0,0,0,0,115,49,57,52,53,95,109,99,117,95,100,105,114,101,99,116,105,111,110,0,0,0,0,0,98,103,95,101,110,97,98,108,101,0,0,0,0,0,0,0,84,104,101,32,71,108,111,98,32,40,80,97,99,45,77,97,110,32,104,97,114,100,119,97,114,101,41,0,0,0,0,0,48,45,53,0,0,0,0,0,121,97,110,107,101,101,100,111,0,0,0,0,0,0,0,0,53,32,117,110,100,101,114,32,52,48,48,48,32,112,116,115,0,0,0,0,0,0,0,0,109,100,95,99,114,97,115,104,100,117,109,112,0,0,0,0,68,111,110,107,101,121,32,75,111,110,103,32,40,74,97,112,97,110,32,115,101,116,32,50,41,0,0,0,0,0,0,0,66,0,0,0,101,0,0,0,101,0,0,0,32,0,0,0,83,0,0,0,116,0,0,0,111,0,0,0,114,0,0,0,109,0,0,0,32,0,0,0,45,0,0,0,32,0,0,0,68,0,0,0,111,0,0,0,68,0,0,0,111,0,0,0,110,0,0,0,80,0,0,0,97,0,0,0,116,0,0,0,99,0,0,0,104,0,0,0,105,0,0,0,32,0,0,0,73,0,0,0,73,0,0,0,0,0,0,0,18,96,0,0,150,153,0,0,134,152,0,0,2,135,0,0,13,255,0,0,2,135,0,0,180,102,0,0,32,0,0,0,40,0,0,0,86,0,0,0,49,0,0,0,48,0,0,0,50,0,0,0,44,0,0,0,32,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,107,110,105,103,104,116,115,104,50,0,0,0,0,0,0,0,112,99,101,95,100,115,97,98,101,114,0,0,0,0,0,0,102,115,119,111,114,100,115,0,101,120,101,100,101,120,101,115,95,110,98,103,95,120,115,99,114,111,108,108,0,0,0,0,87,105,122,97,114,100,32,111,102,32,116,104,101,32,73,109,109,111,114,116,97,108,32,40,74,112,110,41,0,0,0,0,90,56,48,32,82,65,77,32,40,67,80,85,32,35,50,41,0,0,0,0,0,0,0,0,84,104,117,110,100,101,114,32,70,111,114,99,101,32,73,73,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,54,48,75,47,49,50,48,75,47,50,52,48,75,47,52,56,48,75,0,0,0,0,0,0,72,121,112,101,114,32,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,50,58,32,84,104,101,32,65,110,110,105,118,101,114,115,97,114,121,32,69,100,105,116,105,111,110,32,40,48,52,48,50,48,50,32,85,83,65,41,0,0,0,0,116,114,111,106,97,110,0,0,115,99,114,111,108,108,95,108,111,99,107,0,0,0,0,0,84,101,116,114,105,115,32,40,99,111,99,107,116,97,105,108,32,115,101,116,32,50,41,0,0,0,0,0,0,0,0,0,109,100,95,105,109,109,111,114,116,97,108,106,0,0,0,0,98,114,105,120,0,0,0,0,84,104,101,32,71,108,111,98,32,40,115,101,116,32,51,41,0,0,0,0,0,0,0,0,83,116,114,101,101,116,32,83,109,97,114,116,32,40,85,83,32,118,101,114,115,105,111,110,32,49,41,0,0,0,0,0,115,105,110,118,97,115,110,98,0,0,0,0,0,0,0,0,49,57,52,51,107,97,105,0,84,104,101,32,73,109,109,111,114,116,97,108,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,0,0,88,86,105,100,101,111,0,0,108,101,100,115,116,111,114,109,0,0,0,0,0,0,0,0,109,100,95,105,109,109,111,114,116,97,108,0,0,0,0,0,66,97,116,116,108,101,32,111,102,32,65,116,108,97,110,116,105,115,32,40,98,111,111,116,108,101,103,41,0,0,0,0,87,99,57,48,98,49,83,99,114,111,108,108,88,76,111,0,71,104,111,115,116,115,39,110,32,71,111,98,108,105,110,115,32,40,85,83,41,0,0,0,82,101,116,114,111,65,114,99,104,58,32,82,79,77,32,115,105,122,101,58,32,37,117,32,98,121,116,101,115,46,10,0,73,77,71,32,73,110,116,101,114,110,97,116,105,111,110,97,108,32,84,111,117,114,32,84,101,110,110,105,115,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,0,87,99,57,48,83,99,114,111,108,108,48,88,76,111,0,0,83,105,108,107,32,87,111,114,109,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,109,100,95,105,109,103,105,116,116,0,0,0,0,0,0,0,100,100,114,97,103,111,110,98,50,0,0,0,0,0,0,0,77,67,54,56,52,48,95,102,108,97,103,0,0,0,0,0,107,111,118,108,115,106,98,97,0,0,0,0,0,0,0,0,109,95,100,114,103,119,50,95,112,114,111,116,95,104,105,108,111,95,115,101,108,101,99,116,0,0,0,0,0,0,0,0,82,101,116,114,111,80,97,100,32,82,51,32,66,117,116,116,111,110,0,0,0,0,0,0,70,105,114,101,32,52,0,0,72,121,112,101,114,32,77,97,114,98,108,101,115,32,40,74,112,110,44,32,71,97,109,101,32,110,111,32,75,97,110,100,117,109,101,32,77,101,103,97,67,68,32,82,105,112,41,0,0,0,0,0,0,0,0,0,79,0,0,0,114,0,0,0,105,0,0,0,101,0,0,0,110,0,0,0,116,0,0,0,97,0,0,0,108,0,0,0,32,0,0,0,76,0,0,0,101,0,0,0,103,0,0,0,101,0,0,0,110,0,0,0,100,0,0,0,0,0,0,0,127,137,0,0,56,110,0,0,202,145,0,0,132,83,0,0,32,79,0,0,32,0,0,0,40,0,0,0,86,0,0,0,49,0,0,0,49,0,0,0,50,0,0,0,32,0,0,0,97,0,0,0,108,0,0,0,116,0,0,0,44,0,0,0,32,0,0,0,67,0,0,0,104,0,0,0,105,0,0,0,110,0,0,0,97,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,49,32,102,105,114,101,32,53,0,0,0,0,0,0,0,68,97,109,97,103,101,32,77,117,108,116,105,112,108,105,101,114,0,0,0,0,0,0,0,49,53,48,107,44,32,51,48,48,107,44,32,32,54,48,48,107,44,32,32,57,48,48,107,44,32,49,50,48,48,107,0,112,111,114,116,49,95,111,117,116,0,0,0,0,0,0,0,84,101,116,114,105,115,32,40,115,101,116,32,50,44,32,74,97,112,97,110,44,32,83,121,115,116,101,109,32,49,54,66,44,32,70,68,49,48,57,52,32,51,49,55,45,48,48,57,50,41,0,0,0,0,0,0,109,100,95,104,121,112,101,114,109,103,110,107,0,0,0,0,80,49,32,76,101,102,116,32,68,111,119,110,0,0,0,0,76,103,104,111,115,116,86,97,108,117,101,0,0,0,0,0,67,111,105,110,32,82,97,116,101,32,83,108,111,116,32,65,0,0,0,0,0,0,0,0,67,114,111,99,111,100,105,108,101,115,32,40,84,111,110,103,32,66,111,121,41,0,0,0,72,121,112,101,114,32,77,97,114,98,108,101,115,32,40,74,112,110,44,32,83,101,103,97,78,101,116,41,0,0,0,0,70,105,101,108,100,32,67,111,108,111,117,114,0,0,0,0,78,69,67,32,65,118,101,110,117,101,0,0,0,0,0,0,110,80,115,105,107,121,111,90,56,48,66,97,110,107,0,0,80,49,32,71,0,0,0,0,115,117,112,114,103,108,111,98,0,0,0,0,0,0,0,0,51,32,117,110,100,101,114,32,52,48,48,48,32,112,116,115,0,0,0,0,0,0,0,0,109,100,95,104,121,112,101,114,109,0,0,0,0,0,0,0,66,101,101,32,83,116,111,114,109,32,45,32,68,111,68,111,110,80,97,99,104,105,32,73,73,32,40,86,49,48,50,44,32,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,77,97,115,105,121,97,0,0,83,0,0,0,97,0,0,0,109,0,0,0,117,0,0,0,114,0,0,0,97,0,0,0,105,0,0,0,32,0,0,0,83,0,0,0,104,0,0,0,111,0,0,0,100,0,0,0,111,0,0,0,119,0,0,0,110,0,0,0,32,0,0,0,73,0,0,0,73,0,0,0,73,0,0,0,0,0,0,0,181,48,0,0,224,48,0,0,233,48,0,0,164,48,0,0,185,48,0,0,212,48,0,0,234,48,0,0,195,48,0,0,196,48,0,0,32,0,0,0,45,0,0,0,32,0,0,0,172,101,0,0,5,125,0,0,206,144,0,0,33,113,0,0,204,83,0,0,99,82,0,0,32,0,0,0,40,0,0,0,78,0,0,0,71,0,0,0,72,0,0,0,45,0,0,0,48,0,0,0,56,0,0,0,55,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,66,97,115,101,98,97,108,108,32,83,116,97,114,115,32,80,114,111,102,101,115,115,105,111,110,97,108,32,40,78,71,77,45,48,48,50,41,0,0,0,84,104,114,101,101,32,87,111,110,100,101,114,115,32,40,119,111,110,100,101,114,32,51,32,57,49,48,53,50,48,32,85,83,65,41,0,0,0,0,0,68,111,117,98,108,101,32,68,114,105,98,98,108,101,32,45,32,84,104,101,32,80,108,97,121,111,102,102,32,69,100,105,116,105,111,110,32,40,85,83,65,41,0,0,0,0,0,0,83,112,114,105,116,101,32,108,97,121,101,114,32,116,105,108,101,32,82,65,77,0,0,0,109,100,95,116,102,50,0,0,109,100,95,100,100,114,105,98,98,108,101,0,0,0,0,0,112,114,105,110,116,95,115,99,114,101,101,110,0,0,0,0,105,110,99,111,114,114,101,99,116,32,100,97,116,97,32,99,104,101,99,107,0,0,0,0,72,121,112,101,114,32,68,117,110,107,32,45,32,84,104,101,32,80,108,97,121,111,102,102,32,69,100,105,116,105,111,110,32,40,74,112,110,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,0,79,112,101,110,86,71,32,111,117,116,112,117,116,32,115,117,112,112,111,114,116,0,0,0,83,76,79,84,45,62,107,101,121,0,0,0,0,0,0,0,103,108,68,101,98,117,103,77,101,115,115,97,103,101,67,111,110,116,114,111,108,0,0,0,109,100,95,104,121,112,101,114,100,110,107,106,112,0,0,0,97,116,108,97,110,116,105,115,0,0,0,0,0,0,0,0,73,110,112,117,116,83,105,122,101,0,0,0,0,0,0,0,72,121,112,101,114,32,68,117,110,107,32,45,32,84,104,101,32,80,108,97,121,111,102,102,32,69,100,105,116,105,111,110,32,40,74,112,110,41,0,0,83,67,82,69,69,78,83,72,79,84,32,68,73,82,32,37,115,0,0,0,0,0,0,0,109,100,95,104,121,112,101,114,100,110,107,106,0,0,0,0,37,46,51,102,0,0,0,0,74,97,109,101,115,32,80,111,110,100,32,73,73,32,45,32,67,111,100,101,110,97,109,101,32,82,111,98,111,67,111,100,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,82,101,116,114,111,80,97,100,32,76,51,32,66,117,116,116,111,110,0,0,0,0,0,0,75,48,53,50,49,48,57,82,111,109,83,117,98,66,97,110,107,0,0,0,0,0,0,0,109,111,115,121,111,117,103,105,0,0,0,0,0,0,0,0,80,50,32,66,111,111,115,116,0,0,0,0,0,0,0,0,72,121,112,101,114,32,68,117,110,107,32,40,69,117,114,111,41,0,0,0,0,0,0,0,100,101,118,115,116,111,114,115,51,0,0,0,0,0,0,0,80,49,32,70,105,114,101,32,53,0,0,0,0,0,0,0,49,48,48,107,32,79,110,108,121,0,0,0,0,0,0,0,83,116,101,101,114,105,110,103,32,87,104,101,101,108,32,82,97,110,103,101,0,0,0,0,49,48,48,107,44,32,50,48,48,107,44,32,32,52,48,48,107,44,32,32,54,48,48,107,44,32,32,56,48,48,107,0,112,111,114,116,52,95,105,110,0,0,0,0,0,0,0,0,37,117,120,0,0,0,0,0,116,101,116,114,105,115,50,0,109,100,95,104,121,112,101,114,100,110,107,0,0,0,0,0,115,101,114,118,105,99,101,51,0,0,0,0,0,0,0,0,79,110,32,40,52,41,0,0,68,101,109,111,110,115,116,114,97,116,105,111,110,32,83,111,117,110,100,0,0,0,0,0,78,101,119,32,77,117,108,116,105,32,71,97,109,101,32,53,0,0,0,0,0,0,0,0,84,0,0,0,104,0,0,0,117,0,0,0,110,0,0,0,100,0,0,0,101,0,0,0,114,0,0,0,32,0,0,0,67,0,0,0,114,0,0,0,111,0,0,0,115,0,0,0,115,0,0,0,0,0,0,0,181,48,0,0,243,48,0,0,192,48,0,0,252,48,0,0,175,48,0,0,237,48,0,0,185,48,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,121,111,107,107,111,114,105,32,72,121,111,117,116,97,110,32,74,105,109,97,32,45,32,68,97,105,116,111,117,114,121,111,117,32,111,32,77,101,122,97,115,101,33,32,40,74,112,110,41,0,0,0,0,0,0,103,114,121,122,111,114,49,0,110,83,111,117,110,100,108,97,116,99,104,65,99,107,0,0,120,109,101,110,50,112,106,0,115,114,99,0,0,0,0,0,116,104,101,103,108,111,98,112,0,0,0,0,0,0,0,0,86,117,108,99,97,110,32,86,101,110,116,117,114,101,32,40,79,108,100,101,115,116,41,0,0,0,0,0,0,0,0,0,72,79,77,69,0,0,0,0,83,104,111,119,32,73,110,116,101,114,109,105,115,115,105,111,110,115,0,0,0,0,0,0,109,100,95,104,121,111,107,107,111,104,106,0,0,0,0,0,49,57,52,52,32,45,32,116,104,101,32,108,111,111,112,32,109,97,115,116,101,114,32,40,48,48,48,54,50,48,32,85,83,65,41,0,0,0,0,0,100,100,112,50,106,0,0,0,71,88,57,55,53,0,0,0,75,110,105,103,104,116,115,32,111,102,32,116,104,101,32,82,111,117,110,100,32,40,104,97,99,107,32,115,101,116,32,49,41,0,0,0,0,0,0,0,68,114,97,103,111,110,32,69,103,103,33,0,0,0,0,0,83,97,109,117,114,97,105,32,83,104,111,100,111,119,110,32,73,73,73,32,47,32,83,97,109,117,114,97,105,32,83,112,105,114,105,116,115,32,45,32,90,97,110,107,117,114,111,117,32,77,117,115,111,117,107,101,110,32,40,78,71,72,45,48,56,55,41,0,0,0,0,0,111,118,101,114,108,97,121,37,117,95,110,111,114,109,97,108,105,122,101,100,0,0,0,0,84,104,101,32,72,121,98,114,105,100,32,70,114,111,110,116,32,40,74,112,110,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,0,83,104,105,110,111,98,105,32,73,73,73,32,45,32,82,101,116,117,114,110,32,111,102,32,116,104,101,32,78,105,110,106,97,32,77,97,115,116,101,114,32,40,69,117,114,111,41,0,0,0,0,0,0,0,0,0,100,101,115,99,114,105,112,116,105,111,110,0,0,0,0,0,84,101,101,110,97,103,101,32,77,117,116,97,110,116,32,72,101,114,111,32,84,117,114,116,108,101,115,32,40,85,75,32,50,32,80,108,97,121,101,114,115,44,32,115,101,116,32,49,41,0,0,0,0,0,0,0,104,115,102,50,0,0,0,0,66,111,109,98,101,114,32,77,97,110,32,87,111,114,108,100,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,98,97,116,116,114,111,97,100,0,0,0,0,0,0,0,0,109,100,95,104,121,98,114,105,100,102,112,0,0,0,0,0,75,105,99,107,108,101,32,67,117,98,101,108,101,0,0,0,73,110,32,84,104,101,32,72,117,110,116,32,40,87,111,114,108,100,41,0,0,0,0,0,88,32,77,117,108,116,105,112,108,121,32,40,87,111,114,108,100,44,32,77,56,49,41,0,0,0,0,0,0,0,0,0,84,104,101,32,72,121,98,114,105,100,32,70,114,111,110,116,32,40,74,112,110,41,0,0,79,112,101,110,86,71,0,0,109,100,95,104,121,98,114,105,100,102,0,0,0,0,0,0,97,116,108,97,110,116,105,115,98,0,0,0,0,0,0,0,72,117,114,114,105,99,97,110,101,115,32,40,69,117,114,111,41,0,0,0,0,0,0,0,109,100,95,104,117,114,114,105,99,97,110,0,0,0,0,0,82,101,116,114,111,80,97,100,32,82,50,32,66,117,116,116,111,110,0,0,0,0,0,0,80,50,32,87,101,97,112,111,110,0,0,0,0,0,0,0,84,104,101,32,72,117,109,97,110,115,32,40,85,83,65,41,0,0,0,0,0,0,0,0,112,49,32,102,105,114,101,32,52,0,0,0,0,0,0,0,53,48,107,32,79,110,108,121,0,0,0,0,0,0,0,0,84,121,112,101,32,49,0,0,112,49,32,102,105,114,101,32,56,0,0,0,0,0,0,0,112,111,114,116,51,95,105,110,0,0,0,0,0,0,0,0,84,101,116,114,105,115,32,40,115,101,116,32,49,44,32,74,97,112,97,110,44,32,83,121,115,116,101,109,32,49,54,66,44,32,70,68,49,48,57,52,32,51,49,55,45,48,48,57,49,41,0,0,0,0,0,0,109,100,95,104,117,109,97,110,115,0,0,0,0,0,0,0,80,49,32,76,101,102,116,32,85,112,0,0,0,0,0,0,80,51,32,83,101,114,118,105,99,101,0,0,0,0,0,0,79,110,32,40,50,41,0,0,78,117,109,98,101,114,32,111,102,32,80,108,97,121,101,114,115,0,0,0,0,0,0,0,77,117,108,116,105,32,53,0,72,111,111,107,32,40,85,83,65,41,0,0,0,0,0,0,80,49,32,70,0,0,0,0,83,105,103,109,97,32,69,110,116,101,114,112,114,105,115,101,115,32,73,110,99,46,32,40,86,101,110,116,117,114,101,32,76,105,110,101,32,108,105,99,101,110,115,101,41,0,0,0,109,100,95,104,111,111,107,117,0,0,0,0,0,0,0,0,68,105,102,102,105,99,117,108,116,121,32,111,102,32,80,108,101,97,115,105,110,103,32,76,111,108,97,0,0,0,0,0,114,103,117,105,0,0,0,0,66,0,0,0,101,0,0,0,101,0,0,0,32,0,0,0,83,0,0,0,116,0,0,0,111,0,0,0,114,0,0,0,109,0,0,0,32,0,0,0,45,0,0,0,32,0,0,0,68,0,0,0,111,0,0,0,68,0,0,0,111,0,0,0,110,0,0,0,80,0,0,0,97,0,0,0,116,0,0,0,99,0,0,0,104,0,0,0,105,0,0,0,32,0,0,0,73,0,0,0,73,0,0,0,0,0,0,0,18,96,0,0,150,153,0,0,134,152,0,0,2,135,0,0,13,255,0,0,2,135,0,0,180,102,0,0,32,0,0,0,40,0,0,0,86,0,0,0,49,0,0,0,48,0,0,0,48,0,0,0,44,0,0,0,32,0,0,0,75,0,0,0,111,0,0,0,114,0,0,0,101,0,0,0,97,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,107,110,105,103,104,116,115,104,0,0,0,0,0,0,0,0,112,99,101,95,100,114,97,103,110,101,103,103,0,0,0,0,115,97,109,115,104,111,51,104,0,0,0,0,0,0,0,0,72,111,111,107,32,40,69,117,114,111,41,0,0,0,0,0,109,100,95,115,104,105,110,111,98,105,51,0,0,0,0,0,71,105,103,97,32,87,105,110,103,32,40,57,57,48,50,50,51,32,74,97,112,97,110,41,0,0,0,0,0,0,0,0,109,100,95,104,111,111,107,0,50,32,67,111,105,110,115,32,116,111,32,83,116,97,114,116,47,49,32,116,111,32,67,111,110,116,46,0,0,0,0,0,118,111,105,99,101,45,62,118,99,108,107,0,0,0,0,0,72,111,110,111,111,32,110,111,32,84,111,117,107,121,117,117,106,105,32,45,32,68,111,100,103,101,32,68,97,110,112,101,105,32,40,74,112,110,41,0,0,0,0,0,0,0,0,0,69,71,76,32,99,111,110,116,101,120,116,32,115,117,112,112,111,114,116,0,0,0,0,0,67,111,114,101,32,100,111,101,115,32,110,111,116,32,115,117,112,112,111,114,116,32,115,97,118,101,32,115,116,97,116,101,115,46,0,0,0,0,0,0,109,100,95,100,100,97,110,112,101,105,0,0,0,0,0,0,80,104,111,101,110,105,120,32,80,97,114,116,32,50,0,0,77,115,104,117,116,116,108,101,65,89,56,57,49,48,67,83,0,0,0,0,0,0,0,0,72,111,109,101,32,65,108,111,110,101,32,50,32,45,32,76,111,115,116,32,105,110,32,78,101,119,32,89,111,114,107,32,40,85,83,65,41,0,0,0,109,100,95,104,111,109,101,97,50,0,0,0,0,0,0,0,69,118,101,114,121,32,57,48,48,48,48,0,0,0,0,0,82,101,116,114,111,80,97,100,32,76,50,32,66,117,116,116,111,110,0,0,0,0,0,0,109,115,108,117,103,0,0,0,80,50,32,72,105,103,104,32,65,116,116,97,99,107,0,0,72,111,109,101,32,65,108,111,110,101,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,68,114,118,77,105,100,114,101,115,65,110,97,108,111,103,73,110,112,117,116,0,0,0,0,80,49,32,70,105,114,101,32,52,0,0,0,0,0,0,0,49,48,48,107,32,50,48,48,107,0,0,0,0,0,0,0,84,121,112,101,32,48,0,0,80,49,32,70,105,114,101,32,56,0,0,0,0,0,0,0,65,100,100,32,84,105,109,101,0,0,0,0,0,0,0,0,112,111,114,116,50,95,105,110,0,0,0,0,0,0,0,0,109,100,95,104,111,109,101,97,112,0,0,0,0,0,0,0,71,97,109,101,32,84,105,116,108,101,0,0,0,0,0,0,72,105,116,32,116,104,101,32,73,99,101,32,40,85,83,65,41,0,0,0,0,0,0,0,98,86,66,108,97,110,107,0,80,50,32,70,108,105,112,0,80,111,110,112,111,107,111,32,40,86,101,110,116,117,114,101,32,76,105,110,101,41,0,0,83,116,97,114,116,105,110,103,32,76,97,112,115,0,0,0,109,100,95,104,105,116,105,99,101,0,0,0,0,0,0,0,66,101,101,32,83,116,111,114,109,32,45,32,68,111,68,111,110,80,97,99,104,105,32,73,73,32,40,86,49,48,48,44,32,75,111,114,101,97,41,0,0,0,0,0,0,0,0,0,75,110,105,103,104,116,115,32,111,102,32,116,104,101,32,82,111,117,110,100,32,40,98,111,111,116,108,101,103,32,115,101,116,32,52,32,40,119,105,116,104,32,89,77,50,49,53,49,32,43,32,50,120,77,83,77,53,50,48,53,41,44,32,57,49,49,49,50,55,32,101,116,99,41,0,0,0,0,0,0,68,111,119,110,108,111,97,100,32,40,65,108,116,41,0,0,83,0,0,0,97,0,0,0,109,0,0,0,117,0,0,0,114,0,0,0,97,0,0,0,105,0,0,0,32,0,0,0,83,0,0,0,104,0,0,0,111,0,0,0,100,0,0,0,111,0,0,0,119,0,0,0,110,0,0,0,32,0,0,0,73,0,0,0,73,0,0,0,73,0,0,0,0,0,0,0,181,48,0,0,224,48,0,0,233,48,0,0,164,48,0,0,185,48,0,0,212,48,0,0,234,48,0,0,195,48,0,0,196,48,0,0,32,0,0,0,45,0,0,0,32,0,0,0,172,101,0,0,5,125,0,0,206,144,0,0,33,113,0,0,204,83,0,0,99,82,0,0,32,0,0,0,40,0,0,0,78,0,0,0,71,0,0,0,77,0,0,0,45,0,0,0,48,0,0,0,56,0,0,0,55,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,72,101,114,122,111,103,32,90,119,101,105,32,40,74,112,110,41,0,0,0,0,0,0,0,70,73,70,65,32,83,111,99,99,101,114,32,57,53,32,40,75,111,114,41,0,0,0,0,103,105,103,97,119,105,110,103,106,0,0,0,0,0,0,0,109,100,95,104,101,114,122,111,103,106,0,0,0,0,0,0,72,101,108,108,102,105,114,101,32,40,85,83,65,41,0,0,69,71,76,0,0,0,0,0,76,101,102,116,32,68,45,112,97,100,0,0,0,0,0,0,109,100,95,104,101,108,108,102,105,114,101,117,0,0,0,0,112,104,111,101,110,120,112,50,0,0,0,0,0,0,0,0,72,101,108,108,102,105,114,101,32,40,74,112,110,41,0,0,109,100,95,104,101,108,108,102,105,114,101,106,0,0,0,0,82,101,116,114,111,80,97,100,32,82,32,66,117,116,116,111,110,0,0,0,0,0,0,0,78,97,122,99,97,0,0,0,80,50,32,76,111,119,32,65,116,116,97,99,107,0,0,0,72,101,108,108,102,105,114,101,32,40,69,117,114,111,41,0,0,0,0,0,0,0,0,0,68,114,118,83,108,121,115,112,121,80,114,111,116,86,97,108,117,101,0,0,0,0,0,0,53,48,107,32,49,53,48,107,0,0,0,0,0,0,0,0,49,32,67,111,105,110,115,32,50,32,67,114,101,100,105,116,115,0,0,0,0,0,0,0,112,111,114,116,49,95,105,110,0,0,0,0,0,0,0,0,116,101,116,114,105,115,49,0,109,100,95,104,101,108,108,102,105,114,101,0,0,0,0,0,73,68,32,78,111,0,0,0,68,114,118,79,107,105,66,97,110,107,0,0,0,0,0,0,72,101,105,32,84,97,111,32,50,32,45,32,83,117,112,101,114,32,66,105,103,32,50,32,40,67,104,105,41,0,0,0,112,111,110,112,111,107,111,118,0,0,0,0,0,0,0,0,77,111,111,110,32,65,108,105,101,110,0,0,0,0,0,0,50,110,100,32,66,111,110,117,115,32,71,105,118,101,110,0,109,100,95,104,101,105,116,97,111,0,0,0,0,0,0,0,100,100,112,50,49,48,48,107,0,0,0,0,0,0,0,0,107,110,105,103,104,116,115,98,52,0,0,0,0,0,0,0,112,99,101,95,100,111,119,110,108,111,97,100,49,0,0,0,83,97,109,117,114,97,105,32,83,104,111,100,111,119,110,32,73,73,73,32,47,32,83,97,109,117,114,97,105,32,83,112,105,114,105,116,115,32,45,32,90,97,110,107,117,114,111,117,32,77,117,115,111,117,107,101,110,32,40,78,71,77,45,48,56,55,41,0,0,0,0,0,84,111,104,111,0,0,0,0,99,104,45,62,98,108,111,99,107,95,102,110,117,109,0,0,109,100,95,102,105,102,97,57,53,0,0,0,0,0,0,0,71,105,103,97,32,87,105,110])
.concat([103,32,40,57,57,48,50,50,50,32,72,105,115,112,97,110,105,99,41,0,0,0,0,0,72,101,97,118,121,32,85,110,105,116,32,45,32,77,101,103,97,32,68,114,105,118,101,32,83,112,101,99,105,97,108,32,40,74,112,110,41,0,0,0,109,117,116,97,110,116,102,0,110,117,109,108,111,99,107,0,110,77,83,77,54,50,57,53,83,116,97,116,117,115,91,110,67,104,105,112,93,0,0,0,109,100,95,104,118,121,117,110,105,116,0,0,0,0,0,0,75,77,83,47,69,71,76,32,99,111,110,116,101,120,116,32,115,117,112,112,111,114,116,0,72,101,97,118,121,32,78,111,118,97,32,40,85,83,65,41,0,0,0,0,0,0,0,0,76,101,105,115,117,114,101,32,97,110,100,32,65,108,108,105,101,100,0,0,0,0,0,0,109,100,95,104,101,97,118,121,110,111,118,0,0,0,0,0,72,105,103,104,32,83,101,97,115,32,72,97,118,111,99,32,40,85,83,65,41,0,0,0,69,118,101,114,121,32,52,48,48,48,48,0,0,0,0,0,109,100,95,104,97,118,111,99,117,0,0,0,0,0,0,0,82,101,116,114,111,80,97,100,32,76,32,66,117,116,116,111,110,0,0,0,0,0,0,0,80,49,32,66,111,111,115,116,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,71,69,84,95,79,86,69,82,83,67,65,78,58,32,37,117,10,0,0,0,0,68,114,118,84,105,108,101,82,97,109,66,97,110,107,0,0,51,48,107,32,111,110,108,121,0,0,0,0,0,0,0,0,80,49,32,70,105,114,101,32,55,0,0,0,0,0,0,0,83,108,97,118,101,0,0,0,100,100,114,52,0,0,0,0,83,117,112,101,114,32,76,101,97,103,117,101,32,40,70,68,49,48,57,52,32,51,49,55,45,48,48,52,53,41,0,0,72,97,117,110,116,105,110,103,32,83,116,97,114,114,105,110,103,32,80,111,108,116,101,114,103,117,121,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,0,0,0,103,102,120,95,98,97,110,107,0,0,0,0,0,0,0,0,109,100,95,104,97,117,110,116,105,110,103,0,0,0,0,0,67,114,101,100,105,116,115,32,102,111,114,32,50,32,80,108,97,121,101,114,0,0,0,0,80,50,32,68,101,97,108,0,83,105,103,109,97,32,69,110,116,101,114,112,114,105,115,101,115,32,73,110,99,46,0,0,49,48,48,48,48,48,32,51,48,48,48,48,48,0,0,0,72,97,114,100,66,97,108,108,33,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,66,0,0,0,101,0,0,0,101,0,0,0,32,0,0,0,83,0,0,0,116,0,0,0,111,0,0,0,114,0,0,0,109,0,0,0,32,0,0,0,45,0,0,0,32,0,0,0,68,0,0,0,111,0,0,0,68,0,0,0,111,0,0,0,110,0,0,0,80,0,0,0,97,0,0,0,116,0,0,0,99,0,0,0,104,0,0,0,105,0,0,0,32,0,0,0,73,0,0,0,73,0,0,0,0,0,0,0,18,96,0,0,150,153,0,0,134,152,0,0,2,135,0,0,13,255,0,0,2,135,0,0,180,102,0,0,32,0,0,0,40,0,0,0,86,0,0,0,49,0,0,0,48,0,0,0,49,0,0,0,44,0,0,0,32,0,0,0,75,0,0,0,111,0,0,0,114,0,0,0,101,0,0,0,97,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,75,110,105,103,104,116,115,32,111,102,32,116,104,101,32,82,111,117,110,100,32,40,98,111,111,116,108,101,103,32,115,101,116,32,51,44,32,57,49,49,49,50,55,32,74,97,112,97,110,41,0,0,0,0,0,0,68,111,119,110,108,111,97,100,0,0,0,0,0,0,0,0,99,104,105,112,45,62,101,103,95,99,110,116,0,0,0,0,109,100,95,104,97,114,100,98,97,108,108,0,0,0,0,0,109,100,95,102,105,102,97,57,53,107,0,0,0,0,0,0,103,105,103,97,119,105,110,103,104,0,0,0,0,0,0,0,99,97,112,115,108,111,99,107,0,0,0,0,0,0,0,0,72,97,114,100,66,97,108,108,32,73,73,73,32,40,85,83,65,41,0,0,0,0,0,0,109,100,95,104,97,114,100,98,97,108,51,0,0,0,0,0,75,77,83,0,0,0,0,0,67,104,101,108,110,111,118,32,45,32,65,116,111,109,105,99,32,82,117,110,110,101,114,32,40,85,83,41,0,0,0,0,66,32,40,98,111,116,116,111,109,41,0,0,0,0,0,0,72,97,114,100,66,97,108,108,32,39,57,53,32,40,85,83,65,41,0,0,0,0,0,0,71,104,111,115,116,32,77,117,110,99,104,101,114,0,0,0,109,100,95,104,97,114,100,98,108,57,53,0,0,0,0,0,72,97,114,100,66,97,108,108,32,39,57,52,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,0,0,70,114,101,101,122,101,32,77,111,100,101,0,0,0,0,0,67,111,98,114,97,45,67,111,109,109,97,110,100,32,40,74,97,112,97,110,41,0,0,0,82,101,116,114,111,80,97,100,32,88,32,66,117,116,116,111,110,0,0,0,0,0,0,0,116,117,114,102,109,97,115,116,0,0,0,0,0,0,0,0,80,49,32,87,101,97,112,111,110,0,0,0,0,0,0,0,109,100,95,104,97,114,100,98,108,57,52,0,0,0,0,0,68,114,118,80,114,105,111,114,105,116,121,0,0,0,0,0,51,48,107,32,49,48,48,107,0,0,0,0,0,0,0,0,112,49,32,102,105,114,101,32,54,0,0,0,0,0,0,0,77,97,115,116,101,114,0,0,100,100,114,51,0,0,0,0,115,117,112,114,108,101,97,103,0,0,0,0,0,0,0,0,72,97,114,100,32,68,114,105,118,105,110,39,32,40,87,111,114,108,100,41,0,0,0,0,110,83,111,117,110,100,66,117,102,102,101,114,80,111,115,0,112,114,105,111,114,105,116,121,95,114,101,103,0,0,0,0,109,100,95,104,97,114,100,100,114,105,118,0,0,0,0,0,83,112,114,105,116,101,32,116,97,98,108,101,115,0,0,0,80,50,32,69,0,0,0,0,80,111,110,112,111,107,111,0,0,0,0,0,0,0,0,0,50,53,48,48,48,32,49,48,48,48,48,48,0,0,0,0,87,105,110,103,115,32,111,102,32,87,111,114,32,40,85,83,65,41,0,0,0,0,0,0,66,101,101,32,83,116,111,114,109,32,45,32,68,111,68,111,110,80,97,99,104,105,32,73,73,32,40,86,49,48,49,44,32,75,111,114,101,97,41,0,0,0,0,0,0,0,0,0,107,110,105,103,104,116,115,98,51,0,0,0,0,0,0,0,112,99,101,95,100,111,119,110,108,111,97,100,0,0,0,0,84,104,101,32,75,105,110,103,32,111,102,32,70,105,103,104,116,101,114,115,32,39,57,53,32,40,78,71,72,45,48,56,52,41,0,0,0,0,0,0,109,100,95,119,105,110,103,115,119,111,114,0,0,0,0,0,75,105,100,32,67,104,97,109,101,108,101,111,110,32,40,69,117,114,111,44,32,75,111,114,101,97,44,32,85,83,65,41,0,0,0,0,0,0,0,0,71,105,103,97,32,87,105,110,103,32,40,57,57,48,50,50,50,32,66,114,97,122,105,108,41,0,0,0,0,0,0,0,97,108,112,104,97,109,50,0,71,121,110,111,117,103,32,40,74,112,110,41,0,0,0,0,104,97,114,100,119,97,114,101,58,32,37,100,10,0,0,0,110,89,77,90,50,56,48,66,82,101,103,105,115,116,101,114,0,0,0,0,0,0,0,0,99,117,114,114,95,99,121,99,108,101,115,0,0,0,0,0,109,100,95,103,121,110,111,117,103,106,0,0,0,0,0,0,79,112,101,110,71,76,32,100,114,105,118,101,114,0,0,0,82,45,62,112,111,114,116,50,95,100,97,116,97,0,0,0,83,101,97,116,111,110,103,114,111,118,101,32,76,116,100,32,40,77,97,103,105,99,32,69,108,101,116,114,111,110,105,99,115,32,85,83,65,32,108,105,99,101,110,99,101,41,0,0,79,102,102,0,0,0,0,0,65,114,109,101,100,32,80,111,108,105,99,101,32,66,97,116,114,105,100,101,114,32,45,32,65,32,86,101,114,115,105,111,110,32,40,84,97,105,119,97,110,41,32,40,77,111,110,32,68,101,99,32,50,50,32,49,57,57,55,41,0,0,0,0,70,105,120,69,105,103,104,116,32,40,84,97,105,119,97,110,41,0,0,0,0,0,0,0,71,121,110,111,117,103,32,40,69,117,114,111,41,0,0,0,75,48,53,49,54,52,57,32,70,114,101,113,117,101,110,99,121,32,82,101,103,115,0,0,84,111,97,112,108,97,110,32,47,32,84,97,105,116,111,32,65,109,101,114,105,99,97,32,67,111,114,112,111,114,97,116,105,111,110,32,40,75,105,116,107,111,114,112,32,108,105,99,101,110,115,101,41,0,0,0,52,32,67,111,105,110,115,32,49,32,67,114,101,100,105,116,115,0,0,0,0,0,0,0,103,104,111,115,116,109,117,110,0,0,0,0,0,0,0,0,109,100,95,103,121,110,111,117,103,0,0,0,0,0,0,0,49,57,52,53,32,80,97,114,116,32,50,32,40,66,97,116,116,108,101,32,71,97,114,97,103,97,32,104,97,99,107,41,0,0,0,0,0,0,0,0,83,97,109,101,33,32,83,97,109,101,33,32,83,97,109,101,33,0,0,0,0,0,0,0,71,117,110,115,116,97,114,32,72,101,114,111,101,115,32,40,85,83,65,41,0,0,0,0,82,101,116,114,111,80,97,100,32,65,32,66,117,116,116,111,110,0,0,0,0,0,0,0,80,49,32,72,105,103,104,32,65,116,116,97,99,107,0,0,109,100,95,103,117,110,115,116,97,114,117,0,0,0,0,0,102,114,111,109,95,109,97,105,110,0,0,0,0,0,0,0,68,97,116,97,32,69,97,115,116,32,67,111,114,112,111,114,97,116,105,111,110,32,40,108,105,99,101,110,115,101,100,32,102,114,111,109,32,70,105,114,115,116,32,83,116,97,114,41,0,0,0,0,0,0,0,0,53,48,107,32,49,48,48,107,32,50,48,48,107,32,50,48,48,107,43,0,0,0,0,0,67,101,110,116,114,101,0,0,100,101,97,100,99,111,110,120,106,0,0,0,0,0,0,0,80,49,32,70,105,114,101,32,54,0,0,0,0,0,0,0,83,116,97,110,100,32,97,108,111,110,101,0,0,0,0,0,100,100,114,50,0,0,0,0,104,97,114,100,119,97,114,101,0,0,0,0,0,0,0,0,83,111,110,105,99,32,66,111,111,109,32,40,70,68,49,48,57,52,32,51,49,55,45,48,48,53,51,41,0,0,0,0,48,49,48,48,48,48,48,48,48,48,0,0,0,0,0,0,71,117,110,115,116,97,114,32,72,101,114,111,101,115,32,40,74,112,110,44,32,83,97,109,112,108,101,41,0,0,0,0,83,104,111,111,116,0,0,0,105,110,112,117,116,95,100,97,116,97,0,0,0,0,0,0,65,114,107,97,110,111,105,100,32,45,32,82,101,118,101,110,103,101,32,111,102,32,68,79,72,32,40,85,83,41,0,0,97,114,107,97,110,111,105,100,106,98,0,0,0,0,0,0,109,100,95,103,117,110,115,116,97,114,106,115,0,0,0,0,84,105,108,101,109,97,112,32,97,116,116,114,105,98,117,116,101,115,0,0,0,0,0,0,82,97,115,116,97,110,32,83,97,103,97,32,50,32,40,74,97,112,97,110,41,0,0,0,80,50,32,68,0,0,0,0,86,68,67,32,83,112,114,105,116,101,32,82,65,77,0,0,112,111,110,112,111,107,111,0,215,14,0,0,0,0,0,0,66,97,116,116,108,101,32,83,104,97,114,107,32,40,74,97,112,97,110,44,32,74,111,121,115,116,105,99,107,41,0,0,99,111,105,110,95,108,111,99,107,111,117,116,0,0,0,0,71,117,110,115,116,97,114,32,72,101,114,111,101,115,32,40,74,112,110,41,0,0,0,0,112,97,108,100,109,97,95,102,97,100,101,0,0,0,0,0,79,112,101,114,97,116,105,111,110,32,87,111,108,102,32,40,87,111,114,108,100,44,32,115,101,116,32,50,41,0,0,0,67,97,100,97,115,104,32,40,71,101,114,109,97,110,121,41,0,0,0,0,0,0,0,0,100,100,112,50,49,48,49,107,0,0,0,0,0,0,0,0,75,110,105,103,104,116,115,32,111,102,32,116,104,101,32,82,111,117,110,100,32,40,98,111,111,116,108,101,103,32,115,101,116,32,50,44,32,57,49,49,49,50,55,32,101,116,99,41,0,0,0,0,0,0,0,0,78,67,83,0,0,0,0,0,107,111,102,57,53,104,0,0,109,100,95,103,117,110,115,116,97,114,106,0,0,0,0,0,84,104,101,32,78,105,110,106,97,32,87,97,114,114,105,111,114,115,32,40,85,83,41,0,0,0,0,0,0,0,0,0,109,100,95,107,105,100,99,104,97,109,0,0,0,0,0,0,103,105,103,97,119,105,110,103,98,0,0,0,0,0,0,0,83,117,112,101,114,32,72,97,110,103,45,79,110,32,40,115,105,116,100,111,119,110,47,117,112,114,105,103,104,116,44,32,117,110,112,114,111,116,101,99,116,101,100,41,0,0,0,0,107,101,121,112,97,100,57,0,71,117,110,115,116,97,114,32,72,101,114,111,101,115,32,40,69,117,114,111,41,0,0,0,97,108,116,98,101,97,115,116,106,0,0,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,73,32,50,110,100,32,73,109,112,97,99,116,58,32,71,105,97,110,116,32,65,116,116,97,99,107,32,40,65,115,105,97,32,57,55,48,57,51,48,44,32,78,79,32,67,68,41,0,0,0,0,0,0,0,0,66,111,111,116,108,101,103,66,103,80,97,103,101,0,0,0,109,100,95,103,117,110,115,116,97,114,0,0,0,0,0,0,79,112,101,110,71,76,0,0,84,104,101,32,84,111,103,121,117,32,40,51,49,53,45,53,48,54,53,44,32,74,97,112,97,110,41,0,0,0,0,0,99,108,116,99,104,105,116,114,106,0,0,0,0,0,0,0,112,100,114,105,102,116,97,0,71,117,110,115,104,105,112,32,40,69,117,114,111,41,0,0,103,112,114,105,100,101,114,117,0,0,0,0,0,0,0,0,49,32,67,111,105,110,32,54,32,67,114,101,100,105,116,115,32,0,0,0,0,0,0,0,80,97,99,45,77,97,110,32,40,71,97,108,97,120,105,97,110,32,104,97,114,100,119,97,114,101,44,32,115,101,116,32,50,41,0,0,0,0,0,0,51,32,67,111,105,110,115,32,52,32,67,114,101,100,105,116,115,0,0,0,0,0,0,0,86,100,112,87,105,110,100,111,119,68,111,119,110,0,0,0,97,108,105,101,110,115,121,110,50,0,0,0,0,0,0,0,109,100,95,103,117,110,115,104,105,112,0,0,0,0,0,0,72,97,110,103,45,79,110,32,40,114,105,100,101,45,111,110,41,0,0,0,0,0,0,0,51,32,67,111,105,110,115,32,50,32,67,114,101,100,105,116,115,32,0,0,0,0,0,0,77,117,108,116,105,32,67,104,97,109,112,32,68,101,108,117,120,101,32,40,118,101,114,46,32,48,49,48,54,44,32,48,54,47,48,49,47,50,48,48,48,41,0,0,0,0,0,0,100,98,108,112,111,105,110,116,100,0,0,0,0,0,0,0,82,117,110,97,114,107,32,40,74,112,110,44,32,75,111,114,41,0,0,0,0,0,0,0,118,105,100,101,111,95,119,105,110,100,111,119,101,100,95,102,117,108,108,115,99,114,101,101,110,0,0,0,0,0,0,0,112,99,108,117,98,121,115,97,0,0,0,0,0,0,0,0,80,49,32,76,111,119,32,65,116,116,97,99,107,0,0,0,109,100,95,114,117,110,97,114,107,0,0,0,0,0,0,0,106,140,0,0,64,136,0,0,250,91,0,0,22,89,0,0,29,79,0,0,32,0,0,0,71,0,0,0,111,0,0,0,103,0,0,0,101,0,0,0,116,0,0,0,115,0,0,0,117,0,0,0,106,0,0,0,105,0,0,0,32,0,0,0,0,103,0,0,55,95,0,0,29,79,0,0,172,138,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,44,0,0,0,32,0,0,0,118,0,0,0,101,0,0,0,114,0,0,0,46,0,0,0,32,0,0,0,57,0,0,0,53,0,0,0,47,0,0,0,48,0,0,0,54,0,0,0,47,0,0,0,50,0,0,0,48,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,110,83,111,117,110,100,108,97,116,99,104,0,0,0,0,0,51,48,107,32,49,48,48,107,32,50,48,48,107,32,49,48,48,107,43,0,0,0,0,0,67,111,109,109,117,110,105,99,97,116,105,111,110,32,77,111,100,101,0,0,0,0,0,0,66,108,111,111,100,32,77,111,100,101,0,0,0,0,0,0,100,100,114,49,0,0,0,0,115,111,110,105,99,98,111,109,0,0,0,0,0,0,0,0,71,114,111,119,108,32,40,85,83,65,41,0,0,0,0,0,67,105,116,121,0,0,0,0,112,114,111,116,95,118,97,108,0,0,0,0,0,0,0,0,97,105,114,97,116,116,99,107,0,0,0,0,0,0,0,0,114,97,105,100,101,110,98,0,75,111,115,111,100,97,116,101,32,81,117,105,122,32,77,121,32,65,110,103,101,108,32,50,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,109,100,95,103,114,111,119,108,0,0,0,0,0,0,0,0,37,115,32,61,32,34,37,115,34,32,37,115,10,0,0,0,84,105,108,101,109,97,112,32,49,0,0,0,0,0,0,0,80,50,32,67,0,0,0,0,98,111,109,98,107,105,99,107,97,0,0,0,0,0,0,0,84,101,99,104,115,116,97,114,32,40,83,117,110,110,32,108,105,99,101,110,115,101,41,0,86,45,70,105,118,101,32,40,74,112,110,41,0,0,0,0,205,95,0,0,5,128,0,0,32,0,0,0,141,159,0,0,99,82,0,0,29,79,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,44,0,0,0,32,0,0,0,115,0,0,0,101,0,0,0,116,0,0,0,32,0,0,0,50,0,0,0,41,0,0,0,0,0,0,0,78,0,0,0,105,0,0,0,110,0,0,0,106,0,0,0,97,0,0,0,32,0,0,0,82,0,0,0,121,0,0,0,117,0,0,0,107,0,0,0,101,0,0,0,110,0,0,0,100,0,0,0,101,0,0,0,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,0,0,0,101,0,0,0,101,0,0,0,32,0,0,0,83,0,0,0,116,0,0,0,111,0,0,0,114,0,0,0,109,0,0,0,32,0,0,0,45,0,0,0,32,0,0,0,68,0,0,0,111,0,0,0,68,0,0,0,111,0,0,0,110,0,0,0,80,0,0,0,97,0,0,0,116,0,0,0,99,0,0,0,104,0,0,0,105,0,0,0,32,0,0,0,73,0,0,0,73,0,0,0,0,0,0,0,18,96,0,0,150,153,0,0,134,152,0,0,2,135,0,0,13,255,0,0,2,135,0,0,180,102,0,0,32,0,0,0,40,0,0,0,86,0,0,0,49,0,0,0,48,0,0,0,50,0,0,0,44,0,0,0,32,0,0,0,75,0,0,0,111,0,0,0,114,0,0,0,101,0,0,0,97,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,110,101,119,102,97,110,116,97,0,0,0,0,0,0,0,0,107,110,105,103,104,116,115,98,50,0,0,0,0,0,0,0,68,111,117,98,108,101,32,68,117,110,103,101,111,110,115,32,45,32,87,0,0,0,0,0,84,104,101,32,75,105,110,103,32,111,102,32,70,105,103,104,116,101,114,115,32,39,57,53,32,40,78,71,77,45,48,56,52,41,0,0,0,0,0,0,109,100,95,118,102,105,118,101,0,0,0,0,0,0,0,0,83,113,117,97,115,104,32,40,86,101,114,46,32,49,46,48,41,0,0,0,0,0,0,0,49,48,48,75,32,53,48,48,75,0,0,0,0,0,0,0,54,56,75,32,82,79,77,0,80,114,101,116,116,121,32,83,111,108,100,105,101,114,32,83,97,105,108,111,114,32,77,111,111,110,32,40,118,101,114,46,32,57,53,47,48,51,47,50,50,66,44,32,84,97,105,119,97,110,41,0,0,0,0,0,84,105,116,108,101,32,76,111,103,111,32,84,121,112,101,0,66,117,103,115,32,66,117,110,110,121,32,105,110,32,68,111,117,98,108,101,32,84,114,111,117,98,108,101,32,40,69,117,114,111,41,0,0,0,0,0,71,105,103,97,32,87,105,110,103,32,40,57,57,48,50,50,50,32,65,115,105,97,41,0,0,0,0,0,0,0,0,0,68,101,99,111,49,54,105,99,32,82,111,119,115,99,114,111,108,108,32,37,100,0,0,0,67,114,101,100,105,116,115,32,84,111,32,83,116,97,114,116,0,0,0,0,0,0,0,0,107,101,121,112,97,100,56,0,71,114,105,110,100,32,83,116,111,114,109,101,114,32,40,85,83,65,41,0,0,0,0,0,83,112,105,110,97,108,32,66,114,101,97,107,101,114,115,32,40,87,111,114,108,100,41,0,0,0,0,0,0,0,0,0,99,116,114,105,98,101,106,0,109,100,95,103,114,105,110,100,115,116,0,0,0,0,0,0,84,104,114,101,97,100,105,110,103,32,115,117,112,112,111,114,116,0,0,0,0,0,0,0,68,114,97,103,111,110,32,85,110,105,116,32,47,32,67,97,115,116,108,101,32,111,102,32,68,114,97,103,111,110,0,0,71,114,101,101,110,100,111,103,32,45,32,84,104,101,32,66,101,97,99,104,101,100,32,83,117,114,102,101,114,32,68,117,100,101,33,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,0,0,0,50,32,67,111,105,110,45,49,32,80,108,97,121,0,0,0,112,97,99,109,97,110,98,108,97,0,0,0,0,0,0,0,83,101,109,105,67,111,109,32,47,32,69,120,105,116,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,105,110,105,116,32,112,105,120,101,108,32,99,111,110,118,101,114,116,101,114,46,10,0,0,0,77,0,0,0,101,0,0,0,116,0,0,0,97,0,0,0,108,0,0,0,32,0,0,0,83,0,0,0,97,0,0,0,118,0,0,0,101,0,0,0,114,0,0,0,0,0,0,0,84,186,0,0,200,208,0,0,56,193,0,0,116,199,0,0,132,188,0,0,0,0,0,0,0,0,0,0,0,0,0,0,109,100,95,103,114,101,101,110,100,111,103,0,0,0,0,0,71,117,110,98,105,114,100,32,40,75,111,114,101,97,41,0,0,0,0,0,0,0,0,0,80,83,53,0,0,0,0,0,77,97,104,106,111,110,103,32,72,111,116,32,71,105,109,109,105,99,107,32,73,110,116,101,103,114,97,108,32,40,74,97,112,97,110,41,0,0,0,0,68,114,118,79,107,105,66,97,110,107,49,95,49,0,0,0,71,114,101,97,116,101,115,116,32,72,101,97,118,121,119,101,105,103,104,116,115,32,40,85,83,65,41,0,0,0,0,0,115,116,114,97,116,118,111,120,0,0,0,0,0,0,0,0,67,104,111,117,106,105,32,77,101,105,107,121,117,117,32,76,101,103,105,111,110,32,40,118,101,114,32,50,46,48,51,41,0,0,0,0,0,0,0,0,83,116,97,114,116,32,50,0,109,100,95,103,104,119,117,0,76,101,112,114,101,99,104,97,117,110,0,0,0,0,0,0,49,48,48,107,32,51,48,48,107,32,53,48,48,107,0,0,83,105,110,103,108,101,32,67,111,109,112,97,110,121,0,0,68,101,102,97,117,108,116,32,43,32,49,58,48,48,0,0,68,114,118,83,111,117,110,100,76,97,116,99,104,0,0,0,80,114,101,104,105,115,108,101,68,105,112,0,0,0,0,0,80,104,105,108,107,111,0,0,71,114,101,97,116,101,115,116,32,72,101,97,118,121,119,101,105,103,104,116,115,32,40,74,112,110,41,0,0,0,0,0,68,101,108,117,120,101,0,0,80,117,99,107,32,77,97,110,32,40,74,97,112,97,110,32,115,101,116,32,50,41,0,0,66,0,0,0,0,0,0,0,109,100,95,103,104,119,106,0,71,97,117,110,116,108,101,116,32,40,71,101,114,109,97,110,44,32,114,101,118,32,56,41,0,0,0,0,0,0,0,0,118,111,108,117,109,101,0,0,48,53,58,48,48,0,0,0,57,48,0,0,0,0,0,0,84,105,108,101,109,97,112,32,48,0,0,0,0,0,0,0,102,103,95,101,110,97,98,108,101,0,0,0,0,0,0,0,80,50,32,66,0,0,0,0,76,105,122,97,114,100,32,87,105,122,97,114,100,0,0,0,48,45,52,0,0,0,0,0,77,114,46,32,68,111,33,32,40,112,114,111,116,111,116,121,112,101,41,0,0,0,0,0,101,120,101,0,0,0,0,0,68,111,114,111,100,111,110,32,40,115,101,116,32,49,41,0,0,0,0,0,0,0,0,0,84,104,101,32,71,114,101,97,116,32,87,97,108,100,111,32,83,101,97,114,99,104,32,40,85,83,65,41,0,0,0,0,100,107,111,110,103,106,111,0,51,48,107,32,49,48,48,107,32,49,53,48,107,43,0,0,66,101,101,32,83,116,111,114,109,32,45,32,68,111,68,111,110,80,97,99,104,105,32,73,73,32,40,86,49,48,50,44,32,75,111,114,101,97,41,0,0,0,0,0,0,0,0,0,75,110,105,103,104,116,115,32,111,102,32,116,104,101,32,82,111,117,110,100,32,40,98,111,111,116,108,101,103,32,115,101,116,32,49,32,40,119,105,116,104,32,89,77,50,49,53,49,32,43,32,50,120,77,83,77,53,50,48,53,41,44,32,57,49,49,49,50,55,32,101,116,99,41,0,0,0,0,0,0,104,111,114,101,107,105,100,0,112,99,101,95,100,100,117,110,103,119,0,0,0,0,0,0,74,117,74,117,32,68,101,110,115,101,116,115,117,32,40,74,97,112,97,110,44,32,98,111,111,116,108,101,103,41,0,0,101,120,101,100,101,120,101,115,95,110,98,103,95,121,115,99,114,111,108,108,0,0,0,0,109,100,95,119,97,108,100,111,0,0,0,0,0,0,0,0,82,111,97,100,32,82,65,77,32,40,67,80,85,32,35,49,41,0,0,0,0,0,0,0,109,100,95,98,117,103,115,98,117,110,0,0,0,0,0,0,56,48,75,47,49,54,48,75,47,51,50,48,75,47,54,52,48,75,0,0,0,0,0,0,103,105,103,97,119,105,110,103,97,0,0,0,0,0,0,0,107,101,121,112,97,100,55,0,97,116,101,116,114,105,115,99,50,0,0,0,0,0,0,0,84,104,101,32,71,114,101,97,116,32,67,105,114,99,117,115,32,77,121,115,116,101,114,121,32,83,116,97,114,114,105,110,103,32,77,105,99,107,101,121,32,38,32,77,105,110,110,105,101,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,90,122,121,122,122,121,120,120,32,40,115,101,116,32,50,41,0,0,0,0,0,0,0,0,116,104,101,103,108,111,98,51,0,0,0,0,0,0,0,0,115,116,114,101,101,116,115,109,49,0,0,0,0,0,0,0,83,112,97,99,101,32,73,110,118,97,115,105,111,110,32,40,69,117,114,111,112,101,41,0,0,0,0,0,0,0,0,0,49,57,52,51,58,32,84,104,101,32,66,97,116,116,108,101,32,111,102,32,77,105,100,119,97,121,32,40,98,111,111,116,108,101,103,32,115,101,116,32,50,44,32,104,97,99,107,32,111,102,32,74,97,112,97,110,32,115,101,116,41,0,0,0,84,104,114,101,97,100,115,0,70,108,97,115,104,103,97,108,32,40,115,101,116,32,49,41,0,0,0,0,0,0,0,0,77,97,100,32,71,101,97,114,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,71,114,101,97,116,32,67,105,114,99,117,115,32,77,121,115,116,101,114,121,32,45,32,77,105,99,107,101,121,32,116,111,32,77,105,110,110,105,101,32,77,97,103,105,99,97,108,32,65,100,118,101,110,116,117,114,101,32,50,32,40,74,112,110,41,0,0,0,0,0,0,0,118,101,99,116,111,114,0,0,80,97,99,45,77,97,110,32,40,71,97,108,97,120,105,97,110,32,104,97,114,100,119,97,114,101,44,32,115,101,116,32,49,41,0,0,0,0,0,0,87,99,57,48,98,49,83,99,114,111,108,108,49,88,0,0,103,110,103,116,0,0,0,0,109,100,95,109,105,99,107,101,121,99,109,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,32,110,111,116,32,114,101,97,100,32,82,79,77,32,102,105,108,101,46,10,0,0,87,99,57,48,83,99,114,111,108,108,48,89,72,105,0,0,52,67,95,51,67,0,0,0,115,105,108,107,119,111,114,109,106,0,0,0,0,0,0,0,109,100,95,103,114,101,97,116,99,105,114,106,0,0,0,0,68,111,117,98,108,101,32,68,114,97,103,111,110,32,40,85,83,32,115,101,116,32,51,41,0,0,0,0,0,0,0,0,77,67,54,56,52,48,95,99,116,114,0,0,0,0,0,0,107,111,118,108,115,106,98,0,109,95,100,114,103,119,50,95,112,114,111,116,95,104,105,108,111,0,0,0,0,0,0,0,82,105,103,104,116,0,0,0,74,101,110,110,105,102,101,114,32,67,97,112,114,105,97,116,105,32,84,101,110,110,105,115,32,40,85,83,65,41,0,0,105,56,55,53,49,82,101,116,86,97,108,0,0,0,0,0,79,114,105,101,110,116,97,108,32,76,101,103,101,110,100,32,45,32,88,105,32,89,111,32,71,105,32,83,104,105,32,82,101,32,90,117,97,110,103,32,40,86,49,49,50,32,97,108,116,44,32,67,104,105,110,97,41,0,0,0,0,0,0,0,49,48,48,107,32,51,48,48,107,32,52,52,48,107,0,0,68,111,117,98,108,101,32,67,111,109,112,97,110,121,0,0,68,101,102,97,117,108,116,0,68,114,118,83,111,117,110,100,78,109,105,80,101,110,100,105,110,103,0,0,0,0,0,0,83,110,97,112,112,101,114,32,40,75,111,114,101,97,41,0,0,0,0,0,0,0,0,0,109,100,95,106,101,110,110,105,102,99,116,0,0,0,0,0,83,117,112,101,114,32,68,101,108,117,120,101,0,0,0,0,90,56,48,32,82,65,77,0,80,50,32,65,0,0,0,0,108,105,122,119,105,122,0,0,109,100,95,102,50,50,97,0,67,114,101,100,105,116,115,32,111,110,32,82,101,115,101,116,0,0,0,0,0,0,0,0,71,114,97,110,100,83,108,97,109,32,45,32,84,104,101,32,84,101,110,110,105,115,32,84,111,117,114,110,97,109,101,110,116,32,39,57,50,32,40,74,112,110,41,0,0,0,0,0,100,100,112,50,107,0,0,0,107,110,105,103,104,116,115,98,0,0,0,0,0,0,0,0,68,111,114,97,101,109,111,110,32,45,32,78,111,98,105,116,97,32,110,111,32,68,111,114,97,98,105,97,110,32,78,105,103,104,116,0,0,0,0,0,83,0,0,0,117,0,0,0,112,0,0,0,101,0,0,0,114,0,0,0,32,0,0,0,83,0,0,0,105,0,0,0,100,0,0,0,101,0,0,0,107,0,0,0,105,0,0,0,99,0,0,0,107,0,0,0,115,0,0,0,32,0,0,0,51,0,0,0,32,0,0,0,45,0,0,0,32,0,0,0,84,0,0,0,104,0,0,0,101,0,0,0,32,0,0,0,78,0,0,0,101,0,0,0,120,0,0,0,116,0,0,0,32,0,0,0,71,0,0,0,108,0,0,0,111,0,0,0,114,0,0,0,121,0,0,0,0,0,0,0,151,95,0,0,185,112,0,0,139,115,0,0,19,255,0,0,32,0,0,0,45,0,0,0,32,0,0,0,4,104,0,0,73,81,0,0,120,48,0,0,110,48,0,0,17,99,0,0,38,98,0,0,0,0,0,0,0,0,0,0,51,119,111,110,100,101,114,115,117,0,0,0,0,0,0,0,109,100,95,103,114,97,110,100,115,108,106,0,0,0,0,0,71,114,97,112,104,105,99,115,32,82,65,77,0,0,0,0,90,97,110,121,32,71,111,108,102,32,40,69,117,114,111,44,32,85,83,65,44,32,118,49,46,49,41,0,0,0,0,0,71,105,103,97,32,87,105,110,103,32,40,57,57,48,50,50,50,32,85,83,65,41,0,0,107,101,121,112,97,100,54,0,71,114,97,110,100,83,108,97,109,32,45,32,84,104,101,32,84,101,110,110,105,115,32,84,111,117,114,110,97,109,101,110,116,32,40,69,117,114,111,41,0,0,0,0,0,0,0,0,109,100,95,103,114,97,110,100,115,108,0,0,0,0,0,0,83,68,76,32,100,114,105,118,101,114,115,0,0,0,0,0,83,76,79,84,45,62,115,108,0,0,0,0,0,0,0,0,75,48,53,49,57,54,48,32,82,97,109,0,0,0,0,0,103,108,73,115,86,101,114,116,101,120,65,114,114,97,121,79,69,83,0,0,0,0,0,0,71,114,97,110,97,100,97,32,40,74,112,110,44,32,85,83,65,41,0,0,0,0,0,0,76,85,84,84,101,120,67,111,111,114,100,0,0,0,0,0,109,100,95,103,114,97,110,97,100,97,49,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,71,76,32,86,83,121,110,99,32,61,62,32,37,115,10,0,0,0,0,0,0,66,82,79,87,83,69,82,32,68,73,82,32,37,115,0,0,82,101,110,111,118,97,116,105,111,110,32,126,32,87,111,108,102,32,84,101,97,109,0,0,37,117,32,115,101,99,111,110,100,115,0,0,0,0,0,0,109,100,95,114,111,98,111,99,111,100,0,0,0,0,0,0,75,48,53,50,49,48,57,82,77,82,68,76,105,110,101,0,115,111,110,105,99,119,105,51,0,0,0,0,0,0,0,0,76,101,102,116,0,0,0,0,71,114,97,110,97,100,97,32,40,74,112,110,44,32,85,83,65,44,32,118,49,46,49,41,0,0,0,0,0,0,0,0,68,101,118,97,115,116,97,116,111,114,115,32,40,118,101,114,46,32,88,41,0,0,0,0,116,110,122,115,98,0,0,0,65,108,105,101,110,115,32,40,65,115,105,97,41,0,0,0,68,101,102,97,117,108,116,32,45,32,49,58,48,48,0,0,68,114,118,83,111,117,110,100,78,109,105,69,110,97,98,108,101,0,0,0,0,0,0,0,115,110,97,112,112,101,114,0,109,100,95,103,114,97,110,97,100,97,0,0,0,0,0,0,83,116,114,111,110,103,0,0,75,48,53,50,49,48,57,32,82,97,109,0,0,0,0,0,73,116,101,109,115,32,116,111,32,102,105,110,100,0,0,0,84,104,117,110,100,101,114,32,67,114,111,115,115,32,40,74,97,112,97,110,41,0,0,0,69,114,97,115,101,32,111,110,32,82,101,115,101,116,0,0,71,114,121,122,111,114,32,40,83,101,116,32,49,41,0,0,88,45,77,101,110,32,40,50,32,80,108,97,121,101,114,115,32,118,101,114,32,65,65,65,41,0,0,0,0,0,0,0,80,49,32,70,108,105,112,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,97,110,110,111,116,32,104,97,118,101,32,109,111,114,101,32,116,104,97,110,32,111,110,101,32,118,101,114,116,101,120,32,115,104,97,100,101,114,32,105,110,32,97,32,112,114,111,103,114,97,109,46,10,0,0,0,0,0,87,111,111,100,112,101,99,107,101,114,32,40,115,101,116,32,50,41,0,0,0,0,0,0,118,117,108,99,97,110,98,0,71,111,117,107,101,116,115,117,106,105,32,73,99,104,105,122,111,107,117,32,40,74,112,110,41,0,0,0,0,0,0,0,66,0,0,0,101,0,0,0,101,0,0,0,32,0,0,0,83,0,0,0,116,0,0,0,111,0,0,0,114,0,0,0,109,0,0,0,32,0,0,0,45,0,0,0,32,0,0,0,68,0,0,0,111,0,0,0,68,0,0,0,111,0,0,0,110,0,0,0,80,0,0,0,97,0,0,0,116,0,0,0,99,0,0,0,104,0,0,0,105,0,0,0,32,0,0,0,73,0,0,0,73,0,0,0,0,0,0,0,18,96,0,0,150,153,0,0,134,152,0,0,2,135,0,0,13,255,0,0,2,135,0,0,180,102,0,0,32,0,0,0,40,0,0,0,86,0,0,0,49,0,0,0,48,0,0,0,48,0,0,0,44,0,0,0,32,0,0,0,72,0,0,0,111,0,0,0,110,0,0,0,103,0,0,0,32,0,0,0,75,0,0,0,111,0,0,0,110,0,0,0,103,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,69,115,99,97,112,101,32,75,105,100,115,32,40,65,115,105,97,44,32,52,32,80,108,97,121,101,114,115,41,0,0,0,75,110,105,103,104,116,115,32,111,102,32,116,104,101,32,82,111,117,110,100,32,40,57,49,49,49,50,55,32,74,97,112,97,110,44,32,66,45,66,111,97,114,100,32,56,57,54,50,53,66,45,49,41,0,0,0,112,99,101,95,100,111,114,97,110,100,110,0,0,0,0,0,83,117,112,101,114,32,83,105,100,101,107,105,99,107,115,32,51,32,45,32,84,104,101,32,78,101,120,116,32,71,108,111,114,121,32,47,32,84,111,107,117,116,101,110,32,79,117,32,51,32,45,32,101,105,107,111,117,32,101,32,110,111,32,109,105,99,104,105,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,100,101,115,99,115,46,10,0,0,0,0,0,0,109,100,95,103,111,117,107,101,116,115,117,0,0,0,0,0,109,100,95,122,97,110,121,103,111,108,102,0,0,0,0,0,99,104,101,97,116,0,0,0,116,109,104,116,50,112,0,0,98,98,109,97,110,119,106,0,71,111,111,102,121,39,115,32,72,121,115,116,101,114,105,99,97,108,32,72,105,115,116,111,114,121,32,84,111,117,114,32,40,85,83,65,41,0,0,0,75,117,110,103,45,70,117,32,77,97,115,116,101,114,32,40,98,111,111,116,108,101,103,32,115,101,116,32,51,41,0,0,107,101,121,112,97,100,53,0,67,104,105,112,37,105,82,101,103,105,115,116,101,114,115,0,107,105,107,99,117,98,105,99,98,0,0,0,0,0,0,0,109,100,95,103,111,111,102,121,0,0,0,0,0,0,0,0,83,68,76,0,0,0,0,0,68,105,97,103,110,111,115,116,105,99,115,59,32,100,105,115,97,98,108,101,100,124,101,110,97,98,108,101,100,0,0,0,83,104,50,69,120,116,91,105,93,46,111,112,98,97,115,101,0,0,0,0,0,0,0,0,112,97,99,109,97,110,98,108,0,0,0,0,0,0,0,0,82,46,80,82,69,86,80,67,0,0,0,0,0,0,0,0,85,99,104,117,117,32,83,101,110,107,97,110,32,71,111,109,111,114,97,32,40,74,112,110,41,0,0,0,0,0,0,0,107,48,53,51,50,54,48,32,99,104,97,110,110,101,108,115,32,35,32,37,100,0,0,0,109,100,95,103,111,109,111,114,97,0,0,0,0,0,0,0,49,57,57,54,0,0,0,0,68,111,119,110,0,0,0,0,82,101,116,114,111,80,97,100,32,83,116,97,114,116,32,66,117,116,116,111,110,0,0,0,71,111,108,100,101,110,32,65,120,101,32,73,73,73,32,40,74,112,110,41,0,0,0,0,49,53,48,107,32,51,48,48,107,32,52,53,48,107,0,0,50,48,48,107,32,51,48,48,107,32,51,48,48,107,43,0,49,48,48,48,32,80,111,105,110,116,115,0,0,0,0,0,68,101,102,97,117,108,116,32,45,32,50,58,48,48,0,0,68,114,118,83,111,117,110,100,83,116,97,116,117,115,0,0,83,0,0,0,117,0,0,0,107,0,0,0,101,0,0,0,98,0,0,0,97,0,0,0,110,0,0,0,32,0,0,0,74,0,0,0,97,0,0,0,110,0,0,0,115,0,0,0,105,0,0,0,32,0,0,0,82,0,0,0,121,0,0,0,117,0,0,0,107,0,0,0,111,0,0,0,32,0,0,0,40,0,0,0,115,0,0,0,101,0,0,0,116,0,0,0,32,0,0,0,50,0,0,0,44,0,0,0,32,0,0,0,83,0,0,0,121,0,0,0,115,0,0,0,116,0,0,0,101,0,0,0,109,0,0,0,32,0,0,0,49,0,0,0,54,0,0,0,66,0,0,0,44,0,0,0,32,0,0,0,70,0,0,0,68,0,0,0,49,0,0,0,48,0,0,0,56,0,0,0,57,0,0,0,66,0,0,0,32,0,0,0,51,0,0,0,49,0,0,0,55,0,0,0,45,0,0,0,53,0,0,0,48,0,0,0,50,0,0,0,49,0,0,0,41,0,0,0,0,0,0,0,185,48,0,0,177,48,0,0,208,48,0,0,243,48,0,0,192,150,0,0,235,88,0,0,32,0,0,0,220,122,0,0,80,91,0,0,0,0,0,0,0,0,0,0,0,0,0,0,109,100,95,103,111,108,100,110,97,120,51,0,0,0,0,0,87,101,97,107,0,0,0,0,101,97,46,119,46,108,0,0,71,111,108,100,101,110,32,65,120,101,32,73,73,32,40,87,111,114,108,100,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,0,0,73,56,48,51,57,82,65,77,0,0,0,0,0,0,0,0,90,56,48,32,82,79,77,0,119,111,111,100,112,101,99,97,0,0,0,0,0,0,0,0,109,100,95,103,111,108,100,110,97,120,50,112,0,0,0,0,37,48,56,120,58,32,71,52,45,48,32,85,110,100,101,102,105,110,101,100,32,84,104,117,109,98,32,105,110,115,116,114,117,99,116,105,111,110,58,32,37,48,52,120,32,37,120,10,0,0,0,0,0,0,0,0,97,114,109,95,105,99,111,117,110,116,0,0,0,0,0,0,66,101,101,32,83,116,111,114,109,32,45,32,68,111,68,111,110,80,97,99,104,105,32,73,73,32,40,86,49,48,48,44,32,72,111,110,103,32,75,111,110,103,41,0,0,0,0,0,107,110,105,103,104,116,115,106,97,0,0,0,0,0,0,0,68,111,114,97,101,109,111,110,32,45,32,77,101,105,107,121,117,117,32,68,97,105,32,83,97,107,117,115,101,110,0,0,71,111,108,100,101,110,32,65,120,101,32,73,73,32,40,87,111,114,108,100,41,0,0,0,72,68,54,51,48,57,67,80,85,67,111,110,116,101,120,116,91,105,93,46,110,67,121,99,108,101,115,83,101,103,109,101,110,116,0,0,0,0,0,0,90,111,111,109,33,32,40,87,111,114,108,100,41,0,0,0,103,105,103,97,119,105,110,103,0,0,0,0,0,0,0,0,107,101,121,112,97,100,52,0,109,100,95,103,111,108,100,110,97,120,50,0,0,0,0,0,71,111,108,100,101,110,32,65,120,101,32,40,87,111,114,108,100,41,0,0,0,0,0,0,9,37,115,58,10,9,9,37,115,58,32,37,115,10,0,0,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,115,116,97,116,101,32,102,114,111,109,32,34,37,115,34,46,0,110,90,56,48,73,67,111,117,110,116,91,105,93,0,0,0,109,100,95,103,111,108,100,110,97,120,101,49,0,0,0,0,112,116,114,45,62,110,67,121,99,108,101,115,83,101,103,109,101,110,116,0,0,0,0,0,83,116,114,101,97,107,105,110,103,32,40,115,101,116,32,50,41,0,0,0,0,0,0,0,77,111,111,110,119,97,114,80,111,114,116,83,101,108,101,99,116,0,0,0,0,0,0,0,82,45,62,112,99,0,0,0,71,111,108,100,101,110,32,65,120,101,32,40,87,111,114,108,100,44,32,118,49,46,49,41,0,0,0,0,0,0,0,0,99,114,105,109,102,103,104,116,0,0,0,0,0,0,0,0,109,100,95,103,111,108,100,110,97,120,101,0,0,0,0,0,49,57,56,50,0,0,0,0,85,112,0,0,0,0,0,0,82,101,116,114,111,80,97,100,32,83,101,108,101,99,116,32])
.concat([66,117,116,116,111,110,0,0,71,111,100,115,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,49,48,48,107,32,50,48,48,107,32,51,48,48,107,0,0,49,48,48,107,32,50,53,48,107,32,50,53,48,107,43,0,49,53,48,48,32,80,111,105,110,116,115,0,0,0,0,0,70,105,114,101,0,0,0,0,65,100,100,32,84,105,109,101,32,40,97,102,116,101,114,32,99,108,101,97,114,41,0,0,73,67,52,51,66,0,0,0,109,100,95,103,111,100,115,117,112,0,0,0,0,0,0,0,87,104,105,116,101,32,66,111,97,114,100,0,0,0,0,0,99,104,105,112,45,62,98,97,115,101,95,111,102,102,115,101,116,0,0,0,0,0,0,0,49,57,56,57,0,0,0,0,83,104,105,101,108,100,32,83,116,114,101,110,103,116,104,0,50,32,67,111,105,110,115,32,53,32,67,114,101,100,105,116,115,32,0,0,0,0,0,0,71,111,100,115,32,40,85,83,65,41,0,0,0,0,0,0,50,48,0,0,0,0,0,0,80,49,32,68,101,97,108,0,65,109,101,110,105,112,32,40,80,97,108,99,111,109,32,81,117,101,101,110,32,82,105,118,101,114,41,0,0,0,0,0,109,100,95,103,111,100,115,117,0,0,0,0,0,0,0,0,100,100,112,50,49,48,48,104,107,0,0,0,0,0,0,0,75,110,105,103,104,116,115,32,111,102,32,116,104,101,32,82,111,117,110,100,32,40,57,49,49,49,50,55,32,74,97,112,97,110,44,32,66,45,66,111,97,114,100,32,57,49,54,51,52,66,45,50,41,0,0,0,112,99,101,95,100,111,114,97,109,115,0,0,0,0,0,0,70,0,0,0,97,0,0,0,116,0,0,0,97,0,0,0,108,0,0,0,32,0,0,0,70,0,0,0,117,0,0,0,114,0,0,0,121,0,0,0,32,0,0,0,51,0,0,0,32,0,0,0,45,0,0,0,32,0,0,0,82,0,0,0,111,0,0,0,97,0,0,0,100,0,0,0,32,0,0,0,116,0,0,0,111,0,0,0,32,0,0,0,116,0,0,0,104,0,0,0,101,0,0,0,32,0,0,0,70,0,0,0,105,0,0,0,110,0,0,0,97,0,0,0,108,0,0,0,32,0,0,0,86,0,0,0,105,0,0,0,99,0,0,0,116,0,0,0,111,0,0,0,114,0,0,0,121,0,0,0,0,0,0,0,19,153,0,0,252,114,0,0,29,79,0,0,172,138,0,0,19,255,0,0,32,0,0,0,40,0,0,0,78,0,0,0,71,0,0,0,77,0,0,0,45,0,0,0,48,0,0,0,54,0,0,0,57,0,0,0,41,0,0,0,40,0,0,0,78,0,0,0,71,0,0,0,72,0,0,0,45,0,0,0,48,0,0,0,54,0,0,0,57,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,67,77,32,67,111,109,112,108,101,116,101,0,0,0,0,109,100,95,122,111,111,109,0,85,108,116,105,109,97,116,101,32,69,99,111,108,111,103,121,32,40,57,51,49,50,48,51,32,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,73,110,118,97,108,105,100,0,107,101,121,112,97,100,51,0,71,111,100,115,32,40,74,112,110,41,0,0,0,0,0,0,103,114,105,110,100,115,116,109,0,0,0,0,0,0,0,0,109,100,95,103,111,100,115,106,0,0,0,0,0,0,0,0,70,101,97,116,117,114,101,115,58,0,0,0,0,0,0,0,71,111,100,115,32,40,69,117,114,111,41,0,0,0,0,0,49,57,56,53,0,0,0,0,115,116,114,101,97,107,110,103,97,0,0,0,0,0,0,0,37,102,0,0,0,0,0,0,109,100,95,103,111,100,115,0,77,105,99,107,32,38,32,77,97,99,107,32,97,115,32,116,104,101,32,71,108,111,98,97,108,32,71,108,97,100,105,97,116,111,114,115,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,109,100,95,109,105,99,107,109,97,99,107,117,112,0,0,0,97,111,102,51,0,0,0,0,84,104,114,111,116,116,108,101,0,0,0,0,0,0,0,0,82,101,116,114,111,80,97,100,32,89,32,66,117,116,116,111,110,0,0,0,0,0,0,0,75,48,53,52,53,51,57,32,82,101,103,115,32,35,32,37,100,0,0,0,0,0,0,0,53,48,107,32,32,49,50,48,107,32,49,57,48,107,0,0,55,48,107,32,50,48,48,107,32,50,48,48,107,43,0,0,56,58,48,48,0,0,0,0,73,67,52,51,65,0,0,0,83,117,107,101,98,97,110,32,74,97,110,115,105,32,82,121,117,107,111,32,40,115,101,116,32,50,44,32,83,121,115,116,101,109,32,49,54,66,44,32,70,68,49,48,56,57,66,32,51,49,55,45,53,48,50,49,41,0,0,0,0,0,0,0,77,105,99,107,32,38,32,77,97,99,107,32,97,115,32,116,104,101,32,71,108,111,98,97,108,32,71,108,97,100,105,97,116,111,114,115,32,40,85,83,65,41,0,0,0,0,0,0,51,48,107,32,55,48,107,0,69,110,101,114,103,121,32,84,105,109,101,114,0,0,0,0,76,117,99,107,121,32,84,105,109,101,114,0,0,0,0,0,51,32,67,111,105,110,115,47,53,32,67,114,101,100,105,116,115,0,0,0,0,0,0,0,109,100,95,109,105,99,107,109,97,99,107,117,0,0,0,0,87,105,110,110,105,110,103,32,82,111,117,110,100,115,0,0,69,120,116,101,110,100,32,112,108,97,121,101,114,0,0,0,104,99,97,115,116,108,101,0,87,111,111,100,112,101,99,107,101,114,32,40,115,101,116,32,49,41,0,0,0,0,0,0,109,111,111,110,97,108,110,0,50,48,48,48,48,32,49,48,48,48,48,48,0,0,0,0,77,105,99,107,32,38,32,77,97,99,107,32,97,115,32,116,104,101,32,71,108,111,98,97,108,32,71,108,97,100,105,97,116,111,114,115,32,40,69,117,114,111,41,0,0,0,0,0,66,0,0,0,101,0,0,0,101,0,0,0,32,0,0,0,83,0,0,0,116,0,0,0,111,0,0,0,114,0,0,0,109,0,0,0,32,0,0,0,45,0,0,0,32,0,0,0,68,0,0,0,111,0,0,0,68,0,0,0,111,0,0,0,110,0,0,0,80,0,0,0,97,0,0,0,116,0,0,0,99,0,0,0,104,0,0,0,105,0,0,0,32,0,0,0,73,0,0,0,73,0,0,0,0,0,0,0,18,96,0,0,150,153,0,0,134,152,0,0,2,135,0,0,13,255,0,0,2,135,0,0,180,102,0,0,32,0,0,0,40,0,0,0,86,0,0,0,49,0,0,0,48,0,0,0,49,0,0,0,44,0,0,0,32,0,0,0,72,0,0,0,111,0,0,0,110,0,0,0,103,0,0,0,32,0,0,0,75,0,0,0,111,0,0,0,110,0,0,0,103,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,107,110,105,103,104,116,115,106,0,0,0,0,0,0,0,0,68,111,110,32,68,111,107,111,32,68,111,110,33,0,0,0,49,57,56,56,0,0,0,0,70,97,116,97,108,32,70,117,114,121,32,51,32,45,32,82,111,97,100,32,116,111,32,116,104,101,32,70,105,110,97,108,32,86,105,99,116,111,114,121,32,47,32,71,97,114,111,117,32,68,101,110,115,101,116,115,117,32,51,32,45,32,104,97,114,117,107,97,45,110,97,114,117,32,116,97,116,97,107,97,105,32,40,78,71,77,45,48,54,57,41,40,78,71,72,45,48,54,57,41,0,0,0,0,109,100,95,109,105,99,107,109,97,99,107,0,0,0,0,0,83,112,105,100,101,114,45,77,97,110,32,97,110,100,32,88,45,77,101,110,32,45,32,65,114,99,97,100,101,39,115,32,82,101,118,101,110,103,101,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,117,101,99,111,108,111,103,121,0,0,0,0,0,0,0,0,67,97,118,101,109,97,110,32,78,105,110,106,97,32,40,98,111,111,116,108,101,103,41,0,0,0,0,0,0,0,0,0,107,101,121,112,97,100,50,0,99,104,105,112,45,62,115,116,97,116,117,115,0,0,0,0,71,108,101,121,76,97,110,99,101,114,32,40,74,112,110,41,0,0,0,0,0,0,0,0,67,104,97,114,108,105,101,32,78,105,110,106,97,0,0,0,100,111,103,121,117,117,110,0,109,100,95,103,108,101,121,108,97,110,99,0,0,0,0,0,83,104,111,101,105,0,0,0,68,97,105,32,77,97,107,97,105,109,117,114,97,32,40,74,112,110,41,0,0,0,0,0,109,100,95,100,97,105,109,97,107,97,105,0,0,0,0,0,52,48,107,32,97,110,100,32,56,48,107,0,0,0,0,0,100,105,101,116,103,111,0,0,86,117,108,99,97,110,0,0,82,101,116,114,111,80,97,100,32,66,32,66,117,116,116,111,110,0,0,0,0,0,0,0,71,104,111,115,116,98,117,115,116,101,114,115,32,40,87,111,114,108,100,41,0,0,0,0,51,48,107,32,32,32,56,48,107,32,49,54,48,107,0,0,53,48,107,32,49,53,48,107,32,49,53,48,107,43,0,0,55,58,48,48,0,0,0,0,68,114,118,70,108,105,112,83,99,114,101,101,110,0,0,0,115,106,114,121,117,107,111,0,109,100,95,103,104,111,115,116,98,115,116,49,0,0,0,0,50,48,107,32,53,48,107,0,115,101,114,118,105,99,101,50,0,0,0,0,0,0,0,0,97,110,97,108,111,103,95,100,97,116,97,0,0,0,0,0,67,111,110,116,105,110,117,101,32,99,111,105,110,0,0,0,73,116,97,108,105,97,110,0,71,104,111,115,116,98,117,115,116,101,114,115,32,40,87,111,114,108,100,44,32,118,49,46,49,41,0,0,0,0,0,0,83,116,114,101,110,103,116,104,32,111,102,32,69,110,101,109,105,101,115,0,0,0,0,0,109,97,105,110,50,115,117,98,91,48,93,0,0,0,0,0,70,105,103,104,116,101,114,115,0,0,0,0,0,0,0,0,80,49,32,69,0,0,0,0,119,111,111,100,112,101,99,107,0,0,0,0,0,0,0,0,109,100,95,103,104,111,115,116,98,115,116,0,0,0,0,0,66,101,101,32,83,116,111,114,109,32,45,32,68,111,68,111,110,80,97,99,104,105,32,73,73,32,40,86,49,48,49,44,32,72,111,110,103,32,75,111,110,103,41,0,0,0,0,0,75,110,105,103,104,116,115,32,111,102,32,116,104,101,32,82,111,117,110,100,32,40,57,49,49,49,50,55,32,85,83,65,41,0,0,0,0,0,0,0,112,99,101,95,100,111,110,100,111,107,111,0,0,0,0,0,71,101,111,114,103,101,32,70,111,114,101,109,97,110,39,115,32,75,79,32,66,111,120,105,110,103,32,40,85,83,65,41,0,0,0,0,0,0,0,0,109,100,95,115,112,105,100,120,109,101,110,0,0,0,0,0,69,99,111,32,70,105,103,104,116,101,114,115,32,40,57,51,49,50,48,51,32,85,83,65,41,0,0,0,0,0,0,0,107,101,121,112,97,100,49,0,109,100,95,103,101,111,114,103,101,107,111,117,0,0,0,0,71,101,111,114,103,101,32,70,111,114,101,109,97,110,39,115,32,75,79,32,66,111,120,105,110,103,32,40,69,117,114,111,41,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,45,45,109,101,110,117,32,119,97,115,32,117,115,101,100,44,32,98,117,116,32,82,79,77,32,102,105,108,101,32,119,97,115,32,112,97,115,115,101,100,32,97,115,32,119,101,108,108,46,10,0,99,104,101,108,110,111,118,117,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,80,73,88,69,76,95,70,79,82,77,65,84,58,32,88,82,71,66,56,56,56,56,46,10,0,109,100,95,103,101,111,114,103,101,107,111,0,0,0,0,0,83,116,114,101,97,107,105,110,103,32,40,115,101,116,32,49,41,0,0,0,0,0,0,0,71,80,57,48,48,49,80,111,105,110,116,101,114,0,0,0,65,111,107,105,32,79,111,107,97,109,105,32,116,111,32,83,104,105,114,111,107,105,32,77,101,106,105,107,97,32,45,32,71,101,110,99,104,111,117,32,72,105,115,104,105,32,40,74,112,110,41,0,0,0,0,0,109,100,95,103,101,110,99,104,111,104,105,0,0,0,0,0,52,48,107,44,32,57,48,107,32,116,104,101,110,32,101,118,101,114,121,32,57,48,107,0,99,111,98,114,97,99,111,109,106,0,0,0,0,0,0,0,114,98,102,102,49,0,0,0,77,105,115,115,105,108,101,0,46,47,103,101,110,101,114,97,108,46,104,0,0,0,0,0,71,101,110,103,104,105,115,32,75,104,97,110,32,73,73,32,45,32,67,108,97,110,32,111,102,32,116,104,101,32,71,114,97,121,32,87,111,108,102,32,40,85,83,65,41,0,0,0,73,110,118,117,108,110,101,114,97,98,105,108,105,116,121,32,40,68,101,98,117,103,41,0,54,58,48,48,0,0,0,0,68,114,118,86,105,100,101,111,69,110,97,98,108,101,0,0,83,104,105,110,111,98,105,32,40,115,101,116,32,53,44,32,83,121,115,116,101,109,32,49,54,66,44,32,117,110,112,114,111,116,101,99,116,101,100,41,0,0,0,0,0,0,0,0,109,100,95,103,101,110,103,104,105,115,50,0,0,0,0,0,80,50,32,83,101,114,118,105,99,101,0,0,0,0,0,0,67,111,110,116,105,110,117,101,32,67,111,105,110,0,0,0,67,104,105,110,101,115,101,0,78,117,109,98,101,114,32,111,102,32,69,110,101,109,105,101,115,0,0,0,0,0,0,0,71,101,110,101,114,97,116,105,111,110,115,32,76,111,115,116,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,83,117,112,101,114,32,104,97,114,100,0,0,0,0,0,0,78,111,118,111,109,97,116,105,99,0,0,0,0,0,0,0,109,97,105,110,101,118,116,0,49,48,48,48,48,32,52,48,48,48,48,0,0,0,0,0,109,100,95,103,101,110,101,108,111,115,116,0,0,0,0,0,100,100,112,50,49,48,49,104,107,0,0,0,0,0,0,0,107,110,105,103,104,116,115,117,0,0,0,0,0,0,0,0,68,105,103,105,116,97,108,32,67,104,97,109,112,0,0,0,83,97,117,108,97,98,105,32,83,112,105,114,105,116,115,32,47,32,74,105,110,32,83,97,117,108,97,98,105,32,84,117,32,72,111,110,32,40,75,111,114,101,97,110,32,114,101,108,101,97,115,101,32,111,102,32,83,97,109,117,114,97,105,32,83,104,111,100,111,119,110,32,73,73,41,0,0,0,0,0,71,101,110,101,114,97,108,32,67,104,97,111,115,32,68,97,105,107,111,110,115,101,110,32,40,74,112,110,41,0,0,0,80,105,110,107,32,71,111,101,115,32,116,111,32,72,111,108,108,121,119,111,111,100,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,101,99,111,102,103,104,116,114,117,49,0,0,0,0,0,0,107,105,110,103,100,109,103,112,0,0,0,0,0,0,0,0,107,101,121,112,97,100,48,0,103,101,110,114,101,58,32,37,100,10,0,0,0,0,0,0,109,100,95,103,101,110,99,104,97,111,115,106,0,0,0,0,116,111,116,97,108,95,99,121,99,108,101,115,0,0,0,0,119,105,122,100,102,105,114,101,0,0,0,0,0,0,0,0,115,115,116,114,105,107,101,114,0,0,0,0,0,0,0,0,71,101,110,101,114,97,108,32,67,104,97,111,115,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,69,114,114,111,114,32,112,97,114,115,105,110,103,32,97,114,103,117,109,101,110,116,115,46,10,0,0,82,45,62,112,111,114,116,49,95,100,97,116,97,0,0,0,69,105,103,104,116,32,66,97,108,108,32,65,99,116,105,111,110,32,40,68,75,32,99,111,110,118,101,114,115,105,111,110,41,0,0,0,0,0,0,0,79,110,0,0,0,0,0,0,98,97,116,114,105,100,101,114,116,0,0,0,0,0,0,0,102,105,120,101,105,103,104,116,116,119,0,0,0,0,0,0,109,100,95,103,101,110,99,104,97,111,115,0,0,0,0,0,71,117,97,114,100,105,97,110,0,0,0,0,0,0,0,0,115,116,114,101,97,107,110,103,0,0,0,0,0,0,0,0,82,111,121,97,108,32,66,108,111,111,100,32,40,74,112,110,41,0,0,0,0,0,0,0,98,103,97,114,101,103,103,97,98,108,0,0,0,0,0,0,115,97,109,101,115,97,109,101,50,0,0,0,0,0,0,0,109,100,95,114,111,121,97,108,98,108,100,0,0,0,0,0,108,97,115,116,109,0,0,0,67,111,105,110,32,52,0,0,71,101,109,102,105,114,101,32,40,85,83,65,41,0,0,0,100,105,115,97,98,108,101,95,99,112,117,91,50,93,0,0,66,111,117,108,100,101,114,32,68,97,115,104,32,47,32,66,111,117,108,100,101,114,32,68,97,115,104,32,80,97,114,116,32,50,32,40,87,111,114,108,100,41,0,0,0,0,0,0,49,48,107,32,51,48,48,107,32,51,48,48,107,43,0,0,84,97,105,116,111,32,67,111,114,112,111,114,97,116,105,111,110,32,74,97,112,97,110,0,80,49,32,83,116,101,101,114,105,110,103,0,0,0,0,0,53,58,48,48,0,0,0,0,68,114,118,77,67,85,65,99,116,105,118,101,0,0,0,0,84,104,101,32,76,101,103,101,110,100,32,111,102,32,75,97,103,101,32,40,98,111,111,116,108,101,103,32,115,101,116,32,51,41,0,0,0,0,0,0,115,104,105,110,111,98,105,53,0,0,0,0,0,0,0,0,48,49,49,49,0,0,0,0,109,100,95,103,101,109,102,105,114,101,0,0,0,0,0,0,80,111,115,115,105,98,108,101,0,0,0,0,0,0,0,0,107,111,110,116,101,115,116,0,80,108,97,121,32,84,105,109,101,0,0,0,0,0,0,0,97,114,107,110,111,105,100,50,117,0,0,0,0,0,0,0,65,114,99,97,100,105,97,0,0,0,0,0,0,0,0,0,85,110,107,110,111,119,110,0,71,97,117,110,116,108,101,116,32,40,74,112,110,41,0,0,74,111,121,115,116,105,99,107,115,32,38,32,66,117,116,116,111,110,115,0,0,0,0,0,114,97,115,116,115,97,103,50,0,0,0,0,0,0,0,0,80,49,32,68,0,0,0,0,119,114,111,110,103,32,99,111,108,111,114,115,0,0,0,0,118,100,99,95,115,97,116,98,95,99,111,117,110,116,100,111,119,110,91,105,93,0,0,0,65,100,100,105,116,105,111,110,97,108,32,66,111,110,117,115,0,0,0,0,0,0,0,0,98,115,104,97,114,107,106,106,115,0,0,0,0,0,0,0,109,100,95,103,97,117,110,116,108,116,52,106,0,0,0,0,99,117,114,114,101,110,116,95,98,97,110,107,0,0,0,0,112,97,108,100,109,97,95,100,101,115,116,0,0,0,0,0,111,112,119,111,108,102,97,0,99,97,100,97,115,104,103,0,66,0,0,0,101,0,0,0,101,0,0,0,32,0,0,0,83,0,0,0,116,0,0,0,111,0,0,0,114,0,0,0,109,0,0,0,32,0,0,0,45,0,0,0,32,0,0,0,68,0,0,0,111,0,0,0,68,0,0,0,111,0,0,0,110,0,0,0,80,0,0,0,97,0,0,0,116,0,0,0,99,0,0,0,104,0,0,0,105,0,0,0,32,0,0,0,73,0,0,0,73,0,0,0,0,0,0,0,18,96,0,0,150,153,0,0,134,152,0,0,2,135,0,0,13,255,0,0,2,135,0,0,180,102,0,0,32,0,0,0,40,0,0,0,86,0,0,0,49,0,0,0,48,0,0,0,50,0,0,0,44,0,0,0,32,0,0,0,72,0,0,0,111,0,0,0,110,0,0,0,103,0,0,0,32,0,0,0,75,0,0,0,111,0,0,0,110,0,0,0,103,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,75,110,105,103,104,116,115,32,111,102,32,116,104,101,32,82,111,117,110,100,32,40,57,49,49,49,50,55,32,101,116,99,41,0,0,0,0,0,0,0,112,99,101,95,100,105,103,105,99,104,109,112,0,0,0,0,115,97,109,115,104,111,50,107,0,0,0,0,0,0,0,0,71,97,117,110,116,108,101,116,32,73,86,32,40,69,117,114,111,44,32,85,83,65,44,32,49,57,57,51,48,56,41,0,0,0,0,0,0,0,0,0,83,117,112,101,114,109,97,110,32,40,87,111,114,108,100,41,0,0,0,0,0,0,0,0,110,105,110,106,97,119,117,0,109,100,95,112,105,110,107,0,69,99,111,32,70,105,103,104,116,101,114,115,32,40,57,52,48,50,49,53,32,85,83,65,41,0,0,0,0,0,0,0,112,97,103,101,100,111,119,110,0,0,0,0,0,0,0,0,109,100,95,103,97,117,110,116,108,116,52,97,0,0,0,0,84,67,48,50,50,48,73,79,67,73,110,112,117,116,80,111,114,116,49,0,0,0,0,0,65,108,116,101,114,101,100,32,66,101,97,115,116,32,40,115,101,116,32,56,44,32,56,55,53,49,32,51,49,55,45,48,48,55,56,41,0,0,0,0,115,102,105,105,105,50,110,0,84,67,48,49,49,48,80,67,82,32,80,97,108,101,116,116,101,0,0,0,0,0,0,0,83,121,115,116,101,109,49,54,80,97,103,101,0,0,0,0,49,67,32,50,67,0,0,0,71,97,117,110,116,108,101,116,32,73,86,32,40,69,117,114,111,44,32,85,83,65,44,32,49,57,57,51,48,57,41,0,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,73,110,118,97,108,105,100,32,97,114,103,117,109,101,110,116,32,105,110,32,45,45,115,114,97,109,45,109,111,100,101,46,10,0,0,116,104,101,116,111,103,121,117,0,0,0,0,0,0,0,0,67,108,117,116,99,104,32,72,105,116,116,101,114,32,40,115,101,116,32,50,44,32,85,83,44,32,70,68,49,48,57,52,32,51,49,55,45,48,49,55,54,41,0,0,0,0,0,0,109,100,95,103,97,117,110,116,108,116,52,0,0,0,0,0,80,111,119,101,114,32,68,114,105,102,116,32,40,87,111,114,108,100,44,32,82,101,118,32,65,41,0,0,0,0,0,0,67,97,108,77,97,115,107,0,71,80,32,82,105,100,101,114,32,40,74,97,112,97,110,44,32,70,68,49,48,57,52,32,51,49,55,45,48,49,54,49,41,0,0,0,0,0,0,0,49,32,67,111,105,110,32,51,32,67,114,101,100,105,116,115,32,0,0,0,0,0,0,0,76,97,100,121,32,66,117,103,32,40,98,111,111,116,108,101,103,32,111,110,32,71,97,108,97,120,105,97,110,32,104,97,114,100,119,97,114,101,41,0,0,0,0,0,0,0,0,0,86,100,112,87,105,110,100,111,119,82,105,103,104,116,0,0,65,108,105,101,110,32,83,121,110,100,114,111,109,101,32,40,115,101,116,32,49,44,32,74,97,112,97,110,44,32,111,108,100,44,32,83,121,115,116,101,109,32,49,54,65,44,32,70,68,49,48,56,57,65,32,51,49,55,45,48,48,51,51,41,0,0,0,0,0,0,0,0,68,105,115,110,101,121,32,73,110,116,101,114,97,99,116,105,118,101,0,0,0,0,0,0,104,97,110,103,111,110,50,0,52,32,67,111,105,110,115,32,52,32,67,114,101,100,105,116,115,0,0,0,0,0,0,0,101,120,112,108,98,114,107,114,0,0,0,0,0,0,0,0,109,99,104,97,109,112,100,120,0,0,0,0,0,0,0,0,68,111,117,98,108,101,32,80,111,105,110,116,0,0,0,0,71,97,114,103,111,121,108,101,115,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,115,116,111,112,115,117,98,99,112,117,0,0,0,0,0,0,118,105,100,101,111,95,102,117,108,108,115,99,114,101,101,110,0,0,0,0,0,0,0,0,80,117,122,122,108,101,32,67,108,117,98,32,40,89,117,110,32,83,117,110,103,44,32,115,101,116,32,49,41,0,0,0,103,111,119,99,97,105,122,114,0,0,0,0,0,0,0,0,80,52,32,70,105,114,101,32,51,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,102,105,110,100,32,99,111,110,102,105,103,32,97,116,32,112,97,116,104,58,32,34,37,115,34,10,0,0,0,0,0,0,0,0,109,100,95,103,97,114,103,111,121,108,101,0,0,0,0,0,87,105,110,110,105,110,103,32,82,111,117,110,100,115,32,40,80,108,97,121,101,114,32,86,83,32,80,108,97,121,101,114,41,0,0,0,0,0,0,0,71,111,117,107,101,116,115,117,106,105,32,71,97,105,100,101,110,32,83,97,105,107,121,111,117,32,68,101,110,115,101,116,115,117,32,40,74,97,112,97,110,44,32,118,101,114,46,32,57,53,47,48,54,47,50,48,41,0,0,0,0,0,0,0,51,32,68,111,116,115,0,0,49,57,56,55,0,0,0,0,98,103,49,115,99,114,111,108,108,121,0,0,0,0,0,0,49,48,107,32,50,48,48,107,32,50,48,48,107,43,0,0,83,116,101,101,114,105,110,103,0,0,0,0,0,0,0,0,83,116,97,114,116,105,110,103,32,84,105,109,101,0,0,0,68,114,118,83,111,117,110,100,67,80,85,65,99,116,105,118,101,0,0,0,0,0,0,0,83,104,105,110,111,98,105,32,40,115,101,116,32,52,44,32,83,121,115,116,101,109,32,49,54,66,44,32,77,67,45,56,49,50,51,66,32,51,49,55,45,48,48,53,52,41,0,0,71,97,114,102,105,101,108,100,32,45,32,67,97,117,103,104,116,32,105,110,32,116,104,101,32,65,99,116,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,0,0,112,49,32,122,45,97,120,105,115,0,0,0,0,0,0,0,73,109,112,111,115,115,105,98,108,101,0,0,0,0,0,0,68,105,115,112,108,97,121,32,67,111,109,98,111,115,0,0,67,111,109,97,100,0,0,0,97,114,99,97,100,105,97,0,83,104,111,119,32,84,97,114,103,101,116,115,0,0,0,0,83,101,105,98,117,32,75,97,105,104,97,116,115,117,32,40,73,66,76,32,67,111,114,112,111,114,97,116,105,111,110,32,108,105,99,101,110,115,101,41,0,0,0,0,0,0,0,0,52,32,80,108,97,121,101,114,115,32,40,84,101,97,109,41,0,0,0,0,0,0,0,0,109,121,97,110,103,101,108,50,0,0,0,0,0,0,0,0,109,100,95,103,97,114,102,105,101,108,100,0,0,0,0,0,67,111,110,116,114,111,108,32,84,121,112,101,0,0,0,0,37,115,32,61,32,34,37,115,34,10,0,0,0,0,0,0,83,99,114,101,101,110,32,114,101,118,101,114,115,101,0,0,66,111,109,98,32,75,105,99,107,32,40,115,101,116,32,49,41,0,0,0,0,0,0,0,67,97,110,110,111,110,32,66,97,108,108,32,40,80,97,99,109,97,110,32,72,97,114,100,119,97,114,101,41,0,0,0,78,105,110,106,97,32,82,121,117,107,101,110,100,101,110,32,40,74,97,112,97,110,44,32,115,101,116,32,50,41,0,0,71,97,109,101,32,110,111,32,75,97,110,100,117,109,101,32,79,116,111,107,117,121,111,117,32,40,74,112,110,41,0,0,52,32,67,111,105,110,115,32,53,32,67,114,101,100,105,116,115,0,0,0,0,0,0,0,66,101,101,32,83,116,111,114,109,32,45,32,68,111,68,111,110,80,97,99,104,105,32,73,73,32,40,86,49,48,50,44,32,72,111,110,103,32,75,111,110,103,41,0,0,0,0,0,78,101,119,32,70,97,110,116,97,115,105,97,0,0,0,0,107,110,105,103,104,116,115,0,68,105,101,32,72,97,114,100,0,0,0,0,0,0,0,0,83,0,0,0,97,0,0,0,109,0,0,0,117,0,0,0,114,0,0,0,97,0,0,0,105,0,0,0,32,0,0,0,83,0,0,0,104,0,0,0,111,0,0,0,100,0,0,0,111,0,0,0,119,0,0,0,110,0,0,0,32,0,0,0,73,0,0,0,73,0,0,0,0,0,0,0,31,119,0,0,32,0,0,0,83,0,0,0,97,0,0,0,109,0,0,0,117,0,0,0,114,0,0,0,97,0,0,0,105,0,0,0,32,0,0,0,83,0,0,0,112,0,0,0,105,0,0,0,114,0,0,0,105,0,0,0,116,0,0,0,115,0,0,0,32,0,0,0,45,0,0,0,32,0,0,0,135,137,0,0,139,115,0,0,56,78,0,0,48,87,0,0,68,115,0,0,9,89,0,0,32,0,0,0,40,0,0,0,78,0,0,0,71,0,0,0,77,0,0,0,45,0,0,0,48,0,0,0,54,0,0,0,51,0,0,0,41,0,0,0,40,0,0,0,78,0,0,0,71,0,0,0,72,0,0,0,45,0,0,0,48,0,0,0,54,0,0,0,51,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,247,150,0,0,203,142,0,0,151,101,0,0,32,0,0,0,82,0,0,0,105,0,0,0,111,0,0,0,116,0,0,0,0,0,0,0,0,0,0,0,109,100,95,103,97,109,101,110,107,111,0,0,0,0,0,0,69,120,116,114,97,32,66,97,108,108,0,0,0,0,0,0,115,97,105,108,111,114,109,110,116,0,0,0,0,0,0,0,77,117,116,97,110,116,32,76,101,97,103,117,101,32,70,111,111,116,98,97,108,108,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,101,99,111,102,103,104,116,114,117,0,0,0,0,0,0,0,78,111,115,116,114,97,100,97,109,117,115,32,40,75,111,114,101,97,41,0,0,0,0,0,112,97,103,101,117,112,0,0,71,97,109,98,108,101,114,32,74,105,107,111,99,104,117,117,115,104,105,110,104,97,32,45,32,75,97,116,97,121,97,109,97,32,77,97,115,97,121,117,107,105,32,110,111,32,77,97,104,106,111,110,103,32,68,111,117,106,111,117,32,40,74,112,110,41,0,0,0,0,0,0,97,108,105,101,110,115,0,0,84,104,101,32,67,111,109,98,97,116,114,105,98,101,115,32,40,85,83,41,32,45,32,83,101,116,32,49,63,0,0,0,109,100,95,103,97,109,98,108,101,114,0,0,0,0,0,0,108,111,97,100,45,115,97,118,101,0,0,0,0,0,0,0,71,97,108,97,120,121,32,70,111,114,99,101,32,73,73,32,40,87,111,114,108,100,41,0,0,0,0,0,0,0,0,0,78,105,104,111,110,32,83,121,115,116,101,109,0,0,0,0,51,32,67,111,105,110,45,49,32,80,108,97,121,0,0,0,77,111,114,101,32,77,111,114,101,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,86,105,100,101,111,32,64,32,102,117,108,108,115,99,114,101,101,110,10,0,0,70,105,114,115,116,32,65,109,117,115,101,109,101,110,116,0,109,100,95,103,102,111,114,99,101,50,97,0,0,0,0,0,103,117,110,98,105,114,100,107,0,0,0,0,0,0,0,0,71,117,110,98,105,114,100,32,50,0,0,0,0,0,0,0,49,32,67,111,105,110,32,50,32,80,108,97,121,115,0,0,71,97,105,110,32,71,114,111,117,110,100,32,40,87,111,114,108,100,44,32,65,108,116,41,0,0,0,0,0,0,0,0,70,45,49,32,68,114,101,97,109,32,40,98,111,111,116,108,101,103,41,0,0,0,0,0,83,117,110,32,69,108,101,99,116,114,111,110,105,99,115,0,108,101,103,105,111,110,0,0,84,67,48,53,49,48,78,73,79,73,110,112,117,116,80,111,114,116,49,0,0,0,0,0,72,117,100,115,111,110,0,0,80,52,32,70,105,114,101,32,50,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,70,111,117,110,100,32,100,101,102,97,117,108,116,32,99,111,110,102,105,103,58,32,37,115,46,10,0,0,0,109,100,95,103,103,114,111,117,110,100,49,0,0,0,0,0,80,67,48,57,48,79,74,83,112,114,105,116,101,67,116,114,108,0,0,0,0,0,0,0,80,111,107,101,114,32,76,97,100,105,101,115,32,40,76,101,112,114,101,99,104,97,117,110,32,118,101,114,46,32,53,49,48,41,0,0,0,0,0,0,80,67,48,56,48,83,78,67,116,114,108,91,105,93,0,0,49,48,107,32,49,53,48,107,32,49,53,48,107,43,0,0,118,98,108,97,110,107,0,0,51,32,67,111,105,110,32,32,49,32,67,114,101,100,105,116,115,0,0,0,0,0,0,0,68,114,118,83,108,97,118,101,67,80,85,65,99,116,105,118,101,0,0,0,0,0,0,0,80,114,101,104,105,115,108,101,73,110,112,117,116,0,0,0,115,104,105,110,111,98,105,52,0,0,0,0,0,0,0,0,65,103,114,101,115,115,32,40,69,110,103,108,105,115,104,32,98,111,111,116,108,101,103,41,0,0,0,0,0,0,0,0,71,97,105,110,32,71,114,111,117,110,100,32,40,87,111,114,108,100,41,0,0,0,0,0,80,49,32,83,101,114,118,105,99,101,0,0,0,0,0,0,74,111,105,110,32,68,117,114,105,110,103,32,71,97,109,101,0,0,0,0,0,0,0,0,122,56,48,98,97,110,107,100,97,116,97,91,49,93,0,0,77,101,100,105,97,32,84,114,97,100,105,110,103,32,67,111,114,112,0,0,0,0,0,0,112,117,99,107,109,111,100,0,66,108,97,99,107,32,68,114,97,103,111,110,32,40,98,111,111,116,108,101,103,41,0,0,65,0,0,0,0,0,0,0,103,97,117,110,116,108,101,116,103,114,56,0,0,0,0,0,109,100,95,103,103,114,111,117,110,100,0,0,0,0,0,0,67,114,97,122,121,32,70,105,103,104,116,0,0,0,0,0,48,52,58,48,48,0,0,0,69,118,101,110,116,32,83,101,108,101,99,116,105,111,110,0,66,106,68,105,112,0,0,0,69,118,101,114,121,32,52,48,48,44,48,48,48,32,112,111,105,110,116,115,0,0,0,0,80,49,32,67,0,0,0,0,99,97,110,110,111,110,98,112,0,0,0,0,0,0,0,0,48,45,51,0,0,0,0,0,109,114,100,111,121,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,99,114,101,97,116,101,32,100,105,114,101,99,116,111,114,121,58,32,34,37,115,34,46,10,0,71,97,105,97,114,101,115,32,40,74,112,110,44,32,85,83,65,41,0,0,0,0,0,0,100,111,114,111,100,111,110,0,68,111,110,107,101,121,32,75,111,110,103,32,40,74,97,112,97,110,32,115,101,116,32,49,41,0,0,0,0,0,0,0,51,48,107,32,49,48,48,107,32,49,48,48,107,43,0,0,100,100,112,50,104,107,0,0,39,89,0,0,84,155,0,0,76,117,0,0,81,103,0,0,0,0,0,0,68,0,0,0,97,0,0,0,105,0,0,0,32,0,0,0,77,0,0,0,97,0,0,0,107,0,0,0,97,0,0,0,105,0,0,0,45,0,0,0,77,0,0,0,117,0,0,0,114,0,0,0,97,0,0,0,32,0,0,0,40,0,0,0,98,0,0,0,111,0,0,0,111,0,0,0,116,0,0,0,108,0,0,0,101,0,0,0,103,0,0,0,44,0,0,0,32,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,83,101,105,32,83,101,110,115,104,105,32,65,109,97,116,101,108,97,115,115,0,0,0,0,112,99,101,95,100,105,101,104,97,114,100,0,0,0,0,0,106,117,106,117,98,97,0,0,83,97,109,117,114,97,105,32,83,104,111,100,111,119,110,32,73,73,32,47,32,83,104,105,110,32,83,97,109,117,114,97,105,32,83,112,105,114,105,116,115,32,45,32,72,97,111,104,109,97,114,117,32,106,105,103,111,107,117,104,101,110,32,40,78,71,77,45,48,54,51,41,40,78,71,72,45,48,54,51,41,0,0,0,0,0,0,0,101,120,101,100,101,120,101,115,95,102,103,95,101,110,97,98,108,101,0,0,0,0,0,0,84,67,48,54,52,48,70,73,79,73,110,112,117,116,80,111,114,116,49,0,0,0,0,0,109,100,95,103,97,105,97,114,101,115,0,0,0,0,0,0,118,117,108,103,117,115,95,115,99,114,111,108,108,91,49,93,0,0,0,0,0,0,0,0,54,56,75,32,35,49,32,82,65,77,32,40,67,80,85,32,35,49,41,0,0,0,0,0,109,100,95,109,108,102,111,111,116,98,0,0,0,0,0,0,49,48,48,75,47,50,48,48,75,47,52,48,48,75,47,56,48,48,75,0,0,0,0,0,69,99,111,32,70,105,103,104,116,101,114,115,32,40,57,51,49,50,48,51,32,72,105,115,112,97,110,105,99,41,0,0,76,101,103,101,110,100,97,114,121,32,87,105,110,103,115,32,40,98,111,111,116,108,101,103,41,0,0,0,0,0,0,0,110,117,109,57,0,0,0,0,84,101,116,114,105,115,32,40,99,111,99,107,116,97,105,108,32,115,101,116,32,49,41,0,0,0,0,0,0,0,0,0,71,97,100,103,101,116,32,84,119,105,110,115,32,40,85,83,65,41,0,0,0,0,0,0,83,117,112,101,114,109,97,110,80,111,114,116,0,0,0,0,122,122,121,122,122,121,120,120,50,0,0,0,0,0,0,0,84,104,101,32,71,108,111,98,32,40,101,97,114,108,105,101,114,41,0,0,0,0,0,0,83,116,114,101,101,116,32,83,109,97,114,116,32,40,85,83,32,118,101,114,115,105,111,110,32,50,41,0,0,0,0,0,115,105,110,118,97,115,110,0,49,57,52,51,98,50,0,0,109,100,95,103,97,100,103,101,116,0,0,0,0,0,0,0,108,111,97,100,45,110,111,115,97,118,101,0,0,0,0,0,84,104,101,32,68,111,117,98,108,101,32,68,121,110,97,109,105,116,101,115,32,40,85,83,41,0,0,0,0,0,0,0,109,97,100,103,101,97,114,106,0,0,0,0,0,0,0,0,71,45,76,79,67,32,65,105,114,32,66,97,116,116,108,101,32,40,87,111,114,108,100,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,77,105,115,115,105,110,103,32,115,111,117,110,100,115,0,0,108,97,100,121,98,117,103,103,0,0,0,0,0,0,0,0,87,99,57,48,98,49,83,99,114,111,108,108,49,89,0,0,37,46,48,76,102,0,0,0,71,104,111,115,116,115,39,110,32,71,111,98,108,105,110,115,32,40,112,114,111,116,111,116,121,112,101,41,0,0,0,0,109,100,95,103,108,111,99,112,0,0,0,0,0,0,0,0,71,97,108,108,97,103,0,0,82,101,116,114,111,65,114,99,104,58,32,76,111,97,100,105,110,103,32,82,79,77,32,102,105,108,101,58,32,37,115,46,10,0,0,0,0,0,0,0,87,99,57,48,83,99,114,111,108,108,48,89,76,111,0,0,77,97,105,110,32,82,65,77,0,0,0,0,0,0,0,0,78,101,119,32,82,97,108,108,121,32,88,0,0,0,0,0,86,45,83,121,115,116,101,109,32,67,111,46,32,40,68,97,116,97,32,69,97,115,116,32,108,105,99,101,110,115,101,41,0,0,0,0,0,0,0,0,83,105,108,107,32,87,111,114,109,0,0,0,0,0,0,0,71,45,76,79,67,32,65,105,114,32,66,97,116,116,108,101,32,40,87,111,114,108,100,41,0,0,0,0,0,0,0,0,53,48,107,44,32,49,48,48,107,32,116,104,101,110,32,101,118,101,114,121,32,49,48,48,107,0,0,0,0,0,0,0,103,98,101,114,101,116,0,0,100,100,114,97,103,111,110,117,98,0,0,0,0,0,0,0,77,67,54,56,52,48,95,116,101,109,112,111,50,0,0,0,107,111,118,108,115,113,104,50,0,0,0,0,0,0,0,0,109,95,100,114,103,119,50,95,112,114,111,116,95,104,111,108,100,0,0,0,0,0,0,0,80,52,32,70,105,114,101,32,49,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,76,111,97,100,105,110,103,32,100,101,102,97,117,108,116,32,99,111,110,102,105,103,46,10,0,0,0,0,0,109,100,95,103,108,111,99,0,70,114,97,109,101,98,117,102,102,101,114,32,49,0,0,0,50,32,68,111,116,115,0,0,111,114,108,101,103,101,110,100,99,97,0,0,0,0,0,0,49,48,107,32,49,48,48,107,32,49,48,48,107,43,0,0,50,32,67,111,105,110,32,32,49,32,67,114,101,100,105,116,115,0,0,0,0,0,0,0,68,114,118,82,111,109,66,97,110,107,0,0,0,0,0,0,83,104,105,110,111,98,105,32,40,115,101,116,32,51,44,32,83,121,115,116,101,109,32,49,54,66,44,32,77,67,45,56,49,50,51,66,32,51,49,55,45,48,48,53,52,41,0,0,48,0,0,0,0,0,0,0,70,117,110,32,67,97,114,32,82,97,108,108,121,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,41,0,0,56,32,72,97,114,100,0,0,122,56,48,98,97,110,107,100,97,116,97,91,48,93,0,0,99,104,105,112,45,62,107,101,121,0,0,0,0,0,0,0,109,100,95,102,117,110,99,97,114,0,0,0,0,0,0,0,112,111,114,116,66,95,105,110,0,0,0,0,0,0,0,0,112,99,101,95,97,98,117,114,110,101,114,50,0,0,0,0,68,101,98,117,103,32,68,105,112,0,0,0,0,0,0,0,70,117,110,32,39,78,39,32,71,97,109,101,115,32,40,85,83,65,41,0,0,0,0,0,66,0,0,0,101,0,0,0,101,0,0,0,32,0,0,0,83,0,0,0,116,0,0,0,111,0,0,0,114,0,0,0,109,0,0,0,32,0,0,0,45,0,0,0,32,0,0,0,68,0,0,0,111,0,0,0,68,0,0,0,111,0,0,0,110,0,0,0,80,0,0,0,97,0,0,0,116,0,0,0,99,0,0,0,104,0,0,0,105,0,0,0,32,0,0,0,73,0,0,0,73,0,0,0,0,0,0,0,18,96,0,0,150,153,0,0,134,152,0,0,2,135,0,0,13,255,0,0,2,135,0,0,180,102,0,0,32,0,0,0,40,0,0,0,86,0,0,0,49,0,0,0,48,0,0,0,48,0,0,0,44,0,0,0,32,0,0,0,87,0,0,0,111,0,0,0,114,0,0,0,108,0,0,0,100,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,68,97,105,32,77,97,107,97,105,45,77,117,114,97,32,40,98,111,111,116,108,101,103,44,32,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,68,101,118,105,108,32,67,114,97,115,104,32,45,32,78,97,120,97,116,32,80,105,110,98,97,108,108,0,0,0,0,0,78,65,77,45,49,57,55,53,32,40,78,71,77,45,48,48,49,41,40,78,71,72,45,48,48,49,41,0,0,0,0,0,84,104,114,101,101,32,87,111,110,100,101,114,115,32,40,119,111,110,100,101,114,32,51,32,57,49,48,53,49,51,32,101,116,99,41,0,0,0,0,0,109,100,95,102,117,110,110,103,97,109,101,117,0,0,0,0,80,97,108,101,116,116,101,32,49,0,0,0,0,0,0,0,67,82,73,32,126,32,83,101,103,97,0,0,0,0,0,0,101,99,111,102,103,104,116,114,104,0,0,0,0,0,0,0,66,111,109,98,101,114,32,77,97,110,0,0,0,0,0,0,110,117,109,56,0,0,0,0,70,117,110,32,39,78,32,71,97,109,101,115,32,40,69,117,114,111,41,0,0,0,0,0,109,100,95,102,117,110,110,103,97,109,101,0,0,0,0,0,118,100,99,95,100,97,116,97,91,105,93,0,0,0,0,0,110,111,108,111,97,100,45,115,97,118,101,0,0,0,0,0,83,76,79,84,45,62,118,111,108,117,109,101,0,0,0,0,109,99,117,95,99,111,105,110,97,103,101,95,105,110,105,116,0,0,0,0,0,0,0,0,84,67,48,49,48,48,83,67,78,67,116,114,108,91,48,93,0,0,0,0,0,0,0,0,103,108,71,101,110,86,101,114,116,101,120,65,114,114,97,121])
.concat([115,79,69,83,0,0,0,0,84,67,48,50,56,48,71,82,68,67,116,114,108,0,0,0,77,97,106,101,115,99,111,0,84,67,48,52,56,48,83,67,80,67,116,114,108,0,0,0,66,97,116,109,97,110,32,80,97,114,116,32,50,0,0,0,67,111,108,111,114,0,0,0,70,114,111,103,103,101,114,32,40,85,83,65,41,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,91,71,76,93,58,32,51,50,45,98,105,116,32,70,66,79,32,110,111,116,32,115,117,112,112,111,114,116,101,100,46,32,70,97,108,108,105,110,103,32,98,97,99,107,32,116,111,32,49,54,45,98,105,116,46,10,0,0,0,0,79,86,69,82,76,65,89,32,37,115,0,0,0,0,0,0,109,100,95,102,114,111,103,103,101,114,0,0,0,0,0,0,51,48,107,44,32,55,48,107,32,116,104,101,110,32,101,118,101,114,121,32,55,48,107,0,74,97,109,101,115,32,80,111,110,100,32,45,32,85,110,100,101,114,119,97,116,101,114,32,65,103,101,110,116,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,0,75,48,53,50,49,48,57,67,104,97,114,82,111,109,66,97,110,107,50,91,51,93,0,0,107,97,98,117,107,105,107,108,0,0,0,0,0,0,0,0,80,52,32,66,117,116,116,111,110,32,52,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,76,111,97,100,105,110,103,32,99,111,110,102,105,103,32,102,114,111,109,58,32,37,115,46,10,0,0,0,0,70,114,97,110,107,32,84,104,111,109,97,115,32,66,105,103,32,72,117,114,116,32,66,97,115,101,98,97,108,108,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,69,110,101,114,103,121,32,80,111,119,101,114,32,68,101,99,114,101,97,115,101,32,111,110,32,67,111,110,116,105,110,117,101,0,0,0,0,0,0,0,100,101,118,115,116,111,114,115,50,0,0,0,0,0,0,0,97,108,105,101,110,115,97,0,77,97,116,99,104,32,80,111,105,110,116,0,0,0,0,0,111,110,0,0,0,0,0,0,115,104,105,110,111,98,105,51,0,0,0,0,0,0,0,0,109,100,95,98,105,103,104,117,114,116,0,0,0,0,0,0,98,101,115,116,111,102,98,101,115,116,95,112,114,111,116,0,84,97,98,108,101,32,52,0,116,104,117,110,100,101,114,120,106,0,0,0,0,0,0,0,82,97,112,105,100,32,72,101,114,111,0,0,0,0,0,0,68,111,110,39,116,32,69,114,97,115,101,0,0,0,0,0,77,97,114,121,32,83,104,101,108,108,101,121,39,115,32,70,114,97,110,107,101,110,115,116,101,105,110,32,40,85,83,65,41,0,0,0,0,0,0,0,99,114,97,122,121,102,103,116,0,0,0,0,0,0,0,0,103,114,121,122,111,114,0,0,120,109,101,110,50,112,97,0,80,49,32,66,0,0,0,0,118,101,114,116,101,120,0,0,86,117,108,99,97,110,32,86,101,110,116,117,114,101,32,40,79,108,100,41,0,0,0,0,109,100,95,102,114,97,110,107,101,110,0,0,0,0,0,0,105,114,113,66,95,109,97,115,107,0,0,0,0,0,0,0,49,57,52,52,0,0,0,0,66,101,101,32,83,116,111,114,109,32,45,32,68,111,68,111,110,80,97,99,104,105,32,73,73,32,40,86,49,48,48,44,32,87,111,114,108,100,41,0,0,0,0,0,0,0,0,0,101,115,99,107,105,100,115,0,100,97,105,109,97,107,97,105,98,0,0,0,0,0,0,0,112,99,101,95,100,101,118,108,99,114,115,104,0,0,0,0,83,0,0,0,117,0,0,0,112,0,0,0,101,0,0,0,114,0,0,0,32,0,0,0,83,0,0,0,105,0,0,0,100,0,0,0,101,0,0,0,107,0,0,0,105,0,0,0,99,0,0,0,107,0,0,0,115,0,0,0,32,0,0,0,50,0,0,0,32,0,0,0,45,0,0,0,32,0,0,0,116,0,0,0,104,0,0,0,101,0,0,0,32,0,0,0,119,0,0,0,111,0,0,0,114,0,0,0,108,0,0,0,100,0,0,0,32,0,0,0,99,0,0,0,104,0,0,0,97,0,0,0,109,0,0,0,112,0,0,0,105,0,0,0,111,0,0,0,110,0,0,0,115,0,0,0,104,0,0,0,105,0,0,0,112,0,0,0,0,0,0,0,151,95,0,0,185,112,0,0,139,115,0,0,18,255,0,0,32,0,0,0,45,0,0,0,32,0,0,0,234,48,0,0,162,48,0,0,235,48,0,0,213,48,0,0,161,48,0,0,164,48,0,0,200,48,0,0,213,48,0,0,195,48,0,0,200,48,0,0,220,48,0,0,252,48,0,0,235,48,0,0,32,0,0,0,40,0,0,0,78,0,0,0,71,0,0,0,77,0,0,0,45,0,0,0,48,0,0,0,54,0,0,0,49,0,0,0,41,0,0,0,40,0,0,0,78,0,0,0,71,0,0,0,72,0,0,0,45,0,0,0,48,0,0,0,54,0,0,0,49,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,70,97,105,108,101,100,32,116,111,32,114,101,97,100,32,110,117,109,98,101,114,32,111,102,32,100,101,115,99,115,32,102,114,111,109,32,99,111,110,102,105,103,32,107,101,121,58,32,37,115,46,10,0,0,0,0,70,111,114,103,111,116,116,101,110,32,87,111,114,108,100,115,32,40,87,111,114,108,100,41,0,0,0,0,0,0,0,0,112,97,114,111,100,105,117,115,0,0,0,0,0,0,0,0,71,97,108,97,120,121,32,70,111,114,99,101,32,73,73,32,40,87,111,114,108,100,44,32,82,101,118,46,32,66,41,0,0,0,0,0,0,0,0,0,84,101,101,110,97,103,101,32,77,117,116,97,110,116,32,78,105,110,106,97,32,84,117,114,116,108,101,115,32,40,74,97,112,97,110,32,52,32,80,108,97,121,101,114,115,41,0,0,82,101,116,114,111,65,114,99,104,58,32,70,111,117,110,100,32,99,104,101,97,116,32,102,111,114,32,103,97,109,101,58,32,34,37,115,34,10,0,0,69,99,111,32,70,105,103,104,116,101,114,115,32,40,57,51,49,50,48,51,32,65,115,105,97,41,0,0,0,0,0,0,66,111,109,98,101,114,32,77,97,110,32,87,111,114,108,100,32,47,32,78,101,119,32,68,121,110,97,32,66,108,97,115,116,101,114,32,45,32,71,108,111,98,97,108,32,81,117,101,115,116,0,0,0,0,0,0,68,121,110,97,98,108,97,115,116,101,114,0,0,0,0,0,107,117,110,103,102,117,98,51,0,0,0,0,0,0,0,0,110,117,109,55,0,0,0,0,109,100,95,102,111,114,103,111,116,116,110,49,0,0,0,0,77,101,105,107,121,117,32,74,105,109,97,32,40,74,97,112,97,110,41,0,0,0,0,0,105,110,116,104,117,110,116,0,120,109,117,108,116,105,112,108,0,0,0,0,0,0,0,0,70,111,114,103,111,116,116,101,110,32,87,111,114,108,100,115,32,40,87,111,114,108,100,44,32,118,49,46,49,41,0,0,110,111,108,111,97,100,45,110,111,115,97,118,101,0,0,0,109,100,95,102,111,114,103,111,116,116,110,0,0,0,0,0,70,111,114,101,109,97,110,32,102,111,114,32,82,101,97,108,32,40,87,111,114,108,100,41,0,0,0,0,0,0,0,0,109,100,95,102,111,114,101,109,97,110,0,0,0,0,0,0,51,48,107,44,32,53,48,107,32,116,104,101,110,32,101,118,101,114,121,32,53,48,107,0,80,52,32,66,117,116,116,111,110,32,51,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,99,114,101,97,116,101,32,110,101,119,32,99,111,110,102,105,103,32,102,105,108,101,32,105,110,58,32,34,37,115,34,46,10,0,0,0,0,0,0,0,0,84,104,101,32,70,108,105,110,116,115,116,111,110,101,115,32,40,85,83,65,41,0,0,0,83,105,114,101,110,32,86,111,108,117,109,101,0,0,0,0,83,104,105,110,111,98,105,32,40,115,101,116,32,50,44,32,83,121,115,116,101,109,32,49,54,66,44,32,70,68,49,48,57,52,32,51,49,55,45,48,48,52,57,41,0,0,0,0,109,100,95,102,108,105,110,116,117,0,0,0,0,0,0,0,99,111,108,111,114,95,98,97,110,107,0,0,0,0,0,0,84,97,98,108,101,32,51,0,84,104,101,32,70,108,105,110,116,115,116,111,110,101,115,32,40,74,112,110,41,0,0,0,65,116,104,101,110,97,32,47,32,83,101,116,97,0,0,0,109,100,95,102,108,105,110,116,106,0,0,0,0,0,0,0,66,97,99,107,117,112,32,82,97,109,32,50,0,0,0,0,100,100,112,50,49,48,48,0,39,89,0,0,84,155,0,0,76,117,0,0,81,103,0,0,0,0,0,0,68,0,0,0,97,0,0,0,105,0,0,0,32,0,0,0,77,0,0,0,97,0,0,0,107,0,0,0,97,0,0,0,105,0,0,0,45,0,0,0,77,0,0,0,117,0,0,0,114,0,0,0,97,0,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,32,0,0,0,82,0,0,0,101,0,0,0,115,0,0,0,97,0,0,0,108,0,0,0,101,0,0,0,32,0,0,0,86,0,0,0,101,0,0,0,114,0,0,0,46,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,83,117,112,101,114,32,83,105,100,101,107,105,99,107,115,32,50,32,45,32,84,104,101,32,87,111,114,108,100,32,67,104,97,109,112,105,111,110,115,104,105,112,32,47,32,84,111,107,117,116,101,110,32,79,117,32,50,32,45,32,114,101,97,108,32,102,105,103,104,116,32,102,111,111,116,98,97,108,108,32,40,78,71,77,45,48,54,49,41,40,78,71,72,45,48,54,49,41,0,0,0,0,0,0,84,104,101,32,70,108,105,110,116,115,116,111,110,101,115,32,40,69,117,114,111,41,0,0,46,103,108,115,108,112,0,0,109,100,95,103,102,111,114,99,101,50,0,0,0,0,0,0,101,99,111,102,103,104,116,114,97,0,0,0,0,0,0,0,54,32,77,105,110,117,116,101,115,0,0,0,0,0,0,0,110,117,109,54,0,0,0,0,109,100,95,102,108,105,110,116,0,0,0,0,0,0,0,0,110,67,97,118,101,89,79,102,102,115,101,116,0,0,0,0,102,100,49,48,57,52,95,115,116,97,116,101,0,0,0,0,70,108,105,110,107,32,40,69,117,114,111,41,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,68,105,115,99,111,110,110,101,99,116,32,100,101,118,105,99,101,32,102,114,111,109,32,97,32,118,97,108,105,100,32,112,111,114,116,46,10,0,0,0,0,0,0,76,111,97,100,101,100,32,115,116,97,116,101,32,102,114,111,109,32,115,108,111,116,32,35,37,117,46,0,0,0,0,0,109,100,95,102,108,105,110,107,0,0,0,0,0,0,0,0,98,97,116,109,97,110,50,0,117,108,116,114,97,109,97,110,0,0,0,0,0,0,0,0,83,99,114,97,109,98,108,101,80,114,111,116,101,99,116,105,111,110,82,101,115,117,108,116,0,0,0,0,0,0,0,0,70,108,105,99,107,121,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,109,100,95,102,108,105,99,107,121,0,0,0,0,0,0,0,71,97,108,76,102,111,66,105,116,0,0,0,0,0,0,0,119,104,112,0,0,0,0,0,80,52,32,66,117,116,116,111,110,32,50,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,67,114,101,97,116,101,100,32,110,101,119,32,99,111,110,102,105,103,32,102,105,108,101,32,105,110,58,32,34,37,115,34,46,10,0,0,70,108,97,115,104,32,80,111,105,110,116,32,40,74,112,110,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,80,108,97,121,101,114,32,38,32,69,110,101,109,121,32,69,110,101,114,103,121,0,0,0,68,97,109,97,103,101,32,67,108,101,97,114,101,100,32,97,116,32,67,111,110,116,105,110,117,101,0,0,0,0,0,0,78,105,116,114,111,115,0,0,85,112,32,84,111,32,76,101,118,101,108,32,51,0,0,0,115,104,105,110,111,98,105,0,109,100,95,102,108,97,115,104,112,0,0,0,0,0,0,0,77,111,118,105,110,103,32,80,105,116,99,104,0,0,0,0,84,97,98,108,101,32,50,0,114,97,112,104,101,114,111,0,49,32,99,111,105,110,32,54,32,99,114,101,100,105,116,0,70,108,97,115,104,98,97,99,107,32,45,32,84,104,101,32,81,117,101,115,116,32,102,111,114,32,73,100,101,110,116,105,116,121,32,40,85,83,65,44,32,65,108,116,41,0,0,0,67,97,108,105,98,101,114,32,53,48,0,0,0,0,0,0,80,49,32,65,0,0,0,0,74,117,109,112,32,83,104,111,116,32,69,110,103,105,110,101,101,114,105,110,103,32,83,97,109,112,108,101,0,0,0,0,109,100,95,102,108,97,115,104,98,117,49,0,0,0,0,0,66,0,0,0,101,0,0,0,101,0,0,0,32,0,0,0,83,0,0,0,116,0,0,0,111,0,0,0,114,0,0,0,109,0,0,0,32,0,0,0,45,0,0,0,32,0,0,0,68,0,0,0,111,0,0,0,68,0,0,0,111,0,0,0,110,0,0,0,80,0,0,0,97,0,0,0,116,0,0,0,99,0,0,0,104,0,0,0,105,0,0,0,32,0,0,0,73,0,0,0,73,0,0,0,0,0,0,0,18,96,0,0,150,153,0,0,134,152,0,0,2,135,0,0,13,255,0,0,2,135,0,0,180,102,0,0,32,0,0,0,40,0,0,0,86,0,0,0,49,0,0,0,48,0,0,0,49,0,0,0,44,0,0,0,32,0,0,0,87,0,0,0,111,0,0,0,114,0,0,0,108,0,0,0,100,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,68,97,105,32,77,97,107,97,105,45,77,117,114,97,32,40,74,97,112,97,110,32,82,101,115,97,108,101,32,86,101,114,46,41,0,0,0,0,0,0,68,101,116,97,110,97,33,33,32,84,119,105,110,98,101,101,0,0,0,0,0,0,0,0,70,108,97,115,104,98,97,99,107,32,45,32,84,104,101,32,81,117,101,115,116,32,102,111,114,32,73,100,101,110,116,105,116,121,32,40,85,83,65,41,0,0,0,0,0,0,0,0,69,120,45,77,117,116,97,110,116,115,32,40,69,117,114,111,44,32,85,83,65,41,0,0,69,99,111,32,70,105,103,104,116,101,114,115,32,40,57,51,49,50,48,51,32,101,116,99,41,0,0,0,0,0,0,0,53,32,77,105,110,117,116,101,115,0,0,0,0,0,0,0,52,32,80,108,97,121,101,114,32,85,112,114,105,103,104,116,32,66,0,0,0,0,0,0,110,117,109,53,0,0,0,0,109,100,95,102,108,97,115,104,98,117,0,0,0,0,0,0,70,108,97,115,104,98,97,99,107,32,40,74,112,110,41,0,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,110,110,101,99,116,32,109,111,117,115,101,32,116,111,32,97,32,118,97,108,105,100,32,112,111,114,116,46,10,0,0,0,0,68,111,119,110,32,68,45,112,97,100,0,0,0,0,0,0,109,100,95,102,108,97,115,104,98,106,0,0,0,0,0,0,98,111,111,116,108,101,103,32,40,80,83,86,32,83,46,65,46,41,0,0,0,0,0,0,70,108,97,115,104,98,97,99,107,32,40,69,117,114,111,44,32,82,101,118,46,32,65,41,0,0,0,0,0,0,0,0,109,100,95,102,108,97,115,104,98,0,0,0,0,0,0,0,73,110,102,105,110,105,116,101,32,76,105,118,101,115,32,40,67,104,101,97,116,0,0,0,65,105,99,111,109,0,0,0,80,52,32,66,117,116,116,111,110,32,49,0,0,0,0,0,110,117,108,108,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,85,115,105,110,103,32,115,107,101,108,101,116,111,110,32,99,111,110,102,105,103,32,34,37,115,34,32,97,115,32,98,97,115,101,32,102,111,114,32,97,32,110,101,119,32,99,111,110,102,105,103,32,102,105,108,101,46,10,0,0,51,54,48,32,68,101,103,114,101,101,0,0,0,0,0,0,55,48,32,115,101,99,111,110,100,115,0,0,0,0,0,0,85,112,32,84,111,32,76,101,118,101,108,32,50,0,0,0,115,104,105,110,111,98,105,50,0,0,0,0,0,0,0,0,83,97,109,101,33,32,83,97,109,101,33,32,83,97,109,101,33,32,40,74,112,110,41,0,0,0,0,0,0,0,0,0,77,111,118,105,110,103,32,82,111,108,108,0,0,0,0,0,71,101,110,86,68,80,32,86,83,82,65,77,0,0,0,0,115,111,117,110,100,108,97,116,99,104,51,0,0,0,0,0,84,97,98,108,101,32,49,0,83,112,97,99,101,32,66,97,116,116,108,101,32,83,104,105,112,32,71,111,109,111,114,114,97,104,0,0,0,0,0,0,49,32,99,111,105,110,32,53,32,99,114,101,100,105,116,0,109,100,95,115,97,109,101,115,97,109,101,0,0,0,0,0,99,97,108,105,98,114,53,48,0,0,0,0,0,0,0,0,106,117,109,112,115,104,111,116,112,0,0,0,0,0,0,0,98,111,116,116,111,109,57,0,78,97,109,99,111,32,40,84,97,105,116,111,32,108,105,99,101,110,115,101,41,0,0,0,70,105,114,101,32,83,104,97,114,107,32,40,85,83,65,44,32,65,108,116,41,0,0,0,66,101,101,32,83,116,111,114,109,32,45,32,68,111,68,111,110,80,97,99,104,105,32,73,73,32,40,86,49,48,49,44,32,87,111,114,108,100,41,0,0,0,0,0,0,0,0,0,100,97,105,109,97,107,97,105,114,0,0,0,0,0,0,0,112,99,101,95,116,119,105,110,98,101,101,0,0,0,0,0,83,0,0,0,97,0,0,0,118,0,0,0,97,0,0,0,103,0,0,0,101,0,0,0,32,0,0,0,82,0,0,0,101,0,0,0,105,0,0,0,103,0,0,0,110,0,0,0,0,0,0,0,168,152,0,0,242,150,0,0,217,158,0,0,58,121,0,0,50,147,0,0,32,0,0,0,45,0,0,0,32,0,0,0,60,104,0,0,216,149,0,0,117,82,0,0,22,78,0,0,0,0,0,0,0,0,0,0,0,0,0,0,109,100,95,102,105,114,101,115,104,114,107,117,49,0,0,0,109,100,95,101,120,109,117,116,97,110,116,0,0,0,0,0,68,114,101,97,109,119,111,114,107,115,32,71,97,109,101,115,0,0,0,0,0,0,0,0,80,101,114,105,111,100,32,76,101,110,103,116,104,0,0,0,52,32,80,108,97,121,101,114,32,85,112,114,105,103,104,116,32,65,0,0,0,0,0,0,99,110,105,110,106,97,98,108,0,0,0,0,0,0,0,0,110,117,109,52,0,0,0,0,115,105,110,99,0,0,0,0,70,105,114,101,32,83,104,97,114,107,32,40,85,83,65,41,0,0,0,0,0,0,0,0,99,104,105,112,45,62,97,100,100,114,101,115,115,0,0,0,112,97,114,115,101,95,105,110,112,117,116,40,41,0,0,0,99,104,97,114,108,105,101,110,0,0,0,0,0,0,0,0,109,100,95,102,105,114,101,115,104,114,107,117,0,0,0,0,80,97,106,97,114,111,32,100,101,108,32,69,115,112,97,99,105,111,32,40,83,112,97,110,105,115,104,32,98,111,111,116,108,101,103,32,111,102,32,85,110,105,87,97,114,32,83,41,0,0,0,0,0,0,0,0,82,101,115,116,111,114,101,32,76,105,102,101,32,77,101,116,101,114,0,0,0,0,0,0,70,105,114,101,32,83,104,97,114,107,32,40,69,117,114,111,41,0,0,0,0,0,0,0,109,100,95,102,105,114,101,115,104,114,107,0,0,0,0,0,73,110,118,117,108,110,101,114,97,98,105,108,105,116,121,32,40,67,104,101,97,116,0,0,80,52,32,85,115,101,0,0,70,105,114,101,32,77,117,115,116,97,110,103,32,40,74,112,110,41,0,0,0,0,0,0,114,101,116,114,111,97,114,99,104,46,99,102,103,0,0,0,50,55,48,32,68,101,103,114,101,101,0,0,0,0,0,0,54,48,32,115,101,99,111,110,100,115,0,0,0,0,0,0,50,53,48,48,0,0,0,0,68,101,102,101,110,115,101,32,40,83,121,115,116,101,109,32,49,54,66,44,32,70,68,49,48,56,57,65,32,51,49,55,45,48,48,50,56,41,0,0,109,100,95,102,105,114,101,109,117,115,116,0,0,0,0,0,115,111,117,110,100,108,97,116,99,104,50,0,0,0,0,0,76,117,99,107,121,32,67,104,97,110,99,101,0,0,0,0,115,98,115,103,111,109,111,0,49,32,99,111,105,110,32,51,32,99,114,101,100,105,116,0,70,105,110,97,108,32,90,111,110,101,32,40,85,83,65,41,32,126,32,70,90,32,83,101,110,107,105,32,65,120,105,115,32,40,74,112,110,41,0,0,66,97,108,108,121,32,77,105,100,119,97,121,0,0,0,0,109,100,95,102,122,111,110,101,0,0,0,0,0,0,0,0,100,100,112,50,49,48,49,0,39,89,0,0,84,155,0,0,76,117,0,0,81,103,0,0,0,0,0,0,68,0,0,0,97,0,0,0,105,0,0,0,32,0,0,0,77,0,0,0,97,0,0,0,107,0,0,0,97,0,0,0,105,0,0,0,45,0,0,0,77,0,0,0,117,0,0,0,114,0,0,0,97,0,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,101,101,112,32,66,108,117,101,32,45,32,75,97,105,116,101,105,32,83,104,105,110,119,97,0,0,0,0,0,0,0,83,97,118,97,103,101,32,82,101,105,103,110,32,47,32,70,117,39,117,110,32,77,111,107,117,115,104,105,114,111,107,117,32,45,32,107,97,107,117,116,111,117,32,115,111,117,115,101,105,0,0,0,0,0,0,0,68,101,115,101,114,116,32,65,115,115,97,117,108,116,32,40,85,83,32,52,32,80,108,97,121,101,114,115,41,0,0,0,70,105,103,104,116,105,110,103,32,77,97,115,116,101,114,115,32,40,74,112,110,44,32,75,111,114,41,0,0,0,0,0,104,101,120,105,111,110,0,0,69,118,97,110,100,101,114,32,72,111,108,121,102,105,101,108,100,39,115,32,39,82,101,97,108,32,68,101,97,108,39,32,66,111,120,105,110,103,32,40,87,111,114,108,100,41,0,0,101,99,111,102,103,104,116,114,0,0,0,0,0,0,0,0,50,32,80,108,97,121,101,114,32,85,112,114,105,103,104,116,0,0,0,0,0,0,0,0,110,117,109,51,0,0,0,0,109,100,95,102,105,103,104,116,109,97,115,106,0,0,0,0,75,48,53,49,55,51,51,32,82,97,109,0,0,0,0,0,70,105,103,104,116,105,110,103,32,77,97,115,116,101,114,115,32,40,85,83,65,41,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,110,110,101,99,116,32,100,117,97,108,97,110,97,108,111,103,32,116,111,32,97,32,118,97,108,105,100,32,112,111,114,116,46,10,0,0,0,0,0,0,0,67,104,101,108,110,111,118,32,45,32,65,116,111,109,105,99,32,82,117,110,110,101,114,32,40,87,111,114,108,100,41,0,0,0,0,0,0,0,0,0,109,100,95,102,105,103,104,116,109,97,115,0,0,0,0,0,49,57,57,48,63,0,0,0,46,116,103,97,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,80,73,88,69,76,95,70,79,82,77,65,84,58,32,82,71,66,53,54,53,46,10,0,0,0,112,97,106,97,114,111,101,115,0,0,0,0,0,0,0,0,70,73,70,65,32,57,56,32,45,32,82,111,97,100,32,116,111,32,87,111,114,108,100,32,67,117,112,32,40,69,117,114,111,41,0,0,0,0,0,0,67,111,98,114,97,45,67,111,109,109,97,110,100,32,40,87,111,114,108,100,32,114,101,118,105,115,105,111,110,32,53,41,0,0,0,0,0,0,0,0,112,117,108,115,116,97,114,0,80,52,32,83,101,108,101,99,116,0,0,0,0,0,0,0,109,100,95,102,105,102,97,57,56,0,0,0,0,0,0,0,47,101,116,99,0,0,0,0,49,32,67,111,105,110,32,32,49,32,67,114,101,100,105,116,0,0,0,0,0,0,0,0,83,116,101,101,114,105,110,103,32,82,97,100,105,117,115,0,53,48,32,115,101,99,111,110,100,115,0,0,0,0,0,0,50,48,48,48,0,0,0,0,70,73,70,65,32,83,111,99,99,101,114,32,50,48,48,48,32,71,111,108,100,32,69,100,105,116,105,111,110,32,40,80,105,114,97,116,101,41,0,0,100,101,102,101,110,115,101,0,98,105,116,109,97,112,0,0,85,112,47,68,111,119,110,0,50,32,67,114,101,100,105,116,115,32,116,111,32,115,116,97,114,116,0,0,0,0,0,0,66,105,111,45,115,104,105,112,32,80,97,108,97,100,105,110,0,0,0,0,0,0,0,0,109,117,116,97,110,116,102,95,112,111,114,116,95,101,56,95,104,97,99,107,0,0,0,0,49,32,99,111,105,110,32,50,32,99,114,101,100,105,116,0,109,100,95,102,105,102,97,50,107,0,0,0,0,0,0,0,74,117,109,112,32,83,104,111,116,0,0,0,0,0,0,0,70,73,70,65,32,83,111,99,99,101,114,32,57,57,32,40,80,105,114,97,116,101,41,0,0,0,0,0,0,0,0,0,83,101,108,101,99,116,32,71,97,109,101,32,51,0,0,0,82,111,116,97,114,121,50,79,108,100,86,97,108,0,0,0,82,101,116,114,111,65,114,99,104,58,32,85,115,105,110,103,32,102,111,110,116,32,114,101,110,100,101,114,105,110,103,32,98,97,99,107,101,110,100,58,32,37,115,46,10,0,0,0,66,0,0,0,101,0,0,0,101,0,0,0,32,0,0,0,83,0,0,0,116,0,0,0,111,0,0,0,114,0,0,0,109,0,0,0,32,0,0,0,45,0,0,0,32,0,0,0,68,0,0,0,111,0,0,0,68,0,0,0,111,0,0,0,110,0,0,0,80,0,0,0,97,0,0,0,116,0,0,0,99,0,0,0,104,0,0,0,105,0,0,0,32,0,0,0,73,0,0,0,73,0,0,0,0,0,0,0,18,96,0,0,150,153,0,0,134,152,0,0,2,135,0,0,13,255,0,0,2,135,0,0,180,102,0,0,32,0,0,0,40,0,0,0,86,0,0,0,49,0,0,0,48,0,0,0,50,0,0,0,44,0,0,0,32,0,0,0,87,0,0,0,111,0,0,0,114,0,0,0,108,0,0,0,100,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,68,97,105,32,77,97,107,97,105,45,77,117,114,97,32,40,74,97,112,97,110,41,0,0,112,99,101,95,100,101,101,112,98,108,117,101,0,0,0,0,109,100,95,102,105,102,97,57,57,0,0,0,0,0,0,0,109,100,95,101,118,97,110,100,101,114,0,0,0,0,0,0,86,97,109,112,105,114,101,32,45,32,116,104,101,32,110,105,103,104,116,32,119,97,114,114,105,111,114,115,32,40,57,52,48,54,51,48,32,74,97,112,97,110,41,0,0,0,0,0,114,105,100,104,101,114,111,0,110,117,109,50,0,0,0,0,100,114,118,110,97,109,101,58,32,37,115,10,0,0,0,0,70,73,70,65,32,83,111,99,99,101,114,32,57,54,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,65,82,77,55,95,73,67,79,85,78,84,0,0,0,0,0,87,111,108,102,32,70,97,110,103,32,45,75,117,104,103,97,32,50,48,48,49,45,32,40,74,97,112,97,110,41,0,0,109,100,95,102,105,102,97,57,54,0,0,0,0,0,0,0,104,115,58,102,118,83,58,109,58,112,52,106,74,65,58,103,58,98,58,99,58,66,58,89,58,90,58,85,58,68,78,58,88,58,80,58,82,58,77,58,0,0,0,0,0,0,0,0,82,45,62,112,111,114,116,52,95,100,100,114,0,0,0,0,49,57,56,52,0,0,0,0,65,100,118,101,114,116,105,115,101,32,115,111,117,110,100,0,65,114,109,101,100,32,80,111,108,105,99,101,32,66,97,116,114,105,100,101,114,32,45,32,65,32,86,101,114,115,105,111,110,32,40,74,97,112,97,110,41,32,40,77,111,110,32,68,101,99,32,50,50,32,49,57,57,55,41,0,0,0,0,0,70,105,120,69,105,103,104,116,32,40,84,97,105,119,97,110,44,32,84,97,105,116,111,32,108,105,99,101,110,115,101,41,0,0,0,0,0,0,0,0,70,117,116,98,111,108,32,65,114,103,101,110,116,105,110,111,32,57,56,32,45,32,80,97,115,105,111,110,32,100,101,32,77,117,108,116,105,116,117,100,101,115,32,40,80,105,114,97,116,101,41,0,0,0,0,0,49,57,56,54,0,0,0,0,68,101,109,111,32,83,111,117,110,100,115,0,0,0,0,0,98,111,111,116,108,101,103,32,40,69,108,101,99,116,114,111,103,97,109,101,32,83,46,65,46,41,0,0,0,0,0,0,105,114,113,95,116,105,109,101,114,0,0,0,0,0,0,0,109,100,95,102,117,116,98,111,108,0,0,0,0,0,0,0,66,97,116,116,108,101,32,71,97,114,101,103,103,97,32,40,84,97,105,119,97,110,32,47,32,71,101,114,109,97,110,121,41,32,40,84,104,117,32,70,101,98,32,49,32,49,57,57,54,41,0,0,0,0,0,0,171,155,0,0,33,0,0,0,171,155,0,0,33,0,0,0,171,155,0,0,33,0,0,0,0,0,0,0,83,0,0,0,97,0,0,0,109,0,0,0,101,0,0,0,33,0,0,0,32,0,0,0,83,0,0,0,97,0,0,0,109,0,0,0,101,0,0,0,33,0,0,0,32,0,0,0,83,0,0,0,97,0,0,0,109,0,0,0,101,0,0,0,33,0,0,0,32,0,0,0,40,0,0,0,50,0,0,0,32,0,0,0,112,0,0,0,108,0,0,0,97,0,0,0,121,0,0,0,101,0,0,0,114,0,0,0,32,0,0,0,97,0,0,0,108,0,0,0,116,0,0,0,101,0,0,0,114,0,0,0,110,0,0,0,97,0,0,0,116,0,0,0,105,0,0,0,110,0,0,0,103,0,0,0,32,0,0,0,118,0,0,0,101,0,0,0,114,0,0,0,46,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,70,73,70,65,32,73,110,116,101,114,110,97,116,105,111,110,97,108,32,83,111,99,99,101,114,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,83,97,117,114,117,115,0,0,80,52,32,80,105,110,0,0,109,100,95,102,105,102,97,0,46,114,101,116,114,111,97,114,99,104,46,99,102,103,0,0,100,105,115,97,98,108,101,95,99,112,117,91,49,93,0,0,50,32,67,111,105,110,115,32,49,32,67,114,101,100,105,116,0,0,0,0,0,0,0,0,68,101,97,100,32,67,111,110,110,101,99,116,105,111,110,32,40,87,111,114,108,100,41,0,0,0,0,0,0,0,0,0,52,48,32,115,101,99,111,110,100,115,0,0,0,0,0,0,49,53,48,48,0,0,0,0,108,107,97,103,101,98,51,0,83,68,73,32,45,32,83,116,114,97,116,101,103,105,99,32,68,101,102,101,110,115,101,32,73,110,105,116,105,97,116,105,118,101,32,40,98,111,111,116,108,101,103,41,0,0,0,0,48,49,48,49,0,0,0,0,70,105,100,111,32,68,105,100,111,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,49,32,69,97,115,121,0,0,65,114,107,97,110,111,105,100,32,45,32,82,101,118,101,110,103,101,32,111,102,32,68,79,72,32,40,87,111,114,108,100,41,0,0,0,0,0,0,0,98,105,111,115,104,105,112,0,68,105,115,99,111,117,110,116,32,84,111,32,67,111,110,116,105,110,117,101,0,0,0,0,65,114,107,97,110,111,105,100,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,109,100,95,102,105,100,111,100,105,100,111,0,0,0,0,0,83,101,116,97,32,40,84,97,105,116,111,32,108,105,99,101,110,115,101,41,0,0,0,0,78,97,115,116,97,114,32,40,87,111,114,108,100,41,0,0,118,100,99,95,99,117,114,108,105,110,101,91,105,93,0,0,66,97,116,116,108,101,32,83,104,97,114,107,32,40,74,97,112,97,110,41,0,0,0,0,99,117,114,114,101,110,116,95,114,111,117,110,100,0,0,0,83,101,108,101,99,116,32,71,97,109,101,32,50,0,0,0,82,111,116,97,114,121,50,0,72,101,97,100,45,79,110,32,83,111,99,99,101,114,32,40,85,83,65,41,0,0,0,0,112,97,108,100,109,97,95,115,111,117,114,99,101,0,0,0,79,112,101,114,97,116,105,111,110,32,87,111,108,102,32,40,87,111,114,108,100,44,32,115,101,116,32,49,41,0,0,0,67,97,100,97,115,104,32,40,70,114,97,110,99,101,41,0,0,0,0,0,0,0,0,0,66,101,101,32,83,116,111,114,109,32,45,32,68,111,68,111,110,80,97,99,104,105,32,73,73,32,40,86,49,48,50,44,32,87,111,114,108,100,41,0,0,0,0,0,0,0,0,0,115,99,111,110,116,114,97,0,100,97,105,109,97,107,97,105,0,0,0,0,0,0,0,0,66,46,83,46,83,46,0,0,109,100,95,104,101,97,100,111,110,0,0,0,0,0,0,0,85,170,90,0,0,0,0,0,84,104,101,32,78,105,110,106,97,32,87,97,114,114,105,111,114,115,32,40,74,97,112,97,110,41,0,0,0,0,0,0,69,83,87,65,84,32,45,32,67,105,116,121,32,85,110,100,101,114,32,83,105,101,103,101,32,40,69,117,114,111,44,32,85,83,65,44,32,82,101,118,46,32,65,41,0,0,0,0,118,97,109,112,106,114,49,0,115,104,97,110,103,111,110,0,78,101,119,32,68,121,110,97,32,66,108,97,115,116,101,114,32,71,108,111,98,97,108,32,81,117,101,115,116,0,0,0,110,117,109,49,0,0,0,0,85,46,83,46,32,71,111,108,100,0,0,0,0,0,0,0,97,108,116,98,101,97,115,116,0,0,0,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,73,32,50,110,100,32,73,109,112,97,99,116,58,32,71,105,97,110,116,32,65,116,116,97,99,107,32,40,74,97,112,97,110,32,57,55,48,57,51,48,41,0,0,0,0,0,0,83,121,115,116,101,109,49,54,84,105,108,101,66,97,110,107,115,0,0,0,0,0,0,0,49,67,32,49,67,0,0,0,70,101,118,101,114,32,80,105,116,99,104,32,83,111,99,99,101,114,32,40,69,117,114,111,41,0,0,0,0,0,0,0,102,101,97,116,117,114,101,115,0,0,0,0,0,0,0,0,66,117,108,108,102,105,103,104,116,32,40,51,49,53,45,53,48,54,53,41,0,0,0,0,68,114,118,79,107,105,66,97,110,107,50,0,0,0,0,0,112,100,114,105,102,116,0,0,37,108,108,117,0,0,0,0,109,100,95,102,101,118,101,114,112,105,116,0,0,0,0,0,103,112,114,105,100,101,114,106,0,0,0,0,0,0,0,0,49,32,67,111,105,110,32,50,32,67,114,101,100,105,116,115,32,0,0,0,0,0,0,0,65,116,97,113,117,101,32,83,105,100,101,114,97,108,32,40,83,112,97,110,105,115,104,32,98,111,111,116,108,101,103,32,111,102,32,85,110,105,87,97,114,32,83,41,0,0,0,0,86,100,112,83,99,114,111,108,108,72,101,105,103,104,116,0,105,114,113,95,109,97,115,107,0,0,0,0,0,0,0,0,70,101,114,114,97,114,105,32,71,114,97,110,100,32,80,114,105,120,32,67,104,97,108,108,101,110,103,101,32,40,85,83,65,41,0,0,0,0,0,0,72,97,110,103,45,79,110,0,0,0,0,0,0,0,0,0,66,46,67,46,32,75,105,100,32,47,32,66,111,110,107,39,115,32,65,100,118,101,110,116,117,114,101,32,47,32,75,121,117,107,121,111,107,117,33,33,32,80,67,32,71,101,110,106,105,110,0,0,0,0,0,0,69,83,68,32,47,32,70,117,117,107,105,0,0,0,0,0,109,100,95,102,101,114,114,97,114,105,117,0,0,0,0,0,52,67,32,49,67,0,0,0,118,105,100,101,111,95,102,117,108,108,115,99,114,101,101,110,95,121,0,0,0,0,0,0,80,52,32,74,117,109,112,0,70,101,114,114,97,114,105,32,71,114,97,110,100,32,80,114,105,120,32,67,104,97,108,108,101,110,103,101,32,40,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,0,0,51,47,53,0,0,0,0,0,112,108,101,103,101,110,100,115,106,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,76,111,111,107,105,110,103,32,102,111,114,32,99,111,110,102,105,103,32,105,110,58,32,34,37,115,34,46,10,0,0,0,0,0,0,0,0,68,105,112,32,51,0,0,0,98,103,49,115,99,114,111,108,108,120,0,0,0,0,0,0,51,32,67,111,105,110,115,32,49,32,67,114,101,100,105,116,0,0,0,0,0,0,0,0,66,108,111,111,100,32,67,111,108,111,117,114,0,0,0,0,73,110,105,116,105,97,108,32,84,105,109,101,0,0,0,0,53,48,48,0,0,0,0,0,83,116,101,114,101,111,0,0,115,100,105,98,108,0,0,0,109,100,95,102,101,114,114,97,114,105,112,0,0,0,0,0,80,108,97,121,32,77,111,100,101,0,0,0,0,0,0,0,83,46,83,46,32,77,105,115,115,105,111,110,0,0,0,0,75,111,117,116,101,116,115,117,32,89,111,117,115,97,105,32,83,116,114,97,104,108,32,40,74,97,112,97,110,32,115,101,116,32,50,41,0,0,0,0,82,97,105,100,101,110,32,40,75,111,114,101,97,41,0,0,80,91,0,0,178,128,0,0,102,48,0,0,175,48,0,0,164,48,0,0,186,48,0,0,32,0,0,0,222,48,0,0,164,48,0,0,32,0,0,0,168,48,0,0,243,48,0,0,184,48,0,0,167,48,0,0,235,48,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,75,0,0,0,111,0,0,0,115,0,0,0,111,0,0,0,100,0,0,0,97,0,0,0,116,0,0,0,101,0,0,0,32,0,0,0,81,0,0,0,117,0,0,0,105,0,0,0,122,0,0,0,32,0,0,0,77,0,0,0,121,0,0,0,32,0,0,0,65,0,0,0,110,0,0,0,103,0,0,0,101,0,0,0,108,0,0,0,0,0,0,0,0,0,0,0,70,0,0,0,233,0,0,0,114,0,0,0,105,0,0,0,97,0,0,0,115,0,0,0,32,0,0,0,70,0,0,0,114,0,0,0,117,0,0,0,115,0,0,0,116,0,0,0,114,0,0,0,97,0,0,0,100,0,0,0,97,0,0,0,115,0,0,0,32,0,0,0,100,0,0,0,111,0,0,0,32,0,0,0,80,0,0,0,105,0,0,0,99,0,0,0,97,0,0,0,45,0,0,0,80,0,0,0,97,0,0,0,117,0,0,0,32,0,0,0,40,0,0,0,66,0,0,0,114,0,0,0,97,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,119,105,110,32,69,97,103,108,101,32,45,32,82,101,118,101,110,103,101,32,74,111,101,39,115,32,66,114,111,116,104,101,114,0,0,0,0,0,0,54,32,67,114,101,100,105,116,115,0,0,0,0,0,0,0,35,105,110,99,108,117,100,101,32,34,37,115,34,10,0,0,106,117,109,112,115,104,111,116,0,0,0,0,0,0,0,0,83,101,108,101,99,116,32,71,97,109,101,32,49,0,0,0,114,121,117,107,101,110,100,110,97,0,0,0,0,0,0,0,82,111,116,97,114,121,49,79,108,100,86,97,108,0,0,0,70,101,114,105,97,115,32,70,114,117,115,116,114,97,100,97,115,32,100,111,32,80,105,99,97,45,80,97,117,32,40,66,114,97,41,0,0,0,0,0,87,87,70,32,87,114,101,115,116,108,101,70,101,115,116,32,40,75,111,114,101,97,41,0,0,0,0,0,0,0,0,0,100,100,112,50,0,0,0,0,71,104,111,117,108,115,39,110,32,71,104,111,115,116,115,32,40,85,83,41,0,0,0,0,68,101,97,100,32,77,111,111,110,32,45,32,84,115,117,107,105,32,83,101,107,97,105,32,110,111,32,65,107,117,109,117,0,0,0,0,0,0,0,0,70,0,0,0,97,0,0,0,116,0,0,0,97,0,0,0,108,0,0,0,32,0,0,0,70,0,0,0,117,0,0,0,114,0,0,0,121,0,0,0,32,0,0,0,83,0,0,0,112,0,0,0,101,0,0,0,99,0,0,0,105,0,0,0,97,0,0,0,108,0,0,0,0,0,0,0,19,153,0,0,252,114,0,0,29,79,0,0,172,138,0,0,32,0,0,0,83,0,0,0,112,0,0,0,101,0,0,0,99,0,0,0,105,0,0,0,97,0,0,0,108,0,0,0,32,0,0,0,40,0,0,0,115,0,0,0,101,0,0,0,116,0,0,0,32,0,0,0,50,0,0,0,41,0,0,0,40,0,0,0,78,0,0,0,71,0,0,0,77,0,0,0,45,0,0,0,48,0,0,0,53,0,0,0,56,0,0,0,41,0,0,0,40,0,0,0,78,0,0,0,71,0,0,0,72,0,0,0,45,0,0,0,48,0,0,0,53,0,0,0,56,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,115,113,117,97,115,104,0,0,109,100,95,102,101,114,105,97,115,0,0,0,0,0,0,0,80,0,0,0,114,0,0,0,101,0,0,0,116,0,0,0,116,0,0,0,121,0,0,0,32,0,0,0,83,0,0,0,111,0,0,0,108,0,0,0,100,0,0,0,105,0,0,0,101,0,0,0,114,0,0,0,32,0,0,0,83,0,0,0,97,0,0,0,105,0,0,0,108,0,0,0,111,0,0,0,114,0,0,0,32,0,0,0,77,0,0,0,111,0,0,0,111,0,0,0,110,0,0,0,0,0,0,0,142,127,0,0,17,92,0,0,115,89,0,0,38,98,0,0,235,88,0,0,32,0,0,0,187,48,0,0,252,48,0,0,233,48,0,0,252,48,0,0,224,48,0,0,252,48,0,0,243,48,0,0,32,0,0,0,40,0,0,0,118,0,0,0,101,0,0,0,114,0,0,0,46,0,0,0,32,0,0,0,57,0,0,0,53,0,0,0,47,0,0,0,48,0,0,0,51,0,0,0,47,0,0,0,50,0,0,0,50,0,0,0,66,0,0,0,44,0,0,0,32,0,0,0,75,0,0,0,111,0,0,0,114,0,0,0,101,0,0,0,97,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,109,100,95,101,115,119,97,116,0,0,0,0,0,0,0,0,86,97,109,112,105,114,101,32,45,32,116,104,101,32,110,105,103,104,116,32,119,97,114,114,105,111,114,115,32,40,57,52,48,55,48,53,32,74,97,112,97,110,44,32,97,108,116,41,0,0,0,0,0,0,0,0,110,111,115,116,107,0,0,0,66,111,109,98,101,114,32,77,97,110,32,87,111,114,108,100,0,0,0,0,0,0,0,0,110,117,109,48,0,0,0,0,70,101,110,103,32,83,104,101,110,32,89,105,110,103,32,74,105,101,32,90,104,117,97,110,32,40,67,104,105,44,32,65,108,116,63,41,0,0,0,0,115,112,105,110,108,98,114,107,0,0,0,0,0,0,0,0,109,111,103,117,114,97,0,0,99,116,114,105,98,101,49,0,109,100,95,102,101,110,103,115])
.concat([104,101,110,97,0,0,0,0,100,101,116,97,99,104,0,0,100,114,103,110,117,110,105,116,0,0,0,0,0,0,0,0,150,153,0,0,24,152,0,0,2,135,0,0,32,0,0,0,68,0,0,0,111,0,0,0,110,0,0,0,80,0,0,0,97,0,0,0,99,0,0,0,104,0,0,0,105,0,0,0,32,0,0,0,40,0,0,0,72,0,0,0,111,0,0,0,110,0,0,0,103,0,0,0,32,0,0,0,75,0,0,0,111,0,0,0,110,0,0,0,103,0,0,0,44,0,0,0,32,0,0,0,118,0,0,0,101,0,0,0,114,0,0,0,46,0,0,0,32,0,0,0,49,0,0,0,46,0,0,0,49,0,0,0,48,0,0,0,44,0,0,0,32,0,0,0,57,0,0,0,53,0,0,0,47,0,0,0,48,0,0,0,53,0,0,0,47,0,0,0,49,0,0,0,55,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,67,104,117,97,110,112,117,32,84,101,99,104,110,111,108,111,103,105,101,115,0,0,0,0,83,107,121,32,83,109,97,115,104,101,114,0,0,0,0,0,52,32,67,111,105,110,45,53,32,80,108,97,121,0,0,0,97,115,105,100,101,114,97,108,0,0,0,0,0,0,0,0,115,99,97,110,108,105,110,101,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,86,105,100,101,111,32,64,32,37,117,120,37,117,10,0,0,0,0,0,0,0,77,101,116,97,108,32,83,97,118,101,114,0,0,0,0,0,70,101,110,103,32,83,104,101,110,32,89,105,110,103,32,74,105,101,32,67,104,117,97,110,32,40,67,104,105,41,0,0,71,0,0,0,117,0,0,0,110,0,0,0,98,0,0,0,105,0,0,0,114,0,0,0,100,0,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,172,48,0,0,243,48,0,0,208,48,0,0,252,48,0,0,201,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,111,116,103,109,99,107,105,0,0,0,0,0,0,0,0,109,100,95,102,101,110,103,115,104,101,110,0,0,0,0,0,49,32,67,111,105,110,115,32,49,32,80,108,97,121,0,0,102,49,100,114,101,97,109,98,0,0,0,0,0,0,0,0,83,112,101,97,107,32,38,32,82,101,115,99,117,101,0,0,73,109,112,101,114,102,101,99,116,32,71,114,97,112,104,105,99,115,0,0,0,0,0,0,115,116,97,107,119,105,110,0,80,52,32,65,116,116,97,99,107,0,0,0,0,0,0,0,70,101,110,103,32,75,117,97,110,103,32,84,97,111,32,72,117,97,32,89,117,97,110,32,40,67,104,105,41,0,0,0,68,105,112,32,50,0,0,0,46,99,111,110,102,105,103,47,114,101,116,114,111,97,114,99,104,47,114,101,116,114,111,97,114,99,104,46,99,102,103,0,112,107,108,97,100,105,101,115,108,0,0,0,0,0,0,0,68,97,116,101,108,32,83,65,83,0,0,0,0,0,0,0,84,117,114,98,111,115,32,83,116,111,99,107,101,100,0,0,107,97,110,103,97,114,111,0,83,116,97,110,100,97,114,100,32,67,111,99,107,112,105,116,0,0,0,0,0,0,0,0,66,111,110,117,115,32,80,111,105,110,116,115,0,0,0,0,83,68,73,32,45,32,83,116,114,97,116,101,103,105,99,32,68,101,102,101,110,115,101,32,73,110,105,116,105,97,116,105,118,101,32,40,83,121,115,116,101,109,32,49,54,66,44,32,70,68,49,48,56,57,65,32,51,49,55,45,48,48,50,56,41,0,0,0,0,0,0,0,109,100,95,102,101,110,103,107,117,97,110,0,0,0,0,0,115,116,114,97,104,108,97,0,49,32,67,111,105,110,32,53,32,67,114,101,100,105,116,115,32,0,0,0,0,0,0,0,98,111,111,116,108,101,103,32,40,70,97,108,99,111,109,63,41,0,0,0,0,0,0,0,98,108,107,100,114,103,111,110,98,0,0,0,0,0,0,0,84,104,101,32,75,105,108,108,105,110,103,32,71,97,109,101,32,83,104,111,119,32,40,74,112,110,41,0,0,0,0,0,71,97,117,110,116,108,101,116,32,40,114,101,118,32,57,41,0,0,0,0,0,0,0,0,48,51,58,48,48,0,0,0,52,32,67,114,101,100,105,116,115,0,0,0,0,0,0,0,68,114,118,74,111,121,50,0,52,48,107,32,116,104,101,110,32,101,118,101,114,121,32,56,48,107,0,0,0,0,0,0,65,98,115,99,97,109,0,0,48,45,50,0,0,0,0,0,77,114,46,32,68,117,33,0,0,0,0,0,0,0,0,0,67,111,115,109,105,99,32,65,118,101,110,103,101,114,0,0,46,37,115,0,0,0,0,0,82,111,116,97,114,121,49,0,109,100,95,107,105,108,108,115,104,111,119,0,0,0,0,0,100,107,111,110,103,106,0,0,51,48,107,32,56,48,107,32,56,48,107,43,0,0,0,0,75,0,0,0,110,0,0,0,105,0,0,0,103,0,0,0,104,0,0,0,116,0,0,0,115,0,0,0,32,0,0,0,111,0,0,0,102,0,0,0,32,0,0,0,86,0,0,0,97,0,0,0,108,0,0,0,111,0,0,0,117,0,0,0,114,0,0,0,32,0,0,0,50,0,0,0,32,0,0,0,80,0,0,0,108,0,0,0,117,0,0,0,115,0,0,0,0,0,0,0,9,78,0,0,253,86,0,0,24,98,0,0,170,126,0,0,32,0,0,0,50,0,0,0,32,0,0,0,45,0,0,0,32,0,0,0,164,127,0,0,196,150,0,0,137,78,0,0,56,151,0,0,32,0,0,0,40,0,0,0,86,0,0,0,77,0,0,0,50,0,0,0,48,0,0,0,50,0,0,0,88,0,0,0,88,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,97,109,97,116,101,108,97,115,0,0,0,0,0,0,0,0,103,104,111,117,108,115,117,0,112,99,101,95,100,101,97,100,109,111,111,110,0,0,0,0,98,111,111,116,108,101,103,32,40,80,108,97,121,109,97,114,107,41,0,0,0,0,0,0,70,97,116,97,108,32,70,117,114,121,32,83,112,101,99,105,97,108,32,47,32,71,97,114,111,117,32,68,101,110,115,101,116,115,117,32,83,112,101,99,105,97,108,32,40,115,101,116,32,50,41,40,78,71,77,45,48,53,56,41,40,78,71,72,45,48,53,56,41,0,0,0,83,104,111,119,32,116,104,101,32,97,110,115,119,101,114,0,70,97,116,97,108,32,82,101,119,105,110,100,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,0,0,101,120,101,100,101,120,101,115,95,98,103,95,101,110,97,98,108,101,0,0,0,0,0,0,112,104,97,115,101,99,111,117,110,116,0,0,0,0,0,0,118,117,108,103,117,115,95,115,99,114,111,108,108,91,48,93,0,0,0,0,0,0,0,0,67,97,112,99,111,109,32,40,87,105,108,108,105,97,109,115,32,69,108,101,99,116,114,111,110,105,99,115,32,108,105,99,101,110,115,101,41,0,0,0,80,97,108,101,116,116,101,32,82,65,77,0,0,0,0,0,84,104,101,32,73,110,99,114,101,100,105,98,108,101,32,67,114,97,115,104,32,68,117,109,109,105,101,115,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,0,0,118,97,109,112,106,97,0,0,108,119,105,110,103,115,98,0,102,49,50,0,0,0,0,0,109,100,95,102,97,116,97,108,114,101,119,0,0,0,0,0,67,105,110,101,109,97,116,114,111,110,105,99,115,32,43,32,65,100,118,97,110,99,101,100,32,77,105,99,114,111,99,111,109,112,117,116,101,114,32,83,121,115,116,101,109,115,0,0,116,104,101,103,108,111,98,50,0,0,0,0,0,0,0,0,115,116,114,101,101,116,115,109,0,0,0,0,0,0,0,0,115,111,117,110,100,95,115,116,97,116,117,115,0,0,0,0,67,111,109,109,97,110,100,111,32,40,98,111,111,116,108,101,103,32,50,41,0,0,0,0,49,57,52,51,58,32,84,104,101,32,66,97,116,116,108,101,32,111,102,32,77,105,100,119,97,121,32,40,98,111,111,116,108,101,103,32,115,101,116,32,49,44,32,104,97,99,107,32,111,102,32,74,97,112,97,110,32,115,101,116,41,0,0,0,83,104,105,32,110,111,32,77,101,105,107,121,117,117,32,45,32,76,97,98,121,114,105,110,116,104,32,111,102,32,68,101,97,116,104,32,40,74,112,110,44,32,71,97,109,101,32,110,111,32,75,97,110,100,117,109,101,32,77,101,103,97,67,68,32,82,105,112,41,0,0,0,120,109,108,0,0,0,0,0,100,98,108,100,121,110,117,0,102,108,97,115,104,103,97,108,0,0,0,0,0,0,0,0,109,100,95,108,97,98,100,101,97,116,104,103,110,107,0,0,77,97,100,32,71,101,97,114,32,40,85,83,41,0,0,0,66,117,114,110,71,117,110,89,0,0,0,0,0,0,0,0,68,114,97,103,111,110,32,66,117,115,116,101,114,0,0,0,87,99,57,48,98,49,83,99,114,111,108,108,48,88,0,0,98,111,111,116,108,101,103,32,40,84,97,105,116,111,32,100,111,32,66,114,97,115,105,108,41,0,0,0,0,0,0,0,109,111,110,101,121,95,103,101,116,32,101,114,114,111,114,0,103,110,103,112,114,111,116,0,109,114,102,108,101,97,95,115,101,108,101,99,116,91,51,93,0,0,0,0,0,0,0,0,83,104,105,32,110,111,32,77,101,105,107,121,117,117,32,45,32,76,97,98,121,114,105,110,116,104,32,111,102,32,68,101,97,116,104,32,40,74,112,110,44,32,83,101,103,97,78,101,116,41,0,0,0,0,0,0,103,97,108,108,97,103,0,0,87,99,57,48,68,105,112,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,73,110,118,97,108,105,100,32,82,79,77,32,116,121,112,101,46,10,0,83,117,112,101,114,32,86,111,108,108,101,121,98,97,108,108,32,40,85,83,41,0,0,0,56,56,103,97,109,101,115,0,109,100,95,108,97,98,100,101,97,116,104,0,0,0,0,0,68,111,117,98,108,101,32,68,114,97,103,111,110,32,40,85,83,32,115,101,116,32,50,41,0,0,0,0,0,0,0,0,77,67,54,56,52,48,95,116,101,109,112,111,0,0,0,0,107,111,118,113,104,115,103,115,97,0,0,0,0,0,0,0,109,95,111,108,100,115,95,99,109,100,51,0,0,0,0,0,80,52,32,82,105,103,104,116,0,0,0,0,0,0,0,0,70,97,116,97,108,32,76,97,98,121,114,105,110,116,104,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,114,101,116,114,111,97,114,99,104,47,114,101,116,114,111,97,114,99,104,46,99,102,103,0,79,0,0,0,114,0,0,0,105,0,0,0,101,0,0,0,110,0,0,0,116,0,0,0,97,0,0,0,108,0,0,0,32,0,0,0,76,0,0,0,101,0,0,0,103,0,0,0,101,0,0,0,110,0,0,0,100,0,0,0,0,0,0,0,127,137,0,0,56,110,0,0,202,145,0,0,132,83,0,0,32,79,0,0,32,0,0,0,40,0,0,0,86,0,0,0,49,0,0,0,49,0,0,0,50,0,0,0,44,0,0,0,32,0,0,0,67,0,0,0,104,0,0,0,105,0,0,0,110,0,0,0,97,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,53,53,32,83,101,99,111,110,100,115,0,0,0,0,0,0,85,112,114,105,103,104,116,32,40,97,108,116,41,0,0,0,65,32,49,54,0,0,0,0,115,100,105,0,0,0,0,0,109,100,95,102,97,116,97,108,108,97,98,0,0,0,0,0,49,50,0,0,0,0,0,0,83,117,105,99,105,100,101,0,83,99,114,101,101,110,32,70,108,105,112,0,0,0,0,0,75,111,117,116,101,116,115,117,32,89,111,117,115,97,105,32,83,116,114,97,104,108,32,40,74,97,112,97,110,32,115,101,116,32,49,41,0,0,0,0,71,97,114,111,117,32,68,101,110,115,101,116,115,117,32,50,32,45,32,65,114,97,116,97,110,97,114,117,32,84,97,116,97,107,97,105,32,40,74,112,110,41,0,0,0,0,0,0,116,119,105,110,101,97,103,108,0,0,0,0,0,0,0,0,70,117,108,108,32,50,32,80,108,97,121,101,114,115,32,71,97,109,101,0,0,0,0,0,65,101,114,111,32,66,108,97,115,116,101,114,115,0,0,0,52,48,107,32,116,104,101,110,32,101,118,101,114,121,32,54,48,107,0,0,0,0,0,0,97,98,115,99,97,109,0,0,109,100,95,103,97,114,111,117,50,0,0,0,0,0,0,0,73,110,102,105,110,105,116,101,32,76,105,118,101,115,0,0,75,110,105,103,104,116,115,32,111,102,32,86,97,108,111,117,114,32,50,32,80,108,117,115,32,45,32,78,105,110,101,32,68,114,97,103,111,110,115,32,40,86,77,50,48,50,88,88,41,0,0,0,0,0,0,0,71,104,111,117,108,115,39,110,32,71,104,111,115,116,115,32,40,87,111,114,108,100,41,0,0,0,0,0,0,0,0,0,68,97,114,105,117,115,32,80,108,117,115,0,0,0,0,0,102,97,116,102,117,114,115,112,97,0,0,0,0,0,0,0,51,119,111,110,100,101,114,115,114,49,0,0,0,0,0,0,70,97,116,97,108,32,70,117,114,121,32,50,32,40,85,83,65,44,32,75,111,114,41,0,0,0,0,0,0,0,0,0,80,97,108,101,116,116,101,32,48,0,0,0,0,0,0,0,109,100,95,99,114,97,115,104,100,117,109,0,0,0,0,0,86,97,109,112,105,114,101,32,45,32,116,104,101,32,110,105,103,104,116,32,119,97,114,114,105,111,114,115,32,40,57,52,48,55,48,53,32,74,97,112,97,110,41,0,0,0,0,0,52,32,80,108,97,121,101,114,32,49,38,50,32,51,38,52,32,83,104,97,114,101,32,67,111,105,110,115,0,0,0,0,102,49,49,0,0,0,0,0,109,100,95,102,97,116,102,117,114,121,50,0,0,0,0,0,71,97,114,111,117,32,68,101,110,115,101,116,115,117,32,45,32,83,104,117,107,117,109,101,105,32,110,111,32,84,97,116,97,107,97,105,32,40,74,112,110,41,0,0,0,0,0,0,114,105,111,116,0,0,0,0,110,111,45,112,97,116,99,104,0,0,0,0,0,0,0,0,83,76,79,84,45,62,84,76,0,0,0,0,0,0,0,0,103,108,68,101,108,101,116,101,86,101,114,116,101,120,65,114,114,97,121,115,79,69,83,0,109,100,95,103,97,114,111,117,0,0,0,0,0,0,0,0,71,97,108,97,120,121,32,69,109,112,105,114,101,32,40,98,111,111,116,108,101,103,63,41,0,0,0,0,0,0,0,0,86,101,114,116,101,120,67,111,111,114,100,0,0,0,0,0,76,105,116,116,108,101,0,0,118,101,99,116,111,114,95,99,110,116,0,0,0,0,0,0,65,82,77,95,97,114,103,98,56,0,0,0,0,0,0,0,70,97,116,97,108,32,70,117,114,121,32,40,85,83,65,41,0,0,0,0,0,0,0,0,75,48,53,50,49,48,57,67,104,97,114,82,111,109,66,97,110,107,50,91,50,93,0,0,115,97,109,115,104,111,51,0,80,52,32,76,101,102,116,0,109,100,95,102,97,116,102,117,114,121,117,0,0,0,0,0,68,105,112,32,49,0,0,0,170,96,0,0,84,155,0,0,206,87,0,0,32,0,0,0,201,48,0,0,233,48,0,0,173,48,0,0,229,48,0,0,233,48,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,32,0,0,0,118,0,0,0,101,0,0,0,114,0,0,0,46,0,0,0,32,0,0,0,78,0,0,0,41,0,0,0,0,0,0,0,65,0,0,0,107,0,0,0,117,0,0,0,109,0,0,0,97,0,0,0,45,0,0,0,74,0,0,0,111,0,0,0,117,0,0,0,32,0,0,0,68,0,0,0,114,0,0,0,97,0,0,0,99,0,0,0,117,0,0,0,108,0,0,0,97,0,0,0,0,0,0,0,0,0,0,0,71,88,56,57,48,0,0,0,65,108,105,101,110,115,32,40,74,97,112,97,110,32,115,101,116,32,50,41,0,0,0,0,54,48,32,83,101,99,111,110,100,115,0,0,0,0,0,0,68,101,108,117,120,101,32,77,111,116,111,114,105,122,101,100,32,67,97,98,105,110,101,116,0,0,0,0,0,0,0,0,66,32,49,52,0,0,0,0,80,0,0,0,97,0,0,0,114,0,0,0,111,0,0,0,100,0,0,0,105,0,0,0,117,0,0,0,115,0,0,0,32,0,0,0,209,48,0,0,237,48,0,0,199,48,0,0,163,48,0,0,166,48,0,0,185,48,0,0,96,48,0,0,1,255,0,0,32,0,0,0,13,255,0,0,94,121,0,0,113,138,0,0,75,48,0,0,137,48,0,0,74,48,0,0,17,123,0,0,68,48,0,0,120,48,0,0,13,255,0,0,32,0,0,0,40,0,0,0,65,0,0,0,115,0,0,0,105,0,0,0,97,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,115,100,105,98,0,0,0,0,70,97,116,97,108,32,70,117,114,121,32,40,69,117,114,111,44,32,75,111,114,41,0,0,80,108,97,121,101,114,32,86,105,116,97,108,105,116,121,0,49,48,0,0,0,0,0,0,77,111,118,101,32,116,111,32,99,101,110,116,114,101,0,0,75,97,110,101,107,111,49,54,66,103,49,53,83,101,108,101,99,116,0,0,0,0,0,0,84,104,117,110,100,101,114,32,67,114,111,115,115,32,40,115,101,116,32,51,41,0,0,0,115,116,114,97,104,108,0,0,87,111,114,108,100,32,82,101,99,111,114,100,115,0,0,0,109,100,95,102,97,116,102,117,114,121,0,0,0,0,0,0,66,155,0,0,151,101,0,0,133,127,0,0,32,0,0,0,179,48,0,0,243,48,0,0,200,48,0,0,233,48,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,32,0,0,0,98,0,0,0,111,0,0,0,111,0,0,0,116,0,0,0,108,0,0,0,101,0,0,0,103,0,0,0,41,0,0,0,0,0,0,0,67,0,0,0,111,0,0,0,110,0,0,0,116,0,0,0,114,0,0,0,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,32,67,114,101,100,105,116,32,47,32,51,32,73,110,110,105,110,103,115,0,0,0,0,80,50,32,83,116,114,111,110,103,32,107,105,99,107,0,0,88,45,77,101,110,32,40,50,32,80,108,97,121,101,114,115,32,118,101,114,32,69,65,65,41,0,0,0,0,0,0,0,50,48,107,32,116,104,101,110,32,101,118,101,114,121,32,56,48,107,0,0,0,0,0,0,80,105,114,97,110,104,97,32,40,104,97,99,107,41,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,91,71,76,93,58,32,76,101,103,97,99,121,32,115,104,97,100,101,114,115,32,97,114,101,32,100,101,112,114,101,99,97,116,101,100,46,10,0,0,0,0,0,0,0,118,117,108,99,97,110,97,0,72,117,109,97,110,32,69,110,116,101,114,116,97,105,110,109,101,110,116,0,0,0,0,0,105,114,113,65,95,101,110,97,98,108,101,0,0,0,0,0,49,57,88,88,32,45,32,116,104,101,32,119,97,114,32,97,103,97,105,110,115,116,32,100,101,115,116,105,110,121,32,40,57,53,49,50,48,55,32,74,97,112,97,110,41,0,0,0,107,111,118,50,112,50,48,50,0,0,0,0,0,0,0,0,67,114,105,109,101,32,70,105,103,104,116,101,114,115,32,50,32,40,74,97,112,97,110,32,50,32,80,108,97,121,101,114,115,32,118,101,114,46,32,80,41,0,0,0,0,0,0,0,103,104,111,117,108,115,0,0,112,99,101,95,100,97,114,105,117,115,112,0,0,0,0,0,97,106,97,120,0,0,0,0,70,0,0,0,97,0,0,0,116,0,0,0,97,0,0,0,108,0,0,0,32,0,0,0,70,0,0,0,117,0,0,0,114,0,0,0,121,0,0,0,32,0,0,0,83,0,0,0,112,0,0,0,101,0,0,0,99,0,0,0,105,0,0,0,97,0,0,0,108,0,0,0,0,0,0,0,19,153,0,0,252,114,0,0,29,79,0,0,172,138,0,0,32,0,0,0,83,0,0,0,112,0,0,0,101,0,0,0,99,0,0,0,105,0,0,0,97,0,0,0,108,0,0,0,32,0,0,0,40,0,0,0,115,0,0,0,101,0,0,0,116,0,0,0,32,0,0,0,49,0,0,0,41,0,0,0,40,0,0,0,78,0,0,0,71,0,0,0,77,0,0,0,45,0,0,0,48,0,0,0,53,0,0,0,56,0,0,0,41,0,0,0,40,0,0,0,78,0,0,0,71,0,0,0,72,0,0,0,45,0,0,0,48,0,0,0,53,0,0,0,56,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,104,101,32,83,105,109,112,115,111,110,115,32,40,50,32,80,108,97,121,101,114,115,32,74,97,112,97,110,41,0,0,105,114,113,116,114,105,103,103,101,114,0,0,0,0,0,0,111,118,101,114,108,97,121,37,117,95,100,101,115,99,115,0,70,97,115,116,101,115,116,32,49,32,40,74,112,110,41,0,0,0,0,0,0,0,0,0,69,83,80,78,32,83,117,110,100,97,121,32,78,105,103,104,116,32,78,70,76,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,41,0,0,110,97,109,101,0,0,0,0,118,97,109,112,106,0,0,0,52,32,80,108,97,121,101,114,32,83,104,97,114,101,100,32,67,111,105,110,115,0,0,0,83,108,111,119,32,77,111,116,105,111,110,32,77,111,100,101,0,0,0,0,0,0,0,0,75,117,110,103,45,70,117,32,77,97,115,116,101,114,32,40,98,111,111,116,108,101,103,32,115,101,116,32,50,41,0,0,102,49,48,0,0,0,0,0,109,100,95,102,97,115,116,101,115,116,49,0,0,0,0,0,107,105,107,99,117,98,105,99,0,0,0,0,0,0,0,0,70,97,110,116,97,115,116,105,99,32,68,105,122,122,121,32,40,69,117,114,111,44,32,85,83,65,44,32,65,108,116,41,0,0,0,0,0,0,0,0,105,112,115,0,0,0,0,0,109,100,95,102,97,110,116,100,105,122,122,49,0,0,0,0,103,97,108,101,109,112,0,0,76,105,102,101,32,80,101,114,32,83,116,97,103,101,0,0,70,97,110,116,97,115,116,105,99,32,68,105,122,122,121,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,109,100,95,102,97,110,116,100,105,122,122,0,0,0,0,0,49,57,57,55,0,0,0,0,80,52,32,68,111,119,110,0,70,97,110,116,97,115,105,97,32,40,87,111,114,108,100,41,0,0,0,0,0,0,0,0,115,101,114,118,105,99,101,0,88,68,71,95,67,79,78,70,73,71,95,72,79,77,69,0,54,53,32,83,101,99,111,110,100,115,0,0,0,0,0,0,78,117,109,98,101,114,32,79,102,32,75,101,121,115,0,0,83,117,112,101,114,32,66,111,98,98,108,101,32,66,111,98,98,108,101,0,0,0,0,0,82,0,0,0,121,0,0,0,117,0,0,0,75,0,0,0,121,0,0,0,117,0,0,0,32,0,0,0,9,116,0,0,3,116,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,44,0,0,0,32,0,0,0,70,0,0,0,68,0,0,0,49,0,0,0,48,0,0,0,57,0,0,0,52,0,0,0,32,0,0,0,51,0,0,0,49,0,0,0,55,0,0,0,45,0,0,0,53,0,0,0,48,0,0,0,50,0,0,0,51,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,109,100,95,102,97,110,116,97,115,105,97,49,0,0,0,0,51,58,51,48,0,0,0,0,75,97,110,101,107,111,49,54,66,103,49,53,82,101,103,0,72,97,99,104,97,32,77,101,99,104,97,32,70,105,103,104,116,101,114,32,40,49,57,116,104,32,83,101,112,46,32,49,57,57,49,41,0,0,0,0,70,97,110,116,97,115,105,97,32,40,87,111,114,108,100,44,32,82,101,118,46,32,65,41,0,0,0,0,0,0,0,0,49,32,67,114,101,100,105,116,32,47,32,50,32,73,110,110,105,110,103,115,0,0,0,0,112,105,114,97,110,104,97,104,0,0,0,0,0,0,0,0,112,111,119,95,99,104,97,114,98,97,115,101,0,0,0,0,109,100,95,102,97,110,116,97,115,105,97,0,0,0,0,0,75,0,0,0,110,0,0,0,105,0,0,0,103,0,0,0,104,0,0,0,116,0,0,0,115,0,0,0,32,0,0,0,111,0,0,0,102,0,0,0,32,0,0,0,86,0,0,0,97,0,0,0,108,0,0,0,111,0,0,0,117,0,0,0,114,0,0,0,32,0,0,0,50,0,0,0,32,0,0,0,80,0,0,0,108,0,0,0,117,0,0,0,115,0,0,0,0,0,0,0,9,78,0,0,253,86,0,0,24,98,0,0,170,126,0,0,32,0,0,0,50,0,0,0,32,0,0,0,45,0,0,0,32,0,0,0,164,127,0,0,196,150,0,0,137,78,0,0,56,151,0,0,32,0,0,0,40,0,0,0,86,0,0,0,77,0,0,0,50,0,0,0,48,0,0,0,52,0,0,0,88,0,0,0,88,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,71,97,110,98,97,114,101,33,32,77,97,114,105,110,101,32,75,117,110,32,40,77,97,114,105,110,101,32,50,75,48,52,49,49,32,74,80,78,41,0,0,0,0,0,0,0,0,0,83,117,112,101,114,71,114,97,102,120,32,69,110,104,97,110,99,101,100,0,0,0,0,0,70,97,116,97,108,32,70,117,114,121,32,83,112,101,99,105,97,108,32,47,32,71,97,114,111,117,32,68,101,110,115,101,116,115,117,32,83,112,101,99,105,97,108,32,40,115,101,116,32,49,41,40,78,71,77,45,48,53,56,41,40,78,71,72,45,48,53,56,41,0,0,0,70,97,109,105,108,121,32,70,101,117,100,32,40,85,83,65,41,0,0,0,0,0,0,0,109,100,95,101,115,112,110,110,102,108,0,0,0,0,0,0,68,97,114,107,115,116,97,108,107,101,114,115,32,45,32,116,104,101,32,110,105,103,104,116,32,119,97,114,114,105,111,114,115,32,40,57,52,48,55,48,53,32,85,83,65,41,0,0,52,32,80,108,97,121,101,114,32,83,101,112,114,97,116,101,32,67,111,105,110,115,0,0,102,57,0,0,0,0,0,0,109,100,95,102,97,109,102,101,117,100,0,0,0,0,0,0,114,111,108,108,101,114,103,0,84,104,101,32,70,97,101,114,121,32,84,97,108,101,32,65,100,118,101,110,116,117,114,101,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,98,112,115,0,0,0,0,0,109,100,95,102,97,101,114,121,116,97,108,0,0,0,0,0,83,107,121,32,82,97,105,100,101,114,115,0,0,0,0,0,83,102,120,83,97,109,112,108,101,67,111,110,116,114,111,108,0,0,0,0,0,0,0,0,70,49,32,67,105,114,99,117,115,32,77,68,32,40,74,112,110,41,0,0,0,0,0,0,71,97,108,76,102,111,70,114,101,113,70,114,97,109,101,86,97,114,0,0,0,0,0,0,80,52,32,85,112,0,0,0,109,100,95,102,49,99,105,114,99,117,115,0,0,0,0,0,83,101,114,118,105,99,101,0,65,110,97,108,111,103,32,82,105,103,104,116,32,40,67,111,99,107,116,97,105,108,41,0,55,48,32,83,101,99,111,110,100,115,0,0,0,0,0,0,66,111,98,98,108,101,32,66,111,98,98,108,101,0,0,0,82,121,117,75,121,117,32,40,74,97,112,97,110,44,32,70,68,49,48,57,52,32,51,49,55,45,53,48,50,51,41,0,0,0,0,0,0,0,0,0,70,49,32,45,32,87,111,114,108,100,32,67,104,97,109,112,105,111,110,115,104,105,112,32,69,100,105,116,105,111,110,32,40,69,117,114,111,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,0,51,58,48,48,0,0,0,0,75,97,110,101,107,111,49,54,76,97,121,101,114,49,82,101,103,115,0,0,0,0,0,0,54,48,48,75,0,0,0,0,104,97,99,104,97,109,102,0,109,100,95,102,49,119,99,112,0,0,0,0,0,0,0,0,77,101,116,97,32,70,111,120,0,0,0,0,0,0,0,0,86,115,32,71,97,109,101,0,80,50,32,77,101,100,105,117,109,32,107,105,99,107,0,0,80,105,114,97,110,104,97,32,40,111,108,100,101,114,41,0,0,0,0,0,0,0,0,0,83,111,117,110,100,32,67,104,101,99,107,0,0,0,0,0,115,112,114,105,116,101,95,102,108,105,112,0,0,0,0,0,70,49,32,45,32,87,111,114,108,100,32,67,104,97,109,112,105,111,110,115,104,105,112,32,69,100,105,116,105,111,110,32,40,69,117,114,111,41,0,0,75,110,105,103,104,116,115,32,111,102,32,86,97,108,111,117,114,32,50,32,80,108,117,115,32,45,32,78,105,110,101,32,68,114,97,103,111,110,115,32,40,86,77,50,48,52,88,88,41,0,0,0,0,0,0,0,103,97,110,98,97,114,101,0,68,97,114,105,117,115,32,65,108,112,104,97,0,0,0,0,109,100,95,102,49,119,99,0,109,100,95,101,115,112,110,110,102,108,112,0,0,0,0,0,100,115,116,108,107,117,114,49,0,0,0,0,0,0,0,0,102,56,0,0,0,0,0,0,70,111,114,109,117,108,97,32,79,110,101,32,40,85,83,65,41,0,0,0,0,0,0,0,102,109,32,99,104,97,110,110,101,108,32,37,100,32,117,110,115,117,112,112,111,114,116,101,100,32,116,111,107,101,110,32,37,48,50,120,0,0,0,0,109,100,95,102,111,114,109,117,108,97,49,0,0,0,0,0,117,112,115,0,0,0,0,0,70,49,32,40,69,117,114,111,41,0,0,0,0,0,0,0,115,107,121,114,97,105,100,114,0,0,0,0,0,0,0,0,84,105,109,101,114,32,68,101,99,114,101,109,101,110,116,0,109,100,95,102,49,0,0,0,70,45,50,50,32,73,110,116,101,114,99,101,112,116,111,114,32,40,74,112,110,41,0,0,80,52,32,83,116,97,114,116,0,0,0,0,0,0,0,0,109,100,95,102,50,50,106,0,104,37,117,37,115,0,0,0,134,48,0,0,70,48,0,0,134,48,0,0,32,0,0,0,110,48,0,0,175,48,0,0,164,48,0,0,186,48,0,0,103,48,0,0,32,0,0,0,39,255,0,0,79,255,0,0,33,0,0,0,39,255,0,0,79,255,0,0,33,0,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,89,0,0,0,117,0,0,0,117,0,0,0,121,0,0,0,117,0,0,0,32,0,0,0,110,0,0,0,111,0,0,0,32,0,0,0,81,0,0,0,117,0,0,0,105,0,0,0,122,0,0,0,32,0,0,0,100,0,0,0,101,0,0,0,32,0,0,0,71,0,0,0,79,0,0,0,33,0,0,0,71,0,0,0,79,0,0,0,33,0,0,0,0,0,0,0,0,0,0,0,84,105,109,101,114,32,83,101,116,116,105,110,103,0,0,0,86,101,114,121,32,72,105,103,104,0,0,0,0,0,0,0,99,111,110,116,114,97,0,0,114,121,117,107,121,117,0,0,70,45,50,50,32,73,110,116,101,114,99,101,112,116,111,114,32,40,69,117,114,111,44,32,85,83,65,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,0,0,0,50,58,52,48,0,0,0,0,75,97,110,101,107,111,49,54,76,97,121,101,114,48,82,101,103,115,0,0,0,0,0,0,53,48,48,75,44,32,51,48,48,48,75,0,0,0,0,0,91,85,80,76,93,32,40,98,111,111,116,108,101,103,41,0,109,100,95,102,50,50,112,0,109,101,116,97,102,111,120,0,43,55,0,0,0,0,0,0,112,105,114,97,110,104,97,111,0,0,0,0,0,0,0,0,75,48,53,51,50,53,49,32,82,97,109,0,0,0,0,0,71,97,108,97,120,105,97,110,32,40,84,97,105,116,111,41,0,0,0,0,0,0,0,0,70,45,50,50,32,73,110,116,101,114,99,101,112,116,111,114,32,40,69,117,114,111,44,32,85,83,65,44,32,49,57,57,50,48,54,41,0,0,0,0,107,111,118,50,112,50,48,52,0,0,0,0,0,0,0,0,76,111,115,116,32,87,111,114,108,100,115,32,40,74,97,112,97,110,32,79,108,100,32,118,101,114,46,41,0,0,0,0,112,99,101,95,100,97,114,105,117,115,97,0,0,0,0,0,65,0,0,0,114,0,0,0,116,0,0,0,32,0,0,0,111,0,0,0,102,0,0,0,32,0,0,0,70,0,0,0,105,0,0,0,103,0,0,0,104,0,0,0,116,0,0,0,105,0,0,0,110,0,0,0,103,0,0,0,32,0,0,0,50,0,0,0,0,0,0,0,141,159,0,0,78,134,0,0,110,48,0,0,243,98,0,0,18,255,0,0,32,0,0,0,40,0,0,0,78,0,0,0,71,0,0,0,72,0,0,0,45,0,0,0,48,0,0,0,53,0,0,0,54,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,70,45,49,53,32,83,116,114,105,107,101,32,69,97,103,108,101,32,73,73,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,83,111,110,121,32,73,109,97,103,101,115,111,102,116,0,0,68,97,114,107,115,116,97,108,107,101,114,115,32,45,32,116,104,101,32,110,105,103,104,116,32,119,97,114,114,105,111,114,115,32,40,57,52,48,56,49,56,32,85,83,65,41,0,0,116,117,109,98,108,101,112,0,102,55,0,0,0,0,0,0,109,100,95,102,49,53,115,101,50,117,112,0,0,0,0,0,70,45,49,53,32,83,116,114,105,107,101,32,69,97,103,108,101,32,73,73,32,40,85,83,65,41,0,0,0,0,0,0,115,114,97,109,45,109,111,100,101,0,0,0,0,0,0,0,77,97,103,105,99,97,108,32,68,114,111,112,32,80,108,117,115,32,49,32,40,74,97,112,97,110,44,32,86,101,114,115,105,111,110,32,50,46,49,44,32,49,57,57,53,46,48,57,46,49,50,41,0,0,0,0,109,100,95,102,49,53,115,101,50,117,0,0,0,0,0,0,99,104,105,112,45,62,105,110,115,116,95,116,97,98,0,0,83,112,97,99,101,32,69,109,112,105,114,101,32,40,98,111,111,116,108,101,103,41,0,0,67,114,101,100,105,116,40,115,41,32,116,111,32,83,116,97,114,116,0,0,0,0,0,0,70,45,49,53,32,83,116,114,105,107,101,32,69,97,103,108,101,32,73,73,32,40,69,117,114,111,41,0,0,0,0,0,109,100,95,102,49,53,115,101,50,0,0,0,0,0,0,0,57,48,48,0,0,0,0,0,80,52,32,67,111,105,110,0,70,45,49,49,55,32,83,116,101,97,108,116,104,32,45,32,79,112,101,114,97,116,105,111,110,32,78,105,103,104,116,32,83,116,111,114,109,32,40,74,112,110,41,0,0,0,0,0,65,110,97,108,111,103,32,76,101,102,116,32,40,67,111,99,107,116,97,105,108,41,0,0,89,117,117,121,117,32,110,111,32,81,117,105,122,32,100,101,32,71,79,33,71,79,33,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,97,114,107,97,110,111,105,100,95,98,111,111,116,108,101,103,95,99,109,100,0,0,0,0,53,48,107,32,65,110,100,32,69,118,101,114,121,32,49,48,48,107,0,0,0,0,0,0,82,105,111,116,32,67,105,116,121,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,109,100,95,102,49,49,55,106,0,0,0,0,0,0,0,0,50,58,50,48,0,0,0,0,75,97,110,101,107,111,49,54,83,112,114,105,116,101,82,101,103,115,0,0,0,0,0,0,53,48,48,75,44,32,50,48,48,48,75,0,0,0,0,0,86,97,110,100,121,107,101,32,40,98,111,111,116,108,101,103,32,119,105,116,104,32,80,73,67,49,54,99,53,55,41,0,0,0,0,0,0,0,0,0,70,45,49,49,55,32,78,105,103,104,116,32,83,116,111,114,109,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,73,109,112,101,114,102,101,99,116,32,105,110,112,117,116,115,0,0,0,0,0,0,0,0,43,49,48,0,0,0,0,0,80,50,32,87,101,97,107,32,107,105,99,107,0,0,0,0,71,76,32,40,85,83,32,66,105,108,108,105,97,114,100,115,32,76,105,99,101,110,115,101,41,0,0,0,0,0,0,0,109,100,95,102,49,49,55,0,75,0,0,0,110,0,0,0,105,0,0,0,103,0,0,0,104,0,0,0,116,0,0,0,115,0,0,0,32,0,0,0,111,0,0,0,102,0,0,0,32,0,0,0,86,0,0,0,97,0,0,0,108,0,0,0,111,0,0,0,117,0,0,0,114,0,0,0,32,0,0,0,50,0,0,0,32,0,0,0,80,0,0,0,108,0,0,0,117,0,0,0,115,0,0,0,0,0,0,0,9,78,0,0,253,86,0,0,24,98,0,0,170,126,0,0,32,0,0,0,50,0,0,0,32,0,0,0,45,0,0,0,32,0,0,0,164,127,0,0,196,150,0,0,137,78,0,0,56,151,0,0,32,0,0,0,40,0,0,0,86,0,0,0,77,0,0,0,50,0,0,0,48,0,0,0,53,0,0,0,88,0,0,0,88,0,0,0,44,0,0,0,32,0,0,0,67,0,0,0,104,0,0,0,105,0,0,0,110,0,0,0,97,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,108,111,115,116,119,114,108,100,111,0,0,0,0,0,0,0,83,97,108,105,111,0,0,0,65,114,116,32,111,102,32,70,105,103,104,116,105,110,103,32,50,32,47,32,82,121,117,117,107,111,32,110,111,32,75,101,110,32,50,32,40,78,71,72,45,48,53,54,41,0,0,0,100,97,115,115,97,117,108,116,52,0,0,0,0,0,0,0,65,89,56,57,49,48,32,35,37,100,0,0,0,0,0,0,69,120,111,100,117,115,32,45,32,74,111,117,114,110,101,121,32,116,111,32,116,104,101,32,80,114,111,109,105,115,101,100,32,76,97,110,100,32,40,85,83,65,41,0,0,0,0,0,69,83,80,78,32,83,112,101,101,100,119,111,114,108,100,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,0,0,100,115,116,108,107,117,0,0,70,117,101,108,32,68,101,99,114,101,97,115,101,0,0,0,102,54,0,0,0,0,0,0,109,100,95,101,120,111,100,117,115,0,0,0,0,0,0,0,69,120,111,32,83,113,117,97,100,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,98,115,118,114,101,99,111,114,100,0,0,0,0,0,0,0,109,100,95,101,120,111,115,113,117,97,100,117,112,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,80,73,88,69,76,95,70,79,82,77,65,84,58,32,48,82,71,66,49,53,53,53,46,10,0,115,112,97,99,101,109,112,114,0,0,0,0,0,0,0,0,69,120,111,32,83,113,117,97,100,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,109,100,95,101,120,111,115,113,117,97,100,117,0,0,0,0,120,109,101,110,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,67,111,117,108,100,110,39,116,32,102,105,110,100,32,97,110,121,32,110,101,120,116,32,97,117,100,105,111,32,100,114,105,118,101,114,32,40,99,117,114,114,101,110,116,32,111,110,101,58,32,34,37,115,34,41,46,10,0,0,0,56,48,48,0,0,0,0,0,67,111,105,110,32,51,0,0,69,120,111,32,83,113,117,97,100,32,40,69,117,114,111,41,0,0,0,0,0,0,0,0,121,117,121,117,103,111,103,111,0,0,0,0,0,0,0,0,50,48,107,32,65,110,100,32,69,118,101,114,121,32,53,48,107,0,0,0,0,0,0,0,114,105,111,116,99,105,116,121,0,0,0,0,0,0,0,0,109,100,95,101,120,111,115,113,117,97,100,0,0,0,0,0,75,97,110,101,107,111,49,54,68,105,115,112,108,97,121,69,110,97,98,108,101,0,0,0,53,48,48,75,44,32,49,53,48,48,75,0,0,0,0,0,118,97,110,100,121,107,101,98,0,0,0,0,0,0,0,0,109,117,116,97,110,116,102,95,112,111,114,116,95,54,97,95,104,97,99,107,0,0,0,0,69,120,105,108,101,32,45,32,84,111,107,105,32,110,111,32,72,97,122,97,109,97,32,101,32,40,74,112,110,41,0,0,65,114,98,97,108,101,115,116,101,114,0,0,0,0,0,0,118,115,32,67,80,85,32,71,97,109,101,32,69,110,100,115,0,0,0,0,0,0,0,0,80,105,114,97,110,104,97,0,0,0,0,0,0,0,0,0,105,110,118,101,114,116,95,99,111,110,116,114,111,108,115,0,109,100,95,101,120,105,108,101,106,0,0,0,0,0,0,0,75,110,105,103,104,116,115,32,111,102,32,86,97,108,111,117,114,32,50,32,80,108,117,115,32,45,32,78,105,110,101,32,68,114,97,103,111,110,115,32,40,86,77,50,48,53,88,88,44,32,67,104,105,110,97,41,0,0,0,0,0,0,0,0,76,111,115,116,32,87,111,114,108,100,115,32,40,74,97,112,97,110,41,0,0,0,0,0,68,97,105,99,104,105,32,75,117,110,32,67,114,105,115,105,115,32,45,32,68,111,32,78,97,116,117,114,97,108,0,0,97,111,102,50,97,0,0,0,69,120,105,108,101,32,40,85,83,65,41,0,0,0,0,0,109,100,95,101,115,112,110,115,112,101,100,0,0,0,0,0,68,97,114,107,115,116,97,108,107,101,114,115,32,45,32,116,104,101,32,110,105,103,104,116,32,119,97,114,114,105,111,114,115,32,40,57,52,48,56,49,56,32,72,105,115,112,97,110,105,99,41,0,0,0,0,0,65,68,75,0,0,0,0,0,68,76,32,52,83,83,0,0,102,53,0,0,0,0,0,0,98,111,97,114,100,114,111,109,58,32,37,115,10,0,0,0,109,100,95,101,120,105,108,101,0,0,0,0,0,0,0,0,73,110,116,101,114,110,97,108,32,82,65,77,0,0,0,0,65,108,108,32,32,82,101,103,105,115,116,101,114,115,0,0,119,111,108,102,102,97,110,103,0,0,0,0,0,0,0,0,74,46,32,76,101,97,103,117,101,32,67,104,97,109,112,105,111,110,32,83,111,99,99,101,114,32,40,74,112,110,41,0,0,0,0,0,0,0,0,0,98,115,118,112,108,97,121,0,82,45,62,112,111,114,116,51,95,100,100,114,0,0,0,0,56,98,97,108,108,97,99,116,0,0,0,0,0,0,0,0,83,99,114,101,101,110,32,116,101,115,116,32,109,111,100,101,0,0,0,0,0,0,0,0,98,97,116,114,105,100,101,114,106,97,0,0,0,0,0,0,102,105,120,101,105,103,104,116,116,119,116,0,0,0,0,0,109,100,95,106,108,99,115,0,103,101,116,115,116,97,114,0,83,112,97,99,101,32,66,97,116,116,108,101,32,40,98,111,111,116,108,101,103,32,115,101,116,32,50,41,0,0,0,0,68,105,115,99,111,117,110,116,32,99,111,110,116,105,110,117,101,0,0,0,0,0,0,0,87,111,114,108,100,32,84,114,111,112,104,121,32,83,111,99,99,101,114,32,40,85,83,65,41,0,0,0,0,0,0,0,98,103,97,114,101,103,103,97,116,119,0,0,0,0,0,0,83,97,109,101,33,32,83,97,109,101,33,32,83,97,109,101,33,32,40,50,32,112,108,97,121,101,114,32,97,108,116,101,114,110,97,116,105,110,103,32,118,101,114,46,41,0,0,0])
.concat([114,101,115,101,116,95,100,101,108,97,121,0,0,0,0,0,109,100,95,119,111,114,108,100,116,115,0,0,0,0,0,0,55,48,48,0,0,0,0,0,80,51,32,70,105,114,101,32,51,0,0,0,0,0,0,0,69,117,114,111,112,101,97,110,32,67,108,117,98,32,83,111,99,99,101,114,32,40,69,117,114,111,41,0,0,0,0,0,112,50,32,102,105,114,101,32,51,0,0,0,0,0,0,0,100,105,115,97,98,108,101,95,99,112,117,91,48,93,0,0,57,255,0,0,69,255,0,0,83,255,0,0,46,0,0,0,46,255,0,0,79,255,0,0,32,0,0,0,195,95,0,0,6,116,0,0,32,0,0,0,200,48,0,0,173,48,0,0,225,48,0,0,173,48,0,0,193,48,0,0,227,48,0,0,252,48,0,0,200,48,0,0,0,0,0,0,89,0,0,0,101,0,0,0,115,0,0,0,47,0,0,0,78,0,0,0,111,0,0,0,32,0,0,0,83,0,0,0,105,0,0,0,110,0,0,0,114,0,0,0,105,0,0,0,32,0,0,0,84,0,0,0,111,0,0,0,107,0,0,0,105,0,0,0,109,0,0,0,101,0,0,0,107,0,0,0,105,0,0,0,32,0,0,0,67,0,0,0,104,0,0,0,97,0,0,0,114,0,0,0,116,0,0,0,0,0,0,0,0,0,0,0,98,111,117,108,100,97,115,104,0,0,0,0,0,0,0,0,77,111,100,101,32,66,32,40,87,111,114,108,100,41,0,0,77,111,110,115,116,101,114,32,83,112,101,101,100,0,0,0,84,104,101,32,76,101,103,101,110,100,32,111,102,32,75,97,103,101,32,40,98,111,111,116,108,101,103,32,115,101,116,32,50,41,0,0,0,0,0,0,48,49,49,48,0,0,0,0,109,100,95,101,117,114,111,99,108,117,98,0,0,0,0,0,69,120,112,101,114,105,101,110,99,101,32,79,110,108,121,0,83,104,105,102,116,32,85,112,0,0,0,0,0,0,0,0,75,97,110,101,107,111,49,54,83,112,114,105,116,101,70,108,105,112,89,0,0,0,0,0,52,48,48,75,0,0,0,0,97,114,107,110,111,105,100,50,0,0,0,0,0,0,0,0,86,97,110,100,121,107,101,32,40,74,97,108,101,99,111,44,32,83,101,116,32,50,41,0,0,0,0,0,0,0,0,0,97,114,107,97,110,111,105,100,106,0,0,0,0,0,0,0,69,116,101,114,110,97,108,32,67,104,97,109,112,105,111,110,115,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,97,114,98,97,108,101,115,116,0,0,0,0,0,0,0,0,80,50,32,83,116,114,111,110,103,32,112,117,110,99,104,0,115,117,114,97,116,107,0,0,112,105,114,97,110,104,97,0,98,115,104,97,114,107,106,0,118,100,99,95,114,97,115,116,101,114,95,99,111,117,110,116,91,105,93,0,0,0,0,0,99,53,56,97,0,0,0,0,109,100,95,101,116,101,114,110,97,108,99,117,0,0,0,0,103,102,120,102,108,97,115,104,95,98,97,110,107,0,0,0,99,97,100,97,115,104,102,0,107,111,118,50,112,0,0,0,108,111,115,116,119,114,108,100,0,0,0,0,0,0,0,0,112,99,101,95,100,111,110,97,116,117,114,108,0,0,0,0,65,0,0,0,114,0,0,0,116,0,0,0,32,0,0,0,111,0,0,0,102,0,0,0,32,0,0,0,70,0,0,0,105,0,0,0,103,0,0,0,104,0,0,0,116,0,0,0,105,0,0,0,110,0,0,0,103,0,0,0,32,0,0,0,50,0,0,0,0,0,0,0,141,159,0,0,78,134,0,0,110,48,0,0,243,98,0,0,18,255,0,0,32,0,0,0,40,0,0,0,78,0,0,0,71,0,0,0,77,0,0,0,45,0,0,0,48,0,0,0,53,0,0,0,54,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,111,98,98,108,101,32,66,111,98,98,108,101,32,40,115,101,116,32,49,41,0,0,0,69,116,101,114,110,97,108,32,67,104,97,109,112,105,111,110,115,32,40,74,112,110,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,51,49,49,49,55,41,0,0,0,0,115,117,112,101,114,109,97,110,0,0,0,0,0,0,0,0,165,90,170,0,0,0,0,0,110,105,110,106,97,119,106,0,109,100,95,101,115,112,110,115,112,101,100,112,0,0,0,0,100,115,116,108,107,104,0,0,68,76,32,49,50,55,53,0,102,52,0,0,0,0,0,0,109,100,95,101,116,101,114,110,97,108,99,106,112,0,0,0,65,108,105,101,110,32,83,121,110,100,114,111,109,101,32,40,115,101,116,32,54,44,32,74,97,112,97,110,44,32,110,101,119,44,32,83,121,115,116,101,109,32,49,54,66,44,32,70,68,49,48,56,57,65,32,51,49,55,45,48,48,51,51,41,0,0,0,0,0,0,0,0,115,102,105,105,105,50,106,0,75,48,53,51,50,52,53,32,82,97,109,0,0,0,0,0,83,121,115,116,101,109,49,54,83,112,114,105,116,101,66,97,110,107,115,0,0,0,0,0,50,67,32,49,67,0,0,0,69,116,101,114,110,97,108,32,67,104,97,109,112,105,111,110,115,32,40,74,112,110,44,32,75,111,114,41,0,0,0,0,115,117,102,97,109,105,66,0,99,108,116,99,104,105,116,114,0,0,0,0,0,0,0,0,68,114,118,79,107,105,66,97,110,107,49,0,0,0,0,0,71,45,76,79,67,32,82,51,54,48,0,0,0,0,0,0,109,100,95,101,116,101,114,110,97,108,99,106,0,0,0,0,71,80,32,82,105,100,101,114,32,40,87,111,114,108,100,44,32,70,68,49,48,57,52,32,51,49,55,45,48,49,54,51,41,0,0,0,0,0,0,0,49,32,67,111,105,110,32,49,32,67,114,101,100,105,116,115,32,0,0,0,0,0,0,0,115,112,97,99,98,97,116,50,0,0,0,0,0,0,0,0,86,100,112,83,99,114,111,108,108,87,105,100,116,104,0,0,69,116,101,114,110,97,108,32,67,104,97,109,112,105,111,110,115,32,40,69,117,114,111,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,104,97,110,103,111,110,49,0,98,111,110,107,97,100,118,0,83,116,111,114,121,32,108,105,110,101,32,105,110,32,74,97,112,97,110,101,115,101,44,32,103,97,109,101,32,105,110,115,116,114,117,99,116,105,111,110,115,32,105,110,32,69,110,103,108,105,115,104,0,0,0,0,100,98,108,112,111,105,110,116,0,0,0,0,0,0,0,0,109,100,95,101,116,101,114,110,97,108,99,112,0,0,0,0,118,105,100,101,111,95,102,117,108,108,115,99,114,101,101,110,95,120,0,0,0,0,0,0,112,99,108,117,98,121,115,0,107,111,102,57,53,0,0,0,80,51,32,70,105,114,101,32,50,0,0,0,0,0,0,0,69,116,101,114,110,97,108,32,67,104,97,109,112,105,111,110,115,32,40,69,117,114,111,41,0,0,0,0,0,0,0,0,106,140,0,0,64,136,0,0,250,91,0,0,22,89,0,0,29,79,0,0,32,0,0,0,71,0,0,0,111,0,0,0,103,0,0,0,101,0,0,0,116,0,0,0,115,0,0,0,117,0,0,0,106,0,0,0,105,0,0,0,32,0,0,0,76,0,0,0,101,0,0,0,103,0,0,0,101,0,0,0,110,0,0,0,100,0,0,0,115,0,0,0,32,0,0,0,40,0,0,0,85,0,0,0,83,0,0,0,65,0,0,0,44,0,0,0,32,0,0,0,118,0,0,0,101,0,0,0,114,0,0,0,46,0,0,0,32,0,0,0,57,0,0,0,53,0,0,0,47,0,0,0,48,0,0,0,54,0,0,0,47,0,0,0,50,0,0,0,48,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,90,101,114,111,32,80,111,105,110,116,32,50,0,0,0,0,98,103,48,115,99,114,111,108,108,121,0,0,0,0,0,0,89,101,115,47,78,111,32,83,105,110,114,105,32,84,111,107,105,109,101,107,105,32,67,104,97,114,116,0,0,0,0,0,77,111,100,101,32,65,32,40,74,97,112,97,110,41,0,0,77,111,110,111,0,0,0,0,49,48,48,32,40,67,104,101,97,116,41,0,0,0,0,0,76,101,97,118,101,32,79,102,102,0,0,0,0,0,0,0,83,97,116,0,0,0,0,0,109,100,95,101,116,101,114,110,97,108,99,0,0,0,0,0,70,105,103,104,116,47,69,120,112,101,114,105,101,110,99,101,0,0,0,0,0,0,0,0,75,97,110,101,107,111,49,54,83,112,114,105,116,101,70,108,105,112,88,0,0,0,0,0,51,48,48,75,44,32,49,48,48,48,75,0,0,0,0,0,118,97,110,100,121,107,101,106,97,108,50,0,0,0,0,0,114,97,105,100,101,110,107,0,78,97,109,99,111,0,0,0,67,121,98,101,114,32,80,111,108,105,99,101,32,69,83,87,65,84,32,40,74,112,110,44,32,82,101,118,46,32,48,41,0,0,0,0,0,0,0,0,98,111,109,98,107,105,99,107,0,0,0,0,0,0,0,0,69,103,103,111,114,0,0,0,205,95,0,0,5,128,0,0,32,0,0,0,141,159,0,0,99,82,0,0,29,79,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,44,0,0,0,32,0,0,0,115,0,0,0,101,0,0,0,116,0,0,0,32,0,0,0,49,0,0,0,41,0,0,0,0,0,0,0,78,0,0,0,105,0,0,0,110,0,0,0,106,0,0,0,97,0,0,0,32,0,0,0,82,0,0,0,121,0,0,0,117,0,0,0,107,0,0,0,101,0,0,0,110,0,0,0,100,0,0,0,101,0,0,0,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,109,100,95,101,115,119,97,116,106,0,0,0,0,0,0,0,119,119,102,119,102,101,115,116,107,0,0,0,0,0,0,0,75,0,0,0,110,0,0,0,105,0,0,0,103,0,0,0,104,0,0,0,116,0,0,0,115,0,0,0,32,0,0,0,111,0,0,0,102,0,0,0,32,0,0,0,86,0,0,0,97,0,0,0,108,0,0,0,111,0,0,0,117,0,0,0,114,0,0,0,32,0,0,0,50,0,0,0,0,0,0,0,9,78,0,0,253,86,0,0,24,98,0,0,170,126,0,0,32,0,0,0,50,0,0,0,32,0,0,0,40,0,0,0,86,0,0,0,49,0,0,0,48,0,0,0,48,0,0,0,44,0,0,0,32,0,0,0,49,0,0,0,48,0,0,0,48,0,0,0,44,0,0,0,32,0,0,0,49,0,0,0,48,0,0,0,48,0,0,0,44,0,0,0,32,0,0,0,72,0,0,0,111,0,0,0,110,0,0,0,103,0,0,0,32,0,0,0,75,0,0,0,111,0,0,0,110,0,0,0,103,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,110,101,119,102,97,110,116,0,70,111,114,103,111,116,116,101,110,32,87,111,114,108,100,115,32,40,85,83,44,32,66,45,66,111,97,114,100,32,56,56,54,49,56,66,45,50,44,32,114,101,118,32,65,65,41,0,0,0,0,0,0,0,0,0,68,97,105,32,83,101,110,112,117,0,0,0,0,0,0,0,65,114,116,32,111,102,32,70,105,103,104,116,105,110,103,32,50,32,47,32,82,121,117,117,107,111,32,110,111,32,75,101,110,32,50,32,40,78,71,77,45,48,53,54,41,0,0,0,66,105,111,109,101,99,104,97,110,105,99,97,108,32,84,111,121,32,40,86,101,114,46,32,49,46,48,46,49,56,56,52,41,0,0,0,0,0,0,0,82,105,111,116,0,0,0,0,69,83,80,78,32,83,117,110,100,97,121,32,78,105,103,104,116,32,78,70,76,32,40,85,83,65,41,0,0,0,0,0,80,114,101,116,116,121,32,83,111,108,100,105,101,114,32,83,97,105,108,111,114,32,77,111,111,110,32,40,118,101,114,46,32,57,53,47,48,51,47,50,50,66,44,32,75,111,114,101,97,41,0,0,0,0,0,0,76,105,103,104,116,32,67,114,117,115,97,100,101,114,32,40,69,117,114,111,41,0,0,0,68,97,114,107,115,116,97,108,107,101,114,115,32,45,32,116,104,101,32,110,105,103,104,116,32,119,97,114,114,105,111,114,115,32,40,57,52,48,55,48,53,32,65,115,105,97,41,0,0,0,0,0,0,0,0,0,78,111,115,116,114,97,100,97,109,117,115,32,40,74,97,112,97,110,41,0,0,0,0,0,71,97,109,101,32,83,112,101,101,100,0,0,0,0,0,0,68,101,108,116,114,111,110,105,99,115,32,77,111,100,101,108,0,0,0,0,0,0,0,0,102,51,0,0,0,0,0,0,69,83,80,78,32,83,112,101,101,100,119,111,114,108,100,32,40,85,83,65,41,0,0,0,75,97,114,97,116,101,32,66,108,97,122,101,114,115,32,40,74,97,112,97,110,41,0,0,84,104,101,32,67,111,109,98,97,116,114,105,98,101,115,32,40,85,83,41,0,0,0,0,69,83,80,78,32,78,97,116,105,111,110,97,108,32,72,111,99,107,101,121,32,78,105,103,104,116,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,115,117,102,97,109,105,65,0,66,108,111,111,100,32,69,102,102,101,99,116,0,0,0,0,68,111,110,80,97,99,104,105,32,40,72,111,110,103,32,75,111,110,103,44,32,118,101,114,46,32,49,46,49,48,44,32,57,53,47,48,53,47,49,55,41,0,0,0,0,0,0,0,109,100,95,101,115,112,110,104,110,112,0,0,0,0,0,0,115,107,121,115,109,97,115,104,0,0,0,0,0,0,0,0,52,32,67,111,105,110,45,51,32,80,108,97,121,0,0,0,83,112,97,99,101,32,66,97,116,116,108,101,32,40,98,111,111,116,108,101,103,32,115,101,116,32,49,41,0,0,0,0,109,111,114,101,109,111,114,101,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,65,117,100,105,111,32,114,97,116,101,32,99,111,110,116,114,111,108,32,119,97,115,32,100,101,115,105,114,101,100,44,32,98,117,116,32,100,114,105,118,101,114,32,100,111,101,115,32,110,111,116,32,115,117,112,112,111,114,116,32,110,101,101,100,101,100,32,102,101,97,116,117,114,101,115,46,10,0,0,0,0,0,0,0,69,83,80,78,32,78,97,116,105,111,110,97,108,32,72,111,99,107,101,121,32,78,105,103,104,116,32,40,85,83,65,41,0,0,0,0,0,0,0,0,71,117,110,98,105,114,100,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,83,112,97,99,101,32,66,111,109,98,101,114,0,0,0,0,84,97,105,115,101,110,32,72,111,116,32,71,105,109,109,105,99,107,32,52,32,69,118,101,114,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,79,114,99,97,32,40,69,115,99,111,32,84,114,97,100,105,110,103,32,67,111,32,108,105,99,101,110,115,101,41,0,0,109,100,95,101,115,112,110,104,110,0,0,0,0,0,0,0,51,32,67,111,105,110,115,32,49,32,80,108,97,121,0,0,70,45,49,32,68,114,101,97,109,0,0,0,0,0,0,0,53,48,75,0,0,0,0,0,75,111,122,117,114,101,32,79,111,107,97,109,105,32,40,74,97,112,97,110,41,0,0,0,80,51,32,70,105,114,101,32,49,0,0,0,0,0,0,0,69,83,80,78,32,66,97,115,101,98,97,108,108,32,84,111,110,105,103,104,116,32,40,85,83,65,41,0,0,0,0,0,77,105,116,99,104,101,108,108,0,0,0,0,0,0,0,0,121,101,115,110,111,106,0,0,105,110,99,111,114,114,101,99,116,32,99,111,108,111,114,115,0,0,0,0,0,0,0,0,67,111,99,107,112,105,116,0,66,111,111,116,108,101,103,0,67,111,105,110,32,77,111,100,101,0,0,0,0,0,0,0,71,0,0,0,101,0,0,0,110,0,0,0,115,0,0,0,104,0,0,0,105,0,0,0,45,0,0,0,84,0,0,0,111,0,0,0,117,0,0,0,32,0,0,0,49,0,0,0,57,0,0,0,51,0,0,0,48,0,0,0,39,0,0,0,115,0,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,159,83,0,0,203,89,0,0,246,92,0,0,32,0,0,0,49,0,0,0,57,0,0,0,51,0,0,0,48,0,0,0,39,0,0,0,115,0,0,0,0,0,0,0,0,0,0,0,65,116,116,114,97,99,116,32,65,110,105,109,97,116,105,111,110,0,0,0,0,0,0,0,80,97,115,115,105,110,103,32,83,104,111,116,32,40,74,97,112,97,110,44,32,52,32,80,108,97,121,101,114,115,44,32,70,68,49,48,57,52,32,51,49,55,45,48,48,55,48,41,0,0,0,0,0,0,0,0,97,103,114,101,115,115,98,0,109,100,95,101,115,112,110,98,98,0,0,0,0,0,0,0,105,111,115,116,114,101,97,109,0,0,0,0,0,0,0,0,70,105,103,104,116,105,110,103,32,79,110,108,121,0,0,0,83,104,105,102,116,32,68,111,119,110,0,0,0,0,0,0,80,50,32,82,105,103,104,116,32,83,116,105,99,107,32,82,105,103,104,116,0,0,0,0,75,97,110,101,107,111,49,54,83,111,117,110,100,76,97,116,99,104,0,0,0,0,0,0,85,80,76,32,40,74,97,108,101,99,111,32,108,105,99,101,110,115,101,41,0,0,0,0,80,117,99,107,32,77,97,110,32,40,98,111,111,116,108,101,103,32,115,101,116,32,50,41,0,0,0,0,0,0,0,0,66,108,97,99,107,32,68,114,97,103,111,110,32,40,74,97,112,97,110,41,0,0,0,0,69,115,99,97,112,101,32,102,114,111,109,32,77,97,114,115,32,83,116,97,114,114,105,110,103,32,84,97,122,32,40,85,83,65,41,0,0,0,0,0,103,97,117,110,116,108,101,116,114,57,0,0,0,0,0,0,48,50,58,48,48,0,0,0,68,114,118,74,111,121,49,0,80,50,32,77,101,100,105,117,109,32,112,117,110,99,104,0,78,97,109,99,111,32,40,66,97,108,108,121,32,77,105,100,119,97,121,32,108,105,99,101,110,115,101,41,0,0,0,0,101,103,103,111,114,0,0,0,48,45,49,0,0,0,0,0,109,114,100,117,0,0,0,0,109,100,95,116,97,122,109,97,114,115,117,0,0,0,0,0,99,97,118,101,110,103,101,114,0,0,0,0,0,0,0,0,70,114,105,0,0,0,0,0,83,111,108,111,109,111,110,68,105,112,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,45,37,109,37,100,45,37,72,37,77,37,83,46,0,0,68,111,110,107,101,121,32,75,111,110,103,32,40,85,83,32,115,101,116,32,50,41,0,0,75,110,105,103,104,116,115,32,111,102,32,86,97,108,111,117,114,32,50,32,40,86,49,48,48,44,32,49,48,48,44,32,49,48,48,44,32,72,111,110,103,32,75,111,110,103,41,0,0,0,0,0,0,0,0,0,83,111,108,100,105,101,114,32,71,105,114,108,32,65,109,97,122,111,110,0,0,0,0,0,102,111,114,103,111,116,116,110,117,97,97,0,0,0,0,0,112,99,101,95,100,97,105,115,101,110,112,117,0,0,0,0,74,117,74,117,32,68,101,110,115,101,116,115,117,32,40,80,108,97,121,109,97,114,107,32,98,111,111,116,108,101,103,41,0,0,0,0,0,0,0,0,69,115,99,97,112,101,32,102,114,111,109,32,77,97,114,115,32,83,116,97,114,114,105,110,103,32,84,97,122,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,53,50,51,41,0,0,0,0,0,101,120,101,100,101,120,101,115,95,111,98,106,95,101,110,97,98,108,101,0,0,0,0,0,115,104,97,100,101,114,115,0,118,117,108,103,117,115,95,112,97,108,101,116,116,101,95,98,97,110,107,0,0,0,0,0,49,57,52,50,32,40,87,105,108,108,105,97,109,115,32,69,108,101,99,116,114,111,110,105,99,115,32,108,105,99,101,110,115,101,41,0,0,0,0,0,109,100,95,108,105,103,104,116,99,0,0,0,0,0,0,0,100,115,116,108,107,97,0,0,65,114,101,115,32,110,111,32,84,115,117,98,97,115,97,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,109,100,95,116,97,122,109,97,114,115,112,48,55,0,0,0,65,108,108,111,119,32,50,32,80,108,97,121,101,114,32,71,97,109,101,0,0,0,0,0,49,48,32,80,111,105,110,116,115,32,45,32,49,32,84,105,99,107,101,116,0,0,0,0,97,116,101,116,114,105,115,99,0,0,0,0,0,0,0,0,102,50,0,0,0,0,0,0,37,115,46,67,72,37,100,46,83,76,79,84,37,100,0,0,90,122,121,122,122,121,120,120,32,40,115,101,116,32,49,41,0,0,0,0,0,0,0,0,84,104,101,32,71,108,111,98,0,0,0,0,0,0,0,0,83,65,82,32,45,32,83,101,97,114,99,104,32,65,110,100,32,82,101,115,99,117,101,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,115,111,117,110,100,95,105,114,113,95,116,105,109,101,114,0,99,111,109,109,97,110,100,111,98,50,0,0,0,0,0,0,49,57,52,51,98,0,0,0,69,115,99,97,112,101,32,102,114,111,109,32,77,97,114,115,32,83,116,97,114,114,105,110,103,32,84,97,122,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,53,49,56,41,0,0,0,0,0,109,117,108,116,105,116,97,112,0,0,0,0,0,0,0,0,84,104,101,32,68,111,117,98,108,101,32,68,121,110,97,109,105,116,101,115,32,40,74,97,112,97,110,41,0,0,0,0,83,107,121,32,87,111,108,102,32,40,115,101,116,32,51,41,0,0,0,0,0,0,0,0,109,100,95,116,97,122,109,97,114,115,112,48,56,0,0,0,87,99,57,48,98,49,83,99,114,111,108,108,48,89,0,0,115,112,97,99,98,97,116,116,0,0,0,0,0,0,0,0,71,104,111,115,116,115,39,110,32,71,111,98,108,105,110,115,32,40,73,116,97,108,105,97,110,32,98,111,111,116,108,101,103,44,32,104,97,114,100,101,114,41,0,0,0,0,0,0,37,76,102,0,0,0,0,0,109,114,102,108,101,97,95,115,101,108,101,99,116,91,50,93,0,0,0,0,0,0,0,0,69,115,99,97,112,101,32,102,114,111,109,32,77,97,114,115,32,83,116,97,114,114,105,110,103,32,84,97,122,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,53,48,57,41,0,0,0,0,0,79,117,116,32,88,32,61,32,37,100,32,61,62,32,73,110,32,88,32,61,32,37,100,10,0,0,0,0,0,0,0,0,71,97,108,97,103,97,32,40,77,105,100,119,97,121,32,115,101,116,32,49,32,119,105,116,104,32,102,97,115,116,32,115,104,111,111,116,32,104,97,99,107,41,0,0,0,0,0,0,87,99,57,48,73,110,112,117,116,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,101,120,116,114,97,99,116,32,82,79,77,32,102,114,111,109,32,122,105,112,112,101,100,32,102,105,108,101,58,32,37,115,46,10,0,0,0,0,0,0,0,110,114,97,108,108,121,120,0,115,118,111,108,108,101,121,117,0,0,0,0,0,0,0,0,115,105,108,107,119,111,114,109,0,0,0,0,0,0,0,0,109,100,95,116,97,122,109,97,114,115,112,48,57,0,0,0,100,100,114,97,103,111,110,117,97,0,0,0,0,0,0,0,77,67,54,56,52,48,95,114,101,103,49,0,0,0,0,0,107,111,118,113,104,115,103,115,0,0,0,0,0,0,0,0,109,95,111,108,100,115,95,98,115,0,0,0,0,0,0,0,112,98,111,98,98,108,101,110,0,0,0,0,0,0,0,0,80,51,32,66,117,116,116,111,110,32,52,0,0,0,0,0,69,115,99,97,112,101,32,102,114,111,109,32,77,97,114,115,32,83,116,97,114,114,105,110,103,32,84,97,122,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,51,48,57,41,0,0,0,0,0,53,48,48,48,48,32,38,32,49,50,48,48,48,48,0,0,37,99,37,117,0,0,0,0,79,114,105,101,110,116,97,108,32,76,101,103,101,110,100,32,45,32,88,105,32,89,111,32,71,105,32,83,104,105,32,82,101,32,90,117,97,110,103,32,40,86,49,49,50,44,32,67,104,105,110,97,41,0,0,0,84,104,117,110,100,101,114,32,70,111,120,32,40,85,83,41,0,0,0,0,0,0,0,0,70,97,115,116,101,114,0,0,69,118,101,114,121,32,50,48,48,107,0,0,0,0,0,0,112,97,115,115,115,104,116,106,0,0,0,0,0,0,0,0,84,104,117,0,0,0,0,0,100,101,118,105,108,119,0,0,109,100,95,116,97,122,109,97,114,115,112,49,49,0,0,0,50,32,67,111,105,110,115,32,49,32,67,114,101,100,105,116,32,52,47,50,32,53,47,51,32,54,47,52,0,0,0,0,80,50,32,82,105,103,104,116,32,83,116,105,99,107,32,76,101,102,116,0,0,0,0,0,75,97,110,101,107,111,49,54,73,110,112,117,116,0,0,0,86,97,110,100,121,107,101,32,40,74,97,108,101,99,111,44,32,83,101,116,32,49,41,0,0,0,0,0,0,0,0,0,109,111,117,115,101,32,98,117,116,116,111,110,0,0,0,0,69,115,99,97,112,101,32,102,114,111,109,32,77,97,114,115,32,83,116,97,114,114,105,110,103,32,84,97,122,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,54,50,48,41,0,0,0,0,0,84,101,99,104,115,116,97,114,0,0,0,0,0,0,0,0,109,100,95,116,97,122,109,97,114,115,112,48,49,0,0,0,107,111,118,50,49,48,48,0,70,111,114,103,111,116,116,101,110,32,87,111,114,108,100,115,32,40,85,83,44,32,66,45,66,111,97,114,100,32,56,56,54,49,56,66,45,50,44,32,114,101,118,32,65,41,0,0,67,121,98,101,114,32,75,110,105,103,104,116,0,0,0,0,84,104,101,32,75,105,110,103,32,111,102,32,70,105,103,104,116,101,114,115,32,39,57,52,32,40,78,71,77,45,48,53,53,41,40,78,71,72,45,48,53,53,41,0,0,0,0,0,110,83,77,65,82,97,110,100,111,109,78,117,109,98,101,114,0,0,0,0,0,0,0,0,69,115,99,97,112,101,32,102,114,111,109,32,77,97,114,115,32,83,116,97,114,114,105,110,103,32,84,97,122,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,54,49,56,45,65,41,0,0,0,90,56,48,32,112,114,111,103,114,97,109,32,82,65,77,0,84,104,114,101,101,32,87,111,110,100,101,114,115,32,40,119,111,110,100,101,114,32,51,32,57,49,48,53,50,48,32,101,116,99,41,0,0,0,0,0,84,104,101,32,65,100,100,97,109,115,32,70,97,109,105,108,121,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,68,97,114,107,115,116,97,108,107,101,114,115,32,45,32,116,104,101,32,110,105,103,104,116,32,119,97,114,114,105,111,114,115,32,40,57,52,48,55,48,53,32,69,117,114,111,41,0,0,0,0,0,0,0,0,0,53,32,80,111,105,110,116,115,32,45,32,49,32,84,105,99,107,101,116,0,0,0,0,0,102,49,0,0,0,0,0,0,109,100,95,116,97,122,109,97,114,115,112,48,50,0,0,0,69,115,99,97,112,101,32,102,114,111,109,32,77,97,114,115,32,83,116,97,114,114,105,110,103,32,84,97,122,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,54,49,52,41,0,0,0,0,0,98,115,120,115,108,111,116,0,105,110,118,97,108,105,100,32,100,105,115,116,97,110,99,101,115,32,115,101,116,0,0,0,83,76,79,84,45,62,115,116,97,116,101,0,0,0,0,0,103,108,66,105,110,100,86,101,114,116,101,120,65,114,114,97,121,79,69,83,0,0,0,0,109,100,95,116,97,122,109,97,114,115,112,48,51,0,0,0,71,105,110,103,97,116,101,105,107,111,107,117,32,78,111,32,71,121,97,107,117,115,104,117,32,40,98,111,111,116,108,101,103,32,115,101,116,32,50,41,0,0,0,0,0,0,0,0,84,101,120,67,111,111,114,100,0,0,0,0,0,0,0,0,69,115,99,97,112,101,32,102,114,111,109,32,77,97,114,115,32,83,116,97,114,114,105,110,103,32,84,97,122,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,54,49,48,41,0,0,0,0,0,79,69,83,95,114,103,98,56,95,114,103,98,97,56,0,0,77,69,78,85,32,37,115,0,109,100,95,116,97,122,109,97,114,115,112,48,52,0,0,0,78,47,65,0,0,0,0,0,109,100,95,106,112,111,110,100,0,0,0,0,0,0,0,0,75,48,53,50,49,48,57,67,104,97,114,82,111,109,66,97,110,107,50,91,49,93,0,0,84,101,99,104,110,111,115,0,80,51,32,66,117,116,116,111,110,32,51,0,0,0,0,0,69,115,99,97,112,101,32,102,114,111,109,32,77,97,114,115,32,83,116,97,114,114,105,110,103,32,84,97,122,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,54,48,55,41,0,0,0,0,0,50,48,48,48,48,32,38,32,56,48,48,48,48,0,0,0,65,107,117,109,97,45,74,111,117,32,68,114,97,99,117,108,97,32,40,74,97,112,97,110,32,118,101,114,46,32,78,41,0,0,0,0,0,0,0,0,68,101,118,97,115,116,97,116,111,114,115,32,40,118,101,114,46,32,90,41,0,0,0,0,116,104,117,110,100,102,111,120,117,0,0,0,0,0,0,0,97,108,105,101,110,115,106,50,0,0,0,0,0,0,0,0,77,0,0,0,114,0,0,0,46,0,0,0,32,0,0,0,71,0,0,0,111,0,0,0,101,0,0,0,109,0,0,0,111,0,0,0,110,0,0,0,32,0,0,0,148,78,0,0,243,83,0,0,91,136,0,0,128,149,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,53,48,107,32,65,110,100,32,69,118,101,114,121,32,50,48,48,107,0,0,0,0,0,53,48,107,32,50,53,48,107,32,53,48,48,107,0,0,0,80,97,114,111,100,105,117,115,32,68,65,33,32,40,65,115,105,97,41,0,0,0,0,0,80,97,115,115,105,110,103,32,83,104,111,116,32,40,87,111,114,108,100,44,32,52,32,80,108,97,121,101,114,115,44,32,70,68,49,48,57,52,32,51,49,55,45,48,48,55,52,41,0,0,0,0,0,0,0,0,87,101,100,0,0,0,0,0,109,100,95,116,97,122,109,97,114,115,112,48,53,0,0,0,80,50,32,82,105,103,104,116,32,83,116,105,99,107,32,68,111,119,110,0,0,0,0,0,75,97,110,101,107,111,49,54,68,105,112,0,0,0,0,0,116,104,117,110,100,101,114,120,98,0,0,0,0,0,0,0,118,97,110,100,121,107,101,106,97,108,0,0,0,0,0,0,85,80,68,55,55,53,57,68,101,118,105,99,101,0,0,0,67,104,97,114,97,99,116,101,114,32,116,101,115,116,0,0,69,115,99,97,112,101,32,102,114,111,109,32,77,97,114,115,32,83,116,97,114,114,105,110,103,32,84,97,122,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,54,48,50,41,0,0,0,0,0,67,111,110,116,114,97,32,40,74,97,112,97,110,32,98,111,111,116,108,101,103,44,32,115,101,116,32,50,41,0,0,0,80,50,32,87,101,97,107,32,112,117,110,99,104,0,0,0,120,109,101,110,50,112,101,0,71,111,114,107,97,110,115,0,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,71,76,93,58,32,83,104,97,100,101,114,32,114,101,112,111,114,116,115,32,97,32,71,76,69,83,50,32,115,116,121,108,101,32,115,104,97,100,101,114,46,10,0,0,71,88,55,56,53,0,0,0,109,100,95,116,97,122,109,97,114,115,112,48,54,0,0,0,103,114,97,100,105,117,115,51,95,99,112,117,98,95,101,110,97,98,108,101,0,0,0,0,98,108,111,99,107,104,108,0,49,57,120,120,106,114,49,0,75,0,0,0,110,0,0,0,105,0,0,0,103,0,0,0,104,0,0,0,116,0,0,0,115,0,0,0,32,0,0,0,111,0,0,0,102,0,0,0,32,0,0,0,86,0,0,0,97,0,0,0,108,0,0,0,111,0,0,0,117,0,0,0,114,0,0,0,32,0,0,0,50,0,0,0,0,0,0,0,9,78,0,0,253,86,0,0,24,98,0,0,170,126,0,0,32,0,0,0,50,0,0,0,32,0,0,0,40,0,0,0,86,0,0,0,49,0,0,0,48,0,0,0,49,0,0,0,44,0,0,0,32,0,0,0,49,0,0,0,48,0,0,0,49,0,0,0,44,0,0,0,32,0,0,0,49,0,0,0,48,0,0,0,48,0,0,0,44,0,0,0,32,0,0,0,72,0,0,0,111,0,0,0,110,0,0,0,103,0,0,0,32,0,0,0,75,0,0,0,111,0,0,0,110,0,0,0,103,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,118,101,110,100,101,116,116,97,106,0,0,0,0,0,0,0,102,111,114,103,111,116,116,110,117,97,0,0,0,0,0,0,112,99,101,95,99,121,107,110,105,103,104,116,0,0,0,0,115,105,109,112,115,111,110,115,50,112,106,0,0,0,0,0,111,118,101,114,108,97,121,37,117,95,102,117,108,108,95,115,99,114,101,101,110,0,0,0,69,115,99,97,112,101,32,102,114,111,109,32,77,97,114,115,32,83,116,97,114,114,105,110,103,32,84,97,122,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,52,49,56,41,0,0,0,0,0,109,100,95,97,100,100,102,97,109,0,0,0,0,0,0,0,116,109,110,116,106,0,0,0,100,115,116,108,107,0,0,0,115,99,97,108,101,95,121,37,117,0,0,0,0,0,0,0,98,98,109,97,110,119,0,0,50,32,80,108,97,121,101,114,115,32,76,105,118,101,115,0,107,117,110,103,102,117,98,50,0,0,0,0,0,0,0,0,83,116,111,112,32,77,111,100,101,0,0,0,0,0,0,0,50,32,80,111,105,110,116,115,32,45,32,49,32,84,105,99,107,101,116,0,0,0,0,0,107,112,95,109,105,110,117,115,0,0,0,0,0,0,0,0,109,100,95,116,97,122,109,97,114,115,112,49,48,0,0,0,86,105,103,105,108,97,110,116,101,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,80,97,114,97,100,105,115,101,32,67,111,46,32,76,116,100,46,0,0,0,0,0,0,0,82,45,84,121,112,101,32,40,87,111,114,108,100,32,98,111,111,116,108,101,103,41,0,0,69,115,99,97,112,101,32,102,114,111,109,32,77,97,114,115,32,83,116,97,114,114,105,110,103,32,84,97,122,32,40,69,117,114,111,41,0,0,0,0,98,115,120,0,0,0,0,0,75,48,53,51,50,52,55,32,82,97,109,0,0,0,0,0,109,100,95,116,97,122,109,97,114,115,0,0,0,0,0,0,103,116,101,105,107,111,98,50,0,0,0,0,0,0,0,0,75,111,117,116,101,116,115,117,32,84,101,105,107,111,107,117,32,40,74,112,110,41,0,0,109,100,95,107,111,116,101,116,101,105,107,0,0,0,0,0,69,110,101,109,121,39,115,32,87,101,97,112,111,110,32,83,112,101,101,100,0,0,0,0,80,51,32,66,117,116,116,111,110,32,50,0,0,0,0,0,83,116,101,101,108,32,69,109,112,105,114,101,32,40,85,83,65,41,0,0,0,0,0,0,70,97,115,116,0,0,0,0,84,104,117,110,100,101,114,32,70,111,120,32,40,74,97,112,97,110,41,0,0,0,0,0,49,53,48,48,48,48,32,79,110,108,121,0,0,0,0,0,50,48,75,0,0,0,0,0,49,48,48,107,32,65,110,100,32,69,118,101,114,121,32,50,48,48,107,0,0,0,0,0,52,48,107,32,50,48,48,107,32,53,48,48,107,0,0,0,112,97,115,115,115,104,116,97,0,0,0,0,0,0,0,0,84,117,101,0,0,0,0,0,109,100,95,115,116,101,101,108,101,109,112,0,0,0,0,0,80,50,32,82,105,103,104,116,32,83,116,105,99,107,32,85,112,0,0,0,0,0,0,0,86,97,110,100,121,107,101,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,82,97,109,67,84,66,54,52,107,0,0,0,0,0,0,0,69,109,112,105,114,101,32,111,102,32,83,116,101,101,108,32,40,69,117,114,111,41,0,0,109,100,95,101,109,112,115,116,101,101,108,0,0,0,0,0,75,110,105,103,104,116,115,32,111,102,32,86,97,108,111,117,114,32,50,32,40,86,49,48,49,44,32,49,48,49,44,32,49,48,48,44,32,72,111,110,103,32,75,111,110,103,41,0,0,0,0,0,0,0,0,0,70,111,114,103,111,116,116,101,110,32,87,111,114,108,100,115,32,40,85,83,44,32,66,45,66,111,97,114,100,32,56,56,54,49,56,66,45,50,44,32,82,101,118,32,67,41,0,0,84,111,110,107,105,110,32,72,111,117,115,101,0,0,0,0,83,0,0,0,117,0,0,0,112,0,0,0,101,0,0,0,114,0,0,0,32,0,0,0,83,0,0,0,105,0,0,0,100,0,0,0,101,0,0,0,107,0,0,0,105,0,0,0,99,0,0,0,107,0,0,0,115,0,0,0,0,0,0,0,151,95,0,0,185,112,0,0,139,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,69,108,105,116,115,101,114,105,101,110,32,57,54,32,40,83,119,101,41,0,0,0,0,0,83,117,112,101,114,32,83,109,97,115,104,32,84,86,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,68,105,109,97,104,111,111,32,40,48,48,48,49,50,49,32,85,83,65,41,0,0,0,0,115,99,97,108,101,95,120,37,117,0,0,0,0,0,0,0,49,32,80,111,105,110,116,32,45,32,49,32,84,105,99,107,101,116,0,0,0,0,0,0,107,112,95,112,108,117,115,0,109,100,95,101,108,105,116,57,54,0,0,0,0,0,0,0,69,108,105,116,115,101,114,105,101,110,32,57,53,32,40,83,119,101,41,0,0,0,0,0,115,97,118,101,115,116,97,116,101,0,0,0,0,0,0,0,37,115,37,117,0,0,0,0,109,100,95,101,108,105,116,57,53,0,0,0,0,0,0,0,71,105,110,103,97,116,101,105,107,111,107,117,32,78,111,32,71,121,97,107,117,115,104,117,32,40,98,111,111,116,108,101,103,32,115,101,116,32,49,41,0,0,0,0,0,0,0,0,86,101,114,121,32,76,111,119,0,0,0,0,0,0,0,0,75,111,110,97,109,105,83,111,117,110,100,67,111,110,116,114,111,108,0,0,0,0,0,0,83,111,102,116,32,86,105,115,105,111,110,0,0,0,0,0,69,108,105,109,105,110,97,116,101,32,68,111,119,110,32,40,74,112,110,41,0,0,0,0,71,97,108,76,102,111,70,114,101,113,0,0,0,0,0,0,69,110,101,109,121,32,69,110,99,111,117,110,116,101,114,32,82,97,116,101,0,0,0,0,100,111,117,98,108,101,100,114,0,0,0,0,0,0,0,0,80,51,32,66,117,116,116,111,110,32,49,0,0,0,0,0,109,100,95,101,108,105,109,100,111,119,110,0,0,0,0,0,105,110,112,117,116,95,100,101,118,105,99,101,95,112,37,117,0,0,0,0,0,0,0,0,103,114,97,100,105,117,115,51,0,0,0,0,0,0,0,0,116,104,117,110,100,102,111,120,106,0,0,0,0,0,0,0,49,48,48,107,32,53,48,48,107,0,0,0,0,0,0,0,50,48,75,32,54,48,75,32,54,48,75,43,0,0,0,0,69,118,101,114,121,32,49,48,48,107,0,0,0,0,0,0,51,48,107,32,49,48,48,107,32,52,48,48,107,0,0,0,77,111,114,101,0,0,0,0,80,97,115,115,105,110,103,32,83,104,111,116,32,40,87,111,114,108,100,44,32,50,32,80,108,97,121,101,114,115,44,32,70,68,49,48,57,52,32,51,49,55,45,48,48,56,48,41,0,0,0,0,0,0,0,0,77,111,110,0,0,0,0,0,69,108,101,109,101,110,116,97,108,32,77,97,115,116,101,114,32,40,74,112,110,41,0,0,118,97,110,100,121,107,101,0,82,97,109,67,117,114,80,97,108,0,0,0,0,0,0,0,109,100,95,101,108,101,109,97,115,116,106,0,0,0,0,0,103,111,114,107,97,110,115,0,69,108,101,109,101,110,116,97,108,32,77,97,115,116,101,114,32,40,85,83,65,41,0,0,107,111,118,50,49,48,49,0,102,111,114,103,111,116,116,110,117,49,0,0,0,0,0,0,67,121,98,101,114,32,68,111,100,103,101,0,0,0,0,0,83,117,112,101,114,32,83,105,100,101,107,105,99,107,115,32,47,32,84,111,107,117,116,101,110,32,79,117,0,0,0,0,109,100,95,101,108,101,109,97,115,116,0,0,0,0,0,0,109,100,95,115,115,109,97,115,104,116,118,0,0,0,0,0,100,105,109,97,104,111,111,117,0,0,0,0,0,0,0,0,115,99,97,108,101,37,117,0,49,32,67,111,105,110,32,32,56,32,80,108,97,121,115,0,80,111,105,110,116,115,32,80,101,114,32,84,105,99,107,101,116,0,0,0,0,0,0,0,115,117,98,116,114,97,99,116,0,0,0,0,0,0,0,0,69,108,32,86,105,101,110,116,111,32,40,74,112,110,41,0,0,0,0,0,0,0,0,0,109,100,95,101,108,118,105,101,110,116,111,106,0,0,0,0,100,117,97,108,97,110,97,108,111,103,0,0,0,0,0,0,85,112,32,68,45,112,97,100,0,0,0,0,0,0,0,0,69,108,32,86,105,101,110,116,111,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,103,116,101,105,107,111,107,98,0,0,0,0,0,0,0,0,80,108,97,121,101,114,39,115,32,80,111,119,101,114,0,0,109,100,95,101,108,118,105,101,110,116,111,0,0,0,0,0,69,99,99,111,32,74,114,46,32,40,85,83,65,44,32,79,99,101,97,110,105,97,44,32,49,57,57,53,48,51,41,0,0,0,0,0,0,0,0,0,80,51,32,85,115,101,0,0,109,100,95,101,99,99,111,106,114,49,0,0,0,0,0,0,72,101,114,111,32,115,112,101,101,100,0,0,0,0,0,0,99,117,115,116,111,109,95,98,103,109,95,101,110,97,98,108,101,0,0,0,0,0,0,0,78,85,76,76,0,0,0,0,49,48,48,107,32,52,48,48,107,0,0,0,0,0,0,0,83,108,111,119,101,114,0,0,86,105,115,99,111,32,40,82,111,109,115,116,97,114,41,0,50,48,107,32,32,56,48,107,32,51,48,48,107,0,0,0,76,101,115,115,0,0,0,0,119,99,57,48,0,0,0,0,112,97,115,115,115,104,116,0,83,117,110,0,0,0,0,0,69,99,99,111,32,74,114,46,32,40,85,83,65,44,32,79,99,101,97,110,105,97,44,32,49,57,57,53,48,50,41,0,0,0,0,0,0,0,0,0,80,50,32,76,101,102,116,32,83,116,105,99,107,32,82,105,103,104,116,0,0,0,0,0,84,105,109,101,114,32,83,112,101,101,100,32,40,66,111,120,32,76,111,103,105,99,41,0,66,108,97,99,107,32,72,101,97,114,116,32,40,74,97,112,97,110,41,0,0,0,0,0,109,100,95,101,99,99,111,106,114,0,0,0,0,0,0,0,84,101,108,107,111,0,0,0,103,97,108,97,120,105,97,110,116,0,0,0,0,0,0,0,69,99,99,111,32,45,32,84,104,101,32,84,105,100,101,115,32,111,102,32,84,105,109,101,32,40,85,83,65,41,0,0,75,0,0,0,110,0,0,0])
.concat([105,0,0,0,103,0,0,0,104,0,0,0,116,0,0,0,115,0,0,0,32,0,0,0,111,0,0,0,102,0,0,0,32,0,0,0,86,0,0,0,97,0,0,0,108,0,0,0,111,0,0,0,117,0,0,0,114,0,0,0,32,0,0,0,50,0,0,0,0,0,0,0,9,78,0,0,253,86,0,0,24,98,0,0,170,126,0,0,32,0,0,0,50,0,0,0,32,0,0,0,40,0,0,0,86,0,0,0,49,0,0,0,48,0,0,0,50,0,0,0,44,0,0,0,32,0,0,0,49,0,0,0,48,0,0,0,49,0,0,0,44,0,0,0,32,0,0,0,49,0,0,0,48,0,0,0,48,0,0,0,44,0,0,0,32,0,0,0,72,0,0,0,111,0,0,0,110,0,0,0,103,0,0,0,32,0,0,0,75,0,0,0,111,0,0,0,110,0,0,0,103,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,70,111,114,103,111,116,116,101,110,32,87,111,114,108,100,115,32,40,85,83,44,32,66,45,66,111,97,114,100,32,56,56,54,50,49,66,45,50,44,32,114,101,118,32,67,41,0,0,112,99,101,95,99,121,98,101,114,100,111,100,0,0,0,0,115,112,121,0,0,0,0,0,109,100,95,101,99,99,111,50,117,0,0,0,0,0,0,0,83,117,112,101,114,32,77,111,110,97,99,111,32,71,80,32,40,69,117,114,111,44,32,74,112,110,44,32,82,101,118,46,32,65,41,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,82,71,85,73,93,58,32,79,112,101,110,105,110,103,32,104,105,115,116,111,114,121,58,32,37,115,46,10,0,0,0,0,0,0,0,0,176,48,0,0,236,48,0,0,252,48,0,0,200,48,0,0,84,155,0,0,213,108,0,0,39,89,0,0,92,79,0,0,38,98,0,0,32,0,0,0,40,0,0,0,71,0,0,0,114,0,0,0,101,0,0,0,97,0,0,0,116,0,0,0,32,0,0,0,77,0,0,0,97,0,0,0,104,0,0,0,111,0,0,0,117,0,0,0,32,0,0,0,68,0,0,0,97,0,0,0,105,0,0,0,115,0,0,0,97,0,0,0,107,0,0,0,117,0,0,0,115,0,0,0,101,0,0,0,110,0,0,0,32,0,0,0,48,0,0,0,48,0,0,0,48,0,0,0,49,0,0,0,50,0,0,0,49,0,0,0,32,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,73,110,118,97,108,105,100,32,97,116,116,114,105,98,117,116,101,46,10,0,0,0,0,0,0,0,0,73,110,112,117,116,32,68,101,118,105,99,101,0,0,0,0,84,105,99,107,101,116,32,68,105,115,112,101,110,115,101,114,0,0,0,0,0,0,0,0,83,116,111,110,101,97,103,101,32,40,98,111,111,116,108,101,103,32,111,102,32,67,97,118,101,109,97,110,32,78,105,110,106,97,41,0,0,0,0,0,97,100,100,0,0,0,0,0,69,99,99,111,32,45,32,84,104,101,32,84,105,100,101,115,32,111,102,32,84,105,109,101,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,32,88,49,49,44,32,49,57,57,52,48,52,49,51,41,0,0,0,0,0,0,0,0,0,109,100,95,101,99,99,111,50,112,120,49,49,0,0,0,0,106,117,115,116,105,102,105,101,114,115,0,0,0,0,0,0,109,97,103,100,114,111,112,112,0,0,0,0,0,0,0,0,69,99,99,111,32,116,104,101,32,68,111,108,112,104,105,110,32,73,73,32,40,74,112,110,41,0,0,0,0,0,0,0,71,105,110,103,97,116,101,105,107,111,107,117,32,78,111,32,71,121,97,107,117,115,104,117,0,0,0,0,0,0,0,0,84,114,105,111,32,84,104,101,32,80,117,110,99,104,32,45,32,78,101,118,101,114,32,70,111,114,103,101,116,32,77,101,46,46,46,32,40,74,97,112,97,110,41,0,0,0,0,0,109,100,95,101,99,99,111,50,106,0,0,0,0,0,0,0,99,104,105,112,45,62,110,111,105,115,101,95,102,0,0,0,69,99,99,111,32,45,32,84,104,101,32,84,105,100,101,115,32,111,102,32,84,105,109,101,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,52,50,57,41,0,0,0,0,0,69,110,101,109,121,39,115,32,86,105,116,97,108,105,116,121,0,0,0,0,0,0,0,0,115,115,105,100,101,107,105,51,0,0,0,0,0,0,0,0,80,51,32,83,101,108,101,99,116,0,0,0,0,0,0,0,109,100,95,101,99,99,111,50,112,50,0,0,0,0,0,0,116,105,103,101,114,104,73,110,112,117,116,0,0,0,0,0,115,111,117,110,100,95,109,111,100,101,0,0,0,0,0,0,84,104,117,110,100,101,114,32,70,111,120,32,40,87,111,114,108,100,41,0,0,0,0,0,49,48,48,107,32,50,48,48,107,32,51,48,48,107,32,52,52,48,107,0,0,0,0,0,66,97,108,108,32,83,112,101,101,100,0,0,0,0,0,0,67,111,112,121,114,105,103,104,116,0,0,0,0,0,0,0,67,111,108,111,117,114,32,67,104,97,110,103,101,0,0,0,77,86,80,32,40,115,101,116,32,49,44,32,74,97,112,97,110,44,32,70,68,49,48,57,52,32,51,49,55,45,48,49,52,50,41,0,0,0,0,0,83,97,116,117,114,100,97,121,0,0,0,0,0,0,0,0,69,99,99,111,32,45,32,84,104,101,32,84,105,100,101,115,32,111,102,32,84,105,109,101,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,65,108,116,41,0,0,87,97,116,101,114,32,77,97,116,99,104,32,40,51,49,53,45,53,48,54,52,41,0,0,78,117,109,98,101,114,32,111,102,32,77,97,99,104,105,110,101,115,0,0,0,0,0,0,78,86,82,97,109,0,0,0,76,105,118,101,115,32,40,77,97,103,105,99,32,69,121,101,41,0,0,0,0,0,0,0,98,108,107,104,101,97,114,116,106,0,0,0,0,0,0,0,83,110,100,66,97,110,107,0,84,101,110,100,101,114,0,0,109,100,95,101,99,99,111,50,112,49,0,0,0,0,0,0,77,114,46,32,84,78,84,0,0,0,0,0,0,0,0,0,69,99,99,111,32,45,32,84,104,101,32,84,105,100,101,115,32,111,102,32,84,105,109,101,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,0,50,80,32,67,97,110,32,83,116,97,114,116,32,65,110,121,116,105,109,101,0,0,0,0,75,110,105,103,104,116,115,32,111,102,32,86,97,108,111,117,114,32,50,32,40,86,49,48,50,44,32,49,48,49,44,32,49,48,48,44,32,72,111,110,103,32,75,111,110,103,41,0,0,0,0,0,0,0,0,0,102,111,114,103,111,116,116,110,117,0,0,0,0,0,0,0,70,0,0,0,97,0,0,0,116,0,0,0,97,0,0,0,108,0,0,0,32,0,0,0,70,0,0,0,117,0,0,0,114,0,0,0,121,0,0,0,32,0,0,0,50,0,0,0,0,0,0,0,19,153,0,0,252,114,0,0,29,79,0,0,172,138,0,0,18,255,0,0,32,0,0,0,45,0,0,0,32,0,0,0,176,101,0,0,95,48,0,0,106,48,0,0,139,48,0,0,216,149,0,0,32,0,0,0,40,0,0,0,78,0,0,0,71,0,0,0,77,0,0,0,45,0,0,0,48,0,0,0,52,0,0,0,55,0,0,0,41,0,0,0,40,0,0,0,78,0,0,0,71,0,0,0,72,0,0,0,45,0,0,0,48,0,0,0,52,0,0,0,55,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,101,115,101,114,116,32,65,115,115,97,117,108,116,32,40,85,83,41,0,0,0,0,0,109,100,95,101,99,99,111,50,112,0,0,0,0,0,0,0,109,100,95,115,109,103,112,0,46,114,101,116,114,111,97,114,99,104,45,103,97,109,101,45,104,105,115,116,111,114,121,46,116,120,116,0,0,0,0,0,71,114,101,97,116,32,77,97,104,111,117,32,68,97,105,115,97,107,117,115,101,110,32,40,48,48,48,49,50,49,32,74,97,112,97,110,41,0,0,0,115,99,97,108,101,95,116,121,112,101,95,121,37,117,0,0,55,32,67,111,105,110,115,32,49,32,80,108,97,121,0,0,101,115,99,97,112,101,0,0,69,99,99,111,32,45,32,84,104,101,32,84,105,100,101,115,32,111,102,32,84,105,109,101,32,40,69,117,114,111,41,0,0,0,0,0,0,0,0,0,109,100,95,101,99,99,111,50,0,0,0,0,0,0,0,0,106,117,115,116,105,102,105,101,114,0,0,0,0,0,0,0,99,104,101,108,110,111,118,0,69,99,99,111,32,116,104,101,32,68,111,108,112,104,105,110,32,40,74,112,110,41,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,89,83,84,69,77,95,68,73,82,69,67,84,79,82,89,58,32,34,37,115,34,46,10,0,0,0,0,0,103,116,101,105,107,111,107,117,0,0,0,0,0,0,0,0,103,121,114,117,115,115,0,0,109,100,95,101,99,99,111,106,0,0,0,0,0,0,0,0,69,99,99,111,32,116,104,101,32,68,111,108,112,104,105,110,32,40,69,117,114,111,44,32,85,83,65,44,32,75,111,114,41,0,0,0,0,0,0,0,99,111,98,114,97,99,111,109,0,0,0,0,0,0,0,0,83,116,97,103,101,32,67,108,101,97,114,32,66,111,110,117,115,0,0,0,0,0,0,0,80,51,32,80,105,110,0,0,109,100,95,101,99,99,111,0,110,80,114,111,116,101,99,116,73,110,100,101,120,0,0,0,99,117,114,114,101,110,116,95,114,101,115,111,108,117,116,105,111,110,95,105,100,0,0,0,116,104,117,110,100,102,111,120,0,0,0,0,0,0,0,0,54,48,75,32,49,48,48,75,32,54,48,75,43,0,0,0,82,83,0,0,109,105,0,0,60,138,0,0,248,102,0,0,0,0,0,0,83,0,0,0,111,0,0,0,116,0,0,0,115,0,0,0,117,0,0,0,103,0,0,0,121,0,0,0,111,0,0,0,32,0,0,0,83,0,0,0,104,0,0,0,111,0,0,0,117,0,0,0,115,0,0,0,104,0,0,0,111,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,109,118,112,106,0,0,0,0,70,114,105,100,97,121,0,0,69,97,114,116,104,119,111,114,109,32,74,105,109,32,50,32,40,85,83,65,41,0,0,0,119,109,97,116,99,104,0,0,80,50,32,76,101,102,116,32,83,116,105,99,107,32,76,101,102,116,0,0,0,0,0,0,77,83,77,54,50,57,53,66,97,110,107,49,0,0,0,0,84,105,109,101,114,32,83,112,101,101,100,32,40,77,97,103,105,99,32,69,121,101,41,0,66,108,97,99,107,32,72,101,97,114,116,0,0,0,0,0,109,117,116,97,110,116,102,95,112,111,114,116,95,48,101,95,104,97,99,107,0,0,0,0,109,100,95,101,106,105,109,50,117,0,0,0,0,0,0,0,69,120,99,105,116,105,110,103,0,0,0,0,0,0,0,0,68,105,112,32,52,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,109,101,109,111,114,121,32,102,111,114,32,115,97,118,101,32,115,116,97,116,101,32,98,117,102,102,101,114,46,10,0,0,68,111,119,110,84,111,119,110,32,47,32,77,111,107,117,103,101,107,105,32,40,74,111,121,115,116,105,99,107,32,72,97,99,107,41,0,0,0,0,0,109,114,116,110,116,0,0,0,100,114,103,119,50,0,0,0,69,97,114,116,104,119,111,114,109,32,74,105,109,32,50,32,40,69,117,114,111,41,0,0,50,48,48,48,48,48,32,53,48,48,48,48,48,0,0,0,107,111,118,50,49,48,50,0,67,121,98,101,114,32,67,111,114,101,0,0,0,0,0,0,70,97,116,97,108,32,70,117,114,121,32,50,32,47,32,71,97,114,111,117,32,68,101,110,115,101,116,115,117,32,50,32,45,32,97,114,97,116,97,45,110,97,114,117,32,116,97,116,97,107,97,105,32,40,78,71,77,45,48,52,55,41,40,78,71,72,45,48,52,55,41,0,0,0,0,0,0,0,0,0,109,100,95,101,106,105,109,50,0,0,0,0,0,0,0,0,84,104,101,32,83,116,111,114,121,32,111,102,32,84,104,111,114,32,45,32,65,32,83,117,99,99,101,115,115,111,114,32,111,102,32,84,104,101,32,76,105,103,104,116,32,40,70,114,97,41,0,0,0,0,0,0,102,114,111,110,116,101,110,100,47,109,101,110,117,47,46,46,47,46,46,47,103,101,110,101,114,97,108,46,104,0,0,0,103,109,97,104,111,117,0,0,115,99,97,108,101,95,116,121,112,101,95,120,37,117,0,0,49,32,80,108,97,121,101,114,32,76,105,118,101,115,0,0,112,97,114,101,110,116,114,111,109,58,32,37,115,10,0,0,69,97,114,116,104,119,111,114,109,32,74,105,109,32,40,85,83,65,41,0,0,0,0,0,82,46,111,112,99,111,100,101,0,0,0,0,0,0,0,0,37,48,56,120,58,32,32,85,110,100,101,102,105,110,101,100,32,105,110,115,116,114,117,99,116,105,111,110,10,0,0,0,109,100,95,101,106,105,109,117,0,0,0,0,0,0,0,0,115,99,111,112,101,0,0,0,82,111,104,103,97,32,65,114,109,111,114,32,70,111,114,99,101,32,40,85,83,32,118,49,46,48,41,0,0,0,0,0,82,45,62,112,111,114,116,50,95,100,100,114,0,0,0,0,84,97,105,116,111,32,67,111,114,112,111,114,97,116,105,111,110,0,0,0,0,0,0,0,78,111,114,109,97,108,32,109,111,100,101,0,0,0,0,0,65,114,109,101,100,32,80,111,108,105,99,101,32,66,97,116,114,105,100,101,114,32,40,75,111,114,101,97,41,32,40,70,114,105,32,70,101,98,32,49,51,32,49,57,57,56,41,0,0,0,0,0,0,0,0,0,70,105,120,69,105,103,104,116,32,40,72,111,110,103,32,75,111,110,103,41,0,0,0,0,69,97,114,116,104,119,111,114,109,32,74,105,109,32,40,69,117,114,111,41,0,0,0,0,84,105,103,101,114,32,72,101,108,105,32,40,98,111,111,116,108,101,103,44,32,115,101,116,32,51,41,0,0,0,0,0,78,111,114,109,97,108,32,99,111,110,116,105,110,117,101,0,109,100,95,101,106,105,109,0,68,0,0,0,111,0,0,0,103,0,0,0,121,0,0,0,117,0,0,0,117,0,0,0,110,0,0,0,32,0,0,0,40,0,0,0,116,0,0,0,101,0,0,0,115,0,0,0,116,0,0,0,32,0,0,0,108,0,0,0,111,0,0,0,99,0,0,0,97,0,0,0,116,0,0,0,105,0,0,0,111,0,0,0,110,0,0,0,32,0,0,0,118,0,0,0,101,0,0,0,114,0,0,0,115,0,0,0,105,0,0,0,111,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,68,0,0,0,111,0,0,0,103,0,0,0,121,0,0,0,117,0,0,0,117,0,0,0,110,0,0,0,32,0,0,0,201,48,0,0,173,48,0,0,229,48,0,0,252,48,0,0,243,48,0,0,1,255,0,0,1,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,97,116,116,108,101,32,71,97,114,101,103,103,97,32,40,72,111,110,103,32,75,111,110,103,32,47,32,65,117,115,116,114,105,97,63,41,32,40,83,97,116,32,70,101,98,32,51,32,49,57,57,54,41,0,0,108,111,99,107,101,100,0,0,69,97,114,110,101,115,116,32,69,118,97,110,115,32,40,85,83,65,41,0,0,0,0,0,79,117,116,32,90,111,110,101,32,40,115,101,116,32,53,41,0,0,0,0,0,0,0,0,73,110,118,101,114,116,0,0,80,51,32,74,117,109,112,0,109,100,95,101,97,114,110,101,115,116,0,0,0,0,0,0,110,83,116,97,116,117,115,73,110,100,101,120,0,0,0,0,101,110,97,98,108,101,95,105,110,116,101,114,114,117,112,116,91,49,93,0,0,0,0,0,115,111,102,116,95,102,105,108,116,101,114,95,105,110,100,101,120,0,0,0,0,0,0,0,77,97,106,101,115,116,105,99,32,84,119,101,108,118,101,32,45,32,84,104,101,32,83,112,97,99,101,32,73,110,118,97,100,101,114,115,32,80,97,114,116,32,73,86,32,40,74,97,112,97,110,41,0,0,0,0,65,108,116,101,114,110,97,116,101,0,0,0,0,0,0,0,68,114,97,103,111,110,110,105,110,106,97,32,40,98,111,111,116,108,101,103,32,115,101,116,32,50,41,0,0,0,0,0,100,101,97,100,99,111,110,120,0,0,0,0,0,0,0,0,55,48,48,48,48,32,49,53,48,48,48,48,0,0,0,0,108,107,97,103,101,98,50,0,77,86,80,32,40,115,101,116,32,50,44,32,85,83,44,32,70,68,49,48,57,52,32,51,49,55,45,48,49,52,51,41,0,0,0,0,0,0,0,0,84,104,117,114,115,100,97,121,0,0,0,0,0,0,0,0,69,65,32,83,112,111,114,116,115,32,68,111,117,98,108,101,32,72,101,97,100,101,114,32,40,69,117,114,111,41,0,0,87,111,110,100,101,114,32,66,111,121,32,68,101,108,117,120,101,0,0,0,0,0,0,0,77,83,77,54,50,57,53,66,97,110,107,48,0,0,0,0,83,111,102,116,32,97,110,100,32,72,97,114,100,0,0,0,69,120,116,101,114,109,105,110,97,116,105,111,110,32,40,74,97,112,97,110,41,0,0,0,98,108,107,104,101,97,114,116,0,0,0,0,0,0,0,0,84,111,117,114,110,97,109,101,110,116,32,65,114,107,97,110,111,105,100,32,40,85,83,41,0,0,0,0,0,0,0,0,71,97,116,101,32,111,102,32,68,111,111,109,32,40,85,83,32,114,101,118,105,115,105,111,110,32,49,41,0,0,0,0,82,97,110,107,105,110,103,32,77,117,115,105,99,0,0,0,109,100,95,101,97,115,112,111,114,116,115,0,0,0,0,0,100,111,119,110,116,111,119,110,106,0,0,0,0,0,0,0,110,97,115,116,97,114,0,0,69,121,101,115,32,40,98,111,111,116,108,101,103,32,115,101,116,32,50,44,32,100,101,99,114,121,112,116,101,100,41,0,0,0,0,0,0,0,0,0,66,97,116,116,108,101,32,83,104,97,114,107,32,40,87,111,114,108,100,41,0,0,0,0,118,100,99,95,99,117,114,114,101,110,116,95,115,101,103,109,101,110,116,95,108,105,110,101,91,105,93,0,0,0,0,0,99,53,56,57,0,0,0,0,78,72,76,32,72,111,99,107,101,121,32,40,85,83,65,41,0,0,0,0,0,0,0,0,99,112,115,51,95,99,117,114,114,101,110,116,95,101,101,112,114,111,109,95,114,101,97,100,0,0,0,0,0,0,0,0,111,112,119,111,108,102,0,0,49,48,48,48,48,48,32,51,48,48,48,48,48,32,54,48,48,48,48,48,0,0,0,0,67,97,100,97,115,104,32,40,73,116,97,108,121,41,0,0,75,0,0,0,110,0,0,0,105,0,0,0,103,0,0,0,104,0,0,0,116,0,0,0,115,0,0,0,32,0,0,0,111,0,0,0,102,0,0,0,32,0,0,0,86,0,0,0,97,0,0,0,108,0,0,0,111,0,0,0,117,0,0,0,114,0,0,0,32,0,0,0,50,0,0,0,0,0,0,0,9,78,0,0,253,86,0,0,24,98,0,0,170,126,0,0,32,0,0,0,50,0,0,0,32,0,0,0,40,0,0,0,86,0,0,0,49,0,0,0,48,0,0,0,51,0,0,0,44,0,0,0,32,0,0,0,49,0,0,0,48,0,0,0,49,0,0,0,44,0,0,0,32,0,0,0,49,0,0,0,48,0,0,0,48,0,0,0,44,0,0,0,32,0,0,0,72,0,0,0,111,0,0,0,110,0,0,0,103,0,0,0,32,0,0,0,75,0,0,0,111,0,0,0,110,0,0,0,103,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,112,99,101,95,99,121,98,114,99,111,114,101,0,0,0,0,118,101,110,100,101,116,116,97,0,0,0,0,0,0,0,0,98,111,98,108,98,111,98,108,0,0,0,0,0,0,0,0,109,100,95,110,104,108,0,0,76,0,0,0,97,0,0,0,115,0,0,0,116,0,0,0,32,0,0,0,83,0,0,0,116,0,0,0,114,0,0,0,105,0,0,0,107,0,0,0,101,0,0,0,114,0,0,0,0,0,0,0,70,0,0,0,105,0,0,0,110,0,0,0,97,0,0,0,108,0,0,0,32,0,0,0,118,122,0,0,117,105,0,0,32,0,0,0,110,48,0,0,32,0,0,0,83,0,0,0,116,0,0,0,114,0,0,0,105,0,0,0,107,0,0,0,101,0,0,0,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,90,165,85,0,0,0,0,0,109,100,95,116,104,111,114,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,65,115,115,101,114,116,105,111,110,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,46,10,0,0,0,0,0,0,0,0,56,105,110,103,32,47,32,82,97,105,122,105,110,103,32,47,32,67,97,112,99,111,109,0,115,99,97,108,101,95,116,121,112,101,37,117,0,0,0,0,79,117,116,32,82,117,110,32,40,98,111,111,116,108,101,103,41,0,0,0,0,0,0,0,69,110,101,114,103,121,32,68,101,99,114,101,97,115,101,32,82,97,116,101,0,0,0,0,97,108,116,0,0,0,0,0,69,65,32,72,111,99,107,101,121,32,40,74,112,110,41,0,0,0,0,0,0,0,0,0,97,108,105,101,110,115,121,110,106,0,0,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,73,32,50,110,100,32,73,109,112,97,99,116,58,32,71,105,97,110,116,32,65,116,116,97,99,107,32,40,85,83,65,32,57,55,48,57,51,48,41,0,0,0,0,0,0,0,0,83,121,115,116,101,109,49,54,82,111,119,83,99,114,111,108,108,0,0,0,0,0,0,0,109,100,95,101,97,104,111,99,107,101,121,106,0,0,0,0,110,111,100,101,118,105,99,101,0,0,0,0,0,0,0,0,98,117,108,108,102,103,116,0,66,108,111,120,101,101,100,32,40,74,97,112,97,110,44,32,70,68,49,48,57,52,32,51,49,55,45,48,49,51,57,41,0,0,0,0,0,0,0,0,69,65,32,72,111,99,107,101,121,32,40,69,117,114,111,41,0,0,0,0,0,0,0,0,103,108,111,99,114,51,54,48,0,0,0,0,0,0,0,0,103,112,114,105,100,101,114,0,50,32,67,111,105,110,115,32,49,32,67,114,101,100,105,116,115,32,0,0,0,0,0,0,85,110,105,87,97,114,32,83,0,0,0,0,0,0,0,0,86,100,112,87,105,110,100,111,119,87,105,100,116,104,0,0,97,108,105,101,110,115,121,110,106,111,0,0,0,0,0,0,109,100,95,101,97,104,111,99,107,101,121,0,0,0,0,0,72,97,110,103,45,79,110,32,40,114,101,118,32,65,41,0,0,0,0,0,0,0,0,0,110,68,114,118,86,105,100,82,65,77,66,97,110,107,0,0,75,111,114,101,97,110,0,0,66,108,111,111,100,32,87,97,114,114,105,111,114,0,0,0,72,101,97,100,32,80,97,110,105,99,32,40,118,101,114,46,32,48,51,49,53,44,32,49,53,47,48,51,47,50,48,48,48,41,0,0,0,0,0,0,68,121,110,97,109,105,116,101,32,72,101,97,100,100,121,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,54,50,50,41,0,0,0,103,114,97,112,104,105,99,115,32,105,115,115,117,101,115,63,0,0,0,0,0,0,0,0,118,105,100,101,111,95,121,115,99,97,108,101,0,0,0,0,83,101,97,114,99,104,32,69,121,101,32,80,108,117,115,32,86,50,46,48,0,0,0,0,113,117,105,122,107,111,102,0,80,51,32,65,116,116,97,99,107,0,0,0,0,0,0,0,109,100,95,100,104,101,97,100,112,49,0,0,0,0,0,0,49,47,49,0,0,0,0,0,65,116,108,117,115,32,47,32,75,77,32,73,110,116,101,114,110,97,116,105,111,110,97,108,0,0,0,0,0,0,0,0,98,83,111,117,110,100,78,77,73,69,110,97,98,108,101,0,102,108,105,99,107,101,114,95,102,105,108,116,101,114,95,105,110,100,101,120,0,0,0,0,98,103,48,115,99,114,111,108,108,120,0,0,0,0,0,0,109,97,106,101,115,116,49,50,0,0,0,0,0,0,0,0,68,101,110,105,97,109,45,49,54,99,32,72,97,114,100,119,97,114,101,0,0,0,0,0,83,111,117,110,100,0,0,0,53,48,48,48,48,32,49,53,48,48,48,48,0,0,0,0,109,118,112,0,0,0,0,0,87,101,100,110,101,115,100,97,121,0,0,0,0,0,0,0,68,121,110,97,109,105,116,101,32,72,101,97,100,100,121,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,54,49,54,41,0,0,0,119,98,100,101,108,117,120,101,0,0,0,0,0,0,0,0,100,114,103,110,109,115,116,95,111,107,105,95,99,111,109,109,97,110,100,0,0,0,0,0,80,50,32,76,101,102,116,32,83,116,105,99,107,32,68,111,119,110,0,0,0,0,0,0,84,111,121,98,111,120,77,67,85,67,111,109,0,0,0,0,83,111,102,116,32,111,110,108,121,0,0,0,0,0,0,0,115,115,109,105,115,115,105,110,0,0,0,0,0,0,0,0,71,117,110,78,97,105,108,32,40,50,56,116,104,32,77,97,121,46,32,49,57,57,50,41,0,0,0,0,0,0,0,0,83,101,105,98,117,32,75,97,105,104,97,116,115,117,32,40,70,97,98,116,101,107,32,108,105,99,101,110,115,101,41,0,75,111,110,97,109,105,0,0,75,111,115,111,100,97,116,101,32,81,117,105,122,32,77,121,32,65,110,103,101,108,32,40,74,97,112,97,110,41,0,0,109,100,95,100,104,101,97,100,112,50,0,0,0,0,0,0,83,104,111,99,107,105,110,103,0,0,0,0,0,0,0,0,101,121,101,115,122,97,99,98,0,0,0,0,0,0,0,0,78,105,110,106,97,32,82,121,117,107,101,110,100,101,110,32,40,74,97,112,97,110,44,32,115,101,116,32,49,41,0,0,68,121,110,97,109,105,116,101,32,72,101,97,100,100,121,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,54,49,52,45,67,65,66,69,90,65,41,0,0,0,0,87,87,70,32,87,114,101,115,116,108,101,70,101,115,116,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,97,100,112,99,109,95,101,110,100,0,0,0,0,0,0,0,75,110,105,103,104,116,115,32,111,102,32,86,97,108,111,117,114,32,50,32,40,86,49,48,51,44,32,49,48,49,44,32,49,48,48,44,32,72,111,110,103,32,75,111,110,103,41,0,0,0,0,0,0,0,0,0,83,117,112,101,114,32,77,111,100,101,108,0,0,0,0,0,66,111,117,110,99,105,110,103,32,66,97,108,108,115,0,0,102,111,114,103,111,116,116,110,0,0,0,0,0,0,0,0,67,114,111,115,115,32,87,105,98,101,114,32,45,32,67,121,98,101,114,32,67,111,109,98,97,116,32,80,111,108,105,99,101,0,0,0,0,0,0,0,112,114,111,116,95,100,97,116,97,0,0,0,0,0,0,0,98,105,111,109,116,111,121,97,0,0,0,0,0,0,0,0,76,48,0,0,147,48,0,0,112,48,0,0,140,48,0,0,32,0,0,0,174,48,0,0,243,48,0,0,79,48,0,0,147,48,0,0,0,0,0,0,71,0,0,0,97,0,0,0,110,0,0,0,98,0,0,0,97,0,0,0,114,0,0,0,101,0,0,0,32,0,0,0,71,0,0,0,105,0,0,0,110,0,0,0,107,0,0,0,117,0,0,0,110,0,0,0,0,0,0,0,0,0,0,0,109,100,95,100,104,101,97,100,112,51,0,0,0,0,0,0,115,97,105,108,111,114,109,110,107,0,0,0,0,0,0,0,109,100,95,116,104,111,114,102,0,0,0,0,0,0,0,0,45,45,32,87,101,108,99,111,109,101,32,116,111,32,82,101,116,114,111,65,114,99,104,32,47,32,82,71,85,73,32,45,45,10,32,10,66,97,115,105,99,32,82,71,85,73,32,99,111,110,116,114,111,108,115,58,10,32,32,32,32,83,99,114,111,108,108,32,40,85,112,41,58,32,37,45,50,48,115,10,32,32,83,99,114,111,108,108,32,40,68,111,119,110,41,58,32,37,45,50,48,115,10,32,32,32,32,32,32,65,99,99,101,112,116,47,79,75,58,32,37,45,50,48,115,10,32,32,32,32,32,32,32,32,32,32,32,66,97,99,107,58,32,37,45,50,48,115,10,69,110,116,101,114,47,69,120,105,116,32,82,71,85,73,58,32,37,45,50,48,115,10,32,69,120,105,116,32,82,101,116,114,111,65,114,99,104,58,32,37,45,50,48,115,10,32,10,84,111,32,112,108,97,121,32,97,32,103,97,109,101,58,10,76,111,97,100,32,97,32,108,105,98,114,101,116,114,111,32,99,111,114,101,32,40,67,111,114,101,41,46,10,76,111,97,100,32,97,32,82,79,77,32,40,76,111,97,100,32,71,97,109,101,41,46,32,32,32,32,32,10,32,10,83,101,101,32,80,97,116,104,32,79,112,116,105,111,110,115,32,116,111,32,115,101,116,32,100,105,114,101,99,116,111,114,105,101,115,10,102,111,114,32,102,97,115,116,101,114,32,97,99,99,101,115,115,32,116,111,32,102,105,108,101,115,46,10,32,10,80,114,101,115,115,32,65,99,99,101,112,116,47,79,75,32,116,111,32,99,111,110,116,105,110,117,101,46,0,68,105,109,97,104,111,111,32,40,48,48,48,49,50,49,32,69,117,114,111,41,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,112,97,114,115,101,32,115,104,97,100,101,114,32,115,111,117,114,99,101,32,40,37,115,41,46,10,0,0,0,0,0,0,0,0,110,111,115,116,106,0,0,0,67,114,101,100,105,116,115,32,112,101,114,32,80,108,97,121,101,114,0,0,0,0,0,0,68,121,110,97,109,105,116,101,32,72,101,97,100,100,121,32,40,74,112,110,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,0,0,68,114,118,83,97,109,112,108,101,65,100,100,114,101,115,115,0,0,0,0,0,0,0,0,99,116,114,108,0,0,0,0,49,57,120,120,0,0,0,0,115,99,111,116,114,115,104,116,0,0,0,0,0,0,0,0,107,97,114,97,116,98,108,122,106,0,0,0,0,0,0,0,99,116,114,105,98,101,0,0,109,100,95,100,104,101,97,100,106,112,0,0,0,0,0,0,100,111,110,112,97,99,104,105,104,107,0,0,0,0,0,0,68,121,110,97,109,105,116,101,32,72,101,97,100,100,121,32,40,74,112,110,41,0,0,0,52,32,67,111,105,110,45,49,32,80,108,97,121,0,0,0,117,110,105,119,97,114,115,0,67,111,111,107,105,101,32,38,32,66,105,98,105,32,51,0,0,0,0,0,0,0,0,0,109,101,116,108,115,97,118,114,0,0,0,0,0,0,0,0,18,96,0,0,150,153,0,0,24,152,0,0,2,135,0,0,32,0,0,0,68,0,0,0,111,0,0,0,68,0,0,0,111,0,0,0,110,0,0,0,80,0,0,0,97,0,0,0,99,0,0,0,104,0,0,0,105,0,0,0,32,0,0,0,40,0,0,0,65,0,0,0,114,0,0,0,114,0,0,0,97,0,0,0,110,0,0,0,103,0,0,0,101,0,0,0,32,0,0,0,77,0,0,0,111,0,0,0,100,0,0,0,101,0,0,0,32,0,0,0,118,0,0,0,101,0,0,0,114,0,0,0,115,0,0,0,105,0,0,0,111,0,0,0,110,0,0,0,32,0,0,0,49,0,0,0,46,0,0,0,49,0,0,0,44,0,0,0,32,0,0,0,104,0,0,0,97,0,0,0,99,0,0,0,107,0,0,0,32,0,0,0,98,0,0,0,121,0,0,0,32,0,0,0,84,0,0,0,114,0,0,0,97,0,0,0,112,0,0,0,49,0,0,0,53,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,40,100,101,102,97,117,108,116,41,0,0,0,0,0,0,0,109,100,95,100,104,101,97,100,106,0,0,0,0,0,0,0,66,0,0,0,101,0,0,0,115,0,0,0,116,0,0,0,114,0,0,0,105,0,0,0,0,0,0,0,160,188,0,0,164,194,0,0,184,210,0,0,124,183,0,0,116,199,0,0,32,0,0,0,40,0,0,0,75,0,0,0,111,0,0,0,114,0,0,0,101,0,0,0,97,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,106,111,121,115,116,105,99,107,95,112,111,114,116,95,115,101,108,101,99,116,0,0,0,0,103,117,110,98,105,114,100,106,0,0,0,0,0,0,0,0,107,111,102,57,55,111,114,111,0,0,0,0,0,0,0,0,83,107,121,32,76,97,110,99,101,114,32,40,69,115,99,111,32,84,114,97,100,105,110,103,32,67,111,32,108,105,99,101,110,115,101,41,0,0,0,0,52,48,48,0,0,0,0,0,68,121,110,97,109,105,116,101,32,72,101,97,100,100,121,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,52,32,67,111,105,110,115,32,49,32,80,108,97,121,0,0,52,48,75,0,0,0,0,0,115,112,101,97,107,114,101,115,0,0,0,0,0,0,0,0,80,51,32,82,105,103,104,116,0,0,0,0,0,0,0,0,109,100,95,100,104,101,97,100,0,0,0,0,0,0,0,0,98,83,111,117,110,100,67,80,85,69,110,97,98,108,101,0,80,111,107,101,114,32,76,97,100,105,101,115,0,0,0,0,102,108,105,99,107,101,114,95,102,105,108,116,101,114,95,101,110,97,98,108,101,0,0,0,83,117,112,101,114,32,83,112,97,99,101,32,73,110,118,97,100,101,114,115,32,39,57,49,32,40,87,111,114,108,100,41,0,0,0,0,0,0,0,0,82,111,99,107,32,68,117,99,107,32,40,112,114,111,116,111,116,121,112,101,63,41,0,0,67,111,110,116,114,111,108,115,32,63,0,0,0,0,0,0,87,87,70,32,83,117,112,101,114,115,116,97,114,115,32,40,98,111,111,116,108,101,103,41,0,0,0,0,0,0,0,0,75,97,110,103,97,114,111,111,32,40,98,111,111,116,108,101,103,41,0,0,0,0,0,0,71,101,110,115,104,105,45,84,111,117,32,49,57,51,48,39,115,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,51,48,48,48,48,32,49,53,48,48,48,48,0,0,0,0,72,101,97,118,121,119,101,105,103,104,116,32,67,104,97,109,112,32,40,74,97,112,97,110,44,32,70,68,49,48,57,52,32,51,49,55,45,48,48,52,54,41,0,0,0,0,0,0,80,97,108,99,111,0,0,0,84,117,101,115,100,97,121,0,68,121,110,97,109,105,116,101,32,68,117,107,101,32,40,87,111,114,108,100,41,0,0,0,87,111,110,100,101,114,32,66,111,121,32,40,110,111,116,32,101,110,99,114,121,112,116,101,100,41,0,0,0,0,0,0,50,32,116,111,32,115,116,97,114,116,44,32,50,32,116,111,32,99,111,110,116,105,110,117,101,0,0,0,0,0,0,0,84,105,116,108,101,32,76,101,118,101,108,32,68,105,115,112,108,97,121,0,0,0,0,0,103,117,110,110,97,105,108,0,98,108,107,100,114,103,111,110,0,0,0,0,0,0,0,0,109,100,95,100,121,110,100,117,107,101,49,0,0,0,0,0,71,117,110,115,0,0,0,0,97,112,112,101,110,100,99,111,110,102,105,103,0,0,0,0,71,97,117,110,116,108,101,116,32,40,74,97,112,97,110,101,115,101,44,32,114,101,118,32,49,50,41,0,0,0,0,0,48,49,58,48,48,0,0,0,80,97,99,45,76,97,110,100,32,40,77,105,100,119,97,121,41,0,0,0,0,0,0,0,69,121,101,115,32,40,98,111,111,116,108,101,103,32,115,101,116,32,49,41,0,0,0,0,48,45,48,0,0,0,0,0,83,110,97,112,32,74,97,99,107,0,0,0,0,0,0,0,83,111,108,111,109,111,110,73,110,112,117,116,0,0,0,0,68,121,110,97,109,105,116,101,32,68,117,107,101,32,40,87,111,114,108,100,44,32,82,101,118,46,32,65,41,0,0,0,102,105,108,101,95,112,97,116,104,46,99,0,0,0,0,0,100,107,111,110,103,111,0,0,97,100,112,99,109,95,112,111,115,0,0,0,0,0,0,0,71,117,110,46,32,83,109,111,107,101,32,40,85,83,32,115,101,116,32,50,41,0,0,0,107,111,118,50,49,48,51,0,112,99,101,95,120,119,105,98,101,114,0,0,0,0,0,0,106,117,106,117,98,0,0,0,84,111,112,32,72,117,110,116,101,114,32,45,32,82,111,100,100,121,32,38,32,67,97,116,104,121,32,40,78,71,72,45,48,52,54,41,0,0,0,0,101,120,101,100,101,120,101,115,95,116,120,116,95,101,110,97,98,108,101,0,0,0,0,0,109,100,95,100,121,110,100,117,107,101,0,0,0,0,0,0,118,117,108,103,117,115,95,115,111,117,110,100,108,97,116,99,104,0,0,0,0,0,0,0,86,105,100,101,111,32,82,97,109,32,35,50,0,0,0,0,83,112,97,99,101,32,72,97,114,114,105,101,114,32,73,73,32,40,87,111,114,108,100,41,0,0,0,0,0,0,0,0,100,105,109,97,104,111,111,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,73,110,118,97,108,105,100,32,119,114,97,112,112,105,110,103,32,116,121,112,101,32,37,115,46,32,86,97,108,105,100,32,111,110,101,115,32,97,114,101,58,32,99,108,97,109,112,95,116,111,95,98,111,114,100,101,114,32,40,100,101,102,97,117,108,116,41,44,32,99,108,97,109,112,95,116,111,95,101,100,103,101,44,32,114,101,112,101,97,116,32,97,110,100,32,109,105,114,114,111,114,101,100,95,114,101,112,101,97,116,46,32,70,97,108,108,105,110,103,32,98,97,99,107,32,116,111,32,100,101,102,97,117,108,116,46,10,0,0,0,108,119,105,110,103,115,106,0,49,32,77,105,110,117,116,101,0,0,0,0,0,0,0,0,68,114,118,82,101,97,114,72,111,114,105,122,83,99,114,111,108,108,72,105,0,0,0,0,84,101,116,114,105,115,32,40,98,111,111,116,108,101,103,32,115,101,116,32,50,41,0,0,115,104,105,102,116,0,0,0,68,121,110,97,32,66,114,111,116,104,101,114,115,32,50,32,45,32,83,101,103,97,32,67,104,97,110,110,101,108,32,83,112,101,99,105,97,108,32,40,74,112,110,44,32,83,101,103,97,32,67,104,97,110,110,101,108,41,0,0,0,0,0,0,122,122,121,122,122,121,120,120,0,0,0,0,0,0,0,0,116,104,101,103,108,111,98,0,115,101,97,114,99,104,97,114,106,0,0,0,0,0,0,0,42,115,111,117,110,100,108,97,116,99,104,0,0,0,0,0,109,100,95,100,121,110,97,98,114,50,115,112,0,0,0,0,49,0,0,0,57,0,0,0,52,0,0,0,51,0,0,0,58,0,0,0,32,0,0,0,223,48,0,0,195,48,0,0,201,48,0,0,166,48,0,0,167,48,0,0,164,48,0,0,119,109,0,0,38,98,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,112,104,97,115,101,115,116,101,112,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,105,110,105,116,32,114,101,119,105,110,100,32,98,117,102,102,101,114,46,32,82,101,119,105,110,100,105,110,103,32,119,105,108,108,32,98,101,32,100,105,115,97,98,108,101,100,46,10,0,0,100,98,108,100,121,110,106,0,115,107,121,119,111,108,102,51,0,0,0,0,0,0,0,0,68,121,110,97,32,66,114,111,116,104,101,114,115,32,50,32,40,74,112,110,41,0,0,0,109,97,100,103,101,97,114,0,105,110,118,97,108,105,100,32,100,105,115,116,97,110,99,101,32,99,111,100,101,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,40,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,100,114,103,110,98,115,116,114,0,0,0,0,0,0,0,0,87,99,57,48,98,49,68,105,112,0,0,0,0,0,0,0,79,109,110,105,0,0,0,0,103,110,103,98,108,105,116,97,0,0,0,0,0,0,0,0,109,114,102,108,101,97,95,115,101,108,101,99,116,91,49,93,0,0,0,0,0,0,0,0,109,100,95,100,121,110,97,98,114,50,0,0,0,0,0,0,103,97,108,97,103,97,109,102,0,0,0,0,0,0,0,0,87,99,57,48,83,111,117,110,100,76,97,116,99,104,0,0,103,98,117,115,116,101,114,115,0,0,0,0,0,0,0,0,83,117,112,101,114,32,86,111,108,108,101,121,98,97,108,108,32,40,75,111,114,101,97,41,0,0,0,0,0,0,0,0,86,111,108,116,32,69,108,101,99,32,99,111,45,108,116,100,0,0,0,0,0,0,0,0,82,121,103,97,114,32,40,85,83,44,32,98,111,111,116,108,101,103,41,0,0,0,0,0,67,82,73,0,0,0,0,0,91,84,101,99,104,110,111,115,93,32,40,84,97,105,116,111,32,65,109,101,114,105,99,97,32,108,105,99,101,110,115,101,41,0,0,0,0,0,0,0,77,67,54,56,52,48,95,114,101,103,48,0,0,0,0,0,110,80,103,109,67,117,114,114,101,110,116,66,105,111,115,0,109,95,111,108,100,115,95,112,116,114,0,0,0,0,0,0,115,116,114,104,111,111,112,0,80,51,32,76,101,102,116,0,68,121,110,97,32,66,114,111,116,104,101,114,115,32,40,74,112,110,41,0,0,0,0,0,98,73,110,116,101,114,114,117,112,116,69,110,97,98,108,101,0,0,0,0,0,0,0,0,115,111,102,116,95,102,105,108,116,101,114,95,101,110,97,98,108,101,0,0,0,0,0,0,111,114,108,101,103,101,110,100,99,0,0,0,0,0,0,0,115,115,105,0,0,0,0,0,82,111,117,110,100,32,83,101,108,101,99,116,0,0,0,0,49,32,67,111,105,110,32,32,50,32,80,108,97,121,115,0,104,119,99,104,97,109,112,106,0,0,0,0,0,0,0,0,77,111,110,100,97,121,0,0,109,100,95,100,121,110,97,98,114,0,0,0,0,0,0,0,119,98,111,121,117,0,0,0,77,97,99,104,105,110,101,32,73,68,0,0,0,0,0,0,80,50,32,76,101,102,116,32,83,116,105,99,107,32,85,112,0,0,0,0,0,0,0,0,68,101,109,111,32,83,111,117,110,100,0,0,0,0,0,0,53,67,32,49,67,0,0,0,83,117,112,101,114,32,83,112,97,99,101,102,111,114,116,114,101,115,115,32,77,97,99,114,111,115,115,32,47,32,67,104,111,117,45,74,105,107,117,117,32,89,111,117,115,97,105,32,77,97,99,114,111,115,115,0,0,0,0,0,0,0,0,0,83,116,97,103,101,32,83,101,108,101,99,116,0,0,0,0,68,117,110,103,101,111,110,115,32,38,32,68,114,97,103,111,110,115,32,45,32,87,97,114,114,105,111,114,115,32,111,102,32,116,104,101,32,69,116,101,114,110,97,108,32,83,117,110,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,78,111,32,115,111,117,110,100,44,32,105,109,112,101,114,102,101,99,116,32,105,110,112,117,116,115,0,0,0,0,0,0,112,99,101,95,97,101,114,111,98,108,115,116,0,0,0,0,101,121,101,115,98,0,0,0])
.concat([109,100,95,100,100,119,97,114,101,115,0,0,0,0,0,0,75,0,0,0,110,0,0,0,105,0,0,0,103,0,0,0,104,0,0,0,116,0,0,0,115,0,0,0,32,0,0,0,111,0,0,0,102,0,0,0,32,0,0,0,86,0,0,0,97,0,0,0,108,0,0,0,111,0,0,0,117,0,0,0,114,0,0,0,32,0,0,0,50,0,0,0,0,0,0,0,9,78,0,0,253,86,0,0,24,98,0,0,170,126,0,0,32,0,0,0,50,0,0,0,32,0,0,0,40,0,0,0,86,0,0,0,49,0,0,0,48,0,0,0,54,0,0,0,44,0,0,0,32,0,0,0,49,0,0,0,48,0,0,0,50,0,0,0,44,0,0,0,32,0,0,0,49,0,0,0,48,0,0,0,48,0,0,0,32,0,0,0,72,0,0,0,111,0,0,0,110,0,0,0,103,0,0,0,32,0,0,0,75,0,0,0,111,0,0,0,110,0,0,0,103,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,70,105,110,97,108,32,67,114,97,115,104,32,40,98,111,111,116,108,101,103,32,40,119,105,116,104,32,50,120,89,77,50,50,48,51,32,43,32,50,120,77,83,77,53,50,48,53,41,41,0,0,0,0,0,0,0,67,111,114,121,111,111,110,32,45,32,67,104,105,108,100,32,111,102,32,68,114,97,103,111,110,32,40,65,108,116,41,0,0,0,0,0,0,0,0,0,116,111,112,104,117,110,116,114,104,0,0,0,0,0,0,0,78,101,111,32,71,101,111,32,67,68,90,0,0,0,0,0,68,117,110,101,32,45,32,84,104,101,32,66,97,116,116,108,101,32,102,111,114,32,65,114,114,97,107,105,115,32,40,85,83,65,41,0,0,0,0,0,54,56,75,32,112,114,111,103,114,97,109,32,82,65,77,0,109,100,95,115,104,97,114,114,105,101,114,0,0,0,0,0,37,115,32,40,37,100,44,32,37,100,32,58,32,37,52,117,120,37,52,117,41,0,0,0,68,117,110,103,101,111,110,115,32,38,32,68,114,97,103,111,110,115,32,45,32,116,111,119,101,114,32,111,102,32,100,111,111,109,32,40,57,52,48,49,49,51,32,85,83,65,41,0,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,97,110,110,111,116,32,102,105,110,100,32,112,97,116,104,32,116,111,32,116,101,120,116,117,114,101,32,34,37,115,34,32,46,46,46,10,0,0,0,0,0,0,80,101,114,105,111,100,32,84,105,109,101,0,0,0,0,0,68,114,118,82,101,97,114,72,111,114,105,122,83,99,114,111,108,108,76,111,0,0,0,0,114,115,104,105,102,116,0,0,109,100,95,100,117,110,101,117,0,0,0,0,0,0,0,0,68,117,110,101,32,73,73,32,45,32,75,97,109,112,102,32,117,109,32,100,101,110,32,87,117,115,116,101,110,112,108,97,110,101,116,101,110,32,40,71,101,114,41,0,0,0,0,0,99,111,110,102,105,103,0,0,54,56,75,32,66,73,79,83,0,0,0,0,0,0,0,0,83,76,79,84,45,62,101,103,95,116,121,112,101,0,0,0,105,110,118,97,108,105,100,32,108,105,116,101,114,97,108,47,108,101,110,103,116,104,115,32,115,101,116,0,0,0,0,0,103,108,70,114,97,109,101,98,117,102,102,101,114,84,101,120,116,117,114,101,51,68,79,69,83,0,0,0,0,0,0,0,109,100,95,100,117,110,101,50,103,0,0,0,0,0,0,0,77,86,80,77,97,116,114,105,120,0,0,0,0,0,0,0,111,109,110,105,0,0,0,0,68,117,110,101,32,73,73,32,45,32,66,97,116,116,108,101,32,102,111,114,32,65,114,114,97,107,105,115,32,40,69,117,114,111,41,0,0,0,0,0,100,111,101,115,110,39,116,32,101,120,105,115,116,0,0,0,83,72,65,68,69,82,32,37,115,0,0,0,0,0,0,0,83,102,50,109,100,116,90,56,48,66,97,110,107,65,100,100,114,101,115,115,0,0,0,0,109,100,95,100,117,110,101,50,0,0,0,0,0,0,0,0,37,46,51,102,32,72,122,32,40,37,46,49,102,37,37,32,100,101,118,44,32,37,117,32,115,97,109,112,108,101,115,41,0,0,0,0,0,0,0,0,68,111,109,97,114,107,0,0,75,48,53,50,49,48,57,67,104,97,114,82,111,109,66,97,110,107,50,91,48,93,0,0,83,117,110,115,111,102,116,0,80,108,97,121,101,114,39,115,32,86,105,116,97,108,105,116,121,0,0,0,0,0,0,0,80,51,32,68,111,119,110,0,68,117,107,101,32,78,117,107,101,109,32,51,68,32,40,66,114,97,41,0,0,0,0,0,85,46,83,46,65,46,32,40,82,111,109,115,116,97,114,32,105,110,99,46,41,0,0,0,97,107,117,109,97,106,111,117,110,0,0,0,0,0,0,0,116,114,105,112,108,101,95,98,117,102,102,101,114,105,110,103,95,101,110,97,98,108,101,0,65,110,97,108,111,103,32,82,105,103,104,116,0,0,0,0,100,101,118,115,116,111,114,115,0,0,0,0,0,0,0,0,83,111,108,105,116,97,114,121,32,70,105,103,104,116,101,114,32,40,87,111,114,108,100,41,0,0,0,0,0,0,0,0,65,108,105,101,110,115,32,40,74,97,112,97,110,32,115,101,116,32,49,41,0,0,0,0,77,114,46,32,71,111,101,109,111,110,32,40,74,97,112,97,110,41,0,0,0,0,0,0,50,32,67,111,105,110,115,32,51,32,80,108,97,121,115,0,86,101,114,121,32,68,105,102,102,105,99,117,108,116,0,0,112,97,114,111,100,105,117,115,97,0,0,0,0,0,0,0,72,101,97,118,121,119,101,105,103,104,116,32,67,104,97,109,112,0,0,0,0,0,0,0,83,117,110,100,97,121,0,0,109,100,95,100,117,107,101,110,107,51,100,0,0,0,0,0,87,111,110,100,101,114,32,66,111,121,32,40,115,101,116,32,53,44,32,98,111,111,116,108,101,103,41,0,0,0,0,0,80,49,32,82,105,103,104,116,32,83,116,105,99,107,32,82,105,103,104,116,0,0,0,0,66,101,115,116,32,111,102,32,49,0,0,0,0,0,0,0,84,104,117,110,100,101,114,32,67,114,111,115,115,32,40,115,101,116,32,50,41,0,0,0,109,97,99,114,111,115,115,0,98,103,95,115,99,114,111,108,108,95,121,0,0,0,0,0,107,56,56,103,97,109,101,115,95,112,114,105,111,114,105,116,121,0,0,0,0,0,0,0,115,105,109,112,115,111,110,115,0,0,0,0,0,0,0,0,108,111,114,100,103,117,110,95,103,117,110,95,104,119,95,121,91,49,93,0,0,0,0,0,68,114,97,103,111,110,39,115,32,82,101,118,101,110,103,101,32,40,74,112,110,41,0,0,68,111,119,110,84,111,119,110,32,47,32,77,111,107,117,103,101,107,105,32,40,83,101,116,32,49,41,0,0,0,0,0,99,111,110,116,114,97,98,106,49,0,0,0,0,0,0,0,88,45,77,101,110,32,40,52,32,80,108,97,121,101,114,115,32,118,101,114,32,74,66,65,41,0,0,0,0,0,0,0,84,101,99,104,115,116,97,114,32,40,82,111,99,107,45,111,108,97,32,108,105,99,101,110,115,101,41,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,71,76,93,58,32,85,115,105,110,103,32,117,110,105,102,111,114,109,32,97,110,100,32,97,116,116,114,105,98,32,112,114,101,102,105,120,58,32,37,115,10,0,0,0,86,117,108,99,97,110,32,86,101,110,116,117,114,101,32,40,78,101,119,41,0,0,0,0,109,100,95,100,114,97,103,110,114,101,118,106,0,0,0,0,103,114,97,100,105,117,115,51,95,112,114,105,111,114,105,116,121,0,0,0,0,0,0,0,86,101,110,117,115,0,0,0,49,57,88,88,32,45,32,116,104,101,32,119,97,114,32,97,103,97,105,110,115,116,32,100,101,115,116,105,110,121,32,40,57,53,49,50,50,53,32,74,97,112,97,110,41,0,0,0,75,110,105,103,104,116,115,32,111,102,32,86,97,108,111,117,114,32,50,32,40,86,49,48,54,44,32,49,48,50,44,32,49,48,48,32,72,111,110,103,32,75,111,110,103,41,0,0,86,101,110,100,101,116,116,97,32,40,65,115,105,97,32,50,32,80,108,97,121,101,114,115,32,118,101,114,46,32,68,41,0,0,0,0,0,0,0,0,102,99,114,97,115,104,0,0,112,99,101,95,99,111,114,121,111,111,110,49,0,0,0,0,84,111,112,32,72,117,110,116,101,114,32,45,32,82,111,100,100,121,32,38,32,67,97,116,104,121,32,40,78,71,77,45,48,52,54,41,0,0,0,0,68,114,97,103,111,110,39,115,32,82,101,118,101,110,103,101,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,84,104,101,32,83,105,109,112,115,111,110,115,32,40,50,32,80,108,97,121,101,114,115,32,65,115,105,97,41,0,0,0,67,112,117,32,35,49,32,82,97,109,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,70,97,105,108,101,100,32,116,111,32,115,112,108,105,116,32,114,101,99,116,32,34,37,115,34,32,105,110,116,111,32,97,116,32,108,101,97,115,116,32,102,111,117,114,32,116,111,107,101,110,115,46,10,0,0,0,83,111,110,105,99,32,83,112,105,110,98,97,108,108,32,40,69,117,114,111,41,0,0,0,84,101,101,110,97,103,101,32,77,117,116,97,110,116,32,72,101,114,111,32,84,117,114,116,108,101,115,32,40,85,75,32,52,32,80,108,97,121,101,114,115,44,32,115,101,116,32,50,41,0,0,0,0,0,0,0,83,101,116,32,66,111,116,116,111,109,45,82,105,103,104,116,32,67,111,114,110,101,114,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,119,114,105,116,101,32,88,77,76,32,99,104,101,97,116,32,115,101,116,116,105,110,103,115,32,116,111,32,34,37,115,34,46,32,67,104,101,99,107,32,112,101,114,109,105,115,115,105,111,110,115,46,10,0,0,0,0,100,100,116,111,100,117,114,49,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,78,111,32,97,100,100,114,101,115,115,32,97,115,115,105,103,110,101,100,32,116,111,32,115,101,109,97,110,116,105,99,46,10,0,0,63,62,10,0,0,0,0,0,73,114,101,109,32,65,109,101,114,105,99,97,32,40,108,105,99,101,110,115,101,100,32,102,114,111,109,32,72,117,100,115,111,110,32,83,111,102,116,41,0,0,0,0,0,0,0,0,68,114,118,72,111,114,105,122,83,99,114,111,108,108,72,105,0,0,0,0,0,0,0,0,104,111,109,101,0,0,0,0,109,100,95,100,114,97,103,110,114,101,118,0,0,0,0,0,118,105,103,105,108,97,110,116,106,0,0,0,0,0,0,0,70,105,103,104,116,105,110,103,32,66,97,115,107,101,116,98,97,108,108,0,0,0,0,0,80,101,116,101,114,32,80,97,110,32,40,98,111,111,116,108,101,103,32,111,102,32,72,111,111,107,41,0,0,0,0,0,114,116,121,112,101,98,0,0,84,101,99,104,110,111,115,111,102,116,0,0,0,0,0,0,103,97,109,101,98,111,121,0,68,101,118,105,108,32,67,114,97,115,104,32,77,68,32,40,74,112,110,41,0,0,0,0,80,105,115,99,101,115,32,40,98,111,111,116,108,101,103,41,0,0,0,0,0,0,0,0,109,100,95,100,101,118,108,99,114,115,104,0,0,0,0,0,68,114,97,103,111,110,39,115,32,76,97,105,114,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,41,0,0,80,51,32,85,112,0,0,0,109,100,95,100,108,97,105,114,0,0,0,0,0,0,0,0,84,97,105,119,97,110,32,40,83,112,97,99,101,121,32,67,111,44,32,108,116,100,46,41,0,0,0,0,0,0,0,0,103,97,109,109,97,95,99,111,114,114,101,99,116,105,111,110,0,0,0,0,0,0,0,0,115,111,108,102,105,103,116,114,0,0,0,0,0,0,0,0,49,32,67,111,105,110,32,32,49,32,80,108,97,121,0,0,68,105,102,102,105,99,117,108,116,0,0,0,0,0,0,0,104,119,99,104,97,109,112,0,68,114,97,103,111,110,39,115,32,70,117,114,121,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,0,119,98,111,121,53,0,0,0,73,110,105,116,105,97,108,32,67,114,101,100,105,116,0,0,80,49,32,82,105,103,104,116,32,83,116,105,99,107,32,76,101,102,116,0,0,0,0,0,49,80,32,86,115,32,50,80,32,82,111,117,110,100,115,0,85,80,76,32,40,84,97,105,116,111,32,108,105,99,101,110,115,101,41,0,0,0,0,0,80,50,32,85,112,32,47,32,68,111,119,110,0,0,0,0,98,103,95,115,99,114,111,108,108,95,120,0,0,0,0,0,108,111,114,100,103,117,110,95,103,117,110,95,104,119,95,120,91,49,93,0,0,0,0,0,109,100,95,100,102,117,114,121,0,0,0,0,0,0,0,0,100,111,119,110,116,111,119,110,0,0,0,0,0,0,0,0,69,121,101,115,32,40,84,101,99,104,115,116,97,114,41,0,0,0,0,0,0,0,0,0,112,111,111,121,97,110,0,0,107,111,118,50,49,48,54,0,67,111,114,121,111,111,110,32,45,32,67,104,105,108,100,32,111,102,32,68,114,97,103,111,110,0,0,0,0,0,0,0,70,105,110,97,108,32,70,105,103,104,116,32,40,98,111,111,116,108,101,103,44,32,87,111,114,108,100,41,0,0,0,0,68,114,97,103,111,110,39,115,32,69,121,101,32,80,108,117,115,32,45,32,83,104,97,110,103,104,97,105,32,73,73,73,32,40,74,112,110,41,0,0,109,100,95,115,115,112,105,110,0,0,0,0,0,0,0,0,83,101,116,32,85,112,112,101,114,45,76,101,102,116,32,67,111,114,110,101,114,0,0,0,68,117,110,103,101,111,110,115,32,38,32,68,114,97,103,111,110,115,32,45,32,116,111,119,101,114,32,111,102,32,100,111,111,109,32,40,57,52,48,49,50,53,32,85,83,65,41,0,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,73,110,118,97,108,105,100,32,115,101,109,97,110,116,105,99,46,10,0,68,114,118,72,111,114,105,122,83,99,114,111,108,108,76,111,0,0,0,0,0,0,0,0,101,110,100,0,0,0,0,0,109,100,95,115,104,97,110,103,104,51,0,0,0,0,0,0,68,114,97,103,111,110,32,83,108,97,121,101,114,32,45,32,69,105,121,117,117,32,68,101,110,115,101,116,115,117,32,73,73,32,40,74,112,110,41,0,0,0,0,0,0,0,0,0,118,101,114,98,111,115,101,0,82,101,116,114,111,65,114,99,104,58,32,84,97,107,105,110,103,32,115,99,114,101,101,110,115,104,111,116,46,10,0,0,100,101,108,0,0,0,0,0,109,100,95,100,115,108,97,121,101,100,50,0,0,0,0,0,112,105,115,99,101,115,98,0,75,105,110,103,98,97,108,108,83,112,101,101,99,104,68,105,112,0,0,0,0,0,0,0,68,114,97,103,111,110,32,83,108,97,121,101,114,32,45,32,69,105,121,117,117,32,68,101,110,115,101,116,115,117,32,40,74,112,110,41,0,0,0,0,109,100,95,100,115,108,97,121,101,100,0,0,0,0,0,0,71,97,108,76,102,111,86,111,108,117,109,101,0,0,0,0,103,97,108,97,120,121,102,103,0,0,0,0,0,0,0,0,80,51,32,83,116,97,114,116,0,0,0,0,0,0,0,0,68,114,97,103,111,110,32,66,97,108,108,32,90,32,45,32,76,39,65,112,112,101,108,32,100,117,32,68,101,115,116,105,110,32,40,70,114,97,41,0,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,97,118,105,110,103,32,99,111,110,102,105,103,32,97,116,32,112,97,116,104,58,32,34,37,115,34,10,0,65,110,97,108,111,103,32,76,101,102,116,0,0,0,0,0,175,48,0,0,164,48,0,0,186,48,0,0,32,0,0,0,175,48,0,0,168,48,0,0,185,48,0,0,200,48,0,0,32,0,0,0,13,255,0,0,235,89,0,0,104,48,0,0,199,82,0,0,5,128,0,0,110,48,0,0,105,114,0,0,158,138,0,0,13,255,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,81,0,0,0,117,0,0,0,105,0,0,0,122,0,0,0,32,0,0,0,81,0,0,0,117,0,0,0,101,0,0,0,115,0,0,0,116,0,0,0,32,0,0,0,45,0,0,0,32,0,0,0,72,0,0,0,105,0,0,0,109,0,0,0,101,0,0,0,32,0,0,0,116,0,0,0,111,0,0,0,32,0,0,0,89,0,0,0,117,0,0,0,117,0,0,0,115,0,0,0,104,0,0,0,97,0,0,0,32,0,0,0,110,0,0,0,111,0,0,0,32,0,0,0,77,0,0,0,111,0,0,0,110,0,0,0,111,0,0,0,103,0,0,0,97,0,0,0,116,0,0,0,97,0,0,0,114,0,0,0,105,0,0,0,0,0,0,0,0,0,0,0,114,43,98,0,0,0,0,0,50,32,67,111,105,110,115,32,49,32,80,108,97,121,0,0,58,32,0,0,0,0,0,0,71,111,108,100,101,110,32,65,120,101,32,40,115,101,116,32,53,44,32,85,83,44,32,70,68,49,48,57,52,32,51,49,55,45,48,49,50,50,41,0,0,0,0,0,0,0,0,0,83,0,0,0,97,0,0,0,116,0,0,0,0,0,0,0,109,100,95,100,98,122,102,0,87,111,110,100,101,114,32,66,111,121,32,40,115,101,116,32,52,44,32,51,49,53,45,53,49,54,50,41,0,0,0,0,77,105,110,105,32,85,112,114,105,103,104,116,0,0,0,0,80,49,32,82,105,103,104,116,32,83,116,105,99,107,32,68,111,119,110,0,0,0,0,0,83,116,97,110,100,97,114,100,0,0,0,0,0,0,0,0,76,105,118,101,115,32,40,77,97,100,32,66,97,108,108,41,0,0,0,0,0,0,0,0,65,99,114,111,98,97,116,32,77,105,115,115,105,111,110,0,0,0,0,0,0,0,0,0,102,103,95,115,99,114,111,108,108,95,121,0,0,0,0,0,67,111,105,110,32,109,111,100,101,0,0,0,0,0,0,0,108,111,114,100,103,117,110,95,103,117,110,95,104,119,95,121,91,48,93,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,90,73,80,32,101,120,116,114,97,99,116,105,111,110,32,102,97,105,108,101,100,32,97,116,32,108,105,110,101,58,32,37,100,46,10,0,0,0,0,0,0,0,0,66,97,110,100,97,105,0,0,66,97,110,112,114,101,115,116,111,32,43,32,84,115,117,98,117,114,97,121,97,32,80,114,111,100,46,0,0,0,0,0,101,121,101,115,50,0,0,0,67,112,115,70,114,103,0,0,68,114,97,103,111,110,32,66,97,108,108,32,90,32,45,32,66,117,121,117,117,32,82,101,116,115,117,100,101,110,32,40,74,112,110,41,0,0,0,0,91,82,80,78,71,93,58,32,69,114,114,111,114,32,105,110,32,108,105,110,101,32,37,100,46,10,0,0,0,0,0,0,83,111,117,110,100,32,90,56,48,32,82,65,77,0,0,0,75,0,0,0,110,0,0,0,105,0,0,0,103,0,0,0,104,0,0,0,116,0,0,0,115,0,0,0,32,0,0,0,111,0,0,0,102,0,0,0,32,0,0,0,86,0,0,0,97,0,0,0,108,0,0,0,111,0,0,0,117,0,0,0,114,0,0,0,32,0,0,0,50,0,0,0,0,0,0,0,9,78,0,0,253,86,0,0,24,98,0,0,170,126,0,0,32,0,0,0,50,0,0,0,32,0,0,0,40,0,0,0,86,0,0,0,49,0,0,0,48,0,0,0,55,0,0,0,44,0,0,0,32,0,0,0,49,0,0,0,48,0,0,0,50,0,0,0,44,0,0,0,32,0,0,0,49,0,0,0,48,0,0,0,48,0,0,0,44,0,0,0,32,0,0,0,72,0,0,0,111,0,0,0,110,0,0,0,103,0,0,0,32,0,0,0,75,0,0,0,111,0,0,0,110,0,0,0,103,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,112,99,101,95,99,111,114,121,111,111,110,0,0,0,0,0,102,102,105,103,104,116,98,108,0,0,0,0,0,0,0,0,109,100,95,100,98,122,0,0,83,111,110,105,99,32,67,111,109,112,105,108,97,116,105,111,110,32,40,69,117,114,111,44,32,69,97,114,108,105,101,114,41,0,0,0,0,0,0,0,37,115,32,40,37,52,117,120,37,52,117,44,32,37,117,32,120,32,37,117,32,115,99,97,108,101,41,0,0,0,0,0,100,100,116,111,100,117,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,78,111,32,115,101,109,97,110,116,105,99,32,102,111,114,32,105,109,112,111,114,116,32,118,97,114,105,97,98,108,101,46,10,0,0,86,101,114,121,32,83,108,111,119,0,0,0,0,0,0,0,68,114,118,82,101,97,114,68,105,115,97,98,108,101,0,0,68,114,97,103,111,110,32,45,32,84,104,101,32,66,114,117,99,101,32,76,101,101,32,83,116,111,114,121,32,40,85,83,65,41,0,0,0,0,0,0,109,100,95,100,114,97,103,111,110,117,0,0,0,0,0,0,102,117,108,108,115,99,114,101,101,110,0,0,0,0,0,0,105,110,115,101,114,116,0,0,103,108,69,71,76,73,109,97,103,101,84,97,114,103,101,116,82,101,110,100,101,114,98,117,102,102,101,114,83,116,111,114,97,103,101,79,69,83,0,0,68,114,97,103,111,110,32,45,32,84,104,101,32,66,114,117,99,101,32,76,101,101,32,83,116,111,114,121,32,40,69,117,114,111,41,0,0,0,0,0,80,105,115,99,101,115,0,0,109,100,95,100,114,97,103,111,110,0,0,0,0,0,0,0,68,111,110,103,32,71,117,32,82,105,32,84,101,32,67,104,105,32,74,97,107,32,74,101,111,110,32,40,75,111,114,41,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,79,118,101,114,108,97,121,32,105,110,116,101,114,102,97,99,101,32,105,115,32,110,111,116,32,112,114,101,115,101,110,116,32,105,110,32,118,105,100,101,111,32,100,114,105,118,101,114,46,10,0,80,51,32,67,111,105,110,0,109,100,95,100,111,110,103,103,117,114,105,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,115,121,115,116,101,109,95,100,105,114,101,99,116,111,114,121,32,105,115,32,110,111,116,32,115,101,116,32,105,110,32,99,111,110,102,105,103,46,32,65,115,115,117,109,105,110,103,32,115,121,115,116,101,109,32,100,105,114,101,99,116,111,114,121,32,105,115,32,115,97,109,101,32,102,111,108,100,101,114,32,97,115,32,103,97,109,101,58,32,34,37,115,34,46,10,0,0,0,0,0,81,117,105,122,32,81,117,101,115,116,32,45,32,72,105,109,101,32,116,111,32,89,117,117,115,104,97,32,110,111,32,77,111,110,111,103,97,116,97,114,105,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,54,48,75,0,0,0,0,0,84,101,115,116,32,40,82,65,77,32,97,110,100,32,83,111,117,110,100,41,0,0,0,0,68,114,46,32,82,111,98,111,116,110,105,107,39,115,32,77,101,97,110,32,66,101,97,110,32,77,97,99,104,105,110,101,32,40,85,83,65,41,0,0,103,111,108,100,110,97,120,101,117,0,0,0,0,0,0,0,70,0,0,0,114,0,0,0,105,0,0,0,0,0,0,0,105,110,99,111,114,114,101,99,116,32,104,101,97,100,101,114,32,99,104,101,99,107,0,0,119,98,111,121,52,0,0,0,85,112,114,105,103,104,116,47,83,105,116,32,68,111,119,110,0,0,0,0,0,0,0,0,80,49,32,82,105,103,104,116,32,83,116,105,99,107,32,85,112,0,0,0,0,0,0,0,83,99,114,101,101,110,32,68,105,114,101,99,116,105,111,110,0,0,0,0,0,0,0,0,97,99,114,111,98,97,116,109,0,0,0,0,0,0,0,0,102,103,95,115,99,114,111,108,108,95,120,0,0,0,0,0,109,100,95,100,114,114,111,98,111,116,110,117,0,0,0,0,108,111,114,100,103,117,110,95,103,117,110,95,104,119,95,120,91,48,93,0,0,0,0,0,114,119,101,98,97,117,100,105,111,0,0,0,0,0,0,0,103,108,115,108,112,0,0,0,68,105,103,105,116,114,101,120,32,84,101,99,104,115,116,97,114,32,40,82,111,99,107,45,111,108,97,32,108,105,99,101,110,115,101,41,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,69,77,83,67,82,73,80,84,69,78,47,69,71,76,93,58,32,73,110,105,116,105,97,108,105,122,105,110,103,46,46,46,10,0,0,0,71,97,108,97,120,105,97,110,32,40,77,105,100,119,97,121,32,115,101,116,32,50,41,0,0,0,0,0,0,0,0,0,68,114,46,32,82,111,98,111,116,110,105,107,39,115,32,77,101,97,110,32,66,101,97,110,32,77,97,99,104,105,110,101,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,0,75,110,105,103,104,116,115,32,111,102,32,86,97,108,111,117,114,32,50,32,40,86,49,48,55,44,32,49,48,50,44,32,49,48,48,44,32,72,111,110,103,32,75,111,110,103,41,0,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,67,111,117,108,100,110,39,116,32,105,110,105,116,32,102,111,110,116,32,114,101,110,100,101,114,101,114,46,10,0,0,0,0,0,0,0,78,105,104,111,110,32,84,101,108,101,110,101,116,0,0,0,83,116,114,101,101,116,32,83,109,97,114,116,32,47,32,70,105,110,97,108,32,70,105,103,104,116,32,40,74,97,112,97,110,44,32,104,97,99,107,41,0,0,0,0,0,0,0,0,83,97,109,117,114,97,105,32,83,104,111,100,111,119,110,32,47,32,83,97,109,117,114,97,105,32,83,112,105,114,105,116,115,32,40,78,71,72,45,48,52,53,41,0,0,0,0,0,109,100,95,100,114,114,111,98,111,116,110,117,112,0,0,0,109,100,95,115,111,110,105,99,99,109,112,0,0,0,0,0,83,101,116,32,115,99,97,108,101,0,0,0,0,0,0,0,68,117,110,103,101,111,110,115,32,38,32,68,114,97,103,111,110,115,32,45,32,116,111,119,101,114,32,111,102,32,100,111,111,109,32,40,57,52,48,49,49,51,32,74,97,112,97,110,41,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,76,111,97,100,105,110,103,32,101,120,116,101,114,110,97,108,32,115,111,117,114,99,101,32,102,114,111,109,32,34,37,115,34,46,10,0,0,68,114,118,82,101,97,114,67,111,108,111,117,114,0,0,0,115,116,111,110,101,97,103,101,0,0,0,0,0,0,0,0,68,114,46,32,82,111,98,111,116,110,105,107,39,115,32,77,101,97,110,32,66,101,97,110,32,77,97,99,104,105,110,101,32,40,69,117,114,111,41,0,0,0,0,0,0,0,0,0,109,100,95,100,114,114,111,98,111,116,110,0,0,0,0,0,115,97,118,101,0,0,0,0,77,97,103,105,99,97,108,32,68,114,111,112,32,40,74,97,112,97,110,44,32,86,101,114,115,105,111,110,32,49,46,49,44,32,49,57,57,53,46,48,54,46,50,49,41,0,0,0,68,111,117,98,108,101,32,68,114,97,103,111,110,32,86,32,45,32,84,104,101,32,83,104,97,100,111,119,32,70,97,108,108,115,32,40,85,83,65,41,0,0,0,0,0,0,0,0,112,105,115,99,101,115,0,0,116,114,105,111,116,104,101,112,106,0,0,0,0,0,0,0,109,100,95,100,100,114,97,103,111,110,53,0,0,0,0,0,68,111,117,98,108,101,32,68,114,97,103,111,110,32,51,32,45,32,84,104,101,32,65,114,99,97,100,101,32,71,97,109,101,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,83,105,100,101,32,80,111,99,107,101,116,32,40,98,111,111,116,108,101,103,32,115,101,116,32,50,41,0,0,0,0,0,99,104,105,112,45,62,110,111,105,115,101,95,112,0,0,0,115,111,110,105,99,119,105,50,0,0,0,0,0,0,0,0,80,50,32,66,117,116,116,111,110,32,68,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,99,114,101,97,116,101,32,70,66,79,32,116,97,114,103,101,116,115,46,32,87,105,108,108,32,99,111,110,116,105,110,117,101,32,119,105,116,104,111,117,116,32,70,66,79,46,10,0,0,109,100,95,100,100,114,97,103,111,110,51,0,0,0,0,0,112,49,32,102,105,114,101,32,51,0,0,0,0,0,0,0,68,97,116,97,32,69,97,115,116,32,85,83,65,0,0,0,115,121,115,116,101,109,95,100,105,114,101,99,116,111,114,121,0,0,0,0,0,0,0,0,113,122,113,117,101,115,116,0,54,48,75,32,54,48,75,32,54,48,75,43,0,0,0,0,84,101,115,116,32,40,71,114,105,100,32,97,110,100,32,73,110,112,117,116,115,41,0,0,71,111,108,100,101,110,32,65,120,101,32,40,115,101,116,32,52,44,32,74,97,112,97,110,44,32,70,68,49,48,57,52,32,51,49,55,45,48,49,50,49,41,0,0,0,0,0,0,84,0,0,0,104,0,0,0,117,0,0,0,0,0,0,0,87,111,110,100,101,114,32,66,111,121,32,40,115,101,116,32,51,44,32,51,49,53,45,53,49,51,53,41,0,0,0,0,70,108,97,103,32,79,110,108,121,0,0,0,0,0,0,0,75,117,104,103,97,32,45,32,79,112,101,114,97,116,105,111,110,32,67,111,100,101,32,39,86,97,112,111,114,32,84,114,97,105,108,39,32,40,74,97,112,97,110,32,114,101,118,105,115,105,111,110,32,51,41,0,0,0,0,0,0,0,0,0,84,104,117,110,100,101,114,32,68,114,97,103,111,110,32,40,98,111,111,116,108,101,103,41,0,0,0,0,0,0,0,0,116,120,95,115,99,114,111,108,108,95,121,0,0,0,0,0,68,111,117,98,108,101,32,68,114,97,103,111,110,32,73,73,32,45,32,84,104,101,32,82,101,118,101,110,103,101,32,40,74,112,110,41,0,0,0,0,108,111,114,100,103,117,110,95,112,114,111,116,101,99,116,105,111,110,95,100,97,116,97,0,85,108,116,114,97,32,84,111,117,107,111,110,32,68,101,110,115,101,116,115,117,32,40,74,97,112,97,110,41,0,0,0,65,109,101,114,105,99,97,32,84,121,112,101,0,0,0,0,80,49,32,83,116,114,111,110,103,32,107,105,99,107,0,0,67,114,101,100,105,116,115,32,102,111,114,32,49,32,80,108,97,121,101,114,0,0,0,0,69,121,101,115,32,40,68,105,103,105,116,114,101,120,32,84,101,99,104,115,116,97,114,41,0,0,0,0,0,0,0,0,66,97,115,101,32,83,104,105,112,32,73,110,118,117,108,110,101,114,97,98,105,108,105,116,121,0,0,0,0,0,0,0,109,100,95,100,100,114,97,103,111,110,50,0,0,0,0,0,53,48,48,48,48,32,50,48,48,48,48,48,32,53,48,48,48,48,48,0,0,0,0,0,67,111,108,117,109,110,115,0,0,0,0,0,0,0,0,0,102,102,105,103,104,116,106,104,0,0,0,0,0,0,0,0,115,97,109,115,104,111,104,0,100,97,115,115,97,117,108,116,0,0,0,0,0,0,0,0,109,100,95,115,111,110,105,99,99,109,112,49,0,0,0,0,91,37,115,93,10,112,114,101,115,115,32,106,111,121,112,97,100,10,40,82,69,84,85,82,78,32,116,111,32,115,107,105,112,41,0,0,0,0,0,0,100,100,116,111,100,106,114,50,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,71,111,116,32,111,117,116,115,99,97,108,101,95,121,32,97,116,116,114,58,32,37,46,49,102,10,0,0,0,71,97,109,101,32,82,101,112,101,97,116,115,0,0,0,0,68,114,118,73,114,113,86,101,99,116,111,114,0,0,0,0,68,111,117,98,108,101,32,68,114,97,103,111,110,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,0,109,100,95,100,100,114,97,103,111,110,0,0,0,0,0,0,104,101,108,112,0,0,0,0,107,112,95,101,110,116,101,114,0,0,0,0,0,0,0,0,87,111,110,100,101,114,32,80,108,97,110,101,116,32,40,74,97,112,97,110,41,0,0,0,68,111,117,98,108,101,32,67,108,117,116,99,104,32,40,69,117,114,111,41,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,80,69,82,70,79,82,77,65,78,67,69,95,76,69,86,69,76,58,32,37,117,46,10,0,0,0,0,0,0,98,111,111,116,108,101,103,32,40,82,101,98,101,110,32,83,46,65,46,41,0,0,0,0,109,100,95,100,111,117,98,108,101,99,108,0,0,0,0,0,68,111,114,97,101,109,111,110,32,45,32,89,117,109,101,32,68,111,114,111,98,111,117,32,116,111,32,55,45,110,105,110,32,110,111,32,71,111,122,97,110,115,32,40,74,112,110,41,0,0,0,0,0,0,0,0,77,101,105,107,121,117,117,32,72,117,110,116,101,114,32,71,32,40,74,97,112,97,110,44,32,115,101,116,32,50,41,0,0,0,0,0,0,0,0,0,80,50,32,66,117,116,116,111,110,32,67,0,0,0,0,0,109,100,95,100,111,114,97,101,109,111,110,0,0,0,0,0,83,116,111,112,32,109,111,100,101,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,115,97,118,101,115,116,97,116,101,95,100,105,114,101,99,116,111,114,121,32,105,115,32,110,111,116,32,97,32,100,105,114,101,99,116,111,114,121,44,32,105,103,110,111,114,105,110,103,32,46,46,46,10,0,0,0,0,0,0,0,175,48,0,0,164,48,0,0,186,48,0,0,32,0,0,0,48,87,0,0,3,116,0,0,50,150,0,0,91,136,0,0,205,142,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,81,0,0,0,117,0,0,0,105,0,0,0,122,0,0,0,32,0,0,0,67,0,0,0,104,0,0,0,105,0,0,0,107,0,0,0,121,0,0,0,117,0,0,0,32,0,0,0,66,0,0,0,111,0,0,0,117,0,0,0,101,0,0,0,105,0,0,0,32,0,0,0,71,0,0,0,117,0,0,0,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,71,97,109,101,44,32,74,97,112,97,110,101,115,101,0,0,103,111,108,100,110,97,120,101,106,0,0,0,0,0,0,0,87,0,0,0,101,0,0,0,100,0,0,0,0,0,0,0,80,108,97,121,109,97,116,101,115,32,73,110,116,101,114,97,99,116,105,118,101,0,0,0,119,98,111,121,51,0,0,0,80,49,32,76,101,102,116,32,83,116,105,99,107,32,82,105,103,104,116,0,0,0,0,0,65,110,116,104,101,109,32,79,110,108,121,0,0,0,0,0,116,100,114,97,103,111,110,98,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,65,112,112,108,121,105,110,103,32,115,104,97,100,101,114,32,46,46,46,10,0,116,120,95,115,99,114,111,108,108,95,120,0,0,0,0,0,100,101,99,111,112,114,111,116,95,108,97,115,116,95,119,114,105,116,101,95,118,97,108,0,108,111,114,100,103,117,110,95,119,104,105,116,101,115,99,114,101,101,110,0,0,0,0,0,68,111,111,109,32,84,114,111,111,112,101,114,115,32,45,32,84,104,101,32,77,117,116,97,110,116,32,67,104,114,111,110,105,99,108,101,115,32,40,85,83,65,41,0,0,0,0,0,117,116,111,117,107,111,110,100,0,0,0,0,0,0,0,0,69,117,114,111,112,32,84,121,112,101,0,0,0,0,0,0,101,121,101,115,0,0,0,0,67,111,109,112,108,101,116,101,32,73,110,118,117,108,110,101,114,97,98,105,108,105,116,121,0,0,0,0,0,0,0,0,109,100,95,100,111,111,109,116,114,111,112,0,0,0,0,0,80,108,97,110,101,0,0,0,112,99,101,95,99,111,108,117,109,110,115,0,0,0,0,0,70,105,110,97,108,32,70,105,103,104,116,32,40,57,48,48,51,48,53,32,74,97,112,97,110,41,0,0,0,0,0,0,109,100,95,102,50,50,0,0,83,97,109,117,114,97,105,32,83,104,111,100,111,119,110,32,47,32,83,97,109,117,114,97,105,32,83,112,105,114,105,116,115,32,40,78,71,77,45,48,52,53,41,0,0,0,0,0,67,104,105,112,45,62,87,104,105,116,101,110,111,105,115,101,73,110,118,101,114,116,0,0,68,111,110,97,108,100,32,105,110,32,77,97,117,105,32,77,97,108,108,97,114,100,32,40,66,114,97,41,0,0,0,0,75,48,53,49,57,54,48,83,112,114,105,116,101,82,111,109,66,97,110,107,0,0,0,0,83,111,110,105,99,32,116,104,101,32,72,101,100,103,101,104,111,103,32,51,32,40,74,112,110,44,32,75,111,114,41,0,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,111,118,101,114,108,97,121,46,10,0,0,0,75,48,53,50,49,48,57,83,99,114,111,108,108,88,91,48,93,0,0,0,0,0,0,0,68,117,110,103,101,111,110,115,32,38,32,68,114,97,103,111,110,115,32,45,32,116,111,119,101,114,32,111,102,32,100,111,111,109,32,40,57,52,48,49,50,53,32,74,97,112,97,110,41,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,71,111,116,32,111,117,116,115,99,97,108,101,95,120,32,97,116,116,114,58,32,37,46,49,102,10,0,0,0,109,97,103,108,111,114,100,0,116,109,110,116,0,0,0,0,104,97,115,95,97,110,97,108,111,103,58,32,37,100,10,0,109,100,95,109,97,117,105,109,97,108,108,98,0,0,0,0,82,46,112,114,101,115,99,97,108,101,114,0,0,0,0,0,75,48,53,52,48,48,48,32,82,97,109,0,0,0,0,0,37,48,56,120,58,32,85,110,100,101,102,105,110,101,100,32,84,104,117,109,98,32,105,110,115,116,114,117,99,116,105,111,110,58,32,37,48,52,120,10,0,0,0,0,0,0,0,0,68,111,110,97,108,100,32,105,110,32,77,97,117,105,32,77,97,108,108,97,114,100,32,40,69,117,114,111,41,0,0,0,109,101,110,117,0,0,0,0,114,111,104,103,97,117,0,0,101,110,116,101,114,0,0,0,82,45,62,112,111,114,116,49,95,100,100,114,0,0,0,0,68,111,99,107,32,77,97,110,0,0,0,0,0,0,0,0,73,110,118,101,114,116,32,115,99,114,101,101,110,0,0,0,98,97,116,114,105,100,101,114,107,0,0,0,0,0,0,0,102,105,120,101,105,103,104,116,104,0,0,0,0,0,0,0,84,97,98,108,101,32,116,121,112,101,0,0,0,0,0,0,109,100,95,109,97,117,105,109,97,108,108,0,0,0,0,0,116,105,103,101,114,104,98,51,0,0,0,0,0,0,0,0,83,99,114,97,109,98,108,101,32,40,82,101,98,101,110,32,83,46,65,46,32,83,112,97,110,105,115,104,32,98,111,111,116,108,101,103,41,0,0,0,68,111,109,105,110,117,115,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,0,0,68,111,103,121,117,117,110,32,40,116,101,115,116,32,108,111,99,97,116,105,111,110,32,118,101,114,115,105,111,110,41,0,0,0,0,0,0,0,0,0,98,103,97,114,101,103,103,97,104,107,0,0,0,0,0,0,115,97,109,101,115,97,109,101,0,0,0,0,0,0,0,0,109,100,95,100,111,109,105,110,117,115,0,0,0,0,0,0,115,101,110,100,105,110,103,0,111,117,116,122,111,110,101,100,0,0,0,0,0,0,0,0,68,101,109,111,110,39,115,32,87,111,114,108,100,32,47,32,72,111,114,114,111,114,32,83,116,111,114,121,32,40,115,101,116,32,52,41,0,0,0,0,73,107,97,122,117,115,101,33,32,75,111,105,32,110,111,32,68,111,107,105,32,68,111,107,105,32,80,101,110,103,117,105,110,32,76,97,110,100,32,77,68,32,40,74,112,110,44,32,71,97,109,101,32,110,111,32,75,97,110,100,117,109,101,32,77,101,103,97,67,68,32,82,105,112,41,0,0,0,0,0,97,111,100,107,0,0,0,0,77,97,103,105,99,32,71,97,117,103,101,32,83,112,101,101,100,0,0,0,0,0,0,0,80,50,32,66,117,116,116,111,110,32,66,0,0,0,0,0,101,110,97,98,108,101,95,105,110,116,101,114,114,117,112,116,91,48,93,0,0,0,0,0,46,115,116,97,116,101,0,0,81,117,105,122,32,67,104,105,107,121,117,32,66,111,117,101,105,32,71,117,110,32,40,74,97,112,97,110,41,0,0,0,49,57,56,55,63,0,0,0,100,114,103,110,105,110,106,97,98,50,0,0,0,0,0,0,71,97,109,101,44,32,69,110,103,108,105,115,104,0,0,0,67,111,110,116,114,111,108,115,0,0,0,0,0,0,0,0,101,118,101,114,121,32,49,48,48,48,75,0,0,0,0,0,82,97,99,107,32,84,101,115,116,0,0,0,0,0,0,0,71,111,108,100,101,110,32,65,120,101,32,40,115,101,116,32,51,44,32,87,111,114,108,100,44,32,70,68,49,48,57,52,32,51,49,55,45,48,49,50,48,41,0,0,0,0,0,0,84,0,0,0,117,0,0,0,101,0,0,0,0,0,0,0,109,100,95,100,111,107,105,100,111,107,105,103,110,107,0,0,87,111,110,100,101,114,32,66,111,121,32,40,115,101,116,32,50,44,32,110,111,116,32,101,110,99,114,121,112,116,101,100,41,0,0,0,0,0,0,0,79,112,101,114,97,116,105,111,110,32,84,104,117,110,100,101,114,98,111,108,116,32,40,74,97,112,97,110,41,0,0,0,85,115,101,32,77,101,109,111,114,121,0,0,0,0,0,0,101,120,116,114,109,97,116,110,106,0,0,0,0,0,0,0,68,73,80,32,66,0,0,0,84,104,117,110,100,101,114,32,68,114,97,103,111,110,32,40,52,116,104,32,74,117,110,46,32,49,57,57,49,41,0,0,106,117,109,112,112,111,105,110,116,101,114,0,0,0,0,0,103,97,116,101,100,111,111,109,49,0,0,0,0,0,0,0,97,108,105,101,110,99,104,97,95,100,105,112,95,115,101,108,0,0,0,0,0,0,0,0,73,107,97,122,117,115,101,33,32,75,111,105,32,110,111,32,68,111,107,105,32,68,111,107,105,32,80,101,110,103,117,105,110,32,76,97,110,100,32,77,68,32,40,74,112,110,44,32,83,101,103,97,78,101,116,41,0,0,0,0,0,0,0,0,83,117,112,101,114,32,66,97,114,0,0,0,0,0,0,0,80,49,32,77,101,100,105,117,109,32,107,105,99,107,0,0,75,111,114,111,115,117,107,101,32,82,111,108,108,101,114,0,0,0,0,0,0,0,0,0,67,104,105,110,97,32,84,111,119,110,32,40,74,97,112,97,110,41,0,0,0,0,0,0,99,53,56,56,0,0,0,0,118,100,99,95,99,117,114,114,101,110,116,95,115,101,103,109,101,110,116,91,105,93,0,0,109,100,95,100,111,107,105,100,111,107,105,0,0,0,0,0])
.concat([67,97,114,0,0,0,0,0,115,111,117,110,100,50,95,98,97,110,107,0,0,0,0,0,99,114,97,109,95,98,97,110,107,0,0,0,0,0,0,0,68,97,114,105,117,115,32,40,69,120,116,114,97,41,32,40,74,97,112,97,110,41,0,0,99,97,100,97,115,104,105,0,67,105,116,121,32,72,117,110,116,101,114,0,0,0,0,0,102,102,105,103,104,116,106,50,0,0,0,0,0,0,0,0,66,117,98,98,108,101,32,66,111,98,98,108,101,32,40,85,83,41,0,0,0,0,0,0,68,74,32,66,111,121,32,40,85,83,65,41,0,0,0,0,76,97,115,116,32,83,116,114,105,107,101,114,32,47,32,75,121,117,117,107,121,111,107,117,32,110,111,32,83,116,114,105,107,101,114,0,0,0,0,0,109,99,117,95,99,111,105,110,95,108,111,99,107,111,117,116,0,0,0,0,0,0,0,0,84,104,101,32,78,105,110,106,97,32,87,97,114,114,105,111,114,115,32,40,87,111,114,108,100,41,0,0,0,0,0,0,109,100,95,115,111,110,105,99,51,106,0,0,0,0,0,0,60,85,115,101,32,116,104,105,115,32,100,105,114,101,99,116,111,114,121,62,0,0,0,0,100,100,116,111,100,106,114,49,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,71,111,116,32,111,117,116,115,99,97,108,101,32,97,116,116,114,58,32,37,46,49,102,10,0,0,0,0,0,111,117,116,114,117,110,98,0,109,100,95,100,106,98,111,121,117,0,0,0,0,0,0,0,65,108,105,101,110,32,83,121,110,100,114,111,109,101,32,40,115,101,116,32,55,44,32,83,121,115,116,101,109,32,49,54,66,44,32,77,67,45,56,49,50,51,66,32,51,49,55,45,48,48,120,120,41,0,0,0,115,102,105,105,105,50,0,0,46,99,103,112,0,0,0,0,83,121,115,116,101,109,49,54,67,111,108,83,99,114,111,108,108,0,0,0,0,0,0,0,68,74,32,66,111,121,32,40,74,112,110,41,0,0,0,0,78,111,118,32,49,48,32,50,48,49,51,0,0,0,0,0,82,71,85,73,32,109,101,110,117,32,116,111,103,103,108,101,0,0,0,0,0,0,0,0,66,114,97,105,110,0,0,0,46,105,110,102,111,0,0,0,71,45,76,79,67,32,65,105,114,32,66,97,116,116,108,101,32,40,85,83,41,0,0,0,109,100,95,100,106,98,111,121,106,0,0,0,0,0,0,0,65,102,116,101,114,32,66,117,114,110,101,114,32,40,74,97,112,97,110,41,0,0,0,0,51,32,67,111,105,110,115,32,49,32,67,114,101,100,105,116,115,32,0,0,0,0,0,0,86,100,112,86,83,99,114,111,108,108,77,111,100,101,0,0,115,99,114,97,109,98,108,101,114,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,105,110,99,32,114,101,115,97,109,112,108,101,114,32,91,67,93,10,0,0,68,74,32,66,111,121,32,40,69,117,114,111,41,0,0,0,65,108,101,120,32,75,105,100,100,58,32,84,104,101,32,76,111,115,116,32,83,116,97,114,115,32,40,115,101,116,32,49,44,32,70,68,49,48,56,57,65,32,51,49,55,45,117,110,107,110,111,119,110,41,0,0,110,68,114,118,82,111,109,66,97,110,107,0,0,0,0,0,104,101,100,112,97,110,105,99,102,0,0,0,0,0,0,0,46,112,110,103,0,0,0,0,109,100,95,100,106,98,111,121,0,0,0,0,0,0,0,0,66,97,99,107,32,83,116,114,101,101,116,32,83,111,99,99,101,114,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,99,114,101,97,116,101,32,114,101,110,100,101,114,105,110,103,32,98,97,99,107,101,110,100,58,32,37,115,46,10,0,0,0,118,105,100,101,111,95,120,115,99,97,108,101,0,0,0,0,115,101,97,114,99,104,112,50,0,0,0,0,0,0,0,0,86,105,100,101,111,32,83,121,115,116,101,109,0,0,0,0,80,50,32,66,117,116,116,111,110,32,65,0,0,0,0,0,67,89,88,0,0,0,0,0,87,105,110,110,105,110,103,32,82,111,117,110,100,115,32,40,80,108,97,121,101,114,32,86,83,32,67,80,85,41,0,0,71,111,117,107,101,116,115,117,106,105,32,71,97,105,100,101,110,32,76,101,103,101,110,100,115,32,40,85,83,65,44,32,118,101,114,46,32,57,53,47,48,54,47,50,48,41,0,0,122,101,114,111,112,110,116,50,0,0,0,0,0,0,0,0,110,66,114,105,103,104,116,110,101,115,115,0,0,0,0,0,115,97,118,101,115,116,97,116,101,95,100,105,114,101,99,116,111,114,121,0,0,0,0,0,113,122,99,104,105,107,121,117,0,0,0,0,0,0,0,0,76,111,103,105,99,32,80,114,111,32,50,32,40,74,97,112,97,110,41,0,0,0,0,0,77,111,100,101,0,0,0,0,101,118,101,114,121,32,57,48,48,107,0,0,0,0,0,0,103,111,108,100,110,97,120,101,51,0,0,0,0,0,0,0,77,0,0,0,111,0,0,0,110,0,0,0,0,0,0,0,68,105,118,105,110,101,32,83,101,97,108,105,110,103,32,40,74,112,110,41,0,0,0,0,119,98,111,121,50,117,0,0,100,114,103,110,109,115,116,95,111,107,105,49,95,98,97,110,107,0,0,0,0,0,0,0,80,49,32,76,101,102,116,32,83,116,105,99,107,32,76,101,102,116,0,0,0,0,0,0,78,97,116,105,111,110,97,108,32,65,110,116,104,101,109,32,38,32,70,108,97,103,0,0,66,101,101,45,79,104,0,0,116,100,114,97,103,111,110,49,0,0,0,0,0,0,0,0,82,97,105,100,101,110,32,40,85,83,44,32,115,101,116,32,49,41,0,0,0,0,0,0,86,32,114,101,118,101,114,115,101,0,0,0,0,0,0,0,106,117,109,112,99,111,100,101,0,0,0,0,0,0,0,0,109,121,97,110,103,101,108,0,109,100,95,100,105,118,105,110,101,0,0,0,0,0,0,0,115,117,112,101,114,98,97,114,0,0,0,0,0,0,0,0,107,111,114,111,115,117,107,101,0,0,0,0,0,0,0,0,84,104,101,32,68,105,115,110,101,121,32,67,111,108,108,101,99,116,105,111,110,32,45,32,77,105,99,107,101,121,32,97,110,100,32,68,111,110,97,108,100,32,40,69,117,114,111,41,0,0,0,0,0,0,0,0,112,110,103,0,0,0,0,0,84,121,112,101,0,0,0,0,115,102,95,97,99,116,105,118,101,0,0,0,0,0,0,0,119,119,102,119,102,101,115,116,106,0,0,0,0,0,0,0,115,117,112,109,111,100,101,108,0,0,0,0,0,0,0,0,112,99,101,95,99,105,116,121,104,117,110,116,0,0,0,0,70,105,110,97,108,32,70,105,103,104,116,32,40,57,48,48,49,49,50,32,74,97,112,97,110,41,0,0,0,0,0,0,65,0,0,0,114,0,0,0,116,0,0,0,32,0,0,0,111,0,0,0,102,0,0,0,32,0,0,0,70,0,0,0,105,0,0,0,103,0,0,0,104,0,0,0,116,0,0,0,105,0,0,0,110,0,0,0,103,0,0,0,0,0,0,0,141,159,0,0,78,134,0,0,110,48,0,0,243,98,0,0,32,0,0,0,40,0,0,0,78,0,0,0,71,0,0,0,77,0,0,0,45,0,0,0,48,0,0,0,52,0,0,0,52,0,0,0,41,0,0,0,40,0,0,0,78,0,0,0,71,0,0,0,72,0,0,0,45,0,0,0,48,0,0,0,52,0,0,0,52,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,105,111,109,101,99,104,97,110,105,99,97,108,32,84,111,121,32,40,86,101,114,46,32,49,46,48,46,49,56,56,53,41,0,0,0,0,0,0,0,109,100,95,100,105,115,110,101,121,99,108,0,0,0,0,0,127,48,0,0,132,48,0,0,89,48,0,0,110,48,0,0,147,48,0,0,77,48,0,0,110,48,0,0,32,0,0,0,175,48,0,0,164,48,0,0,186,48,0,0,17,255,0,0,24,255,0,0,129,121,0,0,32,0,0,0,36,255,0,0,82,255,0,0,14,255,0,0,32,0,0,0,168,48,0,0,195,48,0,0,97,48,0,0,131,48,0,0,147,48,0,0,110,48,0,0,58,138,0,0,223,91,0,0,164,91,0,0,0,0,0,0,77,0,0,0,105,0,0,0,121,0,0,0,97,0,0,0,115,0,0,0,117,0,0,0,32,0,0,0,78,0,0,0,111,0,0,0,110,0,0,0,107,0,0,0,105,0,0,0,32,0,0,0,110,0,0,0,111,0,0,0,32,0,0,0,81,0,0,0,117,0,0,0,105,0,0,0,122,0,0,0,32,0,0,0,49,0,0,0,56,0,0,0,45,0,0,0,75,0,0,0,105,0,0,0,110,0,0,0,0,0,0,0,0,0,0,0,80,0,0,0,114,0,0,0,101,0,0,0,116,0,0,0,116,0,0,0,121,0,0,0,32,0,0,0,83,0,0,0,111,0,0,0,108,0,0,0,100,0,0,0,105,0,0,0,101,0,0,0,114,0,0,0,32,0,0,0,83,0,0,0,97,0,0,0,105,0,0,0,108,0,0,0,111,0,0,0,114,0,0,0,32,0,0,0,77,0,0,0,111,0,0,0,111,0,0,0,110,0,0,0,0,0,0,0,142,127,0,0,17,92,0,0,115,89,0,0,38,98,0,0,235,88,0,0,32,0,0,0,187,48,0,0,252,48,0,0,233,48,0,0,252,48,0,0,224,48,0,0,252,48,0,0,243,48,0,0,32,0,0,0,40,0,0,0,118,0,0,0,101,0,0,0,114,0,0,0,46,0,0,0,32,0,0,0,57,0,0,0,53,0,0,0,47,0,0,0,48,0,0,0,51,0,0,0,47,0,0,0,50,0,0,0,50,0,0,0,66,0,0,0,44,0,0,0,32,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,83,111,110,105,99,32,116,104,101,32,72,101,100,103,101,104,111,103,32,51,32,40,69,117,114,111,41,0,0,0,0,0,37,115,124,122,105,112,0,0,68,117,110,103,101,111,110,115,32,38,32,68,114,97,103,111,110,115,32,45,32,116,111,119,101,114,32,111,102,32,100,111,111,109,32,40,57,52,48,52,49,50,32,74,97,112,97,110,41,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,71,111,116,32,115,105,122,101,95,121,32,97,116,116,114,58,32,37,117,10,0,70,97,99,101,0,0,0,0,80,111,119,101,114,32,73,110,115,116,105,110,99,116,32,40,85,83,65,44,32,98,111,111,116,108,101,103,32,115,101,116,32,50,41,0,0,0,0,0,84,111,109,32,77,97,115,111,110,39,115,32,68,105,110,111,115,97,117,114,115,32,102,111,114,32,72,105,114,101,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,51,48,53,48,50,41,0,0,0,0,75,97,114,97,116,101,32,66,108,97,122,101,114,115,32,40,85,83,41,0,0,0,0,0,72,111,116,32,77,105,110,100,32,40,72,97,114,100,32,84,105,109,101,115,32,104,97,114,100,119,97,114,101,41,0,0,109,100,95,100,105,110,111,104,105,114,101,112,49,0,0,0,66,117,105,108,116,58,32,37,115,10,0,0,0,0,0,0,150,153,0,0,24,152,0,0,2,135,0,0,32,0,0,0,68,0,0,0,111,0,0,0,110,0,0,0,80,0,0,0,97,0,0,0,99,0,0,0,104,0,0,0,105,0,0,0,32,0,0,0,40,0,0,0,75,0,0,0,111,0,0,0,114,0,0,0,101,0,0,0,97,0,0,0,44,0,0,0,32,0,0,0,118,0,0,0,101,0,0,0,114,0,0,0,46,0,0,0,32,0,0,0,49,0,0,0,46,0,0,0,49,0,0,0,50,0,0,0,44,0,0,0,32,0,0,0,57,0,0,0,53,0,0,0,47,0,0,0,48,0,0,0,53,0,0,0,47,0,0,0,50,0,0,0,120,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,111,109,32,77,97,115,111,110,39,115,32,68,105,110,111,115,97,117,114,115,32,102,111,114,32,72,105,114,101,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,51,48,52,50,55,41,0,0,0,0,53,32,67,111,105,110,45,54,32,80,108,97,121,0,0,0,83,99,114,97,109,98,108,101,32,40,98,111,111,116,108,101,103,41,0,0,0,0,0,0,75,48,53,51,50,53,49,80,97,108,73,110,100,101,120,91,48,93,0,0,0,0,0,0,109,100,95,100,105,110,111,104,105,114,101,112,50,0,0,0,66,101,115,116,114,105,32,40,75,111,114,101,97,41,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,105,110,105,116,105,97,108,105,122,101,32,114,101,115,97,109,112,108,101,114,32,34,37,115,34,46,10,0,0,0,0,0,0,80,115,105,107,121,111,0,0,83,112,97,99,101,32,66,111,109,98,101,114,32,40,118,101,114,46,32,66,41,0,0,0,104,111,116,103,109,52,101,118,0,0,0,0,0,0,0,0,115,107,121,108,97,110,99,114,101,0,0,0,0,0,0,0,84,111,109,32,77,97,115,111,110,39,115,32,68,105,110,111,115,97,117,114,115,32,102,111,114,32,72,105,114,101,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,51,48,52,50,54,41,0,0,0,0,53,32,67,111,105,110,115,32,49,32,80,108,97,121,0,0,102,49,100,114,101,97,109,0,80,111,114,107,121,0,0,0,75,48,53,50,49,48,57,32,67,111,110,116,114,111,108,0,51,48,75,0,0,0,0,0,82,111,117,116,101,32,88,32,40,98,111,111,116,108,101,103,41,0,0,0,0,0,0,0,107,111,122,117,114,101,0,0,67,111,105,110,32,50,0,0,109,100,95,100,105,110,111,104,105,114,101,112,51,0,0,0,112,52,32,102,105,114,101,32,50,0,0,0,0,0,0,0,112,107,108,97,100,105,101,115,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,115,97,118,101,102,105,108,101,95,100,105,114,101,99,116,111,114,121,32,105,115,32,110,111,116,32,97,32,100,105,114,101,99,116,111,114,121,44,32,105,103,110,111,114,105,110,103,32,46,46,46,10,0,0,0,0,0,0,0,0,81,117,105,122,32,72,46,81,46,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,114,111,99,107,100,117,99,107,0,0,0,0,0,0,0,0,119,119,102,115,115,116,97,114,98,0,0,0,0,0,0,0,107,97,110,103,97,114,111,111,98,0,0,0,0,0,0,0,83,117,112,101,114,32,68,114,101,97,109,32,76,97,110,100,0,0,0,0,0,0,0,0,68,101,98,117,103,32,77,111,100,101,0,0,0,0,0,0,101,118,101,114,121,32,56,48,48,107,0,0,0,0,0,0,103,101,110,115,105,116,111,117,0,0,0,0,0,0,0,0,71,111,108,100,101,110,32,65,120,101,32,40,115,101,116,32,50,44,32,85,83,44,32,56,55,53,49,32,51,49,55,45,48,49,49,50,41,0,0,0,65,103,114,101,115,115,0,0,75,48,53,51,50,52,53,32,66,117,102,102,101,114,0,0,83,0,0,0,117,0,0,0,110,0,0,0,0,0,0,0,84,111,109,32,77,97,115,111,110,39,115,32,68,105,110,111,115,97,117,114,115,32,102,111,114,32,72,105,114,101,32,40,85,83,65,41,0,0,0,0,87,111,110,100,101,114,32,66,111,121,32,40,115,101,116,32,50,44,32,51,49,53,45,53,49,55,56,41,0,0,0,0,85,115,101,32,66,114,97,107,101,0,0,0,0,0,0,0,68,73,80,32,65,0,0,0,117,110,115,112,101,99,105,102,105,101,100,32,105,111,115,116,114,101,97,109,95,99,97,116,101,103,111,114,121,32,101,114,114,111,114,0,0,0,0,0,78,77,75,32,40,84,101,99,109,111,32,108,105,99,101,110,115,101,41,0,0,0,0,0,112,117,99,107,109,97,110,104,0,0,0,0,0,0,0,0,112,114,111,116,0,0,0,0,69,118,101,114,121,32,53,48,48,44,48,48,48,44,32,79,110,99,101,32,97,116,32,72,105,103,104,101,115,116,32,83,99,111,114,101,0,0,0,0,66,108,97,99,107,32,84,105,103,101,114,32,40,98,111,111,116,108,101,103,32,115,101,116,32,50,41,0,0,0,0,0,70,97,107,101,32,68,105,112,0,0,0,0,0,0,0,0,109,100,95,100,105,110,111,104,105,114,101,0,0,0,0,0,103,97,117,110,116,108,101,116,106,49,50,0,0,0,0,0,80,114,111,109,97,116,0,0,71,97,109,101,32,116,105,109,101,32,40,97,99,116,117,97,108,32,103,97,109,101,41,0,104,97,115,97,109,117,0,0,67,111,110,116,105,110,117,101,32,80,108,97,121,32,79,102,102,0,0,0,0,0,0,0,115,112,97,99,101,0,0,0,98,111,109,98,106,97,99,107,73,82,81,0,0,0,0,0,80,49,32,87,101,97,107,32,107,105,99,107,0,0,0,0,112,97,99,108,97,110,100,109,0,0,0,0,0,0,0,0,77,97,103,105,99,32,66,114,117,115,104,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,97,110,110,111,116,32,102,105,110,100,32,34,115,104,97,100,101,114,115,34,32,112,97,114,97,109,46,10,0,0,0,0,0,0,77,114,46,32,76,111,33,0,0,0,0,0,0,0,0,0,51,48,107,32,116,104,101,110,32,101,118,101,114,121,32,55,48,107,0,0,0,0,0,0,83,111,108,111,109,111,110,83,111,117,110,100,76,97,116,99,104,0,0,0,0,0,0,0,72,105,45,84,101,99,104,32,69,120,112,114,101,115,115,105,111,110,0,0,0,0,0,0,79,117,116,32,89,32,61,32,37,100,32,61,62,32,73,110,32,89,32,61,32,37,100,10,0,0,0,0,0,0,0,0,77,0,0,0,97,0,0,0,114,0,0,0,116,0,0,0,105,0,0,0,97,0,0,0,108,0,0,0,32,0,0,0,77,0,0,0,97,0,0,0,115,0,0,0,116,0,0,0,101,0,0,0,114,0,0,0,115,0,0,0,0,0,0,0,98,95,0,0,15,97,0,0,243,98,0,0,32,0,0,0,40,0,0,0,86,0,0,0,49,0,0,0,48,0,0,0,50,0,0,0,44,0,0,0,32,0,0,0,49,0,0,0,48,0,0,0,49,0,0,0,44,0,0,0,32,0,0,0,49,0,0,0,48,0,0,0,49,0,0,0,44,0,0,0,32,0,0,0,67,0,0,0,104,0,0,0,105,0,0,0,110,0,0,0,97,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,97,109,97,122,111,110,0,0,89,117,110,105,32,80,111,115,116,0,0,0,0,0,0,0,102,102,105,103,104,116,106,49,0,0,0,0,0,0,0,0,74,117,74,117,32,68,101,110,115,101,116,115,117,32,40,74,97,112,97,110,41,0,0,0,65,114,116,32,111,102,32,70,105,103,104,116,105,110,103,32,47,32,82,121,117,117,107,111,32,110,111,32,75,101,110,32,40,78,71,77,45,48,52,52,41,40,78,71,72,45,48,52,52,41,0,0,0,0,0,0,101,120,101,100,101,120,101,115,95,115,111,117,110,100,108,97,116,99,104,0,0,0,0,0,65,32,68,105,110,111,115,97,117,114,39,115,32,84,97,108,101,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,118,117,108,103,117,115,95,102,108,105,112,115,99,114,101,101,110,0,0,0,0,0,0,0,49,57,52,50,119,0,0,0,86,105,100,101,111,32,82,97,109,32,35,49,0,0,0,0,109,100,95,115,111,110,105,99,51,0,0,0,0,0,0,0,99,103,124,103,108,115,108,0,100,100,116,111,100,106,0,0,82,101,116,114,111,65,114,99,104,58,32,71,111,116,32,115,105,122,101,95,120,32,97,116,116,114,58,32,37,117,10,0,76,101,103,101,110,100,97,114,121,32,87,105,110,103,115,32,40,85,83,32,115,101,116,32,50,41,0,0,0,0,0,0,97,116,101,116,114,105,115,98,50,0,0,0,0,0,0,0,109,100,95,100,105,110,111,116,97,108,101,0,0,0,0,0,75,48,53,51,50,52,55,32,82,101,103,115,0,0,0,0,72,97,114,97,32,73,110,100,117,115,116,114,105,101,115,0,83,117,112,101,114,32,71,108,111,98,0,0,0,0,0,0,83,65,82,32,45,32,83,101,97,114,99,104,32,65,110,100,32,82,101,115,99,117,101,32,40,85,83,41,0,0,0,0,67,104,111,117,32,84,111,117,114,121,117,117,32,82,101,116,115,117,100,101,110,32,45,32,68,105,110,111,32,76,97,110,100,32,40,74,112,110,41,0,0,0,0,0,0,0,0,0,67,111,109,109,97,110,100,111,32,40,98,111,111,116,108,101,103,41,0,0,0,0,0,0,49,57,52,51,58,32,77,105,100,119,97,121,32,75,97,105,115,101,110,32,40,74,97,112,97,110,41,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,85,115,105,110,103,32,82,88,77,76,32,97,115,32,100,114,111,112,32,105,110,32,102,111,114,32,108,105,98,120,109,108,50,46,32,66,101,104,97,118,105,111,114,32,109,105,103,104,116,32,98,101,32,118,101,114,121,32,98,117,103,103,121,46,10,0,0,0,52,46,50,46,49,32,67,111,109,112,97,116,105,98,108,101,32,67,108,97,110,103,32,51,46,50,32,40,116,97,103,115,47,82,69,76,69,65,83,69,95,51,50,47,102,105,110,97,108,41,0,0,0,0,0,0,71,114,97,98,32,109,111,117,115,101,32,116,111,103,103,108,101,0,0,0,0,0,0,0,83,107,121,32,87,111,108,102,32,40,115,101,116,32,50,41,0,0,0,0,0,0,0,0,109,100,95,100,105,110,111,108,97,110,100,106,0,0,0,0,102,101,101,100,98,97,99,107,0,0,0,0,0,0,0,0,115,102,112,0,0,0,0,0,82,117,115,104,32,38,32,67,114,97,115,104,32,40,74,97,112,97,110,41,0,0,0,0,78,97,109,99,111,32,91,83,105,112,101,109,32,108,105,99,101,110,115,101,93,0,0,0,87,99,57,48,98,49,73,110,112,117,116,0,0,0,0,0,115,99,114,97,109,98,50,0,71,104,111,115,116,115,39,110,32,71,111,98,108,105,110,115,32,40,98,111,111,116,108,101,103,44,32,104,97,114,100,101,114,41,0,0,0,0,0,0,109,114,102,108,101,97,95,115,101,108,101,99,116,91,48,93,0,0,0,0,0,0,0,0,68,105,110,111,32,76,97,110,100,32,40,85,83,65,41,0,0,0,0,0,0,0,0,0,71,97,108,97,103,97,32,40,77,105,100,119,97,121,32,115,101,116,32,50,41,0,0,0,82,97,108,108,121,32,88,32,40,77,111,100,101,108,32,82,97,99,105,110,103,41,0,0,82,101,116,114,111,65,114,99,104,58,32,83,97,118,101,100,32,115,117,99,99,101,115,115,102,117,108,108,121,32,116,111,32,34,37,115,34,46,10,0,115,118,111,108,108,101,121,107,0,0,0,0,0,0,0,0,65,109,98,117,115,104,32,40,86,111,108,116,32,69,108,101,99,32,99,111,45,108,116,100,41,0,0,0,0,0,0,0,114,121,103,97,114,98,0,0,109,100,95,100,105,110,111,108,97,110,100,0,0,0,0,0,68,111,117,98,108,101,32,68,114,97,103,111,110,32,40,85,83,32,115,101,116,32,49,41,0,0,0,0,0,0,0,0,77,67,54,56,52,48,95,105,100,120,49,0,0,0,0,0,110,80,103,109,90,56,48,87,111,114,107,0,0,0,0,0,109,95,111,108,100,115,95,114,101,103,0,0,0,0,0,0,112,115,112,105,107,101,115,50,0,0,0,0,0,0,0,0,70,114,101,101,122,101,32,83,99,114,101,101,110,0,0,0,80,50,32,70,105,114,101,32,51,0,0,0,0,0,0,0,68,105,110,111,32,68,105,110,105,39,115,32,83,111,99,99,101,114,32,40,69,117,114,111,41,0,0,0,0,0,0,0,46,115,114,109,0,0,0,0,79,0,0,0,114,0,0,0,105,0,0,0,101,0,0,0,110,0,0,0,116,0,0,0,97,0,0,0,108,0,0,0,32,0,0,0,76,0,0,0,101,0,0,0,103,0,0,0,101,0,0,0,110,0,0,0,100,0,0,0,0,0,0,0,127,137,0,0,56,110,0,0,202,145,0,0,132,83,0,0,32,79,0,0,32,0,0,0,40,0,0,0,86,0,0,0,49,0,0,0,49,0,0,0,50,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,113,117,105,122,104,113,0,0,68,114,101,97,109,32,76,97,110,100,0,0,0,0,0,0,101,118,101,114,121,32,55,48,48,107,0,0,0,0,0,0,103,111,108,100,110,97,120,101,50,0,0,0,0,0,0,0,109,100,95,100,105,110,111,100,105,110,105,0,0,0,0,0,83,0,0,0,97,0,0,0,116,0,0,0,117,0,0,0,114,0,0,0,100,0,0,0,97,0,0,0,121,0,0,0,0,0,0,0,0,0,0,0,119,98,111,121,50,0,0,0,80,49,32,76,101,102,116,32,83,116,105,99,107,32,68,111,119,110,0,0,0,0,0,0,87,104,101,101,108,32,40,50,55,48,41,0,0,0,0,0,84,104,117,110,100,101,114,32,68,114,97,103,111,110,32,40,57,116,104,32,74,97,110,46,32,49,57,57,50,41,0,0,50,52,48,44,48,48,48,44,32,49,44,52,48,48,44,48,48,48,0,0,0,0,0,0,84,105,109,101,32,87,97,114,110,101,114,32,73,110,116,101,114,97,99,116,105,118,101,0,87,105,103,103,105,101,32,87,97,103,103,105,101,0,0,0,67,111,110,116,105,110,117,101,32,80,108,97,121,32,79,110,0,0,0,0,0,0,0,0,109,98,114,117,115,104,0,0,65,109,97,122,111,110,80,114,111,116,82,101,103,0,0,0,68,105,99,107,32,86,105,116,97,108,101,39,115,32,39,65,119,101,115,111,109,101,44,32,66,97,98,121,33,39,32,67,111,108,108,101,103,101,32,72,111,111,112,115,32,40,85,83,65,41,0,0,0,0,0,0,51,48,107,32,56,48,107,32,56,48,107,0,0,0,0,0,73,110,118,105,110,99,105,98,105,108,105,116,121,32,40,67,104,101,97,116,41,0,0,0,77,97,114,116,105,97,108,32,77,97,115,116,101,114,115,32,40,86,49,48,50,44,32,49,48,49,44,32,49,48,49,44,32,67,104,105,110,97,41,0,0,0,0,0,0,0,0,0,67,105,114,99,117,115,32,76,105,100,111,0,0,0,0,0,70,105,110,97,108,32,70,105,103,104,116,32,40,74,97,112,97,110,41,0,0,0,0,0,83,121,115,116,101,109,32,45,32,109,101,100,105,97,32,115,101,108,101,99,116,101,100,32,115,101,112,101,114,97,116,101,108,121,0,0,0,0,0,0,109,100,95,100,105,99,107,118,105,116,108,0,0,0,0,0,51,119,111,110,100,101,114,115,0,0,0,0,0,0,0,0,83,111,108,101,105,108,32,40,71,101,114,41,0,0,0,0,99,103,112,124,103,108,115,108,112,0,0,0,0,0,0,0,68,117,110,103,101,111,110,115,32,38,32,68,114,97,103,111,110,115,32,45,32,116,111,119,101,114,32,111,102,32,100,111,111,109,32,40,57,52,48,49,49,51,32,72,105,115,112,97,110,105,99,41,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,71,111,116,32,115,105,122,101,32,97,116,116,114,58,32,37,117,10,0,0,0,68,105,99,107,32,84,114,97,99,121,32,40,87,111,114,108,100,41,0,0,0,0,0,0,109,100,95,100,105,99,107,116,114,0,0,0,0,0,0,0,67,108,97,110,103,47,76,76,86,77,32,40,37,115,41,32,37,117,45,98,105,116,10,0,83,76,79,84,45,62,67,79,78,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,99,111,100,101,32,45,45,32,109,105,115,115,105,110,103,32,101,110,100,45,111,102,45,98,108,111,99,107,0,0,0,0,103,108,67,111,109,112,114,101,115,115,101,100,84,101,120,83,117,98,73,109,97,103,101,51,68,79,69,83,0,0,0,0,68,105,97,108,32,81,32,111,32,77,97,119,97,115,101,33,32,40,74,112,110,41,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,99,111,110,102,105,103,32,102,105,108,101,58,32,37,115,46,10,0,0,0,105,110,32,118,101,99,50,32,84,101,120,67,111,111,114,100,59,10,105,110,32,118,101,99,50,32,86,101,114,116,101,120,67,111,111,114,100,59,10,105,110,32,118,101,99,52,32,67,111,108,111,114,59,10,117,110,105,102,111,114,109,32,109,97,116,52,32,77,86,80,77,97,116,114,105,120,59,10,111,117,116,32,118,101,99,50,32,116,101,120,95,99,111,111,114,100,59,10,111,117,116,32,118,101,99,52,32,99,111,108,111,114,59,10,118,111,105,100,32,109,97,105,110,40,41,32,123,10,32,32,32,103,108,95,80,111,115,105,116,105,111,110,32,61,32,77,86,80,77,97,116,114,105,120,32,42,32,118,101,99,52,40,86,101,114,116,101,120,67,111,111,114,100,44,32,48,46,48,44,32,49,46,48,41,59,10,32,32,32,116,101,120,95,99,111,111,114,100,32,61,32,84,101,120,67,111,111,114,100,59,10,32,32,32,99,111,108,111,114,32,61,32,67,111,108,111,114,59,10,125,0,0,83,99,114,97,109,98,108,101,32,40,98,111,111,116,108,101,103,32,111,110,32,71,97,108,97,120,105,97,110,32,104,97,114,100,119,97,114,101,41,0,0,0,0,0,0,0,0,0,109,100,95,100,105,97,108,113,111,0,0,0,0,0,0,0,101,120,105,115,116,115,0,0,72,111,116,45,66,0,0,0,37,46,49,102,120,0,0,0,74,97,109,101,115,32,66,111,110,100,32,48,48,55,32,45,32,84,104,101,32,68,117,101,108,32,40,69,117,114,111,44,32,82,101,118,46,32,65,41,0,0,0,0,0,0,0,0,75,48,53,50,49,48,57,67,104,97,114,82,111,109,66,97,110,107,91,51,93,0,0,0,80,50,32,70,105,114,101,32,50,0,0,0,0,0,0,0,66,97,100,32,79,109,101,110,32,40,74,112,110,44,32,75,111,114,41,0,0,0,0,0,170,96,0,0,84,155,0,0,206,87,0,0,32,0,0,0,201,48,0,0,233,48,0,0,173,48,0,0,229,48,0,0,233,48,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,32,0,0,0,118,0,0,0,101,0,0,0,114,0,0,0,46,0,0,0,32,0,0,0,80,0,0,0,41,0,0,0,0,0,0,0,65,0,0,0,107,0,0,0,117,0,0,0,109,0,0,0,97,0,0,0,45,0,0,0,74,0,0,0,111,0,0,0,117,0,0,0,32,0,0,0,68,0,0,0,114,0,0,0,97,0,0,0,99,0,0,0,117,0,0,0,108,0,0,0,97,0,0,0,0,0,0,0,0,0,0,0,112,52,32,102,105,114,101,32,49,0,0,0,0,0,0,0,234,48,0,0,243,48,0,0,176,48,0,0,110,48,0,0,32,0,0,0,139,115,0,0,5,128,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,32,0,0,0,50,0,0,0,32,0,0,0,80,0,0,0,108,0,0,0,97,0,0,0,121,0,0,0,101,0,0,0,114,0,0,0,115,0,0,0,32,0,0,0,118,0,0,0,101,0,0,0,114,0,0,0,46,0,0,0,32,0,0,0,78,0,0,0,41,0,0,0,0,0,0,0,82,0,0,0,105,0,0,0,110,0,0,0,103,0,0,0,32,0,0,0,110,0,0,0,111,0,0,0,32,0,0,0,79,0,0,0,104,0,0,0,106,0,0,0,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,115,97,118,101,102,105,108,101,95,100,105,114,101,99,116,111,114,121,0,0,0,0,0,0,79,48,0,0,68,48,0,0,90,48,0,0,32,0,0,0,230,130,0,0,195,128,0,0,45,152,0,0,32,0,0,0,85,99,0,0,105,114,0,0,51,94,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,81,0,0,0,117,0,0,0,105,0,0,0,122,0,0,0,32,0,0,0,84,0,0,0,111,0,0,0,114,0,0,0,105,0,0,0,109,0,0,0,111,0,0,0,110,0,0,0,111,0,0,0,99,0,0,0,104,0,0,0,111,0,0,0,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,97,108,105,101,110,115,106,0,71,97,109,101,0,0,0,0,80,0,0,0,97,0,0,0,114,0,0,0,111,0,0,0,100,0,0,0,105,0,0,0,117,0,0,0,115,0,0,0,32,0,0,0,209,48,0,0,237,48,0,0,199,48,0,0,163,48,0,0,166,48,0,0,185,48,0,0,96,48,0,0,1,255,0,0,32,0,0,0,13,255,0,0,94,121,0,0,113,138,0,0,75,48,0,0,137,48,0,0,74,48,0,0,17,123,0,0,68,48,0,0,120,48,0,0,13,255,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,83,101,116,116,105,110,103,32,82,71,85,73,32,67,71,80,32,102,97,105,108,101,100,46,10,0,0,71,111,108,100,101,110,32,65,120,101,32,40,115,101,116,32,49,44,32,87,111,114,108,100,44,32,70,68,49,48,57,52,32,51,49,55,45,48,49,49,48,41,0,0,0,0,0,0,109,100,95,98,97,100,111,109,101,110,0,0,0,0,0,0,70,0,0,0,114,0,0,0,105,0,0,0,100,0,0,0,97,0,0,0,121,0,0,0,0,0,0,0,0,0,0,0,87,111,110,100,101,114,32,66,111,121,32,40,115,101,116,32,49,44,32,51,49,53,45,53,49,51,53,41,0,0,0,0,100,97,116,97,98,97,115,101,0,0,0,0,0,0,0,0,50,32,74,111,121,115,116,105,99,107,115,0,0,0,0,0,103,102,120,114,111,109,95,115,101,108,101,99,116,0,0,0,116,104,117,110,100,101,114,120,97,0,0,0,0,0,0,0,116,100,114,97,103,111,110,0,82,101,116,114,111,65,114,99,104,58,32,85,115,105,110,103,32,82,80,78,71,32,102,111,114,32,80,78,71,32,115,99,114,101,101,110,115,104,111,116,115,46,10,0,0,0,0,0,84,101,99,109,111,32,75,110,105,103,104,116,0,0,0,0,116,105,108,100,101,0,0,0,71,111,32,116,111,32,116,101,115,116,32,109,111,100,101,32,110,111,119,0,0,0,0,0,50,50,48,44,48,48,48,44,32,49,44,50,48,48,44,48,48,48,0,0,0,0,0,0,68,101,118,105,108,105,115,104,32,45,32,84,104,101,32,78,101,120,116,32,80,111,115,115,101,115,115,105,111,110,32,40,85,83,65,41,0,0,0,0,119,105,103,103,105,101,0,0,66,155,0,0,151,101,0,0,133,127,0,0,32,0,0,0,179,48,0,0,243,48,0,0,200,48,0,0,233,48,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,67,0,0,0,111,0,0,0,110,0,0,0,116,0,0,0,114,0,0,0,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,49,32,83,116,114,111,110,103,32,112,117,110,99,104,0,120,109,101,110,106,0,0,0,65,32,52,67,47,49,80,32,66,32,49,67,47,49,80,0,77,97,107,101,32,84,114,97,120,32,40,115,101,116,32,50,41,0,0,0,0,0,0,0,112,114,101,102,105,120,0,0,65,109,97,122,111,110,80,114,111,116,67,109,100,0,0,0,109,100,95,100,101,118,105,108,105,115,104,0,0,0,0,0,115,102,95,98,103,95,115,99,114,111,108,108,95,120,0,0,50,48,107,32,55,48,107,32,55,48,107,0,0,0,0,0,118,101,110,117,115,0,0,0,49,57,120,120,106,0,0,0,109,97,114,116,109,97,115,116,99,49,48,50,0,0,0,0,118,101,110,100,101,116,116,97,50,112,100,0,0,0,0,0,112,99,101,95,99,105,114,99,117,115,108,100,0,0,0,0,102,102,105,103,104,116,106,0,51,32,67,111,117,110,116,32,66,111,117,116,32,47,32,70,105,114,101,32,83,117,112,108,101,120,32,40,78,71,77,45,48,52,51,41,40,78,71,72,45,48,52,51,41,0,0,0,115,105,109,112,115,111,110,115,50,112,97,0,0,0,0,0,99,111,109,112,97,116,47,99,111,109,112,97,116,46,99,0,67,112,117,32,35,48,32,82,97,109,0,0,0,0,0,0,68,101,115,101,114,116,32,83,116,114,105,107,101,32,40,74,112,110,44,32,75,111,114,41,0,0,0,0,0,0,0,0,44,32,0,0,0,0,0,0,67,72,45,62,107,99,111,100,101,0,0,0,0,0,0,0,109,100,95,115,111,108,101,105,108,103,0,0,0,0,0,0,116,109,104,116,97,0,0,0,47,0,0,0,0,0,0,0,37,117,59,0,0,0,0,0,100,100,116,111,100,104,114,50,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,71,111,116,32,115,99,97,108,101,95,121,32,97,116,116,114,58,32,37,46,49,102,10,0,0,0,0,0,0,60,63,120,109,108,0,0,0,65,116,111,109,105,99,32,80,117,110,107,32,40,85,83,41,0,0,0,0,0,0,0,0,84,101,108,101,112,111,114,116,0,0,0,0,0,0,0,0,75,117,110,103,45,70,117,32,77,97,115,116,101,114,32,40,98,111,111,116,108,101,103,32,115,101,116,32,49,41,0,0,109,100,95,100,115,116,114,105,107,101,106,0,0,0,0,0,86,105,103,105,108,97,110,116,101,32,40,85,83,44,32,114,101,118,32,71,41,0,0,0,102,103,104,116,98,115,107,116,0,0,0,0,0,0,0,0,112,112,97,110,0,0,0,0,73,114,101,109,32,40,78,105,110,116,101,110,100,111,32,111,102,32,65,109,101,114,105,99,97,32,108,105,99,101,110,115,101,41,0,0,0,0,0,0,68,101,115,101,114,116,32,83,116,114,105,107,101,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,0,10,67,111,109,112,105,108,101,114,58,32,0,0,0,0,0,68,105,115,107,32,110,101,120,116,0,0,0,0,0,0,0,107,117,110,103,102,117,109,0,109,100,95,100,115,116,114,105,107,101,0,0,0,0,0,0,115,99,114,97,109,98,108,101,0,0,0,0,0,0,0,0,68,101,115,101,114,116,32,68,101,109,111,108,105,116,105,111,110,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,49,50,49,57,41,0,0,0,0,0,0,0,0,0,109,100,95,100,101,115,114,116,100,101,109,112,49,0,0,0,107,97,114,110,111,118,114,0,80,50,32,70,105,114,101,32,49,0,0,0,0,0,0,0,68,101,115,101,114,116,32,68,101,109,111,108,105,116,105,111,110,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,49,50,49,54,41,0,0,0,0,0,0,0,0,0,99,111,110,102,105,103,95,115,97,118,101,95,111,110,95,101,120,105,116,0,0,0,0,0,81,117,105,122,32,84,111,114,105,109,111,110,111,99,104,111,117,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,80,50,32,82,105,103,104,116,32,47,32,108,101,102,116,0,103,111,108,100,110,97,120,101,49,0,0,0,0,0,0,0,109,100,95,100,101,115,114,116,100,101,109,112,50,0,0,0,119,98,111,121,111,0,0,0,80,49,32,76,101,102,116,32,83,116,105,99,107,32,85,112,0,0,0,0,0,0,0,0,49,32,74,111,121,115,116,105,99,107,0,0,0,0,0,0,84,105,109,101,114,32,83,112,101,101,100,32,40,77,97,105,110,32,76,101,118,101,108,115,41,0,0,0,0,0,0,0,85,83,32,65,65,70,32,77,117,115,116,97,110,103,32,40,84,65,66,32,65,117,115,116,114,105,97,32,98,111,111,116,108,101,103,41,0,0,0,0,115,111,117,110,100,98,97,110,107,0,0,0,0,0,0,0,87,105,108,100,32,70,97,110,103,0,0,0,0,0,0,0,73,109,112,97,99,116,0,0,50,48,48,44,48,48,48,44,32,49,44,48,48,48,44,48,48,48,0,0,0,0,0,0,68,101,115,101,114,116,32,68,101,109,111,108,105,116,105,111,110,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,49,50,49,53,41,0,0,0,0,0,0,0,0,0,65,32,51,67,47,49,80,32,66,32,49,67,47,50,80,0,109,97,107,101,116,114,120,98,0,0,0,0,0,0,0,0,84,0,0,0,104,0,0,0,117,0,0,0,114,0,0,0,115,0,0,0,100,0,0,0,97,0,0,0,121,0,0,0,0,0,0,0,0,0,0,0,109,100,95,100,101,115,114,116,100,101,109,112,51,0,0,0,115,102,95,102,103,95,115,99,114,111,108,108,95,120,0,0,77,0,0,0,97,0,0,0,114,0,0,0,116,0,0,0,105,0,0,0,97,0,0,0,108,0,0,0,32,0,0,0,77,0,0,0,97,0,0,0,115,0,0,0,116,0,0,0,101,0,0,0,114,0,0,0,115,0,0,0,0,0,0,0,98,95,0,0,15,97,0,0,243,98,0,0,32,0,0,0,40,0,0,0,86,0,0,0,49,0,0,0,48,0,0,0,52,0,0,0,44,0,0,0,32,0,0,0,49,0,0,0,48,0,0,0,50,0,0,0,44,0,0,0,32,0,0,0,49,0,0,0,48,0,0,0,49,0,0,0,44,0,0,0,32,0,0,0,67,0,0,0,104,0,0,0,105,0,0,0,110,0,0,0,97,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,67,104,111,117,122,101,116,115,117,32,82,105,110,106,105,110,32,45,32,66,114,97,118,111,109,97,110,0,0,0,0,0,70,105,110,97,108,32,70,105,103,104,116,32,40,57,48,48,54,49,51,32,85,83,65,41,0,0,0,0,0,0,0,0,68,101,115,101,114,116,32,68,101,109,111,108,105,116,105,111,110,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,49,50,49,52,41,0,0,0,0,0,0,0,0,0,83,111,108,101,105,108,32,40,70,114,97,41,0,0,0,0,37,115,32,40,37,115,41,0,68,117,110,103,101,111,110,115,32,38,32,68,114,97,103,111,110,115,32,45,32,116,111,119,101,114,32,111,102,32,100,111,111,109,32,40,57,52,48,49,50,53,32,72,105,115,112,97,110,105,99,41,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,71,111,116,32,115,99,97,108,101,95,120,32,97,116,116,114,58,32,37,46,49,102,10,0,0,0,0,0,0,109,100,95,100,101,115,114,116,100,101,109,112,52,0,0,0,68,101,115,101,114,116,32,68,101,109,111,108,105,116,105,111,110,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,49,50,49,51,41,0,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,82,101,116,114,111,65,114,99,104,32,105,115,32,99,111,109,112,105,108,101,100,32,97,103,97,105,110,115,116,32,97,32,100,105,102,102])
.concat([101,114,101,110,116,32,118,101,114,115,105,111,110,32,111,102,32,108,105,98,114,101,116,114,111,32,116,104,97,110,32,116,104,105,115,32,108,105,98,114,101,116,114,111,32,105,109,112,108,101,109,101,110,116,97,116,105,111,110,46,10,0,0,0,82,101,116,114,111,65,114,99,104,58,32,73,110,105,116,105,110,103,32,114,101,119,105,110,100,32,98,117,102,102,101,114,32,119,105,116,104,32,115,105,122,101,58,32,37,117,32,77,66,10,0,0,0,0,0,0,109,100,95,100,101,115,114,116,100,101,109,112,53,0,0,0,115,99,114,97,109,98,108,98,0,0,0,0,0,0,0,0,75,105,110,103,98,97,108,108,83,111,117,110,100,0,0,0,68,101,115,101,114,116,32,68,101,109,111,108,105,116,105,111,110,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,49,50,49,50,41,0,0,0,0,0,0,0,0,0,109,100,95,100,101,115,114,116,100,101,109,112,54,0,0,0,71,97,108,67,111,117,110,116,68,111,119,110,0,0,0,0,68,97,116,97,32,69,97,115,116,0,0,0,0,0,0,0,80,50,32,70,105,114,101,0,68,101,115,101,114,116,32,68,101,109,111,108,105,116,105,111,110,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,49,50,49,50,45,66,41,0,0,0,0,0,0,0,112,52,32,114,105,103,104,116,0,0,0,0,0,0,0,0,106,111,121,112,97,100,95,97,117,116,111,99,111,110,102,105,103,95,100,105,114,0,0,0,113,116,111,114,105,109,111,110,0,0,0,0,0,0,0,0,71,111,108,100,101,110,32,65,120,101,32,40,115,101,116,32,54,44,32,85,83,44,32,56,55,53,49,32,51,49,55,45,49,50,51,65,41,0,0,0,109,100,95,100,101,115,114,116,100,101,109,112,55,0,0,0,83,101,103,97,32,40,69,115,99,97,112,101,32,76,105,99,101,110,115,101,41,0,0,0,67,97,110,110,111,110,0,0,109,117,115,116,97,110,103,98,50,0,0,0,0,0,0,0,116,97,98,0,0,0,0,0,110,79,107,105,66,97,110,107,0,0,0,0,0,0,0,0,68,101,115,101,114,116,32,68,101,109,111,108,105,116,105,111,110,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,49,50,48,56,41,0,0,0,0,0,0,0,0,0,59,32,0,0,0,0,0,0,78,111,32,68,101,97,116,104,44,32,83,116,111,112,32,77,111,100,101,0,0,0,0,0,80,49,32,77,101,100,105,117,109,32,112,117,110,99,104,0,65,32,50,67,47,49,80,32,66,32,49,67,47,51,80,0,91,75,117,114,97,108,93,32,40,87,105,108,108,105,97,109,115,32,108,105,99,101,110,115,101,41,0,0,0,0,0,0,67,112,115,82,97,109,55,48,56,0,0,0,0,0,0,0,87,0,0,0,101,0,0,0,100,0,0,0,110,0,0,0,101,0,0,0,115,0,0,0,100,0,0,0,97,0,0,0,121,0,0,0,0,0,0,0,109,100,95,100,101,115,114,116,100,101,109,112,56,0,0,0,77,97,114,116,105,97,108,32,77,97,115,116,101,114,115,32,40,86,49,48,52,44,32,49,48,50,44,32,49,48,49,44,32,67,104,105,110,97,41,0,0,0,0,0,0,0,0,0,112,99,101,95,98,114,97,118,111,109,97,110,0,0,0,0,102,102,105,103,104,116,117,98,0,0,0,0,0,0,0,0,175,48,0,0,164,48,0,0,186,48,0,0,247,143,0,0,162,99,0,0,117,80,0,0,205,48,0,0,170,48,0,0,6,255,0,0,184,48,0,0,170,48,0,0,32,0,0,0,45,0,0,0,32,0,0,0,81,0,0,0,117,0,0,0,105,0,0,0,122,0,0,0,32,0,0,0,68,0,0,0,97,0,0,0,105,0,0,0,115,0,0,0,111,0,0,0,117,0,0,0,115,0,0,0,97,0,0,0,32,0,0,0,83,0,0,0,101,0,0,0,110,0,0,0,32,0,0,0,112,0,0,0,97,0,0,0,114,0,0,0,116,0,0,0,32,0,0,0,50,0,0,0,32,0,0,0,40,0,0,0,78,0,0,0,71,0,0,0,77,0,0,0,45,0,0,0,48,0,0,0,52,0,0,0,50,0,0,0,41,0,0,0,40,0,0,0,78,0,0,0,71,0,0,0,72,0,0,0,45,0,0,0,48,0,0,0,52,0,0,0,50,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,101,115,101,114,116,32,68,101,109,111,108,105,116,105,111,110,32,40,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,49,50,48,54,41,0,0,0,0,0,0,0,0,0,109,100,95,115,111,108,101,105,108,102,0,0,0,0,0,0,81,117,105,116,32,82,101,116,114,111,65,114,99,104,0,0,100,100,116,111,100,104,114,49,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,71,111,116,32,115,99,97,108,101,32,97,116,116,114,58,32,37,46,49,102,10,0,0,0,0,0,0,0,0,50,48,75,32,55,48,75,0,109,100,95,100,101,115,114,116,100,101,109,112,57,0,0,0,80,108,97,121,101,114,32,65,100,100,105,110,103,0,0,0,114,119,101,98,105,110,112,117,116,0,0,0,0,0,0,0,118,105,103,105,108,97,110,116,0,0,0,0,0,0,0,0,68,101,115,101,114,116,32,68,101,109,111,108,105,116,105,111,110,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,82,101,116,114,111,65,114,99,104,58,32,67,111,109,112,105,108,101,100,32,97,103,97,105,110,115,116,32,65,80,73,58,32,37,117,10,0,0,0,0,68,105,115,107,32,101,106,101,99,116,32,116,111,103,103,108,101,0,0,0,0,0,0,0,109,100,95,100,101,115,114,116,100,101,109,0,0,0,0,0,83,116,97,114,116,32,98,117,116,116,111,110,0,0,0,0,84,97,122,122,45,77,97,110,105,97,32,40,71,97,108,97,120,105,97,110,32,104,97,114,100,119,97,114,101,41,0,0,68,101,109,111,108,105,116,105,111,110,32,77,97,110,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,0,0,0,37,117,0,0,0,0,0,0,109,100,95,100,101,109,111,109,97,110,112,0,0,0,0,0,80,50,32,66,111,109,98,0,68,101,109,111,108,105,116,105,111,110,32,77,97,110,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,105,110,112,117,116,95,97,117,116,111,100,101,116,101,99,116,95,101,110,97,98,108,101,0,175,48,0,0,164,48,0,0,186,48,0,0,32,0,0,0,186,78,0,0,31,117,0,0,135,82,0,0,52,88,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,81,0,0,0,117,0,0,0,105,0,0,0,122,0,0,0,32,0,0,0,74,0,0,0,105,0,0,0,110,0,0,0,115,0,0,0,101,0,0,0,105,0,0,0,32,0,0,0,71,0,0,0,101,0,0,0,107,0,0,0,105,0,0,0,106,0,0,0,111,0,0,0,104,0,0,0,0,0,0,0,0,0,0,0,50,48,48,48,48,48,32,49,48,48,48,48,48,0,0,0,103,111,108,100,110,97,120,101,0,0,0,0,0,0,0,0,109,100,95,100,101,109,111,109,97,110,0,0,0,0,0,0,84,0,0,0,117,0,0,0,101,0,0,0,115,0,0,0,100,0,0,0,97,0,0,0,121,0,0,0,0,0,0,0,87,111,110,100,101,114,32,66,111,121,32,40,115,101,116,32,49,44,32,51,49,53,45,53,49,55,55,41,0,0,0,0,49,80,32,86,115,32,50,80,32,82,111,117,110,100,115,32,40,74,111,105,110,45,105,110,41,0,0,0,0,0,0,0,68,101,99,97,112,65,116,116,97,99,107,32,40,69,117,114,111,44,32,85,83,65,44,32,75,111,114,41,0,0,0,0,83,111,107,111,110,117,107,101,32,84,97,105,115,101,110,32,71,97,109,101,32,40,74,97,112,97,110,41,0,0,0,0,65,32,50,67,47,49,80,32,66,32,49,67,47,50,80,0,77,97,107,101,32,84,114,97,120,32,40,115,101,116,32,49,41,0,0,0,0,0,0,0,68,114,118,68,105,115,97,98,108,101,66,103,0,0,0,0,51,48,44,48,48,48,0,0,103,97,108,97,120,105,97,110,109,111,0,0,0,0,0,0,109,100,95,100,101,99,97,112,97,116,116,0,0,0,0,0,52,48,48,48,48,44,32,56,48,48,48,48,44,32,49,48,48,48,48,48,0,0,0,0,86,101,114,121,32,100,105,102,102,105,99,117,108,116,0,0,48,48,3,223,0,0,0,0,109,97,114,116,109,97,115,116,99,0,0,0,0,0,0,0,67,104,105,107,117,100,101,110,121,97,32,84,111,117,98,101,105,32,45,32,75,117,98,105,107,105,114,105,32,89,97,107,97,116,97,32,89,111,114,105,32,40,65,108,116,41,0,0,70,105,110,97,108,32,70,105,103,104,116,32,40,57,48,48,49,49,50,32,85,83,65,41,0,0,0,0,0,0,0,0,81,117,105,122,32,77,101,105,116,97,110,116,101,105,32,78,101,111,32,38,32,71,101,111,32,45,32,81,117,105,122,32,68,97,105,115,111,117,115,97,32,83,101,110,32,112,97,114,116,32,50,32,40,78,71,77,45,48,52,50,41,40,78,71,72,45,48,52,50,41,0,0,82,97,122,111,114,115,111,102,116,0,0,0,0,0,0,0,83,111,108,101,105,108,32,40,83,112,97,41,0,0,0,0,72,101,108,112,0,0,0,0,68,117,110,103,101,111,110,115,32,38,32,68,114,97,103,111,110,115,32,45,32,116,111,119,101,114,32,111,102,32,100,111,111,109,32,40,57,52,48,52,49,50,32,72,105,115,112,97,110,105,99,41,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,71,111,116,32,102,114,97,109,101,32,99,111,117,110,116,32,109,111,100,32,97,116,116,114,58,32,37,117,10,0,0,0,0,0,0,0,0,55,48,75,0,0,0,0,0,85,112,114,105,103,104,116,32,40,50,80,41,0,0,0,0,68,101,97,116,104,32,68,117,101,108,32,40,85,83,65,41,0,0,0,0,0,0,0,0,84,97,116,97,107,97,101,32,71,101,110,115,104,105,122,105,110,32,74,111,101,32,38,32,77,97,99,32,40,74,97,112,97,110,32,118,101,114,32,49,41,0,0,0,0,0,0,0,109,100,95,100,101,97,116,104,100,108,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,86,101,114,115,105,111,110,32,111,102,32,108,105,98,114,101,116,114,111,32,65,80,73,58,32,37,117,10,0,109,97,103,100,114,111,112,0,84,104,101,32,68,101,97,116,104,32,97,110,100,32,82,101,116,117,114,110,32,111,102,32,83,117,112,101,114,109,97,110,32,40,85,83,65,41,0,0,116,97,122,109,97,110,105,97,0,0,0,0,0,0,0,0,84,114,105,111,32,84,104,101,32,80,117,110,99,104,32,45,32,78,101,118,101,114,32,70,111,114,103,101,116,32,77,101,46,46,46,32,40,87,111,114,108,100,41,0,0,0,0,0,109,100,95,100,101,97,116,104,114,101,116,0,0,0,0,0,80,111,119,101,114,32,65,116,104,108,101,116,101,32,40,74,112,110,44,32,75,111,114,41,0,0,0,0,0,0,0,0,115,105,100,101,112,99,107,116,98,50,0,0,0,0,0,0,67,104,97,110,45,62,108,111,111,112,115,116,0,0,0,0,119,105,108,121,116,111,119,114,0,0,0,0,0,0,0,0,109,100,95,112,111,119,101,114,97,116,104,0,0,0,0,0,119,106,97,109,109,101,114,115,0,0,0,0,0,0,0,0,80,50,32,83,104,111,116,32,50,0,0,0,0,0,0,0,99,104,105,112,45,62,110,111,105,115,101,95,114,110,103,0,112,52,32,108,101,102,116,0,84,119,111,32,67,114,117,100,101,32,40,85,83,41,0,0,105,110,112,117,116,95,100,101,98,117,103,95,101,110,97,98,108,101,0,0,0,0,0,0,81,117,105,122,32,74,105,110,115,101,105,32,71,101,107,105,106,111,104,32,40,74,97,112,97,110,41,0,0,0,0,0,49,48,48,48,48,48,32,50,48,48,48,48,48,0,0,0,70,108,97,115,104,32,80,111,105,110,116,32,40,74,97,112,97,110,44,32,98,111,111,116,108,101,103,41,0,0,0,0,68,101,97,100,108,121,32,77,111,118,101,115,32,40,85,83,65,41,0,0,0,0,0,0,77,0,0,0,111,0,0,0,110,0,0,0,100,0,0,0,97,0,0,0,121,0,0,0,0,0,0,0,0,0,0,0,119,98,111,121,0,0,0,0,86,101,114,121,32,69,97,115,121,0,0,0,0,0,0,0,107,117,104,103,97,0,0,0,85,83,32,65,65,70,32,77,117,115,116,97,110,103,32,40,98,111,111,116,108,101,103,41,0,0,0,0,0,0,0,0,66,101,115,116,32,111,102,32,55,0,0,0,0,0,0,0,109,100,95,100,101,97,100,108,121,109,118,0,0,0,0,0,115,111,107,111,110,117,107,101,0,0,0,0,0,0,0,0,72,101,114,111,32,67,111,117,110,116,115,32,52,0,0,0,80,49,32,87,101,97,107,32,112,117,110,99,104,0,0,0,65,32,49,67,47,49,80,32,66,32,49,67,47,52,80,0,109,97,107,101,116,114,97,120,0,0,0,0,0,0,0,0,68,114,118,83,99,114,111,108,108,89,0,0,0,0,0,0,50,48,44,48,48,48,0,0,68,97,122,101,32,66,101,102,111,114,101,32,67,104,114,105,115,116,109,97,115,32,40,79,99,101,97,110,105,97,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,52,48,48,48,48,44,32,56,48,48,48,48,44,32,56,48,48,48,48,0,0,0,0,0,64,0,2,223,0,0,0,0,53,48,48,48,48,32,32,50,48,48,48,48,48,0,0,0,77,0,0,0,97,0,0,0,114,0,0,0,116,0,0,0,105,0,0,0,97,0,0,0,108,0,0,0,32,0,0,0,77,0,0,0,97,0,0,0,115,0,0,0,116,0,0,0,101,0,0,0,114,0,0,0,115,0,0,0,0,0,0,0,98,95,0,0,15,97,0,0,243,98,0,0,32,0,0,0,40,0,0,0,86,0,0,0,49,0,0,0,48,0,0,0,52,0,0,0,44,0,0,0,32,0,0,0,49,0,0,0,48,0,0,0,50,0,0,0,44,0,0,0,32,0,0,0,49,0,0,0,48,0,0,0,50,0,0,0,44,0,0,0,32,0,0,0,85,0,0,0,83,0,0,0,65,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,99,101,95,99,104,105,107,117,100,101,110,49,0,0,0,102,102,105,103,104,116,117,97,0,0,0,0,0,0,0,0,113,117,105,122,100,97,105,50,0,0,0,0,0,0,0,0,84,104,117,110,100,101,114,32,90,111,110,101,32,40,74,97,112,97,110,41,0,0,0,0,109,100,95,100,97,122,101,120,109,97,115,112,0,0,0,0,109,100,95,115,111,108,101,105,108,0,0,0,0,0,0,0,83,97,118,101,32,78,101,119,32,67,111,110,102,105,103,0,100,100,116,111,100,104,0,0,116,114,117,101,0,0,0,0,68,97,122,101,32,66,101,102,111,114,101,32,67,104,114,105,115,116,109,97,115,32,40,79,99,101,97,110,105,97,41,0,0,0,0,0,0,0,0,0,109,100,95,100,97,122,101,120,109,97,115,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,70,111,117,110,100,32,108,97,115,116,32,115,116,97,116,101,32,115,108,111,116,58,32,35,37,117,10,0,0,79,118,101,114,108,97,121,32,110,101,120,116,0,0,0,0,119,110,100,114,112,108,110,116,0,0,0,0,0,0,0,0,68,97,118,105,115,32,67,117,112,32,73,73,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,72,85,84,68,79,87,78,46,10,0,0,0,116,97,122,122,109,97,110,103,0,0,0,0,0,0,0,0,109,100,95,100,97,118,105,115,99,112,50,97,0,0,0,0,68,97,118,105,115,32,67,117,112,32,87,111,114,108,100,32,84,111,117,114,32,84,101,110,110,105,115,32,50,32,40,80,114,111,116,111,116,121,112,101,32,49,41,0,0,0,0,0,109,101,105,107,121,117,104,97,0,0,0,0,0,0,0,0,80,50,32,83,104,111,116,32,49,0,0,0,0,0,0,0,109,100,95,100,97,118,105,115,99,112,50,0,0,0,0,0,105,110,112,117,116,95,100,117,116,121,95,99,121,99,108,101,0,0,0,0,0,0,0,0,113,106,105,110,115,101,105,0,83,111,116,115,117,103,121,111,32,83,104,111,117,115,104,111,0,0,0,0,0,0,0,0,50,48,48,48,48,48,32,51,48,48,48,48,48,0,0,0,102,112,111,105,110,116,98,106,0,0,0,0,0,0,0,0,68,97,118,105,115,32,67,117,112,32,87,111,114,108,100,32,84,111,117,114,32,40,69,117,114,111,44,32,85,83,65,44,32,49,57,57,51,48,54,41,0,0,0,0,0,0,0,0,83,0,0,0,117,0,0,0,110,0,0,0,100,0,0,0,97,0,0,0,121,0,0,0,0,0,0,0,0,0,0,0,85,112,39,110,32,68,111,119,110,32,40,110,111,116,32,101,110,99,114,121,112,116,101,100,41,0,0,0,0,0,0,0,80,111,116,101,110,116,105,111,109,101,116,101,114,0,0,0,83,108,111,119,101,115,116,0,109,117,115,116,97,110,103,98,0,0,0,0,0,0,0,0,66,101,115,116,32,111,102,32,53,0,0,0,0,0,0,0,100,101,99,111,112,114,111,116,95,108,97,115,116,95,119,114,105,116,101,0,0,0,0,0,109,100,95,100,97,118,105,115,99,117,112,97,0,0,0,0,83,97,109,109,121,32,73,110,100,117,115,116,114,105,101,115,32,74,97,112,97,110,0,0,72,101,114,111,32,67,111,117,110,116,115,32,51,0,0,0,65,32,49,67,47,50,80,32,66,32,49,67,47,50,80,0,91,75,117,114,97,108,93,32,40,83,105,100,97,109,32,98,111,111,116,108,101,103,41,0,68,114,118,83,99,114,111,108,108,88,0,0,0,0,0,0,85,112,114,105,103,104,116,32,84,119,111,32,80,108,97,121,101,114,115,0,0,0,0,0,68,97,118,105,115,32,67,117,112,32,87,111,114,108,100,32,84,111,117,114,32,40,69,117,114,111,44,32,85,83,65,44,32,49,57,57,51,48,55,41,0,0,0,0,0,0,0,0,75,121,117,103,111,70,108,105,112,83,99,114,101,101,110,0,51,48,48,48,48,44,32,56,48,48,48,48,44,32,56,48,48,48,48,0,0,0,0,0,49,48,48,48,48,48,32,51,48,48,48,48,48,32,56,48,48,48,48,48,0,0,0,0,77,97,114,116,105,97,108,32,77,97,115,116,101,114,115,32,40,86,49,48,52,44,32,49,48,50,44,32,49,48,50,44,32,85,83,65,41,0,0,0,67,104,105,107,117,100,101,110,121,97,32,84,111,117,98,101,105,32,45,32,75,117,98,105,107,105,114,105,32,89,97,107,97,116,97,32,89,111,114,105,0,0,0,0,0,0,0,0,70,105,110,97,108,32,70,105,103,104,116,32,40,85,83,65,44,32,115,101,116,32,50,41,0,0,0,0,0,0,0,0,66,97,115,101,98,97,108,108,32,83,116,97,114,115,32,50,0,0,0,0,0,0,0,0,67,104,105,112,45,62,87,104,105,116,101,110,111,105,115,101,84,97,112,115,0,0,0,0,109,100,95,100,97,118,105,115,99,117,112,0,0,0,0,0,84,104,101,32,71,114,101,97,116,32,82,97,103,116,105,109,101,32,83,104,111,119,32,40,74,97,112,97,110,32,118,49,46,51,44,32,57,50,46,49,49,46,50,54,41,0,0,0,109,100,95,115,111,108,101,105,108,115,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,67,111,110,102,105,103,0,0,0,0,0,0,0,0,68,117,110,103,101,111,110,115,32,38,32,68,114,97,103,111,110,115,32,45,32,116,111,119,101,114,32,111,102,32,100,111,111,109,32,40,57,52,48,49,49,51,32,65,115,105,97,41,0,0,0,0,0,0,0,0,102,108,111,97,116,95,102,114,97,109,101,98,117,102,102,101,114,0,0,0,0,0,0,0,51,48,75,32,50,48,48,75,0,0,0,0,0,0,0,0,91,70,66,65,93,32,67,97,110,110,111,116,32,102,105,110,100,32,100,114,105,118,101,114,46,10,0,0,0,0,0,0,68,97,118,105,100,32,82,111,98,105,110,115,111,110,32,66,97,115,107,101,116,98,97,108,108,32,40,74,112,110,41,0,0,0,0,0,0,0,0,0,82,46,83,84,65,67,75,91,49,93,0,0,0,0,0,0,37,48,56,120,58,32,85,110,100,101,102,105,110,101,100,32,84,104,117,109,98,32,105,110,115,116,114,117,99,116,105,111,110,58,32,37,48,52,120,32,40,65,82,77,57,32,114,101,115,101,114,118,101,100,41,10,0,0,0,0,0,0,0,0,109,100,95,100,114,115,99,106,0,0,0,0,0,0,0,0,65,117,116,111,45,108,111,97,100,105,110,103,32,115,97,118,101,115,116,97,116,101,32,102,114,111,109,32,34,37,115,34,32,37,115,46,0,0,0,0,82,111,104,103,97,32,65,114,109,111,114,32,70,111,114,99,101,32,40,72,111,110,103,32,75,111,110,103,32,118,51,46,48,41,0,0,0,0,0,0,82,45,62,101,120,116,114,97,95,99,121,99,108,101,115,0,100,111,99,107,109,97,110,0,78,111,114,109,97,108,32,115,99,114,101,101,110,0,0,0,65,114,109,101,100,32,80,111,108,105,99,101,32,66,97,116,114,105,100,101,114,32,45,32,66,32,86,101,114,115,105,111,110,32,40,74,97,112,97,110,41,32,40,70,114,105,32,70,101,98,32,49,51,32,49,57,57,56,41,0,0,0,0,0,70,105,120,69,105,103,104,116,32,40,72,111,110,103,32,75,111,110,103,44,32,84,97,105,116,111,32,108,105,99,101,110,115,101,41,0,0,0,0,0,68,97,118,105,100,32,82,111,98,105,110,115,111,110,39,115,32,83,117,112,114,101,109,101,32,67,111,117,114,116,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,84,105,103,101,114,32,72,101,108,105,32,40,98,111,111,116,108,101,103,44,32,115,101,116,32,50,41,0,0,0,0,0,70,108,105,112,32,83,99,114,101,101,110,0,0,0,0,0,82,97,105,116,32,69,108,101,99,116,114,111,110,105,99,115,32,76,116,100,0,0,0,0,66,97,116,115,117,103,117,110,32,40,115,101,116,32,50,41,0,0,0,0,0,0,0,0,68,105,115,99,111,117,110,116,0,0,0,0,0,0,0,0,109,100,95,100,114,115,99,0,100,111,103,121,117,117,110,116,0,0,0,0,0,0,0,0,68,105,101,116,32,71,111,32,71,111,32,40,74,97,112,97,110,32,118,49,46,49,32,49,57,57,50,46,48,57,46,50,54,41,0,0,0,0,0,0,66,97,116,116,108,101,32,71,97,114,101,103,103,97,32,45,32,78,101,119,32,86,101,114,115,105,111,110,32,40,72,111,110,103,32,75,111,110,103,32,47,32,65,117,115,116,114,105,97,63,41,32,40,83,97,116,32,77,97,114,32,50,32,49,57,57,54,41,0,0,0,0,70,105,114,101,32,83,104,97,114,107,32,40,75,111,114,101,97,44,32,115,101,116,32,50,44,32,104,97,114,100,101,114,41,0,0,0,0,0,0,0,49,48,48,32,75,0,0,0,86,105,109,97,110,97,32,40,74,97,112,97,110,41,0,0,68,97,118,105,100,32,67,114,97,110,101,39,115,32,65,109,97,122,105,110,103,32,84,101,110,110,105,115,32,40,85,83,65,41,0,0,0,0,0,0,79,117,116,32,90,111,110,101,32,40,115,101,116,32,52,41,0,0,0,0,0,0,0,0,99,108,111,99,107,95,108,105,110,101,0,0,0,0,0,0,72,101,108,108,102,105,114,101,32,40,49,80,32,86,101,114,46,44,32,97,108,116,41,0,0,0,0,0,0,0,0,0,100,101,109,111,110,119,108,100,51,0,0,0,0,0,0,0,83,99,114,101,101,110,0,0,119,104,50,106,0,0,0,0,80,50,32,65,110,115,119,101,114,32,52,0,0,0,0,0,109,100,95,97,109,97,122,110,116,101,110,0,0,0,0,0,112,52,32,100,111,119,110,0,105,110,112,117,116,95,116,117,114,98,111,95,112,101,114,105,111,100,0,0,0,0,0,0,175,48,0,0,236,48,0,0,232,48,0,0,243,48,0,0,87,48,0,0,147,48,0,0,97,48,0,0,131,48,0,0,147,48,0,0,32,0,0,0,170,48,0,0,233,48,0,0,104,48,0,0,74,144,0,0,124,48,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,67,0,0,0,114,0,0,0,97,0,0,0,121,0,0,0,111,0,0,0,110,0,0,0,32,0,0,0,83,0,0,0,104,0,0,0,105,0,0,0,110,0,0,0,99,0,0,0,104,0,0,0,97,0,0,0,110,0,0,0,32,0,0,0,79,0,0,0,114,0,0,0,97,0,0,0,116,0,0,0,111,0,0,0,32,0,0,0,65,0,0,0,115,0,0,0,111,0,0,0,98,0,0,0,111,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,67,97,109,101,108,116,114,121,32,40,74,97,112,97,110,44,32,89,77,50,54,49,48,41,0,0,0,0,0,0,0,0,50,48,48,48,48,48,32,50,48,48,48,48,48,0,0,0,84,104,101,32,76,101,103,101,110,100,32,111,102,32,75,97,103,101,32,40,98,111,111,116,108,101,103,32,115,101,116,32,49,41,0,0,0,0,0,0,70,108,97,115,104,32,80,111,105,110,116,32,40,87,111,114,108,100,44,32,98,111,111,116,108,101,103,41,0,0,0,0,68,97,115,104,105,110,39,32,68,101,115,112,101,114,97,100,111,101,115,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,83,117,112,101,114,32,67,104,97,115,101,32,45,32,67,114,105,109,105,110,97,108,32,84,101,114,109,105,110,97,116,105,111,110,32,40,74,97,112,97,110,41,0,0,0,0,0,0,117,112,110,100,111,119,110,117,0,0,0,0,0,0,0,0,80,50,32,85,112,47,68,111,119,110,0,0,0,0,0,0,111,116,104,117,110,100,101,114,106,0,0,0,0,0,0,0,77,105,99,114,111,115,119,105,116,99,104,0,0,0,0,0,84,105,109,101,114,32,83,112,101,101,100,32,40,66,111,110,117,115,32,76,101,118,101,108,115,41,0,0,0,0,0,0,91,84,97,105,116,111,93,32,87,111,114,108,100,32,71,97,109,101,115,0,0,0,0,0,85,80,76,32,40,83,101,111,117,108,32,84,114,97,100,105,110,103,32,108,105,99,101,110,115,101,41,0,0,0,0,0,97,114,107,97,116,111,117,114,0,0,0,0,0,0,0,0,71,97,116,101,32,111,102,32,68,111,111,109,32,40,85,83,32,114,101,118,105,115,105,111,110,32,52,41,0,0,0,0,109,100,95,100,97,115,104,100,101,115,112,50,0,0,0,0,69,120,116,114,101,109,101,32,68,111,119,110,104,105,108,108,32,40,118,49,46,53,41,0,0,0,0,0,0,0,0,0,72,101,114,111,32,67,111,117,110,116,115,32,50,0,0,0,77,97,115,116,101,114,32,111,102,32,87,101,97,112,111,110,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,65,32,49,67,47,51,80,32,66,32,49,67,47,51,80,0,67,114,117,115,104,32,82,111,108,108,101,114,32,40,83,105,100,97,109,32,98,111,111,116,108,101,103,41,0,0,0,0,98,115,104,97,114,107,0,0,85,112,114,105,103,104,116,32,79,110,101,32,80,108,97,121,101,114,0,0,0,0,0,0,67,67,104,105,112,67,111,105,110,115,0,0,0,0,0,0,49,32,67,111,105,110,115,32,52,32,67,114,101,100,105,116,0,0,0,0,0,0,0,0,68,97,115,104,105,110,39,32,68,101,115,112,101,114,97,100,111,101,115,32,40,69,117,114,111,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,75,121,117,103,111,66,103,83,99,114,111,108,108,89,0,0,50,48,48,48,48,44,32,54,48,48,48,48,44,32,56,48,48,48,48,0,0,0,0,0,118,100,99,95,118,98,108,97,110,107,95,116,114,105,103,103,101,114,101,100,91,105,93,0,115,115,95,112,97,108,95,98,97,115,101,0,0,0,0,0,100,97,114,105,117,115,101,0,53,48,48,48,48,32,32,50,48,48,48,48,48,32,53,48,48,48,48,48,0,0,0,0,109,97,114,116,109,97,115,116,0,0,0,0,0,0,0,0,112,99,101,95,99,104,105,107,117,100,101,110,0,0,0,0,102,102,105,103,104,116,117,49,0,0,0,0,0,0,0,0,98,117,98,108,98,111,98,108,114,49,0,0,0,0,0,0,109,100,95,100,97,115,104,100,101,115,112,49,0,0,0,0,107,121,117,115,116,114,107,114,0,0,0,0,0,0,0,0,109,99,117,95,99,111,109,109,97,110,100,0,0,0,0,0,84,67,48,49,48,48,83,67,78,68,98,108,87,105,100,116,104,0,0,0,0,0,0,0,73,110,102,111,103,114,97,109,101,115,0,0,0,0,0,0,82,101,115,116,97,114,116,32,82,101,116,114,111,65,114,99,104,0,0,0,0,0,0,0,79,110,110,97,32,83,97,110,115,105,114,111,117,32,45,32,84,121,112,104,111,111,110,32,71,97,108,32,40,115,101,116,32,50,41,0,0,0,0,0,100,100,116,111,100,97,114,49,0,0,0,0,0,0,0,0,102,114,97,109,101,95,99,111,117,110,116,95,109,111,100,0,50,48,75,32,49,53,48,75,0,0,0,0,0,0,0,0,79,117,116,32,82,117,110,32,40,115,105,116,100,111,119,110,47,117,112,114,105,103,104,116,44,32,82,101,118,32,65,41,0,0,0,0,0,0,0,0,69,110,101,114,103,121,32,68,101,99,114,101,97,115,101,0,68,97,115,104,105,110,39,32,68,101,115,112,101,114,97,100,111,101,115,32,40,85,83,65,41,0,0,0,0,0,0,0,97,108,105,101,110,115,121,110,55,0,0,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,73,73,73,58,32,78,101,119,32,71,101,110,101,114,97,116,105,111,110,32,40,65,115,105,97,32,57,55,48,50,48,52,44,32,78,79,32,67,68,41,0,0,0,0,0,0,0,0,0,83,121,115,116,101,109,49,54,83,99,114,111,108,108,89,0,109,100,95,100,97,115,104,100,101,115,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,70,111,117,110,100,32,97,117,116,111,32,115,97,118,101,115,116,97,116,101,32,105,110,58,32,37,115,10,0,86,111,108,117,109,101,32,45,0,0,0,0,0,0,0,0,65,108,105,101,110,32,83,116,111,114,109,32,40,115,101,116,32,50,44,32,85,83,44,32,51,32,80,108,97,121,101,114,115,44,32,70,68,49,48,57,52,32,51,49,55,45,48,49,52,55,41,0,0,0,0,0,68,97,114,119,105,110,32,52,48,56,49,32,40,74,112,110,44,32,75,111,114,41,0,0,97,98,117,114,110,101,114,0,52,32,67,111,105,110,115,32,49,32,67,114,101,100,105,116,115,32,0,0,0,0,0,0,86,100,112,72,83,99,114,111,108,108,66,97,115,101,0,0,65,122,117,114,105,97,110,32,65,116,116,97,99,107,0,0,97,108,101,120,107,105,100,100,49,0,0,0,0,0,0,0,109,100,95,100,97,114,119,105,110,0,0,0,0,0,0,0,69,0,0,0,83,0,0,0,80,0,0,0,32,0,0,0,82,0,0,0,97,0,0,0,46,0,0,0,68,0,0,0,101,0,0,0,46,0,0,0,32,0,0,0,168,48,0,0,185,48,0,0,215,48,0,0,236,48,0,0,164,48,0,0,201,48,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,44,0,0,0,32,0,0,0,118,0,0,0,101,0,0,0,114,0,0,0,46,0,0,0,32,0,0,0,57,0,0,0,56,0,0,0,47,0,0,0,48,0,0,0,52,0,0,0,47,0,0,0,49,0,0,0,52,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,110,68,114,118,79,107,105,66,97,110,107,0,0,0,0,0,98,108,111,111,100,119,97,114,0,0,0,0,0,0,0,0,83,116,111,114,121,32,108,105,110,101,32,38,32,103,97,109,101,32,105,110,115,116,114,117,99,116,105,111,110,115,32,105,110,32,69,110,103,108,105,115,104,0,0,0,0,0,0,0,57,48,32,75,0,0,0,0,77,105,115,115,32,80,117,122,122,108,101,0,0,0,0,0,68,97,114,107,32,67,97,115,116,108,101,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,0,0,0,98,115,115,111,99,99,101,114,0,0,0,0,0,0,0,0,83,101,97,114,99,104,32,69,121,101,0,0,0,0,0,0,80,50,32,65,110,115,119,101,114,32,51,0,0,0,0,0,61,61,61,32,67,111,110,102,105,103,32,101,110,100,32,61,61,61,10,0,0,0,0,0,109,100,95,100,97,114,107,99,97,115,116,0,0,0,0,0,90,101,114,111,32,80,111,105,110,116,32,40,115,101,116,32,50,41,0,0,0,0,0,0,67,114,97,121,111,110,32,83,104,105,110,99,104,97,110,32,79,114,97,116,111,32,65,115,111,98,111,32,40,74,97,112,97,110,41,0,0,0,0,0,103,97,109,101,95,104,105,115,116,111,114,121,95,115,105,122,101,0,0,0,0,0,0,0,65,66,77,0,0,0,0,0,102,112,111,105,110,116,98,108,0,0,0,0,0,0,0,0,68,97,110,103,101,114,111,117,115,32,83,101,101,100,32,40,74,112,110,41,0,0,0,0,68,101,99,0,0,0,0,0,100,114,103,110,109,115,116,95,111,107,105,48,95,98,97,110,107,0,0,0,0,0,0,0,85,112,39,110,32,68,111,119,110,32,40,51,49,53,45,53,48,51,48,41,0,0,0,0,80,101,100,97,108,32,70,117,110,99,116,105,111,110,0,0,77,97,110,121,32,66,108,111,99,107,0,0,0,0,0,0,85,83,32,65,65,70,32,77,117,115,116,97,110,103,32,40,50,53,116,104,32,77,97,121,46,32,49,57,57,48,32,47,32,83,101,111,117,108,32,84,114,97,100,105,110,103,41,0,0,0,0,0,0,0,0,0,80,49,32,85,112,32,47,32,68,111,119,110,0,0,0,0,114,97,105,100,101,110,117,0,57,151,0,0,243,150,0,0,241,130,0,0,196,150,0,0,32,0,0,0,84,0,0,0,104,0,0,0,117,0,0,0,110,0,0,0,100,0,0,0,101,0,0,0,114,0,0,0,32,0,0,0,72,0,0,0,101,0,0,0,114,0,0,0,111,0,0,0,101,0,0,0,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,76,101,118,101,108,32,85,112,32,83,112,101,101,100,0,0,229,130,0,0,73,131,0,0,105,114,0,0,158,138,0,0,32,0,0,0,187,158,0,0,192,150,0,0,219,86,0,0,201,89,0,0,185,89,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,87,0,0,0,97,0,0,0,107,0,0,0,97,0,0,0,107,0,0,0,117,0,0,0,115,0,0,0,97,0,0,0,109,0,0,0,111,0,0,0,110,0,0,0,111,0,0,0,103,0,0,0,97,0,0,0,116,0,0,0,97,0,0,0,114,0,0,0,105,0,0,0,32,0,0,0,77,0,0,0,97,0,0,0,104,0,0,0,106,0,0,0,111,0,0,0,110,0,0,0,103,0,0,0,32,0,0,0,89,0,0,0,111,0,0,0,110,0,0,0,115,0,0,0,104,0,0,0,105,0,0,0,109,0,0,0,97,0,0,0,105,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,109,100,95,100,97,110,103,115,101,101,100,0,0,0,0,0,101,120,116,100,119,110,104,108,0,0,0,0,0,0,0,0,53,48,48,75,44,32,53,48,48,75,32,69,118,101,114,121,0,0,0,0,0,0,0,0,116,105,108,101,98,97,110,107,0,0,0,0,0,0,0,0,72,101,114,111,32,67,111,117,110,116,115,32,49,0,0,0,65,32,49,67,47,52,80,32,66,32,49,67,47,52,80,0,115,104,111,99,107,105,110,103,0,0,0,0,0,0,0,0,99,114,117,115,104,115,0,0,37,120,0,0,0,0,0,0,83,112,114,105,116,101,32,84,101,115,116,0,0,0,0,0,52,48,48,48,48,32,49,48,48,48,48,48,0,0,0,0,49,32,67,111,105,110,115,32,51,32,67,114,101,100,105,116,0,0,0,0,0,0,0,0,114,121,117,107,101,110,100,110,0,0,0,0,0,0,0,0,72,101,114,99,117,108,101,115,0,0,0,0,0,0,0,0,53,32,67,111,105,110,115,47,50,32,67,114,101,100,105,116,115,0,0,0,0,0,0,0,75,121,117,103,111,66,103,83,99,114,111,108,108,88,76,111,0,0,0,0,0,0,0,0,50,53,48,0,0,0,0,0,80,117,122,122,108,105,32,50,32,83,117,112,101,114,32,40,86,50,48,48,41,0,0,0,70,97,110,116,97,115,105,97,32,40,57,52,48,51,48,55,32,80,67,66,41,0,0,0,98,98,97,108,108,115,0,0,67,104,105,98,105,32,77,97,114,117,107,111,32,67,104,97,110,32,45,32,81,117,105,122,32,100,101,32,80,105,105,104,121,97,114,97,0,0,0,0,70,105,110,97,108,32,70,105,103,104,116,32,40,85,83,65,44,32,115,101,116,32,49,41,0,0,0,0,0,0,0,0,83,0,0,0,101,0,0,0,110,0,0,0,103,0,0,0,111,0,0,0,107,0,0,0,117,0,0,0,32,0,0,0,50,0,0,0,0,0,0,0,38,98,0,0,253,86,0,0,29,79,0,0,127,98,0,0,18,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,71,97,110,98,97,114,101,32,71,105,110,107,117,110,0,0,109,100,95,104,101,114,99,117,108,101,115,0,0,0,0,0,84,111,117,107,105,100,101,110,115,104,111,117,32,45,32,65,110,103,101,108,32,69,121,101,115,32,40,86,69,82,46,32,57,54,48,52,50,55,41,0,0,0,0,0,0,0,0,0,69,73,77,0,0,0,0,0,84,104,101,32,83,109,117,114,102,115,32,40,69,117,114,111,44,32,82,101,118,46,32,65,41,0,0,0,0,0,0,0,80,114,101,116,116,121,32,83,111,108,100,105,101,114,32,83,97,105,108,111,114,32,77,111,111,110,32,40,118,101,114,46,32,57,53,47,48,51,47,50,50,66,44,32,74,97,112,97,110,41,0,0,0,0,0,0,82,101,115,116,97,114,116,32,71,97,109,101,0,0,0,0,68,117,110,103,101,111,110,115,32,38,32,68,114,97,103,111,110,115,32,45,32,116,111,119,101,114,32,111,102,32,100,111,111,109,32,40,57,52,48,52,49,50,32,65,115,105,97,41,0,0,0,0,0,0,0,0,111,117,116,115,99,97,108,101,95,121,0,0,0,0,0,0,78,111,115,116,114,97,100,97,109,117,115,0,0,0,0,0,112,111,119,101,114,105,110,115,98,0,0,0,0,0,0,0,76,101,118,101,108,32,83,101,108,101,99,116,105,111,110,32,77,111,100,101,0,0,0,0,65,108,105,101,110,32,67,104,97,108,108,101,110,103,101,32,40,67,104,105,110,97,41,0,0,0,0,0,0,0,0,0,68,97,104,110,97,32,40,75,111,114,41,0,0,0,0,0,107,97,114,97,116,98,108,122,117,0,0,0,0,0,0,0,53,32,67,111,105,110,115,32,52,32,67,114,101,100,105,116,115,0,0,0,0,0,0,0,98,108,97,99,107,112,101,110,0,0,0,0,0,0,0,0,104,111,116,109,105,110,100,0,68,111,117,98,108,101,32,68,114,97,103,111,110,32,51,32,45,32,84,104,101,32,82,111,115,101,116,116,97,32,83,116,111,110,101,32,40,98,111,111,116,108,101,103,41,0,0,0,109,100,95,100,97,104,110,97,109,107,0,0,0,0,0,0,104,111,111,107,0,0,0,0,68,111,110,80,97,99,104,105,32,40,75,111,114,101,97,44,32,118,101,114,46,32,49,46,49,50,44,32,57,53,47,48,53,47,50,120,41,0,0,0,70,45,49,32,71,114,97,110,100,32,80,114,105,120,32,80,97,114,116,32,73,73,0,0,54,32,67,111,105,110,45,51,32,80,108,97,121,0,0,0,97,122,117,114,105,97,110,0,99,111,111,107,98,105,98,51,0,0,0,0,0,0,0,0,74,117,109,112,32,75,105,100,115,0,0,0,0,0,0,0,68,97,104,110,97,32,77,101,103,97,109,105,32,84,97,110,106,111,117,32,40,74,112,110,41,0,0,0,0,0,0,0,68,111,68,111,110,80,97,99,104,105,32,40,65,114,114,97,110,103,101,32,77,111,100,101,32,118,101,114,115,105,111,110,32,49,46,49,44,32,104,97,99,107,32,98,121,32,84,114,97,112,49,53,41,0,0,0,98,101,115,116,114,105,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,105,110,105,116,105,97,108,105,122,101,32,97,117,100,105,111,32,100,114,105,118,101,114,46,32,87,105,108,108,32,99,111,110,116,105,110,117,101,32,119,105,116,104,111,117,116,32,97,117,100,105,111,46,10,0,0,0,71,117,110,98,105,114,100,32,40,87,111,114,108,100,41,0,0,0,0,0,0,0,0,0,84,97,105,115,101,110,32,72,111,116,32,71,105,109,109,105,99,107,32,51,32,68,105,103,105,116,97,108,32,83,117,114,102,105,110,103,32,40,74,97,112,97,110,41,0,0,0,0,83,107,121,32,76,97,110,99,101,114,0,0,0,0,0,0,80,97,115,115,105,110,103,32,80,111,105,110,116,115,0,0,55,48,32,75,0,0,0,0,109,100,95,100,97,104,110,97,109,0,0,0,0,0,0,0,112,111,114,107,121,0,0,0,114,111,117,116,101,120,0,0,67,114,97,122,121,32,67,108,105,109,98,101,114,32,50,32,40,74,97,112,97,110,44,32,72,97,114,100,101,114,41,0,0,0,0,0,0,0,0,0,115,97,109,115,104,111,50,0,80,50,32,65,110,115,119,101,114,32,50,0,0,0,0,0,68,97,102,102,121,32,68,117,99,107,32,105,110,32,72,111,108,108,121,119,111,111,100,32,40,69,117,114,111,44,32,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,0,112,52,32,117,112,0,0,0,113,99,114,97,121,111,110,50,0,0,0,0,0,0,0,0,91,84,101,99,104,110,111,115,93,32,85,110,105,118,101,114,115,97,108,32,85,83,65,0,103,97,109,101,95,104,105,115,116,111,114,121,95,112,97,116,104,0,0,0,0,0,0,0,87,87,70,32,83,117,112,101,114,115,116,97,114,115,32,40,74,97,112,97,110,41,0,0,91,83,117,110,32,69,108,101,99,116,114,111,110,105,99,115,93,32,40,65,116,97,114,105,32,108,105,99,101,110,115,101,41,0,0,0,0,0,0,0,83,78,75,32,40,86,105,99,116,111,114,32,108,105,99,101,110,115,101,41,0,0,0,0,85,112,32,67,111,99,107,112,105,116,0,0,0,0,0,0,70,108,97,115,104,32,80,111,105,110,116,32,40,115,101,116,32,49,44,32,74,97,112,97,110,44,32,70,68,49,48,57,52,32,51,49,55,45,48,49,50,55,65,41,0,0,0,0,109,100,95,100,97,102,102,121])
.concat([112,0,0,0,0,0,0,0,78,111,118,0,0,0,0,0,117,112,110,100,111,119,110,0,80,50,32,76,101,102,116,47,82,105,103,104,116,0,0,0,87,104,101,101,108,32,40,50,55,48,65,41,0,0,0,0,109,117,115,116,97,110,103,115,0,0,0,0,0,0,0,0,49,80,32,86,115,32,50,80,32,82,111,117,110,100,115,32,40,83,116,97,114,116,41,0,98,108,107,116,105,103,101,114,98,50,0,0,0,0,0,0,68,97,102,102,121,32,68,117,99,107,32,105,110,32,72,111,108,108,121,119,111,111,100,32,40,69,117,114,111,41,0,0,71,97,117,110,116,108,101,116,32,40,71,101,114,109,97,110,44,32,114,101,118,32,49,48,41,0,0,0,0,0,0,0,74,46,32,74,46,32,83,113,117,97,119,107,101,114,115,32,40,98,111,111,116,108,101,103,41,0,0,0,0,0,0,0,51,48,48,75,44,32,53,48,48,75,32,69,118,101,114,121,0,0,0,0,0,0,0,0,99,114,101,100,105,116,115,0,84,111,112,32,83,101,99,114,101,116,32,40,74,97,112,97,110,41,0,0,0,0,0,0,80,97,99,45,76,97,110,100,32,40,74,97,112,97,110,32,111,108,100,101,114,41,0,0,80,97,105,110,116,32,82,111,108,108,101,114,0,0,0,0,109,114,108,111,0,0,0,0,80,111,114,116,117,103,101,115,101,0,0,0,0,0,0,0,115,110,97,112,106,97,99,107,0,0,0,0,0,0,0,0,49,32,67,111,105,110,115,32,50,32,67,114,101,100,105,116,0,0,0,0,0,0,0,0,83,111,108,111,109,111,110,70,108,105,112,83,99,114,101,101,110,0,0,0,0,0,0,0,109,100,95,100,97,102,102,121,0,0,0,0,0,0,0,0,75,121,117,103,111,66,103,83,99,114,111,108,108,88,72,105,0,0,0,0,0,0,0,0,68,111,110,107,101,121,32,75,111,110,103,32,40,85,83,32,115,101,116,32,49,41,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,111,112,101,110,32,100,105,114,101,99,116,111,114,121,58,32,34,37,115,34,10,0,0,0,0,103,117,110,115,109,111,107,101,117,97,0,0,0,0,0,0,84,101,114,114,97,32,67,114,101,115,116,97,32,40,89,77,50,50,48,51,41,0,0,0,112,99,101,95,99,104,105,98,105,109,0,0,0,0,0,0,102,102,105,103,104,116,117,0,106,117,106,117,0,0,0,0,83,101,110,103,111,107,117,32,50,32,47,32,83,101,110,103,111,107,117,32,68,101,110,115,104,111,117,32,50,0,0,0,100,105,114,116,121,0,0,0,65,108,108,32,67,80,85,32,35,49,32,82,97,109,0,0,67,121,98,111,114,103,32,74,117,115,116,105,99,101,32,40,80,114,111,116,111,116,121,112,101,41,0,0,0,0,0,0,49,57,52,50,32,40,70,105,114,115,116,32,86,101,114,115,105,111,110,41,0,0,0,0,86,105,100,101,111,32,82,97,109,32,35,48,0,0,0,0,109,100,95,115,109,117,114,102,115,0,0,0,0,0,0,0,82,101,115,117,109,101,32,71,97,109,101,0,0,0,0,0,77,101,116,114,111,45,67,114,111,115,115,32,40,115,101,116,32,50,41,0,0,0,0,0,100,100,116,111,100,97,0,0,111,117,116,115,99,97,108,101,95,120,0,0,0,0,0,0,50,50,0,0,0,0,0,0,107,101,121,32,103,0,0,0,108,119,105,110,103,115,50,0,97,121,56,57,49,48,95,115,101,108,101,99,116,0,0,0,109,100,95,99,121,98,111,114,103,106,112,0,0,0,0,0,84,114,101,97,115,117,114,101,32,72,117,110,116,32,40,98,111,111,116,108,101,103,63,41,0,0,0,0,0,0,0,0,115,101,97,114,99,104,97,114,117,0,0,0,0,0,0,0,99,111,109,109,97,110,100,111,98,0,0,0,0,0,0,0,49,57,52,51,106,97,0,0,67,121,98,111,114,103,32,74,117,115,116,105,99,101,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,116,97,114,116,105,110,103,32,109,111,118,105,101,32,112,108,97,121,98,97,99,107,46,10,0,0,0,0,68,121,110,97,109,105,116,101,32,68,117,107,101,32,40,85,83,41,0,0,0,0,0,0,86,111,108,117,109,101,32,43,0,0,0,0,0,0,0,0,83,97,116,117,114,110,0,0,115,107,121,119,111,108,102,50,0,0,0,0,0,0,0,0,107,101,121,32,102,0,0,0,76,97,115,116,32,68,117,101,108,32,40,98,111,111,116,108,101,103,41,0,0,0,0,0,109,100,95,99,121,98,111,114,103,106,0,0,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,32,40,74,97,112,97,110,41,0,0,114,117,115,104,99,114,115,104,0,0,0,0,0,0,0,0,83,107,121,32,75,105,100,32,40,83,105,112,101,109,41,0,0,0,0,0,0,0,0,0,87,99,57,48,98,49,77,83,77,53,50,48,53,78,101,120,116,0,0,0,0,0,0,0,68,101,115,105,103,110,32,76,97,98,115,32,47,32,84,104,111,109,97,115,32,65,117,116,111,109,97,116,105,99,115,0,103,110,103,98,108,97,0,0,109,114,102,108,101,97,95,103,102,120,95,98,97,110,107,0,67,121,98,101,114,66,97,108,108,32,40,87,111,114,108,100,41,0,0,0,0,0,0,0,37,115,46,67,72,37,100,0,103,97,108,97,103,97,109,107,0,0,0,0,0,0,0,0,87,111,114,108,100,32,67,117,112,32,39,57,48,32,40,116,114,97,99,107,98,97,108,108,41,0,0,0,0,0,0,0,68,114,118,83,111,117,110,100,84,114,105,103,103,101,114,0,114,97,108,108,121,120,109,114,0,0,0,0,0,0,0,0,83,117,112,101,114,32,86,111,108,108,101,121,98,97,108,108,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,65,116,116,101,109,112,116,105,110,103,32,116,111,32,114,101,99,111,118,101,114,32,46,46,46,10,0,0,107,101,121,32,100,0,0,0,97,109,98,117,115,104,118,0,53,48,32,75,0,0,0,0,65,114,103,117,115,32,110,111,32,83,101,110,115,104,105,32,40,74,97,112,97,110,41,0,0,0,0,0,0,0,0,0,109,100,95,99,121,98,101,114,98,97,108,0,0,0,0,0,100,100,114,97,103,111,110,117,0,0,0,0,0,0,0,0,77,67,54,56,52,48,95,105,100,120,48,0,0,0,0,0,80,103,109,73,110,112,117,116,0,0,0,0,0,0,0,0,109,95,111,108,100,115,95,99,109,100,0,0,0,0,0,0,80,50,32,65,110,115,119,101,114,32,49,0,0,0,0,0,67,117,116,84,104,114,111,97,116,32,73,115,108,97,110,100,32,40,80,114,111,116,111,116,121,101,41,0,0,0,0,0,79,114,105,101,110,116,97,108,32,76,101,103,101,110,100,32,45,32,88,105,32,89,111,32,71,105,32,83,104,105,32,82,101,32,90,117,97,110,103,32,40,86,49,49,50,41,0,0,175,48,0,0,164,48,0,0,186,48,0,0,32,0,0,0,175,48,0,0,236,48,0,0,232,48,0,0,243,48,0,0,87,48,0,0,147,48,0,0,97,48,0,0,131,48,0,0,147,48,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,81,0,0,0,117,0,0,0,105,0,0,0,122,0,0,0,32,0,0,0,67,0,0,0,114,0,0,0,97,0,0,0,121,0,0,0,111,0,0,0,110,0,0,0,32,0,0,0,83,0,0,0,104,0,0,0,105,0,0,0,110,0,0,0,99,0,0,0,104,0,0,0,97,0,0,0,110,0,0,0,0,0,0,0,0,0,0,0,115,116,100,105,110,95,99,109,100,95,101,110,97,98,108,101,0,0,0,0,0,0,0,0,107,101,121,32,115,0,0,0,78,111,116,32,77,111,118,105,110,103,0,0,0,0,0,0,102,112,111,105,110,116,49,0,109,100,95,99,117,116,116,104,114,112,0,0,0,0,0,0,79,99,116,0,0,0,0,0,84,101,100,100,121,66,111,121,32,66,108,117,101,115,32,40,98,111,111,116,108,101,103,41,0,0,0,0,0,0,0,0,87,104,101,101,108,32,40,50,55,48,68,41,0,0,0,0,85,83,32,65,65,70,32,77,117,115,116,97,110,103,32,40,50,53,116,104,32,77,97,121,46,32,49,57,57,48,41,0,0,0,0,0,0,0,0,0,83,111,102,116,32,116,104,101,110,32,72,97,114,100,0,0,84,104,101,32,78,117,109,98,101,114,32,111,102,32,80,108,97,121,101,114,0,0,0,0,67,117,116,84,104,114,111,97,116,32,73,115,108,97,110,100,32,40,69,117,114,111,44,32,85,83,65,41,0,0,0,0,106,106,115,113,117,97,119,107,98,0,0,0,0,0,0,0,69,120,116,101,110,100,32,50,48,48,48,48,48,32,79,110,108,121,0,0,0,0,0,0,65,100,118,101,110,116,117,114,101,32,73,115,108,97,110,100,0,0,0,0,0,0,0,0,115,112,101,97,107,114,101,115,95,118,114,120,0,0,0,0,112,97,105,110,116,114,108,114,0,0,0,0,0,0,0,0,115,116,97,114,115,95,115,116,97,116,101,0,0,0,0,0,107,101,121,32,97,0,0,0,116,114,111,106,97,110,95,98,103,50,95,105,109,97,103,101,0,0,0,0,0,0,0,0,50,32,67,111,105,110,115,32,52,32,67,114,101,100,105,116,0,0,0,0,0,0,0,0,109,100,95,99,117,116,116,104,114,0,0,0,0,0,0,0,75,121,117,103,111,66,103,80,97,108,101,116,116,101,66,97,110,107,0,0,0,0,0,0,112,117,122,122,108,105,50,115,0,0,0,0,0,0,0,0,67,104,97,109,112,105,111,110,32,87,114,101,115,116,108,101,114,0,0,0,0,0,0,0,70,105,110,97,108,32,70,105,103,104,116,32,40,87,111,114,108,100,44,32,115,101,116,32,50,41,0,0,0,0,0,0,78,101,111,32,71,101,111,32,67,68,90,32,115,121,115,116,101,109,0,0,0,0,0,0,67,117,116,105,101,32,83,117,122,117,107,105,32,110,111,32,82,105,110,103,115,105,100,101,32,65,110,103,101,108,32,40,74,112,110,41,0,0,0,0,49,57,52,49,32,45,32,67,111,117,110,116,101,114,32,65,116,116,97,99,107,32,40,74,97,112,97,110,41,0,0,0,83,104,105,110,105,110,103,32,70,111,114,99,101,32,73,73,32,40,69,117,114,111,41,0,0,0,0,0,0,0,0,0,84,97,107,101,32,83,99,114,101,101,110,115,104,111,116,0,68,117,110,103,101,111,110,115,32,38,32,68,114,97,103,111,110,115,32,45,32,116,111,119,101,114,32,111,102,32,100,111,111,109,32,40,57,52,48,49,49,51,32,69,117,114,111,41,0,0,0,0,0,0,0,0,111,117,116,115,99,97,108,101,0,0,0,0,0,0,0,0,105,114,113,95,101,110,97,98,108,101,100,0,0,0,0,0,107,101,121,32,98,97,99,107,115,108,97,115,104,0,0,0,80,117,110,107,32,83,104,111,116,32,40,74,97,112,97,110,32,50,32,80,108,97,121,101,114,115,41,0,0,0,0,0,109,100,95,99,117,116,105,101,115,117,122,0,0,0,0,0,77,105,99,114,111,110,101,116,0,0,0,0,0,0,0,0,83,76,79,84,45,62,111,112,49,95,111,117,116,0,0,0,83,116,97,114,116,105,110,103,32,109,111,118,105,101,32,112,108,97,121,98,97,99,107,46,0,0,0,0,0,0,0,0,67,72,45,62,98,108,111,99,107,95,102,110,117,109,0,0,105,110,118,97,108,105,100,32,98,105,116,32,108,101,110,103,116,104,32,114,101,112,101,97,116,0,0,0,0,0,0,0,107,101,121,32,93,0,0,0,103,108,67,111,109,112,114,101,115,115,101,100,84,101,120,73,109,97,103,101,51,68,79,69,83,0,0,0,0,0,0,0,67,117,114,115,101,32,40,74,112,110,41,0,0,0,0,0,97,116,116,114,105,98,117,116,101,32,118,101,99,50,32,84,101,120,67,111,111,114,100,59,10,97,116,116,114,105,98,117,116,101,32,118,101,99,50,32,86,101,114,116,101,120,67,111,111,114,100,59,10,97,116,116,114,105,98,117,116,101,32,118,101,99,52,32,67,111,108,111,114,59,10,117,110,105,102,111,114,109,32,109,97,116,52,32,77,86,80,77,97,116,114,105,120,59,10,118,97,114,121,105,110,103,32,118,101,99,50,32,116,101,120,95,99,111,111,114,100,59,10,118,97,114,121,105,110,103,32,118,101,99,52,32,99,111,108,111,114,59,10,118,111,105,100,32,109,97,105,110,40,41,32,123,10,32,32,32,103,108,95,80,111,115,105,116,105,111,110,32,61,32,77,86,80,77,97,116,114,105,120,32,42,32,118,101,99,52,40,86,101,114,116,101,120,67,111,111,114,100,44,32,48,46,48,44,32,49,46,48,41,59,10,32,32,32,116,101,120,95,99,111,111,114,100,32,61,32,84,101,120,67,111,111,114,100,59,10,32,32,32,99,111,108,111,114,32,61,32,67,111,108,111,114,59,10,125,0,0,0,0,0,84,114,105,112,108,101,32,68,114,97,119,32,80,111,107,101,114,0,0,0,0,0,0,0,109,100,95,99,117,114,115,101,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,81,117,101,114,121,105,110,103,32,71,76,32,101,120,116,101,110,115,105,111,110,58,32,37,115,32,61,62,32,37,115,10,0,0,0,0,0,107,101,121,32,91,0,0,0,67,114,121,115,116,97,108,39,115,32,80,111,110,121,32,84,97,108,101,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,53,50,54,41,0,0,75,48,53,50,49,48,57,67,104,97,114,82,111,109,66,97,110,107,91,50,93,0,0,0,115,115,105,100,101,107,105,50,0,0,0,0,0,0,0,0,80,50,32,83,117,112,101,114,0,0,0,0,0,0,0,0,109,100,95,99,114,121,115,116,108,112,116,112,49,51,0,0,65,107,117,109,97,45,74,111,117,32,68,114,97,99,117,108,97,32,40,74,97,112,97,110,32,118,101,114,46,32,80,41,0,0,0,0,0,0,0,0,112,52,32,115,116,97,114,116,0,0,0,0,0,0,0,0,82,105,110,103,32,110,111,32,79,104,106,97,32,40,74,97,112,97,110,32,50,32,80,108,97,121,101,114,115,32,118,101,114,46,32,78,41,0,0,0,81,117,105,122,32,67,114,97,121,111,110,32,83,104,105,110,99,104,97,110,32,40,74,97,112,97,110,41,0,0,0,0,110,101,116,119,111,114,107,95,99,109,100,95,112,111,114,116,0,0,0,0,0,0,0,0,65,108,105,101,110,115,32,40,85,83,41,0,0,0,0,0,109,114,103,111,101,109,111,110,0,0,0,0,0,0,0,0,107,101,121,32,112,0,0,0,83,117,112,101,114,32,67,104,97,114,103,101,114,0,0,0,80,97,114,111,100,105,117,115,32,68,65,33,32,40,74,97,112,97,110,41,0,0,0,0,70,108,97,115,104,32,80,111,105,110,116,32,40,115,101,116,32,50,44,32,74,97,112,97,110,44,32,70,68,49,48,57,52,32,51,49,55,45,48,49,50,55,65,41,0,0,0,0,67,114,121,115,116,97,108,39,115,32,80,111,110,121,32,84,97,108,101,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,53,49,57,41,0,0,83,101,112,0,0,0,0,0,116,101,100,100,121,98,98,111,98,108,0,0,0,0,0,0,87,104,101,101,108,32,40,51,54,48,41,0,0,0,0,0,112,109,99,98,97,110,107,0,71,88,56,55,51,0,0,0,118,105,100,101,111,98,97,110,107,0,0,0,0,0,0,0,65,0,0,0,106,0,0,0,97,0,0,0,120,0,0,0,0,0,0,0,168,48,0,0,252,48,0,0,184,48,0,0,227,48,0,0,195,48,0,0,175,48,0,0,185,48,0,0,32,0,0,0,40,0,0,0,74,0,0,0,97,0,0,0,112,0,0,0,97,0,0,0,110,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,109,100,95,99,114,121,115,116,108,112,116,112,49,52,0,0,74,46,32,74,46,32,83,113,117,97,119,107,101,114,115,32,40,98,111,111,116,108,101,103,44,32,66,108,97,110,100,105,97,32,99,111,110,118,101,114,115,105,111,110,41,0,0,0,67,111,110,116,114,97,32,40,74,97,112,97,110,41,0,0,69,120,116,101,110,100,32,49,48,48,48,48,48,44,32,50,48,48,48,48,48,0,0,0,88,45,77,101,110,32,40,52,32,80,108,97,121,101,114,115,32,118,101,114,32,69,66,65,41,0,0,0,0,0,0,0,116,116,109,97,104,106,110,103,95,112,111,114,116,95,115,101,108,101,99,116,0,0,0,0,68,114,118,86,105,100,101,111,66,97,110,107,0,0,0,0,75,117,114,97,108,32,84,87,84,0,0,0,0,0,0,0,71,76,69,83,50,0,0,0,115,116,97,114,115,95,111,102,102,115,101,116,0,0,0,0,118,117,108,99,97,110,0,0,107,101,121,32,111,0,0,0,116,114,111,106,97,110,95,98,103,50,95,115,99,114,111,108,108,120,0,0,0,0,0,0,67,114,121,115,116,97,108,39,115,32,80,111,110,121,32,84,97,108,101,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,53,49,49,41,0,0,71,0,0,0,114,0,0,0,97,0,0,0,100,0,0,0,105,0,0,0,117,0,0,0,115,0,0,0,32,0,0,0,73,0,0,0,73,0,0,0,73,0,0,0,32,0,0,0,29,79,0,0,172,138,0,0,75,48,0,0,137,48,0,0,94,121,0,0,113,138,0,0,120,48,0,0,32,0,0,0,40,0,0,0,65,0,0,0,115,0,0,0,105,0,0,0,97,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,75,121,117,103,111,70,103,67,111,108,111,117,114,0,0,0,67,111,105,110,97,103,101,32,97,102,102,101,99,116,115,0,110,82,97,109,66,97,110,107,0,0,0,0,0,0,0,0,80,117,122,122,108,105,32,50,32,40,86,49,48,48,41,0,0,0,0,0,0,0,0,0,49,57,88,88,32,45,32,116,104,101,32,119,97,114,32,97,103,97,105,110,115,116,32,100,101,115,116,105,110,121,32,40,57,53,49,50,49,56,32,72,105,115,112,97,110,105,99,41,0,0,0,0,0,0,0,0,86,101,110,100,101,116,116,97,32,40,65,115,105,97,32,50,32,80,108,97,121,101,114,115,32,118,101,114,46,32,85,41,0,0,0,0,0,0,0,0,112,99,101,95,99,104,97,109,112,119,114,115,0,0,0,0,102,102,105,103,104,116,97,0,84,104,101,32,83,105,109,112,115,111,110,115,32,40,50,32,80,108,97,121,101,114,115,32,87,111,114,108,100,44,32,115,101,116,32,50,41,0,0,0,109,100,95,99,114,121,115,116,108,112,116,112,49,53,0,0,111,118,101,114,108,97,121,37,117,95,114,101,99,116,0,0,109,100,95,115,104,105,110,102,114,99,50,0,0,0,0,0,84,101,101,110,97,103,101,32,77,117,116,97,110,116,32,72,101,114,111,32,84,117,114,116,108,101,115,32,40,85,75,32,52,32,80,108,97,121,101,114,115,44,32,115,101,116,32,49,41,0,0,0,0,0,0,0,76,111,97,100,32,83,116,97,116,101,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,97,110,110,111,116,32,115,97,118,101,32,88,77,76,32,99,104,101,97,116,32,115,101,116,116,105,110,103,115,46,10,0,0,0,100,100,116,111,100,114,49,0,115,105,122,101,95,121,0,0,45,45,62,0,0,0,0,0,97,116,111,109,112,117,110,107,0,0,0,0,0,0,0,0,107,101,121,32,105,0,0,0,112,117,110,107,115,104,111,116,106,0,0,0,0,0,0,0,107,117,110,103,102,117,98,0,67,114,121,115,116,97,108,39,115,32,80,111,110,121,32,84,97,108,101,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,54,51,48,41,0,0,118,105,103,105,108,97,110,116,117,50,0,0,0,0,0,0,65,116,111,109,105,99,32,66,111,121,32,40,114,101,118,105,115,105,111,110,32,65,41,0,0,0,0,0,0,0,0,0,72,111,111,107,32,40,74,97,112,97,110,41,0,0,0,0,82,45,84,121,112,101,32,40,85,83,41,0,0,0,0,0,109,100,95,99,114,121,115,116,108,112,116,112,48,55,0,0,105,110,105,116,95,109,111,118,105,101,40,41,0,0,0,0,69,110,97,98,108,101,32,104,111,116,107,101,121,115,0,0,107,101,121,32,117,0,0,0,114,116,121,112,101,0,0,0,67,114,121,115,116,97,108,39,115,32,80,111,110,121,32,84,97,108,101,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,54,50,56,41,0,0,109,100,95,99,114,121,115,116,108,112,116,112,48,56,0,0,107,101,121,32,121,0,0,0,105,56,55,53,49,95,108,101,118,101,108,0,0,0,0,0,67,114,121,115,116,97,108,39,115,32,80,111,110,121,32,84,97,108,101,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,54,50,51,41,0,0,112,53,32,102,105,114,101,32,54,0,0,0,0,0,0,0,80,50,32,83,104,111,116,32,40,97,117,116,111,41,0,0,109,100,95,99,114,121,115,116,108,112,116,112,48,57,0,0,110,101,116,119,111,114,107,95,99,109,100,95,101,110,97,98,108,101,0,0,0,0,0,0,80,49,32,82,105,103,104,116,32,47,32,108,101,102,116,0,80,53,32,66,117,116,116,111,110,32,54,0,0,0,0,0,107,101,121,32,116,0,0,0,87,105,100,101,115,99,114,101,101,110,0,0,0,0,0,0,84,105,109,101,32,65,100,106,117,115,116,0,0,0,0,0,102,112,111,105,110,116,0,0,67,114,121,115,116,97,108,39,115,32,80,111,110,121,32,84,97,108,101,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,54,49,48,41,0,0,65,117,103,0,0,0,0,0,84,101,100,100,121,66,111,121,32,66,108,117,101,115,32,40,51,49,53,45,53,49,49,53,44,32,79,108,100,32,86,101,114,46,41,0,0,0,0,0,49,48,48,107,44,32,50,48,48,107,32,97,110,100,32,53,48,48,107,0,0,0,0,0,66,97,110,107,32,85,112,47,68,111,119,110,0,0,0,0,83,101,108,101,99,116,97,98,108,101,32,71,97,109,101,115,0,0,0,0,0,0,0,0,109,117,115,116,97,110,103,0,72,97,114,100,32,111,110,108,121,0,0,0,0,0,0,0,112,53,32,102,105,114,101,32,53,0,0,0,0,0,0,0,67,111,110,116,105,110,117,101,32,80,108,97,121,0,0,0,109,100,95,99,114,121,115,116,108,112,116,112,49,48,0,0,106,106,115,113,117,97,119,107,98,50,0,0,0,0,0,0,69,120,116,101,110,100,32,49,48,48,48,48,48,32,79,110,108,121,0,0,0,0,0,0,112,97,108,101,116,116,101,95,50,0,0,0,0,0,0,0,67,114,117,115,104,32,82,111,108,108,101,114,32,40,75,117,114,97,108,32,84,87,84,41,0,0,0,0,0,0,0,0,80,53,32,66,117,116,116,111,110,32,53,0,0,0,0,0,107,101,121,32,114,0,0,0,97,118,101,110,103,101,114,115,95,115,111,117,110,100,115,116,97,116,101,0,0,0,0,0,51,32,67,111,105,110,115,32,52,32,67,114,101,100,105,116,0,0,0,0,0,0,0,0,67,114,121,115,116,97,108,39,115,32,80,111,110,121,32,84,97,108,101,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,54,48,54,41,0,0,75,121,117,103,111,83,117,98,67,80,85,69,110,97,98,108,101,0,0,0,0,0,0,0,82,111,117,110,100,32,116,105,109,101,0,0,0,0,0,0,66,97,100,32,103,114,97,112,104,105,99,115,0,0,0,0,70,105,110,97,108,32,70,105,103,104,116,32,40,87,111,114,108,100,44,32,115,101,116,32,49,41,0,0,0,0,0,0,112,53,32,102,105,114,101,32,52,0,0,0,0,0,0,0,75,105,110,103,32,111,102,32,116,104,101,32,77,111,110,115,116,101,114,115,32,50,32,45,32,84,104,101,32,78,101,120,116,32,84,104,105,110,103,32,40,112,114,111,116,111,116,121,112,101,41,0,0,0,0,0,109,100,95,99,114,121,115,116,108,112,116,112,49,49,0,0,80,104,97,110,116,97,115,121,32,83,116,97,114,32,73,73,32,40,69,117,114,111,44,32,85,83,65,44,32,82,101,118,46,32,65,41,0,0,0,0,83,97,118,101,32,83,116,97,116,101,0,0,0,0,0,0,115,105,122,101,95,120,0,0,68,117,110,103,101,111,110,115,32,38,32,68,114,97,103,111,110,115,32,45,32,116,111,119,101,114,32,111,102,32,100,111,111,109,32,40,57,52,48,52,49,50,32,69,117,114,111,41,0,0,0,0,0,0,0,0,80,53,32,66,117,116,116,111,110,32,52,0,0,0,0,0,107,101,121,32,101,0,0,0,80,117,110,107,32,83,104,111,116,32,40,85,83,32,50,32,80,108,97,121,101,114,115,41,0,0,0,0,0,0,0,0,67,114,121,115,116,97,108,39,115,32,80,111,110,121,32,84,97,108,101,32,40,85,83,65,44,32,80,114,111,116,111,116,121,112,101,44,32,49,57,57,52,48,54,48,49,41,0,0,112,53,32,102,105,114,101,32,51,0,0,0,0,0,0,0,109,100,95,99,114,121,115,116,108,112,116,112,49,50,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,109,111,118,105,101,32,102,105,108,101,58,32,34,37,115,34,46,10,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,112,101,114,102,111,114,109,32,105,110,105,116,105,97,108,32,115,101,114,105,97,108,105,122,97,116,105,111,110,32,102,111,114,32,114,101,119,105,110,100,46,10,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,97,110,110,111,116,32,116,97,107,101,32,115,99,114,101,101,110,115,104,111,116,46,32,71,80,85,32,114,101,110,100,101,114,105,110,103,32,105,115,32,117,115,101,100,32,97,110,100,32,114,101,97,100,95,118,105,101,119,112,111,114,116,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,46,10,0,0,1,2,3,4,5,6,7,8,8,9,9,10,10,11,11,12,12,12,12,13,13,13,13,14,14,14,14,15,15,15,15,16,16,16,16,16,16,16,16,17,17,17,17,17,17,17,17,18,18,18,18,18,18,18,18,19,19,19,19,19,19,19,19,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,21,21,21,21,21,21,21,21,21,21,21,21,21,21,21,21,22,22,22,22,22,22,22,22,22,22,22,22,22,22,22,22,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,28,0,1,2,3,4,4,5,5,6,6,6,6,7,7,7,7,8,8,8,8,8,8,8,8,9,9,9,9,9,9,9,9,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,0,0,16,17,18,18,19,19,20,20,20,20,21,21,21,21,22,22,22,22,22,22,22,22,23,23,23,23,23,23,23,23,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,25,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,26,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,27,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,28,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,49,50,51,52,53,54,55,56,57,0,0,0,0,0,0,48,49,50,51,52,53,54,55,56,57,0,0,0,0,0,0,37,0,0,0,89,0,0,0,45,0,0,0,37,0,0,0,109,0,0,0,45,0,0,0,37,0,0,0,100,0,0,0,37,0,0,0,72,0,0,0,58,0,0,0,37,0,0,0,77,0,0,0,58,0,0,0,37,0,0,0,83,0,0,0,37,0,0,0,72,0,0,0,58,0,0,0,37,0,0,0,77,0,0,0,0,0,0,0,37,0,0,0,73,0,0,0,58,0,0,0,37,0,0,0,77,0,0,0,58,0,0,0,37,0,0,0,83,0,0,0,32,0,0,0,37,0,0,0,112,0,0,0,0,0,0,0,37,0,0,0,109,0,0,0,47,0,0,0,37,0,0,0,100,0,0,0,47,0,0,0,37,0,0,0,121,0,0,0,37,0,0,0,72,0,0,0,58,0,0,0,37,0,0,0,77,0,0,0,58,0,0,0,37,0,0,0,83,0,0,0,37,72,58,37,77,58,37,83,37,72,58,37,77,0,0,0,37,73,58,37,77,58,37,83,32,37,112,0,0,0,0,0,37,89,45,37,109,45,37,100,37,109,47,37,100,47,37,121,37,72,58,37,77,58,37,83,37,0,0,0,0,0,0,0,37,112,0,0,0,0,0,0,10,0,0,0,13,0,0,0,16,0,0,0,20,0,0,0,2,0,0,0,4,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,24,0,0,0,24,0,0,0,0,0,0,0,14,19,19,0,0,0,0,0,18,19,19,0,0,0,0,0,5,6,5,7,0,0,0,0,255,255,255,255,254,255,255,255,253,255,255,255,0,0,0,0,3,0,0,0,2,0,0,0,1,0,0,0,0,0,0,0,12,8,13,11,14,10,15,9,3,2,1,0,4,5,6,7,10,11,14,12,15,13,8,9,6,7,5,3,0,4,2,1,14,13,15,9,8,12,11,10,7,4,1,5,6,0,3,2,15,14,8,9,10,11,13,12,1,2,7,3,4,6,0,5,10,9,13,14,15,8,12,11,5,2,1,0,3,4,7,6,8,9,15,14,10,11,13,12,0,6,5,4,1,2,3,7,14,8,15,9,10,11,13,12,4,5,3,0,2,7,6,1,13,11,12,10,15,9,14,8,6,0,7,5,1,4,3,2,12,11,13,10,9,8,14,15,0,2,4,6,7,5,3,1,15,13,9,8,10,11,12,14,2,1,0,7,6,5,4,3,13,8,9,10,11,12,15,14,6,0,1,2,3,7,4,5,12,11,10,8,9,13,14,15,6,5,4,0,7,1,2,3,12,15,8,13,9,11,14,10,6,5,4,3,2,1,0,7,11,12,13,14,15,8,9,10,4,5,7,1,6,3,2,0,13,8,12,14,11,15,10,9,7,6,5,4,3,2,1,0,15,14,13,12,11,10,9,8,0,6,7,4,3,2,1,5,44,181,88,36,154,19,152,201,142,206,68,81,41,4,212,170,49,163,69,54,163,105,100,172,83,26,131,80,234,77,55,210,0,4,0,0,2,0,0,0,0,8,0,0,3,0,0,0,3,0,0,0,0,0,0,0,255,3,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,2,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,1,0,0,0,0,0,0,0,3,0,0,0,2,0,0,0,1,0,0,0,0,0,0,0,2,0,0,0,3,0,0,0,1,0,0,0,0,0,0,0,3,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,1,0,0,0,3,0,0,0,0,0,0,0,8,0,0,0,1,0,0,0,2,0,0,0,4,0,0,0,0,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,3,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,3,0,0,0,2,0,0,0,1,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,2,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,3,0,0,0,4,0,0,0,4,0,0,0,5,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,3,0,0,0,4,0,0,0,4,0,0,0,5,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,2,0,0,0,3,0,0,0,3,0,0,0,4,0,0,0,3,0,0,0,4,0,0,0,4,0,0,0,5,0,0,0,4,0,0,0,5,0,0,0,3,10,10,0,0,0,0,0,128,129,129,135,0,0,0,0,129,129,129,143,0,0,0,128,120,97,22,0,120,97,22,0,120,97,22,0,120,97,22,0,114,110,22,0,0,0,96,0,0,0,96,0,0,0,96,0,74,207,24,0,74,207,24,0,74,207,24,0,74,207,24,0,68,220,24,0,0,0,96,0,0,0,96,0,0,0,96,0,168,148,22,0,174,207,22,0,242,235,22,0,168,250,22,0,22,68,23,0,0,0,96,0,0,0,96,0,0,0,96,0,122,2,25,0,128,61,25,0,196,89,25,0,122,104,25,0,232,177,25,0,0,0,96,0,0,0,96,0,0,0,96,0,0,0,0,0,0,0,0,0,16,17,18,19,36,37,38,39,56,57,58,59,76,77,78,79,0,0,0,0,0,0,0,0,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,65,54,53,52,56,54,65,54,51,54,52,54,55,54,68,54,67,55,54,52,67,55,55,55,54,55,54,55,55,56,65,55,65,53,55,52,69,53,69,53,67,53,55,53,54,65,69,53,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,70,53,49,55,56,53,68,53,48,53,49,53,57,52,48,53,65,54,51,55,66,54,65,54,51,54,50,54,57,54,51,54,70,52,53,55,52,52,69,52,50,52,51,52,56,56,50,52,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,65,51,51,50,54,51,66,51,48,51,51,51,48,50,48,51,52,52,53,52,56,52,56,52,53,52,52,52,48,52,53,52,65,50,55,50,52,50,67,50,51,50,53,50,51,54,51,50,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,49,50,53,51,51,50,55,50,48,50,52,50,49,49,48,50,51,51,56,54,52,51,55,51,55,51,54,51,49,51,55,51,52,49,65,51,51,49,65,49,54,49,55,49,53,52,54,49,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,49,51,52,49,55,49,53,48,48,48,55,49,49,50,48,51,52,52,52,50,54,51,53,49,57,49,54,50,50,50,57,51,53,49,52,51,68,52,56,51,56,51,68,51,55,49,56,54,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,50,52,51,50,52,50,51,48,48,48,52,49,50,51,48,53,54,54,51,51,51,52,51,51,48,50,51,51,51,51,48,53,55,50,51,52,65,53,54,53,65,53,65,52,65,50,65,56,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,52,54,50,51,50,52,50,50,65,48,50,50,51,52,65,55,56,56,50,52,49,54,50,52,65,50,49,52,53,52,65,55,65,51,50,53,54,55,52,55,65,54,54,53,68,51,65,65,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,55,48,52,48,54,48,50,48,48,48,51,48,53,48,66,48,65,48,53,48,57,48,53,48,52,48,53,48,53,48,56,48,53,48,54,48,65,48,57,48,56,48,54,48,52,48,67,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,50,52,55,50,48,51,48,53,48,51,50,51,48,53,51,52,54,51,57,50,54,51,51,66,50,51,52,51,51,66,53,51,48,51,57,50,56,52,54,52,53,52,51,52,54,52,50,51,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,49,51,49,51,48,53,50,52,48,53,48,53,48,52,50,51,51,50,50,51,55,53,52,56,48,53,51,53,52,56,51,50,51,50,51,51,52,54,65,51,56,54,56,54,65,51,51,50,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,55,50,49,57,48,55,50,51,48,55,48,55,50,51,68,50,56,49,51,57,52,55,55,54,48,55,48,55,55,54,68,49,65,49,53,57,50,57,70,50,53,57,53,57,70,50,70,49,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,54,53,48,55,48,54,52,49,49,65,50,65,49,49,54,56,55,55,48,55,51,55,67,52,51,65,51,65,51,52,54,54,56,55,48,55,49,70,48,49,51,67,48,67,51,49,55,53,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,50,48,48,49,52,48,50,55,50,55,51,48,50,48,50,48,52,52,48,51,48,52,56,70,52,65,52,56,52,51,52,52,52,65,48,53,48,66,48,55,52,69,48,69,52,52,52,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,51,48,48,51,56,48,48,67,51,53,54,56,51,49,51,48,53,51,48,52,48,51,53,67,53,56,55,67,53,52,53,51,53,54,48,55,48,56,48,67,53,66,50,54,53,53,53,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,52,56,48,49,68,48,48,48,52,51,56,53,52,50,52,53,54,67,48,50,48,48,51,56,54,54,57,65,54,53,54,57,54,54,48,52,48,53,48,65,54,57,52,52,54,55,54,52,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,53,48,52,48,48,48,48,48,49,48,51,48,53,48,52,48,65,48,53,48,57,48,53,48,52,48,54,48,51,48,55,48,52,48,57,48,68,48,53,48,55,48,49,48,52,48,51,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,54,56,53,65,53,56,54,57,51,55,70,55,55,55,70,55,57,56,56,65,55,57,55,65,54,55,65,55,65,55,65,55,66,56,67,65,56,57,56,68,67,55,51,55,70,55,56,55,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,52,55,51,56,65,54,49,55,48,53,49,53,48,53,48,53,56,55,57,55,54,55,50,56,51,53,50,53,48,53,51,53,55,55,55,55,48,55,50,65,50,53,51,53,48,53,50,53,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,51,53,50,53,54,52,50,52,48,52,51,52,48,52,48,52,54,53,53,52,52,53,51,53,53,52,52,52,48,52,53,52,53,53,52,52,48,53,51,54,51,52,53,52,48,52,51,52,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,50,51,48,49,57,50,51,50,48,51,52,51,48,51,48,51,52,51,51,51,56,51,52,51,56,51,54,51,48,51,55,51,51,51,50,52,48,51,52,52,55,51,55,51,48,51,54,51,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,51,49,51,48,51,48,52,48,48,48,55,54,50,48,48,53,53,51,53,50,53,50,53,50,57,49,54,49,52,49,57,51,54,52,54,51,54,51,53,52,56,51,68,48,54,53,56,49,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,52,50,52,49,52,49,53,49,48,48,52,56,51,49,48,55,54,52,54,51,54,51,49,51,48,50,51,51,53,51,48,52,55,54,55,53,55,52,49,53,65,53,65,48,55,55,65,51,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,53,51,53,50,53,50,56,50,65,48,50,65,52,51,65,65,55,54,55,52,55,52,50,52,65,51,49,53,54,53,65,53,56,56,56,56,56,53,51,54,65,54,54,48,56,57,65,52,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,53,48,52,48,51,48,52,48,48,48,68,48,53,48,67,48,56,48,54,48,53,48,54,48,52,48,55,48,55,48,55,48,65,48,65,48,54,48,56,48,56,48,48,48,67,48,54,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,51,52,55,48,51,54,53,57,53,54,51,52,50,57,51,53,53,53,57,48,53,55,56,57,57,55,53,53,52,57,53,56,55,51,67,48,55,56,65,56,67,53,55,51,54,56,55,65,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,53,51,53,53,54,53,48,54,56,53,48,51,48,54,48,52,50,52,50,55,51,54,50,54,56,54,48,52,50,54,48,55,48,49,48,65,48,55,48,53,56,52,48,49,48,53,48,56,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,50,48,56,52,51,50,52,53,52,48,50,50,52,48,51,55,51,55,65,50,52,51,52,53,53,55,51,51,52,48,54,48,48,48,68,48,53,48,51,53,51,48,48,48,51,48,55,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,65,48,50,51,50,51,51,48,48,51,50,48,50,52,50,52,67,49,51,52,50])
.concat([51,52,52,50,52,50,48,52,48,48,48,70,50,52,49,49,51,50,48,48,49,49,48,53,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,51,48,51,49,49,49,51,48,51,48,51,48,48,48,51,48,53,49,53,50,50,49,53,50,53,50,53,49,50,48,53,49,55,50,55,51,51,51,55,51,55,52,55,50,51,50,55,50,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,52,49,52,49,50,49,52,48,52,49,52,49,49,48,52,49,54,50,54,51,51,50,54,51,54,51,54,50,51,49,54,50,56,51,56,53,52,52,56,53,56,53,56,51,52,51,56,51,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,53,49,53,51,50,50,53,49,53,50,53,49,50,48,53,49,55,51,55,53,52,51,55,52,55,53,55,51,52,50,55,51,57,53,57,56,53,53,57,54,57,55,57,52,54,52,57,53,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,50,48,53,48,50,48,51,48,51,48,50,48,49,48,50,48,52,48,55,48,52,48,54,48,54,48,52,48,51,48,52,48,54,48,65,48,54,48,56,48,57,48,54,48,53,48,54,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,52,49,53,49,68,49,52,49,68,51,68,49,55,55,70,55,53,52,53,52,67,52,52,52,56,50,67,52,65,55,65,55,48,52,48,52,68,52,53,52,57,49,68,52,70,55,56,55,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,51,48,51,48,51,50,51,55,52,50,51,48,53,48,53,57,54,57,54,57,54,50,54,55,51,53,54,48,53,51,53,48,53,48,53,48,53,52,53,48,50,56,53,48,53,50,53,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,51,48,51,48,51,48,51,53,53,48,51,48,52,48,52,55,55,55,55,55,55,48,55,53,52,52,55,48,52,53,52,48,54,48,54,48,54,48,54,48,51,55,54,48,52,51,52,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,53,48,53,48,53,51,53,52,55,48,53,48,51,48,51,52,57,52,57,52,57,50,57,52,53,51,57,48,51,55,51,48,56,48,56,48,56,51,56,48,52,53,56,48,51,54,51,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,66,48,67,52,52,52,48,50,51,52,52,50,48,48,53,51,68,51,70,51,51,51,52,51,51,51,51,52,49,57,51,48,48,48,48,48,52,51,53,48,52,48,52,54,53,56,49,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,56,48,57,53,54,53,48,56,53,56,54,51,49,48,55,48,66,54,65,51,53,50,51,55,52,52,53,53,51,48,52,48,48,55,48,48,54,52,52,48,53,48,54,55,55,65,51,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,54,48,55,51,56,55,57,67,56,67,56,52,51,65,65,48,57,52,57,50,55,51,57,65,53,56,55,54,53,65,53,48,48,53,48,48,56,52,65,48,54,48,56,56,57,65,52,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,53,48,54,48,66,48,55,48,66,48,66,48,53,48,67,48,55,48,55,48,57,48,55,48,55,48,57,48,55,48,55,48,48,48,48,48,66,48,56,48,55,48,66,48,67,48,54,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,51,52,51,48,56,48,50,49,54,50,48,48,53,51,48,48,51,52,52,49,55,48,52,50,53,49,50,53,52,50,48,48,51,52,53,50,54,48,54,52,53,48,50,69,51,49,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,49,48,54,52,49,50,48,51,50,55,51,51,48,54,48,49,49,65,54,53,50,50,48,53,51,54,50,56,51,53,48,50,50,65,54,54,51,50,48,55,50,54,50,48,68,52,50,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,49,51,48,56,50,50,51,48,53,50,50,52,50,48,56,48,50,52,55,56,50,51,51,48,55,49,50,51,53,49,55,48,51,53,55,56,50,52,51,48,57,48,50,51,48,57,54,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,50,49,49,49,51,51,52,51,51,51,51,51,49,52,48,52,51,51,53,51,51,50,52,50,51,50,51,50,52,56,48,55,52,53,66,53,51,49,52,49,51,49,51,49,48,56,51,55,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,51,50,51,50,52,52,53,52,52,52,52,52,53,51,48,50,52,52,53,52,52,51,53,51,52,51,52,51,66,55,50,53,53,54,55,54,52,50,53,50,52,50,52,50,66,55,52,53,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,52,51,52,51,53,53,54,53,53,53,53,53,48,50,48,49,53,53,55,53,53,52,54,52,53,52,53,52,48,53,50,52,54,55,56,55,53,51,54,51,53,51,53,51,55,53,53,52,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,54,52,55,52,54,54,55,54,55,54,54,54,48,49,48,48,55,54,57,54,54,53,55,53,55,53,54,53,48,52,50,51,56,56,65,56,54,52,55,52,55,52,54,52,53,52,55,51,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,48,49,48,55,48,55,48,49,48,53,48,48,48,52,48,48,48,51,48,54,48,54,48,51,48,52,48,51,48,51,48,48,48,53,48,53,48,53,48,53,48,52,48,51,48,50,0,0,0,0,0,0,0,0,255,63,0,0,0,192,0,0,0,128,0,0,255,127,0,0,255,255,0,0,0,0,0,0,255,7,0,0,0,248,0,0,3,3,3,3,3,3,3,3,0,0,5,5,5,5,5,5,1,1,0,0,0,7,7,7,2,2,1,1,1,0,0,9,4,4,2,2,2,1,1,0,5,6,4,4,4,2,2,1,6,5,6,6,6,4,4,2,7,7,7,7,8,6,6,4,8,8,8,8,7,8,8,6,9,9,9,9,9,9,9,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,250,185,255,255,226,254,184,23,0,231,64,184,32,0,231,66,184,15,0,231,66,184,0,160,142,208,142,216,190,0,63,176,0,136,4,58,4,117,8,70,254,192,117,245,233,24,0,51,246,233,3,0,190,64,0,184,0,176,142,216,199,6,254,15,0,0,234,98,17,0,0,229,4,15,25,192,15,116,224,188,0,64,51,219,185,0,16,184,0,176,142,216,138,195,2,199,136,7,67,226,247,51,201,254,201,117,252,254,205,117,248,51,219,185,0,16,138,195,2,199,52,255,58,7,117,182,67,226,243,51,219,185,252,15,254,7,67,226,251,144,144,144,154,0,0,0,176,115,246,144,144,144,184,0,176,142,192,51,210,66,129,226,1,0,191,178,4,232,123,0,232,62,0,235,240,144,144,144,11,56,41,67,79,80,89,82,73,71,72,84,32,49,57,56,57,32,73,82,69,77,32,67,79,82,80,79,82,65,84,73,79,78,11,80,43,65,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,189,0,0,0,113,0,0,0,200,0,0,0,189,0,0,0,113,0,0,0,239,0,0,0,189,0,0,0,114,0,0,0,40,0,0,0,126,0,0,0,112,0,0,0,158,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,142,0,0,0,66,0,0,0,178,0,0,0,88,0,0,0,236,0,0,0,133,0,0,0,221,0,0,0,76,0,0,0,173,0,0,0,159,0,0,0,0,0,0,0,76,0,0,0,126,0,0,0,66,0,0,0,167,0,0,0,255,0,0,0,5,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,96,224,160,176,144,208,80,112,16,0,0,0,32,0,0,0,64,0,0,0,64,0,0,0,0,3,7,0,1,2,8,0,5,4,6,0,0,0,0,0,1,0,0,0,6,0,0,0,6,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,2,0,0,0,10,0,0,0,10,0,0,0,9,0,0,0,9,0,0,0,9,0,0,0,9,0,0,0,3,0,0,0,14,0,0,0,14,0,0,0,14,0,0,0,13,0,0,0,13,0,0,0,13,0,0,0,13,0,0,0,4,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,61,0,0,0,35,0,0,0,38,0,0,0,10,0,0,0,182,0,0,0,17,0,0,0,164,0,0,0,15,0,0,0,0,0,0,0,1,64,1,80,2,21,2,0,160,161,162,128,129,130,131,132,133,134,135,136,137,138,139,140,141,142,143,151,150,155,154,149,158,152,144,147,157,156,163,145,159,153,166,174,148,165,164,167,146,171,172,176,177,178,179,180,181,182,183,184,185,186,187,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,32,32,80,80,144,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,160,0,0,0,0,0,0,0,0,0,0,0,0,64,64,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,16,16,0,0,144,48,48,48,176,176,176,176,240,240,240,240,208,240,0,0,0,0,16,16,80,48,176,176,240,240,240,240,240,240,0,0,0,0,0,0,0,0,0,0,16,16,16,48,48,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,143,143,15,15,15,15,15,15,15,15,15,15,15,15,15,15,255,255,255,239,239,207,143,143,15,15,15,5,3,1,2,0,0,0,0,15,0,0,0,14,0,0,0,10,0,0,0,7,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,8,0,0,0,0,0,0,0,12,0,0,0,11,0,0,0,13,0,0,0,6,0,0,0,9,0,0,0,5,0,0,0,4,0,0,0,7,0,0,0,1,0,0,0,8,0,0,0,11,0,0,0,15,0,0,0,9,0,0,0,2,0,0,0,3,0,0,0,5,0,0,0,13,0,0,0,4,0,0,0,14,0,0,0,10,0,0,0,0,0,0,0,6,0,0,0,12,0,0,0,8,0,0,0,6,0,0,0,14,0,0,0,3,0,0,0,10,0,0,0,7,0,0,0,15,0,0,0,1,0,0,0,4,0,0,0,0,0,0,0,2,0,0,0,5,0,0,0,13,0,0,0,11,0,0,0,12,0,0,0,9,0,0,0,2,0,0,0,8,0,0,0,15,0,0,0,9,0,0,0,3,0,0,0,4,0,0,0,11,0,0,0,7,0,0,0,13,0,0,0,6,0,0,0,0,0,0,0,10,0,0,0,1,0,0,0,12,0,0,0,14,0,0,0,5,0,0,0,1,0,0,0,13,0,0,0,6,0,0,0,15,0,0,0,14,0,0,0,3,0,0,0,8,0,0,0,10,0,0,0,9,0,0,0,4,0,0,0,7,0,0,0,12,0,0,0,5,0,0,0,2,0,0,0,0,0,0,0,11,0,0,0,11,0,0,0,15,0,0,0,3,0,0,0,4,0,0,0,7,0,0,0,0,0,0,0,9,0,0,0,2,0,0,0,6,0,0,0,14,0,0,0,12,0,0,0,1,0,0,0,8,0,0,0,5,0,0,0,10,0,0,0,13,0,0,0,10,0,0,0,5,0,0,0,13,0,0,0,8,0,0,0,6,0,0,0,15,0,0,0,1,0,0,0,14,0,0,0,11,0,0,0,9,0,0,0,3,0,0,0,0,0,0,0,12,0,0,0,7,0,0,0,4,0,0,0,2,0,0,0,9,0,0,0,3,0,0,0,7,0,0,0,0,0,0,0,2,0,0,0,12,0,0,0,4,0,0,0,11,0,0,0,14,0,0,0,10,0,0,0,5,0,0,0,8,0,0,0,15,0,0,0,13,0,0,0,1,0,0,0,6,0,0,0,112,0,0,0,96,0,0,0,80,0,0,0,64,0,0,0,48,0,0,0,32,0,0,0,16,0,0,0,0,0,0,0,11,0,0,0,10,0,0,0,9,0,0,0,8,0,0,0,3,0,0,0,2,0,0,0,1,0,0,0,0,0,0,0,0,1,4,5,16,17,20,21,2,3,6,7,18,19,22,23,8,9,12,13,24,25,28,29,10,11,14,15,26,27,30,31,32,33,36,37,48,49,52,53,34,35,38,39,50,51,54,55,40,41,44,45,56,57,60,61,42,43,46,47,58,59,62,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,5,0,0,0,7,0,0,0,9,0,0,0,11,0,0,0,13,0,0,0,15,0,0,0,16,0,0,0,19,0,0,0,21,0,0,0,23,0,0,0,25,0,0,0,27,0,0,0,29,0,0,0,31,0,0,0,189,0,0,0,115,0,0,0,128,0,0,0,189,0,0,0,115,0,0,0,167,0,0,0,189,0,0,0,115,0,0,0,224,0,0,0,126,0,0,0,114,0,0,0,86,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,142,0,0,0,66,0,0,0,173,0,0,0,88,0,0,0,236,0,0,0,133,0,0,0,221,0,0,0,76,0,0,0,173,0,0,0,159,0,0,0,0,0,0,0,76,0,0,0,126,0,0,0,66,0,0,0,162,0,0,0,255,0,0,0,5,0,0,0,3,0,0,0,2,0,0,0,0,0,0,0,4,84,81,21,64,68,1,81,85,16,68,65,5,85,80,20,65,69,0,80,84,17,69,64,4,84,81,21,64,68,1,81,85,16,68,65,5,85,80,20,65,69,0,80,84,17,69,64,4,84,81,21,64,68,1,81,85,16,68,65,5,85,80,20,4,84,81,21,64,68,1,81,85,16,68,65,5,85,80,20,65,69,0,80,84,17,69,64,4,84,81,21,64,68,1,81,85,16,68,65,5,85,80,20,65,69,0,80,84,17,69,64,4,84,81,21,64,68,1,81,85,16,68,65,5,85,80,20,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,6,0,0,0,6,0,0,0,6,0,0,0,6,0,0,0,6,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,9,0,0,0,9,0,0,0,9,0,0,0,9,0,0,0,9,0,0,0,10,0,0,0,10,0,0,0,10,0,0,0,10,0,0,0,10,0,0,0,11,0,0,0,11,0,0,0,11,0,0,0,11,0,0,0,11,0,0,0,12,0,0,0,12,0,0,0,12,0,0,0,12,0,0,0,12,0,0,0,13,0,0,0,13,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,9,0,0,0,9,0,0,0,9,0,0,0,9,0,0,0,9,0,0,0,10,0,0,0,10,0,0,0,10,0,0,0,10,0,0,0,10,0,0,0,11,0,0,0,11,0,0,0,11,0,0,0,11,0,0,0,12,0,0,0,12,0,0,0,12,0,0,0,12,0,0,0,12,0,0,0,13,0,0,0,13,0,0,0,13,0,0,0,13,0,0,0,13,0,0,0,14,0,0,0,14,0,0,0,14,0,0,0,14,0,0,0,14,0,0,0,15,0,0,0,15,0,0,0,15,0,0,0,15,0,0,0,15,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,17,0,0,0,17,0,0,0,17,0,0,0,17,0,0,0,17,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,19,0,0,0,19,0,0,0,19,0,0,0,19,0,0,0,19,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,21,0,0,0,21,0,0,0,0,0,0,0,4,0,0,0,0,0,4,0,4,0,4,0,8,0,0,0,12,0,0,0,8,0,4,0,12,0,4,0,128,0,0,0,132,0,0,0,128,0,4,0,132,0,4,0,136,0,0,0,140,0,0,0,136,0,4,0,140,0,4,0,0,0,0,0,16,0,0,0,32,0,0,0,48,0,0,0,64,0,0,0,80,0,0,0,96,0,0,0,112,0,0,0,0,1,0,0,16,1,0,0,32,1,0,0,48,1,0,0,64,1,0,0,80,1,0,0,96,1,0,0,112,1,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,128,0,0,0,129,0,0,0,130,0,0,0,131,0,0,0,132,0,0,0,133,0,0,0,134,0,0,0,135,0,0,0,8,0,0,0,0,0,0,0,8,0,64,0,0,0,64,0,0,0,32,0,0,0,16,0,0,0,32,0,0,0,16,0,0,0,32,0,0,0,16,0,0,0,64,0,0,0,48,0,1,0,0,0,1,0,0,0,3,0,0,0,2,0,0,0,0,0,24,0,0,0,8,0,0,0,16,0,0,0,0,0,3,2,0,1,33,32,34,35,51,50,48,49,17,16,18,19,23,22,20,21,53,52,54,55,63,62,60,61,29,28,30,31,27,26,24,25,57,56,58,59,43,42,40,41,9,8,10,11,15,14,12,13,45,44,46,47,39,38,36,37,5,4,6,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,1,0,255,0,1,255,1,0,255,255,255,255,1,0,255,0,1,255,1,0,255,255,255,255,0,0,255,0,0,255,1,0,254,255,0,0,0,0,73,71,83,80,71,77,0,0,0,0,67,72,73,78,65,0,0,0,0,1,0,0,192,0,0,0,128,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,0,0,1,0,1,0,1,0,2,0,1,0,3,0,1,0,128,0,0,0,129,0,0,0,130,0,0,0,131,0,0,0,128,0,1,0,129,0,1,0,130,0,1,0,131,0,1,0,0,0,1,0,1,0,1,0,2,0,1,0,3,0,1,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,0,0,2,0,4,0,2,0,0,0,0,0,4,0,0,0,64,0,0,0,128,0,0,0,0,1,0,0,32,0,0,0,0,0,0,2,0,0,0,0,8,0,0,0,0,0,0,1,8,0,0,1,0,0,0,0,0,0,0,0,16,0,0,0,8,0,0,0,24,0,0,0,32,0,0,0,48,0,0,0,40,0,0,0,56,0,0,0,0,2,0,0,16,2,0,0,8,2,0,0,24,2,0,0,32,2,0,0,48,2,0,0,40,2,0,0,56,2,0,0,7,0,0,0,6,0,0,0,5,0,0,0,4,0,0,0,3,0,0,0,2,0,0,0,1,0,0,0,0,0,0,0,7,1,0,0,6,1,0,0,5,1,0,0,4,1,0,0,3,1,0,0,2,1,0,0,1,1,0,0,0,1,0,0,1,0,0,0,2,0,0,0,5,0,0,0,6,0,0,0,9,0,0,0,10,0,0,0,13,0,0,0,14,0,0,0,17,0,0,0,18,0,0,0,21,0,0,0,22,0,0,0,25,0,0,0,26,0,0,0,29,0,0,0,30,0,0,0,33,0,0,0,34,0,0,0,37,0,0,0,38,0,0,0,41,0,0,0,42,0,0,0,0,0,0,0,3,0,0,0,4,0,0,0,7,0,0,0,8,0,0,0,11,0,0,0,12,0,0,0,15,0,0,0,16,0,0,0,19,0,0,0,20,0,0,0,23,0,0,0,24,0,0,0,27,0,0,0,28,0,0,0,31,0,0,0,32,0,0,0,35,0,0,0,36,0,0,0,39,0,0,0,40,0,0,0,43,0,0,0,44,0,0,0,0,0,0,0,45,0,0,0,46,0,0,0,49,0,0,0,50,0,0,0,53,0,0,0,54,0,0,0,57,0,0,0,58,0,0,0,61,0,0,0,62,0,0,0,65,0,0,0,66,0,0,0,69,0,0,0,70,0,0,0,73,0,0,0,74,0,0,0,77,0,0,0,78,0,0,0,81,0,0,0,82,0,0,0,0,0,0,0,47,0,0,0,48,0,0,0,51,0,0,0,52,0,0,0,55,0,0,0,56,0,0,0,59,0,0,0,60,0,0,0,63,0,0,0,64,0,0,0,67,0,0,0,68,0,0,0,71,0,0,0,72,0,0,0,75,0,0,0,76,0,0,0,79,0,0,0,80,0,0,0,83,0,0,0,84,0,0,0,0,0,0,0,85,0,0,0,86,0,0,0,89,0,0,0,90,0,0,0,93,0,0,0,94,0,0,0,97,0,0,0,98,0,0,0,101,0,0,0,102,0,0,0,105,0,0,0,106,0,0,0,109,0,0,0,110,0,0,0,113,0,0,0,114,0,0,0,117,0,0,0,118,0,0,0,121,0,0,0,122,0,0,0,125,0,0,0,126,0,0,0,0,0,0,0,87,0,0,0,88,0,0,0,91,0,0,0,92,0,0,0,95,0,0,0,96,0,0,0,99,0,0,0,100,0,0,0,103,0,0,0,104,0,0,0,107,0,0,0,108,0,0,0,111,0,0,0,112,0,0,0,115,0,0,0,116,0,0,0,119,0,0,0,120,0,0,0,123,0,0,0,124,0,0,0,127,0,0,0,128,0,0,0,0,0,0,0,129,0,0,0,130,0,0,0,133,0,0,0,134,0,0,0,137,0,0,0,138,0,0,0,141,0,0,0,142,0,0,0,145,0,0,0,146,0,0,0,149,0,0,0,150,0,0,0,153,0,0,0,154,0,0,0,157,0,0,0,158,0,0,0,161,0,0,0,162,0,0,0,165,0,0,0,166,0,0,0,169,0,0,0,170,0,0,0,173,0,0,0,174,0,0,0,0,0,0,0,131,0,0,0,132,0,0,0,135,0,0,0,136,0,0,0,139,0,0,0,140,0,0,0,143,0,0,0,144,0,0,0,147,0,0,0,148,0,0,0,151,0,0,0,152,0,0,0,155,0,0,0,156,0,0,0,159,0,0,0,160,0,0,0,163,0,0,0,164,0,0,0,167,0,0,0,168,0,0,0,171,0,0,0,172,0,0,0,175,0,0,0,176,0,0,0,0,0,0,0,177,16,0,0,178,16,0,0,0,0,0,0,179,16,0,0,180,16,0,0,255,255,255,255,88,5,0,0,32,5,0,0,192,5,0,0,0,6,0,0,32,5,0,0,64,5,0,0,96,5,0,0,192,5,0,0,136,6,0,0,136,6,0,0,168,7,0,0,80,8,0,0,128,8,0,0,128,8,0,0,144,9,0,0,176,9,0,0,176,9,0,0,224,9,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,3,0,0,112,3,0,0,216,3,0,0,128,5,0,0,176,5,0,0,64,6,0,0,160,6,0,0,224,8,0,0,224,8,0,0,64,9,0,0,240,9,0,0,32,10,0,0,80,10,0,0,128,10,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,11,0,0,208,11,0,0,32,11,0,0,32,11,0,0,216,11,0,0,80,11,0,0,216,11,0,0,32,11,0,0,224,11,0,0,64,11,0,0,128,11,0,0,24,10,0,0,8,10,0,0,8,10,0,0,128,9,0,0,224,8,0,0,128,7,0,0,144,7,0,0,80,6,0,0,0,6,0,0,208,5,0,0,160,5,0,0,112,5,0,0,144,5,0,0,224,5,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,5,0,0,208,5,0,0,224,5,0,0,200,5,0,0,40,5,0,0,32,5,0,0,216,5,0,0,224,5,0,0,216,5,0,0,64,5,0,0,112,5,0,0,160,5,0,0,88,6,0,0,152,6,0,0,16,7,0,0,184,7,0,0,224,8,0,0,224,8,0,0,216,8,0,0,24,8,0,0,232,8,0,0,32,8,0,0,224,8,0,0,72,8,0,0,72,8,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,2,0,0,128,2,0,0,0,7,0,0,144,7,0,0,144,7,0,0,232,7,0,0,232,7,0,0,208,8,0,0,32,9,0,0,80,9,0,0,208,10,0,0,144,11,0,0,80,11,0,0,16,11,0,0,224,11,0,0,224,11,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,13,0,0,224,13,0,0,32,13,0,0,224,13,0,0,128,13,0,0,128,13,0,0,144,13,0,0,208,13,0,0,176,13,0,0,32,11,0,0,64,10,0,0,224,9,0,0,96,9,0,0,160,8,0,0,112,8,0,0,64,8,0,0,224,7,0,0,176,7,0,0,128,7,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,7,0,0,224,7,0,0,32,7,0,0,224,7,0,0,64,7,0,0,192,7,0,0,48,7,0,0,208,7,0,0,64,7,0,0,192,7,0,0,48,7,0,0,208,7,0,0,32,7,0,0,224,7,0,0,32,7,0,0,224,7,0,0,32,7,0,0,224,7,0,0,32,7,0,0,224,7,0,0,48,7,0,0,208,7,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,8,0,0,0,12,0,0,0,16,0,0,0,20,0,0,0,24,0,0,0,28,0,0,0,0,2,0,0,4,2,0,0,8,2,0,0,12,2,0,0,16,2,0,0,20,2,0,0,24,2,0,0,28,2,0,0,0,0,0,0,0,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,7,0,0,0,0,0,0,0,2,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,4,0,0,0,4,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,5,0,0,0,3,0,0,0,5,0,0,0,1,0,0,0,5,0,0,0,3,0,0,0,5,0,0,0,3,0,0,0,1,0,0,0,5,0,0,0,1,0,0,0,5,0,0,0,5,0,0,0,3,0,0,0,5,0,0,0,3,0,0,0,7,6,5,4,3,2,1,0,0,7,6,3,4,5,2,1,0,32,5,0,4,3,7,1,2,6,164,5,0,4,3,7,1,2,6,140,2,3,1,7,4,6,0,5,110,2,3,4,7,1,6,0,5,78,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,0,0,56,0,0,0,52,0,0,0,60,0,0,0,64,0,0,0,72,0,0,0,68,0,0,0,76,0,0,0,80,0,0,0,88,0,0,0,84,0,0,0,92,0,0,0,96,0,0,0,104,0,0,0,100,0,0,0,108,0,0,0,112,0,0,0,120,0,0,0,116,0,0,0,124,0,0,0,128,0,0,0,136,0,0,0,132,0,0,0,140,0,0,0,6,2,4,5,1,3,0,7,39,14,28,21,27,23,10,15,22,20,35,11,34,38,8,36,33,19,26,12,25,29,37,16,9,32,24,31,30,18,13,17,67,0,0,0,66,0,0,0,65,0,0,0,64,0,0,0,3,0,0,0,2,0,0,0,1,0,0,0,0,0,0,0,32,64,128,128,0,0,0,0,0,0,7,0,248,15,255,15,8,7,6,4,0,2,3,5,1,9,0,0,0,0,0,0,65,84,81,20,5,16,1,85,68,17,0,80,21,64,4,69,80,17,64,85,81,20,69,4,84,21,16,5,68,1,0,65,68,17,0,80,65,84,4,20,21,64,81,85,5,16,1,69,16,80,84,85,1,68,64,4,20,17,0,65,69,21,81,5,20,65,1,68,4,80,81,69,17,64,84,21,16,0,85,5,1,5,65,69,84,80,85,16,17,21,81,20,68,64,4,0,5,85,0,80,17,64,84,20,69,81,16,4,68,1,65,21,85,80,21,16,1,4,65,68,69,64,5,0,17,20,81,84,3,3,5,7,133,0,133,133,128,128,6,3,3,0,0,129,131,135,3,135,6,0,6,4,2,0,132,132,4,0,1,131,130,130,132,2,4,0,0,3,130,0,6,128,3,0,129,7,6,6,130,129,133,0,4,7,129,5,4,0,3,0,130,132,7,7,128,7,7,0,133,134,0,7,6,4,133,0,134,133,129,131,2,2,135,0,134,3,4,6,128,5,135,0,129,129,1,1,0,7,7,0,1,1,7,7,6,0,6,0,7,7,128,135,129,135,131,0,132,1,1,134,134,128,134,0,134,134,3,3,5,7,133,0,133,133,128,128,6,3,3,0,0,129,131,135,3,135,6,0,6,4,2,0,132,132,4,0,1,131,130,130,132,2,4,0,0,3,130,0,6,128,3,0,129,7,6,6,130,129,133,0,4,7,129,5,4,0,3,0,130,132,7,7,128,7,7,0,133,134,0,7,6,4,133,0,134,133,129,131,2,2,135,0,134,3,4,6,128,5,135,0,129,129,1,1,0,7,7,0,1,1,7,7,6,0,6,0,7,7,128,135,129,135,131,0,132,1,1,134,134,128,134,0,134,134,96,0,0,0,48,0,0,0,64,0,0,0,0,0,0,0,160,0,0,0,40,0,0,0,80,0,0,0,20,0,0,0,0,0,2,0,4,0,6,0,7,0,3,0,5,0,1,0,6,0,0,0,2,0,4,0,1,0,5,0,3,0,0,0,2,0,4,0,6,0,3,0,5,0,6,0,0,0,2,0,4,0,1,0,1,0,5,0,3,0,7,0,7,0,7,0,0,0,128,1,0,0,0,1,8,0,128,0,0,0,128,0,8,0,0,0,0,0,0,0,123,130,240,188,127,29,162,197,42,250,85,238,26,208,89,118,94,117,121,22,165,246,132,237,15,46,242,54,97,172,205,171,1,59,1,135,115,171,206,93,212,29,104,42,53,234,19,39,0,170,70,54,110,101,128,126,25,226,150,171,172,165,108,99,74,111,135,246,106,172,56,226,31,135,249,170,245,65,96,166,66,185,48,242,195,28,78,75,8,16,66,50,191,178,197,15,122,171,151,246,231,179,70,248,236,43,125,95,177,16,3,228,15,34,223,141,16,102,167,126,150,189,90,175,170,67,223,16,124,4,226,157,102,215,240,2,88,138,85,23,22,226,226,82,175,217,249,13,89,112,134,60,5,209,82,167,240,191,23,208,35,21,254,35,242,128,96,111,149,137,103,101,201,14,252,22,214,138,159,37,44,15,45,228,81,178,168,24,58,93,102,160,159,176,88,234,120,114,8,106,144,182,164,245,8,25,96,78,146,189,241,5,103,79,36,153,105,29,12,109,231,116,136,34,45,21,122,162,55,169,160,176,44,251,39,229,79,182,205,117,220,57,206,111,31,254,204,181,230,218,216,238,133,238,47,4,6,0,6,0,5,1,5,1,4,2,6,1,2,4,5,0,4,6,1,5,0,6,2,5,0,2,0,2,1,4,1,4,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,64,0,0,0,65,0,0,0,66,0,0,0,67,0,0,0,68,0,0,0,69,0,0,0,70,0,0,0,71,0,0,0,0,0,192,0,0,0,128,0,0,0,64,0,0,0,0,0,32,0,160,128,168,160,136,128,32,0,160,128,168,160,136,128,32,0,160,128,168,160,136,128,136,8,128,0,160,128,168,136,136,8,128,0,160,128,168,136,32,0,160,128,168,160,136,128,136,8,128,0,160,128,168,136,40,168,8,136,136,128,8,0,32,0,160,128,168,160,136,128,136,8,128,0,160,128,168,136,136,8,128,0,160,128,168,136,32,0,160,128,168,160,136,128,136,8,128,0,160,128,168,136,40,168,8,136,136,128,8,0,32,0,160,128,168,160,136,128,136,8,128,0,160,128,168,136,136,168,128,160,136,8,128,0,40,168,8,136,160,168,128,136,168,160,40,32,168,160,40,32,40,168,8,136,160,168,128,136,40,8,168,136,40,8,168,136,40,168,8,136,136,8,128,0,40,8,168,136,40,8,168,136,40,168,8,136,168,160,40,32,136,8,128,0,136,168,128,160,160,168,128,136,40,168,8,136,168,160,40,32,136,168,128,160,168,160,40,32,40,168,8,136,40,8,168,136,136,168,128,160,40,8,168,136,40,8,168,136,136,168,128,160,136,168,128,160,168,160,40,32,40,8,168,136,160,128,168,136,160,128,168,136,8,136,40,168,40,168,32,160,160,128,168,136,160,128,168,136,160,168,32,40,160,168,32,40,160,128,168,136,32,0,160,128,40,168,32,160,32,0,160,128,160,168,32,40,160,168,32,40,40,168,32,160,160,168,32,40,32,0,160,128,128,136,160,168,128,136,160,168,128,136,160,168,160,168,32,40,160,128,168,136,128,136,160,168,40,168,32,160,32,0,160,128,128,136,160,168,128,136,160,168,32,0,160,128,160,168,32,40,160,128,168,136,128,136,160,168,40,168,32,160,0,0,0,0,2,0,0,0,4,0,0,0,2,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,2,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,2,0,0,0,4,0,0,0,2,0,0,0,7,6,5,4,3,2,1,0,0,7,6,5,4,3,2,1,0,40,6,1,3,2,5,7,0,4,150,6,1,5,2,3,7,0,4,190,0,3,7,6,4,2,1,5,213,0,3,4,6,7,2,1,5,221,0,0,8,136,0,128,160,32,128,0,168,160,40,32,136,168,128,160,136,128,8,0,40,8,168,136,136,168,128,160,40,8,168,136,136,168,128,160,160,32,128,0,168,160,40,32,168,160,40,32,136,128,8,0,136,168,128,160,136,168,128,160,136,168,128,160,160,32,128,0,160,32,128,0,8,136,0,128,40,8,168,136,136,168,128,160,136,128,8,0,136,168,128,160,40,8,168,136,136,168,128,160,136,168,128,160,136,168,128,160,136,168,128,160,136,128,8,0,136,128,8,0,8,136,0,128,40,8,168,136,3,0,0,0,2,0,0,0,1,0,0,0,0,0,0,0,11,0,0,0,10,0,0,0,9,0,0,0,8,0,0,0,19,0,0,0,18,0,0,0,17,0,0,0,16,0,0,0,27,0,0,0,26,0,0,0,25,0,0,0,24,0,0,0,136,168,128,160,160,128,168,136,136,168,128,160,136,128,8,0,160,128,168,136,136,168,128,160,136,168,128,160,136,128,8,0,160,128,168,136,136,128,8,0,136,128,8,0,136,128,8,0,160,128,168,136,136,128,8,0,136,128,8,0,40,8,168,136,160,32,168,40,136,168,128,160,160,32,168,40,136,168,128,160,160,32,168,40,136,168,128,160,136,168,128,160,40,8,168,136,40,168,8,136,160,32,168,40,160,32,168,40,40,168,8,136,40,168,8,136,160,32,168,40,40,8,168,136,40,168,8,136,1,0,0,0,2,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,14,12,10,8,7,5,3,1,15,13,11,9,6,4,2,0,64,65,68,21,5,81,84,85,80,0,1,4,255,16,17,20,69,81,85,68,64,17,5,65,16,20,84,80,21,4,0,1,17,20,16,0,68,5,255,4,69,21,85,80,255,1,84,81,20,1,17,16,80,21,0,64,4,81,69,5,85,84,255,68,4,16,255,64,21,65,80,80,17,255,20,0,81,69,85,1,68,69,0,81,255,255,21,17,1,16,4,85,5,64,80,65,81,0,1,5,4,85,84,80,65,255,17,21,20,16,68,64,5,4,81,1,255,255,85,255,0,80,21,20,68,65,64,84,48,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,48,0,0,0,0,0,0,0,8,0,0,2,0,0,0,2,8,0,0,1,0,0,0,1,8,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,8,0,0,1,0,0,0,1,8,0,0,2,0,0,0,2,130,199,0,44,108,0,159,199,0,41,105,0,139,199,0,0,32,40,0,8,128,0,160,32,32,40,0,8,160,168,32,40,40,8,168,136,160,128,168,136,160,168,32,40,160,128,168,136,32,40,0,8,40,8,168,136,160,168,32,40,160,168,32,40,160,128,168,136,40,8,168,136,160,168,32,40,40,8,168,136,128,0,160,32,128,0,160,32,160,32,168,40,160,168,32,40,160,32,168,40,160,128,168,136,160,128,168,136,160,128,168,136,128,0,160,32,32,40,0,8,160,168,32,40,160,32,168,40,128,0,160,32,160,128,168,136,160,168,32,40,160,32,168,40,40,8,168,136,136,128,8,0,40,8,168,136,40,168,8,136,136,128,8,0,136,8,128,0,136,8,128,0,40,168,8,136,40,8,168,136,136,128,8,0,136,128,8,0,136,128,8,0,136,8,128,0,136,8,128,0,160,128,168,136,160,128,168,136,128,160,0,32,40,8,168,136,40,168,8,136,40,8,168,136,128,160,0,32,128,160,0,32,40,168,8,136,128,160,0,32,160,128,168,136,40,8,168,136,128,160,0,32,160,128,168,136,160,128,168,136,128,160,0,32,160,128,168,136,160,128,168,136,58,1,8,133,0,0,203,252,0,3,144,69,229,9,78,117,0,1,3,255,255,2,5,255,255,5,0,0,0,0,0,0,3,5,1,2,0,0,0,0,0,3,4,5,0,0,0,0,34,0,0,0,9,0,0,0,32,0,0,0,24,0,0,0,44,0,0,0,54,0,0,0,38,0,0,0,61,0,0,0,47,0,0,0,13,0,0,0,28,0,0,0,7,0,0,0,29,0,0,0,58,0,0,0,18,0,0,0,1,0,0,0,20,0,0,0,60,0,0,0,15,0,0,0,6,0,0,0,11,0,0,0,43,0,0,0,39,0,0,0,19,0,0,0,63,0,0,0,23,0,0,0,16,0,0,0,62,0,0,0,54,0,0,0,40,0,0,0,31,0,0,0,3,0,0,0,56,0,0,0,61,0,0,0,17,0,0,0,25,0,0,0,47,0,0,0,38,0,0,0,55,0,0,0,57,0,0,0,5,0,0,0,4,0,0,0,15,0,0,0,42,0,0,0,22,0,0,0,7,0,0,0,2,0,0,0,19,0,0,0,46,0,0,0,37,0,0,0,29,0,0,0,39,0,0,0,12,0,0,0,30,0,0,0,49,0,0,0,57,0,0,0,31,0,0,0,41,0,0,0,26,0,0,0,27,0,0,0,24,0,0,0,36,0,0,0,11,0,0,0,63,0,0,0,33,0,0,0,16,0,0,0,56,0,0,0,62,0,0,0,48,0,0,0,60,0,0,0,59,0,0,0,32,0,0,0,12,0,0,0,30,0,0,0,53,0,0,0,48,0,0,0,10,0,0,0,0,0,0,0,50,0,0,0,35,0,0,0,3,0,0,0,59,0,0,0,14,0,0,0,49,0,0,0,51,0,0,0,45,0,0,0,44,0,0,0,2,0,0,0,21,0,0,0,33,0,0,0,55,0,0,0,52,0,0,0,23,0,0,0,28,0,0,0,8,0,0,0,26,0,0,0,33,0,0,0,58,0,0,0,49,0,0,0,36,0,0,0,0,0,0,0,31,0,0,0,22,0,0,0,30,0,0,0,3,0,0,0,16,0,0,0,5,0,0,0,53,0,0,0,10,0,0,0,41,0,0,0,23,0,0,0,19,0,0,0,27,0,0,0,39,0,0,0,43,0,0,0,6,0,0,0,34,0,0,0,12,0,0,0,61,0,0,0,21,0,0,0,48,0,0,0,13,0,0,0,32,0,0,0,35,0,0,0,6,0,0,0,42,0,0,0,43,0,0,0,14,0,0,0,21,0,0,0,41,0,0,0,52,0,0,0,25,0,0,0,18,0,0,0,47,0,0,0,46,0,0,0,37,0,0,0,57,0,0,0,53,0,0,0,20,0,0,0,8,0,0,0,55,0,0,0,54,0,0,0,59,0,0,0,60,0,0,0,27,0,0,0,33,0,0,0,35,0,0,0,18,0,0,0,8,0,0,0,15,0,0,0,63,0,0,0,1,0,0,0,50,0,0,0,44,0,0,0,16,0,0,0,46,0,0,0,5,0,0,0,4,0,0,0,45,0,0,0,51,0,0,0,38,0,0,0,25,0,0,0,13,0,0,0,11,0,0,0,62,0,0,0,29,0,0,0,48,0,0,0,2,0,0,0,59,0,0,0,61,0,0,0,62,0,0,0,56,0,0,0,51,0,0,0,57,0,0,0,54,0,0,0,9,0,0,0,24,0,0,0,63,0,0,0,22,0,0,0,7,0,0,0,26,0,0,0,42,0,0,0,45,0,0,0,40,0,0,0,23,0,0,0,14,0,0,0,2,0,0,0,31,0,0,0,52,0,0,0,28,0,0,0,44,0,0,0,17,0,0,0,0,0,96,0,0,0,64,0,0,0,32,0,0,0,0,0,64,0,0,0,16,0,0,0,32,0,0,0,32,0,0,0,16,0,0,0,64,0,0,0,32,0,0,0,32,0,0,0,128,0,0,0,16,0,0,0,64,0,0,0,32,0,0,0,32,0,0,0,64,0,0,0,64,0,0,0,32,0,0,0,0,1,0,0,16,0,0,0,128,0,0,0,32,0,0,0,64,0,0,0,64,0,0,0,128,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,85,0,0,0,6,0,0,0,5,0,0,0,1,0,0,0,0,0,0,0,7,0,0,0,4,0,0,0,2,0,0,0,3,0,0,0,148,0,0,0,7,0,0,0,6,0,0,0,4,0,0,0,2,0,0,0,0,0,0,0,5,0,0,0,1,0,0,0,3,0,0,0,141,0,0,0,1,0,0,0,4,0,0,0,2,0,0,0,3,0,0,0,0,0,0,0,6,0,0,0,7,0,0,0,5,0,0,0,154,0,0,0,4,0,0,0,3,0,0,0,5,0,0,0,6,0,0,0,0,0,0,0,2,0,0,0,1,0,0,0,7,0,0,0,114,0,0,0,4,0,0,0,3,0,0,0,7,0,0,0,0,0,0,0,5,0,0,0,6,0,0,0,1,0,0,0,2,0,0,0,255,0,0,0,1,0,0,0,7,0,0,0,2,0,0,0,3,0,0,0,6,0,0,0,4,0,0,0,5,0,0,0,0,0,0,0,6,0,0,0,6,0,0,0,5,0,0,0,3,0,0,0,2,0,0,0,4,0,0,0,1,0,0,0,0,0,0,0,7,0,0,0,197,0,0,0,3,0,0,0,5,0,0,0,1,0,0,0,4,0,0,0,2,0,0,0,7,0,0,0])
.concat([0,0,0,0,6,0,0,0,236,0,0,0,4,0,0,0,7,0,0,0,5,0,0,0,1,0,0,0,6,0,0,0,0,0,0,0,2,0,0,0,3,0,0,0,137,0,0,0,3,0,0,0,5,0,0,0,0,0,0,0,6,0,0,0,1,0,0,0,2,0,0,0,7,0,0,0,4,0,0,0,92,0,0,0,1,0,0,0,3,0,0,0,0,0,0,0,7,0,0,0,5,0,0,0,2,0,0,0,4,0,0,0,6,0,0,0,63,0,0,0,7,0,0,0,3,0,0,0,0,0,0,0,2,0,0,0,4,0,0,0,6,0,0,0,1,0,0,0,5,0,0,0,87,0,0,0,6,0,0,0,4,0,0,0,7,0,0,0,2,0,0,0,1,0,0,0,5,0,0,0,3,0,0,0,0,0,0,0,247,0,0,0,6,0,0,0,3,0,0,0,7,0,0,0,0,0,0,0,5,0,0,0,4,0,0,0,2,0,0,0,1,0,0,0,58,0,0,0,6,0,0,0,1,0,0,0,3,0,0,0,2,0,0,0,7,0,0,0,4,0,0,0,5,0,0,0,0,0,0,0,172,0,0,0,1,0,0,0,6,0,0,0,3,0,0,0,5,0,0,0,0,0,0,0,7,0,0,0,4,0,0,0,2,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,0,0,0,0,1,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,1,0,0,0,255,255,255,255,1,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,1,0,0,0,0,0,0,0,1,0,0,0,255,255,255,255,1,0,0,0,1,0,0,0,0,0,0,0,255,255,255,255,1,0,0,0,1,0,0,0,1,0,0,0,241,249,245,253,241,241,61,61,115,251,119,255,115,243,63,63,223,255,255,255,219,255,251,255,255,255,255,255,251,255,251,255,127,127,187,119,119,119,190,246,127,127,187,119,119,119,190,246,255,255,253,253,253,253,239,239,255,255,253,253,253,253,239,239,84,21,68,81,16,65,85,20,69,80,17,64,84,21,68,81,16,65,85,20,69,80,17,64,84,21,68,81,16,65,85,20,84,21,68,81,16,65,85,20,69,80,17,64,84,21,68,81,16,65,85,20,69,80,17,64,84,21,68,81,16,65,85,20,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,3,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,5,0,0,0,5,0,0,0,6,0,0,0,6,0,0,0,6,0,0,0,7,0,0,0,7,0,0,0,8,0,0,0,8,0,0,0,9,0,0,0,9,0,0,0,9,0,0,0,10,0,0,0,10,0,0,0,11,0,0,0,11,0,0,0,11,0,0,0,12,0,0,0,12,0,0,0,13,0,0,0,8,0,0,0,8,0,0,0,9,0,0,0,9,0,0,0,9,0,0,0,10,0,0,0,10,0,0,0,11,0,0,0,11,0,0,0,12,0,0,0,12,0,0,0,12,0,0,0,13,0,0,0,13,0,0,0,14,0,0,0,14,0,0,0,14,0,0,0,15,0,0,0,15,0,0,0,16,0,0,0,16,0,0,0,17,0,0,0,17,0,0,0,17,0,0,0,18,0,0,0,18,0,0,0,19,0,0,0,19,0,0,0,19,0,0,0,20,0,0,0,20,0,0,0,21,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,3,0,0,0,4,0,0,0,4,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,6,0,0,0,6,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,8,0,0,0,8,0,0,0,9,0,0,0,9,0,0,0,10,0,0,0,10,0,0,0,10,0,0,0,11,0,0,0,11,0,0,0,12,0,0,0,12,0,0,0,12,0,0,0,13,0,0,0,8,0,0,0,8,0,0,0,9,0,0,0,9,0,0,0,10,0,0,0,10,0,0,0,10,0,0,0,11,0,0,0,11,0,0,0,12,0,0,0,12,0,0,0,13,0,0,0,13,0,0,0,13,0,0,0,14,0,0,0,14,0,0,0,15,0,0,0,15,0,0,0,15,0,0,0,16,0,0,0,16,0,0,0,17,0,0,0,17,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,19,0,0,0,19,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,21,0,0,0,4,81,64,1,85,68,5,80,65,0,84,69,4,81,64,1,85,68,5,80,65,0,84,69,4,81,64,1,85,68,5,80,4,81,64,1,85,68,5,80,65,0,84,69,4,81,64,1,85,68,5,80,65,0,84,69,4,81,64,1,85,68,5,80,0,0,0,0,8,0,0,0,16,0,0,0,24,0,0,0,32,0,0,0,40,0,0,0,48,0,0,0,56,0,0,0,0,0,8,0,8,0,8,0,16,0,8,0,24,0,8,0,32,0,8,0,40,0,8,0,48,0,8,0,56,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,0,0,4,0,1,0,4,0,2,0,4,0,3,0,4,0,4,0,4,0,5,0,4,0,6,0,4,0,7,0,4,0,0,0,12,0,0,0,8,0,0,0,4,0,0,0,0,0,16,4,8,128,224,8,216,129,48,10,24,129,208,11,216,128,32,12,32,129,88,14,104,129,168,14,152,129,0,16,32,128,8,16,16,128,136,18,152,128,72,19,72,128,136,22,136,128,176,22,136,129,216,22,200,128,248,22,200,129,168,25,168,128,184,25,168,129,96,32,72,129,8,33,24,128,160,33,160,129,152,34,160,128,224,35,232,128,24,36,0,128,72,36,88,128,112,36,64,129,136,36,128,128,176,36,128,129,216,36,192,128,248,36,192,129,72,39,80,128,128,39,144,128,184,39,144,129,0,40,40,128,32,43,0,129,48,43,16,129,240,43,208,129,192,44,208,128,216,44,224,128,240,44,224,129,96,45,96,129,0,0,0,0,8,0,0,0,16,0,0,0,24,0,0,0,32,0,0,0,40,0,0,0,48,0,0,0,56,0,0,0,64,0,0,0,72,0,0,0,80,0,0,0,88,0,0,0,96,0,0,0,104,0,0,0,112,0,0,0,120,0,0,0,135,0,0,0,134,0,0,0,133,0,0,0,132,0,0,0,131,0,0,0,130,0,0,0,129,0,0,0,128,0,0,0,7,0,0,0,6,0,0,0,5,0,0,0,4,0,0,0,3,0,0,0,2,0,0,0,1,0,0,0,0,0,0,0,0,0,160,0,0,0,0,0,0,0,80,0,0,0,240,0,4,0,2,0,0,0,2,0,4,0,0,0,0,0,0,0,0,225,195,252,236,248,52,255,23,240,238,239,172,194,28,7,0,225,195,252,236,248,52,255,23,240,238,239,172,194,28,7,0,0,0,0,71,0,0,0,151,0,0,0,222,0,0,0,0,0,0,0,16,0,0,0,32,0,0,0,48,0,0,0,64,0,0,0,144,0,0,0,160,0,0,0,176,0,0,0,160,0,0,0,208,0,0,0,16,0,0,0,0,0,0,0,24,0,0,0,8,0,0,0,6,4,2,0,4,6,2,0,2,4,6,0,0,4,2,6,6,2,4,0,6,0,2,4,6,4,0,2,2,6,4,0,4,2,6,0,4,6,0,2,6,0,4,2,0,6,4,2,4,0,6,2,0,4,6,2,6,2,0,4,2,6,0,4,0,6,2,4,2,0,6,4,0,2,6,4,4,2,0,6,2,4,0,6,4,0,2,6,2,0,4,6,0,2,4,6,8,136,0,128,160,128,168,136,128,0,160,32,136,128,8,0,160,128,168,136,40,8,32,0,40,8,32,0,160,128,168,136,8,136,0,128,128,0,160,32,128,0,160,32,136,128,8,0,40,8,32,0,40,8,32,0,40,8,32,0,136,128,8,0,8,136,0,128,168,136,40,8,168,136,40,8,128,0,160,32,40,8,32,0,136,128,8,0,168,136,40,8,136,128,8,0,8,136,0,128,128,0,160,32,168,136,40,8,128,0,160,32,40,8,32,0,40,8,32,0,8,136,0,128,136,128,8,0,5,0,0,0,10,0,0,0,14,0,0,0,9,0,0,0,4,0,0,0,0,0,0,0,15,0,0,0,6,0,0,0,1,0,0,0,8,0,0,0,3,0,0,0,2,0,0,0,12,0,0,0,7,0,0,0,13,0,0,0,11,0,0,0,5,0,0,0,12,0,0,0,7,0,0,0,2,0,0,0,13,0,0,0,11,0,0,0,9,0,0,0,14,0,0,0,4,0,0,0,1,0,0,0,6,0,0,0,10,0,0,0,8,0,0,0,0,0,0,0,15,0,0,0,3,0,0,0,4,0,0,0,10,0,0,0,2,0,0,0,0,0,0,0,6,0,0,0,9,0,0,0,12,0,0,0,1,0,0,0,11,0,0,0,7,0,0,0,15,0,0,0,8,0,0,0,13,0,0,0,5,0,0,0,14,0,0,0,3,0,0,0,14,0,0,0,11,0,0,0,12,0,0,0,7,0,0,0,4,0,0,0,5,0,0,0,2,0,0,0,10,0,0,0,1,0,0,0,15,0,0,0,0,0,0,0,9,0,0,0,8,0,0,0,6,0,0,0,13,0,0,0,3,0,0,0,0,0,0,0,96,0,0,0,224,0,0,0,254,0,0,0,254,0,0,0,254,0,0,0,254,0,0,0,254,0,0,0,24,0,0,0,28,0,0,0,0,0,0,0,4,0,0,0,8,0,0,0,12,0,0,0,16,0,0,0,20,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,85,5,65,20,80,0,21,81,1,68,16,85,5,17,84,4,64,21,81,1,20,80,0,69,17,84,4,16,85,5,65,20,85,5,65,20,80,0,21,81,1,68,16,85,5,17,84,4,64,21,81,1,20,80,0,69,17,84,4,16,85,5,65,20,2,0,0,0,5,0,0,0,1,0,0,0,5,0,0,0,1,0,0,0,5,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,7,0,0,0,3,0,0,0,7,0,0,0,3,0,0,0,7,0,0,0,3,0,0,0,6,0,0,0,2,0,0,0,6,0,0,0,2,0,0,0,6,0,0,0,1,0,0,0,5,0,0,0,1,0,0,0,5,0,0,0,1,0,0,0,5,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,10,0,0,0,13,0,0,0,9,0,0,0,13,0,0,0,9,0,0,0,13,0,0,0,8,0,0,0,12,0,0,0,8,0,0,0,12,0,0,0,8,0,0,0,12,0,0,0,15,0,0,0,11,0,0,0,15,0,0,0,11,0,0,0,15,0,0,0,11,0,0,0,14,0,0,0,10,0,0,0,14,0,0,0,10,0,0,0,14,0,0,0,9,0,0,0,13,0,0,0,9,0,0,0,13,0,0,0,9,0,0,0,13,0,0,0,8,0,0,0,12,0,0,0,8,0,0,0,3,0,0,0,7,0,0,0,3,0,0,0,7,0,0,0,3,0,0,0,7,0,0,0,2,0,0,0,6,0,0,0,2,0,0,0,6,0,0,0,2,0,0,0,5,0,0,0,1,0,0,0,5,0,0,0,1,0,0,0,5,0,0,0,1,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,8,0,0,0,3,0,0,0,7,0,0,0,3,0,0,0,7,0,0,0,3,0,0,0,6,0,0,0,2,0,0,0,6,0,0,0,2,0,0,0,11,0,0,0,15,0,0,0,11,0,0,0,15,0,0,0,11,0,0,0,15,0,0,0,10,0,0,0,14,0,0,0,10,0,0,0,14,0,0,0,10,0,0,0,13,0,0,0,9,0,0,0,13,0,0,0,9,0,0,0,13,0,0,0,9,0,0,0,12,0,0,0,8,0,0,0,12,0,0,0,8,0,0,0,12,0,0,0,16,0,0,0,11,0,0,0,15,0,0,0,11,0,0,0,15,0,0,0,11,0,0,0,14,0,0,0,10,0,0,0,14,0,0,0,10,0,0,0,0,69,17,1,68,16,85,5,65,20,4,64,21,81,1,68,16,0,69,17,84,4,64,21,5,65,20,80,0,69,17,1,0,69,17,1,68,16,85,5,65,20,4,64,21,81,1,68,16,0,69,17,84,4,64,21,5,65,20,80,0,69,17,1,0,32,0,0,64,180,255,0,75,164,99,70,240,145,234,98,1,0,0,0,0,0,0,0,3,0,0,0,2,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,9,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,1,0,0,0,0,0,0,0,3,0,0,0,2,0,0,0,8,0,0,0,9,0,0,0,3,0,0,0,2,0,0,0,1,0,0,0,0,0,0,0,6,0,0,0,7,0,0,0,4,0,0,0,5,0,0,0,8,0,0,0,9,0,0,0,6,0,0,0,7,0,0,0,4,0,0,0,5,0,0,0,3,0,0,0,2,0,0,0,1,0,0,0,0,0,0,0,8,0,0,0,9,0,0,0,128,33,0,0,0,24,0,0,128,52,0,0,0,43,0,0,0,62,0,0,128,71,0,0,0,81,0,0,128,90,0,0,0,100,0,0,128,109,0,0,128,31,0,0,128,28,0,0,0,39,0,0,0,36,0,0,128,43,0,0,128,46,0,0,0,51,0,0,0,54,0,0,128,58,0,0,128,61,0,0,0,0,0,0,0,0,16,0,4,0,0,0,4,0,16,0,10,0,16,0,10,0,0,0,14,0,16,0,14,0,0,0,1,112,10,0,234,20,255,0,75,164,99,70,240,145,234,98,0,0,0,0,7,0,0,0,14,0,0,0,20,0,0,0,25,0,0,0,30,0,0,0,34,0,0,0,38,0,0,0,42,0,0,0,46,0,0,0,49,0,0,0,52,0,0,0,54,0,0,0,57,0,0,0,59,0,0,0,61,0,0,0,0,7,14,20,25,30,34,38,42,46,49,52,54,57,59,61,172,10,0,0,0,8,0,0,104,6,0,0,84,5,0,0,148,4,0,0,0,4,0,0,144,3,0,0,52,3,0,0,232,2,0,0,172,2,0,0,120,2,0,0,72,2,0,0,36,2,0,0,0,2,0,0,224,1,0,0,200,1,0,0,176,1,0,0,152,1,0,0,136,1,0,0,116,1,0,0,100,1,0,0,84,1,0,0,72,1,0,0,60,1,0,0,48,1,0,0,36,1,0,0,28,1,0,0,16,1,0,0,8,1,0,0,0,1,0,0,248,0,0,0,240,0,0,0,236,0,0,0,228,0,0,0,220,0,0,0,216,0,0,0,212,0,0,0,204,0,0,0,200,0,0,0,196,0,0,0,192,0,0,0,188,0,0,0,184,0,0,0,180,0,0,0,176,0,0,0,172,0,0,0,168,0,0,0,164,0,0,0,160,0,0,0,156,0,0,0,152,0,0,0,148,0,0,0,144,0,0,0,140,0,0,0,136,0,0,0,128,0,0,0,120,0,0,0,112,0,0,0,104,0,0,0,96,0,0,0,88,0,0,0,80,0,0,0,72,0,0,0,64,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,0,0,0,0,0,255,0,0,240,255,0,0,252,255,0,0,0,0,0,0,2,0,0,0,8,0,0,0,10,0,0,0,0,0,0,0,1,0,0,0,4,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,32,0,0,0,48,0,0,0,64,0,0,0,80,0,0,0,96,0,0,0,112,0,0,0,128,0,0,0,144,0,0,0,160,0,0,0,176,0,0,0,192,0,0,0,208,0,0,0,224,0,0,0,240,0,0,0,7,1,0,0,6,1,0,0,5,1,0,0,4,1,0,0,3,1,0,0,2,1,0,0,1,1,0,0,0,1,0,0,7,0,0,0,6,0,0,0,5,0,0,0,4,0,0,0,3,0,0,0,2,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,192,0,8,0,192,0,4,0,0,0,0,0,0,0,4,128,0,0,0,128,0,0,0,0,0,0,8,0,0,0,16,0,0,0,24,0,0,0,32,0,0,0,40,0,0,0,48,0,0,0,56,0,0,0,64,0,0,0,72,0,0,0,80,0,0,0,88,0,0,0,96,0,0,0,104,0,0,0,112,0,0,0,120,0,0,0,135,0,0,0,134,0,0,0,133,0,0,0,132,0,0,0,131,0,0,0,130,0,0,0,129,0,0,0,128,0,0,0,7,0,0,0,6,0,0,0,5,0,0,0,4,0,0,0,3,0,0,0,2,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,128,0,0,0,192,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,10,0,0,0,4,0,0,0,5,0,0,0,13,0,0,0,7,0,0,0,17,0,0,0,21,0,0,0,2,0,0,0,18,0,0,0,9,0,0,0,15,0,0,0,3,0,0,0,6,0,0,0,11,0,0,0,19,0,0,0,8,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,20,0,0,0,20,0,0,0,14,0,0,0,14,0,0,0,16,0,0,0,16,0,0,0,12,0,0,0,12,0,0,0,64,0,0,0,65,0,0,0,66,0,0,0,67,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,192,0,0,0,193,0,0,0,194,0,0,0,195,0,0,0,128,0,0,0,129,0,0,0,130,0,0,0,131,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,96,0,0,0,64,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,32,0,0,0,48,0,0,0,64,0,0,0,80,0,0,0,96,0,0,0,112,0,0,0,128,0,0,0,144,0,0,0,160,0,0,0,176,0,0,0,192,0,0,0,208,0,0,0,224,0,0,0,240,0,0,0,0,0,0,0,16,0,0,0,32,0,0,0,48,0,0,0,0,0,0,0,64,0,0,0,128,0,0,0,192,0,0,0,0,1,0,0,64,1,0,0,128,1,0,0,192,1,0,0,0,2,0,0,64,2,0,0,128,2,0,0,192,2,0,0,0,3,0,0,64,3,0,0,128,3,0,0,192,3,0,0,0,4,0,0,64,4,0,0,128,4,0,0,192,4,0,0,0,5,0,0,64,5,0,0,128,5,0,0,192,5,0,0,0,6,0,0,64,6,0,0,128,6,0,0,192,6,0,0,0,7,0,0,64,7,0,0,128,7,0,0,192,7,0,0,240,0,0,0,224,0,0,0,208,0,0,0,192,0,0,0,176,0,0,0,160,0,0,0,144,0,0,0,128,0,0,0,112,0,0,0,96,0,0,0,80,0,0,0,64,0,0,0,48,0,0,0,32,0,0,0,16,0,0,0,0,0,0,0,112,1,0,0,96,1,0,0,80,1,0,0,64,1,0,0,48,1,0,0,32,1,0,0,16,1,0,0,0,1,0,0,112,0,0,0,96,0,0,0,80,0,0,0,64,0,0,0,48,0,0,0,32,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,64,0,0,0,96,0,0,0,128,0,0,0,160,0,0,0,192,0,0,0,224,0,0,0,0,1,0,0,32,1,0,0,64,1,0,0,96,1,0,0,128,1,0,0,160,1,0,0,192,1,0,0,224,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,16,0,0,0,24,0,0,0,32,0,0,0,40,0,0,0,48,0,0,0,56,0,0,0,64,0,0,0,72,0,0,0,80,0,0,0,88,0,0,0,96,0,0,0,104,0,0,0,112,0,0,0,120,0,0,0,0,0,0,0,128,0,0,0,0,1,0,0,128,1,0,0,0,2,0,0,128,2,0,0,0,3,0,0,128,3,0,0,0,4,0,0,128,4,0,0,0,5,0,0,128,5,0,0,0,6,0,0,128,6,0,0,0,7,0,0,128,7,0,0,56,0,0,0,48,0,0,0,40,0,0,0,32,0,0,0,24,0,0,0,16,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,32,0,0,0,48,0,0,0,64,0,0,0,80,0,0,0,96,0,0,0,112,0,0,0,128,0,0,0,144,0,0,0,160,0,0,0,176,0,0,0,192,0,0,0,208,0,0,0,224,0,0,0,240,0,0,0,0,1,0,0,16,1,0,0,32,1,0,0,48,1,0,0,64,1,0,0,80,1,0,0,96,1,0,0,112,1,0,0,128,1,0,0,144,1,0,0,160,1,0,0,176,1,0,0,192,1,0,0,208,1,0,0,224,1,0,0,240,1,0,0,0,0,0,0,16,0,0,0,32,0,0,0,48,0,0,0,64,0,0,0,80,0,0,0,96,0,0,0,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,9,0,0,0,10,0,0,0,11,0,0,0,12,0,0,0,13,0,0,0,14,0,0,0,15,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,0,2,0,0,1,2,0,0,2,2,0,0,3,2,0,0,16,2,0,0,17,2,0,0,18,2,0,0,19,2,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,64,0,0,0,65,0,0,0,66,0,0,0,67,0,0,0,128,0,0,0,129,0,0,0,130,0,0,0,131,0,0,0,192,0,0,0,193,0,0,0,194,0,0,0,195,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,8,0,0,0,9,0,0,0,10,0,0,0,11,0,0,0,0,1,0,0,1,1,0,0,2,1,0,0,3,1,0,0,8,1,0,0,9,1,0,0,10,1,0,0,11,1,0,0,0,0,128,1,0,0,0,1,0,0,128,0,0,0,0,0,8,0,128,1,8,0,0,1,8,0,128,0,8,0,0,0,0,0,0,2,1,0,0,2,2,0,0,2,3,0,0,2,4,0,0,2,5,0,0,2,6,0,0,2,7,0,0,2,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,3,0,0,0,2,0,0,0,1,0,0,0,0,0,0,0,19,0,0,0,18,0,0,0,17,0,0,0,16,0,0,0,3,2,0,0,2,2,0,0,1,2,0,0,0,2,0,0,19,2,0,0,18,2,0,0,17,2,0,0,16,2,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,9,0,0,0,10,0,0,0,11,0,0,0,12,0,0,0,13,0,0,0,14,0,0,0,15,0,0,0,11,1,0,0,10,1,0,0,9,1,0,0,8,1,0,0,3,1,0,0,2,1,0,0,1,1,0,0,0,1,0,0,11,0,0,0,10,0,0,0,9,0,0,0,8,0,0,0,3,0,0,0,2,0,0,0,1,0,0,0,0,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,132,0,0,0,133,0,0,0,134,0,0,0,135,0,0,0,128,0,0,0,129,0,0,0,130,0,0,0,131,0,0,0,4,1,0,0,0,1,0,0,132,1,0,0,128,1,0,0,4,0,0,0,0,0,0,0,132,0,0,0,128,0,0,0,64,0,0,0,65,0,0,0,66,0,0,0,67,0,0,0,128,0,0,0,129,0,0,0,130,0,0,0,131,0,0,0,192,0,0,0,193,0,0,0,194,0,0,0,195,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,0,0,0,0,4,0,16,0,0,0,16,0,12,0,0,0,8,0,0,0,12,0,16,0,8,0,16,0,20,0,0,0,16,0,0,0,20,0,16,0,16,0,16,0,28,0,0,0,24,0,0,0,28,0,16,0,24,0,16,0,3,0,0,0,2,0,0,0,1,0,0,0,0,0,0,0,131,0,0,0,130,0,0,0,129,0,0,0,128,0,0,0,3,1,0,0,2,1,0,0,1,1,0,0,0,1,0,0,131,1,0,0,130,1,0,0,129,1,0,0,128,1,0,0,0,0,0,0,2,0,0,0,4,0,0,0,6,0,0,0,8,0,0,0,10,0,0,0,12,0,0,0,14,0,0,0,128,0,0,0,130,0,0,0,132,0,0,0,134,0,0,0,136,0,0,0,138,0,0,0,140,0,0,0,142,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,0,128,0,0,1,128,0,0,2,128,0,0,3,128,0,0,4,128,0,0,5,128,0,0,6,128,0,0,7,128,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,0,128,0,0,1,128,0,0,2,128,0,0,3,128,0,0,7,0,0,0,6,0,0,0,5,0,0,0,4,0,0,0,3,0,0,0,2,0,0,0,1,0,0,0,0,0,0,0,7,0,0,0,6,0,0,0,5,0,0,0,4,0,0,0,3,0,0,0,2,0,0,0,1,0,0,0,0,0,0,0,135,0,0,0,134,0,0,0,133,0,0,0,132,0,0,0,131,0,0,0,130,0,0,0,129,0,0,0,128,0,0,0,0,0,0,0,0,0,128,0,8,0,0,0,8,0,128,0,16,0,0,0,16,0,128,0,24,0,0,0,24,0,128,0,16,0,0,0,20,0,0,0,24,0,0,0,28,0,0,0,0,0,0,0,4,0,0,0,8,0,0,0,12,0,0,0,48,0,0,0,52,0,0,0,56,0,0,0,60,0,0,0,32,0,0,0,36,0,0,0,40,0,0,0,44,0,0,0,8,0,0,0,12,0,0,0,0,0,0,0,4,0,0,0,24,0,0,0,28,0,0,0,16,0,0,0,20,0,0,0,40,0,0,0,44,0,0,0,32,0,0,0,36,0,0,0,56,0,0,0,60,0,0,0,48,0,0,0,52,0,0,0,0,0,128,0,1,0,128,0,2,0,128,0,3,0,128,0,4,0,128,0,5,0,128,0,6,0,128,0,7,0,128,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,32,0,128,0,33,0,128,0,34,0,128,0,35,0,128,0,36,0,128,0,37,0,128,0,38,0,128,0,39,0,128,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,8,0,0,0,9,0,0,0,10,0,0,0,11,0,0,0,0,2,0,0,1,2,0,0,2,2,0,0,3,2,0,0,8,2,0,0,9,2,0,0,10,2,0,0,11,2,0,0,0,4,0,0,1,4,0,0,2,4,0,0,3,4,0,0,8,4,0,0,9,4,0,0,10,4,0,0,11,4,0,0,0,6,0,0,1,6,0,0,2,6,0,0,3,6,0,0,8,6,0,0,9,6,0,0,10,6,0,0,11,6,0,0,7,1,0,0,6,1,0,0,5,1,0,0,4,1,0,0,3,1,0,0,2,1,0,0,1,1,0,0,0,1,0,0,7,0,0,0,6,0,0,0,5,0,0,0,4,0,0,0,3,0,0,0,2,0,0,0,1,0,0,0,0,0,0,0,64,0,0,0,65,0,0,0,66,0,0,0,67,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,0,64,0,0,1,64,0,0,2,64,0,0,3,64,0,0,4,64,0,0,5,64,0,0,6,64,0,0,7,64,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,0,64,0,0,1,64,0,0,2,64,0,0,3,64,0,0,0,0,0,0,0,0,32,0,0,0,64,0,0,0,96,0,4,0,1,0,0,0,1,0,4,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,12,0,0,0,8,0,0,0,4,128,0,0,0,128,0,0,4,0,0,0,0,0,0,0,0,0,4,0,4,0,4,0,0,0,0,0,4,0,0,0,0,0,16,0,0,0,0,0,0,0,24,0,0,0,8,0,48,0,0,0,16,0,0,0,32,0,0,0,0,0,0,0,0,0,32,0,4,0,32,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,12,0,0,0,24,0,0,0,36,0,0,0,48,0,0,0,0,0,0,0,16,0,0,0,32,0,0,0,0,0,4,0,2,0,0,0,2,0,4,0,0,0,4,0,192,0,0,0,192,0,4,0,128,0,0,0,128,0,4,0,64,0,0,0,64,0,4,0,0,0,0,0,0,0,8,0,0,0,12,0,0,0,0,0,0,0,4,0,0,0,0,0,96,0,0,0,32,0,0,0,64,0,0,0,0,0,4,0,0,0,0,0,0,0,4,0,16,0,0,0,16,0,0,0,0,0,0,0,8,0,0,0,16,0,0,0,24,0,0,0,64,0,0,0,192,0,0,0,64,1,0,0,192,1,0,0,128,0,4,0,128,0,0,0,0,0,4,0,0,0,4,0,8,0,0,0,8,0,4,0,0,0,0,0,0,0,4,0,128,0,0,0,128,0,4,0,64,0,0,0,64,0,4,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,16,0,0,0,24,0,0,0,0,0,4,0,0,0,12,0,0,0,0,0,0,0,8,0,0,0,96,0,0,0,64,0,0,0,32,0,0,0,0,0,0,0,224,0,0,0,192,0,0,0,160,0,0,0,128,0,0,0,64,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,8,0,4,0,8,0,48,0,0,0,32,0,0,0,16,0,0,0,0,0,0,0,56,0,0,0,40,0,0,0,24,0,0,0,8,0,0,0,0,0,32,0,0,0,48,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,128,0,0,0,0,1,0,0,128,1,8,0,0,3,0,0,0,3,8,0,0,1,0,0,0,1,8,0,0,2,0,0,0,2,8,0,0,0,0,0,0,0,4,0,64,0,0,0,64,0,4,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,4,0,8,0,0,0,8,0,24,0,0,0,16,0,0,0,8,0,0,0,0,0,0,0,120,0,0,0,112,0,0,0,104,0,0,0,96,0,0,0,88,0,0,0,80,0,0,0,72,0,0,0,64,0,0,0,56,0,0,0,48,0,0,0,40,0,0,0,32,0,0,0,24,0,0,0,16,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,16,0,0,0,24,0,0,0,32,0,0,0,40,0,0,0,48,0,0,0,56,0,0,0,0,1,0,0,8,1,0,0,16,1,0,0,24,1,0,0,32,1,0,0,40,1,0,0,48,1,0,0,56,1,0,0,0,0,0,0,8,0,0,0,16,0,0,0,24,0,0,0,32,0,0,0,40,0,0,0,48,0,0,0,56,0,0,0,128,0,0,0,136,0,0,0,144,0,0,0,152,0,0,0,160,0,0,0,168,0,0,0,176,0,0,0,184,0,0,0,0,0,0,0,32,0,0,0,64,0,0,0,96,0,0,0,128,0,0,0,160,0,0,0,192,0,0,0,224,0,0,0,0,1,0,0,32,1,0,0,64,1,0,0,96,1,0,0,128,1,0,0,160,1,0,0,192,1,0,0,224,1,0,0,0,0,0,0,64,0,0,0,128,0,0,0,192,0,0,0,0,1,0,0,64,1,0,0,128,1,0,0,192,1,0,0,0,2,0,0,64,2,0,0,128,2,0,0,192,2,0,0,0,3,0,0,64,3,0,0,128,3,0,0,192,3,0,0,0,0,0,0,8,0,0,0,16,0,0,0,24,0,0,0,32,0,0,0,40,0,0,0,48,0,0,0,56,0,0,0,128,0,0,0,136,0,0,0,144,0,0,0,152,0,0,0,160,0,0,0,168,0,0,0,176,0,0,0,184,0,0,0,0,1,0,0,8,1,0,0,16,1,0,0,24,1,0,0,32,1,0,0,40,1,0,0,48,1,0,0,56,1,0,0,128,1,0,0,136,1,0,0,144,1,0,0,152,1,0,0,160,1,0,0,168,1,0,0,176,1,0,0,184,1,0,0,0,0,0,0,8,0,0,0,16,0,0,0,24,0,0,0,32,0,0,0,40,0,0,0,48,0,0,0,56,0,0,0,64,0,0,0,72,0,0,0,80,0,0,0,88,0,0,0,96,0,0,0,104,0,0,0,112,0,0,0,120,0,0,0,0,1,0,0,8,1,0,0,16,1,0,0,24,1,0,0,32,1,0,0,40,1,0,0,48,1,0,0,56,1,0,0,64,1,0,0,72,1,0,0,80,1,0,0,88,1,0,0,96,1,0,0,104,1,0,0,112,1,0,0,120,1,0,0,7,0,0,0,6,0,0,0,5,0,0,0,4,0,0,0,3,0,0,0,2,0,0,0,1,0,0,0,0,0,0,0,71,0,0,0,70,0,0,0,69,0,0,0,68,0,0,0,67,0,0,0,66,0,0,0,65,0,0,0,64,0,0,0,3,0,0,0,2,0,0,0,1,0,0,0,0,0,0,0,11,0,0,0,10,0,0,0,9,0,0,0,8,0,0,0,131,0,0,0,130,0,0,0,129,0,0,0,128,0,0,0,139,0,0,0,138,0,0,0,137,0,0,0,136,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,8,0,0,0,9,0,0,0,10,0,0,0,11,0,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,56,0,0,0,60,0,0,0,48,0,0,0,52,0,0,0,40,0,0,0,44,0,0,0,32,0,0,0,36,0,0,0,24,0,0,0,28,0,0,0,16,0,0,0,20,0,0,0,8,0,0,0,12,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,8,0,0,0,9,0,0,0,10,0,0,0,11,0,0,0,4,0,0,0,0,0,0,0,12,0,0,0,8,0,0,0,20,0,0,0,16,0,0,0,28,0,0,0,24,0,0,0,36,0,0,0,32,0,0,0,44,0,0,0,40,0,0,0,52,0,0,0,48,0,0,0,60,0,0,0,56,0,0,0,4,0,0,0,0,0,0,0,12,0,0,0,8,0,0,0,20,0,0,0,16,0,0,0,28,0,0,0,24,0,0,0,4,1,0,0,0,1,0,0,12,1,0,0,8,1,0,0,20,1,0,0,16,1,0,0,28,1,0,0,24,1,0,0,128,0,0,0,129,0,0,0,130,0,0,0,131,0,0,0,132,0,0,0,133,0,0,0,134,0,0,0,135,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,7,0,0,0,6,0,0,0,5,0,0,0,4,0,0,0,3,0,0,0,2,0,0,0,1,0,0,0,0,0,0,0,15,0,0,0,14,0,0,0,13,0,0,0,12,0,0,0,11,0,0,0,10,0,0,0,9,0,0,0,8,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,64,0,0,0,65,0,0,0,66,0,0,0,67,0,0,0,135,0,0,0,134,0,0,0,133,0,0,0,132,0,0,0,131,0,0,0,130,0,0,0,129,0,0,0,128,0,0,0,7,0,0,0,6,0,0,0,5,0,0,0,4,0,0,0,3,0,0,0,2,0,0,0,1,0,0,0,0,0,0,0,8,0,0,0,12,0,0,0,0,0,0,0,4,0,0,0,24,0,0,0,28,0,0,0,16,0,0,0,20,0,0,0,0,0,32,0,4,0,32,0,0,0,0,0,4,0,0,0,8,0,32,0,12,0,32,0,8,0,0,0,12,0,0,0,8,0,0,0,12,0,0,0,0,0,0,0,4,0,0,0,24,0,0,0,28,0,0,0,16,0,0,0,20,0,0,0,8,1,0,0,12,1,0,0,0,1,0,0,4,1,0,0,24,1,0,0,28,1,0,0,16,1,0,0,20,1,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,0,0,1,0,1,0,1,0,2,0,1,0,3,0,1,0,4,0,1,0,5,0,1,0,6,0,1,0,7,0,1,0,0,0,2,0,0,0,0,0,0,0,6,0,0,0,4,0,0,0,8,0,4,0,8,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,0,0,4,0,0,0,0,0,4,0,4,0,4,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,0,0,0,2,1,0,0,2,2,0,0,2,3,0,0,2,24,0,0,0,8,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,128,0,0,0,192,0,0,0,64,0,0,0,96,0,0,0,0,0,0,0,32,0,0,0,0,0,4,0,0,0,0,0,64,0,4,0,64,0,8,0,0,0,12,0,0,0,8,0,64,0,12,0,64,0,4,0,4,0,0,0,4,0,4,0,0,0,0,0,0,0,0,0,24,0,0,0,16,0,0,0,8,0,0,0,0,0,4,0,0,0,0,0,0,0,4,0,112,0,0,0,112,0,4,0,0,0,0,0,0,0,4,0,64,0,0,0,64,0,4,0,0,0,0,0,0,0,4,0,32,0,0,0,32,0,0,0,0,0,16,0,0,0,128,0,0,0,144,0,0,0,8,0,0,0,24,0,0,0,136,0,0,0,152,0,0,0,32,0,0,0,48,0,0,0,160,0,0,0,176,0,0,0,40,0,0,0,56,0,0,0,168,0,0,0,184,0,0,0,0,0,0,0,128,0,0,0,32,0,0,0,160,0,0,0,16,0,0,0,144,0,0,0,48,0,0,0,176,0,0,0,8,0,0,0,136,0,0,0,40,0,0,0,168,0,0,0,24,0,0,0,152,0,0,0,56,0,0,0,184,0,0,0,0,0,0,0,16,0,0,0,32,0,0,0,48,0,0,0,64,0,0,0,80,0,0,0,96,0,0,0,112,0,0,0,0,2,0,0,16,2,0,0,32,2,0,0,48,2,0,0,64,2,0,0,80,2,0,0,96,2,0,0,112,2,0,0,128,1,0,0,129,1,0,0,130,1,0,0,131,1,0,0,0,1,0,0,1,1,0,0,2,1,0,0,3,1,0,0,128,0,0,0,129,0,0,0,130,0,0,0,131,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,192,0,0,0,193,0,0,0,194,0,0,0,195,0,0,0,128,0,0,0,129,0,0,0,130,0,0,0,131,0,0,0,64,0,0,0,65,0,0,0,66,0,0,0,67,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,8,0,0,2,0,0,0,4,8,0,0,0,0,0,0,0,8,0,0,6,0,0,0,6,8,0,0,4,0,0,0,2,0,0,128,0,0,0,192,0,0,0,64,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,192,1,0,0,128,1,0,0,64,1,0,0,0,1,0,0,192,0,0,0,128,0,0,0,64,0,0,0,0,0,0,2,0,0,1,2,0,0,2,2,0,0,3,2,0,0,4,2,0,0,5,2,0,0,6,2,0,0,7,2,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,0,1,0,0,1,1,0,0,2,1,0,0,3,1,0,0,4,1,0,0,5,1,0,0,6,1,0,0,7,1,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,0,2,0,0,1,2,0,0,2,2,0,0,3,2,0,0,4,2,0,0,5,2,0,0,6,2,0,0,7,2,0,0,0,4,0,0,1,4,0,0,2,4,0,0,3,4,0,0,4,4,0,0,5,4,0,0,6,4,0,0,7,4,0,0,0,6,0,0,1,6,0,0,2,6,0,0,3,6,0,0,4,6,0,0,5,6,0,0,6,6,0,0,7,6,0,0,0,160,0,0,192,178,254,0,203,41,125,67,210,58,194,180,60,70,90,110,140,200,80,0,0,80,10,0,0,0,0,0,249,224,93,243,234,146,190,239,0,34,98,140,199,0,0,63,127,137,199,0,0,43,107,0,0,0,0,4,3,0,1,2,8,0,0,0,9,0,0,0,10,0,0,0,11,0,0,0,12,0,0,0,13,0,0,0,14,0,0,0,15,0,0,0,1,5,2,1,0,0,0,0,1,1,1,2,0,0,0,0,2,8,42,32,32,42,8,2,136,136,0,0,136,136,0,0,136,10,130,0,160,34,170,40,136,10,130,0,160,34,170,40,42,8,42,8,138,168,138,168,42,8,42,8,138,168,138,168,136,10,130,0,160,34,170,40,136,10,130,0,160,34,170,40,160,130,40,10,130,160,10,40,136,10,130,0,136,10,130,0,160,128,168,136,40,168,8,136,40,168,8,136,160,128,168,136,160,128,32,0,160,128,32,0,8,40,136,168,160,128,168,136,8,0,136,128,40,168,8,136,160,128,32,0,8,0,136,128,160,128,32,0,160,128,32,0,160,128,32,0,0,8,32,40,136,128,8,0,160,128,32,0,136,128,8,0,0,8,32,40,8,40,136,168,8,40,136,168,160,128,168,136,160,128,32,0,8,0,136,128,136,128,8,0,0,8,32,40,136,128,8,0,8,40,136,168,8,40,136,168,8,0,136,128,160,128,32,0,0,4,0,0,2,0,0,0,0,8,0,0,3,0,0,0,3,0,0,0,0,0,0,0,255,3,0,0,0,0,0,0,0,32,12,0,40,172,255,0,195,253,129,172,109,231,191,158,1,224,4,0,246,44,254,0,195,253,129,172,109,231,191,158,0,16,0,0,32,206,255,0,196,131,168,95,33,39,100,175])
.concat([9,3,4,5,7,1,11,8,0,13,2,12,14,6,15,10,1,3,12,4,0,15,11,10,8,5,14,6,13,2,7,9,15,14,13,12,11,10,9,8,7,6,5,4,3,2,1,0,15,14,12,6,10,11,7,8,9,2,3,4,5,13,1,0,1,6,2,5,15,7,11,9,10,3,13,14,12,4,0,8,7,5,13,14,11,10,0,1,9,6,12,2,3,4,8,15,0,5,6,3,9,11,10,7,1,13,2,14,4,12,8,15,9,12,4,2,15,0,11,8,10,13,3,6,5,14,1,7,3,0,7,2,5,1,4,6,1,2,6,5,4,0,3,7,7,6,5,4,3,2,1,0,7,6,5,0,1,4,3,2,2,0,1,4,3,5,7,6,5,3,7,0,4,6,2,1,2,7,0,6,5,3,1,4,3,4,7,6,2,0,5,1,0,0,3,0,0,192,1,0,0,64,2,0,0,192,5,0,0,0,5,0,0,64,4,0,0,0,2,0,0,64,5,0,0,128,5,0,0,128,0,0,0,0,0,0,0,0,0,0,0,4,0,0,2,0,0,0,0,8,0,0,3,0,0,0,3,0,0,0,0,0,0,0,255,3,0,0,0,0,0,0,255,131,95,255,255,191,20,183,163,164,128,41,55,166,50,57,55,144,16,51,186,163,0,55,1,0,255,255,3,66,255,255,255,131,255,255,255,135,255,255,255,255,255,255,255,255,255,255,192,128,0,64,0,64,192,128,48,32,0,16,0,0,0,0,1,32,64,128,0,0,0,0,77,54,56,48,57,32,35,110,0,0,0,0,0,0,0,0,77,54,53,48,50,32,35,110,0,0,0,0,0,0,0,0,2,3,4,4,4,4,4,5,0,1,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,0,0,0,0,2,0,0,0,4,0,0,0,6,0,0,0,1,0,0,0,3,0,0,0,5,0,0,0,7,0,0,0,86,50,53,32,35,48,0,0,78,69,67,32,35,48,0,0,90,56,48,32,35,48,0,0,83,72,50,32,35,48,0,0,77,67,54,56,48,48,48,32,35,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,32,0,0,0,48,0,0,0,64,0,0,120,79,0,0,120,95,0,0,248,79,0,0,248,95,0,0,120,80,0,0,120,96,0,0,248,80,0,0,248,96,0,0,104,81,0,0,104,97,0,0,216,81,0,0,216,97,0,0,64,82,0,0,64,98,0,0,56,98,0,0,56,114,0,0,96,98,0,0,96,114,0,0,128,98,0,0,128,114,0,0,160,98,0,0,160,114,0,0,184,98,0,0,184,114,0,0,208,98,0,0,208,114,0,0,232,98,0,0,232,114,0,0,128,113,0,0,144,113,0,0,160,113,0,0,168,113,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,18,0,0,0,20,0,0,0,22,0,0,0,23,0,0,0,25,0,0,0,27,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,43,0,0,0,46,0,0,0,47,0,0,0,48,0,0,0,49,0,0,0,52,0,0,0,53,0,0,0,54,0,0,0,55,0,0,0,58,0,0,0,59,0,0,0,60,0,0,0,61,0,0,0,64,0,0,0,65,0,0,0,66,0,0,0,67,0,0,0,70,0,0,0,71,0,0,0,72,0,0,0,73,0,0,0,76,0,0,0,77,0,0,0,80,0,0,0,81,0,0,0,84,0,0,0,85,0,0,0,86,0,0,0,87,0,0,0,90,0,0,0,91,0,0,0,92,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,32,0,0,0,48,0,0,0,64,0,0,0,56,0,0,0,72,0,0,0,61,0,0,0,77,0,0,128,60,0,0,128,76,0,0,0,80,0,0,0,96,0,0,0,82,0,0,0,98,0,0,0,84,0,0,0,100,0,0,128,105,0,0,128,121,0,0,0,106,0,0,0,122,0,0,128,106,0,0,128,122,0,0,0,107,0,0,0,123,0,0,128,107,0,0,128,123,0,0,0,108,0,0,0,124,0,0,128,108,0,0,128,124,0,0,0,109,0,0,0,125,0,0,128,85,0,0,128,101,0,0,0,86,0,0,0,102,0,0,128,86,0,0,128,102,0,0,0,87,0,0,0,103,0,0,128,87,0,0,128,103,0,0,0,88,0,0,0,104,0,0,128,88,0,0,128,104,0,0,0,89,0,0,0,105,0,0,128,109,0,0,128,125,0,0,0,110,0,0,0,126,0,0,128,110,0,0,128,126,0,0,128,126,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,32,0,0,0,48,0,0,0,64,0,0,192,76,0,0,192,92,0,0,32,79,0,0,32,95,0,0,120,80,0,0,120,96,0,0,208,80,0,0,208,96,0,0,120,81,0,0,120,97,0,0,8,82,0,0,8,98,0,0,72,82,0,0,72,98,0,0,144,82,0,0,144,98,0,0,232,82,0,0,232,98,0,0,24,83,0,0,24,99,0,0,208,100,0,0,16,101,0,0,112,102,0,0,40,105,0,0,136,104,0,0,24,104,0,0,152,105,0,0,72,105,0,0,128,105,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,32,0,0,0,48,0,0,0,64,0,0,0,56,0,0,0,72,0,0,0,61,0,0,0,77,0,0,0,63,0,0,0,79,0,0,0,80,0,0,0,96,0,0,0,82,0,0,0,98,0,0,0,84,0,0,0,100,0,0,128,89,0,0,128,105,0,0,0,90,0,0,0,106,0,0,128,90,0,0,128,106,0,0,0,91,0,0,0,107,0,0,128,91,0,0,128,107,0,0,0,92,0,0,0,108,0,0,128,92,0,0,128,108,0,0,0,93,0,0,0,109,0,0,128,85,0,0,128,101,0,0,0,86,0,0,0,102,0,0,128,86,0,0,128,102,0,0,0,87,0,0,0,103,0,0,128,87,0,0,128,103,0,0,0,88,0,0,0,104,0,0,128,88,0,0,128,104,0,0,0,89,0,0,0,105,0,0,0,109,0,0,128,109,0,0,0,110,0,0,128,110,0,0,0,111,0,0,128,111,0,0,0,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,120,2,0,8,163,7,0,120,223,5,0,152,147,4,0,176,124,3,0,216,183,2,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,0,0,0,0,2,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,0,0,0,0,1,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,7,0,0,0,8,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,6,0,0,0,8,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,7,0,0,0,6,0,0,0,2,0,0,0,1,0,0,0,0,0,0,0,8,0,0,0,7,0,0,0,6,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,1,0,0,0,2,0,0,0,6,0,0,0,7,0,0,0,0,0,0,0,8,0,0,0,4,0,0,0,10,0,0,0,4,0,0,0,10,0,0,0,4,0,0,0,10,0,0,0,4,0,0,0,10,0,0,0,10,0,0,0,4,0,0,0,10,0,0,0,4,0,0,0,10,0,0,0,4,0,0,0,10,0,0,0,4,0,0,0,9,0,0,0,7,0,0,0,9,0,0,0,7,0,0,0,9,0,0,0,7,0,0,0,9,0,0,0,7,0,0,0,9,0,0,0,9,0,0,0,4,0,0,0,4,0,0,0,9,0,0,0,9,0,0,0,4,0,0,0,4,0,0,0,11,0,0,0,13,0,0,0,11,0,0,0,13,0,0,0,3,0,0,0,5,0,0,0,3,0,0,0,5,0,0,0,14,0,0,0,14,0,0,0,3,0,0,0,3,0,0,0,14,0,0,0,14,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,5,0,0,0,11,0,0,0,13,0,0,0,3,0,0,0,5,0,0,0,11,0,0,0,13,0,0,0,4,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,14,0,0,0,10,0,0,0,14,0,0,0,10,0,0,0,0,0,0,0,2,0,0,0,8,0,0,0,10,0,0,0,32,0,0,0,34,0,0,0,40,0,0,0,42,0,0,0,0,0,0,0,1,0,0,0,4,0,0,0,5,0,0,0,16,0,0,0,17,0,0,0,20,0,0,0,21,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,4,0,0,0,4,0,0,0,8,0,0,0,1,0,0,0,2,0,0,0,1,0,0,0,2,0,0,0,4,0,0,0,2,0,0,0,4,0,0,0,8,0,0,0,0,0,0,0,136,0,0,0,204,0,0,0,255,0,0,0,8,0,128,0,0,0,128,0,8,0,32,0,0,0,32,0,8,0,96,0,0,0,96,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,15,0,0,0,14,0,0,0,13,0,0,0,12,0,0,0,11,0,0,0,10,0,0,0,9,0,0,0,8,0,0,0,30,0,0,0,28,0,0,0,26,0,0,0,24,0,0,0,31,0,0,0,29,0,0,0,27,0,0,0,25,0,0,0,7,0,0,0,12,0,0,0,18,0,0,0,8,0,0,0,21,0,0,0,0,0,0,0,22,0,0,0,21,0,0,0,13,0,0,0,21,0,0,0,20,0,0,0,13,0,0,0,20,0,0,0,14,0,0,0,6,0,0,0,3,0,0,0,5,0,0,0,20,0,0,0,8,0,0,0,20,0,0,0,4,0,0,0,8,0,0,0,17,0,0,0,22,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,17,0,0,0,17,0,0,0,9,0,0,0,0,0,0,0,16,0,0,0,13,0,0,0,21,0,0,0,3,0,0,0,2,0,0,0,18,0,0,0,6,0,0,0,11,0,0,0,3,0,0,0,3,0,0,0,18,0,0,0,18,0,0,0,19,0,0,0,3,0,0,0,0,0,0,0,5,0,0,0,0,0,0,0,11,0,0,0,8,0,0,0,8,0,0,0,1,0,0,0,7,0,0,0,2,0,0,0,10,0,0,0,8,0,0,0,10,0,0,0,2,0,0,0,1,0,0,0,3,0,0,0,12,0,0,0,16,0,0,0,0,0,0,0,17,0,0,0,10,0,0,0,1,0,0,0,7,0,0,0,1,0,0,0,11,0,0,0,23,0,0,0,17,0,0,0,23,0,0,0,0,0,0,0,15,0,0,0,19,0,0,0,20,0,0,0,12,0,0,0,10,0,0,0,0,0,0,0,18,0,0,0,18,0,0,0,5,0,0,0,20,0,0,0,13,0,0,0,0,0,0,0,18,0,0,0,14,0,0,0,5,0,0,0,6,0,0,0,10,0,0,0,21,0,0,0,1,0,0,0,11,0,0,0,9,0,0,0,3,0,0,0,21,0,0,0,4,0,0,0,1,0,0,0,17,0,0,0,5,0,0,0,7,0,0,0,16,0,0,0,13,0,0,0,19,0,0,0,23,0,0,0,20,0,0,0,2,0,0,0,10,0,0,0,23,0,0,0,23,0,0,0,15,0,0,0,10,0,0,0,12,0,0,0,0,0,0,0,22,0,0,0,14,0,0,0,6,0,0,0,15,0,0,0,11,0,0,0,17,0,0,0,15,0,0,0,21,0,0,0,0,0,0,0,6,0,0,0,1,0,0,0,1,0,0,0,18,0,0,0,5,0,0,0,15,0,0,0,15,0,0,0,20,0,0,0,0,0,0,0,4,68,21,81,65,16,21,84,4,81,5,85,5,84,69,4,16,1,81,85,69,85,69,4,85,64,17,21,1,64,1,17,69,68,64,5,21,21,1,80,0,68,4,80,81,69,80,84,65,64,20,64,80,69,16,5,80,1,64,1,80,80,80,68,64,16,0,0,0,0,0,0,84,20,21,65,20,80,85,5,65,1,16,81,5,17,5,20,85,65,5,4,65,20,16,69,80,0,69,0,0,0,69,0,0,84,4,21,16,4,5,17,68,4,1,5,0,68,21,64,69,16,21,81,80,0,21,81,68,21,4,68,68,80,16,4,4,0,0,0,0,0,0,0,40,168,8,136,136,128,8,0,136,8,128,0,136,128,8,0,40,8,168,136,40,168,8,136,136,8,128,0,136,8,128,0,40,8,168,136,136,128,8,0,136,128,8,0,40,168,8,136,160,128,168,136,40,8,168,136,160,128,168,136,160,128,168,136,136,128,8,0,136,128,8,0,136,8,128,0,136,128,8,0,160,128,32,0,40,8,168,136,160,128,32,0,136,8,128,0,40,8,168,136,160,128,32,0,160,128,32,0,160,128,32,0,160,128,168,136,40,8,168,136,160,128,32,0,160,128,168,136,16,4,20,1,17,5,21,0,16,4,20,1,17,5,21,0,16,4,20,1,17,5,21,0,16,4,20,1,17,5,21,0,16,4,20,1,17,5,21,0,16,4,20,1,17,5,21,0,16,4,20,1,17,5,21,0,16,4,20,1,17,5,21,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,6,0,0,0,6,0,0,0,6,0,0,0,6,0,0,0,6,0,0,0,6,0,0,0,6,0,0,0,6,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,9,0,0,0,9,0,0,0,9,0,0,0,9,0,0,0,9,0,0,0,9,0,0,0,9,0,0,0,9,0,0,0,10,0,0,0,10,0,0,0,10,0,0,0,10,0,0,0,10,0,0,0,10,0,0,0,10,0,0,0,10,0,0,0,11,0,0,0,11,0,0,0,11,0,0,0,11,0,0,0,11,0,0,0,11,0,0,0,11,0,0,0,11,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,6,0,0,0,6,0,0,0,6,0,0,0,6,0,0,0,6,0,0,0,6,0,0,0,6,0,0,0,6,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,7,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,9,0,0,0,9,0,0,0,9,0,0,0,9,0,0,0,9,0,0,0,9,0,0,0,9,0,0,0,9,0,0,0,10,0,0,0,10,0,0,0,10,0,0,0,10,0,0,0,10,0,0,0,10,0,0,0,10,0,0,0,10,0,0,0,11,0,0,0,11,0,0,0,11,0,0,0,11,0,0,0,11,0,0,0,11,0,0,0,11,0,0,0,11,0,0,0,12,0,0,0,64,80,68,84,65,81,69,85,64,80,68,84,65,81,69,85,64,80,68,84,65,81,69,85,64,80,68,84,65,81,69,85,64,80,68,84,65,81,69,85,64,80,68,84,65,81,69,85,64,80,68,84,65,81,69,85,64,80,68,84,65,81,69,85,160,168,32,40,128,160,0,32,32,40,0,8,32,40,0,8,160,168,32,40,8,40,0,32,136,8,168,40,136,8,168,40,160,168,32,40,32,40,0,8,40,168,32,160,32,40,0,8,160,168,32,40,8,40,0,32,136,8,168,40,136,8,168,40,40,168,32,160,160,168,32,40,136,8,168,40,128,160,0,32,40,168,32,160,8,40,0,32,40,168,32,160,128,160,0,32,32,40,0,8,32,40,0,8,136,8,168,40,32,40,0,8,8,40,0,32,128,160,0,32,8,40,0,32,136,8,168,40,4,68,48,60,7,108,0,0,0,0,255,0,1,55,0,2,1,0,0,255,255,0,0,128,31,0,0,0,28,0,0,0,31,0,0,0,30,0,0,0,31,0,0,0,30,0,0,0,31,0,0,0,31,0,0,0,30,0,0,0,31,0,0,0,30,0,0,0,31,0,0,0,0,1,83,0,0,0,0,0,136,8,128,0,0,8,32,40,40,168,8,136,40,168,8,136,40,32,168,160,40,32,168,160,136,8,128,0,136,8,128,0,0,8,32,40,136,8,128,0,160,128,32,0,128,136,0,8,136,8,128,0,160,128,32,0,136,8,128,0,40,32,168,160,40,168,8,136,128,136,0,8,128,136,0,8,0,8,32,40,40,32,168,160,40,168,8,136,0,8,32,40,128,160,136,168,128,136,0,8,160,128,32,0,128,160,136,168,160,128,32,0,160,128,32,0,128,160,136,168,40,32,168,160,0,8,32,40,32,0,160,128,128,160,136,168,32,0,160,128,128,160,136,168,168,160,136,128,168,160,136,128,8,136,0,128,128,160,136,168,32,0,160,128,40,168,8,136,32,0,160,128,8,136,0,128,40,168,8,136,168,160,136,128,8,136,0,128,168,160,136,128,40,168,8,136,32,0,160,128,128,160,136,168,32,0,160,128,128,160,136,168,128,160,136,168,168,160,136,128,128,160,136,168,136,128,8,0,136,128,8,0,136,128,8,0,8,136,0,128,136,128,8,0,168,160,136,128,136,128,8,0,168,160,136,128,32,0,160,128,128,160,136,168,32,0,160,128,128,160,136,168,168,160,136,128,168,160,136,128,8,136,0,128,128,160,136,168,32,0,160,128,40,168,8,136,32,0,160,128,8,136,0,128,40,168,8,136,168,160,136,128,8,136,0,128,168,160,136,128,40,168,8,136,32,0,160,128,128,160,136,168,32,0,160,128,128,160,136,168,128,160,136,168,168,160,136,128,128,160,136,168,136,128,8,0,136,128,8,0,136,128,8,0,8,136,0,128,136,128,8,0,168,160,136,128,136,128,8,0,168,160,136,128,136,8,128,0,0,32,128,160,0,32,128,160,136,8,128,0,136,8,168,40,0,32,128,160,0,32,128,160,136,8,168,40,0,32,128,160,8,0,136,128,0,32,128,160,32,40,160,168,32,40,160,168,0,32,128,160,32,40,160,168,136,8,168,40,136,8,128,0,8,0,136,128,8,0,136,128,136,8,128,0,8,40,0,32,8,40,0,32,136,8,128,0,8,40,0,32,8,40,0,32,8,0,136,128,8,40,0,32,32,40,160,168,32,40,160,168,8,40,0,32,32,40,160,168,8,40,0,32,255,255,255,255,0,0,0,0,255,255,255,255,0,0,0,0,49,40,49,48,49,48,49,49,48,49,48,49,0,0,0,0,4,0,0,0,1,0,0,0,8,0,0,0,2,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,9,0,0,0,10,0,0,0,11,0,0,0,10,0,0,0,13,0,0,0,136,168,128,160,160,128,32,0,8,136,0,128,136,168,128,160,32,0,160,128,32,40,160,168,32,40,160,168,160,128,32,0,168,40,136,8,168,40,136,8,8,136,0,128,168,40,136,8,168,40,136,8,32,40,160,168,168,40,136,8,168,40,136,8,32,40,160,168,136,168,128,160,136,168,128,160,32,40,160,168,32,40,160,168,160,128,32,0,32,40,160,168,32,40,160,168,32,0,160,128,32,40,160,168,168,40,136,8,160,128,32,0,32,40,160,168,32,40,160,168,168,40,136,8,168,40,136,8,1,0,0,0,10,0,0,0,30,0,0,0,60,0,0,0,64,0,0,0,0,1,0,0,0,8,0,0,0,16,0,0,0,0,0,1,0,4,0,9,0,16,0,25,0,36,0,49,0,192,0,207,0,220,0,231,0,240,0,247,0,252,0,255,0,0,0,0,1,0,0,0,2,0,0,0,4,0,0,0,8,0,0,0,16,0,0,0,32,0,0,0,64,0,0,0,128,255,255,255,192,255,255,255,224,255,255,255,240,255,255,255,248,255,255,255,252,255,255,255,254,255,255,255,255,255,255,255,199,85,0,0,0,0,0,0,136,8,128,0,160,168,128,136,136,8,128,0,136,168,128,160,160,128,32,0,136,8,128,0,160,168,128,136,136,8,128,0,40,32,168,160,160,168,128,136,136,168,128,160,40,32,168,160,160,128,32,0,160,168,128,136,40,32,168,160,160,168,128,136,160,128,32,0,160,128,32,0,160,32,128,0,136,168,128,160,160,32,128,0,160,32,128,0,160,32,128,0,160,32,128,0,160,128,32,0,160,128,32,0,136,168,128,160,40,32,168,160,160,168,128,136,160,128,32,0,40,32,168,160,160,168,128,136,7,56,8,0,9,0,10,0,36,179,37,0,38,249,39,21,40,0,40,1,40,2,64,0,65,0,66,0,68,0,69,0,70,0,72,0,73,0,74,0,76,0,77,0,78,0,255,0,72,68,54,51,48,57,32,35,110,0,0,0,0,0,0,0,0,0,0,0,112,139,9,0,182,4,0,0,64,2,0,0,154,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,139,9,0,232,3,0,0,44,0,0,0,62,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,139,9,0,58,1,0,0,246,5,0,0,142,13,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,139,9,0,100,3,0,0,18,6,0,0,8,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,139,9,0,100,3,0,0,20,1,0,0,8,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,139,9,0,220,4,0,0,232,0,0,0,204,5,0,0,4,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,139,9,0,236,4,0,0,10,1,0,0,204,5,0,0,2,0,0,0,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,140,9,0,148,1,0,0,66,5,0,0,204,5,0,0,10,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,140,9,0,68,6,0,0,48,4,0,0,204,5,0,0,12,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,140,9,0,166,5,0,0,254,2,0,0,204,5,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,140,9,0,238,0,0,0,20,4,0,0,204,5,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,141,9,0,24,6,0,0,208,3,0,0,204,5,0,0,46,0,0,0,70,0,0,0,82,0,0,0,68,0,0,0,12,0,0,0,66,0,0,0,4,0,0,0,248,255,255,255,8,141,9,0,80,4,0,0,82,6,0,0,176,5,0,0,214,10,0,0,4,0,0,0,174,8,0,0,248,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,141,9,0,84,3,0,0,64,6,0,0,204,5,0,0,8,0,0,0,112,0,0,0,108,0,0,0,34,0,0,0,74,0,0,0,6,0,0,0,2,0,0,0,248,255,255,255,48,141,9,0,192,0,0,0,174,0,0,0,18,14,0,0,16,6,0,0,116,6,0,0,0,7,0,0,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,141,9,0,96,3,0,0,102,5,0,0,204,5,0,0,142,12,0,0,150,11,0,0,250,2,0,0,108,4,0,0,198,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,141,9,0,142,2,0,0,46,5,0,0,204,5,0,0,92,2,0,0,170,4,0,0,124,9,0,0,226,1,0,0,182,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,141,9,0,174,2,0,0,200,5,0,0,204,5,0,0,226,13,0,0,44,0,0,0,8,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,141,9,0,158,4,0,0,174,0,0,0,204,5,0,0,162,0,0,0,112,0,0,0,134,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,141,9,0,190,1,0,0,184,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,141,9,0,190,3,0,0,176,4,0,0,142,13,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,141,9,0,114,5,0,0,108,1,0,0,204,5,0,0,104,0,0,0,102,0,0,0,104,0,0,0,100,0,0,0,62,0,0,0,10,0,0,0,8,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,141,9,0,242,5,0,0,120,2,0,0,204,5,0,0,54,0,0,0,58,0,0,0,84,0,0,0,56,0,0,0,58,0,0,0,6,0,0,0,4,0,0,0,92,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,142,9,0,84,2,0,0,74,5,0,0,204,5,0,0,24,0,0,0,22,0,0,0,16,0,0,0,18,0,0,0,2,0,0,0,20,0,0,0,14,0,0,0,30,0,0,0,28,0,0,0,26,0,0,0,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,142,9,0,56,6,0,0,240,3,0,0,204,5,0,0,102,0,0,0,94,0,0,0,88,0,0,0,90,0,0,0,48,0,0,0,92,0,0,0,86,0,0,0,100,0,0,0,98,0,0,0,96,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,142,9,0,206,4,0,0,40,2,0,0,204,5,0,0,114,3,0,0,134,0,0,0,174,45,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,142,9,0,40,5,0,0,234,2,0,0,204,5,0,0,166,0,0,0,142,0,0,0,224,46,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,142,9,0,168,5,0,0,240,1,0,0,204,5,0,0,16,0,0,0,2,0,0,0,242,1,0,0,16,8,0,0,36,10,0,0,154,3,0,0,130,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,142,9,0,80,5,0,0,46,4,0,0,204,5,0,0,10,0,0,0,8,0,0,0,138,3,0,0,104,2,0,0,162,8,0,0,200,1,0,0,112,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,142,9,0,80,5,0,0,114,0,0,0,204,5,0,0,12,0,0,0,6,0,0,0,160,0,0,0,248,12,0,0,74,1,0,0,98,3,0,0,172,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,142,9,0,80,5,0,0,96,5,0,0,204,5,0,0,4,0,0,0,14,0,0,0,0,4,0,0,166,2,0,0,184,13,0,0,24,1,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,142,9,0,80,5,0,0,76,4,0,0,204,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,143,9,0,226,1,0,0,50,4,0,0,204,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,143,9,0,80,5,0,0,58,2,0,0,204,5,0,0,120,45,0,0,16,0,0,0,18,0,0,0,2,0,0,0,118,37,0,0,122,28,0,0,112,7,0,0,192,37,0,0,94,26,0,0,20,0,0,0,36,46,0,0,126,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,143,9,0,64,5,0,0,154,2,0,0,204,5,0,0,154,18,0,0,248,39,0,0,246,62,0,0,92,29,0,0,252,13,0,0,28,0,0,0,178,24,0,0,132,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,143,9,0,138,2,0,0,154,5,0,0,96,13,0,0,82,0,0,0,202,47,0,0,190,33,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,143,9,0,80,5,0,0,48,5,0,0,204,5,0,0,4,0,0,0,14,0,0,0,0,4,0,0,166,2,0,0,184,13,0,0,24,1,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,143,9,0,80,5,0,0,140,1,0,0,204,5,0,0,4,0,0,0,14,0,0,0,0,4,0,0,166,2,0,0,184,13,0,0,24,1,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,143,9,0,218,5,0,0,222,1,0,0,38,12,0,0,98,34,0,0,94,0,0,0,18,0,0,0,86,7,0,0,244,1,0,0,26,24,0,0,52,7,0,0,18,13,0,0,236,8,0,0,56,33,0,0,120,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,143,9,0,22,3,0,0,242,3,0,0,202,5,0,0,226,14,0,0,26,0,0,0,30,0,0,0,102,2,0,0,118,9,0,0,194,41,0,0,58,12,0,0,182,13,0,0,82,58,0,0,246,37,0,0,214,39,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,200,143,9,0,56,0,0,0,168,2,0,0,252,255,255,255,252,255,255,255,200,143,9,0,148,3,0,0,128,1,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,224,143,9,0,234,4,0,0,228,4,0,0,252,255,255,255,252,255,255,255,224,143,9,0,0,3,0,0,154,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,248,143,9,0,180,1,0,0,50,1,0,0,248,255,255,255,248,255,255,255,248,143,9,0,46,3,0,0,26,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,16,144,9,0,188,0,0,0,236,2,0,0,248,255,255,255,248,255,255,255,16,144,9,0,154,3,0,0,78,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,144,9,0,232,4,0,0,68,1,0,0,142,13,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,144,9,0,14,6,0,0,76,2,0,0,2,0,0,0,98,34,0,0,94,0,0,0,18,0,0,0,176,1,0,0,244,1,0,0,26,24,0,0,52,7,0,0,18,13,0,0,236,8,0,0,124,3,0,0,42,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,144,9,0,214,1,0,0,28,5,0,0,90,9,0,0,226,14,0,0,26,0,0,0,30,0,0,0,176,3,0,0,118,9,0,0,194,41,0,0,58,12,0,0,182,13,0,0,82,58,0,0,48,24,0,0,68,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,144,9,0,150,4,0,0,8,1,0,0,204,5,0,0,94,13,0,0,182,6,0,0,6,11,0,0,112,9,0,0,152,3,0,0,140,9,0,0,194,12,0,0,102,13,0,0,92,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,144,9,0,148,0,0,0,174,3,0,0,204,5,0,0,112,10,0,0,114,0,0,0,150,9,0,0,80,13,0,0,168,0,0,0,72,12,0,0,14,8,0,0,10,8,0,0,236,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,144,9,0,138,1,0,0,140,5,0,0,204,5,0,0,208,1,0,0,192,5,0,0,68,6,0,0,20,2,0,0,34,8,0,0,218,4,0,0,50,8,0,0,128,3,0,0,20,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,144,9,0,186,4,0,0,216,1,0,0,204,5,0,0,96,3,0,0,104,10,0,0,108,11,0,0,230,0,0,0,42,4,0,0,76,7,0,0,204,5,0,0,102,1,0,0,24,13,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,145,9,0,44,1,0,0,180,4,0,0,196,4,0,0,98,34,0,0,94,0,0,0,18,0,0,0,86,7,0,0,244,1,0,0,26,24,0,0,106,9,0,0,162,13,0,0,174,58,0,0,56,33,0,0,120,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,145,9,0,254,1,0,0,4,5,0,0,188,7,0,0,226,14,0,0,26,0,0,0,30,0,0,0,102,2,0,0,118,9,0,0,194,41,0,0,194,4,0,0,234,8,0,0,70,29,0,0,246,37,0,0,214,39,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,145,9,0,50,0,0,0,168,4,0,0,198,2,0,0,136,3,0,0,90,39,0,0,72,0,0,0,14,0,0,0,38,0,0,0,0,0,0,0,0,0,0,0,121,0,0,0,0,0,0,0,120,0,0,0,0,0,0,0,119,0,0,0,0,0,0,0,108,0,0,0,0,0,0,0,98,0,0,0,0,0,0,0,97,0,0,0,0,0,0,0,83,116,57,116,121,112,101,95,105,110,102,111,0,0,0,0,83,116,57,101,120,99,101,112,116,105,111,110,0,0,0,0,83,116,57,98,97,100,95,97,108,108,111,99,0,0,0,0,83,116,56,98,97,100,95,99,97,115,116,0,0,0,0,0,83,116,49,51,114,117,110,116,105,109,101,95,101,114,114,111,114,0,0,0,0,0,0,0,83,116,49,50,108,101,110,103,116,104,95,101,114,114,111,114,0,0,0,0,0,0,0,0,83,116,49,49,108,111,103,105,99,95,101,114,114,111,114,0,78,83,116,51,95,95,49,57,116,105,109,101,95,98,97,115,101,69,0,0,0,0,0,0,78,83,116,51,95,95,49,57,109,111,110,101,121,95,112,117,116,73,119,78,83,95,49,57,111,115,116,114,101,97,109,98,117,102,95,105,116,101,114,97,116,111,114,73,119,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,119,69,69,69,69,69,69,0,0,0,78,83,116,51,95,95,49,57,109,111,110,101,121,95,112,117,116,73,99,78,83,95,49,57,111,115,116,114,101,97,109,98,117,102,95,105,116,101,114,97,116,111,114,73,99,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,99,69,69,69,69,69,69,0,0,0,78,83,116,51,95,95,49,57,109,111,110,101,121,95,103,101,116,73,119,78,83,95,49,57,105,115,116,114,101,97,109,98,117,102,95,105,116,101,114,97,116,111,114,73,119,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,119,69,69,69,69,69,69,0,0,0,78,83,116,51,95,95,49,57,109,111,110,101,121,95,103,101,116,73,99,78,83,95,49,57,105,115,116,114,101,97,109,98,117,102,95,105,116,101,114,97,116,111,114,73,99,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,99,69,69,69,69,69,69,0,0,0,78,83,116,51,95,95,49,57,98,97,115,105,99,95,105,111,115,73,119,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,119,69,69,69,69,0,0,0,0,0,0,0,78,83,116,51,95,95,49,57,98,97,115,105,99,95,105,111,115,73,99,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,99,69,69,69,69,0,0,0,0,0,0,0,78,83,116,51,95,95,49,57,95,95,110,117,109,95,112,117,116,73,119,69,69,0,0,0,78,83,116,51,95,95,49,57,95,95,110,117,109,95,112,117,116,73,99,69,69,0,0,0,78,83,116,51,95,95,49,57,95,95,110,117,109,95,103,101,116,73,119,69,69,0,0,0,78,83,116,51,95,95,49,57,95,95,110,117,109,95,103,101,116,73,99,69,69,0,0,0,78,83,116,51,95,95,49,56,116,105,109,101,95,112,117,116,73,119,78,83,95,49,57,111,115,116,114,101,97,109,98,117,102,95,105,116,101,114,97,116,111,114,73,119,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,119,69,69,69,69,69,69,0,0,0,0,78,83,116,51,95,95,49,56,116,105,109,101,95,112,117,116,73,99,78,83,95,49,57,111,115,116,114,101,97,109,98,117,102,95,105,116,101,114,97,116,111,114,73,99,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,99,69,69,69,69,69,69,0,0,0,0,78,83,116,51,95,95,49,56,116,105,109,101,95,103,101,116,73,119,78,83,95,49,57,105,115,116,114,101,97,109,98,117,102,95,105,116,101,114,97,116,111,114,73,119,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,119,69,69,69,69,69,69,0,0,0,0,78,83,116,51,95,95,49,56,116,105,109,101,95,103,101,116,73,99,78,83,95,49,57,105,115,116,114,101,97,109,98,117,102,95,105,116,101,114,97,116,111,114,73,99,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,99,69,69,69,69,69,69,0,0,0,0,78,83,116,51,95,95,49,56,110,117,109,112,117,110,99,116,73,119,69,69,0,0,0,0,78,83,116,51,95,95,49,56,110,117,109,112,117,110,99,116,73,99,69,69,0,0,0,0,78,83,116,51,95,95,49,56,109,101,115,115,97,103,101,115,73,119,69,69,0,0,0,0,78,83,116,51,95,95,49,56,109,101,115,115,97,103,101,115,73,99,69,69,0,0,0,0,78,83,116,51,95,95,49,56,105,111,115,95,98,97,115,101,69,0,0,0,0,0,0,0,78,83,116,51,95,95,49,56,105,111,115,95,98,97,115,101,55,102,97,105,108,117,114,101,69,0,0,0,0,0,0,0,78,83,116,51,95,95,49,55,110,117,109,95,112,117,116,73,119,78,83,95,49,57,111,115,116,114,101,97,109,98,117,102,95,105,116,101,114,97,116,111,114,73,119,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,119,69,69,69,69,69,69,0,0,0,0,0,78,83,116,51,95,95,49,55,110,117,109,95,112,117,116,73,99,78,83,95,49,57,111,115,116,114,101,97,109,98,117,102,95,105,116,101,114,97,116,111,114,73,99,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,99,69,69,69,69,69,69,0,0,0,0,0,78,83,116,51,95,95,49,55,110,117,109,95,103,101,116,73,119,78,83,95,49,57,105,115,116,114,101,97,109,98,117,102,95,105,116,101,114,97,116,111,114,73,119,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,119,69,69,69,69,69,69,0,0,0,0,0,78,83,116,51,95,95,49,55,110,117,109,95,103,101,116,73,99,78,83,95,49,57,105,115,116,114,101,97,109,98,117,102,95,105,116,101,114,97,116,111,114,73,99,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,99,69,69,69,69,69,69,0,0,0,0,0,78,83,116,51,95,95,49,55,99,111,108,108,97,116,101,73,119,69,69,0,0,0,0,0,78,83,116,51,95,95,49,55,99,111,108,108,97,116,101,73,99,69,69,0,0,0,0,0,78,83,116,51,95,95,49,55,99,111,100,101,99,118,116,73,119,99,49,49,95,95,109,98,115,116,97,116,101,95,116,69,69,0,0,0,0,0,0,0,78,83,116,51,95,95,49,55,99,111,100,101,99,118,116,73,99,99,49,49,95,95,109,98,115,116,97,116,101,95,116,69,69,0,0,0,0,0,0,0,78,83,116,51,95,95,49,55,99,111,100,101,99,118,116,73,68,115,99,49,49,95,95,109,98,115,116,97,116,101,95,116,69,69,0,0,0,0,0,0,78,83,116,51,95,95,49,55,99,111,100,101,99,118,116,73,68,105,99,49,49,95,95,109,98,115,116,97,116,101,95,116,69,69,0,0,0,0,0,0,78,83,116,51,95,95,49,54,108,111,99,97,108,101,53,102,97,99,101,116,69,0,0,0,78,83,116,51,95,95,49,54,108,111,99,97,108,101,53,95,95,105,109,112,69,0,0,0,78,83,116,51,95,95,49,53,99,116,121,112,101,73,119,69,69,0,0,0,0,0,0,0,78,83,116,51,95,95,49,53,99,116,121,112,101,73,99,69,69,0,0,0,0,0,0,0,78,83,116,51,95,95,49,50,48,95,95,116,105,109,101,95,103,101,116,95,99,95,115,116,111,114,97,103,101,73,119,69,69,0,0,0,0,0,0,0,78,83,116,51,95,95,49,50,48,95,95,116,105,109,101,95,103,101,116,95,99,95,115,116,111,114,97,103,101,73,99,69,69,0,0,0,0,0,0,0,78,83,116,51,95,95,49,49,57,95,95,105,111,115,116,114,101,97,109,95,99,97,116,101,103,111,114,121,69,0,0,0,78,83,116,51,95,95,49,49,55,95,95,119,105,100,101,110,95,102,114,111,109,95,117,116,102,56,73,76,106,51,50,69,69,69,0,0,0,0,0,0,78,83,116,51,95,95,49,49,54,95,95,110,97,114,114,111,119,95,116,111,95,117,116,102,56,73,76,106,51,50,69,69,69,0,0,0,0,0,0,0,78,83,116,51,95,95,49,49,53,98,97,115,105,99,95,115,116,114,101,97,109,98,117,102,73,119,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,119,69,69,69,69,0,0,0,0,0,0,0,0,78,83,116,51,95,95,49,49,53,98,97,115,105,99,95,115,116,114,101,97,109,98,117,102,73,99,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,99,69,69,69,69,0,0,0,0,0,0,0,0,78,83,116,51,95,95,49,49,52,101,114,114,111,114,95,99,97,116,101,103,111,114,121,69,0,0,0,0,0,0,0,0,78,83,116,51,95,95,49,49,52,95,95,115,104,97,114,101,100,95,99,111,117,110,116,69,0,0,0,0,0,0,0,0,78,83,116,51,95,95,49,49,52,95,95,110,117,109,95,112,117,116,95,98,97,115,101,69,0,0,0,0,0,0,0,0,78,83,116,51,95,95,49,49,52,95,95,110,117,109,95,103,101,116,95,98,97,115,101,69,0,0,0,0,0,0,0,0,78,83,116,51,95,95,49,49,51,109,101,115,115,97,103,101,115,95,98,97,115,101,69,0,78,83,116,51,95,95,49,49])
.concat([51,98,97,115,105,99,95,111,115,116,114,101,97,109,73,119,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,119,69,69,69,69,0,0,78,83,116,51,95,95,49,49,51,98,97,115,105,99,95,111,115,116,114,101,97,109,73,99,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,99,69,69,69,69,0,0,78,83,116,51,95,95,49,49,51,98,97,115,105,99,95,105,115,116,114,101,97,109,73,119,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,119,69,69,69,69,0,0,78,83,116,51,95,95,49,49,51,98,97,115,105,99,95,105,115,116,114,101,97,109,73,99,78,83,95,49,49,99,104,97,114,95,116,114,97,105,116,115,73,99,69,69,69,69,0,0,78,83,116,51,95,95,49,49,50,115,121,115,116,101,109,95,101,114,114,111,114,69,0,0,78,83,116,51,95,95,49,49,50,99,111,100,101,99,118,116,95,98,97,115,101,69,0,0,78,83,116,51,95,95,49,49,50,95,95,100,111,95,109,101,115,115,97,103,101,69,0,0,78,83,116,51,95,95,49,49,49,95,95,115,116,100,111,117,116,98,117,102,73,119,69,69,0,0,0,0,0,0,0,0,78,83,116,51,95,95,49,49,49,95,95,115,116,100,111,117,116,98,117,102,73,99,69,69,0,0,0,0,0,0,0,0,78,83,116,51,95,95,49,49,49,95,95,109,111,110,101,121,95,112,117,116,73,119,69,69,0,0,0,0,0,0,0,0,78,83,116,51,95,95,49,49,49,95,95,109,111,110,101,121,95,112,117,116,73,99,69,69,0,0,0,0,0,0,0,0,78,83,116,51,95,95,49,49,49,95,95,109,111,110,101,121,95,103,101,116,73,119,69,69,0,0,0,0,0,0,0,0,78,83,116,51,95,95,49,49,49,95,95,109,111,110,101,121,95,103,101,116,73,99,69,69,0,0,0,0,0,0,0,0,78,83,116,51,95,95,49,49,48,109,111,110,101,121,112,117,110,99,116,73,119,76,98,49,69,69,69,0,0,0,0,0,78,83,116,51,95,95,49,49,48,109,111,110,101,121,112,117,110,99,116,73,119,76,98,48,69,69,69,0,0,0,0,0,78,83,116,51,95,95,49,49,48,109,111,110,101,121,112,117,110,99,116,73,99,76,98,49,69,69,69,0,0,0,0,0,78,83,116,51,95,95,49,49,48,109,111,110,101,121,112,117,110,99,116,73,99,76,98,48,69,69,69,0,0,0,0,0,78,83,116,51,95,95,49,49,48,109,111,110,101,121,95,98,97,115,101,69,0,0,0,0,78,83,116,51,95,95,49,49,48,99,116,121,112,101,95,98,97,115,101,69,0,0,0,0,78,83,116,51,95,95,49,49,48,95,95,116,105,109,101,95,112,117,116,69,0,0,0,0,78,83,116,51,95,95,49,49,48,95,95,115,116,100,105,110,98,117,102,73,119,69,69,0,78,83,116,51,95,95,49,49,48,95,95,115,116,100,105,110,98,117,102,73,99,69,69,0,78,49,48,95,95,99,120,120,97,98,105,118,49,50,49,95,95,118,109,105,95,99,108,97,115,115,95,116,121,112,101,95,105,110,102,111,69,0,0,0,78,49,48,95,95,99,120,120,97,98,105,118,49,50,48,95,95,115,105,95,99,108,97,115,115,95,116,121,112,101,95,105,110,102,111,69,0,0,0,0,78,49,48,95,95,99,120,120,97,98,105,118,49,49,55,95,95,99,108,97,115,115,95,116,121,112,101,95,105,110,102,111,69,0,0,0,0,0,0,0,78,49,48,95,95,99,120,120,97,98,105,118,49,49,54,95,95,115,104,105,109,95,116,121,112,101,95,105,110,102,111,69,0,0,0,0,0,0,0,0,0,0,0,0,184,127,9,0,0,0,0,0,200,127,9,0,0,0,0,0,216,127,9,0,104,139,9,0,0,0,0,0,0,0,0,0,232,127,9,0,104,139,9,0,0,0,0,0,0,0,0,0,248,127,9,0,104,139,9,0,0,0,0,0,0,0,0,0,16,128,9,0,176,139,9,0,0,0,0,0,0,0,0,0,40,128,9,0,104,139,9,0,0,0,0,0,0,0,0,0,56,128,9,0,96,127,9,0,80,128,9,0,0,0,0,0,2,0,0,0,240,142,9,0,2,0,0,0,112,144,9,0,0,0,0,0,96,127,9,0,152,128,9,0,0,0,0,0,2,0,0,0,240,142,9,0,2,0,0,0,120,144,9,0,0,0,0,0,96,127,9,0,224,128,9,0,0,0,0,0,2,0,0,0,240,142,9,0,2,0,0,0,128,144,9,0,0,0,0,0,96,127,9,0,40,129,9,0,0,0,0,0,2,0,0,0,240,142,9,0,2,0,0,0,136,144,9,0,0,0,0,0,0,0,0,0,112,129,9,0,184,141,9,0,0,0,0,0,0,0,0,0,160,129,9,0,184,141,9,0,0,0,0,0,96,127,9,0,208,129,9,0,0,0,0,0,1,0,0,0,176,143,9,0,0,0,0,0,96,127,9,0,232,129,9,0,0,0,0,0,1,0,0,0,176,143,9,0,0,0,0,0,96,127,9,0,0,130,9,0,0,0,0,0,1,0,0,0,184,143,9,0,0,0,0,0,96,127,9,0,24,130,9,0,0,0,0,0,1,0,0,0,184,143,9,0,0,0,0,0,96,127,9,0,48,130,9,0,0,0,0,0,2,0,0,0,240,142,9,0,2,0,0,0,32,145,9,0,0,8,0,0,96,127,9,0,120,130,9,0,0,0,0,0,2,0,0,0,240,142,9,0,2,0,0,0,32,145,9,0,0,8,0,0,96,127,9,0,192,130,9,0,0,0,0,0,3,0,0,0,240,142,9,0,2,0,0,0,192,139,9,0,2,0,0,0,80,143,9,0,0,8,0,0,96,127,9,0,8,131,9,0,0,0,0,0,3,0,0,0,240,142,9,0,2,0,0,0,192,139,9,0,2,0,0,0,88,143,9,0,0,8,0,0,0,0,0,0,80,131,9,0,240,142,9,0,0,0,0,0,0,0,0,0,104,131,9,0,240,142,9,0,0,0,0,0,96,127,9,0,128,131,9,0,0,0,0,0,2,0,0,0,240,142,9,0,2,0,0,0,192,143,9,0,2,0,0,0,96,127,9,0,152,131,9,0,0,0,0,0,2,0,0,0,240,142,9,0,2,0,0,0,192,143,9,0,2,0,0,0,0,0,0,0,176,131,9,0,0,0,0,0,200,131,9,0,40,144,9,0,0,0,0,0,96,127,9,0,232,131,9,0,0,0,0,0,2,0,0,0,240,142,9,0,2,0,0,0,104,140,9,0,0,0,0,0,96,127,9,0,48,132,9,0,0,0,0,0,2,0,0,0,240,142,9,0,2,0,0,0,128,140,9,0,0,0,0,0,96,127,9,0,120,132,9,0,0,0,0,0,2,0,0,0,240,142,9,0,2,0,0,0,152,140,9,0,0,0,0,0,96,127,9,0,192,132,9,0,0,0,0,0,2,0,0,0,240,142,9,0,2,0,0,0,176,140,9,0,0,0,0,0,0,0,0,0,8,133,9,0,240,142,9,0,0,0,0,0,0,0,0,0,32,133,9,0,240,142,9,0,0,0,0,0,96,127,9,0,56,133,9,0,0,0,0,0,2,0,0,0,240,142,9,0,2,0,0,0,56,144,9,0,2,0,0,0,96,127,9,0,96,133,9,0,0,0,0,0,2,0,0,0,240,142,9,0,2,0,0,0,56,144,9,0,2,0,0,0,96,127,9,0,136,133,9,0,0,0,0,0,2,0,0,0,240,142,9,0,2,0,0,0,56,144,9,0,2,0,0,0,96,127,9,0,176,133,9,0,0,0,0,0,2,0,0,0,240,142,9,0,2,0,0,0,56,144,9,0,2,0,0,0,0,0,0,0,216,133,9,0,168,143,9,0,0,0,0,0,0,0,0,0,240,133,9,0,240,142,9,0,0,0,0,0,96,127,9,0,8,134,9,0,0,0,0,0,2,0,0,0,240,142,9,0,2,0,0,0,24,145,9,0,2,0,0,0,96,127,9,0,32,134,9,0,0,0,0,0,2,0,0,0,240,142,9,0,2,0,0,0,24,145,9,0,2,0,0,0,0,0,0,0,56,134,9,0,0,0,0,0,96,134,9,0,0,0,0,0,136,134,9,0,64,144,9,0,0,0,0,0,0,0,0,0,168,134,9,0,208,142,9,0,0,0,0,0,0,0,0,0,208,134,9,0,208,142,9,0,0,0,0,0,0,0,0,0,248,134,9,0,0,0,0,0,48,135,9,0,0,0,0,0,104,135,9,0,0,0,0,0,136,135,9,0,0,0,0,0,168,135,9,0,0,0,0,0,200,135,9,0,0,0,0,0,232,135,9,0,96,127,9,0,0,136,9,0,0,0,0,0,1,0,0,0,72,140,9,0,3,244,255,255,96,127,9,0,48,136,9,0,0,0,0,0,1,0,0,0,88,140,9,0,3,244,255,255,96,127,9,0,96,136,9,0,0,0,0,0,1,0,0,0,72,140,9,0,3,244,255,255,96,127,9,0,144,136,9,0,0,0,0,0,1,0,0,0,88,140,9,0,3,244,255,255,0,0,0,0,192,136,9,0,144,139,9,0,0,0,0,0,0,0,0,0,216,136,9,0,0,0,0,0,240,136,9,0,160,143,9,0,0,0,0,0,0,0,0,0,8,137,9,0,144,143,9,0,0,0,0,0,0,0,0,0,40,137,9,0,152,143,9,0,0,0,0,0,0,0,0,0,72,137,9,0,0,0,0,0,104,137,9,0,0,0,0,0,136,137,9,0,0,0,0,0,168,137,9,0,96,127,9,0,200,137,9,0,0,0,0,0,2,0,0,0,240,142,9,0,2,0,0,0,16,145,9,0,2,0,0,0,96,127,9,0,232,137,9,0,0,0,0,0,2,0,0,0,240,142,9,0,2,0,0,0,16,145,9,0,2,0,0,0,96,127,9,0,8,138,9,0,0,0,0,0,2,0,0,0,240,142,9,0,2,0,0,0,16,145,9,0,2,0,0,0,96,127,9,0,40,138,9,0,0,0,0,0,2,0,0,0,240,142,9,0,2,0,0,0,16,145,9,0,2,0,0,0,0,0,0,0,72,138,9,0,0,0,0,0,96,138,9,0,0,0,0,0,120,138,9,0,0,0,0,0,144,138,9,0,144,143,9,0,0,0,0,0,0,0,0,0,168,138,9,0,152,143,9,0,0,0,0,0,0,0,0,0,192,138,9,0,104,145,9,0,0,0,0,0,0,0,0,0,232,138,9,0,104,145,9,0,0,0,0,0,0,0,0,0,16,139,9,0,120,145,9,0,0,0,0,0,0,0,0,0,56,139,9,0,96,139,9,0,0,0,0,0,48,49,50,51,52,53,54,55,56,57,97,98,99,100,101,102,65,66,67,68,69,70,120,88,43,45,112,80,105,73,110,78,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,86,213,203,115,99,41,154,75,188,179,115,188,201,203,181,174,109,30,181,213,118,230,197,92,90,57,174,218,41,38,158,229,0,0,0,0,0,0,0,0,115,102,101,45,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,202,195,70,131,1,0,16,1,115,102,101,45,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,168,250,75,58,1,0,16,1,115,102,101,45,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,238,103,14,180,1,0,16,1,115,102,101,45,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,91,61,124,71,1,0,16,1,115,102,101,45,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,43,25,71,37,1,0,16,1,115,102,101,45,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,78,15,104,121,1,0,16,1,115,102,45,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,52,197,154,74,2,0,16,1,115,102,117,45,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,3,233,204,167,3,0,16,1,115,102,45,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,213,240,224,134,3,0,16,1,115,102,45,51,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,146,210,227,206,4,0,32,0,115,102,45,51,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,118,150,169,46,4,0,32,0,115,102,45,52,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,149,4,40,224,4,0,32,0,115,102,45,52,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,222,48,11,199,4,0,32,0,115,102,45,50,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,46,4,35,127,5,0,32,0,115,102,45,50,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,28,185,248,146,5,0,32,0,115,102,45,51,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,86,152,57,177,5,0,32,0,115,102,45,51,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,46,174,182,150,5,0,32,0,115,102,45,50,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,245,233,237,84,5,0,32,0,115,102,45,50,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,103,154,100,240,5,0,32,0,115,102,45,51,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,26,215,77,143,5,0,32,0,115,102,45,51,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,180,15,192,112,5,0,32,0,115,102,45,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,219,19,1,252,6,0,32,0,115,102,45,49,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,211,166,228,130,6,0,32,0,115,102,45,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,27,223,18,225,6,0,32,0,115,102,45,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,153,34,213,66,6,0,32,0,115,102,45,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,217,64,243,73,6,0,32,0,115,102,45,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,177,233,236,149,6,0,32,0,115,102,45,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,129,87,160,92,6,0,32,0,115,102,45,49,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,142,196,250,105,6,0,32,0,115,102,45,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,141,209,207,113,6,0,32,0,115,102,45,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,75,178,46,250,6,0,32,0,115,102,45,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,149,92,149,173,6,0,32,0,115,102,45,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,49,58,183,65,6,0,32,0,115,102,45,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,80,28,196,145,6,0,32,0,115,102,45,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,190,124,140,83,6,0,32,0,115,102,45,50,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,109,179,9,43,7,0,32,0,115,102,45,51,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,61,157,208,35,8,0,32,0,115,102,45,51,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,108,223,22,234,8,0,32,0,115,102,45,51,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,217,43,223,114,8,0,32,0,115,102,45,51,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,213,211,153,62,8,0,32,0,109,98,55,49,49,52,104,46,49,50,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,83,53,175,117,0,0,0,8,109,98,55,49,49,52,104,46,49,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,134,101,229,192,0,0,0,8,109,98,55,49,49,52,104,46,49,50,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,100,75,115,76,0,0,0,8,109,109,105,45,55,54,48,51,46,49,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,83,218,188,6,0,0,0,8,0,0,0,0,0,0,0,0,116,232,168,100,38,68,166,154,165,105,162,211,109,186,255,243,235,110,227,112,114,88,39,217,228,159,80,162,221,206,110,246,68,114,12,126,77,65,119,45,0,173,26,95,107,192,29,78,76,114,98,60,50,40,67,248,157,82,5,126,209,238,130,97,59,63,119,243,143,126,63,241,223,143,104,67,215,104,223,25,135,255,116,229,63,67,142,128,15,126,219,50,232,209,102,143,190,226,51,148,200,50,57,250,240,67,222,132,24,208,109,213,116,152,248,100,207,132,198,234,85,50,226,56,221,234,253,108,235,110,227,112,174,56,199,217,84,132,16,193,253,30,110,109,55,224,3,158,6,54,104,91,227,246,127,11,86,121,224,168,152,119,199,43,165,121,255,47,202,21,113,126,2,191,135,183,122,142,230,100,50,98,42,202,35,114,135,181,12,2,75,238,68,114,156,126,93,193,167,29,48,56,218,201,91,208,17,249,177,114,108,4,49,201,80,96,111,193,242,174,0,244,93,102,67,14,122,195,118,174,60,194,183,201,82,244,116,81,175,18,25,198,117,232,108,84,126,99,221,174,7,90,183,0,181,94,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,48,0,104,0,160,31,198,6,60,56,71,198,6,61,56,71,198,6,66,56,68,198,6,67,56,68,104,0,176,31,198,6,0,9,182,198,6,0,10,182,198,6,0,11,182,104,0,208,31,198,6,112,22,87,234,93,1,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,51,10,0,136,50,10,0,152,49,10,0,8,49,10,0,120,48,10,0,168,42,10,0,8,42,10,0,232,41,10,0,200,41,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,231,6,163,112,242,88,230,89,228,207,194,121,29,227,113,14,182,144,154,42,140,65,247,130,155,239,153,12,250,47,241,254,143,112,244,193,181,61,124,96,76,9,244,46,124,135,99,95,206,153,132,149,6,154,32,35,90,185,82,149,72,44,132,96,105,227,147,73,185,214,187,214,158,220,150,18,250,96,218,95,85,93,91,32,7,30,151,66,119,234,29,224,112,251,106,0,119,154,239,27,224,249,13,193,46,47,239,37,41,229,216,44,175,1,217,108,49,206,92,234,171,28,146,22,97,188,228,124,90,118,233,146,57,91,151,96,234,87,131,156,146,41,167,18,169,113,122,249,7,104,167,69,136,16,129,18,44,103,77,85,51,240,250,215,29,77,14,99,3,52,101,226,118,15,152,169,95,154,211,202,221,193,91,61,77,248,64,8,220,5,56,0,203,36,2,255,57,226,158,4,154,8,99,200,43,90,52,6,98,193,187,138,208,84,76,67,33,78,76,153,128,194,61,206,42,123,9,98,26,145,155,195,65,36,160,253,181,103,147,7,167,184,133,138,161,30,79,182,117,56,101,138,249,124,0,160,68,71,184,40,3,162,33,188,23,50,78,226,223,105,53,199,162,6,236,54,210,68,18,106,141,81,107,32,105,1,202,240,113,196,52,220,107,214,66,42,93,181,199,111,79,216,179,237,81,158,55,30,192,133,42,145,198,156,172,245,32,59,9,116,36,241,224,66,2,190,132,117,74,130,162,23,174,182,36,121,10,90,86,203,161,46,71,234,169,37,115,121,11,23,158,51,100,182,3,127,79,195,174,69,230,130,39,1,134,107,80,22,211,34,144,100,252,169,49,28,65,213,7,211,178,254,83,214,57,251,230,190,218,77,138,68,58,155,157,86,94,95,255,106,182,222,47,18,90,93,176,208,147,146,178,44,157,89,238,5,171,168,210,37,44,197,222,24,77,182,78,61,191,250,249,29,186,118,121,252,66,178,140,174,169,69,186,172,85,142,56,103,195,165,13,220,204,145,115,105,39,188,128,223,48,164,5,216,231,210,183,75,60,16,140,93,138,215,104,122,97,7,249,165,136,218,223,12,66,27,17,224,209,147,124,99,57,197,237,67,70,219,48,38,208,223,122,134,62,46,4,191,73,42,249,102,0,0,0,0,0,0,0,0,192,25,0,0,234,6,0,0,170,12,0,0,4,44,0,0,126,49,0,0,244,30,0,0,162,36,0,0,54,18,0,0,230,23,0,0,210,4,0,0,46,46,0,0,82,1,0,0,64,33,0,0,44,39,0,0,138,20,0,0,68,26,0,0,182,33,0,0,208,1,0,0,138,46,0,0,124,15,0,0,180,9,0,0,64,28,0,0,190,22,0,0,70,41,0,0,134,35,0,0,200,3,0,0,6,13,0,0,94,7,0,0,252,17,0,0,118,20,0,0,224,38,0,0,34,33,0,0,164,44,0,0,112,2,0,0,170,7,0,0,96,39,0,0,214,20,0,0,130,1,0,0,110,33,0,0,58,15,0,0,4,43,0,0,128,24,0,0,204,15,0,0,242,46,0,0,130,28,0,0,14,10,0,0,148,41,0,0,22,23,0,0,38,10,0,0,152,28,0,0,14,47,0,0,224,15,0,0,6,36,0,0,60,4,0,0,50,23,0,0,146,45,0,0,94,8,0,0,252,26,0,0,32,46,0,0,2,15,0,0,46,33,0,0,86,3,0,0,46,22,0,0,214,40,0,0,236,29,0,0,122,11,0,0,36,17,0,0,112,48,0,0,184,5,0,0,66,37,0,0,248,42,0,0,116,24,0,0,46,28,0,0,186,9,0,0,190,43,0,0,66,49,0,0,172,30,0,0,80,25,0,0,214,13,0,0,132,25,0,0,70,45,0,0,10,14,0,0,78,8,0,0,240,26,0,0,146,19,0,0,246,37,0,0,72,32,0,0,226,0,0,0,144,43,0,0,62,12,0,0,134,24,0,0,228,18,0,0,80,37,0,0,186,26,0,0,128,48,0,0,20,43,0,0,18,49,0,0,132,30,0,0,86,12,0,0,156,43,0,0,110,23,0,0,124,4,0,0,66,36,0,0,210,17,0,0,66,0,0,0,68,32,0,0,18,13,0,0,118,44,0,0,24,26,0,0,128,5,0,0,38,37,0,0,174,18,0,0,206,14,0,0,6,33,0,0,242,0,0,0,24,17,0,0,230,27,0,0,46,7,0,0,240,25,0,0,60,44,0,0,140,16,0,0,202,34,0,0,182,43,0,0,108,12,0,0,158,30,0,0,58,49,0,0,242,17,0,0,104,36,0,0,120,9,0,0,252,41,0,0,196,37,0,0,28,28,0,0,126,33,0,0,72,15,0,0,230,20,0,0,146,1,0,0,58,11,0,0,198,42,0,0,112,23,0,0,228,28,0,0,114,10,0,0,34,16,0,0,86,47,0,0,150,2,0,0,0,25,0,0,114,43,0,0,178,37,0,0,24,34,0,0,140,50,0,0,206,11,0,0,216,13,0,0,36,32,0,0,60,23,0,0,208,41,0,0,176,3,0,0,108,48,0,0,18,17,0,0,118,11,0,0,220,29,0,0,112,24,0,0,242,1,0,0,180,21,0,0,156,15,0,0,204,33,0,0,90,28,0,0,180,46,0,0,108,41,0,0,212,9,0,0,216,3,0,0,194,22,0,0,180,27,0,0,246,32,0,0,236,0,0,0,22,22,0,0,170,14,0,0,252,8,0,0,120,13,0,0,188,44,0,0,32,3,0,0,198,7,0,0,102,39,0,0,250,20,0,0,132,1,0,0,148,33,0,0,64,47,0,0,30,43,0,0,80,27,0,0,154,8,0,0,118,36,0,0,188,21,0,0,84,14,0,0,122,34,0,0,194,28,0,0,50,47,0,0,6,16,0,0,80,34,0,0,66,4,0,0,78,23,0,0,196,41,0,0,72,10,0,0,20,27,0,0,106,45,0,0,224,7,0,0,146,26,0,0,228,44,0,0,110,15,0,0,174,33,0,0,198,1,0,0,138,48,0,0,6,30,0,0,138,35,0,0,84,48,0,0,140,24,0,0,212,5,0,0,136,11,0,0,22,43,0,0,186,46,0,0,184,15,0,0,142,12,0,0,60,25,0,0,84,6,0,0,12,14,0,0,46,45,0,0,40,0,0,0,42,14,0,0,110,32,0,0,12,27,0,0,88,45,0,0,150,24,0,0,102,6,0,0,76,0,0,0,150,19,0,0,96,12,0,0,140,30,0,0,0,50,0,0,138,44,0,0,42,13,0,0,146,5,0,0,232,23,0,0,172,8,0,0,246,17,0,0,36,49,0,0,162,30,0,0,90,12,0,0,26,42,0,0,140,23,0,0,154,4,0,0,90,36,0,0,178,19,0,0,108,0,0,0,164,38,0,0,68,20,0,0,246,0,0,0,56,31,0,0,192,22,0,0,64,44,0,0,42,3,0,0,10,22,0,0,162,16,0,0,234,34,0,0,178,27,0,0,254,45,0,0,176,40,0,0,26,9,0,0,244,4,0,0,0,24,0,0,30,4,0,0,178,48,0,0,110,17,0,0,4,10,0,0,146,28,0,0,6,23,0,0,30,38,0,0,174,19,0,0,114,25,0,0,130,6,0,0,58,14,0,0,110,45,0,0,96,0,0,0,96,32,0,0,36,40,0,0,148,21,0,0,42,30,0,0,186,35,0,0,96,17,0,0,190,24,0,0,254,5,0,0,184,11,0,0,208,29,0,0,72,48,0,0,8,17,0,0,86,35,0,0,0,20,0,0,134,22,0,0,4,41,0,0,140,9,0,0,16,28,0,0,196,25,0,0,162,37,0,0,36,6,0,0,186,44,0,0,90,43,0,0,246,11,0,0,70,30,0,0,162,14,0,0,196,45,0,0,126,27,0,0,220,8,0,0,114,38,0,0,44,20,0,0,204,0,0,0,226,32,0,0,194,12,0,0,234,10,0,0,196,13,0,0,250,44,0,0,184,26,0,0,18,6,0,0,64,22,0,0,32,19,0,0,214,48,0,0,30,17,0,0,36,12,0,0,106,30,0,0,40,25,0,0,132,43,0,0,234,37,0,0,72,6,0,0,44,47,0,0,24,16,0,0,228,6,0,0,172,0,0,0,20,20,0,0,124,14,0,0,196,32,0,0,78,9,0,0,142,33,0,0,84,15,0,0,238,20,0,0,160,1,0,0,194,7,0,0,128,31,0,0,184,44,0,0,142,26,0,0,104,35,0,0,4,17,0,0,184,32,0,0,88,38,0,0,8,20,0,0,174,25,0,0,220,6,0,0,154,12,0,0,30,5,0,0,222,36,0,0,0,5,0,0,14,24,0,0,22,44,0,0,214,12,0,0,8,31,0,0,166,49,0,0,56,20,0,0,140,38,0,0,120,26,0,0,160,44,0,0,112,13,0,0,108,33,0,0,134,27,0,0,60,20,0,0,116,2,0,0,96,34,0,0,22,16,0,0,68,47,0,0,118,18,0,0,94,10,0,0,214,41,0,0,94,23,0,0,82,4,0,0,42,36,0,0,114,1,0,0,96,33,0,0,38,15,0,0,64,46,0,0,252,27,0,0,96,9,0,0,158,19,0,0,254,37,0,0,88,32,0,0,50,0,0,0,170,43,0,0,72,12,0,0,116,6,0,0,74,25,0,0,228,17,0,0,82,36,0,0,174,10,0,0,250,21,0,0,134,40,0,0,0,33,0,0,238,0,0,0,226,45,0,0,208,3,0,0,122,35,0,0,90,41,0,0,178,22,0,0,248,29,0,0,52,47,0,0,42,17,0,0,126,48,0,0,228,1,0,0,196,33,0,0,234,2,0,0,240,8,0,0,120,40,0,0,172,47,0,0,56,29,0,0,180,34,0,0,172,19,0,0,56,0,0,0,124,6,0,0,4,38,0,0,78,45,0,0,2,27,0,0,92,32,0,0,32,14,0,0,128,21,0,0,50,2,0,0,182,18,0,0,84,24,0,0,136,5,0,0,56,13,0,0,126,44,0,0,242,49,0,0,54,11,0,0,186,29,0,0,122,17,0,0,240,16,0,0,54,35,0,0,150,3,0,0,12,30,0,0,0,41,0,0,112,9,0,0,14,28,0,0,110,18,0,0,118,30,0,0,14,49,0,0,178,17,0,0,58,36,0,0,98,4,0,0,166,45,0,0,114,27,0,0,198,8,0,0,94,40,0,0,178,15,0,0,200,0,0,0])
.concat([190,32,0,0,138,14,0,0,254,43,0,0,188,25,0,0,228,37,0,0,80,19,0,0,10,0,0,0,104,30,0,0,34,12,0,0,126,43,0,0,84,30,0,0,212,48,0,0,94,43,0,0,14,12,0,0,50,6,0,0,14,25,0,0,62,19,0,0,194,37,0,0,182,28,0,0,4,47,0,0,42,31,0,0,232,25,0,0,130,11,0,0,154,38,0,0,28,7,0,0,234,0,0,0,50,15,0,0,94,46,0,0,120,1,0,0,104,33,0,0,86,39,0,0,198,20,0,0,114,26,0,0,160,7,0,0,232,16,0,0,20,49,0,0,10,7,0,0,40,22,0,0,40,44,0,0,120,44,0,0,34,31,0,0,216,36,0,0,142,49,0,0,68,18,0,0,180,36,0,0,222,4,0,0,206,25,0,0,18,44,0,0,184,12,0,0,234,30,0,0,192,0,0,0,38,20,0,0,108,50,0,0,8,19,0,0,126,37,0,0,222,7,0,0,62,4,0,0,224,44,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,26,0,0,0,255,255,255,0,0,0,0,0,27,0,0,0,255,255,255,0,0,0,0,0,28,0,0,0,255,255,248,0,0,0,0,0,29,0,0,0,255,255,127,0,0,0,0,0,0,0,0,0,254,0,2,0,40,241,1,0,26,0,0,0,1,2,0,0,96,135,7,0,26,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,2,0,216,82,6,0,26,0,0,0,1,16,0,0,248,81,6,0,26,0,0,0,1,16,16,0,248,38,7,0,0,0,0,0,254,0,2,0,168,234,7,0,26,0,0,0,1,32,32,0,96,135,7,0,26,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,72,4,1,0,26,0,0,0,1,64,64,0,96,135,7,0,26,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,8,0,200,87,7,0,27,0,0,0,1,7,0,0,80,252,6,0,27,0,0,0,1,7,1,0,16,242,7,0,27,0,0,0,1,7,2,0,104,236,7,0,27,0,0,0,1,7,7,0,128,230,7,0,27,0,0,0,1,7,6,0,184,164,6,0,27,0,0,0,1,7,5,0,80,74,6,0,27,0,0,0,1,7,4,0,192,32,6,0,27,0,0,0,1,7,3,0,32,242,5,0,0,0,0,0,254,0,8,0,160,123,6,0,27,0,0,0,1,56,0,0,80,252,6,0,27,0,0,0,1,56,8,0,16,242,7,0,27,0,0,0,1,56,16,0,104,236,7,0,27,0,0,0,1,56,56,0,128,230,7,0,27,0,0,0,1,56,48,0,184,164,6,0,27,0,0,0,1,56,40,0,80,74,6,0,27,0,0,0,1,56,32,0,192,32,6,0,27,0,0,0,1,56,24,0,32,242,5,0,0,0,0,0,254,0,6,0,208,80,1,0,28,0,0,0,1,56,56,0,208,138,2,0,28,0,0,0,1,56,48,0,112,150,2,0,28,0,0,0,1,56,40,0,48,61,1,0,28,0,0,0,1,56,32,0,40,172,5,0,28,0,0,0,1,56,24,0,184,44,1,0,28,0,0,0,1,56,8,0,152,36,1,0,0,0,0,0,254,0,2,0,120,26,1,0,28,0,0,0,1,64,64,0,152,21,4,0,28,0,0,0,1,64,0,0,208,75,4,0,0,0,0,0,254,0,6,0,72,6,1,0,29,0,0,0,1,7,7,0,208,138,2,0,29,0,0,0,1,7,6,0,112,150,2,0,29,0,0,0,1,7,5,0,48,61,1,0,29,0,0,0,1,7,4,0,40,172,5,0,29,0,0,0,1,7,3,0,184,44,1,0,29,0,0,0,1,7,2,0,48,1,1,0,0,0,0,0,254,0,4,0,16,254,8,0,29,0,0,0,1,24,24,0,80,167,5,0,29,0,0,0,1,24,16,0,120,148,5,0,29,0,0,0,1,24,8,0,56,132,5,0,29,0,0,0,1,24,0,0,40,226,8,0,0,0,0,0,254,0,4,0,72,202,5,0,29,0,0,0,1,96,96,0,248,38,7,0,29,0,0,0,1,96,64,0,80,246,3,0,29,0,0,0,1,96,32,0,48,123,8,0,29,0,0,0,1,96,0,0,232,199,8,0,0,0,0,0,102,120,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,75,117,81,182,0,0,16,1,102,120,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,193,220,210,243,0,0,16,1,102,120,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,107,223,7,137,0,0,16,1,102,120,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,79,131,101,198,0,0,16,1,102,120,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,134,66,80,74,0,0,32,0,49,55,46,57,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,88,20,33,65,0,0,32,0,49,56,46,49,48,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,212,204,14,116,0,0,32,0,49,54,46,49,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,219,165,244,193,0,0,32,0,49,52,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,71,4,76,61,0,0,32,0,49,51,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,103,74,65,34,0,0,32,0,49,50,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,131,66,227,97,0,0,32,0,49,49,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,239,255,186,187,0,0,32,0,49,48,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,151,79,86,222,0,0,32,0,57,46,49,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,21,200,13,137,0,0,32,0,109,114,46,49,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,110,67,10,17,0,0,32,0,109,103,46,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,240,217,191,15,0,0,32,0,109,98,46,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,12,137,66,163,0,0,32,0,109,50,46,53,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,173,85,10,25,0,0,32,0,109,49,46,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,1,146,163,131,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,0,0,255,255,192,0,0,0,0,0,16,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,4,0,200,87,7,0,15,0,0,0,1,3,0,0,200,201,5,0,15,0,0,0,1,3,1,0,152,160,5,0,15,0,0,0,1,3,2,0,144,127,5,0,15,0,0,0,1,3,3,0,224,189,3,0,0,0,0,0,254,0,4,0,160,123,6,0,15,0,0,0,1,12,4,0,224,67,5,0,15,0,0,0,1,12,0,0,200,201,5,0,15,0,0,0,1,12,8,0,152,160,5,0,15,0,0,0,1,12,12,0,144,127,5,0,0,0,0,0,254,0,4,0,128,129,4,0,15,0,0,0,1,48,48,0,208,75,4,0,15,0,0,0,1,48,0,0,8,49,4,0,15,0,0,0,1,48,16,0,152,21,4,0,15,0,0,0,1,48,32,0,72,246,3,0,0,0,0,0,254,0,2,0,200,30,2,0,15,0,0,0,1,64,64,0,120,97,1,0,15,0,0,0,1,64,0,0,96,19,1,0,0,0,0,0,254,0,2,0,80,105,6,0,15,0,0,0,1,128,0,0,96,135,7,0,15,0,0,0,1,128,128,0,152,182,7,0,0,0,0,0,254,0,4,0,224,202,4,0,16,0,0,0,1,7,0,0,176,116,6,0,16,0,0,0,1,7,1,0,160,191,4,0,16,0,0,0,1,7,2,0,152,53,6,0,16,0,0,0,1,7,3,0,8,49,6,0,16,0,0,0,1,7,4,0,160,191,4,0,16,0,0,0,1,7,5,0,8,49,6,0,16,0,0,0,1,7,6,0,160,191,4,0,16,0,0,0,1,7,7,0,8,49,6,0,0,0,0,0,254,0,4,0,120,57,4,0,16,0,0,0,1,24,0,0,80,246,3,0,16,0,0,0,1,24,8,0,80,124,6,0,16,0,0,0,1,24,16,0,112,212,3,0,16,0,0,0,1,24,24,0,248,160,5,0,0,0,0,0,254,0,4,0,232,167,3,0,16,0,0,0,1,96,32,0,80,246,3,0,16,0,0,0,1,96,0,0,80,124,6,0,16,0,0,0,1,96,64,0,112,212,3,0,16,0,0,0,1,96,96,0,248,160,5,0,0,0,0,0,254,0,2,0,72,142,3,0,16,0,0,0,1,128,0,0,80,246,3,0,16,0,0,0,1,128,128,0,112,212,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,34,147,0,217,34,147,0,216,34,147,0,96,97,215,0,255,255,255,255,0,0,0,0,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,57,0,130,174,44,157,75,115,251,172,212,109,109,91,119,192,0,0,0,0,0,0,0,0,17,74,56,152,172,57,178,85,114,243,123,60,238,148,110,213,65,188,147,208,69,125,73,104,177,96,84,239,162,132,41,32,166,82,137,4,8,105,159,36,70,244,61,195,241,37,171,45,230,44,164,81,167,181,229,136,189,11,90,53,91,199,174,95,10,207,185,217,226,99,198,118,33,43,119,192,39,144,253,9,48,140,150,46,146,153,187,190,14,186,191,128,231,183,233,55,28,209,92,173,34,23,197,103,157,246,251,35,201,75,50,180,16,67,83,124,1,254,120,145,64,133,163,232,223,219,255,108,182,21,203,142,7,130,112,141,78,221,102,122,98,111,211,106,62,22,68,30,237,100,18,154,126,5,6,206,155,138,247,248,3,38,113,116,168,19,194,66,234,249,127,169,175,86,214,179,87,196,71,49,107,170,88,139,72,27,245,117,149,143,240,58,135,115,89,20,12,215,0,176,220,252,101,52,222,250,216,193,134,94,227,158,2,40,80,129,151,47,228,165,160,77,161,54,93,24,109,121,25,59,29,184,225,204,97,26,224,51,76,63,156,200,212,218,205,210,131,202,235,79,242,15,13,42,236,31,0,0,0,0,0,0,0,0,54,1,0,0,112,20,0,0,214,38,0,0,86,7,0,0,8,26,0,0,106,44,0,0,4,13,0,0,102,31,0,0,60,3,0,0,28,22,0,0,198,30,0,0,96,49,0,0,114,3,0,0,128,36,0,0,174,4,0,0,198,23,0,0,96,36,0,0,0,18,0,0,68,49,0,0,174,30,0,0,150,10,0,0,40,42,0,0,156,23,0,0,212,25,0,0,102,25,0,0,194,19,0,0,14,50,0,0,60,36,0,0,64,13,0,0,238,42,0,0,110,24,0,0,168,5,0,0,120,32,0,0,88,0,0,0,104,45,0,0,54,14,0,0,154,6,0,0,110,25,0,0,200,19,0,0,22,38,0,0,156,30,0,0,54,49,0,0,178,11,0,0,248,5,0,0,188,24,0,0,84,17,0,0,182,35,0,0,40,30,0,0,70,17,0,0,154,48,0,0,236,3,0,0,158,35,0,0,28,43,0,0,156,24,0,0,22,30,0,0,154,11,0,0,146,15,0,0,208,46,0,0,202,30,0,0,138,36,0,0,36,18,0,0,160,25,0,0,186,6,0,0,146,12,0,0,62,47,0,0,20,16,0,0,94,34,0,0,110,2,0,0,90,23,0,0,238,41,0,0,88,10,0,0,224,28,0,0,118,45,0,0,68,14,0,0,94,33,0,0,110,1,0,0,176,20,0,0,240,40,0,0,92,9,0,0,250,27,0,0,234,31,0,0,140,13,0,0,206,44,0,0,250,3,0,0,212,7,0,0,158,39,0,0,4,21,0,0,186,1,0,0,30,30,0,0,166,11,0,0,64,2,0,0,66,34,0,0,240,15,0,0,30,47,0,0,168,28,0,0,52,10,0,0,62,21,0,0,228,39,0,0,216,33,0,0,254,1,0,0,60,27,0,0,166,15,0,0,236,9,0,0,100,28,0,0,244,22,0,0,118,41,0,0,4,50,0,0,140,44,0,0,46,13,0,0,126,7,0,0,54,26,0,0,154,20,0,0,212,12,0,0,38,44,0,0,162,49,0,0,38,31,0,0,218,36,0,0,210,5,0,0,10,24,0,0,250,4,0,0,6,11,0,0,132,42,0,0,102,33,0,0,88,39,0,0,206,20,0,0,116,26,0,0,158,7,0,0,110,13,0,0,220,42,0,0,102,11,0,0,210,29,0,0,102,48,0,0,12,17,0,0,110,35,0,0,168,3,0,0,162,22,0,0,44,41,0,0,178,9,0,0,8,22,0,0,168,40,0,0,18,9,0,0,166,27,0,0,252,45,0,0,192,14,0,0,160,10,0,0,250,8,0,0,128,40,0,0,244,21,0,0,232,0,0,0,242,32,0,0,166,14,0,0,222,45,0,0,234,25,0,0,30,7,0,0,104,41,0,0,220,22,0,0,212,3,0,0,202,33,0,0,154,15,0,0,176,46,0,0,186,4,0,0,108,36,0,0,30,18,0,0,70,49,0,0,64,29,0,0,176,10,0,0,64,42,0,0,180,23,0,0,178,6,0,0,70,38,0,0,134,0,0,0,90,7,0,0,218,38,0,0,146,18,0,0,214,49,0,0,110,31,0,0,132,0,0,0,160,14,0,0,80,14,0,0,150,32,0,0,142,25,0,0,198,43,0,0,46,38,0,0,156,6,0,0,80,49,0,0,136,34,0,0,68,37,0,0,182,31,0,0,38,50,0,0,2,43,0,0,126,11,0,0,190,5,0,0,190,35,0,0,180,49,0,0,0,23,0,0,240,3,0,0,182,11,0,0,58,43,0,0,82,38,0,0,132,27,0,0,12,34,0,0,174,15,0,0,128,6,0,0,106,12,0,0,174,43,0,0,94,0,0,0,94,32,0,0,32,38,0,0,32,16,0,0,106,34,0,0,148,2,0,0,176,21,0,0,244,41,0,0,110,10,0,0,226,28,0,0,84,47,0,0,88,14,0,0,164,32,0,0,4,45,0,0,192,13,0,0,16,32,0,0,244,1,0,0,52,21,0,0,214,39,0,0,94,50,0,0,254,31,0,0,176,13,0,0,244,44,0,0,162,26,0,0,244,7,0,0,160,39,0,0,32,21,0,0,176,48,0,0,56,30,0,0,136,14,0,0,162,45,0,0,108,27,0,0,216,8,0,0,92,40,0,0,218,21,0,0,250,39,0,0,44,8,0,0,14,2,0,0,82,21,0,0,98,39,0,0,4,34,0,0,126,28,0,0,224,46,0,0,146,41,0,0,240,9,0,0,2,26,0,0,96,20,0,0,206,38,0,0,22,33,0,0,14,1,0,0,12,46,0,0,54,1,0,0,112,20,0,0,214,38,0,0,86,7,0,0,8,26,0,0,106,44,0,0,4,13,0,0,102,31,0,0,60,3,0,0,28,22,0,0,198,30,0,0,96,49,0,0,114,3,0,0,128,36,0,0,174,4,0,0,198,23,0,0,96,36,0,0,0,18,0,0,68,49,0,0,174,30,0,0,150,10,0,0,40,42,0,0,156,23,0,0,212,25,0,0,102,25,0,0,194,19,0,0,14,50,0,0,60,36,0,0,64,13,0,0,238,42,0,0,110,24,0,0,168,5,0,0,120,32,0,0,88,0,0,0,104,45,0,0,54,14,0,0,154,6,0,0,110,25,0,0,200,19,0,0,22,38,0,0,156,30,0,0,54,49,0,0,178,11,0,0,248,5,0,0,188,24,0,0,84,17,0,0,182,35,0,0,40,30,0,0,70,17,0,0,154,48,0,0,236,3,0,0,158,35,0,0,28,43,0,0,156,24,0,0,22,30,0,0,154,11,0,0,146,15,0,0,208,46,0,0,202,30,0,0,138,36,0,0,36,18,0,0,160,25,0,0,186,6,0,0,146,12,0,0,62,47,0,0,20,16,0,0,94,34,0,0,110,2,0,0,90,23,0,0,238,41,0,0,88,10,0,0,224,28,0,0,118,45,0,0,68,14,0,0,94,33,0,0,110,1,0,0,176,20,0,0,240,40,0,0,92,9,0,0,250,27,0,0,234,31,0,0,140,13,0,0,206,44,0,0,250,3,0,0,212,7,0,0,158,39,0,0,4,21,0,0,186,1,0,0,30,30,0,0,166,11,0,0,64,2,0,0,66,34,0,0,240,15,0,0,30,47,0,0,168,28,0,0,52,10,0,0,62,21,0,0,110,49,0,0,216,33,0,0,150,36,0,0,60,27,0,0,120,48,0,0,236,9,0,0,152,12,0,0,244,22,0,0,198,47,0,0,4,50,0,0,124,7,0,0,46,13,0,0,190,49,0,0,54,26,0,0,80,33,0,0,212,12,0,0,254,46,0,0,162,49,0,0,26,10,0,0,218,36,0,0,38,23,0,0,10,24,0,0,234,35,0,0,6,11,0,0,60,45,0,0,102,33,0,0,42,46,0,0,206,20,0,0,62,9,0,0,158,7,0,0,60,22,0,0,220,42,0,0,102,11,0,0,210,29,0,0,102,48,0,0,12,17,0,0,110,35,0,0,168,3,0,0,162,22,0,0,44,41,0,0,178,9,0,0,8,22,0,0,168,40,0,0,18,9,0,0,166,27,0,0,252,45,0,0,192,14,0,0,160,10,0,0,250,8,0,0,128,40,0,0,244,21,0,0,232,0,0,0,242,32,0,0,166,14,0,0,222,45,0,0,234,25,0,0,30,7,0,0,104,41,0,0,220,22,0,0,90,21,0,0,202,33,0,0,244,9,0,0,176,46,0,0,186,4,0,0,108,36,0,0,30,18,0,0,70,49,0,0,64,29,0,0,176,10,0,0,64,42,0,0,180,23,0,0,178,6,0,0,70,38,0,0,134,0,0,0,104,24,0,0,218,38,0,0,146,18,0,0,214,49,0,0,110,31,0,0,132,0,0,0,160,14,0,0,80,14,0,0,150,32,0,0,142,25,0,0,198,43,0,0,46,38,0,0,156,6,0,0,80,49,0,0,136,34,0,0,68,37,0,0,182,31,0,0,38,50,0,0,2,43,0,0,126,11,0,0,190,5,0,0,190,35,0,0,180,49,0,0,0,23,0,0,240,3,0,0,182,11,0,0,58,43,0,0,82,38,0,0,132,27,0,0,12,34,0,0,174,15,0,0,128,6,0,0,106,12,0,0,174,43,0,0,94,0,0,0,94,32,0,0,32,38,0,0,32,16,0,0,106,34,0,0,148,2,0,0,176,21,0,0,244,41,0,0,110,10,0,0,226,28,0,0,84,47,0,0,88,14,0,0,164,32,0,0,4,45,0,0,192,13,0,0,16,32,0,0,244,1,0,0,52,21,0,0,214,39,0,0,94,50,0,0,92,46,0,0,176,13,0,0,138,33,0,0,162,26,0,0,234,20,0,0,160,39,0,0,192,7,0,0,176,48,0,0,180,44,0,0,136,14,0,0,210,12,0,0,108,27,0,0,160,49,0,0,92,40,0,0,214,36,0,0,250,39,0,0,20,5,0,0,14,2,0,0,198,27,0,0,98,39,0,0,16,44,0,0,126,28,0,0,6,31,0,0,146,41,0,0,144,16,0,0,2,26,0,0,6,19,0,0,206,38,0,0,220,7,0,0,14,1,0,0,222,44,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,14,13,12,11,10,9,8,7,6,5,4,3,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,14,13,12,11,10,9,8,7,6,5,4,3,2,1,0,15,14,13,12,11,10,9,8,7,6,5,4,3,2,1,0,15,14,13,12,11,10,9,8,7,6,5,4,3,2,1,0,15,14,13,12,11,10,9,8,7,6,5,4,3,2,1,0,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,15,14,13,12,11,10,9,8,7,6,5,4,3,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,15,14,13,12,11,10,9,8,7,6,5,4,3,2,1,0,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,15,14,13,12,11,10,9,8,7,6,5,4,3,2,1,0,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,42,74,57,152,172,57,178,85,114,243,123,60,238,148,110,213,205,188,154,208,69,125,73,104,177,97,84,239,162,132,41,32,50,82,130,4,56,105,159,36,70,244,63,194,241,37,172,45,223,45,180,81,199,181,229,136,189,59,90,37,91,199,174,95,67,207,137,217,226,99,198,118,33,43,119,192,39,152,253,9,225,140,38,46,146,153,188,190,14,186,191,112,231,183,233,55,92,209,94,173,34,23,197,103,157,198,251,83,199,77,50,180,242,67,83,124,1,254,210,145,64,133,163,232,223,219,255,108,100,21,205,142,7,130,120,141,78,45,102,138,98,111,211,106,174,22,68,30,237,196,18,122,190,5,6,206,155,138,247,248,116,35,115,116,184,19,194,66,234,249,127,169,175,86,214,179,183,196,71,49,103,170,88,139,71,27,245,117,149,143,240,58,133,118,89,36,12,215,0,179,220,252,101,52,222,250,216,195,195,94,227,158,2,40,80,129,149,47,228,181,160,77,161,54,157,24,109,121,25,59,29,184,225,204,97,26,226,49,76,63,220,202,212,218,205,210,131,202,235,79,242,47,45,42,236,31,1,2,4,8,16,32,64,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,1,0,3,0,0,2,0,6,0,34,4,0,3,0,0,6,0,32,7,0,3,0,33,1,0,0,99,0,0,9,10,11,0,1,2,3,4,5,6,7,8,0,0,0,0,93,0,134,0,140,0,139,0,224,0,139,0,98,0,175,0,182,0,175,0,10,1,175,0,0,0,0,0,0,0,0,0,2,3,4,5,6,1,10,11,12,13,14,9,0,0,0,0,5,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,16,14,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,2,2,2,2,2,2,3,3,3,4,4,4,3,3,3,0,0,0,0,0,3,3,4,4,4,4,5,5,5,5,6,6,3,3,4,4,5,5,5,5,6,6,7,7,3,3,4,4,5,5,5,5,6,6,7,7,6,6,6,6,6,6,6,7,7,7,7,7,6,6,6,6,6,6,7,7,7,7,8,8,5,5,5,5,5,5,5,6,6,6,7,7,6,6,6,7,7,7,8,8,9,9,9,9,7,7,7,7,7,8,8,8,8,9,9,9,6,6,7,7,7,8,8,8,8,8,9,9,5,5,6,6,6,7,7,8,8,8,8,9,7,7,7,7,7,8,8,8,8,9,9,9,6,6,7,3,7,6,7,7,8,7,5,4,3,3,4,4,5,5,6,6,6,6,6,6,3,4,4,4,4,5,5,6,6,6,6,7,4,4,5,5,6,6,6,6,6,7,7,8,5,5,6,7,7,8,8,8,8,8,8,8,5,5,5,7,7,7,7,7,7,8,8,8,8,8,9,9,9,9,3,4,4,5,5,5,6,6,7,7,7,7,8,8,8,9,9,9,3,4,5,5,4,3,4,4,4,5,5,4,3,3,3,3,3,3,3,3,3,3,3,4,4,4,4,4,4,4,4,4,4,3,3,3,3,3,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,72,124,0,16,108,126,0,160,9,126,0,16,107,124,0,112,83,124,0,160,156,123,0,240,136,123,0,64,135,123,0,96,1,123,0,32,255,122,0,32,17,123,0,16,115,122,0,48,66,121,0,0,127,120,0,128,188,126,0,240,187,126,0,96,187,126,0,48,184,123,0,112,186,123,0,176,65,120,0,32,65,120,0,0,64,120,0,144,64,120,0,112,63,120,0,96,64,114,0,176,243,125,0,96,245,125,0,208,244,125,0,64,244,125,0,192,179,122,0,224,180,122,0,80,180,122,0,112,181,122,0,48,179,122,0,0,21,115,0,208,175,122,0,96,176,122,0,240,176,122,0,16,178,122,0,128,177,122,0,160,178,122,0,64,175,122,0,112,241,125,0,0,242,125,0,144,242,125,0,32,243,125,0,64,87,126,0,48,190,126,0,80,240,125,0,128,237,125,0,48,239,125,0,224,240,125,0,192,239,125,0,160,238,125,0,16,238,125,0,192,61,120,0,176,164,120,0,32,164,120,0,144,163,120,0,80,62,120,0,112,20,115,0,160,189,126,0,48,61,120,0,160,60,120,0,16,60,120,0,32,67,124,0,16,17,124,0,128,59,120,0,16,189,126,0,160,17,124,0,96,58,120,0,128,181,121,0,240,58,120,0,16,151,122,0,160,71,124,0,80,174,119,0,192,173,119,0,0,41,119,0,208,12,120,0,176,185,126,0,64,186,126,0,160,180,126,0,176,56,120,0,208,57,120,0,64,57,120,0,32,182,120,0,0,184,126,0,112,183,126,0,224,182,126,0,48,181,126,0,192,181,126,0,80,182,126,0,0,55,120,0,112,54,120,0,208,186,126,0,192,16,120,0,48,52,120,0,192,43,120,0,192,18,115,0,240,163,123,0,48,43,120,0,80,41,114,0,48,18,115,0,208,39,120,0,16,180,126,0,128,179,126,0,240,178,126,0,192,58,114,0,48,58,114,0,160,42,120,0,64,39,120,0,176,38,120,0,16,42,120,0,128,41,120,0,240,40,120,0,96,40,120,0,32,185,126,0,144,184,126,0,224,19,115,0,32,56,120,0,144,55,120,0,112,104,121,0,80,179,120,0,96,178,126,0,208,177,126,0,160,75,123,0,224,173,126,0,80,173,126,0,48,172,126,0,160,171,126,0,112,36,120,0,192,172,126,0,80,35,120,0,224,35,120,0,16,171,126,0,64,177,126,0,176,176,126,0,32,176,126,0,144,175,126,0,0,175,126,0,112,174,126,0,192,34,120,0,48,34,120,0,128,170,126,0,240,169,126,0,96,169,126,0,208,168,126,0,176,167,126,0,64,168,126,0,160,33,120,0,128,32,120,0,32,167,126,0,208,63,114,0,144,28,120,0,176,29,120,0,64,30,120,0,32,29,120,0,0,28,120,0,0,166,126,0,144,166,126,0,0,181,120,0,224,164,126,0,112,165,126,0,80,19,115,0,112,42,114,0,16,162,126,0,80,26,120,0,192,25,120,0,240,124,126,0,96,124,126,0,128,125,126,0,16,126,126,0,16,6,120,0,112,156,126,0,64,159,126,0,176,158,126,0,208,159,126,0,32,158,126,0,0,157,126,0,144,157,126,0,16,229,125,0,128,228,125,0,160,229,125,0,240,227,125,0,96,227,125,0,208,226,125,0,224,26,120,0,112,27,120,0,160,162,126,0,128,161,126,0,240,160,126,0,96,160,126,0,80,164,126,0,192,163,126,0,48,163,126,0,48,25,120,0,160,24,120,0,16,24,120,0,224,155,126,0,80,155,126,0,240,151,126,0,128,23,120,0,48,154,126,0,160,153,126,0,16,153,126,0,128,152,126,0,192,154,126,0,32,149,126,0,144,148,126,0,0,148,126,0,112,147,126,0,208,141,126,0,96,22,120,0,224,146,126,0,192,145,126,0,80,146,126,0,48,145,126,0,160,144,126,0,16,144,126,0,128,143,126,0,32,38,120,0,144,37,120,0,0,37,120,0,224,179,120,0,240,142,126,0,64,21,120,0,176,20,120,0,16,17,115,0,32,20,120,0,96,142,126,0,128,16,115,0,80,187,118,0,224,137,126,0,240,15,115,0,224,17,120,0,192,136,126,0,48,136,126,0,80,137,126,0,160,135,126,0,192,178,120,0,48,178,120,0,16,135,126,0,128,134,126,0,48,16,120,0,160,15,120,0,240,133,126,0,128,14,120,0,96,13,120,0,240,13,120,0,144,233,125,0,32,234,125,0,208,18,123,0,64,13,122,0,0,172,120,0,112,171,120,0,208,174,120,0,224,170,120,0,160,177,120,0,16,177,120,0,128,176,120,0,240,175,120,0,80,170,120,0,64,174,120,0,160,168,120,0,192,169,120,0,48,169,120,0,96,175,120,0,96,133,126,0,208,132,126,0,64,132,126,0,176,131,126,0,32,131,126,0,144,130,126,0,96,15,115,0,144,103,126,0,32,104,126,0,224,101,126,0,192,100,126,0,112,102,126,0,80,101,126,0,0,103,126,0,0,130,126,0,112,129,126,0,224,231,125,0,48,230,125,0,112,232,125,0,80,231,125,0,0,233,125,0,192,230,125,0,176,11,120,0,32,11,120,0,144,10,120,0,0,10,120,0,144,19,120,0,0,19,120,0,112,18,120,0,176,140,126,0,144,139,126,0,32,140,126,0,112,138,126,0,0,139,126,0,112,9,120,0,208,14,115,0,224,128,126,0,192,127,126,0,48,127,126,0,80,128,126,0,224,8,120,0,208,47,118,0,80,8,120,0,192,7,120,0,48,7,120,0,160,6,120,0,208,123,126,0,176,122,126,0,64,123,126,0,32,122,126,0,144,121,126,0,160,126,126,0,0,121,126,0,144,181,120,0,208,114,126,0,96,115,126,0,64,114,126,0,176,113,126,0,240,4,120,0,128,5,120,0,64,14,115,0,96,4,120,0,208,3,120,0,64,3,120,0,80,255,119,0,224,255,119,0,112,0,120,0,0,1,120,0,144,1,120,0,32,2,120,0,176,2,120,0,192,254,119,0,0,112,126,0,144,112,126,0,32,113,126,0,48,254,119,0,176,13,115,0,160,253,119,0,224,110,126,0,112,111,126,0,16,253,119,0,128,252,119,0,240,251,119,0,96,251,119,0,80,150,116,0,192,149,116,0,80,110,126,0,192,109,126,0,48,55,126,0,192,91,126,0,48,91,126,0,48,200,119,0,160,199,119,0,64,250,119,0,176,249,119,0,208,250,119,0,32,249,119,0,144,248,119,0,128,167,120,0,160,45,126,0,0,248,119,0,112,247,119,0,48,109,126,0,160,108,126,0,224,246,119,0,128,107,126,0,80,246,119,0,240,166,120,0,240,106,126,0,96,106,126,0,192,245,119,0,192,40,114,0,144,12,115,0,208,105,126,0,48,245,119,0,16,168,120,0,96,166,120,0,208,165,120,0,64,165,120,0,64,105,126,0,160,244,119,0,16,244,119,0,128,207,119,0,240,206,119,0,96,206,119,0,0,12,115,0,128,243,119,0,240,242,119,0,96,242,119,0,208,241,119,0,112,11,115,0,144,239,119,0,128,44,126,0,240,43,126,0,16,45,126,0,0,239,119,0,112,238,119,0,80,10,115,0,224,237,119,0,192,236,119,0,16,235,119,0,48,236,119,0,80,237,119,0,176,104,126,0,160,235,119,0,160,99,126,0,48,100,126,0,16,99,126,0,64,63,114,0,128,98,126,0,96,97,126,0,240,97,126,0,80,92,126,0,176,225,125,0,32,225,125,0,64,226,125,0,144,224,125,0,128,131,120,0,176,86,126,0,0,85,126,0,208,87,126,0,32,86,126,0,96,88,126,0,144,85,126,0,96,233,119,0,96,43,126,0,224,10,115,0,80,183,119,0,192,182,119,0,240,115,126,0,16,117,126,0,128,116,126,0,48,40,114,0,80,47,126,0,192,46,126,0,48,46,126,0,224,47,126,0,240,233,119,0,128,234,119,0,224,183,119,0,160,181,119,0,48,182,119,0,176,95,126,0,32,95,126,0,64,96,126,0,192,9,115,0,0,230,119,0,144,230,119,0,176,231,119,0,112,162,120,0,80,228,119,0,192,227,119,0,48,227,119,0,48,162,124,0,160,161,124,0,16,161,124,0,128,160,124,0,240,159,124,0,192,162,124,0,208,158,124,0,64,158,124,0,176,157,124,0,32,157,124,0,144,156,124,0,96,159,124,0,0,156,124,0,112,155,124,0,224,154,124,0,80,154,124,0,192,153,124,0,80,163,124,0,16,63,126,0,160,226,119,0,128,89,126,0,176,213,119,0,64,214,119,0,240,88,126,0,32,213,119,0,144,212,119,0,0,212,119,0,16,94,125,0,112,211,119,0,112,84,126,0,224,161,120,0,224,83,126,0,80,83,126,0,48,9,115,0,160,8,115,0,192,209,119,0,80,210,119,0,48,209,119,0,160,208,119,0,16,208,119,0,16,81,126,0,160,81,126,0,48,82,126,0,80,161,120,0,192,160,120,0,48,160,120,0,160,159,120,0,0,224,116,0,0,76,126,0,144,76,126,0,112,75,126,0,224,74,126,0,80,74,126,0,192,73,126,0,160,72,126,0,240,157,120,0,48,73,126,0,96,61,126,0,208,205,119,0,96,79,126,0,208,78,126,0,0,203,119,0,112,202,119,0,64,78,126,0,160,39,114,0,128,158,120,0,144,172,120,0,32,173,120,0,96,70,126,0,32,68,126,0,240,70,126,0,144,67,126,0,208,69,126,0,64,69,126,0,176,68,126,0,32,77,126,0,0,67,126,0,176,77,126,0,64,205,119,0,176,204,119,0,16,8,115,0,16,72,126,0,128,71,126,0,112,66,126,0,224,65,126,0,80,65,126,0,192,64,126,0,32,204,119,0,16,39,114,0,160,63,126,0,48,64,126,0,144,203,119,0,128,62,126,0,240,61,126,0,16,159,120,0,32,155,120,0,208,60,126,0,240,6,115,0,128,198,119,0,16,199,119,0,240,197,119,0,176,195,119,0,64,196,119,0,208,196,119,0,96,197,119,0,64,60,126,0,144,58,126,0,32,59,126,0,0,58,126,0,112,57,126,0,224,56,126,0,32,195,119,0,176,59,126,0,80,56,126,0,112,93,126,0,0,94,126,0,96,6,115,0,128,38,114,0,240,37,114,0,208,5,115,0,64,5,115,0,176,4,115,0,32,4,115,0,128,80,126,0,240,79,126,0,144,194,119,0,80,201,119,0,224,201,119,0,192,200,119,0,192,55,126,0,64,36,114,0,96,37,114,0,208,36,114,0,0,194,119,0,48,191,119,0,192,191,119,0,80,192,119,0,224,192,119,0,112,193,119,0,128,53,126,0,160,54,126,0,16,54,126,0,240,52,126,0,160,190,119,0,16,190,119,0,208,51,126,0,96,52,126,0,128,189,119,0,176,50,126,0,64,51,126,0,208,198,114,0,144,49,126,0,32,50,126,0,144,94,126,0,240,188,119,0,176,35,114,0,112,184,119,0,0,49,126,0,112,31,119,0,224,30,119,0,32,35,114,0,0,3,115,0,96,157,120,0,208,156,120,0,96,188,119,0,112,48,126,0,32,186,119,0,176,186,119,0,64,187,119,0,208,187,119,0])
.concat([64,156,120,0,144,185,119,0,0,185,119,0,16,181,119,0,128,180,119,0,240,179,119,0,176,41,126,0,96,179,119,0,208,178,119,0,144,40,126,0,208,42,126,0,32,41,126,0,0,40,126,0,64,42,126,0,224,38,126,0,112,39,126,0,112,2,115,0,176,177,119,0,64,178,119,0,176,155,120,0,80,38,126,0,192,37,126,0,32,177,119,0,144,176,119,0,0,176,119,0,112,175,119,0,224,174,119,0,224,1,115,0,48,37,126,0,160,36,126,0,48,173,119,0,128,171,119,0,128,35,126,0,80,1,115,0,96,34,126,0,240,34,126,0,208,33,126,0,96,170,119,0,208,169,119,0,64,169,119,0,112,249,114,0,224,92,126,0,64,33,126,0,176,32,126,0,32,32,126,0,0,31,126,0,112,30,126,0,224,29,126,0,80,29,126,0,192,28,126,0,176,168,119,0,144,31,126,0,144,34,114,0,192,0,115,0,176,189,125,0,128,183,125,0,80,186,125,0,192,185,125,0,48,185,125,0,144,188,125,0,0,188,125,0,32,189,125,0,160,184,125,0,16,184,125,0,224,186,125,0,32,168,119,0,144,167,119,0,0,167,119,0,80,165,119,0,112,166,119,0,48,28,126,0,224,165,119,0,160,27,126,0,96,25,126,0,128,26,126,0,16,27,126,0,240,25,126,0,144,154,120,0,208,24,126,0,80,156,119,0,192,212,125,0,80,213,125,0,224,213,125,0,48,212,125,0,160,211,125,0,16,211,125,0,112,214,125,0,240,186,124,0,128,210,125,0,208,155,118,0,192,164,119,0,48,164,119,0,160,163,119,0,192,221,125,0,160,220,125,0,48,221,125,0,80,222,125,0,0,224,125,0,112,223,125,0,224,222,125,0,16,163,119,0,128,162,119,0,240,161,119,0,112,191,124,0,0,192,124,0,224,143,120,0,240,218,125,0,128,219,125,0,208,217,125,0,16,220,125,0,64,217,125,0,112,157,119,0,0,158,119,0,16,82,119,0,48,83,119,0,160,82,119,0,64,24,126,0,80,143,120,0,176,23,126,0,32,23,126,0,32,5,126,0,144,4,126,0,176,5,126,0,64,6,126,0,224,156,119,0,160,18,126,0,48,19,126,0,192,155,119,0,0,81,118,0,48,0,115,0,224,23,114,0,16,154,119,0,48,155,119,0,160,154,119,0,80,102,119,0,0,140,119,0,48,116,122,0,144,215,125,0,128,43,115,0,16,18,126,0,240,16,126,0,96,16,126,0,128,17,126,0,96,152,119,0,208,151,119,0,208,15,126,0,64,15,126,0,64,151,119,0,176,150,119,0,32,14,126,0,144,13,126,0,176,14,126,0,32,150,119,0,144,149,119,0,0,149,119,0,112,148,119,0,224,147,119,0,112,33,114,0,0,13,126,0,192,146,119,0,240,216,121,0,16,255,114,0,80,147,119,0,16,69,120,0,176,216,125,0,48,146,119,0,160,145,119,0,128,254,114,0,240,253,114,0,112,12,126,0,224,32,114,0,16,145,119,0,128,144,119,0,240,143,119,0,112,153,120,0,32,216,125,0,224,11,126,0,112,228,117,0,144,41,119,0,224,41,123,0,112,42,123,0,80,116,120,0,192,115,120,0,144,3,115,0,96,143,119,0,208,142,119,0,176,141,119,0,64,142,119,0,32,141,119,0,144,140,119,0,96,246,118,0,192,10,126,0,48,10,126,0,80,11,126,0,80,91,124,0,208,252,114,0,64,252,114,0,112,139,119,0,224,138,119,0,80,138,119,0,192,137,119,0,48,137,119,0,160,136,119,0,16,136,119,0,208,6,126,0,96,7,126,0,128,135,119,0,80,2,126,0,0,4,126,0,112,3,126,0,224,2,126,0,0,154,120,0,240,134,119,0,96,134,119,0,144,122,119,0,32,123,119,0,176,123,119,0,64,124,119,0,208,124,119,0,96,125,119,0,240,125,119,0,128,126,119,0,16,127,119,0,160,127,119,0,48,128,119,0,192,128,119,0,80,129,119,0,224,129,119,0,112,130,119,0,0,131,119,0,144,131,119,0,32,132,119,0,176,132,119,0,208,133,119,0,64,133,119,0,0,122,119,0,176,251,114,0,224,152,120,0,224,120,119,0,112,121,119,0,80,120,119,0,192,119,119,0,48,119,119,0,160,118,119,0,80,152,120,0,16,118,119,0,96,116,119,0,32,114,119,0,128,117,119,0,240,116,119,0,16,109,119,0,160,109,119,0,208,115,119,0,64,115,119,0,176,114,119,0,224,111,119,0,48,110,119,0,192,110,119,0,80,111,119,0,0,113,119,0,112,112,119,0,144,113,119,0,240,107,119,0,48,1,126,0,192,1,126,0,128,255,125,0,16,0,126,0,128,108,119,0,96,107,119,0,96,254,125,0,208,253,125,0,64,253,125,0,240,254,125,0,144,251,125,0,0,251,125,0,112,250,125,0,176,252,125,0,32,252,125,0,208,106,119,0,64,106,119,0,224,249,125,0,80,249,125,0,192,248,125,0,176,105,119,0,32,105,119,0,144,104,119,0,0,104,119,0,112,103,119,0,32,251,114,0,144,250,114,0,144,22,126,0,48,248,125,0,224,102,119,0,128,246,125,0,16,247,125,0,240,245,125,0,160,247,125,0,0,86,119,0,240,98,119,0,128,99,119,0,96,98,119,0,192,101,119,0,80,32,114,0,16,100,119,0,144,83,122,0,80,20,126,0,192,19,126,0,224,199,124,0,80,199,124,0,16,9,126,0,128,8,126,0,240,7,126,0,32,219,122,0,48,198,124,0,160,197,124,0,192,198,124,0,240,195,124,0,16,197,124,0,128,196,124,0,16,249,120,0,192,151,120,0,96,195,124,0,64,194,124,0,80,100,115,0,208,194,124,0,0,106,114,0,48,151,120,0,0,145,120,0,112,144,120,0,144,145,120,0,32,146,120,0,112,21,126,0,208,97,119,0,224,20,126,0,0,22,126,0,64,97,119,0,176,96,119,0,32,96,119,0,96,148,120,0,208,147,120,0,64,147,120,0,128,149,120,0,16,150,120,0,160,150,120,0,240,148,120,0,176,146,120,0,144,192,124,0,144,95,119,0,0,95,119,0,144,86,119,0,32,87,119,0,176,87,119,0,64,88,119,0,208,88,119,0,96,89,119,0,240,89,119,0,128,90,119,0,16,91,119,0,160,91,119,0,48,92,119,0,192,92,119,0,224,93,119,0,80,93,119,0,112,94,119,0,16,188,124,0,128,187,124,0,112,85,119,0,224,84,119,0,80,84,119,0,192,83,119,0,224,248,114,0,192,31,114,0,0,250,114,0,80,248,114,0,112,251,118,0,208,185,124,0,240,80,119,0,96,186,124,0,128,81,119,0,96,209,125,0,240,209,125,0,176,207,125,0,64,208,125,0,208,208,125,0,96,80,119,0,208,79,119,0,64,167,124,0,32,166,124,0,144,165,124,0,224,163,124,0,176,166,124,0,0,165,124,0,112,164,124,0,64,79,119,0,176,78,119,0,144,77,119,0,32,78,119,0,144,206,125,0,0,206,125,0,32,207,125,0,176,62,114,0,224,75,119,0,192,247,114,0,32,242,114,0,112,76,119,0,0,77,119,0,0,120,124,0,144,120,124,0,176,184,124,0,32,184,124,0,144,183,124,0,224,181,124,0,0,183,124,0,112,182,124,0,80,75,119,0,64,185,124,0,80,181,124,0,128,178,124,0,96,177,124,0,240,177,124,0,192,180,124,0,48,247,114,0,16,179,124,0,160,179,124,0,48,180,124,0,192,74,119,0,160,246,114,0,208,176,124,0,48,74,119,0,64,176,124,0,32,175,124,0,176,175,124,0,144,174,124,0,0,174,124,0,112,173,124,0,96,182,125,0,240,182,125,0,176,180,125,0,32,180,125,0,208,181,125,0,64,181,125,0,48,31,114,0,176,137,120,0,32,137,120,0,160,73,119,0,128,72,119,0,16,73,119,0,240,71,119,0,16,98,124,0,208,90,114,0,240,22,120,0,176,24,119,0,64,25,119,0,208,70,119,0,160,30,114,0,176,69,119,0,64,70,119,0,96,71,119,0,32,69,119,0,144,68,119,0,176,139,124,0,64,140,124,0,128,29,114,0,240,244,114,0,240,62,119,0,144,138,124,0,96,62,119,0,208,61,119,0,176,60,119,0,240,28,114,0,96,244,114,0,32,60,119,0,192,135,124,0,80,136,124,0,224,136,124,0,112,137,124,0,0,138,124,0,48,135,124,0,48,44,122,0,160,43,122,0,160,134,124,0,144,59,119,0,0,59,119,0,48,142,120,0,160,141,120,0,80,109,124,0,16,134,124,0,240,132,124,0,96,132,124,0,128,133,124,0,208,131,124,0,80,172,124,0,224,172,124,0,176,130,124,0,64,131,124,0,112,58,119,0,96,53,119,0,240,53,119,0,16,55,119,0,128,54,119,0,160,55,119,0,48,56,119,0,192,56,119,0,80,57,119,0,224,57,119,0,0,23,119,0,112,22,119,0,32,130,124,0,32,116,114,0,192,126,124,0,80,127,124,0,224,127,124,0,208,243,114,0,64,52,119,0,0,129,124,0,144,129,124,0,112,128,124,0,96,28,114,0,208,52,119,0,192,47,119,0,48,47,119,0,48,126,124,0,160,46,119,0,16,46,119,0,64,243,114,0,16,125,124,0,160,125,124,0,128,124,124,0,240,123,124,0,192,142,120,0,176,242,114,0,96,191,125,0,64,190,125,0,208,190,125,0,96,123,124,0,240,44,119,0,32,42,119,0,64,122,124,0,176,121,124,0,208,122,124,0,112,187,125,0,16,33,120,0,240,31,120,0,96,31,120,0,208,30,120,0,64,12,120,0,112,229,119,0,224,228,119,0,80,88,118,0,192,87,118,0,32,121,124,0,192,38,119,0,48,38,119,0,160,37,119,0,16,37,119,0,160,107,124,0,192,108,124,0,48,108,124,0,16,152,124,0,160,152,124,0,48,153,124,0,240,150,124,0,128,151,124,0,128,106,124,0,240,105,124,0,96,105,124,0,208,104,124,0,208,34,119,0,64,34,119,0,16,141,120,0,176,103,124,0,32,103,124,0,64,104,124,0,144,241,114,0,112,8,118,0,0,9,118,0,176,33,119,0,112,119,124,0,16,116,124,0,240,114,124,0,96,114,124,0,224,118,124,0,144,111,124,0,192,117,124,0,48,117,124,0,80,118,124,0,160,116,124,0,112,110,124,0,0,111,124,0,64,113,124,0,176,112,124,0,32,112,124,0,128,115,124,0,208,113,124,0,0,102,124,0,112,101,124,0,224,100,124,0,144,102,124,0,32,33,119,0,0,241,114,0,112,240,114,0,144,32,119,0,80,100,124,0,192,99,124,0,240,139,120,0,128,140,120,0,48,171,124,0,192,171,124,0,0,32,119,0,192,144,124,0,96,150,124,0,144,147,124,0,80,66,119,0,0,147,124,0,96,139,120,0,48,144,124,0,16,143,124,0,128,142,124,0,160,143,124,0,208,149,124,0,48,65,119,0,64,149,124,0,176,148,124,0,32,148,124,0,80,145,124,0,192,65,119,0,224,145,124,0,112,146,124,0,160,64,119,0,16,64,119,0,128,245,114,0,16,30,114,0,240,168,124,0,128,169,124,0,224,239,114,0,80,239,114,0,160,98,124,0,48,99,124,0,240,26,119,0,96,26,119,0,208,25,119,0,176,85,124,0,0,84,124,0,32,85,124,0,144,84,124,0,48,29,119,0,160,28,119,0,0,68,119,0,112,67,119,0,128,97,124,0,96,96,124,0,208,167,124,0,96,168,124,0,208,95,124,0,192,238,114,0,144,93,124,0,128,236,114,0,240,235,114,0,32,24,119,0,144,23,119,0,96,235,114,0,176,26,114,0,0,93,124,0,48,81,124,0,192,90,124,0,112,92,124,0,144,136,120,0,208,27,114,0,16,193,116,0,176,51,119,0,128,36,119,0,80,30,119,0,192,29,119,0,176,94,124,0,32,94,124,0,64,95,124,0,240,96,124,0,64,86,124,0,224,109,124,0,208,138,120,0,224,82,124,0,48,90,124,0,160,89,124,0,16,89,124,0,128,88,124,0,240,87,124,0,96,87,124,0,48,238,114,0,160,237,114,0,64,27,114,0,64,138,120,0,224,21,119,0,80,21,119,0,80,82,124,0,160,19,119,0,192,20,119,0,48,20,119,0,32,26,114,0,208,234,114,0,160,202,125,0,240,200,125,0,128,201,125,0,64,199,125,0,80,204,125,0,16,202,125,0,192,203,125,0,224,204,125,0,112,205,125,0,48,203,125,0,208,199,125,0,96,200,125,0,144,197,125,0,16,193,125,0,80,195,125,0,160,193,125,0,240,191,125,0,224,195,125,0,48,194,125,0,128,192,125,0,32,198,125,0,0,197,125,0,176,198,125,0,112,196,125,0,192,194,125,0,128,63,119,0,192,81,124,0,16,19,119,0,128,18,119,0,240,17,119,0,160,80,124,0,16,80,124,0,128,79,124,0,240,78,124,0,96,78,124,0,208,16,119,0,96,17,119,0,208,140,124,0,96,141,124,0,240,141,124,0,32,51,119,0,144,50,119,0,0,50,119,0,80,48,119,0,224,48,119,0,112,49,119,0,144,179,125,0,0,179,125,0,64,16,119,0,160,62,124,0,16,62,124,0,128,61,124,0,48,63,124,0,176,15,119,0,32,15,119,0,112,13,119,0,208,77,124,0,64,77,124,0,176,76,124,0,144,14,119,0,176,6,119,0,0,5,119,0,32,6,119,0,144,5,119,0,80,12,119,0,240,8,119,0,128,9,119,0,48,11,119,0,16,10,119,0,160,10,119,0,208,7,119,0,64,7,119,0,224,12,119,0,96,8,119,0,192,11,119,0,192,176,125,0,80,177,125,0,160,175,125,0,128,174,125,0,48,176,125,0,16,175,125,0,80,73,124,0,0,136,120,0,112,135,120,0,176,182,120,0,48,72,124,0,16,71,124,0,16,1,119,0,160,1,119,0,224,3,119,0,112,4,119,0,80,3,119,0,192,2,119,0,48,2,119,0,128,0,119,0,128,70,124,0,240,69,124,0,96,69,124,0,64,234,114,0,64,68,124,0,176,67,124,0,208,68,124,0,96,29,116,0,48,23,116,0,192,23,116,0,80,24,116,0,224,24,116,0,112,25,116,0,0,26,116,0,144,26,116,0,32,27,116,0,176,27,116,0,64,28,116,0,208,28,116,0,160,22,116,0,144,66,124,0,0,66,124,0,192,63,124,0,80,64,124,0,224,64,124,0,112,65,124,0,240,255,118,0,96,255,118,0,208,254,118,0,32,253,118,0,144,252,118,0,64,254,118,0,176,253,118,0,0,252,118,0,224,250,118,0,48,249,118,0,80,250,118,0,192,249,118,0,160,248,118,0,96,60,124,0,240,220,120,0,128,247,118,0,16,248,118,0,240,246,118,0,176,244,118,0,224,241,118,0,80,241,118,0,208,59,124,0,64,59,124,0,176,58,124,0,32,58,124,0,144,57,124,0,208,245,118,0,64,245,118,0,144,243,118,0,0,243,118,0,112,242,118,0,0,57,124,0,32,244,118,0,224,55,124,0,112,56,124,0,192,54,124,0,160,53,124,0,48,54,124,0,80,55,124,0,192,133,120,0,48,133,120,0,224,134,120,0,80,134,120,0,224,230,114,0,16,53,124,0,128,52,124,0,240,51,124,0,96,51,124,0,80,230,114,0,48,240,118,0,160,239,118,0,16,239,118,0,128,238,118,0,240,237,118,0,144,234,118,0,32,235,118,0,112,233,118,0,0,234,118,0,144,3,124,0,32,4,124,0,192,240,118,0,64,236,118,0,176,235,118,0,0,232,114,0,32,233,114,0,144,232,114,0,112,231,114,0,96,237,118,0,192,229,114,0,144,25,114,0,80,232,118,0,208,50,124,0,176,49,124,0,64,50,124,0,48,231,118,0,192,231,118,0,0,48,124,0,112,47,124,0,32,49,124,0,160,230,118,0,16,230,118,0,224,46,124,0,0,25,114,0,48,229,114,0,240,42,124,0,16,44,124,0,128,43,124,0,80,46,124,0,192,45,124,0,48,45,124,0,160,44,124,0,144,48,124,0,144,109,120,0,96,42,124,0,128,229,118,0,64,227,118,0,32,226,118,0,208,41,124,0,176,226,118,0,32,40,124,0,144,39,124,0,64,41,124,0,176,40,124,0,96,228,118,0,208,227,118,0,144,225,118,0,0,225,118,0,112,224,118,0,224,223,118,0,80,223,118,0,192,222,118,0,48,222,118,0,160,221,118,0,16,221,118,0,112,38,124,0,128,220,118,0,176,217,118,0,112,215,118,0,224,214,118,0,240,219,118,0,96,219,118,0,32,217,118,0,144,216,118,0,0,216,118,0,80,214,118,0,208,218,118,0,64,218,118,0,160,132,120,0,16,132,120,0,64,129,120,0,192,36,124,0,224,37,124,0,80,37,124,0,48,213,118,0,192,213,118,0,160,228,114,0,208,225,114,0,160,35,124,0,160,212,118,0,16,35,124,0,48,36,124,0,240,173,125,0,32,171,125,0,80,168,125,0,144,170,125,0,192,167,125,0,64,172,125,0,176,171,125,0,112,169,125,0,224,168,125,0,96,173,125,0,208,172,125,0,112,24,114,0,16,228,114,0,128,227,114,0,240,226,114,0,96,226,114,0,128,7,124,0,16,8,124,0,128,34,124,0,112,197,118,0,80,155,117,0,240,33,124,0,16,212,118,0,64,225,114,0,176,224,114,0,32,224,114,0,128,211,118,0,208,32,124,0,64,32,124,0,240,210,118,0,96,210,118,0,96,33,124,0,176,31,124,0,160,26,124,0,0,30,124,0,112,29,124,0,224,28,124,0,80,28,124,0,192,27,124,0,48,27,124,0,32,31,124,0,144,30,124,0,16,26,124,0,128,25,124,0,240,24,124,0,96,24,124,0,208,14,124,0,144,207,118,0,96,15,124,0,240,15,124,0,64,14,124,0,208,209,118,0,64,209,118,0,176,208,118,0,32,208,118,0,208,23,124,0,64,23,124,0,176,22,124,0,32,22,124,0,112,20,124,0,224,19,124,0,144,21,124,0,0,21,124,0,0,207,118,0,112,206,118,0,48,204,118,0,48,18,124,0,0,39,124,0,160,203,118,0,128,165,125,0,240,164,125,0,16,166,125,0,160,166,125,0,48,167,125,0,128,202,118,0,16,203,118,0,0,223,114,0,144,223,114,0,240,201,118,0,240,228,118,0,224,210,119,0,208,129,120,0,176,13,124,0,32,13,124,0,112,11,124,0,0,215,125,0,128,34,115,0,160,115,122,0,144,12,124,0,0,12,124,0,192,9,124,0,224,10,124,0,80,10,124,0,208,200,118,0,112,160,116,0,240,6,124,0,176,199,118,0,32,199,118,0,64,200,118,0,32,128,120,0,176,128,120,0,240,130,120,0,208,5,124,0,96,6,124,0,176,4,124,0,64,5,124,0,144,198,118,0,16,189,117,0,160,17,115,0,0,198,118,0,48,211,123,0,160,176,118,0,16,176,118,0,160,210,123,0,224,196,118,0,224,221,114,0,0,3,124,0,112,222,114,0,80,196,118,0,64,182,118,0,176,181,118,0,80,221,114,0,80,23,114,0,80,1,124,0,48,0,124,0,192,0,124,0,224,1,124,0,160,255,123,0,96,42,115,0,208,41,115,0,192,195,118,0,96,253,123,0,176,251,123,0,32,251,123,0,144,250,123,0,208,252,123,0,64,252,123,0,112,249,123,0,0,250,123,0,128,254,123,0,240,253,123,0,128,19,121,0,240,244,123,0,224,248,123,0,144,127,120,0,128,218,123,0,240,217,123,0,96,217,123,0,240,183,118,0,128,184,118,0,192,247,123,0,48,247,123,0,160,246,123,0,80,248,123,0,16,246,123,0,128,245,123,0,48,195,118,0,208,182,118,0,96,183,118,0,160,194,118,0,16,194,118,0,192,211,123,0,192,220,114,0,96,244,123,0,96,164,125,0,144,223,123,0,32,224,123,0,112,126,120,0,208,243,123,0,128,193,118,0,240,192,118,0,64,243,123,0,224,125,120,0,176,242,123,0,80,125,120,0,32,242,123,0,96,192,118,0,208,191,118,0,0,215,116,0,144,241,123,0,0,241,123,0,112,240,123,0,224,239,123,0,208,234,123,0,96,235,123,0,176,233,123,0,64,234,123,0,32,233,123,0,240,235,123,0,144,232,123,0,0,232,123,0,112,231,123,0,224,230,123,0,192,229,123,0,80,230,123,0,32,190,118,0,48,229,123,0,128,236,123,0,160,228,123,0,16,228,123,0,128,227,123,0,240,226,123,0,96,226,123,0,208,225,123,0,80,239,123,0,160,237,123,0,48,238,123,0,192,238,123,0,16,237,123,0,176,190,118,0,64,191,118,0,48,220,114,0,144,189,118,0,0,223,123,0,0,189,118,0,112,188,118,0,224,187,118,0,192,186,118,0,48,186,118,0,112,222,123,0,160,219,114,0,16,219,114,0,128,218,114,0,224,221,123,0,160,185,118,0,16,185,118,0,80,221,123,0,48,220,123,0,160,219,123,0,16,219,123,0,192,124,120,0,192,22,114,0,176,215,123,0,240,199,123,0,128,200,123,0,144,180,118,0,32,181,118,0,48,124,120,0,16,210,123,0,208,207,123,0,64,207,123,0,176,206,123,0,144,205,123,0,0,205,123,0,32,206,123,0,240,208,123,0,96,208,123,0,112,179,118,0,0,180,118,0,64,163,125,0,208,163,125,0,144,214,123,0,32,215,123,0,144,161,125,0,0,161,125,0,224,159,125,0,112,160,125,0,32,162,125,0,192,158,125,0,80,159,125,0,176,162,125,0,0,214,123,0,112,213,123,0,224,212,123,0,80,212,123,0,0,187,123,0,144,187,123,0,32,188,123,0,48,177,118,0,160,123,120,0,128,175,118,0,240,174,118,0,96,174,118,0,208,173,118,0,96,253,114,0,64,173,118,0,224,203,123,0,80,203,123,0,192,202,123,0,48,202,123,0,160,201,123,0,112,204,123,0,112,170,118,0,0,171,118,0,176,172,118,0,32,172,118,0,144,171,118,0,240,217,114,0,96,127,123,0,80,169,118,0,16,123,120,0,16,201,123,0,240,104,122,0,96,104,122,0,48,98,122,0,192,168,118,0,208,85,122,0,208,198,123,0,64,198,123,0,96,199,123,0,96,217,114,0,176,197,123,0,32,197,123,0,144,196,123,0,80,194,123,0,0,196,123,0,224,194,123,0,176,163,118,0,160,167,118,0,48,168,118,0,128,166,118,0,16,167,118,0,192,184,123,0,160,183,123,0,16,183,123,0,240,165,118,0,48,158,125,0,224,178,118,0,80,178,118,0,192,177,118,0,64,225,123,0,176,224,123,0,96,165,118,0,128,191,123,0,240,190,123,0,208,164,118,0,208,189,123,0,64,164,118,0,96,190,123,0,64,189,123,0,176,188,123,0,192,220,123,0,48,193,123,0,192,193,123,0,16,192,123,0,112,195,123,0,128,182,123,0,192,175,123,0,240,181,123,0,48,175,123,0,160,174,123,0,96,172,123,0,208,171,123,0,128,173,123,0,240,172,123,0,128,209,123,0,64,180,123,0,176,179,123,0,96,181,123,0,208,180,123,0,160,21,114,0,144,178,123,0,224,176,123,0,80,176,123,0,112,177,123,0,0,178,123,0,208,216,114,0,64,216,114,0,16,174,123,0,32,163,118,0,144,162,118,0,0,162,118,0,112,161,118,0,224,160,118,0,240,121,120,0,64,171,123,0,176,170,123,0,32,170,123,0,80,160,118,0,192,159,118,0,144,169,123,0,0,169,123,0,224,167,123,0,80,167,123,0,112,168,123,0,192,166,123,0,0,151,123,0,144,151,123,0,176,215,114,0,160,165,123,0,48,166,123,0,16,165,123,0,96,121,120,0,208,120,120,0,64,120,120,0,144,214,114,0,32,215,114,0,240,156,118,0,160,138,123,0,16,158,118,0,128,157,118,0,48,159,118,0,160,158,118,0,32,145,118,0,144,144,118,0,128,164,123,0,128,137,123,0,16,138,123,0,0,214,114,0,176,161,123,0,32,161,123,0,64,162,123,0,96,156,118,0,144,160,123,0,0,160,123,0,176,154,118,0,96,163,123,0,208,162,123,0,144,133,123,0,32,154,118,0,224,212,114,0,48,141,118,0,0,133,123,0,112,132,123,0,144,153,118,0,112,159,123,0,80,158,123,0,192,157,123,0,224,158,123,0,0,153,118,0,112,152,118,0,224,151,118,0,48,157,123,0,80,151,118,0,192,150,118,0,128,155,123,0,16,156,123,0,48,150,118,0,160,149,118,0,240,154,123,0,176,152,123,0,64,153,123,0,96,154,123,0,208,153,123,0,64,155,118,0,112,150,123,0,16,36,126,0,80,149,123,0,224,149,123,0,16,149,118,0,112,213,114,0,16,21,114,0,128,148,118,0,240,147,118,0,208,146,118,0,96,147,118,0,48,148,123,0,16,246,114,0,224,66,119,0,64,146,118,0,16,147,123,0,128,146,123,0,176,145,118,0,160,147,123,0,208,144,123,0,64,144,123,0,224,140,123,0,80,140,123,0,192,139,123,0,48,139,123,0,32,119,120,0,0,144,118,0,112,143,118,0,96,136,123,0,208,135,123,0,192,148,123,0,192,141,118,0,128,139,118,0,240,138,118,0,96,138,118,0,208,137,118,0,176,136,118,0,64,137,118,0,224,131,123,0,80,131,123,0,192,130,123,0,96,155,125,0,128,156,125,0,240,155,125,0,16,157,125,0,160,157,125,0,240,127,123,0,32,136,118,0,144,135,118,0,0,135,118,0,80,212,114,0,96,130,120,0,48,130,123,0,144,118,120,0,112,117,120,0,224,116,120,0,0,118,120,0,96,35,119,0,240,35,119,0,160,129,123,0,192,211,114,0,128,128,123,0,16,129,123,0,224,133,118,0,48,228,121,0,128,20,114,0,176,125,123,0,64,126,123,0,128,130,118,0,160,131,118,0,16,131,118,0,96,129,118,0,240,129,118,0,208,126,123,0,64,128,118,0,192,123,118,0,80,124,118,0,224,124,118,0,112,125,118,0,0,126,118,0,144,126,118,0,32,127,118,0,176,127,118,0,208,128,118,0,48,123,118,0,240,120,118,0,160,122,118,0,16,122,118,0,144,124,123,0,128,121,118,0,96,120,118,0,64,119,118,0,80,122,123,0,192,121,123,0,48,121,123,0,112,107,118,0,240,208,114,0,48,105,118,0,80,106,118,0,192,105,118,0,160,104,118,0,96,19,114,0,224,176,114,0,144,121,117,0,160,12,114,0,48,115,120,0,160,114,120,0,16,114,120,0,48,211,114,0,0,124,123,0,112,123,123,0,240,19,114,0,80,115,118,0,0,117,118,0,112,116,118,0,224,115,118,0,176,91,118,0,32,91,118,0,192,248,116,0,48,248,116,0,176,118,118,0,32,118,118,0,144,117,118,0,16,28,119,0,16,113,118,0,128,112,118,0,208,110,118,0,240,111,118,0,96,111,118,0,224,74,117,0,64,110,118,0,176,109,118,0,160,210,114,0,224,122,123,0,144,108,118,0,32,109,118,0,16,210,114,0,128,209,114,0,0,108,118,0,240,112,120,0,96,112,120,0,16,104,118,0,128,119,123,0,16,120,123,0,128,103,118,0,96,102,118,0,240,102,118,0,64,29,118,0,176,28,118,0,96,30,118,0,208,29,118,0,80,25,118,0,208,111,120,0,176,116,123,0,64,117,123,0,144,115,123,0,32,116,123,0,96,118,123,0,208,117,123,0,48,112,123,0,192,112,123,0,80,113,123,0,224,113,123,0,112,114,123,0,0,115,123,0,16,111,123,0,160,111,123,0,240,118,123,0,32,74,120,0,32,100,118,0,64,111,120,0,48,114,118,0,160,113,118,0,192,114,118,0,208,108,123,0,176,107,123,0,64,108,123,0,32,107,123,0,144,106,123,0,112,105,123,0,176,110,120,0,32,110,120,0,0,106,123,0,240,109,123,0,224,104,123,0,80,104,123,0,224,88,118,0,144,90,118,0,112,89,118,0,0,90,118,0,96,109,123,0,48,87,118,0,144,99,118,0,0,99,118,0,208,92,118,0,64,92,118,0,112,98,118,0,96,93,118,0,240,93,118,0,128,94,118,0,16,95,118,0,160,95,118,0,48,96,118,0,192,96,118,0,80,97,118,0,224,97,118,0,224,106,118,0,96,208,114,0,208,207,114,0,16,86,118,0,160,86,118,0,208,150,126,0,96,151,126,0,208,154,125,0,128,113,120,0,208,74,118,0,64,74,118,0,176,73,118,0,240,84,118,0,128,85,118,0,160,102,123,0,16,102,123,0,48,103,123,0,208,192,120,0,128,101,123,0,16,138,114,0,128,137,114,0,240,100,123,0,224,107,120,0,0,109,120,0,112,108,120,0,208,99,123,0,64,99,123,0,176,98,123,0,32,98,123,0,112,96,123,0,0,97,123,0,144,97,123,0,80,107,120,0,64,207,114,0,176,206,114,0,96,84,118,0,208,83,118,0,208,18,114,0,80,95,123,0,192,106,120,0,48,106,120,0,160,105,120,0,16,105,120,0,160,93,123,0,48,94,123,0,192,94,123,0,32,82,118,0,32,206,114,0,96,91,123,0,144,81,118,0,128,92,123,0,16,93,123,0,240,145,123,0,96,145,123,0,208,87,117,0,144,205,114,0,32,89,123,0,176,89,123,0,64,18,114,0,0,205,114,0,0,79,123,0,112,78,123,0,224,70,118,0,192,69,118,0,16,75,123,0,96,73,123,0,48,69,118,0,80,70,118,0,128,74,123,0,240,73,123,0,192,78,118,0,80,79,118,0,48,78,118,0,144,88,123,0,160,77,118,0,16,77,118,0,0,88,123,0,176,17,114,0,112,204,114,0,128,76,118,0,240,75,118,0,224,203,114,0,64,154,125,0,192,149,125,0,80,150,125,0,48,149,125,0,176,153,125,0,32,153,125,0,144,152,125,0,0,152,125,0,112,151,125,0,224,150,125,0,64,72,123,0,176,71,123,0,208,72,123,0,144,70,123,0,0,70,123,0,112,69,123,0,224,68,123,0,80,68,123,0,32,71,123,0,48,67,123,0,160,66,123,0,192,67,123,0,128,65,123,0,16,66,123,0,80,80,120,0,224,80,120,0,112,60,123,0,32,62,123,0,144,61,123,0,0,61,123,0,176,62,123,0,192,79,120,0,112,81,120,0,0,82,120,0,240,64,123,0,96,64,123,0,208,63,123,0,64,63,123,0,48,79,120,0,112,87,123,0,192,103,123,0,224,95,123,0,96,75,118,0,240,60,124,0,0,72,118,0,224,77,123,0,192,76,123,0,80,77,123,0,160,156,114,0,16,156,114,0,48,76,123,0,144,82,120,0,96,194,122,0,208,193,122,0,112,71,118,0,224,112,121,0,80,112,121,0,224,59,123,0,16,68,118,0,160,68,118,0,80,59,123,0,240,66,118,0,64,83,118,0,16,57,123,0,192,58,123,0,48,58,123,0,160,57,123,0,128,56,123,0,96,66,118,0,208,65,118,0,64,65,118,0,176,64,118,0,160,201,114,0,48,202,114,0,80,203,114,0,128,67,118,0,208,56,118,0,176,53,123,0,144,52,123,0,32,53,123,0,64,54,123,0,16,201,114,0,128,200,114,0,0,63,118,0,80,61,118,0,192,60,118,0,224,61,118,0,112,62,118,0,48,60,118,0,160,59,118,0,96,57,118,0,240,57,118,0,128,58,118,0,16,59,118,0,160,78,120,0,16,21,123,0,16,39,123,0,160,39,123,0,32,55,118,0,144,54,118,0,48,22,123,0,112,51,123,0,0,52,123,0,224,50,123,0,208,75,120,0,192,49,123,0,48,49,123,0,80,50,123,0,192,22,123,0,208,54,123,0,160,48,123,0,16,48,123,0,192,13,123,0,32,44,123,0,144,43,123,0,96,199,114,0,64,27,123,0,0,16,114,0,176,26,123,0,32,26,123,0,144,25,123,0,0,43,123,0,96,19,123,0,128,20,123,0,240,19,123,0,48,51,118,0,16,50,118,0,160,50,118,0,80,41,123,0,80,52,118,0,192,51,118,0,176,193,124,0,32,193,124,0,128,49,118,0,240,48,118,0,96,48,118,0,112,53,118,0,224,52,118,0,192,40,123,0,48,40,123,0,64,47,118,0,176,46,118,0,32,46,118,0,144,45,118,0,0,45,118,0,112,44,118,0,224,43,118,0,80,43,118,0,192,42,118,0,240,37,123,0,96,37,123,0,128,38,123,0,112,203,121,0,128,29,123,0,240,28,123,0,16,30,123,0,96,47,116,0,16,41,118,0,240,39,118,0,128,40,118,0,64,36,123,0,208,36,123,0,176,35,123,0,32,35,123,0,64,75,120,0,208,38,118,0,128,47,123,0,176,44,123,0,240,199,114,0,160,30,123,0,48,31,123,0,240,46,123,0,208,45,123,0,96,46,123,0,64,45,123,0,208,27,123,0,96,28,123,0,64,38,118,0,176,37,118,0,0,25,123,0,224,34,118,0,80,34,118,0,112,24,123,0,224,23,123,0,144,143,125,0,32,144,125,0,80,23,123,0,192,33,118,0,48,33,118,0,160,32,118,0,176,74,120,0,160,21,123,0,16,32,118,0,144,236,122,0,32,237,122,0,176,237,122,0,240,21,118,0,96,21,118,0,0,18,118,0,80,14,123,0,224,14,123,0,48,13,123,0,128,31,118,0,240,30,118,0,32,28,118,0,144,27,118,0,0,27,118,0,112,26,118,0,224,25,118,0,192,24,118,0,32,62,114,0,48,24,118,0,64,66,120,0,128,11,123,0,240,10,123,0,160,5,118,0,96,119,125,0,208,118,125,0,240,119,125,0,64,118,125,0,16,250,122,0,128,249,122,0,112,15,114,0,64,198,114,0,208,238,122,0,64,238,122,0,96,239,122,0,160,12,123,0,144,73,120,0,0,73,120,0,16,12,123,0,160,23,118,0,48,199,117,0,224,71,120,0,112,72,120,0,16,23,118,0,64,238,113,0,128,22,118,0,208,229,122,0,128,240,122,0,128,191,114,0,240,239,122,0,160,192,114,0,16,192,114,0,240,190,114,0,96,190,114,0,112,141,123,0,208,9,123,0,176,228,122,0,32,228,122,0,208,189,114,0,96,10,123,0,208,202,122,0,192,193,114,0,144,7,123,0,128,110,114,0,64,229,122,0,80,5,123,0,224,5,123,0,112,6,123,0,0,7,123,0,192,4,123,0,176,197,114,0,32,197,114,0,48,4,123,0,160,3,123,0,16,3,123,0,80,71,120,0,192,70,120,0,144,196,114,0,208,20,118,0,128,2,123,0,0,196,114,0,240,1,123,0,208,0,123,0,144,18,118,0,112,17,118,0,64,0,123,0,176,255,122,0,224,16,118,0,80,16,118,0,208,21,120,0,192,15,118,0,144,254,122,0,16,14,118,0,48,15,118,0,160,14,118,0,0,254,122,0,48,140,125,0,160,139,125,0,192,140,125,0,128,13,118,0,240,12,118,0,160,69,120,0,48,70,120,0,112,253,122,0,208,11,118,0,96,12,118,0,160,130,125,0,48,131,125,0,96,128,125,0,64,127,125,0,208,127,125,0,16,130,125,0,128,129,125,0,240,128,125,0,144,125,125,0,32,126,125,0,112,124,125,0,176,126,125,0,224,123,125,0,48,122,125,0,128,120,125,0,16,121,125,0,192,122,125,0,80,123,125,0,0,125,125,0,160,121,125,0,240,110,125,0,0,116,125,0,160,112,125,0,192,113,125,0,144,116,125,0,112,115,125,0,32,117,125,0,224,114,125,0,80,114,125,0,48,113,125,0,128,111,125,0,16,112,125,0,96,201,118,0,96,100,123,0,176,10,118,0,64,11,118,0,192,251,122,0,32,194,117,0,48,251,122,0,80,252,122,0,160,250,122,0,32,10,118,0,144,9,118,0,240,67,120,0,128,68,120,0,144,227,122,0,224,7,118,0,80,7,118,0,192,6,118,0,48,6,118,0,208,66,120,0,96,67,120,0,16,5,118,0,128,4,118,0,240,3,118,0,96,3,118,0,208,2,118,0,176,248,117,0,64,247,122,0,176,246,122,0,208,247,122,0,176,1,118,0,32,1,118,0,64,2,118,0,0,0,118,0,112,255,117,0,224,254,117,0,80,254,117,0,192,253,117,0,48,253,117,0,144,0,118,0,32,135,125,0,96,137,125,0,192,131,125,0,96,250,117,0,64,136,125,0,144,134,125,0,208,136,125,0,176,135,125,0,144,247,117,0,0,247,117,0,224,245,117,0,80,245,117,0,176,117,125,0,16,252,117,0,160,252,117,0,128,251,117,0,240,250,117,0,32,246,122,0,208,249,117,0,64,249,117,0,32,248,117,0,112,246,117,0,144,245,122,0,240,91,123,0,0,245,122,0,112,244,122,0,192,244,117,0,48,244,117,0,0,134,125,0,80,132,125,0,224,132,125,0,160,243,117,0,224,194,114,0,224,243,122,0,192,242,122,0,80,243,122,0,16,243,117,0,240,241,117,0,48,242,122,0,176,58,115,0,64,18,123,0,0,57,115,0,32,58,115,0,224,55,115,0,112,56,115,0,16,62,115,0,192,54,115,0,128,61,115,0,48,54,115,0,80,55,115,0,240,60,115,0,144,57,115,0,176,17,123,0,80,194,114,0,96,69,115,0,160,241,122,0,16,241,122,0,144,16,123,0,176,194,117,0,64,195,117,0,64,240,117,0,176,239,117,0,32,239,117,0,32,221,117,0,144,220,117,0,0,220,117,0,112,219,117,0,208,240,117,0,192,235,117,0,112,237,117,0,80,236,117,0,224,236,117,0,48,235,117,0,160,234,117,0,16,234,117,0,0,238,117,0,144,238,117,0,112,235,122,0,240,232,117,0,224,234,122,0,128,233,117,0,0,236,122,0,96,232,117,0,208,231,117,0,64,231,117,0,176,230,117,0,0,229,117,0,80,234,122,0,48,233,122,0,192,233,122,0,224,218,117,0,240,214,117,0,128,215,117,0,48,217,117,0,192,217,117,0,0,211,117,0,16,216,117,0,160,216,117,0,80,218,117,0,96,214,117,0,144,211,117,0,32,212,117,0,176,212,117,0,64,213,117,0,208,213,117,0,224,141,125,0,0,143,125,0,80,141,125,0,112,142,125,0,224,39,119,0,80,39,119,0,224,14,114,0,80,185,123,0,224,185,123,0,64,68,115,0,80,226,115,0,160,232,122,0,176,67,115,0,128,242,117,0,224,207,122,0,16,232,122,0,240,203,122,0,96,203,122,0,128,231,122,0,0,209,122,0,112,208,122,0,96,77,122,0,48,193,114,0,240,230,122,0,16,225,117,0,128,224,117,0,96,223,117,0,80,207,122,0,192,206,122,0,32,179,123,0,0,227,122,0,112,226,122,0,224,225,122,0,32,188,114,0,176,188,114,0,0,187,114,0,144,187,114,0,208,68,115,0,112,210,117,0,224,209,117,0,64,189,114,0,144,193,117,0,64,202,122,0,80,209,117,0,48,224,122,0,80,225,122,0,192,224,122,0,64,220,122,0,176,219,122,0,96,221,122,0,208,220,122,0,128,222,122,0,240,221,122,0,0,218,122,0,80,216,122,0,192,215,122,0,224,216,122,0,144,218,122,0,112,217,122,0,16,223,122,0,48,215,122,0,128,204,122,0,16,205,122,0,160,205,122,0,48,206,122,0,160,223,122,0,160,214,122,0,16,214,122,0,128,213,122,0,240,212,122,0,112,186,114,0,240,223,117,0,80,227,117,0,48,226,117,0,160,225,117,0,192,226,117,0,224,185,114,0,80,14,114,0,80,185,114,0,192,184,114,0,144,66,115,0,0,66,115,0,224,64,115,0,112,65,115,0,80,64,115,0,96,212,122,0,208,211,122,0,48,184,114,0,160,183,114,0,64,211,122,0,32,210,122,0,144,209,122,0,176,210,122,0,48,63,115,0,192,208,117,0,48,208,117,0,160,62,115,0,16,53,115,0,160,53,115,0,240,51,115,0,128,52,115,0,96,51,115,0,80,200,117,0,192,199,117,0,208,50,115,0,64,59,115,0,64,50,115,0,208,59,115,0,96,60,115,0,224,77,114,0,176,201,122,0,64,203,115,0,160,198,117,0,16,198,117,0,128,197,117,0,192,219,121,0,48,170,122,0,160,169,122,0,32,201,122,0,144,200,122,0,96,248,122,0,240,248,122,0,16,139,125,0,240,137,125,0,128,138,125,0,240,196,117,0,96,196,117,0,112,180,120,0,48,197,122,0,160,196,122,0,192,197,122,0,208,222,117,0,64,222,117,0,176,221,117,0,16,196,122,0,240,194,122,0,128,195,122,0,176,192,122,0,64,193,122,0,144,48,115,0,32,49,115,0,176,49,115,0,112,192,117,0,0,193,117,0,144,191,122,0,32,192,122,0,224,191,117,0,112,195,114,0,128,188,117,0,208,236,118,0,240,187,117,0,0,191,122,0,112,190,122,0,176,153,116,0,128,7,115,0,96,187,117,0,208,186,117,0,224,189,122,0,80,189,122,0,32,31,115,0,144,30,115,0,16,183,114,0,128,182,114,0,240,181,114,0,64,186,117,0,176,185,117,0,144,184,117,0,128,170,117,0,16,171,117,0,160,171,117,0,48,172,117,0,192,172,117,0,80,173,117,0,224,173,117,0,112,174,117,0,0,175,117,0,144,175,117,0,32,176,117,0,176,176,117,0,64,177,117,0,208,177,117,0,96,178,117,0,240,178,117,0,128,179,117,0,16,180,117,0,160,180,117,0,192,181,117,0,48,181,117,0,80,182,117,0,112,183,117,0,224,182,117,0,0,184,117,0,208,168,117,0,96,169,117,0,240,169,117,0,32,185,117,0,64,168,117,0,176,167,117,0,32,167,117,0,0,166,117,0,144,166,117,0,112,165,117,0,224,164,117,0,80,164,117,0,192,163,117,0,48,163,117,0,160,162,117,0,16,162,117,0,128,161,117,0,240,160,117,0,160,172,119,0,16,172,119,0,96,160,117,0,240,170,119,0,208,159,117,0,64,159,117,0,176,158,117,0,32,158,117,0,96,181,114,0,208,180,114,0,64,180,114,0,224,137,117,0,96,55,123,0,240,55,123,0,176,179,114,0,224,155,117,0,32,179,114,0,208,109,125,0,96,110,125,0,80,46,115,0,48,45,115,0,16,44,115,0,240,42,115,0,192,188,122,0,160,44,115,0,48,188,122,0,64,41,115,0,176,40,115,0,144,39,115,0,32,40,115,0,144,43,114,0,224,37,115,0,176,237,113,0,16,187,122,0,112,38,115,0,192,45,115,0,0,178,114,0,48,13,114,0,144,178,114,0,192,13,114,0,192,190,117,0,80,191,117,0,48,190,117,0,160,189,117,0,224,41,114,0,128,186,122,0,240,185,122,0,96,185,122,0,192,154,117,0,160,35,115,0,112,163,122,0,176,183,122,0,48,154,117,0,192,36,115,0,48,36,115,0,208,184,122,0,64,184,122,0,128,152,117,0,176,140,117,0,64,141,117,0,208,141,117,0,96,142,117,0,240,142,117,0,16,144,117,0,128,143,117,0,160,144,117,0,48,145,117,0,192,145,117,0,80,146,117,0,224,146,117,0,112,147,117,0,144,148,117,0,0,148,117,0,32,149,117,0,176,149,117,0,64,150,117,0,208,150,117,0,240,151,117,0,96,151,117,0,32,140,117,0,16,153,117,0,160,153,117,0,144,139,117,0,0,139,117,0,112,138,117,0,16,35,115,0,240,33,115,0,112,177,114,0,192,136,117,0,160,135,117,0,16,135,117,0,128,134,117,0,240,133,117,0,96,133,117,0,208,123,117,0,96,124,117,0,240,124,117,0,128,125,117,0,16,126,117,0,160,126,117,0,48,127,117,0,192,127,117,0,80,128,117,0,224,128,117,0,112,129,117,0,0,130,117,0,144,130,117,0,176,131,117,0,32,131,117,0,64,132,117,0,208,132,117,0,48,136,117,0,64,123,117,0,32,122,117,0,176,122,117,0,176,19,118,0,32,19,118,0,16,12,114,0,144,182,122,0,0,182,122,0,32,183,122,0,176,108,125,0,64,109,125,0,32,108,125,0,144,107,125,0,112,106,125,0,0,107,125,0,144,157,117,0,0,157,117,0,112,156,117,0,208,32,115,0,64,32,115,0,0,121,117,0,176,174,122,0,112,120,117,0,112,47,115,0,0,48,115,0,224,46,115,0,80,137,117,0,112,2,124,0,96,33,115,0,176,165,122,0,32,165,122,0,144,164,122,0,0,164,122,0,192,175,114,0,144,11,122,0,32,12,122,0,224,162,122,0,128,11,114,0,192,170,122,0,160,117,117,0,16,169,122,0,128,168,122,0,80,119,117,0,192,118,117,0,48,118,117,0,224,119,117,0,16,117,117,0,240,167,122,0,96,167,122,0,208,166,122,0,64,166,122,0,48,175,114,0,192,161,122,0,48,161,122,0,128,116,117,0,240,115,117,0,96,115,117,0,208,114,117,0,64,114,117,0,96,158,122,0,208,157,122,0,176,113,117,0,176,31,115,0,176,156,122,0,64,157,122,0,32,113,117,0,224,153,122,0,64,105,117,0,192,143,122,0,48,143,122,0,160,142,122,0,80,144,122,0,160,174,114,0,80,153,122,0,192,152,122,0,32,156,122,0,112,154,122,0,0,155,122,0,144,155,122,0,48,152,122,0])
.concat([160,151,122,0,48,22,114,0,240,10,114,0,16,174,114,0,240,149,122,0,96,149,122,0,64,148,122,0,176,147,122,0,208,148,122,0,128,150,122,0,128,159,122,0,16,160,122,0,240,158,122,0,0,30,115,0,160,160,122,0,224,144,122,0,144,103,117,0,128,173,114,0,0,112,117,0,144,112,117,0,240,172,114,0,176,138,122,0,32,138,122,0,144,137,122,0,0,137,122,0,64,139,122,0,16,142,122,0,128,141,122,0,240,140,122,0,96,140,122,0,208,139,122,0,224,101,117,0,80,101,117,0,128,98,117,0,240,97,117,0,192,100,117,0,48,100,117,0,160,99,117,0,16,99,117,0,32,104,117,0,176,104,117,0,112,29,115,0,96,172,114,0,112,136,122,0,208,171,114,0,80,117,122,0,96,91,114,0,16,36,117,0,96,97,117,0,224,28,115,0,176,170,114,0,96,10,114,0,80,135,122,0,192,134,122,0,48,134,122,0,160,133,122,0,224,135,122,0,16,133,122,0,128,132,122,0,80,28,115,0,192,27,115,0,16,26,115,0,48,27,115,0,64,96,117,0,128,25,115,0,176,95,117,0,32,95,117,0,208,96,117,0,64,171,114,0,240,24,115,0,96,24,115,0,0,94,117,0,144,94,117,0,176,250,121,0,208,23,115,0,240,131,122,0,96,131,122,0,64,130,122,0,32,129,122,0,176,129,122,0,208,130,122,0,144,128,122,0,16,103,125,0,128,102,125,0,224,105,125,0,80,105,125,0,192,104,125,0,48,104,125,0,160,103,125,0,64,23,115,0,144,85,117,0,208,9,114,0,0,128,122,0,48,91,117,0,160,90,117,0,192,91,117,0,32,170,114,0,64,9,114,0,144,169,114,0,224,126,122,0,192,125,122,0,112,127,122,0,80,126,122,0,0,169,114,0,96,88,117,0,64,94,122,0,128,96,122,0,48,125,122,0,240,122,122,0,16,124,122,0,160,124,122,0,128,123,122,0,64,87,117,0,112,168,114,0,48,166,114,0,224,167,114,0,80,167,114,0,192,166,114,0,160,165,114,0,112,84,117,0,224,83,117,0,80,83,117,0,192,82,117,0,208,99,114,0,160,102,114,0,128,101,114,0,16,102,114,0,240,100,114,0,96,100,114,0,112,118,122,0,80,95,114,0,224,95,114,0,64,99,114,0,32,59,117,0,176,93,122,0,224,117,122,0,224,222,116,0,80,222,116,0,48,221,116,0,192,221,116,0,16,97,122,0,64,78,117,0,96,79,117,0,208,78,117,0,48,82,117,0,16,81,117,0,160,81,117,0,128,80,117,0,240,79,117,0,192,116,122,0,176,41,117,0,64,42,117,0,224,38,117,0,112,39,117,0,0,40,117,0,144,40,117,0,32,41,117,0,80,38,117,0,16,45,117,0,160,45,117,0,48,46,117,0,176,50,117,0,32,50,117,0,144,49,117,0,128,44,117,0,0,49,117,0,112,48,117,0,224,47,117,0,80,47,117,0,192,46,117,0,96,43,117,0,240,43,117,0,208,42,117,0,176,77,117,0,32,77,117,0,144,76,117,0,0,76,117,0,112,75,117,0,128,114,122,0,96,113,122,0,240,113,122,0,80,74,117,0,192,73,117,0,48,73,117,0,160,72,117,0,176,111,122,0,32,218,120,0,208,112,122,0,64,112,122,0,144,97,114,0,0,97,114,0,112,96,114,0,176,119,120,0,32,111,122,0,176,86,117,0,240,70,117,0,96,70,117,0,32,86,117,0,144,110,122,0,0,110,122,0,32,68,117,0,176,68,117,0,208,69,117,0,64,69,117,0,112,109,122,0,224,108,122,0,80,108,122,0,176,98,114,0,208,103,122,0,64,100,125,0,112,66,117,0,224,65,117,0,192,94,114,0,240,101,125,0,16,106,122,0,128,105,122,0,48,64,117,0,16,63,117,0,160,63,117,0,80,65,117,0,192,64,117,0,128,62,117,0,192,107,122,0,160,106,122,0,48,107,122,0,48,94,114,0,64,103,122,0,160,93,114,0,16,93,114,0,176,102,122,0,32,102,122,0,144,101,122,0,128,92,114,0,0,101,122,0,240,91,114,0,112,159,114,0,224,158,114,0,240,61,117,0,96,61,117,0,208,60,117,0,112,100,122,0,224,99,122,0,64,60,117,0,16,165,114,0,128,164,114,0,0,119,122,0,32,120,122,0,144,119,122,0,176,120,122,0,0,85,117,0,80,158,114,0,192,157,114,0,176,8,114,0,240,163,114,0,160,97,122,0,80,99,122,0,192,98,122,0,96,86,122,0,0,160,114,0,32,161,114,0,144,160,114,0,96,163,114,0,208,162,114,0,64,162,114,0,176,161,114,0,144,67,117,0,0,67,117,0,176,89,114,0,240,154,114,0,240,86,122,0,176,59,117,0,208,100,125,0,96,101,125,0,192,55,117,0,64,90,114,0,96,95,122,0,208,94,122,0,240,95,122,0,48,55,117,0,160,54,117,0,176,3,122,0,32,3,122,0,144,2,122,0,0,2,122,0,112,1,122,0,224,0,122,0,64,4,122,0,80,0,122,0,192,255,121,0,48,255,121,0,160,254,121,0,16,254,121,0,16,54,117,0,128,53,117,0,0,39,115,0,144,58,117,0,112,57,117,0,224,56,117,0,80,56,117,0,0,58,117,0,16,90,117,0,128,89,117,0,240,88,117,0,96,52,117,0,208,51,117,0,208,153,114,0,64,51,117,0,48,157,114,0,128,155,114,0,240,52,117,0,32,99,125,0,176,99,125,0,112,97,125,0,144,98,125,0,0,98,125,0,224,96,125,0,160,36,117,0,96,154,114,0,48,37,117,0,192,37,117,0,144,146,122,0,0,146,122,0,112,145,122,0,32,147,122,0,32,8,114,0,144,88,114,0,112,87,114,0,32,89,114,0,224,86,114,0,160,26,115,0,0,88,114,0,128,35,117,0,240,34,117,0,96,34,117,0,144,92,122,0,32,93,122,0,208,33,117,0,80,86,114,0,224,90,122,0,112,91,122,0,0,92,122,0,48,89,122,0,80,90,122,0,192,89,122,0,144,31,117,0,32,32,117,0,224,29,117,0,112,30,117,0,0,31,117,0,176,90,125,0,64,91,125,0,208,91,125,0,112,134,118,0,160,31,116,0,96,122,122,0,144,21,115,0,32,22,115,0,176,22,115,0,64,153,114,0,176,84,122,0,208,121,122,0,64,121,122,0,64,85,122,0,48,85,114,0,192,85,114,0,128,16,124,0,160,88,122,0,160,2,121,0,16,2,121,0,128,110,123,0,16,88,122,0,128,87,122,0,176,152,114,0,160,27,117,0,80,29,117,0,192,28,117,0,48,28,117,0,16,27,117,0,240,25,117,0,96,25,117,0,208,24,117,0,128,78,122,0,48,80,122,0,160,79,122,0,16,79,122,0,240,77,122,0,128,26,117,0,144,89,125,0,32,90,125,0,112,73,122,0,32,84,122,0,176,75,122,0,64,76,122,0,176,143,123,0,32,75,122,0,0,83,122,0,144,74,122,0,112,82,122,0,16,84,114,0,160,84,114,0,80,72,122,0,224,72,122,0,208,76,122,0,0,89,125,0,0,74,122,0,192,71,122,0,224,81,122,0,48,71,122,0,80,81,122,0,112,88,125,0,192,80,122,0,32,152,114,0,0,7,114,0,112,19,122,0,0,20,122,0,192,17,122,0,144,20,122,0,208,22,122,0,64,22,122,0,176,21,122,0,32,21,122,0,224,18,122,0,80,18,122,0,192,148,114,0,48,148,114,0,224,11,117,0,80,11,117,0,32,14,117,0,0,13,117,0,112,12,117,0,144,13,117,0,96,23,122,0,160,70,122,0,144,151,114,0,64,24,117,0,128,69,122,0,0,151,114,0,16,70,122,0,240,68,122,0,96,68,122,0,208,67,122,0,176,23,117,0,32,23,117,0,144,22,117,0,0,22,117,0,64,67,122,0,80,77,114,0,224,20,117,0,128,83,114,0,112,150,114,0,144,7,114,0,224,63,122,0,144,65,122,0,0,65,122,0,112,64,122,0,80,63,122,0,192,62,122,0,48,62,122,0,192,19,117,0,160,61,122,0,160,110,121,0,64,49,122,0,208,49,122,0,240,50,122,0,128,51,122,0,96,50,122,0,192,10,117,0,16,61,122,0,240,59,122,0,128,60,122,0,96,59,122,0,208,58,122,0,64,58,122,0,176,57,122,0,32,57,122,0,160,18,117,0,48,19,117,0,128,17,117,0,16,18,117,0,240,16,117,0,96,16,117,0,208,15,117,0,144,56,122,0,224,54,122,0,80,54,122,0,192,53,122,0,0,56,122,0,112,55,122,0,160,52,122,0,16,52,122,0,48,53,122,0,224,149,114,0,176,14,117,0,64,15,117,0,32,98,114,0,96,82,114,0,240,82,114,0,176,80,114,0,64,81,114,0,208,81,114,0,32,80,114,0,144,79,114,0,32,48,122,0,176,48,122,0,144,47,122,0,0,47,122,0,80,45,122,0,192,44,122,0,112,46,122,0,16,9,117,0,128,42,122,0,16,43,122,0,240,41,122,0,96,41,122,0,208,6,117,0,208,40,122,0,64,40,122,0,64,6,117,0,144,38,122,0,176,39,122,0,32,39,122,0,0,4,117,0,0,38,122,0,112,37,122,0,112,3,117,0,48,230,116,0,192,230,116,0,80,231,116,0,224,231,116,0,112,232,116,0,0,233,116,0,144,233,116,0,32,234,116,0,224,2,117,0,80,2,117,0,224,36,122,0,80,36,122,0,192,35,122,0,80,87,125,0,192,86,125,0,224,87,125,0,192,1,117,0,48,35,122,0,160,34,122,0,48,1,117,0,160,0,117,0,16,34,122,0,16,0,117,0,240,254,116,0,128,255,116,0,32,252,116,0,176,252,116,0,64,253,116,0,208,253,116,0,96,254,116,0,64,235,116,0,176,234,116,0,80,249,116,0,96,236,116,0,240,236,116,0,208,235,116,0,224,249,116,0,112,250,116,0,128,33,122,0,0,79,114,0,32,30,122,0,0,29,122,0,144,29,122,0,176,30,122,0,112,28,122,0,240,32,122,0,96,32,122,0,208,31,122,0,64,31,122,0,160,247,116,0,128,246,116,0,240,245,116,0,96,245,116,0,208,244,116,0,64,244,116,0,16,247,116,0,176,243,116,0,224,27,122,0,112,78,114,0,144,251,116,0,0,251,116,0,80,149,114,0,32,243,116,0,144,242,116,0,0,242,116,0,16,85,125,0,160,85,125,0,112,241,116,0,224,240,116,0,80,240,116,0,48,86,125,0,208,195,117,0,192,26,122,0,48,26,122,0,80,27,122,0,160,25,122,0,16,25,122,0,240,23,122,0,128,24,122,0,160,229,116,0,16,229,116,0,128,228,116,0,240,227,116,0,48,239,116,0,160,238,116,0,16,238,116,0,128,45,119,0,192,76,114,0,160,75,114,0,48,76,114,0,16,75,114,0,128,237,116,0,96,227,116,0,48,17,122,0,208,226,116,0,16,16,122,0,160,16,122,0,128,15,122,0,240,14,122,0,96,14,122,0,208,13,122,0,176,12,122,0,0,11,122,0,64,226,116,0,160,147,114,0,208,134,121,0,96,135,121,0,0,132,121,0,64,20,118,0,208,125,121,0,96,5,122,0,208,4,122,0,16,147,114,0,144,224,116,0,80,162,122,0,128,146,114,0,160,76,116,0,48,77,116,0,240,145,114,0,144,249,121,0,112,223,116,0,0,249,121,0,112,248,121,0,160,220,116,0,16,220,116,0,32,250,121,0,128,253,121,0,240,252,121,0,208,251,121,0,96,252,121,0,64,251,121,0,32,71,114,0,144,70,114,0,176,71,114,0,208,72,114,0,96,73,114,0,240,73,114,0,128,219,116,0,112,6,114,0,64,217,116,0,176,216,116,0,32,216,116,0,16,224,124,0,128,223,124,0,240,222,124,0,96,222,124,0,240,218,116,0,144,219,124,0,80,226,124,0,192,225,124,0,48,225,124,0,160,224,124,0,176,220,124,0,32,220,124,0,144,8,125,0,80,217,124,0,192,216,124,0,48,216,124,0,96,218,116,0,208,217,116,0,192,129,121,0,80,68,114,0,192,67,114,0,224,68,114,0,224,6,125,0,0,8,125,0,112,7,125,0,224,159,116,0,80,159,116,0,224,247,121,0,64,72,114,0,192,246,121,0,80,247,121,0,176,241,121,0,64,204,117,0,208,204,117,0,96,205,117,0,240,205,117,0,128,206,117,0,16,207,117,0,160,207,117,0,112,214,116,0,176,232,121,0,64,233,121,0,240,234,121,0,96,234,121,0,208,233,121,0,224,213,116,0,0,231,121,0,144,231,121,0,32,232,121,0,112,230,121,0,224,229,121,0,160,227,121,0,80,229,121,0,192,228,121,0,0,70,114,0,128,226,121,0,160,187,122,0,240,225,121,0,240,209,116,0,64,224,121,0,96,225,121,0,208,224,121,0,96,209,116,0,208,208,116,0,176,223,121,0,32,223,121,0,144,222,121,0,0,222,121,0,16,227,121,0,144,206,116,0,32,207,116,0,176,207,116,0,112,221,121,0,224,220,121,0,0,206,116,0,112,205,116,0,64,150,126,0,48,129,121,0,64,144,114,0,80,220,121,0,160,192,123,0,128,217,121,0,48,219,121,0,160,218,121,0,16,218,121,0,96,162,121,0,176,143,114,0,112,133,125,0,160,0,126,0,80,204,116,0,192,203,116,0,224,204,116,0,48,203,116,0,96,106,117,0,208,105,117,0,16,209,121,0,128,208,121,0,64,199,116,0,48,201,121,0,160,200,121,0,192,201,121,0,176,189,116,0,208,206,121,0,96,207,121,0,240,207,121,0,208,232,119,0,0,163,120,0,32,231,119,0,64,232,119,0,64,206,121,0,176,205,121,0,32,198,116,0,176,198,116,0,224,195,116,0,112,196,116,0,144,197,116,0,0,197,116,0,80,195,116,0,144,142,114,0,192,194,116,0,48,194,116,0,160,193,116,0,96,191,116,0,32,189,116,0,144,63,118,0,32,64,118,0,48,42,118,0,160,41,118,0,144,143,116,0,144,188,116,0,112,21,117,0,80,20,117,0,80,186,116,0,240,182,116,0,208,181,116,0,96,182,116,0,192,185,116,0,128,183,116,0,16,184,116,0,160,184,116,0,48,185,116,0,224,186,116,0,112,187,116,0,80,140,114,0,32,196,121,0,240,198,121,0,96,198,121,0,208,197,121,0,64,197,121,0,176,196,121,0,128,199,121,0,144,195,121,0,16,200,121,0,64,181,116,0,176,180,116,0,32,180,116,0,0,195,121,0,192,139,114,0,112,194,121,0,144,179,116,0,0,61,114,0,112,60,114,0,144,61,114,0,224,193,121,0,80,5,114,0,0,179,116,0,48,139,114,0,160,138,114,0,112,178,116,0,128,210,116,0,160,211,116,0,16,211,116,0,224,177,116,0,80,177,116,0,192,176,116,0,48,176,116,0,160,175,116,0,192,192,121,0,48,192,121,0,16,175,116,0,160,191,121,0,128,174,116,0,240,173,116,0,80,193,121,0,192,4,114,0,240,136,114,0,48,4,114,0,96,136,114,0,128,190,121,0,240,189,121,0,16,191,121,0,64,188,121,0,176,187,121,0,32,187,121,0,144,186,121,0,208,135,114,0,160,3,114,0,176,171,116,0,32,171,116,0,0,170,116,0,64,135,114,0,176,178,121,0,32,178,121,0,0,177,121,0,144,177,121,0,112,176,121,0,224,175,121,0,80,59,114,0,224,59,114,0,80,175,121,0,192,174,121,0,48,174,121,0,160,173,121,0,16,173,121,0,192,158,116,0,128,172,121,0,240,171,121,0,96,171,121,0,208,170,121,0,48,158,116,0,64,170,121,0,160,157,116,0,128,156,116,0,32,169,121,0,176,169,121,0,96,146,116,0,128,163,121,0,240,162,121,0,64,145,116,0,240,46,114,0,96,46,114,0,208,45,114,0,128,47,114,0,64,45,114,0,176,44,114,0,32,44,114,0,0,159,121,0,112,158,121,0,176,144,116,0,224,157,121,0,176,160,121,0,32,160,121,0,144,159,121,0,80,157,121,0,208,161,121,0,64,161,121,0,48,156,121,0,192,156,121,0,32,144,116,0,0,133,114,0,160,155,121,0,16,155,121,0,0,143,116,0,16,3,114,0,112,132,114,0,224,131,114,0,176,149,126,0,112,142,116,0,224,141,116,0,80,141,116,0,192,140,116,0,48,140,116,0,128,154,121,0,96,153,121,0,240,153,121,0,128,2,114,0,176,151,121,0,32,151,121,0,144,150,121,0,80,131,114,0,176,162,116,0,64,163,116,0,208,163,116,0,96,164,116,0,240,164,116,0,128,165,116,0,16,166,116,0,160,166,116,0,48,167,116,0,80,168,116,0,192,167,116,0,224,168,116,0,64,172,116,0,32,162,116,0,144,161,116,0,0,161,116,0,192,131,116,0,48,131,116,0,160,130,116,0,32,126,116,0,176,126,116,0,64,127,116,0,208,127,116,0,96,128,116,0,240,128,116,0,128,129,116,0,16,130,116,0,160,245,121,0,208,152,121,0,224,123,116,0,80,123,116,0,80,213,116,0,192,122,116,0,160,121,116,0,16,121,116,0,128,120,116,0,240,248,113,0,32,81,116,0,144,80,116,0,0,80,116,0,112,79,116,0,224,78,116,0,160,139,116,0,48,122,116,0,240,119,116,0,224,132,116,0,112,133,116,0,0,134,116,0,144,134,116,0,32,135,116,0,176,135,116,0,64,136,116,0,128,138,116,0,208,136,116,0,240,137,116,0,16,139,116,0,96,137,116,0,80,132,116,0,144,125,116,0,0,125,116,0,112,124,116,0,64,152,121,0,80,105,116,0,128,6,122,0,240,5,122,0,224,105,116,0,112,106,116,0,0,107,116,0,0,150,121,0,192,104,116,0,48,104,116,0,160,103,116,0,16,103,116,0,208,145,116,0,224,148,121,0,112,149,121,0,208,242,121,0,96,243,121,0,240,243,121,0,64,143,121,0,176,142,121,0,160,57,114,0,16,146,121,0,128,102,116,0,160,146,121,0,0,142,114,0,224,5,114,0,80,202,121,0,224,202,121,0,64,190,116,0,208,190,116,0,192,130,114,0,96,173,116,0,208,172,116,0,48,147,121,0,192,147,121,0,80,148,121,0,16,255,123,0,16,182,121,0,160,182,121,0,32,142,121,0,176,133,121,0,144,141,121,0,240,101,116,0,96,101,116,0,208,100,116,0,96,144,121,0,208,143,121,0,16,57,114,0,96,145,114,0,0,240,121,0,112,239,121,0,224,238,121,0,32,241,121,0,144,240,121,0,112,140,121,0,0,141,121,0,224,139,121,0,64,100,116,0,176,99,116,0,32,99,116,0,192,138,121,0,48,138,121,0,80,139,121,0,80,96,116,0,144,98,116,0,0,98,116,0,112,97,116,0,192,95,116,0,224,96,116,0,128,56,114,0,240,55,114,0,48,130,114,0,160,137,121,0,128,136,121,0,16,137,121,0,160,129,114,0,48,95,116,0,160,94,116,0,240,1,114,0,16,129,114,0,16,94,116,0,240,92,116,0,96,92,116,0,128,93,116,0,208,91,116,0,64,91,116,0,176,90,116,0,32,90,116,0,144,89,116,0,0,89,116,0,240,135,121,0,112,88,116,0,64,134,121,0,224,87,116,0,96,117,121,0,64,54,114,0,176,53,114,0,128,75,116,0,16,76,116,0,208,116,121,0,64,116,121,0,176,115,121,0,32,115,121,0,112,70,116,0,224,69,116,0,48,59,116,0,192,59,116,0,80,60,116,0,224,60,116,0,16,58,116,0,160,58,116,0,112,61,116,0,0,62,116,0,32,72,116,0,176,72,116,0,96,74,116,0,240,74,116,0,64,73,116,0,208,73,116,0,80,69,116,0,192,68,116,0,48,68,116,0,160,67,116,0,144,114,121,0,128,8,117,0,240,7,117,0,96,7,117,0,16,67,116,0,112,113,121,0,144,62,116,0,32,63,116,0,240,108,121,0,240,127,114,0,48,111,121,0,192,111,121,0,144,52,114,0,32,53,114,0,16,110,121,0,128,109,121,0,160,66,114,0,16,66,114,0,128,65,114,0,240,64,114,0,48,67,114,0,96,29,125,0,240,29,125,0,208,28,125,0,128,30,125,0,16,31,125,0,64,37,125,0,64,28,125,0,176,36,125,0,144,35,125,0,32,36,125,0,112,34,125,0,80,33,125,0,160,31,125,0,0,35,125,0,224,33,125,0,48,32,125,0,192,32,125,0,64,82,125,0,176,81,125,0,32,81,125,0,144,80,125,0,0,80,125,0,112,79,125,0,224,78,125,0,32,45,125,0,208,64,125,0,192,59,125,0,144,44,125,0,176,63,125,0,224,42,125,0,48,59,125,0,0,44,125,0,112,43,125,0,160,58,125,0,80,42,125,0,128,84,125,0,16,58,125,0,192,41,125,0,48,41,125,0,160,40,125,0,80,60,125,0,128,57,125,0,80,78,125,0,192,77,125,0,0,53,125,0,240,47,125,0,64,64,125,0,96,47,125,0,32,143,114,0,240,74,125,0,128,75,125,0,48,68,125,0,0,71,125,0,112,70,125,0,224,69,125,0,80,69,125,0,192,68,125,0,64,73,125,0,208,73,125,0,128,66,125,0,208,82,125,0,240,83,125,0,96,83,125,0,240,65,125,0,48,77,125,0,32,54,125,0,144,53,125,0,112,52,125,0,224,51,125,0,80,51,125,0,192,50,125,0,48,50,125,0,160,49,125,0,16,49,125,0,128,48,125,0,16,76,125,0,144,71,125,0,96,74,125,0,160,76,125,0,176,72,125,0,160,67,125,0,32,72,125,0,16,67,125,0,208,46,125,0,64,46,125,0,176,45,125,0,16,40,125,0,128,39,125,0,240,38,125,0,96,38,125,0,208,37,125,0,32,63,125,0,224,60,125,0,64,55,125,0,176,54,125,0,160,202,116,0,240,200,116,0,240,56,125,0,96,56,125,0,208,55,125,0,16,202,116,0,128,201,116,0,0,62,125,0,112,61,125,0,144,62,125,0,96,65,125,0,176,214,121,0,64,215,121,0,208,215,121,0,112,212,121,0,32,214,121,0,0,213,121,0,144,213,121,0,80,211,121,0,224,211,121,0,160,209,121,0,192,210,121,0,48,210,121,0,96,216,121,0,224,15,125,0,96,11,125,0,112,16,125,0,16,13,125,0,240,11,125,0,160,13,125,0,192,14,125,0,128,12,125,0,80,15,125,0,48,14,125,0,32,27,125,0,176,27,125,0,128,21,125,0,240,20,125,0,96,20,125,0,48,23,125,0,160,22,125,0,16,22,125,0,192,23,125,0,80,24,125,0,0,26,125,0,224,24,125,0,112,25,125,0,144,26,125,0,0,17,125,0,144,17,125,0,64,19,125,0,32,18,125,0,208,19,125,0,176,18,125,0,192,49,114,0,80,87,116,0,112,51,114,0,64,82,116,0,0,52,114,0,224,50,114,0,80,50,114,0,0,170,125,0,144,107,116,0,96,119,116,0,64,118,116,0,176,117,116,0,80,114,116,0,224,114,116,0,112,115,116,0,0,116,116,0,144,116,116,0,32,117,116,0,32,108,116,0,176,108,116,0,64,109,116,0,208,109,116,0,96,110,116,0,240,110,116,0,128,111,116,0,16,112,116,0,160,112,116,0,48,113,116,0,192,113,116,0,208,118,116,0,128,66,116,0,80,244,124,0,160,242,124,0,48,243,124,0,192,243,124,0,208,64,116,0,240,65,116,0,96,65,116,0,96,108,121,0,0,114,121,0,64,64,116,0,176,63,116,0,112,10,122,0,224,9,122,0,48,8,122,0,160,7,122,0,16,7,122,0,80,9,122,0,192,8,122,0,128,74,114,0,96,127,114,0,208,107,121,0,128,57,116,0,240,56,116,0,64,55,116,0,96,56,116,0,208,55,116,0,176,54,116,0,64,242,121,0,96,180,121,0,240,180,121,0,32,54,116,0,64,107,121,0,32,124,121,0,112,122,121,0,224,121,121,0,192,120,121,0,16,119,121,0,144,123,121,0,0,123,121,0,176,124,121,0,80,121,121,0,48,120,121,0,160,119,121,0,128,118,121,0,80,78,116,0,192,77,116,0,176,225,116,0,32,225,116,0,112,52,116,0,0,105,121,0,224,62,120,0,144,215,116,0,16,245,121,0,128,244,121,0,208,46,116,0,144,105,121,0,176,106,121,0,32,106,121,0,48,246,121,0,16,48,114,0,80,103,121,0,192,102,121,0,224,103,121,0,80,238,121,0,192,237,121,0,160,236,121,0,48,237,121,0,16,236,121,0,128,235,121,0,0,53,116,0,144,53,116,0,112,69,114,0,192,212,116,0,48,212,116,0,96,200,116,0,208,199,116,0,48,102,121,0,64,10,125,0,32,9,125,0,176,9,125,0,208,10,125,0,208,98,121,0,208,54,114,0,96,55,114,0,224,51,116,0,144,204,121,0,0,204,121,0,32,205,121,0,240,191,116,0,128,192,116,0,64,98,121,0,0,188,116,0,16,49,116,0,128,48,116,0,240,47,116,0,144,170,116,0,112,169,116,0,64,46,116,0,176,97,121,0,176,45,116,0,144,96,121,0,32,97,121,0,96,155,116,0,240,155,116,0,112,151,116,0,208,154,116,0,64,154,116,0,32,153,116,0,0,152,116,0,144,152,116,0,224,252,122,0,176,134,114,0,96,99,121,0,32,134,114,0,144,133,114,0,48,149,116,0,224,150,116,0,80,166,121,0,224,166,121,0,160,148,116,0,160,164,121,0,48,165,121,0,192,165,121,0,16,148,116,0,0,168,121,0,112,167,121,0,144,168,121,0,16,164,121,0,192,5,125,0,80,6,125,0,160,49,116,0,64,101,118,0,208,101,118,0,176,100,118,0,240,144,121,0,128,145,121,0,160,4,125,0,128,3,125,0,16,4,125,0,48,5,125,0,96,2,125,0,240,2,125,0,192,86,116,0,48,86,116,0,144,132,121,0,32,133,121,0,160,85,116,0,16,128,121,0,128,127,121,0,240,126,121,0,96,83,116,0,208,82,116,0,176,81,116,0,160,128,121,0,0,16,123,0,112,15,123,0,240,117,121,0,96,1,114,0,128,128,114,0,16,85,116,0,128,84,116,0,224,253,124,0,32,0,125,0,208,1,125,0,144,255,124,0,112,254,124,0,144,246,124,0,32,247,124,0,176,0,125,0,64,1,125,0,0,255,124,0,240,83,116,0,96,249,124,0,240,249,124,0,128,250,124,0,16,251,124,0,160,251,124,0,48,252,124,0,192,252,124,0,208,248,124,0,80,253,124,0,176,247,124,0,64,248,124,0,112,245,124,0,224,244,124,0,0,246,124,0,0,71,116,0,144,71,116,0,0,96,121,0,160,48,114,0,48,49,114,0,48,41,116,0,80,42,116,0,192,41,116,0,64,126,114,0,208,0,114,0,192,93,121,0,48,93,121,0,160,92,121,0,64,125,121,0,16,101,121,0,128,100,121,0,48,50,116,0,192,50,116,0,160,101,121,0,80,51,116,0,224,42,116,0,224,94,121,0,80,94,121,0,112,95,121,0,208,126,114,0,160,40,116,0,16,92,121,0,128,91,121,0,240,90,121,0,16,40,116,0,128,39,116,0,208,194,115,0,240,38,116,0,96,38,116,0,208,37,116,0,64,37,116,0,32,67,115,0,144,8,116,0,176,36,116,0,32,36,116,0,144,35,116,0,0,35,116,0,32,159,119,0,144,158,119,0,112,34,116,0,144,142,123,0,0,142,123,0,32,143,123,0,32,152,123,0,0,34,114,0,160,255,114,0,224,33,116,0,176,125,114,0,112,141,114,0,224,140,114,0,64,0,114,0,176,255,113,0,80,33,116,0,192,32,116,0,96,90,121,0,48,32,116,0,208,89,121,0,64,89,121,0,192,225,115,0,32,70,121,0,144,69,121,0,128,30,116,0,16,31,116,0,160,120,123,0,80,22,121,0,0,124,114,0,32,125,114,0,144,124,114,0,240,29,116,0,144,87,121,0,32,88,121,0,176,88,121,0,16,22,116,0,96,20,116,0,128,12,116,0,64,19,116,0,240,45,121,0,208,19,116,0,48,14,116,0,192,14,116,0,80,15,116,0,0,17,116,0,112,16,116,0,224,15,116,0,176,18,116,0,144,17,116,0,32,18,116,0,160,13,116,0,16,13,116,0,144,236,113,0,240,11,116,0,160,83,121,0,16,83,121,0,128,82,121,0,64,44,121,0,176,43,121,0,96,45,121,0,0,42,121,0,64,248,115,0,176,247,115,0,208,44,121,0,0,245,113,0,112,244,113,0,32,43,121,0,48,39,121,0,144,42,121,0,160,38,121,0,16,38,121,0,112,41,121,0,0,246,115,0,32,247,115,0,112,245,115,0,224,244,115,0,80,40,121,0,192,39,121,0,224,40,121,0,144,246,115,0,96,11,116,0,240,81,121,0,208,10,116,0,176,9,116,0,32,9,116,0,64,10,116,0,224,177,125,0,112,178,125,0,0,219,124,0,64,221,124,0,112,218,124,0,96,81,121,0,208,80,121,0,208,144,114,0,32,79,121,0,64,80,121,0,144,78,121,0,176,79,121,0,224,122,114,0,112,77,121,0,224,76,121,0,80,76,121,0,0,78,121,0,128,21,116,0,80,119,126,0,192,118,126,0,240,72,121,0,48,118,126,0,160,117,126,0,0,43,114,0,208,71,121,0,96,72,121,0,224,6,116,0,80,6,116,0,112,120,126,0,160,74,121,0,224,119,126,0,16,74,121,0,128,73,121,0,48,75,121,0,192,75,121,0,64,71,121,0,176,70,121,0,224,53,120,0,80,53,120,0,192,52,120,0,160,51,120,0,224,44,120,0,112,45,120,0,0,46,120,0,144,46,120,0,32,47,120,0,176,47,120,0,64,48,120,0,208,48,120,0,96,49,120,0,240,49,120,0,128,50,120,0,16,51,120,0,80,44,120,0,32,230,117,0,144,229,117,0,192,239,116,0,192,63,115,0,64,141,126,0,80,17,120,0,48,10,117,0,160,9,117,0,208,96,126,0,208,214,119,0,96,215,119,0,240,215,119,0,128,216,119,0,16,217,119,0,160,217,119,0,48,218,119,0,192,218,119,0,80,219,119,0,224,219,119,0,112,220,119,0,0,221,119,0,144,221,119,0,32,222,119,0,176,222,119,0,64,223,119,0,208,223,119,0,96,224,119,0,240,224,119,0,128,225,119,0,16,226,119,0,160,90,126,0,16,90,126,0,192,82,126,0,240,152,119,0,128,153,119,0,224,73,124,0,0,75,124,0,112,74,124,0,144,75,124,0,192,189,124,0,48,189,124,0,160,188,124,0,224,190,124,0,80,190,124,0,32,139,124,0,64,61,119,0,112,40,119,0,160,170,124,0,16,170,124,0,0,14,119,0,0,69,121,0,112,68,121,0,224,232,118,0,80,19,124,0,192,18,124,0,160,8,124,0,48,9,124,0,224,205,118,0,80,205,118,0,192,204,118,0,64,140,115,0,224,67,121,0,80,67,121,0,32,246,113,0,192,66,121,0,96,241,117,0,32,66,122,0,176,66,122,0,144,183,115,0,80,142,118,0,160,140,118,0,16,140,118,0,80,133,118,0,48,101,119,0,160,100,119,0,224,142,118,0,48,132,118,0,208,179,121,0,64,179,121,0,32,125,123,0,208,119,118,0,176,82,118,0,64,90,123,0,208,90,123,0,112,80,118,0,64,145,125,0,160,148,125,0,16,148,125,0,240,146,125,0,208,145,125,0,96,146,125,0,128,147,125,0,176,144,125,0,224,86,123,0,192,85,123,0,80,86,123,0,80,89,120,0,48,88,120,0,192,88,120,0,160,84,123,0,48,85,123,0,160,87,120,0,240,82,123,0,128,83,123,0,16,84,123,0,128,86,120,0,96,82,123,0,208,81,123,0,16,87,120,0,240,85,120,0,144,79,123,0,32,80,123,0,176,80,123,0,64,81,123,0,32,73,118,0,144,72,118,0,208,84,120,0,176,83,120,0,64,84,120,0,96,85,120,0,32,83,120,0,240,94,120,0,128,95,120,0,128,104,120,0,96,94,120,0,208,93,120,0,176,92,120,0,64,93,120,0,96,103,120,0,240,103,120,0,144,91,120,0,32,92,120,0,112,99,120,0,208,102,120,0,64,102,120,0,0,100,120,0,176,101,120,0,32,101,120,0,144,100,120,0,224,98,120,0,80,98,120,0,112,90,120,0,0,91,120,0,192,97,120,0,48,97,120,0,160,96,120,0,224,89,120,0,16,96,120,0,192,202,114,0,128,77,120,0,16,78,120,0,240,76,120,0,96,76,120,0,0,54,118,0,144,34,123,0,0,34,123,0,112,33,123,0,224,32,123,0,80,32,123,0,192,31,123,0,96,189,121,0,208,188,121,0,32,17,114,0,144,16,114,0,96,39,118,0,32,37,118,0,144,36,118,0,0,36,118,0,112,35,118,0,224,200,117,0,112,201,117,0,0,202,117,0,144,202,117,0,32,203,117,0,176,203,117,0,176,8,123,0,32,8,123,0,64,9,123,0,224,227,117,0,48,121,114,0,48,243,115,0,80,243,113,0,128,37,121,0,224,243,113,0,240,36,121,0,96,36,121,0,144,173,122,0,0,173,122,0,32,174,122,0,80,176,114,0,224,171,122,0,80,171,122,0,112,172,122,0,112,111,117,0,80,110,117,0,224,110,117,0,16,108,117,0,160,108,117,0,240,106,117,0,128,107,117,0,192,109,117,0,48,109,117,0,0,103,117,0,112,102,117,0,112,93,117,0,224,92,117,0,80,92,117,0,128,71,117,0,16,72,117,0,160,65,121,0,160,94,125,0,128,93,125,0,240,92,125,0,96,92,125,0,80,96,125,0,192,95,125,0,48,95,125,0,64,33,117,0,176,32,117,0,208,216,123,0,64,216,123,0,144,4,117,0,32,5,117,0,176,5,117,0,64,208,116,0,80,184,121,0,192,183,121,0,112,185,121,0,224,184,121,0,0,186,121,0,48,183,121,0,32,240,119,0,176,240,119,0,64,241,119,0,128,147,116,0,240,146,116,0,112,131,121,0,224,130,121,0,80,130,121,0,176,0,116,0,144,255,115,0,112,254,115,0,224,253,115,0,48,252,115,0,192,252,115,0,80,253,115,0,32,0,116,0,0,255,115,0,32,45,116,0,144,44,116,0,0,44,116,0,112,43,116,0,240,99,121,0,0,8,116,0,112,7,116,0,160,251,115,0,128,64,121,0,16,237,114,0,96,126,121,0,224,215,120,0,224,82,115,0,208,1,116,0,64,1,116,0,128,240,113,0,208,235,125,0,96,236,125,0,64,235,125,0,240,236,125,0,176,234,125,0,48,57,121,0,112,123,114,0,208,62,121,0,96,63,121,0,240,63,121,0,240,54,121,0,160,56,121,0,16,56,121,0,128,55,121,0,176,61,121,0,32,61,121,0,64,62,121,0,224,85,121,0,112,86,121,0,48,84,121,0,192,84,121,0,80,85,121,0,192,5,116,0,48,5,116,0,160,4,116,0,16,4,116,0,128,3,116,0,208,53,121,0,96,2,116,0,64,53,121,0,240,2,116,0,96,54,121,0,16,65,121,0,80,58,121,0,144,228,115,0,224,58,121,0,0,60,121,0,112,59,121,0,144,60,121,0,32,52,121,0,144,51,121,0,0,51,121,0,112,50,121,0,176,52,121,0,32,255,113,0,80,49,121,0,224,49,121,0,144,254,113,0,80,122,114,0,16,251,115,0,192,48,121,0,128,250,115,0,240,249,115,0,160,47,121,0,48,48,121,0,144,245,113,0,0,254,113,0,96,249,115,0,208,248,115,0,32,220,115,0,96,222,115,0,208,221,115,0,176,220,115,0,144,219,115,0,64,221,115,0,192,121,114,0,80,244,115,0,192,243,115,0,16,157,116,0,208,239,115,0,160,242,115,0,128,241,115,0,16,242,115,0,240,240,115,0,96,240,115,0,160,120,114,0,176,34,121,0,0,33,121,0,208,35,121,0,64,35,121,0,176,238,115,0,64,239,115,0,144,33,121,0,32,34,121,0,32,238,115,0,144,237,115,0,176,42,119,0,64,43,119,0,208,43,119,0,96,44,119,0,176,55,118,0,64,56,118,0,112,236,115,0,0,237,115,0,224,235,115,0,48,242,113,0,192,242,113,0,96,27,121,0,80,235,115,0,192,234,115,0,208,86,124,0,160,241,113,0,80,31,121,0,224,31,121,0,112,32,121,0,16,120,114,0,192,30,121,0,48,30,121,0,176,233,114,0,48,234,115,0,96,18,121,0,240,18,121,0,160,233,115,0,224,79,118,0,128,46,121,0,16,47,121,0,176,173,120,0,128,232,115,0,128,119,114,0,96,231,115,0,208,230,115,0,240,231,115,0,0,228,115,0,112,227,115,0,224,226,115,0,240,239,113,0,16,241,113,0,96,239,113,0,208,238,113,0,240,118,114,0,112,253,113,0,208,26,121,0,176,25,121,0,64,26,121,0,0,87,121,0,0,24,121,0,64,230,115,0,176,229,115,0,32,229,115,0,32,25,121,0,144,24,121,0,192,21,121,0,112,23,121,0,224,22,121,0,48,21,121,0,48,225,115,0,160,224,115,0,16,224,115,0,128,223,115,0,240,222,115,0,16,20,121,0,160,20,121,0,96,118,114,0,32,13,115,0,208,17,121,0,64,17,121,0,32,16,121,0,176,16,121,0,112,218,115,0,0,219,115,0,144,15,121,0,128,28,121,0,16,29,121,0,240,27,121,0,160,29,121,0,16,233,115,0,0,15,121,0,224,217,115,0,112,14,121,0,224,13,121,0,224,252,113,0,80,217,115,0,80,13,121,0,80,252,113,0,208,117,114,0,192,251,113,0,64,117,114,0,176,116,114,0,48,251,113,0,192,12,121,0,160,11,121,0,48,12,121,0,192,216,115,0,16,11,121,0,48,216,115,0,240,9,121,0,128,10,121,0,96,9,121,0,32,237,113,0,160,215,115,0,16,215,115,0,208,8,121,0,128,214,115,0,240,213,115,0,96,213,115,0,64,8,121,0,208,212,115,0,32,76,124,0,128,241,124,0,96,218,125,0,224,169,118,0,16,242,124,0,0,210,115,0,112,209,115,0,64,212,115,0,32,211,115,0,144,210,115,0,176,7,121,0,96,0,121,0,224,4,121,0,176,211,115,0,80,4,121,0,224,208,115,0,80,208,115,0,144,6,121,0,0,6,121,0,112,5,121,0,32,7,121,0,192,207,115,0,192,3,121,0,48,207,115,0,48,3,121,0,160,206,115,0,128,1,121,0,240,0,121,0,16,206,115,0,80,198,122,0,0,200,122,0,112,199,122,0,224,198,122,0,240,20,116,0,128,27,119,0,144,115,114,0,128,205,115,0,208,255,120,0,160,188,115,0,192,233,113,0,48,233,113,0,240,204,115,0,208,203,115,0,96,204,115,0,208,239,124,0,240,240,124,0,96,240,124,0,160,233,124,0,48,234,124,0,192,234,124,0,80,235,124,0,112,236,124,0,224,235,124,0,0,237,124,0,96,231,124,0,208,230,124,0,16,233,124,0,64,230,124,0,176,229,124,0,32,229,124,0,240,231,124,0,128,232,124,0,0,236,113,0,224,234,113,0,112,235,113,0,176,254,120,0,32,254,120,0,144,253,120,0,64,255,120,0,176,202,115,0,112,252,120,0,0,253,120,0,224,251,120,0,160,240,120,0,48,241,120,0,32,238,124,0,144,237,124,0,64,239,124,0,176,238,124,0,144,201,115,0,16,197,115,0,240,195,115,0,128,196,115,0,112,200,115,0,160,197,115,0,48,198,115,0,192,198,115,0,80,199,115,0,224,199,115,0,0,201,115,0,112,114,114,0,160,250,113,0,48,250,120,0,160,249,120,0,192,250,120,0,128,248,120,0,80,251,120,0,96,195,115,0,240,247,120,0,64,194,115,0,176,193,115,0,16,250,113,0,224,113,114,0,176,134,123,0,32,134,123,0,208,237,120,0,80,234,113,0,16,188,115,0,128,187,115,0,80,113,114,0,128,249,113,0,64,246,120,0,176,245,120,0,32,245,120,0,96,247,120,0,208,246,120,0,0,244,120,0,144,244,120,0,112,243,120,0,224,45,122,0,80,242,120,0,192,241,120,0,224,242,120,0,192,112,114,0,32,193,115,0,144,192,115,0,192,189,115,0,80,190,115,0,224,190,115,0,112,191,115,0,0,192,115,0,48,189,115,0,32,202,115,0,64,185,115,0,96,186,115,0,240,186,115,0,48,112,114,0,240,238,120,0,128,239,120,0,208,185,115,0,96,238,120,0,16,240,120,0,128,122,120,0,176,184,115,0,64,237,120,0,176,236,120,0,32,236,120,0,128,231,113,0,160,232,113,0,16,232,113,0,32,107,114,0,32,184,115,0,0,102,115,0,144,102,115,0,32,103,115,0,176,103,115,0,160,111,114,0,96,230,122,0,240,230,113,0,0,115,114,0,144,235,120,0,0,235,120,0,16,111,114,0,48,205,120,0,192,205,120,0,0,183,115,0,0,208,120,0,112,234,120,0,224,233,120,0,48,232,120,0,192,232,120,0,112,182,115,0,224,181,115,0,80,181,115,0,192,180,115,0,48,180,115,0,160,179,115,0,80,233,120,0,16,179,115,0,128,178,115,0,224,217,124,0,224,226,124,0,160,215,124,0,208,221,124,0,240,177,115,0,160,231,120,0,16,213,120,0,96,177,115,0,208,176,115,0,64,176,115,0,64,158,115,0,176,218,120,0,64,219,120,0,32,157,115,0,144,156,115,0,176,159,119,0,64,160,119,0,208,160,119,0,96,161,119,0,0,156,115,0,112,155,115,0,144,217,120,0,0,217,120,0,48,144,115,0,16,15,120,0,0,228,124,0,112,227,124,0,144,228,124,0,112,216,120,0,160,143,115,0,16,143,115,0,128,142,115,0,240,141,115,0,0,227,113,0,80,206,120,0,224,206,120,0,112,207,120,0,96,141,115,0,208,108,114,0,208,140,115,0,176,139,115,0,0,138,115,0,32,139,115,0,144,138,115,0,112,137,115,0,224,136,115,0,80,215,120,0,192,135,115,0,80,136,115,0,192,214,120,0,48,214,120,0,192,132,118,0,240,211,120,0,48,135,115,0,160,134,115,0,16,215,124,0,48,223,120,0,192,223,120,0,32,227,120,0,144,226,120,0,0,226,120,0,112,225,120,0,224,224,120,0,80,224,120,0,176,227,120,0,176,175,115,0,128,230,120,0,240,229,120,0,96,229,120,0,208,228,120,0,64,228,120,0,16,231,120,0,144,174,115,0,32,175,115,0,96,211,120,0,160,213,120,0,16,134,115,0,176,107,114,0,128,212,120,0,208,210,120,0,112,226,113,0,224,225,113,0,240,109,114,0,240,159,115,0,224,172,115,0,128,160,115,0,80,172,115,0,48,162,115,0,80,163,115,0,224,163,115,0,112,164,115,0,0,165,115,0,32,166,115,0,176,166,115,0,64,167,115,0,192,162,115,0,144,165,115,0,208,167,115,0,96,168,115,0,240,168,115,0,128,169,115,0,16,170,115,0,48,171,115,0,160,170,115,0,192,171,115,0,160,161,115,0,16,161,115,0,96,109,114,0,96,248,113,0,0,174,115,0,112,173,115,0,208,247,113,0,96,220,120,0,16,222,120,0,128,221,120,0,208,219,120,0,160,222,120,0,96,159,115,0,208,158,115,0,208,229,113,0,96,230,113,0,224,154,115,0,16,152,115,0,160,152,115,0,48,153,115,0,80,154,115,0,192,153,115,0,64,229,113,0,176,157,115,0,192,144,115,0,80,145,115,0,224,145,115,0,112,146,115,0,0,147,115,0,144,147,115,0,32,148,115,0,176,148,115,0,64,149,115,0,208,149,115,0,96,150,115,0,128,151,115,0,240,150,115,0,176,228,113,0,32,228,113,0,144,227,113,0,64,108,114,0,240,132,115,0,96,132,115,0,128,133,115,0,208,131,115,0,80,127,115,0,96,114,115,0,240,114,115,0,128,115,115,0,16,116,115,0,160,116,115,0,48,117,115,0,192,117,115,0,80,118,115,0,224,118,115,0,112,119,115,0,0,120,115,0,144,120,115,0,32,121,115,0,176,121,115,0,64,122,115,0,208,122,115,0,96,123,115,0,128,124,115,0,240,123,115,0,16,125,115,0,160,125,115,0,48,126,115,0,192,126,115,0,208,113,115,0,64,113,115,0,224,127,115,0,160,107,115,0,48,108,115,0,192,108,115,0,80,109,115,0,224,109,115,0,112,110,115,0,0,111,115,0,144,111,115,0,32,112,115,0,176,112,115,0,64,247,113,0,64,131,115,0,176,130,115,0,32,130,115,0,64,210,120,0,144,129,115,0,0,129,115,0,32,209,120,0,144,208,120,0,176,209,120,0,112,128,115,0,16,107,115,0,80,37,115,0,96,105,115,0,208,104,115,0,64,104,115,0,16,204,120,0,160,204,120,0,128,203,120,0,96,202,120,0,240,202,120,0,32,200,120,0,144,199,120,0,176,200,120,0,208,201,120,0,64,201,120,0,128,106,115,0,240,105,115,0,240,193,120,0,128,194,120,0,112,198,120,0,224,197,120,0,80,197,120,0,48,196,120,0,192,196,120,0,160,195,120,0,16,195,120,0,0,199,120,0,16,98,115,0,64,86,115,0,112,209,124,0,96,213,124,0])
.concat([0,210,124,0,144,210,124,0,32,211,124,0,240,213,124,0,80,208,124,0,224,208,124,0,64,212,124,0,176,211,124,0,192,207,124,0,128,214,124,0,208,212,124,0,128,97,115,0,208,86,115,0,96,87,115,0,240,87,115,0,128,88,115,0,16,89,115,0,160,89,115,0,48,90,115,0,192,90,115,0,80,91,115,0,224,91,115,0,112,92,115,0,0,93,115,0,144,93,115,0,32,94,115,0,64,95,115,0,176,94,115,0,208,95,115,0,96,96,115,0,240,96,115,0,176,202,124,0,128,205,124,0,32,202,124,0,64,203,124,0,16,206,124,0,48,207,124,0,96,204,124,0,208,203,124,0,0,201,124,0,112,200,124,0,160,206,124,0,240,204,124,0,144,201,124,0,32,85,115,0,176,85,115,0,112,101,115,0,224,100,115,0,192,57,121,0,144,106,114,0,192,99,115,0,48,99,115,0,160,98,115,0,96,193,120,0,0,84,115,0,144,84,115,0,80,225,113,0,64,192,120,0,176,246,113,0,112,83,115,0,176,191,120,0,112,105,114,0,192,81,115,0,80,82,115,0,160,80,115,0,16,80,115,0,48,81,115,0,224,104,114,0,32,191,120,0,128,79,115,0,96,78,115,0,240,78,115,0,192,224,113,0,192,103,114,0,80,104,114,0,224,188,120,0,144,190,120,0,112,189,120,0,0,190,120,0,208,77,115,0,176,76,115,0,80,188,120,0,64,77,115,0,192,187,120,0,48,187,120,0,32,76,115,0,144,75,115,0,160,186,120,0,224,91,124,0,0,75,115,0,16,186,120,0,128,185,120,0,240,184,120,0,48,224,113,0,160,223,113,0,96,184,120,0,48,103,114,0,112,74,115,0,208,183,120,0,224,73,115,0,80,73,115,0,192,72,115,0,48,72,115,0,160,71,115,0,16,71,115,0,128,70,115,0,240,69,115,0,64,183,120,0,128,222,113,0,16,223,113,0,0,0,0,0,0,0,0,0,0,0,0,240,0,0,0,240,248,6,8,8,40,0,184,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,5,4,8,4,9,0,0,8,8,40,0,184,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,1,4,9,4,10,208,0,8,9,176,0,144,0,160,1,224,4,4,9,4,10,208,3,8,9,176,0,56,0,224,4,64,7,4,9,4,10,96,6,8,9,176,0,152,0,64,7,80,9,4,9,4,10,232,7,8,9,184,0,184,0,80,9,128,10,4,9,4,10,248,8,8,9,176,0,128,0,128,10,160,13,4,9,4,10,208,12,8,9,184,0,176,0,160,13,64,15,4,9,4,10,8,14,8,9,184,0,112,0,64,15,192,16,4,9,4,10,232,15,8,9,184,0,152,0,192,16,112,19,4,9,4,10,64,17,8,9,184,0,104,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,18,112,19,0,8,0,9,136,18,8,8,153,0,206,0,112,19,224,20,0,8,0,9,240,18,8,8,120,0,40,0,224,20,96,22,0,8,0,9,136,20,8,8,128,0,112,0,96,22,240,24,0,8,0,9,0,22,8,8,128,0,144,0,128,20,64,22,248,6,0,8,8,21,8,7,128,0,144,0,64,22,96,23,248,6,0,8,232,22,240,6,128,0,88,0,96,23,0,25,248,6,0,8,112,23,40,7,128,0,128,0,224,20,112,21,160,6,248,6,8,21,232,5,64,0,136,0,112,21,128,22,160,6,248,6,104,21,8,6,128,0,144,0,128,22,112,23,160,6,248,6,64,22,232,5,136,0,136,0,112,23,208,24,160,6,248,6,112,23,80,6,216,0,112,0,224,20,112,21,100,6,160,6,8,21,232,5,64,0,136,0,112,21,128,22,100,6,160,6,120,21,208,5,152,0,96,0,128,22,112,23,100,6,160,6,64,22,232,5,136,0,136,0,112,23,208,24,100,6,160,6,112,23,80,6,216,0,112,0,224,20,112,21,36,6,100,6,8,21,232,5,64,0,136,0,112,21,128,22,36,6,100,6,120,21,208,5,152,0,96,0,128,22,112,23,36,6,100,6,64,22,232,5,136,0,136,0,112,23,208,24,36,6,100,6,112,23,136,5,144,0,136,0,224,20,112,21,212,5,36,6,8,21,232,5,64,0,136,0,112,21,128,22,212,5,36,6,120,21,208,5,152,0,96,0,128,22,160,22,212,5,36,6,48,22,40,5,136,0,136,0,160,22,112,23,212,5,36,6,88,22,40,5,136,0,136,0,112,23,208,24,212,5,36,6,112,23,136,5,144,0,136,0,224,20,208,21,164,5,212,5,8,21,128,5,64,0,128,0,208,21,240,21,164,5,212,5,8,21,248,4,128,0,96,0,240,21,48,22,164,5,212,5,128,21,248,4,104,0,128,0,48,22,160,22,164,5,212,5,48,22,48,5,136,0,128,0,160,22,176,23,164,5,212,5,88,22,40,5,136,0,136,0,176,23,192,24,164,5,212,5,112,23,8,5,152,0,136,0,224,20,240,21,248,4,164,5,8,21,248,4,128,0,96,0,240,21,112,22,248,4,164,5,200,21,72,5,168,0,112,0,112,22,80,23,248,4,164,5,128,22,40,5,168,0,112,0,80,23,208,24,248,4,164,5,112,23,160,4,168,0,120,0,224,20,48,22,120,4,248,4,8,21,248,4,128,0,96,0,48,22,176,22,120,4,248,4,208,21,64,4,184,0,120,0,176,22,96,23,120,4,248,4,96,22,96,4,128,0,96,0,96,23,240,23,120,4,248,4,56,23,32,4,144,0,112,0,240,23,208,24,120,4,248,4,112,23,80,4,216,0,96,0,224,20,208,22,248,3,120,4,0,21,232,3,144,0,88,0,208,22,240,23,248,3,120,4,224,22,152,3,104,0,104,0,240,23,208,24,248,3,120,4,112,23,80,4,216,0,96,0,224,20,16,22,92,3,248,3,24,21,104,3,144,0,88,0,16,22,176,22,92,3,248,3,176,21,64,3,152,0,88,0,176,22,224,23,92,3,248,3,40,23,32,3,104,0,104,0,224,23,208,24,92,3,248,3,112,23,48,3,192,0,128,0,224,20,80,22,248,2,92,3,24,21,104,3,144,0,88,0,80,22,208,23,248,2,92,3,48,22,176,2,136,0,96,0,208,23,208,24,248,2,92,3,64,23,168,2,144,0,88,0,224,20,80,22,104,2,248,2,168,21,104,2,128,0,88,0,80,22,176,23,104,2,248,2,80,22,80,2,128,0,88,0,176,23,208,24,104,2,248,2,64,23,168,2,144,0,88,0,224,20,240,21,216,1,104,2,8,21,8,2,120,0,96,0,240,21,176,23,216,1,104,2,200,22,120,1,128,0,96,0,176,23,208,24,216,1,104,2,64,23,168,2,144,0,88,0,224,20,208,24,88,1,216,1,16,22,16,1,120,0,104,0,224,20,208,24,88,1,216,1,16,22,16,1,120,0,104,0,208,20,208,24,92,1,156,1,24,22,16,1,120,0,104,0,208,20,176,21,156,1,188,1,24,22,16,1,120,0,104,0,176,21,112,22,156,1,188,1,128,21,40,1,112,0,128,0,112,22,208,24,156,1,188,1,24,22,16,1,120,0,104,0,208,20,240,20,188,1,220,1,24,22,16,1,120,0,104,0,240,20,240,21,188,1,220,1,8,21,8,2,120,0,96,0,240,21,112,22,188,1,220,1,128,21,40,1,112,0,128,0,112,22,208,24,188,1,220,1,24,22,16,1,120,0,104,0,208,20,240,20,188,1,220,1,24,22,16,1,120,0,104,0,240,20,112,22,140,1,188,1,8,21,8,2,120,0,96,0,208,20,176,21,140,1,188,1,24,22,16,1,120,0,104,0,176,21,112,22,140,1,188,1,128,21,40,1,112,0,128,0,112,22,208,24,140,1,188,1,24,22,16,1,120,0,104,0,208,20,208,24,92,1,140,1,24,22,16,1,120,0,104,0,224,20,64,24,152,0,92,1,176,22,176,0,136,0,96,0,64,24,208,24,136,0,92,1,112,23,24,1,192,0,96,0,80,18,160,21,0,0,8,1,0,21,0,0,128,0,72,0,160,21,240,22,0,0,152,0,152,22,0,0,128,0,80,0,240,22,208,24,0,0,136,0,112,23,0,0,184,0,96,0,80,18,224,20,0,0,12,1,0,21,0,0,128,0,72,0,224,20,160,21,0,0,156,0,0,21,0,0,128,0,72,0,160,21,240,22,0,0,156,0,152,22,0,0,128,0,80,0,240,22,48,24,0,0,156,0,112,23,0,0,184,0,96,0,48,24,208,24,0,0,156,0,112,23,24,1,192,0,96,0,224,20,48,24,156,0,88,1,176,22,176,0,136,0,96,0,48,24,208,24,156,0,88,1,112,23,24,1,192,0,96,0,224,20,80,22,156,2,240,2,168,21,104,2,128,0,88,0,224,20,16,22,240,2,252,3,24,21,104,3,144,0,88,0,224,20,48,22,252,3,108,4,0,21,232,3,144,0,88,0,224,20,48,22,108,4,28,5,8,21,248,4,128,0,96,0,224,20,240,21,28,5,156,5,8,21,248,4,128,0,96,0,224,20,240,21,156,5,216,5,8,21,128,5,64,0,128,0,224,20,112,21,216,5,0,7,8,21,232,5,64,0,136,0,128,20,64,22,0,7,8,8,8,21,8,7,128,0,144,0,0,0,208,24,0,0,0,9,136,18,8,8,153,0,206,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,3,160,6,4,7,4,8,96,5,8,7,104,0,144,0,160,6,80,8,4,7,4,8,0,6,8,7,128,0,112,0,80,8,224,9,4,7,4,8,96,8,8,7,96,0,144,0,224,9,0,12,4,7,4,8,192,9,8,7,104,0,128,0,0,12,160,13,4,7,4,8,88,12,8,7,104,0,112,0,160,13,128,15,4,7,4,8,128,13,8,7,112,0,176,0,128,15,128,16,4,7,4,8,168,14,8,7,112,0,176,0,128,16,48,18,4,7,4,8,192,15,8,7,128,0,48,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,2,24,6,248,6,216,0,8,6,184,0,160,0,128,2,128,3,24,6,248,6,176,2,8,6,184,0,144,0,128,3,32,6,24,6,248,6,200,2,8,6,192,0,144,0,32,6,96,7,24,6,248,6,48,6,8,6,192,0,40,0,96,7,16,9,24,6,248,6,232,7,8,6,184,0,120,0,16,9,48,10,24,6,248,6,48,9,8,6,184,0,128,0,48,10,96,11,24,6,248,6,72,10,8,6,192,0,104,0,144,0,208,1,248,6,248,7,32,0,16,6,184,0,168,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,1,244,4,248,5,0,0,24,5,104,0,176,0,192,1,192,3,244,4,248,5,208,0,24,5,120,0,96,0,192,3,224,6,244,4,248,5,240,2,24,5,120,0,72,0,224,6,64,8,244,4,248,5,112,6,24,5,120,0,72,0,64,8,16,10,244,4,248,5,216,7,24,5,112,0,96,0,16,10,128,11,244,4,248,5,232,9,0,5,128,0,128,0,128,11,144,16,244,4,248,5,32,11,24,4,112,0,128,0,48,2,160,3,12,4,244,4,232,2,176,4,128,0,144,0,160,3,176,3,12,4,244,4,120,2,24,3,120,0,168,0,32,5,224,8,12,4,244,4,8,6,24,3,128,0,88,0,224,8,0,10,12,4,244,4,120,8,24,3,120,0,152,0,48,2,176,3,248,2,12,4,120,2,24,3,120,0,168,0,176,3,32,5,248,2,12,4,144,3,24,3,112,0,184,0,32,5,224,8,248,2,12,4,8,6,24,3,128,0,88,0,224,8,0,10,248,2,12,4,120,8,24,3,120,0,152,0,0,0,32,1,0,1,0,2,0,0,8,2,64,0,112,0,0,0,32,1,0,2,0,3,0,0,8,2,64,0,112,0,32,1,96,4,0,2,0,3,128,0,24,2,176,0,128,0,96,4,144,6,0,2,120,2,80,4,248,1,144,0,48,0,96,4,144,6,120,2,0,3,80,4,24,2,160,0,160,0,144,6,208,7,0,2,120,2,24,6,248,1,160,0,64,0,144,6,208,7,120,2,0,3,40,6,24,2,168,0,176,0,208,7,176,8,0,2,0,3,168,7,24,2,144,0,96,0,176,8,208,9,0,2,0,3,64,8,24,2,136,0,96,0,208,9,0,11,0,2,0,3,88,9,24,2,160,0,112,0,0,11,144,12,0,2,0,3,152,10,24,2,136,0,80,0,144,12,0,14,0,2,0,3,32,12,0,2,160,0,40,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,1,0,0,24,0,32,0,168,0,0,2,128,3,0,0,0,1,224,1,24,0,112,0,152,0,128,3,32,6,0,0,0,1,160,4,24,0,112,0,144,0,32,6,240,8,0,0,0,1,184,6,24,0,120,0,120,0,240,8,32,10,0,0,0,1,200,8,24,0,112,0,40,0,32,10,128,12,0,0,0,1,104,10,24,0,112,0,88,0,128,12,0,14,0,0,0,1,64,12,24,0,112,0,64,0,128,3,192,7,0,1,0,2,56,0,24,4,112,0,168,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,28,227,2,98,89,151,74,103,77,31,17,118,100,193,225,210,65,159,253,250,4,254,171,137,235,192,245,172,43,100,34,144,125,136,197,140,224,217,112,60,244,125,49,28,202,226,241,49,130,134,177,85,149,119,1,119,59,171,230,136,239,119,17,86,1,172,85,247,109,155,109,146,20,35,174,75,128,174,106,67,204,53,254,161,13,179,33,78,76,153,128,194,61,206,70,155,93,104,117,254,30,37,65,36,160,121,253,181,103,147,7,58,120,36,100,225,163,98,117,56,101,138,191,249,124,0,160,109,219,31,128,55,55,142,151,26,69,97,14,16,36,138,39,242,68,145,62,98,68,197,85,230,142,90,37,138,144,37,116,160,149,51,247,81,206,228,160,19,207,51,30,89,91,236,66,197,184,228,197,113,56,197,107,141,29,132,248,78,33,109,220,44,241,174,173,25,197,237,142,54,181,129,148,254,98,58,232,201,149,132,189,101,21,22,21,210,231,22,215,156,211,210,102,246,70,227,50,98,81,134,74,103,204,77,234,55,69,213,166,128,230,186,179,8,216,48,91,95,242,90,251,99,176,164,65,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,3,0,0,0,5,0,0,0,3,0,0,0,0,0,0,0,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,4,0,4,4,4,4,4,4,4,4,4,4,4,4,4,4,6,0,0,6,6,0,6,6,6,6,6,6,0,6,6,0,4,0,0,4,4,0,4,4,4,4,4,0,4,4,0,4,4,0,0,4,4,0,4,4,4,4,4,0,4,4,0,4,7,0,0,7,7,0,7,7,7,7,7,0,7,7,0,7,6,0,0,6,6,0,6,6,6,6,6,0,6,6,0,6,9,6,0,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,2,2,2,2,2,2,0,2,2,2,2,2,2,2,2,0,2,2,2,2,0,8,2,0,4,4,4,4,4,4,4,5,4,4,4,4,3,7,4,5,5,5,5,5,5,5,5,6,5,5,5,5,4,8,5,6,6,6,6,6,6,6,6,7,6,6,6,6,5,9,6,7,5,5,5,5,5,5,5,6,5,5,5,5,4,8,5,6,4,4,4,4,4,4,4,5,4,4,4,4,3,7,4,5,1,1,1,1,1,1,1,1,4,4,4,4,5,5,5,5,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,3,3,7,6,3,3,3,3,3,3,3,3,3,3,4,4,3,3,4,4,4,4,4,4,4,4,4,4,3,3,3,3,3,1,1,1,3,3,3,3,3,3,3,3,5,5,5,5,5,5,5,5,3,3,3,3,3,3,3,3,5,5,5,5,5,5,5,5,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,5,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,6,2,2,2,4,4,4,4,4,2,2,2,2,3,3,2,1,3,2,2,11,22,11,2,4,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,2,2,3,2,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,1,0,0,0,2,0,0,0,4,0,0,0,8,0,0,0,16,0,0,0,32,0,0,0,64,0,0,0,128,0,0,0,254,0,0,0,253,0,0,0,251,0,0,0,247,0,0,0,239,0,0,0,223,0,0,0,191,0,0,0,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,78,7,0,0,122,28,0,0,88,20,0,0,10,1,0,0,94,31,0,0,248,12,0,0,86,44,0,0,254,25,0,0,80,5,0,0,32,18,0,0,84,49,0,0,190,30,0,0,124,12,0,0,52,42,0,0,160,23,0,0,166,4,0,0,202,22,0,0,78,41,0,0,218,9,0,0,74,28,0,0,184,46,0,0,132,15,0,0,208,33,0,0,216,1,0,0,56,21,0,0,182,39,0,0,194,23,0,0,60,42,0,0,192,10,0,0,60,29,0,0,152,47,0,0,110,16,0,0,222,30,0,0,160,12,0,0,46,18,0,0,116,49,0,0,200,6,0,0,90,38,0,0,236,43,0,0,158,48,0,0,166,32,0,0,116,14,0,0,32,30,0,0,170,35,0,0,78,17,0,0,166,24,0,0,234,5,0,0,170,11,0,0,62,46,0,0,26,15,0,0,76,9,0,0,238,27,0,0,164,20,0,0,60,39,0,0,86,33,0,0,20,8,0,0,50,48,0,0,150,23,0,0,16,4,0,0,164,48,0,0,82,17,0,0,242,9,0,0,128,28,0,0,250,22,0,0,172,45,0,0,94,27,0,0,204,8,0,0,84,40,0,0,198,21,0,0,190,2,0,0,108,3,0,0,68,16,0,0,128,47,0,0,4,29,0,0,202,37,0,0,88,19,0,0,154,50,0,0,50,32,0,0,228,13,0,0,26,45,0,0,236,41,0,0,164,29,0,0,58,48,0,0,222,16,0,0,28,37,0,0,64,5,0,0,64,24,0,0,180,42,0,0,10,13,0,0,88,31,0,0,24,12,0,0,122,30,0,0,234,48,0,0,104,19,0,0,214,37,0,0,82,6,0,0,194,26,0,0,10,8,0,0,210,13,0,0,128,16,0,0,136,50,0,0,8,32,0,0,170,37,0,0,52,19,0,0,88,28,0,0,210,9,0,0,148,18,0,0,88,24,0,0,110,5,0,0,74,11,0,0,192,42,0,0,80,48,0,0,24,42,0,0,138,10,0,0,150,4,0,0,138,23,0,0,244,17,0,0,88,36,0,0,120,30,0,0,34,49,0,0,88,40,0,0,188,8,0,0,206,42,0,0,56,37,0,0,130,5,0,0,6,50,0,0,206,18,0,0,44,13,0,0,116,16,0,0,162,47,0,0,68,29,0,0,208,10,0,0,138,40,0,0,238,21,0,0,250,2,0,0,172,34,0,0,38,18,0,0,108,49,0,0,100,8,0,0,20,40,0,0,130,21,0,0,58,0,0,0,252,40,0,0,34,14,0,0,152,31,0,0,18,50,0,0,198,18,0,0,52,37,0,0,144,5,0,0,94,24,0,0,222,42,0,0,82,11,0,0,68,33,0,0,84,1,0,0,104,32,0,0,74,0,0,0,190,19,0,0,14,38,0,0,144,6,0,0,88,25,0,0,32,32,0,0,164,50,0,0,70,19,0,0,212,37,0,0,56,6,0,0,24,25,0,0,110,43,0,0,20,12,0,0,96,30,0,0,230,48,0,0,126,18,0,0,252,36,0,0,60,5,0,0,54,24,0,0,178,42,0,0,34,11,0,0,218,18,0,0,42,50,0,0,194,5,0,0,74,37,0,0,168,44,0,0,90,26,0,0,196,31,0,0,82,13,0,0,218,20,0,0,104,1,0,0,238,10,0,0,174,16,0,0,222,47,0,0,10,5,0,0,190,36,0,0,140,42,0,0,60,34,0,0,52,2,0,0,20,47,0,0,228,15,0,0,98,8,0,0,0,27,0,0,126,21,0,0,156,34,0,0,12,36,0,0,48,4,0,0,34,6,0,0,24,23,0,0,236,47,0,0,206,40,0,0,40,9,0,0,76,3,0,0,6,5,0,0,226,36,0,0,196,23,0,0,168,49,0,0,174,44,0,0,222,12,0,0,24,44,0,0,228,25,0,0,252,6,0,0,144,38,0,0,84,26,0,0,172,7,0,0,72,39,0,0,192,19,0,0,100,1,0,0,112,33,0,0,244,20,0,0,134,39,0,0,196,7,0,0,144,26,0,0,102,46,0,0,86,15,0,0,146,33,0,0,168,1,0,0,132,22,0,0,34,41,0,0,50,37,0,0,176,25,0,0,234,43,0,0,118,14,0,0,186,32,0,0,164,0,0,0,28,36,0,0,168,17,0,0,196,34,0,0,92,4,0,0,68,10,0,0,226,41,0,0,48,47,0,0,216,28,0,0,200,37,0,0,86,19,0,0,236,6,0,0,172,12,0,0,242,43,0,0,130,49,0,0,250,34,0,0,164,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,1,0,0,40,8,0,0,150,5,0,0,162,10,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,36,12,0,0,4,13,0,0,66,8,0,0,220,10,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,0,15,0,0,88,0,0,0,214,16,0,0,104,14,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,196,4,0,0,40,5,0,0,50,7,0,0,218,9,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,58,0,0,0,28,6,0,0,40,12,0,0,46,3,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,124,11,0,0,48,3,0,0,226,13,0,0,32,16,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,232,13,0,0,34,9,0,0,180,2,0,0,18,0,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,226,9,0,0,194,3,0,0,204,14,0,0,126,1,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,170,1,0,0,142,16,0,0,28,4,0,0,174,18,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,180,11,0,0,212,10,0,0,52,1,0,0,68,2,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,18,3,0,0,0,12,0,0,2,15,0,0,44,15,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,162,4,0,0,222,12,0,0,64,6,0,0,32,17,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,198,0,0,0,84,4,0,0,200,9,0,0,94,10,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,126,2,0,0,60,5,0,0,204,0,0,0,136,1,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,186,16,0,0,76,7,0,0,224,4,0,0,112,3,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,10,12,0,0,78,16,0,0,140,1,0,0,254,14,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,30,19,0,0,50,8,0,0,26,18,0,0,32,5,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,70,3,0,0,108,19,0,0,196,13,0,0,164,14,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,0,0,0,0,0,0,0,0,0,41,44,53,58,65,74,78,87,94,119,121,122,123,124,125,126,127,128,129,130,133,134,135,136,137,138,139,140,141,142,144,149,150,151,152,153,154,155,156,158,163,212,169,175,181,187,193,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,1,4,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,49,32,0,112,50,32,0,112,51,32,0,112,52,32,0,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,5,4,7,6,1,0,3,2,13,12,15,14,9,8,11,10,10,11,8,9,14,15,12,13,2,3,0,1,6,7,4,5,15,14,13,12,11,10,9,8,7,6,5,4,3,2,1,0,0,1,2,3,4,5,6,7,1,0,3,2,5,4,7,6,6,7,4,5,2,3,0,1,7,6,5,4,3,2,1,0,0,1,2,3,4,5,6,7,5,4,7,6,1,0,3,2,2,3,0,1,6,7,4,5,7,6,5,4,3,2,1,0,0,1,2,3,1,0,3,2,2,3,0,1,3,2,1,0,0,0,0,0,0,0,0,0,208,69,188,132,147,96,125,73,104,177,84,162,5,41,65,32,4,8,82,37,137,244,105,159,36,70,61,241,249,171,166,45,24,25,109,51,121,35,59,29,224,184,97,26,225,76,93,63,94,2,227,77,158,128,40,80,160,129,228,165,151,161,134,54,30,237,22,138,68,6,100,18,154,126,206,155,239,247,62,248,21,7,203,111,142,60,130,112,98,141,102,122,78,211,182,106,81,167,44,199,164,11,181,229,136,189,90,91,27,174,230,95,46,146,140,183,150,186,153,187,190,14,191,231,47,233,48,55,152,172,74,148,56,243,57,178,85,114,123,238,221,110,17,213,38,168,113,214,116,127,19,194,86,234,169,175,195,66,3,179,196,107,71,240,49,245,170,88,143,72,117,149,53,139,87,58,115,12,89,216,20,101,215,0,250,220,52,222,192,176,135,193,200,205,212,42,218,232,210,131,13,202,242,15,235,236,156,31,173,34,209,75,92,246,23,197,103,157,251,201,204,50,28,180,217,226,207,144,185,43,99,198,118,33,119,39,252,253,10,9,124,1,67,219,83,133,254,120,145,64,163,223,79,255,16,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,0,0,2,0,0,0,6,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,186,7,0,0,148,1,0,0,138,6,0,0,6,1,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,20,13,0,0,102,3,0,0,88,8,0,0,18,4,0,0,230,3,0,0,170,12,0,0,172,13,0,0,114,7,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,100,11,0,0,192,6,0,0,78,1,0,0,40,19,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,198,6,0,0,18,10,0,0,116,13,0,0,142,9,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,240,5,0,0,144,10,0,0,100,1,0,0,200,17,0,0,226,10,0,0,224,13,0,0,110,0,0,0,228,11,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,72,8,0,0,202,12,0,0,252,4,0,0,202,17,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,144,11,0,0,248,13,0,0,86,2,0,0,238,17,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,42,13,0,0,46,6,0,0,6,20,0,0,112,2,0,0,154,13,0,0,106,3,0,0,188,5,0,0,246,15,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,52,3,0,0,172,0,0,0,82,14,0,0,136,2,0,0,194,6,0,0,194,6,0,0,194,6,0,0,194,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,4,4,4,4,4,4,4,4,15,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,15,4,4,4,4,4,4,4,14,20,10,9,9,9,4,4,15,20,10,9,9,9,4,4,4,4,4,23,23,19,4,4,15,4,4,4,4,4,4,4,4,4,4,9,9,19,4,4,4,4,4,9,9,19,4,4,4,4,4,9,9,19,4,4,4,4,4,9,9,19,4,9,9,9,9,9,9,19,9,9,9,9,9,9,9,19,9,19,19,19,19,19,19,4,19,4,4,4,4,9,9,19,4,4,4,4,4,9,9,19,4,4,4,4,4,9,9,19,4,4,4,4,4,9,9,19,4,4,4,4,4,9,9,19,4,4,4,4,4,9,9,19,4,4,4,4,4,9,9,19,4,4,4,4,4,9,9,19,4,4,4,4,4,9,9,19,4,4,4,4,4,4,4,4,4,4,4,4,0,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,14,4,23,4,15,4,4,4,8,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,10,4,4,4,4,4,4,4,10,7,6,4,4,7,4,4,11,7,6,4,4,7,4,8,10,7,6,4,4,7,4,12,11,7,6,4,4,7,4,7,10,16,6,4,4,7,4,7,11,16,6,4,4,7,4,7,10,13,6,11,11,10,4,7,11,13,6,4,4,7,4,4,4,4,4,4,4,7,4,4,4,4,4,4,4,7,4,4,4,4,4,4,4,7,4,4,4,4,4,4,4,7,4,4,4,4,4,4,4,7,4,4,4,4,4,4,4,7,4,7,7,7,7,7,7,4,7,4,4,4,4,4,4,7,4,4,4,4,4,4,4,7,4,4,4,4,4,4,4,7,4,4,4,4,4,4,4,7,4,4,4,4,4,4,4,7,4,4,4,4,4,4,4,7,4,4,4,4,4,4,4,7,4,4,4,4,4,4,4,7,4,4,4,4,4,4,4,7,4,5,10,10,10,10,11,7,11,5,10,10,0,10,17,7,11,5,10,10,11,10,11,7,11,5,4,10,11,10,0,7,11,5,10,10,19,10,11,7,11,5,4,10,4,10,0,7,11,5,10,10,4,10,11,7,11,5,6,10,4,10,0,7,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,0,0,0,0,5,0,0,0,0,0,0,0,5,0,0,0,0,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,5,5,5,0,0,0,0,5,5,5,5,0,0,0,0,6,0,0,0,7,0,0,2,6,0,0,0,7,0,0,2,6,0,0,0,7,0,0,2,6,0,0,0,7,0,0,2,6,0,0,0,7,0,0,2,6,0,0,0,7,0,0,2,6,0,0,0,7,0,0,2,6,0,0,0,7,0,0,2,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,12,12,15,20,8,14,8,9,12,12,15,20,8,14,8,9,12,12,15,20,8,14,8,9,12,12,15,20,8,14,8,9,12,12,15,20,8,14,8,18,12,12,15,20,8,14,8,18,12,12,15,20,8,14,8,8,12,12,15,20,8,14,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,16,16,16,16,8,8,8,8,16,16,16,16,8,8,8,8,16,16,16,16,8,8,8,8,16,16,16,16,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,15,8,8,8,8,8,8,8,15,8,8,8,8,8,8,8,15,8,8,8,8,8,8,8,15,8,8,8,8,8,8,8,15,8,8,8,8,8,8,8,15,8,8,8,8,8,8,8,15,8,8,8,8,8,8,8,15,8,8,8,8,8,8,8,12,8,8,8,8,8,8,8,12,8,8,8,8,8,8,8,12,8,8,8,8,8,8,8,12,8,8,8,8,8,8,8,12,8,8,8,8,8,8,8,12,8,8,8,8,8,8,8,12,8,8,8,8,8,8,8,12,8,8,8,8,8,8,8,15,8,8,8,8,8,8,8,15,8,8,8,8,8,8,8,15,8,8,8,8,8,8,8,15,8,8,8,8,8,8,8,15,8,8,8,8,8,8,8,15,8,8,8,8,8,8,8,15,8,8,8,8,8,8,8,15,8,8,8,8,8,8,8,15,8,8,8,8,8,8,8,15,8,8,8,8,8,8,8,15,8,8,8,8,8,8,8,15,8,8,8,8,8,8,8,15,8,8,8,8,8,8,8,15,8,8,8,8,8,8,8,15,8,8,8,8,8,8,8,15,8,126,38,0,0,32,20,0,0,216,25,0,0,242,6,0,0,148,14,0,0,174,45,0,0,214,0,0,0,206,32,0,0,206,36,0,0,234,4,0,0,136,37,0,0,88,43,0,0,228,24,0,0,4,32,0,0,188,13,0,0,46,19,0,0,156,3,0,0,120,22,0,0,248,16,0,0,66,35,0,0,110,14,0,0,76,25,0,0,20,41,0,0,122,9,0,0,148,1,0,0,232,20,0,0,228,11,0,0,42,6,0,0,244,24,0,0,136,17,0,0,236,35,0,0,76,30,0,0,202,7,0,0,10,31,0,0,252,20,0,0,138,1,0,0,232,31,0,0,124,13,0,0,196,44,0,0,128,26,0,0,154,9,0,0,8,41,0,0,206,6,0,0,94,38,0,0,252,19,0,0,100,49,0,0,224,30,0,0,140,12,0,0,82,23,0,0,228,12,0,0,82,10,0,0,200,28,0,0,166,29,0,0,10,16,0,0,86,34,0,0,100,2,0,0,22,25,0,0,54,6,0,0,232,30,0,0,62,43,0,0,66,18,0,0,144,36,0,0,216,4,0,0,212,23,0,0,250,49,0,0,196,15,0,0,84,21,0,0,16,2,0,0,46,8,0,0,240,33,0,0,24,45,0,0,222,26,0,0,46,32,0,0,248,13,0,0,74,26,0,0,158,31,0,0,76,13,0,0,208,18,0,0,30,50,0,0,158,5,0,0,146,42,0,0,80,11,0,0,14,5,0,0,254,23,0,0,98,18,0,0,182,16,0,0,16,31,0,0,152,49,0,0,30,44,0,0,200,12,0,0,46,50,0,0,156,44,0,0,88,13,0,0,136,7,0,0,94,26,0,0,226,20,0,0,236,2,0,0,100,4,0,0,108,16,0,0,176,47,0,0,24,21,0,0,186,10,0,0,56,42,0,0,114,37,0,0,228,0,0,0,220,32,0,0,66,45,0,0,166,6,0,0,76,8,0,0,8,40,0,0,116,21,0,0,36,2,0,0,180,18,0,0,58,37,0,0,134,5,0,0,106,24,0,0,124,44,0,0,52,13,0,0,134,31,0,0,10,50,0,0,6,17,0,0,80,35,0,0,160,19,0,0,0,38,0,0,122,6,0,0,250,26,0,0,76,45,0,0,22,14,0,0,146,22,0,0,160,3,0,0,166,9,0,0,28,41,0,0,88,48,0,0,224,29,0,0,96,35,0,0,252,16,0,0,100,24,0,0,148,5,0,0,204,14,0,0,62,20,0,0,8,1,0,0,2,9,0,0,160,40,0,0,232,45,0,0,220,37,0,0,60,6,0,0,42,0,0,0,118,19,0,0,30,12,0,0,102,30,0,0,32,25,0,0,122,43,0,0,246,39,0,0,60,8,0,0,212,38,0,0,10,33,0,0,34,1,0,0,72,44,0,0,0,13,0,0,64,7,0,0,30,29,0,0,110,38,0,0,176,26,0,0,254,44,0,0,132,37,0,0,26,6,0,0,112,50,0,0,40,19,0,0,220,11,0,0,68,30,0,0,186,42,0,0,44,37,0,0,96,5,0,0,54,48,0,0,236,16,0,0,68,11,0,0,120,17,0,0,198,48,0,0,62,30,0,0,240,11,0,0,158,41,0,0,40,23,0,0,36,4,0,0,246,35,0,0,30,19,0,0,118,50,0,0,14,31,0,0,190,12,0,0,26,44,0,0,248,23,0,0,12,5,0,0,194,36,0,0,168,32,0,0,168,0,0,0,244,19,0,0,92,38,0,0,204,6,0,0,186,25,0,0,238,43,0,0,162,12,0,0,110,34,0,0,178,2,0,0,6,12,0,0,80,30,0,0,210,48,0,0,144,17,0,0,22,36,0,0,56,4,0,0,168,15,0,0,202,46,0,0,0,2,0,0,220,33,0,0,232,39,0,0,66,21,0,0,206,26,0,0,18,8,0,0,226,13,0,0,10,45,0,0,180,14,0,0,70,20,0,0,248,0,0,0,56,7,0,0,168,38,0,0,236,11,0,0,96,1,0,0,190,20,0,0,24,15,0,0,100,33,0,0,232,27,0,0,72,46,0,0,224,40,0,0,100,9,0,0,106,3,0,0,102,22,0,0,2,31,0,0,204,25,0,0,14,44,0,0,102,38,0,0,152,3,0,0,130,7,0,0,150,34,0,0,74,16,0,0,148,47,0,0,24,29,0,0,172,10,0,0,36,42,0,0,172,23,0,0,158,4,0,0,218,32,0,0,134,14,0,0])
.concat([188,33,0,0,128,15,0,0,142,46,0,0,70,28,0,0,184,9,0,0,76,41,0,0,206,33,0,0,214,1,0,0,182,46,0,0,210,37,0,0,214,9,0,0,72,28,0,0,196,22,0,0,112,41,0,0,136,35,0,0,224,3,0,0,184,34,0,0,58,29,0,0,178,47,0,0,58,42,0,0,188,10,0,0,172,4,0,0,220,25,0,0,244,6,0,0,206,12,0,0,12,44,0,0,226,49,0,0,252,30,0,0,168,36,0,0,84,18,0,0,236,23,0,0,248,4,0,0,234,24,0,0,46,30,0,0,222,11,0,0,102,17,0,0,190,48,0,0,52,22,0,0,86,10,0,0,204,28,0,0,24,47,0,0,12,16,0,0,36,36,0,0,170,23,0,0,84,23,0,0,202,41,0,0,106,8,0,0,30,27,0,0,104,4,0,0,148,36,0,0,218,4,0,0,168,25,0,0,248,43,0,0,150,12,0,0,170,44,0,0,130,26,0,0,178,7,0,0,114,39,0,0,254,20,0,0,140,1,0,0,152,33,0,0,68,15,0,0,14,43,0,0,162,24,0,0,240,43,0,0,154,25,0,0,210,6,0,0,72,38,0,0,254,19,0,0,142,0,0,0,72,45,0,0,48,14,0,0,84,8,0,0,18,27,0,0,154,19,0,0,198,24,0,0,80,32,0,0,80,0,0,0,166,43,0,0,70,12,0,0,40,46,0,0,198,40,0,0,60,9,0,0,56,1,0,0,132,20,0,0,146,34,0,0,246,29,0,0,140,11,0,0,40,17,0,0,146,48,0,0,188,5,0,0,88,37,0,0,252,42,0,0,144,24,0,0,80,28,0,0,194,9,0,0,212,28,0,0,184,27,0,0,46,9,0,0,170,16,0,0,250,47,0,0,52,3,0,0,216,14,0,0,8,36,0,0,28,1,0,0,74,20,0,0,156,28,0,0,166,36,0,0,4,26,0,0,70,44,0,0,152,16,0,0,218,34,0,0,200,15,0,0,8,34,0,0,18,2,0,0,86,21,0,0,0,40,0,0,48,8,0,0,40,49,0,0,134,30,0,0,56,19,0,0,186,43,0,0,148,23,0,0,132,4,0,0,92,36,0,0,216,17,0,0,72,0,0,0,106,32,0,0,136,41,0,0,230,22,0,0,252,3,0,0,248,33,0,0,188,15,0,0,218,46,0,0,36,25,0,0,124,43,0,0,224,37,0,0,64,6,0,0,8,0,0,0,76,19,0,0,244,13,0,0,40,32,0,0,96,23,0,0,218,41,0,0,98,50,0,0,76,20,0,0,178,38,0,0,12,33,0,0,36,1,0,0,248,45,0,0,170,9,0,0,30,41,0,0,126,46,0,0,36,28,0,0,166,33,0,0,76,15,0,0,10,21,0,0,36,9,0,0,88,11,0,0,202,42,0,0,244,0,0,0,48,7,0,0,162,38,0,0,62,44,0,0,34,50,0,0,54,31,0,0,142,13,0,0,182,44,0,0,82,50,0,0,220,31,0,0,110,37,0,0,232,18,0,0,178,24,0,0,216,5,0,0,176,11,0,0,242,3,0,0,42,5,0,0,30,11,0,0,172,42,0,0,24,48,0,0,154,29,0,0,12,35,0,0,248,47,0,0,168,16,0,0,62,6,0,0,50,3,0,0,8,24,0,0,130,42,0,0,8,11,0,0,104,29,0,0,30,46,0,0,234,14,0,0,184,48,0,0,124,17,0,0,212,35,0,0,22,6,0,0,248,24,0,0,76,43,0,0,138,32,0,0,66,14,0,0,90,19,0,0,36,27,0,0,134,8,0,0,48,40,0,0,154,21,0,0,108,2,0,0,196,30,0,0,112,12,0,0,204,24,0,0,8,6,0,0,146,37,0,0,24,19,0,0,132,49,0,0,252,31,0,0,36,33,0,0,40,1,0,0,22,46,0,0,224,14,0,0,72,7,0,0,16,26,0,0,120,20,0,0,226,38,0,0,86,31,0,0,224,45,0,0,74,41,0,0,114,35,0,0,202,3,0,0,140,46,0,0,126,15,0,0,182,9,0,0,232,17,0,0,6,42,0,0,140,4,0,0,102,36,0,0,196,43,0,0,108,25,0,0,182,30,0,0,102,12,0,0,66,16,0,0,130,47,0,0,224,47,0,0,154,22,0,0,198,12,0,0,78,14,0,0,232,42,0,0,94,48,0,0,234,1,0,0,70,21,0,0,200,39,0,0,22,8,0,0,242,4,0,0,12,45,0,0,202,13,0,0,26,32,0,0,234,3,0,0,210,22,0,0,128,8,0,0,236,28,0,0,100,47,0,0,56,16,0,0,118,34,0,0,160,2,0,0,100,35,0,0,254,16,0,0,90,48,0,0,200,29,0,0,90,11,0,0,214,42,0,0,178,13,0,0,132,5,0,0,170,33,0,0,80,15,0,0,126,34,0,0,72,16,0,0,216,30,0,0,14,29,0,0,140,10,0,0,28,42,0,0,12,0,0,0,82,19,0,0,230,37,0,0,66,6,0,0,218,26,0,0,20,45,0,0,172,28,0,0,44,32,0,0,242,48,0,0,160,17,0,0,202,8,0,0,116,27,0,0,168,45,0,0,80,16,0,0,134,34,0,0,218,2,0,0,112,16,0,0,154,47,0,0,240,2,0,0,160,34,0,0,122,40,0,0,220,21,0,0,132,10,0,0,218,8,0,0,156,14,0,0,194,45,0,0,134,15,0,0,58,21,0,0,220,1,0,0,14,8,0,0,184,39,0,0,6,45,0,0,68,2,0,0,50,38,0,0,242,15,0,0,68,34,0,0,2,18,0,0,34,47,0,0,174,41,0,0,54,10,0,0,54,4,0,0,64,23,0,0,138,37,0,0,136,26,0,0,210,44,0,0,118,39,0,0,214,7,0,0,150,1,0,0,72,18,0,0,146,49,0,0,238,30,0,0,186,12,0,0,112,42,0,0,240,23,0,0,228,4,0,0,186,36,0,0,12,20,0,0,196,0,0,0,238,31,0,0,154,13,0,0,232,44,0,0,148,43,0,0,252,5,0,0,70,8,0,0,106,33,0,0,126,1,0,0,208,20,0,0,92,39,0,0,164,7,0,0,118,26,0,0,162,44,0,0,114,13,0,0,46,35,0,0,140,3,0,0,216,12,0,0,250,32,0,0,164,49,0,0,90,18,0,0,220,36,0,0,4,5,0,0,200,48,0,0,90,30,0,0,252,35,0,0,146,17,0,0,252,24,0,0,52,6,0,0,242,11,0,0,100,43,0,0,6,47,0,0,186,28,0,0,224,12,0,0,102,18,0,0,174,49,0,0,32,7,0,0,158,38,0,0,48,44,0,0,122,14,0,0,50,43,0,0,90,27,0,0,170,45,0,0,96,38,0,0,230,6,0,0,174,0,0,0,18,20,0,0,168,12,0,0,242,30,0,0,130,43,0,0,232,37,0,0,74,6,0,0,216,48,0,0,164,17,0,0,38,12,0,0,130,19,0,0,18,0,0,0,64,32,0,0,250,13,0,0,254,17,0,0,224,26,0,0,90,45,0,0,14,40,0,0,112,21,0,0,44,2,0,0,142,11,0,0,0,43,0,0,146,24,0,0,70,31,0,0,166,20,0,0,214,18,0,0,190,34,0,0,246,2,0,0,246,21,0,0,130,40,0,0,200,10,0,0,84,29,0,0,184,47,0,0,114,16,0,0,134,36,0,0,204,4,0,0,166,35,0,0,214,3,0,0,222,22,0,0,18,43,0,0,192,15,0,0,2,30,0,0,124,19,0,0,252,37,0,0,88,6,0,0,64,25,0,0,50,45,0,0,18,14,0,0,58,32,0,0,44,0,0,0,196,17,0,0,50,36,0,0,116,20,0,0,220,38,0,0,92,7,0,0,170,27,0,0,14,46,0,0,222,14,0,0,188,34,0,0,174,24,0,0,242,21,0,0,8,3,0,0,244,8,0,0,152,40,0,0,216,45,0,0,148,27,0,0,240,32,0,0,190,14,0,0,16,27,0,0,76,32,0,0,46,14,0,0,152,19,0,0,78,0,0,0,112,6,0,0,60,43,0,0,186,11,0,0,0,6,0,0,196,24,0,0,18,19,0,0,194,3,0,0,242,31,0,0,86,50,0,0,238,44,0,0,158,13,0,0,100,0,0,0,82,45,0,0,62,14,0,0,102,8,0,0,24,27,0,0,150,21,0,0,148,8,0,0,58,40,0,0,166,21,0,0,136,2,0,0,152,32,0,0,82,14,0,0,126,45,0,0,52,27,0,0,96,10,0,0,228,41,0,0,166,7,0,0,100,39,0,0,212,20,0,0,40,50,0,0,188,31,0,0,80,13,0,0,30,24,0,0,152,42,0,0,20,11,0,0,130,29,0,0,16,48,0,0,188,16,0,0,4,35,0,0,10,18,0,0,236,25,0,0,32,44,0,0,204,31,0,0,54,50,0,0,226,18,0,0,78,37,0,0,208,5,0,0,132,24,0,0,156,39,0,0,2,21,0,0,158,26,0,0,210,7,0,0,104,15,0,0,112,46,0,0,180,1,0,0,162,33,0,0,120,37,0,0,246,18,0,0,100,38,0,0,2,44,0,0,194,25,0,0,200,32,0,0,126,14,0,0,26,20,0,0,190,21,0,0,244,5,0,0,100,50,0,0,4,19,0,0,210,11,0,0,36,30,0,0,216,24,0,0,46,43,0,0,42,11,0,0,10,4,0,0,94,45,0,0,54,40,0,0,124,8,0,0,120,0,0,0,232,13,0,0,72,14,0,0,76,22,0,0,80,3,0,0,74,9,0,0,212,40,0,0,132,34,0,0,146,29,0,0,16,35,0,0,192,16,0,0,158,20,0,0,66,1,0,0,136,21,0,0,34,27,0,0,110,8,0,0,18,16,0,0,26,47,0,0,104,2,0,0,198,6,0,0,148,25,0,0,230,43,0,0,132,12,0,0,210,30,0,0,94,49,0,0,44,18,0,0,126,36,0,0,160,8,0,0,58,27,0,0,238,14,0,0,26,33,0,0,52,1,0,0,100,20,0,0,70,29,0,0,84,7,0,0,156,41,0,0,54,33,0,0,28,4,0,0,198,35,0,0,212,15,0,0,234,46,0,0,148,28,0,0,2,10,0,0,254,4,0,0,210,24,0,0,178,40,0,0,36,22,0,0,36,3,0,0,18,33,0,0,46,34,0,0,0,46,0,0,70,26,0,0,136,44,0,0,28,30,0,0,122,7,0,0,92,1,0,0,148,20,0,0,20,15,0,0,70,33,0,0,228,27,0,0,52,46,0,0,250,33,0,0,94,28,0,0,220,46,0,0,114,41,0,0,234,9,0,0,0,4,0,0,206,17,0,0,32,49,0,0,120,4,0,0,84,36,0,0,0,42,0,0,134,23,0,0,240,28,0,0,134,10,0,0,58,16,0,0,106,47,0,0,226,9,0,0,152,15,0,0,212,46,0,0,238,1,0,0,234,33,0,0,206,39,0,0,202,1,0,0,162,21,0,0,174,39,0,0,8,8,0,0,60,28,0,0,172,46,0,0,118,15,0,0,246,48,0,0,114,50,0,0,22,19,0,0,232,2,0,0,206,21,0,0,114,40,0,0,164,10,0,0,42,29,0,0,136,47,0,0,254,36,0,0,130,18,0,0,198,49,0,0,102,34,0,0,240,12,0,0,80,44,0,0,248,25,0,0,70,7,0,0,30,35,0,0,160,45,0,0,32,29,0,0,236,8,0,0,42,42,0,0,158,23,0,0,164,4,0,0,98,36,0,0,182,21,0,0,68,40,0,0,180,2,0,0,186,2,0,0,144,45,0,0,96,14,0,0,174,8,0,0,72,27,0,0,120,23,0,0,14,42,0,0,140,22,0,0,244,16,0,0,88,35,0,0,18,28,0,0,108,46,0,0,12,41,0,0,24,6,0,0,130,37,0,0,82,43,0,0,224,24,0,0,0,32,0,0,198,13,0,0,34,19,0,0,110,50,0,0,2,8,0,0,192,39,0,0,68,48,0,0,136,3,0,0,74,35,0,0,116,25,0,0,78,24,0,0,180,29,0,0,206,19,0,0,126,13,0,0,224,18,0,0,72,50,0,0,180,7,0,0,116,39,0,0,172,44,0,0,72,3,0,0,254,29,0,0,160,11,0,0,136,45,0,0,136,0,0,0,156,32,0,0,76,40,0,0,174,21,0,0,86,27,0,0,160,16,0,0,232,34,0,0,34,3,0,0,34,22,0,0,172,40,0,0,38,9,0,0,218,11,0,0,18,46,0,0,76,18,0,0,200,36,0,0,122,45,0,0,76,14,0,0,148,32,0,0,128,0,0,0,224,19,0,0,42,38,0,0,86,0,0,0,116,32,0,0,234,29,0,0,102,45,0,0,106,25,0,0,152,6,0,0,20,38,0,0,198,19,0,0,88,2,0,0,78,34,0,0,16,15,0,0,48,46,0,0,226,27,0,0,32,41,0,0,46,39,0,0,142,20,0,0,156,35,0,0,232,3,0,0,150,48,0,0,68,17,0,0,152,11,0,0,20,30,0,0,152,24,0,0,38,4,0,0,94,37,0,0,222,5,0,0,4,15,0,0,52,9,0,0,216,27,0,0,48,22,0,0,216,40,0,0,86,6,0,0,12,49,0,0,116,30,0,0,56,36,0,0,180,17,0,0,108,23,0,0,96,4,0,0,100,10,0,0,232,41,0,0,76,47,0,0,210,18,0,0,56,48,0,0,148,3,0,0,56,35,0,0,2,41,0,0,112,22,0,0,12,28,0,0,176,33,0,0,174,1,0,0,20,21,0,0,142,39,0,0,174,9,0,0,212,14,0,0,136,46,0,0,94,15,0,0,244,31,0,0,88,50,0,0,200,41,0,0,84,10,0,0,202,28,0,0,228,48,0,0,154,17,0,0,34,36,0,0,26,5,0,0,236,11,0,0,168,3,0,0,124,12,0,0,28,8,0,0,174,11,0,0,238,12,0,0,90,0,0,0,26,5,0,0,236,11,0,0,168,3,0,0,124,12,0,0,28,8,0,0,174,11,0,0,238,12,0,0,90,0,0,0,26,5,0,0,236,11,0,0,168,3,0,0,124,12,0,0,28,8,0,0,174,11,0,0,238,12,0,0,90,0,0,0,26,5,0,0,236,11,0,0,168,3,0,0,124,12,0,0,28,8,0,0,174,11,0,0,238,12,0,0,90,0,0,0,26,5,0,0,236,11,0,0,168,3,0,0,124,12,0,0,28,8,0,0,174,11,0,0,238,12,0,0,90,0,0,0,26,5,0,0,236,11,0,0,168,3,0,0,124,12,0,0,28,8,0,0,174,11,0,0,238,12,0,0,90,0,0,0,26,5,0,0,236,11,0,0,168,3,0,0,124,12,0,0,28,8,0,0,174,11,0,0,238,12,0,0,90,0,0,0,26,5,0,0,236,11,0,0,168,3,0,0,124,12,0,0,28,8,0,0,174,11,0,0,238,12,0,0,90,0,0,0,48,4,0,0,72,6,0,0,20,13,0,0,52,6,0,0,48,13,0,0,122,10,0,0,206,2,0,0,144,0,0,0,48,4,0,0,72,6,0,0,20,13,0,0,52,6,0,0,48,13,0,0,122,10,0,0,206,2,0,0,144,0,0,0,48,4,0,0,72,6,0,0,20,13,0,0,52,6,0,0,48,13,0,0,122,10,0,0,206,2,0,0,144,0,0,0,48,4,0,0,72,6,0,0,20,13,0,0,52,6,0,0,48,13,0,0,122,10,0,0,206,2,0,0,144,0,0,0,48,4,0,0,72,6,0,0,20,13,0,0,52,6,0,0,48,13,0,0,122,10,0,0,206,2,0,0,144,0,0,0,48,4,0,0,72,6,0,0,20,13,0,0,52,6,0,0,48,13,0,0,122,10,0,0,206,2,0,0,144,0,0,0,48,4,0,0,72,6,0,0,20,13,0,0,52,6,0,0,48,13,0,0,122,10,0,0,206,2,0,0,144,0,0,0,48,4,0,0,72,6,0,0,20,13,0,0,52,6,0,0,48,13,0,0,122,10,0,0,206,2,0,0,144,0,0,0,156,10,0,0,250,12,0,0,228,11,0,0,154,13,0,0,108,13,0,0,232,9,0,0,14,9,0,0,64,2,0,0,156,10,0,0,250,12,0,0,228,11,0,0,154,13,0,0,108,13,0,0,232,9,0,0,14,9,0,0,64,2,0,0,156,10,0,0,250,12,0,0,228,11,0,0,154,13,0,0,108,13,0,0,232,9,0,0,14,9,0,0,64,2,0,0,156,10,0,0,250,12,0,0,228,11,0,0,154,13,0,0,108,13,0,0,232,9,0,0,14,9,0,0,64,2,0,0,156,10,0,0,250,12,0,0,228,11,0,0,154,13,0,0,108,13,0,0,232,9,0,0,14,9,0,0,64,2,0,0,156,10,0,0,250,12,0,0,228,11,0,0,154,13,0,0,108,13,0,0,232,9,0,0,14,9,0,0,64,2,0,0,156,10,0,0,250,12,0,0,228,11,0,0,154,13,0,0,108,13,0,0,232,9,0,0,14,9,0,0,64,2,0,0,156,10,0,0,250,12,0,0,228,11,0,0,154,13,0,0,108,13,0,0,232,9,0,0,14,9,0,0,64,2,0,0,20,5,0,0,78,12,0,0,154,8,0,0,34,13,0,0,66,8,0,0,130,3,0,0,8,6,0,0,114,5,0,0,20,5,0,0,78,12,0,0,154,8,0,0,34,13,0,0,66,8,0,0,130,3,0,0,8,6,0,0,114,5,0,0,20,5,0,0,78,12,0,0,154,8,0,0,34,13,0,0,66,8,0,0,130,3,0,0,8,6,0,0,114,5,0,0,20,5,0,0,78,12,0,0,154,8,0,0,34,13,0,0,66,8,0,0,130,3,0,0,8,6,0,0,114,5,0,0,20,5,0,0,78,12,0,0,154,8,0,0,34,13,0,0,66,8,0,0,130,3,0,0,8,6,0,0,114,5,0,0,20,5,0,0,78,12,0,0,154,8,0,0,34,13,0,0,66,8,0,0,130,3,0,0,8,6,0,0,114,5,0,0,20,5,0,0,78,12,0,0,154,8,0,0,34,13,0,0,66,8,0,0,130,3,0,0,8,6,0,0,114,5,0,0,20,5,0,0,78,12,0,0,154,8,0,0,34,13,0,0,66,8,0,0,130,3,0,0,8,6,0,0,114,5,0,0,116,12,0,0,32,8,0,0,230,7,0,0,250,7,0,0,84,6,0,0,122,1,0,0,132,13,0,0,94,2,0,0,116,12,0,0,32,8,0,0,230,7,0,0,250,7,0,0,84,6,0,0,122,1,0,0,132,13,0,0,94,2,0,0,116,12,0,0,32,8,0,0,230,7,0,0,250,7,0,0,84,6,0,0,122,1,0,0,132,13,0,0,94,2,0,0,116,12,0,0,32,8,0,0,230,7,0,0,250,7,0,0,84,6,0,0,122,1,0,0,132,13,0,0,94,2,0,0,116,12,0,0,32,8,0,0,230,7,0,0,250,7,0,0,84,6,0,0,122,1,0,0,132,13,0,0,94,2,0,0,116,12,0,0,32,8,0,0,230,7,0,0,250,7,0,0,84,6,0,0,122,1,0,0,132,13,0,0,94,2,0,0,116,12,0,0,32,8,0,0,230,7,0,0,250,7,0,0,84,6,0,0,122,1,0,0,132,13,0,0,94,2,0,0,116,12,0,0,32,8,0,0,230,7,0,0,250,7,0,0,84,6,0,0,122,1,0,0,132,13,0,0,94,2,0,0,14,3,0,0,190,8,0,0,86,9,0,0,138,13,0,0,38,8,0,0,130,10,0,0,216,10,0,0,146,12,0,0,14,3,0,0,190,8,0,0,86,9,0,0,138,13,0,0,38,8,0,0,130,10,0,0,216,10,0,0,146,12,0,0,14,3,0,0,190,8,0,0,86,9,0,0,138,13,0,0,38,8,0,0,130,10,0,0,216,10,0,0,146,12,0,0,14,3,0,0,190,8,0,0,86,9,0,0,138,13,0,0,38,8,0,0,130,10,0,0,216,10,0,0,146,12,0,0,14,3,0,0,190,8,0,0,86,9,0,0,138,13,0,0,38,8,0,0,130,10,0,0,216,10,0,0,146,12,0,0,14,3,0,0,190,8,0,0,86,9,0,0,138,13,0,0,38,8,0,0,130,10,0,0,216,10,0,0,146,12,0,0,14,3,0,0,190,8,0,0,86,9,0,0,138,13,0,0,38,8,0,0,130,10,0,0,216,10,0,0,146,12,0,0,14,3,0,0,190,8,0,0,86,9,0,0,138,13,0,0,38,8,0,0,130,10,0,0,216,10,0,0,146,12,0,0,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,32,0,48,0,40,0,208,0,80,0,144,0,0,0,24,1,0,0,144,12,0,56,0,0,0,1,72,0,40,0,40,0,144,0,112,0,176,0,0,0,192,2,0,0,160,12,0,48,0,0,24,5,104,0,184,0,40,0,208,0,104,0,176,0,248,2,24,5,0,0,248,14,0,48,120,9,8,6,200,0,176,0,40,0,208,0,152,0,200,0,8,6,232,6,0,0,72,10,0,32,16,4,8,7,112,0,48,0,40,0,208,0,96,0,144,0,8,7,8,7,16,4,112,16,0,56,136,18,8,8,153,0,206,0,40,0,208,0,96,0,192,0,0,0,8,8,136,18,112,23,0,48,176,17,8,9,24,1,64,0,40,0,208,0,176,0,192,0,0,9,16,9,80,0,176,17,0,56,0,0,8,8,40,0,184,0,40,0,208,0,112,0,176,0,8,8,8,8,0,0,152,3,0,16,248,6,8,8,40,0,184,0,40,0,208,0,112,0,176,0,8,8,8,8,248,6,248,6,0,136,248,6,8,8,40,0,184,0,40,0,208,0,112,0,176,0,8,8,8,8,248,6,248,6,255,255,248,6,8,8,40,0,184,0,40,0,208,0,112,0,176,0,8,8,8,8,248,6,248,6,255,255,0,0,0,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,64,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,4,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,68,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,132,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,5,87,95,254,79,189,54,128,139,138,10,137,144,71,128,34,144,144,93,129,60,181,131,104,255,117,117,141,91,138,56,139,235,210,10,180,199,70,209,10,83,189,144,34,255,31,3,251,69,195,2,144,15,144,2,15,183,144,36,198,235,27,50,141,185,254,8,136,144,138,138,117,138,189,88,254,81,30,139,15,34,246,144,195,54,3,141,187,22,188,144,15,94,249,46,144,144,89,144,187,26,12,141,137,114,131,164,195,179,139,233,129,67,160,44,15,85,243,54,176,89,232,3,38,233,34,176,144,142,36,138,208,62,195,58,144,121,87,22,136,134,36,116,51,195,83,184,171,117,144,144,142,177,233,93,249,2,60,144,128,211,137,232,144,144,42,116,144,95,246,136,79,86,140,3,71,144,136,144,3,254,144,252,42,144,51,7,177,80,15,62,189,77,243,191,89,210,234,198,42,116,114,226,62,46,144,46,46,115,136,114,69,93,193,185,50,56,136,193,160,6,69,144,144,134,75,135,144,138,59,171,51,190,144,50,189,199,178,128,15,117,192,185,7,116,62,162,138,72,62,141,235,144,254,144,7,0,0,0,8,0,0,0,240,36,5,0,32,7,5,0,48,227,4,0,40,191,4,0,136,159,4,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,32,0,0,0,64,26,0,0,0,184,240,52,202,33,60,249,1,142,117,112,236,19,39,150,244,91,136,31,235,74,125,157,190,2,20,175,162,6,198,219,53,107,116,69,123,41,210,254,182,21,208,138,169,45,25,246,94,90,144,233,17,51,194,71,55,76,79,89,195,4,87,29,242,99,109,110,49,149,203,62,103,178,227,152,237,141,230,251,248,186,93,212,42,245,59,130,5,22,68,239,77,231,147,218,159,187,97,201,83,189,118,120,82,54,12,102,193,16,221,122,132,105,205,253,88,13,108,137,104,173,58,176,75,70,197,3,180,247,48,140,78,96,115,161,139,177,98,204,209,8,252,119,126,207,86,81,7,166,128,146,220,11,164,199,232,225,181,113,234,179,47,148,24,226,61,73,101,170,241,145,200,153,85,121,134,167,38,160,172,95,206,106,92,243,135,143,18,28,216,228,155,100,46,30,215,192,23,188,163,168,154,14,37,64,65,80,185,191,40,223,50,84,158,72,213,43,66,250,156,127,211,133,67,222,129,15,36,196,56,174,131,27,111,124,229,255,26,217,63,183,34,151,9,224,165,32,35,44,114,214,57,171,10,238,69,159,110,47,40,188,94,109,218,181,13,184,192,142,162,50,238,205,141,72,140,39,20,235,101,215,242,147,153,144,145,252,95,203,250,117,63,38,222,114,51,57,199,31,136,121,115,171,78,54,93,68,210,65,160,126,167,139,166,191,3,216,134,220,44,170,112,61,70,7,128,88,11,43,226,240,177,254,66,243,233,163,133,120,195,208,90,219,26,251,157,138,165,18,14,84,143,197,108,174,37,91,75,23,2,156,74,36,64,229,158,34,198,73,98,182,107,187,168,204,232,129,80,71,200,190,92,164,214,148,79,123,154,207,228,89,122,161,234,49,55,19,45,175,33,105,25,29,111,22,152,30,8,227,178,77,155,127,169,119,237,189,212,217,52,211,202,9,24,96,201,106,1,244,246,100,180,58,21,172,137,82,104,113,231,130,193,12,146,247,48,230,28,62,15,10,103,53,186,97,221,41,194,248,151,149,183,59,224,206,249,213,6,118,179,5,76,4,132,60,135,35,99,124,83,86,225,125,150,27,209,236,42,102,241,17,16,255,67,46,223,131,116,245,56,32,253,173,196,185,85,81,176,239,0,87,0,0,0,0,8,0,0,0,16,0,0,0,24,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,7,0,0,0,8,0,0,0,240,36,5,0,32,7,5,0,48,227,4,0,40,191,4,0,136,159,4,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,16,0,0,0,152,33,8,0,240,236,7,0,32,184,7,0,184,137,7,0,16,90,7,0,0,0,0,0,0,0,0,0,0,0,0,0,98,3,0,0,82,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,186,5,0,0,0,0,0,0,6,0,0,0,16,0,0,0,152,33,8,0,240,236,7,0,32,184,7,0,184,137,7,0,88,148,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,190,6,90,250,66,21,242,63,10,132,147,78,120,59,137,50,152,162,135,115,221,38,229,5,113,8,110,155,224,223,158,252,131,129,239,178,192,195,191,167,109,27,149,237,185,62,19,176,71,156,122,36,65,104,208,54,11,181,194,103,247,84,146,30,68,134,43,148,204,186,35,13,202,107,76,42,154,45,139,227,82,41,240,33,189,187,31,163,171,248,70,183,69,130,94,219,7,93,233,157,26,72,206,145,18,212,238,169,57,241,24,44,34,138,126,52,74,140,193,20,243,32,53,217,150,51,119,159,118,124,144,198,213,161,91,172,117,199,12,179,23,214,153,86,166,61,29,177,46,216,188,47,222,96,85,108,64,205,67,255,173,56,121,81,200,14,95,196,102,203,168,125,164,58,234,39,123,112,142,92,25,15,128,111,143,16,249,73,133,105,127,235,28,1,101,55,165,40,228,106,3,4,209,49,17,48,251,136,151,211,246,197,77,245,60,232,97,220,210,180,184,160,174,22,37,2,9,254,207,83,99,175,89,244,225,236,215,231,80,226,201,170,75,141,79,230,100,218,116,182,114,87,98,253,88,252,155,28,53,114,83,214,125,132,164,197,147,123,231,71,213,36,162,250,25,12,177,140,185,157,216,89,79,60,178,120,74,42,150,154,241,31,34,168,91,103,163,15,0,251,223,235,10,87,184,37,215,240,107,11,49,149,35,45,92,39,199,244,85,26,247,116,190,211,172,61,193,127,189,40,1,16,229,9,55,30,88,175,23,242,22,48,146,54,104,230,212,234,183,117,84,119,65,180,141,224,243,81,3,169,232,102,171,41,165,237,203,209,170,245,219,76,66,151,138,174,201,110,4,51,133,221,43,111,239,18,33,122,161,90,145,200,204,192,167,96,62,86,47,228,113,153,194,160,69,128,101,187,135,105,129,115,202,246,70,67,218,38,126,143,225,139,253,80,121,186,198,99,75,179,142,52,226,72,20,205,227,196,5,19,64,6,108,136,176,233,27,77,248,118,2,68,148,207,50,254,206,59,93,44,137,95,220,210,156,106,236,24,109,14,134,255,94,158,238,17,208,73,82,78,97,144,13,195,57,21,131,181,98,63,112,124,173,32,191,46,8,29,249,182,166,100,7,130,56,152,58,159,222,188,217,0,0,0,0,182,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,26,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,98,44,0,0,98,47,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,246,42,0,0,202,12,0,0,42,10,0,0,184,29,0,0,144,44,0,0,214,17,0,0,128,33,0,0,168,20,0,0,116,38,0,0,56,15,0,0,34,40,0,0,236,36,0,0,244,37,0,0,116,19,0,0,246,28,0,0,182,19,0,0,172,16,0,0,28,44,0,0,40,18,0,0,224,34,0,0,24,39,0,0,218,43,0,0,38,1,0,0,212,16,0,0,72,29,0,0,142,6,0,0,116,31,0,0,78,43,0,0,218,40,0,0,106,14,0,0,32,48,0,0,232,40,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,0,0,0,2,1,0,0,2,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,60,0,0,0,40,0,0,0,20,0,0,0,0,0,8,0,32,0,0,0,32,0,8,0,0,0,0,0,0,0,49,0,0,0,255,255,33,0,0,0,0,0,0,0,0,0,7,0,0,0,8,0,0,0,224,7,2,0,112,36,6,0,0,0,0,0,176,242,1,0,0,232,1,0,0,0,0,0,0,0,0,0,0,0,0,0,41,151,26,44,11,148,62,117,1,13,27,225,77,56,57,143,231,208,96,144,178,15,187,112,31,230,91,135,180,67,253,245,246,249,173,192,152,23,159,145,21,81,85,100,108,24,97,14,217,147,171,214,36,47,106,58,34,177,79,170,35,72,237,185,136,139,163,107,38,76,232,45,28,153,189,92,88,8,80,242,42,98,193,114,102,4,16,55,110,252,68,169,223,212,32,221,238,65,219,115,222,84,236,201,243,75,46,174,90,74,94,71,7,43,118,164,227,40,254,176,240,2,6,209,175,66,194,165,224,103,191,22,142,53,206,138,229,61,123,150,215,121,82,30,161,251,155,190,33,156,233,86,20,127,160,228,195,196,70,234,247,210,29,49,10,95,235,162,104,141,181,197,116,12,220,130,128,9,25,149,113,154,17,87,119,78,198,255,18,3,167,199,244,200,182,122,89,54,60,83,226,105,140,37,5,69,99,248,52,137,51,63,133,39,188,101,250,168,109,132,93,186,64,50,48,239,131,19,166,120,204,129,158,218,202,211,126,157,111,205,183,179,216,207,59,0,146,184,134,172,73,124,241,213,203,125,0,95,3,82,206,227,125,143,107,248,32,222,123,126,57,190,245,148,24,120,128,201,127,122,62,99,242,224,78,247,135,39,105,108,164,29,133,91,230,68,37,12,152,199,1,2,163,38,9,56,219,195,30,207,35,69,104,118,214,34,93,90,174,22,159,162,181,205,129,234,94,184,185,157,156,26,15,255,225,231,116,170,212,175,252,198,51,41,92,171,149,240,25,71,89,103,243,150,96,31,98,146,189,137,238,40,19,6,254,250,50,109,87,60,84,80,44,88,73,251,23,204,239,178,180,249,7,112,197,169,223,213,59,134,43,13,110,77,10,144,67,49,193,246,136,11,218,83,20,220,117,142,176,235,153,70,161,21,113,200,233,63,74,217,115,229,124,48,119,211,179,75,55,114,194,4,151,8,54,177,58,97,236,226,28,154,139,209,27,46,158,138,216,65,228,196,64,47,173,192,182,132,81,102,187,18,232,221,203,188,111,208,17,131,86,76,202,191,5,16,215,186,253,237,140,14,79,61,53,145,183,172,52,100,42,241,121,106,155,45,101,244,66,160,141,167,72,85,33,147,36,210,166,165,168,130,0,0,0,0,0,0,0,0,9,0,0,0,0,0,0,0,32,0,0,0,64,44,0,0,96,129,0,0,192,200,0,0,224,255,0,0,0,48,1,0,32,88,1,0,64,95,1,0,8,0,0,6,0,0,0,6,8,0,0,4,0,0,0,4,8,0,0,2,0,0,0,2,8,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,8,0,0,0,9,0,0,0,10,0,0,0,11,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,0,0,128,0,1,0,128,0,2,0,128,0,3,0,128,0,0,0,128,0,1,0,128,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,24,0,0,0,8,0,0,0,16,0,0,0,0,0,0,0,8,0,128,1,0,0,128,1,8,0,0,1,0,0,0,1,8,0,128,0,0,0,128,0,8,0,0,0,0,0,0,0,206,1,0,0,210,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,40,0,0,0,0,0,0,0,0,0,255,0,1,65,65,0,0,0,255,0,0,240,240,0,0,0,255,0,1,65,65,0,0,0,255,0,0,240,240,0,128,0,128,0,128,0,128,0,1,64,0,0,0,240,0,0,1,66,133,0,0,241,227,0,1,64,0,0,0,240,0,0,1,66,133,0,0,241,227,204,203,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,7,0,0,0,8,0,0,0,152,33,8,0,240,236,7,0,32,184,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,155,157,193,61,169,184,244,111,246,37,199,71,213,151,223,107,235,144,164,178,93,245,102,176,185,139,147,100,236,123,101,140,241,67,66,110,69,159,179,53,6,113,150,219,160,251,11,58,31,248,142,105,205,38,171,134,162,12,189,99,165,122,231,106,95,24,158,191,173,85,177,28,92,3,48,198,55,32,227,201,82,232,238,79,1,112,196,119,41,42,186,83,18,4,125,175,51,143,168,77,170,91,180,15,146,187,237,225,47,80,108,210,44,149,217,249,152,195,118,76,242,228,229,43,239,156,73,182,49,59,188,161,202,222,98,116,234,129,0,221,166,70,136,63,57,214,35,84,36,74,216,220,215,209,204,190,87,124,218,68,97,206,211,212,233,40,128,224,86,138,9,5,154,137,27,247,243,153,109,94,72,145,192,208,197,121,120,65,89,33,46,255,194,75,56,131,50,230,226,127,30,23,88,29,26,250,133,130,148,200,114,126,183,172,14,252,253,22,39,117,141,203,8,254,10,2,13,54,17,34,132,64,52,62,45,104,90,167,103,174,135,7,16,96,20,115,60,81,25,163,181,207,19,240,21,78,0,177,30,197,61,64,69,94,242,248,4,99,54,135,136,191,171,204,120,8,221,32,212,53,9,142,68,174,51,169,158,205,179,229,173,65,218,190,244,22,87,46,83,103,175,219,138,216,52,23,60,1,85,115,207,227,232,199,13,233,163,19,12,246,144,78,251,151,109,95,168,113,17,252,209,149,129,186,140,27,57,254,162,21,166,82,77,91,89,165,224,150,217,143,123,237,41,211,31,14,236,35,15,184,108,111,125,24,70,214,228,181,154,121,2,245,3,192,96,102,92,47,118,133,157,84,26,106,40,206,127,124,145,153,76,131,62,180,29,5,193,195,215,71,222,188,98,110,134,20,128,119,235,243,7,49,86,210,194,198,107,220,253,34,146,240,6,81,45,56,230,160,37,223,213,44,28,148,18,156,176,155,196,11,200,208,247,48,203,39,250,122,16,97,170,164,112,183,42,90,201,241,10,73,101,238,105,75,58,141,50,93,104,185,159,117,25,63,172,55,79,231,147,137,126,74,59,234,116,114,67,189,36,239,182,255,100,88,132,139,167,187,178,225,38,43,80,202,33,249,152,161,226,66,130,72,38,72,6,155,33,169,27,118,201,248,180,103,228,255,153,247,21,158,98,0,114,77,160,79,2,241,234,239,11,243,235,166,147,120,111,124,218,212,123,5,233,198,214,219,80,206,210,1,181,232,224,42,8,26,184,227,249,177,244,139,57,45,133,156,85,115,99,64,56,150,220,163,162,161,37,102,109,86,142,16,15,49,28,245,40,119,10,209,117,52,164,254,125,7,81,121,65,144,34,53,18,187,196,202,178,31,203,200,172,221,208,13,252,197,157,20,188,131,217,88,194,48,154,106,192,12,173,246,93,116,127,47,189,29,71,213,230,137,207,183,211,89,54,152,240,251,60,242,63,167,24,130,66,92,171,186,222,82,9,145,170,97,236,215,149,35,205,128,165,104,96,39,113,225,44,46,141,43,87,101,191,193,25,199,73,100,136,74,204,32,78,216,59,76,19,95,159,190,94,110,253,226,250,84,55,14,22,122,108,51,179,112,132,126,195,4,176,174,185,129,3,41,223,70,229,105,231,36,146,90,75,91,148,17,58,61,135,237,151,182,50,62,69,175,30,67,68,140,83,134,107,238,168,138,143,23,0,0,0,0,0,0,0,0,0,32,0,32,0,32,0,32,0,32,0,32,0,4,0,4,0,4,0,0,0,0,0,0,7,0,0,0,0,0,0,0,32,0,0,0,224,68,0,0,160,152,0,0,32,200,0,0,160,247,0,0,192,8,1,0,28,0,0,0,0,0,0,0,32,0,0,0,0,24,0,0,160,45,0,0,224,59,0,0,224,90,0,0,0,97,0,0,224,109,0,0,96,114,0,0,96,122,0,0,32,135,0,0,192,165,0,0,192,195,0,0,160,199,0,0,64,225,0,0,0,251,0,0,160,15,1,0,192,15,1,0,224,15,1,0,64,31,1,0,32,43,1,0,160,48,1,0,96,60,1,0,64,71,1,0,192,83,1,0,224,151,1,0,64,175,1,0,128,192,1,0,0,0,0,0,6,0,0,0,0,0,0,0,16,0,0,0,16,37,0,0,16,101,0,0,16,133,0,0,16,147,0,0,0,0,0,0,8,0,0,3,0,0,0,3,8,0,0,2,0,0,0,2,8,0,0,1,0,0,0,1,8,0,0,0,0,0,0,0,184,40,2,0,1,0,0,0,208,155,215,0,248,191,2,0,56,250,6,0,1,0,0,0,212,155,215,0,184,160,2,0,184,164,8,0,1,0,0,0,209,155,215,0,64,246,1,0,88,149,7,0,1,0,0,0,213,155,215,0,136,224,1,0,56,210,6,0,1,0,0,0,205,155,215,0,192,135,2,0,24,163,6,0,1,0,0,0,204,155,215,0,240,108,2,0,152,122,6,0,1,0,0,0,207,155,215,0,96,82,2,0,192,72,6,0,1,0,0,0,206,155,215,0,32,56,2,0,48,123,2,0,1,0,0,0,200,155,215,0,152,30,2,0,96,69,2,0,1,0,0,0,201,155,215,0,232,10,2,0,144,55,2,0,1,0,0,0,202,155,215,0,152,138,8,0,80,123,7,0,1,0,0,0,203,155,215,0,48,119,7,0,176,223,1,0,1,0,0,0,197,155,215,0,72,198,1,0,192,209,1,0,1,0,0,0,196,155,215,0,24,182,1,0,24,198,1,0,1,0,0,0,199,155,215,0,40,167,1,0,120,189,1,0,1,0,0,0,198,155,215,0,200,149,1,0,248,187,8,0,1,0,0,0,192,155,215,0,56,126,1,0,184,179,8,0,1,0,0,0,193,155,215,0,32,101,1,0,240,173,8,0,1,0,0,0,194,155,215,0,96,32,8,0,208,72,7,0,1,0,0,0,195,155,215,0,16,68,7,0,16,17,8,0,1,0,0,0,211,155,215,0,224,12,8,0,32,77,1,0,1,0,0,0,210,155,215,0,216,70,1,0,88,212,3,0,1,0,0,0,200,154,215,0,40,185,3,0,248,5,8,0,9,0,0,0,0,156,215,0,32,58,1,0,144,250,7,0,9,0,0,0,1,156,215,0,32,58,1,0,184,40,2,0,1,0,0,0,208,155,215,0,248,191,2,0,56,250,6,0,1,0,0,0,212,155,215,0,184,160,2,0,184,164,8,0,1,0,0,0,209,155,215,0,64,246,1,0,88,149,7,0,1,0,0,0,213,155,215,0,136,224,1,0,56,210,6,0,1,0,0,0,205,155,215,0,192,135,2,0,24,163,6,0,1,0,0,0,204,155,215,0,240,108,2,0,152,122,6,0,1,0,0,0,207,155,215,0,96,82,2,0,192,72,6,0,1,0,0,0,206,155,215,0,32,56,2,0,48,123,2,0,1,0,0,0,200,155,215,0,152,30,2,0,96,69,2,0,1,0,0,0,201,155,215,0,232,10,2,0,144,55,2,0,1,0,0,0,202,155,215,0,152,138,8,0,176,223,1,0,1,0,0,0,197,155,215,0,72,198,1,0,192,209,1,0,1,0,0,0,196,155,215,0,24,182,1,0,24,198,1,0,1,0,0,0,199,155,215,0,40,167,1,0,120,189,1,0,1,0,0,0,198,155,215,0,200,149,1,0,248,187,8,0,1,0,0,0,192,155,215,0,56,126,1,0,184,179,8,0,1,0,0,0,193,155,215,0,32,101,1,0,240,173,8,0,1,0,0,0,194,155,215,0,96,32,8,0,16,17,8,0,1,0,0,0,211,155,215,0,224,12,8,0,32,77,1,0,1,0,0,0,210,155,215,0,216,70,1,0,88,212,3,0,1,0,0,0,200,154,215,0,40,185,3,0,248,5,8,0,9,0,0,0,0,156,215,0,32,58,1,0])
.concat([144,250,7,0,9,0,0,0,1,156,215,0,32,58,1,0,184,40,2,0,1,0,0,0,208,155,215,0,248,191,2,0,56,250,6,0,1,0,0,0,212,155,215,0,184,160,2,0,184,164,8,0,1,0,0,0,209,155,215,0,64,246,1,0,88,149,7,0,1,0,0,0,213,155,215,0,136,224,1,0,56,210,6,0,1,0,0,0,205,155,215,0,192,135,2,0,24,163,6,0,1,0,0,0,204,155,215,0,240,108,2,0,152,122,6,0,1,0,0,0,207,155,215,0,96,82,2,0,192,72,6,0,1,0,0,0,206,155,215,0,32,56,2,0,48,123,2,0,1,0,0,0,201,155,215,0,152,30,2,0,176,223,1,0,1,0,0,0,197,155,215,0,72,198,1,0,192,209,1,0,1,0,0,0,196,155,215,0,24,182,1,0,24,198,1,0,1,0,0,0,199,155,215,0,40,167,1,0,120,189,1,0,1,0,0,0,198,155,215,0,200,149,1,0,248,187,8,0,1,0,0,0,193,155,215,0,56,126,1,0,16,17,8,0,1,0,0,0,211,155,215,0,224,12,8,0,32,77,1,0,1,0,0,0,210,155,215,0,216,70,1,0,88,212,3,0,1,0,0,0,200,154,215,0,40,185,3,0,248,5,8,0,9,0,0,0,0,156,215,0,32,58,1,0,144,250,7,0,9,0,0,0,1,156,215,0,32,58,1,0,0,0,0,0,0,0,8,0,0,0,4,0,0,0,12,0,116,34,0,0,122,21,0,0,32,11,0,0,248,44,0,0,10,32,0,0,226,22,0,0,58,35,0,0,82,42,0,0,36,16,0,0,52,33,0,0,96,7,0,0,218,25,0,0,238,25,0,0,108,17,0,0,54,39,0,0,182,12,0,0,170,32,0,0,220,41,0,0,154,33,0,0,44,27,0,0,98,43,0,0,28,40,0,0,120,34,0,0,100,34,0,0,32,12,0,0,170,10,0,0,140,8,0,0,30,6,0,0,240,20,0,0,110,46,0,0,120,45,0,0,220,39,0,0,214,44,0,0,124,45,0,0,78,19,0,0,12,37,0,0,50,42,0,0,132,48,0,0,216,0,0,0,152,10,0,0,244,45,0,0,8,4,0,0,104,44,0,0,202,43,0,0,50,21,0,0,220,43,0,0,54,28,0,0,22,39,0,0,228,36,0,0,238,19,0,0,226,16,0,0,22,47,0,0,58,45,0,0,30,49,0,0,10,42,0,0,130,48,0,0,46,12,0,0,136,36,0,0,34,8,0,0,200,21,0,0,168,10,0,0,92,23,0,0,168,27,0,0,244,29,0,0,218,30,0,0,214,24,0,0,194,11,0,0,10,3,0,0,222,28,0,0,82,32,0,0,238,2,0,0,254,30,0,0,54,44,0,0,216,32,0,0,246,12,0,0,208,15,0,0,98,42,0,0,218,19,0,0,220,26,0,0,114,19,0,0,140,34,0,0,156,40,0,0,24,22,0,0,188,37,0,0,78,20,0,0,82,8,0,0,130,12,0,0,12,32,0,0,100,25,0,0,214,16,0,0,42,37,0,0,26,34,0,0,208,9,0,0,28,23,0,0,18,40,0,0,246,30,0,0,182,13,0,0,34,2,0,0,80,22,0,0,64,21,0,0,240,47,0,0,202,9,0,0,228,31,0,0,164,8,0,0,218,7,0,0,230,35,0,0,4,6,0,0,144,33,0,0,224,0,0,0,192,26,0,0,38,36,0,0,110,12,0,0,176,1,0,0,198,26,0,0,16,16,0,0,4,27,0,0,60,21,0,0,82,20,0,0,40,21,0,0,200,34,0,0,200,22,0,0,22,32,0,0,142,37,0,0,62,22,0,0,192,2,0,0,130,3,0,0,164,9,0,0,12,47,0,0,82,27,0,0,166,47,0,0,118,29,0,0,98,41,0,0,128,37,0,0,216,23,0,0,64,18,0,0,96,3,0,0,72,26,0,0,170,1,0,0,74,46,0,0,194,49,0,0,206,23,0,0,192,40,0,0,28,11,0,0,146,2,0,0,88,12,0,0,28,26,0,0,22,17,0,0,80,18,0,0,50,44,0,0,62,18,0,0,248,48,0,0,58,50,0,0,68,44,0,0,26,8,0,0,48,43,0,0,252,34,0,0,168,31,0,0,150,25,0,0,204,7,0,0,172,31,0,0,216,21,0,0,130,8,0,0,228,47,0,0,200,2,0,0,136,42,0,0,216,22,0,0,8,13,0,0,74,14,0,0,246,13,0,0,126,8,0,0,80,29,0,0,78,16,0,0,196,4,0,0,254,24,0,0,154,35,0,0,146,21,0,0,16,36,0,0,82,7,0,0,248,15,0,0,82,25,0,0,6,40,0,0,176,36,0,0,4,48,0,0,52,7,0,0,40,2,0,0,78,50,0,0,230,42,0,0,220,16,0,0,250,28,0,0,66,7,0,0,250,7,0,0,108,39,0,0,160,29,0,0,110,44,0,0,156,16,0,0,204,48,0,0,254,40,0,0,180,12,0,0,220,28,0,0,44,9,0,0,224,32,0,0,160,48,0,0,194,35,0,0,234,8,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,12,0,0,0,8,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,32,0,0,0,48,0,8,0,0,0,0,0,0,0,8,0,128,0,0,0,128,0,8,0,0,0,0,0,0,0,116,117,49,46,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,47,212,211,93,1,0,16,1,116,109,50,46,50,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,40,202,231,239,1,0,16,1,116,109,51,46,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,166,129,120,2,1,0,16,1,116,109,52,46,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,220,231,253,160,1,0,16,1,116,117,53,46,50,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,166,168,100,248,1,0,16,1,116,109,56,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,31,97,174,112,4,0,32,0,116,109,57,46,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,158,153,78,142,4,0,32,0,116,52,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,221,182,66,202,7,0,32,0,116,54,46,54,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,204,140,32,173,7,0,32,0,116,53,46,55,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,255,140,216,27,7,0,32,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,0,0,0,0,8,0,0,0,7,0,0,0,8,0,0,0,224,7,2,0,32,0,2,0,0,0,0,0,176,242,1,0,0,232,1,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,0,255,255,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,0,0,0,0,0,0,32,0,0,0,32,32,0,0,0,0,0,0,32,87,0,0,0,0,0,0,96,123,0,0,96,155,0,0,96,195,0,0,27,86,117,136,140,6,88,114,131,134,54,26,95,211,140,233,34,15,3,42,235,42,249,15,164,189,117,243,79,83,142,254,135,232,177,141,54,181,67,115,42,91,249,2,36,138,3,128,134,139,209,62,141,62,88,251,195,121,189,183,138,232,15,129,183,208,139,235,255,184,144,139,94,162,144,144,171,180,128,89,135,114,181,189,176,136,80,15,254,210,195,144,138,144,249,117,26,179,116,10,104,36,187,144,117,71,254,44,190,195,136,210,62,193,140,51,15,144,139,144,185,30,255,162,62,34,190,87,129,58,246,136,235,177,137,138,50,128,15,177,72,195,104,114,83,2,192,2,232,180,116,188,144,88,10,243,117,198,144,232,38,80,252,140,144,177,195,209,235,131,164,191,38,75,70,254,226,137,179,136,3,86,15,56,187,12,144,15,7,138,138,51,254,249,177,160,69,54,34,94,138,190,198,234,60,178,30,232,144,235,85,246,138,176,93,192,187,141,246,208,209,136,77,144,81,81,116,189,50,209,144,210,83,199,171,54,80,233,51,179,46,5,136,89,116,116,34,142,138,138,54,8,15,69,144,46,27,86,117,136,140,6,88,114,131,134,54,26,95,211,140,233,34,15,3,42,235,42,249,15,164,189,117,243,79,83,142,254,135,232,177,141,54,181,67,115,42,91,249,2,36,138,3,128,134,139,209,62,141,62,88,251,195,121,189,183,138,232,15,129,183,208,139,235,255,184,144,139,94,162,144,144,171,180,128,89,135,114,181,189,176,136,80,15,254,210,195,144,138,144,249,117,26,179,116,10,104,36,187,144,117,71,254,44,190,195,136,210,62,193,140,51,15,144,139,144,185,30,255,162,62,34,190,87,129,58,246,136,235,177,137,138,50,128,15,177,72,195,104,114,83,2,192,2,232,180,116,188,144,88,10,243,117,198,144,232,38,80,252,140,144,177,195,209,235,131,164,191,38,75,70,254,226,137,179,136,3,86,15,56,187,12,144,15,7,138,138,51,254,249,177,160,69,54,34,94,138,190,198,234,60,178,30,232,144,235,85,246,138,176,93,192,187,141,246,208,209,136,77,144,81,81,116,189,50,209,144,210,83,199,171,54,80,233,51,179,46,5,136,89,116,116,34,142,138,138,54,8,15,69,144,46,27,86,117,136,140,6,88,114,131,134,54,26,95,211,140,233,34,15,3,42,235,42,249,15,164,189,117,243,79,83,142,254,135,232,177,141,54,181,67,115,42,91,249,2,36,138,3,128,134,139,209,62,141,62,88,251,195,121,189,183,138,232,15,129,183,208,139,235,255,184,144,139,94,162,144,144,171,180,128,89,135,114,181,189,176,136,80,15,254,210,195,144,138,144,249,117,26,179,116,10,104,36,187,144,117,71,254,44,190,195,136,210,62,193,140,51,15,144,139,144,185,30,255,162,62,34,190,87,129,58,246,136,235,177,137,138,50,128,15,177,72,195,104,114,83,2,192,2,232,180,116,188,144,88,10,243,117,198,144,232,38,80,252,140,144,177,195,209,235,131,164,191,38,75,70,254,226,137,179,136,3,86,15,56,187,12,144,15,7,138,138,51,254,249,177,160,69,54,34,94,138,190,198,234,60,178,30,232,144,235,85,246,138,176,93,192,187,141,246,208,209,136,77,144,81,81,116,189,50,209,144,210,83,199,171,54,80,233,51,179,46,5,136,89,116,116,34,142,138,138,54,8,15,69,144,46,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,0,255,255,1,0,0,0,0,0,0,0,0,0,254,0,4,0,224,149,1,0,18,0,0,0,1,3,1,0,8,49,4,0,18,0,0,0,1,3,2,0,152,21,4,0,18,0,0,0,1,3,3,0,72,246,3,0,18,0,0,0,1,3,0,0,80,126,1,0,9,0,0,0,8,0,0,0,240,36,5,0,32,7,5,0,48,227,4,0,72,23,1,0,224,14,1,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,176,168,4,0,224,137,4,0,136,109,4,0,72,23,1,0,224,14,1,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,176,168,4,0,224,137,4,0,136,109,4,0,72,23,1,0,224,14,1,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,16,0,0,0,240,36,5,0,32,7,5,0,48,227,4,0,40,191,4,0,136,159,4,0,1,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,16,0,0,0,240,36,5,0,32,7,5,0,48,227,4,0,40,191,4,0,136,159,4,0,1,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,16,0,0,0,240,36,5,0,32,7,5,0,48,227,4,0,40,191,4,0,136,159,4,0,1,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,16,0,0,0,240,36,5,0,32,7,5,0,48,227,4,0,40,191,4,0,136,159,4,0,1,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,16,0,0,0,240,36,5,0,32,7,5,0,48,227,4,0,40,191,4,0,136,159,4,0,1,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,16,0,0,0,240,36,5,0,32,7,5,0,48,227,4,0,40,191,4,0,136,159,4,0,1,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,16,0,0,0,240,36,5,0,32,7,5,0,48,227,4,0,40,191,4,0,136,159,4,0,1,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,16,0,0,0,240,36,5,0,32,7,5,0,48,227,4,0,40,191,4,0,136,159,4,0,1,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,16,0,0,0,240,36,5,0,32,7,5,0,48,227,4,0,40,191,4,0,136,159,4,0,1,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,16,0,0,0,240,36,5,0,32,7,5,0,48,227,4,0,40,191,4,0,136,159,4,0,1,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,16,0,0,0,240,36,5,0,32,7,5,0,48,227,4,0,40,191,4,0,136,159,4,0,1,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,16,0,0,0,240,36,5,0,32,7,5,0,48,227,4,0,40,191,4,0,136,159,4,0,1,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,16,0,0,0,240,36,5,0,32,7,5,0,48,227,4,0,40,191,4,0,136,159,4,0,1,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,16,0,0,0,240,36,5,0,32,7,5,0,48,227,4,0,40,191,4,0,136,159,4,0,1,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,16,0,0,0,240,36,5,0,32,7,5,0,48,227,4,0,40,191,4,0,136,159,4,0,1,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,16,0,0,0,240,36,5,0,32,7,5,0,48,227,4,0,40,191,4,0,136,159,4,0,1,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,16,0,0,0,240,36,5,0,32,7,5,0,48,227,4,0,40,191,4,0,136,159,4,0,1,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,16,0,0,0,240,36,5,0,32,7,5,0,48,227,4,0,40,191,4,0,136,159,4,0,1,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,16,0,0,0,240,36,5,0,32,7,5,0,48,227,4,0,40,191,4,0,136,159,4,0,1,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,16,0,0,0,240,36,5,0,32,7,5,0,48,227,4,0,40,191,4,0,136,159,4,0,1,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,16,0,0,0,240,36,5,0,32,7,5,0,48,227,4,0,40,191,4,0,136,159,4,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,32,0,0,0,192,62,0,0,64,86,0,0,192,109,0,0,160,131,0,0,0,192,0,0,96,235,0,0,224,18,1,0,192,61,1,0,32,101,1,0,96,109,1,0,224,138,1,0,160,165,1,0,0,191,1,0,64,195,1,0,0,0,0,0,0,0,0,0,64,0,0,0,128,0,0,0,192,0,0,0,0,1,0,0,64,1,0,0,128,1,0,0,192,1,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,184,40,2,0,1,0,0,0,208,155,215,0,248,191,2,0,56,250,6,0,1,0,0,0,212,155,215,0,184,160,2,0,184,164,8,0,1,0,0,0,209,155,215,0,64,246,1,0,88,149,7,0,1,0,0,0,213,155,215,0,136,224,1,0,56,210,6,0,1,0,0,0,205,155,215,0,192,135,2,0,24,163,6,0,1,0,0,0,204,155,215,0,240,108,2,0,152,122,6,0,1,0,0,0,207,155,215,0,96,82,2,0,192,72,6,0,1,0,0,0,206,155,215,0,32,56,2,0,48,123,2,0,1,0,0,0,201,155,215,0,152,30,2,0,96,69,2,0,1,0,0,0,202,155,215,0,232,10,2,0,176,223,1,0,1,0,0,0,197,155,215,0,72,198,1,0,192,209,1,0,1,0,0,0,196,155,215,0,24,182,1,0,24,198,1,0,1,0,0,0,199,155,215,0,40,167,1,0,120,189,1,0,1,0,0,0,198,155,215,0,200,149,1,0,248,187,8,0,1,0,0,0,193,155,215,0,56,126,1,0,184,179,8,0,1,0,0,0,194,155,215,0,32,101,1,0,16,17,8,0,1,0,0,0,211,155,215,0,224,12,8,0,32,77,1,0,1,0,0,0,210,155,215,0,216,70,1,0,88,212,3,0,1,0,0,0,200,154,215,0,40,185,3,0,248,5,8,0,9,0,0,0,0,156,215,0,32,58,1,0,144,250,7,0,9,0,0,0,1,156,215,0,32,58,1,0,248,241,7,0,9,0,0,0,2,156,215,0,32,58,1,0,0,0,0,0,64,0,0,0,128,0,0,0,192,0,0,0,0,1,0,0,64,1,0,0,128,1,0,0,192,1,0,0,0,2,0,0,64,2,0,0,128,2,0,0,192,2,0,0,0,3,0,0,64,3,0,0,128,3,0,0,192,3,0,0,8,0,0,0,12,0,0,0,0,0,0,0,4,0,0,0,24,0,0,0,28,0,0,0,16,0,0,0,20,0,0,0,40,0,0,0,44,0,0,0,32,0,0,0,36,0,0,0,56,0,0,0,60,0,0,0,48,0,0,0,52,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,0,0,0,0,64,0,0,0,32,0,0,0,96,0,0,0,0,2,0,0,64,2,0,0,32,2,0,0,96,2,0,0,128,0,0,0,192,0,0,0,160,0,0,0,224,0,0,0,128,2,0,0,192,2,0,0,160,2,0,0,224,2,0,0,4,0,0,0,0,0,0,0,4,1,0,0,0,1,0,0,20,0,0,0,16,0,0,0,20,1,0,0,16,1,0,0,12,0,0,0,8,0,0,0,12,1,0,0,8,1,0,0,28,0,0,0,24,0,0,0,28,1,0,0,24,1,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,0,0,0,0,64,0,0,0,128,0,0,0,192,0,0,0,0,1,0,0,64,1,0,0,128,1,0,0,192,1,0,0,0,2,0,0,64,2,0,0,128,2,0,0,192,2,0,0,0,3,0,0,64,3,0,0,128,3,0,0,192,3,0,0,12,0,0,0,8,0,0,0,44,0,0,0,40,0,0,0,4,0,0,0,0,0,0,0,36,0,0,0,32,0,0,0,28,0,0,0,24,0,0,0,60,0,0,0,56,0,0,0,20,0,0,0,16,0,0,0,52,0,0,0,48,0,0,0,168,86,7,0,1,0,0,0,72,255,146,0,248,191,2,0,24,38,7,0,1,0,0,0,96,255,146,0,184,160,2,0,56,210,6,0,1,0,0,0,103,255,146,0,192,135,2,0,24,163,6,0,1,0,0,0,102,255,146,0,240,108,2,0,152,122,6,0,1,0,0,0,100,255,146,0,96,82,2,0,192,72,6,0,1,0,0,0,101,255,146,0,32,56,2,0,200,110,3,0,1,0,0,0,99,255,146,0,152,30,2,0,120,89,3,0,1,0,0,0,98,255,146,0,232,10,2,0,120,74,3,0,1,0,0,0,87,255,146,0,152,138,8,0,192,61,3,0,1,0,0,0,86,255,146,0,48,119,7,0,40,246,1,0,1,0,0,0,73,255,146,0,64,246,1,0,144,236,1,0,1,0,0,0,88,255,146,0,136,224,1,0,176,223,1,0,1,0,0,0,95,255,146,0,72,198,1,0,192,209,1,0,1,0,0,0,94,255,146,0,24,182,1,0,24,198,1,0,1,0,0,0,92,255,146,0,40,167,1,0,120,189,1,0,1,0,0,0,93,255,146,0,200,149,1,0,224,22,1,0,1,0,0,0,91,255,146,0,56,126,1,0,160,14,1,0,1,0,0,0,90,255,146,0,32,101,1,0,176,9,1,0,1,0,0,0,83,255,146,0,96,32,8,0,200,3,1,0,1,0,0,0,82,255,146,0,16,68,7,0,88,212,3,0,1,0,0,0,232,218,146,0,40,185,3,0,16,17,8,0,1,0,0,0,76,255,146,0,224,12,8,0,72,65,1,0,9,0,0,0,88,5,147,0,32,58,1,0,48,50,1,0,9,0,0,0,89,5,147,0,32,58,1,0,168,86,7,0,1,0,0,0,72,255,146,0,248,191,2,0,24,38,7,0,1,0,0,0,96,255,146,0,184,160,2,0,56,210,6,0,1,0,0,0,103,255,146,0,192,135,2,0,24,163,6,0,1,0,0,0,102,255,146,0,240,108,2,0,152,122,6,0,1,0,0,0,100,255,146,0,96,82,2,0,192,72,6,0,1,0,0,0,101,255,146,0,32,56,2,0,200,110,3,0,1,0,0,0,99,255,146,0,152,30,2,0,120,89,3,0,1,0,0,0,98,255,146,0,232,10,2,0,120,74,3,0,1,0,0,0,97,255,146,0,152,138,8,0,40,246,1,0,1,0,0,0,73,255,146,0,64,246,1,0,144,236,1,0,1,0,0,0,88,255,146,0,136,224,1,0,176,223,1,0,1,0,0,0,95,255,146,0,72,198,1,0,192,209,1,0,1,0,0,0,94,255,146,0,24,182,1,0,24,198,1,0,1,0,0,0,92,255,146,0,40,167,1,0,120,189,1,0,1,0,0,0,93,255,146,0,200,149,1,0,224,22,1,0,1,0,0,0,91,255,146,0,56,126,1,0,160,14,1,0,1,0,0,0,90,255,146,0,32,101,1,0,176,9,1,0,1,0,0,0,89,255,146,0,96,32,8,0,88,212,3,0,1,0,0,0,232,218,146,0,40,185,3,0,16,17,8,0,1,0,0,0,76,255,146,0,224,12,8,0,72,65,1,0,9,0,0,0,88,5,147,0,32,58,1,0,48,50,1,0,9,0,0,0,89,5,147,0,32,58,1,0,168,86,7,0,1,0,0,0,72,255,146,0,248,191,2,0,24,38,7,0,1,0,0,0,96,255,146,0,184,160,2,0,56,210,6,0,1,0,0,0,103,255,146,0,192,135,2,0,24,163,6,0,1,0,0,0,102,255,146,0,240,108,2,0,152,122,6,0,1,0,0,0,100,255,146,0,96,82,2,0,192,72,6,0,1,0,0,0,101,255,146,0,32,56,2,0,200,110,3,0,1,0,0,0,99,255,146,0,152,30,2,0,120,89,3,0,1,0,0,0,98,255,146,0,232,10,2,0,40,246,1,0,1,0,0,0,73,255,146,0,64,246,1,0,144,236,1,0,1,0,0,0,88,255,146,0,136,224,1,0,176,223,1,0,1,0,0,0,95,255,146,0,72,198,1,0,192,209,1,0,1,0,0,0,94,255,146,0,24,182,1,0,24,198,1,0,1,0,0,0,92,255,146,0,40,167,1,0,120,189,1,0,1,0,0,0,93,255,146,0,200,149,1,0,224,22,1,0,1,0,0,0,91,255,146,0,56,126,1,0,160,14,1,0,1,0,0,0,90,255,146,0,32,101,1,0,88,212,3,0,1,0,0,0,232,218,146,0,40,185,3,0,16,17,8,0,1,0,0,0,76,255,146,0,224,12,8,0,72,65,1,0,9,0,0,0,88,5,147,0,32,58,1,0,48,50,1,0,9,0,0,0,89,5,147,0,32,58,1,0,22,0,0,0,255,14,0,0,0,0,0,0,0,0,0,0,254,0,1,0,48,45,3,0,22,0,0,0,1,14,0,0,176,20,3,0,22,0,0,0,1,14,2,0,24,4,2,0,22,0,0,0,1,14,4,0,8,234,2,0,22,0,0,0,1,14,6,0,32,192,2,0,22,0,0,0,1,14,8,0,232,41,1,0,22,0,0,0,1,14,10,0,56,50,1,0,22,0,0,0,1,14,12,0,192,20,3,0,22,0,0,0,1,14,14,0,80,65,1,0,23,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,5,0,48,45,3,0,23,0,0,0,1,255,0,0,224,32,1,0,23,0,0,0,1,255,16,0,168,60,1,0,23,0,0,0,1,255,32,0,56,50,1,0,23,0,0,0,1,255,64,0,192,20,3,0,23,0,0,0,1,255,128,0,80,65,1,0,0,0,0,0,0,0,0,0,253,0,7,0,48,45,3,0,27,0,0,0,1,255,81,0,176,20,3,0,27,0,0,0,1,255,82,0,160,236,1,0,27,0,0,0,1,255,83,0,136,50,1,0,27,0,0,0,1,255,84,0,160,134,3,0,27,0,0,0,1,255,85,0,128,33,1,0,27,0,0,0,1,255,86,0,232,23,1,0,27,0,0,0,1,255,87,0,88,15,1,0,27,0,0,0,1,255,88,0,160,236,1,0,27,0,0,0,1,255,80,0,176,20,3,0,168,86,7,0,1,0,0,0,240,33,216,0,248,191,2,0,24,38,7,0,1,0,0,0,248,33,216,0,184,160,2,0,192,154,3,0,4,0,0,0,24,34,216,0,152,210,1,0,128,150,3,0,4,0,0,0,26,34,216,0,208,189,1,0,136,30,2,0,1,0,0,0,252,32,216,0,248,174,1,0,224,19,2,0,1,0,0,0,253,32,216,0,104,160,1,0,40,246,1,0,1,0,0,0,241,33,216,0,64,246,1,0,144,236,1,0,1,0,0,0,250,33,216,0,136,224,1,0,184,155,8,0,1,0,0,0,254,32,216,0,56,126,1,0,136,149,8,0,1,0,0,0,255,32,216,0,32,101,1,0,88,212,3,0,1,0,0,0,200,32,216,0,40,185,3,0,80,251,6,0,1,0,0,0,48,33,216,0,216,70,1,0,16,17,8,0,1,0,0,0,242,33,216,0,224,12,8,0,248,5,8,0,9,0,0,0,12,33,216,0,32,58,1,0,144,250,7,0,9,0,0,0,13,33,216,0,32,58,1,0,208,23,1,0,9,0,0,0,152,32,216,0,32,58,1,0,184,22,1,0,9,0,0,0,128,37,0,0,32,58,1,0,0,22,1,0,9,0,0,0,56,33,216,0,32,58,1,0,120,20,1,0,9,0,0,0,57,33,216,0,32,58,1,0,110,98,97,32,97,99,116,105,111,110,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,110,111,118,32,49,56,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,75,30,65,45,33,0,16,0,110,98,97,32,97,99,116,105,111,110,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,110,111,118,32,50,51,44,32,49,57,57,52,32,45,32,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,204,207,80,70,33,0,16,0,110,98,97,32,97,99,116,105,111,110,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,100,101,99,32,48,50,44,32,49,57,57,52,32,45,32,98,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,110,111,191,4,33,0,16,0,110,98,97,32,97,99,116,105,111,110,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,100,101,99,32,48,57,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,135,132,25,43,33,0,16,0,110,98,97,32,97,99,116,105,111,110,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,100,101,99,32,49,53,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,109,180,163,16,33,0,16,0,110,98,97,32,97,99,116,105,111,110,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,100,101,99,32,50,50,44,32,49,57,57,52,32,45,32,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,35,163,43,249,33,0,16,0,110,98,97,32,97,99,116,105,111,110,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,100,101,99,32,50,52,44,32,49,57,57,52,32,45,32,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,80,69,176,221,33,0,16,0,110,98,97,32,97,99,116,105,111,110,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,100,101,99,32,50,57,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,42,227,235,220,33,0,16,0,110,98,97,32,97,99,116,105,111,110,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,100,101,99,32,51,48,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,201,86,121,216,33,0,16,0,110,98,97,32,97,99,116,105,111,110,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,100,101,99,32,51,49,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,143,55,42,88,33,0,16,0,110,98,97,32,97,99,116,105,111,110,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,97,110,32,48,51,44,32,49,57,57,53,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,96,241,74,55,33,0,16,0,110,98,97,32,97,99,116,105,111,110,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,97,110,32,48,56,44,32,49,57,57,53,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,158,123,107,10,33,0,16,0,110,98,97,32,97,99,116,105,111,110,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,97,110,32,49,50,44,32,49,57,57,53,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,37,240,127,180,33,0,16,0,110,98,97,32,97,99,116,105,111,110,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,97,110,32,49,53,44,32,49,57,57,53,32,45,32,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,39,31,106,156,33,0,16,0,110,98,97,32,97,99,116,105,111,110,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,97,110,32,50,49,44,32,49,57,57,53,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,251,189,55,227,33,0,16,0,110,98,97,32,97,99,116,105,111,110,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,97,110,32,50,50,44,32,49,57,57,53,32,45,32,98,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,71,202,215,123,33,0,16,0,110,98,97,32,97,99,116,105,111,110,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,97,110,32,50,52,44,32,49,57,57,53,32,45,32,98,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,65,207,171,21,33,0,16,0,110,98,97,32,97,99,116,105,111,110,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,97,110,32,50,55,44,32,49,57,57,53,32,45,32,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,225,31,0,0,251,199,121,33,0,16,0,110,98,97,32,97,99,116,105,111,110,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,97,110,32,50,55,44,32,49,57,57,53,32,45,32,98,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,225,31,0,139,96,127,239,33,0,16,0,110,98,97,32,97,99,116,105,111,110,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,97,110,32,50,56,44,32,49,57,57,53,32,45,32,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,156,198,194,87,33,0,16,0,110,98,97,32,97,99,116,105,111,110,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,97,110,32,50,56,44,32,49,57,57,53,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,158,225,31,0,93,7,215,151,33,0,16,0,110,98,97,32,97,99,116,105,111,110,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,97,110,32,51,48,44,32,49,57,57,53,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,178,128,172,47,33,0,16,0,110,98,97,32,97,99,116,105,111,110,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,102,101,98,32,48,49,44,32,49,57,57,53,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,157,167,2,44,33,0,16,0,110,98,97,32,97,99,116,105,111,110,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,102,101,98,32,49,44,32,49,57,57,53,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,158,244,31,0,36,166,160,196,33,0,16,0,110,98,97,32,97,99,116,105,111,110,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,102,101,98,32,50,44,32,49,57,57,53,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,225,31,0,3,121,22,169,33,0,16,0,109,115,46,32,112,97,99,45,109,97,110,32,40,117,115,97,41,32,40,112,105,114,97,116,101,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,38,27,181,57,33,0,16,0,108,101,109,109,105,110,103,115,32,40,117,115,97,44,32,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,173,194,21,240,33,0,16,0,115,104,105,32,110,111,32,109,101,105,107,121,117,117,32,45,32,108,97,98,121,114,105,110,116,104,32,111,102,32,100,101,97,116,104,32,40,106,112,110,41,32,40,103,110,107,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,211,76,196,64,33,0,16,0,105,107,97,122,117,115,101,33,32,107,111,105,32,110,111,32,100,111,107,105,32,100,111,107,105,32,112,101,110,103,117,105,110,32,108,97,110,100,32,109,100,32,40,106,112,110,41,32,40,103,110,107,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,80,102,115,34,33,0,16,0,99,114,121,115,116,97,108,39,115,32,112,111,110,121,32,116,97,108,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,109,97,121,32,49,49,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,75,215,201,234,33,0,16,0,99,114,121,115,116,97,108,39,115,32,112,111,110,121,32,116,97,108,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,109,97,121,32,49,57,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,65,183,80,220,33,0,16,0,99,114,121,115,116,97,108,39,115,32,112,111,110,121,32,116,97,108,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,109,97,121,32,50,54,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,85,186,234,162,33,0,16,0,99,114,121,115,116,97,108,39,115,32,112,111,110,121,32,116,97,108,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,117,110,32,48,49,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,124,52,198,20,33,0,16,0,99,114,121,115,116,97,108,39,115,32,112,111,110,121,32,116,97,108,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,117,110,32,48,54,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,201,202,232,131,33,0,16,0,99,114,121,115,116,97,108,39,115,32,112,111,110,121,32,116,97,108,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,117,110,32,49,48,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,103,210,29,158,33,0,16,0,99,114,121,115,116,97,108,39,115,32,112,111,110,121,32,116,97,108,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,117,110,32,50,51,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,175,25,204,76,33,0,16,0,99,114,121,115,116,97,108,39,115,32,112,111,110,121,32,116,97,108,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,117,110,32,50,56,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,102,127,190,3,33,0,16,0,99,114,121,115,116,97,108,39,115,32,112,111,110,121,32,116,97,108,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,117,110,32,51,48,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,251,115,140,221,33,0,16,0,99,114,121,115,116,97,108,39,115,32,112,111,110,121,32,116,97,108,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,117,108,32,48,49,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,79,46,172,22,33,0,16,0,99,114,121,115,116,97,108,39,115,32,112,111,110,121,32,116,97,108,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,117,108,32,48,50,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,84,67,188,36,33,0,16,0,99,114,121,115,116,97,108,39,115,32,112,111,110,121,32,116,97,108,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,117,108,32,48,51,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,124,168,103,109,33,0,16,0,99,114,121,115,116,97,108,39,115,32,112,111,110,121,32,116,97,108,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,117,108,32,49,50,44,32,49,57,57,52,32,45,32,98,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,114,220,119,53,33,0,16,0,99,114,121,115,116,97,108,39,115,32,112,111,110,121,32,116,97,108,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,117,108,32,49,50,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,245,15,0,83,10,252,43,33,0,16,0,99,114,121,115,116,97,108,39,115,32,112,111,110,121,32,116,97,108,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,117,108,32,49,51,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,186,109,123,198,33,0,16,0,0,0,0,0,0,0,0,0,116,173,93,29,158,195,250,78,247,219,202,162,100,54,86,12,79,207,67,102,30,145,227,165,88,194,193,212,185,221,118,22,206,97,117,1,43,34,56,85,80,239,108,153,5,233,232,224,45,164,75,74,66,174,186,140,111,147,20,189,113,33,176,2,21,196,230,96,215,68,253,133,126,120,143,0,129,241,167,59,160,16,244,159,57,136,53,98,203,25,49,17,81,251,42,32,69,211,125,146,27,242,9,13,151,169,181,60,238,92,175,123,210,58,73,142,182,205,217,222,138,41,110,216,11,225,105,135,26,150,24,204,223,231,197,199,248,82,201,240,183,229,51,218,103,157,163,3,14,114,38,121,226,184,252,170,254,180,134,200,209,188,18,8,119,235,64,141,4,37,77,90,106,122,46,65,101,28,19,148,178,99,40,89,94,154,48,7,198,191,23,245,15,137,243,31,234,109,179,192,112,71,249,83,246,214,84,237,107,76,228,139,131,36,144,177,124,187,115,171,213,47,95,236,156,44,168,52,70,55,39,161,10,6,128,104,130,50,132,255,72,172,127,63,149,220,152,155,190,35,87,62,91,208,61,166,22,0,0,0,255,14,4,0,0,0,0,0,0,0,0,0,254,0,7,0,48,45,3,0,22,0,0,0,1,14,2,0,24,4,2,0,22,0,0,0,1,14,4,0,8,234,2,0,22,0,0,0,1,14,6,0,32,192,2,0,22,0,0,0,1,14,8,0,232,41,1,0,22,0,0,0,1,14,10,0,56,50,1,0,22,0,0,0,1,14,12,0,192,20,3,0,22,0,0,0,1,14,14,0,80,65,1,0,22,0,0,0,1,14,0,0,176,20,3,0,27,0,0,0,255,255,5,0,0,0,0,0,0,0,0,0,22,0,0,0,255,15,0,0,0,0,0,0,0,0,0,0,254,0,11,0,48,45,3,0,22,0,0,0,1,15,0,0,248,74,3,0,22,0,0,0,1,15,1,0,56,50,1,0,22,0,0,0,1,15,2,0,80,45,3,0,22,0,0,0,1,15,3,0,192,20,3,0,22,0,0,0,1,15,4,0,216,255,2,0,22,0,0,0,1,15,5,0,80,65,1,0,22,0,0,0,1,15,6,0,120,210,2,0,22,0,0,0,1,15,7,0,32,192,2,0,22,0,0,0,1,15,8,0,8,234,2,0,22,0,0,0,1,15,10,0,232,160,2,0,22,0,0,0,1,15,11,0,168,147,2,0,22,0,0,0,1,15,9,0,8,234,2,0,22,0,0,0,1,15,12,0,232,160,2,0,22,0,0,0,1,15,13,0,168,147,2,0,22,0,0,0,1,15,14,0,56,50,1,0,22,0,0,0,1,15,15,0,56,50,1,0,31,0,0,0,0,0,0,0,32,0,0,0,64,0,0,0,96,19,0,0,128,37,0,0,32,79,0,0,64,98,0,0,224,118,0,0,96,134,0,0,160,146,0,0,160,155,0,0,96,165,0,0,224,206,0,0,32,222,0,0,32,230,0,0,192,241,0,0,0,2,1,0,32,2,1,0,64,2,1,0,128,19,1,0,96,39,1,0,128,39,1,0,160,39,1,0,64,60,1,0,160,64,1,0,96,103,1,0,64,126,1,0,224,142,1,0,96,159,1,0,192,187,1,0,224,206,1,0,22,0,0,0,255,15,0,0,0,0,0,0,0,0,0,0,254,0,12,0,48,45,3,0,22,0,0,0,1,15,0,0,176,20,3,0,22,0,0,0,1,15,1,0,24,4,2,0,22,0,0,0,1,15,2,0,8,234,2,0,22,0,0,0,1,15,3,0,192,20,3,0,22,0,0,0,1,15,4,0,56,50,1,0,22,0,0,0,1,15,5,0,80,65,1,0,22,0,0,0,1,15,6,0,200,211,6,0,22,0,0,0,1,15,7,0,24,165,6,0,22,0,0,0,1,15,8,0,104,124,6,0,22,0,0,0,1,15,9,0,192,74,6,0,22,0,0,0,1,15,10,0,8,33,6,0,22,0,0,0,1,15,15,0,128,242,5,0,22,0,0,0,255,15,5,0,0,0,0,0,0,0,0,0,254,0,9,0,48,45,3,0,22,0,0,0,1,15,0,0,176,20,3,0,22,0,0,0,1,15,1,0,24,4,2,0,22,0,0,0,1,15,2,0,120,82,2,0,22,0,0,0,1,15,3,0,8,234,2,0,22,0,0,0,1,15,4,0,80,45,3,0,22,0,0,0,1,15,5,0,248,74,3,0,22,0,0,0,1,15,6,0,80,65,1,0,22,0,0,0,1,15,8,0,120,210,2,0,22,0,0,0,1,15,15,0,128,242,5,0,0,0,0,0,6,0,0,0,16,0,0,0,152,33,8,0,240,236,7,0,32,184,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,254,0,2,0,80,123,2,0,22,0,0,0,1,8,0,0,248,108,2,0,22,0,0,0,1,8,8,0,136,98,2,0,22,0,0,0,255,15,1,0,0,0,0,0,0,0,0,0,254,0,2,0,48,45,3,0,22,0,0,0,1,3,1,0,128,56,2,0,22,0,0,0,1,3,3,0,224,40,2,0,22,0,0,0,1,3,0,0,208,30,2,0,22,0,0,0,1,3,2,0,240,19,2,0,0,0,0,0,0,0,0,0,254,0,2,0,80,123,2,0,22,0,0,0,1,8,0,0,248,108,2,0,22,0,0,0,1,8,8,0,136,98,2,0,22,0,0,0,255,15,1,0,0,0,0,0,0,0,0,0,254,0,2,0,48,45,3,0,22,0,0,0,1,3,1,0,8,11,2,0,22,0,0,0,1,3,3,0,40,4,2,0,22,0,0,0,1,3,0,0,208,30,2,0,22,0,0,0,1,3,2,0,240,19,2,0,0,0,0,0,0,0,0,0,254,0,2,0,80,123,2,0,22,0,0,0,1,8,0,0,248,108,2,0,22,0,0,0,1,8,8,0,136,98,2,0,22,0,0,0,255,15,0,0,0,0,0,0,0,0,0,0,254,0,4,0,48,45,3,0,22,0,0,0,1,3,0,0,176,20,3,0,22,0,0,0,1,3,1,0,96,167,1,0,22,0,0,0,1,3,2,0,56,160,1,0,22,0,0,0,1,3,3,0,160,236,1,0,0,0,0,0,0,0,0,0,254,0,2,0,80,123,2,0,22,0,0,0,1,8,0,0,248,108,2,0,22,0,0,0,1,8,8,0,136,98,2,0,22,0,0,0,255,15,1,0,0,0,0,0,0,0,0,0,254,0,2,0,48,45,3,0,22,0,0,0,1,3,1,0,88,246,1,0,22,0,0,0,1,3,3,0,232,41,1,0,22,0,0,0,1,3,0,0,208,30,2,0,22,0,0,0,1,3,2,0,240,19,2,0,0,0,0,0,24,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,253,0,26,0,48,45,3,0,24,0,0,0,1,31,0,0,248,10,2,0,24,0,0,0,1,31,1,0,24,4,2,0,24,0,0,0,1,31,2,0,8,234,2,0,24,0,0,0,1,31,3,0,160,236,1,0,24,0,0,0,1,31,4,0,176,224,1,0,24,0,0,0,1,31,5,0,224,209,1,0,24,0,0,0,1,31,6,0,80,198,1,0,24,0,0,0,1,31,7,0,136,189,1,0,24,0,0,0,1,31,8,0,32,182,1,0,24,0,0,0,1,31,9,0,200,174,1,0,24,0,0,0,1,31,10,0,64,167,1,0,24,0,0,0,1,31,11,0,40,160,1,0,24,0,0,0,1,31,12,0,216,149,1,0,24,0,0,0,1,31,13,0,152,140,1,0,24,0,0,0,1,31,14,0,72,126,1,0,24,0,0,0,1,31,15,0,40,112,1,0,24,0,0,0,1,31,16,0,64,101,1,0,24,0,0,0,1,31,17,0,24,92,1,0,24,0,0,0,1,31,18,0,160,85,1,0,24,0,0,0,1,31,19,0,48,77,1,0,24,0,0,0,1,31,20,0,224,70,1,0,24,0,0,0,1,31,21,0,80,65,1,0,24,0,0,0,1,31,22,0,40,58,1,0,24,0,0,0,1,31,23,0,56,50,1,0,24,0,0,0,1,31,24,0,232,41,1,0,24,0,0,0,1,31,25,0,224,32,1,0,24,0,0,0,255,255,21,0,0,0,0,0,0,0,0,0,24,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,8,0,0,0,4,0,0,0,0,0,0,0,28,0,0,0,24,0,0,0,20,0,0,0,16,0,0,0,44,0,0,0,40,0,0,0,36,0,0,0,32,0,0,0,60,0,0,0,56,0,0,0,52,0,0,0,48,0,0,0,0,0,0,0,64,0,0,0,128,0,0,0,192,0,0,0,0,1,0,0,64,1,0,0,128,1,0,0,192,1,0,0,0,2,0,0,64,2,0,0,128,2,0,0,192,2,0,0,0,3,0,0,64,3,0,0,128,3,0,0,192,3,0,0,0,0,0,0,4,0,0,0,8,0,0,0,12,0,0,0,16,0,0,0,20,0,0,0,24,0,0,0,28,0,0,0,32,0,0,0,36,0,0,0,40,0,0,0,44,0,0,0,48,0,0,0,52,0,0,0,56,0,0,0,60,0,0,0,114,116,101,95,51,48,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,25,21,84,13,1,0,16,1,114,116,101,95,51,53,46,49,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,32,14,221,115,1,0,16,1,114,116,101,95,51,49,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,125,51,224,51,1,0,16,1,114,116,101,95,51,54,46,49,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,67,82,134,168,1,0,16,1,114,116,101,95,50,56,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,200,55,65,5,1,0,16,1,114,116,101,95,51,51,46,57,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,27,203,100,114,1,0,16,1,114,116,101,95,50,57,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,228,241,141,154,1,0,16,1,114,116,101,95,51,52,46,49,48,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,157,167,72,99,1,0,16,1,114,116,45,53,109,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,4,248,174,134,4,0,32,0,114,116,45,55,109,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,16,113,5,79,4,0,32,0,114,116,45,49,109,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,208,137,36,144,4,0,32,0,114,116,45,51,109,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,32,231,92,227,4,0,32,0,114,116,45,54,109,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,124,14,203,19,4,0,32,0,114,116,45,56,109,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,20,80,5,31,4,0,32,0,114,116,45,50,109,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,244,52,160,233,4,0,32,0,114,116,45,52,109,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,139,234,14,223,4,0,32,0,114,116,95,57,40,95,95,51,119,111,110,100,101,114,115,114,49,41,46,49,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,167,119,90,125,3,0,16,0,114,116,95,49,56,40,95,95,51,119,111,110,100,101,114,115,114,49,41,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,61,13,220,246,5,0,64,0,114,116,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,208,74,230,219,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,114,116,50,52,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,89,81,184,84,0,0,0,8,105,111,98,49,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,105,111,99,49,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,129,32,24,13,0,0,0,8,168,86,7,0,1,0,0,0,232,47,216,0,248,191,2,0,24,38,7,0,1,0,0,0,236,47,216,0,184,160,2,0,56,210,6,0,1,0,0,0,35,48,216,0,192,135,2,0,24,163,6,0,1,0,0,0,34,48,216,0,240,108,2,0,152,122,6,0,1,0,0,0,33,48,216,0,96,82,2,0,192,72,6,0,1,0,0,0,32,48,216,0,32,56,2,0,200,110,3,0,1,0,0,0,36,48,216,0,152,30,2,0,120,89,3,0,1,0,0,0,37,48,216,0,232,10,2,0,40,246,1,0,1,0,0,0,233,47,216,0,64,246,1,0,144,236,1,0,1,0,0,0,237,47,216,0,136,224,1,0,176,223,1,0,1,0,0,0,43,48,216,0,72,198,1,0,192,209,1,0,1,0,0,0,42,48,216,0,24,182,1,0,24,198,1,0,1,0,0,0,41,48,216,0,40,167,1,0,120,189,1,0,1,0,0,0,40,48,216,0,200,149,1,0,224,22,1,0,1,0,0,0,44,48,216,0,56,126,1,0,160,14,1,0,1,0,0,0,45,48,216,0,32,101,1,0,88,212,3,0,1,0,0,0,144,46,216,0,40,185,3,0,240,152,1,0,1,0,0,0,238,47,216,0,216,70,1,0,16,17,8,0,1,0,0,0,234,47,216,0,224,12,8,0,72,65,1,0,9,0,0,0,232,48,216,0,32,58,1,0,48,50,1,0,9,0,0,0,224,48,216,0,32,58,1,0,224,41,1,0,9,0,0,0,216,48,216,0,32,58,1,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,0,0,0,0,64,0,0,0,128,0,0,0,192,0,0,0,0,1,0,0,64,1,0,0,128,1,0,0,192,1,0,0,0,2,0,0,64,2,0,0,128,2,0,0,192,2,0,0,0,3,0,0,64,3,0,0,128,3,0,0,192,3,0,0,4,0,0,0,0,0,0,0,20,0,0,0,16,0,0,0,12,0,0,0,8,0,0,0,28,0,0,0,24,0,0,0,36,0,0,0,32,0,0,0,52,0,0,0,48,0,0,0,44,0,0,0,40,0,0,0,60,0,0,0,56,0,0,0,0,0,0,0,64,0,0,0,128,0,0,0,192,0,0,0,0,1,0,0,64,1,0,0,128,1,0,0,192,1,0,0,0,2,0,0,64,2,0,0,128,2,0,0,192,2,0,0,0,3,0,0,64,3,0,0,128,3,0,0,192,3,0,0,0,0,0,0,4,0,0,0,8,0,0,0,12,0,0,0,16,0,0,0,20,0,0,0,24,0,0,0,28,0,0,0,32,0,0,0,36,0,0,0,40,0,0,0,44,0,0,0,48,0,0,0,52,0,0,0,56,0,0,0,60,0,0,0,0,0,0,0,8,0,0,0,16,0,0,0,24,0,0,0,32,0,0,0,40,0,0,0,48,0,0,0,56,0,0,0,128,0,0,0,136,0,0,0,144,0,0,0,152,0,0,0,160,0,0,0,168,0,0,0,176,0,0,0,184,0,0,0,0,2,0,0,8,2,0,0,16,2,0,0,24,2,0,0,32,2,0,0,40,2,0,0,48,2,0,0,56,2,0,0,128,2,0,0,136,2,0,0,144,2,0,0,152,2,0,0,160,2,0,0,168,2,0,0,176,2,0,0,184,2,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,64,0,0,0,65,0,0,0,66,0,0,0,67,0,0,0,68,0,0,0,69,0,0,0,70,0,0,0,71,0,0,0,0,1,0,0,1,1,0,0,2,1,0,0,3,1,0,0,4,1,0,0,5,1,0,0,6,1,0,0,7,1,0,0,64,1,0,0,65,1,0,0,66,1,0,0,67,1,0,0,68,1,0,0,69,1,0,0,70,1,0,0,71,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,16,0,0,0,24,0,0,0,32,0,0,0,40,0,0,0,48,0,0,0,56,0,0,0,64,0,0,0,72,0,0,0,80,0,0,0,88,0,0,0,96,0,0,0,104,0,0,0,112,0,0,0,120,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,128,0,0,0,129,0,0,0,130,0,0,0,131,0,0,0,132,0,0,0,133,0,0,0,134,0,0,0,135,0,0,0,4,0,0,0,0,0,0,0,4,0,8,0,0,0,8,0,12,0,0,0,8,0,0,0,12,0,8,0,8,0,8,0,20,0,0,0,16,0,0,0,20,0,8,0,16,0,8,0,28,0,0,0,24,0,0,0,28,0,8,0,24,0,8,0,34,6,0,0,114,47,0,0,26,7,0,0,64,4,0,0,90,3,0,0,104,11,0,0,228,43,0,0,152,10,0,0,22,9,0,0,158,44,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,0,0,32,0,0,0,16,0,0,0,0,0,0,0,48,0,4,0,48,0,0,0,0,0,4,0,0,0,168,86,7,0,1,0,0,0,212,47,216,0,248,191,2,0,24,38,7,0,1,0,0,0,208,47,216,0,184,160,2,0,56,210,6,0,1,0,0,0,35,48,216,0,192,135,2,0,24,163,6,0,1,0,0,0,34,48,216,0,240,108,2,0,152,122,6,0,1,0,0,0,33,48,216,0,96,82,2,0,192,72,6,0,1,0,0,0,32,48,216,0,32,56,2,0,152,226,4,0,1,0,0,0,36,48,216,0,152,30,2,0,168,190,4,0,1,0,0,0,37,48,216,0,232,10,2,0,240,158,4,0,1,0,0,0,38,48,216,0,152,138,8,0,136,128,4,0,1,0,0,0,248,47,216,0,48,119,7,0,176,101,4,0,1,0,0,0,249,47,216,0,112,109,7,0,136,75,4,0,1,0,0,0,250,47,216,0,24,133,7,0,40,246,1,0,1,0,0,0,213,47,216,0,64,246,1,0,144,236,1,0,1,0,0,0,209,47,216,0,136,224,1,0,176,223,1,0,1,0,0,0,43,48,216,0,72,198,1,0,192,209,1,0,1,0,0,0,42,48,216,0,24,182,1,0,24,198,1,0,1,0,0,0,41,48,216,0,40,167,1,0,120,189,1,0,1,0,0,0,40,48,216,0,200,149,1,0,40,126,1,0,1,0,0,0,44,48,216,0,56,126,1,0,0,112,1,0,1,0,0,0,45,48,216,0,32,101,1,0,0,101,1,0,1,0,0,0,46,48,216,0,96,32,8,0,248,91,1,0,1,0,0,0,252,47,216,0,16,68,7,0,128,85,1,0,1,0,0,0,253,47,216,0,240,58,7,0,248,76,1,0,1,0,0,0,214,47,216,0,200,42,1,0,88,212,3,0,1,0,0,0,144,46,216,0,40,185,3,0,240,152,1,0,1,0,0,0,201,47,216,0,216,70,1,0,16,17,8,0,1,0,0,0,202,47,216,0,224,12,8,0,136,67,2,0,1,0,0,0,176,48,216,0,72,120,6,0,8,66,2,0,1,0,0,0,184,48,216,0,88,119,7,0,7,0,0,0,8,0,0,0,224,7,2,0,32,0,2,0,0,0,0,0,176,242,1,0,0,232,1,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,48,45,3,0,23,0,0,0,1,255,0,0,176,20,3,0,23,0,0,0,1,255,15,0,224,32,1,0,6,0,0,0,16,0,0,0,152,33,8,0,240,236,7,0,32,184,7,0,184,137,7,0,88,148,2,0,0,0,0,0,1,0,0,0,0,0,0,0,7,0,0,0,8,0,0,0,224,7,2,0,32,0,2,0,0,0,0,0,176,242,1,0,0,232,1,0,0,0,0,0,0,0,0,0,0,0,0,0,50,62,178,55,49,34,214,13,53,92,141,60,122,95,215,172,83,255,235,68,232,17,105,119,217,52,54,69,166,233,28,198,59,189,173,46,24,223,161,171,221,82,87,194,229,10,0,109,103,100,21,112,182,57,39,120,130,210,113,185,19,245,147,146,250,231,94,176,246,175,149,138,124,115,249,99,134,203,26,86,241,58,174,97,1,41,151,35,142,93,154,101,116,33,32,64,211,5,162,225,188,158,30,16,20,12,136,156,236,56,181,157,45,247,23,14,132,199,125,206,148,22,72,168,129,110,123,216,167,127,66,230,160,42,239,238,36,186,184,126,201,43,144,204,91,209,243,226,111,237,159,240,75,84,140,8,248,81,104,200,3,11,187,193,227,77,4,197,143,9,15,191,98,73,118,89,29,128,222,96,7,224,27,102,165,190,205,135,220,195,107,78,208,253,212,63,152,150,47,76,179,234,44,117,228,192,108,106,155,183,67,139,65,71,2,219,153,61,163,121,80,79,180,85,90,37,244,202,88,48,196,18,169,70,218,145,164,170,252,133,251,137,6,207,254,51,213,40,31,25,74,177,131,242,114,38,116,97,116,115,117,106,105,110,32,40,106,97,112,97,110,41,32,40,112,114,111,116,111,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,89,102,178,193,0,0,16,1,112,111,112,117,108,111,117,115,32,40,106,97,112,97,110,41,32,91,97,93,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,153,222,154,10,0,0,16,1,109,111,116,111,32,114,111,97,100,101,114,32,105,105,32,40,106,97,112,97,110,41,32,91,97,93,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,186,37,165,75,0,0,16,1,109,97,104,106,111,110,103,32,103,97,107,117,101,110,32,109,105,108,100,32,45,32,116,111,117,109,97,32,115,111,117,115,104,105,114,111,117,32,116,111,117,106,111,117,32,40,106,97,112,97,110,41,32,91,97,93,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,42,67,77,62,0,0,16,1,108,97,100,121,32,115,119,111,114,100,32,40,106,97,112,97,110,41,32,91,97,93,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,21,61,131,235,0,0,16,1,102,105,110,97,108,32,115,111,108,100,105,101,114,32,40,115,112,101,99,105,97,108,32,118,101,114,115,105,111,110,41,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,197,120,165,2,0,0,16,1,102,49,32,99,105,114,99,117,115,32,40,106,97,112,97,110,41,32,91,97,93,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,121,87,112,121,0,0,16,1,100,114,111,112,32,114,111,99,107,32,104,111,114,97,32,104,111,114,97,32,40,106,97,112,97,110,41,32,91,97,93,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,172,252,129,142,0,0,16,1,100,111,119,110,108,111,97,100,32,40,106,97,112,97,110,41,32,91,97,93,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,136,228,13,78,0,0,16,1,99,104,105,107,117,100,101,110,121,97,32,116,111,117,98,101,105,32,45,32,107,117,98,105,107,105,114,105,32,121,97,107,97,116,97,32,121,111,114,105,32,40,106,97,112,97,110,41,32,91,97,93,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,132,136,9,132,0,0,16,1,98,111,109,98,101,114,109,97,110,32,39,57,51,32,40,115,112,101,99,105,97,108,32,118,101,114,115,105,111,110,41,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,160,154,48,2,0,0,16,1,0,0,0,0,0,0,0,0,112,48,49,48,49,46,49,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,203,225,34,122,1,0,16,1,116,48,49,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,64,0,30,94,66,97,2,0,32,0,97,48,49,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,138,216,59,139,3,0,32,0,97,48,49,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,68,150,158,59,3,0,32,0,97,48,49,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,56,44,158,6,3,0,32,0,97,48,49,48,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,253,163,96,68,3,0,32,0,97,48,49,48,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,86,187,138,95,3,0,32,0,97,48,49,48,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,71,113,122,161,3,0,32,0,98,48,49,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,140,228,210,105,4,0,32,0,98,48,49,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,243,123,88,13,4,0,32,0,98,48,49,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,30,60,130,67,4,0,32,0,109,48,49,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,131,108,195,229,5,0,64,0,25,0,0,0,240,0,0,0,0,0,0,0,0,0,0,0,255,255,0,0,0,0,0,0,1,0,0,0,255,127,0,0,0,0,0,0,2,0,0,0,255,255,131,0,0,0,0,0,3,0,0,0,255,255,2,0,0,0,0,0,0,0,0,0,254,0,2,0,208,161,1,0,0,0,0,0,1,4,0,0,96,135,7,0,0,0,0,0,1,4,4,0,152,182,7,0,25,0,0,0,240,0,0,0,0,0,0,0,0,0,0,0,255,255,0,0,0,0,0,0,1,0,0,0,255,127,0,0,0,0,0,0,2,0,0,0,255,255,142,0,0,0,0,0,3,0,0,0,255,255,2,0,0,0,0,0,0,0,0,0,254,0,2,0,208,161,1,0,0,0,0,0,1,4,0,0,96,135,7,0,0,0,0,0,1,4,4,0,152,182,7,0,119,111,114,108,100,32,111,102,32,105,108,108,117,115,105,111,110,32,45,32,102,117,115,104,105,103,105,32,110,97,32,109,97,103,105,99,32,98,111,120,32,40,106,112,110,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,15,104,127,87,33,0,16,0,116,97,122,32,105,110,32,101,115,99,97,112,101,32,102,114,111,109,32,109,97,114,115,32,40,112,114,111,116,111,116,121,112,101,32,45,32,109,97,114,32,48,57,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,54,153,29,0,30,39,194,227,33,0,16,0,116,97,122,32,105,110,32,101,115,99,97,112,101,32,102,114,111,109,32,109,97,114,115,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,112,114,32,49,56,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,236,118,167,191,33,0,16,0,116,97,122,32,105,110,32,101,115,99,97,112,101,32,102,114,111,109,32,109,97,114,115,32,40,112,114,111,116,111,116,121,112,101,32,45,32,109,97,121,32,48,57,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,134,112,114,17,33,0,16,0,116,97,122,32,105,110,32,101,115,99,97,112,101,32,102,114,111,109,32,109,97,114,115,32,40,112,114,111,116,111,116,121,112,101,32,45,32,109,97,121,32,49,56,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,132,149,11,0,222,102,38,110,33,0,16,0,116,97,122,32,105,110,32,101,115,99,97,112,101,32,102,114,111,109,32,109,97,114,115,32,40,112,114,111,116,111,116,121,112,101,32,45,32,109,97,121,32,50,51,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,210,79,52,234,33,0,16,0,116,97,122,32,105,110,32,101,115,99,97,112,101,32,102,114,111,109,32,109,97,114,115,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,117,110,32,48,50,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,194,69,243,57,33,0,16,0,116,97,122,32,105,110,32,101,115,99,97,112,101,32,102,114,111,109,32,109,97,114,115,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,117,110,32,48,55,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,9,231,129,52,33,0,16,0,116,97,122,32,105,110,32,101,115,99,97,112,101,32,102,114,111,109,32,109,97,114,115,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,117,110,32,49,48,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,180,76,47,131,33,0,16,0,116,97,122,32,105,110,32,101,115,99,97,112,101,32,102,114,111,109,32,109,97,114,115,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,117,110,32,49,52,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,91,182,173,43,33,0,16,0,116,97,122,32,105,110,32,101,115,99,97,112,101,32,102,114,111,109,32,109,97,114,115,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,117,110,32,49,56,44,32,49,57,57,52,32,45,32,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,156,30,75,60,33,0,16,0,116,97,122,32,105,110,32,101,115,99,97,112,101,32,102,114,111,109,32,109,97,114,115,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,117,110,32,50,48,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,3,66,15,240,33,0,16,0,115,117,112,101,114,32,115,104,105,110,111,98,105,32,105,105,44,32,116,104,101,32,40,106,112,110,41,32,40,98,101,116,97,41,32,40,101,97,114,108,105,101,114,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,227,188,229,30,33,0,16,0,115,117,112,101,114,32,115,104,105,110,111,98,105,32,105,105,44,32,116,104,101,32,40,106,112,110,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,234,138,126,196,33,0,16,0,115,112,105,100,101,114,45,109,97,110,32,40,117,115,97,41,32,40,97,99,99,108,97,105,109,41,32,40,98,101,116,97,41,32,40,101,97,114,108,105,101,114,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,118,254,225,131,33,0,16,0,115,112,105,100,101,114,45,109,97,110,32,40,117,115,97,41,32,40,97,99,99,108,97,105,109,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,13,113,138,184,33,0,16,0,115,104,105,110,105,110,103,32,102,111,114,99,101,32,105,105,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,112,114,32,48,52,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,12,103,67,88,33,0,16,0,115,104,105,110,105,110,103,32,102,111,114,99,101,32,105,105,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,117,110,32,48,55,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,186,139,182,3,33,0,16,0,115,104,105,110,105,110,103,32,105,110,32,116,104,101,32,100,97,114,107,110,101,115,115,32,40,98,114,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,196,187,226,62,33,0,16,0,115,104,97,100,111,119,114,117,110,32,40,112,114,111,116,111,116,121,112,101,32,45,32,100,101,99,32,50,56,44,32,49,57,57,51,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,210,173,85,36,33,0,16,0,115,104,97,100,111,119,114,117,110,32,40,112,114,111,116,111,116,121,112,101,32,45,32,100,101,99,32,51,49,44,32,49,57,57,51,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,250,226,181,187,33,0,16,0,115,104,97,100,111,119,114,117,110,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,97,110,32,50,53,44,32,49,57,57,52,32,45,32,99,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,168,188,43,110,33,0,16,0,115,104,97,100,111,119,114,117,110,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,97,110,32,50,53,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,205,75,150,42,33,0,16,0,114,111,98,111,99,111,112,32,118,101,114,115,117,115,32,116,104,101,32,116,101,114,109,105,110,97,116,111,114,32,40,98,101,116,97,41,32,40,97,108,116,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,41,255,235,236,33,0,16,0,112,121,114,97,109,105,100,32,109,97,103,105,99,32,40,106,112,110,41,32,40,103,110,107,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,234,114,2,178,33,0,16,0,112,97,103,101,109,97,115,116,101,114,44,32,116,104,101,32,40,117,115,97,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,61,94,137,41,33,0,16,0,111,117,116,114,117,110,32,50,48,49,57,32,40,117,115,97,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,250,221,236,210,33,0,16,0,111,108,121,109,112,105,99,32,103,111,108,100,32,40,117,115,97,41,32,40,97,108,116,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,118,147,99,175,33,0,16,0,109,117,104,97,109,109,97,100,32,97,108,105,32,104,101,97,118,121,119,101,105,103,104,116,32,98,111,120,105,110,103,32,40,117,115,97,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,83,38,133,123,33,0,16,0,109,105,99,107,32,38,32,109,97,99,107,32,97,115,32,116,104,101,32,103,108,111,98,97,108,32,103,108,97,100,105,97,116,111,114,115,32,40,117,115,97,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,33,175,194,8,33,0,16,0,109,99,100,111,110,97,108,100,39,115,32,116,114,101,97,115,117,114,101,32,108,97,110,100,32,97,100,118,101,110,116,117,114,101,32,40,106,112,110,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,232,119,244,123,33,0,16,0,115,117,110,115,111,102,116,95,108,101,109,56,95,106,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,98,3,199,104,33,0,16,0,108,97,110,100,115,116,97,108,107,101,114,32,40,117,115,97,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,3,61,72,112,33,0,16,0,104,121,112,101,114,32,100,117,110,107,32,45,32,116,104,101,32,112,108,97,121,111,102,102,32,101,100,105,116,105,111,110,32,40,106,112,110,41,32,40,98,101,116,97,41,46,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,187,75,18,219,33,0,16,0,102,105,114,101,32,115,104,97,114,107,32,40,117,115,97,41,32,40,97,108,116,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,70,81,23,156,33,0,16,0,101,120,111,32,115,113,117,97,100,32,40,117,115,97,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,100,249,237,112,33,0,16,0,101,116,101,114,110,97,108,32,99,104,97,109,112,105,111,110,115,32,40,106,112,110,41,32,40,112,114,111,116,111,116,121,112,101,32,45,32,110,111,118,32,49,55,44,32,49,57,57,51,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,244,47,0,57,180,134,196,33,0,16,0,100,114,46,32,114,111,98,111,116,110,105,107,39,115,32,109,101,97,110,32,98,101,97,110,32,109,97,99,104,105,110,101,32,40,117,115,97,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,115,82,14,77,33,0,16,0,100,105,110,111,115,97,117,114,115,32,102,111,114,32,104,105,114,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,112,114,32,50,54,44,32,49,57,57,51,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,62,125,199,84,33,0,16,0,100,105,110,111,115,97,117,114,115,32,102,111,114,32,104,105,114,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,112,114,32,50,55,44,32,49,57,57,51,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,83,4,0,22,33,0,16,0,100,105,110,111,115,97,117,114,115,32,102,111,114,32,104,105,114,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,109,97,121,32,48,50,44,32,49,57,57,51,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,233,222,84,137,33,0,16,0,100,101,115,101,114,116,32,100,101,109,111,108,105,116,105,111,110,32,40,112,114,111,116,111,116,121,112,101,32,45,32,100,101,99,32,48,54,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,173,208,14,0,229,233,127,210,33,0,16,0,100,101,115,101,114,116,32,100,101,109,111,108,105,116,105,111,110,32,40,112,114,111,116,111,116,121,112,101,32,45,32,100,101,99,32,48,56,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,223,15,0,182,234,170,105,33,0,16,0,100,101,115,101,114,116,32,100,101,109,111,108,105,116,105,111,110,32,40,112,114,111,116,111,116,121,112,101,32,45,32,100,101,99,32,49,50,44,32,49,57,57,52,32,45,32,98,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,131,146,241,22,33,0,16,0,100,101,115,101,114,116,32,100,101,109,111,108,105,116,105,111,110,32,40,112,114,111,116,111,116,121,112,101,32,45,32,100,101,99,32,49,50,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,201,14,0,215,73,173,93,33,0,16,0,100,101,115,101,114,116,32,100,101,109,111,108,105,116,105,111,110,32,40,112,114,111,116,111,116,121,112,101,32,45,32,100,101,99,32,49,51,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,156,222,15,0,21,238,93,55,33,0,16,0,100,101,115,101,114,116,32,100,101,109,111,108,105,116,105,111,110,32,40,112,114,111,116,111,116,121,112,101,32,45,32,100,101,99,32,49,52,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,156,222,15,0,4,243,249,57,33,0,16,0,100,101,115,101,114,116,32,100,101,109,111,108,105,116,105,111,110,32,40,112,114,111,116,111,116,121,112,101,32,45,32,100,101,99,32,49,53,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,156,222,15,0,106,115,9,81,33,0,16,0,100,101,115,101,114,116,32,100,101,109,111,108,105,116,105,111,110,32,40,112,114,111,116,111,116,121,112,101,32,45,32,100,101,99,32,49,54,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,251,171,63,87,33,0,16,0,100,101,115,101,114,116,32,100,101,109,111,108,105,116,105,111,110,32,40,112,114,111,116,111,116,121,112,101,32,45,32,100,101,99,32,49,57,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,156,222,15,0,88,231,236,176,33,0,16,0,99,111,111,108,32,115,112,111,116,32,40,117,115,97,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,168,164,186,14,33,0,16,0,99,104,117,99,107,32,114,111,99,107,32,105,105,32,45,32,115,111,110,32,111,102,32,99,104,117,99,107,32,40,117,115,97,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,36,179,163,214,33,0,16,0,99,97,112,116,97,105,110,32,97,109,101,114,105,99,97,32,97,110,100,32,116,104,101,32,97,118,101,110,103,101,114,115,32,40,117,115,97,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,192,89,172,186,33,0,16,0,110,98,97,32,112,108,97,121,111,102,102,115,32,45,32,98,117,108,108,115,32,118,115,32,98,108,97,122,101,114,115,32,40,106,112,110,41,32,40,97,108,116,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,31,206,101,69,33,0,16,0,97,100,118,101,110,116,117,114,101,115,32,111,102,32,98,97,116,109,97,110,32,38,32,114,111,98,105,110,44,32,116,104,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,112,114,32,48,54,44,32,49,57,57,53,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,137,243,92,240,33,0,16,0,97,100,118,101,110,116,117,114,101,115,32,111,102,32,98,97,116,109,97,110,32,38,32,114,111,98,105,110,44,32,116,104,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,112,114,32,49,48,44,32,49,57,57,53,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,112,160,243,212,33,0,16,0,97,100,118,101,110,116,117,114,101,115,32,111,102,32,98,97,116,109,97,110,32,38,32,114,111,98,105,110,44,32,116,104,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,112,114,32,49,49,44,32,49,57,57,53,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,144,162,181,181,33,0,16,0,97,100,118,101,110,116,117,114,101,115,32,111,102,32,98,97,116,109,97,110,32,38,32,114,111,98,105,110,44,32,116,104,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,112,114,32,49,56,44,32,49,57,57,53,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,43,20,116,104,33,0,16,0,97,100,118,101,110,116,117,114,101,115,32,111,102,32,98,97,116,109,97,110,32,38,32,114,111,98,105,110,44,32,116,104,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,112,114,32,49,57,44,32,49,57,57,53,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,86,218,2,112,33,0,16,0,97,100,118,101,110,116,117,114,101,115,32,111,102,32,98,97,116,109,97,110,32,38,32,114,111,98,105,110,44,32,116,104,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,112,114,32,50,49,44,32,49,57,57,53,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,19,47,240,97,33,0,16,0,97,100,118,101,110,116,117,114,101,115,32,111,102,32,98,97,116,109,97,110,32,38,32,114,111,98,105,110,44,32,116,104,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,112,114,32,50,50,44,32,49,57,57,53,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,178,54,130,235,33,0,16,0,97,100,118,101,110,116,117,114,101,115,32,111,102,32,98,97,116,109,97,110,32,38,32,114,111,98,105,110,44,32,116,104,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,112,114,32,50,52,44,32,49,57,57,53,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,248,71,57,37,33,0,16,0,97,100,118,101,110,116,117,114,101,115,32,111,102,32,98,97,116,109,97,110,32,38,32,114,111,98,105,110,44,32,116,104,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,112,114,32,50,54,44,32,49,57,57,53,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,238,247,121,188,33,0,16,0,97,100,118,101,110,116,117,114,101,115,32,111,102,32,98,97,116,109,97,110,32,38,32,114,111,98,105,110,44,32,116,104,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,112,114,32,50,55,44,32,49,57,57,53,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,144,129,172,253,33,0,16,0,97,100,118,101,110,116,117,114,101,115,32,111,102,32,98,97,116,109,97,110,32,38,32,114,111,98,105,110,44,32,116,104,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,112,114,32,50,56,44,32,49,57,57,53,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,75,82,161,39,33,0,16,0,97,100,118,101,110,116,117,114,101,115,32,111,102,32,98,97,116,109,97,110,32,38,32,114,111,98,105,110,44,32,116,104,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,109,97,121,32,48,49,44,32,49,57,57,53,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,3,162,154,88,33,0,16,0,66,6,0,0,128,30,0,0,22,4,0,0,120,12,0,0,80,5,0,0,214,14,0,0,234,41,0,0,244,8,0,0,202,5,0,0,42,44,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,5,0,48,45,3,0,23,0,0,0,1,255,0,0,224,32,1,0,23,0,0,0,1,255,1,0,168,60,1,0,23,0,0,0,1,255,2,0,56,50,1,0,23,0,0,0,1,255,4,0,192,20,3,0,23,0,0,0,1,255,8,0,80,65,1,0,0,0,0,0,18,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,4,0,224,149,1,0,18,0,0,0,1,3,2,0,192,255,2,0,18,0,0,0,1,3,3,0,208,75,4,0,18,0,0,0,1,3,0,0,8,49,4,0,18,0,0,0,1,3,1,0,72,246,3,0,1,0,181,0,182,0,182,0,182,0,182,0,182,0,182,0,183,0,1,0,184,0,47,0,47,0,47,0,47,0,185,0,170,0,49,0,171,0,171,0,171,0,172,0,173,0,173,0,174,0,175,0,176,0,177,0,178,0,179,0,180,0,145,0,156,0,157,0,158,0,159,0,160,0,161,0,162,0,163,0,164,0,165,0,166,0,167,0,168,0,169,0,155,0,145,0,188,0,146,0,11,0,9,0,147,0,148,0,149,0,150,0,151,0,115,0,1,0,152,0,153,0,154,0,155,0,145,0,188,0,123,0,11,0,8,0,135,0,136,0,137,0,138,0,127,0,139,0,140,0,141,0,142,0,143,0,144,0,145,0,189,0,123,0,11,0,7,0,124,0,125,0,126,0,1,0,127,0,128,0,129,0,130,0,131,0,132,0,133,0,134,0,188,0,112,0,11,0,6,0,113,0,114,0,115,0,1,0,116,0,13,0,117,0,118,0,119,0,120,0,121,0,122,0,188,0,186,0,10,0,5,0,101,0,102,0,103,0,104,0,104,0,105,0,106,0,107,0,108,0,109,0,110,0,111,0,188,0,89,0,1,0,4,0,90,0,91,0,1,0,92,0,93,0,94,0,95,0,96,0,97,0,98,0,99,0,100,0,20,0,77,0,1,0,3,0,78,0,79,0,80,0,81,0,82,0,1,0,83,0,84,0,85,0,86,0,87,0,88,0,20,0,67,0,1,0,2,0,68,0,69,0,70,0,71,0,72,0,73,0,187,0,74,0,75,0,76,0,1,0,1,0,20,0,43,0,1,0,56,0,57,0,58,0,59,0,49,0,60,0,61,0,62,0,63,0,64,0,65,0,66,0,1,0,20,0,45,0,1,0,46,0,47,0,48,0,49,0,50,0,51,0,52,0,53,0,54,0,1,0,20,0,55,0,1,0,20,0,33,0,34,0,35,0,36,0,37,0,38,0,39,0,40,0,41,0,1,0,1,0,1,0,42,0,43,0,44,0,20,0,21,0,22,0,23,0,24,0,25,0,26,0,27,0,28,0,29,0,30,0,30,0,30,0,30,0,31,0,32,0,12,0,13,0,14,0,1,0,15,0,16,0,17,0,18,0,13,0,13,0,13,0,13,0,13,0,13,0,13,0,19,0,82,0,49,0,167,0,67,0,7,0,138,0,177,0,102,0,159,0,204,0,9,0,77,0,51,0,40,0,208,0,37,0,3,0,64,0,5,0,128,0,3,0,128,0,5,0,160,0,3,0,64,0,5,0,192,0,3,0,128,0,5,0,224,0,3,0,64,0,6,0,0,0,3,0,128,0,6,0,32,0,3,0,64,0,6,0,64,0,3,0,128,0,6,0,96,0,0,0,160,0,9,0,224,0,0,0,224,0,10,0,0,0,0,0,160,0,10,0,32,0,0,0,224,0,10,0,64,0,0,0,160,0,10,0,96,0,0,0,224,0,10,0,128,0,0,0,160,0,10,0,160,0,0,0,224,0,10,0,192,0,3,0,64,0,5,0,128,0,3,0,128,0,5,0,160,0,3,0,64,0,5,0,192,0,3,0,128,0,5,0,224,0,3,0,64,0,6,0,0,0,3,0,128,0,6,0,32,0,3,0,64,0,6,0,64,0,3,0,128,0,6,0,96,0,0,0,160,0,9,0,224,0,0,0,224,0,10,0,0,0,0,0,160,0,10,0,32,0,0,0,224,0,10,0,64,0,0,0,160,0,10,0,96,0,0,0,224,0,10,0,128,0,0,0,160,0,10,0,160,0,0,0,224,0,10,0,192,0,22,0,0,0,255,15,3,0,0,0,0,0,0,0,0,0,254,0,9,0,48,45,3,0,22,0,0,0,1,15,0,0,176,20,3,0,22,0,0,0,1,15,1,0,24,4,2,0,22,0,0,0,1,15,2,0,120,82,2,0,22,0,0,0,1,15,3,0,8,234,2,0,22,0,0,0,1,15,4,0,80,45,3,0,22,0,0,0,1,15,5,0,248,74,3,0,22,0,0,0,1,15,6,0,80,65,1,0,22,0,0,0,1,15,8,0,120,210,2,0,22,0,0,0,1,15,15,0,128,242,5,0,0,0,0,0,38,5,132,6,95,1,173,1,54,7,65,3,195,4,60,2,235,3,31,0,142,1,117,3,41,0,39,2,7,7,6,5,206,5,220,0,220,5,253,5,92,1,19,0,185,7,193,3,125,7,235,1,61,5,169,4,110,6,169,0,226,4,97,3,45,3,81,1,106,1,237,5,176,4,138,7,209,0,30,0,190,4,221,7,45,2,37,1,1,4,24,1,81,0,132,7,138,4,131,0,47,4,107,5,72,4,121,6,25,0,118,0,76,4,99,6,161,3,64,7,149,0,66,2,197,4,59,1,196,3,48,1,34,1,71,0,107,1,98,1,217,0,244,1,190,0,24,0,108,5,148,4,176,0,133,1,179,3,87,2,100,7,93,0,212,7,189,2,89,1,251,2,122,0,101,3,253,4,81,4,82,4,45,5,83,7,200,5,164,1,14,5,255,5,54,5,91,4,129,2,184,4,255,1,40,2,249,5,202,1,135,5,253,0,42,0,218,0,63,0,164,6,113,6,217,2,119,3,156,3,52,5,197,6,178,1,219,1,99,2,195,5,199,0,116,4,219,4,82,1,222,3,125,4,74,6,28,4,108,6,217,3,105,7,193,0,236,4,107,4,116,2,170,6,35,6,26,3,239,2,112,2,231,1,229,4,227,2,249,1,3,2,80,1,163,4,211,7,175,0,200,1,16,3,205,4,166,1,78,1,54,6,248,3,77,0,55,3,65,4,192,3,216,1,130,4,153,3,239,3,32,5,96,2,82,3,248,4,33,5,113,2,230,6,218,5,99,7,149,5,224,4,219,2,198,3,18,0,155,0,79,1,107,2,18,5,203,0])
.concat([22,6,5,6,58,6,226,5,57,1,205,7,208,7,12,0,152,1,52,2,247,4,126,3,161,0,189,4,161,1,240,2,180,3,166,0,199,1,30,5,102,1,103,5,25,7,203,5,181,3,28,3,81,7,161,6,101,0,250,4,225,6,6,1,165,1,49,3,162,3,109,1,86,7,144,0,84,5,65,2,154,1,92,3,233,0,136,3,201,1,27,1,199,5,106,5,104,1,178,5,127,4,169,5,81,5,187,3,211,3,40,4,50,1,215,4,209,1,56,5,215,5,151,2,223,6,206,0,40,7,197,2,246,6,13,6,160,2,95,4,109,4,240,4,234,5,224,1,214,4,66,4,47,3,67,2,15,3,201,0,68,3,45,4,47,2,39,3,178,2,88,1,175,7,210,3,39,1,211,6,17,4,235,7,50,6,119,2,11,6,86,3,7,3,195,1,241,0,98,7,7,2,62,1,90,2,208,6,142,3,167,0,154,7,165,2,113,7,158,3,37,3,96,1,20,0,21,1,152,6,18,7,200,2,195,3,188,1,150,6,214,0,146,6,159,4,222,4,179,5,204,0,243,2,103,6,24,3,44,5,224,3,129,1,98,4,247,1,102,3,244,4,71,5,78,4,190,1,237,3,78,0,144,4,97,6,3,7,32,3,46,4,6,4,97,1,89,2,2,7,139,5,25,6,31,5,2,5,145,3,206,4,121,7,249,0,91,0,94,4,74,1,106,6,43,4,90,3,99,3,184,1,115,3,23,1,143,7,78,3,224,2,215,2,238,7,123,2,198,2,3,1,220,7,61,2,173,2,73,0,138,6,31,4,130,5,213,3,49,6,7,1,190,2,142,2,175,5,25,1,148,6,68,7,70,5,155,1,102,7,207,5,238,2,224,0,165,4,19,3,163,6,177,3,138,2,4,1,21,4,158,1,28,0,9,0,103,1,102,2,151,3,86,0,37,5,22,4,79,6,137,6,6,7,19,4,4,0,201,6,68,2,248,2,139,7,16,5,46,0,5,5,166,5,18,6,20,1,217,4,204,1,15,2,233,7,58,1,132,5,149,4,210,6,244,5,147,0,63,4,227,0,130,3,70,7,30,7,148,7,45,7,236,3,193,7,58,0,61,3,236,1,40,1,127,2,0,7,73,1,12,1,83,5,188,2,146,4,128,0,176,5,21,0,196,1,145,6,55,0,159,5,66,5,207,4,83,2,174,5,77,7,7,4,232,6,84,3,180,7,155,4,0,3,242,6,110,2,244,3,134,0,124,3,238,1,71,3,177,6,109,2,5,1,93,5,186,1,11,7,54,2,227,3,182,0,194,2,59,3,84,2,64,1,232,2,194,5,59,0,76,0,170,5,128,4,96,5,237,6,51,6,166,7,159,2,137,7,228,0,138,0,91,1,126,5,254,4,50,5,92,2,21,2,9,7,247,5,151,1,134,5,241,2,224,5,119,4,27,6,8,6,99,0,27,0,18,2,22,0,149,7,5,2,250,1,66,7,119,7,11,4,70,1,59,7,3,5,146,7,14,1,69,5,246,7,247,3,173,4,141,3,185,3,22,5,172,2,189,3,27,3,20,2,112,1,214,5,27,2,177,1,205,3,19,2,101,5,10,4,19,1,21,5,36,7,61,0,192,5,52,3,233,3,168,2,197,1,137,0,78,2,203,7,213,4,128,2,108,3,176,2,48,4,230,0,213,0,197,3,98,6,117,2,15,6,222,0,72,2,123,0,44,2,181,7,64,3,57,7,184,2,90,6,8,5,22,1,121,0,160,7,194,4,153,0,187,4,42,5,209,4,137,3,163,3,230,1,164,2,13,1,186,4,129,5,178,0,2,3,244,0,96,7,93,2,198,4,155,3,43,1,70,0,55,6,139,3,246,0,9,1,28,5,13,4,233,6,226,6,218,7,160,4,135,4,126,6,95,6,101,2,57,4,137,1,8,2,181,4,80,2,241,4,110,1,150,4,252,3,114,2,12,2,174,7,146,2,227,5,114,4,88,4,109,6,87,6,34,7,56,4,184,3,228,4,154,3,152,5,57,5,180,4,144,2,139,1,222,1,92,6,234,2,255,6,10,2,50,2,88,0,211,2,211,0,241,1,29,6,210,0,210,1,149,2,102,4,56,0,172,0,199,4,199,6,114,6,64,0,160,6,153,6,36,6,31,7,32,1,11,1,114,0,146,1,186,3,56,6,141,5,48,5,14,0,97,7,221,6,205,1,141,1,66,1,235,2,94,5,178,7,103,3,211,5,28,7,210,2,160,0,178,6,52,1,134,2,46,1,207,0,221,5,231,2,75,7,97,2,130,0,38,7,77,1,227,1,183,4,231,7,53,4,148,2,31,3,84,1,207,2,245,5,48,3,0,4,61,1,41,6,209,7,162,4,230,3,232,3,245,1,243,3,104,3,16,4,202,3,33,2,27,7,105,6,149,1,242,7,15,7,6,0,4,5,98,0,97,4,83,0,247,6,163,0,250,6,242,1,69,7,223,7,42,1,90,0,59,2,218,4,104,5,101,6,13,3,246,5,40,3,131,2,105,1,124,1,1,6,1,2,195,6,192,6,145,4,63,6,245,6,181,2,199,2,40,6,249,3,43,0,138,3,233,2,12,6,169,2,2,1,159,3,195,0,44,4,207,7,223,3,249,4,53,2,168,3,228,7,133,4,29,2,73,3,232,0,184,0,69,3,131,6,140,1,23,3,202,6,35,3,125,1,106,3,201,7,160,1,225,3,249,6,162,0,83,3,182,7,89,7,135,2,215,7,94,2,35,5,146,0,39,4,167,5,150,3,54,1,90,7,214,3,7,5,133,3,222,5,95,5,173,0,150,0,57,2,184,5,203,6,116,5,17,5,30,4,55,5,116,0,72,1,164,7,14,7,203,2,132,2,145,1,110,0,218,2,26,5,116,3,186,6,27,4,82,5,96,4,113,3,131,1,179,0,68,4,72,7,244,7,158,5,189,5,129,3,171,0,253,6,204,4,229,3,197,5,156,0,23,7,46,2,8,7,187,1,12,7,166,4,120,7,52,0,213,1,11,3,245,7,67,7,174,6,222,2,166,2,19,6,208,5,12,4,191,0,9,2,183,1,245,4,43,7,32,6,71,6,67,6,36,0,202,2,189,0,1,5,164,0,83,4,255,3,181,6,37,6,247,2,86,5,105,4,9,4,71,7,49,0,246,1,124,4,171,2,253,1,51,5,79,7,149,3,84,7,208,0,176,6,42,4,53,6,175,1,169,6,156,4,123,7,17,6,174,2,180,2,165,3,181,1,254,3,171,3,121,4,152,4,170,3,193,5,126,2,106,2,144,5,157,2,44,0,33,1,4,4,28,6,80,6,24,5,58,3,104,7,242,0,180,0,134,6,123,6,1,3,75,0,193,1,217,7,114,7,200,0,154,4,143,6,155,5,25,4,58,7,80,7,96,3,142,5,100,2,46,5,13,0,110,4,133,0,111,4,136,7,100,1,216,3,219,6,43,5,115,4,50,3,115,0,64,4,40,0,91,3,241,3,75,1,251,7,62,0,140,2,234,1,245,3,168,6,60,5,181,5,251,0,133,5,120,4,121,1,172,4,55,1,115,1,229,1,198,7,98,2,39,0,216,6,68,1,228,3,115,6,183,7,69,1,183,6,150,5,198,1,75,5,16,1,85,1,78,6,246,4,75,4,250,7,34,4,164,5,108,0,29,5,35,0,170,0,89,4,252,5,26,1,221,2,225,4,3,6,36,2,151,4,8,3,201,5,221,3,232,4,141,4,203,4,72,5,111,3,148,0,110,3,138,5,153,2,151,7,125,5,200,7,95,7,33,3,49,4,69,0,49,1,67,5,134,4,206,1,123,4,127,5,143,3,117,7,221,1,74,3,119,1,216,4,52,6,140,4,229,2,238,5,85,2,68,6,86,4,83,6,233,1,202,0,46,7,118,5,16,7,171,6,170,4,251,4,105,5,65,5,9,3,217,1,20,7,93,3,87,7,120,2,239,7,236,2,104,6,215,6,53,3,45,6,182,3,180,5,118,6,108,4,226,0,188,5,189,7,127,0,103,2,142,6,73,6,33,7,63,5,38,2,205,0,194,6,18,3,185,1,29,1,62,5,2,6,189,6,97,5,156,1,42,6,53,1,81,6,158,0,200,3,55,2,4,2,16,6,152,7,144,6,165,5,243,5,248,0,64,5,20,6,76,1,209,5,15,0,2,4,185,4,131,5,198,5,30,2,87,4,246,3,126,0,22,2,177,4,105,3,107,0,127,3,145,0,128,5,26,6,207,1,178,4,196,2,191,1,140,3,255,0,20,3,216,7,111,2,169,7,30,3,242,2,202,7,45,1,1,1,78,5,46,3,145,7,161,4,109,7,185,6,77,3,97,0,156,6,187,6,29,4,113,5,17,7,57,3,187,5,225,1,128,6,38,0,50,0,63,2,36,5,41,3,136,4,201,2,248,7,67,0,221,0,196,5,137,5,241,6,200,4,11,0,130,7,112,6,184,6,150,1,212,1,61,4,15,1,110,5,48,0,101,1,89,5,182,6,239,4,125,6,93,1,111,5,237,2,162,7,74,0,193,4,163,7,228,2,17,1,248,5,37,7,133,6,188,3,251,1,163,5,120,1,147,2,166,3,169,3,54,0,171,7,125,0,201,4,161,5,183,5,157,1,60,1,25,5,238,0,87,1,168,5,62,2,175,2,46,6,91,2,133,7,61,7,114,1,190,3,237,7,230,4,94,1,231,5,17,2,77,4,130,6,219,7,182,5,15,4,32,0,245,0,192,7,9,6,242,5,207,6,139,0,86,2,20,5,153,7,210,5,226,1,39,7,229,7,121,2,12,3,28,1,10,3,143,5,223,0,60,0,119,5,239,5,194,7,90,5,177,5,118,7,93,6,170,2,37,2,219,3,118,2,165,6,236,5,41,2,202,5,19,5,168,1,14,3,131,7,253,3,36,1,53,5,63,1,76,6,163,1,7,6,47,0,229,0,1,7,76,2,92,4,102,5,209,6,53,0,68,0,85,4,66,0,14,2,232,7,103,7,250,2,118,4,3,0,191,2,122,3,212,5,71,2,96,6,240,1,214,2,109,3,100,5,194,3,123,3,244,2,122,1,167,4,118,1,212,3,154,5,131,3,88,2,142,0,152,0,40,5,44,6,47,7,94,3,181,0,109,5,240,6,74,4,35,7,93,4,235,4,85,0,133,2,237,0,130,1,41,4,147,3,112,4,85,5,164,3,120,0,162,1,58,4,108,1,94,6,135,0,243,7,78,7,115,2,134,3,218,6,80,5,95,2,6,2,57,0,163,2,230,2,153,1,203,1,69,4,192,4,106,0,76,5,22,3,216,0,65,7,148,1,92,0,6,6,62,4,0,1,26,2,60,4,196,4,147,6,225,5,211,1,64,2,13,2,51,4,150,7,56,2,101,7,175,4,235,0,225,7,80,0,238,4,213,2,94,7,162,5,190,5,10,7,207,3,118,3,5,0,30,6,2,0,205,5,105,0,198,0,65,0,132,0,75,6,14,6,104,2,27,5,0,0,100,4,75,3,21,6,215,3,204,5,176,1,51,2,254,7,65,6,58,5,77,2,10,0,42,3,143,1,130,2,73,7,220,3,183,0,185,5,54,3,196,0,235,5,152,3,117,4,216,2,191,5,70,6,24,4,160,5,204,3,49,5,135,1,234,3,188,6,171,1,228,1,157,6,60,6,248,6,243,0,81,2,220,2,72,6,167,6,25,2,49,7,115,5,241,7,112,0,136,1,213,7,54,4,48,7,222,6,125,2,99,1,41,1,3,4,152,2,185,2,109,0,87,3,73,2,179,4,150,2,182,2,180,6,151,6,112,7,132,4,3,3,252,7,218,1,209,2,240,7,121,3,111,1,34,2,143,4,148,3,77,6,141,6,178,3,171,5,226,3,241,5,255,7,155,6,12,5,132,3,85,6,70,3,70,4,234,7,243,4,252,2,177,2,98,5,135,3,255,2,237,4,229,5,217,5,254,6,239,1,86,6,126,4,113,1,103,0,0,6,235,6,70,2,210,4,60,7,5,3,208,1,52,4,216,5,231,6,129,7,44,3,187,2,212,4,182,4,147,4,192,0,191,3,242,4,186,7,116,7,173,6,120,3,196,7,59,6,51,7,82,7,84,4,132,1,76,7,201,3,24,6,136,6,84,0,20,4,196,6,124,0,183,2,199,3,254,2,62,7,81,3,164,4,250,3,228,6,217,6,168,4,254,1,23,5,16,0,211,4,200,6,83,1,128,1,147,5,177,7,165,7,75,2,65,1,36,4,224,7,134,1,5,4,206,2,4,6,37,4,71,4,119,6,155,7,111,7,236,0,205,2,88,3,252,1,183,3,240,0,43,3,204,2,56,1,53,7,154,0,73,5,4,7,32,7,134,7,242,3,136,0,57,6,51,1,176,7,174,4,249,2,7,0,77,5,140,6,9,5,141,0,122,6,67,4,186,0,153,4,111,0,29,7,188,0,149,6,176,3,62,6,52,7,87,0,51,0,161,7,104,0,85,3,157,4,186,5,108,7,117,6,74,5,10,1,23,4,160,3,88,6,223,1,170,7,18,1,193,6,114,3,32,4,72,0,17,0,223,2,2,2,34,6,131,4,230,5,141,2,168,0,36,3,128,3,234,6,73,4,58,2,162,6,102,0,33,0,251,6,232,1,139,4,212,0,102,6,63,3,119,0,15,5,112,3,56,3,106,7,253,2,214,1,162,2,126,7,137,4,173,3,63,7,197,7,123,1,113,4,223,5,170,1,245,2,219,0,214,7,224,6,204,7,69,6,41,7,140,0,151,0,144,7,26,4,220,4,168,7,189,1,31,2,26,0,172,3,19,7,147,1,91,5,157,5,192,1,206,6,100,3,60,3,233,4,123,5,38,4,167,1,28,2,237,1,67,3,154,6,50,7,239,6,92,5,42,7,138,1,249,7,50,4,155,2,179,7,104,4,25,3,254,0,69,2,236,7,190,7,79,2,8,0,0,5,29,3,62,3,23,2,190,6,13,5,48,2,45,0,90,1,106,4,172,1,32,2,174,0,215,1,10,5,88,5,24,7,14,4,33,6,148,5,47,5,122,2,88,7,158,2,208,4,66,6,91,7,86,1,11,2,80,3,157,3,187,0,143,0,24,2,117,0,82,6,124,5,213,6,234,0,120,6,82,0,219,5,180,1,35,4,167,3,223,4,11,5,127,7,158,4,197,0,172,5,158,7,251,3,145,5,250,5,194,0,225,0,85,7,124,6,107,6,10,6,111,6,129,4,103,4,167,7,31,6,122,5,126,1,95,0,240,5,247,7,215,0,115,7,94,0,226,7,229,6,89,6,231,4,56,7,74,2,44,1,124,7,191,4,90,4,159,6,253,7,158,6,41,5,159,1,186,2,177,0,39,6,18,4,91,6,246,2,105,2,66,3,179,2,145,2,252,0,218,3,47,1,227,4,146,5,250,0,99,4,188,7,128,7,31,1,255,4,172,7,143,2,117,1,239,0,214,6,234,4,39,5,238,3,247,0,185,0,17,3,124,2,37,0,195,2,26,7,175,6,144,1,30,1,136,5,142,7,198,6,71,1,174,3,120,5,172,6,252,4,82,2,199,7,59,4,87,5,227,7,208,2,61,6,156,7,43,6,64,6,35,1,227,6,6,3,122,7,171,4,135,7,33,4,220,1,144,3,174,1,243,1,5,7,210,7,129,0,225,2,233,5,254,5,135,6,161,2,156,5,165,0,35,2,141,7,95,3,195,7,38,3,117,5,72,3,21,7,179,6,147,7,244,6,184,7,100,0,16,2,192,2,121,5,34,0,175,3,74,7,0,2,169,1,93,7,206,7,44,7,159,7,92,7,157,0,221,4,226,2,230,7,127,1,22,7,112,5,222,7,23,0,110,7,79,5,98,3,154,2,34,5,179,1,42,2,114,5,209,3,8,4,55,4,203,3,220,6,140,5,166,6,125,3,59,5,182,1,191,7,232,5,67,1,137,2,146,3,43,2,251,5,173,5,29,0,193,2,108,2,107,7,13,7,79,4,252,6,157,7,202,4,80,4,79,3,231,3,194,1,100,6,208,3,1,0,173,7,243,6,89,3,68,5,127,6,99,5,212,6,8,1,142,4,240,3,79,0,34,3,205,6,212,2,151,5,159,0,47,6,228,5,139,2,129,6,49,2,48,6,21,3,139,6,89,0,206,3,107,3,84,6,122,4,156,2,191,6,113,0,204,6,167,2,51,3,4,3,248,1,231,0,153,5,116,1,96,0,116,6,236,6,187,7,136,2,238,6,55,7,76,3,23,6,188,4,213,5,140,7,101,4,38,1,38,6,39,5,161,1,246,2,35,5,151,2,5,0,65,1,180,3,57,5,148,7,221,6,152,4,155,5,25,1,219,5,49,6,241,2,101,5,9,4,88,1,214,2,110,1,113,5,185,0,67,5,43,5,104,6,192,0,253,5,22,2,234,5,78,2,75,1,155,0,209,6,245,2,145,5,180,0,168,0,74,6,155,3,217,0,54,3,161,2,96,4,104,0,180,7,135,1,154,5,240,2,205,5,129,1,247,7,51,7,35,2,129,5,197,4,212,1,27,1,42,2,136,6,56,7,48,1,2,2,46,1,3,2,62,3,208,4,189,2,196,0,66,0,20,6,194,6,133,3,237,3,226,7,187,2,239,2,225,3,84,6,63,7,71,4,95,1,29,4,32,3,90,0,244,2,22,1,214,1,194,0,193,4,243,0,148,6,143,2,92,1,37,1,67,3,145,2,59,3,30,2,49,0,250,4,107,7,51,1,3,5,232,4,156,1,198,3,74,2,181,0,223,1,30,7,237,5,100,5,72,6,215,5,194,5,164,4,14,3,80,7,116,4,31,1,162,4,187,3,76,6,88,2,199,4,134,5,113,0,98,3,147,5,82,2,176,2,170,5,83,0,71,0,239,6,105,6,232,6,17,0,147,0,67,4,60,3,96,0,17,2,211,7,200,4,38,4,193,1,232,2,251,1,26,5,2,4,159,4,25,5,199,1,150,0,230,4,121,2,85,4,172,7,166,3,175,4,54,7,203,1,92,4,117,2,140,1,118,7,224,6,212,5,156,5,16,2,88,3,79,6,207,2,244,0,7,3,119,5,186,7,150,2,246,0,163,1,157,0,197,2,50,5,189,7,108,2,113,1,39,7,186,5,218,2,123,3,7,7,102,3,14,1,70,3,7,1,10,2,177,4,45,1,11,1,3,6,136,7,247,2,218,6,139,2,141,0,255,3,230,1,164,2,159,3,84,4,18,1,236,2,65,4,250,0,84,0,229,3,162,3,236,1,34,3,62,5,19,4,181,5,88,0,81,7,122,2,167,3,209,2,109,1,243,3,245,5,62,1,34,1,254,1,105,0,221,7,19,2,36,4,111,3,245,6,14,2,49,4,178,5,94,2,1,6,105,1,169,1,205,1,227,2,158,3,56,3,229,7,229,5,177,7,220,3,100,4,101,0,85,2,70,2,28,7,92,5,247,3,246,5,200,0,180,1,72,1,132,2,159,6,127,1,205,4,212,6,63,6,202,7,138,2,95,7,223,2,8,7,66,4,14,0,64,1,87,4,79,1,58,6,32,4,62,2,114,6,64,4,22,7,202,3,187,1,34,6,103,3,24,0,9,1,193,3,6,2,203,7,46,4,76,4,19,6,30,6,124,6,150,3,109,0,27,0,201,0,15,4,182,4,184,6,133,4,88,7,211,4,27,6,77,3,254,4,166,7,37,0,235,3,58,7,155,7,219,3,18,3,144,1,93,3,178,7,139,7,72,2,16,0,117,0,43,1,69,3,83,7,75,6,99,1,116,3,87,5,216,4,91,2,128,7,121,4,18,0,96,3,28,5,161,3,208,0,32,0,55,1,207,5,197,7,137,1,121,6,82,3,218,7,138,4,139,1,252,5,253,1,68,3,221,4,158,6,97,7,66,5,93,6,91,5,85,7,249,4,39,4,1,5,41,3,242,6,180,2,182,1,25,3,89,4,251,3,223,6,171,4,118,1,253,2,47,6,202,1,179,1,183,1,220,2,116,6,108,5,171,3,40,4,192,6,65,5,61,2,131,2,170,6,203,5,49,2,19,7,20,0,156,7,175,1,242,3,43,3,155,1,210,0,92,2,190,5,197,1,131,3,13,5,228,3,87,6,187,4,232,0,3,4,107,2,78,1,183,3,143,0,27,3,63,4,117,3,202,2,188,6,120,6,61,1,227,0,149,3,255,2,32,1,235,7,48,6,45,5,105,3,106,3,140,5,56,5,74,0,97,4,79,2,23,7,60,7,132,7,159,5,195,0,64,3,118,4,7,2,183,6,28,3,218,0,41,7,192,2,240,7,213,3,122,6,146,0,20,3,79,3,188,2,238,6,42,3,167,1,107,0,11,4,41,0,252,7,8,6,22,3,90,1,19,1,184,3,43,2,69,4,137,3,161,7,116,1,24,2,13,1,155,2,165,4,229,0,95,2,80,2,94,7,196,4,33,7,48,2,216,0,194,3,128,6,95,6,93,2,34,2,77,4,125,5,86,0,127,3,169,4,13,3,222,6,245,7,35,4,249,2,190,3,151,0,128,3,124,2,241,5,186,2,234,1,165,2,98,1,189,0,255,4,250,5,191,3,28,0,174,3,130,6,80,5,106,4,60,1,147,1,203,3,30,0,233,6,58,0,214,6,35,3,90,5,79,7,8,5,241,4,22,6,9,6,179,2,44,3,183,0,132,5,124,7,194,4,18,4,13,2,28,2,248,5,111,2,154,6,13,4,11,5,82,5,0,0,233,4,226,6,34,0,209,5,243,2,67,2,45,2,6,7,4,3,109,7,1,2,224,1,190,7,169,3,116,0,172,1,122,5,84,7,68,2,138,0,37,4,97,5,211,6,143,4,152,2,54,6,96,7,7,5,130,2,19,0,145,0,50,2,103,0,239,1,145,6,232,7,137,4,46,6,137,2,135,4,223,3,98,5,231,3,4,1,64,0,23,1,216,3,241,3,53,1,178,1,204,3,228,0,232,5,92,7,149,5,175,2,47,7,97,3,207,0,202,5,209,3,73,0,2,0,71,3,135,2,55,3,153,7,4,4,188,7,241,0,1,1,103,4,226,1,68,5,149,0,124,3,250,2,99,7,143,3,118,3,34,7,53,0,225,2,142,2,158,0,251,4,109,2,17,6,108,4,231,5,99,5,210,6,36,7,160,2,117,4,77,2,64,2,55,4,200,7,220,1,122,4,86,3,43,7,106,0,101,7,153,4,168,1,176,7,61,7,146,5,73,1,203,4,169,5,225,1,186,4,116,7,182,0,112,5,105,4,148,2,208,2,223,5,163,5,108,1,115,2,185,2,195,6,138,6,198,5,65,0,104,7,227,4,188,0,119,0,26,2,219,2,190,0,6,0,154,7,123,1,236,6,137,6,181,4,113,4,245,0,21,5,131,6,125,4,118,5,222,5,176,3,5,7,118,6,212,7,89,6,44,0,158,4,94,0,45,0,140,6,200,3,185,4,221,5,144,3,240,0,42,4,99,6,129,3,139,4,110,0,190,2,199,0,47,4,44,6,104,5,238,5,18,2,89,5,236,3,185,3,128,1,226,4,233,1,3,3,70,4,135,3,201,6,42,5,61,3,228,7,37,3,255,5,84,5,144,2,117,6,219,7,47,2,120,5,191,5,182,3,183,4,220,7,226,5,143,1,186,1,106,5,140,7,175,6,162,5,73,7,214,4,8,2,0,4,58,4,95,3,134,2,81,2,50,3,48,0,246,6,211,0,134,7,165,3,20,2,135,0,103,6,120,3,158,2,21,0,102,1,206,7,247,1,232,3,156,4,135,7,190,6,111,1,186,0,214,7,88,4,136,4,131,7,207,7,136,5,220,5,196,6,10,7,0,1,253,4,58,1,120,0,21,7,210,1,51,6,45,3,42,7,213,6,253,6,143,7,210,3,195,2,62,0,126,1,5,5,131,5,38,3,234,2,27,5,74,4,77,0,215,3,228,1,171,0,230,3,36,1,177,3,104,3,194,2,198,6,142,6,238,4,213,1,12,0,48,4,26,7,81,6,46,2,15,2,236,4,142,0,146,2,134,0,137,5,53,4,219,6,103,5,105,7,246,4,153,5,56,0,109,3,72,4,247,4,250,3,130,0,192,3,33,0,191,4,185,5,119,2,35,0,34,4,198,0,171,6,229,4,68,0,15,0,58,2,100,6,107,3,251,6,98,4,212,3,236,5,57,4,4,6,76,0,70,5,162,0,76,1,54,4,40,1,99,0,53,7,204,7,16,4,5,1,209,4,85,6,181,1,164,3,186,6,75,0,52,6,198,7,206,1,239,3,26,1,102,0,51,4,103,7,38,5,36,5,122,3,173,5,236,0,220,4,141,3,91,3,178,4,77,5,157,1,114,1,149,4,146,6,69,5,168,6,160,5,100,1,7,4,66,7,69,1,171,1,196,7,133,2,153,2,170,1,107,6,93,5,148,5,155,6,56,1,96,6,99,4,184,5,39,0,157,2,124,5,122,7,129,4,151,7,217,7,50,7,193,7,193,6,22,4,1,7,142,7,149,6,166,4,234,7,79,4,230,7,6,1,217,5,126,5,242,4,121,7,159,7,9,5,181,2,44,2,2,5,8,1,184,0,40,2,98,0,71,1,252,4,23,4,5,2,25,6,11,6,8,3,215,7,238,1,85,5,191,0,152,3,78,0,46,0,97,0,243,4,153,6,130,1,140,4,233,0,184,4,150,1,126,2,222,1,182,2,214,3,119,6,214,0,121,5,0,7,154,1,175,3,141,6,29,5,210,5,30,3,174,4,23,6,248,1,124,4,179,7,227,7,15,5,112,4,163,3,220,6,193,0,110,4,178,6,174,5,225,5,146,4,182,6,77,1,120,1,201,1,152,7,129,7,165,0,59,2,2,7,64,5,69,2,217,3,181,3,234,3,174,6,5,6,222,3,170,0,121,1,201,2,174,2,238,0,160,6,98,2,172,4,204,0,10,6,177,5,205,0,148,1,173,0,108,7,62,7,29,7,235,5,192,7,134,4,203,0,0,2,81,5,198,1,188,3,134,6,150,6,44,1,66,2,33,3,115,3,15,6,53,6,109,5,21,1,230,5,218,4,4,7,141,4,97,2,248,4,23,2,154,4,250,6,133,0,107,5,173,2,90,7,218,5,32,7,144,7,249,1,15,1,94,5,93,0,29,2,72,7,99,2,215,4,113,7,189,3,110,2,126,0,21,4,50,4,235,6,37,5,238,2,3,7,139,0,116,2,16,3,51,5,176,1,31,2,243,5,177,1,144,0,166,5,94,3,173,7,229,6,48,3,176,4,117,1,198,4,13,7,211,2,178,2,139,6,239,5,80,6,3,0,129,0,185,1,111,4,31,0,38,0,205,7,203,2,66,6,166,0,100,7,163,7,142,5,90,4,59,6,237,6,219,1,228,5,141,7,97,6,228,2,81,0,25,7,88,5,253,7,210,4,72,3,32,2,233,5,119,3,52,4,211,5,161,4,122,0,1,3,169,7,63,3,114,3,46,5,130,5,15,7,217,1,144,6,244,6,145,3,132,0,160,4,153,3,175,7,240,6,172,5,246,7,174,1,146,3,123,7,44,5,249,7,231,2,169,0,167,5,160,3,161,6,188,5,252,6,47,3,70,7,189,6,107,1,45,4,54,0,51,2,247,0,36,2,128,4,85,0,101,4,170,4,89,1,254,5,120,4,195,1,54,5,24,5,194,7,67,1,225,7,49,3,151,5,153,1,171,5,213,4,222,2,237,0,220,0,23,3,41,2,219,4,110,7,81,3,193,5,24,6,132,6,75,5,244,1,3,1,83,5,78,6,177,2,113,2,117,7,165,1,57,2,33,5,31,5,47,1,24,4,102,4,52,1,104,4,249,0,91,1,146,1,72,5,188,1,185,6,225,6,17,4,83,6,193,2,240,5,205,6,17,5,175,0,209,7,214,5,189,5,173,3,78,3,26,4,253,0,244,4,58,3,102,6,70,1,221,1,15,3,168,5,84,2,157,6,78,4,44,4,241,1,251,5,125,3,178,3,128,0,216,7,172,2,33,2,173,1,111,6,235,0,230,0,73,6,254,7,162,2,115,6,142,1,53,5,204,5,68,6,147,2,94,6,246,1,115,5,80,1,218,3,55,2,56,2,195,3,91,4,242,1,212,4,61,4,208,1,61,6,41,4,134,3,77,6,109,4,32,6,174,7,83,4,199,2,123,5,151,6,231,6,221,2,227,5,159,0,25,0,27,4,227,6,62,4,99,3,219,0,45,6,65,3,21,2,126,3,233,3,218,1,46,3,71,6,27,2,6,4,147,7,143,5,96,5,178,0,105,5,7,6,205,2,64,6,142,3,138,3,136,3,201,4,82,6,133,1,25,2,191,7,171,7,235,1,114,4,173,4,38,2,254,2,63,5,112,2,57,7,19,3,50,0,243,7,12,7,224,3,169,2,89,2,183,5,140,0,199,3,173,6,93,1,251,2,10,1,93,7,110,6,228,4,250,1,143,6,67,6,184,2,191,6,151,4,255,6,5,4,144,4,112,1,14,5,115,0,147,6,216,1,157,5,60,5,232,1,17,7,64,7,55,6,36,6,94,4,131,4,243,6,154,0,19,5,187,5,76,3,20,4,76,5,7,0,87,7,74,7,163,2,85,3,23,0,46,7,121,3,161,5,163,4,196,2,113,6,49,7,114,5,92,6,208,5,52,0,190,1,31,3,0,3,184,7,210,2,254,0,127,5,251,7,164,6,39,2,96,2,194,1,82,0,239,0,206,5,71,5,16,5,242,0,206,6,172,6,79,0,215,2,213,0,165,5,154,2,86,2,172,3,149,1,72,0,82,7,217,6,6,6,230,2,255,7,92,0,246,3,212,0,35,6,2,6,179,5,138,5,126,7,248,6,245,3,152,6,135,5,138,7,80,4,199,7,233,2,108,6,157,4,29,0,206,2,70,0,209,1,87,3,40,6,24,7,221,0,59,1,133,6,0,6,65,7,114,0,235,4,70,6,31,7,101,1,91,0,62,6,67,0,54,1,109,6,252,0,0,5,248,0,63,2,26,3,90,3,187,7,95,4,16,7,100,2,141,5,242,2,121,0,86,6,84,1,68,4,60,0,42,1,185,7,14,6,21,3,100,3,248,3,37,7,117,5,101,3,170,7,230,6,150,7,9,0,8,0,163,6,171,2,73,5,123,4,167,2,120,7,48,7,39,6,242,7,67,7,168,3,156,3,152,5,127,6,189,1,91,6,27,7,21,6,216,6,127,2,20,7,63,1,208,7,224,0,38,1,24,1,166,2,210,7,207,4,170,2,13,6,221,3,159,1,76,2,37,2,167,6,12,6,238,7,228,6,31,4,234,6,1,0,135,6,204,6,247,6,20,5,12,4,222,4,28,1,154,3,227,1,61,5,39,3,80,0,118,2,50,6,29,1,131,1,197,0,254,3,168,2,11,0,11,3,240,4,157,7,87,2,240,3,94,1,60,4,241,6,16,1,150,5,198,2,197,5,187,0,24,3,125,7,6,3,204,1,103,2,182,5,97,1,81,1,96,1,56,6,244,7,211,1,231,1,82,4,177,6,87,0,151,1,36,3,130,4,51,3,18,7,186,3,162,1,249,3,202,6,153,0,102,2,90,2,122,1,29,6,184,1,86,5,179,4,166,6,172,0,123,6,146,7,106,6,202,0,152,0,77,7,91,7,34,5,41,6,18,5,58,5,59,7,41,5,86,1,90,6,148,0,142,4,55,7,35,1,41,1,192,1,138,1,98,6,236,7,207,6,56,4,203,6,74,1,217,4,40,7,52,5,88,6,108,0,11,7,132,1,252,3,107,4,145,7,101,6,223,7,68,7,253,3,238,3,225,0,148,3,110,5,150,4,10,3,241,7,95,5,169,6,141,2,112,7,252,2,30,4,255,0,4,2,148,4,134,1,200,1,85,1,235,2,40,3,213,5,155,4,12,5,231,0,106,7,53,2,126,4,42,6,251,0,244,3,201,7,128,2,195,4,164,7,86,7,226,0,195,5,75,2,100,0,5,3,226,3,139,3,168,7,29,3,211,3,50,1,237,2,177,0,31,6,43,0,66,3,141,1,10,0,43,6,190,4,44,7,255,1,199,5,222,7,149,2,179,0,89,0,213,7,83,2,11,2,245,1,247,5,125,2,163,0,93,4,248,7,160,1,136,0,59,4,237,1,55,0,249,6,83,1,71,7,105,2,18,6,106,1,101,2,112,3,116,5,4,5,84,3,167,7,183,2,217,2,74,5,160,7,69,7,33,4,52,7,40,5,209,0,113,3,204,4,133,5,123,0,119,4,139,5,205,3,120,2,140,3,59,0,73,3,10,4,231,7,180,6,197,6,158,1,147,4,231,4,168,4,130,3,16,6,45,7,102,5,108,3,200,5,102,7,131,0,75,3,137,7,237,7,176,0,115,1,57,1,68,1,140,2,225,4,12,2,179,3,28,4,191,1,224,2,164,1,240,1,4,0,127,7,239,7,20,1,60,6,74,3,123,2,112,0,224,4,55,5,180,4,39,1,2,3,51,0,127,4,244,5,207,3,196,3,127,0,114,2,2,1,181,6,33,1,22,5,249,5,182,7,118,0,52,3,192,5,226,2,57,3,227,3,176,6,156,6,234,0,111,5,104,1,224,5,103,1,201,3,57,6,145,1,98,7,181,7,149,7,132,3,114,7,206,3,111,7,47,0,60,2,115,7,73,2,200,2,61,0,76,7,111,0,156,0,174,0,162,6,49,1,234,4,252,1,9,3,216,2,208,3,30,5,224,7,9,2,17,1,52,2,26,0,130,7,229,2,6,5,92,3,165,7,204,2,23,5,12,3,215,0,89,7,106,2,206,4,1,4,243,1,12,1,73,4,159,2,180,5,158,7,199,6,40,0,48,5,129,6,151,3,13,0,112,6,213,2,175,5,32,5,164,0,165,6,223,0,35,7,57,0,167,4,129,2,14,7,229,1,222,0,42,0,196,5,119,7,86,4,66,1,81,4,133,7,125,1,147,3,145,4,25,4,208,6,69,6,71,2,30,1,161,0,128,5,115,4,170,3,9,7,124,1,187,6,119,1,47,5,104,2,167,0,202,4,38,6,162,7,78,5,132,4,245,4,189,4,242,5,152,1,223,4,196,1,164,5,212,2,87,1,192,4,65,2,49,5,14,4,75,4,248,2,160,0,215,1,80,3,82,1,125,6,179,6,200,6,136,2,110,3,195,7,33,6,126,6,239,4,183,7,250,7,89,3,8,4,215,6,156,2,201,5,144,5,69,0,197,3,176,5,158,5,206,0,10,5,54,2,166,1,65,6,79,5,28,6,95,0,26,6,78,7,75,7,22,0,254,6,17,3,157,3,237,4,83,3,37,6,188,4,53,3,43,4,216,5,125,0,63,0,137,0,233,7,124,0,207,1,36,0,136,1,59,5,191,2,38,7,24,0,0,0,255,255,1,0,0,0,0,0,0,0,0,0,253,0,26,0,48,45,3,0,24,0,0,0,1,31,0,0,248,10,2,0,24,0,0,0,1,31,1,0,24,4,2,0,24,0,0,0,1,31,2,0,8,234,2,0,24,0,0,0,1,31,3,0,160,236,1,0,24,0,0,0,1,31,4,0,176,224,1,0,24,0,0,0,1,31,5,0,224,209,1,0,24,0,0,0,1,31,6,0,80,198,1,0,24,0,0,0,1,31,7,0,136,189,1,0,24,0,0,0,1,31,8,0,32,182,1,0,24,0,0,0,1,31,9,0,200,174,1,0,24,0,0,0,1,31,10,0,64,167,1,0,24,0,0,0,1,31,11,0,40,160,1,0,24,0,0,0,1,31,12,0,216,149,1,0,24,0,0,0,1,31,13,0,152,140,1,0,24,0,0,0,1,31,14,0,72,126,1,0,24,0,0,0,1,31,15,0,40,112,1,0,24,0,0,0,1,31,16,0,64,101,1,0,24,0,0,0,1,31,17,0,24,92,1,0,24,0,0,0,1,31,18,0,160,85,1,0,24,0,0,0,1,31,19,0,48,77,1,0,24,0,0,0,1,31,20,0,224,70,1,0,24,0,0,0,1,31,21,0,80,65,1,0,24,0,0,0,1,31,22,0,40,58,1,0,24,0,0,0,1,31,23,0,56,50,1,0,24,0,0,0,1,31,24,0,232,41,1,0,24,0,0,0,1,31,25,0,224,32,1,0,24,0,0,0,255,255,1,0,0,0,0,0,0,0,0,0,24,0,0,0,255,255,23,0,0,0,0,0,0,0,0,0,24,0,0,0,255,255,24,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,16,0,0,0,24,0,0,0,32,0,0,0,40,0,0,0,48,0,0,0,56,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,0,0,0,0,32,0,0,0,64,0,0,0,96,0,0,0,128,0,0,0,160,0,0,0,192,0,0,0,224,0,0,0,8,0,0,0,12,0,0,0,0,0,0,0,4,0,0,0,24,0,0,0,28,0,0,0,16,0,0,0,20,0,0,0,0,0,0,0,0,0,0,0,35,1,48,18,1,35,18,48,16,50,3,33,50,16,33,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,96,0,0,0,32,0,184,40,2,0,1,0,0,0,72,234,148,0,248,191,2,0,56,250,6,0,1,0,0,0,143,233,148,0,184,160,2,0,184,164,8,0,1,0,0,0,73,234,148,0,64,246,1,0,88,149,7,0,1,0,0,0,207,232,148,0,136,224,1,0,104,28,8,0,1,0,0,0,74,234,148,0,232,209,1,0,248,23,7,0,1,0,0,0,47,232,148,0,144,189,1,0,64,183,7,0,1,0,0,0,75,234,148,0,104,195,5,0,48,19,7,0,1,0,0,0,7,232,148,0,32,245,8,0,56,210,6,0,1,0,0,0,138,233,148,0,192,135,2,0,24,163,6,0,1,0,0,0,139,233,148,0,240,108,2,0,152,122,6,0,1,0,0,0,136,233,148,0,96,82,2,0,192,72,6,0,1,0,0,0,137,233,148,0,32,56,2,0,48,123,2,0,1,0,0,0,140,233,148,0,152,30,2,0,96,69,2,0,1,0,0,0,141,233,148,0,232,10,2,0,176,223,1,0,1,0,0,0,202,232,148,0,72,198,1,0,192,209,1,0,1,0,0,0,203,232,148,0,24,182,1,0,24,198,1,0,1,0,0,0,200,232,148,0,40,167,1,0,120,189,1,0,1,0,0,0,201,232,148,0,200,149,1,0,248,187,8,0,1,0,0,0,204,232,148,0,56,126,1,0,184,179,8,0,1,0,0,0,205,232,148,0,32,101,1,0,192,122,8,0,1,0,0,0,42,232,148,0,208,174,1,0,40,116,8,0,1,0,0,0,43,232,148,0,48,160,1,0,72,110,8,0,1,0,0,0,40,232,148,0,160,140,1,0,184,102,8,0,1,0,0,0,41,232,148,0,56,112,1,0,240,45,8,0,1,0,0,0,44,232,148,0,32,92,1,0,40,38,8,0,1,0,0,0,45,232,148,0,64,77,1,0,248,16,8,0,1,0,0,0,2,232,148,0,32,231,8,0,192,12,8,0,1,0,0,0,3,232,148,0,88,214,8,0,224,5,8,0,1,0,0,0,0,232,148,0,224,202,8,0,144,1,8,0,1,0,0,0,1,232,148,0,72,193,8,0,72,204,7,0,1,0,0,0,4,232,148,0,144,180,8,0,208,196,7,0,1,0,0,0,5,232,148,0,208,164,8,0,88,212,3,0,1,0,0,0,248,221,146,0,40,185,3,0,56,122,5,0,1,0,0,0,76,234,148,0,224,12,8,0,0,105,5,0,1,0,0,0,77,234,148,0,128,176,7,0,152,120,4,0,1,0,0,0,78,234,148,0,248,114,7,0,112,109,5,0,1,0,0,0,79,234,148,0,32,105,5,0,32,77,1,0,1,0,0,0,231,231,148,0,216,70,1,0,0,0,0,0,4,0,0,0,16,0,0,0,20,0,0,0,32,0,0,0,36,0,0,0,48,0,0,0,52,0,0,0,0,2,0,0,4,2,0,0,16,2,0,0,20,2,0,0,32,2,0,0,36,2,0,0,48,2,0,0,52,2,0,0,0,0,0,0,32,0,0,0,64,0,0,0,96,0,0,0,128,0,0,0,160,0,0,0,192,0,0,0,224,0,0,0,8,0,0,0,12,0,0,0,0,0,0,0,4,0,0,0,24,0,0,0,28,0,0,0,16,0,0,0,20,0,0,0,0,0,0,0,32,0,0,0,64,0,0,0,96,0,0,0,128,0,0,0,160,0,0,0,192,0,0,0,224,0,0,0,0,1,0,0,32,1,0,0,64,1,0,0,96,1,0,0,128,1,0,0,160,1,0,0,192,1,0,0,224,1,0,0,0,0,0,0,4,0,0,0,0,0,32,0,4,0,32,0,8,0,0,0,12,0,0,0,8,0,32,0,12,0,32,0,16,0,0,0,20,0,0,0,16,0,32,0,20,0,32,0,24,0,0,0,28,0,0,0,24,0,32,0,28,0,32,0,0,0,0,0,0,0,0,0,24,38,7,0,1,0,0,0,239,34,216,0,184,160,2,0,56,210,6,0,1,0,0,0,232,34,216,0,192,135,2,0,24,163,6,0,1,0,0,0,233,34,216,0,240,108,2,0,152,122,6,0,1,0,0,0,234,34,216,0,96,82,2,0,192,72,6,0,1,0,0,0,235,34,216,0,32,56,2,0,136,30,2,0,1,0,0,0,238,34,216,0,152,30,2,0,224,19,2,0,1,0,0,0,236,34,216,0,232,10,2,0,216,10,2,0,1,0,0,0,237,34,216,0,152,138,8,0,208,39,5,0,1,0,0,0,242,34,216,0,48,119,7,0,192,230,4,0,1,0,0,0,241,34,216,0,112,109,7,0,72,162,4,0,1,0,0,0,240,34,216,0,24,133,7,0,48,105,4,0,1,0,0,0,243,34,216,0,96,78,4,0,144,236,1,0,1,0,0,0,223,34,216,0,136,224,1,0,176,223,1,0,1,0,0,0,216,34,216,0,72,198,1,0,192,209,1,0,1,0,0,0,217,34,216,0,24,182,1,0,24,198,1,0,1,0,0,0,218,34,216,0,40,167,1,0,120,189,1,0,1,0,0,0,219,34,216,0,200,149,1,0,184,155,8,0,1,0,0,0,222,34,216,0,56,126,1,0,136,149,8,0,1,0,0,0,220,34,216,0,32,101,1,0,216,142,8,0,1,0,0,0,221,34,216,0,96,32,8,0,0,86,3,0,1,0,0,0,226,34,216,0,16,68,7,0,224,85,3,0,1,0,0,0,225,34,216,0,240,58,7,0,208,85,3,0,1,0,0,0,224,34,216,0,200,42,1,0,80,85,3,0,1,0,0,0,227,34,216,0,24,60,1,0,72,126,8,0,1,0,0,0,207,34,216,0,144,189,1,0,192,122,8,0,1,0,0,0,200,34,216,0,208,174,1,0,40,116,8,0,1,0,0,0,201,34,216,0,48,160,1,0,72,110,8,0,1,0,0,0,202,34,216,0,160,140,1,0,184,102,8,0,1,0,0,0,203,34,216,0,56,112,1,0,232,60,1,0,1,0,0,0,206,34,216,0,32,92,1,0,152,58,1,0,1,0,0,0,204,34,216,0,64,77,1,0,128,57,1,0,1,0,0,0,205,34,216,0,112,157,4,0,104,83,3,0,1,0,0,0,210,34,216,0,176,194,6,0,16,83,3,0,1,0,0,0,209,34,216,0,168,22,1,0,24,82,3,0,1,0,0,0,208,34,216,0,104,20,1,0,192,81,3,0,1,0,0,0,211,34,216,0,32,40,1,0,160,19,8,0,1,0,0,0,191,34,216,0,32,245,8,0,248,16,8,0,1,0,0,0,184,34,216,0,32,231,8,0,192,12,8,0,1,0,0,0,185,34,216,0,88,214,8,0,224,5,8,0,1,0,0,0,186,34,216,0,224,202,8,0,144,1,8,0,1,0,0,0,187,34,216,0,72,193,8,0,128,42,1,0,1,0,0,0,190,34,216,0,144,180,8,0,32,41,1,0,1,0,0,0,188,34,216,0,208,164,8,0,192,39,1,0,1,0,0,0,189,34,216,0,160,152,4,0,152,78,3,0,1,0,0,0,194,34,216,0,40,184,6,0,24,78,3,0,1,0,0,0,193,34,216,0,128,8,1,0,232,77,3,0,1,0,0,0,192,34,216,0,48,7,1,0,144,77,3,0,1,0,0,0,195,34,216,0,40,17,1,0,88,212,3,0,1,0,0,0,176,34,216,0,40,185,3,0,72,65,1,0,9,0,0,0,248,34,216,0,32,58,1,0,48,50,1,0,9,0,0,0,249,34,216,0,32,58,1,0,0,0,0,0,0,0,0,0,234,3,0,0,6,1,0,0,220,3,0,0,122,3,0,0,78,12,0,0,112,4,0,0,80,38,0,0,190,3,0,0,112,32,0,0,250,24,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,128,0,0,0,192,0,0,0,0,1,0,0,64,1,0,0,128,1,0,0,192,1,0,0,0,2,0,0,64,2,0,0,128,2,0,0,192,2,0,0,0,3,0,0,64,3,0,0,128,3,0,0,192,3,0,0,12,0,0,0,8,0,0,0,4,0,0,0,0,0,0,0,28,0,0,0,24,0,0,0])
.concat([20,0,0,0,16,0,0,0,44,0,0,0,40,0,0,0,36,0,0,0,32,0,0,0,60,0,0,0,56,0,0,0,52,0,0,0,48,0,0,0,0,0,0,0,32,0,0,0,64,0,0,0,96,0,0,0,128,0,0,0,160,0,0,0,192,0,0,0,224,0,0,0,0,2,0,0,32,2,0,0,64,2,0,0,96,2,0,0,128,2,0,0,160,2,0,0,192,2,0,0,224,2,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,0,1,0,0,1,1,0,0,2,1,0,0,3,1,0,0,4,1,0,0,5,1,0,0,6,1,0,0,7,1,0,0,0,0,48,0,0,0,32,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,255,0,0,0,0,0,0,0,12,12,0,0,172,12,0,0,66,13,0,0,162,13,0,0,234,14,0,0,46,17,0,0,0,19,0,0,250,19,0,0,154,21,0,0,48,22,0,0,154,16,0,0,0,23,0,0,80,23,0,0,6,24,0,0,214,24,0,0,68,26,0,0,82,27,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,5,0,48,45,3,0,23,0,0,0,1,255,1,0,8,202,1,0,23,0,0,0,1,255,2,0,56,50,1,0,23,0,0,0,1,255,4,0,192,20,3,0,23,0,0,0,1,255,8,0,80,65,1,0,23,0,0,0,1,255,0,0,224,32,1,0,0,0,0,0,109,97,100,111,117,32,111,117,32,103,114,97,110,122,111,114,116,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,102,17,4,31,0,0,16,1,100,97,105,109,97,107,97,105,32,109,117,114,97,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,237,168,134,180,0,0,16,1,98,97,116,116,108,101,32,97,99,101,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,175,19,59,0,0,16,1,64,3,0,0,214,15,0,0,100,7,0,0,24,9,0,0,34,5,0,0,84,3,0,0,30,0,0,0,224,10,0,0,6,10,0,0,246,3,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,255,255,1,0,0,0,0,0,0,0,0,0,254,0,2,0,48,45,3,0,23,0,0,0,1,255,0,0,176,20,3,0,23,0,0,0,1,255,1,0,224,32,1,0,119,111,114,108,100,32,99,105,114,99,117,105,116,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,46,234,238,179,0,0,16,1,119,97,105,32,119,97,105,32,109,97,104,106,111,110,103,32,45,32,121,117,107,97,105,110,97,32,106,97,110,121,117,117,32,116,97,99,104,105,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,110,119,160,162,0,0,16,1,118,105,111,108,101,110,116,32,115,111,108,100,105,101,114,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,54,107,195,27,0,0,16,1,118,105,103,105,108,97,110,116,101,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,224,79,18,228,0,0,16,1,118,105,99,116,111,114,121,32,114,117,110,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,255,140,226,3,0,0,16,1,119,97,108,107,117,101,114,101,32,110,111,32,100,101,110,115,101,116,115,117,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,120,57,48,163,0,0,16,1,117,115,97,32,112,114,111,32,98,97,115,107,101,116,98,97,108,108,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,127,75,173,28,0,0,16,1,116,118,32,115,112,111,114,116,115,32,104,111,99,107,101,121,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,144,152,82,231,0,0,16,1,116,118,32,115,112,111,114,116,115,32,102,111,111,116,98,97,108,108,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,138,144,141,150,0,0,16,1,116,118,32,115,112,111,114,116,115,32,98,97,115,107,101,116,98,97,108,108,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,6,182,16,0,0,16,1,116,115,117,112,112,97,114,105,32,111,111,122,117,109,111,117,32,45,32,104,101,105,115,101,105,32,98,97,110,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,16,226,166,97,0,0,16,1,116,111,121,32,115,104,111,112,32,98,111,121,115,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,154,238,197,151,0,0,16,1,116,111,114,97,32,101,32,110,111,32,109,105,99,104,105,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,22,59,174,130,0,0,16,1,116,105,109,101,32,99,114,117,105,115,101,32,105,105,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,106,29,236,207,0,0,16,1,116,101,114,114,97,32,99,114,101,115,116,97,32,105,105,32,45,32,109,97,110,100,111,114,97,97,32,110,111,32,103,121,97,107,117,115,104,117,117,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,119,0,45,27,0,0,16,1,116,97,116,115,117,110,111,107,111,32,102,105,103,104,116,101,114,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,67,221,182,238,0,0,16,1,116,97,116,115,117,106,105,110,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,117,130,8,166,0,0,16,1,116,97,107,97,104,97,115,104,105,32,109,101,105,106,105,110,32,110,111,32,115,104,105,110,32,98,111,117,107,101,110,106,105,109,97,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,25,234,21,228,0,0,16,1,115,116,114,97,116,101,103,111,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,86,70,127,114,0,0,16,1,115,112,105,114,97,108,32,119,97,118,101,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,208,13,41,165,0,0,16,1,115,112,105,110,32,112,97,105,114,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,89,244,111,28,0,0,16,1,115,112,97,99,101,32,105,110,118,97,100,101,114,115,32,45,32,102,117,107,107,97,116,115,117,32,110,111,32,104,105,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,179,109,73,153,0,0,16,1,115,111,108,100,105,101,114,32,98,108,97,100,101,32,115,112,101,99,105,97,108,32,45,32,99,97,114,97,118,97,110,32,115,116,97,103,101,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,237,56,159,243,0,0,16,1,115,111,108,100,105,101,114,32,98,108,97,100,101,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,43,177,32,132,0,0,16,1,115,105,110,100,105,98,97,100,32,99,104,105,116,101,105,32,110,111,32,100,97,105,32,109,97,107,121,117,117,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,189,238,196,181,0,0,16,1,115,105,100,101,97,114,109,115,32,45,32,104,121,112,101,114,32,100,121,110,101,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,183,184,231,229,0,0,16,1,107,97,105,122,111,117,32,99,104,111,117,106,105,110,32,115,104,117,98,105,98,105,110,109,97,110,32,50,32,45,32,97,114,97,116,97,110,97,114,117,32,116,101,107,105,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,116,164,155,16,0,0,16,1,116,97,107,101,100,97,32,115,104,105,110,103,101,110,32,40,106,97,112,97,110,41,32,91,97,93,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,28,247,122,223,0,0,16,1,115,112,97,99,101,32,104,97,114,114,105,101,114,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,4,88,100,0,0,16,1,115,104,97,110,103,104,97,105,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,54,215,35,105,0,0,16,1,115,101,110,103,111,107,117,32,109,97,104,106,111,110,103,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,73,191,230,144,0,0,16,1,115,101,107,105,103,97,104,97,114,97,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,81,80,149,46,0,0,16,1,115,97,108,97,109,97,110,100,101,114,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,32,206,236,250,0,0,16,1,115,97,105,103,111,32,110,111,32,110,105,110,100,111,117,32,45,32,110,105,110,106,97,32,115,112,105,114,105,116,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,86,161,144,5,0,0,16,1,114,97,99,105,110,103,32,100,97,109,97,115,104,105,105,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,76,115,121,62,0,0,16,1,114,97,98,105,111,32,108,101,112,117,115,32,115,112,101,99,105,97,108,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,230,61,55,216,0,0,16,1,112,117,122,122,108,101,32,98,111,121,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,135,225,166,250,0,0,16,1,112,114,111,32,121,97,107,121,117,117,32,119,111,114,108,100,32,115,116,97,100,105,117,109,32,39,57,49,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,169,103,177,102,0,0,16,1,107,111,114,101,32,103,97,32,112,114,111,32,121,97,107,121,117,117,32,39,57,48,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,41,178,114,23,0,0,16,1,107,111,114,101,32,103,97,32,112,114,111,32,121,97,107,121,117,117,32,39,56,57,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,55,1,246,68,0,0,16,1,112,111,119,101,114,32,103,97,116,101,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,59,110,139,190,0,0,16,1,112,111,112,117,108,111,117,115,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,106,149,60,8,0,0,16,1,112,99,32,103,101,110,106,105,110,32,51,32,45,32,112,105,116,104,101,99,97,110,116,104,114,111,112,117,115,32,99,111,109,112,117,116,101,114,117,114,117,115,32,40,116,97,105,107,101,110,98,97,110,41,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,1,211,110,111,0,0,16,1,112,97,114,111,100,105,117,115,32,100,97,33,32,45,32,115,104,105,110,119,97,32,107,97,114,97,32,111,119,97,114,97,105,32,104,101,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,249,24,119,100,0,0,16,1,112,97,114,97,110,111,105,97,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,230,224,147,152,0,0,16,1,112,97,99,104,105,111,32,107,117,110,32,45,32,106,117,117,98,97,110,32,115,104,111,117,98,117,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,124,253,72,65,0,0,16,1,111,118,101,114,114,105,100,101,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,98,197,78,183,0,0,16,1,110,105,110,106,97,32,114,121,117,117,107,101,110,32,100,101,110,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,172,59,87,103,0,0,16,1,110,105,110,106,97,32,119,97,114,114,105,111,114,115,44,32,116,104,101,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,157,205,224,150,0,0,16,1,106,97,99,107,32,110,105,99,107,108,97,117,115,39,32,103,114,101,97,116,101,115,116,32,49,56,32,104,111,108,101,115,32,111,102,32,109,97,106,111,114,32,99,104,97,109,112,105,111,110,115,104,105,112,32,103,111,108,102,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,130,30,117,234,0,0,16,1,110,104,107,32,116,97,105,103,97,32,100,114,97,109,97,32,45,32,116,97,105,104,101,105,107,105,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,213,48,36,163,0,0,16,1,110,101,117,116,111,112,105,97,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,17,239,73,156,0,0,16,1,110,101,117,116,111,112,105,97,32,105,105,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,220,174,148,43,0,0,16,1,110,101,107,107,101,116,115,117,32,107,111,117,107,111,117,32,100,111,100,103,101,98,97,108,108,32,98,117,32,45,32,115,111,99,99,101,114,32,112,99,32,104,101,110,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,109,92,40,242,0,0,16,1,110,101,107,107,101,116,115,117,32,107,111,117,107,111,117,32,100,111,100,103,101,98,97,108,108,32,98,117,32,45,32,112,99,32,98,97,110,103,97,105,32,104,101,110,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,99,184,253,101,0,0,16,1,110,101,99,116,97,114,105,115,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,59,69,67,2,0,0,16,1,110,101,99,114,111,109,97,110,99,101,114,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,230,154,16,83,0,0,16,1,110,97,122,111,32,110,111,32,109,97,115,99,97,114,97,100,101,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,90,216,65,4,0,0,16,1,109,111,116,111,32,114,111,97,100,101,114,32,105,105,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,95,110,127,11,0,0,16,1,109,111,116,111,32,114,111,97,100,101,114,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,205,54,143,66,0,0,16,1,109,111,114,105,116,97,32,115,104,111,117,103,105,32,112,99,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,224,239,70,37,0,0,16,1,109,111,109,111,116,97,114,111,117,32,100,101,110,115,101,116,115,117,32,116,117,114,98,111,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,166,33,82,98,0,0,16,1,109,111,109,111,116,97,114,111,117,32,107,97,116,115,117,103,101,107,105,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,233,67,95,52,0,0,16,1,109,111,110,115,116,101,114,32,112,117,114,111,114,101,115,117,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,37,109,228,242,0,0,16,1,109,97,104,106,111,110,103,32,104,97,111,117,32,100,101,110,32,45,32,107,97,105,115,101,114,39,115,32,113,117,101,115,116,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,149,200,16,223,0,0,16,1,109,97,104,106,111,110,103,32,103,111,107,117,117,32,115,112,101,99,105,97,108,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,86,20,134,248,0,0,16,1,109,97,104,106,111,110,103,32,103,97,107,117,101,110,32,45,32,116,111,117,109,97,32,115,111,117,115,104,105,114,111,117,32,116,111,117,106,111,117,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,85,13,185,245,0,0,16,1,109,97,104,106,111,110,103,32,103,97,107,117,101,110,32,109,105,108,100,32,45,32,116,111,117,109,97,32,115,111,117,115,104,105,114,111,117,32,116,111,117,106,111,117,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,134,20,244,0,0,16,1,109,105,122,117,98,97,107,117,32,100,97,105,32,98,111,117,107,101,110,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,141,85,239,178,0,0,16,1,109,101,116,97,108,32,115,116,111,107,101,114,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,238,43,160,37,0,0,16,1,109,97,110,105,97,99,32,112,117,114,111,114,101,115,117,32,45,32,97,115,117,32,101,32,110,111,32,116,97,116,97,107,97,105,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,92,134,242,153,0,0,16,1,109,97,107,121,111,117,32,100,101,110,115,101,116,115,117,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,70,175,197,212,0,0,16,1,109,97,107,97,105,32,112,114,105,110,99,101,32,100,111,114,97,98,111,99,99,104,97,110,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,51,179,1,177,0,0,16,1,109,97,107,97,105,32,104,97,107,107,101,110,32,100,101,110,32,115,104,97,100,97,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,245,238,98,190,0,0,16,1,109,97,103,105,99,97,108,32,99,104,97,115,101,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,140,191,14,221,0,0,16,1,98,111,117,107,101,110,32,100,97,110,115,104,97,107,117,32,100,111,110,32,45,32,116,104,101,32,108,111,115,116,32,115,117,110,104,101,97,114,116,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,148,159,77,143,0,0,16,1,108,97,100,121,32,115,119,111,114,100,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,236,100,247,198,0,0,16,1,107,121,117,117,107,121,111,107,117,32,109,97,104,106,111,110,103,32,45,32,105,100,111,108,32,103,114,97,112,104,105,99,115,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,62,224,221,2,0,0,16,1,107,121,117,117,107,121,111,107,117,32,109,97,104,106,111,110,103,32,105,105,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,229,179,182,229,0,0,16,1,107,110,105,103,104,116,32,114,105,100,101,114,32,115,112,101,99,105,97,108,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,108,17,20,198,0,0,16,1,107,105,110,103,32,111,102,32,99,97,115,105,110,111,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,142,120,82,191,0,0,16,1,107,105,99,107,98,97,108,108,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,123,54,60,126,0,0,16,1,107,97,116,111,32,99,104,97,110,32,38,32,107,101,110,32,99,104,97,110,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,231,197,105,96,0,0,16,1,106,117,117,111,117,107,105,32,40,106,97,112,97,110,41,32,91,97,93,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,130,137,98,106,0,0,16,1,106,105,103,111,107,117,32,109,101,103,117,114,105,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,235,62,125,204,0,0,16,1,105,109,97,103,101,32,102,105,103,104,116,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,95,86,12,168,0,0,16,1,105,100,111,108,32,104,97,110,97,102,117,100,97,32,102,97,110,32,99,108,117,98,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,108,252,198,158,0,0,16,1,104,97,110,105,105,32,105,110,32,116,104,101,32,115,107,121,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,199,44,62,191,0,0,16,1,104,97,110,105,105,32,111,110,32,116,104,101,32,114,111,97,100,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,134,250,151,152,0,0,16,1,104,97,110,97,32,116,97,97,107,97,32,100,97,107,97,33,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,212,13,77,186,0,0,16,1,103,117,110,104,101,100,32,45,32,104,117,100,115,111,110,32,103,117,110,104,101,100,32,116,97,105,107,97,105,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,174,131,241,87,0,0,16,1,103,101,110,112,101,105,32,116,111,117,109,97,100,101,110,32,110,105,32,110,111,32,109,97,107,105,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,140,117,147,135,0,0,16,1,103,101,110,106,105,32,116,115,117,117,115,104,105,110,32,97,103,101,100,97,109,97,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,252,13,69,173,0,0,16,1,103,101,107,105,115,104,97,32,98,111,121,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,81,45,112,232,0,0,16,1,103,97,110,98,97,114,101,33,32,103,111,108,102,32,98,111,121,115,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,26,209,164,39,0,0,16,1,103,97,108,97,103,97,32,39,56,56,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,198,147,131,26,0,0,16,1,103,97,105,32,102,108,97,109,101,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,236,13,249,149,0,0,16,1,103,97,105,97,32,110,111,32,109,111,110,115,104,111,117,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,124,130,214,111,0,0,16,1,102,111,114,109,97,116,105,111,110,32,115,111,99,99,101,114,32,45,32,104,117,109,97,110,32,99,117,112,32,39,57,48,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,182,231,161,133,0,0,16,1,102,105,114,101,32,112,114,111,32,119,114,101,115,116,108,105,110,103,32,51,32,45,32,108,101,103,101,110,100,32,98,111,117,116,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,8,136,78,83,0,0,16,1,102,105,114,101,32,112,114,111,32,119,114,101,115,116,108,105,110,103,32,50,32,45,32,50,110,100,32,98,111,117,116,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,187,135,137,232,0,0,16,1,102,105,114,101,32,112,114,111,32,119,114,101,115,116,108,105,110,103,32,45,32,99,111,109,98,105,110,97,116,105,111,110,32,116,97,103,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,117,101,237,144,0,0,16,1,102,105,110,97,108,32,98,108,97,115,116,101,114,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,186,113,9,201,0,0,16,1,102,105,110,97,108,32,115,111,108,100,105,101,114,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,175,210,45,175,0,0,16,1,102,105,110,97,108,32,108,97,112,32,116,119,105,110,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,227,132,192,200,0,0,16,1,102,105,103,104,116,105,110,103,32,114,117,110,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,229,210,40,24,0,0,16,1,102,97,110,116,97,115,121,32,122,111,110,101,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,157,15,203,114,0,0,16,1,102,49,32,99,105,114,99,117,115,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,8,238,77,225,0,0,16,1,102,49,32,99,105,114,99,117,115,32,39,57,50,32,45,32,116,104,101,32,115,112,101,101,100,32,111,102,32,115,111,117,110,100,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,162,242,104,178,0,0,16,1,102,49,32,99,105,114,99,117,115,32,39,57,49,32,45,32,119,111,114,108,100,32,99,104,97,109,112,105,111,110,115,104,105,112,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,15,215,207,215,0,0,16,1,116,111,115,104,105,32,116,101,110,115,111,117,32,107,101,105,107,97,107,117,32,45,32,101,116,101,114,110,97,108,32,99,105,116,121,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,45,16,141,177,0,0,16,1,100,117,110,103,101,111,110,32,101,120,112,108,111,114,101,114,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,162,128,26,27,0,0,16,1,100,114,111,112,32,114,111,99,107,32,104,111,114,97,32,104,111,114,97,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,196,94,236,103,0,0,16,1,100,114,97,103,111,110,32,101,103,103,33,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,213,5,36,68,0,0,16,1,100,111,119,110,108,111,97,100,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,32,28,16,133,0,0,16,1,100,97,105,99,104,105,32,107,117,110,32,99,114,105,115,105,115,32,45,32,100,111,32,110,97,116,117,114,97,108,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,95,147,162,97,0,0,16,1,100,105,103,105,116,97,108,32,99,104,97,109,112,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,50,48,186,23,0,0,16,1,100,101,118,105,108,32,99,114,97,115,104,32,45,32,110,97,120,97,116,32,112,105,110,98,97,108,108,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,128,26,200,78,0,0,16,1,100,101,101,112,32,98,108,117,101,32,45,32,107,97,105,116,101,105,32,115,104,105,110,119,97,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,131,15,58,5,0,0,16,1,100,101,97,100,32,109,111,111,110,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,199,155,115,86,0,0,16,1,100,97,105,32,115,101,110,112,117,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,200,188,7,145,0,0,16,1,99,121,98,101,114,32,107,110,105,103,104,116,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,192,250,148,165,0,0,16,1,99,121,98,101,114,32,99,111,114,101,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,106,39,141,169,0,0,16,1,99,121,98,101,114,32,100,111,100,103,101,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,22,107,50,181,0,0,16,1,99,111,114,121,111,111,110,32,45,32,99,104,105,108,100,32,111,102,32,100,114,97,103,111,110,32,40,106,97,112,97,110,41,32,91,97,93,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,137,152,56,213,0,0,16,1,99,105,116,121,32,104,117,110,116,101,114,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,95,5,27,249,0,0,16,1,99,105,114,99,117,115,32,108,105,100,111,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,36,44,33,195,0,0,16,1,103,111,107,117,114,97,107,117,33,32,99,104,117,117,107,97,32,116,97,105,115,101,110,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,44,162,73,231,0,0,16,1,99,104,105,107,117,100,101,110,121,97,32,116,111,117,98,101,105,32,45,32,107,117,98,105,107,105,114,105,32,121,97,107,97,116,97,32,121,111,114,105,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,46,27,178,202,0,0,16,1,99,104,97,109,112,105,111,110,32,119,114,101,115,116,108,101,114,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,234,10,220,158,0,0,16,1,98,117,114,110,105,110,103,32,97,110,103,101,108,115,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,90,192,51,210,0,0,16,1,98,117,108,108,32,102,105,103,104,116,32,45,32,114,105,110,103,32,110,111,32,104,97,106,97,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,145,25,77,92,0,0,16,1,98,117,98,98,108,101,103,117,109,32,99,114,97,115,104,33,32,45,32,107,110,105,103,104,116,32,115,97,98,101,114,115,32,50,48,51,52,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,57,97,118,13,0,0,16,1,99,104,111,117,122,101,116,115,117,32,114,105,110,106,105,110,32,45,32,98,114,97,118,111,109,97,110,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,144,124,245,13,0,0,16,1,98,111,109,98,101,114,109,97,110,32,45,32,117,115,101,114,115,32,98,97,116,116,108,101,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,81,250,137,20,0,0,16,1,98,111,109,98,101,114,109,97,110,32,39,57,52,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,22,37,54,5,0,0,16,1,98,111,109,98,101,114,109,97,110,32,39,57,51,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,208,197,0,179,0,0,16,1,98,111,100,121,32,99,111,110,113,117,101,115,116,32,105,105,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,88,36,217,255,0,0,16,1,110,97,114,97,122,117,109,111,110,111,32,115,101,110,116,97,105,32,98,117,116,97,105,32,45,32,98,108,111,111,100,121,32,119,111,108,102,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,194,112,31,176,0,0,16,1,98,105,107,107,117,114,105,109,97,110,32,119,111,114,108,100,32,40,106,97,112,97,110,41,32,91,97,93,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,145,56,137,52,0,0,16,1,98,97,116,116,108,101,32,108,111,100,101,32,114,117,110,110,101,114,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,69,79,228,89,0,0,16,1,98,97,114,105,32,98,97,114,105,32,100,101,110,115,101,116,115,117,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,93,226,103,194,0,0,16,1,98,97,108,108,105,115,116,105,120,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,170,200,207,138,0,0,16,1,97,116,111,109,105,99,32,114,111,98,111,45,107,105,100,32,115,112,101,99,105,97,108,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,253,94,23,221,0,0,16,1,97,112,112,97,114,101,32,103,97,116,101,98,97,108,108,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,162,203,84,43,0,0,16,1,97,111,105,32,98,108,105,110,107,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,154,155,160,8,0,0,16,1,97,101,114,111,32,98,108,97,115,116,101,114,115,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,129,43,190,37,0,0,16,1,97,100,118,101,110,116,117,114,101,32,105,115,108,97,110,100,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,243,212,113,142,0,0,16,1,97,102,116,101,114,32,98,117,114,110,101,114,32,105,105,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,40,168,114,202,0,0,16,1,0,0,0,0,160,183,37,0,0,183,37,0,96,182,37,0,192,181,37,0,32,181,37,0,128,180,37,0,224,179,37,0,64,179,37,0,160,178,37,0,0,178,37,0,96,177,37,0,192,176,37,0,32,176,37,0,128,175,37,0,224,174,37,0,64,174,37,0,160,173,37,0,112,48,49,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,197,108,15,77,1,0,16,1,116,48,49,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,30,94,66,97,2,0,32,0,97,48,49,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,138,216,59,139,3,0,32,0,97,48,49,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,68,150,158,59,3,0,32,0,97,48,49,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,56,44,158,6,3,0,32,0,97,48,49,48,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,253,163,96,68,3,0,32,0,97,48,49,48,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,86,187,138,95,3,0,32,0,97,48,49,48,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,71,113,122,161,3,0,32,0,98,48,49,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,140,228,210,105,4,0,32,0,98,48,49,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,243,123,88,13,4,0,32,0,98,48,49,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,30,60,130,67,4,0,32,0,109,48,49,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,131,108,195,229,5,0,64,0,112,48,49,48,49,46,49,54,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,30,12,79,178,1,0,16,1,116,48,49,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,30,94,66,97,2,0,32,0,97,48,49,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,138,216,59,139,3,0,32,0,97,48,49,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,68,150,158,59,3,0,32,0,97,48,49,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,56,44,158,6,3,0,32,0,97,48,49,48,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,253,163,96,68,3,0,32,0,97,48,49,48,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,86,187,138,95,3,0,32,0,97,48,49,48,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,71,113,122,161,3,0,32,0,98,48,49,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,140,228,210,105,4,0,32,0,98,48,49,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,243,123,88,13,4,0,32,0,98,48,49,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,30,60,130,67,4,0,32,0,109,48,49,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,131,108,195,229,5,0,64,0,111,108,118,49,49,49,99,104,46,117,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,115,99,184,95,1,0,16,1,111,108,118,49,49,49,99,104,46,117,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,200,9,207,131,1,0,16,1,111,108,118,49,49,49,99,104,46,117,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,175,159,231,110,1,0,16,1,111,108,118,49,49,49,99,104,46,117,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,60,221,13,184,1,0,16,1,116,48,49,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,30,94,66,97,2,0,32,0,97,48,49,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,138,216,59,139,3,0,32,0,97,48,49,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,68,150,158,59,3,0,32,0,97,48,49,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,56,44,158,6,3,0,32,0,97,48,49,48,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,253,163,96,68,3,0,32,0,97,48,49,48,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,86,187,138,95,3,0,32,0,97,48,49,48,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,71,113,122,161,3,0,32,0,98,48,49,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,140,228,210,105,4,0,32,0,98,48,49,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,243,123,88,13,4,0,32,0,98,48,49,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,30,60,130,67,4,0,32,0,109,48,49,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,131,108,195,229,5,0,64,0,111,108,118,49,48,53,107,111,46,117,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,254,3,103,184,1,0,16,1,111,108,118,49,48,53,107,111,46,117,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,57,142,16,90,1,0,16,1,111,108,118,49,48,53,107,111,46,117,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,204,250,18,87,1,0,16,1,111,108,118,49,48,53,107,111,46,117,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,158,77,174,64,1,0,16,1,116,48,49,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,30,94,66,97,2,0,32,0,97,48,49,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,138,216,59,139,3,0,32,0,97,48,49,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,68,150,158,59,3,0,32,0,97,48,49,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,56,44,158,6,3,0,32,0,97,48,49,48,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,253,163,96,68,3,0,32,0,97,48,49,48,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,86,187,138,95,3,0,32,0,97,48,49,48,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,71,113,122,161,3,0,32,0,98,48,49,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,140,228,210,105,4,0,32,0,98,48,49,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,243,123,88,13,4,0,32,0,98,48,49,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,30,60,130,67,4,0,32,0,109,48,49,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,131,108,195,229,5,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,51,54,45,98,105,111,115,46,115,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,150,107,62,133,0,0,16,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,115,109,49,46,115,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,103,109,65,148,0,0,16,3,115,102,105,120,46,115,102,105,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,253,12,234,194,0,0,32,2,48,48,48,45,108,111,46,108,111,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,242,207,134,90,0,0,0,3,13,0,0,0,255,255,0,0,0,0,0,0,14,0,0,0,255,127,0,0,0,0,0,0,15,0,0,0,255,255,134,0,0,0,0,0,0,0,0,0,254,0,2,0,232,159,1,0,13,0,0,0,1,1,0,0,96,135,7,0,13,0,0,0,1,1,1,0,152,182,7,0,0,0,0,0,254,0,2,0,48,140,3,0,13,0,0,0,1,2,0,0,192,255,2,0,13,0,0,0,1,2,2,0,208,75,4,0,0,0,0,0,254,0,2,0,208,161,1,0,13,0,0,0,1,4,0,0,96,135,7,0,13,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,254,0,5,0,192,157,1,0,13,0,0,0,1,56,0,0,168,165,2,0,13,0,0,0,1,56,8,0,216,154,1,0,13,0,0,0,1,56,16,0,144,153,1,0,13,0,0,0,1,56,24,0,248,150,1,0,13,0,0,0,1,56,32,0,72,149,1,0,13,0,0,0,1,56,40,0,192,148,1,0,13,0,0,0,1,56,48,0,72,148,1,0,13,0,0,0,1,56,56,0,224,146,1,0,0,0,0,0,254,0,2,0,40,182,1,0,13,0,0,0,1,64,0,0,96,135,7,0,13,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,248,142,8,0,13,0,0,0,1,128,0,0,96,135,7,0,13,0,0,0,1,128,128,0,152,182,7,0,0,0,0,0,253,0,2,0,0,0,0,0,15,0,0,0,2,4,4,0,56,4,1,0,15,0,0,0,0,48,0,0,0,0,0,0,15,0,0,0,2,4,0,0,184,3,1,0,15,0,0,0,0,48,0,0,0,0,0,0,0,0,0,0,253,0,3,0,48,45,3,0,15,0,0,0,1,3,0,0,176,20,3,0,15,0,0,0,1,3,1,0,160,134,3,0,15,0,0,0,1,3,2,0,248,8,1,0,15,0,0,0,1,3,3,0,176,20,3,0,0,0,0,0,253,0,2,0,40,109,1,0,15,0,0,0,1,128,128,0,64,108,1,0,15,0,0,0,1,128,0,0,120,107,1,0,0,0,0,0,253,0,2,0,56,3,1,0,15,0,0,0,1,64,64,0,80,104,1,0,15,0,0,0,1,64,0,0,248,38,7,0,0,0,0,0,168,86,7,0,1,0,0,0,240,33,216,0,248,191,2,0,24,38,7,0,1,0,0,0,248,33,216,0,184,160,2,0,120,36,5,0,1,0,0,0,249,33,216,0,96,78,4,0,56,210,6,0,1,0,0,0,0,33,216,0,192,135,2,0,24,163,6,0,1,0,0,0,1,33,216,0,240,108,2,0,152,122,6,0,1,0,0,0,2,33,216,0,96,82,2,0,192,72,6,0,1,0,0,0,3,33,216,0,32,56,2,0,136,30,2,0,1,0,0,0,4,33,216,0,152,30,2,0,224,19,2,0,1,0,0,0,5,33,216,0,232,10,2,0,216,10,2,0,1,0,0,0,6,33,216,0,152,138,8,0,248,3,2,0,1,0,0,0,7,33,216,0,48,119,7,0,120,198,7,0,1,0,0,0,0,34,216,0,56,255,0,0,16,150,7,0,1,0,0,0,1,34,216,0,96,254,0,0,160,103,7,0,1,0,0,0,2,34,216,0,184,253,0,0,16,53,7,0,1,0,0,0,3,34,216,0,48,255,8,0,128,9,7,0,1,0,0,0,4,34,216,0,144,253,8,0,32,223,6,0,1,0,0,0,5,34,216,0,16,252,8,0,168,178,6,0,1,0,0,0,6,34,216,0,96,251,8,0,184,135,6,0,1,0,0,0,8,34,216,0,16,251,8,0,160,89,6,0,1,0,0,0,9,34,216,0,64,250,8,0,192,43,6,0,1,0,0,0,10,34,216,0,192,247,8,0,136,1,6,0,1,0,0,0,11,34,216,0,176,245,8,0,216,211,5,0,1,0,0,0,12,34,216,0,120,244,8,0,32,172,5,0,1,0,0,0,13,34,216,0,224,242,8,0,88,136,5,0,1,0,0,0,14,34,216,0,48,242,8,0,192,152,5,0,1,0,0,0,16,34,216,0,160,240,8,0,216,192,5,0,1,0,0,0,17,34,216,0,88,239,8,0,16,24,6,0,1,0,0,0,18,34,216,0,168,237,8,0,192,185,5,0,1,0,0,0,19,34,216,0,40,236,8,0,192,232,5,0,1,0,0,0,20,34,216,0,40,235,8,0,40,246,1,0,1,0,0,0,241,33,216,0,64,246,1,0,144,236,1,0,1,0,0,0,250,33,216,0,136,224,1,0,128,149,1,0,1,0,0,0,251,33,216,0,24,60,1,0,176,223,1,0,1,0,0,0,248,32,216,0,72,198,1,0,192,209,1,0,1,0,0,0,249,32,216,0,24,182,1,0,24,198,1,0,1,0,0,0,250,32,216,0,40,167,1,0,120,189,1,0,1,0,0,0,251,32,216,0,200,149,1,0,184,155,8,0,1,0,0,0,252,32,216,0,56,126,1,0,136,149,8,0,1,0,0,0,253,32,216,0,32,101,1,0,216,142,8,0,1,0,0,0,254,32,216,0,96,32,8,0,40,138,8,0,1,0,0,0,255,32,216,0,16,68,7,0,88,212,3,0,1,0,0,0,200,32,216,0,40,185,3,0,80,251,6,0,1,0,0,0,48,33,216,0,216,70,1,0,16,17,8,0,1,0,0,0,242,33,216,0,224,12,8,0,248,5,8,0,9,0,0,0,12,33,216,0,32,58,1,0,144,250,7,0,9,0,0,0,13,33,216,0,32,58,1,0,208,23,1,0,9,0,0,0,152,32,216,0,32,58,1,0,184,22,1,0,9,0,0,0,128,37,0,0,32,58,1,0,0,22,1,0,9,0,0,0,56,33,216,0,32,58,1,0,120,20,1,0,9,0,0,0,57,33,216,0,32,58,1,0,122,101,114,111,32,119,105,110,103,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,43,61,32,126,33,0,16,0,122,97,110,121,32,103,111,108,102,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,234,18,93,237,33,0,16,0,119,97,99,107,121,32,119,111,114,108,100,115,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,117,103,32,48,56,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,160,62,211,72,33,0,16,0,119,97,99,107,121,32,119,111,114,108,100,115,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,117,103,32,49,55,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,203,15,0,11,151,21,70,33,0,16,0,119,97,99,107,121,32,119,111,114,108,100,115,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,117,103,32,49,57,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,150,203,15,0,37,105,40,127,33,0,16,0,119,114,101,115,116,108,101,32,119,97,114,32,40,106,112,110,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,123,232,222,28,33,0,16,0,119,111,114,108,100,32,111,102,32,105,108,108,117,115,105,111,110,32,115,116,97,114,114,105,110,103,32,109,105,99,107,101,121,32,109,111,117,115,101,32,97,110,100,32,100,111,110,97,108,100,32,100,117,99,107,32,40,117,115,97,44,32,107,111,114,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,28,189,30,146,33,0,16,0,119,111,114,108,100,32,111,102,32,105,108,108,117,115,105,111,110,32,45,32,102,117,115,104,105,103,105,32,110,97,32,109,97,103,105,99,32,98,111,120,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,56,226,158,203,33,0,16,0,119,105,110,116,101,114,32,99,104,97,108,108,101,110,103,101,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,196,168,210,96,33,0,16,0,97,99,119,99,115,103,95,40,49,50,45,57,49,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,28,237,195,219,33,0,16,0,119,105,109,98,108,101,100,111,110,32,99,104,97,109,112,105,111,110,115,104,105,112,32,116,101,110,110,105,115,32,40,117,115,97,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,96,199,235,159,33,0,16,0,119,104,105,112,32,114,117,115,104,32,45,32,119,97,107,117,115,101,105,32,118,111,108,116,101,103,97,115,32,110,111,32,110,97,122,111,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,209,180,132,128,33,0,16,0,118,105,101,119,112,111,105,110])
.concat([116,32,40,117,115,97,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,231,156,230,242,33,0,16,0,118,101,99,116,111,114,109,97,110,32,50,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,117,103,32,49,53,44,32,49,57,57,54,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,124,8,139,153,33,0,16,0,118,101,99,116,111,114,109,97,110,32,50,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,117,103,32,49,54,44,32,49,57,57,54,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,206,229,134,41,33,0,16,0,118,101,99,116,111,114,109,97,110,32,50,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,117,103,32,49,57,44,32,49,57,57,54,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,126,171,239,73,33,0,16,0,118,101,99,116,111,114,109,97,110,32,50,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,117,103,32,50,54,44,32,49,57,57,54,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,70,142,42,0,200,36,129,235,33,0,16,0,118,101,99,116,111,114,109,97,110,32,50,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,117,103,32,50,55,44,32,49,57,57,54,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,154,216,51,99,33,0,16,0,118,101,99,116,111,114,109,97,110,32,50,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,239,176,162,173,33,0,16,0,119,111,114,108,100,32,115,111,99,99,101,114,32,40,112,114,111,116,111,116,121,112,101,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,114,31,69,157,33,0,16,0,116,119,111,32,99,114,117,100,101,32,100,117,100,101,115,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,68,87,27,114,33,0,16,0,116,105,110,121,32,116,111,111,110,32,97,100,118,101,110,116,117,114,101,115,32,45,32,98,117,115,116,101,114,39,115,32,104,105,100,100,101,110,32,116,114,101,97,115,117,114,101,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,224,58,109,162,33,0,16,0,116,105,110,121,32,116,111,111,110,32,97,100,118,101,110,116,117,114,101,115,32,40,107,111,114,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,251,168,163,76,33,0,16,0,116,114,105,112,108,101,32,112,108,97,121,32,103,111,108,100,32,40,117,115,97,41,32,40,97,108,116,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,160,56,150,168,33,0,16,0,116,111,121,32,115,116,111,114,121,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,19,227,159,130,33,0,16,0,116,111,109,32,97,110,100,32,106,101,114,114,121,32,45,32,102,114,97,110,116,105,99,32,97,110,116,105,99,115,32,40,117,115,97,41,32,40,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,12,70,68,48,33,0,16,0,116,105,109,101,32,107,105,108,108,101,114,115,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,172,82,95,75,33,0,16,0,116,101,114,109,105,110,97,116,111,114,44,32,116,104,101,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,190,41,166,49,33,0,16,0,116,101,99,109,111,32,115,117,112,101,114,32,98,111,119,108,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,12,226,198,144,33,0,16,0,116,101,99,109,111,32,115,117,112,101,114,32,98,111,119,108,32,40,117,115,97,41,32,40,115,101,112,116,101,109,98,101,114,32,49,57,57,51,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,238,51,89,189,33,0,16,0,116,101,99,109,111,32,115,117,112,101,114,32,98,111,119,108,32,105,105,32,45,32,115,112,101,99,105,97,108,32,101,100,105,116,105,111,110,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,61,99,251,50,33,0,16,0,116,101,99,109,111,32,115,117,112,101,114,32,110,98,97,32,98,97,115,107,101,116,98,97,108,108,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,182,62,243,121,33,0,16,0,116,97,115,107,32,102,111,114,99,101,32,104,97,114,114,105,101,114,32,101,120,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,237,78,165,233,33,0,16,0,115,121,108,118,101,115,116,101,114,32,97,110,100,32,116,119,101,101,116,121,32,105,110,32,99,97,103,101,121,32,99,97,112,101,114,115,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,107,120,156,157,33,0,16,0,115,119,111,114,100,32,111,102,32,115,111,100,97,110,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,243,179,237,88,33,0,16,0,115,117,112,101,114,32,108,101,97,103,117,101,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,29,203,19,234,33,0,16,0,115,117,112,101,114,109,97,110,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,105,88,58,84,33,0,16,0,115,117,112,101,114,109,97,110,32,40,117,115,97,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,212,225,208,92,33,0,16,0,109,112,114,45,49,50,52,55,55,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,111,22,10,213,33,0,16,0,115,117,98,116,101,114,114,97,110,105,97,32,40,112,114,111,116,111,116,121,112,101,32,45,32,102,101,98,32,48,50,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,148,227,104,179,33,0,16,0,115,117,98,116,101,114,114,97,110,105,97,32,40,98,101,116,97,41,32,40,101,97,114,108,105,101,114,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,0,92,210,19,156,33,0,16,0,115,117,98,116,101,114,114,97,110,105,97,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,209,34,16,58,33,0,16,0,115,116,111,114,109,108,111,114,100,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,237,15,68,11,33,0,16,0,115,116,114,105,100,101,114,32,114,101,116,117,114,110,115,32,45,32,106,111,117,114,110,101,121,32,102,114,111,109,32,100,97,114,107,110,101,115,115,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,121,155,88,66,33,0,16,0,115,116,101,101,108,32,116,97,108,111,110,115,32,40,117,115,97,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,47,5,196,33,0,16,0,115,116,101,101,108,32,116,97,108,111,110,115,32,40,106,112,110,44,32,107,111,114,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,230,136,243,4,33,0,16,0,115,116,97,114,103,97,116,101,32,40,101,117,114,111,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,35,171,200,141,33,0,16,0,115,117,110,115,101,116,32,114,105,100,101,114,115,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,151,194,48,172,33,0,16,0,109,112,114,45,49,50,57,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,26,225,70,67,33,0,16,0,115,112,108,97,116,116,101,114,104,111,117,115,101,32,112,97,114,116,32,51,32,40,106,112,110,44,32,107,111,114,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,34,61,184,49,33,0,16,0,115,112,108,97,116,116,101,114,104,111,117,115,101,32,50,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,233,102,23,45,33,0,16,0,115,104,50,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,27,153,189,173,17,0,16,0,115,112,101,101,100,98,97,108,108,32,50,32,45,32,98,114,117,116,97,108,32,100,101,108,117,120,101,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,167,64,195,159,33,0,16,0,115,112,101,101,100,98,97,108,108,32,50,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,52,35,68,245,33,0,16,0,115,112,97,114,107,115,116,101,114,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,237,20,219,107,33,0,16,0,115,112,97,114,107,115,116,101,114,32,45,32,114,111,99,107,101,116,32,107,110,105,103,104,116,32,97,100,118,101,110,116,117,114,101,115,32,50,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,98,198,78,145,33,0,16,0,115,111,117,108,32,101,100,103,101,32,118,115,32,115,97,109,117,114,97,105,32,115,112,105,114,105,116,115,32,40,117,110,108,41,91,102,49,93,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,167,215,166,116,33,0,16,0,115,111,117,108,32,98,108,97,100,101,32,40,117,110,108,41,91,112,93,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,121,122,28,221,33,0,16,0,115,111,110,105,99,95,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,1,101,216,135,33,0,16,0,115,111,110,105,99,32,106,97,109,32,54,32,40,117,110,108,41,32,40,112,105,114,97,116,101,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,62,201,240,4,33,0,16,0,109,112,114,45,49,56,50,48,51,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,158,199,97,254,17,0,16,0,109,112,114,45,49,56,50,48,52,46,105,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,70,33,212,33,23,0,16,0,115,111,110,105,99,32,116,104,101,32,104,101,100,103,101,104,111,103,32,51,32,40,112,105,114,97,116,101,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,253,246,24,200,33,0,16,0,115,111,110,105,99,32,51,100,32,98,108,97,115,116,32,40,112,114,111,116,111,116,121,112,101,32,55,51,32,45,32,106,117,108,32,48,51,44,32,49,57,57,54,44,32,49,51,46,53,56,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,153,94,183,147,33,0,16,0,115,111,110,105,99,32,51,100,32,98,108,97,115,116,32,40,112,114,111,116,111,116,121,112,101,32,56,49,52,32,45,32,97,117,103,32,49,53,44,32,49,57,57,54,44,32,48,55,46,53,53,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,117,118,78,214,33,0,16,0,115,111,110,105,99,32,51,100,32,98,108,97,115,116,32,40,112,114,111,116,111,116,121,112,101,32,56,49,57,32,45,32,97,117,103,32,49,57,44,32,49,57,57,54,44,32,49,57,46,52,57,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,58,244,67,44,33,0,16,0,115,111,110,105,99,32,51,100,32,98,108,97,115,116,32,40,112,114,111,116,111,116,121,112,101,32,56,50,53,32,45,32,97,117,103,32,50,54,44,32,49,57,57,54,44,32,49,53,46,52,54,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,189,207,91,70,33,0,16,0,115,111,110,105,99,32,51,100,32,98,108,97,115,116,32,40,112,114,111,116,111,116,121,112,101,32,56,51,48,32,45,32,97,117,103,32,51,49,44,32,49,57,57,54,44,32,48,56,46,49,57,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,255,63,0,34,4,100,87,33,0,16,0,115,111,110,105,99,32,51,100,32,98,108,97,115,116,32,40,112,114,111,116,111,116,121,112,101,32,56,51,49,32,45,32,115,101,112,32,48,51,44,32,49,57,57,54,44,32,49,48,46,48,55,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,83,228,51,89,33,0,16,0,115,111,110,105,99,32,51,100,32,98,108,97,115,116,32,40,112,114,111,116,111,116,121,112,101,32,57,52,32,45,32,115,101,112,32,48,52,44,32,49,57,57,54,44,32,49,50,46,48,49,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,113,66,42,47,33,0,16,0,115,111,110,105,99,32,51,100,32,98,108,97,115,116,32,40,117,115,97,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,91,56,15,210,33,0,16,0,115,117,112,101,114,32,109,97,114,105,111,32,119,111,114,108,100,32,54,52,32,40,104,97,99,107,101,100,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,170,152,15,162,33,0,16,0,115,97,116,117,114,100,97,121,32,110,105,103,104,116,32,115,108,97,109,109,97,115,116,101,114,115,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,186,234,180,47,33,0,16,0,115,107,101,108,101,116,111,110,32,107,114,101,119,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,203,90,224,194,33,0,16,0,109,112,114,45,49,53,48,48,56,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,93,39,159,175,33,0,16,0,115,105,100,101,32,112,111,99,107,101,116,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,62,191,107,51,33,0,16,0,115,104,105,110,111,98,105,32,105,105,105,32,45,32,114,101,116,117,114,110,32,111,102,32,116,104,101,32,110,105,110,106,97,32,109,97,115,116,101,114,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,111,80,129,83,33,0,16,0,115,104,105,110,105,110,103,32,102,111,114,99,101,32,40,117,115,97,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,58,20,103,206,33,0,16,0,115,104,105,110,105,110,103,32,102,111,114,99,101,32,45,32,107,97,109,105,103,97,109,105,32,110,111,32,105,115,97,110,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,205,251,120,147,33,0,16,0,115,104,105,110,105,110,103,32,102,111,114,99,101,32,105,105,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,117,224,21,72,33,0,16,0,115,104,105,110,105,110,103,32,102,111,114,99,101,32,105,105,32,45,32,107,111,101,32,110,111,32,102,117,117,105,110,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,225,243,136,2,33,0,16,0,109,112,114,45,49,51,56,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,28,245,106,73,33,0,16,0,109,112,114,45,49,49,57,51,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,40,251,192,237,33,0,16,0,115,104,97,110,103,104,97,105,32,105,105,32,45,32,100,114,97,103,111,110,39,115,32,101,121,101,32,40,98,101,116,97,41,32,40,97,108,116,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,123,134,51,94,33,0,16,0,115,104,97,100,111,119,114,117,110,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,247,153,33,211,33,0,16,0,115,101,110,115,105,98,108,101,32,115,111,99,99,101,114,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,77,102,82,239,33,0,16,0,115,101,103,97,32,99,104,97,110,110,101,108,32,40,103,101,110,101,114,97,108,32,105,110,115,116,114,117,109,101,110,116,115,41,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,17,63,249,93,33,0,16,0,115,101,97,113,117,101,115,116,32,100,115,118,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,128,84,176,37,33,0,16,0,115,104,111,119,32,100,111,32,109,105,108,104,97,111,32,118,111,108,117,109,101,32,50,32,40,98,114,97,41,32,40,97,108,116,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,109,172,201,216,33,0,16,0,115,117,112,101,114,32,100,111,110,107,101,121,32,107,111,110,103,32,57,57,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,119,145,125,142,33,0,16,0,114,111,98,111,99,111,112,32,118,101,114,115,117,115,32,116,104,101,32,116,101,114,109,105,110,97,116,111,114,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,164,119,173,187,33,0,16,0,114,111,98,111,99,111,112,32,118,101,114,115,117,115,32,116,104,101,32,116,101,114,109,105,110,97,116,111,114,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,159,4,135,36,33,0,16,0,114,111,98,111,99,111,112,32,118,101,114,115,117,115,32,116,104,101,32,116,101,114,109,105,110,97,116,111,114,32,40,106,112,110,44,32,107,111,114,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,240,225,68,212,33,0,16,0,114,111,97,100,98,108,97,115,116,101,114,115,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,64,84,1,160,33,0,16,0,114,111,99,107,32,110,39,32,114,111,108,108,32,114,97,99,105,110,103,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,119,181,186,106,33,0,16,0,114,101,110,32,38,32,115,116,105,109,112,121,32,115,104,111,119,32,112,114,101,115,101,110,116,115,32,115,116,105,109,112,121,39,115,32,105,110,118,101,110,116,105,111,110,44,32,116,104,101,32,40,117,115,97,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,54,99,184,252,33,0,16,0,116,104,101,32,98,97,116,116,108,101,32,111,102,32,114,101,100,32,99,108,105,102,102,115,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,144,160,236,99,33,0,16,0,115,104,105,110,32,115,111,117,115,101,105,107,105,32,114,97,103,110,97,99,101,110,116,121,32,40,106,112,110,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,85,116,121,67,33,0,16,0,114,97,103,110,97,99,101,110,116,121,32,40,107,111,114,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,11,177,181,119,33,0,16,0,113,117,97,99,107,115,104,111,116,32,115,116,97,114,114,105,110,103,32,100,111,110,97,108,100,32,100,117,99,107,32,45,45,32,113,117,97,99,107,115,104,111,116,32,45,32,103,117,114,117,122,105,97,32,111,117,32,110,111,32,104,105,104,111,117,32,40,119,111,114,108,100,41,32,40,97,108,116,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,148,221,200,136,33,0,16,0,112,117,121,111,32,112,117,121,111,32,50,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,151,119,173,81,33,0,16,0,112,117,116,116,101,114,32,103,111,108,102,32,40,106,112,110,41,32,40,103,110,107,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,170,127,85,166,33,0,16,0,112,117,110,105,115,104,101,114,44,32,116,104,101,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,184,216,92,105,33,0,16,0,112,114,105,110,99,101,32,111,102,32,112,101,114,115,105,97,32,40,98,101,116,97,41,32,40,101,97,114,108,105,101,114,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,135,106,94,66,33,0,16,0,112,111,112,117,108,111,117,115,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,30,179,116,189,33,0,16,0,112,111,112,117,108,111,117,115,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,104,194,151,33,0,16,0,112,111,99,97,104,111,110,116,97,115,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,109,28,221,109,33,0,16,0,112,105,116,45,102,105,103,104,116,101,114,32,40,119,111,114,108,100,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,49,8,14,30,33,0,16,0,112,105,114,97,116,101,115,32,111,102,32,100,97,114,107,32,119,97,116,101,114,44,32,116,104,101,32,40,101,117,114,111,44,32,117,115,97,41,32,40,109,97,121,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,52,222,98,10,33,0,16,0,109,112,114,45,49,52,55,55,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,174,80,66,225,33,0,16,0,112,97,103,101,109,97,115,116,101,114,44,32,116,104,101,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,78,109,169,117,33,0,16,0,112,97,100,100,108,101,32,102,105,103,104,116,101,114,32,40,106,112,110,41,32,40,103,110,107,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,164,5,239,235,33,0,16,0,111,117,116,114,117,110,32,50,48,49,57,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,226,23,46,227,33,0,16,0,111,117,116,114,117,110,32,50,48,49,57,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,64,116,172,14,33,0,16,0,111,117,116,108,97,110,100,101,114,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,191,123,186,197,33,0,16,0,111,116,116,105,102,97,110,116,115,44,32,116,104,101,32,40,103,101,114,109,97,110,121,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,35,221,227,198,33,0,16,0,111,117,116,114,117,110,110,101,114,115,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,159,160,100,225,33,0,16,0,111,108,121,109,112,105,99,32,103,111,108,100,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,180,148,149,51,33,0,16,0,111,108,121,109,112,105,99,32,103,111,108,100,32,40,106,112,110,44,32,107,111,114,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,184,37,201,233,33,0,16,0,108,104,53,51,55,48,104,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,68,18,156,119,33,0,16,0,110,98,97,32,106,97,109,32,116,111,117,114,110,97,109,101,110,116,32,101,100,105,116,105,111,110,32,40,119,111,114,108,100,41,32,40,102,105,120,101,100,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,240,235,37,110,33,0,16,0,109,117,104,97,109,109,97,100,32,97,108,105,32,104,101,97,118,121,119,101,105,103,104,116,32,98,111,120,105,110,103,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,163,182,56,182,33,0,16,0,109,111,110,111,112,111,108,121,32,40,117,115,97,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,250,195,188,223,33,0,16,0,97,100,118,101,110,116,117,114,101,115,32,111,102,32,109,105,103,104,116,121,32,109,97,120,44,32,116,104,101,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,58,241,85,33,0,16,0,109,105,99,114,111,32,109,97,99,104,105,110,101,115,32,50,32,45,32,116,117,114,98,111,32,116,111,117,114,110,97,109,101,110,116,32,40,101,117,114,111,41,32,40,106,45,99,97,114,116,41,32,40,97,108,116,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,93,42,194,1,33,0,16,0,109,105,99,114,111,32,109,97,99,104,105,110,101,115,32,40,99,97,110,97,100,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,241,207,228,84,33,0,16,0,109,105,99,114,111,32,109,97,99,104,105,110,101,115,32,40,101,117,114,111,44,32,117,115,97,41,32,40,97,108,116,50,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,173,209,251,127,33,0,16,0,109,105,99,114,111,32,109,97,99,104,105,110,101,115,32,40,101,117,114,111,44,32,117,115,97,41,32,40,97,108,116,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,13,86,207,229,33,0,16,0,109,109,57,54,109,100,55,99,99,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,222,177,146,116,33,0,16,0,109,105,99,107,32,38,32,109,97,99,107,32,97,115,32,116,104,101,32,103,108,111,98,97,108,32,103,108,97,100,105,97,116,111,114,115,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,179,123,241,64,33,0,16,0,109,101,103,97,32,116,117,114,114,105,99,97,110,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,201,140,137,254,33,0,16,0,109,101,103,97,32,115,119,105,118,32,40,101,117,114,111,41,32,40,112,105,114,97,116,101,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,247,107,198,30,33,0,16,0,109,101,103,97,32,98,111,109,98,101,114,109,97,110,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,125,102,214,75,33,0,16,0,109,99,100,111,110,97,108,100,39,115,32,116,114,101,97,115,117,114,101,32,108,97,110,100,32,97,100,118,101,110,116,117,114,101,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,153,72,239,4,33,0,16,0,109,99,100,111,110,97,108,100,39,115,32,116,114,101,97,115,117,114,101,32,108,97,110,100,32,97,100,118,101,110,116,117,114,101,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,6,253,188,254,33,0,16,0,109,97,122,105,110,32,115,97,103,97,32,45,32,109,117,116,97,110,116,32,102,105,103,104,116,101,114,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,241,254,217,27,33,0,16,0,109,97,122,105,110,32,115,97,103,97,32,40,106,112,110,44,32,107,111,114,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,75,163,179,69,33,0,16,0,109,97,122,105,110,32,115,97,103,97,32,40,97,115,105,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,89,155,69,54,33,0,16,0,109,112,114,45,49,57,54,50,53,45,117,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,72,154,155,95,33,0,16,0,108,114,111,103,52,53,50,45,109,109,108,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,33,45,22,93,33,0,16,0,108,105,111,110,32,107,105,110,103,32,51,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,228,85,5,142,33,0,16,0,108,105,111,110,95,107,105,110,103,95,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,67,105,232,135,41,0,16,0,115,104,105,32,122,105,32,119,97,110,103,32,105,105,32,45,32,116,104,101,32,108,105,111,110,32,107,105,110,103,32,105,105,44,32,116,104,101,32,40,99,104,105,41,32,40,117,110,108,41,32,40,112,105,114,97,116,101,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,129,73,27,114,33,0,16,0,108,101,116,104,97,108,32,101,110,102,111,114,99,101,114,115,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,74,168,217,81,33,0,16,0,102,122,48,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,73,30,95,242,33,0,16,0,108,101,109,109,105,110,103,115,32,50,32,45,32,116,104,101,32,116,114,105,98,101,115,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,163,163,89,222,33,0,16,0,108,97,110,103,114,105,115,115,101,114,32,105,105,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,252,29,137,127,33,0,16,0,108,97,110,103,114,105,115,115,101,114,32,105,105,32,40,106,112,110,41,32,40,118,49,46,49,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,147,5,170,12,33,0,16,0,108,97,110,100,115,116,97,108,107,101,114,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,151,91,187,251,33,0,16,0,108,97,110,100,115,116,97,108,107,101,114,32,45,32,107,111,117,116,101,105,32,110,111,32,122,97,105,104,111,117,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,219,206,212,96,33,0,16,0,108,97,110,100,115,116,97,108,107,101,114,32,45,32,100,105,101,32,115,99,104,97,116,122,101,32,118,111,110,32,107,111,110,105,103,32,110,111,108,111,32,40,103,101,114,109,97,110,121,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,143,219,254,16,33,0,16,0,109,112,114,45,49,53,57,55,54,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,23,217,231,93,33,0,16,0,107,97,119,97,115,97,107,105,32,115,117,112,101,114,98,105,107,101,32,99,104,97,108,108,101,110,103,101,32,40,117,115,97,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,27,77,147,85,33,0,16,0,106,117,114,97,115,115,105,99,32,112,97,114,107,32,45,32,114,97,109,112,97,103,101,32,101,100,105,116,105,111,110,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,117,110,32,50,48,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,110,31,0,92,250,128,18,33,0,16,0,106,117,114,97,115,115,105,99,32,112,97,114,107,32,45,32,114,97,109,112,97,103,101,32,101,100,105,116,105,111,110,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,117,110,32,50,50,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,43,47,88,83,33,0,16,0,106,117,114,97,115,115,105,99,32,112,97,114,107,32,45,32,114,97,109,112,97,103,101,32,101,100,105,116,105,111,110,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,117,110,32,51,48,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,150,179,244,191,33,0,16,0,106,117,114,97,115,115,105,99,32,112,97,114,107,32,45,32,114,97,109,112,97,103,101,32,101,100,105,116,105,111,110,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,117,108,32,48,56,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,208,139,199,244,33,0,16,0,106,117,114,97,115,115,105,99,32,112,97,114,107,32,45,32,114,97,109,112,97,103,101,32,101,100,105,116,105,111,110,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,117,108,32,49,51,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,5,161,117,132,33,0,16,0,106,117,114,97,115,115,105,99,32,112,97,114,107,32,45,32,114,97,109,112,97,103,101,32,101,100,105,116,105,111,110,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,117,108,32,49,52,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,141,226,240,155,33,0,16,0,106,117,114,97,115,115,105,99,32,112,97,114,107,32,45,32,114,97,109,112,97,103,101,32,101,100,105,116,105,111,110,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,117,108,32,49,53,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,229,43,32,210,33,0,16,0,106,117,114,97,115,115,105,99,32,112,97,114,107,32,45,32,114,97,109,112,97,103,101,32,101,100,105,116,105,111,110,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,117,108,32,49,55,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,64,97,174,46,33,0,16,0,106,117,114,97,115,115,105,99,32,112,97,114,107,32,45,32,114,97,109,112,97,103,101,32,101,100,105,116,105,111,110,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,117,108,32,49,56,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,38,184,98,26,33,0,16,0,109,112,114,45,49,52,51,53,54,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,74,58,54,242,33,0,16,0,105,110,100,105,97,110,97,32,106,111,110,101,115,32,97,110,100,32,116,104,101,32,108,97,115,116,32,99,114,117,115,97,100,101,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,253,163,153,53,33,0,16,0,119,105,122,97,114,100,32,111,102,32,116,104,101,32,105,109,109,111,114,116,97,108,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,146,173,159,201,33,0,16,0,104,121,112,101,114,32,109,97,114,98,108,101,115,32,40,106,112,110,41,32,40,103,110,107,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,70,33,215,158,33,0,16,0,102,122,48,48,57,97,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,215,83,175,91,33,0,16,0,104,101,108,108,102,105,114,101,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,249,24,64,24,33,0,16,0,104,101,108,108,102,105,114,101,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,186,19,94,142,33,0,16,0,103,117,110,115,116,97,114,32,104,101,114,111,101,115,32,40,106,112,110,41,32,40,115,97,109,112,108,101,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,2,181,144,111,33,0,16,0,103,114,101,97,116,32,99,105,114,99,117,115,32,109,121,115,116,101,114,121,32,45,32,109,105,99,107,101,121,32,116,111,32,109,105,110,110,105,101,32,109,97,103,105,99,97,108,32,97,100,118,101,110,116,117,114,101,32,50,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,160,243,160,90,33,0,16,0,109,112,114,45,49,50,56,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,144,43,24,232,33,0,16,0,103,111,108,100,101,110,32,97,120,101,32,105,105,32,40,119,111,114,108,100,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,187,161,46,230,33,0,16,0,103,104,111,115,116,98,117,115,116,101,114,115,32,40,119,111,114,108,100,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,163,157,65,0,33,0,16,0,103,101,111,114,103,101,32,102,111,114,101,109,97,110,39,115,32,107,111,32,98,111,120,105,110,103,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,135,199,253,225,33,0,16,0,103,101,110,101,114,97,108,32,99,104,97,111,115,32,100,97,105,107,111,110,115,101,110,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,105,115,204,5,33,0,16,0,103,97,117,110,116,108,101,116,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,85,32,135,249,33,0,16,0,103,97,117,110,116,108,101,116,32,105,118,32,40,101,117,114,111,44,32,117,115,97,41,32,40,97,117,103,117,115,116,32,49,57,57,51,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,206,109,244,59,33,0,16,0,102,117,110,32,39,110,39,32,103,97,109,101,115,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,29,53,174,181,33,0,16,0,109,112,114,45,49,50,54,55,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,52,100,238,208,33,0,16,0,102,105,114,101,32,115,104,97,114,107,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,36,80,11,87,33,0,16,0,102,105,103,104,116,105,110,103,32,109,97,115,116,101,114,115,32,40,106,112,110,44,32,107,111,114,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,128,190,57,33,0,16,0,117,110,107,110,111,119,110,32,99,104,105,110,101,115,101,32,103,97,109,101,32,49,32,40,99,104,105,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,255,185,172,223,33,0,16,0,102,97,110,116,97,115,116,105,99,32,100,105,122,122,121,32,40,101,117,114,111,44,32,117,115,97,41,32,40,97,108,116,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,53,162,178,134,33,0,16,0,109,112,114,45,49,52,48,50,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,66,178,81,211,33,0,16,0,101,120,111,32,115,113,117,97,100,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,243,3,236,16,33,0,16,0,101,116,101,114,110,97,108,32,99,104,97,109,112,105,111,110,115,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,46,164,241,72,33,0,16,0,101,116,101,114,110,97,108,32,99,104,97,109,112,105,111,110,115,32,40,101,117,114,111,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,6,95,102,224,33,0,16,0,101,116,101,114,110,97,108,32,99,104,97,109,112,105,111,110,115,32,40,106,112,110,44,32,107,111,114,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,100,60,170,102,33,0,16,0,117,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,177,136,87,82,49,0,16,0,117,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,201,169,173,50,0,16,0,117,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,41,16,238,232,53,0,16,0,117,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,145,196,62,15,54,0,16,0,101,108,32,118,105,101,110,116,111,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,110,195,145,96,33,0,16,0,101,99,99,111,32,45,32,116,104,101,32,116,105,100,101,115,32,111,102,32,116,105,109,101,32,40,112,114,111,116,111,116,121,112,101,32,120,49,49,32,45,32,97,112,114,32,49,51,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0])
.concat([23,72,214,181,33,0,16,0,101,97,32,104,111,99,107,101,121,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,148,200,205,157,33,0,16,0,100,121,110,97,32,98,114,111,116,104,101,114,115,32,50,32,45,32,115,101,103,97,32,99,104,97,110,110,101,108,32,115,112,101,99,105,97,108,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,0,188,84,53,186,33,0,16,0,100,117,107,101,95,110,117,107,101,109,95,51,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,13,60,233,19,33,0,16,0,100,114,46,32,114,111,98,111,116,110,105,107,39,115,32,109,101,97,110,32,98,101,97,110,32,109,97,99,104,105,110,101,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,127,81,202,199,33,0,16,0,100,114,101,97,109,32,116,101,97,109,32,117,115,97,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,114,27,226,226,33,0,16,0,100,114,97,103,111,110,39,115,32,114,101,118,101,110,103,101,32,40,106,97,112,97,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,215,239,210,216,33,0,16,0,99,104,111,117,32,116,111,117,114,121,117,117,32,114,101,116,115,117,100,101,110,32,45,32,100,105,110,111,32,108,97,110,100,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,222,57,249,129,33,0,16,0,100,97,122,101,32,98,101,102,111,114,101,32,99,104,114,105,115,116,109,97,115,32,40,97,117,115,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,145,148,124,49,33,0,16,0,100,97,118,105,115,32,99,117,112,32,119,111,114,108,100,32,116,111,117,114,32,40,101,117,114,111,44,32,117,115,97,41,32,40,106,117,110,101,32,49,57,57,51,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,70,6,107,124,33,0,16,0,100,97,118,105,115,32,99,117,112,32,105,105,32,40,117,115,97,41,32,40,112,114,111,116,111,116,121,112,101,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,216,190,242,118,33,0,16,0,100,97,115,104,105,110,39,32,100,101,115,112,101,114,97,100,111,101,115,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,63,252,175,173,33,0,16,0,100,97,115,104,105,110,39,32,100,101,115,112,101,114,97,100,111,101,115,32,40,117,115,97,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,165,36,210,152,33,0,16,0,99,114,117,101,32,98,97,108,108,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,226,83,76,81,33,0,16,0,105,110,99,114,101,100,105,98,108,101,32,99,114,97,115,104,32,100,117,109,109,105,101,115,44,32,116,104,101,32,40,117,115,97,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,15,146,58,98,33,0,16,0,99,111,111,108,32,115,112,111,116,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,161,193,36,240,33,0,16,0,99,111,111,108,32,115,112,111,116,32,40,106,112,110,44,32,107,111,114,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,177,239,105,232,33,0,16,0,99,111,109,105,120,32,122,111,110,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,109,97,121,32,50,54,44,32,49,57,57,53,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,31,154,2,54,33,0,16,0,99,111,109,105,120,32,122,111,110,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,109,97,121,32,51,48,44,32,49,57,57,53,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,44,202,46,167,33,0,16,0,99,111,109,105,120,32,122,111,110,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,117,110,32,48,49,44,32,49,57,57,53,32,45,32,98,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,182,60,224,187,33,0,16,0,99,111,109,105,120,32,122,111,110,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,117,110,32,48,49,44,32,49,57,57,53,32,45,32,99,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,148,154,59,65,33,0,16,0,99,111,109,105,120,32,122,111,110,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,117,110,32,48,49,44,32,49,57,57,53,32,45,32,100,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,157,60,233,154,33,0,16,0,99,111,109,105,120,32,122,111,110,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,117,110,32,48,49,44,32,49,57,57,53,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,53,104,80,186,33,0,16,0,99,111,109,105,120,32,122,111,110,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,117,110,32,48,50,44,32,49,57,57,53,32,45,32,98,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,229,218,240,181,33,0,16,0,99,111,109,105,120,32,122,111,110,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,117,110,32,48,50,44,32,49,57,57,53,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,243,188,74,26,33,0,16,0,99,111,109,105,120,32,122,111,110,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,117,110,32,48,51,44,32,49,57,57,53,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,20,38,243,175,33,0,16,0,99,111,109,105,120,32,122,111,110,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,117,108,32,49,50,44,32,49,57,57,53,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,193,137,140,226,33,0,16,0,99,111,108,117,109,110,115,32,105,105,105,32,45,32,116,97,105,107,101,116,115,117,33,32,99,111,108,117,109,110,115,32,119,111,114,108,100,32,40,106,112,110,44,32,107,111,114,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,47,70,7,205,33,0,16,0,99,111,108,108,101,103,101,32,102,111,111,116,98,97,108,108,39,115,32,110,97,116,105,111,110,97,108,32,99,104,97,109,112,105,111,110,115,104,105,112,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,112,114,32,49,51,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,239,45,119,217,33,0,16,0,99,111,108,108,101,103,101,32,102,111,111,116,98,97,108,108,39,115,32,110,97,116,105,111,110,97,108,32,99,104,97,109,112,105,111,110,115,104,105,112,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,112,114,32,49,56,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,95,112,161,224,33,0,16,0,99,111,108,108,101,103,101,32,102,111,111,116,98,97,108,108,39,115,32,110,97,116,105,111,110,97,108,32,99,104,97,109,112,105,111,110,115,104,105,112,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,112,114,32,49,57,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,195,102,254,213,33,0,16,0,99,111,108,108,101,103,101,32,102,111,111,116,98,97,108,108,39,115,32,110,97,116,105,111,110,97,108,32,99,104,97,109,112,105,111,110,115,104,105,112,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,112,114,32,50,57,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,115,25,218,153,33,0,16,0,99,111,108,108,101,103,101,32,102,111,111,116,98,97,108,108,39,115,32,110,97,116,105,111,110,97,108,32,99,104,97,109,112,105,111,110,115,104,105,112,32,40,112,114,111,116,111,116,121,112,101,32,45,32,109,97,121,32,48,51,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,102,63,26,219,33,0,16,0,99,111,108,108,101,103,101,32,102,111,111,116,98,97,108,108,39,115,32,110,97,116,105,111,110,97,108,32,99,104,97,109,112,105,111,110,115,104,105,112,32,40,112,114,111,116,111,116,121,112,101,32,45,32,109,97,121,32,48,54,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,117,142,83,10,33,0,16,0,99,111,108,108,101,103,101,32,102,111,111,116,98,97,108,108,39,115,32,110,97,116,105,111,110,97,108,32,99,104,97,109,112,105,111,110,115,104,105,112,32,40,112,114,111,116,111,116,121,112,101,32,45,32,109,97,121,32,49,49,44,32,49,57,57,52,32,45,32,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,148,178,101,206,33,0,16,0,99,111,108,108,101,103,101,32,102,111,111,116,98,97,108,108,39,115,32,110,97,116,105,111,110,97,108,32,99,104,97,109,112,105,111,110,115,104,105,112,32,40,112,114,111,116,111,116,121,112,101,32,45,32,109,97,121,32,49,55,44,32,49,57,57,52,32,45,32,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,134,76,253,140,33,0,16,0,99,111,108,108,101,103,101,32,102,111,111,116,98,97,108,108,39,115,32,110,97,116,105,111,110,97,108,32,99,104,97,109,112,105,111,110,115,104,105,112,32,40,112,114,111,116,111,116,121,112,101,32,45,32,109,97,121,32,50,48,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,94,56,133,242,33,0,16,0,99,111,108,108,101,103,101,32,102,111,111,116,98,97,108,108,39,115,32,110,97,116,105,111,110,97,108,32,99,104,97,109,112,105,111,110,115,104,105,112,32,40,112,114,111,116,111,116,121,112,101,32,45,32,109,97,121,32,50,53,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,74,51,46,72,33,0,16,0,99,111,108,108,101,103,101,32,102,111,111,116,98,97,108,108,39,115,32,110,97,116,105,111,110,97,108,32,99,104,97,109,112,105,111,110,115,104,105,112,32,40,112,114,111,116,111,116,121,112,101,32,45,32,109,97,121,32,51,49,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,69,103,118,198,33,0,16,0,99,111,108,108,101,103,101,32,102,111,111,116,98,97,108,108,39,115,32,110,97,116,105,111,110,97,108,32,99,104,97,109,112,105,111,110,115,104,105,112,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,117,110,32,48,49,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,143,188,77,153,33,0,16,0,99,111,108,108,101,103,101,32,102,111,111,116,98,97,108,108,39,115,32,110,97,116,105,111,110,97,108,32,99,104,97,109,112,105,111,110,115,104,105,112,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,117,110,32,48,51,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,33,147,162,156,33,0,16,0,99,111,108,108,101,103,101,32,102,111,111,116,98,97,108,108,39,115,32,110,97,116,105,111,110,97,108,32,99,104,97,109,112,105,111,110,115,104,105,112,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,117,110,32,48,55,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,30,121,11,180,33,0,16,0,99,111,108,108,101,103,101,32,102,111,111,116,98,97,108,108,39,115,32,110,97,116,105,111,110,97,108,32,99,104,97,109,112,105,111,110,115,104,105,112,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,117,110,32,48,56,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,188,222,8,208,33,0,16,0,99,111,108,108,101,103,101,32,102,111,111,116,98,97,108,108,39,115,32,110,97,116,105,111,110,97,108,32,99,104,97,109,112,105,111,110,115,104,105,112,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,117,110,32,49,52,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,231,125,239,236,33,0,16,0,99,111,108,108,101,103,101,32,102,111,111,116,98,97,108,108,39,115,32,110,97,116,105,111,110,97,108,32,99,104,97,109,112,105,111,110,115,104,105,112,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,117,110,32,49,53,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,152,169,229,199,33,0,16,0,99,111,108,108,101,103,101,32,102,111,111,116,98,97,108,108,39,115,32,110,97,116,105,111,110,97,108,32,99,104,97,109,112,105,111,110,115,104,105,112,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,117,110,32,49,56,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,157,138,152,116,33,0,16,0,99,111,108,108,101,103,101,32,102,111,111,116,98,97,108,108,39,115,32,110,97,116,105,111,110,97,108,32,99,104,97,109,112,105,111,110,115,104,105,112,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,117,110,32,50,48,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,250,23,140,137,33,0,16,0,99,108,97,121,32,102,105,103,104,116,101,114,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,193,27,44,177,33,0,16,0,99,104,117,99,107,32,114,111,99,107,32,105,105,32,45,32,115,111,110,32,111,102,32,99,104,117,99,107,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,219,28,139,64,33,0,16,0,99,104,117,99,107,32,114,111,99,107,32,105,105,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,232,75,210,191,33,0,16,0,99,104,117,99,107,32,114,111,99,107,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,74,69,172,248,33,0,16,0,109,112,114,45,49,51,52,57,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,198,51,131,206,33,0,16,0,119,104,101,114,101,32,105,110,32,116,104,101,32,119,111,114,108,100,32,105,115,32,99,97,114,109,101,110,32,115,97,110,100,105,101,103,111,32,40,98,114,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,173,80,68,125,33,0,16,0,119,104,101,114,101,32,105,110,32,116,105,109,101,32,105,115,32,99,97,114,109,101,110,32,115,97,110,100,105,101,103,111,32,40,98,114,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,82,181,35,213,33,0,16,0,99,97,112,116,97,105,110,32,112,108,97,110,101,116,32,97,110,100,32,116,104,101,32,112,108,97,110,101,116,101,101,114,115,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,58,189,44,191,33,0,16,0,99,97,112,116,97,105,110,32,97,109,101,114,105,99,97,32,97,110,100,32,116,104,101,32,97,118,101,110,103,101,114,115,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,162,156,99,224,33,0,16,0,98,117,114,110,105,110,103,32,102,111,114,99,101,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,44,240,200,189,33,0,16,0,98,117,114,110,105,110,103,32,102,111,114,99,101,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,71,235,29,12,33,0,16,0,110,98,97,32,112,114,111,32,98,97,115,107,101,116,98,97,108,108,32,45,32,98,117,108,108,115,32,118,115,32,108,97,107,101,114,115,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,57,206,22,68,33,0,16,0,110,98,97,32,112,108,97,121,111,102,102,115,32,45,32,98,117,108,108,115,32,118,115,32,98,108,97,122,101,114,115,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,192,232,234,33,0,16,0,98,117,103,39,115,32,108,105,102,101,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,103,26,28,237,33,0,16,0,98,117,98,98,108,101,32,97,110,100,32,115,113,117,101,97,107,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,6,160,196,40,33,0,16,0,98,114,105,97,110,32,108,97,114,97,32,99,114,105,99,107,101,116,32,40,101,117,114,111,41,32,40,109,97,114,99,104,32,49,57,57,53,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,183,194,245,144,33,0,16,0,109,100,98,108,95,57,56,52,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,175,36,48,250,33,0,16,0,98,111,110,107,101,114,115,32,40,112,114,111,116,111,116,121,112,101,32,45,32,109,97,114,32,50,56,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,136,197,103,205,33,0,16,0,98,111,110,107,101,114,115,32,40,112,114,111,116,111,116,121,112,101,32,45,32,109,97,121,32,48,51,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,97,13,205,228,33,0,16,0,98,111,110,107,101,114,115,32,40,112,114,111,116,111,116,121,112,101,32,45,32,111,99,116,32,48,52,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,52,200,60,145,33,0,16,0,98,111,110,107,101,114,115,32,40,112,114,111,116,111,116,121,112,101,32,45,32,111,99,116,32,50,53,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,79,220,94,62,33,0,16,0,98,111,110,107,101,114,115,32,40,112,114,111,116,111,116,121,112,101,32,45,32,111,99,116,32,50,57,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,62,121,132,123,33,0,16,0,98,111,110,97,110,122,97,32,98,114,111,115,46,32,40,117,115,97,44,32,107,111,114,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,76,173,209,32,33,0,16,0,98,111,110,97,110,122,97,32,98,114,111,115,46,32,40,101,117,114,111,44,32,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,108,71,246,173,33,0,16,0,98,108,97,115,116,101,114,32,109,97,115,116,101,114,32,50,32,40,117,115,97,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,112,140,247,8,33,0,16,0,98,105,111,32,104,97,122,97,114,100,32,98,97,116,116,108,101,32,40,117,115,97,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,26,221,16,221,33,0,16,0,98,101,121,111,110,100,32,111,97,115,105,115,32,40,112,114,111,116,111,116,121,112,101,32,45,32,110,111,118,32,48,49,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,71,248,89,250,33,0,16,0,98,101,114,101,110,115,116,97,105,110,32,98,101,97,114,115,39,32,99,97,109,112,105,110,103,32,97,100,118,101,110,116,117,114,101,44,32,116,104,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,109,97,114,32,50,51,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,204,215,188,191,33,0,16,0,98,101,114,101,110,115,116,97,105,110,32,98,101,97,114,115,39,32,99,97,109,112,105,110,103,32,97,100,118,101,110,116,117,114,101,44,32,116,104,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,112,114,32,50,56,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,70,233,34,242,33,0,16,0,98,101,114,101,110,115,116,97,105,110,32,98,101,97,114,115,39,32,99,97,109,112,105,110,103,32,97,100,118,101,110,116,117,114,101,44,32,116,104,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,112,114,32,50,57,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,180,147,20,226,33,0,16,0,98,101,114,101,110,115,116,97,105,110,32,98,101,97,114,115,39,32,99,97,109,112,105,110,103,32,97,100,118,101,110,116,117,114,101,44,32,116,104,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,109,97,121,32,48,54,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,216,20,60,113,33,0,16,0,98,101,114,101,110,115,116,97,105,110,32,98,101,97,114,115,39,32,99,97,109,112,105,110,103,32,97,100,118,101,110,116,117,114,101,44,32,116,104,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,109,97,121,32,49,49,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,106,28,184,247,33,0,16,0,98,101,114,101,110,115,116,97,105,110,32,98,101,97,114,115,39,32,99,97,109,112,105,110,103,32,97,100,118,101,110,116,117,114,101,44,32,116,104,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,109,97,121,32,49,55,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,222,90,133,225,33,0,16,0,98,101,114,101,110,115,116,97,105,110,32,98,101,97,114,115,39,32,99,97,109,112,105,110,103,32,97,100,118,101,110,116,117,114,101,44,32,116,104,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,109,97,121,32,49,57,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,31,247,201,7,33,0,16,0,98,101,114,101,110,115,116,97,105,110,32,98,101,97,114,115,39,32,99,97,109,112,105,110,103,32,97,100,118,101,110,116,117,114,101,44,32,116,104,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,109,97,121,32,50,51,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,183,135,56,145,33,0,16,0,98,101,114,101,110,115,116,97,105,110,32,98,101,97,114,115,39,32,99,97,109,112,105,110,103,32,97,100,118,101,110,116,117,114,101,44,32,116,104,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,109,97,121,32,50,54,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,164,15,60,211,33,0,16,0,98,101,114,101,110,115,116,97,105,110,32,98,101,97,114,115,39,32,99,97,109,112,105,110,103,32,97,100,118,101,110,116,117,114,101,44,32,116,104,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,109,97,121,32,51,48,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,41,244,59,156,33,0,16,0,98,101,114,101,110,115,116,97,105,110,32,98,101,97,114,115,39,32,99,97,109,112,105,110,103,32,97,100,118,101,110,116,117,114,101,44,32,116,104,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,117,110,32,48,50,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,228,25,207,131,33,0,16,0,98,101,114,101,110,115,116,97,105,110,32,98,101,97,114,115,39,32,99,97,109,112,105,110,103,32,97,100,118,101,110,116,117,114,101,44,32,116,104,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,117,110,32,49,48,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,207,226,72,167,33,0,16,0,98,101,114,101,110,115,116,97,105,110,32,98,101,97,114,115,39,32,99,97,109,112,105,110,103,32,97,100,118,101,110,116,117,114,101,44,32,116,104,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,117,108,32,48,57,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,5,164,106,191,33,0,16,0,98,101,114,101,110,115,116,97,105,110,32,98,101,97,114,115,39,32,99,97,109,112,105,110,103,32,97,100,118,101,110,116,117,114,101,44,32,116,104,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,117,108,32,49,54,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,142,173,74,200,33,0,16,0,98,101,114,101,110,115,116,97,105,110,32,98,101,97,114,115,39,32,99,97,109,112,105,110,103,32,97,100,118,101,110,116,117,114,101,44,32,116,104,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,117,108,32,50,48,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,94,76,238,171,33,0,16,0,98,101,114,101,110,115,116,97,105,110,32,98,101,97,114,115,39,32,99,97,109,112,105,110,103,32,97,100,118,101,110,116,117,114,101,44,32,116,104,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,117,103,32,48,49,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,92,70,205,183,33,0,16,0,98,101,114,101,110,115,116,97,105,110,32,98,101,97,114,115,39,32,99,97,109,112,105,110,103,32,97,100,118,101,110,116,117,114,101,44,32,116,104,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,117,103,32,48,50,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,100,213,58,56,33,0,16,0,98,101,114,101,110,115,116,97,105,110,32,98,101,97,114,115,39,32,99,97,109,112,105,110,103,32,97,100,118,101,110,116,117,114,101,44,32,116,104,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,117,103,32,48,51,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,166,104,242,24,33,0,16,0,98,101,114,101,110,115,116,97,105,110,32,98,101,97,114,115,39,32,99,97,109,112,105,110,103,32,97,100,118,101,110,116,117,114,101,44,32,116,104,101])
.concat([32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,117,103,32,48,53,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,111,155,21,36,33,0,16,0,98,101,114,101,110,115,116,97,105,110,32,98,101,97,114,115,39,32,99,97,109,112,105,110,103,32,97,100,118,101,110,116,117,114,101,44,32,116,104,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,117,103,32,48,56,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,252,176,182,88,33,0,16,0,115,105,109,112,115,111,110,115,44,32,116,104,101,32,45,32,98,97,114,116,32,118,115,32,116,104,101,32,115,112,97,99,101,32,109,117,116,97,110,116,115,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,116,5,98,200,33,0,16,0,98,97,114,107,108,101,121,32,115,104,117,116,32,117,112,32,97,110,100,32,106,97,109,33,32,50,32,40,117,115,97,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,123,53,39,222,33,0,16,0,98,97,99,107,32,116,111,32,116,104,101,32,102,117,116,117,114,101,32,112,97,114,116,32,105,105,105,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,195,136,163,102,33,0,16,0,98,97,98,121,32,98,111,111,109,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,117,110,32,48,54,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,141,244,12,110,33,0,16,0,98,97,98,121,32,98,111,111,109,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,117,110,32,48,51,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,111,127,217,192,33,0,16,0,97,119,101,115,111,109,101,32,112,111,115,115,117,109,32,40,117,115,97,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,83,220,88,1,33,0,16,0,97,116,112,32,116,111,117,114,32,99,104,97,109,112,105,111,110,115,104,105,112,32,116,101,110,110,105,115,32,40,112,114,111,116,111,116,121,112,101,32,45,32,109,97,121,32,48,57,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,188,141,122,177,33,0,16,0,97,116,112,32,116,111,117,114,32,99,104,97,109,112,105,111,110,115,104,105,112,32,116,101,110,110,105,115,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,117,108,32,49,57,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,136,116,146,203,33,0,16,0,97,116,112,32,116,111,117,114,32,99,104,97,109,112,105,111,110,115,104,105,112,32,116,101,110,110,105,115,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,117,108,32,50,51,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,81,80,93,161,33,0,16,0,97,116,112,32,116,111,117,114,32,99,104,97,109,112,105,111,110,115,104,105,112,32,116,101,110,110,105,115,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,117,103,32,48,50,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,161,159,106,104,33,0,16,0,97,116,112,32,116,111,117,114,32,99,104,97,109,112,105,111,110,115,104,105,112,32,116,101,110,110,105,115,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,117,103,32,48,53,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,103,249,254,161,33,0,16,0,97,116,112,32,116,111,117,114,32,99,104,97,109,112,105,111,110,115,104,105,112,32,116,101,110,110,105,115,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,117,103,32,48,56,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,100,136,57,230,33,0,16,0,97,116,112,32,116,111,117,114,32,99,104,97,109,112,105,111,110,115,104,105,112,32,116,101,110,110,105,115,32,40,112,114,111,116,111,116,121,112,101,32,45,32,115,101,112,32,48,56,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,164,76,63,184,33,0,16,0,109,112,114,45,49,51,52,56,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,126,6,51,232,33,0,16,0,97,115,116,101,114,105,120,32,97,110,100,32,116,104,101,32,103,114,101,97,116,32,114,101,115,99,117,101,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,216,44,17,127,33,0,16,0,119,105,108,108,105,97,109,115,32,97,114,99,97,100,101,39,115,32,103,114,101,97,116,101,115,116,32,104,105,116,115,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,156,142,214,33,0,16,0,97,110,105,109,97,110,105,97,99,115,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,134,77,34,134,33,0,16,0,97,108,105,101,110,32,115,111,108,100,105,101,114,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,57,21,250,144,33,0,16,0,97,108,101,120,32,107,105,100,100,32,105,110,32,116,104,101,32,101,110,99,104,97,110,116,101,100,32,99,97,115,116,108,101,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,172,160,219,71,33,0,16,0,97,108,101,120,32,107,105,100,100,32,45,32,99,104,101,111,110,103,111,110,103,32,109,97,115,101,111,110,103,32,40,107,111,114,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,251,120,6,91,33,0,16,0,97,108,101,120,32,107,105,100,100,32,45,32,116,101,110,107,117,117,32,109,97,106,111,117,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,86,216,94,138,33,0,16,0,97,108,101,120,32,107,105,100,100,32,105,110,32,116,104,101,32,101,110,99,104,97,110,116,101,100,32,99,97,115,116,108,101,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,41,37,165,195,33,0,16,0,97,108,97,100,100,105,110,32,40,117,115,97,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,115,239,96,140,33,0,16,0,97,105,114,32,100,105,118,101,114,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,145,91,45,158,33,0,16,0,97,99,116,105,111,110,32,53,50,32,40,117,115,97,41,32,40,97,108,116,41,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,102,214,9,136,33,0,16,0,109,112,114,45,49,50,57,52,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,102,126,243,79,33,0,16,0,109,97,114,116,109,97,115,116,95,117,57,45,118,49,48,50,46,51,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,42,185,36,187,1,0,16,1,116,49,48,48,48,46,117,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,181,121,248,187,2,0,32,0,97,49,48,48,48,46,117,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,200,122,87,67,3,0,32,0,97,49,48,48,49,46,117,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,111,71,122,254,3,0,32,0,97,49,48,48,50,46,117,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,56,61,227,98,3,0,32,0,97,49,48,48,51,46,117,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,90,148,196,178,3,0,32,0,97,49,48,48,52,46,117,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,253,245,211,159,3,0,32,0,98,49,48,48,48,46,117,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,111,31,150,197,4,0,32,0,98,49,48,48,49,46,117,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,6,28,126,11,4,0,32,0,109,49,48,48,48,46,117,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,232,122,64,237,5,0,64,0,109,49,48,48,49,46,117,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,72,45,45,102,5,0,64,0,109,97,114,116,105,97,108,95,109,97,115,116,101,114,115,95,118,49,48,49,95,99,110,46,97,115,105,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,125,91,226,179,7,0,16,1,109,97,114,116,109,97,115,116,95,117,49,48,45,118,49,48,49,46,49,54,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,148,50,217,213,8,0,16,1,46,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,6,0,144,165,4,0,46,0,0,0,1,7,0,0,232,41,1,0,46,0,0,0,1,7,1,0,80,65,1,0,46,0,0,0,1,7,2,0,176,20,3,0,46,0,0,0,1,7,3,0,56,50,1,0,46,0,0,0,1,7,4,0,192,20,3,0,46,0,0,0,1,7,5,0,224,32,1,0,2,0,0,0,0,0,0,0,255,15,0,0,0,0,0,0,8,0,0,0,0,16,0,0,255,63,0,0,0,0,0,0,5,0,0,0,0,64,0,0,255,127,0,0,0,0,0,0,5,0,0,0,0,128,0,0,255,255,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,0,0,0,0,0,0,255,127,0,0,0,0,0,0,15,0,0,0,0,128,0,0,255,255,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,255,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,255,79,0,0,0,0,0,0,4,0,0,0,0,64,0,0,255,127,0,0,0,0,0,0,8,0,0,0,0,0,0,0,255,127,0,0,1,0,0,0,2,0,0,0,0,112,0,0,255,127,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,255,127,0,0,0,0,0,0,1,0,0,0,0,128,0,0,255,255,0,0,1,0,0,0,1,0,0,0,0,0,1,0,255,31,1,0,2,0,0,0,8,0,0,0,0,32,0,0,255,63,0,0,2,0,0,0,2,0,0,0,0,64,0,0,255,79,0,0,2,0,0,0,4,0,0,0,0,80,0,0,255,127,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,0,0,0,0,0,0,255,127,0,0,0,0,0,0,15,0,0,0,0,128,0,0,255,255,0,0,1,0,0,0,15,0,0,0,0,0,1,0,255,127,1,0,2,0,0,0,15,0,0,0,0,128,1,0,255,255,1,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,255,15,0,0,0,0,0,0,5,0,0,0,0,16,0,0,255,95,0,0,0,0,0,0,8,0,0,0,0,96,0,0,255,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,255,31,0,0,0,0,0,0,2,0,0,0,0,32,0,0,255,47,0,0,0,0,0,0,4,0,0,0,0,64,0,0,255,127,0,0,0,0,0,0,8,0,0,0,0,0,0,0,255,255,1,0,1,0,0,0,1,0,0,0,0,32,0,0,255,63,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,114,183,175,103,222,29,177,120,196,79,181,75,24,118,221,17,226,54,161,130,3,152,160,16,95,63,214,31,144,106,11,112,224,100,203,159,56,139,83,4,202,248,208,7,104,86,50,174,28,46,72,99,146,154,156,68,133,65,64,9,192,200,191,234,187,247,45,153,33,246,186,21,206,171,176,42,96,188,241,240,158,213,151,216,78,20,157,66,77,44,92,43,166,225,167,239,37,51,122,235,231,27,109,76,82,38,98,182,53,190,128,1,189,253,55,249,71,85,113,180,242,255,39,250,35,201,131,23,57,19,13,199,134,22,236,73,111,254,52,5,143,0,230,164,218,123,193,243,244,217,117,40,102,135,168,69,108,32,233,119,147,126,60,30,116,245,140,62,148,212,194,90,6,14,232,61,169,178,227,228,34,207,36,142,107,138,141,132,74,210,145,136,121,87,165,15,205,185,172,59,170,179,209,238,49,129,124,215,137,211,150,67,197,198,195,105,127,70,223,48,91,110,229,8,149,155,251,184,88,12,97,80,93,58,162,41,18,252,81,125,26,2,101,84,94,25,204,220,219,115,237,173,89,47,163,156,255,1,0,1,0,2,0,2,0,3,0,3,0,4,0,5,0,6,0,7,0,8,0,9,0,10,0,11,0,12,0,13,0,14,0,15,0,16,0,17,0,18,0,19,0,20,0,21,0,22,0,23,0,24,0,25,0,26,0,27,0,28,0,29,0,30,0,31,0,32,0,33,0,34,0,35,0,36,0,37,0,38,0,39,0,40,0,41,0,42,0,43,0,44,0,45,0,46,0,47,0,48,0,49,0,50,0,51,0,52,0,53,0,54,0,55,0,56,0,57,0,58,0,59,0,60,0,61,0,62,0,63,0,64,0,65,0,67,0,68,0,69,0,70,0,71,0,72,0,73,0,74,0,75,0,76,0,78,0,79,0,80,0,81,0,82,0,83,0,84,0,85,0,86,0,87,0,89,0,90,0,91,0,92,0,93,0,94,0,95,0,96,0,97,0,90,0,99,0,101,0,102,0,103,0,104,0,105,0,106,0,107,0,108,0,109,0,110,0,111,0,113,0,114,0,116,0,117,0,119,0,120,0,122,0,123,0,125,0,126,0,128,0,129,0,131,0,133,0,135,0,137,0,139,0,141,0,142,0,143,0,144,0,146,0,147,0,149,0,151,0,152,0,153,0,154,0,155,0,156,0,157,0,158,0,160,0,161,0,162,0,163,0,164,0,165,0,166,0,167,0,168,0,169,0,170,0,172,0,173,0,174,0,175,0,176,0,177,0,178,0,179,0,180,0,181,0,182,0,184,0,185,0,186,0,187,0,188,0,189,0,190,0,191,0,192,0,193,0,194,0,196,0,197,0,198,0,199,0,200,0,201,0,202,0,203,0,204,0,205,0,207,0,208,0,209,0,210,0,211,0,212,0,213,0,214,0,215,0,216,0,217,0,219,0,220,0,221,0,222,0,223,0,224,0,225,0,226,0,227,0,228,0,229,0,231,0,232,0,233,0,234,0,235,0,236,0,237,0,238,0,239,0,240,0,241,0,243,0,244,0,245,0,246,0,247,0,248,0,249,0,250,0,251,0,252,0,254,0,255,0,0,1,1,1,2,1,3,1,4,1,5,1,6,1,7,1,8,1,10,1,11,1,12,1,13,1,14,1,15,1,16,1,17,1,18,1,19,1,20,1,22,1,23,1,24,1,25,1,26,1,27,1,28,1,29,1,30,1,31,1,32,1,34,1,35,1,36,1,37,1,38,1,39,1,40,1,41,1,42,1,43,1,44,1,46,1,47,1,48,1,49,1,50,1,51,1,52,1,53,1,54,1,55,1,57,1,58,1,59,1,60,1,61,1,62,1,63,1,64,1,65,1,66,1,67,1,69,1,70,1,71,1,72,1,73,1,74,1,75,1,76,1,77,1,78,1,79,1,81,1,82,1,83,1,84,1,85,1,86,1,87,1,88,1,89,1,90,1,91,1,93,1,94,1,95,1,96,1,97,1,98,1,99,1,100,1,101,1,102,1,103,1,105,1,106,1,107,1,108,1,109,1,110,1,111,1,112,1,113,1,114,1,116,1,117,1,118,1,119,1,120,1,121,1,122,1,123,1,124,1,125,1,126,1,127,1,128,1,129,1,130,1,131,1,132,1,133,1,134,1,135,1,136,1,137,1,138,1,139,1,140,1,141,1,142,1,143,1,144,1,145,1,146,1,147,1,148,1,149,1,150,1,151,1,152,1,153,1,154,1,155,1,156,1,157,1,158,1,159,1,160,1,161,1,162,1,163,1,164,1,165,1,166,1,167,1,168,1,169,1,170,1,171,1,172,1,173,1,174,1,175,1,176,1,177,1,178,1,179,1,180,1,181,1,182,1,183,1,184,1,185,1,186,1,187,1,188,1,189,1,190,1,191,1,191,1,0,0,0,0,7,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,64,44,0,0,32,67,0,0,32,113,0,0,0,178,0,0,94,9,179,57,96,113,113,83,17,229,38,52,76,140,144,238,237,181,5,149,158,107,221,135,14,123,237,51,175,194,98,152,236,200,44,43,87,61,0,189,18,172,186,100,129,153,22,41,180,99,168,217,201,95,254,33,187,191,155,209,123,147,196,130,239,43,232,166,220,104,58,217,201,35,199,123,152,91,225,199,163,212,81,10,134,48,32,81,110,4,28,212,251,245,34,143,22,111,185,89,48,207,171,50,29,108,132,171,35,144,148,177,231,75,109,193,132,186,50,104,163,242,71,40,229,203,187,71,20,44,173,77,161,215,24,83,247,111,5,129,143,187,41,220,189,23,97,146,155,29,78,122,131,20,159,123,122,106,225,39,98,82,126,130,69,218,237,241,10,59,108,2,91,110,69,78,242,101,135,29,128,237,106,195,119,203,232,141,90,184,218,137,136,75,39,213,87,41,145,134,18,187,211,140,199,73,132,156,150,89,48,147,146,235,89,43,147,91,95,249,103,172,151,140,4,218,27,101,215,239,68,202,196,135,24,43,215,73,179,57,96,113,112,83,17,0,39,178,97,211,140,139,178,222,106,120,64,93,77,136,235,129,208,42,191,140,34,13,137,131,200,239,13,122,246,240,29,73,162,211,30,239,28,162,206,0,94,168,127,76,65,39,168,107,146,10,184,3,47,126,175,74,208,92,206,235,14,138,77,11,115,179,243,12,131,170,229,228,132,6,215,204,203,82,141,190,164,223,217,171,80,89,83,97,161,200,109,188,222,171,170,94,198,247,131,220,64,203,27,221,40,59,238,177,31,55,219,233,187,116,75,194,138,232,236,110,14,53,227,46,190,239,253,7,191,140,254,243,92,191,135,229,188,207,96,220,24,248,252,81,80,134,198,72,61,185,29,38,247,126,135,144,18,232,6,10,69,233,217,216,65,104,33,82,146,15,214,218,162,151,235,104,208,177,21,25,139,208,72,26,235,144,63,42,51,30,94,48,102,1,100,239,153,82,186,35,189,83,192,96,135,9,203,77,211,135,14,58,92,141,200,184,183,52,1,235,114,13,177,31,15,234,106,19,179,9,96,121,97,83,17,51,65,49,118,52,136,15,119,8,182,116,200,54,188,112,226,135,154,33,232,86,225,154,38,87,126,155,219,183,212,61,15,254,138,42,186,45,34,3,207,156,250,119,53,57,106,20,174,48,137,66,220,89,178,147,111,130,209,18,217,136,250,59,183,12,31,5,104,163,12,166,15,244,158,27,41,130,119,58,172,146,45,4,208,97,101,10,119,108,137,56,170,169,248,12,31,55,9,43,202,41,5,229,78,87,251,205,64,168,12,6,45,224,48,217,151,185,89,138,222,201,135,29,63,132,76,115,4,133,97,176,110,44,143,162,106,205,49,243,37,131,225,94,93,167,231,170,19,38,177,51,240,19,88,122,176,70,29,223,2,191,30,209,113,67,86,130,79,88,157,1,45,199,218,107,71,5,209,213,232,146,60,24,33,207,201,50,14,18,237,181,170,164,18,117,1,125,199,33,222,236,50,19,238,212,156,230,4,63,72,251,180,199,33,142,141,125,84,3,17,231,185,79,133,182,31,170,227,83,179,9,96,121,96,83,17,102,91,200,139,148,132,171,60,24,3,87,106,15,69,88,192,116,100,24,248,57,161,15,194,43,27,96,170,14,178,137,1,155,114,128,87,131,40,99,233,57,151,70,234,63,147,1,155,244,128,147,1,175,29,143,22,161,185,199,228,12,231,210,59,243,202,61,195,84,173,137,81,30,209,23,122,31,35,34,203,77,206,15,174,48,147,211,155,119,113,167,231,150,44,133,172,41,75,94,43,117,176,0,129,233,182,71,170,159,223,212,126,215,164,63,227,176,65,44,183,12,231,235,154,218,217,16,35,29,28,212,221,125,194,108,77,156,165,24,208,67,171,220,189,228,127,181,95,4,13,172,171,230,184,118,242,21,65,239,23,142,246,185,239,148,82,131,150,69,143,242,156,180,19,63,187,161,210,249,163,242,6,120,224,158,167,211,220,19,143,77,246,25,189,3,157,36,220,214,233,207,166,210,29,73,202,196,85,24,188,112,91,85,254,143,107,66,240,209,33,227,231,145,89,78,22,131,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,179,16,243,11,224,113,96,83,17,154,18,112,31,30,129,218,157,31,75,214,113,72,131,225,4,108,27,241,205,9,223,62,11,170,149,193,7,236,15,84,208,22,176,220,134,123,82,56,60,104,43,237,226,235,179,198,72,36,65,54,23,37,31,165,34,198,92,166,25,239,23,92,86,75,74,43,117,171,230,34,213,192,211,70,204,228,212,196,140,154,138,117,36,115,164,38,202,121,175,179,148,42,21,190,64,123,77,246,180,164,123,207,206,160,29,203,47,96,40,99,133,152,211,210,69,63,2,101,215,244,188,42,231,80,209,63,127,246,5,184,233,57,16,110,104,168,137,96,0,104,253,32,196,220,239,103,117,251,190,254,43,22,166,90,119,13,12,226,45,209,228,17,201,75,129,58,12,36,170,119,43,47,131,35,209,233,167,41,10,249,38,157,81,200,109,113,157,206,70,114,38,72,61,100,229,103,187,26,180,109,33,17,121,120,194,213,17,106,210,234,3,77,146,175,24,213,7,121,170,249,68,147,111,65,34,13,45,80,243,11,224,113,97,83,17,180,44,238,52,126,125,94,98,72,151,210,249,58,242,201,250,89,228,232,246,210,159,178,167,126,50,134,188,67,236,160,194,203,152,51,35,209,88,152,86,5,199,188,152,216,220,179,53,232,81,110,59,123,137,186,225,229,68,92,36,115,4,13,217,51,245,99,233,92,136,5,24,208,7,91,30,129,128,172,146,110,19,128,27,41,210,239,8,132,151,35,209,23,47,56,180,109,143,42,21,240,64,233,2,51,215,94,153,87,21,50,189,143,72,56,145,54,233,7,201,55,29,18,42,191,95,219,133,117,191,220,89,138,67,81,75,119,253,132,196,40,199,133,37,26,135,139,193,217,26,120,229,3,32,86,160,194,23,242,41,160,189,248,97,156,125,84,58,17,181,105,154,28,187,246,45,134,168,77,221,90,214,228,17,126,75,19,108,182,1,10,114,188,232,241,130,14,208,207,191,80,149,183,167,236,215,179,73,92,71,95,169,218,112,176,220,154,163,72,211,245,114,213,67,216,25,204,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,115,112,106,46,115,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,215,141,20,0,0,16,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,115,102,105,120,46,115,102,105,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,253,12,234,194,0,0,32,2,48,48,48,45,108,111,46,108,111,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,242,207,134,90,0,0,0,3,255,255,255,255,0,0,0,0,0,0,0,0,253,0,8,0,48,45,3,0,27,0,0,0,1,255,1,0,176,20,3,0,27,0,0,0,1,255,2,0,160,236,1,0,27,0,0,0,1,255,3,0,136,50,1,0,27,0,0,0,1,255,4,0,160,134,3,0,27,0,0,0,1,255,5,0,128,33,1,0,27,0,0,0,1,255,6,0,232,23,1,0,27,0,0,0,1,255,7,0,88,15,1,0,27,0,0,0,1,255,8,0,56,50,1,0,27,0,0,0,1,255,0,0,80,4,1,0,27,0,0,0,255,255,81,0,0,0,0,0,0,0,0,0,6,0,0,0,16,0,0,0,240,36,5,0,32,7,5,0,0,0,0,0,40,191,4,0,136,159,4,0,0,0,0,0,5,0,0,0,0,0,0,0,3,0,128,0,6,0,96,0,0,0,224,0,10,0,192,0,3,0,128,0,6,0,96,0,0,0,224,0,10,0,192,0,3,0,128,0,6,0,96,0,0,0,224,0,10,0,192,0,3,0,128,0,6,0,96,0,0,0,224,0,10,0,192,0,27,0,0,0,255,255,83,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,96,3,3,0,152,7,3,0,168,12,3,0,184,17,3,0,240,21,3,0,0,27,3,0,192,33,3,0,128,40,3,0,104,46,3,0,0,54,3,0,152,61,3,0,184,71,3,0,120,78,3,0,16,86,3,0,128,94,3,0,160,104,3,0,56,112,3,0,32,118,3,0,88,122,3,0,24,129,3,0,0,135,3,0,232,140,3,0,168,147,3,0,104,154,3,0,216,162,3,0,32,172,3,0,104,181,3,0,136,191,3,0,72,198,3,0,224,205,3,0,80,214,3,0,192,222,3,0,88,230,3,0,200,238,3,0,56,247,3,0,128,0,4,0,240,8,4,0,56,18,4,0,128,27,4,0,160,37,4,0,120,38,4,0,80,39,4,0,40,40,4,0,0,41,4,0,216,41,4,0,176,42,4,0,136,43,4,0,96,44,4,0,56,45,4,0,24,0,0,0,255,255,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,254,255,255,255,0,0,0,0,0,0,0,0,254,255,255,255,254,255,255,255,254,255,255,255,254,255,255,255,254,255,255,255,254,255,255,255,254,255,255,255,254,255,255,255,254,255,255,255,254,255,255,255,0,0,0,0,254,255,255,255,254,255,255,255,0,0,0,0,254,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,0,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,43,0,0,0,44,0,0,0,45,0,0,0,46,0,0,0,47,0,0,0,48,0,0,0,49,0,0,0,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,117,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,247,160,228,176,0,0,16,1,117,55,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,196,98,104,38,0,0,16,1,117,55,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,182,13,106,182,0,0,32,0,117,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,234,72,75,95,0,0,32,0,117,55,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,227,17,66,212,0,0,32,0,117,55,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,252,106,89,175,0,0,32,0,117,51,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,218,129,4,228,0,0,64,0,117,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,190,17,60,200,0,0,64,0,56,55,99,53,50,46,109,99,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,16,112,114,111,116,100,97,116,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,124,186,222,133,0,0,16,1,114,116,101,95,51,48,97,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,51,139,91,239,1,0,16,1,114,116,101,95,51,53,97,46,49,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,41,85,112,125,1,0,16,1,114,116,101,95,51,49,97,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,94,94,131,50,1,0,16,1,114,116,101,95,51,54,97,46,49,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,95,151,55,118,1,0,16,1,114,116,95,50,56,97,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,200,55,65,5,1,0,16,1,114,116,95,51,51,97,46,57,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,27,203,100,114,1,0,16,1,114,116,101,95,50,57,97,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,25,169,218,205,1,0,16,1,114,116,101,95,51,52,97,46,49,48,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,229,231,82,237,1,0,16,1,114,116,45,53,109,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,4,248,174,134,4,0,32,0,114,116,45,55,109,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,16,113,5,79,4,0,32,0,114,116,45,49,109,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,208,137,36,144,4,0,32,0,114,116,45,51,109,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,32,231,92,227,4,0,32,0,114,116,45,54,109,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,124,14,203,19,4,0,32,0,114,116,45,56,109,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,20,80,5,31,4,0,32,0,114,116,45,50,109,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,244,52,160,233,4,0,32,0,114,116,45,52,109,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,139,234,14,223,4,0,32,0,114,116,95,57,46,49,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,101,161,252,171,3,0,16,0,114,116,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,171,17,178,38,5,0,64,0,114,116,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,208,74,230,219,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,114,116,50,52,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,89,81,184,84,0,0,0,8,105,111,98,49,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,105,111,99,49,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,129,32,24,13,0,0,0,8,19,0,0,0,255,255,0,0,0,0,0,0,20,0,0,0,255,255,101,0,0,0,0,0,21,0,0,0,255,255,102,0,0,0,0,0,0,0,0,0,254,0,8,0,200,87,7,0,19,0,0,0,1,7,7,0,80,252,6,0,19,0,0,0,1,7,6,0,16,242,7,0,19,0,0,0,1,7,5,0,104,236,7,0,19,0,0,0,1,7,0,0,128,230,7,0,19,0,0,0,1,7,1,0,184,164,6,0,19,0,0,0,1,7,2,0,80,74,6,0,19,0,0,0,1,7,3,0,192,32,6,0,19,0,0,0,1,7,4,0,32,242,5,0,0,0,0,0,254,0,8,0,160,123,6,0,19,0,0,0,1,56,56,0,80,252,6,0,19,0,0,0,1,56,48,0,16,242,7,0,19,0,0,0,1,56,40,0,104,236,7,0,19,0,0,0,1,56,0,0,128,230,7,0,19,0,0,0,1,56,8,0,184,164,6,0,19,0,0,0,1,56,16,0,80,74,6,0,19,0,0,0,1,56,24,0,192,32,6,0,19,0,0,0,1,56,32,0,32,242,5,0,0,0,0,0,254,0,2,0,64,232,1,0,19,0,0,0,1,64,0,0,96,135,7,0,19,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,72,4,1,0,19,0,0,0,1,128,0,0,96,135,7,0,19,0,0,0,1,128,128,0,152,182,7,0,0,0,0,0,254,0,4,0,56,24,1,0,20,0,0,0,1,3,0,0,192,255,2,0,20,0,0,0,1,3,1,0,208,75,4,0,20,0,0,0,1,3,2,0,8,49,4,0,20,0,0,0,1,3,3,0,72,246,3,0,0,0,0,0,254,0,4,0,104,22,1,0,20,0,0,0,1,12,0,0,80,246,3,0,20,0,0,0,1,12,4,0,248,38,7,0,20,0,0,0,1,12,8,0,112,212,3,0,20,0,0,0,1,12,12,0,248,160,5,0,0,0,0,0,254,0,4,0,40,22,1,0,20,0,0,0,1,48,0,0,192,255,2,0,20,0,0,0,1,48,16,0,208,75,4,0,20,0,0,0,1,48,32,0,8,49,4,0,20,0,0,0,1,48,48,0,72,246,3,0,0,0,0,0,254,0,4,0,168,20,1,0,20,0,0,0,1,192,0,0,80,246,3,0,20,0,0,0,1,192,64,0,248,38,7,0,20,0,0,0,1,192,128,0,112,212,3,0,20,0,0,0,1,192,192,0,248,160,5,0,0,0,0,0,254,0,4,0,208,19,1,0,21,0,0,0,1,3,0,0,192,255,2,0,21,0,0,0,1,3,1,0,208,75,4,0,21,0,0,0,1,3,2,0,8,49,4,0,21,0,0,0,1,3,3,0,72,246,3,0,0,0,0,0,254,0,4,0,24,19,1,0,21,0,0,0,1,12,0,0,80,246,3,0,21,0,0,0,1,12,4,0,248,38,7,0,21,0,0,0,1,12,8,0,112,212,3,0,21,0,0,0,1,12,12,0,248,160,5,0,0,0,0,0,254,0,2,0,144,212,8,0,21,0,0,0,1,16,0,0,96,135,7,0,21,0,0,0,1,16,16,0,152,182,7,0,0,0,0,0,254,0,2,0,40,111,8,0,21,0,0,0,1,32,0,0,96,135,7,0,21,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,21,0,0,0,1,64,0,0,96,135,7,0,21,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,168,79,2,0,21,0,0,0,1,128,0,0,32,182,8,0,21,0,0,0,1,128,128,0,80,251,6,0,0,0,0,0,184,40,2,0,1,0,0,0,72,234,148,0,248,191,2,0,184,164,8,0,1,0,0,0,73,234,148,0,64,246,1,0,104,28,8,0,1,0,0,0,74,234,148,0,232,209,1,0,64,183,7,0,1,0,0,0,75,234,148,0,104,195,5,0,56,210,6,0,1,0,0,0,138,233,148,0,192,135,2,0,24,163,6,0,1,0,0,0,139,233,148,0,240,108,2,0,152,122,6,0,1,0,0,0,136,233,148,0,96,82,2,0,192,72,6,0,1,0,0,0,137,233,148,0,32,56,2,0,48,123,2,0,1,0,0,0,140,233,148,0,152,30,2,0,96,69,2,0,1,0,0,0,141,233,148,0,232,10,2,0,176,223,1,0,1,0,0,0,202,232,148,0,72,198,1,0,192,209,1,0,1,0,0,0,203,232,148,0,24,182,1,0,24,198,1,0,1,0,0,0,200,232,148,0,40,167,1,0,120,189,1,0,1,0,0,0,201,232,148,0,200,149,1,0,248,187,8,0,1,0,0,0,204,232,148,0,56,126,1,0,184,179,8,0,1,0,0,0,205,232,148,0,32,101,1,0,192,122,8,0,1,0,0,0,42,232,148,0,208,174,1,0,40,116,8,0,1,0,0,0,43,232,148,0,48,160,1,0,72,110,8,0,1,0,0,0,40,232,148,0,160,140,1,0,184,102,8,0,1,0,0,0,41,232,148,0,56,112,1,0,240,45,8,0,1,0,0,0,44,232,148,0,32,92,1,0,40,38,8,0,1,0,0,0,45,232,148,0,64,77,1,0,248,16,8,0,1,0,0,0,2,232,148,0,32,231,8,0,192,12,8,0,1,0,0,0,3,232,148,0,88,214,8,0,224,5,8,0,1,0,0,0,0,232,148,0,224,202,8,0,144,1,8,0,1,0,0,0,1,232,148,0,72,193,8,0,72,204,7,0,1,0,0,0,4,232,148,0,144,180,8,0,208,196,7,0,1,0,0,0,5,232,148,0,208,164,8,0,88,212,3,0,1,0,0,0,248,221,146,0,40,185,3,0,56,122,5,0,1,0,0,0,76,234,148,0,224,12,8,0,0,105,5,0,1,0,0,0,77,234,148,0,128,176,7,0,152,120,4,0,1,0,0,0,78,234,148,0,248,114,7,0,112,109,5,0,1,0,0,0,79,234,148,0,32,105,5,0,32,77,1,0,1,0,0,0,231,231,148,0,216,70,1,0,8,0,0,1,0,0,0,1,8,0,0,0,0,0,0,0,168,86,7,0,1,0,0,0,176,236,146,0,248,191,2,0,24,38,7,0,1,0,0,0,135,2,147,0,184,160,2,0,56,210,6,0,1,0,0,0,130,2,147,0,192,135,2,0,24,163,6,0,1,0,0,0,131,2,147,0,240,108,2,0,152,122,6,0,1,0,0,0,128,2,147,0,96,82,2,0,192,72,6,0,1,0,0,0,129,2,147,0,32,56,2,0,200,110,3,0,1,0,0,0,132,2,147,0,152,30,2,0,120,89,3,0,1,0,0,0,133,2,147,0,232,10,2,0,40,246,1,0,1,0,0,0,177,236,146,0,64,246,1,0,144,236,1,0,1,0,0,0,199,249,146,0,136,224,1,0,176,223,1,0,1,0,0,0,194,249,146,0,72,198,1,0,192,209,1,0,1,0,0,0,195,249,146,0,24,182,1,0,24,198,1,0,1,0,0,0,192,249,146,0,40,167,1,0,120,189,1,0,1,0,0,0,193,249,146,0,200,149,1,0,224,22,1,0,1,0,0,0,196,249,146,0,56,126,1,0,160,14,1,0,1,0,0,0,197,249,146,0,32,101,1,0,32,77,1,0,1,0,0,0,200,7,147,0,216,70,1,0,88,212,3,0,1,0,0,0,232,221,146,0,40,185,3,0,0,0,0,0,0,0,0,0,184,40,2,0,1,0,0,0,41,39,216,0,248,191,2,0,8,227,1,0,1,0,0,0,32,39,216,0,184,160,2,0,152,224,1,0,1,0,0,0,33,39,216,0,136,224,1,0,240,167,7,0,1,0,0,0,44,39,216,0,192,135,2,0,176,163,7,0,1,0,0,0,47,39,216,0,240,108,2,0,208,158,7,0,1,0,0,0,42,39,216,0,96,82,2,0,184,154,7,0,1,0,0,0,43,39,216,0,32,56,2,0,8,96,7,0,1,0,0,0,36,39,216,0,72,198,1,0,48,89,7,0,1,0,0,0,46,39,216,0,24,182,1,0,16,83,7,0,1,0,0,0,34,39,216,0,40,167,1,0,96,79,7,0,1,0,0,0,35,39,216,0,200,149,1,0,48,76,7,0,1,0,0,0,45,39,216,0,56,126,1,0,144,72,7,0,1,0,0,0,37,39,216,0,32,101,1,0,88,212,3,0,1,0,0,0,48,38,216,0,40,185,3,0,16,17,8,0,1,0,0,0,40,39,216,0,224,12,8,0,248,5,8,0,9,0,0,0,112,39,216,0,32,58,1,0,144,250,7,0,9,0,0,0,113,39,216,0,32,58,1,0,248,241,7,0,9,0,0,0,114,39,216,0,32,58,1,0,72,82,8,0,9,0,0,0,115,39,216,0,32,58,1,0,168,86,7,0,1,0,0,0,232,47,216,0,248,191,2,0,24,38,7,0,1,0,0,0,236,47,216,0,184,160,2,0,56,210,6,0,1,0,0,0,35,48,216,0,192,135,2,0,24,163,6,0,1,0,0,0,34,48,216,0,240,108,2,0,152,122,6,0,1,0,0,0,33,48,216,0,96,82,2,0,192,72,6,0,1,0,0,0,32,48,216,0,32,56,2,0,152,31,6,0,1,0,0,0,36,48,216,0,152,30,2,0,248,97,5,0,1,0,0,0,37,48,216,0,232,10,2,0,136,20,3,0,1,0,0,0,38,48,216,0,152,138,8,0,40,246,1,0,1,0,0,0,233,47,216,0,64,246,1,0])
.concat([144,236,1,0,1,0,0,0,237,47,216,0,136,224,1,0,176,223,1,0,1,0,0,0,43,48,216,0,72,198,1,0,192,209,1,0,1,0,0,0,42,48,216,0,24,182,1,0,24,198,1,0,1,0,0,0,41,48,216,0,40,167,1,0,120,189,1,0,1,0,0,0,40,48,216,0,200,149,1,0,8,182,1,0,1,0,0,0,44,48,216,0,56,126,1,0,32,167,1,0,1,0,0,0,45,48,216,0,32,101,1,0,216,244,8,0,1,0,0,0,46,48,216,0,96,32,8,0,88,212,3,0,1,0,0,0,144,46,216,0,40,185,3,0,240,152,1,0,1,0,0,0,238,47,216,0,216,70,1,0,16,17,8,0,1,0,0,0,234,47,216,0,224,12,8,0,72,65,1,0,9,0,0,0,232,48,216,0,32,58,1,0,48,50,1,0,9,0,0,0,224,48,216,0,32,58,1,0,0,0,0,0,32,0,0,0,64,0,0,0,96,0,0,0,128,0,0,0,160,0,0,0,192,0,0,0,224,0,0,0,0,0,0,0,4,0,0,0,8,0,0,0,12,0,0,0,16,0,0,0,20,0,0,0,24,0,0,0,28,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,132,2,0,0,188,29,0,0,168,13,0,0,240,10,0,0,244,3,0,0,46,8,0,0,132,23,0,0,206,0,0,0,186,15,0,0,134,45,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,82,0,0,0,246,45,0,0,46,12,0,0,18,9,0,0,148,5,0,0,98,16,0,0,36,10,0,0,124,10,0,0,16,49,0,0,108,5,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,34,6,0,0,114,47,0,0,26,7,0,0,64,4,0,0,90,3,0,0,104,11,0,0,228,43,0,0,174,5,0,0,22,9,0,0,158,44,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,34,6,0,0,114,47,0,0,26,7,0,0,64,4,0,0,90,3,0,0,104,11,0,0,228,43,0,0,50,13,0,0,22,9,0,0,158,44,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,158,5,0,0,60,35,0,0,242,3,0,0,254,0,0,0,18,14,0,0,230,14,0,0,150,30,0,0,224,7,0,0,188,26,0,0,206,28,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,16,0,0,0,24,0,0,0,32,0,0,0,40,0,0,0,48,0,0,0,56,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,180,2,0,0,24,9,0,0,190,0,0,0,76,10,0,0,168,3,0,0,78,13,0,0,116,22,0,0,198,8,0,0,72,43,0,0,28,8,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,49,51,54,48,52,49,45,50,48,55,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,180,241,26,14,0,0,16,1,49,51,54,48,52,49,45,50,48,56,46,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,56,162,81,191,0,0,16,1,49,51,54,48,51,55,45,50,48,53,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,81,237,153,109,0,0,16,1,49,51,54,48,51,55,45,50,48,54,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,145,173,94,84,0,0,16,1,49,51,54,48,52,49,45,51,48,57,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,43,205,203,90,0,0,16,1,49,51,54,48,52,49,45,51,49,48,46,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,119,171,137,24,0,0,16,1,49,51,54,48,51,55,45,49,50,48,46,49,54,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,204,243,231,110,0,0,16,1,49,51,54,48,51,55,45,49,49,57,46,49,54,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,31,134,25,250,0,0,16,1,49,51,54,48,51,55,45,49,48,52,46,54,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,89,91,42,158,0,0,32,0,49,51,54,48,51,55,45,49,49,49,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,51,15,112,145,0,0,32,0,49,51,54,48,51,55,45,49,49,50,46,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,190,48,147,134,0,0,32,0,49,51,54,48,51,55,45,49,49,51,46,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,168,208,151,212,0,0,32,0,49,51,54,48,51,55,45,49,49,52,46,49,109,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,130,152,239,41,0,0,32,0,49,51,54,48,51,55,45,49,49,53,46,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,152,184,16,149,0,0,32,0,49,51,54,48,51,55,45,49,49,54,46,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,91,172,224,17,0,0,32,0,49,51,54,48,51,55,45,49,49,55,46,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,65,219,165,41,0,0,32,0,49,51,54,48,51,55,45,49,49,56,46,50,109,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,99,178,243,139,0,0,32,0,55,52,115,52,55,50,45,49,51,54,48,51,55,45,49,48,49,46,55,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,111,247,100,41,0,0,32,0,55,52,115,52,55,50,45,49,51,54,48,51,55,45,49,48,50,46,53,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,108,236,79,77,0,0,32,0,55,52,115,50,56,55,45,49,51,54,48,51,55,45,49,48,51,46,52,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,8,207,92,108,0,0,32,0,49,51,54,48,52,49,45,50,48,55,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,180,241,26,14,0,0,16,1,49,51,54,48,52,49,45,50,48,56,46,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,56,162,81,191,0,0,16,1,49,51,54,48,51,55,45,50,48,53,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,81,237,153,109,0,0,16,1,49,51,54,48,51,55,45,50,48,54,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,145,173,94,84,0,0,16,1,49,51,54,48,52,49,45,50,48,57,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,111,181,201,221,0,0,16,1,49,51,54,48,52,49,45,50,49,48,46,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,79,138,231,255,0,0,16,1,49,51,54,48,51,55,45,49,50,48,46,49,54,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,204,243,231,110,0,0,16,1,49,51,54,48,51,55,45,49,49,57,46,49,54,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,31,134,25,250,0,0,16,1,49,51,54,48,51,55,45,49,48,52,46,54,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,89,91,42,158,0,0,32,0,49,51,54,48,51,55,45,49,49,49,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,51,15,112,145,0,0,32,0,49,51,54,48,51,55,45,49,49,50,46,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,190,48,147,134,0,0,32,0,49,51,54,48,51,55,45,49,49,51,46,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,168,208,151,212,0,0,32,0,49,51,54,48,51,55,45,49,49,52,46,49,109,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,130,152,239,41,0,0,32,0,49,51,54,48,51,55,45,49,49,53,46,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,152,184,16,149,0,0,32,0,49,51,54,48,51,55,45,49,49,54,46,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,91,172,224,17,0,0,32,0,49,51,54,48,51,55,45,49,49,55,46,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,65,219,165,41,0,0,32,0,49,51,54,48,51,55,45,49,49,56,46,50,109,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,99,178,243,139,0,0,32,0,55,52,115,52,55,50,45,49,51,54,48,51,55,45,49,48,49,46,55,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,111,247,100,41,0,0,32,0,55,52,115,52,55,50,45,49,51,54,48,51,55,45,49,48,50,46,53,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,108,236,79,77,0,0,32,0,55,52,115,50,56,55,45,49,51,54,48,51,55,45,49,48,51,46,52,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,8,207,92,108,0,0,32,0,49,51,54,48,52,49,45,49,48,55,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,216,116,175,63,0,0,16,1,49,51,54,48,52,49,45,49,48,56,46,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,21,216,230,241,0,0,16,1,49,51,54,48,51,55,45,50,48,53,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,81,237,153,109,0,0,16,1,49,51,54,48,51,55,45,50,48,54,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,145,173,94,84,0,0,16,1,49,51,54,48,52,49,45,49,48,57,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,184,197,208,86,0,0,16,1,49,51,54,48,52,49,45,49,49,48,46,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,151,227,154,59,0,0,16,1,49,51,54,48,51,55,45,49,50,48,46,49,54,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,204,243,231,110,0,0,16,1,49,51,54,48,51,55,45,49,49,57,46,49,54,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,31,134,25,250,0,0,16,1,49,51,54,48,51,55,45,49,48,52,46,54,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,89,91,42,158,0,0,32,0,49,51,54,48,51,55,45,49,49,49,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,51,15,112,145,0,0,32,0,49,51,54,48,51,55,45,49,49,50,46,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,190,48,147,134,0,0,32,0,49,51,54,48,51,55,45,49,49,51,46,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,168,208,151,212,0,0,32,0,49,51,54,48,51,55,45,49,49,52,46,49,109,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,130,152,239,41,0,0,32,0,49,51,54,48,51,55,45,49,49,53,46,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,152,184,16,149,0,0,32,0,49,51,54,48,51,55,45,49,49,54,46,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,91,172,224,17,0,0,32,0,49,51,54,48,51,55,45,49,49,55,46,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,65,219,165,41,0,0,32,0,49,51,54,48,51,55,45,49,49,56,46,50,109,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,99,178,243,139,0,0,32,0,55,52,115,52,55,50,45,49,51,54,48,51,55,45,49,48,49,46,55,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,111,247,100,41,0,0,32,0,55,52,115,52,55,50,45,49,51,54,48,51,55,45,49,48,50,46,53,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,108,236,79,77,0,0,32,0,55,52,115,50,56,55,45,49,51,54,48,51,55,45,49,48,51,46,52,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,8,207,92,108,0,0,32,0,56,98,45,100,107,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,155,28,108,22,0,0,16,1,56,98,45,100,107,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,170,123,200,158,0,0,16,1,56,98,45,100,107,46,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,98,169,54,248,0,0,16,1,56,98,45,100,107,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,212,102,88,212,0,0,16,1,56,98,45,100,107,46,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,96,44,117,168,0,0,16,1,56,98,45,100,107,46,51,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,103,8,131,68,0,0,32,0,56,98,45,100,107,46,51,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,242,198,72,97,0,0,32,0,56,98,45,100,107,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,245,9,68,227,0,0,32,0,56,98,45,100,107,46,55,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,202,55,220,180,0,0,32,0,56,98,45,100,107,46,55,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,168,248,90,101,0,0,32,0,56,98,45,100,107,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,99,39,155,162,0,0,32,0,56,98,46,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,18,154,55,199,0,0,32,0,56,98,46,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,180,18,102,17,0,0,32,0,56,98,46,50,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,136,105,88,48,0,0,32,0,56,50,115,49,52,55,46,112,114,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,146,188,229,70,0,0,32,0,112,108,115,49,53,51,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,235,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,128,0,0,0,192,0,0,0,0,1,0,0,64,1,0,0,128,1,0,0,192,1,0,0,0,2,0,0,64,2,0,0,128,2,0,0,192,2,0,0,0,3,0,0,64,3,0,0,128,3,0,0,192,3,0,0,4,0,0,0,0,0,0,0,20,0,0,0,16,0,0,0,12,0,0,0,8,0,0,0,28,0,0,0,24,0,0,0,36,0,0,0,32,0,0,0,52,0,0,0,48,0,0,0,44,0,0,0,40,0,0,0,60,0,0,0,56,0,0,0,0,0,0,0,16,0,0,0,32,0,0,0,48,0,0,0,64,0,0,0,80,0,0,0,96,0,0,0,112,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,1,1,0,0,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,99,104,51,46,104,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,33,80,104,32,1,0,16,1,99,108,51,46,108,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,210,253,147,1,0,16,1,99,104,48,46,104,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,138,221,56,148,1,0,16,1,99,108,48,46,108,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,19,226,169,6,1,0,16,1,116,52,52,46,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,110,24,69,219,2,0,32,0,116,52,53,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,212,100,7,77,2,0,32,0,116,52,54,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,164,101,196,240,2,0,32,0,116,52,55,46,49,49,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,75,178,99,18,2,0,32,0,116,52,56,46,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,79,148,41,65,2,0,32,0,116,52,57,46,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,249,230,70,35,2,0,32,0,116,53,48,46,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,62,84,34,227,2,0,32,0,116,53,49,46,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,177,247,155,34,2,0,32,0,116,53,51,46,97,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,148,36,8,26,3,0,32,0,116,53,52,46,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,197,22,108,7,3,0,32,0,116,53,53,46,97,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,165,119,216,37,3,0,32,0,116,53,54,46,97,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,245,19,18,91,3,0,32,0,116,53,55,46,98,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,199,224,132,10,4,0,32,0,116,53,56,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,29,18,116,168,4,0,32,0,116,53,57,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,144,185,222,105,4,0,32,0,116,54,48,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,153,159,198,20,4,0,32,0,116,53,50,46,118,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,128,189,177,45,5,0,64,0,120,109,117,108,116,105,112,108,95,105,56,55,53,49,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,205,179,206,200,0,0,0,8,48,56,49,117,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,229,173,217,180,1,0,16,1,48,56,49,98,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,155,77,96,76,2,0,16,1,48,56,49,97,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,169,119,199,180,3,0,32,0,48,56,49,97,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,217,200,42,39,3,0,32,0,48,56,49,97,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,164,154,75,70,4,0,32,0,48,56,49,97,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,89,55,23,78,4,0,32,0,48,56,49,97,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,128,109,254,233,4,0,32,0,48,56,49,97,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,154,178,34,138,4,0,32,0,48,56,49,97,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,234,186,182,20,5,0,64,0,118,101,110,100,101,116,116,97,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,48,78,172,251,0,0,0,8,48,56,49,100,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,149,164,93,51,1,0,16,1,48,56,49,98,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,155,77,96,76,2,0,16,1,48,56,49,97,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,169,119,199,180,3,0,32,0,48,56,49,97,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,217,200,42,39,3,0,32,0,48,56,49,97,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,164,154,75,70,4,0,32,0,48,56,49,97,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,89,55,23,78,4,0,32,0,48,56,49,97,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,128,109,254,233,4,0,32,0,48,56,49,97,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,154,178,34,138,4,0,32,0,48,56,49,97,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,234,186,182,20,5,0,64,0,118,101,110,100,101,116,116,97,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,48,78,172,251,0,0,0,8,118,100,107,45,101,118,101,110,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,132,90,224,205,1,0,16,1,118,100,107,45,111,100,100,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,64,234,111,15,1,0,16,1,118,100,107,45,52,46,49,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,240,68,165,235,2,0,16,1,118,100,107,45,51,46,50,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,27,124,84,90,3,0,32,0,118,100,107,45,48,49,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,190,36,90,25,4,0,32,0,118,100,107,45,48,55,46,50,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,6,31,212,66,5,0,32,0,118,100,107,45,48,54,46,50,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,34,71,213,5,0,32,0,118,100,107,45,48,52,46,50,45,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,71,5,115,10,5,0,32,0,118,100,107,45,48,53,46,51,45,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,109,69,186,5,0,32,0,118,100,107,45,48,50,46,49,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,116,50,16,178,6,0,64,0,118,100,107,45,48,51,46,49,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,211,118,23,99,7,0,64,0,105,99,49,48,48,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,151,28,237,152,0,0,0,8,105,99,49,48,49,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,108,184,219,207,0,0,0,8,119,111,114,108,100,32,99,111,117,114,116,32,116,101,110,110,105,115,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,240,125,69,164,0,0,16,1,119,111,114,108,100,32,99,108,97,115,115,32,98,97,115,101,98,97,108,108,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,192,208,134,65,0,0,16,1,118,105,103,105,108,97,110,116,101,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,13,154,212,121,0,0,16,1,118,105,99,116,111,114,121,32,114,117,110,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,69,208,203,133,0,0,16,1,116,118,32,115,112,111,114,116,115,32,104,111,99,107,101,121,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,207,91,254,151,0,0,16,1,116,118,32,115,112,111,114,116,115,32,102,111,111,116,98,97,108,108,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,87,181,37,94,0,0,16,1,116,118,32,115,112,111,114,116,115,32,98,97,115,107,101,116,98,97,108,108,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,83,214,84,234,0,0,16,1,116,117,114,114,105,99,97,110,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,223,94,4,235,0,0,16,1,116,105,109,101,98,97,108,108,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,25,80,57,93,0,0,16,1,116,105,103,101,114,32,114,111,97,100,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,45,73,93,152,0,0,16,1,116,97,108,101,115,112,105,110,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,204,206,233,186,0,0,16,1,116,97,107,105,110,39,32,105,116,32,116,111,32,116,104,101,32,104,111,111,112,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,151,23,213,233,0,0,16,1,115,111,109,101,114,32,97,115,115,97,117,108,116,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,233,242,202,143,0,0,16,1,115,111,108,100,105,101,114,32,98,108,97,100,101,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,19,139,182,75,0,0,16,1,115,105,110,105,115,116,114,111,110,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,189,45,110,79,0,0,16,1,115,105,100,101,97,114,109,115,32,45,32,104,121,112,101,114,32,100,121,110,101,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,159,60,153,209,0,0,16,1,115,104,111,99,107,109,97,110,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,44,70,116,39,0,0,16,1,115,112,97,99,101,32,104,97,114,114,105,101,114,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,184,94,176,67,0,0,16,1,115,97,109,117,114,97,105,45,103,104,111,115,116,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,183,36,169,119,0,0,16,1,106,97,99,107,32,110,105,99,107,108,97,117,115,39,32,116,117,114,98,111,32,103,111,108,102,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,114,69,56,131,0,0,16,1,110,101,117,116,111,112,105,97,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,27,78,169,169,0,0,16,1,110,101,117,116,111,112,105,97,32,105,105,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,7,67,237,196,0,0,16,1,109,111,116,111,32,114,111,97,100,101,114,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,68,213,176,226,0,0,16,1,109,105,108,105,116,97,114,121,32,109,97,100,110,101,115,115,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,247,22,243,147,0,0,16,1,109,97,103,105,99,97,108,32,99,104,97,115,101,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,121,41,205,149,0,0,16,1,107,105,110,103,32,111,102,32,99,97,115,105,110,111,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,64,34,46,47,0,0,16,1,107,101,105,116,104,32,99,111,117,114,97,103,101,32,105,110,32,97,108,112,104,97,32,122,111,110,101,115,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,114,122,77,71,0,0,16,1,105,109,112,111,115,115,97,109,111,108,101,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,95,15,71,226,0,0,16,1,103,104,111,115,116,32,109,97,110,111,114,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,253,193,180,45,0,0,16,1,103,97,108,97,103,97,32,39,57,48,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,198,222,9,41,0,0,16,1,99,104,97,109,112,105,111,110,115,32,102,111,114,101,118,101,114,32,98,111,120,105,110,103,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,154,136,238,21,0,0,16,1,102,105,110,97,108,32,108,97,112,32,116,119,105,110,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,163,142,64,38,0,0,16,1,102,97,110,116,97,115,121,32,122,111,110,101,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,61,87,195,232,0,0,16,1,100,117,110,103,101,111,110,32,101,120,112,108,111,114,101,114,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,21,21,240,79,0,0,16,1,100,114,97,103,111,110,39,115,32,99,117,114,115,101,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,9,75,44,125,0,0,16,1,100,101,118,105,108,39,115,32,99,114,117,115,104,32,45,32,110,97,120,97,116,32,112,105,110,98,97,108,108,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,146,68,123,21,0,0,16,1,100,101,101,112,32,98,108,117,101,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,68,11,180,22,0,0,16,1,100,101,97,100,32,109,111,111,110,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,11,139,217,245,0,0,16,1,100,97,118,105,115,32,99,117,112,32,116,101,110,110,105,115,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,150,181,218,158,0,0,16,1,100,97,114,107,119,105,110,103,32,100,117,99,107,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,6,118,201,74,0,0,16,1,99,121,98,101,114,32,99,111,114,101,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,62,110,251,76,0,0,16,1,99,114,97,116,101,114,109,97,122,101,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,58,232,51,144,0,0,16,1,99,104,105,110,97,32,119,97,114,114,105,111,114,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,29,54,238,162,0,0,16,1,98,114,97,118,111,109,97,110,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,2,139,160,204,0,0,16,1,98,111,109,98,101,114,109,97,110,32,39,57,51,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,28,28,23,86,0,0,16,1,98,108,111,111,100,121,32,119,111,108,102,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,188,246,186,55,0,0,16,1,98,108,97,122,105,110,103,32,108,97,122,101,114,115,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,246,176,161,180,0,0,16,1,98,97,116,116,108,101,32,114,111,121,97,108,101,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,175,1,11,231,0,0,16,1,98,97,108,108,105,115,116,105,120,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,137,161,15,66,0,0,16,1,97,101,114,111,32,98,108,97,115,116,101,114,115,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,50,11,62,176,0,0,16,1,110,101,119,32,97,100,118,101,110,116,117,114,101,32,105,115,108,97,110,100,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,2,24,106,117,0,0,16,1,6,0,0,0,16,0,0,0,152,33,8,0,240,236,7,0,32,184,7,0,184,137,7,0,16,90,7,0,0,0,0,0,0,0,0,0,0,0,0,0,48,55,50,45,103,48,50,46,49,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,214,225,12,88,1,0,16,1,48,55,50,45,103,48,49,46,49,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,239,61,132,159,1,0,16,1,48,55,50,45,109,49,51,46,49,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,35,148,108,243,1,0,16,1,48,55,50,45,108,49,50,46,49,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,186,217,249,132,1,0,16,1,48,55,50,45,101,48,51,46,54,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,53,122,107,134,2,0,16,1,48,55,50,45,98,48,55,46,49,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,16,201,30,186,3,0,32,0,48,55,50,45,98,48,54,46,49,54,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,171,188,43,207,3,0,32,0,48,55,50,45,98,48,56,46,51,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,173,0,229,125,4,0,32,0,48,55,50,45,98,48,57,46,56,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,147,80,8,170,4,0,32,0,48,55,50,45,98,49,48,46,49,50,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,83,189,125,87,4,0,32,0,48,55,50,45,98,49,49,46,49,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,93,176,250,85,4,0,32,0,48,55,50,45,100,48,53,46,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,59,167,151,19,5,0,64,0,48,55,50,45,100,48,52,46,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,19,128,119,120,5,0,64,0,115,105,109,112,115,111,110,115,52,112,97,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,73,4,63,236,0,0,0,8,48,55,50,45,115,48,50,46,49,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,71,122,95,38,1,0,16,1,48,55,50,45,116,48,49,46,49,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,45,92,222,145,1,0,16,1,48,55,50,45,50,49,51,46,49,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,174,169,38,179,1,0,16,1,48,55,50,45,50,49,50,46,49,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,55,157,77,88,1,0,16,1,48,55,50,45,103,48,51,46,54,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,12,133,193,118,2,0,16,1,48,55,50,45,98,48,55,46,49,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,16,201,30,186,3,0,32,0,48,55,50,45,98,48,54,46,49,54,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,171,188,43,207,3,0,32,0,48,55,50,45,98,48,56,46,51,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,173,0,229,125,4,0,32,0,48,55,50,45,98,48,57,46,56,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,147,80,8,170,4,0,32,0,48,55,50,45,98,49,48,46,49,50,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,83,189,125,87,4,0,32,0,48,55,50,45,98,49,49,46,49,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,93,176,250,85,4,0,32,0,48,55,50,45,100,48,53,46,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,59,167,151,19,5,0,64,0,48,55,50,45,100,48,52,46,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,19,128,119,120,5,0,64,0,115,105,109,112,115,111,110,115,50,112,106,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,78,165,80,53,0,0,0,8,48,55,50,45,103,48,50,46,49,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,214,225,12,88,1,0,16,1,48,55,50,45,112,48,49,46,49,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,234,234,206,7,1,0,16,1,48,55,50,45,49,49,51,46,49,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,90,16,129,135,1,0,16,1,48,55,50,45,49,49,50,46,49,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,4,148,214,59,1,0,16,1,48,55,50,45,101,48,51,46,54,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,53,122,107,134,2,0,16,1,48,55,50,45,98,48,55,46,49,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,16,201,30,186,3,0,32,0,48,55,50,45,98,48,54,46,49,54,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,171,188,43,207,3,0,32,0,48,55,50,45,98,48,56,46,51,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,173,0,229,125,4,0,32,0,48,55,50,45,98,48,57,46,56,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,147,80,8,170,4,0,32,0,48,55,50,45,98,49,48,46,49,50,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,83,189,125,87,4,0,32,0,48,55,50,45,98,49,49,46,49,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,93,176,250,85,4,0,32,0,48,55,50,45,100,48,53,46,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,59,167,151,19,5,0,64,0,48,55,50,45,100,48,52,46,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,19,128,119,120,5,0,64,0,115,105,109,112,115,111,110,115,50,112,97,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,48,78,172,251,0,0,0,8,48,55,50,45,103,48,50,46,49,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,214,225,12,88,1,0,16,1,48,55,50,45,112,48,49,46,49,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,234,234,206,7,1,0,16,1,48,55,50,45,95,49,51,46,49,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,102,223,230,84,1,0,16,1,48,55,50,45,95,49,50,46,49,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,37,98,99,150,1,0,16,1,48,55,50,45,103,48,51,46,54,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,12,133,193,118,2,0,16,1,48,55,50,45,98,48,55,46,49,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,16,201,30,186,3,0,32,0,48,55,50,45,98,48,54,46,49,54,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,171,188,43,207,3,0,32,0,48,55,50,45,98,48,56,46,51,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,173,0,229,125,4,0,32,0,48,55,50,45,98,48,57,46,56,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,147,80,8,170,4,0,32,0,48,55,50,45,98,49,48,46,49,50,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,83,189,125,87,4,0,32,0,48,55,50,45,98,49,49,46,49,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,93,176,250,85,4,0,32,0,48,55,50,45,100,48,53,46,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,59,167,151,19,5,0,64,0,48,55,50,45,100,48,52,46,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,19,128,119,120,5,0,64,0,115,105,109,112,115,111,110,115,50,112,50,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,48,78,172,251,0,0,0,8,97,108,100,121,110,101,115,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,176,38,33,76,0,0,16,1,118,49,48,52,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,15,7,81,224,1,0,16,1,116,48,55,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,77,59,148,147,2,0,32,0,97,48,55,48,48,46,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,156,174,169,38,3,0,32,0,97,48,55,48,48,46,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,193,31,188,121,3,0,32,0,97,48,55,48,49,46,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,129,127,96,35,3,0,32,0,97,48,55,48,49,46,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,55,253,46,95,3,0,32,0,97,48,55,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,27,158,35,66,3,0,32,0,98,48,55,48,48,46,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,4,105,9,175,4,0,32,0,98,48,55,48,48,46,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,38,222,83,109,4,0,32,0,99,103,118,49,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,62,236,2,218,4,0,32,0,109,48,55,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,206,175,199,172,5,0,64,0,105,103,115,48,50,55,97,95,112,104,111,116,111,121,50,107,95,118,49,48,48,95,99,104,105,110,97,95,97,108,116,46,97,115,105,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,87,242,215,109,7,0,16,1,118,49,48,50,46,117,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,159,218,94,166,1,0,16,1,118,49,48,50,46,117,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,4,85,202,185,1,0,16,1,118,49,48,50,46,117,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,27,98,1,146,1,0,16,1,118,49,48,50,46,117,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,143,43,226,59,1,0,16,1,116,48,55,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,77,59,148,147,2,0,32,0,97,48,55,48,48,46,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,156,174,169,38,3,0,32,0,97,48,55,48,48,46,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,193,31,188,121,3,0,32,0,97,48,55,48,49,46,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,129,127,96,35,3,0,32,0,97,48,55,48,49,46,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,55,253,46,95,3,0,32,0,97,48,55,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,27,158,35,66,3,0,32,0,98,48,55,48,48,46,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,4,105,9,175,4,0,32,0,98,48,55,48,48,46,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,38,222,83,109,4,0,32,0,99,103,118,49,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,62,236,2,218,4,0,32,0,109,48,55,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,206,175,199,172,5,0,64,0,105,103,115,48,50,55,97,95,112,104,111,116,111,121,50,107,95,118,49,48,48,95,99,104,105,110,97,95,97,108,116,46,97,115,105,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,87,242,215,109,7,0,16,1,122,101,114,111,32,52,32,99,104,97,109,112,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,33,103,21,238,0,0,16,1,121,111,117,107,97,105,32,100,111,117,99,104,117,117,107,105,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,6,183,49,241,0,0,16,1,120,101,118,105,111,117,115,32,45,32,102,97,114,100,114,97,117,116,32,100,101,110,115,101,116,115,117,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,236,94,248,248,0,0,16,1,119,111,110,100,101,114,32,109,111,109,111,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,20,115,208,89,0,0,16,1,119,111,114,108,100,32,106,111,99,107,101,121,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,84,41,171,169,0,0,16,1,119,105,110,110,105,110,103,32,115,104,111,116,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,88,188,94,155,0,0,16,1,119,97,108,108,97,98,121,33,33,32,45,32,117,115,97,103,105,32,110,111,32,107,117,110,105,32,110,111,32,107,97,110,103,97,114,111,111,32,114,97,99,101,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,199,208,18,1,0,0,16,1,118,111,108,102,105,101,100,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,48,111,34,173,0,0,16,1,118,101,105,103,117,101,115,32,45,32,116,97,99,116,105,99,97,108,32,103,108,97,100,105,97,116,111,114,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,92,140,24,4,0,0,16,1,100,101,116,97,110,97,33,33,32,116,119,105,110,98,101,101,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,128,157,245,92,0,0,16,1,116,111,105,108,101,116,32,107,105,100,115,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,75,120,183,83,0,0,16,1,115,117,112,101,114,32,118,111,108,108,101,121,98,97,108,108,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,159,79,46,206,0,0,16,1,115,116,114,105,112,32,102,105,103,104,116,101,114,32,105,105,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,206,81,252,214,0,0,16,1,115,117,112,101,114,32,115,116,97,114,32,115,111,108,100,105,101,114,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,5,49,14,93,0,0,16,1,115,112,108,97,116,116,101,114,104,111,117,115,101,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,87,148,49,107,0,0,16,1,115,111,110,32,115,111,110,32,105,105,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,242,29,146,215,0,0,16,1,115,111,117,107,111,98,97,110,32,119,111,114,108,100,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,196,221,55,251,0,0,16,1,115,117,112,101,114,32,109,101,116,97,108,32,99,114,117,115,104,101,114,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,54,139,72,86,0,0,16,1,115,105,108,101,110,116,32,100,101,98,117,103,103,101,114,115,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,121,161,110,97,0,0,16,1,107,97,105,122,111,117,32,99,104,111,117,106,105,110,32,115,104,117,98,105,98,105,110,109,97,110,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,110,77,8,169,0,0,16,1,115,104,111,117,103,105,32,115,104,111,115,104,105,110,115,104,97,32,109,117,121,111,117,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,196,43,127,69,0,0,16,1,115,104,111,117,103,105,32,115,104,111,100,97,110,32,105,99,99,104,111,107,117,115,101,110,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,112,137,236,35,0,0,16,1,115,104,105,110,111,98,105,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,243,92,101,188,0,0,16,1,116,97,107,101,100,97,32,115,104,105,110,103,101,110,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,19,190,34,240,0,0,16,1,116,101,110,115,101,105,114,121,117,117,32,45,32,115,97,105,110,116,32,100,114,97,103,111,110,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,203,140,39,46,0,0,16,1,115,97,100,97,107,105,99,104,105,32,55,32,115,101,114,105,101,115,32,45,32,104,105,100,101,121,111,115,104,105,32,110,111,32,111,117,103,111,110,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,111,53,153,249,0,0,16,1,114,45,116,121,112,101,32,112,97,114,116,45,50,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,174,236,7,242,0,0,16,1,114,45,116,121,112,101,32,112,97,114,116,45,49,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,138,210,195,206,0,0,16,1,114,97,115,116,97,110,32,115,97,103,97,32,105,105,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,105,142,195,0,0,0,16,1,112,117,122,122,110,105,99,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,179,149,92,150,0,0,16,1,112,114,111,32,116,101,110,110,105,115,32,119,111,114,108,100,32,99,111,117,114,116,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,69,103,163,17,0,0,16,1,112,115,121,99,104,111,32,99,104,97,115,101,114,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,232,62,136,3,0,0,16,1,112,111,119,101,114,32,115,112,111,114,116,115,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,36,192,238,41,0,0,16,1,112,111,119,101,114,32,101,108,101,118,101,110,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,139,125,100,62,0,0,16,1,112,111,119,101,114,32,108,101,97,103,117,101,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,132,9,24,105,0,0,16,1,112,111,119,101,114,32,108,101,97,103,117,101,32,40,97,108,108,32,115,116,97,114,32,118,101,114,115,105,111,110,41,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,105,87,168,4,0,0,16,1,112,111,119,101,114,32,108,101,97,103,117,101,32,39,57,51,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,51,111,62,125,0,0,16,1,112,111,119,101,114,32,100,114,105,102,116,32,40,106,97,112,97,110,41,32,91,97,93,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,136,217,230,153,0,0,16,1,112,99,32,112,97,99,104,105,45,115,108,111,116,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,51,143,168,10,0,0,16,1,112,99,32,103,101,110,106,105,110,32,45,32,112,105,116,104,101,99,97,110,116,104,114,111,112,117,115,32,99,111,109,112,117,116,101,114,117,114,117,115,32,40,106,97,112,97,110,41,32,91,97,93,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,110,94,179,103,0,0,16,1,112,99,32,103,101,110,106,105,110,32,51,32,45,32,112,105,116,104,101,99,97,110,116,104,114,111,112,117,115,32,99,111,109,112,117,116,101,114,117,114,117,115,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,14,182,112,161,0,0,16,1,112,99,32,103,101,110,106,105,110,32,50,32,45,32,112,105,116,104,101,99,97,110,116,104,114,111,112,117,115,32,99,111,109,112,117,116,101,114,117,114,117,115,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,202,247,40,48,0,0,16,1,112,97,114,97,115,111,108,32,115,116,97,114,115,32,45,32,116,104,101,32,115,116,111,114,121,32,111,102,32,98,117,98,98,108,101,32,98,111,98,98,108,101,32,105,105,105,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,81,100,232,81,0,0,16,1,112,97,99,45,108,97,110,100,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,186,211,250,20,0,0,16,1,111,117,116,32,108,105,118,101,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,91,63,219,92,0,0,16,1,111,98,111,99,99,104,97,109,97,32,107,117,110,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,201,11,59,77,0,0,16,1,110,97,120,97,116,32,115,116,97,100,105,117,109,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,40,209,167,32,0,0,16,1,110,97,120,97,116,32,111,112,101,110,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,34,174,236,96,0,0,16,1,109,114,46,32,104,101,108,105,32,110,111,32,100,97,105,98,111,117,107,101,110,32,40,106,97,112,97,110,41,32,91,97,93,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,150,215,12,172,0,0,16,1,109,111,109,111,116,97,114,111,117,32,100,101,110,115,101,116,115,117,32,103,97,105,100,101,110,32,100,97,105,32,49,32,115,104,117,117,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,92,69,96,248,0,0,16,1,109,97,105,115,111,110,32,105,107,107,111,107,117,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,225,254,120,92,0,0,16,1,109,101,115,111,112,111,116,97,109,105,97,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,241,144,113,232,0,0,16,1,109,97,101,114,99,104,101,110,32,109,97,122,101,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,55,31,90,161,0,0,16,1,107,105,107,105,32,107,97,105,107,97,105,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,221,90,203,192,0,0,16,1,107,97,116,116,111,98,105,33,32,116,97,107,117,104,97,105,32,107,117,110,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,176,68,40,79,0,0,16,1,106,117,117,111,117,107,105,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,62,214,199,200,0,0,16,1,106,46,32,108,101,97,103,117,101,32,103,114,101,97,116,101,115,116,32,101,108,101,118,101,110,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,4,123,217,10,0,0,16,1,104,101,97,118,121,32,117,110,105,116,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,229,61,146,235,0,0,16,1,103,114,97,100,105,117,115,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,101,218,23,5,0,0,16,1,102,111,114,109,97,116,105,111,110,32,115,111,99,99,101,114,32,45,32,111,110,32,106,46,32,108,101,97,103,117,101,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,124,2,70,113,0,0,16,1,102,105,110,97,108,32,109,97,116,99,104,32,116,101,110,110,105,115,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,5,35,13,86,0,0,16,1,102,45,49,32,112,105,108,111,116,32,45,32,121,111,117,39,114,101,32,107,105,110,103,32,111,102,32,107,105,110,103,115,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,116,129,4,9,0,0,16,1,102,45,49,32,100,114,101,97,109,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,48,247,15,213,0,0,16,1,100,114,97,103,111,110,32,115,112,105,114,105,116,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,53,105,167,1,0,0,16,1,100,114,97,103,111,110,32,115,97,98,101,114,32,45,32,97,102,116,101,114,32,115,116,111,114,121,32,111,102,32,100,114,97,103,111,110,32,115,112,105,114,105,116,32,40,106,97,112,97,110,41,32,91,97,93,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,90,231,156,200,0,0,16,1,100,111,114,97,101,109,111,110,32,45,32,110,111,98,105,116,97,32,110,111,32,100,111,114,97,98,105,97,110,32,110,105,103,104,116,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,127,116,58,1,0,0,16,1,100,111,110,32,100,111,107,111,32,100,111,110,33,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,62,167,42,244,0,0,16,1,100,105,101,32,104,97,114,100,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,177,28,91,27,0,0,16,1,104,111,110,111,111,32,110,111,32,116,111,117,107,121,117,117,106,105,32,100,111,100,103,101,32,100,97,110,112,101,105,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,3,231,30,176,0,0,16,1,100,97,114,105,117,115,32,112,108,117,115,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,66,224,191,190,0,0,16,1,100,97,114,105,117,115,32,97,108,112,104,97,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,159,104,186,176,0,0,16,1,99,111,114,121,111,111,110,32,45,32,99,104,105,108,100,32,111,102,32,100,114,97,103,111,110,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,59,158,210,180,0,0,16,1,99,111,108,117,109,110,115,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,114,165,247,153,0,0,16,1,116,97,105,116,111,32,99,104,97,115,101,32,104,46,113,46,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,144,215,79,111,0,0,16,1,98,114,101,97,107,32,105,110,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,106,66,215,201,0,0,16,1,98,111,109,98,101,114,109,97,110,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,31,77,187,154,0,0,16,1,98,105,107,107,117,114,105,109,97,110,32,119,111,114,108,100,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,30,253,65,40,0,0,16,1,98,97,114,117,110,98,97,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,202,243,61,74,0,0,16,1,97,118,32,112,111,107,101,114,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,130,210,102,184,0,0,16,1,97,114,116,105,115,116,32,116,111,111,108,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,19,167,79,94,0,0,16,1,49,57,52,51,32,107,97,105,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,109,141,224,253,0,0,16,1,168,86,7,0,1,0,0,0,240,33,216,0,248,191,2,0,24,38,7,0,1,0,0,0,248,33,216,0,184,160,2,0,120,36,5,0,1,0,0,0,249,33,216,0,96,78,4,0,56,210,6,0,1,0,0,0,0,33,216,0,192,135,2,0,24,163,6,0,1,0,0,0,1,33,216,0,240,108,2,0,152,122,6,0,1,0,0,0,2,33,216,0,96,82,2,0,192,72,6,0,1,0,0,0,3,33,216,0,32,56,2,0,136,30,2,0,1,0,0,0,4,33,216,0,152,30,2,0,224,19,2,0,1,0,0,0,5,33,216,0,232,10,2,0,216,10,2,0,1,0,0,0,6,33,216,0,152,138,8,0,248,3,2,0,1,0,0,0,7,33,216,0,248,174,1,0,8,16,4,0,4,0,0,0,24,34,216,0,152,210,1,0,40,246,1,0,1,0,0,0,241,33,216,0,64,246,1,0,144,236,1,0,1,0,0,0,250,33,216,0,136,224,1,0,128,149,1,0,1,0,0,0,251,33,216,0,24,60,1,0,176,223,1,0,1,0,0,0,248,32,216,0,72,198,1,0,192,209,1,0,1,0,0,0,249,32,216,0,24,182,1,0,24,198,1,0,1,0,0,0,250,32,216,0,40,167,1,0,120,189,1,0,1,0,0,0,251,32,216,0,200,149,1,0,184,155,8,0,1,0,0,0,252,32,216,0,56,126,1,0,136,149,8,0,1,0,0,0,253,32,216,0,32,101,1,0,216,142,8,0,1,0,0,0,254,32,216,0,96,32,8,0,40,138,8,0,1,0,0,0,255,32,216,0,16,68,7,0,200,11,4,0,4,0,0,0,26,34,216,0,136,7,4,0,88,212,3,0,1,0,0,0,200,32,216,0,40,185,3,0,80,251,6,0,1,0,0,0,48,33,216,0,216,70,1,0,16,17,8,0,1,0,0,0,242,33,216,0,224,12,8,0,248,5,8,0,9,0,0,0,12,33,216,0,32,58,1,0,144,250,7,0,9,0,0,0,13,33,216,0,32,58,1,0,208,23,1,0,9,0,0,0,152,32,216,0,32,58,1,0,184,22,1,0,9,0,0,0,128,37,0,0,32,58,1,0,0,22,1,0,9,0,0,0,56,33,216,0,32,58,1,0,120,20,1,0,9,0,0,0,57,33,216,0,32,58,1,0,0,0,0,0,0,0,0,0,122,111,109,98,105,101,115,32,97,116,101,32,109,121,32,110,101,105,103,104,98,111,114,115,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,111,98,243,43,33,0,16,0,122,111,109,98,105,101,32,104,105,103,104,32,40,117,115,97,41,32,40,112,114,111,116,111,116,121,112,101,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,239,160,15,0,148,97,234,123,33,0,16,0,109,112,114,45,49,52,52,54,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,163,68,183,137,33,0,16,0,122,97,110,121,32,103,111,108,102,32,40,101,117,114,111,44,32,117,115,97,41,32,40,118,49,46,49,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,7,118,237,116,33,0,16,0,122,97,110,32,121,97,115,104,97,32,101,110,98,117,107,121,111,107,117,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,243,232,127,99,33,0,16,0,121,111,117,110,103,32,105,110,100,105,97,110,97,32,106,111,110,101,115,32,99,104,114,111])
.concat([110,105,99,108,101,115,44,32,116,104,101,32,40,117,115,97,41,32,40,112,114,111,116,111,116,121,112,101,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,53,190,246,68,33,0,16,0,121,111,103,105,32,98,101,97,114,39,115,32,99,97,114,116,111,111,110,32,99,97,112,101,114,115,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,216,151,79,32,33,0,16,0,120,45,109,101,110,32,50,32,45,32,99,108,111,110,101,32,119,97,114,115,32,40,112,114,111,116,111,116,121,112,101,32,45,32,109,97,121,32,48,54,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,180,235,32,167,33,0,16,0,120,45,109,101,110,32,50,32,45,32,99,108,111,110,101,32,119,97,114,115,32,40,112,114,111,116,111,116,121,112,101,32,45,32,109,97,121,32,49,48,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,133,209,93,155,33,0,16,0,120,45,109,101,110,32,50,32,45,32,99,108,111,110,101,32,119,97,114,115,32,40,112,114,111,116,111,116,121,112,101,32,45,32,111,99,116,32,49,56,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,125,243,207,82,33,0,16,0,120,45,109,101,110,32,50,32,45,32,99,108,111,110,101,32,119,97,114,115,32,40,112,114,111,116,111,116,121,112,101,32,45,32,110,111,118,32,49,55,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,222,208,12,217,33,0,16,0,120,45,109,101,110,32,50,32,45,32,99,108,111,110,101,32,119,97,114,115,32,40,112,114,111,116,111,116,121,112,101,32,45,32,110,111,118,32,50,51,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,129,163,134,67,33,0,16,0,120,45,109,101,110,32,50,32,45,32,99,108,111,110,101,32,119,97,114,115,32,40,112,114,111,116,111,116,121,112,101,32,45,32,110,111,118,32,50,56,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,77,58,56,112,33,0,16,0,120,45,109,101,110,32,50,32,45,32,99,108,111,110,101,32,119,97,114,115,32,40,112,114,111,116,111,116,121,112,101,32,45,32,110,111,118,32,51,48,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,10,174,29,51,33,0,16,0,120,45,109,101,110,32,50,32,45,32,99,108,111,110,101,32,119,97,114,115,32,40,112,114,111,116,111,116,121,112,101,32,45,32,100,101,99,32,48,50,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,34,190,31,0,233,164,215,122,33,0,16,0,120,45,109,101,110,32,50,32,45,32,99,108,111,110,101,32,119,97,114,115,32,40,112,114,111,116,111,116,121,112,101,32,45,32,100,101,99,32,48,51,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,156,147,155,102,33,0,16,0,120,45,109,101,110,32,50,32,45,32,99,108,111,110,101,32,119,97,114,115,32,40,112,114,111,116,111,116,121,112,101,32,45,32,100,101,99,32,48,54,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,245,12,29,91,33,0,16,0,120,45,109,101,110,32,50,32,45,32,99,108,111,110,101,32,119,97,114,115,32,40,112,114,111,116,111,116,121,112,101,32,45,32,100,101,99,32,48,55,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,218,48,106,36,33,0,16,0,120,45,109,101,110,32,50,32,45,32,99,108,111,110,101,32,119,97,114,115,32,40,112,114,111,116,111,116,121,112,101,32,45,32,100,101,99,32,48,56,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,238,31,0,28,11,217,198,33,0,16,0,120,45,109,101,110,32,50,32,45,32,99,108,111,110,101,32,119,97,114,115,32,40,112,114,111,116,111,116,121,112,101,32,45,32,100,101,99,32,48,57,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,88,123,48,40,33,0,16,0,120,45,109,101,110,32,50,32,45,32,99,108,111,110,101,32,119,97,114,115,32,40,112,114,111,116,111,116,121,112,101,32,45,32,100,101,99,32,49,48,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,250,31,0,254,239,226,115,33,0,16,0,120,45,109,101,110,32,50,32,45,32,99,108,111,110,101,32,119,97,114,115,32,40,112,114,111,116,111,116,121,112,101,32,45,32,100,101,99,32,49,49,44,32,49,57,57,52,32,45,32,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,134,91,65,17,33,0,16,0,120,45,109,101,110,32,50,32,45,32,99,108,111,110,101,32,119,97,114,115,32,40,112,114,111,116,111,116,121,112,101,32,45,32,100,101,99,32,49,49,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,89,98,135,81,33,0,16,0,120,45,109,101,110,32,50,32,45,32,99,108,111,110,101,32,119,97,114,115,32,40,112,114,111,116,111,116,121,112,101,32,45,32,100,101,99,32,49,52,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,230,45,102,205,33,0,16,0,120,45,109,101,110,32,50,32,45,32,99,108,111,110,101,32,119,97,114,115,32,40,112,114,111,116,111,116,121,112,101,32,45,32,100,101,99,32,49,53,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,254,31,0,48,142,24,165,33,0,16,0,120,45,109,101,110,32,50,32,45,32,99,108,111,110,101,32,119,97,114,115,32,40,112,114,111,116,111,116,121,112,101,32,45,32,100,101,99,32,49,54,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,114,9,196,232,33,0,16,0,119,119,102,32,114,111,121,97,108,32,114,117,109,98,108,101,32,40,119,111,114,108,100,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,62,197,157,182,33,0,16,0,119,111,114,108,100,32,115,101,114,105,101,115,32,98,97,115,101,98,97,108,108,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,100,101,99,32,48,56,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,80,176,70,136,33,0,16,0,119,111,114,108,100,32,115,101,114,105,101,115,32,98,97,115,101,98,97,108,108,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,100,101,99,32,49,52,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,84,227,91,56,33,0,16,0,119,111,114,108,100,32,115,101,114,105,101,115,32,98,97,115,101,98,97,108,108,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,100,101,99,32,50,56,44,32,49,57,57,52,32,45,32,115,98,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,124,188,109,158,33,0,16,0,119,111,114,108,100,32,115,101,114,105,101,115,32,98,97,115,101,98,97,108,108,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,97,110,32,48,49,44,32,49,57,57,53,32,45,32,116,115,116,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,114,67,87,199,33,0,16,0,119,111,114,108,100,32,115,101,114,105,101,115,32,98,97,115,101,98,97,108,108,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,97,110,32,48,51,44,32,49,57,57,53,32,45,32,116,115,116,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,247,99,131,73,33,0,16,0,119,111,114,108,100,32,115,101,114,105,101,115,32,98,97,115,101,98,97,108,108,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,97,110,32,48,53,44,32,49,57,57,53,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,251,171,32,24,33,0,16,0,119,111,114,108,100,32,115,101,114,105,101,115,32,98,97,115,101,98,97,108,108,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,97,110,32,48,57,44,32,49,57,57,53,32,45,32,116,115,116,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,188,205,231,61,33,0,16,0,119,111,114,108,100,32,115,101,114,105,101,115,32,98,97,115,101,98,97,108,108,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,97,110,32,49,48,44,32,49,57,57,53,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,176,114,39,172,33,0,16,0,119,111,114,108,100,32,115,101,114,105,101,115,32,98,97,115,101,98,97,108,108,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,97,110,32,49,52,44,32,49,57,57,53,32,45,32,114,109,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,85,22,48,0,207,7,11,247,33,0,16,0,119,111,114,108,100,32,115,101,114,105,101,115,32,98,97,115,101,98,97,108,108,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,97,110,32,49,54,44,32,49,57,57,53,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,33,43,226,240,33,0,16,0,119,111,114,108,100,32,115,101,114,105,101,115,32,98,97,115,101,98,97,108,108,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,97,110,32,49,56,44,32,49,57,57,53,32,45,32,114,109,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,211,35,48,0,143,15,231,92,33,0,16,0,119,111,114,108,100,32,115,101,114,105,101,115,32,98,97,115,101,98,97,108,108,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,97,110,32,50,48,44,32,49,57,57,53,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,70,94,193,22,33,0,16,0,119,111,114,108,100,32,115,101,114,105,101,115,32,98,97,115,101,98,97,108,108,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,97,110,32,50,53,44,32,49,57,57,53,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,51,158,93,180,33,0,16,0,119,111,114,108,100,32,115,101,114,105,101,115,32,98,97,115,101,98,97,108,108,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,97,110,32,51,48,44,32,49,57,57,53,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,157,106,167,106,33,0,16,0,119,111,114,108,100,32,115,101,114,105,101,115,32,98,97,115,101,98,97,108,108,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,102,101,98,32,48,50,44,32,49,57,57,53,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,92,254,71,169,33,0,16,0,119,111,114,108,100,32,115,101,114,105,101,115,32,98,97,115,101,98,97,108,108,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,102,101,98,32,48,51,44,32,49,57,57,53,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,252,84,55,31,33,0,16,0,119,111,114,108,100,32,115,101,114,105,101,115,32,98,97,115,101,98,97,108,108,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,102,101,98,32,48,55,44,32,49,57,57,53,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,89,101,5,228,33,0,16,0,119,111,114,108,100,32,115,101,114,105,101,115,32,98,97,115,101,98,97,108,108,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,102,101,98,32,48,57,44,32,49,57,57,53,32,45,32,98,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,218,158,187,51,33,0,16,0,119,111,114,108,100,32,115,101,114,105,101,115,32,98,97,115,101,98,97,108,108,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,102,101,98,32,48,57,44,32,49,57,57,53,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,207,152,190,131,33,0,16,0,119,111,114,108,100,32,115,101,114,105,101,115,32,98,97,115,101,98,97,108,108,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,102,101,98,32,49,49,44,32,49,57,57,53,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,233,79,102,160,33,0,16,0,119,111,114,108,100,32,115,101,114,105,101,115,32,98,97,115,101,98,97,108,108,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,102,101,98,32,49,50,44,32,49,57,57,53,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,24,143,218,69,33,0,16,0,119,111,114,108,100,32,115,101,114,105,101,115,32,98,97,115,101,98,97,108,108,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,102,101,98,32,49,51,44,32,49,57,57,53,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,48,174,48,159,33,0,16,0,119,111,114,108,100,32,115,101,114,105,101,115,32,98,97,115,101,98,97,108,108,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,102,101,98,32,49,52,44,32,49,57,57,53,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,87,168,0,243,33,0,16,0,119,114,101,115,116,108,101,98,97,108,108,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,127,224,99,213,33,0,16,0,109,112,114,45,49,52,48,50,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,133,42,22,45,33,0,16,0,109,112,114,45,49,53,50,55,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,73,106,28,18,33,0,16,0,119,111,108,118,101,114,105,110,101,32,45,32,97,100,97,109,97,110,116,105,117,109,32,114,97,103,101,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,183,123,67,210,33,0,16,0,119,111,108,102,99,104,105,108,100,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,191,28,91,235,33,0,16,0,119,105,122,39,110,39,108,105,122,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,98,107,3,223,33,0,16,0,97,99,119,99,115,103,45,49,95,40,49,45,57,50,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,104,112,124,245,33,0,16,0,119,105,110,103,115,32,111,102,32,119,111,114,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,205,47,10,33,33,0,16,0,119,105,109,98,108,101,100,111,110,32,99,104,97,109,112,105,111,110,115,104,105,112,32,116,101,110,110,105,115,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,238,42,20,249,33,0,16,0,119,105,109,98,108,101,100,111,110,32,99,104,97,109,112,105,111,110,115,104,105,112,32,116,101,110,110,105,115,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,175,157,12,62,33,0,16,0,119,105,108,100,32,115,110,97,107,101,32,40,117,115,97,41,32,40,112,114,111,116,111,116,121,112,101,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,229,73,26,12,33,0,16,0,119,104,105,112,32,114,117,115,104,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,107,184,182,126,33,0,16,0,119,104,101,101,108,32,111,102,32,102,111,114,116,117,110,101,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,195,239,216,200,33,0,16,0,119,104,97,99,45,97,45,99,114,105,116,116,101,114,32,40,117,115,97,41,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,184,2,221,27,33,0,16,0,119,101,97,112,111,110,108,111,114,100,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,101,83,137,185,33,0,16,0,119,97,121,110,101,39,115,32,119,111,114,108,100,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,190,110,207,210,33,0,16,0,119,97,116,101,114,119,111,114,108,100,32,40,101,117,114,111,41,32,40,112,114,111,116,111,116,121,112,101,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,152,4,200,81,33,0,16,0,119,97,114,114,105,111,114,32,111,102,32,114,111,109,101,32,105,105,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,42,71,140,205,33,0,16,0,119,97,114,112,115,112,101,101,100,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,237,151,54,20,33,0,16,0,119,97,114,108,111,99,107,32,40,117,115,97,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,179,237,182,201,33,0,16,0,119,97,114,100,110,101,114,32,110,111,32,109,111,114,105,32,115,112,101,99,105,97,108,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,92,3,241,128,33,0,16,0,119,97,110,105,32,119,97,110,105,32,119,111,114,108,100,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,178,219,240,86,33,0,16,0,119,97,99,107,121,32,114,97,99,101,115,32,40,117,115,97,41,32,40,112,114,111,116,111,116,121,112,101,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,9,63,23,27,33,0,16,0,118,105,114,116,117,97,108,32,112,105,110,98,97,108,108,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,170,115,52,214,33,0,16,0,118,105,120,101,110,32,51,53,55,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,123,45,250,58,33,0,16,0,118,105,101,119,112,111,105,110,116,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,102,24,199,89,33,0,16,0,118,101,99,116,111,114,109,97,110,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,117,108,32,50,52,44,32,49,57,57,53,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,139,115,69,1,33,0,16,0,118,101,99,116,111,114,109,97,110,32,40,98,101,116,97,41,32,40,97,108,116,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,218,211,132,32,33,0,16,0,118,101,99,116,111,114,109,97,110,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,170,200,21,163,33,0,16,0,117,110,110,101,99,101,115,115,97,114,121,32,114,111,117,103,104,110,101,115,115,32,57,53,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,183,231,32,153,33,0,16,0,120,120,120,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,240,169,141,24,33,0,16,0,117,110,105,118,101,114,115,97,108,32,115,111,108,100,105,101,114,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,73,189,46,53,33,0,16,0,117,110,99,104,97,114,116,101,100,32,119,97,116,101,114,115,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,89,236,218,78,33,0,16,0,109,112,114,45,49,53,56,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,88,110,219,131,33,0,16,0,117,108,116,114,97,109,97,110,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,251,213,180,131,33,0,16,0,109,112,114,45,49,53,54,53,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,217,139,152,238,33,0,16,0,116,119,111,32,99,114,117,100,101,32,100,117,100,101,115,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,16,10,217,182,33,0,16,0,116,119,105,115,116,101,100,32,102,108,105,112,112,101,114,32,40,117,115,97,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,84,117,212,109,33,0,16,0,116,119,105,110,107,108,101,32,116,97,108,101,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,36,249,87,215,33,0,16,0,116,119,105,110,32,104,97,119,107,32,45,45,32,100,97,105,115,101,110,112,117,117,32,40,101,117,114,111,44,32,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,103,140,236,162,33,0,16,0,116,119,105,110,32,99,111,98,114,97,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,72,130,112,44,33,0,16,0,116,117,114,114,105,99,97,110,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,166,103,77,99,33,0,16,0,116,117,114,109,97,32,100,97,32,109,111,110,105,99,97,32,110,97,32,116,101,114,114,97,32,100,111,115,32,109,111,110,115,116,114,111,115,32,40,98,114,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,225,141,40,248,33,0,16,0,109,112,114,45,49,53,52,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,81,186,15,209,33,0,16,0,116,114,117,101,32,108,105,101,115,32,40,119,111,114,108,100,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,104,148,192,24,33,0,16,0,116,114,111,117,98,108,101,32,115,104,111,111,116,101,114,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,155,195,207,190,33,0,16,0,116,97,114,103,101,116,32,101,97,114,116,104,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,211,98,223,205,33,0,16,0,109,105,110,97,116,111,32,110,111,32,116,114,97,121,115,105,97,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,9,253,137,189,33,0,16,0,116,114,97,109,112,111,108,105,110,101,32,116,101,114,114,111,114,33,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,159,52,187,170,33,0,16,0,116,114,105,112,108,101,32,112,108,97,121,32,103,111,108,100,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,23,144,230,187,33,0,16,0,109,112,114,45,49,56,56,52,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,243,169,137,142,33,0,16,0,116,111,117,103,104,109,97,110,32,99,111,110,116,101,115,116,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,147,188,159,225,33,0,16,0,116,111,116,97,108,32,102,111,111,116,98,97,108,108,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,106,182,96,131,33,0,16,0,116,111,112,32,112,114,111,32,103,111,108,102,32,50,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,179,152,206,184,33,0,16,0,116,111,112,32,103,101,97,114,32,50,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,210,116,48,189,33,0,16,0,116,111,112,32,102,105,103,104,116,101,114,32,50,48,48,48,32,109,107,32,118,105,105,105,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,220,25,85,247,33,0,16,0,116,111,109,32,97,110,100,32,106,101,114,114,121,32,45,32,102,114,97,110,116,105,99,32,97,110,116,105,99,115,32,40,117,115,97,41,32,40,49,57,57,51,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,28,46,153,185,33,0,16,0,116,111,101,32,106,97,109,32,38,32,101,97,114,108,32,105,110,32,112,97,110,105,99,32,111,110,32,102,117,110,107,111,116,114,111,110,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,221,27,2,170,33,0,16,0,116,111,101,32,106,97,109,32,38,32,101,97,114,108,32,105,110,32,112,97,110,105,99,32,111,110,32,102,117,110,107,111,116,114,111,110,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,80,104,179,225,33,0,16,0,116,111,101,32,106,97,109,32,38,32,101,97,114,108,32,105,110,32,112,97,110,105,99,32,97,117,102,32,102,117,110,107,111,116,114,111,110,32,40,103,101,114,109,97,110,121,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,242,185,129,64,33,0,16,0,116,105,109,101,32,107,105,108,108,101,114,115,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,26,138,244,164,33,0,16,0,116,112,98,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,197,162,157,40,33,0,16,0,109,112,114,45,49,52,57,50,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,2,211,244,21,33,0,16,0,116,101,108,101,98,114,97,100,101,115,99,111,32,114,101,115,105,100,101,110,99,105,97,32,40,98,114,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,69,144,185,29,33,0,16,0,116,101,107,107,101,110,32,51,32,115,112,101,99,105,97,108,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,88,230,202,127,33,0,16,0,116,101,105,116,111,107,117,32,110,111,32,107,101,116,115,117,100,97,110,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,228,228,8,155,33,0,16,0,116,101,100,100,121,32,98,111,121,32,98,108,117,101,115,32,40,106,112,110,41,32,40,115,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,179,46,61,115,33,0,16,0,116,101,99,104,110,111,99,111,112,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,6,173,89,116,33,0,16,0,116,101,99,109,111,32,119,111,114,108,100,32,99,117,112,32,39,57,50,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,176,200,147,94,33,0,16,0,116,101,99,109,111,32,115,117,112,101,114,32,98,111,119,108,32,40,117,115,97,41,32,40,111,99,116,111,98,101,114,32,49,57,57,51,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,52,125,242,33,33,0,16,0,116,101,99,109,111,32,115,117,112,101,114,32,98,111,119,108,32,105,105,105,32,45,32,102,105,110,97,108,32,101,100,105,116,105,111,110,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,159,8,228,170,33,0,16,0,116,101,99,109,111,32,115,117,112,101,114,32,98,111,119,108,32,105,105,32,45,32,115,112,101,99,105,97,108,32,101,100,105,116,105,111,110,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,216,103,14,10,33,0,16,0,116,101,99,109,111,32,115,117,112,101,114,32,110,98,97,32,98,97,115,107,101,116,98,97,108,108,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,145,57,145,83,33,0,16,0,116,101,99,109,111,32,115,117,112,101,114,32,104,111,99,107,101,121,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,201,221,134,95,33,0,16,0,116,101,99,109,111,32,99,117,112,32,40,106,112,110,41,32,40,112,114,111,116,111,116,121,112,101,63,41,32,40,98,97,100,32,100,117,109,112,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,96,208,253,136,33,0,16,0,116,101,99,104,110,111,32,99,108,97,115,104,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,131,228,101,78,33,0,16,0,116,97,122,32,105,110,32,101,115,99,97,112,101,32,102,114,111,109,32,109,97,114,115,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,140,159,0,98,33,0,16,0,109,112,114,45,49,52,56,51,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,69,31,144,14,33,0,16,0,116,97,115,107,32,102,111,114,99,101,32,104,97,114,114,105,101,114,32,101,120,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,87,2,187,200,33,0,16,0,116,97,110,107,32,50,48,49,49,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,32,152,115,3,33,0,16,0,109,112,114,45,49,53,48,53,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,208,200,192,245,33,0,16,0,116,97,105,107,111,117,32,114,105,115,115,104,105,100,101,110,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,0,91,225,111,249,33,0,16,0,115,121,110,100,105,99,97,116,101,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,123,248,187,149,33,0,16,0,115,121,108,118,101,115,116,101,114,32,38,32,116,119,101,101,116,121,32,105,110,32,99,97,103,101,121,32,99,97,112,101,114,115,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,206,84,252,137,33,0,16,0,115,121,100,32,111,102,32,118,97,108,105,115,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,8,1,220,55,33,0,16,0,115,119,111,114,100,32,111,102,32,115,111,100,97,110,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,143,70,184,156,33,0,16,0,115,117,112,101,114,32,118,111,108,108,101,121,32,98,97,108,108,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,234,40,92,155,33,0,16,0,115,117,112,101,114,32,118,111,108,108,101,121,32,98,97,108,108,32,40,117,115,97,41,32,40,97,108,116,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,153,39,16,133,33,0,16,0,115,117,112,101,114,32,115,104,105,110,111,98,105,32,105,105,44,32,116,104,101,32,40,106,112,110,44,32,107,111,114,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,22,40,65,91,33,0,16,0,115,117,112,101,114,32,108,101,97,103,117,101,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,110,236,186,85,33,0,16,0,115,117,112,101,114,32,98,117,98,98,108,101,32,98,111,98,98,108,101,32,40,99,104,105,41,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,97,161,32,72,33,0,16,0,101,108,102,32,119,111,114,32,40,99,104,105,41,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,178,198,74,226,33,0,16,0,115,117,112,101,114,32,104,121,100,108,105,100,101,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,170,221,53,19,33,0,16,0,109,112,114,45,49,50,54,51,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,134,227,155,89,33,0,16,0,115,117,112,101,114,32,111,102,102,32,114,111,97,100,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,218,218,47,143,33,0,16,0,109,112,114,45,49,53,51,50,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,186,52,180,125,33,0,16,0,109,112,114,45,49,51,56,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,130,25,69,250,33,0,16,0,109,112,114,45,49,50,52,55,55,97,45,104,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,110,93,100,17,33,0,16,0,115,117,98,116,101,114,114,97,110,105,97,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,69,108,60,220,33,0,16,0,115,117,98,116,101,114,114,97,110,105,97,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,145,234,56,118,33,0,16,0,115,116,97,114,32,116,114,101,107,32,45,32,116,104,101,32,110,101,120,116,32,103,101,110,101,114,97,116,105,111,110,32,45,32,101,99,104,111,101,115,32,102,114,111,109,32,116,104,101,32,112,97,115,116,32,40,112,114,111,116,111,116,121,112,101,32,45,32,100,101,99,32,50,56,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,249,112,166,59,33,0,16,0,115,116,97,114,32,116,114,101,107,32,45,32,116,104,101,32,110,101,120,116,32,103,101,110,101,114,97,116,105,111,110,32,45,32,101,99,104,111,101,115,32,102,114,111,109,32,116,104,101,32,112,97,115,116,32,40,112,114,111,116,111,116,121,112,101,32,45,32,100,101,99,32,50,57,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,67,188,107,49,33,0,16,0,115,116,97,114,32,116,114,101,107,32,45,32,116,104,101,32,110,101,120,116,32,103,101,110,101,114,97,116,105,111,110,32,45,32,101,99,104,111,101,115,32,102,114,111,109,32,116,104,101,32,112,97,115,116,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,97,110,32,48,51,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,104,107,200,202,33,0,16,0,115,116,97,114,32,116,114,101,107,32,45,32,116,104,101,32,110,101,120,116,32,103,101,110,101,114,97,116,105,111,110,32,45,32,101,99,104,111,101,115,32,102,114,111,109,32,116,104,101,32,112,97,115,116,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,97,110,32,49,48,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,62,202,56,209,33,0,16,0,115,116,97,114,32,116,114,101,107,32,45,32,116,104,101,32,110,101,120,116,32,103,101,110,101,114,97,116,105,111,110,32,45,32,101,99,104,111,101,115,32,102,114,111,109,32,116,104,101,32,112,97,115,116,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,97,110,32,49,56,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,122,185,218,216,33,0,16,0,115,116,97,114,32,116,114,101,107,32,45,32,116,104,101,32,110,101,120,116,32,103,101,110,101,114,97,116,105,111,110,32,45,32,101,99,104,111,101,115,32,102,114,111,109,32,116,104,101,32,112,97,115,116,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,97,110,32,50,53,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,111,158,242,99,33,0,16,0,115,116,111,114,109,108,111,114,100,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,165,80,171,57,33,0,16,0,115,116,114,105,107,101,114,32,40,101,117,114,111,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,14,39,11,193,33,0,16,0,115,116,114,105,100,101,114,32,104,105,114,121,117,117,32,40,106,112,110,44,32,107,111,114,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,242,115,145,133,33,0,16,0,115,116,114,105,100,101,114,32,105,105,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,112,82,94,232,33,0,16,0,115,116,111,110,101,32,112,114,111,116,101,99,116,111,114,115,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,79,213,240,251,33,0,16,0,115,116,101,101,108,32,116,97,108,111,110,115,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,99,236,228,16,33,0,16,0,115,116,101,101,108,32,101,109,112,105,114,101,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,182,160,231,208,33,0,16,0,115,116,97,114,32,119,97,114,115,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,68,141,175,148,33,0,16,0,115,116,97,114,32,119,97,114,115,32,106,101,100,105,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,160,18,0,96,191,197,72,33,0,16,0,115,116,97,114,103,97,116,101,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,158,6,135,229,33,0,16,0,115,116,97,114,32,99,111,110,116,114,111,108,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,175,206,43,142,33,0,16,0,115,116,97,114,32,99,114,117,105,115,101,114,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,47,181,117,43,33,0,16,0,109,112,114,45,49,53,51,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,84,48,243,15,33,0,16,0,109,112,114,45,49,53,48,52,48,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,182,18,36,242,33,0,16,0,115,117,112,101,114,32,114,111,98,111,116,32,119,97,114,115,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,20,38,174,207,33,0,16,0,109,112,114,45,49,51,52,51,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,186,101,71,240,33,0,16,0,115,113,117,105,114,114,101,108,32,107,105,110,103,32,40,99,104,105,41,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,245,31,38,184,33,0,16,0,115,112,121,32,107,105,100,115,32,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,163,94,4,154,33,0,16,0,115,112,111,114,116,115,32,116,97,108,107,32,98,97,115,101,98,97,108,108,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,194,121,235,13,33,0,16,0,115,112,111,110,103,101,32,98,111,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,150,116,67,197,33,0,16,0,115,112,108,97,116,116,101,114,104,111,117,115,101,32,51,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,7,93,240,0,33,0,16,0,115,112,108,97,116,116,101,114,104,111,117,115,101,32,50,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,60,224,89,37,33,0,16,0,115,112,105,114,105,116,117,97,108,32,119,97,114,102,97,114,101,32,40,117,115,97,41,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,255,100,163,217,33,0,16,0,109,112,114,45,49,53,55,48,57,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,234,20,68,74,33,0,16,0,115,112,105,100,101,114,45,109,97,110,32,97,110,100,32,118,101,110,111,109,32,45,32,109,97,120,105,109,117,109,32,99,97,114,110,97,103,101,32,40,119,111,114,108,100,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,230,182,160,143,33,0,16,0,109,112,114,45,49,52,48,50,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,95,119,171,112,33,0,16,0,115,112,105,100,101,114,45,109,97,110,32,40,101,117,114,111,44,32,117,115,97,41,32,40,97,99,99,108,97,105,109,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,144,181,181,17,33,0,16,0,109,112,114,45,49,52,57,57,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,3,110,106,5,33,0,16,0,115,112,97,114,107,115,116,101,114,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,45,159,62,214,33,0,16,0,115,112,97,99,101,32,102,117,110,107,121,32,98,46,111,46,98,46,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,59,13,49,233,33,0,16,0,115,111,117,108,32,101,100,103,101,32,118,115,32,115,97,109,117,114,97,105,32,115,112,105,114,105,116,115,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,17,214,27,177,33,0,16,0,115,111,117,108,32,98,108,97,100,101,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,209,136,111,242,33,0,16,0,115,111,114,99,101,114,32,107])
.concat([105,110,103,100,111,109,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,202,53,65,148,33,0,16,0,115,111,114,99,101,114,101,114,39,115,32,107,105,110,103,100,111,109,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,234,193,230,203,33,0,16,0,115,116,114,101,101,116,115,32,111,102,32,114,97,103,101,32,51,32,40,112,114,111,116,111,116,121,112,101,32,45,32,109,97,114,32,48,56,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,81,181,80,234,33,0,16,0,115,116,114,101,101,116,115,32,111,102,32,114,97,103,101,32,51,32,40,112,114,111,116,111,116,121,112,101,32,45,32,109,97,114,32,49,55,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,43,150,173,57,33,0,16,0,115,116,114,101,101,116,115,32,111,102,32,114,97,103,101,32,51,32,40,112,114,111,116,111,116,121,112,101,32,45,32,109,97,114,32,49,56,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,132,36,20,96,33,0,16,0,115,116,114,101,101,116,115,32,111,102,32,114,97,103,101,32,51,32,40,112,114,111,116,111,116,121,112,101,32,45,32,109,97,114,32,50,56,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,151,247,87,135,33,0,16,0,115,116,114,101,101,116,115,32,111,102,32,114,97,103,101,32,51,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,112,114,32,48,49,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,183,117,126,121,33,0,16,0,115,116,114,101,101,116,115,32,111,102,32,114,97,103,101,32,51,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,112,114,32,48,52,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,19,143,150,107,33,0,16,0,115,116,114,101,101,116,115,32,111,102,32,114,97,103,101,32,51,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,112,114,32,48,56,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,194,118,186,212,33,0,16,0,115,116,114,101,101,116,115,32,111,102,32,114,97,103,101,32,51,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,112,114,32,49,49,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,130,90,94,250,33,0,16,0,115,116,114,101,101,116,115,32,111,102,32,114,97,103,101,32,51,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,112,114,32,49,50,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,114,203,82,63,33,0,16,0,115,116,114,101,101,116,115,32,111,102,32,114,97,103,101,32,51,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,112,114,32,49,51,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,7,88,103,107,33,0,16,0,115,111,110,105,99,32,116,104,101,32,104,101,100,103,101,104,111,103,32,40,101,117,114,111,44,32,117,115,97,41,32,40,112,105,114,97,116,101,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,11,63,9,122,33,0,16,0,115,111,110,105,99,32,106,97,109,32,54,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,151,216,57,191,33,0,16,0,109,112,114,45,49,57,54,57,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,227,174,150,198,33,0,16,0,115,111,110,105,99,32,51,99,32,40,112,114,111,116,111,116,121,112,101,32,48,53,49,55,32,45,32,109,97,121,32,49,55,44,32,49,57,57,52,44,32,49,55,46,48,56,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,129,75,108,118,33,0,16,0,115,111,110,105,99,32,116,104,101,32,104,101,100,103,101,104,111,103,32,50,32,40,98,101,116,97,32,52,32,45,32,115,101,112,32,49,56,44,32,49,57,57,50,44,32,49,54,46,50,54,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,197,92,218,143,33,0,16,0,115,111,110,105,99,32,116,104,101,32,104,101,100,103,101,104,111,103,32,50,32,40,98,101,116,97,32,53,32,45,32,115,101,112,32,50,49,44,32,49,57,57,50,44,32,49,50,46,48,54,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,137,154,107,6,33,0,16,0,115,111,110,105,99,32,116,104,101,32,104,101,100,103,101,104,111,103,32,50,32,40,98,101,116,97,32,54,32,45,32,115,101,112,32,50,50,44,32,49,57,57,50,44,32,49,56,46,52,55,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,224,100,188,206,33,0,16,0,115,111,110,105,99,32,116,104,101,32,104,101,100,103,101,104,111,103,32,50,32,40,98,101,116,97,32,54,32,45,32,115,101,112,32,50,50,44,32,49,57,57,50,44,32,49,57,46,52,50,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,108,110,3,203,33,0,16,0,115,111,110,105,99,32,116,104,101,32,104,101,100,103,101,104,111,103,32,50,32,40,98,101,116,97,32,55,32,45,32,115,101,112,32,50,52,44,32,49,57,57,50,44,32,48,57,46,50,54,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,44,225,123,220,33,0,16,0,115,111,110,105,99,32,116,104,101,32,104,101,100,103,101,104,111,103,32,50,32,40,98,101,116,97,32,56,32,45,32,115,101,112,32,50,52,44,32,49,57,57,50,44,32,49,57,46,50,55,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,221,250,137,96,33,0,16,0,115,111,110,105,99,32,116,104,101,32,104,101,100,103,101,104,111,103,32,50,32,40,112,114,111,116,111,116,121,112,101,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,92,27,162,238,33,0,16,0,115,111,110,105,99,32,116,104,101,32,104,101,100,103,101,104,111,103,32,50,32,40,119,111,114,108,100,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,112,170,250,57,33,0,16,0,115,111,108,100,105,101,114,115,32,111,102,32,102,111,114,116,117,110,101,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,161,40,77,168,33,0,16,0,115,111,108,45,100,101,97,99,101,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,159,78,126,167,33,0,16,0,115,110,111,119,32,98,114,111,115,46,32,45,32,110,105,99,107,32,38,32,116,111,109,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,40,98,181,17,33,0,16,0,115,110,111,119,32,113,117,101,101,110,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,70,121,192,230,33,0,16,0,115,110,97,107,101,32,114,97,116,116,108,101,32,110,39,32,114,111,108,108,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,48,237,59,84,33,0,16,0,115,109,117,114,102,115,32,116,114,97,118,101,108,32,116,104,101,32,119,111,114,108,100,44,32,116,104,101,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,105,221,139,178,33,0,16,0,110,97,111,109,105,99,104,105,32,111,122,97,107,105,32,110,111,32,115,117,112,101,114,32,109,97,115,116,101,114,115,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,37,168,139,8,33,0,16,0,115,117,112,101,114,32,109,97,114,105,111,32,119,111,114,108,100,32,54,52,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,97,65,172,231,33,0,16,0,115,117,112,101,114,95,109,97,114,105,111,95,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,75,220,166,13,33,0,16,0,115,108,97,117,103,104,116,101,114,32,115,112,111,114,116,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,156,157,159,175,33,0,16,0,115,108,97,112,32,102,105,103,104,116,32,109,100,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,149,86,105,214,33,0,16,0,115,108,97,109,32,45,32,115,104,97,113,32,118,115,46,32,116,104,101,32,108,101,103,101,110,100,115,32,40,112,114,111,116,111,116,121,112,101,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,90,72,31,0,14,32,156,193,33,0,16,0,115,97,116,117,114,100,97,121,32,110,105,103,104,116,32,115,108,97,109,109,97,115,116,101,114,115,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,63,90,250,8,33,0,16,0,102,114,111,109,32,116,118,32,97,110,105,109,97,116,105,111,110,32,115,108,97,109,32,100,117,110,107,32,45,32,107,121,111,117,103,111,117,32,109,97,107,107,111,117,32,116,97,105,107,101,116,115,117,33,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,143,103,245,205,33,0,16,0,115,117,112,101,114,32,107,105,110,103,32,107,111,110,103,32,57,57,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,226,254,61,65,41,0,16,0,115,107,105,116,99,104,105,110,32,115,107,105,116,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,215,249,133,247,33,0,16,0,109,112,114,45,49,53,52,50,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,255,147,55,244,33,0,16,0,115,107,101,108,101,116,111,110,32,107,114,101,119,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,55,39,135,95,33,0,16,0,115,105,100,101,32,112,111,99,107,101,116,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,69,129,224,54,33,0,16,0,115,104,117,114,97,32,110,111,32,109,111,110,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,229,166,157,225,33,0,16,0,115,104,117,105,32,104,117,32,122,104,117,97,110,32,40,99,104,105,41,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,195,88,228,97,33,0,16,0,109,112,114,45,49,53,55,57,56,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,181,62,109,11,33,0,16,0,115,104,105,110,105,110,103,32,102,111,114,99,101,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,190,74,89,224,33,0,16,0,109,112,114,45,49,54,57,51,51,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,209,70,203,131,33,0,16,0,115,104,105,110,105,110,103,32,105,110,32,116,104,101,32,100,97,114,107,110,101,115,115,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,188,133,39,77,33,0,16,0,115,117,112,101,114,32,104,105,103,104,32,105,109,112,97,99,116,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,247,194,112,184,33,0,16,0,115,104,105,107,105,110,106,111,104,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,125,201,160,94,33,0,16,0,109,112,114,45,49,51,53,55,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,16,173,233,235,33,0,16,0,109,112,114,45,49,50,51,53,53,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,176,203,201,229,33,0,16,0,109,112,114,45,49,50,54,52,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,163,1,34,203,33,0,16,0,115,104,97,110,103,104,97,105,32,105,105,32,45,32,100,114,97,103,111,110,39,115,32,101,121,101,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,45,202,74,21,33,0,16,0,115,104,97,110,101,32,119,97,114,110,101,32,99,114,105,99,107,101,116,32,40,97,117,115,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,111,95,134,104,33,0,16,0,115,104,97,100,111,119,114,117,110,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,9,41,185,251,33,0,16,0,109,112,114,45,49,54,48,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,184,150,179,249,33,0,16,0,115,101,110,115,105,98,108,101,32,115,111,99,99,101,114,32,45,32,105,110,116,101,114,110,97,116,105,111,110,97,108,32,101,100,105,116,105,111,110,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,202,188,227,4,33,0,16,0,115,101,103,97,32,115,112,111,114,116,115,32,49,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,0,241,218,254,7,33,0,16,0,115,101,103,97,32,99,104,97,110,110,101,108,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,237,182,121,188,33,0,16,0,115,101,97,113,117,101,115,116,32,100,115,118,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,189,17,181,11,33,0,16,0,115,104,111,119,32,100,111,32,109,105,108,104,97,111,32,40,98,114,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,4,223,34,10,33,0,16,0,115,104,111,119,32,100,111,32,109,105,108,104,97,111,32,118,111,108,117,109,101,32,50,32,40,98,114,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,203,102,238,72,33,0,16,0,115,117,112,101,114,32,100,111,110,107,101,121,32,107,111,110,103,32,57,57,32,40,117,110,108,41,32,40,112,114,111,116,101,99,116,101,100,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,213,77,190,67,43,0,16,0,115,99,114,97,98,98,108,101,32,40,101,117,114,111,41,32,40,112,114,111,116,111,116,121,112,101,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,16,38,11,54,33,0,16,0,115,97,110,103,111,107,117,115,104,105,32,114,101,116,115,117,100,101,110,32,45,32,114,97,110,115,101,105,32,110,111,32,101,105,121,117,117,116,97,99,104,105,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,90,120,86,15,33,0,16,0,115,97,110,103,111,107,117,115,104,105,32,105,105,105,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,234,106,222,168,33,0,16,0,109,112,114,45,49,52,52,53,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,38,163,123,67,33,0,16,0,112,101,116,101,32,115,97,109,112,114,97,115,32,116,101,110,110,105,115,32,40,101,117,114,111,44,32,117,115,97,41,32,40,106,45,99,97,114,116,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,209,187,245,158,33,0,16,0,109,100,115,116,101,101,95,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,188,25,139,170,33,0,16,0,115,97,109,112,114,97,115,32,116,101,110,110,105,115,32,57,54,32,40,101,117,114,111,41,32,40,106,45,99,97,114,116,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,123,251,227,20,33,0,16,0,109,112,114,45,49,51,51,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,65,216,187,119,33,0,16,0,98,105,115,104,111,117,106,111,32,115,101,110,115,104,105,32,115,97,105,108,111,114,32,109,111,111,110,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,56,105,36,94,33,0,16,0,114,121,117,117,107,111,32,110,111,32,107,101,110,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,246,245,76,5,33,0,16,0,114,111,121,97,108,32,98,108,111,111,100,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,241,7,1,14,33,0,16,0,114,111,109,97,110,99,101,32,111,102,32,116,104,101,32,116,104,114,101,101,32,107,105,110,103,100,111,109,115,32,105,105,105,32,45,32,100,114,97,103,111,110,32,111,102,32,100,101,115,116,105,110,121,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,0,254,200,65,126,33,0,16,0,114,111,109,97,110,99,101,32,111,102,32,116,104,101,32,116,104,114,101,101,32,107,105,110,103,100,111,109,115,32,105,105,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,120,36,132,61,33,0,16,0,114,111,99,107,109,97,110,32,120,51,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,240,57,230,62,33,0,16,0,114,111,99,107,109,97,110,32,109,101,103,97,32,119,111,114,108,100,32,40,106,112,110,41,32,40,97,108,116,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,239,86,201,133,33,0,16,0,114,111,98,111,116,32,119,114,101,99,107,97,103,101,32,40,117,115,97,41,32,40,112,114,111,116,111,116,121,112,101,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,20,219,125,198,33,0,16,0,114,111,98,111,99,111,112,32,118,101,114,115,117,115,32,116,104,101,32,116,101,114,109,105,110,97,116,111,114,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,141,63,169,133,33,0,16,0,114,111,98,111,116,32,98,97,116,116,108,101,114,32,40,106,112,110,41,32,40,115,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,255,62,242,253,33,0,16,0,114,111,98,111,99,111,112,32,51,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,123,251,52,33,0,16,0,106,97,109,101,115,32,112,111,110,100,32,105,105,32,45,32,99,111,100,101,110,97,109,101,32,114,111,98,111,99,111,100,32,40,106,112,110,44,32,107,111,114,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,2,71,121,152,33,0,16,0,114,111,97,100,32,114,97,115,104,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,25,61,165,222,33,0,16,0,114,111,97,100,98,108,97,115,116,101,114,115,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,240,213,108,236,33,0,16,0,114,111,99,107,32,110,39,32,114,111,108,108,32,114,97,99,105,110,103,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,98,5,90,188,33,0,16,0,114,105,115,116,97,114,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,117,108,32,48,49,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,10,122,92,124,33,0,16,0,114,105,115,116,97,114,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,117,108,32,49,56,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,201,204,236,107,33,0,16,0,114,105,115,116,97,114,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,117,103,32,49,50,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,70,240,113,67,33,0,16,0,114,105,115,116,97,114,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,117,103,32,50,54,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,221,79,199,208,33,0,16,0,101,115,49,51,51,45,49,95,114,105,115,101,95,111,102,95,116,104,101,95,114,111,98,111,116,115,46,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,247,62,88,237,17,0,16,0,101,115,49,51,51,45,50,95,114,105,115,101,95,111,102,95,116,104,101,95,114,111,98,111,116,115,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,112,132,241,252,23,0,16,0,114,105,110,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,151,196,252,65,33,0,16,0,114,105,99,107,32,100,97,110,103,101,114,111,117,115,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,62,0,228,187,92,84,33,0,16,0,114,101,118,101,110,103,101,32,111,102,32,115,104,105,110,111,98,105,44,32,116,104,101,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,148,121,242,5,33,0,16,0,114,101,118,101,110,103,101,32,111,102,32,115,104,105,110,111,98,105,44,32,116,104,101,32,40,101,117,114,111,44,32,117,115,97,41,32,40,114,101,118,32,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,126,171,145,254,33,0,16,0,109,112,114,45,49,52,49,56,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,130,95,81,46,33,0,16,0,114,101,110,32,38,32,115,116,105,109,112,121,32,115,104,111,119,32,112,114,101,115,101,110,116,115,32,115,116,105,109,112,121,39,115,32,105,110,118,101,110,116,105,111,110,44,32,116,104,101,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,165,59,80,217,33,0,16,0,116,104,101,32,98,97,116,116,108,101,32,111,102,32,114,101,100,32,99,108,105,102,102,115,32,45,32,114,111,109,97,110,99,101,32,111,102,32,116,104,101,32,116,104,114,101,101,32,107,105,110,103,100,111,109,115,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,32,0,146,52,70,68,33,0,16,0,114,97,105,110,98,111,119,32,105,115,108,97,110,100,115,32,101,120,116,114,97,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,53,203,77,199,33,0,16,0,114,97,115,116,97,110,32,115,97,103,97,32,105,105,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,90,251,172,235,33,0,16,0,114,97,110,103,101,114,45,120,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,21,89,145,85,33,0,16,0,114,97,109,112,97,114,116,32,40,106,112,110,44,32,107,111,114,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,76,214,234,22,33,0,16,0,115,104,105,110,32,115,111,117,115,101,105,107,105,32,114,97,103,110,97,99,101,110,116,121,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,226,90,63,106,33,0,16,0,114,97,100,105,99,97,118,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,56,132,76,59,17,0,16,0,114,97,100,105,99,97,115,102,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,68,251,138,134,17,0,16,0,114,97,99,101,32,100,114,105,118,105,110,39,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,61,207,55,215,33,0,16,0,113,117,97,100,32,99,104,97,108,108,101,110,103,101,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,128,106,115,116,33,0,16,0,109,112,114,45,49,52,51,55,49,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,215,141,210,93,65,0,16,0,112,121,114,97,109,105,100,32,109,97,103,105,99,32,115,112,101,99,105,97,108,32,40,106,112,110,41,32,40,115,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,250,58,58,21,33,0,16,0,112,121,114,97,109,105,100,32,109,97,103,105,99,32,105,105,105,32,40,106,112,110,41,32,40,115,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,10,130,41,131,33,0,16,0,112,121,114,97,109,105,100,32,109,97,103,105,99,32,105,105,32,40,106,112,110,41,32,40,115,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,114,172,221,201,33,0,16,0,112,117,121,111,32,112,117,121,111,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,78,97,38,127,33,0,16,0,112,117,121,111,32,112,117,121,111,32,50,32,40,106,112,110,41,32,40,118,49,46,49,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,170,178,183,37,33,0,16,0,112,117,110,105,115,104,101,114,44,32,116,104,101,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,23,221,158,114,33,0,16,0,112,117,108,115,101,109,97,110,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,78,16,138,19,33,0,16,0,112,115,121,45,111,45,98,108,97,100,101,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,197,230,167,139,33,0,16,0,112,104,97,110,116,97,115,121,32,115,116,97,114,32,105,118,32,40,112,114,111,116,111,116,121,112,101,32,45,32,109,97,121,32,51,48,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,225,23,43,179,33,0,16,0,112,104,97,110,116,97,115,121,32,115,116,97,114,32,105,118,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,117,110,32,48,56,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,10,28,46,220,33,0,16,0,112,104,97,110,116,97,115,121,32,115,116,97,114,32,105,118,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,117,103,32,49,53,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,37,127,19,96,33,0,16,0,112,104,97,110,116,97,115,121,32,115,116,97,114,32,105,118,32,40,112,114,111,116,111,116,121,112,101,32,45,32,111,99,116,32,50,55,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,10,89,162,18,33,0,16,0,112,104,97,110,116,97,115,121,32,115,116,97,114,32,105,118,32,40,112,114,111,116,111,116,121,112,101,32,45,32,110,111,118,32,48,55,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,223,156,162,189,33,0,16,0,112,104,97,110,116,97,115,121,32,115,116,97,114,32,105,105,105,32,45,32,103,101,110,101,114,97,116,105,111,110,115,32,111,102,32,100,111,111,109,32,40,98,114,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,35,76,155,46,33,0,16,0,112,104,97,110,116,97,115,121,32,115,116,97,114,32,105,105,32,40,98,114,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,102,139,104,230,33,0,16,0,112,114,111,32,121,97,107,121,117,117,32,115,117,112,101,114,32,108,101,97,103,117,101,32,39,57,49,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,126,171,72,169,33,0,16,0,106,46,32,108,101,97,103,117,101,32,112,114,111,32,115,116,114,105,107,101,114,32,102,105,110,97,108,32,115,116,97,103,101,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,251,37,94,227,33,0,16,0,112,114,105,109,101,32,116,105,109,101,32,110,102,108,32,115,116,97,114,114,105,110,103,32,100,101,105,111,110,32,115,97,110,100,101,114,115,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,188,60,165,90,33,0,16,0,112,114,101,109,105,101,114,32,109,97,110,97,103,101,114,32,57,55,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,155,246,203,252,33,0,16,0,109,112,114,45,49,56,52,55,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,159,136,59,48,33,0,16,0,112,114,101,100,97,116,111,114,32,50,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,62,17,186,189,33,0,16,0,112,114,105,110,99,101,32,111,102,32,112,101,114,115,105,97,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,164,129,193,19,33,0,16,0,112,114,105,110,99,101,32,111,102,32,112,101,114,115,105,97,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,182,20,83,80,33,0,16,0,112,114,105,110,99,101,32,111,102,32,112,101,114,115,105,97,32,50,32,45,32,116,104,101,32,115,104,97,100,111,119,32,97,110,100,32,116,104,101,32,102,108,97,109,101,32,40,101,117,114,111,41,32,40,112,114,111,116,111,116,121,112,101,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,70,77,180,58,33,0,16,0,112,111,119,101,114,98,97,108,108,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,47,35,223,122,33,0,16,0,112,111,119,101,114,32,97,116,104,108,101,116,101,32,40,106,112,110,44,32,107,111,114,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,207,119,27,180,33,0,16,0,112,111,112,117,108,111,117,115,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,100,111,213,131,33,0,16,0,112,111,107,101,109,111,110,32,115,116,97,100,105,117,109,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,93,124,24,254,33,0,16,0,112,111,99,107,101,116,32,109,111,110,115,116,101,114,115,32,40,117,110,108,41,32,40,97,108,116,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,103,102,23,251,33,0,16,0,112,111,99,107,101,116,32,109,111,110,115,116,101,114,115,32,50,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,31,3,247,48,33,0,16,0,109,112,114,45,49,56,56,55,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,135,121,94,22,33,0,16,0,112,111,119,101,114,32,109,111,110,103,101,114,32,40,106,112,110,44,32,107,111,114,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,179,137,50,85,33,0,16,0,109,112,114,45,49,52,51,50,48,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,2,139,138,212,33,0,16,0,112,105,116,102,97,108,108,32,45,32,116,104,101,32,109,97,121,97,110,32,97,100,118,101,110,116,117,114,101,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,79,227,23,249,33,0,16,0,112,105,114,97,116,101,115,33,32,103,111,108,100,32,40,117,115,97,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,65,86,82,10,33,0,16,0,112,105,114,97,116,101,115,32,111,102,32,100,97,114,107,32,119,97,116,101,114,44,32,116,104,101,32,40,117,115,97,41,32,40,106,97,110,117,97,114,121,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,247,185,69,12,33,0,16,0,106,101,114,114,121,32,103,108,97,110,118,105,108,108,101,39,115,32,112,105,103,115,107,105,110,32,102,111,111,116,98,114,97,119,108,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,48,141,244,231,33,0,16,0,112,104,101,108,105,111,115,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,32,147,199,17,33,0,16,0,112,104,101,108,105,111,115,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,116,97,89,148,33,0,16,0,112,104,97,110,116,111,109,32,50,48,52,48,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,243,225,54,251,33,0,16,0,112,97,116,32,114,105,108,101,121,32,98,97,115,107,101,116,98,97,108,108,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,167,24,147,61,33,0,16,0,107,105,100,111,117,32,107,101,105,115,97,116,115,117,32,112,97,116,108,97,98,111,114,32,45,32,57,56,45,115,104,105,107,105,32,107,105,100,111,117,32,115,101,121,111,33,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,73,231,160,33,33,0,16,0,112,97,112,101,114,98,111,121,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,155,129,68,10,33,0,16,0,109,112,114,45,49,53,51,50,48,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,177,139,226,29,33,0,16,0,112,97,103,101,109,97,115,116,101,114,44,32,116,104,101,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,226,128,161,121,33,0,16,0,112,97,99,45,112,97,110,105,99,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,130,120,66,60,33,0,16,0,109,112,114,45,49,52,51,57,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,155,160,187,116,33,0,16,0,112,97,99,104,105,110,107,111,32,107,117,117,110,121,97,110,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,127,126,19,157,33,0,16,0,112,97,99,45,97,116,116,97,99,107,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,247,130,243,93,33,0,16,0,109,112,114,45,49,53,52,56,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,106,83,179,92,33,0,16,0,111,117,116,108,97,110,100,101,114,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,80,35,111,254,33,0,16,0,111,116,116,105,102,97,110,116,115,44,32,116,104,101,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,3,128,172,65,33,0,16,0,111,115,111,109,97,116,115,117,45,107,117,110,32,104,97,99,104,97,109,101,99,104,97,32,103,101,107,105,106,111,117,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,12,53,83,36,33,0,16,0,111,117,116,114,117,110,110,101,114,115,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,185,54,230,237,33,0,16,0,111,112,101,114,97,116,105,111,110,32,101,117,114,111,112,101,32,45,32,112,97,116,104,32,116,111,32,118,105,99,116,111,114,121,32,49,57,51,57,45,52,53,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,216,161,203,231,33,0,16,0,104,117,110,116,105,110,103,32,115,101,97,115,111,110,32,51,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,13,9,0,140,135,51,180,33,0,16,0,111,108,121,109,112,105,99,32,115,117,109,109,101,114,32,103,97,109,101,115,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,185,15,71,158,33,0,16,0,109,112,114,45,49,52,55,53,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,211,87,78,146,33,0,16,0,110,111,32,101,115,99,97,112,101,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,32,95,238,68,33,0,16,0,110,111,98,117,110,97,103,97,32,110,111,32,121,97,98,111,117,32,45,32,122,101,110,107,111,107,117,32,98,97,110,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,19,179,129,19,33,0,16,0,109,112,114,45,49,52,52,53,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,55,134,191,48,33,0,16,0,106,97,99,107,32,110,105,99,107,108,97,117,115,39,32,112,111,119,101,114,32,99,104,97,108,108,101,110,103,101,32,103,111,108,102,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,9,233,69,85,33,0,16,0,110,104,108,112,97,32,104,111,99,107,101,121,32,57,51,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,98,66,191,203,33,0,16,0,110,104,108,112,97,32,50,48,48,51,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,27,87,145,69,33,0,16,0,110,104,108,32,97,108,108,45,115,116,97,114,32,104,111,99,107,101,121,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,115,101,112,32,49,52,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,141,196,75,93,33,0,16,0,110,104,108,32,97,108,108,45,115,116,97,114,32,104,111,99,107,101,121,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,115,101,112,32,50,57,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,249,255,31,0,79,228,186,150,33,0,16,0,110,104,108,32,97,108,108,45,115,116,97,114,32,104,111,99,107,101,121,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,111,99,116,32,48,49,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,249,255,31,0,178,251,192,177,33,0,16,0,110,104,108,32,97,108,108,45,115,116,97,114,32,104,111,99,107,101,121,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,111,99,116,32,50,49,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,56,34,235,23,33,0,16,0,110,104,108,32,97,108,108,45,115,116,97,114,32,104,111,99,107,101,121,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,110,111,118,32,48,55,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,143,200,242,232,33,0,16,0,110,104,108,32,97,108,108,45,115,116,97,114,32,104,111,99,107,101,121,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,110,111,118,32,48,57,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,249,255,31,0,115,64,98,130,33,0,16,0,110,104,108,32,97,108,108,45,115,116,97,114,32,104,111,99,107,101,121,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,110,111,118,32,49,57,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,138,88,15,205,33,0,16,0,110,104,108,32,97,108,108,45,115,116,97,114,32,104,111,99,107,101,121,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,110,111,118,32,50,49,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0])
.concat([157,5,228,207,33,0,16,0,110,104,108,32,97,108,108,45,115,116,97,114,32,104,111,99,107,101,121,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,110,111,118,32,50,50,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,250,255,31,0,230,15,211,129,33,0,16,0,110,104,108,32,97,108,108,45,115,116,97,114,32,104,111,99,107,101,121,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,110,111,118,32,50,51,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,250,255,31,0,56,252,212,136,33,0,16,0,110,104,108,32,97,108,108,45,115,116,97,114,32,104,111,99,107,101,121,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,110,111,118,32,50,55,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,250,255,31,0,82,254,143,101,33,0,16,0,110,104,108,32,97,108,108,45,115,116,97,114,32,104,111,99,107,101,121,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,110,111,118,32,50,56,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,250,255,31,0,86,0,173,81,33,0,16,0,110,104,108,32,97,108,108,45,115,116,97,114,32,104,111,99,107,101,121,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,110,111,118,32,50,57,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,250,255,31,0,11,166,96,160,33,0,16,0,110,104,108,32,97,108,108,45,115,116,97,114,32,104,111,99,107,101,121,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,100,101,99,32,48,49,44,32,49,57,57,52,32,45,32,98,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,250,255,31,0,32,215,9,194,33,0,16,0,110,104,108,32,97,108,108,45,115,116,97,114,32,104,111,99,107,101,121,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,100,101,99,32,48,49,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,250,255,31,0,179,76,46,17,33,0,16,0,110,104,108,32,97,108,108,45,115,116,97,114,32,104,111,99,107,101,121,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,100,101,99,32,48,50,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,250,255,31,0,199,166,214,1,33,0,16,0,110,104,107,32,116,97,105,103,97,32,100,114,97,109,97,32,45,32,116,97,105,104,101,105,107,105,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,14,179,251,9,33,0,16,0,109,112,114,45,49,53,48,48,53,43,109,112,114,45,49,53,48,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,225,31,11,206,33,0,16,0,110,102,108,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,117,103,32,48,49,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,78,234,87,90,33,0,16,0,110,102,108,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,117,103,32,48,53,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,115,23,213,136,33,0,16,0,110,102,108,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,117,103,32,49,48,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,11,113,197,163,33,0,16,0,110,102,108,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,117,103,32,49,50,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,59,99,35,61,33,0,16,0,110,102,108,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,117,103,32,49,50,44,32,49,57,57,52,32,45,32,98,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,89,162,134,204,33,0,16,0,110,102,108,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,117,103,32,49,55,44,32,49,57,57,52,32,45,32,98,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,41,92,1,166,33,0,16,0,110,102,108,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,117,103,32,49,55,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,200,102,89,101,33,0,16,0,110,102,108,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,117,103,32,50,50,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,229,52,20,176,33,0,16,0,110,102,108,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,117,103,32,51,48,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,54,164,224,208,33,0,16,0,110,102,108,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,117,103,32,51,49,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,30,82,96,195,33,0,16,0,110,102,108,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,115,101,112,32,48,49,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,170,252,64,146,33,0,16,0,110,102,108,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,115,101,112,32,48,50,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,73,154,4,255,33,0,16,0,110,102,108,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,115,101,112,32,48,52,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,64,77,96,96,33,0,16,0,110,102,108,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,115,101,112,32,48,53,44,32,49,57,57,52,32,45,32,98,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,165,133,57,18,33,0,16,0,110,102,108,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,115,101,112,32,48,53,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,172,97,223,219,33,0,16,0,110,102,108,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,115,101,112,32,48,54,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,153,134,75,98,33,0,16,0,110,102,108,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,115,101,112,32,48,55,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,190,164,138,174,33,0,16,0,110,102,108,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,115,101,112,32,48,56,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,137,226,197,34,33,0,16,0,110,102,108,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,115,101,112,32,48,57,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,102,16,223,85,33,0,16,0,110,102,108,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,115,101,112,32,49,49,44,32,49,57,57,52,32,45,32,98,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,160,198,26,17,33,0,16,0,110,102,108,32,39,57,53,32,40,112,114,111,116,111,116,121,112,101,32,45,32,115,101,112,32,49,49,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,79,76,97,33,33,0,16,0,117,110,99,104,97,114,116,101,100,32,119,97,116,101,114,115,32,45,32,110,101,119,32,104,111,114,105,122,111,110,115,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,36,152,214,234,33,0,16,0,110,101,107,107,101,116,115,117,32,107,111,117,107,111,117,32,100,111,100,103,101,98,97,108,108,32,98,117,32,45,32,115,111,99,99,101,114,32,104,101,110,32,109,100,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,134,58,156,244,33,0,16,0,110,99,97,97,32,102,111,111,116,98,97,108,108,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,240,18,16,8,33,0,16,0,110,99,97,97,32,102,105,110,97,108,32,102,111,117,114,32,98,97,115,107,101,116,98,97,108,108,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,3,19,12,237,33,0,16,0,110,98,97,32,115,104,111,119,100,111,119,110,32,39,57,52,32,40,117,115,97,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,8,163,67,102,33,0,16,0,110,98,97,32,112,114,111,32,98,97,115,107,101,116,98,97,108,108,32,39,57,52,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,206,155,161,238,33,0,16,0,110,98,97,32,108,105,118,101,32,57,56,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,138,58,71,35,33,0,16,0,110,98,97,32,108,105,118,101,32,57,55,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,58,132,36,112,33,0,16,0,110,98,97,32,108,105,118,101,32,57,54,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,98,0,222,73,33,0,16,0,110,98,97,32,108,105,118,101,32,57,53,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,188,138,1,102,33,0,16,0,110,98,97,32,106,97,109,32,116,111,117,114,110,97,109,101,110,116,32,101,100,105,116,105,111,110,32,40,119,111,114,108,100,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,55,203,255,233,33,0,16,0,106,97,109,111,100,48,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,13,36,6,133,49,0,16,0,106,97,109,101,118,48,46,105,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,148,127,89,46,50,0,16,0,106,97,109,111,100,49,46,105,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,172,79,44,118,53,0,16,0,106,97,109,101,118,49,46,105,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,185,53,135,54,0,16,0,110,98,97,32,104,97,110,103,32,116,105,109,101,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,56,3,107,23,33,0,16,0,110,98,97,32,97,108,108,45,115,116,97,114,32,99,104,97,108,108,101,110,103,101,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,223,74,103,196,33,0,16,0,110,98,97,32,97,99,116,105,111,110,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,97,110,32,48,52,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,47,223,145,36,33,0,16,0,110,98,97,32,97,99,116,105,111,110,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,97,110,32,49,54,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,157,199,67,254,33,0,16,0,110,98,97,32,97,99,116,105,111,110,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,97,110,32,50,55,44,32,49,57,57,52,41,32,40,98,114,111,107,101,110,32,45,32,99,48,56,32,109,105,115,115,105,110,103,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,197,75,106,23,33,0,16,0,110,98,97,32,97,99,116,105,111,110,32,39,57,53,32,115,116,97,114,114,105,110,103,32,100,97,118,105,100,32,114,111,98,105,110,115,111,110,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,214,6,112,170,33,0,16,0,110,97,107,97,106,105,109,97,32,115,97,116,111,114,117,32,107,97,110,115,104,117,117,32,102,49,32,115,117,112,101,114,32,108,105,99,101,110,115,101,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,121,188,116,135,33,0,16,0,110,97,107,97,106,105,109,97,32,115,97,116,111,114,117,32,107,97,110,115,104,117,117,32,102,49,32,103,114,97,110,100,32,112,114,105,120,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,207,71,190,147,33,0,16,0,110,101,119,32,51,100,32,103,111,108,102,32,115,105,109,117,108,97,116,105,111,110,32,119,97,105,97,108,97,101,32,110,111,32,107,105,115,101,107,105,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,246,193,226,203,33,0,16,0,110,101,119,32,51,100,32,103,111,108,102,32,115,105,109,117,108,97,116,105,111,110,32,112,101,98,98,108,101,32,98,101,97,99,104,32,110,111,32,104,97,116,111,117,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,93,46,237,150,33,0,16,0,110,101,119,32,51,100,32,103,111,108,102,32,115,105,109,117,108,97,116,105,111,110,32,100,101,118,105,108,39,115,32,99,111,117,114,115,101,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,103,12,9,189,33,0,16,0,109,112,114,45,49,54,48,55,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,146,191,169,210,33,0,16,0,109,112,114,45,49,50,55,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,184,26,206,249,33,0,16,0,109,117,104,97,109,109,97,100,32,97,108,105,32,104,101,97,118,121,119,101,105,103,104,116,32,98,111,120,105,110,103,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,123,113,164,142,33,0,16,0,109,115,46,32,112,97,99,45,109,97,110,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,230,27,4,175,33,0,16,0,109,111,110,115,116,101,114,115,32,105,110,99,46,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,213,87,70,63,33,0,16,0,109,111,110,111,112,111,108,121,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,218,104,2,193,33,0,16,0,109,105,103,104,116,121,32,109,111,114,112,104,105,110,32,112,111,119,101,114,32,114,97,110,103,101,114,115,32,45,32,116,104,101,32,109,111,118,105,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,117,108,32,49,51,44,32,49,57,57,53,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,253,247,123,34,33,0,16,0,109,105,103,104,116,121,32,109,111,114,112,104,105,110,32,112,111,119,101,114,32,114,97,110,103,101,114,115,32,45,32,116,104,101,32,109,111,118,105,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,117,108,32,49,55,44,32,49,57,57,53,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,87,230,157,87,33,0,16,0,109,105,103,104,116,121,32,109,111,114,112,104,105,110,32,112,111,119,101,114,32,114,97,110,103,101,114,115,32,45,32,116,104,101,32,109,111,118,105,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,117,108,32,50,50,44,32,49,57,57,53,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,139,58,202,194,33,0,16,0,109,105,103,104,116,121,32,109,111,114,112,104,105,110,32,112,111,119,101,114,32,114,97,110,103,101,114,115,32,45,32,116,104,101,32,109,111,118,105,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,117,108,32,50,52,44,32,49,57,57,53,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,58,250,41,52,33,0,16,0,109,105,99,107,101,121,32,109,97,110,105,97,32,45,32,116,104,101,32,116,105,109,101,108,101,115,115,32,97,100,118,101,110,116,117,114,101,115,32,111,102,32,109,105,99,107,101,121,32,109,111,117,115,101,32,40,117,115,97,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,240,189,193,127,33,0,16,0,109,117,116,97,110,116,32,108,101,97,103,117,101,32,104,111,99,107,101,121,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,15,24,41,53,33,0,16,0,109,117,116,97,110,116,32,108,101,97,103,117,101,32,102,111,111,116,98,97,108,108,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,175,230,151,42,33,0,16,0,109,105,114,97,99,108,101,32,112,105,97,110,111,32,116,101,97,99,104,105,110,103,32,115,121,115,116,101,109,44,32,116,104,101,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,46,84,25,167,33,0,16,0,99,104,111,117,32,107,121,117,117,107,97,105,32,109,105,114,97,99,108,101,32,110,105,110,101,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,6,34,140,109,33,0,16,0,109,105,103,104,116,32,97,110,100,32,109,97,103,105,99,32,105,105,105,32,45,32,105,115,108,101,115,32,111,102,32,116,101,114,114,97,32,40,117,115,97,41,32,40,112,114,111,116,111,116,121,112,101,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,74,16,247,110,33,0,16,0,109,112,114,45,49,55,52,51,52,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,187,163,241,36,33,0,16,0,109,105,103,104,116,32,97,110,100,32,109,97,103,105,99,32,45,32,103,97,116,101,115,32,116,111,32,97,110,111,116,104,101,114,32,119,111,114,108,100,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,95,20,9,245,33,0,16,0,109,100,109,95,50,98,101,97,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,235,183,191,66,33,0,16,0,109,100,109,109,97,99,100,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,11,26,8,80,33,0,16,0,109,109,57,54,109,100,101,100,100,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,13,157,49,35,33,0,16,0,109,112,114,45,49,53,50,51,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,106,140,33,92,33,0,16,0,109,105,99,107,101,121,39,115,32,117,108,116,105,109,97,116,101,32,99,104,97,108,108,101,110,103,101,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,238,18,181,48,33,0,16,0,103,114,101,97,116,32,99,105,114,99,117,115,32,109,121,115,116,101,114,121,32,115,116,97,114,114,105,110,103,32,109,105,99,107,101,121,32,38,32,109,105,110,110,105,101,44,32,116,104,101,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,131,72,116,20,33,0,16,0,109,101,116,97,108,32,102,97,110,103,115,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,76,28,223,168,33,0,16,0,109,101,103,97,32,116,117,114,114,105,99,97,110,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,15,93,209,177,33,0,16,0,109,101,103,97,116,114,97,120,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,65,119,131,160,33,0,16,0,109,101,103,97,32,115,119,105,118,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,70,240,194,120,33,0,16,0,109,101,103,97,112,97,110,101,108,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,121,245,64,98,33,0,16,0,109,101,103,97,32,97,110,115,101,114,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,103,227,236,8,33,0,16,0,109,101,103,97,109,105,110,100,32,40,106,112,110,41,32,40,115,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,226,42,223,118,33,0,16,0,109,112,114,45,49,56,56,55,49,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,79,126,62,254,33,0,16,0,109,101,103,97,32,103,97,109,101,115,32,54,32,118,111,108,46,32,50,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,185,13,209,232,33,0,16,0,109,112,114,45,49,56,48,48,50,43,109,112,114,49,56,48,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,13,184,111,182,33,0,16,0,109,101,103,97,32,103,97,109,101,115,32,49,48,32,40,98,114,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,104,227,154,193,33,0,16,0,109,112,114,45,49,55,49,48,56,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,235,59,171,84,33,0,16,0,109,99,100,111,110,97,108,100,39,115,32,116,114,101,97,115,117,114,101,32,108,97,110,100,32,97,100,118,101,110,116,117,114,101,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,218,168,182,106,33,0,16,0,109,97,122,105,110,32,119,97,114,115,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,5,161,7,75,33,0,16,0,100,111,110,97,108,100,32,105,110,32,109,97,117,105,32,109,97,108,108,97,114,100,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,127,133,221,178,33,0,16,0,109,97,116,104,32,98,108,97,115,116,101,114,32,45,32,101,112,105,115,111,100,101,32,49,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,98,164,85,208,33,0,16,0,109,112,114,45,49,52,49,50,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,194,232,30,213,33,0,16,0,109,97,114,118,101,108,32,108,97,110,100,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,183,238,126,205,33,0,16,0,110,105,103,101,108,32,109,97,110,115,101,108,108,39,115,32,119,111,114,108,100,32,99,104,97,109,112,105,111,110,115,104,105,112,32,114,97,99,105,110,103,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,44,123,197,107,33,0,16,0,109,97,104,106,111,110,103,32,99,111,112,32,114,121,117,117,32,45,32,115,104,105,114,111,32,111,111,107,97,109,105,32,110,111,32,121,97,98,111,117,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,130,199,203,28,33,0,16,0,109,97,103,105,115,116,114,32,49,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,133,230,136,36,33,0,16,0,109,97,103,105,99,97,108,32,104,97,116,32,110,111,32,98,117,116,116,111,98,105,32,116,117,114,98,111,33,32,100,97,105,98,111,117,107,101,110,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,61,133,62,228,33,0,16,0,109,97,100,111,117,32,109,111,110,111,103,97,116,97,114,105,32,105,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,1,196,130,221,33,0,16,0,109,97,100,100,101,110,32,110,102,108,32,57,56,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,98,234,81,224,33,0,16,0,109,97,100,100,101,110,32,110,102,108,32,57,55,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,18,225,180,196,33,0,16,0,109,97,100,100,101,110,32,110,102,108,32,57,54,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,139,145,38,241,33,0,16,0,109,97,100,100,101,110,32,110,102,108,32,57,53,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,194,224,11,219,33,0,16,0,109,97,100,100,101,110,32,110,102,108,32,39,57,52,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,27,129,75,209,33,0,16,0,106,109,102,51,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,62,59,50,202,33,0,16,0,106,111,104,110,32,109,97,100,100,101,110,32,102,111,111,116,98,97,108,108,32,39,57,50,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,69,57,110,4,33,0,16,0,106,111,104,110,32,109,97,100,100,101,110,32,102,111,111,116,98,97,108,108,32,39,57,51,32,45,32,99,104,97,109,112,105,111,110,115,104,105,112,32,101,100,105,116,105,111,110,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,26,75,83,202,33,0,16,0,109,97,100,97,103,97,115,99,97,114,32,51,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,165,208,214,11,33,0,16,0,109,97,100,97,103,97,115,99,97,114,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,229,172,40,109,33,0,16,0,109,45,49,32,97,98,114,97,109,115,32,98,97,116,116,108,101,32,116,97,110,107,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,207,116,47,30,33,0,16,0,108,111,115,116,32,119,111,114,108,100,44,32,116,104,101,32,45,32,106,117,114,97,115,115,105,99,32,112,97,114,107,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,76,40,10,20,33,0,16,0,108,111,115,116,32,118,105,107,105,110,103,115,44,32,116,104,101,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,219,158,164,123,33,0,16,0,108,111,115,116,32,118,105,107,105,110,103,115,44,32,116,104,101,32,40,101,117,114,111,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,95,210,190,23,33,0,16,0,109,112,114,45,49,55,50,55,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,188,165,150,86,33,0,16,0,115,104,105,32,122,105,32,119,97,110,103,32,51,32,45,32,116,104,101,32,108,105,111,110,32,107,105,110,103,32,51,32,40,99,104,105,41,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,157,33,4,192,41,0,16,0,115,104,105,32,122,105,32,119,97,110,103,32,105,105,32,45,32,116,104,101,32,108,105,111,110,32,107,105,110,103,32,105,105,44,32,116,104,101,32,40,99,104,105,41,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,101,103,244,175,33,0,16,0,108,105,103,104,116,101,110,105,110,103,32,102,111,114,99,101,32,45,32,113,117,101,115,116,32,102,111,114,32,116,104,101,32,100,97,114,107,115,116,97,114,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,224,192,248,200,33,0,16,0,108,101,116,104,97,108,32,101,110,102,111,114,99,101,114,115,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,157,249,43,202,33,0,16,0,109,112,114,45,49,53,50,51,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,121,69,26,106,33,0,16,0,108,101,109,109,105,110,103,115,32,50,32,45,32,116,104,101,32,116,114,105,98,101,115,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,36,182,30,116,33,0,16,0,108,97,119,110,109,111,119,101,114,32,109,97,110,44,32,116,104,101,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,89,205,202,167,33,0,16,0,109,112,114,45,49,50,53,55,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,119,173,250,187,33,0,16,0,108,97,32,114,117,115,115,97,32,98,97,115,101,98,97,108,108,32,57,53,32,40,117,115,97,44,32,97,117,115,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,146,138,132,63,33,0,16,0,109,112,114,45,49,51,56,52,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,22,80,234,182,33,0,16,0,108,97,110,103,114,105,115,115,101,114,32,105,105,32,40,106,112,110,41,32,40,118,49,46,50,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,249,201,103,73,33,0,16,0,108,97,110,100,115,116,97,108,107,101,114,32,45,32,116,104,101,32,116,114,101,97,115,117,114,101,115,32,111,102,32,107,105,110,103,32,110,111,108,101,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,119,82,198,227,33,0,16,0,115,104,105,32,110,111,32,109,101,105,107,121,117,117,32,45,32,108,97,98,121,114,105,110,116,104,32,111,102,32,100,101,97,116,104,32,40,106,112,110,41,32,40,115,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,45,224,215,166,33,0,16,0,107,121,117,117,107,97,105,32,100,111,117,99,104,117,117,107,105,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,227,220,72,222,33,0,16,0,107,111,117,116,101,116,115,117,32,116,101,105,107,111,107,117,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,138,11,93,117,33,0,16,0,107,105,115,115,32,115,104,111,116,32,40,106,112,110,41,32,40,115,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,140,8,135,228,33,0,16,0,107,105,115,104,105,32,100,101,110,115,101,116,115,117,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,74,240,225,34,33,0,16,0,107,105,110,103,39,115,32,98,111,117,110,116,121,32,45,32,116,104,101,32,99,111,110,113,117,101,114,111,114,39,115,32,113,117,101,115,116,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,46,169,104,170,33,0,16,0,107,105,110,103,32,115,97,108,109,111,110,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,159,252,44,33,0,16,0,107,105,108,108,105,110,103,32,103,97,109,101,32,115,104,111,119,44,32,116,104,101,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,138,102,231,184,33,0,16,0,99,104,97,109,101,108,101,111,110,32,107,105,100,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,128,124,33,80,33,0,16,0,107,105,99,107,32,111,102,102,32,51,32,45,32,101,117,114,111,112,101,97,110,32,99,104,97,108,108,101,110,103,101,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,26,64,55,188,33,0,16,0,107,117,110,103,32,102,117,32,112,97,110,100,97,32,50,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,37,59,140,160,33,0,16,0,107,97,119,97,115,97,107,105,32,115,117,112,101,114,98,105,107,101,32,99,104,97,108,108,101,110,103,101,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,233,200,28,99,33,0,16,0,106,117,117,111,117,107,105,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,192,150,124,27,33,0,16,0,106,117,110,99,116,105,111,110,32,40,117,115,97,44,32,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,141,206,205,148,33,0,16,0,106,117,110,103,108,101,32,115,116,114,105,107,101,32,40,117,115,97,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,212,64,213,12,33,0,16,0,106,117,110,103,108,101,32,115,116,114,105,107,101,32,45,32,117,107,101,116,115,117,103,97,114,101,116,97,32,107,121,111,117,107,105,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,11,135,122,186,33,0,16,0,106,111,114,100,97,110,32,118,115,32,98,105,114,100,32,45,32,111,110,101,32,111,110,32,111,110,101,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,150,232,55,136,33,0,16,0,106,111,114,100,97,110,32,118,115,32,98,105,114,100,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,109,126,215,34,33,0,16,0,109,112,114,45,49,52,51,53,54,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,147,168,93,164,33,0,16,0,106,105,109,32,112,111,119,101,114,32,45,32,116,104,101,32,97,114,99,97,100,101,32,103,97,109,101,32,40,117,115,97,41,32,40,112,114,111,116,111,116,121,112,101,41,32,40,98,97,100,32,100,117,109,112,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,139,35,243,28,33,0,16,0,106,105,109,109,121,32,119,104,105,116,101,39,115,32,119,104,105,114,108,119,105,110,100,32,115,110,111,111,107,101,114,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,31,91,239,10,33,0,16,0,106,101,119,101,108,32,109,97,115,116,101,114,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,108,146,246,44,33,0,16,0,106,101,111,112,97,114,100,121,33,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,241,243,207,86,33,0,16,0,106,101,111,112,97,114,100,121,33,32,115,112,111,114,116,115,32,101,100,105,116,105,111,110,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,210,36,249,19,33,0,16,0,106,101,111,112,97,114,100,121,33,32,100,101,108,117,120,101,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,210,249,226,37,33,0,16,0,106,101,110,110,105,102,101,114,32,99,97,112,114,105,97,116,105,32,116,101,110,110,105,115,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,142,188,42,171,33,0,16,0,106,101,108,108,121,32,98,111,121,32,40,101,117,114,111,41,32,40,112,114,111,116,111,116,121,112,101,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,22,220,250,124,33,0,16,0,106,117,100,103,101,32,100,114,101,100,100,32,40,117,115,97,41,32,40,98,101,116,97,41,32,40,97,108,116,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,132,247,73,230,33,0,16,0,106,117,100,103,101,32,100,114,101,100,100,32,40,117,115,97,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,218,244,70,141,33,0,16,0,109,112,114,45,49,51,50,54,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,42,207,187,135,33,0,16,0,105,114,97,113,32,119,97,114,32,50,48,48,51,32,40,97,108,116,41,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,55,146,104,35,33,0,16,0,105,110,116,101,114,110,97,116,105,111,110,97,108,32,114,117,103,98,121,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,153,22,125,217,33,0,16,0,105,110,115,116,114,117,109,101,110,116,115,32,111,102,32,99,104,97,111,115,32,115,116,97,114,114,105,110,103,32,121,111,117,110,103,32,105,110,100,105,97,110,97,32,106,111,110,101,115,32,40,112,114,111,116,111,116,121,112,101,32,45,32,100,101,99,32,50,56,44,32,49,57,57,51,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,28,100,202,81,33,0,16,0,105,110,115,116,114,117,109,101,110,116,115,32,111,102,32,99,104,97,111,115,32,115,116,97,114,114,105,110,103,32,121,111,117,110,103,32,105,110,100,105,97,110,97,32,106,111,110,101,115,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,97,110,32,48,49,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,76,26,63,38,33,0,16,0,105,110,115,116,114,117,109,101,110,116,115,32,111,102,32,99,104,97,111,115,32,115,116,97,114,114,105,110,103,32,121,111,117,110,103,32,105,110,100,105,97,110,97,32,106,111,110,101,115,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,97,110,32,48,51,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,61,216,70,60,33,0,16,0,105,110,115,116,114,117,109,101,110,116,115,32,111,102,32,99,104,97,111,115,32,115,116,97,114,114,105,110,103,32,121,111,117,110,103,32,105,110,100,105,97,110,97,32,106,111,110,101,115,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,97,110,32,50,54,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,66,133,73,243,33,0,16,0,105,110,115,116,114,117,109,101,110,116,115,32,111,102,32,99,104,97,111,115,32,115,116,97,114,114,105,110,103,32,121,111,117,110,103,32,105,110,100,105,97,110,97,32,106,111,110,101,115,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,97,110,32,50,55,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,195,18,49,244,33,0,16,0,105,110,115,116,114,117,109,101,110,116,115,32,111,102,32,99,104,97,111,115,32,115,116,97,114,114,105,110,103,32,121,111,117,110,103,32,105,110,100,105,97,110,97,32,106,111,110,101,115,32,40,112,114,111,116,111,116,121,112,101,32,45,32,115,101,112,32,50,51,44,32,49,57,57,52,32,45,32,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,196,227,15,0,41,58,68,20,33,0,16,0,105,110,115,116,114,117,109,101,110,116,115,32,111,102,32,99,104,97,111,115,32,115,116,97,114,114,105,110,103,32,121,111,117,110,103,32,105,110,100,105,97,110,97,32,106,111,110,101,115,32,40,112,114,111,116,111,116,121,112,101,32,45,32,100,101,99,32,50,56,44,32,49,57,57,52,32,45,32,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,60,247,15,0,70,173,133,242,33,0,16,0,105,110,115,116,114,117,109,101,110,116,115,32,111,102,32,99,104,97,111,115,32,115,116,97,114,114,105,110,103,32,121,111,117,110,103,32,105,110,100,105,97,110,97,32,106,111,110,101,115,32,40,112,114,111,116,111,116,121,112,101,32,45,32,100,101,99,32,50,57,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,81,35,176,148,33,0,16,0,105,110,115,116,114,117,109,101,110,116,115,32,111,102,32,99,104,97,111,115,32,115,116,97,114,114,105,110,103,32,121,111,117,110,103,32,105,110,100,105,97,110,97,32,106,111,110,101,115,32,40,117,115,97,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,80,32,108,173,33,0,16,0,105,110,115,101,99,116,111,114,32,120,32,40,106,112,110,44,32,107,111,114,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,52,196,37,150,33,0,16,0,109,112,114,45,49,53,50,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,116,67,143,235,33,0,16,0,116,104,101,32,105,110,99,114,101,100,105,98,108,101,115,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,124,175,247,49,33,0,16,0,105,109,109,111,114,116,97,108,44,32,116,104,101,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,8,197,83,246,33,0,16,0,104,121,112,101,114,32,100,117,110,107,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,106,87,124,242,33,0,16,0,104,121,111,107,107,111,114,105,32,104,121,111,117,116,97,110,106,105,109,97,32,45,32,100,97,105,116,111,117,114,121,111,117,32,111,32,109,101,122,97,115,101,33,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,219,59,37,114,33,0,16,0,104,121,98,114,105,100,32,102,114,111,110,116,44,32,116,104,101,32,40,106,112,110,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,135,38,240,4,33,0,16,0,104,117,114,114,105,99,97,110,101,115,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,116,200,204,222,33,0,16,0,104,97,114,114,121,32,112,111,116,116,101,114,32,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,159,71,132,22,33,0,16,0,104,101,114,99,117,108,101,115,32,50,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,219,35,38,41,33,0,16,0,104,101,114,99,117,108,101,115,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,208,217,117,255,33,0,16,0,109,112,114,45,49,52,52,51,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,172,48,207,33,0,16,0,104,101,97,118,121,32,110,111,118,97,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,216,169,182,246,33,0,16,0,104,97,117,110,116,105,110,103,32,115,116,97,114,114,105,110,103,32,112,111,108,116,101,114,103,117,121,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,109,135,252,201,33,0,16,0,109,112,114,45,49,51,52,56,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,175,186,37,50,33,0,16,0,104,97,114,100,98,97,108,108,32,39,57,53,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,158,188,16,237,33,0,16,0,104,97,114,100,98,97,108,108,32,39,57,52,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,120,72,156,234,33,0,16,0,104,97,114,100,98,97,108,108,33,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,4,154,27,189,33,0,16,0,104,97,114,100,98,97,108,108,32,105,105,105,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,17,240,242,164,33,0,16,0,103,117,110,115,116,97,114,32,104,101,114,111,101,115,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,13,207,19,184,33,0,16,0,103,117,110,115,116,97,114,32,104,101,114,111,101,115,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,131,3,253,28,33,0,16,0,109,112,114,45,49,52,57,57,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,3,10,130,196,33,0,16,0,103,114,97,110,100,115,108,97,109,32,45,32,116,104,101,32,116,101,110,110,105,115,32,116,111,117,114,110,97,109,101,110,116,32,39,57,50,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,208,55,207,48,33,0,16,0,103,114,97,110,97,100,97,32,40,117,115,97,44,32,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,155,113,69,127,33,0,16,0,103,111,117,107,101,116,115,117,106,105,32,105,99,104,105,122,111,107,117,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,21,196,233,171,33,0,16,0,103,111,108,100,101,110,32,97,120,101,32,40,119,111,114,108,100,41,32,40,118,49,46,49,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,249,125,93,102,33,0,16,0,103,111,108,100,101,110,32,97,120,101,32,105,105,105,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,163,46,134,199,33,0,16,0,109,112,114,45,49,52,50,55,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,10,94,114,33,0,16,0,103,111,108,100,101,110,32,49,48,45,105,110,45,49,32,40,98,97,100,32,100,117,109,112,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,43,248,163,79,33,0,16,0,97,100,118,97,110,99,101,100,32,98,117,115,116,101,114,104,97,119,107,32,103,108,101,121,108,97,110,99,101,114,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,91,155,207,66,33,0,16,0,103,104,111,115,116,98,117,115,116,101,114,115,32,40,119,111,114,108,100,41,32,40,118,49,46,49,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,59,249,45,121,33,0,16,0,103,97,105,110,32,103,114,111,117,110,100,32,40,119,111,114,108,100,41,32,40,97,108,116,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,174,184,231,131,33,0,16,0,103,97,108,97,120,121,32,102,111,114,99,101,32,105,105,32,40,119,111,114,108,100,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,197,131,232,202,33,0,16,0,103,101,111,114,103,101,32,102,111,114,101,109,97,110,39,115,32,107,111,32,98,111,120,105,110,103,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,129,99,85,189,33,0,16,0,103,101,110,103,104,105,115,32,107,104,97,110,32,105,105,32,45,32,99,108,97,110,32,111,102,32,116,104,101,32,103,114,97,121,32,119,111,108,102,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,174,129,162,135,33,0,16,0,103,101,110,101,114,97,116,105,111,110,115,32,108,111,115,116,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,166,54,31,19,33,0,16,0,97,111,107,105,32,111,111,107,97,109,105,32,116,111,32,115,104,105,114,111,107,105,32,109,101,115,104,105,107,97,32,45,32,103,101,110,99,104,111,117,32,104,105,115,104,105,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,0,147,29,190,16,33,0,16,0,103,101,110,101,114,97,108,32,99,104,97,111,115,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,223,196,236,241,33,0,16,0,103,97,117,110,116,108,101,116,32,105,118,32,40,101,117,114,111,44,32,117,115,97,41,32,40,115,101,112,116,101,109,98,101,114,32,49,57,57,51,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,16,5,214,249,33,0,16,0,103,97,114,103,111,121,108,101,115,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,100,83,150,45,33,0,16,0,103,97,114,102,105,101,108,100,32,45,32,99,97,117,103,104,116,32,105,110,32,116,104,101,32,97,99,116,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,142,7,255,240,33,0,16,0,102,117,110,110,121,32,119,111,114,108,100,32,38,32,98,97,108,108,111,111,110,32,98,111,121,32,40,117,115,97,41,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,240,5,47,168,33,0,16,0,102,117,110,32,39,110,39,32,103,97,109,101,115,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,205,179,74,218,33,0,16,0,102,111,114,109,117,108,97,32,111,110,101,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,56,55,215,204,33,0,16,0,102,111,114,103,111,116,116,101,110,32,119,111,114,108,100,115,32,40,119,111,114,108,100,41,32,40,118,49,46,49,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,133,57,81,149,33,0,16,0,102,108,97,115,104,98,97,99,107,32,45,32,116,104,101,32,113,117,101,115,116,32,102,111,114,32,105,100,101,110,116,105,116,121,32,40,117,115,97,41,32,40,97,108,116,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,101,43,205,51,33,0,16,0,109,112,114,45,49,52,51,52,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,206,81,35,33,0,16,0,102,105,114,101,32,109,117,115,116,97,110,103,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,195,54,126,235,33,0,16,0,102,105,103,104,116,105,110,103,32,109,97,115,116,101,114,115,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,59,152,81,95,33,0,16,0,102,105,102,97,32,50,48,49,48,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,17,132,30,133,33,0,16,0,102,105,100,111,32,100,105,100,111,32,40,117,115,97,41,32,40,112,114,111,116,111,116,121,112,101,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,64,162,212,198,33,0,16,0,102,101,118,101,114,32,112,105,116,99,104,32,115,111,99,99,101,114,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,119,150,194,250,33,0,16,0,102,101,114,114,97,114,105,32,103,114,97,110,100,32,112,114,105,120,32,99,104,97,108,108,101,110,103,101,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,236,107,63,247,33,0,16,0,102,101,114,114,97,114,105,32,103,114,97,110,100,32,112,114,105,120,32,99,104,97,108,108,101,110,103,101,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,212,2,141,212,33,0,16,0,102,101,110,103,32,115,104,101,110,32,121,105,110,103,32,106,105,101,32,99,104,117,97,110,32,40,99,104,105,41,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,96,43,56,106,33,0,16,0,102,101,110,103,32,107,117,97,110,103,32,116,97,111,32,104,117,97,32,121,117,97,110,32,40,99,104,105,41,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,79,214,64,141,33,0,16,0,102,97,116,97,108,32,102,117,114,121,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,112,145,212,152,33,0,16,0,102,97,116,97,108,32,102,117,114,121,32,50,32,40,117,115,97,44,32,107,111,114,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,203,84,23,27,33,0,16,0,102,97,116,97,108,32,114,101,119,105,110,100,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,5,237,26,233,33,0,16,0,102,97,116,97,108,32,108,97,98,121,114,105,110,116,104,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,132,217,11,95,33,0,16,0,102,97,115,116,32,97,110,100,32,116,104,101,32,102,117,114,105,111,117,115,32,53,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,16,0,122,216,244,41,33,0,16,0,102,97,115,116,101,115,116,32,49,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,222,240,67,187,33,0,16,0,102,97,110,116,97,115,116,105,99,32,100,105,122,122,121,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,122,126,68,70,33,0,16,0,109,112,114,45,49,52,48,50,56,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,45,223,67,252,33,0,16,0,102,97,101,114,121,32,116,97,108,101,32,97,100,118,101,110,116,117,114,101,44,32,116,104,101,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,105,73,63,150,33,0,16,0,110,97,107,97,106,105,109,97,32,115,97,116,111,114,117,32,107,97,110,115,104,117,117,32,102,49,32,104,101,114,111,32,109,100,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,135,121,248,36,33,0,16,0,102,49,32,99,105,114,99,117,115,32,109,100,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,251,190,48,93,33,0,16,0,102,45,49,53,32,115,116,114,105,107,101,32,101,97,103,108,101,32,105,105,32,40,117,115,97,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,90,79,253,33,0,16,0,101,120,45,114,97,110,122,97,32,40,106,112,110,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,244,253,66,198,33,0,16,0,101,120,111,32,115,113,117,97,100,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,249,185,153,181,33,0,16,0,109,112,114,45,49,53,50,50,53,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,159,151,177,51,33,0,16,0,99,104,117,99,107,39,115,32,101,120,99,101,108,108,101,110,116,32,97,114,116,32,116,111,111,108,32,97,110,105,109,97,116,111,114,32,40,117,115,97,41,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,88,238,96,99,33,0,16,0,101,117,114,111,112,97,32,115,101,110,115,101,110,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,96,108,65,176,33,0,16,0,109,112,114,45,49,52,55,55,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,4,241,92,106,33,0,16,0,109,112,114,45,49,54,50,49,50,43,109,112,114,45,49,54,50,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,94,47,81,185,33,0,16,0,101,115,112,110,32,115,112,101,101,100,32,119,111,114,108,100,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,120,228,11,245,33,0,16,0,117,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,33,114,66,159,49,0,16,0,117,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,232,240,69,52,50,0,16,0,117,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,197,239,5,93,53,0,16,0,117,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,75,253,230,122,54,0,16,0,101,109,112,105,114,101,32,111,102,32,115,116,101,101,108,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,119,123,81,229,33,0,16,0,109,112,114,45,49,52,51,51,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,235,28,10,7,33,0,16,0,101,108,105,109,105,110,97,116,101,32,100,111,119,110,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,66,117,70,72,33,0,16,0,101,108,101,109,101,110,116,97,108,32,109,97,115,116,101,114,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,41,62,85,95,33,0,16,0,101,97,51,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,188,76,181,160,33,0,16,0,101,97,114,116,104,32,100,101,102,101,110,115,101,32,40,117,115,97,41,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,34,196,25,53,33,0,16,0,101,97,32,104,111,99,107,101,121,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,156,39,252,155,33,0,16,0,100,121,110,111,32,98,108,97,122,101,32,40,112,114,111,116,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,198,17,23,0,132,229,37,214,33,0,16,0,109,112,114,45,49,51,52,51,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,140,28,208,57,33,0,16,0,100,117,107,101,32,110,117,107,101,109,32,51,100,32,40,98,114,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,203,172,210,107,33,0,16,0,100,101,115,101,114,116,32,115,116,114,105,107,101,32,40,106,112,110,44,32,107,111,114,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,69,1,116,30,33,0,16,0,100,114,97,103,111,110,32,115,108,97,121,101,114,32,45,32,101,105,121,117,117,32,100,101,110,115,101,116,115,117,32,105,105,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,195,77,146,70,33,0,16,0,100,114,46,32,114,111,98,111,116,110,105,107,39,115,32,109,101,97,110,32,98,101,97,110,32,109,97,99,104,105,110,101,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,6,7,104,112,33,0,16,0,100,114,97,103,111,110,39,115,32,114,101,118,101,110,103,101,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,192,219,30,132,33,0,16,0,98,114,97,109,32,115,116,111,107,101,114,39,115,32,100,114,97,99,117,108,97,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,166,132,112,7,33,0,16,0,100,111,117,98,108,101,32,99,108,117,116,99,104,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,60,98,140,217,33,0,16,0,100,111,114,97,101,109,111,110,32,45,32,121,117,109,101,32,100,111,114,111,98,111,117,32,116,111,32,55,45,110,105,110,32,110,111,32,103,111,122,97,110,115,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,48,17,237,238,33,0,16,0,100,111,111,109,32,116,114,111,111,112,101,114,115,32,45,32,116,104,101,32,109,117,116,97,110,116,32,99,104,114,111,110,105,99,108,101,115,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,20,68,25,17,33,0,16,0,100,111,110,103,32,103,117,32,114,105,32,116,101,32,99,104,105,32,106,97,107,32,106,101,111,110,32,40,107,111,114,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,28,11,47,227,33,0,16,0,105,107,97,122,117,115,101,33,32,107,111,105,32,110,111,32,100,111,107,105,32,100,111,107,105,32,112,101,110,103,117,105,110,32,108,97,110,100,32,109,100,32,40,106,112,110,41,32,40,115,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,214,191,83,0,33,0,16,0,109,105,107,101,32,100,105,116,107,97,32,112,111,119,101,114,32,102,111,111,116,98,97,108,108,32,40,101,117,114,111,44,32,117,115,97,41,32,40,97,108,116,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,142,202,80,222,33,0,16,0,100,105,115,110,101,121,32,99,111,108,108,101,99,116,105,111,110,44,32,116,104,101,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,131,232,253,173,33,0,16,0,100,105,110,111,115,97,117,114,39,115,32,116,97,108,101,44,32,97,32,40,117,115,97,41])
.concat([46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,91,91,21,112,33,0,16,0,100,105,110,111,32,108,97,110,100,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,184,81,227,95,33,0,16,0,100,105,110,111,115,97,117,114,115,32,102,111,114,32,104,105,114,101,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,70,17,53,57,33,0,16,0,100,105,110,111,32,100,105,110,105,39,115,32,115,111,99,99,101,114,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,58,245,8,70,33,0,16,0,100,105,99,107,32,118,105,116,97,108,101,39,115,32,39,97,119,101,115,111,109,101,44,32,98,97,98,121,33,39,32,99,111,108,108,101,103,101,32,104,111,111,112,115,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,34,207,18,19,33,0,16,0,100,101,118,105,108,32,99,114,97,115,104,32,109,100,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,216,170,76,76,33,0,16,0,100,101,118,105,108,105,115,104,32,45,32,116,104,101,32,110,101,120,116,32,112,111,115,115,101,115,115,105,111,110,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,172,0,243,211,33,0,16,0,100,101,115,101,114,116,32,100,101,109,111,108,105,116,105,111,110,32,115,116,97,114,114,105,110,103,32,114,111,97,100,32,114,117,110,110,101,114,32,97,110,100,32,119,105,108,101,32,101,46,32,99,111,121,111,116,101,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,61,52,135,194,33,0,16,0,100,101,109,111,108,105,116,105,111,110,32,109,97,110,32,40,117,115,97,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,122,173,255,87,33,0,16,0,100,101,101,114,32,104,117,110,116,101,114,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,139,151,17,218,33,0,16,0,109,112,114,45,49,52,50,52,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,216,13,220,115,33,0,16,0,100,101,97,116,104,32,97,110,100,32,114,101,116,117,114,110,32,111,102,32,115,117,112,101,114,109,97,110,44,32,116,104,101,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,211,66,34,152,33,0,16,0,100,101,97,116,104,32,99,97,108,105,98,101,114,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,151,199,210,60,33,0,16,0,100,101,97,100,108,121,32,109,111,118,101,115,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,55,210,203,53,33,0,16,0,100,111,117,98,108,101,32,100,114,105,98,98,108,101,32,45,32,116,104,101,32,112,108,97,121,111,102,102,32,101,100,105,116,105,111,110,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,208,177,82,131,33,0,16,0,100,111,117,98,108,101,32,100,114,97,103,111,110,32,118,32,45,32,116,104,101,32,115,104,97,100,111,119,32,102,97,108,108,115,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,53,158,229,39,33,0,16,0,100,111,117,98,108,101,32,100,114,97,103,111,110,32,51,32,45,32,116,104,101,32,97,114,99,97,100,101,32,103,97,109,101,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,92,183,106,179,33,0,16,0,100,111,117,98,108,101,32,100,114,97,103,111,110,32,105,105,32,45,32,116,104,101,32,114,101,118,101,110,103,101,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,214,219,191,168,33,0,16,0,100,97,122,101,32,98,101,102,111,114,101,32,99,104,114,105,115,116,109,97,115,32,40,97,117,115,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,201,37,94,185,33,0,16,0,100,97,118,105,115,32,99,117,112,32,119,111,114,108,100,32,116,111,117,114,32,40,101,117,114,111,44,32,117,115,97,41,32,40,106,117,108,121,32,49,57,57,51,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,240,134,70,137,33,0,16,0,100,97,118,105,115,32,99,117,112,32,119,111,114,108,100,32,116,111,117,114,32,116,101,110,110,105,115,32,50,32,40,98,101,116,97,32,49,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,192,131,65,111,33,0,16,0,100,97,114,107,32,99,97,115,116,108,101,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,164,172,100,4,33,0,16,0,100,97,110,103,101,114,111,117,115,32,115,101,101,100,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,49,0,153,162,33,0,16,0,100,97,105,32,109,97,107,97,105,109,117,114,97,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,121,243,89,86,33,0,16,0,100,97,105,107,111,117,107,97,105,32,106,105,100,97,105,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,88,36,101,90,33,0,16,0,99,121,98,111,114,103,32,106,117,115,116,105,99,101,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,30,241,218,145,33,0,16,0,99,121,98,101,114,45,99,111,112,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,200,25,231,1,33,0,16,0,109,112,114,45,49,51,50,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,150,14,18,118,33,0,16,0,99,117,116,105,101,32,115,117,122,117,107,105,32,110,111,32,114,105,110,103,115,105,100,101,32,97,110,103,101,108,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,202,93,121,19,33,0,16,0,99,114,121,115,116,97,108,39,115,32,112,111,110,121,32,116,97,108,101,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,223,164,247,108,33,0,16,0,99,114,117,115,97,100,101,114,32,111,102,32,99,101,110,116,121,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,111,143,133,65,33,0,16,0,99,114,117,101,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,192,95,25,75,33,0,16,0,99,114,97,99,107,32,100,111,119,110,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,81,144,206,185,33,0,16,0,99,114,97,99,107,32,100,111,119,110,32,40,101,117,114,111,44,32,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,93,170,138,83,33,0,16,0,109,112,114,45,49,54,50,53,57,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,74,87,110,31,33,0,16,0,109,112,114,45,49,53,48,54,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,170,24,13,168,33,0,16,0,109,112,114,45,49,53,52,55,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,65,250,9,95,33,0,16,0,99,111,109,109,97,110,100,32,38,32,99,111,110,113,117,101,114,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,134,98,24,0,98,204,127,116,33,0,16,0,99,111,109,109,97,110,100,111,115,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,111,141,168,40,33,0,16,0,99,111,109,98,97,116,32,99,97,114,115,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,177,57,228,33,0,16,0,99,111,108,117,109,110,115,32,105,105,105,32,45,32,114,101,118,101,110,103,101,32,111,102,32,99,111,108,117,109,110,115,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,109,143,103,220,33,0,16,0,109,112,114,45,49,51,49,57,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,122,61,22,3,33,0,16,0,99,111,108,108,101,103,101,32,115,108,97,109,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,49,36,164,150,33,0,16,0,99,111,108,108,101,103,101,32,102,111,111,116,98,97,108,108,32,117,115,97,32,57,55,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,163,144,187,46,33,0,16,0,99,111,108,108,101,103,101,32,102,111,111,116,98,97,108,108,32,117,115,97,32,57,54,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,133,83,7,185,33,0,16,0,109,112,114,45,49,55,53,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,7,119,175,26,33,0,16,0,99,108,97,115,115,105,99,32,99,111,108,108,101,99,116,105,111,110,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,177,72,249,115,33,0,16,0,99,104,97,111,32,106,105,32,100,97,32,102,117,32,119,101,110,103,32,40,99,104,105,41,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,135,166,46,46,33,0,16,0,99,104,117,99,107,32,114,111,99,107,32,105,105,32,45,32,115,111,110,32,111,102,32,99,104,117,99,107,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,136,148,222,26,33,0,16,0,99,104,117,99,107,32,114,111,99,107,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,234,11,212,124,33,0,16,0,99,104,105,110,101,115,101,32,99,104,101,115,115,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,160,21,82,71,33,0,16,0,99,104,101,115,116,101,114,32,99,104,101,101,116,97,104,32,45,32,119,105,108,100,32,119,105,108,100,32,113,117,101,115,116,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,93,115,123,185,33,0,16,0,99,104,97,115,101,32,104,46,113,46,32,105,105,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,242,75,158,243,33,0,16,0,99,104,97,111,115,32,101,110,103,105,110,101,44,32,116,104,101,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,244,236,158,189,33,0,16,0,99,104,97,111,115,32,101,110,103,105,110,101,32,50,44,32,116,104,101,32,40,101,117,114,111,41,32,40,112,114,111,116,111,116,121,112,101,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,194,69,176,63,33,0,16,0,115,51,53,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,219,51,62,136,33,0,16,0,99,104,97,109,112,105,111,110,115,104,105,112,32,112,111,111,108,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,207,18,53,37,33,0,16,0,99,104,97,109,112,105,111,110,115,104,105,112,32,98,111,119,108,105,110,103,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,32,37,249,27,33,0,16,0,99,97,115,116,108,101,32,111,102,32,105,108,108,117,115,105,111,110,32,115,116,97,114,114,105,110,103,32,109,105,99,107,101,121,32,109,111,117,115,101,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,208,159,78,186,33,0,16,0,119,104,101,114,101,32,105,110,32,116,104,101,32,119,111,114,108,100,32,105,115,32,99,97,114,109,101,110,32,115,97,110,100,105,101,103,111,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,232,114,243,238,33,0,16,0,119,104,101,114,101,32,105,110,32,116,105,109,101,32,105,115,32,99,97,114,109,101,110,32,115,97,110,100,105,101,103,111,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,164,212,25,234,33,0,16,0,99,97,112,116,97,105,110,32,112,108,97,110,101,116,32,97,110,100,32,116,104,101,32,112,108,97,110,101,116,101,101,114,115,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,165,239,114,118,33,0,16,0,99,97,112,116,97,105,110,32,108,97,110,103,32,40,106,97,112,97,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,153,129,186,97,33,0,16,0,109,112,114,45,49,53,52,57,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,18,86,34,67,33,0,16,0,99,97,108,32,114,105,112,107,101,110,32,106,114,46,32,98,97,115,101,98,97,108,108,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,192,150,28,155,33,0,16,0,109,112,114,45,49,52,51,55,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,114,182,177,67,33,0,16,0,98,117,114,110,105,110,103,32,102,111,114,99,101,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,255,246,111,119,33,0,16,0,98,117,108,108,115,32,118,115,32,108,97,107,101,114,115,32,97,110,100,32,116,104,101,32,110,98,97,32,112,108,97,121,111,102,102,115,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,160,35,96,229,33,0,16,0,98,117,108,108,115,32,118,101,114,115,117,115,32,98,108,97,122,101,114,115,32,97,110,100,32,116,104,101,32,110,98,97,32,112,108,97,121,111,102,102,115,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,232,180,228,212,33,0,16,0,98,117,103,39,115,32,108,105,102,101,44,32,97,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,9,142,69,16,33,0,16,0,98,117,103,115,32,98,117,110,110,121,32,105,110,32,100,111,117,98,108,101,32,116,114,111,117,98,108,101,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,162,5,83,54,33,0,16,0,98,117,100,111,107,97,110,32,45,32,116,104,101,32,109,97,114,116,105,97,108,32,115,112,105,114,105,116,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,252,245,217,172,33,0,16,0,98,117,98,98,108,101,32,97,110,100,32,115,113,117,101,97,107,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,241,27,21,134,33,0,16,0,98,97,116,116,108,101,116,111,97,100,115,32,38,32,100,111,117,98,108,101,32,100,114,97,103,111,110,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,23,221,57,130,33,0,16,0,98,97,116,116,108,101,32,109,97,110,105,97,32,100,97,105,103,105,110,106,111,117,32,40,106,112,110,44,32,107,111,114,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,242,160,47,49,33,0,16,0,98,97,116,116,108,101,32,109,97,110,105,97,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,41,74,108,167,33,0,16,0,98,114,105,97,110,32,108,97,114,97,32,99,114,105,99,107,101,116,32,40,101,117,114,111,41,32,40,106,117,110,101,32,49,57,57,53,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,195,245,140,64,33,0,16,0,98,114,105,97,110,32,108,97,114,97,32,99,114,105,99,107,101,116,32,57,54,32,40,101,117,114,111,41,32,40,97,112,114,105,108,32,49,57,57,54,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,225,247,82,254,33,0,16,0,98,111,120,105,110,103,32,108,101,103,101,110,100,115,32,111,102,32,116,104,101,32,114,105,110,103,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,172,37,242,0,33,0,16,0,98,111,100,121,32,99,111,117,110,116,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,97,110,32,50,55,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,113,78,202,102,33,0,16,0,98,111,100,121,32,99,111,117,110,116,32,40,112,114,111,116,111,116,121,112,101,32,45,32,102,101,98,32,48,56,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,249,15,0,151,216,254,197,33,0,16,0,98,111,100,121,32,99,111,117,110,116,32,40,112,114,111,116,111,116,121,112,101,32,45,32,109,97,114,32,48,51,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,119,110,188,106,33,0,16,0,98,111,100,121,32,99,111,117,110,116,32,40,112,114,111,116,111,116,121,112,101,32,45,32,109,97,114,32,48,56,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,63,33,101,137,33,0,16,0,109,112,114,45,49,51,57,48,53,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,137,197,170,198,33,0,16,0,98,108,97,115,116,101,114,32,109,97,115,116,101,114,32,50,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,161,75,30,193,33,0,16,0,98,108,117,101,32,97,108,109,97,110,97,99,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,179,235,34,114,33,0,16,0,101,115,50,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,235,188,242,249,33,0,16,0,98,108,111,99,45,117,49,95,98,108,111,48,51,43,98,108,111,99,45,117,50,95,98,108,111,48,51,46,98,105,110,44,109,112,114,45,49,52,50,52,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,241,102,41,94,33,0,16,0,98,108,97,100,101,115,32,111,102,32,118,101,110,103,101,97,110,99,101,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,73,90,198,116,33,0,16,0,109,112,114,45,49,53,50,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,43,234,176,149,33,0,16,0,98,119,99,102,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,98,51,216,62,33,0,16,0,98,105,108,108,32,119,97,108,115,104,32,99,111,108,108,101,103,101,32,102,111,111,116,98,97,108,108,32,57,53,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,90,244,130,165,33,0,16,0,98,105,98,108,101,32,97,100,118,101,110,116,117,114,101,115,32,40,117,115,97,41,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,119,107,68,100,33,0,16,0,98,101,121,111,110,100,32,122,101,114,111,32,116,111,108,101,114,97,110,99,101,32,40,117,115,97,41,32,40,112,114,111,116,111,116,121,112,101,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,237,210,30,198,33,0,16,0,98,101,121,111,110,100,32,111,97,115,105,115,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,37,130,114,196,33,0,16,0,98,101,97,118,105,115,32,97,110,100,32,98,117,116,116,45,104,101,97,100,32,40,117,115,97,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,53,83,237,129,33,0,16,0,98,101,97,117,116,121,32,97,110,100,32,116,104,101,32,98,101,97,115,116,32,45,32,114,111,97,114,32,111,102,32,116,104,101,32,98,101,97,115,116,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,25,181,231,19,33,0,16,0,98,101,97,115,116,32,98,97,108,108,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,184,15,0,118,101,23,106,33,0,16,0,98,97,116,116,108,101,32,103,111,108,102,101,114,32,121,117,105,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,78,62,160,74,33,0,16,0,98,97,116,116,108,101,32,115,113,117,97,100,114,111,110,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,191,168,234,15,33,0,16,0,98,97,116,116,108,101,109,97,115,116,101,114,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,227,53,43,253,33,0,16,0,109,112,114,45,49,52,57,57,56,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,192,37,50,74,33,0,16,0,98,97,116,109,97,110,32,45,32,114,101,118,101,110,103,101,32,111,102,32,116,104,101,32,106,111,107,101,114,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,161,68,160,202,33,0,16,0,98,97,115,115,32,109,97,115,116,101,114,115,32,99,108,97,115,115,105,99,32,45,32,112,114,111,32,101,100,105,116,105,111,110,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,61,235,221,158,33,0,16,0,109,112,114,45,49,52,55,53,57,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,202,232,112,219,33,0,16,0,115,105,109,112,115,111,110,115,44,32,116,104,101,32,45,32,98,97,114,116,39,115,32,110,105,103,104,116,109,97,114,101,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,124,80,215,36,33,0,16,0,98,97,114,107,108,101,121,32,115,104,117,116,32,117,112,32,97,110,100,32,106,97,109,33,32,50,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,189,182,27,50,33,0,16,0,98,97,114,98,105,101,32,115,117,112,101,114,32,109,111,100,101,108,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,43,102,201,129,33,0,16,0,98,97,108,108,32,106,97,99,107,115,32,40,101,117,114,111,44,32,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,79,197,195,245,33,0,16,0,109,112,114,45,49,51,54,55,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,218,104,226,177,33,0,16,0,109,112,114,45,49,52,51,50,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,46,249,55,39,33,0,16,0,98,97,98,121,32,98,111,111,109,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,117,103,32,49,49,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,84,112,105,189,33,0,16,0,97,119,101,115,111,109,101,32,112,111,115,115,117,109,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,127,87,7,31,33,0,16,0,97,117,115,116,114,97,108,105,97,110,32,114,117,103,98,121,32,108,101,97,103,117,101,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,106,194,91,172,33,0,16,0,97,116,112,32,116,111,117,114,32,99,104,97,109,112,105,111,110,115,104,105,112,32,116,101,110,110,105,115,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,132,40,130,140,33,0,16,0,97,116,111,109,105,99,32,114,117,110,110,101,114,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,16,194,119,6,33,0,16,0,97,116,111,109,105,99,32,114,111,98,111,45,107,105,100,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,158,22,216,124,33,0,16,0,97,115,116,101,114,105,120,32,97,110,100,32,116,104,101,32,112,111,119,101,114,32,111,102,32,116,104,101,32,103,111,100,115,32,40,101,117,114,111,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,183,181,200,69,33,0,16,0,109,112,114,45,49,53,57,54,49,43,109,112,114,45,49,53,57,54,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,230,254,53,71,33,0,16,0,97,115,115,97,115,115,105,110,115,32,99,114,101,101,100,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,204,108,45,63,33,0,16,0,109,112,114,45,49,52,51,56,52,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,221,44,183,241,33,0,16,0,97,32,114,101,115,115,104,97,32,100,101,32,105,107,111,117,32,109,100,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,79,222,69,61,33,0,16,0,109,112,114,45,49,52,55,54,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,231,215,137,227,33,0,16,0,109,105,100,119,97,121,32,112,114,101,115,101,110,116,115,32,97,114,99,97,100,101,39,115,32,103,114,101,97,116,101,115,116,32,104,105,116,115,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,229,224,220,192,33,0,16,0,109,112,114,45,49,56,56,49,53,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,144,32,237,138,33,0,16,0,97,113,117,97,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,167,75,15,64,33,0,16,0,109,112,114,45,49,53,52,57,56,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,65,32,116,233,33,0,16,0,102,120,48,49,52,97,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,85,242,182,146,33,0,16,0,109,97,114,105,111,32,97,110,100,114,101,116,116,105,32,114,97,99,105,110,103,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,170,192,29,127,33,0,16,0,97,109,101,114,105,99,97,110,32,103,108,97,100,105,97,116,111,114,115,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,133,250,82,153,33,0,16,0,100,97,118,105,100,32,99,114,97,110,101,39,115,32,97,109,97,122,105,110,103,32,116,101,110,110,105,115,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,140,8,119,145,33,0,16,0,109,112,114,45,49,50,53,51,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,187,89,77,21,33,0,16,0,97,108,105,115,105,97,32,100,114,97,103,111,111,110,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,64,92,141,210,33,0,16,0,97,108,105,115,105,97,32,100,114,97,103,111,111,110,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,34,103,71,77,33,0,16,0,97,108,105,101,110,32,115,111,108,100,105,101,114,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,108,224,150,4,33,0,16,0,109,112,114,45,49,50,54,48,56,97,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,15,138,119,33,0,16,0,97,108,97,100,100,105,110,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,169,126,66,237,33,0,16,0,97,108,97,100,100,105,110,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,240,172,90,251,33,0,16,0,97,108,97,100,100,105,110,32,105,105,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,151,147,95,190,33,0,16,0,97,105,114,32,109,97,110,97,103,101,109,101,110,116,32,105,105,32,45,32,107,111,117,107,117,117,111,117,32,111,32,109,101,122,97,115,101,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,123,129,130,69,33,0,16,0,97,105,114,32,109,97,110,97,103,101,109,101,110,116,32,45,32,111,111,122,111,114,97,32,110,105,32,107,97,107,101,114,117,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,113,12,219,179,33,0,16,0,97,105,114,32,100,105,118,101,114,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,94,136,65,32,33,0,16,0,97,105,114,32,98,117,115,116,101,114,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,170,91,214,243,33,0,16,0,97,110,100,114,101,32,97,103,97,115,115,105,32,116,101,110,110,105,115,32,40,117,115,97,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,13,112,191,59,33,0,16,0,97,101,114,111,32,98,108,97,115,116,101,114,115,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,135,169,13,160,33,0,16,0,97,101,114,111,98,105,122,32,115,117,112,101,114,115,111,110,105,99,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,181,241,119,147,33,0,16,0,109,112,114,45,49,51,56,52,50,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,138,225,213,224,33,0,16,0,97,100,118,101,110,116,117,114,101,115,32,111,102,32,98,97,116,109,97,110,32,38,32,114,111,98,105,110,44,32,116,104,101,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,172,164,170,12,33,0,16,0,97,100,100,97,109,115,32,102,97,109,105,108,121,44,32,116,104,101,32,40,117,115,97,41,32,40,98,101,116,97,41,32,40,97,108,116,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,31,62,23,58,33,0,16,0,97,100,100,97,109,115,32,102,97,109,105,108,121,44,32,116,104,101,32,40,117,115,97,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,202,165,3,40,33,0,16,0,97,99,116,105,111,110,32,53,50,32,40,117,115,97,41,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,174,88,255,41,33,0,16,0,109,112,114,45,49,51,50,54,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,14,224,175,204,33,0,16,0,97,97,32,104,97,114,105,109,97,110,97,100,97,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,33,96,95,6,33,0,16,0,97,97,97,104,104,33,33,33,32,114,101,97,108,32,109,111,110,115,116,101,114,115,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,252,11,200,253,33,0,16,0,109,112,114,45,49,51,57,53,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,247,139,197,242,33,0,16,0,109,100,112,112,102,56,50,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,81,131,221,50,33,0,16,0,109,100,109,109,95,97,99,100,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,11,26,8,80,39,0,16,0,49,54,32,116,111,110,32,40,106,112,110,41,32,40,103,110,107,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,175,158,20,152,33,0,16,0,49,51,32,109,97,104,106,111,110,103,32,57,56,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,246,114,179,104,33,0,16,0,15,0,0,0,0,0,0,0,255,255,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,0,0,0,0,255,127,0,0,0,0,0,0,5,0,0,0,0,128,0,0,255,159,0,0,1,0,0,0,2,0,0,0,0,160,0,0,255,191,0,0,1,0,0,0,8,0,0,0,0,192,0,0,255,255,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,255,31,0,0,0,0,0,0,8,0,0,0,0,32,0,0,255,63,0,0,0,0,0,0,2,0,0,0,0,64,0,0,255,71,0,0,0,0,0,0,4,0,0,0,0,72,0,0,255,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,255,79,0,0,0,0,0,0,8,0,0,0,0,80,0,0,255,111,0,0,0,0,0,0,2,0,0,0,0,112,0,0,255,127,0,0,0,0,0,0,4,0,0,0,0,0,0,0,255,63,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,0,0,0,0,0,0,255,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,0,0,0,0,0,0,255,63,0,0,0,0,0,0,15,0,0,0,0,64,0,0,255,127,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,255,63,0,0,0,0,0,0,1,0,0,0,0,64,0,0,255,95,0,0,1,0,0,0,2,0,0,0,0,96,0,0,255,127,0,0,1,0,0,0,8,0,0,0,0,0,0,0,255,63,0,0,2,0,0,0,4,0,0,0,0,64,0,0,255,127,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,255,127,0,0,0,0,0,0,1,0,0,0,0,128,0,0,255,255,0,0,1,0,0,0,1,0,0,0,0,0,1,0,255,31,1,0,2,0,0,0,8,0,0,0,0,32,0,0,255,63,0,0,2,0,0,0,2,0,0,0,0,64,0,0,255,79,0,0,2,0,0,0,4,0,0,0,0,80,0,0,255,127,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,255,255,1,0,0,0,0,0,1,0,0,0,0,0,0,0,255,63,0,0,0,0,0,0,1,0,0,0,0,64,0,0,255,79,0,0,1,0,0,0,4,0,0,0,0,64,0,0,255,127,0,0,1,0,0,0,8,0,0,0,0,0,0,0,255,63,0,0,2,0,0,0,8,0,0,0,0,64,0,0,255,127,0,0,3,0,0,0,2,0,0,0,0,112,0,0,255,127,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,255,67,0,0,0,0,0,0,2,0,0,0,0,68,0,0,255,75,0,0,0,0,0,0,8,0,0,0,0,76,0,0,255,95,0,0,0,0,0,0,4,0,0,0,0,96,0,0,255,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,255,83,0,0,0,0,0,0,2,0,0,0,0,84,0,0,255,111,0,0,0,0,0,0,8,0,0,0,0,112,0,0,255,127,0,0,0,0,0,0,8,0,0,0,0,0,0,0,255,63,0,0,1,0,0,0,4,0,0,0,0,40,0,0,255,127,0,0,1,0,0,0,1,0,0,0,0,84,0,0,255,127,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,255,63,0,0,0,0,0,0,1,0,0,0,0,64,0,0,255,83,0,0,1,0,0,0,2,0,0,0,0,84,0,0,255,111,0,0,1,0,0,0,8,0,0,0,0,112,0,0,255,127,0,0,1,0,0,0,8,0,0,0,0,0,0,0,255,63,0,0,2,0,0,0,4,0,0,0,0,40,0,0,255,63,0,0,2,0,0,0,4,0,0,0,0,64,0,0,255,127,0,0,3,0,0,0,1,0,0,0,0,84,0,0,255,127,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,255,7,0,0,0,0,0,0,8,0,0,0,0,8,0,0,255,31,0,0,0,0,0,0,5,0,0,0,0,32,0,0,255,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,255,63,0,0,0,0,0,0,2,0,0,0,0,0,0,0,255,63,0,0,0,0,0,0,4,0,0,0,0,0,0,0,255,63,0,0,0,0,0,0,8,0,0,0,0,0,0,0,255,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,0,0,0,0,255,111,0,0,0,0,0,0,8,0,0,0,0,112,0,0,255,119,0,0,0,0,0,0,2,0,0,0,0,120,0,0,255,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,255,15,0,0,0,0,0,0,1,0,0,0,0,16,0,0,255,127,0,0,0,0,0,0,5,0,0,0,0,128,0,0,255,219,0,0,1,0,0,0,8,0,0,0,0,220,0,0,255,255,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,255,11,0,0,0,0,0,0,4,0,0,0,0,12,0,0,255,59,0,0,0,0,0,0,8,0,0,0,0,60,0,0,255,75,0,0,0,0,0,0,1,0,0,0,0,76,0,0,255,127,0,0,0,0,0,0,1,0,0,0,0,128,0,0,255,167,0,0,1,0,0,0,4,0,0,0,0,168,0,0,255,183,0,0,1,0,0,0,8,0,0,0,0,184,0,0,255,191,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,255,63,0,0,0,0,0,0,4,0,0,0,0,0,0,0,255,63,0,0,0,0,0,0,2,0,0,0,0,64,0,0,255,71,0,0,0,0,0,0,1,0,0,0,0,72,0,0,255,103,0,0,0,0,0,0,4,0,0,0,0,72,0,0,255,103,0,0,0,0,0,0,8,0,0,0,0,104,0,0,255,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,255,63,0,0,0,0,0,0,2,0,0,0,0,64,0,0,255,79,0,0,0,0,0,0,4,0,0,0,0,80,0,0,255,111,0,0,0,0,0,0,8,0,0,0,0,112,0,0,255,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,255,15,0,0,0,0,0,0,5,0,0,0,0,16,0,0,255,127,0,0,0,0,0,0,5,0,0,0,0,128,0,0,255,255,0,0,1,0,0,0,5,0,0,0,0,0,1,0,255,103,1,0,2,0,0,0,8,0,0,0,0,104,1,0,255,127,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,255,127,0,0,0,0,0,0,2,0,0,0,0,0,0,0,255,255,1,0,0,0,0,0,16,0,0,0,0,0,0,0,255,255,1,0,1,0,0,0,4,0,0,0,0,0,0,0,255,255,1,0,1,0,0,0,8,0,0,0,0,0,0,0,255,255,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,255,127,0,0,0,0,0,0,2,0,0,0,0,0,0,0,255,255,1,0,0,0,0,0,16,0,0,0,0,0,0,0,255,255,1,0,1,0,0,0,4,0,0,0,0,0,0,0,255,255,1,0,1,0,0,0,8,0,0,0,0,0,0,0,255,255,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,255,127,0,0,0,0,0,0,4,0,0,0,0,0,0,0,255,127,0,0,0,0,0,0,2,0,0,0,0,128,0,0,255,159,0,0,1,0,0,0,1,0,0,0,0,128,0,0,255,207,0,0,1,0,0,0,4,0,0,0,0,128,0,0,255,207,0,0,1,0,0,0,8,0,0,0,0,208,0,0,255,255,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,255,127,0,0,0,0,0,0,1,0,0,0,0,128,0,0,255,143,0,0,1,0,0,0,4,0,0,0,0,144,0,0,255,191,0,0,1,0,0,0,2,0,0,0,0,192,0,0,255,215,0,0,1,0,0,0,8,0,0,0,0,216,0,0,255,255,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,128,0,0,255,191,0,0,1,0,0,0,1,0,0,0,0,32,0,0,255,63,0,0,2,0,0,0,31,0,0,0,0,0,0,0,255,255,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,255,31,0,0,0,0,0,0,2,0,0,0,0,32,0,0,255,63,0,0,0,0,0,0,4,0,0,0,0,64,0,0,255,127,0,0,1,0,0,0,8,0,0,0,0,0,0,0,255,255,1,0,2,0,0,0,1,0,0,0,0,32,0,0,255,63,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,255,47,0,0,0,0,0,0,2,0,0,0,0,48,0,0,255,63,0,0,0,0,0,0,4,0,0,0,0,64,0,0,255,111,0,0,0,0,0,0,8,0,0,0,0,112,0,0,255,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,255,15,0,0,0,0,0,0,1,0,0,0,0,16,0,0,255,127,0,0,0,0,0,0,5,0,0,0,0,128,0,0,255,223,0,0,1,0,0,0,8,0,0,0,0,224,0,0,255,255,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,255,127,0,0,0,0,0,0,4,0,0,0,0,0,0,0,255,127,0,0,0,0,0,0,1,0,0,0,0,128,0,0,255,255,0,0,1,0,0,0,2,0,0,0,0,128,0,0,255,255,0,0,1,0,0,0,4,0,0,0,0,128,0,0,255,255,0,0,1,0,0,0,8,0,0,0,0,128,0,0,255,255,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,255,47,0,0,0,0,0,0,4,0,0,0,0,0,0,0,255,47,0,0,0,0,0,0,8,0,0,0,0,48,0,0,255,79,0,0,0,0,0,0,2,0,0,0,0,80,0,0,255,87,0,0,0,0,0,0,1,0,0,0,0,88,0,0,255,127,0,0,0,0,0,0,4,0,0,0,0,88,0,0,255,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,255,47,0,0,0,0,0,0,4,0,0,0,0,0,0,0])
.concat([255,47,0,0,0,0,0,0,8,0,0,0,0,48,0,0,255,63,0,0,0,0,0,0,8,0,0,0,0,64,0,0,255,79,0,0,1,0,0,0,2,0,0,0,0,80,0,0,255,87,0,0,1,0,0,0,1,0,0,0,0,88,0,0,255,127,0,0,1,0,0,0,4,0,0,0,0,88,0,0,255,127,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,255,47,0,0,0,0,0,0,2,0,0,0,0,48,0,0,255,63,0,0,0,0,0,0,4,0,0,0,0,64,0,0,255,95,0,0,0,0,0,0,8,0,0,0,0,96,0,0,255,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,255,47,0,0,0,0,0,0,2,0,0,0,0,48,0,0,255,63,0,0,0,0,0,0,4,0,0,0,0,64,0,0,255,95,0,0,1,0,0,0,8,0,0,0,0,96,0,0,255,127,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,244,188,2,247,44,61,232,217,80,98,236,189,83,115,121,97,0,52,207,162,99,40,144,175,68,59,197,141,58,70,7,112,102,190,216,139,233,160,75,152,220,223,226,22,116,241,55,245,183,33,129,1,28,27,148,54,9,161,74,145,48,146,155,154,41,177,56,77,85,242,86,24,36,71,157,63,128,31,34,164,17,84,132,13,37,72,238,198,89,21,3,122,253,108,195,51,91,196,123,90,5,127,166,64,169,93,65,138,150,82,211,240,171,114,16,136,111,149,124,168,205,156,95,50,174,133,57,172,229,215,251,212,8,35,25,101,107,167,147,187,43,191,184,53,208,6,38,104,62,221,185,105,42,178,222,135,69,88,255,60,158,125,218,237,73,140,20,142,117,47,224,110,120,109,32,210,250,45,81,204,199,231,29,39,151,252,49,219,248,66,227,153,94,131,14,180,46,246,192,12,76,87,182,100,10,23,163,193,119,18,254,230,143,19,113,228,249,173,159,206,213,137,126,15,194,134,243,103,186,96,67,201,4,179,176,30,181,200,235,165,118,234,92,130,26,79,170,202,225,11,78,203,106,239,209,214,72,138,72,165,1,72,169,0,133,1,162,16,38,16,38,17,38,1,165,1,197,0,144,4,229,0,133,1,38,16,38,17,202,208,237,104,133,1,104,170,104,96,0,0,0,0,0,0,0,0,0,0,0,0,0,0,27,0,0,0,255,255,1,0,0,0,0,0,0,0,0,0,116,112,45,48,50,54,45,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,106,116,177,247,0,0,16,1,116,112,45,48,50,54,45,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,152,141,87,229,0,0,32,0,116,112,45,48,50,54,45,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,83,203,96,183,0,0,32,0,116,112,45,48,50,54,45,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,31,63,6,133,0,0,64,0,57,51,99,52,53,46,117,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,240,93,215,64,0,0,16,1,102,105,120,101,105,103,104,116,116,119,116,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,108,192,213,182,0,0,16,1,103,101,55,50,45,104,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,44,153,173,160,1,0,16,1,103,101,55,50,45,108,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,240,150,99,153,1,0,16,1,103,101,55,50,45,104,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,5,96,184,216,1,0,16,1,103,101,55,50,45,108,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,165,3,211,35,1,0,16,1,104,104,95,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,239,39,81,236,2,0,32,0,104,104,95,49,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,148,82,246,222,2,0,32,0,104,104,95,50,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,212,106,13,187,2,0,32,0,104,104,95,51,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,78,4,81,67,2,0,32,0,103,101,55,50,98,45,97,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,42,107,245,245,3,0,32,0,103,101,55,50,45,97,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,8,234,148,209,3,0,32,0,103,101,55,50,45,97,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,195,188,6,43,3,0,32,0,103,101,55,50,45,97,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,250,107,185,148,3,0,32,0,103,101,55,50,45,98,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,179,150,135,32,4,0,32,0,103,101,55,50,45,98,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,144,244,167,180,4,0,32,0,103,101,55,50,98,45,98,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,127,143,254,52,4,0,32,0,103,101,55,50,98,45,98,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,244,146,14,75,4,0,32,0,103,101,110,45,118,111,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,102,92,89,216,5,0,64,0,100,107,103,101,110,109,55,50,95,105,56,55,53,49,46,109,99,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,24,220,2,180,3,68,4,188,4,180,3,68,4,220,5,12,5,148,5,180,6,180,6,148,8,92,6,204,6,188,7,188,8,4,7,156,5,12,3,4,5,4,5,100,5,204,5,68,6,12,8,108,8,228,8,84,9,92,6,212,6,84,7,196,7,212,6,84,7,36,8,132,8,12,8,108,8,228,8,108,9,153,9,153,9,153,9,153,9,153,9,153,9,153,9,153,9,153,9,153,9,0,0,0,0,49,46,105,99,56,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,194,61,249,159,1,0,16,1,50,46,105,99,56,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,235,60,195,187,1,0,16,1,97,55,53,45,48,54,46,105,99,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,182,119,93,81,2,0,16,1,97,55,53,45,48,51,46,105,99,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,186,116,139,3,3,0,32,0,97,55,53,45,48,52,46,105,99,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,153,225,250,113,3,0,32,0,97,55,53,45,48,53,46,105,99,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,226,116,99,199,3,0,32,0,97,55,53,45,48,55,46,105,99,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,137,178,248,10,4,0,32,0,97,55,53,45,48,56,46,105,99,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,251,2,176,171,4,0,32,0,97,55,53,45,48,57,46,105,99,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,119,194,198,167,4,0,32,0,168,86,7,0,1,0,0,0,176,191,145,0,248,191,2,0,24,38,7,0,1,0,0,0,178,191,145,0,184,160,2,0,56,210,6,0,1,0,0,0,80,254,146,0,192,135,2,0,24,163,6,0,1,0,0,0,81,254,146,0,240,108,2,0,152,122,6,0,1,0,0,0,82,254,146,0,96,82,2,0,192,72,6,0,1,0,0,0,83,254,146,0,32,56,2,0,200,110,3,0,1,0,0,0,84,254,146,0,152,30,2,0,120,89,3,0,1,0,0,0,85,254,146,0,232,10,2,0,120,74,3,0,1,0,0,0,86,254,146,0,152,138,8,0,192,61,3,0,1,0,0,0,87,254,146,0,48,119,7,0,144,236,1,0,1,0,0,0,179,191,145,0,136,224,1,0,176,223,1,0,1,0,0,0,0,246,146,0,72,198,1,0,192,209,1,0,1,0,0,0,1,246,146,0,24,182,1,0,24,198,1,0,1,0,0,0,2,246,146,0,40,167,1,0,120,189,1,0,1,0,0,0,3,246,146,0,200,149,1,0,224,22,1,0,1,0,0,0,4,246,146,0,56,126,1,0,160,14,1,0,1,0,0,0,5,246,146,0,32,101,1,0,176,9,1,0,1,0,0,0,6,246,146,0,96,32,8,0,200,3,1,0,1,0,0,0,7,246,146,0,16,68,7,0,88,212,3,0,1,0,0,0,56,218,146,0,40,185,3,0,72,65,1,0,9,0,0,0,68,224,146,0,32,58,1,0,48,50,1,0,9,0,0,0,69,224,146,0,32,58,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,86,7,0,1,0,0,0,176,238,146,0,248,191,2,0,24,38,7,0,1,0,0,0,178,238,146,0,184,160,2,0,56,210,6,0,1,0,0,0,208,252,146,0,192,135,2,0,24,163,6,0,1,0,0,0,209,252,146,0,240,108,2,0,152,122,6,0,1,0,0,0,210,252,146,0,96,82,2,0,192,72,6,0,1,0,0,0,211,252,146,0,32,56,2,0,152,226,4,0,1,0,0,0,212,252,146,0,152,30,2,0,168,190,4,0,1,0,0,0,213,252,146,0,232,10,2,0,240,158,4,0,1,0,0,0,214,252,146,0,152,138,8,0,136,128,4,0,1,0,0,0,224,236,146,0,48,119,7,0,176,101,4,0,1,0,0,0,225,236,146,0,112,109,7,0,136,75,4,0,1,0,0,0,226,236,146,0,24,133,7,0,40,246,1,0,1,0,0,0,177,238,146,0,64,246,1,0,144,236,1,0,1,0,0,0,179,238,146,0,136,224,1,0,176,223,1,0,1,0,0,0,128,244,146,0,72,198,1,0,192,209,1,0,1,0,0,0,129,244,146,0,24,182,1,0,24,198,1,0,1,0,0,0,130,244,146,0,40,167,1,0,120,189,1,0,1,0,0,0,131,244,146,0,200,149,1,0,40,126,1,0,1,0,0,0,132,244,146,0,56,126,1,0,0,112,1,0,1,0,0,0,133,244,146,0,32,101,1,0,0,101,1,0,1,0,0,0,134,244,146,0,96,32,8,0,248,91,1,0,1,0,0,0,32,236,146,0,16,68,7,0,128,85,1,0,1,0,0,0,33,236,146,0,240,58,7,0,248,76,1,0,1,0,0,0,34,236,146,0,200,42,1,0,88,212,3,0,1,0,0,0,48,217,146,0,40,185,3,0,16,17,8,0,1,0,0,0,182,238,146,0,224,12,8,0,56,58,1,0,1,0,0,0,181,238,146,0,64,50,1,0,72,65,1,0,9,0,0,0,56,94,147,0,32,58,1,0,48,50,1,0,9,0,0,0,57,94,147,0,32,58,1,0,224,41,1,0,9,0,0,0,58,94,147,0,32,58,1,0,48,45,3,0,9,0,0,0,59,94,147,0,32,58,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,40,2,0,1,0,0,0,208,155,215,0,248,191,2,0,56,250,6,0,1,0,0,0,212,155,215,0,184,160,2,0,184,164,8,0,1,0,0,0,209,155,215,0,64,246,1,0,88,149,7,0,1,0,0,0,213,155,215,0,136,224,1,0,56,210,6,0,1,0,0,0,205,155,215,0,192,135,2,0,24,163,6,0,1,0,0,0,204,155,215,0,240,108,2,0,152,122,6,0,1,0,0,0,207,155,215,0,96,82,2,0,192,72,6,0,1,0,0,0,206,155,215,0,32,56,2,0,48,123,2,0,1,0,0,0,201,155,215,0,152,30,2,0,96,69,2,0,1,0,0,0,202,155,215,0,232,10,2,0,176,223,1,0,1,0,0,0,197,155,215,0,72,198,1,0,192,209,1,0,1,0,0,0,196,155,215,0,24,182,1,0,24,198,1,0,1,0,0,0,199,155,215,0,40,167,1,0,120,189,1,0,1,0,0,0,198,155,215,0,200,149,1,0,248,187,8,0,1,0,0,0,193,155,215,0,56,126,1,0,184,179,8,0,1,0,0,0,194,155,215,0,32,101,1,0,16,17,8,0,1,0,0,0,211,155,215,0,224,12,8,0,32,77,1,0,1,0,0,0,210,155,215,0,216,70,1,0,88,212,3,0,1,0,0,0,200,154,215,0,40,185,3,0,248,5,8,0,9,0,0,0,0,156,215,0,32,58,1,0,144,250,7,0,9,0,0,0,1,156,215,0,32,58,1,0,48,54,52,117,100,97,48,50,46,56,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,183,166,41,81,0,0,16,1,48,54,52,117,100,97,48,51,46,56,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,20,114,136,159,0,0,16,1,48,54,52,101,97,98,48,52,46,49,48,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,189,21,35,239,0,0,16,1,48,54,52,101,97,98,48,53,46,49,48,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,196,251,214,81,0,0,16,1,48,54,52,101,48,49,46,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,82,188,185,68,0,0,16,1,48,54,52,101,49,50,46,49,54,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,25,198,189,226,0,0,32,0,48,54,52,101,49,49,46,49,50,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,176,168,140,45,0,0,32,0,48,54,52,101,48,57,46,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,114,195,96,65,0,0,32,0,48,54,52,101,48,55,46,51,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,60,103,221,100,0,0,32,0,48,54,52,101,48,54,46,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,249,13,129,89,0,0,64,0,115,115,114,105,100,101,114,115,95,117,100,97,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,100,109,140,20,0,0,0,8,48,54,52,117,98,99,48,50,46,56,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,165,253,167,172,0,0,16,1,48,54,52,117,98,99,48,51,46,56,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,255,222,31,187,0,0,16,1,48,54,52,101,97,98,48,52,46,49,48,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,189,21,35,239,0,0,16,1,48,54,52,101,97,98,48,53,46,49,48,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,196,251,214,81,0,0,16,1,48,54,52,101,48,49,46,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,82,188,185,68,0,0,16,1,48,54,52,101,49,50,46,49,54,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,25,198,189,226,0,0,32,0,48,54,52,101,49,49,46,49,50,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,176,168,140,45,0,0,32,0,48,54,52,101,48,57,46,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,114,195,96,65,0,0,32,0,48,54,52,101,48,55,46,51,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,60,103,221,100,0,0,32,0,48,54,52,101,48,54,46,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,249,13,129,89,0,0,64,0,115,115,114,105,100,101,114,115,95,117,98,99,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,79,80,197,49,0,0,0,8,48,54,52,117,97,99,48,50,46,56,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,182,115,4,135,0,0,16,1,48,54,52,117,97,99,48,51,46,56,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,154,40,223,234,0,0,16,1,48,54,52,101,97,98,48,52,46,49,48,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,189,21,35,239,0,0,16,1,48,54,52,101,97,98,48,53,46,49,48,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,196,251,214,81,0,0,16,1,48,54,52,101,48,49,46,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,82,188,185,68,0,0,16,1,48,54,52,101,49,50,46,49,54,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,25,198,189,226,0,0,32,0,48,54,52,101,49,49,46,49,50,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,176,168,140,45,0,0,32,0,48,54,52,101,48,57,46,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,114,195,96,65,0,0,32,0,48,54,52,101,48,55,46,51,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,60,103,221,100,0,0,32,0,48,54,52,101,48,54,46,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,249,13,129,89,0,0,64,0,115,115,114,105,100,101,114,115,95,117,97,99,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,160,241,200,38,0,0,0,8,48,54,52,117,97,98,48,50,46,56,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,72,197,163,241,0,0,16,1,48,54,52,117,97,98,48,51,46,56,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,135,18,166,102,0,0,16,1,48,54,52,101,97,98,48,52,46,49,48,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,189,21,35,239,0,0,16,1,48,54,52,101,97,98,48,53,46,49,48,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,196,251,214,81,0,0,16,1,48,54,52,101,48,49,46,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,82,188,185,68,0,0,16,1,48,54,52,101,49,50,46,49,54,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,25,198,189,226,0,0,32,0,48,54,52,101,49,49,46,49,50,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,176,168,140,45,0,0,32,0,48,54,52,101,48,57,46,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,114,195,96,65,0,0,32,0,48,54,52,101,48,55,46,51,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,60,103,221,100,0,0,32,0,48,54,52,101,48,54,46,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,249,13,129,89,0,0,64,0,115,115,114,105,100,101,114,115,95,117,97,98,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,16,178,8,254,0,0,0,8,48,54,52,106,98,100,48,50,46,56,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,227,193,205,122,0,0,16,1,48,54,52,106,98,100,48,51,46,56,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,24,73,66,106,0,0,16,1,48,54,52,101,97,98,48,52,46,49,48,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,189,21,35,239,0,0,16,1,48,54,52,101,97,98,48,53,46,49,48,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,196,251,214,81,0,0,16,1,48,54,52,101,48,49,46,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,82,188,185,68,0,0,16,1,48,54,52,101,49,50,46,49,54,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,25,198,189,226,0,0,32,0,48,54,52,101,49,49,46,49,50,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,176,168,140,45,0,0,32,0,48,54,52,101,48,57,46,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,114,195,96,65,0,0,32,0,48,54,52,101,48,55,46,51,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,60,103,221,100,0,0,32,0,48,54,52,101,48,54,46,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,249,13,129,89,0,0,64,0,115,115,114,105,100,101,114,115,95,106,98,100,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,227,0,98,0,0,0,0,8,48,54,52,106,97,99,48,50,46,56,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,111,95,163,100,0,0,16,1,48,54,52,106,97,99,48,51,46,56,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,70,121,149,181,0,0,16,1,48,54,52,101,97,98,48,52,46,49,48,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,189,21,35,239,0,0,16,1,48,54,52,101,97,98,48,53,46,49,48,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,196,251,214,81,0,0,16,1,48,54,52,101,48,49,46,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,82,188,185,68,0,0,16,1,48,54,52,101,49,50,46,49,54,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,25,198,189,226,0,0,32,0,48,54,52,101,49,49,46,49,50,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,176,168,140,45,0,0,32,0,48,54,52,101,48,57,46,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,114,195,96,65,0,0,32,0,48,54,52,101,48,55,46,51,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,60,103,221,100,0,0,32,0,48,54,52,101,48,54,46,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,249,13,129,89,0,0,64,0,115,115,114,105,100,101,114,115,95,106,97,99,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,95,197,176,238,0,0,0,8,48,54,52,101,98,100,48,50,46,56,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,172,249,238,141,0,0,16,1,48,54,52,101,98,100,48,51,46,56,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,7,193,112,35,0,0,16,1,48,54,52,101,97,98,48,52,46,49,48,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,189,21,35,239,0,0,16,1,48,54,52,101,97,98,48,53,46,49,48,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,196,251,214,81,0,0,16,1,48,54,52,101,48,49,46,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,82,188,185,68,0,0,16,1,48,54,52,101,49,50,46,49,54,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,25,198,189,226,0,0,32,0,48,54,52,101,49,49,46,49,50,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,176,168,140,45,0,0,32,0,48,54,52,101,48,57,46,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,114,195,96,65,0,0,32,0,48,54,52,101,48,55,46,51,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,60,103,221,100,0,0,32,0,48,54,52,101,48,54,46,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,249,13,129,89,0,0,64,0,115,115,114,105,100,101,114,115,95,101,98,100,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,246,3,201,203,0,0,0,8,48,54,52,101,98,99,48,50,46,56,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,100,209,215,155,0,0,16,1,48,54,52,101,98,99,48,51,46,56,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,101,65,253,64,0,0,16,1,48,54,52,101,97,98,48,52,46,49,48,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,189,21,35,239,0,0,16,1,48,54,52,101,97,98,48,53,46,49,48,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,196,251,214,81,0,0,16,1,48,54,52,101,48,49,46,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,82,188,185,68,0,0,16,1,48,54,52,101,49,50,46,49,54,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,25,198,189,226,0,0,32,0,48,54,52,101,49,49,46,49,50,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,176,168,140,45,0,0,32,0,48,54,52,101,48,57,46,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,114,195,96,65,0,0,32,0,48,54,52,101,48,55,46,51,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,60,103,221,100,0,0,32,0,48,54,52,101,48,54,46,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,249,13,129,89,0,0,64,0,115,115,114,105,100,101,114,115,95,101,98,99,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,15,233,24,25,0,0,0,8,48,54,52,101,97,97,48,50,46,56,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,15,102,68,72,0,0,16,1,48,54,52,101,97,97,48,51,46,56,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,124,204,155,11,0,0,16,1,48,54,52,101,97,97,48,52,46,49,48,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,28,124,145,93,0,0,16,1,48,54,52,101,97,97,48,53,46,49,48,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,116,123,100,244,0,0,16,1,48,54,52,101,97,97,48,49,46,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,130,93,228,188,0,0,16,1,48,54,52,101,49,50,46,49,54,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,25,198,189,226,0,0,32,0,48,54,52,101,49,49,46,49,50,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,176,168,140,45,0,0,32,0,48,54,52,101,48,57,46,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,114,195,96,65,0,0,32,0,48,54,52,101,48,55,46,51,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,60,103,221,100,0,0,32,0,48,54,52,101,48,54,46,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,249,13,129,89,0,0,64,0,115,115,114,105,100,101,114,115,95,101,97,97,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,245,94,164,116,0,0,0,8,48,54,52,97,100,100,48,50,46,56,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,142,19,176,6,0,0,16,1,48,54,52,97,100,100,48,51,46,56,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,145,139,235,3,0,0,16,1,48,54,52,101,97,98,48,52,46,49,48,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,189,21,35,239,0,0,16,1,48,54,52,101,97,98,48,53,46,49,48,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,196,251,214,81,0,0,16,1,48,54,52,101,48,49,46,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,82,188,185,68,0,0,16,1,48,54,52,101,49,50,46,49,54,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,25,198,189,226,0,0,32,0,48,54,52,101,49,49,46,49,50,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,176,168,140,45,0,0,32,0,48,54,52,101,48,57,46,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,114,195,96,65,0,0,32,0,48,54,52,101,48,55,46,51,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,60,103,221,100,0,0,32,0,48,54,52,101,48,54,46,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,249,13,129,89,0,0,64,0,115,115,114,105,100,101,114,115,95,97,100,100,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,213,66,98,240,0,0,0,8,48,54,52,97,98,100,48,50,46,56,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,203,6,52,113,0,0,16,1,48,54,52,97,98,100,48,51,46,56,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,60,235,15,104,0,0,16,1,48,54,52,101,97,98,48,52,46,49,48,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,189,21,35,239,0,0,16,1,48,54,52,101,97,98,48,53,46,49,48,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,196,251,214,81,0,0,16,1,48,54,52,101,48,49,46,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,82,188,185,68,0,0,16,1,48,54,52,101,49,50,46,49,54,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,25,198,189,226,0,0,32,0,48,54,52,101,49,49,46,49,50,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,176,168,140,45,0,0,32,0,48,54,52,101,48,57,46,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,114,195,96,65,0,0,32,0,48,54,52,101,48,55,46,51,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,60,103,221,100,0,0,32,0,48,54,52,101,48,54,46,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,249,13,129,89,0,0,64,0,115,115,114,105,100,101,114,115,95,97,98,100,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,223,254,218,191,0,0,0,8,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,0,0,0,0,8,0,0,0,16,0,0,0,24,0,0,0,0,0,0,0,8,0,0,0,16,0,0,0,24,0,0,0,0,0,0,1,1,0,0,1,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,0,0,0,0,8,0,0,0,16,0,0,0,24,0,0,0,8,0,128,0,0,0,128,0,8,0,0,0,0,0,0,0,8,0,0,0,12,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,8,0,64,0,0,0,64,0,8,0,0,0,0,0,0,0,4,0,16,0,0,0,16,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,4,0,0,0,6,0,4,0,6,0,0,0,6,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,32,0,0,0,48,0,0,0,16,0,0,0,48,0,0,0,0,0,0,0,32,0,0,0,0,0,64,0,0,0,128,0,0,0,192,0,0,0,0,1,0,0,64,1,0,0,128,1,0,0,192,1,0,0,0,0,0,0,0,0,0,0,168,86,7,0,1,0,0,0,192,47,216,0,248,191,2,0,24,38,7,0,1,0,0,0,196,47,216,0,184,160,2,0,56,210,6,0,1,0,0,0,251,47,216,0,192,135,2,0,24,163,6,0,1,0,0,0,250,47,216,0,240,108,2,0,152,122,6,0,1,0,0,0,249,47,216,0,96,82,2,0,192,72,6,0,1,0,0,0,248,47,216,0,32,56,2,0,152,226,4,0,1,0,0,0,252,47,216,0,152,30,2,0,168,190,4,0,1,0,0,0,253,47,216,0,232,10,2,0,240,158,4,0,1,0,0,0,254,47,216,0,152,138,8,0,136,128,4,0,1,0,0,0,144,47,216,0,48,119,7,0,176,101,4,0,1,0,0,0,145,47,216,0,112,109,7,0,136,75,4,0,1,0,0,0,146,47,216,0,24,133,7,0,40,246,1,0,1,0,0,0,193,47,216,0,64,246,1,0,144,236,1,0,1,0,0,0,197,47,216,0,136,224,1,0,176,223,1,0,1,0,0,0,3,48,216,0,72,198,1,0,192,209,1,0,1,0,0,0,2,48,216,0,24,182,1,0,24,198,1,0,1,0,0,0,1,48,216,0,40,167,1,0,120,189,1,0,1,0,0,0,0,48,216,0,200,149,1,0,40,126,1,0,1,0,0,0,4,48,216,0,56,126,1,0,0,112,1,0,1,0,0,0,5,48,216,0,32,101,1,0,0,101,1,0,1,0,0,0,6,48,216,0,96,32,8,0,248,91,1,0,1,0,0,0,148,47,216,0,16,68,7,0,128,85,1,0,1,0,0,0,149,47,216,0,240,58,7,0,248,76,1,0,1,0,0,0,150,47,216,0,200,42,1,0,88,212,3,0,1,0,0,0,144,46,216,0,40,185,3,0,240,152,1,0,1,0,0,0,198,47,216,0,216,70,1,0,16,17,8,0,1,0,0,0,194,47,216,0,224,12,8,0,72,65,1,0,9,0,0,0,232,48,216,0,32,58,1,0,48,50,1,0,9,0,0,0,224,48,216,0,32,58,1,0,224,41,1,0,9,0,0,0,216,48,216,0,32,58,1,0,168,86,7,0,1,0,0,0,232,47,216,0,248,191,2,0,24,38,7,0,1,0,0,0,236,47,216,0,184,160,2,0,56,210,6,0,1,0,0,0,35,48,216,0,192,135,2,0,24,163,6,0,1,0,0,0,34,48,216,0,240,108,2,0,152,122,6,0,1,0,0,0,33,48,216,0,96,82,2,0,192,72,6,0,1,0,0,0,32,48,216,0,32,56,2,0,152,226,4,0,1,0,0,0,36,48,216,0,152,30,2,0,168,190,4,0,1,0,0,0,37,48,216,0,232,10,2,0,240,158,4,0,1,0,0,0,38,48,216,0,152,138,8,0,136,128,4,0,1,0,0,0,240,47,216,0,48,119,7,0,176,101,4,0,1,0,0,0,241,47,216,0,112,109,7,0,136,75,4,0,1,0,0,0,242,47,216,0,24,133,7,0,40,246,1,0,1,0,0,0,233,47,216,0,64,246,1,0,144,236,1,0,1,0,0,0,237,47,216,0,136,224,1,0,176,223,1,0,1,0,0,0,43,48,216,0,72,198,1,0,192,209,1,0,1,0,0,0,42,48,216,0,24,182,1,0,24,198,1,0,1,0,0,0,41,48,216,0,40,167,1,0,120,189,1,0,1,0,0,0,40,48,216,0,200,149,1,0,40,126,1,0,1,0,0,0,44,48,216,0,56,126,1,0,0,112,1,0,1,0,0,0,45,48,216,0,32,101,1,0,0,101,1,0,1,0,0,0,46,48,216,0,96,32,8,0,248,91,1,0,1,0,0,0,244,47,216,0,16,68,7,0,128,85,1,0,1,0,0,0,245,47,216,0,240,58,7,0,248,76,1,0,1,0,0,0,246,47,216,0,200,42,1,0,88,212,3,0,1,0,0,0,144,46,216,0,40,185,3,0,240,152,1,0,1,0,0,0,238,47,216,0,216,70,1,0,16,17,8,0,1,0,0,0,234,47,216,0,224,12,8,0,72,65,1,0,9,0,0,0,232,48,216,0,32,58,1,0,48,50,1,0,9,0,0,0,224,48,216,0,32,58,1,0,224,41,1,0,9,0,0,0,216,48,216,0,32,58,1,0,109,99,48,49,46,49,106,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,95,228,235,11,0,0,16,1,109,99,48,50,46,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,176,120,83,55,0,0,16,1,109,103,45,49,46,49,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,5,8,106,253,0,0,32,0,109,103,45,50,46,49,52,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,30,135,110,226,0,0,32,0,109,103,45,51,46,49,54,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,154,29,120,221,0,0,32,0,109,103,45,52,46,49,55,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,121,204,175,151,0,0,32,0,109,99,48,54,46,52,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,38,57,248,14,0,0,32,0,109,99,48,55,46,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,177,255,249,89,0,0,32,0,109,103,45,53,46,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,241,50,3,23,0,0,64,0,184,40,2,0,1,0,0,0,40,39,216,0,248,191,2,0,56,250,6,0,1,0,0,0,32,39,216,0,184,160,2,0,184,164,8,0,1,0,0,0,41,39,216,0,64,246,1,0,88,149,7,0,1,0,0,0,33,39,216,0,136,224,1,0,240,167,7,0,1,0,0,0,35,39,216,0,192,135,2,0,176,163,7,0,1,0,0,0,47,39,216,0,240,108,2,0,208,158,7,0,1,0,0,0,42,39,216,0,96,82,2,0,184,154,7,0,1,0,0,0,43,39,216,0,32,56,2,0,176,108,2,0,1,0,0,0,44,39,216,0,152,30,2,0,128,98,2,0,1,0,0,0,34,39,216,0,232,10,2,0,8,96,7,0,1,0,0,0,36,39,216,0,72,198,1,0,48,89,7,0,1,0,0,0,46,39,216,0,24,182,1,0,48,76,7,0,1,0,0,0,37,39,216,0,56,126,1,0,144,72,7,0,1,0,0,0,45,39,216,0,32,101,1,0,88,212,3,0,1,0,0,0,48,38,216,0,40,185,3,0,248,5,8,0,9,0,0,0,112,39,216,0,32,58,1,0,144,250,7,0,9,0,0,0,113,39,216,0,32,58,1,0,248,241,7,0,9,0,0,0,114,39,216,0,32,58,1,0,0,0,0,0,16,0,0,0,32,0,0,0,48,0,0,0,64,0,0,0,80,0,0,0,96,0,0,0,112,0,0,0,0,0,0,0,4,0,0,0,0,0,32,0,4,0,32,0,8,0,0,0,12,0,0,0,8,0,32,0,12,0,32,0,168,86,7,0,1,0,0,0,72,234,148,0,248,191,2,0,24,38,7,0,1,0,0,0,224,231,148,0,184,160,2,0,56,210,6,0,1,0,0,0,138,233,148,0,192,135,2,0,24,163,6,0,1,0,0,0,139,233,148,0,240,108,2,0,152,122,6,0,1,0,0,0,136,233,148,0,96,82,2,0,192,72,6,0,1,0,0,0,137,233,148,0,32,56,2,0,200,110,3,0,1,0,0,0,140,233,148,0,152,30,2,0,120,89,3,0,1,0,0,0,141,233,148,0,232,10,2,0,40,246,1,0,1,0,0,0,73,234,148,0,64,246,1,0,144,236,1,0,1,0,0,0,225,231,148,0,136,224,1,0,176,223,1,0,1,0,0,0,202,232,148,0,72,198,1,0,192,209,1,0,1,0,0,0,203,232,148,0,24,182,1,0,24,198,1,0,1,0,0,0,200,232,148,0,40,167,1,0,120,189,1,0,1,0,0,0,201,232,148,0,200,149,1,0,224,22,1,0,1,0,0,0,204,232,148,0,56,126,1,0,160,14,1,0,1,0,0,0,205,232,148,0,32,101,1,0,88,212,3,0,1,0,0,0,248,221,146,0,40,185,3,0,16,17,8,0,1,0,0,0,76,234,148,0,224,12,8,0,72,65,1,0,9,0,0,0,240,94,147,0,32,58,1,0,48,50,1,0,9,0,0,0,241,94,147,0,32,58,1,0,224,41,1,0,9,0,0,0,242,94,147,0,32,58,1,0,115,109,99,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,214,160,156,56,1,0,16,1,115,109,99,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,48,180,10,65,1,0,16,1,115,109,99,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,75,20,180,166,1,0,16,1,115,109,99,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,254,70,192,76,1,0,16,1,115,109,99,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,166,120,211,6,1,0,16,1,115,109,99,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,39,169,132,110,1,0,16,1,115,109,99,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,232,241,90,180,1,0,16,1,115,109,99,56,102,95,117,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,255,178,104,185,1,0,16,1,109,99,115,95,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,129,31,15,251,4,0,32,0,109,99,115,95,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,21,42,147,19,4,0,32,0,109,99,115,95,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,90,187,30,99,4,0,32,0,109,99,115,95,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,69,209,207,36,4,0,32,0,109,109,105,54,51,51,49,46,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,135,125,12,106,7,0,32,0,6,0,0,0,16,0,0,0,152,33,8,0,240,236,7,0,32,184,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,38,7,0,1,0,0,0,239,34,216,0,184,160,2,0,56,210,6,0,1,0,0,0,232,34,216,0,192,135,2,0,24,163,6,0,1,0,0,0,233,34,216,0,240,108,2,0,152,122,6,0,1,0,0,0,234,34,216,0,96,82,2,0,192,72,6,0,1,0,0,0,235,34,216,0,32,56,2,0,136,30,2,0,1,0,0,0,238,34,216,0,152,30,2,0,224,19,2,0,1,0,0,0,236,34,216,0,232,10,2,0,216,10,2,0,1,0,0,0,237,34,216,0,152,138,8,0,208,39,5,0,1,0,0,0,242,34,216,0,48,119,7,0,192,230,4,0,1,0,0,0,241,34,216,0,112,109,7,0,72,162,4,0,1,0,0,0,240,34,216,0,24,133,7,0,48,105,4,0,1,0,0,0,243,34,216,0,96,78,4,0,144,236,1,0,1,0,0,0,223,34,216,0,136,224,1,0,176,223,1,0,1,0,0,0,216,34,216,0,72,198,1,0,192,209,1,0,1,0,0,0,217,34,216,0,24,182,1,0,24,198,1,0,1,0,0,0,218,34,216,0,40,167,1,0,120,189,1,0,1,0,0,0,219,34,216,0,200,149,1,0,184,155,8,0,1,0,0,0,222,34,216,0,56,126,1,0,136,149,8,0,1,0,0,0,220,34,216,0,32,101,1,0,216,142,8,0,1,0,0,0,221,34,216,0,96,32,8,0,0,86,3,0,1,0,0,0,226,34,216,0,16,68,7,0,224,85,3,0,1,0,0,0,225,34,216,0,240,58,7,0,208,85,3,0,1,0,0,0,224,34,216,0,200,42,1,0,80,85,3,0,1,0,0,0,227,34,216,0,24,60,1,0,88,212,3,0,1,0,0,0,176,34,216,0,40,185,3,0,72,65,1,0,9,0,0,0,248,34,216,0,32,58,1,0,48,50,1,0,9,0,0,0,249,34,216,0,32,58,1,0,50,0,0,0,255,255,1,0,0,0,0,0,0,0,0,0,254,0,5,0,184,93,3,0,49,0,0,0,1,193,1,0,16,93,3,0,49,0,0,0,1,193,0,0,248,92,3,0,49,0,0,0,1,193,64,0,160,92,3,0,49,0,0,0,1,193,128,0,160,134,3,0,49,0,0,0,1,193,192,0,8,234,2,0,0,0,0,0,254,0,2,0,120,92,3,0,49,0,0,0,1,32,32,0,56,111,3,0,49,0,0,0,1,32,0,0,104,134,3,0,0,0,0,0,254,0,3,0,96,91,3,0,50,0,0,0,1,3,0,0,208,90,3,0,50,0,0,0,1,3,1,0,152,90,3,0,50,0,0,0,1,3,2,0,80,90,3,0,168,86,7,0,1,0,0,0,168,1,147,0,248,191,2,0,24,38,7,0,1,0,0,0,239,248,146,0,184,160,2,0,56,210,6,0,1,0,0,0,234,248,146,0,192,135,2,0,24,163,6,0,1,0,0,0,235,248,146,0,240,108,2,0,152,122,6,0,1,0,0,0,232,248,146,0,96,82,2,0,192,72,6,0,1,0,0,0,233,248,146,0,32,56,2,0,200,110,3,0,1,0,0,0,237,248,146,0,152,30,2,0,120,89,3,0,1,0,0,0,236,248,146,0,232,10,2,0,120,74,3,0,1,0,0,0,238,248,146,0,152,138,8,0,40,246,1,0,1,0,0,0,169,1,147,0,64,246,1,0,144,236,1,0,1,0,0,0,207,240,146,0,136,224,1,0,176,223,1,0,1,0,0,0,202,240,146,0,72,198,1,0,192,209,1,0,1,0,0,0,203,240,146,0,24,182,1,0,24,198,1,0,1,0,0,0,200,240,146,0,40,167,1,0,120,189,1,0,1,0,0,0,201,240,146,0,200,149,1,0,224,22,1,0,1,0,0,0,205,240,146,0,56,126,1,0,160,14,1,0,1,0,0,0,204,240,146,0,32,101,1,0,176,9,1,0,1,0,0,0,206,240,146,0,96,32,8,0,88,212,3,0,1,0,0,0,40,221,146,0,40,185,3,0,56,122,5,0,1,0,0,0,172,1,147,0,224,12,8,0,0,105,5,0,1,0,0,0,173,1,147,0,128,176,7,0,72,65,1,0,9,0,0,0,240,6,147,0,32,58,1,0,48,50,1,0,9,0,0,0,241,6,147,0,32,58,1,0,224,41,1,0,9,0,0,0,242,6,147,0,32,58,1,0,49,51,54,48,51,55,45,49,50,48,55,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,13,97,192,109,0,0,16,1,49,51,54,48,51,55,45,49,50,48,56,46,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,235,6,163,250,0,0,16,1,49,51,54,48,51,55,45,50,48,53,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,81,237,153,109,0,0,16,1,49,51,54,48,51,55,45,50,48,54,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,145,173,94,84,0,0,16,1,49,51,54,48,51,55,45,49,49,48,57,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,251,148,1,80,0,0,16,1,49,51,54,48,51,55,45,49,49,49,48,46,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,118,144,150,178,0,0,16,1,49,51,54,48,51,55,45,49,50,48,46,49,54,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,204,243,231,110,0,0,16,1,49,51,54,48,51,55,45,49,49,57,46,49,54,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,31,134,25,250,0,0,16,1,49,51,54,48,51,55,45,49,48,52,46,54,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,89,91,42,158,0,0,32,0,49,51,54,48,51,55,45,49,49,49,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,51,15,112,145,0,0,32,0,49,51,54,48,51,55,45,49,49,50,46,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,190,48,147,134,0,0,32,0,49,51,54,48,51,55,45,49,49,51,46,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,168,208,151,212,0,0,32,0,49,51,54,48,51,55,45,49,49,52,46,49,109,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,130,152,239,41,0,0,32,0,49,51,54,48,51,55,45,49,49,53,46,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,152,184,16,149,0,0,32,0,49,51,54,48,51,55,45,49,49,54,46,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,91,172,224,17,0,0,32,0,49,51,54,48,51,55,45,49,49,55,46,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,65,219,165,41,0,0,32,0,49,51,54,48,51,55,45,49,49,56,46,50,109,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,99,178,243,139,0,0,32,0,55,52,115,52,55,50,45,49,51,54,48,51,55,45,49,48,49,46,55,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,111,247,100,41,0,0,32,0,55,52,115,52,55,50,45,49,51,54,48,51,55,45,49,48,50,46,53,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,108,236,79,77,0,0,32,0,55,52,115,50,56,55,45,49,51,54,48,51,55,45,49,48,51,46,52,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,8,207,92,108,0,0,32,0,49,51,54,48,51,55,45,56,48,55,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,194,11,28,103,0,0,16,1,49,51,54,48,51,55,45,56,48,56,46,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,244,42,132,242,0,0,16,1,49,51,54,48,51,55,45,49,48,53,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,149,205,66,70,0,0,16,1,49,51,54,48,51,55,45,49,48,54,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,94,148,223,200,0,0,16,1,49,51,54,48,51,55,45,56,48,57,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,96,45,100,5,0,0,16,1,49,51,54,48,51,55,45,56,49,48,46,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,227,149,210,54,0,0,16,1,49,51,54,48,51,55,45,49,50,48,46,49,54,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,204,243,231,110,0,0,16,1,49,51,54,48,51,55,45,49,49,57,46,49,54,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,31,134,25,250,0,0,16,1,49,51,54,48,51,55,45,49,48,52,46,54,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,89,91,42,158,0,0,32,0,49,51,54,48,51,55,45,49,49,49,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,51,15,112,145,0,0,32,0,49,51,54,48,51,55,45,49,49,50,46,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,190,48,147,134,0,0,32,0,49,51,54,48,51,55,45,49,49,51,46,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,168,208,151,212,0,0,32,0,49,51,54,48,51,55,45,49,49,52,46,49,109,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,130,152,239,41,0,0,32,0,49,51,54,48,51,55,45,49,49,53,46,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,152,184,16,149,0,0,32,0,49,51,54,48,51,55,45,49,49,54,46,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,91,172,224,17,0,0,32,0,49,51,54,48,51,55,45,49,49,55,46,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,65,219,165,41,0,0,32,0,49,51,54,48,51,55,45,49,49,56,46,50,109,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,99,178,243,139,0,0,32,0,55,52,115,52,55,50,45,49,51,54,48,51,55,45,49,48,49,46,55,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,111,247,100,41,0,0,32,0,55,52,115,52,55,50,45,49,51,54,48,51,55,45,49,48,50,46,53,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,108,236,79,77,0,0,32,0,55,52,115,50,56,55,45,49,51,54,48,51,55,45,49,48,51,46,52,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,8,207,92,108,0,0,32,0,49,51,54,48,51,55,45,51,48,55,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,201,39,152,117,0,0,16,1,49,51,54,48,51,55,45,51,48,56,46,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,209,98,18,215,0,0,16,1,49,51,54,48,51,55,45,49,48,53,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,149,205,66,70,0,0,16,1,49,51,54,48,51,55,45,49,48,54,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,94,148,223,200,0,0,16,1,49,51,54,48,51,55,45,54,48,57,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,222,129,51,205,0,0,16,1,49,51,54,48,51,55,45,54,49,48,46,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,42,147,255,44,0,0,16,1,49,51,54,48,51,55,45,49,50,48,46,49,54,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,204,243,231,110,0,0,16,1,49,51,54,48,51,55,45,49,49,57,46,49,54,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,31,134,25,250,0,0,16,1,49,51,54,48,51,55,45,49,48,52,46,54,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,89,91,42,158,0,0,32,0,49,51,54,48,51,55,45,49,49,49,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,51,15,112,145,0,0,32,0,49,51,54,48,51,55,45,49,49,50,46,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,190,48,147,134,0,0,32,0,49,51,54,48,51,55,45,49,49,51,46,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,168,208,151,212,0,0,32,0,49,51,54,48,51,55,45,49,49,52,46,49,109,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,130,152,239,41,0,0,32,0,49,51,54,48,51,55,45,49,49,53,46,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,152,184,16,149,0,0,32,0,49,51,54,48,51,55,45,49,49,54,46,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,91,172,224,17,0,0,32,0,49,51,54,48,51,55,45,49,49,55,46,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,65,219,165,41,0,0,32,0,49,51,54,48,51,55,45,49,49,56,46,50,109,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,99,178,243,139,0,0,32,0,55,52,115,52,55,50,45,49,51,54,48,51,55,45,49,48,49,46,55,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,111,247,100,41,0,0,32,0,55,52,115,52,55,50,45,49,51,54,48,51,55,45,49,48,50,46,53,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,108,236,79,77,0,0,32,0,55,52,115,50,56,55,45,49,51,54,48,51,55,45,49,48,51,46,52,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,8,207,92,108,0,0,32,0,49,51,54,48,51,55,45,51,48,55,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,201,39,152,117,0,0,16,1,49,51,54,48,51,55,45,51,48,56,46,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,209,98,18,215,0,0,16,1,49,51,54,48,51,55,45,49,48,53,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,149,205,66,70,0,0,16,1,49,51,54,48,51,55,45,49,48,54,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,94,148,223,200,0,0,16,1,49,51,54,48,51,55,45,51,48,57,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,107,105,3,127,0,0,16,1,49,51,54,48,51,55,45,51,49,48,46,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,252,151,113,141,0,0,16,1,49,51,54,48,51,55,45,49,50,48,46,49,54,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,204,243,231,110,0,0,16,1,49,51,54,48,51,55,45,49,49,57,46,49,54,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,31,134,25,250,0,0,16,1,49,51,54,48,51,55,45,49,48,52,46,54,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,89,91,42,158,0,0,32,0,49,51,54,48,51,55,45,49,49,49,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,51,15,112,145,0,0,32,0,49,51,54,48,51,55,45,49,49,50,46,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,190,48,147,134,0,0,32,0,49,51,54,48,51,55,45,49,49,51,46,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,168,208,151,212,0,0,32,0,49,51,54,48,51,55,45,49,49,52,46,49,109,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,130,152,239,41,0,0,32,0,49,51,54,48,51,55,45,49,49,53,46,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,152,184,16,149,0,0,32,0,49,51,54,48,51,55,45,49,49,54,46,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,91,172,224,17,0,0,32,0,49,51,54,48,51,55,45,49,49,55,46,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,65,219,165,41,0,0,32,0,49,51,54,48,51,55,45,49,49,56,46,50,109,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,99,178,243,139,0,0,32,0,55,52,115,52,55,50,45,49,51,54,48,51,55,45,49,48,49,46,55,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,111,247,100,41,0,0,32,0,55,52,115,52,55,50,45,49,51,54,48,51,55,45,49,48,50,46,53,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,108,236,79,77,0,0,32,0,55,52,115,50,56,55,45,49,51,54,48,51,55,45,49,48,51,46,52,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,8,207,92,108,0,0,32,0,49,51,54,48,52,49,45,53,48,55,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,63,19,132,135,0,0,16,1,49,51,54,48,52,49,45,53,48,56,46,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,227,189,67,40,0,0,16,1,49,51,54,48,51,55,45,50,48,53,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,81,237,153,109,0,0,16,1,49,51,54,48,51,55,45,50,48,54,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,145,173,94,84,0,0,16,1,49,51,54,48,52,49,45,53,48,57,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,38,242,46,251,0,0,16,1,49,51,54,48,52,49,45,53,49,48,46,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,218,232,155,166,0,0,16,1,49,51,54,48,51,55,45,49,50,48,46,49,54,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,204,243,231,110,0,0,16,1,49,51,54,48,51,55,45,49,49,57,46,49,54,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,31,134,25,250,0,0,16,1,49,51,54,48,51,55,45,49,48,52,46,54,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,89,91,42,158,0,0,32,0,49,51,54,48,51,55,45,49,49,49,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,51,15,112,145,0,0,32,0,49,51,54,48,51,55,45,49,49,50,46,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,190,48,147,134,0,0,32,0,49,51,54,48,51,55,45,49,49,51,46,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,168,208,151,212,0,0,32,0,49,51,54,48,51,55,45,49,49,52,46,49,109,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,130,152,239,41,0,0,32,0,49,51,54,48,51,55,45,49,49,53,46,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,152,184,16,149,0,0,32,0,49,51,54,48,51,55,45,49,49,54,46,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,91,172,224,17,0,0,32,0,49,51,54,48,51,55,45,49,49,55,46,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,65,219,165,41,0,0,32,0,49,51,54,48,51,55,45,49,49,56,46,50,109,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,99,178,243,139,0,0,32,0,55,52,115,52,55,50,45,49,51,54,48,51,55,45,49,48,49,46,55,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,111,247,100,41,0,0,32,0,55,52,115,52,55,50,45,49,51,54,48,51,55,45,49,48,50,46,53,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,108,236,79,77,0,0,32,0,55,52,115,50,56,55,45,49,51,54,48,51,55,45,49,48,51,46,52,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,8,207,92,108,0,0,32,0,49,51,54,48,52,49,45,52,48,55,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,64,33,231,205,0,0,16,1,49,51,54,48,52,49,45,52,48,56,46,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,98,175,177,74,0,0,16,1,49,51,54,48,51,55,45,50,48,53,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,81,237,153,109,0,0,16,1,49,51,54,48,51,55,45,50,48,54,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,145,173,94,84,0,0,16,1,49,51,54,48,52,49,45,52,48,57,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,89,20,224,68,0,0,16,1,49,51,54,48,52,49,45,52,49,48,46,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,211,150,141,181,0,0,16,1,49,51,54,48,51,55,45,49,50,48,46,49,54,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,204,243,231,110,0,0,16,1,49,51,54,48,51,55,45,49,49,57,46,49,54,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,31,134,25,250,0,0,16,1,49,51,54,48,51,55,45,49,48,52,46,54,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,89,91,42,158,0,0,32,0,49,51,54,48,51,55,45,49,49,49,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,51,15,112,145,0,0,32,0,49,51,54,48,51,55,45,49,49,50,46,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,190,48,147,134,0,0,32,0,49,51,54,48,51,55,45,49,49,51,46,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,168,208,151,212,0,0,32,0,49,51,54,48,51,55,45,49,49,52,46,49,109,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,130,152,239,41,0,0,32,0,49,51,54,48,51,55,45,49,49,53,46,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,152,184,16,149,0,0,32,0,49,51,54,48,51,55,45,49,49,54,46,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,91,172,224,17,0,0,32,0,49,51,54,48,51,55,45,49,49,55,46,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,65,219,165,41,0,0,32,0,49,51,54,48,51,55,45,49,49,56,46,50,109,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,99,178,243,139,0,0,32,0,55,52,115,52,55,50,45,49,51,54,48,51,55,45,49,48,49,46,55,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,111,247,100,41,0,0,32,0,55,52,115,52,55,50,45,49,51,54,48,51,55,45,49,48,50,46,53,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,108,236,79,77,0,0,32,0,55,52,115,50,56,55,45,49,51,54,48,51,55,45,49,48,51,46,52,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,8,207,92,108,0,0,32,0,184,40,2,0,1,0,0,0,40,39,216,0,248,191,2,0,56,250,6,0,1,0,0,0,32,39,216,0,184,160,2,0,184,164,8,0,1,0,0,0,41,39,216,0,64,246,1,0,88,149,7,0,1,0,0,0,33,39,216,0,136,224,1,0,240,167,7,0,1,0,0,0,44,39,216,0,192,135,2,0,176,163,7,0,1,0,0,0,45,39,216,0,240,108,2,0,208,158,7,0,1,0,0,0,42,39,216,0,96,82,2,0,184,154,7,0,1,0,0,0,43,39,216,0,32,56,2,0,8,96,7,0,1,0,0,0,36,39,216,0,72,198,1,0,48,89,7,0,1,0,0,0,37,39,216,0,24,182,1,0,16,83,7,0,1,0,0,0,34,39,216,0,40,167,1,0,96,79,7,0,1,0,0,0,35,39,216,0,200,149,1,0,88,212,3,0,1,0,0,0,48,38,216,0,40,185,3,0,16,17,8,0,1,0,0,0,47,39,216,0,224,12,8,0,248,5,8,0,9,0,0,0,112,39,216,0,32,58,1,0,144,250,7,0,9,0,0,0,113,39,216,0,32,58,1,0,248,241,7,0,9,0,0,0,114,39,216,0,32,58,1,0,117,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,120,88,129,113,0,0,16,1,117,55,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,162,63,45,226,0,0,16,1,117,55,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,156,188,31,108,0,0,32,0,117,51,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,128,172,148,200,0,0,64,0,117,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,14,155,176,148,0,0,64,0,19,0,0,0,255,255,254,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,40,111,8,0,19,0,0,0,1,1,1,0,96,135,7,0,19,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,19,0,0,0,1,6,4,0,192,255,2,0,19,0,0,0,1,6,6,0,208,75,4,0,19,0,0,0,1,6,2,0,8,49,4,0,19,0,0,0,1,6,0,0,152,21,4,0,0,0,0,0,254,0,16,0,232,24,7,0,19,0,0,0,1,120,24,0,168,241,6,0,19,0,0,0,1,120,56,0,224,19,7,0,19,0,0,0,1,120,16,0,192,204,6,0,19,0,0,0,1,120,88,0,64,15,7,0,19,0,0,0,1,120,48,0,208,201,6,0,19,0,0,0,1,120,8,0,136,198,6,0,19,0,0,0,1,120,0,0,136,195,6,0,19,0,0,0,1,120,40,0,176,190,6,0,19,0,0,0,1,120,80,0,112,185,6,0,19,0,0,0,1,120,120,0,224,9,7,0,19,0,0,0,1,120,32,0,32,179,6,0,19,0,0,0,1,120,72,0,88,239,6,0,19,0,0,0,1,120,64,0,152,173,6,0,19,0,0,0,1,120,112,0,144,3,7,0,19,0,0,0,1,120,104,0,224,166,6,0,19,0,0,0,1,120,96,0,80,236,6,0,0,0,0,0,254,0,2,0,16,227,4,0,19,0,0,0,1,128,128,0,96,135,7,0,19,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,3,2,0,192,255,2,0,20,0,0,0,1,3,0,0,208,75,4,0,20,0,0,0,1,3,3,0,8,49,4,0,20,0,0,0,1,3,1,0,152,21,4,0,0,0,0,0,254,0,2,0,128,156,8,0,20,0,0,0,1,128,128,0,32,182,8,0,20,0,0,0,1,128,0,0,80,251,6,0,52,100,46,49,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,199,27,109,84,0,0,16,1,52,100,46,49,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,195,78,7,241,0,0,16,1,52,100,46,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,143,30,124,56,0,0,16,1,52,100,46,49,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,9,192,65,82,0,0,16,1,52,100,46,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,9,46,27,243,0,0,32,0,52,100,46,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,37,233,48,84,0,0,32,0,52,100,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,81,35,68,159,0,0,32,0,52,100,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,189,50,50,99,0,0,32,0,52,100,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,237,162,191,82,0,0,32,0,52,100,46,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,88,70,186,233,0,0,32,0,52,100,46,49,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,65,65,110,67,0,0,32,0,52,100,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,239,236,124,139,0,0,32,0,52,100,46,49,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,10,153,197,110,0,0,32,0,52,100,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,106,30,26,243,0,0,32,0,112,114,53,51,49,55,46,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,184,80,131,100,0,0,0,8,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,254,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,19,0,0,0,1,15,7,0,80,252,6,0,19,0,0,0,1,15,8,0,16,242,7,0,19,0,0,0,1,15,9,0,104,236,7,0,19,0,0,0,1,15,5,0,192,54,8,0,19,0,0,0,1,15,4,0,56,24,4,0,19,0,0,0,1,15,15,0,128,230,7,0,19,0,0,0,1,15,0,0,128,230,7,0,19,0,0,0,1,15,3,0,176,162,3,0,19,0,0,0,1,15,2,0,24,188,3,0,19,0,0,0,1,15,1,0,72,216,3,0,19,0,0,0,1,15,6,0,120,211,6,0,19,0,0,0,1,15,14,0,184,164,6,0,19,0,0,0,1,15,13,0,80,74,6,0,19,0,0,0,1,15,12,0,192,32,6,0,19,0,0,0,1,15,11,0,192,234,2,0,19,0,0,0,1,15,10,0,32,242,5,0,0,0,0,0,254,0,16,0,160,123,6,0,19,0,0,0,1,240,112,0,80,252,6,0,19,0,0,0,1,240,128,0,16,242,7,0,19,0,0,0,1,240,144,0,104,236,7,0,19,0,0,0,1,240,80,0,192,54,8,0,19,0,0,0,1,240,64,0,56,24,4,0,19,0,0,0,1,240,240,0,128,230,7,0,19,0,0,0,1,240,0,0,128,230,7,0,19,0,0,0,1,240,48,0,176,162,3,0,19,0,0,0,1,240,32,0,24,188,3,0,19,0,0,0,1,240,16,0,72,216,3,0,19,0,0,0,1,240,96,0,120,211,6,0,19,0,0,0,1,240,224,0,184,164,6,0,19,0,0,0,1,240,208,0,80,74,6,0,19,0,0,0,1,240,192,0,192,32,6,0,19,0,0,0,1,240,176,0,192,234,2,0,19,0,0,0,1,240,160,0,32,242,5,0,0,0,0,0,254,0,2,0,200,30,2,0,20,0,0,0,1,1,0,0,120,97,1,0,20,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,6,6,0,8,49,4,0,20,0,0,0,1,6,4,0,152,21,4,0,20,0,0,0,1,6,2,0,72,246,3,0,20,0,0,0,1,6,0,0,112,49,6,0,0,0,0,0,254,0,8,0,64,37,5,0,20,0,0,0,1,56,56,0,192,33,6,0,20,0,0,0,1,56,48,0,160,30,6,0,20,0,0,0,1,56,40,0,208,26,6,0,20,0,0,0,1,56,32,0,232,23,6,0,20,0,0,0,1,56,24,0,48,20,6,0,20,0,0,0,1,56,16,0,248,216,5,0,20,0,0,0,1,56,8,0,248,211,5,0,20,0,0,0,1,56,0,0,120,7,5,0,0,0,0,0,254,0,2,0,72,202,5,0,20,0,0,0,1,64,64,0,80,246,3,0,20,0,0,0,1,64,0,0,112,212,3,0,108,119,117,95,49,49,97,97,46,49,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,183,32,233,115,1,0,16,1,108,119,117,95,49,53,97,97,46,49,52,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,185,36,117,228,1,0,16,1,108,119,117,95,49,48,97,97,46,49,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,148,89,164,190,1,0,16,1,108,119,117,95,49,52,97,97,46,49,51,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,57,35,155,83,1,0,16,1,108,119,45,48,55,46,49,51,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,38,42,37,253,2,0,16,1,108,119,45,48,49,46,57,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,152,242,24,3,4,0,32,0,108,119,45,48,56,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,60,228,168,37,4,0,32,0,108,119,45,48,53,46,57,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,215,47,85,228,4,0,32,0,108,119,45,49,50,46,57,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,43,131,106,142,4,0,32,0,108,119,45,48,50,46,49,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,200,197,230,67,4,0,32,0,108,119,45,48,57,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,173,180,156,137,4,0,32,0,108,119,45,48,54,46,49,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,252,223,158,91,4,0,32,0,108,119,45,49,51,46,49,50,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,245,142,5,142,4,0,32,0,108,119,117,95,48,48,46,49,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,99,42,223,89,3,0,16,0,108,119,45,48,51,117,46,49,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,31,5,125,128,5,0,64,0,108,119,45,48,52,117,46,49,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,142,9,205,230,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,108,119,99,104,114,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,57,76,237,84,0,0,0,8,108,119,105,111,46,49,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,12,185,82,173,0,0,0,8,4,0,0,0,12,0,0,0,0,0,0,0,8,0,0,0,102,122,50,95,115,49,54,99,46,112,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,29,108,209,183,1,0,16,1,102,122,50,95,115,49,54,99,46,112,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,124,72,71,44,1,0,16,1,102,122,50,95,115,49,54,99,46,115,99,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,192,26,59,237,2,0,32,0,102,122,50,95,115,49,54,99,46,115,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,238,111,208,20,3,0,32,0,102,122,50,95,115,49,54,99,46,115,110,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,193,14,211,14,4,0,16,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,64,0,0,0,96,0,0,0,128,0,0,0,160,0,0,0,192,0,0,0,224,0,0,0,0,0,0,0,4,0,0,0,8,0,0,0,12,0,0,0,16,0,0,0,20,0,0,0,24,0,0,0,28,0,0,0,184,40,2,0,1,0,0,0,40,39,216,0,248,191,2,0,56,250,6,0,1,0,0,0,32,39,216,0,184,160,2,0,184,164,8,0,1,0,0,0,41,39,216,0,64,246,1,0,88,149,7,0,1,0,0,0,33,39,216,0,136,224,1,0,240,167,7,0,1,0,0,0,44,39,216,0,192,135,2,0,176,163,7,0,1,0,0,0,47,39,216,0,240,108,2,0,208,158,7,0,1,0,0,0,42,39,216,0,96,82,2,0,184,154,7,0,1,0,0,0,43,39,216,0,32,56,2,0,176,108,2,0,1,0,0,0,25,39,216,0,152,30,2,0,128,98,2,0,1,0,0,0,24,39,216,0,232,10,2,0,8,96,7,0,1,0,0,0,36,39,216,0,72,198,1,0,48,89,7,0,1,0,0,0,46,39,216,0,24,182,1,0,16,83,7,0,1,0,0,0,34,39,216,0,40,167,1,0,96,79,7,0,1,0,0,0,35,39,216,0,200,149,1,0,48,76,7,0,1,0,0,0,37,39,216,0,56,126,1,0,144,72,7,0,1,0,0,0,45,39,216,0,32,101,1,0,88,212,3,0,1,0,0,0,48,38,216,0,40,185,3,0,248,5,8,0,9,0,0,0,112,39,216,0,32,58,1,0,144,250,7,0,9,0,0,0,113,39,216,0,32,58,1,0,248,241,7,0,9,0,0,0,114,39,216,0,32,58,1,0,99,99,106,95,50,51,98,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,14,216,162,226,2,0,16,1,99,99,106,95,50,50,99,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,160,130,155,2,0,16,1,99,99,106,95,50,52,98,46,57,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,178,153,255,132,1,0,16,1,99,99,106,95,50,56,98,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,35,194,206,251,1,0,16,1,99,99,95,48,49,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,186,216,97,114,4,0,32,0,99,99,95,48,50,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,73,249,96,106,4,0,32,0,99,99,95,48,51,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,2,115,99,0,4,0,32,0,99,99,95,48,52,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,207,135,204,4,0,32,0,99,99,95,48,53,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,237,139,113,40,4,0,32,0,99,99,95,48,54,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,58,197,172,212,4,0,32,0,99,99,95,48,55,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,81,241,105,12,4,0,32,0,99,99,95,48,56,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,151,187,158,31,4,0,32,0,99,99,106,95,48,57,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,88,139,142,105,3,0,16,0,99,99,106,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,219,194,226,109,5,0,64,0,99,99,106,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,174,145,144,185,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,99,99,54,51,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,249,240,232,202,0,0,0,8,105,111,98,49,46,49,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,99,99,112,114,103,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,196,37,194,225,0,0,0,8,105,111,99,49,46,105,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,129,32,24,13,0,0,0,8,99,54,51,50,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,112,146,189,15,0,0,0,8,184,40,2,0,1,0,0,0,83,234,148,0,248,191,2,0,56,250,6,0,1,0,0,0,80,234,148,0,184,160,2,0,184,164,8,0,1,0,0,0,212,232,148,0,64,246,1,0,88,149,7,0,1,0,0,0,81,234,148,0,136,224,1,0,240,167,7,0,1,0,0,0,147,233,148,0,192,135,2,0,176,163,7,0,1,0,0,0,146,233,148,0,240,108,2,0,208,158,7,0,1,0,0,0,145,233,148,0,96,82,2,0,184,154,7,0,1,0,0,0,144,233,148,0,32,56,2,0,176,108,2,0,1,0,0,0,151,233,148,0,152,30,2,0,128,98,2,0,1,0,0,0,149,233,148,0,232,10,2,0,8,96,7,0,1,0,0,0,211,232,148,0,72,198,1,0,48,89,7,0,1,0,0,0,210,232,148,0,24,182,1,0,16,83,7,0,1,0,0,0,209,232,148,0,40,167,1,0,96,79,7,0,1,0,0,0,208,232,148,0,200,149,1,0,48,76,7,0,1,0,0,0,215,232,148,0,56,126,1,0,144,72,7,0,1,0,0,0,213,232,148,0,32,101,1,0,88,212,3,0,1,0,0,0,8,222,146,0,40,185,3,0,248,5,8,0,9,0,0,0,248,94,147,0,32,58,1,0,144,250,7,0,9,0,0,0,249,94,147,0,32,58,1,0,248,241,7,0,9,0,0,0,250,94,147,0,32,58,1,0,184,40,2,0,1,0,0,0,137,151,215,0,248,191,2,0,56,250,6,0,1,0,0,0,120,151,215,0,184,160,2,0,184,164,8,0,1,0,0,0,136,151,215,0,64,246,1,0,88,149,7,0,1,0,0,0,121,151,215,0,136,224,1,0,240,167,7,0,1,0,0,0,122,151,215,0,192,135,2,0,176,163,7,0,1,0,0,0,123,151,215,0,240,108,2,0,208,158,7,0,1,0,0,0,125,151,215,0,96,82,2,0,184,154,7,0,1,0,0,0,124,151,215,0,32,56,2,0,176,108,2,0,1,0,0,0,126,151,215,0,152,30,2,0,128,98,2,0,1,0,0,0,127,151,215,0,232,10,2,0,88,212,3,0,1,0,0,0,200,147,215,0,40,185,3,0,16,17,8,0,1,0,0,0,138,151,215,0,224,12,8,0,56,58,1,0,1,0,0,0,139,151,215,0,64,50,1,0,248,5,8,0,9,0,0,0,152,151,215,0,32,58,1,0,144,250,7,0,9,0,0,0,153,151,215,0,32,58,1,0,74,3,0,0,86,41,0,0,80,1,0,0,132,13,0,0,48,19,0,0,242,6,0,0,74,24,0,0,58,10,0,0,166,44,0,0,92,27,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,184,40,2,0,1,0,0,0,31,39,216,0,248,191,2,0,56,250,6,0,1,0,0,0,39,39,216,0,184,160,2,0,184,164,8,0,1,0,0,0,30,39,216,0,64,246,1,0,88,149,7,0,1,0,0,0,38,39,216,0,136,224,1,0,240,167,7,0,1,0,0,0,44,39,216,0,192,135,2,0,176,163,7,0,1,0,0,0,46,39,216,0,240,108,2,0,208,158,7,0,1,0,0,0,29,39,216,0,96,82,2,0,184,154,7,0,1,0,0,0,28,39,216,0,32,56,2,0,176,108,2,0,1,0,0,0,27,39,216,0,152,30,2,0,8,96,7,0,1,0,0,0,24,39,216,0,72,198,1,0,48,89,7,0,1,0,0,0,40,39,216,0,24,182,1,0,16,83,7,0,1,0,0,0,37,39,216,0,40,167,1,0,96,79,7,0,1,0,0,0,36,39,216,0,200,149,1,0,48,76,7,0,1,0,0,0,35,39,216,0,56,126,1,0,88,212,3,0,1,0,0,0,48,38,216,0,40,185,3,0,248,5,8,0,9,0,0,0,112,39,216,0,32,58,1,0,144,250,7,0,9,0,0,0,113,39,216,0,32,58,1,0,248,241,7,0,9,0,0,0,114,39,216,0,32,58,1,0,184,40,2,0,1,0,0,0,208,155,215,0,248,191,2,0,56,250,6,0,1,0,0,0,212,155,215,0,184,160,2,0,184,164,8,0,1,0,0,0,209,155,215,0,64,246,1,0,88,149,7,0,1,0,0,0,213,155,215,0,136,224,1,0,56,210,6,0,1,0,0,0,186,155,215,0,192,135,2,0,24,163,6,0,1,0,0,0,187,155,215,0,240,108,2,0,152,122,6,0,1,0,0,0,184,155,215,0,96,82,2,0,192,72,6,0,1,0,0,0,185,155,215,0,32,56,2,0,88,99,4,0,1,0,0,0,176,155,215,0,144,97,4,0,168,95,4,0,1,0,0,0,177,155,215,0,80,94,4,0,224,90,4,0,1,0,0,0,214,155,215,0,152,30,2,0,120,36,5,0,1,0,0,0,204,155,215,0,232,10,2,0,120,84,4,0,1,0,0,0,200,155,215,0,152,138,8,0,144,80,4,0,1,0,0,0,201,155,215,0,48,119,7,0,208,76,4,0,1,0,0,0,202,155,215,0,112,109,7,0,8,75,4,0,1,0,0,0,203,155,215,0,24,133,7,0,40,71,4,0,1,0,0,0,204,155,215,0,72,120,6,0,168,66,4,0,1,0,0,0,205,155,215,0,88,119,7,0,248,61,4,0,1,0,0,0,206,155,215,0,240,202,2,0,160,54,4,0,1,0,0,0,207,155,215,0,216,199,2,0,248,46,4,0,1,0,0,0,196,155,215,0,0,195,2,0,160,42,4,0,1,0,0,0,197,155,215,0,248,39,4,0,64,38,4,0,1,0,0,0,198,155,215,0,48,35,4,0,176,223,1,0,1,0,0,0,190,155,215,0,72,198,1,0,192,209,1,0,1,0,0,0,191,155,215,0,24,182,1,0,24,198,1,0,1,0,0,0,188,155,215,0,40,167,1,0,120,189,1,0,1,0,0,0,189,155,215,0,200,149,1,0,200,32,4,0,1,0,0,0,178,155,215,0,176,29,4,0,184,26,4,0,1,0,0,0,179,155,215,0,176,22,4,0,112,20,4,0,1,0,0,0,215,155,215,0,56,126,1,0,128,149,1,0,1,0,0,0,172,155,215,0,32,101,1,0,80,16,4,0,1,0,0,0,168,155,215,0,96,32,8,0,8,14,4,0,1,0,0,0,169,155,215,0,16,68,7,0,8,12,4,0,1,0,0,0,170,155,215,0,240,58,7,0,80,8,4,0,1,0,0,0,171,155,215,0,200,42,1,0,40,1,4,0,1,0,0,0,172,155,215,0,16,178,2,0,240,247,3,0,1,0,0,0,173,155,215,0,136,174,2,0,152,241,3,0,1,0,0,0,174,155,215,0,48,173,2,0,200,235,3,0,1,0,0,0,175,155,215,0,0,171,2,0,160,230,3,0,1,0,0,0,164,155,215,0,56,168,2,0,168,223,3,0,1,0,0,0,165,155,215,0,24,219,3,0,24,214,3,0,1,0,0,0,166,155,215,0,56,211,3,0,16,17,8,0,1,0,0,0,211,155,215,0,224,12,8,0,32,77,1,0,1,0,0,0,210,155,215,0,216,70,1,0,88,212,3,0,1,0,0,0,200,154,215,0,40,185,3,0,248,5,8,0,9,0,0,0,0,156,215,0,32,58,1,0,144,250,7,0,9,0,0,0,1,156,215,0,32,58,1,0,168,86,7,0,1,0,0,0,251,190,145,0,248,191,2,0,24,38,7,0,1,0,0,0,253,190,145,0,184,160,2,0,56,210,6,0,1,0,0,0,208,250,146,0,192,135,2,0,24,163,6,0,1,0,0,0,209,250,146,0,240,108,2,0,152,122,6,0,1,0,0,0,210,250,146,0,96,82,2,0,192,72,6,0,1,0,0,0,211,250,146,0,32,56,2,0,200,110,3,0,1,0,0,0,212,250,146,0,152,30,2,0,120,89,3,0,1,0,0,0,213,250,146,0,232,10,2,0,40,246,1,0,1,0,0,0,252,190,145,0,64,246,1,0,144,236,1,0,1,0,0,0,254,190,145,0,136,224,1,0,176,223,1,0,1,0,0,0,168,242,146,0,72,198,1,0,192,209,1,0,1,0,0,0,169,242,146,0,24,182,1,0,24,198,1,0,1,0,0,0,170,242,146,0,40,167,1,0,120,189,1,0,1,0,0,0,171,242,146,0,200,149,1,0,224,22,1,0,1,0,0,0,172,242,146,0,56,126,1,0,160,14,1,0,1,0,0,0,173,242,146,0,32,101,1,0,88,212,3,0,1,0,0,0,144,215,146,0,40,185,3,0,32,77,1,0,1,0,0,0,248,190,145,0,216,70,1,0,72,65,1,0,9,0,0,0,42,223,146,0,32,58,1,0,48,50,1,0,9,0,0,0,43,223,146,0,32,58,1,0,224,41,1,0,9,0,0,0,45,223,146,0,32,58,1,0,50,52,97,99,45,48,52,46,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,14,133,155,238,1,0,16,1,50,52,97,100,45,48,52,46,51,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,239,46,124,5,1,0,16,1,50,52,97,98,45,48,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,170,248,68,30,2,0,16,1,50,52,97,57,45,48,46,52,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,143,240,63,112,3,0,64,0,50,52,106,56,45,48,46,52,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,135,132,19,97,3,0,64,0,50,52,97,97,45,48,46,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,64,186,18,203,4,0,32,0,99,57,53,49,46,49,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,240,209,118,250,5,0,32,0,50,52,106,52,45,48,46,49,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,163,137,165,196,5,0,32,0,50,52,106,53,45,48,46,49,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,54,164,188,214,5,0,32,0,99,57,53,48,46,49,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0])
.concat([61,112,165,204,5,0,32,0,50,52,106,50,45,48,46,49,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,118,27,220,5,0,32,0,50,52,106,51,45,48,46,49,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,67,45,161,59,5,0,32,0,50,52,106,55,45,48,46,49,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,158,144,161,224,6,0,32,0,50,52,106,54,45,48,46,49,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,248,46,147,119,6,0,32,0,48,56,49,119,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,50,113,229,206,1,0,16,1,48,56,49,98,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,155,77,96,76,2,0,16,1,48,56,49,97,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,169,119,199,180,3,0,32,0,48,56,49,97,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,217,200,42,39,3,0,32,0,48,56,49,97,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,164,154,75,70,4,0,32,0,48,56,49,97,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,89,55,23,78,4,0,32,0,48,56,49,97,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,128,109,254,233,4,0,32,0,48,56,49,97,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,154,178,34,138,4,0,32,0,48,56,49,97,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,234,186,182,20,5,0,64,0,118,101,110,100,101,116,116,97,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,48,78,172,251,0,0,0,8,102,108,48,50,45,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,84,190,89,108,1,0,16,1,102,108,48,48,45,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,244,190,248,105,1,0,16,1,102,108,95,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,68,40,189,128,1,0,16,1,102,108,95,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,133,176,116,148,1,0,16,1,102,106,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,155,223,174,233,2,0,16,1,102,108,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,231,249,137,96,3,0,32,0,102,108,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,10,41,137,57,3,0,32,0,102,108,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,250,27,85,65,3,0,32,0,102,108,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,92,250,103,220,3,0,32,0,118,116,109,97,97,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,27,163,23,194,4,0,32,0,118,116,109,97,97,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,142,249,31,9,4,0,32,0,118,116,109,97,97,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,204,233,19,183,5,0,32,0,118,116,109,97,97,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,129,191,48,26,5,0,32,0,102,106,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,53,162,152,110,6,0,64,0,102,106,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,181,162,205,57,7,0,64,0,102,106,45,50,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,66,87,4,101,8,0,0,8,112,97,108,49,54,108,56,97,46,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,143,142,116,238,9,0,0,8,112,97,108,49,54,108,56,98,46,49,51,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,218,59,161,109,9,0,0,8,112,97,108,49,54,108,56,98,46,49,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,152,224,169,98,9,0,0,8,112,97,108,49,54,108,56,98,46,49,52,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,170,104,103,3,9,0,0,8,112,97,108,49,54,108,56,98,46,49,52,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,206,31,66,191,9,0,0,8,118,100,107,45,49,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,89,28,208,193,1,0,16,1,106,97,108,101,99,111,50,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,46,77,14,23,1,0,16,1,118,100,107,45,52,46,49,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,240,68,165,235,2,0,16,1,118,100,107,45,51,46,50,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,27,124,84,90,3,0,32,0,118,100,107,45,48,49,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,190,36,90,25,4,0,32,0,118,100,107,45,48,55,46,50,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,6,31,212,66,5,0,32,0,118,100,107,45,48,54,46,50,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,34,71,213,5,0,32,0,118,100,107,45,48,52,46,50,45,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,71,5,115,10,5,0,32,0,118,100,107,45,48,53,46,51,45,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,109,69,186,5,0,32,0,118,100,107,45,48,50,46,49,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,116,50,16,178,6,0,64,0,118,100,107,45,48,51,46,49,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,211,118,23,99,7,0,64,0,105,99,49,48,48,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,151,28,237,152,0,0,0,8,105,99,49,48,49,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,108,184,219,207,0,0,0,8,168,86,7,0,1,0,0,0,192,191,145,0,248,191,2,0,24,38,7,0,1,0,0,0,194,191,145,0,184,160,2,0,56,210,6,0,1,0,0,0,152,254,146,0,192,135,2,0,24,163,6,0,1,0,0,0,153,254,146,0,240,108,2,0,152,122,6,0,1,0,0,0,154,254,146,0,96,82,2,0,192,72,6,0,1,0,0,0,155,254,146,0,32,56,2,0,200,110,3,0,1,0,0,0,156,254,146,0,152,30,2,0,40,246,1,0,1,0,0,0,193,191,145,0,64,246,1,0,144,236,1,0,1,0,0,0,195,191,145,0,136,224,1,0,176,223,1,0,1,0,0,0,56,246,146,0,72,198,1,0,192,209,1,0,1,0,0,0,57,246,146,0,24,182,1,0,24,198,1,0,1,0,0,0,58,246,146,0,40,167,1,0,120,189,1,0,1,0,0,0,59,246,146,0,200,149,1,0,224,22,1,0,1,0,0,0,60,246,146,0,56,126,1,0,168,132,8,0,1,0,0,0,199,191,145,0,144,189,1,0,72,126,8,0,1,0,0,0,135,239,146,0,144,189,1,0,192,122,8,0,1,0,0,0,128,239,146,0,208,174,1,0,40,116,8,0,1,0,0,0,129,239,146,0,48,160,1,0,72,110,8,0,1,0,0,0,130,239,146,0,160,140,1,0,184,102,8,0,1,0,0,0,131,239,146,0,56,112,1,0,248,67,8,0,1,0,0,0,132,239,146,0,32,92,1,0,88,212,3,0,1,0,0,0,104,218,146,0,40,185,3,0,72,65,1,0,9,0,0,0,92,224,146,0,32,58,1,0,48,50,1,0,9,0,0,0,93,224,146,0,32,58,1,0,168,86,7,0,1,0,0,0,27,191,145,0,248,191,2,0,24,38,7,0,1,0,0,0,29,191,145,0,184,160,2,0,56,210,6,0,1,0,0,0,0,251,146,0,192,135,2,0,24,163,6,0,1,0,0,0,1,251,146,0,240,108,2,0,152,122,6,0,1,0,0,0,2,251,146,0,96,82,2,0,192,72,6,0,1,0,0,0,3,251,146,0,32,56,2,0,200,110,3,0,1,0,0,0,4,251,146,0,152,30,2,0,120,89,3,0,1,0,0,0,5,251,146,0,232,10,2,0,120,74,3,0,1,0,0,0,6,251,146,0,152,138,8,0,40,246,1,0,1,0,0,0,28,191,145,0,64,246,1,0,144,236,1,0,1,0,0,0,30,191,145,0,136,224,1,0,176,223,1,0,1,0,0,0,216,242,146,0,72,198,1,0,192,209,1,0,1,0,0,0,217,242,146,0,24,182,1,0,24,198,1,0,1,0,0,0,218,242,146,0,40,167,1,0,120,189,1,0,1,0,0,0,219,242,146,0,200,149,1,0,224,22,1,0,1,0,0,0,220,242,146,0,56,126,1,0,160,14,1,0,1,0,0,0,221,242,146,0,32,101,1,0,176,9,1,0,1,0,0,0,222,242,146,0,96,32,8,0,88,212,3,0,1,0,0,0,184,215,146,0,40,185,3,0,32,77,1,0,1,0,0,0,24,191,145,0,216,70,1,0,72,65,1,0,9,0,0,0,75,223,146,0,32,58,1,0,48,50,1,0,9,0,0,0,76,223,146,0,32,58,1,0,224,41,1,0,9,0,0,0,77,223,146,0,32,58,1,0,0,0,0,0,0,0,0,0,72,23,4,0,1,0,0,0,85,0,147,0,248,191,2,0,56,210,6,0,1,0,0,0,80,0,147,0,192,135,2,0,152,122,6,0,1,0,0,0,81,0,147,0,96,82,2,0,192,72,6,0,1,0,0,0,82,0,147,0,32,56,2,0,24,163,6,0,1,0,0,0,83,0,147,0,240,108,2,0,200,110,3,0,1,0,0,0,189,247,146,0,152,30,2,0,120,89,3,0,1,0,0,0,190,247,146,0,232,10,2,0,176,223,1,0,1,0,0,0,184,247,146,0,72,198,1,0,24,198,1,0,1,0,0,0,185,247,146,0,40,167,1,0,120,189,1,0,1,0,0,0,186,247,146,0,200,149,1,0,192,209,1,0,1,0,0,0,187,247,146,0,24,182,1,0,200,110,3,0,1,0,0,0,188,247,146,0,56,126,1,0,120,89,3,0,1,0,0,0,87,0,147,0,32,101,1,0,88,212,3,0,1,0,0,0,128,219,146,0,40,185,3,0,232,75,4,0,1,0,0,0,87,0,147,0,216,70,1,0,64,23,5,0,9,0,0,0,201,5,147,0,32,58,1,0,104,20,5,0,9,0,0,0,202,5,147,0,32,58,1,0,216,16,5,0,9,0,0,0,200,5,147,0,32,58,1,0,118,101,105,103,117,101,115,32,45,32,116,97,99,116,105,99,97,108,32,103,108,97,100,105,97,116,111,114,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,183,79,209,153,0,0,16,1,116,105,109,101,32,99,114,117,105,115,101,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,96,150,195,2,0,0,16,1,115,117,112,101,114,32,118,111,108,108,101,121,98,97,108,108,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,179,64,80,36,0,0,16,1,115,117,112,101,114,32,115,116,97,114,32,115,111,108,100,105,101,114,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,111,72,41,219,0,0,16,1,115,112,108,97,116,116,101,114,104,111,117,115,101,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,79,167,12,208,0,0,16,1,115,105,108,101,110,116,32,100,101,98,117,103,103,101,114,115,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,102,93,126,250,0,0,16,1,112,115,121,99,104,111,115,105,115,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,36,8,193,108,0,0,16,1,112,97,114,97,115,111,108,32,115,116,97,114,115,32,45,32,116,104,101,32,115,116,111,114,121,32,111,102,32,98,117,98,98,108,101,32,98,111,98,98,108,101,32,105,105,105,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,18,130,69,230,0,0,16,1,112,97,110,122,97,32,107,105,99,107,32,98,111,120,105,110,103,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,233,224,128,169,0,0,16,1,112,97,99,45,108,97,110,100,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,205,12,227,214,0,0,16,1,110,105,110,106,97,32,115,112,105,114,105,116,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,193,241,138,222,0,0,16,1,110,105,103,104,116,32,99,114,101,97,116,117,114,101,115,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,27,118,89,193,0,0,16,1,108,101,103,101,110,100,97,114,121,32,97,120,101,32,105,105,44,32,116,104,101,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,145,191,14,34,0,0,16,1,106,46,106,46,32,38,32,106,101,102,102,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,39,81,28,224,0,0,16,1,103,117,110,98,111,97,116,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,142,181,112,243,0,0,16,1,111,114,100,101,114,32,111,102,32,116,104,101,32,103,114,105,102,102,111,110,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,96,252,224,250,0,0,16,1,100,114,97,103,111,110,32,115,112,105,114,105,116,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,140,20,111,8,0,0,16,1,100,114,111,112,46,111,102,102,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,50,123,162,254,0,0,16,1,99,104,101,119,32,109,97,110,32,102,117,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,154,62,209,140,0,0,16,1,116,97,105,116,111,32,99,104,97,115,101,32,104,46,113,46,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,76,37,152,146,0,0,16,1,98,111,120,121,98,111,121,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,19,226,91,96,0,0,16,1,98,111,109,98,101,114,109,97,110,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,42,60,111,95,0,0,16,1,168,86,7,0,1,0,0,0,206,251,146,0,248,191,2,0,24,38,7,0,1,0,0,0,204,251,146,0,184,160,2,0,24,163,6,0,1,0,0,0,200,251,146,0,240,108,2,0,152,122,6,0,1,0,0,0,201,251,146,0,96,82,2,0,192,72,6,0,1,0,0,0,202,251,146,0,32,56,2,0,200,110,3,0,1,0,0,0,203,251,146,0,152,30,2,0,40,246,1,0,1,0,0,0,207,251,146,0,64,246,1,0,48,245,6,0,1,0,0,0,205,251,146,0,136,224,1,0,192,209,1,0,1,0,0,0,144,243,146,0,24,182,1,0,24,198,1,0,1,0,0,0,145,243,146,0,40,167,1,0,120,189,1,0,1,0,0,0,146,243,146,0,200,149,1,0,224,22,1,0,1,0,0,0,147,243,146,0,56,126,1,0,88,212,3,0,1,0,0,0,128,216,146,0,40,185,3,0,248,5,8,0,9,0,0,0,224,3,147,0,32,58,1,0,168,86,7,0,1,0,0,0,19,191,145,0,248,191,2,0,24,38,7,0,1,0,0,0,21,191,145,0,184,160,2,0,56,210,6,0,1,0,0,0,248,250,146,0,192,135,2,0,24,163,6,0,1,0,0,0,249,250,146,0,240,108,2,0,152,122,6,0,1,0,0,0,250,250,146,0,96,82,2,0,192,72,6,0,1,0,0,0,251,250,146,0,32,56,2,0,200,110,3,0,1,0,0,0,252,250,146,0,152,30,2,0,120,89,3,0,1,0,0,0,253,250,146,0,232,10,2,0,120,74,3,0,1,0,0,0,254,250,146,0,152,138,8,0,40,246,1,0,1,0,0,0,20,191,145,0,64,246,1,0,144,236,1,0,1,0,0,0,22,191,145,0,136,224,1,0,176,223,1,0,1,0,0,0,208,242,146,0,72,198,1,0,192,209,1,0,1,0,0,0,209,242,146,0,24,182,1,0,24,198,1,0,1,0,0,0,210,242,146,0,40,167,1,0,120,189,1,0,1,0,0,0,211,242,146,0,200,149,1,0,224,22,1,0,1,0,0,0,212,242,146,0,56,126,1,0,160,14,1,0,1,0,0,0,213,242,146,0,32,101,1,0,176,9,1,0,1,0,0,0,214,242,146,0,96,32,8,0,88,212,3,0,1,0,0,0,176,215,146,0,40,185,3,0,32,77,1,0,1,0,0,0,16,191,145,0,216,70,1,0,72,65,1,0,9,0,0,0,67,223,146,0,32,58,1,0,48,50,1,0,9,0,0,0,68,223,146,0,32,58,1,0,224,41,1,0,9,0,0,0,69,223,146,0,32,58,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,115,112,45,52,120,46,115,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,131,2,89,180,0,0,16,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,115,102,105,120,46,115,102,105,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,253,12,234,194,0,0,32,2,48,48,48,45,108,111,46,108,111,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,242,207,134,90,0,0,0,3,168,86,7,0,1,0,0,0,192,191,145,0,248,191,2,0,24,38,7,0,1,0,0,0,194,191,145,0,184,160,2,0,56,210,6,0,1,0,0,0,152,254,146,0,192,135,2,0,24,163,6,0,1,0,0,0,153,254,146,0,240,108,2,0,152,122,6,0,1,0,0,0,154,254,146,0,96,82,2,0,192,72,6,0,1,0,0,0,155,254,146,0,32,56,2,0,200,110,3,0,1,0,0,0,156,254,146,0,152,30,2,0,120,89,3,0,1,0,0,0,157,254,146,0,232,10,2,0,120,74,3,0,1,0,0,0,158,254,146,0,152,138,8,0,40,246,1,0,1,0,0,0,193,191,145,0,64,246,1,0,144,236,1,0,1,0,0,0,195,191,145,0,136,224,1,0,176,223,1,0,1,0,0,0,56,246,146,0,72,198,1,0,192,209,1,0,1,0,0,0,57,246,146,0,24,182,1,0,24,198,1,0,1,0,0,0,58,246,146,0,40,167,1,0,120,189,1,0,1,0,0,0,59,246,146,0,200,149,1,0,224,22,1,0,1,0,0,0,60,246,146,0,56,126,1,0,160,14,1,0,1,0,0,0,61,246,146,0,32,101,1,0,176,9,1,0,1,0,0,0,62,246,146,0,96,32,8,0,88,212,3,0,1,0,0,0,104,218,146,0,40,185,3,0,72,65,1,0,9,0,0,0,91,224,146,0,32,58,1,0,48,50,1,0,9,0,0,0,92,224,146,0,32,58,1,0,255,255,255,255,0,0,0,0,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,168,86,7,0,1,0,0,0,51,191,145,0,248,191,2,0,24,38,7,0,1,0,0,0,53,191,145,0,184,160,2,0,56,210,6,0,1,0,0,0,32,251,146,0,192,135,2,0,24,163,6,0,1,0,0,0,33,251,146,0,240,108,2,0,152,122,6,0,1,0,0,0,34,251,146,0,96,82,2,0,192,72,6,0,1,0,0,0,35,251,146,0,32,56,2,0,200,110,3,0,1,0,0,0,36,251,146,0,152,30,2,0,120,89,3,0,1,0,0,0,37,251,146,0,232,10,2,0,40,246,1,0,1,0,0,0,52,191,145,0,64,246,1,0,144,236,1,0,1,0,0,0,54,191,145,0,136,224,1,0,176,223,1,0,1,0,0,0,40,238,146,0,72,198,1,0,192,209,1,0,1,0,0,0,41,238,146,0,24,182,1,0,24,198,1,0,1,0,0,0,42,238,146,0,40,167,1,0,120,189,1,0,1,0,0,0,43,238,146,0,200,149,1,0,224,22,1,0,1,0,0,0,44,238,146,0,56,126,1,0,160,14,1,0,1,0,0,0,45,238,146,0,32,101,1,0,72,126,8,0,1,0,0,0,46,238,146,0,144,189,1,0,192,122,8,0,1,0,0,0,40,238,146,0,208,174,1,0,40,116,8,0,1,0,0,0,41,238,146,0,48,160,1,0,72,110,8,0,1,0,0,0,42,238,146,0,160,140,1,0,184,102,8,0,1,0,0,0,43,238,146,0,56,112,1,0,248,67,8,0,1,0,0,0,44,238,146,0,32,92,1,0,136,64,8,0,1,0,0,0,45,238,146,0,64,77,1,0,160,19,8,0,1,0,0,0,206,236,146,0,32,245,8,0,248,16,8,0,1,0,0,0,200,236,146,0,32,231,8,0,192,12,8,0,1,0,0,0,201,236,146,0,88,214,8,0,224,5,8,0,1,0,0,0,202,236,146,0,224,202,8,0,144,1,8,0,1,0,0,0,203,236,146,0,72,193,8,0,176,222,7,0,1,0,0,0,204,236,146,0,144,180,8,0,176,218,7,0,1,0,0,0,205,236,146,0,208,164,8,0,88,212,3,0,1,0,0,0,216,215,146,0,40,185,3,0,32,77,1,0,1,0,0,0,48,191,145,0,216,70,1,0,72,65,1,0,9,0,0,0,99,223,146,0,32,58,1,0,48,50,1,0,9,0,0,0,100,223,146,0,32,58,1,0,224,41,1,0,9,0,0,0,101,223,146,0,32,58,1,0,48,55,50,45,103,48,50,46,49,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,214,225,12,88,1,0,16,1,48,55,50,45,112,48,49,46,49,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,234,234,206,7,1,0,16,1,48,55,50,45,48,49,51,46,49,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,90,16,129,135,1,0,16,1,48,55,50,45,48,49,50,46,49,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,137,146,79,36,1,0,16,1,48,55,50,45,103,48,51,46,54,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,12,133,193,118,2,0,16,1,48,55,50,45,98,48,55,46,49,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,16,201,30,186,3,0,32,0,48,55,50,45,98,48,54,46,49,54,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,171,188,43,207,3,0,32,0,48,55,50,45,98,48,56,46,51,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,173,0,229,125,4,0,32,0,48,55,50,45,98,48,57,46,56,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,147,80,8,170,4,0,32,0,48,55,50,45,98,49,48,46,49,50,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,83,189,125,87,4,0,32,0,48,55,50,45,98,49,49,46,49,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,93,176,250,85,4,0,32,0,48,55,50,45,100,48,53,46,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,59,167,151,19,5,0,64,0,48,55,50,45,100,48,52,46,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,19,128,119,120,5,0,64,0,115,105,109,112,115,111,110,115,50,112,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,48,78,172,251,0,0,0,8,168,86,7,0,1,0,0,0,131,191,145,0,248,191,2,0,24,38,7,0,1,0,0,0,133,191,145,0,184,160,2,0,56,210,6,0,1,0,0,0,152,251,146,0,192,135,2,0,24,163,6,0,1,0,0,0,153,251,146,0,240,108,2,0,152,122,6,0,1,0,0,0,154,251,146,0,96,82,2,0,192,72,6,0,1,0,0,0,155,251,146,0,32,56,2,0,200,110,3,0,1,0,0,0,156,251,146,0,152,30,2,0,120,89,3,0,1,0,0,0,157,251,146,0,232,10,2,0,120,74,3,0,1,0,0,0,158,251,146,0,152,138,8,0,40,246,1,0,1,0,0,0,132,191,145,0,64,246,1,0,144,236,1,0,1,0,0,0,134,191,145,0,136,224,1,0,176,223,1,0,1,0,0,0,104,243,146,0,72,198,1,0,192,209,1,0,1,0,0,0,105,243,146,0,24,182,1,0,24,198,1,0,1,0,0,0,106,243,146,0,40,167,1,0,120,189,1,0,1,0,0,0,107,243,146,0,200,149,1,0,224,22,1,0,1,0,0,0,108,243,146,0,56,126,1,0,160,14,1,0,1,0,0,0,109,243,146,0,32,101,1,0,176,9,1,0,1,0,0,0,110,243,146,0,96,32,8,0,88,212,3,0,1,0,0,0,80,216,146,0,40,185,3,0,32,77,1,0,1,0,0,0,128,191,145,0,216,70,1,0,72,65,1,0,9,0,0,0,179,223,146,0,32,58,1,0,48,50,1,0,9,0,0,0,180,223,146,0,32,58,1,0,224,41,1,0,9,0,0,0,181,223,146,0,32,58,1,0,51,50,106,49,50,45,48,49,46,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,29,190,253,56,0,0,16,1,51,50,106,49,51,45,48,49,46,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,241,246,29,110,0,0,16,1,51,50,106,49,52,45,48,49,46,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,96,251,227,137,0,0,16,1,51,50,106,49,53,45,48,49,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,74,168,195,61,0,0,16,1,51,50,106,49,48,45,48,46,52,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,117,244,218,101,0,0,16,1,51,50,106,49,49,45,48,46,53,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,147,217,82,114,0,0,32,0,51,50,106,52,45,48,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,182,165,190,30,0,0,32,0,51,50,106,53,45,48,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,181,38,0,96,0,0,32,0,51,50,106,54,45,48,46,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,190,142,222,108,0,0,32,0,51,50,106,55,45,48,46,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,34,121,179,188,0,0,32,0,51,50,106,56,45,48,46,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,246,235,27,32,0,0,32,0,51,50,106,49,45,48,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,64,167,204,241,0,0,32,0,51,50,106,50,45,48,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,62,172,95,0,0,32,0,51,50,106,51,45,48,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,94,146,151,210,0,0,32,0,51,50,106,57,45,48,46,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,129,30,0,22,0,0,64,0,168,86,7,0,1,0,0,0,96,190,145,0,248,191,2,0,24,38,7,0,1,0,0,0,15,253,146,0,184,160,2,0,192,72,6,0,1,0,0,0,8,253,146,0,32,56,2,0,152,122,6,0,1,0,0,0,9,253,146,0,96,82,2,0,56,210,6,0,1,0,0,0,10,253,146,0,192,135,2,0,24,163,6,0,1,0,0,0,11,253,146,0,240,108,2,0,200,110,3,0,1,0,0,0,12,253,146,0,152,30,2,0,120,89,3,0,1,0,0,0,13,253,146,0,232,10,2,0,120,74,3,0,1,0,0,0,14,253,146,0,152,138,8,0,192,61,3,0,1,0,0,0,144,191,145,0,48,119,7,0,120,194,6,0,1,0,0,0,145,191,145,0,112,109,7,0,96,189,6,0,1,0,0,0,146,191,145,0,24,133,7,0,40,246,1,0,1,0,0,0,97,190,145,0,64,246,1,0,144,236,1,0,1,0,0,0,191,244,146,0,136,224,1,0,120,189,1,0,1,0,0,0,184,244,146,0,200,149,1,0,24,198,1,0,1,0,0,0,185,244,146,0,40,167,1,0,176,223,1,0,1,0,0,0,186,244,146,0,72,198,1,0,192,209,1,0,1,0,0,0,187,244,146,0,24,182,1,0,224,22,1,0,1,0,0,0,188,244,146,0,56,126,1,0,160,14,1,0,1,0,0,0,189,244,146,0,32,101,1,0,176,9,1,0,1,0,0,0,190,244,146,0,96,32,8,0,200,3,1,0,1,0,0,0,147,191,145,0,16,68,7,0,208,183,6,0,1,0,0,0,148,191,145,0,240,58,7,0,200,177,6,0,1,0,0,0,149,191,145,0,200,42,1,0,88,212,3,0,1,0,0,0,96,217,146,0,40,185,3,0,72,65,1,0,9,0,0,0,249,223,146,0,32,58,1,0,48,50,1,0,9,0,0,0,251,223,146,0,32,58,1,0,224,41,1,0,9,0,0,0,253,223,146,0,32,58,1,0,168,169,1,0,9,0,0,0,255,223,146,0,32,58,1,0,50,55,50,45,112,49,99,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,77,121,145,146,1,0,16,1,50,55,50,45,112,50,99,46,115,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,216,125,26,250,1,0,16,1,50,55,50,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,26,102,151,79,3,0,32,0,50,55,50,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,79,218,175,163,3,0,32,0,50,55,50,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,2,117,60,140,3,0,32,0,50,55,50,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,226,226,213,50,3,0,32,0,50,55,50,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,188,133,224,108,3,0,32,0,50,55,50,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,142,220,200,5,3,0,32,0,50,55,50,45,99,55,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,66,183,23,20,3,0,32,0,50,55,50,45,99,56,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,205,115,151,212,3,0,32,0,50,55,50,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,64,191,238,173,4,0,16,1,50,55,50,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,39,65,169,118,5,0,64,0,50,55,50,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,241,7,165,75,5,0,64,0,115,109,112,114,103,46,117,52,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,17,79,35,0,0,16,1,98,112,115,109,46,117,52,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,128,78,8,50,0,0,16,1,98,112,115,109,57,52,53,97,46,117,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,72,229,141,67,0,0,16,1,98,112,115,109,46,117,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,186,165,67,162,0,0,32,0,98,112,115,109,46,117,55,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,172,164,121,81,0,0,32,0,98,112,115,109,46,117,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,131,95,177,185,0,0,32,0,98,112,115,109,46,117,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,157,103,0,143,0,0,32,0,98,112,115,109,46,117,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,99,123,190,134,0,0,32,0,98,112,115,109,46,117,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,59,168,187,224,0,0,32,0,98,112,115,109,46,117,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,172,191,227,161,0,0,32,0,98,112,115,109,46,117,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,82,75,1,106,0,0,32,0,98,112,115,109,46,117,54,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,192,104,36,153,0,0,32,0,98,112,115,109,46,117,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,181,183,15,246,0,0,32,0,98,112,115,109,46,117,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,28,211,89,101,0,0,32,0,98,112,115,109,46,117,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,180,86,122,213,0,0,32,0,98,112,115,109,46,117,52,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,209,78,142,73,0,0,64,0,98,112,115,109,46,117,52,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,185,1,41,15,0,0,64,0,115,97,105,108,111,114,109,110,95,117,115,97,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,227,171,21,57,0,0,16,1,115,109,112,114,103,46,117,52,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,17,79,35,0,0,16,1,98,112,115,109,46,117,52,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,128,78,8,50,0,0,16,1,98,112,115,109,57,52,53,97,46,117,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,72,229,141,67,0,0,16,1,98,112,115,109,46,117,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,186,165,67,162,0,0,32,0,98,112,115,109,46,117,55,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,172,164,121,81,0,0,32,0,98,112,115,109,46,117,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,131,95,177,185,0,0,32,0,98,112,115,109,46,117,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,157,103,0,143,0,0,32,0,98,112,115,109,46,117,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,99,123,190,134,0,0,32,0,98,112,115,109,46,117,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,59,168,187,224,0,0,32,0,98,112,115,109,46,117,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,172,191,227,161,0,0,32,0,98,112,115,109,46,117,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,82,75,1,106,0,0,32,0,98,112,115,109,46,117,54,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,192,104,36,153,0,0,32,0,98,112,115,109,46,117,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,181,183,15,246,0,0,32,0,98,112,115,109,46,117,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,28,211,89,101,0,0,32,0,98,112,115,109,46,117,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,180,86,122,213,0,0,32,0,98,112,115,109,46,117,52,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,209,78,142,73,0,0,64,0,98,112,115,109,46,117,52,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,185,1,41,15,0,0,64,0,115,97,105,108,111,114,109,110,95,116,97,105,119,97,110,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,42,140,126,108,0,0,16,1,115,109,112,114,103,46,117,52,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,17,79,35,0,0,16,1,98,112,115,109,46,117,52,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,128,78,8,50,0,0,16,1,98,112,115,109,57,52,53,97,46,117,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,72,229,141,67,0,0,16,1,98,112,115,109,46,117,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,186,165,67,162,0,0,32,0,98,112,115,109,46,117,55,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,172,164,121,81,0,0,32,0,98,112,115,109,46,117,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,131,95,177,185,0,0,32,0,98,112,115,109,46,117,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,157,103,0,143,0,0,32,0,98,112,115,109,46,117,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,99,123,190,134,0,0,32,0,98,112,115,109,46,117,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,59,168,187,224,0,0,32,0,98,112,115,109,46,117,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,172,191,227,161,0,0,32,0,98,112,115,109,46,117,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,82,75,1,106,0,0,32,0,98,112,115,109,46,117,54,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,192,104,36,153,0,0,32,0,98,112,115,109,46,117,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,181,183,15,246,0,0,32,0,98,112,115,109,46,117,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,28,211,89,101,0,0,32,0,98,112,115,109,46,117,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,180,86,122,213,0,0,32,0,98,112,115,109,46,117,52,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,209,78,142,73,0,0,64,0,98,112,115,109,46,117,52,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,185,1,41,15,0,0,64,0,115,97,105,108,111,114,109,110,95,107,111,114,101,97,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,152,227,125,14,0,0,16,1,115,109,112,114,103,46,117,52,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,17,79,35,0,0,16,1,98,112,115,109,46,117,52,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,128,78,8,50,0,0,16,1,98,112,115,109,57,52,53,97,46,117,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,72,229,141,67,0,0,16,1,98,112,115,109,46,117,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,186,165,67,162,0,0,32,0,98,112,115,109,46,117,55,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,172,164,121,81,0,0,32,0,98,112,115,109,46,117,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,131,95,177,185,0,0,32,0,98,112,115,109,46,117,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,157,103,0,143,0,0,32,0,98,112,115,109,46,117,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,99,123,190,134,0,0,32,0,98,112,115,109,46,117,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,59,168,187,224,0,0,32,0,98,112,115,109,46,117,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,172,191,227,161,0,0,32,0,98,112,115,109,46,117,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,82,75,1,106,0,0,32,0,98,112,115,109,46,117,54,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,192,104,36,153,0,0,32,0,98,112,115,109,46,117,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,181,183,15,246,0,0,32,0,98,112,115,109,46,117,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,28,211,89,101,0,0,32,0,98,112,115,109,46,117,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,180,86,122,213,0,0,32,0,98,112,115,109,46,117,52,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,209,78,142,73,0,0,64,0,98,112,115,109,46,117,52,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,185,1,41,15,0,0,64,0,115,97,105,108,111,114,109,110,95,106,97,112,97,110,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,10,195,3,234,0,0,16,1,115,109,112,114,103,46,117,52,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,17,79,35,0,0,16,1,98,112,115,109,46,117,52,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,128,78,8,50,0,0,16,1,98,112,115,109,57,52,53,97,46,117,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,72,229,141,67,0,0,16,1,98,112,115,109,46,117,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,186,165,67,162,0,0,32,0,98,112,115,109,46,117,55,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,172,164,121,81,0,0,32,0,98,112,115,109,46,117,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,131,95,177,185,0,0,32,0,98,112,115,109,46,117,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,157,103,0,143,0,0,32,0,98,112,115,109,46,117,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,99,123,190,134,0,0,32,0,98,112,115,109,46,117,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,59,168,187,224,0,0,32,0,98,112,115,109,46,117,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,172,191,227,161,0,0,32,0,98,112,115,109,46,117,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,82,75,1,106,0,0,32,0,98,112,115,109,46,117,54,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,192,104,36,153,0,0,32,0,98,112,115,109,46,117,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,181,183,15,246,0,0,32,0,98,112,115,109,46,117,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,28,211,89,101,0,0,32,0,98,112,115,109,46,117,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,180,86,122,213,0,0,32,0,98,112,115,109,46,117,52,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,209,78,142,73,0,0,64,0,98,112,115,109,46,117,52,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,185,1,41,15,0,0,64,0,115,97,105,108,111,114,109,110,95,104,111,110,103,107,111,110,103,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,116,200,36,77,0,0,16,1,168,86,7,0,1,0,0,0,240,253,146,0,248,191,2,0,24,38,7,0,1,0,0,0,239,253,146,0,184,160,2,0,56,210,6,0,1,0,0,0,232,253,146,0,192,135,2,0,24,163,6,0,1,0,0,0,233,253,146,0,240,108,2,0,152,122,6,0,1,0,0,0,234,253,146,0,96,82,2,0,192,72,6,0,1,0,0,0,235,253,146,0,32,56,2,0,200,110,3,0,1,0,0,0,236,253,146,0,152,30,2,0,120,89,3,0,1,0,0,0,237,253,146,0,232,10,2,0,120,74,3,0,1,0,0,0,238,253,146,0,152,138,8,0,40,246,1,0,1,0,0,0,160,245,146,0,64,246,1,0,144,236,1,0,1,0,0,0,159,245,146,0,136,224,1,0,176,223,1,0,1,0,0,0,152,245,146,0,72,198,1,0,192,209,1,0,1,0,0,0,153,245,146,0,24,182,1,0,24,198,1,0,1,0,0,0,154,245,146,0,40,167,1,0,120,189,1,0,1,0,0,0,155,245,146,0,200,149,1,0,224,22,1,0,1,0,0,0,156,245,146,0,56,126,1,0,160,14,1,0,1,0,0,0,157,245,146,0,32,101,1,0,176,9,1,0,1,0,0,0,158,245,146,0,96,32,8,0,88,212,3,0,1,0,0,0,248,217,146,0,40,185,3,0,32,77,1,0,1,0,0,0,241,253,146,0,216,70,1,0,16,17,8,0,1,0,0,0,161,245,146,0,224,12,8,0,184,40,2,0,1,0,0,0,85,0,147,0,248,191,2,0,184,164,8,0,1,0,0,0,86,0,147,0,64,246,1,0,56,250,6,0,1,0,0,0,189,247,146,0,184,160,2,0,88,149,7,0,1,0,0,0,190,247,146,0,136,224,1,0,56,210,6,0,1,0,0,0,80,0,147,0,192,135,2,0,152,122,6,0,1,0,0,0,81,0,147,0,96,82,2,0,192,72,6,0,1,0,0,0,82,0,147,0,32,56,2,0,24,163,6,0,1,0,0,0,83,0,147,0,240,108,2,0,176,223,1,0,1,0,0,0,184,247,146,0,72,198,1,0,24,198,1,0,1,0,0,0,185,247,146,0,40,167,1,0,120,189,1,0,1,0,0,0,186,247,146,0,200,149,1,0,192,209,1,0,1,0,0,0,187,247,146,0,24,182,1,0,56,58,1,0,1,0,0,0,87,0,147,0,216,70,1,0,88,212,3,0,1,0,0,0,128,219,146,0,40,185,3,0,64,23,5,0,9,0,0,0,202,5,147,0,32,58,1,0,104,20,5,0,9,0,0,0,203,5,147,0,32,58,1,0,216,16,5,0,9,0,0,0,200,5,147,0,32,58,1,0,88,12,5,0,9,0,0,0,201,5,147,0,32,58,1,0,97,102,101,103,97,95,52,46,117,49,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,42,104,230,230,1,0,16,1,97,102,101,103,97,95,53,46,117,49,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,214,46,170,47,1,0,16,1,97,102,101,103,97,95,49,46,117,57,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,142,242,140,93,2,0,16,1,97,102,101,103,97,95,51,46,117,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,135,134,96,100,3,0,32,0,97,102,101,103,97,95,97,102,49,45,98,50,46,117,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,194,136,133,214,4,0,32,0,97,102,101,103,97,95,97,102,49,45,98,49,46,117,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,168,0,178,248,4,0,32,0,97,102,101,103,97,95,97,102,49,45,115,112,46,117,99,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,133,73,77,125,5,0,32,0,97,102,101,103,97,95,50,46,117,57,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,51,206,17,233,6,0,64,0,114,101,100,101,97,114,116,104,95,101,117,114,111,46,50,57,102,52,48,48,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,54,243,224,2,0,0,0,3,114,101,100,101,97,114,116,104,40,95,95,57,54,49,48,50,51,41,45,115,105,109,109,49,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,70,195,186,101,0,0,16,1,114,101,100,101,97,114,116,104,40,95,95,57,54,49,48,50,51,41,45,115,105,109,109,49,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,174,74,236,168,0,0,16,1,114,101,100,101,97,114,116,104,40,95,95,57,54,49,48,50,51,41,45,115,105,109,109,49,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,149,137,175,44,0,0,16,1,114,101,100,101,97,114,116,104,40,95,95,57,54,49,48,50,51,41,45,115,105,109,109,49,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,29,194,235,19,0,0,16,1,114,101,100,101,97,114,116,104,45,115,105,109,109,51,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,197,12,53,131,0,0,32,0,114,101,100,101,97,114,116,104,45,115,105,109,109,51,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,230,77,115,86,0,0,32,0,114,101,100,101,97,114,116,104,45,115,105,109,109,51,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,241,160,14,128,0,0,32,0,114,101,100,101,97,114,116,104,45,115,105,109,109,51,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,108,20,233,151,0,0,32,0,114,101,100,101,97,114,116,104,45,115,105,109,109,51,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,72,214,177,12,0,0,32,0,114,101,100,101,97,114,116,104,45,115,105,109,109,51,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,240,153,16,122,0,0,32,0,114,101,100,101,97,114,116,104,45,115,105,109,109,51,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,84,143,255,174,0,0,32,0,114,101,100,101,97,114,116,104,45,115,105,109,109,51,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,208,172,112,247,0,0,32,0,114,101,100,101,97,114,116,104,45,115,105,109,109,52,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,242,86,30,48,0,0,32,0,114,101,100,101,97,114,116,104,45,115,105,109,109,52,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,3,225,72,32,0,0,32,0,114,101,100,101,97,114,116,104,45,115,105,109,109,52,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,85,52,67,201,0,0,32,0,114,101,100,101,97,114,116,104,45,115,105,109,109,52,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,168,113,33,192,0,0,32,0,114,101,100,101,97,114,116,104,45,115,105,109,109,52,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,118,242,219,45,0,0,32,0,114,101,100,101,97,114,116,104,45,115,105,109,109,52,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,166,32,168,254,0,0,32,0,114,101,100,101,97,114,116,104,45,115,105,109,109,52,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,241,141,82,199,0,0,32,0,114,101,100,101,97,114,116,104,45,115,105,109,109,52,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,59,207,73,36,0,0,32,0,114,101,100,101,97,114,116,104,45,115,105,109,109,53,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,185,81,68,66,0,0,32,0,114,101,100,101,97,114,116,104,45,115,105,109,109,53,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,107,181,140,155,0,0,32,0,168,86,7,0,1,0,0,0,224,252,146,0,248,191,2,0,24,38,7,0,1,0,0,0,223,252,146,0,184,160,2,0,56,210,6,0,1,0,0,0,216,252,146,0,192,135,2,0,24,163,6,0,1,0,0,0,217,252,146,0,240,108,2,0,152,122,6,0,1,0,0,0,218,252,146,0,96,82,2,0,192,72,6,0,1,0,0,0,219,252,146,0,32,56,2,0,200,110,3,0,1,0,0,0,220,252,146,0,152,30,2,0,120,89,3,0,1,0,0,0,221,252,146,0,232,10,2,0,120,74,3,0,1,0,0,0,222,252,146,0,152,138,8,0,192,61,3,0,1,0,0,0,226,252,146,0,48,119,7,0,40,246,1,0,1,0,0,0,144,244,146,0,64,246,1,0,144,236,1,0,1,0,0,0,143,244,146,0,136,224,1,0,176,223,1,0,1,0,0,0,136,244,146,0,72,198,1,0,192,209,1,0,1,0,0,0,137,244,146,0,24,182,1,0,24,198,1,0,1,0,0,0,138,244,146,0,40,167,1,0,120,189,1,0,1,0,0,0,139,244,146,0,200,149,1,0,224,22,1,0,1,0,0,0,140,244,146,0,56,126,1,0,160,14,1,0,1,0,0,0,141,244,146,0,32,101,1,0,176,9,1,0,1,0,0,0,142,244,146,0,96,32,8,0,200,3,1,0,1,0,0,0,146,244,146,0,16,68,7,0,88,212,3,0,1,0,0,0,56,217,146,0,40,185,3,0,32,77,1,0,1,0,0,0,225,252,146,0,216,70,1,0,16,17,8,0,1,0,0,0,145,244,146,0,224,12,8,0,168,86,7,0,1,0,0,0,184,191,145,0,248,191,2,0,24,38,7,0,1,0,0,0,187,191,145,0,184,160,2,0,56,210,6,0,1,0,0,0,107,254,146,0,192,135,2,0,24,163,6,0,1,0,0,0,106,254,146,0,240,108,2,0,152,122,6,0,1,0,0,0,105,254,146,0,96,82,2,0,192,72,6,0,1,0,0,0,104,254,146,0,32,56,2,0,200,110,3,0,1,0,0,0,108,254,146,0,152,30,2,0,120,89,3,0,1,0,0,0,109,254,146,0,232,10,2,0,120,74,3,0,1,0,0,0,110,254,146,0,152,138,8,0,192,61,3,0,1,0,0,0,111,254,146,0,48,119,7,0,40,246,1,0,1,0,0,0,185,191,145,0,64,246,1,0,144,236,1,0,1,0,0,0,188,191,145,0,136,224,1,0,176,223,1,0,1,0,0,0,27,246,146,0,72,198,1,0,192,209,1,0,1,0,0,0,26,246,146,0,24,182,1,0,24,198,1,0,1,0,0,0,25,246,146,0,40,167,1,0,120,189,1,0,1,0,0,0,24,246,146,0,200,149,1,0,224,22,1,0,1,0,0,0,28,246,146,0,56,126,1,0,160,14,1,0,1,0,0,0,29,246,146,0,32,101,1,0,176,9,1,0,1,0,0,0,30,246,146,0,96,32,8,0,200,3,1,0,1,0,0,0,31,246,146,0,16,68,7,0,88,212,3,0,1,0,0,0,72,218,146,0,40,185,3,0,32,77,1,0,1,0,0,0,189,191,145,0,216,70,1,0,16,17,8,0,1,0,0,0,186,191,145,0,224,12,8,0,72,65,1,0,9,0,0,0,84,224,146,0,32,58,1,0,48,50,1,0,9,0,0,0,86,224,146,0,32,58,1,0,122,105,112,97,110,103,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,161,183,170,103,0,0,16,1,122,101,114,111,32,52,32,99,104,97,109,112,32,40,106,97,112,97,110,41,32,40,118,49,46,53,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,47,46,127,183,0,0,16,1,99,114,111,115,115,32,119,105,98,101,114,32,45,32,99,121,98,101,114,32,99,111,109,98,97,116,32,112,111,108,105,99,101,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,208,123,249,45,0,0,16,1,119,111,114,108,100,32,98,101,97,99,104,32,118,111,108,108,101,121,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,48,5,133,190,0,0,16,1,109,97,106,105,110,32,101,105,121,117,117,32,100,101,110,32,119,97,116,97,114,117,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,170,53,137,47,0,0,16,1,116,114,105,99,107,121,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,143,47,234,58,0,0,16,1,116,104,117,110,100,101,114,32,98,108,97,100,101,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,9,232,195,221,0,0,16,1,115,117,115,97,110,111,111,32,100,101,110,115,101,116,115,117,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,252,216,115,207,0,0,16,1,115,117,112,101,114,32,109,111,109,111,116,97,114,111,117,32,100,101,110,116,101,116,115,117,32,105,105,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,252,35,192,43,0,0,16,1,115,107,119,101,101,107,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,159,156,83,77,0,0,16,1,115,104,105,114,121,111,117,32,115,101,110,115,101,110,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,223,15,154,70,0,0,16,1,114,121,117,107,121,117,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,111,137,230,145,0,0,16,1,114,111,99,107,45,111,110,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,18,83,214,47,0,0,16,1,114,97,105,100,101,110,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,242,41,8,133,0,0,16,1,113,117,105,122,32,116,111,117,107,111,117,32,115,104,97,115,104,105,110,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,109,133,230,242,0,0,16,1,112,114,111,32,121,97,107,121,117,117,32,119,111,114,108,100,32,115,116,97,100,105,117,109,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,169,137,224,52,0,0,16,1,112,111,119,101,114,32,108,101,97,103,117,101,32,118,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,41,224,97,139,0,0,16,1,112,111,119,101,114,32,108,101,97,103,117,101,32,105,118,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,99,53,204,48,0,0,16,1,112,111,119,101,114,32,108,101,97,103,117,101,32,105,105,105,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,32,178,164,138,0,0,16,1,112,111,119,101,114,32,108,101,97,103,117,101,32,105,105,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,137,250,253,197,0,0,16,1,112,111,119,101,114,32,100,114,105,102,116,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,233,246,224,37,0,0,16,1,112,99,32,103,101,110,106,105,110,32,45,32,112,105,116,104,101,99,97,110,116,104,114,111,112,117,115,32,99,111,109,112,117,116,101,114,117,114,117,115,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,85,205,181,44,0,0,16,1,111,117,116,32,114,117,110,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,35,242,3,226,0,0,16,1,111,114,100,121,110,101,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,182,92,86,140,0,0,16,1,111,112,101,114,97,116,105,111,110,32,119,111,108,102,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,135,143,137,255,0,0,16,1,110,101,99,114,111,115,32,110,111,32,121,111,117,115,97,105,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,254,220,15,251,0,0,16,1,109,114,46,32,104,101,108,105,32,110,111,32,100,97,105,98,111,117,107,101,110,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,144,34,185,44,0,0,16,1,109,97,104,106,111,110,103,32,115,104,105,107,121,97,107,117,32,114,101,116,115,117,100,101,110,32,45,32,109,97,104,106,111,110,103,32,119,97,114,115,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,234,170,52,108,0,0,16,1,107,117,110,103,32,102,117,44,32,116,104,101,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,6,201,82,181,0,0,16,1,107,121,117,117,107,121,111,107,117,32,116,105,103,101,114,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,21,147,80,9,0,0,16,1,106,105,110,109,117,32,100,101,110,115,104,111,117,32,40,106,97,112,97,110,41,32,91,97,93,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,249,14,36,132,0,0,16,1,104,105,116,32,116,104,101,32,105,99,101,32,45,32,118,104,108,32,116,104,101,32,111,102,102,105,99,105,97,108,32,118,105,100,101,111,32,104,111,99,107,101,121,32,108,101,97,103,117,101,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,200,96,203,122,0,0,16,1,104,97,116,114,105,115,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,83,223,231,68,0,0,16,1,103,117,110,104,101,100,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,126,77,125,161,0,0,16,1,103,111,109,111,108,97,32,115,112,101,101,100,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,253,58,53,154,0,0,16,1,103,101,110,112,101,105,32,116,111,117,109,97,100,101,110,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,130,198,38,185,0,0,16,1,101,110,101,114,103,121,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,33,255,104,202,0,0,16,1,100,114,97,103,111,110,32,115,97,98,101,114,32,45,32,97,102,116,101,114,32,115,116,111,114,121,32,111,102,32,100,114,97,103,111,110,32,115,112,105,114,105,116,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,156,132,25,50,0,0,16,1,116,111,119,101,114,32,111,102,32,100,114,117,97,103,97,44,32,116,104,101,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,196,11,224,114,0,0,16,1,100,111,114,97,101,109,111,110,32,45,32,109,101,105,107,121,117,117,32,100,97,105,32,115,97,107,117,115,101,110,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,7,10,118,220,0,0,16,1,100,111,117,98,108,101,32,100,117,110,103,101,111,110,115,32,45,32,119,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,57,123,8,134,0,0,16,1,98,117,115,111,117,32,107,101,105,106,105,32,45,32,99,121,98,101,114,32,99,114,111,115,115,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,202,80,194,208,0,0,16,1,99,104,105,98,105,32,109,97,114,117,107,111,32,99,104,97,110,32,45,32,113,117,105,122,32,100,101,32,112,105,105,104,121,97,114,97,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,128,211,30,149,0,0,16,1,99,97,100,97,115,104,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,95,216,192,141,0,0,16,1,98,108,111,100,105,97,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,205,139,149,0,0,16,1,98,101,32,98,97,108,108,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,153,242,57,228,0,0,16,1,98,97,116,109,97,110,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,178,183,107,16,0,0,16,1,116,115,117,114,117,32,116,101,114,117,104,105,116,111,32,110,111,32,106,105,115,115,101,110,32,107,97,98,117,115,104,105,107,105,32,98,97,105,32,98,97,105,32,103,97,109,101,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,229,18,1,247,0,0,16,1,97,114,109,101,100,32,102,111,114,109,97,116,105,111,110,32,102,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,253,135,239,32,0,0,16,1,97,110,107,111,107,117,32,100,101,110,115,101,116,115,117,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,251,6,204,202,0,0,16,1,97,108,105,101,110,32,99,114,117,115,104,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,225,244,237,96,0,0,16,1,50,49,32,101,109,111,110,32,45,32,109,101,122,97,115,101,32,104,111,116,101,108,32,111,117,33,33,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,96,70,97,115,0,0,16,1,112,108,49,95,49,46,56,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,148,251,41,247,1,0,16,1,112,108,49,95,50,46,56,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,111,235,102,92,1,0,16,1,112,108,49,95,51,46,56,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,57,167,159,170,1,0,16,1,112,108,49,95,52,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,144,90,137,43,1,0,16,1,112,108,49,95,53,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,98,246,122,1,0,16,1,112,108,49,95,54,46,56,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,169,89,30,176,1,0,16,1,112,108,49,95,55,46,51,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0])
.concat([174,236,91,140,2,0,16,1,99,117,115,54,48,45,54,48,97,49,46,109,99,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,42,168,110,7,2,0,16,1,112,108,49,95,49,50,46,54,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,206,251,89,193,3,0,32,0,112,108,49,95,49,51,46,54,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,174,217,94,108,4,0,32,0,112,108,49,95,57,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,135,138,118,128,5,0,32,0,112,108,49,95,56,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,109,228,32,43,5,0,32,0,112,108,49,95,49,48,46,55,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,232,96,38,198,5,0,32,0,112,108,49,95,49,49,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,216,117,151,197,5,0,32,0,112,108,49,45,50,46,49,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,222,133,40,71,6,0,32,0,112,108,49,45,49,46,49,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,175,189,142,167,6,0,32,0,112,108,49,45,53,46,53,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,18,231,126,75,6,0,32,0,112,108,49,45,52,46,52,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,24,228,123,58,6,0,32,0,112,108,49,45,51,46,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,168,141,85,128,6,0,32,0,168,86,7,0,1,0,0,0,178,241,146,0,248,191,2,0,24,38,7,0,1,0,0,0,176,241,146,0,184,160,2,0,56,210,6,0,1,0,0,0,147,2,147,0,192,135,2,0,24,163,6,0,1,0,0,0,146,2,147,0,240,108,2,0,152,122,6,0,1,0,0,0,145,2,147,0,96,82,2,0,192,72,6,0,1,0,0,0,144,2,147,0,32,56,2,0,200,110,3,0,1,0,0,0,151,2,147,0,152,30,2,0,120,89,3,0,1,0,0,0,150,2,147,0,232,10,2,0,40,246,1,0,1,0,0,0,179,241,146,0,64,246,1,0,144,236,1,0,1,0,0,0,177,241,146,0,136,224,1,0,176,223,1,0,1,0,0,0,211,249,146,0,72,198,1,0,192,209,1,0,1,0,0,0,210,249,146,0,24,182,1,0,24,198,1,0,1,0,0,0,209,249,146,0,40,167,1,0,120,189,1,0,1,0,0,0,208,249,146,0,200,149,1,0,224,22,1,0,1,0,0,0,215,249,146,0,56,126,1,0,160,14,1,0,1,0,0,0,214,249,146,0,32,101,1,0,168,132,8,0,1,0,0,0,197,237,146,0,232,209,1,0,72,126,8,0,1,0,0,0,196,237,146,0,144,189,1,0,192,122,8,0,1,0,0,0,195,237,146,0,208,174,1,0,40,116,8,0,1,0,0,0,194,237,146,0,48,160,1,0,72,110,8,0,1,0,0,0,193,237,146,0,160,140,1,0,184,102,8,0,1,0,0,0,192,237,146,0,56,112,1,0,248,67,8,0,1,0,0,0,199,237,146,0,32,92,1,0,136,64,8,0,1,0,0,0,198,237,146,0,64,77,1,0,232,23,8,0,1,0,0,0,189,236,146,0,104,195,5,0,160,19,8,0,1,0,0,0,188,236,146,0,32,245,8,0,248,16,8,0,1,0,0,0,187,236,146,0,32,231,8,0,192,12,8,0,1,0,0,0,186,236,146,0,88,214,8,0,224,5,8,0,1,0,0,0,185,236,146,0,224,202,8,0,144,1,8,0,1,0,0,0,184,236,146,0,72,193,8,0,176,222,7,0,1,0,0,0,191,236,146,0,144,180,8,0,176,218,7,0,1,0,0,0,190,236,146,0,208,164,8,0,88,212,3,0,1,0,0,0,0,222,146,0,40,185,3,0,16,17,8,0,1,0,0,0,180,241,146,0,224,12,8,0,72,65,1,0,9,0,0,0,152,7,147,0,32,58,1,0,48,50,1,0,9,0,0,0,153,7,147,0,32,58,1,0,168,86,7,0,1,0,0,0,202,191,145,0,248,191,2,0,24,38,7,0,1,0,0,0,200,191,145,0,184,160,2,0,56,210,6,0,1,0,0,0,163,2,147,0,192,135,2,0,24,163,6,0,1,0,0,0,162,2,147,0,240,108,2,0,152,122,6,0,1,0,0,0,161,2,147,0,96,82,2,0,192,72,6,0,1,0,0,0,160,2,147,0,32,56,2,0,200,110,3,0,1,0,0,0,167,2,147,0,152,30,2,0,120,89,3,0,1,0,0,0,166,2,147,0,232,10,2,0,40,246,1,0,1,0,0,0,203,191,145,0,64,246,1,0,144,236,1,0,1,0,0,0,201,191,145,0,136,224,1,0,176,223,1,0,1,0,0,0,227,249,146,0,72,198,1,0,192,209,1,0,1,0,0,0,226,249,146,0,24,182,1,0,24,198,1,0,1,0,0,0,225,249,146,0,40,167,1,0,120,189,1,0,1,0,0,0,224,249,146,0,200,149,1,0,224,22,1,0,1,0,0,0,231,249,146,0,56,126,1,0,160,14,1,0,1,0,0,0,230,249,146,0,32,101,1,0,168,132,8,0,1,0,0,0,189,241,146,0,232,209,1,0,72,126,8,0,1,0,0,0,188,241,146,0,144,189,1,0,192,122,8,0,1,0,0,0,187,241,146,0,208,174,1,0,40,116,8,0,1,0,0,0,186,241,146,0,48,160,1,0,72,110,8,0,1,0,0,0,185,241,146,0,160,140,1,0,184,102,8,0,1,0,0,0,184,241,146,0,56,112,1,0,248,67,8,0,1,0,0,0,191,241,146,0,32,92,1,0,136,64,8,0,1,0,0,0,190,241,146,0,64,77,1,0,232,23,8,0,1,0,0,0,205,237,146,0,104,195,5,0,160,19,8,0,1,0,0,0,204,237,146,0,32,245,8,0,248,16,8,0,1,0,0,0,203,237,146,0,32,231,8,0,192,12,8,0,1,0,0,0,202,237,146,0,88,214,8,0,224,5,8,0,1,0,0,0,201,237,146,0,224,202,8,0,144,1,8,0,1,0,0,0,200,237,146,0,72,193,8,0,176,222,7,0,1,0,0,0,207,237,146,0,144,180,8,0,176,218,7,0,1,0,0,0,206,237,146,0,208,164,8,0,88,212,3,0,1,0,0,0,24,222,146,0,40,185,3,0,16,17,8,0,1,0,0,0,204,191,145,0,224,12,8,0,72,65,1,0,9,0,0,0,53,225,146,0,32,58,1,0,48,50,1,0,9,0,0,0,54,225,146,0,32,58,1,0,224,41,1,0,9,0,0,0,55,225,146,0,32,58,1,0,168,86,7,0,1,0,0,0,202,191,145,0,248,191,2,0,24,38,7,0,1,0,0,0,200,191,145,0,184,160,2,0,56,210,6,0,1,0,0,0,163,2,147,0,192,135,2,0,24,163,6,0,1,0,0,0,162,2,147,0,240,108,2,0,152,122,6,0,1,0,0,0,161,2,147,0,96,82,2,0,192,72,6,0,1,0,0,0,160,2,147,0,32,56,2,0,200,110,3,0,1,0,0,0,167,2,147,0,152,30,2,0,120,89,3,0,1,0,0,0,166,2,147,0,232,10,2,0,40,246,1,0,1,0,0,0,203,191,145,0,64,246,1,0,144,236,1,0,1,0,0,0,201,191,145,0,136,224,1,0,176,223,1,0,1,0,0,0,227,249,146,0,72,198,1,0,192,209,1,0,1,0,0,0,226,249,146,0,24,182,1,0,24,198,1,0,1,0,0,0,225,249,146,0,40,167,1,0,120,189,1,0,1,0,0,0,224,249,146,0,200,149,1,0,224,22,1,0,1,0,0,0,231,249,146,0,56,126,1,0,160,14,1,0,1,0,0,0,230,249,146,0,32,101,1,0,168,132,8,0,1,0,0,0,189,241,146,0,232,209,1,0,72,126,8,0,1,0,0,0,188,241,146,0,144,189,1,0,192,122,8,0,1,0,0,0,187,241,146,0,208,174,1,0,40,116,8,0,1,0,0,0,186,241,146,0,48,160,1,0,72,110,8,0,1,0,0,0,185,241,146,0,160,140,1,0,184,102,8,0,1,0,0,0,184,241,146,0,56,112,1,0,248,67,8,0,1,0,0,0,191,241,146,0,32,92,1,0,136,64,8,0,1,0,0,0,190,241,146,0,64,77,1,0,88,212,3,0,1,0,0,0,24,222,146,0,40,185,3,0,16,17,8,0,1,0,0,0,204,191,145,0,224,12,8,0,72,65,1,0,9,0,0,0,53,225,146,0,32,58,1,0,48,50,1,0,9,0,0,0,54,225,146,0,32,58,1,0,224,41,1,0,9,0,0,0,55,225,146,0,32,58,1,0,168,86,7,0,1,0,0,0,178,241,146,0,248,191,2,0,24,38,7,0,1,0,0,0,176,241,146,0,184,160,2,0,56,210,6,0,1,0,0,0,147,2,147,0,192,135,2,0,24,163,6,0,1,0,0,0,146,2,147,0,240,108,2,0,152,122,6,0,1,0,0,0,145,2,147,0,96,82,2,0,192,72,6,0,1,0,0,0,144,2,147,0,32,56,2,0,200,110,3,0,1,0,0,0,151,2,147,0,152,30,2,0,120,89,3,0,1,0,0,0,150,2,147,0,232,10,2,0,40,246,1,0,1,0,0,0,179,241,146,0,64,246,1,0,144,236,1,0,1,0,0,0,177,241,146,0,136,224,1,0,176,223,1,0,1,0,0,0,211,249,146,0,72,198,1,0,192,209,1,0,1,0,0,0,210,249,146,0,24,182,1,0,24,198,1,0,1,0,0,0,209,249,146,0,40,167,1,0,120,189,1,0,1,0,0,0,208,249,146,0,200,149,1,0,224,22,1,0,1,0,0,0,215,249,146,0,56,126,1,0,160,14,1,0,1,0,0,0,214,249,146,0,32,101,1,0,88,212,3,0,1,0,0,0,0,222,146,0,40,185,3,0,16,17,8,0,1,0,0,0,180,241,146,0,224,12,8,0,72,65,1,0,9,0,0,0,152,7,147,0,32,58,1,0,48,50,1,0,9,0,0,0,153,7,147,0,32,58,1,0,168,86,7,0,1,0,0,0,202,191,145,0,248,191,2,0,24,38,7,0,1,0,0,0,200,191,145,0,184,160,2,0,56,210,6,0,1,0,0,0,163,2,147,0,192,135,2,0,24,163,6,0,1,0,0,0,162,2,147,0,240,108,2,0,152,122,6,0,1,0,0,0,161,2,147,0,96,82,2,0,192,72,6,0,1,0,0,0,160,2,147,0,32,56,2,0,200,110,3,0,1,0,0,0,167,2,147,0,152,30,2,0,120,89,3,0,1,0,0,0,166,2,147,0,232,10,2,0,40,246,1,0,1,0,0,0,203,191,145,0,64,246,1,0,144,236,1,0,1,0,0,0,201,191,145,0,136,224,1,0,176,223,1,0,1,0,0,0,227,249,146,0,72,198,1,0,192,209,1,0,1,0,0,0,226,249,146,0,24,182,1,0,24,198,1,0,1,0,0,0,225,249,146,0,40,167,1,0,120,189,1,0,1,0,0,0,224,249,146,0,200,149,1,0,224,22,1,0,1,0,0,0,231,249,146,0,56,126,1,0,160,14,1,0,1,0,0,0,230,249,146,0,32,101,1,0,88,212,3,0,1,0,0,0,24,222,146,0,40,185,3,0,16,17,8,0,1,0,0,0,204,191,145,0,224,12,8,0,72,65,1,0,9,0,0,0,53,225,146,0,32,58,1,0,48,50,1,0,9,0,0,0,54,225,146,0,32,58,1,0,224,41,1,0,9,0,0,0,55,225,146,0,32,58,1,0,140,0,0,0,192,0,0,0,198,0,0,0,4,4,0,0,118,0,0,0,70,3,0,0,100,0,0,0,214,2,0,0,46,2,0,0,212,1,0,0,38,2,0,0,220,1,0,0,70,0,0,0,12,4,0,0,60,0,0,0,84,2,0,0,200,0,0,0,118,2,0,0,112,3,0,0,116,2,0,0,190,2,0,0,2,1,0,0,222,0,0,0,224,1,0,0,242,0,0,0,144,3,0,0,60,2,0,0,18,4,0,0,184,2,0,0,206,0,0,0,50,0,0,0,240,3,0,0,242,3,0,0,202,2,0,0,94,1,0,0,38,0,0,0,204,0,0,0,200,3,0,0,18,1,0,0,118,1,0,0,172,3,0,0,8,1,0,0,84,3,0,0,218,0,0,0,130,3,0,0,182,0,0,0,14,1,0,0,134,3,0,0,28,2,0,0,30,3,0,0,20,4,0,0,62,2,0,0,156,0,0,0,188,3,0,0,6,2,0,0,30,2,0,0,58,0,0,0,76,2,0,0,64,3,0,0,14,2,0,0,120,1,0,0,52,1,0,0,10,4,0,0,232,3,0,0,80,2,0,0,176,2,0,0,46,0,0,0,176,1,0,0,150,2,0,0,106,1,0,0,28,1,0,0,8,0,0,0,160,1,0,0,142,3,0,0,178,2,0,0,236,1,0,0,78,2,0,0,122,0,0,0,174,0,0,0,36,3,0,0,210,3,0,0,52,3,0,0,140,1,0,0,178,3,0,0,30,1,0,0,252,1,0,0,148,0,0,0,202,3,0,0,2,2,0,0,66,0,0,0,216,1,0,0,30,0,0,0,102,0,0,0,4,3,0,0,10,1,0,0,28,3,0,0,218,2,0,0,174,1,0,0,232,2,0,0,186,0,0,0,22,3,0,0,132,3,0,0,162,3,0,0,216,0,0,0,74,3,0,0,54,2,0,0,168,3,0,0,196,2,0,0,184,1,0,0,90,3,0,0,168,1,0,0,88,3,0,0,152,0,0,0,224,0,0,0,216,2,0,0,86,0,0,0,238,0,0,0,124,2,0,0,66,3,0,0,144,1,0,0,6,3,0,0,252,0,0,0,26,3,0,0,112,2,0,0,240,1,0,0,188,1,0,0,234,1,0,0,86,1,0,0,72,1,0,0,186,3,0,0,62,1,0,0,246,1,0,0,254,3,0,0,16,4,0,0,226,1,0,0,64,0,0,0,92,0,0,0,154,1,0,0,4,1,0,0,190,0,0,0,14,3,0,0,162,1,0,0,90,1,0,0,6,0,0,0,48,2,0,0,20,3,0,0,194,0,0,0,192,1,0,0,58,3,0,0,66,1,0,0,64,2,0,0,114,0,0,0,48,0,0,0,54,1,0,0,102,2,0,0,164,3,0,0,202,0,0,0,38,1,0,0,240,0,0,0,168,2,0,0,180,3,0,0,56,1,0,0,110,1,0,0,164,1,0,0,16,0,0,0,98,2,0,0,174,3,0,0,76,3,0,0,40,3,0,0,14,0,0,0,204,2,0,0,20,0,0,0,246,3,0,0,50,2,0,0,214,3,0,0,148,2,0,0,116,3,0,0,166,1,0,0,194,2,0,0,176,3,0,0,164,2,0,0,26,1,0,0,68,0,0,0,4,0,0,0,220,3,0,0,152,3,0,0,162,0,0,0,250,3,0,0,90,2,0,0,142,0,0,0,12,2,0,0,108,2,0,0,226,0,0,0,124,0,0,0,78,1,0,0,166,3,0,0,166,2,0,0,238,2,0,0,236,0,0,0,110,2,0,0,214,0,0,0,242,2,0,0,12,1,0,0,108,3,0,0,6,1,0,0,82,1,0,0,36,1,0,0,120,0,0,0,146,1,0,0,64,1,0,0,248,3,0,0,88,2,0,0,26,4,0,0,228,0,0,0,158,0,0,0,240,2,0,0,78,0,0,0,54,0,0,0,236,3,0,0,202,1,0,0,78,3,0,0,42,1,0,0,158,3,0,0,34,1,0,0,142,2,0,0,230,1,0,0,192,3,0,0,8,3,0,0,82,2,0,0,126,3,0,0,154,0,0,0,214,1,0,0,20,1,0,0,92,2,0,0,72,2,0,0,60,3,0,0,224,3,0,0,44,3,0,0,22,0,0,0,194,1,0,0,220,2,0,0,32,2,0,0,152,1,0,0,124,1,0,0,98,1,0,0,0,2,0,0,22,2,0,0,234,0,0,0,40,1,0,0,156,3,0,0,96,2,0,0,82,0,0,0,22,4,0,0,2,4,0,0,206,1,0,0,134,1,0,0,40,0,0,0,134,2,0,0,216,3,0,0,118,3,0,0,228,3,0,0,88,1,0,0,150,1,0,0,204,1,0,0,232,1,0,0,100,1,0,0,244,3,0,0,180,2,0,0,8,4,0,0,110,3,0,0,248,2,0,0,42,0,0,0,234,3,0,0,170,1,0,0,26,2,0,0,162,2,0,0,130,0,0,0,198,1,0,0,24,0,0,0,90,0,0,0,108,0,0,0,232,0,0,0,28,0,0,0,206,2,0,0,138,0,0,0,52,0,0,0,58,1,0,0,56,0,0,0,146,3,0,0,188,0,0,0,50,1,0,0,94,2,0,0,152,2,0,0,222,1,0,0,114,1,0,0,208,0,0,0,22,1,0,0,92,1,0,0,178,1,0,0,110,0,0,0,10,3,0,0,40,2,0,0,170,2,0,0,34,3,0,0,208,2,0,0,60,1,0,0,106,0,0,0,34,0,0,0,148,3,0,0,222,2,0,0,236,2,0,0,218,3,0,0,128,0,0,0,222,3,0,0,56,2,0,0,144,2,0,0,192,2,0,0,10,0,0,0,196,0,0,0,12,0,0,0,210,0,0,0,180,1,0,0,62,0,0,0,128,3,0,0,136,3,0,0,246,2,0,0,74,1,0,0,100,3,0,0,84,1,0,0,228,2,0,0,180,0,0,0,212,2,0,0,32,3,0,0,172,0,0,0,142,1,0,0,208,3,0,0,86,2,0,0,32,1,0,0,212,0,0,0,204,3,0,0,254,1,0,0,106,2,0,0,190,1,0,0,168,0,0,0,116,0,0,0,92,3,0,0,88,0,0,0,226,2,0,0,44,0,0,0,122,2,0,0,104,2,0,0,250,1,0,0,132,2,0,0,144,0,0,0,176,0,0,0,36,0,0,0,136,1,0,0,170,0,0,0,16,2,0,0,254,2,0,0,138,2,0,0,52,2,0,0,102,1,0,0,228,1,0,0,200,2,0,0,18,0,0,0,80,0,0,0,252,3,0,0,178,0,0,0,42,3,0,0,86,3,0,0,136,0,0,0,220,0,0,0,108,1,0,0,154,2,0,0,104,0,0,0,18,2,0,0,0,1,0,0,104,1,0,0,16,3,0,0,24,4,0,0,96,1,0,0,94,3,0,0,130,2,0,0,210,1,0,0,76,0,0,0,100,2,0,0,66,2,0,0,96,0,0,0,184,3,0,0,34,2,0,0,190,3,0,0,182,3,0,0,238,3,0,0,174,2,0,0,226,3,0,0,26,0,0,0,116,1,0,0,48,3,0,0,120,3,0,0,128,2,0,0,218,1,0,0,244,0,0,0,230,2,0,0,112,1,0,0,94,0,0,0,186,2,0,0,208,1,0,0,196,1,0,0,50,3,0,0,20,2,0,0,134,0,0,0,46,1,0,0,112,0,0,0,72,3,0,0,24,2,0,0,140,2,0,0,120,2,0,0,210,2,0,0,18,3,0,0,12,3,0,0,98,0,0,0,46,3,0,0,0,3,0,0,206,3,0,0,122,3,0,0,248,0,0,0,250,0,0,0,82,3,0,0,126,2,0,0,72,0,0,0,230,0,0,0,250,2,0,0,126,0,0,0,70,1,0,0,244,2,0,0,54,3,0,0,42,2,0,0,160,2,0,0,44,1,0,0,128,1,0,0,8,2,0,0,102,3,0,0,74,2,0,0,2,0,0,0,150,0,0,0,246,0,0,0,172,1,0,0,182,1,0,0,194,3,0,0,62,3,0,0,172,2,0,0,150,3,0,0,158,2,0,0,68,2,0,0,68,1,0,0,58,2,0,0,106,3,0,0,248,1,0,0,114,2,0,0,2,3,0,0,234,2,0,0,186,1,0,0,80,1,0,0,4,2,0,0,38,3,0,0,74,0,0,0,138,1,0,0,70,2,0,0,158,1,0,0,124,3,0,0,182,2,0,0,36,2,0,0,24,3,0,0,230,3,0,0,122,1,0,0,136,2,0,0,14,4,0,0,244,1,0,0,252,2,0,0,198,3,0,0,146,0,0,0,44,2,0,0,156,2,0,0,76,1,0,0,254,0,0,0,170,3,0,0,10,2,0,0,132,0,0,0,238,1,0,0,80,3,0,0,16,1,0,0,156,1,0,0,104,3,0,0,160,3,0,0,130,1,0,0,164,0,0,0,6,4,0,0,140,3,0,0,224,2,0,0,148,1,0,0,198,2,0,0,68,3,0,0,84,0,0,0,96,3,0,0,196,3,0,0,184,0,0,0,48,1,0,0,56,3,0,0,188,2,0,0,212,3,0,0,32,0,0,0,44,0,0,0,240,0,0,0,0,0,0,0,0,0,0,0,255,255,0,0,0,0,0,0,1,0,0,0,255,127,0,0,0,0,0,0,2,0,0,0,255,255,128,0,0,0,0,0,3,0,0,0,255,255,1,0,0,0,0,0,0,0,0,0,254,0,2,0,168,0,1,0,0,0,0,0,1,4,0,0,96,135,7,0,0,0,0,0,1,4,4,0,152,182,7,0,25,0,0,0,240,0,0,0,0,0,0,0,0,0,0,0,255,255,0,0,0,0,0,0,1,0,0,0,255,127,0,0,0,0,0,0,2,0,0,0,255,255,128,0,0,0,0,0,3,0,0,0,255,255,1,0,0,0,0,0,0,0,0,0,254,0,2,0,208,161,1,0,0,0,0,0,1,4,0,0,96,135,7,0,0,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,57,46,103,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,24,73,198,151,1,0,16,1,49,48,46,101,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,67,218,197,242,2,0,32,0,56,50,115,49,50,51,46,104,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,233,231,69,53,3,0,32,0,56,50,115,49,50,57,45,51,46,100,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,228,168,179,62,3,0,32,0,56,50,115,49,50,57,45,49,46,97,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,134,204,169,4,0,64,0,56,50,115,49,50,57,45,50,46,99,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,115,112,45,52,120,46,115,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,131,2,89,180,0,0,16,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,115,102,105,120,46,115,102,105,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,253,12,234,194,0,0,32,2,48,48,48,45,108,111,46,108,111,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,242,207,134,90,0,0,0,3,168,86,7,0,1,0,0,0,160,191,145,0,248,191,2,0,40,246,1,0,1,0,0,0,161,191,145,0,64,246,1,0,120,198,7,0,1,0,0,0,120,253,146,0,88,94,5,0,128,9,7,0,1,0,0,0,121,253,146,0,0,69,5,0,160,89,6,0,1,0,0,0,122,253,146,0,0,46,5,0,32,172,5,0,1,0,0,0,123,253,146,0,192,22,5,0,16,24,6,0,1,0,0,0,124,253,146,0,24,8,5,0,24,38,7,0,1,0,0,0,125,253,146,0,184,160,2,0,16,150,7,0,1,0,0,0,40,245,146,0,40,90,5,0,32,223,6,0,1,0,0,0,41,245,146,0,32,64,5,0,192,43,6,0,1,0,0,0,42,245,146,0,248,37,5,0,88,136,5,0,1,0,0,0,43,245,146,0,48,16,5,0,192,232,5,0,1,0,0,0])
.concat([44,245,146,0,56,244,4,0,232,194,2,0,1,0,0,0,45,245,146,0,24,16,4,0,160,103,7,0,1,0,0,0,8,239,146,0,128,83,5,0,168,178,6,0,1,0,0,0,9,239,146,0,48,59,5,0,136,1,6,0,1,0,0,0,10,239,146,0,120,32,5,0,216,192,5,0,1,0,0,0,11,239,146,0,8,252,4,0,192,185,5,0,1,0,0,0,12,239,146,0,128,237,4,0,16,53,7,0,1,0,0,0,248,236,146,0,168,77,5,0,184,135,6,0,1,0,0,0,249,236,146,0,248,53,5,0,216,211,5,0,1,0,0,0,250,236,146,0,192,27,5,0,192,152,5,0,1,0,0,0,251,236,146,0,32,2,5,0,32,147,5,0,1,0,0,0,40,236,146,0,216,11,4,0,200,140,5,0,1,0,0,0,41,236,146,0,80,4,4,0,168,132,5,0,1,0,0,0,42,236,146,0,56,129,5,0,48,126,5,0,1,0,0,0,43,236,146,0,48,252,3,0,176,90,4,0,1,0,0,0,44,236,146,0,248,119,5,0,16,118,5,0,1,0,0,0,45,236,146,0,8,115,5,0,88,212,3,0,1,0,0,0,168,217,146,0,40,185,3,0,16,17,8,0,1,0,0,0,162,191,145,0,224,12,8,0,72,65,1,0,9,0,0,0,35,224,146,0,32,58,1,0,48,50,1,0,9,0,0,0,36,224,146,0,32,58,1,0,168,86,7,0,1,0,0,0,152,255,146,0,248,191,2,0,24,38,7,0,1,0,0,0,151,255,146,0,184,160,2,0,56,210,6,0,1,0,0,0,144,255,146,0,192,135,2,0,24,163,6,0,1,0,0,0,145,255,146,0,240,108,2,0,152,122,6,0,1,0,0,0,146,255,146,0,96,82,2,0,192,72,6,0,1,0,0,0,147,255,146,0,32,56,2,0,200,110,3,0,1,0,0,0,148,255,146,0,152,30,2,0,120,89,3,0,1,0,0,0,149,255,146,0,232,10,2,0,120,74,3,0,1,0,0,0,150,255,146,0,152,138,8,0,192,61,3,0,1,0,0,0,154,255,146,0,48,119,7,0,40,246,1,0,1,0,0,0,16,247,146,0,64,246,1,0,144,236,1,0,1,0,0,0,15,247,146,0,136,224,1,0,176,223,1,0,1,0,0,0,8,247,146,0,72,198,1,0,192,209,1,0,1,0,0,0,9,247,146,0,24,182,1,0,24,198,1,0,1,0,0,0,10,247,146,0,40,167,1,0,120,189,1,0,1,0,0,0,11,247,146,0,200,149,1,0,224,22,1,0,1,0,0,0,12,247,146,0,56,126,1,0,160,14,1,0,1,0,0,0,13,247,146,0,32,101,1,0,176,9,1,0,1,0,0,0,14,247,146,0,96,32,8,0,200,3,1,0,1,0,0,0,18,247,146,0,16,68,7,0,88,212,3,0,1,0,0,0,0,219,146,0,40,185,3,0,32,77,1,0,1,0,0,0,153,255,146,0,216,70,1,0,16,17,8,0,1,0,0,0,17,247,146,0,224,12,8,0,122,111,109,98,105,101,115,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,162,26,154,23,33,0,16,0,122,101,116,115,103,95,108,111,95,55,53,48,48,45,48,48,48,51,52,97,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,24,213,194,185,49,0,16,0,122,101,116,115,103,95,104,105,95,55,53,48,48,45,48,48,48,51,51,97,46,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,140,43,54,175,50,0,16,0,120,45,112,101,114,116,115,32,40,112,114,111,116,111,116,121,112,101,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,73,114,6,157,33,0,16,0,120,105,110,32,113,105,32,103,97,105,32,119,97,110,103,32,122,105,32,40,99,104,105,41,32,40,97,108,116,41,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,254,75,90,218,33,0,16,0,119,97,99,107,121,32,119,111,114,108,100,115,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,45,85,244,138,33,0,16,0,119,111,114,108,100,32,116,114,111,112,104,121,32,115,111,99,99,101,114,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,124,220,62,110,33,0,16,0,119,111,110,100,101,114,32,108,105,98,114,97,114,121,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,84,231,80,147,33,0,16,0,119,105,122,39,110,39,108,105,122,32,45,32,116,104,101,32,102,114,97,110,116,105,99,32,119,97,98,98,105,116,32,119,101,115,99,117,101,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,180,83,147,240,33,0,16,0,119,105,110,116,101,114,32,111,108,121,109,112,105,99,32,103,97,109,101,115,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,55,68,131,197,33,0,16,0,119,105,110,116,101,114,32,111,108,121,109,112,105,99,115,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,132,70,74,101,33,0,16,0,119,105,109,98,108,101,100,111,110,32,99,104,97,109,112,105,111,110,115,104,105,112,32,116,101,110,110,105,115,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,53,164,145,183,33,0,16,0,119,111,114,108,100,32,99,104,97,109,112,105,111,110,115,104,105,112,32,115,111,99,99,101,114,32,105,105,32,40,112,114,111,116,111,116,121,112,101,32,103,32,45,32,102,101,98,32,50,50,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,78,161,191,111,33,0,16,0,119,111,114,108,100,32,99,104,97,109,112,105,111,110,115,104,105,112,32,115,111,99,99,101,114,32,105,105,32,40,112,114,111,116,111,116,121,112,101,32,45,32,102,101,98,32,50,51,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,64,226,185,170,33,0,16,0,119,111,114,108,100,32,99,104,97,109,112,105,111,110,115,104,105,112,32,115,111,99,99,101,114,32,105,105,32,40,112,114,111,116,111,116,121,112,101,32,106,32,45,32,102,101,98,32,50,56,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,76,167,16,226,33,0,16,0,119,111,114,108,100,32,99,104,97,109,112,105,111,110,115,104,105,112,32,115,111,99,99,101,114,32,105,105,32,40,112,114,111,116,111,116,121,112,101,32,110,32,45,32,109,97,114,32,48,51,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,164,135,179,7,33,0,16,0,119,111,114,108,100,32,99,104,97,109,112,105,111,110,115,104,105,112,32,115,111,99,99,101,114,32,105,105,32,40,112,114,111,116,111,116,121,112,101,32,111,32,45,32,109,97,114,32,48,51,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,66,141,69,90,33,0,16,0,119,111,114,108,100,32,99,104,97,109,112,105,111,110,115,104,105,112,32,115,111,99,99,101,114,32,105,105,32,40,112,114,111,116,111,116,121,112,101,32,112,32,45,32,109,97,114,32,48,52,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,239,246,233,143,33,0,16,0,119,111,114,108,100,32,99,104,97,109,112,105,111,110,115,104,105,112,32,115,111,99,99,101,114,32,105,105,32,40,112,114,111,116,111,116,121,112,101,32,45,32,109,97,114,32,48,57,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,204,137,250,113,33,0,16,0,119,111,114,108,100,32,99,104,97,109,112,105,111,110,115,104,105,112,32,115,111,99,99,101,114,32,105,105,32,40,112,114,111,116,111,116,121,112,101,32,114,32,45,32,109,97,114,32,48,57,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,114,85,98,148,33,0,16,0,119,111,114,108,100,32,99,104,97,109,112,105,111,110,115,104,105,112,32,115,111,99,99,101,114,32,105,105,32,40,112,114,111,116,111,116,121,112,101,32,117,32,45,32,109,97,114,32,49,52,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,124,16,236,67,33,0,16,0,119,111,114,108,100,32,99,104,97,109,112,105,111,110,115,104,105,112,32,115,111,99,99,101,114,32,105,105,32,40,112,114,111,116,111,116,121,112,101,32,121,32,45,32,109,97,114,32,49,56,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,97,91,115,246,33,0,16,0,119,111,114,108,100,32,99,104,97,109,112,105,111,110,115,104,105,112,32,115,111,99,99,101,114,32,105,105,32,40,112,114,111,116,111,116,121,112,101,32,45,32,109,97,114,32,50,51,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,20,229,82,56,33,0,16,0,119,111,114,108,100,32,99,104,97,109,112,105,111,110,115,104,105,112,32,115,111,99,99,101,114,32,105,105,32,40,112,114,111,116,111,116,121,112,101,32,45,32,109,97,114,32,50,52,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,74,59,212,166,33,0,16,0,119,111,114,108,100,32,99,104,97,109,112,105,111,110,115,104,105,112,32,115,111,99,99,101,114,32,105,105,32,40,112,114,111,116,111,116,121,112,101,32,45,32,109,97,114,32,50,53,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,251,36,54,107,33,0,16,0,119,111,114,108,100,32,99,104,97,109,112,105,111,110,115,104,105,112,32,115,111,99,99,101,114,32,105,105,32,40,112,114,111,116,111,116,121,112,101,32,45,32,109,97,114,32,50,54,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,156,237,215,26,33,0,16,0,119,111,114,108,100,32,99,104,97,109,112,105,111,110,115,104,105,112,32,115,111,99,99,101,114,32,105,105,32,40,112,114,111,116,111,116,121,112,101,32,45,32,109,97,114,32,50,55,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,9,21,20,78,33,0,16,0,119,111,114,108,100,32,99,104,97,109,112,105,111,110,115,104,105,112,32,115,111,99,99,101,114,32,105,105,32,40,112,114,111,116,111,116,121,112,101,32,45,32,109,97,114,32,50,57,44,32,49,57,57,52,32,45,32,98,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,64,147,117,166,33,0,16,0,119,111,114,108,100,32,99,104,97,109,112,105,111,110,115,104,105,112,32,115,111,99,99,101,114,32,105,105,32,40,112,114,111,116,111,116,121,112,101,32,45,32,109,97,114,32,50,57,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,247,81,156,95,33,0,16,0,119,111,114,108,100,32,99,104,97,109,112,105,111,110,115,104,105,112,32,115,111,99,99,101,114,32,105,105,32,40,112,114,111,116,111,116,121,112,101,32,45,32,109,97,114,32,51,48,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,146,156,212,141,33,0,16,0,119,111,114,108,100,32,99,108,97,115,115,32,108,101,97,100,101,114,98,111,97,114,100,32,103,111,108,102,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,171,75,67,83,33,0,16,0,119,97,114,115,111,110,103,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,133,2,104,75,33,0,16,0,119,97,114,114,105,111,114,32,111,102,32,114,111,109,101,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,106,12,225,91,33,0,16,0,119,97,114,108,111,99,107,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,155,83,70,10,33,0,16,0,119,97,114,100,110,101,114,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,226,154,54,30,33,0,16,0,118,114,32,116,114,111,111,112,101,114,115,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,110,81,53,47,33,0,16,0,118,111,108,102,105,101,100,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,247,227,197,176,33,0,16,0,118,101,114,121,116,101,120,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,95,55,252,186,33,0,16,0,118,101,114,109,105,108,105,111,110,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,195,223,0,228,33,0,16,0,118,101,99,116,111,114,109,97,110,32,50,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,136,64,162,193,33,0,16,0,118,97,112,111,114,32,116,114,97,105,108,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,10,58,158,196,33,0,16,0,118,97,108,105,115,32,105,105,105,32,40,106,112,110,41,32,40,114,101,118,32,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,102,161,73,77,33,0,16,0,117,114,98,97,110,32,115,116,114,105,107,101,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,117,10,105,207,33,0,16,0,116,117,110,32,115,104,105,32,116,105,97,110,32,100,105,32,105,105,105,32,40,99,104,105,41,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,102,65,60,178,33,0,16,0,116,105,110,121,32,116,111,111,110,32,97,100,118,101,110,116,117,114,101,115,32,45,32,97,99,109,101,32,97,108,108,45,115,116,97,114,115,32,40,117,115,97,44,32,107,111,114,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,29,170,159,47,33,0,16,0,116,114,117,120,116,111,110,32,45,45,32,116,97,116,115,117,106,105,110,32,40,119,111,114,108,100,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,45,136,208,91,33,0,16,0,116,114,117,99,111,57,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,252,236,219,205,33,0,16,0,116,114,111,121,32,97,105,107,109,97,110,32,110,102,108,32,102,111,111,116,98,97,108,108,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,19,39,95,1,33,0,16,0,116,114,97,121,115,105,97,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,79,79,24,150,33,0,16,0,116,114,97,110,115,102,111,114,109,101,114,115,32,51,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,13,17,0,109,36,50,134,33,0,16,0,116,114,105,112,108,101,32,112,108,97,121,32,39,57,54,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,145,142,116,241,33,0,16,0,116,117,114,98,111,32,111,117,116,114,117,110,32,40,101,117,114,111,44,32,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,105,19,102,12,33,0,16,0,109,112,114,45,49,52,56,53,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,6,214,186,98,33,0,16,0,116,111,112,32,102,105,103,104,116,101,114,32,50,48,48,53,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,230,239,77,23,33,0,16,0,116,111,101,32,106,97,109,32,38,32,101,97,114,108,32,40,119,111,114,108,100,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,134,103,179,209,33,0,16,0,109,112,114,45,49,54,49,55,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,113,168,176,71,33,0,16,0,116,110,110,32,98,97,115,115,32,116,111,117,114,110,97,109,101,110,116,32,111,102,32,99,104,97,109,112,105,111,110,115,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,27,250,63,200,33,0,16,0,116,101,101,110,97,103,101,32,109,117,116,97,110,116,32,110,105,110,106,97,32,116,117,114,116,108,101,115,32,45,32,116,111,117,114,110,97,109,101,110,116,32,102,105,103,104,116,101,114,115,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,77,72,181,149,33,0,16,0,116,101,101,110,97,103,101,32,109,117,116,97,110,116,32,110,105,110,106,97,32,116,117,114,116,108,101,115,32,45,32,116,111,117,114,110,97,109,101,110,116,32,102,105,103,104,116,101,114,115,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,201,242,67,136,33,0,16,0,116,101,101,110,97,103,101,32,109,117,116,97,110,116,32,110,105,110,106,97,32,116,117,114,116,108,101,115,32,45,32,114,101,116,117,114,110,32,111,102,32,116,104,101,32,115,104,114,101,100,100,101,114,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,152,52,0,27,33,0,16,0,116,105,110,104,101,97,100,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,132,75,114,214,33,0,16,0,116,105,109,101,32,100,111,109,105,110,97,116,111,114,32,49,115,116,32,40,106,112,110,44,32,107,111,114,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,92,122,186,126,33,0,16,0,116,101,116,114,105,115,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,178,74,2,235,33,0,16,0,109,100,45,116,115,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,41,140,207,84,33,0,16,0,116,101,99,109,111,32,119,111,114,108,100,32,99,117,112,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,44,235,248,202,33,0,16,0,116,101,99,109,111,32,115,117,112,101,114,32,98,97,115,101,98,97,108,108,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,120,17,122,34,33,0,16,0,116,101,97,109,32,117,115,97,32,98,97,115,107,101,116,98,97,108,108,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,126,249,202,160,33,0,16,0,116,97,122,32,105,110,32,101,115,99,97,112,101,32,102,114,111,109,32,109,97,114,115,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,153,0,16,98,33,0,16,0,115,117,112,101,114,32,118,111,108,108,101,121,32,98,97,108,108,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,68,238,143,168,33,0,16,0,115,117,114,103,105,110,103,32,97,117,114,97,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,43,29,172,101,33,0,16,0,109,112,114,45,49,50,54,55,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,166,94,126,92,33,0,16,0,115,117,112,101,114,32,104,121,100,108,105,100,101,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,11,217,226,31,33,0,16,0,115,117,112,101,114,32,104,46,113,46,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,176,82,44,171,33,0,16,0,109,112,114,45,49,54,54,50,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,141,210,206,232,33,0,16,0,115,116,114,105,107,101,114,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,178,122,93,204,33,0,16,0,109,112,114,45,49,51,52,56,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,164,153,208,185,33,0,16,0,109,112,114,45,49,49,57,57,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,54,120,215,139,33,0,16,0,115,116,97,114,102,108,105,103,104,116,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,40,201,80,213,33,0,16,0,115,97,105,110,116,32,115,119,111,114,100,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,15,160,96,57,33,0,16,0,115,111,110,105,99,32,115,112,105,110,98,97,108,108,32,40,117,115,97,41,32,40,97,108,116,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,113,3,150,233,33,0,16,0,115,112,111,116,32,103,111,101,115,32,116,111,32,104,111,108,108,121,119,111,111,100,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,188,28,173,189,33,0,16,0,115,111,114,99,101,114,101,114,39,115,32,107,105,110,103,100,111,109,32,40,117,115,97,41,32,40,118,49,46,49,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,206,201,31,187,33,0,16,0,115,111,110,105,99,32,101,114,97,115,101,114,32,40,106,112,110,41,32,40,115,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,231,160,216,98,33,0,16,0,115,111,110,105,99,32,116,104,101,32,104,101,100,103,101,104,111,103,32,51,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,206,146,193,155,33,0,16,0,109,112,114,45,49,54,51,52,51,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,31,29,149,244,33,0,16,0,115,111,110,105,99,32,51,100,32,98,108,97,115,116,32,45,45,32,115,111,110,105,99,32])
.concat([51,100,32,45,32,102,108,105,99,107,105,101,115,39,32,105,115,108,97,110,100,32,40,101,117,114,111,44,32,117,115,97,44,32,107,111,114,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,68,202,162,68,33,0,16,0,115,111,110,105,99,32,51,99,32,40,112,114,111,116,111,116,121,112,101,32,48,52,48,56,32,45,32,97,112,114,32,48,56,44,32,49,57,57,52,44,32,49,55,46,50,57,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,245,61,210,89,33,0,16,0,115,111,110,105,99,32,116,104,101,32,104,101,100,103,101,104,111,103,32,50,32,40,119,111,114,108,100,41,32,40,114,101,118,32,115,99,48,50,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,179,212,58,242,33,0,16,0,115,111,110,105,99,32,116,104,101,32,104,101,100,103,101,104,111,103,32,50,32,40,119,111,114,108,100,41,32,40,114,101,118,32,48,49,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,125,129,216,146,33,0,16,0,115,111,110,105,99,32,116,104,101,32,104,101,100,103,101,104,111,103,32,50,32,40,119,111,114,108,100,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,58,76,171,36,33,0,16,0,109,112,114,45,49,55,53,49,50,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,35,195,212,158,33,0,16,0,109,112,114,45,49,55,53,49,52,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,205,158,43,51,33,0,16,0,109,112,114,45,49,55,53,49,51,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,173,30,220,8,33,0,16,0,115,104,105,106,111,117,32,115,97,105,100,97,105,32,110,111,32,115,111,117,107,111,98,97,110,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,204,170,244,64,33,0,16,0,115,110,100,116,111,111,108,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,82,180,65,238,33,0,16,0,115,117,112,101,114,32,109,97,114,105,111,32,50,32,49,57,57,56,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,225,179,225,247,33,0,16,0,115,108,105,109,101,32,119,111,114,108,100,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,159,82,245,127,33,0,16,0,115,104,111,118,101,32,105,116,33,32,46,46,46,116,104,101,32,119,97,114,101,104,111,117,115,101,32,103,97,109,101,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,203,64,31,197,33,0,16,0,109,112,114,45,49,50,54,52,48,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,7,209,119,56,33,0,16,0,100,114,97,103,111,110,39,115,32,101,121,101,32,112,108,117,115,32,45,32,115,104,97,110,103,104,97,105,32,105,105,105,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,207,195,240,129,33,0,16,0,115,104,97,110,103,104,97,105,32,105,105,32,45,32,100,114,97,103,111,110,39,115,32,101,121,101,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,64,232,233,235,33,0,16,0,115,117,112,101,114,32,102,97,110,116,97,115,121,32,122,111,110,101,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,215,128,119,118,33,0,16,0,115,101,103,97,32,116,111,112,32,102,105,118,101,32,40,98,114,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,105,144,6,97,33,0,16,0,115,101,103,97,32,99,104,97,110,110,101,108,32,100,101,109,111,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,137,232,186,42,33,0,16,0,115,101,99,111,110,100,32,115,97,109,117,114,97,105,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,67,33,233,120,33,0,16,0,115,100,32,118,97,108,105,115,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,234,114,239,26,33,0,16,0,115,97,110,32,103,117,111,32,122,104,105,32,118,32,40,99,104,105,41,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,208,83,126,205,33,0,16,0,115,97,109,117,114,97,105,32,115,112,105,114,105,116,115,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,54,174,162,14,33,0,16,0,115,97,109,117,114,97,105,32,115,104,111,100,111,119,110,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,212,178,184,91,33,0,16,0,109,100,115,116,54,54,51,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,178,5,229,148,33,0,16,0,114,117,103,98,121,32,119,111,114,108,100,32,99,117,112,32,49,57,57,53,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,138,10,249,97,33,0,16,0,114,111,108,108,105,110,103,32,116,104,117,110,100,101,114,32,50,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,155,66,206,58,33,0,16,0,114,111,108,108,105,110,103,32,116,104,117,110,100,101,114,32,50,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,40,38,91,150,33,0,16,0,114,111,97,100,32,114,97,115,104,32,51,32,40,117,115,97,41,32,40,97,108,112,104,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,131,96,98,182,33,0,16,0,114,111,97,100,32,114,97,115,104,32,105,105,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,182,35,87,154,33,0,16,0,114,114,50,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,9,194,41,123,33,0,16,0,97,100,118,101,110,116,117,114,101,115,32,111,102,32,114,111,99,107,121,32,97,110,100,32,98,117,108,108,119,105,110,107,108,101,32,97,110,100,32,102,114,105,101,110,100,115,44,32,116,104,101,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,123,213,2,239,33,0,16,0,114,111,99,107,109,97,110,32,109,101,103,97,32,119,111,114,108,100,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,94,35,135,77,33,0,16,0,114,111,99,107,101,116,32,107,110,105,103,104,116,32,97,100,118,101,110,116,117,114,101,115,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,71,236,239,166,33,0,16,0,114,111,99,107,101,116,32,107,110,105,103,104,116,32,97,100,118,101,110,116,117,114,101,115,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,197,193,200,209,33,0,16,0,112,111,110,100,95,105,105,95,114,111,98,111,99,111,100,95,114,111,95,98,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,102,93,43,195,17,0,16,0,114,105,115,116,97,114,32,45,32,116,104,101,32,115,104,111,111,116,105,110,103,32,115,116,97,114,32,40,106,112,110,44,32,107,111,114,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,14,79,70,206,33,0,16,0,114,105,115,116,97,114,32,40,101,117,114,111,44,32,117,115,97,41,32,40,97,117,103,117,115,116,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,155,19,0,151,33,0,16,0,109,112,114,45,49,50,57,51,48,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,228,235,53,77,33,0,16,0,114,101,110,32,38,32,115,116,105,109,112,121,32,115,104,111,119,32,112,114,101,115,101,110,116,115,32,115,116,105,109,112,121,39,115,32,105,110,118,101,110,116,105,111,110,44,32,116,104,101,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,32,194,118,194,33,0,16,0,114,101,100,32,122,111,110,101,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,229,46,81,86,33,0,16,0,114,46,98,46,105,46,32,98,97,115,101,98,97,108,108,32,39,57,52,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,228,213,180,78,33,0,16,0,114,46,98,46,105,46,32,98,97,115,101,98,97,108,108,32,39,57,51,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,132,206,175,190,33,0,16,0,114,46,98,46,105,46,32,98,97,115,101,98,97,108,108,32,52,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,120,2,66,247,33,0,16,0,114,46,98,46,105,46,32,98,97,115,101,98,97,108,108,32,52,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,5,16,78,143,33,0,16,0,114,97,115,116,97,110,32,115,97,103,97,32,105,105,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,101,137,238,199,33,0,16,0,114,97,110,103,101,114,45,120,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,4,72,192,184,33,0,16,0,114,97,109,112,97,114,116,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,87,208,77,156,33,0,16,0,109,112,114,45,49,50,54,53,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,61,240,50,34,33,0,16,0,114,97,100,105,99,97,108,32,114,101,120,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,126,236,110,46,33,0,16,0,112,121,114,97,109,105,100,32,109,97,103,105,99,32,40,106,112,110,41,32,40,115,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,158,131,109,48,33,0,16,0,112,117,103,103,115,121,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,104,33,19,112,33,0,16,0,112,117,103,103,115,121,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,119,72,250,55,33,0,16,0,109,100,112,112,48,50,49,102,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,161,241,184,26,33,0,16,0,112,104,97,110,116,97,115,121,32,115,116,97,114,32,105,118,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,66,100,35,254,33,0,16,0,112,104,97,110,116,97,115,121,32,115,116,97,114,32,45,32,115,101,110,110,101,110,107,105,32,110,111,32,111,119,97,114,105,32,110,105,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,66,173,191,240,33,0,16,0,112,104,97,110,116,97,115,121,32,115,116,97,114,32,105,105,105,32,45,32,116,111,107,105,32,110,111,32,107,101,105,115,104,111,117,115,104,97,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,111,192,72,108,33,0,16,0,109,112,114,45,49,50,49,52,48,43,109,112,114,45,49,50,49,56,49,43,109,112,114,45,49,50,49,56,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,90,235,200,190,33,0,16,0,112,104,97,110,116,97,115,121,32,115,116,97,114,32,105,105,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,239,208,7,13,33,0,16,0,112,114,105,110,99,101,32,111,102,32,112,101,114,115,105,97,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,224,111,222,97,33,0,16,0,112,111,99,107,101,116,32,109,111,110,115,116,101,114,115,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,103,99,143,246,33,0,16,0,112,111,107,101,109,111,110,32,99,114,97,122,121,32,100,114,117,109,109,101,114,32,40,117,110,108,41,32,91,97,93,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,97,144,244,132,33,0,16,0,112,109,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,134,155,89,251,33,0,16,0,112,105,116,102,97,108,108,32,45,32,116,104,101,32,109,97,121,97,110,32,97,100,118,101,110,116,117,114,101,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,25,142,25,201,33,0,16,0,112,105,114,97,116,101,115,33,32,103,111,108,100,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,92,231,80,237,33,0,16,0,112,104,101,108,105,111,115,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,178,194,171,19,33,0,16,0,112,104,97,110,116,111,109,32,50,48,52,48,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,46,136,36,176,33,0,16,0,101,117,114,111,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,205,90,164,140,33,0,16,0,112,101,98,98,108,101,32,98,101,97,99,104,32,103,111,108,102,32,108,105,110,107,115,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,67,60,130,149,33,0,16,0,112,97,110,111,114,97,109,97,32,99,111,116,116,111,110,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,0,46,217,87,158,33,0,16,0,112,105,114,97,116,101,115,32,111,102,32,116,104,101,32,99,97,114,105,98,98,101,97,110,32,45,32,111,110,32,115,116,114,97,110,103,101,114,32,116,105,100,101,115,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,124,12,201,99,33,0,16,0,112,97,99,45,109,97,110,32,50,32,45,32,116,104,101,32,110,101,119,32,97,100,118,101,110,116,117,114,101,115,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,209,126,122,254,33,0,16,0,111,117,116,114,117,110,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,74,159,125,238,33,0,16,0,111,112,101,110,32,115,101,97,115,111,110,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,114,36,235,6,33,0,16,0,111,111,122,101,44,32,116,104,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,117,110,32,49,53,44,32,49,57,57,53,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,206,53,14,0,253,6,17,146,33,0,16,0,111,111,122,101,44,32,116,104,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,117,110,32,49,57,44,32,49,57,57,53,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,29,40,57,250,33,0,16,0,111,111,122,101,44,32,116,104,101,32,40,112,114,111,116,111,116,121,112,101,32,49,48,52,32,45,32,106,117,110,32,50,50,44,32,49,57,57,53,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,190,14,0,159,19,31,206,33,0,16,0,111,111,122,101,44,32,116,104,101,32,40,112,114,111,116,111,116,121,112,101,32,49,49,50,32,45,32,106,117,110,32,50,54,44,32,49,57,57,53,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,197,14,0,66,148,65,112,33,0,16,0,111,111,122,101,44,32,116,104,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,117,110,32,50,57,44,32,49,57,57,53,32,45,32,98,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,86,228,14,0,59,233,147,202,33,0,16,0,111,111,122,101,44,32,116,104,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,117,110,32,50,57,44,32,49,57,57,53,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,59,118,118,23,33,0,16,0,111,111,122,101,44,32,116,104,101,32,40,101,117,114,111,41,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,117,108,32,50,56,44,32,49,57,57,53,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,231,104,248,124,33,0,16,0,110,111,98,117,110,97,103,97,32,110,111,32,121,97,98,111,117,32,45,32,104,97,111,117,100,101,110,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,198,31,192,150,33,0,16,0,110,111,98,117,110,97,103,97,39,115,32,97,109,98,105,116,105,111,110,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,188,7,188,185,33,0,16,0,104,57,51,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,191,208,97,243,33,0,16,0,110,105,110,106,97,32,103,97,105,100,101,110,32,40,106,112,110,41,32,40,112,114,111,116,111,116,121,112,101,41,32,40,98,97,100,32,100,117,109,112,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,186,116,127,13,33,0,16,0,110,102,108,32,113,117,97,114,116,101,114,98,97,99,107,32,99,108,117,98,32,57,54,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,171,124,163,213,33,0,16,0,110,101,119,109,97,110,32,104,97,97,115,32,105,110,100,121,32,99,97,114,32,102,101,97,116,117,114,105,110,103,32,110,105,103,101,108,32,109,97,110,115,101,108,108,32,45,45,32,110,105,103,101,108,32,109,97,110,115,101,108,108,32,105,110,100,121,32,99,97,114,32,40,119,111,114,108,100,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,41,162,51,18,33,0,16,0,110,98,97,32,115,104,111,119,100,111,119,110,32,39,57,52,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,144,112,11,22,33,0,16,0,110,98,97,32,106,97,109,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,90,48,198,166,33,0,16,0,115,50,56,53,95,118,101,114,95,49,46,48,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,143,36,250,16,33,0,16,0,110,98,97,32,104,97,110,103,32,116,105,109,101,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,170,212,180,237,33,0,16,0,110,97,114,110,105,97,32,51,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,157,18,0,211,188,105,171,33,0,16,0,109,121,115,116,105,99,97,108,32,102,105,103,104,116,101,114,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,155,166,242,178,33,0,16,0,109,112,114,45,49,50,55,48,55,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,147,93,253,80,33,0,16,0,109,111,110,115,116,101,114,32,119,111,114,108,100,32,105,118,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,164,170,163,54,33,0,16,0,109,97,115,116,101,114,32,111,102,32,119,101,97,112,111,110,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,120,97,173,18,33,0,16,0,109,97,103,105,99,97,108,32,116,97,114,117,114,117,117,116,111,45,107,117,110,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,165,96,16,241,33,0,16,0,109,114,46,32,110,117,116,122,32,45,32,104,111,112,112,105,110,39,32,109,97,100,32,40,112,114,111,116,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,62,170,252,43,33,0,16,0,109,105,103,104,116,121,32,109,111,114,112,104,105,110,32,112,111,119,101,114,32,114,97,110,103,101,114,115,32,45,32,116,104,101,32,109,111,118,105,101,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,188,28,148,170,33,0,16,0,109,105,99,107,101,121,32,109,97,110,105,97,32,45,32,116,104,101,32,116,105,109,101,108,101,115,115,32,97,100,118,101,110,116,117,114,101,115,32,111,102,32,109,105,99,107,101,121,32,109,111,117,115,101,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,99,89,158,98,33,0,16,0,109,105,99,107,101,121,32,109,97,110,105,97,32,45,32,116,104,101,32,116,105,109,101,108,101,115,115,32,97,100,118,101,110,116,117,114,101,115,32,111,102,32,109,105,99,107,101,121,32,109,111,117,115,101,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,247,12,24,35,33,0,16,0,109,108,102,48,51,46,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,157,156,226,220,33,0,16,0,109,105,100,110,105,103,104,116,32,114,101,115,105,115,116,97,110,99,101,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,77,110,63,143,33,0,16,0,109,105,99,114,111,32,109,97,99,104,105,110,101,115,32,109,105,108,105,116,97,114,121,32,40,101,117,114,111,41,32,40,106,45,99,97,114,116,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,94,177,171,179,33,0,16,0,109,112,114,45,49,53,48,55,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,247,133,107,147,33,0,16,0,109,101,103,97,110,101,116,32,40,98,114,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,194,60,179,250,33,0,16,0,109,101,103,97,32,109,97,110,32,45,32,116,104,101,32,119,105,108,121,32,119,97,114,115,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,178,232,246,220,33,0,16,0,109,101,103,97,45,108,111,45,109,97,110,105,97,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,25,134,13,166,33,0,16,0,109,101,103,97,45,108,111,45,109,97,110,105,97,32,40,102,114,97,110,99,101,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,237,49,50,59,33,0,16,0,109,112,114,45,49,53,50,51,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,109,213,72,33,33,0,16,0,109,101,103,97,32,103,97,109,101,115,32,51,32,40,101,117,114,111,44,32,97,115,105,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,152,125,36,180,33,0,16,0,109,101,103,97,32,103,97,109,101,115,32,50,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,47,159,213,48,33,0,16,0,109,112,114,45,49,53,48,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,36,50,117,219,33,0,16,0,109,101,103,97,32,98,111,109,98,101,114,109,97,110,32,45,32,56,32,112,108,97,121,101,114,32,100,101,109,111,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,129,13,28,212,33,0,16,0,109,97,103,105,99,95,98,117,98,98,108,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,70,12,74,206,33,0,16,0,109,97,115,116,101,114,32,111,102,32,109,111,110,115,116,101,114,115,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,32,72,53,145,33,0,16,0,109,97,114,115,117,112,105,108,97,109,105,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,223,88,101,199,33,0,16,0,109,112,114,45,49,52,51,55,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,108,235,100,246,33,0,16,0,109,97,111,117,32,114,101,110,106,105,115,104,105,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,140,242,167,36,33,0,16,0,110,105,103,101,108,32,109,97,110,115,101,108,108,39,115,32,119,111,114,108,100,32,99,104,97,109,112,105,111,110,115,104,105,112,32,114,97,99,105,110,103,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,59,214,227,63,33,0,16,0,109,100,115,115,49,50,99,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,166,227,224,202,33,0,16,0,109,97,104,106,111,110,103,32,108,111,118,101,114,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,242,207,194,246,33,0,16,0,106,111,104,110,32,109,97,100,100,101,110,32,102,111,111,116,98,97,108,108,32,45,32,112,114,111,32,102,111,111,116,98,97,108,108,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,28,97,96,4,33,0,16,0,108,111,116,117,115,32,105,105,32,40,117,115,97,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,212,183,151,41,33,0,16,0,108,111,115,116,32,118,105,107,105,110,103,115,44,32,116,104,101,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,198,239,20,31,33,0,16,0,108,111,114,100,32,109,111,110,97,114,99,104,32,45,32,116,111,107,111,116,111,110,32,115,101,110,116,111,117,32,100,101,110,115,101,116,115,117,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,219,245,139,35,33,0,16,0,108,105,103,104,116,32,99,114,117,115,97,100,101,114,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,220,21,183,190,33,0,16,0,108,105,103,104,116,32,99,114,117,115,97,100,101,114,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,117,110,32,48,56,44,32,49,57,57,53,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,250,204,80,227,33,0,16,0,108,105,103,104,116,32,99,114,117,115,97,100,101,114,32,40,107,111,114,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,178,188,12,109,33,0,16,0,108,105,103,104,116,32,99,114,117,115,97,100,101,114,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,164,118,112,35,33,0,16,0,108,105,98,101,114,116,121,32,111,114,32,100,101,97,116,104,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,100,3,219,42,33,0,16,0,108,97,115,116,32,97,99,116,105,111,110,32,104,101,114,111,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,222,125,53,21,33,0,16,0,109,112,114,45,49,50,55,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,4,3,181,79,33,0,16,0,116,111,110,121,32,108,97,32,114,117,115,115,97,32,98,97,115,101,98,97,108,108,32,40,117,115,97,44,32,97,117,115,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,120,156,98,36,33,0,16,0,97,103,101,110,116,32,104,117,103,111,32,45,32,105,110,32,116,104,101,32,119,111,114,108,100,32,111,102,32,100,105,110,111,115,97,117,114,115,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,28,190,14,189,33,0,16,0,97,103,101,110,116,32,104,117,103,111,32,45,32,101,110,118,105,114,111,110,109,101,110,116,32,97,116,32,114,105,115,107,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,91,214,50,190,33,0,16,0,107,117,106,97,107,117,32,111,117,32,50,32,45,32,103,101,110,101,105,106,111,117,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,188,86,253,175,33,0,16,0,107,114,117,115,116,121,39,115,32,115,117,112,101,114,32,102,117,110,32,104,111,117,115,101,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,94,0,100,247,33,0,16,0,107,111,108,111,98,111,107,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,171,91,197,196,33,0,16,0,107,110,117,99,107,108,101,115,32,105,110,32,115,111,110,105,99,32,50,32,40,112,114,111,116,111,116,121,112,101,32,48,53,50,52,32,45,32,109,97,121,32,50,55,44,32,49,57,57,52,44,32,49,48,46,52,54,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,168,193,120,136,33,0,16,0,107,105,110,103,32,115,97,108,109,111,110,32,45,32,116,104,101,32,98,105,103,32,99,97,116,99,104,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,217,231,22,245,33,0,16,0,109,112,114,45,49,52,57,50,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,199,179,231,255,33,0,16,0,109,112,114,45,49,52,53,53,55,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,204,230,54,206,33,0,16,0,109,112,114,45,49,53,51,51,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,12,35,220,155,33,0,16,0,107,97,45,103,101,45,107,105,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,161,102,24,57,33,0,16,0,106,117,117,111,117,107,105,32,40,106,112,110,41,32,40,118,49,46,49,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,135,62,35,178,33,0,16,0,106,117,110,103,108,101,32,98,111,111,107,44,32,116,104,101,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,46,217,182,63,33,0,16,0,106,117,110,103,108,101,32,115,116,114,105,107,101,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,53,151,210,165,33,0,16,0,106,117,114,97,115,115,105,99,32,112,97,114,107,32,40,117,115,97,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,237,14,137,207,33,0,16,0,106,117,114,97,115,115,105,99,32,112,97,114,107,32,45,32,114,97,109,112,97,103,101,32,101,100,105,116,105,111,110,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,27,170,180,152,33,0,16,0,106,111,114,100,97,110,32,118,115,32,98,105,114,100,32,40,101,117,114,111,44,32,117,115,97,41,32,40,118,49,46,49,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,124,221,61,77,33,0,16,0,109,112,114,45,49,51,54,53,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,221,161,166,138,33,0,16,0,106,117,115,116,105,99,101,32,108,101,97,103,117,101,32,116,97,115,107,32,102,111,114,99,101,32,40,119,111,114,108,100,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,233,235,96,42,33,0,16,0,109,112,114,45,49,52,49,49,56,97,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,19,136,233,206,33,0,16,0,105,122,122,121,39,115,32,113,117,101,115,116,32,102,111,114,32,116,104,101,32,111,108,121,109,112,105,99,32,114,105,110,103,115,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,228,22,180,119,33,0,16,0,105,114,97,113,32,119,97,114,32,50,48,48,51,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,82,111,221,73,33,0,16,0,105,110,115,101,99,116,111,114,32,120,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,4,99,98,112,33,0,16,0,105,110,100,105,97,110,97,32,106,111,110,101,115,32,45,32,99,111,114,114,105,100,111,114,115,32,111,102,32,116,105,109,101,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,118,44,248,84,33,0,16,0,105,99,101,32,97,103,101,32,52,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,230,16,0,252,108,232,146,33,0,16,0,105,99,101,32,97,103,101,32,51,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,113,16,0,179,255,252,88,33,0,16,0,104,121,98,114,105,100,32,102,114,111,110,116,44,32,116,104,101,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,231,207,241,161,33,0,16,0,104,101,97,118,121,32,117,110,105,116,32,45,32,109,101,103,97,32,100,114,105,118,101,32,115,112,101,99,105,97,108,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,8,230,203,26,33,0,16,0,104,97,114,114,121,32,112,111,116,116,101,114,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,118,252,132,161,33,0,16,0,104,101,114,122,111,103,32,122,119,101,105,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,179,118,246,76,33,0,16,0,103,121,110,111,117,103,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,31,36,105,27,33,0,16,0,103,117,110,115,116,97,114,32,104,101,114,111,101,115,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,208,217,110,134,33,0,16,0,103,117,110,115,104,105,112,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,201,64,20,218,33,0,16,0,103,114,105,110,100,32,115,116,111,114,109,101,114,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,21,239,107,126,33,0,16,0,109,112,114,45,49,53,50,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,222,112,38,140,33,0,16,0,103,114,97,110,97,100,97,32,40,117,115,97,44,32,106,112,110,41,32,40,118,49,46,49,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,102,30,157,232,33,0,16,0,109,112,114,45,49,50,54,48,53,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,171,198,102,16,17,0,16,0,109,112,114,45,49,50,54,48,54,46,105,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,111,197,235,206,19,0,16,0,103,97,105,110,32,103,114,111,117,110,100,32,40,119,111,114,108,100,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,171,162,65,134,33,0,16,0,115,103,114,48,48,49,43,115,103,114,48,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,76,62,41,95,33,0,16,0,109,112,114,45,49,52,50,52,56,98,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,60,92,95,209,33,0,16,0,103,101,109,102,105,114,101,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,91,19,54,61,33,0,16,0,103,97,109,101,32,110,111,32,107,97,110,100,117,109,101,32,111,116,111,107,117,121,111,117,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,107,126,173,205,33,0,16,0,103,97,109,98,108,101,114,32,106,105,107,111,32,99,104,117,117,115,104,105,110,104,97,32,45,32,107,97,116,97,121,97,109,97,32,109,97,115,97,121,117,107,105,32,110,111,32,109,97,104,106,111,110,103,32,100,111,117,106,111,117,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,122,11,101,5,33,0,16,0,103,97,108,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,188,87,149,103,33,0,16,0,103,97,105,97,114,101,115,32,40,117,115,97,44,32,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,139,246,139,93,33,0,16,0,102,114,111,103,103,101,114,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,192,72,46,234,33,0,16,0,109,97,114,121,32,115,104,101,108,108,101,121,39,115,32,102,114,97,110,107,101,110,115,116,101,105,110,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,195,61,153,72,33,0,16,0,102,111,114,101,109,97,110,32,102,111,114,32,114,101,97,108,32,40,119,111,114,108,100,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,144,143,36,54,33,0,16,0,102,108,97,115,104,98,97,99])
.concat([107,32,45,32,116,104,101,32,113,117,101,115,116,32,102,111,114,32,105,100,101,110,116,105,116,121,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,109,97,169,35,33,0,16,0,102,108,97,115,104,98,97,99,107,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,180,227,144,183,33,0,16,0,108,104,53,51,55,48,104,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,249,145,37,1,33,0,16,0,102,105,102,97,32,50,48,48,51,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,2,203,155,65,33,0,16,0,102,105,102,97,32,119,111,114,108,100,32,99,117,112,32,50,48,48,50,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,142,255,43,133,33,0,16,0,109,112,114,45,49,52,55,55,48,97,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,223,17,1,37,33,0,16,0,102,97,116,97,108,32,102,117,114,121,32,40,101,117,114,111,44,32,107,111,114,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,145,10,115,46,33,0,16,0,102,97,109,105,108,121,32,102,101,117,100,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,176,40,166,26,33,0,16,0,102,45,49,53,32,115,116,114,105,107,101,32,101,97,103,108,101,32,105,105,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,96,77,44,65,33,0,16,0,109,112,114,45,49,53,53,56,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,141,182,155,52,33,0,16,0,109,112,114,45,49,52,56,54,48,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,200,55,239,79,33,0,16,0,101,115,112,110,32,115,117,110,100,97,121,32,110,105,103,104,116,32,110,102,108,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,9,195,233,97,33,0,16,0,101,115,112,110,32,110,97,116,105,111,110,97,108,32,104,111,99,107,101,121,32,110,105,103,104,116,32,40,117,115,97,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,74,129,39,164,33,0,16,0,101,108,101,109,101,110,116,97,108,32,109,97,115,116,101,114,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,198,24,9,57,33,0,16,0,101,99,99,111,32,106,114,46,32,40,117,115,97,44,32,97,117,115,41,32,40,109,97,114,99,104,32,49,57,57,53,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,117,121,81,60,33,0,16,0,101,99,99,111,32,105,105,32,45,32,116,104,101,32,116,105,100,101,115,32,111,102,32,116,105,109,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,112,114,32,50,57,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,203,62,248,90,33,0,16,0,101,99,99,111,32,45,32,116,104,101,32,116,105,100,101,115,32,111,102,32,116,105,109,101,32,40,98,101,116,97,44,32,97,108,116,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,234,112,20,29,33,0,16,0,101,97,114,110,101,115,116,32,101,118,97,110,115,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,109,129,67,162,33,0,16,0,109,112,114,45,49,51,52,51,56,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,218,11,111,36,33,0,16,0,100,121,110,97,32,98,114,111,116,104,101,114,115,32,50,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,78,166,224,71,33,0,16,0,100,101,115,101,114,116,32,115,116,114,105,107,101,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,11,134,169,103,33,0,16,0,100,114,97,103,111,110,32,115,108,97,121,101,114,32,45,32,101,105,121,117,117,32,100,101,110,115,101,116,115,117,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,4,22,188,1,33,0,16,0,100,114,97,103,111,110,32,45,32,116,104,101,32,98,114,117,99,101,32,108,101,101,32,115,116,111,114,121,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,229,80,232,239,33,0,16,0,98,114,97,109,32,115,116,111,107,101,114,39,115,32,100,114,97,99,117,108,97,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,99,160,165,155,33,0,16,0,100,111,109,105,110,117,115,32,40,117,115,97,41,32,40,112,114,111,116,111,116,121,112,101,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,189,110,0,48,33,0,16,0,109,105,107,101,32,100,105,116,107,97,32,112,111,119,101,114,32,102,111,111,116,98,97,108,108,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,16,179,120,96,33,0,16,0,114,111,110,97,108,100,105,110,104,111,32,57,56,32,40,112,105,114,97,116,101,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,78,200,39,221,33,0,16,0,100,121,110,97,109,105,116,101,32,104,101,97,100,100,121,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,117,110,32,49,52,44,32,49,57,57,52,32,45,32,99,97,98,101,122,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,76,242,30,151,33,0,16,0,100,121,110,97,109,105,116,101,32,104,101,97,100,100,121,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,117,110,32,49,54,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,25,103,169,248,33,0,16,0,100,121,110,97,109,105,116,101,32,104,101,97,100,100,121,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,117,110,32,50,50,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,200,30,0,97,33,0,16,0,100,121,110,97,109,105,116,101,32,104,101,97,100,100,121,32,40,106,112,110,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,52,233,37,92,33,0,16,0,100,101,109,111,108,105,116,105,111,110,32,109,97,110,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,119,24,247,95,33,0,16,0,100,101,97,116,104,32,100,117,101,108,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,204,77,128,169,33,0,16,0,100,117,110,103,101,111,110,115,32,38,32,100,114,97,103,111,110,115,32,45,32,119,97,114,114,105,111,114,115,32,111,102,32,116,104,101,32,101,116,101,114,110,97,108,32,115,117,110,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,215,156,74,175,33,0,16,0,100,111,117,98,108,101,32,100,114,97,103,111,110,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,83,93,79,5,33,0,16,0,109,112,114,45,49,52,56,53,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,198,7,15,99,33,0,16,0,100,97,115,104,105,110,39,32,100,101,115,112,101,114,97,100,111,101,115,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,183,111,183,220,33,0,16,0,100,97,114,105,117,115,32,105,105,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,42,230,223,37,33,0,16,0,100,97,105,107,111,117,107,97,105,32,106,105,100,97,105,32,105,105,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,218,240,64,224,33,0,16,0,109,112,114,45,49,52,54,51,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,161,158,130,16,33,0,16,0,109,112,114,45,49,53,52,54,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,105,18,13,171,33,0,16,0,99,97,115,116,108,101,118,97,110,105,97,32,45,32,98,108,111,111,100,108,105,110,101,115,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,223,166,30,251,33,0,16,0,99,97,115,116,108,101,118,97,110,105,97,32,45,32,116,104,101,32,110,101,119,32,103,101,110,101,114,97,116,105,111,110,32,40,101,117,114,111,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,58,16,205,132,33,0,16,0,99,105,112,114,101,118,105,101,119,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,242,57,73,127,33,0,16,0,99,111,117,110,116,101,114,32,115,116,114,105,107,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,186,131,123,158,33,0,16,0,109,112,114,45,49,51,53,55,56,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,122,164,18,208,33,0,16,0,99,111,110,116,114,97,32,45,32,116,104,101,32,104,97,114,100,32,99,111,114,112,115,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,128,99,178,42,33,0,16,0,99,111,109,105,120,32,122,111,110,101,32,40,117,115,97,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,238,182,252,46,33,0,16,0,99,111,109,105,120,32,122,111,110,101,32,40,115,101,103,97,32,99,104,97,110,110,101,108,41,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,117,110,32,49,50,44,32,49,57,57,53,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,225,185,125,199,33,0,16,0,99,111,109,105,120,32,122,111,110,101,32,40,107,111,114,41,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,117,110,32,48,57,44,32,49,57,57,53,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,244,21,90,228,33,0,16,0,99,111,108,117,109,110,115,32,40,119,111,114,108,100,41,32,40,118,49,46,49,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,68,194,131,215,33,0,16,0,99,111,108,108,101,103,101,32,102,111,111,116,98,97,108,108,39,115,32,110,97,116,105,111,110,97,108,32,99,104,97,109,112,105,111,110,115,104,105,112,32,105,105,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,19,68,182,101,33,0,16,0,99,108,105,102,102,104,97,110,103,101,114,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,211,68,191,156,33,0,16,0,99,108,105,102,102,104,97,110,103,101,114,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,253,81,130,98,33,0,16,0,99,104,105,110,101,115,101,32,102,105,103,104,116,101,114,32,105,105,105,32,40,117,110,108,44,32,97,108,116,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,125,36,152,111,33,0,16,0,99,104,101,115,116,101,114,32,99,104,101,101,116,97,104,32,45,32,116,111,111,32,99,111,111,108,32,116,111,32,102,111,111,108,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,195,62,14,37,33,0,16,0,99,104,101,108,110,111,118,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,216,116,254,178,33,0,16,0,99,104,97,118,101,122,32,105,105,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,184,219,192,91,33,0,16,0,99,97,110,110,111,110,32,102,111,100,100,101,114,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,84,118,33,173,33,0,16,0,99,97,101,115,97,114,115,32,112,97,108,97,99,101,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,187,169,218,143,33,0,16,0,99,97,101,115,97,114,32,110,111,32,121,97,98,111,117,32,105,105,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,58,123,50,79,33,0,16,0,109,112,114,45,49,56,56,56,55,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,187,160,192,206,33,0,16,0,98,117,100,111,107,97,110,32,45,32,116,104,101,32,109,97,114,116,105,97,108,32,115,112,105,114,105,116,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,189,213,173,151,33,0,16,0,98,117,99,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,255,191,227,68,33,0,16,0,116,101,99,109,111,32,99,117,112,32,40,106,112,110,41,32,40,112,105,114,97,116,101,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,226,137,232,33,0,16,0,98,114,117,116,97,108,32,45,32,112,97,119,115,32,111,102,32,102,117,114,121,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,205,2,213,152,33,0,16,0,98,111,111,103,101,114,109,97,110,32,45,32,97,32,112,105,99,107,32,97,110,100,32,102,108,105,99,107,32,97,100,118,101,110,116,117,114,101,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,236,43,122,26,33,0,16,0,98,111,110,107,101,114,115,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,23,96,230,209,33,0,16,0,98,111,100,121,32,99,111,117,110,116,32,40,101,117,114,111,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,206,182,255,180,33,0,16,0,109,112,114,45,49,54,50,53,50,32,119,53,49,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,209,7,150,100,33,0,16,0,102,114,97,110,107,32,116,104,111,109,97,115,32,98,105,103,32,104,117,114,116,32,98,97,115,101,98,97,108,108,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,80,9,62,134,33,0,16,0,98,101,115,116,32,111,102,32,116,104,101,32,98,101,115,116,32,45,32,99,104,97,109,112,105,111,110,115,104,105,112,32,107,97,114,97,116,101,32,40,101,117,114,111,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,11,36,66,248,33,0,16,0,98,101,97,118,105,115,32,97,110,100,32,98,117,116,116,45,104,101,97,100,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,72,185,215,245,33,0,16,0,98,101,97,115,116,32,119,97,114,114,105,111,114,115,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,148,198,70,70,33,0,16,0,98,97,116,109,97,110,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,174,16,116,1,33,0,16,0,98,97,116,109,97,110,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,191,254,180,215,33,0,16,0,98,97,116,109,97,110,32,102,111,114,101,118,101,114,32,40,119,111,114,108,100,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,1,61,114,139,33,0,16,0,98,97,114,107,108,101,121,32,115,104,117,116,32,117,112,32,97,110,100,32,106,97,109,33,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,151,244,251,99,33,0,16,0,98,97,114,98,105,101,32,118,97,99,97,116,105,111,110,32,97,100,118,101,110,116,117,114,101,32,40,117,115,97,41,32,40,112,114,111,116,111,116,121,112,101,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,105,186,224,16,33,0,16,0,98,97,108,108,122,32,51,100,32,45,32,102,105,103,104,116,105,110,103,32,97,116,32,105,116,115,32,98,97,108,108,122,105,101,115,116,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,5,183,98,179,33,0,16,0,98,97,100,32,111,109,101,110,32,40,106,112,110,44,32,107,111,114,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,206,147,86,151,33,0,16,0,97,116,112,32,116,111,117,114,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,197,168,61,26,33,0,16,0,109,112,114,45,49,53,50,56,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,24,84,192,179,33,0,16,0,109,112,114,45,49,55,55,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,63,216,241,79,33,0,16,0,97,114,116,116,111,111,108,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,50,245,83,83,33,0,16,0,109,112,114,45,49,50,54,52,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,239,149,185,53,33,0,16,0,109,112,114,45,49,52,54,56,48,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,209,91,22,40,33,0,16,0,109,112,114,45,49,53,48,54,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,110,13,176,163,33,0,16,0,109,112,114,45,49,53,57,51,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,143,94,132,209,33,0,16,0,97,107,117,109,97,106,111,117,32,100,114,97,99,117,108,97,32,45,32,118,97,109,112,105,114,101,32,107,105,108,108,101,114,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,43,125,181,145,33,0,16,0,97,110,100,114,101,32,97,103,97,115,115,105,32,116,101,110,110,105,115,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,81,221,85,231,33,0,16,0,97,101,114,111,98,105,122,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,206,155,170,207,33,0,16,0,97,100,118,101,110,116,117,114,111,117,115,32,98,111,121,32,45,32,109,97,111,32,120,105,97,110,32,120,105,97,111,32,122,105,32,40,99,104,105,41,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,19,57,64,212,33,0,16,0,109,112,114,45,49,56,48,49,57,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,57,140,94,53,33,0,16,0,97,100,100,97,109,115,32,102,97,109,105,108,121,32,118,97,108,117,101,115,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,146,185,6,185,33,0,16,0,97,97,97,104,104,33,33,33,32,114,101,97,108,32,109,111,110,115,116,101,114,115,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,255,21,209,122,33,0,16,0,51,45,105,110,45,49,32,114,111,97,100,32,114,97,115,104,32,45,32,109,115,46,32,112,97,99,45,109,97,110,32,45,32,98,108,111,99,107,32,111,117,116,32,40,112,105,114,97,116,101,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,84,97,201,19,33,0,16,0,51,45,105,110,45,49,32,102,108,97,115,104,98,97,99,107,32,45,32,119,111,114,108,100,32,99,104,97,109,112,46,32,115,111,99,99,101,114,32,45,32,116,101,99,109,111,32,119,111,114,108,100,32,99,117,112,32,57,50,32,40,112,105,114,97,116,101,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,215,40,253,168,33,0,16,0,50,48,50,48,32,116,111,115,104,105,32,115,117,112,101,114,32,98,97,115,101,98,97,108,108,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,39,225,190,43,33,0,16,0,168,86,7,0,1,0,0,0,184,2,147,0,248,191,2,0,24,38,7,0,1,0,0,0,183,2,147,0,184,160,2,0,56,210,6,0,1,0,0,0,176,2,147,0,192,135,2,0,24,163,6,0,1,0,0,0,177,2,147,0,240,108,2,0,152,122,6,0,1,0,0,0,178,2,147,0,96,82,2,0,192,72,6,0,1,0,0,0,179,2,147,0,32,56,2,0,200,110,3,0,1,0,0,0,180,2,147,0,152,30,2,0,120,89,3,0,1,0,0,0,181,2,147,0,232,10,2,0,120,74,3,0,1,0,0,0,182,2,147,0,152,138,8,0,40,246,1,0,1,0,0,0,248,249,146,0,64,246,1,0,144,236,1,0,1,0,0,0,247,249,146,0,136,224,1,0,176,223,1,0,1,0,0,0,240,249,146,0,72,198,1,0,192,209,1,0,1,0,0,0,241,249,146,0,24,182,1,0,24,198,1,0,1,0,0,0,242,249,146,0,40,167,1,0,120,189,1,0,1,0,0,0,243,249,146,0,200,149,1,0,224,22,1,0,1,0,0,0,244,249,146,0,56,126,1,0,160,14,1,0,1,0,0,0,245,249,146,0,32,101,1,0,176,9,1,0,1,0,0,0,246,249,146,0,96,32,8,0,88,212,3,0,1,0,0,0,40,222,146,0,40,185,3,0,32,77,1,0,1,0,0,0,185,2,147,0,216,70,1,0,16,17,8,0,1,0,0,0,249,249,146,0,224,12,8,0,15,0,0,0,1,0,0,0,255,255,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,0,0,0,0,0,0,255,255,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,86,7,0,1,0,0,0,139,191,145,0,248,191,2,0,24,38,7,0,1,0,0,0,141,191,145,0,184,160,2,0,56,210,6,0,1,0,0,0,160,251,146,0,192,135,2,0,24,163,6,0,1,0,0,0,161,251,146,0,240,108,2,0,152,122,6,0,1,0,0,0,162,251,146,0,96,82,2,0,192,72,6,0,1,0,0,0,163,251,146,0,32,56,2,0,200,110,3,0,1,0,0,0,164,251,146,0,152,30,2,0,120,89,3,0,1,0,0,0,165,251,146,0,232,10,2,0,120,74,3,0,1,0,0,0,166,251,146,0,152,138,8,0,40,246,1,0,1,0,0,0,140,191,145,0,64,246,1,0,144,236,1,0,1,0,0,0,142,191,145,0,136,224,1,0,176,223,1,0,1,0,0,0,112,243,146,0,72,198,1,0,192,209,1,0,1,0,0,0,113,243,146,0,24,182,1,0,24,198,1,0,1,0,0,0,114,243,146,0,40,167,1,0,120,189,1,0,1,0,0,0,115,243,146,0,200,149,1,0,224,22,1,0,1,0,0,0,116,243,146,0,56,126,1,0,160,14,1,0,1,0,0,0,117,243,146,0,32,101,1,0,176,9,1,0,1,0,0,0,118,243,146,0,96,32,8,0,88,212,3,0,1,0,0,0,88,216,146,0,40,185,3,0,32,77,1,0,1,0,0,0,136,191,145,0,216,70,1,0,72,65,1,0,9,0,0,0,187,223,146,0,32,58,1,0,48,50,1,0,9,0,0,0,188,223,146,0,32,58,1,0,224,41,1,0,9,0,0,0,189,223,146,0,32,58,1,0,152,136,88,0,0,135,88,0,104,133,88,0,208,131,88,0,56,130,88,0,160,128,88,0,8,127,88,0,0,0,0,0,72,23,4,0,1,0,0,0,86,0,147,0,248,191,2,0,56,250,6,0,1,0,0,0,189,247,146,0,184,160,2,0,88,149,7,0,1,0,0,0,190,247,146,0,136,224,1,0,56,210,6,0,1,0,0,0,80,0,147,0,192,135,2,0,152,122,6,0,1,0,0,0,81,0,147,0,96,82,2,0,192,72,6,0,1,0,0,0,82,0,147,0,32,56,2,0,24,163,6,0,1,0,0,0,83,0,147,0,240,108,2,0,200,110,3,0,1,0,0,0,87,0,147,0,152,30,2,0,176,223,1,0,1,0,0,0,184,247,146,0,72,198,1,0,24,198,1,0,1,0,0,0,185,247,146,0,40,167,1,0,120,189,1,0,1,0,0,0,186,247,146,0,200,149,1,0,192,209,1,0,1,0,0,0,187,247,146,0,24,182,1,0,200,110,3,0,1,0,0,0,85,0,147,0,56,126,1,0,88,212,3,0,1,0,0,0,128,219,146,0,40,185,3,0,232,75,4,0,1,0,0,0,87,0,147,0,216,70,1,0,160,193,3,0,9,0,0,0,202,5,147,0,32,58,1,0,104,20,5,0,9,0,0,0,200,5,147,0,32,58,1,0,216,16,5,0,9,0,0,0,201,5,147,0,32,58,1,0,88,12,5,0,9,0,0,0,203,5,147,0,32,58,1,0,218,167,214,110,47,94,240,63,164,206,211,253,70,42,172,201,190,235,159,213,60,97,150,17,208,56,202,6,237,27,101,231,35,221,217,5,191,91,93,165,149,0,236,241,1,169,166,252,187,84,227,46,146,88,10,123,182,204,177,95,20,53,114,255,230,82,215,140,243,67,175,156,192,79,12,66,142,239,128,205,29,126,136,59,152,161,173,228,157,141,43,86,181,80,223,102,109,212,96,9,225,238,74,71,249,254,115,7,137,168,57,234,130,158,207,38,178,78,195,89,242,61,154,176,105,247,188,52,229,54,34,251,87,113,153,108,131,48,85,194,189,244,119,233,118,151,160,224,185,134,107,163,132,103,26,112,2,90,65,92,37,129,170,40,120,75,198,100,83,22,77,139,32,147,174,15,148,44,58,199,98,232,196,219,4,197,250,41,72,209,8,36,13,226,216,16,180,145,138,19,14,220,210,121,184,248,186,45,203,245,125,55,81,64,49,162,11,24,99,127,179,171,155,135,246,144,222,200,39,69,124,28,133,104,51,25,3,117,21,122,31,73,143,76,193,68,23,18,111,50,183,62,116,30,33,106,154,47,204,78,64,105,172,202,165,123,10,97,145,13,85,116,205,139,11,128,9,94,56,199,218,191,245,55,35,49,51,233,174,135,229,250,110,92,173,244,118,98,159,46,1,226,246,71,140,124,170,152,181,146,81,236,95,7,93,111,22,161,29,169,72,69,240,106,156,30,17,160,6,70,213,241,115,237,148,247,195,87,27,224,151,177,164,167,36,231,43,5,91,52,12,184,15,155,200,77,90,166,134,62,20,41,132,88,144,219,45,84,157,130,212,125,198,103,65,137,193,19,176,158,129,109,168,89,189,57,142,230,37,143,217,162,228,83,197,114,126,54,74,79,82,194,34,42,206,60,33,44,0,215,117,138,39,238,67,254,203,107,185,163,120,183,133,2,32,208,131,196,18,249,253,216,121,100,58,73,3,180,192,242,223,21,147,8,53,255,112,221,40,108,14,4,222,122,101,210,171,66,149,225,63,59,127,102,209,141,227,187,28,252,119,26,136,24,25,104,31,86,214,232,182,188,211,234,61,38,179,201,68,220,243,50,48,239,150,76,175,23,248,251,96,80,235,75,153,99,186,178,113,207,16,190,244,40,180,143,250,235,142,84,43,73,209,118,113,71,139,87,146,133,124,184,92,34,249,38,188,91,109,103,174,95,111,245,159,72,102,64,13,17,78,178,107,53,21,15,24,37,29,186,211,105,121,236,168,140,201,127,75,219,81,175,202,226,179,129,18,94,126,56,200,149,1,255,253,251,242,116,98,20,165,152,166,218,128,83,232,86,172,27,82,208,241,69,66,182,26,74,58,153,252,210,156,207,49,45,221,134,47,41,225,3,25,162,65,51,131,144,193,191,11,8,61,216,141,108,57,160,227,85,2,80,70,230,195,130,54,19,117,171,39,215,31,10,212,137,89,79,192,93,198,247,136,189,60,0,239,205,5,28,170,155,237,122,97,23,147,254,35,185,243,104,120,246,90,123,224,228,163,238,22,114,199,59,138,55,42,112,169,44,33,248,36,9,206,32,158,6,135,197,4,100,67,125,77,16,214,164,148,76,96,222,223,88,177,68,63,176,217,229,203,187,190,234,7,52,115,106,119,240,157,12,46,14,145,154,204,194,183,99,151,213,220,196,50,231,132,62,48,161,30,181,110,101,233,173,167,150,16,97,241,120,133,82,104,227,18,13,250,240,201,54,94,61,249,166,1,46,199,132,234,43,109,20,56,79,85,28,157,167,122,198,248,154,230,66,181,237,125,58,177,5,67,74,34,253,172,164,49,195,50,118,149,158,126,136,142,162,151,24,190,42,245,214,202,204,114,59,135,108,222,117,215,33,203,11,221,231,225,101,170,185,68,251,102,21,26,60,152,207,138,223,55,165,47,103,210,131,182,107,252,224,180,124,8,220,147,48,171,228,25,194,139,235,160,10,200,3,192,75,100,113,134,156,155,22,121,255,112,9,140,208,246,83,7,115,212,137,179,0,233,254,236,143,188,178,30,93,17,53,169,6,89,159,193,211,123,242,197,119,78,57,32,213,106,130,218,69,243,51,129,35,186,226,29,95,92,81,73,174,141,196,168,247,31,15,52,40,161,217,39,216,76,44,191,145,62,105,87,65,37,12,90,144,146,176,99,111,64,175,116,184,45,128,187,70,148,229,41,238,183,27,150,173,19,14,88,153,96,77,23,38,206,232,219,239,36,163,110,127,84,63,2,209,91,80,86,72,244,189,98,71,4,205,107,98,95,117,51,95,118,49,48,52,46,117,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,25,215,177,109,1,0,16,1,107,98,95,117,54,95,118,49,48,52,46,117,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,120,201,236,49,1,0,16,1,107,98,95,117,52,95,118,49,48,52,46,117,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,231,178,216,30,1,0,16,1,107,98,95,117,53,95,118,49,48,52,46,117,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,41,252,186,160,1,0,16,1,116,48,51,48,48,46,117,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,217,247,34,9,2,0,32,0,97,48,51,48,48,46,117,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,211,85,148,63,3,0,32,0,97,48,51,48,49,46,117,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,137,104,119,146,3,0,32,0,97,48,51,48,51,46,117,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,105,204,245,51,3,0,32,0,97,48,51,48,54,46,117,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,142,138,1,204,3,0,32,0,97,48,51,48,55,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,57,46,119,188,3,0,32,0,98,48,51,48,48,46,117,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,129,105,135,127,4,0,32,0,98,48,51,48,50,46,117,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,2,197,169,238,4,0,32,0,98,48,51,48,51,46,117,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,46,101,169,119,4,0,32,0,109,48,51,48,48,46,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,149,150,21,147,5,0,64,0,107,98,95,117,50,95,118,49,48,52,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,213,246,112,201,0,0,16,1,112,103,109,95,116,48,49,115,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,160,35,113,26,0,0,32,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,86,7,0,1,0,0,0,192,191,145,0,248,191,2,0,24,38,7,0,1,0,0,0,194,191,145,0,184,160,2,0,56,210,6,0,1,0,0,0,152,254,146,0,192,135,2,0,24,163,6,0,1,0,0,0,153,254,146,0,240,108,2,0,152,122,6,0,1,0,0,0,154,254,146,0,96,82,2,0,192,72,6,0,1,0,0,0,155,254,146,0,32,56,2,0,200,110,3,0,1,0,0,0,156,254,146,0,152,30,2,0,120,89,3,0,1,0,0,0,157,254,146,0,232,10,2,0,120,74,3,0,1,0,0,0,158,254,146,0,152,138,8,0,192,61,3,0,1,0,0,0,159,254,146,0,48,119,7,0,40,246,1,0,1,0,0,0,193,191,145,0,64,246,1,0,144,236,1,0,1,0,0,0,195,191,145,0,136,224,1,0,176,223,1,0,1,0,0,0,56,246,146,0,72,198,1,0,192,209,1,0,1,0,0,0,57,246,146,0,24,182,1,0,24,198,1,0,1,0,0,0,58,246,146,0,40,167,1,0,120,189,1,0,1,0,0,0,59,246,146,0,200,149,1,0,224,22,1,0,1,0,0,0,60,246,146,0,56,126,1,0,160,14,1,0,1,0,0,0,61,246,146,0,32,101,1,0,176,9,1,0,1,0,0,0,62,246,146,0,96,32,8,0,200,3,1,0,1,0,0,0,63,246,146,0,16,68,7,0,168,132,8,0,1,0,0,0,196,191,145,0,232,209,1,0,72,126,8,0,1,0,0,0,198,191,145,0,144,189,1,0,192,122,8,0,1,0,0,0,128,239,146,0,208,174,1,0,40,116,8,0,1,0,0,0,129,239,146,0,48,160,1,0,72,110,8,0,1,0,0,0,130,239,146,0,160,140,1,0,184,102,8,0,1,0,0,0,131,239,146,0,56,112,1,0,248,67,8,0,1,0,0,0,132,239,146,0,32,92,1,0,136,64,8,0,1,0,0,0,133,239,146,0,64,77,1,0,128,58,8,0,1,0,0,0,134,239,146,0,112,157,4,0,200,53,8,0,1,0,0,0,135,239,146,0,176,194,6,0,232,23,8,0,1,0,0,0,197,191,145,0,104,195,5,0,160,19,8,0,1,0,0,0,199,191,145,0,32,245,8,0,248,16,8,0,1,0,0,0,32,237,146,0,32,231,8,0,192,12,8,0,1,0,0,0,33,237,146,0,88,214,8,0,224,5,8,0,1,0,0,0,34,237,146,0,224,202,8,0,144,1,8,0,1,0,0,0,35,237,146,0,72,193,8,0,176,222,7,0,1,0,0,0,36,237,146,0,144,180,8,0,176,218,7,0,1,0,0,0,37,237,146,0,208,164,8,0,248,214,7,0,1,0,0,0,38,237,146,0,160,152,4,0,64,209,7,0,1,0,0,0,39,237,146,0,40,184,6,0,88,212,3,0,1,0,0,0,104,218,146,0,40,185,3,0,72,65,1,0,9,0,0,0,94,224,146,0,32,58,1,0,48,50,1,0,9,0,0,0,95,224,146,0,32,58,1,0,0,0,0,0,0,0,0,0,184,40,2,0,1,0,0,0,85,0,147,0,248,191,2,0,184,164,8,0,1,0,0,0,86,0,147,0,64,246,1,0,56,250,6,0,1,0,0,0,189,247,146,0,184,160,2,0,88,149,7,0,1,0,0,0,190,247,146,0,136,224,1,0,56,210,6,0,1,0,0,0,80,0,147,0,192,135,2,0,152,122,6,0,1,0,0,0,81,0,147,0,96,82,2,0,192,72,6,0,1,0,0,0,82,0,147,0,32,56,2,0,24,163,6,0,1,0,0,0,83,0,147,0,240,108,2,0,200,110,3,0,1,0,0,0,189,247,146,0,152,30,2,0,176,223,1,0,1,0,0,0,184,247,146,0,72,198,1,0,24,198,1,0,1,0,0,0,185,247,146,0,40,167,1,0,120,189,1,0,1,0,0,0,186,247,146,0,200,149,1,0,192,209,1,0,1,0,0,0,187,247,146,0,24,182,1,0,224,22,1,0,1,0,0,0,190,247,146,0,56,126,1,0,88,212,3,0,1,0,0,0,128,219,146,0,40,185,3,0,232,75,4,0,1,0,0,0,87,0,147,0,216,70,1,0,64,23,5,0,9,0,0,0,202,5,147,0,32,58,1,0,104,20,5,0,9,0,0,0,200,5,147,0,32,58,1,0,216,16,5,0,9,0,0,0,201,5,147,0,32,58,1,0,106,111,106,111,98,97,95,101,117,114,111,95,110,111,99,100,46,50,57,102,52,48,48,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,121,214,226,30,0,0,0,3,106,111,106,111,98,97,40,95,95,57,57,48,57,49,51,41,45,115,105,109,109,49,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,49,98,151,118,0,0,16,1,106,111,106,111,98,97,40,95,95,57,57,48,57,49,51,41,45,115,105,109,109,49,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,231,120,221,206,0,0,16,1,106,111,106,111,98,97,40,95,95,57,57,48,57,49,51,41,45,115,105,109,109,49,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,127,183,85,41,0,0,16,1,106,111,106,111,98,97,40,95,95,57,57,48,57,49,51,41,45,115,105,109,109,49,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,215,57,1,40,0,0,16,1,106,111,106,111,98,97,40,95,95,57,57,48,57,49,51,41,45,115,105,109,109,50,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,20,73,92,48,0,0,16,1,106,111,106,111,98,97,40,95,95,57,57,48,57,49,51,41,45,115,105,109,109,50,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,59,79,175,24,0,0,16,1,106,111,106,111,98,97,40,95,95,57,57,48,57,49,51,41,45,115,105,109,109,50,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,158,92,126,57,0,0,16,1,106,111,106,111,98,97,40,95,95,57,57,48,57,49,51,41,45,115,105,109,109,50,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,215,167,208,169,0,0,16,1,106,111,106,111,98,97,45,115,105,109,109,51,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,17,225,22,77,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,51,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,211,6,52,155,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,51,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,151,73,65,242,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,51,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,125,156,75,149,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,51,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,29,220,90,98,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,51,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,180,11,167,32,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,51,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,175,197,14,161,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,51,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,122,222,208,11,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,52,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,220,74,161,110,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,52,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,251,66,76,143,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,52,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,209,134,5,239,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,52,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,112,196,204,147,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,52,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,210,199,158,61,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,52,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,80,104,230,3,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,52,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,195,106,96,1,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,52,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,135,43,57,54,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,53,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,12,198,248,46,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,53,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,166,124,125,207,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,53,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,250,91,129,183,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,53,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,73,192,254,155,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,53,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,107,83,103,209,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,53,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,66,160,231,85,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,53,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,6,41,179,79,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,53,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,32,229,139,140,0,0,32,0,117,51,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,59,145,76,249,1,0,16,1,117,52,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,190,162,39,2,1,0,16,1,117,54,52,46,51,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,58,113,216,17,3,0,32,0,117,54,51,46,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,240,94,56,122,3,0,32,0])
.concat([117,54,54,46,53,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,197,64,175,187,4,0,32,0,117,54,53,46,52,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,175,92,163,165,28,0,32,0,117,54,56,46,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,31,224,154,174,5,0,32,0,117,54,55,46,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,142,72,53,162,29,0,32,0,117,55,48,46,49,48,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,184,85,26,24,6,0,64,0,168,86,7,0,1,0,0,0,32,252,146,0,248,191,2,0,24,38,7,0,1,0,0,0,31,252,146,0,184,160,2,0,56,210,6,0,1,0,0,0,24,252,146,0,192,135,2,0,24,163,6,0,1,0,0,0,25,252,146,0,240,108,2,0,152,122,6,0,1,0,0,0,26,252,146,0,96,82,2,0,192,72,6,0,1,0,0,0,27,252,146,0,32,56,2,0,200,110,3,0,1,0,0,0,28,252,146,0,152,30,2,0,120,89,3,0,1,0,0,0,29,252,146,0,232,10,2,0,120,74,3,0,1,0,0,0,30,252,146,0,152,138,8,0,40,246,1,0,1,0,0,0,232,243,146,0,64,246,1,0,144,236,1,0,1,0,0,0,231,243,146,0,136,224,1,0,176,223,1,0,1,0,0,0,224,243,146,0,72,198,1,0,192,209,1,0,1,0,0,0,225,243,146,0,24,182,1,0,24,198,1,0,1,0,0,0,226,243,146,0,40,167,1,0,120,189,1,0,1,0,0,0,227,243,146,0,200,149,1,0,224,22,1,0,1,0,0,0,228,243,146,0,56,126,1,0,160,14,1,0,1,0,0,0,229,243,146,0,32,101,1,0,176,9,1,0,1,0,0,0,230,243,146,0,96,32,8,0,88,212,3,0,1,0,0,0,200,216,146,0,40,185,3,0,32,77,1,0,1,0,0,0,33,252,146,0,216,70,1,0,16,17,8,0,1,0,0,0,233,243,146,0,224,12,8,0,168,86,7,0,1,0,0,0,123,191,145,0,248,191,2,0,24,38,7,0,1,0,0,0,125,191,145,0,184,160,2,0,56,210,6,0,1,0,0,0,136,251,146,0,192,135,2,0,24,163,6,0,1,0,0,0,137,251,146,0,240,108,2,0,152,122,6,0,1,0,0,0,138,251,146,0,96,82,2,0,192,72,6,0,1,0,0,0,139,251,146,0,32,56,2,0,200,110,3,0,1,0,0,0,140,251,146,0,152,30,2,0,120,89,3,0,1,0,0,0,141,251,146,0,232,10,2,0,40,246,1,0,1,0,0,0,124,191,145,0,64,246,1,0,144,236,1,0,1,0,0,0,126,191,145,0,136,224,1,0,176,223,1,0,1,0,0,0,88,243,146,0,72,198,1,0,192,209,1,0,1,0,0,0,89,243,146,0,24,182,1,0,24,198,1,0,1,0,0,0,90,243,146,0,40,167,1,0,120,189,1,0,1,0,0,0,91,243,146,0,200,149,1,0,224,22,1,0,1,0,0,0,92,243,146,0,56,126,1,0,160,14,1,0,1,0,0,0,93,243,146,0,32,101,1,0,88,212,3,0,1,0,0,0,64,216,146,0,40,185,3,0,32,77,1,0,1,0,0,0,120,191,145,0,216,70,1,0,72,65,1,0,9,0,0,0,170,223,146,0,32,58,1,0,48,50,1,0,9,0,0,0,171,223,146,0,32,58,1,0,224,41,1,0,9,0,0,0,173,223,146,0,32,58,1,0,0,0,0,0,0,0,0,0,116,112,45,48,50,54,45,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,106,116,177,247,0,0,16,1,116,112,45,48,50,54,45,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,152,141,87,229,0,0,32,0,116,112,45,48,50,54,45,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,83,203,96,183,0,0,32,0,116,112,45,48,50,54,45,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,31,63,6,133,0,0,64,0,57,51,99,52,53,46,117,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,240,93,215,64,0,0,16,1,102,105,120,101,105,103,104,116,117,116,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,238,147,205,159,0,0,16,1,116,112,45,48,50,54,45,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,106,116,177,247,0,0,16,1,116,112,45,48,50,54,45,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,152,141,87,229,0,0,32,0,116,112,45,48,50,54,45,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,83,203,96,183,0,0,32,0,116,112,45,48,50,54,45,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,31,63,6,133,0,0,64,0,57,51,99,52,53,46,117,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,240,93,215,64,0,0,16,1,102,105,120,101,105,103,104,116,116,119,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,185,175,230,116,0,0,16,1,116,112,45,48,50,54,45,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,106,116,177,247,0,0,16,1,116,112,45,48,50,54,45,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,152,141,87,229,0,0,32,0,116,112,45,48,50,54,45,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,83,203,96,183,0,0,32,0,116,112,45,48,50,54,45,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,31,63,6,133,0,0,64,0,57,51,99,52,53,46,117,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,240,93,215,64,0,0,16,1,102,105,120,101,105,103,104,116,107,116,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,186,115,250,8,0,0,16,1,116,112,45,48,50,54,45,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,106,116,177,247,0,0,16,1,116,112,45,48,50,54,45,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,152,141,87,229,0,0,32,0,116,112,45,48,50,54,45,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,83,203,96,183,0,0,32,0,116,112,45,48,50,54,45,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,31,63,6,133,0,0,64,0,57,51,99,52,53,46,117,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,240,93,215,64,0,0,16,1,102,105,120,101,105,103,104,116,106,116,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,237,79,209,227,0,0,16,1,116,112,45,48,50,54,45,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,106,116,177,247,0,0,16,1,116,112,45,48,50,54,45,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,152,141,87,229,0,0,32,0,116,112,45,48,50,54,45,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,83,203,96,183,0,0,32,0,116,112,45,48,50,54,45,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,31,63,6,133,0,0,64,0,57,51,99,52,53,46,117,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,240,93,215,64,0,0,16,1,102,105,120,101,105,103,104,116,104,116,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,81,170,237,87,0,0,16,1,116,112,45,48,50,54,45,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,106,116,177,247,0,0,16,1,116,112,45,48,50,54,45,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,152,141,87,229,0,0,32,0,116,112,45,48,50,54,45,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,83,203,96,183,0,0,32,0,116,112,45,48,50,54,45,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,31,63,6,133,0,0,64,0,57,51,99,52,53,46,117,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,240,93,215,64,0,0,16,1,102,105,120,101,105,103,104,116,97,116,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,135,25,194,233,0,0,16,1,111,49,55,95,48,57,100,121,104,46,56,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,221,20,76,123,0,0,16,1,111,49,55,95,49,48,100,121,104,46,56,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,249,89,241,163,0,0,16,1,111,49,55,95,49,49,120,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,120,195,234,107,0,0,16,1,111,49,55,95,49,50,120,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,181,110,219,106,0,0,16,1,111,49,55,95,48,53,46,49,50,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,248,21,83,86,0,0,32,0,111,49,55,95,48,54,46,49,51,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,76,45,38,149,0,0,32,0,111,49,55,95,48,55,46,49,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,92,115,75,76,0,0,32,0,111,49,55,95,48,56,46,49,51,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,108,88,198,149,0,0,32,0,111,49,55,95,48,49,46,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,145,228,18,234,0,0,32,0,111,49,55,95,48,50,46,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,159,58,161,50,0,0,32,0,111,49,55,95,48,51,46,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,201,61,114,104,0,0,32,0,111,49,55,95,48,52,46,55,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,19,203,14,254,0,0,32,0,112,114,111,109,49,52,46,50,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,237,204,136,188,0,0,32,0,112,114,111,109,49,53,46,50,48,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,146,116,225,161,0,0,32,0,104,100,54,52,55,49,56,48,46,48,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,24,168,86,7,0,1,0,0,0,192,253,146,0,248,191,2,0,24,38,7,0,1,0,0,0,191,253,146,0,184,160,2,0,56,210,6,0,1,0,0,0,184,253,146,0,192,135,2,0,24,163,6,0,1,0,0,0,185,253,146,0,240,108,2,0,152,122,6,0,1,0,0,0,186,253,146,0,96,82,2,0,192,72,6,0,1,0,0,0,187,253,146,0,32,56,2,0,200,110,3,0,1,0,0,0,188,253,146,0,152,30,2,0,120,89,3,0,1,0,0,0,189,253,146,0,232,10,2,0,120,74,3,0,1,0,0,0,190,253,146,0,152,138,8,0,40,246,1,0,1,0,0,0,112,245,146,0,64,246,1,0,144,236,1,0,1,0,0,0,111,245,146,0,136,224,1,0,176,223,1,0,1,0,0,0,104,245,146,0,72,198,1,0,192,209,1,0,1,0,0,0,105,245,146,0,24,182,1,0,24,198,1,0,1,0,0,0,106,245,146,0,40,167,1,0,120,189,1,0,1,0,0,0,107,245,146,0,200,149,1,0,224,22,1,0,1,0,0,0,108,245,146,0,56,126,1,0,160,14,1,0,1,0,0,0,109,245,146,0,32,101,1,0,176,9,1,0,1,0,0,0,110,245,146,0,96,32,8,0,88,212,3,0,1,0,0,0,208,217,146,0,40,185,3,0,32,77,1,0,1,0,0,0,193,253,146,0,216,70,1,0,16,17,8,0,1,0,0,0,113,245,146,0,224,12,8,0,27,0,0,0,255,255,3,0,0,0,0,0,0,0,0,0,116,48,49,115,46,117,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,160,35,113,26,0,0,32,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,103,81,243,25,160,17,177,17,176,238,227,246,190,129,53,227,251,230,239,223,97,1,250,34,93,67,1,165,59,23,212,116,240,244,243,67,181,25,4,213,132,206,135,254,53,62,196,60,199,133,42,51,0,134,208,77,101,75,249,233,192,186,170,119,158,102,246,15,79,58,182,241,100,154,233,37,26,95,34,163,162,191,75,119,63,52,201,110,219,18,92,51,165,139,108,177,116,200,64,78,47,231,70,174,153,252,176,85,84,223,167,161,15,94,73,207,86,60,144,43,172,101,110,219,88,62,201,0,174,83,77,146,250,64,178,107,101,75,144,138,12,226,165,154,208,32,41,85,164,68,172,81,135,84,83,52,36,75,129,103,52,76,95,49,78,242,241,25,24,28,52,56,225,129,23,207,36,185,154,203,52,81,80,89,68,177,11,80,149,108,72,126,20,164,198,217,211,165,214,208,197,151,240,69,208,152,81,145,159,163,67,81,5,144,238,202,126,95,114,83,177,211,175,54,8,117,176,155,224,13,67,136,170,39,68,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,65,243,57,160,17,161,17,176,162,76,35,19,233,37,61,15,114,58,157,181,150,209,218,7,41,65,154,173,112,186,70,99,43,127,61,190,64,173,212,76,115,39,88,167,101,220,214,253,222,181,110,214,108,117,26,50,69,213,227,106,20,109,128,132,21,175,204,123,97,81,130,64,83,127,56,160,214,143,97,121,25,229,153,132,216,120,39,63,22,151,120,79,123,12,166,55,219,198,12,36,180,199,148,157,146,210,59,213,17,111,10,219,118,102,231,205,24,43,102,216,65,64,88,162,1,30,109,68,117,231,25,79,178,232,196,150,119,98,2,201,220,89,243,67,141,200,254,158,42,186,50,59,98,227,146,110,194,8,77,81,205,249,58,62,201,80,39,33,37,151,215,14,248,57,56,245,134,148,147,191,235,24,168,252,36,245,249,153,32,61,205,44,148,37,121,40,119,143,47,16,105,134,48,67,1,215,154,23,227,71,55,189,98,117,66,120,244,43,87,76,10,219,83,77,161,10,214,58,22,21,170,44,108,57,66,18,9,243,41,160,17,160,17,176,213,102,161,40,74,33,192,211,155,134,128,87,111,65,194,228,47,11,145,189,58,122,186,0,229,53,2,116,125,139,33,87,16,15,174,68,187,226,55,24,123,82,61,140,89,158,32,31,10,204,28,142,106,215,149,43,52,176,130,109,253,37,51,170,59,43,112,21,135,49,93,187,41,25,149,213,142,36,40,94,208,32,131,70,74,33,112,91,205,174,123,97,161,250,244,43,132,21,110,54,93,27,36,15,9,58,97,56,15,24,53,17,56,180,189,238,247,236,15,29,183,72,1,170,9,143,97,181,15,29,38,57,46,140,214,38,92,61,35,99,233,107,151,180,159,123,182,186,160,124,198,37,161,115,54,103,127,116,30,29,218,112,191,165,99,53,57,36,140,159,133,22,216,80,149,113,192,246,30,109,128,237,21,235,99,233,27,246,120,49,198,92,221,25,189,223,167,236,80,34,173,187,246,235,214,163,32,201,230,159,203,242,151,185,84,18,102,166,190,74,18,67,236,0,234,73,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,40,2,0,1,0,0,0,85,0,147,0,248,191,2,0,184,164,8,0,1,0,0,0,87,0,147,0,64,246,1,0,56,250,6,0,1,0,0,0,189,247,146,0,184,160,2,0,88,149,7,0,1,0,0,0,190,247,146,0,136,224,1,0,56,210,6,0,1,0,0,0,80,0,147,0,192,135,2,0,152,122,6,0,1,0,0,0,81,0,147,0,96,82,2,0,192,72,6,0,1,0,0,0,82,0,147,0,32,56,2,0,24,163,6,0,1,0,0,0,83,0,147,0,240,108,2,0,200,110,3,0,1,0,0,0,84,0,147,0,152,30,2,0,176,223,1,0,1,0,0,0,184,247,146,0,72,198,1,0,24,198,1,0,1,0,0,0,185,247,146,0,40,167,1,0,120,189,1,0,1,0,0,0,186,247,146,0,200,149,1,0,192,209,1,0,1,0,0,0,187,247,146,0,24,182,1,0,224,22,1,0,1,0,0,0,188,247,146,0,112,50,4,0,88,212,3,0,1,0,0,0,128,219,146,0,40,185,3,0,64,23,5,0,9,0,0,0,202,5,147,0,32,58,1,0,104,20,5,0,9,0,0,0,200,5,147,0,32,58,1,0,216,16,5,0,9,0,0,0,201,5,147,0,32,58,1,0,88,12,5,0,9,0,0,0,203,5,147,0,32,58,1,0,112,114,103,107,46,117,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,139,76,175,187,0,0,16,1,97,116,100,112,46,117,52,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,83,233,137,113,0,0,32,0,97,116,100,112,46,117,52,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,63,23,132,105,0,0,32,0,97,116,100,112,46,117,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,102,107,218,107,0,0,32,0,97,116,100,112,46,117,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,185,114,14,10,0,0,32,0,117,53,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,255,121,83,40,0,0,32,0,97,116,100,112,46,117,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,202,252,137,13,0,0,64,0,97,116,100,112,46,117,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,222,73,215,0,0,64,0,101,101,112,114,111,109,45,100,111,110,112,97,99,104,105,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,70,181,95,49,0,0,16,1,112,101,101,108,49,56,99,118,56,112,45,49,53,46,117,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,85,1,0,0,233,135,71,63,0,0,0,8,51,55,46,117,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,48,159,243,113,0,0,16,1,97,116,100,112,46,117,52,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,83,233,137,113,0,0,32,0,97,116,100,112,46,117,52,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,63,23,132,105,0,0,32,0,97,116,100,112,46,117,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,102,107,218,107,0,0,32,0,97,116,100,112,46,117,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,185,114,14,10,0,0,32,0,117,53,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,255,121,83,40,0,0,32,0,97,116,100,112,46,117,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,202,252,137,13,0,0,64,0,97,116,100,112,46,117,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,222,73,215,0,0,64,0,101,101,112,114,111,109,45,100,111,110,112,97,99,104,105,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,70,181,95,49,0,0,16,1,112,101,101,108,49,56,99,118,56,112,45,49,53,46,117,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,85,1,0,0,233,135,71,63,0,0,0,8,168,86,7,0,1,0,0,0,240,254,146,0,248,191,2,0,24,38,7,0,1,0,0,0,239,254,146,0,184,160,2,0,56,210,6,0,1,0,0,0,232,254,146,0,192,135,2,0,24,163,6,0,1,0,0,0,233,254,146,0,240,108,2,0,152,122,6,0,1,0,0,0,234,254,146,0,96,82,2,0,192,72,6,0,1,0,0,0,235,254,146,0,32,56,2,0,200,110,3,0,1,0,0,0,236,254,146,0,152,30,2,0,120,89,3,0,1,0,0,0,237,254,146,0,232,10,2,0,120,74,3,0,1,0,0,0,238,254,146,0,152,138,8,0,40,246,1,0,1,0,0,0,144,246,146,0,64,246,1,0,144,236,1,0,1,0,0,0,143,246,146,0,136,224,1,0,176,223,1,0,1,0,0,0,136,246,146,0,72,198,1,0,192,209,1,0,1,0,0,0,137,246,146,0,24,182,1,0,24,198,1,0,1,0,0,0,138,246,146,0,40,167,1,0,120,189,1,0,1,0,0,0,139,246,146,0,200,149,1,0,224,22,1,0,1,0,0,0,140,246,146,0,56,126,1,0,160,14,1,0,1,0,0,0,141,246,146,0,32,101,1,0,176,9,1,0,1,0,0,0,142,246,146,0,96,32,8,0,88,212,3,0,1,0,0,0,168,218,146,0,40,185,3,0,32,77,1,0,1,0,0,0,241,254,146,0,216,70,1,0,16,17,8,0,1,0,0,0,145,246,146,0,224,12,8,0,2,7,5,7,1,1,4,4,7,5,6,7,7,3,4,3,0,2,1,3,0,4,7,7,2,5,3,1,4,4,6,7,6,7,4,5,1,3,0,3,7,2,5,0,1,5,2,1,4,0,6,1,1,2,4,2,1,0,6,5,2,6,4,6,4,4,2,2,0,6,0,4,6,0,1,7,0,6,1,2,5,0,1,5,0,2,6,2,2,7,0,7,2,4,6,3,3,5,1,1,2,3,4,1,4,6,1,4,0,6,6,3,5,4,1,1,3,0,5,7,5,4,5,4,3,6,2,0,4,5,7,3,1,3,4,7,7,4,2,7,1,6,4,1,1,4,0,4,2,0,4,0,1,5,6,4,7,7,3,7,7,0,1,2,6,7,7,0,5,1,2,4,2,0,4,4,7,4,0,3,7,1,7,4,2,5,7,4,3,7,3,6,7,3,0,5,1,7,5,3,0,1,6,1,7,4,7,6,5,1,2,7,3,3,1,4,6,2,3,7,0,4,5,6,3,2,3,1,7,6,0,1,5,7,4,0,5,1,4,1,2,0,6,4,3,5,7,4,3,0,0,6,5,1,7,6,0,2,4,0,0,5,4,7,4,3,3,0,2,3,5,7,0,3,2,3,7,2,0,0,7,6,3,5,0,1,3,2,4,7,2,3,4,7,1,5,6,7,3,6,4,1,7,7,4,4,3,4,0,7,5,3,2,5,7,7,0,4,0,7,7,2,5,1,2,4,7,6,0,6,7,0,5,0,1,6,5,0,2,4,5,1,6,7,6,0,7,0,6,0,1,4,3,2,0,2,4,6,3,2,3,3,0,5,7,2,3,7,1,2,6,3,7,2,0,5,7,1,2,6,4,3,4,6,4,0,1,4,2,3,3,2,3,7,0,7,4,3,2,1,0,3,5,2,5,3,0,0,0,4,6,4,4,6,1,0,3,1,1,5,7,1,5,2,0,1,5,7,2,4,5,4,2,6,3,1,4,0,3,0,1,7,3,5,1,1,1,2,2,3,4,1,2,0,0,7,1,6,1,5,2,2,2,1,6,6,0,5,5,4,2,3,7,4,6,6,6,3,1,3,3,0,1,7,4,6,3,7,0,1,4,2,3,3,1,7,6,0,6,4,1,3,6,1,6,2,3,1,6,5,3,4,2,1,3,3,1,6,6,3,6,6,5,0,1,7,1,0,4,6,0,6,0,0,3,6,5,6,4,0,4,2,6,5,0,4,2,7,6,2,4,6,6,4,6,6,0,5,6,6,5,2,3,0,4,4,6,4,1,6,6,0,7,0,1,6,1,2,2,4,6,4,2,5,4,2,2,5,4,1,3,3,4,5,3,4,5,6,3,5,2,3,7,6,1,0,4,4,7,6,0,5,2,6,2,2,3,7,1,5,4,2,6,7,0,5,5,2,5,7,5,6,2,3,0,5,4,5,2,1,0,5,3,6,7,2,3,4,0,3,5,7,6,6,5,6,7,2,2,2,3,5,0,2,0,1,2,2,4,6,7,2,5,4,4,3,5,7,3,4,5,3,4,7,1,2,3,5,3,3,6,0,4,4,2,5,4,1,7,2,7,7,4,5,2,1,0,3,4,1,3,6,2,4,3,3,3,0,0,1,2,0,3,3,6,5,6,7,5,2,0,4,2,0,1,6,7,1,0,4,1,7,5,2,3,0,2,7,2,2,4,6,7,5,7,5,0,6,5,3,2,7,2,3,3,6,0,4,1,5,2,2,5,6,4,1,3,6,2,7,4,3,4,1,6,0,5,6,0,0,3,1,1,2,4,3,4,1,4,2,0,3,0,7,6,3,2,0,2,3,6,5,3,3,6,6,2,4,5,4,1,5,1,6,0,7,5,5,4,7,3,7,4,3,5,0,7,4,4,3,5,5,7,7,2,4,6,6,7,0,7,6,1,0,2,4,0,2,3,5,4,6,3,5,2,4,2,4,2,4,5,2,6,5,2,4,6,2,2,2,4,4,2,1,4,0,1,1,1,4,7,0,3,1,7,5,7,5,5,4,1,0,2,3,5,3,3,7,2,6,1,2,7,4,1,5,2,4,2,5,4,0,5,0,5,4,1,3,5,1,7,4,2,2,1,3,3,7,6,3,2,1,7,5,3,2,4,6,6,5,6,2,0,2,5,3,4,2,3,4,0,2,6,3,4,6,6,7,3,0,3,0,1,0,2,7,4,6,0,3,5,2,5,5,5,3,6,4,7,3,5,3,7,1,1,3,1,5,7,3,0,4,6,5,3,3,2,3,0,7,0,5,1,1,7,2,2,0,0,6,7,6,7,6,3,4,7,3,7,6,6,0,7,6,3,0,0,6,2,7,1,0,2,7,6,2,2,2,7,1,3,2,3,4,1,3,1,7,5,2,0,7,7,0,6,1,6,0,2,2,6,7,0,6,7,0,6,4,0,1,6,6,6,0,1,3,4,4,4,1,2,2,7,3,7,2,4,4,3,4,0,3,1,0,0,7,3,3,6,5,0,4,3,5,5,0,1,7,2,3,3,0,6,6,5,6,4,0,6,0,1,7,5,4,2,6,3,7,4,4,5,6,7,6,1,7,2,5,5,5,1,4,3,0,6,3,2,3,0,2,0,0,0,1,0,6,3,7,7,4,3,2,3,4,6,4,2,0,5,3,3,6,4,3,5,1,4,0,0,1,0,5,2,1,6,3,3,1,1,6,2,0,3,0,7,0,2,0,5,3,6,6,0,6,2,4,0,3,0,1,2,1,6,4,5,2,3,4,1,2,0,6,7,0,5,5,0,0,3,7,1,4,1,2,7,3,4,7,4,4,5,5,7,0,4,2,0,7,4,4,7,2,7,2,1,7,4,5,5,7,7,4,0,5,2,2,7,0,5,3,3,2,0,5,2,1,1,7,0,5,4,3,1,3,2,5,3,4,5,3,4,6,2,2,2,5,4,2,1,3,1,4,7,5,5,7,3,2,0,4,6,0,4,1,6,5,6,1,3,0,1,1,0,4,5,1,5,0,2,3,7,2,5,6,0,6,4,2,6,1,5,6,3,3,5,0,3,2,0,0,1,2,1,0,2,7,5,1,6,4,1,7,6,5,3,2,3,4,3,2,7,1,6,2,3,2,4,3,4,7,0,5,2,0,6,7,2,0,3,7,6,7,4,0,4,3,7,7,5,2,6,6,7,6,3,6,6,1,6,2,3,1,5,1,0,5,1,0,3,7,4,5,0,3,2,1,3,5,3,1,1,7,4,2,1,2,3,0,4,7,1,1,6,3,6,4,0,2,7,1,0,5,4,6,1,2,7,1,3,6,5,2,3,0,5,7,3,5,5,2,2,6,1,6,0,4,5,7,3,4,0,7,0,5,4,3,6,5,7,0,1,0,0,7,3,3,4,4,1,4,7,1,2,0,0,7,0,5,3,4,6,3,4,6,4,2,5,0,7,5,5,6,6,7,6,7,3,4,5,0,5,5,7,5,4,4,1,4,3,1,4,3,3,2,5,7,6,3,0,4,1,2,5,4,4,3,0,2,7,5,5,7,3,7,3,3,7,0,0,5,3,1,4,4,6,0,1,3,1,4,7,2,1,1,4,1,0,7,4,5,2,7,2,4,5,7,3,3,7,6,4,4,5,3,2,4,0,3,5,5,5,4,3,6,7,7,5,1,3,0,2,6,3,2,0,4,6,7,4,6,7,2,0,6,7,2,5,0,1,3,0,2,4,7,5,1,4,7,7,4,2,3,6,4,3,2,0,4,0,6,0,0,5,7,0,4,0,4,6,3,6,0,0,3,1,0,1,2,6,2,1,0,5,7,6,4,5,4,1,2,3,6,6,1,3,1,1,2,4,3,1,4,1,0,4,2,0,3,2,1,1,1,1,6,2,1,3,0,6,6,2,5,5,5,2,6,7,6,1,1,3,1,1,6,0,2,6,0,3,6,0,6,3,4,3,3,0,2,0,1,5,6,5,0,5,3,4,2,7,5,6,4,4,1,1,4,7,7,1,2,3,6,1,6,4,5,3,6,5,1,7,1,0,6,6,2,6,2,6,0,2,2,6,1,0,2,5,6,6,7,4,4,7,6,1,0,1,4,3,1,2,1,4,1,4,6,2,5,1,2,0,2,3,4,3,0,3,7,7,6,5,1,7,3,1,0,6,1,1,3,0,7,4,3,1,3,7,6,1,5,4,3,5,4,7,0,2,5,4,5,1,6,3,7,4,5,6,7,3,6,1,2,3,3,6,6,1,5,2,0,7,2,5,4,1,7,6,6,0,1,7,5,2,4,1,2,0,2,2,2,7,4,3,0,6,0,7,2,1,7,5,1,7,1,2,2,4,3,1,3,6,5,5,0,2,6,2,6,0,1,4,1,1,4,3,2,6,0,6,3,7,5,6,0,7,7,7,2,0,4,2,5,6,3,4,3,2,0,3,1,6,2,3,3,6,7,1,5,6,6,4,0,6,1,1,6,2,0,7,6,3,2,5,6,0,4,2,4,4,2,5,7,5,4,4,1,6,3,4,6,5,5,6,0,0,4,4,7,2,2,1,3,4,4,1,7,0,2,5,4,7,3,7,6,1,5,6,0,7,4,1,1,5,2,2,6,7,2,4,0,7,2,0,0,7,2,0,1,6,3,2,2,2,2,0,5,6,3,7,0,0,5,1,1,1,7,1,0,0,0,2,5,6,6,2,0,4,1,5,0,1,7,4,7,0,4,6,2,1,5,3,1,2,4,6,4,2,0,4,3,3,7,2,7,0,6,0,5,0,2,2,6,4,0,3,5,5,7,0,4,7,5,4,5,6,3,5,5,3,6,2,0,0,4,2,3,7,5,6,4,7,4,3,2,0,0,0,1,5,4,0,3,7,3,1,6,4,1,2,6,7,4,1,3,0,7,1,7,2,6,5,6,5,1,6,7,0,3,4,6,5,0,6,2,2,6,4,6,7,3,2,3,2,4,0,0,4,5,6,5,0,3,0,6,0,6,0,6,7,1,3,5,0,4,5,3,7,4,3,3,5,1,2,1,6,7,1,6,7,6,0,5,2,4,5,1,0,6,3,3,4,1,0,1,1,6,3,4,7,0,4,1,6,5,5,2,2,3,5,3,0,6,6,7,4,4,7,3,3,2,0,6,3,0,4,7,7,6,1,1,1,7,1,5,3,7,6,4,6,2,2,4,1,5,4,6,5,3,5,5,4,2,7,4,7,4,3,3,5,7,4,0,3,0,4,3,2,2,2,5,0,3,5,7,0,7,2,7,7,7,2,3,3,6,4,0,3,7,2,5,1,2,1,0,5,4,3,5,5,3,6,3,4,6,2,2,1,4,2,5,4,3,0,4,0,3,6,4,7,1,7,2,3,7,6,2,3,3,4,1,5,7,0,0,6,7,5,2,2,7,1,5,7,4,6,3,0,4,4,3,6,6,5,1,1,6,6,1,1,5,1,5,1,4,1,6,5,6,2,6,6,0,7,7,3,4,0,3,5,7,4,5,1,6,1,7,5,6,4,6,7,0,7,6,5,2,4,6,2,5,5,3,6,6,5,6,2,5,1,7,6,1,3,5,1,4,6,6,6,4,6,0,4,2,5,6,5,0,4,5,1,1,2,2,1,3,4,7,3,3,2,0,2,7,6,3,3,3,2,6,4,5,6,4,0,0,6,5,2,5,1,6,1,5,0,2,4,0,0,5,6,0,5,1,7,1,5,7,6,5,7,3,2,1,2,0,4,5,7,4,3,5,0,6,1,6,1,6,2,6,3,5,6,3,1,1,6,6,4,0,0,7,5,3,2,4,4,3,4,3,3,2,3,3,6,0,1,6,0,7,7,7,6,7,5,5,7,0,6,7,4,7,3,5,4,5,0,1,1,7,0,4,1,0,0,3,2,6,2,6,4,5,4,6,3,3,4,4,7,4,4,5,3,3,0,0,3,5,2,5,3,4,4,0,5,2,6,5,6,3,0,5,2,3,3,2,5,7,0,4,1,7,0,5,7,5,3,6,1,5,2,4,3,4,7,7,5,7,7,5,5,2,5,4,7,2,5,5,2,0,3,3,6,4,7,1,7,5,5,0,6,3,4,3,7,7,1,0,2,2,3,0,2,0,6,5,4,0,4,5,6,0,3,7,5,0,3,4,0,6,7,0,2,3,6,3,5,6,3,4,6,0,1,1,2,2,1,6,6,1,6,1,2,6,0,6,5,4,5,5,5,4,7,3,6,6,5,6,5,5,0,6,4,2,2,4,2,7,5,7,7,0,1,5,5,3,4,1,6,4,3,0,1,5,0,2,0,7,4,1,6,4,5,3,4,4,4,6,5,4,7,6,5,1,6,3,6,6,0,1,2,2,7,6,5,1,0,2,7,4,3,6,5,5,4,5,6,5,5,0,6,7,0,5,3,0,7,0,6,0,3,3,4,6,0,3,5,7,4,5,0,1,1,5,3,4,3,5,2,6,6,1,1,2,7,1,2,1,5,7,3,2,3,6,7,5,4,7,1,7,2,1,7,0,5,5,1,2,6,5,0,6,5,6,3,0,5,3,0,5,5,1,0,3,0,5,1,5,6,3,2,7,4,1,0,5,6,3,7,5,1,3,0,3,1,0,0,1,1,7,4,0,7,4,4,5,4,7,3,7,6,6,1,1,2,5,7,6,4,1,1,5,6,7,1,1,2,7,1,3,6,4,1,3,6,3,5,3,5,6,2,0,4,5,3,5,1,1,0,4,2,6,6,5,3,2,5,5,1,0,4,3,5,7,6,3,4,4,7,1,6,2,2,2,0,3,3,4,5,1,6,2,0,5,3,0,7,3,6,3,6,7,4,0,0,3,7,4,6,1,1,1,6,0,0,0,7,1,2,3,5,5,2,3,0,3,7,2,5,1,3,5,4,0,4,6,2,2,0,7,7,7,2,5,3,4,7,7,3,2,3,5,4,1,6,7,0,7,3,7,0,6,0,2,7,6,2,6,1,6,5,0,0,0,2,2,2,2,5,5,5,6,5,0,4,1,1,2,2,0,3,5,5,5,6,3,5,1,3,0,1,4,1,0,0,3,1,5,3,1,0,5,5,6,4,5,3,0,3,3,1,4,4,4,4,2,7,7,7,0,1,6,1,1,1,7,7,5,6,4,7,5,3,6,6,1,1,6,7,1,4,4,7,7,6,0,6,4,6,7,6,6,3,3,1,1,3,7,3,1,0,4,4,3,4,2,2,4,7,1,5,1,5,0,3,4,7,3,7,4,5,3,5,4,0,2,0,7,6,0,4,0,6,0,7,1,3,4,7,0,0,6,7,5,7,7,2,2,0,7,2,4,7,1,6,1,1,5,5,5,2,5,3,5,1,1,5,0,5,4,3,2,2,0,3,1,2,2,6,7,2,7,4,1,4,5,6,0,1,0,6,4,2,1,7,2,2,2,4,1,3,0,3,5,7,2,1,1,3,6,2,5,5,7,4,2,7,5,5,5,1,4,4,0,7,2,0,6,0,6,2,5,4,7,6,2,1,2,4,5,1,2,3,5,1,6,2,3,0,0,7,5,0,1,0,5,7,7,0,7,2,6,0,0,3,6,1,0,4,0,5,1,5,7,4,3,1,5,7,7,6,4,7,3,3,4,6,5,0,4,7,6,4,1,2,4,0,4,3,1,5,6,3,1,7,0,2,4,0,2,6,0,7,0,3,3,4,5,2,2,0,6,6,0,3,7,7,1,5,0,2,1,5,1,1,5,2,4,5,3,1,6,4,7,6,3,4,3,5,3,6,7,7,4,4,3,2,4,0,6,7,4,1,6,2,6,0,2,3,5,3,0,2,2,5,5,2,3,1,5,1,0,0,0,6,3,6,3,3,5,6,4,0,4,2,6,3,5,1,2,7,1,3,0,3,3,0,2,3,2,7,0,7,7,4,6,2,4,7,0,7,5,6,7,2,2,0,2,5,0,0,3,2,7,3,3,5,7,5,4,3,6,2,2,6,4,3,7,2,6,5,7,7,7,6,0,2,6,7,2,4,0,1,0,3,5,3,4,3,1,7,7,5,4,0,1,6,3,0,7,6,4,5,4,7,3,0,5,3,5,0,6,2,3,5,0,4,2,5,3,1,1,3,7,4,1,2,7,7,4,1,6,3,7,7,7,6,6,4,1,1,3,1,3,4,7,5,6,2,7,2,5,1,1,6,7,0,7,6,3,4,1,4,0,1,2,6,0,5,2,2,2,7,7,1,7,0,0,4,5,3,3,7,5,0,4,4,4,0,5,7,0,0,6,7,7,4,1,1,6,1,1,0,1,4,5,2,6,0,4,4,5,7,0,3,7,4,6,6,2,1,7,6,4,7,1,7,2,5,5,6,6,5,5,0,5,2,0,3,4,4,7,3,7,1,2,1,2,4,0,3,3,3,4,2,3,0,1,7,0,0,0,4,0,7,2,1,5,6,3,4,6,2,6,6,3,5,4,3,4,0,4,7,4,7,7,0,2,1,6,7,0,6,7,5,7,4,0,3,4,5,4,6,7,1,7,5,3,6,7,1,7,1,0,5,5,7,3,2,6,7,4,4,2,6,7,3,4,1,7,4,1,5,3,3,5,3,4,6,4,4,6,0,4,2,6,0,4,3,1,7,2,7,7,1,7,1,0,4,6,4,7,1,7,6,3,3,3,6,0,3,6,2,3,6,2,6,4,5,3,1,2,1,6,7,5,0,0,4,0,7,0,6,1,1,2,2,7,6,2,5,4,4,6,3,5,4,7,3,1,4,0,0,2,4,1,4,6,3,6,0,7,2,3,0,7,7,1,7,0,1,2,7,3,7,2,7,5,1,3,6,2,7,2,0,1,3,5,2,3,4,4,2,4,4,3,4,4,0,3,7,2,6,6,6,0,0,7,1,0,1,5,0,1,7,1,4,3,7,7,6,1,0,4,3,3,1,2,0,5,6,3,1,2,5,6,0,0,0,4,2,0,1,6,2,4,0,1,5,4,7,1,2,2,7,7,5,3,6,3,3,5,4,0,5,3,0,1,5,5,4,0,5,0,1,1,3,6,4,2,3,1,5,5,7,4,0,5,7,0,6,6,6,6,7,3,2,2,5,4,0,6,1,1,6,0,4,3,2,0,4,0,3,4,7,3,3,5,7,1,3,5,2,3,6,5,6,0,1,1,6,0,6,1,7,2,4,5,6,5,0,4,0,3,2,3,7,7,0,3,5,0,4,1,1,1,117,50,55,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,174,153,184,68,0,0,16,1,117,50,54,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,9,122,114,0,0,16,1,117,53,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,236,96,178,20,0,0,32,0,117,53,49,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,72,81,62,15,0,0,32,0,117,53,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,224,46,73,2,0,0,32,0,117,53,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,240,16,76,203,0,0,32,0,117,54,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,167,150,48,144,0,0,32,0,117,54,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,49,118,155,216,0,0,32,0,117,54,50,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,197,198,228,66,0,0,32,0,117,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,175,175,253,157,0,0,64,0,117,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,213,23,91,121,0,0,64,0,101,101,112,114,111,109,45,100,100,111,110,112,97,99,104,106,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,56,100,241,45,0,0,16,1,168,86,7,0,1,0,0,0,24,255,146,0,248,191,2,0,24,38,7,0,1,0,0,0,23,255,146,0,184,160,2,0,56,210,6,0,1,0,0,0,16,255,146,0,192,135,2,0,24,163,6,0,1,0,0,0,17,255,146,0,240,108,2,0,152,122,6,0,1,0,0,0,18,255,146,0,96,82,2,0,192,72,6,0,1,0,0,0,19,255,146,0,32,56,2,0,200,110,3,0,1,0,0,0,20,255,146,0,152,30,2,0,120,89,3,0,1,0,0,0,21,255,146,0,232,10,2,0,120,74,3,0,1,0,0,0,22,255,146,0,152,138,8,0,40,246,1,0,1,0,0,0,176,246,146,0,64,246,1,0,144,236,1,0,1,0,0,0,175,246,146,0,136,224,1,0,176,223,1,0,1,0,0,0,168,246,146,0,72,198,1,0,192,209,1,0,1,0,0,0,169,246,146,0,24,182,1,0,24,198,1,0,1,0,0,0,170,246,146,0,40,167,1,0,120,189,1,0,1,0,0,0,171,246,146,0,200,149,1,0,224,22,1,0,1,0,0,0,172,246,146,0,56,126,1,0,160,14,1,0,1,0,0,0,173,246,146,0,32,101,1,0,176,9,1,0,1,0,0,0,174,246,146,0,96,32,8,0,88,212,3,0,1,0,0,0,200,218,146,0,40,185,3,0,32,77,1,0,1,0,0,0,25,255,146,0,216,70,1,0,16,17,8,0,1,0,0,0,177,246,146,0,224,12,8,0,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,6,6,6,6,6,6,6,7,3,3,3,3,4,5,20,22,20,20,20,2,20,20,20,20,20,20,2,20,2,2,20,2,20,20,20,2,20,20,20,20,20,20,2,20,2,2,20,2,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,3,3,20,4,20,20,3,20,20,20,20,3,4,25,34,28,4,4,20,5,20,20,4,4,20,20,20,4,5,26,35,29,5,5,20,6,20,20,5,5,20,20,20,5,6,27,36,30,5,5,20,6,20,20,5,5,20,20,20,5,6,27,36,30,3,3,20,20,20,20,3,20,20,20,20,3,20,20,20,20,4,4,20,20,20,20,4,4,20,20,20,4,20,20,20,20,5,5,20,20,20,20,5,5,20,20,20,5,20,20,20,20,5,5,20,20,20,20,5,5,20,20,20,5,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,7,7,7,7,7,7,7,8,3,3,3,3,4,5,20,20,20,20,20,2,20,20,20,20,20,20,2,20,2,2,20,2,20,20,20,2,20,20,20,20,20,20,2,20,2,2,20,2,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,3,3,20,5,20,20,3,20,20,20,20,3,5,25,34,28,5,5,20,7,20,20,5,5,20,20,20,5,7,27,36,30,5,5,20,7,20,20,5,5,20,20,20,5,7,27,36,30,6,6,20,8,20,20,6,6,20,20,20,6,8,28,37,31,3,3,20,20,20,20,3,20,20,20,20,3,20,20,20,20,5,5,20,20,20,20,5,5,20,20,20,5,20,20,20,20,5,5,20,20,20,20,5,5,20,20,20,5,20,20,20,20,6,6,20,20,20,20,6,6,20,20,20,6,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,4,4,4,4,4,4,4,4,6,6,6,6,20,20,20,22,1,20,20,1,1,20,1,1,1,1,1,20,1,1,20,1,20,20,20,2,2,20,2,20,20,2,2,20,2,2,20,1,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,4,4,4,4,4,4,4,20,4,4,4,4,4,20,4,20,5,5,5,5,5,5,5,5,5,5,5,5,5,20,5,5,6,6,6,6,6,6,6,6,6,6,6,6,6,20,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,20,6,6,20,20,20,20,20,20,20,20,20,20,20,20,20,20,4,20,20,20,20,20,20,20,20,20,20,20,20,20,7,7,5,5,20,20,20,20,20,20,20,20,20,20,20,20,8,8,6,6,20,20,20,20,20,20,20,20,20,20,20,20,8,8,6,6,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,4,4,4,4,4,4,4,4,6,6,6,6,20,20,20,20,2,20,20,2,2,20,2,2,2,2,2,20,2,2,20,2,20,20,20,3,3,20,3,20,20,3,3,20,3,3,20,3,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,5,5,5,5,5,5,4,20,5,5,5,5,5,20,4,20,7,7,7,7,7,7,6,6,7,7,7,7,7,20,6,6,7,7,7,7,7,7,6,6,7,7,7,7,7,20,6,6,8,8,8,8,8,8,7,7,8,8,8,8,8,20,7,7,20,20,20,20,20,20,20,20,20,20,20,20,20,20,4,20,20,20,20,20,20,20,20,20,20,20,20,20,8,8,6,6,20,20,20,20,20,20,20,20,20,20,20,20,8,8,6,6,20,20,20,20,20,20,20,20,20,20,20,20,9,9,7,7,104,1,120,0,104,1,104,1,104,1,208,2,104,1,60,0,88,2,88,2,88,2,88,2,88,2,88,2,0,0,0,0,224,1,224,1,224,1,224,1,224,1,224,1,224,1,0,0,104,1,104,1,104,1,104,1,104,1,30,0,104,1,104,1,104,1,104,1,104,1,104,1,104,1,104,1,0,0,0,0,104,1,104,1,104,1,104,1,104,1,104,1,0,0,0,0,104,1,104,1,104,1,104,1,104,1,104,1,104,1,0,0,224,1,224,1,224,1,224,1,224,1,224,1,224,1,0,0,164,1,164,1,164,1,164,1,164,1,164,1,164,1,164,1,0,5,0,5,0,5,0,5,0,5,0,5,0,5,0,5,184,40,2,0,1,0,0,0,85,0,147,0,248,191,2,0,184,164,8,0,1,0,0,0,86,0,147,0,64,246,1,0,56,250,6,0,1,0,0,0,189,247,146,0,184,160,2,0,88,149,7,0,1,0,0,0,190,247,146,0,136,224,1,0,56,210,6,0,1,0,0,0,80,0,147,0,192,135,2,0,152,122,6,0,1,0,0,0,81,0,147,0,96,82,2,0,192,72,6,0,1,0,0,0,82,0,147,0,32,56,2,0,24,163,6,0,1,0,0,0,83,0,147,0,240,108,2,0,200,110,3,0,1,0,0,0,87,0,147,0,152,30,2,0,176,223,1,0,1,0,0,0,184,247,146,0,72,198,1,0,24,198,1,0,1,0,0,0,185,247,146,0,40,167,1,0,120,189,1,0,1,0,0,0,186,247,146,0,200,149,1,0,192,209,1,0,1,0,0,0,187,247,146,0,24,182,1,0,160,14,1,0,1,0,0,0,188,247,146,0,56,126,1,0,88,212,3,0,1,0,0,0,128,219,146,0,40,185,3,0,64,23,5,0,9,0,0,0,202,5,147,0,32,58,1,0,104,20,5,0,9,0,0,0,200,5,147,0,32,58,1,0,216,16,5,0,9,0,0,0,201,5,147,0,32,58,1,0,184,40,2,0,1,0,0,0,85,0,147,0,248,191,2,0,200,110,3,0,1,0,0,0,80,0,147,0,152,30,2,0,120,89,3,0,1,0,0,0,81,0,147,0,232,10,2,0,120,74,3,0,1,0,0,0,82,0,147,0,152,138,8,0,192,61,3,0,1,0,0,0,83,0,147,0,48,119,7,0,120,194,6,0,1,0,0,0,189,247,146,0,112,109,7,0,96,189,6,0,1,0,0,0,190,247,146,0,24,133,7,0,224,22,1,0,1,0,0,0,184,247,146,0,56,126,1,0,160,14,1,0,1,0,0,0,185,247,146,0,32,101,1,0,176,9,1,0,1,0,0,0,186,247,146,0,96,32,8,0,200,3,1,0,1,0,0,0,187,247,146,0,16,68,7,0,208,183,6,0,1,0,0,0,189,247,146,0,240,58,7,0,200,177,6,0,1,0,0,0,87,0,147,0,200,42,1,0,16,208,6,0,1,0,0,0,84,0,147,0,216,70,1,0,88,212,3,0,1,0,0,0,128,219,146,0,40,185,3,0,64,23,5,0,9,0,0,0,201,5,147,0,32,58,1,0,104,20,5,0,9,0,0,0,202,5,147,0,32,58,1,0,216,16,5,0,9,0,0,0,200,5,147,0,32,58,1,0,168,86,7,0,1,0,0,0,16,3,147,0,248,191,2,0,24,38,7,0,1,0,0,0,64,255,146,0,184,160,2,0,56,210,6,0,1,0,0,0,71,255,146,0,192,135,2,0,24,163,6,0,1,0,0,0,70,255,146,0,240,108,2,0,152,122,6,0,1,0,0,0,68,255,146,0,96,82,2,0,192,72,6,0,1,0,0,0,69,255,146,0,32,56,2,0,24,204,8,0,1,0,0,0,67,255,146,0,152,30,2,0,80,194,8,0,1,0,0,0,66,255,146,0,232,10,2,0,200,184,8,0,1,0,0,0,65,255,146,0,152,138,8,0,168,167,8,0,1,0,0,0,15,3,147,0,48,119,7,0,152,151,8,0,1,0,0,0,14,3,147,0,112,109,7,0,80,140,8,0,1,0,0,0,13,3,147,0,24,133,7,0,40,246,1,0,1,0,0,0,17,3,147,0,64,246,1,0,144,236,1,0,1,0,0,0,216,246,146,0,136,224,1,0,176,223,1,0,1,0,0,0,223,246,146,0,72,198,1,0,192,209,1,0,1,0,0,0,222,246,146,0,24,182,1,0,24,198,1,0,1,0,0,0,220,246,146,0,40,167,1,0,120,189,1,0,1,0,0,0,221,246,146,0,200,149,1,0,240,60,8,0,1,0,0,0,219,246,146,0,56,126,1,0,104,48,8,0,1,0,0,0,218,246,146,0,32,101,1,0,96,34,8,0,1,0,0,0,217,246,146,0,96,32,8,0,80,25,8,0,1,0,0,0,11,3,147,0,16,68,7,0,8,18,8,0,1,0,0,0,10,3,147,0,240,58,7,0,224,8,8,0,1,0,0,0,9,3,147,0,200,42,1,0,88,212,3,0,1,0,0,0,224,218,146,0,40,185,3,0,80,251,6,0,1,0,0,0,21,3,147,0,216,70,1,0,16,17,8,0,1,0,0,0])
.concat([20,3,147,0,224,12,8,0,248,5,8,0,9,0,0,0,173,224,146,0,32,58,1,0,144,250,7,0,9,0,0,0,172,224,146,0,32,58,1,0,48,45,3,0,9,0,0,0,174,224,146,0,32,58,1,0,152,205,7,0,9,0,0,0,175,224,146,0,32,58,1,0,7,0,0,0,8,0,0,0,240,36,5,0,32,7,5,0,0,0,0,0,32,184,1,0,48,177,1,0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,168,129,9,0,200,129,9,0,112,130,9,0,40,131,9,0,152,138,9,0,22,132,9,0,48,132,9,0,80,132,9,0,232,132,9,0,128,133,9,0,180,138,9,0,144,140,9,0,162,140,9,0,212,140,9,0,6,141,9,0,112,141,9,0,130,141,9,0,180,141,9,0,230,141,9,0,56,141,9,0,70,141,9,0,84,141,9,0,98,141,9,0,24,142,9,0,38,142,9,0,52,142,9,0,66,142,9,0,78,134,9,0,104,134,9,0,148,134,9,0,12,135,9,0,132,135,9,0,252,135,9,0,40,136,9,0,160,136,9,0,24,137,9,0,208,138,9,0,226,138,9,0,20,139,9,0,70,139,9,0,176,139,9,0,194,139,9,0,244,139,9,0,38,140,9,0,120,139,9,0,134,139,9,0,148,139,9,0,162,139,9,0,88,140,9,0,102,140,9,0,116,140,9,0,130,140,9,0,144,137,9,0,238,137,9,0,70,138,9,0,164,137,9,0,2,138,9,0,90,138,9,0,218,137,9,0,50,138,9,0,138,138,9,0,14,143,9,0,80,143,9,0,182,143,9,0,28,144,9,0,130,144,9,0,220,144,9,0,132,145,9,0,44,146,9,0,212,146,9,0,16,147,9,0,112,147,9,0,208,147,9,0,48,148,9,0,162,148,9,0,72,149,9,0,238,149,9,0,240,164,9,0,32,165,9,0,116,165,9,0,200,165,9,0,28,166,9,0,106,166,9,0,22,167,9,0,194,167,9,0,110,168,9,0,176,168,9,0,38,169,9,0,156,169,9,0,18,170,9,0,120,170,9,0,18,171,9,0,172,171,9,0,148,150,9,0,208,150,9,0,48,151,9,0,144,151,9,0,240,151,9,0,56,152,9,0,222,152,9,0,132,153,9,0,42,154,9,0,102,154,9,0,214,154,9,0,70,155,9,0,182,155,9,0,22,156,9,0,196,156,9,0,114,157,9,0,70,172,9,0,106,172,9,0,178,172,9,0,250,172,9,0,66,173,9,0,132,173,9,0,52,174,9,0,228,174,9,0,148,175,9,0,236,175,9,0,92,176,9,0,204,176,9,0,60,177,9,0,150,177,9,0,72,178,9,0,250,178,9,0,32,158,9,0,84,158,9,0,236,158,9,0,132,159,9,0,28,160,9,0,80,160,9,0,168,160,9,0,0,161,9,0,172,179,9,0,224,179,9,0,120,180,9,0,16,181,9,0,168,181,9,0,232,181,9,0,76,182,9,0,176,182,9,0,88,161,9,0,152,161,9,0,60,162,9,0,224,162,9,0,132,163,9,0,196,163,9,0,40,164,9,0,140,164,9,0,20,183,9,0,72,183,9,0,224,183,9,0,120,184,9,0,16,185,9,0,92,185,9,0,204,185,9,0,60,186,9,0,80,142,9,0,130,142,9,0,210,142,9,0,136,195,9,0,148,195,9,0,178,195,9,0,220,195,9,0,232,195,9,0,6,196,9,0,48,196,9,0,60,196,9,0,90,196,9,0,254,196,9,0,20,197,9,0,132,196,9,0,140,196,9,0,32,197,9,0,28,199,9,0,184,197,9,0,44,198,9,0,146,198,9,0,218,198,9,0,204,199,9,0,158,200,9,0,92,204,9,0,104,202,9,0,38,206,9,0,168,203,9,0,136,207,9,0,96,208,9,0,82,209,9,0,68,210,9,0,54,211,9,0,174,212,9,0,160,213,9,0,146,214,9,0,132,215,9,0,196,221,9,0,228,221,9,0,32,222,9,0,92,222,9,0,106,222,9,0,152,222,9,0,248,222,9,0,52,223,9,0,58,223,9,0,104,223,9,0,164,223,9,0,178,223,9,0,208,223,9,0,222,223,9,0,252,223,9,0,56,224,9,0,148,224,9,0,206,224,9,0,220,224,9,0,2,225,9,0,62,225,9,0,84,225,9,0,114,225,9,0,174,225,9,0,0,226,9,0,22,226,9,0,52,226,9,0,142,226,9,0,148,226,9,0,178,226,9,0,254,226,9,0,28,227,9,0,66,227,9,0,126,227,9,0,132,227,9,0,172,186,9,0,172,186,9,0,172,186,9,0,172,186,9,0,68,187,9,0,12,188,9,0,244,188,9,0,252,189,9,0,36,191,9,0,14,192,9,0,64,192,9,0,36,193,9,0,86,193,9,0,64,194,9,0,114,194,9,0,86,195,9,0,252,216,9,0,16,217,9,0,54,217,9,0,252,216,9,0,16,217,9,0,110,217,9,0,252,216,9,0,16,217,9,0,184,217,9,0,210,217,10,0,60,14,11,0,44,39,11,0,76,39,11,0,76,40,11,0,36,41,11,0,66,50,11,0,14,42,11,0,40,42,11,0,72,42,11,0,76,43,11,0,26,44,11,0,94,50,11,0,58,52,11,0,76,52,11,0,126,52,11,0,176,52,11,0,26,53,11,0,44,53,11,0,94,53,11,0,144,53,11,0,226,52,11,0,240,52,11,0,254,52,11,0,12,53,11,0,194,53,11,0,208,53,11,0,222,53,11,0,236,53,11,0,26,45,11,0,52,45,11,0,102,45,11,0,254,45,11,0,150,46,11,0,46,47,11,0,102,47,11,0,254,47,11,0,150,48,11,0,122,50,11,0,140,50,11,0,190,50,11,0,240,50,11,0,90,51,11,0,108,51,11,0,158,51,11,0,208,51,11,0,34,51,11,0,48,51,11,0,62,51,11,0,76,51,11,0,2,52,11,0,16,52,11,0,30,52,11,0,44,52,11,0,46,49,11,0,134,49,11,0,228,49,11,0,66,49,11,0,160,49,11,0,254,49,11,0,114,49,11,0,208,49,11,0,46,50,11,0,2,55,11,0,62,55,11,0,174,55,11,0,30,56,11,0,142,56,11,0,214,56,11,0,124,57,11,0,34,58,11,0,200,58,11,0,16,59,11,0,134,59,11,0,252,59,11,0,114,60,11,0,192,60,11,0,108,61,11,0,24,62,11,0,152,77,11,0,212,77,11,0,68,78,11,0,180,78,11,0,36,79,11,0,120,79,11,0,26,80,11,0,188,80,11,0,94,81,11,0,172,81,11,0,18,82,11,0,120,82,11,0,222,82,11,0,32,83,11,0,208,83,11,0,128,84,11,0,196,62,11,0,244,62,11,0,88,63,11,0,188,63,11,0,32,64,11,0,92,64,11,0,32,65,11,0,228,65,11,0,168,66,11,0,222,66,11,0,72,67,11,0,178,67,11,0,28,68,11,0,88,68,11,0,216,68,11,0,88,69,11,0,48,85,11,0,96,85,11,0,196,85,11,0,40,86,11,0,140,86,11,0,200,86,11,0,130,87,11,0,60,88,11,0,246,88,11,0,74,89,11,0,188,89,11,0,46,90,11,0,160,90,11,0,232,90,11,0,142,91,11,0,52,92,11,0,216,69,11,0,36,70,11,0,212,70,11,0,132,71,11,0,52,72,11,0,128,72,11,0,240,72,11,0,96,73,11,0,218,92,11,0,38,93,11,0,214,93,11,0,134,94,11,0,54,95,11,0,130,95,11,0,242,95,11,0,98,96,11,0,208,73,11,0,16,74,11,0,180,74,11,0,88,75,11,0,252,75,11,0,72,76,11,0,184,76,11,0,40,77,11,0,210,96,11,0,18,97,11,0,182,97,11,0,90,98,11,0,254,98,11,0,74,99,11,0,186,99,11,0,42,100,11,0,250,53,11,0,102,54,11,0,216,54,11,0,26,107,11,0,38,107,11,0,68,107,11,0,110,107,11,0,122,107,11,0,152,107,11,0,194,107,11,0,206,107,11,0,236,107,11,0,144,108,11,0,166,108,11,0,22,108,11,0,30,108,11,0,178,108,11,0,174,110,11,0,74,109,11,0,190,109,11,0,36,110,11,0,108,110,11,0,94,111,11,0,48,112,11,0,238,115,11,0,250,113,11,0,184,117,11,0,58,115,11,0,26,119,11,0,242,119,11,0,228,120,11,0,214,121,11,0,200,122,11,0,64,124,11,0,50,125,11,0,36,126,11,0,22,127,11,0,174,132,11,0,206,132,11,0,10,133,11,0,70,133,11,0,84,133,11,0,130,133,11,0,226,133,11,0,30,134,11,0,36,134,11,0,82,134,11,0,142,134,11,0,156,134,11,0,186,134,11,0,200,134,11,0,230,134,11,0,34,135,11,0,126,135,11,0,184,135,11,0,198,135,11,0,236,135,11,0,40,136,11,0,62,136,11,0,92,136,11,0,152,136,11,0,234,136,11,0,0,137,11,0,30,137,11,0,120,137,11,0,126,137,11,0,156,137,11,0,232,137,11,0,6,138,11,0,44,138,11,0,104,138,11,0,110,138,11,0,154,100,11,0,154,100,11,0,154,100,11,0,154,100,11,0,208,100,11,0,182,101,11,0,220,102,11,0,2,104,11,0,40,105,11,0,140,105,11,0,8,106,11,0,132,106,11,0,60,105,11,0,160,105,11,0,28,106,11,0,152,106,11,0,0,107,11,0,142,128,11,0,162,128,11,0,200,128,11,0,142,128,11,0,162,128,11,0,28,129,11,0,62,129,11,0,136,177,11,0,192,177,11,0,8,179,10,0,164,148,10,0,196,148,10,0,104,149,10,0,70,150,10,0,252,157,10,0,70,151,10,0,96,151,10,0,128,151,10,0,36,152,10,0,200,152,10,0,24,158,10,0,244,159,10,0,6,160,10,0,56,160,10,0,106,160,10,0,212,160,10,0,230,160,10,0,24,161,10,0,74,161,10,0,156,160,10,0,170,160,10,0,184,160,10,0,198,160,10,0,124,161,10,0,138,161,10,0,152,161,10,0,166,161,10,0,112,153,10,0,138,153,10,0,176,153,10,0,68,154,10,0,216,154,10,0,108,155,10,0,140,155,10,0,234,155,10,0,72,156,10,0,52,158,10,0,70,158,10,0,120,158,10,0,170,158,10,0,20,159,10,0,38,159,10,0,88,159,10,0,138,159,10,0,220,158,10,0,234,158,10,0,248,158,10,0,6,159,10,0,188,159,10,0,202,159,10,0,216,159,10,0,230,159,10,0,166,156,10,0,4,157,10,0,134,157,10,0,186,156,10,0,24,157,10,0,154,157,10,0,240,156,10,0,114,157,10,0,232,157,10,0,96,162,10,0,150,162,10,0,240,162,10,0,74,163,10,0,164,163,10,0,254,163,10,0,176,164,10,0,98,165,10,0,20,166,10,0,122,166,10,0,248,166,10,0,118,167,10,0,244,167,10,0,96,168,10,0,0,169,10,0,160,169,10,0,242,185,10,0,34,186,10,0,118,186,10,0,202,186,10,0,30,187,10,0,96,187,10,0,0,188,10,0,160,188,10,0,64,189,10,0,136,189,10,0,244,189,10,0,96,190,10,0,204,190,10,0,32,191,10,0,168,191,10,0,48,192,10,0,64,170,10,0,118,170,10,0,208,170,10,0,42,171,10,0,132,171,10,0,234,171,10,0,136,172,10,0,38,173,10,0,196,173,10,0,36,174,10,0,184,174,10,0,76,175,10,0,224,175,10,0,58,176,10,0,226,176,10,0,138,177,10,0,184,192,10,0,232,192,10,0,60,193,10,0,144,193,10,0,228,193,10,0,38,194,10,0,198,194,10,0,102,195,10,0,6,196,10,0,78,196,10,0,186,196,10,0,38,197,10,0,146,197,10,0,212,197,10,0,148,198,10,0,84,199,10,0,50,178,10,0,114,178,10,0,22,179,10,0,186,179,10,0,94,180,10,0,158,180,10,0,2,181,10,0,102,181,10,0,20,200,10,0,72,200,10,0,224,200,10,0,120,201,10,0,16,202,10,0,68,202,10,0,156,202,10,0,244,202,10,0,202,181,10,0,34,182,10,0,222,182,10,0,154,183,10,0,86,184,10,0,162,184,10,0,18,185,10,0,130,185,10,0,76,203,10,0,128,203,10,0,14,204,10,0,156,204,10,0,42,205,10,0,106,205,10,0,206,205,10,0,50,206,10,0,180,161,10,0,242,161,10,0,54,162,10,0,26,221,10,0,38,221,10,0,68,221,10,0,110,221,10,0,122,221,10,0,152,221,10,0,194,221,10,0,206,221,10,0,236,221,10,0,144,222,10,0,166,222,10,0,22,222,10,0,30,222,10,0,178,222,10,0,62,225,10,0,218,223,10,0,78,224,10,0,180,224,10,0,252,224,10,0,238,225,10,0,192,226,10,0,126,230,10,0,138,228,10,0,72,232,10,0,202,229,10,0,170,233,10,0,130,234,10,0,116,235,10,0,102,236,10,0,88,237,10,0,208,238,10,0,194,239,10,0,180,240,10,0,166,241,10,0,82,247,10,0,114,247,10,0,174,247,10,0,234,247,10,0,248,247,10,0,38,248,10,0,134,248,10,0,194,248,10,0,200,248,10,0,246,248,10,0,50,249,10,0,64,249,10,0,94,249,10,0,108,249,10,0,138,249,10,0,198,249,10,0,34,250,10,0,92,250,10,0,106,250,10,0,144,250,10,0,204,250,10,0,226,250,10,0,0,251,10,0,60,251,10,0,142,251,10,0,164,251,10,0,194,251,10,0,28,252,10,0,34,252,10,0,64,252,10,0,140,252,10,0,170,252,10,0,208,252,10,0,12,253,10,0,18,253,10,0,150,206,10,0,160,207,10,0,170,208,10,0,180,209,10,0,190,210,10,0,250,212,10,0,90,215,10,0,218,217,10,0,122,220,10,0,122,220,10,0,122,220,10,0,122,220,10,0,30,243,10,0,68,243,10,0,100,243,10,0,30,243,10,0,68,243,10,0,156,243,10,0,166,243,11,0,44,39,11,0,76,39,11,0,76,40,11,0,36,41,10,0,60,14,10,0,92,14,10,0,0,15,10,0,168,15,10,0,226,22,10,0,92,16,10,0,118,16,10,0,150,16,10,0,58,17,10,0,222,17,10,0,254,22,10,0,218,24,10,0,236,24,10,0,30,25,10,0,80,25,10,0,186,25,10,0,204,25,10,0,254,25,10,0,48,26,10,0,130,25,10,0,144,25,10,0,158,25,10,0,172,25,10,0,98,26,10,0,112,26,10,0,126,26,10,0,140,26,10,0,134,18,10,0,160,18,10,0,210,18,10,0,74,19,10,0,194,19,10,0,58,20,10,0,108,20,10,0,228,20,10,0,92,21,10,0,26,23,10,0,44,23,10,0,94,23,10,0,144,23,10,0,250,23,10,0,12,24,10,0,62,24,10,0,112,24,10,0,194,23,10,0,208,23,10,0,222,23,10,0,236,23,10,0,162,24,10,0,176,24,10,0,190,24,10,0,204,24,10,0,212,21,10,0,50,22,10,0,138,22,10,0,232,21,10,0,70,22,10,0,158,22,10,0,30,22,10,0,118,22,10,0,206,22,10,0,82,27,10,0,130,27,10,0,214,27,10,0,42,28,10,0,126,28,10,0,204,28,10,0,104,29,10,0,4,30,10,0,160,30,10,0,232,30,10,0,84,31,10,0,192,31,10,0,44,32,10,0,122,32,10,0,6,33,10,0,146,33,10,0,146,48,10,0,194,48,10,0,22,49,10,0,106,49,10,0,190,49,10,0,12,50,10,0,184,50,10,0,100,51,10,0,16,52,10,0,94,52,10,0,208,52,10,0,66,53,10,0,180,53,10,0,2,54,10,0,174,54,10,0,90,55,10,0,30,34,10,0,78,34,10,0,162,34,10,0,246,34,10,0,74,35,10,0,146,35,10,0,56,36,10,0,222,36,10,0,132,37,10,0,198,37,10,0,44,38,10,0,146,38,10,0,248,38,10,0,58,39,10,0,218,39,10,0,122,40,10,0,6,56,10,0,54,56,10,0,138,56,10,0,222,56,10,0,50,57,10,0,128,57,10,0,44,58,10,0,216,58,10,0,132,59,10,0,204,59,10,0,72,60,10,0,196,60,10,0,64,61,10,0,142,61,10,0,58,62,10,0,230,62,10,0,26,41,10,0,78,41,10,0,230,41,10,0,126,42,10,0,22,43,10,0,86,43,10,0,186,43,10,0,30,44,10,0,146,63,10,0,198,63,10,0,94,64,10,0,246,64,10,0,142,65,10,0,194,65,10,0,26,66,10,0,114,66,10,0,130,44,10,0,206,44,10,0,134,45,10,0,62,46,10,0,246,46,10,0,66,47,10,0,178,47,10,0,34,48,10,0,202,66,10,0,254,66,10,0,150,67,10,0,46,68,10,0,198,68,10,0,250,68,10,0,82,69,10,0,170,69,10,0,154,26,10,0,240,26,10,0,46,27,10,0,44,77,10,0,56,77,10,0,86,77,10,0,128,77,10,0,140,77,10,0,170,77,10,0,212,77,10,0,224,77,10,0,254,77,10,0,162,78,10,0,184,78,10,0,40,78,10,0,48,78,10,0,196,78,10,0,192,80,10,0,92,79,10,0,208,79,10,0,54,80,10,0,126,80,10,0,112,81,10,0,66,82,10,0,0,86,10,0,12,84,10,0,202,87,10,0,76,85,10,0,44,89,10,0,4,90,10,0,246,90,10,0,232,91,10,0,218,92,10,0,82,94,10,0,68,95,10,0,54,96,10,0,40,97,10,0,56,103,10,0,88,103,10,0,148,103,10,0,208,103,10,0,222,103,10,0,12,104,10,0,108,104,10,0,168,104,10,0,174,104,10,0,220,104,10,0,24,105,10,0,38,105,10,0,68,105,10,0,82,105,10,0,112,105,10,0,172,105,10,0,8,106,10,0,66,106,10,0,80,106,10,0,118,106,10,0,178,106,10,0,200,106,10,0,230,106,10,0,34,107,10,0,116,107,10,0,138,107,10,0,168,107,10,0,2,108,10,0,8,108,10,0,38,108,10,0,114,108,10,0,144,108,10,0,182,108,10,0,242,108,10,0,248,108,10,0,2,70,10,0,2,70,10,0,2,70,10,0,2,70,10,0,68,70,10,0,248,70,10,0,172,71,10,0,96,72,10,0,70,70,10,0,250,70,10,0,174,71,10,0,98,72,10,0,22,73,10,0,36,73,10,0,38,74,10,0,40,75,10,0,42,76,10,0,160,98,10,0,180,98,10,0,218,98,10,0,160,98,10,0,180,98,10,0,30,99,10,0,56,99,10,0,164,148,10,0,196,148,10,0,104,149,7,0,60,204,7,0,104,204,7,0,28,205,7,0,154,205,7,0,22,214,7,0,56,206,7,0,82,206,7,0,114,206,7,0,22,207,7,0,170,207,7,0,50,214,7,0,14,216,7,0,32,216,7,0,82,216,7,0,132,216,7,0,238,216,7,0,0,217,7,0,50,217,7,0,100,217,7,0,182,216,7,0,196,216,7,0,210,216,7,0,224,216,7,0,150,217,7,0,164,217,7,0,178,217,7,0,192,217,7,0,100,208,7,0,126,208,7,0,194,208,7,0,106,209,7,0,18,210,7,0,186,210,7,0,254,210,7,0,166,211,7,0,78,212,7,0,78,214,7,0,96,214,7,0,146,214,7,0,196,214,7,0,46,215,7,0,64,215,7,0,114,215,7,0,164,215,7,0,246,214,7,0,4,215,7,0,18,215,7,0,32,215,7,0,214,215,7,0,228,215,7,0,242,215,7,0,0,216,7,0,246,212,7,0,78,213,7,0,190,213,7,0,10,213,7,0,98,213,7,0,210,213,7,0,58,213,7,0,176,213,7,0,2,214,7,0,140,218,7,0,200,218,7,0,44,219,7,0,144,219,7,0,244,219,7,0,54,220,7,0,224,220,7,0,138,221,7,0,52,222,7,0,148,222,7,0,60,223,7,0,228,223,7,0,140,224,7,0,242,224,7,0,180,225,7,0,118,226,7,0,214,242,7,0,12,243,7,0,102,243,7,0,192,243,7,0,26,244,7,0,98,244,7,0,56,245,7,0,14,246,7,0,228,246,7,0,122,247,7,0,98,248,7,0,74,249,7,0,50,250,7,0,206,250,7,0,198,251,7,0,190,252,7,0,56,227,7,0,110,227,7,0,200,227,7,0,34,228,7,0,124,228,7,0,184,228,7,0,82,229,7,0,236,229,7,0,134,230,7,0,224,230,7,0,114,231,7,0,4,232,7,0,150,232,7,0,226,232,7,0,70,233,7,0,170,233,7,0,182,253,7,0,230,253,7,0,58,254,7,0,142,254,7,0,226,254,7,0,60,255,7,0,228,255,8,0,140,0,8,0,52,1,8,0,178,1,8,0,130,2,8,0,82,3,8,0,34,4,8,0,166,4,8,0,134,5,8,0,102,6,7,0,14,234,7,0,108,234,7,0,34,235,7,0,216,235,7,0,142,236,7,0,236,236,7,0,114,237,7,0,248,237,8,0,70,7,8,0,158,7,8,0,62,8,8,0,222,8,8,0,126,9,8,0,214,9,8,0,86,10,8,0,214,10,7,0,126,238,7,0,208,238,7,0,122,239,7,0,36,240,7,0,206,240,7,0,50,241,7,0,190,241,7,0,74,242,8,0,86,11,8,0,180,11,8,0,90,12,8,0,0,13,8,0,166,13,8,0,4,14,8,0,138,14,8,0,16,15,7,0,206,217,7,0,28,218,7,0,88,218,8,0,220,30,8,0,232,30,8,0,6,31,8,0,48,31,8,0,60,31,8,0,90,31,8,0,132,31,8,0,144,31,8,0,174,31,8,0,76,32,8,0,98,32,8,0,216,31,8,0,224,31,8,0,110,32,8,0,106,34,8,0,6,33,8,0,122,33,8,0,224,33,8,0,40,34,8,0,26,35,8,0,230,35,8,0,164,39,8,0,176,37,8,0,110,41,8,0,240,38,8,0,208,42,8,0,168,43,8,0,148,44,8,0,128,45,8,0,108,46,8,0,222,47,8,0,202,48,8,0,182,49,8,0,162,50,8,0,20,52,8,0,52,52,8,0,112,52,8,0,172,52,8,0,186,52,8,0,232,52,8,0,72,53,8,0,132,53,8,0,138,53,8,0,184,53,8,0,244,53,8,0,2,54,8,0,32,54,8,0,46,54,8,0,76,54,8,0,136,54,8,0,228,54,8,0,30,55,8,0,44,55,8,0,82,55,8,0,142,55,8,0,164,55,8,0,194,55,8,0,254,55,8,0,80,56,8,0,102,56,8,0,132,56,8,0,222,56,8,0,228,56,8,0,2,57,8,0,78,57,8,0,108,57,8,0,146,57,8,0,206,57,8,0,212,57,8,0,150,15,8,0,162,16,8,0,182,16,8,0,194,17,8,0,214,17,8,0,226,18,8,0,246,18,8,0,2,20,8,0,22,20,8,0,232,20,8,0,222,21,8,0,222,22,8,0,222,23,8,0,52,25,8,0,138,26,8,0,224,27,8,0,54,29,8,0,80,29,8,0,112,29,8,0,174,29,8,0,200,29,8,0,232,29,8,0,44,30,8,0,70,30,8,0,90,30,8,0,174,29,8,0,200,29,8,0,154,30,8,0,172,30,8,0,28,99,8,0,72,99,8,0,40,241,8,0,72,241,8,0,236,241,8,0,170,242,8,0,128,250,8,0,170,243,8,0,196,243,8,0,228,243,8,0,168,244,8,0,108,245,8,0,156,250,8,0,120,252,8,0,138,252,8,0,188,252,8,0,238,252,8,0,88,253,8,0,106,253,8,0,156,253,8,0,206,253,8,0,32,253,8,0,46,253,8,0,60,253,8,0,74,253,8,0,0,254,8,0,14,254,8,0,28,254,8,0,42,254,8,0,48,246,8,0,74,246,8,0,124,246,8,0,244,246,8,0,108,247,8,0,228,247,8,0,22,248,8,0,142,248,8,0,6,249,8,0,184,250,8,0,202,250,8,0,252,250,8,0,46,251,8,0,152,251,8,0,170,251,8,0,220,251,8,0,14,252,8,0,96,251,8,0,110,251,8,0,124,251,8,0,138,251,8,0,64,252,8,0,78,252,8,0,92,252,8,0,106,252,8,0,126,249,8,0,208,249,8,0,40,250,8,0,146,249,8,0,228,249,8,0,60,250,8,0,188,249,8,0,20,250,8,0,108,250,8,0,26,255,8,0,74,255,8,0,158,255,8,0,242,255,9,0,70,0,9,0,160,0,9,0,46,1,9,0,188,1,9,0,74,2,9,0,164,2,9,0,34,3,9,0,160,3,9,0,30,4,9,0,108,4,9,0,248,4,9,0,132,5,9,0,196,22,9,0,0,23,9,0,96,23,9,0,192,23,9,0,32,24,9,0,104,24,9,0,14,25,9,0,180,25,9,0,90,26,9,0,174,26,9,0,54,27,9,0,190,27,9,0,70,28,9,0,154,28,9,0,70,29,9,0,242,29,9,0,16,6,9,0,76,6,9,0,188,6,9,0,44,7,9,0,156,7,9,0,240,7,9,0,188,8,9,0,136,9,9,0,84,10,9,0,156,10,9,0,24,11,9,0,148,11,9,0,16,12,9,0,118,12,9,0,16,13,9,0,170,13,9,0,158,30,9,0,206,30,9,0,34,31,9,0,118,31,9,0,202,31,9,0,36,32,9,0,188,32,9,0,84,33,9,0,236,33,9,0,64,34,9,0,200,34,9,0,80,35,9,0,216,35,9,0,62,36,9,0,216,36,9,0,114,37,9,0,68,14,9,0,144,14,9,0,64,15,9,0,240,15,9,0,160,16,9,0,4,17,9,0,124,17,9,0,244,17,9,0,12,38,9,0,100,38,9,0,0,39,9,0,156,39,9,0,56,40,9,0,120,40,9,0,220,40,9,0,64,41,9,0,108,18,9,0,208,18,9,0,152,19,9,0,96,20,9,0,40,21,9,0,116,21,9,0,228,21,9,0,84,22,9,0,164,41,9,0,234,41,9,0,132,42,9,0,30,43,9,0,184,43,9,0,254,43,9,0,88,44,9,0,178,44,8,0,56,254,8,0,166,254,8,0,246,254,9,0,6,52,9,0,18,52,9,0,48,52,9,0,90,52,9,0,102,52,9,0,132,52,9,0,174,52,9,0,186,52,9,0,216,52,9,0,124,53,9,0,146,53,9,0,2,53,9,0,10,53,9,0,158,53,9,0,154,55,9,0,54,54,9,0,170,54,9,0,16,55,9,0,88,55,9,0,74,56,9,0,28,57,9,0,218,60,9,0,230,58,9,0,164,62,9,0,38,60,9,0,6,64,9,0,222,64,9,0,208,65,9,0,194,66,9,0,180,67,9,0,44,69,9,0,30,70,9,0,16,71,9,0,2,72,9,0,216,78,9,0,248,78,9,0,52,79,9,0,112,79,9,0,126,79,9,0,172,79,9,0,12,80,9,0,72,80,9,0,78,80,9,0,124,80,9,0,184,80,9,0,198,80,9,0,228,80,9,0,242,80,9,0,16,81,9,0,76,81,9,0,168,81,9,0,226,81,9,0,240,81,9,0,22,82,9,0,82,82,9,0,104,82,9,0,134,82,9,0,194,82,9,0,20,83,9,0,42,83,9,0,72,83,9,0,162,83,9,0,168,83,9,0,198,83,9,0,18,84,9,0,48,84,9,0,86,84,9,0,146,84,9,0,152,84,9,0,12,45,9,0,200,45,9,0,132,46,9,0,64,47,9,0,14,45,9,0,202,45,9,0,134,46,9,0,66,47,9,0,252,47,9,0,10,48,9,0,10,48,9,0,10,48,9,0,10,48,9,0,94,48,9,0,72,49,9,0,50,50,9,0,28,51,9,0,122,73,9,0,142,73,9,0,162,73,9,0,122,73,9,0,142,73,9,0,230,73,9,0,246,73,9,0,122,73,9,0,142,73,9,0,24,74,9,0,42,74,9,0,168,129,9,0,200,129,9,0,112,130,8,0,28,99,8,0,72,99,8,0,236,99,8,0,148,100,8,0,92,108,8,0,152,101,8,0,178,101,8,0,210,101,8,0,118,102,8,0,74,103,8,0,120,108,8,0,84,110,8,0,102,110,8,0,152,110,8,0,202,110,8,0,52,111,8,0,70,111,8,0,120,111,8,0,170,111,8,0,252,110,8,0,10,111,8,0,24,111,8,0,38,111,8,0,220,111,8,0,234,111,8,0,248,111,8,0,6,112,8,0,30,104,8,0,56,104,8,0,100,104,8,0,204,104,8,0,52,105,8,0,156,105,8,0,200,105,8,0,48,106,8,0,152,106,8,0,148,108,8,0,166,108,8,0,216,108,8,0,10,109,8,0,116,109,8,0,134,109,8,0,184,109,8,0,234,109,8,0,60,109,8,0,74,109,8,0,88,109,8,0,102,109,8,0,28,110,8,0,42,110,8,0,56,110,8,0,70,110,8,0,0,107,8,0,100,107,8,0,224,107,8,0,26,107,8,0,126,107,8,0,0,108,8,0,74,107,8,0,192,107,8,0,66,108,8,0,0,113,8,0,48,113,8,0,132,113,8,0,216,113,8,0,44,114,8,0,128,114,8,0,34,115,8,0,196,115,8,0,102,116,8,0,174,116,8,0,26,117,8,0,134,117,8,0,242,117,8,0,88,118,8,0,226,118,8,0,108,119,8,0,122,133,8,0,170,133,8,0,254,133,8,0,82,134,8,0,166,134,8,0,12,135,8,0,144,135,8,0,20,136,8,0,152,136,8,0,236,136,8,0,100,137,8,0,220,137,8,0,84,138,8,0,186,138,8,0,104,139,8,0,22,140,8,0,246,119,8,0,44,120,8,0,134,120,8,0,224,120,8,0,58,121,8,0,130,121,8,0,40,122,8,0,206,122,8,0,116,123,8,0,164,123,8,0,248,123,8,0,76,124,8,0,160,124,8,0,250,124,8,0,146,125,8,0,42,126,8,0,196,140,8,0,244,140,8,0,72,141,8,0,156,141,8,0,240,141,8,0,62,142,8,0,234,142,8,0,150,143,8,0,66,144,8,0,126,144,8,0,222,144,8,0,62,145,8,0,158,145,8,0,254,145,8,0,156,146,8,0,58,147,8,0,194,126,8,0,246,126,8,0,142,127,8,0,38,128,8,0,190,128,8,0,254,128,8,0,82,129,8,0,166,129,8,0,216,147,8,0,18,148,8,0,176,148,8,0,78,149,8,0,236,149,8,0,68,150,8,0,192,150,8,0,60,151,8,0,250,129,8,0,58,130,8,0,222,130,8,0,130,131,8,0,38,132,8,0,96,132,8,0,190,132,8,0,28,133,8,0,184,151,8,0,242,151,8,0,144,152,8,0,46,153,8,0,204,153,8,0,18,154,8,0,124,154,8,0,230,154,8,0,20,112,8,0,106,112,8,0,196,112,8,0,110,161,8,0,122,161,8,0,152,161,8,0,194,161,8,0,206,161,8,0,236,161,8,0,22,162,8,0,34,162,8,0,64,162,8,0,228,162,8,0,250,162,8,0,106,162,8,0,114,162,8,0,6,163,8,0,146,165,8,0,46,164,8,0,162,164,8,0,8,165,8,0,80,165,8,0,66,166,8,0,20,167,8,0,210,170,8,0,222,168,8,0,156,172,8,0,30,170,8,0,254,173,8,0,214,174,8,0,200,175,8,0,186,176,8,0,172,177,8,0,36,179,8,0,22,180,8,0,8,181,8,0,250,181,8,0,28,188,8,0,60,188,8,0,120,188,8,0,180,188,8,0,194,188,8,0,240,188,8,0,80,189,8,0,140,189,8,0,146,189,8,0,192,189,8,0,252,189,8,0,10,190,8,0,40,190,8,0,54,190,8,0,84,190,8,0,144,190,8,0,236,190,8,0,38,191,8,0,52,191,8,0,90,191,8,0,150,191,8,0,172,191,8,0,202,191,8,0,6,192,8,0,88,192,8,0,110,192,8,0,140,192,8,0,230,192,8,0,236,192,8,0,10,193,8,0,86,193,8,0,116,193,8,0,154,193,8,0,214,193,8,0,220,193,8,0,80,155,8,0,248,155,8,0,220,156,8,0,192,157,8,0,82,155,8,0,250,155,8,0,222,156,8,0,194,157,8,0,164,158,8,0,178,158,8,0,56,159,8,0,76,159,8,0,210,159,8,0,230,159,8,0,108,160,8,0,128,160,8,0,6,161,8,0,26,161,8,0,26,161,8,0,26,161,8,0,26,161,8,0,114,183,8,0,134,183,8,0,172,183,8,0,234,183,8,0,254,183,8,0,24,184,8,0,114,183,8,0,134,183,8,0,126,184,8,0,114,183,8,0,134,183,8,0,240,184,8,0,18,185,8,0,58,185,8,0,40,241,8,0,72,241,8,0,236,241,8,0,170,242,11,0,136,177,11,0,192,177,11,0,8,179,11,0,144,181,11,0,56,207,11,0,0,186,11,0,26,186,11,0,58,186,11,0,98,190,11,0,170,196,11,0,84,207,11,0,48,209,11,0,66,209,11,0,116,209,11,0,166,209,11,0,16,210,11,0,34,210,11,0,84,210,11,0,134,210,11,0,216,209,11,0,230,209,11,0,244,209,11,0,2,210,11,0,184,210,11,0,198,210,11,0,212,210,11,0,226,210,11,0,98,198,11,0,124,198,11,0,180,198,11,0,188,199,11,0,196,200,11,0,184,201,11,0,228,201,11,0,88,203,11,0,204,204,11,0,112,207,11,0,130,207,11,0,180,207,11,0,230,207,11,0,80,208,11,0,98,208,11,0,148,208,11,0,198,208,11,0,24,208,11,0,38,208,11,0,52,208,11,0,66,208,11,0,248,208,11,0,6,209,11,0,20,209,11,0,34,209,11,0,24,206,11,0,88,206,11,0,206,206,11,0,44,206,11,0,108,206,11,0,226,206,11,0,68,206,11,0,192,206,11,0,42,207,11,0,42,213,11,0,102,213,11,0,198,213,11,0,38,214,11,0,134,214,11,0,212,214,11,0,128,215,11,0,44,216,11,0,216,216,11,0,32,217,11,0,156,217,11,0,24,218,11,0,148,218,11,0,238,218,11,0,134,219,11,0,30,220,11,0,114,237,11,0,156,237,11,0,250,237,11,0,88,238,11,0,182,238,11,0,248,238,11,0,184,239,11,0,120,240,11,0,56,241,11,0,134,241,11,0,8,242,11,0,138,242,11,0,12,243,11,0,102,243,11,0,254,243,11,0,150,244,11,0,182,220,11,0,236,220,11,0,86,221,11,0,192,221,11,0,42,222,11,0,108,222,11,0,44,223,11,0,236,223,11,0,172,224,11,0,12,225,11,0,160,225,11,0,52,226,11,0,200,226,11,0,50,227,11,0,180,227,11,0,54,228,11,0,46,245,11,0,94,245,11,0,194,245,11,0,38,246,11,0,138,246,11,0,204,246,11,0,124,247,11,0,44,248,11,0,220,248,11,0,58,249,11,0,176,249,11,0,38,250,11,0,156,250,11,0,246,250,11,0,142,251,11,0,38,252,11,0,184,228,11,0,248,228,11,0,156,229,11,0,64,230,11,0,228,230,11,0,42,231,11,0,148,231,11,0,254,231,11,0,190,252,11,0,242,252,11,0,138,253,11,0,34,254,11,0,186,254,11,0,238,254,11,0,70,255,11,0,158,255,11,0,104,232,11,0,238,232,11,0,206,233,11,0,174,234,11,0,142,235,11,0,236,235,11,0,110,236,11,0,240,236,11,0,246,255,12,0,142,0,12,0,120,1,12,0,98,2,12,0,76,3,12,0,140,3,12,0,240,3,12,0,84,4,11,0,240,210,11,0,80,212,11,0,226,212,12,0,70,9,12,0,82,9,12,0,112,9,12,0,154,9,12,0,166,9,12,0,196,9,12,0,238,9,12,0,250,9,12,0,24,10,12,0,188,10,12,0,210,10,12,0,66,10,12,0,74,10,12,0,222,10,12,0,106,13,12,0,6,12,12,0,122,12,12,0,224,12,12,0,40,13,12,0,26,14,12,0,236,14,12,0,170,18,12,0,182,16,12,0,116,20,12,0,246,17,12,0,214,21,12,0,174,22,12,0,160,23,12,0,146,24,12,0,132,25,12,0,252,26,12,0,238,27,12,0,224,28,12,0,210,29,12,0,106,36,12,0,138,36,12,0,198,36,12,0,2,37,12,0,16,37,12,0,62,37,12,0,158,37,12,0,218,37,12,0,224,37,12,0,14,38,12,0,74,38,12,0,88,38,12,0,118,38,12,0,132,38,12,0,162,38,12,0,222,38,12,0,58,39,12,0,116,39,12,0,130,39,12,0,168,39,12,0,228,39,12,0,250,39,12,0,24,40,12,0,84,40,12,0,166,40,12,0,188,40,12,0,218,40,12,0,52,41,12,0,58,41,12,0,88,41,12,0,164,41,12,0,194,41,12,0,232,41,12,0,36,42,12,0,42,42,12,0,184,4,12,0,6,5,12,0,14,5,12,0,22,5,12,0,30,5,12,0,32,6,12,0,52,6,12,0,54,7,12,0,74,7,12,0,52,8,12,0,72,8,12,0,50,9,12,0,74,31,12,0,94,31,12,0,120,31,12,0,74,31,12,0,94,31,12,0,194,31,12,0,204,31,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,7,0,114,43,7,0,158,43,7,0,82,44,7,0,54,45,7,0,132,53,7,0,58,46,7,0,84,46,7,0,116,46,7,0,40,47,7,0,34,48,7,0,160,53,7,0,124,55,7,0,142,55,7,0,192,55,7,0,242,55,7,0,92,56,7,0,110,56,7,0,160,56,7,0,210,56,7,0,36,56,7,0,50,56,7,0,64,56,7,0,78,56,7,0,4,57,7,0,18,57,7,0,32,57,7,0,46,57,7,0,246,48,7,0,16,49,7,0,66,49,7,0,186,49,7,0,50,50,7,0,172,50,7,0,222,50,7,0,86,51,7,0,206,51,7,0,188,53,7,0,206,53,7,0,0,54,7,0,50,54,7,0,156,54,7,0,174,54,7,0,224,54,7,0,18,55,7,0,100,54,7,0,114,54,7,0,128,54,7,0,142,54,7,0,68,55,7,0,82,55,7,0,96,55,7,0,110,55,7,0,70,52,7,0,164,52,7,0,20,53,7,0,90,52,7,0,184,52,7,0,40,53,7,0,144,52,7,0,0,53,7,0,112,53,7,0,24,58,7,0,72,58,7,0,156,58,7,0,240,58,7,0,68,59,7,0,176,59,7,0,100,60,7,0,24,61,7,0,204,61,7,0,32,62,7,0,152,62,7,0,16,63,7,0,136,63,7,0,214,63,7,0,114,64,7,0,14,65,7,0,128,81,7,0,188,81,7,0,28,82,7,0,124,82,7,0,220,82,7,0,48,83,7,0,210,83,7,0,116,84,7,0,22,85,7,0,112,85,7,0,238,85,7,0,108,86,7,0,234,86,7,0,104,87,7,0,10,88,7,0,172,88,7,0,170,65,7,0,218,65,7,0,46,66,7,0,130,66,7,0,214,66,7,0,54,67,7,0,238,67,7,0,166,68,7,0,94,69,7,0,190,69,7,0,66,70,7,0,198,70,7,0,74,71,7,0,164,71,7,0,102,72,7,0,40,73,7,0,78,89,7,0,126,89,7,0,210,89,7,0,38,90,7,0,122,90,7,0,218,90,7,0,110,91,7,0,2,92,7,0,150,92,7,0,240,92,7,0,120,93,7,0,0,94,7,0,136,94,7,0,224,94,7,0,80,95,7,0,192,95,7,0,234,73,7,0,30,74,7,0,182,74,7,0,78,75,7,0,230,75,7,0,50,76,7,0,162,76,7,0,18,77,7,0,48,96,7,0,112,96,7,0,30,97,7,0,204,97,7,0,122,98,7,0,186,98,7,0,30,99,7,0,130,99,7,0,130,77,7,0,218,77,7,0,150,78,7,0,82,79,7,0,14,80,7,0,72,80,7,0,176,80,7,0,24,81,7,0,230,99,7,0,38,100,7,0,202,100,7,0,110,101,7,0,18,102,7,0,82,102,7,0,182,102,7,0,26,103,7,0,60,57,7,0,146,57,7,0,238,57,7,0,162,111,7,0,174,111,7,0,204,111,7,0,246,111,7,0,2,112,7,0,32,112,7,0,74,112,7,0,86,112,7,0,116,112,7,0,24,113,7,0,46,113,7,0,158,112,7,0,166,112,7,0,58,113,7,0,198,115,7,0,98,114,7,0,214,114,7,0,60,115,7,0,132,115,7,0,118,116,7,0,72,117,7,0,6,121,7,0,18,119,7,0,208,122,7,0,82,120,7,0,50,124,7,0,10,125,7,0,252,125,7,0,238,126,7,0,224,127,7,0,88,129,7,0,74,130,7,0,60,131,7,0,46,132,7,0,146,143,7,0,178,143,7,0,238,143,7,0,42,144,7,0,56,144,7,0,102,144,7,0,198,144,7,0,2,145,7,0,8,145,7,0,54,145,7,0,114,145,7,0,128,145,7,0,158,145,7,0,172,145,7,0,202,145,7,0,6,146,7,0,98,146,7,0,156,146,7,0,170,146,7,0,208,146,7,0,12,147,7,0,34,147,7,0,64,147,7,0,124,147,7,0,206,147,7,0,228,147,7,0,2,148,7,0,92,148,7,0,98,148,7,0,128,148,7,0,204,148,7,0,234,148,7,0,16,149,7,0,76,149,7,0,82,149,7,0,126,103,7,0,126,103,7,0,126,103,7,0,126,103,7,0,204,103,7,0,204,103,7,0,204,103,7,0,204,103,7,0,32,104,7,0,166,104,7,0,126,105,7,0,166,106,7,0,30,108,7,0,190,108,7,0,174,109,7,0,158,110,7,0,102,108,7,0,36,109,7,0,20,110,7,0,4,111,7,0,142,111,7,0,166,133,7,0,186,133,7,0,206,133,7,0,42,134,7,0,68,134,7,0,88,134,7,0,42,134,7,0,68,134,7,0,156,134,7,0,166,134,7,0,60,204,7,0,104,204,7,0,28,205,7,0,154,205,8,255,2,255,0,0,3,255,0,4,1,255,0,3,6,255,191,1,6,255,0,0,2,52,5,255,5,0,20,76,2,52,5,255,6,0,20,76,5,255,6,0,20,76,4,255,2,0,2,52,4,255,0,0,5,255,5,0,20,76,4,255,2,0,2,52,4,255,0,0,6,255,0,0,6,255,0,0,3,52,5,255,5,0,27,76,3,52,5,255,2,0,27,76,5,255,7,0,50,75,5,255,2,0,31,76,4,255,2,0,3,52,4,255,0,0,5,255,5,0,27,76,4,255,2,0,3,52,4,255,0,0,6,255,0,0,6,255,0,0,4,52,5,255,5,0,34,76,4,52,5,255,2,0,34,76,5,255,7,0,58,75,5,255,2,0,38,76,4,255,2,0,4,52,4,255,0,0,5,255,5,0,34,76,4,255,2,0,4,52,4,255,0,0,6,255,0,0,5,255,7,0,12,52,5,255,7,0,12,52,5,255,7,0,12,52,5,255,7,0,12,52,6,255,0,0,1,52,5,255,6,0,41,32,5,255,13,0,126,32,5,255,6,0,41,32,4,255,2,0,1,52,4,255,0,0,6,255,0,0,6,255,0,0,2,52,5,255,6,0,48,32,5,255,13,0,140,32,5,255,6,0,48,32,4,255,2,0,2,52,4,255,0,0,6,255,0,0,6,255,0,0,3,52,5,255,6,0,55,32,5,255,13,0,154,32,5,255,6,0,55,32,4,255,2,0,3,52,4,255,0,0,6,255,0,0,6,255,0,0,4,52,5,255,6,0,62,32,5,255,13,0,168,32,5,255,6,0,62,32,4,255,2,0,4,52,4,255,0,0,6,255,0,0,6,255,0,0,5,52,5,255,6,0,69,32,5,255,13,0,182,32,5,255,6,0,69,32,4,255,2,0,5,52,4,255,0,0,6,255,0,0,6,255,0,0,6,52,5,255,1,0,118,32,5,255,4,0,78,32,5,255,13,0,196,32,5,255,4,0,76,32,5,255,1,0,122,32,4,255,2,0,6,52,4,255,0,0,6,255,0,0,6,255,0,0,7,52,5,255,1,0,120,32,5,255,4,0,85,32,5,255,13,0,210,32,5,255,4,0,83,32,5,255,1,0,124,32,4,255,2,0,7,52,4,255,0,0,6,255,0,0,6,255,0,0,8,52,5,255,6,0,90,32,5,255,13,0,224,32,5,255,6,0,90,32,4,255,2,0,8,52,4,255,0,0,6,255,0,0,6,255,0,0,9,52,5,255,6,0,97,32,5,255,13,0,238,32,5,255,6,0,97,32,4,255,2,0,9,52,4,255,0,0,6,255,0,0,6,255,0,0,10,52,5,255,6,0,104,32,5,255,13,0,1,33,5,255,6,0,104,32,4,255,2,0,10,52,4,255,0,0,6,255,0,0,6,255,0,0,11,52,5,255,6,0,111,32,5,255,13,0,15,33,5,255,6,0,111,32,4,255,2,0,11,52,4,255,0,0,6,255,0,0,6,255,95,0,8,255,2,255,1,0,3,255,0,2,1,255,0,6,6,255,191,1,6,255,127,0,5,255,31,0,208,52,6,255,3,0,240,52,5,255,4,0,7,37,5,255,11,0,1,37,5,255,4,0,2,37,4,255,2,0,240,52,4,255,0,0,6,255,3,0,6,255,3,0,241,52,5,255,4,0,19,37,5,255,11,0,13,37,5,255,4,0,14,37,4,255,2,0,241,52,4,255,0,0,6,255,3,0,6,255,3,0,242,52,5,255,4,0,31,37,5,255,11,0,25,37,5,255,4,0,26,37,4,255,2,0,242,52,4,255,0,0,6,255,3,0,6,255,3,0,243,52,5,255,4,0,43,37,5,255,11,0,37,37,5,255,4,0])
.concat([38,37,4,255,2,0,243,52,4,255,0,0,6,255,3,0,6,255,3,0,244,52,5,255,4,0,55,37,5,255,11,0,49,37,5,255,4,0,50,37,4,255,2,0,244,52,4,255,0,0,6,255,3,0,6,255,3,0,245,52,5,255,4,0,67,37,5,255,11,0,61,37,5,255,4,0,62,37,4,255,2,0,245,52,4,255,0,0,6,255,3,0,6,255,3,0,246,52,5,255,4,0,79,37,5,255,11,0,73,37,5,255,4,0,74,37,4,255,2,0,246,52,4,255,0,0,6,255,3,0,6,255,3,0,247,52,5,255,4,0,91,37,5,255,11,0,85,37,5,255,4,0,86,37,4,255,2,0,247,52,4,255,0,0,6,255,3,0,6,255,3,0,248,52,5,255,4,0,103,37,5,255,11,0,97,37,5,255,4,0,98,37,4,255,2,0,248,52,4,255,0,0,6,255,3,0,6,255,127,0,8,255,2,255,2,0,3,255,0,2,1,255,0,2,6,255,191,1,6,255,159,0,5,255,31,0,8,52,6,255,2,0,5,255,3,0,48,40,1,52,5,255,3,0,48,40,5,255,7,0,40,44,5,255,3,0,48,40,4,255,2,0,1,52,4,255,0,0,5,255,3,0,48,40,6,255,2,0,6,255,2,0,5,255,3,0,60,40,2,52,5,255,3,0,60,40,5,255,7,0,52,44,5,255,3,0,60,40,4,255,2,0,2,52,4,255,0,0,5,255,3,0,60,40,6,255,2,0,6,255,2,0,5,255,3,0,72,40,3,52,5,255,3,0,72,40,5,255,7,0,64,44,5,255,3,0,72,40,4,255,2,0,3,52,4,255,0,0,5,255,3,0,72,40,6,255,2,0,6,255,2,0,5,255,3,0,84,40,4,52,5,255,3,0,84,40,5,255,7,0,76,44,5,255,3,0,84,40,4,255,2,0,4,52,4,255,0,0,5,255,3,0,84,40,6,255,2,0,6,255,2,0,5,255,3,0,96,40,5,52,5,255,3,0,96,40,5,255,7,0,88,44,5,255,3,0,96,40,4,255,2,0,5,52,4,255,0,0,5,255,3,0,96,40,6,255,2,0,6,255,2,0,5,255,3,0,108,40,6,52,5,255,3,0,108,40,5,255,7,0,100,44,5,255,3,0,108,40,4,255,2,0,6,52,4,255,0,0,5,255,3,0,108,40,6,255,2,0,6,255,2,0,5,255,3,0,120,40,7,52,5,255,3,0,120,40,5,255,7,0,112,44,5,255,3,0,120,40,4,255,2,0,7,52,4,255,0,0,5,255,3,0,120,40,6,255,2,0,6,255,159,0,8,255,2,255,3,0,3,255,0,2,1,255,0,2,6,255,191,1,6,255,191,0,6,255,5,0,5,255,4,0,128,52,5,255,4,0,128,52,5,255,4,0,128,52,5,255,4,0,128,52,6,255,5,0,6,255,5,0,5,255,19,0,133,48,6,255,5,0,6,255,5,0,5,255,19,0,153,48,6,255,5,0,6,255,5,0,5,255,19,0,173,48,6,255,5,0,6,255,5,0,5,255,19,0,193,48,6,255,5,0,6,255,5,0,5,255,19,0,213,48,6,255,5,0,5,255,15,0,233,68,4,255,2,0,9,255,15,0,248,68,4,255,0,0,5,255,15,0,1,65,4,255,2,0,9,255,15,0,16,65,4,255,0,0,5,255,15,0,17,61,4,255,2,0,9,255,15,0,32,61,4,255,0,0,5,255,15,0,33,57,4,255,2,0,9,255,15,0,48,57,4,255,0,0,5,255,15,0,49,57,4,255,2,0,9,255,15,0,64,57,4,255,0,0,5,255,15,0,65,57,4,255,2,0,9,255,15,0,80,57,4,255,0,0,0,255,255,255,255,255,255,255,255,255,255,255,8,255,2,255,0,0,3,255,0,4,1,255,0,10,6,255,191,1,6,255,6,0,5,255,1,0,136,60,6,255,5,0,5,255,1,0,1,64,6,255,5,0,4,255,2,0,9,255,1,0,137,60,4,255,0,0,6,255,6,0,6,255,6,0,5,255,1,0,138,60,6,255,4,0,5,255,2,0,3,64,6,255,5,0,4,255,2,0,9,255,1,0,139,60,4,255,0,0,6,255,6,0,6,255,1,0,5,255,4,0,50,48,5,255,1,0,22,60,6,255,4,0,5,255,3,0,6,64,6,255,4,0,4,255,2,0,9,255,1,0,23,60,9,255,4,0,54,48,4,255,0,0,6,255,1,0,6,255,0,0,5,255,5,0,55,48,5,255,1,0,24,60,6,255,4,0,5,255,3,0,10,64,6,255,4,0,4,255,2,0,9,255,1,0,25,60,9,255,5,0,60,48,4,255,0,0,6,255,0,0,6,255,0,0,5,255,5,0,61,48,5,255,1,0,26,60,6,255,4,0,5,255,3,0,14,64,6,255,4,0,4,255,2,0,9,255,1,0,27,60,9,255,5,0,66,48,4,255,0,0,6,255,0,0,6,255,0,0,5,255,5,0,67,48,5,255,1,0,28,60,6,255,4,0,5,255,3,0,18,64,6,255,4,0,4,255,2,0,9,255,1,0,29,60,9,255,5,0,72,48,6,255,0,0,4,255,0,0,5,255,6,0,73,48,5,255,1,0,30,60,6,255,13,0,4,255,2,0,9,255,1,0,31,60,9,255,6,0,79,48,4,255,0,0,5,255,6,0,80,48,5,255,1,0,32,60,6,255,13,0,4,255,2,0,9,255,1,0,33,60,9,255,6,0,86,48,4,255,0,0,5,255,6,0,87,48,5,255,1,0,34,60,6,255,13,0,4,255,2,0,9,255,1,0,35,60,9,255,6,0,93,48,4,255,0,0,5,255,5,0,94,48,6,255,0,0,5,255,1,0,36,60,6,255,13,0,4,255,2,0,9,255,1,0,37,60,6,255,0,0,9,255,5,0,99,48,4,255,0,0,6,255,0,0,5,255,4,0,100,48,6,255,0,0,5,255,1,0,38,60,6,255,13,0,4,255,2,0,9,255,1,0,39,60,6,255,0,0,9,255,4,0,104,48,4,255,0,0,6,255,0,0,6,255,0,0,5,255,4,0,105,48,6,255,0,0,5,255,1,0,40,60,6,255,13,0,4,255,2,0,9,255,1,0,41,60,6,255,0,0,9,255,4,0,109,48,4,255,0,0,6,255,0,0,6,255,0,0,5,255,4,0,110,48,6,255,0,0,5,255,1,0,42,60,6,255,13,0,4,255,2,0,9,255,1,0,43,60,6,255,0,0,9,255,4,0,114,48,4,255,0,0,6,255,0,0,6,255,0,0,5,255,4,0,115,48,6,255,0,0,5,255,1,0,44,60,6,255,13,0,4,255,2,0,9,255,1,0,45,60,6,255,0,0,9,255,4,0,119,48,4,255,0,0,6,255,0,0,5,255,5,0,120,48,6,255,0,0,5,255,1,0,46,60,6,255,13,0,4,255,2,0,9,255,1,0,47,60,6,255,0,0,9,255,5,0,125,48,4,255,0,0,5,255,5,0,126,48,6,255,0,0,5,255,1,0,48,60,6,255,13,0,4,255,2,0,9,255,1,0,49,60,6,255,0,0,9,255,5,0,131,48,4,255,0,0,6,255,63,0,8,255,2,255,1,0,3,255,0,2,1,255,0,10,6,255,191,1,6,255,9,0,5,255,1,0,140,60,6,255,7,0,4,255,2,0,9,255,1,0,141,60,4,255,0,0,6,255,9,0,6,255,1,0,5,255,2,0,160,64,6,255,4,0,5,255,1,0,142,60,6,255,2,0,5,255,1,0,144,64,6,255,2,0,4,255,2,0,9,255,1,0,143,60,6,255,4,0,9,255,2,0,162,64,4,255,0,0,6,255,1,0,6,255,1,0,5,255,2,0,163,64,6,255,0,0,5,255,3,0,199,52,5,255,1,0,175,60,6,255,1,0,5,255,3,0,146,64,6,255,1,0,4,255,2,0,9,255,1,0,176,60,9,255,3,0,202,52,6,255,0,0,9,255,2,0,165,64,4,255,0,0,6,255,1,0,6,255,1,0,5,255,2,0,166,64,5,255,4,0,203,52,5,255,1,0,177,60,6,255,2,0,5,255,1,0,150,64,6,255,2,0,4,255,2,0,9,255,1,0,178,60,9,255,4,0,207,52,9,255,2,0,168,64,4,255,0,0,6,255,1,0,6,255,1,0,5,255,2,0,169,64,5,255,4,0,208,52,5,255,1,0,179,60,6,255,1,0,5,255,3,0,152,64,6,255,1,0,4,255,2,0,9,255,1,0,180,60,9,255,4,0,212,52,9,255,2,0,171,64,4,255,0,0,6,255,1,0,6,255,1,0,5,255,2,0,172,64,5,255,4,0,213,52,5,255,1,0,181,60,6,255,1,0,5,255,3,0,156,64,6,255,1,0,4,255,2,0,9,255,1,0,182,60,9,255,4,0,217,52,9,255,2,0,174,64,4,255,0,0,6,255,1,0,6,255,4,0,5,255,4,0,218,52,5,255,1,0,183,60,6,255,7,0,4,255,2,0,9,255,1,0,184,60,9,255,4,0,222,52,4,255,0,0,6,255,4,0,6,255,4,0,5,255,4,0,223,52,5,255,1,0,185,60,6,255,7,0,4,255,2,0,9,255,1,0,186,60,9,255,4,0,227,52,4,255,0,0,6,255,4,0,6,255,4,0,5,255,4,0,228,52,5,255,1,0,187,60,6,255,7,0,4,255,2,0,9,255,1,0,188,60,9,255,4,0,232,52,4,255,0,0,6,255,4,0,6,255,4,0,5,255,4,0,233,52,5,255,1,0,189,60,6,255,7,0,4,255,2,0,9,255,1,0,190,60,9,255,4,0,237,52,4,255,0,0,6,255,4,0,6,255,4,0,5,255,4,0,238,52,5,255,1,0,191,60,6,255,7,0,4,255,2,0,9,255,1,0,192,60,9,255,4,0,242,52,4,255,0,0,6,255,4,0,6,255,5,0,5,255,2,0,243,52,6,255,0,0,5,255,1,0,193,60,6,255,7,0,4,255,2,0,9,255,1,0,194,60,6,255,0,0,9,255,2,0,245,52,4,255,0,0,6,255,5,0,6,255,4,0,5,255,4,0,246,52,5,255,1,0,195,60,6,255,7,0,4,255,2,0,9,255,1,0,196,60,9,255,4,0,250,52,4,255,0,0,6,255,4,0,6,255,4,0,5,255,4,0,251,52,5,255,1,0,197,60,6,255,7,0,4,255,2,0,9,255,1,0,198,60,9,255,4,0,255,52,4,255,0,0,6,255,4,0,6,255,127,0,8,255,2,255,2,0,3,255,0,2,1,255,0,7,6,255,191,1,5,255,15,0,1,60,4,255,2,0,9,255,15,0,16,60,4,255,0,0,6,255,3,0,5,255,11,0,17,60,4,255,2,0,9,255,11,0,28,60,4,255,0,0,6,255,3,0,6,255,6,0,5,255,1,0,29,64,6,255,0,0,5,255,2,0,53,56,35,60,6,255,0,0,5,255,1,0,29,64,6,255,0,0,4,255,2,0,35,60,9,255,2,0,55,56,6,255,0,0,9,255,1,0,30,64,4,255,0,0,6,255,6,0,6,255,6,0,5,255,1,0,31,64,5,255,3,0,56,56,36,60,6,255,0,0,5,255,1,0,31,64,6,255,0,0,4,255,2,0,36,60,9,255,3,0,59,56,9,255,1,0,32,64,4,255,0,0,6,255,6,0,6,255,6,0,5,255,1,0,33,64,5,255,3,0,60,56,37,60,6,255,0,0,5,255,1,0,33,64,6,255,0,0,4,255,2,0,37,60,9,255,3,0,63,56,9,255,1,0,34,64,4,255,0,0,6,255,6,0,6,255,8,0,5,255,3,0,64,56,38,60,6,255,3,0,4,255,2,0,38,60,9,255,3,0,67,56,4,255,0,0,6,255,8,0,6,255,8,0,5,255,3,0,68,56,39,60,6,255,3,0,4,255,2,0,39,60,9,255,3,0,71,56,4,255,0,0,6,255,8,0,6,255,8,0,5,255,3,0,72,56,40,60,6,255,3,0,4,255,2,0,40,60,9,255,3,0,75,56,4,255,0,0,6,255,8,0,6,255,8,0,5,255,3,0,76,56,41,60,6,255,3,0,4,255,2,0,41,60,9,255,3,0,79,56,4,255,0,0,6,255,8,0,6,255,8,0,5,255,3,0,80,56,42,60,6,255,3,0,4,255,2,0,42,60,9,255,3,0,83,56,4,255,0,0,6,255,8,0,6,255,8,0,5,255,3,0,84,56,43,60,5,255,3,0,45,68,4,255,2,0,43,60,9,255,3,0,87,56,4,255,0,0,6,255,8,0,6,255,8,0,5,255,3,0,88,56,44,60,5,255,3,0,49,68,4,255,2,0,44,60,9,255,3,0,91,56,4,255,0,0,6,255,8,0,6,255,3,0,5,255,23,0,92,72,6,255,3,0,5,255,31,0,116,72,5,255,31,0,148,72,5,255,31,0,180,72,5,255,31,0,212,72,5,255,11,0,244,72,5,255,19,0,1,73,8,255,2,255,3,0,3,255,0,2,1,255,0,8,6,255,191,1,5,255,7,0,32,40,5,255,7,0,32,40,5,255,7,0,32,40,5,255,7,0,32,40,5,255,7,0,40,40,5,255,7,0,40,40,5,255,7,0,40,40,5,255,7,0,40,40,5,255,7,0,48,40,5,255,7,0,48,40,5,255,7,0,48,40,5,255,7,0,48,40,5,255,7,0,56,36,5,255,7,0,56,36,5,255,7,0,56,36,5,255,7,0,56,36,5,255,7,0,64,32,5,255,7,0,64,32,5,255,7,0,64,32,5,255,7,0,64,32,5,255,7,0,72,32,5,255,7,0,72,32,5,255,7,0,72,32,5,255,7,0,72,32,10,255,31,0,80,44,5,255,7,0,81,32,5,255,7,0,81,32,5,255,7,0,81,32,5,255,7,0,81,32,5,255,7,0,89,32,5,255,7,0,89,32,5,255,7,0,89,32,5,255,7,0,89,32,5,255,7,0,97,36,5,255,7,0,97,36,5,255,7,0,97,36,5,255,7,0,97,36,5,255,7,0,105,40,5,255,7,0,105,40,5,255,7,0,105,40,5,255,7,0,105,40,5,255,7,0,113,40,5,255,7,0,113,40,5,255,7,0,113,40,5,255,7,0,113,40,5,255,7,0,121,40,5,255,7,0,121,40,5,255,7,0,121,40,5,255,7,0,121,40,5,255,7,0,129,40,5,255,7,0,129,40,5,255,7,0,129,40,5,255,7,0,129,40,6,255,127,0,0,255,8,255,8,255,2,255,0,0,3,255,0,3,1,255,0,11,6,255,191,1,6,255,1,0,1,52,6,255,0,0,5,255,2,0,2,52,6,255,16,0,5,255,1,0,64,52,6,255,1,0,5,255,1,0,92,52,6,255,1,0,6,255,1,0,5,52,6,255,0,0,5,255,2,0,6,52,6,255,0,0,5,255,1,0,128,72,6,255,12,0,130,72,5,255,1,0,66,52,6,255,1,0,5,255,1,0,94,52,6,255,1,0,6,255,1,0,9,52,6,255,0,0,5,255,2,0,10,52,6,255,0,0,5,255,15,0,131,72,5,255,1,0,68,52,6,255,1,0,5,255,1,0,96,52,6,255,1,0,6,255,1,0,13,52,6,255,0,0,5,255,2,0,14,52,6,255,0,0,5,255,15,0,147,72,5,255,1,0,70,52,6,255,1,0,5,255,1,0,98,52,6,255,1,0,6,255,1,0,17,52,6,255,0,0,5,255,2,0,18,52,6,255,2,0,5,255,1,0,163,64,165,68,6,255,1,0,5,255,1,0,166,68,6,255,1,0,5,255,2,0,168,68,6,255,1,0,5,255,1,0,72,52,6,255,1,0,5,255,1,0,100,52,6,255,1,0,6,255,1,0,21,52,6,255,0,0,5,255,2,0,22,52,6,255,0,0,5,255,3,0,171,64,5,255,9,0,175,68,5,255,1,0,185,64,5,255,1,0,74,52,6,255,1,0,5,255,1,0,102,52,6,255,1,0,6,255,1,0,25,52,6,255,0,0,5,255,2,0,26,52,6,255,3,0,5,255,1,0,187,68,6,255,5,0,5,255,1,0,208,68,6,255,2,0,5,255,1,0,76,52,6,255,1,0,5,255,1,0,104,52,6,255,1,0,6,255,1,0,5,255,4,0,29,52,6,255,3,0,5,255,1,0,189,68,6,255,5,0,5,255,1,0,210,68,6,255,2,0,5,255,1,0,78,52,6,255,1,0,5,255,1,0,106,52,6,255,1,0,6,255,1,0,5,255,4,0,34,52,6,255,3,0,5,255,1,0,191,68,6,255,5,0,5,255,1,0,212,68,6,255,2,0,5,255,1,0,80,52,6,255,1,0,5,255,1,0,108,52,6,255,1,0,6,255,1,0,5,255,4,0,39,52,6,255,2,0,5,255,2,0,193,68,6,255,5,0,5,255,2,0,214,68,6,255,1,0,5,255,1,0,82,52,5,255,1,0,117,56,5,255,1,0,110,52,6,255,1,0,6,255,1,0,5,255,4,0,44,52,6,255,2,0,5,255,2,0,196,68,6,255,5,0,5,255,2,0,217,68,6,255,1,0,5,255,1,0,84,52,5,255,1,0,119,56,5,255,1,0,112,52,6,255,1,0,6,255,1,0,5,255,4,0,49,52,6,255,2,0,5,255,2,0,199,68,6,255,5,0,5,255,2,0,220,68,6,255,1,0,5,255,1,0,86,52,5,255,2,0,121,56,114,52,6,255,1,0,6,255,1,0,5,255,4,0,54,52,6,255,2,0,5,255,2,0,202,68,6,255,5,0,5,255,2,0,223,68,6,255,1,0,5,255,1,0,88,52,5,255,1,0,124,56,6,255,0,0,115,52,6,255,1,0,6,255,1,0,5,255,4,0,59,52,6,255,2,0,5,255,2,0,205,68,6,255,5,0,5,255,2,0,226,68,6,255,1,0,5,255,1,0,90,52,5,255,1,0,126,56,6,255,0,0,116,52,6,255,1,0,5,255,7,0,229,60,4,255,2,0,9,255,7,0,8,61,4,255,0,0,5,255,15,0,1,61,5,255,6,0,237,60,4,255,2,0,9,255,8,0,25,61,4,255,0,0,5,255,15,0,17,61,5,255,5,0,244,60,4,255,2,0,9,255,9,0,42,61,4,255,0,0,5,255,15,0,33,61,5,255,4,0,250,60,4,255,2,0,9,255,10,0,59,61,4,255,0,0,5,255,15,0,49,61,8,255,2,255,1,0,3,255,0,4,1,255,0,12,6,255,191,1,6,255,63,0,6,255,13,0,5,255,3,0,80,40,6,255,13,0,6,255,13,0,5,255,3,0,84,40,6,255,13,0,6,255,13,0,5,255,2,0,88,40,6,255,14,0,6,255,13,0,5,255,2,0,91,40,6,255,14,0,3,255,0,3,6,255,17,0,5,255,3,0,122,48,6,255,9,0,6,255,13,0,5,255,7,0,126,48,6,255,9,0,6,255,4,0,5,255,1,0,94,48,6,255,6,0,5,255,11,0,134,48,6,255,5,0,6,255,4,0,5,255,2,0,96,48,6,255,5,0,5,255,11,0,146,48,6,255,5,0,6,255,4,0,5,255,4,0,99,48,6,255,2,0,5,255,13,0,158,48,6,255,4,0,6,255,4,0,5,255,3,0,104,48,6,255,3,0,5,255,12,0,171,48,6,255,5,0,6,255,4,0,5,255,6,0,108,48,5,255,14,0,184,48,6,255,4,0,6,255,4,0,5,255,6,0,115,48,5,255,14,0,199,48,6,255,4,0,6,255,127,0,8,255,2,255,2,0,3,255,0,2,1,255,0,9,6,255,191,1,5,255,6,0,1,32,6,255,0,0,5,255,7,0,8,32,5,255,6,0,1,32,6,255,0,0,5,255,7,0,8,32,5,255,15,0,16,32,5,255,15,0,16,32,5,255,15,0,32,32,5,255,15,0,32,32,5,255,15,0,48,32,5,255,15,0,48,32,5,255,15,0,64,32,5,255,15,0,64,32,5,255,15,0,80,32,5,255,15,0,80,32,5,255,15,0,96,32,5,255,15,0,96,32,5,255,15,0,112,32,5,255,15,0,112,32,5,255,15,0,128,32,5,255,15,0,128,32,5,255,13,0,144,32,6,255,0,0,158,32,5,255,13,0,144,32,6,255,0,0,158,32,159,32,6,255,1,0,5,255,10,0,160,32,6,255,0,0,171,32,159,32,6,255,1,0,5,255,10,0,160,32,6,255,0,0,171,32,172,32,6,255,1,0,5,255,10,0,173,32,6,255,0,0,184,32,172,32,6,255,1,0,5,255,10,0,173,32,6,255,0,0,184,32,185,32,6,255,1,0,5,255,12,0,186,32,185,32,6,255,1,0,5,255,12,0,186,32,5,255,15,0,199,32,5,255,15,0,199,32,6,255,127,0,8,255,2,255,3,0,3,255,0,2,1,255,0,9,6,255,191,1,10,255,5,0,1,37,5,255,9,0,1,37,5,255,4,0,91,37,10,255,4,0,1,37,10,255,5,0,1,37,5,255,5,0,166,37,5,255,9,0,11,37,5,255,5,0,96,37,10,255,3,0,1,37,5,255,5,0,160,37,5,255,5,0,178,37,5,255,9,0,21,37,5,255,6,0,102,37,1,37,5,255,1,0,109,37,5,255,5,0,172,37,5,255,5,0,190,37,5,255,9,0,31,37,5,255,9,0,111,37,5,255,5,0,184,37,5,255,5,0,202,37,5,255,9,0,41,37,5,255,9,0,121,37,5,255,5,0,196,37,5,255,5,0,214,37,5,255,9,0,51,37,5,255,9,0,131,37,5,255,5,0,208,37,5,255,5,0,226,37,5,255,9,0,61,37,5,255,9,0,141,37,5,255,5,0,220,37,5,255,5,0,238,37,5,255,9,0,71,37,5,255,2,0,151,37,10,255,1,0,1,37,154,37,10,255,1,0,1,37,5,255,1,0,155,37,5,255,5,0,232,37,5,255,5,0,250,37,5,255,9,0,81,37,10,255,9,0,1,37,5,255,5,0,244,37,3,255,0,3,6,255,6,0,224,44,6,255,2,0,225,44,6,255,10,0,224,44,6,255,2,0,225,44,6,255,3,0,6,255,5,0,5,255,6,0,226,44,6,255,8,0,5,255,6,0,226,44,6,255,2,0,6,255,5,0,5,255,6,0,233,44,6,255,8,0,5,255,6,0,233,44,6,255,2,0,6,255,5,0,5,255,6,0,240,44,6,255,8,0,5,255,6,0,240,44,6,255,2,0,6,255,5,0,5,255,6,0,247,44,6,255,8,0,5,255,6,0,247,44,6,255,2,0,6,255,127,0,0,255,8,255,2,255,8,255,2,255,0,0,3,255,0,4,1,255,0,15,6,255,191,1,6,255,95,0,6,255,15,0,1,68,6,255,14,0,6,255,12,0,5,255,5,0,2,68,6,255,12,0,6,255,12,0,5,255,5,0,8,68,6,255,12,0,6,255,12,0,5,255,5,0,14,68,6,255,12,0,6,255,12,0,5,255,5,0,20,68,6,255,12,0,6,255,12,0,5,255,5,0,26,64,6,255,12,0,6,255,8,0,5,255,1,0,1,73,6,255,0,0,5,255,7,0,32,64,6,255,0,0,4,255,2,0,9,255,1,0,2,73,4,255,0,0,6,255,8,0,6,255,7,0,5,255,2,0,3,73,6,255,0,0,5,255,7,0,40,64,6,255,0,0,4,255,2,0,9,255,2,0,5,73,4,255,0,0,6,255,7,0,6,255,7,0,5,255,2,0,6,73,6,255,0,0,5,255,7,0,48,60,6,255,0,0,4,255,2,0,9,255,2,0,8,73,4,255,0,0,6,255,7,0,6,255,7,0,5,255,2,0,9,73,6,255,0,0,5,255,7,0,56,60,6,255,0,0,4,255,2,0,9,255,2,0,11,73,4,255,0,0,6,255,7,0,6,255,7,0,12,73,6,255,0,0,13,73,5,255,9,0,64,60,4,255,2,0,13,73,6,255,0,0,12,73,4,255,0,0,6,255,7,0,6,255,7,0,14,73,6,255,1,0,5,255,9,0,74,60,6,255,1,0,4,255,2,0,14,73,4,255,0,0,6,255,7,0,6,255,7,0,15,73,6,255,3,0,5,255,5,0,84,60,6,255,3,0,4,255,2,0,15,73,4,255,0,0,6,255,7,0,6,255,63,0,8,255,2,255,1,0,3,255,0,3,1,255,0,15,6,255,191,1,6,255,127,0,6,255,1,0,5,255,1,0,112,56,6,255,5,0,5,255,1,0,114,56,6,255,7,0,5,255,1,0,202,56,6,255,5,0,4,255,2,0,9,255,1,0,113,56,4,255,0,0,6,255,1,0,6,255,1,0,5,255,2,0,116,56,6,255,0,0,119,56,6,255,1,0,5,255,2,0,120,56,6,255,7,0,5,255,2,0,204,56,6,255,3,0,4,255,2,0,9,255,2,0,118,56,4,255,0,0,6,255,1,0,6,255,1,0,5,255,5,0,123,56,6,255,0,0,5,255,3,0,129,56,6,255,5,0,5,255,3,0,207,56,6,255,3,0,4,255,2,0,9,255,2,0,125,56,4,255,0,0,6,255,1,0,6,255,0,0,5,255,6,0,133,56,6,255,0,0,5,255,3,0,140,56,6,255,5,0,5,255,7,0,211,56,4,255,2,0,9,255,3,0,136,56,4,255,0,0,6,255,0,0,6,255,0,0,5,255,7,0,144,56,6,255,0,0,5,255,2,0,152,56,6,255,5,0,5,255,7,0,219,56,4,255,2,0,9,255,3,0,147,56,4,255,0,0,6,255,0,0,6,255,0,0,5,255,11,0,155,56,6,255,5,0,5,255,7,0,227,56,4,255,2,0,9,255,3,0,158,56,4,255,0,0,6,255,0,0,6,255,0,0,5,255,11,0,167,56,6,255,5,0,5,255,7,0,235,56,4,255,2,0,9,255,3,0,170,56,4,255,0,0,6,255,0,0,6,255,0,0,5,255,11,0,179,56,6,255,5,0,5,255,7,0,243,56,4,255,2,0,9,255,3,0,182,56,4,255,0,0,6,255,0,0,6,255,1,0,5,255,10,0,191,56,6,255,5,0,5,255,4,0,251,56,5,255,2,0,109,56,4,255,2,0,9,255,2,0,193,56,4,255,0,0,6,255,1,0,6,255,159,0,8,255,2,255,2,0,3,255,0,2,1,255,0,12,6,255,191,1,6,255,1,0,0,32,5,255,1,0,1,32,0,36,5,255,1,0,144,37,0,40,5,255,1,0,172,41,0,44,5,255,1,0,203,45,6,255,3,0,4,255,2,0,9,255,1,0,2,32,0,32,9,255,1,0,145,37,0,36,9,255,1,0,173,41,0,40,9,255,1,0,204,45,0,44,4,255,0,0,6,255,1,0,6,255,1,0,0,32,5,255,1,0,3,32,5,255,2,0,146,37,5,255,2,0,174,41,5,255,2,0,205,45,6,255,3,0,4,255,2,0,9,255,1,0,4,32,0,32,9,255,2,0,148,37,9,255,2,0,176,41,9,255,2,0,207,45,4,255,0,0,6,255,1,0,6,255,1,0,0,32,5,255,1,0,5,32,5,255,2,0,149,37,5,255,2,0,177,41,5,255,2,0,208,45,6,255,3,0,4,255,2,0,9,255,1,0,6,32,0,32,9,255,2,0,151,37,9,255,2,0,179,41,9,255,2,0,210,45,4,255,0,0,6,255,1,0,6,255,1,0,0,32,5,255,1,0,7,32,0,36,5,255,1,0,152,37,5,255,2,0,180,41,0,44,5,255,1,0,211,45,6,255,3,0,4,255,2,0,9,255,1,0,8,32,0,32,9,255,1,0,153,37,0,36,9,255,2,0,182,41,9,255,1,0,212,45,0,44,4,255,0,0,6,255,1,0,6,255,1,0,0,32,5,255,1,0,9,32,5,255,2,0,154,37,5,255,2,0,183,41,0,44,5,255,1,0,213,45,6,255,3,0,4,255,2,0,9,255,1,0,10,32,0,32,9,255,2,0,156,37,9,255,2,0,185,41,9,255,1,0,214,45,0,44,4,255,0,0,6,255,1,0,6,255,1,0,0,32,5,255,1,0,11,32,5,255,2,0,157,37,5,255,2,0,186,41,0,44,5,255,1,0,215,45,6,255,3,0,4,255,2,0,9,255,1,0,12,32,0,32,9,255,2,0,159,37,9,255,2,0,188,41,9,255,1,0,216,45,0,44,4,255,0,0,6,255,1,0,6,255,1,0,0,32,5,255,1,0,13,32,5,255,2,0,160,37,5,255,2,0,189,41,0,44,5,255,1,0,217,45,6,255,3,0,4,255,2,0,9,255,1,0,14,32,0,32,9,255,2,0,162,37,9,255,2,0,191,41,9,255,1,0,218,45,0,44,4,255,0,0,6,255,1,0,6,255,1,0,5,255,2,0,15,32,5,255,2,0,163,37,5,255,2,0,192,41,5,255,2,0,219,45,6,255,3,0,4,255,2,0,9,255,2,0,17,32,9,255,2,0,165,37,9,255,2,0,194,41,9,255,2,0,221,45,4,255,0,0,6,255,1,0,6,255,1,0,5,255,2,0,18,32,5,255,2,0,166,37,5,255,2,0,195,41,5,255,2,0,222,45,6,255,3,0,4,255,2,0,9,255,2,0,20,32,9,255,2,0,168,37,9,255,2,0,197,41,9,255,2,0,224,45,4,255,0,0,6,255,1,0,6,255,1,0,5,255,2,0,21,32,169,37,10,255,1,0,0,36,5,255,2,0,198,41,225,45,10,255,1,0,0,44,6,255,3,0,4,255,2,0,9,255,2,0,23,32,10,255,1,0,0,36,169,37,9,255,2,0,200,41,10,255,1,0,0,44,225,45,4,255,0,0,6,255,1,0,6,255,1,0,24,32,10,255,1,0,0,32,170,37,10,255,1,0,0,36,201,41,10,255,1,0,0,40,226,45,10,255,1,0,0,44,6,255,3,0,4,255,2,0,10,255,1,0,0,32,24,32,10,255,1,0,0,36,170,37,10,255,1,0,0,40,201,41,10,255,1,0,0,44,226,45,4,255,0,0,6,255,1,0,6,255,1,0,25,32,10,255,1,0,0,32,171,37,10,255,1,0,0,36,202,41,10,255,1,0,0,40,227,45,10,255,1,0,0,44,6,255,3,0,4,255,2,0,10,255,1,0,0,32,25,32,10,255,1,0,0,36,171,37,10,255,1,0,0,40,202,41,10,255,1,0,0,44,227,45,4,255,0,0,6,255,1,0,6,255,31,0,3,255,0,4,6,255,11,0,5,255,1,0,112,49,10,255,4,0,114,49,115,49,6,255,11,0,6,255,10,0,5,255,9,0,116,49,6,255,10,0,6,255,10,0,5,255,9,0,126,49,6,255,10,0,6,255,63,0,8,255,2,255,3,0,3,255,0,2,1,255,0,12,6,255,191,1,4,255,2,0,9,255,15,0,63,52,4,255,0,0,5,255,15,0,48,52,4,255,2,0,9,255,15,0,79,52,4,255,0,0,5,255,15,0,64,52,4,255,2,0,9,255,15,0,95,52,4,255,0,0,5,255,15,0,80,52,4,255,2,0,10,255,1,0,99,52,113,52,99,52,9,255,2,0,110,52,10,255,1,0,99,52,9,255,1,0,105,52,10,255,1,0,99,52,9,255,2,0,98,52,4,255,0,0,5,255,2,0,96,52,10,255,1,0,99,52,5,255,1,0,104,52,10,255,1,0,99,52,5,255,2,0,108,52,99,52,113,52,10,255,1,0,99,52,4,255,2,0,10,255,1,0,99,52,114,52,10,255,2,0,99,52,111,52,10,255,2,0,99,52,106,52,10,255,1,0,99,52,9,255,1,0,101,52,10,255,1,0,99,52,4,255,0,0,5,255,1,0,100,52,10,255,1,0,99,52,106,52,10,255,2,0,99,52,111,52,10,255,2,0,99,52,114,52,10,255,1,0,99,52,4,255,2,0,10,255,1,0,29,52,115,52,10,255,2,0,29,52,112,52,10,255,2,0,29,52,107,52,10,255,1,0,29,52,9,255,1,0,103,52,10,255,1,0,29,52,4,255,0,0,5,255,1,0,102,52,10,255,1,0,29,52,107,52,10,255,2,0,29,52,112,52,10,255,2,0,29,52,115,52,10,255,1,0,29,52,3,255,0,3,5,255,10,0,116,52,6,255,8,0,5,255,4,0,187,52,4,255,2,0,9,255,6,0,122,52,4,255,0,0,5,255,11,0,127,52,6,255,7,0,5,255,4,0,192,52,4,255,2,0,9,255,6,0,133,52,4,255,0,0,5,255,11,0,139,52,6,255,7,0,5,255,4,0,197,52,4,255,2,0,9,255,6,0,145,52,4,255,0,0,5,255,11,0,151,52,6,255,7,0,5,255,4,0,202,52,4,255,2,0,9,255,6,0,157,52,4,255,0,0,5,255,11,0,163,52,6,255,6,0,5,255,5,0,207,52,4,255,2,0,9,255,6,0,169,52,4,255,0,0,5,255,11,0,175,52,6,255,6,0,5,255,5,0,213,52,4,255,2,0,9,255,6,0,181,52,4,255,0,0,10,255,31,0,29,48,5,255,3,0,219,48,5,255,3,0,219,48,5,255,3,0,219,48,5,255,3,0,219,48,5,255,3,0,219,48,5,255,3,0,219,48,5,255,3,0,219,48,5,255,3,0,219,48,5,255,15,0,33,49,5,255,15,0,223,48,5,255,15,0,49,49,5,255,15,0,239,48,5,255,15,0,65,49,5,255,15,0,1,49,5,255,15,0,81,49,5,255,15,0,17,49,0,255,8,255,2,255,8,255,2,255,0,0,3,255,0,4,1,255,0,17,6,255,191,1,6,255,223,0,6,255,1,0,4,255,2,0,9,255,1,0,2,36,4,255,0,0,6,255,23,0,5,255,1,0,1,36,6,255,1,0,4,255,2,0,9,255,4,0,7,36,4,255,0,0,6,255,3,0,5,255,1,0,55,56,6,255,9,0,4,255,2,0,9,255,1,0,56,56,4,255,0,0,6,255,3,0,5,255,4,0,3,36,4,255,2,0,9,255,5,0,13,36,4,255,0,0,6,255,2,0,5,255,2,0,57,56,6,255,7,0,4,255,2,0,9,255,2,0,59,56,4,255,0,0,6,255,2,0,5,255,5,0,8,36,4,255,2,0,9,255,5,0,21,36,4,255,0,0,6,255,2,0,5,255,1,0,60,56,6,255,9,0,4,255,2,0,9,255,1,0,61,56,4,255,0,0,6,255,2,0,5,255,5,0,16,36,4,255,2,0,9,255,6,0,30,36,4,255,0,0,6,255,1,0,5,255,1,0,62,56,6,255,9,0,4,255,2,0,9,255,1,0,63,56,4,255,0,0,6,255,1,0,5,255,6,0,24,36,4,255,2,0,9,255,6,0,39,36,4,255,0,0,6,255,2,0,64,56,6,255,9,0,4,255,2,0,64,56,4,255,0,0,6,255,2,0,5,255,6,0,33,36,4,255,2,0,9,255,6,0,48,36,4,255,0,0,6,255,1,0,5,255,2,0,65,56,6,255,7,0,4,255,2,0,9,255,2,0,67,56,4,255,0,0,6,255,1,0,5,255,6,0,42,36,6,255,0,0,4,255,2,0,9,255,1,0,52,36,4,255,0,0,6,255,5,0,5,255,2,0,68,56,6,255,7,0,4,255,2,0,9,255,2,0,70,56,4,255,0,0,6,255,5,0,5,255,1,0,51,36,6,255,0,0,8,255,2,255,1,0,3,255,0,4,1,255,0,17,6,255,191,1,6,255,63,0,6,255,1,0,4,255,2,0,9,255,13,0,124,52,4,255,0,0,5,255,13,0,111,52,6,255,1,0,6,255,1,0,4,255,2,0,9,255,13,0,138,52,4,255,0,0,5,255,13,0,125,52,6,255,1,0,6,255,0,0,4,255,2,0,9,255,14,0,153,52,4,255,0,0,5,255,14,0,139,52,6,255,0,0,4,255,2,0,9,255,15,0,169,52,4,255,0,0,5,255,15,0,154,52,4,255,2,0,9,255,15,0,185,52,4,255,0,0,5,255,15,0,170,52,6,255,0,0,4,255,2,0,9,255,14,0,200,48,4,255,0,0,5,255,14,0,186,48,6,255,0,0,4,255,2,0,9,255,15,0,216,48,4,255,0,0,5,255,15,0,201,48,4,255,2,0,9,255,12,0,229,48,4,255,0,0,6,255,5,0,5,255,12,0,217,48,4,255,2,0,9,255,12,0,242,48,4,255,0,0,6,255,5,0,5,255,12,0,230,48,4,255,2,0,9,255,12,0,255,48,4,255,0,0,6,255,5,0,5,255,12,0,243,48,4,255,2,0,9,255,12,0,13,49,4,255,0,0,6,255,5,0,5,255,12,0,1,49,4,255,2,0,9,255,12,0,26,49,4,255,0,0,6,255,5,0,5,255,12,0,14,49,6,255,127,0,8,255,2,255,2,0,3,255,0,4,1,255,0,14,6,255,191,1,6,255,191,0,6,255,10,0,5,255,11,0,1,44,6,255,8,0,6,255,10,0,5,255,11,0,13,44,6,255,8,0,6,255,10,0,5,255,11,0,25,44,6,255,8,0,6,255,10,0,5,255,11,0,37,44,6,255,8,0,6,255,10,0,5,255,11,0,49,44,6,255,8,0,6,255,10,0,5,255,11,0,61,44,6,255,8,0,6,255,10,0,5,255,11,0,73,44,6,255,8,0,10,255,11,0,97,60,5,255,11,0,85,44,10,255,7,0,97,60,4,255,2,0,9,255,13,0,121,60,4,255,0,0,5,255,1,0,98,60,5,255,15,0,106,60,4,255,2,0,9,255,13,0,137,60,4,255,0,0,5,255,1,0,100,60,5,255,15,0,122,60,4,255,2,0,9,255,13,0,153,60,4,255,0,0,5,255,1,0,102,60,5,255,15,0,138,60,4,255,2,0,9,255,13,0,169,60,4,255,0,0,5,255,1,0,104,60,5,255,15,0,154,60,8,255,2,255,3,0,3,255,0,2,1,255,0,14,6,255,191,1,5,255,15,0,176,32,5,255,15,0,176,32,5,255,15,0,192,32,5,255,15,0,192,32,5,255,15,0,208,32,5,255,15,0,208,32,5,255,15,0,224,32,5,255,15,0,224,32,5,255,15,0,240,32,5,255,15,0,240,32,5,255,15,0,1,33,5,255,15,0,1,33,5,255,15,0,17,33,5,255,15,0,17,33,5,255,15,0,33,33,5,255,15,0,33,33,6,255,63,1,0,255,8,255,2,255,0,0,8,255,2,255,0,0,3,255,0,2,1,255,0,8,6,255,191,1,6,255,127,0,6,255,9,0,5,255,2,0,1,40,5,255,4,0,41,52,6,255,0,0,5,255,2,0,46,52,5,255,2,0,21,40,6,255,6,0,6,255,9,0,5,255,2,0,4,40,5,255,8,0,49,52,5,255,2,0,24,40,6,255,6,0,6,255,9,0,5,255,1,0,7,40,6,255,0,0,5,255,8,0,58,52,6,255,0,0,5,255,1,0,27,40,6,255,6,0,6,255,9,0,5,255,1,0,9,40,6,255,0,0,5,255,4,0,67,52,6,255,0,0,5,255,2,0,72,52,6,255,0,0,5,255,1,0,29,40,6,255,6,0,6,255,9,0,5,255,1,0,11,40,6,255,10,0,5,255,1,0,31,40,6,255,6,0,6,255,9,0,5,255,1,0,13,40,6,255,10,0,5,255,1,0,33,40,6,255,6,0,6,255,9,0,5,255,1,0,15,40,6,255,10,0,5,255,1,0,35,40,6,255,6,0,6,255,9,0,5,255,1,0,17,40,6,255,10,0,5,255,1,0,37,40,6,255,6,0,6,255,9,0,5,255,1,0,19,40,6,255,10,0,5,255,1,0,39,40,6,255,6,0,5,255,7,0,83,32,5,255,15,0,75,32,5,255,7,0,75,32,5,255,7,0,99,32,5,255,15,0,91,32,5,255,7,0,91,32,5,255,7,0,115,32,5,255,15,0,107,32,5,255,7,0,107,32,6,255,63,0,8,255,2,255,1,0,3,255,0,2,1,255,0,9,6,255,191,1,6,255,1,0,5,255,13,0,1,40,5,255,15,0,74,40,6,255,3,0,5,255,11,0,15,40,5,255,13,0,90,40,6,255,1,0,6,255,5,0,5,255,9,0,27,40,5,255,12,0,104,40,6,255,2,0,6,255,6,0,5,255,8,0,37,40,5,255,10,0,117,40,6,255,4,0,6,255,8,0,5,255,6,0,46,40,5,255,9,0,128,40,6,255,5,0,6,255,9,0,5,255,5,0,53,40,5,255,6,0,138,40,6,255,8,0,6,255,10,0,5,255,4,0,59,40,5,255,5,0,145,40,6,255,9,0,6,255,11,0,5,255,3,0,64,40,5,255,5,0,151,40,6,255,9,0,6,255,12,0,5,255,2,0,68,40,5,255,4,0,157,40,6,255,10,0,6,255,12,0,71,40,6,255,5,0,162,40,6,255,10,0,6,255,12,0,72,40,6,255,5,0,163,40,6,255,10,0,6,255,12,0,73,40,6,255,5,0,164,40,6,255,10,0,6,255,95,0,3,255,0,3,6,255,0,0,4,255,2,0,9,255,14,0,179,48,4,255,0,0,5,255,14,0,165,48,6,255,0,0,4,255,2,0,9,255,15,0,195,48,4,255,0,0,5,255,15,0,180,48,4,255,2,0,9,255,15,0,211,48,4,255,0,0,5,255,15,0,196,48,8,255,2,255,2,0,3,255,0,2,1,255,0,4,6,255,191,1,6,255,95,0,6,255,5,0,5,255,1,0,198,37,6,255,5,0,5,255,3,0,1,36,6,255,13,0,6,255,3,0,5,255,3,0,200,37,5,255,12,0,5,36,6,255,3,0,5,255,2,0,228,37,6,255,3,0,6,255,3,0,5,255,3,0,204,37,5,255,15,0,18,36,5,255,3,0,231,37,6,255,3,0,6,255,3,0,5,255,3,0,208,37,5,255,15,0,34,36,5,255,3,0,235,37,6,255,3,0,6,255,3,0,5,255,3,0,212,37,5,255,15,0,50,36,5,255,3,0,239,37,6,255,3,0,6,255,3,0,5,255,3,0,216,37,5,255,15,0,66,36,5,255,3,0,243,37,6,255,3,0,6,255,3,0,5,255,3,0,220,37,5,255,15,0,82,36,5,255,3,0,247,37,6,255,3,0,6,255,3,0,5,255,3,0,224,37,5,255,15,0,98,36,5,255,3,0,251,37,6,255,3,0,6,255,95,0,3,255,0,4,6,255,4,0,5,255,2,0,1,58,6,255,0,0,5,255,1,0,7,58,6,255,9,0,5,255,1,0,11,58,6,255,0,0,5,255,2,0,15,58,6,255,4,0,6,255,4,0,5,255,2,0,4,58,6,255,0,0,5,255,1,0,9,58,6,255,9,0,5,255,1,0,13,58,6,255,0,0,5,255,2,0,18,58,6,255,4,0,6,255,63,0,8,255,2,255,3,0,3,255,0,2,1,255,0,6,6,255,191,1,5,255,15,0,109,60,5,255,15,0,109,60,5,255,15,0,125,60,5,255,15,0,125,60,5,255,15,0,141,60,5,255,15,0,141,60,5,255,15,0,109,60,5,255,15,0,109,60,5,255,15,0,125,60,5,255,15,0,125,60,5,255,15,0,141,60,5,255,15,0,141,60,6,255,127,0,3,255,0,3,5,255,7,0,40,44,5,255,15,0,32,44,5,255,7,0,32,44,5,255,7,0,56,44,5,255,15,0,48,44,5,255,7,0,48,44,5,255,7,0,72,44,5,255,15,0,64,44,5,255,7,0,64,44,5,255,7,0,88,44,5,255,15,0,80,44,5,255,7,0,80,44,6,255,3,0,5,255,3,0,102,44,5,255,4,0,96,44,6,255,6,0,5,255,3,0,102,44,5,255,4,0,96,44,6,255,2,0,6,255,5,0,5,255,1,0,107,44,106,44,6,255,12,0,5,255,1,0,107,44,106,44,6,255,6,0,6,255,63,0,0,255,8,255,8,255,2,255,0,0,3,255,0,4,1,255,0,2,6,255,191,1,5,255,15,0,1,44,5,255,15,0,1,44,5,255,15,0,17,44,5,255,15,0,17,44,5,255,1,0,39,60,6,255,3,0,5,255,3,0,37,60,6,255,3,0,5,255,3,0,37,60,6,255,3,0,5,255,3,0,37,60,6,255,3,0,5,255,1,0,37,60,5,255,1,0,43,60,6,255,3,0,5,255,3,0,41,60,6,255,3,0,5,255,3,0,41,60,6,255,3,0,5,255,3,0,41,60,6,255,3,0,5,255,1,0,41,60,5,255,1,0,47,60,6,255,3,0,5,255,3,0,45,60,6,255,3,0,5,255,3,0,45,60,6,255,3,0,5,255,3,0,45,60,6,255,3,0,5,255,1,0,45,60,5,255,1,0,51,60,6,255,3,0,5,255,3,0,49,60,6,255,3,0,5,255,3,0,49,60,6,255,3,0,5,255,3,0,49,60,6,255,3,0,5,255,1,0,49,60,54,60,6,255,5,0,5,255,1,0,53,60,6,255,5,0,5,255,1,0,53,60,6,255,5,0,5,255,1,0,53,60,6,255,5,0,53,60,6,255,223,0,3,255,0,3,6,255,1,0,5,255,1,0,57,36,5,255,1,0,59,32,5,255,2,0,61,36,5,255,12,0,64,32,4,255,2,0,64,32,9,255,2,0,63,36,9,255,1,0,60,32,9,255,1,0,58,36,4,255,0,0,6,255,1,0,6,255,0,0,5,255,2,0,78,36,5,255,1,0,81,32,5,255,2,0,83,36,5,255,12,0,86,32,4,255,2,0,86,32,9,255])
.concat([2,0,85,36,9,255,1,0,82,32,9,255,2,0,80,36,4,255,0,0,6,255,0,0,5,255,3,0,99,36,5,255,1,0,103,32,5,255,2,0,105,36,5,255,12,0,108,32,4,255,2,0,108,32,9,255,2,0,107,36,9,255,1,0,104,32,9,255,3,0,102,36,4,255,0,0,5,255,3,0,121,36,5,255,1,0,125,32,5,255,2,0,127,36,5,255,12,0,130,32,4,255,2,0,130,32,9,255,2,0,129,36,9,255,1,0,126,32,9,255,3,0,124,36,4,255,0,0,8,255,2,255,1,0,3,255,0,4,1,255,0,2,6,255,191,1,6,255,63,0,6,255,3,0,5,255,1,0,171,56,6,255,2,0,5,255,1,0,171,56,6,255,9,0,4,255,2,0,9,255,1,0,172,56,6,255,2,0,9,255,1,0,172,56,4,255,0,0,6,255,3,0,6,255,3,0,5,255,1,0,173,56,6,255,2,0,5,255,1,0,173,56,6,255,9,0,4,255,2,0,9,255,1,0,174,56,6,255,2,0,9,255,1,0,174,56,4,255,0,0,6,255,3,0,6,255,3,0,5,255,1,0,175,56,6,255,2,0,5,255,1,0,175,56,6,255,9,0,4,255,2,0,9,255,1,0,176,56,6,255,2,0,9,255,1,0,176,56,4,255,0,0,6,255,3,0,6,255,3,0,5,255,1,0,177,56,6,255,2,0,5,255,1,0,177,56,6,255,9,0,4,255,2,0,9,255,1,0,178,56,6,255,2,0,9,255,1,0,178,56,4,255,0,0,6,255,3,0,6,255,3,0,5,255,1,0,179,56,6,255,2,0,5,255,1,0,179,56,6,255,0,0,5,255,1,0,144,52,6,255,3,0,4,255,2,0,9,255,1,0,145,48,6,255,0,0,9,255,1,0,180,56,6,255,2,0,9,255,1,0,180,56,4,255,0,0,6,255,3,0,6,255,3,0,5,255,1,0,181,56,6,255,2,0,5,255,1,0,181,56,6,255,0,0,5,255,2,0,146,52,6,255,1,0,4,255,2,0,9,255,2,0,148,48,6,255,0,0,9,255,1,0,182,56,6,255,2,0,9,255,1,0,182,56,4,255,0,0,6,255,3,0,6,255,3,0,5,255,1,0,183,56,6,255,2,0,5,255,1,0,183,56,6,255,0,0,5,255,2,0,149,52,6,255,1,0,4,255,2,0,9,255,2,0,151,48,6,255,0,0,9,255,1,0,184,56,6,255,2,0,9,255,1,0,184,56,4,255,0,0,6,255,3,0,6,255,3,0,5,255,1,0,185,56,6,255,2,0,5,255,1,0,185,56,5,255,3,0,152,52,6,255,1,0,4,255,2,0,9,255,3,0,155,48,9,255,1,0,186,56,6,255,2,0,9,255,1,0,186,56,4,255,0,0,6,255,3,0,6,255,3,0,5,255,1,0,187,56,6,255,2,0,5,255,1,0,187,56,5,255,4,0,156,52,4,255,2,0,9,255,4,0,160,48,9,255,1,0,188,56,6,255,2,0,9,255,1,0,188,56,4,255,0,0,6,255,3,0,6,255,3,0,5,255,1,0,189,56,6,255,2,0,5,255,1,0,189,56,5,255,4,0,161,52,4,255,2,0,9,255,4,0,165,48,9,255,1,0,190,56,6,255,2,0,9,255,1,0,190,56,4,255,0,0,6,255,3,0,6,255,3,0,5,255,1,0,191,56,6,255,2,0,5,255,1,0,191,56,5,255,4,0,166,52,4,255,2,0,9,255,4,0,170,48,9,255,1,0,192,56,6,255,2,0,9,255,1,0,192,56,4,255,0,0,6,255,3,0,6,255,3,0,5,255,1,0,193,56,6,255,2,0,5,255,7,0,193,56,4,255,2,0,9,255,5,0,198,56,6,255,2,0,9,255,1,0,194,56,4,255,0,0,6,255,3,0,6,255,3,0,5,255,1,0,201,56,6,255,2,0,5,255,7,0,201,56,4,255,2,0,9,255,5,0,206,56,6,255,2,0,9,255,1,0,202,56,4,255,0,0,6,255,3,0,6,255,95,0,8,255,2,255,2,0,3,255,0,4,1,255,0,1,6,255,191,1,6,255,63,0,5,255,2,0,1,44,5,255,2,0,1,44,5,255,2,0,1,44,5,255,2,0,1,44,5,255,2,0,1,44,5,255,2,0,1,44,5,255,2,0,1,44,5,255,2,0,1,44,5,255,2,0,1,44,5,255,2,0,1,44,5,255,1,0,1,44,5,255,2,0,4,44,5,255,2,0,4,44,5,255,2,0,4,44,5,255,2,0,4,44,5,255,2,0,4,44,5,255,2,0,4,44,5,255,2,0,4,44,5,255,2,0,4,44,5,255,2,0,4,44,5,255,2,0,4,44,5,255,1,0,4,44,5,255,7,0,7,44,5,255,7,0,7,44,5,255,7,0,7,44,5,255,7,0,7,44,5,255,7,0,15,44,5,255,7,0,15,44,5,255,7,0,15,44,5,255,7,0,15,44,6,255,2,0,25,56,6,255,3,0,25,56,6,255,3,0,25,56,6,255,3,0,25,56,6,255,3,0,25,56,6,255,3,0,25,56,6,255,2,0,6,255,2,0,26,56,6,255,3,0,26,56,6,255,3,0,26,56,6,255,3,0,26,56,6,255,3,0,26,56,6,255,3,0,26,56,6,255,2,0,6,255,2,0,27,56,6,255,3,0,27,56,6,255,3,0,27,56,6,255,3,0,27,56,6,255,3,0,27,56,6,255,3,0,27,56,6,255,2,0,6,255,2,0,28,56,6,255,3,0,28,56,6,255,3,0,28,56,6,255,3,0,28,56,6,255,3,0,28,56,6,255,3,0,28,56,6,255,2,0,6,255,2,0,29,56,6,255,3,0,29,56,6,255,3,0,29,56,6,255,3,0,29,56,6,255,3,0,29,56,6,255,3,0,29,56,6,255,2,0,6,255,2,0,30,56,6,255,3,0,30,56,6,255,3,0,30,56,6,255,3,0,30,56,6,255,3,0,30,56,6,255,3,0,30,56,6,255,2,0,6,255,2,0,31,56,6,255,3,0,31,56,6,255,3,0,31,56,6,255,3,0,31,56,6,255,3,0,31,56,6,255,3,0,31,56,6,255,2,0,6,255,2,0,32,56,6,255,3,0,32,56,6,255,3,0,32,56,6,255,3,0,32,56,6,255,3,0,32,56,6,255,3,0,32,56,6,255,2,0,6,255,2,0,33,56,6,255,3,0,33,56,6,255,3,0,33,56,6,255,3,0,33,56,6,255,3,0,33,56,6,255,3,0,33,56,6,255,2,0,6,255,95,0,8,255,2,255,3,0,3,255,0,4,1,255,0,1,6,255,191,1,6,255,191,0,5,255,7,0,48,44,5,255,7,0,48,44,5,255,7,0,48,44,5,255,7,0,48,44,5,255,15,0,56,44,5,255,15,0,160,44,5,255,15,0,72,44,5,255,15,0,176,44,5,255,15,0,88,44,5,255,15,0,192,44,6,255,2,0,4,255,2,0,9,255,11,0,117,40,4,255,0,0,5,255,13,0,104,40,6,255,2,0,6,255,2,0,4,255,2,0,9,255,11,0,131,40,4,255,0,0,5,255,13,0,118,40,6,255,2,0,6,255,2,0,4,255,2,0,9,255,11,0,145,40,4,255,0,0,5,255,13,0,132,40,6,255,2,0,6,255,2,0,4,255,2,0,9,255,11,0,159,40,4,255,0,0,5,255,13,0,146,40,6,255,2,0,6,255,127,0,0,255,8,255,2,255,0,0,3,255,0,2,1,255,8,255,2,255,0,0,3,255,0,4,1,255,0,0,6,255,191,1,6,255,3,0,1,68,6,255,2,0,1,68,5,255,1,0,11,52,6,255,0,0,1,68,6,255,5,0,4,255,2,0,1,68,6,255,0,0,4,255,0,0,5,255,2,0,31,52,4,255,2,0,1,68,6,255,2,0,1,68,4,255,0,0,6,255,2,0,6,255,3,0,2,68,6,255,2,0,2,68,5,255,1,0,11,52,6,255,0,0,2,68,6,255,5,0,4,255,2,0,2,68,6,255,0,0,4,255,0,0,5,255,2,0,31,52,4,255,2,0,2,68,6,255,2,0,2,68,4,255,0,0,6,255,2,0,6,255,2,0,5,255,1,0,3,68,6,255,1,0,5,255,1,0,3,68,5,255,1,0,11,52,5,255,1,0,3,68,6,255,5,0,4,255,2,0,9,255,1,0,4,68,4,255,0,0,5,255,2,0,31,52,4,255,2,0,9,255,1,0,4,68,6,255,1,0,9,255,1,0,4,68,4,255,0,0,6,255,1,0,6,255,2,0,5,255,1,0,5,64,6,255,1,0,5,255,1,0,5,64,5,255,1,0,11,52,5,255,1,0,5,64,6,255,5,0,4,255,2,0,9,255,1,0,6,64,4,255,0,0,5,255,2,0,31,52,4,255,2,0,9,255,1,0,6,64,6,255,1,0,9,255,1,0,6,64,4,255,0,0,6,255,1,0,6,255,2,0,5,255,1,0,7,64,6,255,1,0,5,255,1,0,7,64,5,255,1,0,13,52,5,255,1,0,7,64,6,255,5,0,4,255,2,0,9,255,1,0,8,64,4,255,0,0,5,255,2,0,34,52,4,255,2,0,9,255,1,0,8,64,6,255,1,0,9,255,1,0,8,64,4,255,0,0,6,255,1,0,6,255,2,0,5,255,1,0,9,68,6,255,1,0,5,255,1,0,9,68,5,255,1,0,15,52,5,255,1,0,9,68,6,255,5,0,4,255,2,0,9,255,1,0,10,68,4,255,0,0,5,255,2,0,37,52,4,255,2,0,9,255,1,0,10,68,6,255,1,0,9,255,1,0,10,68,4,255,0,0,6,255,1,0,6,255,8,0,5,255,1,0,17,52,6,255,9,0,5,255,2,0,40,52,6,255,7,0,6,255,8,0,5,255,1,0,19,52,6,255,9,0,5,255,2,0,43,52,6,255,7,0,6,255,8,0,5,255,1,0,21,52,6,255,9,0,5,255,2,0,46,52,6,255,7,0,6,255,6,0,62,56,6,255,0,0,5,255,1,0,23,52,61,56,6,255,7,0,62,56,5,255,2,0,49,52,61,56,6,255,6,0,5,255,7,0,65,56,6,255,0,0,5,255,1,0,25,52,5,255,9,0,63,56,5,255,2,0,52,52,5,255,7,0,63,56,5,255,7,0,75,56,6,255,0,0,5,255,1,0,27,52,5,255,9,0,73,56,5,255,2,0,55,52,5,255,7,0,73,56,5,255,7,0,85,56,6,255,0,0,5,255,1,0,29,52,5,255,9,0,83,56,5,255,2,0,58,52,5,255,7,0,83,56,6,255,6,0,5,255,1,0,94,56,6,255,1,0,93,56,6,255,7,0,5,255,1,0,94,56,6,255,1,0,93,56,6,255,6,0,4,255,2,0,9,255,13,0,113,60,4,255,0,0,5,255,17,0,96,60,4,255,2,0,9,255,13,0,131,60,4,255,0,0,5,255,17,0,114,60,4,255,2,0,9,255,13,0,149,60,4,255,0,0,5,255,17,0,132,60,4,255,2,0,9,255,13,0,167,60,4,255,0,0,5,255,17,0,150,60,8,255,2,255,1,0,3,255,0,3,1,255,0,0,6,255,191,1,6,255,3,0,5,255,2,0,176,44,5,255,2,0,176,44,5,255,2,0,176,44,5,255,2,0,176,44,5,255,2,0,176,44,5,255,2,0,176,44,5,255,2,0,176,44,5,255,2,0,176,44,6,255,3,0,6,255,3,0,5,255,2,0,176,44,5,255,2,0,176,44,5,255,2,0,176,44,5,255,2,0,176,44,5,255,2,0,176,44,5,255,2,0,176,44,5,255,2,0,176,44,5,255,2,0,176,44,6,255,3,0,6,255,3,0,5,255,3,0,179,44,5,255,3,0,179,44,5,255,3,0,179,44,5,255,3,0,179,44,5,255,3,0,179,44,5,255,3,0,179,44,6,255,3,0,6,255,3,0,5,255,1,0,183,44,6,255,4,0,5,255,2,0,185,44,6,255,4,0,5,255,2,0,19,45,6,255,4,0,22,45,6,255,3,0,6,255,3,0,5,255,1,0,188,44,6,255,4,0,5,255,2,0,190,44,6,255,4,0,5,255,2,0,23,45,6,255,4,0,26,45,6,255,3,0,6,255,3,0,5,255,1,0,193,44,6,255,4,0,5,255,2,0,195,44,6,255,4,0,5,255,2,0,27,45,6,255,4,0,30,45,6,255,3,0,6,255,3,0,5,255,1,0,198,44,6,255,4,0,5,255,2,0,200,44,6,255,4,0,5,255,2,0,31,45,6,255,4,0,34,45,6,255,3,0,6,255,3,0,5,255,1,0,203,44,6,255,4,0,5,255,2,0,205,44,6,255,4,0,5,255,2,0,35,45,6,255,4,0,38,45,6,255,3,0,6,255,3,0,5,255,1,0,208,44,6,255,4,0,5,255,2,0,210,44,6,255,4,0,5,255,2,0,39,45,6,255,4,0,42,45,6,255,3,0,6,255,3,0,5,255,1,0,213,44,6,255,4,0,5,255,2,0,215,44,6,255,4,0,5,255,2,0,43,45,6,255,4,0,46,45,6,255,3,0,6,255,3,0,5,255,1,0,218,44,6,255,4,0,5,255,2,0,220,44,6,255,4,0,5,255,2,0,47,45,6,255,4,0,50,45,6,255,3,0,6,255,3,0,5,255,11,0,223,44,5,255,11,0,51,45,6,255,3,0,6,255,3,0,5,255,11,0,235,44,5,255,11,0,63,45,6,255,3,0,6,255,1,0,247,44,5,255,8,0,247,44,5,255,3,0,1,45,5,255,12,0,75,45,247,44,6,255,1,0,6,255,1,0,5,255,13,0,5,45,5,255,13,0,88,45,6,255,1,0,6,255,95,0,8,255,2,255,2,0,3,255,0,4,1,255,0,0,6,255,191,1,6,255,63,0,5,255,7,0,1,48,5,255,7,0,1,48,5,255,7,0,1,48,5,255,7,0,1,48,5,255,7,0,9,48,5,255,7,0,9,48,5,255,7,0,9,48,5,255,7,0,9,48,6,255,31,0,3,255,0,3,6,255,3,0,5,255,1,0,17,40,6,255,3,0,5,255,1,0,17,40,6,255,7,0,5,255,1,0,17,40,6,255,3,0,5,255,1,0,17,40,6,255,3,0,6,255,3,0,5,255,1,0,19,40,6,255,3,0,5,255,1,0,19,40,6,255,7,0,5,255,1,0,19,40,6,255,3,0,5,255,1,0,19,40,6,255,3,0,6,255,2,0,5,255,3,0,21,40,6,255,1,0,5,255,3,0,21,40,6,255,5,0,5,255,3,0,21,40,6,255,1,0,5,255,3,0,21,40,6,255,2,0,6,255,2,0,5,255,3,0,25,40,6,255,1,0,5,255,3,0,25,40,6,255,5,0,5,255,3,0,25,40,6,255,1,0,5,255,3,0,25,40,6,255,2,0,6,255,1,0,5,255,4,0,29,40,6,255,0,0,5,255,4,0,29,40,6,255,4,0,5,255,4,0,29,40,6,255,0,0,5,255,4,0,29,40,6,255,2,0,6,255,1,0,5,255,5,0,34,40,5,255,5,0,34,40,6,255,3,0,5,255,5,0,34,40,5,255,5,0,34,40,6,255,1,0,6,255,1,0,5,255,5,0,40,40,5,255,5,0,40,40,6,255,3,0,5,255,5,0,40,40,5,255,5,0,40,40,6,255,1,0,6,255,191,0,8,255,2,255,3,0,3,255,0,3,1,255,0,0,6,255,191,1,6,255,127,0,6,255,3,0,5,255,2,0,50,36,5,255,2,0,70,32,5,255,4,0,48,36,5,255,2,0,70,32,5,255,4,0,48,36,5,255,2,0,70,32,5,255,1,0,48,36,6,255,3,0,6,255,3,0,5,255,2,0,55,36,5,255,2,0,73,32,5,255,4,0,53,36,5,255,2,0,73,32,5,255,4,0,53,36,5,255,2,0,73,32,5,255,1,0,53,36,6,255,3,0,6,255,3,0,5,255,1,0,60,36,5,255,3,0,76,32,5,255,3,0,58,36,5,255,3,0,76,32,5,255,3,0,58,36,5,255,3,0,76,32,5,255,1,0,58,36,6,255,3,0,6,255,3,0,63,36,5,255,5,0,80,32,5,255,1,0,62,36,5,255,5,0,80,32,5,255,1,0,62,36,5,255,5,0,80,32,62,40,6,255,3,0,6,255,3,0,65,36,5,255,5,0,86,32,5,255,1,0,64,36,5,255,5,0,86,32,5,255,1,0,64,36,5,255,5,0,86,32,64,40,6,255,3,0,6,255,3,0,67,36,5,255,5,0,92,32,5,255,1,0,66,36,5,255,5,0,92,32,5,255,1,0,66,36,5,255,5,0,92,32,66,40,6,255,3,0,6,255,3,0,69,36,5,255,5,0,98,32,5,255,1,0,68,36,5,255,5,0,98,32,5,255,1,0,68,36,5,255,5,0,98,32,68,40,6,255,3,0,6,255,3,0,5,255,7,0,104,32,5,255,7,0,104,32,5,255,7,0,104,32,6,255,3,0,6,255,3,0,5,255,7,0,112,32,5,255,7,0,112,32,5,255,7,0,112,32,6,255,3,0,6,255,159,0,0,255,8,255,2,255,0,0,3,255,0,4,1,255,0,2,6,255,8,255,2,255,0,0,3,255,0,4,1,255,0,13,6,255,191,1,6,255,255,0,6,255,8,0,1,44,6,255,1,0,5,255,2,0,2,44,6,255,1,0,5,255,2,0,85,44,6,255,1,0,88,44,6,255,8,0,6,255,7,0,5,255,7,0,5,44,5,255,7,0,89,44,6,255,7,0,6,255,7,0,5,255,7,0,13,44,5,255,7,0,97,44,6,255,7,0,5,255,15,0,21,44,5,255,15,0,105,44,5,255,15,0,37,44,5,255,15,0,121,44,5,255,15,0,53,44,5,255,15,0,137,44,5,255,15,0,69,44,5,255,15,0,153,44,4,255,2,0,9,255,7,0,208,40,4,255,0,0,5,255,7,0,169,40,5,255,15,0,193,40,4,255,2,0,9,255,7,0,224,40,4,255,0,0,5,255,7,0,177,40,5,255,15,0,209,40,4,255,2,0,9,255,7,0,240,40,4,255,0,0,5,255,7,0,185,40,5,255,15,0,225,40,8,255,2,255,1,0,3,255,0,4,1,255,0,14,6,255,191,1,6,255,31,0,6,255,1,0,5,255,2,0,1,36,6,255,26,0,6,255,1,0,5,255,3,0,4,36,6,255,25,0,6,255,1,0,5,255,4,0,9,36,6,255,24,0,6,255,1,0,5,255,5,0,14,36,6,255,17,0,5,255,3,0,116,36,6,255,1,0,6,255,1,0,5,255,8,0,20,36,6,255,10,0,5,255,7,0,120,36,6,255,1,0,6,255,1,0,5,255,8,0,29,36,6,255,10,0,5,255,7,0,128,36,6,255,1,0,6,255,1,0,5,255,9,0,38,36,6,255,9,0,5,255,7,0,136,36,6,255,1,0,6,255,1,0,5,255,9,0,48,36,6,255,8,0,5,255,8,0,144,36,6,255,1,0,6,255,1,0,5,255,10,0,58,36,6,255,7,0,5,255,8,0,153,36,6,255,1,0,6,255,1,0,5,255,10,0,69,36,6,255,7,0,5,255,8,0,162,36,6,255,1,0,6,255,1,0,5,255,8,0,80,36,6,255,9,0,5,255,8,0,171,36,6,255,1,0,6,255,1,0,5,255,8,0,89,36,6,255,9,0,5,255,8,0,180,36,6,255,1,0,6,255,1,0,5,255,8,0,98,36,6,255,9,0,5,255,8,0,189,36,6,255,1,0,6,255,1,0,5,255,8,0,107,36,6,255,8,0,5,255,9,0,198,72,6,255,1,0,5,255,31,0,198,72,6,255,63,0,8,255,2,255,2,0,3,255,0,4,1,255,0,11,6,255,191,1,6,255,95,0,6,255,10,0,5,255,1,0,1,48,6,255,18,0,6,255,8,0,5,255,4,0,3,48,6,255,17,0,6,255,6,0,5,255,8,0,8,48,6,255,15,0,6,255,4,0,5,255,10,0,17,48,6,255,15,0,6,255,4,0,5,255,11,0,28,48,5,255,9,0,97,52,6,255,4,0,6,255,4,0,5,255,11,0,40,48,5,255,9,0,107,52,6,255,4,0,6,255,4,0,5,255,21,0,52,48,6,255,4,0,6,255,4,0,5,255,21,0,74,48,6,255,4,0,6,255,4,0,10,255,21,0,96,48,6,255,4,0,6,255,191,0,8,255,2,255,3,0,3,255,0,4,1,255,0,11,6,255,191,1,6,255,63,0,6,255,14,0,5,255,2,0,213,52,6,255,1,0,5,255,2,0,128,56,6,255,8,0,6,255,14,0,5,255,2,0,216,52,6,255,0,0,5,255,4,0,131,56,6,255,7,0,6,255,14,0,5,255,2,0,219,52,6,255,0,0,5,255,4,0,136,56,6,255,7,0,6,255,17,0,5,255,6,0,141,56,6,255,6,0,6,255,16,0,5,255,7,0,148,56,6,255,6,0,6,255,14,0,5,255,10,0,156,56,6,255,5,0,6,255,15,0,5,255,9,0,167,56,6,255,5,0,6,255,14,0,5,255,10,0,177,56,6,255,4,0,6,255,14,0,5,255,10,0,189,56,6,255,4,0,6,255,14,0,5,255,10,0,201,56,6,255,4,0,6,255,191,0,0,255,8,255,2,255,5,0,0,0,50,66,248,86,141,45,8,33,74,41,140,49,206,57,16,66,82,74,148,82,214,90,24,99,90,107,156,115,222,123,160,8,2,13,66,17,194,25,235,62,13,67,108,75,79,79,80,79,42,67,138,54,138,50,233,58,137,54,104,50,38,42,39,42,233,58,78,75,105,50,235,62,168,58,163,25,226,8,229,33,71,46,42,63,79,75,11,63,235,58,168,54,227,37,198,29,6,38,70,46,170,54,102,46,168,54,202,54,169,50,4,38,194,21,130,17,66,13,131,21,98,17,34,13,162,21,227,25,194,17,69,30,4,26,4,34,104,46,228,37,164,29,104,50,201,58,45,75,169,54,12,67,70,42,79,83,47,83,234,66,38,42,100,25,142,79,141,79,108,75,77,71,74,67,41,63,232,58,8,59,75,71,9,63,73,67,107,75,68,25,68,29,199,37,8,46,234,58,136,54,71,50,42,58,200,58,137,54,170,62,110,66,195,16,3,38,3,21,37,25,202,66,235,66,42,63,227,37,168,66,78,83,36,25,204,70,13,75,164,46,228,29,5,38,103,46,202,58,170,58,69,42,133,17,70,46,34,17,98,8,194,8,98,21,37,42,38,42,36,38,46,71,136,54,77,75,163,21,228,33,78,79,110,79,109,79,52,95,54,95,54,95,86,95,209,78,175,70,110,66,38,46,198,33,74,50,20,91,119,103,86,99,21,95,110,3,111,3,45,3,77,3,78,3,12,3,237,2,204,2,236,2,13,3,137,2,238,2,7,2,231,1,7,2,162,9,194,13,130,13,133,13,39,2,73,2,105,2,15,3,205,2,237,2,14,3,13,3,46,3,40,2,171,2,138,2,138,2,170,2,105,2,232,1,110,3,45,3,137,2,169,2,206,2,50,3,49,3,81,3,81,3,80,3,80,3,48,3,209,2,50,3,16,3,229,95,229,91,229,91,228,91,228,87,228,91,164,79,132,75,132,75,133,79,164,83,133,75,166,83,197,87,102,67,135,75,167,75,102,71,196,46,166,46,67,38,7,59,163,50,195,54,232,87,202,87,196,79,227,50,228,50,195,50,99,34,163,42,145,46,4,96,166,63,161,42,36,55,166,63,224,67,232,79,196,91,197,99,237,103,240,111,243,119,250,127,252,127,255,127,46,53,224,127,31,124,0,124,160,54,160,62,224,70,32,83,128,95,224,107,224,115,226,127,240,127,246,127,252,127,222,123,0,0,224,127,31,124,0,124,9,56,9,60,9,64,6,68,14,72,15,80,18,88,22,96,251,112,189,125,189,126,222,123,0,0,224,127,31,124,0,124,19,0,26,16,28,24,31,32,31,40,31,52,31,64,31,72,31,88,31,104,255,109,222,123,0,0,224,127,31,124,0,124,31,48,31,56,31,64,31,72,31,84,31,92,31,104,31,112,95,124,95,126,95,123,222,123,0,0,224,127,31,124,79,2,179,2,245,10,88,19,156,27,253,35,255,43,255,63,255,79,255,95,255,107,255,119,255,127,0,0,224,127,31,124,0,124,0,2,0,2,96,2,192,2,32,3,224,3,224,35,231,51,236,71,243,95,248,111,222,123,0,0,224,127,31,124,0,124,96,14,192,30,0,35,96,47,224,51,224,67,224,79,224,99,237,103,238,119,245,119,222,123,47,45,224,127,5,52,5,60,9,68,7,76,7,84,10,92,9,100,9,108,9,116,207,124,21,126,186,126,93,127,222,123,8,52,15,60,19,72,18,76,19,84,15,92,13,104,10,112,132,116,0,121,160,125,205,126,109,127,245,127,126,127,222,123,12,36,12,40,12,44,12,52,12,56,12,60,12,64,14,68,16,72,18,80,19,84,14,64,14,68,14,76,79,40,78,44,255,255,14,65,4,96,166,63,161,42,36,55,166,63,224,67,232,79,196,91,197,99,237,103,240,111,243,119,250,127,252,127,255,127,46,53,224,127,31,124,0,124,160,54,160,62,224,70,32,83,128,95,224,107,224,115,226,127,240,127,246,127,252,127,222,123,0,0,224,127,31,124,0,124,9,56,9,60,9,64,6,68,14,72,15,80,18,88,22,96,251,112,189,125,189,126,222,123,0,0,224,127,31,124,0,124,19,0,26,16,28,24,31,32,31,40,31,52,31,64,31,72,31,88,31,104,255,109,222,123,0,0,224,127,31,124,0,124,31,48,31,56,31,64,31,72,31,84,31,92,31,104,31,112,95,124,95,126,95,123,222,123,0,0,224,127,31,124,79,2,179,2,245,10,88,19,156,27,253,35,255,43,255,63,255,79,255,95,255,107,255,119,255,127,0,0,224,127,31,124,0,124,0,2,0,2,96,2,192,2,32,3,224,3,224,35,231,51,236,71,243,95,248,111,222,123,0,0,224,127,31,124,0,124,96,14,192,30,0,35,96,47,224,51,224,67,224,79,224,99,237,103,238,119,245,119,222,123,47,45,224,127,5,52,5,60,9,68,7,76,7,84,10,92,9,100,9,108,9,116,207,124,21,126,186,126,93,127,222,123,22,2,87,2,216,18,24,39,184,47,185,63,250,71,252,79,255,83,255,91,255,91,254,103,255,111,223,115,223,123,255,127,178,1,244,1,21,2,55,2,88,2,122,2,155,2,219,2,250,2,58,3,91,3,155,2,221,2,31,3,16,2,21,2,255,255,211,65,4,96,166,63,161,42,36,55,166,63,224,67,232,79,196,91,197,99,237,103,240,111,243,119,250,127,252,127,255,127,46,53,224,127,31,124,0,124,160,54,160,62,224,70,32,83,128,95,224,107,224,115,226,127,240,127,246,127,252,127,222,123,0,0,224,127,31,124,0,124,9,56,9,60,9,64,6,68,14,72,15,80,18,88,22,96,251,112,189,125,189,126,222,123,0,0,224,127,31,124,0,124,19,0,26,16,28,24,31,32,31,40,31,52,31,64,31,72,31,88,31,104,255,109,222,123,0,0,224,127,31,124,0,124,31,48,31,56,31,64,31,72,31,84,31,92,31,104,31,112,95,124,95,126,95,123,222,123,0,0,224,127,31,124,79,2,179,2,245,10,88,19,156,27,253,35,255,43,255,63,255,79,255,95,255,107,255,119,255,127,0,0,224,127,31,124,0,124,0,2,0,2,96,2,192,2,32,3,224,3,224,35,231,51,236,71,243,95,248,111,222,123,0,0,224,127,31,124,0,124,96,14,192,30,0,35,96,47,224,51,224,67,224,79,224,99,237,103,238,119,245,119,222,123,47,45,224,127,5,52,5,60,9,68,7,76,7,84,10,92,9,100,9,108,9,116,207,124,21,126,186,126,93,127,222,123,1,27,160,35,192,47,224,59,224,67,192,79,192,87,224,95,224,99,224,103,224,111,238,119,243,127,250,127,252,127,255,127,32,2,96,2,128,2,192,2,224,2,32,3,64,3,128,39,160,43,224,55,224,63,64,3,224,11,224,19,163,29,67,34,255,255,14,65,4,96,166,63,161,42,36,55,166,63,224,67,232,79,196,91,197,99,237,103,240,111,243,119,250,127,252,127,255,127,46,53,224,127,31,124,0,124,160,54,160,62,224,70,32,83,128,95,224,107,224,115,226,127,240,127,246,127,252,127,222,123,0,0,224,127,31,124,0,124,9,56,9,60,9,64,6,68,14,72,15,80,18,88,22,96,251,112,189,125,189,126,222,123,0,0,224,127,31,124,0,124,19,0,26,16,28,24,31,32,31,40,31,52,31,64,31,72,31,88,31,104,255,109,222,123,0,0,224,127,31,124,0,124,31,48,31,56,31,64,31,72,31,84,31,92,31,104,31,112,95,124,95,126,95,123,222,123,0,0,224,127,31,124,79,2,179,2,245,10,88,19,156,27,253,35,255,43,255,63,255,79,255,95,255,107,255,119,255,127,0,0,224,127,31,124,0,124,0,2,0,2,96,2,192,2,32,3,224,3,224,35,231,51,236,71,243,95,248,111,222,123,0,0,224,127,31,124,0,124,96,14,192,30,0,35,96,47,224,51,224,67,224,79,224,99,237,103,238,119,245,119,222,123,47,45,224,127,5,52,5,60,9,68,7,76,7,84,10,92,9,100,9,108,9,116,207,124,21,126,186,126,93,127,222,123,183,25,218,33,188,49,158,61,158,73,29,81,254,92,223,96,191,104,127,112,31,116,31,124,127,126,95,127,159,127,255,127,140,1,142,1,143,1,145,1,146,1,148,1,149,1,151,37,152,41,153,53,153,61,149,1,153,9,153,17,207,33,212,37,255,255,4,0,74,206,4,0,5,0,0,0,50,66,248,86,141,45,8,33,74,41,140,49,206,57,16,66,82,74,148,82,214,90,24,99,90,107,156,115,222,123,160,8,2,13,66,17,194,25,235,62,13,67,108,75,79,79,80,79,42,67,138,54,138,50,233,58,137,54,104,50,38,42,39,42,233,58,78,75,105,50,235,62,168,58,163,25,226,8,229,33,71,46,42,63,79,75,11,63,235,58,168,54,227,37,198,29,6,38,70,46,170,54,102,46,168,54,202,54,169,50,4,38,194,21,130,17,66,13,131,21,98,17,34,13,162,21,227,25,194,17,69,30,4,26,4,34,104,46,228,37,164,29,104,50,201,58,45,75,169,54,12,67,70,42,79,83,47,83,234,66,38,42,100,25,142,79,141,79,108,75,77,71,74,67,41,63,232,58,8,59,75,71,9,63,73,67,107,75,68,25,68,29,199,37,8,46,234,58,136,54,71,50,42,58,200,58,137,54,170,62,110,66,195,16,3,38,3,21,37,25,202,66,235,66,42,63,227,37,168,66,78,83,36,25,204,70,13,75,164,46,228,29,5,38,103,46,202,58,170,58,69,42,133,17,70,46,34,17,98,8,194,8,98,21,37,42,38,42,36,38,46,71,136,54,77,75,163,21,228,33,78,79,110,79,109,79,52,95,54,95,54,95,86,95,209,78,175,70,110,66,38,46,198,33,74,50,20,91,119,103,86,99,21,95,128,19,128,19,96,15,128,15,128,15,32,15,0,19,224,14,0,15,32,19,130,14,0,19,2,10,226,13,2,14,162,9,194,13,130,13,133,13,34,14,66,14,98,18,32,23,224,14,0,15,32,19,32,15,96,15,35,22,164,26,131,22,131,18,163,18,98,14,227,21,160,19,96,11,130,18,162,18,224,22,96,23,96,23,128,27,128,23,128,31,128,27,96,27,224,26,96,27,32,23,229,95,229,91,229,91,228,91,228,87,228,91,164,79,132,75,132,75,133,79,164,83,133,75,166,83,197,87,102,67,135,75,167,75,102,71,196,46,166,46,67,38,7,59,163,50,195,54,232,87,202,87,196,79,227,50,228,50,195,50,99,34,163,42,145,46,4,96,166,63,161,42,36,55,166,63,224,67,232,79,196,91,197,99,237,103,240,111,243,119,250,127,252,127,255,127,46,53,224,127,31,124,0,124,160,54,160,62,224,70,32,83,128,95,224,107,224,115,226,127,240,127,246,127,252,127,222,123,0,0,224,127,31,124,0,124,9,56,9,60,9,64,6,68,14,72,15,80,18,88,22,96,251,112,189,125,189,126,222,123,0,0,224,127,31,124,0,124,19,0,26,16,28,24,31,32,31,40,31,52,31,64,31,72,31,88,31,104,255,109,222,123,0,0,224,127,31,124,0,124,31,48,31,56,31,64,31,72,31,84,31,92,31,104,31,112,95,124,95,126,95,123,222,123,0,0,224,127,31,124,79,2,179,2,245,10,88,19,156,27,253,35,255,43,255,63,255,79,255,95,255,107,255,119,255,127,0,0,224,127,31,124,0,124,0,2,0,2,96,2,192,2,32,3,224,3,224,35,231,51,236,71,243,95,248,111,222,123,0,0,224,127,31,124,0,124,96,14,192,30,0,35,96,47,224,51,224,67,224,79,224,99,237,103,238,119,245,119,222,123,47,45,224,127,5,52,5,60,9,68,7,76,7,84,10,92,9,100,9,108,9,116,207,124,21,126,186,126,93,127,222,123,8,52,15,60,19,72,18,76,19,84,15,92,13,104,10,112,132,116,0,121,160,125,205,126,109,127,245,127,126,127,222,123,12,36,12,40,12,44,12,52,12,56,12,60,12,64,14,68,16,72,18,80,19,84,14,64,14,68,14,76,79,40,78,44,255,255,14,65,4,96,166,63,161,42,36,55,166,63,224,67,232,79,196,91,197,99,237,103,240,111,243,119,250,127,252,127,255,127,46,53,224,127,31,124,0,124,160,54,160,62,224,70,32,83,128,95,224,107,224,115,226,127,240,127,246,127,252,127,222,123,0,0,224,127,31,124,0,124,9,56,9,60,9,64,6,68,14,72,15,80,18,88,22,96,251,112,189,125,189,126,222,123,0,0,224,127,31,124,0,124,19,0,26,16,28,24,31,32,31,40,31,52,31,64,31,72,31,88,31,104,255,109,222,123,0,0,224,127,31,124,0,124,31,48,31,56,31,64,31,72,31,84,31,92,31,104,31,112,95,124,95,126,95,123,222,123,0,0,224,127,31,124,79,2,179,2,245,10,88,19,156,27,253,35,255,43,255,63,255,79,255,95,255,107,255,119,255,127,0,0,224,127,31,124,0,124,0,2,0,2,96,2,192,2,32,3,224,3,224,35,231,51,236,71,243,95,248,111,222,123,0,0,224,127,31,124,0,124,96,14,192,30,0,35,96,47,224,51,224,67,224,79,224,99,237,103,238,119,245,119,222,123,47,45,224,127,5,52,5,60,9,68,7,76,7,84,10,92,9,100,9,108,9,116,207,124,21,126,186,126,93,127,222,123,22,2,87,2,216,18,24,39,184,47,185,63,250,71,252,79,255,83,255,91,255,91,254,103,255,111,223,115,223,123,255,127,178,1,244,1,21,2,55,2,88,2,122,2,155,2,219,2,250,2,58,3,91,3,155,2,221,2,31,3,16,2,21,2,255,255,211,65,4,96,166,63,161,42,36,55,166,63,224,67,232,79,196,91,197,99,237,103,240,111,243,119,250,127,252,127,255,127,46,53,224,127,31,124,0,124,160,54,160,62,224,70,32,83,128,95,224,107,224,115,226,127,240,127,246,127,252,127,222,123,0,0,224,127,31,124,0,124,9,56,9,60,9,64,6,68,14,72,15,80,18,88,22,96,251,112,189,125,189,126,222,123,0,0,224,127,31,124,0,124,19,0,26,16,28,24,31,32,31,40,31,52,31,64,31,72,31,88,31,104,255,109,222,123,0,0,224,127,31,124,0,124,31,48,31,56,31,64,31,72,31,84,31,92,31,104,31,112,95,124,95,126,95,123,222,123,0,0,224,127,31,124,79,2,179,2,245,10,88,19,156,27,253,35,255,43,255,63,255,79,255,95,255,107,255,119,255,127,0,0,224,127,31,124,0,124,0,2,0,2,96,2,192,2,32,3,224,3,224,35,231,51,236,71,243,95,248,111,222,123,0,0,224,127,31,124,0,124,96,14,192,30,0,35,96,47,224,51,224,67,224,79,224,99,237,103,238,119,245,119,222,123,47,45,224,127,5,52,5,60,9,68,7,76,7,84,10,92,9,100,9,108,9,116,207,124,21,126,186,126,93,127,222,123,1,27,160,35,192,47,224,59,224,67,192,79,192,87,224,95,224,99,224,103,224,111,238,119,243,127,250,127,252,127,255,127,32,2,96,2,128,2,192,2,224,2,32,3,64,3,128,39,160,43,224,55,224,63,64,3,224,11,224,19,163,29,67,34,255,255,14,65,4,96,166,63,161,42,36,55,166,63,224,67,232,79,196,91,197,99,237,103,240,111,243,119,250,127,252,127,255,127,46,53,224,127,31,124,0,124,160,54,160,62,224,70,32,83,128,95,224,107,224,115,226,127,240,127,246,127,252,127,222,123,0,0,224,127,31,124,0,124,9,56,9,60,9,64,6,68,14,72,15,80,18,88,22,96,251,112,189,125,189,126,222,123,0,0,224,127,31,124,0,124,19,0,26,16,28,24,31,32,31,40,31,52,31,64,31,72,31,88,31,104,255,109,222,123,0,0,224,127,31,124,0,124,31,48,31,56,31,64,31,72,31,84,31,92,31,104,31,112,95,124,95,126,95,123,222,123,0,0,224,127,31,124,79,2,179,2,245,10,88,19,156,27,253,35,255,43,255,63,255,79,255,95,255,107,255,119,255,127,0,0,224,127,31,124,0,124,0,2,0,2,96,2,192,2,32,3,224,3,224,35,231,51,236,71,243,95,248,111,222,123,0,0,224,127,31,124,0,124,96,14,192,30,0,35,96,47,224,51,224,67,224,79,224,99,237,103,238,119,245,119,222,123,47,45,224,127,5,52,5,60,9,68,7,76,7,84,10,92,9,100,9,108,9,116,207,124,21,126,186,126,93,127,222,123,183,25,218,33,188,49,158,61,158,73,29,81,254,92,223,96,191,104,127,112,31,116,31,124,127,126,95,127,159,127,255,127,140,1,142,1,143,1,145,1,146,1,148,1,149,1,151,37,152,41,153,53,153,61,149,1,153,9,153,17,207,33,212,37,255,255,5,0,0,0,50,66,3,0,0,0,50,66,248,86,141,45,8,33,74,41,140,49,206,57,16,66,82,74,148,82,214,90,24,99,90,107,156,115,222,123,36,21,194,12,226,12,227,12,227,16,3,17,227,20,68,21,70,25,102,25,102,33,103,33,135,33,103,37,167,37,232,41,5,42,5,46,69,46,102,50,133,50,133,50,132,50,165,50,197,54,225,58,193,62,226,62,4,71,36,71,69,71,100,71,101,71,134,71,101,75,102,79,134,79,135,79,103,83,134,83,168,87,169,87,200,87,200,91,233,91,201,95,202,95,233,95,236,99,236,99,235,99,235,103,235,107,238,107,237,107,239,111,238,115,238,115,239,115,238,115,239,119,243,123,245,127,246,127,64,4,128,0,64,9,128,13,192,17,0,18,64,18,128,18,224,18,0,19,1,19,97,23,129,27,194,27,225,27,1,30,128,30,160,30,192,34,225,34,97,35,129,35,130,35,130,39,194,39,228,39,195,43,196,47,229,47,229,51,230,51,232,55,32,21,0,21,64,25,96,25,128,29,225,37,227,45,66,50,98,50,131,54,195,62,196,62,35,63,165,66,199,66,101,71,8,75,70,75,102,75,199,83,105,87,199,87,200,91,202,91,201,95,232,95,233,95,235,111,237,115,239,119,244,127,248,127,97,42,129,46,163,50,194,54,194,58,227,62,227,66,3,67,36,67,69,75,103,79,136,79,169,87,205,91,237,99,238,99,238,107,240,107,239,107,240,107,242,111,240,111,241,111,241,115,242,115,242,123,243,123,244,123,247,123,252,127,252,127,252,127,4,21,228,16,36,21,69,25,101,25,103,29,135,29,135,37,168,37,232,41,7,42,8,46,74,50,104,50,105,50,104,58,192,50,224,54,0,59,32,63,67,67,99,75,135,79,166,83,199,87,233,91,231,95,232,99,233,99,236,99,236,103,237,107,97,4,65,4,98,8,130,8,194,12,195,12,226,12,227,12,195,16,227,16,228,16,3,17,4,17,35,17,228,20,36,21,255,255,15,57,224,127,31,124,0,124,19,0,26,16,28,24,31,28,31,36,224,11,224,59,224,83,31,56,31,76,255,101,222,123,255,255,211,65,19,0,31,40,31,88,255,109,67,34,0,0,64,3,16,66,82,74,148,82,214,90,24,99,9,68,192,123,255,127,46,53,224,127,31,124,0,124,160,54,160,62,224,70,32,83,128,95,224,107,224,115,226,127,240,127,246,127,252,127,255,127,0,0,224,127,31,124,0,124,9,56,9,60,9,64,6,68,14,72,15,80,18,88,22,96,251,112,189,125,189,126,255,127,0,0,224,127,31,124,0,124,19,0,26,16,28,24,31,32,31,40,31,52,31,64,31,72,31,88,31,104,255,109,255,127,0,0,224,127,31,124,0,124,31,48,31,56,31,64,31,72,31,84,31,92,31,104,31,112,95,124,95,126,95,123,255,127,0,0,224,127,31,124,88,11,187,19,255,31,255,51,255,67,255,71,255,79,255,87,255,95,255,103,255,111,255,119,255,127,0,0,224,127,31,124,0,124,0,2,0,2,96,2,192,2,32,3,224,3,224,35,231,51,236,71,243,95,248,111,255,127,0,0,224,127,31,124,0,124,96,14,192,30,0,35,96,47,224,51,224,67,224,79,224,99,237,103,238,119,245,119,255,127,47,45,224,127,5,52,5,60,9,68,7,76,7,84,10,92,9,100,9,108,9,116,207,124,21,126,186,126,93,127,255,127,161,42,36,55,166,63,224,67,232,79,196,91,197,99,235,103,235,103,237,103,240,111,243,119,247,127,250,127,252,127,255,127,32,2,96,2,128,2,192,2,224,2,32,3,64,3,128,39,160,43,224,55,224,63,64,3,224,11,224,19,163,29,67,34,211,65,66,8,132,16,198,24,8,33,74,41,140,49,206,57,160,3,224,35,224,55,224,63,224,79,237,103,238,119,255,127,255,255,5,0,0,0,50,66,248,86,3,0,0,0,50,66,248,86,141,45,8,33,74,41,140,49,206,57,16,66,82,74,148,82,214,90,24,99,90,107,156,115,222,123,36,21,194,12,226,12,227,12,227,16,3,17,227,20,68,21,70,25,102,25,102,33,103,33,135,33,103,37,167,37,232,41,234,49,10,50,75,58,77,58,107,58,77,62,107,62,109,62,110,62,141,62,110,66,142,66,143,70,174,70,207,70,238,70,239,70,16,71,239,74,240,78,16,79,17,79,241,82,16,83,18,83,19,83,50,83,50,87,83,87,51,91,52,91,83,91,149,95,181,95,212,95,180,99,181,99,182,99,213,99,247,103,215,111,247,111,248,111,247,111,248,111,250,115,252,123,252,127,64,4,128,0,64,9,128,13,192,17,0,18,64,18,128,18,224,18,0,19,1,19,97,23,129,27,194,27,225,27,1,30,128,30,160,30,192,34,225,34,97,35,129,35,130,35,130,39,194,39,228,39,195,43,196,47,229,47,229,51,230,51,232,55,32,21,0,21,64,25,96,25,128,29,225,37,227,45,66,50,98,50,131,54,195,62,196,62,35,63,165,66,199,66,101,71,8,75,70,75,102,75,199,83,105,87,199,87,200,91,202,91,201,95,232,95,233,95,235,111,237,115,239,119,244,127,248,127,10,46,10,50,78,58,109,58,77,62,109,62,110,62,110,66,207,70,16,83,18,83,50,83,148,91,182,95,151,103,214,103,216,107,218,107,249,107,250,107,220,111,250,111,251,111,251,115,252,115,251,123,252,123,253,123,254,123,253,127,254,127,255,127,4,21,228,16,36,21,69,25,101,25,103,29,135,29,135,37,168,37,232,41,7,42,8,46,74,50,104,50,105,50,104,58,139,58,171,62,203,66,46,79,48,83,79,83,82,83,177,87,179,95,180,95,243,103,244,107,245,107,248,107,247,111,249,115,97,4,65,4,98,8,130,8,194,12,195,12,226,12,227,12,195,16,227,16,228,16,3,17,4,17,35,17,228,20,36,21,255,255,15,57,224,127,31,124,0,124,19,0,26,16,28,24,31,28,31,36,224,11,224,59,224,83,31,56,31,76,255,101,222,123,255,255,211,65,19,0,31,40,31,88,255,109,67,34,0,0,64,3,16,66,82,74,148,82,214,90,24,99,9,68,192,123,255,127,46,53,224,127,31,124,0,124,160,54,160,62,224,70,32,83,128,95,224,107,224,115,226,127,240,127,246,127,252,127,255,127,0,0,224,127,31,124,0,124,9,56,9,60,9,64,6,68,14,72,15,80,18,88,22,96,251,112,189,125,189,126,255,127,0,0,224,127,31,124,0,124,19,0,26,16,28,24,31,32,31,40,31,52,31,64,31,72,31,88,31,104,255,109,255,127,0,0,224,127,31,124,0,124,31,48,31,56,31,64,31,72,31,84,31,92,31,104,31,112,95,124,95,126,95,123,255,127,0,0,224,127,31,124,88,11,187,19,255,31,255,51,255,67,255,71,255,79,255,87,255,95,255,103,255,111,255,119,255,127,0,0,224,127,31,124,0,124,0,2,0,2,96,2,192,2,32,3,224,3,224,35,231,51,236,71,243,95,248,111,255,127,0,0,224,127,31,124,0,124,96,14,192,30,0,35,96,47,224,51,224,67,224,79,224,99,237,103])
.concat([238,119,245,119,255,127,47,45,224,127,5,52,5,60,9,68,7,76,7,84,10,92,9,100,9,108,9,116,207,124,21,126,186,126,93,127,255,127,161,42,36,55,166,63,224,67,232,79,196,91,197,99,235,103,235,103,237,103,240,111,243,119,247,127,250,127,252,127,255,127,32,2,96,2,128,2,192,2,224,2,32,3,64,3,128,39,160,43,224,55,224,63,64,3,224,11,224,19,163,29,67,34,211,65,66,8,132,16,198,24,8,33,74,41,140,49,206,57,160,3,224,35,224,55,224,63,224,79,237,103,238,119,255,127,255,255,3,0,0,0,50,66,248,86,2,0,0,0,50,66,248,86,141,45,8,33,74,41,140,49,206,57,16,66,82,74,148,82,214,90,24,99,90,107,156,115,222,123,106,41,139,45,172,49,205,53,239,53,240,57,16,58,209,61,17,62,18,62,48,66,49,66,48,70,49,70,113,70,115,70,116,70,115,74,147,74,179,74,180,74,116,78,117,78,179,82,180,82,211,82,244,86,245,86,22,91,23,91,54,91,55,91,57,99,120,103,121,103,122,103,120,103,121,103,121,107,122,107,124,107,120,107,121,107,122,107,121,107,121,111,122,111,124,111,122,115,123,115,125,115,123,123,156,123,157,123,158,123,159,123,158,127,158,127,159,127,191,127,158,127,191,127,191,127,191,127,233,24,8,25,42,33,72,33,74,37,106,41,139,41,173,53,206,53,47,58,16,66,47,66,146,70,114,74,211,82,245,82,245,86,246,86,21,87,246,90,22,91,54,95,23,99,86,99,87,99,119,99,87,103,119,103,121,103,153,111,154,111,154,115,37,8,70,12,134,16,135,16,166,16,167,16,199,20,232,24,8,25,8,29,40,25,41,25,73,33,74,33,105,33,73,37,140,41,172,45,203,45,204,45,238,53,240,57,47,62,111,66,178,74,149,78,118,91,154,103,152,107,155,115,158,119,159,127,130,25,164,29,197,33,230,37,7,42,39,46,71,46,103,50,168,54,201,58,234,62,10,63,43,63,76,67,108,71,140,71,142,79,173,79,206,79,239,83,240,83,240,87,240,91,241,91,243,95,244,95,242,95,242,99,244,99,245,103,246,107,155,115,16,40,49,44,115,52,148,56,181,60,214,64,247,68,24,73,57,77,90,81,123,85,156,89,189,93,254,101,31,106,127,118,9,12,10,16,12,24,13,28,14,32,15,36,16,40,82,48,115,52,181,60,247,68,57,77,123,85,189,93,254,101,190,123,195,16,5,25,70,33,70,37,136,41,200,49,201,53,235,57,12,62,44,66,78,70,242,86,51,87,83,87,51,91,82,91,227,16,163,12,228,16,3,17,4,17,36,21,70,25,165,33,8,42,42,50,106,54,238,66,15,79,178,95,179,95,211,99,113,61,224,127,31,124,0,124,96,14,192,30,0,35,96,47,224,51,224,67,224,79,224,99,237,103,238,119,245,119,222,123,255,255,3,0,0,0,50,66,248,86,141,45,8,33,2,0,0,0,50,66,248,86,141,45,8,33,74,41,140,49,206,57,16,66,82,74,148,82,214,90,24,99,90,107,156,115,222,123,169,41,202,45,235,49,12,54,13,58,45,58,77,58,78,62,110,62,111,62,110,66,142,66,142,70,143,70,175,74,176,74,208,70,208,74,240,74,241,74,241,78,17,79,18,79,17,83,18,83,48,83,81,87,82,87,115,91,116,91,147,91,148,91,150,99,213,103,214,103,215,103,213,103,214,103,214,107,215,107,217,107,213,107,214,107,215,107,214,107,214,111,215,111,217,111,215,115,216,115,218,115,216,123,249,123,250,123,251,123,252,123,251,127,251,127,252,127,253,127,251,127,253,127,253,127,254,127,70,25,101,25,135,33,165,33,167,37,199,41,232,41,10,54,43,54,140,58,109,66,140,66,239,70,207,74,80,83,82,83,82,87,83,87,145,87,83,91,115,91,179,95,116,99,179,99,180,99,212,99,180,103,212,103,214,103,246,111,247,111,247,115,130,8,163,12,227,16,228,16,3,17,4,17,36,21,69,25,101,25,101,29,133,25,134,25,166,33,167,33,198,33,166,37,233,41,9,46,40,46,41,46,75,54,77,58,140,62,204,66,15,75,242,78,211,91,247,103,245,107,248,115,251,119,252,127,130,25,164,29,197,33,230,37,7,42,39,46,71,46,103,50,168,54,201,58,234,62,10,63,43,63,76,67,108,71,140,71,142,79,173,79,206,79,239,83,240,83,240,87,240,91,241,91,243,95,244,95,242,95,242,99,244,99,245,103,246,107,248,115,36,30,68,30,101,34,135,34,167,34,200,38,232,38,9,43,42,47,73,51,108,63,141,67,174,71,210,83,242,87,243,95,9,12,10,16,12,24,13,28,14,32,15,36,16,40,82,48,115,52,181,60,247,68,57,77,123,85,189,93,254,101,190,123,195,16,5,25,70,33,70,37,136,41,200,49,201,53,235,57,12,62,44,66,78,70,242,86,51,87,83,87,51,91,82,91,227,16,163,12,228,16,3,17,4,17,36,21,70,25,165,33,8,42,42,50,106,54,238,66,15,79,178,95,179,95,211,99,113,61,224,127,31,124,0,124,96,14,192,30,0,35,96,47,224,51,224,67,224,79,224,99,237,103,238,119,245,119,222,123,255,255,2,0,0,0,50,66,248,86,141,45,8,33,6,0,177,60,50,66,248,86,141,45,8,33,74,41,140,49,206,57,16,66,82,74,148,82,214,90,24,99,90,107,156,115,222,123,203,28,73,16,74,24,233,24,170,28,76,28,174,32,13,33,76,33,235,32,13,33,203,32,45,41,45,37,46,41,45,37,76,37,46,41,76,37,44,37,77,41,12,41,45,45,76,41,77,45,79,49,111,41,142,49,112,53,113,53,81,53,49,53,208,53,241,57,144,49,209,61,209,65,18,62,211,65,179,61,178,57,242,61,83,66,243,69,242,73,210,61,50,62,179,65,85,74,84,70,243,65,19,70,211,69,86,74,117,74,212,69,244,69,53,78,242,69,18,70,116,70,244,69,53,74,53,74,53,78,85,74,51,70,20,74,118,78,150,86,117,78,87,82,120,90,150,82,118,78,53,74,120,82,215,86,25,91,151,78,60,103,27,99,218,90,28,107,60,103,254,102,251,102,250,94,218,90,217,94,252,98,26,103,27,107,60,103,125,103,250,102,127,119,127,119,95,115,126,107,127,119,159,123,95,111,158,107,61,115,30,107,127,115,94,111,94,111,61,107,127,115,62,111,255,127,255,127,223,127,191,123,223,127,159,123,127,119,159,123,159,119,191,123,255,127,255,127,191,123,223,127,159,119,223,127,231,63,64,9,96,9,96,9,128,9,160,9,192,9,0,18,32,18,64,18,160,22,192,26,224,26,96,39,64,31,96,31,224,38,0,39,32,39,64,39,128,39,129,39,160,39,161,39,193,39,225,39,192,34,224,34,225,34,0,35,0,35,64,35,98,55,130,55,162,55,193,55,194,55,195,55,226,55,226,55,227,55,229,55,227,59,228,59,229,59,229,59,228,63,228,63,229,75,230,75,231,75,229,75,230,79,231,79,230,79,231,79,230,79,230,79,232,79,232,83,232,91,235,95,235,95,237,103,245,111,69,34,3,30,229,33,70,42,136,54,8,63,7,55,72,63,171,71,171,79,173,83,239,95,237,87,236,87,238,87,205,79,240,87,209,91,239,91,240,95,241,95,242,95,240,99,241,99,242,99,243,99,244,111,244,107,245,107,246,115,246,119,211,65,0,0,0,0,26,19,191,43,191,79,224,35,224,67,237,103,7,76,9,100,207,124,31,60,31,84,31,108,255,127,0,124,134,55,166,55,134,59,198,59,71,63,134,63,198,63,230,63,231,63,167,71,198,71,199,71,230,71,231,71,167,75,168,75,199,75,200,75,231,75,232,75,168,79,200,79,232,79,200,83,202,83,203,83,234,83,235,83,236,83,204,91,205,91,208,91,235,91,236,91,237,91,238,91,208,95,237,95,239,95,240,95,242,95,239,99,241,99,242,99,243,99,245,99,246,99,243,107,245,107,246,107,247,107,248,107,246,111,247,111,248,111,250,111,251,111,252,111,251,115,252,115,253,115,255,115,255,127,231,83,232,95,231,79,231,75,230,63,198,55,166,51,166,43,102,35,37,35,70,35,4,35,134,39,6,35,70,39,36,31,4,31,69,35,6,31,198,51,230,51,166,39,133,39,134,43,196,30,230,55,166,55,230,59,69,39,230,71,230,75,230,79,231,71,232,91,234,91,134,59,102,55,232,75,232,83,234,95,235,99,239,111,240,115,241,115,240,111,237,111,236,107,234,99,233,95,233,99,228,26,101,35,165,43,165,39,164,26,198,34,133,43,36,26,134,51,198,63,231,63,38,39,70,43,102,51,196,21,229,21,68,22,5,22,4,22,132,30,198,30,6,35,228,21,37,22,198,34,100,22,36,22,166,30,134,30,69,22,187,106,155,106,91,106,58,102,26,102,217,93,153,93,25,85,183,72,150,72,12,20,13,20,11,20,11,16,10,16,9,16,8,12,9,12,15,32,13,32,13,28,10,28,12,32,10,32,9,32,42,32,74,32,139,32,201,36,199,36,109,53,12,28,16,20,18,20,19,28,21,32,23,36,23,44,25,52,25,56,25,68,119,72,57,76,89,76,121,76,58,84,121,84,214,85,89,88,121,88,185,92,186,92,218,92,57,93,89,93,155,93,249,96,27,101,91,101,27,106,59,106,187,106,219,106,27,111,255,255,108,57,224,127,31,124,0,124,31,0,255,3,31,48,31,64,31,80,31,92,31,104,31,112,95,124,255,125,159,126,222,123,159,127,107,24,171,28,108,28,142,32,79,32,178,40,178,40,178,40,178,40,178,40,115,40,147,40,146,44,178,44,116,48,148,48,212,48,244,48,118,48,212,52,244,52,118,52,183,52,247,52,23,53,120,52,184,52,121,52,214,60,183,60,184,60,88,61,217,60,57,61,123,60,187,60,219,60,251,60,252,60,127,64,248,68,120,69,217,68,249,68,57,69,187,68,219,68,92,69,189,68,221,68,29,69,190,68,127,68,154,77,218,76,60,77,221,76,62,77,191,76,223,76,31,77,63,77,222,84,62,85,223,84,31,85,63,85,127,85,223,92,31,93,63,93,95,93,127,93,159,93,31,101,95,101,191,101,223,101,31,102,31,105,95,105,190,105,223,105,31,106,95,113,127,113,191,113,223,113,31,114,63,114,95,114,127,114,191,117,255,117,31,118,63,114,95,114,159,118,63,119,127,123,191,117,255,117,63,122,255,122,127,127,95,117,255,117,63,118,159,122,223,122,95,127,191,127,223,127,255,117,31,118,63,118,95,118,127,122,159,122,191,122,223,126,255,126,63,127,127,127,191,127,255,127,0,0,255,255,236,49,224,127,31,124,0,124,31,0,255,3,31,48,31,64,31,80,31,92,31,104,31,112,95,124,255,125,159,126,222,123,252,127,64,28,129,28,96,32,128,40,128,44,193,56,193,56,193,56,193,56,193,56,192,60,192,60,224,56,225,56,0,65,0,69,3,69,3,69,0,77,34,69,34,69,32,77,33,81,35,81,36,81,32,85,33,85,32,89,98,77,97,81,97,85,101,85,97,89,100,89,96,97,96,97,97,97,98,97,98,101,130,105,162,85,166,89,161,89,162,89,164,89,160,97,161,97,164,101,160,105,160,105,162,105,160,109,160,113,230,93,224,93,227,101,224,105,227,109,224,113,225,113,227,113,195,113,32,110,36,110,33,114,35,114,36,114,38,114,97,114,99,114,100,114,101,114,102,114,103,114,163,114,165,114,168,114,169,114,171,114,195,114,197,114,199,114,201,114,193,114,6,115,6,115,8,115,9,115,11,115,12,115,13,115,14,115,40,115,42,115,43,115,8,115,76,119,144,123,180,123,217,127,40,119,75,119,140,123,181,127,217,127,37,119,42,119,77,123,112,123,180,127,249,127,252,127,253,127,74,123,75,123,76,123,45,123,110,123,111,123,144,123,178,123,179,123,214,127,216,127,218,123,254,127,0,0,255,255,108,57,224,127,31,124,0,124,31,0,255,3,31,48,31,64,31,80,31,92,31,104,31,112,95,124,255,125,159,126,222,123,159,127,208,29,240,37,241,29,19,34,20,26,23,30,55,34,55,38,87,38,87,38,88,30,120,34,120,34,120,38,153,30,185,34,185,42,185,46,187,30,217,42,217,46,219,30,220,46,220,54,220,50,221,30,222,38,222,30,27,43,28,39,29,39,60,59,61,43,28,51,30,27,254,38,30,43,31,47,31,47,63,31,91,51,59,55,60,47,60,51,60,51,62,43,62,47,94,55,95,35,31,47,95,47,95,35,95,27,122,43,154,47,156,51,157,43,158,51,159,55,159,55,159,63,159,63,222,59,158,59,159,47,159,55,159,59,159,67,159,43,159,55,159,59,159,63,159,67,159,71,191,55,223,63,223,75,223,79,223,87,191,55,223,63,158,71,159,75,159,83,223,71,223,75,223,79,223,83,223,87,223,91,223,95,255,99,255,87,255,91,255,95,223,91,223,99,255,107,255,115,255,123,255,95,255,99,255,103,255,115,255,123,255,95,255,99,255,103,255,111,255,115,255,119,191,127,223,127,255,87,255,91,255,95,255,99,255,103,255,107,255,111,255,115,255,119,255,123,255,123,255,127,255,127,0,0,255,255,237,40,224,127,31,124,0,124,31,0,255,3,31,48,31,64,31,80,31,92,31,104,31,112,95,124,255,125,159,126,222,123,250,127,128,17,128,21,192,21,192,25,0,22,0,26,64,26,64,30,128,30,128,34,160,30,160,34,192,30,192,34,192,38,0,35,2,35,3,35,0,35,2,39,3,43,32,39,35,39,67,39,68,39,96,39,97,39,98,39,96,43,98,43,97,47,102,51,128,51,131,51,166,51,161,51,162,51,195,51,195,55,192,55,98,55,102,55,129,55,130,55,132,55,160,55,161,55,166,59,193,59,194,59,196,59,224,59,227,59,135,63,161,63,164,63,193,63,228,63,224,63,225,63,227,63,228,63,224,67,226,75,228,75,230,75,232,75,234,75,226,83,228,83,230,83,232,83,234,83,236,83,228,91,230,91,232,91,234,91,236,91,228,95,230,95,232,95,234,95,236,95,226,103,228,103,230,103,232,103,234,103,236,103,232,111,234,111,236,111,238,111,240,111,224,115,232,115,240,115,244,115,249,115,224,119,232,119,240,119,244,119,249,119,226,123,230,123,236,123,242,123,245,123,249,123,251,127,252,123,224,119,226,119,228,119,230,119,232,119,234,123,237,123,240,123,243,123,246,123,249,123,251,123,255,127,0,0,255,255,2,0,0,0,6,0,0,0,50,66,248,86,141,45,8,33,74,41,140,49,206,57,16,66,82,74,148,82,214,90,24,99,90,107,156,115,222,123,0,13,0,13,64,13,64,13,96,13,128,13,64,17,97,21,129,21,161,21,225,21,1,22,161,25,193,25,194,25,225,25,35,30,66,30,67,30,130,30,4,34,35,34,66,34,67,34,68,34,98,34,99,34,162,34,163,34,100,38,131,38,132,38,163,42,164,42,195,46,196,46,164,50,195,50,196,50,4,51,5,51,37,51,68,51,197,54,4,55,5,55,6,55,7,55,69,59,70,59,101,59,132,59,133,59,5,63,39,63,40,63,68,63,70,63,71,63,101,63,102,63,103,63,133,63,165,63,40,67,71,67,166,67,167,71,168,71,198,71,199,71,229,71,230,71,105,75,167,75,168,75,198,75,199,75,200,75,231,75,233,87,232,87,231,87,202,91,233,91,234,91,236,91,232,91,233,91,232,91,235,91,110,95,205,95,235,95,233,95,236,91,233,103,234,103,236,103,237,103,237,111,237,111,238,111,239,111,236,111,236,111,237,111,235,111,237,111,236,111,238,115,236,115,241,119,240,119,241,119,241,123,242,123,243,123,241,123,242,123,242,127,244,127,242,127,244,127,242,127,244,127,244,127,245,127,233,51,130,13,193,13,194,13,225,13,226,13,2,14,35,18,67,18,99,18,163,18,195,18,227,18,3,19,35,19,67,19,227,22,3,23,35,23,67,23,131,23,132,23,163,23,164,23,196,23,228,23,195,26,227,26,228,26,3,27,4,27,67,27,69,31,101,31,133,31,164,31,165,31,166,31,197,31,229,31,230,31,232,31,230,35,231,35,232,35,232,35,231,39,231,39,232,43,233,43,234,43,232,43,233,47,234,47,233,47,234,47,233,47,233,47,235,47,235,51,235,59,238,63,238,63,240,71,248,127,230,37,166,41,167,41,231,45,10,58,172,70,204,74,239,78,47,79,47,83,78,87,241,103,210,99,239,99,241,99,245,107,246,107,183,111,245,111,246,111,247,111,246,111,246,119,247,119,248,119,249,119,248,123,250,127,251,127,220,123,250,127,211,65,0,0,0,0,26,19,191,43,191,79,224,35,224,67,237,103,7,76,9,100,207,124,31,60,31,84,31,108,255,127,0,124,134,55,166,55,134,59,198,59,71,63,134,63,198,63,230,63,231,63,167,71,198,71,199,71,230,71,231,71,167,75,168,75,199,75,200,75,231,75,232,75,168,79,200,79,232,79,200,83,202,83,203,83,234,83,235,83,236,83,204,91,205,91,208,91,235,91,236,91,237,91,238,91,208,95,237,95,239,95,240,95,242,95,239,99,241,99,242,99,243,99,245,99,246,99,243,107,245,107,246,107,247,107,248,107,246,111,247,111,248,111,250,111,251,111,252,111,251,115,252,115,253,115,255,115,255,127,231,83,232,95,231,79,231,75,230,63,198,55,166,51,166,43,102,35,37,35,70,35,4,35,134,39,6,35,70,39,36,31,4,31,69,35,6,31,198,51,230,51,166,39,133,39,134,43,196,30,230,55,166,55,230,59,69,39,230,71,230,75,230,79,231,71,232,91,234,91,134,59,102,55,232,75,232,83,234,95,235,99,239,111,240,115,241,115,240,111,237,111,236,107,234,99,233,95,233,99,228,26,101,35,165,43,165,39,164,26,198,34,133,43,36,26,134,51,198,63,231,63,38,39,70,43,102,51,196,21,229,21,68,22,5,22,4,22,132,30,198,30,6,35,228,21,37,22,198,34,100,22,36,22,166,30,134,30,69,22,187,106,155,106,91,106,58,102,26,102,217,93,153,93,25,85,183,72,150,72,12,20,13,20,11,20,11,16,10,16,9,16,8,12,9,12,15,32,13,32,13,28,10,28,12,32,10,32,9,32,42,32,74,32,139,32,201,36,199,36,109,53,12,28,16,20,18,20,19,28,21,32,23,36,23,44,25,52,25,56,25,68,119,72,57,76,89,76,121,76,58,84,121,84,214,85,89,88,121,88,185,92,186,92,218,92,57,93,89,93,155,93,249,96,27,101,91,101,27,106,59,106,187,106,219,106,27,111,255,255,108,57,224,127,31,124,0,124,31,0,255,3,31,48,31,64,31,80,31,92,31,104,31,112,95,124,255,125,159,126,222,123,159,127,107,24,171,28,108,28,142,32,79,32,178,40,178,40,178,40,178,40,178,40,115,40,147,40,146,44,178,44,116,48,148,48,212,48,244,48,118,48,212,52,244,52,118,52,183,52,247,52,23,53,120,52,184,52,121,52,214,60,183,60,184,60,88,61,217,60,57,61,123,60,187,60,219,60,251,60,252,60,127,64,248,68,120,69,217,68,249,68,57,69,187,68,219,68,92,69,189,68,221,68,29,69,190,68,127,68,154,77,218,76,60,77,221,76,62,77,191,76,223,76,31,77,63,77,222,84,62,85,223,84,31,85,63,85,127,85,223,92,31,93,63,93,95,93,127,93,159,93,31,101,95,101,191,101,223,101,31,102,31,105,95,105,190,105,223,105,31,106,95,113,127,113,191,113,223,113,31,114,63,114,95,114,127,114,191,117,255,117,31,118,63,114,95,114,159,118,63,119,127,123,191,117,255,117,63,122,255,122,127,127,95,117,255,117,63,118,159,122,223,122,95,127,191,127,223,127,255,117,31,118,63,118,95,118,127,122,159,122,191,122,223,126,255,126,63,127,127,127,191,127,255,127,0,0,255,255,236,49,224,127,31,124,0,124,31,0,255,3,31,48,31,64,31,80,31,92,31,104,31,112,95,124,255,125,159,126,222,123,252,127,64,28,129,28,96,32,128,40,128,44,193,56,193,56,193,56,193,56,193,56,192,60,192,60,224,56,225,56,0,65,0,69,3,69,3,69,0,77,34,69,34,69,32,77,33,81,35,81,36,81,32,85,33,85,32,89,98,77,97,81,97,85,101,85,97,89,100,89,96,97,96,97,97,97,98,97,98,101,130,105,162,85,166,89,161,89,162,89,164,89,160,97,161,97,164,101,160,105,160,105,162,105,160,109,160,113,230,93,224,93,227,101,224,105,227,109,224,113,225,113,227,113,195,113,32,110,36,110,33,114,35,114,36,114,38,114,97,114,99,114,100,114,101,114,102,114,103,114,163,114,165,114,168,114,169,114,171,114,195,114,197,114,199,114,201,114,193,114,6,115,6,115,8,115,9,115,11,115,12,115,13,115,14,115,40,115,42,115,43,115,8,115,76,119,144,123,180,123,217,127,40,119,75,119,140,123,181,127,217,127,37,119,42,119,77,123,112,123,180,127,249,127,252,127,253,127,74,123,75,123,76,123,45,123,110,123,111,123,144,123,178,123,179,123,214,127,216,127,218,123,254,127,0,0,255,255,108,57,224,127,31,124,0,124,31,0,255,3,31,48,31,64,31,80,31,92,31,104,31,112,95,124,255,125,159,126,222,123,159,127,208,29,240,37,241,29,19,34,20,26,23,30,55,34,55,38,87,38,87,38,88,30,120,34,120,34,120,38,153,30,185,34,185,42,185,46,187,30,217,42,217,46,219,30,220,46,220,54,220,50,221,30,222,38,222,30,27,43,28,39,29,39,60,59,61,43,28,51,30,27,254,38,30,43,31,47,31,47,63,31,91,51,59,55,60,47,60,51,60,51,62,43,62,47,94,55,95,35,31,47,95,47,95,35,95,27,122,43,154,47,156,51,157,43,158,51,159,55,159,55,159,63,159,63,222,59,158,59,159,47,159,55,159,59,159,67,159,43,159,55,159,59,159,63,159,67,159,71,191,55,223,63,223,75,223,79,223,87,191,55,223,63,158,71,159,75,159,83,223,71,223,75,223,79,223,83,223,87,223,91,223,95,255,99,255,87,255,91,255,95,223,91,223,99,255,107,255,115,255,123,255,95,255,99,255,103,255,115,255,123,255,95,255,99,255,103,255,111,255,115,255,119,191,127,223,127,255,87,255,91,255,95,255,99,255,103,255,107,255,111,255,115,255,119,255,123,255,123,255,127,255,127,0,0,255,255,237,40,224,127,31,124,0,124,31,0,255,3,31,48,31,64,31,80,31,92,31,104,31,112,95,124,255,125,159,126,222,123,250,127,128,17,128,21,192,21,192,25,0,22,0,26,64,26,64,30,128,30,128,34,160,30,160,34,192,30,192,34,192,38,0,35,2,35,3,35,0,35,2,39,3,43,32,39,35,39,67,39,68,39,96,39,97,39,98,39,96,43,98,43,97,47,102,51,128,51,131,51,166,51,161,51,162,51,195,51,195,55,192,55,98,55,102,55,129,55,130,55,132,55,160,55,161,55,166,59,193,59,194,59,196,59,224,59,227,59,135,63,161,63,164,63,193,63,228,63,224,63,225,63,227,63,228,63,224,67,226,75,228,75,230,75,232,75,234,75,226,83,228,83,230,83,232,83,234,83,236,83,228,91,230,91,232,91,234,91,236,91,228,95,230,95,232,95,234,95,236,95,226,103,228,103,230,103,232,103,234,103,236,103,232,111,234,111,236,111,238,111,240,111,224,115,232,115,240,115,244,115,249,115,224,119,232,119,240,119,244,119,249,119,226,123,230,123,236,123,242,123,245,123,249,123,251,127,252,123,224,119,226,119,228,119,230,119,232,119,234,123,237,123,240,123,243,123,246,123,249,123,251,123,255,127,0,0,255,255,6,0,177,60,2,0,0,0,50,66,248,86,141,45,8,33,74,41,140,49,206,57,16,66,82,74,148,82,214,90,24,99,90,107,156,115,222,123,109,20,175,28,239,36,239,36,16,41,83,53,183,61,184,69,147,57,16,38,150,65,50,38,82,42,47,29,82,38,154,86,21,42,25,74,214,65,248,65,214,57,242,37,19,38,21,46,86,46,52,42,86,46,85,42,86,42,54,42,109,28,49,41,176,32,51,45,51,49,150,65,150,53,117,53,214,57,52,49,213,49,148,41,242,44,19,49,152,61,216,65,58,62,27,78,249,77,26,82,59,86,26,86,60,90,159,98,60,90,184,73,24,86,216,77,151,73,249,73,249,81,248,77,26,86,27,86,230,37,39,46,205,66,146,95,210,95,176,91,244,103,247,111,247,111,210,103,246,111,247,115,245,107,247,115,248,119,249,119,236,66,233,62,78,75,15,71,113,87,247,111,243,103,243,99,244,103,247,115,181,95,246,103,248,115,181,99,181,95,147,95,99,16,132,20,165,24,66,12,198,28,66,12,99,16,66,12,66,12,132,20,132,20,99,16,201,16,73,20,134,25,66,12,132,20,99,16,99,16,132,20,165,24,164,16,165,24,168,41,165,24,201,41,200,41,10,50,11,50,165,24,132,20,71,29,40,17,40,21,104,16,107,20,138,21,171,25,172,29,238,33,237,33,13,34,12,34,45,34,74,25,205,33,173,33,14,38,14,34,239,37,233,41,234,45,12,58,45,62,15,42,238,41,210,70,143,66,209,74,177,70,144,70,141,66,8,38,80,66,194,17,131,22,2,35,5,35,34,27,195,30,133,35,230,63,68,51,196,47,231,79,227,42,107,55,10,43,197,34,136,38,132,46,70,71,135,87,70,79,168,87,69,75,233,95,171,91,138,87,170,87,105,83,232,95,168,83,167,79,68,67,69,67,99,13,98,17,131,25,164,25,164,21,196,25,228,25,228,29,4,26,5,30,70,34,71,38,38,42,70,42,70,38,37,38,136,46,105,54,170,54,38,38,70,38,38,34,234,54,235,54,235,58,203,54,202,54,13,75,139,58,142,79,179,99,15,75,13,41,4,96,255,127,9,100,31,104,31,40,31,64,255,43,255,79,255,119,95,124,31,104,31,84,21,126,224,127,224,3,211,65,4,96,166,63,161,42,36,55,166,63,224,67,232,79,196,91,197,99,237,103,240,111,243,119,250,127,252,127,255,127,136,46,105,54,4,30,226,13,70,38,38,34,234,54,106,46,235,58,203,54,169,50,12,67,139,58,111,83,179,99,15,75,0,0,27,32,29,36,31,44,31,52,30,60,31,64,31,72,31,84,31,92,31,104,31,112,95,124,95,126,31,123,222,123,250,127,194,28,101,32,131,32,196,36,226,36,2,37,3,37,165,40,67,45,69,45,99,45,100,45,68,49,69,49,131,53,132,53,134,53,135,53,195,53,134,57,135,57,195,57,229,57,231,57,232,57,227,57,5,58,35,58,198,65,229,65,5,66,10,66,38,66,41,66,99,66,101,66,102,66,103,66,135,66,227,70,7,74,11,74,38,74,39,74,41,74,101,74,102,74,138,74,165,74,166,74,168,74,197,74,227,74,76,82,134,82,137,82,166,82,201,82,229,82,230,82,232,82,233,82,198,90,201,90,230,90,232,90,233,90,235,90,230,98,232,98,233,98,234,98,235,98,236,98,232,106,234,106,237,106,238,106,240,106,232,110,234,110,237,110,238,110,240,110,234,118,235,118,237,118,14,119,16,119,17,119,18,119,19,119,13,127,15,127,16,127,18,127,19,127,53,127,26,127,27,127,14,127,48,127,50,127,56,127,91,127,107,127,112,127,146,127,149,127,151,127,154,127,190,127,223,127,145,127,178,127,179,127,180,127,181,127,182,127,183,127,184,127,185,127,191,127,187,127,255,127,255,127,0,0,255,255,6,0,0,0,50,66,248,86,141,45,8,33,2,0,0,0,50,66,248,86,141,45,8,33,74,41,140,49,206,57,16,66,82,74,148,82,214,90,24,99,90,107,156,115,222,123,194,26,226,26,2,27,3,23,35,23,67,23,99,23,132,23,163,27,163,23,196,27,198,27,229,31,194,18,229,27,197,31,165,31,101,27,100,31,134,35,134,39,131,27,164,27,166,35,231,35,197,31,231,35,230,31,232,31,200,31,164,26,132,26,3,23,4,23,4,27,132,31,35,23,70,31,167,35,5,27,196,27,163,19,195,22,228,26,232,47,235,67,235,55,234,47,236,55,237,59,238,63,237,63,238,67,238,67,238,67,235,51,235,55,235,55,234,51,236,59,236,59,235,55,236,63,237,63,199,37,8,46,142,66,81,87,147,95,113,91,243,103,181,103,216,111,147,103,247,111,248,115,182,107,216,115,249,119,250,119,143,66,205,70,15,75,208,70,50,87,213,103,181,99,181,99,182,107,214,107,215,111,183,103,249,115,118,99,118,103,84,95,4,17,228,16,228,16,36,21,37,21,100,17,164,21,101,25,3,17,68,21,3,17,100,21,132,21,4,22,134,25,163,12,37,21,228,16,37,25,196,16,229,20,164,16,103,33,168,41,135,37,201,41,200,41,10,50,11,50,168,37,166,29,71,29,40,17,40,21,35,18,100,22,138,21,171,25,172,29,238,33,237,33,13,34,12,34,45,34,74,25,205,33,173,33,14,38,14,34,239,37,233,41,234,45,12,58,45,62,15,42,238,41,210,70,143,66,209,74,177,70,144,70,141,66,8,38,80,66,3,41,68,45,101,53,200,65,167,61,134,57,232,65,8,74,231,65,232,69,75,82,38,53,78,86,237,73,168,61,107,65,132,46,70,71,135,87,70,79,168,87,69,75,233,95,171,91,138,87,170,87,105,83,232,95,168,83,167,79,68,67,69,67,99,13,98,17,131,25,164,25,164,21,196,25,228,25,228,29,4,26,5,30,70,34,71,38,38,42,70,42,70,38,37,38,136,46,105,54,170,54,38,38,70,38,38,34,234,54,235,54,235,58,203,54,202,54,204,58,139,58,111,83,179,99,15,75,13,41,4,96,255,127,9,100,31,104,31,40,31,64,255,43,255,79,255,119,95,124,31,104,31,84,21,126,224,127,224,3,211,65,4,96,166,63,161,42,36,55,166,63,224,67,232,79,196,91,197,99,237,103,240,111,243,119,250,127,252,127,255,127,136,46,105,54,4,30,226,13,70,38,38,34,234,54,106,46,235,58,203,54,169,50,12,67,139,58,111,83,179,99,15,75,0,0,27,32,29,36,31,44,31,52,30,60,31,64,31,72,31,84,31,92,31,104,31,112,95,124,95,126,31,123,222,123,250,127,194,28,101,32,131,32,196,36,226,36,2,37,3,37,165,40,67,45,69,45,99,45,100,45,68,49,69,49,131,53,132,53,134,53,135,53,195,53,134,57,135,57,195,57,229,57,231,57,232,57,227,57,5,58,35,58,198,65,229,65,5,66,10,66,38,66,41,66,99,66,101,66,102,66,103,66,135,66,227,70,7,74,11,74,38,74,39,74,41,74,101,74,102,74,138,74,165,74,166,74,168,74,197,74,227,74,76,82,134,82,137,82,166,82,201,82,229,82,230,82,232,82,233,82,198,90,201,90,230,90,232,90,233,90,235,90,230,98,232,98,233,98,234,98,235,98,236,98,232,106,234,106,237,106,238,106,240,106,232,110,234,110,237,110,238,110,240,110,234,118,235,118,237,118,14,119,16,119,17,119,18,119,19,119,13,127,15,127,16,127,18,127,19,127,53,127,26,127,27,127,14,127,48,127,50,127,56,127,91,127,107,127,112,127,146,127,149,127,151,127,154,127,190,127,223,127,145,127,178,127,179,127,180,127,181,127,182,127,183,127,184,127,185,127,191,127,187,127,255,127,255,127,0,0,255,255,2,0,0,0,50,66,248,86,141,45,8,33,9,0,0,0,50,66,248,86,141,45,31,108,31,124,31,126,191,126,19,92,82,92,50,100,117,112,146,121,246,125,249,126,222,123,242,82,17,79,239,74,205,66,138,54,72,46,39,42,6,38,38,38,38,34,5,30,5,26,196,21,132,21,102,25,196,12,105,46,72,42,39,38,71,38,70,34,4,26,229,25,197,25,133,25,68,17,4,13,196,8,164,8,164,12,132,12,100,8,166,33,134,29,101,25,101,21,4,17,164,16,198,33,231,37,165,29,68,21,36,17,228,16,19,91,174,70,108,58,234,49,141,66,235,53,135,37,233,45,102,33,69,25,5,21,102,29,100,12,196,16,165,16,199,29,167,29,69,21,166,29,36,13,239,78,18,83,208,74,75,62,75,58,233,49,42,58,200,45,168,45,135,41,102,37,37,29,4,21,167,37,199,45,8,54,134,41,231,45,42,58,7,50,165,37,164,33,197,41,75,58,106,70,8,58,40,58,8,58,100,37,165,49,166,41,132,49,101,41,3,25,67,33,99,33,99,41,100,33,164,45,131,37,197,49,99,29,100,33,166,49,230,53,198,49,138,62,105,58,231,45,205,70,47,83,139,62,230,45,226,16,2,21,205,74,15,83,7,46,193,8,166,37,226,16,34,21,35,21,165,37,209,78,45,58,12,58,202,49,12,54,234,49,202,45,11,54,104,37,169,45,110,66,143,70,169,41,168,41,136,37,4,21,136,41,103,33,10,54,109,66,236,53,45,62,209,82,144,74,44,58,78,66,77,62,16,83,50,87,108,66,149,103,81,91,81,91,213,111,115,99,239,82,39,29,73,37,196,16,194,8,230,24,174,53,172,49,140,45,173,45,173,49,106,37,40,29,6,21,196,12,248,111,179,99,237,74,138,62,15,79,204,66,150,103,143,74,73,50,238,74,178,95,237,70,106,58,42,50,238,123,234,99,233,87,168,79,68,59,196,58,34,38,65,17,11,79,249,123,242,103,176,95,227,37,45,79,112,91,205,74,110,87,78,87,47,87,99,18,131,14,163,14,37,23,200,35,4,19,196,23,230,34,35,19,98,10,33,6,193,1,161,5,211,65,65,2,160,2,228,2,34,3,105,3,140,31,206,39,208,55,243,63,246,71,251,83,255,95,255,107,255,111,255,127,255,255,145,65,224,17,32,26,128,38,192,50,0,59,64,71,97,79,160,87,226,99,228,111,230,119,239,123,244,127,251,127,222,123,255,255,145,65,0,32,0,40,0,48,0,52,0,56,0,64,0,72,0,84,0,92,33,104,132,112,41,125,82,126,57,127,222,123,255,255,211,65,209,1,21,2,119,10,185,18,251,22,60,39,93,55,94,67,127,75,127,83,159,91,159,99,191,111,223,119,255,127,255,255,145,65,64,127,96,123,128,119,160,115,192,111,224,107,224,107,227,111,230,115,233,119,236,123,239,127,244,127,249,127,222,123,145,65,0,96,0,100,0,104,0,108,33,112,132,116,198,120,41,125,104,125,166,125,228,125,35,126,130,126,225,126,222,123,166,33,0,32,0,36,0,44,0,52,0,56,0,60,0,64,0,68,0,72,0,76,0,80,0,84,0,88,0,92,234,49,255,255,145,65,255,71,255,75,255,79,255,83,255,87,255,91,255,95,255,99,255,103,255,107,255,111,255,115,255,119,255,123,222,123,33,4,159,23,191,27,223,31,255,35,255,39,255,43,255,47,255,51,255,55,255,59,255,63,255,67,255,71,255,75,222,123,166,33,63,20,191,16,31,13,159,9,255,5,63,6,127,10,191,10,223,14,255,14,31,19,63,19,95,23,127,23,234,49,255,255,145,65,224,83,224,87,224,91,224,95,224,99,224,103,224,107,227,111,230,115,233,119,236,123,239,127,244,127,249,127,222,123,33,4,224,27,224,31,224,35,224,39,224,43,224,47,224,51,224,55,224,59,224,63,224,67,224,71,224,75,224,79,222,123,166,33,0,22,32,22,64,22,96,22,128,22,160,22,192,22,224,22,0,23,32,23,64,23,96,23,128,23,160,27,234,49,255,255,145,65,239,3,234,3,229,3,224,3,224,3,224,23,224,43,224,63,224,83,224,103,224,127,239,127,244,127,249,127,222,123,0,0,31,100,31,80,31,60,31,40,31,20,31,0,191,0,95,1,255,1,159,2,63,3,255,3,249,3,244,3,222,123,0,0,234,127,224,127,32,127,128,126,224,125,64,125,160,124,0,124,5,124,10,120,15,124,20,124,25,124,31,124,222,123,255,255,2,0,0,0,50,66,248,86,141,45,8,33,74,41,9,0,0,0,50,66,248,86,141,45,255,39,255,59,255,83,255,99,30,64,31,76,31,88,31,108,31,124,31,126,191,126,222,123,205,75,236,71,202,67,200,59,69,47,3,39,226,34,193,30,225,30,225,26,192,22,192,18,128,14,64,14,33,18,128,5,101,39,36,35,3,31,35,31,34,27,224,18,193,18,129,18,65,18,0,10,192,5,128,1,64,1,64,5,32,5,0,1,66,26,34,22,1,18,1,14,128,5,0,1,98,26,131,30,65,22,224,13,160,5,96,5,175,83,74,63,8,51,134,42,41,59,135,46,67,30,165,38,34,26,1,18,161,13,2,22,192,0,64,5,33,5,99,22,67,22,225,13,66,22,192,5,239,78,18,83,208,74,75,62,75,58,233,49,42,58,200,45,168,45,135,41,102,37,37,29,4,21,167,37,199,45,8,54,134,41,231,45,42,58,7,50,165,37,164,33,197,41,75,58,106,70,8,58,40,58,8,58,100,37,165,49,166,41,132,49,101,41,3,25,67,33,99,33,99,41,100,33,164,45,131,37,197,49,99,29,100,33,166,49,230,53,198,49,138,62,105,58,231,45,205,70,47,83,139,62,230,45,226,16,2,21,205,74,15,83,7,46,193,8,166,37,226,16,34,21,35,21,165,37,209,78,45,58,12,58,202,49,12,54,234,49,202,45,11,54,104,37,169,45,110,66,143,70,169,41,168,41,136,37,4,21,136,41,103,33,10,54,109,66,236,53,45,62,209,82,144,74,44,58,78,66,77,62,16,83,50,87,108,66,149,103,81,91,81,91,213,111,115,99,239,82,39,29,73,37,196,16,194,8,230,24,174,53,172,49,140,45,173,45,173,49,106,37,40,29,6,21,196,12,248,111,179,99,237,74,138,62,15,79,204,66,150,103,143,74,73,50,238,74,178,95,237,70,106,58,42,50,238,123,234,99,233,87,168,79,68,59,196,58,34,38,65,17,11,79,249,123,242,103,176,95,227,37,45,79,112,91,205,74,110,87,78,87,47,87,99,18,131,14,163,14,37,23,200,35,4,19,196,23,230,34,35,19,98,10,33,6,193,1,161,5,211,65,65,2,160,2,228,2,34,3,105,3,140,31,206,39,208,55,243,63,246,71,251,83,255,95,255,107,255,111,255,127,255,255,145,65,224,17,32,26,128,38,192,50,0,59,64,71,97,79,160,87,226,99,228,111,230,119,239,123,244,127,251,127,222,123,255,255,145,65,0,32,0,40,0,48,0,52,0,56,0,64,0,72,0,84,0,92,33,104,132,112,41,125,82,126,57,127,222,123,255,255,211,65,209,1,21,2,119,10,185,18,251,22,60,39,93,55,94,67,127,75,127,83,159,91,159,99,191,111,223,119,255,127,255,255,145,65,64,127,96,123,128,119,160,115,192,111,224,107,224,107,227,111,230,115,233,119,236,123,239,127,244,127,249,127,222,123,145,65,0,96,0,100,0,104,0,108,33,112,132,116,198,120,41,125,104,125,166,125,228,125,35,126,130,126,225,126,222,123,166,33,0,32,0,36,0,44,0,52,0,56,0,60,0,64,0,68,0,72,0,76,0,80,0,84,0,88,0,92,234,49,255,255,145,65,255,71,255,75,255,79,255,83,255,87,255,91,255,95,255,99,255,103,255,107,255,111,255,115,255,119,255,123,222,123,33,4,159,23,191,27,223,31,255,35,255,39,255,43,255,47,255,51,255,55,255,59,255,63,255,67,255,71,255,75,222,123,166,33,63,20,191,16,31,13,159,9,255,5,63,6,127,10,191,10,223,14,255,14,31,19,63,19,95,23,127,23,234,49,255,255,145,65,224,83,224,87,224,91,224,95,224,99,224,103,224,107,227,111,230,115,233,119,236,123,239,127,244,127,249,127,222,123,33,4,224,27,224,31,224,35,224,39,224,43,224,47,224,51,224,55,224,59,224,63,224,67,224,71,224,75,224,79,222,123,166,33,0,22,32,22,64,22,96,22,128,22,160,22,192,22,224,22,0,23,32,23,64,23,96,23,128,23,160,27,234,49,255,255,145,65,239,3,234,3,229,3,224,3,224,3,224,23,224,43,224,63,224,83,224,103,224,127,239,127,244,127,249,127,222,123,0,0,31,100,31,80,31,60,31,40,31,20,31,0,191,0,95,1,255,1,159,2,63,3,255,3,249,3,244,3,222,123,0,0,234,127,224,127,32,127,128,126,224,125,64,125,160,124,0,124,5,124,10,120,15,124,20,124,25,124,31,124,222,123,255,255,9,0,0,0,50,66,248,86,141,45,31,108,31,124,5,0,206,64,50,66,248,86,141,45,233,32,43,41,109,49,175,57,241,65,51,74,117,82,183,90,249,98,59,107,125,115,223,123,250,127,246,115,245,111,242,103,206,87,243,103,239,91,240,91,239,87,239,91,8,59,238,83,237,83,235,83,39,51,132,30,41,59,1,18,34,22,193,13,74,63,7,55,66,26,33,18,7,51,198,46,225,13,99,30,75,67,172,83,240,103,36,30,233,62,43,71,76,75,243,107,245,111,246,111,247,115,246,115,247,115,245,111,240,95,241,95,106,71,161,25,97,17,225,25,197,42,199,50,230,50,106,63,40,59,101,38,65,9,137,50,203,71,235,75,137,67,68,26,133,34,166,42,132,34,35,26,255,127,254,127,253,127,252,127,249,119,112,83,146,83,47,75,146,87,179,91,49,79,252,127,251,127,248,115,17,79,240,70,206,62,137,50,241,78,50,79,50,83,115,87,175,70,143,66,200,30,9,51,138,54,39,42,200,34,40,46,7,42,7,38,230,37,105,46,98,17,130,13,197,33,11,59,37,34,142,71,176,79,143,75,210,83,246,111,250,127,248,111,244,95,204,54,143,83,109,71,12,59,105,42,5,30,71,38,168,46,169,46,37,30,195,17,99,13,229,21,67,17,98,13,33,9,32,9,248,99,242,79,141,59,76,47,44,47,11,43,77,51,111,55,110,55,109,51,9,47,10,39,200,34,40,43,197,30,166,26,39,35,225,5,225,5,197,30,229,34,197,26,68,26,1,6,97,14,131,34,130,30,129,26,70,43,73,47,42,51,166,22,255,127,249,119,202,58,136,50,102,42,78,75,235,62,0,9,6,38,99,21,64,9,66,17,67,30,12,67,11,67,10,63,243,95,176,83,137,54,227,29,103,46,162,21,145,87,162,21,104,46,162,21,110,79,71,42,46,75,7,38,71,46,138,58,144,83,136,54,248,123,251,119,213,95,212,91,247,115,249,119,10,63,79,79,8,38,247,111,244,95,241,95,177,91,234,62,77,75,203,58,98,17,12,71,144,83,228,33,164,33,78,79,249,111,248,107,105,46,172,58,236,66,113,83,45,67,80,79,145,65,0,60,0,64,0,68,0,72,33,76,99,80,132,84,165,92,198,100,99,112,165,120,206,125,148,126,57,127,222,123,255,255,211,65,0,3,64,3,98,3,162,3,201,3,204,31,238,39,240,55,243,63,246,71,251,83,255,95,255,107,255,111,255,127,255,255,145,65,25,0,27,0,28,0,221,24,93,41,159,49,223,57,31,66,95,74,159,82,223,90,31,99,95,107,159,115,222,123,255,255,145,65,224,46,0,51,32,59,64,67,96,71,128,79,161,87,192,91,226,103,228,111,230,119,239,123,244,127,251,127,222,123,255,255,9,0,0,0,50,66,5,0,206,64,50,66,248,86,141,45,8,29,74,37,140,45,206,53,16,62,82,70,148,78,214,86,24,95,90,103,156,111,222,123,249,123,245,111,212,107,241,99,141,83,242,99,238,87,239,87,238,83,206,87,231,54,205,79,236,79,202,79,6,47,99,26,41,59,1,18,34,22,193,13,74,63,7,55,66,26,33,18,7,51,198,46,225,13,99,30,75,67,172,83,240,103,36,30,233,62,43,71,76,75,243,107,245,111,246,115,246,115,246,115,245,115,245,111,240,95,241,95,106,71,161,25,97,17,225,25,197,42,199,50,230,50,106,63,40,59,101,38,65,9,137,50,203,71,235,75,137,67,68,26,133,34,166,42,132,34,35,26,255,127,254,127,253,127,253,127,249,119,112,83,146,83,47,75,146,87,179,91,49,79,253,127,252,127,216,115,17,79,240,70,142,62,43,50,241,78,211,78,50,83,115,87,175,70,143,66,111,38,176,58,76,54,233,41,109,42,234,45,201,41,201,37,200,37,75,46,68,17,100,13,167,33,11,59,7,34,142,71,176,79,143,75,210,83,246,111,250,127,248,111,244,95,204,54,111,83,77,71,236,58,73,42,229,29,39,38,136,46,137,46,5,30,132,17,36,13,166,21,4,17,35,13,226,8,225,8,255,107,125,87,216,66,151,54,119,54,86,50,152,58,186,62,185,62,184,58,84,54,85,46,19,42,116,50,16,38,241,33,145,42,69,5,70,9,49,38,79,42,49,34,174,33,102,5,200,21,237,41,236,37,42,34,176,46,180,54,148,58,17,30,255,127,249,119,202,58,136,50,102,42,78,75,235,62,0,9,6,38,99,21,64,9,66,17,67,30,12,67,11,67,10,63,243,95,176,83,137,54,227,29,103,46,162,21,145,87,162,21,104,46,162,21,110,79,71,42,46,75,7,38,71,46])
.concat([138,58,144,83,136,54,248,123,251,119,213,95,212,91,247,115,249,119,10,63,79,79,8,38,247,111,244,95,241,95,177,91,234,62,110,79,236,62,131,21,45,75,177,87,5,38,197,37,111,83,250,115,249,111,138,50,205,62,13,71,146,87,78,71,113,83,145,65,0,60,0,64,0,68,0,72,33,76,99,80,132,84,165,92,198,100,99,112,165,120,206,125,148,126,57,127,222,123,255,255,211,65,0,3,64,3,98,3,162,3,201,3,204,31,238,39,240,55,243,63,246,71,251,83,255,95,255,107,255,111,255,127,255,255,145,65,25,0,27,0,28,0,221,24,93,41,159,49,223,57,31,66,95,74,159,82,223,90,31,99,95,107,159,115,222,123,255,255,145,65,224,46,0,51,32,59,64,67,96,71,128,79,161,87,192,91,226,103,228,111,230,119,239,123,244,127,251,127,222,123,255,255,5,0,206,64,50,66,4,0,0,0,50,66,248,86,141,45,8,33,74,41,140,49,206,57,16,66,82,74,148,82,214,90,24,99,90,107,156,115,222,123,41,12,42,12,75,24,10,16,42,20,173,36,76,28,77,28,209,48,142,36,241,48,175,40,176,44,143,36,142,32,109,32,43,16,144,40,174,32,109,28,110,32,208,40,240,44,247,81,215,81,25,90,91,94,24,90,247,85,213,81,148,77,150,73,54,69,53,65,178,44,85,69,184,77,242,56,152,77,210,56,184,81,151,77,20,61,108,32,119,73,20,53,76,24,77,24,215,73,148,69,140,32,207,40,241,52,242,52,208,48,142,40,143,40,108,28,107,24,74,20,41,16,85,65,51,57,52,61,179,73,22,86,90,94,90,98,114,65,214,77,177,44,176,48,242,52,144,44,13,24,12,20,145,40,22,61,245,56,212,56,179,48,79,36,144,36,116,65,215,77,185,81,217,77,53,65,119,81,152,81,218,89,185,85,242,60,183,77,82,65,120,73,119,77,120,77,152,73,242,48,177,44,77,32,149,69,174,36,107,28,19,57,210,52,211,48,18,57,243,52,209,40,146,56,174,24,51,61,182,73,83,61,170,28,83,65,149,73,248,89,181,77,249,85,21,82,244,77,120,90,177,48,173,40,142,32,64,42,160,83,225,99,229,111,229,111,194,91,196,95,195,95,196,103,200,111,198,115,230,107,224,41,0,46,0,46,130,62,71,91,160,29,192,62,129,54,128,54,3,75,100,83,0,42,132,83,135,87,38,91,196,95,226,95,226,91,0,63,32,67,192,58,64,46,32,42,96,71,0,67,65,75,64,50,32,50,97,58,96,50,128,50,96,42,160,50,0,46,160,58,34,71,160,58,192,49,0,50,32,50,32,54,0,50,133,83,231,103,132,87,136,99,104,99,170,115,203,115,130,58,197,115,231,107,67,25,66,21,161,8,227,12,225,12,98,25,100,33,229,41,163,37,196,37,37,46,38,50,39,50,99,25,164,33,232,45,132,29,165,37,34,17,96,4,226,12,67,21,163,29,164,29,229,37,197,37,231,45,198,41,7,46,73,58,203,66,12,79,179,53,224,127,31,124,0,124,31,0,255,3,31,48,31,64,31,80,31,92,31,104,31,112,95,124,255,125,159,126,222,123,0,0,224,127,31,124,0,124,31,0,224,15,224,27,224,39,224,55,224,67,224,79,224,99,237,103,238,119,245,127,222,123,255,255,179,53,224,127,31,124,0,124,31,0,255,3,31,48,31,64,31,80,31,92,31,104,31,112,95,124,255,125,159,126,222,123,159,127,107,24,171,28,108,28,142,32,79,32,178,40,178,40,178,40,178,40,178,40,115,40,147,40,146,44,178,44,116,48,148,48,212,48,244,48,118,48,212,52,244,52,118,52,183,52,247,52,23,53,120,52,184,52,121,52,214,60,183,60,184,60,88,61,217,60,57,61,123,60,187,60,219,60,251,60,252,60,127,64,248,68,120,69,217,68,249,68,57,69,187,68,219,68,92,69,189,68,221,68,29,69,190,68,127,68,154,77,218,76,60,77,221,76,62,77,191,76,223,76,31,77,63,77,222,84,62,85,223,84,31,85,63,85,127,85,223,92,31,93,63,93,95,93,127,93,159,93,31,101,95,101,191,101,223,101,31,102,31,105,95,105,190,105,223,105,31,106,95,113,127,113,191,113,223,113,31,114,63,114,95,114,127,114,191,121,255,121,31,122,95,122,127,122,191,122,95,123,127,123,223,125,31,126,95,126,31,127,127,127,127,125,31,126,95,126,191,126,255,126,95,127,191,127,223,127,63,126,95,126,127,126,159,126,191,126,223,126,255,126,31,127,63,127,95,127,127,127,191,127,255,127,0,0,255,255,72,60,224,127,31,124,0,124,31,0,255,3,31,48,31,64,31,80,31,92,31,104,31,112,95,124,255,125,159,126,222,123,224,127,69,4,197,8,229,4,5,5,37,5,69,5,101,5,69,9,101,9,102,9,134,9,166,9,140,25,170,25,102,29,224,127,130,29,162,29,194,29,140,33,172,33,194,33,141,37,172,37,173,41,174,41,175,41,207,41,226,41,145,45,176,45,224,127,240,45,208,49,209,49,210,49,241,49,242,49,146,53,209,53,210,53,242,53,243,53,51,58,243,61,244,61,245,61,224,127,20,62,21,62,51,62,52,62,98,63,211,65,245,65,21,66,22,66,52,66,53,66,54,66,130,67,22,70,23,70,224,127,54,70,55,70,57,70,86,70,87,70,118,70,23,74,25,74,55,74,57,74,119,78,120,78,173,79,89,82,90,82,224,127,121,82,122,82,153,82,153,82,154,82,236,83,238,83,153,86,154,86,185,86,186,86,188,86,156,90,186,90,188,90,224,127,241,91,251,94,252,94,189,98,253,98,254,98,29,99,253,102,29,103,30,103,61,103,178,103,212,103,62,107,63,107,224,127,127,111,127,115,158,115,159,115,253,115,191,119,249,119,190,123,221,123,252,123,250,127,251,127,252,127,253,127,255,127,224,127,108,29,208,45,19,62,53,70,120,82,189,90,127,111,72,60,72,60,72,60,72,60,72,60,72,60,72,60,72,60,113,57,66,8,198,21,102,38,140,30,10,39,241,50,171,46,207,59,210,59,238,75,246,83,148,91,181,107,251,111,222,123,255,255,5,0,206,64,50,66,248,86,4,0,0,0,50,66,248,86,141,45,8,33,74,41,140,49,206,57,16,66,82,74,148,82,214,90,24,99,90,107,156,115,222,123,34,20,35,20,68,32,3,24,35,28,166,44,69,36,70,36,202,56,135,44,234,56,168,48,169,52,136,44,135,40,102,40,36,24,137,48,167,40,102,36,103,40,201,48,233,52,240,89,208,89,18,98,84,102,17,98,240,93,206,89,141,85,143,81,47,77,46,73,171,52,78,77,177,85,235,64,145,85,203,64,177,89,144,85,13,69,101,40,112,81,13,61,69,32,70,32,208,81,141,77,133,40,200,48,234,60,235,60,201,56,135,48,136,48,101,36,100,32,67,28,34,24,78,73,44,65,45,69,172,81,15,94,83,102,83,106,107,73,207,85,170,52,169,56,235,60,137,52,6,32,5,28,138,48,15,69,238,64,205,64,172,56,72,44,137,44,110,73,208,85,178,89,210,85,46,73,112,89,145,89,211,97,178,93,235,68,176,85,75,73,113,81,112,85,113,85,145,81,235,56,170,52,70,40,142,77,167,44,100,36,12,65,203,60,204,56,11,65,236,60,202,48,139,64,167,32,44,69,175,81,76,69,163,36,76,73,142,81,241,97,174,85,242,93,14,90,237,85,113,98,170,56,166,48,135,40,64,42,160,83,225,99,229,111,229,111,194,91,196,95,195,95,196,103,200,111,198,115,230,107,224,41,0,46,0,46,130,62,71,91,160,29,192,62,129,54,128,54,3,75,100,83,0,42,132,83,135,87,38,91,196,95,226,95,226,91,0,63,32,67,192,58,64,46,32,42,96,71,0,67,65,75,64,50,32,50,97,58,96,50,128,50,96,42,160,50,0,46,160,58,34,71,160,58,192,49,0,50,32,50,32,54,0,50,133,83,231,103,132,87,136,99,104,99,170,115,203,115,130,58,197,115,231,107,67,25,66,21,161,8,227,12,225,12,98,25,100,33,229,41,163,37,196,37,37,46,38,50,39,50,99,25,164,33,232,45,132,29,165,37,34,17,96,4,226,12,67,21,163,29,164,29,229,37,197,37,231,45,198,41,7,46,73,58,203,66,12,79,179,53,224,127,31,124,0,124,31,0,255,3,31,48,31,64,31,80,31,92,31,104,31,112,95,124,255,125,159,126,222,123,0,0,224,127,31,124,0,124,31,0,224,15,224,27,224,39,224,55,224,67,224,79,224,99,237,103,238,119,245,127,222,123,255,255,179,53,224,127,31,124,0,124,31,0,255,3,31,48,31,64,31,80,31,92,31,104,31,112,95,124,255,125,159,126,222,123,159,127,107,24,171,28,108,28,142,32,79,32,178,40,178,40,178,40,178,40,178,40,115,40,147,40,146,44,178,44,116,48,148,48,212,48,244,48,118,48,212,52,244,52,118,52,183,52,247,52,23,53,120,52,184,52,121,52,214,60,183,60,184,60,88,61,217,60,57,61,123,60,187,60,219,60,251,60,252,60,127,64,248,68,120,69,217,68,249,68,57,69,187,68,219,68,92,69,189,68,221,68,29,69,190,68,127,68,154,77,218,76,60,77,221,76,62,77,191,76,223,76,31,77,63,77,222,84,62,85,223,84,31,85,63,85,127,85,223,92,31,93,63,93,95,93,127,93,159,93,31,101,95,101,191,101,223,101,31,102,31,105,95,105,190,105,223,105,31,106,95,113,127,113,191,113,223,113,31,114,63,114,95,114,127,114,191,121,255,121,31,122,95,122,127,122,191,122,95,123,127,123,223,125,31,126,95,126,31,127,127,127,127,125,31,126,95,126,191,126,255,126,95,127,191,127,223,127,63,126,95,126,127,126,159,126,191,126,223,126,255,126,31,127,63,127,95,127,127,127,191,127,255,127,0,0,255,255,72,60,224,127,31,124,0,124,31,0,255,3,31,48,31,64,31,80,31,92,31,104,31,112,95,124,255,125,159,126,222,123,224,127,69,4,197,8,229,4,5,5,37,5,69,5,101,5,69,9,101,9,102,9,134,9,166,9,140,25,170,25,102,29,224,127,130,29,162,29,194,29,140,33,172,33,194,33,141,37,172,37,173,41,174,41,175,41,207,41,226,41,145,45,176,45,224,127,240,45,208,49,209,49,210,49,241,49,242,49,146,53,209,53,210,53,242,53,243,53,51,58,243,61,244,61,245,61,224,127,20,62,21,62,51,62,52,62,98,63,211,65,245,65,21,66,22,66,52,66,53,66,54,66,130,67,22,70,23,70,224,127,54,70,55,70,57,70,86,70,87,70,118,70,23,74,25,74,55,74,57,74,119,78,120,78,173,79,89,82,90,82,224,127,121,82,122,82,153,82,153,82,154,82,236,83,238,83,153,86,154,86,185,86,186,86,188,86,156,90,186,90,188,90,224,127,241,91,251,94,252,94,189,98,253,98,254,98,29,99,253,102,29,103,30,103,61,103,178,103,212,103,62,107,63,107,224,127,127,111,127,115,158,115,159,115,253,115,191,119,249,119,190,123,221,123,252,123,250,127,251,127,252,127,253,127,255,127,224,127,108,29,208,45,19,62,53,70,120,82,189,90,127,111,72,60,72,60,72,60,72,60,72,60,72,60,72,60,72,60,113,57,66,8,198,21,102,38,140,30,10,39,241,50,171,46,207,59,210,59,238,75,246,83,148,91,181,107,251,111,222,123,255,255,4,0,0,0,50,66,248,86,11,0,42,41,50,66,248,86,141,45,8,33,74,41,140,49,206,57,16,66,82,74,148,82,214,90,24,99,90,107,156,115,222,123,42,46,233,41,9,38,233,41,41,38,74,42,75,42,10,38,232,37,200,37,101,25,168,33,167,33,232,37,167,29,168,33,168,33,134,33,134,29,36,21,135,33,70,33,37,25,4,21,36,25,229,24,226,12,226,16,38,25,195,16,227,20,130,16,160,16,64,12,96,12,128,16,161,20,194,24,37,25,36,25,195,12,70,33,162,12,37,29,192,16,4,17,5,25,196,24,35,21,69,29,1,17,98,29,102,29,101,29,69,25,4,17,194,12,226,12,3,13,169,37,6,25,103,29,37,17,47,66,121,111,89,111,87,107,55,103,55,107,122,111,122,115,120,107,88,107,153,111,120,111,176,78,144,74,78,62,143,74,201,45,110,70,143,74,54,103,86,103,51,87,175,74,142,70,77,66,234,49,233,45,201,41,202,45,201,41,10,50,43,54,203,45,12,54,13,54,11,50,69,29,70,29,227,16,195,12,234,53,235,53,134,33,135,37,168,41,69,25,101,29,102,29,102,33,194,12,227,12,36,21,3,17,3,21,2,13,35,17,67,21,162,8,194,8,66,13,98,8,36,25,226,12,35,21,104,33,165,25,140,58,230,33,40,42,170,54,70,38,169,46,235,54,167,42,134,34,166,34,230,30,6,31,206,66,83,87,5,26,2,14,68,26,201,50,236,58,169,46,15,71,38,34,131,17,138,46,203,54,70,34,66,13,5,26,135,38,233,42,39,34,45,71,13,67,236,66,136,50,79,79,205,70,170,54,135,46,7,42,73,50,137,54,66,17,199,37,164,29,204,66,106,54,165,33,132,25,11,71,234,62,10,67,196,33,205,66,8,46,110,83,71,38,47,79,114,91,139,58,74,50,229,33,41,46,136,127,136,127,169,126,115,123,104,126,203,114,203,102,42,119,72,99,168,82,78,111,236,102,105,86,42,107,136,82,133,69,5,46,6,46,99,29,76,79,176,70,206,70,235,70,77,83,196,41,195,37,136,58,199,98,231,98,204,74,45,83,13,75,74,41,2,0,2,0,2,0,2,0,2,0,2,0,2,0,31,56,31,76,31,88,30,108,30,120,31,126,191,126,222,123,175,45,110,41,142,41,174,41,174,45,207,49,208,49,207,45,141,37,109,37,10,25,77,33,76,33,110,37,76,29,108,33,109,33,43,29,43,25,233,16,75,29,44,29,9,21,232,16,233,20,8,21,166,8,166,12,41,21,199,12,200,16,165,12,195,12,98,8,130,8,162,12,196,16,229,20,39,25,38,25,197,12,72,33,164,12,72,25,227,12,233,12,9,21,231,20,37,21,71,29,3,17,100,29,102,29,101,29,69,25,4,17,194,12,226,12,3,13,105,37,6,25,103,29,231,16,47,66,121,111,89,111,87,107,55,103,55,107,122,111,122,115,120,107,88,107,153,111,120,111,176,78,144,74,78,62,143,74,201,45,110,70,143,74,54,103,86,103,51,87,175,74,142,70,77,66,234,49,233,45,201,41,202,45,169,41,10,50,43,54,203,45,12,54,13,54,11,50,69,29,70,29,227,16,195,12,234,53,235,53,134,33,135,37,168,41,69,25,101,29,102,29,102,33,194,12,227,12,36,21,3,17,3,21,2,13,35,17,67,21,162,8,194,8,66,13,98,8,36,25,226,12,35,21,104,33,165,25,140,58,230,33,40,42,170,54,70,38,169,46,235,54,167,42,134,34,166,34,230,30,6,31,206,66,83,87,5,26,2,14,68,26,201,50,236,58,169,46,15,71,38,34,131,17,138,46,203,54,70,34,66,13,5,26,135,38,233,42,39,34,45,71,13,67,236,66,136,50,79,79,205,70,170,54,135,46,7,42,73,50,137,54,66,17,199,37,164,29,204,66,106,54,165,33,132,25,11,71,234,62,10,67,196,33,205,66,8,46,110,83,71,38,47,79,114,91,139,58,74,50,229,33,41,46,200,103,232,103,233,103,143,107,138,99,203,95,107,91,202,111,232,91,72,75,238,103,140,95,169,66,202,99,200,66,102,54,5,46,6,46,99,29,76,79,176,70,206,70,235,70,77,83,196,41,195,37,136,58,103,91,135,91,204,74,45,83,13,75,12,45,2,0,2,0,2,0,2,0,2,0,2,0,2,0,96,3,224,19,224,43,233,59,238,79,243,95,248,111,222,123,175,45,110,41,142,41,174,41,174,45,207,49,208,49,207,45,141,37,109,37,10,25,77,33,76,33,110,37,76,29,108,33,109,33,43,29,43,25,233,16,75,29,44,29,9,21,232,16,233,20,8,21,166,8,166,12,41,21,199,12,200,16,165,12,195,12,98,8,130,8,162,12,196,16,229,20,39,25,38,25,197,12,72,33,164,12,72,25,227,12,233,12,9,21,231,20,37,21,71,29,3,17,100,29,102,29,101,29,69,25,4,17,194,12,226,12,3,13,105,37,6,25,103,29,231,16,47,66,121,111,89,111,87,107,55,103,55,107,122,111,122,115,120,107,88,107,153,111,120,111,176,78,144,74,78,62,143,74,201,45,110,70,143,74,54,103,86,103,51,87,175,74,142,70,77,66,234,49,233,45,201,41,202,45,169,41,10,50,43,54,203,45,12,54,13,54,11,50,69,29,70,29,227,16,195,12,234,53,235,53,134,33,135,37,168,41,69,25,101,29,102,29,102,33,194,12,227,12,36,21,3,17,3,21,2,13,35,17,67,21,162,8,194,8,66,13,98,8,36,25,226,12,35,21,104,33,165,25,140,58,230,33,40,42,170,54,70,38,169,46,235,54,167,42,134,34,166,34,230,30,6,31,206,66,83,87,5,26,2,14,68,26,201,50,236,58,169,46,15,71,38,34,131,17,138,46,203,54,70,34,66,13,5,26,135,38,233,42,39,34,45,71,13,67,236,66,136,50,79,79,205,70,170,54,135,46,7,42,73,50,137,54,66,17,199,37,164,29,204,66,106,54,165,33,132,25,11,71,234,62,10,67,196,33,205,66,8,46,110,83,71,38,47,79,114,91,139,58,74,50,229,33,41,46,200,103,232,103,233,103,143,107,138,99,203,95,107,91,202,111,232,91,72,75,238,103,140,95,169,66,202,99,200,66,102,54,5,46,6,46,99,29,76,79,176,70,206,70,235,70,77,83,196,41,195,37,136,58,103,91,135,91,204,74,45,83,13,75,145,65,2,0,2,0,2,0,2,0,2,0,2,0,2,0,192,42,0,55,160,71,192,91,228,111,239,123,251,127,222,123,175,45,110,41,142,41,174,41,174,45,207,49,208,49,207,45,141,37,109,37,10,25,77,33,76,33,110,37,76,29,108,33,109,33,43,29,43,25,233,16,75,29,44,29,9,21,232,16,233,20,8,21,166,8,166,12,41,21,199,12,200,16,165,12,195,12,98,8,130,8,162,12,196,16,229,20,39,25,38,25,197,12,72,33,164,12,72,25,227,12,233,12,9,21,231,20,37,21,71,29,3,17,100,29,102,29,101,29,69,25,4,17,194,12,226,12,3,13,105,37,6,25,103,29,231,16,47,66,121,111,89,111,87,107,55,103,55,107,122,111,122,115,120,107,88,107,153,111,120,111,176,78,144,74,78,62,143,74,201,45,110,70,143,74,54,103,86,103,51,87,175,74,142,70,77,66,234,49,233,45,201,41,202,45,169,41,10,50,43,54,203,45,12,54,13,54,11,50,69,29,70,29,227,16,195,12,234,53,235,53,134,33,135,37,168,41,69,25,101,29,102,29,102,33,194,12,227,12,36,21,3,17,3,21,2,13,35,17,67,21,162,8,194,8,66,13,98,8,36,25,226,12,35,21,104,33,165,25,140,58,230,33,40,42,170,54,70,38,169,46,235,54,167,42,134,34,166,34,230,30,6,31,206,66,83,87,5,26,2,14,68,26,201,50,236,58,169,46,15,71,38,34,131,17,138,46,203,54,70,34,66,13,5,26,135,38,233,42,39,34,45,71,13,67,236,66,136,50,79,79,205,70,170,54,135,46,7,42,73,50,137,54,66,17,199,37,164,29,204,66,106,54,165,33,132,25,11,71,234,62,10,67,196,33,205,66,8,46,110,83,71,38,47,79,114,91,139,58,74,50,229,33,41,46,200,103,232,103,233,103,143,107,138,99,203,95,107,91,202,111,232,91,72,75,238,103,140,95,169,66,202,99,200,66,102,54,5,46,6,46,99,29,76,79,176,70,206,70,235,70,77,83,196,41,195,37,136,58,103,91,135,91,204,74,45,83,13,75,12,45,2,0,2,0,2,0,2,0,2,0,2,0,2,0,28,2,190,10,30,23,95,39,159,55,191,79,191,103,222,123,175,45,110,41,142,41,174,41,174,45,207,49,208,49,207,45,141,37,109,37,10,25,77,33,76,33,110,37,76,29,108,33,109,33,43,29,43,25,233,16,75,29,44,29,9,21,232,16,233,20,8,21,166,8,166,12,41,21,199,12,200,16,165,12,195,12,98,8,130,8,162,12,196,16,229,20,39,25,38,25,197,12,72,33,164,12,72,25,227,12,233,12,9,21,231,20,37,21,71,29,3,17,100,29,102,29,101,29,69,25,4,17,194,12,226,12,3,13,105,37,6,25,103,29,231,16,47,66,121,111,89,111,87,107,55,103,55,107,122,111,122,115,120,107,88,107,153,111,120,111,176,78,144,74,78,62,143,74,201,45,110,70,143,74,54,103,86,103,51,87,175,74,142,70,77,66,234,49,233,45,201,41,202,45,169,41,10,50,43,54,203,45,12,54,13,54,11,50,69,29,70,29,227,16,195,12,234,53,235,53,134,33,135,37,168,41,69,25,101,29,102,29,102,33,194,12,227,12,36,21,3,17,3,21,2,13,35,17,67,21,162,8,194,8,66,13,98,8,36,25,226,12,35,21,104,33,165,25,140,58,230,33,40,42,170,54,70,38,169,46,235,54,167,42,134,34,166,34,230,30,6,31,206,66,83,87,5,26,2,14,68,26,201,50,236,58,169,46,15,71,38,34,131,17,138,46,203,54,70,34,66,13,5,26,135,38,233,42,39,34,45,71,13,67,236,66,136,50,79,79,205,70,170,54,135,46,7,42,73,50,137,54,66,17,199,37,164,29,204,66,106,54,165,33,132,25,11,71,234,62,10,67,196,33,205,66,8,46,110,83,71,38,47,79,114,91,139,58,74,50,229,33,41,46,200,103,232,103,233,103,143,107,138,99,203,95,107,91,202,111,232,91,72,75,238,103,140,95,169,66,202,99,200,66,102,54,5,46,6,46,99,29,76,79,176,70,206,70,235,70,77,83,196,41,195,37,136,58,103,91,135,91,204,74,45,83,13,75,179,53,224,127,31,124,0,124,31,0,255,3,31,48,31,64,31,80,31,92,31,104,31,112,95,124,255,125,159,126,222,123,1,27,160,35,192,47,224,59,224,67,192,79,192,87,224,95,224,99,224,103,224,111,238,119,243,127,250,127,252,127,255,127,32,2,96,2,128,2,192,2,224,2,32,3,64,3,128,39,160,43,224,55,224,63,64,3,224,11,224,19,163,29,67,34,47,45,224,127,5,52,5,60,9,68,7,76,7,84,10,92,9,100,9,108,9,116,207,124,21,126,186,126,93,127,222,123,255,255,179,53,224,127,31,124,0,124,31,0,255,3,31,48,31,64,31,80,31,92,31,104,31,112,95,124,255,125,159,126,222,123,161,42,36,55,166,63,224,67,232,79,196,91,197,99,235,103,235,103,237,103,240,111,243,119,247,127,250,127,252,127,255,127,32,2,96,2,128,2,192,2,224,2,32,3,64,3,128,39,160,43,224,55,224,63,64,3,224,11,224,19,163,29,67,34,255,255,211,65,209,1,21,2,119,10,185,18,251,22,60,39,93,55,94,67,127,75,127,83,159,91,159,99,191,111,223,119,255,127,255,255,145,65,17,0,22,0,26,0,29,28,30,40,29,52,30,64,30,80,30,88,30,100,31,108,95,120,95,126,63,127,222,123,255,255,145,65,0,32,0,40,0,48,0,52,0,56,0,64,0,72,0,84,0,92,33,104,132,112,41,125,82,126,57,127,222,123,255,255,145,65,32,19,64,35,96,43,128,51,160,63,160,71,193,79,192,91,226,103,228,111,230,119,239,123,244,127,251,127,222,123,255,255,4,0,11,0,0,0,50,66,248,86,141,45,255,39,255,59,255,83,255,99,31,56,31,76,31,88,31,108,31,124,31,126,191,126,222,123,175,45,110,41,142,41,174,41,174,45,207,49,208,49,207,45,141,37,109,37,10,25,77,33,76,33,110,37,76,29,108,33,109,33,43,29,43,25,233,16,75,29,44,29,9,21,232,16,233,20,8,21,166,8,166,12,41,21,199,12,200,16,165,12,195,12,98,8,130,8,162,12,196,16,229,20,39,25,38,25,197,12,72,33,164,12,72,25,227,12,233,12,9,21,231,20,37,21,71,29,3,17,100,29,102,29,101,29,69,25,4,17,194,12,226,12,3,13,105,37,6,25,103,29,231,16,47,66,121,111,89,111,87,107,55,103,55,107,122,111,122,115,120,107,88,107,153,111,120,111,176,78,144,74,78,62,143,74,201,45,110,70,143,74,54,103,86,103,51,87,175,74,142,70,77,66,234,49,233,45,201,41,202,45,169,41,10,50,43,54,203,45,12,54,13,54,11,50,69,29,70,29,227,16,195,12,234,53,235,53,134,33,135,37,168,41,69,25,101,29,102,29,102,33,194,12,227,12,36,21,3,17,3,21,2,13,35,17,67,21,162,8,194,8,66,13,98,8,36,25,226,12,35,21,104,33,165,25,140,58,230,33,40,42,170,54,70,38,169,46,235,54,167,42,134,34,166,34,230,30,6,31,206,66,83,87,5,26,2,14,68,26,201,50,236,58,169,46,15,71,38,34,131,17,138,46,203,54,70,34,66,13,5,26,135,38,233,42,39,34,45,71,13,67,236,66,136,50,79,79,205,70,170,54,135,46,7,42,73,50,137,54,66,17,199,37,164,29,204,66,106,54,165,33,132,25,11,71,234,62,10,67,196,33,205,66,8,46,110,83,71,38,47,79,114,91,139,58,74,50,229,33,41,46,200,103,232,103,233,103,143,107,138,99,203,95,107,91,202,111,232,91,72,75,238,103,140,95,169,66,202,99,200,66,102,54,5,46,6,46,99,29,76,79,176,70,206,70,235,70,77,83,196,41,195,37,136,58,103,91,135,91,204,74,45,83,13,75,74,41,2,0,2,0,2,0,2,0,2,0,2,0,2,0,31,56,31,76,31,88,30,108,30,120,31,126,191,126,222,123,175,45,110,41,142,41,174,41,174,45,207,49,208,49,207,45,141,37,109,37,10,25,77,33,76,33,110,37,76,29,108,33,109,33,43,29,43,25,233,16,75,29,44,29,9,21,232,16,233,20,8,21,166,8,166,12,41,21,199,12,200,16,165,12,195,12,98,8,130,8,162,12,196,16,229,20,39,25,38,25,197,12,72,33,164,12,72,25,227,12,233,12,9,21,231,20,37,21,71,29,3,17,100,29,102,29,101,29,69,25,4,17,194,12,226,12,3,13,105,37,6,25,103,29,231,16,47,66,121,111,89,111,87,107,55,103,55,107,122,111,122,115,120,107,88,107,153,111,120,111,176,78,144,74,78,62,143,74,201,45,110,70,143,74,54,103,86,103,51,87,175,74,142,70,77,66,234,49,233,45,201,41,202,45,169,41,10,50,43,54,203,45,12,54,13,54,11,50,69,29,70,29,227,16,195,12,234,53,235,53,134,33,135,37,168,41,69,25,101,29,102,29,102,33,194,12,227,12,36,21,3,17,3,21,2,13,35,17,67,21,162,8,194,8,66,13,98,8,36,25,226,12,35,21,104,33,165,25,140,58,230,33,40,42,170,54,70,38,169,46,235,54,167,42,134,34,166,34,230,30,6,31,206,66,83,87,5,26,2,14,68,26,201,50,236,58,169,46,15,71,38,34,131,17,138,46,203,54,70,34,66,13,5,26,135,38,233,42,39,34,45,71,13,67,236,66,136,50,79,79,205,70,170,54,135,46,7,42,73,50,137,54,66,17,199,37,164,29,204,66,106,54,165,33,132,25,11,71,234,62,10,67,196,33,205,66,8,46,110,83,71,38,47,79,114,91,139,58,74,50,229,33,41,46,200,103,232,103,233,103,143,107,138,99,203,95,107,91,202,111,232,91,72,75,238,103,140,95,169,66,202,99,200,66,102,54,5,46,6,46,99,29,76,79,176,70,206,70,235,70,77,83,196,41,195,37,136,58,103,91,135,91,204,74,45,83,13,75,12,45,2,0,2,0,2,0,2,0,2,0,2,0,2,0,96,3,224,19,224,43,233,59,238,79,243,95,248,111,222,123,175,45,110,41,142,41,174,41,174,45,207,49,208,49,207,45,141,37,109,37,10,25,77,33,76,33,110,37,76,29,108,33,109,33,43,29,43,25,233,16,75,29,44,29,9,21,232,16,233,20,8,21,166,8,166,12,41,21,199,12,200,16,165,12,195,12,98,8,130,8,162,12,196,16,229,20,39,25,38,25,197,12,72,33,164,12,72,25,227,12,233,12,9,21,231,20,37,21,71,29,3,17,100,29,102,29,101,29,69,25,4,17,194,12,226,12,3,13,105,37,6,25,103,29,231,16,47,66,121,111,89,111,87,107,55,103,55,107,122,111,122,115,120,107,88,107,153,111,120,111,176,78,144,74,78,62,143,74,201,45,110,70,143,74,54,103,86,103,51,87,175,74,142,70,77,66,234,49,233,45,201,41,202,45,169,41,10,50,43,54,203,45,12,54,13,54,11,50,69,29,70,29,227,16,195,12,234,53,235,53,134,33,135,37,168,41,69,25,101,29,102,29,102,33,194,12,227,12,36,21,3,17,3,21,2,13,35,17,67,21,162,8,194,8,66,13,98,8,36,25,226,12,35,21,104,33,165,25,140,58,230,33,40,42,170,54,70,38,169,46,235,54,167,42,134,34,166,34,230,30,6,31,206,66,83,87,5,26,2,14,68,26,201,50,236,58,169,46,15,71,38,34,131,17,138,46,203,54,70,34,66,13,5,26,135,38,233,42,39,34,45,71,13,67,236,66,136,50,79,79,205,70,170,54,135,46,7,42,73,50,137,54,66,17,199,37,164,29,204,66,106,54,165,33,132,25,11,71,234,62,10,67,196,33,205,66,8,46,110,83,71,38,47,79,114,91,139,58,74,50,229,33,41,46,200,103,232,103,233,103,143,107,138,99,203,95,107,91,202,111,232,91,72,75,238,103,140,95,169,66,202,99,200,66,102,54,5,46,6,46,99,29,76,79,176,70,206,70,235,70,77,83,196,41,195,37,136,58,103,91,135,91,204,74,45,83,13,75,145,65,2,0,2,0,2,0,2,0,2,0,2,0,2,0,192,42,0,55,160,71,192,91,228,111,239,123,251,127,222,123,175,45,110,41,142,41,174,41,174,45,207,49,208,49,207,45,141,37,109,37,10,25,77,33,76,33,110,37,76,29,108,33,109,33,43,29,43,25,233,16,75,29,44,29,9,21,232,16,233,20,8,21,166,8,166,12,41,21,199,12,200,16,165,12,195,12,98,8,130,8,162,12,196,16,229,20,39,25,38,25,197,12,72,33,164,12,72,25,227,12,233,12,9,21,231,20,37,21,71,29,3,17,100,29,102,29,101,29,69,25,4,17,194,12,226,12,3,13,105,37,6,25,103,29,231,16,47,66,121,111,89,111,87,107,55,103,55,107,122,111,122,115,120,107,88,107,153,111,120,111,176,78,144,74,78,62,143,74,201,45,110,70,143,74,54,103,86,103,51,87,175,74,142,70,77,66,234,49,233,45,201,41,202,45,169,41,10,50,43,54,203,45,12,54,13,54,11,50,69,29,70,29,227,16,195,12,234,53,235,53,134,33,135,37,168,41,69,25,101,29,102,29,102,33,194,12,227,12,36,21,3,17,3,21,2,13,35,17,67,21,162,8,194,8,66,13,98,8,36,25,226,12,35,21,104,33,165,25,140,58,230,33,40,42,170,54,70,38,169,46,235,54,167,42,134,34,166,34,230,30,6,31,206,66,83,87,5,26,2,14,68,26,201,50,236,58,169,46,15,71,38,34,131,17,138,46,203,54,70,34,66,13,5,26,135,38,233,42,39,34,45,71,13,67,236,66,136,50,79,79,205,70,170,54,135,46,7,42,73,50,137,54,66,17,199,37,164,29,204,66,106,54,165,33,132,25,11,71,234,62,10,67,196,33,205,66,8,46,110,83,71,38,47,79,114,91,139,58,74,50,229,33,41,46,200,103,232,103,233,103,143,107,138,99,203,95,107,91,202,111,232,91,72,75,238,103,140,95,169,66,202,99,200,66,102,54,5,46,6,46,99,29,76,79,176,70,206,70,235,70,77,83,196,41,195,37,136,58,103,91,135,91,204,74,45,83,13,75,12,45,2,0,2,0,2,0,2,0,2,0,2,0,2,0,28,2,190,10,30,23,95,39,159,55,191,79,191,103,222,123,175,45,110,41,142,41,174,41,174,45,207,49,208,49,207,45,141,37,109,37,10,25,77,33,76,33,110,37,76,29,108,33,109,33,43,29,43,25,233,16,75,29,44,29,9,21,232,16,233,20,8,21,166,8,166,12,41,21,199,12,200,16,165,12,195,12,98,8,130,8,162,12,196,16,229,20,39,25,38,25,197,12,72,33,164,12,72,25,227,12,233,12,9,21,231,20,37,21,71,29,3,17,100,29,102,29,101,29,69,25,4,17,194,12,226,12,3,13,105,37,6,25,103,29,231,16,47,66,121,111,89,111,87,107,55,103,55,107,122,111,122,115,120,107,88,107,153,111,120,111,176,78,144,74,78,62,143,74,201,45,110,70,143,74,54,103,86,103,51,87,175,74,142,70,77,66,234,49,233,45,201,41,202,45,169,41,10,50,43,54,203,45,12,54,13,54,11,50,69,29,70,29,227,16,195,12,234,53,235,53,134,33,135,37,168,41,69,25,101,29,102,29,102,33,194,12,227,12,36,21,3,17,3,21,2,13,35,17,67,21,162,8,194,8,66,13,98,8,36,25,226,12,35,21,104,33,165,25,140,58,230,33,40,42,170,54,70,38,169,46,235,54,167,42,134,34,166,34,230,30,6,31,206,66,83,87,5,26,2,14,68,26,201,50,236,58,169,46,15,71,38,34,131,17,138,46,203,54,70,34,66,13,5,26,135,38,233,42,39,34,45,71,13,67,236,66,136,50,79,79,205,70,170,54,135,46,7,42,73,50,137,54,66,17,199,37,164,29,204,66,106,54,165,33,132,25,11,71,234,62,10,67,196,33,205,66,8,46,110,83,71,38,47,79,114,91,139,58,74,50,229,33,41,46,200,103,232,103,233,103,143,107,138,99,203,95,107,91,202,111,232,91,72,75,238,103,140,95,169,66,202,99,200,66,102,54,5,46,6,46,99,29,76,79,176,70,206,70,235,70,77,83,196,41,195,37,136,58,103,91,135,91,204,74,45,83,13,75,179,53,224,127,31,124,0,124,31,0,255,3,31,48,31,64,31,80,31,92,31,104,31,112,95,124,255,125,159,126,222,123,1,27,160,35,192,47,224,59,224,67,192,79,192,87,224,95,224,99,224,103,224,111,238,119,243,127,250,127,252,127,255,127,32,2,96,2,128,2,192,2,224,2,32,3,64,3,128,39,160,43,224,55,224,63,64,3,224,11,224,19,163,29,67,34,47,45,224,127,5,52,5,60,9,68,7,76,7,84,10,92,9,100,9,108,9,116,207,124,21,126,186,126,93,127,222,123,255,255,179,53,224,127,31,124,0,124,31,0,255,3,31,48,31,64,31,80,31,92,31,104,31,112,95,124,255,125,159,126,222,123,161,42,36,55,166,63,224,67,232,79,196,91,197,99,235,103,235,103,237,103,240,111,243,119,247,127,250,127,252,127,255,127,32,2,96,2,128,2,192,2,224,2,32,3,64,3,128,39,160,43,224,55,224,63,64,3,224,11,224,19,163,29,67,34,255,255,211,65,209,1,21,2,119,10,185,18,251,22,60,39,93,55,94,67,127,75,127,83,159,91,159,99,191,111,223,119,255,127,255,255,145,65,17,0,22,0,26,0,29,28,30,40,29,52,30,64,30,80,30,88,30,100,31,108,95,120,95,126,63,127,222,123,255,255,145,65,0,32,0,40,0,48,0,52,0,56,0,64,0,72,0,84,0,92,33,104,132,112,41,125,82,126,57,127,222,123,255,255,145,65,32,19,64,35,96,43,128,51,160,63,160,71,193,79,192,91,226,103,228,111,230,119,239,123,244,127,251,127,222,123,255,255,11,0,220,0,188,0,214,0,188,0,172,252,192,4,192,16,0,16,1,0,192,1,224,0,42,7,8,255,2,255,0,0,3,255,170,0,138,0,160,0,134,0,219,252,192,5,128,19,128,15,0,0,224,1,240,0,45,8,220,0,188,0,214,0,188,0,200,0,168,0,214,0,156,0,200,252,192,5,64,15,192,12,1,0,96,1,176,0,33,4,170,0,138,0,160,0,134,0,190,0,158,0,194,0,168,0,191,252,192,4,0,17,0,12,1,0,128,1,192,0,36,5,200,0,168,0,214,0,156,0,160,0,128,0,220,0,196,0,162,252,192,5,192,10,128,8,1,0,160,1,208,0,39,6,190,0,158,0,194,0,168,0,210,0,178,0,202,0,176,0,181,252,192,5,0,16,0,12,1,0,64,1,160,0,30,3,160,0,128,0,220,0,196,0,240,0,208,0,244,0,220,0,144,252,192,3,0,12,192,12,1,0,0,2,0,1,48,9,210,0,178,0,202,0,176,0,180,0,148,0,172,0,148,0,210,252,192,3,0,16,0,9,1,0,0,1,128,0,24,1,240,0,208,0,244,0,220,0,230,0,198,0,232,0,208,0,154,252,192,5,0,15,192,8,1,0,32,1,144,0,27,2,180,0,148,0,172,0,148,0,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,30,178,226,71,1,0,16,1,98,100,117,45,48,50,97,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,232,150,239,123,1,0,16,1,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,209,110,197,82,1,0,16,1,98,100,45,48,52,46,57,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,236,246,106,237,1,0,16,1,98,100,45,48,53,46,49,48,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,46,183,89,174,1,0,16,1,98,100,45,48,54,46,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,116,66,245,44,2,0,16,1,98,100,45,49,53,46,50,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,120,93,23,112,3,0,32,0,98,100,45,49,50,46,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,147,73,82,196,4,0,32,0,98,100,45,49,49,46,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,111,200,50,121,4,0,32,0,98,100,45,49,52,46,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,58,89,73,220,4,0,32,0,98,100,45,49,51,46,56,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,34,161,215,126,4,0,32,0,98,100,45,48,56,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,56,116,241,226,5,0,32,0,98,100,45,48,55,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,39,189,204,95,5,0,32,0,98,100,45,49,48,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,198,204,51,252,5,0,32,0,98,100,45,48,57,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,222,73,244,5,0,32,0,98,100,48,49,46,56,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,229,89,180,41,6,0,0,8,98,100,48,50,46,57,106,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,30,116,139,6,0,0,8,98,100,48,51,46,49,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,117,28,32,39,6,0,0,8,98,100,48,52,46,49,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,104,11,73,229,6,0,0,8,98,116,105,103,101,114,49,46,102,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,232,100,132,157,1,0,16,1,98,100,117,45,48,50,97,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,232,150,239,123,1,0,16,1,98,116,105,103,101,114,51,46,106,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,209,110,197,82,1,0,16,1,98,100,45,48,52,46,57,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,236,246,106,237,1,0,16,1,98,100,45,48,53,46,49,48,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,46,183,89,174,1,0,16,1,98,100,45,48,54,46,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,116,66,245,44,2,0,16,1,98,100,45,49,53,46,50,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,120,93,23,112,3,0,32,0,98,100,45,49,50,46,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,147,73,82,196,4,0,32,0,98,100,45,49,49,46,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,111,200,50,121,4,0,32,0,98,100,45,49,52,46,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,58,89,73,220,4,0,32,0,98,100,45,49,51,46,56,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,34,161,215,126,4,0,32,0,98,100,45,48,56,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,56,116,241,226,5,0,32,0,98,100,45,48,55,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,39,189,204,95,5,0,32,0,98,100,45,49,48,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,198,204,51,252,5,0,32,0,98,100,45,48,57,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,222,73,244,5,0,32,0,98,100,48,49,46,56,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,229,89,180,41,6,0,0,8,98,100,48,50,46,57,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,30,116,139,6,0,0,8,98,100,48,51,46,49,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,117,28,32,39,6,0,0,8,98,100,48,52,46,49,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,104,11,73,229,6,0,0,8,184,40,2,0,1,0,0,0,85,0,147,0,248,191,2,0,184,164,8,0,1,0,0,0,86,0,147,0,64,246,1,0,56,210,6,0,1,0,0,0,80,0,147,0,192,135,2,0,152,122,6,0,1,0,0,0,81,0,147,0,96,82,2,0,192,72,6,0,1,0,0,0,82,0,147,0,32,56,2,0,24,163,6,0,1,0,0,0,83,0,147,0,240,108,2,0,176,223,1,0,1,0,0,0,184,247,146,0,72,198,1,0,24,198,1,0,1,0,0,0,185,247,146,0,40,167,1,0,120,189,1,0,1,0,0,0,186,247,146,0,200,149,1,0,192,209,1,0,1,0,0,0,187,247,146,0,24,182,1,0,88,212,3,0,1,0,0,0,128,219,146,0,40,185,3,0,232,75,4,0,1,0,0,0,87,0,147,0,216,70,1,0,64,23,5,0,9,0,0,0,201,5,147,0,32,58,1,0,104,20,5,0,9,0,0,0,202,5,147,0,32,58,1,0,216,16,5,0,9,0,0,0,200,5,147,0,32,58,1,0,120,116,45,56,109,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,203,87,102,74,0,0,16,1,54,35,45,51,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,237,72,254,55,0,0,32,0,53,35,45,51,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,49,192,6,90,0,0,32,0,49,35,45,50,53,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,20,205,13,118,0,0,32,0,115,110,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,82,41,99,104,0,0,16,1,114,111,109,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,99,152,212,246,0,0,64,0,50,35,45,50,53,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,110,209,109,69,0,0,32,0,168,86,7,0,1,0,0,0,115,191,145,0,248,191,2,0,24,38,7,0,1,0,0,0,117,191,145,0,184,160,2,0,56,210,6,0,1,0,0,0,128,251,146,0,192,135,2,0,24,163,6,0,1,0,0,0,129,251,146,0,240,108,2,0,152,122,6,0,1,0,0,0,130,251,146,0,96,82,2,0,192,72,6,0,1,0,0,0,131,251,146,0,32,56,2,0,48,52,7,0,1,0,0,0,132,251,146,0,152,30,2,0,8,47,7,0,1,0,0,0,133,251,146,0,232,10,2,0,120,40,7,0,1,0,0,0,134,251,146,0,152,138,8,0,40,246,1,0,1,0,0,0,116,191,145,0,64,246,1,0,144,236,1,0,1,0,0,0,118,191,145,0,136,224,1,0,176,223,1,0,1,0,0,0,80,243,146,0,72,198,1,0,192,209,1,0,1,0,0,0,81,243,146,0,24,182,1,0,24,198,1,0,1,0,0,0,82,243,146,0,40,167,1,0,120,189,1,0,1,0,0,0,83,243,146,0,200,149,1,0,64,36,7,0,1,0,0,0,84,243,146,0,56,126,1,0,168,33,7,0,1,0,0,0,85,243,146,0,32,101,1,0,96,29,7,0,1,0,0,0,86,243,146,0,96,32,8,0,88,212,3,0,1,0,0,0,56,216,146,0,40,185,3,0,80,251,6,0,1,0,0,0,114,191,145,0,216,70,1,0,16,17,8,0,1,0,0,0,112,191,145,0,224,12,8,0,248,5,8,0,9,0,0,0,163,223,146,0,32,58,1,0,144,250,7,0,9,0,0,0,164,223,146,0,32,58,1,0,248,241,7,0,9,0,0,0,165,223,146,0,32,58,1,0,48,45,3,0,9,0,0,0,248,172,145,0,32,58,1,0,168,86,7,0,1,0,0,0,43,191,145,0,248,191,2,0,24,38,7,0,1,0,0,0,45,191,145,0,184,160,2,0,56,210,6,0,1,0,0,0,16,251,146,0,192,135,2,0,24,163,6,0,1,0,0,0,17,251,146,0,240,108,2,0,152,122,6,0,1,0,0,0,18,251,146,0,96,82,2,0,192,72,6,0,1,0,0,0,19,251,146,0,32,56,2,0,200,110,3,0,1,0,0,0,20,251,146,0,152,30,2,0,120,89,3,0,1,0,0,0,21,251,146,0,232,10,2,0,120,74,3,0,1,0,0,0,22,251,146,0,152,138,8,0,40,246,1,0,1,0,0,0,44,191,145,0,64,246,1,0,144,236,1,0,1,0,0,0,46,191,145,0,136,224,1,0,176,223,1,0,1,0,0,0,232,242,146,0,72,198,1,0,192,209,1,0,1,0,0,0,233,242,146,0,24,182,1,0,24,198,1,0,1,0,0,0,234,242,146,0,40,167,1,0,120,189,1,0,1,0,0,0,235,242,146,0,200,149,1,0,224,22,1,0,1,0,0,0,236,242,146,0,56,126,1,0,160,14,1,0,1,0,0,0,237,242,146,0,32,101,1,0,176,9,1,0,1,0,0,0,238,242,146,0,96,32,8,0,88,212,3,0,1,0,0,0,200,215,146,0,40,185,3,0,32,77,1,0,1,0,0,0,40,191,145,0,216,70,1,0,72,65,1,0,9,0,0,0,91,223,146,0,32,58,1,0,48,50,1,0,9,0,0,0,92,223,146,0,32,58,1,0,224,41,1,0,9,0,0,0,93,223,146,0,32,58,1,0,168,86,7,0,1,0,0,0,107,155,145,0,248,191,2,0,24,38,7,0,1,0,0,0,109,155,145,0,184,160,2,0,56,210,6,0,1,0,0,0,160,229,146,0,192,135,2,0,24,163,6,0,1,0,0,0,161,229,146,0,240,108,2,0,152,122,6,0,1,0,0,0,162,229,146,0,96,82,2,0,192,72,6,0,1,0,0,0,163,229,146,0,32,56,2,0,48,52,7,0,1,0,0,0,164,229,146,0,152,30,2,0,8,47,7,0,1,0,0,0,165,229,146,0,232,10,2,0,120,40,7,0,1,0,0,0,166,229,146,0,152,138,8,0,40,246,1,0,1,0,0,0,108,155,145,0,64,246,1,0,144,236,1,0,1,0,0,0,110,155,145,0,136,224,1,0,176,223,1,0,1,0,0,0,152,229,146,0,72,198,1,0,192,209,1,0,1,0,0,0,153,229,146,0,24,182,1,0,24,198,1,0,1,0,0,0,154,229,146,0,40,167,1,0,120,189,1,0,1,0,0,0,155,229,146,0,200,149,1,0,64,36,7,0,1,0,0,0,156,229,146,0,56,126,1,0,168,33,7,0,1,0,0,0,157,229,146,0,32,101,1,0,96,29,7,0,1,0,0,0,158,229,146,0,96,32,8,0,88,212,3,0,1,0,0,0,240,203,146,0,40,185,3,0,80,251,6,0,1,0,0,0,106,155,145,0,216,70,1,0,16,17,8,0,1,0,0,0,104,155,145,0,224,12,8,0,248,5,8,0,9,0,0,0,251,203,146,0,32,58,1,0,144,250,7,0,9,0,0,0,252,203,146,0,32,58,1,0,248,241,7,0,9,0,0,0,253,203,146,0,32,58,1,0,48,45,3,0,9,0,0,0,96,155,145,0,32,58,1,0,0,0,0,0,0,0,0,0,27,0,0,0,255,255,2,0,0,0,0,0,0,0,0,0,168,86,7,0,1,0,0,0,253,0,147,0,248,191,2,0,120,248,6,0,1,0,0,0,248,0,147,0,184,160,2,0,56,210,6,0,1,0,0,0,88,248,146,0,192,135,2,0,24,163,6,0,1,0,0,0,89,248,146,0,240,108,2,0,200,110,3,0,1,0,0,0,80,240,146,0,152,30,2,0,48,245,6,0,1,0,0,0,249,0,147,0,136,224,1,0,176,223,1,0,1,0,0,0,92,248,146,0,64,98,7,0,192,209,1,0,1,0,0,0,93,248,146,0,24,182,1,0,224,22,1,0,1,0,0,0,80,237,146,0,56,126,1,0,88,212,3,0,1,0,0,0,64,220,146,0,40,185,3,0,248,5,8,0,9,0,0,0,96,6,147,0,32,58,1,0,144,250,7,0,9,0,0,0,97,6,147,0,32,58,1,0,168,86,7,0,1,0,0,0,136,239,146,0,248,191,2,0,24,38,7,0,1,0,0,0,223,254,146,0,184,160,2,0,200,110,3,0,1,0,0,0,220,254,146,0,248,174,1,0,120,89,3,0,1,0,0,0,221,254,146,0,104,160,1,0,240,251,8,0,4,0,0,0,8,8,147,0,152,210,1,0,176,223,8,0,4,0,0,0,12,8,147,0,208,189,1,0,40,246,1,0,1,0,0,0,137,239,146,0,64,246,1,0,144,236,1,0,1,0,0,0,127,246,146,0,136,224,1,0,224,22,1,0,1,0,0,0,124,246,146,0,56,126,1,0,160,14,1,0,1,0,0,0,125,246,146,0,32,101,1,0,112,188,8,0,4,0,0,0,16,8,147,0,136,7,4,0,192,123,8,0,4,0,0,0,20,8,147,0,136,113,1,0,88,212,3,0,1,0,0,0,160,218,146,0,40,185,3,0,16,17,8,0,1,0,0,0,138,239,146,0,224,12,8,0,72,65,1,0,9,0,0,0,48,5,147,0,32,58,1,0,48,50,1,0,9,0,0,0,49,5,147,0,32,58,1,0,224,41,1,0,9,0,0,0,50,5,147,0,32,58,1,0,228,0,0,0,194,42,0,0,144,1,0,0,34,5,0,0,24,12,0,0,88,13,0,0,140,40,0,0,216,6,0,0,146,36,0,0,48,6,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,86,7,0,1,0,0,0,190,252,146,0,248,191,2,0,24,38,7,0,1,0,0,0,110,244,146,0,184,160,2,0,56,210,6,0,1,0,0,0,184,252,146,0,192,135,2,0,24,163,6,0,1,0,0,0,185,252,146,0,240,108,2,0,152,122,6,0,1,0,0,0,187,252,146,0,96,82,2,0,192,72,6,0,1,0,0,0,186,252,146,0,32,56,2,0,200,110,3,0,1,0,0,0,188,252,146,0,152,30,2,0,120,89,3,0,1,0,0,0,189,252,146,0,232,10,2,0,40,246,1,0,1,0,0,0,191,252,146,0,64,246,1,0,144,236,1,0,1,0,0,0,111,244,146,0,136,224,1,0,176,223,1,0,1,0,0,0,104,244,146,0,72,198,1,0,192,209,1,0,1,0,0,0,105,244,146,0,24,182,1,0,24,198,1,0,1,0,0,0,107,244,146,0,40,167,1,0,120,189,1,0,1,0,0,0,106,244,146,0,200,149,1,0,224,22,1,0,1,0,0,0,108,244,146,0,56,126,1,0,160,14,1,0,1,0,0,0,109,244,146,0,32,101,1,0,88,212,3,0,1,0,0,0,32,217,146,0,40,185,3,0,216,85,2,0,9,0,0,0,72,4,147,0,32,58,1,0,56,250,6,0,1,0,0,0,47,0,147,0,184,160,2,0,88,149,7,0,1,0,0,0,151,247,146,0,136,224,1,0,248,23,7,0,1,0,0,0,150,247,146,0,144,189,1,0,168,86,7,0,1,0,0,0,209,239,146,0,248,191,2,0,56,210,6,0,1,0,0,0,42,0,147,0,192,135,2,0,24,163,6,0,1,0,0,0,43,0,147,0,240,108,2,0,152,122,6,0,1,0,0,0,41,0,147,0,96,82,2,0,192,72,6,0,1,0,0,0,40,0,147,0,32,56,2,0,200,110,3,0,1,0,0,0,44,0,147,0,152,30,2,0,120,89,3,0,1,0,0,0,45,0,147,0,232,10,2,0,40,246,1,0,1,0,0,0,210,239,146,0,64,246,1,0,176,223,1,0,1,0,0,0,146,247,146,0,72,198,1,0,192,209,1,0,1,0,0,0,147,247,146,0,24,182,1,0,24,198,1,0,1,0,0,0,145,247,146,0,40,167,1,0,120,189,1,0,1,0,0,0,144,247,146,0,200,149,1,0,224,22,1,0,1,0,0,0,148,247,146,0,56,126,1,0,160,14,1,0,1,0,0,0,149,247,146,0,32,101,1,0,88,212,3,0,1,0,0,0,104,219,146,0,40,185,3,0,16,17,8,0,1,0,0,0,211,239,146,0,224,12,8,0,72,65,1,0,9,0,0,0,176,5,147,0,32,58,1,0,48,50,1,0,9,0,0,0,177,5,147,0,32,58,1,0,168,86,7,0,1,0,0,0,136,239,146,0,248,191,2,0,24,38,7,0,1,0,0,0,223,254,146,0,184,160,2,0,56,210,6,0,1,0,0,0,218,254,146,0,192,135,2,0,24,163,6,0,1,0,0,0,219,254,146,0,240,108,2,0,152,122,6,0,1,0,0,0,216,254,146,0,96,82,2,0,192,72,6,0,1,0,0,0,217,254,146,0,32,56,2,0,200,110,3,0,1,0,0,0,220,254,146,0,152,30,2,0,120,89,3,0,1,0,0,0,221,254,146,0,232,10,2,0,120,74,3,0,1,0,0,0,221,254,146,0,152,138,8,0,40,246,1,0,1,0,0,0,137,239,146,0,64,246,1,0,144,236,1,0,1,0,0,0,127,246,146,0,136,224,1,0,176,223,1,0,1,0,0,0,122,246,146,0,72,198,1,0,192,209,1,0,1,0,0,0,123,246,146,0,24,182,1,0,24,198,1,0,1,0,0,0,120,246,146,0,40,167,1,0,120,189,1,0,1,0,0,0,121,246,146,0,200,149,1,0,224,22,1,0,1,0,0,0,124,246,146,0,56,126,1,0,160,14,1,0,1,0,0,0,125,246,146,0,32,101,1,0,176,9,1,0,1,0,0,0,125,246,146,0,96,32,8,0,88,212,3,0,1,0,0,0,160,218,146,0,40,185,3,0,16,17,8,0,1,0,0,0,138,239,146,0,224,12,8,0,56,58,1,0,1,0,0,0,139,239,146,0,64,50,1,0,72,65,1,0,9,0,0,0,48,5,147,0,32,58,1,0,48,50,1,0,9,0,0,0,49,5,147,0,32,58,1,0,224,41,1,0,9,0,0,0,50,5,147,0,32,58,1,0,168,86,7,0,1,0,0,0,152,242,146,0,248,191,2,0,24,38,7,0,1,0,0,0,199,250,146,0,184,160,2,0,56,210,6,0,1,0,0,0,192,250,146,0,192,135,2,0,24,163,6,0,1,0,0,0,193,250,146,0,240,108,2,0,152,122,6,0,1,0,0,0,194,250,146,0,96,82,2,0,192,72,6,0,1,0,0,0,195,250,146,0,32,56,2,0,200,110,3,0,1,0,0,0,196,250,146,0,152,30,2,0,120,89,3,0,1,0,0,0,197,250,146,0,232,10,2,0,40,246,1,0,1,0,0,0,153,242,146,0,64,246,1,0,144,236,1,0,1,0,0,0,207,250,146,0,136,224,1,0,176,223,1,0,1,0,0,0,200,250,146,0,72,198,1,0,192,209,1,0,1,0,0,0,201,250,146,0,24,182,1,0,24,198,1,0,1,0,0,0,202,250,146,0,40,167,1,0,120,189,1,0,1,0,0,0,203,250,146,0,200,149,1,0,224,22,1,0,1,0,0,0,204,250,146,0,56,126,1,0,160,14,1,0,1,0,0,0,205,250,146,0,32,101,1,0,88,212,3,0,1,0,0,0,136,215,146,0,40,185,3,0,16,17,8,0,1,0,0,0,154,242,146,0,224,12,8,0,72,65,1,0,9,0,0,0,144,3,147,0,32,58,1,0,48,50,1,0,9,0,0,0,145,3,147,0,32,58,1,0,168,86,7,0,1,0,0,0,159,2,147,0,248,191,2,0,24,38,7,0,1,0,0,0,158,2,147,0,184,160,2,0,56,210,6,0,1,0,0,0,156,2,147,0,192,135,2,0,24,163,6,0,1,0,0,0,155,2,147,0,240,108,2,0,152,122,6,0,1,0,0,0,154,2,147,0,96,82,2,0,192,72,6,0,1,0,0,0,153,2,147,0,32,56,2,0,200,110,3,0,1,0,0,0,152,2,147,0,152,30,2,0,40,246,1,0,1,0,0,0,221,249,146,0,64,246,1,0,144,236,1,0,1,0,0,0,157,2,147,0,136,224,1,0,176,223,1,0,1,0,0,0,220,249,146,0,72,198,1,0,192,209,1,0,1,0,0,0,219,249,146,0,24,182,1,0,24,198,1,0,1,0,0,0,218,249,146,0,40,167,1,0,120,189,1,0,1,0,0,0,217,249,146,0,200,149,1,0,224,22,1,0,1,0,0,0,216,249,146,0,56,126,1,0,88,212,3,0,1,0,0,0,16,222,146,0,40,185,3,0,16,17,8,0,1,0,0,0,222,249,146,0,224,12,8,0,72,65,1,0,9,0,0,0,160,7,147,0,32,58,1,0,48,50,1,0,9,0,0,0,161,7,147,0,32,58,1,0,168,86,7,0,1,0,0,0,72,254,146,0,248,191,2,0,24,38,7,0,1,0,0,0,74,254,146,0,184,160,2,0,56,210,6,0,1,0,0,0,248,245,146,0,192,135,2,0,24,163,6,0,1,0,0,0,249,245,146,0,240,108,2,0,152,122,6,0,1,0,0,0,250,245,146,0,96,82,2,0,192,72,6,0,1,0,0,0,251,245,146,0,32,56,2,0,200,110,3,0,1,0,0,0,252,245,146,0,152,30,2,0,120,89,3,0,1,0,0,0,253,245,146,0,232,10,2,0,40,246,1,0,1,0,0,0,73,254,146,0,64,246,1,0,144,236,1,0,1,0,0,0,75,254,146,0,136,224,1,0,176,223,1,0,1,0,0,0,96,239,146,0,72,198,1,0,192,209,1,0,1,0,0,0,97,239,146,0,24,182,1,0,24,198,1,0,1,0,0,0,98,239,146,0,40,167,1,0,120,189,1,0,1,0,0,0,99,239,146,0,200,149,1,0,224,22,1,0,1,0,0,0,100,239,146,0,56,126,1,0,160,14,1,0,1,0,0,0,101,239,146,0,32,101,1,0,88,212,3,0,1,0,0,0,48,218,146,0,40,185,3,0,80,251,6,0,1,0,0,0,76,254,146,0,216,70,1,0,16,17,8,0,1,0,0,0,78,254,146,0,224,12,8,0,72,65,1,0,9,0,0,0,240,4,147,0,32,58,1,0,48,50,1,0,9,0,0,0,241,4,147,0,32,58,1,0,184,40,2,0,1,0,0,0,10,151,215,0,248,191,2,0,56,250,6,0,1,0,0,0,12,151,215,0,184,160,2,0,184,164,8,0,1,0,0,0,11,151,215,0,64,246,1,0,88,149,7,0,1,0,0,0,13,151,215,0,136,224,1,0,56,210,6,0,1,0,0,0,0,151,215,0,192,135,2,0,24,163,6,0,1,0,0,0,1,151,215,0,240,108,2,0,152,122,6,0,1,0,0,0,2,151,215,0,96,82,2,0,192,72,6,0,1,0,0,0,3,151,215,0,32,56,2,0,48,123,2,0,1,0,0,0,252,150,215,0,152,30,2,0,96,69,2,0,1,0,0,0,253,150,215,0,232,10,2,0,144,55,2,0,1,0,0,0,14,151,215,0,152,138,8,0,176,223,1,0,1,0,0,0,4,151,215,0,72,198,1,0,192,209,1,0,1,0,0,0,5,151,215,0,24,182,1,0,24,198,1,0,1,0,0,0,6,151,215,0,40,167,1,0,120,189,1,0,1,0,0,0,7,151,215,0,200,149,1,0,248,187,8,0,1,0,0,0,254,150,215,0,56,126,1,0,184,179,8,0,1,0,0,0,255,150,215,0,32,101,1,0,240,173,8,0,1,0,0,0,15,151,215,0,96,32,8,0,88,212,3,0,1,0,0,0,200,147,215,0,40,185,3,0,16,17,8,0,1,0,0,0,8,151,215,0,224,12,8,0,56,58,1,0,1,0,0,0,9,151,215,0,64,50,1,0,72,4,1,0,1,0,0,0,251,150,215,0,64,255,0,0,248,5,8,0,9,0,0,0,24,151,215,0,32,58,1,0,144,250,7,0,9,0,0,0,25,151,215,0,32,58,1,0,184,40,2,0,1,0,0,0,40,39,216,0,248,191,2,0,56,250,6,0,1,0,0,0,32,39,216,0,184,160,2,0,184,164,8,0,1,0,0,0,41,39,216,0,64,246,1,0,88,149,7,0,1,0,0,0,33,39,216,0,136,224,1,0,240,167,7,0,1,0,0,0,47,39,216,0,192,135,2,0,176,163,7,0,1,0,0,0,46,39,216,0,240,108,2,0,208,158,7,0,1,0,0,0,42,39,216,0,96,82,2,0,184,154,7,0,1,0,0,0,43,39,216,0,32,56,2,0,176,108,2,0,1,0,0,0,44,39,216,0,152,30,2,0,8,96,7,0,1,0,0,0,41,39,216,0,72,198,1,0,48,89,7,0,1,0,0,0,37,39,216,0,24,182,1,0,16,83,7,0,1,0,0,0,34,39,216,0,40,167,1,0,96,79,7,0,1,0,0,0,35,39,216,0,200,149,1,0,48,76,7,0,1,0,0,0,36,39,216,0,56,126,1,0,88,212,3,0,1,0,0,0,48,38,216,0,40,185,3,0,248,5,8,0,9,0,0,0,112,39,216,0,32,58,1,0,144,250,7,0,9,0,0,0,113,39,216,0,32,58,1,0,248,241,7,0,9,0,0,0,114,39,216,0,32,58,1,0,168,86,7,0,1,0,0,0,122,151,215,0,248,191,2,0,24,38,7,0,1,0,0,0,126,151,215,0,184,160,2,0,56,210,6,0,1,0,0,0,136,151,215,0,192,135,2,0,24,163,6,0,1,0,0,0,137,151,215,0,240,108,2,0,152,122,6,0,1,0,0,0,138,151,215,0,96,82,2,0,192,72,6,0,1,0,0,0,139,151,215,0,32,56,2,0,200,110,3,0,1,0,0,0,140,151,215,0,152,30,2,0,120,89,3,0,1,0,0,0,141,151,215,0,232,10,2,0,120,74,3,0,1,0,0,0,142,151,215,0,152,138,8,0,40,246,1,0,1,0,0,0,123,151,215,0,64,246,1,0,144,236,1,0,1,0,0,0,127,151,215,0,136,224,1,0,176,223,1,0,1,0,0,0,128,151,215,0,72,198,1,0,192,209,1,0,1,0,0,0,129,151,215,0,24,182,1,0,24,198,1,0,1,0,0,0,130,151,215,0,40,167,1,0,120,189,1,0,1,0,0,0,131,151,215,0,200,149,1,0,224,22,1,0,1,0,0,0,132,151,215,0,56,126,1,0,160,14,1,0,1,0,0,0,133,151,215,0,32,101,1,0,88,212,3,0,1,0,0,0,200,147,215,0,40,185,3,0,16,17,8,0,1,0,0,0,121,151,215,0,224,12,8,0,56,58,1,0,1,0,0,0,120,151,215,0,64,50,1,0,72,65,1,0,9,0,0,0,152,151,215,0,32,58,1,0,48,50,1,0,9,0,0,0,153,151,215,0,32,58,1,0,130,0,0,0,226,29,0,0,184,4,0,0,236,6,0,0,200,19,0,0,6,5,0,0,116,35,0,0,150,13,0,0,140,7,0,0,6,8,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,168,86,7,0,1,0,0,0,111,2,147,0,248,191,2,0,24,38,7,0,1,0,0,0,168,236,146,0,184,160,2,0,56,210,6,0,1,0,0,0,106,2,147,0,192,135,2,0,24,163,6,0,1,0,0,0,107,2,147,0,240,108,2,0,152,122,6,0,1,0,0,0,105,2,147,0,96,82,2,0,192,72,6,0,1,0,0,0,104,2,147,0,32,56,2,0,200,110,3,0,1,0,0,0,108,2,147,0,152,30,2,0,120,89,3,0,1,0,0,0,109,2,147,0,232,10,2,0,40,246,1,0,1,0,0,0,175,249,146,0,64,246,1,0,144,236,1,0,1,0,0,0,169,236,146,0,136,224,1,0,176,223,1,0,1,0,0,0,170,249,146,0,72,198,1,0,192,209,1,0,1,0,0,0,171,249,146,0,24,182,1,0,24,198,1,0,1,0,0,0,169,249,146,0,40,167,1,0,120,189,1,0,1,0,0,0,168,249,146,0,200,149,1,0,224,22,1,0,1,0,0,0,172,249,146,0,56,126,1,0,160,14,1,0,1,0,0,0,173,249,146,0,32,101,1,0,88,212,3,0,1,0,0,0,208,221,146,0,40,185,3,0,32,77,1,0,1,0,0,0,24,236,146,0,216,70,1,0,16,17,8,0,1,0,0,0,172,236,146,0,224,12,8,0,168,86,7,0,1,0,0,0,111,2,147,0,248,191,2,0,56,210,6,0,1,0,0,0,106,2,147,0,192,135,2,0,24,163,6,0,1,0,0,0,107,2,147,0,240,108,2,0,152,122,6,0,1,0,0,0,105,2,147,0,96,82,2,0,192,72,6,0,1,0,0,0,104,2,147,0,32,56,2,0,200,110,3,0,1,0,0,0,108,2,147,0,152,30,2,0,120,89,3,0,1,0,0,0,109,2,147,0,232,10,2,0,40,246,1,0,1,0,0,0,175,249,146,0,64,246,1,0,176,223,1,0,1,0,0,0,170,249,146,0,72,198,1,0,192,209,1,0,1,0,0,0,171,249,146,0,24,182,1,0,24,198,1,0,1,0,0,0,169,249,146,0,40,167,1,0,120,189,1,0,1,0,0,0,168,249,146,0,200,149,1,0,224,22,1,0,1,0,0,0,172,249,146,0,56,126,1,0,160,14,1,0,1,0,0,0,173,249,146,0,32,101,1,0,168,132,8,0,1,0,0,0,143,241,146,0,232,209,1,0,192,122,8,0,1,0,0,0,138,241,146,0,208,174,1,0,40,116,8,0,1,0,0,0,139,241,146,0,48,160,1,0,72,110,8,0,1,0,0,0,137,241,146,0,160,140,1,0,184,102,8,0,1,0,0,0,136,241,146,0,56,112,1,0,248,67,8,0,1,0,0,0,140,241,146,0,32,92,1,0,136,64,8,0,1,0,0,0,141,241,146,0,64,77,1,0,232,23,8,0,1,0,0,0,183,237,146,0,104,195,5,0,248,16,8,0,1,0,0,0,178,237,146,0,32,231,8,0,192,12,8,0,1,0,0,0,179,237,146,0,88,214,8,0,224,5,8,0,1,0,0,0,177,237,146,0,224,202,8,0,144,1,8,0,1,0,0,0,176,237,146,0,72,193,8,0,176,222,7,0,1,0,0,0,180,237,146,0,144,180,8,0,176,218,7,0,1,0,0,0,181,237,146,0,208,164,8,0,88,212,3,0,1,0,0,0,208,221,146,0,40,185,3,0,32,77,1,0,1,0,0,0,24,236,146,0,216,70,1,0,168,86,7,0,1,0,0,0,16,242,146,0,248,191,2,0,24,38,7,0,1,0,0,0,63,250,146,0,184,160,2,0,56,210,6,0,1,0,0,0,56,250,146,0,192,135,2,0,24,163,6,0,1,0,0,0,57,250,146,0,240,108,2,0,152,122,6,0,1,0,0,0,58,250,146,0,96,82,2,0,192,72,6,0,1,0,0,0,59,250,146,0,32,56,2,0,200,110,3,0,1,0,0,0,60,250,146,0,152,30,2,0,120,89,3,0,1,0,0,0,61,250,146,0,232,10,2,0,40,246,1,0,1,0,0,0,17,242,146,0,64,246,1,0,144,236,1,0,1,0,0,0,71,250,146,0,136,224,1,0,176,223,1,0,1,0,0,0,64,250,146,0,72,198,1,0,192,209,1,0,1,0,0,0,65,250,146,0,24,182,1,0,24,198,1,0,1,0,0,0,66,250,146,0,40,167,1,0,120,189,1,0,1,0,0,0,67,250,146,0,200,149,1,0,224,22,1,0,1,0,0,0,68,250,146,0,56,126,1,0,160,14,1,0,1,0,0,0,69,250,146,0,32,101,1,0,88,212,3,0,1,0,0,0,64,215,146,0,40,185,3,0,72,65,1,0,9,0,0,0,80,3,147,0,32,58,1,0,48,50,1,0,9,0,0,0,81,3,147,0,32,58,1,0,168,86,7,0,1,0,0,0,214,1,147,0,248,191,2,0,24,38,7,0,1,0,0,0,16,249,146,0,184,160,2,0,56,210,6,0,1,0,0,0,17,249,146,0,192,135,2,0,24,163,6,0,1,0,0,0,18,249,146,0,240,108,2,0,152,122,6,0,1,0,0,0,19,249,146,0,96,82,2,0,192,72,6,0,1,0,0,0,20,249,146,0,32,56,2,0,200,110,3,0,1,0,0,0,21,249,146,0,152,30,2,0,120,89,3,0,1,0,0,0,22,249,146,0,232,10,2,0,120,74,3,0,1,0,0,0,23,249,146,0,152,138,8,0,40,246,1,0,1,0,0,0,215,1,147,0,64,246,1,0,144,236,1,0,1,0,0,0,240,240,146,0,136,224,1,0,176,223,1,0,1,0,0,0,241,240,146,0,72,198,1,0,192,209,1,0,1,0,0,0,242,240,146,0,24,182,1,0,24,198,1,0,1,0,0,0,243,240,146,0,40,167,1,0,120,189,1,0,1,0,0,0,244,240,146,0,200,149,1,0,224,22,1,0,1,0,0,0,245,240,146,0,56,126,1,0,160,14,1,0,1,0,0,0,246,240,146,0,32,101,1,0,176,9,1,0,1,0,0,0,247,240,146,0,96,32,8,0,88,212,3,0,1,0,0,0,80,221,146,0,40,185,3,0,32,77,1,0,1,0,0,0,212,1,147,0,216,70,1,0,16,17,8,0,1,0,0,0,213,1,147,0,224,12,8,0,72,65,1,0,9,0,0,0,24,7,147,0,32,58,1,0,48,50,1,0,9,0,0,0,25,7,147,0,32,58,1,0,184,40,2,0,1,0,0,0,207,252,146,0,248,191,2,0,184,164,8,0,1,0,0,0,127,244,146,0,64,246,1,0,24,38,7,0,1,0,0,0,206,252,146,0,184,160,2,0,56,210,6,0,1,0,0,0,192,252,146,0,192,135,2,0,24,163,6,0,1,0,0,0,193,252,146,0,240,108,2,0,152,122,6,0,1,0,0,0,194,252,146,0,96,82,2,0,192,72,6,0,1,0,0,0,195,252,146,0,32,56,2,0,200,110,3,0,1,0,0,0,196,252,146,0,152,30,2,0,120,89,3,0,1,0,0,0,197,252,146,0,232,10,2,0,144,236,1,0,1,0,0,0,126,244,146,0,136,224,1,0,176,223,1,0,1,0,0,0,112,244,146,0,72,198,1,0,192,209,1,0,1,0,0,0,113,244,146,0,24,182,1,0,24,198,1,0,1,0,0,0,114,244,146,0,40,167,1,0,120,189,1,0,1,0,0,0,115,244,146,0,200,149,1,0,224,22,1,0,1,0,0,0,116,244,146,0,56,126,1,0,160,14,1,0,1,0,0,0,117,244,146,0,32,101,1,0,16,17,8,0,1,0,0,0,204,252,146,0,224,12,8,0,88,212,3,0,1,0,0,0,40,217,146,0,40,185,3,0,248,5,8,0,9,0,0,0,80,4,147,0,32,58,1,0,144,250,7,0,9,0,0,0,81,4,147,0,32,58,1,0,248,241,7,0,9,0,0,0,82,4,147,0,32,58,1,0,168,86,7,0,1,0,0,0,168,148,215,0,248,191,2,0,24,38,7,0,1,0,0,0,191,148,215,0,184,160,2,0,56,210,6,0,1,0,0,0,184,148,215,0,192,135,2,0,24,163,6,0,1,0,0,0,185,148,215,0,240,108,2,0,152,122,6,0,1,0,0,0,186,148,215,0,96,82,2,0,192,72,6,0,1,0,0,0,187,148,215,0,32,56,2,0,200,110,3,0,1,0,0,0,188,148,215,0,152,30,2,0,120,89,3,0,1,0,0,0,189,148,215,0,232,10,2,0,120,74,3,0,1,0,0,0,190,148,215,0,152,138,8,0])
.concat([40,246,1,0,1,0,0,0,169,148,215,0,64,246,1,0,144,236,1,0,1,0,0,0,183,148,215,0,136,224,1,0,176,223,1,0,1,0,0,0,176,148,215,0,72,198,1,0,192,209,1,0,1,0,0,0,177,148,215,0,24,182,1,0,24,198,1,0,1,0,0,0,178,148,215,0,40,167,1,0,120,189,1,0,1,0,0,0,179,148,215,0,200,149,1,0,224,22,1,0,1,0,0,0,180,148,215,0,56,126,1,0,160,14,1,0,1,0,0,0,181,148,215,0,32,101,1,0,176,9,1,0,1,0,0,0,182,148,215,0,96,32,8,0,88,212,3,0,1,0,0,0,200,147,215,0,40,185,3,0,16,17,8,0,1,0,0,0,170,148,215,0,224,12,8,0,56,58,1,0,1,0,0,0,171,148,215,0,64,50,1,0,248,5,8,0,9,0,0,0,96,149,215,0,32,58,1,0,144,250,7,0,9,0,0,0,97,149,215,0,32,58,1,0,168,86,7,0,1,0,0,0,216,237,146,0,248,191,2,0,24,38,7,0,1,0,0,0,39,250,146,0,184,160,2,0,56,210,6,0,1,0,0,0,32,250,146,0,192,135,2,0,24,163,6,0,1,0,0,0,33,250,146,0,240,108,2,0,152,122,6,0,1,0,0,0,34,250,146,0,96,82,2,0,192,72,6,0,1,0,0,0,35,250,146,0,32,56,2,0,200,110,3,0,1,0,0,0,36,250,146,0,152,30,2,0,120,89,3,0,1,0,0,0,37,250,146,0,232,10,2,0,120,74,3,0,1,0,0,0,38,250,146,0,152,138,8,0,40,246,1,0,1,0,0,0,217,237,146,0,64,246,1,0,144,236,1,0,1,0,0,0,255,241,146,0,136,224,1,0,176,223,1,0,1,0,0,0,248,241,146,0,72,198,1,0,192,209,1,0,1,0,0,0,249,241,146,0,24,182,1,0,24,198,1,0,1,0,0,0,250,241,146,0,40,167,1,0,120,189,1,0,1,0,0,0,251,241,146,0,200,149,1,0,224,22,1,0,1,0,0,0,252,241,146,0,56,126,1,0,160,14,1,0,1,0,0,0,253,241,146,0,32,101,1,0,176,9,1,0,1,0,0,0,254,241,146,0,96,32,8,0,88,212,3,0,1,0,0,0,40,215,146,0,40,185,3,0,16,17,8,0,1,0,0,0,218,237,146,0,224,12,8,0,72,65,1,0,9,0,0,0,64,3,147,0,32,58,1,0,48,50,1,0,9,0,0,0,65,3,147,0,32,58,1,0,184,40,2,0,1,0,0,0,139,151,215,0,248,191,2,0,56,250,6,0,1,0,0,0,131,151,215,0,184,160,2,0,184,164,8,0,1,0,0,0,138,151,215,0,64,246,1,0,192,183,7,0,4,0,0,0,104,150,215,0,208,13,4,0,48,123,2,0,1,0,0,0,135,151,215,0,152,30,2,0,96,69,2,0,1,0,0,0,143,151,215,0,232,10,2,0,144,55,2,0,1,0,0,0,128,151,215,0,152,138,8,0,80,123,7,0,1,0,0,0,132,151,215,0,48,119,7,0,112,114,7,0,1,0,0,0,133,151,215,0,112,109,7,0,96,137,7,0,1,0,0,0,141,151,215,0,24,133,7,0,128,129,7,0,1,0,0,0,134,151,215,0,72,120,6,0,120,123,7,0,1,0,0,0,142,151,215,0,88,119,7,0,88,212,3,0,1,0,0,0,200,147,215,0,40,185,3,0,16,17,8,0,1,0,0,0,140,151,215,0,224,12,8,0,56,58,1,0,1,0,0,0,130,151,215,0,64,50,1,0,248,5,8,0,9,0,0,0,152,151,215,0,32,58,1,0,144,250,7,0,9,0,0,0,153,151,215,0,32,58,1,0,168,86,7,0,1,0,0,0,136,239,146,0,248,191,2,0,24,38,7,0,1,0,0,0,223,254,146,0,184,160,2,0,56,210,6,0,1,0,0,0,218,254,146,0,192,135,2,0,24,163,6,0,1,0,0,0,219,254,146,0,240,108,2,0,152,122,6,0,1,0,0,0,216,254,146,0,96,82,2,0,192,72,6,0,1,0,0,0,217,254,146,0,32,56,2,0,200,110,3,0,1,0,0,0,220,254,146,0,152,30,2,0,120,89,3,0,1,0,0,0,221,254,146,0,232,10,2,0,40,246,1,0,1,0,0,0,137,239,146,0,64,246,1,0,144,236,1,0,1,0,0,0,127,246,146,0,136,224,1,0,176,223,1,0,1,0,0,0,122,246,146,0,72,198,1,0,192,209,1,0,1,0,0,0,123,246,146,0,24,182,1,0,24,198,1,0,1,0,0,0,120,246,146,0,40,167,1,0,120,189,1,0,1,0,0,0,121,246,146,0,200,149,1,0,224,22,1,0,1,0,0,0,124,246,146,0,56,126,1,0,160,14,1,0,1,0,0,0,125,246,146,0,32,101,1,0,88,212,3,0,1,0,0,0,160,218,146,0,40,185,3,0,16,17,8,0,1,0,0,0,140,239,146,0,224,12,8,0,56,58,1,0,1,0,0,0,141,239,146,0,64,50,1,0,72,65,1,0,9,0,0,0,48,5,147,0,32,58,1,0,48,50,1,0,9,0,0,0,49,5,147,0,32,58,1,0,224,41,1,0,9,0,0,0,50,5,147,0,32,58,1,0,184,40,2,0,1,0,0,0,41,39,216,0,248,191,2,0,56,250,6,0,1,0,0,0,32,39,216,0,184,160,2,0,88,149,7,0,1,0,0,0,33,39,216,0,136,224,1,0,240,167,7,0,1,0,0,0,47,39,216,0,192,135,2,0,176,163,7,0,1,0,0,0,37,39,216,0,240,108,2,0,208,158,7,0,1,0,0,0,42,39,216,0,96,82,2,0,184,154,7,0,1,0,0,0,43,39,216,0,32,56,2,0,176,108,2,0,1,0,0,0,44,39,216,0,152,30,2,0,88,212,3,0,1,0,0,0,48,38,216,0,40,185,3,0,248,5,8,0,9,0,0,0,112,39,216,0,32,58,1,0,144,250,7,0,9,0,0,0,113,39,216,0,32,58,1,0,248,241,7,0,9,0,0,0,114,39,216,0,32,58,1,0,0,0,8,0,0,0,24,0,0,0,0,0,0,0,16,0,168,86,7,0,1,0,0,0,62,247,146,0,248,191,2,0,24,38,7,0,1,0,0,0,56,247,146,0,184,160,2,0,56,210,6,0,1,0,0,0,187,255,146,0,192,135,2,0,24,163,6,0,1,0,0,0,186,255,146,0,240,108,2,0,152,122,6,0,1,0,0,0,185,255,146,0,96,82,2,0,192,72,6,0,1,0,0,0,184,255,146,0,32,56,2,0,200,110,3,0,1,0,0,0,188,255,146,0,152,30,2,0,120,89,3,0,1,0,0,0,189,255,146,0,232,10,2,0,40,246,1,0,1,0,0,0,63,247,146,0,64,246,1,0,144,236,1,0,1,0,0,0,57,247,146,0,136,224,1,0,176,223,1,0,1,0,0,0,195,255,146,0,72,198,1,0,192,209,1,0,1,0,0,0,194,255,146,0,24,182,1,0,24,198,1,0,1,0,0,0,193,255,146,0,40,167,1,0,120,189,1,0,1,0,0,0,192,255,146,0,200,149,1,0,224,22,1,0,1,0,0,0,196,255,146,0,56,126,1,0,160,14,1,0,1,0,0,0,197,255,146,0,32,101,1,0,88,212,3,0,1,0,0,0,24,219,146,0,40,185,3,0,72,65,1,0,9,0,0,0,120,94,147,0,32,58,1,0,48,50,1,0,9,0,0,0,121,94,147,0,32,58,1,0,184,40,2,0,1,0,0,0,122,151,215,0,248,191,2,0,56,250,6,0,1,0,0,0,143,151,215,0,184,160,2,0,184,164,8,0,1,0,0,0,123,151,215,0,64,246,1,0,88,149,7,0,1,0,0,0,135,151,215,0,136,224,1,0,56,210,6,0,1,0,0,0,136,151,215,0,192,135,2,0,24,163,6,0,1,0,0,0,137,151,215,0,240,108,2,0,152,122,6,0,1,0,0,0,138,151,215,0,96,82,2,0,192,72,6,0,1,0,0,0,139,151,215,0,32,56,2,0,48,123,2,0,1,0,0,0,140,151,215,0,152,30,2,0,96,69,2,0,1,0,0,0,141,151,215,0,232,10,2,0,144,55,2,0,1,0,0,0,142,151,215,0,152,138,8,0,176,223,1,0,1,0,0,0,128,151,215,0,72,198,1,0,192,209,1,0,1,0,0,0,129,151,215,0,24,182,1,0,24,198,1,0,1,0,0,0,130,151,215,0,40,167,1,0,120,189,1,0,1,0,0,0,131,151,215,0,200,149,1,0,248,187,8,0,1,0,0,0,132,151,215,0,56,126,1,0,184,179,8,0,1,0,0,0,133,151,215,0,32,101,1,0,240,173,8,0,1,0,0,0,134,151,215,0,96,32,8,0,88,212,3,0,1,0,0,0,200,147,215,0,40,185,3,0,16,17,8,0,1,0,0,0,121,151,215,0,224,12,8,0,56,58,1,0,1,0,0,0,120,151,215,0,64,50,1,0,248,5,8,0,9,0,0,0,152,151,215,0,32,58,1,0,144,250,7,0,9,0,0,0,153,151,215,0,32,58,1,0,168,86,7,0,1,0,0,0,240,1,147,0,248,191,2,0,24,38,7,0,1,0,0,0,243,1,147,0,184,160,2,0,56,210,6,0,1,0,0,0,50,249,146,0,192,135,2,0,24,163,6,0,1,0,0,0,51,249,146,0,240,108,2,0,152,122,6,0,1,0,0,0,48,249,146,0,96,82,2,0,192,72,6,0,1,0,0,0,49,249,146,0,32,56,2,0,200,110,3,0,1,0,0,0,52,249,146,0,152,30,2,0,120,89,3,0,1,0,0,0,53,249,146,0,232,10,2,0,40,246,1,0,1,0,0,0,241,1,147,0,64,246,1,0,144,236,1,0,1,0,0,0,244,1,147,0,136,224,1,0,176,223,1,0,1,0,0,0,18,241,146,0,72,198,1,0,192,209,1,0,1,0,0,0,19,241,146,0,24,182,1,0,24,198,1,0,1,0,0,0,16,241,146,0,40,167,1,0,120,189,1,0,1,0,0,0,17,241,146,0,200,149,1,0,224,22,1,0,1,0,0,0,20,241,146,0,56,126,1,0,160,14,1,0,1,0,0,0,21,241,146,0,32,101,1,0,88,212,3,0,1,0,0,0,104,221,146,0,40,185,3,0,16,17,8,0,1,0,0,0,242,1,147,0,224,12,8,0,72,65,1,0,9,0,0,0,48,7,147,0,32,58,1,0,48,50,1,0,9,0,0,0,49,7,147,0,32,58,1,0,224,41,1,0,9,0,0,0,50,7,147,0,32,58,1,0,168,86,7,0,1,0,0,0,224,237,146,0,248,191,2,0,24,38,7,0,1,0,0,0,95,250,146,0,184,160,2,0,56,210,6,0,1,0,0,0,88,250,146,0,192,135,2,0,24,163,6,0,1,0,0,0,89,250,146,0,240,108,2,0,152,122,6,0,1,0,0,0,90,250,146,0,96,82,2,0,192,72,6,0,1,0,0,0,91,250,146,0,32,56,2,0,200,110,3,0,1,0,0,0,92,250,146,0,152,30,2,0,120,89,3,0,1,0,0,0,93,250,146,0,232,10,2,0,40,246,1,0,1,0,0,0,225,237,146,0,64,246,1,0,144,236,1,0,1,0,0,0,103,250,146,0,136,224,1,0,176,223,1,0,1,0,0,0,96,250,146,0,72,198,1,0,192,209,1,0,1,0,0,0,97,250,146,0,24,182,1,0,24,198,1,0,1,0,0,0,98,250,146,0,40,167,1,0,120,189,1,0,1,0,0,0,99,250,146,0,200,149,1,0,224,22,1,0,1,0,0,0,100,250,146,0,56,126,1,0,160,14,1,0,1,0,0,0,101,250,146,0,32,101,1,0,168,132,8,0,1,0,0,0,55,242,146,0,232,209,1,0,192,122,8,0,1,0,0,0,48,242,146,0,208,174,1,0,40,116,8,0,1,0,0,0,49,242,146,0,48,160,1,0,72,110,8,0,1,0,0,0,50,242,146,0,160,140,1,0,184,102,8,0,1,0,0,0,51,242,146,0,56,112,1,0,248,67,8,0,1,0,0,0,52,242,146,0,32,92,1,0,136,64,8,0,1,0,0,0,53,242,146,0,64,77,1,0,232,23,8,0,1,0,0,0,63,242,146,0,104,195,5,0,248,16,8,0,1,0,0,0,56,242,146,0,32,231,8,0,192,12,8,0,1,0,0,0,57,242,146,0,88,214,8,0,224,5,8,0,1,0,0,0,58,242,146,0,224,202,8,0,144,1,8,0,1,0,0,0,59,242,146,0,72,193,8,0,176,222,7,0,1,0,0,0,60,242,146,0,144,180,8,0,176,218,7,0,1,0,0,0,61,242,146,0,208,164,8,0,88,212,3,0,1,0,0,0,80,215,146,0,40,185,3,0,16,17,8,0,1,0,0,0,226,237,146,0,224,12,8,0,72,65,1,0,9,0,0,0,96,3,147,0,32,58,1,0,48,50,1,0,9,0,0,0,97,3,147,0,32,58,1,0,184,40,2,0,1,0,0,0,214,155,215,0,248,191,2,0,56,250,6,0,1,0,0,0,211,155,215,0,184,160,2,0,184,164,8,0,1,0,0,0,215,155,215,0,64,246,1,0,8,3,3,0,4,0,0,0,112,156,215,0,208,13,4,0,248,230,7,0,4,0,0,0,104,156,215,0,184,198,5,0,184,171,7,0,4,0,0,0,96,156,215,0,136,191,7,0,208,193,8,0,1,0,0,0,212,155,215,0,152,30,2,0,112,179,7,0,1,0,0,0,213,155,215,0,232,10,2,0,16,17,8,0,1,0,0,0,210,155,215,0,224,12,8,0,32,77,1,0,1,0,0,0,209,155,215,0,216,70,1,0,88,212,3,0,1,0,0,0,200,154,215,0,40,185,3,0,248,5,8,0,9,0,0,0,0,156,215,0,32,58,1,0,144,250,7,0,9,0,0,0,1,156,215,0,32,58,1,0,168,86,7,0,1,0,0,0,96,253,146,0,248,191,2,0,24,38,7,0,1,0,0,0,99,253,146,0,184,160,2,0,56,210,6,0,1,0,0,0,254,238,146,0,192,135,2,0,24,163,6,0,1,0,0,0,253,238,146,0,240,108,2,0,152,122,6,0,1,0,0,0,252,238,146,0,96,82,2,0,192,72,6,0,1,0,0,0,251,238,146,0,32,56,2,0,200,110,3,0,1,0,0,0,249,238,146,0,152,30,2,0,120,89,3,0,1,0,0,0,250,238,146,0,232,10,2,0,120,74,3,0,1,0,0,0,255,238,146,0,152,138,8,0,40,246,1,0,1,0,0,0,97,253,146,0,64,246,1,0,144,236,1,0,1,0,0,0,100,253,146,0,136,224,1,0,176,223,1,0,1,0,0,0,6,239,146,0,72,198,1,0,192,209,1,0,1,0,0,0,5,239,146,0,24,182,1,0,24,198,1,0,1,0,0,0,4,239,146,0,40,167,1,0,120,189,1,0,1,0,0,0,3,239,146,0,200,149,1,0,224,22,1,0,1,0,0,0,1,239,146,0,56,126,1,0,160,14,1,0,1,0,0,0,2,239,146,0,32,101,1,0,88,212,3,0,1,0,0,0,152,217,146,0,40,185,3,0,16,17,8,0,1,0,0,0,98,253,146,0,224,12,8,0,72,65,1,0,9,0,0,0,144,4,147,0,32,58,1,0,48,50,1,0,9,0,0,0,145,4,147,0,32,58,1,0,101,112,114,45,54,55,51,57,46,49,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,105,126,163,129,0,0,16,1,101,112,114,45,54,55,52,48,46,49,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,169,136,83,113,0,0,16,1,101,112,114,45,54,55,52,49,46,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,95,79,167,229,0,0,16,1,101,112,114,45,54,55,52,56,46,49,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,207,161,37,147,0,0,16,1,49,49,46,114,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,247,170,215,85,0,0,32,0,49,48,46,114,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,61,8,165,82,0,0,32,0,57,46,114,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,163,211,118,128,0,0,32,0,101,112,114,45,54,55,51,53,46,49,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,151,90,227,27,0,0,32,0,101,112,114,45,54,55,51,55,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,122,170,83,107,0,0,32,0,101,112,114,45,54,55,51,54,46,49,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,208,37,92,86,0,0,32,0,101,112,114,45,54,55,51,56,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,95,40,22,225,0,0,32,0,112,114,45,53,51,49,55,46,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,184,80,131,100,0,0,0,8,168,86,7,0,1,0,0,0,96,253,146,0,248,191,2,0,24,38,7,0,1,0,0,0,99,253,146,0,184,160,2,0,56,210,6,0,1,0,0,0,19,245,146,0,192,135,2,0,24,163,6,0,1,0,0,0,18,245,146,0,240,108,2,0,152,122,6,0,1,0,0,0,17,245,146,0,96,82,2,0,192,72,6,0,1,0,0,0,16,245,146,0,32,56,2,0,200,110,3,0,1,0,0,0,20,245,146,0,152,30,2,0,120,89,3,0,1,0,0,0,21,245,146,0,232,10,2,0,120,74,3,0,1,0,0,0,22,245,146,0,152,138,8,0,40,246,1,0,1,0,0,0,97,253,146,0,64,246,1,0,144,236,1,0,1,0,0,0,100,253,146,0,136,224,1,0,176,223,1,0,1,0,0,0,27,245,146,0,72,198,1,0,192,209,1,0,1,0,0,0,26,245,146,0,24,182,1,0,24,198,1,0,1,0,0,0,25,245,146,0,40,167,1,0,120,189,1,0,1,0,0,0,24,245,146,0,200,149,1,0,224,22,1,0,1,0,0,0,28,245,146,0,56,126,1,0,160,14,1,0,1,0,0,0,29,245,146,0,32,101,1,0,176,9,1,0,1,0,0,0,30,245,146,0,96,32,8,0,88,212,3,0,1,0,0,0,152,217,146,0,40,185,3,0,16,17,8,0,1,0,0,0,98,253,146,0,224,12,8,0,72,65,1,0,9,0,0,0,144,4,147,0,32,58,1,0,48,50,1,0,9,0,0,0,145,4,147,0,32,58,1,0,184,40,2,0,1,0,0,0,40,39,216,0,248,191,2,0,48,65,1,0,1,0,0,0,32,39,216,0,184,160,2,0,184,164,8,0,1,0,0,0,41,39,216,0,64,246,1,0,88,149,7,0,1,0,0,0,33,39,216,0,136,224,1,0,240,167,7,0,1,0,0,0,47,39,216,0,192,135,2,0,176,163,7,0,1,0,0,0,46,39,216,0,240,108,2,0,208,158,7,0,1,0,0,0,42,39,216,0,96,82,2,0,184,154,7,0,1,0,0,0,43,39,216,0,32,56,2,0,176,108,2,0,1,0,0,0,44,39,216,0,152,30,2,0,8,96,7,0,1,0,0,0,39,39,216,0,72,198,1,0,48,89,7,0,1,0,0,0,38,39,216,0,24,182,1,0,16,83,7,0,1,0,0,0,34,39,216,0,40,167,1,0,96,79,7,0,1,0,0,0,35,39,216,0,200,149,1,0,48,76,7,0,1,0,0,0,36,39,216,0,56,126,1,0,88,212,3,0,1,0,0,0,48,38,216,0,40,185,3,0,248,5,8,0,9,0,0,0,112,39,216,0,32,58,1,0,144,250,7,0,9,0,0,0,113,39,216,0,32,58,1,0,248,241,7,0,9,0,0,0,114,39,216,0,32,58,1,0,184,40,2,0,1,0,0,0,47,39,216,0,248,191,2,0,56,250,6,0,1,0,0,0,24,39,216,0,184,160,2,0,184,164,8,0,1,0,0,0,46,39,216,0,64,246,1,0,88,149,7,0,1,0,0,0,30,39,216,0,136,224,1,0,240,167,7,0,1,0,0,0,42,39,216,0,192,135,2,0,176,163,7,0,1,0,0,0,43,39,216,0,240,108,2,0,208,158,7,0,1,0,0,0,45,39,216,0,96,82,2,0,184,154,7,0,1,0,0,0,44,39,216,0,32,56,2,0,176,108,2,0,1,0,0,0,41,39,216,0,152,30,2,0,128,98,2,0,1,0,0,0,40,39,216,0,232,10,2,0,8,96,7,0,1,0,0,0,34,39,216,0,72,198,1,0,48,89,7,0,1,0,0,0,35,39,216,0,24,182,1,0,16,83,7,0,1,0,0,0,37,39,216,0,40,167,1,0,96,79,7,0,1,0,0,0,36,39,216,0,200,149,1,0,48,76,7,0,1,0,0,0,39,39,216,0,56,126,1,0,144,72,7,0,1,0,0,0,38,39,216,0,32,101,1,0,88,212,3,0,1,0,0,0,48,38,216,0,40,185,3,0,248,5,8,0,9,0,0,0,112,39,216,0,32,58,1,0,144,250,7,0,9,0,0,0,113,39,216,0,32,58,1,0,248,241,7,0,9,0,0,0,114,39,216,0,32,58,1,0,168,86,7,0,1,0,0,0,176,238,146,0,248,191,2,0,24,38,7,0,1,0,0,0,178,238,146,0,184,160,2,0,56,210,6,0,1,0,0,0,208,252,146,0,192,135,2,0,24,163,6,0,1,0,0,0,209,252,146,0,240,108,2,0,152,122,6,0,1,0,0,0,210,252,146,0,96,82,2,0,192,72,6,0,1,0,0,0,211,252,146,0,32,56,2,0,200,110,3,0,1,0,0,0,212,252,146,0,152,30,2,0,120,89,3,0,1,0,0,0,213,252,146,0,232,10,2,0,120,74,3,0,1,0,0,0,214,252,146,0,152,138,8,0,40,246,1,0,1,0,0,0,177,238,146,0,64,246,1,0,144,236,1,0,1,0,0,0,179,238,146,0,136,224,1,0,176,223,1,0,1,0,0,0,128,244,146,0,72,198,1,0,192,209,1,0,1,0,0,0,129,244,146,0,24,182,1,0,24,198,1,0,1,0,0,0,130,244,146,0,40,167,1,0,120,189,1,0,1,0,0,0,131,244,146,0,200,149,1,0,224,22,1,0,1,0,0,0,132,244,146,0,56,126,1,0,160,14,1,0,1,0,0,0,133,244,146,0,32,101,1,0,176,9,1,0,1,0,0,0,134,244,146,0,96,32,8,0,88,212,3,0,1,0,0,0,48,217,146,0,40,185,3,0,16,17,8,0,1,0,0,0,182,238,146,0,224,12,8,0,56,58,1,0,1,0,0,0,181,238,146,0,64,50,1,0,72,65,1,0,9,0,0,0,56,94,147,0,32,58,1,0,48,50,1,0,9,0,0,0,57,94,147,0,32,58,1,0,224,41,1,0,9,0,0,0,58,94,147,0,32,58,1,0,48,45,3,0,9,0,0,0,59,94,147,0,32,58,1,0,0,0,0,0,32,0,0,0,64,0,0,0,96,0,0,0,128,0,0,0,160,0,0,0,192,0,0,0,224,0,0,0,4,0,0,0,0,0,0,0,12,0,0,0,8,0,0,0,20,0,0,0,16,0,0,0,28,0,0,0,24,0,0,0,184,40,2,0,1,0,0,0,208,155,215,0,248,191,2,0,56,250,6,0,1,0,0,0,212,155,215,0,184,160,2,0,184,164,8,0,1,0,0,0,209,155,215,0,64,246,1,0,88,149,7,0,1,0,0,0,213,155,215,0,136,224,1,0,56,210,6,0,1,0,0,0,205,155,215,0,192,135,2,0,24,163,6,0,1,0,0,0,204,155,215,0,240,108,2,0,152,122,6,0,1,0,0,0,207,155,215,0,96,82,2,0,192,72,6,0,1,0,0,0,206,155,215,0,32,56,2,0,48,123,2,0,1,0,0,0,200,155,215,0,152,30,2,0,96,69,2,0,1,0,0,0,201,155,215,0,232,10,2,0,144,55,2,0,1,0,0,0,202,155,215,0,152,138,8,0,176,223,1,0,1,0,0,0,197,155,215,0,72,198,1,0,192,209,1,0,1,0,0,0,196,155,215,0,24,182,1,0,24,198,1,0,1,0,0,0,199,155,215,0,40,167,1,0,120,189,1,0,1,0,0,0,198,155,215,0,200,149,1,0,248,187,8,0,1,0,0,0,192,155,215,0,56,126,1,0,184,179,8,0,1,0,0,0,193,155,215,0,32,101,1,0,240,173,8,0,1,0,0,0,194,155,215,0,96,32,8,0,16,17,8,0,1,0,0,0,211,155,215,0,224,12,8,0,0,105,5,0,1,0,0,0,214,155,215,0,128,176,7,0,32,77,1,0,1,0,0,0,210,155,215,0,216,70,1,0,88,212,3,0,1,0,0,0,200,154,215,0,40,185,3,0,248,5,8,0,9,0,0,0,0,156,215,0,32,58,1,0,144,250,7,0,9,0,0,0,1,156,215,0,32,58,1,0,184,40,2,0,1,0,0,0,56,244,146,0,248,191,2,0,184,164,8,0,1,0,0,0,57,244,146,0,64,246,1,0,24,38,7,0,1,0,0,0,58,244,146,0,184,160,2,0,56,210,6,0,1,0,0,0,120,252,146,0,192,135,2,0,24,163,6,0,1,0,0,0,121,252,146,0,240,108,2,0,152,122,6,0,1,0,0,0,122,252,146,0,96,82,2,0,192,72,6,0,1,0,0,0,123,252,146,0,32,56,2,0,200,110,3,0,1,0,0,0,124,252,146,0,152,30,2,0,120,89,3,0,1,0,0,0,125,252,146,0,232,10,2,0,120,74,3,0,1,0,0,0,126,252,146,0,152,138,8,0,144,236,1,0,1,0,0,0,59,244,146,0,136,224,1,0,176,223,1,0,1,0,0,0,128,252,146,0,72,198,1,0,192,209,1,0,1,0,0,0,129,252,146,0,24,182,1,0,24,198,1,0,1,0,0,0,130,252,146,0,40,167,1,0,120,189,1,0,1,0,0,0,131,252,146,0,200,149,1,0,224,22,1,0,1,0,0,0,132,252,146,0,56,126,1,0,160,14,1,0,1,0,0,0,133,252,146,0,32,101,1,0,176,9,1,0,1,0,0,0,134,252,146,0,96,32,8,0,16,17,8,0,1,0,0,0,60,244,146,0,224,12,8,0,88,212,3,0,1,0,0,0,0,217,146,0,40,185,3,0,168,86,7,0,1,0,0,0,82,241,146,0,248,191,2,0,24,38,7,0,1,0,0,0,48,2,147,0,184,160,2,0,56,210,6,0,1,0,0,0,49,2,147,0,192,135,2,0,24,163,6,0,1,0,0,0,50,2,147,0,240,108,2,0,152,122,6,0,1,0,0,0,51,2,147,0,96,82,2,0,192,72,6,0,1,0,0,0,52,2,147,0,32,56,2,0,200,110,3,0,1,0,0,0,53,2,147,0,152,30,2,0,120,89,3,0,1,0,0,0,54,2,147,0,232,10,2,0,40,246,1,0,1,0,0,0,83,241,146,0,64,246,1,0,144,236,1,0,1,0,0,0,112,249,146,0,136,224,1,0,176,223,1,0,1,0,0,0,113,249,146,0,72,198,1,0,192,209,1,0,1,0,0,0,114,249,146,0,24,182,1,0,24,198,1,0,1,0,0,0,115,249,146,0,40,167,1,0,120,189,1,0,1,0,0,0,116,249,146,0,200,149,1,0,224,22,1,0,1,0,0,0,117,249,146,0,56,126,1,0,160,14,1,0,1,0,0,0,118,249,146,0,32,101,1,0,88,212,3,0,1,0,0,0,160,221,146,0,40,185,3,0,16,17,8,0,1,0,0,0,80,241,146,0,224,12,8,0,80,251,6,0,1,0,0,0,81,241,146,0,216,70,1,0,72,65,1,0,9,0,0,0,80,7,147,0,32,58,1,0,48,50,1,0,9,0,0,0,81,7,147,0,32,58,1,0,224,41,1,0,9,0,0,0,82,7,147,0,32,58,1,0,184,40,2,0,1,0,0,0,96,232,148,0,248,191,2,0,56,250,6,0,1,0,0,0,223,233,148,0,184,160,2,0,88,149,7,0,1,0,0,0,31,233,148,0,136,224,1,0,56,210,6,0,1,0,0,0,216,233,148,0,192,135,2,0,24,163,6,0,1,0,0,0,217,233,148,0,240,108,2,0,152,122,6,0,1,0,0,0,218,233,148,0,96,82,2,0,192,72,6,0,1,0,0,0,219,233,148,0,32,56,2,0,48,123,2,0,1,0,0,0,220,233,148,0,152,30,2,0,96,69,2,0,1,0,0,0,221,233,148,0,232,10,2,0,144,55,2,0,1,0,0,0,222,233,148,0,152,138,8,0,176,223,1,0,1,0,0,0,24,233,148,0,72,198,1,0,192,209,1,0,1,0,0,0,25,233,148,0,24,182,1,0,24,198,1,0,1,0,0,0,26,233,148,0,40,167,1,0,120,189,1,0,1,0,0,0,27,233,148,0,200,149,1,0,248,187,8,0,1,0,0,0,28,233,148,0,56,126,1,0,184,179,8,0,1,0,0,0,29,233,148,0,32,101,1,0,240,173,8,0,1,0,0,0,30,233,148,0,96,32,8,0,88,212,3,0,1,0,0,0,192,218,146,0,40,185,3,0,248,5,8,0,9,0,0,0,112,94,147,0,32,58,1,0,168,86,7,0,1,0,0,0,48,252,146,0,248,191,2,0,24,38,7,0,1,0,0,0,52,252,146,0,184,160,2,0,56,210,6,0,1,0,0,0,242,243,146,0,192,135,2,0,24,163,6,0,1,0,0,0,243,243,146,0,240,108,2,0,152,122,6,0,1,0,0,0,241,243,146,0,96,82,2,0,192,72,6,0,1,0,0,0,240,243,146,0,32,56,2,0,200,110,3,0,1,0,0,0,244,243,146,0,152,30,2,0,120,89,3,0,1,0,0,0,245,243,146,0,232,10,2,0,40,246,1,0,1,0,0,0,49,252,146,0,64,246,1,0,144,236,1,0,1,0,0,0,53,252,146,0,136,224,1,0,176,223,1,0,1,0,0,0,122,238,146,0,72,198,1,0,192,209,1,0,1,0,0,0,123,238,146,0,24,182,1,0,24,198,1,0,1,0,0,0,121,238,146,0,40,167,1,0,120,189,1,0,1,0,0,0,120,238,146,0,200,149,1,0,224,22,1,0,1,0,0,0,124,238,146,0,56,126,1,0,160,14,1,0,1,0,0,0,125,238,146,0,32,101,1,0,88,212,3,0,1,0,0,0,208,216,146,0,40,185,3,0,16,17,8,0,1,0,0,0,51,252,146,0,224,12,8,0,72,65,1,0,9,0,0,0,8,4,147,0,32,58,1,0,48,50,1,0,9,0,0,0,9,4,147,0,32,58,1,0,168,86,7,0,1,0,0,0,0,1,147,0,248,191,2,0,24,38,7,0,1,0,0,0,2,1,147,0,184,160,2,0,56,210,6,0,1,0,0,0,100,248,146,0,192,135,2,0,24,163,6,0,1,0,0,0,101,248,146,0,240,108,2,0,152,122,6,0,1,0,0,0,97,248,146,0,96,82,2,0,192,72,6,0,1,0,0,0,96,248,146,0,32,56,2,0,200,110,3,0,1,0,0,0,98,248,146,0,152,30,2,0,120,89,3,0,1,0,0,0,99,248,146,0,232,10,2,0,88,212,3,0,1,0,0,0,72,220,146,0,40,185,3,0,72,65,1,0,9,0,0,0,104,6,147,0,32,58,1,0,48,50,1,0,9,0,0,0,105,6,147,0,32,58,1,0,168,86,7,0,1,0,0,0,168,148,215,0,248,191,2,0,24,38,7,0,1,0,0,0,191,148,215,0,184,160,2,0,56,210,6,0,1,0,0,0,184,148,215,0,192,135,2,0,24,163,6,0,1,0,0,0,185,148,215,0,240,108,2,0,152,122,6,0,1,0,0,0,186,148,215,0,96,82,2,0,192,72,6,0,1,0,0,0,187,148,215,0,32,56,2,0,200,110,3,0,1,0,0,0,188,148,215,0,152,30,2,0,120,89,3,0,1,0,0,0,189,148,215,0,232,10,2,0,40,246,1,0,1,0,0,0,169,148,215,0,64,246,1,0,144,236,1,0,1,0,0,0,183,148,215,0,136,224,1,0,176,223,1,0,1,0,0,0,176,148,215,0,72,198,1,0,192,209,1,0,1,0,0,0,177,148,215,0,24,182,1,0,24,198,1,0,1,0,0,0,178,148,215,0,40,167,1,0,120,189,1,0,1,0,0,0,179,148,215,0,200,149,1,0,224,22,1,0,1,0,0,0,180,148,215,0,56,126,1,0,160,14,1,0,1,0,0,0,181,148,215,0,32,101,1,0,88,212,3,0,1,0,0,0,200,147,215,0,40,185,3,0,16,17,8,0,1,0,0,0,170,148,215,0,224,12,8,0,56,58,1,0,1,0,0,0,171,148,215,0,64,50,1,0,248,5,8,0,9,0,0,0,96,149,215,0,32,58,1,0,144,250,7,0,9,0,0,0,97,149,215,0,32,58,1,0,184,40,2,0,1,0,0,0,175,148,215,0,248,191,2,0,56,250,6,0,1,0,0,0,183,148,215,0,184,160,2,0,184,164,8,0,1,0,0,0,174,148,215,0,64,246,1,0,152,122,6,0,1,0,0,0,161,148,215,0,96,82,2,0,192,72,6,0,1,0,0,0,162,148,215,0,32,56,2,0,232,128,5,0,1,0,0,0,160,148,215,0,152,30,2,0,96,69,2,0,1,0,0,0,182,148,215,0,232,10,2,0,144,55,2,0,1,0,0,0,180,148,215,0,152,138,8,0,80,123,7,0,1,0,0,0,181,148,215,0,48,119,7,0,112,114,7,0,1,0,0,0,176,148,215,0,112,109,7,0,88,212,3,0,1,0,0,0,200,147,215,0,40,185,3,0,16,17,8,0,1,0,0,0,173,148,215,0,224,12,8,0,184,213,3,0,1,0,0,0,172,148,215,0,216,70,1,0,184,40,2,0,1,0,0,0,47,39,216,0,248,191,2,0,56,250,6,0,1,0,0,0,41,39,216,0,184,160,2,0,184,164,8,0,1,0,0,0,46,39,216,0,64,246,1,0,88,149,7,0,1,0,0,0,40,39,216,0,136,224,1,0,240,167,7,0,1,0,0,0,42,39,216,0,192,135,2,0,176,163,7,0,1,0,0,0,43,39,216,0,240,108,2,0,208,158,7,0,1,0,0,0,45,39,216,0,96,82,2,0,184,154,7,0,1,0,0,0,44,39,216,0,32,56,2,0,176,108,2,0,1,0,0,0,35,39,216,0,152,30,2,0,128,98,2,0,1,0,0,0,38,39,216,0,232,10,2,0,88,212,3,0,1,0,0,0,48,38,216,0,40,185,3,0,248,5,8,0,9,0,0,0,112,39,216,0,32,58,1,0,144,250,7,0,9,0,0,0,113,39,216,0,32,58,1,0,248,241,7,0,9,0,0,0,114,39,216,0,32,58,1,0,168,86,7,0,1,0,0,0,192,243,146,0,248,191,2,0,24,38,7,0,1,0,0,0,255,251,146,0,184,160,2,0,56,210,6,0,1,0,0,0,248,251,146,0,192,135,2,0,24,163,6,0,1,0,0,0,249,251,146,0,240,108,2,0,152,122,6,0,1,0,0,0,250,251,146,0,96,82,2,0,192,72,6,0,1,0,0,0,251,251,146,0,32,56,2,0,200,110,3,0,1,0,0,0,252,251,146,0,152,30,2,0,120,89,3,0,1,0,0,0,253,251,146,0,232,10,2,0,40,246,1,0,1,0,0,0,193,243,146,0,64,246,1,0,144,236,1,0,1,0,0,0,7,252,146,0,136,224,1,0,176,223,1,0,1,0,0,0,0,252,146,0,72,198,1,0,192,209,1,0,1,0,0,0,1,252,146,0,24,182,1,0,24,198,1,0,1,0,0,0,2,252,146,0,40,167,1,0,120,189,1,0,1,0,0,0,3,252,146,0,200,149,1,0,224,22,1,0,1,0,0,0,4,252,146,0,56,126,1,0,160,14,1,0,1,0,0,0,5,252,146,0,32,101,1,0,88,212,3,0,1,0,0,0,160,216,146,0,40,185,3,0,72,65,1,0,9,0,0,0,176,7,147,0,32,58,1,0,48,50,1,0,9,0,0,0,177,7,147,0,32,58,1,0,72,23,4,0,1,0,0,0,254,0,147,0,248,191,2,0,120,248,6,0,1,0,0,0,248,0,147,0,184,160,2,0,192,72,6,0,1,0,0,0,90,248,146,0,32,56,2,0,152,122,6,0,1,0,0,0,91,248,146,0,96,82,2,0,200,110,3,0,1,0,0,0,80,240,146,0,152,30,2,0,48,245,6,0,1,0,0,0,249,0,147,0,136,224,1,0,120,189,1,0,1,0,0,0,94,248,146,0,200,149,1,0,24,198,1,0,1,0,0,0,95,248,146,0,40,167,1,0,224,22,1,0,1,0,0,0,80,237,146,0,56,126,1,0,88,212,3,0,1,0,0,0,64,220,146,0,40,185,3,0,248,5,8,0,9,0,0,0,96,6,147,0,32,58,1,0,184,40,2,0,1,0,0,0,40,39,216,0,248,191,2,0,56,250,6,0,1,0,0,0,32,39,216,0,184,160,2,0,88,149,7,0,1,0,0,0,33,39,216,0,136,224,1,0,240,167,7,0,1,0,0,0,47,39,216,0,192,135,2,0,176,163,7,0,1,0,0,0,46,39,216,0,240,108,2,0,208,158,7,0,1,0,0,0,42,39,216,0,96,82,2,0,184,154,7,0,1,0,0,0,43,39,216,0,32,56,2,0,8,96,7,0,1,0,0,0,41,39,216,0,72,198,1,0,48,89,7,0,1,0,0,0,37,39,216,0,24,182,1,0,16,83,7,0,1,0,0,0,34,39,216,0,40,167,1,0,96,79,7,0,1,0,0,0,35,39,216,0,200,149,1,0,88,212,3,0,1,0,0,0,48,38,216,0,40,185,3,0,248,5,8,0,9,0,0,0,112,39,216,0,32,58,1,0,144,250,7,0,9,0,0,0,113,39,216,0,32,58,1,0,248,241,7,0,9,0,0,0,114,39,216,0,32,58,1,0,184,40,2,0,1,0,0,0,72,234,148,0,248,191,2,0,56,250,6,0,1,0,0,0,143,233,148,0,184,160,2,0,184,164,8,0,1,0,0,0,73,234,148,0,64,246,1,0,88,149,7,0,1,0,0,0,207,232,148,0,136,224,1,0,56,210,6,0,1,0,0,0,138,233,148,0,192,135,2,0,24,163,6,0,1,0,0,0,139,233,148,0,240,108,2,0,152,122,6,0,1,0,0,0,136,233,148,0,96,82,2,0,192,72,6,0,1,0,0,0,137,233,148,0,32,56,2,0,48,123,2,0,1,0,0,0,140,233,148,0,152,30,2,0,96,69,2,0,1,0,0,0,141,233,148,0,232,10,2,0,176,223,1,0,1,0,0,0,202,232,148,0,72,198,1,0,192,209,1,0,1,0,0,0,203,232,148,0,24,182,1,0,24,198,1,0,1,0,0,0,200,232,148,0,40,167,1,0,120,189,1,0,1,0,0,0,201,232,148,0,200,149,1,0,248,187,8,0,1,0,0,0,204,232,148,0,56,126,1,0,184,179,8,0,1,0,0,0,205,232,148,0,32,101,1,0,88,212,3,0,1,0,0,0,248,221,146,0,40,185,3,0,56,122,5,0,1,0,0,0,76,234,148,0,224,12,8,0,0,105,5,0,1,0,0,0,77,234,148,0,128,176,7,0,32,77,1,0,1,0,0,0,231,231,148,0,216,70,1,0,168,86,7,0,1,0,0,0,96,253,146,0,248,191,2,0,24,38,7,0,1,0,0,0,99,253,146,0,184,160,2,0,56,210,6,0,1,0,0,0,19,245,146,0,192,135,2,0,24,163,6,0,1,0,0,0,18,245,146,0,240,108,2,0,152,122,6,0,1,0,0,0,17,245,146,0,96,82,2,0,192,72,6,0,1,0,0,0,16,245,146,0,32,56,2,0,200,110,3,0,1,0,0,0,20,245,146,0,152,30,2,0,120,89,3,0,1,0,0,0,21,245,146,0,232,10,2,0,40,246,1,0,1,0,0,0,97,253,146,0,64,246,1,0,144,236,1,0,1,0,0,0,100,253,146,0,136,224,1,0,176,223,1,0,1,0,0,0,27,245,146,0,72,198,1,0,192,209,1,0,1,0,0,0,26,245,146,0,24,182,1,0,24,198,1,0,1,0,0,0,25,245,146,0,40,167,1,0,120,189,1,0,1,0,0,0,24,245,146,0,200,149,1,0,224,22,1,0,1,0,0,0,28,245,146,0,56,126,1,0,160,14,1,0,1,0,0,0,29,245,146,0,32,101,1,0,88,212,3,0,1,0,0,0,152,217,146,0,40,185,3,0,72,65,1,0,9,0,0,0,144,4,147,0,32,58,1,0,48,50,1,0,9,0,0,0,145,4,147,0,32,58,1,0])
.concat([168,86,7,0,1,0,0,0,62,1,147,0,248,191,2,0,24,38,7,0,1,0,0,0,56,1,147,0,184,160,2,0,56,210,6,0,1,0,0,0,147,248,146,0,192,135,2,0,24,163,6,0,1,0,0,0,146,248,146,0,240,108,2,0,152,122,6,0,1,0,0,0,145,248,146,0,96,82,2,0,192,72,6,0,1,0,0,0,144,248,146,0,32,56,2,0,200,110,3,0,1,0,0,0,148,248,146,0,152,30,2,0,120,89,3,0,1,0,0,0,149,248,146,0,232,10,2,0,40,246,1,0,1,0,0,0,63,1,147,0,64,246,1,0,144,236,1,0,1,0,0,0,57,1,147,0,136,224,1,0,176,223,1,0,1,0,0,0,123,240,146,0,72,198,1,0,192,209,1,0,1,0,0,0,122,240,146,0,24,182,1,0,24,198,1,0,1,0,0,0,121,240,146,0,40,167,1,0,120,189,1,0,1,0,0,0,120,240,146,0,200,149,1,0,224,22,1,0,1,0,0,0,124,240,146,0,56,126,1,0,160,14,1,0,1,0,0,0,125,240,146,0,32,101,1,0,88,212,3,0,1,0,0,0,160,220,146,0,40,185,3,0,72,65,1,0,9,0,0,0,144,6,147,0,32,58,1,0,48,50,1,0,9,0,0,0,145,6,147,0,32,58,1,0,168,86,7,0,1,0,0,0,192,236,146,0,248,191,2,0,24,38,7,0,1,0,0,0,142,250,146,0,184,160,2,0,56,210,6,0,1,0,0,0,138,250,146,0,192,135,2,0,24,163,6,0,1,0,0,0,139,250,146,0,240,108,2,0,152,122,6,0,1,0,0,0,137,250,146,0,96,82,2,0,192,72,6,0,1,0,0,0,136,250,146,0,32,56,2,0,200,110,3,0,1,0,0,0,140,250,146,0,152,30,2,0,120,89,3,0,1,0,0,0,141,250,146,0,232,10,2,0,144,236,1,0,1,0,0,0,143,250,146,0,136,224,1,0,176,223,1,0,1,0,0,0,98,242,146,0,72,198,1,0,192,209,1,0,1,0,0,0,99,242,146,0,24,182,1,0,24,198,1,0,1,0,0,0,97,242,146,0,40,167,1,0,120,189,1,0,1,0,0,0,96,242,146,0,200,149,1,0,224,22,1,0,1,0,0,0,100,242,146,0,56,126,1,0,160,14,1,0,1,0,0,0,101,242,146,0,32,101,1,0,88,212,3,0,1,0,0,0,104,215,146,0,40,185,3,0,72,65,1,0,9,0,0,0,112,3,147,0,32,58,1,0,48,50,1,0,9,0,0,0,113,3,147,0,32,58,1,0,168,86,7,0,1,0,0,0,231,253,146,0,248,191,2,0,24,38,7,0,1,0,0,0,227,253,146,0,184,160,2,0,56,210,6,0,1,0,0,0,151,245,146,0,192,135,2,0,24,163,6,0,1,0,0,0,150,245,146,0,240,108,2,0,152,122,6,0,1,0,0,0,149,245,146,0,96,82,2,0,192,72,6,0,1,0,0,0,148,245,146,0,32,56,2,0,200,110,3,0,1,0,0,0,147,245,146,0,152,30,2,0,120,89,3,0,1,0,0,0,146,245,146,0,232,10,2,0,120,74,3,0,1,0,0,0,145,245,146,0,152,138,8,0,40,246,1,0,1,0,0,0,229,253,146,0,64,246,1,0,144,236,1,0,1,0,0,0,225,253,146,0,136,224,1,0,176,223,1,0,1,0,0,0,71,239,146,0,72,198,1,0,192,209,1,0,1,0,0,0,70,239,146,0,24,182,1,0,24,198,1,0,1,0,0,0,69,239,146,0,40,167,1,0,120,189,1,0,1,0,0,0,68,239,146,0,200,149,1,0,224,22,1,0,1,0,0,0,67,239,146,0,56,126,1,0,160,14,1,0,1,0,0,0,66,239,146,0,32,101,1,0,176,9,1,0,1,0,0,0,65,239,146,0,96,32,8,0,88,212,3,0,1,0,0,0,232,217,146,0,40,185,3,0,72,65,1,0,9,0,0,0,200,4,147,0,32,58,1,0,48,50,1,0,9,0,0,0,201,4,147,0,32,58,1,0,168,86,7,0,1,0,0,0,56,252,146,0,248,191,2,0,24,38,7,0,1,0,0,0,59,252,146,0,184,160,2,0,56,210,6,0,1,0,0,0,248,243,146,0,192,135,2,0,24,163,6,0,1,0,0,0,249,243,146,0,240,108,2,0,152,122,6,0,1,0,0,0,250,243,146,0,96,82,2,0,192,72,6,0,1,0,0,0,251,243,146,0,32,56,2,0,200,110,3,0,1,0,0,0,252,243,146,0,152,30,2,0,120,89,3,0,1,0,0,0,253,243,146,0,232,10,2,0,40,246,1,0,1,0,0,0,57,252,146,0,64,246,1,0,144,236,1,0,1,0,0,0,60,252,146,0,136,224,1,0,176,223,1,0,1,0,0,0,128,238,146,0,72,198,1,0,192,209,1,0,1,0,0,0,129,238,146,0,24,182,1,0,24,198,1,0,1,0,0,0,130,238,146,0,40,167,1,0,120,189,1,0,1,0,0,0,131,238,146,0,200,149,1,0,224,22,1,0,1,0,0,0,132,238,146,0,56,126,1,0,160,14,1,0,1,0,0,0,133,238,146,0,32,101,1,0,88,212,3,0,1,0,0,0,216,216,146,0,40,185,3,0,16,17,8,0,1,0,0,0,58,252,146,0,224,12,8,0,72,65,1,0,9,0,0,0,16,4,147,0,32,58,1,0,48,50,1,0,9,0,0,0,17,4,147,0,32,58,1,0,224,41,1,0,9,0,0,0,18,4,147,0,32,58,1,0,184,40,2,0,1,0,0,0,139,151,215,0,248,191,2,0,56,250,6,0,1,0,0,0,142,151,215,0,184,160,2,0,184,164,8,0,1,0,0,0,138,151,215,0,64,246,1,0,88,149,7,0,1,0,0,0,143,151,215,0,136,224,1,0,152,225,1,0,4,0,0,0,104,150,215,0,152,210,1,0,152,198,1,0,4,0,0,0,96,150,215,0,208,189,1,0,48,123,2,0,1,0,0,0,120,151,215,0,248,174,1,0,96,69,2,0,1,0,0,0,122,151,215,0,104,160,1,0,144,55,2,0,1,0,0,0,136,151,215,0,152,30,2,0,88,150,1,0,4,0,0,0,88,150,215,0,136,7,4,0,144,126,1,0,4,0,0,0,80,150,215,0,136,113,1,0,248,187,8,0,1,0,0,0,121,151,215,0,56,126,1,0,184,179,8,0,1,0,0,0,123,151,215,0,32,101,1,0,240,173,8,0,1,0,0,0,137,151,215,0,96,32,8,0,88,212,3,0,1,0,0,0,200,147,215,0,40,185,3,0,16,17,8,0,1,0,0,0,140,151,215,0,224,12,8,0,248,5,8,0,9,0,0,0,152,151,215,0,32,58,1,0,144,250,7,0,9,0,0,0,153,151,215,0,32,58,1,0,168,86,7,0,1,0,0,0,132,151,215,0,248,191,2,0,24,38,7,0,1,0,0,0,130,151,215,0,184,160,2,0,56,210,6,0,1,0,0,0,120,151,215,0,192,135,2,0,24,163,6,0,1,0,0,0,121,151,215,0,240,108,2,0,152,122,6,0,1,0,0,0,122,151,215,0,96,82,2,0,192,72,6,0,1,0,0,0,123,151,215,0,32,56,2,0,200,110,3,0,1,0,0,0,136,151,215,0,152,30,2,0,120,89,3,0,1,0,0,0,137,151,215,0,232,10,2,0,120,74,3,0,1,0,0,0,138,151,215,0,152,138,8,0,40,246,1,0,1,0,0,0,133,151,215,0,64,246,1,0,144,236,1,0,1,0,0,0,131,151,215,0,136,224,1,0,176,223,1,0,1,0,0,0,124,151,215,0,72,198,1,0,192,209,1,0,1,0,0,0,125,151,215,0,24,182,1,0,24,198,1,0,1,0,0,0,126,151,215,0,40,167,1,0,120,189,1,0,1,0,0,0,127,151,215,0,200,149,1,0,224,22,1,0,1,0,0,0,139,151,215,0,56,126,1,0,160,14,1,0,1,0,0,0,140,151,215,0,32,101,1,0,176,9,1,0,1,0,0,0,141,151,215,0,96,32,8,0,168,132,8,0,1,0,0,0,136,148,215,0,232,209,1,0,72,126,8,0,1,0,0,0,160,148,215,0,144,189,1,0,192,122,8,0,1,0,0,0,163,148,215,0,208,174,1,0,40,116,8,0,1,0,0,0,164,148,215,0,48,160,1,0,72,110,8,0,1,0,0,0,161,148,215,0,160,140,1,0,184,102,8,0,1,0,0,0,162,148,215,0,56,112,1,0,248,67,8,0,1,0,0,0,165,148,215,0,32,92,1,0,136,64,8,0,1,0,0,0,166,148,215,0,64,77,1,0,128,58,8,0,1,0,0,0,167,148,215,0,112,157,4,0,232,23,8,0,1,0,0,0,138,148,215,0,104,195,5,0,160,19,8,0,1,0,0,0,152,148,215,0,32,245,8,0,248,16,8,0,1,0,0,0,155,148,215,0,32,231,8,0,192,12,8,0,1,0,0,0,156,148,215,0,88,214,8,0,224,5,8,0,1,0,0,0,153,148,215,0,224,202,8,0,144,1,8,0,1,0,0,0,154,148,215,0,72,193,8,0,176,222,7,0,1,0,0,0,157,148,215,0,144,180,8,0,176,218,7,0,1,0,0,0,158,148,215,0,208,164,8,0,248,214,7,0,1,0,0,0,159,148,215,0,160,152,4,0,88,212,3,0,1,0,0,0,200,147,215,0,40,185,3,0,16,17,8,0,1,0,0,0,129,151,215,0,224,12,8,0,16,17,8,0,1,0,0,0,137,148,215,0,224,12,8,0,16,17,8,0,1,0,0,0,139,148,215,0,224,12,8,0,56,58,1,0,1,0,0,0,128,151,215,0,64,50,1,0,72,65,1,0,9,0,0,0,152,151,215,0,32,58,1,0,48,50,1,0,9,0,0,0,153,151,215,0,32,58,1,0,184,40,2,0,1,0,0,0,170,148,215,0,248,191,2,0,56,250,6,0,1,0,0,0,191,148,215,0,184,160,2,0,184,164,8,0,1,0,0,0,171,148,215,0,64,246,1,0,88,149,7,0,1,0,0,0,183,148,215,0,136,224,1,0,56,210,6,0,1,0,0,0,184,148,215,0,192,135,2,0,24,163,6,0,1,0,0,0,185,148,215,0,240,108,2,0,152,122,6,0,1,0,0,0,186,148,215,0,96,82,2,0,192,72,6,0,1,0,0,0,187,148,215,0,32,56,2,0,48,123,2,0,1,0,0,0,188,148,215,0,152,30,2,0,96,69,2,0,1,0,0,0,189,148,215,0,232,10,2,0,144,55,2,0,1,0,0,0,190,148,215,0,152,138,8,0,176,223,1,0,1,0,0,0,176,148,215,0,72,198,1,0,192,209,1,0,1,0,0,0,177,148,215,0,24,182,1,0,24,198,1,0,1,0,0,0,178,148,215,0,40,167,1,0,120,189,1,0,1,0,0,0,179,148,215,0,200,149,1,0,248,187,8,0,1,0,0,0,180,148,215,0,56,126,1,0,184,179,8,0,1,0,0,0,181,148,215,0,32,101,1,0,240,173,8,0,1,0,0,0,182,148,215,0,96,32,8,0,88,212,3,0,1,0,0,0,200,147,215,0,40,185,3,0,16,17,8,0,1,0,0,0,169,148,215,0,224,12,8,0,56,58,1,0,1,0,0,0,168,148,215,0,64,50,1,0,248,5,8,0,9,0,0,0,96,149,215,0,32,58,1,0,144,250,7,0,9,0,0,0,97,149,215,0,32,58,1,0,116,111,97,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,218,2,211,85,0,0,16,1,116,111,97,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,69,225,100,60,0,0,16,1,119,98,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,141,117,190,83,0,0,16,1,119,98,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,46,41,142,252,0,0,16,1,119,98,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,222,33,105,66,0,0,32,0,119,98,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,55,73,32,104,0,0,32,0,119,98,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,199,4,78,239,0,0,32,0,119,98,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,120,9,244,83,0,0,32,0,119,98,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,99,69,203,65,0,0,32,0,119,98,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,140,184,151,148,0,0,32,0,119,98,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,30,43,162,95,0,0,32,0,119,98,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,202,24,231,155,0,0,32,0,119,98,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,223,89,254,83,0,0,64,0,184,40,2,0,1,0,0,0,218,83,148,0,248,191,2,0,56,250,6,0,1,0,0,0,216,83,148,0,184,160,2,0,56,210,6,0,1,0,0,0,232,83,148,0,192,135,2,0,24,163,6,0,1,0,0,0,233,83,148,0,240,108,2,0,152,122,6,0,1,0,0,0,234,83,148,0,96,82,2,0,192,72,6,0,1,0,0,0,235,83,148,0,32,56,2,0,48,123,2,0,1,0,0,0,236,83,148,0,152,30,2,0,96,69,2,0,1,0,0,0,237,83,148,0,232,10,2,0,144,55,2,0,1,0,0,0,238,83,148,0,152,138,8,0,184,164,8,0,1,0,0,0,219,83,148,0,64,246,1,0,88,149,7,0,1,0,0,0,217,83,148,0,136,224,1,0,176,223,1,0,1,0,0,0,224,83,148,0,72,198,1,0,192,209,1,0,1,0,0,0,225,83,148,0,24,182,1,0,24,198,1,0,1,0,0,0,226,83,148,0,40,167,1,0,120,189,1,0,1,0,0,0,227,83,148,0,200,149,1,0,248,187,8,0,1,0,0,0,228,83,148,0,56,126,1,0,184,179,8,0,1,0,0,0,229,83,148,0,32,101,1,0,240,173,8,0,1,0,0,0,230,83,148,0,96,32,8,0,88,212,3,0,1,0,0,0,8,229,148,0,40,185,3,0,16,17,8,0,1,0,0,0,222,83,148,0,224,12,8,0,56,58,1,0,1,0,0,0,221,83,148,0,64,50,1,0,248,5,8,0,9,0,0,0,248,71,215,0,32,58,1,0,144,250,7,0,9,0,0,0,249,71,215,0,32,58,1,0,184,40,2,0,1,0,0,0,40,39,216,0,248,191,2,0,56,250,6,0,1,0,0,0,32,39,216,0,184,160,2,0,184,164,8,0,1,0,0,0,41,39,216,0,64,246,1,0,88,149,7,0,1,0,0,0,33,39,216,0,136,224,1,0,208,158,7,0,1,0,0,0,42,39,216,0,96,82,2,0,184,154,7,0,1,0,0,0,43,39,216,0,32,56,2,0,176,108,2,0,1,0,0,0,44,39,216,0,152,30,2,0,88,212,3,0,1,0,0,0,48,38,216,0,40,185,3,0,248,5,8,0,9,0,0,0,112,39,216,0,32,58,1,0,144,250,7,0,9,0,0,0,113,39,216,0,32,58,1,0,248,241,7,0,9,0,0,0,114,39,216,0,32,58,1,0,184,40,2,0,1,0,0,0,228,150,215,0,248,191,2,0,56,250,6,0,1,0,0,0,212,150,215,0,184,160,2,0,88,149,7,0,1,0,0,0,213,150,215,0,136,224,1,0,56,210,6,0,1,0,0,0,200,150,215,0,192,135,2,0,24,163,6,0,1,0,0,0,201,150,215,0,240,108,2,0,152,122,6,0,1,0,0,0,202,150,215,0,96,82,2,0,192,72,6,0,1,0,0,0,203,150,215,0,32,56,2,0,48,123,2,0,1,0,0,0,216,150,215,0,152,30,2,0,96,69,2,0,1,0,0,0,217,150,215,0,232,10,2,0,144,55,2,0,1,0,0,0,218,150,215,0,152,138,8,0,176,223,1,0,1,0,0,0,204,150,215,0,72,198,1,0,192,209,1,0,1,0,0,0,205,150,215,0,24,182,1,0,24,198,1,0,1,0,0,0,206,150,215,0,40,167,1,0,120,189,1,0,1,0,0,0,207,150,215,0,200,149,1,0,248,187,8,0,1,0,0,0,220,150,215,0,56,126,1,0,184,179,8,0,1,0,0,0,221,150,215,0,32,101,1,0,240,173,8,0,1,0,0,0,222,150,215,0,96,32,8,0,88,212,3,0,1,0,0,0,200,147,215,0,40,185,3,0,16,17,8,0,1,0,0,0,208,150,215,0,224,12,8,0,56,58,1,0,1,0,0,0,225,150,215,0,64,50,1,0,248,5,8,0,9,0,0,0,96,149,215,0,32,58,1,0,168,86,7,0,1,0,0,0,232,47,216,0,248,191,2,0,24,38,7,0,1,0,0,0,236,47,216,0,184,160,2,0,56,210,6,0,1,0,0,0,35,48,216,0,192,135,2,0,24,163,6,0,1,0,0,0,34,48,216,0,240,108,2,0,152,122,6,0,1,0,0,0,33,48,216,0,96,82,2,0,192,72,6,0,1,0,0,0,32,48,216,0,32,56,2,0,152,31,6,0,1,0,0,0,36,48,216,0,152,30,2,0,248,97,5,0,1,0,0,0,37,48,216,0,232,10,2,0,120,67,5,0,1,0,0,0,38,48,216,0,152,138,8,0,40,246,1,0,1,0,0,0,233,47,216,0,64,246,1,0,144,236,1,0,1,0,0,0,237,47,216,0,136,224,1,0,176,223,1,0,1,0,0,0,43,48,216,0,72,198,1,0,192,209,1,0,1,0,0,0,42,48,216,0,24,182,1,0,24,198,1,0,1,0,0,0,41,48,216,0,40,167,1,0,120,189,1,0,1,0,0,0,40,48,216,0,200,149,1,0,8,182,1,0,1,0,0,0,44,48,216,0,56,126,1,0,32,167,1,0,1,0,0,0,45,48,216,0,32,101,1,0,24,160,1,0,1,0,0,0,46,48,216,0,96,32,8,0,168,132,8,0,1,0,0,0,110,47,216,0,232,209,1,0,72,126,8,0,1,0,0,0,111,47,216,0,144,189,1,0,192,122,8,0,1,0,0,0,107,47,216,0,208,174,1,0,40,116,8,0,1,0,0,0,106,47,216,0,48,160,1,0,72,110,8,0,1,0,0,0,105,47,216,0,160,140,1,0,184,102,8,0,1,0,0,0,104,47,216,0,56,112,1,0,248,93,8,0,1,0,0,0,108,47,216,0,32,92,1,0,152,86,8,0,1,0,0,0,109,47,216,0,64,77,1,0,216,80,8,0,1,0,0,0,39,48,216,0,112,157,4,0,232,23,8,0,1,0,0,0,94,47,216,0,104,195,5,0,160,19,8,0,1,0,0,0,95,47,216,0,32,245,8,0,248,16,8,0,1,0,0,0,91,47,216,0,32,231,8,0,192,12,8,0,1,0,0,0,90,47,216,0,88,214,8,0,224,5,8,0,1,0,0,0,89,47,216,0,224,202,8,0,144,1,8,0,1,0,0,0,88,47,216,0,72,193,8,0,96,250,7,0,1,0,0,0,92,47,216,0,144,180,8,0,120,241,7,0,1,0,0,0,93,47,216,0,208,164,8,0,56,236,7,0,1,0,0,0,47,48,216,0,160,152,4,0,88,212,3,0,1,0,0,0,144,46,216,0,40,185,3,0,240,152,1,0,1,0,0,0,238,47,216,0,216,70,1,0,16,17,8,0,1,0,0,0,234,47,216,0,224,12,8,0,224,41,1,0,9,0,0,0,216,48,216,0,32,58,1,0,168,86,7,0,1,0,0,0,248,254,146,0,248,191,2,0,24,38,7,0,1,0,0,0,152,239,146,0,184,160,2,0,56,210,6,0,1,0,0,0,152,246,146,0,192,135,2,0,24,163,6,0,1,0,0,0,153,246,146,0,240,108,2,0,152,122,6,0,1,0,0,0,154,246,146,0,96,82,2,0,192,72,6,0,1,0,0,0,155,246,146,0,32,56,2,0,200,110,3,0,1,0,0,0,156,246,146,0,152,30,2,0,120,89,3,0,1,0,0,0,157,246,146,0,232,10,2,0,40,246,1,0,1,0,0,0,249,254,146,0,64,246,1,0,144,236,1,0,1,0,0,0,156,239,146,0,136,224,1,0,176,223,1,0,1,0,0,0,160,246,146,0,72,198,1,0,192,209,1,0,1,0,0,0,161,246,146,0,24,182,1,0,24,198,1,0,1,0,0,0,162,246,146,0,40,167,1,0,120,189,1,0,1,0,0,0,163,246,146,0,200,149,1,0,224,22,1,0,1,0,0,0,164,246,146,0,56,126,1,0,160,14,1,0,1,0,0,0,165,246,146,0,32,101,1,0,88,212,3,0,1,0,0,0,176,218,146,0,40,185,3,0,16,17,8,0,1,0,0,0,164,239,146,0,224,12,8,0,72,65,1,0,9,0,0,0,56,5,147,0,32,58,1,0,48,50,1,0,9,0,0,0,57,5,147,0,32,58,1,0,54,48,48,95,118,105,100,46,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,174,144,224,142,1,0,16,1,54,48,48,95,118,105,100,46,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,242,175,191,69,1,0,16,1,54,48,48,95,118,105,100,46,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,215,142,76,159,1,0,16,1,54,48,48,95,118,105,100,46,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,86,240,46,169,1,0,16,1,54,48,48,95,118,105,100,46,50,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,45,215,173,109,1,0,16,1,54,48,48,95,115,110,100,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,142,198,115,23,2,0,16,1,54,48,48,95,115,110,100,46,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,152,185,17,163,2,0,16,1,54,48,48,95,118,105,100,46,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,86,61,108,0,4,0,32,0,54,48,48,95,118,105,100,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,38,4,188,125,4,0,32,0,116,117,114,116,108,101,115,46,99,108,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,221,2,239,243,7,0,32,0,168,86,7,0,1,0,0,0,176,236,146,0,248,191,2,0,24,38,7,0,1,0,0,0,135,2,147,0,184,160,2,0,56,210,6,0,1,0,0,0,130,2,147,0,192,135,2,0,24,163,6,0,1,0,0,0,131,2,147,0,240,108,2,0,152,122,6,0,1,0,0,0,128,2,147,0,96,82,2,0,192,72,6,0,1,0,0,0,129,2,147,0,32,56,2,0,200,110,3,0,1,0,0,0,132,2,147,0,152,30,2,0,120,89,3,0,1,0,0,0,133,2,147,0,232,10,2,0,40,246,1,0,1,0,0,0,177,236,146,0,64,246,1,0,144,236,1,0,1,0,0,0,199,249,146,0,136,224,1,0,176,223,1,0,1,0,0,0,194,249,146,0,72,198,1,0,192,209,1,0,1,0,0,0,195,249,146,0,24,182,1,0,24,198,1,0,1,0,0,0,192,249,146,0,40,167,1,0,120,189,1,0,1,0,0,0,193,249,146,0,200,149,1,0,224,22,1,0,1,0,0,0,196,249,146,0,56,126,1,0,160,14,1,0,1,0,0,0,197,249,146,0,32,101,1,0,168,132,8,0,1,0,0,0,178,236,146,0,232,209,1,0,72,126,8,0,1,0,0,0,167,241,146,0,144,189,1,0,192,122,8,0,1,0,0,0,162,241,146,0,208,174,1,0,40,116,8,0,1,0,0,0,163,241,146,0,48,160,1,0,72,110,8,0,1,0,0,0,160,241,146,0,160,140,1,0,184,102,8,0,1,0,0,0,161,241,146,0,56,112,1,0,248,67,8,0,1,0,0,0,164,241,146,0,32,92,1,0,136,64,8,0,1,0,0,0,165,241,146,0,64,77,1,0,232,23,8,0,1,0,0,0,179,236,146,0,104,195,5,0,160,19,8,0,1,0,0,0,191,237,146,0,32,245,8,0,248,16,8,0,1,0,0,0,186,237,146,0,32,231,8,0,192,12,8,0,1,0,0,0,187,237,146,0,88,214,8,0,224,5,8,0,1,0,0,0,184,237,146,0,224,202,8,0,144,1,8,0,1,0,0,0,185,237,146,0,72,193,8,0,176,222,7,0,1,0,0,0,188,237,146,0,144,180,8,0,176,218,7,0,1,0,0,0,189,237,146,0,208,164,8,0,32,77,1,0,1,0,0,0,200,7,147,0,216,70,1,0,88,212,3,0,1,0,0,0,232,221,146,0,40,185,3,0,168,86,7,0,1,0,0,0,16,250,146,0,248,191,2,0,24,38,7,0,1,0,0,0,239,241,146,0,184,160,2,0,56,210,6,0,1,0,0,0,232,241,146,0,192,135,2,0,24,163,6,0,1,0,0,0,233,241,146,0,240,108,2,0,152,122,6,0,1,0,0,0,234,241,146,0,96,82,2,0,192,72,6,0,1,0,0,0,235,241,146,0,32,56,2,0,200,110,3,0,1,0,0,0,236,241,146,0,152,30,2,0,120,89,3,0,1,0,0,0,237,241,146,0,232,10,2,0,120,74,3,0,1,0,0,0,238,241,146,0,152,138,8,0,40,246,1,0,1,0,0,0,17,250,146,0,64,246,1,0,144,236,1,0,1,0,0,0,247,241,146,0,136,224,1,0,176,223,1,0,1,0,0,0,240,241,146,0,72,198,1,0,192,209,1,0,1,0,0,0,241,241,146,0,24,182,1,0,24,198,1,0,1,0,0,0,242,241,146,0,40,167,1,0,120,189,1,0,1,0,0,0,243,241,146,0,200,149,1,0,224,22,1,0,1,0,0,0,244,241,146,0,56,126,1,0,160,14,1,0,1,0,0,0,245,241,146,0,32,101,1,0,176,9,1,0,1,0,0,0,246,241,146,0,96,32,8,0,88,212,3,0,1,0,0,0,32,215,146,0,40,185,3,0,16,17,8,0,1,0,0,0,18,250,146,0,224,12,8,0,72,65,1,0,9,0,0,0,56,3,147,0,32,58,1,0,184,40,2,0,1,0,0,0,154,222,146,0,248,191,2,0,184,164,8,0,1,0,0,0,155,222,146,0,64,246,1,0,24,38,7,0,1,0,0,0,152,222,146,0,184,160,2,0,152,122,6,0,1,0,0,0,120,1,147,0,96,82,2,0,192,72,6,0,1,0,0,0,121,1,147,0,32,56,2,0,24,163,6,0,1,0,0,0,122,1,147,0,240,108,2,0,56,210,6,0,1,0,0,0,123,1,147,0,192,135,2,0,200,110,3,0,1,0,0,0,201,248,146,0,152,30,2,0,120,89,3,0,1,0,0,0,200,248,146,0,232,10,2,0,120,74,3,0,1,0,0,0,202,248,146,0,152,138,8,0,144,236,1,0,1,0,0,0,153,222,146,0,136,224,1,0,24,198,1,0,1,0,0,0,168,240,146,0,40,167,1,0,120,189,1,0,1,0,0,0,169,240,146,0,200,149,1,0,192,209,1,0,1,0,0,0,170,240,146,0,24,182,1,0,176,223,1,0,1,0,0,0,171,240,146,0,72,198,1,0,224,22,1,0,1,0,0,0,121,237,146,0,56,126,1,0,160,14,1,0,1,0,0,0,120,237,146,0,32,101,1,0,176,9,1,0,1,0,0,0,122,237,146,0,96,32,8,0,88,212,3,0,1,0,0,0,248,220,146,0,40,185,3,0,248,5,8,0,9,0,0,0,206,187,145,0,32,58,1,0,144,250,7,0,9,0,0,0,207,187,145,0,32,58,1,0,248,241,7,0,9,0,0,0,208,187,145,0,32,58,1,0,72,82,8,0,9,0,0,0,209,187,145,0,32,58,1,0,184,40,2,0,1,0,0,0,208,155,215,0,248,191,2,0,56,250,6,0,1,0,0,0,212,155,215,0,184,160,2,0,184,164,8,0,1,0,0,0,209,155,215,0,64,246,1,0,8,3,3,0,4,0,0,0,112,156,215,0,208,13,4,0,248,230,7,0,4,0,0,0,104,156,215,0,184,198,5,0,176,108,2,0,1,0,0,0,213,155,215,0,152,30,2,0,128,98,2,0,1,0,0,0,214,155,215,0,232,10,2,0,48,82,2,0,1,0,0,0,215,155,215,0,152,138,8,0,16,17,8,0,1,0,0,0,211,155,215,0,224,12,8,0,32,77,1,0,1,0,0,0,210,155,215,0,216,70,1,0,88,212,3,0,1,0,0,0,200,154,215,0,40,185,3,0,248,5,8,0,9,0,0,0,0,156,215,0,32,58,1,0,144,250,7,0,9,0,0,0,1,156,215,0,32,58,1,0,168,86,7,0,1,0,0,0,0,238,146,0,248,191,2,0,24,38,7,0,1,0,0,0,2,238,146,0,184,160,2,0,56,210,6,0,1,0,0,0,136,250,146,0,192,135,2,0,24,163,6,0,1,0,0,0,137,250,146,0,240,108,2,0,152,122,6,0,1,0,0,0,138,250,146,0,96,82,2,0,192,72,6,0,1,0,0,0,139,250,146,0,32,56,2,0,200,110,3,0,1,0,0,0,140,250,146,0,152,30,2,0,120,89,3,0,1,0,0,0,141,250,146,0,232,10,2,0,40,246,1,0,1,0,0,0,1,238,146,0,64,246,1,0,144,236,1,0,1,0,0,0,3,238,146,0,136,224,1,0,176,223,1,0,1,0,0,0,96,242,146,0,72,198,1,0,192,209,1,0,1,0,0,0,97,242,146,0,24,182,1,0,24,198,1,0,1,0,0,0,98,242,146,0,40,167,1,0,120,189,1,0,1,0,0,0,99,242,146,0,200,149,1,0,224,22,1,0,1,0,0,0,100,242,146,0,56,126,1,0,160,14,1,0,1,0,0,0,101,242,146,0,32,101,1,0,88,212,3,0,1,0,0,0,104,215,146,0,40,185,3,0,72,65,1,0,9,0,0,0,112,3,147,0,32,58,1,0,48,50,1,0,9,0,0,0,113,3,147,0,32,58,1,0,230,3,0,0,102,26,0,0,160,12,0,0,166,12,0,0,100,10,0,0,132,14,0,0,72,22,0,0,68,6,0,0,56,27,0,0,94,1,0,0,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,184,40,2,0,1,0,0,0,96,232,148,0,248,191,2,0,56,250,6,0,1,0,0,0,223,233,148,0,184,160,2,0,184,164,8,0,1,0,0,0,97,232,148,0,64,246,1,0,88,149,7,0,1,0,0,0,31,233,148,0,136,224,1,0,104,28,8,0,1,0,0,0,98,232,148,0,232,209,1,0,64,183,7,0,1,0,0,0,99,232,148,0,104,195,5,0,56,210,6,0,1,0,0,0,216,233,148,0,192,135,2,0,24,163,6,0,1,0,0,0,217,233,148,0,240,108,2,0,152,122,6,0,1,0,0,0,218,233,148,0,96,82,2,0,192,72,6,0,1,0,0,0,219,233,148,0,32,56,2,0,48,123,2,0,1,0,0,0,220,233,148,0,152,30,2,0,96,69,2,0,1,0,0,0,221,233,148,0,232,10,2,0,144,55,2,0,1,0,0,0,222,233,148,0,152,138,8,0,176,223,1,0,1,0,0,0,24,233,148,0,72,198,1,0,192,209,1,0,1,0,0,0,25,233,148,0,24,182,1,0,24,198,1,0,1,0,0,0,26,233,148,0,40,167,1,0,120,189,1,0,1,0,0,0,27,233,148,0,200,149,1,0,248,187,8,0,1,0,0,0,28,233,148,0,56,126,1,0,184,179,8,0,1,0,0,0,29,233,148,0,32,101,1,0,240,173,8,0,1,0,0,0,30,233,148,0,96,32,8,0,88,212,3,0,1,0,0,0,192,218,146,0,40,185,3,0,248,5,8,0,9,0,0,0,112,94,147,0,32,58,1,0,144,250,7,0,9,0,0,0,113,94,147,0,32,58,1,0,168,86,7,0,1,0,0,0,132,151,215,0,248,191,2,0,24,38,7,0,1,0,0,0,130,151,215,0,184,160,2,0,56,210,6,0,1,0,0,0,120,151,215,0,192,135,2,0,24,163,6,0,1,0,0,0,121,151,215,0,240,108,2,0,152,122,6,0,1,0,0,0,122,151,215,0,96,82,2,0,192,72,6,0,1,0,0,0,123,151,215,0,32,56,2,0,200,110,3,0,1,0,0,0,136,151,215,0,152,30,2,0,120,89,3,0,1,0,0,0,137,151,215,0,232,10,2,0,120,74,3,0,1,0,0,0,138,151,215,0,152,138,8,0,40,246,1,0,1,0,0,0,133,151,215,0,64,246,1,0,144,236,1,0,1,0,0,0,131,151,215,0,136,224,1,0,176,223,1,0,1,0,0,0,124,151,215,0,72,198,1,0,192,209,1,0,1,0,0,0,125,151,215,0,24,182,1,0,24,198,1,0,1,0,0,0,126,151,215,0,40,167,1,0,120,189,1,0,1,0,0,0,127,151,215,0,200,149,1,0,224,22,1,0,1,0,0,0,139,151,215,0,56,126,1,0,160,14,1,0,1,0,0,0,140,151,215,0,32,101,1,0,176,9,1,0,1,0,0,0,141,151,215,0,96,32,8,0,88,212,3,0,1,0,0,0,200,147,215,0,40,185,3,0,16,17,8,0,1,0,0,0,129,151,215,0,224,12,8,0,56,58,1,0,1,0,0,0,128,151,215,0,64,50,1,0,72,65,1,0,9,0,0,0,152,151,215,0,32,58,1,0,48,50,1,0,9,0,0,0,153,151,215,0,32,58,1,0,24,0,0,0,28,20,0,0,70,3,0,0,220,12,0,0,42,19,0,0,52,10,0,0,170,4,0,0,148,0,0,0,188,1,0,0,216,35,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,184,40,2,0,1,0,0,0,128,93,148,0,248,191,2,0,56,250,6,0,1,0,0,0,132,93,148,0,184,160,2,0,184,164,8,0,1,0,0,0,129,93,148,0,64,246,1,0,88,149,7,0,1,0,0,0,133,93,148,0,136,224,1,0,56,210,6,0,1,0,0,0,149,93,148,0,192,135,2,0,24,163,6,0,1,0,0,0,148,93,148,0,240,108,2,0,152,122,6,0,1,0,0,0,151,93,148,0,96,82,2,0,192,72,6,0,1,0,0,0,150,93,148,0,32,56,2,0,48,123,2,0,1,0,0,0,144,93,148,0,152,30,2,0,96,69,2,0,1,0,0,0,145,93,148,0,232,10,2,0,144,55,2,0,1,0,0,0,146,93,148,0,152,138,8,0,176,223,1,0,1,0,0,0,141,93,148,0,72,198,1,0,192,209,1,0,1,0,0,0,140,93,148,0,24,182,1,0,24,198,1,0,1,0,0,0,143,93,148,0,40,167,1,0,120,189,1,0,1,0,0,0,142,93,148,0,200,149,1,0,248,187,8,0,1,0,0,0,136,93,148,0,56,126,1,0,184,179,8,0,1,0,0,0,137,93,148,0,32,101,1,0,240,173,8,0,1,0,0,0,138,93,148,0,96,32,8,0,88,212,3,0,1,0,0,0,248,26,149,0,40,185,3,0,16,17,8,0,1,0,0,0,131,93,148,0,224,12,8,0,80,251,6,0,1,0,0,0,130,93,148,0,216,70,1,0,248,5,8,0,9,0,0,0,112,99,215,0,32,58,1,0,144,250,7,0,9,0,0,0,113,99,215,0,32,58,1,0,184,40,2,0,1,0,0,0,152,244,146,0,248,191,2,0,24,38,7,0,1,0,0,0,191,238,146,0,184,160,2,0,56,210,6,0,1,0,0,0,184,238,146,0,192,135,2,0,24,163,6,0,1,0,0,0,185,238,146,0,240,108,2,0,152,122,6,0,1,0,0,0,186,238,146,0,96,82,2,0,192,72,6,0,1,0,0,0,187,238,146,0,32,56,2,0,200,110,3,0,1,0,0,0,188,238,146,0,152,30,2,0,120,89,3,0,1,0,0,0,189,238,146,0,232,10,2,0,144,236,1,0,1,0,0,0,199,238,146,0,136,224,1,0,176,223,1,0,1,0,0,0,192,238,146,0,72,198,1,0,192,209,1,0,1,0,0,0,193,238,146,0,24,182,1,0,24,198,1,0,1,0,0,0,194,238,146,0,40,167,1,0,120,189,1,0,1,0,0,0,195,238,146,0,200,149,1,0,224,22,1,0,1,0,0,0,196,238,146,0,56,126,1,0,160,14,1,0,1,0,0,0,197,238,146,0,32,101,1,0])
.concat([88,212,3,0,1,0,0,0,64,217,146,0,40,185,3,0,248,5,8,0,9,0,0,0,88,4,147,0,32,58,1,0,144,250,7,0,9,0,0,0,89,4,147,0,32,58,1,0,115,99,102,49,46,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,31,170,38,177,1,0,16,1,115,99,102,50,46,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,119,251,37,206,1,0,16,1,115,99,110,115,51,46,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,238,101,194,238,1,0,16,1,115,99,110,115,52,46,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,34,10,56,221,1,0,16,1,115,99,110,115,53,46,50,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,114,14,152,146,1,0,16,1,115,99,110,115,54,46,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,116,99,217,159,1,0,16,1,115,99,110,115,55,46,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,160,7,172,136,1,0,16,1,115,99,110,115,56,46,50,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,9,46,35,117,1,0,16,1,111,116,49,110,115,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,246,124,3,190,2,0,16,1,111,116,50,46,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,218,18,121,222,2,0,16,1,111,116,51,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,51,169,47,186,2,0,16,1,99,50,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,91,132,8,71,4,0,32,0,99,49,46,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,135,40,253,17,4,0,32,0,99,48,49,115,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,171,174,60,78,7,0,32,0,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,196,116,161,139,1,0,16,1,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,164,64,203,67,1,0,16,1,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,238,101,194,238,1,0,16,1,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,34,10,56,221,1,0,16,1,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,114,14,152,146,1,0,16,1,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,116,99,217,159,1,0,16,1,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,160,7,172,136,1,0,16,1,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,9,46,35,117,1,0,16,1,111,116,49,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,240,151,210,188,2,0,16,1,111,116,50,46,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,218,18,121,222,2,0,16,1,111,116,51,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,51,169,47,186,2,0,16,1,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,91,132,8,71,4,0,32,0,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,135,40,253,17,4,0,32,0,99,48,49,115,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,171,174,60,78,7,0,32,0,184,40,2,0,1,0,0,0,47,39,216,0,248,191,2,0,56,250,6,0,1,0,0,0,39,39,216,0,184,160,2,0,184,164,8,0,1,0,0,0,46,39,216,0,64,246,1,0,88,149,7,0,1,0,0,0,38,39,216,0,136,224,1,0,240,167,7,0,1,0,0,0,28,39,216,0,192,135,2,0,176,163,7,0,1,0,0,0,30,39,216,0,240,108,2,0,208,158,7,0,1,0,0,0,45,39,216,0,96,82,2,0,184,154,7,0,1,0,0,0,44,39,216,0,32,56,2,0,176,108,2,0,1,0,0,0,43,39,216,0,152,30,2,0,128,98,2,0,1,0,0,0,41,39,216,0,232,10,2,0,8,96,7,0,1,0,0,0,40,39,216,0,72,198,1,0,48,89,7,0,1,0,0,0,24,39,216,0,24,182,1,0,16,83,7,0,1,0,0,0,37,39,216,0,40,167,1,0,96,79,7,0,1,0,0,0,36,39,216,0,200,149,1,0,48,76,7,0,1,0,0,0,35,39,216,0,56,126,1,0,144,72,7,0,1,0,0,0,34,39,216,0,32,101,1,0,88,212,3,0,1,0,0,0,48,38,216,0,40,185,3,0,16,17,8,0,1,0,0,0,42,39,216,0,224,12,8,0,248,5,8,0,9,0,0,0,112,39,216,0,32,58,1,0,144,250,7,0,9,0,0,0,113,39,216,0,32,58,1,0,248,241,7,0,9,0,0,0,114,39,216,0,32,58,1,0,184,40,2,0,1,0,0,0,40,39,216,0,248,191,2,0,56,250,6,0,1,0,0,0,32,39,216,0,184,160,2,0,88,149,7,0,1,0,0,0,33,39,216,0,136,224,1,0,240,167,7,0,1,0,0,0,47,39,216,0,192,135,2,0,176,163,7,0,1,0,0,0,46,39,216,0,240,108,2,0,208,158,7,0,1,0,0,0,42,39,216,0,96,82,2,0,184,154,7,0,1,0,0,0,43,39,216,0,32,56,2,0,176,108,2,0,1,0,0,0,44,39,216,0,152,30,2,0,128,98,2,0,1,0,0,0,45,39,216,0,232,10,2,0,8,96,7,0,1,0,0,0,39,39,216,0,72,198,1,0,48,89,7,0,1,0,0,0,41,39,216,0,24,182,1,0,16,83,7,0,1,0,0,0,34,39,216,0,40,167,1,0,96,79,7,0,1,0,0,0,35,39,216,0,200,149,1,0,48,76,7,0,1,0,0,0,36,39,216,0,56,126,1,0,144,72,7,0,1,0,0,0,37,39,216,0,32,101,1,0,88,212,3,0,1,0,0,0,48,38,216,0,40,185,3,0,248,5,8,0,9,0,0,0,112,39,216,0,32,58,1,0,144,250,7,0,9,0,0,0,113,39,216,0,32,58,1,0,248,241,7,0,9,0,0,0,114,39,216,0,32,58,1,0,168,86,7,0,1,0,0,0,112,2,147,0,248,191,2,0,24,38,7,0,1,0,0,0,115,2,147,0,184,160,2,0,56,210,6,0,1,0,0,0,178,249,146,0,192,135,2,0,24,163,6,0,1,0,0,0,179,249,146,0,240,108,2,0,152,122,6,0,1,0,0,0,176,249,146,0,96,82,2,0,192,72,6,0,1,0,0,0,177,249,146,0,32,56,2,0,200,110,3,0,1,0,0,0,180,249,146,0,152,30,2,0,40,246,1,0,1,0,0,0,113,2,147,0,64,246,1,0,144,236,1,0,1,0,0,0,116,2,147,0,136,224,1,0,176,223,1,0,1,0,0,0,146,241,146,0,72,198,1,0,192,209,1,0,1,0,0,0,147,241,146,0,24,182,1,0,24,198,1,0,1,0,0,0,144,241,146,0,40,167,1,0,120,189,1,0,1,0,0,0,145,241,146,0,200,149,1,0,224,22,1,0,1,0,0,0,148,241,146,0,56,126,1,0,88,212,3,0,1,0,0,0,216,221,146,0,40,185,3,0,16,17,8,0,1,0,0,0,114,2,147,0,224,12,8,0,72,65,1,0,9,0,0,0,128,7,147,0,32,58,1,0,48,50,1,0,9,0,0,0,129,7,147,0,32,58,1,0,224,41,1,0,9,0,0,0,130,7,147,0,32,58,1,0,112,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,136,141,129,88,1,0,16,1,112,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,159,95,236,139,1,0,16,1,112,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,255,253,183,36,1,0,16,1,112,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,240,226,130,144,1,0,16,1,112,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,192,127,56,32,1,0,16,1,112,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,225,72,108,246,1,0,16,1,112,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,199,52,30,147,1,0,16,1,112,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,29,182,90,171,1,0,16,1,112,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,116,185,81,181,1,0,16,1,112,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,32,141,189,167,1,0,16,1,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,214,169,93,30,4,0,32,0,107,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,10,219,122,165,4,0,32,0,109,109,105,54,51,51,49,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,135,125,12,106,7,0,32,0,15,0,0,0,255,255,0,0,0,0,0,0,16,0,0,0,255,255,64,0,0,0,0,0,17,0,0,0,255,255,4,0,0,0,0,0,18,0,0,0,255,255,2,0,0,0,0,0,0,0,0,0,254,0,4,0,72,202,5,0,16,0,0,0,1,192,0,0,80,246,3,0,16,0,0,0,1,192,64,0,248,38,7,0,16,0,0,0,1,192,128,0,112,212,3,0,16,0,0,0,1,192,192,0,248,160,5,0,0,0,0,0,254,0,3,0,128,129,4,0,17,0,0,0,1,12,0,0,208,75,4,0,17,0,0,0,1,12,4,0,8,49,4,0,17,0,0,0,1,12,8,0,152,21,4,0,0,0,0,0,254,0,2,0,200,30,2,0,18,0,0,0,1,1,0,0,120,97,1,0,18,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,4,0,32,4,2,0,18,0,0,0,1,6,0,0,224,127,8,0,18,0,0,0,1,6,2,0,32,123,8,0,18,0,0,0,1,6,4,0,192,110,8,0,18,0,0,0,1,6,6,0,96,102,7,0,0,0,0,0,168,86,7,0,1,0,0,0,51,238,146,0,248,191,2,0,24,38,7,0,1,0,0,0,53,238,146,0,184,160,2,0,56,210,6,0,1,0,0,0,80,251,146,0,192,135,2,0,24,163,6,0,1,0,0,0,81,251,146,0,240,108,2,0,152,122,6,0,1,0,0,0,82,251,146,0,96,82,2,0,192,72,6,0,1,0,0,0,83,251,146,0,32,56,2,0,200,110,3,0,1,0,0,0,84,251,146,0,152,30,2,0,120,89,3,0,1,0,0,0,85,251,146,0,232,10,2,0,40,246,1,0,1,0,0,0,52,238,146,0,64,246,1,0,144,236,1,0,1,0,0,0,54,238,146,0,136,224,1,0,176,223,1,0,1,0,0,0,32,243,146,0,72,198,1,0,192,209,1,0,1,0,0,0,33,243,146,0,24,182,1,0,24,198,1,0,1,0,0,0,34,243,146,0,40,167,1,0,120,189,1,0,1,0,0,0,35,243,146,0,200,149,1,0,224,22,1,0,1,0,0,0,36,243,146,0,56,126,1,0,160,14,1,0,1,0,0,0,37,243,146,0,32,101,1,0,88,212,3,0,1,0,0,0,0,216,146,0,40,185,3,0,16,17,8,0,1,0,0,0,48,238,146,0,224,12,8,0,56,58,1,0,1,0,0,0,49,238,146,0,64,50,1,0,72,65,1,0,9,0,0,0,176,3,147,0,32,58,1,0,48,50,1,0,9,0,0,0,177,3,147,0,32,58,1,0,224,41,1,0,9,0,0,0,178,3,147,0,32,58,1,0,184,40,2,0,1,0,0,0,40,39,216,0,248,191,2,0,56,250,6,0,1,0,0,0,32,39,216,0,184,160,2,0,184,164,8,0,1,0,0,0,41,39,216,0,64,246,1,0,88,149,7,0,1,0,0,0,33,39,216,0,136,224,1,0,168,188,8,0,1,0,0,0,36,39,216,0,192,135,2,0,24,175,8,0,1,0,0,0,37,39,216,0,240,108,2,0,240,156,8,0,1,0,0,0,34,39,216,0,96,82,2,0,80,144,8,0,1,0,0,0,35,39,216,0,32,56,2,0,64,38,2,0,1,0,0,0,44,39,216,0,72,198,1,0,136,37,2,0,1,0,0,0,45,39,216,0,24,182,1,0,56,36,2,0,1,0,0,0,42,39,216,0,40,167,1,0,96,34,2,0,1,0,0,0,43,39,216,0,200,149,1,0,88,212,3,0,1,0,0,0,48,38,216,0,40,185,3,0,248,5,8,0,9,0,0,0,112,39,216,0,32,58,1,0,144,250,7,0,9,0,0,0,113,39,216,0,32,58,1,0,248,241,7,0,9,0,0,0,114,39,216,0,32,58,1,0,72,82,8,0,9,0,0,0,80,39,216,0,32,58,1,0,168,86,7,0,1,0,0,0,216,241,146,0,248,191,2,0,24,38,7,0,1,0,0,0,7,250,146,0,184,160,2,0,56,210,6,0,1,0,0,0,0,250,146,0,192,135,2,0,24,163,6,0,1,0,0,0,1,250,146,0,240,108,2,0,152,122,6,0,1,0,0,0,2,250,146,0,96,82,2,0,192,72,6,0,1,0,0,0,3,250,146,0,32,56,2,0,200,110,3,0,1,0,0,0,4,250,146,0,152,30,2,0,120,89,3,0,1,0,0,0,5,250,146,0,232,10,2,0,120,74,3,0,1,0,0,0,6,250,146,0,152,138,8,0,40,246,1,0,1,0,0,0,217,241,146,0,64,246,1,0,144,236,1,0,1,0,0,0,15,250,146,0,136,224,1,0,176,223,1,0,1,0,0,0,8,250,146,0,72,198,1,0,192,209,1,0,1,0,0,0,9,250,146,0,24,182,1,0,24,198,1,0,1,0,0,0,10,250,146,0,40,167,1,0,120,189,1,0,1,0,0,0,11,250,146,0,200,149,1,0,224,22,1,0,1,0,0,0,12,250,146,0,56,126,1,0,160,14,1,0,1,0,0,0,13,250,146,0,32,101,1,0,176,9,1,0,1,0,0,0,14,250,146,0,96,32,8,0,88,212,3,0,1,0,0,0,24,215,146,0,40,185,3,0,16,17,8,0,1,0,0,0,218,241,146,0,224,12,8,0,72,65,1,0,9,0,0,0,48,3,147,0,32,58,1,0,48,50,1,0,9,0,0,0,49,3,147,0,32,58,1,0,224,41,1,0,9,0,0,0,50,3,147,0,32,58,1,0,168,86,7,0,1,0,0,0,212,47,216,0,248,191,2,0,24,38,7,0,1,0,0,0,208,47,216,0,184,160,2,0,56,210,6,0,1,0,0,0,35,48,216,0,192,135,2,0,24,163,6,0,1,0,0,0,34,48,216,0,240,108,2,0,152,122,6,0,1,0,0,0,33,48,216,0,96,82,2,0,192,72,6,0,1,0,0,0,32,48,216,0,32,56,2,0,248,48,2,0,1,0,0,0,36,48,216,0,152,30,2,0,24,204,8,0,1,0,0,0,37,48,216,0,232,10,2,0,200,184,8,0,1,0,0,0,38,48,216,0,152,138,8,0,192,61,3,0,1,0,0,0,248,47,216,0,48,119,7,0,168,167,8,0,1,0,0,0,249,47,216,0,112,109,7,0,80,140,8,0,1,0,0,0,250,47,216,0,24,133,7,0,40,246,1,0,1,0,0,0,213,47,216,0,64,246,1,0,144,236,1,0,1,0,0,0,209,47,216,0,136,224,1,0,176,223,1,0,1,0,0,0,43,48,216,0,72,198,1,0,192,209,1,0,1,0,0,0,42,48,216,0,24,182,1,0,24,198,1,0,1,0,0,0,41,48,216,0,40,167,1,0,120,189,1,0,1,0,0,0,40,48,216,0,200,149,1,0,8,40,2,0,1,0,0,0,44,48,216,0,56,126,1,0,240,60,8,0,1,0,0,0,45,48,216,0,32,101,1,0,96,34,8,0,1,0,0,0,46,48,216,0,96,32,8,0,200,3,1,0,1,0,0,0,252,47,216,0,16,68,7,0,80,25,8,0,1,0,0,0,253,47,216,0,240,58,7,0,224,8,8,0,1,0,0,0,214,47,216,0,200,42,1,0,88,212,3,0,1,0,0,0,144,46,216,0,40,185,3,0,240,152,1,0,1,0,0,0,201,47,216,0,216,70,1,0,16,17,8,0,1,0,0,0,202,47,216,0,224,12,8,0,136,67,2,0,1,0,0,0,176,48,216,0,72,120,6,0,8,66,2,0,1,0,0,0,184,48,216,0,88,119,7,0,168,86,7,0,1,0,0,0,76,238,146,0,248,191,2,0,24,38,7,0,1,0,0,0,72,238,146,0,184,160,2,0,152,122,6,0,1,0,0,0,169,251,146,0,96,82,2,0,192,72,6,0,1,0,0,0,171,251,146,0,32,56,2,0,200,110,3,0,1,0,0,0,175,251,146,0,152,30,2,0,40,246,1,0,1,0,0,0,77,238,146,0,64,246,1,0,144,236,1,0,1,0,0,0,73,238,146,0,136,224,1,0,24,198,1,0,1,0,0,0,121,243,146,0,40,167,1,0,120,189,1,0,1,0,0,0,123,243,146,0,200,149,1,0,224,22,1,0,1,0,0,0,127,243,146,0,56,126,1,0,88,212,3,0,1,0,0,0,96,216,146,0,40,185,3,0,16,17,8,0,1,0,0,0,75,238,146,0,224,12,8,0,56,58,1,0,1,0,0,0,74,238,146,0,64,50,1,0,72,65,1,0,9,0,0,0,200,3,147,0,32,58,1,0,48,50,1,0,9,0,0,0,201,3,147,0,32,58,1,0,224,41,1,0,9,0,0,0,202,3,147,0,32,58,1,0,56,108,10,0,120,108,10,0,184,40,2,0,1,0,0,0,176,148,215,0,248,191,2,0,56,250,6,0,1,0,0,0,190,148,215,0,184,160,2,0,184,164,8,0,1,0,0,0,177,148,215,0,64,246,1,0,88,149,7,0,1,0,0,0,189,148,215,0,136,224,1,0,152,122,6,0,1,0,0,0,172,148,215,0,96,82,2,0,192,72,6,0,1,0,0,0,173,148,215,0,32,56,2,0,48,123,2,0,1,0,0,0,174,148,215,0,152,30,2,0,96,69,2,0,1,0,0,0,175,148,215,0,232,10,2,0,24,198,1,0,1,0,0,0,164,148,215,0,40,167,1,0,120,189,1,0,1,0,0,0,165,148,215,0,200,149,1,0,248,187,8,0,1,0,0,0,166,148,215,0,56,126,1,0,184,179,8,0,1,0,0,0,167,148,215,0,32,101,1,0,88,212,3,0,1,0,0,0,200,147,215,0,40,185,3,0,16,17,8,0,1,0,0,0,191,148,215,0,224,12,8,0,56,58,1,0,1,0,0,0,168,148,215,0,64,50,1,0,248,5,8,0,9,0,0,0,96,149,215,0,32,58,1,0,144,250,7,0,9,0,0,0,97,149,215,0,32,58,1,0,168,86,7,0,1,0,0,0,35,238,146,0,248,191,2,0,24,38,7,0,1,0,0,0,37,238,146,0,184,160,2,0,56,210,6,0,1,0,0,0,24,251,146,0,192,135,2,0,24,163,6,0,1,0,0,0,25,251,146,0,240,108,2,0,152,122,6,0,1,0,0,0,26,251,146,0,96,82,2,0,192,72,6,0,1,0,0,0,27,251,146,0,32,56,2,0,200,110,3,0,1,0,0,0,28,251,146,0,152,30,2,0,120,89,3,0,1,0,0,0,29,251,146,0,232,10,2,0,40,246,1,0,1,0,0,0,36,238,146,0,64,246,1,0,144,236,1,0,1,0,0,0,38,238,146,0,136,224,1,0,176,223,1,0,1,0,0,0,240,242,146,0,72,198,1,0,192,209,1,0,1,0,0,0,241,242,146,0,24,182,1,0,24,198,1,0,1,0,0,0,242,242,146,0,40,167,1,0,120,189,1,0,1,0,0,0,243,242,146,0,200,149,1,0,224,22,1,0,1,0,0,0,244,242,146,0,56,126,1,0,160,14,1,0,1,0,0,0,245,242,146,0,32,101,1,0,88,212,3,0,1,0,0,0,208,215,146,0,40,185,3,0,16,17,8,0,1,0,0,0,32,238,146,0,224,12,8,0,56,58,1,0,1,0,0,0,33,238,146,0,64,50,1,0,72,65,1,0,9,0,0,0,160,3,147,0,32,58,1,0,48,50,1,0,9,0,0,0,161,3,147,0,32,58,1,0,224,41,1,0,9,0,0,0,162,3,147,0,32,58,1,0,168,86,7,0,1,0,0,0,31,240,146,0,248,191,2,0,24,38,7,0,1,0,0,0,26,240,146,0,184,160,2,0,152,122,6,0,1,0,0,0,153,0,147,0,96,82,2,0,192,72,6,0,1,0,0,0,152,0,147,0,32,56,2,0,200,110,3,0,1,0,0,0,156,0,147,0,152,30,2,0,144,236,1,0,1,0,0,0,27,240,146,0,136,224,1,0,24,198,1,0,1,0,0,0,1,248,146,0,40,167,1,0,120,189,1,0,1,0,0,0,0,248,146,0,200,149,1,0,224,22,1,0,1,0,0,0,4,248,146,0,56,126,1,0,88,212,3,0,1,0,0,0,208,219,146,0,40,185,3,0,72,65,1,0,9,0,0,0,8,6,147,0,32,58,1,0,184,40,2,0,1,0,0,0,40,39,216,0,248,191,2,0,56,250,6,0,1,0,0,0,32,39,216,0,184,160,2,0,184,164,8,0,1,0,0,0,41,39,216,0,64,246,1,0,88,149,7,0,1,0,0,0,33,39,216,0,136,224,1,0,240,167,7,0,1,0,0,0,45,39,216,0,192,135,2,0,176,163,7,0,1,0,0,0,47,39,216,0,240,108,2,0,208,158,7,0,1,0,0,0,42,39,216,0,96,82,2,0,184,154,7,0,1,0,0,0,43,39,216,0,32,56,2,0,176,108,2,0,1,0,0,0,44,39,216,0,152,30,2,0,88,212,3,0,1,0,0,0,48,38,216,0,40,185,3,0,248,5,8,0,9,0,0,0,112,39,216,0,32,58,1,0,144,250,7,0,9,0,0,0,113,39,216,0,32,58,1,0,248,241,7,0,9,0,0,0,114,39,216,0,32,58,1,0,168,86,7,0,1,0,0,0,140,151,215,0,248,191,2,0,24,38,7,0,1,0,0,0,132,151,215,0,184,160,2,0,200,110,3,0,1,0,0,0,160,148,215,0,152,30,2,0,120,89,3,0,1,0,0,0,161,148,215,0,232,10,2,0,120,74,3,0,1,0,0,0,163,148,215,0,152,138,8,0,192,61,3,0,1,0,0,0,162,148,215,0,48,119,7,0,40,246,1,0,1,0,0,0,141,151,215,0,64,246,1,0,144,236,1,0,1,0,0,0,133,151,215,0,136,224,1,0,224,22,1,0,1,0,0,0,164,148,215,0,56,126,1,0,160,14,1,0,1,0,0,0,165,148,215,0,32,101,1,0,176,9,1,0,1,0,0,0,167,148,215,0,96,32,8,0,200,3,1,0,1,0,0,0,166,148,215,0,16,68,7,0,168,132,8,0,1,0,0,0,142,151,215,0,232,209,1,0,72,126,8,0,1,0,0,0,134,151,215,0,144,189,1,0,248,67,8,0,1,0,0,0,144,148,215,0,32,92,1,0,136,64,8,0,1,0,0,0,145,148,215,0,64,77,1,0,128,58,8,0,1,0,0,0,147,148,215,0,112,157,4,0,200,53,8,0,1,0,0,0,146,148,215,0,176,194,6,0,232,23,8,0,1,0,0,0,143,151,215,0,104,195,5,0,160,19,8,0,1,0,0,0,135,151,215,0,32,245,8,0,176,222,7,0,1,0,0,0,148,148,215,0,144,180,8,0,176,218,7,0,1,0,0,0,149,148,215,0,208,164,8,0,248,214,7,0,1,0,0,0,151,148,215,0,160,152,4,0,64,209,7,0,1,0,0,0,150,148,215,0,40,184,6,0,88,212,3,0,1,0,0,0,200,147,215,0,40,185,3,0,16,17,8,0,1,0,0,0,129,151,215,0,224,12,8,0,16,17,8,0,1,0,0,0,130,151,215,0,224,12,8,0,16,17,8,0,1,0,0,0,131,151,215,0,224,12,8,0,56,58,1,0,1,0,0,0,128,151,215,0,64,50,1,0,72,65,1,0,9,0,0,0,152,151,215,0,32,58,1,0,168,86,7,0,1,0,0,0,136,239,146,0,248,191,2,0,24,38,7,0,1,0,0,0,223,254,146,0,184,160,2,0,200,110,3,0,1,0,0,0,218,254,146,0,152,30,2,0,120,89,3,0,1,0,0,0,219,254,146,0,232,10,2,0,120,74,3,0,1,0,0,0,216,254,146,0,152,138,8,0,192,61,3,0,1,0,0,0,217,254,146,0,48,119,7,0,120,194,6,0,1,0,0,0,220,254,146,0,112,109,7,0,40,246,1,0,1,0,0,0,137,239,146,0,64,246,1,0,144,236,1,0,1,0,0,0,127,246,146,0,136,224,1,0,224,22,1,0,1,0,0,0,122,246,146,0,56,126,1,0,160,14,1,0,1,0,0,0,123,246,146,0,32,101,1,0,176,9,1,0,1,0,0,0,120,246,146,0,96,32,8,0,200,3,1,0,1,0,0,0,121,246,146,0,16,68,7,0,88,212,3,0,1,0,0,0,160,218,146,0,40,185,3,0,16,17,8,0,1,0,0,0,138,239,146,0,224,12,8,0,72,65,1,0,9,0,0,0,48,5,147,0,32,58,1,0,48,50,1,0,9,0,0,0,49,5,147,0,32,58,1,0,224,41,1,0,9,0,0,0,50,5,147,0,32,58,1,0,168,86,7,0,1,0,0,0,136,239,146,0,248,191,2,0,24,38,7,0,1,0,0,0,223,254,146,0,184,160,2,0,200,110,3,0,1,0,0,0,218,254,146,0,152,30,2,0,120,89,3,0,1,0,0,0,219,254,146,0,232,10,2,0,120,74,3,0,1,0,0,0,216,254,146,0,152,138,8,0,192,61,3,0,1,0,0,0,217,254,146,0,48,119,7,0,40,246,1,0,1,0,0,0,137,239,146,0,64,246,1,0,144,236,1,0,1,0,0,0,127,246,146,0,136,224,1,0,224,22,1,0,1,0,0,0,122,246,146,0,56,126,1,0,160,14,1,0,1,0,0,0,123,246,146,0,32,101,1,0,176,9,1,0,1,0,0,0,120,246,146,0,96,32,8,0,200,3,1,0,1,0,0,0,121,246,146,0,16,68,7,0,88,212,3,0,1,0,0,0,160,218,146,0,40,185,3,0,16,17,8,0,1,0,0,0,138,239,146,0,224,12,8,0,72,65,1,0,9,0,0,0,48,5,147,0,32,58,1,0,48,50,1,0,9,0,0,0,49,5,147,0,32,58,1,0,224,41,1,0,9,0,0,0,50,5,147,0,32,58,1,0,184,40,2,0,1,0,0,0,250,150,215,0,248,191,2,0,56,250,6,0,1,0,0,0,15,151,215,0,184,160,2,0,184,164,8,0,1,0,0,0,251,150,215,0,64,246,1,0,88,149,7,0,1,0,0,0,7,151,215,0,136,224,1,0,48,123,2,0,1,0,0,0,8,151,215,0,152,30,2,0,96,69,2,0,1,0,0,0,9,151,215,0,232,10,2,0,144,55,2,0,1,0,0,0,11,151,215,0,152,138,8,0,80,123,7,0,1,0,0,0,10,151,215,0,48,119,7,0,112,114,7,0,1,0,0,0,12,151,215,0,112,109,7,0,248,187,8,0,1,0,0,0,0,151,215,0,56,126,1,0,184,179,8,0,1,0,0,0,1,151,215,0,32,101,1,0,240,173,8,0,1,0,0,0,3,151,215,0,96,32,8,0,208,72,7,0,1,0,0,0,2,151,215,0,16,68,7,0,216,63,7,0,1,0,0,0,13,151,215,0,240,58,7,0,88,212,3,0,1,0,0,0,200,147,215,0,40,185,3,0,16,17,8,0,1,0,0,0,249,150,215,0,224,12,8,0,56,58,1,0,1,0,0,0,248,150,215,0,64,50,1,0,248,5,8,0,9,0,0,0,24,151,215,0,32,58,1,0,144,250,7,0,9,0,0,0,25,151,215,0,32,58,1,0,184,40,2,0,1,0,0,0,122,151,215,0,248,191,2,0,56,250,6,0,1,0,0,0,143,151,215,0,184,160,2,0,184,164,8,0,1,0,0,0,123,151,215,0,64,246,1,0,88,149,7,0,1,0,0,0,135,151,215,0,136,224,1,0,48,123,2,0,1,0,0,0,136,151,215,0,152,30,2,0,96,69,2,0,1,0,0,0,137,151,215,0,232,10,2,0,144,55,2,0,1,0,0,0,139,151,215,0,152,138,8,0,80,123,7,0,1,0,0,0,138,151,215,0,48,119,7,0,248,187,8,0,1,0,0,0,128,151,215,0,56,126,1,0,184,179,8,0,1,0,0,0,129,151,215,0,32,101,1,0,240,173,8,0,1,0,0,0,131,151,215,0,96,32,8,0,208,72,7,0,1,0,0,0,130,151,215,0,16,68,7,0,88,212,3,0,1,0,0,0,200,147,215,0,40,185,3,0,16,17,8,0,1,0,0,0,121,151,215,0,224,12,8,0,56,58,1,0,1,0,0,0,120,151,215,0,64,50,1,0,248,5,8,0,9,0,0,0,152,151,215,0,32,58,1,0,144,250,7,0,9,0,0,0,153,151,215,0,32,58,1,0,168,86,7,0,1,0,0,0,72,234,148,0,248,191,2,0,24,38,7,0,1,0,0,0,143,233,148,0,184,160,2,0,200,110,3,0,1,0,0,0,138,233,148,0,152,30,2,0,120,89,3,0,1,0,0,0])
.concat([139,233,148,0,232,10,2,0,120,74,3,0,1,0,0,0,136,233,148,0,152,138,8,0,192,61,3,0,1,0,0,0,137,233,148,0,48,119,7,0,56,78,6,0,1,0,0,0,140,233,148,0,112,109,7,0,40,246,1,0,1,0,0,0,73,234,148,0,64,246,1,0,144,236,1,0,1,0,0,0,207,232,148,0,136,224,1,0,224,22,1,0,1,0,0,0,202,232,148,0,56,126,1,0,160,14,1,0,1,0,0,0,203,232,148,0,32,101,1,0,176,9,1,0,1,0,0,0,200,232,148,0,96,32,8,0,200,3,1,0,1,0,0,0,201,232,148,0,16,68,7,0,72,55,6,0,1,0,0,0,204,232,148,0,240,58,7,0,88,212,3,0,1,0,0,0,248,221,146,0,40,185,3,0,16,17,8,0,1,0,0,0,76,234,148,0,224,12,8,0,32,77,1,0,1,0,0,0,231,231,148,0,216,70,1,0,184,40,2,0,1,0,0,0,250,150,215,0,248,191,2,0,56,250,6,0,1,0,0,0,15,151,215,0,184,160,2,0,184,164,8,0,1,0,0,0,251,150,215,0,64,246,1,0,88,149,7,0,1,0,0,0,7,151,215,0,136,224,1,0,56,210,6,0,1,0,0,0,8,151,215,0,192,135,2,0,24,163,6,0,1,0,0,0,9,151,215,0,240,108,2,0,152,122,6,0,1,0,0,0,10,151,215,0,96,82,2,0,192,72,6,0,1,0,0,0,11,151,215,0,32,56,2,0,48,123,2,0,1,0,0,0,12,151,215,0,152,30,2,0,176,223,1,0,1,0,0,0,0,151,215,0,72,198,1,0,192,209,1,0,1,0,0,0,1,151,215,0,24,182,1,0,24,198,1,0,1,0,0,0,2,151,215,0,40,167,1,0,120,189,1,0,1,0,0,0,3,151,215,0,200,149,1,0,248,187,8,0,1,0,0,0,4,151,215,0,56,126,1,0,88,212,3,0,1,0,0,0,200,147,215,0,40,185,3,0,16,17,8,0,1,0,0,0,249,150,215,0,224,12,8,0,56,58,1,0,1,0,0,0,248,150,215,0,64,50,1,0,248,5,8,0,9,0,0,0,24,151,215,0,32,58,1,0,144,250,7,0,9,0,0,0,25,151,215,0,32,58,1,0,112,108,50,106,46,48,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,208,27,117,10,1,0,16,1,112,108,50,106,46,48,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,254,42,247,195,1,0,16,1,112,108,50,106,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,252,219,169,110,1,0,16,1,112,108,50,106,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,141,132,20,15,1,0,16,1,112,108,50,45,115,105,109,109,46,48,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,167,19,123,19,6,0,32,0,112,108,50,45,115,105,109,109,46,48,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,7,21,219,162,6,0,32,0,112,108,50,45,115,105,109,109,46,48,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,142,255,128,126,6,0,32,0,112,108,50,45,115,105,109,109,46,48,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,237,230,147,205,6,0,32,0,112,108,50,45,115,105,109,109,46,48,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,202,187,82,15,6,0,32,0,112,108,50,45,115,105,109,109,46,48,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,195,18,39,166,6,0,32,0,112,108,50,45,115,105,109,109,46,48,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,142,159,12,182,6,0,32,0,112,108,50,45,115,105,109,109,46,48,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,132,242,254,131,6,0,32,0,112,108,50,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,105,117,105,53,10,0,16,1,112,108,50,45,115,105,109,109,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,232,251,216,133,13,0,64,0,112,108,50,45,115,105,109,109,46,48,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,132,37,214,30,13,0,64,0,168,86,7,0,1,0,0,0,72,234,148,0,248,191,2,0,56,210,6,0,1,0,0,0,138,233,148,0,192,135,2,0,24,163,6,0,1,0,0,0,139,233,148,0,240,108,2,0,152,122,6,0,1,0,0,0,136,233,148,0,96,82,2,0,192,72,6,0,1,0,0,0,137,233,148,0,32,56,2,0,200,110,3,0,1,0,0,0,140,233,148,0,152,30,2,0,120,89,3,0,1,0,0,0,141,233,148,0,232,10,2,0,40,246,1,0,1,0,0,0,73,234,148,0,64,246,1,0,176,223,1,0,1,0,0,0,202,232,148,0,72,198,1,0,192,209,1,0,1,0,0,0,203,232,148,0,24,182,1,0,24,198,1,0,1,0,0,0,200,232,148,0,40,167,1,0,120,189,1,0,1,0,0,0,201,232,148,0,200,149,1,0,224,22,1,0,1,0,0,0,204,232,148,0,56,126,1,0,160,14,1,0,1,0,0,0,205,232,148,0,32,101,1,0,168,132,8,0,1,0,0,0,74,234,148,0,232,209,1,0,192,122,8,0,1,0,0,0,42,232,148,0,208,174,1,0,40,116,8,0,1,0,0,0,43,232,148,0,48,160,1,0,72,110,8,0,1,0,0,0,40,232,148,0,160,140,1,0,184,102,8,0,1,0,0,0,41,232,148,0,56,112,1,0,248,67,8,0,1,0,0,0,44,232,148,0,32,92,1,0,136,64,8,0,1,0,0,0,45,232,148,0,64,77,1,0,232,23,8,0,1,0,0,0,75,234,148,0,104,195,5,0,248,16,8,0,1,0,0,0,2,232,148,0,32,231,8,0,192,12,8,0,1,0,0,0,3,232,148,0,88,214,8,0,224,5,8,0,1,0,0,0,0,232,148,0,224,202,8,0,144,1,8,0,1,0,0,0,1,232,148,0,72,193,8,0,176,222,7,0,1,0,0,0,4,232,148,0,144,180,8,0,176,218,7,0,1,0,0,0,5,232,148,0,208,164,8,0,88,212,3,0,1,0,0,0,248,221,146,0,40,185,3,0,56,122,5,0,1,0,0,0,76,234,148,0,224,12,8,0,0,105,5,0,1,0,0,0,77,234,148,0,128,176,7,0,152,120,4,0,1,0,0,0,78,234,148,0,248,114,7,0,112,109,5,0,1,0,0,0,79,234,148,0,32,105,5,0,72,65,1,0,9,0,0,0,240,94,147,0,32,58,1,0,48,50,1,0,9,0,0,0,241,94,147,0,32,58,1,0,224,41,1,0,9,0,0,0,242,94,147,0,32,58,1,0,50,51,46,48,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,35,93,164,191,2,0,16,1,50,50,46,48,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,164,120,37,9,2,0,16,1,50,49,46,48,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,219,205,28,210,2,0,16,1,50,48,46,48,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,206,52,243,249,2,0,16,1,49,46,48,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,7,142,70,173,4,0,32,0,50,46,48,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,182,253,185,4,0,32,0,51,46,48,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,120,26,11,190,4,0,32,0,52,46,48,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,67,122,166,187,4,0,32,0,112,115,95,103,102,120,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,57,168,78,197,4,0,32,0,112,115,95,103,102,120,55,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,189,172,197,4,4,0,32,0,112,115,95,103,102,120,54,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,204,244,68,165,4,0,32,0,112,115,95,103,102,120,56,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,54,244,2,143,4,0,32,0,57,46,53,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,181,126,54,184,3,0,16,0,49,56,46,48,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,231,102,92,55,5,0,64,0,49,57,46,48,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,132,168,92,235,5,0,64,0,21,0,0,0,255,255,16,0,0,0,0,0,22,0,0,0,255,255,107,0,0,0,0,0,0,0,0,0,254,0,8,0,32,4,2,0,21,0,0,0,1,7,7,0,80,252,6,0,21,0,0,0,1,7,6,0,16,242,7,0,21,0,0,0,1,7,5,0,104,236,7,0,21,0,0,0,1,7,0,0,128,230,7,0,21,0,0,0,1,7,1,0,184,164,6,0,21,0,0,0,1,7,2,0,80,74,6,0,21,0,0,0,1,7,3,0,192,32,6,0,21,0,0,0,1,7,4,0,32,242,5,0,0,0,0,0,254,0,2,0,64,232,1,0,21,0,0,0,1,8,0,0,96,135,7,0,21,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,21,0,0,0,1,48,0,0,192,255,2,0,21,0,0,0,1,48,16,0,208,75,4,0,21,0,0,0,1,48,32,0,8,49,4,0,21,0,0,0,1,48,48,0,152,21,4,0,0,0,0,0,254,0,2,0,160,94,8,0,21,0,0,0,1,64,0,0,120,152,1,0,21,0,0,0,1,64,64,0,144,149,1,0,0,0,0,0,254,0,2,0,144,212,8,0,21,0,0,0,1,128,0,0,96,135,7,0,21,0,0,0,1,128,128,0,152,182,7,0,0,0,0,0,254,0,8,0,72,202,5,0,22,0,0,0,1,7,0,0,0,149,1,0,22,0,0,0,1,7,1,0,192,255,2,0,22,0,0,0,1,7,2,0,208,75,4,0,22,0,0,0,1,7,3,0,40,148,1,0,22,0,0,0,1,7,4,0,152,21,4,0,22,0,0,0,1,7,5,0,72,246,3,0,22,0,0,0,1,7,6,0,72,0,3,0,22,0,0,0,1,7,7,0,80,147,1,0,0,0,0,0,254,0,4,0,56,191,4,0,22,0,0,0,1,24,0,0,32,70,1,0,22,0,0,0,1,24,8,0,224,144,1,0,22,0,0,0,1,24,16,0,224,143,1,0,22,0,0,0,1,24,24,0,40,143,1,0,0,0,0,0,254,0,2,0,104,159,3,0,22,0,0,0,1,32,0,0,96,135,7,0,22,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,40,111,8,0,22,0,0,0,1,64,0,0,96,135,7,0,22,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,168,86,7,0,1,0,0,0,232,47,216,0,248,191,2,0,24,38,7,0,1,0,0,0,236,47,216,0,184,160,2,0,56,210,6,0,1,0,0,0,35,48,216,0,192,135,2,0,24,163,6,0,1,0,0,0,34,48,216,0,240,108,2,0,152,122,6,0,1,0,0,0,33,48,216,0,96,82,2,0,192,72,6,0,1,0,0,0,32,48,216,0,32,56,2,0,152,31,6,0,1,0,0,0,36,48,216,0,152,30,2,0,248,97,5,0,1,0,0,0,37,48,216,0,232,10,2,0,40,246,1,0,1,0,0,0,233,47,216,0,64,246,1,0,144,236,1,0,1,0,0,0,237,47,216,0,136,224,1,0,176,223,1,0,1,0,0,0,43,48,216,0,72,198,1,0,192,209,1,0,1,0,0,0,42,48,216,0,24,182,1,0,24,198,1,0,1,0,0,0,41,48,216,0,40,167,1,0,120,189,1,0,1,0,0,0,40,48,216,0,200,149,1,0,8,182,1,0,1,0,0,0,44,48,216,0,56,126,1,0,32,167,1,0,1,0,0,0,45,48,216,0,32,101,1,0,88,212,3,0,1,0,0,0,144,46,216,0,40,185,3,0,240,152,1,0,1,0,0,0,238,47,216,0,216,70,1,0,16,17,8,0,1,0,0,0,234,47,216,0,224,12,8,0,224,41,1,0,9,0,0,0,216,48,216,0,32,58,1,0,168,86,7,0,1,0,0,0,202,191,145,0,248,191,2,0,24,38,7,0,1,0,0,0,200,191,145,0,184,160,2,0,56,210,6,0,1,0,0,0,163,2,147,0,192,135,2,0,24,163,6,0,1,0,0,0,162,2,147,0,240,108,2,0,152,122,6,0,1,0,0,0,161,2,147,0,96,82,2,0,192,72,6,0,1,0,0,0,160,2,147,0,32,56,2,0,200,110,3,0,1,0,0,0,167,2,147,0,152,30,2,0,120,89,3,0,1,0,0,0,166,2,147,0,232,10,2,0,120,74,3,0,1,0,0,0,165,2,147,0,152,138,8,0,192,61,3,0,1,0,0,0,201,237,146,0,48,119,7,0,120,194,6,0,1,0,0,0,202,237,146,0,112,109,7,0,96,189,6,0,1,0,0,0,203,237,146,0,24,133,7,0,40,246,1,0,1,0,0,0,203,191,145,0,64,246,1,0,144,236,1,0,1,0,0,0,201,191,145,0,136,224,1,0,176,223,1,0,1,0,0,0,227,249,146,0,72,198,1,0,192,209,1,0,1,0,0,0,226,249,146,0,24,182,1,0,24,198,1,0,1,0,0,0,225,249,146,0,40,167,1,0,120,189,1,0,1,0,0,0,224,249,146,0,200,149,1,0,224,22,1,0,1,0,0,0,231,249,146,0,56,126,1,0,160,14,1,0,1,0,0,0,230,249,146,0,32,101,1,0,176,9,1,0,1,0,0,0,229,249,146,0,96,32,8,0,200,3,1,0,1,0,0,0,205,237,146,0,16,68,7,0,208,183,6,0,1,0,0,0,206,237,146,0,240,58,7,0,200,177,6,0,1,0,0,0,207,237,146,0,200,42,1,0,88,212,3,0,1,0,0,0,24,222,146,0,40,185,3,0,16,17,8,0,1,0,0,0,204,191,145,0,224,12,8,0,72,65,1,0,9,0,0,0,53,225,146,0,32,58,1,0,48,50,1,0,9,0,0,0,54,225,146,0,32,58,1,0,224,41,1,0,9,0,0,0,55,225,146,0,32,58,1,0,112,103,97,106,95,98,108,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,108,103,239,79,1,0,16,1,112,103,97,106,95,98,108,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,59,189,105,160,1,0,16,1,112,103,97,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,152,193,148,81,5,0,32,0,112,103,97,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,63,232,148,183,5,0,32,0,112,103,97,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,24,41,242,135,5,0,32,0,112,103,97,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,91,180,255,101,5,0,32,0,112,103,97,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,146,169,191,189,10,0,16,1,112,103,97,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,78,34,221,171,12,0,64,0,112,103,97,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,6,52,197,218,12,0,64,0,184,40,2,0,1,0,0,0,8,82,148,0,248,191,2,0,56,250,6,0,1,0,0,0,31,82,148,0,184,160,2,0,184,164,8,0,1,0,0,0,9,82,148,0,64,246,1,0,88,149,7,0,1,0,0,0,23,82,148,0,136,224,1,0,56,210,6,0,1,0,0,0,24,82,148,0,192,135,2,0,24,163,6,0,1,0,0,0,25,82,148,0,240,108,2,0,152,122,6,0,1,0,0,0,26,82,148,0,96,82,2,0,192,72,6,0,1,0,0,0,27,82,148,0,32,56,2,0,48,123,2,0,1,0,0,0,28,82,148,0,152,30,2,0,96,69,2,0,1,0,0,0,29,82,148,0,232,10,2,0,144,55,2,0,1,0,0,0,30,82,148,0,152,138,8,0,176,223,1,0,1,0,0,0,16,82,148,0,72,198,1,0,192,209,1,0,1,0,0,0,17,82,148,0,24,182,1,0,24,198,1,0,1,0,0,0,18,82,148,0,40,167,1,0,120,189,1,0,1,0,0,0,19,82,148,0,200,149,1,0,248,187,8,0,1,0,0,0,20,82,148,0,56,126,1,0,184,179,8,0,1,0,0,0,21,82,148,0,32,101,1,0,240,173,8,0,1,0,0,0,22,82,148,0,96,32,8,0,88,212,3,0,1,0,0,0,232,227,148,0,40,185,3,0,16,17,8,0,1,0,0,0,10,82,148,0,224,12,8,0,32,77,1,0,1,0,0,0,11,82,148,0,216,70,1,0,56,58,1,0,1,0,0,0,12,82,148,0,64,50,1,0,248,5,8,0,9,0,0,0,8,70,215,0,32,58,1,0,144,250,7,0,9,0,0,0,9,70,215,0,32,58,1,0,168,86,7,0,1,0,0,0,92,238,146,0,248,191,2,0,24,38,7,0,1,0,0,0,199,251,146,0,184,160,2,0,200,110,3,0,1,0,0,0,196,251,146,0,152,30,2,0,120,89,3,0,1,0,0,0,197,251,146,0,232,10,2,0,240,251,8,0,4,0,0,0,216,7,147,0,208,13,4,0,40,246,1,0,1,0,0,0,93,238,146,0,64,246,1,0,144,236,1,0,1,0,0,0,143,243,146,0,136,224,1,0,224,22,1,0,1,0,0,0,140,243,146,0,56,126,1,0,160,14,1,0,1,0,0,0,141,243,146,0,32,101,1,0,112,188,8,0,4,0,0,0,218,7,147,0,136,7,4,0,88,212,3,0,1,0,0,0,120,216,146,0,40,185,3,0,16,17,8,0,1,0,0,0,88,238,146,0,224,12,8,0,56,58,1,0,1,0,0,0,89,238,146,0,64,50,1,0,72,65,1,0,9,0,0,0,216,3,147,0,32,58,1,0,48,50,1,0,9,0,0,0,217,3,147,0,32,58,1,0,168,86,7,0,1,0,0,0,104,250,146,0,248,191,2,0,24,38,7,0,1,0,0,0,71,242,146,0,184,160,2,0,56,210,6,0,1,0,0,0,64,242,146,0,192,135,2,0,24,163,6,0,1,0,0,0,65,242,146,0,240,108,2,0,152,122,6,0,1,0,0,0,66,242,146,0,96,82,2,0,192,72,6,0,1,0,0,0,67,242,146,0,32,56,2,0,200,110,3,0,1,0,0,0,68,242,146,0,152,30,2,0,120,89,3,0,1,0,0,0,69,242,146,0,232,10,2,0,120,74,3,0,1,0,0,0,70,242,146,0,152,138,8,0,40,246,1,0,1,0,0,0,105,250,146,0,64,246,1,0,144,236,1,0,1,0,0,0,79,242,146,0,136,224,1,0,176,223,1,0,1,0,0,0,72,242,146,0,72,198,1,0,192,209,1,0,1,0,0,0,73,242,146,0,24,182,1,0,24,198,1,0,1,0,0,0,74,242,146,0,40,167,1,0,120,189,1,0,1,0,0,0,75,242,146,0,200,149,1,0,224,22,1,0,1,0,0,0,76,242,146,0,56,126,1,0,160,14,1,0,1,0,0,0,77,242,146,0,32,101,1,0,176,9,1,0,1,0,0,0,78,242,146,0,96,32,8,0,88,212,3,0,1,0,0,0,88,215,146,0,40,185,3,0,16,17,8,0,1,0,0,0,106,250,146,0,224,12,8,0,72,65,1,0,9,0,0,0,104,3,147,0,32,58,1,0,48,50,1,0,9,0,0,0,105,3,147,0,32,58,1,0,48,53,46,49,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,106,225,24,250,0,0,16,1,48,54,46,49,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,70,118,251,162,0,0,16,1,112,107,111,45,48,48,49,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,155,93,173,30,0,0,32,0,112,107,111,45,48,48,51,46,56,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,230,180,154,51,0,0,32,0,112,107,111,45,48,48,50,46,57,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,134,37,240,28,0,0,32,0,112,107,111,45,48,48,52,46,57,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,66,180,204,9,0,0,32,0,112,107,111,45,99,104,114,49,46,50,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,205,51,206,49,0,0,32,0,112,107,111,45,99,104,114,50,46,51,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,95,5,126,173,0,0,32,0,112,107,111,45,118,111,105,49,46,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,49,245,224,7,0,0,64,0,112,107,111,45,118,111,105,50,46,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,246,139,57,24,0,0,64,0,184,40,2,0,1,0,0,0,231,233,148,0,248,191,2,0,56,250,6,0,1,0,0,0,34,233,148,0,184,160,2,0,88,149,7,0,1,0,0,0,194,231,148,0,136,224,1,0,240,219,7,0,1,0,0,0,39,233,148,0,88,94,5,0,176,210,7,0,1,0,0,0,111,232,148,0,40,90,5,0,232,198,7,0,1,0,0,0,247,231,148,0,128,83,5,0,192,184,7,0,1,0,0,0,215,231,148,0,168,77,5,0,16,177,7,0,1,0,0,0,38,233,148,0,0,69,5,0,0,169,7,0,1,0,0,0,37,233,148,0,152,30,2,0,0,193,5,0,1,0,0,0,109,232,148,0,232,10,2,0,232,159,7,0,1,0,0,0,245,231,148,0,152,138,8,0,176,155,7,0,1,0,0,0,199,231,148,0,88,94,5,0,120,150,7,0,1,0,0,0,191,231,148,0,40,90,5,0,16,144,7,0,1,0,0,0,183,231,148,0,128,83,5,0,112,138,7,0,1,0,0,0,31,218,148,0,168,77,5,0,160,133,7,0,1,0,0,0,198,231,148,0,0,69,5,0,40,130,7,0,1,0,0,0,197,231,148,0,56,126,1,0,72,20,5,0,1,0,0,0,189,231,148,0,32,101,1,0,232,123,7,0,1,0,0,0,181,231,148,0,96,32,8,0,88,212,3,0,1,0,0,0,80,219,146,0,40,185,3,0,16,17,8,0,1,0,0,0,224,233,148,0,224,12,8,0,32,77,1,0,1,0,0,0,25,232,148,0,216,70,1,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,168,86,7,0,1,0,0,0,35,191,145,0,248,191,2,0,24,38,7,0,1,0,0,0,37,191,145,0,184,160,2,0,56,210,6,0,1,0,0,0,8,251,146,0,192,135,2,0,24,163,6,0,1,0,0,0,9,251,146,0,240,108,2,0,152,122,6,0,1,0,0,0,10,251,146,0,96,82,2,0,192,72,6,0,1,0,0,0,11,251,146,0,32,56,2,0,200,110,3,0,1,0,0,0,12,251,146,0,152,30,2,0,120,89,3,0,1,0,0,0,13,251,146,0,232,10,2,0,40,246,1,0,1,0,0,0,36,191,145,0,64,246,1,0,144,236,1,0,1,0,0,0,38,191,145,0,136,224,1,0,176,223,1,0,1,0,0,0,224,242,146,0,72,198,1,0,192,209,1,0,1,0,0,0,225,242,146,0,24,182,1,0,24,198,1,0,1,0,0,0,226,242,146,0,40,167,1,0,120,189,1,0,1,0,0,0,227,242,146,0,200,149,1,0,224,22,1,0,1,0,0,0,228,242,146,0,56,126,1,0,160,14,1,0,1,0,0,0,229,242,146,0,32,101,1,0,88,212,3,0,1,0,0,0,192,215,146,0,40,185,3,0,16,17,8,0,1,0,0,0,32,191,145,0,224,12,8,0,56,58,1,0,1,0,0,0,33,191,145,0,64,50,1,0,72,65,1,0,9,0,0,0,83,223,146,0,32,58,1,0,48,50,1,0,9,0,0,0,84,223,146,0,32,58,1,0,224,41,1,0,9,0,0,0,85,223,146,0,32,58,1,0,184,40,2,0,1,0,0,0,40,39,216,0,248,191,2,0,56,250,6,0,1,0,0,0,32,39,216,0,184,160,2,0,184,164,8,0,1,0,0,0,41,39,216,0,64,246,1,0,88,149,7,0,1,0,0,0,33,39,216,0,136,224,1,0,240,167,7,0,1,0,0,0,47,39,216,0,192,135,2,0,176,163,7,0,1,0,0,0,45,39,216,0,240,108,2,0,208,158,7,0,1,0,0,0,42,39,216,0,96,82,2,0,184,154,7,0,1,0,0,0,43,39,216,0,32,56,2,0,176,108,2,0,1,0,0,0,44,39,216,0,152,30,2,0,8,96,7,0,1,0,0,0,46,39,216,0,72,198,1,0,48,89,7,0,1,0,0,0,37,39,216,0,24,182,1,0,16,83,7,0,1,0,0,0,34,39,216,0,40,167,1,0,96,79,7,0,1,0,0,0,35,39,216,0,200,149,1,0,48,76,7,0,1,0,0,0,36,39,216,0,56,126,1,0,88,212,3,0,1,0,0,0,48,38,216,0,40,185,3,0,248,5,8,0,9,0,0,0,112,39,216,0,32,58,1,0,144,250,7,0,9,0,0,0,113,39,216,0,32,58,1,0,248,241,7,0,9,0,0,0,114,39,216,0,32,58,1,0,101,112,114,45,49,49,56,51,51,46,52,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,92,64,177,94,1,0,16,1,101,112,114,45,49,49,56,51,50,46,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,228,63,138,113,1,0,16,1,101,112,114,45,49,49,56,51,52,46,57,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,171,24,78,223,2,0,32,0,101,112,114,45,49,49,56,51])
.concat([53,46,57,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,192,172,7,106,2,0,32,0,101,112,114,45,49,49,56,51,54,46,57,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,40,73,199,147,2,0,32,0,101,112,114,45,49,49,56,52,50,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,39,71,233,182,3,0,32,0,101,112,114,45,49,49,56,52,53,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,213,213,232,23,3,0,32,0,101,112,114,45,49,49,56,52,51,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,152,0,103,62,3,0,32,0,101,112,114,45,49,49,56,52,54,46,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,204,113,235,80,3,0,32,0,101,112,114,45,49,49,56,52,52,46,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,168,60,115,5,3,0,32,0,101,112,114,45,49,49,56,52,55,46,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,151,150,228,129,3,0,32,0,101,112,114,45,49,49,56,51,55,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,82,21,209,116,4,0,16,1,55,55,53,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,252,52,149,106,6,0,16,1,101,112,114,45,49,49,56,51,56,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,105,205,101,164,7,0,64,0,101,112,114,45,49,49,56,51,57,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,151,97,222,153,7,0,64,0,101,112,114,45,49,49,56,52,48,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,179,232,84,152,7,0,64,0,101,112,114,45,49,49,56,52,49,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,126,135,137,30,7,0,64,0,51,49,55,45,48,48,55,49,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,236,73,153,198,5,0,16,1,41,0,0,0,255,255,255,0,0,0,0,0,42,0,0,0,255,255,240,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,41,0,0,0,1,15,7,0,80,252,6,0,41,0,0,0,1,15,8,0,16,242,7,0,41,0,0,0,1,15,9,0,104,236,7,0,41,0,0,0,1,15,5,0,176,51,4,0,41,0,0,0,1,15,4,0,56,24,4,0,41,0,0,0,1,15,15,0,128,230,7,0,41,0,0,0,1,15,1,0,72,216,3,0,41,0,0,0,1,15,2,0,24,188,3,0,41,0,0,0,1,15,3,0,176,162,3,0,41,0,0,0,1,15,6,0,120,211,6,0,41,0,0,0,1,15,14,0,184,164,6,0,41,0,0,0,1,15,13,0,80,74,6,0,41,0,0,0,1,15,12,0,192,32,6,0,41,0,0,0,1,15,11,0,192,234,2,0,41,0,0,0,1,15,10,0,32,242,5,0,41,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,41,0,0,0,1,240,112,0,80,252,6,0,41,0,0,0,1,240,128,0,16,242,7,0,41,0,0,0,1,240,144,0,104,236,7,0,41,0,0,0,1,240,80,0,176,51,4,0,41,0,0,0,1,240,64,0,56,24,4,0,41,0,0,0,1,240,240,0,128,230,7,0,41,0,0,0,1,240,16,0,72,216,3,0,41,0,0,0,1,240,32,0,24,188,3,0,41,0,0,0,1,240,48,0,176,162,3,0,41,0,0,0,1,240,96,0,120,211,6,0,41,0,0,0,1,240,224,0,184,164,6,0,41,0,0,0,1,240,208,0,80,74,6,0,41,0,0,0,1,240,192,0,192,32,6,0,41,0,0,0,1,240,176,0,192,234,2,0,41,0,0,0,1,240,160,0,32,242,5,0,41,0,0,0,1,240,0,0,208,236,2,0,0,0,0,0,254,0,2,0,168,234,7,0,42,0,0,0,1,1,1,0,96,135,7,0,42,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,8,0,184,127,3,0,42,0,0,0,1,14,6,0,184,230,7,0,42,0,0,0,1,14,10,0,72,123,3,0,42,0,0,0,1,14,12,0,152,120,3,0,42,0,0,0,1,14,14,0,136,120,6,0,42,0,0,0,1,14,8,0,160,118,3,0,42,0,0,0,1,14,4,0,176,114,3,0,42,0,0,0,1,14,2,0,32,112,3,0,42,0,0,0,1,14,0,0,104,109,3,0,0,0,0,0,254,0,4,0,112,107,3,0,42,0,0,0,1,48,32,0,80,246,3,0,42,0,0,0,1,48,48,0,248,38,7,0,42,0,0,0,1,48,16,0,112,212,3,0,42,0,0,0,1,48,0,0,248,160,5,0,0,0,0,0,254,0,4,0,72,202,5,0,42,0,0,0,1,192,128,0,80,246,3,0,42,0,0,0,1,192,192,0,248,38,7,0,42,0,0,0,1,192,64,0,112,212,3,0,42,0,0,0,1,192,0,0,248,160,5,0,168,86,7,0,1,0,0,0,234,240,146,0,248,191,2,0,24,38,7,0,1,0,0,0,200,1,147,0,184,160,2,0,56,210,6,0,1,0,0,0,201,1,147,0,192,135,2,0,24,163,6,0,1,0,0,0,202,1,147,0,240,108,2,0,152,122,6,0,1,0,0,0,203,1,147,0,96,82,2,0,192,72,6,0,1,0,0,0,204,1,147,0,32,56,2,0,200,110,3,0,1,0,0,0,205,1,147,0,152,30,2,0,120,89,3,0,1,0,0,0,206,1,147,0,232,10,2,0,120,74,3,0,1,0,0,0,207,1,147,0,152,138,8,0,40,246,1,0,1,0,0,0,235,240,146,0,64,246,1,0,144,236,1,0,1,0,0,0,8,249,146,0,136,224,1,0,176,223,1,0,1,0,0,0,9,249,146,0,72,198,1,0,192,209,1,0,1,0,0,0,10,249,146,0,24,182,1,0,24,198,1,0,1,0,0,0,11,249,146,0,40,167,1,0,120,189,1,0,1,0,0,0,12,249,146,0,200,149,1,0,224,22,1,0,1,0,0,0,13,249,146,0,56,126,1,0,160,14,1,0,1,0,0,0,14,249,146,0,32,101,1,0,176,9,1,0,1,0,0,0,15,249,146,0,96,32,8,0,88,212,3,0,1,0,0,0,72,221,146,0,40,185,3,0,32,77,1,0,1,0,0,0,233,240,146,0,216,70,1,0,16,17,8,0,1,0,0,0,232,240,146,0,224,12,8,0,72,65,1,0,9,0,0,0,16,7,147,0,32,58,1,0,48,50,1,0,9,0,0,0,17,7,147,0,32,58,1,0,224,41,1,0,9,0,0,0,18,7,147,0,32,58,1,0,184,40,2,0,1,0,0,0,40,39,216,0,248,191,2,0,56,250,6,0,1,0,0,0,32,39,216,0,184,160,2,0,184,164,8,0,1,0,0,0,41,39,216,0,64,246,1,0,88,149,7,0,1,0,0,0,33,39,216,0,136,224,1,0,240,167,7,0,1,0,0,0,47,39,216,0,192,135,2,0,176,163,7,0,1,0,0,0,45,39,216,0,240,108,2,0,208,158,7,0,1,0,0,0,42,39,216,0,96,82,2,0,184,154,7,0,1,0,0,0,43,39,216,0,32,56,2,0,8,96,7,0,1,0,0,0,46,39,216,0,72,198,1,0,48,89,7,0,1,0,0,0,37,39,216,0,24,182,1,0,16,83,7,0,1,0,0,0,34,39,216,0,40,167,1,0,96,79,7,0,1,0,0,0,35,39,216,0,200,149,1,0,88,212,3,0,1,0,0,0,48,38,216,0,40,185,3,0,248,5,8,0,9,0,0,0,112,39,216,0,32,58,1,0,144,250,7,0,9,0,0,0,113,39,216,0,32,58,1,0,248,241,7,0,9,0,0,0,114,39,216,0,32,58,1,0,98,54,55,45,50,48,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,162,158,67,33,2,0,16,1,98,54,55,45,50,50,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,60,173,153,15,2,0,16,1,98,54,55,45,49,52,46,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,36,215,61,127,2,0,16,1,98,54,55,45,49,53,46,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,208,98,79,232,2,0,16,1,98,54,55,45,49,51,46,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,177,180,54,41,9,0,16,1,98,54,55,45,48,54,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,100,141,163,185,11,0,32,0,98,54,55,45,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,203,154,173,129,17,0,32,0,98,54,55,45,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,251,210,12,194,17,0,32,0,98,54,55,45,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,237,25,144,188,17,0,32,0,98,54,55,45,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,175,200,244,42,17,0,32,0,98,54,55,45,48,53,46,52,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,43,228,147,149,23,0,32,0,98,54,55,45,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,251,65,143,69,24,0,64,0,98,54,55,45,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,87,67,131,79,25,0,64,0,101,101,112,114,111,109,45,111,116,104,117,110,100,101,114,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,68,184,41,55,32,0,16,0,112,108,104,115,49,56,112,56,98,45,98,54,55,45,48,57,46,105,99,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,73,1,0,0,135,84,3,98,0,0,0,8,112,97,108,49,54,108,56,97,45,98,54,55,45,49,49,46,105,99,51,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,6,251,119,49,0,0,0,8,112,97,108,50,48,108,56,98,45,98,54,55,45,49,50,46,105,99,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,1,0,0,152,39,124,164,0,0,0,8,112,97,108,50,48,108,56,98,45,98,54,55,45,49,48,46,105,99,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,1,0,0,199,9,237,76,0,0,0,8,184,40,2,0,1,0,0,0,139,151,215,0,248,191,2,0,56,250,6,0,1,0,0,0,142,151,215,0,184,160,2,0,184,164,8,0,1,0,0,0,138,151,215,0,64,246,1,0,88,149,7,0,1,0,0,0,143,151,215,0,136,224,1,0,152,225,1,0,4,0,0,0,104,150,215,0,152,210,1,0,152,198,1,0,4,0,0,0,96,150,215,0,208,189,1,0,48,123,2,0,1,0,0,0,120,151,215,0,248,174,1,0,96,69,2,0,1,0,0,0,122,151,215,0,104,160,1,0,88,150,1,0,4,0,0,0,88,150,215,0,136,7,4,0,144,126,1,0,4,0,0,0,80,150,215,0,136,113,1,0,248,187,8,0,1,0,0,0,121,151,215,0,56,126,1,0,184,179,8,0,1,0,0,0,123,151,215,0,32,101,1,0,88,212,3,0,1,0,0,0,200,147,215,0,40,185,3,0,16,17,8,0,1,0,0,0,140,151,215,0,224,12,8,0,248,5,8,0,9,0,0,0,152,151,215,0,32,58,1,0,144,250,7,0,9,0,0,0,153,151,215,0,32,58,1,0,248,241,7,0,9,0,0,0,96,149,215,0,32,58,1,0,184,40,2,0,1,0,0,0,40,39,216,0,248,191,2,0,56,250,6,0,1,0,0,0,32,39,216,0,184,160,2,0,184,164,8,0,1,0,0,0,41,39,216,0,64,246,1,0,88,149,7,0,1,0,0,0,33,39,216,0,136,224,1,0,240,167,7,0,1,0,0,0,47,39,216,0,192,135,2,0,176,163,7,0,1,0,0,0,46,39,216,0,240,108,2,0,208,158,7,0,1,0,0,0,42,39,216,0,96,82,2,0,184,154,7,0,1,0,0,0,43,39,216,0,32,56,2,0,176,108,2,0,1,0,0,0,44,39,216,0,152,30,2,0,8,96,7,0,1,0,0,0,39,39,216,0,72,198,1,0,48,89,7,0,1,0,0,0,45,39,216,0,24,182,1,0,16,83,7,0,1,0,0,0,34,39,216,0,40,167,1,0,96,79,7,0,1,0,0,0,35,39,216,0,200,149,1,0,48,76,7,0,1,0,0,0,36,39,216,0,56,126,1,0,88,212,3,0,1,0,0,0,48,38,216,0,40,185,3,0,248,5,8,0,9,0,0,0,112,39,216,0,32,58,1,0,144,250,7,0,9,0,0,0,113,39,216,0,32,58,1,0,248,241,7,0,9,0,0,0,114,39,216,0,32,58,1,0,168,86,7,0,1,0,0,0,12,252,146,0,248,191,2,0,24,38,7,0,1,0,0,0,8,252,146,0,184,160,2,0,56,210,6,0,1,0,0,0,213,243,146,0,192,135,2,0,24,163,6,0,1,0,0,0,212,243,146,0,240,108,2,0,152,122,6,0,1,0,0,0,210,243,146,0,96,82,2,0,192,72,6,0,1,0,0,0,211,243,146,0,32,56,2,0,200,110,3,0,1,0,0,0,208,243,146,0,152,30,2,0,120,89,3,0,1,0,0,0,209,243,146,0,232,10,2,0,40,246,1,0,1,0,0,0,13,252,146,0,64,246,1,0,144,236,1,0,1,0,0,0,9,252,146,0,136,224,1,0,176,223,1,0,1,0,0,0,109,238,146,0,72,198,1,0,192,209,1,0,1,0,0,0,108,238,146,0,24,182,1,0,24,198,1,0,1,0,0,0,106,238,146,0,40,167,1,0,120,189,1,0,1,0,0,0,107,238,146,0,200,149,1,0,224,22,1,0,1,0,0,0,104,238,146,0,56,126,1,0,160,14,1,0,1,0,0,0,105,238,146,0,32,101,1,0,88,212,3,0,1,0,0,0,176,216,146,0,40,185,3,0,16,17,8,0,1,0,0,0,10,252,146,0,224,12,8,0,56,58,1,0,1,0,0,0,11,252,146,0,64,50,1,0,72,65,1,0,9,0,0,0,248,3,147,0,32,58,1,0,48,50,1,0,9,0,0,0,249,3,147,0,32,58,1,0,224,41,1,0,9,0,0,0,250,3,147,0,32,58,1,0,168,86,7,0,1,0,0,0,136,239,146,0,248,191,2,0,24,38,7,0,1,0,0,0,223,254,146,0,184,160,2,0,56,210,6,0,1,0,0,0,218,254,146,0,192,135,2,0,24,163,6,0,1,0,0,0,219,254,146,0,240,108,2,0,152,122,6,0,1,0,0,0,216,254,146,0,96,82,2,0,192,72,6,0,1,0,0,0,217,254,146,0,32,56,2,0,200,110,3,0,1,0,0,0,220,254,146,0,152,30,2,0,120,89,3,0,1,0,0,0,221,254,146,0,232,10,2,0,144,236,1,0,1,0,0,0,127,246,146,0,136,224,1,0,176,223,1,0,1,0,0,0,122,246,146,0,72,198,1,0,192,209,1,0,1,0,0,0,123,246,146,0,24,182,1,0,24,198,1,0,1,0,0,0,120,246,146,0,40,167,1,0,120,189,1,0,1,0,0,0,121,246,146,0,200,149,1,0,224,22,1,0,1,0,0,0,124,246,146,0,56,126,1,0,160,14,1,0,1,0,0,0,125,246,146,0,32,101,1,0,88,212,3,0,1,0,0,0,160,218,146,0,40,185,3,0,16,17,8,0,1,0,0,0,138,239,146,0,224,12,8,0,16,17,8,0,1,0,0,0,139,239,146,0,224,12,8,0,72,65,1,0,9,0,0,0,48,5,147,0,32,58,1,0,48,50,1,0,9,0,0,0,49,5,147,0,32,58,1,0,224,41,1,0,9,0,0,0,50,5,147,0,32,58,1,0,168,86,7,0,1,0,0,0,152,242,146,0,248,191,2,0,24,38,7,0,1,0,0,0,199,250,146,0,184,160,2,0,56,210,6,0,1,0,0,0,192,250,146,0,192,135,2,0,24,163,6,0,1,0,0,0,193,250,146,0,240,108,2,0,152,122,6,0,1,0,0,0,194,250,146,0,96,82,2,0,192,72,6,0,1,0,0,0,195,250,146,0,32,56,2,0,200,110,3,0,1,0,0,0,196,250,146,0,152,30,2,0,120,89,3,0,1,0,0,0,197,250,146,0,232,10,2,0,40,246,1,0,1,0,0,0,153,242,146,0,64,246,1,0,144,236,1,0,1,0,0,0,207,250,146,0,136,224,1,0,176,223,1,0,1,0,0,0,200,250,146,0,72,198,1,0,192,209,1,0,1,0,0,0,201,250,146,0,24,182,1,0,24,198,1,0,1,0,0,0,202,250,146,0,40,167,1,0,120,189,1,0,1,0,0,0,203,250,146,0,200,149,1,0,224,22,1,0,1,0,0,0,204,250,146,0,56,126,1,0,160,14,1,0,1,0,0,0,205,250,146,0,32,101,1,0,168,132,8,0,1,0,0,0,15,238,146,0,232,209,1,0,192,122,8,0,1,0,0,0,8,238,146,0,208,174,1,0,40,116,8,0,1,0,0,0,9,238,146,0,48,160,1,0,72,110,8,0,1,0,0,0,10,238,146,0,160,140,1,0,184,102,8,0,1,0,0,0,11,238,146,0,56,112,1,0,248,67,8,0,1,0,0,0,12,238,146,0,32,92,1,0,136,64,8,0,1,0,0,0,13,238,146,0,64,77,1,0,88,212,3,0,1,0,0,0,136,215,146,0,40,185,3,0,16,17,8,0,1,0,0,0,154,242,146,0,224,12,8,0,72,65,1,0,9,0,0,0,144,3,147,0,32,58,1,0,48,50,1,0,9,0,0,0,145,3,147,0,32,58,1,0,184,40,2,0,1,0,0,0,141,151,215,0,248,191,2,0,56,250,6,0,1,0,0,0,120,151,215,0,184,160,2,0,184,164,8,0,1,0,0,0,140,151,215,0,64,246,1,0,88,149,7,0,1,0,0,0,121,151,215,0,136,224,1,0,64,9,7,0,4,0,0,0,104,150,215,0,208,13,4,0,96,2,7,0,4,0,0,0,96,150,215,0,184,198,5,0,176,108,2,0,1,0,0,0,126,151,215,0,152,30,2,0,128,98,2,0,1,0,0,0,127,151,215,0,232,10,2,0,88,212,3,0,1,0,0,0,200,147,215,0,40,185,3,0,16,17,8,0,1,0,0,0,142,151,215,0,224,12,8,0,56,58,1,0,1,0,0,0,143,151,215,0,64,50,1,0,248,5,8,0,9,0,0,0,152,151,215,0,32,58,1,0,144,250,7,0,9,0,0,0,153,151,215,0,32,58,1,0,168,86,7,0,1,0,0,0,136,239,146,0,248,191,2,0,24,38,7,0,1,0,0,0,223,254,146,0,184,160,2,0,56,210,6,0,1,0,0,0,218,254,146,0,192,135,2,0,24,163,6,0,1,0,0,0,219,254,146,0,240,108,2,0,152,122,6,0,1,0,0,0,216,254,146,0,96,82,2,0,192,72,6,0,1,0,0,0,217,254,146,0,32,56,2,0,200,110,3,0,1,0,0,0,220,254,146,0,152,30,2,0,40,246,1,0,1,0,0,0,137,239,146,0,64,246,1,0,144,236,1,0,1,0,0,0,127,246,146,0,136,224,1,0,176,223,1,0,1,0,0,0,122,246,146,0,72,198,1,0,192,209,1,0,1,0,0,0,123,246,146,0,24,182,1,0,24,198,1,0,1,0,0,0,120,246,146,0,40,167,1,0,120,189,1,0,1,0,0,0,121,246,146,0,200,149,1,0,224,22,1,0,1,0,0,0,124,246,146,0,56,126,1,0,88,212,3,0,1,0,0,0,160,218,146,0,40,185,3,0,16,17,8,0,1,0,0,0,138,239,146,0,224,12,8,0,56,58,1,0,1,0,0,0,139,239,146,0,64,50,1,0,72,65,1,0,9,0,0,0,48,5,147,0,32,58,1,0,48,50,1,0,9,0,0,0,49,5,147,0,32,58,1,0,224,41,1,0,9,0,0,0,50,5,147,0,32,58,1,0,184,40,2,0,1,0,0,0,56,244,146,0,248,191,2,0,184,164,8,0,1,0,0,0,57,244,146,0,64,246,1,0,24,38,7,0,1,0,0,0,58,244,146,0,184,160,2,0,56,210,6,0,1,0,0,0,120,252,146,0,192,135,2,0,24,163,6,0,1,0,0,0,121,252,146,0,240,108,2,0,152,122,6,0,1,0,0,0,122,252,146,0,96,82,2,0,192,72,6,0,1,0,0,0,123,252,146,0,32,56,2,0,200,110,3,0,1,0,0,0,124,252,146,0,152,30,2,0,120,89,3,0,1,0,0,0,125,252,146,0,232,10,2,0,144,236,1,0,1,0,0,0,59,244,146,0,136,224,1,0,176,223,1,0,1,0,0,0,128,252,146,0,72,198,1,0,192,209,1,0,1,0,0,0,129,252,146,0,24,182,1,0,24,198,1,0,1,0,0,0,130,252,146,0,40,167,1,0,120,189,1,0,1,0,0,0,131,252,146,0,200,149,1,0,224,22,1,0,1,0,0,0,132,252,146,0,56,126,1,0,160,14,1,0,1,0,0,0,133,252,146,0,32,101,1,0,16,17,8,0,1,0,0,0,144,238,146,0,224,12,8,0,88,212,3,0,1,0,0,0,0,217,146,0,40,185,3,0,248,5,8,0,9,0,0,0,48,4,147,0,32,58,1,0,144,250,7,0,9,0,0,0,49,4,147,0,32,58,1,0,168,86,7,0,1,0,0,0,176,252,146,0,248,191,2,0,24,38,7,0,1,0,0,0,175,252,146,0,184,160,2,0,56,210,6,0,1,0,0,0,170,252,146,0,192,135,2,0,24,163,6,0,1,0,0,0,171,252,146,0,240,108,2,0,152,122,6,0,1,0,0,0,169,252,146,0,96,82,2,0,192,72,6,0,1,0,0,0,168,252,146,0,32,56,2,0,200,110,3,0,1,0,0,0,172,252,146,0,152,30,2,0,120,89,3,0,1,0,0,0,173,252,146,0,232,10,2,0,120,74,3,0,1,0,0,0,174,252,146,0,152,138,8,0,40,246,1,0,1,0,0,0,177,252,146,0,64,246,1,0,144,236,1,0,1,0,0,0,95,244,146,0,136,224,1,0,176,223,1,0,1,0,0,0,90,244,146,0,72,198,1,0,192,209,1,0,1,0,0,0,91,244,146,0,24,182,1,0,24,198,1,0,1,0,0,0,89,244,146,0,40,167,1,0,120,189,1,0,1,0,0,0,88,244,146,0,200,149,1,0,224,22,1,0,1,0,0,0,92,244,146,0,56,126,1,0,160,14,1,0,1,0,0,0,93,244,146,0,32,101,1,0,176,9,1,0,1,0,0,0,94,244,146,0,96,32,8,0,88,212,3,0,1,0,0,0,24,217,146,0,40,185,3,0,72,65,1,0,9,0,0,0,64,4,147,0,32,58,1,0,48,50,1,0,9,0,0,0,65,4,147,0,32,58,1,0,224,41,1,0,9,0,0,0,66,4,147,0,32,58,1,0,168,169,1,0,9,0,0,0,67,4,147,0,32,58,1,0,184,40,2,0,1,0,0,0,231,233,148,0,248,191,2,0,56,250,6,0,1,0,0,0,227,233,148,0,184,160,2,0,184,164,8,0,1,0,0,0,229,233,148,0,64,246,1,0,88,149,7,0,1,0,0,0,225,233,148,0,136,224,1,0,56,210,6,0,1,0,0,0,39,233,148,0,192,135,2,0,24,163,6,0,1,0,0,0,38,233,148,0,240,108,2,0,152,122,6,0,1,0,0,0,37,233,148,0,96,82,2,0,192,72,6,0,1,0,0,0,36,233,148,0,32,56,2,0,48,123,2,0,1,0,0,0,35,233,148,0,152,30,2,0,96,69,2,0,1,0,0,0,34,233,148,0,232,10,2,0,144,55,2,0,1,0,0,0,33,233,148,0,152,138,8,0,176,223,1,0,1,0,0,0,111,232,148,0,72,198,1,0,192,209,1,0,1,0,0,0,110,232,148,0,24,182,1,0,24,198,1,0,1,0,0,0,109,232,148,0,40,167,1,0,120,189,1,0,1,0,0,0,108,232,148,0,200,149,1,0,248,187,8,0,1,0,0,0,107,232,148,0,56,126,1,0,184,179,8,0,1,0,0,0,106,232,148,0,32,101,1,0,240,173,8,0,1,0,0,0,105,232,148,0,96,32,8,0,88,212,3,0,1,0,0,0,80,219,146,0,40,185,3,0,16,17,8,0,1,0,0,0,230,233,148,0,224,12,8,0,32,77,1,0,1,0,0,0,25,232,148,0,216,70,1,0,248,5,8,0,9,0,0,0,128,94,147,0,32,58,1,0,97,108,105,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,48,230,15,50,1,0,16,1,109,99,115,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,158,15,220,172,1,0,16,1,109,99,115,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,216,245,227,193,1,0,16,1,97,108,105,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,225,105,209,158,1,0,16,1,97,108,105,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,217,82,138,127,1,0,16,1,109,121,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,128,179,1,54,4,0,32,0,109,121,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,50,233,89,182,4,0,32,0,109,121,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,205,6,43,153,4,0,32,0,109,121,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,206,230,96,216,4,0,32,0,109,115,99,112,114,111,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,240,26,13,234,7,0,32,0,109,121,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,32,41,42,82,0,0,64,8,109,121,48,54,46,52,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,77,190,98,65,0,0,64,8,184,40,2,0,1,0,0,0,40,39,216,0,248,191,2,0,56,250,6,0,1,0,0,0,32,39,216,0,184,160,2,0,184,164,8,0,1,0,0,0,41,39,216,0,64,246,1,0,88,149,7,0,1,0,0,0,33,39,216,0,136,224,1,0,240,167,7,0,1,0,0,0,42,39,216,0,192,135,2,0,176,163,7,0,1,0,0,0,43,39,216,0,240,108,2,0,184,154,7,0,1,0,0,0,45,39,216,0,32,56,2,0,176,108,2,0,1,0,0,0,44,39,216,0,152,30,2,0,8,96,7,0,1,0,0,0,34,39,216,0,72,198,1,0,48,89,7,0,1,0,0,0,35,39,216,0,24,182,1,0,96,79,7,0,1,0,0,0,37,39,216,0,200,149,1,0,48,76,7,0,1,0,0,0,36,39,216,0,56,126,1,0,88,212,3,0,1,0,0,0,48,38,216,0,40,185,3,0,248,5,8,0,9,0,0,0,112,39,216,0,32,58,1,0,144,250,7,0,9,0,0,0,113,39,216,0,32,58,1,0,248,241,7,0,9,0,0,0,114,39,216,0,32,58,1,0,184,40,2,0,1,0,0,0,47,39,216,0,248,191,2,0,56,250,6,0,1,0,0,0,39,39,216,0,184,160,2,0,184,164,8,0,1,0,0,0,46,39,216,0,64,246,1,0,88,149,7,0,1,0,0,0,38,39,216,0,136,224,1,0,208,158,7,0,1,0,0,0,45,39,216,0,96,82,2,0,184,154,7,0,1,0,0,0,44,39,216,0,32,56,2,0,176,108,2,0,1,0,0,0,43,39,216,0,152,30,2,0,16,83,7,0,1,0,0,0,37,39,216,0,40,167,1,0,96,79,7,0,1,0,0,0,36,39,216,0,200,149,1,0,48,76,7,0,1,0,0,0,35,39,216,0,56,126,1,0,88,212,3,0,1,0,0,0,48,38,216,0,40,185,3,0,16,17,8,0,1,0,0,0,42,39,216,0,224,12,8,0,248,5,8,0,9,0,0,0,112,39,216,0,32,58,1,0,144,250,7,0,9,0,0,0,113,39,216,0,32,58,1,0,248,241,7,0,9,0,0,0,114,39,216,0,32,58,1,0,109,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,122,74,149,125,1,0,16,1,109,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,250,124,187,68,1,0,16,1,109,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,4,33,65,156,1,0,16,1,109,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,181,26,155,126,1,0,16,1,109,99,53,46,55,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,175,89,199,22,1,0,16,1,109,99,54,46,56,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,219,175,188,105,1,0,16,1,109,99,55,46,56,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,70,188,13,181,1,0,16,1,56,95,117,107,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,212,122,114,206,1,0,16,1,109,99,115,95,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,129,31,15,251,4,0,32,0,109,99,115,95,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,21,42,147,19,4,0,32,0,109,99,115,95,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,90,187,30,99,4,0,32,0,109,99,115,95,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,69,209,207,36,4,0,32,0,109,109,105,54,51,51,49,46,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,135,125,12,106,7,0,32,0,168,86,7,0,1,0,0,0,212,47,216,0,248,191,2,0,24,38,7,0,1,0,0,0,208,47,216,0,184,160,2,0,56,210,6,0,1,0,0,0,35,48,216,0,192,135,2,0,24,163,6,0,1,0,0,0,34,48,216,0,240,108,2,0,152,122,6,0,1,0,0,0,33,48,216,0,96,82,2,0,192,72,6,0,1,0,0,0,32,48,216,0,32,56,2,0,8,246,3,0,1,0,0,0,36,48,216,0,152,30,2,0,40,212,3,0,1,0,0,0,37,48,216,0,232,10,2,0,104,184,3,0,1,0,0,0,38,48,216,0,152,138,8,0,40,246,1,0,1,0,0,0,213,47,216,0,64,246,1,0,144,236,1,0,1,0,0,0,209,47,216,0,136,224,1,0,176,223,1,0,1,0,0,0,43,48,216,0,72,198,1,0,192,209,1,0,1,0,0,0,42,48,216,0,24,182,1,0,24,198,1,0,1,0,0,0,41,48,216,0,40,167,1,0,120,189,1,0,1,0,0,0,40,48,216,0,200,149,1,0,248,57,1,0,1,0,0,0,44,48,216,0,56,126,1,0,40,50,1,0,1,0,0,0,45,48,216,0,32,101,1,0,208,41,1,0,1,0,0,0,46,48,216,0,96,32,8,0,88,212,3,0,1,0,0,0,144,46,216,0,40,185,3,0,240,152,1,0,1,0,0,0,201,47,216,0,216,70,1,0,16,17,8,0,1,0,0,0,202,47,216,0,224,12,8,0,136,67,2,0,1,0,0,0,176,48,216,0,48,119,7,0,8,66,2,0,1,0,0,0,184,48,216,0,112,109,7,0,184,40,2,0,1,0,0,0,137,148,215,0,248,191,2,0,56,250,6,0,1,0,0,0,189,148,215,0,184,160,2,0,184,164,8,0,1,0,0,0,153,148,215,0,64,246,1,0,224,96,5,0,1,0,0,0,184,148,215,0,88,94,5,0,16,92,5,0,1,0,0,0,176,148,215,0,40,90,5,0,200,87,5,0,1,0,0,0,168,148,215,0,128,83,5,0,0,81,5,0,1,0,0,0,160,148,215,0,168,77,5,0,160,73,5,0,1,0,0,0,185,148,215,0,0,69,5,0,80,66,5,0,1,0,0,0,177,148,215,0,32,64,5,0,64,61,5,0,1,0,0,0,169,148,215,0,48,59,5,0,152,56,5,0,1,0,0,0,161,148,215,0,248,53,5,0,240,50,5,0,1,0,0,0,186,148,215,0,0,46,5,0,24,42,5,0,1,0,0,0,178,148,215,0,248,37,5,0,160,34,5,0,1,0,0,0,170,148,215,0,120,32,5,0,200,29,5,0,1,0,0,0,162,148,215,0,192,27,5,0,176,25,5,0,1,0,0,0,187,148,215,0,192,22,5,0,224,19,5,0,1,0,0,0,179,148,215,0,48,16,5,0,160,11,5,0,1,0,0,0,188,148,215,0,24,8,5,0,120,5,5,0,1,0,0,0,163,148,215,0,32,2,5,0,160,254,4,0,1,0,0,0,171,148,215,0,8,252,4,0,0,249,4,0,1,0,0,0,180,148,215,0,56,244,4,0,248,240,4,0,1,0,0,0,172,148,215,0,128,237,4,0,88,212,3,0,1,0,0,0,200,147,215,0,40,185,3,0,16,17,8,0,1,0,0,0,136,148,215,0,224,12,8,0,56,58,1,0,1,0,0,0,152,148,215,0,64,50,1,0,248,5,8,0,9,0,0,0,96,149,215,0,32,58,1,0,144,250,7,0,9,0,0,0,97,149,215,0,32,58,1,0,184,40,2,0,1,0,0,0,208,155,215,0,248,191,2,0,56,250,6,0,1,0,0,0,212,155,215,0,184,160,2,0,184,164,8,0,1,0,0,0,209,155,215,0,64,246,1,0,88,149,7,0,1,0,0,0,213,155,215,0,136,224,1,0,56,210,6,0,1,0,0,0,186,155,215,0,192,135,2,0,24,163,6,0,1,0,0,0,187,155,215,0,240,108,2,0,152,122,6,0,1,0,0,0,184,155,215,0,96,82,2,0,192,72,6,0,1,0,0,0,185,155,215,0,32,56,2,0,48,123,2,0,1,0,0,0,207,155,215,0,152,30,2,0,96,69,2,0,1,0,0,0,200,155,215,0,232,10,2,0,144,55,2,0,1,0,0,0,201,155,215,0,152,138,8,0,80,123,7,0,1,0,0,0,202,155,215,0,48,119,7,0,112,114,7,0,1,0,0,0,203,155,215,0,112,109,7,0,88,207,4,0,4,0,0,0,112,156,215,0,136,191,7,0,56,210,6,0,1,0,0,0,190,155,215,0,192,135,2,0,24,163,6,0,1,0,0,0,191,155,215,0,240,108,2,0,152,122,6,0,1,0,0,0,188,155,215,0,96,82,2,0,192,72,6,0,1,0,0,0,189,155,215,0,32,56,2,0,248,187,8,0,1,0,0,0,199,155,215,0,56,126,1,0,184,179,8,0,1,0,0,0,192,155,215,0,32,101,1,0,240,173,8,0,1,0,0,0,193,155,215,0,96,32,8,0,208,72,7,0,1,0,0,0,194,155,215,0,16,68,7,0,216,63,7,0,1,0,0,0,195,155,215,0,240,58,7,0,176,189,4,0,4,0,0,0,104,156,215,0,0,187,4,0,16,17,8,0,1,0,0,0,211,155,215,0,224,12,8,0,32,77,1,0,1,0,0,0,210,155,215,0,216,70,1,0,88,212,3,0,1,0,0,0,200,154,215,0,40,185,3,0,248,5,8,0,9,0,0,0,0,156,215,0,32,58,1,0,144,250,7,0,9,0,0,0,1,156,215,0,32,58,1,0,184,40,2,0,1,0,0,0,96,232,148,0,248,191,2,0,56,250,6,0,1,0,0,0,223,233,148,0,184,160,2,0,184,164,8,0,1,0,0,0,97,232,148,0,64,246,1,0,88,149,7,0,1,0,0,0,31,233,148,0,136,224,1,0,56,210,6,0,1,0,0,0,216,233,148,0,192,135,2,0,24,163,6,0,1,0,0,0,217,233,148,0,240,108,2,0,152,122,6,0,1,0,0,0,218,233,148,0,96,82,2,0,192,72,6,0,1,0,0,0,219,233,148,0,32,56,2,0,48,123,2,0,1,0,0,0,220,233,148,0,152,30,2,0,96,69,2,0,1,0,0,0,221,233,148,0,232,10,2,0,144,55,2,0,1,0,0,0,222,233,148,0,152,138,8,0,176,223,1,0,1,0,0,0,24,233,148,0,72,198,1,0,192,209,1,0,1,0,0,0,25,233,148,0,24,182,1,0,24,198,1,0,1,0,0,0,26,233,148,0,40,167,1,0,120,189,1,0,1,0,0,0,27,233,148,0,200,149,1,0,248,187,8,0,1,0,0,0,28,233,148,0,56,126,1,0,184,179,8,0,1,0,0,0,29,233,148,0,32,101,1,0,240,173,8,0,1,0,0,0,30,233,148,0,96,32,8,0,88,212,3,0,1,0,0,0,192,218,146,0,40,185,3,0,248,5,8,0,9,0,0,0,112,94,147,0,32,58,1,0,144,250,7,0,9,0,0,0,113,94,147,0,32,58,1,0,168,86,7,0,1,0,0,0,212,47,216,0,248,191,2,0,24,38,7,0,1,0,0,0,208,47,216,0,184,160,2,0,56,210,6,0,1,0,0,0,35,48,216,0,192,135,2,0,24,163,6,0,1,0,0,0,34,48,216,0,240,108,2,0,152,122,6,0,1,0,0,0,33,48,216,0,96,82,2,0,192,72,6,0,1,0,0,0,32,48,216,0,32,56,2,0,152,31,6,0,1,0,0,0,36,48,216,0,152,30,2,0,248,97,5,0,1,0,0,0,37,48,216,0,232,10,2,0,120,36,5,0,1,0,0,0,38,48,216,0,152,138,8,0,40,246,1,0,1,0,0,0,213,47,216,0,64,246,1,0,144,236,1,0,1,0,0,0,209,47,216,0,136,224,1,0,176,223,1,0,1,0,0,0,43,48,216,0,72,198,1,0,192,209,1,0,1,0,0,0,42,48,216,0,24,182,1,0,24,198,1,0,1,0,0,0,41,48,216,0,40,167,1,0,120,189,1,0,1,0,0,0,40,48,216,0,200,149,1,0,8,182,1,0,1,0,0,0,44,48,216,0,56,126,1,0,32,167,1,0,1,0,0,0,45,48,216,0,32,101,1,0,128,149,1,0,1,0,0,0,46,48,216,0,96,32,8,0,88,212,3,0,1,0,0,0,144,46,216,0,40,185,3,0,240,152,1,0,1,0,0,0,201,47,216,0,216,70,1,0,16,17,8,0,1,0,0,0,202,47,216,0,224,12,8,0,136,67,2,0,1,0,0,0,176,48,216,0,48,119,7,0,8,66,2,0,1,0,0,0,184,48,216,0,112,109,7,0,0,0,0,0,0,0,0,0,184,40,2,0,1,0,0,0,122,151,215,0,248,191,2,0,56,250,6,0,1,0,0,0,124,151,215,0,184,160,2,0,184,164,8,0,1,0,0,0,123,151,215,0,64,246,1,0,88,149,7,0,1,0,0,0,125,151,215,0,136,224,1,0,56,210,6,0,1,0,0,0,136,151,215,0,192,135,2,0,24,163,6,0,1,0,0,0,137,151,215,0,240,108,2,0,152,122,6,0,1,0,0,0,138,151,215,0,96,82,2,0,192,72,6,0,1,0,0,0,139,151,215,0,32,56,2,0,48,123,2,0,1,0,0,0,140,151,215,0,152,30,2,0,96,69,2,0,1,0,0,0,141,151,215,0,232,10,2,0,176,223,1,0,1,0,0,0,128,151,215,0,72,198,1,0,192,209,1,0,1,0,0,0,129,151,215,0,24,182,1,0,24,198,1,0,1,0,0,0,130,151,215,0,40,167,1,0,120,189,1,0,1,0,0,0,131,151,215,0,200,149,1,0,248,187,8,0,1,0,0,0,132,151,215,0,56,126,1,0,184,179,8,0,1,0,0,0,133,151,215,0,32,101,1,0,88,212,3,0,1,0,0,0,200,147,215,0,40,185,3,0,16,17,8,0,1,0,0,0,121,151,215,0,224,12,8,0,56,58,1,0,1,0,0,0,120,151,215,0,64,50,1,0,248,5,8,0,9,0,0,0,152,151,215,0,32,58,1,0,144,250,7,0,9,0,0,0,153,151,215,0,32,58,1,0,168,86,7,0,1,0,0,0,178,241,146,0,248,191,2,0,24,38,7,0,1,0,0,0,176,241,146,0,184,160,2,0,56,210,6,0,1,0,0,0,147,2,147,0,192,135,2,0,24,163,6,0,1,0,0,0,146,2,147,0,240,108,2,0,152,122,6,0,1,0,0,0,145,2,147,0,96,82,2,0,192,72,6,0,1,0,0,0,144,2,147,0,32,56,2,0,200,110,3,0,1,0,0,0,151,2,147,0,152,30,2,0,120,89,3,0,1,0,0,0,150,2,147,0,232,10,2,0,120,74,3,0,1,0,0,0,149,2,147,0,152,138,8,0,40,246,1,0,1,0,0,0,179,241,146,0,64,246,1,0,144,236,1,0,1,0,0,0,177,241,146,0,136,224,1,0,176,223,1,0,1,0,0,0,211,249,146,0,72,198,1,0,192,209,1,0,1,0,0,0,210,249,146,0,24,182,1,0,24,198,1,0,1,0,0,0,209,249,146,0,40,167,1,0,120,189,1,0,1,0,0,0,208,249,146,0,200,149,1,0,224,22,1,0,1,0,0,0,215,249,146,0,56,126,1,0,160,14,1,0,1,0,0,0,214,249,146,0,32,101,1,0,176,9,1,0,1,0,0,0,213,249,146,0,96,32,8,0,88,212,3,0,1,0,0,0,0,222,146,0,40,185,3,0,16,17,8,0,1,0,0,0,180,241,146,0,224,12,8,0,72,65,1,0,9,0,0,0,152,7,147,0,32,58,1,0,48,50,1,0,9,0,0,0,153,7,147,0,32,58,1,0,168,86,7,0,1,0,0,0,23,245,146,0,248,191,2,0,24,38,7,0,1,0,0,0,16,245,146,0,184,160,2,0,56,210,6,0,1,0,0,0,22,245,146,0,192,135,2,0,24,163,6,0,1,0,0,0,21,245,146,0,240,108,2,0,152,122,6,0,1,0,0,0,20,245,146,0,96,82,2,0,192,72,6,0,1,0,0,0,19,245,146,0,32,56,2,0,200,110,3,0,1,0,0,0,17,245,146,0,152,30,2,0,120,89,3,0,1,0,0,0,18,245,146,0,232,10,2,0,40,246,1,0,1,0,0,0,31,245,146,0,64,246,1,0,144,236,1,0,1,0,0,0,24,245,146,0,136,224,1,0,176,223,1,0,1,0,0,0,30,245,146,0,72,198,1,0,192,209,1,0,1,0,0,0,29,245,146,0,24,182,1,0,24,198,1,0,1,0,0,0,28,245,146,0,40,167,1,0,120,189,1,0,1,0,0,0,27,245,146,0,200,149,1,0,224,22,1,0,1,0,0,0,25,245,146,0,56,126,1,0,160,14,1,0,1,0,0,0,26,245,146,0,32,101,1,0,88,212,3,0,1,0,0,0,152,217,146,0,40,185,3,0,72,65,1,0,9,0,0,0,144,4,147,0,32,58,1,0,48,50,1,0,9,0,0,0,145,4,147,0,32,58,1,0,168,86,7,0,1,0,0,0,88,245,146,0,248,191,2,0,24,38,7,0,1,0,0,0,92,245,146,0,184,160,2,0,56,210,6,0,1,0,0,0,171,253,146,0,192,135,2,0,24,163,6,0,1,0,0,0,170,253,146,0,240,108,2,0,152,122,6,0,1,0,0,0,169,253,146,0,96,82,2,0,192,72,6,0,1,0,0,0,168,253,146,0,32,56,2,0,200,110,3,0,1,0,0,0,172,253,146,0,152,30,2,0,144,236,1,0,1,0,0,0,93,245,146,0,136,224,1,0,176,223,1,0,1,0,0,0,179,253,146,0,72,198,1,0,192,209,1,0,1,0,0,0,178,253,146,0,24,182,1,0,24,198,1,0,1,0,0,0,177,253,146,0,40,167,1,0,120,189,1,0,1,0,0,0,176,253,146,0,200,149,1,0,224,22,1,0,1,0,0,0,180,253,146,0,56,126,1,0,88,212,3,0,1,0,0,0,200,217,146,0,40,185,3,0,72,65,1,0,9,0,0,0,176,4,147,0,32,58,1,0,48,50,1,0,9,0,0,0,177,4,147,0,32,58,1,0,184,40,2,0,1,0,0,0,40,39,216,0,248,191,2,0,56,250,6,0,1,0,0,0,32,39,216,0,184,160,2,0,208,158,7,0,1,0,0,0,42,39,216,0,96,82,2,0,184,154,7,0,1,0,0,0,43,39,216,0,32,56,2,0,176,108,2,0,1,0,0,0,44,39,216,0,152,30,2,0,128,98,2,0,1,0,0,0,47,39,216,0,232,10,2,0,88,212,3,0,1,0,0,0,48,38,216,0,40,185,3,0,248,5,8,0,9,0,0,0,112,39,216,0,32,58,1,0,144,250,7,0,9,0,0,0,113,39,216,0,32,58,1,0,248,241,7,0,9,0,0,0,114,39,216,0,32,58,1,0,168,86,7,0,1,0,0,0,80,240,146,0,248,191,2,0,120,248,6,0,1,0,0,0,82,240,146,0,184,160,2,0,56,210,6,0,1,0,0,0,248,0,147,0,192,135,2,0,24,163,6,0,1,0,0,0,249,0,147,0,240,108,2,0,192,72,6,0,1,0,0,0,250,0,147,0,32,56,2,0,152,122,6,0,1,0,0,0,251,0,147,0,96,82,2,0,200,110,3,0,1,0,0,0,252,0,147,0,152,30,2,0,40,246,1,0,1,0,0,0,81,240,146,0,64,246,1,0,48,245,6,0,1,0,0,0,83,240,146,0,136,224,1,0,176,223,1,0,1,0,0,0,88,248,146,0,72,198,1,0,192,209,1,0,1,0,0,0,89,248,146,0,24,182,1,0,120,189,1,0,1,0,0,0,90,248,146,0,200,149,1,0,24,198,1,0,1,0,0,0,91,248,146,0,40,167,1,0,224,22,1,0,1,0,0,0,92,248,146,0,56,126,1,0,88,212,3,0,1,0,0,0,64,220,146,0,40,185,3,0,248,5,8,0,9,0,0,0,96,6,147,0,32,58,1,0,184,40,2,0,1,0,0,0,47,39,216,0,248,191,2,0,56,250,6,0,1,0,0,0,41,39,216,0,184,160,2,0,184,164,8,0,1,0,0,0,46,39,216,0,64,246,1,0,88,149,7,0,1,0,0,0,40,39,216,0,136,224,1,0,168,6,2,0,1,0,0,0,42,39,216,0,192,135,2,0,248,5,2,0,1,0,0,0,43,39,216,0,240,108,2,0,56,5,2,0,1,0,0,0,45,39,216,0,96,82,2,0,8,4,2,0,1,0,0,0,44,39,216,0,32,56,2,0,176,108,2,0,1,0,0,0,38,39,216,0,152,30,2,0,144,3,2,0,1,0,0,0,34,39,216,0,72,198,1,0,56,3,2,0,1,0,0,0,35,39,216,0,24,182,1,0,192,2,2,0,1,0,0,0,37,39,216,0,40,167,1,0,232,1,2,0,1,0,0,0,36,39,216,0,200,149,1,0,88,212,3,0,1,0,0,0,48,38,216,0,40,185,3,0,248,5,8,0,9,0,0,0,112,39,216,0,32,58,1,0,144,250,7,0,9,0,0,0,113,39,216,0,32,58,1,0,248,241,7,0,9,0,0,0,114,39,216,0,32,58,1,0,168,86,7,0,1,0,0,0,104,255,146,0,248,191,2,0,24,38,7,0,1,0,0,0,135,255,146,0,184,160,2,0,56,210,6,0,1,0,0,0,128,255,146,0,192,135,2,0,24,163,6,0,1,0,0,0,129,255,146,0,240,108,2,0,152,122,6,0,1,0,0,0,130,255,146,0,96,82,2,0,192,72,6,0,1,0,0,0,131,255,146,0,32,56,2,0,200,110,3,0,1,0,0,0,132,255,146,0,152,30,2,0,120,89,3,0,1,0,0,0,133,255,146,0,232,10,2,0,120,74,3,0,1,0,0,0,134,255,146,0,152,138,8,0,40,246,1,0,1,0,0,0,105,255,146,0,64,246,1,0,144,236,1,0,1,0,0,0,127,255,146,0,136,224,1,0,176,223,1,0,1,0,0,0,120,255,146,0,72,198,1,0,192,209,1,0,1,0,0,0,121,255,146,0,24,182,1,0,24,198,1,0,1,0,0,0,122,255,146,0,40,167,1,0,120,189,1,0,1,0,0,0,123,255,146,0,200,149,1,0,224,22,1,0,1,0,0,0,124,255,146,0,56,126,1,0,160,14,1,0,1,0,0,0,125,255,146,0,32,101,1,0,176,9,1,0,1,0,0,0,126,255,146,0,96,32,8,0,168,132,8,0,1,0,0,0,106,255,146,0,232,209,1,0,72,126,8,0,1,0,0,0,255,246,146,0,144,189,1,0,192,122,8,0,1,0,0,0,248,246,146,0,208,174,1,0,40,116,8,0,1,0,0,0,249,246,146,0,48,160,1,0,72,110,8,0,1,0,0,0,250,246,146,0,160,140,1,0,184,102,8,0,1,0,0,0,251,246,146,0,56,112,1,0,248,67,8,0,1,0,0,0,252,246,146,0,32,92,1,0,136,64,8,0,1,0,0,0,253,246,146,0,64,77,1,0,128,58,8,0,1,0,0,0,254,246,146,0,112,157,4,0,232,23,8,0,1,0,0,0,107,255,146,0,104,195,5,0,160,19,8,0,1,0,0,0,247,246,146,0,32,245,8,0,248,16,8,0,1,0,0,0,240,246,146,0,32,231,8,0,192,12,8,0,1,0,0,0,241,246,146,0,88,214,8,0,224,5,8,0,1,0,0,0,242,246,146,0,224,202,8,0,144,1,8,0,1,0,0,0,243,246,146,0,72,193,8,0,176,222,7,0,1,0,0,0,244,246,146,0,144,180,8,0,176,218,7,0,1,0,0,0,245,246,146,0,208,164,8,0,248,214,7,0,1,0,0,0,246,246,146,0,160,152,4,0,88,212,3,0,1,0,0,0,240,218,146,0,40,185,3,0,16,17,8,0,1,0,0,0,108,255,146,0,224,12,8,0,16,17,8,0,1,0,0,0,111,255,146,0,224,12,8,0,72,65,1,0,9,0,0,0,96,5,147,0,32,58,1,0,48,50,1,0,9,0,0,0,97,5,147,0,32,58,1,0,168,86,7,0,1,0,0,0,168,239,146,0,248,191,2,0,24,38,7,0,1,0,0,0,192,246,146,0,184,160,2,0,200,110,3,0,1,0,0,0,2,236,146,0,152,30,2,0,120,89,3,0,1,0,0,0,3,236,146,0,232,10,2,0,120,74,3,0,1,0,0,0,0,236,146,0,152,138,8,0,192,61,3,0,1,0,0,0,1,236,146,0,48,119,7,0,144,236,1,0,1,0,0,0,194,246,146,0,136,224,1,0,224,22,1,0,1,0,0,0,42,255,146,0,56,126,1,0,160,14,1,0,1,0,0,0,43,255,146,0,32,101,1,0,176,9,1,0,1,0,0,0,40,255,146,0,96,32,8,0,200,3,1,0,1,0,0,0,41,255,146,0,16,68,7,0,72,126,8,0,1,0,0,0,80,236,146,0,144,189,1,0,248,67,8,0,1,0,0,0,56,237,146,0,32,92,1,0,136,64,8,0,1,0,0,0,57,237,146,0,64,77,1,0,128,58,8,0,1,0,0,0,58,237,146,0,112,157,4,0,200,53,8,0,1,0,0,0,59,237,146,0,176,194,6,0,88,212,3,0,1,0,0,0,208,218,146,0,40,185,3,0,72,65,1,0,9,0,0,0,72,5,147,0,32,58,1,0,168,86,7,0,1,0,0,0,72,234,148,0,248,191,2,0,24,38,7,0,1,0,0,0,75,234,148,0,184,160,2,0,56,210,6,0,1,0,0,0,138,233,148,0,192,135,2,0,24,163,6,0,1,0,0,0,139,233,148,0,240,108,2,0,152,122,6,0,1,0,0,0,136,233,148,0,96,82,2,0,192,72,6,0,1,0,0,0,137,233,148,0,32,56,2,0,200,110,3,0,1,0,0,0,140,233,148,0,152,30,2,0,120,89,3,0,1,0,0,0,141,233,148,0,232,10,2,0,120,74,3,0,1,0,0,0,142,233,148,0,152,138,8,0,40,246,1,0,1,0,0,0,73,234,148,0,64,246,1,0,144,236,1,0,1,0,0,0,76,234,148,0,136,224,1,0,176,223,1,0,1,0,0,0,202,232,148,0,72,198,1,0,192,209,1,0,1,0,0,0,203,232,148,0,24,182,1,0,24,198,1,0,1,0,0,0,200,232,148,0,40,167,1,0,120,189,1,0,1,0,0,0,201,232,148,0,200,149,1,0,224,22,1,0,1,0,0,0,204,232,148,0,56,126,1,0,160,14,1,0,1,0,0,0,205,232,148,0,32,101,1,0,176,9,1,0,1,0,0,0,206,232,148,0,96,32,8,0,88,212,3,0,1,0,0,0,248,221,146,0,40,185,3,0,16,17,8,0,1,0,0,0,78,234,148,0,224,12,8,0,72,65,1,0,9,0,0,0,240,94,147,0,32,58,1,0,48,50,1,0,9,0,0,0,241,94,147,0,32,58,1,0,224,41,1,0,9,0,0,0,242,94,147,0,32,58,1,0,168,86,7,0,1,0,0,0,33,242,146,0,248,191,2,0,24,38,7,0,1,0,0,0,72,250,146,0,184,160,2,0,56,210,6,0,1,0,0,0,152,158,145,0,192,135,2,0,24,163,6,0,1,0,0,0,153,158,145,0,240,108,2,0,152,122,6,0,1,0,0,0,154,158,145,0,96,82,2,0,192,72,6,0,1,0,0,0,155,158,145,0,32,56,2,0,200,110,3,0,1,0,0,0,73,250,146,0,152,30,2,0,120,89,3,0,1,0,0,0,74,250,146,0,232,10,2,0,40,246,1,0,1,0,0,0,32,242,146,0,64,246,1,0,144,236,1,0,1,0,0,0,75,250,146,0,136,224,1,0,176,223,1,0,1,0,0,0,156,158,145,0,72,198,1,0,192,209,1,0,1,0,0,0,157,158,145,0,24,182,1,0,24,198,1,0,1,0,0,0,158,158,145,0,40,167,1,0,120,189,1,0,1,0,0,0,159,158,145,0,200,149,1,0,224,22,1,0,1,0,0,0,76,250,146,0,56,126,1,0,160,14,1,0,1,0,0,0,77,250,146,0,32,101,1,0,88,212,3,0,1,0,0,0,72,215,146,0,40,185,3,0,72,65,1,0,9,0,0,0,88,3,147,0,32,58,1,0,48,50,1,0,9,0,0,0,89,3,147,0,32,58,1,0,224,41,1,0,9,0,0,0,90,3,147,0,32,58,1,0,184,40,2,0,1,0,0,0,214,155,215,0,248,191,2,0,184,164,8,0,1,0,0,0,215,155,215,0,64,246,1,0,56,210,6,0,1,0,0,0,194,155,215,0,192,135,2,0,24,163,6,0,1,0,0,0,195,155,215,0,240,108,2,0,152,122,6,0,1,0,0,0,192,155,215,0,96,82,2,0,192,72,6,0,1,0,0,0,193,155,215,0,32,56,2,0,192,68,7,0,1,0,0,0,160,155,215,0,232,10,2,0,80,64,7,0,1,0,0,0,161,155,215,0,152,138,8,0,112,135,2,0,1,0,0,0,188,155,215,0,152,30,2,0,176,223,1,0,1,0,0,0,202,155,215,0,72,198,1,0,192,209,1,0,1,0,0,0,203,155,215,0,24,182,1,0,24,198,1,0,1,0,0,0,200,155,215,0,40,167,1,0,120,189,1,0,1,0,0,0,201,155,215,0,200,149,1,0,192,19,7,0,1,0,0,0,162,155,215,0,32,101,1,0,248,14,7,0,1,0,0,0,163,155,215,0,96,32,8,0,16,193,8,0,1,0,0,0,184,155,215,0,56,126,1,0,16,17,8,0,1,0,0,0,210,155,215,0,224,12,8,0,0,105,5,0,1,0,0,0,211,155,215,0,192,99,5,0,32,77,1,0,1,0,0,0,209,155,215,0,216,70,1,0,88,212,3,0,1,0,0,0,200,154,215,0,40,185,3,0,248,5,8,0,9,0,0,0,0,156,215,0,32,58,1,0,144,250,7,0,9,0,0,0,1,156,215,0,32,58,1,0,168,86,7,0,1,0,0,0,0,238,146,0,248,191,2,0,24,38,7,0,1,0,0,0,2,238,146,0,184,160,2,0,56,210,6,0,1,0,0,0,136,250,146,0,192,135,2,0,24,163,6,0,1,0,0,0,137,250,146,0,240,108,2,0,152,122,6,0,1,0,0,0,138,250,146,0,96,82,2,0,192,72,6,0,1,0,0,0,139,250,146,0,32,56,2,0,200,110,3,0,1,0,0,0,140,250,146,0,152,30,2,0,120,89,3,0,1,0,0,0,141,250,146,0,232,10,2,0,120,74,3,0,1,0,0,0,142,250,146,0,152,138,8,0,40,246,1,0,1,0,0,0,1,238,146,0,64,246,1,0,144,236,1,0,1,0,0,0,3,238,146,0,136,224,1,0,176,223,1,0,1,0,0,0,96,242,146,0,72,198,1,0,192,209,1,0,1,0,0,0,97,242,146,0,24,182,1,0,24,198,1,0,1,0,0,0,98,242,146,0,40,167,1,0,120,189,1,0,1,0,0,0,99,242,146,0,200,149,1,0,224,22,1,0,1,0,0,0,100,242,146,0,56,126,1,0,160,14,1,0,1,0,0,0,101,242,146,0,32,101,1,0,176,9,1,0,1,0,0,0,102,242,146,0,96,32,8,0,88,212,3,0,1,0,0,0,104,215,146,0,40,185,3,0,72,65,1,0,9,0,0,0,112,3,147,0,32,58,1,0,48,50,1,0,9,0,0,0,113,3,147,0,32,58,1,0,184,40,2,0,1,0,0,0,175,232,148,0,248,191,2,0,56,250,6,0,1,0,0,0,168,232,148,0,184,160,2,0,184,164,8,0,1,0,0,0,174,232,148,0,64,246,1,0,88,149,7,0,1,0,0,0,169,232,148,0,136,224,1,0,240,167,7,0,1,0,0,0,35,234,148,0,192,135,2,0,176,163,7,0,1,0,0,0,34,234,148,0,240,108,2,0,208,158,7,0,1,0,0,0,33,234,148,0,96,82,2,0,184,154,7,0,1,0,0,0,32,234,148,0,32,56,2,0,176,108,2,0,1,0,0,0,36,234,148,0,152,30,2,0,128,98,2,0,1,0,0,0,37,234,148,0,232,10,2,0,8,96,7,0,1,0,0,0,99,233,148,0,72,198,1,0,48,89,7,0,1,0,0,0,98,233,148,0,24,182,1,0,16,83,7,0,1,0,0,0,97,233,148,0,40,167,1,0,96,79,7,0,1,0,0,0,96,233,148,0,200,149,1,0,48,76,7,0,1,0,0,0,100,233,148,0,56,126,1,0,144,72,7,0,1,0,0,0,101,233,148,0,32,101,1,0,88,212,3,0,1,0,0,0,144,220,146,0,40,185,3,0,16,17,8,0,1,0,0,0,173,232,148,0,224,12,8,0,32,77,1,0,1,0,0,0,171,232,148,0,216,70,1,0,248,5,8,0,9,0,0,0,192,94,147,0,32,58,1,0,144,250,7,0,9,0,0,0,193,94,147,0,32,58,1,0,248,241,7,0,9,0,0,0,194,94,147,0,32,58,1,0,184,40,2,0,1,0,0,0,40,39,216,0,248,191,2,0,56,250,6,0,1,0,0,0,32,39,216,0,184,160,2,0,184,164,8,0,1,0,0,0,41,39,216,0,64,246,1,0,88,149,7,0,1,0,0,0,33,39,216,0,136,224,1,0,240,167,7,0,1,0,0,0,47,39,216,0,192,135,2,0,176,163,7,0,1,0,0,0,45,39,216,0,240,108,2,0,208,158,7,0,1,0,0,0,42,39,216,0,96,82,2,0,184,154,7,0,1,0,0,0,43,39,216,0,32,56,2,0,176,108,2,0,1,0,0,0,29,39,216,0,152,30,2,0,8,96,7,0,1,0,0,0,36,39,216,0,72,198,1,0,48,89,7,0,1,0,0,0,46,39,216,0,24,182,1,0,16,83,7,0,1,0,0,0,34,39,216,0,40,167,1,0,96,79,7,0,1,0,0,0,35,39,216,0,200,149,1,0,48,76,7,0,1,0,0,0,37,39,216,0,56,126,1,0,88,212,3,0,1,0,0,0,48,38,216,0,40,185,3,0,248,5,8,0,9,0,0,0,112,39,216,0,32,58,1,0,144,250,7,0,9,0,0,0,113,39,216,0,32,58,1,0,248,241,7,0,9,0,0,0,114,39,216,0,32,58,1,0,184,40,2,0,1,0,0,0,136,254,146,0,248,191,2,0,184,164,8,0,1,0,0,0,137,254,146,0,64,246,1,0,104,28,8,0,1,0,0,0,138,254,146,0,232,209,1,0,136,117,3,0,1,0,0,0,139,254,146,0,152,30,2,0,248,79,3,0,1,0,0,0,140,254,146,0,232,10,2,0,88,212,3,0,1,0,0,0,96,218,146,0,40,185,3,0,16,17,8,0,1,0,0,0,150,254,146,0,224,12,8,0,16,17,8,0,1,0,0,0,148,254,146,0,224,12,8,0,72,65,1,0,9,0,0,0,88,94,147,0,32,58,1,0,184,40,2,0,1,0,0,0,40,39,216,0,248,191,2,0,56,250,6,0,1,0,0,0,32,39,216,0,184,160,2,0,184,164,8,0,1,0,0,0,41,39,216,0,64,246,1,0,88,149,7,0,1,0,0,0,33,39,216,0,136,224,1,0,208,158,7,0,1,0,0,0,42,39,216,0,96,82,2,0,184,154,7,0,1,0,0,0,43,39,216,0,32,56,2,0,176,108,2,0,1,0,0,0,44,39,216,0,152,30,2,0,16,83,7,0,1,0,0,0,34,39,216,0,40,167,1,0,96,79,7,0,1,0,0,0,35,39,216,0,200,149,1,0,48,76,7,0,1,0,0,0,36,39,216,0,56,126,1,0,88,212,3,0,1,0,0,0,48,38,216,0,40,185,3,0,16,17,8,0,1,0,0,0,47,39,216,0,224,12,8,0,248,5,8,0,9,0,0,0,112,39,216,0,32,58,1,0,144,250,7,0,9,0,0,0,113,39,216,0,32,58,1,0,248,241,7,0,9,0,0,0,114,39,216,0,32,58,1,0,32,167,8,0,9,0,0,0,80,39,216,0,32,58,1,0,184,40,2,0,1,0,0,0,84,234,148,0,248,191,2,0,56,250,6,0,1,0,0,0,80,234,148,0,184,160,2,0,184,164,8,0,1,0,0,0,85,234,148,0,64,246,1,0,88,149,7,0,1,0,0,0,81,234,148,0,136,224,1,0,240,167,7,0,1,0,0,0,147,233,148,0,192,135,2,0,176,163,7,0,1,0,0,0,146,233,148,0,240,108,2,0,208,158,7,0,1,0,0,0,145,233,148,0,96,82,2,0,184,154,7,0,1,0,0,0,144,233,148,0,32,56,2,0,176,108,2,0,1,0,0,0,151,233,148,0,152,30,2,0,128,98,2,0,1,0,0,0,149,233,148,0,232,10,2,0,8,96,7,0,1,0,0,0,211,232,148,0,72,198,1,0,48,89,7,0,1,0,0,0,210,232,148,0,24,182,1,0,16,83,7,0,1,0,0,0,209,232,148,0,40,167,1,0,96,79,7,0,1,0,0,0,208,232,148,0,200,149,1,0,48,76,7,0,1,0,0,0,215,232,148,0,56,126,1,0,144,72,7,0,1,0,0,0,213,232,148,0,32,101,1,0,88,212,3,0,1,0,0,0,8,222,146,0,40,185,3,0,248,5,8,0,9,0,0,0,248,94,147,0,32,58,1,0,144,250,7,0,9,0,0,0,249,94,147,0,32,58,1,0,168,86,7,0,1,0,0,0,212,47,216,0,248,191,2,0,24,38,7,0,1,0,0,0,208,47,216,0,184,160,2,0,56,210,6,0,1,0,0,0,35,48,216,0,192,135,2,0,24,163,6,0,1,0,0,0,34,48,216,0,240,108,2,0,152,122,6,0,1,0,0,0,33,48,216,0,96,82,2,0,192,72,6,0,1,0,0,0,32,48,216,0,32,56,2,0,8,227,6,0,1,0,0,0,36,48,216,0,152,30,2,0,136,222,6,0,1,0,0,0,37,48,216,0,232,10,2,0,88,212,3,0,1,0,0,0,144,46,216,0,40,185,3,0,240,152,1,0,1,0,0,0,201,47,216,0,216,70,1,0,16,17,8,0,1,0,0,0,202,47,216,0,224,12,8,0,136,67,2,0,1,0,0,0,176,48,216,0,152,138,8,0,8,66,2,0,1,0,0,0,184,48,216,0,48,119,7,0,168,86,7,0,1,0,0,0,198,251,146,0,248,191,2,0,24,38,7,0,1,0,0,0,199,251,146,0,184,160,2,0,200,110,3,0,1,0,0,0,196,251,146,0,152,30,2,0,120,89,3,0,1,0,0,0,197,251,146,0,232,10,2,0,240,251,8,0,4,0,0,0,216,7,147,0,208,13,4,0,40,246,1,0,1,0,0,0,142,243,146,0,64,246,1,0,144,236,1,0,1,0,0,0,143,243,146,0,136,224,1,0,224,22,1,0,1,0,0,0,140,243,146,0,56,126,1,0,160,14,1,0,1,0,0,0,141,243,146,0,32,101,1,0,112,188,8,0,4,0,0,0,218,7,147,0,136,7,4,0,88,212,3,0,1,0,0,0,120,216,146,0,40,185,3,0,72,65,1,0,9,0,0,0,216,3,147,0,32,58,1,0,48,50,1,0,9,0,0,0,217,3,147,0,32,58,1,0,168,86,7,0,1,0,0,0,136,239,146,0,248,191,2,0,24,38,7,0,1,0,0,0,223,254,146,0,184,160,2,0,56,210,6,0,1,0,0,0,218,254,146,0,192,135,2,0,24,163,6,0,1,0,0,0,219,254,146,0,240,108,2,0,152,122,6,0,1,0,0,0,216,254,146,0,96,82,2,0,192,72,6,0,1,0,0,0,217,254,146,0,32,56,2,0,200,110,3,0,1,0,0,0,220,254,146,0,152,30,2,0,120,89,3,0,1,0,0,0,221,254,146,0,232,10,2,0,40,246,1,0,1,0,0,0,137,239,146,0,64,246,1,0,144,236,1,0,1,0,0,0,127,246,146,0,136,224,1,0,176,223,1,0,1,0,0,0,122,246,146,0,72,198,1,0,192,209,1,0,1,0,0,0,123,246,146,0,24,182,1,0,24,198,1,0,1,0,0,0,120,246,146,0,40,167,1,0,120,189,1,0,1,0,0,0,121,246,146,0,200,149,1,0,224,22,1,0,1,0,0,0,124,246,146,0,56,126,1,0,160,14,1,0,1,0,0,0,125,246,146,0,32,101,1,0,88,212,3,0,1,0,0,0,160,218,146,0,40,185,3,0,16,17,8,0,1,0,0,0,138,239,146,0,224,12,8,0,72,65,1,0,9,0,0,0,48,5,147,0,32,58,1,0,48,50,1,0,9,0,0,0,49,5,147,0,32,58,1,0,224,41,1,0,9,0,0,0,50,5,147,0,32,58,1,0,0,0,0,0,8,0,0,0,16,0,0,0,24,0,0,0,32,0,0,0,40,0,0,0,48,0,0,0,56,0,0,0,184,40,2,0,1,0,0,0,218,83,148,0,248,191,2,0,56,250,6,0,1,0,0,0,216,83,148,0,184,160,2,0,184,164,8,0,1,0,0,0,219,83,148,0,64,246,1,0,88,149,7,0,1,0,0,0,217,83,148,0,136,224,1,0,56,210,6,0,1,0,0,0,232,83,148,0,192,135,2,0,24,163,6,0,1,0,0,0,233,83,148,0,240,108,2,0,152,122,6,0,1,0,0,0,234,83,148,0,96,82,2,0,192,72,6,0,1,0,0,0,235,83,148,0,32,56,2,0,48,123,2,0,1,0,0,0,236,83,148,0,152,30,2,0,96,69,2,0,1,0,0,0,237,83,148,0,232,10,2,0,144,55,2,0,1,0,0,0,238,83,148,0,152,138,8,0,176,223,1,0,1,0,0,0,224,83,148,0,72,198,1,0,192,209,1,0,1,0,0,0,225,83,148,0,24,182,1,0,24,198,1,0,1,0,0,0,226,83,148,0,40,167,1,0,120,189,1,0,1,0,0,0,227,83,148,0,200,149,1,0,248,187,8,0,1,0,0,0,228,83,148,0,56,126,1,0,184,179,8,0,1,0,0,0,229,83,148,0,32,101,1,0,240,173,8,0,1,0,0,0,230,83,148,0,96,32,8,0,88,212,3,0,1,0,0,0,8,229,148,0,40,185,3,0,248,5,8,0,9,0,0,0,248,71,215,0,32,58,1,0,144,250,7,0,9,0,0,0,249,71,215,0,32,58,1,0,184,40,2,0,1,0,0,0,40,39,216,0,248,191,2,0,184,164,8,0,1,0,0,0,41,39,216,0,64,246,1,0,88,149,7,0,1,0,0,0,33,39,216,0,136,224,1,0,176,163,7,0,1,0,0,0,47,39,216,0,240,108,2,0,208,158,7,0,1,0,0,0,42,39,216,0,96,82,2,0,184,154,7,0,1,0,0,0,43,39,216,0,32,56,2,0,176,108,2,0,1,0,0,0,32,39,216,0,152,30,2,0,48,89,7,0,1,0,0,0,46,39,216,0,24,182,1,0,16,83,7,0,1,0,0,0,34,39,216,0,40,167,1,0,96,79,7,0,1,0,0,0,35,39,216,0,200,149,1,0,48,76,7,0,1,0,0,0,37,39,216,0,56,126,1,0,88,212,3,0,1,0,0,0,48,38,216,0,40,185,3,0,248,5,8,0,9,0,0,0,112,39,216,0,32,58,1,0,144,250,7,0,9,0,0,0])
.concat([113,39,216,0,32,58,1,0,248,241,7,0,9,0,0,0,114,39,216,0,32,58,1,0,184,40,2,0,1,0,0,0,96,232,148,0,248,191,2,0,56,250,6,0,1,0,0,0,223,233,148,0,184,160,2,0,184,164,8,0,1,0,0,0,97,232,148,0,64,246,1,0,88,149,7,0,1,0,0,0,31,233,148,0,136,224,1,0,56,210,6,0,1,0,0,0,216,233,148,0,192,135,2,0,24,163,6,0,1,0,0,0,217,233,148,0,240,108,2,0,152,122,6,0,1,0,0,0,218,233,148,0,96,82,2,0,192,72,6,0,1,0,0,0,219,233,148,0,32,56,2,0,48,123,2,0,1,0,0,0,220,233,148,0,152,30,2,0,96,69,2,0,1,0,0,0,221,233,148,0,232,10,2,0,176,223,1,0,1,0,0,0,24,233,148,0,72,198,1,0,192,209,1,0,1,0,0,0,25,233,148,0,24,182,1,0,24,198,1,0,1,0,0,0,26,233,148,0,40,167,1,0,120,189,1,0,1,0,0,0,27,233,148,0,200,149,1,0,248,187,8,0,1,0,0,0,28,233,148,0,56,126,1,0,184,179,8,0,1,0,0,0,29,233,148,0,32,101,1,0,88,212,3,0,1,0,0,0,192,218,146,0,40,185,3,0,248,5,8,0,9,0,0,0,112,94,147,0,32,58,1,0,144,250,7,0,9,0,0,0,113,94,147,0,32,58,1,0,184,40,2,0,1,0,0,0,35,39,216,0,248,191,2,0,56,250,6,0,1,0,0,0,39,39,216,0,184,160,2,0,184,164,8,0,1,0,0,0,36,39,216,0,64,246,1,0,88,149,7,0,1,0,0,0,38,39,216,0,136,224,1,0,240,167,7,0,1,0,0,0,40,39,216,0,192,135,2,0,176,163,7,0,1,0,0,0,42,39,216,0,240,108,2,0,208,158,7,0,1,0,0,0,45,39,216,0,96,82,2,0,184,154,7,0,1,0,0,0,44,39,216,0,32,56,2,0,176,108,2,0,1,0,0,0,43,39,216,0,152,30,2,0,88,212,3,0,1,0,0,0,48,38,216,0,40,185,3,0,16,17,8,0,1,0,0,0,37,39,216,0,224,12,8,0,248,5,8,0,9,0,0,0,112,39,216,0,32,58,1,0,144,250,7,0,9,0,0,0,113,39,216,0,32,58,1,0,248,241,7,0,9,0,0,0,114,39,216,0,32,58,1,0,72,82,8,0,9,0,0,0,115,39,216,0,32,58,1,0,168,86,7,0,1,0,0,0,104,255,146,0,248,191,2,0,24,38,7,0,1,0,0,0,135,255,146,0,184,160,2,0,200,110,3,0,1,0,0,0,128,255,146,0,152,30,2,0,120,89,3,0,1,0,0,0,129,255,146,0,232,10,2,0,120,74,3,0,1,0,0,0,130,255,146,0,152,138,8,0,192,61,3,0,1,0,0,0,131,255,146,0,48,119,7,0,40,246,1,0,1,0,0,0,105,255,146,0,64,246,1,0,144,236,1,0,1,0,0,0,127,255,146,0,136,224,1,0,224,22,1,0,1,0,0,0,120,255,146,0,56,126,1,0,160,14,1,0,1,0,0,0,121,255,146,0,32,101,1,0,176,9,1,0,1,0,0,0,122,255,146,0,96,32,8,0,200,3,1,0,1,0,0,0,123,255,146,0,16,68,7,0,168,132,8,0,1,0,0,0,106,255,146,0,232,209,1,0,72,126,8,0,1,0,0,0,255,246,146,0,144,189,1,0,248,67,8,0,1,0,0,0,248,246,146,0,32,92,1,0,136,64,8,0,1,0,0,0,249,246,146,0,64,77,1,0,128,58,8,0,1,0,0,0,250,246,146,0,112,157,4,0,200,53,8,0,1,0,0,0,251,246,146,0,176,194,6,0,232,23,8,0,1,0,0,0,107,255,146,0,104,195,5,0,160,19,8,0,1,0,0,0,247,246,146,0,32,245,8,0,176,222,7,0,1,0,0,0,240,246,146,0,144,180,8,0,176,218,7,0,1,0,0,0,241,246,146,0,208,164,8,0,248,214,7,0,1,0,0,0,242,246,146,0,160,152,4,0,64,209,7,0,1,0,0,0,243,246,146,0,40,184,6,0,88,212,3,0,1,0,0,0,240,218,146,0,40,185,3,0,16,17,8,0,1,0,0,0,108,255,146,0,224,12,8,0,16,17,8,0,1,0,0,0,111,255,146,0,224,12,8,0,72,65,1,0,9,0,0,0,96,5,147,0,32,58,1,0,184,40,2,0,1,0,0,0,56,244,146,0,248,191,2,0,184,164,8,0,1,0,0,0,57,244,146,0,64,246,1,0,24,38,7,0,1,0,0,0,58,244,146,0,184,160,2,0,56,210,6,0,1,0,0,0,120,252,146,0,192,135,2,0,24,163,6,0,1,0,0,0,121,252,146,0,240,108,2,0,152,122,6,0,1,0,0,0,122,252,146,0,96,82,2,0,192,72,6,0,1,0,0,0,123,252,146,0,32,56,2,0,200,110,3,0,1,0,0,0,124,252,146,0,152,30,2,0,120,89,3,0,1,0,0,0,125,252,146,0,232,10,2,0,144,236,1,0,1,0,0,0,59,244,146,0,136,224,1,0,176,223,1,0,1,0,0,0,128,252,146,0,72,198,1,0,192,209,1,0,1,0,0,0,129,252,146,0,24,182,1,0,24,198,1,0,1,0,0,0,130,252,146,0,40,167,1,0,120,189,1,0,1,0,0,0,131,252,146,0,200,149,1,0,224,22,1,0,1,0,0,0,132,252,146,0,56,126,1,0,160,14,1,0,1,0,0,0,133,252,146,0,32,101,1,0,16,17,8,0,1,0,0,0,60,244,146,0,224,12,8,0,88,212,3,0,1,0,0,0,0,217,146,0,40,185,3,0,184,40,2,0,1,0,0,0,250,150,215,0,248,191,2,0,56,250,6,0,1,0,0,0,15,151,215,0,184,160,2,0,184,164,8,0,1,0,0,0,251,150,215,0,64,246,1,0,88,149,7,0,1,0,0,0,7,151,215,0,136,224,1,0,56,210,6,0,1,0,0,0,8,151,215,0,192,135,2,0,24,163,6,0,1,0,0,0,9,151,215,0,240,108,2,0,152,122,6,0,1,0,0,0,10,151,215,0,96,82,2,0,192,72,6,0,1,0,0,0,11,151,215,0,32,56,2,0,48,123,2,0,1,0,0,0,12,151,215,0,152,30,2,0,96,69,2,0,1,0,0,0,13,151,215,0,232,10,2,0,176,223,1,0,1,0,0,0,0,151,215,0,72,198,1,0,192,209,1,0,1,0,0,0,1,151,215,0,24,182,1,0,24,198,1,0,1,0,0,0,2,151,215,0,40,167,1,0,120,189,1,0,1,0,0,0,3,151,215,0,200,149,1,0,248,187,8,0,1,0,0,0,4,151,215,0,56,126,1,0,184,179,8,0,1,0,0,0,5,151,215,0,32,101,1,0,88,212,3,0,1,0,0,0,200,147,215,0,40,185,3,0,16,17,8,0,1,0,0,0,249,150,215,0,224,12,8,0,56,58,1,0,1,0,0,0,248,150,215,0,64,50,1,0,248,5,8,0,9,0,0,0,24,151,215,0,32,58,1,0,144,250,7,0,9,0,0,0,25,151,215,0,32,58,1,0,168,86,7,0,1,0,0,0,160,191,145,0,248,191,2,0,24,38,7,0,1,0,0,0,127,253,146,0,184,160,2,0,56,210,6,0,1,0,0,0,122,253,146,0,192,135,2,0,24,163,6,0,1,0,0,0,123,253,146,0,240,108,2,0,152,122,6,0,1,0,0,0,120,253,146,0,96,82,2,0,192,72,6,0,1,0,0,0,121,253,146,0,32,56,2,0,200,110,3,0,1,0,0,0,124,253,146,0,152,30,2,0,120,89,3,0,1,0,0,0,125,253,146,0,232,10,2,0,120,74,3,0,1,0,0,0,126,253,146,0,152,138,8,0,192,61,3,0,1,0,0,0,8,239,146,0,48,119,7,0,40,246,1,0,1,0,0,0,161,191,145,0,64,246,1,0,144,236,1,0,1,0,0,0,47,245,146,0,136,224,1,0,176,223,1,0,1,0,0,0,42,245,146,0,72,198,1,0,192,209,1,0,1,0,0,0,43,245,146,0,24,182,1,0,24,198,1,0,1,0,0,0,40,245,146,0,40,167,1,0,120,189,1,0,1,0,0,0,41,245,146,0,200,149,1,0,224,22,1,0,1,0,0,0,44,245,146,0,56,126,1,0,160,14,1,0,1,0,0,0,45,245,146,0,32,101,1,0,176,9,1,0,1,0,0,0,46,245,146,0,96,32,8,0,200,3,1,0,1,0,0,0,248,236,146,0,16,68,7,0,88,212,3,0,1,0,0,0,168,217,146,0,40,185,3,0,16,17,8,0,1,0,0,0,162,191,145,0,224,12,8,0,72,65,1,0,9,0,0,0,35,224,146,0,32,58,1,0,48,50,1,0,9,0,0,0,36,224,146,0,32,58,1,0,224,41,1,0,9,0,0,0,39,224,146,0,32,58,1,0,168,86,7,0,1,0,0,0,80,2,147,0,248,191,2,0,24,38,7,0,1,0,0,0,83,2,147,0,184,160,2,0,56,210,6,0,1,0,0,0,146,249,146,0,192,135,2,0,24,163,6,0,1,0,0,0,147,249,146,0,240,108,2,0,152,122,6,0,1,0,0,0,144,249,146,0,96,82,2,0,192,72,6,0,1,0,0,0,145,249,146,0,32,56,2,0,200,110,3,0,1,0,0,0,148,249,146,0,152,30,2,0,120,89,3,0,1,0,0,0,149,249,146,0,232,10,2,0,120,74,3,0,1,0,0,0,150,249,146,0,152,138,8,0,40,246,1,0,1,0,0,0,81,2,147,0,64,246,1,0,144,236,1,0,1,0,0,0,84,2,147,0,136,224,1,0,176,223,1,0,1,0,0,0,114,241,146,0,72,198,1,0,192,209,1,0,1,0,0,0,115,241,146,0,24,182,1,0,24,198,1,0,1,0,0,0,112,241,146,0,40,167,1,0,120,189,1,0,1,0,0,0,113,241,146,0,200,149,1,0,224,22,1,0,1,0,0,0,116,241,146,0,56,126,1,0,160,14,1,0,1,0,0,0,117,241,146,0,32,101,1,0,176,9,1,0,1,0,0,0,118,241,146,0,96,32,8,0,88,212,3,0,1,0,0,0,184,221,146,0,40,185,3,0,16,17,8,0,1,0,0,0,86,2,147,0,224,12,8,0,72,65,1,0,9,0,0,0,104,7,147,0,32,58,1,0,48,50,1,0,9,0,0,0,105,7,147,0,32,58,1,0,224,41,1,0,9,0,0,0,106,7,147,0,32,58,1,0,184,40,2,0,1,0,0,0,214,155,215,0,248,191,2,0,56,250,6,0,1,0,0,0,211,155,215,0,184,160,2,0,184,164,8,0,1,0,0,0,215,155,215,0,64,246,1,0,8,3,3,0,4,0,0,0,112,156,215,0,208,13,4,0,248,230,7,0,4,0,0,0,104,156,215,0,184,198,5,0,120,223,7,0,4,0,0,0,96,156,215,0,136,7,4,0,128,219,7,0,4,0,0,0,88,156,215,0,56,27,7,0,176,108,2,0,1,0,0,0,212,155,215,0,152,30,2,0,128,98,2,0,1,0,0,0,213,155,215,0,232,10,2,0,16,17,8,0,1,0,0,0,210,155,215,0,224,12,8,0,32,77,1,0,1,0,0,0,209,155,215,0,216,70,1,0,88,212,3,0,1,0,0,0,200,154,215,0,40,185,3,0,248,5,8,0,9,0,0,0,0,156,215,0,32,58,1,0,144,250,7,0,9,0,0,0,1,156,215,0,32,58,1,0,168,86,7,0,1,0,0,0,148,1,147,0,248,191,2,0,24,38,7,0,1,0,0,0,150,1,147,0,184,160,2,0,56,210,6,0,1,0,0,0,136,1,147,0,192,135,2,0,24,163,6,0,1,0,0,0,137,1,147,0,240,108,2,0,152,122,6,0,1,0,0,0,138,1,147,0,96,82,2,0,192,72,6,0,1,0,0,0,139,1,147,0,32,56,2,0,200,110,3,0,1,0,0,0,140,1,147,0,152,30,2,0,120,89,3,0,1,0,0,0,141,1,147,0,232,10,2,0,40,246,1,0,1,0,0,0,149,1,147,0,64,246,1,0,144,236,1,0,1,0,0,0,151,1,147,0,136,224,1,0,176,223,1,0,1,0,0,0,142,1,147,0,72,198,1,0,192,209,1,0,1,0,0,0,143,1,147,0,24,182,1,0,24,198,1,0,1,0,0,0,144,1,147,0,40,167,1,0,120,189,1,0,1,0,0,0,145,1,147,0,200,149,1,0,224,22,1,0,1,0,0,0,146,1,147,0,56,126,1,0,160,14,1,0,1,0,0,0,147,1,147,0,32,101,1,0,88,212,3,0,1,0,0,0,16,221,146,0,40,185,3,0,72,65,1,0,9,0,0,0,216,6,147,0,32,58,1,0,48,50,1,0,9,0,0,0,217,6,147,0,32,58,1,0,103,103,119,106,100,46,48,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,110,117,28,203,1,0,16,1,103,103,119,106,100,46,48,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,4,142,21,250,1,0,16,1,103,103,119,106,100,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,231,196,91,28,1,0,16,1,103,103,119,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,164,48,85,16,5,0,32,0,103,103,119,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,185,74,119,158,5,0,32,0,103,103,119,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,164,11,110,70,5,0,32,0,103,103,119,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,234,141,12,132,5,0,32,0,103,103,119,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,213,81,99,76,10,0,16,1,103,103,119,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,245,172,114,225,12,0,64,0,103,103,119,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,143,78,238,75,12,0,64,0,168,86,7,0,1,0,0,0,120,2,147,0,248,191,2,0,24,38,7,0,1,0,0,0,123,2,147,0,184,160,2,0,56,210,6,0,1,0,0,0,186,249,146,0,192,135,2,0,24,163,6,0,1,0,0,0,187,249,146,0,240,108,2,0,152,122,6,0,1,0,0,0,184,249,146,0,96,82,2,0,192,72,6,0,1,0,0,0,185,249,146,0,32,56,2,0,200,110,3,0,1,0,0,0,188,249,146,0,152,30,2,0,120,89,3,0,1,0,0,0,189,249,146,0,232,10,2,0,40,246,1,0,1,0,0,0,121,2,147,0,64,246,1,0,144,236,1,0,1,0,0,0,124,2,147,0,136,224,1,0,176,223,1,0,1,0,0,0,154,241,146,0,72,198,1,0,192,209,1,0,1,0,0,0,155,241,146,0,24,182,1,0,24,198,1,0,1,0,0,0,152,241,146,0,40,167,1,0,120,189,1,0,1,0,0,0,153,241,146,0,200,149,1,0,224,22,1,0,1,0,0,0,156,241,146,0,56,126,1,0,160,14,1,0,1,0,0,0,157,241,146,0,32,101,1,0,88,212,3,0,1,0,0,0,224,221,146,0,40,185,3,0,16,17,8,0,1,0,0,0,122,2,147,0,224,12,8,0,72,65,1,0,9,0,0,0,136,7,147,0,32,58,1,0,48,50,1,0,9,0,0,0,137,7,147,0,32,58,1,0,224,41,1,0,9,0,0,0,138,7,147,0,32,58,1,0,49,51,54,48,51,55,45,57,48,55,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,153,99,58,193,0,0,16,1,49,51,54,48,51,55,45,57,48,56,46,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,217,7,118,65,0,0,16,1,49,51,54,48,51,55,45,49,48,53,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,149,205,66,70,0,0,16,1,49,51,54,48,51,55,45,49,48,54,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,94,148,223,200,0,0,16,1,49,51,54,48,51,55,45,57,48,57,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,28,220,28,251,0,0,16,1,49,51,54,48,51,55,45,57,49,48,46,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,179,231,136,241,0,0,16,1,49,51,54,48,51,55,45,49,50,48,46,49,54,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,204,243,231,110,0,0,16,1,49,51,54,48,51,55,45,49,49,57,46,49,54,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,31,134,25,250,0,0,16,1,49,51,54,48,51,55,45,49,48,52,46,54,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,89,91,42,158,0,0,32,0,49,51,54,48,51,55,45,49,49,49,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,51,15,112,145,0,0,32,0,49,51,54,48,51,55,45,49,49,50,46,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,190,48,147,134,0,0,32,0,49,51,54,48,51,55,45,49,49,51,46,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,168,208,151,212,0,0,32,0,49,51,54,48,51,55,45,49,49,52,46,49,109,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,130,152,239,41,0,0,32,0,49,51,54,48,51,55,45,49,49,53,46,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,152,184,16,149,0,0,32,0,49,51,54,48,51,55,45,49,49,54,46,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,91,172,224,17,0,0,32,0,49,51,54,48,51,55,45,49,49,55,46,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,65,219,165,41,0,0,32,0,49,51,54,48,51,55,45,49,49,56,46,50,109,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,99,178,243,139,0,0,32,0,55,52,115,52,55,50,45,49,51,54,48,51,55,45,49,48,49,46,55,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,111,247,100,41,0,0,32,0,55,52,115,52,55,50,45,49,51,54,48,51,55,45,49,48,50,46,53,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,108,236,79,77,0,0,32,0,55,52,115,50,56,55,45,49,51,54,48,51,55,45,49,48,51,46,52,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,8,207,92,108,0,0,32,0,49,51,54,48,51,55,45,50,48,55,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,129,31,135,253,0,0,16,1,49,51,54,48,51,55,45,50,48,56,46,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,29,251,178,188,0,0,16,1,49,51,54,48,51,55,45,49,48,53,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,149,205,66,70,0,0,16,1,49,51,54,48,51,55,45,49,48,54,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,94,148,223,200,0,0,16,1,49,51,54,48,51,55,45,55,48,57,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,121,173,225,115,0,0,16,1,49,51,54,48,51,55,45,55,49,48,46,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,234,140,36,253,0,0,16,1,49,51,54,48,51,55,45,49,50,48,46,49,54,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,204,243,231,110,0,0,16,1,49,51,54,48,51,55,45,49,49,57,46,49,54,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,31,134,25,250,0,0,16,1,49,51,54,48,51,55,45,49,48,52,46,54,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,89,91,42,158,0,0,32,0,49,51,54,48,51,55,45,49,49,49,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,51,15,112,145,0,0,32,0,49,51,54,48,51,55,45,49,49,50,46,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,190,48,147,134,0,0,32,0,49,51,54,48,51,55,45,49,49,51,46,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,168,208,151,212,0,0,32,0,49,51,54,48,51,55,45,49,49,52,46,49,109,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,130,152,239,41,0,0,32,0,49,51,54,48,51,55,45,49,49,53,46,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,152,184,16,149,0,0,32,0,49,51,54,48,51,55,45,49,49,54,46,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,91,172,224,17,0,0,32,0,49,51,54,48,51,55,45,49,49,55,46,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,65,219,165,41,0,0,32,0,49,51,54,48,51,55,45,49,49,56,46,50,109,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,99,178,243,139,0,0,32,0,55,52,115,52,55,50,45,49,51,54,48,51,55,45,49,48,49,46,55,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,111,247,100,41,0,0,32,0,55,52,115,52,55,50,45,49,51,54,48,51,55,45,49,48,50,46,53,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,108,236,79,77,0,0,32,0,55,52,115,50,56,55,45,49,51,54,48,51,55,45,49,48,51,46,52,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,8,207,92,108,0,0,32,0,49,51,54,48,51,55,45,50,48,55,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,129,31,135,253,0,0,16,1,49,51,54,48,51,55,45,50,48,56,46,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,29,251,178,188,0,0,16,1,49,51,54,48,51,55,45,49,48,53,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,149,205,66,70,0,0,16,1,49,51,54,48,51,55,45,49,48,54,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,94,148,223,200,0,0,16,1,49,51,54,48,51,55,45,52,48,57,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,179,119,115,197,0,0,16,1,49,51,54,48,51,55,45,53,49,48,46,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,113,32,172,28,0,0,16,1,49,51,54,48,51,55,45,49,50,48,46,49,54,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,204,243,231,110,0,0,16,1,49,51,54,48,51,55,45,49,49,57,46,49,54,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,31,134,25,250,0,0,16,1,49,51,54,48,51,55,45,49,48,52,46,54,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,89,91,42,158,0,0,32,0,49,51,54,48,51,55,45,49,49,49,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,51,15,112,145,0,0,32,0,49,51,54,48,51,55,45,49,49,50,46,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,190,48,147,134,0,0,32,0,49,51,54,48,51,55,45,49,49,51,46,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,168,208,151,212,0,0,32,0,49,51,54,48,51,55,45,49,49,52,46,49,109,110,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,130,152,239,41,0,0,32,0,49,51,54,48,51,55,45,49,49,53,46,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,152,184,16,149,0,0,32,0,49,51,54,48,51,55,45,49,49,54,46,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,91,172,224,17,0,0,32,0,49,51,54,48,51,55,45,49,49,55,46,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,65,219,165,41,0,0,32,0,49,51,54,48,51,55,45,49,49,56,46,50,109,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,99,178,243,139,0,0,32,0,55,52,115,52,55,50,45,49,51,54,48,51,55,45,49,48,49,46,55,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,111,247,100,41,0,0,32,0,55,52,115,52,55,50,45,49,51,54,48,51,55,45,49,48,50,46,53,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,108,236,79,77,0,0,32,0,55,52,115,50,56,55,45,49,51,54,48,51,55,45,49,48,51,46,52,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,8,207,92,108,0,0,32,0,49,51,54,48,51,55,45,50,48,55,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,129,31,135,253,0,0,16,1,49,51,54,48,51,55,45,50,48,56,46,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,29,251,178,188,0,0,16,1,49,51,54,48,51,55,45,49,48,53,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,149,205,66,70,0,0,16,1,49,51,54,48,51,55,45,49,48,54,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,94,148,223,200,0,0,16,1,49,51,54,48,51,55,45,52,48,57,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,179,119,115,197,0,0,16,1,49,51,54,48,51,55,45,52,49,48,46,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,39,26,151,107,0,0,16,1,49,51,54,48,51,55,45,49,50,48,46,49,54,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,204,243,231,110,0,0,16,1,49,51,54,48,51,55,45,49,49,57,46,49,54,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,31,134,25,250,0,0,16,1,49,51,54,48,51,55,45,49,48,52,46,54,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,89,91,42,158,0,0,32,0,49,51,54,48,51,55,45,49,49,49,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,51,15,112,145,0,0,32,0,49,51,54,48,51,55,45,49,49,50,46,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,190,48,147,134,0,0,32,0,49,51,54,48,51,55,45,49,49,51,46,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,168,208,151,212,0,0,32,0,49,51,54,48,51,55,45,49,49,52,46,49,109,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,130,152,239,41,0,0,32,0,49,51,54,48,51,55,45,49,49,53,46,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,152,184,16,149,0,0,32,0,49,51,54,48,51,55,45,49,49,54,46,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,91,172,224,17,0,0,32,0,49,51,54,48,51,55,45,49,49,55,46,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,65,219,165,41,0,0,32,0,49,51,54,48,51,55,45,49,49,56,46,50,109,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,99,178,243,139,0,0,32,0,55,52,115,52,55,50,45,49,51,54,48,51,55,45,49,48,49,46,55,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,111,247,100,41,0,0,32,0,55,52,115,52,55,50,45,49,51,54,48,51,55,45,49,48,50,46,53,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,108,236,79,77,0,0,32,0,55,52,115,50,56,55,45,49,51,54,48,51,55,45,49,48,51,46,52,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,8,207,92,108,0,0,32,0,49,51,54,48,51,55,45,50,48,55,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,129,31,135,253,0,0,16,1,49,51,54,48,51,55,45,50,48,56,46,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,29,251,178,188,0,0,16,1,49,51,54,48,51,55,45,49,48,53,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,149,205,66,70,0,0,16,1,49,51,54,48,51,55,45,49,48,54,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,94,148,223,200,0,0,16,1,49,51,54,48,51,55,45,50,48,57,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,220,167,16,216,0,0,16,1,49,51,54,48,51,55,45,50,49,48,46,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,144,114,186,251,0,0,16,1,49,51,54,48,51,55,45,49,50,48,46,49,54,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,204,243,231,110,0,0,16,1,49,51,54,48,51,55,45,49,49,57,46,49,54,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,31,134,25,250,0,0,16,1,49,51,54,48,51,55,45,49,48,52,46,54,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,89,91,42,158,0,0,32,0,49,51,54,48,51,55,45,49,49,49,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,51,15,112,145,0,0,32,0,49,51,54,48,51,55,45,49,49,50,46,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,190,48,147,134,0,0,32,0,49,51,54,48,51,55,45,49,49,51,46,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,168,208,151,212,0,0,32,0,49,51,54,48,51,55,45,49,49,52,46,49,109,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,130,152,239,41,0,0,32,0,49,51,54,48,51,55,45,49,49,53,46,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,152,184,16,149,0,0,32,0,49,51,54,48,51,55,45,49,49,54,46,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,91,172,224,17,0,0,32,0,49,51,54,48,51,55,45,49,49,55,46,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,65,219,165,41,0,0,32,0,49,51,54,48,51,55,45,49,49,56,46,50,109,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,99,178,243,139,0,0,32,0,55,52,115,52,55,50,45,49,51,54,48,51,55,45,49,48,49,46,55,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,111,247,100,41,0,0,32,0,55,52,115,52,55,50,45,49,51,54,48,51,55,45,49,48,50,46,53,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,108,236,79,77,0,0,32,0,55,52,115,50,56,55,45,49,51,54,48,51,55,45,49,48,51,46,52,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,8,207,92,108,0,0,32,0,49,51,54,48,51,55,45,49,48,55,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,20,94,136,165,0,0,16,1,49,51,54,48,51,55,45,49,48,56,46,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,171,241,135,0,0,0,16,1,49,51,54,48,51,55,45,49,48,53,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,149,205,66,70,0,0,16,1,49,51,54,48,51,55,45,49,48,54,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,94,148,223,200,0,0,16,1,49,51,54,48,51,55,45,49,48,57,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,152,113,216,85,0,0,16,1,49,51,54,48,51,55,45,49,49,48,46,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,109,208,74,248,0,0,16,1,49,51,54,48,51,55,45,49,50,48,46,49,54,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,204,243,231,110,0,0,16,1,49,51,54,48,51,55,45,49,49,57,46,49,54,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,31,134,25,250,0,0,16,1,49,51,54,48,51,55,45,49,48,52,46,54,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,89,91,42,158,0,0,32,0,49,51,54,48,51,55,45,49,49,49,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,51,15,112,145,0,0,32,0,49,51,54,48,51,55,45,49,49,50,46,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,190,48,147,134,0,0,32,0,49,51,54,48,51,55,45,49,49,51,46,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,168,208,151,212,0,0,32,0,49,51,54,48,51,55,45,49,49,52,46,49,109,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,130,152,239,41,0,0,32,0,49,51,54,48,51,55,45,49,49,53,46,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,152,184,16,149,0,0,32,0,49,51,54,48,51,55,45,49,49,54,46,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,91,172,224,17,0,0,32,0,49,51,54,48,51,55,45,49,49,55,46,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,65,219,165,41,0,0,32,0,49,51,54,48,51,55,45,49,49,56,46,50,109,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,99,178,243,139,0,0,32,0,55,52,115,52,55,50,45,49,51,54,48,51,55,45,49,48,49,46,55,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,111,247,100,41,0,0,32,0,55,52,115,52,55,50,45,49,51,54,48,51,55,45,49,48,50,46,53,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,108,236,79,77,0,0,32,0,55,52,115,50,56,55,45,49,51,54,48,51,55,45,49,48,51,46,52,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,8,207,92,108,0,0,32,0,184,40,2,0,1,0,0,0,219,231,148,0,248,191,2,0,184,164,8,0,1,0,0,0,218,231,148,0,64,246,1,0,104,28,8,0,1,0,0,0,217,231,148,0,232,209,1,0,64,183,7,0,1,0,0,0,216,231,148,0,104,195,5,0,56,210,6,0,1,0,0,0,239,233,148,0,192,135,2,0,24,163,6,0,1,0,0,0,238,233,148,0,240,108,2,0,152,122,6,0,1,0,0,0,237,233,148,0,96,82,2,0,192,72,6,0,1,0,0,0,236,233,148,0,32,56,2,0,48,123,2,0,1,0,0,0,233,233,148,0,152,30,2,0,96,69,2,0,1,0,0,0,232,233,148,0,232,10,2,0,176,223,1,0,1,0,0,0,47,233,148,0,72,198,1,0,192,209,1,0,1,0,0,0,46,233,148,0,24,182,1,0,24,198,1,0,1,0,0,0,45,233,148,0,40,167,1,0,120,189,1,0,1,0,0,0,44,233,148,0,200,149,1,0,248,187,8,0,1,0,0,0,41,233,148,0,56,126,1,0,184,179,8,0,1,0,0,0,40,233,148,0,32,101,1,0,192,122,8,0,1,0,0,0,119,232,148,0,208,174,1,0,40,116,8,0,1,0,0,0,118,232,148,0,48,160,1,0,72,110,8,0,1,0,0,0,117,232,148,0,160,140,1,0,184,102,8,0,1,0,0,0,116,232,148,0,56,112,1,0,240,45,8,0,1,0,0,0,113,232,148,0,32,92,1,0,40,38,8,0,1,0,0,0,112,232,148,0,64,77,1,0,248,16,8,0,1,0,0,0,39,232,148,0,32,231,8,0,192,12,8,0,1,0,0,0,38,232,148,0,88,214,8,0,224,5,8,0,1,0,0,0,37,232,148,0,224,202,8,0,144,1,8,0,1,0,0,0,36,232,148,0,72,193,8,0,72,204,7,0,1,0,0,0,33,232,148,0,144,180,8,0,208,196,7,0,1,0,0,0,32,232,148,0,208,164,8,0,88,212,3,0,1,0,0,0,144,219,146,0,40,185,3,0,32,77,1,0,1,0,0,0,251,231,148,0,216,70,1,0,49,51,54,48,52,49,45,53,48,55,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,63,19,132,135,0,0,16,1,49,51,54,48,52,49,45,53,48,56,46,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,227,189,67,40,0,0,16,1,49,51,54,48,51,55,45,50,48,53,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,81,237,153,109,0,0,16,1,49,51,54,48,51,55,45,50,48,54,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,145,173,94,84,0,0,16,1,49,51,54,48,52,49,45,54,48,57,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,21,228,78,91,0,0,16,1,49,51,54,48,52,49,45,54,49,48,46,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,226,201,245,65,0,0,16,1,49,51,54,48,51,55,45,49,50,48,46,49,54,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,204,243,231,110,0,0,16,1,49,51,54,48,51,55,45,49,49,57,46,49,54,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,31,134,25,250,0,0,16,1,49,51,54,48,51,55,45,49,48,52,46,54,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,89,91,42,158,0,0,32,0,49,51,54,48,51,55,45,49,49,49,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,51,15,112,145,0,0,32,0,49,51,54,48,51,55,45,49,49,50,46,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,190,48,147,134,0,0,32,0,49,51,54,48,51,55,45,49,49,51,46,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,168,208,151,212,0,0,32,0,49,51,54,48,51,55,45,49,49,52,46,49,109,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,130,152,239,41,0,0,32,0,49,51,54,48,51,55,45,49,49,53,46,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,152,184,16,149,0,0,32,0,49,51,54,48,51,55,45,49,49,54,46,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,91,172,224,17,0,0,32,0,49,51,54,48,51,55,45,49,49,55,46,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,65,219,165,41,0,0,32,0,49,51,54,48,51,55,45,49,49,56,46,50,109,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,99,178,243,139,0,0,32,0,55,52,115,52,55,50,45,49,51,54,48,51,55,45,49,48,49,46,55,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,111,247,100,41,0,0,32,0,55,52,115,52,55,50,45,49,51,54,48,51,55,45,49,48,50,46,53,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,108,236,79,77,0,0,32,0,55,52,115,50,56,55,45,49,51,54,48,51,55,45,49,48,51,46,52,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,8,207,92,108,0,0,32,0,168,86,7,0,1,0,0,0,192,236,146,0,248,191,2,0,24,38,7,0,1,0,0,0,142,250,146,0,184,160,2,0,56,210,6,0,1,0,0,0,136,250,146,0,192,135,2,0,24,163,6,0,1,0,0,0,137,250,146,0,240,108,2,0,152,122,6,0,1,0,0,0,138,250,146,0,96,82,2,0,192,72,6,0,1,0,0,0,139,250,146,0,32,56,2,0,200,110,3,0,1,0,0,0,140,250,146,0,152,30,2,0,120,89,3,0,1,0,0,0,141,250,146,0,232,10,2,0,40,246,1,0,1,0,0,0,193,236,146,0,64,246,1,0,144,236,1,0,1,0,0,0,143,250,146,0,136,224,1,0,176,223,1,0,1,0,0,0,96,242,146,0,72,198,1,0,192,209,1,0,1,0,0,0,97,242,146,0,24,182,1,0,24,198,1,0,1,0,0,0,98,242,146,0,40,167,1,0,120,189,1,0,1,0,0,0,99,242,146,0,200,149,1,0,224,22,1,0,1,0,0,0,100,242,146,0,56,126,1,0,160,14,1,0,1,0,0,0,101,242,146,0,32,101,1,0,88,212,3,0,1,0,0,0,104,215,146,0,40,185,3,0,72,65,1,0,9,0,0,0,112,3,147,0,32,58,1,0,48,50,1,0,9,0,0,0,113,3,147,0,32,58,1,0,184,40,2,0,1,0,0,0,88,239,146,0,248,191,2,0,184,164,8,0,1,0,0,0,89,239,146,0,64,246,1,0,136,204,6,0,1,0,0,0,90,239,146,0,184,160,2,0,176,116,3,0,1,0,0,0,52,254,146,0,152,30,2,0,64,79,3,0,1,0,0,0,229,245,146,0,232,10,2,0,248,48,3,0,1,0,0,0,53,254,146,0,152,138,8,0,88,212,3,0,1,0,0,0,32,218,146,0,40,185,3,0,72,65,1,0,9,0,0,0,232,4,147,0,32,58,1,0,48,50,1,0,9,0,0,0,233,4,147,0,32,58,1,0,168,86,7,0,1,0,0,0,170,191,145,0,248,191,2,0,24,38,7,0,1,0,0,0,168,191,145,0,184,160,2,0,56,210,6,0,1,0,0,0,248,253,146,0,192,135,2,0,24,163,6,0,1,0,0,0,249,253,146,0,240,108,2,0,152,122,6,0,1,0,0,0,250,253,146,0,96,82,2,0,192,72,6,0,1,0,0,0,251,253,146,0,32,56,2,0,200,110,3,0,1,0,0,0,252,253,146,0,152,30,2,0,40,246,1,0,1,0,0,0,171,191,145,0,64,246,1,0,144,236,1,0,1,0,0,0,169,191,145,0,136,224,1,0,176,223,1,0,1,0,0,0,168,245,146,0,72,198,1,0,192,209,1,0,1,0,0,0,169,245,146,0,24,182,1,0,24,198,1,0,1,0,0,0,170,245,146,0,40,167,1,0,120,189,1,0,1,0,0,0,171,245,146,0,200,149,1,0,224,22,1,0,1,0,0,0,172,245,146,0,56,126,1,0,88,212,3,0,1,0,0,0,0,218,146,0,40,185,3,0,16,17,8,0,1,0,0,0,174,191,145,0,224,12,8,0,56,58,1,0,1,0,0,0,173,191,145,0,64,50,1,0,72,65,1,0,9,0,0,0,56,224,146,0,32,58,1,0,48,50,1,0,9,0,0,0,58,224,146,0,32,58,1,0,168,86,7,0,1,0,0,0,170,191,145,0,248,191,2,0,24,38,7,0,1,0,0,0,168,191,145,0,184,160,2,0,56,210,6,0,1,0,0,0,248,253,146,0,192,135,2,0,24,163,6,0,1,0,0,0,249,253,146,0,240,108,2,0,152,122,6,0,1,0,0,0,250,253,146,0,96,82,2,0,192,72,6,0,1,0,0,0,251,253,146,0,32,56,2,0,200,110,3,0,1,0,0,0,252,253,146,0,152,30,2,0,120,89,3,0,1,0,0,0,253,253,146,0,232,10,2,0,120,74,3,0,1,0,0,0,254,253,146,0,152,138,8,0,40,246,1,0,1,0,0,0,171,191,145,0,64,246,1,0,144,236,1,0,1,0,0,0,169,191,145,0,136,224,1,0,176,223,1,0,1,0,0,0,168,245,146,0,72,198,1,0,192,209,1,0,1,0,0,0,169,245,146,0,24,182,1,0,24,198,1,0,1,0,0,0,170,245,146,0,40,167,1,0,120,189,1,0,1,0,0,0,171,245,146,0,200,149,1,0,224,22,1,0,1,0,0,0,172,245,146,0,56,126,1,0,160,14,1,0,1,0,0,0,173,245,146,0,32,101,1,0,176,9,1,0,1,0,0,0,174,245,146,0,96,32,8,0,88,212,3,0,1,0,0,0,0,218,146,0,40,185,3,0,72,65,1,0,9,0,0,0,56,224,146,0,32,58,1,0,48,50,1,0,9,0,0,0,58,224,146,0,32,58,1,0,103,97,108,97,120,105,97,110,46,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,52,45,196,250,1,0,16,1,103,97,108,97,120,105,97,110,46,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,227,131,130,245,1,0,16,1,103,97,108,97,120,105,97,110,46,119,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,192,49,112,76,1,0,16,1,103,97,108,97,120,105,97,110,46,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,148,172,167,150,1,0,16,1,55,108,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,90,215,65,83,1,0,16,1,103,97,108,97,120,105,97,110,46,106,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,152,207,222,132,4,0,32,0,103,97,108,97,120,105,97,110,46,108,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,158,218,26,195,4,0,32,0,54,108,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,103,148,172,195,7,0,32,0,103,97,108,48,48,101,103,46,105,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,12,81,68,124,1,0,16,1,103,97,108,48,49,101,103,46,105,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,101,66,42,1,0,16,1,103,97,108,48,50,46,105,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,22,128,226,48,1,0,16,1,103,97,108,48,51,46,105,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,112,119,126,222,1,0,16,1,103,97,108,48,52,46,105,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,25,201,22,169,1,0,16,1,103,97,108,48,53,46,105,99,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,43,136,117,145,1,0,16,1,103,97,108,48,54,46,105,99,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,218,185,55,18,1,0,16,1,103,97,108,48,55,101,103,46,105,99,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,88,70,20,22,1,0,16,1,103,97,108,48,56,46,105,99,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,204,148,24,144,1,0,16,1,103,97,108,48,57,46,105,99,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,149,246,118,88,1,0,16,1,103,97,108,97,120,105,97,110,46,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,164,67,251,57,4,0,32,0,103,97,108,97,120,105,97,110,46,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,162,86,63,126,4,0,32,0,54,108,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,103,148,172,195,7,0,32,0,12,0,0,0,255,255,0,0,0,0,0,0,13,0,0,0,255,255,0,0,0,0,0,0,14,0,0,0,255,255,4,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,12,0,0,0,1,32,0,0,120,97,1,0,12,0,0,0,1,32,32,0,96,19,1,0,0,0,0,0,254,0,2,0,232,75,4,0,12,0,0,0,1,64,0,0,96,135,7,0,12,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,4,0,32,4,2,0,13,0,0,0,1,192,64,0,224,127,8,0,13,0,0,0,1,192,0,0,32,123,8,0,13,0,0,0,1,192,128,0,192,110,8,0,13,0,0,0,1,192,192,0,104,151,6,0,0,0,0,0,254,0,4,0,64,37,5,0,14,0,0,0,1,3,0,0,120,7,5,0,14,0,0,0,1,3,1,0,176,116,6,0,14,0,0,0,1,3,2,0,32,160,1,0,14,0,0,0,1,3,3,0,80,110,6,0,0,0,0,0,254,0,2,0,128,129,4,0,14,0,0,0,1,4,0,0,208,75,4,0,14,0,0,0,1,4,4,0,8,49,4,0,184,40,2,0,1,0,0,0,40,39,216,0,248,191,2,0,56,250,6,0,1,0,0,0,32,39,216,0,184,160,2,0,184,164,8,0,1,0,0,0,41,39,216,0,64,246,1,0,88,149,7,0,1,0,0,0,33,39,216,0,136,224,1,0,208,158,7,0,1,0,0,0,42,39,216,0,96,82,2,0,184,154,7,0,1,0,0,0,43,39,216,0,32,56,2,0,176,108,2,0,1,0,0,0,44,39,216,0,152,30,2,0,16,83,7,0,1,0,0,0,34,39,216,0,40,167,1,0,96,79,7,0,1,0,0,0,35,39,216,0,200,149,1,0,48,76,7,0,1,0,0,0,36,39,216,0,56,126,1,0,88,212,3,0,1,0,0,0,48,38,216,0,40,185,3,0,16,17,8,0,1,0,0,0,47,39,216,0,224,12,8,0,248,5,8,0,9,0,0,0,112,39,216,0,32,58,1,0,144,250,7,0,9,0,0,0,113,39,216,0,32,58,1,0,248,241,7,0,9,0,0,0,114,39,216,0,32,58,1,0,0,64,0,64,0,64,0,64,0,64,0,64,0,64,0,64,0,64,0,64,0,64,0,64,0,64,0,64,0,64,0,64,0,192,0,192,0,192,0,192,0,192,0,192,0,192,0,192,0,192,0,192,0,192,0,192,0,192,0,192,0,192,0,192,168,86,7,0,1,0,0,0,96,252,146,0,248,191,2,0,24,38,7,0,1,0,0,0,98,252,146,0,184,160,2,0,56,210,6,0,1,0,0,0,32,244,146,0,192,135,2,0,24,163,6,0,1,0,0,0,33,244,146,0,240,108,2,0,152,122,6,0,1,0,0,0,34,244,146,0,96,82,2,0,192,72,6,0,1,0,0,0,35,244,146,0,32,56,2,0,200,110,3,0,1,0,0,0,36,244,146,0,152,30,2,0,40,246,1,0,1,0,0,0,97,252,146,0,64,246,1,0,144,236,1,0,1,0,0,0,99,252,146,0,136,224,1,0,176,223,1,0,1,0,0,0,136,238,146,0,72,198,1,0,192,209,1,0,1,0,0,0,137,238,146,0,24,182,1,0,24,198,1,0,1,0,0,0,138,238,146,0,40,167,1,0,120,189,1,0,1,0,0,0,139,238,146,0,200,149,1,0,224,22,1,0,1,0,0,0,140,238,146,0,56,126,1,0,88,212,3,0,1,0,0,0,240,216,146,0,40,185,3,0,72,65,1,0,9,0,0,0,32,4,147,0,32,58,1,0,168,86,7,0,1,0,0,0,104,242,146,0,248,191,2,0,24,38,7,0,1,0,0,0,151,250,146,0,184,160,2,0,56,210,6,0,1,0,0,0,144,250,146,0,192,135,2,0,24,163,6,0,1,0,0,0,145,250,146,0,240,108,2,0,152,122,6,0,1,0,0,0,146,250,146,0,96,82,2,0,192,72,6,0,1,0,0,0,147,250,146,0,32,56,2,0,200,110,3,0,1,0,0,0,148,250,146,0,152,30,2,0,120,89,3,0,1,0,0,0,149,250,146,0,232,10,2,0,120,74,3,0,1,0,0,0,150,250,146,0,152,138,8,0,40,246,1,0,1,0,0,0,105,242,146,0,64,246,1,0,144,236,1,0,1,0,0,0,159,250,146,0,136,224,1,0,176,223,1,0,1,0,0,0,152,250,146,0,72,198,1,0,192,209,1,0,1,0,0,0,153,250,146,0,24,182,1,0,24,198,1,0,1,0,0,0,154,250,146,0,40,167,1,0,120,189,1,0,1,0,0,0,155,250,146,0,200,149,1,0,224,22,1,0,1,0,0,0,156,250,146,0,56,126,1,0,160,14,1,0,1,0,0,0,157,250,146,0,32,101,1,0,176,9,1,0,1,0,0,0,158,250,146,0,96,32,8,0,88,212,3,0,1,0,0,0,112,215,146,0,40,185,3,0,16,17,8,0,1,0,0,0,106,242,146,0,224,12,8,0,72,65,1,0,9,0,0,0,120,3,147,0,32,58,1,0,48,50,1,0,9,0,0,0,121,3,147,0,32,58,1,0,184,40,2,0,1,0,0,0,30,84,148,0,248,191,2,0,56,250,6,0,1,0,0,0,22,84,148,0,184,160,2,0,184,164,8,0,1,0,0,0,31,84,148,0,64,246,1,0,88,149,7,0,1,0,0,0,23,84,148,0,136,224,1,0,56,210,6,0,1,0,0,0,19,84,148,0,192,135,2,0,24,163,6,0,1,0,0,0,18,84,148,0,240,108,2,0,152,122,6,0,1,0,0,0,17,84,148,0,96,82,2,0,192,72,6,0,1,0,0,0,16,84,148,0,32,56,2,0,48,123,2,0,1,0,0,0,20,84,148,0,152,30,2,0,96,69,2,0,1,0,0,0,21,84,148,0,232,10,2,0,176,223,1,0,1,0,0,0,27,84,148,0,72,198,1,0,192,209,1,0,1,0,0,0,26,84,148,0,24,182,1,0,24,198,1,0,1,0,0,0,25,84,148,0,40,167,1,0,120,189,1,0,1,0,0,0,24,84,148,0,200,149,1,0,248,187,8,0,1,0,0,0,28,84,148,0,56,126,1,0,184,179,8,0,1,0,0,0,29,84,148,0,32,101,1,0,88,212,3,0,1,0,0,0,40,229,148,0,40,185,3,0,248,5,8,0,9,0,0,0,160,72,215,0,32,58,1,0,144,250,7,0,9,0,0,0,161,72,215,0,32,58,1,0,184,40,2,0,1,0,0,0,208,155,215,0,248,191,2,0,56,250,6,0,1,0,0,0,212,155,215,0,184,160,2,0,184,164,8,0,1,0,0,0,209,155,215,0,64,246,1,0,88,149,7,0,1,0,0,0,213,155,215,0,136,224,1,0,56,210,6,0,1,0,0,0,205,155,215,0,192,135,2,0,24,163,6,0,1,0,0,0,204,155,215,0,240,108,2,0,152,122,6,0,1,0,0,0,207,155,215,0,96,82,2,0,192,72,6,0,1,0,0,0,206,155,215,0,32,56,2,0,48,123,2,0,1,0,0,0,202,155,215,0,152,30,2,0,176,223,1,0,1,0,0,0,197,155,215,0,72,198,1,0,192,209,1,0,1,0,0,0,196,155,215,0,24,182,1,0,24,198,1,0,1,0,0,0,199,155,215,0,40,167,1,0,120,189,1,0,1,0,0,0,198,155,215,0,200,149,1,0,248,187,8,0,1,0,0,0,194,155,215,0,56,126,1,0,16,17,8,0,1,0,0,0,211,155,215,0,224,12,8,0,32,77,1,0,1,0,0,0,210,155,215,0,216,70,1,0,88,212,3,0,1,0,0,0,200,154,215,0,40,185,3,0,248,5,8,0,9,0,0,0,0,156,215,0,32,58,1,0,144,250,7,0,9,0,0,0,1,156,215,0,32,58,1,0,108,119,117,95,49,49,97,46,49,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,49,136,247,221,1,0,16,1,108,119,117,95,49,53,97,46,49,52,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,151,32,206,247,1,0,16,1,108,119,117,95,49,48,97,46,49,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,129,140,179,140,1,0,16,1,108,119,117,95,49,52,97,46,49,51,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,253,249,14,215,1,0,16,1,108,119,45,48,55,46,49,51,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,38,42,37,253,2,0,16,1,108,119,45,48,49,46,57,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,152,242,24,3,4,0,32,0,108,119,45,48,56,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,60,228,168,37,4,0,32,0,108,119,45,48,53,46,57,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,215,47,85,228,4,0,32,0,108,119,45,49,50,46,57,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,43,131,106,142,4,0,32,0,108,119,45,48,50,46,49,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,200,197,230,67,4,0,32,0,108,119,45,48,57,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,173,180,156,137,4,0,32,0,108,119,45,48,54,46,49,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,252,223,158,91,4,0,32,0,108,119,45,49,51,46,49,50,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,245,142,5,142,4,0,32,0,108,119,117,95,48,48,46,49,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,99,42,223,89,3,0,16,0,108,119,45,48,51,117,46,49,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,31,5,125,128,5,0,64,0,108,119,45,48,52,117,46,49,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,142,9,205,230,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,108,119,99,104,114,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,57,76,237,84,0,0,0,8,108,119,105,111,46,49,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,12,185,82,173,0,0,0,8,108,119,49,49,99,46,49,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,182,66,39,230,1,0,16,1,108,119,49,53,99,46,49,52,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,22,242,112,27,1,0,16,1,108,119,49,48,99,46,49,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,245,163,94,143,1,0,16,1,108,119,49,52,99,46,49,51,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,114,116,142,112,1,0,16,1,108,119,45,48,55,46,49,51,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,38,42,37,253,2,0,16,1,108,119,45,48,49,46,57,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,152,242,24,3,4,0,32,0,108,119,45,48,56,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,60,228,168,37,4,0,32,0,108,119,45,48,53,46,57,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,215,47,85,228,4,0,32,0,108,119,45,49,50,46,57,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,43,131,106,142,4,0,32,0,108,119,45,48,50,46,49,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,200,197,230,67,4,0,32,0,108,119,45,48,57,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,173,180,156,137,4,0,32,0,108,119,45,48,54,46,49,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,252,223,158,91,4,0,32,0,108,119,45,49,51,46,49,50,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,245,142,5,142,4,0,32,0,108,119,95,48,48,46,49,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,99,42,223,89,3,0,16,0,108,119,45,48,51,117,46,49,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,31,5,125,128,5,0,64,0,108,119,45,48,52,117,46,49,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,142,9,205,230,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,108,119,99,104,114,46,51,97,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,57,76,237,84,0,0,0,8,108,119,105,111,46,49,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,12,185,82,173,0,0,0,8,168,86,7,0,1,0,0,0,232,47,216,0,248,191,2,0,24,38,7,0,1,0,0,0,236,47,216,0,184,160,2,0,56,210,6,0,1,0,0,0,35,48,216,0,192,135,2,0,24,163,6,0,1,0,0,0,34,48,216,0,240,108,2,0,152,122,6,0,1,0,0,0,33,48,216,0,96,82,2,0,192,72,6,0,1,0,0,0,32,48,216,0,32,56,2,0,152,31,6,0,1,0,0,0,36,48,216,0,152,30,2,0,40,127,5,0,4,0,0,0,184,47,216,0,136,191,7,0,40,246,1,0,1,0,0,0,233,47,216,0,64,246,1,0,144,236,1,0,1,0,0,0,237,47,216,0,136,224,1,0,176,223,1,0,1,0,0,0,43,48,216,0,72,198,1,0,192,209,1,0,1,0,0,0,42,48,216,0,24,182,1,0,24,198,1,0,1,0,0,0,41,48,216,0,40,167,1,0,120,189,1,0,1,0,0,0,40,48,216,0,200,149,1,0,8,182,1,0,1,0,0,0,44,48,216,0,56,126,1,0,168,174,1,0,4,0,0,0,176,47,216,0,0,187,4,0,88,212,3,0,1,0,0,0,144,46,216,0,40,185,3,0,16,17,8,0,1,0,0,0,234,47,216,0,224,12,8,0,72,65,1,0,9,0,0,0,232,48,216,0,32,58,1,0,48,50,1,0,9,0,0,0,224,48,216,0,32,58,1,0,224,41,1,0,9,0,0,0,216,48,216,0,32,58,1,0,184,40,2,0,1,0,0,0,168,148,215,0,248,191,2,0,56,250,6,0,1,0,0,0,191,148,215,0,184,160,2,0,184,164,8,0,1,0,0,0,169,148,215,0,64,246,1,0,88,149,7,0,1,0,0,0,183,148,215,0,136,224,1,0,104,28,8,0,1,0,0,0,170,148,215,0,232,209,1,0,248,23,7,0,1,0,0,0,167,148,215,0,144,189,1,0,64,183,7,0,1,0,0,0,171,148,215,0,104,195,5,0,48,19,7,0,1,0,0,0,159,148,215,0,32,245,8,0,56,210,6,0,1,0,0,0,184,148,215,0,192,135,2,0,24,163,6,0,1,0,0,0,185,148,215,0,240,108,2,0,152,122,6,0,1,0,0,0,186,148,215,0,96,82,2,0,192,72,6,0,1,0,0,0,187,148,215,0,32,56,2,0,48,123,2,0,1,0,0,0,188,148,215,0,152,30,2,0,96,69,2,0,1,0,0,0,189,148,215,0,232,10,2,0,176,223,1,0,1,0,0,0,176,148,215,0,72,198,1,0,192,209,1,0,1,0,0,0,177,148,215,0,24,182,1,0,24,198,1,0,1,0,0,0,178,148,215,0,40,167,1,0,120,189,1,0,1,0,0,0,179,148,215,0,200,149,1,0,248,187,8,0,1,0,0,0,180,148,215,0,56,126,1,0,184,179,8,0,1,0,0,0,181,148,215,0,32,101,1,0,192,122,8,0,1,0,0,0,160,148,215,0,208,174,1,0,40,116,8,0,1,0,0,0,161,148,215,0,48,160,1,0,72,110,8,0,1,0,0,0,162,148,215,0,160,140,1,0,184,102,8,0,1,0,0,0,163,148,215,0,56,112,1,0,240,45,8,0,1,0,0,0,164,148,215,0,32,92,1,0,40,38,8,0,1,0,0,0,165,148,215,0,64,77,1,0,248,16,8,0,1,0,0,0,152,148,215,0,32,231,8,0,192,12,8,0,1,0,0,0,153,148,215,0,88,214,8,0,224,5,8,0,1,0,0,0,154,148,215,0,224,202,8,0,144,1,8,0,1,0,0,0,155,148,215,0,72,193,8,0,72,204,7,0,1,0,0,0,156,148,215,0,144,180,8,0,208,196,7,0,1,0,0,0,157,148,215,0,208,164,8,0,88,212,3,0,1,0,0,0,200,147,215,0,40,185,3,0,16,17,8,0,1,0,0,0,172,148,215,0,224,12,8,0,0,105,5,0,1,0,0,0,173,148,215,0,192,99,5,0,152,120,4,0,1,0,0,0,174,148,215,0,96,118,4,0,56,58,1,0,1,0,0,0,175,148,215,0,64,50,1,0,248,5,8,0,9,0,0,0,96,149,215,0,32,58,1,0,144,250,7,0,9,0,0,0,97,149,215,0,32,58,1,0,168,86,7,0,1,0,0,0,3,191,145,0,248,191,2,0,24,38,7,0,1,0,0,0,5,191,145,0,184,160,2,0,56,210,6,0,1,0,0,0,216,250,146,0,192,135,2,0,24,163,6,0,1,0,0,0,217,250,146,0,240,108,2,0,152,122,6,0,1,0,0,0,218,250,146,0,96,82,2,0,192,72,6,0,1,0,0,0,219,250,146,0,32,56,2,0,200,110,3,0,1,0,0,0,220,250,146,0,152,30,2,0,120,89,3,0,1,0,0,0,221,250,146,0,232,10,2,0,40,246,1,0,1,0,0,0,4,191,145,0,64,246,1,0,144,236,1,0,1,0,0,0,6,191,145,0,136,224,1,0,176,223,1,0,1,0,0,0,176,242,146,0,72,198,1,0,192,209,1,0,1,0,0,0,177,242,146,0,24,182,1,0,24,198,1,0,1,0,0,0,178,242,146,0,40,167,1,0,120,189,1,0,1,0,0,0,179,242,146,0,200,149,1,0,224,22,1,0,1,0,0,0,180,242,146,0,56,126,1,0,160,14,1,0,1,0,0,0,181,242,146,0,32,101,1,0,168,132,8,0,1,0,0,0,0,191,145,0,232,209,1,0,72,126,8,0,1,0,0,0,30,238,146,0,144,189,1,0,192,122,8,0,1,0,0,0,24,238,146,0,208,174,1,0,40,116,8,0,1,0,0,0,25,238,146,0,48,160,1,0,72,110,8,0,1,0,0,0,26,238,146,0,160,140,1,0,184,102,8,0,1,0,0,0,27,238,146,0,56,112,1,0,248,67,8,0,1,0,0,0,28,238,146,0,32,92,1,0,136,64,8,0,1,0,0,0,29,238,146,0,64,77,1,0,88,212,3,0,1,0,0,0,152,215,146,0,40,185,3,0,56,58,1,0,1,0,0,0,1,191,145,0,64,50,1,0,72,65,1,0,9,0,0,0,52,223,146,0,32,58,1,0,168,86,7,0,1,0,0,0,157,2,147,0,248,191,2,0,24,38,7,0,1,0,0,0,159,2,147,0,184,160,2,0,56,210,6,0,1,0,0,0,153,2,147,0,192,135,2,0,24,163,6,0,1,0,0,0,152,2,147,0,240,108,2,0,152,122,6,0,1,0,0,0,155,2,147,0,96,82,2,0,192,72,6,0,1,0,0,0,154,2,147,0,32,56,2,0,200,110,3,0,1,0,0,0,156,2,147,0,152,30,2,0,40,246,1,0,1,0,0,0,221,249,146,0,64,246,1,0,144,236,1,0,1,0,0,0,158,2,147,0,136,224,1,0,176,223,1,0,1,0,0,0,217,249,146,0,72,198,1,0,192,209,1,0,1,0,0,0,216,249,146,0,24,182,1,0,24,198,1,0,1,0,0,0,219,249,146,0,40,167,1,0,120,189,1,0,1,0,0,0,218,249,146,0,200,149,1,0,224,22,1,0,1,0,0,0,220,249,146,0,56,126,1,0,88,212,3,0,1,0,0,0,16,222,146,0,40,185,3,0,72,65,1,0,9,0,0,0,160,7,147,0,32,58,1,0,184,40,2,0,1,0,0,0,41,39,216,0,248,191,2,0,56,250,6,0,1,0,0,0,32,39,216,0,184,160,2,0,88,149,7,0,1,0,0,0,33,39,216,0,136,224,1,0,208,158,7,0,1,0,0,0,42,39,216,0,96,82,2,0,184,154,7,0,1,0,0,0,43,39,216,0,32,56,2,0,176,108,2,0,1,0,0,0,44,39,216,0,152,30,2,0,88,212,3,0,1,0,0,0,48,38,216,0,40,185,3,0,248,5,8,0,9,0,0,0,112,39,216,0,32,58,1,0,144,250,7,0,9,0,0,0,113,39,216,0,32,58,1,0,248,241,7,0,9,0,0,0,114,39,216,0,32,58,1,0,168,86,7,0,1,0,0,0,136,239,146,0,248,191,2,0,24,38,7,0,1,0,0,0,223,254,146,0,184,160,2,0,152,122,6,0,1,0,0,0,216,254,146,0,96,82,2,0,192,72,6,0,1,0,0,0,217,254,146,0,32,56,2,0,200,110,3,0,1,0,0,0,220,254,146,0,152,30,2,0,40,246,1,0,1,0,0,0,137,239,146,0,64,246,1,0,144,236,1,0,1,0,0,0,127,246,146,0,136,224,1,0,24,198,1,0,1,0,0,0,120,246,146,0,40,167,1,0,120,189,1,0,1,0,0,0,121,246,146,0,200,149,1,0,224,22,1,0,1,0,0,0,124,246,146,0,56,126,1,0,88,212,3,0,1,0,0,0,160,218,146,0,40,185,3,0,16,17,8,0,1,0,0,0,138,239,146,0,224,12,8,0,72,65,1,0,9,0,0,0,48,5,147,0,32,58,1,0,48,50,1,0,9,0,0,0,49,5,147,0,32,58,1,0,224,41,1,0,9,0,0,0,50,5,147,0,32,58,1,0,184,40,2,0,1,0,0,0,47,39,216,0,248,191,2,0,56,250,6,0,1,0,0,0,39,39,216,0,184,160,2,0,184,164,8,0,1,0,0,0,46,39,216,0,64,246,1,0,88,149,7,0,1,0,0,0,38,39,216,0,136,224,1,0,240,167,7,0,1,0,0,0,40,39,216,0,192,135,2,0,176,163,7,0,1,0,0,0,42,39,216,0,240,108,2,0,208,158,7,0,1,0,0,0,45,39,216,0,96,82,2,0,184,154,7,0,1,0,0,0,44,39,216,0,32,56,2,0,176,108,2,0,1,0,0,0,43,39,216,0,152,30,2,0,128,98,2,0,1,0,0,0,41,39,216,0,232,10,2,0,88,212,3,0,1,0,0,0,48,38,216,0,40,185,3,0,248,5,8,0,9,0,0,0,112,39,216,0,32,58,1,0,144,250,7,0,9,0,0,0,113,39,216,0,32,58,1,0,248,241,7,0,9,0,0,0,114,39,216,0,32,58,1,0,72,82,8,0,9,0,0,0,115,39,216,0,32,58,1,0,184,40,2,0,1,0,0,0,122,83,148,0,248,191,2,0,56,250,6,0,1,0,0,0,120,83,148,0,184,160,2,0,184,164,8,0,1,0,0,0,123,83,148,0,64,246,1,0,88,149,7,0,1,0,0,0,121,83,148,0,136,224,1,0,56,210,6,0,1,0,0,0,136,83,148,0,192,135,2,0,24,163,6,0,1,0,0,0,137,83,148,0,240,108,2,0,152,122,6,0,1,0,0,0,138,83,148,0,96,82,2,0,192,72,6,0,1,0,0,0,139,83,148,0,32,56,2,0,48,123,2,0,1,0,0,0,140,83,148,0,152,30,2,0,96,69,2,0,1,0,0,0,141,83,148,0,232,10,2,0,176,223,1,0,1,0,0,0,128,83,148,0,72,198,1,0,192,209,1,0,1,0,0,0,129,83,148,0,24,182,1,0,24,198,1,0,1,0,0,0,130,83,148,0,40,167,1,0,120,189,1,0,1,0,0,0,131,83,148,0,200,149,1,0,248,187,8,0,1,0,0,0,132,83,148,0,56,126,1,0,184,179,8,0,1,0,0,0,133,83,148,0,32,101,1,0,88,212,3,0,1,0,0,0,192,228,148,0,40,185,3,0,16,17,8,0,1,0,0,0,126,83,148,0,224,12,8,0,248,5,8,0,9,0,0,0,16,71,215,0,32,58,1,0,184,40,2,0,1,0,0,0,208,155,215,0,248,191,2,0,56,250,6,0,1,0,0,0,212,155,215,0,184,160,2,0,184,164,8,0,1,0,0,0,209,155,215,0,64,246,1,0,88,149,7,0,1,0,0,0,213,155,215,0,136,224,1,0,56,210,6,0,1,0,0,0,178,155,215,0,192,135,2,0,24,163,6,0,1,0,0,0,179,155,215,0,240,108,2,0,152,122,6,0,1,0,0,0,176,155,215,0,96,82,2,0,192,72,6,0,1,0,0,0,177,155,215,0,32,56,2,0,136,230,2,0,1,0,0,0,200,155,215,0,152,30,2,0,192,228,2,0,1,0,0,0,201,155,215,0,232,10,2,0,120,225,2,0,1,0,0,0,202,155,215,0,152,138,8,0,144,224,2,0,1,0,0,0,203,155,215,0,48,119,7,0,184,222,2,0,1,0,0,0,204,155,215,0,112,109,7,0,168,217,2,0,1,0,0,0,205,155,215,0,24,133,7,0,56,211,2,0,1,0,0,0,206,155,215,0,72,120,6,0,80,207,2,0,1,0,0,0,207,155,215,0,88,119,7,0,224,204,2,0,1,0,0,0,185,155,215,0,240,202,2,0,120,36,5,0,1,0,0,0,186,155,215,0,216,199,2,0,24,197,2,0,1,0,0,0,184,155,215,0,0,195,2,0,176,223,1,0,1,0,0,0,182,155,215,0,72,198,1,0,192,209,1,0,1,0,0,0,183,155,215,0,24,182,1,0,24,198,1,0,1,0,0,0,180,155,215,0,40,167,1,0,120,189,1,0,1,0,0,0,181,155,215,0,200,149,1,0,232,192,2,0,1,0,0,0,192,155,215,0,56,126,1,0,64,191,2,0,1,0,0,0,193,155,215,0,32,101,1,0,216,189,2,0,1,0,0,0,194,155,215,0,96,32,8,0,64,187,2,0,1,0,0,0,195,155,215,0,16,68,7,0,0,186,2,0,1,0,0,0,196,155,215,0,240,58,7,0,224,182,2,0,1,0,0,0,197,155,215,0,200,42,1,0,160,180,2,0,1,0,0,0,198,155,215,0,16,178,2,0,40,176,2,0,1,0,0,0,199,155,215,0,136,174,2,0,232,173,2,0,1,0,0,0,189,155,215,0,48,173,2,0,128,149,1,0,1,0,0,0,190,155,215,0,0,171,2,0,152,169,2,0,1,0,0,0,188,155,215,0,56,168,2,0,16,17,8,0,1,0,0,0,211,155,215,0,224,12,8,0,32,77,1,0,1,0,0,0,210,155,215,0,216,70,1,0,88,212,3,0,1,0,0,0,200,154,215,0,40,185,3,0,248,5,8,0,9,0,0,0,0,156,215,0,32,58,1,0,144,250,7,0,9,0,0,0,1,156,215,0,32,58,1,0,168,86,7,0,1,0,0,0,111,2,147,0,248,191,2,0,24,38,7,0,1,0,0,0,168,236,146,0,184,160,2,0,56,210,6,0,1,0,0,0,106,2,147,0,192,135,2,0,24,163,6,0,1,0,0,0,107,2,147,0,240,108,2,0,152,122,6,0,1,0,0,0,105,2,147,0,96,82,2,0,192,72,6,0,1,0,0,0,104,2,147,0,32,56,2,0,200,110,3,0,1,0,0,0,108,2,147,0,152,30,2,0,120,89,3,0,1,0,0,0,109,2,147,0,232,10,2,0,40,246,1,0,1,0,0,0,175,249,146,0,64,246,1,0,144,236,1,0,1,0,0,0,169,236,146,0,136,224,1,0,176,223,1,0,1,0,0,0,170,249,146,0,72,198,1,0,192,209,1,0,1,0,0,0,171,249,146,0,24,182,1,0,24,198,1,0,1,0,0,0,169,249,146,0,40,167,1,0,120,189,1,0,1,0,0,0,168,249,146,0,200,149,1,0,224,22,1,0,1,0,0,0,172,249,146,0,56,126,1,0,160,14,1,0,1,0,0,0,173,249,146,0,32,101,1,0,88,212,3,0,1,0,0,0,208,221,146,0,40,185,3,0,32,77,1,0,1,0,0,0,24,236,146,0,216,70,1,0,56,122,5,0,1,0,0,0,172,236,146,0,224,12,8,0,0,105,5,0,1,0,0,0,173,236,146,0,128,176,7,0,168,86,7,0,1,0,0,0,136,239,146,0,248,191,2,0,24,38,7,0,1,0,0,0,223,254,146,0,184,160,2,0,56,210,6,0,1,0,0,0,218,254,146,0,192,135,2,0,24,163,6,0,1,0,0,0,219,254,146,0,240,108,2,0,152,122,6,0,1,0,0,0,216,254,146,0,96,82,2,0,192,72,6,0,1,0,0,0,217,254,146,0,32,56,2,0,200,110,3,0,1,0,0,0,220,254,146,0,152,30,2,0,120,89,3,0,1,0,0,0,221,254,146,0,232,10,2,0,40,246,1,0,1,0,0,0,137,239,146,0,64,246,1,0,144,236,1,0,1,0,0,0,127,246,146,0,136,224,1,0,176,223,1,0,1,0,0,0,122,246,146,0,72,198,1,0,192,209,1,0,1,0,0,0,123,246,146,0,24,182,1,0,24,198,1,0,1,0,0,0,120,246,146,0,40,167,1,0,120,189,1,0,1,0,0,0,121,246,146,0,200,149,1,0,224,22,1,0,1,0,0,0,124,246,146,0,56,126,1,0,160,14,1,0,1,0,0,0,125,246,146,0,32,101,1,0,88,212,3,0,1,0,0,0,160,218,146,0,40,185,3,0,16,17,8,0,1,0,0,0,138,239,146,0,224,12,8,0,56,58,1,0,1,0,0,0,139,239,146,0,64,50,1,0,72,65,1,0,9,0,0,0,48,5,147,0,32,58,1,0,48,50,1,0,9,0,0,0,49,5,147,0,32,58,1,0,224,41,1,0,9,0,0,0,50,5,147,0,32,58,1,0,117,101,99,117,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,12,72,146,103,1,0,16,1,117,101,99,117,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,213,105,206,149,1,0,16,1,117,101,99,117,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,173,120,30,58,1,0,16,1,117,101,99,117,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,204,243,226,163,1,0,16,1,117,101,99,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,54,20,175,220,5,0,32,0,117,101,99,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,65,223,7,40,5,0,32,0,117,101,99,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,2,141,112,138,5,0,32,0,117,101,99,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,239,224,123,222,5,0,32,0,117,101,99,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,88,53,0,26,5,0,32,0,117,101,99,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,249,166,248,79,5,0,32,0,117,101,99,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,18,174,103,177,5,0,32,0,117,101,99,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,194,189,100,16,5,0,32,0,117,101,99,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,21,189,53,194,10,0,16,1,117,101,99,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,57,93,178,129,12,0,64,0,117,101,99,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,82,158,114,39,12,0,64,0,168,86,7,0,1,0,0,0,212,47,216,0,248,191,2,0,24,38,7,0,1,0,0,0,208,47,216,0,184,160,2,0,56,210,6,0,1,0,0,0,35,48,216,0,192,135,2,0,24,163,6,0,1,0,0,0,34,48,216,0,240,108,2,0,152,122,6,0,1,0,0,0,33,48,216,0,96,82,2,0,192,72,6,0,1,0,0,0,32,48,216,0,32,56,2,0,240,13,7,0,1,0,0,0,36,48,216,0,152,30,2,0,152,31,6,0,1,0,0,0,37,48,216,0,232,10,2,0,64,2,7,0,1,0,0,0,38,48,216,0,152,138,8,0,40,246,1,0,1,0,0,0,213,47,216,0,64,246,1,0,144,236,1,0,1,0,0,0,209,47,216,0,136,224,1,0,176,223,1,0,1,0,0,0,43,48,216,0,72,198,1,0,192,209,1,0,1,0,0,0,42,48,216,0,24,182,1,0,24,198,1,0,1,0,0,0,41,48,216,0,40,167,1,0,120,189,1,0,1,0,0,0,40,48,216,0,200,149,1,0,8,9,7,0,1,0,0,0,44,48,216,0,56,126,1,0,8,182,1,0,1,0,0,0,45,48,216,0,32,101,1,0,248,251,6,0,1,0,0,0,46,48,216,0,96,32,8,0,88,212,3,0,1,0,0,0,144,46,216,0,40,185,3,0,240,152,1,0,1,0,0,0,201,47,216,0,216,70,1,0,16,17,8,0,1,0,0,0,202,47,216,0,224,12,8,0,136,67,2,0,1,0,0,0,176,48,216,0,48,119,7,0,8,66,2,0,1,0,0,0,184,48,216,0,112,109,7,0,184,40,2,0,1,0,0,0,208,155,215,0,248,191,2,0,56,250,6,0,1,0,0,0,212,155,215,0,184,160,2,0,184,164,8,0,1,0,0,0,209,155,215,0,64,246,1,0,88,149,7,0,1,0,0,0,213,155,215,0,136,224,1,0,248,23,7,0,1,0,0,0,214,155,215,0,144,189,1,0,48,19,7,0,1,0,0,0,215,155,215,0,32,245,8,0,56,210,6,0,1,0,0,0,194,155,215,0,192,135,2,0,24,163,6,0,1,0,0,0,195,155,215,0,240,108,2,0,152,122,6,0,1,0,0,0,192,155,215,0,96,82,2,0,192,72,6,0,1,0,0,0,193,155,215,0,32,56,2,0,48,123,2,0,1,0,0,0,200,155,215,0,152,30,2,0,96,69,2,0,1,0,0,0,201,155,215,0,232,10,2,0,176,223,1,0,1,0,0,0,198,155,215,0,72,198,1,0,192,209,1,0,1,0,0,0,199,155,215,0,24,182,1,0,24,198,1,0,1,0,0,0,196,155,215,0,40,167,1,0,120,189,1,0,1,0,0,0,197,155,215,0,200,149,1,0,248,187,8,0,1,0,0,0,202,155,215,0,56,126,1,0,184,179,8,0,1,0,0,0,203,155,215,0,32,101,1,0,192,122,8,0,1,0,0,0,186,155,215,0,208,174,1,0,40,116,8,0,1,0,0,0,187,155,215,0,48,160,1,0,72,110,8,0,1,0,0,0,184,155,215,0,160,140,1,0,184,102,8,0,1,0,0,0,185,155,215,0,56,112,1,0,240,45,8,0,1,0,0,0,204,155,215,0,32,92,1,0,40,38,8,0,1,0,0,0,205,155,215,0,64,77,1,0,248,16,8,0,1,0,0,0,190,155,215,0,32,231,8,0,192,12,8,0,1,0,0,0,191,155,215,0,88,214,8,0,224,5,8,0,1,0,0,0,188,155,215,0,224,202,8,0,144,1,8,0,1,0,0,0,189,155,215,0,72,193,8,0,72,204,7,0,1,0,0,0,206,155,215,0,144,180,8,0,208,196,7,0,1,0,0,0,207,155,215,0,208,164,8,0,16,17,8,0,1,0,0,0,211,155,215,0,224,12,8,0,32,77,1,0,1,0,0,0,210,155,215,0,216,70,1,0,88,212,3,0,1,0,0,0,200,154,215,0,40,185,3,0,248,5,8,0,9,0,0,0,0,156,215,0,32,58,1,0,144,250,7,0,9,0,0,0,1,156,215,0,32,58,1,0,0,0,0,0,8,0,0,0,16,0,0,0,24,0,0,0,32,0,0,0,40,0,0,0,48,0,0,0,56,0,0,0,64,0,0,0,72,0,0,0,80,0,0,0,88,0,0,0,96,0,0,0,104,0,0,0,112,0,0,0,120,0,0,0,0,2,0,0,8,2,0,0,16,2,0,0,24,2,0,0,32,2,0,0,40,2,0,0,48,2,0,0,56,2,0,0,64,2,0,0,72,2,0,0,80,2,0,0,88,2,0,0,96,2,0,0,104,2,0,0,112,2,0,0,120,2,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,128,0,0,0,129,0,0,0,130,0,0,0,131,0,0,0,132,0,0,0,133,0,0,0,134,0,0,0,135,0,0,0,0,1,0,0,1,1,0,0,2,1,0,0,3,1,0,0,4,1,0,0,5,1,0,0,6,1,0,0,7,1,0,0,128,1,0,0,129,1,0,0,130,1,0,0,131,1,0,0,132,1,0,0,133,1,0,0,134,1,0,0,135,1,0,0,0,0,0,0,0,0,0,0,168,86,7,0,1,0,0,0,205,255,146,0,248,191,2,0,152,122,6,0,1,0,0,0,201,255,146,0,96,82,2,0,192,72,6,0,1,0,0,0,202,255,146,0,32,56,2,0,200,110,3,0,1,0,0,0,69,247,146,0,152,30,2,0,120,89,3,0,1,0,0,0,70,247,146,0,232,10,2,0,88,212,3,0,1,0,0,0,32,219,146,0,40,185,3,0,16,17,8,0,1,0,0,0,207,255,146,0,224,12,8,0,72,65,1,0,9,0,0,0,128,5,147,0,32,58,1,0,184,40,2,0,1,0,0,0,40,39,216,0,248,191,2,0,184,164,8,0,1,0,0,0,41,39,216,0,64,246,1,0,208,158,7,0,1,0,0,0,42,39,216,0,96,82,2,0,184,154,7,0,1,0,0,0,43,39,216,0,32,56,2,0,176,108,2,0,1,0,0,0,32,39,216,0,152,30,2,0,128,98,2,0,1,0,0,0,33,39,216,0,232,10,2,0,88,212,3,0,1,0,0,0,48,38,216,0,40,185,3,0,248,5,8,0,9,0,0,0,112,39,216,0,32,58,1,0,144,250,7,0,9,0,0,0,113,39,216,0,32,58,1,0,248,241,7,0,9,0,0,0,114,39,216,0,32,58,1,0,72,82,8,0,9,0,0,0,115,39,216,0,32,58,1,0,184,40,2,0,1,0,0,0,250,150,215,0,248,191,2,0,56,250,6,0,1,0,0,0,15,151,215,0,184,160,2,0,184,164,8,0,1,0,0,0,251,150,215,0,64,246,1,0,56,210,6,0,1,0,0,0,8,151,215,0,192,135,2,0,24,163,6,0,1,0,0,0,9,151,215,0,240,108,2,0,152,122,6,0,1,0,0,0,10,151,215,0,96,82,2,0,192,72,6,0,1,0,0,0,11,151,215,0,32,56,2,0,48,123,2,0,1,0,0,0,12,151,215,0,152,30,2,0,96,69,2,0,1,0,0,0,13,151,215,0,232,10,2,0,88,212,3,0,1,0,0,0,200,147,215,0,40,185,3,0,16,17,8,0,1,0,0,0,249,150,215,0,224,12,8,0,56,58,1,0,1,0,0,0,248,150,215,0,64,50,1,0,248,5,8,0,9,0,0,0,24,151,215,0,32,58,1,0,144,250,7,0,9,0,0,0,25,151,215,0,32,58,1,0,168,86,7,0,1,0,0,0,136,239,146,0,248,191,2,0,24,38,7,0,1,0,0,0,223,254,146,0,184,160,2,0,56,210,6,0,1,0,0,0,218,254,146,0,192,135,2,0,24,163,6,0,1,0,0,0,219,254,146,0,240,108,2,0,152,122,6,0,1,0,0,0,216,254,146,0,96,82,2,0,192,72,6,0,1,0,0,0,217,254,146,0,32,56,2,0,200,110,3,0,1,0,0,0,220,254,146,0,152,30,2,0,120,89,3,0,1,0,0,0,221,254,146,0,232,10,2,0,120,74,3,0,1,0,0,0,222,254,146,0,152,138,8,0,40,246,1,0,1,0,0,0,137,239,146,0,64,246,1,0,144,236,1,0,1,0,0,0,127,246,146,0,136,224,1,0,176,223,1,0,1,0,0,0,122,246,146,0,72,198,1,0,192,209,1,0,1,0,0,0,123,246,146,0,24,182,1,0,24,198,1,0,1,0,0,0,120,246,146,0,40,167,1,0,120,189,1,0,1,0,0,0,121,246,146,0,200,149,1,0,224,22,1,0,1,0,0,0,124,246,146,0,56,126,1,0,160,14,1,0,1,0,0,0,125,246,146,0,32,101,1,0,176,9,1,0,1,0,0,0,126,246,146,0,96,32,8,0,88,212,3,0,1,0,0,0,160,218,146,0,40,185,3,0,16,17,8,0,1,0,0,0,138,239,146,0,224,12,8,0,56,58,1,0,1,0,0,0,139,239,146,0,64,50,1,0,72,65,1,0,9,0,0,0,48,5,147,0,32,58,1,0,48,50,1,0,9,0,0,0,49,5,147,0,32,58,1,0,224,41,1,0,9,0,0,0,50,5,147,0,32,58,1,0,97,49,52,46,51,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,231,244,185,196,0,0,16,1,97,49,49,46,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,96,124,204,228,0,0,16,1,97,49,50,46,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,247,250,129,43,0,0,16,1,97,57,46,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,157,46,44,197,0,0,16,1,101,103,48,55,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,81,47,29,0,0,0,16,1,97,50,50,46,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,32,188,145,103,0,0,32,0,97,50,51,46,57,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,143,252,117,93,0,0,32,0,97,50,53,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,229,195,207,5,0,0,32,0,97,50,55,46,49,48,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,143,152,30,225,0,0,32,0,97,50,52,46,49,48,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,128,216,147,184,0,0,32,0,97,50,54,46,49,48,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,218,109,34,111,0,0,32,0,97,50,49,46,57,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,252,137,233,178,0,0,32,0,97,50,57,46,49,48,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,102,9,248,75,0,0,32,0,97,50,48,46,57,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,147,7,28,231,0,0,32,0,97,50,56,46,49,48,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,45,3,56,45,0,0,32,0,97,54,46,52,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,127,214,23,86,0,0,32,0,97,50,46,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,51,38,228,23,0,0,32,0,97,56,46,53,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,216,232,131,186,0,0,32,0,97,52,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,52,161,162,254,0,0,32,0,97,53,46,51,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,142,224,145,253,0,0,32,0,97,49,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,10,118,60,232,0,0,32,0,97,55,46,52,45,53,103,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,35,123,27,96,0,0,32,0,97,51,46,52,45,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,26,138,238,238,0,0,32,0,97,51,48,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,38,104,128,246,0,0,64,0,105,56,55,53,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,16,16,168,86,7,0,1,0,0,0,143,239,146,0,248,191,2,0,24,38,7,0,1,0,0,0,223,254,146,0,184,160,2,0,56,210,6,0,1,0,0,0,216,254,146,0,192,135,2,0,24,163,6,0,1,0,0,0,217,254,146,0,240,108,2,0,152,122,6,0,1,0,0,0,218,254,146,0,96,82,2,0,192,72,6,0,1,0,0,0,219,254,146,0,32,56,2,0,200,110,3,0,1,0,0,0,220,254,146,0,152,30,2,0,120,89,3,0,1,0,0,0,221,254,146,0,232,10,2,0,192,61,3,0,1,0,0,0,225,254,146,0,48,119,7,0,40,246,1,0,1,0,0,0,142,239,146,0,64,246,1,0,144,236,1,0,1,0,0,0,127,246,146,0,136,224,1,0,176,223,1,0,1,0,0,0,120,246,146,0,72,198,1,0,192,209,1,0,1,0,0,0,121,246,146,0,24,182,1,0,24,198,1,0,1,0,0,0,122,246,146,0,40,167,1,0,120,189,1,0,1,0,0,0,123,246,146,0,200,149,1,0,224,22,1,0,1,0,0,0,124,246,146,0,56,126,1,0,160,14,1,0,1,0,0,0,125,246,146,0,32,101,1,0,200,3,1,0,1,0,0,0,129,246,146,0,16,68,7,0,88,212,3,0,1,0,0,0,160,218,146,0,40,185,3,0,16,17,8,0,1,0,0,0,141,239,146,0,224,12,8,0,56,58,1,0,1,0,0,0,140,239,146,0,64,50,1,0,72,65,1,0,9,0,0,0,48,5,147,0,32,58,1,0,48,50,1,0,9,0,0,0,49,5,147,0,32,58,1,0,224,41,1,0,9,0,0,0,50,5,147,0,32,58,1,0,184,40,2,0,1,0,0,0,122,151,215,0,248,191,2,0,56,250,6,0,1,0,0,0,143,151,215,0,184,160,2,0,184,164,8,0,1,0,0,0,123,151,215,0,64,246,1,0,88,149,7,0,1,0,0,0,135,151,215,0,136,224,1,0,56,210,6,0,1,0,0,0,136,151,215,0,192,135,2,0,24,163,6,0,1,0,0,0,137,151,215,0,240,108,2,0,152,122,6,0,1,0,0,0,138,151,215,0,96,82,2,0,192,72,6,0,1,0,0,0,139,151,215,0,32,56,2,0,48,123,2,0,1,0,0,0,140,151,215,0,152,30,2,0,96,69,2,0,1,0,0,0,141,151,215,0,232,10,2,0,176,223,1,0,1,0,0,0,128,151,215,0,72,198,1,0,192,209,1,0,1,0,0,0,129,151,215,0,24,182,1,0,24,198,1,0,1,0,0,0,130,151,215,0,40,167,1,0,120,189,1,0,1,0,0,0,131,151,215,0,200,149,1,0,248,187,8,0,1,0,0,0,132,151,215,0,56,126,1,0,184,179,8,0,1,0,0,0,133,151,215,0,32,101,1,0,88,212,3,0,1,0,0,0,200,147,215,0,40,185,3,0,16,17,8,0,1,0,0,0,121,151,215,0,224,12,8,0,56,58,1,0,1,0,0,0,120,151,215,0,64,50,1,0,248,5,8,0,9,0,0,0,152,151,215,0,32,58,1,0,144,250,7,0,9,0,0,0,153,151,215,0,32,58,1,0,184,40,2,0,1,0,0,0,40,39,216,0,248,191,2,0,56,250,6,0,1,0,0,0,32,39,216,0,184,160,2,0,88,149,7,0,1,0,0,0,33,39,216,0,136,224,1,0,240,167,7,0,1,0,0,0,44,39,216,0,192,135,2,0,176,163,7,0,1,0,0,0,47,39,216,0,240,108,2,0,208,158,7,0,1,0,0,0,42,39,216,0,96,82,2,0,184,154,7,0,1,0,0,0,43,39,216,0,32,56,2,0,176,108,2,0,1,0,0,0,45,39,216,0,152,30,2,0,8,96,7,0,1,0,0,0,36,39,216,0,72,198,1,0,48,89,7,0,1,0,0,0,46,39,216,0,24,182,1,0,16,83,7,0,1,0,0,0,34,39,216,0,40,167,1,0,96,79,7,0,1,0,0,0,35,39,216,0,200,149,1,0,48,76,7,0,1,0,0,0,37,39,216,0,56,126,1,0,88,212,3,0,1,0,0,0,48,38,216,0,40,185,3,0,248,5,8,0,9,0,0,0,112,39,216,0,32,58,1,0,144,250,7,0,9,0,0,0,113,39,216,0,32,58,1,0,248,241,7,0,9,0,0,0,114,39,216,0,32,58,1,0,106,117,109,112,46,119,97,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,108,97,110,100,46,119,97,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,114,111,97,114,46,119,97,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,99,108,105,109,98,48,46,119,97,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,99,108,105,109,98,49,46,119,97,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,99,108,105,109,98,50,46,119,97,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,100,101,97,116,104,46,119,97,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,100,114,111,112,46,119,97,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,119,97,108,107,48,46,119,97,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,119,97,108,107,49,46,119,97,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,119,97,108,107,50,46,119,97,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,115,110,97,112,106,97,119,46,119,97,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,40,2,0,1,0,0,0,16,244,146,0,248,191,2,0,184,164,8,0,1,0,0,0,17,244,146,0,64,246,1,0,104,28,8,0,1,0,0,0,18,244,146,0,232,209,1,0,24,38,7,0,1,0,0,0,87,252,146,0,184,160,2,0,56,210,6,0,1,0,0,0,80,252,146,0,192,135,2,0,24,163,6,0,1,0,0,0,81,252,146,0,240,108,2,0,152,122,6,0,1,0,0,0,82,252,146,0,96,82,2,0,192,72,6,0,1,0,0,0,83,252,146,0,32,56,2,0,200,110,3,0,1,0,0,0,84,252,146,0,152,30,2,0,120,89,3,0,1,0,0,0,85,252,146,0,232,10,2,0,144,236,1,0,1,0,0,0,95,252,146,0,136,224,1,0,176,223,1,0,1,0,0,0,88,252,146,0,72,198,1,0,192,209,1,0,1,0,0,0,89,252,146,0,24,182,1,0,24,198,1,0,1,0,0,0,90,252,146,0,40,167,1,0,120,189,1,0,1,0,0,0,91,252,146,0,200,149,1,0,224,22,1,0,1,0,0,0,92,252,146,0,56,126,1,0,160,14,1,0,1,0,0,0,93,252,146,0,32,101,1,0,88,212,3,0,1,0,0,0,232,216,146,0,40,185,3,0,72,65,1,0,9,0,0,0,24,4,147,0,32,58,1,0,168,86,7,0,1,0,0,0,168,1,147,0,248,191,2,0,24,38,7,0,1,0,0,0,239,248,146,0,184,160,2,0,56,210,6,0,1,0,0,0,234,248,146,0,192,135,2,0,24,163,6,0,1,0,0,0,235,248,146,0,240,108,2,0,152,122,6,0,1,0,0,0,232,248,146,0,96,82,2,0,192,72,6,0,1,0,0,0,233,248,146,0,32,56,2,0,200,110,3,0,1,0,0,0,236,248,146,0,152,30,2,0,120,89,3,0,1,0,0,0,237,248,146,0,232,10,2,0,40,246,1,0,1,0,0,0,169,1,147,0,64,246,1,0,144,236,1,0,1,0,0,0,207,240,146,0,136,224,1,0,176,223,1,0,1,0,0,0,202,240,146,0,72,198,1,0,192,209,1,0,1,0,0,0,203,240,146,0,24,182,1,0,24,198,1,0,1,0,0,0,200,240,146,0,40,167,1,0,120,189,1,0,1,0,0,0,201,240,146,0,200,149,1,0,224,22,1,0,1,0,0,0,204,240,146,0,56,126,1,0,160,14,1,0,1,0,0,0,205,240,146,0,32,101,1,0,88,212,3,0,1,0,0,0,40,221,146,0,40,185,3,0,16,17,8,0,1,0,0,0,172,1,147,0,224,12,8,0,72,65,1,0,9,0,0,0,240,6,147,0,32,58,1,0,48,50,1,0,9,0,0,0,241,6,147,0,32,58,1,0,224,41,1,0,9,0,0,0,242,6,147,0,32,58,1,0,184,40,2,0,1,0,0,0,47,39,216,0,248,191,2,0,56,250,6,0,1,0,0,0,39,39,216,0,184,160,2,0,184,164,8,0,1,0,0,0,46,39,216,0,64,246,1,0,88,149,7,0,1,0,0,0,38,39,216,0,136,224,1,0,240,167,7,0,1,0,0,0,28,39,216,0,192,135,2,0,176,163,7,0,1,0,0,0,30,39,216,0,240,108,2,0,208,158,7,0,1,0,0,0,45,39,216,0,96,82,2,0,184,154,7,0,1,0,0,0,44,39,216,0,32,56,2,0,176,108,2,0,1,0,0,0,43,39,216,0,152,30,2,0,8,96,7,0,1,0,0,0,40,39,216,0,72,198,1,0,48,89,7,0,1,0,0,0,24,39,216,0,24,182,1,0,16,83,7,0,1,0,0,0,37,39,216,0,40,167,1,0,96,79,7,0,1,0,0,0,36,39,216,0,200,149,1,0,48,76,7,0,1,0,0,0,35,39,216,0,56,126,1,0,88,212,3,0,1,0,0,0,48,38,216,0,40,185,3,0,248,5,8,0,9,0,0,0,112,39,216,0,32,58,1,0,144,250,7,0,9,0,0,0,113,39,216,0,32,58,1,0,248,241,7,0,9,0,0,0,114,39,216,0,32,58,1,0,184,40,2,0,1,0,0,0,208,155,215,0,248,191,2,0,56,250,6,0,1,0,0,0,212,155,215,0,184,160,2,0,184,164,8,0,1,0,0,0,209,155,215,0,64,246,1,0,88,149,7,0,1,0,0,0,213,155,215,0,136,224,1,0,104,28,8,0,1,0,0,0,187,155,215,0,232,209,1,0,248,23,7,0,1,0,0,0,215,155,215,0,144,189,1,0,56,210,6,0,1,0,0,0,205,155,215,0,192,135,2,0,24,163,6,0,1,0,0,0,204,155,215,0,240,108,2,0,152,122,6,0,1,0,0,0,207,155,215,0,96,82,2,0,192,72,6,0,1,0,0,0,206,155,215,0,32,56,2,0,48,123,2,0,1,0,0,0,200,155,215,0,152,30,2,0,96,69,2,0,1,0,0,0,201,155,215,0,232,10,2,0,144,55,2,0,1,0,0,0,202,155,215,0,152,138,8,0,176,223,1,0,1,0,0,0,197,155,215,0,72,198,1,0,192,209,1,0,1,0,0,0,196,155,215,0,24,182,1,0,24,198,1,0,1,0,0,0,199,155,215,0,40,167,1,0,120,189,1,0,1,0,0,0,198,155,215,0,200,149,1,0,248,187,8,0,1,0,0,0,192,155,215,0,56,126,1,0,184,179,8,0,1,0,0,0,193,155,215,0,32,101,1,0,240,173,8,0,1,0,0,0,194,155,215,0,96,32,8,0,192,122,8,0,1,0,0,0,189,155,215,0,208,174,1,0,40,116,8,0,1,0,0,0,188,155,215,0,48,160,1,0,72,110,8,0,1,0,0,0,191,155,215,0,160,140,1,0,184,102,8,0,1,0,0,0,190,155,215,0,56,112,1,0,240,45,8,0,1,0,0,0,184,155,215,0,32,92,1,0,40,38,8,0,1,0,0,0,185,155,215,0,64,77,1,0,48,32,8,0,1,0,0,0,186,155,215,0,112,157,4,0,16,17,8,0,1,0,0,0,211,155,215,0,224,12,8,0,32,77,1,0,1,0,0,0,210,155,215,0,216,70,1,0,88,212,3,0,1,0,0,0,200,154,215,0,40,185,3,0,248,5,8,0,9,0,0,0,0,156,215,0,32,58,1,0,144,250,7,0,9,0,0,0,1,156,215,0,32,58,1,0,168,86,7,0,1,0,0,0,67,238,146,0,248,191,2,0,24,38,7,0,1,0,0,0,69,238,146,0,184,160,2,0,56,210,6,0,1,0,0,0,144,251,146,0,192,135,2,0,24,163,6,0,1,0,0,0,145,251,146,0,240,108,2,0,152,122,6,0,1,0,0,0,146,251,146,0,96,82,2,0,192,72,6,0,1,0,0,0,147,251,146,0,32,56,2,0,200,110,3,0,1,0,0,0,148,251,146,0,152,30,2,0,120,89,3,0,1,0,0,0,149,251,146,0,232,10,2,0,120,74,3,0,1,0,0,0,150,251,146,0,152,138,8,0,40,246,1,0,1,0,0,0,68,238,146,0,64,246,1,0,144,236,1,0,1,0,0,0,70,238,146,0,136,224,1,0,176,223,1,0,1,0,0,0,96,243,146,0,72,198,1,0,192,209,1,0,1,0,0,0,97,243,146,0,24,182,1,0,24,198,1,0,1,0,0,0,98,243,146,0,40,167,1,0,120,189,1,0,1,0,0,0,99,243,146,0,200,149,1,0,224,22,1,0,1,0,0,0,100,243,146,0,56,126,1,0,160,14,1,0,1,0,0,0,101,243,146,0,32,101,1,0,176,9,1,0,1,0,0,0,102,243,146,0,96,32,8,0,88,212,3,0,1,0,0,0,72,216,146,0,40,185,3,0,16,17,8,0,1,0,0,0,64,238,146,0,224,12,8,0,56,58,1,0,1,0,0,0,65,238,146,0,64,50,1,0,72,65,1,0,9,0,0,0,192,3,147,0,32,58,1,0,48,50,1,0,9,0,0,0,193,3,147,0,32,58,1,0,224,41,1,0,9,0,0,0,194,3,147,0,32,58,1,0,168,86,7,0,1,0,0,0,248,236,146,0,248,191,2,0,24,38,7,0,1,0,0,0,47,245,146,0,184,160,2,0,240,251,8,0,4,0,0,0,232,7,147,0,152,210,1,0,176,223,8,0,4,0,0,0,236,7,147,0,208,189,1,0,200,110,3,0,1,0,0,0,120,253,146,0,248,174,1,0,120,89,3,0,1,0,0,0,121,253,146,0,104,160,1,0,120,74,3,0,1,0,0,0,14,239,146,0,152,138,8,0,192,61,3,0,1,0,0,0,46,245,146,0,48,119,7,0,88,212,3,0,1,0,0,0,168,217,146,0,40,185,3,0,16,17,8,0,1,0,0,0,250,236,146,0,224,12,8,0,72,65,1,0,9,0,0,0,38,224,146,0,32,58,1,0,48,50,1,0,9,0,0,0,39,224,146,0,32,58,1,0,184,40,2,0,1,0,0,0,168,148,215,0,248,191,2,0,56,250,6,0,1,0,0,0,191,148,215,0,184,160,2,0,184,164,8,0,1,0,0,0,169,148,215,0,64,246,1,0,88,149,7,0,1,0,0,0,183,148,215,0,136,224,1,0,56,210,6,0,1,0,0,0,184,148,215,0,192,135,2,0,24,163,6,0,1,0,0,0,185,148,215,0,240,108,2,0,152,122,6,0,1,0,0,0,186,148,215,0,96,82,2,0,192,72,6,0,1,0,0,0,187,148,215,0,32,56,2,0,48,123,2,0,1,0,0,0,188,148,215,0,152,30,2,0,96,69,2,0,1,0,0,0,189,148,215,0,232,10,2,0,176,223,1,0,1,0,0,0,176,148,215,0,72,198,1,0,192,209,1,0,1,0,0,0,177,148,215,0,24,182,1,0,24,198,1,0,1,0,0,0,178,148,215,0,40,167,1,0,120,189,1,0,1,0,0,0,179,148,215,0,200,149,1,0,248,187,8,0,1,0,0,0,180,148,215,0,56,126,1,0,184,179,8,0,1,0,0,0,181,148,215,0,32,101,1,0,88,212,3,0,1,0,0,0,200,147,215,0,40,185,3,0,16,17,8,0,1,0,0,0,172,148,215,0,224,12,8,0,0,105,5,0,1,0,0,0,173,148,215,0,192,99,5,0,152,120,4,0,1,0,0,0,174,148,215,0,96,118,4,0,56,58,1,0,1,0,0,0,175,148,215,0,64,50,1,0,248,5,8,0,9,0,0,0,96,149,215,0,32,58,1,0,144,250,7,0,9,0,0,0,97,149,215,0,32,58,1,0,168,86,7,0,1,0,0,0,152,252,146,0,248,191,2,0,56,210,6,0,1,0,0,0,156,252,146,0,192,135,2,0,24,163,6,0,1,0,0,0,157,252,146,0,240,108,2,0,152,122,6,0,1,0,0,0,158,252,146,0,96,82,2,0,192,72,6,0,1,0,0,0,159,252,146,0,32,56,2,0,200,110,3,0,1,0,0,0,153,252,146,0,152,30,2,0,120,89,3,0,1,0,0,0,154,252,146,0,232,10,2,0,120,74,3,0,1,0,0,0,155,252,146,0,152,138,8,0,176,223,1,0,1,0,0,0,164,252,146,0,72,198,1,0,192,209,1,0,1,0,0,0,165,252,146,0,24,182,1,0,24,198,1,0,1,0,0,0,166,252,146,0,40,167,1,0,120,189,1,0,1,0,0,0,167,252,146,0,200,149,1,0,224,22,1,0,1,0,0,0,161,252,146,0,56,126,1,0,160,14,1,0,1,0,0,0,162,252,146,0,32,101,1,0,176,9,1,0,1,0,0,0,163,252,146,0,96,32,8,0,88,212,3,0,1,0,0,0,16,217,146,0,40,185,3,0,72,65,1,0,9,0,0,0,56,4,147,0,32,58,1,0,168,86,7,0,1,0,0,0,152,243,146,0,248,191,2,0,24,38,7,0,1,0,0,0,215,251,146,0,184,160,2,0,56,210,6,0,1,0,0,0,208,251,146,0,192,135,2,0,24,163,6,0,1,0,0,0,209,251,146,0,240,108,2,0,152,122,6,0,1,0,0,0,210,251,146,0,96,82,2,0,192,72,6,0,1,0,0,0,211,251,146,0,32,56,2,0,200,110,3,0,1,0,0,0,212,251,146,0,152,30,2,0,120,89,3,0,1,0,0,0,213,251,146,0,232,10,2,0,40,246,1,0,1,0,0,0,153,243,146,0,64,246,1,0,144,236,1,0,1,0,0,0,223,251,146,0,136,224,1,0,176,223,1,0,1,0,0,0,216,251,146,0,72,198,1,0,192,209,1,0,1,0,0,0,217,251,146,0,24,182,1,0,24,198,1,0,1,0,0,0,218,251,146,0,40,167,1,0,120,189,1,0,1,0,0,0,219,251,146,0,200,149,1,0,224,22,1,0,1,0,0,0,220,251,146,0,56,126,1,0,160,14,1,0,1,0,0,0,221,251,146,0,32,101,1,0,88,212,3,0,1,0,0,0,136,216,146,0,40,185,3,0,72,65,1,0,9,0,0,0,40,94,147,0,32,58,1,0,48,50,1,0,9,0,0,0,41,94,147,0,32,58,1,0,184,40,2,0,1,0,0,0,47,39,216,0,248,191,2,0,184,164,8,0,1,0,0,0,46,39,216,0,64,246,1,0,208,158,7,0,1,0,0,0,16,39,216,0,96,82,2,0,184,154,7,0,1,0,0,0,17,39,216,0,32,56,2,0,176,108,2,0,1,0,0,0,41,39,216,0,152,30,2,0,128,98,2,0,1,0,0,0,42,39,216,0,232,10,2,0,48,82,2,0,1,0,0,0,40,39,216,0,152,138,8,0,88,212,3,0,1,0,0,0,48,38,216,0,40,185,3,0,248,5,8,0,9,0,0,0,112,39,216,0,32,58,1,0,144,250,7,0,9,0,0,0,113,39,216,0,32,58,1,0,248,241,7,0,9,0,0,0,114,39,216,0,32,58,1,0,184,40,2,0,1,0,0,0,138,151,215,0,248,191,2,0,56,250,6,0,1,0,0,0,140,151,215,0,184,160,2,0,184,164,8,0,1,0,0,0,139,151,215,0,64,246,1,0,88,149,7,0,1,0,0,0,141,151,215,0,136,224,1,0,56,210,6,0,1,0,0,0,128,151,215,0,192,135,2,0,24,163,6,0,1,0,0,0,129,151,215,0,240,108,2,0,152,122,6,0,1,0,0,0,130,151,215,0,96,82,2,0,192,72,6,0,1,0,0,0,131,151,215,0,32,56,2,0,48,123,2,0,1,0,0,0,124,151,215,0,152,30,2,0,96,69,2,0,1,0,0,0,125,151,215,0,232,10,2,0,176,223,1,0,1,0,0,0,132,151,215,0,72,198,1,0,192,209,1,0,1,0,0,0,133,151,215,0,24,182,1,0,24,198,1,0,1,0,0,0,134,151,215,0,40,167,1,0,120,189,1,0,1,0,0,0,135,151,215,0,200,149,1,0,248,187,8,0,1,0,0,0,126,151,215,0,56,126,1,0,184,179,8,0,1,0,0,0,127,151,215,0,32,101,1,0,88,212,3,0,1,0,0,0,200,147,215,0,40,185,3,0,16,17,8,0,1,0,0,0,136,151,215,0,224,12,8,0,56,58,1,0,1,0,0,0,137,151,215,0,64,50,1,0,72,4,1,0,1,0,0,0,123,151,215,0,64,255,0,0,248,5,8,0,9,0,0,0,152,151,215,0,32,58,1,0,144,250,7,0,9,0,0,0,153,151,215,0,32,58,1,0,100,98,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,254,52,107,158,1,0,16,1,100,98,57,46,112,114,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,99,69,22,87,1,0,16,1,100,98,49,48,112,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,123,197,41,193,1,0,16,1,100,98,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,245,101,76,234,1,0,16,1,100,98,56,46,112,114,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,244,31,4,253,1,0,16,1,100,98,54,112,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,1,238,220,53,1,0,16,1,100,98,55,46,112,114,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,94,31,91,103,1,0,16,1,100,98,53,46,112,114,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,204,158,101,117,1,0,16,1,100,98,51,46,112,114,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,16,151,154,158,4,0,32,0,100,98,49,97,112,46,112,114,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,205,100,185,76,4,0,32,0,100,98,52,46,112,114,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,51,223,210,217,4,0,32,0,100,98,50,46,112,114,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,245,106,10,10,4,0,32,0,109,105,45,55,54,48,51,45,53,46,105,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,47,249,49,241,7,0,32,0,109,105,45,55,54,48,51,45,53,46,105,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,71,76,165,226,0,0,0,8,184,40,2,0,1,0,0,0,41,39,216,0,248,191,2,0,56,250,6,0,1,0,0,0,43,39,216,0,184,160,2,0,184,164,8,0,1,0,0,0,40,39,216,0,64,246,1,0,88,149,7,0,1,0,0,0,42,39,216,0,136,224,1,0,240,167,7,0,1,0,0,0,37,39,216,0,192,135,2,0,176,163,7,0,1,0,0,0,36,39,216,0,240,108,2,0,208,158,7,0,1,0,0,0,35,39,216,0,96,82,2,0,184,154,7,0,1,0,0,0,34,39,216,0,32,56,2,0,176,108,2,0,1,0,0,0,32,39,216,0,152,30,2,0,128,98,2,0,1,0,0,0,33,39,216,0,232,10,2,0,48,82,2,0,1,0,0,0,47,39,216,0,152,138,8,0,88,212,3,0,1,0,0,0,48,38,216,0,40,185,3,0,248,5,8,0,9,0,0,0,112,39,216,0,32,58,1,0,144,250,7,0,9,0,0,0,113,39,216,0,32,58,1,0,248,241,7,0,9,0,0,0,114,39,216,0,32,58,1,0,168,86,7,0,1,0,0,0,207,0,147,0,248,191,2,0,24,38,7,0,1,0,0,0,205,0,147,0,184,160,2,0,136,89,2,0,4,0,0,0,136,133,215,0,208,13,4,0,32,61,2,0,1,0,0,0,8,227,146,0,152,138,8,0,200,110,3,0,1,0,0,0,55,248,146,0,152,30,2,0,120,89,3,0,1,0,0,0,201,0,147,0,232,10,2,0,136,251,1,0,4,0,0,0,128,133,215,0,136,7,4,0,72,229,1,0,4,0,0,0,120,133,215,0,136,113,1,0,40,246,1,0,1,0,0,0,206,0,147,0,64,246,1,0,144,236,1,0,1,0,0,0,204,0,147,0,136,224,1,0,224,22,1,0,1,0,0,0,54,248,146,0,56,126,1,0,160,14,1,0,1,0,0,0,200,0,147,0,32,101,1,0,88,212,3,0,1,0,0,0,16,220,146,0,40,185,3,0,16,17,8,0,1,0,0,0,202,0,147,0,224,12,8,0,72,65,1,0,9,0,0,0,56,6,147,0,32,58,1,0,48,50,1,0,9,0,0,0,57,6,147,0,32,58,1,0,224,41,1,0,9,0,0,0,58,6,147,0,32,58,1,0,168,169,1,0,9,0,0,0,59,6,147,0,32,58,1,0,40,238,4,0,9,0,0,0,60,6,147,0,32,58,1,0,168,86,7,0,1,0,0,0,232,47,216,0,248,191,2,0,24,38,7,0,1,0,0,0,236,47,216,0,184,160,2,0,152,255,2,0,1,0,0,0,36,48,216,0,152,30,2,0,224,233,2,0,1,0,0,0,37,48,216,0,232,10,2,0,32,210,2,0,1,0,0,0,38,48,216,0,152,138,8,0,216,191,2,0,1,0,0,0,39,48,216,0,48,119,7,0,40,246,1,0,1,0,0,0,233,47,216,0,64,246,1,0,144,236,1,0,1,0,0,0,237,47,216,0,136,224,1,0,48,238,8,0,1,0,0,0,44,48,216,0,56,126,1,0,224,230,8,0,1,0,0,0,45,48,216,0,32,101,1,0,96,222,8,0,1,0,0,0,46,48,216,0,96,32,8,0,56,214,8,0,1,0,0,0,47,48,216,0,16,68,7,0,88,212,3,0,1,0,0,0,144,46,216,0,40,185,3,0,240,152,1,0,1,0,0,0,238,47,216,0,216,70,1,0,16,17,8,0,1,0,0,0,234,47,216,0,224,12,8,0,72,65,1,0,9,0,0,0,232,48,216,0,32,58,1,0,48,50,1,0,9,0,0,0,224,48,216,0,32,58,1,0,224,41,1,0,9,0,0,0,216,48,216,0,32,58,1,0,168,86,7,0,1,0,0,0,208,253,146,0,248,191,2,0,24,38,7,0,1,0,0,0,211,253,146,0,184,160,2,0,56,210,6,0,1,0,0,0,200,253,146,0,192,135,2,0,24,163,6,0,1,0,0,0,201,253,146,0,240,108,2,0,152,122,6,0,1,0,0,0,202,253,146,0,96,82,2,0,192,72,6,0,1,0,0,0,203,253,146,0,32,56,2,0,200,110,3,0,1,0,0,0,204,253,146,0,152,30,2,0,120,89,3,0,1,0,0,0,205,253,146,0,232,10,2,0,120,74,3,0,1,0,0,0,206,253,146,0,152,138,8,0,40,246,1,0,1,0,0,0,209,253,146,0,64,246,1,0,144,236,1,0,1,0,0,0,212,253,146,0,136,224,1,0,176,223,1,0,1,0,0,0,120,245,146,0,72,198,1,0,192,209,1,0,1,0,0,0,121,245,146,0,24,182,1,0,24,198,1,0,1,0,0,0,122,245,146,0,40,167,1,0,120,189,1,0,1,0,0,0,123,245,146,0,200,149,1,0,224,22,1,0,1,0,0,0,124,245,146,0,56,126,1,0,160,14,1,0,1,0,0,0,125,245,146,0,32,101,1,0,176,9,1,0,1,0,0,0,126,245,146,0,96,32,8,0,168,132,8,0,1,0,0,0,210,253,146,0,232,209,1,0,72,126,8,0,1,0,0,0,47,239,146,0,144,189,1,0,192,122,8,0,1,0,0,0,40,239,146,0,208,174,1,0,40,116,8,0,1,0,0,0,41,239,146,0,48,160,1,0,72,110,8,0,1,0,0,0,42,239,146,0,160,140,1,0,184,102,8,0,1,0,0,0,43,239,146,0,56,112,1,0,248,67,8,0,1,0,0,0,44,239,146,0,32,92,1,0,136,64,8,0,1,0,0,0,45,239,146,0,64,77,1,0,128,58,8,0,1,0,0,0,46,239,146,0,112,157,4,0,88,212,3,0,1,0,0,0,216,217,146,0,40,185,3,0,16,17,8,0,1,0,0,0,215,253,146,0,224,12,8,0,56,58,1,0,1,0,0,0,214,253,146,0,64,50,1,0,72,65,1,0,9,0,0,0,184,4,147,0,32,58,1,0,48,50,1,0,9,0,0,0,185,4,147,0,32,58,1,0,224,41,1,0,9,0,0,0,186,4,147,0,32,58,1,0,48,45,3,0,9,0,0,0,187,4,147,0,32,58,1,0,168,86,7,0,1,0,0,0,208,246,146,0,248,191,2,0,24,38,7,0,1,0,0,0,55,255,146,0,184,160,2,0,56,210,6,0,1,0,0,0,48,255,146,0,192,135,2,0,24,163,6,0,1,0,0,0,49,255,146,0,240,108,2,0,152,122,6,0,1,0,0,0,50,255,146,0,96,82,2,0,192,72,6,0,1,0,0,0,51,255,146,0,32,56,2,0,200,110,3,0,1,0,0,0,52,255,146,0,152,30,2,0,120,89,3,0,1,0,0,0,53,255,146,0,232,10,2,0,40,246,1,0,1,0,0,0,209,246,146,0,64,246,1,0,144,236,1,0,1,0,0,0,63,255,146,0,136,224,1,0,176,223,1,0,1,0,0,0,56,255,146,0,72,198,1,0,192,209,1,0,1,0,0,0,57,255,146,0,24,182,1,0,24,198,1,0,1,0,0,0,58,255,146,0,40,167,1,0,120,189,1,0,1,0,0,0,59,255,146,0,200,149,1,0,224,22,1,0,1,0,0,0,60,255,146,0,56,126,1,0,160,14,1,0,1,0,0,0,61,255,146,0,32,101,1,0,88,212,3,0,1,0,0,0,216,218,146,0,40,185,3,0,72,65,1,0,9,0,0,0,80,5,147,0,32,58,1,0,48,50,1,0,9,0,0,0,81,5,147,0,32,58,1,0,168,86,7,0,1,0,0,0,144,236,146,0,248,191,2,0,24,38,7,0,1,0,0,0,159,1,147,0,184,160,2,0,56,210,6,0,1,0,0,0,154,1,147,0,192,135,2,0,24,163,6,0,1,0,0,0,155,1,147,0,240,108,2,0,152,122,6,0,1,0,0,0,152,1,147,0,96,82,2,0,192,72,6,0,1,0,0,0,153,1,147,0,32,56,2,0,200,110,3,0,1,0,0,0,156,1,147,0,152,30,2,0,120,89,3,0,1,0,0,0,157,1,147,0,232,10,2,0,120,74,3,0,1,0,0,0,158,1,147,0,152,138,8,0,40,246,1,0,1,0,0,0,145,236,146,0,64,246,1,0,144,236,1,0,1,0,0,0,223,248,146,0,136,224,1,0,176,223,1,0,1,0,0,0,218,248,146,0,72,198,1,0,192,209,1,0,1,0,0,0,219,248,146,0,24,182,1,0,24,198,1,0,1,0,0,0,216,248,146,0,40,167,1,0,120,189,1,0,1,0,0,0,217,248,146,0,200,149,1,0,224,22,1,0,1,0,0,0,220,248,146,0,56,126,1,0,160,14,1,0,1,0,0,0,221,248,146,0,32,101,1,0,176,9,1,0,1,0,0,0,222,248,146,0,96,32,8,0,88,212,3,0,1,0,0,0,24,221,146,0,40,185,3,0,56,122,5,0,1,0,0,0,148,236,146,0,224,12,8,0,0,105,5,0,1,0,0,0,149,236,146,0,128,176,7,0,72,65,1,0,9,0,0,0,224,6,147,0,32,58,1,0,48,50,1,0,9,0,0,0,225,6,147,0,32,58,1,0,224,41,1,0,9,0,0,0,226,6,147,0,32,58,1,0,168,86,7,0,1,0,0,0,144,236,146,0,248,191,2,0,56,210,6,0,1,0,0,0,154,1,147,0,192,135,2,0,24,163,6,0,1,0,0,0,155,1,147,0,240,108,2,0,152,122,6,0,1,0,0,0,152,1,147,0,96,82,2,0,192,72,6,0,1,0,0,0,153,1,147,0,32,56,2,0,200,110,3,0,1,0,0,0,156,1,147,0,152,30,2,0,120,89,3,0,1,0,0,0,157,1,147,0,232,10,2,0,40,246,1,0,1,0,0,0,145,236,146,0,64,246,1,0,176,223,1,0,1,0,0,0,218,248,146,0,72,198,1,0,192,209,1,0,1,0,0,0,219,248,146,0,24,182,1,0,24,198,1,0,1,0,0,0,216,248,146,0,40,167,1,0,120,189,1,0,1,0,0,0,217,248,146,0,200,149,1,0,224,22,1,0,1,0,0,0,220,248,146,0,56,126,1,0,160,14,1,0,1,0,0,0,221,248,146,0,32,101,1,0,168,132,8,0,1,0,0,0,146,236,146,0,232,209,1,0,192,122,8,0,1,0,0,0,186,240,146,0,208,174,1,0,40,116,8,0,1,0,0,0,187,240,146,0,48,160,1,0,72,110,8,0,1,0,0,0,184,240,146,0,160,140,1,0,184,102,8,0,1,0,0,0,185,240,146,0,56,112,1,0,248,67,8,0,1,0,0,0,188,240,146,0,32,92,1,0,136,64,8,0,1,0,0,0,189,240,146,0,64,77,1,0])
.concat([232,23,8,0,1,0,0,0,147,236,146,0,104,195,5,0,248,16,8,0,1,0,0,0,130,237,146,0,32,231,8,0,192,12,8,0,1,0,0,0,131,237,146,0,88,214,8,0,224,5,8,0,1,0,0,0,128,237,146,0,224,202,8,0,144,1,8,0,1,0,0,0,129,237,146,0,72,193,8,0,176,222,7,0,1,0,0,0,132,237,146,0,144,180,8,0,176,218,7,0,1,0,0,0,133,237,146,0,208,164,8,0,88,212,3,0,1,0,0,0,24,221,146,0,40,185,3,0,56,122,5,0,1,0,0,0,148,236,146,0,224,12,8,0,0,105,5,0,1,0,0,0,149,236,146,0,128,176,7,0,152,120,4,0,1,0,0,0,150,236,146,0,248,114,7,0,112,109,5,0,1,0,0,0,151,236,146,0,32,105,5,0,72,65,1,0,9,0,0,0,224,6,147,0,32,58,1,0,48,50,1,0,9,0,0,0,225,6,147,0,32,58,1,0,224,41,1,0,9,0,0,0,226,6,147,0,32,58,1,0,168,86,7,0,1,0,0,0,216,254,146,0,248,191,2,0,208,157,4,0,1,0,0,0,120,246,146,0,152,30,2,0,248,152,4,0,1,0,0,0,121,246,146,0,232,10,2,0,152,148,4,0,1,0,0,0,122,246,146,0,152,138,8,0,128,142,4,0,1,0,0,0,123,246,146,0,48,119,7,0,136,134,4,0,1,0,0,0,124,246,146,0,112,109,7,0,200,127,4,0,1,0,0,0,125,246,146,0,24,133,7,0,88,212,3,0,1,0,0,0,160,218,146,0,40,185,3,0,16,17,8,0,1,0,0,0,127,246,146,0,224,12,8,0,72,65,1,0,9,0,0,0,48,5,147,0,32,58,1,0,48,50,1,0,9,0,0,0,49,5,147,0,32,58,1,0,98,51,51,45,51,52,46,105,99,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,193,22,224,225,2,0,16,1,98,51,51,45,51,51,46,105,99,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,75,212,57,245,2,0,16,1,98,51,51,45,50,49,45,50,46,105,99,51,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,227,249,35,39,6,0,16,1,98,51,51,45,51,49,45,49,46,105,99,51,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,247,49,132,67,6,0,16,1,98,51,51,45,51,48,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,52,98,116,216,9,0,16,1,98,51,51,45,48,50,46,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,162,59,251,246,11,0,32,0,98,51,51,45,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,153,5,180,44,17,0,32,0,98,51,51,45,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,234,158,223,189,17,0,32,0,98,51,51,45,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,162,102,248,141,17,0,32,0,98,51,51,45,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,217,54,108,79,17,0,32,0,98,51,51,45,48,49,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,232,43,31,241,22,0,32,0,98,51,51,45,48,55,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,31,30,21,23,0,32,0,98,51,51,45,48,57,46,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,36,103,30,24,0,64,0,98,51,51,45,49,48,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,171,3,206,233,24,0,64,0,98,51,51,45,48,56,46,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,200,196,161,202,25,0,64,0,98,49,52,45,51,48,46,57,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,127,12,203,220,0,0,0,8,98,49,52,45,51,49,46,53,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,61,1,107,92,0,0,0,8,98,51,51,45,49,55,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,244,143,125,123,0,0,0,8,98,51,51,45,49,56,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,48,31,248,251,0,0,0,8,184,40,2,0,1,0,0,0,139,151,215,0,248,191,2,0,56,250,6,0,1,0,0,0,131,151,215,0,184,160,2,0,184,164,8,0,1,0,0,0,138,151,215,0,64,246,1,0,240,190,7,0,4,0,0,0,104,150,215,0,208,13,4,0,32,201,5,0,1,0,0,0,135,151,215,0,152,30,2,0,208,240,5,0,1,0,0,0,143,151,215,0,232,10,2,0,32,160,5,0,1,0,0,0,132,151,215,0,152,138,8,0,216,240,6,0,1,0,0,0,133,151,215,0,48,119,7,0,200,238,6,0,1,0,0,0,134,151,215,0,112,109,7,0,144,235,6,0,1,0,0,0,141,151,215,0,24,133,7,0,120,231,6,0,1,0,0,0,142,151,215,0,72,120,6,0,88,212,3,0,1,0,0,0,200,147,215,0,40,185,3,0,16,17,8,0,1,0,0,0,140,151,215,0,224,12,8,0,56,58,1,0,1,0,0,0,130,151,215,0,64,50,1,0,248,5,8,0,9,0,0,0,152,151,215,0,32,58,1,0,144,250,7,0,9,0,0,0,153,151,215,0,32,58,1,0,168,86,7,0,1,0,0,0,0,238,146,0,248,191,2,0,24,38,7,0,1,0,0,0,143,250,146,0,184,160,2,0,56,210,6,0,1,0,0,0,136,250,146,0,192,135,2,0,24,163,6,0,1,0,0,0,137,250,146,0,240,108,2,0,152,122,6,0,1,0,0,0,138,250,146,0,96,82,2,0,192,72,6,0,1,0,0,0,139,250,146,0,32,56,2,0,200,110,3,0,1,0,0,0,140,250,146,0,152,30,2,0,120,89,3,0,1,0,0,0,141,250,146,0,232,10,2,0,40,246,1,0,1,0,0,0,1,238,146,0,64,246,1,0,144,236,1,0,1,0,0,0,103,242,146,0,136,224,1,0,176,223,1,0,1,0,0,0,96,242,146,0,72,198,1,0,192,209,1,0,1,0,0,0,97,242,146,0,24,182,1,0,24,198,1,0,1,0,0,0,98,242,146,0,40,167,1,0,120,189,1,0,1,0,0,0,99,242,146,0,200,149,1,0,224,22,1,0,1,0,0,0,100,242,146,0,56,126,1,0,160,14,1,0,1,0,0,0,101,242,146,0,32,101,1,0,88,212,3,0,1,0,0,0,104,215,146,0,40,185,3,0,72,65,1,0,9,0,0,0,112,3,147,0,32,58,1,0,48,50,1,0,9,0,0,0,113,3,147,0,32,58,1,0,184,40,2,0,1,0,0,0,41,39,216,0,248,191,2,0,224,158,1,0,1,0,0,0,32,39,216,0,184,160,2,0,184,164,8,0,1,0,0,0,40,39,216,0,64,246,1,0,64,158,1,0,1,0,0,0,33,39,216,0,136,224,1,0,240,167,7,0,1,0,0,0,47,39,216,0,192,135,2,0,176,163,7,0,1,0,0,0,45,39,216,0,240,108,2,0,208,158,7,0,1,0,0,0,42,39,216,0,96,82,2,0,184,154,7,0,1,0,0,0,43,39,216,0,32,56,2,0,8,96,7,0,1,0,0,0,46,39,216,0,72,198,1,0,48,89,7,0,1,0,0,0,37,39,216,0,24,182,1,0,16,83,7,0,1,0,0,0,34,39,216,0,40,167,1,0,96,79,7,0,1,0,0,0,35,39,216,0,200,149,1,0,48,76,7,0,1,0,0,0,36,39,216,0,56,126,1,0,144,72,7,0,1,0,0,0,44,39,216,0,32,101,1,0,88,212,3,0,1,0,0,0,48,38,216,0,40,185,3,0,248,5,8,0,9,0,0,0,112,39,216,0,32,58,1,0,144,250,7,0,9,0,0,0,113,39,216,0,32,58,1,0,248,241,7,0,9,0,0,0,114,39,216,0,32,58,1,0,168,86,7,0,1,0,0,0,242,251,146,0,248,191,2,0,24,38,7,0,1,0,0,0,244,251,146,0,184,160,2,0,56,210,6,0,1,0,0,0,187,243,146,0,192,135,2,0,24,163,6,0,1,0,0,0,186,243,146,0,240,108,2,0,152,122,6,0,1,0,0,0,184,243,146,0,96,82,2,0,192,72,6,0,1,0,0,0,185,243,146,0,32,56,2,0,200,110,3,0,1,0,0,0,188,243,146,0,152,30,2,0,120,89,3,0,1,0,0,0,189,243,146,0,232,10,2,0,40,246,1,0,1,0,0,0,243,251,146,0,64,246,1,0,144,236,1,0,1,0,0,0,245,251,146,0,136,224,1,0,176,223,1,0,1,0,0,0,99,238,146,0,72,198,1,0,192,209,1,0,1,0,0,0,98,238,146,0,24,182,1,0,24,198,1,0,1,0,0,0,96,238,146,0,40,167,1,0,120,189,1,0,1,0,0,0,97,238,146,0,200,149,1,0,224,22,1,0,1,0,0,0,100,238,146,0,56,126,1,0,160,14,1,0,1,0,0,0,101,238,146,0,32,101,1,0,88,212,3,0,1,0,0,0,152,216,146,0,40,185,3,0,16,17,8,0,1,0,0,0,246,251,146,0,224,12,8,0,56,58,1,0,1,0,0,0,247,251,146,0,64,50,1,0,72,65,1,0,9,0,0,0,240,3,147,0,32,58,1,0,48,50,1,0,9,0,0,0,241,3,147,0,32,58,1,0,224,41,1,0,9,0,0,0,242,3,147,0,32,58,1,0,168,86,7,0,1,0,0,0,250,255,146,0,248,191,2,0,24,38,7,0,1,0,0,0,248,255,146,0,184,160,2,0,120,138,2,0,1,0,0,0,240,255,146,0,192,135,2,0,56,136,2,0,1,0,0,0,241,255,146,0,240,108,2,0,32,135,2,0,1,0,0,0,242,255,146,0,96,82,2,0,152,134,2,0,1,0,0,0,243,255,146,0,32,56,2,0,192,133,2,0,1,0,0,0,244,255,146,0,208,174,1,0,96,132,2,0,1,0,0,0,245,255,146,0,48,160,1,0,200,130,2,0,1,0,0,0,246,255,146,0,160,140,1,0,32,127,2,0,1,0,0,0,247,255,146,0,56,112,1,0,40,246,1,0,1,0,0,0,251,255,146,0,64,246,1,0,144,236,1,0,1,0,0,0,249,255,146,0,136,224,1,0,208,122,2,0,1,0,0,0,88,247,146,0,72,198,1,0,48,122,2,0,1,0,0,0,89,247,146,0,24,182,1,0,112,121,2,0,1,0,0,0,90,247,146,0,40,167,1,0,208,120,2,0,1,0,0,0,91,247,146,0,200,149,1,0,24,120,2,0,1,0,0,0,92,247,146,0,32,231,8,0,152,116,2,0,1,0,0,0,93,247,146,0,88,214,8,0,128,112,2,0,1,0,0,0,94,247,146,0,224,202,8,0,40,108,2,0,1,0,0,0,95,247,146,0,72,193,8,0,88,212,3,0,1,0,0,0,56,219,146,0,40,185,3,0,16,17,8,0,1,0,0,0,96,247,146,0,224,12,8,0,56,58,1,0,1,0,0,0,98,247,146,0,64,50,1,0,72,65,1,0,9,0,0,0,144,5,147,0,32,58,1,0,48,50,1,0,9,0,0,0,145,5,147,0,32,58,1,0,99,99,101,95,50,51,100,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,206,142,197,25,2,0,16,1,99,99,95,50,50,100,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,183,73,25,169,2,0,16,1,99,99,95,50,52,100,46,57,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,84,14,104,1,0,16,1,99,99,95,50,56,100,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,159,3,32,136,1,0,16,1,99,99,45,53,109,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,186,216,97,114,4,0,32,0,99,99,45,55,109,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,73,249,96,106,4,0,32,0,99,99,45,49,109,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,2,115,99,0,4,0,32,0,99,99,45,51,109,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,207,135,204,4,0,32,0,99,99,45,54,109,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,237,139,113,40,4,0,32,0,99,99,45,56,109,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,58,197,172,212,4,0,32,0,99,99,45,50,109,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,81,241,105,12,4,0,32,0,99,99,45,52,109,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,151,187,158,31,4,0,32,0,99,99,95,48,57,46,49,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,88,139,142,105,3,0,16,0,99,99,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,219,194,226,109,5,0,64,0,99,99,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,174,145,144,185,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,99,99,54,51,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,249,240,232,202,0,0,0,8,105,111,98,49,46,49,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,99,99,112,114,103,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,196,37,194,225,0,0,0,8,105,111,99,49,46,105,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,129,32,24,13,0,0,0,8,99,54,51,50,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,112,146,189,15,0,0,0,8,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,40,237,166,195,1,0,16,1,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,53,147,114,40,1,0,16,1,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,115,109,82,27,1,0,16,1,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,9,151,201,115,1,0,16,1,99,97,112,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,186,216,97,114,4,0,32,0,99,98,112,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,73,249,96,106,4,0,32,0,99,99,112,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,2,115,99,0,4,0,32,0,99,100,112,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,207,135,204,4,0,32,0,99,97,105,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,237,139,113,40,4,0,32,0,99,98,105,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,58,197,172,212,4,0,32,0,99,99,105,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,81,241,105,12,4,0,32,0,99,100,105,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,151,187,158,31,4,0,32,0,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,189,244,210,174,3,0,16,0,168,86,7,0,1,0,0,0,232,47,216,0,248,191,2,0,24,38,7,0,1,0,0,0,236,47,216,0,184,160,2,0,56,210,6,0,1,0,0,0,35,48,216,0,192,135,2,0,24,163,6,0,1,0,0,0,34,48,216,0,240,108,2,0,152,122,6,0,1,0,0,0,33,48,216,0,96,82,2,0,192,72,6,0,1,0,0,0,32,48,216,0,32,56,2,0,152,31,6,0,1,0,0,0,36,48,216,0,152,30,2,0,248,97,5,0,1,0,0,0,37,48,216,0,232,10,2,0,40,246,1,0,1,0,0,0,233,47,216,0,64,246,1,0,144,236,1,0,1,0,0,0,237,47,216,0,136,224,1,0,176,223,1,0,1,0,0,0,43,48,216,0,72,198,1,0,192,209,1,0,1,0,0,0,42,48,216,0,24,182,1,0,24,198,1,0,1,0,0,0,41,48,216,0,40,167,1,0,120,189,1,0,1,0,0,0,40,48,216,0,200,149,1,0,8,182,1,0,1,0,0,0,44,48,216,0,56,126,1,0,32,167,1,0,1,0,0,0,45,48,216,0,32,101,1,0,168,132,8,0,1,0,0,0,166,47,216,0,232,209,1,0,72,126,8,0,1,0,0,0,167,47,216,0,144,189,1,0,192,122,8,0,1,0,0,0,163,47,216,0,208,174,1,0,40,116,8,0,1,0,0,0,162,47,216,0,48,160,1,0,72,110,8,0,1,0,0,0,161,47,216,0,160,140,1,0,184,102,8,0,1,0,0,0,160,47,216,0,56,112,1,0,248,93,8,0,1,0,0,0,164,47,216,0,32,92,1,0,152,86,8,0,1,0,0,0,165,47,216,0,64,77,1,0,232,23,8,0,1,0,0,0,158,47,216,0,104,195,5,0,160,19,8,0,1,0,0,0,159,47,216,0,32,245,8,0,248,16,8,0,1,0,0,0,155,47,216,0,32,231,8,0,192,12,8,0,1,0,0,0,154,47,216,0,88,214,8,0,224,5,8,0,1,0,0,0,153,47,216,0,224,202,8,0,144,1,8,0,1,0,0,0,152,47,216,0,72,193,8,0,96,250,7,0,1,0,0,0,156,47,216,0,144,180,8,0,120,241,7,0,1,0,0,0,157,47,216,0,208,164,8,0,88,212,3,0,1,0,0,0,144,46,216,0,40,185,3,0,240,152,1,0,1,0,0,0,238,47,216,0,216,70,1,0,16,17,8,0,1,0,0,0,234,47,216,0,224,12,8,0,72,65,1,0,9,0,0,0,232,48,216,0,32,58,1,0,48,50,1,0,9,0,0,0,224,48,216,0,32,58,1,0,224,41,1,0,9,0,0,0,216,48,216,0,32,58,1,0,99,51,56,45,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,160,45,23,190,2,0,16,1,99,51,56,45,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,222,48,164,255,2,0,16,1,99,51,56,45,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,172,250,96,14,9,0,16,1,99,51,56,45,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,54,255,112,193,15,0,32,0,99,51,56,45,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,75,113,17,26,28,0,32,0,99,51,56,45,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,187,48,211,83,29,0,64,0,184,40,2,0,1,0,0,0,122,151,215,0,248,191,2,0,56,250,6,0,1,0,0,0,143,151,215,0,184,160,2,0,184,164,8,0,1,0,0,0,123,151,215,0,64,246,1,0,88,149,7,0,1,0,0,0,135,151,215,0,136,224,1,0,8,16,4,0,4,0,0,0,104,150,215,0,208,13,4,0,48,123,2,0,1,0,0,0,140,151,215,0,152,30,2,0,200,11,4,0,4,0,0,0,96,150,215,0,136,7,4,0,248,187,8,0,1,0,0,0,132,151,215,0,56,126,1,0,88,212,3,0,1,0,0,0,200,147,215,0,40,185,3,0,16,17,8,0,1,0,0,0,121,151,215,0,224,12,8,0,56,58,1,0,1,0,0,0,120,151,215,0,64,50,1,0,248,5,8,0,9,0,0,0,152,151,215,0,32,58,1,0,144,250,7,0,9,0,0,0,153,151,215,0,32,58,1,0,168,86,7,0,1,0,0,0,143,239,146,0,248,191,2,0,24,38,7,0,1,0,0,0,223,254,146,0,184,160,2,0,56,210,6,0,1,0,0,0,216,254,146,0,192,135,2,0,24,163,6,0,1,0,0,0,217,254,146,0,240,108,2,0,152,122,6,0,1,0,0,0,218,254,146,0,96,82,2,0,192,72,6,0,1,0,0,0,219,254,146,0,32,56,2,0,200,110,3,0,1,0,0,0,220,254,146,0,152,30,2,0,120,89,3,0,1,0,0,0,221,254,146,0,232,10,2,0,120,74,3,0,1,0,0,0,222,254,146,0,152,138,8,0,40,246,1,0,1,0,0,0,142,239,146,0,64,246,1,0,144,236,1,0,1,0,0,0,127,246,146,0,136,224,1,0,176,223,1,0,1,0,0,0,120,246,146,0,72,198,1,0,192,209,1,0,1,0,0,0,121,246,146,0,24,182,1,0,24,198,1,0,1,0,0,0,122,246,146,0,40,167,1,0,120,189,1,0,1,0,0,0,123,246,146,0,200,149,1,0,224,22,1,0,1,0,0,0,124,246,146,0,56,126,1,0,160,14,1,0,1,0,0,0,125,246,146,0,32,101,1,0,176,9,1,0,1,0,0,0,126,246,146,0,96,32,8,0,88,212,3,0,1,0,0,0,160,218,146,0,40,185,3,0,16,17,8,0,1,0,0,0,141,239,146,0,224,12,8,0,56,58,1,0,1,0,0,0,140,239,146,0,64,50,1,0,72,65,1,0,9,0,0,0,48,5,147,0,32,58,1,0])
.concat([48,50,1,0,9,0,0,0,49,5,147,0,32,58,1,0,224,41,1,0,9,0,0,0,50,5,147,0,32,58,1,0,1,2,3,4,5,6,7,8,6,5,1,8,5,5,6,8,7,6,6,5,8,7,10,0,4,7,5,8,6,8,3,0,5,8,4,8,8,7,0,0,10,11,10,10,16,16,0,0,7,7,7,8,5,8,7,11,3,5,7,7,8,8,1,0,3,5,1,2,4,4,0,0,3,3,3,3,12,12,10,7,10,10,8,8,8,8,0,0,16,0,38,0,60,0,82,0,104,0,126,0,148,0,170,0,1,8,3,26,73,8,3,26,133,8,199,24,195,90,183,110,0,5,0,1,255,255,193,24,195,24,9,25,3,26,69,9,199,24,195,90,183,110,0,5,0,1,255,255,129,25,69,57,201,25,67,57,5,10,199,24,195,90,183,110,0,5,0,1,255,255,65,26,69,24,137,26,67,24,197,10,199,24,195,90,183,110,0,5,0,0,255,255,1,27,197,24,73,27,195,24,133,11,199,24,195,90,183,110,0,5,0,1,255,255,193,19,71,57,9,20,69,57,69,12,199,24,195,90,183,110,0,5,0,1,255,255,129,28,69,25,201,28,67,25,5,13,199,24,195,90,183,110,0,5,0,1,255,255,65,13,197,24,137,13,195,24,197,13,199,24,195,90,183,110,0,5,0,1,255,255,16,0,38,0,60,0,82,0,104,0,126,0,148,0,170,0,1,8,67,73,73,8,67,73,133,8,199,24,195,90,183,110,104,1,0,1,255,255,193,0,67,57,9,1,67,73,69,1,199,24,195,90,183,110,104,1,0,1,255,255,129,9,195,89,201,9,195,89,5,10,199,24,195,90,183,110,104,1,0,1,255,255,65,50,195,91,137,50,195,91,197,10,199,24,195,90,183,110,104,1,0,0,255,255,1,3,195,73,73,3,195,73,133,11,199,24,195,90,183,110,104,1,0,1,255,255,193,11,195,25,9,12,195,25,69,12,199,24,195,90,183,110,104,1,0,1,255,255,129,20,197,57,201,20,195,57,5,13,199,24,195,90,183,110,104,1,0,1,255,255,65,13,199,57,137,13,197,57,197,13,199,24,195,90,183,110,104,1,0,1,255,255,14,0,36,0,58,0,80,0,102,0,124,0,146,0,1,24,197,65,73,24,195,65,133,8,199,24,195,90,183,110,224,1,0,1,255,255,193,8,197,65,9,9,195,65,69,9,199,24,195,90,183,110,224,1,0,1,255,255,129,9,69,74,201,9,67,74,5,10,199,24,195,90,183,110,224,1,0,1,255,255,65,26,197,57,129,26,195,57,197,10,199,24,195,90,183,110,224,1,0,0,255,255,1,11,69,90,73,11,67,90,133,11,199,24,195,90,183,110,224,1,0,1,255,255,193,3,197,89,9,4,195,89,69,12,199,24,195,90,183,110,224,1,0,1,255,255,128,12,69,41,200,12,67,41,4,13,199,24,195,90,183,110,224,1,0,1,255,255,14,0,36,0,58,0,80,0,102,0,124,0,146,0,1,24,69,57,73,24,67,57,133,8,199,24,195,90,183,110,104,1,0,1,255,255,193,24,69,57,9,25,67,57,69,9,199,24,195,90,183,110,104,1,0,1,255,255,129,25,69,57,201,25,67,57,5,10,199,24,195,90,183,110,104,1,0,1,255,255,65,10,199,57,137,10,197,57,197,10,199,24,195,90,183,110,104,1,0,0,255,255,1,11,5,66,73,11,3,66,133,11,199,24,195,90,183,110,104,1,0,1,255,255,193,11,197,57,9,12,195,57,69,12,199,24,195,90,183,110,104,1,0,1,255,255,129,12,77,10,201,12,75,10,5,13,199,24,195,90,183,110,104,1,0,1,255,255,12,0,34,0,56,0,78,0,100,0,122,0,1,24,67,57,73,24,67,57,133,8,199,24,195,90,183,110,104,1,0,1,255,255,193,24,195,57,9,25,195,57,69,9,195,24,195,90,183,110,104,1,0,1,255,255,129,25,67,57,201,25,67,57,5,10,199,24,195,90,183,110,104,1,0,1,255,255,65,10,67,25,137,10,67,25,197,10,71,25,195,90,183,110,104,1,0,0,255,255,1,43,195,25,73,43,194,25,133,11,199,24,195,90,183,110,104,1,0,1,255,255,193,11,195,24,9,12,195,24,69,12,199,24,195,90,183,110,104,1,0,1,255,255,12,0,34,0,56,0,78,0,100,0,122,0,0,56,198,24,72,56,198,24,132,8,199,24,195,90,183,110,104,1,0,1,255,255,192,152,201,24,8,153,201,24,68,9,199,24,195,90,183,110,104,1,0,1,255,255,128,89,201,24,200,89,201,24,4,10,199,24,195,90,183,110,104,1,0,1,255,255,64,58,196,24,136,58,196,24,196,10,199,24,195,90,183,110,104,1,0,1,255,255,0,3,128,24,72,3,128,24,132,11,199,24,195,90,183,110,104,1,0,1,255,255,192,91,133,49,8,92,133,49,68,12,199,24,195,90,183,110,104,1,0,1,255,255,16,0,38,0,60,0,82,0,104,0,126,0,148,0,170,0,1,8,193,57,73,8,193,57,132,8,199,24,195,90,183,110,104,1,0,1,255,255,193,8,193,57,9,9,193,57,68,9,199,24,195,90,183,110,104,1,0,1,255,255,129,1,64,57,201,1,64,57,4,10,199,24,195,90,183,110,104,1,0,1,255,255,65,10,195,57,137,10,195,57,196,10,199,24,195,90,183,110,104,1,0,1,255,255,1,3,64,25,73,3,64,25,132,11,199,24,195,90,183,110,104,1,0,1,255,255,193,11,211,73,9,12,201,73,68,12,199,24,195,90,183,110,120,0,0,1,255,255,129,36,199,27,201,36,199,27,4,13,199,24,195,90,183,110,104,1,0,1,255,255,64,101,65,41,136,101,64,41,196,13,199,24,195,90,183,110,104,1,0,1,255,255,14,0,36,0,58,0,80,0,102,0,124,0,146,0,1,24,199,57,73,24,197,57,132,8,199,24,195,90,183,110,224,1,0,1,255,255,193,8,199,57,9,9,197,57,68,9,199,24,195,90,183,110,224,1,0,1,255,255,129,9,71,73,201,9,69,73,4,10,199,24,195,90,183,110,224,1,0,1,255,255,65,2,199,73,137,2,197,73,196,10,199,24,195,90,183,110,224,1,0,1,255,255,1,3,67,41,73,3,66,41,132,11,199,24,195,90,183,110,224,1,0,1,255,255,193,27,67,41,9,28,66,41,68,12,199,24,195,90,183,110,224,1,0,1,255,255,129,12,67,57,201,12,65,57,4,13,199,24,195,90,183,110,224,1,0,1,255,255,12,0,34,0,56,0,78,0,100,0,122,0,1,8,196,25,73,8,196,25,132,8,199,24,230,90,191,110,88,2,0,1,255,255,193,8,196,25,9,9,196,25,68,9,199,24,235,90,193,110,88,2,0,1,255,255,65,10,69,26,137,10,67,26,196,10,199,24,195,90,183,110,88,2,0,1,255,255,129,17,193,41,201,17,193,41,4,10,199,24,195,90,183,110,88,2,0,1,255,255,1,3,192,25,73,3,192,25,132,11,199,24,195,90,183,110,88,2,0,1,255,255,201,3,192,57,9,4,192,57,68,12,199,24,195,90,183,110,88,2,0,1,255,255,28,0,28,0,50,0,50,0,72,0,72,0,182,0,94,0,160,0,160,0,116,0,116,0,138,0,138,0,1,8,196,25,73,8,196,25,133,8,199,24,195,90,183,110,208,2,0,1,255,255,201,8,211,25,9,9,196,25,69,9,199,24,195,90,183,110,240,0,0,1,255,255,128,9,197,25,200,9,195,25,4,10,199,24,195,90,183,110,208,2,0,1,255,255,65,10,199,41,137,10,199,41,197,10,199,24,195,90,183,110,208,2,0,1,255,255,1,11,69,41,73,11,67,41,133,11,199,24,195,90,183,110,208,2,0,1,255,255,73,11,71,41,73,11,71,41,133,11,199,24,195,90,183,110,208,2,0,1,255,255,192,11,193,24,8,12,193,24,68,12,199,24,195,90,183,110,208,2,0,1,255,255,128,4,192,57,128,12,195,57,196,12,199,24,195,90,183,110,60,0,0,1,255,255,0,0,0,0,48,0,52,0,56,0,64,0,72,0,80,0,88,0,96,0,104,0,112,0,120,0,128,0,136,0,144,0,152,0,160,0,166,0,172,0,180,0,188,0,196,0,204,0,208,0,212,0,175,11,177,11,175,11,177,11,179,11,181,11,239,15,240,15,183,11,185,11,187,11,189,11,183,11,185,11,187,11,189,11,207,11,209,11,241,15,242,15,71,17,73,17,75,17,77,17,71,17,73,17,75,17,77,17,79,17,81,17,253,15,254,15,239,11,241,11,243,11,245,11,239,11,241,11,243,11,245,11,247,11,249,11,243,15,244,15,251,11,253,11,15,12,17,12,251,11,253,11,15,12,17,12,19,12,21,12,245,15,246,15,107,17,109,17,111,17,107,17,109,17,111,17,29,12,47,12,247,15,248,15,49,12,51,12,53,12,55,12,49,12,51,12,53,12,55,12,57,12,59,12,249,15,250,15,61,12,79,12,61,12,79,12,81,12,83,12,251,15,252,15,220,2,221,2,48,0,52,0,56,0,60,0,62,0,64,0,66,0,70,0,74,0,78,0,92,0,106,0,110,0,112,0,114,0,118,0,122,0,126,0,130,0,136,0,142,0,146,0,150,0,154,0,176,9,178,9,176,9,178,9,180,9,176,9,182,9,182,9,182,9,184,9,186,9,184,9,186,9,188,9,184,9,190,9,208,9,210,9,212,9,214,9,216,9,218,9,190,9,208,9,210,9,212,9,214,9,216,9,218,9,220,9,212,9,222,9,222,9,244,9,222,9,246,9,248,9,246,9,248,9,26,10,246,9,28,10,30,10,48,10,28,10,30,10,48,10,50,10,28,10,52,10,54,10,52,10,54,10,56,10,54,10,0,0,42,0,50,0,58,0,62,0,66,0,70,0,74,0,78,0,82,0,86,0,94,0,102,0,106,0,110,0,114,0,118,0,120,0,122,0,126,0,130,0,134,0,161,5,163,5,165,5,167,5,169,5,171,5,173,5,175,5,193,5,195,5,197,5,199,5,197,5,199,5,227,5,229,5,231,5,233,5,237,5,239,5,3,6,5,6,88,16,90,16,92,16,94,16,88,16,90,16,92,16,94,16,98,16,100,16,37,6,39,6,37,6,39,6,41,6,43,6,47,6,47,6,45,6,47,6,156,5,157,5,156,5,157,5,120,16,157,5,0,0,0,0,0,0,42,0,50,0,58,0,62,0,70,0,78,0,82,0,90,0,98,0,102,0,106,0,110,0,114,0,118,0,122,0,126,0,130,0,134,0,138,0,142,0,146,0,91,8,93,8,95,8,97,8,91,8,93,8,95,8,97,8,101,8,99,8,103,8,105,8,123,8,125,8,103,8,105,8,123,8,125,8,129,8,127,8,131,8,133,8,135,8,137,8,131,8,133,8,135,8,137,8,157,8,155,8,159,8,161,8,159,8,161,8,165,8,163,8,167,8,169,8,167,8,169,8,189,8,187,8,191,8,193,8,191,8,193,8,197,8,195,8,221,8,223,8,221,8,223,8,225,8,199,8,199,8,36,0,44,0,52,0,56,0,64,0,72,0,76,0,84,0,92,0,96,0,100,0,104,0,108,0,120,0,132,0,136,0,140,0,144,0,67,6,69,6,71,6,73,6,67,6,69,6,71,6,73,6,101,6,99,6,109,6,111,6,113,6,131,6,109,6,111,6,113,6,131,6,111,6,131,6,133,6,135,6,137,6,139,6,133,6,135,6,137,6,139,6,143,6,141,6,173,6,175,6,173,6,175,6,195,6,177,6,197,6,199,6,201,6,203,6,205,6,207,6,197,6,199,6,201,6,203,6,205,6,207,6,203,6,197,6,227,6,209,6,227,6,209,6,229,6,227,6,0,0,0,0,36,0,36,0,52,0,56,0,56,0,96,0,100,0,100,0,124,0,128,0,128,0,144,0,148,0,148,0,150,0,154,0,154,0,178,0,86,5,87,5,88,5,89,5,90,5,91,5,92,5,93,5,135,5,134,5,94,5,95,5,96,5,97,5,98,5,99,5,94,5,95,5,96,5,97,5,98,5,99,5,100,5,101,5,102,5,103,5,102,5,101,5,100,5,99,5,133,5,132,5,104,5,105,5,106,5,107,5,108,5,109,5,110,5,111,5,112,5,113,5,114,5,109,5,137,5,136,5,115,5,116,5,117,5,118,5,119,5,120,5,121,5,122,5,139,5,138,5,123,5,140,5,140,5,74,5,75,5,76,5,77,5,78,5,79,5,80,5,81,5,82,5,83,5,84,5,85,5,131,5,130,5,0,0,48,0,52,0,56,0,60,0,64,0,68,0,72,0,74,0,76,0,80,0,84,0,88,0,92,0,94,0,96,0,100,0,104,0,108,0,112,0,122,0,132,0,136,0,162,0,188,0,81,4,83,4,81,4,83,4,81,4,81,4,85,4,87,4,85,4,87,4,85,4,85,4,89,4,89,4,89,4,159,4,93,4,91,4,93,4,91,4,149,4,147,4,95,4,95,4,153,4,151,4,117,4,119,4,127,4,145,4,157,4,155,4,177,4,179,4,181,4,183,4,185,4,177,4,179,4,181,4,183,4,185,4,189,4,187,4,214,4,215,4,216,4,217,4,218,4,219,4,220,4,221,4,222,4,223,4,224,4,225,4,226,4,214,4,215,4,216,4,217,4,218,4,219,4,220,4,221,4,222,4,223,4,224,4,225,4,226,4,18,5,17,5,42,0,50,0,58,0,62,0,70,0,78,0,82,0,86,0,90,0,94,0,96,0,98,0,102,0,104,0,106,0,110,0,118,0,126,0,130,0,134,0,138,0,1,3,3,3,5,3,7,3,1,3,3,3,5,3,7,3,35,3,33,3,37,3,39,3,41,3,43,3,37,3,39,3,41,3,43,3,71,3,35,3,97,3,99,3,97,3,99,3,103,3,101,3,73,3,73,3,103,3,101,3,105,3,105,3,201,3,199,3,133,3,135,3,137,3,139,3,133,3,135,3,137,3,139,3,201,3,199,3,171,3,173,3,175,3,193,3,197,3,195,3,0,0,36,0,40,0,44,0,48,0,52,0,56,0,60,0,66,0,72,0,76,0,80,0,84,0,88,0,90,0,92,0,96,0,98,0,100,0,170,1,172,1,206,1,208,1,110,2,112,2,98,1,100,1,134,1,136,1,106,2,108,2,2,2,4,2,6,2,8,2,10,2,12,2,130,2,132,2,14,2,16,2,34,2,36,2,134,2,136,2,38,2,46,2,138,2,140,2,40,16,40,16,142,2,144,2,40,0,44,0,48,0,52,0,56,0,60,0,64,0,68,0,72,0,84,0,88,0,92,0,96,0,104,0,112,0,116,0,120,0,124,0,128,0,132,0,50,0,52,0,86,0,88,0,152,0,150,0,122,0,124,0,86,0,88,0,152,0,150,0,18,1,19,1,28,1,29,1,41,1,40,1,38,1,39,1,42,1,43,1,250,0,252,0,254,0,0,1,2,16,0,16,214,0,216,0,210,0,212,0,222,0,224,0,218,0,220,0,244,0,242,0,54,1,55,1,56,1,57,1,59,1,58,1,52,1,53,1,201,2,200,2,184,40,2,0,1,0,0,0,64,232,148,0,248,191,2,0,56,250,6,0,1,0,0,0,68,232,148,0,184,160,2,0,184,164,8,0,1,0,0,0,65,232,148,0,64,246,1,0,88,149,7,0,1,0,0,0,69,232,148,0,136,224,1,0,56,210,6,0,1,0,0,0,179,233,148,0,192,135,2,0,24,163,6,0,1,0,0,0,178,233,148,0,240,108,2,0,152,122,6,0,1,0,0,0,177,233,148,0,96,82,2,0,192,72,6,0,1,0,0,0,176,233,148,0,32,56,2,0,48,123,2,0,1,0,0,0,180,233,148,0,152,30,2,0,96,69,2,0,1,0,0,0,181,233,148,0,232,10,2,0,144,55,2,0,1,0,0,0,182,233,148,0,152,138,8,0,176,223,1,0,1,0,0,0,243,232,148,0,72,198,1,0,192,209,1,0,1,0,0,0,242,232,148,0,24,182,1,0,24,198,1,0,1,0,0,0,241,232,148,0,40,167,1,0,120,189,1,0,1,0,0,0,240,232,148,0,200,149,1,0,248,187,8,0,1,0,0,0,244,232,148,0,56,126,1,0,184,179,8,0,1,0,0,0,245,232,148,0,32,101,1,0,240,173,8,0,1,0,0,0,246,232,148,0,96,32,8,0,88,212,3,0,1,0,0,0,88,217,146,0,40,185,3,0,16,17,8,0,1,0,0,0,66,232,148,0,224,12,8,0,0,105,5,0,1,0,0,0,67,232,148,0,192,99,5,0,248,5,8,0,9,0,0,0,64,94,147,0,32,58,1,0,144,250,7,0,9,0,0,0,65,94,147,0,32,58,1,0,184,40,2,0,1,0,0,0,84,234,148,0,248,191,2,0,56,250,6,0,1,0,0,0,87,234,148,0,184,160,2,0,184,164,8,0,1,0,0,0,212,232,148,0,64,246,1,0,88,149,7,0,1,0,0,0,86,234,148,0,136,224,1,0,240,167,7,0,1,0,0,0,147,233,148,0,192,135,2,0,176,163,7,0,1,0,0,0,146,233,148,0,240,108,2,0,208,158,7,0,1,0,0,0,145,233,148,0,96,82,2,0,184,154,7,0,1,0,0,0,144,233,148,0,32,56,2,0,176,108,2,0,1,0,0,0,151,233,148,0,152,30,2,0,128,98,2,0,1,0,0,0,149,233,148,0,232,10,2,0,8,96,7,0,1,0,0,0,211,232,148,0,72,198,1,0,48,89,7,0,1,0,0,0,210,232,148,0,24,182,1,0,16,83,7,0,1,0,0,0,209,232,148,0,40,167,1,0,96,79,7,0,1,0,0,0,208,232,148,0,200,149,1,0,48,76,7,0,1,0,0,0,215,232,148,0,56,126,1,0,144,72,7,0,1,0,0,0,213,232,148,0,32,101,1,0,88,212,3,0,1,0,0,0,8,222,146,0,40,185,3,0,248,5,8,0,9,0,0,0,248,94,147,0,32,58,1,0,144,250,7,0,9,0,0,0,249,94,147,0,32,58,1,0,248,241,7,0,9,0,0,0,250,94,147,0,32,58,1,0,108,99,97,118,101,48,54,95,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,25,194,92,24,0,0,16,1,108,99,97,118,101,48,53,95,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,231,221,28,56,0,0,16,1,108,99,97,118,101,48,56,95,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,225,104,106,2,0,0,16,1,97,55,56,45,48,55,46,52,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,232,38,154,79,0,0,16,1,97,55,56,45,48,49,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,61,181,191,177,0,0,16,1,108,99,97,118,101,48,57,95,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,239,126,11,185,0,0,32,0,108,99,97,118,101,49,48,95,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,5,47,178,79,0,0,32,0,97,55,56,45,49,49,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,18,229,115,151,0,0,32,0,108,99,97,118,101,49,50,95,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,158,180,158,228,0,0,32,0,108,99,97,118,101,49,51,95,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,52,151,145,97,0,0,32,0,108,99,97,118,101,49,52,95,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,189,19,58,126,0,0,32,0,108,99,97,118,101,49,53,95,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,58,199,83,194,0,0,32,0,108,99,97,118,101,49,54,95,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,238,146,108,230,0,0,32,0,97,55,56,45,49,55,46,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,213,98,151,214,0,0,32,0,108,99,97,118,101,49,56,95,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,68,37,238,71,0,0,32,0,108,99,97,118,101,49,57,95,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,250,177,238,28,0,0,32,0,108,99,97,118,101,50,48,95,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,36,46,50,100,0,0,32,0,97,55,49,45,50,53,46,52,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,69,133,15,45,0,0,32,0,184,40,2,0,1,0,0,0,170,233,148,0,248,191,2,0,56,250,6,0,1,0,0,0,238,232,148,0,184,160,2,0,184,164,8,0,1,0,0,0,171,233,148,0,64,246,1,0,88,149,7,0,1,0,0,0,62,232,148,0,136,224,1,0,152,122,6,0,1,0,0,0,232,232,148,0,96,82,2,0,192,72,6,0,1,0,0,0,233,232,148,0,32,56,2,0,48,123,2,0,1,0,0,0,237,232,148,0,152,30,2,0,96,69,2,0,1,0,0,0,236,232,148,0,232,10,2,0,24,198,1,0,1,0,0,0,56,232,148,0,40,167,1,0,120,189,1,0,1,0,0,0,57,232,148,0,200,149,1,0,248,187,8,0,1,0,0,0,61,232,148,0,56,126,1,0,184,179,8,0,1,0,0,0,60,232,148,0,32,101,1,0,88,212,3,0,1,0,0,0,168,216,146,0,40,185,3,0,16,17,8,0,1,0,0,0,169,233,148,0,224,12,8,0,56,58,1,0,1,0,0,0,168,233,148,0,64,50,1,0,248,5,8,0,9,0,0,0,48,94,147,0,32,58,1,0,144,250,7,0,9,0,0,0,49,94,147,0,32,58,1,0,184,40,2,0,1,0,0,0,236,235,146,0,248,191,2,0,184,164,8,0,1,0,0,0,237,235,146,0,64,246,1,0,104,28,8,0,1,0,0,0,238,235,146,0,232,209,1,0,64,183,7,0,1,0,0,0,239,235,146,0,104,195,5,0,24,38,7,0,1,0,0,0,199,252,146,0,184,160,2,0,56,210,6,0,1,0,0,0,192,252,146,0,192,135,2,0,24,163,6,0,1,0,0,0,193,252,146,0,240,108,2,0,152,122,6,0,1,0,0,0,194,252,146,0,96,82,2,0,192,72,6,0,1,0,0,0,195,252,146,0,32,56,2,0,200,110,3,0,1,0,0,0,196,252,146,0,152,30,2,0,120,89,3,0,1,0,0,0,197,252,146,0,232,10,2,0,120,74,3,0,1,0,0,0,198,252,146,0,152,138,8,0,144,236,1,0,1,0,0,0,119,244,146,0,136,224,1,0,176,223,1,0,1,0,0,0,112,244,146,0,72,198,1,0,192,209,1,0,1,0,0,0,113,244,146,0,24,182,1,0,24,198,1,0,1,0,0,0,114,244,146,0,40,167,1,0,120,189,1,0,1,0,0,0,115,244,146,0,200,149,1,0,224,22,1,0,1,0,0,0,116,244,146,0,56,126,1,0,160,14,1,0,1,0,0,0,117,244,146,0,32,101,1,0,176,9,1,0,1,0,0,0,118,244,146,0,96,32,8,0,72,126,8,0,1,0,0,0,167,238,146,0,144,189,1,0,192,122,8,0,1,0,0,0,160,238,146,0,208,174,1,0,40,116,8,0,1,0,0,0,161,238,146,0,48,160,1,0,72,110,8,0,1,0,0,0,162,238,146,0,160,140,1,0,184,102,8,0,1,0,0,0,163,238,146,0,56,112,1,0,248,67,8,0,1,0,0,0,164,238,146,0,32,92,1,0,136,64,8,0,1,0,0,0,165,238,146,0,64,77,1,0,128,58,8,0,1,0,0,0,166,238,146,0,112,157,4,0,160,19,8,0,1,0,0,0,215,236,146,0,32,245,8,0,248,16,8,0,1,0,0,0,208,236,146,0,32,231,8,0,192,12,8,0,1,0,0,0,209,236,146,0,88,214,8,0,224,5,8,0,1,0,0,0,210,236,146,0,224,202,8,0,144,1,8,0,1,0,0,0,211,236,146,0,72,193,8,0,176,222,7,0,1,0,0,0,212,236,146,0,144,180,8,0,176,218,7,0,1,0,0,0,213,236,146,0,208,164,8,0,248,214,7,0,1,0,0,0,214,236,146,0,160,152,4,0,16,17,8,0,1,0,0,0,166,238,146,0,224,12,8,0,88,212,3,0,1,0,0,0,40,217,146,0,40,185,3,0,248,5,8,0,9,0,0,0,80,4,147,0,32,58,1,0,144,250,7,0,9,0,0,0,81,4,147,0,32,58,1,0,248,241,7,0,9,0,0,0,82,4,147,0,32,58,1,0,168,86,7,0,1,0,0,0,176,250,146,0,248,191,2,0,24,38,7,0,1,0,0,0,143,242,146,0,184,160,2,0,56,210,6,0,1,0,0,0,136,242,146,0,192,135,2,0,24,163,6,0,1,0,0,0,137,242,146,0,240,108,2,0,152,122,6,0,1,0,0,0,138,242,146,0,96,82,2,0,192,72,6,0,1,0,0,0,139,242,146,0,32,56,2,0,200,110,3,0,1,0,0,0,140,242,146,0,152,30,2,0,120,89,3,0,1,0,0,0,141,242,146,0,232,10,2,0,120,74,3,0,1,0,0,0,142,242,146,0,152,138,8,0,40,246,1,0,1,0,0,0,177,250,146,0,64,246,1,0,144,236,1,0,1,0,0,0,151,242,146,0,136,224,1,0,176,223,1,0,1,0,0,0,144,242,146,0,72,198,1,0,192,209,1,0,1,0,0,0,145,242,146,0,24,182,1,0,24,198,1,0,1,0,0,0,146,242,146,0,40,167,1,0,120,189,1,0,1,0,0,0,147,242,146,0,200,149,1,0,224,22,1,0,1,0,0,0,148,242,146,0,56,126,1,0,160,14,1,0,1,0,0,0,149,242,146,0,32,101,1,0,176,9,1,0,1,0,0,0,150,242,146,0,96,32,8,0,88,212,3,0,1,0,0,0,128,215,146,0,40,185,3,0,16,17,8,0,1,0,0,0,178,250,146,0,224,12,8,0,72,65,1,0,9,0,0,0,136,3,147,0,32,58,1,0,48,50,1,0,9,0,0,0,137,3,147,0,32,58,1,0,168,86,7,0,1,0,0,0,176,148,215,0,248,191,2,0,24,38,7,0,1,0,0,0,190,148,215,0,184,160,2,0,56,210,6,0,1,0,0,0,170,148,215,0,192,135,2,0,24,163,6,0,1,0,0,0,171,148,215,0,240,108,2,0,152,122,6,0,1,0,0,0,172,148,215,0,96,82,2,0,192,72,6,0,1,0,0,0,173,148,215,0,32,56,2,0,200,110,3,0,1,0,0,0,174,148,215,0,152,30,2,0,120,89,3,0,1,0,0,0,175,148,215,0,232,10,2,0,40,246,1,0,1,0,0,0,177,148,215,0,64,246,1,0,144,236,1,0,1,0,0,0,189,148,215,0,136,224,1,0,176,223,1,0,1,0,0,0,161,148,215,0,72,198,1,0,192,209,1,0,1,0,0,0,162,148,215,0,24,182,1,0,24,198,1,0,1,0,0,0,163,148,215,0,40,167,1,0,120,189,1,0,1,0,0,0,164,148,215,0,200,149,1,0,224,22,1,0,1,0,0,0,165,148,215,0,56,126,1,0,160,14,1,0,1,0,0,0,166,148,215,0,32,101,1,0,88,212,3,0,1,0,0,0,200,147,215,0,40,185,3,0,16,17,8,0,1,0,0,0,191,148,215,0,224,12,8,0,56,58,1,0,1,0,0,0,168,148,215,0,64,50,1,0,72,65,1,0,9,0,0,0,96,149,215,0,32,58,1,0,48,50,1,0,9,0,0,0,97,149,215,0,32,58,1,0,168,86,7,0,1,0,0,0,88,245,146,0,248,191,2,0,24,38,7,0,1,0,0,0,92,245,146,0,184,160,2,0,56,210,6,0,1,0,0,0,171,253,146,0,192,135,2,0,24,163,6,0,1,0,0,0,170,253,146,0,240,108,2,0,152,122,6,0,1,0,0,0,169,253,146,0,96,82,2,0,192,72,6,0,1,0,0,0,168,253,146,0,32,56,2,0,200,110,3,0,1,0,0,0,173,253,146,0,152,30,2,0,120,89,3,0,1,0,0,0,172,253,146,0,232,10,2,0,120,74,3,0,1,0,0,0,174,253,146,0,152,138,8,0,144,236,1,0,1,0,0,0,93,245,146,0,136,224,1,0,176,223,1,0,1,0,0,0,179,253,146,0,72,198,1,0,192,209,1,0,1,0,0,0,178,253,146,0,24,182,1,0,24,198,1,0,1,0,0,0,177,253,146,0,40,167,1,0,120,189,1,0,1,0,0,0,176,253,146,0,200,149,1,0,224,22,1,0,1,0,0,0,181,253,146,0,56,126,1,0,160,14,1,0,1,0,0,0,180,253,146,0,32,101,1,0,176,9,1,0,1,0,0,0,182,253,146,0,96,32,8,0,88,212,3,0,1,0,0,0,200,217,146,0,40,185,3,0,72,65,1,0,9,0,0,0,176,4,147,0,32,58,1,0,48,50,1,0,9,0,0,0,177,4,147,0,32,58,1,0,184,40,2,0,1,0,0,0,171,233,148,0,248,191,2,0,56,250,6,0,1,0,0,0,174,233,148,0,184,160,2,0,184,164,8,0,1,0,0,0,170,233,148,0,64,246,1,0,88,149,7,0,1,0,0,0,238,232,148,0,136,224,1,0,152,122,6,0,1,0,0,0,168,233,148,0,96,82,2,0,192,72,6,0,1,0,0,0,169,233,148,0,32,56,2,0,48,123,2,0,1,0,0,0,173,233,148,0,152,30,2,0,96,69,2,0,1,0,0,0,172,233,148,0,232,10,2,0,24,198,1,0,1,0,0,0,232,232,148,0,40,167,1,0,120,189,1,0,1,0,0,0,233,232,148,0,200,149,1,0,248,187,8,0,1,0,0,0,237,232,148,0,56,126,1,0,184,179,8,0,1,0,0,0,236,232,148,0,32,101,1,0,88,212,3,0,1,0,0,0,168,216,146,0,40,185,3,0,16,17,8,0,1,0,0,0,235,232,148,0,224,12,8,0,56,58,1,0,1,0,0,0,234,232,148,0,64,50,1,0,248,5,8,0,9,0,0,0,48,94,147,0,32,58,1,0,144,250,7,0,9,0,0,0,49,94,147,0,32,58,1,0,168,86,7,0,1,0,0,0,32,1,147,0,248,191,2,0,24,38,7,0,1,0,0,0,33,1,147,0,184,160,2,0,56,210,6,0,1,0,0,0,38,1,147,0,192,135,2,0,24,163,6,0,1,0,0,0,39,1,147,0,240,108,2,0,152,122,6,0,1,0,0,0,36,1,147,0,96,82,2,0,192,72,6,0,1,0,0,0,37,1,147,0,32,56,2,0,200,110,3,0,1,0,0,0,35,1,147,0,152,30,2,0,40,246,1,0,1,0,0,0,120,248,146,0,64,246,1,0,144,236,1,0,1,0,0,0,121,248,146,0,136,224,1,0,176,223,1,0,1,0,0,0,126,248,146,0,72,198,1,0,192,209,1,0,1,0,0,0,127,248,146,0,24,182,1,0,24,198,1,0,1,0,0,0,124,248,146,0,40,167,1,0,120,189,1,0,1,0,0,0,125,248,146,0,200,149,1,0,224,22,1,0,1,0,0,0,123,248,146,0,56,126,1,0,88,212,3,0,1,0,0,0,128,220,146,0,40,185,3,0,16,17,8,0,1,0,0,0,122,248,146,0,224,12,8,0,56,58,1,0,1,0,0,0,34,1,147,0,64,50,1,0,72,65,1,0,9,0,0,0,128,6,147,0,32,58,1,0,48,50,1,0,9,0,0,0,129,6,147,0,32,58,1,0,184,40,2,0,1,0,0,0,72,234,148,0,248,191,2,0,56,250,6,0,1,0,0,0,76,234,148,0,184,160,2,0,184,164,8,0,1,0,0,0,73,234,148,0,64,246,1,0,88,149,7,0,1,0,0,0,77,234,148,0,136,224,1,0,56,210,6,0,1,0,0,0,138,233,148,0,192,135,2,0,24,163,6,0,1,0,0,0,139,233,148,0,240,108,2,0,152,122,6,0,1,0,0,0,136,233,148,0,96,82,2,0,192,72,6,0,1,0,0,0,137,233,148,0,32,56,2,0,48,123,2,0,1,0,0,0,140,233,148,0,152,30,2,0,96,69,2,0,1,0,0,0,141,233,148,0,232,10,2,0,176,223,1,0,1,0,0,0,202,232,148,0,72,198,1,0,192,209,1,0,1,0,0,0,203,232,148,0,24,182,1,0,24,198,1,0,1,0,0,0,200,232,148,0,40,167,1,0,120,189,1,0,1,0,0,0,201,232,148,0,200,149,1,0,248,187,8,0,1,0,0,0,204,232,148,0,56,126,1,0,184,179,8,0,1,0,0,0,205,232,148,0,32,101,1,0,88,212,3,0,1,0,0,0,248,221,146,0,40,185,3,0,16,17,8,0,1,0,0,0,74,234,148,0,224,12,8,0,32,77,1,0,1,0,0,0,75,234,148,0,216,70,1,0,184,40,2,0,1,0,0,0,122,83,148,0,248,191,2,0,56,250,6,0,1,0,0,0,120,83,148,0,184,160,2,0,184,164,8,0,1,0,0,0,123,83,148,0,64,246,1,0,88,149,7,0,1,0,0,0,121,83,148,0,136,224,1,0,56,210,6,0,1,0,0,0,136,83,148,0,192,135,2,0,24,163,6,0,1,0,0,0,137,83,148,0,240,108,2,0,152,122,6,0,1,0,0,0,138,83,148,0,96,82,2,0,192,72,6,0,1,0,0,0,139,83,148,0,32,56,2,0,48,123,2,0,1,0,0,0,140,83,148,0,152,30,2,0,96,69,2,0,1,0,0,0,141,83,148,0,232,10,2,0,144,55,2,0,1,0,0,0,142,83,148,0,152,138,8,0,80,123,7,0,1,0,0,0,143,83,148,0,48,119,7,0,176,223,1,0,1,0,0,0,128,83,148,0,72,198,1,0,192,209,1,0,1,0,0,0,129,83,148,0,24,182,1,0,24,198,1,0,1,0,0,0,130,83,148,0,40,167,1,0,120,189,1,0,1,0,0,0,131,83,148,0,200,149,1,0,248,187,8,0,1,0,0,0,132,83,148,0,56,126,1,0,184,179,8,0,1,0,0,0,133,83,148,0,32,101,1,0,240,173,8,0,1,0,0,0,134,83,148,0,96,32,8,0,208,72,7,0,1,0,0,0,114,83,148,0,16,68,7,0,88,212,3,0,1,0,0,0,192,228,148,0,40,185,3,0,16,17,8,0,1,0,0,0,126,83,148,0,224,12,8,0,80,251,6,0,1,0,0,0,124,83,148,0,216,70,1,0,248,5,8,0,9,0,0,0,16,71,215,0,32,58,1,0,168,86,7,0,1,0,0,0,248,254,146,0,248,191,2,0,24,38,7,0,1,0,0,0,152,239,146,0,184,160,2,0,56,210,6,0,1,0,0,0,152,246,146,0,192,135,2,0,24,163,6,0,1,0,0,0,153,246,146,0,240,108,2,0,152,122,6,0,1,0,0,0,154,246,146,0,96,82,2,0,192,72,6,0,1,0,0,0,155,246,146,0,32,56,2,0,200,110,3,0,1,0,0,0,156,246,146,0,152,30,2,0,120,89,3,0,1,0,0,0,157,246,146,0,232,10,2,0,120,74,3,0,1,0,0,0,158,246,146,0,152,138,8,0,40,246,1,0,1,0,0,0,249,254,146,0,64,246,1,0,144,236,1,0,1,0,0,0,156,239,146,0,136,224,1,0,176,223,1,0,1,0,0,0,160,246,146,0,72,198,1,0,192,209,1,0,1,0,0,0,161,246,146,0,24,182,1,0,24,198,1,0,1,0,0,0,162,246,146,0,40,167,1,0,120,189,1,0,1,0,0,0,163,246,146,0,200,149,1,0,224,22,1,0,1,0,0,0,164,246,146,0,56,126,1,0,160,14,1,0,1,0,0,0,165,246,146,0,32,101,1,0,176,9,1,0,1,0,0,0,166,246,146,0,96,32,8,0,88,212,3,0,1,0,0,0,176,218,146,0,40,185,3,0,16,17,8,0,1,0,0,0,164,239,146,0,224,12,8,0,72,65,1,0,9,0,0,0,56,5,147,0,32,58,1,0,48,50,1,0,9,0,0,0,57,5,147,0,32,58,1,0,184,40,2,0,1,0,0,0,225,239,146,0,248,191,2,0,184,164,8,0,1,0,0,0,226,239,146,0,64,246,1,0,104,28,8,0,1,0,0,0,227,239,146,0,232,209,1,0,24,38,7,0,1,0,0,0,71,0,147,0,184,160,2,0,56,210,6,0,1,0,0,0,66,0,147,0,192,135,2,0,24,163,6,0,1,0,0,0,67,0,147,0,240,108,2,0,152,122,6,0,1,0,0,0,65,0,147,0,96,82,2,0,192,72,6,0,1,0,0,0,64,0,147,0,32,56,2,0,200,110,3,0,1,0,0,0,102,236,146,0,152,30,2,0,120,89,3,0,1,0,0,0,69,0,147,0,232,10,2,0,120,74,3,0,1,0,0,0,70,0,147,0,152,138,8,0,192,61,3,0,1,0,0,0,68,0,147,0,48,119,7,0,144,236,1,0,1,0,0,0,175,247,146,0,136,224,1,0,176,223,1,0,1,0,0,0,170,247,146,0,72,198,1,0,192,209,1,0,1,0,0,0,171,247,146,0,24,182,1,0,24,198,1,0,1,0,0,0,169,247,146,0,40,167,1,0,120,189,1,0,1,0,0,0,168,247,146,0,200,149,1,0,224,22,1,0,1,0,0,0,103,236,146,0,56,126,1,0,160,14,1,0,1,0,0,0,173,247,146,0,32,101,1,0,176,9,1,0,1,0,0,0,174,247,146,0,96,32,8,0,200,3,1,0,1,0,0,0,172,247,146,0,16,68,7,0,88,212,3,0,1,0,0,0,120,219,146,0,40,185,3,0,248,5,8,0,9,0,0,0,192,5,147,0,32,58,1,0,144,250,7,0,9,0,0,0,193,5,147,0,32,58,1,0,184,40,2,0,1,0,0,0,231,233,148,0,248,191,2,0,56,250,6,0,1,0,0,0,227,233,148,0,184,160,2,0,88,149,7,0,1,0,0,0,225,233,148,0,136,224,1,0,152,122,6,0,1,0,0,0,37,233,148,0,96,82,2,0,192,72,6,0,1,0,0,0,36,233,148,0,32,56,2,0,48,123,2,0,1,0,0,0,39,233,148,0,152,30,2,0,24,198,1,0,1,0,0,0,109,232,148,0,40,167,1,0,120,189,1,0,1,0,0,0,108,232,148,0,200,149,1,0,248,187,8,0,1,0,0,0,111,232,148,0,56,126,1,0,88,212,3,0,1,0,0,0,80,219,146,0,40,185,3,0,16,17,8,0,1,0,0,0])
.concat([230,233,148,0,224,12,8,0,32,77,1,0,1,0,0,0,25,232,148,0,216,70,1,0,184,40,2,0,1,0,0,0,128,93,148,0,248,191,2,0,56,250,6,0,1,0,0,0,132,93,148,0,184,160,2,0,184,164,8,0,1,0,0,0,129,93,148,0,64,246,1,0,88,149,7,0,1,0,0,0,133,93,148,0,136,224,1,0,152,122,6,0,1,0,0,0,144,93,148,0,96,82,2,0,192,72,6,0,1,0,0,0,145,93,148,0,32,56,2,0,48,123,2,0,1,0,0,0,134,93,148,0,152,30,2,0,24,198,1,0,1,0,0,0,146,93,148,0,40,167,1,0,120,189,1,0,1,0,0,0,147,93,148,0,200,149,1,0,248,187,8,0,1,0,0,0,135,93,148,0,56,126,1,0,88,212,3,0,1,0,0,0,248,26,149,0,40,185,3,0,16,17,8,0,1,0,0,0,131,93,148,0,224,12,8,0,248,5,8,0,9,0,0,0,112,99,215,0,32,58,1,0,144,250,7,0,9,0,0,0,113,99,215,0,32,58,1,0,184,40,2,0,1,0,0,0,225,239,146,0,248,191,2,0,184,164,8,0,1,0,0,0,226,239,146,0,64,246,1,0,104,28,8,0,1,0,0,0,227,239,146,0,232,209,1,0,24,38,7,0,1,0,0,0,71,0,147,0,184,160,2,0,56,210,6,0,1,0,0,0,66,0,147,0,192,135,2,0,24,163,6,0,1,0,0,0,67,0,147,0,240,108,2,0,152,122,6,0,1,0,0,0,65,0,147,0,96,82,2,0,192,72,6,0,1,0,0,0,64,0,147,0,32,56,2,0,200,110,3,0,1,0,0,0,68,0,147,0,152,30,2,0,120,89,3,0,1,0,0,0,69,0,147,0,232,10,2,0,120,74,3,0,1,0,0,0,70,0,147,0,152,138,8,0,192,61,3,0,1,0,0,0,102,236,146,0,48,119,7,0,144,236,1,0,1,0,0,0,175,247,146,0,136,224,1,0,176,223,1,0,1,0,0,0,170,247,146,0,72,198,1,0,192,209,1,0,1,0,0,0,171,247,146,0,24,182,1,0,24,198,1,0,1,0,0,0,169,247,146,0,40,167,1,0,120,189,1,0,1,0,0,0,168,247,146,0,200,149,1,0,224,22,1,0,1,0,0,0,172,247,146,0,56,126,1,0,160,14,1,0,1,0,0,0,173,247,146,0,32,101,1,0,176,9,1,0,1,0,0,0,174,247,146,0,96,32,8,0,200,3,1,0,1,0,0,0,103,236,146,0,16,68,7,0,88,212,3,0,1,0,0,0,120,219,146,0,40,185,3,0,248,5,8,0,9,0,0,0,192,5,147,0,32,58,1,0,144,250,7,0,9,0,0,0,193,5,147,0,32,58,1,0,168,86,7,0,1,0,0,0,38,254,146,0,248,191,2,0,24,38,7,0,1,0,0,0,214,245,146,0,184,160,2,0,56,210,6,0,1,0,0,0,32,254,146,0,192,135,2,0,24,163,6,0,1,0,0,0,33,254,146,0,240,108,2,0,152,122,6,0,1,0,0,0,35,254,146,0,96,82,2,0,192,72,6,0,1,0,0,0,34,254,146,0,32,56,2,0,200,110,3,0,1,0,0,0,37,254,146,0,152,30,2,0,120,89,3,0,1,0,0,0,36,254,146,0,232,10,2,0,40,246,1,0,1,0,0,0,39,254,146,0,64,246,1,0,144,236,1,0,1,0,0,0,215,245,146,0,136,224,1,0,176,223,1,0,1,0,0,0,208,245,146,0,72,198,1,0,192,209,1,0,1,0,0,0,209,245,146,0,24,182,1,0,24,198,1,0,1,0,0,0,211,245,146,0,40,167,1,0,120,189,1,0,1,0,0,0,210,245,146,0,200,149,1,0,224,22,1,0,1,0,0,0,213,245,146,0,56,126,1,0,160,14,1,0,1,0,0,0,212,245,146,0,32,101,1,0,88,212,3,0,1,0,0,0,24,218,146,0,40,185,3,0,16,17,8,0,1,0,0,0,72,239,146,0,224,12,8,0,72,65,1,0,9,0,0,0,224,4,147,0,32,58,1,0,48,50,1,0,9,0,0,0,225,4,147,0,32,58,1,0,224,41,1,0,9,0,0,0,226,4,147,0,32,58,1,0,184,40,2,0,1,0,0,0,207,252,146,0,248,191,2,0,184,164,8,0,1,0,0,0,127,244,146,0,64,246,1,0,24,38,7,0,1,0,0,0,206,252,146,0,184,160,2,0,56,210,6,0,1,0,0,0,192,252,146,0,192,135,2,0,24,163,6,0,1,0,0,0,193,252,146,0,240,108,2,0,152,122,6,0,1,0,0,0,194,252,146,0,96,82,2,0,192,72,6,0,1,0,0,0,195,252,146,0,32,56,2,0,200,110,3,0,1,0,0,0,196,252,146,0,152,30,2,0,120,89,3,0,1,0,0,0,197,252,146,0,232,10,2,0,120,74,3,0,1,0,0,0,198,252,146,0,152,138,8,0,192,61,3,0,1,0,0,0,201,252,146,0,48,119,7,0,120,194,6,0,1,0,0,0,202,252,146,0,112,109,7,0,96,189,6,0,1,0,0,0,203,252,146,0,24,133,7,0,144,236,1,0,1,0,0,0,126,244,146,0,136,224,1,0,176,223,1,0,1,0,0,0,112,244,146,0,72,198,1,0,192,209,1,0,1,0,0,0,113,244,146,0,24,182,1,0,24,198,1,0,1,0,0,0,114,244,146,0,40,167,1,0,120,189,1,0,1,0,0,0,115,244,146,0,200,149,1,0,224,22,1,0,1,0,0,0,116,244,146,0,56,126,1,0,160,14,1,0,1,0,0,0,117,244,146,0,32,101,1,0,176,9,1,0,1,0,0,0,118,244,146,0,96,32,8,0,200,3,1,0,1,0,0,0,121,244,146,0,16,68,7,0,208,183,6,0,1,0,0,0,122,244,146,0,240,58,7,0,200,177,6,0,1,0,0,0,123,244,146,0,200,42,1,0,16,17,8,0,1,0,0,0,166,238,146,0,224,12,8,0,88,212,3,0,1,0,0,0,40,217,146,0,40,185,3,0,248,5,8,0,9,0,0,0,80,4,147,0,32,58,1,0,144,250,7,0,9,0,0,0,81,4,147,0,32,58,1,0,184,40,2,0,1,0,0,0,122,83,148,0,248,191,2,0,56,250,6,0,1,0,0,0,120,83,148,0,184,160,2,0,184,164,8,0,1,0,0,0,123,83,148,0,64,246,1,0,88,149,7,0,1,0,0,0,121,83,148,0,136,224,1,0,56,210,6,0,1,0,0,0,136,83,148,0,192,135,2,0,24,163,6,0,1,0,0,0,137,83,148,0,240,108,2,0,152,122,6,0,1,0,0,0,138,83,148,0,96,82,2,0,192,72,6,0,1,0,0,0,139,83,148,0,32,56,2,0,48,123,2,0,1,0,0,0,140,83,148,0,152,30,2,0,96,69,2,0,1,0,0,0,141,83,148,0,232,10,2,0,144,55,2,0,1,0,0,0,142,83,148,0,152,138,8,0,176,223,1,0,1,0,0,0,128,83,148,0,72,198,1,0,192,209,1,0,1,0,0,0,129,83,148,0,24,182,1,0,24,198,1,0,1,0,0,0,130,83,148,0,40,167,1,0,120,189,1,0,1,0,0,0,131,83,148,0,200,149,1,0,248,187,8,0,1,0,0,0,132,83,148,0,56,126,1,0,184,179,8,0,1,0,0,0,133,83,148,0,32,101,1,0,240,173,8,0,1,0,0,0,134,83,148,0,96,32,8,0,88,212,3,0,1,0,0,0,192,228,148,0,40,185,3,0,16,17,8,0,1,0,0,0,126,83,148,0,224,12,8,0,80,251,6,0,1,0,0,0,124,83,148,0,216,70,1,0,56,58,1,0,1,0,0,0,125,83,148,0,64,50,1,0,248,5,8,0,9,0,0,0,16,71,215,0,32,58,1,0,144,250,7,0,9,0,0,0,17,71,215,0,32,58,1,0,168,86,7,0,1,0,0,0,217,0,147,0,248,191,2,0,24,38,7,0,1,0,0,0,219,0,147,0,184,160,2,0,56,210,6,0,1,0,0,0,59,248,146,0,192,135,2,0,24,163,6,0,1,0,0,0,58,248,146,0,240,108,2,0,152,122,6,0,1,0,0,0,56,248,146,0,96,82,2,0,192,72,6,0,1,0,0,0,57,248,146,0,32,56,2,0,200,110,3,0,1,0,0,0,60,248,146,0,152,30,2,0,40,246,1,0,1,0,0,0,218,0,147,0,64,246,1,0,144,236,1,0,1,0,0,0,220,0,147,0,136,224,1,0,176,223,1,0,1,0,0,0,67,240,146,0,72,198,1,0,192,209,1,0,1,0,0,0,66,240,146,0,24,182,1,0,24,198,1,0,1,0,0,0,64,240,146,0,40,167,1,0,120,189,1,0,1,0,0,0,65,240,146,0,200,149,1,0,224,22,1,0,1,0,0,0,68,240,146,0,56,126,1,0,88,212,3,0,1,0,0,0,32,220,146,0,40,185,3,0,16,17,8,0,1,0,0,0,216,0,147,0,224,12,8,0,72,65,1,0,9,0,0,0,72,6,147,0,32,58,1,0,48,50,1,0,9,0,0,0,73,6,147,0,32,58,1,0,224,41,1,0,9,0,0,0,74,6,147,0,32,58,1,0,184,40,2,0,1,0,0,0,40,39,216,0,248,191,2,0,56,250,6,0,1,0,0,0,42,39,216,0,184,160,2,0,184,164,8,0,1,0,0,0,41,39,216,0,64,246,1,0,88,149,7,0,1,0,0,0,32,39,216,0,136,224,1,0,240,167,7,0,1,0,0,0,45,39,216,0,192,135,2,0,176,163,7,0,1,0,0,0,46,39,216,0,240,108,2,0,208,158,7,0,1,0,0,0,43,39,216,0,96,82,2,0,184,154,7,0,1,0,0,0,44,39,216,0,32,56,2,0,176,108,2,0,1,0,0,0,47,39,216,0,152,30,2,0,8,96,7,0,1,0,0,0,36,39,216,0,72,198,1,0,48,89,7,0,1,0,0,0,37,39,216,0,24,182,1,0,16,83,7,0,1,0,0,0,34,39,216,0,40,167,1,0,96,79,7,0,1,0,0,0,35,39,216,0,200,149,1,0,48,76,7,0,1,0,0,0,38,39,216,0,56,126,1,0,88,212,3,0,1,0,0,0,48,38,216,0,40,185,3,0,248,5,8,0,9,0,0,0,112,39,216,0,32,58,1,0,144,250,7,0,9,0,0,0,113,39,216,0,32,58,1,0,248,241,7,0,9,0,0,0,114,39,216,0,32,58,1,0,184,40,2,0,1,0,0,0,18,236,146,0,248,191,2,0,184,164,8,0,1,0,0,0,19,236,146,0,64,246,1,0,24,38,7,0,1,0,0,0,17,236,146,0,184,160,2,0,152,122,6,0,1,0,0,0,120,1,147,0,96,82,2,0,192,72,6,0,1,0,0,0,121,1,147,0,32,56,2,0,24,163,6,0,1,0,0,0,122,1,147,0,240,108,2,0,56,210,6,0,1,0,0,0,123,1,147,0,192,135,2,0,200,110,3,0,1,0,0,0,200,248,146,0,152,30,2,0,120,89,3,0,1,0,0,0,201,248,146,0,232,10,2,0,120,74,3,0,1,0,0,0,202,248,146,0,152,138,8,0,144,236,1,0,1,0,0,0,16,236,146,0,136,224,1,0,24,198,1,0,1,0,0,0,168,240,146,0,40,167,1,0,120,189,1,0,1,0,0,0,169,240,146,0,200,149,1,0,192,209,1,0,1,0,0,0,170,240,146,0,24,182,1,0,176,223,1,0,1,0,0,0,171,240,146,0,72,198,1,0,224,22,1,0,1,0,0,0,120,237,146,0,56,126,1,0,160,14,1,0,1,0,0,0,121,237,146,0,32,101,1,0,176,9,1,0,1,0,0,0,122,237,146,0,96,32,8,0,88,212,3,0,1,0,0,0,248,220,146,0,40,185,3,0,248,5,8,0,9,0,0,0,206,187,145,0,32,58,1,0,144,250,7,0,9,0,0,0,207,187,145,0,32,58,1,0,248,241,7,0,9,0,0,0,208,187,145,0,32,58,1,0,72,82,8,0,9,0,0,0,209,187,145,0,32,58,1,0,168,86,7,0,1,0,0,0,200,241,146,0,248,191,2,0,24,38,7,0,1,0,0,0,239,250,146,0,184,160,2,0,56,210,6,0,1,0,0,0,232,250,146,0,192,135,2,0,24,163,6,0,1,0,0,0,233,250,146,0,240,108,2,0,152,122,6,0,1,0,0,0,234,250,146,0,96,82,2,0,192,72,6,0,1,0,0,0,235,250,146,0,32,56,2,0,200,110,3,0,1,0,0,0,236,250,146,0,152,30,2,0,120,89,3,0,1,0,0,0,237,250,146,0,232,10,2,0,120,74,3,0,1,0,0,0,238,250,146,0,152,138,8,0,192,61,3,0,1,0,0,0,208,241,146,0,48,119,7,0,120,194,6,0,1,0,0,0,209,241,146,0,112,109,7,0,96,189,6,0,1,0,0,0,210,241,146,0,24,133,7,0,40,246,1,0,1,0,0,0,201,241,146,0,64,246,1,0,144,236,1,0,1,0,0,0,199,242,146,0,136,224,1,0,176,223,1,0,1,0,0,0,192,242,146,0,72,198,1,0,192,209,1,0,1,0,0,0,193,242,146,0,24,182,1,0,24,198,1,0,1,0,0,0,194,242,146,0,40,167,1,0,120,189,1,0,1,0,0,0,195,242,146,0,200,149,1,0,224,22,1,0,1,0,0,0,196,242,146,0,56,126,1,0,160,14,1,0,1,0,0,0,197,242,146,0,32,101,1,0,176,9,1,0,1,0,0,0,198,242,146,0,96,32,8,0,200,3,1,0,1,0,0,0,212,241,146,0,16,68,7,0,208,183,6,0,1,0,0,0,213,241,146,0,240,58,7,0,200,177,6,0,1,0,0,0,214,241,146,0,200,42,1,0,88,212,3,0,1,0,0,0,168,215,146,0,40,185,3,0,16,17,8,0,1,0,0,0,202,241,146,0,224,12,8,0,72,65,1,0,9,0,0,0,152,3,147,0,32,58,1,0,184,40,2,0,1,0,0,0,47,39,216,0,248,191,2,0,56,250,6,0,1,0,0,0,39,39,216,0,184,160,2,0,184,164,8,0,1,0,0,0,46,39,216,0,64,246,1,0,88,149,7,0,1,0,0,0,38,39,216,0,136,224,1,0,240,167,7,0,1,0,0,0,28,39,216,0,192,135,2,0,176,163,7,0,1,0,0,0,30,39,216,0,240,108,2,0,208,158,7,0,1,0,0,0,45,39,216,0,96,82,2,0,184,154,7,0,1,0,0,0,44,39,216,0,32,56,2,0,176,108,2,0,1,0,0,0,43,39,216,0,152,30,2,0,128,98,2,0,1,0,0,0,41,39,216,0,232,10,2,0,8,96,7,0,1,0,0,0,40,39,216,0,72,198,1,0,48,89,7,0,1,0,0,0,24,39,216,0,24,182,1,0,16,83,7,0,1,0,0,0,37,39,216,0,40,167,1,0,96,79,7,0,1,0,0,0,36,39,216,0,200,149,1,0,48,76,7,0,1,0,0,0,35,39,216,0,56,126,1,0,144,72,7,0,1,0,0,0,34,39,216,0,32,101,1,0,88,212,3,0,1,0,0,0,48,38,216,0,40,185,3,0,248,5,8,0,9,0,0,0,112,39,216,0,32,58,1,0,144,250,7,0,9,0,0,0,113,39,216,0,32,58,1,0,248,241,7,0,9,0,0,0,114,39,216,0,32,58,1,0,168,86,7,0,1,0,0,0,32,253,146,0,248,191,2,0,24,38,7,0,1,0,0,0,36,253,146,0,184,160,2,0,56,210,6,0,1,0,0,0,208,244,146,0,192,135,2,0,24,163,6,0,1,0,0,0,209,244,146,0,240,108,2,0,152,122,6,0,1,0,0,0,210,244,146,0,96,82,2,0,192,72,6,0,1,0,0,0,211,244,146,0,32,56,2,0,200,110,3,0,1,0,0,0,212,244,146,0,152,30,2,0,120,89,3,0,1,0,0,0,213,244,146,0,232,10,2,0,120,74,3,0,1,0,0,0,214,244,146,0,152,138,8,0,40,246,1,0,1,0,0,0,33,253,146,0,64,246,1,0,144,236,1,0,1,0,0,0,37,253,146,0,136,224,1,0,176,223,1,0,1,0,0,0,216,244,146,0,72,198,1,0,192,209,1,0,1,0,0,0,217,244,146,0,24,182,1,0,24,198,1,0,1,0,0,0,218,244,146,0,40,167,1,0,120,189,1,0,1,0,0,0,219,244,146,0,200,149,1,0,224,22,1,0,1,0,0,0,220,244,146,0,56,126,1,0,160,14,1,0,1,0,0,0,221,244,146,0,32,101,1,0,176,9,1,0,1,0,0,0,222,244,146,0,96,32,8,0,88,212,3,0,1,0,0,0,112,217,146,0,40,185,3,0,16,17,8,0,1,0,0,0,40,253,146,0,224,12,8,0,72,65,1,0,9,0,0,0,120,4,147,0,32,58,1,0,48,50,1,0,9,0,0,0,121,4,147,0,32,58,1,0,224,41,1,0,9,0,0,0,122,4,147,0,32,58,1,0,168,86,7,0,1,0,0,0,235,251,146,0,248,191,2,0,24,38,7,0,1,0,0,0,237,251,146,0,184,160,2,0,56,210,6,0,1,0,0,0,224,251,146,0,192,135,2,0,24,163,6,0,1,0,0,0,225,251,146,0,240,108,2,0,152,122,6,0,1,0,0,0,226,251,146,0,96,82,2,0,192,72,6,0,1,0,0,0,227,251,146,0,32,56,2,0,200,110,3,0,1,0,0,0,228,251,146,0,152,30,2,0,120,89,3,0,1,0,0,0,229,251,146,0,232,10,2,0,40,246,1,0,1,0,0,0,236,251,146,0,64,246,1,0,144,236,1,0,1,0,0,0,238,251,146,0,136,224,1,0,176,223,1,0,1,0,0,0,168,243,146,0,72,198,1,0,192,209,1,0,1,0,0,0,169,243,146,0,24,182,1,0,24,198,1,0,1,0,0,0,170,243,146,0,40,167,1,0,120,189,1,0,1,0,0,0,171,243,146,0,200,149,1,0,224,22,1,0,1,0,0,0,172,243,146,0,56,126,1,0,160,14,1,0,1,0,0,0,173,243,146,0,32,101,1,0,88,212,3,0,1,0,0,0,144,216,146,0,40,185,3,0,16,17,8,0,1,0,0,0,232,251,146,0,224,12,8,0,72,65,1,0,9,0,0,0,232,3,147,0,32,58,1,0,48,50,1,0,9,0,0,0,233,3,147,0,32,58,1,0,142,0,0,0,4,11,0,0,10,2,0,0,242,3,0,0,64,14,0,0,92,11,0,0,194,29,0,0,64,5,0,0,72,17,0,0,106,46,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,168,86,7,0,1,0,0,0,142,243,146,0,248,191,2,0,24,38,7,0,1,0,0,0,199,251,146,0,184,160,2,0,200,110,3,0,1,0,0,0,196,251,146,0,152,30,2,0,240,251,8,0,4,0,0,0,216,7,147,0,208,13,4,0,40,246,1,0,1,0,0,0,140,243,146,0,64,246,1,0,144,236,1,0,1,0,0,0,195,251,146,0,136,224,1,0,224,22,1,0,1,0,0,0,192,251,146,0,56,126,1,0,112,188,8,0,4,0,0,0,218,7,147,0,136,7,4,0,88,212,3,0,1,0,0,0,120,216,146,0,40,185,3,0,16,17,8,0,1,0,0,0,141,243,146,0,224,12,8,0,56,58,1,0,1,0,0,0,143,243,146,0,64,50,1,0,72,65,1,0,9,0,0,0,216,3,147,0,32,58,1,0,48,50,1,0,9,0,0,0,217,3,147,0,32,58,1,0,168,86,7,0,1,0,0,0,169,244,146,0,248,191,2,0,24,38,7,0,1,0,0,0,7,253,146,0,184,160,2,0,56,210,6,0,1,0,0,0,0,253,146,0,192,135,2,0,24,163,6,0,1,0,0,0,1,253,146,0,240,108,2,0,152,122,6,0,1,0,0,0,2,253,146,0,96,82,2,0,192,72,6,0,1,0,0,0,3,253,146,0,32,56,2,0,200,110,3,0,1,0,0,0,4,253,146,0,152,30,2,0,120,89,3,0,1,0,0,0,5,253,146,0,232,10,2,0,40,246,1,0,1,0,0,0,168,244,146,0,64,246,1,0,144,236,1,0,1,0,0,0,255,252,146,0,136,224,1,0,176,223,1,0,1,0,0,0,248,252,146,0,72,198,1,0,192,209,1,0,1,0,0,0,249,252,146,0,24,182,1,0,24,198,1,0,1,0,0,0,250,252,146,0,40,167,1,0,120,189,1,0,1,0,0,0,251,252,146,0,200,149,1,0,224,22,1,0,1,0,0,0,252,252,146,0,56,126,1,0,160,14,1,0,1,0,0,0,253,252,146,0,32,101,1,0,88,212,3,0,1,0,0,0,80,217,146,0,40,185,3,0,16,17,8,0,1,0,0,0,171,244,146,0,224,12,8,0,72,65,1,0,9,0,0,0,104,4,147,0,32,58,1,0,48,50,1,0,9,0,0,0,105,4,147,0,32,58,1,0,224,41,1,0,9,0,0,0,106,4,147,0,32,58,1,0,184,40,2,0,1,0,0,0,138,151,215,0,248,191,2,0,56,250,6,0,1,0,0,0,131,151,215,0,184,160,2,0,184,164,8,0,1,0,0,0,139,151,215,0,64,246,1,0,240,167,7,0,1,0,0,0,128,151,215,0,192,135,2,0,176,163,7,0,1,0,0,0,131,151,215,0,240,108,2,0,208,158,7,0,1,0,0,0,129,151,215,0,96,82,2,0,184,154,7,0,1,0,0,0,130,151,215,0,32,56,2,0,0,229,5,0,1,0,0,0,133,151,215,0,152,30,2,0,208,240,5,0,1,0,0,0,137,151,215,0,232,10,2,0,240,175,7,0,1,0,0,0,134,151,215,0,152,138,8,0,112,179,7,0,1,0,0,0,132,151,215,0,48,119,7,0,88,212,3,0,1,0,0,0,200,147,215,0,40,185,3,0,16,17,8,0,1,0,0,0,140,151,215,0,224,12,8,0,56,58,1,0,1,0,0,0,141,151,215,0,64,50,1,0,248,5,8,0,9,0,0,0,152,151,215,0,32,58,1,0,144,250,7,0,9,0,0,0,153,151,215,0,32,58,1,0,97,110,116,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,144,188,222,105,1,0,16,1,97,110,116,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,5,40,53,171,1,0,16,1,114,97,52,45,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,79,11,48,135,2,0,16,1,114,97,52,45,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,254,95,78,175,2,0,16,1,103,102,120,95,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,177,36,40,30,4,0,32,0,103,102,120,95,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,179,25,67,120,4,0,32,0,99,111,108,114,54,102,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,199,51,227,252,7,0,32,0,15,0,0,0,255,255,0,0,0,0,0,0,16,0,0,0,255,255,2,0,0,0,0,0,17,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,16,0,0,0,1,1,0,0,120,97,1,0,16,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,2,0,168,234,7,0,16,0,0,0,1,2,0,0,96,135,7,0,16,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,2,0,32,4,2,0,17,0,0,0,1,2,0,0,184,146,2,0,17,0,0,0,1,2,2,0,144,147,2,0,0,0,0,0,254,0,4,0,128,129,4,0,17,0,0,0,1,12,0,0,8,49,4,0,17,0,0,0,1,12,4,0,152,21,4,0,17,0,0,0,1,12,8,0,72,246,3,0,17,0,0,0,1,12,12,0,72,0,3,0,0,0,0,0,184,40,2,0,1,0,0,0,47,39,216,0,248,191,2,0,56,250,6,0,1,0,0,0,24,39,216,0,184,160,2,0,184,164,8,0,1,0,0,0,46,39,216,0,64,246,1,0,88,149,7,0,1,0,0,0,30,39,216,0,136,224,1,0,240,167,7,0,1,0,0,0,42,39,216,0,192,135,2,0,176,163,7,0,1,0,0,0,43,39,216,0,240,108,2,0,208,158,7,0,1,0,0,0,45,39,216,0,96,82,2,0,184,154,7,0,1,0,0,0,44,39,216,0,32,56,2,0,176,108,2,0,1,0,0,0,40,39,216,0,152,30,2,0,8,96,7,0,1,0,0,0,34,39,216,0,72,198,1,0,48,89,7,0,1,0,0,0,35,39,216,0,24,182,1,0,16,83,7,0,1,0,0,0,37,39,216,0,40,167,1,0,96,79,7,0,1,0,0,0,36,39,216,0,200,149,1,0,48,76,7,0,1,0,0,0,38,39,216,0,56,126,1,0,88,212,3,0,1,0,0,0,48,38,216,0,40,185,3,0,248,5,8,0,9,0,0,0,112,39,216,0,32,58,1,0,144,250,7,0,9,0,0,0,113,39,216,0,32,58,1,0,248,241,7,0,9,0,0,0,114,39,216,0,32,58,1,0,168,86,7,0,1,0,0,0,56,252,146,0,248,191,2,0,24,38,7,0,1,0,0,0,59,252,146,0,184,160,2,0,168,188,8,0,1,0,0,0,252,243,146,0,208,174,1,0,24,175,8,0,1,0,0,0,253,243,146,0,48,160,1,0,240,156,8,0,1,0,0,0,254,243,146,0,160,140,1,0,80,144,8,0,1,0,0,0,255,243,146,0,56,112,1,0,16,134,8,0,1,0,0,0,248,243,146,0,192,135,2,0,112,128,8,0,1,0,0,0,249,243,146,0,240,108,2,0,128,123,8,0,1,0,0,0,250,243,146,0,96,82,2,0,120,117,8,0,1,0,0,0,251,243,146,0,32,56,2,0,40,246,1,0,1,0,0,0,57,252,146,0,64,246,1,0,144,236,1,0,1,0,0,0,60,252,146,0,136,224,1,0,16,111,8,0,1,0,0,0,132,238,146,0,32,231,8,0,32,95,8,0,1,0,0,0,133,238,146,0,88,214,8,0,192,81,8,0,1,0,0,0,134,238,146,0,224,202,8,0,112,71,8,0,1,0,0,0,135,238,146,0,72,193,8,0,56,65,8,0,1,0,0,0,128,238,146,0,72,198,1,0,48,60,8,0,1,0,0,0,129,238,146,0,24,182,1,0,224,54,8,0,1,0,0,0,130,238,146,0,40,167,1,0,160,47,8,0,1,0,0,0,131,238,146,0,200,149,1,0,88,212,3,0,1,0,0,0,216,216,146,0,40,185,3,0,16,17,8,0,1,0,0,0,58,252,146,0,224,12,8,0,72,65,1,0,9,0,0,0,16,4,147,0,32,58,1,0,48,50,1,0,9,0,0,0,17,4,147,0,32,58,1,0,224,41,1,0,9,0,0,0,18,4,147,0,32,58,1,0,101,112,114,45,49,49,55,50,49,46,97,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,222,17,93,28,1,0,16,1,101,112,114,45,49,49,55,50,48,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,207,80,83,115,1,0,16,1,101,112,114,45,49,49,55,50,50,46,97,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,181,141,170,173,2,0,32,0,101,112,114,45,49,49,55,51,54,46,98,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,137,94,173,233,2,0,32,0,101,112,114,45,49,49,55,50,51,46,97,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,154,63,26,19,2,0,32,0,101,112,114,45,49,49,55,51,55,46,98,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,35,0,66,46,2,0,32,0,101,112,114,45,49,49,55,50,52,46,97,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,10,213,46,111,2,0,32,0,101,112,114,45,49,49,55,51,56,46,98,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,2,109,61,222,2,0,32,0,101,112,114,45,49,49,55,50,53,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,78,104,179,248,3,0,32,0,101,112,114,45,49,49,55,50,57,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,147,39,60,174,3,0,32,0,101,112,114,45,49,49,55,50,54,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,25,84,206,60,3,0,32,0,101,112,114,45,49,49,55,51,48,46,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,85,43,246,58,3,0,32,0,101,112,114,45,49,49,55,50,55,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,120,0,57,176,3,0,32,0,101,112,114,45,49,49,55,51,49,46,98,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,74,116,135,42,3,0,32,0,101,112,114,45,49,49,55,50,56,46,98,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,216,63,164,243,3,0,32,0,101,112,114,45,49,49,55,51,50,46,98,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,85,227,179,47,3,0,32,0,101,112,114,45,49,49,55,49,55,46,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,203,224,107,103,3,0,32,0,101,112,114,45,49,49,55,51,51,46,98,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,148,172,44,128,3,0,32,0,101,112,114,45,49,49,55,49,56,46,97,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,194,100,40,136,3,0,32,0,101,112,114,45,49,49,55,51,52,46,98,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,210,4,199,118,3,0,32,0,101,112,114,45,49,49,55,49,57,46,97,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,247,135,153,51,3,0,32,0,101,112,114,45,49,49,55,51,53,46,98,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,170,6,228,79,3,0,32,0,101,112,114,45,49,49,54,55,49,46,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,59,52,113,43,4,0,16,1,111,112,114,45,49,49,54,55,50,46,97,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,96,244,215,187,8,0,64,0,111,112,114,45,49,49,54,55,51,46,97,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,54,74,12,64,8,0,64,0,51,49,55,45,48,48,54,56,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,16,67,237,193,5,0,16,1,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,58,75,11,121,1,0,16,1,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,93,242,101,15,1,0,16,1,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,43,215,205,101,1,0,16,1,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,196,251,147,51,1,0,16,1,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,16,125,150,164,2,0,32,0,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,171,130,30,2,2,0,32,0,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,63,207,38,26,2,0,32,0,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,134,240,126,39,2,0,32,0,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,175,37,18,102,2,0,32,0,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,167,157,1,215,2,0,32,0,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,78,104,179,248,3,0,32,0,50,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,147,39,60,174,3,0,32,0,49,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,25,84,206,60,3,0,32,0,50,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,85,43,246,58,3,0,32,0,49,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,120,0,57,176,3,0,32,0,50,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,74,116,135,42,3,0,32,0,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,216,63,164,243,3,0,32,0,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,85,227,179,47,3,0,32,0,50,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,203,224,107,103,3,0,32,0,50,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,148,172,44,128,3,0,32,0,50,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,194,100,40,136,3,0,32,0,50,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,210,4,199,118,3,0,32,0,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,247,135,153,51,3,0,32,0,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,170,6,228,79,3,0,32,0,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,163,157,224,103,4,0,16,1,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,139,61,101,124,4,0,16,1,101,112,114,45,49,48,54,57,57,46,52,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,23,141,211,63,1,0,16,1,101,112,114,45,49,48,54,57,54,46,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,159,241,52,215,1,0,16,1,101,112,114,45,49,48,55,48,48,46,52,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,82,178,4,59,1,0,16,1,101,112,114,45,49,48,54,57,55,46,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,61,18,188,242,1,0,16,1,101,112,114,45,49,48,55,48,49,46,52,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,81,23,23,146,1,0,16,1,101,112,114,45,49,48,54,57,56,46,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,192,253,228,193,1,0,16,1,101,112,114,45,49,48,55,51,57,46,57,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,7,194,158,162,2,0,32,0,101,112,114,45,49,48,55,52,48,46,57,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,21,48,249,71,2,0,32,0,101,112,114,45,49,48,55,52,49,46,57,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,156,115,112,73,2,0,32,0,101,112,114,45,49,48,55,48,57,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,144,10,223,173,3,0,32,0,101,112,114,45,49,48,55,49,51,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,58,222,236,236,3,0,32,0,101,112,114,45,49,48,55,49,48,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,235,105,35,153,3,0,32,0,101,112,114,45,49,48,55,49,52,46,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,251,66,191,145,3,0,32,0,101,112,114,45,49,48,55,49,49,46,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,246,110,22,41,3,0,32,0,101,112,114,45,49,48,55,49,53,46,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,132,115,197,167,3,0,32,0,101,112,114,45,49,48,55,49,50,46,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,25,208,106,135,3,0,32,0,101,112,114,45,49,48,55,49,54,46,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,72,29,186,64,3,0,32,0,101,112,114,45,49,48,55,48,53,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,158,116,123,119,4,0,16,1,55,55,53,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,252,52,149,106,6,0,16,1,101,112,114,45,49,48,55,48,54,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,204,74,17,170,7,0,64,0,101,112,114,45,49,48,55,48,55,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,130,29,12,128,7,0,64,0,101,112,114,45,49,48,55,48,56,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,82,239,33,89,7,0,64,0,51,49,55,45,48,48,51,51,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,229,130,232,73,5,0,16,1,168,86,7,0,1,0,0,0,16,237,146,0,248,191,2,0,24,38,7,0,1,0,0,0,120,254,146,0,184,160,2,0,56,210,6,0,1,0,0,0,121,254,146,0,192,135,2,0,24,163,6,0,1,0,0,0,122,254,146,0,240,108,2,0,152,122,6,0,1,0,0,0,123,254,146,0,96,82,2,0,192,72,6,0,1,0,0,0,124,254,146,0,32,56,2,0,200,110,3,0,1,0,0,0,125,254,146,0,152,30,2,0,120,89,3,0,1,0,0,0,126,254,146,0,232,10,2,0,120,74,3,0,1,0,0,0,127,254,146,0,152,138,8,0,192,61,3,0,1,0,0,0,18,237,146,0,48,119,7,0,120,194,6,0,1,0,0,0,19,237,146,0,112,109,7,0,96,189,6,0,1,0,0,0,20,237,146,0,24,133,7,0,40,246,1,0,1,0,0,0,17,237,146,0,64,246,1,0,144,236,1,0,1,0,0,0,40,246,146,0,136,224,1,0,176,223,1,0,1,0,0,0,41,246,146,0,72,198,1,0,192,209,1,0,1,0,0,0,42,246,146,0,24,182,1,0,24,198,1,0,1,0,0,0,43,246,146,0,40,167,1,0,120,189,1,0,1,0,0,0,44,246,146,0,200,149,1,0,224,22,1,0,1,0,0,0,45,246,146,0,56,126,1,0,160,14,1,0,1,0,0,0,46,246,146,0,32,101,1,0,176,9,1,0,1,0,0,0,47,246,146,0,96,32,8,0,200,3,1,0,1,0,0,0,21,237,146,0,16,68,7,0,208,183,6,0,1,0,0,0,22,237,146,0,240,58,7,0,200,177,6,0,1,0,0,0,23,237,146,0,200,42,1,0,88,212,3,0,1,0,0,0,88,218,146,0,40,185,3,0,16,17,8,0,1,0,0,0,113,239,146,0,224,12,8,0,72,65,1,0,9,0,0,0,8,5,147,0,32,58,1,0,48,50,1,0,9,0,0,0,9,5,147,0,32,58,1,0,224,41,1,0,9,0,0,0,10,5,147,0,32,58,1,0,32,167,8,0,9,0,0,0,11,5,147,0,32,58,1,0,168,86,7,0,1,0,0,0,18,239,146,0,248,191,2,0,24,38,7,0,1,0,0,0,16,239,146,0,184,160,2,0,56,210,6,0,1,0,0,0,144,253,146,0,192,135,2,0,24,163,6,0,1,0,0,0,145,253,146,0,240,108,2,0,152,122,6,0,1,0,0,0,146,253,146,0,96,82,2,0,192,72,6,0,1,0,0,0,147,253,146,0,32,56,2,0,200,110,3,0,1,0,0,0,148,253,146,0,152,30,2,0,120,89,3,0,1,0,0,0,149,253,146,0,232,10,2,0,40,246,1,0,1,0,0,0,19,239,146,0,64,246,1,0,144,236,1,0,1,0,0,0,17,239,146,0,136,224,1,0,176,223,1,0,1,0,0,0,64,245,146,0,72,198,1,0,192,209,1,0,1,0,0,0,65,245,146,0,24,182,1,0,24,198,1,0,1,0,0,0,66,245,146,0,40,167,1,0,120,189,1,0,1,0,0,0,67,245,146,0,200,149,1,0,224,22,1,0,1,0,0,0,68,245,146,0,56,126,1,0,160,14,1,0,1,0,0,0,69,245,146,0,32,101,1,0,88,212,3,0,1,0,0,0,184,217,146,0,40,185,3,0,16,17,8,0,1,0,0,0,22,239,146,0,224,12,8,0,72,65,1,0,9,0,0,0,160,4,147,0,32,58,1,0,48,50,1,0,9,0,0,0,161,4,147,0,32,58,1,0,168,86,7,0,1,0,0,0,216,237,146,0,248,191,2,0,24,38,7,0,1,0,0,0,39,250,146,0,184,160,2,0,56,210,6,0,1,0,0,0,32,250,146,0,192,135,2,0,24,163,6,0,1,0,0,0,33,250,146,0,240,108,2,0,152,122,6,0,1,0,0,0,34,250,146,0,96,82,2,0,192,72,6,0,1,0,0,0,35,250,146,0,32,56,2,0,200,110,3,0,1,0,0,0,36,250,146,0,152,30,2,0,120,89,3,0,1,0,0,0,37,250,146,0,232,10,2,0,40,246,1,0,1,0,0,0,217,237,146,0,64,246,1,0,144,236,1,0,1,0,0,0,255,241,146,0,136,224,1,0,176,223,1,0,1,0,0,0,248,241,146,0,72,198,1,0,192,209,1,0,1,0,0,0,249,241,146,0,24,182,1,0,24,198,1,0,1,0,0,0,250,241,146,0,40,167,1,0,120,189,1,0,1,0,0,0,251,241,146,0,200,149,1,0,224,22,1,0,1,0,0,0,252,241,146,0,56,126,1,0,160,14,1,0,1,0,0,0,253,241,146,0,32,101,1,0,88,212,3,0,1,0,0,0,40,215,146,0,40,185,3,0,16,17,8,0,1,0,0,0,218,237,146,0,224,12,8,0,72,65,1,0,9,0,0,0,64,3,147,0,32,58,1,0,48,50,1,0,9,0,0,0,65,3,147,0,32,58,1,0,168,86,7,0,1,0,0,0,96,253,146,0,248,191,2,0,24,38,7,0,1,0,0,0,99,253,146,0,184,160,2,0,56,210,6,0,1,0,0,0,19,245,146,0,192,135,2,0,24,163,6,0,1,0,0,0,18,245,146,0,240,108,2,0,152,122,6,0,1,0,0,0,17,245,146,0,96,82,2,0,192,72,6,0,1,0,0,0,16,245,146,0,32,56,2,0,200,110,3,0,1,0,0,0,20,245,146,0,152,30,2,0,120,89,3,0,1,0,0,0,21,245,146,0,232,10,2,0,120,74,3,0,1,0,0,0,22,245,146,0,152,138,8,0,40,246,1,0,1,0,0,0,97,253,146,0,64,246,1,0,144,236,1,0,1,0,0,0,100,253,146,0,136,224,1,0,176,223,1,0,1,0,0,0,27,245,146,0,72,198,1,0,192,209,1,0,1,0,0,0,26,245,146,0,24,182,1,0,24,198,1,0,1,0,0,0,25,245,146,0,40,167,1,0,120,189,1,0,1,0,0,0,24,245,146,0,200,149,1,0,224,22,1,0,1,0,0,0,28,245,146,0,56,126,1,0,160,14,1,0,1,0,0,0,29,245,146,0,32,101,1,0,88,212,3,0,1,0,0,0,152,217,146,0,40,185,3,0,16,17,8,0,1,0,0,0,98,253,146,0,224,12,8,0,72,65,1,0,9,0,0,0,144,4,147,0,32,58,1,0,48,50,1,0,9,0,0,0,145,4,147,0,32,58,1,0,184,40,2,0,1,0,0,0,214,155,215,0,248,191,2,0,56,250,6,0,1,0,0,0,211,155,215,0,184,160,2,0,184,164,8,0,1,0,0,0,215,155,215,0,64,246,1,0,8,3,3,0,4,0,0,0,112,156,215,0,208,13,4,0,248,230,7,0,4,0,0,0,104,156,215,0,184,198,5,0,184,171,7,0,4,0,0,0,96,156,215,0,136,191,7,0,240,175,7,0,1,0,0,0,212,155,215,0,152,30,2,0,112,179,7,0,1,0,0,0,213,155,215,0,232,10,2,0,16,17,8,0,1,0,0,0,210,155,215,0,224,12,8,0,32,77,1,0,1,0,0,0,209,155,215,0,216,70,1,0,88,212,3,0,1,0,0,0,200,154,215,0,40,185,3,0,248,5,8,0,9,0,0,0,0,156,215,0,32,58,1,0,144,250,7,0,9,0,0,0,1,156,215,0,32,58,1,0,234,48,2,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,8,0,0,0,224,7,2,0,32,0,2,0,0,0,0,0,176,242,1,0,0,232,1,0,0,0,0,0,0,0,0,0,0,0,0,0,50,52,97,99,45,48,54,46,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,228,80,74,146,1,0,16,1,50,52,97,100,45,48,55,46,51,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,14,165,118,154,1,0,16,1,50,52,97,98,45,48,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,170,248,68,30,2,0,16,1,50,52,97,57,45,48,46,52,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,143,240,63,112,3,0,64,0,50,52,106,56,45,48,46,52,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,135,132,19,97,3,0,64,0,50,52,97,97,45,48,46,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,64,186,18,203,4,0,32,0,99,57,53,49,46,49,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,240,209,118,250,5,0,32,0,50,52,106,52,45,48,46,49,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,163,137,165,196,5,0,32,0,50,52,106,53,45,48,46,49,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,54,164,188,214,5,0,32,0,99,57,53,48,46,49,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,61,112,165,204,5,0,32,0,50,52,106,50,45,48,46,49,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,118,27,220,5,0,32,0,50,52,106,51,45,48,46,49,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,67,45,161,59,5,0,32,0,50,52,106,55,45,48,46,49,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,158,144,161,224,6,0,32,0,50,52,106,54,45,48,46,49,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,248,46,147,119,6,0,32,0,50,52,97,99,45,48,95,106,45,49,95,106,97,112,97,110,46,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,104,233,114,248,1,0,16,1,50,52,97,100,45,48,95,106,45,49,95,106,97,112,97,110,46,51,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,35,205,11,199,1,0,16,1,50,52,97,98,45,48,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,170,248,68,30,2,0,16,1,50,52,97,57,45,48,46,52,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,143,240,63,112,3,0,64,0,50,52,106,56,45,48,46,52,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,135,132,19,97,3,0,64,0,50,52,97,97,45,48,95,106,46,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,54,27,32,185,4,0,32,0,99,57,53,49,46,49,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,240,209,118,250,5,0,32,0,50,52,106,52,45,48,46,49,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,163,137,165,196,5,0,32,0,50,52,106,53,45,48,46,49,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,54,164,188,214,5,0,32,0,99,57,53,48,46,49,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,61,112,165,204,5,0,32,0,50,52,106,50,45,48,46,49,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,118,27,220,5,0,32,0,50,52,106,51,45,48,46,49,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,67,45,161,59,5,0,32,0,50,52,106,55,45,48,46,49,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,158,144,161,224,6,0,32,0,50,52,106,54,45,48,46,49,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,248,46,147,119,6,0,32,0,119,119,102,115,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,101,242,29,98,1,0,16,1,119,119,102,115,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,254,45,56,163,1,0,16,1,119,119,102,115,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,230,89,149,54,1,0,16,1,119,119,102,115,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,170,213,188,140,1,0,16,1,119,119,102,115,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,170,248,68,30,2,0,16,1,119,119,102,115,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,87,196,99,110,3,0,64,0,119,119,102,115,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,156,138,1,215,3,0,64,0,119,119,102,115,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,14,162,53,138,3,0,64,0,119,119,102,115,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,98,137,240,109,3,0,64,0,119,119,102,115,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,206,165,76,21,4,0,32,0,119,119,102,115,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,220,132,70,61,4,0,32,0,119,119,102,115,51,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,154,176,7,216,5,0,32,0,119,119,102,115,51,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,211,148,234,216,5,0,32,0,119,119,102,115,51,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,7,116,141,94,5,0,32,0,119,119,102,115,51,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,66,233,5,144,5,0,32,0,119,119,102,115,52,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,56,74,252,170,5,0,32,0,119,119,102,115,52,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,251,136,139,228,5,0,32,0,119,119,102,115,52,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,213,105,127,237,5,0,32,0,119,119,102,115,52,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,137,253,117,77,5,0,32,0,119,119,102,115,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,68,212,38,116,5,0,32,0,119,119,102,115,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,42,173,17,175,5,0,32,0,119,119,102,115,49,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,159,6,18,239,5,0,32,0,119,119,102,115,49,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,127,62,52,8,5,0,32,0,119,119,102,115,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,40,169,197,170,5,0,32,0,119,119,102,115,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,234,123,235,103,5,0,32,0,119,119,102,115,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,118,110,11,151,5,0,32,0,119,119,102,115,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,245,175,44,36,5,0,32,0,119,119,102,115,50,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,185,138,235,243,5,0,32,0,119,119,102,115,50,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,175,30,169,44,5,0,32,0,119,119,102,115,50,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,106,156,246,187,5,0,32,0,119,119,102,115,50,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,205,139,176,118,5,0,32,0,119,119,102,115,50,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,94,91,31,104,5,0,32,0,119,119,102,115,50,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,247,27,254,129,5,0,32,0,119,119,102,115,50,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,94,238,46,197,5,0,32,0,119,119,102,115,50,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,14,5,168,178,5,0,32,0,119,119,102,115,51,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,130,141,100,157,5,0,32,0,119,119,102,115,51,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,219,121,42,116,5,0,32,0,119,119,102,115,51,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,182,61,146,246,5,0,32,0,119,119,102,115,51,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,33,214,236,155,5,0,32,0,119,119,102,115,51,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,213,116,76,249,5,0,32,0,119,119,102,115,51,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,24,69,9,148,5,0,32,0,119,119,102,115,50,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,131,157,91,123,5,0,32,0,119,119,102,115,50,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,38,166,253,112,5,0,32,0,119,119,102,115,53,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,133,115,21,81,6,0,32,0,119,119,102,115,53,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,245,157,199,127,6,0,32,0,119,119,102,115,52,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,176,118,64,161,6,0,32,0,119,119,102,115,52,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,253,114,19,37,6,0,32,0,119,119,102,115,52,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,234,182,215,111,6,0,32,0,119,119,102,115,52,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,128,81,94,152,6,0,32,0,119,119,102,115,52,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,146,215,250,178,6,0,32,0,119,119,102,115,52,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,169,95,150,79,6,0,32,0,184,40,2,0,1,0,0,0,85,0,147,0,248,191,2,0,184,164,8,0,1,0,0,0,86,0,147,0,64,246,1,0,56,250,6,0,1,0,0,0,189,247,146,0,184,160,2,0,88,149,7,0,1,0,0,0,190,247,146,0,136,224,1,0,56,210,6,0,1,0,0,0,80,0,147,0,192,135,2,0,152,122,6,0,1,0,0,0,81,0,147,0,96,82,2,0,192,72,6,0,1,0,0,0,82,0,147,0,32,56,2,0,24,163,6,0,1,0,0,0,83,0,147,0,240,108,2,0,200,110,3,0,1,0,0,0,188,247,146,0,152,30,2,0,176,223,1,0,1,0,0,0,184,247,146,0,72,198,1,0,24,198,1,0,1,0,0,0,185,247,146,0,40,167,1,0,120,189,1,0,1,0,0,0,186,247,146,0,200,149,1,0,192,209,1,0,1,0,0,0,187,247,146,0,24,182,1,0,224,22,1,0,1,0,0,0,191,247,146,0,32,101,1,0,88,212,3,0,1,0,0,0,128,219,146,0,40,185,3,0,232,75,4,0,1,0,0,0,87,0,147,0,216,70,1,0,64,23,5,0,9,0,0,0,200,5,147,0,32,58,1,0,104,20,5,0,9,0,0,0,202,5,147,0,32,58,1,0,216,16,5,0,9,0,0,0,201,5,147,0,32,58,1,0,106,102,45,48,49,46,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,65,42,228,189,1,0,16,1,106,102,45,48,48,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,149,201,163,188,1,0,16,1,106,102,45,48,51,46,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,4,212,23,82,1,0,16,1,106,102,45,48,50,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,40,206,161,54,1,0,16,1,109,97,115,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,206,86,82,126,1,0,16,1,109,97,115,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,153,212,91,0,1,0,16,1,106,102,45,48,54,46,50,48,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,70,37,4,121,2,0,16,1,106,102,45,48,52,46,49,48,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,168,203,115,3,0,32,0,106,102,45,48,53,46,49,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,157,196,226,34,3,0,32,0,109,97,115,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,52,16,1,61,4,0,32,0,109,97,115,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,11,157,12,109,4,0,32,0,109,97,115,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,32,230,0,175,5,0,32,0,109,97,115,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,162,30,230,47,5,0,32,0,109,97,115,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,59,149,86,30,6,0,32,0,109,97,115,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,248,184,38,56,6,0,32,0,109,97,115,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,69,189,139,59,6,0,32,0,109,97,115,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,105,55,48,49,6,0,32,0,109,97,115,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,122,251,36,226,7,0,32,0,109,97,115,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,65,235,109,95,7,0,32,0,109,97,115,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,167,6,220,110,8,0,64,0,109,97,115,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,242,164,240,194,9,0,64,0,109,98,55,49,50,50,104,46,49,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,204,87,238,43,0,0,0,8,168,86,7,0,1,0,0,0,19,191,145,0,248,191,2,0,24,38,7,0,1,0,0,0,21,191,145,0,184,160,2,0,56,210,6,0,1,0,0,0,248,250,146,0,192,135,2,0,24,163,6,0,1,0,0,0,249,250,146,0,240,108,2,0,152,122,6,0,1,0,0,0,250,250,146,0,96,82,2,0,192,72,6,0,1,0,0,0,251,250,146,0,32,56,2,0,200,110,3,0,1,0,0,0,252,250,146,0,152,30,2,0,120,89,3,0,1,0,0,0,253,250,146,0,232,10,2,0,40,246,1,0,1,0,0,0,20,191,145,0,64,246,1,0,144,236,1,0,1,0,0,0,22,191,145,0,136,224,1,0,176,223,1,0,1,0,0,0,208,242,146,0,72,198,1,0,192,209,1,0,1,0,0,0,209,242,146,0,24,182,1,0,24,198,1,0,1,0,0,0,210,242,146,0,40,167,1,0,120,189,1,0,1,0,0,0,211,242,146,0,200,149,1,0,224,22,1,0,1,0,0,0,212,242,146,0,56,126,1,0,160,14,1,0,1,0,0,0,213,242,146,0,32,101,1,0,88,212,3,0,1,0,0,0,176,215,146,0,40,185,3,0,16,17,8,0,1,0,0,0,16,191,145,0,224,12,8,0,56,58,1,0,1,0,0,0,17,191,145,0,64,50,1,0,72,65,1,0,9,0,0,0,67,223,146,0,32,58,1,0,48,50,1,0,9,0,0,0,68,223,146,0,32,58,1,0,224,41,1,0,9,0,0,0,69,223,146,0,32,58,1,0,106,50,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,145,86,236,104,1,0,16,1,106,49,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,44,234,152,21,1,0,16,1,108,104,53,51,50,106,49,48,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,101,198,135,17,1,0,16,1,108,104,53,51,50,106,49,49,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,229,169,237,24,1,0,16,1,51,46,49,52,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,62,118,143,174,2,0,16,1,108,104,53,51,52,106,49,49,46,49,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,13,251,133,191,3,0,64,0,108,104,53,51,52,106,48,57,46,49,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,165,233,44,108,4,0,64,0,108,104,53,51,52,106,49,48,46,49,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,33,34,104,227,4,0,64,0,48,52,54,46,57,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,119,109,217,49,5,0,32,0,48,52,56,46,57,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,218,67,70,187,5,0,32,0,108,104,53,51,52,106,49,50,46,55,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,116,139,26,182,6,0,32,0,119,97,114,122,97,114,100,95,106,97,112,97,110,46,50,57,102,52,48,48,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,198,240,226,248,0,0,0,3,114,101,100,101,97,114,116,104,40,95,95,57,54,49,48,50,51,41,45,115,105,109,109,49,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,70,195,186,101,0,0,16,1,114,101,100,101,97,114,116,104,40,95,95,57,54,49,48,50,51,41,45,115,105,109,109,49,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,174,74,236,168,0,0,16,1,114,101,100,101,97,114,116,104,40,95,95,57,54,49,48,50,51,41,45,115,105,109,109,49,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,149,137,175,44,0,0,16,1,114,101,100,101,97,114,116,104,40,95,95,57,54,49,48,50,51,41,45,115,105,109,109,49,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,29,194,235,19,0,0,16,1,114,101,100,101,97,114,116,104,45,115,105,109,109,51,46,48,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,197,12,53,131,0,0,32,0,114,101,100,101,97,114,116,104,45,115,105,109,109,51,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,230,77,115,86,0,0,32,0,114,101,100,101,97,114,116,104,45,115,105,109,109,51,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,241,160,14,128,0,0,32,0,114,101,100,101,97,114,116,104,45,115,105,109,109,51,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,108,20,233,151,0,0,32,0,114,101,100,101,97,114,116,104,45,115,105,109,109,51,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,72,214,177,12,0,0,32,0,114,101,100,101,97,114,116,104,45,115,105,109,109,51,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,240,153,16,122,0,0,32,0,114,101,100,101,97,114,116,104,45,115,105,109,109,51,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,84,143,255,174,0,0,32,0,114,101,100,101,97,114,116,104,45,115,105,109,109,51,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,208,172,112,247,0,0,32,0,114,101,100,101,97,114,116,104,45,115,105,109,109,52,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,242,86,30,48,0,0,32,0,114,101,100,101,97,114,116,104,45,115,105,109,109,52,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,3,225,72,32,0,0,32,0,114,101,100,101,97,114,116,104,45,115,105,109,109,52,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,85,52,67,201,0,0,32,0,114,101,100,101,97,114,116,104,45,115,105,109,109,52,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,168,113,33,192,0,0,32,0,114,101,100,101,97,114,116,104,45,115,105,109,109,52,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,118,242,219,45,0,0,32,0,114,101,100,101,97,114,116,104,45,115,105,109,109,52,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,166,32,168,254,0,0,32,0,114,101,100,101,97,114,116,104,45,115,105,109,109,52,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,241,141,82,199,0,0,32,0,114,101,100,101,97,114,116,104,45,115,105,109,109,52,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,59,207,73,36,0,0,32,0,114,101,100,101,97,114,116,104,45,115,105,109,109,53,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,185,81,68,66,0,0,32,0,114,101,100,101,97,114,116,104,45,115,105,109,109,53,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,107,181,140,155,0,0,32,0,99,49,54,45,49,49,46,52,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,136,211,219,35,2,0,0,0,99,49,54,45,49,51,46,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,252,127,148,171,2,0,0,0,99,49,54,45,48,55,46,52,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,89,208,209,100,2,0,0,0,99,49,54,45,48,54,46,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,216,97,55,4,2,0,0,0,99,49,54,45,49,50,46,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,199,40,176,111,9,0,0,0,99,49,54,45,48,49,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,131,206,89,112,11,0,0,0,99,49,54,45,48,50,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,5,233,88,180,11,0,0,0,99,49,54,45,48,51,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,49,148,90,81,11,0,0,0,99,49,54,45,48,52,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,226,133,242,235,11,0,0,0,99,49,54,45,48,53,46,52,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,74,6,157,164,29,0,0,0,112,97,108,49,54,108,56,98,45,99,49,54,45,48,56,46,105,99,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,120,210,86,148,0,0,0,8,112,97,108,49,54,108,56,98,45,99,49,54,45,48,57,46,105,99,51,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,171,186,101,9,0,0,0,8,99,49,54,45,49,49,46,52,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,136,211,219,35,2,0,0,0,99,49,54,45,49,48,46,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,70,46,157,50,2,0,0,0,99,49,54,45,48,55,46,52,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,89,208,209,100,2,0,0,0,99,49,54,45,48,54,46,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,216,97,55,4,2,0,0,0,99,49,54,45,49,50,46,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,199,40,176,111,9,0,0,0,99,49,54,45,48,49,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,131,206,89,112,11,0,0,0,99,49,54,45,48,50,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,5,233,88,180,11,0,0,0,99,49,54,45,48,51,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,49,148,90,81,11,0,0,0,99,49,54,45,48,52,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,226,133,242,235,11,0,0,0,99,49,54,45,48,53,46,52,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,74,6,157,164,29,0,0,0,112,97,108,49,54,108,56,98,45,99,49,54,45,48,56,46,105,99,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,120,210,86,148,0,0,0,8,112,97,108,49,54,108,56,98,45,99,49,54,45,48,57,46,105,99,51,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,171,186,101,9,0,0,0,8,48,56,49,114,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,129,98,121,132,1,0,16,1,48,56,49,98,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,155,77,96,76,2,0,16,1,48,56,49,97,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,169,119,199,180,3,0,32,0,48,56,49,97,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,217,200,42,39,3,0,32,0,48,56,49,97,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,164,154,75,70,4,0,32,0,48,56,49,97,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,89,55,23,78,4,0,32,0,48,56,49,97,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,128,109,254,233,4,0,32,0,48,56,49,97,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,154,178,34,138,4,0,32,0,48,56,49,97,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,234,186,182,20,5,0,64,0,118,101,110,100,101,116,116,97,114,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,73,4,63,236,0,0,0,8,48,56,49,112,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,66,2,227,95,1,0,16,1,48,56,49,98,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,155,77,96,76,2,0,16,1,48,56,49,97,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,169,119,199,180,3,0,32,0,48,56,49,97,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,217,200,42,39,3,0,32,0,48,56,49,97,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,164,154,75,70,4,0,32,0,48,56,49,97,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,89,55,23,78,4,0,32,0,48,56,49,97,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,128,109,254,233,4,0,32,0,48,56,49,97,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,154,178,34,138,4,0,32,0,48,56,49,97,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,234,186,182,20,5,0,64,0,118,101,110,100,101,116,116,97,106,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,78,165,80,53,0,0,0,8,102,106,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,115,251,175,162,1,0,16,1,102,106,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,123,224,5,239,1,0,16,1,102,106,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,121,51,137,68,1,0,16,1,102,106,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,7,193,251,151,1,0,16,1,102,106,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,155,223,174,233,2,0,16,1,118,116,109,97,97,48,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,59,225,48,3,3,0,32,0,118,116,109,97,97,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,27,163,23,194,4,0,32,0,118,116,109,97,97,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,142,249,31,9,4,0,32,0,118,116,109,97,97,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,204,233,19,183,5,0,32,0,118,116,109,97,97,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,129,191,48,26,5,0,32,0,102,106,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,53,162,152,110,6,0,64,0,102,106,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,181,162,205,57,7,0,64,0,102,106,45,50,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,66,87,4,101,8,0,0,8,112,97,108,49,54,108,56,97,46,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,143,142,116,238,9,0,0,8,112,97,108,49,54,108,56,98,46,49,51,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,218,59,161,109,9,0,0,8,112,97,108,49,54,108,56,98,46,49,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,152,224,169,98,9,0,0,8,112,97,108,49,54,108,56,98,46,49,52,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,170,104,103,3,9,0,0,8,112,97,108,49,54,108,56,98,46,49,52,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,206,31,66,191,9,0,0,8,184,40,2,0,1,0,0,0,85,0,147,0,248,191,2,0,184,164,8,0,1,0,0,0,87,0,147,0,64,246,1,0,56,250,6,0,1,0,0,0,189,247,146,0,184,160,2,0,88,149,7,0,1,0,0,0,190,247,146,0,136,224,1,0,56,210,6,0,1,0,0,0,80,0,147,0,192,135,2,0,152,122,6,0,1,0,0,0,81,0,147,0,96,82,2,0,192,72,6,0,1,0,0,0,82,0,147,0,32,56,2,0,24,163,6,0,1,0,0,0,83,0,147,0,240,108,2,0,200,110,3,0,1,0,0,0,84,0,147,0,152,30,2,0,176,223,1,0,1,0,0,0,184,247,146,0,72,198,1,0,24,198,1,0,1,0,0,0,185,247,146,0,40,167,1,0,120,189,1,0,1,0,0,0,186,247,146,0,200,149,1,0,192,209,1,0,1,0,0,0,187,247,146,0,24,182,1,0,224,22,1,0,1,0,0,0,188,247,146,0,56,126,1,0,88,212,3,0,1,0,0,0,128,219,146,0,40,185,3,0,64,23,5,0,9,0,0,0,202,5,147,0,32,58,1,0,104,20,5,0,9,0,0,0,200,5,147,0,32,58,1,0,216,16,5,0,9,0,0,0,201,5,147,0,32,58,1,0,27,0,0,0,255,255,4,0,0,0,0,0,0,0,0,0,168,86,7,0,1,0,0,0,107,191,145,0,248,191,2,0,24,38,7,0,1,0,0,0,109,191,145,0,184,160,2,0,56,210,6,0,1,0,0,0,120,251,146,0,192,135,2,0,24,163,6,0,1,0,0,0,121,251,146,0,240,108,2,0,152,122,6,0,1,0,0,0,122,251,146,0,96,82,2,0,192,72,6,0,1,0,0,0,123,251,146,0,32,56,2,0,200,110,3,0,1,0,0,0,124,251,146,0,152,30,2,0,120,89,3,0,1,0,0,0,125,251,146,0,232,10,2,0,40,246,1,0,1,0,0,0,108,191,145,0,64,246,1,0,144,236,1,0,1,0,0,0,110,191,145,0,136,224,1,0,176,223,1,0,1,0,0,0,72,243,146,0,72,198,1,0,192,209,1,0,1,0,0,0,73,243,146,0,24,182,1,0,24,198,1,0,1,0,0,0,74,243,146,0,40,167,1,0,120,189,1,0,1,0,0,0,75,243,146,0,200,149,1,0,224,22,1,0,1,0,0,0,76,243,146,0,56,126,1,0,160,14,1,0,1,0,0,0,77,243,146,0,32,101,1,0,88,212,3,0,1,0,0,0,48,216,146,0,40,185,3,0,32,77,1,0,1,0,0,0,104,191,145,0,216,70,1,0,72,65,1,0,9,0,0,0,154,223,146,0,32,58,1,0,48,50,1,0,9,0,0,0,155,223,146,0,32,58,1,0,224,41,1,0,9,0,0,0,157,223,146,0,32,58,1,0,102,102,45,49,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,182,225,215,132,1,0,16,1,102,102,45,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,124,164,173,110,1,0,16,1,102,102,45,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,74,222,167,75,1,0,16,1,102,102,45,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,99,238,233,157,2,0,16,1,102,102,45,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,242,73,251,21,3,0,32,0,102,102,45,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0])
.concat([35,150,12,226,3,0,32,0,102,102,45,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,199,133,232,25,4,0,32,0,102,102,45,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,122,71,107,75,4,0,32,0,102,102,45,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,14,188,198,121,4,0,32,0,102,102,45,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,69,228,145,19,4,0,32,0,102,102,45,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,45,212,106,179,4,0,32,0,102,102,45,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,206,36,157,107,4,0,32,0,102,102,45,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,102,10,216,104,4,0,32,0,102,102,45,48,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,66,36,35,65,4,0,32,0,102,102,45,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,135,60,234,124,5,0,32,0,102,102,45,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,143,62,127,94,5,0,32,0,102,102,45,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,5,63,177,139,5,0,32,0,102,102,45,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,195,255,122,13,5,0,32,0,102,102,45,49,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,5,13,171,240,6,0,64,0,48,52,54,45,112,103,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,188,57,30,119,1,0,16,1,48,52,54,45,112,50,46,115,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,62,203,130,241,1,0,16,1,48,52,54,45,115,103,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,140,172,233,146,2,0,32,0,48,52,54,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,74,10,114,250,3,0,32,0,48,52,54,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,5,194,0,201,3,0,32,0,48,52,54,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,37,60,14,136,3,0,32,0,48,52,54,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,170,72,34,122,3,0,32,0,48,52,54,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,69,94,115,75,3,0,32,0,48,52,54,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,223,113,49,39,3,0,32,0,48,52,54,45,99,55,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,76,156,130,18,3,0,32,0,48,52,54,45,99,56,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,61,224,68,201,3,0,32,0,48,52,54,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,159,187,132,63,4,0,16,1,48,52,54,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,219,194,249,193,5,0,64,0,48,52,54,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,100,74,37,86,5,0,64,0,48,52,54,45,118,51,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,177,63,17,88,5,0,64,0,48,52,54,45,118,52,46,118,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,135,193,84,79,5,0,64,0,97,101,112,114,103,101,46,112,97,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,255,9,162,23,1,0,16,1,97,101,112,114,103,111,46,112,97,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,161,230,101,210,1,0,16,1,97,101,115,112,114,103,45,50,46,122,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,182,10,85,67,2,0,16,1,97,101,49,48,48,104,46,97,104,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,43,37,190,6,3,0,32,0,97,101,49,48,48,46,97,108,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,244,223,156,0,3,0,32,0,97,101,49,48,49,104,46,98,104,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,255,158,70,242,3,0,32,0,97,101,49,48,49,46,98,108,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,187,145,119,219,3,0,32,0,97,101,49,48,50,104,46,99,104,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,67,163,210,249,3,0,32,0,97,101,49,48,50,46,99,108,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,137,232,27,104,3,0,32,0,97,101,49,48,52,46,101,108,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,152,183,49,228,3,0,32,0,97,101,49,48,53,46,102,108,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,193,235,249,183,3,0,32,0,97,101,49,48,54,46,103,108,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,75,55,80,124,3,0,32,0,97,101,51,48,48,119,51,54,46,98,100,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,158,242,41,232,4,0,32,0,97,101,50,48,48,119,55,52,46,98,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,65,80,100,193,5,0,32,0,97,101,50,48,49,119,55,53,46,98,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,255,189,99,63,6,0,32,0,97,101,50,48,50,119,55,54,46,98,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,202,87,200,92,7,0,32,0,97,101,52,48,48,116,50,51,46,121,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,67,176,255,198,8,0,64,0,97,101,52,48,49,116,50,52,46,121,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,115,26,63,216,8,0,64,0,97,101,53,48,48,119,48,55,46,97,100,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,44,249,52,55,9,0,64,0,116,107,100,101,110,115,104,111,95,54,56,104,99,49,49,97,56,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,16,116,107,100,101,110,115,104,111,95,54,56,104,99,49,49,97,56,46,101,101,112,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,16,56,55,51,45,110,48,51,46,107,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,62,46,30,160,1,0,16,1,56,55,51,45,110,48,50,46,107,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,204,162,175,85,1,0,16,1,56,55,51,45,102,48,49,46,102,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,163,255,53,234,2,0,16,1,56,55,51,99,48,54,97,46,102,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,103,11,52,14,3,0,32,0,56,55,51,99,48,54,99,46,102,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,205,114,14,239,3,0,32,0,56,55,51,99,48,54,98,46,101,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,46,32,173,151,3,0,32,0,56,55,51,99,48,54,100,46,101,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,46,212,147,131,3,0,32,0,56,55,51,99,48,55,97,46,102,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,79,184,170,168,3,0,32,0,56,55,51,99,48,55,99,46,102,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,154,0,33,37,3,0,32,0,56,55,51,99,48,55,98,46,101,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,186,184,162,18,3,0,32,0,56,55,51,99,48,55,100,46,101,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,101,249,233,250,3,0,32,0,56,55,51,99,48,52,97,46,102,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,243,11,116,247,4,0,32,0,56,55,51,99,48,52,99,46,102,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,43,189,172,93,4,0,32,0,56,55,51,99,48,52,98,46,101,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,218,129,197,154,4,0,32,0,56,55,51,99,48,52,100,46,101,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,140,102,164,68,4,0,32,0,56,55,51,99,48,53,97,46,102,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,125,16,62,215,4,0,32,0,56,55,51,99,48,53,99,46,102,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,50,144,89,4,0,32,0,56,55,51,99,48,53,98,46,101,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,153,155,5,129,4,0,32,0,56,55,51,99,48,53,100,46,101,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,223,215,163,127,4,0,32,0,56,55,51,97,48,56,46,102,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,27,154,208,226,6,0,0,8,56,55,51,45,48,51,46,107,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,78,10,104,54,1,0,16,1,56,55,51,45,48,50,46,107,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,52,44,139,197,1,0,16,1,56,55,51,45,102,48,49,46,102,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,163,255,53,234,2,0,16,1,56,55,51,99,48,54,97,46,102,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,103,11,52,14,3,0,32,0,56,55,51,99,48,54,99,46,102,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,205,114,14,239,3,0,32,0,56,55,51,99,48,54,98,46,101,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,46,32,173,151,3,0,32,0,56,55,51,99,48,54,100,46,101,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,46,212,147,131,3,0,32,0,56,55,51,99,48,55,97,46,102,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,79,184,170,168,3,0,32,0,56,55,51,99,48,55,99,46,102,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,154,0,33,37,3,0,32,0,56,55,51,99,48,55,98,46,101,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,186,184,162,18,3,0,32,0,56,55,51,99,48,55,100,46,101,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,101,249,233,250,3,0,32,0,56,55,51,99,48,52,97,46,102,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,243,11,116,247,4,0,32,0,56,55,51,99,48,52,99,46,102,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,43,189,172,93,4,0,32,0,56,55,51,99,48,52,98,46,101,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,218,129,197,154,4,0,32,0,56,55,51,99,48,52,100,46,101,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,140,102,164,68,4,0,32,0,56,55,51,99,48,53,97,46,102,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,125,16,62,215,4,0,32,0,56,55,51,99,48,53,99,46,102,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,50,144,89,4,0,32,0,56,55,51,99,48,53,98,46,101,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,153,155,5,129,4,0,32,0,56,55,51,99,48,53,100,46,101,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,223,215,163,127,4,0,32,0,56,55,51,97,48,56,46,102,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,27,154,208,226,6,0,0,8,56,55,51,45,107,48,51,46,107,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,173,23,104,39,1,0,16,1,56,55,51,45,107,48,50,46,107,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,69,28,204,128,1,0,16,1,56,55,51,45,104,48,49,46,102,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,124,122,11,153,2,0,16,1,56,55,51,99,48,54,97,46,102,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,103,11,52,14,3,0,32,0,56,55,51,99,48,54,99,46,102,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,205,114,14,239,3,0,32,0,56,55,51,99,48,54,98,46,101,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,46,32,173,151,3,0,32,0,56,55,51,99,48,54,100,46,101,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,46,212,147,131,3,0,32,0,56,55,51,99,48,55,97,46,102,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,79,184,170,168,3,0,32,0,56,55,51,99,48,55,99,46,102,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,154,0,33,37,3,0,32,0,56,55,51,99,48,55,98,46,101,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,186,184,162,18,3,0,32,0,56,55,51,99,48,55,100,46,101,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,101,249,233,250,3,0,32,0,56,55,51,99,48,52,97,46,102,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,243,11,116,247,4,0,32,0,56,55,51,99,48,52,99,46,102,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,43,189,172,93,4,0,32,0,56,55,51,99,48,52,98,46,101,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,218,129,197,154,4,0,32,0,56,55,51,99,48,52,100,46,101,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,140,102,164,68,4,0,32,0,56,55,51,99,48,53,97,46,102,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,125,16,62,215,4,0,32,0,56,55,51,99,48,53,99,46,102,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,50,144,89,4,0,32,0,56,55,51,99,48,53,98,46,101,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,153,155,5,129,4,0,32,0,56,55,51,99,48,53,100,46,101,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,223,215,163,127,4,0,32,0,56,55,51,97,48,56,46,102,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,27,154,208,226,6,0,0,8,103,117,48,49,46,97,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,232,248,40,235,1,0,16,1,103,117,48,51,46,97,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,49,180,210,154,1,0,16,1,103,117,48,48,46,97,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,79,232,169,252,1,0,16,1,103,117,48,50,46,97,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,174,107,2,182,1,0,16,1,103,117,49,48,46,97,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,125,232,66,128,2,0,16,1,103,117,48,56,46,97,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,250,91,137,200,2,0,16,1,103,117,49,49,46,97,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,130,235,214,192,2,0,16,1,103,117,48,57,46,97,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,167,19,222,66,2,0,16,1,103,117,48,52,46,102,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,191,158,194,129,3,0,16,1,103,117,48,53,46,104,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,106,153,174,10,4,0,32,0,103,117,48,54,46,104,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,61,240,253,78,4,0,32,0,109,97,106,45,48,50,46,104,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,55,188,59,56,5,0,32,0,109,97,106,45,48,49,46,99,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,4,162,64,152,6,0,32,0,109,97,106,45,48,48,46,99,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,22,141,234,135,6,0,32,0,109,97,106,45,48,52,46,114,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,25,155,228,54,7,0,32,0,109,97,106,45,48,53,46,114,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,204,113,252,128,7,0,32,0,109,97,106,45,48,54,46,114,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,75,104,122,46,7,0,32,0,109,97,106,45,48,55,46,114,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,120,31,204,58,7,0,32,0,109,97,106,45,48,56,46,115,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,109,163,88,25,7,0,32,0,109,97,106,45,48,57,46,115,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,161,135,16,194,7,0,32,0,109,97,106,45,49,48,46,115,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,65,166,47,160,7,0,32,0,109,97,106,45,49,49,46,115,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,5,147,190,218,7,0,32,0,103,116,49,50,46,110,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,21,160,134,154,8,0,32,0,103,116,49,51,46,110,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,5,153,112,244,8,0,32,0,103,116,49,52,46,110,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,35,197,15,117,8,0,32,0,103,116,49,53,46,110,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,61,221,78,241,8,0,32,0,103,115,48,55,46,104,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,93,126,11,117,9,0,64,0,109,97,106,45,48,51,46,104,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,195,250,220,49,10,0,64,0,109,98,55,49,50,56,121,46,49,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,162,128,231,189,11,0,0,8,109,98,55,49,50,56,121,46,49,54,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,81,39,77,196,11,0,0,8,109,98,55,49,50,56,121,46,49,54,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,81,39,77,196,11,0,0,8,109,98,55,49,50,56,121,46,49,55,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,81,39,77,196,11,0,0,8,112,97,108,49,54,114,56,97,32,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,12,0,0,16,112,97,108,49,54,108,56,98,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,12,0,0,16,112,97,108,49,54,108,56,98,46,55,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,253,131,158,25,12,0,0,8,112,97,108,49,54,108,56,98,46,55,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,12,0,0,16,112,97,108,49,54,108,56,98,46,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,12,0,0,16,112,97,108,49,54,108,56,98,46,56,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,12,0,0,16,112,97,108,49,54,108,56,98,46,57,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,12,0,0,16,112,97,108,49,54,108,56,98,46,49,48,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,12,0,0,16,109,97,108,45,49,50,46,110,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,16,109,97,108,45,49,51,46,110,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,16,109,97,108,45,49,52,46,110,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,16,109,97,108,45,49,53,46,110,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,16,109,97,108,45,48,55,46,104,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,16,103,122,48,49,46,97,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,40,195,232,21,1,0,16,1,103,122,48,51,46,97,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,110,200,181,170,1,0,16,1,103,116,48,48,46,97,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,117,113,39,183,1,0,16,1,103,116,48,50,46,97,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,53,30,227,205,1,0,16,1,103,122,49,48,46,97,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,233,25,249,121,2,0,16,1,103,122,48,56,46,97,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,54,120,125,212,2,0,16,1,103,116,49,49,45,49,46,97,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,222,35,203,128,2,0,16,1,103,116,48,57,45,49,46,97,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,225,167,143,10,2,0,16,1,103,116,48,52,46,102,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,191,158,194,129,3,0,16,1,103,116,48,53,46,104,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,106,153,174,10,4,0,32,0,103,116,48,54,46,104,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,61,240,253,78,4,0,32,0,109,97,106,45,48,50,46,104,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,55,188,59,56,5,0,32,0,109,97,106,45,48,49,46,99,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,4,162,64,152,6,0,32,0,109,97,106,45,48,48,46,99,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,22,141,234,135,6,0,32,0,109,97,106,45,48,52,46,114,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,25,155,228,54,7,0,32,0,109,97,106,45,48,53,46,114,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,204,113,252,128,7,0,32,0,109,97,106,45,48,54,46,114,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,75,104,122,46,7,0,32,0,109,97,106,45,48,55,46,114,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,120,31,204,58,7,0,32,0,109,97,106,45,48,56,46,115,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,109,163,88,25,7,0,32,0,109,97,106,45,48,57,46,115,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,161,135,16,194,7,0,32,0,109,97,106,45,49,48,46,115,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,65,166,47,160,7,0,32,0,109,97,106,45,49,49,46,115,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,5,147,190,218,7,0,32,0,103,116,49,50,46,110,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,21,160,134,154,8,0,32,0,103,116,49,51,46,110,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,5,153,112,244,8,0,32,0,103,116,49,52,46,110,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,35,197,15,117,8,0,32,0,103,116,49,53,46,110,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,61,221,78,241,8,0,32,0,103,116,48,55,46,104,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,93,126,11,117,9,0,64,0,109,97,106,45,48,51,46,104,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,195,250,220,49,10,0,64,0,109,98,55,49,50,56,121,46,49,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,162,128,231,189,11,0,0,8,109,98,55,49,50,56,121,46,49,54,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,81,39,77,196,11,0,0,8,109,98,55,49,50,56,121,46,49,54,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,81,39,77,196,11,0,0,8,109,98,55,49,50,56,121,46,49,55,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,81,39,77,196,11,0,0,8,112,97,108,49,54,114,56,97,32,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,12,0,0,16,112,97,108,49,54,108,56,98,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,12,0,0,16,112,97,108,49,54,108,56,98,46,55,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,253,131,158,25,12,0,0,8,112,97,108,49,54,108,56,98,46,55,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,12,0,0,16,112,97,108,49,54,108,56,98,46,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,12,0,0,16,112,97,108,49,54,108,56,98,46,56,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,12,0,0,16,112,97,108,49,54,108,56,98,46,57,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,12,0,0,16,112,97,108,49,54,108,56,98,46,49,48,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,12,0,0,16,50,55,99,48,49,48,46,97,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,8,22,242,48,1,0,16,1,50,55,99,48,49,48,46,97,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,51,106,136,96,1,0,16,1,103,116,48,48,46,97,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,117,113,39,183,1,0,16,1,103,116,48,50,46,97,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,53,30,227,205,1,0,16,1,100,50,55,99,48,49,48,46,97,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,186,108,53,153,2,0,16,1,100,50,55,99,48,49,48,46,97,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,231,20,241,139,2,0,16,1,100,50,55,99,48,49,48,46,97,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,126,212,150,61,2,0,16,1,100,50,55,99,48,49,48,46,97,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,182,185,42,2,0,16,1,103,117,48,52,46,102,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,191,158,194,129,3,0,16,1,50,55,53,49,50,46,106,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,120,160,34,171,4,0,32,0,50,55,53,49,50,46,106,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,40,68,252,52,4,0,32,0,109,97,106,45,48,50,46,104,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,55,188,59,56,5,0,32,0,109,97,106,45,48,49,46,99,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,4,162,64,152,6,0,32,0,109,97,106,45,48,48,46,99,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,22,141,234,135,6,0,32,0,109,97,106,45,48,52,46,114,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,25,155,228,54,7,0,32,0,109,97,106,45,48,53,46,114,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,204,113,252,128,7,0,32,0,109,97,106,45,48,54,46,114,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,75,104,122,46,7,0,32,0,109,97,106,45,48,55,46,114,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,120,31,204,58,7,0,32,0,109,97,106,45,48,56,46,115,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,109,163,88,25,7,0,32,0,109,97,106,45,48,57,46,115,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,161,135,16,194,7,0,32,0,109,97,106,45,49,48,46,115,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,65,166,47,160,7,0,32,0,109,97,106,45,49,49,46,115,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,5,147,190,218,7,0,32,0,103,116,49,50,46,110,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,21,160,134,154,8,0,32,0,103,116,49,51,46,110,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,5,153,112,244,8,0,32,0,103,116,49,52,46,110,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,35,197,15,117,8,0,32,0,103,116,49,53,46,110,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,61,221,78,241,8,0,32,0,103,115,48,55,46,104,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,93,126,11,117,9,0,64,0,109,97,106,45,48,51,46,104,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,195,250,220,49,10,0,64,0,109,98,55,49,50,56,121,46,49,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,162,128,231,189,11,0,0,8,109,98,55,49,50,56,121,46,49,54,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,81,39,77,196,11,0,0,8,109,98,55,49,50,56,121,46,49,54,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,81,39,77,196,11,0,0,8,109,98,55,49,50,56,121,46,49,55,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,81,39,77,196,11,0,0,8,112,97,108,49,54,114,56,97,32,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,12,0,0,16,112,97,108,49,54,108,56,98,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,12,0,0,16,112,97,108,49,54,108,56,98,46,55,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,253,131,158,25,12,0,0,8,112,97,108,49,54,108,56,98,46,55,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,12,0,0,16,112,97,108,49,54,108,56,98,46,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,12,0,0,16,112,97,108,49,54,108,56,98,46,56,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,12,0,0,16,112,97,108,49,54,108,56,98,46,57,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,12,0,0,16,112,97,108,49,54,108,56,98,46,49,48,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,12,0,0,16,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,170,58,146,120,1,0,16,1,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,89,162,206,153,1,0,16,1,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,55,248,89,185,2,0,16,1,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,74,46,64,199,3,0,32,0,56,57,48,53,48,45,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,135,214,215,100,4,0,32,0,56,57,48,53,48,45,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,164,63,219,36,5,0,32,0,56,57,48,53,48,45,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,33,84,113,127,5,0,32,0,56,57,48,53,48,45,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,57,76,238,17,6,0,64,0,56,57,48,53,48,45,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,171,82,53,137,7,0,64,0,50,49,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,234,239,213,252,0,0,0,8,50,50,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,108,184,219,207,0,0,0,8,50,51,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,244,105,53,252,0,0,0,8,50,52,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,254,9,160,224,0,0,0,8,50,53,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,254,9,160,224,0,0,0,8,50,54,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,62,179,191,12,0,0,0,8,119,111,114,108,100,32,115,112,111,114,116,115,32,99,111,109,112,101,116,105,116,105,111,110,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,172,240,147,75,0,0,16,1,115,111,110,105,99,32,115,112,105,107,101,32,45,32,119,111,114,108,100,32,99,104,97,109,112,105,111,110,115,104,105,112,32,98,101,97,99,104,32,118,111,108,108,101,121,98,97,108,108,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,179,94,78,247,0,0,16,1,116,114,105,99,107,121,32,107,105,99,107,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,52,253,230,72,0,0,16,1,114,97,105,100,101,110,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,30,195,89,188,0,0,16,1,111,114,100,121,110,101,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,116,42,191,231,0,0,16,1,108,101,103,101,110,100,97,114,121,32,97,120,101,44,32,116,104,101,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,7,16,33,45,0,0,16,1,104,105,116,32,116,104,101,32,105,99,101,32,45,32,118,104,108,32,116,104,101,32,111,102,102,105,99,105,97,108,32,118,105,100,101,111,32,104,111,99,107,101,121,32,108,101,97,103,117,101,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,170,195,41,139,0,0,16,1,102,97,108,99,111,110,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,43,161,192,11,0,0,16,1,100,111,117,98,108,101,32,100,117,110,103,101,111,110,115,32,45,32,119,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,96,140,26,74,0,0,16,1,99,97,100,97,115,104,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,239,58,11,187,0,0,16,1,97,108,105,101,110,32,99,114,117,115,104,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,148,132,72,234,0,0,16,1,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,202,107,13,49,1,0,16,1,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,97,190,112,184,2,0,16,1,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,250,170,136,212,3,0,32,0,119,119,57,51,48,57,49,52,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,93,198,104,249,4,0,32,0,119,119,57,51,48,57,49,55,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,203,115,136,185,5,0,32,0,119,119,57,51,48,57,49,56,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,178,132,238,186,5,0,32,0,119,119,57,51,48,57,49,54,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,230,95,195,7,6,0,64,0,119,119,57,51,48,57,49,53,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,171,91,2,130,7,0,64,0,57,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,162,83,86,67,0,0,0,8,49,48,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,73,211,234,230,0,0,0,8,116,116,48,45,117,57,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,167,204,212,105,1,0,16,1,116,116,49,45,117,57,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,105,84,2,65,1,0,16,1,51,45,117,49,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,228,196,103,161,2,0,16,1,117,56,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,30,37,142,144,3,0,32,0,117,56,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,166,11,41,196,3,0,32,0,117,56,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,235,154,125,64,3,0,32,0,117,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,233,35,88,233,4,0,32,0,117,49,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,169,135,147,232,5,0,64,0,117,49,50,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,35,203,240,12,6,0,64,0,101,112,114,45,53,50,50,54,46,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,221,20,245,87,1,0,16,1,101,112,114,45,53,50,50,55,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,176,47,29,90,1,0,16,1,101,112,114,45,53,50,50,56,46,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,138,130,151,165,1,0,16,1,101,112,114,45,53,50,50,50,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,7,114,165,10,2,0,16,1,101,112,114,45,53,50,50,53,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,129,254,113,229,3,0,32,0,101,112,114,45,53,50,50,52,46,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,60,249,48,97,3,0,32,0,101,112,114,45,53,50,50,51,46,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,78,0,3,59,3,0,32,0,101,112,114,45,53,50,50,57,46,53,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,211,62,45,238,4,0,32,0,101,112,114,45,53,50,51,48,46,53,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,80,75,74,240,4,0,32,0,112,114,45,53,50,50,48,46,49,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,229,140,12,123,5,0,32,0,112,114,45,53,50,49,57,46,56,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,203,2,75,29,5,0,32,0,112,114,45,53,50,50,49,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,79,103,186,137,0,0,0,8,103,99,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,106,31,98,181,1,0,16,1,103,99,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,12,42,27,85,1,0,16,1,103,99,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,244,192,230,224,2,0,16,1,109,97,101,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,160,204,21,167,3,0,32,0,109,97,101,48,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,148,48,4,48,4,0,32,0,109,97,101,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,251,243,74,67,4,0,32,0,103,99,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,255,70,34,47,5,0,64,0,51,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,99,242,181,152,1,0,16,1,52,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,185,104,126,147,1,0,16,1,103,99,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,244,192,230,224,2,0,16,1,109,97,101,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,160,204,21,167,3,0,32,0,109,97,101,48,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,148,48,4,48,4,0,32,0,109,97,101,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,251,243,74,67,4,0,32,0,103,99,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,255,70,34,47,5,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,254,0,2,0,72,209,1,0,20,0,0,0,1,4,0,0,64,5,1,0,20,0,0,0,1,4,4,0,176,111,1,0,0,0,0,0,254,0,2,0,144,212,8,0,20,0,0,0,1,8,0,0,96,135,7,0,20,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,2,0,56,72,1,0,20,0,0,0,1,16,0,0,72,66,1,0,20,0,0,0,1,16,16,0,112,60,1,0,0,0,0,0,254,0,2,0,16,17,8,0,20,0,0,0,1,32,0,0,96,135,7,0,20,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,120,51,1,0,20,0,0,0,1,64,0,0,56,0,1,0,20,0,0,0,1,64,64,0,144,43,1,0,0,0,0,0,254,0,2,0,48,25,1,0,20,0,0,0,1,128,0,0,24,16,1,0,20,0,0,0,1,128,128,0,40,11,1,0,0,0,0,0,254,0,2,0,72,209,1,0,20,0,0,0,1,4,0,0,64,5,1,0,20,0,0,0,1,4,4,0,176,111,1,0,0,0,0,0,254,0,2,0,144,212,8,0,20,0,0,0,1,8,0,0,96,135,7,0,20,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,2,0,56,72,1,0,20,0,0,0,1,16,0,0,72,66,1,0,20,0,0,0,1,16,16,0,112,60,1,0,0,0,0,0,254,0,2,0,16,17,8,0,20,0,0,0,1,32,0,0,96,135,7,0,20,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,120,51,1,0,20,0,0,0,1,64,0,0,144,43,1,0,20,0,0,0,1,64,64,0,176,34,1,0,0,0,0,0,254,0,2,0,48,25,1,0,20,0,0,0,1,128,0,0,24,16,1,0,20,0,0,0,1,128,128,0,40,11,1,0,0,0,0,0,254,0,2,0,80,111,3,0,20,0,0,0,1,4,0,0,184,112,5,0,20,0,0,0,1,4,4,0,104,87,1,0,0,0,0,0,254,0,2,0,144,212,8,0,20,0,0,0,1,8,0,0,96,135,7,0,20,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,2,0,56,72,1,0,20,0,0,0,1,16,0,0,72,66,1,0,20,0,0,0,1,16,16,0,112,60,1,0,0,0,0,0,254,0,2,0,16,17,8,0,20,0,0,0,1,32,0,0,96,135,7,0,20,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,120,51,1,0,20,0,0,0,1,64,0,0,144,43,1,0,20,0,0,0,1,64,64,0,176,34,1,0,0,0,0,0,254,0,2,0,48,25,1,0,20,0,0,0,1,128,0,0,24,16,1,0,20,0,0,0,1,128,128,0,40,11,1,0,48,51,49,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,36,28,128,162,1,0,16,1,48,51,49,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,116,113,17,76,2,0,32,0,48,51,49,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,184,78,10,189,3,0,32,0,48,51,49,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,130,83,222,239,3,0,32,0,48,51,49,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,51,127,15,88,3,0,32,0,48,51,49,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,232,125,41,237,3,0,32,0,48,51,49,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,124,66,55,203,4,0,16,1,48,51,49,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,126,73,120,204,5,0,64,0,48,51,49,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,198,67,160,221,5,0,64,0,109,116,50,45,104,48,45,97,46,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,199,187,109,124,1,0,16,1,109,116,50,45,108,48,45,97,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,137,246,229,157,1,0,16,1,105,115,45,104,49,46,53,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,242,225,168,155,1,0,16,1,105,115,45,108,49,46,53,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,38,6,224,228,1,0,16,1,109,116,50,115,104,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,67,234,203,30,2,0,16,1,109,116,50,115,108,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,49,181,213,143,2,0,16,1,99,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,181,228,97,126,3,0,32,0,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,100,117,102,10,3,0,32,0,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,18,67,180,94,3,0,32,0,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,148,98,134,242,3,0,32,0,107,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,120,38,154,140,4,0,32,0,107,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,120,223,85,84,4,0,32,0,107,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,65,140,37,58,4,0,32,0,107,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,20,26,233,193,4,0,32,0,100,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,159,158,59,113,5,0,64,0,109,116,50,101,101,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,113,249,138,32,6,0,16,1,112,97,108,49,54,108,56,45,109,57,50,45,97,45,51,109,46,105,99,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,7,0,0,16,112,97,108,49,54,108,56,45,109,57,50,45,97,45,55,106,46,105,99,52,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,7,0,0,16,112,97,108,49,54,108,56,45,109,57,50,45,97,45,57,106,46,105,99,53,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,7,0,0,16,112,97,108,49,54,108,56,45,109,57,50,45,98,45,50,108,46,105,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,7,0,0,16,112,97,108,49,54,108,56,45,109,57,50,45,98,45,55,104,46,105,99,52,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,7,0,0,16,101,51,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,88,253,134,61,1,0,16,1,101,52,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,81,187,199,166,1,0,16,1,101,50,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,128,251,163,183,2,0,16,1,101,49,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,217,28,10,232,3,0,32,0,101,53,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,89,209,56,17,4,0,32,0,101,54,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,247,20,98,217,4,0,32,0,101,55,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,142,179,148,4,4,0,32,0,101,56,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,245,205,227,140,4,0,32,0,101,57,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,187,56,113,140,5,0,32,0,101,49,48,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,125,104,196,192,5,0,32,0,101,49,49,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,143,86,15,187,5,0,32,0,101,49,50,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,17,40,71,252,5,0,32,0,101,49,51,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,75,246,157,64,6,0,32,0,101,49,52,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,182,205,42,176,6,0,32,0,101,49,53,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,94,178,247,202,6,0,32,0,101,49,54,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,115,56,201,126,6,0,32,0,114,111,109,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,252,0,82,78,1,0,16,0,114,111,109,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,140,199,204,115,1,0,16,0,117,110,105,99,111,95,115,114,49,51,46,114,111,109,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,223,195,1,208,2,0,32,0,117,110,105,99,111,95,115,114,48,57,46,114,111,109,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,141,144,109,105,2,0,32,0,117,110,105,99,111,95,115,114,48,53,46,114,111,109,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,193,56,246,0,2,0,32,0,114,111,109,49,52,46,114,111,109,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,196,25,11,208,2,0,32,0,114,111,109,49,48,46,114,111,109,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,128,66,50,125,2,0,32,0,114,111,109,48,54,46,114,111,109,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,96,96,194,58,2,0,32,0,114,111,109,48,55,46,114,111,109,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,157,255,198,159,2,0,32,0,114,111,109,49,49,46,114,111,109,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,28,175,171,17,2,0,32,0,114,111,109,49,53,46,114,111,109,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,104,177,163,38,2,0,32,0,114,111,109,48,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,171,167,11,177,3,0,64,0,114,111,109,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,85,180,140,219,4,0,64,0,50,51,56,45,112,103,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,220,248,237,239,1,0,16,1,50,51,56,45,112,50,46,115,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,197,9,74,91,1,0,16,1,50,51,56,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,219,206,149,31,2,0,32,0,50,51,56,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,129,161,198,144,3,0,32,0,50,51,56,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,240,32,135,136,3,0,32,0,50,51,56,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,163,58,57,44,3,0,32,0,50,51,56,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,235,9,233,185,3,0,32,0,50,51,56,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,235,104,44,194,3,0,32,0,50,51,56,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,205,35,147,17,3,0,32,0,50,51,56,45,99,55,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,237,231,44,167,3,0,32,0,50,51,56,45,99,56,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,251,46,124,28,3,0,32,0,50,51,56,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,24,149,91,7,4,0,16,1,50,51,56,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,239,11,12,38,5,0,64,0,50,51,56,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,158,213,215,74,5,0,64,0,115,102,105,105,105,51,95,117,115,97,46,50,57,102,52,48,48,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,193,69,197,236,0,0,0,3,115,102,105,105,105,51,40,95,95,57,57,48,53,49,50,41,45,115,105,109,109,49,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,53,98,230,102,0,0,16,1,115,102,105,105,105,51,40,95,95,57,57,48,53,49,50,41,45,115,105,109,109,49,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,95,140,110,24,0,0,16,1,115,102,105,105,105,51,40,95,95,57,57,48,53,49,50,41,45,115,105,109,109,49,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,171,140,225,188,0,0,16,1,115,102,105,105,105,51,40,95,95,57,57,48,53,49,50,41,45,115,105,109,109,49,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,201,194,157,18,0,0,16,1,115,102,105,105,105,51,45,115,105,109,109,50,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,158,150,235,6,0,0,16,1,115,102,105,105,105,51,45,115,105,109,109,50,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,130,159,3,231,0,0,16,1,115,102,105,105,105,51,45,115,105,109,109,50,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,247,150,92,100,0,0,16,1,115,102,105,105,105,51,45,115,105,109,109,50,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,177,250,14,97,0,0,16,1,115,102,105,105,105,51,45,115,105,109,109,51,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,121,31,170,123,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,51,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,254,248,75,35,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,51,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,8,195,235,217,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,51,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,119,186,60,41,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,51,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,71,231,85,96,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,51,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,252,166,154,73,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,51,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,158,135,19,108,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,51,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,222,142,79,207,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,52,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,186,213,31,9,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,52,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,23,137,202,11,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,52,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,139,87,253,160,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,52,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,153,198,248,75,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,52,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,133,135,123,19,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,52,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,113,6,183,79,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,52,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,164,116,35,131,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,52,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,109,87,136,28,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,53,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,144,145,125,198,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,53,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,104,152,183,108,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,53,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,14,147,105,223,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,53,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,224,84,55,51,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,53,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,23,212,246,120,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,53,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,177,217,202,140,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,53,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,229,89,222,133,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,53,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,179,41,126,238,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,54,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,66,144,166,141,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,54,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,196,122,140,28,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,54,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,29,52,113,166,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,54,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,73,2,153,26,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,54,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,172,57,203,32,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,54,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,47,75,132,95,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,54,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,40,141,14,69,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,54,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,135,65,95,204,0,0,32,0,115,102,105,105,105,51,95,106,97,112,97,110,95,110,111,99,100,46,50,57,102,52,48,48,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,102,99,220,30,0,0,0,3,115,102,105,105,105,51,40,95,95,57,57,48,53,49,50,41,45,115,105,109,109,49,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,53,98,230,102,0,0,16,1,115,102,105,105,105,51,40,95,95,57,57,48,53,49,50,41,45,115,105,109,109,49,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,95,140,110,24,0,0,16,1,115,102,105,105,105,51,40,95,95,57,57,48,53,49,50,41,45,115,105,109,109,49,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,171,140,225,188,0,0,16,1,115,102,105,105,105,51,40,95,95,57,57,48,53,49,50,41,45,115,105,109,109,49,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,201,194,157,18,0,0,16,1,115,102,105,105,105,51,45,115,105,109,109,50,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,158,150,235,6,0,0,16,1,115,102,105,105,105,51,45,115,105,109,109,50,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,130,159,3,231,0,0,16,1,115,102,105,105,105,51,45,115,105,109,109,50,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,247,150,92,100,0,0,16,1,115,102,105,105,105,51,45,115,105,109,109,50,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,177,250,14,97,0,0,16,1,115,102,105,105,105,51,45,115,105,109,109,51,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,121,31,170,123,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,51,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,254,248,75,35,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,51,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,8,195,235,217,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,51,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,119,186,60,41,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,51,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,71,231,85,96,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,51,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,252,166,154,73,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,51,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,158,135,19,108,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,51,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,222,142,79,207,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,52,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,186,213,31,9,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,52,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,23,137,202,11,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,52,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,139,87,253,160,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,52,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,153,198,248,75,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,52,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,133,135,123,19,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,52,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,113,6,183,79,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,52,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,164,116,35,131,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,52,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,109,87,136,28,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,53,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,144,145,125,198,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,53,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,104,152,183,108,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,53,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,14,147,105,223,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,53,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,224,84,55,51,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,53,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,23,212,246,120,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,53,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,177,217,202,140,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,53,46,54,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,229,89,222,133,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,53,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,179,41,126,238,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,54,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,66,144,166,141,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,54,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,196,122,140,28,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,54,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,29,52,113,166,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,54,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,73,2,153,26,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,54,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,172,57,203,32,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,54,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,47,75,132,95,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,54,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,40,141,14,69,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,54,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,135,65,95,204,0,0,32,0,50,55,50,45,112,49,99,97,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,221,8,10,195,1,0,16,1,50,55,50,45,112,50,99,97,46,115,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,24,165,100,189,1,0,16,1,50,55,50,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,26,102,151,79,3,0,32,0,50,55,50,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,79,218,175,163,3,0,32,0,50,55,50,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,2,117,60,140,3,0,32,0,50,55,50,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,226,226,213,50,3,0,32,0,50,55,50,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,188,133,224,108,3,0,32,0,50,55,50,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,142,220,200,5,3,0,32,0,50,55,50,45,99,55,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,66,183,23,20,3,0,32,0,50,55,50,45,99,56,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,205,115,151,212,3,0,32,0,50,55,50,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,64,191,238,173,4,0,16,1,50,55,50,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,39,65,169,118,5,0,64,0,50,55,50,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,241,7,165,75,5,0,64,0,111,49,55,95,48,57,120,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,62,224,114,52,0,0,16,1,111,49,55,95,49,48,120,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,181,73,172,163,0,0,16,1,111,49,55,95,49,49,105,105,46,55,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,120,195,234,107,0,0,16,1,111,49,55,95,49,50,105,105,46,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,181,110,219,106,0,0,16,1,111,49,55,95,48,53,46,49,50,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,248,21,83,86,0,0,32,0,111,49,55,95,48,54,46,49,51,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,76,45,38,149,0,0,32,0,111,49,55,95,48,55,46,49,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,92,115,75,76,0,0,32,0,111,49,55,95,48,56,46,49,51,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,108,88,198,149,0,0,32,0,111,49,55,95,48,49,46,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,145,228,18,234,0,0,32,0,111,49,55,95,48,50,46,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,159,58,161,50,0,0,32,0,111,49,55,95,48,51,46,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,201,61,114,104,0,0,32,0,111,49,55,95,48,52,46,55,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,19,203,14,254,0,0,32,0,112,114,111,109,49,52,46,50,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,237,204,136,188,0,0,32,0,112,114,111,109,49,53,46,50,48,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,146,116,225,161,0,0,32,0,104,100,54,52,55,49,56,48,46,48,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,24,98,112,115,109,57,52,53,97,46,117,52,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,21,149,140,137,0,0,16,1,98,112,115,109,46,117,52,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,128,78,8,50,0,0,16,1,98,112,115,109,57,52,53,97,46,117,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,72,229,141,67,0,0,16,1,98,112,115,109,46,117,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,186,165,67,162,0,0,32,0,98,112,115,109,46,117,55,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,172,164,121,81,0,0,32,0,98,112,115,109,46,117,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,131,95,177,185,0,0,32,0,98,112,115,109,46,117,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,157,103,0,143,0,0,32,0,98,112,115,109,46,117,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,99,123,190,134,0,0,32,0,98,112,115,109,46,117,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,59,168,187,224,0,0,32,0,98,112,115,109,46,117,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,172,191,227,161,0,0,32,0,98,112,115,109,46,117,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,82,75,1,106,0,0,32,0,98,112,115,109,46,117,54,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,192,104,36,153,0,0,32,0,98,112,115,109,46,117,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,181,183,15,246,0,0,32,0,98,112,115,109,46,117,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,28,211,89,101,0,0,32,0,98,112,115,109,46,117,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,180,86,122,213,0,0,32,0,98,112,115,109,46,117,52,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,209,78,142,73,0,0,64,0,98,112,115,109,46,117,52,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,185,1,41,15,0,0,64,0,115,97,105,108,111,114,109,110,95,117,115,97,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,227,171,21,57,0,0,16,1,98,112,115,109,57,52,53,97,46,117,52,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,21,149,140,137,0,0,16,1,98,112,115,109,46,117,52,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,128,78,8,50,0,0,16,1,98,112,115,109,57,52,53,97,46,117,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,72,229,141,67,0,0,16,1,98,112,115,109,46,117,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,186,165,67,162,0,0,32,0,98,112,115,109,46,117,55,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,172,164,121,81,0,0,32,0,98,112,115,109,46,117,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,131,95,177,185,0,0,32,0,98,112,115,109,46,117,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,157,103,0,143,0,0,32,0,98,112,115,109,46,117,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,99,123,190,134,0,0,32,0,98,112,115,109,46,117,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,59,168,187,224,0,0,32,0,98,112,115,109,46,117,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,172,191,227,161,0,0,32,0,98,112,115,109,46,117,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,82,75,1,106,0,0,32,0,98,112,115,109,46,117,54,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,192,104,36,153,0,0,32,0,98,112,115,109,46,117,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,181,183,15,246,0,0,32,0,98,112,115,109,46,117,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,28,211,89,101,0,0,32,0,98,112,115,109,46,117,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,180,86,122,213,0,0,32,0,98,112,115,109,46,117,52,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,209,78,142,73,0,0,64,0,98,112,115,109,46,117,52,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,185,1,41,15,0,0,64,0,115,97,105,108,111,114,109,110,95,116,97,105,119,97,110,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,42,140,126,108,0,0,16,1,115,109,112,114,103,46,117,52,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,17,79,35,0,0,16,1,98,112,115,109,46,117,52,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,128,78,8,50,0,0,16,1,98,112,115,109,57,52,53,97,46,117,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,72,229,141,67,0,0,16,1,98,112,115,109,46,117,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,186,165,67,162,0,0,32,0,98,112,115,109,46,117,55,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,172,164,121,81,0,0,32,0,98,112,115,109,46,117,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,131,95,177,185,0,0,32,0,98,112,115,109,46,117,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,157,103,0,143,0,0,32,0,98,112,115,109,46,117,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,99,123,190,134,0,0,32,0,98,112,115,109,46,117,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,59,168,187,224,0,0,32,0,98,112,115,109,46,117,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,172,191,227,161,0,0,32,0,98,112,115,109,46,117,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,82,75,1,106,0,0,32,0,98,112,115,109,46,117,54,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,192,104,36,153,0,0,32,0,98,112,115,109,46,117,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,181,183,15,246,0,0,32,0,98,112,115,109,46,117,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,28,211,89,101,0,0,32,0,98,112,115,109,46,117,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,180,86,122,213,0,0,32,0,98,112,115,109,46,117,52,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,209,78,142,73,0,0,64,0,98,112,115,109,46,117,52,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,185,1,41,15,0,0,64,0,115,97,105,108,111,114,109,110,95,101,117,114,111,112,101,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,80,220,167,89,0,0,16,1,98,112,115,109,57,52,53,97,46,117,52,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,21,149,140,137,0,0,16,1,98,112,115,109,46,117,52,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,128,78,8,50,0,0,16,1,98,112,115,109,57,52,53,97,46,117,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,72,229,141,67,0,0,16,1,98,112,115,109,46,117,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,186,165,67,162,0,0,32,0,98,112,115,109,46,117,55,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,172,164,121,81,0,0,32,0,98,112,115,109,46,117,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,131,95,177,185,0,0,32,0,98,112,115,109,46,117,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,157,103,0,143,0,0,32,0,98,112,115,109,46,117,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,99,123,190,134,0,0,32,0,98,112,115,109,46,117,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,59,168,187,224,0,0,32,0,98,112,115,109,46,117,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,172,191,227,161,0,0,32,0,98,112,115,109,46,117,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,82,75,1,106,0,0,32,0,98,112,115,109,46,117,54,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,192,104,36,153,0,0,32,0,98,112,115,109,46,117,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,181,183,15,246,0,0,32,0,98,112,115,109,46,117,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,28,211,89,101,0,0,32,0,98,112,115,109,46,117,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,180,86,122,213,0,0,32,0,98,112,115,109,46,117,52,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,209,78,142,73,0,0,64,0,98,112,115,109,46,117,52,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,185,1,41,15,0,0,64,0,115,97,105,108,111,114,109,110,95,107,111,114,101,97,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,152,227,125,14,0,0,16,1,98,112,115,109,57,52,53,97,46,117,52,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,21,149,140,137,0,0,16,1,98,112,115,109,46,117,52,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,128,78,8,50,0,0,16,1,98,112,115,109,57,52,53,97,46,117,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,72,229,141,67,0,0,16,1,98,112,115,109,46,117,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,186,165,67,162,0,0,32,0,98,112,115,109,46,117,55,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,172,164,121,81,0,0,32,0,98,112,115,109,46,117,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,131,95,177,185,0,0,32,0,98,112,115,109,46,117,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,157,103,0,143,0,0,32,0,98,112,115,109,46,117,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,99,123,190,134,0,0,32,0,98,112,115,109,46,117,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,59,168,187,224,0,0,32,0,98,112,115,109,46,117,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,172,191,227,161,0,0,32,0,98,112,115,109,46,117,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,82,75,1,106,0,0,32,0,98,112,115,109,46,117,54,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,192,104,36,153,0,0,32,0,98,112,115,109,46,117,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,181,183,15,246,0,0,32,0,98,112,115,109,46,117,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,28,211,89,101,0,0,32,0,98,112,115,109,46,117,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,180,86,122,213,0,0,32,0,98,112,115,109,46,117,52,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,209,78,142,73,0,0,64,0,98,112,115,109,46,117,52,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,185,1,41,15,0,0,64,0,115,97,105,108,111,114,109,110,95,106,97,112,97,110,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,10,195,3,234,0,0,16,1,98,112,115,109,57,52,53,97,46,117,52,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,21,149,140,137,0,0,16,1,98,112,115,109,46,117,52,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,128,78,8,50,0,0,16,1,98,112,115,109,57,52,53,97,46,117,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,72,229,141,67,0,0,16,1,98,112,115,109,46,117,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,186,165,67,162,0,0,32,0,98,112,115,109,46,117,55,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,172,164,121,81,0,0,32,0,98,112,115,109,46,117,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,131,95,177,185,0,0,32,0,98,112,115,109,46,117,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,157,103,0,143,0,0,32,0,98,112,115,109,46,117,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,99,123,190,134,0,0,32,0,98,112,115,109,46,117,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,59,168,187,224,0,0,32,0,98,112,115,109,46,117,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,172,191,227,161,0,0,32,0,98,112,115,109,46,117,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,82,75,1,106,0,0,32,0,98,112,115,109,46,117,54,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,192,104,36,153,0,0,32,0,98,112,115,109,46,117,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,181,183,15,246,0,0,32,0,98,112,115,109,46,117,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,28,211,89,101,0,0,32,0,98,112,115,109,46,117,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,180,86,122,213,0,0,32,0,98,112,115,109,46,117,52,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,209,78,142,73,0,0,64,0,98,112,115,109,46,117,52,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,185,1,41,15,0,0,64,0,115,97,105,108,111,114,109,110,95,104,111,110,103,107,111,110,103,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,116,200,36,77,0,0,16,1,115,98,49,46,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,226,101,111,223,1,0,16,1,115,98,50,46,55,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,184,26,44,13,1,0,16,1,105,99,51,53,46,115,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,157,201,123,235,3,0,32,0,105,99,51,50,46,115,98,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,5,34,198,36,4,0,32,0,105,99,49,48,48,46,115,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,110,22,15,178,5,0,32,0,105,99,51,48,46,115,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,175,7,132,40,6,0,64,0,105,99,50,55,46,115,98,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,126,58,227,67,7,0,64,0,255,7,0,0,0,0,0,0,114,111,98,111,48,51,46,107,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,201,108,201,244,1,0,16,1,114,111,98,111,48,55,46,107,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,124,58,229,17,1,0,16,1,114,111,98,111,48,50,46,106,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,13,106,8,250,1,0,16,1,114,111,98,111,48,54,46,106,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,208,73,59,112,1,0,16,1,103,111,45,48,49,45,49,46,104,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,192,86,83,171,1,0,16,1,103,111,45,48,53,45,49,46,104,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,165,189,33,206,1,0,16,1,103,111,45,48,48,46,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,234,105,51,169,1,0,16,1,103,111,45,48,52,46,102,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,217,106,47,238,1,0,16,1,103,112,45,48,57,46,107,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,141,15,78,74,2,0,16,1,103,112,49,48,45,49,46,121,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,156,113,93,210,3,0,32,0,103,112,49,49,45,49,46,122,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,71,237,13,3,3,0,32,0,109,97,104,45,48,52,46,122,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,140,161,108,155,4,0,32,0,109,97,104,45,48,51,46,121,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,220,77,137,55,4,0,32,0,109,97,104,45,48,49,46,122,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,255,223,224,38,5,0,32,0,109,97,104,45,48,48,46,121,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,65,158,214,123,5,0,32,0,109,97,104,45,48,50,46,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,125,36,138,50,5,0,32,0,109,97,104,45,48,53,46,121,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,19,230,115,103,6,0,32,0,109,97,104,45,48,56,46,121,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,165,16,211,136,6,0,32,0,109,97,104,45,48,54,46,122,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,138,128,168,39,6,0,32,0,109,97,104,45,48,57,46,122,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,167,67,140,165,6,0,32,0,109,97,104,45,48,55,46,97,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,144,65,111,82,6,0,32,0,109,97,104,45,49,48,46,97,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,218,112,183,20,6,0,32,0,103,112,45,48,56,46,106,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,177,131,81,54,7,0,64,0,109,97,104,45,49,49,46,102,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,146,198,43,100,8,0,64,0,103,111,45,49,50,46,118,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,79,103,143,39,0,0,0,8,103,111,45,48,51,45,49,46,107,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,8,102,80,82,1,0,16,1,103,111,45,48,55,45,49,46,107,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,23,218,156,115,1,0,16,1,103,111,45,48,50,45,49,46,106,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,233,172,192,72,1,0,16,1,103,111,45,48,54,45,49,46,106,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,135,236,171,65,1,0,16,1,103,111,45,48,49,45,49,46,104,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,192,86,83,171,1,0,16,1])
.concat([103,111,45,48,53,45,49,46,104,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,165,189,33,206,1,0,16,1,103,111,45,48,48,46,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,234,105,51,169,1,0,16,1,103,111,45,48,52,46,102,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,217,106,47,238,1,0,16,1,103,112,45,48,57,46,107,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,141,15,78,74,2,0,16,1,103,112,49,48,45,49,46,121,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,156,113,93,210,3,0,32,0,103,112,49,49,45,49,46,122,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,71,237,13,3,3,0,32,0,109,97,104,45,48,52,46,122,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,140,161,108,155,4,0,32,0,109,97,104,45,48,51,46,121,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,220,77,137,55,4,0,32,0,109,97,104,45,48,49,46,122,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,255,223,224,38,5,0,32,0,109,97,104,45,48,48,46,121,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,65,158,214,123,5,0,32,0,109,97,104,45,48,50,46,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,125,36,138,50,5,0,32,0,109,97,104,45,48,53,46,121,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,19,230,115,103,6,0,32,0,109,97,104,45,48,56,46,121,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,165,16,211,136,6,0,32,0,109,97,104,45,48,54,46,122,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,138,128,168,39,6,0,32,0,109,97,104,45,48,57,46,122,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,167,67,140,165,6,0,32,0,109,97,104,45,48,55,46,97,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,144,65,111,82,6,0,32,0,109,97,104,45,49,48,46,97,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,218,112,183,20,6,0,32,0,103,112,45,48,56,46,106,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,177,131,81,54,7,0,64,0,109,97,104,45,49,49,46,102,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,146,198,43,100,8,0,64,0,103,111,45,49,50,46,118,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,79,103,143,39,0,0,0,8,117,49,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,11,96,49,63,1,0,16,1,117,49,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,180,74,164,218,1,0,16,1,117,57,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,194,85,75,134,2,0,16,1,117,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,148,35,25,3,0,32,0,97,102,101,103,97,95,97,102,49,45,98,50,46,117,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,194,136,133,214,4,0,32,0,97,102,101,103,97,95,97,102,49,45,98,49,46,117,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,168,0,178,248,4,0,32,0,97,102,101,103,97,95,97,102,49,45,115,112,46,117,99,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,133,73,77,125,5,0,32,0,97,102,101,103,97,49,46,117,57,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,51,206,17,233,6,0,64,0,50,50,51,45,112,49,107,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,145,131,140,183,1,0,16,1,50,50,51,45,112,50,46,115,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,8,143,221,173,1,0,16,1,50,50,51,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,140,110,205,126,2,0,32,0,50,50,51,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,226,5,171,235,3,0,32,0,50,50,51,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,195,104,24,100,3,0,32,0,50,50,51,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,31,25,0,202,3,0,32,0,50,50,51,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,96,216,35,31,3,0,32,0,50,50,51,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,44,54,30,50,3,0,32,0,50,50,51,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,144,239,252,216,3,0,32,0,50,50,51,45,99,55,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,45,221,128,188,3,0,32,0,50,50,51,45,99,56,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,2,33,214,90,3,0,32,0,50,50,51,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,191,70,238,63,4,0,16,1,50,50,51,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,105,56,103,118,5,0,64,0,50,50,51,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,205,90,39,122,5,0,64,0,50,50,51,45,118,51,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,210,127,121,90,5,0,64,0,0,0,0,0,0,0,0,0,116,114,115,48,49,95,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,13,158,148,64,1,0,0,0,116,114,115,48,49,95,53,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,159,196,168,175,1,0,0,0,116,114,115,48,49,95,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,61,38,184,81,1,0,0,0,116,114,115,48,49,95,53,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,247,1,1,31,1,0,0,0,116,114,115,48,49,53,97,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,76,85,102,81,2,0,0,0,116,114,115,48,49,118,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,14,51,149,240,4,0,0,0,116,114,115,48,49,118,51,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,240,22,163,21,4,0,0,0,116,114,115,48,49,118,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,185,13,187,224,5,0,0,0,116,114,115,48,49,118,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,173,125,78,108,5,0,0,0,116,114,115,48,49,118,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,241,99,221,111,5,0,0,0,116,114,115,48,49,118,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,85,39,246,187,5,0,0,0,116,114,115,48,49,99,50,106,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,135,124,8,42,8,0,0,0,116,114,115,48,49,99,50,107,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,175,93,12,101,8,0,0,0,116,114,115,48,49,99,50,108,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,16,121,8,35,8,0,0,0,116,114,115,48,49,49,104,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,194,80,204,219,6,0,0,0,116,114,115,48,49,101,51,107,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,156,152,111,108,7,0,0,0,116,114,115,48,49,52,104,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,140,180,241,209,3,0,0,0,116,114,115,48,49,118,49,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,21,131,130,27,8,0,0,0,49,50,51,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,174,94,243,166,1,0,16,1,49,50,51,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,138,147,222,83,2,0,32,0,49,50,51,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,6,166,121,229,3,0,32,0,49,50,51,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,55,200,130,225,3,0,32,0,49,50,51,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,249,83,127,214,4,0,16,1,49,50,51,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,249,74,111,152,5,0,64,0,103,48,50,106,46,117,52,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,215,171,208,66,0,0,16,1,103,48,50,106,46,117,52,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,243,122,43,54,0,0,16,1,103,48,50,106,46,117,52,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,107,89,76,201,0,0,16,1,103,48,50,106,46,117,52,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,112,130,76,79,0,0,16,1,103,48,50,106,46,117,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,241,1,173,238,0,0,16,1,103,48,50,46,117,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,152,3,227,145,0,0,32,0,103,48,50,46,117,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,215,93,69,217,0,0,32,0,103,48,50,46,117,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,11,86,32,77,0,0,32,0,103,48,50,46,117,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,110,155,123,177,0,0,32,0,103,48,50,46,117,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,120,24,84,8,0,0,32,0,103,48,50,46,117,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,54,42,207,190,0,0,32,0,103,48,50,46,117,54,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,139,43,254,82,0,0,32,0,103,48,50,46,117,55,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,210,99,202,30,0,0,32,0,103,48,50,46,117,56,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,133,246,63,138,0,0,32,0,103,48,50,46,117,56,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,115,31,62,55,0,0,32,0,103,48,50,106,46,56,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,225,111,232,59,0,0,32,0,103,48,50,46,117,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,224,217,189,196,0,0,64,0,103,48,50,46,117,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,14,213,87,19,0,0,64,0,103,48,50,46,117,53,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,152,40,16,45,0,0,64,0,103,48,50,46,117,53,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,218,13,245,159,0,0,64,0,57,48,55,122,48,50,46,105,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,137,92,58,122,0,0,16,1,57,48,55,122,48,51,46,105,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,214,217,163,34,0,0,16,1,57,48,55,102,48,49,46,101,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,132,196,64,240,0,0,16,1,57,48,55,100,48,54,46,101,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,244,56,204,245,0,0,32,0,57,48,55,100,48,53,46,101,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,193,116,87,226,0,0,32,0,57,48,55,100,48,55,46,107,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,67,69,254,176,0,0,32,0,57,48,55,100,48,56,46,107,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,157,141,172,213,0,0,32,0,57,48,55,100,48,52,46,100,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,94,235,15,9,0,0,64,0,57,48,55,109,48,50,46,105,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,117,69,225,89,0,0,16,1,57,48,55,109,48,51,46,105,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,30,75,177,173,0,0,16,1,57,48,55,102,48,49,46,101,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,132,196,64,240,0,0,16,1,57,48,55,100,48,54,46,101,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,244,56,204,245,0,0,32,0,57,48,55,100,48,53,46,101,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,193,116,87,226,0,0,32,0,57,48,55,100,48,55,46,107,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,67,69,254,176,0,0,32,0,57,48,55,100,48,56,46,107,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,157,141,172,213,0,0,32,0,57,48,55,100,48,52,46,100,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,94,235,15,9,0,0,64,0,112,111,112,49,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,74,124,2,157,1,0,16,1,112,111,112,53,46,54,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,137,113,76,25,1,0,16,1,112,111,112,50,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,187,40,162,91,1,0,16,1,112,111,112,54,46,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,30,70,245,186,1,0,16,1,112,111,112,51,46,54,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,74,156,65,8,1,0,16,1,112,111,112,55,46,54,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,31,181,116,171,1,0,16,1,112,111,112,52,46,54,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,130,176,57,80,1,0,16,1,112,111,112,56,46,54,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,215,112,23,147,1,0,16,1,112,111,112,57,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,193,196,105,181,2,0,32,0,112,111,112,49,49,46,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,157,184,145,53,2,0,32,0,112,111,112,49,48,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,164,181,79,1,2,0,32,0,112,111,112,49,50,46,53,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,100,28,185,33,2,0,32,0,56,50,115,49,50,51,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,189,80,198,47,3,0,32,0,56,50,115,49,50,54,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,228,168,179,62,3,0,32,0,56,50,115,49,50,54,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,134,204,169,4,0,64,0,56,50,115,49,50,54,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,184,40,2,0,1,0,0,0,85,0,147,0,248,191,2,0,184,164,8,0,1,0,0,0,86,0,147,0,64,246,1,0,56,250,6,0,1,0,0,0,189,247,146,0,184,160,2,0,88,149,7,0,1,0,0,0,190,247,146,0,136,224,1,0,56,210,6,0,1,0,0,0,80,0,147,0,192,135,2,0,152,122,6,0,1,0,0,0,81,0,147,0,96,82,2,0,192,72,6,0,1,0,0,0,82,0,147,0,32,56,2,0,24,163,6,0,1,0,0,0,83,0,147,0,240,108,2,0,144,0,6,0,1,0,0,0,84,0,147,0,152,30,2,0,176,223,1,0,1,0,0,0,184,247,146,0,72,198,1,0,24,198,1,0,1,0,0,0,185,247,146,0,40,167,1,0,120,189,1,0,1,0,0,0,186,247,146,0,200,149,1,0,192,209,1,0,1,0,0,0,187,247,146,0,24,182,1,0,160,192,3,0,1,0,0,0,188,247,146,0,152,30,2,0,88,212,3,0,1,0,0,0,128,219,146,0,40,185,3,0,232,75,4,0,1,0,0,0,87,0,147,0,216,70,1,0,64,23,5,0,9,0,0,0,202,5,147,0,32,58,1,0,104,20,5,0,9,0,0,0,203,5,147,0,32,58,1,0,216,16,5,0,9,0,0,0,200,5,147,0,32,58,1,0,88,12,5,0,9,0,0,0,201,5,147,0,32,58,1,0,112,114,111,103,46,117,52,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,178,61,245,148,0,0,16,1,112,114,111,103,46,117,52,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,86,215,10,219,0,0,16,1,112,114,49,50,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,89,37,32,14,0,0,16,1,112,114,49,50,46,117,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,33,47,116,84,0,0,16,1,100,49,53,46,117,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,192,206,82,99,0,0,16,1,100,49,55,46,117,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,216,16,248,122,0,0,16,1,115,111,117,110,100,46,117,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,32,21,247,54,0,0,16,1,103,48,50,46,117,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,152,3,227,145,0,0,32,0,103,48,50,46,117,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,215,93,69,217,0,0,32,0,103,48,50,46,117,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,11,86,32,77,0,0,32,0,103,48,50,46,117,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,110,155,123,177,0,0,32,0,103,48,50,46,117,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,120,24,84,8,0,0,32,0,103,48,50,46,117,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,54,42,207,190,0,0,32,0,97,116,103,115,46,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,169,52,111,170,0,0,32,0,97,116,103,115,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,39,218,62,85,0,0,32,0,97,116,103,115,46,117,55,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,203,14,113,22,0,0,32,0,97,116,103,115,46,117,56,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,145,202,42,203,0,0,32,0,97,116,103,115,46,117,56,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,15,90,244,101,0,0,32,0,116,101,120,116,46,117,56,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,234,51,115,245,0,0,32,0,103,48,50,46,117,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,224,217,189,196,0,0,64,0,103,48,50,46,117,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,14,213,87,19,0,0,64,0,103,48,50,46,117,53,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,152,40,16,45,0,0,64,0,103,48,50,46,117,53,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,218,13,245,159,0,0,64,0,107,103,48,48,45,50,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,55,65,220,98,1,0,16,1,109,97,122,45,48,50,46,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,89,90,211,201,2,0,32,0,109,97,122,45,48,48,46,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,244,113,48,250,3,0,32,0,109,97,122,45,48,49,46,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,33,254,52,73,3,0,32,0,107,101,48,49,46,49,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,99,98,16,138,4,0,64,0,109,97,122,45,48,51,46,49,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,100,201,19,163,5,0,64,0,112,105,112,95,99,112,117,95,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,189,5,50,174,0,0,16,1,112,105,112,95,99,112,117,95,111,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,169,105,22,36,0,0,16,1,99,103,95,48,49,95,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,70,239,209,33,0,0,32,0,99,103,95,48,49,95,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,40,99,114,213,0,0,32,0,99,103,95,50,51,95,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,208,65,77,17,0,0,32,0,99,103,95,50,51,95,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,129,70,224,0,0,32,0,112,105,112,95,115,110,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,59,24,191,142,0,0,16,1,116,112,48,50,53,45,49,46,97,108,116,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,152,45,82,62,0,0,16,1,116,112,48,50,53,45,50,46,97,108,116,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,133,4,55,72,0,0,16,1,116,112,48,50,53,45,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,68,247,151,171,0,0,32,0,116,112,48,50,53,45,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,30,16,22,123,0,0,32,0,116,112,48,50,53,45,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,229,253,143,191,0,0,16,1,168,86,7,0,1,0,0,0,160,191,145,0,248,191,2,0,24,38,7,0,1,0,0,0,127,253,146,0,184,160,2,0,56,210,6,0,1,0,0,0,122,253,146,0,192,135,2,0,24,163,6,0,1,0,0,0,123,253,146,0,240,108,2,0,152,122,6,0,1,0,0,0,120,253,146,0,96,82,2,0,192,72,6,0,1,0,0,0,121,253,146,0,32,56,2,0,200,110,3,0,1,0,0,0,124,253,146,0,152,30,2,0,120,89,3,0,1,0,0,0,125,253,146,0,232,10,2,0,40,246,1,0,1,0,0,0,161,191,145,0,64,246,1,0,144,236,1,0,1,0,0,0,47,245,146,0,136,224,1,0,176,223,1,0,1,0,0,0,42,245,146,0,72,198,1,0,192,209,1,0,1,0,0,0,43,245,146,0,24,182,1,0,24,198,1,0,1,0,0,0,40,245,146,0,40,167,1,0,120,189,1,0,1,0,0,0,41,245,146,0,200,149,1,0,224,22,1,0,1,0,0,0,44,245,146,0,56,126,1,0,160,14,1,0,1,0,0,0,45,245,146,0,32,101,1,0,88,212,3,0,1,0,0,0,168,217,146,0,40,185,3,0,32,77,1,0,1,0,0,0,163,191,145,0,216,70,1,0,16,17,8,0,1,0,0,0,162,191,145,0,224,12,8,0,72,65,1,0,9,0,0,0,35,224,146,0,32,58,1,0,48,50,1,0,9,0,0,0,36,224,146,0,32,58,1,0,119,45,114,105,110,103,32,45,32,116,104,101,32,100,111,117,98,108,101,32,114,105,110,103,115,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,16,0,153,190,0,0,16,1,116,105,116,97,110,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,47,56,15,210,0,0,16,1,115,117,112,101,114,32,109,111,109,111,116,97,114,111,117,32,100,101,110,116,101,116,115,117,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,74,48,181,62,0,0,16,1,115,116,114,101,101,116,32,102,105,103,104,116,101,114,32,105,105,39,32,45,32,99,104,97,109,112,105,111,110,32,101,100,105,116,105,111,110,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,0,187,182,92,209,0,0,16,1,112,111,119,101,114,32,103,111,108,102,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,7,79,50,234,0,0,16,1,109,111,109,111,116,97,114,111,117,32,100,101,110,115,101,116,115,117,32,105,105,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,154,84,225,217,0,0,16,1,108,111,100,101,32,114,117,110,110,101,114,32,45,32,108,111,115,116,32,108,97,98,121,114,105,110,116,104,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,104,20,238,230,0,0,16,1,106,105,110,109,117,32,100,101,110,115,104,111,117,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,122,99,80,193,0,0,16,1,106,97,99,107,105,101,32,99,104,97,110,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,115,99,250,198,0,0,16,1,102,117,115,104,105,103,105,32,110,111,32,121,117,109,101,32,110,111,32,97,108,105,99,101,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,253,230,196,18,0,0,16,1,117,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,243,158,30,172,1,0,16,1,117,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,56,229,170,156,2,0,32,0,117,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,148,212,154,232,3,0,32,0,117,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,235,215,66,75,3,0,32,0,117,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,138,54,36,244,4,0,16,1,117,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,196,203,64,8,5,0,64,0,117,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0])
.concat([72,137,84,10,5,0,64,0,57,53,53,101,48,49,46,102,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,52,163,186,73,1,0,16,1,57,53,53,101,48,50,46,104,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,111,13,1,20,1,0,16,1,57,53,53,101,48,51,46,100,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,86,163,10,148,2,0,16,1,57,53,53,100,48,55,46,107,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,63,71,137,3,0,32,0,57,53,53,100,48,56,46,107,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,161,205,213,67,3,0,32,0,57,53,53,100,48,53,46,107,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,224,85,30,122,4,0,32,0,57,53,53,100,48,54,46,107,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,117,40,37,244,4,0,32,0,57,53,53,100,48,52,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,26,73,113,230,5,0,64,0,50,46,102,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,11,65,166,38,1,0,16,1,51,46,104,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,242,219,16,148,1,0,16,1,57,53,53,101,48,51,46,100,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,86,163,10,148,2,0,16,1,57,53,53,100,48,55,46,107,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,63,71,137,3,0,32,0,57,53,53,100,48,56,46,107,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,161,205,213,67,3,0,32,0,57,53,53,100,48,53,46,107,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,224,85,30,122,4,0,32,0,57,53,53,100,48,54,46,107,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,117,40,37,244,4,0,32,0,57,53,53,100,48,52,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,26,73,113,230,5,0,64,0,98,45,49,56,46,102,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,205,86,99,0,1,0,16,1,98,45,49,57,46,104,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,23,100,161,229,1,0,16,1,57,53,53,101,48,51,46,100,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,86,163,10,148,2,0,16,1,57,53,53,100,48,55,46,107,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,63,71,137,3,0,32,0,57,53,53,100,48,56,46,107,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,161,205,213,67,3,0,32,0,57,53,53,100,48,53,46,107,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,224,85,30,122,4,0,32,0,57,53,53,100,48,54,46,107,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,117,40,37,244,4,0,32,0,57,53,53,100,48,52,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,26,73,113,230,5,0,64,0,112,108,49,95,49,46,56,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,148,251,41,247,1,0,16,1,112,108,49,95,50,46,56,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,111,235,102,92,1,0,16,1,112,108,49,95,51,46,56,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,57,167,159,170,1,0,16,1,112,108,49,95,52,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,144,90,137,43,1,0,16,1,112,108,49,95,53,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,98,246,122,1,0,16,1,112,108,49,95,54,46,56,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,169,89,30,176,1,0,16,1,112,108,49,95,55,46,51,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,174,236,91,140,2,0,16,1,99,117,115,54,48,45,54,48,97,49,46,109,99,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,42,168,110,7,2,0,16,1,112,108,49,95,49,50,46,54,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,206,251,89,193,3,0,32,0,112,108,49,95,49,51,46,54,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,174,217,94,108,4,0,32,0,112,108,49,95,57,98,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,135,138,118,128,5,0,32,0,112,108,49,95,56,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,109,228,32,43,5,0,32,0,112,108,49,95,49,48,98,46,55,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,110,214,217,255,5,0,32,0,112,108,49,95,49,49,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,216,117,151,197,5,0,32,0,112,108,49,45,50,46,49,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,222,133,40,71,6,0,32,0,112,108,49,45,49,46,49,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,175,189,142,167,6,0,32,0,112,108,49,45,53,46,53,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,18,231,126,75,6,0,32,0,112,108,49,45,52,46,52,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,24,228,123,58,6,0,32,0,112,108,49,45,51,46,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,168,141,85,128,6,0,32,0,168,86,7,0,1,0,0,0,99,191,145,0,248,191,2,0,24,38,7,0,1,0,0,0,101,191,145,0,184,160,2,0,56,210,6,0,1,0,0,0,112,251,146,0,192,135,2,0,24,163,6,0,1,0,0,0,113,251,146,0,240,108,2,0,152,122,6,0,1,0,0,0,114,251,146,0,96,82,2,0,192,72,6,0,1,0,0,0,115,251,146,0,32,56,2,0,200,110,3,0,1,0,0,0,116,251,146,0,152,30,2,0,120,89,3,0,1,0,0,0,117,251,146,0,232,10,2,0,120,74,3,0,1,0,0,0,118,251,146,0,152,138,8,0,40,246,1,0,1,0,0,0,100,191,145,0,64,246,1,0,144,236,1,0,1,0,0,0,102,191,145,0,136,224,1,0,176,223,1,0,1,0,0,0,64,243,146,0,72,198,1,0,192,209,1,0,1,0,0,0,65,243,146,0,24,182,1,0,24,198,1,0,1,0,0,0,66,243,146,0,40,167,1,0,120,189,1,0,1,0,0,0,67,243,146,0,200,149,1,0,224,22,1,0,1,0,0,0,68,243,146,0,56,126,1,0,160,14,1,0,1,0,0,0,69,243,146,0,32,101,1,0,176,9,1,0,1,0,0,0,70,243,146,0,96,32,8,0,88,212,3,0,1,0,0,0,40,216,146,0,40,185,3,0,32,77,1,0,1,0,0,0,96,191,145,0,216,70,1,0,72,65,1,0,9,0,0,0,146,223,146,0,32,58,1,0,48,50,1,0,9,0,0,0,147,223,146,0,32,58,1,0,224,41,1,0,9,0,0,0,149,223,146,0,32,58,1,0,52,24,0,0,198,14,0,0,180,20,0,0,118,10,0,0,224,41,0,0,78,1,0,0,78,1,0,0,78,1,0,0,198,14,0,0,198,14,0,0,198,14,0,0,198,14,0,0,198,14,0,0,198,14,0,0,198,14,0,0,198,14,0,0,103,81,243,25,160,17,225,17,16,238,227,246,190,129,53,227,251,230,239,223,97,1,250,34,93,67,1,165,59,23,212,116,240,244,243,67,181,25,4,213,132,206,135,254,53,62,196,60,199,133,42,51,0,134,208,77,101,75,249,233,192,186,170,119,158,102,246,15,79,58,182,241,100,154,233,37,26,95,34,163,162,191,75,119,63,52,201,110,219,18,92,51,165,139,108,177,116,200,64,78,47,231,70,174,153,252,176,85,84,223,167,161,15,94,73,207,86,60,144,43,172,101,110,219,88,62,201,0,174,83,77,146,250,64,178,107,101,75,144,138,12,226,165,154,208,32,41,85,164,68,172,81,135,84,83,52,36,75,129,103,52,76,95,49,78,242,241,25,24,28,52,56,225,129,23,207,36,185,154,203,52,81,80,89,68,177,11,80,149,108,72,126,20,164,198,217,211,165,214,208,197,151,240,69,208,152,81,145,159,163,67,81,5,144,238,202,126,95,114,83,177,211,175,54,8,117,176,155,224,13,67,136,170,39,68,17,249,25,243,9,160,17,224,17,16,34,253,142,211,200,49,103,192,16,60,194,3,242,106,10,84,73,202,181,75,224,148,232,141,200,144,238,107,111,250,9,118,132,111,85,209,148,202,156,225,34,198,2,181,140,249,58,82,16,240,34,228,17,21,115,94,158,222,196,90,189,163,137,231,155,149,93,117,246,195,159,228,207,101,115,144,208,117,86,250,204,228,62,156,65,129,98,177,211,40,189,108,237,96,40,39,238,242,161,180,44,108,187,66,215,29,98,192,51,125,249,228,92,226,65,164,28,152,161,135,149,173,97,86,150,64,8,107,226,75,149,123,27,216,100,179,238,157,121,105,234,93,207,1,145,234,63,112,41,220,224,8,32,191,70,144,168,252,41,20,209,13,32,121,210,44,233,82,166,140,189,163,62,136,45,184,78,242,116,80,204,18,222,211,90,164,123,162,141,145,104,18,12,156,185,109,38,102,96,195,109,208,17,51,5,29,168,182,81,230,224,88,97,116,55,204,58,77,106,10,9,113,227,126,165,59,233,115,89,243,9,160,17,225,17,16,85,24,13,232,41,45,4,133,57,136,190,139,203,217,11,50,54,148,172,116,195,59,93,42,131,70,179,58,172,216,85,104,33,87,171,110,209,208,252,226,190,99,208,107,121,35,64,88,212,231,115,34,103,127,136,5,189,223,122,101,65,144,58,82,131,40,174,233,142,101,130,14,223,152,136,225,134,33,62,26,135,109,98,122,246,175,44,213,197,16,45,169,218,147,161,155,199,53,212,21,120,24,213,117,106,215,219,18,42,106,200,54,83,87,166,240,19,103,67,121,240,14,73,177,236,205,164,138,97,6,185,234,83,242,71,125,214,248,157,46,170,39,53,97,206,155,99,188,7,81,90,194,13,57,66,210,94,33,32,16,160,229,8,247,61,40,4,153,147,151,175,249,18,192,1,45,234,243,152,11,70,194,38,147,16,105,29,113,142,51,0,94,128,47,71,10,204,148,22,231,55,69,208,97,121,50,134,8,42,91,85,254,238,82,56,170,24,233,57,26,30,184,38,107,61,75,169,6,1,243,57,160,17,240,17,16,111,50,139,253,137,41,160,74,98,237,161,45,164,73,242,16,60,119,163,132,141,250,209,198,87,226,120,239,233,182,161,90,189,63,2,11,40,214,118,252,91,25,159,33,102,76,45,69,153,222,171,70,189,233,132,196,220,199,48,112,221,100,234,188,107,211,230,69,63,7,126,80,239,178,132,51,60,204,63,57,91,245,109,113,197,221,245,249,208,247,156,230,199,173,27,41,185,144,8,117,196,195,239,168,252,171,85,124,33,87,151,135,74,203,12,86,10,79,203,82,51,135,49,243,67,91,65,144,248,192,221,90,164,38,42,96,165,109,218,242,106,240,179,218,37,51,135,34,228,172,211,150,224,153,62,251,20,69,23,37,86,190,239,143,142,61,30,199,153,162,161,80,254,223,212,161,135,244,213,222,166,140,109,108,222,71,190,89,143,212,151,195,244,218,187,166,115,169,203,242,1,185,144,143,237,96,100,64,28,182,201,165,124,23,82,111,220,109,8,42,26,230,104,63,212,66,105,127,65,243,57,160,17,241,17,16,162,76,35,19,233,37,61,15,114,58,157,181,150,209,218,7,41,65,154,173,112,186,70,99,43,127,61,190,64,173,212,76,115,39,88,167,101,220,214,253,222,181,110,214,108,117,26,50,69,213,227,106,20,109,128,132,21,175,204,123,97,81,130,64,83,127,56,160,214,143,97,121,25,229,153,132,216,120,39,63,22,151,120,79,123,12,166,55,219,198,12,36,180,199,148,157,146,210,59,213,17,111,10,219,118,102,231,205,24,43,102,216,65,64,88,162,1,30,109,68,117,231,25,79,178,232,196,150,119,98,2,201,220,89,243,67,141,200,254,158,42,186,50,59,98,227,146,110,194,8,77,81,205,249,58,62,201,80,39,33,37,151,215,14,248,57,56,245,134,148,147,191,235,24,168,252,36,245,249,153,32,61,205,44,148,37,121,40,119,143,47,16,105,134,48,67,1,215,154,23,227,71,55,189,98,117,66,120,244,43,87,76,10,219,83,77,161,10,214,58,22,21,170,44,108,57,66,18,9,243,41,160,17,240,17,16,213,102,161,40,74,33,192,211,155,134,128,87,111,65,194,228,47,11,145,189,58,122,186,0,229,53,2,116,125,139,33,87,16,15,174,68,187,226,55,24,123,82,61,140,89,158,32,31,10,204,28,142,106,215,149,43,52,176,130,109,253,37,51,170,59,43,112,21,135,49,93,187,41,25,149,213,142,36,40,94,208,32,131,70,74,33,112,91,205,174,123,97,161,250,244,43,132,21,110,54,93,27,36,15,9,58,97,56,15,24,53,17,56,180,189,238,247,236,15,29,183,72,1,170,9,143,97,181,15,29,38,57,46,140,214,38,92,61,35,99,233,107,151,180,159,123,182,186,160,124,198,37,161,115,54,103,127,116,30,29,218,112,191,165,99,53,57,36,140,159,133,22,216,80,149,113,192,246,30,109,128,237,21,235,99,233,27,246,120,49,198,92,221,25,189,223,167,236,80,34,173,187,246,235,214,163,32,201,230,159,203,242,151,185,84,18,102,166,190,74,18,67,236,0,234,73,2,164,73,243,41,160,17,241,17,16,239,128,32,61,170,54,93,152,196,210,99,223,97,176,195,194,53,212,136,230,29,58,47,156,185,209,198,67,186,105,109,73,172,221,5,224,248,232,151,25,24,8,12,66,70,199,13,37,206,195,84,178,217,66,145,234,83,152,56,120,129,18,202,21,35,189,193,112,31,210,64,253,57,51,170,39,43,232,16,125,164,168,142,61,0,79,58,127,216,150,234,158,142,21,110,159,118,87,186,125,194,223,87,66,130,244,218,137,6,5,4,98,47,41,35,84,213,187,151,245,249,193,207,236,95,29,253,187,166,215,74,168,102,191,185,9,68,177,96,40,169,53,22,21,245,19,193,7,126,215,64,223,142,211,50,169,53,152,21,50,169,73,192,36,180,74,83,107,121,170,119,108,197,136,105,229,93,222,66,40,249,183,92,171,25,199,188,197,96,235,94,168,82,196,50,124,53,2,6,70,119,48,182,51,75,184,253,2,216,20,64,153,37,126,85,214,68,67,141,115,14,113,72,211,130,64,218,0,0,0,0,27,0,0,0,240,0,0,0,0,0,0,0,0,0,0,0,255,255,0,0,0,0,0,0,1,0,0,0,255,127,0,0,0,0,0,0,2,0,0,0,255,255,128,0,0,0,0,0,3,0,0,0,255,255,1,0,0,0,0,0,0,0,0,0,103,97,108,95,112,49,97,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,253,133,220,1,1,0,16,1,103,97,108,95,115,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,73,116,85,144,2,0,32,0,103,97,108,95,99,49,97,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,52,30,34,248,3,0,32,0,103,97,108,95,99,50,97,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,252,241,12,195,3,0,32,0,103,97,108,95,109,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,234,145,2,156,4,0,16,1,103,97,108,95,118,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,251,184,190,222,5,0,64,0,168,86,7,0,1,0,0,0,240,33,216,0,248,191,2,0,24,38,7,0,1,0,0,0,248,33,216,0,184,160,2,0,120,36,5,0,1,0,0,0,249,33,216,0,96,78,4,0,56,210,6,0,1,0,0,0,0,33,216,0,192,135,2,0,24,163,6,0,1,0,0,0,1,33,216,0,240,108,2,0,152,122,6,0,1,0,0,0,2,33,216,0,96,82,2,0,192,72,6,0,1,0,0,0,3,33,216,0,32,56,2,0,136,30,2,0,1,0,0,0,4,33,216,0,152,30,2,0,224,19,2,0,1,0,0,0,5,33,216,0,232,10,2,0,216,10,2,0,1,0,0,0,6,33,216,0,152,138,8,0,248,3,2,0,1,0,0,0,7,33,216,0,48,119,7,0,40,246,1,0,1,0,0,0,241,33,216,0,64,246,1,0,144,236,1,0,1,0,0,0,250,33,216,0,136,224,1,0,128,149,1,0,1,0,0,0,251,33,216,0,24,60,1,0,176,223,1,0,1,0,0,0,248,32,216,0,72,198,1,0,192,209,1,0,1,0,0,0,249,32,216,0,24,182,1,0,24,198,1,0,1,0,0,0,250,32,216,0,40,167,1,0,120,189,1,0,1,0,0,0,251,32,216,0,200,149,1,0,184,155,8,0,1,0,0,0,252,32,216,0,56,126,1,0,136,149,8,0,1,0,0,0,253,32,216,0,32,101,1,0,216,142,8,0,1,0,0,0,254,32,216,0,96,32,8,0,40,138,8,0,1,0,0,0,255,32,216,0,16,68,7,0,168,132,8,0,1,0,0,0,224,33,216,0,232,209,1,0,72,126,8,0,1,0,0,0,232,33,216,0,144,189,1,0,64,76,8,0,1,0,0,0,233,33,216,0,32,40,1,0,192,122,8,0,1,0,0,0,240,32,216,0,208,174,1,0,40,116,8,0,1,0,0,0,241,32,216,0,48,160,1,0,72,110,8,0,1,0,0,0,242,32,216,0,160,140,1,0,184,102,8,0,1,0,0,0,243,32,216,0,56,112,1,0,232,60,1,0,1,0,0,0,244,32,216,0,32,92,1,0,152,58,1,0,1,0,0,0,245,32,216,0,64,77,1,0,128,57,1,0,1,0,0,0,246,32,216,0,112,157,4,0,240,55,1,0,1,0,0,0,247,32,216,0,176,194,6,0,232,23,8,0,1,0,0,0,225,33,216,0,104,195,5,0,160,19,8,0,1,0,0,0,234,33,216,0,32,245,8,0,88,230,7,0,1,0,0,0,235,33,216,0,40,17,1,0,248,16,8,0,1,0,0,0,232,32,216,0,32,231,8,0,192,12,8,0,1,0,0,0,233,32,216,0,88,214,8,0,224,5,8,0,1,0,0,0,234,32,216,0,224,202,8,0,144,1,8,0,1,0,0,0,235,32,216,0,72,193,8,0,128,42,1,0,1,0,0,0,236,32,216,0,144,180,8,0,32,41,1,0,1,0,0,0,237,32,216,0,208,164,8,0,192,39,1,0,1,0,0,0,238,32,216,0,160,152,4,0,240,38,1,0,1,0,0,0,239,32,216,0,40,184,6,0,88,212,3,0,1,0,0,0,200,32,216,0,40,185,3,0,104,33,1,0,1,0,0,0,48,33,216,0,216,70,1,0,56,122,5,0,1,0,0,0,242,33,216,0,224,12,8,0,24,31,1,0,1,0,0,0,49,33,216,0,176,123,145,0,0,105,5,0,1,0,0,0,226,33,216,0,176,123,145,0,248,5,8,0,9,0,0,0,12,33,216,0,32,58,1,0,144,250,7,0,9,0,0,0,13,33,216,0,32,58,1,0,208,23,1,0,9,0,0,0,152,32,216,0,32,58,1,0,184,22,1,0,9,0,0,0,128,37,0,0,32,58,1,0,0,22,1,0,9,0,0,0,56,33,216,0,32,58,1,0,120,20,1,0,9,0,0,0,57,33,216,0,32,58,1,0,255,255,255,255,0,0,0,0,104,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,86,31,140,227,1,0,16,1,108,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,72,110,132,119,1,0,16,1,104,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,91,8,203,77,1,0,16,1,108,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,112,79,223,136,1,0,16,1,115,104,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,238,33,114,252,2,0,16,1,115,108,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,230,9,200,101,2,0,16,1,109,114,45,99,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,173,143,42,135,3,0,32,0,109,114,45,99,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,122,178,255,210,3,0,32,0,109,114,45,99,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,135,242,191,98,3,0,32,0,109,114,45,99,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,171,98,218,208,3,0,32,0,109,114,45,111,48,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,22,206,249,160,4,0,32,0,109,114,45,111,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,233,169,112,78,4,0,32,0,109,114,45,111,50,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,252,104,196,185,4,0,32,0,109,114,45,111,51,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,58,67,50,204,4,0,32,0,109,114,45,100,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,89,252,17,26,5,0,64,0,168,86,7,0,1,0,0,0,160,191,145,0,248,191,2,0,24,38,7,0,1,0,0,0])
.concat([127,253,146,0,184,160,2,0,200,110,3,0,1,0,0,0,126,253,146,0,152,30,2,0,120,89,3,0,1,0,0,0,125,253,146,0,232,10,2,0,120,74,3,0,1,0,0,0,124,253,146,0,152,138,8,0,192,61,3,0,1,0,0,0,123,253,146,0,48,119,7,0,40,246,1,0,1,0,0,0,161,191,145,0,64,246,1,0,144,236,1,0,1,0,0,0,47,245,146,0,136,224,1,0,224,22,1,0,1,0,0,0,46,245,146,0,56,126,1,0,160,14,1,0,1,0,0,0,45,245,146,0,32,101,1,0,176,9,1,0,1,0,0,0,44,245,146,0,96,32,8,0,200,3,1,0,1,0,0,0,43,245,146,0,16,68,7,0,88,212,3,0,1,0,0,0,168,217,146,0,40,185,3,0,32,77,1,0,1,0,0,0,163,191,145,0,216,70,1,0,16,17,8,0,1,0,0,0,162,191,145,0,224,12,8,0,72,65,1,0,9,0,0,0,35,224,146,0,32,58,1,0,48,50,1,0,9,0,0,0,36,224,146,0,32,58,1,0,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,59,54,198,19,1,0,16,1,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,35,247,6,13,1,0,16,1,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,153,4,130,144,2,0,16,1,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,173,252,204,129,3,0,32,0,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,177,223,143,95,4,0,32,0,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,106,125,117,57,4,0,32,0,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,67,82,221,179,4,0,32,0,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,47,117,201,198,4,0,32,0,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,34,7,63,209,5,0,32,0,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,149,63,119,84,5,0,32,0,49,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,67,251,193,135,5,0,32,0,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,51,62,45,147,5,0,32,0,49,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,213,58,208,35,5,0,32,0,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,135,47,43,166,5,0,32,0,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,194,207,166,66,5,0,32,0,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,102,238,59,157,5,0,32,0,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,191,196,246,246,6,0,64,0,102,97,48,48,50,48,48,50,46,117,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,131,176,227,222,1,0,16,1,102,97,48,48,49,48,48,49,46,117,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,208,57,161,252,1,0,16,1,102,97,48,48,49,48,48,56,46,117,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,72,207,172,231,3,0,32,0,102,97,48,48,49,48,48,55,46,117,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,166,152,49,121,3,0,32,0,102,97,48,48,49,48,48,54,46,117,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,92,54,96,59,4,0,32,0,102,97,48,48,49,48,48,53,46,117,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,134,255,215,140,5,0,32,0,102,97,48,48,49,48,48,52,46,117,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,124,240,101,185,6,0,64,0,184,40,2,0,1,0,0,0,85,0,147,0,248,191,2,0,184,164,8,0,1,0,0,0,86,0,147,0,64,246,1,0,104,28,8,0,1,0,0,0,87,0,147,0,232,209,1,0,56,250,6,0,1,0,0,0,189,247,146,0,184,160,2,0,88,149,7,0,1,0,0,0,190,247,146,0,136,224,1,0,56,210,6,0,1,0,0,0,80,0,147,0,192,135,2,0,152,122,6,0,1,0,0,0,81,0,147,0,96,82,2,0,192,72,6,0,1,0,0,0,82,0,147,0,32,56,2,0,24,163,6,0,1,0,0,0,83,0,147,0,240,108,2,0,176,223,1,0,1,0,0,0,184,247,146,0,72,198,1,0,24,198,1,0,1,0,0,0,185,247,146,0,40,167,1,0,120,189,1,0,1,0,0,0,186,247,146,0,200,149,1,0,192,209,1,0,1,0,0,0,187,247,146,0,24,182,1,0,88,212,3,0,1,0,0,0,128,219,146,0,40,185,3,0,64,23,5,0,9,0,0,0,202,5,147,0,32,58,1,0,104,20,5,0,9,0,0,0,200,5,147,0,32,58,1,0,216,16,5,0,9,0,0,0,201,5,147,0,32,58,1,0,88,12,5,0,9,0,0,0,203,5,147,0,32,58,1,0,109,99,50,45,51,46,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,117,128,224,255,1,0,16,1,109,99,50,45,49,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,234,57,162,5,1,0,16,1,109,99,50,45,50,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,109,14,155,219,1,0,16,1,109,99,49,45,52,46,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,152,248,136,156,2,0,16,1,99,117,115,54,48,45,54,48,97,49,46,109,99,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,42,168,110,7,2,0,16,1,109,99,49,45,53,46,51,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,58,163,94,155,3,0,32,0,109,99,49,45,55,46,52,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,3,160,223,201,4,0,32,0,109,99,49,45,54,46,52,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,60,220,134,150,4,0,32,0,109,99,49,45,56,46,56,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,250,49,91,38,5,0,32,0,109,99,49,45,57,46,56,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,41,192,30,84,5,0,32,0,109,99,49,45,49,46,49,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,139,138,167,50,6,0,32,0,109,99,49,45,50,46,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,123,202,77,111,6,0,32,0,122,111,117,33,32,122,111,117,33,32,122,111,117,33,32,114,101,115,99,117,101,32,100,97,105,115,97,107,117,115,101,110,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,103,30,118,26,33,0,16,0,122,104,117,111,32,103,117,105,32,100,97,32,115,104,105,32,45,32,103,104,111,115,116,32,104,117,110,116,101,114,32,40,99,104,105,41,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,139,42,198,118,33,0,16,0,121,117,117,32,121,117,117,32,104,97,107,117,115,104,111,32,45,32,115,117,110,115,101,116,32,102,105,103,104,116,101,114,115,32,40,98,114,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,238,184,63,254,33,0,16,0,121,117,117,32,121,117,117,32,104,97,107,117,115,104,111,32,45,32,109,97,107,121,111,117,32,116,111,105,116,115,117,115,101,110,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,111,172,206,113,33,0,16,0,121,97,32,115,101,32,99,104,117,97,110,32,115,104,117,111,32,40,99,104,105,41,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,21,154,91,9,33,0,16,0,121,97,110,103,32,106,105,97,32,106,105,97,110,103,32,45,32,121,97,110,103,32,119,97,114,114,105,111,114,32,102,97,109,105,108,121,32,40,99,104,105,41,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,158,167,4,102,33,0,16,0,120,45,112,101,114,116,115,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,253,171,232,87,33,0,16,0,120,105,110,32,113,105,32,103,97,105,32,119,97,110,103,32,122,105,32,40,99,104,105,41,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,181,56,47,221,33,0,16,0,120,105,97,111,32,109,111,110,118,32,45,32,109,97,103,105,99,32,103,105,114,108,32,40,99,104,105,41,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,46,169,73,142,33,0,16,0,109,112,114,45,49,53,48,54,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,249,231,171,89,33,0,16,0,109,112,114,45,49,53,50,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,197,214,41,185,33,0,16,0,119,119,102,32,114,97,119,32,40,119,111,114,108,100,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,17,212,245,78,33,0,16,0,119,119,102,32,119,114,101,115,116,108,101,109,97,110,105,97,32,45,32,116,104,101,32,97,114,99,97,100,101,32,103,97,109,101,32,40,117,115,97,41,32,40,97,108,112,104,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,85,97,157,113,33,0,16,0,119,117,32,107,111,110,103,32,119,97,105,32,122,104,117,97,110,32,40,99,104,105,41,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,110,145,10,136,33,0,16,0,119,111,114,108,100,32,115,101,114,105,101,115,32,98,97,115,101,98,97,108,108,32,40,112,114,111,116,111,116,121,112,101,32,45,32,111,99,116,32,48,49,44,32,49,57,57,51,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,46,185,122,79,33,0,16,0,119,111,114,108,100,32,115,101,114,105,101,115,32,98,97,115,101,98,97,108,108,32,40,112,114,111,116,111,116,121,112,101,32,45,32,100,101,99,32,50,50,44,32,49,57,57,51,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,93,192,31,0,141,85,192,13,33,0,16,0,119,111,114,108,100,32,115,101,114,105,101,115,32,98,97,115,101,98,97,108,108,32,40,112,114,111,116,111,116,121,112,101,32,45,32,100,101,99,32,50,54,44,32,49,57,57,51,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,88,106,46,71,33,0,16,0,119,111,114,108,100,32,115,101,114,105,101,115,32,98,97,115,101,98,97,108,108,32,40,112,114,111,116,111,116,121,112,101,32,45,32,100,101,99,32,50,57,44,32,49,57,57,51,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,54,153,148,237,33,0,16,0,119,111,114,108,100,32,115,101,114,105,101,115,32,98,97,115,101,98,97,108,108,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,97,110,32,48,51,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,53,240,83,75,33,0,16,0,119,111,114,108,100,32,115,101,114,105,101,115,32,98,97,115,101,98,97,108,108,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,97,110,32,48,54,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,211,226,125,176,33,0,16,0,119,111,114,108,100,32,115,101,114,105,101,115,32,98,97,115,101,98,97,108,108,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,97,110,32,49,54,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,62,19,34,83,33,0,16,0,119,111,114,108,100,32,115,101,114,105,101,115,32,98,97,115,101,98,97,108,108,32,40,112,114,111,116,111,116,121,112,101,32,45,32,102,101,98,32,49,56,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,80,252,173,60,33,0,16,0,119,111,114,108,100,32,115,101,114,105,101,115,32,98,97,115,101,98,97,108,108,32,40,112,114,111,116,111,116,121,112,101,32,45,32,109,97,114,32,48,52,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,162,234,31,0,165,68,218,237,33,0,16,0,119,111,114,108,100,32,115,101,114,105,101,115,32,98,97,115,101,98,97,108,108,32,40,112,114,111,116,111,116,121,112,101,32,45,32,109,97,121,32,50,55,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,138,114,115,228,33,0,16,0,119,111,114,109,115,32,40,101,117,114,111,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,148,22,25,29,33,0,16,0,119,105,110,120,32,51,100,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,163,18,0,201,236,60,147,33,0,16,0,119,105,110,116,101,114,32,111,108,121,109,112,105,99,115,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,69,122,83,250,33,0,16,0,119,111,114,108,100,32,99,117,112,32,117,115,97,32,57,52,32,40,101,117,114,111,44,32,117,115,97,44,32,107,111,114,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,127,180,113,1,33,0,16,0,109,112,114,45,49,51,50,51,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,41,248,149,221,33,0,16,0,119,111,114,108,100,32,99,104,97,109,112,105,111,110,115,104,105,112,32,115,111,99,99,101,114,32,105,105,32,40,117,115,97,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,26,28,226,193,33,0,16,0,109,112,114,45,49,53,50,55,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,195,1,202,218,33,0,16,0,109,112,114,45,49,52,53,53,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,176,245,146,21,33,0,16,0,119,97,121,110,101,32,103,114,101,116,122,107,121,32,97,110,100,32,116,104,101,32,110,104,108,112,97,32,97,108,108,45,115,116,97,114,115,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,129,59,193,194,33,0,16,0,119,97,114,105,111,32,108,97,110,100,32,51,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,165,147,92,205,33,0,16,0,118,105,114,116,117,97,32,102,105,103,104,116,101,114,32,50,32,118,115,32,116,101,107,107,101,110,32,50,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,157,73,219,44,33,0,16,0,109,112,114,45,49,51,52,51,48,43,109,112,114,45,49,51,52,51,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,171,201,27,234,33,0,16,0,118,101,99,116,111,114,109,97,110,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,84,51,139,211,33,0,16,0,109,117,103,101,110,32,115,101,110,115,104,105,32,118,97,108,105,115,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,37,22,67,36,33,0,16,0,118,97,108,105,115,32,105,105,105,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,104,163,162,89,33,0,16,0,117,122,117,32,107,101,111,98,117,107,115,101,111,110,32,40,107,111,114,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,91,37,167,33,0,16,0,117,110,100,101,97,100,32,108,105,110,101,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,230,161,60,251,33,0,16,0,117,108,116,105,109,97,116,101,32,113,105,120,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,217,105,51,216,33,0,16,0,116,121,114,97,110,116,115,32,45,32,102,105,103,104,116,32,116,104,114,111,117,103,104,32,116,105,109,101,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,30,146,68,167,33,0,16,0,116,117,110,32,115,104,105,32,116,105,97,110,32,100,105,32,105,105,105,32,40,99,104,105,41,32,40,115,105,109,112,108,101,32,99,104,105,110,101,115,101,41,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,104,182,87,234,33,0,16,0,116,105,110,121,32,116,111,111,110,32,97,100,118,101,110,116,117,114,101,115,32,51,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,212,131,93,214,33,0,16,0,109,112,114,45,49,55,48,54,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,178,178,39,18,33,0,16,0,109,112,114,45,49,52,54,55,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,115,140,64,36,33,0,16,0,116,111,120,105,99,32,99,114,117,115,97,100,101,114,115,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,206,70,253,17,33,0,16,0,109,112,114,45,49,52,50,51,54,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,75,143,88,122,33,0,16,0,116,110,110,32,111,117,116,100,111,111,114,115,32,98,97,115,115,32,116,111,117,114,110,97,109,101,110,116,32,39,57,54,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,11,60,82,92,33,0,16,0,116,109,110,116,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,110,53,177,127,33,0,16,0,116,101,101,110,97,103,101,32,109,117,116,97,110,116,32,110,105,110,106,97,32,116,117,114,116,108,101,115,32,45,32,116,104,101,32,104,121,112,101,114,115,116,111,110,101,32,104,101,105,115,116,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,222,65,156,103,33,0,16,0,116,101,101,110,97,103,101,32,109,117,116,97,110,116,32,104,101,114,111,32,116,117,114,116,108,101,115,32,45,32,116,111,117,114,110,97,109,101,110,116,32,102,105,103,104,116,101,114,115,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,230,183,210,60,33,0,16,0,116,101,101,110,97,103,101,32,109,117,116,97,110,116,32,104,101,114,111,32,116,117,114,116,108,101,115,32,45,32,116,104,101,32,104,121,112,101,114,115,116,111,110,101,32,104,101,105,115,116,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,134,82,109,150,33,0,16,0,116,105,110,116,105,110,32,97,117,32,116,105,98,101,116,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,243,202,67,66,33,0,16,0,115,116,111,114,121,32,111,102,32,116,104,111,114,44,32,116,104,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,111,99,116,32,48,52,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,145,111,72,158,33,0,16,0,115,116,111,114,121,32,111,102,32,116,104,111,114,44,32,116,104,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,111,99,116,32,49,55,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,74,211,67,170,33,0,16,0,115,116,111,114,121,32,111,102,32,116,104,111,114,44,32,116,104,101,32,40,106,112,110,41,32,40,98,101,116,97,41,32,40,98,97,100,32,100,117,109,112,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,27,0,73,22,193,191,33,0,16,0,116,104,111,109,97,115,32,116,104,101,32,116,97,110,107,32,101,110,103,105,110,101,32,38,32,102,114,105,101,110,100,115,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,153,98,64,26,33,0,16,0,109,112,114,45,49,50,51,53,54,43,109,112,114,45,49,50,51,53,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,176,13,233,76,33,0,16,0,116,101,108,45,116,101,108,32,109,97,104,106,111,110,103,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,146,126,129,68,33,0,16,0,116,99,50,48,48,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,219,27,249,206,33,0,16,0,108,114,111,103,52,53,51,45,101,116,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,252,63,220,5,33,0,16,0,116,97,105,119,97,110,32,100,97,104,101,110,103,32,40,99,104,105,41,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,129,15,242,186,33,0,16,0,115,117,109,109,101,114,32,99,104,97,108,108,101,110,103,101,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,193,61,213,215,33,0,16,0,115,116,97,114,32,116,114,101,107,32,45,32,116,104,101,32,110,101,120,116,32,103,101,110,101,114,97,116,105,111,110,32,45,32,101,99,104,111,101,115,32,102,114,111,109,32,116,104,101,32,112,97,115,116,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,251,83,33,39,33,0,16,0,115,116,97,114,32,116,114,101,107,32,45,32,100,101,101,112,32,115,112,97,99,101,32,110,105,110,101,32,45,32,99,114,111,115,115,114,111,97,100,115,32,111,102,32,116,105,109,101,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,164,225,113,167,33,0,16,0,109,112,114,45,49,50,51,53,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,238,135,48,177,33,0,16,0,115,116,97,114,102,108,105,103,104,116,32,40,101,117,114,111,44,32,117,115,97,41,32,40,118,49,46,49,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,234,219,23,18,33,0,16,0,115,97,105,110,116,32,115,119,111,114,100,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,255,107,246,68,33,0,16,0,115,111,110,105,99,32,115,112,105,110,98,97,108,108,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,203,6,114,103,33,0,16,0,115,111,110,105,99,32,115,112,105,110,98,97,108,108,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,0,121,73,82,177,33,0,16,0,115,111,110,105,99,32,115,112,105,110,98,97,108,108,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,232,140,208,172,33,0,16,0,115,116,114,101,101,116,32,115,109,97,114,116,32,40,117,115,97,44,32,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,173,223,222,177,33,0,16,0,115,117,112,101,114,32,115,107,105,100,109,97,114,107,115,32,40,101,117,114,111,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,12,15,26,166,33,0,16,0,109,112,114,45,49,55,57,56,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,254,213,88,26,33,0,16,0,109,112,114,45,49,56,54,56,48,43,109,112,114,45,49,56,54,56,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,234,84,226,251,33,0,16,0,109,112,114,45,49,57,57,52,53,45,109,120,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,71,7,218,37,17,0,16,0,115,112,105,114,111,117,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,48,177,52,102,33,0,16,0,109,112,114,45,49,50,57,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,197,168,67,161,33,0,16,0,115,116,114,101,101,116,115,32,111,102,32,114,97,103,101,32,51,32,40,101,117,114,111,41,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,112,114,32,49,50,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,171,229,124,161,33,0,16,0,115,116,114,101,101,116,115,32,111,102,32,114,97,103,101,32,51,32,40,101,117,114,111,41,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,112,114,32,49,51,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,174,66,78,22,33,0,16,0,115,116,114,101,101,116,115,32,111,102,32,114,97,103,101,32,51,32,40,101,117,114,111,41,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,112,114,32,49,53,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,107,30,79,198,33,0,16,0,115,116,114,101,101,116,115,32,111,102,32,114,97,103,101,32,51,32,40,101,117,114,111,41,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,112,114,32,50,48,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,142,189,228,106,33,0,16,0,115,116,114,101,101,116,115,32,111,102,32,114,97,103,101,32,51,32,40,101,117,114,111,41,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,112,114,32,50,53,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,138,135,51,112,33,0,16,0,109,112,114,45,49,51,57,51,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,238,94,224,175,33,0,16,0,109,112,114,45,49,54,51,52,50,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,3,37,99,106,33,0,16,0,109,112,114,45,49,53,48,48,48,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,131,83,144,123,33,0,16,0,109,112,114,45,49,55,52,57,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,177,189,14,163,33,0,16,0,115,111,99,107,101,116,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,90,225,20,60,33,0,16,0,109,112,114,45,49,55,48,49,57,97,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,255,14,179,136,33,0,16,0,97,121,114,116,111,110,32,115,101,110,110,97,39,115,32,115,117,112,101,114,32,109,111,110,97,99,111,32,103,112,32,105,105,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,214,222,200,234,33,0,16,0,116,111,100,100,39,115,32,97,100,118,101,110,116,117,114,101,115,32,105,110,32,115,108,105,109,101,32,119,111,114,108,100,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,125,139,46,101,33,0,16,0,115,112,97,99,101,32,105,110,118,97,100,101,114,115,32,57,49,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,40,181,131,187,33,0,16,0,115,112,97,99,101,32,105,110,118,97,100,101,114,115,32,57,48,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,102,189,173,34,33,0,16,0,115,104,117,105,32,104,117,32,45,32,102,101,110,103,32,121,117,110,32,122,104,117,97,110,32,40,99,104,105,41,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,12,1,158,62,33,0,16,0,115,104,114,101,107,32,50,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,81,54,205,12,33,0,16,0,115,104,111,117,103,105,32,110,111,32,104,111,115,104,105,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,22,248,72,65,33,0,16,0,115,104,105,116,101,110,32,109,121,111,117,111,117,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,147,150,114,126,33,0,16,0,115,104,105,32,106,105,101,32,122,104,105,32,98,97,110,103,32,122,104,101,110,103,32,98,97,32,122,104,97,110,32,45,32,119,111,114,108,100,32,112,114,111,32,98,97,115,101,98,97,108,108,32,57,52,32,40,99,104,105,41,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,79,136,221,114,33,0,16,0,115,102,98,50,95,117,49,43,115,102,98,50,95,117,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,242,85,153,73,33,0,16,0,115,104,97,100,111,119,32,98,108,97,115,116,101,114,115,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,123,55,61,113,33,0,16,0,109,112,114,45,49,53,49,50,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,190,117,121,146,33,0,16,0,115,116,114,101,101,116,32,102,105,103,104,116,101,114,32,105,105,39,32,116,117,114,98,111,32,40,112,105,114,97,116,101,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,174,145,84,168,33,0,16,0,115,101,115,97,109,101,32,115,116,114,101,101,116,32,99,111,117,110,116,105,110,103,32,99,97,102,101,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,195,72,79,10,33,0,16,0,115,111,110,105,99,32,99,114,97,99,107,101,114,115,32,40,106,112,110,41,32,40,112,114,111,116,111,116,121,112,101,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,141,168,173,127,33,0,16,0,115,99,111,111,98,121,32,100,111,111,32,109,121,115,116,101,114,121,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,155,221,185,123,33,0,16,0,115,117,112,101,114,32,98,97,116,116,108,101,116,97,110,107,32,45,32,119,97,114,32,105,110,32,116,104,101,32,103,117,108,102,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,201,227,181,176,33,0,16,0,115,117,112,101,114,32,98,97,116,116,108,101,115,104,105,112,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,251,27,202,153,33,0,16,0,115,97,110,32,115,97,110,32,40,106,97,112,97,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,237,222,133,91,33,0,16,0,115,97,110,32,103,117,111,32,122,104,105,32,108,105,101,32,122,104,117,97,110,32,45,32,108,117,97,110,32,115,104,105,32,113,117,110,32,121,105,110,103,32,40,99,104,105,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,152,195,92,59,33,0,16,0,115,97,109,117,114,97,105,32,115,104,111,100,111,119,110,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,79,1,114,201,33,0,16,0,115,97,103,97,105,97,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,67,47,226,241,33,0,16,0,115,117,112,101,114,32,49,57,45,105,110,45,49,32,40,112,105,114,97,116,101,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,66,179,210,10,33,0,16,0,115,117,112,101,114,32,49,53,45,105,110,45,49,32,40,112,105,114,97,116,101,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,255,223,23,109,33,0,16,0,114,117,110,97,114,107,32,40,106,112,110,44,32,107,111,114,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,251,216,148,8,33,0,16,0,114,111,108,108,105,110,103,32,116,104,117,110,100,101,114,32,51,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,170,19,251,100,33,0,16,0,114,111,108,108,105,110,103,32,116,104,117,110,100,101,114,32,50,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,146,242,64,196,33,0,16,0,114,105,99,104,97,114,100,32,115,99,97,114,114,121,39,115,32,98,117,115,121,116,111,119,110,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,117,108,32,50,49,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,48,31,0,255,214,146,30,33,0,16,0,114,105,99,104,97,114,100,32,115,99,97,114,114,121,39,115,32,98,117,115,121,116,111,119,110,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,117,103,32,48,57,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,236,236,31,0,48,188,140,196,33,0,16,0,114,105,99,104,97,114,100,32,115,99,97,114,114,121,39,115,32,98,117,115,121,116,111,119,110,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,117,103,32,49,53,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,23,217,14,101,33,0,16,0,114,105,99,104,97,114,100,32,115,99,97,114,114,121,39,115,32,98,117,115,121,116,111,119,110,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,117,103,32,49,54,44,32,49,57,57,52,32,45,32,98,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,98,255,12,118,33,0,16,0,114,105,99,104,97,114,100,32,115,99,97,114,114,121,39,115,32,98,117,115,121,116,111,119,110,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,117,103,32,49,55,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,164,250,31,0,74,63,156,59,33,0,16,0,114,105,99,104,97,114,100,32,115,99,97,114,114,121,39,115,32,98,117,115,121,116,111,119,110,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,117,103,32,50,53,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,186,19,192,160,33,0,16,0,114,105,99,104,97,114,100,32,115,99,97,114,114,121,39,115,32,98,117,115,121,116,111,119,110,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,117,103,32,50,54,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,243,112,210,26,33,0,16,0,114,114,51,98,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,86,89,120,21,33,0,16,0,114,111,97,100,32,114,97,115,104,32,105,105,32,40,101,117,114,111,44,32,117,115,97,41,32,40,118,49,46,50,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,146,233,118,8,33,0,16,0,102,120,48,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,81,253,237,142,33,0,16,0,114,105,115,116,97,114,32,40,101,117,114,111,44,32,117,115,97,41,32,40,115,101,112,116,101,109,98,101,114,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,97,170,17,101,33,0,16,0,114,105,115,107,121,32,119,111,111,100,115,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,60,233,117,217,33,0,16,0,114,105,100,100,108,101,32,119,105,114,101,100,32,40,106,112,110,41,32,40,115,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,32,215,227,250,33,0,16,0,114,104,108,32,50,48,48,48,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,139,151,122,187,33,0,16,0,114,46,98,46,105,46,32,98,97,115,101,98,97,108,108,32,52,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,148,155,207,254,33,0,16,0,114,46,98,46,105,46,32,98,97,115,101,98,97,108,108,32,51,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,140,52,64,72,33,0,16,0,114,97,110,115,101,105,32,110,111,32,104,97,115,104,97,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,61,8,160,169,33,0,16,0,114,97,109,98,111,32,105,105,105,32,40,119,111,114,108,100,41,32,40,118,49,46,49,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,71,166,71,77,33,0,16,0,114,97,105,100,101,110,32,116,114,97,100,32,45,45,32,114,97,105,100,101,110,32,100,101,110,115,101,116,115,117,32,40,117,115,97,44,32,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,17,168,57,248,33,0,16,0,114,97,100,105,99,97,108,32,114,101,120,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,130,50,45,208,33,0,16,0,112,111,107,101,114,32,99,108,117,98,32,40,115,97,99,104,101,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,235,217,40,174,33,0,16,0,112,117,116,116,101,114,32,103,111,108,102,32,40,106,112,110,41,32,40,115,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,166,104,241,32,33,0,16,0,112,117,103,103,115,121,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,222,154,92,93,33,0,16,0,109,100,112,112,102,56,50,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,81,131,221,50,33,0,16,0,112,104,97,110,116,97,115,121])
.concat([32,115,116,97,114,32,105,118,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,104,41,156,56,33,0,16,0,112,104,97,110,116,97,115,121,32,115,116,97,114,32,105,105,105,32,45,32,103,101,110,101,114,97,116,105,111,110,115,32,111,102,32,100,111,111,109,32,40,101,117,114,111,44,32,117,115,97,44,32,107,111,114,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,15,43,180,198,33,0,16,0,109,112,114,45,49,50,56,53,49,97,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,16,65,113,116,17,0,16,0,109,112,114,45,49,50,56,53,50,97,46,105,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,26,35,4,227,20,0,16,0,112,114,111,98,111,116,101,99,116,111,114,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,72,125,89,188,33,0,16,0,112,114,105,109,97,108,32,114,97,103,101,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,209,198,132,40,33,0,16,0,112,101,112,101,110,103,97,32,112,101,110,103,111,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,75,50,226,209,33,0,16,0,112,111,107,101,109,111,110,32,99,114,97,122,121,32,100,114,117,109,109,101,114,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,93,162,56,136,33,0,16,0,112,105,110,111,99,99,104,105,111,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,216,40,65,205,33,0,16,0,112,101,98,98,108,101,32,98,101,97,99,104,32,103,111,108,102,32,108,105,110,107,115,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,151,114,252,108,33,0,16,0,112,111,119,101,114,32,100,114,105,118,101,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,97,173,0,140,33,0,16,0,112,105,114,97,116,101,115,32,111,102,32,116,104,101,32,99,97,114,105,98,98,101,97,110,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,244,11,218,72,33,0,16,0,112,97,114,116,121,32,113,117,105,122,32,109,101,103,97,32,113,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,122,68,75,157,33,0,16,0,112,97,100,100,108,101,32,102,105,103,104,116,101,114,32,40,106,112,110,41,32,40,115,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,230,71,129,61,33,0,16,0,111,117,116,114,117,110,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,210,168,217,253,33,0,16,0,111,111,122,101,44,32,116,104,101,32,40,117,115,97,44,32,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,47,212,13,28,33,0,16,0,111,110,115,108,97,117,103,104,116,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,214,25,159,33,0,16,0,110,105,110,106,97,32,98,117,114,97,105,32,100,101,110,115,101,116,115,117,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,160,40,216,168,33,0,16,0,110,105,107,107,97,110,32,115,112,111,114,116,115,32,112,114,111,32,121,97,107,121,117,117,32,118,97,110,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,89,90,101,195,33,0,16,0,110,102,108,32,102,111,111,116,98,97,108,108,32,39,57,52,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,74,220,144,228,33,0,16,0,110,105,103,104,116,109,97,114,101,32,99,105,114,99,117,115,32,40,112,114,111,116,111,116,121,112,101,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,184,241,150,238,33,0,16,0,110,105,103,104,116,109,97,114,101,32,99,105,114,99,117,115,32,40,98,114,97,41,32,40,97,108,116,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,148,90,222,49,33,0,16,0,110,98,97,32,106,97,109,32,40,101,117,114,111,44,32,117,115,97,41,32,40,118,49,46,49,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,230,96,131,235,33,0,16,0,110,98,97,32,97,99,116,105,111,110,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,186,72,195,153,33,0,16,0,110,98,97,32,50,48,48,53,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,56,2,97,232,33,0,16,0,110,97,114,117,116,111,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,3,53,155,178,33,0,16,0,109,112,114,45,49,51,50,56,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,27,121,112,106,33,0,16,0,109,117,115,104,97,32,97,108,101,115,116,101,32,45,32,102,117,108,108,32,109,101,116,97,108,32,102,105,103,104,116,101,114,32,101,108,108,105,110,111,114,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,171,24,222,143,33,0,16,0,109,97,103,105,99,32,115,99,104,111,111,108,32,98,117,115,44,32,116,104,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,97,110,32,49,50,44,32,49,57,57,53,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,228,178,14,0,249,70,99,148,33,0,16,0,109,97,103,105,99,32,115,99,104,111,111,108,32,98,117,115,44,32,116,104,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,102,101,98,32,48,50,44,32,49,57,57,53,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,201,181,5,120,33,0,16,0,109,97,103,105,99,32,115,99,104,111,111,108,32,98,117,115,44,32,116,104,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,102,101,98,32,49,55,44,32,49,57,57,53,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,188,246,13,0,192,136,122,43,33,0,16,0,109,97,103,105,99,32,115,99,104,111,111,108,32,98,117,115,44,32,116,104,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,109,97,114,32,48,55,44,32,49,57,57,53,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,154,14,0,184,30,199,38,33,0,16,0,109,97,103,105,99,32,115,99,104,111,111,108,32,98,117,115,44,32,116,104,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,109,97,114,32,49,52,44,32,49,57,57,53,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,28,15,0,175,161,166,55,33,0,16,0,109,97,103,105,99,32,115,99,104,111,111,108,32,98,117,115,44,32,116,104,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,109,97,114,32,50,55,44,32,49,57,57,53,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,82,15,0,64,218,101,176,33,0,16,0,109,97,103,105,99,32,115,99,104,111,111,108,32,98,117,115,44,32,116,104,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,109,97,114,32,51,49,44,32,49,57,57,53,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,147,15,0,239,141,120,205,33,0,16,0,109,97,103,105,99,32,115,99,104,111,111,108,32,98,117,115,44,32,116,104,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,112,114,32,49,49,44,32,49,57,57,53,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,188,223,15,0,188,35,48,136,33,0,16,0,109,97,103,105,99,32,115,99,104,111,111,108,32,98,117,115,44,32,116,104,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,112,114,32,50,49,44,32,49,57,57,53,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,207,15,0,173,183,68,120,33,0,16,0,109,97,103,105,99,32,115,99,104,111,111,108,32,98,117,115,44,32,116,104,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,112,114,32,50,53,44,32,49,57,57,53,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,213,15,0,135,45,189,182,33,0,16,0,109,97,103,105,99,32,115,99,104,111,111,108,32,98,117,115,44,32,116,104,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,112,114,32,50,56,44,32,49,57,57,53,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,156,232,15,0,135,174,107,155,33,0,16,0,109,97,103,105,99,32,115,99,104,111,111,108,32,98,117,115,44,32,116,104,101,32,40,112,114,111,116,111,116,121,112,101,32,45,32,109,97,121,32,48,53,44,32,49,57,57,53,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,234,15,0,28,95,49,162,33,0,16,0,109,114,46,32,110,117,116,122,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,11,234,134,7,33,0,16,0,109,105,103,104,116,121,32,109,111,114,112,104,105,110,32,112,111,119,101,114,32,114,97,110,103,101,114,115,32,45,32,116,104,101,32,109,111,118,105,101,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,114,73,74,37,33,0,16,0,109,105,103,104,116,121,32,109,111,114,112,104,105,110,32,112,111,119,101,114,32,114,97,110,103,101,114,115,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,117,108,32,48,56,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,84,108,145,230,33,0,16,0,109,105,103,104,116,121,32,109,111,114,112,104,105,110,32,112,111,119,101,114,32,114,97,110,103,101,114,115,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,117,108,32,49,56,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,26,219,204,90,33,0,16,0,109,105,103,104,116,121,32,109,111,114,112,104,105,110,32,112,111,119,101,114,32,114,97,110,103,101,114,115,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,117,103,32,48,52,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,175,90,174,243,33,0,16,0,109,105,103,104,116,121,32,109,111,114,112,104,105,110,32,112,111,119,101,114,32,114,97,110,103,101,114,115,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,117,103,32,48,56,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,73,69,100,87,33,0,16,0,109,105,103,104,116,121,32,109,111,114,112,104,105,110,32,112,111,119,101,114,32,114,97,110,103,101,114,115,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,117,103,32,48,57,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,10,254,86,67,33,0,16,0,109,105,103,104,116,121,32,109,111,114,112,104,105,110,32,112,111,119,101,114,32,114,97,110,103,101,114,115,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,117,103,32,49,48,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,20,210,156,231,33,0,16,0,109,105,103,104,116,121,32,109,111,114,112,104,105,110,32,112,111,119,101,114,32,114,97,110,103,101,114,32,45,32,116,104,101,32,102,105,103,104,116,105,110,103,32,101,100,105,116,105,111,110,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,108,241,63,181,33,0,16,0,109,112,114,45,49,55,48,56,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,133,139,90,203,33,0,16,0,109,105,103,45,50,57,32,102,105,103,104,116,101,114,32,112,105,108,111,116,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,178,171,204,89,33,0,16,0,109,105,103,45,50,57,32,102,105,103,104,116,101,114,32,112,105,108,111,116,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,70,144,35,61,33,0,16,0,109,105,100,110,105,103,104,116,32,114,101,115,105,115,116,97,110,99,101,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,246,106,124,24,33,0,16,0,109,105,110,110,101,115,111,116,97,32,102,97,116,115,32,45,32,112,111,111,108,32,108,101,103,101,110,100,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,64,79,23,56,33,0,16,0,109,101,110,103,32,104,117,97,110,32,115,104,117,105,32,103,117,111,32,112,97,110,32,45,32,55,55,55,32,99,97,115,105,110,111,32,40,99,104,105,41,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,228,3,220,66,33,0,16,0,109,101,103,97,45,108,111,45,109,97,110,105,97,32,40,101,117,114,111,41,32,40,118,49,46,49,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,48,237,159,171,33,0,16,0,109,101,100,97,108,32,99,105,116,121,32,40,106,112,110,41,32,40,115,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,93,19,244,62,33,0,16,0,109,97,114,115,117,112,105,108,97,109,105,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,112,189,155,224,33,0,16,0,109,97,114,107,111,39,115,32,109,97,103,105,99,32,102,111,111,116,98,97,108,108,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,206,140,140,43,33,0,16,0,109,97,114,107,111,39,115,32,109,97,103,105,99,32,102,111,111,116,98,97,108,108,32,40,101,117,114,111,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,100,229,115,2,33,0,16,0,109,97,114,105,111,32,52,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,217,236,176,150,33,0,16,0,109,97,114,105,111,32,51,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,47,176,245,105,33,0,16,0,109,97,114,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,138,162,235,121,33,0,16,0,109,97,32,113,105,97,111,32,101,32,109,111,32,116,97,32,45,32,100,101,118,105,108,105,115,104,32,109,97,104,106,111,110,103,32,116,111,119,101,114,32,40,99,104,105,41,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,148,89,227,18,33,0,16,0,109,97,109,111,110,111,32,104,117,110,116,101,114,32,121,111,117,107,111,32,45,32,100,97,105,32,55,32,110,111,32,107,101,105,115,104,111,117,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,155,53,187,16,33,0,16,0,109,97,32,106,105,97,110,103,32,113,105,110,103,32,114,101,110,32,45,32,106,105,32,109,97,32,106,105,97,110,103,32,122,104,105,32,40,99,104,105,41,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,164,43,208,221,33,0,16,0,106,111,104,110,32,109,97,100,100,101,110,32,102,111,111,116,98,97,108,108,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,136,251,144,33,0,16,0,108,111,116,117,115,95,116,117,114,98,111,95,108,111,116,48,51,46,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,122,203,60,184,17,0,16,0,108,111,116,50,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,16,224,142,29,33,0,16,0,108,111,114,100,32,111,102,32,116,104,101,32,114,105,110,103,115,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,117,166,62,81,33,0,16,0,109,112,114,45,49,56,48,57,48,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,43,37,199,82,33,0,16,0,97,115,115,97,117,108,116,32,115,117,105,116,32,108,101,121,110,111,115,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,200,162,129,33,0,16,0,108,97,107,101,114,115,32,118,101,114,115,117,115,32,99,101,108,116,105,99,115,32,97,110,100,32,116,104,101,32,110,98,97,32,112,108,97,121,111,102,102,115,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,117,252,51,14,33,0,16,0,107,121,117,117,107,121,111,107,117,32,116,105,103,101,114,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,33,109,39,97,33,0,16,0,107,114,117,115,116,121,39,115,32,115,117,112,101,114,32,102,117,110,32,104,111,117,115,101,32,40,101,117,114,111,44,32,117,115,97,41,32,40,118,49,46,49,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,98,151,86,33,0,16,0,107,105,110,103,32,111,102,32,102,105,103,104,116,101,114,115,32,57,57,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,190,175,130,171,33,0,16,0,107,105,110,103,32,111,102,32,102,105,103,104,116,101,114,115,32,39,57,56,44,32,116,104,101,32,40,117,110,108,41,32,40,112,105,114,97,116,101,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,116,16,158,199,33,0,16,0,107,97,45,103,101,45,107,105,32,45,32,102,105,115,116,115,32,111,102,32,115,116,101,101,108,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,166,15,252,239,33,0,16,0,106,117,110,107,101,114,39,115,32,104,105,103,104,32,40,106,112,110,41,32,40,98,101,116,97,41,32,40,98,97,100,32,100,117,109,112,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,73,73,83,35,33,0,16,0,106,117,110,103,108,101,32,98,111,111,107,44,32,116,104,101,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,153,154,112,185,33,0,16,0,106,97,109,101,115,32,112,111,110,100,32,51,32,45,32,111,112,101,114,97,116,105,111,110,32,115,116,97,114,102,105,115,104,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,42,75,246,38,33,0,16,0,106,117,114,97,115,115,105,99,32,112,97,114,107,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,239,222,49,123,33,0,16,0,106,117,114,97,115,115,105,99,32,112,97,114,107,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,131,87,142,236,33,0,16,0,106,111,115,104,117,97,32,38,32,116,104,101,32,98,97,116,116,108,101,32,111,102,32,106,101,114,105,99,104,111,32,40,117,115,97,41,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,170,37,158,218,33,0,16,0,106,111,101,32,38,32,109,97,99,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,199,193,188,133,33,0,16,0,106,105,117,32,106,105,32,109,97,32,106,105,97,110,103,32,105,105,32,45,32,121,101,32,121,97,110,32,98,105,97,110,32,40,99,104,105,41,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,34,155,130,233,33,0,16,0,106,117,100,103,101,32,100,114,101,100,100,32,40,119,111,114,108,100,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,216,46,52,234,33,0,16,0,106,97,109,101,115,32,98,111,110,100,32,48,48,55,32,45,32,116,104,101,32,100,117,101,108,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,72,69,97,78,33,0,16,0,48,48,55,32,115,104,105,116,111,117,32,45,32,116,104,101,32,100,117,101,108,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,98,178,180,174,33,0,16,0,106,97,110,116,101,105,32,109,111,110,111,103,97,116,97,114,105,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,173,25,27,138,33,0,16,0,106,97,110,111,117,32,116,111,117,114,121,117,117,109,111,110,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,198,151,239,181,33,0,16,0,106,97,109,109,105,116,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,184,82,27,217,33,0,16,0,105,116,32,99,97,109,101,32,102,114,111,109,32,116,104,101,32,100,101,115,101,114,116,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,247,180,175,37,33,0,16,0,109,98,56,51,52,50,48,48,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,94,125,222,177,33,0,16,0,105,110,115,116,114,117,109,101,110,116,115,32,111,102,32,99,104,97,111,115,32,115,116,97,114,114,105,110,103,32,121,111,117,110,103,32,105,110,100,105,97,110,97,32,106,111,110,101,115,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,240,78,56,78,33,0,16,0,105,109,103,32,105,110,116,101,114,110,97,116,105,111,110,97,108,32,116,111,117,114,32,116,101,110,110,105,115,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,43,252,79,224,33,0,16,0,105,99,101,32,97,103,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,8,84,88,58,33,0,16,0,104,121,112,101,114,32,109,97,114,98,108,101,115,32,40,106,112,110,41,32,40,115,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,153,39,187,131,33,0,16,0,104,117,109,97,110,115,44,32,116,104,101,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,102,67,207,160,33,0,16,0,104,117,97,110,32,108,101,32,116,97,111,32,113,105,32,115,104,117,32,45,32,115,109,97,114,116,32,109,111,117,115,101,32,40,99,104,105,41,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,64,247,205,222,33,0,16,0,104,117,97,32,109,117,32,108,97,110,32,45,32,109,117,108,97,110,32,40,99,104,105,41,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,184,130,104,121,33,0,16,0,104,111,109,101,32,97,108,111,110,101,32,40,117,115,97,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,185,95,35,58,33,0,16,0,104,111,109,101,32,97,108,111,110,101,32,50,32,45,32,108,111,115,116,32,105,110,32,110,101,119,32,121,111,114,107,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,20,124,248,203,33,0,16,0,104,111,107,117,116,111,32,110,111,32,107,101,110,32,45,32,115,104,105,110,32,115,101,105,107,105,109,97,116,115,117,32,107,121,117,117,115,101,105,115,104,117,32,100,101,110,115,101,116,115,117,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,231,133,101,27,33,0,16,0,104,105,116,32,116,104,101,32,105,99,101,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,6,54,178,133,33,0,16,0,109,112,114,45,49,50,57,50,57,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,91,182,5,166,33,0,16,0,104,101,105,32,116,97,111,32,50,32,45,32,115,117,112,101,114,32,98,105,103,32,50,32,40,99,104,105,41,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,19,145,68,49,33,0,16,0,104,101,97,100,45,111,110,32,115,111,99,99,101,114,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,39,163,255,220,33,0,16,0,104,105,103,104,32,115,101,97,115,32,104,97,118,111,99,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,28,85,190,23,33,0,16,0,109,112,114,45,49,52,52,51,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,2,81,64,3,33,0,16,0,117,99,104,117,117,32,115,101,110,107,97,110,32,103,111,109,111,114,97,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,210,232,17,197,33,0,16,0,103,111,100,115,32,40,117,115,97,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,100,187,6,44,33,0,16,0,109,112,114,45,49,50,54,48,53,97,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,204,195,103,211,17,0,16,0,109,112,114,45,49,50,54,48,54,97,46,105,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,198,68,100,245,19,0,16,0,115,103,114,48,48,49,45,97,43,115,103,114,48,48,50,45,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,74,206,219,20,33,0,16,0,109,112,114,45,49,54,55,48,52,43,109,112,114,45,49,54,55,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,127,66,244,42,33,0,16,0,109,112,114,45,49,50,55,53,48,97,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,25,200,133,193,33,0,16,0,103,97,100,103,101,116,32,116,119,105,110,115,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,72,226,229,122,33,0,16,0,102,117,116,98,111,108,32,97,114,103,101,110,116,105,110,111,32,57,56,32,45,32,112,97,115,105,111,110,32,100,101,32,109,117,108,116,105,116,117,100,101,115,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,136,88,1,92,33,0,16,0,102,117,110,32,99,97,114,32,114,97,108,108,121,32,40,117,115,97,41,32,40,112,114,111,116,111,116,121,112,101,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,69,120,226,66,33,0,16,0,102,108,105,110,116,115,116,111,110,101,115,44,32,116,104,101,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,89,44,152,124,33,0,16,0,102,108,105,110,116,115,116,111,110,101,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,49,48,10,146,33,0,16,0,102,108,105,99,107,121,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,171,200,145,66,33,0,16,0,102,108,97,115,104,32,112,111,105,110,116,32,40,106,97,112,97,110,41,32,40,112,114,111,116,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,77,7,85,6,33,0,16,0,109,112,114,45,49,53,52,49,48,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,131,28,49,111,33,0,16,0,102,105,110,97,108,32,98,108,111,119,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,93,80,173,72,33,0,16,0,102,105,102,97,32,115,111,99,99,101,114,32,57,57,32,40,112,105,114,97,116,101,41,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,176,164,197,197,33,0,16,0,102,105,102,97,32,57,56,32,45,32,114,111,97,100,32,116,111,32,119,111,114,108,100,32,99,117,112,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,87,127,148,150,33,0,16,0,102,105,102,97,95,57,55,95,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,97,176,237,43,17,0,16,0,102,105,102,97,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,250,15,211,186,33,0,16,0,102,105,102,97,57,53,98,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,54,208,137,179,33,0,16,0,102,105,102,97,32,115,111,99,99,101,114,32,50,48,48,48,32,103,111,108,100,32,101,100,105,116,105,111,110,32,40,112,105,114,97,116,101,41,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,4,245,125,100,33,0,16,0,102,101,114,105,97,115,32,102,114,117,115,116,114,97,100,97,115,32,100,111,32,112,105,99,97,45,112,97,117,32,40,98,114,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,109,65,46,123,33,0,16,0,102,97,116,109,97,110,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,58,218,103,120,33,0,16,0,102,45,49,53,32,115,116,114,105,107,101,32,101,97,103,108,101,32,105,105,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,112,227,142,233,33,0,16,0,101,120,111,100,117,115,32,45,32,106,111,117,114,110,101,121,32,116,111,32,116,104,101,32,112,114,111,109,105,115,101,100,32,108,97,110,100,32,40,117,115,97,41,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,4,252,230,34,33,0,16,0,101,120,105,108,101,32,45,32,116,111,107,105,32,110,111,32,104,97,122,97,109,97,32,101,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,17,243,11,136,33,0,16,0,109,112,114,45,49,51,49,57,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,162,54,182,135,33,0,16,0,101,115,112,110,32,110,97,116,105,111,110,97,108,32,104,111,99,107,101,121,32,110,105,103,104,116,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,140,130,8,29,33,0,16,0,101,115,112,110,32,98,97,115,101,98,97,108,108,32,116,111,110,105,103,104,116,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,12,68,216,150,33,0,16,0,101,108,105,116,115,101,114,105,101,110,32,57,54,32,40,115,119,101,100,101,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,163,208,33,152,33,0,16,0,115,119,101,100,57,53,56,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,192,37,10,225,33,0,16,0,101,97,114,116,104,119,111,114,109,32,106,105,109,32,50,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,167,139,127,213,33,0,16,0,101,99,99,111,32,106,114,46,32,40,117,115,97,44,32,97,117,115,41,32,40,102,101,98,114,117,97,114,121,32,49,57,57,53,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,137,75,111,108,33,0,16,0,101,99,99,111,32,45,32,116,104,101,32,116,105,100,101,115,32,111,102,32,116,105,109,101,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,152,31,178,204,33,0,16,0,101,99,99,111,32,45,32,116,104,101,32,116,105,100,101,115,32,111,102,32,116,105,109,101,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,73,7,182,141,33,0,16,0,109,112,114,45,49,54,57,57,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,156,67,45,6,33,0,16,0,100,121,110,97,32,98,114,111,116,104,101,114,115,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,32,27,12,54,33,0,16,0,100,117,110,101,32,105,105,32,45,32,107,97,109,112,102,32,117,109,32,100,101,110,32,119,117,115,116,101,110,112,108,97,110,101,116,101,110,32,40,103,101,114,109,97,110,121,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,40,7,121,57,33,0,16,0,106,97,115,104,105,110,32,100,114,97,120,111,115,32,40,106,112,110,44,32,107,111,114,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,242,122,160,30,33,0,16,0,100,114,97,103,111,110,32,45,32,116,104,101,32,98,114,117,99,101,32,108,101,101,32,115,116,111,114,121,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,29,213,238,253,33,0,16,0,100,111,109,105,110,111,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,190,9,68,166,33,0,16,0,100,106,32,98,111,121,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,219,2,159,220,33,0,16,0,100,106,32,98,111,121,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,186,42,32,33,0,16,0,100,105,118,105,110,101,32,115,101,97,108,105,110,103,32,40,106,112,110,41,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,60,151,114,202,33,0,16,0,109,112,114,45,49,51,54,54,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,51,117,136,239,33,0,16,0,100,105,97,108,32,113,32,111,32,109,97,119,97,115,101,33,32,40,106,112,110,41,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,175,229,50,198,33,0,16,0,100,105,97,98,108,111,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,160,45,100,189,33,0,16,0,100,121,110,97,109,105,116,101,32,104,101,97,100,100,121,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,83,219,60,208,33,0,16,0,100,97,114,119,105,110,32,52,48,56,49,32,40,106,112,110,44,32,107,111,114,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,203,176,51,122,33,0,16,0,100,97,104,110,97,32,109,101,103,97,109,105,32,116,97,110,106,111,117,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,79,88,2,70,33,0,16,0,100,97,102,102,121,32,100,117,99,107,32,105,110,32,104,111,108,108,121,119,111,111,100,32,40,101,117,114,111,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,64,71,170,14,33,0,16,0,99,97,115,116,108,101,118,97,110,105,97,32,45,32,116,104,101,32,110,101,119,32,103,101,110,101,114,97,116,105,111,110,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,165,228,212,77,33,0,16,0,99,117,116,116,104,114,111,97,116,32,105,115,108,97,110,100,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,112,188,171,235,33,0,16,0,99,114,121,105,110,103,32,45,32,97,115,101,105,109,101,105,32,115,101,110,115,111,117,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,106,29,186,74,33,0,16,0,99,114,117,100,101,32,98,117,115,116,101,114,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,75,251,175,33,0,16,0,99,114,97,121,111,110,32,115,104,105,110,45,99,104,97,110,32,45,32,97,114,97,115,104,105,32,111,32,121,111,98,117,32,101,110,106,105,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,210,66,252,151,33,0,16,0,99,104,97,109,112,105,111,110,115,104,105,112,32,112,114,111,45,97,109,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,40,222,150,180,33,0,16,0,99,111,115,109,105,99,32,115,112,97,99,101,104,101,97,100,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,28,211,147,197,33,0,16,0,99,111,110,116,114,97,32,45,32,104,97,114,100,32,99,111,114,112,115,32,40,117,115,97,44,32,107,111,114,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,94,244,121,197,33,0,16,0,99,111,109,105,120,32,122,111,110,101,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,84,3,218,23,33,0,16,0,99,111,109,105,120,32,122,111,110,101,32,40,101,117,114,111,41,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,117,110,32,50,56,44,32,49,57,57,53,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,76,253,158,147,33,0,16,0,99,111,109,105,120,32,122,111,110,101,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,184,39,96,122,33,0,16,0,99,111,109,98,97,116,32,97,99,101,115,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,90,13,86,132,33,0,16,0,99,111,108,108,101,103,101,32,102,111,111,116,98,97,108,108,39,115,32,110,97,116,105,111,110,97,108,32,99,104,97,109,112,105,111,110,115,104,105,112,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,187,93,44,23,33,0,16,0,99,111,97,99,104,32,107,32,99,111,108,108,101,103,101,32,98,97,115,107,101,116,98,97,108,108,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,198,9,195,103,33,0,16,0,99,108,105,102,102,104,97,110,103,101,114,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,253,241,191,53,33,0,16,0,99,104,105,110,101,115,101,32,102,105,103,104,116,101,114,32,105,105,105,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,110,188,51,232,33,0,16,0,99,104,105,107,105,32,99,104,105,107,105,32,98,111,121,115,32,40,106,112,110,44,32,107,111,114,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,23,140,145,6,33,0,16,0,99,104,105,32,99,104,105,39,115,32,112,114,111,32,99,104,97,108,108,101,110,103,101,32,103,111,108,102,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,164,115,57,156,33,0,16,0,99,104,105,98,105,32,109,97,114,117,107,111,45,99,104,97,110,32,45,32,119,97,107,117,119,97,107,117,32,115,104,111,112,112,105,110,103,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,184,68,161,145,33,0,16,0,99,104,101,115,115,32,40,117,110,108,41,32,91,114,117,115,32,118,49,46,48,53,93,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,131,62,104,16,33,0,16,0,99,104,101,115,115,32,40,117,110,108,41,32,91,114,117,115,93,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0])
.concat([182,247,206,165,33,0,16,0,99,104,101,101,115,101,32,99,97,116,45,97,115,116,114,111,112,104,101,32,115,116,97,114,114,105,110,103,32,115,112,101,101,100,121,32,103,111,110,122,97,108,101,115,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,40,75,99,255,33,0,16,0,99,104,97,107,97,110,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,222,72,106,4,33,0,16,0,99,101,110,116,117,114,105,111,110,32,45,32,100,101,102,101,110,100,101,114,32,111,102,32,114,111,109,101,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,20,59,40,33,33,0,16,0,99,97,101,115,97,114,32,110,111,32,121,97,98,111,117,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,147,110,121,105,33,0,16,0,99,97,100,97,115,104,32,40,117,115,97,44,32,97,115,105,97,44,32,107,111,114,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,116,243,189,19,33,0,16,0,98,117,50,115,103,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,86,255,190,248,33,0,16,0,98,117,98,98,97,39,110,39,115,116,105,120,32,45,32,97,32,115,116,114,97,116,101,103,121,32,97,100,118,101,110,116,117,114,101,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,111,180,92,212,33,0,16,0,98,117,98,98,97,39,110,39,115,116,105,120,32,40,101,117,114,111,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,180,28,115,168,33,0,16,0,98,97,116,116,108,101,116,111,97,100,115,32,40,119,111,114,108,100,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,58,16,14,209,33,0,16,0,98,114,117,116,97,108,32,45,32,112,97,119,115,32,111,102,32,102,117,114,121,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,50,141,154,126,33,0,16,0,98,114,101,116,116,32,104,117,108,108,32,104,111,99,107,101,121,32,39,57,53,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,9,90,119,247,33,0,16,0,98,111,111,103,105,101,32,119,111,111,103,105,101,32,98,111,119,108,105,110,103,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,40,40,245,204,33,0,16,0,98,111,111,103,101,114,109,97,110,32,45,32,97,32,112,105,99,107,32,97,110,100,32,102,108,105,99,107,32,97,100,118,101,110,116,117,114,101,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,12,52,196,219,33,0,16,0,98,111,109,98,111,121,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,25,32,93,6,33,0,16,0,98,111,109,98,101,114,32,91,33,93,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,88,166,137,99,33,0,16,0,98,111,100,121,32,99,111,117,110,116,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,48,160,117,53,33,0,16,0,98,108,111,99,107,98,117,115,116,101,114,32,119,111,114,108,100,32,118,105,100,101,111,32,103,97,109,101,32,99,104,97,109,112,105,111,110,115,104,105,112,32,105,105,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,102,227,133,67,33,0,16,0,98,105,109,105,110,105,32,114,117,110,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,136,81,220,212,33,0,16,0,98,101,115,116,32,111,102,32,116,104,101,32,98,101,115,116,32,45,32,99,104,97,109,112,105,111,110,115,104,105,112,32,107,97,114,97,116,101,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,212,165,214,195,33,0,16,0,98,101,114,101,110,115,116,97,105,110,32,98,101,97,114,115,39,32,99,97,109,112,105,110,103,32,97,100,118,101,110,116,117,114,101,44,32,116,104,101,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,123,35,134,31,33,0,16,0,98,101,97,118,105,115,32,97,110,100,32,98,117,116,116,45,104,101,97,100,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,94,67,182,199,33,0,16,0,98,101,97,117,116,121,32,97,110,100,32,116,104,101,32,98,101,97,115,116,32,45,32,98,101,108,108,101,39,115,32,113,117,101,115,116,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,174,111,251,190,33,0,16,0,98,101,97,115,116,32,119,114,101,115,116,108,101,114,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,100,187,165,12,33,0,16,0,115,104,97,100,111,119,32,111,102,32,116,104,101,32,98,101,97,115,116,32,45,32,109,97,115,104,111,117,32,110,111,32,111,107,105,116,101,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,49,157,208,12,33,0,16,0,115,104,97,100,111,119,32,111,102,32,116,104,101,32,98,101,97,115,116,32,105,105,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,219,227,237,45,33,0,16,0,109,112,114,45,49,52,53,54,49,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,53,12,198,97,33,0,16,0,98,97,115,115,32,109,97,115,116,101,114,115,32,99,108,97,115,115,105,99,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,10,240,31,207,33,0,16,0,98,97,114,118,101,114,32,98,97,116,116,108,101,32,115,97,103,97,32,45,32,116,97,105,32,107,111,110,103,32,122,104,97,110,32,115,104,105,32,40,99,104,105,41,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,198,55,122,211,33,0,16,0,98,97,114,110,101,121,39,115,32,104,105,100,101,32,38,32,115,101,101,107,32,103,97,109,101,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,83,157,250,30,33,0,16,0,98,97,98,121,39,115,32,100,97,121,32,111,117,116,32,40,117,115,97,41,32,40,112,114,111,116,111,116,121,112,101,41,32,40,101,97,114,108,105,101,114,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,28,137,155,69,33,0,16,0,97,119,115,32,112,114,111,32,109,111,118,101,115,32,115,111,99,99,101,114,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,229,23,112,112,33,0,16,0,97,118,97,116,97,114,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,218,10,62,211,33,0,16,0,109,112,114,45,49,51,57,52,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,229,141,172,245,33,0,16,0,97,114,114,111,119,32,102,108,97,115,104,32,40,119,111,114,108,100,41,32,40,97,108,116,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,107,230,137,77,33,0,16,0,97,114,99,117,115,32,111,100,121,115,115,101,121,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,79,251,197,65,33,0,16,0,97,113,32,114,101,110,107,97,110,32,97,119,97,32,40,99,104,105,41,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,119,189,108,44,33,0,16,0,109,112,114,45,49,53,48,54,49,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,27,253,39,179,33,0,16,0,109,112,114,45,49,53,52,56,56,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,199,86,66,34,33,0,16,0,97,101,114,111,32,116,104,101,32,97,99,114,111,45,98,97,116,32,50,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,235,116,235,57,33,0,16,0,109,112,114,45,49,54,49,52,55,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,20,134,245,113,33,0,16,0,52,45,105,110,45,49,32,40,112,105,114,97,116,101,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,123,133,114,190,33,0,16,0,51,32,110,105,110,106,97,115,32,107,105,99,107,32,98,97,99,107,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,153,73,162,229,33,0,16,0,115,117,112,101,114,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,229,206,122,193,33,0,16,0,49,54,32,122,104,97,110,103,32,109,97,32,106,105,97,110,103,32,40,99,104,105,41,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,130,124,64,54,33,0,16,0,109,122,112,45,48,46,117,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,159,39,164,67,0,0,16,1,109,122,112,45,49,46,57,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,186,172,64,219,0,0,16,1,109,122,115,46,117,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,237,247,180,197,0,0,16,1,98,112,57,52,51,97,45,50,46,117,53,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,89,57,225,151,0,0,32,0,98,112,57,52,51,97,45,51,46,117,53,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,221,87,73,156,0,0,32,0,98,112,57,52,51,97,45,49,46,117,54,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,21,116,50,70,0,0,32,0,98,112,57,52,51,97,45,48,46,117,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,138,217,254,193,0,0,32,0,98,112,57,52,51,97,45,52,46,117,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,154,242,199,63,0,0,64,0,109,97,122,105,110,103,101,114,95,106,97,112,97,110,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,69,42,74,248,0,0,16,1,118,49,48,52,95,51,50,109,46,117,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,244,223,217,207,1,0,16,1,116,49,48,48,48,46,117,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,181,121,248,187,2,0,32,0,97,49,48,48,48,46,117,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,200,122,87,67,3,0,32,0,97,49,48,48,49,46,117,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,111,71,122,254,3,0,32,0,97,49,48,48,50,46,117,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,56,61,227,98,3,0,32,0,97,49,48,48,51,46,117,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,90,148,196,178,3,0,32,0,97,49,48,48,52,46,117,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,253,245,211,159,3,0,32,0,98,49,48,48,48,46,117,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,111,31,150,197,4,0,32,0,98,49,48,48,49,46,117,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,6,28,126,11,4,0,32,0,109,49,48,48,48,46,117,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,232,122,64,237,5,0,64,0,109,49,48,48,49,46,117,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,72,45,45,102,5,0,64,0,109,97,114,116,105,97,108,95,109,97,115,116,101,114,115,95,118,49,48,49,95,99,110,46,97,115,105,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,125,91,226,179,7,0,16,1,118,49,48,50,95,49,54,109,46,117,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,230,69,183,24,8,0,16,1,109,116,95,104,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,112,44,104,185,1,0,16,1,109,116,95,108,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,214,159,44,112,1,0,16,1,109,116,95,104,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,48,124,233,217,1,0,16,1,109,116,95,108,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,181,145,189,141,1,0,16,1,109,116,95,115,112,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,169,96,66,228,6,0,16,1,109,116,95,110,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,220,205,24,86,2,0,32,0,109,116,95,110,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,59,135,59,72,2,0,32,0,109,116,95,110,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,91,102,93,79,2,0,32,0,109,116,95,110,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,73,21,87,131,2,0,32,0,109,116,95,99,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,2,122,14,120,3,0,32,0,109,116,95,99,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,129,19,173,69,3,0,32,0,109,116,95,99,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,109,133,245,93,3,0,32,0,109,116,95,99,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,200,108,49,245,3,0,32,0,109,116,95,102,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,213,5,94,45,14,0,32,0,109,116,95,102,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,95,214,140,198,14,0,32,0,109,116,95,102,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,45,235,31,167,14,0,32,0,109,116,95,102,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,98,117,159,23,14,0,32,0,109,116,95,118,111,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,44,187,36,235,5,0,64,0,109,116,50,45,104,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,173,113,141,138,1,0,16,1,109,116,50,45,108,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,81,255,79,221,1,0,16,1,105,115,45,104,49,46,53,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,242,225,168,155,1,0,16,1,105,115,45,108,49,46,53,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,38,6,224,228,1,0,16,1,109,116,50,115,104,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,67,234,203,30,2,0,16,1,109,116,50,115,108,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,49,181,213,143,2,0,16,1,99,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,181,228,97,126,3,0,32,0,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,100,117,102,10,3,0,32,0,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,18,67,180,94,3,0,32,0,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,148,98,134,242,3,0,32,0,107,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,120,38,154,140,4,0,32,0,107,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,120,223,85,84,4,0,32,0,107,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,65,140,37,58,4,0,32,0,107,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,20,26,233,193,4,0,32,0,100,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,159,158,59,113,5,0,64,0,109,116,50,101,101,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,113,249,138,32,6,0,16,1,112,97,108,49,54,108,56,45,109,57,50,45,97,45,51,109,46,105,99,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,7,0,0,16,112,97,108,49,54,108,56,45,109,57,50,45,97,45,55,106,46,105,99,52,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,7,0,0,16,112,97,108,49,54,108,56,45,109,57,50,45,97,45,57,106,46,105,99,53,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,7,0,0,16,112,97,108,49,54,108,56,45,109,57,50,45,98,45,50,108,46,105,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,7,0,0,16,112,97,108,49,54,108,56,45,109,57,50,45,98,45,55,104,46,105,99,52,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,7,0,0,16,55,57,57,120,48,50,46,107,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,80,198,207,66,1,0,16,1,55,57,57,99,48,49,46,102,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,92,76,124,68,2,0,16,1,55,57,57,99,48,54,46,102,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,88,203,57,248,3,0,32,0,55,57,57,99,48,55,46,104,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,56,245,109,23,3,0,32,0,55,57,57,99,48,56,46,106,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,120,0,30,208,3,0,32,0,55,57,57,99,48,57,46,107,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,94,199,174,155,3,0,32,0,55,57,57,98,48,52,46,104,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,43,12,62,50,4,0,32,0,55,57,57,98,48,53,46,107,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,49,88,28,87,4,0,32,0,55,57,57,98,48,51,46,100,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,66,211,207,241,5,0,64,0,55,57,57,98,48,54,46,99,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,215,71,140,44,6,0,32,0,54,51,115,49,52,49,110,46,107,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,209,200,246,97,7,0,0,8,0,0,0,0,0,0,0,0,168,86,7,0,1,0,0,0,216,255,146,0,248,191,2,0,24,38,7,0,1,0,0,0,217,255,146,0,184,160,2,0,144,236,1,0,1,0,0,0,218,255,146,0,136,224,1,0,120,198,7,0,1,0,0,0,219,255,146,0,88,94,5,0,128,9,7,0,1,0,0,0,220,255,146,0,0,69,5,0,160,89,6,0,1,0,0,0,221,255,146,0,0,46,5,0,32,172,5,0,1,0,0,0,222,255,146,0,192,22,5,0,16,24,6,0,1,0,0,0,223,255,146,0,24,8,5,0,16,150,7,0,1,0,0,0,224,255,146,0,40,90,5,0,32,223,6,0,1,0,0,0,225,255,146,0,32,64,5,0,192,43,6,0,1,0,0,0,226,255,146,0,248,37,5,0,88,136,5,0,1,0,0,0,227,255,146,0,48,16,5,0,192,232,5,0,1,0,0,0,228,255,146,0,56,244,4,0,160,103,7,0,1,0,0,0,229,255,146,0,128,83,5,0,168,178,6,0,1,0,0,0,230,255,146,0,48,59,5,0,136,1,6,0,1,0,0,0,231,255,146,0,120,32,5,0,216,192,5,0,1,0,0,0,232,255,146,0,8,252,4,0,192,185,5,0,1,0,0,0,233,255,146,0,128,237,4,0,16,53,7,0,1,0,0,0,234,255,146,0,168,77,5,0,184,135,6,0,1,0,0,0,235,255,146,0,248,53,5,0,216,211,5,0,1,0,0,0,236,255,146,0,192,27,5,0,192,152,5,0,1,0,0,0,237,255,146,0,32,2,5,0,88,212,3,0,1,0,0,0,48,219,146,0,40,185,3,0,117,51,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,2,74,22,168,1,0,16,1,117,51,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,173,133,248,88,1,0,16,1,109,97,103,98,117,98,108,101,46,49,52,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,83,39,25,4,2,0,16,1,117,54,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,205,61,82,137,3,0,32,0,117,54,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,112,26,224,48,3,0,32,0,117,54,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,127,53,254,3,0,32,0,117,55,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,115,164,152,19,3,0,32,0,117,55,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,23,224,68,8,3,0,32,0,117,55,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,203,177,29,89,3,0,32,0,117,55,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,60,60,79,203,3,0,32,0,117,55,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,16,73,255,129,3,0,32,0,109,97,103,98,117,98,108,101,46,117,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,140,59,14,247,4,0,32,0,109,97,103,98,117,98,108,101,46,117,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,243,44,8,173,4,0,32,0,109,97,103,98,117,98,108,101,46,117,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,122,223,104,124,4,0,32,0,109,97,103,98,117,98,108,101,46,117,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,193,63,118,199,4,0,32,0,109,97,103,98,117,98,108,101,46,49,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,137,78,224,3,5,0,64,0,49,50,46,117,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,46,55,29,102,1,0,16,1,51,46,117,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,159,82,99,10,1,0,16,1,48,108,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,93,133,174,204,2,0,32,0,48,104,46,117,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,89,108,20,122,2,0,32,0,49,108,46,117,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,30,210,156,122,2,0,32,0,49,104,46,117,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,13,13,244,120,2,0,32,0,115,110,100,48,46,117,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,143,120,163,45,3,0,64,0,57,51,57,109,48,50,46,101,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,132,33,161,97,0,0,16,1,57,51,57,109,48,51,46,101,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,157,101,182,109,0,0,16,1,57,51,57,101,48,49,46,100,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,72,200,95,74,0,0,16,1,57,51,57,97,48,55,46,107,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,207,223,85,121,0,0,32,0,57,51,57,97,48,56,46,107,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,133,179,149,237,0,0,32,0,57,51,57,97,48,54,46,107,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,6,194,147,227,0,0,32,0,57,51,57,97,48,53,46,107,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,122,212,98,54,0,0,32,0,57,51,57,97,48,52,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,110,43,78,194,0,0,64,0,57,51,57,106,95,48,50,46,101,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,116,74,187,187,0,0,16,1,57,51,57,106,95,48,51,46,101,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,183,167,77,141,0,0,16,1,57,51,57,101,48,49,46,100,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,72,200,95,74,0,0,16,1,57,51,57,97,48,55,46,107,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,207,223,85,121,0,0,32,0,57,51,57,97,48,56,46,107,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,133,179,149,237,0,0,32,0,57,51,57,97,48,54,46,107,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,6,194,147,227,0,0,32,0,57,51,57,97,48,53,46,107,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,122,212,98,54,0,0,32,0,57,51,57,97,48,52,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,110,43,78,194,0,0,64,0,50,51,52,45,112,103,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,109,192,1,205,1,0,16,1,50,51,52,45,112,50,46,115,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,158,40,220,15,1,0,16,1,50,51,52,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,18,20,86,149,2,0,32,0,50,51,52,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,211,43,126,159,3,0,32,0,50,51,52,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,60,61,98,128,3,0,32,0,50,51,52,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,48,26,171,145,3,0,32,0,50,51,52,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,55,176,96,61,3,0,32,0,50,51,52,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,238,12,168,27,3,0,32,0,50,51,52,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,145,208,175,190,3,0,32,0,50,51,52,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,234,40,118,8,4,0,16,1,50,51,52,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,111,183,102,237,5,0,64,0,50,51,52,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,226,246,231,160,5,0,64,0,50,51,52,45,118,51,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,226,225,6,165,5,0,64,0,50,51,52,45,118,52,46,118,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,127,21,52,14,5,0,64,0,112,103,109,95,115,103,113,121,122,99,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,62,74,119,9,1,0,16,1,116,48,54,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,214,26,204,74,2,0,32,0,97,48,54,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,52,120,22,216,3,0,32,0,97,48,54,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,115,67,122,255,3,0,32,0,97,48,54,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,89,41,163,231,3,0,32,0,113,121,122,97,48,54,48,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,32,34,185,200,3,0,32,0,98,48,54,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,89,208,60,125,4,0,32,0,113,121,122,98,48,54,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,130,88,245,100,4,0,32,0,109,48,54,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,214,79,218,58,5,0,64,0,107,111,118,115,103,113,121,122,98,95,105,103,115,48,50,55,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,7,0,16,17,112,103,109,95,115,103,113,121,122,98,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,192,185,184,24,1,0,16,1,116,48,54,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,214,26,204,74,2,0,32,0,97,48,54,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,52,120,22,216,3,0,32,0,97,48,54,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,115,67,122,255,3,0,32,0,97,48,54,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,89,41,163,231,3,0,32,0,113,121,122,97,48,54,48,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,32,34,185,200,3,0,32,0,98,48,54,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,89,208,60,125,4,0,32,0,113,121,122,98,48,54,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,130,88,245,100,4,0,32,0,109,48,54,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,214,79,218,58,5,0,64,0,107,111,118,115,103,113,121,122,98,95,105,103,115,48,50,55,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,7,0,16,17,112,103,109,95,115,103,113,121,122,97,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,183,220,48,90,1,0,16,1,116,48,54,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,214,26,204,74,2,0,32,0,97,48,54,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,52,120,22,216,3,0,32,0,97,48,54,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,115,67,122,255,3,0,32,0,97,48,54,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,89,41,163,231,3,0,32,0,113,121,122,97,48,54,48,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,32,34,185,200,3,0,32,0,98,48,54,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,89,208,60,125,4,0,32,0,113,121,122,98,48,54,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,130,88,245,100,4,0,32,0,109,48,54,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,214,79,218,58,5,0,64,0,107,111,118,115,103,113,121,122,97,95,105,103,115,48,50,55,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,7,0,16,17,113,104,115,103,97,95,99,53,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,112,160,94,76,1,0,16,1,108,115,113,104,50,95,116,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,127,217,152,212,2,0,32,0,108,115,113,104,50,95,97,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,253,62,174,37,3,0,32,0,108,115,113,104,50,95,97,50,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,145,119,122,3,0,32,0,108,115,113,104,50,95,97,52,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,82,224,125,93,3,0,32,0,108,115,113,104,50,95,98,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,150,166,124,223,4,0,32,0,108,115,113,104,50,95,109,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,101,27,175,1,5,0,64,0,113,104,115,103,95,112,114,111,116,46,99,53,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,193,165,9,15,7,0,16,1,107,101,116,115,116,111,105,99,117,95,118,49,48,48,46,117,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,228,132,201,53,1,0,16,1,116,48,52,55,48,49,119,48,54,52,46,117,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,65,176,101,38,2,0,32,0,97,48,52,55,48,49,119,48,54,52,46,117,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,75,185,241,94,3,0,32,0,97,48,52,55,48,50,119,48,54,52,46,117,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,127,218,214,38,3,0,32,0,98,48,52,55,48,49,119,48,54,52,46,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,141,0,236,27,4,0,32,0,109,48,52,55,48,49,98,48,51,50,46,117,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,209,34,110,180,5,0,64,0,107,101,116,95,105,103,115,48,50,55,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,7,0,16,17,107,101,116,95,100,101,102,97,117,108,116,115,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,216,146,168,60,0,0,0,8,107,101,116,97,114,114,49,53,49,95,118,49,48,48,46,117,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,13,3,124,43,1,0,16,1,116,48,52,55,48,49,119,48,54,52,46,117,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,65,176,101,38,2,0,32,0,97,48,52,55,48,49,119,48,54,52,46,117,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,75,185,241,94,3,0,32,0,97,48,52,55,48,50,119,48,54,52,46,117,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,127,218,214,38,3,0,32,0,98,48,52,55,48,49,119,48,54,52,46,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,141,0,236,27,4,0,32,0,109,48,52,55,48,49,98,48,51,50,46,117,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,209,34,110,180,5,0,64,0,107,101,116,95,105,103,115,48,50,55,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,7,0,16,17,107,101,116,95,100,101,102,97,117,108,116,115,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,216,146,168,60,0,0,0,8,106,115,54,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,94,225,197,172,1,0,16,1,106,115,54,102,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,164,139,180,98,1,0,16,1,106,115,54,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,48,94,155,124,1,0,16,1,106,115,54,106,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,246,57,12,159,1,0,16,1,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,245,144,250,217,2,0,32,0,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,193,17,199,46,2,0,32,0,112,114,111,109,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,243,66,43,135,3,0,32,0,112,114,111,109,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,159,243,153,3,3,0,32,0,56,50,115,49,50,54,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,134,204,169,4,0,64,0,56,50,115,49,50,54,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,87,84,0,0,78,73,0,0,75,95,0,0,73,65,0,0,69,83,0,0,95,82,0,0,73,77,0,0,65,89,0,0,65,82,0,0,73,83,0,0,79,77,0,0,73,74,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,254,255,255,255,79,89,0,0,255,255,255,255,117,78,0,0,255,255,255,255,255,255,255,255,255,255,255,255,254,255,255,255,255,255,255,255,255,255,255,255,117,78,0,0,255,255,255,255,73,83,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,117,78,0,0,255,255,255,255,73,72,0,0,255,255,255,255,255,255,255,255,254,255,255,255,255,255,255,255,255,255,255,255,79,82,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,254,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,106,111,106,111,98,97,95,106,97,112,97,110,95,110,111,99,100,46,50,57,102,52,48,48,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,245,25,171,77,0,0,0,3,106,111,106,111,98,97,40,95,95,57,57,48,57,49,51,41,45,115,105,109,109,49,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,49,98,151,118,0,0,16,1,106,111,106,111,98,97,40,95,95,57,57,48,57,49,51,41,45,115,105,109,109,49,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,231,120,221,206,0,0,16,1,106,111,106,111,98,97,40,95,95,57,57,48,57,49,51,41,45,115,105,109,109,49,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,127,183,85,41,0,0,16,1,106,111,106,111,98,97,40,95,95,57,57,48,57,49,51,41,45,115,105,109,109,49,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,215,57,1,40,0,0,16,1,106,111,106,111,98,97,40,95,95,57,57,48,57,49,51,41,45,115,105,109,109,50,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,20,73,92,48,0,0,16,1,106,111,106,111,98,97,40,95,95,57,57,48,57,49,51,41,45,115,105,109,109,50,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,59,79,175,24,0,0,16,1,106,111,106,111,98,97,40,95,95,57,57,48,57,49,51,41,45,115,105,109,109,50,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,158,92,126,57,0,0,16,1,106,111,106,111,98,97,40,95,95,57,57,48,57,49,51,41,45,115,105,109,109,50,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,215,167,208,169,0,0,16,1,106,111,106,111,98,97,45,115,105,109,109,51,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,17,225,22,77,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,51,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,211,6,52,155,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,51,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,151,73,65,242,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,51,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,125,156,75,149,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,51,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,29,220,90,98,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,51,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,180,11,167,32,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,51,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,175,197,14,161,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,51,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,122,222,208,11,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,52,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,220,74,161,110,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,52,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,251,66,76,143,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,52,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,209,134,5,239,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,52,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,112,196,204,147,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,52,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,210,199,158,61,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,52,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,80,104,230,3,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,52,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,195,106,96,1,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,52,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,135,43,57,54,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,53,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,12,198,248,46,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,53,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,166,124,125,207,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,53,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,250,91,129,183,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,53,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,73,192,254,155,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,53,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,107,83,103,209,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,53,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,66,160,231,85,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,53,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,6,41,179,79,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,53,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,32,229,139,140,0,0,32,0,48,48,56,45,101,112,114,95,97,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,50,85,243,184,1,0,16,1,48,48,56,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,24,191,172,169,3,0,32,0,48,48,56,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,249,238,137,98,3,0,32,0,48,48,56,45,109,103,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,144,198,99,209,4,0,16,1,48,48,56,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,186,173,62,68,5,0,64,0,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,7,189,213,175,1,0,16,1,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,102,115,10,116,1,0,16,1,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,247,2,149,150,3,0,32,0,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,209,83,82,118,3,0,32,0,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,187,164,227,177,4,0,32,0,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,247,124,211,165,4,0,32,0,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,184,85,26,24,6,0,64,0,112,114,111,116,111,95,50,50,48,45,112,49,111,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,160,227,55,206,1,0,16,1,112,114,111,116,111,95,50,50,48,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,23,226,47,55,2,0,32,0,112,114,111,116,111,95,50,50,48,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,220,183,162,154,3,0,32,0,112,114,111,116,111,95,50,50,48,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,8,215,42,138,3,0,32,0,112,114,111,116,111,95,50,50,48,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,90,177,127,214,3,0,32,0,112,114,111,116,111,95,50,50,48,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,139,163,62,231,3,0,32,0,112,114,111,116,111,95,50,50,48,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,99,187,8,58,4,0,16,1,112,114,111,116,111,95,50,50,48,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,21,162,48,143,5,0,64,0,105,102,45,99,45,104,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,128,45,45,89,1,0,16,1,105,102,45,99,45,108,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,86,144,248,97,1,0,16,1,105,102,45,99,45,104,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,65,5,3,234,1,0,16,1,105,102,45,99,45,108,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,72,227,106,198,1,0,16,1,105,102,45,99,45,48,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,56,102,94,116,2,0,32,0,105,102,45,99,45,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,73,132,16,183,2,0,32,0,105,102,45,99,45,50,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,186,60,243,174,2,0,32,0,105,102,45,99,45,51,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,149,230,152,31,2,0,32,0,105,102,45,97,45,97,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,119,45,238,52,3,0,32,0,105,102,45,97,45,97,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,91,132,210,107,3,0,32,0,105,102,45,97,45,97,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,229,80,13,9,3,0,32,0,105,102,45,97,45,97,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,131,48,142,58,3,0,32,0,105,102,45,97,45,98,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,41,200,37,180,4,0,32,0,105,102,45,97,45,98,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,62,226,191,233,4,0,32,0,105,102,45,97,45,98,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,242,80,110,37,4,0,32,0,105,102,45,97,45,98,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,133,39,104,76,4,0,32,0,105,102,45,99,45,118,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,148,161,100,203,5,0,64,0,105,102,45,99,45,118,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,245,139,182,69,5,0,64,0,105,109,103,102,105,103,104,116,106,95,105,56,55,53,49,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,152,80,13,239,0,0,0,8,0,0,0,0,0,0,0,0,168,86,7,0,1,0,0,0,72,244,146,0,248,191,2,0,24,38,7,0,1,0,0,0,136,252,146,0,184,160,2,0,56,210,6,0,1,0,0,0,137,252,146,0,192,135,2,0,24,163,6,0,1,0,0,0,138,252,146,0,240,108,2,0,152,122,6,0,1,0,0,0,139,252,146,0,96,82,2,0,192,72,6,0,1,0,0,0,140,252,146,0,32,56,2,0,200,110,3,0,1,0,0,0,141,252,146,0,152,30,2,0,120,89,3,0,1,0,0,0,142,252,146,0,232,10,2,0,120,74,3,0,1,0,0,0,143,252,146,0,152,138,8,0,40,246,1,0,1,0,0,0,73,244,146,0,64,246,1,0,144,236,1,0,1,0,0,0,144,252,146,0,136,224,1,0,176,223,1,0,1,0,0,0,145,252,146,0,72,198,1,0,192,209,1,0,1,0,0,0,146,252,146,0,24,182,1,0,24,198,1,0,1,0,0,0,147,252,146,0,40,167,1,0,120,189,1,0,1,0,0,0,148,252,146,0,200,149,1,0,224,22,1,0,1,0,0,0,149,252,146,0,56,126,1,0,160,14,1,0,1,0,0,0,150,252,146,0,32,101,1,0,176,9,1,0,1,0,0,0,151,252,146,0,96,32,8,0,88,212,3,0,1,0,0,0,8,217,146,0,40,185,3,0,32,77,1,0,1,0,0,0,74,244,146,0,216,70,1,0,16,17,8,0,1,0,0,0,75,244,146,0,224,12,8,0,103,102,95,104,48,45,100,46,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,92,123,219,166,1,0,16,1,103,102,95,108,48,45,100,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,246,85,207,130,1,0,16,1,103,102,95,104,49,45,100,46,53,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,108,115,163,8,1,0,16,1,103,102,95,108,49,45,100,46,53,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,79,82,95,67,1,0,16,1,103,102,95,115,104,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,224,22,143,63,2,0,16,1,103,102,95,115,108,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,163,19,11,219,2,0,16,1,103,102,95,99,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,121,73,183,179,3,0,32,0,103,102,95,99,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,10,89,200,245,3,0,32,0,103,102,95,99,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,100,251,249,48,3,0,32,0,103,102,95,99,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,33,230,179,135,3,0,32,0,103,102,95,48,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,141,142,158,32,4,0,32,0,103,102,95,48,49,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,8,120,110,110,4,0,32,0,103,102,95,48,50,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,176,60,92,111,4,0,32,0,103,102,95,48,51,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,159,138,151,24,4,0,32,0,103,102,45,100,97,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,53,169,59,147,5,0,64,0,103,102,98,95,104,48,45,101,46,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,15,110,195,67,1,0,16,1,103,102,98,95,108,48,45,101,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,216,88,165,36,1,0,16,1,103,102,98,95,104,49,45,101,46,53,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,93,79,116,217,1,0,16,1,103,102,98,95,108,49,45,101,46,53,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,27,182,247,160,1,0,16,1,103,102,95,115,104,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,224,22,143,63,2,0,16,1,103,102,95,115,108,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,163,19,11,219,2,0,16,1,103,102,95,99,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,121,73,183,179,3,0,32,0,103,102,95,99,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,10,89,200,245,3,0,32,0,103,102,95,99,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,100,251,249,48,3,0,32,0,103,102,95,99,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,33,230,179,135,3,0,32,0,103,102,95,48,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,141,142,158,32,4,0,32,0,103,102,95,48,49,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,8,120,110,110,4,0,32,0,103,102,95,48,50,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,176,60,92,111,4,0,32,0,103,102,95,48,51,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,159,138,151,24,4,0,32,0,103,102,45,100,97,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,53,169,59,147,5,0,64,0,168,86,7,0,1,0,0,0,16,3,147,0,248,191,2,0,24,38,7,0,1,0,0,0,64,255,146,0,184,160,2,0,56,210,6,0,1,0,0,0,71,255,146,0,192,135,2,0,24,163,6,0,1,0,0,0,70,255,146,0,240,108,2,0,152,122,6,0,1,0,0,0,68,255,146,0,96,82,2,0,192,72,6,0,1,0,0,0,69,255,146,0,32,56,2,0,200,110,3,0,1,0,0,0,67,255,146,0,152,30,2,0,120,89,3,0,1,0,0,0,66,255,146,0,232,10,2,0,120,74,3,0,1,0,0,0,65,255,146,0,152,138,8,0,40,246,1,0,1,0,0,0,17,3,147,0,64,246,1,0,144,236,1,0,1,0,0,0,216,246,146,0,136,224,1,0,176,223,1,0,1,0,0,0,223,246,146,0,72,198,1,0,192,209,1,0,1,0,0,0,222,246,146,0,24,182,1,0,24,198,1,0,1,0,0,0,220,246,146,0,40,167,1,0,120,189,1,0,1,0,0,0,221,246,146,0,200,149,1,0,224,22,1,0,1,0,0,0,219,246,146,0,56,126,1,0,160,14,1,0,1,0,0,0,218,246,146,0,32,101,1,0,176,9,1,0,1,0,0,0,217,246,146,0,96,32,8,0,88,212,3,0,1,0,0,0,224,218,146,0,40,185,3,0,80,251,6,0,1,0,0,0,21,3,147,0,216,70,1,0,16,17,8,0,1,0,0,0,20,3,147,0,224,12,8,0,248,5,8,0,9,0,0,0,173,224,146,0,32,58,1,0,144,250,7,0,9,0,0,0,172,224,146,0,32,58,1,0,248,241,7,0,9,0,0,0,174,224,146,0,32,58,1,0,97,102,101,103,97,50,46,117,49,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,80,16,212,22,1,0,16,1,97,102,101,103,97,51,46,117,49,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,153,10,146,5,1,0,16,1,97,102,101,103,97,55,46,117,57,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,142,242,140,93,2,0,16,1,97,102,101,103,97,49,46,117,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,134,240,126,158,3,0,32,0,97,102,101,103,97,95,97,102,49,45,98,50,46,117,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,194,136,133,214,4,0,32,0,97,102,101,103,97,95,97,102,49,45,98,49,46,117,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,168,0,178,248,4,0,32,0,97,102,101,103,97,54,46,117,99,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,132,255,84,155,5,0,32,0,97,102,101,103,97,49,46,117,57,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,51,206,17,233,6,0,64,0,103,115,116,45,48,52,46,117,49,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,26,147,44,146,1,0,16,1,103,115,116,45,48,53,46,117,49,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,220,162,44,210,1,0,16,1,97,102,101,103,97,55,46,117,57,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,142,242,140,93,2,0,16,1,103,115,116,45,48,51,46,117,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,151,114,52,161,3,0,32,0,97,102,101,103,97,95,97,102,49,45,98,50,46,117,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,194,136,133,214,4,0,32,0,97,102,101,103,97,95,97,102,49,45,98,49,46,117,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,168,0,178,248,4,0,32,0,97,102,101,103,97,95,97,102,49,45,115,112,46,117,99,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,133,73,77,125,5,0,32,0,97,102,101,103,97,49,46,117,57,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,51,206,17,233,6,0,64,0,103,115,54,95,99,50,46,117,99,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,77,62,54,234,1,0,16,1,103,115,53,95,99,49,46,117,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,74,62,38,192,1,0,16,1,103,115,49,95,115,49,46,117,99,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,142,242,140,93,2,0,16,1,103,115,51,95,116,49,46,117,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,239,35,196,136,3,0,32,0,103,115,49,48,95,99,114,53,46,117,99,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,227,35,140,44,4,0,32,0,103,115,52,95,99,114,55,46,117,99,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,8,201,246,195,4,0,32,0,103,115,56,95,99,114,49,46,117,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,240,37,1,220,4,0,32,0,103,115,57,95,99,114,51,46,117,99,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,107,99,160,216,4,0,32,0,103,115,56,95,98,114,51,46,117,99,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,122,165,66,123,5,0,32,0,103,115,55,95,98,114,49,46,117,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,101,66,121,230,5,0,32,0,103,115,49,48,95,98,114,52,46,117,99,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,225,87,59,29,5,0,32,0,103,115,57,95,98,114,50,46,117,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,11,34,44,77,5,0,32,0,103,115,50,95,115,50,46,117,99,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,51,206,17,233,6,0,64,0,168,86,7,0,1,0,0,0,160,191,145,0,248,191,2,0,152,122,6,0,1,0,0,0,120,253,146,0,96,82,2,0,192,72,6,0,1,0,0,0,121,253,146,0,32,56,2,0,56,210,6,0,1,0,0,0,122,253,146,0,192,135,2,0,24,163,6,0,1,0,0,0,123,253,146,0,240,108,2,0,200,110,3,0,1,0,0,0,124,253,146,0,152,30,2,0,120,89,3,0,1,0,0,0,125,253,146,0,232,10,2,0,120,74,3,0,1,0,0,0,126,253,146,0,152,138,8,0,24,38,7,0,1,0,0,0,127,253,146,0,184,160,2,0,40,246,1,0,1,0,0,0,161,191,145,0,64,246,1,0,24,198,1,0,1,0,0,0,40,245,146,0,40,167,1,0,120,189,1,0,1,0,0,0,41,245,146,0,200,149,1,0,176,223,1,0,1,0,0,0,42,245,146,0,72,198,1,0,192,209,1,0,1,0,0,0,43,245,146,0,24,182,1,0,224,22,1,0,1,0,0,0,44,245,146,0,56,126,1,0,160,14,1,0,1,0,0,0,45,245,146,0,32,101,1,0,176,9,1,0,1,0,0,0,46,245,146,0,96,32,8,0,144,236,1,0,1,0,0,0,47,245,146,0,136,224,1,0,88,212,3,0,1,0,0,0,168,217,146,0,40,185,3,0,32,77,1,0,1,0,0,0,163,191,145,0,216,70,1,0,16,17,8,0,1,0,0,0,162,191,145,0,224,12,8,0,72,65,1,0,9,0,0,0,35,224,146,0,32,58,1,0,48,50,1,0,9,0,0,0,36,224,146,0,32,58,1,0,57,52,53,95,115,49,51,46,102,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,162,64,194,112,1,0,16,1,57,52,53,95,115,49,50,46,101,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,212,0,195,187,1,0,16,1,57,52,53,95,109,48,57,46,114,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,37,223,166,180,2,0,16,1,57,52,53,95,109,48,56,46,110,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,210,129,233,116,2,0,16,1,57,52,53,95,108,48,54,98,46,114,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,4,35,119,131,2,0,16,1,57,52,53,95,108,48,54,97,46,110,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,182,117,253,225,2,0,16,1,57,52,53,95,108,48,55,99,46,114,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,182,153,227,193,2,0,16,1,57,52,53,95,108,48,55,97,46,110,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,4,45,34,150,2,0,16,1,57,52,53,95,108,48,55,100,46,114,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,189,212,22,76,2,0,16,1,57,52,53,95,108,48,55,98,46,110,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,1,157,32,94,2,0,16,1,57,52,53,95,109,48,53,46,100,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,101,83,196,200,3,0,16,1,57,52,53,95,97,48,50,46,108,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,116,253,255,77,4,0,32,0,57,52,53,95,108,48,52,97,46,107,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,238,33,78,136,4,0,32,0,57,52,53,95,108,48,52,99,46,109,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,33,217,188,69,4,0,32,0,57,52,53,95,108,48,52,98,46,107,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,125,198,59,132,4,0,32,0,57,52,53,95,108,48,52,100,46,109,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,142,208,152,10,4,0,32,0,57,52,53,95,97,48,49,46,104,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,210,109,157,51,4,0,32,0,57,52,53,95,108,48,51,97,46,101,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,135,240,126,166,4,0,32,0,57,52,53,95,108,48,51,99,46,104,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,122,225,107,165,4,0,32,0,57,52,53,95,108,48,51,98,46,101,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,185,104,62,147,4,0,32,0,57,52,53,95,108,48,51,100,46,104,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,123,232,117,243,4,0,32,0,57,52,53,95,97,49,48,46,98,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,16,62,8,29,5,0,64,0,57,52,53,95,108,49,49,97,46,99,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,235,244,67,96,5,0,64,0,57,52,53,95,108,49,49,98,46,99,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,175,59,234,137,5,0,64,0,57,52,53,108,49,52,46,106,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,137,193,120,199,6,0,0,8,55,56,53,95,112,48,53,46,54,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,54,231,176,77,1,0,16,1,55,56,53,95,112,48,52,46,52,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,230,153,91,118,1,0,16,1,55,56,53,95,106,48,57,46,54,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,227,167,150,109,1,0,16,1,55,56,53,95,106,48,56,46,52,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,8,145,28,43,1,0,16,1,55,56,53,95,112,48,55,46,49,48,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,157,84,109,104,2,0,16,1,55,56,53,95,112,48,54,46,56,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,238,75,201,112,2,0,16,1,55,56,53,95,112,49,51,46,49,48,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,10,219,143,71,2,0,16,1,55,56,53,95,112,49,50,46,56,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,42,64,234,56,2,0,16,1,55,56,53,95,103,48,51,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,13,181,163,103,3,0,16,1,55,56,53,95,103,49,52,46,100,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,157,173,205,157,4,0,32,0,55,56,53,102,49,55,46,112,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,164,193,190,143,5,0,32,0,55,56,53,102,49,56,46,112,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,56,30,214,80,5,0,32,0,55,56,53,102,49,53,46,112,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,243,174,150,175,5,0,32,0,55,56,53,102,49,54,46,112,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,31,223,88,184,5,0,32,0,55,56,53,95,102,48,49,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,158,214,216,160,7,0,32,0,55,56,53,95,102,48,50,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,164,92,159,195,8,0,32,0,55,56,53,95,112,48,53,46,54,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,54,231,176,77,1,0,16,1,55,56,53,95,112,48,52,46,52,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,230,153,91,118,1,0,16,1,55,56,53,95,116,48,57,46,54,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,101,73,63,78,1,0,16,1,55,56,53,95,106,48,56,46,52,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,8,145,28,43,1,0,16,1,55,56,53,95,112,48,55,46,49,48,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,157,84,109,104,2,0,16,1,55,56,53,95,112,48,54,46,56,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,238,75,201,112,2,0,16,1,55,56,53,95,112,49,51,46,49,48,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,10,219,143,71,2,0,16,1,55,56,53,95,112,49,50,46,56,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,42,64,234,56,2,0,16,1,55,56,53,95,103,48,51,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,13,181,163,103,3,0,16,1,55,56,53,95,103,49,52,46,100,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,157,173,205,157,4,0,32,0,55,56,53,102,49,55,46,112,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,164,193,190,143,5,0,32,0,55,56,53,102,49,56,46,112,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,56,30,214,80,5,0,32,0,55,56,53,102,49,53,46,112,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,243,174,150,175,5,0,32,0,55,56,53,102,49,54,46,112,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,31,223,88,184,5,0,32,0,55,56,53,95,102,48,49,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,158,214,216,160,7,0,64,0,55,56,53,95,102,48,50,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,164,92,159,195,8,0,64,0,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,163,216,161,109,1,0,16,1,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,89,45,211,11,1,0,16,1,103,110,95,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,231,16,110,231,2,0,16,1,103,110,95,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,251,201,138,27,3,0,32,0,103,110,95,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,104,230,63,231,3,0,32,0,103,110,95,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,233,161,52,193,4,0,32,0,103,110,95,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,33,236,59,29,4,0,32,0,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,69,7,162,72,5,0,32,0,103,110,95,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,53,88,198,189,6,0,32,0,103,110,95,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,254,234,184,194,6,0,32,0,103,110,95,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,24,60,199,247,6,0,32,0,103,110,95,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,59,124,224,165,6,0,32,0,103,110,95,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,5,230,208,240,7,0,32,0,103,110,95,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,59,19,217,14,8,0,64,0,103,110,95,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,44,34,186,241,8,0,64,0,168,86,7,0,1,0,0,0,166,219,148,0,248,191,2,0,24,38,7,0,1,0,0,0,164,219,148,0,184,160,2,0,56,210,6,0,1,0,0,0,168,219,148,0,192,135,2,0,24,163,6,0,1,0,0,0,170,219,148,0,240,108,2,0,152,122,6,0,1,0,0,0,171,219,148,0,96,82,2,0,192,72,6,0,1,0,0,0,169,219,148,0,32,56,2,0,200,110,3,0,1,0,0,0,161,219,148,0,152,30,2,0,120,89,3,0,1,0,0,0,160,219,148,0,232,10,2,0,40,246,1,0,1,0,0,0,167,219,148,0,64,246,1,0,144,236,1,0,1,0,0,0,165,219,148,0,136,224,1,0,176,223,1,0,1,0,0,0,172,219,148,0,72,198,1,0,192,209,1,0,1,0,0,0,174,219,148,0,24,182,1,0,24,198,1,0,1,0,0,0,175,219,148,0,40,167,1,0,120,189,1,0,1,0,0,0,173,219,148,0,200,149,1,0,224,22,1,0,1,0,0,0,163,219,148,0,56,126,1,0,160,14,1,0,1,0,0,0,162,219,148,0,32,101,1,0,88,212,3,0,1,0,0,0,168,38,149,0,40,185,3,0,72,65,1,0,9,0,0,0,178,38,149,0,32,58,1,0,48,50,1,0,9,0,0,0,179,38,149,0,32,58,1,0,184,40,2,0,1,0,0,0,231,240,146,0,248,191,2,0,184,164,8,0,1,0,0,0,230,240,146,0,64,246,1,0,24,38,7,0,1,0,0,0,229,240,146,0,184,160,2,0,144,236,1,0,1,0,0,0,228,240,146,0,136,224,1,0,152,122,6,0,1,0,0,0,192,1,147,0,96,82,2,0,192,72,6,0,1,0,0,0,193,1,147,0,32,56,2,0,56,210,6,0,1,0,0,0,194,1,147,0,192,135,2,0,24,163,6,0,1,0,0,0,195,1,147,0,240,108,2,0,200,110,3,0,1,0,0,0,196,1,147,0,152,30,2,0,120,89,3,0,1,0,0,0,197,1,147,0,232,10,2,0,88,212,3,0,1,0,0,0,64,221,146,0,40,185,3,0,248,5,8,0,9,0,0,0,11,7,147,0,32,58,1,0,144,250,7,0,9,0,0,0,10,7,147,0,32,58,1,0,168,86,7,0,1,0,0,0,0,2,147,0,248,191,2,0,24,38,7,0,1,0,0,0,67,249,146,0,184,160,2,0,200,110,3,0,1,0,0,0,64,249,146,0,152,30,2,0,120,89,3,0,1,0,0,0,65,249,146,0,232,10,2,0,120,74,3,0,1,0,0,0,66,249,146,0,152,138,8,0,40,246,1,0,1,0,0,0,1,2,147,0,64,246,1,0,144,236,1,0,1,0,0,0,71,249,146,0,136,224,1,0,224,22,1,0,1,0,0,0,68,249,146,0,56,126,1,0,160,14,1,0,1,0,0,0,69,249,146,0,32,101,1,0,176,9,1,0,1,0,0,0,70,249,146,0,96,32,8,0,72,126,8,0,1,0,0,0,35,241,146,0,144,189,1,0,248,67,8,0,1,0,0,0,32,241,146,0,32,92,1,0,136,64,8,0,1,0,0,0,33,241,146,0,64,77,1,0,128,58,8,0,1,0,0,0,34,241,146,0,112,157,4,0,160,19,8,0,1,0,0,0,39,241,146,0,32,245,8,0,176,222,7,0,1,0,0,0,36,241,146,0,144,180,8,0,176,218,7,0,1,0,0,0,37,241,146,0,208,164,8,0,248,214,7,0,1,0,0,0,38,241,146,0,160,152,4,0,88,212,3,0,1,0,0,0,120,221,146,0,40,185,3,0,16,17,8,0,1,0,0,0,2,2,147,0,224,12,8,0,72,65,1,0,9,0,0,0,56,7,147,0,32,58,1,0,48,50,1,0,9,0,0,0,57,7,147,0,32,58,1,0,224,41,1,0,9,0,0,0,58,7,147,0,32,58,1,0,106,104,48,48,45,50,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,183,152,91,1,0,16,1,106,104,48,49,45,50,46,49,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,32,2,40,33,1,0,16,1,106,107,48,50,46,49,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,216,11,140,116,2,0,16,1,109,97,116,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,126,76,185,228,3,0,32,0,109,97,116,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,141,58,9,36,4,0,32,0,109,97,116,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,40,2,218,251,4,0,32,0,106,107,48,51,46,49,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,247,234,160,105,5,0,64,0,116,112,45,48,50,54,45,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,106,116,177,247,0,0,16,1,116,112,45,48,50,54,45,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,152,141,87,229,0,0,32,0,116,112,45,48,50,54,45,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,83,203,96,183,0,0,32,0,116,112,45,48,50,54,45,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,31,63,6,133,0,0,64,0,57,51,99,52,53,46,117,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,240,93,215,64,0,0,16,1,102,105,120,101,105,103,104,116,117,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,59,252,254,93,0,0,16,1,116,112,45,48,50,54,45,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,106,116,177,247,0,0,16,1,116,112,45,48,50,54,45,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,152,141,87,229,0,0,32,0,116,112,45,48,50,54,45,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,83,203,96,183,0,0,32,0,116,112,45,48,50,54,45,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,31,63,6,133,0,0,64,0,57,51,99,52,53,46,117,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,240,93,215,64,0,0,16,1,102,105,120,101,105,103,104,116,116,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,5,74,218,192,0,0,16,1,116,112,45,48,50,54,45,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,106,116,177,247,0,0,16,1,116,112,45,48,50,54,45,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,152,141,87,229,0,0,32,0,116,112,45,48,50,54,45,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,83,203,96,183,0,0,32,0,116,112,45,48,50,54,45,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,31,63,6,133,0,0,64,0,57,51,99,52,53,46,117,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,240,93,215,64,0,0,16,1,102,105,120,101,105,103,104,116,107,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,111,28,201,202,0,0,16,1,116,112,45,48,50,54,45,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,106,116,177,247,0,0,16,1,116,112,45,48,50,54,45,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,152,141,87,229,0,0,32,0,116,112,45,48,50,54,45,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,83,203,96,183,0,0,32,0,116,112,45,48,50,54,45,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,31,63,6,133,0,0,64,0,57,51,99,52,53,46,117,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,240,93,215,64,0,0,16,1,102,105,120,101,105,103,104,116,106,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,56,32,226,33,0,0,16,1,116,112,45,48,50,54,45,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,106,116,177,247,0,0,16,1,116,112,45,48,50,54,45,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,152,141,87,229,0,0,32,0,116,112,45,48,50,54,45,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,83,203,96,183,0,0,32,0,116,112,45,48,50,54,45,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,31,63,6,133,0,0,64,0,57,51,99,52,53,46,117,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,240,93,215,64,0,0,16,1,102,105,120,101,105,103,104,116,104,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,132,197,222,149,0,0,16,1,116,112,45,48,50,54,45,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,106,116,177,247,0,0,16,1,116,112,45,48,50,54,45,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,152,141,87,229,0,0,32,0,116,112,45,48,50,54,45,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,83,203,96,183,0,0,32,0,116,112,45,48,50,54,45,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,31,63,6,133,0,0,64,0,57,51,99,52,53,46,117,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,240,93,215,64,0,0,16,1,102,105,120,101,105,103,104,116,97,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,82,118,241,43,0,0,16,1,111,49,55,95,48,57,100,121,110,46,56,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,39,238,94,226,0,0,16,1,111,49,55,95,49,48,100,121,110,46,56,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,246,140,197,196,0,0,16,1,111,49,55,95,49,49,105,105,46,55,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,120,195,234,107,0,0,16,1,111,49,55,95,49,50,105,105,46,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,181,110,219,106,0,0,16,1,111,49,55,95,48,53,46,49,50,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,248,21,83,86,0,0,32,0,111,49,55,95,48,54,46,49,51,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,76,45,38,149,0,0,32,0,111,49,55,95,48,55,46,49,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,92,115,75,76,0,0,32,0,111,49,55,95,48,56,46,49,51,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,108,88,198,149,0,0,32,0,111,49,55,95,48,49,46,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,145,228,18,234,0,0,32,0,111,49,55,95,48,50,46,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,159,58,161,50,0,0,32,0,111,49,55,95,48,51,46,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,201,61,114,104,0,0,32,0,111,49,55,95,48,52,46,55,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,19,203,14,254,0,0,32,0,112,114,111,109,49,52,46,50,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,237,204,136,188,0,0,32,0,112,114,111,109,49,53,46,50,48,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,146,116,225,161,0,0,32,0,104,100,54,52,55,49,56,48,46,48,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,24,48,54,48,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,80,75,16,42,1,0,16,1,48,54,48,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,4,33,1,127,2,0,32,0,48,54,48,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,249,255,8,137,3,0,32,0,48,54,48,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,146,148,100,198,3,0,32,0,48,54,48,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,55,180,86,9,3,0,32,0,48,54,48,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,98,59,111,2,3,0,32,0,48,54,48,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,101,78,124,11,4,0,16,1,48,54,48,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,21,194,23,244,5,0,64,0,48,54,48,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,207,247,207,239,5,0,64,0,48,54,48,45,101,112,114,46,115,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,27,4,50,48,0,0,16,1,48,53,56,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,162,91,88,47,1,0,16,1,48,53,56,45,112,50,46,115,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,107,26,199,215,1,0,16,1,48,53,56,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,151,49,240,45,2,0,32,0,48,53,56,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,60,177,74,4,3,0,32,0,48,53,56,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,150,191,230,17,3,0,32,0,48,53,56,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,213,56,121,111,3,0,32,0,48,53,56,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,255,102,208,74,3,0,32,0,48,53,56,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,191,224,197,73,3,0,32,0,48,53,56,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,61,244,241,143,3,0,32,0,48,53,56,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,110,24,197,204,4,0,16,1,48,53,56,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,132,206,215,85,5,0,64,0,48,53,56,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,16,11,8,238,5,0,64,0,48,53,56,45,118,51,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,74,61,235,249,5,0,64,0,48,53,56,45,101,112,114,46,101,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,26,30,12,159,0,0,16,1,117,52,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,229,199,24,7,0,0,16,1,117,52,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,57,5,243,222,0,0,16,1,101,115,112,95,117,54,51,46,117,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,44,233,47,47,0,0,32,0,101,115,112,95,117,54,52,46,117,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,164,61,26,73,0,0,32,0,101,115,112,95,117,54,53,46,117,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,254,62,86,6,0,0,32,0,101,115,112,95,117,54,54,46,117,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,252,76,190,123,0,0,32,0,101,115,112,95,117,53,52,46,117,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,54,105,202,231,0,0,32,0,101,115,112,95,117,53,53,46,117,53,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,79,217,59,245,0,0,32,0,101,115,112,95,117,53,50,46,117,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,180,231,171,231,0,0,32,0,101,115,112,95,117,53,51,46,117,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,145,243,160,81,0,0,32,0,101,115,112,95,117,53,49,46,117,53,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,92,135,155,11,0,0,32,0,101,115,112,95,117,49,57,46,117,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,171,28,75,245,0,0,64,0,101,101,112,114,111,109,45,101,115,112,114,97,100,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,70,181,95,49,0,0,16,1,168,86,7,0,1,0,0,0,72,252,146,0,248,191,2,0,24,38,7,0,1,0,0,0,71,252,146,0,184,160,2,0,56,210,6,0,1,0,0,0,64,252,146,0,192,135,2,0,24,163,6,0,1,0,0,0,65,252,146,0,240,108,2,0,152,122,6,0,1,0,0,0,66,252,146,0,96,82,2,0,192,72,6,0,1,0,0,0,67,252,146,0,32,56,2,0,200,110,3,0,1,0,0,0,68,252,146,0,152,30,2,0,120,89,3,0,1,0,0,0,69,252,146,0,232,10,2,0,120,74,3,0,1,0,0,0,70,252,146,0,152,138,8,0,40,246,1,0,1,0,0,0,8,244,146,0,64,246,1,0,144,236,1,0,1,0,0,0,7,244,146,0,136,224,1,0,176,223,1,0,1,0,0,0,0,244,146,0,72,198,1,0,192,209,1,0,1,0,0,0,1,244,146,0,24,182,1,0,24,198,1,0,1,0,0,0,2,244,146,0,40,167,1,0,120,189,1,0,1,0,0,0,3,244,146,0,200,149,1,0,224,22,1,0,1,0,0,0,4,244,146,0,56,126,1,0,160,14,1,0,1,0,0,0,5,244,146,0,32,101,1,0,176,9,1,0,1,0,0,0,6,244,146,0,96,32,8,0,88,212,3,0,1,0,0,0,224,216,146,0,40,185,3,0,32,77,1,0,1,0,0,0,73,252,146,0,216,70,1,0,16,17,8,0,1,0,0,0,9,244,146,0,224,12,8,0,0,0,0,0,0,0,0,0,97,51,95,45,104,48,45,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,205,219,225,141,1,0,16,1,97,51,95,45,108,48,45,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,253,139,223,211,1,0,16,1,100,115,95,104,49,45,99,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,27,4,9,97,1,0,16,1,100,115,95,108,49,45,99,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,107,31,160,151,1,0,16,1,100,115,95,115,104,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,252,111,254,35,2,0,16,1,100,115,95,115,108,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,229,50,129,118,2,0,16,1,99,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,71,138,234,131,3,0,32,0,99,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,109,62,6,100,3,0,32,0,99,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,26,98,31,204,3,0,32,0,99,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,225,41,88,81,3,0,32,0,97,51,45,111,48,48,45,119,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,173,229,148,176,4,0,32,0,97,51,45,111,48,49,45,119,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,64,243,145,4,0,32,0,97,51,45,111,49,48,45,119,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,244,238,221,237,4,0,32,0,97,51,45,111,49,49,45,119,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,38,149,74,39,4,0,32,0,97,51,45,111,50,48,45,119,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,147,67,6,50,4,0,32,0,97,51,45,111,50,49,45,119,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,217,227,186,87,4,0,32,0,97,51,45,111,51,48,45,119,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,47,142,131,190,4,0,32,0,97,51,45,111,51,49,45,119,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,13,159,137,191,4,0,32,0,100,115,95,100,97,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,253,82,252,103,5,0,64,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,26,0,0,0,6,0,0,0,12,0,0,0,16,0,0,0,34,0,0,0,20,0,0,0,4,0,0,0,16,0,0,0,8,0,0,0,2,0,0,0,24,0,0,0,117,100,50,45,48,48,49,45,48,48,48,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,96,82,150,241,1,0,16,1,117,100,50,45,48,48,49,45,48,48,51,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,95,250,213,231,1,0,16,1,117,51,55,46,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,87,118,4,115,1,0,16,1,117,51,49,46,56,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,64,2,5,106,1,0,16,1,117,100,50,45,48,48,50,45,48,48,52,46,49,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,177,56,213,187,2,0,16,1,117,100,50,45,48,48,49,45,48,48,53,45,116,48,49,46,50,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,73,210,230,119,11,0,32,0,117,100,50,45,48,48,49,45,48,48,54,45,116,48,50,46,51,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,242,27,56,110,11,0,32,0,117,100,50,45,48,48,49,45,48,48,55,45,116,48,51,46,53,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,113,73,123,115,11,0,32,0,117,100,50,45,48,48,49,45,48,48,56,45,116,48,52,46,54,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,87,215,185,153,11,0,32,0,117,100,50,45,48,48,49,45,48,48,57,45,116,48,53,46,56,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,129,197,230,174,4,0,32,0,117,100,50,45,48,48,49,45,48,49,48,45,116,48,54,46,57,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,84,157,57,61,4,0,32,0,117,100,50,45,48,48,49,45,48,49,49,45,116,48,55,46,49,52,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,159,246,159,156,6,0,64,0,112,114,103,46,117,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,74,225,107,0,0,16,1,97,116,100,112,46,117,52,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,83,233,137,113,0,0,32,0,97,116,100,112,46,117,52,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,63,23,132,105,0,0,32,0,97,116,100,112,46,117,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,102,107,218,107,0,0,32,0,97,116,100,112,46,117,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,185,114,14,10,0,0,32,0,117,53,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,255,121,83,40,0,0,32,0,97,116,100,112,46,117,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,202,252,137,13,0,0,64,0,97,116,100,112,46,117,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,222,73,215,0,0,64,0,101,101,112,114,111,109,45,100,111,110,112,97,99,104,105,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,70,181,95,49,0,0,16,1,112,101,101,108,49,56,99,118,56,112,45,49,53,46,117,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,85,1,0,0,233,135,71,63,0,0,0,8,168,86,7,0,1,0,0,0,59,191,145,0,248,191,2,0,24,38,7,0,1,0,0,0,61,191,145,0,184,160,2,0,56,210,6,0,1,0,0,0,40,251,146,0,192,135,2,0,24,163,6,0,1,0,0,0,41,251,146,0,240,108,2,0,152,122,6,0,1,0,0,0,42,251,146,0,96,82,2,0,192,72,6,0,1,0,0,0,43,251,146,0,32,56,2,0,200,110,3,0,1,0,0,0,44,251,146,0,152,30,2,0,120,89,3,0,1,0,0,0,45,251,146,0,232,10,2,0,120,74,3,0,1,0,0,0,46,251,146,0,152,138,8,0,40,246,1,0,1,0,0,0,60,191,145,0,64,246,1,0,144,236,1,0,1,0,0,0,62,191,145,0,136,224,1,0,176,223,1,0,1,0,0,0,248,242,146,0,72,198,1,0,192,209,1,0,1,0,0,0,249,242,146,0,24,182,1,0,24,198,1,0,1,0,0,0,250,242,146,0,40,167,1,0,120,189,1,0,1,0,0,0,251,242,146,0,200,149,1,0,224,22,1,0,1,0,0,0,252,242,146,0,56,126,1,0,160,14,1,0,1,0,0,0,253,242,146,0,32,101,1,0,176,9,1,0,1,0,0,0,254,242,146,0,96,32,8,0,88,212,3,0,1,0,0,0,224,215,146,0,40,185,3,0,32,77,1,0,1,0,0,0,56,191,145,0,216,70,1,0,72,65,1,0,9,0,0,0,107,223,146,0,32,58,1,0,48,50,1,0,9,0,0,0,108,223,146,0,32,58,1,0,224,41,1,0,9,0,0,0,109,223,146,0,32,58,1,0,100,107,106,112,46,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,11,135,72,123,1,0,0,0,100,107,106,112,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,101,22,57,18,1,0,0,0,100,107,106,112,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,3,145,159,108,1,0,0,0,99,95,51,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,248,165,93,113,2,0,0,0,100,107,106,46,51,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,169,172,81,141,3,0,0,0,100,107,106,46,51,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,165,75,246,78,3,0,0,0,118,95,55,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,100,65,127,220,4,0,0,0,118,95,55,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,246,220,231,12,4,0,0,0,118,95,55,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,23,255,209,36,4,0,0,0,118,95,55,102,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,63,8,140,15,4,0,0,0,99,45,50,101,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,173,199,61,70,5,0,0,0,99,45,50,102,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,66,0,186,71,5,0,0,0,118,45,50,110,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,133,241,219,5,0,0,0,56,57,48,107,48,50,46,107,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,221,204,244,82,1,0,16,1,56,57,48,107,48,49,46,102,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,176,62,75,212,2,0,16,1,56,57,48,102,48,54,46,102,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,85,33,89,38,3,0,32,0,56,57,48,102,48,55,46,104,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,46,250,116,108,3,0,32,0,56,57,48,102,48,56,46,106,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,128,46,225,41,3,0,32,0,56,57,48,102,48,57,46,107,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,213,64,202,103,3,0,32,0,56,57,48,102,48,52,46,104,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,250,209,108,241,4,0,32,0,56,57,48,102,48,53,46,107,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,5,219,55,218,4,0,32,0,56,57,48,102,48,51,46,100,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,49,80,6,25,6,0,32,0,54,51,115,49,52,49,110,46,107,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,6,1,98,211,5,0,0,8,56,57,48,120,48,50,46,107,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,53,187,142,229,1,0,16,1,56,57,48,107,48,49,46,102,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,176,62,75,212,2,0,16,1,56,57,48,102,48,54,46,102,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,85,33,89,38,3,0,32,0,56,57,48,102,48,55,46,104,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,46,250,116,108,3,0,32,0,56,57,48,102,48,56,46,106,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,128,46,225,41,3,0,32,0,56,57,48,102,48,57,46,107,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,213,64,202,103,3,0,32,0,56,57,48,102,48,52,46,104,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,250,209,108,241,4,0,32,0,56,57,48,102,48,53,46,107,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,8,0,5,219,55,218,4,0,32,0,56,57,48,102,48,51,46,100,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,49,80,6,25,6,0,32,0,54,51,115,49,52,49,110,46,107,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,6,1,98,211,5,0,0,8,111,49,54,45,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,224,104,116,111,0,0,16,1,111,49,54,45,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,247,245,114,165,0,0,16,1,114,111,109,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,27,202,126,57,0,0,16,1,100,115,112,95,50,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,118,83,19,45,0,0,16,1,100,115,112,95,50,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,113,154,56,121,0,0,16,1,114,111,109,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,130,201,6,101,0,0,32,0,114,111,109,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,147,217,160,163,0,0,32,0,114,111,109,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,243,229,197,79,0,0,32,0,114,111,109,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,171,83,235,0,0,32,0,114,111,109,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,233,36,55,27,0,0,32,0,114,111,109,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,77,164,32,123,0,0,32,0,114,111,109,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,208,220,172,44,0,0,32,0,114,111,109,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,1,50,253,118,0,0,32,0,112,114,111,109,49,50,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,237,204,136,188,0,0,32,0,112,114,111,109,49,51,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,146,116,225,161,0,0,32,0,111,49,54,45,49,48,45,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,24,82,238,132,0,0,16,1,111,49,54,45,48,57,45,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,178,76,71,207,0,0,16,1,114,111,109,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,27,202,126,57,0,0,16,1,100,115,112,95,50,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,118,83,19,45,0,0,16,1,100,115,112,95,50,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,113,154,56,121,0,0,16,1,114,111,109,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,130,201,6,101,0,0,32,0,114,111,109,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,147,217,160,163,0,0,32,0,114,111,109,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,243,229,197,79,0,0,32,0,114,111,109,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,171,83,235,0,0,32,0,114,111,109,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,233,36,55,27,0,0,32,0,114,111,109,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,77,164,32,123,0,0,32,0,114,111,109,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,208,220,172,44,0,0,32,0,114,111,109,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,1,50,253,118,0,0,32,0,112,114,111,109,49,50,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,237,204,136,188,0,0,32,0,112,114,111,109,49,51,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,146,116,225,161,0,0,32,0,111,49,54,45,49,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,108,228,110,3,0,0,16,1,111,49,54,45,48,57,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,227,70,215,190,0,0,16,1,114,111,109,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,27,202,126,57,0,0,16,1,100,115,112,95,50,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,118,83,19,45,0,0,16,1,100,115,112,95,50,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,113,154,56,121,0,0,16,1,114,111,109,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,130,201,6,101,0,0,32,0,114,111,109,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,147,217,160,163,0,0,32,0,114,111,109,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,243,229,197,79,0,0,32,0,114,111,109,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,171,83,235,0,0,32,0,114,111,109,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,233,36,55,27,0,0,32,0,114,111,109,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,77,164,32,123,0,0,32,0,114,111,109,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,208,220,172,44,0,0,32,0,114,111,109,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,1,50,253,118,0,0,32,0,112,114,111,109,49,50,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,237,204,136,188,0,0,32,0,112,114,111,109,49,51,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,146,116,225,161,0,0,32,0,13,13,0,10,8,15,12,0,10,8,13,15,12,3,15,2,11,1,8,10,13,4,10,12,11,2,0,3,0,11,8,11,5,14,11,2,5,3,8,11,8,13,14,4,3,13,11,10,14,6,9,11,11,8,0,15,2,4,5,7,15,8,13,11,7,0,12,3,13,3,1,2,6,14,10,3,15,11,15,7,13,14,4,6,1,10,14,8,4,15,2,8,15,9,3,11,15,11,1,14,11,5,6,14,3,9,12,14,15,12,6,15,12,13,3,15,4,0,8,0,6,8,0,1,6,10,14,9,12,15,3,5,11,4,9,6,9,13,12,0,12,14,9,9,13,10,15,8,15,4,9,3,15,15,14,8,9,0,10,11,15,15,1,15,10,6,11,15,7,11,8,15,2,12,15,15,1,14,10,13,0,14,4,3,12,13,3,5,7,0,4,1,3,5,13,2,0,7,2,13,3,7,9,2,15,0,2,2,2,8,6,6,14,2,15,11,8,0,1,15,5,4,2,15,13,1,1,13,4,10,15,3,14,2,12,8,9,8,13,2,0,14,2,9,0,2,12,3,4,15,13,8,4,12,3,11,13,15,5,8,7,7,7,15,5,11,10,4,2,1,4,11,11,11,8,10,1,13,5,3,1,5,8,15,10,3,10,9,4,14,2,8,6,14,14,9,7,2,15,0,15,5,10,3,5,12,10,0,7,2,1,11,4,13,10,14,3,1,1,1,9,10,11,0,14,0,1,11,1,2,4,14,9,1,12,15,0,10,11,6,10,4,9,1,1,5,4,3,15,9,11,0,7,12,10,9,3,14,4,11,11,3,2,10,1,12,4,3,11,1,9,1,15,9,3,11,12,7,11,6,15,8,1,3,10,12,10,4,2,13,13,11,3,13,1,2,7,13,6,6,7,14,12,15,9,7,15,7,15,6,5,11,5,1,15,11,11,7,14,12,12,4,11,3,8,9,8,15,12,8,10,6,0,12,5,9,6,7,10,6,1,6,13,1,3,10,8,2,1,13,9,4,6,11,2,6,2,15,4,13,3,0,7,0,9,0,6,14,2,12,11,0,5,12,7,2,6,0,2,10,10,5,1,12,5,14,12,1,13,2,6,11,7,10,0,0,7,1,8,10,2,3,6,4,11,10,10,13,15,0,14,10,3,8,14,10,0,7,2,4,4,4,0,9,15,9,14,3,4,3,5,4,7,15,6,13,7,12,1,12,10,1,8,15,5,15,12,13,14,14,0,4,0,0,5,0,6,14,8,14,14,1,11,5,5,11,3,0,2,15,11,2,7,1,14,10,14,3,1,5,5,10,1,10,13,13,9,9,2,1,6,7,6,7,11,15,6,6,4,12,8,4,3,0,0,15,8,2,2,14,1,8,11,7,11,10,3,10,6,10,14,10,14,6,1,3,5,2,2,5,5,5,8,3,12,15,6,9,12,10,4,8,11,6,1,8,9,15,15,10,0,6,11,8,2,9,15,2,2,10,0,5,6,5,11,0,0,6,0,1,13,6,4,4,4,1,4,0,9,12,2,10,13,5,10,12,15,10,12,3,4,7,10,13,3,15,12,11,6,8,13,2,8,10,3,12,13,9,10,4,2,11,1,4,9,1,11,2,14,5,2,0,10,12,0,6,7,0,2,10,15,9,0,0,8,1,0,9,1,14,0,13,12,13,9,6,10,12,10,0,13,3,7,4,12,0,11,0,0,11,5,0,14,15,11,8,2,5,4,6,5,9,13,5,4,4,13,4,0,12,10,3,2,2,0,13,11,12,4,12,9,7,13,14,14,8,5,0,13,0,1,4,15,15,9,8,5,12,13,8,12,8,8,10,0,15,8,11,5,6,9,8,10,12,9,12,5,14,6,9,7,15,1,9,15,0,1,9,1,2,8,1,4,12,1,4,9,7,2,10,8,1,13,6,0,12,0,6,12,13,5,9,4,12,7,14,10,4,6,8,12,4,9,1,2,2,3,13,10,2,15,7,1,6,0,12,5,10,9,1,0,14,15,3,7,6,9,12,13,7,0,13,2,5,7,13,1,3,8,15,9,10,3,0,15,2,11,5,7,3,10,7,4,0,7,2,10,2,0,3,6,6,13,0,5,9,13,8,11,9,0,4,1,11,15,5,15,3,1,15,1,15,12,8,9,4,1,5,8,11,5,7,6,11,5,7,15,15,9,4,7,12,14,11,8,6,7,7,12,3,9,12,6,9,5,8,13,14,6,14,4,7,12,12,2,14,10,2,1,10,3,8,12,11,12,7,12,15,7,13,9,15,6,3,1,14,13,14,8,11,14,4,9,2,13,13,0,2,9,11,3,2,4,11,6,8,2,14,7,15,8,8,9,5,4,15,11,7,13,7,4,15,15,4,2,1,6,4,3,15,0,11,14,15,6,15,11,14,10,4,4,0,5,4,6,15,8,10,15,1,3,8,13,3,3,0,7,7,2,3,2,11,14,1,12,13,10,2,4,13,4,13,9,3,2,1,14,9,8,11,15,4,8,9,13,2,10,14,2,4,8,13,13,14,12,1,5,15,13,3,12,8,11,12,12,1,0,15,9,2,6,9,3,12,5,0,10,8,5,6,11,14,7,7,0,10,0,14,10,8,4,12,5,3,11,10,5,13,15,9,14,12,12,0,14,3,2,12,9,14,11,11,9,2,8,9,13,0,10,3,14,14,13,6,4,14,2,10,10,9,10,4,5,4,5,3,4,6,15,5,14,2,6,10,4,8,6,9,9,7,3,3,9,5,9,8,10,5,0,13,7,8,4,1,3,13,4,1,8,10,3,11,13,3,12,0,2,0,3,1,3,3,1,6,13,2,3,13,11,5,9,0,4,12,6,11,4,4,3,3,12,7,13,2,15,12,1,11,15,7,10,0,9,3,3,13,12,12,9,14,2,2,0,3,12,2,0,15,0,10,1,9,8,3,2,3,9,1,4,5,12,9,10,11,0,2,2,11,5,13,8,1,7,8,4,12,11,1,2,11,7,7,8,6,5,8,8,14,2,6,10,6,1,9,3,4,2,9,11,1,4,9,8,13,5,0,15,13,0,9,9,11,5,11,6,4,6,9,5,1,13,8,8,2,14,14,2,3,14,12,4,6,15,4,11,14,7,2,3,14,4,15,4,1,8,13,5,5,7,0,6,14,0,1,1,13,5,10,10,14,14,10,2,9,1,11,5,6,8,12,4,2,7,7,11,6,13,15,1,3,9,0,14,12,9,2,3,2,1,9,12,7,4,12,14,3,3,2,3,14,10,5,8,4,9,9,11,14,13,15,14,7,3,13,0,9,4,9,12,12,1,2,10,11,7,11,1,9,2,8,1,4,5,14,8,15,9,3,8,9,6,3,7,3,1,10,7,5,13,14,8,7,4,10,14,4,6,9,6,2,5,3,8,0,9,7,2,7,12,8,12,2,15,4,5,0,11,8,11,2,14,8,15,0,8,9,14,5,4,13,12,11,2,6,11,9,9,7,14,6,6,7,4,6,3,5,12,5,11,1,12,14,0,13,15,13,2,2,1,8,3,11,3,1,6,9,12,12,5,10,7,13,15,4,12,10,9,11,12,14,12,11,15,2,3,2,7,8,15,2,2,0,12,12,9,11,13,14,13,7,3,11,11,14,12,3,2,7,4,8,9,11,8,11,5,10,3,7,15,11,12,15,10,8,5,13,8,3,9,8,5,7,1,15,15,0,13,7,8,6,8,10,8,6,6,3,4,10,13,1,6,6,10,1,2,11,4,15,15,3,1,1,14,12,1,15,1,6,8,10,14,14,9,4,7,8,6,5,3,1,0,5,3,8,6,1,4,2,13,15,14,5,13,11,10,13,11,11,6,10,7,2,1,15,2,10,5,0,11,5,15,8,0,14,3,12,11,7,10,1,4,0,3,15,7,15,12,8,9,0,1,15,13,2,3,2,15,15,14,14,7,8,12,11,15,15,14,2,8,8,2,0,15,4,2,5,14,10,4,12,2,1,0,13,7,5,4,3,11,6,0,2,6,14,9,14,10,13,6,10,5,8,15,2,4,7,1,8,5,3,11,5,12,1,3,1,14,4,8,12,6,10,14,7,14,7,15,14,5,10,6,9,3,6,12,15,1,12,0,6,1,4,13,13,7,1,7,1,9,1,8,6,9,9,8,12,5,2,8,11,9,1,3,9,0,11,14,8,5,9,7,7,14,4,6,1,6,11,4,0,15,5,9,8,5,13,2,6,13,10,12,3,4,3,15,5,6,14,2,10,14,1,5,9,6,1,9,2,7,11,14,7,14,5,8,9,14,13,14,8,3,8,4,10,3,14,0,13,12,15,9,9,0,4,6,7,12,13,12,1,15,2,13,13,8,10,13,5,12,5,4,0,2,1,13,12,2,14,9,15,13,9,7,13,7,0,14,7,12,15,3,11,0,5,8,1,0,12,9,0,11,13,6,3,3,7,2,2,3,5,14,14,0,9,2,6,4,12,2,6,3,12,3,13,3,14,7,1,8,15,14,3,0,10,2,15,15,9,14,11,10,12,13,13,13,9,7,7,12,5,3,14,1,5,1,10,6,7,9,8,15,7,13,11,4,5,4,10,14,14,12,1,13,14,15,14,15,10,0,1,2,3,4,5,5,6,7,8,9,10,7,11,11,9,11,3,7,10,12,13,3,14,0,0,9,0,15,3,4,14,6,3,14,14,3,12,3,13,9,5,13,3,8,2,7,14,2,5,1,2,3,4,14,11,8,0,6,7,10,3,4,7,15,1,2,7,7,14,15,0,7,9,15,3,14,10,9,12,11,12,2,8,1,10,9,14,5,6,15,10,4,15,5,2,3,2,4,15,7,7,10,13,1,13,6,6,7,5,10,9,5,15,14,2,7,12,7,4,2,15,12,10,11,15,4,6,9,3,11,13,0,3,6,4,15,8,3,8,0,3,13,8,6,0,11,4,9,7,11,1,8,1,10,9,2,8,11,15,2,8,10,5,3,8,0,10,0,15,3,1,15,3,8,6,13,11,10,4,15,4,4,3,7,7,15,3,11,15,15,2,3,7,13,4,10,12,9,8,11,2,5,8,7,4,14,0,12,1,15,10,3,10,5,13,1,4,0,7,7,2,8,15,12,1,9,14,12,9,11,5,13,1,12,12,14,8,8,13,4,13,1,12,10,1,10,15,7,5,1,13,10,10,15,1,3,14,13,0,0,1,3,9,5,0,4,13,6,14,2,8,3,3,5,8,1,10,7,5,13,4,2,12,5,1,0,4,4,6,14,10,6,3,11,10,0,10,2,3,11,11,15,13,3,10,3,8,3,4,7,1,5,3,9,8,14,13,13,4,1,0,1,12,12,12,11,11,3,7,4,10,10,3,10,3,1,7,4,6,2,12,3,3,0,0,10,0,6,8,0,7,2,15,10,14,1,14,4,12,4,2,3,4,8,0,10,10,15,1,8,4,11,2,12,6,12,12,12,2,4,6,3,12,4,7,14,11,10,6,13,3,4,14,7,5,7,5,10,8,5,0,7,12,3,7,14,3,3,8,0,7,6,9,11,15,10,15,9,7,0,13,7,3,7,4,10,1,7,4,3,15,2,6,1,14,12,12,10,10,1,11,15,0,10,7,12,15,8,10,2,14,11,0,10,12,13,15,12,15,8,11,5,3,0,7,10,6,1,9,11,8,4,2,4,12,6,3,15,3,2,1,10,2,2,7,10,6,11,12,6,2,11,7,15,1,13,9,12,3,9,12,2,12,6,5,11,8,0,7,14,10,7,8,6,5,12,4,1,12,12,13,8,4,8,12,8,2,1,15,13,14,8,6,11,2,13,5,6,10,9,5,7,11,5,11,13,2,0,8,2,10,2,1,6,4,8,14,0,4,8,11,8,15,12,0,15,6,1,13,15,10,3,13,14,13,4,5,12,4,3,8,9,15,13,11,4,8,10,7,12,7,7,9,7,11,13,0,15,5,11,5,6,2,5,1,9,2,9,15,9,8,14,6,11,7,10,4,14,12,3,12,3,0,4,8,11,9,5,7,14,1,10,3,2,12,12,10,12,8,4,5,10,13,11,6,14,4,13,14,8,3,10,5,6,4,4,10,6,5,12,11,10,5,9,6,7,6,4,6,3,15,5,14,14,13,7,6,12,13,15,5,15,10,2,1,15,3,10,15,7,4,5,2,10,15,14,15,1,13,12,9,8,14,15,3,4,1,9,13,13,3,12,15,8,15,7,1,10,12,10,9,12,10,14,6,5,5,4,0,12,14,15,6,5,5,2,14,2,6,14,2,12,7,5,1,2,3,2,12,15,4,10,5,10,13,0,2,2,1,5,7,5,2,0,13,0,4,13,13,9,12,5,5,10,15,6,11,5,2,11,8,0,6,9,13,2,6,1,11,5,1,12,8,4,7,9,13,4,4,15,3,4,5,5,0,9,4,10,8,1,0,13,8,6,12,15,15,10,7,10,2,6,1,4,0,2,8,3,10,2,12,4,1,12,15,0,1,10,0,10,11,6,1,0,3,2,3,4,4,9,14,7,3,13,7,13,9,14,12,10,5,4,14,0,5,15,8,12,12,0,5,11,15,8,7,15,5,12,5,5,3,6,13,15,15,7,0,3,9,1,5,7,7,12,5,3,12,10,11,2,11,5,10,1,3,6,2,7,1,3,0,6,8,12,15,14,6,10,13,9,1,15,4,6,13,14,7,2,13,12,9,4,7,9,9,6,10,6,15,15,2,0,4,12,12,10,2,7,4,14,10,2,6,5,12,0,14,1,15,13,1,4,13,3,13,6,15,11,15,0,13,12,5,4,11,14,15,6,13,6,7,2,2,7,11,6,7,15,0,13,10,6,14,9,13,12,14,4,8,5,13,3,14,6,6,13,8,7,7,5,8,12,2,6,0,6,8,2,13,9,14,3,15,1,4,13,3,6,8,15,4,8,7,4,10,0,9,2,15,2,1,3,3,1,4,0,3,1,8,5,0,10,0,1,6,11,3,12,0,14,11,0,5,15,9,1,7,15,12,12,10,2,2,3,15,13,13,2,13,14,13,13,8,11,10,9,9,9,7,7,4,9,1,9,10,9,9,9,15,13,14,12,13,6,11,4,6,9,14,6,6,7,0,8,6,10,7,9,13,4,8,1,8,9,9,3,14,10,14,11,7,15,8,13,11,9,0,5,4,4,7,6,0,13,9,13,7,9,3,2,0,7,11,5,8,8,0,10,3,1,4,2,15,12,5,2,6,15,5,13,6,12,8,10,9,12,9,1,2,15,14,5,11,13,3,6,8,15,5,8,2,10,2,8,14,15,5,4,0,10,2,14,14,8,8,9,9,11,11,12,11,5,4,2,12,15,12,1,11,5,13,0,12,2,4,0,0,12,12,4,15,7,1,2,13,10,10,6,4,8,6,0,14,13,1,8,3,10,9,11,12,6,0,11,14,1,13,7,4,11,3,10,0,2,10,14,13,7,8,10,7,7,12,10,11,3,9,13,8,0,10,10,13,7,12,8,8,5,15,10,15,7,1,8,2,12,1,14,10,10,4,5,7,11,3,7,7,1,12,12,12,1,14,4,0,11,15,8,10,1,14,2,11,5,5,10,12,2,2,1,0,10,0,6,2,10,13,1,11,14,0,12,11,8,8,12,4,5,5,14,14,9,8,0,10,1,9,15,10,13,5,2,7,1,2,6,5,5,11,0,13,8,0,7,2,15,11,15,0,5,15,5,6,0,2,5,3,0,14,14,4,11,7,7,4,10,11,1,8,13,9,4,13,3,6,1,10,1,0,15,15,12,10,6,11,3,4,7,8,7,14,8,7,12,15,9,8,7,14,14,9,15,8,9,4,12,3,12,12,7,8,11,2,4,8,4,9,4,11,15,2,13,6,3,13,1,13,5,0,2,10,5,8,1,13,14,0,11,15,8,12,10,4,5,10,4,11,11,2,2,13,2,6,0,7,4,11,1,12,6,13,14,5,9,0,5,13,14,6,13,3,13,9,14,14,0,9,12,14,9,10,1,2,12,3,3,15,8,4,3,1,13,13,13,13,4,3,5,15,8,2,15,13,11,7,4,0,15,14,1,13,6,8,2,8,7,14,11,7,4,1,8,12,13,11,0,9,0,3,12,11,2,3,9,1,3,13,4,5,15,10,5,9,0,3,9,6,13,7,15,13,11,13,12,6,14,15,3,6,10,3,11,10,1,4,13,0,15,15,11,0,7,14,9,15,1,14,2,13,7,12,11,7,9,6,11,5,12,4,3,6,8,3,9,0,15,7,1,11,7,12,2,13,13,3,0,11,1,11,6,1,5,5,4,5,12,3,3,15,3,10,7,12,15,0,13,10,0,2,6,12,9,5,3,0,0,6,3,13,7,14,11,15,7,2,2,11,6,11,9,3,10,11,1,8,1,13,0,11,2,10,3,12,4,11,0,0,10,10,2,3,15,0,0,9,14,5,14,10,14,0,13,1,1,12,3,3,1,15,8,8,11,13,8,4,8,5,8,7,13,2,1,1,14,15,1,7,7,1,14,1,4,14,0,0,7,6,5,11,5,8,7,1,4,3,8,14,5,11,13,8,1,9,6,12,9,6,3,3,11,12,5,11,4,4,3,11,0,0,10,10,7,15,15,11,1,11,13,11,6,8,2,15,10,7,0,6,3,5,2,14,12,8,12,10,15,8,4,11,8,13,11,2,5,13,10,5,9,10,15,6,3,12,3,0,11,15,5,13,12,13,12,0,8,12,10,0,5,5,3,2,10,5,3,10,7,2,13,12,15,13,1,10,4,10,12,14,12,1,6,13,6,6,0,13,11,4,5,7,1,7,7,0,4,13,13,12,14,6,1,3,13,11,1,4,9,9,2,12,8,5,10,15,2,0,14,9,5,8,11,5,3,4,7,1,2,13,3,8,1,3,11,12,11,5,1,5,10,12,10,2,10,13,12,3,9,2,12,14,13,8,2,1,5,3,15,2,8,2,1,15,10,6,10,3,8,9,6,9,2,10,4,12,10,15,14,15,1,15,0,13,6,0,5,6,13,12,2,14,0,10,6,15,8,8,6,8,2,12,11,3,9,5,9,15,11,3,11,14,15,6,14,6,7,12,7,10,6,14,6,6,3,5,9,14,7,5,8,6,2,12,15,1,2,4,11,6,3,0,5,11,14,14,14,4,13,6,11,6,4,12,15,2,4,1,1,5,1,15,7,0,5,0,0,0,12,1,118,49,48,49,95,49,54,109,46,117,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,253,134,87,94,1,0,16,1,100,100,112,50,95,105,103,115,48,50,55,97,95,104,111,110,103,95,107,111,110,103,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,206,202,209,167,7,0,16,1,116,49,51,48,48,46,117,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,203,240,72,231,2,0,32,0,97,49,51,48,48,46,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,5,164,135,252,3,0,32,0,97,49,51,48,49,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,218,32,133,12,3,0,32,0,98,49,51,48,48,46,117,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,4,102,100,239,4,0,32,0,109,49,51,48,48,46,117,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,93,1,212,130,5,0,64,0,118,49,48,48,46,117,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,41,221,195,6,8,0,16,1,118,49,48,48,46,117,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,234,168,138,12,1,0,16,1,100,100,112,50,95,105,103,115,48,50,55,97,95,104,111,110,103,95,107,111,110,103,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,206,202,209,167,7,0,16,1,116,49,51,48,48,46,117,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,203,240,72,231,2,0,32,0,97,49,51,48,48,46,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,5,164,135,252,3,0,32,0,97,49,51,48,49,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,218,32,133,12,3,0,32,0,98,49,51,48,48,46,117,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,4,102,100,239,4,0,32,0,109,49,51,48,48,46,117,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,93,1,212,130,5,0,64,0,118,49,48,48,46,117,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,41,221,195,6,8,0,16,1,117,50,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,155,255,50,36,0,0,16,1,117,50,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,74,145,58,79,0,0,16,1,117,53,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,236,96,178,20,0,0,32,0,117,53,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,206,140,186,231,0,0,32,0,117,53,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,224,46,73,2,0,0,32,0,117,53,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,240,16,76,203,0,0,32,0,117,54,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,167,150,48,144,0,0,32,0,117,54,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,49,118,155,216,0,0,32,0,117,54,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,107,251,43,41,0,0,32,0,117,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,175,175,253,157,0,0,64,0,117,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,213,23,91,121,0,0,64,0,101,101,112,114,111,109,45,100,100,111,110,112,97,99,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,70,181,95,49,0,0,16,1,100,98,95,99,45,104,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,60,6,243,75,1,0,16,1,100,98,95,99,45,108,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,121,155,184,228,1,0,16,1,100,98,95,99,45,104,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,178,159,167,90,1,0,16,1,100,98,95,99,45,108,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,6,94,15,237,1,0,16,1,100,98,95,107,56,48,48,109,46,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,207,168,39,192,2,0,32,0,100,98,95,107,56,48,49,109,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,51,175,63,9,2,0,32,0,100,98,95,107,56,48,50,109,46,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,89,76,91,5,2,0,32,0,100,98,95,107,56,48,51,109,46,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,34,57,214,142,2,0,32,0,100,98,95,107,56,48,52,109,46,97,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,46,233,131,76,3,0,32,0,100,98,95,107,56,48,53,109,46,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,104,242,94,131,3,0,32,0,100,98,95,107,56,48,54,109,46,97,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,20,241,23,81,3,0,32,0,100,98,95,107,56,48,55,109,46,97,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,120,201,176,142,3,0,32,0,100,98,95,107,56,48,52,109,46,98,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,46,233,131,76,4,0,32,0,100,98,95,107,56,48,53,109,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,104,242,94,131,4,0,32,0,100,98,95,107,56,48,54,109,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,20,241,23,81,4,0,32,0,100,98,95,107,56,48,55,109,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,120,201,176,142,4,0,32,0,100,98,95,99,45,118,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,130,114,47,49,5,0,64,0,100,98,114,101,101,100,109,55,50,95,105,56,55,53,49,46,109,99,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,24,103,115,48,49,46,97,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,77,99,19,134,1,0,16,1,103,115,48,51,46,97,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,212,11,134,234,1,0,16,1,103,115,48,48,46,97,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,117,113,39,183,1,0,16,1,103,115,48,50,46,97,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,53,30,227,205,1,0,16,1,103,115,49,48,46,97,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,163,114,95,40,2,0,16,1,103,115,48,56,46,97,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,222,30,105,22,2,0,16,1,103,115,49,49,46,97,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,222,35,203,128,2,0,16,1,103,115,48,57,46,97,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,225,167,143,10,2,0,16,1,103,115,48,52,46,102,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,191,158,194,129,3,0,16,1,103,115,48,53,46,104,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,106,153,174,10,4,0,32,0,103,115,48,54,46,104,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,61,240,253,78,4,0,32,0,109,97,106,45,48,50,46,104,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,55,188,59,56,5,0,32,0,109,97,106,45,48,49,46,99,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,4,162,64,152,6,0,32,0,109,97,106,45,48,48,46,99,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,22,141,234,135,6,0,32,0,109,97,106,45,48,52,46,114,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,25,155,228,54,7,0,32,0,109,97,106,45,48,53,46,114,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,204,113,252,128,7,0,32,0,109,97,106,45,48,54,46,114,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,75,104,122,46,7,0,32,0,109,97,106,45,48,55,46,114,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,120,31,204,58,7,0,32,0,109,97,106,45,48,56,46,115,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,109,163,88,25,7,0,32,0,109,97,106,45,48,57,46,115,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,161,135,16,194,7,0,32,0,109,97,106,45,49,48,46,115,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,65,166,47,160,7,0,32,0,109,97,106,45,49,49,46,115,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,5,147,190,218,7,0,32,0,103,115,49,50,46,110,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,21,160,134,154,8,0,32,0,103,115,49,51,46,110,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,5,153,112,244,8,0,32,0,103,115,49,52,46,110,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,35,197,15,117,8,0,32,0,103,115,49,53,46,110,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,61,221,78,241,8,0,32,0,103,115,48,55,46,104,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,93,126,11,117,9,0,64,0,109,97,106,45,48,51,46,104,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,195,250,220,49,10,0,64,0,109,98,55,49,50,56,121,46,49,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,162,128,231,189,11,0,0,8,109,98,55,49,50,56,121,46,49,54,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,81,39,77,196,11,0,0,8,109,98,55,49,50,56,121,46,49,54,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,81,39,77,196,11,0,0,8,109,98,55,49,50,56,121,46,49,55,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,81,39,77,196,11,0,0,8,112,97,108,49,54,114,56,97,32,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,12,0,0,16,112,97,108,49,54,108,56,98,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,12,0,0,16,112,97,108,49,54,108,56,98,46,55,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,253,131,158,25,12,0,0,8,112,97,108,49,54,108,56,98,46,55,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,12,0,0,16,112,97,108,49,54,108,56,98,46,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,12,0,0,16,112,97,108,49,54,108,56,98,46,56,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,12,0,0,16,112,97,108,49,54,108,56,98,46,57,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,12,0,0,16,112,97,108,49,54,108,56,98,46,49,48,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,12,0,0,16,106,98,45,48,49,45,51,46,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,1,140,48,130,1,0,16,1,106,98,45,48,48,45,51,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,58,17,56,29,1,0,16,1,106,98,45,48,51,46,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,4,212,23,82,1,0,16,1,106,98,45,48,50,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,40,206,161,54,1,0,16,1,109,97,115,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,206,86,82,126,1,0,16,1,109,97,115,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,153,212,91,0,1,0,16,1,106,98,45,48,54,46,50,48,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,221,161,102,32,2,0,16,1,106,98,45,48,52,46,49,48,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,168,203,115,3,0,32,0,106,98,45,48,53,46,49,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,157,196,226,34,3,0,32,0,109,97,115,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,52,16,1,61,4,0,32,0,109,97,115,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,11,157,12,109,4,0,32,0,109,97,115,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,32,230,0,175,5,0,32,0,109,97,115,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,162,30,230,47,5,0,32,0,109,97,115,48,52,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,59,149,86,30,6,0,32,0,109,97,115,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,248,184,38,56,6,0,32,0,109,97,115,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,69,189,139,59,6,0,32,0,109,97,115,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,105,55,48,49,6,0,32,0,109,97,115,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,122,251,36,226,7,0,32,0,109,97,115,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,65,235,109,95,7,0,32,0,109,97,115,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,167,6,220,110,8,0,64,0,109,97,115,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,242,164,240,194,9,0,64,0,109,98,55,49,50,50,104,46,49,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,204,87,238,43,0,0,0,8,1,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,49,45,105,99,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,205,170,132,178,1,0,16,1,119,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,37,115,223,165,1,0,16,1,119,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,109,102,157,252,1,0,16,1,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,15,144,10,231,2,0,16,1,104,56,57,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,195,147,173,54,3,0,32,0,119,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,13,249,93,177,4,0,32,0,119,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,147,107,50,40,4,0,32,0,119,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,209,106,5,212,4,0,32,0,104,56,57,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,40,1,35,227,5,0,32,0,104,56,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,51,2,246,255,5,0,32,0,104,56,57,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,193,0,51,213,6,0,64,0,104,56,57,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,99,59,81,50,6,0,64,0,50,95,95,40,99,111,110,116,114,97,98,116,106,50,41,46,50,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,109,25,185,189,1,0,16,1,49,46,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,56,116,95,93,1,0,16,1,97,51,46,52,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,85,146,84,209,2,0,16,1,97,55,46,49,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,210,103,244,87,3,0,32,0,97,49,48,46,49,52,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,133,150,219,230,3,0,32,0,97,57,46,49,52,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,222,97,92,135,3,0,32,0,97,56,46,49,52,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,214,101,39,100,3,0,32,0,97,49,53,46,49,52,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,75,50,162,218,3,0,32,0,97,49,54,46,49,52,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,53,200,124,226,3,0,32,0,97,49,55,46,49,52,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,185,48,67,206,3,0,32,0,97,49,56,46,49,52,119,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,66,206,113,21,3,0,32,0,97,52,46,49,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,44,229,199,44,4,0,32,0,97,53,46,49,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,156,91,26,224,4,0,32,0,101,54,46,49,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,68,103,234,174,4,0,32,0,97,49,52,46,49,52,113,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,199,253,90,118,4,0,32,0,97,49,49,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,44,169,155,189,4,0,32,0,97,49,50,46,49,52,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,194,126,190,208,4,0,32,0,97,49,51,46,49,52,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,18,61,81,43,4,0,32,0,54,51,51,101,48,56,46,49,48,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,250,73,9,159,5,0,32,0,54,51,51,101,48,57,46,49,50,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,25,94,202,20,5,0,32,0,54,51,51,102,49,48,46,49,56,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,132,77,36,43,5,0,32,0,54,51,51,102,49,49,46,50,48,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,25,94,202,20,5,0,32,0,97,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,76,182,56,187,1,0,0,0,97,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,131,138,135,124,1,0,0,0,97,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,203,90,80,4,1,0,0,0,97,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,137,94,202,98,2,0,0,0,97,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,119,97,36,71,3,0,0,0,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,151,103,107,217,4,0,0,0,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,2,156,239,63,4,0,0,0,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,52,108,174,191,4,0,0,0,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,14,112,235,234,4,0,0,0,97,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,143,41,145,201,5,0,0,0,97,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,229,103,226,245,5,0,0,0,97,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,130,89,204,107,5,0,0,0,97,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,181,67,4,201,5,0,0,0,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,51,96,79,28,6,0,0,0,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,148,167,75,210,6,0,0,0,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,206,73,10,216,6,0,0,0,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,195,31,119,109,6,0,0,0,101,108,45,49,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,227,2,161,198,1,0,0,0,101,108,45,49,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,180,218,178,114,1,0,0,0,101,108,45,49,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,203,90,80,4,1,0,0,0,101,108,45,49,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,137,94,202,98,2,0,0,0,101,108,45,49,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,119,97,36,71,3,0,0,0,101,104,45,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,151,103,107,217,4,0,0,0,101,104,45,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,2,156,239,63,4,0,0,0,101,104,45,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,52,108,174,191,4,0,0,0,101,104,45,48,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,248,144,103,213,4,0,0,0,101,108,45,48,56,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,76,207,13,203,5,0,0,0,101,108,45,48,57,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,231,91,174,31,5,0,0,0,101,108,45,48,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,51,96,79,28,6,0,0,0,101,108,45,48,54,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,148,167,75,210,6,0,0,0,101,108,45,48,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,206,73,10,216,6,0,0,0,101,108,45,48,55,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,195,31,119,109,6,0,0,0,5,6,6,5,5,6,5,5,5,5,5,6,5,4,2,5,0,0,1,4,4,19,4,7,19,1,2,19,3,1,5,4,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,4,4,4,4,4,4,4,4,19,4,1,6,22,10,19,21,1,19,19,1,1,19,1,1,1,1,1,19,1,1,19,1,1,19,19,1,1,19,1,1,1,1,1,19,1,1,19,1,6,7,7,6,6,6,6,6,6,6,6,7,6,5,3,6,6,7,7,6,6,7,6,6,6,6,6,5,6,5,3,6,2,2,2,3,2,2,2,19,2,2,2,2,3,6,3,19,3,3,3,4,3,3,3,3,3,3,3,3,4,6,4,4,4,4,4,5,4,4,4,4,4,4,4,4,5,6,5,5,4,4,4,5,4,4,4,4,4,4,4,4,5,7,5,5,2,2,2,3,2,2,2,19,2,2,2,2,3,5,3,19,3,3,3,4,3,3,3,3,3,3,3,3,4,4,4,4,4,4,4,5,4,4,4,4,4,4,4,4,5,5,5,5,4,4,4,5,4,4,4,4,4,4,4,4,5,5,5,5,6,6,6,6,6,6,6,6,6,6,6,6,6,6,3,6,0,0,2,4,4,19,5,9,19,2,3,19,3,2,8,6,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,4,4,4,4,5,5,5,5,19,5,3,6,20,11,19,19,2,19,19,2,2,19,2,2,2,2,2,19,2,2,19,2,2,19,19,2,2,19,2,2,2,2,2,19,2,2,19,2,6,7,7,6,6,6,6,6,6,6,6,7,6,6,3,6,7,7,7,7,7,7,7,7,7,7,7,5,7,7,4,7,2,2,2,4,2,2,2,19,2,2,2,2,4,7,3,19,4,4,4,6,4,4,4,4,4,4,4,4,6,7,5,5,4,4,4,6,4,4,4,4,4,4,4,4,6,7,5,5,5,5,5,7,5,5,5,5,5,5,5,5,7,8,6,6,2,2,2,4,2,2,2,19,2,2,2,2,3,5,3,19,4,4,4,6,4,4,4,4,4,4,4,4,5,5,5,5,4,4,4,6,4,4,4,4,4,4,4,4,5,5,5,5,5,5,5,7,5,5,5,5,5,5,5,5,6,6,6,6,112,114,111,116,111,95,48,49,56,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,231,50,64,91,1,0,16,1,112,114,111,116,111,95,48,49,56,45,112,50,46,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,104,47,118,120,1,0,16,1,112,114,111,116,111,95,48,49,56,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,232,48,209,243,2,0,32,0,112,114,111,116,111,95,48,49,56,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,139,1,105,101,3,0,32,0,112,114,111,116,111,95,48,49,56,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,181,73,105,3,0,32,0,112,114,111,116,111,95,48,49,56,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,59,101,15,65,3,0,32,0,112,114,111,116,111,95,48,49,56,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,165,242,59,212,3,0,32,0,112,114,111,116,111,95,48,49,56,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,211,9,125,131,3,0,32,0,112,114,111,116,111,95,48,49,56,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,231,81,238,95,3,0,32,0,112,114,111,116,111,95,48,49,56,45,99,55,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,35,8,63,15,3,0,32,0,112,114,111,116,111,95,48,49,56,45,99,56,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,52,158,204,103,3,0,32,0,112,114,111,116,111,95,48,49,56,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,212,213,13,71,4,0,16,1,112,114,111,116,111,95,48,49,56,45,118,49,49,46,118,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,60,234,7,220,5,0,64,0,112,114,111,116,111,95,48,49,56,45,118,49,50,46,118,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,124,99,174,241,5,0,64,0,112,114,111,116,111,95,48,49,56,45,118,50,49,46,118,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,218,78,59,159,5,0,64,0,48,49,56,45,104,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,244,203,255,221,1,0,16,1,48,49,56,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,13,234,153,103,2,0,32,0,48,49,56,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,155,94,162,37,3,0,32,0,48,49,56,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,118,136,55,212,3,0,32,0,48,49,56,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,218,96,43,134,3,0,32,0,48,49,56,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,247,175,224,226,3,0,32,0,48,49,56,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,226,158,147,12,4,0,16,1,48,49,56,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,252,159,140,80,5,0,64,0,48,49,56,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,119,242,78,133,5,0,64,0,107,109,95,48,48,45,50,46,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,198,113,171,113,1,0,16,1,107,109,95,48,50,45,50,46,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,249,7,15,233,1,0,16,1,107,109,95,48,49,45,50,46,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,211,226,220,127,1,0,16,1,107,109,95,48,51,45,50,46,52,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,227,45,88,11,1,0,16,1,107,109,48,54,46,49,56,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,225,196,139,62,2,0,16,1,107,109,48,53,46,57,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,149,239,10,209,3,0,32,0,107,109,48,52,46,56,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,168,35,147,50,3,0,32,0,109,98,100,45,48,49,46,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,75,79,222,215,4,0,32,0,109,98,100,45,48,48,46,56,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,169,11,178,173,4,0,32,0,109,98,100,45,48,50,46,49,48,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,33,167,90,178,4,0,32,0,109,98,100,45,48,51,46,49,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,44,143,121,207,5,0,32,0,109,98,100,45,48,52,46,49,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,11,77,118,217,5,0,32,0,109,98,100,45,48,53,46,49,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,106,198,104,23,6,0,32,0,109,98,100,45,48,54,46,49,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,122,132,80,119,6,0,32,0,109,98,100,45,48,55,46,49,56,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,193,170,31,36,7,0,32,0,109,98,100,45,48,56,46,49,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,86,30,59,241,7,0,32,0,109,98,100,45,49,48,46,49,55,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,106,247,89,241,8,0,64,0,109,98,100,45,48,57,46,49,54,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,135,47,79,244,9,0,64,0,107,106,45,48,48,46,49,53,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,11,213,212,173,10,0,0,8,98,52,49,45,48,57,45,49,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,188,31,130,175,2,0,16,1,98,52,49,45,49,49,45,49,46,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,255,63,130,2,0,16,1,98,52,49,45,49,48,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,119,77,169,76,2,0,16,1,98,52,49,45,49,52,46,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,106,241,222,55,2,0,16,1,98,52,49,45,48,49,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,164,47,7,93,1,0,16,1,98,52,49,45,49,51,46,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,84,66,70,158,9,0,16,1,98,52,49,45,48,51,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,208,53,109,115,11,0,32,0,98,52,49,45,48,50,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,217,5,242,41,15,0,32,0,98,52,49,45,48,52,46,52,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,143,99,104,198,24,0,64,0,98,52,49,45,48,57,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,16,135,129,6,2,0,16,1,98,52,49,45,49,49,46,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,244,194,196,51,2,0,16,1,98,52,49,45,49,48,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,119,77,169,76,2,0,16,1,98,52,49,45,49,53,46,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,208,160,215,174,2,0,16,1,98,52,49,45,48,49,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,164,47,7,93,1,0,16,1,98,52,49,45,49,51,46,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,84,66,70,158,9,0,16,1,98,52,49,45,48,51,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,208,53,109,115,11,0,32,0,98,52,49,45,48,50,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,217,5,242,41,15,0,32,0,98,52,49,45,48,52,46,52,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,143,99,104,198,24,0,64,0,113,112,115,114,117,116,119,118,121,120,123,122,125,124,127,126,117,78,0,0,0,0,0,0,164,0,1,0,165,0,90,0,166,0,116,0,167,0,155,0,168,0,208,0,169,0,254,0,170,0,93,1,171,0,176,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,2,0,25,0,91,0,34,0,117,0,45,0,156,0,65,0,209,0,78,0,255,0,96,0,95,1,114,0,177,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,8,0,26,0,97,0,35,0,123,0,46,0,162,0,66,0,215,0,79,0,7,1,97,0,101,1,115,0,183,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,0,0,99,0,0,0,125,0,0,0,164,0,0,0,217,0,0,0,9,1,0,0,103,1,0,0,185,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,11,0,27,0,100,0,36,0,126,0,47,0,165,0,67,0,218,0,80,0,10,1,98,0,104,1,116,0,186,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,101,0,0,0,127,0,0,0,166,0,0,0,219,0,0,0,11,1,0,0,105,1,0,0,187,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,8,0,28,0,97,0,37,0,123,0,48,0,162,0,68,0,215,0,81,0,7,1,99,0,101,1,117,0,183,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,13,0,29,0,102,0,37,0,123,0,49,0,167,0,69,0,220,0,81,0,7,1,99,0,101,1,117,0,183,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,105,0,0,0,137,0,0,0,175,0,0,0,223,0,0,0,21,1,0,0,115,1,0,0,197,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,21,0,30,0,103,0,41,0,135,0,52,0,173,0,70,0,221,0,85,0,19,1,103,0,113,1,121,0,195,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,14,0,6,0,14,0,38,0,128,0,6,0,14,0,0,0,0,0,82,0,12,1,100,0,106,1,118,0,188,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,16,0,7,0,16,0,39,0,130,0,50,0,168,0,0,0,0,0,83,0,14,1,101,0,108,1,119,0,190,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,19,0,0,0,19,0,0,0,133,0,0,0,171,0,0,0,0,0,0,0,17,1,0,0,111,1,0,0,193,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,20,0,8,0,20,0,40,0,134,0,51,0,172,0,0,0,0,0,84,0,18,1,102,0,112,1,120,0,194,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,0,0,106,0,0,0,138,0,0,0,176,0,0,0,224,0,0,0,22,1,0,0,116,1,0,0,198,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,101,0,0,0,127,0,0,0,166,0,0,0,219,0,0,0,11,1,0,0,105,1,0,0,187,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,25,0,31,0,107,0,42,0,139,0,53,0,177,0,71,0,225,0,86,0,23,1,104,0,117,1,122,0,199,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,25,0,32,0,107,0,43,0,139,0,54,0,177,0,72,0,225,0,87,0,23,1,105,0,117,1,122,0,199,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,62,0,21,0,62,0,153,0,149,0,21,0,62,0,0,0,0,0,158,0,58,1,109,0,143,1,126,0,220,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,29,0,12,0,29,0,12,0,29,0,12,0,29,0,73,0,229,0,88,0,27,1,106,0,121,1,123,0,201,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,231,0,0,0,29,1,0,0,123,1,0,0,203,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,13,0,32,0,33,0,111,0,44,0,143,0,55,0,181,0,74,0,232,0,89,0,30,1,107,0,124,1,124,0,204,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,34,0,0,0,113,0,0,0,145,0,0,0,183,0,0,0,234,0,0,0,32,1,0,0,126,1,0,0,206,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,0,59,0,20,0,59,0,93,0,146,0,20,0,59,0,20,0,59,0,157,0,55,1,160,0,140,1,161,0,217,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,54,0,18,0,54,0,18,0,54,0,18,0,54,0,138,0,229,0,190,0,60,1,108,0,132,1,125,0,209,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,19,0,56,0,19,0,56,0,19,0,56,0,19,0,56,0,138,0,229,0,191,0,61,1,108,0,132,1,125,0,209,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,0,186,0,56,0,186,0,56,0,186,0,56,0,186,0,56,0,186,0,162,0,40,1,110,0,156,1,127,0,231,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,92,0,77,1,92,0,77,1,92,0,77,1,92,0,77,1,0,0,0,0,156,0,36,1,113,0,165,1,130,0,240,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,91,0,77,1,91,0,77,1,91,0,77,1,91,0,77,1,0,0,0,0,155,0,36,1,112,0,161,1,129,0,236,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,0,0,0,68,0,0,0,68,0,0,0,68,0,0,0,219,0,0,0,11,1,0,0,105,1,0,0,187,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,69,0,24,0,69,0,24,0,69,0,24,0,69,0,68,0,215,0,81,0,7,1,99,0,101,1,117,0,183,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,139,0,14,0,139,0,14,0,140,0,128,0,139,0,14,0,0,0,0,0,141,0,12,1,142,0,106,1,143,0,188,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,0,16,0,144,0,16,0,145,0,130,0,146,0,168,0,0,0,0,0,147,0,14,1,148,0,108,1,149,0,190,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,150,0,62,0,150,0,62,0,154,0,149,0,150,0,62,0,0,0,0,0,159,0,58,1,151,0,143,1,152,0,220,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,73,0,0,0,105,0,0,0,152,0,0,0,175,0,0,0,223,0,0,0,69,1,0,0,115,1,0,0,197,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,94,0,72,0,95,0,104,0,111,0,151,0,128,0,174,0,172,0,222,0,173,0,68,1,174,0,114,1,175,0,196,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,75,0,237,0,75,0,237,0,75,0,237,0,75,0,237,0,75,0,237,0,176,0,43,1,182,0,134,1,186,0,211,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,135,0,242,0,135,0,242,0,135,0,242,0,135,0,242,0,135,0,242,0,179,0,48,1,184,0,139,1,188,0,216,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,193,0,80,0,193,0,80,0,193,0,80,0,193,0,80,0,193,0,80,0,195,0,72,1,197,0,154,1,199,0,229,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,194,0,80,0,194,0,80,0,194,0,80,0,194,0,80,0,194,0,80,0,196,0,72,1,198,0,154,1,200,0,229,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,204,0,12,204,192,192,128,192,132,4,166,182,4,4,192,128,177,128,161,177,178,161,179,162,163,179,177,163,177,177,192,177,161,192,161,161,178,161,162,178,144,162,144,144,185,185,169,169,170,186,187,187,171,171,185,185,185,185,200,200,169,169,169,169,186,186,170,170,152,152,185,152,169,185,186,169,187,170,171,187,185,171,185,185,200,185,169,200,169,169,186,169,170,186,152,170,152,152,177,177,161,161,162,178,179,179,163,163,177,177,177,177,192,192,161,161,161,161,178,178,162,162,144,144,0,144,0,0,19,16,17,20,22,18,25,21,23,26,36,24,34,35,31,33,30,32,28,29,39,27,37,40,41,38,43,42,47,46,45,44,48,49,53,52,51,50,62,63,60,61,59,58,56,57,54,55,67,66,65,64,69,68,73,70,71,74,76,72,79,75,77,80,90,78,88,89,85,87,84,86,82,83,93,81,91,94,95,92,97,96,101,100,99,98,102,103,107,106,105,104,116,117,114,115,113,112,110,111,108,109,121,120,119,118,123,122,125,124,127,126,0,140,0,151,0,160,0,167,0,178,0,183,0,192,0,204,0,214,0,223,0,239,0,245,0,253,1,5,1,11,1,24,1,30,1,41,1,49,1,55,1,65,1,73,1,11,1,93,0,167,0,178,1,108,1,129,0,178,1,129,1,129,1,129,1,129,1,129,1,129,1,129,1,129,1,129,1,129,1,129,1,129,1,129,1,129,1,129,1,129,1,129,1,129,1,129,1,129,1,129,1,129,1,129,1,129,1,129,1,129,2,46,2,54,2,61,2,65,2,79,2,85,2,85,2,95,2,100,2,109,2,115,2,120,2,125,2,131,2,138,101,1,43,113,254,87,162,87,0,255,3,0,58,124,108,67,255,102,0,0,108,2,67,109,0,255,0,0,165,116,115,131,153,53,255,159,0,0,74,7,0,255,2,0,136,135,49,51,255,50,0,0,118,2,113,140,140,45,18,254,255,140,0,0,113,1,41,13,13,254,255,41,0,0,89,5,91,90,139,138,0,255,3,0,14,13,106,87,30,100,13,254,254,14,163,100,0,255,6,0,98,2,0,255,7,0,63,62,123,122,0,255,7,0,132,117,83,76,0,255,1,0,69,102,0,255,7,0,24,13,132,41,132,83,13,254,255,41,0,0,87,4,255,92,0,0,81,7,2,82,254,69,117,69,0,255,0,0,26,25,110,27,0,255,6,0,114,52,0,255,0,0,105,101,15,9,35,139,0,255,4,0,60,59,121,61,0,255,128,0,10,119,118,129,101,42,254,100,118,119,42,254,254,118,10,101,0,255,0,0,17,16,38,18,40,39,85,166,15,148,255,104,0,0,69,128,119,100,129,10,42,118,254,101,118,119,42,254,254,118,10,101,0,255,0,0,107,22,0,255,7,0,48,30,255,57,0,0,69,3,119,58,67,120,71,70,0,255,0,0,53,115,153,131,255,159,0,0,55,2,255,56,0,0,68,0,59,48,0,255,0,0,126,125,161,127,255,10,0,0,112,0,0,255,0,0,63,62,123,122,128,97,164,137,0,255,6,0,165,134,66,79,0,255,0,0,17,16,85,18,104,15,0,255,2,0,136,135,51,64,0,255,5,0,15,101,0,255,8,0,150,149,167,155,0,255,0,0,73,72,255,130,0,0,46,2,48,47,0,255,1,0,120,119,38,88,40,39,255,166,0,0,19,8,2,20,255,81,0,0,46,7,93,92,0,255,6,0,255,87,0,0,48,2,30,57,254,101,48,101,0,255,0,0,255,75,0,0,142,0,144,143,255,145,0,0,146,0,23,157,0,255,0,0,0,255,0,0,155,141,125,167,127,126,10,161,150,149,0,255,1,0,147,25,0,255,0,0,255,103,0,0,103,0,0,255,0,0,255,39,0,0,144,3,35,142,139,151,0,255,0,0,158,29,0,255,7,0,255,59,0,0,29,0,0,255,0,0,144,142,0,255,5,0,149,36,255,150,0,0,154,0,0,255,0,0,0,0,192,2,0,0,0,1,0,4,0,1,0,0,0,0,0,0,96,4,0,0,0,1,160,5,0,1,0,0,0,0,0,0,160,3,0,0,0,1,224,4,0,1,0,0,0,0,0,0,192,3,0,0,0,1,0,5,0,1,0,0,0,0,0,0,32,5,0,0,0,1,96,6,0,1,0,0,0,0,0,0,240,2,0,0,0,1,48,4,0,1,0,0,0,0,0,0,192,5,0,0,0,1,0,7,0,1,0,0,0,0,0,0,192,6,0,0,0,1,176,3,0,1,96,4,80,0,224,5,80,0,80,6,224,255,0,8,224,255,0,0,0,0,0,0,48,6,0,0,0,1,112,7,0,1,0,0,0,0,0,0,160,7,0,0,0,1,224,8,0,1,0,0,0,0,0,0,224,6,0,0,0,1,32,8,0,1,0,0,0,0,0,0,112,4,0,0,0,1,176,5,0,1,0,0,0,0,0,0,160,5,0,0,0,1,224,6,0,1,0,0,0,0,0,0,48,7,0,0,0,1,112,8,0,1,0,0,0,0,0,0,240,5,0,0,0,1,48,7,0,1,0,0,0,0,0,0,16,6,0,0,0,1,80,7,0,1,0,0,0,0,0,0,192,5,0,0,0,1,0,2,0,1,128,2,192,0,224,2,96,0,160,3,0,0,0,7,0,0,0,0,0,0,0,0,32,9,0,0,0,1,96,10,0,1,0,0,0,0,0,0,96,7,0,0,0,1,112,2,0,1,32,3,176,1,96,4,176,1,16,5,0,1,224,5,0,1,32,6,32,1,160,8,32,1,0,0,0,0,0,0,112,6,0,0,0,1,0,2,0,1,224,2,144,0,0,4,144,0,224,4,0,1,176,7,0,1,0,0,0,0,0,0,192,4,0,0,0,1,0,6,0,1,0,0,0,0,117,51,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,24,214,36,70,1,0,16,1,117,51,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,243,5,161,197,1,0,16,1,98,107,95,117,54,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,54,245,98,25,3,0,32,0,98,107,95,117,54,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,164,117,12,216,3,0,32,0,98,107,95,117,54,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,111,30,94,97,3,0,32,0,98,107,95,117,55,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,241,126,129,89,3,0,32,0,98,107,95,117,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,63,62,184,194,4,0,32,0,98,107,95,117,50,49,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,146,1,137,214,4,0,32,0,98,107,95,117,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,108,196,56,149,4,0,32,0,98,107,95,117,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,61,31,131,227,4,0,32,0,98,107,95,117,49,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,50,87,204,34,5,0,64,0,98,108,111,111,100,98,114,111,115,48,50,46,117,48,50,49,46,55,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,110,202,77,32,1,0,16,1,98,108,111,111,100,98,114,111,115,48,49,46,117,48,50,50,46,56,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,231,25,103,172,1,0,16,1,98,98,95,48,52,46,117,48,50,51,46,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,44,28,149,253,1,0,16,1,98,98,95,48,51,46,117,48,50,52,46,56,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,96,196,211,24,1,0,16,1,98,98,95,48,55,46,117,49,48,49,54,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,232,148,27,65,2,0,16,1,98,98,95,48,53,46,117,48,54,49,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,25,109,186,4,3,0,32,0,98,98,95,48,54,46,117,48,54,51,46,54,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,91,227,146,112,3,0,32,0,98,108,111,111,100,95,98,114,111,115,95,98,107,95,95,40,99,41,49,57,57,48,95,116,97,100,95,99,111,114,112,46,117,48,54,52,46,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,230,126,168,26,4,0,32,0,98,108,111,111,100,95,98,114,111,115,95,111,98,106,95,95,40,99,41,49,57,57,48,95,116,97,100,95,99,111,114,112,46,117,48,55,56,46,50,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,82,57,124,210,5,0,32,0,98,98,95,48,56,46,117,48,57,53,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,117,185,177,222,6,0,64,0,50,106,95,97,46,117,48,50,49,46,55,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,184,33,202,232,1,0,16,1,49,106,95,97,46,117,48,50,50,46,56,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,199,207,40,107,1,0,16,1,98,98,95,48,52,46,117,48,50,51,46,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,44,28,149,253,1,0,16,1,98,98,95,48,51,46,117,48,50,52,46,56,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,96,196,211,24,1,0,16,1,98,98,95,48,55,46,117,49,48,49,54,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,232,148,27,65,2,0,16,1,98,98,95,48,53,46,117,48,54,49,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,25,109,186,4,3,0,32,0,98,98,95,48,54,46,117,48,54,51,46,54,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,91,227,146,112,3,0,32,0,98,108,111,111,100,95,98,114,111,115,95,98,107,95,95,40,99,41,49,57,57,48,95,116,97,100,95,99,111,114,112,46,117,48,54,52,46,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,230,126,168,26,4,0,32,0,98,108,111,111,100,95,98,114,111,115,95,111,98,106,95,95,40,99,41,49,57,57,48,95,116,97,100,95,99,111,114,112,46,117,48,55,56,46,50,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,82,57,124,210,5,0,32,0,98,98,95,48,56,46,117,48,57,53,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,117,185,177,222,6,0,64,0,98,100,117,45,48,49,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,34,57,177,71,1,0,16,1,98,100,117,45,48,50,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,27,175,13,46,1,0,16,1,98,100,117,45,48,51,46,56,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,236,223,103,59,1,0,16,1,98,100,45,48,52,46,57,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,236,246,106,237,1,0,16,1,98,100,45,48,53,46,49,48,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,46,183,89,174,1,0,16,1,98,100,45,48,54,46,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,116,66,245,44,2,0,16,1,98,100,45,49,53,46,50,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,120,93,23,112,3,0,32,0,98,100,45,49,50,46,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,147,73,82,196,4,0,32,0,98,100,45,49,49,46,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,111,200,50,121,4,0,32,0,98,100,45,49,52,46,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,58,89,73,220,4,0,32,0,98,100,45,49,51,46,56,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,34,161,215,126,4,0,32,0,98,100,45,48,56,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,56,116,241,226,5,0,32,0,98,100,45,48,55,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,39,189,204,95,5,0,32,0,98,100,45,49,48,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,198,204,51,252,5,0,32,0,98,100,45,48,57,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,222,73,244,5,0,32,0,98,100,48,49,46,56,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,229,89,180,41,6,0,0,8,98,100,48,50,46,57,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,30,116,139,6,0,0,8,98,100,48,51,46,49,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,117,28,32,39,6,0,0,8,98,100,48,52,46,49,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,104,11,73,229,6,0,0,8,98,100,46,54,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,241,20,125,172,7,0,16,8,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,103,198,165,224,1,0,16,1,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,232,69,206,124,1,0,16,1,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,149,162,239,124,2,0,16,1,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,22,58,171,161,3,0,32,0,57,48,48,54,56,45,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,36,79,171,161,4,0,32,0,57,48,48,54,56,45,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,178,4,50,157,5,0,32,0,57,48,48,54,56,45,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,132,49,88,58,6,0,64,0,57,48,48,54,56,45,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,210,105,175,231,7,0,64,0,57,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,151,28,237,152,0,0,0,8,49,48,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,108,184,219,207,0,0,0,8,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,160,43,175,124,1,0,16,1,98,108,107,100,114,103,111,110,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,111,194,57,125,1,0,16,1,97,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,57,15,205,244,1,0,16,1,98,108,107,100,114,103,111,110,46,57,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,128,102,29,77,1,0,16,1,98,108,107,100,114,103,111,110,46,49,48,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,94,196,208,200,1,0,16,1,98,100,45,48,54,46,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,116,66,245,44,2,0,16,1,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,183,210,42,133,3,0,32,0,98,108,107,100,114,103,111,110,46,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,176,164,208,34,4,0,32,0,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,92,177,58,5,4,0,32,0,98,108,107,100,114,103,111,110,46,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,120,195,152,148,4,0,32,0,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,67,233,198,157,4,0,32,0,98,100,45,48,56,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,56,116,241,226,5,0,32,0,98,100,45,48,55,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,39,189,204,95,5,0,32,0,98,100,45,49,48,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,198,204,51,252,5,0,32,0,98,100,45,48,57,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,222,73,244,5,0,32,0,98,100,48,49,46,56,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,229,89,180,41,6,0,0,8,98,100,48,50,46,57,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,30,116,139,6,0,0,8,98,100,48,51,46,49,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,117,28,32,39,6,0,0,8,98,100,48,52,46,49,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,104,11,73,229,6,0,0,8,168,86,7,0,1,0,0,0,75,191,145,0,248,191,2,0,24,38,7,0,1,0,0,0,77,191,145,0,184,160,2,0,56,210,6,0,1,0,0,0,72,251,146,0,192,135,2,0,24,163,6,0,1,0,0,0,73,251,146,0,240,108,2,0,152,122,6,0,1,0,0,0,74,251,146,0,96,82,2,0,192,72,6,0,1,0,0,0,75,251,146,0,32,56,2,0,200,110,3,0,1,0,0,0,76,251,146,0,152,30,2,0,120,89,3,0,1,0,0,0,77,251,146,0,232,10,2,0,120,74,3,0,1,0,0,0,78,251,146,0,152,138,8,0,40,246,1,0,1,0,0,0,76,191,145,0,64,246,1,0,144,236,1,0,1,0,0,0,78,191,145,0,136,224,1,0,176,223,1,0,1,0,0,0,24,243,146,0,72,198,1,0,192,209,1,0,1,0,0,0,25,243,146,0,24,182,1,0,24,198,1,0,1,0,0,0,26,243,146,0,40,167,1,0,120,189,1,0,1,0,0,0,27,243,146,0,200,149,1,0,224,22,1,0,1,0,0,0,28,243,146,0,56,126,1,0,160,14,1,0,1,0,0,0,29,243,146,0,32,101,1,0,176,9,1,0,1,0,0,0,30,243,146,0,96,32,8,0,88,212,3,0,1,0,0,0,248,215,146,0,40,185,3,0,32,77,1,0,1,0,0,0,72,191,145,0,216,70,1,0,72,65,1,0,9,0,0,0,123,223,146,0,32,58,1,0,48,50,1,0,9,0,0,0,124,223,146,0,32,58,1,0,224,41,1,0,9,0,0,0,125,223,146,0,32,58,1,0,0,28,118,106,94,66,36,56,75,103,173,129,233,197,3,47,69,105,175,131,231,203,1,45,2,30,120,100,92,64,42,54,50,46,68,88,228,248,158,130,41,5,207,227,147,191,121,85,63,19,213,249,133,169,99,79,184,164,194,222,110,114,24,4,12,16,122,102,252,224,134,154,71,107,161,141,187,151,81,125,23,59,253,209,235,199,13,33,160,188,218,198,80,76,38,58,62,34,72,84,70,90,60,32,37,9,195,239,193,237,43,7,109,65,135,171,137,165,111,67,26,6,96,124,98,126,20,8,10,22,112,108,220,192,170,182,77,97,167,139,247,219,17,61,91,119,189,145,225,205,11,39,128,156,246,234,86,74,44,48,176,172,202,214,238,242,152,132,55,27,221,241,149,185,115,95,57,21,223,243,155,183,113,93,178,174,196,216,236,240,150,138,168,180,210,206,208,204,166,186,31,51,245,217,251,215,29,49,87,123,177,157,179,159,89,117,140,144,250,230,244,232,142,146,18,14,104,116,226,254,148,136,101,73,143,163,153,181,127,83,53,25,211,255,201,229,35,15,190,162,200,212,78,82,52,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,51,54,48,54,54,45,49,49,48,50,46,52,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,2,137,210,27,1,0,16,1,49,51,54,48,54,54,45,49,49,48,51,46,51,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,147,127,42,236,2,0,32,0,107,49,45,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,9,104,5,250,1,0,16,1,49,51,54,48,54,54,45,49,49,48,49,46,51,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,159,147,161,132,2,0,32,0,49,46,51,102,46,105,99,56,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,194,61,249,159,1,0,16,1,50,46,52,102,46,105,99,56,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,235,60,195,187,1,0,16,1,97,55,53,45,48,54,46,105,99,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,182,119,93,81,2,0,16,1,51,46,49,99,46,105,99,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,186,116,139,3,3,0,32,0,52,46,51,99,46,105,99,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,153,225,250,113,3,0,32,0,53,46,52,99,46,105,99,51,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,226,116,99,199,3,0,32,0,97,55,53,45,48,55,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,137,178,248,10,4,0,32,0,97,55,53,45,48,56,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,251,2,176,171,4,0,32,0,97,55,53,45,48,57,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,119,194,198,167,4,0,32,0,54,56,55,48,53,112,51,46,54,105,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,251,140,154,56,0,0,16,8,54,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,194,61,249,159,1,0,16,1,54,102,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,171,98,107,237,1,0,16,1,97,55,53,45,48,54,46,105,99,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,182,119,93,81,2,0,16,1,51,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,186,116,139,3,3,0,32,0,51,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,153,225,250,113,3,0,32,0,51,102,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,226,116,99,199,3,0,32,0,97,55,53,45,48,55,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,137,178,248,10,4,0,32,0,97,55,53,45,48,56,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,251,2,176,171,4,0,32,0,97,55,53,45,48,57,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,119,194,198,167,4,0,32,0,0,0,0,0,255,7,0,0,255,15,0,0,255,23,0,0,255,31,0,0,255,39,0,0,255,47,0,0,255,55,0,0,255,63,0,0,255,71,0,0,255,79,0,0,255,87,0,0,255,95,0,0,255,103,0,0,255,111,0,0,255,119,0,0,105,103,115,99,48,49,48,50,46,117,56,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,227,43,67,227,1,0,16,1,104,102,104,95,112,46,117,56,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,220,235,117,81,1,0,16,1,104,102,104,95,112,46,117,55,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,140,151,173,66,1,0,16,1,104,102,104,95,115,46,117,56,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,237,169,40,87,2,0,16,1,105,103,115,116,48,49,48,49,46,117,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,123,45,225,44,3,0,32,0,105,103,115,116,48,49,48,50,46,117,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,160,118,42,84,3,0,32,0,105,103,115,116,48,49,48,51,46,117,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,138,105,245,173,3,0,32,0,105,103,115,98,48,49,48,49,46,117,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,126,95,153,92,4,0,32,0,105,103,115,98,48,49,48,50,46,117,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,175,155,174,162,4,0,32,0,105,103,115,98,48,49,48,51,46,117,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,175,39,185,17,4,0,32,0,105,103,115,97,48,49,48,49,46,117,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,196,7,77,55,5,0,32,0,105,103,115,97,48,49,48,50,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,172,231,238,219,5,0,32,0,105,103,115,97,48,49,48,51,46,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,65,144,241,229,5,0,32,0,104,102,104,95,103,46,117,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,87,155,70,236,6,0,64,0,104,102,104,95,103,46,117,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,142,217,252,124,7,0,64,0,121,114,119,56,48,49,45,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,67,141,157,42,8,0,64,0,184,40,2,0,1,0,0,0,85,0,147,0,248,191,2,0,184,164,8,0,1,0,0,0,87,0,147,0,64,246,1,0,56,250,6,0,1,0,0,0,189,247,146,0,184,160,2,0,88,149,7,0,1,0,0,0,190,247,146,0,136,224,1,0,56,210,6,0,1,0,0,0,80,0,147,0,192,135,2,0,152,122,6,0,1,0,0,0,81,0,147,0,96,82,2,0,192,72,6,0,1,0,0,0,82,0,147,0,32,56,2,0,24,163,6,0,1,0,0,0,83,0,147,0,240,108,2,0,200,110,3,0,1,0,0,0,86,0,147,0,152,30,2,0,176,223,1,0,1,0,0,0,184,247,146,0,72,198,1,0,24,198,1,0,1,0,0,0,185,247,146,0,40,167,1,0,120,189,1,0,1,0,0,0,186,247,146,0,200,149,1,0,192,209,1,0,1,0,0,0,187,247,146,0,24,182,1,0,224,22,1,0,1,0,0,0,188,247,146,0,56,126,1,0,88,212,3,0,1,0,0,0,128,219,146,0,40,185,3,0,64,23,5,0,9,0,0,0,200,5,147,0,32,58,1,0,104,20,5,0,9,0,0,0,201,5,147,0,32,58,1,0,216,16,5,0,9,0,0,0,202,5,147,0,32,58,1,0,88,12,5,0,9,0,0,0,203,5,147,0,32,58,1,0,55,54,56,110,48,51,46,107,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,42,202,77,62,1,0,16,1,55,54,56,106,48,54,46,107,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,62,60,40,66,1,0,16,1,55,54,56,101,48,49,46,101,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,132,241,255,185,2,0,16,1,55,54,56,99,48,57,46,103,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,221,63,190,227,3,0,32,0,55,54,56,99,48,56,46,103,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,139,219,51,150,3,0,32,0,55,54,56,99,48,52,46,106,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,14,104,96,41,4,0,32,0,55,54,56,99,48,53,46,106,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,242,162,101,4,0,32,0,55,54,56,99,48,55,46,101,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,156,136,249,1,5,0,64,0,55,54,56,99,49,51,46,106,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,203,128,222,245,6,0,32,0,55,54,56,99,49,52,46,106,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,183,113,32,179,6,0,32,0,55,54,56,99,49,49,46,105,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,203,128,222,245,6,0,32,0,55,54,56,99,49,48,46,105,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,183,113,32,179,6,0,32,0,55,54,56,98,49,50,46,100,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,184,68,37,54,0,0,32,8,112,114,45,49,52,106,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,189,5,152,107,1,0,16,1,112,114,45,49,49,106,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,36,65,70,133,2,0,16,1,112,114,45,50,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,240,93,10,110,3,0,16,1,105,56,48,99,53,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,4,0,0,16,112,114,45,48,48,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,13,143,166,140,5,0,32,0,112,114,45,48,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,119,179,108,126,6,0,32,0,112,114,45,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,70,94,189,107,6,0,32,0,112,114,45,50,48,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,144,51,221,164,7,0,64,0,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,162,22,66,158,1,0,16,1,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,36,65,70,133,2,0,16,1,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,240,93,10,110,3,0,16,1,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,162,240,59,46,4,0,32,0,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,70,198,35,44,4,0,32,0,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,112,212,108,13,4,0,32,0,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,81,46,55,179,4,0,32,0,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,109,232,222,117,5,0,32,0,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,51,131,138,201,5,0,32,0,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,189,174,155,78,5,0,32,0,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,216,140,220,99,5,0,32,0,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,70,94,189,107,5,0,32,0,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,227,191,217,33,6,0,64,0,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,226,25,205,88,6,0,64,0,53,46,117,101,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,5,192,137,101,1,0,16,1,54,46,117,99,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,240,186,114,53,1,0,16,1,51,46,115,117,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,112,35,53,62,2,0,16,1,52,46,117,108,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,180,42,54,233,3,0,32,0,57,46,117,119,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,102,153,229,134,4,0,32,0,49,48,46,117,120,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,4,141,44,18,4,0,32,0,56,46,117,111,56,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,216,227,131,154,5,0,32,0,55,46,117,111,56,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,113,214,56,60,5,0,32,0,50,46,115,117,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,91,97,171,147,6,0,64,0,49,46,115,117,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,187,54,168,9,6,0,64,0,56,50,115,49,50,57,46,117,103,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,108,184,219,207,0,0,0,8,56,50,115,49,52,55,46,117,104,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,114,208,11,237,0,0,0,8,20,0,0,0,255,255,1,0,0,0,0,0,0,0,0,0,254,0,2,0,48,45,3,0,20,0,0,0,1,1,0,0,80,65,1,0,20,0,0,0,1,1,1,0,176,20,3,0,168,86,7,0,1,0,0,0,192,191,145,0,248,191,2,0,24,38,7,0,1,0,0,0,194,191,145,0,184,160,2,0,56,210,6,0,1,0,0,0,152,254,146,0,192,135,2,0,24,163,6,0,1,0,0,0,153,254,146,0,240,108,2,0,152,122,6,0,1,0,0,0,154,254,146,0,96,82,2,0,192,72,6,0,1,0,0,0,155,254,146,0,32,56,2,0,200,110,3,0,1,0,0,0,156,254,146,0,152,30,2,0,120,89,3,0,1,0,0,0,157,254,146,0,232,10,2,0,40,246,1,0,1,0,0,0,193,191,145,0,64,246,1,0,144,236,1,0,1,0,0,0,195,191,145,0,136,224,1,0,176,223,1,0,1,0,0,0,56,246,146,0,72,198,1,0,192,209,1,0,1,0,0,0,57,246,146,0,24,182,1,0,24,198,1,0,1,0,0,0,58,246,146,0,40,167,1,0,120,189,1,0,1,0,0,0,59,246,146,0,200,149,1,0,224,22,1,0,1,0,0,0,60,246,146,0,56,126,1,0,160,14,1,0,1,0,0,0,61,246,146,0,32,101,1,0,168,132,8,0,1,0,0,0,198,191,145,0,232,209,1,0,88,212,3,0,1,0,0,0,104,218,146,0,40,185,3,0,72,65,1,0,9,0,0,0,91,224,146,0,32,58,1,0,48,50,1,0,9,0,0,0,92,224,146,0,32,58,1,0,224,41,1,0,9,0,0,0,93,224,146,0,32,58,1,0,102,100,48,56,45,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,96,75,0,105,1,0,16,1,102,100,48,57,45,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,62,174,85,164,1,0,16,1,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,55,209,186,202,1,0,16,1,49,55,45,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,6,209,154,40,2,0,16,1,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,30,242,186,161,3,0,32,0,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,48,71,230,34,3,0,32,0,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,252,14,219,177,4,0,32,0,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,79,224,19,243,4,0,32,0,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,135,221,182,140,4,0,32,0,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,239,93,52,221,4,0,32,0,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,80,149,10,213,4,0,32,0,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,147,94,147,52,4,0,32,0,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,149,23,244,188,4,0,32,0,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,170,148,139,211,4,0,32,0,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,32,116,69,214,5,0,32,0,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,122,123,120,8,5,0,32,0,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,220,55,12,195,5,0,32,0,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,159,109,0,31,5,0,32,0,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,66,178,85,92,6,0,64,0,48,56,45,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,164,20,242,59,1,0,16,1,48,57,45,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,213,120,174,19,1,0,16,1,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,55,209,186,202,1,0,16,1,49,55,45,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,6,209,154,40,2,0,16,1,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,30,242,186,161,3,0,32,0,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,48,71,230,34,3,0,32,0,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,252,14,219,177,4,0,32,0,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,79,224,19,243,4,0,32,0,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,135,221,182,140,4,0,32,0,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,239,93,52,221,4,0,32,0,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,80,149,10,213,4,0,32,0,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,147,94,147,52,4,0,32,0,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,149,23,244,188,4,0,32,0,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,170,148,139,211,4,0,32,0,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,32,116,69,214,5,0,32,0,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,122,123,120,8,5,0,32,0,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,220,55,12,195,5,0,32,0,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,159,109,0,31,5,0,32,0,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,66,178,85,92,6,0,64,0,112,114,103,45,49,46,117,53,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,95,52,107,1,0,16,1,112,114,103,45,50,46,117,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,140,185,9,206,1,0,16,1,109,49,54,109,45,49,46,117,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,116,100,154,11,0,0,32,0,109,49,54,109,45,50,46,117,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,46,140,138,54,0,0,32,0,109,49,54,109,45,51,46,117,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,221,128,252,50,0,0,32,0,115,110,100,45,49,46,115,117,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,255,240,183,187,0,0,64,0,115,110,100,45,50,46,115,117,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,46,149,227,71,0,0,64,0,20,0,0,0,255,255,239,0,0,0,0,0,21,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,8,0,184,40,2,0,20,0,0,0,1,7,7,0,216,217,1,0,20,0,0,0,1,7,6,0,224,67,5,0,20,0,0,0,1,7,5,0,216,36,5,0,20,0,0,0,1,7,4,0,152,160,5,0,20,0,0,0,1,7,3,0,16,227,4,0,20,0,0,0,1,7,2,0,128,107,4,0,20,0,0,0,1,7,1,0,8,7,5,0,20,0,0,0,1,7,0,0,144,127,5,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,24,24,0,248,160,5,0,20,0,0,0,1,24,16,0,112,212,3,0,20,0,0,0,1,24,8,0,248,38,7,0,20,0,0,0,1,24,0,0,80,246,3,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,96,96,0,8,49,4,0,20,0,0,0,1,96,64,0,208,75,4,0,20,0,0,0,1,96,32,0,152,21,4,0,20,0,0,0,1,96,0,0,72,246,3,0,0,0,0,0,254,0,2,0,16,17,8,0,20,0,0,0,1,128,128,0,96,135,7,0,20,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,200,135,2,0,21,0,0,0,1,1,1,0,96,135,7,0,21,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,21,0,0,0,1,2,2,0,104,134,3,0,21,0,0,0,1,2,0,0,56,111,3,0,168,86,7,0,1,0,0,0,136,239,146,0,248,191,2,0,24,38,7,0,1,0,0,0,223,254,146,0,184,160,2,0,56,210,6,0,1,0,0,0,218,254,146,0,192,135,2,0,24,163,6,0,1,0,0,0,219,254,146,0,240,108,2,0,152,122,6,0,1,0,0,0,216,254,146,0,96,82,2,0,192,72,6,0,1,0,0,0,217,254,146,0,32,56,2,0,200,110,3,0,1,0,0,0,220,254,146,0,152,30,2,0,120,89,3,0,1,0,0,0,221,254,146,0,232,10,2,0,144,236,1,0,1,0,0,0,127,246,146,0,136,224,1,0,176,223,1,0,1,0,0,0,122,246,146,0,72,198,1,0,192,209,1,0,1,0,0,0,123,246,146,0,24,182,1,0,24,198,1,0,1,0,0,0,120,246,146,0,40,167,1,0,120,189,1,0,1,0,0,0,121,246,146,0,200,149,1,0,224,22,1,0,1,0,0,0,124,246,146,0,56,126,1,0,160,14,1,0,1,0,0,0,125,246,146,0,32,101,1,0,88,212,3,0,1,0,0,0,160,218,146,0,40,185,3,0,16,17,8,0,1,0,0,0,138,239,146,0,224,12,8,0,56,58,1,0,1,0,0,0,139,239,146,0,64,50,1,0,72,65,1,0,9,0,0,0,48,5,147,0,32,58,1,0,48,50,1,0,9,0,0,0,49,5,147,0,32,58,1,0,224,41,1,0,9,0,0,0,50,5,147,0,32,58,1,0,184,40,2,0,1,0,0,0,176,233,148,0,248,191,2,0,56,250,6,0,1,0,0,0,180,233,148,0,184,160,2,0,184,164,8,0,1,0,0,0,177,233,148,0,64,246,1,0,88,149,7,0,1,0,0,0,181,233,148,0,136,224,1,0,152,225,1,0,4,0,0,0,184,218,148,0,152,210,1,0,152,198,1,0,4,0,0,0,168,218,148,0,208,189,1,0,48,123,2,0,1,0,0,0,240,232,148,0,248,174,1,0,88,150,1,0,4,0,0,0,160,218,148,0,136,7,4,0,144,126,1,0,4,0,0,0,152,218,148,0,136,113,1,0,248,187,8,0,1,0,0,0,241,232,148,0,56,126,1,0,88,212,3,0,1,0,0,0,88,217,146,0,40,185,3,0,240,152,1,0,1,0,0,0,178,233,148,0,216,70,1,0,16,17,8,0,1,0,0,0,183,233,148,0,224,12,8,0,248,5,8,0,9,0,0,0,64,94,147,0,32,58,1,0,144,250,7,0,9,0,0,0,65,94,147,0,32,58,1,0,230,0,0,0,230,0,0,0,230,0,0,0,230,0,0,0,51,1,0,0,153,1,0,0,0,2,0,0,102,2,0,0,120,109,110,101,100,46,48,51,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,3,96,245,190,1,0,16,1,120,109,110,101,100,46,48,52,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,166,31,162,177,1,0,16,1,120,109,110,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,89,119,13,172,1,0,16,1,120,109,110,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,40,163,134,27,1,0,16,1,120,109,110,46,48,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,68,42,20,44,1,0,16,1,120,109,110,46,48,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,79,212,18,247,1,0,16,1,120,109,110,46,48,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,232,202,65,146,1,0,16,1,120,109,110,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,185,234,192,83,1,0,16,1,120,109,110,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,115,240,77,191,5,0,32,0,120,109,110,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,239,76,126,77,5,0,32,0,120,109,110,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,23,234,62,81,5,0,32,0,120,109,110,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,252,151,56,210,5,0,32,0,120,109,110,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,183,55,130,119,5,0,32,0,120,109,110,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,72,105,179,103,5,0,32,0,120,109,110,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,76,124,90,1,5,0,32,0,120,109,110,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,88,39,222,157,5,0,32,0,120,109,110,46,48,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,234,121,244,64,10,0,16,1,120,109,110,46,48,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,173,181,217,57,10,0,16,1,120,109,110,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,188,166,72,200,12,0,64,0,120,109,110,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,143,24,156,114,12,0,64,0,120,109,110,104,46,48,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,79,168,176,99,1,0,16,1,120,109,110,104,46,48,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,183,185,177,1,0,16,1,120,109,110,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,89,119,13,172,1,0,16,1,120,109,110,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,40,163,134,27,1,0,16,1,120,109,110,46,48,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,68,42,20,44,1,0,16,1,120,109,110,46,48,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,79,212,18,247,1,0,16,1,120,109,110,46,48,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,232,202,65,146,1,0,16,1,120,109,110,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,185,234,192,83,1,0,16,1,120,109,110,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,115,240,77,191,5,0,32,0,120,109,110,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,239,76,126,77,5,0,32,0,120,109,110,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,23,234,62,81,5,0,32,0,120,109,110,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,252,151,56,210,5,0,32,0,120,109,110,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,183,55,130,119,5,0,32,0,120,109,110,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,72,105,179,103,5,0,32,0,120,109,110,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,76,124,90,1,5,0,32,0,120,109,110,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,88,39,222,157,5,0,32,0,120,109,110,46,48,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,234,121,244,64,10,0,16,1,120,109,110,46,48,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,173,181,217,57,10,0,16,1,120,109,110,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,188,166,72,200,12,0,64,0,120,109,110,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,143,24,156,114,12,0,64,0,120,109,110,97,46,48,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,126,178,248,125,1,0,16,1,120,109,110,97,46,48,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,167,48,78,180,1,0,16,1,120,109,110,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,162,98,237,195,1,0,16,1,120,109,110,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,225,82,60,240,1,0,16,1,120,109,110,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,177,38,86,50,1,0,16,1,120,109,110,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,16,234,148,113,1,0,16,1,120,109,110,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,243,109,148,174,1,0,16,1,120,109,110,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,29,190,166,50,1,0,16,1,120,109,110,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,115,240,77,191,5,0,32,0,120,109,110,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,239,76,126,77,5,0,32,0,120,109,110,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,23,234,62,81,5,0,32,0,120,109,110,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,252,151,56,210,5,0,32,0,120,109,110,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,183,55,130,119,5,0,32,0,120,109,110,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,72,105,179,103,5,0,32,0,120,109,110,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,76,124,90,1,5,0,32,0,120,109,110,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,88,39,222,157,5,0,32,0,120,109,110,46,48,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,234,121,244,64,10,0,16,1,120,109,110,46,48,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,173,181,217,57,10,0,16,1,120,109,110,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,188,166,72,200,12,0,64,0,120,109,110,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,143,24,156,114,12,0,64,0,168,86,7,0,1,0,0,0,248,236,146,0,248,191,2,0,24,38,7,0,1,0,0,0,47,245,146,0,184,160,2,0,240,251,8,0,4,0,0,0,232,7,147,0,152,210,1,0,176,223,8,0,4,0,0,0,236,7,147,0,208,189,1,0,200,110,3,0,1,0,0,0,120,253,146,0,248,174,1,0,120,89,3,0,1,0,0,0,121,253,146,0,104,160,1,0,120,74,3,0,1,0,0,0,14,239,146,0,152,138,8,0,192,61,3,0,1,0,0,0,46,245,146,0,48,119,7,0,40,246,1,0,1,0,0,0,249,236,146,0,64,246,1,0,144,236,1,0,1,0,0,0,15,239,146,0,136,224,1,0,112,188,8,0,4,0,0,0,240,7,147,0,136,7,4,0,192,123,8,0,4,0,0,0,244,7,147,0,136,113,1,0,224,22,1,0,1,0,0,0,124,253,146,0,56,126,1,0,160,14,1,0,1,0,0,0,125,253,146,0,32,101,1,0,176,9,1,0,1,0,0,0,13,239,146,0,96,32,8,0,200,3,1,0,1,0,0,0,45,245,146,0,16,68,7,0,88,212,3,0,1,0,0,0,168,217,146,0,40,185,3,0,16,17,8,0,1,0,0,0,250,236,146,0,224,12,8,0,72,65,1,0,9,0,0,0,38,224,146,0,32,58,1,0,48,50,1,0,9,0,0,0,39,224,146,0,32,58,1,0,101,112,114,45,49,50,51,55,48,46,97,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,118,187,93,203,1,0,16,1,101,112,114,45,49,50,51,54,57,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,47,221,71,111,1,0,16,1,101,112,114,45,49,50,49,52,54,46,97,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,101,166,123,183,1,0,16,1,101,112,114,45,49,50,49,52,52,46,97,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,203,117,240,221,1,0,16,1,109,112,114,45,49,50,49,53,48,46,97,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,185,26,130,106,2,0,32,0,109,112,114,45,49,50,49,53,49,46,97,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,81,7,26,43,2,0,32,0,109,112,114,45,49,50,49,53,50,46,97,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,254,144,225,246,2,0,32,0,109,112,114,45,49,50,49,53,51,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,104,211,167,255,3,0,32,0,109,112,114,45,49,50,49,53,55,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,193,148,119,141,3,0,32,0,109,112,114,45,49,50,49,53,52,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,242,67,211,14,3,0,32,0,109,112,114,45,49,50,49,53,56,46,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,88,141,69,153,3,0,32,0,109,112,114,45,49,50,49,53,53,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,77,16,135,48,3,0,32,0,109,112,114,45,49,50,49,53,57,46,98,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,237,155,207,171,3,0,32,0,111,112,114,45,49,50,49,53,54,46,98,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,139,6,182,65,3,0,32,0,111,112,114,45,49,50,49,54,48,46,98,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,100,193,234,151,3,0,32,0,111,112,114,45,49,50,49,52,49,46,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,197,17,3,38,3,0,32,0,111,112,114,45,49,50,49,54,49,46,98,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,177,177,164,53,3,0,32,0,111,112,114,45,49,50,49,52,50,46,97,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,92,138,227,18,3,0,32,0,111,112,114,45,49,50,49,54,50,46,98,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,36,253,6,250,3,0,32,0,101,112,114,45,49,50,49,52,55,46,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,7,150,96,195,4,0,16,1,109,112,114,45,49,50,49,52,56,46,97,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,41,127,154,251,8,0,64,0,109,112,114,45,49,50,49,52,57,46,97,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,25,123,97,214,8,0,64,0,51,49,55,45,48,49,48,50,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,240,27,186,40,5,0,16,1,101,112,114,45,49,50,49,52,53,46,97,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,46,30,245,42,1,0,16,1,101,112,114,45,49,50,49,52,51,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,69,227,49,65,1,0,16,1,101,112,114,45,49,50,49,52,54,46,97,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,101,166,123,183,1,0,16,1,101,112,114,45,49,50,49,52,52,46,97,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,203,117,240,221,1,0,16,1,109,112,114,45,49,50,49,53,48,46,97,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,185,26,130,106,2,0,32,0,109,112,114,45,49,50,49,53,49,46,97,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,81,7,26,43,2,0,32,0,109,112,114,45,49,50,49,53,50,46,97,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,254,144,225,246,2,0,32,0,109,112,114,45,49,50,49,53,51,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,104,211,167,255,3,0,32,0,109,112,114,45,49,50,49,53,55,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,193,148,119,141,3,0,32,0,109,112,114,45,49,50,49,53,52,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,242,67,211,14,3,0,32,0,109,112,114,45,49,50,49,53,56,46,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,88,141,69,153,3,0,32,0,109,112,114,45,49,50,49,53,53,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,77,16,135,48,3,0,32,0,109,112,114,45,49,50,49,53,57,46,98,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,237,155,207,171,3,0,32,0,111,112,114,45,49,50,49,53,54,46,98,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,139,6,182,65,3,0,32,0,111,112,114,45,49,50,49,54,48,46,98,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,100,193,234,151,3,0,32,0,111,112,114,45,49,50,49,52,49,46,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,197,17,3,38,3,0,32,0,111,112,114,45,49,50,49,54,49,46,98,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,177,177,164,53,3,0,32,0,111,112,114,45,49,50,49,52,50,46,97,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,92,138,227,18,3,0,32,0,111,112,114,45,49,50,49,54,50,46,98,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,36,253,6,250,3,0,32,0,101,112,114,45,49,50,49,52,55,46,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,7,150,96,195,4,0,16,1,109,112,114,45,49,50,49,52,56,46,97,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,41,127,154,251,8,0,64,0,109,112,114,45,49,50,49,52,57,46,97,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,25,123,97,214,8,0,64,0,51,49,55,45,48,48,57,48,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,74,76,194,183,5,0,16,1,119,98,45,112,114,111,103,45,49,46,55,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,227,183,223,184,1,0,16,1,119,98,45,112,114,111,103,45,50,46,55,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,224,84,136,253,1,0,16,1,119,98,45,112,114,111,103,45,51,46,55,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,20,170,149,68,1,0,16,1,119,98,45,112,114,111,103,45,52,46,55,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,124,37,189,228,1,0,16,1,119,98,45,112,114,111,103,45,53,46,55,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,180,123,37,113,1,0,16,1,119,97,114,111,102,98,117,103,46,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,133,250,0,129,4,0,32,0,119,97,114,111,102,98,117,103,46,49,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,233,10,34,209,4,0,32,0,119,97,114,111,102,98,117,103,46,99,108,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,75,230,136,134,7,0,32,0,99,48,52,45,49,50,46,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,236,199,25,227,2,0,16,1,99,48,52,45,48,56,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,85,247,198,129,2,0,16,1,99,48,52,45,49,49,46,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,166,150,86,240,2,0,16,1,99,48,52,45,48,55,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,132,161,237,78,2,0,16,1,99,48,52,45,50,48,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,31,101,234,10,2,0,16,1,99,48,52,45,50,50,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,101,212,5,244,2,0,16,1,99,48,52,45,49,57,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,174,147,20,35,2,0,16,1,99,48,52,45,50,49,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,142,211,152,133,2,0,16,1,99,48,52,45,48,54,46,55,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,178,6,1,183,9,0,16,1,99,48,52,45,49,54,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,239,118,36,140,16,0,32,0,99,48,52,45,49,56,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,44,33,101,118,16,0,32,0,99,48,52,45,49,53,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,120,185,80,124,16,0,32,0,99,48,52,45,49,55,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,184,222,47,198,16,0,32,0,99,48,52,45,49,48,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,73,107,155,66,16,0,32,0,99,48,52,45,48,57,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,87,240,140,199,16,0,32,0,99,48,52,45,49,48,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,73,107,155,66,16,0,32,0,99,48,52,45,48,57,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,87,240,140,199,16,0,32,0,99,48,52,45,52,45,49,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,101,174,159,171,0,0,0,8,99,48,52,45,53,46,55,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,137,236,99,39,0,0,0,8,184,40,2,0,1,0,0,0,176,148,215,0,248,191,2,0,56,250,6,0,1,0,0,0,190,148,215,0,184,160,2,0,184,164,8,0,1,0,0,0,177,148,215,0,64,246,1,0,88,149,7,0,1,0,0,0,189,148,215,0,136,224,1,0,56,210,6,0,1,0,0,0,170,148,215,0,192,135,2,0,24,163,6,0,1,0,0,0,171,148,215,0,240,108,2,0,152,122,6,0,1,0,0,0,172,148,215,0,96,82,2,0,192,72,6,0,1,0,0,0,173,148,215,0,32,56,2,0,48,123,2,0,1,0,0,0,174,148,215,0,152,30,2,0,176,223,1,0,1,0,0,0,161,148,215,0,72,198,1,0,192,209,1,0,1,0,0,0,162,148,215,0,24,182,1,0,24,198,1,0,1,0,0,0,163,148,215,0,40,167,1,0,120,189,1,0,1,0,0,0,164,148,215,0,200,149,1,0,248,187,8,0,1,0,0,0,165,148,215,0,56,126,1,0,88,212,3,0,1,0,0,0,200,147,215,0,40,185,3,0,16,17,8,0,1,0,0,0,191,148,215,0,224,12,8,0,56,58,1,0,1,0,0,0,168,148,215,0,64,50,1,0,248,5,8,0,9,0,0,0,96,149,215,0,32,58,1,0,144,250,7,0,9,0,0,0,97,149,215,0,32,58,1,0,118,112,104,106,115,116,111,112,46,48,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,145,97,78,156,1,0,16,1,118,112,104,106,46,48,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,4,243,92,201,1,0,16,1,118,112,104,106,46,48,53,100,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,221,93,222,80,1,0,16,1,118,112,104,106,46,48,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,213,211,59,172,1,0,16,1,118,112,104,106,46,48,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,159,48,97,7,1,0,16,1,118,112,104,106,46,48,56,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,245,43,92,90,1,0,16,1,118,112,104,106,46,48,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,153,109,61,130,1,0,16,1,118,112,104,106,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,240,216,199,50,1,0,16,1,118,112,104,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,153,175,27,197,5,0,32,0,118,112,104,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,119,60,232,60,5,0,32,0,118,112,104,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,224,8,36,79,5,0,32,0,118,112,104,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,80,2,246,159,5,0,32,0,118,112,104,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,221,26,14,122,5,0,32,0,118,112,104,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,117,202,65,47,5,0,32,0,118,112,104,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,237,142,73,100,5,0,32,0,118,112,104,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,63,67,242,23,5,0,32,0,118,112,104,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,172,220,69,80,10,0,16,1,118,112,104,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,89,14,182,134,10,0,16,1,118,112,104,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,51,125,131,225,12,0,64,0,118,112,104,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,144,205,211,251,12,0,64,0,184,40,2,0,1,0,0,0,128,93,148,0,248,191,2,0,56,250,6,0,1,0,0,0,132,93,148,0,184,160,2,0,184,164,8,0,1,0,0,0,129,93,148,0,64,246,1,0,88,149,7,0,1,0,0,0,133,93,148,0,136,224,1,0,56,210,6,0,1,0,0,0,149,93,148,0,192,135,2,0,24,163,6,0,1,0,0,0,148,93,148,0,240,108,2,0,152,122,6,0,1,0,0,0,151,93,148,0,96,82,2,0,192,72,6,0,1,0,0,0,150,93,148,0,32,56,2,0,48,123,2,0,1,0,0,0,146,93,148,0,152,30,2,0,176,223,1,0,1,0,0,0,141,93,148,0,72,198,1,0,192,209,1,0,1,0,0,0,140,93,148,0,24,182,1,0,24,198,1,0,1,0,0,0,143,93,148,0,40,167,1,0,120,189,1,0,1,0,0,0,142,93,148,0,200,149,1,0,248,187,8,0,1,0,0,0,138,93,148,0,56,126,1,0,88,212,3,0,1,0,0,0,248,26,149,0,40,185,3,0,16,17,8,0,1,0,0,0,131,93,148,0,224,12,8,0,80,251,6,0,1,0,0,0,130,93,148,0,216,70,1,0,248,5,8,0,9,0,0,0,112,99,215,0,32,58,1,0,144,250,7,0,9,0,0,0,113,99,215,0,32,58,1,0,184,40,2,0,1,0,0,0,128,0,147,0,248,191,2,0,184,164,8,0,1,0,0,0,129,0,147,0,64,246,1,0,104,28,8,0,1,0,0,0,130,0,147,0,232,209,1,0,24,38,7,0,1,0,0,0,232,247,146,0,184,160,2,0,56,210,6,0,1,0,0,0,233,247,146,0,192,135,2,0,24,163,6,0,1,0,0,0,237,247,146,0,240,108,2,0,152,122,6,0,1,0,0,0,234,247,146,0,96,82,2,0,192,72,6,0,1,0,0,0,235,247,146,0,32,56,2,0,88,212,3,0,1,0,0,0,184,219,146,0,40,185,3,0,72,65,1,0,9,0,0,0,241,5,147,0,168,57,4,0,48,50,1,0,9,0,0,0,240,5,147,0,168,57,4,0,98,56,55,45,48,57,46,117,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,199,103,98,126,2,0,16,1,98,56,55,45,48,56,46,117,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,111,145,217,49,2,0,16,1,98,56,55,45,48,55,46,49,51,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,160,239,224,226,9,0,16,1,98,56,55,45,48,50,46,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,160,67,173,137,15,0,32,0,98,56,55,45,48,49,46,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,225,42,232,129,15,0,32,0,98,56,55,45,48,52,46,51,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,182,52,132,149,15,0,32,0,98,56,55,45,48,51,46,51,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,224,90,21,206,15,0,32,0,21,0,0,0,255,255,255,0,0,0,0,0,22,0,0,0,255,255,127,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,21,0,0,0,1,2,2,0,96,135,7,0,21,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,21,0,0,0,1,4,4,0,96,135,7,0,21,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,21,0,0,0,1,8,0,0,96,135,7,0,21,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,21,0,0,0,1,48,0,0,80,252,6,0,21,0,0,0,1,48,16,0,16,242,7,0,21,0,0,0,1,48,32,0,104,236,7,0,21,0,0,0,1,48,48,0,128,230,7,0,0,0,0,0,254,0,4,0,160,123,6,0,21,0,0,0,1,192,0,0,80,252,6,0,21,0,0,0,1,192,64,0,16,242,7,0,21,0,0,0,1,192,128,0,104,236,7,0,21,0,0,0,1,192,192,0,128,230,7,0,0,0,0,0,254,0,4,0,72,202,5,0,22,0,0,0,1,3,2,0,80,246,3,0,22,0,0,0,1,3,3,0,80,124,6,0,22,0,0,0,1,3,1,0,112,212,3,0,22,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,64,37,5,0,22,0,0,0,1,12,12,0,248,46,3,0,22,0,0,0,1,12,8,0,224,23,3,0,22,0,0,0,1,12,4,0,152,99,2,0,22,0,0,0,1,12,0,0,240,191,4,0,0,0,0,0,254,0,4,0,128,129,4,0,22,0,0,0,1,48,0,0,208,75,4,0,22,0,0,0,1,48,48,0,8,49,4,0,22,0,0,0,1,48,16,0,152,21,4,0,22,0,0,0,1,48,32,0,72,246,3,0,0,0,0,0,254,0,2,0,104,159,3,0,22,0,0,0,1,128,128,0,96,135,7,0,22,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,184,40,2,0,1,0,0,0,47,39,216,0,248,191,2,0,56,250,6,0,1,0,0,0,39,39,216,0,184,160,2,0,184,164,8,0,1,0,0,0,46,39,216,0,64,246,1,0,88,149,7,0,1,0,0,0,38,39,216,0,136,224,1,0,240,167,7,0,1,0,0,0,28,39,216,0,192,135,2,0,176,163,7,0,1,0,0,0,30,39,216,0,240,108,2,0,208,158,7,0,1,0,0,0,45,39,216,0,96,82,2,0,184,154,7,0,1,0,0,0,44,39,216,0,32,56,2,0,176,108,2,0,1,0,0,0,43,39,216,0,152,30,2,0,8,96,7,0,1,0,0,0,40,39,216,0,72,198,1,0,48,89,7,0,1,0,0,0,24,39,216,0,24,182,1,0,16,83,7,0,1,0,0,0,37,39,216,0,40,167,1,0,96,79,7,0,1,0,0,0,36,39,216,0,200,149,1,0,48,76,7,0,1,0,0,0,35,39,216,0,56,126,1,0,88,212,3,0,1,0,0,0,48,38,216,0,40,185,3,0,16,17,8,0,1,0,0,0,42,39,216,0,224,12,8,0,248,5,8,0,9,0,0,0,112,39,216,0,32,58,1,0,144,250,7,0,9,0,0,0,113,39,216,0,32,58,1,0,248,241,7,0,9,0,0,0,114,39,216,0,32,58,1,0,168,86,7,0,1,0,0,0,120,242,146,0,248,191,2,0,24,38,7,0,1,0,0,0,167,250,146,0,184,160,2,0,56,210,6,0,1,0,0,0,160,250,146,0,192,135,2,0,24,163,6,0,1,0,0,0,161,250,146,0,240,108,2,0,152,122,6,0,1,0,0,0,162,250,146,0,96,82,2,0,192,72,6,0,1,0,0,0,163,250,146,0,32,56,2,0,200,110,3,0,1,0,0,0,164,250,146,0,152,30,2,0,120,89,3,0,1,0,0,0,165,250,146,0,232,10,2,0,40,246,1,0,1,0,0,0,121,242,146,0,64,246,1,0,144,236,1,0,1,0,0,0,175,250,146,0,136,224,1,0,176,223,1,0,1,0,0,0,168,250,146,0,72,198,1,0,192,209,1,0,1,0,0,0,169,250,146,0,24,182,1,0,24,198,1,0,1,0,0,0,170,250,146,0,40,167,1,0,120,189,1,0,1,0,0,0,171,250,146,0,200,149,1,0,224,22,1,0,1,0,0,0,172,250,146,0,56,126,1,0,160,14,1,0,1,0,0,0,173,250,146,0,32,101,1,0,88,212,3,0,1,0,0,0,120,215,146,0,40,185,3,0,16,17,8,0,1,0,0,0,122,242,146,0,224,12,8,0,72,65,1,0,9,0,0,0,128,3,147,0,32,58,1,0,48,50,1,0,9,0,0,0,129,3,147,0,32,58,1,0,184,40,2,0,1,0,0,0,96,232,148,0,248,191,2,0,56,250,6,0,1,0,0,0,223,233,148,0,184,160,2,0,184,164,8,0,1,0,0,0,97,232,148,0,64,246,1,0,88,149,7,0,1,0,0,0,31,233,148,0,136,224,1,0,56,210,6,0,1,0,0,0,216,233,148,0,192,135,2,0,24,163,6,0,1,0,0,0,217,233,148,0,240,108,2,0,152,122,6,0,1,0,0,0,218,233,148,0,96,82,2,0,192,72,6,0,1,0,0,0,219,233,148,0,32,56,2,0,48,123,2,0,1,0,0,0,220,233,148,0,152,30,2,0,96,69,2,0,1,0,0,0,221,233,148,0,232,10,2,0,176,223,1,0,1,0,0,0,24,233,148,0,72,198,1,0,192,209,1,0,1,0,0,0,25,233,148,0,24,182,1,0,24,198,1,0,1,0,0,0,26,233,148,0,40,167,1,0,120,189,1,0,1,0,0,0,27,233,148,0,200,149,1,0,248,187,8,0,1,0,0,0,28,233,148,0,56,126,1,0,184,179,8,0,1,0,0,0,29,233,148,0,32,101,1,0,88,212,3,0,1,0,0,0,192,218,146,0,40,185,3,0,16,17,8,0,1,0,0,0,98,232,148,0,224,12,8,0,248,5,8,0,9,0,0,0,112,94,147,0,32,58,1,0,144,250,7,0,9,0,0,0,113,94,147,0,32,58,1,0,120,244,7,0,1,0,0,0,250,0,147,0,120,244,7,0,240,237,7,0,1,0,0,0,251,0,147,0,240,237,7,0,152,231,7,0,1,0,0,0,252,0,147,0,152,231,7,0,168,86,7,0,1,0,0,0,254,0,147,0,248,191,2,0,120,248,6,0,1,0,0,0,248,0,147,0,184,160,2,0,56,210,6,0,1,0,0,0,88,248,146,0,192,135,2,0,24,163,6,0,1,0,0,0,89,248,146,0,240,108,2,0,192,72,6,0,1,0,0,0,90,248,146,0,32,56,2,0,152,122,6,0,1,0,0,0,91,248,146,0,96,82,2,0,200,110,3,0,1,0,0,0,80,240,146,0,152,30,2,0,120,89,3,0,1,0,0,0,81,240,146,0,232,10,2,0,40,246,1,0,1,0,0,0,253,0,147,0,64,246,1,0,48,245,6,0,1,0,0,0,249,0,147,0,136,224,1,0,56,210,6,0,1,0,0,0,92,248,146,0,192,135,2,0,192,209,1,0,1,0,0,0,93,248,146,0,24,182,1,0,120,189,1,0,1,0,0,0,94,248,146,0,200,149,1,0,24,198,1,0,1,0,0,0,95,248,146,0,40,167,1,0,224,22,1,0,1,0,0,0,80,237,146,0,56,126,1,0,160,14,1,0,1,0,0,0,81,237,146,0,32,101,1,0,88,212,3,0,1,0,0,0,64,220,146,0,40,185,3,0,184,40,2,0,1,0,0,0,214,155,215,0,248,191,2,0,56,250,6,0,1,0,0,0,211,155,215,0,184,160,2,0,184,164,8,0,1,0,0,0,215,155,215,0,64,246,1,0,240,190,7,0,4,0,0,0,112,156,215,0,208,13,4,0,208,240,5,0,4,0,0,0,104,156,215,0,152,30,2,0,32,201,5,0,4,0,0,0,96,156,215,0,232,10,2,0,32,160,5,0,1,0,0,0,224,155,215,0,152,138,8,0,64,154,6,0,1,0,0,0,213,155,215,0,48,119,7,0,16,17,8,0,1,0,0,0,210,155,215,0,224,12,8,0,32,77,1,0,1,0,0,0,209,155,215,0,216,70,1,0,88,212,3,0,1,0,0,0,200,154,215,0,40,185,3,0,248,5,8,0,9,0,0,0,0,156,215,0,32,58,1,0,144,250,7,0,9,0,0,0,1,156,215,0,32,58,1,0,98,49,52,45,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,253,7,3,221,2,0,16,1,98,49,52,45,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,212,8,223,172,2,0,16,1,98,49,52,45,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,216,233,87,101,1,0,16,1,98,49,52,45,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,114,200,157,101,6,0,16,1,98,49,52,45,53,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,27,207,101,209,6,0,16,1,98,49,52,45,50,53,46,54,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,239,40,171,158,9,0,16,1,98,49,52,45,48,55,46,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,255,95,2,198,12,0,32,0,98,49,52,45,48,54,46,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,110,83,226,180,12,0,32,0,98,49,52,45,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,55,111,165,132,17,0,32,0,98,49,52,45,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,107,24,137,104,17,0,32,0,98,49,52,45,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,113,158,237,209,17,0,32,0,98,49,52,45,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,25,5,63,182,17,0,32,0,98,49,52,45,51,48,46,56,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,127,12,203,220,23,0,32,0,98,49,52,45,50,56,46,49,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,174,208,17,223,26,0,64,0,98,49,52,45,50,57,46,49,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,231,131,217,122,26,0,64,0,98,49,52,45,51,49,46,57,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,61,1,107,92,0,0,0,8,101,112,114,45,49,48,53,52,48,97,46,52,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,11,139,132,118,1,0,16,1,101,112,114,45,49,48,53,51,55,97,46,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,74,67,220,77,1,0,16,1,101,112,114,45,49,48,53,52,49,46,52,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,94,148,109,204,1,0,16,1,101,112,114,45,49,48,53,51,56,46,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,115,148,55,104,1,0,16,1,101,112,114,45,49,48,53,52,50,46,52,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,250,125,33,16,1,0,16,1,101,112,114,45,49,48,53,51,57,46,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,46,59,148,16,1,0,16,1,101,112,114,45,49,48,53,52,51,46,57,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,55,204,220,7,2,0,32,0,101,112,114,45,49,48,53,52,52,46,57,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,58,154,251,132,2,0,32,0,101,112,114,45,49,48,53,52,53,46,57,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,192,75,105,200,2,0,32,0,101,112,114,45,49,48,53,52,56,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,53,7,21,170,3,0,32,0,101,112,114,45,49,48,53,53,50,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,247,185,203,111,3,0,32,0,101,112,114,45,49,48,53,52,57,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,103,240,89,47,3,0,32,0,101,112,114,45,49,48,53,53,51,46,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,159,10,34,138,3,0,32,0,101,112,114,45,49,48,53,53,48,46,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,255,105,80,240,3,0,32,0,101,112,114,45,49,48,53,53,52,46,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,9,248,100,220,3,0,32,0,101,112,114,45,49,48,53,53,49,46,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,31,129,93,67,3,0,32,0,101,112,114,45,49,48,53,53,53,46,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,113,196,67,33,3,0,32,0,101,112,114,45,49,48,53,52,54,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,204,229,190,30,4,0,16,1,55,55,53,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,252,52,149,106,6,0,16,1,101,112,114,45,49,48,53,52,55,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,75,252,79,210,7,0,64,0,51,49,55,45,48,48,50,52,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,24,236,66,238,5,0,16,1,0,0,0,0,4,0,0,0,0,0,32,0,4,0,32,0,8,0,0,0,0,0,0,0,8,0,32,0,0,0,32,0,0,0,16,0,4,0,16,0,0,0,0,0,4,0,0,0,99,50,56,45,49,51,45,49,46,53,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,19,112,176,172,2,0,16,1,99,50,56,45,49,53,45,49,46,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,225,132,74,135,2,0,16,1,99,50,56,45,48,56,46,53,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,241,56,224,56,2,0,16,1,99,50,56,45,48,55,46,51,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,187,154,65,36,2,0,16,1,99,50,56,45,49,52,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,22,54,239,69,9,0,16,1,99,50,56,45,48,50,46,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,157,160,48,98,11,0,32,0,99,50,56,45,48,49,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,37,43,85,68,13,0,32,0,99,50,56,45,48,51,46,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,175,199,189,81,16,0,32,0,99,50,56,45,48,52,46,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,53,213,126,186,16,0,32,0,99,50,56,45,48,54,46,52,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,219,131,105,219,24,0,64,0,99,50,56,45,48,53,46,52,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,250,56,178,211,25,0,64,0,21,0,0,0,255,255,255,0,0,0,0,0,22,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,21,0,0,0,1,2,2,0,96,135,7,0,21,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,21,0,0,0,1,4,4,0,96,135,7,0,21,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,21,0,0,0,1,8,0,0,96,135,7,0,21,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,32,4,2,0,21,0,0,0,1,48,0,0,80,252,6,0,21,0,0,0,1,48,16,0,16,242,7,0,21,0,0,0,1,48,32,0,104,236,7,0,21,0,0,0,1,48,48,0,128,230,7,0,0,0,0,0,254,0,4,0,168,248,6,0,21,0,0,0,1,192,0,0,16,242,7,0,21,0,0,0,1,192,64,0,104,236,7,0,21,0,0,0,1,192,128,0,80,245,6,0,21,0,0,0,1,192,192,0,240,240,6,0,0,0,0,0,254,0,4,0,72,202,5,0,22,0,0,0,1,3,2,0,80,246,3,0,22,0,0,0,1,3,3,0,80,124,6,0,22,0,0,0,1,3,1,0,112,212,3,0,22,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,2,0,216,238,6,0,22,0,0,0,1,4,0,0,96,135,7,0,22,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,22,0,0,0,1,48,32,0,208,75,4,0,22,0,0,0,1,48,48,0,8,49,4,0,22,0,0,0,1,48,16,0,152,21,4,0,22,0,0,0,1,48,0,0,72,246,3,0,0,0,0,0,254,0,2,0,104,159,3,0,22,0,0,0,1,64,0,0,96,135,7,0,22,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,6,0,22,0,0,0,1,128,0,0,8,208,6,0,22,0,0,0,1,128,128,0,88,204,6,0,99,50,56,45,49,51,45,49,46,53,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,19,112,176,172,2,0,16,1,99,50,56,45,49,50,45,49,46,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,119,180,77,240,2,0,16,1,99,50,56,45,48,56,46,53,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,241,56,224,56,2,0,16,1,99,50,56,45,48,55,46,51,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,187,154,65,36,2,0,16,1,99,50,56,45,49,52,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,22,54,239,69,9,0,16,1,99,50,56,45,48,50,46,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,157,160,48,98,11,0,32,0,99,50,56,45,48,49,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,37,43,85,68,13,0,32,0,99,50,56,45,48,51,46,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,175,199,189,81,16,0,32,0,99,50,56,45,48,52,46,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,53,213,126,186,16,0,32,0,99,50,56,45,48,54,46,52,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,219,131,105,219,24,0,64,0,99,50,56,45,48,53,46,52,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,250,56,178,211,25,0,64,0,168,86,7,0,1,0,0,0,136,233,148,0,248,191,2,0,24,38,7,0,1,0,0,0,79,234,148,0,184,160,2,0,56,210,6,0,1,0,0,0,74,234,148,0,192,135,2,0,24,163,6,0,1,0,0,0,75,234,148,0,240,108,2,0,152,122,6,0,1,0,0,0,72,234,148,0,96,82,2,0,192,72,6,0,1,0,0,0,73,234,148,0,32,56,2,0,200,110,3,0,1,0,0,0,76,234,148,0,152,30,2,0,120,89,3,0,1,0,0,0,77,234,148,0,232,10,2,0,40,246,1,0,1,0,0,0,137,233,148,0,64,246,1,0,144,236,1,0,1,0,0,0,207,232,148,0,136,224,1,0,176,223,1,0,1,0,0,0,202,232,148,0,72,198,1,0,192,209,1,0,1,0,0,0,203,232,148,0,24,182,1,0,24,198,1,0,1,0,0,0,200,232,148,0,40,167,1,0,120,189,1,0,1,0,0,0,201,232,148,0,200,149,1,0,224,22,1,0,1,0,0,0,204,232,148,0,56,126,1,0,160,14,1,0,1,0,0,0,205,232,148,0,32,101,1,0,88,212,3,0,1,0,0,0,248,221,146,0,40,185,3,0,16,17,8,0,1,0,0,0,138,233,148,0,224,12,8,0,32,77,1,0,1,0,0,0,139,233,148,0,216,70,1,0,101,112,114,45,49,49,51,48,52,46,105,99,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,239,48,6,169,1,0,16,1,101,112,114,45,49,49,51,48,53,46,105,99,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,97,239,163,155,1,0,16,1,101,112,114,45,49,49,51,48,54,46,105,99,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,180,242,149,75,1,0,16,1,101,112,114,45,49,49,51,48,55,46,105,99,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,228,51,104,45,1,0,16,1,101,112,114,45,49,49,51,48,56,46,105,99,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,56,194,86,121,9,0,16,1,101,112,114,45,49,49,51,48,57,46,105,99,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,32,246,135,200,9,0,16,1,101,112,114,45,49,49,51,49,48,46,105,99,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,44,160,159,93,9,0,16,1,101,112,114,45,49,49,51,49,49,46,105,99,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,27,226,61,72,9,0,16,1,101,112,114,45,49,49,51,49,52,46,105,99,49,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,169,84,249,212,2,0,32,0,101,112,114,45,49,49,51,49,53,46,105,99,49,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,136,48,129,53,2,0,32,0,101,112,114,45,49,49,51,49,54,46,105,99,49,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,255,13,41,132,2,0,32,0,101,112,114,45,49,49,51,50,51,46,105,99,57,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,53,7,228,39,3,0,32,0,101,112,114,45,49,49,51,50,50,46,105,99,57,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,116,77,54,16,3,0,32,0,101,112,114,45,49,49,51,50,49,46,105,99,57,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,88,143,115,142,3,0,32,0,101,112,114,45,49,49,51,50,48,46,105,99,49,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,184,118,92,169,3,0,32,0,101,112,114,45,49,49,51,50,55,46,105,99,57,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,241,144,174,222,3,0,32,0,101,112,114,45,49,49,51,50,54,46,105,99,57,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,3,132,25,41,3,0,32,0,101,112,114,45,49,49,51,50,53,46,105,99,57,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,233,138,233,185,3,0,32,0,101,112,114,45,49,49,51,50,52,46,105,99,49,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,82,181,66,151,3,0,32,0,101,112,114,45,49,49,51,51,49,46,105,99,57,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,46,4,44,58,3,0,32,0,101,112,114,45,49,49,51,51,48,46,105,99,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,197,112,124,170,3,0,32,0,101,112,114,45,49,49,51,50,57,46,105,99,49,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,87,2,178,49,3,0,32,0,101,112,114,45,49,49,51,50,56,46,105,99,49,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,156,232,57,218,3,0,32,0,101,112,114,45,49,49,51,51,53,46,105,99,57,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,134,62,155,241,3,0,32,0,101,112,114,45,49,49,51,51,52,46,105,99,57,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,199,145,143,52,3,0,32,0,101,112,114,45,49,49,51,51,51,46,105,99,49,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,51,162,5,3,0,32,0,101,112,114,45,49,49,51,51,50,46,105,99,49,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,198,158,8,220,3,0,32,0,101,112,114,45,49,49,51,49,51,46,105,99,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,195,196,86,106,10,0,32,0,101,112,114,45,49,49,51,49,50,46,105,99,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,210,78,151,59,4,0,16,1,101,112,114,45,49,49,51,49,55,46,105,99,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,31,172,231,212,11,0,64,0,101,112,114,45,49,49,51,49,56,46,105,99,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,44,240,211,112,11,0,64,0,101,112,114,45,49,49,51,49,57,46,105,99,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,46,36,217,80,11,0,64,0,11,0,0,0,255,255,255,0,0,0,0,0,12,0,0,0,255,255,253,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,11,0,0,0,1,15,7,0,80,252,6,0,11,0,0,0,1,15,8,0,16,242,7,0,11,0,0,0,1,15,9,0,104,236,7,0,11,0,0,0,1,15,5,0,176,51,4,0,11,0,0,0,1,15,4,0,56,24,4,0,11,0,0,0,1,15,15,0,128,230,7,0,11,0,0,0,1,15,1,0,72,216,3,0,11,0,0,0,1,15,2,0,24,188,3,0,11,0,0,0,1,15,3,0,176,162,3,0,11,0,0,0,1,15,6,0,120,211,6,0,11,0,0,0,1,15,14,0,184,164,6,0,11,0,0,0,1,15,13,0,80,74,6,0,11,0,0,0,1,15,12,0,192,32,6,0,11,0,0,0,1,15,11,0,192,234,2,0,11,0,0,0,1,15,10,0,32,242,5,0,11,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,11,0,0,0,1,240,112,0,80,252,6,0,11,0,0,0,1,240,128,0,16,242,7,0,11,0,0,0,1,240,144,0,104,236,7,0,11,0,0,0,1,240,80,0,176,51,4,0,11,0,0,0,1,240,64,0,56,24,4,0,11,0,0,0,1,240,240,0,128,230,7,0,11,0,0,0,1,240,16,0,72,216,3,0,11,0,0,0,1,240,32,0,24,188,3,0,11,0,0,0,1,240,48,0,176,162,3,0,11,0,0,0,1,240,96,0,120,211,6,0,11,0,0,0,1,240,224,0,184,164,6,0,11,0,0,0,1,240,208,0,80,74,6,0,11,0,0,0,1,240,192,0,192,32,6,0,11,0,0,0,1,240,176,0,192,234,2,0,11,0,0,0,1,240,160,0,32,242,5,0,11,0,0,0,1,240,0,0,208,236,2,0,0,0,0,0,254,0,2,0,64,251,5,0,12,0,0,0,1,1,1,0,240,149,7,0,12,0,0,0,1,1,0,0,208,200,1,0,0,0,0,0,254,0,2,0,168,234,7,0,12,0,0,0,1,2,2,0,96,135,7,0,12,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,112,59,6,0,12,0,0,0,1,4,4,0,40,161,1,0,12,0,0,0,1,4,0,0,184,152,1,0,0,0,0,0,254,0,4,0,128,129,4,0,12,0,0,0,1,24,8,0,208,75,4,0,12,0,0,0,1,24,24,0,8,49,4,0,12,0,0,0,1,24,16,0,152,21,4,0,12,0,0,0,1,24,0,0,72,246,3,0,0,0,0,0,254,0,2,0,104,159,3,0,12,0,0,0,1,32,0,0,56,111,3,0,12,0,0,0,1,32,32,0,104,134,3,0,0,0,0,0,254,0,4,0,72,202,5,0,12,0,0,0,1,192,64,0,80,246,3,0,12,0,0,0,1,192,192,0,248,38,7,0,12,0,0,0,1,192,128,0,112,212,3,0,12,0,0,0,1,192,0,0,248,160,5,0,184,40,2,0,1,0,0,0,40,39,216,0,248,191,2,0,56,250,6,0,1,0,0,0,32,39,216,0,184,160,2,0,184,164,8,0,1,0,0,0,41,39,216,0,64,246,1,0,88,149,7,0,1,0,0,0,33,39,216,0,136,224,1,0,240,167,7,0,1,0,0,0,44,39,216,0,192,135,2,0,176,163,7,0,1,0,0,0,47,39,216,0,240,108,2,0,208,158,7,0,1,0,0,0,42,39,216,0,96,82,2,0,184,154,7,0,1,0,0,0,43,39,216,0,32,56,2,0,176,108,2,0,1,0,0,0,45,39,216,0,152,30,2,0,8,96,7,0,1,0,0,0,36,39,216,0,72,198,1,0,48,89,7,0,1,0,0,0,46,39,216,0,24,182,1,0,16,83,7,0,1,0,0,0,34,39,216,0,40,167,1,0,96,79,7,0,1,0,0,0,35,39,216,0,200,149,1,0,48,76,7,0,1,0,0,0,37,39,216,0,56,126,1,0,88,212,3,0,1,0,0,0,48,38,216,0,40,185,3,0,248,5,8,0,9,0,0,0,112,39,216,0,32,58,1,0,144,250,7,0,9,0,0,0,113,39,216,0,32,58,1,0,248,241,7,0,9,0,0,0,114,39,216,0,32,58,1,0,27,0,0,0,255,255,255,0,0,0,0,0,28,0,0,0,255,255,255,0,0,0,0,0,29,0,0,0,255,255,255,0,0,0,0,0,30,0,0,0,255,255,8,0,0,0,0,0,0,0,0,0,254,0,2,0,72,209,1,0,27,0,0,0,1,1,1,0,176,111,1,0,27,0,0,0,1,1,0,0,232,78,1,0,0,0,0,0,254,0,8,0,32,4,2,0,27,0,0,0,2,14,10,0,16,242,7,0,27,0,0,0,0,1,0,0,0,0,0,0,27,0,0,0,2,14,12,0,104,236,7,0,27,0,0,0,0,1,0,0,0,0,0,0,27,0,0,0,2,14,14,0,80,245,6,0,27,0,0,0,0,1,0,0,0,0,0,0,27,0,0,0,2,14,8,0,8,201,6,0,27,0,0,0,0,1,0,0,0,0,0,0,27,0,0,0,2,14,6,0,200,197,6,0,27,0,0,0,0,1,0,0,0,0,0,0,27,0,0,0,2,14,4,0,152,194,6,0,27,0,0,0,0,1,0,0,0,0,0,0,27,0,0,0,2,14,2,0,128,95,7,0,27,0,0,0,0,1,0,0,0,0,0,0,27,0,0,0,2,14,0,0,248,189,6,0,27,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,254,0,8,0,184,40,2,0,27,0,0,0,2,14,10,0,16,242,7,0,27,0,0,0,0,1,1,0,0,0,0,0,27,0,0,0,2,14,12,0,104,236,7,0,27,0,0,0,0,1,1,0,0,0,0,0,27,0,0,0,2,14,14,0,80,245,6,0,27,0,0,0,0,1,1,0,0,0,0,0,27,0,0,0,2,14,8,0,8,201,6,0,27,0,0,0,0,1,1,0,0,0,0,0,27,0,0,0,2,14,6,0,200,197,6,0,27,0,0,0,0,1,1,0,0,0,0,0,27,0,0,0,2,14,4,0,152,194,6,0,27,0,0,0,0,1,1,0,0,0,0,0,27,0,0,0,2,14,2,0,128,95,7,0,27,0,0,0,0,1,1,0,0,0,0,0,27,0,0,0,2,14,0,0,248,189,6,0,27,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,254,0,8,0,184,164,8,0,27,0,0,0,2,112,80,0,16,242,7,0,27,0,0,0,0,1,1,0,0,0,0,0,27,0,0,0,2,112,96,0,104,236,7,0,27,0,0,0,0,1,1,0,0,0,0,0,27,0,0,0,2,112,112,0,80,245,6,0,27,0,0,0,0,1,1,0,0,0,0,0,27,0,0,0,2,112,64,0,8,201,6,0,27,0,0,0,0,1,1,0,0,0,0,0,27,0,0,0,2,112,48,0,200,197,6,0,27,0,0,0,0,1,1,0,0,0,0,0,27,0,0,0,2,112,32,0,152,194,6,0,27,0,0,0,0,1,1,0,0,0,0,0,27,0,0,0,2,112,16,0,128,95,7,0,27,0,0,0,0,1,1,0,0,0,0,0,27,0,0,0,2,112,0,0,248,189,6,0,27,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,254,0,2,0,24,172,6,0,27,0,0,0,1,128,128,0,96,135,7,0,27,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,28,0,0,0,1,2,0,0,96,135,7,0,28,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,2,0,16,227,4,0,28,0,0,0,1,4,4,0,96,135,7,0,28,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,28,0,0,0,1,24,16,0,80,246,3,0,28,0,0,0,1,24,24,0,248,38,7,0,28,0,0,0,1,24,8,0,112,212,3,0,28,0,0,0,1,24,0,0,248,160,5,0,0,0,0,0,254,0,2,0,232,75,4,0,28,0,0,0,1,32,32,0,96,135,7,0,28,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,112,11,5,0,29,0,0,0,1,1,1,0,96,135,7,0,29,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,0,233,4,0,29,0,0,0,1,2,0,0,56,111,3,0,29,0,0,0,1,2,2,0,104,134,3,0,0,0,0,0,254,0,5,0,224,133,4,0,30,0,0,0,1,15,0,0,184,255,2,0,30,0,0,0,1,15,1,0,176,20,3,0,30,0,0,0,1,15,2,0,64,54,4,0,30,0,0,0,1,15,4,0,56,50,1,0,30,0,0,0,1,15,8,0,224,32,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,16,0,0,0,24,0,0,0,40,0,0,0,32,0,0,0,48,0,0,0,56,0,0,0,64,0,0,0,72,0,0,0,80,0,0,0,88,0,0,0,96,0,0,0,104,0,0,0,112,0,0,0,120,0,0,0,98,54,49,95,48,57,46,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,88,29,15,100,2,0,16,1,98,54,49,95,48,55,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,83,153,219,253,2,0,16,1,98,54,49,95,48,56,46,97,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,142,2,252,121,2,0,16,1,98,54,49,95,49,50,46,97,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,254,59,77,6,2,0,16,1,98,54,49,95,49,48,46,100,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,232,121,254,110,9,0,16,1,98,54,49,45,49,52,46,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,62,140,54,137,15,0,32,0,98,54,49,45,49,53,46,104,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,249,196,12,145,15,0,32,0,98,54,49,45,49,54,46,106,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,47,237,34,54,15,0,32,0,98,54,49,45,49,55,46,107,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,224,39,79,195,15,0,32,0,98,54,49,45,48,49,46,101,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,134,151,249,60,25,0,64,0,98,54,49,95,49,49,46,109,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,16,17,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,2,2,0,96,135,7,0,19,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,4,4,0,96,135,7,0,19,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,8,0,0,96,135,7,0,19,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,32,4,2,0,19,0,0,0,1,48,0,0,80,252,6,0,19,0,0,0,1,48,16,0,16,242,7,0,19,0,0,0,1,48,32,0,104,236,7,0,19,0,0,0,1,48,48,0,128,230,7,0,0,0,0,0,254,0,4,0,168,248,6,0,19,0,0,0,1,192,0,0,104,11,2,0,19,0,0,0,1,192,64,0,192,4,2,0,19,0,0,0,1,192,128,0,128,230,7,0,19,0,0,0,1,192,192,0,80,75,3,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,3,2,0,80,246,3,0,20,0,0,0,1,3,3,0,80,124,6,0,20,0,0,0,1,3,1,0,112,212,3,0,20,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,48,32,0,208,75,4,0,20,0,0,0,1,48,48,0,8,49,4,0,20,0,0,0,1,48,16,0,152,21,4,0,20,0,0,0,1,48,0,0,72,246,3,0,0,0,0,0,98,54,49,95,48,57,46,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,88,29,15,100,2,0,16,1,98,54,49,95,48,55,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,83,153,219,253,2,0,16,1,98,54,49,95,48,56,46,97,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,142,2,252,121,2,0,16,1,98,54,49,95,48,54,46,97,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,104,11,74,113,2,0,16,1,98,54,49,95,49,48,46,100,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,232,121,254,110,9,0,16,1,98,54,49,45,49,52,46,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,62,140,54,137,15,0,32,0,98,54,49,45,49,53,46,104,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,249,196,12,145,15,0,32,0,98,54,49,45,49,54,46,106,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,47,237,34,54,15,0,32,0,98,54,49,45,49,55,46,107,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,224,39,79,195,15,0,32,0,98,54,49,45,48,49,46,101,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,134,151,249,60,25,0,64,0,98,54,49,95,49,49,46,109,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,16,17,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,2,2,0,96,135,7,0,19,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,4,4,0,96,135,7,0,19,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,8,0,0,96,135,7,0,19,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,19,0,0,0,1,48,16,0,104,236,7,0,19,0,0,0,1,48,48,0,128,230,7,0,19,0,0,0,1,48,0,0,120,211,6,0,19,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,19,0,0,0,1,192,64,0,104,236,7,0,19,0,0,0,1,192,192,0,128,230,7,0,19,0,0,0,1,192,0,0,120,211,6,0,19,0,0,0,1,192,128,0,184,164,6,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,3,2,0,80,246,3,0,20,0,0,0,1,3,3,0,80,124,6,0,20,0,0,0,1,3,1,0,112,212,3,0,20,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,48,32,0,208,75,4,0,20,0,0,0,1,48,48,0,8,49,4,0,20,0,0,0,1,48,16,0,152,21,4,0,20,0,0,0,1,48,0,0,72,246,3,0,0,0,0,0,100,52,54,45,51,53,43,46,105,99,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,167,201,117,21,4,0,16,1,100,52,54,45,51,52,43,46,105,99,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,43,77,42,199,4,0,16,1,100,52,54,45,51,51,43,46,105,99,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,208,188,148,48,4,0,16,1,100,52,54,45,51,49,43,46,105,99,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,163,131,185,56,4,0,16,1,100,52,54,45,50,52,46,105,99,49,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,161,186,6,160,6,0,16,1,100,52,54,45,50,51,46,105,99,49,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,208,219,105,154,6,0,16,1,100,52,54,45,51,55,46,105,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,145,27,181,96,8,0,16,1,100,52,54,45,51,54,46,105,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,118,162,122,143,8,0,16,1,100,52,54,45,48,53,46,105,99,56,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,76,14,13,21,12,0,32,0,100,52,54,45,48,54,46,105,99,56,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,190,8,19,50,12,0,32,0,100,52,54,45,48,52,46,105,99,54,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,169,105,39,131,17,0,32,0,100,52,54,45,48,51,46,105,99,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,253,203,233,224,17,0,32,0,100,52,54,45,48,50,46,105,99,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,46,168,60,168,17,0,32,0,100,52,54,45,48,49,46,105,99,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,45,233,42,92,17,0,32,0,100,52,54,45,48,55,46,105,99,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,147,176,184,195,23,0,32,0,100,52,54,45,49,48,46,105,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,190,86,98,48,31,0,64,0,100,52,54,45,49,50,46,105,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,168,83,74,162,31,0,64,0,100,52,54,45,49,49,46,105,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,86,15,234,212,31,0,64,0,101,101,112,114,111,109,45,115,117,112,101,114,99,104,115,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,83,7,15,35,32,0,16,0,112,97,108,49,54,108,56,98,99,110,45,100,52,54,45,49,51,46,105,99,56,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,137,232,50,47,0,0,0,8,112,97,108,49,54,108,56,98,99,110,45,100,52,54,45,49,52,46,105,99,56,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,248,181,200,90,0,0,0,8,112,97,108,49,54,108,56,98,99,110,45,100,52,54,45,49,53,46,105,99,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,54,159,234,56,0,0,0,8,112,97,108,99,101,50,48,118,56,104,45,100,52,54,45,49,54,46,105,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,87,1,0,0,159,255,225,100,0,0,0,8,112,97,108,99,101,50,48,118,56,104,45,100,52,54,45,49,55,46,105,99,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,87,1,0,0,225,148,157,92,0,0,0,8,112,97,108,99,101,49,54,118,56,104,45,100,52,54,45,49,56,46,105,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,148,184,129,117,0,0,0,8,112,97,108,99,101,49,54,118,56,104,45,100,52,54,45,49,57,46,105,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,208,99,216,165,0,0,0,8,112,97,108,99,101,50,48,118,56,104,45,100,52,54,45,50,48,46,105,99,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,87,1,0,0,17,188,140,131,0,0,0,8,112,97,108,99,101,50,48,118,56,104,45,100,52,54,45,50,49,46,105,99,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,87,1,0,0,194,170,197,147,0,0,0,8,112,97,108,99,101,50,48,118,56,104,45,100,52,54,45,50,50,46,105,99,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,87,1,0,0,6,11,161,198,0,0,0,8,100,52,54,45,50,56,43,46,105,99,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,79,120,51,92,4,0,16,1,100,52,54,45,50,55,43,46,105,99,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,184,37,17,232,4,0,16,1,100,52,54,45,50,54,43,46,105,99,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,176,161,171,42,4,0,16,1,100,52,54,45,50,53,43,46,105,99,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,122,233,65,66,4,0,16,1,100,52,54,45,50,52,46,105,99,49,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,161,186,6,160,6,0,16,1,100,52,54,45,50,51,46,105,99,49,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,208,219,105,154,6,0,16,1,100,52,54,45,51,48,46,105,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,33,164,248,136,8,0,16,1,100,52,54,45,50,57,46,105,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,165,31,80,4,8,0,16,1,100,52,54,45,48,53,46,105,99,56,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,76,14,13,21,12,0,32,0,100,52,54,45,48,54,46,105,99,56,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,190,8,19,50,12,0,32,0,100,52,54,45,48,52,46,105,99,54,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,169,105,39,131,17,0,32,0,100,52,54,45,48,51,46,105,99,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,253,203,233,224,17,0,32,0,100,52,54,45,48,50,46,105,99,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,46,168,60,168,17,0,32,0,100,52,54,45,48,49,46,105,99,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,45,233,42,92,17,0,32,0,100,52,54,45,48,55,46,105,99,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,147,176,184,195,23,0,32,0,100,52,54,45,49,48,46,105,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,190,86,98,48,31,0,64,0,100,52,54,45,48,57,46,105,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,199,139,203,10,31,0,64,0,100,52,54,45,48,56,46,105,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,32,232,119,70,31,0,64,0,101,101,112,114,111,109,45,115,117,112,101,114,99,104,115,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,83,7,15,35,32,0,16,0,112,97,108,49,54,108,56,98,99,110,45,100,52,54,45,49,51,46,105,99,56,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,137,232,50,47,0,0,0,8,112,97,108,49,54,108,56,98,99,110,45,100,52,54,45,49,52,46,105,99,56,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,248,181,200,90,0,0,0,8,112,97,108,49,54,108,56,98,99,110,45,100,52,54,45,49,53,46,105,99,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,54,159,234,56,0,0,0,8,112,97,108,99,101,50,48,118,56,104,45,100,52,54,45,49,54,46,105,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,87,1,0,0,159,255,225,100,0,0,0,8,112,97,108,99,101,50,48,118,56,104,45,100,52,54,45,49,55,46,105,99,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,87,1,0,0,225,148,157,92,0,0,0,8,112,97,108,99,101,49,54,118,56,104,45,100,52,54,45,49,56,46,105,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,148,184,129,117,0,0,0,8,112,97,108,99,101,49,54,118,56,104,45,100,52,54,45,49,57,46,105,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,208,99,216,165,0,0,0,8,112,97,108,99,101,50,48,118,56,104,45,100,52,54,45,50,48,46,105,99,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,87,1,0,0,17,188,140,131,0,0,0,8,112,97,108,99,101,50,48,118,56,104,45,100,52,54,45,50,49,46,105,99,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,87,1,0,0,194,170,197,147,0,0,0,8,112,97,108,99,101,50,48,118,56,104,45,100,52,54,45,50,50,46,105,99,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,87,1,0,0,6,11,161,198,0,0,0,8,51,48,40,95,95,115,116,114,105,100,101,114,117,97,41,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,115,194,174,102,1,0,16,1,51,53,40,95,95,115,116,114,105,100,101,114,117,97,41,46,49,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,101,232,224,80,1,0,16,1,51,49,40,95,95,115,116,114,105,100,101,114,117,97,41,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,209,59,233,234,1,0,16,1,51,54,40,95,95,115,116,114,105,100,101,114,117,97,41,46,49,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,29,163,4,185,1,0,16,1,115,116,45,49,52,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,8,252,60,155,2,0,16,1,115,116,45,50,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,234,154,238,78,4,0,32,0,115,116,45,49,49,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,228,33,127,45,4,0,32,0,115,116,45,53,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,70,170,5,119,4,0,32,0,115,116,45,57,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,34,183,24,91,4,0,32,0,115,116,45,49,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,11,0,95,0,4,0,32,0,115,116,45,49,48,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,25,21,68,185,4,0,32,0,115,116,45,52,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,139,78,208,183,4,0,32,0,115,116,45,56,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,180,19,71,107,4,0,32,0,48,57,40,95,95,115,116,114,105,100,101,114,117,97,41,46,49,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,25,53,214,8,3,0,16,0,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,128,188,134,67,5,0,64,0,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,215,54,69,68,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,115,116,50,52,98,50,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,0,0,0,0,0,0,24,108,119,105,111,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,12,185,82,173,0,0,0,8,20,0,0,0,255,255,0,0,0,0,0,0,21,0,0,0,255,255,0,0,0,0,0,0,22,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,8,0,200,87,7,0,20,0,0,0,1,7,7,0,80,252,6,0,20,0,0,0,1,7,6,0,16,242,7,0])
.concat([20,0,0,0,1,7,5,0,104,236,7,0,20,0,0,0,1,7,0,0,128,230,7,0,20,0,0,0,1,7,1,0,184,164,6,0,20,0,0,0,1,7,2,0,80,74,6,0,20,0,0,0,1,7,3,0,192,32,6,0,20,0,0,0,1,7,4,0,32,242,5,0,0,0,0,0,254,0,8,0,160,123,6,0,20,0,0,0,1,56,56,0,80,252,6,0,20,0,0,0,1,56,48,0,16,242,7,0,20,0,0,0,1,56,40,0,104,236,7,0,20,0,0,0,1,56,0,0,128,230,7,0,20,0,0,0,1,56,8,0,184,164,6,0,20,0,0,0,1,56,16,0,80,74,6,0,20,0,0,0,1,56,24,0,192,32,6,0,20,0,0,0,1,56,32,0,32,242,5,0,0,0,0,0,254,0,3,0,200,30,2,0,20,0,0,0,1,192,0,0,80,6,2,0,20,0,0,0,1,192,64,0,152,5,2,0,20,0,0,0,1,192,192,0,96,19,1,0,0,0,0,0,254,0,8,0,72,202,5,0,21,0,0,0,1,7,3,0,72,198,6,0,21,0,0,0,1,7,2,0,208,75,4,0,21,0,0,0,1,7,1,0,8,49,4,0,21,0,0,0,1,7,0,0,72,195,6,0,21,0,0,0,1,7,4,0,72,246,3,0,21,0,0,0,1,7,5,0,72,0,3,0,21,0,0,0,1,7,6,0,64,47,7,0,21,0,0,0,1,7,7,0,48,173,6,0,0,0,0,0,254,0,2,0,64,232,1,0,21,0,0,0,1,8,0,0,96,135,7,0,21,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,64,37,5,0,21,0,0,0,1,48,0,0,184,204,1,0,21,0,0,0,1,48,16,0,88,203,1,0,21,0,0,0,1,48,32,0,112,202,1,0,21,0,0,0,1,48,48,0,80,201,1,0,0,0,0,0,254,0,4,0,128,129,4,0,22,0,0,0,1,3,3,0,208,75,4,0,22,0,0,0,1,3,0,0,8,49,4,0,22,0,0,0,1,3,1,0,152,21,4,0,22,0,0,0,1,3,2,0,72,246,3,0,0,0,0,0,254,0,2,0,72,4,1,0,22,0,0,0,1,4,0,0,96,135,7,0,22,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,254,0,2,0,16,227,4,0,22,0,0,0,1,8,0,0,96,135,7,0,22,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,2,0,120,207,1,0,22,0,0,0,1,16,0,0,96,135,7,0,22,0,0,0,1,16,16,0,152,182,7,0,0,0,0,0,254,0,2,0,160,94,8,0,22,0,0,0,1,32,32,0,96,135,7,0,22,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,22,0,0,0,1,64,64,0,96,135,7,0,22,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,79,2,0,22,0,0,0,1,128,0,0,32,182,8,0,22,0,0,0,1,128,128,0,80,251,6,0,0,0,0,0,115,116,104,106,95,50,51,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,18,123,110,4,2,0,16,1,115,116,104,106,95,50,50,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,8,252,60,155,2,0,16,1,115,116,104,95,48,49,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,234,154,238,78,4,0,32,0,115,116,104,95,48,50,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,228,33,127,45,4,0,32,0,115,116,104,95,48,51,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,70,170,5,119,4,0,32,0,115,116,104,95,48,52,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,34,183,24,91,4,0,32,0,115,116,104,95,48,53,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,11,0,95,0,4,0,32,0,115,116,104,95,48,54,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,25,21,68,185,4,0,32,0,115,116,104,95,48,55,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,139,78,208,183,4,0,32,0,115,116,104,95,48,56,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,180,19,71,107,4,0,32,0,115,116,104,95,48,57,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,25,53,214,8,3,0,16,0,115,116,104,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,128,188,134,67,5,0,64,0,115,116,104,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,215,54,69,68,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,115,116,104,54,51,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,0,0,0,0,0,0,24,105,111,98,49,46,49,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,98,112,114,103,49,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,167,61,121,49,0,0,0,8,105,111,99,49,46,105,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,129,32,24,13,0,0,0,8,99,54,51,50,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,112,146,189,15,0,0,0,8,168,86,7,0,1,0,0,0,232,47,216,0,248,191,2,0,24,38,7,0,1,0,0,0,236,47,216,0,184,160,2,0,56,210,6,0,1,0,0,0,35,48,216,0,192,135,2,0,24,163,6,0,1,0,0,0,34,48,216,0,240,108,2,0,152,122,6,0,1,0,0,0,33,48,216,0,96,82,2,0,192,72,6,0,1,0,0,0,32,48,216,0,32,56,2,0,152,31,6,0,1,0,0,0,36,48,216,0,152,30,2,0,248,97,5,0,1,0,0,0,37,48,216,0,232,10,2,0,144,55,2,0,1,0,0,0,38,48,216,0,152,138,8,0,40,246,1,0,1,0,0,0,233,47,216,0,64,246,1,0,144,236,1,0,1,0,0,0,237,47,216,0,136,224,1,0,176,223,1,0,1,0,0,0,43,48,216,0,72,198,1,0,192,209,1,0,1,0,0,0,42,48,216,0,24,182,1,0,24,198,1,0,1,0,0,0,41,48,216,0,40,167,1,0,120,189,1,0,1,0,0,0,40,48,216,0,200,149,1,0,8,182,1,0,1,0,0,0,44,48,216,0,56,126,1,0,32,167,1,0,1,0,0,0,45,48,216,0,32,101,1,0,240,173,8,0,1,0,0,0,46,48,216,0,96,32,8,0,88,212,3,0,1,0,0,0,144,46,216,0,40,185,3,0,16,17,8,0,1,0,0,0,234,47,216,0,224,12,8,0,72,65,1,0,9,0,0,0,232,48,216,0,32,58,1,0,48,50,1,0,9,0,0,0,224,48,216,0,32,58,1,0,224,41,1,0,9,0,0,0,216,48,216,0,32,58,1,0,115,116,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,36,225,39,200,1,0,16,1,115,116,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,143,79,29,176,1,0,16,1,115,116,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,147,196,169,199,1,0,16,1,115,116,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,117,124,72,18,1,0,16,1,53,115,116,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,190,226,249,249,1,0,16,1,54,115,116,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,194,230,47,194,1,0,16,1,55,115,116,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,154,134,215,156,1,0,16,1,56,115,116,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,211,10,117,94,1,0,16,1,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,36,137,221,205,5,0,32,0,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,149,160,205,16,5,0,32,0,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,15,138,42,106,6,0,32,0,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,190,223,99,53,6,0,32,0,115,107,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,7,150,231,188,7,0,32,0,97,49,95,105,99,50,57,46,49,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,31,42,162,89,0,0,16,1,97,49,95,105,99,51,48,46,49,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,220,151,69,127,0,0,16,1,97,49,95,105,99,51,49,46,49,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,70,192,116,96,0,0,16,1,97,49,95,105,99,51,50,46,49,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,250,163,72,28,0,0,16,1,97,49,95,105,99,51,51,46,49,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,81,189,152,117,0,0,16,1,97,49,95,105,99,51,52,46,49,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,4,166,111,246,0,0,16,1,101,112,114,45,53,51,51,50,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,61,171,114,122,0,0,16,1,101,112,114,45,53,51,51,49,46,56,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,143,137,29,37,0,0,32,0,97,49,95,105,99,54,53,46,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,60,137,177,10,0,0,32,0,101,112,114,45,53,51,50,57,46,56,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,237,202,139,62,0,0,32,0,97,49,95,105,99,54,52,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,230,138,98,127,0,0,32,0,101,112,114,45,53,51,50,55,46,56,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,177,44,233,121,0,0,32,0,97,49,95,105,99,54,51,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,62,37,203,91,0,0,32,0,97,49,95,105,99,56,54,46,56,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,211,31,46,111,0,0,32,0,97,49,95,105,99,57,51,46,57,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,68,114,152,7,0,0,32,0,112,114,45,53,51,49,55,46,49,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,184,80,131,100,0,0,0,8,168,86,7,0,1,0,0,0,254,247,146,0,248,191,2,0,24,38,7,0,1,0,0,0,149,0,147,0,184,160,2,0,56,210,6,0,1,0,0,0,147,0,147,0,192,135,2,0,24,163,6,0,1,0,0,0,145,0,147,0,240,108,2,0,152,122,6,0,1,0,0,0,144,0,147,0,96,82,2,0,192,72,6,0,1,0,0,0,146,0,147,0,32,56,2,0,200,110,3,0,1,0,0,0,148,0,147,0,152,30,2,0,40,246,1,0,1,0,0,0,255,247,146,0,64,246,1,0,144,236,1,0,1,0,0,0,150,0,147,0,136,224,1,0,176,223,1,0,1,0,0,0,251,247,146,0,72,198,1,0,192,209,1,0,1,0,0,0,249,247,146,0,24,182,1,0,24,198,1,0,1,0,0,0,248,247,146,0,40,167,1,0,120,189,1,0,1,0,0,0,250,247,146,0,200,149,1,0,224,22,1,0,1,0,0,0,252,247,146,0,56,126,1,0,88,212,3,0,1,0,0,0,200,219,146,0,40,185,3,0,72,65,1,0,9,0,0,0,0,6,147,0,32,58,1,0,48,50,1,0,9,0,0,0,1,6,147,0,32,58,1,0,115,112,114,95,97,52,101,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,12,168,148,78,0,0,16,1,115,112,114,95,97,52,100,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,206,203,192,231,0,0,16,1,115,112,114,95,109,55,99,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,54,138,89,87,0,0,16,1,115,112,114,95,109,55,98,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,127,19,245,236,0,0,16,1,115,112,114,97,46,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,60,54,16,65,0,0,16,1,115,112,114,97,46,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,230,210,169,103,0,0,16,1,115,112,114,109,46,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,137,174,247,78,0,0,32,0,115,112,114,109,46,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,128,81,117,163,0,0,32,0,115,112,114,109,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,106,142,0,180,0,0,32,0,115,112,114,109,46,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,18,240,28,246,0,0,32,0,115,112,114,109,46,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,118,28,178,88,0,0,32,0,115,112,114,109,46,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,229,179,92,169,0,0,32,0,115,112,114,98,46,52,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,97,232,240,231,0,0,32,0,115,112,114,98,46,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,151,48,102,50,0,0,32,0,115,112,114,98,46,51,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,115,243,186,143,0,0,32,0,115,112,114,98,46,52,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,118,155,6,55,0,0,32,0,115,112,114,98,46,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,136,106,228,207,0,0,32,0,115,112,114,98,46,52,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,121,137,196,17,0,0,32,0,115,112,114,109,46,52,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,99,46,254,77,0,0,32,0,115,112,114,109,46,52,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,212,44,159,35,0,0,32,0,115,112,114,109,46,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,112,125,208,214,0,0,32,0,115,112,114,109,46,50,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,145,169,143,253,0,0,32,0,115,112,114,98,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,173,204,140,141,0,0,32,0,115,112,114,109,46,50,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,180,144,56,14,0,0,32,0,115,112,114,98,46,49,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,178,28,14,196,0,0,32,0,115,112,114,109,46,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,43,8,120,4,0,0,32,0,115,112,114,98,46,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,72,98,196,62,0,0,32,0,115,112,114,98,46,53,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,56,98,108,116,0,0,32,0,115,112,114,98,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,60,141,216,52,0,0,32,0,115,112,114,109,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,66,196,92,135,0,0,0,8,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,0,0,1,0,1,0,1,0,2,0,1,0,3,0,1,0,4,0,1,0,5,0,1,0,6,0,1,0,7,0,1,0,184,40,2,0,1,0,0,0,47,39,216,0,248,191,2,0,56,250,6,0,1,0,0,0,41,39,216,0,184,160,2,0,184,164,8,0,1,0,0,0,46,39,216,0,64,246,1,0,88,149,7,0,1,0,0,0,43,39,216,0,136,224,1,0,208,158,7,0,1,0,0,0,45,39,216,0,96,82,2,0,184,154,7,0,1,0,0,0,44,39,216,0,32,56,2,0,88,212,3,0,1,0,0,0,48,38,216,0,40,185,3,0,248,5,8,0,9,0,0,0,112,39,216,0,32,58,1,0,144,250,7,0,9,0,0,0,113,39,216,0,32,58,1,0,248,241,7,0,9,0,0,0,114,39,216,0,32,58,1,0,184,40,2,0,1,0,0,0,186,93,148,0,248,191,2,0,56,250,6,0,1,0,0,0,184,93,148,0,184,160,2,0,184,164,8,0,1,0,0,0,187,93,148,0,64,246,1,0,88,149,7,0,1,0,0,0,185,93,148,0,136,224,1,0,240,167,7,0,1,0,0,0,202,93,148,0,192,135,2,0,176,163,7,0,1,0,0,0,203,93,148,0,240,108,2,0,208,158,7,0,1,0,0,0,201,93,148,0,96,82,2,0,184,154,7,0,1,0,0,0,200,93,148,0,32,56,2,0,176,108,2,0,1,0,0,0,205,93,148,0,152,30,2,0,128,98,2,0,1,0,0,0,204,93,148,0,232,10,2,0,8,96,7,0,1,0,0,0,194,93,148,0,72,198,1,0,48,89,7,0,1,0,0,0,195,93,148,0,24,182,1,0,16,83,7,0,1,0,0,0,193,93,148,0,40,167,1,0,96,79,7,0,1,0,0,0,192,93,148,0,200,149,1,0,48,76,7,0,1,0,0,0,197,93,148,0,56,126,1,0,144,72,7,0,1,0,0,0,196,93,148,0,32,101,1,0,88,212,3,0,1,0,0,0,32,27,149,0,40,185,3,0,248,5,8,0,9,0,0,0,176,99,215,0,32,58,1,0,144,250,7,0,9,0,0,0,177,99,215,0,32,58,1,0,184,40,2,0,1,0,0,0,200,155,215,0,248,191,2,0,56,250,6,0,1,0,0,0,201,155,215,0,184,160,2,0,56,210,6,0,1,0,0,0,208,155,215,0,192,135,2,0,24,163,6,0,1,0,0,0,209,155,215,0,240,108,2,0,152,122,6,0,1,0,0,0,210,155,215,0,96,82,2,0,192,72,6,0,1,0,0,0,211,155,215,0,32,56,2,0,48,123,2,0,1,0,0,0,212,155,215,0,152,30,2,0,96,69,2,0,1,0,0,0,213,155,215,0,232,10,2,0,144,55,2,0,1,0,0,0,214,155,215,0,152,138,8,0,88,212,3,0,1,0,0,0,200,154,215,0,40,185,3,0,248,5,8,0,9,0,0,0,0,156,215,0,32,58,1,0,144,250,7,0,9,0,0,0,1,156,215,0,32,58,1,0,109,98,117,95,50,51,101,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,98,0,79,34,2,0,16,1,109,98,117,95,50,52,98,46,57,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,41,231,213,149,1,0,16,1,109,98,117,95,50,56,98,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,203,203,199,177,1,0,16,1,109,98,117,95,50,53,98,46,49,48,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,212,63,13,165,1,0,16,1,109,98,117,95,50,57,98,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,86,46,227,8,1,0,16,1,109,98,117,95,50,49,97,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,5,123,0,213,2,0,16,1,109,98,117,95,50,48,97,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,245,138,132,252,2,0,16,1,109,98,45,49,109,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,6,142,70,65,4,0,32,0,109,98,45,51,109,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,158,170,83,244,4,0,32,0,109,98,45,50,109,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,254,251,47,4,0,32,0,109,98,45,52,109,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,29,132,185,30,4,0,32,0,109,98,45,53,109,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,201,157,107,80,4,0,32,0,109,98,45,55,109,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,251,194,248,175,4,0,32,0,109,98,45,54,109,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,233,112,108,183,4,0,32,0,109,98,45,56,109,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,86,149,12,230,4,0,32,0,109,98,45,49,48,109,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,245,111,151,151,4,0,32,0,109,98,45,49,50,109,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,64,168,80,179,4,0,32,0,109,98,45,49,49,109,46,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,67,71,185,143,4,0,32,0,109,98,45,49,51,109,46,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,95,13,129,218,4,0,32,0,109,98,95,113,97,46,53,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,196,3,26,226,3,0,16,1,109,98,45,113,49,46,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,206,195,48,6,6,0,64,0,109,98,45,113,50,46,50,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,33,156,79,53,6,0,64,0,109,98,45,113,51,46,51,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,124,72,56,120,6,0,64,0,109,98,45,113,52,46,52,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,135,224,102,171,6,0,64,0,109,98,45,113,53,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,242,254,137,199,6,0,64,0,109,98,45,113,54,46,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,27,184,236,6,0,64,0,109,98,45,113,55,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,186,73,30,4,6,0,64,0,109,98,45,113,56,46,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,42,112,254,89,6,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,154,135,134,67,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,109,98,54,51,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,2,47,57,184,0,0,0,8,105,111,98,49,46,49,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,98,112,114,103,49,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,167,61,121,49,0,0,0,8,105,111,99,49,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,129,32,24,13,0,0,0,8,100,55,108,49,46,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,13,65,183,39,0,0,0,8,100,56,108,49,46,56,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,218,199,159,83,0,0,0,8,100,57,107,50,46,57,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,86,161,133,205,0,0,0,8,100,49,48,102,49,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,148,196,25,102,0,0,0,8,184,40,2,0,1,0,0,0,40,39,216,0,248,191,2,0,56,250,6,0,1,0,0,0,32,39,216,0,184,160,2,0,88,149,7,0,1,0,0,0,33,39,216,0,136,224,1,0,208,158,7,0,1,0,0,0,42,39,216,0,96,82,2,0,184,154,7,0,1,0,0,0,43,39,216,0,32,56,2,0,176,108,2,0,1,0,0,0,44,39,216,0,152,30,2,0,128,98,2,0,1,0,0,0,30,39,216,0,232,10,2,0,16,83,7,0,1,0,0,0,34,39,216,0,40,167,1,0,96,79,7,0,1,0,0,0,35,39,216,0,200,149,1,0,48,76,7,0,1,0,0,0,36,39,216,0,56,126,1,0,144,72,7,0,1,0,0,0,31,39,216,0,32,101,1,0,88,212,3,0,1,0,0,0,48,38,216,0,40,185,3,0,248,5,8,0,9,0,0,0,112,39,216,0,32,58,1,0,144,250,7,0,9,0,0,0,113,39,216,0,32,58,1,0,248,241,7,0,9,0,0,0,114,39,216,0,32,58,1,0,184,40,2,0,1,0,0,0,208,155,215,0,248,191,2,0,184,164,8,0,1,0,0,0,209,155,215,0,64,246,1,0,224,96,5,0,1,0,0,0,200,155,215,0,88,94,5,0,16,92,5,0,1,0,0,0,201,155,215,0,40,90,5,0,200,87,5,0,1,0,0,0,202,155,215,0,128,83,5,0,0,81,5,0,1,0,0,0,203,155,215,0,168,77,5,0,160,73,5,0,1,0,0,0,192,155,215,0,0,69,5,0,80,66,5,0,1,0,0,0,193,155,215,0,32,64,5,0,64,61,5,0,1,0,0,0,194,155,215,0,48,59,5,0,152,56,5,0,1,0,0,0,195,155,215,0,248,53,5,0,240,50,5,0,1,0,0,0,184,155,215,0,0,46,5,0,24,42,5,0,1,0,0,0,185,155,215,0,248,37,5,0,160,34,5,0,1,0,0,0,186,155,215,0,120,32,5,0,200,29,5,0,1,0,0,0,187,155,215,0,192,27,5,0,176,25,5,0,1,0,0,0,176,155,215,0,192,22,5,0,224,19,5,0,1,0,0,0,177,155,215,0,48,16,5,0,160,11,5,0,1,0,0,0,160,155,215,0,24,8,5,0,120,5,5,0,1,0,0,0,179,155,215,0,32,2,5,0,160,254,4,0,1,0,0,0,178,155,215,0,8,252,4,0,0,249,4,0,1,0,0,0,161,155,215,0,56,244,4,0,248,240,4,0,1,0,0,0,162,155,215,0,128,237,4,0,216,17,4,0,1,0,0,0,169,155,215,0,24,16,4,0,224,13,4,0,1,0,0,0,204,155,215,0,216,11,4,0,8,8,4,0,1,0,0,0,168,155,215,0,80,4,4,0,200,0,4,0,1,0,0,0,180,155,215,0,48,252,3,0,16,17,8,0,1,0,0,0,211,155,215,0,224,12,8,0,32,77,1,0,1,0,0,0,210,155,215,0,216,70,1,0,88,212,3,0,1,0,0,0,200,154,215,0,40,185,3,0,248,5,8,0,9,0,0,0,0,156,215,0,32,58,1,0,144,250,7,0,9,0,0,0,1,156,215,0,32,58,1,0,168,86,7,0,1,0,0,0,48,244,146,0,248,191,2,0,24,38,7,0,1,0,0,0,111,252,146,0,184,160,2,0,56,210,6,0,1,0,0,0,104,252,146,0,192,135,2,0,24,163,6,0,1,0,0,0,105,252,146,0,240,108,2,0,152,122,6,0,1,0,0,0,106,252,146,0,96,82,2,0,192,72,6,0,1,0,0,0,107,252,146,0,32,56,2,0,200,110,3,0,1,0,0,0,108,252,146,0,152,30,2,0,120,89,3,0,1,0,0,0,109,252,146,0,232,10,2,0,120,74,3,0,1,0,0,0,110,252,146,0,152,138,8,0,40,246,1,0,1,0,0,0,49,244,146,0,64,246,1,0,144,236,1,0,1,0,0,0,119,252,146,0,136,224,1,0,176,223,1,0,1,0,0,0,112,252,146,0,72,198,1,0,192,209,1,0,1,0,0,0,113,252,146,0,24,182,1,0,24,198,1,0,1,0,0,0,114,252,146,0,40,167,1,0,120,189,1,0,1,0,0,0,115,252,146,0,200,149,1,0,224,22,1,0,1,0,0,0,116,252,146,0,56,126,1,0,160,14,1,0,1,0,0,0,117,252,146,0,32,101,1,0,176,9,1,0,1,0,0,0,118,252,146,0,96,32,8,0,88,212,3,0,1,0,0,0,248,216,146,0,40,185,3,0,72,65,1,0,9,0,0,0,40,4,147,0,32,58,1,0,48,50,1,0,9,0,0,0,41,4,147,0,32,58,1,0,168,86,7,0,1,0,0,0,132,151,215,0,248,191,2,0,24,38,7,0,1,0,0,0,130,151,215,0,184,160,2,0,56,210,6,0,1,0,0,0,120,151,215,0,192,135,2,0,24,163,6,0,1,0,0,0,121,151,215,0,240,108,2,0,152,122,6,0,1,0,0,0,122,151,215,0,96,82,2,0,192,72,6,0,1,0,0,0,123,151,215,0,32,56,2,0,200,110,3,0,1,0,0,0,136,151,215,0,152,30,2,0,120,89,3,0,1,0,0,0,137,151,215,0,232,10,2,0,120,74,3,0,1,0,0,0,138,151,215,0,152,138,8,0,40,246,1,0,1,0,0,0,133,151,215,0,64,246,1,0,144,236,1,0,1,0,0,0,131,151,215,0,136,224,1,0,176,223,1,0,1,0,0,0,124,151,215,0,72,198,1,0,192,209,1,0,1,0,0,0,125,151,215,0,24,182,1,0,24,198,1,0,1,0,0,0,126,151,215,0,40,167,1,0,120,189,1,0,1,0,0,0,127,151,215,0,200,149,1,0,224,22,1,0,1,0,0,0,139,151,215,0,56,126,1,0,160,14,1,0,1,0,0,0,140,151,215,0,32,101,1,0,176,9,1,0,1,0,0,0,141,151,215,0,96,32,8,0,168,132,8,0,1,0,0,0,136,148,215,0,232,209,1,0,72,126,8,0,1,0,0,0,160,148,215,0,144,189,1,0,192,122,8,0,1,0,0,0,163,148,215,0,208,174,1,0,40,116,8,0,1,0,0,0,164,148,215,0,48,160,1,0,72,110,8,0,1,0,0,0,161,148,215,0,160,140,1,0,184,102,8,0,1,0,0,0,162,148,215,0,56,112,1,0,248,67,8,0,1,0,0,0,165,148,215,0,32,92,1,0,136,64,8,0,1,0,0,0,166,148,215,0,64,77,1,0,128,58,8,0,1,0,0,0,167,148,215,0,112,157,4,0,232,23,8,0,1,0,0,0,138,148,215,0,104,195,5,0,160,19,8,0,1,0,0,0,152,148,215,0,32,245,8,0,248,16,8,0,1,0,0,0,155,148,215,0,32,231,8,0,192,12,8,0,1,0,0,0,156,148,215,0,88,214,8,0,224,5,8,0,1,0,0,0,153,148,215,0,224,202,8,0,144,1,8,0,1,0,0,0,154,148,215,0,72,193,8,0,176,222,7,0,1,0,0,0,157,148,215,0,144,180,8,0,176,218,7,0,1,0,0,0,158,148,215,0,208,164,8,0,248,214,7,0,1,0,0,0,159,148,215,0,160,152,4,0,88,212,3,0,1,0,0,0,200,147,215,0,40,185,3,0,16,17,8,0,1,0,0,0,129,151,215,0,224,12,8,0,56,58,1,0,1,0,0,0,128,151,215,0,64,50,1,0,72,65,1,0,9,0,0,0,152,151,215,0,32,58,1,0,48,50,1,0,9,0,0,0,153,151,215,0,32,58,1,0,101,112,114,45,49,50,55,50,50,98,46,97,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,162,82,5,192,1,0,16,1,101,112,114,45,49,50,55,50,49,98,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,26,53,61,101,1,0,16,1,109,112,114,45,49,50,55,49,50,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,61,190,218,155,2,0,32,0,109,112,114,45,49,50,55,49,51,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,28,43,45,133,2,0,32,0,109,112,114,45,49,50,55,49,52,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,206,38,130,68,2,0,32,0,109,112,114,45,49,50,55,49,57,46,98,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,52,133,136,214,3,0,32,0,109,112,114,45,49,50,55,50,54,46,97,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,69,73,52,255,3,0,32,0,109,112,114,45,49,50,55,49,56,46,98,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,12,252,46,186,3,0,32,0,109,112,114,45,49,50,55,50,53,46,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,23,12,138,38,3,0,32,0,109,112,114,45,49,50,55,49,55,46,98,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,248,196,28,200,3,0,32,0,109,112,114,45,49,50,55,50,52,46,97,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,220,3,73,15,3,0,32,0,101,112,114,45,49,50,55,49,54,46,98,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,41,230,112,168,3,0,32,0,101,112,114,45,49,50,55,50,51,46,97,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,144,207,6,198,3,0,32,0,101,112,114,45,49,50,55,50,48,46,97,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,225,141,13,122,4,0,16,1,109,112,114,45,49,50,55,49,53,46,98,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,82,26,5,7,19,0,64,0,101,112,114,45,49,50,55,55,50,98,46,97,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,212,164,104,104,1,0,16,1,101,112,114,45,49,50,55,55,49,98,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,132,12,227,4,1,0,16,1,109,112,114,45,49,50,55,49,50,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,61,190,218,155,2,0,32,0,109,112,114,45,49,50,55,49,51,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,28,43,45,133,2,0,32,0,109,112,114,45,49,50,55,49,52,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,206,38,130,68,2,0,32,0,109,112,114,45,49,50,55,49,57,46,98,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,52,133,136,214,3,0,32,0,109,112,114,45,49,50,55,50,54,46,97,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,69,73,52,255,3,0,32,0,109,112,114,45,49,50,55,49,56,46,98,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,12,252,46,186,3,0,32,0,109,112,114,45,49,50,55,50,53,46,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,23,12,138,38,3,0,32,0,109,112,114,45,49,50,55,49,55,46,98,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,248,196,28,200,3,0,32,0,109,112,114,45,49,50,55,50,52,46,97,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,220,3,73,15,3,0,32,0,101,112,114,45,49,50,55,49,54,46,98,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,41,230,112,168,3,0,32,0,101,112,114,45,49,50,55,50,51,46,97,56,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,144,207,6,198,3,0,32,0,101,112,114,45,49,50,55,50,48,46,97,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,225,141,13,122,4,0,16,1,109,112,114,45,49,50,55,49,53,46,98,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,82,26,5,7,19,0,64,0,101,112,114,45,55,49,56,56,46,105,99,57,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,54,160,48,124,1,0,16,1,101,112,114,45,55,49,56,52,46,105,99,56,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,177,174,222,22,1,0,16,1,101,112,114,45,55,49,56,57,46,105,99,57,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,159,48,177,64,1,0,16,1,101,112,114,45,55,49,56,53,46,105,99,56,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,92,4,120,206,1,0,16,1,101,112,114,45,55,49,57,48,46,105,99,57,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,145,16,57,246,1,0,16,1,101,112,114,45,55,49,56,54,46,105,99,56,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,215,103,179,121,1,0,16,1,101,112,114,45,55,49,57,49,46,105,99,49,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,211,233,113,97,1,0,16,1,101,112,114,45,55,49,56,55,46,105,99,56,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,239,114,203,112,1,0,16,1,101,112,114,45,55,49,56,50,46,105,99,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,182,53,197,215,9,0,16,1,101,112,114,45,55,49,56,51,46,105,99,54,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,248,58,21,166,9,0,16,1,101,112,114,45,55,49,57,54,46,105,99,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,37,163,127,52,2,0,32,0,101,112,114,45,55,49,57,55,46,105,99,52,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,209,139,217,57,2,0,32,0,101,112,114,45,55,49,57,56,46,105,99,54,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,107,234,163,61,2,0,32,0,101,112,114,45,55,50,51,48,46,105,99,51,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,100,210,226,147,3,0,32,0,101,112,114,45,55,50,50,50,46,105,99,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,195,95,191,237,3,0,32,0,101,112,114,45,55,50,49,52,46,105,99,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,216,55,197,232,3,0,32,0,101,112,114,45,55,50,48,54,46,105,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,164,79,132,34,3,0,32,0,101,112,114,45,55,50,50,57,46,105,99,51,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,117,110,205,3,0,32,0,101,112,114,45,55,50,50,49,46,105,99,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,156,90,242,65,3,0,32,0,101,112,114,45,55,50,49,51,46,105,99,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,103,154,176,91,3,0,32,0,101,112,114,45,55,50,48,53,46,105,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,191,46,170,220,3,0,32,0,101,112,114,45,55,50,50,56,46,105,99,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,102,94,225,213,3,0,32,0,101,112,114,45,55,50,50,48,46,105,99,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,46,174,98,172,3,0,32,0,101,112,114,45,55,50,49,50,46,105,99,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,149,34,120,156,3,0,32,0,101,112,114,45,55,50,48,52,46,105,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,92,16,17,55,3,0,32,0,101,112,114,45,55,50,50,55,46,105,99,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,187,193,215,96,3,0,32,0,101,112,114,45,55,50,49,57,46,105,99,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,56,0,51,246,3,0,32,0,101,112,114,45,55,50,49,49,46,105,99,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,152,123,115,96,3,0,32,0,101,112,114,45,55,50,48,51,46,105,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,187,94,251,112,3,0,32,0,101,112,114,45,55,50,50,54,46,105,99,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,151,92,123,109,3,0,32,0,101,112,114,45,55,50,49,56,46,105,99,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,124,121,191,206,3,0,32,0,101,112,114,45,55,50,49,48,46,105,99,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,139,106,89,36,3,0,32,0,101,112,114,45,55,50,48,50,46,105,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,130,208,55,181,3,0,32,0,101,112,114,45,55,50,50,53,46,105,99,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,113,66,120,94,3,0,32,0,101,112,114,45,55,50,49,55,46,105,99,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,16,94,14,81,3,0,32,0,101,112,114,45,55,50,48,57,46,105,99,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,21,173,45,122,3,0,32,0,101,112,114,45,55,50,48,49,46,105,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,8,78,186,245,3,0,32,0,101,112,114,45,55,50,50,52,46,105,99,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,239,201,66,236,3,0,32,0,101,112,114,45,55,50,49,54,46,105,99,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,122,125,74,109,3,0,32,0,101,112,114,45,55,50,48,56,46,105,99,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,23,39,115,15,3,0,32,0,101,112,114,45,55,50,48,48,46,105,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,243,248,59,252,3,0,32,0,101,112,114,45,55,50,50,51,46,105,99,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,196,253,81,237,3,0,32,0,101,112,114,45,55,50,49,53,46,105,99,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,61,95,231,223,3,0,32,0,101,112,114,45,55,50,48,55,46,105,99,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,65,119,192,162,3,0,32,0,101,112,114,45,55,49,57,57,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,47,226,145,177,3,0,32,0,101,112,114,45,55,49,56,49,46,105,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,25,4,116,180,10,0,32,0,101,112,114,45,55,50,51,52,46,105,99,55,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,51,121,57,214,4,0,16,1,101,112,114,45,55,50,51,51,46,105,99,55,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,217,118,78,80,4,0,16,1,101,112,114,45,55,50,51,49,46,105,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,20,107,28,135,11,0,64,0,101,112,114,45,55,50,51,50,46,105,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,12,52,89,75,11,0,64,0,101,112,114,45,54,56,52,52,46,105,99,49,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,214,123,236,227,16,0,32,0,51,49,53,45,53,49,54,51,46,105,99,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,16,101,112,114,45,49,51,57,52,52,46,49,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,219,128,154,152,1,0,16,1,101,112,114,45,49,51,57,52,51,46,49,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,80,48,110,66,1,0,16,1,101,112,114,45,49,48,56,57,57,46,49,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,55,170,63,187,1,0,16,1,101,112,114,45,49,48,56,57,55,46,49,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,177,126,8,95,1,0,16,1,101,112,114,45,49,48,54,52,48,46,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,219,104,190,2,9,0,16,1,101,112,114,45,49,48,54,51,56,46,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,238,139,62,241,9,0,16,1,101,112,114,45,49,48,54,52,49,46,55,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,8,248,195,56,9,0,16,1,101,112,114,45,49,48,54,51,57,46,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,232,205,219,140,9,0,16,1,101,112,114,45,49,48,54,53,50,46,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,249,134,2,38,2,0,32,0,101,112,114,45,49,48,54,53,49,46,53,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,123,238,9,198,2,0,32,0,101,112,114,45,49,48,54,53,48,46,53,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,3,164,54,178,2,0,32,0,101,112,114,45,49,48,54,55,53,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,43,1,172,214,3,0,32,0,101,112,114,45,49,48,54,56,50,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,80,50,216,217,3,0,32,0,101,112,114,45,49,51,57,52,53,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,249,238,177,251,3,0,32,0,101,112,114,45,49,51,57,52,54,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,48,73,20,3,3,0,32,0,101,112,114,45,49,48,54,55,55,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,214,184,87,138,3,0,32,0,101,112,114,45,49,48,54,56,52,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,16,137,255,58,3,0,32,0,101,112,114,45,49,48,54,55,56,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,152,48,71,175,3,0,32,0,101,112,114,45,49,48,54,56,53,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,239,254,186,128,3,0,32,0,101,112,114,45,49,48,54,55,57,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,120,72,188,3,3,0,32,0,101,112,114,45,49,48,54,56,54,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,78,115,75,39,3,0,32,0,101,112,114,45,49,48,54,56,48,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,237,119,6,159,3,0,32,0,101,112,114,45,49,48,54,56,55,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,71,138,80,3,0,32,0,101,112,114,45,49,48,54,56,49,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,114,234,118,177,3,0,32,0,101,112,114,45,49,48,54,56,56,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,29,213,252,66,3,0,32,0,101,112,114,45,49,48,54,52,50,46,52,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,195,188,54,120,10,0,32,0,101,112,114,45,49,48,54,52,57,99,46,56,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,113,206,193,246,4,0,16,1,101,112,114,45,49,48,54,52,51,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,100,83,245,6,11,0,64,0,101,112,114,45,49,48,54,52,52,46,54,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,29,84,29,180,11,0,64,0,101,112,114,45,49,48,54,52,53,46,54,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,255,171,13,166,11,0,64,0,101,112,114,45,49,48,54,52,54,46,54,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,17,196,60,71,11,0,64,0,184,40,2,0,1,0,0,0,208,155,215,0,248,191,2,0,56,250,6,0,1,0,0,0,212,155,215,0,184,160,2,0,184,164,8,0,1,0,0,0,209,155,215,0,64,246,1,0,240,190,7,0,4,0,0,0,112,156,215,0,208,13,4,0,208,240,5,0,4,0,0,0,104,156,215,0,152,30,2,0,32,201,5,0,4,0,0,0,96,156,215,0,232,10,2,0,184,245,8,0,1,0,0,0,213,155,215,0,152,138,8,0,16,17,8,0,1,0,0,0,211,155,215,0,224,12,8,0,32,77,1,0,1,0,0,0,210,155,215,0,216,70,1,0,88,212,3,0,1,0,0,0,200,154,215,0,40,185,3,0,248,5,8,0,9,0,0,0,0,156,215,0,32,58,1,0,144,250,7,0,9,0,0,0,1,156,215,0,32,58,1,0,117,50,50,50,45,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,190,146,54,10,1,0,16,1,117,49,57,54,45,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,167,77,69,128,1,0,16,1,115,57,50,95,50,49,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,119,120,90,146,2,0,16,1,115,57,50,95,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0])
.concat([82,216,176,3,4,0,32,0,115,57,50,95,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,137,2,132,4,0,32,0,115,57,50,95,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,240,181,205,4,0,32,0,115,57,50,95,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,114,148,121,226,4,0,32,0,115,57,50,95,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,39,138,186,4,0,32,0,115,57,50,95,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,191,132,229,4,0,32,0,115,57,50,95,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,125,248,227,33,4,0,32,0,115,57,50,95,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,71,252,190,4,0,32,0,115,57,50,95,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,213,135,6,150,4,0,32,0,115,57,50,95,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,205,142,151,4,0,32,0,115,57,50,95,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,10,154,236,214,4,0,32,0,115,57,50,95,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,103,44,237,4,0,32,0,115,57,50,95,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,14,182,246,8,3,0,16,0,115,57,50,95,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,32,22,127,5,0,64,0,115,57,50,95,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,229,173,190,5,0,64,0,54,46,97,109,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,117,162,133,58,8,0,32,0,57,46,97,109,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,47,71,86,145,8,0,32,0,56,46,97,109,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,59,8,219,236,8,0,32,0,49,48,46,97,109,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,132,131,234,143,8,0,32,0,115,102,49,48,45,51,48,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,154,167,54,146,1,0,16,1,115,102,49,48,45,49,48,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,157,134,58,178,1,0,16,1,115,102,49,48,45,50,48,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,28,193,38,130,1,0,16,1,115,102,49,48,45,52,48,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,226,108,76,146,1,0,16,1,115,57,50,95,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,216,176,3,4,0,32,0,115,57,50,95,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,137,2,132,4,0,32,0,115,57,50,95,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,240,181,205,4,0,32,0,115,57,50,95,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,114,148,121,226,4,0,32,0,115,57,50,95,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,39,138,186,4,0,32,0,115,57,50,95,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,191,132,229,4,0,32,0,115,57,50,95,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,125,248,227,33,4,0,32,0,115,57,50,95,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,71,252,190,4,0,32,0,115,57,50,95,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,213,135,6,150,4,0,32,0,115,57,50,95,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,205,142,151,4,0,32,0,115,57,50,95,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,10,154,236,214,4,0,32,0,115,57,50,95,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,103,44,237,4,0,32,0,115,57,50,95,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,14,182,246,8,3,0,16,0,115,57,50,95,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,32,22,127,5,0,64,0,115,57,50,95,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,229,173,190,5,0,64,0,115,57,50,117,95,50,51,99,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,162,106,139,10,2,0,16,1,115,57,50,95,50,50,99,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,11,99,216,95,2,0,16,1,115,57,50,95,50,49,97,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,119,120,90,146,2,0,16,1,121,109,46,117,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,195,156,179,214,2,0,16,1,121,109,46,117,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,117,167,160,239,2,0,16,1,121,109,46,117,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,178,183,18,200,2,0,16,1,115,57,50,95,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,216,176,3,4,0,32,0,115,57,50,95,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,137,2,132,4,0,32,0,115,57,50,95,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,240,181,205,4,0,32,0,115,57,50,95,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,114,148,121,226,4,0,32,0,115,57,50,95,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,39,138,186,4,0,32,0,115,57,50,95,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,191,132,229,4,0,32,0,115,57,50,95,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,125,248,227,33,4,0,32,0,115,57,50,95,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,71,252,190,4,0,32,0,115,57,50,95,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,213,135,6,150,4,0,32,0,115,57,50,95,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,205,142,151,4,0,32,0,115,57,50,95,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,10,154,236,214,4,0,32,0,115,57,50,95,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,103,44,237,4,0,32,0,115,57,50,95,48,57,46,49,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,14,182,246,8,3,0,16,0,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,205,198,222,6,5,0,64,0,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,50,131,119,148,8,0,32,0,49,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,5,197,91,249,8,0,32,0,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,211,82,228,209,8,0,32,0,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,169,36,88,21,8,0,32,0,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,98,11,67,197,0,0,0,8,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,20,65,127,229,0,0,0,8,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,233,114,54,154,0,0,0,8,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,189,158,182,54,0,0,0,8,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,144,63,179,173,0,0,0,8,50,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,169,252,207,250,0,0,0,8,50,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,209,194,180,40,0,0,0,8,50,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,167,230,73,203,0,0,0,8,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,189,201,8,140,0,0,0,8,50,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,189,254,19,246,0,0,0,8,49,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,139,88,59,242,0,0,0,8,50,52,40,95,95,115,102,50,99,101,117,99,98,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,38,98,241,180,0,0,0,8,117,50,50,50,99,104,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,102,123,86,219,1,0,16,1,117,49,57,54,99,104,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,126,89,234,149,1,0,16,1,115,57,50,95,50,49,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,119,120,90,146,2,0,16,1,115,57,50,95,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,216,176,3,4,0,32,0,115,57,50,95,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,137,2,132,4,0,32,0,115,57,50,95,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,240,181,205,4,0,32,0,115,57,50,95,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,114,148,121,226,4,0,32,0,115,57,50,95,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,39,138,186,4,0,32,0,115,57,50,95,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,191,132,229,4,0,32,0,115,57,50,95,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,125,248,227,33,4,0,32,0,115,57,50,95,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,71,252,190,4,0,32,0,115,57,50,95,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,213,135,6,150,4,0,32,0,115,57,50,95,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,205,142,151,4,0,32,0,115,57,50,95,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,10,154,236,214,4,0,32,0,115,57,50,95,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,103,44,237,4,0,32,0,115,57,50,95,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,14,182,246,8,3,0,16,0,115,57,50,95,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,32,22,127,5,0,64,0,115,57,50,95,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,229,173,190,5,0,64,0,115,57,50,117,95,50,51,97,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,91,65,68,172,2,0,16,1,115,57,50,95,50,50,97,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,164,204,241,153,2,0,16,1,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,182,183,115,16,1,0,16,1,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,226,108,76,146,1,0,16,1,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,85,208,18,131,1,0,16,1,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,242,15,88,208,1,0,16,1,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,212,247,135,168,4,0,32,0,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,240,139,250,121,4,0,32,0,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,35,255,144,147,4,0,32,0,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,60,21,95,106,4,0,32,0,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,137,181,179,175,4,0,32,0,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,32,129,81,50,4,0,32,0,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,62,5,242,144,4,0,32,0,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,174,121,101,193,4,0,32,0,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,166,133,157,22,4,0,32,0,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,48,134,99,12,4,0,32,0,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,65,168,163,50,4,0,32,0,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,148,155,225,110,4,0,32,0,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,14,182,246,8,3,0,16,0,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,32,22,127,5,0,64,0,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,229,173,190,5,0,64,0,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,50,131,119,148,8,0,32,0,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,5,197,91,249,8,0,32,0,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,211,82,228,209,8,0,32,0,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,169,36,88,21,8,0,32,0,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,68,28,234,19,0,0,0,8,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,102,123,86,219,1,0,16,1,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,126,89,234,149,1,0,16,1,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,182,183,115,16,1,0,16,1,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,226,108,76,146,1,0,16,1,115,57,50,95,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,216,176,3,4,0,32,0,115,57,50,95,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,137,2,132,4,0,32,0,115,57,50,95,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,240,181,205,4,0,32,0,115,57,50,95,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,114,148,121,226,4,0,32,0,115,57,50,95,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,39,138,186,4,0,32,0,115,57,50,95,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,191,132,229,4,0,32,0,115,57,50,95,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,125,248,227,33,4,0,32,0,115,57,50,95,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,71,252,190,4,0,32,0,115,57,50,95,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,213,135,6,150,4,0,32,0,115,57,50,95,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,205,142,151,4,0,32,0,115,57,50,95,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,10,154,236,214,4,0,32,0,115,57,50,95,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,103,44,237,4,0,32,0,115,57,50,95,48,57,46,49,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,14,182,246,8,3,0,16,0,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,205,198,222,6,5,0,64,0,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,50,131,119,148,8,0,32,0,49,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,5,197,91,249,8,0,32,0,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,211,82,228,209,8,0,32,0,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,169,36,88,21,8,0,32,0,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,68,28,234,19,0,0,0,8,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,98,11,67,197,0,0,0,8,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,20,65,127,229,0,0,0,8,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,233,114,54,154,0,0,0,8,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,189,158,182,54,0,0,0,8,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,144,63,179,173,0,0,0,8,50,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,169,252,207,250,0,0,0,8,50,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,209,194,180,40,0,0,0,8,50,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,167,230,73,203,0,0,0,8,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,189,201,8,140,0,0,0,8,50,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,189,254,19,246,0,0,0,8,49,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,139,88,59,242,0,0,0,8,50,52,40,95,95,115,102,50,99,101,117,97,98,53,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,38,98,241,180,0,0,0,8,54,115,116,45,117,49,57,54,46,117,49,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,212,9,102,89,2,0,16,1,54,115,116,45,117,49,48,46,117,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,189,134,65,237,2,0,16,1,54,115,116,45,117,55,48,46,117,55,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,31,248,160,186,4,0,32,0,54,115,116,45,117,54,56,46,117,54,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,90,249,223,142,4,0,32,0,54,115,116,45,117,54,57,46,117,54,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,177,98,137,70,4,0,32,0,54,115,116,45,117,54,52,46,117,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,54,245,101,129,4,0,32,0,54,115,116,45,117,49,57,46,117,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,211,99,215,57,4,0,32,0,54,115,116,45,117,49,56,46,117,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,110,228,223,45,4,0,32,0,117,49,57,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,14,182,246,8,3,0,16,0,117,50,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,17,251,255,108,5,0,64,0,54,115,116,45,117,51,49,46,117,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,45,111,72,53,10,0,32,0,54,115,116,45,117,50,57,46,117,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,1,166,236,228,10,0,32,0,117,49,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,68,28,234,19,0,0,0,8,121,121,99,45,50,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,102,123,86,219,1,0,16,1,121,121,99,45,51,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,126,89,234,149,1,0,16,1,121,121,99,45,52,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,182,183,115,16,1,0,16,1,121,121,99,45,53,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,226,108,76,146,1,0,16,1,121,121,99,45,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,31,98,66,130,4,0,32,0,121,121,99,45,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,96,169,147,7,4,0,32,0,121,121,99,45,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,115,153,21,176,4,0,32,0,121,121,99,45,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,114,181,168,146,4,0,32,0,121,121,99,45,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,105,132,19,97,4,0,32,0,121,121,99,45,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,219,220,0,184,4,0,32,0,97,45,49,53,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,203,210,7,111,3,0,16,0,98,45,49,54,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,17,251,255,108,5,0,64,0,121,121,99,45,54,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,50,131,119,148,8,0,32,0,121,121,99,45,56,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,5,197,91,249,8,0,32,0,121,121,99,45,55,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,211,82,228,209,8,0,32,0,121,121,99,45,57,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,169,36,88,21,8,0,32,0,99,45,50,55,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,68,28,234,19,0,0,0,8,107,52,45,50,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,102,123,86,219,1,0,16,1,107,52,45,49,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,126,89,234,149,1,0,16,1,117,50,50,49,46,101,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,182,183,115,16,1,0,16,1,117,49,57,53,46,101,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,226,108,76,146,1,0,16,1,115,57,50,95,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,216,176,3,4,0,32,0,115,57,50,95,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,137,2,132,4,0,32,0,115,57,50,95,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,240,181,205,4,0,32,0,115,57,50,95,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,114,148,121,226,4,0,32,0,115,57,50,95,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,39,138,186,4,0,32,0,115,57,50,95,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,191,132,229,4,0,32,0,115,57,50,95,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,125,248,227,33,4,0,32,0,115,57,50,95,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,71,252,190,4,0,32,0,115,57,50,95,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,213,135,6,150,4,0,32,0,115,57,50,95,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,205,142,151,4,0,32,0,115,57,50,95,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,10,154,236,214,4,0,32,0,115,57,50,95,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,103,44,237,4,0,32,0,115,57,50,95,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,14,182,246,8,3,0,16,0,115,57,50,95,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,32,22,127,5,0,64,0,115,57,50,95,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,229,173,190,5,0,64,0,115,102,117,55,45,49,46,48,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,49,155,106,134,1,0,16,1,115,102,117,55,45,51,46,48,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,147,85,164,243,1,0,16,1,115,102,117,55,45,50,46,48,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,52,113,112,209,1,0,16,1,115,102,117,55,45,52,46,48,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,102,86,29,205,1,0,16,1,115,57,50,95,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,216,176,3,4,0,32,0,115,57,50,95,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,137,2,132,4,0,32,0,115,57,50,95,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,240,181,205,4,0,32,0,115,57,50,95,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,114,148,121,226,4,0,32,0,115,57,50,95,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,39,138,186,4,0,32,0,115,57,50,95,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,191,132,229,4,0,32,0,115,57,50,95,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,125,248,227,33,4,0,32,0,115,57,50,95,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,71,252,190,4,0,32,0,115,57,50,95,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,213,135,6,150,4,0,32,0,115,57,50,95,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,205,142,151,4,0,32,0,115,57,50,95,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,10,154,236,214,4,0,32,0,115,57,50,95,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,103,44,237,4,0,32,0,115,57,50,95,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,14,182,246,8,3,0,16,0,115,57,50,95,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,32,22,127,5,0,64,0,115,57,50,95,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,229,173,190,5,0,64,0,117,55,45,49,46,48,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,49,155,106,134,1,0,16,1,117,55,45,51,46,48,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,205,95,177,73,1,0,16,1,115,57,50,95,50,49,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,119,120,90,146,2,0,16,1,115,57,50,95,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,216,176,3,4,0,32,0,115,57,50,95,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,137,2,132,4,0,32,0,115,57,50,95,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,240,181,205,4,0,32,0,115,57,50,95,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,114,148,121,226,4,0,32,0,115,57,50,95,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,39,138,186,4,0,32,0,115,57,50,95,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,191,132,229,4,0,32,0,115,57,50,95,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,125,248,227,33,4,0,32,0,115,57,50,95,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,71,252,190,4,0,32,0,115,57,50,95,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,213,135,6,150,4,0,32,0,115,57,50,95,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,205,142,151,4,0,32,0,115,57,50,95,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,10,154,236,214,4,0,32,0,115,57,50,95,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,103,44,237,4,0,32,0,115,57,50,95,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,14,182,246,8,3,0,16,0,115,57,50,95,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,32,22,127,5,0,64,0,115,57,50,95,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,229,173,190,5,0,64,0,106,111,101,45,57,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,108,85,39,233,1,0,16,1,106,111,101,45,57,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,134,231,50,134,1,0,16,1,115,102,50,109,49,54,95,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,182,183,115,16,1,0,16,1,115,102,50,109,49,54,95,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,226,108,76,146,1,0,16,1,116,97,116,45,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,212,247,135,168,4,0,32,0,116,97,116,45,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,240,139,250,121,4,0,32,0,116,97,116,45,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,35,255,144,147,4,0,32,0,116,97,116,45,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,60,21,95,106,4,0,32,0,116,97,116,45,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,137,181,179,175,4,0,32,0,116,97,116,45,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,32,129,81,50,4,0,32,0,116,97,116,45,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,62,5,242,144,4,0,32,0,116,97,116,45,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,174,121,101,193,4,0,32,0,116,97,116,45,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,166,133,157,22,4,0,32,0,116,97,116,45,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,48,134,99,12,4,0,32,0,116,97,116,45,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,65,168,163,50,4,0,32,0,116,97,116,45,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,148,155,225,110,4,0,32,0,115,102,50,109,49,54,95,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,14,182,246,8,3,0,16,0,115,102,50,109,49,54,95,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,17,251,255,108,5,0,64,0,50,50,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,163,208,32,30,1,0,16,1,49,57,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,163,56,204,136,1,0,16,1,115,57,50,95,50,49,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,119,120,90,146,2,0,16,1,115,57,50,95,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,216,176,3,4,0,32,0,115,57,50,95,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,137,2,132,4,0,32,0,115,57,50,95,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,240,181,205,4,0,32,0,115,57,50,95,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,114,148,121,226,4,0,32,0,115,57,50,95,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,39,138,186,4,0,32,0,115,57,50,95,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,191,132,229,4,0,32,0,115,57,50,95,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,125,248,227,33,4,0,32,0,115,57,50,95,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,71,252,190,4,0,32,0,115,57,50,95,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,213,135,6,150,4,0,32,0,115,57,50,95,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,205,142,151,4,0,32,0,115,57,50,95,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,10,154,236,214,4,0,32,0,115,57,50,95,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,103,44,237,4,0,32,0,115,57,50,95,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,14,182,246,8,3,0,16,0,115,57,50,95,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,32,22,127,5,0,64,0,115,57,50,95,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,229,173,190,5,0,64,0,101,112,114,45,55,49,52,57,46,49,49,54,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,231,173,159,205,0,0,16,1,101,112,114,45,55,49,53,48,46,49,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,226,81,99,195,0,0,16,1,101,112,114,45,54,53,53,50,46,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,216,176,238,242,0,0,16,1,101,112,114,45,54,53,53,57,46,49,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,238,112,21,90,0,0,16,1,101,112,114,45,54,53,53,56,46,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,235,234,249,42,0,0,32,0,101,112,114,45,54,53,57,50,46,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,134,219,4,120,0,0,32,0,101,112,114,45,54,53,53,54,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,247,38,253,121,0,0,32,0,101,112,114,45,54,53,57,48,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,173,140,133,191,0,0,32,0,101,112,114,45,54,53,53,52,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,5,210,201,90,0,0,32,0,101,112,114,45,54,53,56,56,46,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,187,29,147,220,0,0,32,0,101,112,114,45,54,53,52,54,46,49,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,146,86,120,164,0,0,32,0,101,112,114,45,54,53,52,56,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,193,120,242,189,0,0,32,0,101,112,114,45,54,53,52,55,46,49,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,8,27,69,52,0,0,32,0,101,112,114,45,54,53,52,57,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,104,118,5,210,0,0,32,0,112,114,45,53,51,49,55,46,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,184,80,131,100,0,0,0,8,50,100,40,95,95,115,99,114,97,109,98,108,101,115,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,161,7,146,184,1,0,16,1,50,101,40,95,95,115,99,114,97,109,98,108,101,115,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,235,185,180,233,1,0,16,1,50,102,40,95,95,115,99,114,97,109,98,108,101,115,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,76,79,241,161,1,0,16,1,50,104,40,95,95,115,99,114,97,109,98,108,101,115,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,217,192,27,89,1,0,16,1,50,106,40,95,95,115,99,114,97,109,98,108,101,115,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,107,27,241,34,1,0,16,1,50,108,40,95,95,115,99,114,97,109,98,108,101,115,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,73,254,95,112,1,0,16,1,50,109,40,95,95,115,99,114,97,109,98,108,101,115,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,92,195,38,234,1,0,16,1,50,112,40,95,95,115,99,114,97,109,98,108,101,115,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,227,245,216,148,1,0,16,1,111,116,49,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,240,151,210,188,2,0,16,1,111,116,50,46,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,218,18,121,222,2,0,16,1,111,116,51,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,51,169,47,186,2,0,16,1,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,26,49,48,95,4,0,32,0,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,158,2,110,81,4,0,32,0,99,48,49,115,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,171,174,60,78,7,0,32,0,112,114,105,110,99,105,112,97,108,32,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,210,88,105,146,1,0,16,1,112,114,105,110,99,105,112,97,108,32,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,202,110,92,101,1,0,16,1,112,114,105,110,99,105,112,97,108,32,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,154,116,49,205,1,0,16,1,112,114,105,110,99,105,112,97,108,32,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,227,225,85,240,1,0,16,1,112,114,105,110,99,105,112,97,108,32,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,247,13,241,21,1,0,16,1,112,114,105,110,99,105,112,97,108,32,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,3,199,209,75,1,0,16,1,112,114,105,110,99,105,112,97,108,32,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,112,148,180,11,1,0,16,1,112,114,105,110,99,105,112,97,108,32,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,128,243,185,109,1,0,16,1,103,114,97,112,104,32,104,106,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,156,124,1,76,4,0,32,0,103,114,97,112,104,32,107,108,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,153,99,166,40,4,0,32,0,99,48,49,115,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,171,174,60,78,7,0,32,0,15,0,0,0,255,255,0,0,0,0,0,0,16,0,0,0,255,255,0,0,0,0,0,0,17,0,0,0,255,255,248,0,0,0,0,0,0,0,0,0,254,0,4,0,32,4,2,0,16,0,0,0,1,192,0,0,200,209,1,0,16,0,0,0,1,192,64,0,144,147,2,0,16,0,0,0,1,192,128,0,104,69,1,0,16,0,0,0,1,192,192,0,120,67,1,0,0,0,0,0,254,0,4,0,128,129,4,0,17,0,0,0,1,3,0,0,8,49,4,0,17,0,0,0,1,3,1,0,152,21,4,0,17,0,0,0,1,3,2,0,72,246,3,0,17,0,0,0,1,3,3,0,200,28,2,0,0,0,0,0,254,0,2,0,200,30,2,0,17,0,0,0,1,4,0,0,120,97,1,0,17,0,0,0,1,4,4,0,96,19,1,0,184,40,2,0,1,0,0,0,47,39,216,0,248,191,2,0,56,250,6,0,1,0,0,0,39,39,216,0,184,160,2,0,184,164,8,0,1,0,0,0,42,39,216,0,64,246,1,0,88,149,7,0,1,0,0,0,38,39,216,0,136,224,1,0,240,167,7,0,1,0,0,0,28,39,216,0,192,135,2,0,176,163,7,0,1,0,0,0,30,39,216,0,240,108,2,0,208,158,7,0,1,0,0,0,45,39,216,0,96,82,2,0,184,154,7,0,1,0,0,0,44,39,216,0,32,56,2,0,176,108,2,0,1,0,0,0,43,39,216,0,152,30,2,0,128,98,2,0,1,0,0,0,41,39,216,0,232,10,2,0,8,96,7,0,1,0,0,0,40,39,216,0,72,198,1,0,48,89,7,0,1,0,0,0,24,39,216,0,24,182,1,0,16,83,7,0,1,0,0,0,37,39,216,0,40,167,1,0,96,79,7,0,1,0,0,0,36,39,216,0,200,149,1,0,48,76,7,0,1,0,0,0,35,39,216,0,56,126,1,0,144,72,7,0,1,0,0,0,34,39,216,0,32,101,1,0,88,212,3,0,1,0,0,0,48,38,216,0,40,185,3,0,248,5,8,0,9,0,0,0,112,39,216,0,32,58,1,0,144,250,7,0,9,0,0,0,113,39,216,0,32,58,1,0,248,241,7,0,9,0,0,0,114,39,216,0,32,58,1,0,105,99,49,48,57,46,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,201,136,70,245,1,0,16,1,105,99,49,49,48,46,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,18,170,170,145,1,0,16,1,105,99,49,49,49,46,50,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,218,32,55,76,1,0,16,1,105,99,49,49,50,46,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,131,169,226,83,1,0,16,1,105,99,49,49,51,46,50,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,154,41,173,228,1,0,16,1,105,103,114,95,115,99,111,114,112,105,111,110,95,51,50,95,97,52,46,105,99,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,54,138,27,54,2,0,16,1,105,103,114,95,115,99,111,114,112,105,111,110,95,51,50,95,97,53,46,105,99,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,212,205,222,173,2,0,16,1,105,103,114,95,115,99,111,114,112,105,111,110,95,51,50,95,102,53,46,105,99,55,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,214,169,93,30,4,0,32,0,105,103,114,95,115,99,111,114,112,105,111,110,95,51,50,95,104,53,46,105,99,55,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,10,219,122,165,4,0,32,0,109,109,105,54,51,51,49,95,54,101,46,105,99,53,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,171,174,60,78,7,0,32,0,105,103,114,95,115,99,111,114,112,105,111,110,95,51,50,95,97,51,46,105,99,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,120,241,171,4,0,0,64,8,105,103,114,95,115,99,111,114,112,105,111,110,95,51,50,95,97,50,46,105,99,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,212,45,53,144,0,0,64,8,105,103,114,95,115,99,111,114,112,105,111,110,95,51,50,95,97,49,46,105,99,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,45,69,242,59,0,0,64,8,105,103,114,95,115,99,111,114,112,105,111,110,95,51,50,95,100,50,46,105,99,49,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,235,218,185,197,1,0,16,1,105,103,114,95,115,99,111,114,112,105,111,110,95,51,50,95,101,50,46,105,99,49,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,5,141,48,130,1,0,16,1,105,103,114,95,115,99,111,114,112,105,111,110,95,51,50,95,103,50,46,105,99,49,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,205,9,107,117,1,0,16,1,105,103,114,95,115,99,111,114,112,105,111,110,95,51,50,95,104,50,46,105,99,49,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,190,216,122,102,1,0,16,1,105,103,114,95,115,99,111,114,112,105,111,110,95,49,54,95,108,50,46,105,99,49,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,51,218,35,102,1,0,16,1,105,103,114,95,115,99,111,114,112,105,111,110,95,49,54,95,107,50,46,105,99,49,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,216,52,236,66,1,0,16,1,105,103,114,95,115,99,111,114,112,105,111,110,95,51,50,95,97,52,46,105,99,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,54,138,27,54,2,0,16,1,105,103,114,95,115,99,111,114,112,105,111,110,95,51,50,95,97,53,46,105,99,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,212,205,222,173,2,0,16,1,105,103,114,95,115,99,111,114,112,105,111,110,95,51,50,95,102,53,46,105,99,55,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,214,169,93,30,4,0,32,0,105,103,114,95,115,99,111,114,112,105,111,110,95,51,50,95,104,53,46,105,99,55,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,10,219,122,165,4,0,32,0,109,109,105,54,51,51,49,95,54,101,46,105,99,53,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,171,174,60,78,7,0,32,0,105,103,114,95,115,99,111,114,112,105,111,110,95,51,50,95,97,51,46,105,99,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,120,241,171,4,0,0,64,8,105,103,114,95,115,99,111,114,112,105,111,110,95,51,50,95,97,50,46,105,99,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,212,45,53,144,0,0,64,8,105,103,114,95,115,99,111,114,112,105,111,110,95,51,50,95,97,49,46,105,99,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,45,69,242,59,0,0,64,8,168,86,7,0,1,0,0,0,53,241,146,0,248,191,2,0,24,38,7,0,1,0,0,0,23,2,147,0,184,160,2,0,56,210,6,0,1,0,0,0,22,2,147,0,192,135,2,0,24,163,6,0,1,0,0,0,21,2,147,0,240,108,2,0,152,122,6,0,1,0,0,0,20,2,147,0,96,82,2,0,192,72,6,0,1,0,0,0,19,2,147,0,32,56,2,0,200,110,3,0,1,0,0,0,18,2,147,0,152,30,2,0,120,89,3,0,1,0,0,0,17,2,147,0,232,10,2,0,40,246,1,0,1,0,0,0,52,241,146,0,64,246,1,0,144,236,1,0,1,0,0,0,87,249,146,0,136,224,1,0,176,223,1,0,1,0,0,0,86,249,146,0,72,198,1,0,192,209,1,0,1,0,0,0,85,249,146,0,24,182,1,0,24,198,1,0,1,0,0,0,84,249,146,0,40,167,1,0,120,189,1,0,1,0,0,0,83,249,146,0,200,149,1,0,224,22,1,0,1,0,0,0,82,249,146,0,56,126,1,0,160,14,1,0,1,0,0,0,81,249,146,0,32,101,1,0,88,212,3,0,1,0,0,0,136,221,146,0,40,185,3,0,16,17,8,0,1,0,0,0,55,241,146,0,224,12,8,0,72,65,1,0,9,0,0,0,72,7,147,0,32,58,1,0,48,50,1,0,9,0,0,0,73,7,147,0,32,58,1,0,224,41,1,0,9,0,0,0,74,7,147,0,32,58,1,0,114,109,50,106,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,55,20,170,219,1,0,16,1,114,109,50,106,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,18,166,91,207,1,0,16,1,114,109,50,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,252,158,238,2,1,0,16,1,114,109,50,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,180,0,31,155,5,0,32,0,114,109,50,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,36,12,187,194,5,0,32,0,114,109,50,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,81,114,37,18,5,0,32,0,114,109,50,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,134,231,182,249,5,0,32,0,114,109,50,46,48,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,89,120,142,209,10,0,16,1,114,109,50,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,224,236,99,196,10,0,16,1,114,109,50,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,77,23,6,33,12,0,64,0,114,109,50,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,54,22,108,84,12,0,64,0,101,112,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,216,189,101,196,0,0,16,1,101,112,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,110,211,82,19,0,0,16,1,101,112,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,24,157,139,195,0,0,16,1,101,112,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,170,145,76,55,0,0,16,1,101,112,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,184,234,137,16,0,0,16,1,101,110,95,50,52,46,97,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,152,202,226,184,0,0,16,1,101,112,50,51,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,177,74,126,167,0,0,32,0,101,112,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,3,105,189,159,0,0,32,0,101,112,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,184,56,141,29,0,0,32,0,101,112,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,178,41,121,24,0,0,32,0,101,112,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,94,11,88,182,0,0,32,0,101,112,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,199,1,173,155,0,0,32,0,101,112,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,218,206,86,202,0,0,32,0,101,112,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,156,38,69,169,0,0,32,0,101,112,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,88,77,250,231,0,0,32,0,101,112,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,157,232,170,132,0,0,32,0,101,112,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,207,117,93,73,0,0,32,0,101,112,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,226,50,174,162,0,0,32,0,101,112,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,90,66,250,98,0,0,32,0,101,112,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,149,189,227,204,0,0,32,0,101,112,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,86,214,190,17,0,0,32,0,101,112,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,76,123,92,196,0,0,32,0,101,112,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,40,159,202,143,0,0,32,0,101,112,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,195,208,209,60,0,0,32,0,101,112,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,111,228,28,113,0,0,64,0,115,109,98,97,46,48,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,253,77,116,211,1,0,16,1,115,109,98,97,46,48,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,79,91,45,243,1,0,16,1,115,109,98,97,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,79,69,22,16,1,0,16,1,115,109,98,97,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,205,32,180,148,1,0,16,1,115,109,98,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,119,21,161,185,1,0,16,1,115,109,98,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,107,183,49,249,1,0,16,1,115,109,98,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,222,209,178,217,5,0,32,0,115,109,98,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,146,109,118,154,5,0,32,0,115,109,98,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,15,15,128,81,5,0,32,0,115,109,98,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,150,126,117,53,5,0,32,0,115,109,98,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,231,208,191,229,5,0,32,0,115,109,98,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,102,8,108,197,5,0,32,0,115,109,98,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,16,57,237,77,5,0,32,0,115,109,98,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,197,30,234,38,5,0,32,0,115,109,98,46,50,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,252,197,8,10,5,0,32,0,115,109,98,46,50,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,196,182,17,9,5,0,32,0,115,109,98,46,50,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,196,214,130,5,0,32,0,115,109,98,46,50,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,139,103,72,155,5,0,32,0,115,109,98,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,154,34,188,10,10,0,16,1,115,109,98,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,154,103,81,208,10,0,16,1,115,109,98,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,249,53,105,197,12,0,64,0,115,109,98,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,130,7,91,149,12,0,64,0,8,123,10,0,136,123,10,0,8,124,10,0,0,0,0,0,98,50,50,45,49,48,46,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,149,52,1,59,2,0,16,1,98,50,50,45,49,49,46,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,61,26,4,128,2,0,16,1,98,50,50,45,48,56,46,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,69,184,47,150,2,0,16,1,98,50,50,45,48,57,46,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,39,250,62,244,2,0,16,1,98,50,50,45,48,51,46,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,184,15,187,62,2,0,16,1,98,50,50,45,48,52,46,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,127,94,98,145,2,0,16,1,98,50,50,45,49,52,46,52,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,91,26,60,17,9,0,16,1,98,50,50,45,48,49,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,104,145,108,183,11,0,32,0,98,50,50,45,48,50,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,240,236,135,27,15,0,32,0,98,50,50,45,49,50,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,198,109,167,103,16,0,32,0,98,50,50,45,49,51,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,159,9,218,47,16,0,32,0,99,99,104,105,112,95,98,50,50,45,49,53,46,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,24,98,51,57,45,48,49,46,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,128,8,105,80,2,0,16,1,98,51,57,45,48,50,46,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,31,215,234,77,2,0,16,1,98,51,57,45,48,51,46,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,133,183,76,74,2,0,16,1,98,51,57,45,48,52,46,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,189,83,170,76,2,0,16,1,98,50,50,45,48,51,46,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,184,15,187,62,2,0,16,1,98,50,50,45,48,52,46,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,127,94,98,145,2,0,16,1,98,50,50,45,49,52,46,52,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,91,26,60,17,9,0,16,1,98,50,50,45,48,49,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,104,145,108,183,11,0,32,0,98,50,50,45,48,50,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,240,236,135,27,15,0,32,0,98,50,50,45,49,50,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,198,109,167,103,16,0,32,0,98,50,50,45,49,51,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,159,9,218,47,16,0,32,0,99,99,104,105,112,95,98,51,57,45,48,53,46,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,24,98,48,52,45,49,52,46,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,9,201,138,163,2,0,16,1,98,48,52,45,49,51,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,114,8,214,186,2,0,16,1,98,48,52,45,49,54,46,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,220,112,207,107,2,0,16,1,98,48,52,45,49,53,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,197,236,56,136,2,0,16,1,98,48,52,45,49,56,45,49,46,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,57,196,38,182,2,0,16,1,98,48,52,45,49,55,45,49,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,22,165,40,201,2,0,16,1,98,48,52,45,49,57,46,52,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,216,253,129,238,9,0,16,1,98,48,52,45,48,49,46,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,25,222,48,205,11,0,32,0,98,48,52,45,48,51,46,51,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,100,224,103,171,11,0,32,0,98,48,52,45,48,50,46,54,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,236,15,4,84,11,0,32,0,98,48,52,45,48,52,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,147,126,115,148,11,0,32,0,98,48,52,45,48,53,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,172,148,45,194,15,0,32,0,98,48,52,45,48,55,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,81,42,99,181,15,0,32,0,98,48,52,45,48,54,46,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,57,207,44,0,15,0,32,0,98,48,52,45,48,56,46,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,5,202,175,254,15,0,32,0,98,48,52,45,50,48,46,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,204,52,26,253,26,0,64,0,168,86,7,0,1,0,0,0,132,151,215,0,248,191,2,0,24,38,7,0,1,0,0,0,130,151,215,0,184,160,2,0,56,210,6,0,1,0,0,0,120,151,215,0,192,135,2,0,24,163,6,0,1,0,0,0,121,151,215,0,240,108,2,0,152,122,6,0,1,0,0,0,122,151,215,0,96,82,2,0,192,72,6,0,1,0,0,0,123,151,215,0,32,56,2,0,200,110,3,0,1,0,0,0,136,151,215,0,152,30,2,0,120,89,3,0,1,0,0,0,137,151,215,0,232,10,2,0,200,211,5,0,4,0,0,0,104,150,215,0,208,13,4,0,8,203,5,0,4,0,0,0,96,150,215,0,184,198,5,0,40,246,1,0,1,0,0,0,133,151,215,0,64,246,1,0,144,236,1,0,1,0,0,0,131,151,215,0,136,224,1,0,176,223,1,0,1,0,0,0,124,151,215,0,72,198,1,0,192,209,1,0,1,0,0,0,125,151,215,0,24,182,1,0,24,198,1,0,1,0,0,0,126,151,215,0,40,167,1,0,120,189,1,0,1,0,0,0,127,151,215,0,200,149,1,0,224,22,1,0,1,0,0,0,139,151,215,0,56,126,1,0,160,14,1,0,1,0,0,0,140,151,215,0,32,101,1,0,112,195,5,0,4,0,0,0,88,150,215,0,136,7,4,0,88,189,5,0,4,0,0,0,80,150,215,0,136,113,1,0,88,212,3,0,1,0,0,0,200,147,215,0,40,185,3,0,16,17,8,0,1,0,0,0,129,151,215,0,224,12,8,0,56,58,1,0,1,0,0,0,128,151,215,0,64,50,1,0,72,65,1,0,9,0,0,0,152,151,215,0,32,58,1,0,48,50,1,0,9,0,0,0,153,151,215,0,32,58,1,0,98,97,110,103,46,119,97,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,40,2,0,1,0,0,0,10,151,215,0,248,191,2,0,56,250,6,0,1,0,0,0,3,151,215,0,184,160,2,0,184,164,8,0,1,0,0,0,11,151,215,0,64,246,1,0,240,190,7,0,4,0,0,0,104,150,215,0,208,13,4,0,32,201,5,0,1,0,0,0,13,151,215,0,152,30,2,0,208,240,5,0,1,0,0,0,5,151,215,0,232,10,2,0,16,59,7,0,1,0,0,0,0,151,215,0,152,138,8,0,32,160,5,0,1,0,0,0,9,151,215,0,48,119,7,0,72,137,7,0,1,0,0,0,2,151,215,0,112,109,7,0,88,212,3,0,1,0,0,0,200,147,215,0,40,185,3,0,16,17,8,0,1,0,0,0,12,151,215,0,224,12,8,0,248,5,8,0,9,0,0,0,24,151,215,0,32,58,1,0,144,250,7,0,9,0,0,0,25,151,215,0,32,58,1,0,184,40,2,0,1,0,0,0,214,155,215,0,248,191,2,0,56,250,6,0,1,0,0,0,211,155,215,0,184,160,2,0,184,164,8,0,1,0,0,0,215,155,215,0,64,246,1,0,8,3,3,0,4,0,0,0,112,156,215,0,208,13,4,0,208,240,5,0,4,0,0,0,104,156,215,0,152,30,2,0,32,201,5,0,4,0,0,0,96,156,215,0,232,10,2,0,216,7,8,0,1,0,0,0,212,155,215,0,152,138,8,0,184,2,8,0,1,0,0,0,213,155,215,0,48,119,7,0,16,17,8,0,1,0,0,0,210,155,215,0,224,12,8,0,32,77,1,0,1,0,0,0,209,155,215,0,216,70,1,0,88,212,3,0,1,0,0,0,200,154,215,0,40,185,3,0,248,5,8,0,9,0,0,0,0,156,215,0,32,58,1,0,144,250,7,0,9,0,0,0,1,156,215,0,32,58,1,0,168,86,7,0,1,0,0,0,72,254,146,0,248,191,2,0,24,38,7,0,1,0,0,0,74,254,146,0,184,160,2,0,56,210,6,0,1,0,0,0,248,245,146,0,192,135,2,0,24,163,6,0,1,0,0,0,249,245,146,0,240,108,2,0,152,122,6,0,1,0,0,0,250,245,146,0,96,82,2,0,192,72,6,0,1,0,0,0,251,245,146,0,32,56,2,0,200,110,3,0,1,0,0,0,252,245,146,0,152,30,2,0,120,89,3,0,1,0,0,0,253,245,146,0,232,10,2,0,120,74,3,0,1,0,0,0])
.concat([254,245,146,0,152,138,8,0,40,246,1,0,1,0,0,0,73,254,146,0,64,246,1,0,144,236,1,0,1,0,0,0,75,254,146,0,136,224,1,0,176,223,1,0,1,0,0,0,96,239,146,0,72,198,1,0,192,209,1,0,1,0,0,0,97,239,146,0,24,182,1,0,24,198,1,0,1,0,0,0,98,239,146,0,40,167,1,0,120,189,1,0,1,0,0,0,99,239,146,0,200,149,1,0,224,22,1,0,1,0,0,0,100,239,146,0,56,126,1,0,160,14,1,0,1,0,0,0,101,239,146,0,32,101,1,0,176,9,1,0,1,0,0,0,102,239,146,0,96,32,8,0,88,212,3,0,1,0,0,0,48,218,146,0,40,185,3,0,16,17,8,0,1,0,0,0,78,254,146,0,224,12,8,0,72,65,1,0,9,0,0,0,240,4,147,0,32,58,1,0,48,50,1,0,9,0,0,0,241,4,147,0,32,58,1,0,184,40,2,0,1,0,0,0,214,155,215,0,248,191,2,0,184,164,8,0,1,0,0,0,206,155,215,0,64,246,1,0,104,28,8,0,1,0,0,0,198,155,215,0,232,209,1,0,64,183,7,0,1,0,0,0,190,155,215,0,104,195,5,0,56,210,6,0,1,0,0,0,209,155,215,0,192,135,2,0,24,163,6,0,1,0,0,0,208,155,215,0,240,108,2,0,152,122,6,0,1,0,0,0,211,155,215,0,96,82,2,0,192,72,6,0,1,0,0,0,210,155,215,0,32,56,2,0,48,123,2,0,1,0,0,0,212,155,215,0,152,30,2,0,96,69,2,0,1,0,0,0,213,155,215,0,232,10,2,0,176,223,1,0,1,0,0,0,201,155,215,0,72,198,1,0,192,209,1,0,1,0,0,0,200,155,215,0,24,182,1,0,24,198,1,0,1,0,0,0,203,155,215,0,40,167,1,0,120,189,1,0,1,0,0,0,202,155,215,0,200,149,1,0,248,187,8,0,1,0,0,0,204,155,215,0,56,126,1,0,184,179,8,0,1,0,0,0,205,155,215,0,32,101,1,0,192,122,8,0,1,0,0,0,193,155,215,0,192,135,2,0,40,116,8,0,1,0,0,0,192,155,215,0,240,108,2,0,72,110,8,0,1,0,0,0,195,155,215,0,96,82,2,0,184,102,8,0,1,0,0,0,194,155,215,0,32,56,2,0,240,45,8,0,1,0,0,0,196,155,215,0,152,30,2,0,40,38,8,0,1,0,0,0,197,155,215,0,232,10,2,0,248,16,8,0,1,0,0,0,185,155,215,0,72,198,1,0,192,12,8,0,1,0,0,0,184,155,215,0,24,182,1,0,224,5,8,0,1,0,0,0,187,155,215,0,40,167,1,0,144,1,8,0,1,0,0,0,186,155,215,0,200,149,1,0,72,204,7,0,1,0,0,0,188,155,215,0,56,126,1,0,208,196,7,0,1,0,0,0,189,155,215,0,32,101,1,0,56,122,5,0,1,0,0,0,215,155,215,0,224,12,8,0,0,105,5,0,1,0,0,0,207,155,215,0,128,176,7,0,152,120,4,0,1,0,0,0,199,155,215,0,248,114,7,0,112,109,5,0,1,0,0,0,191,155,215,0,32,105,5,0,88,212,3,0,1,0,0,0,200,154,215,0,40,185,3,0,248,5,8,0,9,0,0,0,0,156,215,0,32,58,1,0,144,250,7,0,9,0,0,0,1,156,215,0,32,58,1,0,101,112,114,45,55,55,50,56,46,98,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,142,200,168,86,1,0,16,1,101,112,114,45,55,55,50,53,46,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,201,252,21,238,1,0,16,1,101,112,114,45,55,55,50,57,46,98,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,35,33,36,188,1,0,16,1,101,112,114,45,55,55,50,54,46,98,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,231,72,28,157,1,0,16,1,101,112,114,45,55,54,57,55,46,98,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,93,55,106,58,1,0,16,1,101,112,114,45,55,54,57,52,46,98,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,162,44,123,216,1,0,16,1,101,112,114,45,55,54,57,56,46,99,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,88,96,122,84,2,0,32,0,101,112,114,45,55,54,57,57,46,99,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,29,144,236,119,2,0,32,0,101,112,114,45,55,55,48,48,46,99,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,206,140,52,126,2,0,32,0,101,112,114,45,55,52,54,53,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,215,183,26,138,3,0,32,0,101,112,114,45,55,52,54,57,46,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,79,174,101,203,3,0,32,0,101,112,114,45,55,52,54,54,46,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,243,244,211,178,3,0,32,0,101,112,114,45,55,52,55,48,46,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,177,103,252,22,3,0,32,0,101,112,114,45,55,52,54,55,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,226,141,246,10,3,0,32,0,101,112,114,45,55,52,55,49,46,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,172,213,250,19,3,0,32,0,101,112,114,45,55,52,54,56,46,56,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,192,64,253,221,3,0,32,0,101,112,114,45,55,52,55,50,46,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,236,98,39,142,3,0,32,0,101,112,114,45,55,52,54,52,46,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,6,19,41,159,4,0,16,1,55,55,53,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,252,52,149,106,6,0,16,1,101,112,114,45,55,52,55,51,46,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,250,117,236,6,7,0,64,0,101,112,114,45,55,52,55,53,46,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,6,18,189,122,7,0,64,0,101,112,114,45,55,52,55,52,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,184,83,248,219,7,0,64,0,101,112,114,45,55,52,55,54,46,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,90,101,186,94,7,0,64,0,168,86,7,0,1,0,0,0,212,47,216,0,248,191,2,0,24,38,7,0,1,0,0,0,208,47,216,0,184,160,2,0,152,255,2,0,1,0,0,0,36,48,216,0,152,30,2,0,224,233,2,0,1,0,0,0,37,48,216,0,232,10,2,0,32,210,2,0,1,0,0,0,38,48,216,0,152,138,8,0,216,191,2,0,1,0,0,0,39,48,216,0,48,119,7,0,40,246,1,0,1,0,0,0,213,47,216,0,64,246,1,0,144,236,1,0,1,0,0,0,209,47,216,0,136,224,1,0,48,238,8,0,1,0,0,0,44,48,216,0,56,126,1,0,224,230,8,0,1,0,0,0,45,48,216,0,32,101,1,0,96,222,8,0,1,0,0,0,46,48,216,0,96,32,8,0,56,214,8,0,1,0,0,0,47,48,216,0,16,68,7,0,88,212,3,0,1,0,0,0,144,46,216,0,40,185,3,0,240,152,1,0,1,0,0,0,201,47,216,0,216,70,1,0,16,17,8,0,1,0,0,0,202,47,216,0,224,12,8,0,136,67,2,0,1,0,0,0,176,48,216,0,112,109,7,0,8,66,2,0,1,0,0,0,184,48,216,0,24,133,7,0,184,40,2,0,1,0,0,0,250,150,215,0,248,191,2,0,56,250,6,0,1,0,0,0,15,151,215,0,184,160,2,0,184,164,8,0,1,0,0,0,251,150,215,0,64,246,1,0,88,149,7,0,1,0,0,0,7,151,215,0,136,224,1,0,48,123,2,0,1,0,0,0,8,151,215,0,152,30,2,0,96,69,2,0,1,0,0,0,9,151,215,0,232,10,2,0,144,55,2,0,1,0,0,0,11,151,215,0,152,138,8,0,80,123,7,0,1,0,0,0,10,151,215,0,48,119,7,0,112,114,7,0,1,0,0,0,12,151,215,0,112,109,7,0,248,187,8,0,1,0,0,0,0,151,215,0,56,126,1,0,184,179,8,0,1,0,0,0,1,151,215,0,32,101,1,0,240,173,8,0,1,0,0,0,3,151,215,0,96,32,8,0,208,72,7,0,1,0,0,0,2,151,215,0,16,68,7,0,216,63,7,0,1,0,0,0,4,151,215,0,240,58,7,0,88,212,3,0,1,0,0,0,200,147,215,0,40,185,3,0,16,17,8,0,1,0,0,0,249,150,215,0,224,12,8,0,56,58,1,0,1,0,0,0,248,150,215,0,64,50,1,0,248,5,8,0,9,0,0,0,24,151,215,0,32,58,1,0,144,250,7,0,9,0,0,0,25,151,215,0,32,58,1,0,168,86,7,0,1,0,0,0,212,47,216,0,248,191,2,0,24,38,7,0,1,0,0,0,208,47,216,0,184,160,2,0,56,210,6,0,1,0,0,0,35,48,216,0,192,135,2,0,24,163,6,0,1,0,0,0,34,48,216,0,240,108,2,0,152,122,6,0,1,0,0,0,33,48,216,0,96,82,2,0,192,72,6,0,1,0,0,0,32,48,216,0,32,56,2,0,232,158,3,0,1,0,0,0,36,48,216,0,152,30,2,0,8,16,4,0,4,0,0,0,128,47,216,0,152,210,1,0,40,246,1,0,1,0,0,0,213,47,216,0,64,246,1,0,144,236,1,0,1,0,0,0,209,47,216,0,136,224,1,0,176,223,1,0,1,0,0,0,43,48,216,0,72,198,1,0,192,209,1,0,1,0,0,0,42,48,216,0,24,182,1,0,24,198,1,0,1,0,0,0,41,48,216,0,40,167,1,0,120,189,1,0,1,0,0,0,40,48,216,0,200,149,1,0,200,32,1,0,1,0,0,0,44,48,216,0,56,126,1,0,200,11,4,0,4,0,0,0,120,47,216,0,0,187,4,0,88,212,3,0,1,0,0,0,144,46,216,0,40,185,3,0,240,152,1,0,1,0,0,0,201,47,216,0,216,70,1,0,16,17,8,0,1,0,0,0,202,47,216,0,224,12,8,0,136,67,2,0,1,0,0,0,176,48,216,0,232,10,2,0,8,66,2,0,1,0,0,0,184,48,216,0,152,138,8,0,168,86,7,0,1,0,0,0,190,245,146,0,248,191,2,0,24,38,7,0,1,0,0,0,184,245,146,0,184,160,2,0,56,210,6,0,1,0,0,0,3,254,146,0,192,135,2,0,24,163,6,0,1,0,0,0,2,254,146,0,240,108,2,0,152,122,6,0,1,0,0,0,1,254,146,0,96,82,2,0,192,72,6,0,1,0,0,0,0,254,146,0,32,56,2,0,200,110,3,0,1,0,0,0,4,254,146,0,152,30,2,0,120,89,3,0,1,0,0,0,5,254,146,0,232,10,2,0,120,74,3,0,1,0,0,0,6,254,146,0,152,138,8,0,40,246,1,0,1,0,0,0,191,245,146,0,64,246,1,0,144,236,1,0,1,0,0,0,185,245,146,0,136,224,1,0,176,223,1,0,1,0,0,0,11,254,146,0,72,198,1,0,192,209,1,0,1,0,0,0,10,254,146,0,24,182,1,0,24,198,1,0,1,0,0,0,9,254,146,0,40,167,1,0,120,189,1,0,1,0,0,0,8,254,146,0,200,149,1,0,224,22,1,0,1,0,0,0,12,254,146,0,56,126,1,0,160,14,1,0,1,0,0,0,13,254,146,0,32,101,1,0,176,9,1,0,1,0,0,0,14,254,146,0,96,32,8,0,88,212,3,0,1,0,0,0,8,218,146,0,40,185,3,0,16,17,8,0,1,0,0,0,189,245,146,0,224,12,8,0,72,65,1,0,9,0,0,0,208,4,147,0,32,58,1,0,48,50,1,0,9,0,0,0,209,4,147,0,32,58,1,0,18,0,0,0,255,255,255,0,0,0,0,0,19,0,0,0,255,255,127,0,0,0,0,0,20,0,0,0,255,255,240,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,18,0,0,0,1,15,2,0,80,252,6,0,18,0,0,0,1,15,5,0,16,242,7,0,18,0,0,0,1,15,8,0,104,236,7,0,18,0,0,0,1,15,4,0,120,113,6,0,18,0,0,0,1,15,1,0,232,228,5,0,18,0,0,0,1,15,15,0,128,230,7,0,18,0,0,0,1,15,3,0,56,141,7,0,18,0,0,0,1,15,7,0,120,211,6,0,18,0,0,0,1,15,14,0,184,164,6,0,18,0,0,0,1,15,6,0,24,1,7,0,18,0,0,0,1,15,13,0,80,74,6,0,18,0,0,0,1,15,12,0,192,32,6,0,18,0,0,0,1,15,11,0,192,234,2,0,18,0,0,0,1,15,10,0,32,242,5,0,18,0,0,0,1,15,9,0,176,192,2,0,18,0,0,0,1,15,0,0,16,227,4,0,0,0,0,0,254,0,16,0,160,123,6,0,18,0,0,0,1,240,32,0,80,252,6,0,18,0,0,0,1,240,80,0,16,242,7,0,18,0,0,0,1,240,128,0,104,236,7,0,18,0,0,0,1,240,64,0,120,113,6,0,18,0,0,0,1,240,16,0,232,228,5,0,18,0,0,0,1,240,240,0,128,230,7,0,18,0,0,0,1,240,48,0,56,141,7,0,18,0,0,0,1,240,112,0,120,211,6,0,18,0,0,0,1,240,224,0,184,164,6,0,18,0,0,0,1,240,96,0,24,1,7,0,18,0,0,0,1,240,208,0,80,74,6,0,18,0,0,0,1,240,192,0,192,32,6,0,18,0,0,0,1,240,176,0,192,234,2,0,18,0,0,0,1,240,160,0,32,242,5,0,18,0,0,0,1,240,144,0,176,192,2,0,18,0,0,0,1,240,0,0,136,143,5,0,0,0,0,0,254,0,4,0,80,114,8,0,19,0,0,0,1,12,12,0,0,107,8,0,19,0,0,0,1,12,8,0,224,120,3,0,19,0,0,0,1,12,4,0,224,118,3,0,19,0,0,0,1,12,0,0,88,115,3,0,0,0,0,0,254,0,4,0,72,202,5,0,19,0,0,0,1,96,96,0,80,246,3,0,19,0,0,0,1,96,64,0,80,124,6,0,19,0,0,0,1,96,32,0,112,212,3,0,19,0,0,0,1,96,0,0,248,160,5,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,128,128,0,96,135,7,0,19,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,20,0,0,0,1,16,16,0,96,135,7,0,20,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,20,0,0,0,1,64,64,0,96,135,7,0,20,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,72,4,1,0,20,0,0,0,1,128,128,0,96,135,7,0,20,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,18,0,0,0,255,255,255,0,0,0,0,0,19,0,0,0,255,255,127,0,0,0,0,0,20,0,0,0,255,255,240,0,0,0,0,0,0,0,0,0,254,0,16,0,32,4,2,0,18,0,0,0,1,15,0,0,104,54,4,0,18,0,0,0,1,15,2,0,80,252,6,0,18,0,0,0,1,15,5,0,16,242,7,0,18,0,0,0,1,15,8,0,104,236,7,0,18,0,0,0,1,15,4,0,120,113,6,0,18,0,0,0,1,15,1,0,232,228,5,0,18,0,0,0,1,15,15,0,128,230,7,0,18,0,0,0,1,15,3,0,56,141,7,0,18,0,0,0,1,15,7,0,120,211,6,0,18,0,0,0,1,15,14,0,184,164,6,0,18,0,0,0,1,15,6,0,24,1,7,0,18,0,0,0,1,15,13,0,80,74,6,0,18,0,0,0,1,15,12,0,192,32,6,0,18,0,0,0,1,15,11,0,192,234,2,0,18,0,0,0,1,15,10,0,32,242,5,0,18,0,0,0,1,15,9,0,176,192,2,0,0,0,0,0,254,0,2,0,80,111,3,0,18,0,0,0,1,16,16,0,248,38,7,0,18,0,0,0,1,16,0,0,0,212,5,0,0,0,0,0,254,0,4,0,104,115,3,0,19,0,0,0,1,3,3,0,200,68,4,0,19,0,0,0,1,3,2,0,136,66,4,0,19,0,0,0,1,3,1,0,176,63,4,0,19,0,0,0,1,3,0,0,104,142,4,0,0,0,0,0,254,0,4,0,64,225,7,0,19,0,0,0,1,12,12,0,224,118,3,0,19,0,0,0,1,12,8,0,88,115,3,0,19,0,0,0,1,12,4,0,152,221,7,0,19,0,0,0,1,12,0,0,112,217,7,0,0,0,0,0,254,0,4,0,72,202,5,0,19,0,0,0,1,96,96,0,80,246,3,0,19,0,0,0,1,96,64,0,80,124,6,0,19,0,0,0,1,96,32,0,112,212,3,0,19,0,0,0,1,96,0,0,248,160,5,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,128,128,0,96,135,7,0,19,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,20,0,0,0,1,16,16,0,96,135,7,0,20,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,20,0,0,0,1,64,64,0,96,135,7,0,20,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,72,4,1,0,20,0,0,0,1,128,128,0,96,135,7,0,20,0,0,0,1,128,0,0,152,182,7,0,112,115,117,95,50,54,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,33,209,54,146,1,0,16,1,112,115,117,95,51,48,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,1,229,32,131,1,0,16,1,112,115,117,95,50,55,46,49,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,161,96,201,97,1,0,16,1,112,115,117,95,51,49,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,152,194,212,120,1,0,16,1,112,115,117,95,50,52,46,57,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,215,202,254,28,1,0,16,1,112,115,117,95,50,56,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,193,33,249,189,1,0,16,1,112,115,117,95,50,53,46,49,48,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,148,204,26,197,1,0,16,1,112,115,117,95,50,57,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,202,225,220,82,1,0,16,1,112,115,95,50,49,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,169,165,255,138,2,0,16,1,112,115,45,49,109,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,171,204,183,119,4,0,32,0,112,115,45,51,109,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,11,114,34,1,4,0,32,0,112,115,45,50,109,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,212,88,250,100,4,0,32,0,112,115,45,52,109,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,200,66,218,96,4,0,32,0,112,115,45,53,109,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,57,168,78,197,4,0,32,0,112,115,45,55,109,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,189,172,197,4,4,0,32,0,112,115,45,54,109,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,204,244,68,165,4,0,32,0,112,115,45,56,109,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,54,244,2,143,4,0,32,0,112,115,95,113,46,53,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,70,68,255,73,3,0,16,0,112,115,45,113,49,46,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,38,135,253,49,6,0,64,0,112,115,45,113,50,46,50,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,239,158,10,152,6,0,64,0,112,115,45,113,51,46,51,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,145,68,212,13,6,0,64,0,112,115,45,113,52,46,52,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,3,47,212,190,6,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,154,135,134,67,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,112,115,54,51,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,176,88,167,3,0,0,0,8,105,111,98,49,46,49,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,98,112,114,103,49,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,167,61,121,49,0,0,0,8,105,111,99,49,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,129,32,24,13,0,0,0,8,100,55,108,49,46,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,13,65,183,39,0,0,0,8,100,56,108,49,46,56,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,218,199,159,83,0,0,0,8,100,57,107,50,46,57,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,86,161,133,205,0,0,0,8,100,49,48,102,49,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,148,196,25,102,0,0,0,8,112,115,106,95,50,51,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,218,47,107,2,0,16,1,112,115,106,95,50,50,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,188,54,16,224,2,0,16,1,112,115,106,95,50,49,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,169,165,255,138,2,0,16,1,112,115,95,48,49,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,171,204,183,119,4,0,32,0,112,115,95,48,50,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,11,114,34,1,4,0,32,0,112,115,95,48,51,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,212,88,250,100,4,0,32,0,112,115,95,48,52,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,200,66,218,96,4,0,32,0,112,115,95,48,53,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,57,168,78,197,4,0,32,0,112,115,95,48,54,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,189,172,197,4,4,0,32,0,112,115,95,48,55,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,204,244,68,165,4,0,32,0,112,115,95,48,56,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,54,244,2,143,4,0,32,0,112,115,95,113,46,53,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,70,68,255,73,3,0,16,0,112,115,45,113,49,46,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,38,135,253,49,6,0,64,0,112,115,45,113,50,46,50,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,239,158,10,152,6,0,64,0,112,115,45,113,51,46,51,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,145,68,212,13,6,0,64,0,112,115,45,113,52,46,52,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,3,47,212,190,6,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,154,135,134,67,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,112,115,54,51,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,176,88,167,3,0,0,0,8,105,111,98,49,46,49,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,98,112,114,103,49,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,167,61,121,49,0,0,0,8,105,111,99,49,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,129,32,24,13,0,0,0,8,100,55,108,49,46,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,13,65,183,39,0,0,0,8,100,56,108,49,46,56,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,218,199,159,83,0,0,0,8,100,57,107,50,46,57,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,86,161,133,205,0,0,0,8,100,49,48,102,49,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,148,196,25,102,0,0,0,8,112,115,104,95,50,54,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,131,187,210,106,1,0,16,1,112,115,104,95,51,48,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,89,54,141,5,1,0,16,1,112,115,104,95,50,55,46,49,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,211,79,159,87,1,0,16,1,112,115,104,95,51,49,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,181,112,159,44,1,0,16,1,112,115,104,95,50,52,46,57,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,65,72,161,250,1,0,16,1,112,115,104,95,50,56,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,32,31,91,92,1,0,16,1,112,115,104,95,50,53,46,49,48,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,218,223,79,114,1,0,16,1,112,115,104,95,50,57,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,1,249,156,119,1,0,16,1,112,115,95,50,49,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,169,165,255,138,2,0,16,1,112,115,45,49,109,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,171,204,183,119,4,0,32,0,112,115,45,51,109,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,11,114,34,1,4,0,32,0,112,115,45,50,109,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,212,88,250,100,4,0,32,0,112,115,45,52,109,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,200,66,218,96,4,0,32,0,112,115,45,53,109,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,57,168,78,197,4,0,32,0,112,115,45,55,109,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,189,172,197,4,4,0,32,0,112,115,45,54,109,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,204,244,68,165,4,0,32,0,112,115,45,56,109,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,54,244,2,143,4,0,32,0,112,115,95,113,46,53,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,70,68,255,73,3,0,16,0,112,115,45,113,49,46,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,38,135,253,49,6,0,64,0,112,115,45,113,50,46,50,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,239,158,10,152,6,0,64,0,112,115,45,113,51,46,51,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,145,68,212,13,6,0,64,0,112,115,45,113,52,46,52,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,3,47,212,190,6,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,154,135,134,67,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,112,115,54,51,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,176,88,167,3,0,0,0,8,105,111,98,49,46,49,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,98,112,114,103,49,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,167,61,121,49,0,0,0,8,105,111,99,49,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,129,32,24,13,0,0,0,8,100,55,108,49,46,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,13,65,183,39,0,0,0,8,100,56,108,49,46,56,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,218,199,159,83,0,0,0,8,100,57,107,50,46,57,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,86,161,133,205,0,0,0,8,100,49,48,102,49,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,148,196,25,102,0,0,0,8,99,57,56,45,49,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,222,108,109,129,2,0,16,1,99,57,56,45,49,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,91,61,209,183,2,0,16,1,99,57,56,45,48,54,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,69,27,167,100,2,0,16,1,99,57,56,45,48,55,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,192,91,25,144,2,0,16,1,99,57,56,45,49,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,124,225,88,168,9,0,16,1,99,57,56,45,48,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,178,227,31,14,11,0,32,0,99,57,56,45,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,179,210,42,74,15,0,32,0,99,57,56,45,48,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,143,103,154,88,15,0,32,0,99,57,56,45,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,245,102,127,25,24,0,64,0,99,57,56,45,48,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,57,156,221,157,28,0,32,0,21,0,0,0,255,255,255,0,0,0,0,0,22,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,21,0,0,0,1,2,2,0,96,135,7,0,21,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,21,0,0,0,1,4,4,0,96,135,7,0,21,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,21,0,0,0,1,8,0,0,96,135,7,0,21,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,21,0,0,0,1,48,0,0,16,242,7,0,21,0,0,0,1,48,16,0,104,236,7,0,21,0,0,0,1,48,48,0,128,230,7,0,21,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,21,0,0,0,1,192,0,0,16,242,7,0,21,0,0,0,1,192,64,0,104,236,7,0,21,0,0,0,1,192,192,0,128,230,7,0,21,0,0,0,1,192,128,0,184,164,6,0,0,0,0,0,254,0,4,0,72,202,5,0,22,0,0,0,1,3,2,0,80,246,3,0,22,0,0,0,1,3,3,0,80,124,6,0,22,0,0,0,1,3,1,0,112,212,3,0,22,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,3,0,80,1,6,0,22,0,0,0,1,12,12,0,8,49,4,0,22,0,0,0,1,12,8,0,152,21,4,0,22,0,0,0,1,12,4,0,72,246,3,0,0,0,0,0,254,0,4,0,128,129,4,0,22,0,0,0,1,48,32,0,208,75,4,0,22,0,0,0,1,48,48,0,8,49,4,0,22,0,0,0,1,48,16,0,152,21,4,0,22,0,0,0,1,48,0,0,72,246,3,0,0,0,0,0,254,0,2,0,144,212,6,0,22,0,0,0,1,128,0,0,8,208,6,0,22,0,0,0,1,128,128,0,88,204,6,0,112,103,97,117,95,100,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,197,185,34,186,1,0,16,1,112,103,97,117,95,100,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,239,39,57,223,1,0,16,1,112,103,97,45,115,105,109,109,46,48,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,176,152,47,69,6,0,32,0,112,103,97,45,115,105,109,109,46,48,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,146,32,103,158,6,0,32,0,112,103,97,45,115,105,109,109,46,48,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,254,218,157,174,6,0,32,0,112,103,97,45,115,105,109,109,46,48,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,148,45,215,148,6,0,32,0,112,103,97,45,115,105,109,109,46,48,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,109,136,161,72,6,0,32,0,112,103,97,45,115,105,109,109,46,48,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,55,126,45,23,6,0,32,0,112,103,97,45,115,105,109,109,46,48,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,152,61,227,158,6,0,32,0,112,103,97,45,115,105,109,109,46,48,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,50,238,141,132,6,0,32,0,112,103,97,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,146,169,191,189,10,0,16,1,112,103,97,45,115,105,109,109,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,12,200,170,192,13,0,64,0,112,103,97,45,115,105,109,109,46,48,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,134,93,166,55,13,0,64,0,112,103,97,45,115,105,109,109,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,52,233,241,211,13,0,64,0,112,103,97,45,115,105,109,109,46,48,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,154,72,57,139,13,0,64,0,112,103,97,106,95,100,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,163,243,113,2,1,0,16,1,112,103,97,106,95,100,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,153,119,75,190,1,0,16,1,112,103,97,45,115,105,109,109,46,48,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,176,152,47,69,6,0,32,0,112,103,97,45,115,105,109,109,46,48,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,146,32,103,158,6,0,32,0,112,103,97,45,115,105,109,109,46,48,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,32,0,254,218,157,174,6,0,32,0,112,103,97,45,115,105,109,109,46,48,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,148,45,215,148,6,0,32,0,112,103,97,45,115,105,109,109,46,48,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,109,136,161,72,6,0,32,0,112,103,97,45,115,105,109,109,46,48,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,55,126,45,23,6,0,32,0,112,103,97,45,115,105,109,109,46,48,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,152,61,227,158,6,0,32,0,112,103,97,45,115,105,109,109,46,48,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,50,238,141,132,6,0,32,0,112,103,97,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,146,169,191,189,10,0,16,1,112,103,97,45,115,105,109,109,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,12,200,170,192,13,0,64,0,112,103,97,45,115,105,109,109,46,48,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,134,93,166,55,13,0,64,0,112,103,97,45,115,105,109,109,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,52,233,241,211,13,0,64,0,112,103,97,45,115,105,109,109,46,48,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,154,72,57,139,13,0,64,0,168,86,7,0,1,0,0,0,212,47,216,0,248,191,2,0,24,38,7,0,1,0,0,0,208,47,216,0,184,160,2,0,56,210,6,0,1,0,0,0,35,48,216,0,192,135,2,0,24,163,6,0,1,0,0,0,34,48,216,0,240,108,2,0,152,122,6,0,1,0,0,0,33,48,216,0,96,82,2,0,192,72,6,0,1,0,0,0,32,48,216,0,32,56,2,0,232,158,3,0,1,0,0,0,36,48,216,0,152,30,2,0,40,147,2,0,1,0,0,0,37,48,216,0,232,10,2,0,232,44,3,0,1,0,0,0,38,48,216,0,152,138,8,0,40,246,1,0,1,0,0,0,213,47,216,0,64,246,1,0,144,236,1,0,1,0,0,0,209,47,216,0,136,224,1,0,176,223,1,0,1,0,0,0,43,48,216,0,72,198,1,0,192,209,1,0,1,0,0,0,42,48,216,0,24,182,1,0,24,198,1,0,1,0,0,0,41,48,216,0,40,167,1,0,120,189,1,0,1,0,0,0,40,48,216,0,200,149,1,0,200,32,1,0,1,0,0,0,44,48,216,0,56,126,1,0,200,197,8,0,1,0,0,0,45,48,216,0,32,101,1,0,224,254,0,0,1,0,0,0,46,48,216,0,96,32,8,0,88,212,3,0,1,0,0,0,144,46,216,0,40,185,3,0,240,152,1,0,1,0,0,0,201,47,216,0,216,70,1,0,16,17,8,0,1,0,0,0,202,47,216,0,224,12,8,0,136,67,2,0,1,0,0,0,176,48,216,0,48,119,7,0,8,66,2,0,1,0,0,0,184,48,216,0,112,109,7,0,112,107,48,53,46,49,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,166,64,23,234,0,0,16,1,112,107,48,54,46,49,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,94,255,120,48,0,0,16,1,112,107,111,45,48,48,49,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,155,93,173,30,0,0,32,0,112,107,111,45,48,48,51,46,56,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,230,180,154,51,0,0,32,0,112,107,111,45,48,48,50,46,57,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,134,37,240,28,0,0,32,0,112,107,111,45,48,48,52,46,57,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,66,180,204,9,0,0,32,0,112,107,111,45,99,104,114,49,46,50,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,205,51,206,49,0,0,32,0,112,107,111,45,99,104,114,50,46,51,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,95,5,126,173,0,0,32,0,112,107,111,45,118,111,105,49,46,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,49,245,224,7,0,0,64,0,112,107,111,45,118,111,105,50,46,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,246,139,57,24,0,0,64,0,101,112,114,45,54,54,50,51,46,49,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,214,126,180,188,0,0,16,1,101,112,114,54,54,50,52,97,46,49,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,193,9,139,110,0,0,16,1,101,112,114,45,54,54,50,53,46,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,186,132,84,220,0,0,16,1,101,112,114,45,54,52,54,50,46,49,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,133,145,187,134,0,0,16,1,101,112,114,54,52,55,52,97,46,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,185,17,23,159,0,0,32,0,101,112,114,54,52,55,51,97,46,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,221,184,83,142,0,0,32,0,101,112,114,54,52,55,50,97,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,17,74,243,224,0,0,32,0,101,112,114,54,52,55,49,97,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,92,128,188,213,0,0,32,0,101,112,114,54,52,55,48,97,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,159,114,57,20,0,0,32,0,101,112,114,54,52,54,57,97,46,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,33,105,172,228,0,0,32,0,101,112,114,54,52,53,52,97,46,49,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,128,103,217,165,0,0,32,0,101,112,114,45,54,52,53,53,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,161,100,238,50,0,0,32,0,112,114,45,53,51,49,55,46,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,184,80,131,100,0,0,0,8,101,112,114,45,54,53,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,57,151,118,182,0,0,16,1,101,112,114,45,54,53,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,196,174,230,28,0,0,16,1,101,112,114,54,52,53,56,97,46,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,232,179,48,92,0,0,16,1,101,112,114,45,54,52,54,50,46,49,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,133,145,187,134,0,0,16,1,101,112,114,54,52,55,52,97,46,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,185,17,23,159,0,0,32,0,101,112,114,54,52,55,51,97,46,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,221,184,83,142,0,0,32,0,101,112,114,54,52,55,50,97,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,17,74,243,224,0,0,32,0,101,112,114,54,52,55,49,97,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,92,128,188,213,0,0,32,0,101,112,114,54,52,55,48,97,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,159,114,57,20,0,0,32,0,101,112,114,54,52,54,57,97,46,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,33,105,172,228,0,0,32,0,101,112,114,54,52,53,52,97,46,49,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,128,103,217,165,0,0,32,0,101,112,114,45,54,52,53,53,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,161,100,238,50,0,0,32,0,112,114,45,53,51,49,55,46,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,184,80,131,100,0,0,0,8,168,86,7,0,1,0,0,0,72,246,146,0,248,191,2,0,24,38,7,0,1,0,0,0,175,254,146,0,184,160,2,0,56,210,6,0,1,0,0,0,168,254,146,0,192,135,2,0,24,163,6,0,1,0,0,0,169,254,146,0,240,108,2,0,152,122,6,0,1,0,0,0,170,254,146,0,96,82,2,0,192,72,6,0,1,0,0,0,171,254,146,0,32,56,2,0,200,110,3,0,1,0,0,0,172,254,146,0,152,30,2,0,120,89,3,0,1,0,0,0,173,254,146,0,232,10,2,0,120,74,3,0,1,0,0,0,174,254,146,0,152,138,8,0,40,246,1,0,1,0,0,0,73,246,146,0,64,246,1,0,144,236,1,0,1,0,0,0,183,254,146,0,136,224,1,0,176,223,1,0,1,0,0,0,176,254,146,0,72,198,1,0,192,209,1,0,1,0,0,0,177,254,146,0,24,182,1,0,24,198,1,0,1,0,0,0,178,254,146,0,40,167,1,0,120,189,1,0,1,0,0,0,179,254,146,0,200,149,1,0,224,22,1,0,1,0,0,0,180,254,146,0,56,126,1,0,160,14,1,0,1,0,0,0,181,254,146,0,32,101,1,0,176,9,1,0,1,0,0,0,182,254,146,0,96,32,8,0,88,212,3,0,1,0,0,0,120,218,146,0,40,185,3,0,72,65,1,0,9,0,0,0,24,5,147,0,32,58,1,0,184,40,2,0,1,0,0,0,152,244,146,0,248,191,2,0,24,38,7,0,1,0,0,0,191,238,146,0,184,160,2,0,56,210,6,0,1,0,0,0,184,238,146,0,192,135,2,0,24,163,6,0,1,0,0,0,185,238,146,0,240,108,2,0,152,122,6,0,1,0,0,0,186,238,146,0,96,82,2,0,192,72,6,0,1,0,0,0,187,238,146,0,32,56,2,0,200,110,3,0,1,0,0,0,188,238,146,0,152,30,2,0,120,89,3,0,1,0,0,0,189,238,146,0,232,10,2,0,120,74,3,0,1,0,0,0,190,238,146,0,152,138,8,0,144,236,1,0,1,0,0,0,199,238,146,0,136,224,1,0,176,223,1,0,1,0,0,0,192,238,146,0,72,198,1,0,192,209,1,0,1,0,0,0,193,238,146,0,24,182,1,0,24,198,1,0,1,0,0,0,194,238,146,0,40,167,1,0,120,189,1,0,1,0,0,0,195,238,146,0,200,149,1,0,224,22,1,0,1,0,0,0,196,238,146,0,56,126,1,0,160,14,1,0,1,0,0,0,197,238,146,0,32,101,1,0,176,9,1,0,1,0,0,0,198,238,146,0,96,32,8,0,88,212,3,0,1,0,0,0,64,217,146,0,40,185,3,0,248,5,8,0,9,0,0,0,88,4,147,0,32,58,1,0,144,250,7,0,9,0,0,0,89,4,147,0,32,58,1,0,168,86,7,0,1,0,0,0,140,151,215,0,248,191,2,0,24,38,7,0,1,0,0,0,132,151,215,0,184,160,2,0,56,210,6,0,1,0,0,0,160,148,215,0,192,135,2,0,24,163,6,0,1,0,0,0,161,148,215,0,240,108,2,0,152,122,6,0,1,0,0,0,162,148,215,0,96,82,2,0,192,72,6,0,1,0,0,0,163,148,215,0,32,56,2,0,200,110,3,0,1,0,0,0,120,151,215,0,152,30,2,0,120,89,3,0,1,0,0,0,121,151,215,0,232,10,2,0,120,74,3,0,1,0,0,0,122,151,215,0,152,138,8,0,40,246,1,0,1,0,0,0,141,151,215,0,64,246,1,0,144,236,1,0,1,0,0,0,133,151,215,0,136,224,1,0,176,223,1,0,1,0,0,0,164,148,215,0,72,198,1,0,192,209,1,0,1,0,0,0,165,148,215,0,24,182,1,0,24,198,1,0,1,0,0,0,166,148,215,0,40,167,1,0,120,189,1,0,1,0,0,0,167,148,215,0,200,149,1,0,224,22,1,0,1,0,0,0,124,151,215,0,56,126,1,0,160,14,1,0,1,0,0,0,125,151,215,0,32,101,1,0,176,9,1,0,1,0,0,0,126,151,215,0,96,32,8,0,168,132,8,0,1,0,0,0,142,151,215,0,232,209,1,0,72,126,8,0,1,0,0,0,134,151,215,0,144,189,1,0,192,122,8,0,1,0,0,0,136,148,215,0,208,174,1,0,40,116,8,0,1,0,0,0,137,148,215,0,48,160,1,0,72,110,8,0,1,0,0,0,138,148,215,0,160,140,1,0,184,102,8,0,1,0,0,0,139,148,215,0,56,112,1,0,248,67,8,0,1,0,0,0,152,148,215,0,32,92,1,0,136,64,8,0,1,0,0,0,153,148,215,0,64,77,1,0,128,58,8,0,1,0,0,0,154,148,215,0,112,157,4,0,232,23,8,0,1,0,0,0,143,151,215,0,104,195,5,0,160,19,8,0,1,0,0,0,135,151,215,0,32,245,8,0,248,16,8,0,1,0,0,0,140,148,215,0,32,231,8,0,192,12,8,0,1,0,0,0,141,148,215,0,88,214,8,0,224,5,8,0,1,0,0,0,142,148,215,0,224,202,8,0,144,1,8,0,1,0,0,0,143,148,215,0,72,193,8,0,176,222,7,0,1,0,0,0,156,148,215,0,144,180,8,0,176,218,7,0,1,0,0,0,157,148,215,0,208,164,8,0,248,214,7,0,1,0,0,0,158,148,215,0,160,152,4,0,88,212,3,0,1,0,0,0,200,147,215,0,40,185,3,0,16,17,8,0,1,0,0,0,129,151,215,0,224,12,8,0,16,17,8,0,1,0,0,0,130,151,215,0,224,12,8,0,16,17,8,0,1,0,0,0,131,151,215,0,224,12,8,0,56,58,1,0,1,0,0,0,128,151,215,0,64,50,1,0,72,65,1,0,9,0,0,0,152,151,215,0,32,58,1,0,184,40,2,0,1,0,0,0,208,155,215,0,248,191,2,0,56,250,6,0,1,0,0,0,212,155,215,0,184,160,2,0,184,164,8,0,1,0,0,0,209,155,215,0,64,246,1,0,88,149,7,0,1,0,0,0,213,155,215,0,136,224,1,0,248,23,7,0,1,0,0,0,214,155,215,0,144,189,1,0,48,19,7,0,1,0,0,0,215,155,215,0,32,245,8,0,56,210,6,0,1,0,0,0,201,155,215,0,192,135,2,0,24,163,6,0,1,0,0,0,200,155,215,0,240,108,2,0,152,122,6,0,1,0,0,0,203,155,215,0,96,82,2,0,192,72,6,0,1,0,0,0,202,155,215,0,32,56,2,0,48,123,2,0,1,0,0,0,204,155,215,0,152,30,2,0,96,69,2,0,1,0,0,0,205,155,215,0,232,10,2,0,144,55,2,0,1,0,0,0,206,155,215,0,152,138,8,0,80,123,7,0,1,0,0,0,207,155,215,0,48,119,7,0,176,223,1,0,1,0,0,0,193,155,215,0,72,198,1,0,192,209,1,0,1,0,0,0,192,155,215,0,24,182,1,0,24,198,1,0,1,0,0,0,195,155,215,0,40,167,1,0,120,189,1,0,1,0,0,0,194,155,215,0,200,149,1,0,248,187,8,0,1,0,0,0,196,155,215,0,56,126,1,0,184,179,8,0,1,0,0,0,197,155,215,0,32,101,1,0,240,173,8,0,1,0,0,0,198,155,215,0,96,32,8,0,208,72,7,0,1,0,0,0,199,155,215,0,16,68,7,0,192,122,8,0,1,0,0,0,185,155,215,0,208,174,1,0,40,116,8,0,1,0,0,0,184,155,215,0,48,160,1,0,72,110,8,0,1,0,0,0,187,155,215,0,160,140,1,0,184,102,8,0,1,0,0,0,186,155,215,0,56,112,1,0,240,45,8,0,1,0,0,0,188,155,215,0,32,92,1,0,40,38,8,0,1,0,0,0,189,155,215,0,64,77,1,0,48,32,8,0,1,0,0,0,190,155,215,0,112,157,4,0,144,64,3,0,1,0,0,0,191,155,215,0,176,194,6,0,248,16,8,0,1,0,0,0,177,155,215,0,32,231,8,0,192,12,8,0,1,0,0,0,176,155,215,0,88,214,8,0,224,5,8,0,1,0,0,0,179,155,215,0,224,202,8,0,144,1,8,0,1,0,0,0,178,155,215,0,72,193,8,0,72,204,7,0,1,0,0,0,180,155,215,0,144,180,8,0,208,196,7,0,1,0,0,0,181,155,215,0,208,164,8,0,248,189,7,0,1,0,0,0,182,155,215,0,160,152,4,0,152,38,3,0,1,0,0,0,183,155,215,0,40,184,6,0,16,17,8,0,1,0,0,0,211,155,215,0,224,12,8,0,32,77,1,0,1,0,0,0,210,155,215,0,216,70,1,0,88,212,3,0,1,0,0,0,200,154,215,0,40,185,3,0,248,5,8,0,9,0,0,0,0,156,215,0,32,58,1,0,144,250,7,0,9,0,0,0,1,156,215,0,32,58,1,0,114,111,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,103,249,228,117,1,0,16,1,114,111,109,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,147,66,46,91,1,0,16,1,114,111,109,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,164,48,110,192,1,0,16,1,114,111,109,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,168,75,43,89,1,0,16,1,114,111,109,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,30,192,216,242,4,0,32,0,114,111,109,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,32,23,106,52,4,0,32,0,115,110,55,52,115,50,56,56,110,46,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,196,43,101,36,7,0,32,0,168,86,7,0,1,0,0,0,122,0,147,0,248,191,2,0,24,38,7,0,1,0,0,0,124,0,147,0,184,160,2,0,152,122,6,0,1,0,0,0,228,247,146,0,96,82,2,0,192,72,6,0,1,0,0,0,229,247,146,0,32,56,2,0,200,110,3,0,1,0,0,0,227,247,146,0,152,30,2,0,40,246,1,0,1,0,0,0,123,0,147,0,64,246,1,0,144,236,1,0,1,0,0,0,125,0,147,0,136,224,1,0,24,198,1,0,1,0,0,0,231,247,146,0,40,167,1,0,120,189,1,0,1,0,0,0,120,0,147,0,200,149,1,0,224,22,1,0,1,0,0,0,230,247,146,0,56,126,1,0,88,212,3,0,1,0,0,0,176,219,146,0,40,185,3,0,16,17,8,0,1,0,0,0,121,0,147,0,224,12,8,0,72,65,1,0,9,0,0,0,232,5,147,0,32,58,1,0,48,50,1,0,9,0,0,0,233,5,147,0,32,58,1,0,224,41,1,0,9,0,0,0,234,5,147,0,32,58,1,0,98,54,55,45,50,48,45,49,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,59,69,26,133,2,0,16,1,98,54,55,45,50,50,45,49,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,192,13,72,25,2,0,16,1,98,54,55,45,49,52,46,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,36,215,61,127,2,0,16,1,98,54,55,45,49,53,46,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,208,98,79,232,2,0,16,1,98,54,55,45,49,51,46,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,177,180,54,41,9,0,16,1,98,54,55,45,48,54,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,100,141,163,185,11,0,32,0,98,54,55,45,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,203,154,173,129,17,0,32,0,98,54,55,45,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,251,210,12,194,17,0,32,0,98,54,55,45,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,237,25,144,188,17,0,32,0,98,54,55,45,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,175,200,244,42,17,0,32,0,98,54,55,45,48,53,46,52,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,43,228,147,149,23,0,32,0,98,54,55,45,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,251,65,143,69,24,0,64,0,98,54,55,45,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,87,67,131,79,25,0,64,0,101,101,112,114,111,109,45,111,116,104,117,110,100,101,114,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,68,184,41,55,32,0,16,0,112,108,104,115,49,56,112,56,98,45,98,54,55,45,48,57,46,105,99,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,73,1,0,0,135,84,3,98,0,0,0,8])
.concat([112,97,108,49,54,108,56,97,45,98,54,55,45,49,49,46,105,99,51,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,6,251,119,49,0,0,0,8,112,97,108,50,48,108,56,98,45,98,54,55,45,49,50,46,105,99,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,1,0,0,152,39,124,164,0,0,0,8,112,97,108,50,48,108,56,98,45,98,54,55,45,49,48,46,105,99,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,1,0,0,199,9,237,76,0,0,0,8,14,0,0,0,255,255,255,0,0,0,0,0,15,0,0,0,255,255,127,0,0,0,0,0,16,0,0,0,255,255,7,0,0,0,0,0,0,0,0,0,254,0,2,0,104,159,3,0,14,0,0,0,1,2,0,0,96,135,7,0,14,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,14,0,0,0,1,4,4,0,96,135,7,0,14,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,14,0,0,0,1,8,0,0,96,135,7,0,14,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,14,0,0,0,1,48,16,0,104,236,7,0,14,0,0,0,1,48,48,0,128,230,7,0,14,0,0,0,1,48,0,0,120,211,6,0,14,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,14,0,0,0,1,192,64,0,104,236,7,0,14,0,0,0,1,192,192,0,128,230,7,0,14,0,0,0,1,192,0,0,120,211,6,0,14,0,0,0,1,192,128,0,184,164,6,0,0,0,0,0,254,0,4,0,72,202,5,0,15,0,0,0,1,3,2,0,80,246,3,0,15,0,0,0,1,3,3,0,80,124,6,0,15,0,0,0,1,3,1,0,112,212,3,0,15,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,24,100,5,0,15,0,0,0,1,12,12,0,80,69,5,0,15,0,0,0,1,12,8,0,72,38,5,0,15,0,0,0,1,12,4,0,112,8,5,0,15,0,0,0,1,12,0,0,192,228,4,0,0,0,0,0,254,0,4,0,200,192,4,0,15,0,0,0,1,48,0,0,192,160,4,0,15,0,0,0,1,48,16,0,0,71,4,0,15,0,0,0,1,48,48,0,200,68,4,0,15,0,0,0,1,48,32,0,136,66,4,0,0,0,0,0,254,0,2,0,48,112,3,0,15,0,0,0,1,64,0,0,80,245,6,0,15,0,0,0,1,64,64,0,80,75,3,0,0,0,0,0,254,0,2,0,144,212,8,0,15,0,0,0,1,128,0,0,168,22,4,0,15,0,0,0,1,128,128,0,224,247,3,0,0,0,0,0,254,0,4,0,0,214,3,0,16,0,0,0,1,7,7,0,32,186,3,0,16,0,0,0,1,7,3,0,64,111,3,0,16,0,0,0,1,7,1,0,80,124,6,0,16,0,0,0,1,7,0,0,112,134,3,0,98,54,55,45,50,48,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,162,158,67,33,2,0,16,1,98,54,55,45,50,49,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,134,252,144,150,2,0,16,1,98,54,55,45,49,52,46,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,36,215,61,127,2,0,16,1,98,54,55,45,49,53,46,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,208,98,79,232,2,0,16,1,98,54,55,45,49,51,46,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,177,180,54,41,9,0,16,1,98,54,55,45,48,54,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,100,141,163,185,11,0,32,0,98,54,55,45,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,203,154,173,129,17,0,32,0,98,54,55,45,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,251,210,12,194,17,0,32,0,98,54,55,45,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,237,25,144,188,17,0,32,0,98,54,55,45,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,175,200,244,42,17,0,32,0,98,54,55,45,48,53,46,52,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,43,228,147,149,23,0,32,0,98,54,55,45,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,251,65,143,69,24,0,64,0,98,54,55,45,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,87,67,131,79,25,0,64,0,101,101,112,114,111,109,45,111,116,104,117,110,100,101,114,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,68,184,41,55,32,0,16,0,112,108,104,115,49,56,112,56,98,45,98,54,55,45,48,57,46,105,99,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,73,1,0,0,135,84,3,98,0,0,0,8,112,97,108,49,54,108,56,97,45,98,54,55,45,49,49,46,105,99,51,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,6,251,119,49,0,0,0,8,112,97,108,50,48,108,56,98,45,98,54,55,45,49,50,46,105,99,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,1,0,0,152,39,124,164,0,0,0,8,112,97,108,50,48,108,56,98,45,98,54,55,45,49,48,46,105,99,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,1,0,0,199,9,237,76,0,0,0,8,14,0,0,0,255,255,255,0,0,0,0,0,15,0,0,0,255,255,127,0,0,0,0,0,16,0,0,0,255,255,7,0,0,0,0,0,0,0,0,0,254,0,2,0,104,159,3,0,14,0,0,0,1,2,0,0,96,135,7,0,14,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,14,0,0,0,1,4,4,0,96,135,7,0,14,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,14,0,0,0,1,8,0,0,96,135,7,0,14,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,14,0,0,0,1,48,16,0,104,236,7,0,14,0,0,0,1,48,48,0,128,230,7,0,14,0,0,0,1,48,0,0,120,211,6,0,14,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,14,0,0,0,1,192,64,0,104,236,7,0,14,0,0,0,1,192,192,0,128,230,7,0,14,0,0,0,1,192,0,0,120,211,6,0,14,0,0,0,1,192,128,0,184,164,6,0,0,0,0,0,254,0,4,0,72,202,5,0,15,0,0,0,1,3,2,0,80,246,3,0,15,0,0,0,1,3,3,0,80,124,6,0,15,0,0,0,1,3,1,0,112,212,3,0,15,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,24,100,5,0,15,0,0,0,1,12,12,0,80,69,5,0,15,0,0,0,1,12,8,0,72,38,5,0,15,0,0,0,1,12,4,0,112,8,5,0,15,0,0,0,1,12,0,0,192,228,4,0,0,0,0,0,254,0,4,0,200,192,4,0,15,0,0,0,1,48,0,0,192,160,4,0,15,0,0,0,1,48,16,0,0,71,4,0,15,0,0,0,1,48,48,0,200,68,4,0,15,0,0,0,1,48,32,0,136,66,4,0,0,0,0,0,254,0,2,0,144,212,8,0,15,0,0,0,1,128,0,0,168,22,4,0,15,0,0,0,1,128,128,0,224,247,3,0,0,0,0,0,254,0,4,0,0,214,3,0,16,0,0,0,1,7,7,0,32,186,3,0,16,0,0,0,1,7,3,0,64,111,3,0,16,0,0,0,1,7,1,0,80,124,6,0,16,0,0,0,1,7,0,0,112,134,3,0,0,0,0,0,184,40,2,0,1,0,0,0,228,150,215,0,248,191,2,0,56,250,6,0,1,0,0,0,218,150,215,0,184,160,2,0,184,164,8,0,1,0,0,0,229,150,215,0,64,246,1,0,88,149,7,0,1,0,0,0,222,150,215,0,136,224,1,0,104,28,8,0,1,0,0,0,230,150,215,0,232,209,1,0,64,183,7,0,1,0,0,0,231,150,215,0,104,195,5,0,152,225,1,0,4,0,0,0,104,150,215,0,152,210,1,0,152,198,1,0,4,0,0,0,96,150,215,0,208,189,1,0,48,123,2,0,1,0,0,0,216,150,215,0,248,174,1,0,96,69,2,0,1,0,0,0,217,150,215,0,104,160,1,0,88,150,1,0,4,0,0,0,88,150,215,0,136,7,4,0,144,126,1,0,4,0,0,0,80,150,215,0,136,113,1,0,248,187,8,0,1,0,0,0,220,150,215,0,56,126,1,0,184,179,8,0,1,0,0,0,221,150,215,0,32,101,1,0,88,212,3,0,1,0,0,0,200,147,215,0,40,185,3,0,16,17,8,0,1,0,0,0,208,150,215,0,224,12,8,0,56,58,1,0,1,0,0,0,225,150,215,0,64,50,1,0,248,5,8,0,9,0,0,0,96,149,215,0,32,58,1,0,184,40,2,0,1,0,0,0,80,94,148,0,248,191,2,0,56,250,6,0,1,0,0,0,79,94,148,0,184,160,2,0,184,164,8,0,1,0,0,0,64,94,148,0,64,246,1,0,88,149,7,0,1,0,0,0,63,94,148,0,136,224,1,0,56,210,6,0,1,0,0,0,72,94,148,0,192,135,2,0,24,163,6,0,1,0,0,0,73,94,148,0,240,108,2,0,152,122,6,0,1,0,0,0,74,94,148,0,96,82,2,0,192,72,6,0,1,0,0,0,75,94,148,0,32,56,2,0,48,123,2,0,1,0,0,0,76,94,148,0,152,30,2,0,176,223,1,0,1,0,0,0,56,94,148,0,72,198,1,0,192,209,1,0,1,0,0,0,57,94,148,0,24,182,1,0,24,198,1,0,1,0,0,0,58,94,148,0,40,167,1,0,120,189,1,0,1,0,0,0,59,94,148,0,200,149,1,0,248,187,8,0,1,0,0,0,60,94,148,0,56,126,1,0,88,212,3,0,1,0,0,0,112,27,149,0,40,185,3,0,16,17,8,0,1,0,0,0,65,94,148,0,224,12,8,0,240,152,1,0,1,0,0,0,81,94,148,0,216,70,1,0,248,5,8,0,9,0,0,0,168,100,215,0,32,58,1,0,144,250,7,0,9,0,0,0,169,100,215,0,32,58,1,0,101,112,114,45,54,53,55,51,46,49,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,125,156,145,210,0,0,16,1,101,112,114,45,54,53,55,52,46,49,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,51,40,19,90,0,0,16,1,101,112,114,45,54,53,55,53,46,49,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,212,11,75,169,0,0,16,1,101,112,114,45,54,53,55,54,46,49,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,219,187,211,39,0,0,16,1,101,112,114,45,54,53,55,55,46,49,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,3,110,97,115,0,0,16,1,101,112,114,45,54,53,55,56,46,49,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,159,73,104,171,0,0,16,1,101,112,114,45,54,53,53,57,46,49,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,238,112,21,90,0,0,16,1,101,112,114,45,54,53,53,56,46,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,235,234,249,42,0,0,32,0,101,112,114,45,54,53,53,55,46,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,208,49,177,110,0,0,32,0,101,112,114,45,54,53,53,54,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,247,38,253,121,0,0,32,0,101,112,114,45,54,53,53,53,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,172,154,102,127,0,0,32,0,101,112,114,45,54,53,53,52,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,5,210,201,90,0,0,32,0,101,112,114,45,54,53,53,51,46,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,254,168,130,235,0,0,32,0,101,112,114,45,54,53,52,54,46,49,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,146,86,120,164,0,0,32,0,101,112,114,45,54,53,52,56,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,193,120,242,189,0,0,32,0,101,112,114,45,54,53,52,55,46,49,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,8,27,69,52,0,0,32,0,101,112,114,45,54,53,52,57,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,104,118,5,210,0,0,32,0,112,114,45,53,51,49,55,46,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,184,80,131,100,0,0,0,8,101,112,114,45,54,53,53,48,46,49,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,241,89,109,95,0,0,16,1,101,112,114,45,54,53,53,49,46,49,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,178,51,241,26,0,0,16,1,101,112,114,45,54,53,53,50,46,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,216,176,238,242,0,0,16,1,101,112,114,45,54,53,53,57,46,49,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,238,112,21,90,0,0,16,1,101,112,114,45,54,53,53,56,46,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,235,234,249,42,0,0,32,0,101,112,114,45,54,53,53,55,46,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,208,49,177,110,0,0,32,0,101,112,114,45,54,53,53,54,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,247,38,253,121,0,0,32,0,101,112,114,45,54,53,53,53,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,172,154,102,127,0,0,32,0,101,112,114,45,54,53,53,52,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,5,210,201,90,0,0,32,0,101,112,114,45,54,53,53,51,46,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,254,168,130,235,0,0,32,0,101,112,114,45,54,53,52,54,46,49,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,146,86,120,164,0,0,32,0,101,112,114,45,54,53,52,56,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,193,120,242,189,0,0,32,0,101,112,114,45,54,53,52,55,46,49,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,8,27,69,52,0,0,32,0,101,112,114,45,54,53,52,57,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,104,118,5,210,0,0,32,0,112,114,45,53,51,49,55,46,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,184,80,131,100,0,0,0,8,110,112,114,105,110,99,101,115,46,48,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,60,7,222,224,0,0,16,1,110,112,114,105,110,99,101,115,46,48,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,127,156,33,39,0,0,16,1,101,112,114,45,54,53,53,50,46,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,216,176,238,242,0,0,16,1,101,112,114,45,54,53,53,57,46,49,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,238,112,21,90,0,0,16,1,101,112,114,45,54,53,53,56,46,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,235,234,249,42,0,0,32,0,101,112,114,45,54,53,53,55,46,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,208,49,177,110,0,0,32,0,101,112,114,45,54,53,53,54,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,247,38,253,121,0,0,32,0,101,112,114,45,54,53,53,53,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,172,154,102,127,0,0,32,0,101,112,114,45,54,53,53,52,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,5,210,201,90,0,0,32,0,101,112,114,45,54,53,53,51,46,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,254,168,130,235,0,0,32,0,101,112,114,45,54,53,52,54,46,49,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,146,86,120,164,0,0,32,0,101,112,114,45,54,53,52,56,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,193,120,242,189,0,0,32,0,101,112,114,45,54,53,52,55,46,49,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,8,27,69,52,0,0,32,0,101,112,114,45,54,53,52,57,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,104,118,5,210,0,0,32,0,112,114,45,53,51,49,55,46,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,184,80,131,100,0,0,0,8,110,112,114,105,110,99,101,115,46,49,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,98,95,118,174,0,0,16,0,110,112,114,105,110,99,101,115,46,49,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,233,70,81,237,0,0,16,0,49,57,120,106,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,237,129,163,38,1,0,16,1,49,57,120,106,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,202,12,16,48,1,0,16,1,49,57,120,106,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,56,233,103,222,1,0,16,1,49,57,120,106,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,9,164,249,57,1,0,16,1,49,57,120,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,108,41,192,97,1,0,16,1,49,57,120,46,49,51,109,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,235,122,66,5,0,32,0,49,57,120,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,84,191,189,99,5,0,32,0,49,57,120,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,24,254,45,5,0,32,0,49,57,120,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,121,149,239,203,5,0,32,0,49,57,120,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,124,150,22,233,5,0,32,0,49,57,120,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,219,243,117,110,5,0,32,0,49,57,120,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,152,231,19,34,5,0,32,0,49,57,120,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,150,91,157,171,5,0,32,0,49,57,120,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,94,25,85,239,10,0,16,1,49,57,120,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,243,238,139,211,12,0,64,0,49,57,120,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,226,150,124,212,12,0,64,0,98,57,49,45,52,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,33,52,214,122,2,0,16,1,98,57,49,45,52,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,223,10,195,75,2,0,16,1,98,57,49,45,52,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,122,114,111,62,2,0,16,1,98,57,49,45,52,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,149,190,112,232,2,0,16,1,98,57,49,45,51,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,174,35,91,114,6,0,16,1,98,57,49,45,52,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,77,54,251,129,6,0,16,1,98,57,49,45,52,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,66,187,148,38,9,0,16,1,98,57,49,45,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,49,206,248,255,11,0,32,0,98,57,49,45,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,13,151,161,140,17,0,32,0,98,57,49,45,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,57,237,95,205,17,0,32,0,98,57,49,45,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,184,100,124,69,17,0,32,0,98,57,49,45,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,79,217,49,55,17,0,32,0,98,57,49,45,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,52,92,243,102,21,0,32,0,98,57,49,45,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,207,198,142,77,21,0,32,0,98,57,49,45,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,57,200,77,163,21,0,32,0,98,57,49,45,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,144,172,114,94,21,0,32,0,98,57,49,45,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,180,5,143,29,22,0,32,0,98,57,49,45,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,162,124,36,95,23,0,32,0,98,57,49,45,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,245,240,123,140,24,0,64,0,98,57,49,45,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,175,199,119,218,24,0,64,0,98,57,49,45,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,211,20,195,107,25,0,64,0,98,57,49,45,50,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,79,42,104,119,0,0,0,8,98,57,49,45,50,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,13,73,248,163,0,0,0,8,98,57,49,45,50,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,14,132,47,250,0,0,0,8,98,57,49,45,50,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,232,91,104,173,0,0,0,8,98,57,49,45,51,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,121,31,204,48,0,0,0,8,98,57,49,45,51,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,28,120,137,193,0,0,0,8,98,57,49,45,51,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,48,31,248,251,0,0,0,8,98,57,49,45,51,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,23,157,113,137,0,0,0,8,11,0,0,0,255,255,254,0,0,0,0,0,12,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,11,0,0,0,1,1,1,0,80,46,8,0,11,0,0,0,1,1,0,0,120,97,1,0,0,0,0,0,254,0,2,0,232,75,4,0,11,0,0,0,1,4,4,0,96,135,7,0,11,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,11,0,0,0,1,8,0,0,96,135,7,0,11,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,32,4,2,0,11,0,0,0,1,48,0,0,80,252,6,0,11,0,0,0,1,48,16,0,16,242,7,0,11,0,0,0,1,48,32,0,104,236,7,0,11,0,0,0,1,48,48,0,128,230,7,0,0,0,0,0,254,0,4,0,168,248,6,0,11,0,0,0,1,192,0,0,16,242,7,0,11,0,0,0,1,192,64,0,104,236,7,0,11,0,0,0,1,192,128,0,128,230,7,0,11,0,0,0,1,192,192,0,80,75,3,0,0,0,0,0,254,0,4,0,72,202,5,0,12,0,0,0,1,3,2,0,80,246,3,0,12,0,0,0,1,3,3,0,248,38,7,0,12,0,0,0,1,3,1,0,112,212,3,0,12,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,128,52,7,0,12,0,0,0,1,12,8,0,8,49,4,0,12,0,0,0,1,12,4,0,208,75,4,0,12,0,0,0,1,12,12,0,192,255,2,0,12,0,0,0,1,12,0,0,120,7,5,0,0,0,0,0,254,0,4,0,192,99,6,0,12,0,0,0,1,48,0,0,8,49,4,0,12,0,0,0,1,48,16,0,152,21,4,0,12,0,0,0,1,48,48,0,72,246,3,0,12,0,0,0,1,48,32,0,72,0,3,0,0,0,0,0,254,0,2,0,104,159,3,0,12,0,0,0,1,64,0,0,96,135,7,0,12,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,16,24,7,0,12,0,0,0,1,128,128,0,72,19,7,0,12,0,0,0,1,128,0,0,88,14,7,0,98,57,49,45,52,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,33,52,214,122,2,0,16,1,98,57,49,45,52,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,223,10,195,75,2,0,16,1,98,57,49,45,52,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,122,114,111,62,2,0,16,1,98,57,49,45,52,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,47,239,121,113,2,0,16,1,98,57,49,45,51,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,174,35,91,114,6,0,16,1,98,57,49,45,52,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,77,54,251,129,6,0,16,1,98,57,49,45,52,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,66,187,148,38,9,0,16,1,98,57,49,45,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,49,206,248,255,11,0,32,0,98,57,49,45,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,13,151,161,140,17,0,32,0,98,57,49,45,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,57,237,95,205,17,0,32,0,98,57,49,45,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,184,100,124,69,17,0,32,0,98,57,49,45,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,79,217,49,55,17,0,32,0,98,57,49,45,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,52,92,243,102,21,0,32,0,98,57,49,45,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,207,198,142,77,21,0,32,0,98,57,49,45,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,57,200,77,163,21,0,32,0,98,57,49,45,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,144,172,114,94,21,0,32,0,98,57,49,45,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,180,5,143,29,22,0,32,0,98,57,49,45,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,162,124,36,95,23,0,32,0,98,57,49,45,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,245,240,123,140,24,0,64,0,98,57,49,45,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,175,199,119,218,24,0,64,0,98,57,49,45,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,211,20,195,107,25,0,64,0,98,57,49,45,50,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,79,42,104,119,0,0,0,8,98,57,49,45,50,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,13,73,248,163,0,0,0,8,98,57,49,45,50,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,14,132,47,250,0,0,0,8,98,57,49,45,50,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,232,91,104,173,0,0,0,8,98,57,49,45,51,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,121,31,204,48,0,0,0,8,98,57,49,45,51,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,28,120,137,193,0,0,0,8,98,57,49,45,51,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,48,31,248,251,0,0,0,8,98,57,49,45,51,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,23,157,113,137,0,0,0,8,11,0,0,0,255,255,254,0,0,0,0,0,12,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,11,0,0,0,1,1,1,0,80,46,8,0,11,0,0,0,1,1,0,0,120,97,1,0,0,0,0,0,254,0,2,0,232,75,4,0,11,0,0,0,1,4,4,0,96,135,7,0,11,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,11,0,0,0,1,8,0,0,96,135,7,0,11,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,11,0,0,0,1,48,16,0,104,236,7,0,11,0,0,0,1,48,48,0,128,230,7,0,11,0,0,0,1,48,0,0,120,211,6,0,11,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,11,0,0,0,1,192,64,0,104,236,7,0,11,0,0,0,1,192,192,0,128,230,7,0,11,0,0,0,1,192,0,0,120,211,6,0,11,0,0,0,1,192,128,0,184,164,6,0,0,0,0,0,254,0,4,0,72,202,5,0,12,0,0,0,1,3,2,0,80,246,3,0,12,0,0,0,1,3,3,0,248,38,7,0,12,0,0,0,1,3,1,0,112,212,3,0,12,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,128,52,7,0,12,0,0,0,1,12,8,0,8,49,4,0,12,0,0,0,1,12,4,0,208,75,4,0,12,0,0,0,1,12,12,0,192,255,2,0,12,0,0,0,1,12,0,0,120,7,5,0,0,0,0,0,254,0,4,0,192,99,6,0,12,0,0,0,1,48,0,0,8,49,4,0,12,0,0,0,1,48,16,0,152,21,4,0,12,0,0,0,1,48,48,0,72,246,3,0,12,0,0,0,1,48,32,0,72,0,3,0,0,0,0,0,254,0,2,0,104,159,3,0,12,0,0,0,1,64,0,0,96,135,7,0,12,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,16,24,7,0,12,0,0,0,1,128,128,0,72,19,7,0,12,0,0,0,1,128,0,0,88,14,7,0,52,49,101,95,51,48,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,117,30,235,157,1,0,16,1,52,49,101,95,51,53,46,49,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,179,66,57,214,1,0,16,1,52,49,101,95,51,49,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,18,17,32,223,1,0,16,1,52,49,101,95,51,54,46,49,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,143,129,106,129,1,0,16,1,52,49,45,51,50,109,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,202,72,150,78,2,0,16,1,52,49,45,53,109,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,17,203,209,1,4,0,32,0,52,49,45,55,109,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,9,53,170,174,4,0,32,0,52,49,45,49,109,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,90,152,119,255,4,0,32,0,52,49,45,51,109,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,143,229,59,152,4,0,32,0,52,49,95,57,46,49,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,39,133,157,15,3,0,16,0,52,49,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,235,90,241,209,5,0,64,0,52,49,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,166,195,174,21,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,121,105,50,52,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,223,220,4,48,0,0,0,8,105,111,98,49,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,109,118,99,95,106,97,46,115,105,109,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,194,247,46,106,2,0,16,1,109,118,99,95,106,97,46,115,105,109,109,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,173,9,157,105,2,0,16,1,109,118,99,54,52,45,49,51,109,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,105,206,40,132,5,0,32,0,109,118,99,54,52,45,49,53,109,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,244,40,0,46,5,0,32,0,109,118,99,54,52,45,49,55,109,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,38,168,140,48,5,0,32,0,109,118,99,54,52,45,49,57,109,46,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,225,159,105,16,5,0,32,0,109,118,99,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,149,158,98,65,10,0,16,1,109,118,99,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,107,191,58,150,10,0,16,1,109,118,99,54,52,45,49,49,109,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,224,25,136,93,12,0,64,0,109,118,115,117,95,100,46,48,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,227,190,136,28,1,0,16,1,109,118,115,117,95,100,46,48,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,53,37,139,30,1,0,16,1,109,118,115,95,100,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,251,86,56,55,1,0,16,1,109,118,115,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,48,48,159,149,1,0,16,1,109,118,115,46,48,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,219,91,145,127,1,0,16,1,109,118,115,46,48,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,132,56,129,194,1,0,16,1,109,118,115,46,48,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,136,160,59,1,0,16,1,109,118,115,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,152,186,13,207,1,0,16,1,109,118,115,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,217,95,176,41,5,0,32,0,109,118,115,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,241,204,221,250,5,0,32,0,109,118,115,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,199,244,170,151,5,0,32,0,109,118,115,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,21,233,112,203,5,0,32,0,109,118,115,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,45,151,177,179,5,0,32,0,109,118,115,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,93,219,170,8,5,0,32,0,109,118,115,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,53,139,34,193,5,0,32,0,109,118,115,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,194,198,108,54,5,0,32,0,109,118,115,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,36,35,37,104,10,0,16,1,109,118,115,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,61,119,78,179,10,0,16,1,109,118,115,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,112,151,33,134,12,0,64,0,109,118,115,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,104,127,253,242,12,0,64,0,109,99,115,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,180,146,162,165,1,0,16,1,109,99,115,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,158,15,220,172,1,0,16,1,109,99,115,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,216,245,227,193,1,0,16,1,109,99,115,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,3,119,87,20,1,0,16,1,109,99,115,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,114,103,212,39,1,0,16,1,109,121,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,128,179,1,54,4,0,32,0,109,121,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,50,233,89,182,4,0,32,0,109,121,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,205,6,43,153,4,0,32,0,109,121,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,206,230,96,216,4,0,32,0,109,115,99,112,114,111,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,240,26,13,234,7,0,32,0,109,121,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,32,41,42,82,0,0,64,8,109,121,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,17,215,45,109,0,0,64,8,109,121,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,241,74,87,131,1,0,16,1,109,121,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,200,226,250,28,1,0,16,1,109,121,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,104,163,184,200,1,0,16,1,109,121,48,50,40,95,95,109,115,104,117,116,116,108,101,50,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,28,6,4,152,1,0,16,1,109,121,48,49,40,95,95,109,115,104,117,116,116,108,101,50,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,97,106,116,202,1,0,16,1,109,121,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,128,179,1,54,4,0,32,0,109,121,49,49,40,95,95,109,115,104,117,116,116,108,101,50,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,206,230,96,216,4,0,32,0,109,121,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,205,6,43,153,4,0,32,0,109,121,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,206,230,96,216,4,0,32,0,109,115,99,112,114,111,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,240,26,13,234,7,0,32,0,109,121,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,32,41,42,82,0,0,64,8,109,121,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,17,215,45,109,0,0,64,8,101,112,114,45,53,55,53,49,46,49,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,197,164,151,174,0,0,16,1,101,112,114,45,53,55,53,50,46,49,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,38,103,142,212,0,0,16,1,101,112,114,45,53,55,53,51,46,49,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,135,8,198,40,0,0,16,1,101,112,114,45,53,55,53,52,46,49,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,2,237,71,31,0,0,16,1,101,112,114,45,53,55,53,53,46,49,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,225,42,214,237,0,0,16,1,101,112,114,45,53,55,53,54,46,49,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,64,64,151,17,0,0,16,1,101,112,114,45,53,55,54,51,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,13,40,18,215,0,0,16,1,101,112,114,45,53,55,54,50,46,56,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,138,208,145,74,0,0,32,0,101,112,114,45,53,55,54,49,46,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,101,27,214,247,0,0,32,0,101,112,114,45,53,55,54,48,46,56,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,32,88,4,149,0,0,32,0,101,112,114,45,53,55,53,57,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,78,174,155,95,0,0,32,0,101,112,114,45,53,55,53,56,46,56,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,6,231,142,128,0,0,32,0,101,112,114,45,53,55,53,55,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,116,112,15,72,0,0,32,0,101,112,114,45,53,55,52,57,46,56,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,205,130,70,226,0,0,32,0,101,112,114,45,53,55,53,48,46,57,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,173,209,100,101,0,0,32,0,112,114,45,53,51,49,55,46,49,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,184,80,131,100,0,0,0,8,97,116,119,45,55,108,45,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,152,177,52,123,1,0,16,1,97,116,119,45,55,107,45,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,199,35,202,251,1,0,16,1,97,116,119,45,55,104,45,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,162,87,178,5,1,0,16,1,97,116,119,45,54,119,45,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,113,163,66,175,2,0,16,1,97,116,119,45,54,121,45,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,2,137,43,134,2,0,16,1,97,116,119,45,54,122,45,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,200,108,57,160,2,0,16,1,97,116,119,45,49,104,45,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,99,251,253,56,4,0,32,0,97,116,119,45,112,114,111,109,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,136,177,93,198,7,0,32,0,184,40,2,0,1,0,0,0,47,39,216,0,248,191,2,0,56,250,6,0,1,0,0,0,34,39,216,0,184,160,2,0,184,164,8,0,1,0,0,0,46,39,216,0,64,246,1,0,88,149,7,0,1,0,0,0,35,39,216,0,136,224,1,0,80,23,2,0,1,0,0,0,36,39,216,0,32,101,1,0,40,22,2,0,4,0,0,0,192,39,216,0,136,191,7,0,176,108,2,0,1,0,0,0,39,39,216,0,152,30,2,0,128,98,2,0,1,0,0,0,38,39,216,0,232,10,2,0,48,82,2,0,1,0,0,0,37,39,216,0,152,138,8,0,120,19,2,0,4,0,0,0,184,39,216,0,0,187,4,0,48,76,7,0,1,0,0,0,24,39,216,0,56,126,1,0,224,67,7,0,1,0,0,0,45,39,216,0,96,32,8,0,88,212,3,0,1,0,0,0,48,38,216,0,40,185,3,0,248,5,8,0,9,0,0,0,112,39,216,0,32,58,1,0,144,250,7,0,9,0,0,0,113,39,216,0,32,58,1,0,248,241,7,0,9,0,0,0,114,39,216,0,32,58,1,0,115,109,99,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,214,160,156,56,1,0,16,1,115,109,99,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,48,180,10,65,1,0,16,1,115,109,99,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,75,20,180,166,1,0,16,1,115,109,99,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,254,70,192,76,1,0,16,1,101,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,166,120,211,6,1,0,16,1,98,101,112,114,49,57,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,39,169,132,110,1,0,16,1,101,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,232,241,90,180,1,0,16,1,115,109,99,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,197,100,33,244,1,0,16,1,109,99,115,95,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,129,31,15,251,4,0,32,0,109,99,115,95,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,21,42,147,19,4,0,32,0,109,99,115,95,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,90,187,30,99,4,0,32,0,109,99,115,95,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,69,209,207,36,4,0,32,0,109,109,105,54,51,51,49,46,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,135,125,12,106,7,0,32,0,109,99,49,46,55,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,172,106,168,146,1,0,16,1,109,99,50,46,55,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,75,43,140,67,1,0,16,1,109,99,51,46,55,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,29,210,227,103,1,0,16,1,109,99,52,46,55,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,246,57,219,244,1,0,16,1,109,99,53,46,55,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,175,89,199,22,1,0,16,1,109,99,54,46,56,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,219,175,188,105,1,0,16,1,109,99,55,46,56,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,70,188,13,181,1,0,16,1,109,99,56,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,40,25,43,126,1,0,16,1,109,99,115,95,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,129,31,15,251,4,0,32,0,109,99,115,95,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,21,42,147,19,4,0,32,0,109,99,115,95,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,90,187,30,99,4,0,32,0,109,99,115,95,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,69,209,207,36,4,0,32,0,109,109,105,54,51,51,49,46,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,135,125,12,106,7,0,32,0,101,112,114,49,57,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,177,130,85,14,1,0,16,1,101,112,114,49,57,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,27,32,203,18,1,0,16,1,101,112,114,49,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,20,86,37,24,1,0,16,1,101,112,114,49,57,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,102,20,172,5,1,0,16,1,101,112,114,49,57,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,143,46,138,194,1,0,16,1,101,112,114,49,57,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,222,113,69,90,1,0,16,1,101,112,114,50,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,241,91,200,183,1,0,16,1,101,112,114,50,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,127,160,171,44,1,0,16,1,101,112,114,50,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,97,181,38,190,4,0,32,0,109,99,115,95,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,21,42,147,19,4,0,32,0,101,112,114,50,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,232,199,38,4,0,32,0,109,99,115,95,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,69,209,207,36,4,0,32,0,109,109,105,54,51,51,49,46,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,135,125,12,106,7,0,32,0,168,86,7,0,1,0,0,0,212,47,216,0,248,191,2,0,24,38,7,0,1,0,0,0,208,47,216,0,184,160,2,0,56,210,6,0,1,0,0,0,35,48,216,0,192,135,2,0,24,163,6,0,1,0,0,0,34,48,216,0,240,108,2,0,152,122,6,0,1,0,0,0,33,48,216,0,96,82,2,0,192,72,6,0,1,0,0,0,32,48,216,0,32,56,2,0,232,158,3,0,1,0,0,0,36,48,216,0,152,30,2,0,40,246,1,0,1,0,0,0,213,47,216,0,64,246,1,0,144,236,1,0,1,0,0,0,209,47,216,0,136,224,1,0,176,223,1,0,1,0,0,0,43,48,216,0,72,198,1,0,192,209,1,0,1,0,0,0,42,48,216,0,24,182,1,0,24,198,1,0,1,0,0,0,41,48,216,0,40,167,1,0,120,189,1,0,1,0,0,0,40,48,216,0,200,149,1,0,200,32,1,0,1,0,0,0,44,48,216,0,56,126,1,0,88,212,3,0,1,0,0,0,144,46,216,0,40,185,3,0,240,152,1,0,1,0,0,0,201,47,216,0,216,70,1,0,16,17,8,0,1,0,0,0,202,47,216,0,224,12,8,0,136,67,2,0,1,0,0,0,176,48,216,0,232,10,2,0,8,66,2,0,1,0,0,0,184,48,216,0,152,138,8,0,99,55,55,45,48,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,194,241,23,252,2,0,16,1,99,55,55,45,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,117,247,68,66,2,0,16,1,99,55,55,45,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,56,224,231,194,1,0,16,1,99,55,55,45,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,30,44,107,241,9,0,16,1,99,55,55,45,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,5,18,165,91,11,0,32,0,99,55,55,45,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,64,48,111,106,11,0,32,0,99,55,55,45,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,120,70,165,197,15,0,32,0,99,55,55,45,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,177,23,47,49,24,0,64,0,109,99,49,48,48,104,48,48,46,117,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,167,107,69,199,0,0,16,1,109,99,49,48,49,104,48,48,46,117,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,147,143,234,0,0,16,1,109,99,48,48,48,46,117,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,244,246,172,40,0,0,32,0,109,99,48,48,49,46,117,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,61,196,91,0,0,0,32,0,109,99,48,48,50,104,48,48,46,117,51,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,55,144,114,34,0,0,32,0,109,99,48,49,48,46,117,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,114,39,7,133,0,0,32,0,109,99,48,50,48,46,117,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,241,47,169,30,0,0,32,0,109,99,48,51,48,46,117,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,46,150,101,193,0,0,64,0,109,99,49,48,48,106,48,50,46,117,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,45,136,229,175,0,0,16,1,109,99,49,48,49,106,48,50,46,117,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,146,84,218,96,0,0,16,1,109,99,48,48,48,46,117,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,244,246,172,40,0,0,32,0,109,99,48,48,49,46,117,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,61,196,91,0,0,0,32,0,109,99,48,48,50,101,48,50,46,117,51,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,86,16,172,39,0,0,32,0,109,99,48,49,48,46,117,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,114,39,7,133,0,0,32,0,109,99,48,50,48,46,117,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,241,47,169,30,0,0,32,0,109,99,48,51,48,46,117,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,46,150,101,193,0,0,64,0,184,40,2,0,1,0,0,0,231,233,148,0,248,191,2,0,56,250,6,0,1,0,0,0,34,233,148,0,184,160,2,0,88,149,7,0,1,0,0,0,194,231,148,0,136,224,1,0,240,219,7,0,1,0,0,0,39,233,148,0,88,94,5,0,176,210,7,0,1,0,0,0,111,232,148,0,40,90,5,0,232,198,7,0,1,0,0,0,247,231,148,0,128,83,5,0,192,184,7,0,1,0,0,0,215,231,148,0,168,77,5,0,16,177,7,0,1,0,0,0,38,233,148,0,0,69,5,0,24,120,7,0,1,0,0,0,110,232,148,0,32,64,5,0,176,110,7,0,1,0,0,0,246,231,148,0,48,59,5,0,8,98,7,0,1,0,0,0,214,231,148,0,248,53,5,0,104,84,7,0,1,0,0,0,37,233,148,0,0,46,5,0,56,77,7,0,1,0,0,0,109,232,148,0,248,37,5,0,24,69,7,0,1,0,0,0,245,231,148,0,120,32,5,0,184,59,7,0,1,0,0,0,213,231,148,0,192,27,5,0,64,48,7,0,1,0,0,0,36,233,148,0,192,22,5,0,0,37,7,0,1,0,0,0,108,232,148,0,48,16,5,0,112,30,7,0,1,0,0,0,212,231,148,0,32,2,5,0,248,24,7,0,1,0,0,0,244,231,148,0,8,252,4,0,72,15,7,0,1,0,0,0,35,233,148,0,24,8,5,0,168,3,7,0,1,0,0,0,243,231,148,0,128,237,4,0,56,249,6,0,1,0,0,0,107,232,148,0,56,244,4,0,176,241,6,0,1,0,0,0,204,231,148,0,48,252,3,0,176,155,7,0,1,0,0,0,199,231,148,0,88,94,5,0,120,150,7,0,1,0,0,0,191,231,148,0,40,90,5,0,16,144,7,0,1,0,0,0,183,231,148,0,128,83,5,0,112,138,7,0,1,0,0,0,31,218,148,0,168,77,5,0,160,133,7,0,1,0,0,0,198,231,148,0,0,69,5,0,104,236,6,0,1,0,0,0,190,231,148,0,32,64,5,0,80,232,6,0,1,0,0,0,182,231,148,0,48,59,5,0,144,228,6,0,1,0,0,0,30,218,148,0,248,53,5,0,16,224,6,0,1,0,0,0,197,231,148,0,0,46,5,0,72,218,6,0,1,0,0,0,189,231,148,0,248,37,5,0,0,214,6,0,1,0,0,0,181,231,148,0,120,32,5,0,216,208,6,0,1,0,0,0,29,218,148,0,192,27,5,0,216,204,6,0,1,0,0,0,196,231,148,0,192,22,5,0,216,201,6,0,1,0,0,0,108,232,148,0,48,16,5,0,144,198,6,0,1,0,0,0,28,218,148,0,32,2,5,0,144,195,6,0,1,0,0,0,180,231,148,0,8,252,4,0,184,190,6,0,1,0,0,0,195,231,148,0,24,8,5,0,136,185,6,0,1,0,0,0,179,231,148,0,128,237,4,0,112,179,6,0,1,0,0,0,187,231,148,0,56,244,4,0,160,173,6,0,1,0,0,0,20,218,148,0,48,252,3,0,88,212,3,0,1,0,0,0,80,219,146,0,40,185,3,0,248,5,8,0,9,0,0,0,128,94,147,0,32,58,1,0,144,250,7,0,9,0,0,0,129,94,147,0,32,58,1,0,168,86,7,0,1,0,0,0,143,239,146,0,248,191,2,0,24,38,7,0,1,0,0,0,223,254,146,0,184,160,2,0,56,210,6,0,1,0,0,0,216,254,146,0,192,135,2,0,24,163,6,0,1,0,0,0,217,254,146,0,240,108,2,0,152,122,6,0,1,0,0,0,218,254,146,0,96,82,2,0,192,72,6,0,1,0,0,0,219,254,146,0,32,56,2,0,200,110,3,0,1,0,0,0,220,254,146,0,152,30,2,0,120,89,3,0,1,0,0,0,221,254,146,0,232,10,2,0,40,246,1,0,1,0,0,0,142,239,146,0,64,246,1,0,144,236,1,0,1,0,0,0,127,246,146,0,136,224,1,0,176,223,1,0,1,0,0,0,120,246,146,0,72,198,1,0,192,209,1,0,1,0,0,0,121,246,146,0,24,182,1,0,24,198,1,0,1,0,0,0,122,246,146,0,40,167,1,0,120,189,1,0,1,0,0,0,123,246,146,0,200,149,1,0,224,22,1,0,1,0,0,0,124,246,146,0,56,126,1,0,160,14,1,0,1,0,0,0,125,246,146,0,32,101,1,0,88,212,3,0,1,0,0,0,160,218,146,0,40,185,3,0,16,17,8,0,1,0,0,0,141,239,146,0,224,12,8,0,56,58,1,0,1,0,0,0,140,239,146,0,64,50,1,0,72,65,1,0,9,0,0,0,48,5,147,0,32,58,1,0,48,50,1,0,9,0,0,0,49,5,147,0,32,58,1,0,224,41,1,0,9,0,0,0,50,5,147,0,32,58,1,0,168,86,7,0,1,0,0,0,232,47,216,0,248,191,2,0,24,38,7,0,1,0,0,0,236,47,216,0,184,160,2,0,56,210,6,0,1,0,0,0,35,48,216,0,192,135,2,0,24,163,6,0,1,0,0,0,34,48,216,0,240,108,2,0,152,122,6,0,1,0,0,0,33,48,216,0,96,82,2,0,192,72,6,0,1,0,0,0,32,48,216,0,32,56,2,0,112,135,2,0,1,0,0,0,36,48,216,0,152,30,2,0,248,97,5,0,1,0,0,0,37,48,216,0,232,10,2,0,120,36,5,0,1,0,0,0,38,48,216,0,152,138,8,0,40,246,1,0,1,0,0,0,233,47,216,0,64,246,1,0,144,236,1,0,1,0,0,0,237,47,216,0,136,224,1,0,176,223,1,0,1,0,0,0,43,48,216,0,72,198,1,0,192,209,1,0,1,0,0,0,42,48,216,0,24,182,1,0,24,198,1,0,1,0,0,0,41,48,216,0,40,167,1,0,120,189,1,0,1,0,0,0,40,48,216,0,200,149,1,0,16,193,8,0,1,0,0,0,44,48,216,0,56,126,1,0,32,167,1,0,1,0,0,0,45,48,216,0,32,101,1,0,128,149,1,0,1,0,0,0,46,48,216,0,96,32,8,0,240,152,1,0,1,0,0,0,238,47,216,0,216,70,1,0,16,17,8,0,1,0,0,0,234,47,216,0,224,12,8,0,88,212,3,0,1,0,0,0,144,46,216,0,40,185,3,0,72,65,1,0,9,0,0,0,232,48,216,0,32,58,1,0,48,50,1,0,9,0,0,0,224,48,216,0,32,58,1,0,224,41,1,0,9,0,0,0,216,48,216,0,32,58,1,0,114,109,50,104,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,120,3,24,187,1,0,16,1,114,109,50,104,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,214,252,95,32,1,0,16,1,114,109,50,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,252,158,238,2,1,0,16,1,114,109,50,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,180,0,31,155,5,0,32,0,114,109,50,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,36,12,187,194,5,0,32,0,114,109,50,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,81,114,37,18,5,0,32,0,114,109,50,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,134,231,182,249,5,0,32,0,114,109,50,46,48,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,89,120,142,209,10,0,16,1,114,109,50,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,224,236,99,196,10,0,16,1,114,109,50,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,77,23,6,33,12,0,64,0,114,109,50,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,54,22,108,84,12,0,64,0,114,109,50,97,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,167,12,51,43,1,0,16,1,114,109,50,97,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,43,148,71,139,1,0,16,1,114,109,50,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,252,158,238,2,1,0,16,1,114,109,50,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,180,0,31,155,5,0,32,0,114,109,50,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,36,12,187,194,5,0,32,0,114,109,50,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,81,114,37,18,5,0,32,0,114,109,50,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,134,231,182,249,5,0,32,0,114,109,50,46,48,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,89,120,142,209,10,0,16,1,114,109,50,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,224,236,99,196,10,0,16,1,114,109,50,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,77,23,6,33,12,0,64,0,114,109,50,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,54,22,108,84,12,0,64,0,26,0,0,0,255,255,1,0,0,0,0,0,0,0,0,0,254,0,5,0,184,93,3,0,25,0,0,0,1,193,1,0,16,93,3,0,25,0,0,0,1,193,0,0,248,92,3,0,25,0,0,0,1,193,64,0,160,92,3,0,25,0,0,0,1,193,128,0,160,134,3,0,25,0,0,0,1,193,192,0,8,234,2,0,0,0,0,0,254,0,2,0,120,92,3,0,25,0,0,0,1,32,32,0,56,111,3,0,25,0,0,0,1,32,0,0,104,134,3,0,0,0,0,0,254,0,3,0,96,91,3,0,26,0,0,0,1,3,0,0,208,90,3,0,26,0,0,0,1,3,1,0,152,90,3,0,26,0,0,0,1,3,2,0,80,90,3,0,168,86,7,0,1,0,0,0,0,1,147,0,248,191,2,0,24,38,7,0,1,0,0,0,2,1,147,0,184,160,2,0,152,122,6,0,1,0,0,0,97,248,146,0,96,82,2,0,192,72,6,0,1,0,0,0,96,248,146,0,32,56,2,0,200,110,3,0,1,0,0,0,98,248,146,0,152,30,2,0,120,89,3,0,1,0,0,0,99,248,146,0,232,10,2,0,88,212,3,0,1,0,0,0,72,220,146,0,40,185,3,0,72,65,1,0,9,0,0,0,104,6,147,0,32,58,1,0,48,50,1,0,9,0,0,0,105,6,147,0,32,58,1,0,99,49,49,45,48,55,46,53,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,182,40,210,17,2,0,16,1,99,49,49,45,48,56,46,51,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,202,77,157,167,2,0,16,1,99,49,49,45,48,54,46,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,148,152,36,124,2,0,16,1,99,49,49,45,49,48,46,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,67,154,55,191,2,0,16,1,99,49,49,45,49,50,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,241,148,16,177,9,0,16,1,99,49,49,45,48,53,46,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,142,109,62,115,11,0,32,0,99,49,49,45,48,51,46,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,122,140,113,70,16,0,32,0,99,49,49,45,48,52,46,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,204,51,63,102,16,0,32,0,99,49,49,45,48,49,46,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,50,165,30,253,24,0,64,0,99,49,49,45,48,50,46,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,135,193,28,69,25,0,64,0,19,0,0,0,255,255,254,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,19,0,0,0,1,1,0,0,120,97,1,0,19,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,2,2,0,96,135,7,0,19,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,4,4,0,96,135,7,0,19,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,8,0,0,96,135,7,0,19,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,32,4,2,0,19,0,0,0,1,48,0,0,80,252,6,0,19,0,0,0,1,48,16,0,16,242,7,0,19,0,0,0,1,48,32,0,104,236,7,0,19,0,0,0,1,48,48,0,128,230,7,0,0,0,0,0,254,0,4,0,168,248,6,0,19,0,0,0,1,192,0,0,16,242,7,0,19,0,0,0,1,192,64,0,104,236,7,0,19,0,0,0,1,192,128,0,80,245,6,0,19,0,0,0,1,192,192,0,240,240,6,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,3,2,0,80,246,3,0,20,0,0,0,1,3,3,0,80,124,6,0,20,0,0,0,1,3,1,0,112,212,3,0,20,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,64,37,5,0,20,0,0,0,1,12,12,0,240,191,4,0,20,0,0,0,1,12,4,0,200,213,4,0,20,0,0,0,1,12,8,0,144,227,4,0,20,0,0,0,1,12,0,0,120,7,5,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,48,16,0,192,255,2,0,20,0,0,0,1,48,0,0,208,75,4,0,20,0,0,0,1,48,48,0,8,49,4,0,20,0,0,0,1,48,32,0,152,21,4,0,0,0,0,0,254,0,2,0,144,212,6,0,20,0,0,0,1,64,0,0,8,208,6,0,20,0,0,0,1,64,64,0,88,204,6,0,99,49,49,45,48,55,46,53,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,182,40,210,17,2,0,16,1,99,49,49,45,48,56,46,51,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,202,77,157,167,2,0,16,1,99,49,49,45,48,54,46,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,148,152,36,124,2,0,16,1,99,49,49,45,48,57,46,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,213,170,48,200,2,0,16,1,99,49,49,45,49,50,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,241,148,16,177,9,0,16,1,99,49,49,45,48,53,46,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,142,109,62,115,11,0,32,0,99,49,49,45,48,51,46,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,122,140,113,70,16,0,32,0,99,49,49,45,48,52,46,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,204,51,63,102,16,0,32,0,99,49,49,45,48,49,46,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,50,165,30,253,24,0,64,0,99,49,49,45,48,50,46,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,135,193,28,69,25,0,64,0,19,0,0,0,255,255,254,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,19,0,0,0,1,1,0,0,120,97,1,0,19,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,2,2,0,96,135,7,0,19,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,4,4,0,96,135,7,0,19,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,8,0,0,96,135,7,0,19,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,19,0,0,0,1,48,0,0,104,236,7,0,19,0,0,0,1,48,48,0,128,230,7,0,19,0,0,0,1,48,0,0,120,211,6,0,19,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,19,0,0,0,1,192,64,0,104,236,7,0,19,0,0,0,1,192,192,0,128,230,7,0,19,0,0,0,1,192,0,0,120,211,6,0,19,0,0,0,1,192,128,0,184,164,6,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,3,2,0,80,246,3,0,20,0,0,0,1,3,3,0,80,124,6,0,20,0,0,0,1,3,1,0,112,212,3,0,20,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,64,37,5,0,20,0,0,0,1,12,12,0,240,191,4,0,20,0,0,0,1,12,4,0,200,213,4,0,20,0,0,0,1,12,8,0,144,227,4,0,20,0,0,0,1,12,0,0,120,7,5,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,48,16,0,192,255,2,0,20,0,0,0,1,48,0,0,208,75,4,0,20,0,0,0,1,48,48,0,8,49,4,0,20,0,0,0,1,48,32,0,152,21,4,0,0,0,0,0,254,0,2,0,144,212,6,0,20,0,0,0,1,64,0,0,8,208,6,0,20,0,0,0,1,64,64,0,88,204,6,0,168,86,7,0,1,0,0,0,96,254,146,0,248,191,2,0,24,38,7,0,1,0,0,0,95,254,146,0,184,160,2,0,56,210,6,0,1,0,0,0,88,254,146,0,192,135,2,0,24,163,6,0,1,0,0,0,89,254,146,0,240,108,2,0,152,122,6,0,1,0,0,0,90,254,146,0,96,82,2,0,192,72,6,0,1,0,0,0,91,254,146,0,32,56,2,0,200,110,3,0,1,0,0,0,92,254,146,0,152,30,2,0,120,89,3,0,1,0,0,0,93,254,146,0,232,10,2,0,120,74,3,0,1,0,0,0,94,254,146,0,152,138,8,0,40,246,1,0,1,0,0,0,16,246,146,0,64,246,1,0,144,236,1,0,1,0,0,0,15,246,146,0,136,224,1,0,176,223,1,0,1,0,0,0,8,246,146,0,72,198,1,0,192,209,1,0,1,0,0,0,9,246,146,0,24,182,1,0,24,198,1,0,1,0,0,0,10,246,146,0,40,167,1,0,120,189,1,0,1,0,0,0,11,246,146,0,200,149,1,0,224,22,1,0,1,0,0,0,12,246,146,0,56,126,1,0,160,14,1,0,1,0,0,0,13,246,146,0,32,101,1,0,88,212,3,0,1,0,0,0,64,218,146,0,40,185,3,0,16,17,8,0,1,0,0,0,17,246,146,0,224,12,8,0,72,65,1,0,9,0,0,0,248,4,147,0,32,58,1,0,48,50,1,0,9,0,0,0,249,4,147,0,32,58,1,0,184,40,2,0,1,0,0,0,231,233,148,0,248,191,2,0,56,250,6,0,1,0,0,0,34,233,148,0,184,160,2,0,88,149,7,0,1,0,0,0,194,231,148,0,136,224,1,0,240,219,7,0,1,0,0,0,39,233,148,0,88,94,5,0,176,210,7,0,1,0,0,0,111,232,148,0,40,90,5,0,232,198,7,0,1,0,0,0,247,231,148,0,128,83,5,0,192,184,7,0,1,0,0,0,215,231,148,0,168,77,5,0,16,177,7,0,1,0,0,0,38,233,148,0,0,69,5,0,24,120,7,0,1,0,0,0,110,232,148,0,32,64,5,0,176,110,7,0,1,0,0,0,246,231,148,0,48,59,5,0,8,98,7,0,1,0,0,0,214,231,148,0,248,53,5,0,104,84,7,0,1,0,0,0,37,233,148,0,0,46,5,0,56,77,7,0,1,0,0,0,109,232,148,0,248,37,5,0,24,69,7,0,1,0,0,0,245,231,148,0,120,32,5,0,184,59,7,0,1,0,0,0,213,231,148,0,192,27,5,0,64,48,7,0,1,0,0,0,36,233,148,0,192,22,5,0,0,37,7,0,1,0,0,0,108,232,148,0,48,16,5,0,112,30,7,0,1,0,0,0,212,231,148,0,32,2,5,0,248,24,7,0,1,0,0,0,244,231,148,0,8,252,4,0,72,15,7,0,1,0,0,0,35,233,148,0,24,8,5,0,168,3,7,0,1,0,0,0,243,231,148,0,128,237,4,0,56,249,6,0,1,0,0,0,107,232,148,0,56,244,4,0,176,241,6,0,1,0,0,0,204,231,148,0,48,252,3,0,176,155,7,0,1,0,0,0,199,231,148,0,88,94,5,0,120,150,7,0,1,0,0,0,191,231,148,0,40,90,5,0,16,144,7,0,1,0,0,0,183,231,148,0,128,83,5,0,112,138,7,0,1,0,0,0,31,218,148,0,168,77,5,0,160,133,7,0,1,0,0,0,198,231,148,0,0,69,5,0,104,236,6,0,1,0,0,0,190,231,148,0,32,64,5,0,80,232,6,0,1,0,0,0,182,231,148,0,48,59,5,0,144,228,6,0,1,0,0,0,30,218,148,0,248,53,5,0,16,224,6,0,1,0,0,0,197,231,148,0,0,46,5,0,72,218,6,0,1,0,0,0,189,231,148,0,248,37,5,0,0,214,6,0,1,0,0,0,181,231,148,0,120,32,5,0,216,208,6,0,1,0,0,0,29,218,148,0,192,27,5,0,216,204,6,0,1,0,0,0,196,231,148,0,192,22,5,0,216,201,6,0,1,0,0,0,108,232,148,0,48,16,5,0,144,198,6,0,1,0,0,0,28,218,148,0,32,2,5,0,144,195,6,0,1,0,0,0,180,231,148,0,8,252,4,0,184,190,6,0,1,0,0,0,195,231,148,0,24,8,5,0,136,185,6,0,1,0,0,0,179,231,148,0,128,237,4,0,112,179,6,0,1,0,0,0,187,231,148,0,56,244,4,0,160,173,6,0,1,0,0,0,20,218,148,0,48,252,3,0,88,212,3,0,1,0,0,0,80,219,146,0,40,185,3,0,32,77,1,0,1,0,0,0,25,232,148,0,216,70,1,0,168,86,7,0,1,0,0,0,200,239,146,0,248,191,2,0,24,38,7,0,1,0,0,0,202,239,146,0,184,160,2,0,56,210,6,0,1,0,0,0,26,0,147,0,192,135,2,0,24,163,6,0,1,0,0,0,27,0,147,0,240,108,2,0,152,122,6,0,1,0,0,0,25,0,147,0,96,82,2,0,192,72,6,0,1,0,0,0,24,0,147,0,32,56,2,0,200,110,3,0,1,0,0,0,28,0,147,0,152,30,2,0,120,89,3,0,1,0,0,0,29,0,147,0,232,10,2,0,40,246,1,0,1,0,0,0,201,239,146,0,64,246,1,0,144,236,1,0,1,0,0,0,203,239,146,0,136,224,1,0,176,223,1,0,1,0,0,0,130,247,146,0,72,198,1,0,192,209,1,0,1,0,0,0,131,247,146,0,24,182,1,0,24,198,1,0,1,0,0,0,129,247,146,0,40,167,1,0,120,189,1,0,1,0,0,0,128,247,146,0,200,149,1,0,224,22,1,0,1,0,0,0,132,247,146,0,56,126,1,0,160,14,1,0,1,0,0,0,133,247,146,0,32,101,1,0,88,212,3,0,1,0,0,0,88,219,146,0,40,185,3,0,16,17,8,0,1,0,0,0,207,239,146,0,224,12,8,0,72,65,1,0,9,0,0,0,160,5,147,0,32,58,1,0,48,50,1,0,9,0,0,0,161,5,147,0,32,58,1,0,224,41,1,0,9,0,0,0,162,5,147,0,32,58,1,0,168,86,7,0,1,0,0,0,160,232,148,0,248,191,2,0,24,38,7,0,1,0,0,0,162,232,148,0,184,160,2,0,56,210,6,0,1,0,0,0,24,234,148,0,192,135,2,0,24,163,6,0,1,0,0,0,25,234,148,0,240,108,2,0,152,122,6,0,1,0,0,0,30,234,148,0,96,82,2,0,192,72,6,0,1,0,0,0,31,234,148,0,32,56,2,0,112,135,2,0,1,0,0,0,164,232,148,0,152,30,2,0,144,236,1,0,1,0,0,0,163,232,148,0,136,224,1,0,176,223,1,0,1,0,0,0,88,233,148,0,72,198,1,0,192,209,1,0,1,0,0,0,89,233,148,0,24,182,1,0,24,198,1,0,1,0,0,0,94,233,148,0,40,167,1,0,120,189,1,0,1,0,0,0,95,233,148,0,200,149,1,0,16,193,8,0,1,0,0,0,165,232,148,0,56,126,1,0,88,212,3,0,1,0,0,0,136,220,146,0,40,185,3,0,216,85,2,0,9,0,0,0,184,94,147,0,32,58,1,0,168,86,7,0,1,0,0,0,168,1,147,0,248,191,2,0,56,210,6,0,1,0,0,0,234,248,146,0,192,135,2,0,24,163,6,0,1,0,0,0,235,248,146,0,240,108,2,0,152,122,6,0,1,0,0,0,232,248,146,0,96,82,2,0,192,72,6,0,1,0,0,0,233,248,146,0,32,56,2,0,200,110,3,0,1,0,0,0,237,248,146,0,152,30,2,0,120,89,3,0,1,0,0,0,236,248,146,0,232,10,2,0,40,246,1,0,1,0,0,0,169,1,147,0,64,246,1,0,176,223,1,0,1,0,0,0,202,240,146,0,72,198,1,0,192,209,1,0,1,0,0,0,203,240,146,0,24,182,1,0,24,198,1,0,1,0,0,0,200,240,146,0,40,167,1,0,120,189,1,0,1,0,0,0,201,240,146,0,200,149,1,0,224,22,1,0,1,0,0,0,205,240,146,0,56,126,1,0,160,14,1,0,1,0,0,0,204,240,146,0,32,101,1,0,168,132,8,0,1,0,0,0,170,1,147,0,232,209,1,0,192,122,8,0,1,0,0,0,138,237,146,0,208,174,1,0,40,116,8,0,1,0,0,0,139,237,146,0,48,160,1,0,72,110,8,0,1,0,0,0,136,237,146,0,160,140,1,0,184,102,8,0,1,0,0,0,137,237,146,0,56,112,1,0,248,67,8,0,1,0,0,0,141,237,146,0,32,92,1,0,136,64,8,0,1,0,0,0,140,237,146,0,64,77,1,0,232,23,8,0,1,0,0,0,171,1,147,0,104,195,5,0,248,16,8,0,1,0,0,0,154,236,146,0,32,231,8,0,192,12,8,0,1,0,0,0,155,236,146,0,88,214,8,0,224,5,8,0,1,0,0,0,152,236,146,0,224,202,8,0,144,1,8,0,1,0,0,0,153,236,146,0,72,193,8,0,176,222,7,0,1,0,0,0,157,236,146,0,144,180,8,0,176,218,7,0,1,0,0,0,156,236,146,0,208,164,8,0,88,212,3,0,1,0,0,0,40,221,146,0,40,185,3,0,56,122,5,0,1,0,0,0,172,1,147,0,224,12,8,0,0,105,5,0,1,0,0,0,173,1,147,0,128,176,7,0,152,120,4,0,1,0,0,0,174,1,147,0,248,114,7,0,112,109,5,0,1,0,0,0,175,1,147,0,32,105,5,0,72,65,1,0,9,0,0,0,240,6,147,0,32,58,1,0,48,50,1,0,9,0,0,0,241,6,147,0,32,58,1,0,224,41,1,0,9,0,0,0,242,6,147,0,32,58,1,0,21,0,0,0,255,255,255,0,0,0,0,0,22,0,0,0,255,255,87,0,0,0,0,0,23,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,16,0,32,4,2,0,21,0,0,0,1,15,2,0,80,252,6,0,21,0,0,0,1,15,5,0,16,242,7,0,21,0,0,0,1,15,8,0,104,236,7,0,21,0,0,0,1,15,4,0,120,113,6,0,21,0,0,0,1,15,1,0,232,228,5,0,21,0,0,0,1,15,15,0,128,230,7,0,21,0,0,0,1,15,0,0,232,192,7,0,21,0,0,0,1,15,3,0,56,141,7,0,21,0,0,0,1,15,7,0,120,211,6,0,21,0,0,0,1,15,14,0,184,164,6,0,21,0,0,0,1,15,6,0,24,1,7,0,21,0,0,0,1,15,13,0,80,74,6,0,21,0,0,0,1,15,12,0,192,32,6,0,21,0,0,0,1,15,11,0,192,234,2,0,21,0,0,0,1,15,10,0,32,242,5,0,21,0,0,0,1,15,9,0,176,192,2,0,0,0,0,0,254,0,16,0,160,123,6,0,21,0,0,0,1,240,32,0,80,252,6,0,21,0,0,0,1,240,80,0,16,242,7,0,21,0,0,0,1,240,128,0,104,236,7,0,21,0,0,0,1,240,64,0,120,113,6,0,21,0,0,0,1,240,16,0,232,228,5,0,21,0,0,0,1,240,240,0,128,230,7,0,21,0,0,0,1,240,0,0,232,192,7,0,21,0,0,0,1,240,48,0,56,141,7,0,21,0,0,0,1,240,112,0,120,211,6,0,21,0,0,0,1,240,224,0,184,164,6,0,21,0,0,0,1,240,96,0,24,1,7,0,21,0,0,0,1,240,208,0,80,74,6,0,21,0,0,0,1,240,192,0,192,32,6,0,21,0,0,0,1,240,176,0,192,234,2,0,21,0,0,0,1,240,160,0,32,242,5,0,21,0,0,0,1,240,144,0,176,192,2,0,0,0,0,0,254,0,4,0,240,96,5,0,22,0,0,0,1,24,0,0,176,63,4,0,22,0,0,0,1,24,8,0,104,142,4,0,22,0,0,0,1,24,16,0,56,43,1,0,22,0,0,0,1,24,24,0,80,150,7,0,0,0,0,0,254,0,4,0,72,202,5,0,22,0,0,0,1,96,96,0,80,246,3,0,22,0,0,0,1,96,64,0,248,38,7,0,22,0,0,0,1,96,32,0,112,212,3,0,22,0,0,0,1,96,0,0,24,99,5,0,0,0,0,0,254,0,2,0,168,234,7,0,22,0,0,0,1,128,128,0,96,135,7,0,22,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,23,0,0,0,1,1,1,0,96,135,7,0,23,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,23,0,0,0,1,4,4,0,96,135,7,0,23,0,0,0,1,4,0,0,152,182,7,0,14,0,0,0,255,255,191,0,0,0,0,0,15,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,8,0,32,4,2,0,14,0,0,0,1,7,2,0,40,88,7,0,14,0,0,0,1,7,4,0,96,39,7,0,14,0,0,0,1,7,1,0,120,113,6,0,14,0,0,0,1,7,7,0,144,251,6,0,14,0,0,0,1,7,3,0,120,211,6,0,14,0,0,0,1,7,6,0,184,164,6,0,14,0,0,0,1,7,5,0,80,74,6,0,14,0,0,0,1,7,0,0,16,227,4,0,0,0,0,0,254,0,4,0,72,202,5,0,14,0,0,0,1,24,16,0,80,246,3,0,14,0,0,0,1,24,24,0,248,38,7,0,14,0,0,0,1,24,8,0,112,212,3,0,14,0,0,0,1,24,0,0,24,99,5,0,0,0,0,0,254,0,0,0,168,234,7,0,14,0,0,0,1,64,64,0,96,135,7,0,14,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,14,0,0,0,1,128,128,0,96,135,7,0,14,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,208,20,3,0,15,0,0,0,1,3,3,0,72,95,8,0,15,0,0,0,1,3,0,0,232,252,8,0,15,0,0,0,1,3,1,0,0,88,8,0,15,0,0,0,1,3,2,0,232,239,8,0,0,0,0,0,254,0,4,0,80,232,8,0,15,0,0,0,1,12,8,0,144,117,8,0,15,0,0,0,1,12,12,0,232,74,4,0,15,0,0,0,1,12,4,0,40,208,8,0,15,0,0,0,1,12,0,0,216,203,8,0,0,0,0,0,254,0,4,0,16,199,8,0,15,0,0,0,1,16,0,0,144,117,8,0,15,0,0,0,1,16,16,0,232,74,4,0,0,0,0,0,0,0,0,0,0,0,0,0,108,119,95,49,49,46,49,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,86,204,226,97,1,0,16,1,108,119,95,49,53,46,49,52,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,211,24,12,138,1,0,16,1,108,119,95,49,48,46,49,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,213,164,188,35,1,0,16,1,108,119,95,49,52,46,49,51,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,113,55,2,58,1,0,16,1,108,119,45,48,55,46,49,51,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,38,42,37,253,2,0,16,1,108,119,45,48,49,46,57,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,152,242,24,3,4,0,32,0,108,119,45,48,56,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,60,228,168,37,4,0,32,0,108,119,45,48,53,46,57,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,215,47,85,228,4,0,32,0,108,119,45,49,50,46,57,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,43,131,106,142,4,0,32,0,108,119,45,48,50,46,49,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,200,197,230,67,4,0,32,0,108,119,45,48,57,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,173,180,156,137,4,0,32,0,108,119,45,48,54,46,49,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,252,223,158,91,4,0,32,0,108,119,45,49,51,46,49,50,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,245,142,5,142,4,0,32,0,108,119,95,48,48,98,46,49,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,99,42,223,89,3,0,16,0,108,119,45,48,51,46,49,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,231,89,33,206,5,0,64,0,108,119,45,48,52,46,49,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,54,85,48,57,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,108,119,99,104,114,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,57,76,237,84,0,0,0,8,108,119,105,111,46,49,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,12,185,82,173,0,0,0,8,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,44,109,23,214,1,0,16,1,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,74,95,245,165,1,0,16,1,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,60,250,105,1,1,0,16,1,108,116,104,97,114,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,14,191,44,227,1,0,16,1,50,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,64,224,158,36,1,0,16,1,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,8,230,210,199,1,0,16,1,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,177,197,75,188,1,0,16,1,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,42,190,153,184,2,0,16,1,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,49,175,7,105,2,0,16,1,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,231,55,241,97,4,0,32,0,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,95,222,129,85,4,0,32,0,108,116,112,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,22,184,8,17,7,0,32,0,168,86,7,0,1,0,0,0,16,237,146,0,248,191,2,0,24,38,7,0,1,0,0,0,120,254,146,0,184,160,2,0,240,251,8,0,4,0,0,0,248,7,147,0,152,210,1,0,176,223,8,0,4,0,0,0,252,7,147,0,208,189,1,0,200,110,3,0,1,0,0,0,52,236,146,0,40,55,8,0,40,246,1,0,1,0,0,0,17,237,146,0,64,246,1,0,144,236,1,0,1,0,0,0,40,246,146,0,136,224,1,0,112,188,8,0,4,0,0,0,0,8,147,0,152,210,1,0,192,123,8,0,4,0,0,0,4,8,147,0,208,189,1,0,224,22,1,0,1,0,0,0,53,236,146,0,40,55,8,0,88,212,3,0,1,0,0,0,88,218,146,0,40,185,3,0,16,17,8,0,1,0,0,0,116,239,146,0,224,12,8,0,16,17,8,0,1,0,0,0,127,254,146,0,224,12,8,0,72,65,1,0,9,0,0,0,8,5,147,0,32,58,1,0,184,40,2,0,1,0,0,0,214,155,215,0,248,191,2,0,184,164,8,0,1,0,0,0,215,155,215,0,64,246,1,0,192,76,7,0,4,0,0,0,112,156,215,0,152,210,1,0,176,68,7,0,4,0,0,0,104,156,215,0,208,189,1,0,48,123,2,0,1,0,0,0,207,155,215,0,248,174,1,0,96,69,2,0,1,0,0,0,206,155,215,0,104,160,1,0,224,47,7,0,4,0,0,0,96,156,215,0,136,7,4,0,192,36,7,0,4,0,0,0,88,156,215,0,136,113,1,0,248,187,8,0,1,0,0,0,205,155,215,0,56,126,1,0,184,179,8,0,1,0,0,0,204,155,215,0,32,101,1,0,16,17,8,0,1,0,0,0,210,155,215,0,224,12,8,0,0,105,5,0,1,0,0,0,211,155,215,0,128,176,7,0,32,77,1,0,1,0,0,0,209,155,215,0,216,70,1,0,88,212,3,0,1,0,0,0,200,154,215,0,40,185,3,0,248,5,8,0,9,0,0,0,0,156,215,0,32,58,1,0,144,250,7,0,9,0,0,0,1,156,215,0,32,58,1,0,108,100,117,95,48,54,46,49,51,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,11,160,40,66,0,0,16,1,108,100,117,95,48,53,46,49,50,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,79,67,96,114,0,0,16,1,108,100,117,95,48,52,46,49,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,100,185,159,66,0,0,16,1,108,100,117,95,48,51,46,57,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,114,223,164,90,0,0,16,1,108,100,95,48,50,46,49,54,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,12,77,131,145,0,0,16,1,108,100,95,48,49,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,135,111,60,173,0,0,32,0,108,100,45,49,53,46,54,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,117,161,119,217,0,0,32,0,108,100,45,49,51,46,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,159,114,37,188,0,0,32,0,108,100,45,49,52,46,49,53,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,57,55,101,208,0,0,32,0,108,100,45,49,49,46,49,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,189,219,212,73,0,0,32,0,108,100,45,48,57,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,116,219,250,110,0,0,32,0,108,100,45,49,50,46,49,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,56,83,62,49,0,0,32,0,108,100,45,49,48,46,49,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,227,178,211,184,0,0,32,0,108,100,46,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,220,29,154,114,0,0,32,0,108,100,95,48,54,46,49,51,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,43,225,169,88,0,0,16,1,108,100,95,48,53,46,49,50,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,120,93,104,20,0,0,16,1,108,100,95,48,52,46,49,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,240,75,170,0,0,16,1,108,100,95,48,51,46,57,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,171,200,170,187,0,0,16,1,108,100,95,48,50,46,49,54,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,12,77,131,145,0,0,16,1,108,100,95,48,49,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,135,111,60,173,0,0,32,0,108,100,45,49,53,46,54,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,117,161,119,217,0,0,32,0,108,100,45,49,51,46,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,159,114,37,188,0,0,32,0,108,100,45,49,52,46,49,53,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,57,55,101,208,0,0,32,0,108,100,45,49,49,46,49,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,189,219,212,73,0,0,32,0,108,100,45,48,57,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,116,219,250,110,0,0,32,0,108,100,45,49,50,46,49,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,56,83,62,49,0,0,32,0,108,100,45,49,48,46,49,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,227,178,211,184,0,0,32,0,108,100,46,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,220,29,154,114,0,0,32,0,108,100,95,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,150,26,129,67,0,0,16,1,108,100,95,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,70,9,195,99,0,0,16,1,108,100,95,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,248,224,164,70,0,0,16,1,108,100,95,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,74,32,95,141,0,0,16,1,108,100,117,45,48,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,100,185,159,66,0,0,16,1,108,100,117,45,48,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,114,223,164,90,0,0,16,1,108,100,95,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,12,77,131,145,0,0,16,1,108,100,95,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,135,111,60,173,0,0,32,0,108,100,95,49,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,221,191,136,113,0,0,32,0,108,100,95,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,106,246,42,166,0,0,32,0,108,100,95,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,80,46,118,75,0,0,32,0,108,100,95,50,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,142,24,64,177,0,0,32,0,108,100,95,50,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,72,130,119,6,0,0,32,0,108,100,95,50,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,117,134,199,72,0,0,32,0,108,100,95,50,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,129,172,237,176,0,0,32,0,108,100,95,50,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,154,174,65,197,0,0,32,0,108,100,95,50,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,223,196,234,102,0,0,32,0,108,100,95,50,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,44,51,23,216,0,0,32,0,108,100,95,50,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,18,136,15,248,0,0,32,0,108,100,95,50,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,14,12,79,183,0,0,32,0,108,100,95,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,67,82,253,248,0,0,32,0,108,100,95,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,70,215,154,180,0,0,32,0,108,100,95,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,14,24,13,26,0,0,32,0,108,100,95,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,38,94,116,178,0,0,32,0,108,100,95,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,188,59,177,150,0,0,32,0,108,100,95,49,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,230,247,128,157,0,0,32,0,108,100,95,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,172,152,165,161,0,0,32,0,108,100,95,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,204,21,245,237,0,0,32,0,108,100,46,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,220,29,154,114,0,0,32,0,168,86,7,0,1,0,0,0,72,237,146,0,248,191,2,0,24,38,7,0,1,0,0,0,149,0,147,0,184,160,2,0,56,210,6,0,1,0,0,0,147,0,147,0,192,135,2,0,24,163,6,0,1,0,0,0,145,0,147,0,240,108,2,0,152,122,6,0,1,0,0,0,144,0,147,0,96,82,2,0,192,72,6,0,1,0,0,0,146,0,147,0,32,56,2,0,200,110,3,0,1,0,0,0,148,0,147,0,152,30,2,0,120,89,3,0,1,0,0,0,16,240,146,0,232,10,2,0,40,246,1,0,1,0,0,0,73,237,146,0,64,246,1,0,144,236,1,0,1,0,0,0,150,0,147,0,136,224,1,0,176,223,1,0,1,0,0,0,251,247,146,0,72,198,1,0,192,209,1,0,1,0,0,0,249,247,146,0,24,182,1,0,24,198,1,0,1,0,0,0,248,247,146,0,40,167,1,0,120,189,1,0,1,0,0,0,250,247,146,0,200,149,1,0,224,22,1,0,1,0,0,0,252,247,146,0,56,126,1,0,160,14,1,0,1,0,0,0,20,240,146,0,32,101,1,0,88,212,3,0,1,0,0,0,200,219,146,0,40,185,3,0,56,58,1,0,1,0,0,0,151,0,147,0,64,50,1,0,72,65,1,0,9,0,0,0,0,6,147,0,32,58,1,0,48,50,1,0,9,0,0,0,1,6,147,0,32,58,1,0,184,40,2,0,1,0,0,0,2,151,215,0,248,191,2,0,56,250,6,0,1,0,0,0,11,151,215,0,184,160,2,0,184,164,8,0,1,0,0,0,3,151,215,0,64,246,1,0,88,149,7,0,1,0,0,0,15,151,215,0,136,224,1,0,56,210,6,0,1,0,0,0,248,150,215,0,192,135,2,0,24,163,6,0,1,0,0,0,249,150,215,0,240,108,2,0,152,122,6,0,1,0,0,0,250,150,215,0,96,82,2,0,192,72,6,0,1,0,0,0,251,150,215,0,32,56,2,0,48,123,2,0,1,0,0,0,8,151,215,0,152,30,2,0,96,69,2,0,1,0,0,0,9,151,215,0,232,10,2,0,144,55,2,0,1,0,0,0,10,151,215,0,152,138,8,0,176,223,1,0,1,0,0,0,252,150,215,0,72,198,1,0,192,209,1,0,1,0,0,0,253,150,215,0,24,182,1,0,24,198,1,0,1,0,0,0,254,150,215,0,40,167,1,0,120,189,1,0,1,0,0,0,255,150,215,0,200,149,1,0,248,187,8,0,1,0,0,0,12,151,215,0,56,126,1,0,184,179,8,0,1,0,0,0,13,151,215,0,32,101,1,0,240,173,8,0,1,0,0,0,14,151,215,0,96,32,8,0,88,212,3,0,1,0,0,0,200,147,215,0,40,185,3,0,16,17,8,0,1,0,0,0,1,151,215,0,224,12,8,0,56,58,1,0,1,0,0,0,0,151,215,0,64,50,1,0,248,5,8,0,9,0,0,0,24,151,215,0,32,58,1,0,144,250,7,0,9,0,0,0,25,151,215,0,32,58,1,0,107,114,106,95,51,54,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,142,26,61,173,1,0,16,1,107,114,106,95,52,50,46,49,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,145,164,148,230,1,0,16,1,107,114,106,95,51,55,46,49,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,148,96,89,133,1,0,16,1,107,114,106,95,52,51,46,49,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,143,191,152,145,1,0,16,1,107,114,95,51,52,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,141,176,110,254,1,0,16,1,107,114,95,52,48,46,49,48,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,109,128,114,17,1,0,16,1,107,114,95,51,53,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,32,176,84,248,1,0,16,1,107,114,95,52,49,46,49,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,141,231,82,235,1,0,16,1,107,114,95,48,57,46,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,16,110,183,8,4,0,32,0,107,114,95,48,49,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,92,207,206,64,4,0,32,0,107,114,95,49,51,46,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,3,170,90,67,4,0,32,0,107,114,95,48,53,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,91,97,138,91,4,0,32,0,107,114,95,50,52,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,62,21,101,222,4,0,32,0,107,114,95,49,55,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,104,201,113,177,4,0,32,0,107,114,95,51,56,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,244,107,70,244,4,0,32,0,107,114,95,51,50,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,221,13,56,135,4,0,32,0,107,114,95,49,48,46,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,102,109,0,55,4,0,32,0,107,114,95,48,50,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,227,18,70,181,4,0,32,0,107,114,95,49,52,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,102,135,232,10,4,0,32,0,107,114,95,48,54,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,154,160,177,236,4,0,32,0,107,114,95,50,53,46,55,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,137,225,172,154,4,0,32,0,107,114,95,49,56,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,165,20,250,9,4,0,32,0,107,114,95,51,57,46,57,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,235,154,138,253,4,0,32,0,107,114,95,51,51,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,149,62,128,17,4,0,32,0,107,114,95,49,49,46,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,179,206,103,169,4,0,32,0,107,114,95,48,51,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,7,219,16,234,4,0,32,0,107,114,95,49,53,46,49,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,59,184,64,129,4,0,32,0,107,114,95,48,55,46,49,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,72,6,241,106,4,0,32,0,107,114,95,50,54,46,56,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,107,216,101,136,4,0,32,0,107,114,95,49,57,46,56,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,190,74,159,2,4,0,32,0,107,114,95,50,56,46,49,48,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,47,249,132,95,4,0,32,0,107,114,95,50,49,46,49,48,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,101,80,179,1,4,0,32,0,107,114,95,49,50,46,56,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,177,69,217,3,4,0,32,0,107,114,95,48,52,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,136,131,12,227,4,0,32,0,107,114,95,49,54,46,49,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,27,157,195,64,4,0,32,0,107,114,95,48,56,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,232,201,16,211,4,0,32,0,107,114,95,50,55,46,57,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,68,20,4,62,4,0,32,0,107,114,95,50,48,46,57,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,184,255,75,189,4,0,32,0,107,114,95,50,57,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,118,160,135,19,4,0,32,0,107,114,95,50,50,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,34,25,53,253,4,0,32,0,107,114,95,50,51,46,49,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,238,217,68,94,3,0,16,0,107,114,95,51,48,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,95,209,105,218,5,0,64,0,107,114,95,51,49,46,49,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,233,84,198,191,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,107,114,50,50,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,0,0,0,0,0,0,24,108,119,105,111,46,49,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,12,185,82,173,0,0,0,8,105,111,99,49,46,105,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,129,32,24,13,0,0,0,8,99,54,51,50,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,112,146,189,15,0,0,0,8,107,114,104,97,95,50,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,154,48,253,167,2,0,16,1,107,114,104,95,50,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,112,208,56,20,2,0,16,1,107,114,95,103,102,120,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,164,193,54,158,4,0,32,0,107,114,95,103,102,120,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,174,44,131,197,4,0,32,0,107,114,95,103,102,120,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,45,190,149,240,4,0,32,0,107,114,95,103,102,120,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,150,253,157,23,4,0,32,0,107,114,95,103,102,120,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,210,152,66,31,4,0,32,0,107,114,95,103,102,120,55,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,81,135,250,55,4,0,32,0,107,114,95,103,102,120,54,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,61,188,0,2,4,0,32,0,107,114,95,103,102,120,56,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,231,180,178,11,4,0,32,0,107,114,95,48,57,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,238,217,68,94,3,0,16,0,107,114,95,49,56,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,95,209,105,218,5,0,64,0,107,114,95,49,57,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,233,84,198,191,5,0,64,0,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,44,39,24,184,1,0,16,1,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,194,164,185,176,1,0,16,1,107,114,95,103,102,120,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,164,193,54,158,4,0,32,0,107,114,95,103,102,120,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,174,44,131,197,4,0,32,0,107,114,95,103,102,120,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,45,190,149,240,4,0,32,0,107,114,95,103,102,120,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,150,253,157,23,4,0,32,0,107,114,95,103,102,120,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,210,152,66,31,4,0,32,0,107,114,95,103,102,120,55,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,81,135,250,55,4,0,32,0,107,114,95,103,102,120,54,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,61,188,0,2,4,0,32,0,107,114,95,103,102,120,56,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,231,180,178,11,4,0,32,0,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,193,156,111,189,3,0,16,0,50,51,46,48,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,166,184,51,119,2,0,16,1,50,50,46,48,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,169,113,182,208,2,0,16,1,49,46,48,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,150,21,84,145,4,0,32,0,50,46,48,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,20,33,51,93,4,0,32,0,51,46,48,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,186,142,72,96,4,0,32,0,52,46,48,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,17,221,75,57,4,0,32,0,53,46,48,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,139,249,42,181,4,0,32,0,54,46,48,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,172,94,78,228,4,0,32,0,55,46,48,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,61,188,0,2,4,0,32,0,56,46,48,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,231,180,178,11,4,0,32,0,57,46,53,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,238,217,68,94,3,0,16,0,49,56,46,48,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,171,227,155,155,5,0,64,0,49,57,46,48,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,233,84,198,191,5,0,64,0,48,52,48,45,122,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,126,10,208,149,1,0,16,1,48,52,48,45,114,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,100,11,157,90,1,0,16,1,107,114,95,103,102,120,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,164,193,54,158,4,0,32,0,107,114,95,103,102,120,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,174,44,131,197,4,0,32,0,107,114,95,103,102,120,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,45,190,149,240,4,0,32,0,107,114,95,103,102,120,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,150,253,157,23,4,0,32,0,107,114,95,103,102,120,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,210,152,66,31,4,0,32,0,107,114,95,103,102,120,55,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,81,135,250,55,4,0,32,0,107,114,95,103,102,120,54,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,61,188,0,2,4,0,32,0,107,114,95,103,102,120,56,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,231,180,178,11,4,0,32,0,107,114,95,48,57,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,238,217,68,94,3,0,16,0,107,114,95,49,56,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,95,209,105,218,5,0,64,0,107,114,95,49,57,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,233,84,198,191,5,0,64,0,168,86,7,0,1,0,0,0,232,47,216,0,248,191,2,0,24,38,7,0,1,0,0,0,236,47,216,0,184,160,2,0,56,210,6,0,1,0,0,0,35,48,216,0,192,135,2,0,24,163,6,0,1,0,0,0,34,48,216,0,240,108,2,0,152,122,6,0,1,0,0,0,33,48,216,0,96,82,2,0,192,72,6,0,1,0,0,0,32,48,216,0,32,56,2,0,152,31,6,0,1,0,0,0,36,48,216,0,152,30,2,0,248,97,5,0,1,0,0,0,37,48,216,0,232,10,2,0,40,246,1,0,1,0,0,0,233,47,216,0,64,246,1,0,144,236,1,0,1,0,0,0,237,47,216,0,136,224,1,0,176,223,1,0,1,0,0,0,43,48,216,0,72,198,1,0,192,209,1,0,1,0,0,0,42,48,216,0,24,182,1,0,24,198,1,0,1,0,0,0,41,48,216,0,40,167,1,0,120,189,1,0,1,0,0,0,40,48,216,0,200,149,1,0,8,182,1,0,1,0,0,0,44,48,216,0,56,126,1,0,32,167,1,0,1,0,0,0,45,48,216,0,32,101,1,0,168,132,8,0,1,0,0,0,166,47,216,0,232,209,1,0,72,126,8,0,1,0,0,0,167,47,216,0,144,189,1,0,192,122,8,0,1,0,0,0,163,47,216,0,208,174,1,0,40,116,8,0,1,0,0,0,162,47,216,0,48,160,1,0,72,110,8,0,1,0,0,0,161,47,216,0,160,140,1,0,184,102,8,0,1,0,0,0,160,47,216,0,56,112,1,0,248,93,8,0,1,0,0,0,164,47,216,0,32,92,1,0,152,86,8,0,1,0,0,0,165,47,216,0,64,77,1,0,88,212,3,0,1,0,0,0,144,46,216,0,40,185,3,0,240,152,1,0,1,0,0,0,238,47,216,0,216,70,1,0,16,17,8,0,1,0,0,0,234,47,216,0,224,12,8,0,72,65,1,0,9,0,0,0,232,48,216,0,32,58,1,0,48,50,1,0,9,0,0,0,224,48,216,0,32,58,1,0,224,41,1,0,9,0,0,0,216,48,216,0,32,58,1,0,112,114,103,49,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,70,144,180,108,1,0,16,1,112,114,103,50,46,55,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,22,180,35,194,1,0,16,1,112,114,103,51,46,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,192,52,54,69,1,0,16,1,107,98,106,49,46,105,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,183,190,22,186,2,0,16,1,107,98,106,50,46,105,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,99,106,104,86,2,0,16,1,107,98,106,51,46,105,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,165,112,197,251,2,0,16,1,107,98,106,50,46,105,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,99,106,104,86,2,0,16,1,99,104,103,49,46,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,231,80,213,156,4,0,32,0,99,104,103,50,46,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,125,117,6,162,4,0,32,0,107,98,50,45,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,22,91,221,21,7,0,32,0,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,186,137,165,211,0,0,16,1,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,166,225,225,154,0,0,16,1,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,253,191,166,165,0,0,16,1,109,113,106,45,115,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,130,53,207,187,0,0,16,1,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,26,213,136,23,0,0,32,0,109,113,106,45,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,109,147,217,73,0,0,32,0,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,146,172,12,15,0,0,32,0,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,168,34,56,125,0,0,32,0,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,163,79,251,86,0,0,32,0,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,78,189,125,148,0,0,32,0,109,113,106,45,118,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,86,41,118,84,0,0,64,0,56,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,18,187,121,115,0,0,32,0,54,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,187,12,206,250,0,0,32,0,55,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,187,12,206,250,0,0,32,0,168,86,7,0,1,0,0,0,136,239,146,0,248,191,2,0,200,110,3,0,1,0,0,0,220,254,146,0,152,30,2,0,88,212,3,0,1,0,0,0,160,218,146,0,40,185,3,0,16,17,8,0,1,0,0,0,122,246,146,0,224,12,8,0,72,65,1,0,9,0,0,0,48,5,147,0,32,58,1,0,48,50,1,0,9,0,0,0,49,5,147,0,32,58,1,0,224,41,1,0,9,0,0,0,50,5,147,0,32,58,1,0,102,95,114,95,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,103,170,243,232,1,0,16,1,102,95,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,227,131,130,245,1,0,16,1,102,95,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,174,189,234,221,1,0,16,1,102,95,114,95,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,136,10,83,200,1,0,16,1,102,95,114,95,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,224,119,45,218,1,0,16,1,114,95,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,207,55,126,151,4,0,32,0,114,95,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,201,34,186,208,4,0,32,0,54,108,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,103,148,172,195,7,0,32,0,184,40,2,0,1,0,0,0,96,232,148,0,248,191,2,0,56,250,6,0,1,0,0,0,98,232,148,0,184,160,2,0,184,164,8,0,1,0,0,0,97,232,148,0,64,246,1,0,88,149,7,0,1,0,0,0,99,232,148,0,136,224,1,0,56,210,6,0,1,0,0,0,216,233,148,0,192,135,2,0,24,163,6,0,1,0,0,0,217,233,148,0,240,108,2,0,152,122,6,0,1,0,0,0,218,233,148,0,96,82,2,0,192,72,6,0,1,0,0,0,219,233,148,0,32,56,2,0,48,123,2,0,1,0,0,0,220,233,148,0,152,30,2,0,96,69,2,0,1,0,0,0,221,233,148,0,232,10,2,0,176,223,1,0,1,0,0,0,24,233,148,0,72,198,1,0,192,209,1,0,1,0,0,0,25,233,148,0,24,182,1,0,24,198,1,0,1,0,0,0,26,233,148,0,40,167,1,0,120,189,1,0,1,0,0,0,27,233,148,0,200,149,1,0,248,187,8,0,1,0,0,0,28,233,148,0,56,126,1,0,184,179,8,0,1,0,0,0,29,233,148,0,32,101,1,0,88,212,3,0,1,0,0,0,192,218,146,0,40,185,3,0,248,5,8,0,9,0,0,0,112,94,147,0,32,58,1,0,144,250,7,0,9,0,0,0,113,94,147,0,32,58,1,0,184,40,2,0,1,0,0,0,184,148,215,0,248,191,2,0,56,250,6,0,1,0,0,0,188,148,215,0,184,160,2,0,184,164,8,0,1,0,0,0,185,148,215,0,64,246,1,0,88,149,7,0,1,0,0,0,189,148,215,0,136,224,1,0,152,122,6,0,1,0,0,0,183,148,215,0,96,82,2,0,192,72,6,0,1,0,0,0,182,148,215,0,32,56,2,0,48,123,2,0,1,0,0,0,177,148,215,0,152,30,2,0,96,69,2,0,1,0,0,0,178,148,215,0,232,10,2,0,88,212,3,0,1,0,0,0,200,147,215,0,40,185,3,0,248,5,8,0,9,0,0,0,96,149,215,0,32,58,1,0,144,250,7,0,9,0,0,0,97,149,215,0,32,58,1,0,184,40,2,0,1,0,0,0,40,39,216,0,248,191,2,0,56,250,6,0,1,0,0,0,32,39,216,0,184,160,2,0,184,164,8,0,1,0,0,0,37,39,216,0,64,246,1,0,88,149,7,0,1,0,0,0,33,39,216,0,136,224,1,0,240,167,7,0,1,0,0,0,47,39,216,0,192,135,2,0,176,163,7,0,1,0,0,0,46,39,216,0,240,108,2,0,208,158,7,0,1,0,0,0,42,39,216,0,96,82,2,0,184,154,7,0,1,0,0,0,43,39,216,0,32,56,2,0,176,108,2,0,1,0,0,0,44,39,216,0,152,30,2,0,8,96,7,0,1,0,0,0,41,39,216,0,72,198,1,0,48,89,7,0,1,0,0,0,39,39,216,0,24,182,1,0,16,83,7,0,1,0,0,0,34,39,216,0,40,167,1,0,96,79,7,0,1,0,0,0,35,39,216,0,200,149,1,0,48,76,7,0,1,0,0,0,36,39,216,0,56,126,1,0,88,212,3,0,1,0,0,0,48,38,216,0,40,185,3,0,248,5,8,0,9,0,0,0,112,39,216,0,32,58,1,0,144,250,7,0,9,0,0,0,113,39,216,0,32,58,1,0,248,241,7,0,9,0,0,0,114,39,216,0,32,58,1,0,168,86,7,0,1,0,0,0,91,238,146,0,248,191,2,0,24,38,7,0,1,0,0,0,199,251,146,0,184,160,2,0,56,210,6,0,1,0,0,0,194,251,146,0,192,135,2,0,24,163,6,0,1,0,0,0,195,251,146,0,240,108,2,0,152,122,6,0,1,0,0,0,192,251,146,0,96,82,2,0,192,72,6,0,1,0,0,0,193,251,146,0,32,56,2,0,200,110,3,0,1,0,0,0,196,251,146,0,152,30,2,0,120,89,3,0,1,0,0,0,197,251,146,0,232,10,2,0,40,246,1,0,1,0,0,0,90,238,146,0,64,246,1,0,144,236,1,0,1,0,0,0,143,243,146,0,136,224,1,0,176,223,1,0,1,0,0,0,138,243,146,0,72,198,1,0,192,209,1,0,1,0,0,0,139,243,146,0,24,182,1,0,24,198,1,0,1,0,0,0,136,243,146,0,40,167,1,0,120,189,1,0,1,0,0,0,137,243,146,0,200,149,1,0,224,22,1,0,1,0,0,0,140,243,146,0,56,126,1,0,160,14,1,0,1,0,0,0,141,243,146,0,32,101,1,0,88,212,3,0,1,0,0,0,120,216,146,0,40,185,3,0,16,17,8,0,1,0,0,0,88,238,146,0,224,12,8,0,56,58,1,0,1,0,0,0,89,238,146,0,64,50,1,0,72,65,1,0,9,0,0,0,216,3,147,0,32,58,1,0,48,50,1,0,9,0,0,0,217,3,147,0,32,58,1,0,104,112,97,99,117,104,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,198,178,58,99,0,0,16,1,104,112,97,99,117,105,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,209,0,220,35,0,0,16,1,104,121,112,101,114,112,97,99,46,97,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,218,115,134,189,0,0,32,0,104,121,112,101,114,112,97,99,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,130,205,144,93,0,0,32,0,104,121,112,101,114,112,97,99,46,97,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,99,110,216,97,0,0,32,0,104,121,112,101,114,112,97,99,46,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,142,248,250,3,0,0,64,0,104,121,112,101,114,112,97,99,46,106,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,141,70,159,251,0,0,64,0,184,40,2,0,1,0,0,0,208,155,215,0,248,191,2,0,56,250,6,0,1,0,0,0,212,155,215,0,184,160,2,0,184,164,8,0,1,0,0,0,209,155,215,0,64,246,1,0,88,149,7,0,1,0,0,0,213,155,215,0,136,224,1,0,8,3,3,0,4,0,0,0,112,156,215,0,208,13,4,0,208,158,7,0,4,0,0,0,104,156,215,0,152,30,2,0,184,154,7,0,4,0,0,0,96,156,215,0,232,10,2,0,16,17,8,0,1,0,0,0,211,155,215,0,224,12,8,0,32,77,1,0,1,0,0,0,210,155,215,0,216,70,1,0,88,212,3,0,1,0,0,0,200,154,215,0,40,185,3,0,248,5,8,0,9,0,0,0,0,156,215,0,32,58,1,0,144,250,7,0,9,0,0,0,1,156,215,0,32,58,1,0,184,40,2,0,1,0,0,0,47,39,216,0,248,191,2,0,56,250,6,0,1,0,0,0,39,39,216,0,184,160,2,0,184,164,8,0,1,0,0,0,46,39,216,0,64,246,1,0,88,149,7,0,1,0,0,0,38,39,216,0,136,224,1,0,240,167,7,0,1,0,0,0,28,39,216,0,192,135,2,0,176,163,7,0,1,0,0,0,30,39,216,0,240,108,2,0,208,158,7,0,1,0,0,0,45,39,216,0,96,82,2,0,184,154,7,0,1,0,0,0,44,39,216,0,32,56,2,0,176,108,2,0,1,0,0,0,43,39,216,0,152,30,2,0,8,96,7,0,1,0,0,0,40,39,216,0,72,198,1,0,48,89,7,0,1,0,0,0,25,39,216,0,24,182,1,0,16,83,7,0,1,0,0,0,37,39,216,0,40,167,1,0,96,79,7,0,1,0,0,0,36,39,216,0,200,149,1,0,48,76,7,0,1,0,0,0,35,39,216,0,56,126,1,0,88,212,3,0,1,0,0,0,48,38,216,0,40,185,3,0,16,17,8,0,1,0,0,0,42,39,216,0,224,12,8,0,248,5,8,0,9,0,0,0,112,39,216,0,32,58,1,0,144,250,7,0,9,0,0,0,113,39,216,0,32,58,1,0,248,241,7,0,9,0,0,0,114,39,216,0,32,58,1,0,104,111,116,115,104,111,99,107,46,108,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,247,120,16,64,1,0,16,1,104,111,116,115,104,111,99,107,46,108,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,55,194,118,175,1,0,16,1,104,111,116,115,104,111,99,107,46,108,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,49,96,72,48,1,0,16,1,104,111,116,115,104,111,99,107,46,108,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,18,147,222,91,1,0,16,1,104,111,116,115,104,111,99,107,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,226,240,146,0,2,0,16,1,104,111,116,115,104,111,99,107,46,98,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,68,90,19,194,2,0,16,1,104,111,116,115,104,111,99,107,46,104,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,169,174,189,96,4,0,32,0,104,111,116,115,104,111,99,107,46,104,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,83,116,241,78,4,0,32,0,99,48,49,115,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,171,174,60,78,7,0,32,0,184,40,2,0,1,0,0,0,204,233,148,0,248,191,2,0,56,250,6,0,1,0,0,0,15,233,148,0,184,160,2,0,184,164,8,0,1,0,0,0,205,233,148,0,64,246,1,0,88,149,7,0,1,0,0,0,87,232,148,0,136,224,1,0,56,210,6,0,1,0,0,0,8,233,148,0,192,135,2,0,24,163,6,0,1,0,0,0,9,233,148,0,240,108,2,0,152,122,6,0,1,0,0,0,10,233,148,0,96,82,2,0,192,72,6,0,1,0,0,0,11,233,148,0,32,56,2,0,48,123,2,0,1,0,0,0,12,233,148,0,152,30,2,0,96,69,2,0,1,0,0,0,13,233,148,0,232,10,2,0,88,212,3,0,1,0,0,0,136,218,146,0,40,185,3,0,248,5,8,0,9,0,0,0,96,94,147,0,32,58,1,0,144,250,7,0,9,0,0,0,97,94,147,0,32,58,1,0,168,86,7,0,1,0,0,0,216,235,146,0,248,191,2,0,24,38,7,0,1,0,0,0,213,235,146,0,184,160,2,0,120,198,7,0,1,0,0,0,208,235,146,0,88,94,5,0,16,150,7,0,1,0,0,0,200,235,146,0,40,90,5,0,160,103,7,0,1,0,0,0,192,235,146,0,128,83,5,0,16,53,7,0,1,0,0,0,184,235,146,0,168,77,5,0,128,9,7,0,1,0,0,0,209,235,146,0,0,69,5,0,32,223,6,0,1,0,0,0,201,235,146,0,32,64,5,0,168,178,6,0,1,0,0,0,193,235,146,0,48,59,5,0,184,135,6,0,1,0,0,0,185,235,146,0,248,53,5,0,160,89,6,0,1,0,0,0,210,235,146,0,0,46,5,0,192,43,6,0,1,0,0,0,202,235,146,0,248,37,5,0,136,1,6,0,1,0,0,0,212,235,146,0,120,32,5,0,216,211,5,0,1,0,0,0,186,235,146,0,192,27,5,0,32,172,5,0,1,0,0,0,211,235,146,0,192,22,5,0,88,136,5,0,1,0,0,0,203,235,146,0,48,16,5,0,192,152,5,0,1,0,0,0,187,235,146,0,32,2,5,0,216,192,5,0,1,0,0,0,195,235,146,0,8,252,4,0,16,24,6,0,1,0,0,0,212,235,146,0,24,8,5,0,192,185,5,0,1,0,0,0,196,235,146,0,128,237,4,0,192,232,5,0,1,0,0,0,204,235,146,0,56,244,4,0,40,246,1,0,1,0,0,0,218,235,146,0,64,246,1,0,144,236,1,0,1,0,0,0,181,235,146,0,136,224,1,0,120,198,7,0,1,0,0,0,176,235,146,0,88,94,5,0,16,150,7,0,1,0,0,0,168,235,146,0,40,90,5,0,160,103,7,0,1,0,0,0,160,235,146,0,128,83,5,0,16,53,7,0,1,0,0,0,152,235,146,0,168,77,5,0,128,9,7,0,1,0,0,0,177,235,146,0,0,69,5,0,32,223,6,0,1,0,0,0,169,235,146,0,32,64,5,0,168,178,6,0,1,0,0,0,161,235,146,0,48,59,5,0,184,135,6,0,1,0,0,0,153,235,146,0,248,53,5,0,160,89,6,0,1,0,0,0,178,235,146,0,0,46,5,0,192,43,6,0,1,0,0,0,170,235,146,0,248,37,5,0,136,1,6,0,1,0,0,0,180,235,146,0,120,32,5,0,216,211,5,0,1,0,0,0,154,235,146,0,192,27,5,0,32,172,5,0,1,0,0,0,179,235,146,0,192,22,5,0,88,136,5,0,1,0,0,0,171,235,146,0,48,16,5,0,192,152,5,0,1,0,0,0,155,235,146,0,32,2,5,0,216,192,5,0,1,0,0,0,163,235,146,0,8,252,4,0,16,24,6,0,1,0,0,0,180,235,146,0,24,8,5,0,192,185,5,0,1,0,0,0,164,235,146,0,128,237,4,0,192,232,5,0,1,0,0,0,172,235,146,0,56,244,4,0,88,212,3,0,1,0,0,0,240,218,146,0,40,185,3,0,16,17,8,0,1,0,0,0,220,235,146,0,224,12,8,0,16,17,8,0,1,0,0,0,223,235,146,0,224,12,8,0,72,65,1,0,9,0,0,0,96,5,147,0,32,58,1,0,168,86,7,0,1,0,0,0,160,1,147,0,248,191,2,0,24,38,7,0,1,0,0,0,163,1,147,0,184,160,2,0,56,210,6,0,1,0,0,0,226,248,146,0,192,135,2,0,24,163,6,0,1,0,0,0,227,248,146,0,240,108,2,0,152,122,6,0,1,0,0,0,224,248,146,0,96,82,2,0,192,72,6,0,1,0,0,0,225,248,146,0,32,56,2,0,200,110,3,0,1,0,0,0,228,248,146,0,152,30,2,0,120,89,3,0,1,0,0,0,229,248,146,0,232,10,2,0,40,246,1,0,1,0,0,0,161,1,147,0,64,246,1,0,144,236,1,0,1,0,0,0,164,1,147,0,136,224,1,0,176,223,1,0,1,0,0,0,194,240,146,0,72,198,1,0,192,209,1,0,1,0,0,0,195,240,146,0,24,182,1,0,24,198,1,0,1,0,0,0,192,240,146,0,40,167,1,0,120,189,1,0,1,0,0,0,193,240,146,0,200,149,1,0,224,22,1,0,1,0,0,0,196,240,146,0,56,126,1,0,160,14,1,0,1,0,0,0,197,240,146,0,32,101,1,0,88,212,3,0,1,0,0,0,32,221,146,0,40,185,3,0,16,17,8,0,1,0,0,0,162,1,147,0,224,12,8,0,72,65,1,0,9,0,0,0,232,6,147,0,32,58,1,0,48,50,1,0,9,0,0,0,233,6,147,0,32,58,1,0,224,41,1,0,9,0,0,0,234,6,147,0,32,58,1,0,97,50,49,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,80,74,236,197,0,0,16,1,97,50,49,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,189,35,147,78,0,0,16,1,97,50,49,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,212,89,230,87,0,0,16,1,97,50,49,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,243,147,114,30,0,0,16,1,97,50,49,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,162,10,206,178,0,0,16,1,97,50,49,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,208,24,186,173,0,0,32,0,97,50,49,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,201,241,125,165,0,0,32,0,97,50,49,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,163,59,98,99,0,0,32,0,97,50,49,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,169,105,201,76,0,0,32,0,97,50,49,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,91,77,92,156,0,0,32,0,97,50,49,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,173,90,107,211,0,0,32,0,97,50,49,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,162,174,135,243,0,0,32,0,97,50,49,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,125,125,150,135,0,0,32,0,97,50,49,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,180,10,100,89,0,0,32,0,97,50,49,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,216,136,173,34,0,0,32,0,97,50,49,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,86,251,37,204,0,0,32,0,97,50,49,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,72,68,5,202,0,0,32,0,97,50,49,46,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,73,196,192,35,0,0,32,0,97,50,49,46,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,94,152,196,239,0,0,32,0,109,49,46,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,1,146,163,131,0,0,32,0,99,55,49,45,48,57,46,105,99,52,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,162,68,165,16,2,0,16,1,99,55,49,45,48,56,46,105,99,52,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,160,192,125,193,2,0,16,1,99,55,49,45,49,48,46,105,99,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,6,10,156,243,2,0,16,1,99,55,49,45,49,49,46,105,99,51,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,26,193,35,223,2,0,16,1,99,55,49,45,49,54,46,105,99,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,212,194,188,27,2,0,16,1,99,55,49,45,49,53,46,105,99,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,187,0,62,223,2,0,16,1,99,55,49,45,49,50,46,105,99,52,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,248,199,56,0,9,0,16,1,99,55,49,45,48,50,46,105,99,53,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,146,12,96,42,11,0,32,0,99,55,49,45,48,51,46,105,99,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,5,198,51,145,15,0,32,0,99,55,49,45,48,49,46,105,99,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,90,16,115,14,24,0,64,0,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,2,2,0,96,135,7,0,19,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,4,4,0,96,135,7,0,19,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,8,0,0,96,135,7,0,19,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,19,0,0,0,1,48,0,0,16,242,7,0,19,0,0,0,1,48,16,0,104,236,7,0,19,0,0,0,1,48,48,0,128,230,7,0,19,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,19,0,0,0,1,192,0,0,16,242,7,0,19,0,0,0,1,192,64,0,104,236,7,0,19,0,0,0,1,192,192,0,128,230,7,0,19,0,0,0,1,192,128,0,184,164,6,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,3,2,0,80,246,3,0,20,0,0,0,1,3,3,0,80,124,6,0,20,0,0,0,1,3,1,0,112,212,3,0,20,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,64,37,5,0,20,0,0,0,1,12,8,0,128,189,4,0,20,0,0,0,1,12,12,0,216,186,4,0,20,0,0,0,1,12,4,0,8,184,4,0,20,0,0,0,1,12,0,0,32,182,4,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,48,32,0,192,255,2,0,20,0,0,0,1,48,16,0,208,75,4,0,20,0,0,0,1,48,48,0,8,49,4,0,20,0,0,0,1,48,0,0,72,246,3,0,0,0,0,0,254,0,2,0,104,159,3,0,20,0,0,0,1,64,0,0,96,135,7,0,20,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,6,0,20,0,0,0,1,128,0,0,8,208,6,0,20,0,0,0,1,128,128,0,88,204,6,0,184,40,2,0,1,0,0,0,214,155,215,0,248,191,2,0,56,250,6,0,1,0,0,0,211,155,215,0,184,160,2,0,184,164,8,0,1,0,0,0,215,155,215,0,64,246,1,0,8,3,3,0,4,0,0,0,112,156,215,0,208,13,4,0,208,240,5,0,4,0,0,0,104,156,215,0,152,30,2,0,32,201,5,0,4,0,0,0,96,156,215,0,232,10,2,0,144,47,8,0,1,0,0,0,212,155,215,0,152,138,8,0,192,33,8,0,1,0,0,0,213,155,215,0,48,119,7,0,16,17,8,0,1,0,0,0,210,155,215,0,224,12,8,0,32,77,1,0,1,0,0,0,209,155,215,0,216,70,1,0,88,212,3,0,1,0,0,0,200,154,215,0,40,185,3,0,248,5,8,0,9,0,0,0,0,156,215,0,32,58,1,0,144,250,7,0,9,0,0,0,1,156,215,0,32,58,1,0,101,112,114,45,49,50,53,52,51,46,105,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,164,156,223,176,1,0,16,1,101,112,114,45,49,50,53,52,50,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,60,77,153,183,1,0,16,1,101,112,114,45,49,50,51,56,53,46,105,99,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,224,231,164,184,2,0,32,0,101,112,114,45,49,50,51,56,54,46,105,99,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,121,215,215,37,2,0,32,0,101,112,114,45,49,50,51,56,55,46,105,99,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,243,173,252,199,2,0,32,0,109,112,114,45,49,50,51,55,56,46,105,99,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,130,90,158,17,3,0,32,0,109,112,114,45,49,50,51,55,57,46,105,99,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,87,140,14,26,3,0,32,0,109,112,114,45,49,50,51,56,48,46,105,99,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,83,8,44,187,3,0,32,0,109,112,114,45,49,50,51,56,49,46,105,99,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,204,110,186,129,3,0,32,0,109,112,114,45,49,50,51,56,50,46,105,99,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,111,28,96,129,3,0,32,0,109,112,114,45,49,50,51,56,51,46,105,99,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,122,207,186,93,3,0,32,0,101,112,114,45,49,50,51,57,48,46,105,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,245,197,159,57,4,0,16,1,109,112,114,45,49,50,51,56,52,46,105,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,231,216,24,98,8,0,64,0,51,49,55,45,48,49,50,50,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,251,194,35,241,5,0,16,1,101,112,114,45,49,50,53,52,48,46,97,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,109,204,124,12,1,0,16,1,101,112,114,45,49,50,53,51,57,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,208,247,36,31,1,0,16,1,101,112,114,45,49,50,53,50,49,46,97,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,19,215,1,80,1,0,16,1,101,112,114,45,49,50,53,49,57,46,97,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,142,202,56,68,1,0,16,1,101,112,114,45,49,50,51,56,53,46,97,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,224,231,164,184,2,0,32,0,101,112,114,45,49,50,51,56,54,46,97,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,121,215,215,37,2,0,32,0,101,112,114,45,49,50,51,56,55,46,97,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,243,173,252,199,2,0,32,0,109,112,114,45,49,50,51,55,56,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,130,90,158,17,3,0,32,0,109,112,114,45,49,50,51,55,57,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,87,140,14,26,3,0,32,0,109,112,114,45,49,50,51,56,48,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,83,8,44,187,3,0,32,0,109,112,114,45,49,50,51,56,49,46,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,204,110,186,129,3,0,32,0,109,112,114,45,49,50,51,56,50,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,111,28,96,129,3,0,32,0,109,112,114,45,49,50,51,56,51,46,98,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,122,207,186,93,3,0,32,0,101,112,114,45,49,50,51,57,48,46,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,245,197,159,57,4,0,16,1,109,112,114,45,49,50,51,56,52,46,97,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,231,216,24,98,8,0,64,0,51,49,55,45,48,49,50,49,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,1,237,175,114,5,0,16,1,101,112,114,45,49,50,53,50,53,46,97,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,118,44,51,72,1,0,16,1,101,112,114,45,49,50,53,50,52,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,66,243,88,142,1,0,16,1,101,112,114,45,49,50,53,50,49,46,97,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,19,215,1,80,1,0,16,1,101,112,114,45,49,50,53,49,57,46,97,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,142,202,56,68,1,0,16,1,101,112,114,45,49,50,51,56,53,46,97,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,224,231,164,184,2,0,32,0,101,112,114,45,49,50,51,56,54,46,97,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,121,215,215,37,2,0,32,0,101,112,114,45,49,50,51,56,55,46,97,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,243,173,252,199,2,0,32,0,109,112,114,45,49,50,51,55,56,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,130,90,158,17,3,0,32,0,109,112,114,45,49,50,51,55,57,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,87,140,14,26,3,0,32,0,109,112,114,45,49,50,51,56,48,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,83,8,44,187,3,0,32,0,109,112,114,45,49,50,51,56,49,46,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,204,110,186,129,3,0,32,0,109,112,114,45,49,50,51,56,50,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,111,28,96,129,3,0,32,0,109,112,114,45,49,50,51,56,51,46,98,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,122,207,186,93,3,0,32,0,101,112,114,45,49,50,51,57,48,46,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,245,197,159,57,4,0,16,1,109,112,114,45,49,50,51,56,52,46,97,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,231,216,24,98,8,0,64,0,51,49,55,45,48,49,50,48,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,166,159,110,148,5,0,16,1,101,112,114,45,49,50,53,50,51,46,97,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,215,40,97,142,1,0,16,1,101,112,114,45,49,50,53,50,50,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,96,81,195,182,1,0,16,1,101,112,114,45,49,50,53,50,49,46,97,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,19,215,1,80,1,0,16,1,101,112,114,45,49,50,53,49,57,46,97,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,142,202,56,68,1,0,16,1,101,112,114,45,49,50,51,56,53,46,97,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,224,231,164,184,2,0,32,0,101,112,114,45,49,50,51,56,54,46,97,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,121,215,215,37,2,0,32,0,101,112,114,45,49,50,51,56,55,46,97,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,243,173,252,199,2,0,32,0,109,112,114,45,49,50,51,55,56,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,130,90,158,17,3,0,32,0,109,112,114,45,49,50,51,55,57,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,87,140,14,26,3,0,32,0,109,112,114,45,49,50,51,56,48,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,83,8,44,187,3,0,32,0,109,112,114,45,49,50,51,56,49,46,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,204,110,186,129,3,0,32,0,109,112,114,45,49,50,51,56,50,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,111,28,96,129,3,0,32,0,109,112,114,45,49,50,51,56,51,46,98,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,122,207,186,93,3,0,32,0,101,112,114,45,49,50,51,57,48,46,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,245,197,159,57,4,0,16,1,109,112,114,45,49,50,51,56,52,46,97,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,231,216,24,98,8,0,64,0,51,49,55,45,48,49,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,16,101,112,114,45,49,50,51,56,57,46,105,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,119,250,213,53,1,0,16,1,101,112,114,45,49,50,51,56,56,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,147,42,149,114,1,0,16,1,101,112,114,45,49,50,51,56,53,46,105,99,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,224,231,164,184,2,0,32,0,101,112,114,45,49,50,51,56,54,46,105,99,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,121,215,215,37,2,0,32,0,101,112,114,45,49,50,51,56,55,46,105,99,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,243,173,252,199,2,0,32,0,109,112,114,45,49,50,51,55,56,46,105,99,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,130,90,158,17,3,0,32,0,109,112,114,45,49,50,51,55,57,46,105,99,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,87,140,14,26,3,0,32,0,109,112,114,45,49,50,51,56,48,46,105,99,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,83,8,44,187,3,0,32,0,109,112,114,45,49,50,51,56,49,46,105,99,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,204,110,186,129,3,0,32,0,109,112,114,45,49,50,51,56,50,46,105,99,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,111,28,96,129,3,0,32,0,109,112,114,45,49,50,51,56,51,46,105,99,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,122,207,186,93,3,0,32,0,101,112,114,45,49,50,51,57,48,46,105,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,245,197,159,57,4,0,16,1,109,112,114,45,49,50,51,56,52,46,105,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,231,216,24,98,8,0,64,0,51,49,55,45,48,49,49,48,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,198,125,81,205,5,0,16,1,184,40,2,0,1,0,0,0,40,39,216,0,248,191,2,0,56,250,6,0,1,0,0,0,32,39,216,0,184,160,2,0,88,149,7,0,1,0,0,0,33,39,216,0,136,224,1,0,240,167,7,0,1,0,0,0,47,39,216,0,192,135,2,0,176,163,7,0,1,0,0,0,46,39,216,0,240,108,2,0,208,158,7,0,1,0,0,0,42,39,216,0,96,82,2,0,184,154,7,0,1,0,0,0,43,39,216,0,32,56,2,0,176,108,2,0,1,0,0,0,44,39,216,0,152,30,2,0,8,96,7,0,1,0,0,0,41,39,216,0,72,198,1,0,48,89,7,0,1,0,0,0,37,39,216,0,24,182,1,0,16,83,7,0,1,0,0,0,34,39,216,0,40,167,1,0,96,79,7,0,1,0,0,0,35,39,216,0,200,149,1,0,48,76,7,0,1,0,0,0,36,39,216,0,56,126,1,0,88,212,3,0,1,0,0,0,48,38,216,0,40,185,3,0,120,86,1,0,9,0,0,0,112,39,216,0,32,58,1,0,0,76,1,0,9,0,0,0,113,39,216,0,32,58,1,0,112,75,1,0,9,0,0,0,114,39,216,0,32,58,1,0,168,74,1,0,9,0,0,0,115,39,216,0,32,58,1,0,56,73,1,0,9,0,0,0,116,39,216,0,32,58,1,0,232,84,1,0,9,0,0,0,117,39,216,0,32,58,1,0,120,72,1,0,9,0,0,0,80,39,216,0,32,58,1,0,103,103,119,106,46,48,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,145,59,210,253,1,0,16,1,103,103,119,106,46,48,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,60,9,110,140,1,0,16,1,103,103,119,106,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,84,20,129,67,1,0,16,1,103,103,119,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,164,48,85,16,5,0,32,0,103,103,119,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,185,74,119,158,5,0,32,0,103,103,119,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,164,11,110,70,5,0,32,0,103,103,119,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,234,141,12,132,5,0,32,0,103,103,119,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,213,81,99,76,10,0,16,1,103,103,119,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,245,172,114,225,12,0,64,0,103,103,119,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,143,78,238,75,12,0,64,0,103,103,119,104,46,48,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,235,54,238,185,1,0,16,1,103,103,119,104,46,48,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,254,72,229,114,1,0,16,1,103,103,119,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,66,214,57,50,1,0,16,1,103,103,119,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,164,48,85,16,5,0,32,0,103,103,119,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,185,74,119,158,5,0,32,0,103,103,119,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,164,11,110,70,5,0,32,0,103,103,119,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,234,141,12,132,5,0,32,0,103,103,119,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,213,81,99,76,10,0,16,1,103,103,119,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,245,172,114,225,12,0,64,0,103,103,119,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,143,78,238,75,12,0,64,0,103,103,119,117,95,100,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,250,45,233,221,1,0,16,1,103,103,119,117,95,100,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,226,154,80,224,1,0,16,1,103,103,119,95,100,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,66,0,45,114,1,0,16,1,103,103,119,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,164,48,85,16,5,0,32,0,103,103,119,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,185,74,119,158,5,0,32,0,103,103,119,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,164,11,110,70,5,0,32,0,103,103,119,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,234,141,12,132,5,0,32,0,103,103,119,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,213,81,99,76,10,0,16,1,103,103,119,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,245,172,114,225,12,0,64,0,103,103,119,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,143,78,238,75,12,0,64,0,103,103,119,98,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,72,164,248,161,1,0,16,1,103,103,119,98,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,118,62,66,106,1,0,16,1,103,103,119,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,66,214,57,50,1,0,16,1,103,103,119,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,164,48,85,16,5,0,32,0,103,103,119,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,185,74,119,158,5,0,32,0,103,103,119,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,164,11,110,70,5,0,32,0,103,103,119,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,234,141,12,132,5,0,32,0,103,103,119,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,213,81,99,76,10,0,16,1,103,103,119,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,245,172,114,225,12,0,64,0,103,103,119,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,143,78,238,75,12,0,64,0,103,103,119,97,46,48,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,55,136,111,17,1,0,16,1,103,103,119,97,46,48,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,196,240,227,230,1,0,16,1,103,103,119,97,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,201,138,94,70,1,0,16,1,103,103,119,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,164,48,85,16,5,0,32,0,103,103,119,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,185,74,119,158,5,0,32,0,103,103,119,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,164,11,110,70,5,0,32,0,103,103,119,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,234,141,12,132,5,0,32,0,103,103,119,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,213,81,99,76,10,0,16,1,103,103,119,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,245,172,114,225,12,0,64,0,103,103,119,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,143,78,238,75,12,0,64,0,101,97,115,116,45,49,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,224,80,12,41,2,0,16,1,101,97,115,116,45,51,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,175,130,239,156,2,0,16,1,101,97,115,116,95,50,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,208,180,148,221,2,0,16,1,101,97,115,116,95,52,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,10,49,71,166,2,0,16,1,101,97,115,116,95,53,46,49,55,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,244,181,74,178,9,0,16,1,101,97,115,116,95,56,46,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,40,206,238,117,15,0,32,0,101,97,115,116,95,55,46,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,106,167,121,177,15,0,32,0,101,97,115,116,95,57,46,51,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,152,104,94,92,15,0,32,0,101,97,115,116,95,54,46,51,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,233,48,219,82,15,0,32,0,101,97,115,116,45,49,49,46,49,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,150,31,17,146,24,0,64,0,101,97,115,116,45,49,48,46,49,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,25,196,10,202,25,0,64,0,168,86,7,0,1,0,0,0,195,236,146,0,248,191,2,0,24,38,7,0,1,0,0,0,208,237,146,0,184,160,2,0,56,210,6,0,1,0,0,0,136,250,146,0,192,135,2,0,24,163,6,0,1,0,0,0,137,250,146,0,240,108,2,0,152,122,6,0,1,0,0,0,138,250,146,0,96,82,2,0,192,72,6,0,1,0,0,0,139,250,146,0,32,56,2,0,200,110,3,0,1,0,0,0,140,250,146,0,152,30,2,0,120,89,3,0,1,0,0,0,141,250,146,0,232,10,2,0,40,246,1,0,1,0,0,0,194,236,146,0,64,246,1,0,144,236,1,0,1,0,0,0,209,237,146,0,136,224,1,0,176,223,1,0,1,0,0,0,96,242,146,0,72,198,1,0,192,209,1,0,1,0,0,0,97,242,146,0,24,182,1,0,24,198,1,0,1,0,0,0,98,242,146,0,40,167,1,0,120,189,1,0,1,0,0,0,99,242,146,0,200,149,1,0,224,22,1,0,1,0,0,0,100,242,146,0,56,126,1,0,160,14,1,0,1,0,0,0,101,242,146,0,32,101,1,0,168,132,8,0,1,0,0,0,193,236,146,0,232,209,1,0,72,126,8,0,1,0,0,0,210,237,146,0,144,189,1,0,192,122,8,0,1,0,0,0,0,238,146,0,208,174,1,0,40,116,8,0,1,0,0,0,1,238,146,0,48,160,1,0,72,110,8,0,1,0,0,0,2,238,146,0,160,140,1,0,184,102,8,0,1,0,0,0,3,238,146,0,56,112,1,0,248,67,8,0,1,0,0,0,4,238,146,0,32,92,1,0,136,64,8,0,1,0,0,0,5,238,146,0,64,77,1,0,88,212,3,0,1,0,0,0,104,215,146,0,40,185,3,0,72,65,1,0,9,0,0,0,112,3,147,0,32,58,1,0,48,50,1,0,9,0,0,0,113,3,147,0,32,58,1,0,101,112,114,45,49,49,54,56,56,46,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,223,242,69,200,1,0,16,1,101,112,114,45,49,49,54,56,55,46,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,191,251,190,28,1,0,16,1,101,112,114,45,49,49,56,55,53,46,56,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,198,1,23,200,9,0,16,1,101,112,114,45,49,49,56,55,52,46,56,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,121,253,1,83,9,0,16,1,101,112,114,45,49,49,54,57,48,97,46,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,119,193,139,225,17,0,16,1,101,112,114,45,49,49,54,56,57,97,46,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,62,230,16,96,17,0,16,1,109,112,114,45,49,49,52,54,56,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,165,156,202,116,3,0,32,0,109,112,114,45,49,49,52,54,55,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,54,231,96,110,3,0,32,0,101,112,114,45,49,49,54,57,53,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,190,100,168,56,3,0,32,0,101,112,114,45,49,49,54,57,52,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,132,123,41,126,3,0,32,0,109,112,114,45,49,49,52,54,57,46,54,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,153,34,122,237,18,0,32,0,109,112,114,45,49,49,52,55,48,46,55,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,80,165,222,52,18,0,32,0,109,112,114,45,49,49,52,55,55,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,83,70,120,162,18,0,32,0,109,112,114,45,49,49,52,55,56,46,55,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,147,137,119,139,18,0,32,0,109,112,114,45,49,49,52,55,49,46,56,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,105,64,151,241,18,0,32,0,109,112,114,45,49,49,52,55,50,46,49,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,154,64,36,13,18,0,32,0,109,112,114,45,49,49,52,55,57,46,56,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,138,19,214,236,18,0,32,0,109,112,114,45,49,49,52,56,48,46,49,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,197,102,173,100,18,0,32,0,109,112,114,45,49,49,52,55,51,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,236,198,56,5,18,0,32,0,109,112,114,45,49,49,52,55,52,46,55,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,80,60,146,235,18,0,32,0,109,112,114,45,49,49,52,56,49,46,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,2,0,182,82,230,120,18,0,32,0,109,112,114,45,49,49,52,56,50,46,55,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,102,151,135,47,18,0,32,0,109,112,114,45,49,49,52,55,53,46,56,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,137,236,207,105,18,0,32,0,109,112,114,45,49,49,52,55,54,46,49,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,121,155,11,166,18,0,32,0,109,112,114,45,49,49,52,56,51,46,56,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,5,165,211,213,18,0,32,0,109,112,114,45,49,49,52,56,52,46,49,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,80,106,165,184,18,0,32,0,101,112,114,45,49,49,54,57,54,46,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,158,228,232,153,18,0,32,0,101,112,114,45,49,49,54,57,55,46,55,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,46,197,69,117,18,0,32,0,101,112,114,45,49,49,55,48,48,46,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,193,57,56,225,18,0,32,0,101,112,114,45,49,49,55,48,49,46,54,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,101,211,179,159,18,0,32,0,101,112,114,45,49,49,54,57,56,46,56,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,226,163,235,207,18,0,32,0,101,112,114,45,49,49,54,57,57,46,49,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,74,83,0,74,18,0,32,0,101,112,114,45,49,49,55,48,50,46,56,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,39,198,9,42,18,0,32,0,101,112,114,45,49,49,55,48,51,46,49,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,159,125,187,67,18,0,32,0,101,112,114,45,49,49,53,50,52,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,159,132,53,93,18,0,32,0,101,112,114,45,49,49,53,50,53,46,55,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,82,117,228,154,18,0,32,0,101,112,114,45,49,49,53,51,50,46,54,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,219,93,86,179,18,0,32,0,101,112,114,45,49,49,53,51,51,46,54,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,138,110,209,245,18,0,32,0,101,112,114,45,49,49,53,50,54,46,56,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,240,179,76,9,18,0,32,0,101,112,114,45,49,49,53,50,55,46,49,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,68,161,33,232,18,0,32,0,101,112,114,45,49,49,53,51,52,46,55,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,124,173,240,183,18,0,32,0,101,112,114,45,49,49,53,51,53,46,49,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,70,122,218,149,18,0,32,0,101,112,114,45,49,49,54,57,51,46,49,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,92,120,151,4,4,0,16,1,109,112,114,45,49,49,52,54,53,46,49,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,171,109,67,225,11,0,64,0,101,112,114,45,49,49,53,49,54,46,49,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,127,225,208,25,11,0,64,0,101,112,114,45,49,49,56,49,52,46,49,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,118,211,5,11,11,0,64,0,184,40,2,0,1,0,0,0,214,155,215,0,248,191,2,0,56,250,6,0,1,0,0,0,211,155,215,0,184,160,2,0,184,164,8,0,1,0,0,0,215,155,215,0,64,246,1,0,8,3,3,0,4,0,0,0,112,156,215,0,208,13,4,0,248,230,7,0,4,0,0,0,104,156,215,0,184,198,5,0,184,171,7,0,4,0,0,0,96,156,215,0,136,191,7,0,232,137,7,0,1,0,0,0,212,155,215,0,152,30,2,0,112,179,7,0,1,0,0,0,213,155,215,0,232,10,2,0,16,17,8,0,1,0,0,0,210,155,215,0,224,12,8,0,32,77,1,0,1,0,0,0,209,155,215,0,216,70,1,0,88,212,3,0,1,0,0,0,200,154,215,0,40,185,3,0,248,5,8,0,9,0,0,0,0,156,215,0,32,58,1,0,144,250,7,0,9,0,0,0,1,156,215,0,32,58,1,0,49,51,54,48,51,55,45,49,53,48,55,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,40,50,24,181,0,0,16,1,49,51,54,48,51,55,45,49,53,48,56,46,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,1,197,211,175,0,0,16,1,49,51,54,48,51,55,45,50,48,53,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,81,237,153,109,0,0,16,1,49,51,54,48,51,55,45,50,48,54,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,145,173,94,84,0,0,16,1,49,51,54,48,51,55,45,49,53,48,57,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,233,10,229,105,0,0,16,1,49,51,54,48,51,55,45,49,53,49,48,46,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,44,105,226,84,0,0,16,1,49,51,54,48,51,55,45,49,50,48,46,49,54,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,204,243,231,110,0,0,16,1,49,51,54,48,51,55,45,49,49,57,46,49,54,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,31,134,25,250,0,0,16,1,49,51,54,48,51,55,45,49,48,52,46,54,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,89,91,42,158,0,0,32,0,49,51,54,48,51,55,45,49,49,49,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,51,15,112,145,0,0,32,0,49,51,54,48,51,55,45,49,49,50,46,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,190,48,147,134,0,0,32,0,49,51,54,48,51,55,45,49,49,51,46,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,168,208,151,212,0,0,32,0,49,51,54,48,51,55,45,49,49,52,46,49,109,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,130,152,239,41,0,0,32,0,49,51,54,48,51,55,45,49,49,53,46,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,152,184,16,149,0,0,32,0,49,51,54,48,51,55,45,49,49,54,46,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,91,172,224,17,0,0,32,0,49,51,54,48,51,55,45,49,49,55,46,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,65,219,165,41,0,0,32,0,49,51,54,48,51,55,45,49,49,56,46,50,109,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,99,178,243,139,0,0,32,0,55,52,115,52,55,50,45,49,51,54,48,51,55,45,49,48,49,46,55,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,111,247,100,41,0,0,32,0,55,52,115,52,55,50,45,49,51,54,48,51,55,45,49,48,50,46,53,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,108,236,79,77,0,0,32,0,55,52,115,50,56,55,45,49,51,54,48,51,55,45,49,48,51,46,52,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,8,207,92,108,0,0,32,0,49,51,54,48,51,55,45,49,51,48,55,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,67,135,254,70,0,0,16,1,49,51,54,48,51,55,45,49,51,48,56,46,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,196,21,110,39,0,0,16,1,49,51,54,48,51,55,45,50,48,53,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,81,237,153,109,0,0,16,1,49,51,54,48,51,55,45,50,48,54,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,145,173,94,84,0,0,16,1,49,51,54,48,51,55,45,49,51,48,57,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,216,57,186,232,0,0,16,1,49,51,54,48,51,55,45,49,51,49,48,46,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,151,217,4,162,0,0,16,1,49,51,54,48,51,55,45,49,50,48,46,49,54,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,204,243,231,110,0,0,16,1,49,51,54,48,51,55,45,49,49,57,46,49,54,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,31,134,25,250,0,0,16,1,49,51,54,48,51,55,45,49,48,52,46,54,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,89,91,42,158,0,0,32,0,49,51,54,48,51,55,45,49,49,49,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,51,15,112,145,0,0,32,0,49,51,54,48,51,55,45,49,49,50,46,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,190,48,147,134,0,0,32,0,49,51,54,48,51,55,45,49,49,51,46,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,168,208,151,212,0,0,32,0,49,51,54,48,51,55,45,49,49,52,46,49,109,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,130,152,239,41,0,0,32,0,49,51,54,48,51,55,45,49,49,53,46,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,152,184,16,149,0,0,32,0,49,51,54,48,51,55,45,49,49,54,46,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,91,172,224,17,0,0,32,0,49,51,54,48,51,55,45,49,49,55,46,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,65,219,165,41,0,0,32,0,49,51,54,48,51,55,45,49,49,56,46,50,109,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,99,178,243,139,0,0,32,0,55,52,115,52,55,50,45,49,51,54,48,51,55,45,49,48,49,46,55,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,111,247,100,41,0,0,32,0,55,52,115,52,55,50,45,49,51,54,48,51,55,45,49,48,50,46,53,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,108,236,79,77,0,0,32,0,55,52,115,50,56,55,45,49,51,54,48,51,55,45,49,48,51,46,52,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,8,207,92,108,0,0,32,0,49,51,54,48,51,55,45,49,48,48,55,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,234,76,34,106,0,0,16,1,49,51,54,48,51,55,45,49,48,48,56,46,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,171,29,57,250,0,0,16,1,49,51,54,48,51,55,45,50,48,53,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,81,237,153,109,0,0,16,1,49,51,54,48,51,55,45,50,48,54,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,145,173,94,84,0,0,16,1,49,51,54,48,51,55,45,49,48,48,57,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,102,249,209,117,0,0,16,1,49,51,54,48,51,55,45,49,48,49,48,46,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,123,25,164,40,0,0,16,1,49,51,54,48,51,55,45,49,50,48,46,49,54,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,204,243,231,110,0,0,16,1,49,51,54,48,51,55,45,49,49,57,46,49,54,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,31,134,25,250,0,0,16,1,49,51,54,48,51,55,45,49,48,52,46,54,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,89,91,42,158,0,0,32,0,49,51,54,48,51,55,45,49,49,49,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,51,15,112,145,0,0,32,0,49,51,54,48,51,55,45,49,49,50,46,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,190,48,147,134,0,0,32,0,49,51,54,48,51,55,45,49,49,51,46,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,168,208,151,212,0,0,32,0,49,51,54,48,51,55,45,49,49,52,46,49,109,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,130,152,239,41,0,0,32,0,49,51,54,48,51,55,45,49,49,53,46,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,152,184,16,149,0,0,32,0,49,51,54,48,51,55,45,49,49,54,46,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,91,172,224,17,0,0,32,0,49,51,54,48,51,55,45,49,49,55,46,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,65,219,165,41,0,0,32,0,49,51,54,48,51,55,45,49,49,56,46,50,109,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,99,178,243,139,0,0,32,0,55,52,115,52,55,50,45,49,51,54,48,51,55,45,49,48,49,46,55,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,111,247,100,41,0,0,32,0,55,52,115,52,55,50,45,49,51,54,48,51,55,45,49,48,50,46,53,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,108,236,79,77,0,0,32,0,55,52,115,50,56,55,45,49,51,54,48,51,55,45,49,48,51,46,52,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,8,207,92,108,0,0,32,0,49,51,54,48,51,55,45,49,48,48,55,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,234,76,34,106,0,0,16,1,49,51,54,48,51,55,45,49,48,48,56,46,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,171,29,57,250,0,0,16,1,49,51,54,48,52,51,45,49,49,48,53,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,71,218,223,69,0,0,16,1,49,51,54,48,52,51,45,49,49,48,54,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,156,2,60,52,0,0,16,1,49,51,54,48,52,52,45,50,50,48,57,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,205,46,165,157,0,0,16,1,49,51,54,48,52,52,45,50,50,49,48,46,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,167,246,208,99,0,0,16,1,49,51,54,48,52,52,45,50,50,50,49,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,27,179,149,136,0,0,16,1,49,51,54,48,52,52,45,50,50,50,50,46,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,199,108,69,164,0,0,16,1,49,51,54,48,52,51,45,49,49,50,48,46,49,54,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,6,16,115,92,0,0,16,1,49,51,54,48,52,51,45,49,49,49,57,46,49,54,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,231,145,53,220,0,0,16,1,49,51,54,48,52,51,45,49,49,48,52,46,54,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,111,207,67,19,0,0,32,0,49,51,54,48,52,51,45,49,49,49,49,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,35,110,223,9,0,0,32,0,49,51,54,48,51,55,45,49,49,50,46,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,190,48,147,134,0,0,32,0,49,51,54,48,52,51,45,49,49,50,51,46,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,1,143,201,228,0,0,32,0,49,51,54,48,52,51,45,49,49,49,51,46,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,110,71,203,51,0,0,32,0,49,51,54,48,51,55,45,49,49,52,46,49,109,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,130,152,239,41,0,0,32,0,49,51,54,48,52,51,45,49,49,50,52,46,49,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,121,120,133,196,0,0,32,0,49,51,54,48,52,51,45,49,49,49,53,46,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,3,37,30,247,0,0,32,0,49,51,54,48,51,55,45,49,49,54,46,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,91,172,224,17,0,0,32,0,49,51,54,48,52,51,45,49,49,50,53,46,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,209,194,194,217,0,0,32,0,49,51,54,48,52,51,45,49,49,49,55,46,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,233,178,48,158,0,0,32,0,49,51,54,48,51,55,45,49,49,56,46,50,109,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,99,178,243,139,0,0,32,0,49,51,54,48,52,51,45,49,49,50,54,46,50,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,42,115,44,163,0,0,32,0,55,52,115,52,55,50,45,49,51,54,48,51,55,45,49,48,49,46,55,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,111,247,100,41,0,0,32,0,55,52,115,52,55,50,45,49,51,54,48,51,55,45,49,48,50,46,53,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,108,236,79,77,0,0,32,0,55,52,115,50,56,55,45,49,51,54,48,51,55,45,49,48,51,46,52,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,8,207,92,108,0,0,32,0,49,51,54,48,51,55,45,49,51,48,55,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,67,135,254,70,0,0,16,1,49,51,54,48,51,55,45,49,51,48,56,46,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,196,21,110,39,0,0,16,1,49,51,54,48,52,51,45,49,49,48,53,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,71,218,223,69,0,0,16,1,49,51,54,48,52,51,45,49,49,48,54,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,156,2,60,52,0,0,16,1,49,51,54,48,52,52,45,49,49,48,57,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,235,5,248,49,0,0,16,1,49,51,54,48,52,52,45,49,49,49,48,46,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,226,192,133,82,0,0,16,1,49,51,54,48,52,52,45,49,49,50,49,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,42,179,243,209,0,0,16,1,49,51,54,48,52,52,45,49,49,50,50,46,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,95,120,133,52,0,0,16,1,49,51,54,48,52,51,45,49,49,50,48,46,49,54,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,6,16,115,92,0,0,16,1,49,51,54,48,52,51,45,49,49,49,57,46,49,54,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,231,145,53,220,0,0,16,1,49,51,54,48,52,51,45,49,49,48,52,46,54,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,111,207,67,19,0,0,32,0,49,51,54,48,52,51,45,49,49,49,49,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,35,110,223,9,0,0,32,0,49,51,54,48,51,55,45,49,49,50,46,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,190,48,147,134,0,0,32,0,49,51,54,48,52,51,45,49,49,50,51,46,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,1,143,201,228,0,0,32,0,49,51,54,48,52,51,45,49,49,49,51,46,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,110,71,203,51,0,0,32,0,49,51,54,48,51,55,45,49,49,52,46,49,109,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,130,152,239,41,0,0,32,0,49,51,54,48,52,51,45,49,49,50,52,46,49,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,121,120,133,196,0,0,32,0,49,51,54,48,52,51,45,49,49,49,53,46,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,3,37,30,247,0,0,32,0,49,51,54,48,51,55,45,49,49,54,46,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,91,172,224,17,0,0,32,0,49,51,54,48,52,51,45,49,49,50,53,46,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,209,194,194,217,0,0,32,0,49,51,54,48,52,51,45,49,49,49,55,46,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,233,178,48,158,0,0,32,0,49,51,54,48,51,55,45,49,49,56,46,50,109,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,99,178,243,139,0,0,32,0,49,51,54,48,52,51,45,49,49,50,54,46,50,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,42,115,44,163,0,0,32,0,55,52,115,52,55,50,45,49,51,54,48,51,55,45,49,48,49,46,55,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,111,247,100,41,0,0,32,0,55,52,115,52,55,50,45,49,51,54,48,51,55,45,49,48,50,46,53,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,108,236,79,77,0,0,32,0,55,52,115,50,56,55,45,49,51,54,48,51,55,45,49,48,51,46,52,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,8,207,92,108,0,0,32,0,184,40,2,0,1,0,0,0,152,244,146,0,248,191,2,0,24,38,7,0,1,0,0,0,191,238,146,0,184,160,2,0,56,210,6,0,1,0,0,0,184,238,146,0,192,135,2,0,24,163,6,0,1,0,0,0,185,238,146,0,240,108,2,0,152,122,6,0,1,0,0,0,186,238,146,0,96,82,2,0,192,72,6,0,1,0,0,0,187,238,146,0,32,56,2,0,200,110,3,0,1,0,0,0,188,238,146,0,152,30,2,0,120,89,3,0,1,0,0,0,189,238,146,0,232,10,2,0,88,212,3,0,1,0,0,0,64,217,146,0,40,185,3,0,248,5,8,0,9,0,0,0,88,4,147,0,32,58,1,0,144,250,7,0,9,0,0,0,89,4,147,0,32,58,1,0,184,40,2,0,1,0,0,0,232,47,216,0,248,191,2,0,184,164,8,0,1,0,0,0,233,47,216,0,64,246,1,0,136,204,6,0,1,0,0,0,236,47,216,0,184,160,2,0,136,48,1,0,1,0,0,0,33,48,216,0,96,82,2,0,224,47,1,0,1,0,0,0,32,48,216,0,32,56,2,0,200,46,1,0,1,0,0,0,36,48,216,0,152,30,2,0,128,45,1,0,1,0,0,0,37,48,216,0,232,10,2,0,88,212,3,0,1,0,0,0,144,46,216,0,40,185,3,0,240,152,1,0,1,0,0,0,238,47,216,0,216,70,1,0,16,17,8,0,1,0,0,0,234,47,216,0,224,12,8,0,72,65,1,0,9,0,0,0,232,48,216,0,32,58,1,0,48,50,1,0,9,0,0,0,224,48,216,0,32,58,1,0,224,41,1,0,9,0,0,0,216,48,216,0,32,58,1,0,103,108,45,48,51,46,56,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,103,170,243,232,1,0,16,1,103,108,45,48,52,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,227,131,130,245,1,0,16,1,103,108,45,48,53,46,56,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,192,49,112,76,1,0,16,1,103,108,45,48,54,46,56,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,162,146,125,9,1,0,16,1,103,108,45,48,55,46,56,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,90,215,65,83,1,0,16,1,103,108,45,48,50,46,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,16,117,79,209,4,0,32,0,103,108,45,48,49,46,49,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,22,96,139,150,4,0,32,0,54,108,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,103,148,172,195,7,0,32,0,103,97,108,109,105,100,119,46,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,97,45,94,116,1,0,16,1,103,97,108,109,105,100,119,46,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,64,154,153,156,1,0,16,1,103,97,108,109,105,100,119,46,119,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,37,73,137,181,1,0,16,1,103,97,108,109,105,100,119,46,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,11,161,60,107,1,0,16,1,103,97,108,109,105,100,119,46,122,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,151,247,36,203,1,0,16,1,103,97,108,97,120,105,97,110,46,106,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,152,207,222,132,4,0,32,0,103,97,108,97,120,105,97,110,46,108,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,158,218,26,195,4,0,32,0,54,108,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,103,148,172,195,7,0,32,0,55,102,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,222,177,53,67,1,0,16,1,55,106,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,161,102,111,78,1,0,16,1,55,108,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,90,215,65,83,1,0,16,1,49,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,164,67,251,57,4,0,32,0,49,107,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,162,86,63,126,4,0,32,0,54,108,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,103,148,172,195,7,0,32,0,98,97,110,103,46,119,97,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,98,97,110,103,46,119,97,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,21,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,232,75,4,0,20,0,0,0,1,1,1,0,96,135,7,0,20,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,20,0,0,0,1,2,2,0,96,135,7,0,20,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,8,0,160,123,6,0,20,0,0,0,1,28,0,0,40,88,7,0,20,0,0,0,1,28,16,0,96,39,7,0,20,0,0,0,1,28,28,0,144,251,6,0,20,0,0,0,1,28,12,0,184,164,6,0,20,0,0,0,1,28,20,0,80,74,6,0,20,0,0,0,1,28,4,0,192,32,6,0,20,0,0,0,1,28,24,0,192,234,2,0,20,0,0,0,1,28,8,0,32,242,5,0,0,0,0,0,254,0,8,0,200,87,7,0,20,0,0,0,1,224,0,0,40,88,7,0,20,0,0,0,1,224,128,0,96,39,7,0,20,0,0,0,1,224,224,0,144,251,6,0,20,0,0,0,1,224,96,0,184,164,6,0,20,0,0,0,1,224,160,0,80,74,6,0,20,0,0,0,1,224,32,0,192,32,6,0,20,0,0,0,1,224,192,0,192,234,2,0,20,0,0,0,1,224,64,0,32,242,5,0,0,0,0,0,254,0,2,0,168,234,7,0,21,0,0,0,1,1,1,0,96,135,7,0,21,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,21,0,0,0,1,2,0,0,56,111,3,0,21,0,0,0,1,2,2,0,104,134,3,0,0,0,0,0,254,0,2,0,16,227,4,0,21,0,0,0,1,4,4,0,96,135,7,0,21,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,72,4,1,0,21,0,0,0,1,8,8,0,96,135,7,0,21,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,21,0,0,0,1,48,16,0,80,246,3,0,21,0,0,0,1,48,48,0,248,38,7,0,21,0,0,0,1,48,32,0,112,212,3,0,21,0,0,0,1,48,0,0,248,160,5,0,0,0,0,0,254,0,4,0,128,129,4,0,21,0,0,0,1,192,128,0,192,255,2,0,21,0,0,0,1,192,192,0,208,75,4,0,21,0,0,0,1,192,64,0,8,49,4,0,21,0,0,0,1,192,0,0,152,21,4,0,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,93,216,5,25,0,0,16,1,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,57,252,156,222,0,0,16,1,102,115,116,97,114,102,48,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,53,83,55,84,0,0,32,0,102,115,116,97,114,102,48,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,231,129,162,119,0,0,32,0,102,115,116,97,114,102,48,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,13,146,138,57,0,0,32,0,102,115,116,97,114,102,48,57,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,210,65,19,213,0,0,32,0,102,115,116,97,114,102,48,54,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,135,14,228,7,0,0,32,0,102,115,116,97,114,102,48,55,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,225,93,173,224,0,0,80,0,102,115,116,97,114,102,48,56,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,147,86,173,240,0,0,64,0,101,112,114,45,49,48,49,50,46,105,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,121,12,171,239,1,0,16,1,101,112,114,45,49,48,49,51,97,46,105,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,19,156,202,174,1,0,16,1,101,112,114,45,49,48,49,52,46,105,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,102,16,37,221,1,0,16,1,101,112,114,45,49,48,49,53,46,105,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,2,58,41,191,1,0,16,1,101,112,114,45,54,48,56,46,105,99,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,86,2,171,232,2,0,16,1,101,112,114,45,54,48,57,46,105,99,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,143,164,128,115,2,0,16,1,101,112,114,45,54,49,48,46,105,99,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,39,235,215,49,2,0,16,1,101,112,114,45,54,48,55,46,105,99,49,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,131,216,247,5,4,0,32,0,101,112,114,45,54,48,54,46,105,99,49,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,48,238,36,245,4,0,32,0,112,114,45,57,49,46,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,191,3,55,65,7,0,32,0,102,114,111,103,103,101,114,46,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,214,150,118,89,1,0,16,1,102,114,111,103,103,101,114,46,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,195,252,230,182,1,0,16,1,102,114,111,103,103,101,114,46,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,171,107,134,237,1,0,16,1,101,112,114,45,54,48,56,46,105,99,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,86,2,171,232,2,0,16,1,101,112,114,45,54,48,57,46,105,99,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,143,164,128,115,2,0,16,1,101,112,114,45,54,49,48,46,105,99,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,39,235,215,49,2,0,16,1,101,112,114,45,54,48,55,46,105,99,49,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,131,216,247,5,4,0,32,0,101,112,114,45,54,48,54,46,105,99,49,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,48,238,36,245,4,0,32,0,112,114,45,57,49,46,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,191,3,55,65,7,0,32,0,101,112,114,45,49,48,51,49,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,17,141,124,75,1,0,16,1,101,112,114,45,49,48,51,50,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,217,185,0,172,1,0,16,1,101,112,114,45,49,48,51,51,46,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,188,111,29,188,1,0,16,1,101,112,114,45,49,48,51,52,46,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,153,115,254,158,1,0,16,1,101,112,114,45,49,48,56,50,46,52,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,194,67,40,128,2,0,16,1,101,112,114,45,49,48,51,53,46,52,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,72,65,231,20,2,0,16,1,101,112,114,45,49,48,51,55,46,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,131,216,247,5,4,0,32,0,101,112,114,45,49,48,51,54,46,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,248,69,135,101,4,0,32,0,112,114,45,57,49,46,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,191,3,55,65,7,0,32,0,14,0,0,0,255,255,0,0,0,0,0,0,15,0,0,0,255,255,192,0,0,0,0,0,16,0,0,0,255,255,7,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,15,0,0,0,1,192,192,0,8,49,4,0,15,0,0,0,1,192,128,0,72,246,3,0,15,0,0,0,1,192,64,0,64,47,7,0,15,0,0,0,1,192,0,0,240,64,4,0,0,0,0,0,254,0,2,0,200,30,2,0,16,0,0,0,1,1,1,0,120,97,1,0,16,0,0,0,1,1,0,0,96,19,1,0,0,0,0,0,254,0,4,0,32,4,2,0,16,0,0,0,1,6,2,0,16,165,1,0,16,0,0,0,1,6,4,0,248,163,1,0,16,0,0,0,1,6,6,0,24,162,1,0,16,0,0,0,1,6,0,0,120,161,1,0,184,40,2,0,1,0,0,0,47,39,216,0,248,191,2,0,56,250,6,0,1,0,0,0,39,39,216,0,184,160,2,0,184,164,8,0,1,0,0,0,46,39,216,0,64,246,1,0,88,149,7,0,1,0,0,0,38,39,216,0,136,224,1,0,240,167,7,0,1,0,0,0,28,39,216,0,192,135,2,0,176,163,7,0,1,0,0,0,30,39,216,0,240,108,2,0,208,158,7,0,1,0,0,0,45,39,216,0,96,82,2,0,184,154,7,0,1,0,0,0,44,39,216,0,32,56,2,0,8,96,7,0,1,0,0,0,40,39,216,0,72,198,1,0,48,89,7,0,1,0,0,0,24,39,216,0,24,182,1,0,16,83,7,0,1,0,0,0,37,39,216,0,40,167,1,0,96,79,7,0,1,0,0,0,36,39,216,0,200,149,1,0,88,212,3,0,1,0,0,0,48,38,216,0,40,185,3,0,16,17,8,0,1,0,0,0,42,39,216,0,224,12,8,0,248,5,8,0,9,0,0,0,112,39,216,0,32,58,1,0,144,250,7,0,9,0,0,0,113,39,216,0,32,58,1,0,248,241,7,0,9,0,0,0,114,39,216,0,32,58,1,0,184,40,2,0,1,0,0,0,40,39,216,0,248,191,2,0,56,250,6,0,1,0,0,0,32,39,216,0,184,160,2,0,88,149,7,0,1,0,0,0,33,39,216,0,136,224,1,0,240,167,7,0,1,0,0,0,47,39,216,0,192,135,2,0,176,163,7,0,1,0,0,0,46,39,216,0,240,108,2,0,208,158,7,0,1,0,0,0,42,39,216,0,96,82,2,0,184,154,7,0,1,0,0,0,43,39,216,0,32,56,2,0,88,168,7,0,1,0,0,0,44,39,216,0,152,30,2,0,8,96,7,0,1,0,0,0,41,39,216,0,72,198,1,0,48,89,7,0,1,0,0,0,37,39,216,0,24,182,1,0,16,83,7,0,1,0,0,0,34,39,216,0,40,167,1,0,96,79,7,0,1,0,0,0,35,39,216,0,200,149,1,0,136,87,1,0,1,0,0,0,36,39,216,0,56,126,1,0,88,212,3,0,1,0,0,0,48,38,216,0,40,185,3,0,248,5,8,0,9,0,0,0,112,39,216,0,32,58,1,0,144,250,7,0,9,0,0,0,113,39,216,0,32,58,1,0,248,241,7,0,9,0,0,0,114,39,216,0,32,58,1,0,120,86,1,0,9,0,0,0,115,39,216,0,32,58,1,0,144,85,1,0,9,0,0,0,116,39,216,0,32,58,1,0,232,84,1,0,9,0,0,0,117,39,216,0,32,58,1,0,176,84,1,0,9,0,0,0,118,39,216,0,32,58,1,0,108,119,49,49,99,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,182,66,39,230,1,0,16,1,108,119,49,53,99,46,49,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,22,242,112,27,1,0,16,1,108,119,49,48,99,46,49,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,245,163,94,143,1,0,16,1,108,119,49,52,99,46,49,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,114,116,142,112,1,0,16,1,108,119,45,48,55,46,49,48,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,38,42,37,253,2,0,16,1,108,119,95,50,46,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,238,95,215,75,4,0,32,0,108,119,95,49,46,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,133,20,244,101,4,0,32,0,108,119,45,48,56,46,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,60,228,168,37,4,0,32,0,108,119,45,48,53,46,54,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,215,47,85,228,4,0,32,0,108,119,95,51,48,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,78,149,133,179,4,0,32,0,108,119,95,50,57,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,198,26,218,123,4,0,32,0,108,119,95,52,46,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,127,117,207,80,4,0,32,0,108,119,95,51,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,120,242,62,192,4,0,32,0,108,119,95,51,50,46,57,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,21,122,150,48,4,0,32,0,108,119,95,51,49,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,251,55,157,196,4,0,32,0,108,119,45,48,50,46,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,200,197,230,67,4,0,32,0,108,119,95,49,52,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,206,44,134,130,4,0,32,0,108,119,95,49,51,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,150,14,28,184,4,0,32,0,108,119,45,48,54,46,57,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,252,223,158,91,4,0,32,0,108,119,45,49,51,46,49,48,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,245,142,5,142,4,0,32,0,108,119,95,49,54,46,49,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,84,101,178,64,4,0,32,0,108,119,95,49,53,46,49,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,7,46,125,27,4,0,32,0,108,119,95,48,48,46,49,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,99,42,223,89,3,0,16,0,108,119,45,48,51,117,46,49,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,31,5,125,128,5,0,64,0,108,119,45,48,52,117,46,49,51,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,142,9,205,230,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,108,119,54,50,49,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,233,108,236,94,0,0,0,8,108,119,105,111,46,49,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,12,185,82,173,0,0,0,8,184,40,2,0,1,0,0,0,96,232,148,0,248,191,2,0,56,250,6,0,1,0,0,0,223,233,148,0,184,160,2,0,184,164,8,0,1,0,0,0,97,232,148,0,64,246,1,0,88,149,7,0,1,0,0,0,31,233,148,0,136,224,1,0,56,210,6,0,1,0,0,0,216,233,148,0,192,135,2,0,24,163,6,0,1,0,0,0,217,233,148,0,240,108,2,0,152,122,6,0,1,0,0,0,218,233,148,0,96,82,2,0,192,72,6,0,1,0,0,0,219,233,148,0,32,56,2,0,48,123,2,0,1,0,0,0,220,233,148,0,152,30,2,0,96,69,2,0,1,0,0,0,221,233,148,0,232,10,2,0,144,55,2,0,1,0,0,0,222,233,148,0,152,138,8,0,176,223,1,0,1,0,0,0,24,233,148,0,72,198,1,0,192,209,1,0,1,0,0,0,25,233,148,0,24,182,1,0,24,198,1,0,1,0,0,0,26,233,148,0,40,167,1,0,120,189,1,0,1,0,0,0,27,233,148,0,200,149,1,0,248,187,8,0,1,0,0,0,28,233,148,0,56,126,1,0,184,179,8,0,1,0,0,0,29,233,148,0,32,101,1,0,240,173,8,0,1,0,0,0,30,233,148,0,96,32,8,0,88,212,3,0,1,0,0,0,192,218,146,0,40,185,3,0,16,17,8,0,1,0,0,0,98,232,148,0,224,12,8,0,248,5,8,0,9,0,0,0,112,94,147,0,32,58,1,0,144,250,7,0,9,0,0,0,113,94,147,0,32,58,1,0,168,86,7,0,1,0,0,0,12,252,146,0,248,191,2,0,24,38,7,0,1,0,0,0,8,252,146,0,184,160,2,0,152,122,6,0,1,0,0,0,210,243,146,0,96,82,2,0,192,72,6,0,1,0,0,0,211,243,146,0,32,56,2,0,200,110,3,0,1,0,0,0,208,243,146,0,152,30,2,0,120,89,3,0,1,0,0,0,209,243,146,0,232,10,2,0,40,246,1,0,1,0,0,0,13,252,146,0,64,246,1,0,144,236,1,0,1,0,0,0,9,252,146,0,136,224,1,0,24,198,1,0,1,0,0,0,106,238,146,0,40,167,1,0,120,189,1,0,1,0,0,0,107,238,146,0,200,149,1,0,224,22,1,0,1,0,0,0,104,238,146,0,56,126,1,0,160,14,1,0,1,0,0,0,105,238,146,0,32,101,1,0,88,212,3,0,1,0,0,0,176,216,146,0,40,185,3,0,16,17,8,0,1,0,0,0,10,252,146,0,224,12,8,0,56,58,1,0,1,0,0,0,11,252,146,0,64,50,1,0,72,65,1,0,9,0,0,0,248,3,147,0,32,58,1,0,48,50,1,0,9,0,0,0,249,3,147,0,32,58,1,0,224,41,1,0,9,0,0,0,250,3,147,0,32,58,1,0,101,112,114,45,54,54,50,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,70,245,31,178,0,0,16,1,101,112,114,45,54,54,50,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,241,139,58,19,0,0,16,1,101,112,114,45,53,56,54,57,46,49,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,78,13,34,109,0,0,16,1,54,54,120,120,46,105,99,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,82,167,241,0,0,32,0,54,54,120,48,46,105,99,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,183,239,154,41,0,0,32,0,53,57,57,57,46,105,99,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,87,49,165,28,0,0,32,0,101,112,114,45,53,56,53,53,46,49,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,161,148,248,181,0,0,32,0,101,112,114,45,53,56,53,54,46,49,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,143,247,106,38,0,0,32,0,112,114,45,53,51,49,55,46,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,184,80,131,100,0,0,0,8,102,108,97,115,104,103,97,108,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,206,154,136,170,0,0,16,1,101,112,114,45,55,49,54,56,46,52,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,31,133,196,0,0,0,16,1,101,112,114,45,55,49,54,57,46,52,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,247,184,240,30,0,0,16,1,101,112,114,45,55,49,55,48,46,52,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,222,83,93,136,0,0,16,1,102,108,97,115,104,103,97,108,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,193,28,23,85,0,0,16,1,102,108,97,115,104,103,97,108,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,172,26,210,63,0,0,16,1,102,108,97,115,104,103,97,108,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,116,59,34,161,0,0,16,1,102,108,97,115,104,103,97,108,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,95,160,210,4,0,0,16,1,101,112,114,45,55,49,55,55,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,47,5,169,220,0,0,32,0,101,112,114,45,55,49,55,56,46,57,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,192,98,91,47,0,0,32,0,101,112,114,45,55,49,55,57,46,49,48,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,181,73,187,143,0,0,32,0,101,112,114,45,55,49,56,48])
.concat([46,49,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,195,229,168,38,0,0,32,0,101,112,114,45,55,49,55,49,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,161,242,202,98,0,0,32,0,101,112,114,45,55,49,55,50,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,16,138,247,16,0,0,32,0,101,112,114,45,55,49,55,51,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,89,29,234,54,0,0,32,0,101,112,114,45,55,49,55,52,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,55,216,39,245,0,0,32,0,101,112,114,45,55,49,55,53,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,193,228,118,186,0,0,32,0,101,112,114,45,55,49,55,54,46,49,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,25,214,149,240,0,0,32,0,55,49,54,49,46,49,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,63,4,196,2,0,0,32,0,55,49,54,48,46,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,209,56,89,34,0,0,32,0,55,49,53,57,46,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,211,28,10,30,0,0,32,0,55,49,54,50,46,53,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,159,226,226,204,0,0,32,0,98,112,114,46,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,1,146,163,131,0,0,32,0,101,118,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,96,120,122,121,0,0,16,1,101,118,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,77,24,23,15,0,0,16,1,101,119,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,236,101,109,199,0,0,16,1,101,119,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,166,39,180,233,0,0,16,1,101,119,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,141,185,113,152,0,0,16,1,101,119,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,52,5,1,83,0,0,16,1,101,118,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,193,114,111,104,0,0,32,0,101,118,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,201,220,135,183,0,0,32,0,101,119,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,163,215,128,107,0,0,32,0,101,119,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,100,215,211,120,0,0,32,0,101,119,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,227,93,159,206,0,0,32,0,101,119,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,162,123,122,72,0,0,32,0,101,119,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,164,194,27,78,0,0,32,0,101,119,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,251,125,180,158,0,0,32,0,101,119,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,158,71,207,158,0,0,32,0,101,119,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,170,105,86,229,0,0,32,0,101,118,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,151,247,128,29,0,0,32,0,101,119,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,119,49,35,150,0,0,32,0,101,118,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,107,17,231,196,0,0,32,0,101,119,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,252,7,224,242,0,0,32,0,101,118,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,26,79,121,108,0,0,32,0,101,119,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,137,105,11,71,0,0,32,0,101,118,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,212,9,85,4,0,0,32,0,101,119,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,188,68,210,162,0,0,32,0,101,119,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,77,146,6,182,0,0,64,0,101,112,114,45,55,51,56,53,46,52,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,80,68,182,92,1,0,16,1,101,112,114,45,55,51,56,50,46,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,22,116,218,63,1,0,16,1,101,112,114,45,55,51,56,54,46,52,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,206,10,129,21,1,0,16,1,101,112,114,45,55,51,56,51,46,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,10,225,1,160,1,0,16,1,101,112,114,45,55,51,56,55,46,52,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,93,51,205,10,1,0,16,1,101,112,114,45,55,51,56,52,46,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,65,147,144,253,1,0,16,1,101,112,114,45,55,51,56,56,46,57,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,107,47,176,142,2,0,32,0,101,112,114,45,55,51,56,57,46,57,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,184,113,79,47,2,0,32,0,101,112,114,45,55,51,57,48,46,57,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,198,9,6,217,2,0,32,0,101,112,114,45,55,51,57,50,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,182,200,183,91,3,0,32,0,101,112,114,45,55,51,57,54,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,87,75,174,116,3,0,32,0,101,112,114,45,55,51,57,51,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,130,126,252,20,3,0,32,0,101,112,114,45,55,51,57,55,46,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,37,30,90,224,3,0,32,0,101,112,114,45,55,51,57,52,46,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,63,161,28,83,3,0,32,0,101,112,114,45,55,51,57,56,46,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,73,123,128,104,3,0,32,0,101,112,114,45,55,51,57,49,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,94,21,62,192,4,0,16,1,101,112,114,45,55,51,56,53,46,52,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,80,68,182,92,1,0,16,1,101,112,114,45,55,51,56,50,46,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,22,116,218,63,1,0,16,1,101,112,114,45,55,51,56,54,46,52,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,206,10,129,21,1,0,16,1,101,112,114,45,55,51,56,51,46,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,10,225,1,160,1,0,16,1,101,112,114,45,55,51,56,55,46,52,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,93,51,205,10,1,0,16,1,101,112,114,45,55,51,56,52,46,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,65,147,144,253,1,0,16,1,101,112,114,45,55,51,56,56,46,57,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,107,47,176,142,2,0,32,0,101,112,114,45,55,51,56,57,46,57,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,184,113,79,47,2,0,32,0,101,112,114,45,55,51,57,48,46,57,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,198,9,6,217,2,0,32,0,101,112,114,45,55,51,57,50,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,182,200,183,91,3,0,32,0,101,112,114,45,55,51,57,54,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,87,75,174,116,3,0,32,0,101,112,114,45,55,51,57,51,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,130,126,252,20,3,0,32,0,101,112,114,45,55,51,57,55,46,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,37,30,90,224,3,0,32,0,101,112,114,45,55,51,57,52,46,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,63,161,28,83,3,0,32,0,101,112,114,45,55,51,57,56,46,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,73,123,128,104,3,0,32,0,101,112,114,45,55,53,51,53,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,106,18,178,12,4,0,16,1,99,112,117,49,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,68,249,62,210,1,0,16,1,99,112,117,49,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,228,144,116,64,1,0,16,1,99,112,117,49,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,107,113,199,200,1,0,16,1,99,112,117,49,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,110,123,46,36,1,0,16,1,116,105,108,101,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,206,229,224,71,2,0,32,0,116,105,108,101,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,183,129,225,89,2,0,32,0,116,105,108,101,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,76,53,93,55,2,0,32,0,111,98,106,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,77,122,248,154,3,0,32,0,111,98,106,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,104,202,219,47,3,0,32,0,111,98,106,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,122,72,135,37,3,0,32,0,111,98,106,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,170,231,228,141,3,0,32,0,111,98,106,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,255,164,173,223,3,0,32,0,111,98,106,102,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,61,210,229,101,3,0,32,0,111,98,106,103,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,117,187,159,220,3,0,32,0,111,98,106,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,25,124,187,151,3,0,32,0,111,98,106,105,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,238,15,121,199,3,0,32,0,111,98,106,106,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,14,235,53,69,3,0,32,0,99,112,117,50,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,36,41,201,146,4,0,16,1,99,112,117,50,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,117,212,138,44,8,0,64,0,0,0,0,0,4,0,0,0,8,0,0,0,12,0,0,0,16,0,0,0,20,0,0,0,24,0,0,0,28,0,0,0,102,110,116,50,45,50,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,75,44,169,163,0,0,16,1,102,110,116,50,45,49,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,147,68,206,208,0,0,16,1,102,110,116,50,45,50,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,231,194,137,233,0,0,16,1,102,110,116,50,45,49,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,114,211,6,140,0,0,16,1,102,110,116,50,45,50,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,101,30,159,110,0,0,16,1,102,110,116,50,45,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,43,235,203,133,0,0,16,1,102,110,116,50,45,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,106,34,83,121,0,0,16,1,102,110,116,50,45,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,255,204,216,16,0,0,16,1,102,110,116,50,45,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,163,237,218,76,0,0,16,1,102,110,116,50,45,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,66,240,199,104,0,0,16,1,111,98,106,49,46,49,105,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,42,135,230,82,0,0,32,0,111,98,106,50,46,50,105,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,56,110,234,0,0,32,0,109,117,115,105,99,50,46,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,156,79,204,35,0,0,64,0,109,117,115,105,99,49,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,194,103,65,134,0,0,64,0,112,114,111,103,50,95,49,54,46,117,101,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,16,173,65,11,0,0,16,1,112,114,111,103,49,95,49,51,46,117,100,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,38,135,116,163,0,0,16,1,105,45,115,99,114,54,95,57,46,117,101,49,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,147,131,88,42,0,0,16,1,105,45,115,99,114,53,95,53,46,117,101,49,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,240,224,96,97,0,0,16,1,105,45,115,99,114,52,95,56,46,117,101,49,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,67,183,118,247,0,0,16,1,105,45,115,99,114,51,95,52,46,117,101,49,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,242,223,240,93,0,0,16,1,105,45,115,99,114,50,95,55,46,117,101,49,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,216,7,87,0,0,16,1,105,45,115,99,114,49,95,51,46,117,101,49,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,26,129,203,54,0,0,16,1,105,109,97,103,50,95,49,48,46,117,101,50,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,149,163,20,31,0,0,16,1,105,109,97,103,49,95,54,46,117,101,50,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,228,112,248,250,0,0,16,1,111,98,106,49,95,49,55,46,117,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,183,110,219,170,0,0,32,0,109,117,115,105,99,49,95,49,46,117,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,23,232,11,175,0,0,64,0,109,117,115,105,99,50,95,50,46,117,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,195,214,212,76,0,0,64,0,103,45,115,99,114,50,95,49,53,46,117,108,49,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,104,103,102,70,0,0,0,8,103,45,115,99,114,49,95,49,50,46,117,108,49,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,230,91,210,75,0,0,0,8,103,45,115,99,114,52,95,49,52,46,117,108,49,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,212,110,126,78,0,0,0,8,103,45,115,99,114,51,95,49,49,46,117,108,49,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,197,164,0,109,0,0,0,8,184,40,2,0,1,0,0,0,204,233,148,0,248,191,2,0,56,250,6,0,1,0,0,0,15,233,148,0,184,160,2,0,184,164,8,0,1,0,0,0,205,233,148,0,64,246,1,0,88,149,7,0,1,0,0,0,87,232,148,0,136,224,1,0,56,210,6,0,1,0,0,0,8,233,148,0,192,135,2,0,24,163,6,0,1,0,0,0,9,233,148,0,240,108,2,0,152,122,6,0,1,0,0,0,10,233,148,0,96,82,2,0,192,72,6,0,1,0,0,0,11,233,148,0,32,56,2,0,48,123,2,0,1,0,0,0,12,233,148,0,152,30,2,0,96,69,2,0,1,0,0,0,13,233,148,0,232,10,2,0,144,55,2,0,1,0,0,0,14,233,148,0,152,138,8,0,176,223,1,0,1,0,0,0,80,232,148,0,72,198,1,0,192,209,1,0,1,0,0,0,81,232,148,0,24,182,1,0,24,198,1,0,1,0,0,0,82,232,148,0,40,167,1,0,120,189,1,0,1,0,0,0,83,232,148,0,200,149,1,0,248,187,8,0,1,0,0,0,84,232,148,0,56,126,1,0,184,179,8,0,1,0,0,0,85,232,148,0,32,101,1,0,240,173,8,0,1,0,0,0,86,232,148,0,96,32,8,0,88,212,3,0,1,0,0,0,136,218,146,0,40,185,3,0,248,5,8,0,9,0,0,0,96,94,147,0,32,58,1,0,144,250,7,0,9,0,0,0,97,94,147,0,32,58,1,0,168,86,7,0,1,0,0,0,111,2,147,0,248,191,2,0,24,38,7,0,1,0,0,0,168,236,146,0,184,160,2,0,56,210,6,0,1,0,0,0,106,2,147,0,192,135,2,0,24,163,6,0,1,0,0,0,107,2,147,0,240,108,2,0,152,122,6,0,1,0,0,0,105,2,147,0,96,82,2,0,192,72,6,0,1,0,0,0,104,2,147,0,32,56,2,0,200,110,3,0,1,0,0,0,108,2,147,0,152,30,2,0,120,89,3,0,1,0,0,0,109,2,147,0,232,10,2,0,40,246,1,0,1,0,0,0,175,249,146,0,64,246,1,0,144,236,1,0,1,0,0,0,169,236,146,0,136,224,1,0,176,223,1,0,1,0,0,0,170,249,146,0,72,198,1,0,192,209,1,0,1,0,0,0,171,249,146,0,24,182,1,0,24,198,1,0,1,0,0,0,169,249,146,0,40,167,1,0,120,189,1,0,1,0,0,0,168,249,146,0,200,149,1,0,224,22,1,0,1,0,0,0,172,249,146,0,56,126,1,0,160,14,1,0,1,0,0,0,173,249,146,0,32,101,1,0,168,132,8,0,1,0,0,0,143,241,146,0,232,209,1,0,72,126,8,0,1,0,0,0,170,236,146,0,144,189,1,0,192,122,8,0,1,0,0,0,138,241,146,0,208,174,1,0,40,116,8,0,1,0,0,0,139,241,146,0,48,160,1,0,72,110,8,0,1,0,0,0,137,241,146,0,160,140,1,0,184,102,8,0,1,0,0,0,136,241,146,0,56,112,1,0,248,67,8,0,1,0,0,0,140,241,146,0,32,92,1,0,136,64,8,0,1,0,0,0,141,241,146,0,64,77,1,0,232,23,8,0,1,0,0,0,183,237,146,0,104,195,5,0,160,19,8,0,1,0,0,0,171,236,146,0,32,245,8,0,248,16,8,0,1,0,0,0,178,237,146,0,32,231,8,0,192,12,8,0,1,0,0,0,179,237,146,0,88,214,8,0,224,5,8,0,1,0,0,0,177,237,146,0,224,202,8,0,144,1,8,0,1,0,0,0,176,237,146,0,72,193,8,0,176,222,7,0,1,0,0,0,180,237,146,0,144,180,8,0,176,218,7,0,1,0,0,0,181,237,146,0,208,164,8,0,88,212,3,0,1,0,0,0,208,221,146,0,40,185,3,0,32,77,1,0,1,0,0,0,24,236,146,0,216,70,1,0,56,122,5,0,1,0,0,0,172,236,146,0,224,12,8,0,0,105,5,0,1,0,0,0,173,236,146,0,128,176,7,0,152,120,4,0,1,0,0,0,174,236,146,0,248,114,7,0,112,109,5,0,1,0,0,0,175,236,146,0,32,105,5,0,168,86,7,0,1,0,0,0,233,247,146,0,248,191,2,0,24,38,7,0,1,0,0,0,238,247,146,0,184,160,2,0,152,122,6,0,1,0,0,0,129,0,147,0,96,82,2,0,192,72,6,0,1,0,0,0,133,0,147,0,32,56,2,0,200,110,3,0,1,0,0,0,130,0,147,0,152,30,2,0,120,89,3,0,1,0,0,0,134,0,147,0,232,10,2,0,40,246,1,0,1,0,0,0,239,247,146,0,64,246,1,0,144,236,1,0,1,0,0,0,237,247,146,0,136,224,1,0,24,198,1,0,1,0,0,0,128,0,147,0,40,167,1,0,120,189,1,0,1,0,0,0,131,0,147,0,200,149,1,0,224,22,1,0,1,0,0,0,132,0,147,0,56,126,1,0,160,14,1,0,1,0,0,0,135,0,147,0,32,101,1,0,88,212,3,0,1,0,0,0,184,219,146,0,40,185,3,0,72,65,1,0,9,0,0,0,240,5,147,0,32,58,1,0,48,50,1,0,9,0,0,0,241,5,147,0,32,58,1,0,98,53,56,45,51,49,46,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,113,227,134,214,2,0,16,1,98,53,56,45,51,48,46,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,216,192,115,205,2,0,16,1,98,53,56,45,50,57,46,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,228,164,130,132,6,0,16,1,98,53,56,45,50,56,46,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,177,226,53,151,6,0,16,1,98,53,56,45,51,50,46,52,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,202,142,253,243,9,0,16,1,98,53,56,45,48,57,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,49,91,253,159,11,0,32,0,98,53,56,45,48,52,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,141,240,130,148,17,0,32,0,98,53,56,45,48,51,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,64,196,139,21,17,0,32,0,98,53,56,45,48,50,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,124,48,110,106,17,0,32,0,98,53,56,45,48,49,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,240,233,1,17,0,32,0,98,53,56,45,48,54,46,49,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,112,93,73,179,22,0,32,0,98,53,56,45,48,53,46,55,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,27,153,244,209,23,0,32,0,98,53,56,45,48,55,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,8,186,181,238,24,0,64,0,98,53,56,45,48,56,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,207,67,146,4,24,0,64,0,98,53,56,45,49,48,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,193,12,206,237,25,0,64,0,98,53,56,45,50,54,46,49,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,127,12,203,220,0,0,0,8,98,53,56,45,50,55,46,53,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,61,1,107,92,0,0,0,8,98,53,56,45,50,51,46,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,244,143,125,123,0,0,0,8,98,53,56,45,50,52,46,53,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,48,31,248,251,0,0,0,8,98,53,56,45,50,53,46,55,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,66,115,84,222,0,0,0,8,12,0,0,0,255,255,255,0,0,0,0,0,13,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,232,75,4,0,12,0,0,0,1,4,4,0,96,135,7,0,12,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,12,0,0,0,1,8,0,0,96,135,7,0,12,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,12,0,0,0,1,48,16,0,104,236,7,0,12,0,0,0,1,48,48,0,128,230,7,0,12,0,0,0,1,48,0,0,120,211,6,0,12,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,12,0,0,0,1,192,64,0,104,236,7,0,12,0,0,0,1,192,192,0,128,230,7,0,12,0,0,0,1,192,0,0,120,211,6,0,12,0,0,0,1,192,128,0,184,164,6,0,0,0,0,0,254,0,4,0,0,241,6,0,13,0,0,0,1,48,48,0,96,135,7,0,13,0,0,0,1,48,32,0,152,182,7,0,13,0,0,0,1,48,16,0,224,238,6,0,13,0,0,0,1,48,0,0,224,238,6,0,0,0,0,0,184,40,2,0,1,0,0,0,139,151,215,0,248,191,2,0,56,250,6,0,1,0,0,0,131,151,215,0,184,160,2,0,184,164,8,0,1,0,0,0,138,151,215,0,64,246,1,0,240,167,7,0,1,0,0,0,141,151,215,0,192,135,2,0,176,163,7,0,1,0,0,0,142,151,215,0,240,108,2,0,208,158,7,0,1,0,0,0,143,151,215,0,96,82,2,0,184,154,7,0,1,0,0,0,135,151,215,0,32,56,2,0,16,190,6,0,1,0,0,0,128,151,215,0,152,30,2,0,56,184,6,0,1,0,0,0,129,151,215,0,232,10,2,0,88,212,3,0,1,0,0,0,200,147,215,0,40,185,3,0,16,17,8,0,1,0,0,0,140,151,215,0,224,12,8,0,56,58,1,0,1,0,0,0,130,151,215,0,64,50,1,0,248,5,8,0,9,0,0,0,152,151,215,0,32,58,1,0,144,250,7,0,9,0,0,0,153,151,215,0,32,58,1,0,184,40,2,0,1,0,0,0,208,155,215,0,248,191,2,0,56,250,6,0,1,0,0,0,214,155,215,0,184,160,2,0,184,164,8,0,1,0,0,0,209,155,215,0,64,246,1,0,240,190,7,0,4,0,0,0,112,156,215,0,208,13,4,0,184,252,8,0,4,0,0,0,104,156,215,0,184,198,5,0,208,240,5,0,4,0,0,0,96,156,215,0,152,30,2,0,32,201,5,0,4,0,0,0,88,156,215,0,232,10,2,0,16,17,8,0,1,0,0,0,211,155,215,0,224,12,8,0,32,77,1,0,1,0,0,0,210,155,215,0,216,70,1,0,88,212,3,0,1,0,0,0,200,154,215,0,40,185,3,0,248,5,8,0,9,0,0,0,0,156,215,0,32,58,1,0,144,250,7,0,9,0,0,0,1,156,215,0,32,58,1,0,0,0,0,0,64,0,0,0,128,0,0,0,192,0,0,0,0,1,0,0,64,1,0,0,128,1,0,0,192,1,0,0,0,4,0,0,64,4,0,0,128,4,0,0,192,4,0,0,0,5,0,0,64,5,0,0,128,5,0,0,192,5,0,0,0,0,0,0,8,0,0,0,16,0,0,0,24,0,0,0,32,0,0,0,40,0,0,0,48,0,0,0,56,0,0,0,0,2,0,0,8,2,0,0,16,2,0,0,24,2,0,0,32,2,0,0,40,2,0,0,48,2,0,0,56,2,0,0,168,86,7,0,1,0,0,0,119,254,146,0,248,191,2,0,24,38,7,0,1,0,0,0,115,254,146,0,184,160,2,0,56,210,6,0,1,0,0,0,39,246,146,0,192,135,2,0,24,163,6,0,1,0,0,0,38,246,146,0,240,108,2,0,152,122,6,0,1,0,0,0,37,246,146,0,96,82,2,0,192,72,6,0,1,0,0,0,36,246,146,0,32,56,2,0,200,110,3,0,1,0,0,0,35,246,146,0,152,30,2,0,120,89,3,0,1,0,0,0,34,246,146,0,232,10,2,0,144,236,1,0,1,0,0,0,113,254,146,0,136,224,1,0,176,223,1,0,1,0,0,0,111,239,146,0,72,198,1,0,192,209,1,0,1,0,0,0,110,239,146,0,24,182,1,0,24,198,1,0,1,0,0,0,109,239,146,0,40,167,1,0,120,189,1,0,1,0,0,0,108,239,146,0,200,149,1,0,224,22,1,0,1,0,0,0,107,239,146,0,56,126,1,0,160,14,1,0,1,0,0,0,106,239,146,0,32,101,1,0,88,212,3,0,1,0,0,0,80,218,146,0,40,185,3,0,72,65,1,0,9,0,0,0,0,5,147,0,32,58,1,0,48,50,1,0,9,0,0,0,1,5,147,0,32,58,1,0,117,101,99,117,46,48,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,77,138,216,34,1,0,16,1,117,101,99,117,46,48,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,205,207,54,100,1,0,16,1,117,101,99,117,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,27,18,111,51,1,0,16,1,117,101,99,117,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,132,217,153,111,1,0,16,1,117,101,99,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,54,20,175,220,5,0,32,0,117,101,99,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,65,223,7,40,5,0,32,0,117,101,99,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,2,141,112,138,5,0,32,0,117,101,99,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,239,224,123,222,5,0,32,0,117,101,99,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,88,53,0,26,5,0,32,0,117,101,99,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,249,166,248,79,5,0,32,0,117,101,99,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,18,174,103,177,5,0,32,0,117,101,99,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,194,189,100,16,5,0,32,0,117,101,99,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,21,189,53,194,10,0,16,1,117,101,99,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,57,93,178,129,12,0,64,0,117,101,99,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,82,158,114,39,12,0,64,0,117,101,99,104,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,94,54,201,20,1,0,16,1,117,101,99,104,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,220,149,148,87,1,0,16,1,117,101,99,104,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,142,122,128,150,1,0,16,1,117,101,99,104,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,188,157,43,104,1,0,16,1,117,101,99,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,54,20,175,220,5,0,32,0,117,101,99,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,65,223,7,40,5,0,32,0,117,101,99,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,2,141,112,138,5,0,32,0,117,101,99,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,239,224,123,222,5,0,32,0,117,101,99,46,49,52,109,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,88,53,0,26,5,0,32,0,117,101,99,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,249,166,248,79,5,0,32,0,117,101,99,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,18,174,103,177,5,0,32,0,117,101,99,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,194,189,100,16,5,0,32,0,117,101,99,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,21,189,53,194,10,0,16,1,117,101,99,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,57,93,178,129,12,0,64,0,117,101,99,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,82,158,114,39,12,0,64,0,117,101,99,101,100,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,43,93,114,172,1,0,16,1,117,101,99,101,100,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,141,19,0,248,1,0,16,1,117,101,99,101,100,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,242,18,106,235,1,0,16,1,117,101,99,101,100,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,154,236,128,131,1,0,16,1,117,101,99,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,54,20,175,220,5,0,32,0,117,101,99,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,65,223,7,40,5,0,32,0,117,101,99,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,2,141,112,138,5,0,32,0,117,101,99,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,239,224,123,222,5,0,32,0,117,101,99,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,88,53,0,26,5,0,32,0,117,101,99,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,249,166,248,79,5,0,32,0,117,101,99,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,18,174,103,177,5,0,32,0,117,101,99,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,194,189,100,16,5,0,32,0,117,101,99,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,21,189,53,194,10,0,16,1,117,101,99,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,57,93,178,129,12,0,64,0,117,101,99,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,82,158,114,39,12,0,64,0,117,101,99,97,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,177,137,69,189,1,0,16,1,117,101,99,97,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,125,75,19,29,1,0,16,1,117,101,99,97,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,199,31,88,156,1,0,16,1,117,101,99,97,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,80,124,42,201,1,0,16,1,117,101,99,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,54,20,175,220,5,0,32,0,117,101,99,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,65,223,7,40,5,0,32,0,117,101,99,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,2,141,112,138,5,0,32,0,117,101,99,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,239,224,123,222,5,0,32,0,117,101,99,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,88,53,0,26,5,0,32,0,117,101,99,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,249,166,248,79,5,0,32,0,117,101,99,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,18,174,103,177,5,0,32,0,117,101,99,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,194,189,100,16,5,0,32,0,117,101,99,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,21,189,53,194,10,0,16,1,117,101,99,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,57,93,178,129,12,0,64,0,117,101,99,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,82,158,114,39,12,0,64,0,168,86,7,0,1,0,0,0,96,240,146,0,248,191,2,0,24,38,7,0,1,0,0,0,31,1,147,0,184,160,2,0,56,210,6,0,1,0,0,0,24,1,147,0,192,135,2,0,24,163,6,0,1,0,0,0,25,1,147,0,240,108,2,0,152,122,6,0,1,0,0,0,26,1,147,0,96,82,2,0,192,72,6,0,1,0,0,0,27,1,147,0,32,56,2,0,200,110,3,0,1,0,0,0,28,1,147,0,152,30,2,0,120,89,3,0,1,0,0,0,29,1,147,0,232,10,2,0,120,74,3,0,1,0,0,0,30,1,147,0,152,138,8,0,40,246,1,0,1,0,0,0,97,240,146,0,64,246,1,0,144,236,1,0,1,0,0,0,119,248,146,0,136,224,1,0,176,223,1,0,1,0,0,0,112,248,146,0,72,198,1,0,192,209,1,0,1,0,0,0,113,248,146,0,24,182,1,0,24,198,1,0,1,0,0,0,114,248,146,0,40,167,1,0,120,189,1,0,1,0,0,0,115,248,146,0,200,149,1,0,224,22,1,0,1,0,0,0,116,248,146,0,56,126,1,0,160,14,1,0,1,0,0,0,117,248,146,0,32,101,1,0,176,9,1,0,1,0,0,0,118,248,146,0,96,32,8,0,88,212,3,0,1,0,0,0,112,220,146,0,40,185,3,0,72,65,1,0,9,0,0,0,120,6,147,0,32,58,1,0,48,50,1,0,9,0,0,0,121,6,147,0,32,58,1,0,34,0,0,0,255,255,191,0,0,0,0,0,35,0,0,0,255,255,255,0,0,0,0,0,36,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,112,59,6,0,34,0,0,0,1,3,0,0,64,106,4,0,34,0,0,0,1,3,3,0,160,196,4,0,34,0,0,0,1,3,2,0,88,67,3,0,34,0,0,0,1,3,1,0,176,17,8,0,0,0,0,0,254,0,4,0,72,202,5,0,34,0,0,0,1,12,0,0,160,203,8,0,34,0,0,0,1,12,8,0,80,246,3,0,34,0,0,0,1,12,12,0,248,38,7,0,34,0,0,0,1,12,4,0,112,212,3,0,0,0,0,0,254,0,2,0,168,79,2,0,34,0,0,0,1,16,16,0,184,234,6,0,34,0,0,0,1,16,0,0,192,229,6,0,0,0,0,0,254,0,2,0,24,225,6,0,34,0,0,0,1,32,0,0,136,117,3,0,34,0,0,0,1,32,32,0,48,3,7,0,0,0,0,0,254,0,2,0,168,234,7,0,34,0,0,0,1,64,64,0,96,135,7,0,34,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,34,0,0,0,1,128,128,0,96,135,7,0,34,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,35,0,0,0,1,1,1,0,96,135,7,0,35,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,200,30,2,0,35,0,0,0,1,2,2,0,240,242,5,0,35,0,0,0,1,2,0,0,216,104,6,0,0,0,0,0,254,0,2,0,88,160,1,0,35,0,0,0,1,4,4,0,136,86,1,0,35,0,0,0,1,4,0,0,184,147,6,0,0,0,0,0,254,0,2,0,96,46,8,0,35,0,0,0,1,8,8,0,192,255,2,0,35,0,0,0,1,8,0,0,208,75,4,0,0,0,0,0,254,0,16,0,32,4,2,0,35,0,0,0,1,240,160,0,144,160,3,0,35,0,0,0,1,240,176,0,96,135,3,0,35,0,0,0,1,240,192,0,32,136,7,0,35,0,0,0,1,240,208,0,40,88,7,0,35,0,0,0,1,240,224,0,96,39,7,0,35,0,0,0,1,240,16,0,32,202,2,0,35,0,0,0,1,240,48,0,120,113,6,0,35,0,0,0,1,240,32,0,232,228,5,0,35,0,0,0,1,240,240,0,144,251,6,0,35,0,0,0,1,240,64,0,120,211,6,0,35,0,0,0,1,240,144,0,184,164,6,0,35,0,0,0,1,240,128,0,80,74,6,0,35,0,0,0,1,240,112,0,192,32,6,0,35,0,0,0,1,240,96,0,192,234,2,0,35,0,0,0,1,240,80,0,32,242,5,0,35,0,0,0,1,240,0,0,16,227,4,0,0,0,0,0,254,0,4,0,232,202,6,0,36,0,0,0,1,3,0,0,72,242,7,0,36,0,0,0,1,3,3,0,88,207,5,0,36,0,0,0,1,3,1,0,176,236,7,0,36,0,0,0,1,3,2,0,184,230,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,100,111,95,52,54,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,62,54,96,249,2,0,16,1,100,111,95,52,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,185,102,254,227,2,0,16,1,100,111,95,53,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,36,1,225,255,9,0,16,1,100,111,95,111,98,106,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,196,241,145,84,15,0,32,0,100,111,95,115,110,100,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,43,184,222,242,24,0,64,0,100,111,95,112,105,118,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,247,18,240,196,28,0,32,0,110,45,49,50,46,100,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,82,235,112,90,0,0,16,1,110,45,49,49,46,97,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,146,235,135,56,0,0,16,1,101,103,48,54,46,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,247,250,129,43,0,0,16,1,101,103,48,51,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,157,46,44,197,0,0,16,1,101,103,48,55,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,81,47,29,0,0,0,16,1,101,103,50,53,46,49,53,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,25,123,85,221,0,0,32,0,101,103,50,54,46,49,54,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,143,252,117,93,0,0,32,0,101,103,49,56,46,49,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,229,195,207,5,0,0,32,0,101,103,50,48,46,49,55,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,143,152,30,225,0,0,32,0,101,103,50,50,46,49,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,128,216,147,184,0,0,32,0,101,103,50,52,46,49,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,218,109,34,111,0,0,32,0,101,103,51,48,46,57,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,126,230,56,36,0,0,32,0,101,103,50,56,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,179,42,105,92,0,0,32,0,101,103,49,53,46,49,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,127,214,23,86,0,0,32,0,101,103,49,54,46,49,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,51,38,228,23,0,0,32,0,101,103,49,49,46,49,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,216,232,131,186,0,0,32,0,101,103,49,50,46,49,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,52,161,162,254,0,0,32,0,101,103,49,51,46,49,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,142,224,145,253,0,0,32,0,101,103,49,52,46,49,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,10,118,60,232,0,0,32,0,101,103,48,57,46,49,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,35,123,27,96,0,0,32,0,101,103,49,48,46,49,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,26,138,238,238,0,0,32,0,101,103,48,56,46,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,22,201,242,146,0,0,64,0,105,56,55,53,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,16,16,98,57,53,45,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,122,232,252,208,2,0,16,1,98,57,53,45,49,49,45,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,211,12,212,218,2,0,16,1,98,57,53,45,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,11,31,110,164,2,0,16,1,98,57,53,45,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,101,44,13,53,2,0,16,1,98,57,53,45,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,225,73,170,181,9,0,16,1,98,57,53,45,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,121,233,180,103,11,0,32,0,98,57,53,45,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,206,118,193,81,15,0,32,0,98,57,53,45,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,22,23,76,172,24,0,64,0,98,57,53,45,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,209,160,58,84,28,0,32,0,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,2,2,0,96,135,7,0,19,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,4,4,0,96,135,7,0,19,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,8,0,0,96,135,7,0,19,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,32,4,2,0,19,0,0,0,1,48,0,0,80,252,6,0,19,0,0,0,1,48,16,0,16,242,7,0,19,0,0,0,1,48,32,0,104,236,7,0,19,0,0,0,1,48,48,0,128,230,7,0,0,0,0,0,254,0,4,0,168,248,6,0,19,0,0,0,1,192,0,0,16,242,7,0,19,0,0,0,1,192,64,0,104,236,7,0,19,0,0,0,1,192,128,0,80,245,6,0,19,0,0,0,1,192,192,0,240,240,6,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,3,2,0,80,246,3,0,20,0,0,0,1,3,3,0,80,124,6,0,20,0,0,0,1,3,1,0,112,212,3,0,20,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,64,37,5,0,20,0,0,0,1,12,12,0,96,103,4,0,20,0,0,0,1,12,8,0,0,101,4,0,20,0,0,0,1,12,4,0,48,99,4,0,20,0,0,0,1,12,0,0,96,97,4,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,48,32,0,208,75,4,0,20,0,0,0,1,48,48,0,8,49,4,0,20,0,0,0,1,48,0,0,152,21,4,0,20,0,0,0,1,48,16,0,72,246,3,0,98,57,53,45,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,122,232,252,208,2,0,16,1,98,57,53,45,49,49,45,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,211,12,212,218,2,0,16,1,98,57,53,45,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,11,31,110,164,2,0,16,1,98,57,53,45,48,57,46,98,105,110,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,57,109,200,216,2,0,16,1,98,57,53,45,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,225,73,170,181,9,0,16,1,98,57,53,45,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,121,233,180,103,11,0,32,0,98,57,53,45,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,206,118,193,81,15,0,32,0,98,57,53,45,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,22,23,76,172,24,0,64,0,98,57,53,45,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,209,160,58,84,28,0,32,0,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,2,2,0,96,135,7,0,19,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,4,4,0,96,135,7,0,19,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,8,0,0,96,135,7,0,19,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,19,0,0,0,1,48,0,0,104,236,7,0,19,0,0,0,1,48,48,0,128,230,7,0,19,0,0,0,1,48,0,0,120,211,6,0,19,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,19,0,0,0,1,192,64,0,104,236,7,0,19,0,0,0,1,192,192,0,128,230,7,0,19,0,0,0,1,192,0,0,120,211,6,0,19,0,0,0,1,192,128,0,184,164,6,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,3,2,0,80,246,3,0,20,0,0,0,1,3,3,0,80,124,6,0,20,0,0,0,1,3,1,0,112,212,3,0,20,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,64,37,5,0,20,0,0,0,1,12,12,0,96,103,4,0,20,0,0,0,1,12,8,0,0,101,4,0,20,0,0,0,1,12,4,0,48,99,4,0,20,0,0,0,1,12,0,0,96,97,4,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,48,32,0,208,75,4,0,20,0,0,0,1,48,48,0,8,49,4,0,20,0,0,0,1,48,0,0,152,21,4,0,20,0,0,0,1,48,16,0,72,246,3,0,184,40,2,0,1,0,0,0,250,150,215,0,248,191,2,0,56,250,6,0,1,0,0,0,15,151,215,0,184,160,2,0,184,164,8,0,1,0,0,0,251,150,215,0,64,246,1,0,88,149,7,0,1,0,0,0,7,151,215,0,136,224,1,0,56,210,6,0,1,0,0,0,8,151,215,0,192,135,2,0,24,163,6,0,1,0,0,0,9,151,215,0,240,108,2,0,152,122,6,0,1,0,0,0,10,151,215,0,96,82,2,0,192,72,6,0,1,0,0,0,11,151,215,0,32,56,2,0,48,123,2,0,1,0,0,0,12,151,215,0,152,30,2,0,96,69,2,0,1,0,0,0,13,151,215,0,232,10,2,0,144,55,2,0,1,0,0,0,14,151,215,0,152,138,8,0,176,223,1,0,1,0,0,0,0,151,215,0,72,198,1,0,192,209,1,0,1,0,0,0,1,151,215,0,24,182,1,0,24,198,1,0,1,0,0,0,2,151,215,0,40,167,1,0,120,189,1,0,1,0,0,0,3,151,215,0,200,149,1,0,248,187,8,0,1,0,0,0,4,151,215,0,56,126,1,0,184,179,8,0,1,0,0,0,5,151,215,0,32,101,1,0,240,173,8,0,1,0,0,0,6,151,215,0,96,32,8,0,88,212,3,0,1,0,0,0,200,147,215,0,40,185,3,0,16,17,8,0,1,0,0,0,249,150,215,0,224,12,8,0,56,58,1,0,1,0,0,0,248,150,215,0,64,50,1,0,248,5,8,0,9,0,0,0,24,151,215,0,32,58,1,0,144,250,7,0,9,0,0,0,25,151,215,0,32,58,1,0,168,86,7,0,1,0,0,0,212,47,216,0,248,191,2,0,24,38,7,0,1,0,0,0,208,47,216,0,184,160,2,0,56,210,6,0,1,0,0,0,35,48,216,0,192,135,2,0,24,163,6,0,1,0,0,0,34,48,216,0,240,108,2,0,152,122,6,0,1,0,0,0,33,48,216,0,96,82,2,0,192,72,6,0,1,0,0,0,32,48,216,0,32,56,2,0,232,158,3,0,1,0,0,0,36,48,216,0,152,30,2,0,40,147,2,0,1,0,0,0,37,48,216,0,232,10,2,0,24,134,3,0,1,0,0,0,38,48,216,0,152,138,8,0,40,246,1,0,1,0,0,0,213,47,216,0,64,246,1,0,144,236,1,0,1,0,0,0,209,47,216,0,136,224,1,0,176,223,1,0,1,0,0,0,43,48,216,0,72,198,1,0,192,209,1,0,1,0,0,0,42,48,216,0,24,182,1,0,24,198,1,0,1,0,0,0,41,48,216,0,40,167,1,0,120,189,1,0,1,0,0,0,40,48,216,0,200,149,1,0,200,32,1,0,1,0,0,0,44,48,216,0,56,126,1,0,200,197,8,0,1,0,0,0,45,48,216,0,32,101,1,0,184,251,8,0,1,0,0,0,46,48,216,0,96,32,8,0,88,212,3,0,1,0,0,0,144,46,216,0,40,185,3,0,240,152,1,0,1,0,0,0,201,47,216,0,216,70,1,0,16,17,8,0,1,0,0,0,202,47,216,0,224,12,8,0,136,67,2,0,1,0,0,0,176,48,216,0,48,119,7,0,8,66,2,0,1,0,0,0,184,48,216,0,112,109,7,0,184,40,2,0,1,0,0,0,46,234,148,0,248,191,2,0,56,250,6,0,1,0,0,0,40,234,148,0,184,160,2,0,184,164,8,0,1,0,0,0,47,234,148,0,64,246,1,0,88,149,7,0,1,0,0,0,41,234,148,0,136,224,1,0,240,167,7,0,1,0,0,0,107,233,148,0,192,135,2,0,176,163,7,0,1,0,0,0,106,233,148,0,240,108,2,0,208,158,7,0,1,0,0,0,105,233,148,0,96,82,2,0,184,154,7,0,1,0,0,0,104,233,148,0,32,56,2,0,176,108,2,0,1,0,0,0,108,233,148,0,152,30,2,0,88,212,3,0,1,0,0,0,176,220,146,0,40,185,3,0,248,5,8,0,9,0,0,0,200,94,147,0,32,58,1,0,144,250,7,0,9,0,0,0,201,94,147,0,32,58,1,0,18,0,0,0,255,255,255,0,0,0,0,0,19,0,0,0,255,255,82,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,18,0,0,0,1,15,2,0,80,252,6,0,18,0,0,0,1,15,5,0,16,242,7,0,18,0,0,0,1,15,8,0,104,236,7,0,18,0,0,0,1,15,4,0,120,113,6,0,18,0,0,0,1,15,1,0,232,228,5,0,18,0,0,0,1,15,15,0,128,230,7,0,18,0,0,0,1,15,3,0,56,141,7,0,18,0,0,0,1,15,7,0,120,211,6,0,18,0,0,0,1,15,14,0,184,164,6,0,18,0,0,0,1,15,6,0,24,1,7,0,18,0,0,0,1,15,13,0,80,74,6,0,18,0,0,0,1,15,12,0,192,32,6,0,18,0,0,0,1,15,11,0,192,234,2,0,18,0,0,0,1,15,10,0,32,242,5,0,18,0,0,0,1,15,9,0,176,192,2,0,18,0,0,0,1,15,0,0,16,227,4,0,0,0,0,0,254,0,15,0,160,123,6,0,18,0,0,0,1,240,32,0,80,252,6,0,18,0,0,0,1,240,80,0,16,242,7,0,18,0,0,0,1,240,128,0,104,236,7,0,18,0,0,0,1,240,64,0,120,113,6,0,18,0,0,0,1,240,16,0,232,228,5,0,18,0,0,0,1,240,240,0,128,230,7,0,18,0,0,0,1,240,48,0,56,141,7,0,18,0,0,0,1,240,112,0,120,211,6,0,18,0,0,0,1,240,224,0,184,164,6,0,18,0,0,0,1,240,96,0,24,1,7,0,18,0,0,0,1,240,208,0,80,74,6,0,18,0,0,0,1,240,192,0,192,32,6,0,18,0,0,0,1,240,176,0,192,234,2,0,18,0,0,0,1,240,160,0,32,242,5,0,18,0,0,0,1,240,144,0,176,192,2,0,0,0,0,0,254,0,4,0,128,129,4,0,19,0,0,0,1,3,3,0,208,75,4,0,19,0,0,0,1,3,2,0,8,49,4,0,19,0,0,0,1,3,1,0,72,246,3,0,19,0,0,0,1,3,0,0,64,47,7,0,0,0,0,0,254,0,2,0,200,30,2,0,19,0,0,0,1,4,0,0,120,97,1,0,19,0,0,0,1,4,4,0,96,19,1,0,0,0,0,0,254,0,4,0,64,37,5,0,19,0,0,0,1,24,24,0,232,68,3,0,19,0,0,0,1,24,16,0,200,55,3,0,19,0,0,0,1,24,8,0,88,36,3,0,19,0,0,0,1,24,0,0,136,11,3,0,0,0,0,0,254,0,4,0,72,202,5,0,19,0,0,0,1,96,96,0,80,246,3,0,19,0,0,0,1,96,64,0,248,38,7,0,19,0,0,0,1,96,32,0,112,212,3,0,19,0,0,0,1,96,0,0,24,99,5,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,128,128,0,96,135,7,0,19,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,20,0,0,0,1,1,1,0,96,135,7,0,20,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,20,0,0,0,1,4,4,0,96,135,7,0,20,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,101,112,114,45,49,52,55,57,50,46,97,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,2,157,61,69,1,0,16,1,101,112,114,45,49,52,55,57,52,46,97,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,143,117,38,68,1,0,16,1,101,112,114,45,49,52,55,57,51,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,243,122,157,220,1,0,16,1,101,112,114,45,49,52,55,57,53,46,97,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,217,247,91,126,1,0,16,1,109,112,114,45,49,52,55,56,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,170,215,247,196,2,0,32,0,109,112,114,45,49,52,55,56,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,5,141,201,204,2,0,32,0,109,112,114,45,49,52,55,56,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,236,43,32,239,2,0,32,0,109,112,114,45,49,52,55,56,56,46,99,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,54,85,176,181,3,0,32,0,109,112,114,45,49,52,55,57,54,46,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,10,34,51,192,3,0,32,0,109,112,114,45,49,52,55,56,57,46,99,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,151,203,155,15,3,0,32,0,109,112,114,45,49,52,55,57,55,46,97,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,201,28,48,76,3,0,32,0,109,112,114,45,49,52,55,57,48,46,99,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,39,172,7,106,3,0,32,0,109,112,114,45,49,52,55,57,56,46,97,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,37,70,99,80,3,0,32,0,109,112,114,45,49,52,55,57,49,46,99,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,43,53,174,164,3,0,32,0,109,112,114,45,49,52,55,57,57,46,97,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,37,176,183,174,3,0,32,0,101,112,114,45,49,52,55,56,55,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,199,238,111,204,4,0,16,1,109,112,114,45,49,52,55,56,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,242,73,131,204,19,0,64,0,109,112,114,45,49,52,55,56,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,19,186,171,123,19,0,64,0,109,112,114,45,49,52,55,56,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,228,120,56,7,19,0,64,0,51,49,55,45,48,49,57,52,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,203,196,203,64,5,0,16,1,100,50,56,45,48,54,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,81,255,75,91,2,0,16,1,100,50,56,45,48,55,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,76,149,184,63,2,0,16,1,100,50,56,45,48,57,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,193,12,58,20,2,0,16,1,100,50,56,45,48,56,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,217,43,135,76,2,0,16,1,100,50,56,45,49,48,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,116,93,128,64,9,0,16,1,100,50,56,45,48,52,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,107,194,171,220,12,0,32,0,100,50,56,45,48,53,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,101,150,47,134,12,0,32,0,100,50,56,45,48,49,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,105,123,29,24,15,0,32,0,100,50,56,45,48,50,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,28,119,1,211,15,0,32,0,100,50,56,45,48,51,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,82,75,128,161,24,0,64,0,21,0,0,0,255,255,254,0,0,0,0,0,22,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,21,0,0,0,1,1,0,0,120,97,1,0,21,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,2,0,144,212,8,0,21,0,0,0,1,2,2,0,96,135,7,0,21,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,21,0,0,0,1,4,4,0,96,135,7,0,21,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,21,0,0,0,1,8,0,0,96,135,7,0,21,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,21,0,0,0,1,12,0,0,16,242,7,0,21,0,0,0,1,12,8,0,104,236,7,0,21,0,0,0,1,12,12,0,128,230,7,0,21,0,0,0,1,12,4,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,21,0,0,0,1,3,0,0,16,242,7,0,21,0,0,0,1,3,2,0,104,236,7,0,21,0,0,0,1,3,3,0,128,230,7,0,21,0,0,0,1,3,1,0,184,164,6,0,0,0,0,0,254,0,4,0,72,202,5,0,22,0,0,0,1,3,2,0,80,246,3,0,22,0,0,0,1,3,3,0,80,124,6,0,22,0,0,0,1,3,1,0,112,212,3,0,22,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,120,95,4,0,22,0,0,0,1,24,16,0,56,94,4,0,22,0,0,0,1,24,24,0,248,38,7,0,22,0,0,0,1,24,8,0,176,90,4,0,22,0,0,0,1,24,0,0,192,87,4,0,0,0,0,0,254,0,2,0,224,21,4,0,22,0,0,0,1,128,0,0,48,224,5,0,22,0,0,0,1,128,128,0,0,220,5,0,0,0,0,0,184,40,2,0,1,0,0,0,208,155,215,0,248,191,2,0,56,250,6,0,1,0,0,0,212,155,215,0,184,160,2,0,184,164,8,0,1,0,0,0,209,155,215,0,64,246,1,0,88,149,7,0,1,0,0,0,213,155,215,0,136,224,1,0,104,28,8,0,1,0,0,0,170,155,215,0,232,209,1,0,248,23,7,0,1,0,0,0,168,155,215,0,144,189,1,0,64,183,7,0,1,0,0,0,171,155,215,0,104,195,5,0,48,19,7,0,1,0,0,0,169,155,215,0,32,245,8,0,56,210,6,0,1,0,0,0,205,155,215,0,192,135,2,0,24,163,6,0,1,0,0,0,204,155,215,0,240,108,2,0,152,122,6,0,1,0,0,0,207,155,215,0,96,82,2,0,192,72,6,0,1,0,0,0,206,155,215,0,32,56,2,0,48,123,2,0,1,0,0,0,200,155,215,0,152,30,2,0,96,69,2,0,1,0,0,0,201,155,215,0,232,10,2,0,176,223,1,0,1,0,0,0,197,155,215,0,72,198,1,0,192,209,1,0,1,0,0,0,196,155,215,0,24,182,1,0,24,198,1,0,1,0,0,0,199,155,215,0,40,167,1,0,120,189,1,0,1,0,0,0,198,155,215,0,200,149,1,0,248,187,8,0,1,0,0,0,192,155,215,0,56,126,1,0,184,179,8,0,1,0,0,0,193,155,215,0,32,101,1,0,192,122,8,0,1,0,0,0,189,155,215,0,208,174,1,0,40,116,8,0,1,0,0,0,188,155,215,0,48,160,1,0,72,110,8,0,1,0,0,0,191,155,215,0,160,140,1,0,184,102,8,0,1,0,0,0,190,155,215,0,56,112,1,0,240,45,8,0,1,0,0,0,184,155,215,0,32,92,1,0,40,38,8,0,1,0,0,0,185,155,215,0,64,77,1,0,248,16,8,0,1,0,0,0,181,155,215,0,32,231,8,0,192,12,8,0,1,0,0,0,180,155,215,0,88,214,8,0,224,5,8,0,1,0,0,0,183,155,215,0,224,202,8,0,144,1,8,0,1,0,0,0,182,155,215,0,72,193,8,0,72,204,7,0,1,0,0,0,176,155,215,0,144,180,8,0,208,196,7,0,1,0,0,0,177,155,215,0,208,164,8,0,16,17,8,0,1,0,0,0,211,155,215,0,224,12,8,0,32,77,1,0,1,0,0,0,210,155,215,0,216,70,1,0,88,212,3,0,1,0,0,0,200,154,215,0,40,185,3,0,248,5,8,0,9,0,0,0,0,156,215,0,32,58,1,0,144,250,7,0,9,0,0,0,1,156,215,0,32,58,1,0,184,40,2,0,1,0,0,0,208,155,215,0,248,191,2,0,56,250,6,0,1,0,0,0,212,155,215,0,184,160,2,0,184,164,8,0,1,0,0,0,209,155,215,0,64,246,1,0,88,149,7,0,1,0,0,0,213,155,215,0,136,224,1,0,56,210,6,0,1,0,0,0,205,155,215,0,192,135,2,0,24,163,6,0,1,0,0,0,204,155,215,0,240,108,2,0,152,122,6,0,1,0,0,0,207,155,215,0,96,82,2,0,192,72,6,0,1,0,0,0,206,155,215,0,32,56,2,0,48,123,2,0,1,0,0,0,200,155,215,0,152,30,2,0,96,69,2,0,1,0,0,0,201,155,215,0,232,10,2,0,176,223,1,0,1,0,0,0,197,155,215,0,72,198,1,0,192,209,1,0,1,0,0,0,196,155,215,0,24,182,1,0,24,198,1,0,1,0,0,0,199,155,215,0,40,167,1,0,120,189,1,0,1,0,0,0,198,155,215,0,200,149,1,0,248,187,8,0,1,0,0,0,192,155,215,0,56,126,1,0,184,179,8,0,1,0,0,0,193,155,215,0,32,101,1,0,16,17,8,0,1,0,0,0,211,155,215,0,224,12,8,0,32,77,1,0,1,0,0,0,210,155,215,0,216,70,1,0,88,212,3,0,1,0,0,0,200,154,215,0,40,185,3,0,248,5,8,0,9,0,0,0,0,156,215,0,32,58,1,0,144,250,7,0,9,0,0,0,1,156,215,0,32,58,1,0,184,40,2,0,1,0,0,0,10,151,215,0,248,191,2,0,56,250,6,0,1,0,0,0,3,151,215,0,184,160,2,0,184,164,8,0,1,0,0,0,11,151,215,0,64,246,1,0,240,190,7,0,4,0,0,0,104,150,215,0,208,13,4,0,32,201,5,0,1,0,0,0,13,151,215,0,152,30,2,0,208,240,5,0,1,0,0,0,5,151,215,0,232,10,2,0,64,154,6,0,1,0,0,0,0,151,215,0,152,138,8,0,32,160,5,0,1,0,0,0,9,151,215,0,48,119,7,0,32,158,6,0,1,0,0,0,15,151,215,0,112,109,7,0,72,137,7,0,1,0,0,0,2,151,215,0,24,133,7,0,88,212,3,0,1,0,0,0,200,147,215,0,40,185,3,0,16,17,8,0,1,0,0,0,12,151,215,0,224,12,8,0,56,58,1,0,1,0,0,0,1,151,215,0,64,50,1,0,248,5,8,0,9,0,0,0,24,151,215,0,32,58,1,0,144,250,7,0,9,0,0,0,25,151,215,0,32,58,1,0,30,0,0,0,255,255,255,0,0,0,0,0,31,0,0,0,255,255,127,0,0,0,0,0,0,0,0,0,254,0,8,0,32,4,2,0,30,0,0,0,1,7,0,0,40,88,7,0,30,0,0,0,1,7,1,0,96,39,7,0,30,0,0,0,1,7,7,0,144,251,6,0,30,0,0,0,1,7,6,0,184,164,6,0,30,0,0,0,1,7,5,0,80,74,6,0,30,0,0,0,1,7,4,0,192,32,6,0,30,0,0,0,1,7,3,0,192,234,2,0,30,0,0,0,1,7,2,0,32,242,5,0,0,0,0,0,254,0,2,0,144,212,8,0,30,0,0,0,1,64,64,0,96,135,7,0,30,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,24,172,6,0,30,0,0,0,1,128,128,0,96,135,7,0,30,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,31,0,0,0,1,12,8,0,80,246,3,0,31,0,0,0,1,12,12,0,248,38,7,0,31,0,0,0,1,12,4,0,112,212,3,0,31,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,2,0,168,234,7,0,31,0,0,0,1,128,128,0,96,135,7,0,31,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,168,86,7,0,1,0,0,0,56,2,147,0,248,191,2,0,56,210,6,0,1,0,0,0,122,249,146,0,192,135,2,0,24,163,6,0,1,0,0,0,123,249,146,0,240,108,2,0,152,122,6,0,1,0,0,0,120,249,146,0,96,82,2,0,192,72,6,0,1,0,0,0,121,249,146,0,32,56,2,0,200,110,3,0,1,0,0,0,124,249,146,0,152,30,2,0,120,89,3,0,1,0,0,0,125,249,146,0,232,10,2,0,120,74,3,0,1,0,0,0,126,249,146,0,152,138,8,0,40,246,1,0,1,0,0,0,57,2,147,0,64,246,1,0,176,223,1,0,1,0,0,0,90,241,146,0,72,198,1,0,192,209,1,0,1,0,0,0,91,241,146,0,24,182,1,0,24,198,1,0,1,0,0,0,88,241,146,0,40,167,1,0,120,189,1,0,1,0,0,0,89,241,146,0,200,149,1,0,224,22,1,0,1,0,0,0,92,241,146,0,56,126,1,0,160,14,1,0,1,0,0,0,93,241,146,0,32,101,1,0,176,9,1,0,1,0,0,0,94,241,146,0,96,32,8,0,168,132,8,0,1,0,0,0,58,2,147,0,232,209,1,0,192,122,8,0,1,0,0,0,162,237,146,0,208,174,1,0,40,116,8,0,1,0,0,0,163,237,146,0,48,160,1,0,72,110,8,0,1,0,0,0,160,237,146,0,160,140,1,0,184,102,8,0,1,0,0,0,161,237,146,0,56,112,1,0,248,67,8,0,1,0,0,0,164,237,146,0,32,92,1,0,136,64,8,0,1,0,0,0,165,237,146,0,64,77,1,0,128,58,8,0,1,0,0,0,166,237,146,0,112,157,4,0,88,212,3,0,1,0,0,0,168,221,146,0,40,185,3,0,56,122,5,0,1,0,0,0,62,2,147,0,224,12,8,0,0,105,5,0,1,0,0,0,63,2,147,0,128,176,7,0,152,120,4,0,1,0,0,0,127,249,146,0,248,114,7,0,208,66,7,0,1,0,0,0,59,2,147,0,32,105,5,0,72,65,1,0,9,0,0,0,88,7,147,0,32,58,1,0,48,50,1,0,9,0,0,0,89,7,147,0,32,58,1,0,224,41,1,0,9,0,0,0,90,7,147,0,32,58,1,0,99,48,55,95,50,48,45,49,46,55,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,74,128,176,72,2,0,16,1,99,48,55,95,49,57,45,49,46,55,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,131,79,154,31,2,0,16,1,99,48,55,95,50,49,45,49,46,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,202,176,145,180,2,0,16,1,99,48,55,95,49,56,45,49,46,55,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,47,228,82,197,2,0,16,1,99,48,55,45,48,57,46,55,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,206,194,105,204,1,0,16,1,99,48,55,95,49,55,46,54,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,5,201,22,174,9,0,16,1,99,48,55,45,48,51,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,206,175,155,24,11,0,32,0,99,48,55,45,48,52,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,129,30,66,80,11,0,32,0,99,48,55,45,48,54,46,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,214,188,235,94,17,0,32,0,99,48,55,45,48,53,46,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,80,5,109,251,17,0,32,0,99,48,55,45,48,56,46,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,70,200,125,160,17,0,32,0,99,48,55,45,48,55,46,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,116,158,159,253,17,0,32,0,99,48,55,45,49,48,46,57,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,217,14,190,75,24,0,64,0,99,48,55,45,49,49,46,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,153,86,129,60,24,0,64,0,99,48,55,45,49,50,46,49,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0])
.concat([88,18,183,224,25,0,64,0,99,48,55,45,49,51,46,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,179,142,161,60,0,0,0,8,99,48,55,45,49,52,46,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,147,161,242,186,0,0,0,8,184,40,2,0,1,0,0,0,138,151,215,0,248,191,2,0,56,250,6,0,1,0,0,0,122,151,215,0,184,160,2,0,184,164,8,0,1,0,0,0,139,151,215,0,64,246,1,0,88,149,7,0,1,0,0,0,123,151,215,0,136,224,1,0,56,210,6,0,1,0,0,0,128,151,215,0,192,135,2,0,24,163,6,0,1,0,0,0,129,151,215,0,240,108,2,0,152,122,6,0,1,0,0,0,131,151,215,0,96,82,2,0,192,72,6,0,1,0,0,0,130,151,215,0,32,56,2,0,48,123,2,0,1,0,0,0,124,151,215,0,152,30,2,0,96,69,2,0,1,0,0,0,125,151,215,0,232,10,2,0,176,223,1,0,1,0,0,0,132,151,215,0,72,198,1,0,192,209,1,0,1,0,0,0,133,151,215,0,24,182,1,0,24,198,1,0,1,0,0,0,135,151,215,0,40,167,1,0,120,189,1,0,1,0,0,0,134,151,215,0,200,149,1,0,248,187,8,0,1,0,0,0,126,151,215,0,56,126,1,0,184,179,8,0,1,0,0,0,127,151,215,0,32,101,1,0,88,212,3,0,1,0,0,0,200,147,215,0,40,185,3,0,16,17,8,0,1,0,0,0,120,151,215,0,224,12,8,0,56,58,1,0,1,0,0,0,121,151,215,0,64,50,1,0,72,4,1,0,1,0,0,0,140,151,215,0,64,255,0,0,248,5,8,0,9,0,0,0,152,151,215,0,32,58,1,0,144,250,7,0,9,0,0,0,153,151,215,0,32,58,1,0,100,98,49,49,46,112,114,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,251,211,123,66,1,0,16,1,100,98,57,97,46,112,114,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,99,69,22,87,1,0,16,1,100,98,49,48,97,46,112,114,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,94,156,91,7,1,0,16,1,100,98,49,50,97,46,112,114,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,139,166,1,237,1,0,16,1,100,98,56,97,46,112,114,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,244,31,4,253,1,0,16,1,100,98,54,46,112,114,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,169,1,211,86,1,0,16,1,100,98,55,97,46,112,114,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,94,31,91,103,1,0,16,1,100,98,53,97,46,112,114,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,204,158,101,117,1,0,16,1,100,98,51,97,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,110,226,71,35,4,0,32,0,100,98,49,97,46,112,114,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,205,100,185,76,4,0,32,0,100,98,52,97,46,112,114,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,51,223,210,217,4,0,32,0,100,98,50,97,46,112,114,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,245,106,10,10,4,0,32,0,109,105,45,55,54,48,51,45,53,46,105,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,47,249,49,241,7,0,32,0,109,105,45,55,54,48,51,45,53,46,105,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,71,76,165,226,0,0,0,8,100,97,109,106,95,50,51,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,72,178,195,2,0,16,1,100,97,109,106,95,50,50,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,243,242,95,89,2,0,16,1,100,97,109,95,48,49,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,176,192,169,11,4,0,32,0,100,97,109,95,48,50,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,185,10,118,93,4,0,32,0,100,97,109,95,48,51,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,89,11,169,75,4,0,32,0,100,97,109,95,48,52,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,222,233,222,75,4,0,32,0,100,97,109,95,48,53,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,148,27,198,125,4,0,32,0,100,97,109,95,48,54,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,88,151,232,253,4,0,32,0,100,97,109,95,48,55,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,120,29,53,236,4,0,32,0,100,97,109,95,48,56,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,30,204,42,238,4,0,32,0,100,97,109,95,48,57,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,83,255,86,6,3,0,16,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,100,97,109,54,51,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,138,60,75,71,0,0,0,8,105,111,98,49,46,49,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,98,112,114,103,49,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,167,61,121,49,0,0,0,8,105,111,99,49,46,105,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,129,32,24,13,0,0,0,8,99,54,51,50,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,112,146,189,15,0,0,0,8,100,109,106,98,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,132,159,95,125,1,0,16,1,100,109,106,98,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,196,92,148,155,1,0,16,1,100,109,95,48,50,46,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,72,220,152,139,4,0,32,0,100,109,95,48,49,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,51,108,137,128,4,0,32,0,100,109,95,49,48,46,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,239,217,231,194,4,0,32,0,100,109,95,48,57,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,165,175,196,201,4,0,32,0,100,109,95,49,56,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,153,219,160,26,4,0,32,0,100,109,95,49,55,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,173,216,110,220,4,0,32,0,100,109,95,51,48,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,189,248,211,217,4,0,32,0,100,109,95,50,57,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,150,135,164,73,4,0,32,0,100,109,95,48,52,46,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,240,248,244,164,4,0,32,0,100,109,95,48,51,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,98,62,3,177,4,0,32,0,100,109,95,49,50,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,106,215,253,16,4,0,32,0,100,109,95,49,49,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,4,203,64,144,4,0,32,0,100,109,95,50,48,46,55,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,62,11,29,40,4,0,32,0,100,109,95,49,57,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,47,181,35,38,4,0,32,0,100,109,95,51,50,46,57,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,68,35,105,153,4,0,32,0,100,109,95,51,49,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,41,183,172,84,4,0,32,0,100,109,95,48,54,46,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,25,187,36,174,4,0,32,0,100,109,95,48,53,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,26,39,78,211,4,0,32,0,100,109,95,49,52,46,49,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,55,221,112,63,4,0,32,0,100,109,95,49,51,46,49,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,230,226,105,126,4,0,32,0,100,109,95,50,50,46,56,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,198,182,201,55,4,0,32,0,100,109,95,50,49,46,56,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,180,69,19,47,4,0,32,0,100,109,95,50,54,46,49,48,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,42,33,42,60,4,0,32,0,100,109,95,50,53,46,49,48,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,5,172,154,136,4,0,32,0,100,109,95,48,56,46,56,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,140,242,192,188,4,0,32,0,100,109,95,48,55,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,106,22,64,42,4,0,32,0,100,109,95,49,54,46,49,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,3,92,248,32,4,0,32,0,100,109,95,49,53,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,75,20,38,132,4,0,32,0,100,109,95,50,52,46,57,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,97,141,8,218,4,0,32,0,100,109,95,50,51,46,57,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,240,29,225,23,4,0,32,0,100,109,95,50,56,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,28,186,135,241,4,0,32,0,100,109,95,50,55,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,120,156,247,41,4,0,32,0,100,109,95,51,55,46,49,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,229,246,146,54,3,0,16,0,98,51,51,45,119,119,46,105,99,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,66,46,201,245,2,0,16,1,98,51,51,45,120,120,46,105,99,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,250,209,193,231,2,0,16,1,98,51,51,45,121,121,46,105,99,51,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,45,47,82,22,6,0,16,1,98,51,51,45,122,122,46,105,99,51,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,51,30,116,214,6,0,16,1,98,51,51,45,51,48,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,52,98,116,216,9,0,16,1,98,51,51,45,48,50,46,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,162,59,251,246,11,0,32,0,98,51,51,45,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,153,5,180,44,17,0,32,0,98,51,51,45,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,234,158,223,189,17,0,32,0,98,51,51,45,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,162,102,248,141,17,0,32,0,98,51,51,45,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,217,54,108,79,17,0,32,0,98,51,51,45,48,49,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,232,43,31,241,22,0,32,0,98,51,51,45,48,55,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,31,30,21,23,0,32,0,98,51,51,45,48,57,46,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,36,103,30,24,0,64,0,98,51,51,45,49,48,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,171,3,206,233,24,0,64,0,98,51,51,45,48,56,46,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,200,196,161,202,25,0,64,0,98,49,52,45,51,48,46,57,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,127,12,203,220,0,0,0,8,98,49,52,45,51,49,46,53,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,61,1,107,92,0,0,0,8,98,51,51,45,49,55,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,244,143,125,123,0,0,0,8,98,51,51,45,49,56,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,48,31,248,251,0,0,0,8,14,0,0,0,255,255,255,0,0,0,0,0,15,0,0,0,255,255,223,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,14,0,0,0,1,1,1,0,120,97,1,0,14,0,0,0,1,1,0,0,80,46,8,0,0,0,0,0,254,0,2,0,232,75,4,0,14,0,0,0,1,4,4,0,96,135,7,0,14,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,14,0,0,0,1,8,0,0,96,135,7,0,14,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,14,0,0,0,1,48,16,0,104,236,7,0,14,0,0,0,1,48,48,0,128,230,7,0,14,0,0,0,1,48,0,0,120,211,6,0,14,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,14,0,0,0,1,192,64,0,104,236,7,0,14,0,0,0,1,192,192,0,128,230,7,0,14,0,0,0,1,192,0,0,120,211,6,0,14,0,0,0,1,192,128,0,184,164,6,0,0,0,0,0,254,0,4,0,248,150,6,0,15,0,0,0,1,3,2,0,80,246,3,0,15,0,0,0,1,3,3,0,248,38,7,0,15,0,0,0,1,3,1,0,112,212,3,0,15,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,200,147,6,0,15,0,0,0,1,12,8,0,80,246,3,0,15,0,0,0,1,12,12,0,248,38,7,0,15,0,0,0,1,12,4,0,112,212,3,0,15,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,2,0,56,107,4,0,15,0,0,0,1,16,16,0,64,96,7,0,15,0,0,0,1,16,0,0,192,89,7,0,0,0,0,0,254,0,2,0,0,241,6,0,15,0,0,0,1,32,0,0,96,135,7,0,15,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,98,51,51,45,49,57,46,105,99,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,200,96,83,184,2,0,16,1,98,51,51,45,50,48,46,105,99,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,139,55,136,159,2,0,16,1,98,51,51,45,50,49,45,50,46,105,99,51,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,227,249,35,39,6,0,16,1,98,51,51,45,50,50,45,50,46,105,99,51,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,77,96,141,218,6,0,16,1,98,51,51,45,51,48,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,52,98,116,216,9,0,16,1,98,51,51,45,48,50,46,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,162,59,251,246,11,0,32,0,98,51,51,45,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,153,5,180,44,17,0,32,0,98,51,51,45,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,234,158,223,189,17,0,32,0,98,51,51,45,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,162,102,248,141,17,0,32,0,98,51,51,45,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,217,54,108,79,17,0,32,0,98,51,51,45,48,49,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,232,43,31,241,22,0,32,0,98,51,51,45,48,55,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,31,30,21,23,0,32,0,98,51,51,45,48,57,46,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,36,103,30,24,0,64,0,98,51,51,45,49,48,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,171,3,206,233,24,0,64,0,98,51,51,45,48,56,46,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,200,196,161,202,25,0,64,0,98,49,52,45,51,48,46,57,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,127,12,203,220,0,0,0,8,98,49,52,45,51,49,46,53,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,61,1,107,92,0,0,0,8,98,51,51,45,49,55,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,244,143,125,123,0,0,0,8,98,51,51,45,49,56,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,48,31,248,251,0,0,0,8,14,0,0,0,255,255,255,0,0,0,0,0,15,0,0,0,255,255,223,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,14,0,0,0,1,1,1,0,120,97,1,0,14,0,0,0,1,1,0,0,80,46,8,0,0,0,0,0,254,0,2,0,232,75,4,0,14,0,0,0,1,4,4,0,96,135,7,0,14,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,14,0,0,0,1,8,0,0,96,135,7,0,14,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,14,0,0,0,1,48,16,0,104,236,7,0,14,0,0,0,1,48,48,0,128,230,7,0,14,0,0,0,1,48,0,0,120,211,6,0,14,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,14,0,0,0,1,192,64,0,104,236,7,0,14,0,0,0,1,192,192,0,128,230,7,0,14,0,0,0,1,192,0,0,120,211,6,0,14,0,0,0,1,192,128,0,184,164,6,0,0,0,0,0,254,0,4,0,248,150,6,0,15,0,0,0,1,3,2,0,80,246,3,0,15,0,0,0,1,3,3,0,248,38,7,0,15,0,0,0,1,3,1,0,112,212,3,0,15,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,200,147,6,0,15,0,0,0,1,12,8,0,80,246,3,0,15,0,0,0,1,12,12,0,248,38,7,0,15,0,0,0,1,12,4,0,112,212,3,0,15,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,2,0,56,107,4,0,15,0,0,0,1,16,16,0,64,96,7,0,15,0,0,0,1,16,0,0,192,89,7,0,101,112,114,45,49,51,55,56,51,46,97,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,175,213,161,226,1,0,16,1,101,112,114,45,49,51,55,57,54,46,97,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,103,28,0,6,1,0,16,1,101,112,114,45,49,51,55,56,53,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,98,71,113,9,1,0,16,1,101,112,114,45,49,51,55,57,55,46,97,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,159,222,26,54,1,0,16,1,109,112,114,45,49,51,55,55,51,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,229,0,198,63,2,0,32,0,109,112,114,45,49,51,55,55,52,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,36,168,17,36,2,0,32,0,109,112,114,45,49,51,55,55,53,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,123,82,207,2,0,32,0,109,112,114,45,49,51,55,55,57,46,99,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,22,244,7,199,3,0,32,0,109,112,114,45,49,51,55,56,55,46,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,198,104,92,240,3,0,32,0,109,112,114,45,49,51,55,56,48,46,99,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,224,65,195,164,3,0,32,0,109,112,114,45,49,51,55,56,56,46,97,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,166,254,6,1,3,0,32,0,109,112,114,45,49,51,55,56,49,46,99,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,175,19,59,243,3,0,32,0,109,112,114,45,49,51,55,56,57,46,97,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,53,136,186,9,3,0,32,0,101,112,114,45,49,51,55,56,50,46,99,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,82,8,121,115,3,0,32,0,101,112,114,45,49,51,55,57,48,46,97,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,1,145,132,35,3,0,32,0,101,112,114,45,49,51,55,55,56,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,70,97,232,53,4,0,16,1,101,112,114,45,49,51,55,55,55,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,130,71,82,209,19,0,64,0,101,112,114,45,49,51,55,55,54,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,254,201,42,40,19,0,64,0,51,49,55,45,48,49,55,53,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,131,210,217,112,5,0,16,1,184,40,2,0,1,0,0,0,40,39,216,0,248,191,2,0,240,167,7,0,1,0,0,0,44,39,216,0,192,135,2,0,176,163,7,0,1,0,0,0,47,39,216,0,240,108,2,0,208,158,7,0,1,0,0,0,42,39,216,0,96,82,2,0,184,154,7,0,1,0,0,0,43,39,216,0,32,56,2,0,176,108,2,0,1,0,0,0,32,39,216,0,152,30,2,0,8,96,7,0,1,0,0,0,41,39,216,0,72,198,1,0,48,89,7,0,1,0,0,0,37,39,216,0,24,182,1,0,16,83,7,0,1,0,0,0,34,39,216,0,40,167,1,0,96,79,7,0,1,0,0,0,35,39,216,0,200,149,1,0,48,76,7,0,1,0,0,0,33,39,216,0,56,126,1,0,88,212,3,0,1,0,0,0,48,38,216,0,40,185,3,0,248,5,8,0,9,0,0,0,112,39,216,0,32,58,1,0,144,250,7,0,9,0,0,0,113,39,216,0,32,58,1,0,248,241,7,0,9,0,0,0,114,39,216,0,32,58,1,0,168,86,7,0,1,0,0,0,246,237,146,0,248,191,2,0,24,38,7,0,1,0,0,0,82,242,146,0,184,160,2,0,56,210,6,0,1,0,0,0,120,250,146,0,192,135,2,0,24,163,6,0,1,0,0,0,121,250,146,0,240,108,2,0,152,122,6,0,1,0,0,0,122,250,146,0,96,82,2,0,192,72,6,0,1,0,0,0,123,250,146,0,32,56,2,0,200,110,3,0,1,0,0,0,124,250,146,0,152,30,2,0,120,89,3,0,1,0,0,0,125,250,146,0,232,10,2,0,120,74,3,0,1,0,0,0,126,250,146,0,152,138,8,0,40,246,1,0,1,0,0,0,245,237,146,0,64,246,1,0,144,236,1,0,1,0,0,0,83,242,146,0,136,224,1,0,176,223,1,0,1,0,0,0,128,250,146,0,72,198,1,0,192,209,1,0,1,0,0,0,129,250,146,0,24,182,1,0,24,198,1,0,1,0,0,0,130,250,146,0,40,167,1,0,120,189,1,0,1,0,0,0,131,250,146,0,200,149,1,0,224,22,1,0,1,0,0,0,132,250,146,0,56,126,1,0,160,14,1,0,1,0,0,0,133,250,146,0,32,101,1,0,176,9,1,0,1,0,0,0,134,250,146,0,96,32,8,0,88,212,3,0,1,0,0,0,96,215,146,0,40,185,3,0,16,17,8,0,1,0,0,0,247,237,146,0,224,12,8,0,72,65,1,0,9,0,0,0,24,94,147,0,32,58,1,0,48,50,1,0,9,0,0,0,25,94,147,0,32,58,1,0,99,109,95,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,143,17,106,69,1,0,16,1,99,109,95,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,68,44,107,20,1,0,16,1,99,109,95,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,69,201,225,115,1,0,16,1,99,109,95,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,161,255,60,146,2,0,16,1,99,109,95,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,195,124,106,71,4,0,32,0,99,109,95,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,95,43,223,179,4,0,32,0,99,104,101,99,107,109,97,110,46,99,108,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,87,80,164,87,7,0,32,0,17,0,0,0,255,255,0,0,0,0,0,0,18,0,0,0,255,255,0,0,0,0,0,0,19,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,32,4,2,0,18,0,0,0,1,64,64,0,144,147,2,0,18,0,0,0,1,64,0,0,200,209,1,0,0,0,0,0,254,0,2,0,200,30,2,0,18,0,0,0,1,128,0,0,120,97,1,0,18,0,0,0,1,128,128,0,96,19,1,0,0,0,0,0,254,0,4,0,128,129,4,0,19,0,0,0,1,3,0,0,8,49,4,0,19,0,0,0,1,3,1,0,152,21,4,0,19,0,0,0,1,3,2,0,72,246,3,0,19,0,0,0,1,3,3,0,72,0,3,0,0,0,0,0,254,0,2,0,64,37,5,0,19,0,0,0,1,4,0,0,160,191,4,0,19,0,0,0,1,4,4,0,240,159,4,0,0,0,0,0,254,0,2,0,80,159,1,0,19,0,0,0,1,8,8,0,8,49,4,0,19,0,0,0,1,8,0,0,72,246,3,0,184,40,2,0,1,0,0,0,138,151,215,0,248,191,2,0,56,250,6,0,1,0,0,0,131,151,215,0,184,160,2,0,184,164,8,0,1,0,0,0,139,151,215,0,64,246,1,0,240,190,7,0,4,0,0,0,104,150,215,0,208,13,4,0,32,201,5,0,1,0,0,0,141,151,215,0,152,30,2,0,208,240,5,0,1,0,0,0,133,151,215,0,232,10,2,0,208,26,7,0,1,0,0,0,128,151,215,0,152,138,8,0,32,160,5,0,1,0,0,0,132,151,215,0,48,119,7,0,88,212,3,0,1,0,0,0,200,147,215,0,40,185,3,0,16,17,8,0,1,0,0,0,140,151,215,0,224,12,8,0,56,58,1,0,1,0,0,0,129,151,215,0,64,50,1,0,248,5,8,0,9,0,0,0,152,151,215,0,32,58,1,0,144,250,7,0,9,0,0,0,153,151,215,0,32,58,1,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,0,0,0,0,2,0,0,0,4,0,0,0,6,0,0,0,0,0,0,0,0,0,4,0,0,0,2,0,0,0,6,0,168,86,7,0,1,0,0,0,0,242,146,0,248,191,2,0,24,38,7,0,1,0,0,0,47,250,146,0,184,160,2,0,56,210,6,0,1,0,0,0,40,250,146,0,192,135,2,0,24,163,6,0,1,0,0,0,41,250,146,0,240,108,2,0,152,122,6,0,1,0,0,0,42,250,146,0,96,82,2,0,192,72,6,0,1,0,0,0,43,250,146,0,32,56,2,0,200,110,3,0,1,0,0,0,44,250,146,0,152,30,2,0,120,89,3,0,1,0,0,0,45,250,146,0,232,10,2,0,120,74,3,0,1,0,0,0,46,250,146,0,152,138,8,0,40,246,1,0,1,0,0,0,1,242,146,0,64,246,1,0,144,236,1,0,1,0,0,0,55,250,146,0,136,224,1,0,176,223,1,0,1,0,0,0,48,250,146,0,72,198,1,0,192,209,1,0,1,0,0,0,49,250,146,0,24,182,1,0,24,198,1,0,1,0,0,0,50,250,146,0,40,167,1,0,120,189,1,0,1,0,0,0,51,250,146,0,200,149,1,0,224,22,1,0,1,0,0,0,52,250,146,0,56,126,1,0,160,14,1,0,1,0,0,0,53,250,146,0,32,101,1,0,176,9,1,0,1,0,0,0,54,250,146,0,96,32,8,0,88,212,3,0,1,0,0,0,56,215,146,0,40,185,3,0,72,65,1,0,9,0,0,0,72,3,147,0,32,58,1,0,48,50,1,0,9,0,0,0,73,3,147,0,32,58,1,0,99,99,117,95,50,51,98,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,253,68,218,3,2,0,16,1,99,99,117,95,50,50,99,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,160,130,155,2,0,16,1,99,99,117,95,50,52,98,46,57,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,178,153,255,132,1,0,16,1,99,99,117,95,50,56,98,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,35,194,206,251,1,0,16,1,99,99,45,53,109,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,186,216,97,114,4,0,32,0,99,99,45,55,109,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,73,249,96,106,4,0,32,0,99,99,45,49,109,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,2,115,99,0,4,0,32,0,99,99,45,51,109,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,207,135,204,4,0,32,0,99,99,45,54,109,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,237,139,113,40,4,0,32,0,99,99,45,56,109,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,58,197,172,212,4,0,32,0,99,99,45,50,109,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,81,241,105,12,4,0,32,0,99,99,45,52,109,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,151,187,158,31,4,0,32,0,99,99,117,95,48,57,46,49,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,88,139,142,105,3,0,16,0,99,99,117,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,219,194,226,109,5,0,64,0,99,99,117,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,174,145,144,185,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,99,99,54,51,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,249,240,232,202,0,0,0,8,105,111,98,49,46,49,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,99,99,112,114,103,49,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,196,37,194,225,0,0,0,8,105,111,99,49,46,105,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,129,32,24,13,0,0,0,8,99,54,51,50,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,112,146,189,15,0,0,0,8,99,99,106,95,50,51,102,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,98,43,72,91,2,0,16,1,99,99,106,95,50,50,102,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,149,65,211,15,2,0,16,1,99,99,106,95,50,52,102,46,57,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,37,79,121,58,1,0,16,1,99,99,106,95,50,56,102,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,6,41,60,252,1,0,16,1,99,99,95,48,49,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,186,216,97,114,4,0,32,0,99,99,95,48,50,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,73,249,96,106,4,0,32,0,99,99,95,48,51,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,2,115,99,0,4,0,32,0,99,99,95,48,52,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,207,135,204,4,0,32,0,99,99,95,48,53,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,237,139,113,40,4,0,32,0,99,99,95,48,54,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,58,197,172,212,4,0,32,0,99,99,95,48,55,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,81,241,105,12,4,0,32,0,99,99,95,48,56,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,151,187,158,31,4,0,32,0,99,99,106,95,48,57,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,88,139,142,105,3,0,16,0,99,99,106,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,219,194,226,109,5,0,64,0,99,99,106,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,174,145,144,185,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,99,99,54,51,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,249,240,232,202,0,0,0,8,105,111,98,49,46,49,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,99,99,112,114,103,49,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,196,37,194,225,0,0,0,8,105,111,99,49,46,105,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,129,32,24,13,0,0,0,8,99,54,51,50,98,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,112,146,189,15,0,0,0,8,50,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,122,237,113,203,1,0,16,1,50,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,135,46,203,71,1,0,16,1,50,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,121,66,121,121,1,0,16,1,50,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,186,119,16,176,1,0,16,1,99,57,49,101,45,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,28,7,99,248,4,0,32,0,99,57,49,101,45,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,8,195,3,75,4,0,32,0,99,57,49,101,45,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,150,234,131,51,4,0,32,0,99,57,49,101,45,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,207,244,225,184,4,0,32,0,108,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,88,139,142,105,3,0,16,0,99,57,49,101,45,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,251,21,97,9,5,0,64,0,99,51,56,45,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,32,17,224,42,2,0,16,1,99,51,56,45,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,86,255,216,72,2,0,16,1,99,51,56,45,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,115,136,247,127,9,0,16,1,99,51,56,45,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,54,255,112,193,15,0,32,0,99,51,56,45,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,167,89,250,89,24,0,64,0,99,51,56,45,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,75,113,17,26,28,0,32,0,99,51,56,45,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,160,45,23,190,2,0,16,1,99,51,56,45,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,100,97,173,102,2,0,16,1,99,51,56,45,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,172,250,96,14,9,0,16,1,99,51,56,45,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,54,255,112,193,15,0,32,0,99,51,56,45,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,75,113,17,26,28,0,32,0,99,51,56,45,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,187,48,211,83,29,0,64,0,184,40,2,0,1,0,0,0,47,39,216,0,248,191,2,0,184,164,8,0,1,0,0,0,46,39,216,0,64,246,1,0,56,210,6,0,1,0,0,0,42,39,216,0,192,135,2,0,24,163,6,0,1,0,0,0,43,39,216,0,240,108,2,0,152,122,6,0,1,0,0,0,45,39,216,0,96,82,2,0,192,72,6,0,1,0,0,0,44,39,216,0,32,56,2,0,48,123,2,0,1,0,0,0,24,39,216,0,152,30,2,0,176,223,1,0,1,0,0,0,34,39,216,0,72,198,1,0,192,209,1,0,1,0,0,0,35,39,216,0,24,182,1,0,24,198,1,0,1,0,0,0,37,39,216,0,40,167,1,0,120,189,1,0,1,0,0,0,36,39,216,0,200,149,1,0,248,187,8,0,1,0,0,0,40,39,216,0,56,126,1,0,88,212,3,0,1,0,0,0,48,38,216,0,40,185,3,0,248,5,8,0,9,0,0,0,112,39,216,0,32,58,1,0,144,250,7,0,9,0,0,0,113,39,216,0,32,58,1,0,248,241,7,0,9,0,0,0,114,39,216,0,32,58,1,0,5,1,0,0,0,0,0,0,66,0,0,48,0,0,0,0,19,0,0,4,0,0,0,0,0,0,48,96,0,0,0,0,5,64,4,0,0,0,0,0,53,0,3,0,0,0,0,0,18,2,0,6,0,0,0,0,34,33,2,3,0,0,0,0,0,3,48,3,0,0,0,0,0,51,48,3,0,0,0,0,0,51,52,0,0,0,0,0,2,36,34,2,0,0,0,0,68,48,0,0,0,0,0,0,36,5,3,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,6,0,0,0,0,0,0,0,64,1,80,0,4,0,2,0,2,1,80,0,4,0,8,0,0,48,0,0,0,0,5,0,64,33,80,0,0,0,16,0,4,2,0,0,0,0,34,2,32,0,0,0,0,0,0,0,36,3,0,0,0,0,33,2,18,2,0,0,0,0,34,2,2,0,0,0,0,0,34,2,68,0,0,0,0,0,2,32,82,0,0,0,0,0,17,18,101,0,0,0,0,0,2,0,18,0,0,0,0,0,2,49,3,0,0,0,0,0,32,50,16,0,0,0,0,0,34,49,18,0,0,0,0,0,16,2,32,0,0,0,0,0,49,34,2,0,0,0,0,0,0,6,0,0,0,0,0,0,0,0,8,0,0,0,0,0,32,3,2,2,0,0,0,0,51,32,0,16,0,0,0,0,2,32,18,0,0,0,0,0,48,0,2,17,0,0,0,0,98,99,45,48,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,241,126,101,107,0,0,16,1,49,50,46,117,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,168,59,48,135,0,0,16,1,49,46,117,49,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,195,248,101,235,0,0,16,1,55,46,117,50,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,23,197,227,149,0,0,32,0,56,46,117,49,56,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,171,119,35,254,0,0,32,0,51,46,117,49,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,95,67,220,22,0,0,32,0,52,46,117,56,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,151,191,227,79,0,0,32,0,54,46,117,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,127,239,138,7,0,0,32,0,53,46,117,55,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,144,250,80,246,0,0,32,0,57,46,117,52,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,251,136,97,12,0,0,32,0,49,48,46,117,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,248,63,56,45,0,0,32,0,50,46,117,55,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,172,29,238,54,0,0,64,0,112,114,111,109,49,46,117,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,94,131,36,195,0,0,32,0,112,114,111,109,52,46,117,55,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,244,110,80,230,0,0,32,0,112,114,111,109,51,46,117,56,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,79,9,61,180,0,0,32,0,112,114,111,109,50,46,117,57,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,105,136,170,224,0,0,32,0,17,0,0,0,255,255,244,0,0,0,0,0,18,0,0,0,255,255,255,0,0,0,0,0,19,0,0,0,255,255,127,0,0,0,0,0,0,0,0,0,254,0,2,0,232,75,4,0,17,0,0,0,1,244,244,0,96,135,7,0,17,0,0,0,1,244,0,0,152,182,7,0,0,0,0,0,254,0,12,0,200,87,7,0,18,0,0,0,1,15,4,0,144,102,8,0,18,0,0,0,1,15,7,0,176,45,8,0,18,0,0,0,1,15,0,0,144,55,5,0,18,0,0,0,1,15,10,0,224,127,8,0,18,0,0,0,1,15,6,0,136,252,1,0,18,0,0,0,1,15,3,0,0,67,1,0,18,0,0,0,1,15,15,0,32,123,8,0,18,0,0,0,1,15,5,0,120,205,1,0,18,0,0,0,1,15,14,0,192,110,8,0,18,0,0,0,1,15,13,0,96,102,7,0,18,0,0,0,1,15,12,0,184,105,6,0,18,0,0,0,1,15,11,0,152,96,3,0,0,0,0,0,254,0,12,0,160,123,6,0,18,0,0,0,1,240,64,0,144,102,8,0,18,0,0,0,1,240,112,0,176,45,8,0,18,0,0,0,1,240,0,0,144,55,5,0,18,0,0,0,1,240,160,0,224,127,8,0,18,0,0,0,1,240,96,0,136,252,1,0,18,0,0,0,1,240,48,0,0,67,1,0,18,0,0,0,1,240,240,0,32,123,8,0,18,0,0,0,1,240,80,0,120,205,1,0,18,0,0,0,1,240,224,0,192,110,8,0,18,0,0,0,1,240,208,0,96,102,7,0,18,0,0,0,1,240,192,0,184,105,6,0,18,0,0,0,1,240,176,0,152,96,3,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,1,1,0,96,135,7,0,19,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,19,0,0,0,1,6,6,0,208,75,4,0,19,0,0,0,1,6,4,0,8,49,4,0,19,0,0,0,1,6,2,0,152,21,4,0,19,0,0,0,1,6,0,0,72,246,3,0,0,0,0,0,254,0,4,0,72,202,5,0,19,0,0,0,1,24,24,0,248,38,7,0,19,0,0,0,1,24,8,0,80,124,6,0,19,0,0,0,1,24,16,0,112,212,3,0,19,0,0,0,1,24,0,0,216,13,3,0,0,0,0,0,254,0,2,0,200,30,2,0,19,0,0,0,1,32,32,0,120,97,1,0,19,0,0,0,1,32,0,0,96,19,1,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,64,0,0,96,135,7,0,19,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,19,0,0,0,1,128,128,0,96,135,7,0,19,0,0,0,1,128,0,0,152,182,7,0,99,51,52,95,55,57,46,57,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,147,46,63,188,2,0,16,1,99,51,52,95,55,55,46,55,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,208,22,121,145,2,0,16,1,99,51,52,95,55,56,46,57,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,128,200,252,242,2,0,16,1,99,51,52,95,55,54,46,55,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,192,250,151,222,2,0,16,1,99,51,52,95,56,50,46,49,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,153,250,105,104,6,0,16,1,99,51,52,95,56,48,46,49,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,180,62,120,225,6,0,16,1,99,51,52,95,56,51,46,49,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,100,179,192,238,6,0,16,1,99,51,52,95,56,49,46,49,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,207,107,206,35,6,0,16,1,99,51,52,95,48,53,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,218,131,107,89,11,0,32,0,99,51,52,95,48,52,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,218,176,70,36,17,0,32,0,99,51,52,95,48,51,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,120,171,142,161,17,0,32,0,99,51,52,95,48,50,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,16,186,136,132,17,0,32,0,99,51,52,95,48,49,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,99,140,190,62,17,0,32,0,99,51,52,95,48,55,46,52,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,8,120,176,237,22,0,32,0,99,51,52,95,48,54,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,235,182,0,210,23,0,32,0,99,51,52,95,48,56,46,49])
.concat([50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,80,4,163,137,24,0,64,0,99,51,52,95,48,57,46,49,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,80,43,209,57,25,0,64,0,99,51,52,95,49,56,46,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,246,166,69,114,0,0,0,8,99,51,52,95,49,57,46,55,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,4,196,233,46,0,0,0,8,99,51,52,95,50,48,46,56,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,48,31,248,251,0,0,0,8,99,51,52,95,50,49,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,83,136,114,16,0,0,0,8,99,51,52,95,50,50,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,252,139,62,100,0,0,0,8,13,0,0,0,255,255,255,0,0,0,0,0,14,0,0,0,255,255,247,0,0,0,0,0,0,0,0,0,254,0,2,0,144,95,6,0,13,0,0,0,1,1,1,0,96,135,7,0,13,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,13,0,0,0,1,4,4,0,96,135,7,0,13,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,13,0,0,0,1,8,0,0,96,135,7,0,13,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,13,0,0,0,1,48,16,0,104,236,7,0,13,0,0,0,1,48,48,0,128,230,7,0,13,0,0,0,1,48,0,0,120,211,6,0,13,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,13,0,0,0,1,192,64,0,104,236,7,0,13,0,0,0,1,192,192,0,128,230,7,0,13,0,0,0,1,192,0,0,120,211,6,0,13,0,0,0,1,192,128,0,184,164,6,0,0,0,0,0,254,0,4,0,72,202,5,0,14,0,0,0,1,3,2,0,80,246,3,0,14,0,0,0,1,3,3,0,248,38,7,0,14,0,0,0,1,3,1,0,112,212,3,0,14,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,120,89,6,0,14,0,0,0,1,12,12,0,248,81,6,0,14,0,0,0,1,12,8,0,80,124,6,0,14,0,0,0,1,12,4,0,176,64,8,0,14,0,0,0,1,12,0,0,128,65,6,0,0,0,0,0,102,110,45,49,53,45,49,46,49,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,248,32,239,211,0,0,16,1,102,110,45,49,50,45,49,46,57,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,69,11,161,244,0,0,16,1,102,110,45,49,54,45,46,49,57,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,165,6,24,253,0,0,16,1,102,110,45,49,51,45,46,49,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,129,54,77,210,0,0,16,1,102,110,45,49,55,45,46,50,48,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,55,138,212,40,0,0,16,1,102,110,45,49,52,45,46,49,51,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,130,198,97,140,0,0,16,1,102,110,45,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,231,6,65,199,0,0,16,1,102,110,45,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,96,167,245,64,0,0,32,0,102,110,45,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,104,33,79,130,0,0,32,0,102,110,45,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,179,163,198,234,0,0,32,0,102,110,45,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,146,226,238,63,0,0,32,0,102,110,45,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,210,123,178,194,0,0,32,0,102,110,45,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,120,113,201,90,0,0,32,0,102,110,45,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,27,18,51,147,0,0,32,0,102,110,45,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,15,166,75,37,0,0,32,0,102,110,45,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,152,208,24,236,0,0,32,0,102,110,45,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,186,12,6,79,0,0,32,0,102,110,45,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,217,216,15,153,0,0,64,0,116,97,45,49,54,46,50,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,212,232,38,173,0,0,0,8,168,86,7,0,1,0,0,0,0,241,146,0,248,191,2,0,24,38,7,0,1,0,0,0,224,1,147,0,184,160,2,0,56,210,6,0,1,0,0,0,225,1,147,0,192,135,2,0,24,163,6,0,1,0,0,0,226,1,147,0,240,108,2,0,152,122,6,0,1,0,0,0,227,1,147,0,96,82,2,0,192,72,6,0,1,0,0,0,228,1,147,0,32,56,2,0,200,110,3,0,1,0,0,0,229,1,147,0,152,30,2,0,120,89,3,0,1,0,0,0,230,1,147,0,232,10,2,0,40,246,1,0,1,0,0,0,1,241,146,0,64,246,1,0,144,236,1,0,1,0,0,0,32,249,146,0,136,224,1,0,176,223,1,0,1,0,0,0,33,249,146,0,72,198,1,0,192,209,1,0,1,0,0,0,34,249,146,0,24,182,1,0,24,198,1,0,1,0,0,0,35,249,146,0,40,167,1,0,120,189,1,0,1,0,0,0,36,249,146,0,200,149,1,0,224,22,1,0,1,0,0,0,37,249,146,0,56,126,1,0,160,14,1,0,1,0,0,0,38,249,146,0,32,101,1,0,88,212,3,0,1,0,0,0,88,221,146,0,40,185,3,0,16,17,8,0,1,0,0,0,2,241,146,0,224,12,8,0,72,65,1,0,9,0,0,0,32,7,147,0,32,58,1,0,48,50,1,0,9,0,0,0,33,7,147,0,32,58,1,0,224,41,1,0,9,0,0,0,34,7,147,0,32,58,1,0,0,0,0,0,254,0,2,0,144,123,3,0,21,0,0,0,1,128,128,0,144,100,3,0,21,0,0,0,1,128,0,0,240,83,3,0,0,0,0,0,184,40,2,0,1,0,0,0,122,83,148,0,248,191,2,0,56,250,6,0,1,0,0,0,120,83,148,0,184,160,2,0,184,164,8,0,1,0,0,0,123,83,148,0,64,246,1,0,88,149,7,0,1,0,0,0,121,83,148,0,136,224,1,0,56,210,6,0,1,0,0,0,136,83,148,0,192,135,2,0,24,163,6,0,1,0,0,0,137,83,148,0,240,108,2,0,152,122,6,0,1,0,0,0,138,83,148,0,96,82,2,0,192,72,6,0,1,0,0,0,139,83,148,0,32,56,2,0,48,123,2,0,1,0,0,0,140,83,148,0,152,30,2,0,96,69,2,0,1,0,0,0,141,83,148,0,232,10,2,0,176,223,1,0,1,0,0,0,128,83,148,0,72,198,1,0,192,209,1,0,1,0,0,0,129,83,148,0,24,182,1,0,24,198,1,0,1,0,0,0,130,83,148,0,40,167,1,0,120,189,1,0,1,0,0,0,131,83,148,0,200,149,1,0,248,187,8,0,1,0,0,0,132,83,148,0,56,126,1,0,184,179,8,0,1,0,0,0,133,83,148,0,32,101,1,0,88,212,3,0,1,0,0,0,192,228,148,0,40,185,3,0,16,17,8,0,1,0,0,0,126,83,148,0,224,12,8,0,80,251,6,0,1,0,0,0,124,83,148,0,216,70,1,0,56,58,1,0,1,0,0,0,125,83,148,0,64,50,1,0,248,5,8,0,9,0,0,0,16,71,215,0,32,58,1,0,57,46,49,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,187,163,89,75,0,0,16,1,49,50,46,49,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,106,80,50,10,0,0,16,1,49,51,46,49,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,197,197,74,150,0,0,16,1,51,46,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,193,218,225,84,0,0,32,0,52,46,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,171,40,228,5,0,0,32,0,53,46,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,154,242,130,242,0,0,32,0,49,52,46,55,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,141,133,28,16,0,0,32,0,49,53,46,55,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,242,88,63,1,0,0,32,0,49,54,46,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,151,64,105,148,0,0,32,0,54,46,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,137,189,238,81,0,0,32,0,55,46,49,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,157,142,217,157,0,0,32,0,56,46,49,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,125,238,85,49,0,0,32,0,50,46,53,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,88,97,121,222,0,0,32,0,49,46,54,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,125,145,7,132,0,0,64,1,168,86,7,0,1,0,0,0,104,241,146,0,248,191,2,0,24,38,7,0,1,0,0,0,79,2,147,0,184,160,2,0,56,210,6,0,1,0,0,0,74,2,147,0,192,135,2,0,24,163,6,0,1,0,0,0,75,2,147,0,240,108,2,0,152,122,6,0,1,0,0,0,72,2,147,0,96,82,2,0,192,72,6,0,1,0,0,0,73,2,147,0,32,56,2,0,200,110,3,0,1,0,0,0,76,2,147,0,152,30,2,0,120,89,3,0,1,0,0,0,77,2,147,0,232,10,2,0,120,74,3,0,1,0,0,0,78,2,147,0,152,138,8,0,40,246,1,0,1,0,0,0,105,241,146,0,64,246,1,0,144,236,1,0,1,0,0,0,143,249,146,0,136,224,1,0,176,223,1,0,1,0,0,0,138,249,146,0,72,198,1,0,192,209,1,0,1,0,0,0,139,249,146,0,24,182,1,0,24,198,1,0,1,0,0,0,136,249,146,0,40,167,1,0,120,189,1,0,1,0,0,0,137,249,146,0,200,149,1,0,224,22,1,0,1,0,0,0,140,249,146,0,56,126,1,0,160,14,1,0,1,0,0,0,141,249,146,0,32,101,1,0,176,9,1,0,1,0,0,0,142,249,146,0,96,32,8,0,88,212,3,0,1,0,0,0,176,221,146,0,40,185,3,0,16,17,8,0,1,0,0,0,106,241,146,0,224,12,8,0,72,65,1,0,9,0,0,0,96,7,147,0,32,58,1,0,48,50,1,0,9,0,0,0,97,7,147,0,32,58,1,0,224,41,1,0,9,0,0,0,98,7,147,0,32,58,1,0,184,40,2,0,1,0,0,0,40,39,216,0,248,191,2,0,56,250,6,0,1,0,0,0,32,39,216,0,184,160,2,0,88,149,7,0,1,0,0,0,33,39,216,0,136,224,1,0,208,158,7,0,1,0,0,0,42,39,216,0,96,82,2,0,184,154,7,0,1,0,0,0,43,39,216,0,32,56,2,0,176,108,2,0,1,0,0,0,44,39,216,0,152,30,2,0,16,83,7,0,1,0,0,0,34,39,216,0,40,167,1,0,96,79,7,0,1,0,0,0,35,39,216,0,200,149,1,0,48,76,7,0,1,0,0,0,36,39,216,0,56,126,1,0,88,212,3,0,1,0,0,0,48,38,216,0,40,185,3,0,248,5,8,0,9,0,0,0,112,39,216,0,32,58,1,0,144,250,7,0,9,0,0,0,113,39,216,0,32,58,1,0,248,241,7,0,9,0,0,0,114,39,216,0,32,58,1,0,184,40,2,0,1,0,0,0,143,83,148,0,248,191,2,0,56,250,6,0,1,0,0,0,142,83,148,0,184,160,2,0,184,164,8,0,1,0,0,0,135,83,148,0,64,246,1,0,88,149,7,0,1,0,0,0,134,83,148,0,136,224,1,0,56,210,6,0,1,0,0,0,136,83,148,0,192,135,2,0,24,163,6,0,1,0,0,0,137,83,148,0,240,108,2,0,152,122,6,0,1,0,0,0,138,83,148,0,96,82,2,0,192,72,6,0,1,0,0,0,139,83,148,0,32,56,2,0,48,123,2,0,1,0,0,0,140,83,148,0,152,30,2,0,96,69,2,0,1,0,0,0,141,83,148,0,232,10,2,0,176,223,1,0,1,0,0,0,128,83,148,0,72,198,1,0,192,209,1,0,1,0,0,0,129,83,148,0,24,182,1,0,24,198,1,0,1,0,0,0,130,83,148,0,40,167,1,0,120,189,1,0,1,0,0,0,131,83,148,0,200,149,1,0,248,187,8,0,1,0,0,0,132,83,148,0,56,126,1,0,184,179,8,0,1,0,0,0,133,83,148,0,32,101,1,0,88,212,3,0,1,0,0,0,192,228,148,0,40,185,3,0,16,17,8,0,1,0,0,0,127,83,148,0,224,12,8,0,80,251,6,0,1,0,0,0,125,83,148,0,216,70,1,0,56,58,1,0,1,0,0,0,126,83,148,0,64,50,1,0,248,5,8,0,9,0,0,0,16,71,215,0,32,58,1,0,144,250,7,0,9,0,0,0,17,71,215,0,32,58,1,0,184,40,2,0,1,0,0,0,204,233,148,0,248,191,2,0,56,250,6,0,1,0,0,0,15,233,148,0,184,160,2,0,184,164,8,0,1,0,0,0,205,233,148,0,64,246,1,0,88,149,7,0,1,0,0,0,87,232,148,0,136,224,1,0,56,210,6,0,1,0,0,0,8,233,148,0,192,135,2,0,24,163,6,0,1,0,0,0,9,233,148,0,240,108,2,0,152,122,6,0,1,0,0,0,10,233,148,0,96,82,2,0,192,72,6,0,1,0,0,0,11,233,148,0,32,56,2,0,48,123,2,0,1,0,0,0,12,233,148,0,152,30,2,0,176,223,1,0,1,0,0,0,80,232,148,0,72,198,1,0,192,209,1,0,1,0,0,0,81,232,148,0,24,182,1,0,24,198,1,0,1,0,0,0,82,232,148,0,40,167,1,0,120,189,1,0,1,0,0,0,83,232,148,0,200,149,1,0,248,187,8,0,1,0,0,0,84,232,148,0,56,126,1,0,88,212,3,0,1,0,0,0,136,218,146,0,40,185,3,0,248,5,8,0,9,0,0,0,96,94,147,0,32,58,1,0,144,250,7,0,9,0,0,0,97,94,147,0,32,58,1,0,98,119,49,48,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,235,180,188,230,0,0,16,1,98,119,49,48,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,178,111,5,56,0,0,16,1,98,119,48,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,96,114,146,188,0,0,32,0,98,119,48,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,101,84,63,34,0,0,32,0,98,119,51,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,122,115,88,178,0,0,32,0,98,119,48,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,45,183,180,251,0,0,32,0,98,119,48,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,77,195,0,83,0,0,32,0,98,119,48,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,47,47,175,154,0,0,32,0,98,119,48,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,67,109,219,22,0,0,32,0,98,119,48,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,176,160,81,17,0,0,32,0,98,119,48,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,31,93,163,115,0,0,32,0,98,119,48,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,194,223,71,244,0,0,32,0,98,119,48,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,135,92,248,151,0,0,32,0,98,119,48,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,37,130,164,176,0,0,32,0,98,119,48,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,157,134,254,216,0,0,64,0,22,0,0,0,255,255,255,0,0,0,0,0,23,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,40,134,8,0,22,0,0,0,1,1,1,0,248,38,7,0,22,0,0,0,1,1,0,0,32,158,6,0,0,0,0,0,254,0,8,0,72,27,7,0,22,0,0,0,1,28,28,0,128,230,7,0,22,0,0,0,1,28,24,0,168,126,7,0,22,0,0,0,1,28,20,0,8,15,7,0,22,0,0,0,1,28,16,0,104,9,7,0,22,0,0,0,1,28,12,0,104,236,7,0,22,0,0,0,1,28,8,0,184,252,6,0,22,0,0,0,1,28,4,0,16,242,7,0,22,0,0,0,1,28,0,0,80,252,6,0,0,0,0,0,254,0,8,0,136,241,6,0,22,0,0,0,1,224,224,0,128,230,7,0,22,0,0,0,1,224,192,0,168,126,7,0,22,0,0,0,1,224,160,0,8,15,7,0,22,0,0,0,1,224,128,0,104,9,7,0,22,0,0,0,1,224,96,0,104,236,7,0,22,0,0,0,1,224,64,0,184,252,6,0,22,0,0,0,1,224,32,0,192,234,2,0,22,0,0,0,1,224,0,0,32,242,5,0,0,0,0,0,254,0,4,0,32,232,6,0,23,0,0,0,1,3,3,0,136,128,8,0,23,0,0,0,1,3,2,0,80,246,3,0,23,0,0,0,1,3,1,0,48,123,8,0,23,0,0,0,1,3,0,0,8,117,8,0,0,0,0,0,254,0,4,0,232,119,7,0,23,0,0,0,1,12,12,0,208,75,4,0,23,0,0,0,1,12,8,0,8,49,4,0,23,0,0,0,1,12,4,0,72,246,3,0,23,0,0,0,1,12,0,0,192,255,2,0,0,0,0,0,254,0,4,0,40,213,6,0,23,0,0,0,1,48,48,0,168,22,4,0,23,0,0,0,1,48,32,0,152,140,1,0,23,0,0,0,1,48,16,0,120,201,6,0,23,0,0,0,1,48,0,0,56,198,6,0,0,0,0,0,254,0,2,0,16,115,7,0,23,0,0,0,1,64,0,0,96,135,7,0,23,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,56,195,6,0,23,0,0,0,1,128,128,0,96,212,3,0,23,0,0,0,1,128,0,0,232,184,6,0,101,112,114,45,49,50,52,53,55,46,97,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,85,98,114,188,1,0,16,1,101,112,114,45,49,50,52,53,53,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,235,34,167,182,1,0,16,1,101,112,114,45,49,50,52,53,56,46,97,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,106,71,199,231,1,0,16,1,101,112,114,45,49,50,52,53,54,46,97,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,175,46,220,37,1,0,16,1,111,112,114,45,49,50,52,54,50,46,97,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,181,67,153,161,2,0,32,0,111,112,114,45,49,50,52,54,51,46,97,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,13,32,248,98,2,0,32,0,111,112,114,45,49,50,52,54,52,46,97,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,3,151,197,200,2,0,32,0,109,112,114,45,49,50,52,54,53,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,69,27,214,17,3,0,32,0,109,112,114,45,49,50,52,54,55,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,192,228,180,195,3,0,32,0,109,112,114,45,49,50,52,54,54,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,111,35,127,165,3,0,32,0,109,112,114,45,49,50,52,54,56,46,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,222,119,156,216,3,0,32,0,101,112,114,45,49,50,52,53,57,46,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,208,41,29,62,4,0,16,1,109,112,114,45,49,50,52,54,48,46,97,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,13,87,174,11,8,0,64,0,109,112,114,45,49,50,52,54,49,46,97,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,70,139,59,176,8,0,64,0,51,49,55,45,48,49,49,53,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,20,86,165,117,5,0,16,1,98,114,46,97,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,75,66,198,145,1,0,16,1,98,114,46,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,243,75,149,118,1,0,16,1,98,114,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,131,209,111,157,1,0,16,1,98,114,46,97,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,210,227,161,92,1,0,16,1,98,114,46,97,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,76,173,151,237,1,0,16,1,98,114,46,97,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,5,41,54,13,1,0,16,1,111,112,114,45,49,50,52,54,50,46,97,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,181,67,153,161,2,0,32,0,111,112,114,45,49,50,52,54,51,46,97,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,13,32,248,98,2,0,32,0,111,112,114,45,49,50,52,54,52,46,97,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,3,151,197,200,2,0,32,0,98,114,95,111,98,106,48,111,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,130,94,138,9,3,0,32,0,98,114,95,111,98,106,48,101,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,249,138,35,133,3,0,32,0,98,114,95,111,98,106,49,111,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,161,29,100,204,3,0,32,0,98,114,95,111,98,106,49,101,46,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,21,51,18,211,3,0,32,0,98,114,95,111,98,106,50,111,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,31,172,239,132,3,0,32,0,98,114,95,111,98,106,50,101,46,98,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,203,18,59,183,3,0,32,0,98,114,95,111,98,106,51,111,46,98,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,172,56,226,162,3,0,32,0,98,114,46,98,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,255,120,222,216,3,0,32,0,115,111,117,110,100,46,97,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,4,0,16,16,115,111,117,110,100,46,97,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,8,0,64,16,115,111,117,110,100,46,97,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,8,0,64,16,115,111,117,110,100,46,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,8,0,64,16,115,111,117,110,100,46,97,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,8,0,64,16,184,40,2,0,1,0,0,0,40,39,216,0,248,191,2,0,56,250,6,0,1,0,0,0,32,39,216,0,184,160,2,0,184,164,8,0,1,0,0,0,41,39,216,0,64,246,1,0,88,149,7,0,1,0,0,0,33,39,216,0,136,224,1,0,208,158,7,0,1,0,0,0,42,39,216,0,96,82,2,0,184,154,7,0,1,0,0,0,43,39,216,0,32,56,2,0,176,108,2,0,1,0,0,0,44,39,216,0,152,30,2,0,128,98,2,0,1,0,0,0,47,39,216,0,232,10,2,0,16,83,7,0,1,0,0,0,34,39,216,0,40,167,1,0,96,79,7,0,1,0,0,0,35,39,216,0,200,149,1,0,48,76,7,0,1,0,0,0,36,39,216,0,56,126,1,0,144,72,7,0,1,0,0,0,46,39,216,0,32,101,1,0,88,212,3,0,1,0,0,0,48,38,216,0,40,185,3,0,248,5,8,0,9,0,0,0,112,39,216,0,32,58,1,0,144,250,7,0,9,0,0,0,113,39,216,0,32,58,1,0,248,241,7,0,9,0,0,0,114,39,216,0,32,58,1,0,0,0,0,0,8,0,0,0,16,0,0,0,24,0,0,0,32,0,0,0,40,0,0,0,48,0,0,0,56,0,0,0,128,0,0,0,136,0,0,0,144,0,0,0,152,0,0,0,160,0,0,0,168,0,0,0,176,0,0,0,184,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,64,0,0,0,65,0,0,0,66,0,0,0,67,0,0,0,68,0,0,0,69,0,0,0,70,0,0,0,71,0,0,0,1,0,0,0,0,0,0,0,9,0,0,0,8,0,0,0,17,0,0,0,16,0,0,0,25,0,0,0,24,0,0,0,33,0,0,0,32,0,0,0,41,0,0,0,40,0,0,0,49,0,0,0,48,0,0,0,57,0,0,0,56,0,0,0,65,0,0,0,64,0,0,0,73,0,0,0,72,0,0,0,81,0,0,0,80,0,0,0,89,0,0,0,88,0,0,0,97,0,0,0,96,0,0,0,105,0,0,0,104,0,0,0,113,0,0,0,112,0,0,0,121,0,0,0,120,0,0,0,184,40,2,0,1,0,0,0,44,39,216,0,248,191,2,0,56,250,6,0,1,0,0,0,32,39,216,0,184,160,2,0,88,149,7,0,1,0,0,0,33,39,216,0,136,224,1,0,240,167,7,0,1,0,0,0,41,39,216,0,192,135,2,0,176,163,7,0,1,0,0,0,40,39,216,0,240,108,2,0,208,158,7,0,1,0,0,0,43,39,216,0,96,82,2,0,184,154,7,0,1,0,0,0,42,39,216,0,32,56,2,0,176,108,2,0,1,0,0,0,45,39,216,0,152,30,2,0,8,96,7,0,1,0,0,0,35,39,216,0,72,198,1,0,48,89,7,0,1,0,0,0,34,39,216,0,24,182,1,0,16,83,7,0,1,0,0,0,37,39,216,0,40,167,1,0,96,79,7,0,1,0,0,0,36,39,216,0,200,149,1,0,48,76,7,0,1,0,0,0,46,39,216,0,56,126,1,0,88,212,3,0,1,0,0,0,48,38,216,0,40,185,3,0,248,5,8,0,9,0,0,0,112,39,216,0,32,58,1,0,144,250,7,0,9,0,0,0,113,39,216,0,32,58,1,0,248,241,7,0,9,0,0,0,114,39,216,0,32,58,1,0,72,82,8,0,9,0,0,0,80,39,216,0,32,58,1,0,168,86,7,0,1,0,0,0,20,1,147,0,248,191,2,0,24,38,7,0,1,0,0,0,18,1,147,0,184,160,2,0,200,110,3,0,1,0,0,0,17,1,147,0,152,30,2,0,120,89,3,0,1,0,0,0,16,1,147,0,232,10,2,0,8,3,3,0,4,0,0,0,192,218,148,0,208,13,4,0,248,230,7,0,4,0,0,0,176,218,148,0,184,198,5,0,112,176,5,0,1,0,0,0,96,135,215,0,152,138,8,0,64,111,5,0,1,0,0,0,97,135,215,0,48,119,7,0,88,212,3,0,1,0,0,0,88,220,146,0,40,185,3,0,16,17,8,0,1,0,0,0,23,1,147,0,224,12,8,0,184,40,2,0,1,0,0,0,207,155,215,0,248,191,2,0,56,250,6,0,1,0,0,0,214,155,215,0,184,160,2,0,184,164,8,0,1,0,0,0,215,155,215,0,64,246,1,0,88,149,7,0,1,0,0,0,206,155,215,0,136,224,1,0,56,210,6,0,1,0,0,0,208,155,215,0,192,135,2,0,24,163,6,0,1,0,0,0,209,155,215,0,240,108,2,0,152,122,6,0,1,0,0,0,210,155,215,0,96,82,2,0,192,72,6,0,1,0,0,0,211,155,215,0,32,56,2,0,48,123,2,0,1,0,0,0,212,155,215,0,152,30,2,0,96,69,2,0,1,0,0,0,213,155,215,0,232,10,2,0,176,223,1,0,1,0,0,0,200,155,215,0,72,198,1,0,192,209,1,0,1,0,0,0,201,155,215,0,24,182,1,0,24,198,1,0,1,0,0,0,202,155,215,0,40,167,1,0,120,189,1,0,1,0,0,0,203,155,215,0,200,149,1,0,248,187,8,0,1,0,0,0,204,155,215,0,56,126,1,0,184,179,8,0,1,0,0,0,205,155,215,0,32,101,1,0,88,212,3,0,1,0,0,0,200,154,215,0,40,185,3,0,248,5,8,0,9,0,0,0,0,156,215,0,32,58,1,0,144,250,7,0,9,0,0,0,1,156,215,0,32,58,1,0,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,81,35,97,43,1,0,16,1,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,233,112,201,177,1,0,16,1,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,62,120,195,99,1,0,16,1,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,52,207,247,69,1,0,16,1,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,107,185,53,243,1,0,16,1,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,213,248,11,165,1,0,16,1,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,205,90,205,85,4,0,32,0,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,184,115,231,114,4,0,32,0,115,110,55,52,115,50,56,56,110,46,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,135,125,12,106,7,0,32,0,15,0,0,0,255,255,0,0,0,0,0,0,16,0,0,0,255,255,128,0,0,0,0,0,17,0,0,0,255,255,12,0,0,0,0,0,0,0,0,0,254,0,2,0,200,87,7,0,16,0,0,0,1,64,64,0,224,127,8,0,16,0,0,0,1,64,0,0,32,123,8,0,0,0,0,0,254,0,2,0,160,123,6,0,16,0,0,0,1,128,128,0,0,90,2,0,16,0,0,0,1,128,0,0,104,61,2,0,0,0,0,0,254,0,2,0,72,202,5,0,17,0,0,0,1,2,0,0,80,246,3,0,17,0,0,0,1,2,2,0,112,212,3,0,0,0,0,0,254,0,2,0,128,129,4,0,17,0,0,0,1,4,4,0,8,49,4,0,17,0,0,0,1,4,0,0,72,246,3,0,0,0,0,0,254,0,2,0,200,30,2,0,17,0,0,0,1,8,8,0,120,97,1,0,17,0,0,0,1,8,0,0,96,19,1,0,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,137,128,52,173,1,0,16,1,114,111,109,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,209,5,167,202,1,0,16,1,114,111,109,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,29,100,32,228,1,0,16,1,114,111,109,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,144,45,121,4,1,0,16,1,50,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,52,207,247,69,1,0,16,1,114,111,109,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,75,189,151,178,1,0,16,1,114,111,109,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,213,248,11,165,1,0,16,1,114,111,109,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,132,201,197,210,1,0,16,1,111,116,49,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,240,151,210,188,2,0,16,1,111,116,50,46,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,218,18,121,222,2,0,16,1,111,116,51,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,51,169,47,186,2,0,16,1,114,111,109,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,205,90,205,85,4,0,32,0,114,111,109,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,184,115,231,114,4,0,32,0,99,48,49,115,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,171,174,60,78,7,0,32,0,168,86,7,0,1,0,0,0,241,0,147,0,248,191,2,0,24,163,6,0,1,0,0,0,81,248,146,0,240,108,2,0,152,122,6,0,1,0,0,0,83,248,146,0,96,82,2,0,192,72,6,0,1,0,0,0,82,248,146,0,32,56,2,0,40,171,4,0,1,0,0,0,80,248,146,0,152,30,2,0,40,246,1,0,1,0,0,0,240,0,147,0,64,246,1,0,192,209,1,0,1,0,0,0,85,248,146,0,24,182,1,0,24,198,1,0,1,0,0,0,87,248,146,0,40,167,1,0,120,189,1,0,1,0,0,0,86,248,146,0,200,149,1,0,40,143,3,0,1,0,0,0,84,248,146,0,56,126,1,0,88,212,3,0,1,0,0,0,56,220,146,0,40,185,3,0,248,66,3,0,9,0,0,0,88,6,147,0,32,58,1,0,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,47,189,147,227,1,0,16,1,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,175,67,212,183,1,0,16,1,50,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,164,128,115,230,1,0,16,1,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,55,123,175,114,1,0,16,1,50,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,127,221,176,230,1,0,16,1,115,111,117,110,100,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,83,119,238,84,2,0,16,1,115,111,117,110,100,46,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,192,254,24,82,2,0,16,1,99,112,117,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,209,164,61,138,4,0,32,0,99,112,117,46,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,19,177,189,133,4,0,32,0,56,50,115,49,50,51,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,13,249,135,155,7,0,32,0,184,40,2,0,1,0,0,0,41,39,216,0,248,191,2,0,56,250,6,0,1,0,0,0,32,39,216,0,184,160,2,0,88,149,7,0,1,0,0,0,33,39,216,0,136,224,1,0,240,167,7,0,1,0,0,0,47,39,216,0,192,135,2,0,176,163,7,0,1,0,0,0,34,39,216,0,240,108,2,0,208,158,7,0,1,0,0,0,42,39,216,0,96,82,2,0,184,154,7,0,1,0,0,0,43,39,216,0,32,56,2,0,176,108,2,0,1,0,0,0,44,39,216,0,152,30,2,0,128,98,2,0,1,0,0,0,46,39,216,0,232,10,2,0,88,212,3,0,1,0,0,0,48,38,216,0,40,185,3,0,16,17,8,0,1,0,0,0,40,39,216,0,224,12,8,0,248,5,8,0,9,0,0,0,112,39,216,0,32,58,1,0,144,250,7,0,9,0,0,0,113,39,216,0,32,58,1,0,248,241,7,0,9,0,0,0,114,39,216,0,32,58,1,0,72,82,8,0,9,0,0,0,115,39,216,0,32,58,1,0,168,86,7,0,1,0,0,0,80,1,147,0,248,191,2,0,24,38,7,0,1,0,0,0,137,240,146,0,184,160,2,0,56,210,6,0,1,0,0,0,114,237,146,0,192,135,2,0,24,163,6,0,1,0,0,0,115,237,146,0,240,108,2,0,152,122,6,0,1,0,0,0,113,237,146,0,96,82,2,0,192,72,6,0,1,0,0,0,112,237,146,0,32,56,2,0,200,110,3,0,1,0,0,0,128,236,146,0,152,30,2,0,40,246,1,0,1,0,0,0,81,1,147,0,64,246,1,0,144,236,1,0,1,0,0,0,138,240,146,0,136,224,1,0,176,223,1,0,1,0,0,0,10,236,146,0,72,198,1,0,192,209,1,0,1,0,0,0,11,236,146,0,24,182,1,0,24,198,1,0,1,0,0,0,9,236,146,0,40,167,1,0,120,189,1,0,1,0,0,0,8,236,146,0,200,149,1,0,224,22,1,0,1,0,0,0,224,235,146,0,56,126,1,0,88,212,3,0,1,0,0,0,192,220,146,0,40,185,3,0,16,17,8,0,1,0,0,0,139,240,146,0,224,12,8,0,72,65,1,0,9,0,0,0,168,6,147,0,32,58,1,0,48,50,1,0,9,0,0,0,169,6,147,0,32,58,1,0,98,55,55,45,50,50,46,105,99,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,222,13,64,103,2,0,16,1,98,55,55,45,50,53,46,105,99,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,255,57,74,186,2,0,16,1,98,55,55,45,50,52,46,105,99,54,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,237,67,230,149,6,0,16,1,98,55,55,45,50,51,46,105,99,54,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,28,125,90,57,6,0,16,1,98,55,55,45,50,48,46,105,99,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,183,84,186,132,9,0,16,1,98,55,55,45,48,53,46,105,99,49,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,255,240,56,114,11,0,32,0,98,55,55,45,48,52,46,105,99,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,108,190,208,190,17,0,32,0,98,55,55,45,48,51,46,105,99,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,167,48,48,154,17,0,32,0,98,55,55,45,48,50,46,105,99,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,46,13,234,218,17,0,32,0,98,55,55,45,48,49,46,105,99,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,13,0,171,205,17,0,32,0,98,55,55,45,48,55,46,105,99,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,94,252,177,125,22,0,32,0,98,55,55,45,48,54,46,105,99,51,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,237,42,206,23,0,32,0,98,55,55,45,48,57,46,105,99,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,217,90,142,148,24,0,64,0,98,55,55,45,48,56,46,105,99,53,55,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,133,148,155,17,25,0,64,0,98,55,55,45,49,55,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,48,31,248,251,0,0,0,8,98,55,55,45,49,56,46,105,99,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,244,143,125,123,0,0,0,8,98,55,55,45,50,50,46,105,99,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,222,13,64,103,2,0,16,1,98,55,55,45,50,49,46,105,99,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,69,104,67,35,2,0,16,1,98,55,55,45,50,52,46,105,99,54,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,237,67,230,149,6,0,16,1,98,55,55,45,50,51,46,105,99,54,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,28,125,90,57,6,0,16,1,98,55,55,45,50,48,46,105,99,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,183,84,186,132,9,0,16,1,98,55,55,45,48,53,46,105,99,49,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,255,240,56,114,11,0,32,0,98,55,55,45,48,52,46,105,99,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,108,190,208,190,17,0,32,0,98,55,55,45,48,51,46,105,99,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,167,48,48,154,17,0,32,0,98,55,55,45,48,50,46,105,99,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,46,13,234,218,17,0,32,0,98,55,55,45,48,49,46,105,99,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,13,0,171,205,17,0,32,0,98,55,55,45,48,55,46,105,99,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,94,252,177,125,22,0,32,0,98,55,55,45,48,54,46,105,99,51,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,237,42,206,23,0,32,0,98,55,55,45,48,57,46,105,99,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,217,90,142,148,24,0,64,0,98,55,55,45,48,56,46,105,99,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,133,148,155,17,25,0,64,0,98,55,55,45,49,55,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,48,31,248,251,0,0,0,8,98,55,55,45,49,56,46,105,99,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,244,143,125,123,0,0,0,8,14,0,0,0,255,255,127,0,0,0,0,0,15,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,14,0,0,0,1,128,128,0,80,46,8,0,14,0,0,0,1,128,0,0,120,97,1,0,0,0,0,0,254,0,2,0,232,75,4,0,14,0,0,0,1,32,32,0,96,135,7,0,14,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,14,0,0,0,1,16,0,0,96,135,7,0,14,0,0,0,1,16,16,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,14,0,0,0,1,12,8,0,104,236,7,0,14,0,0,0,1,12,12,0,128,230,7,0,14,0,0,0,1,12,0,0,120,211,6,0,14,0,0,0,1,12,4,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,14,0,0,0,1,3,2,0,104,236,7,0,14,0,0,0,1,3,3,0,128,230,7,0,14,0,0,0,1,3,0,0,120,211,6,0,14,0,0,0,1,3,1,0,184,164,6,0,0,0,0,0,254,0,4,0,72,202,5,0,15,0,0,0,1,192,64,0,80,246,3,0,15,0,0,0,1,192,192,0,248,38,7,0,15,0,0,0,1,192,128,0,112,212,3,0,15,0,0,0,1,192,0,0,248,160,5,0,0,0,0,0,254,0,4,0,64,37,5,0,15,0,0,0,1,48,0,0,152,53,6,0,15,0,0,0,1,48,48,0,8,49,6,0,15,0,0,0,1,48,16,0,184,43,6,0,15,0,0,0,1,48,32,0,160,191,4,0,0,0,0,0,254,0,4,0,128,129,4,0,15,0,0,0,1,12,8,0,192,255,2,0,15,0,0,0,1,12,4,0,208,75,4,0,15,0,0,0,1,12,12,0,8,49,4,0,15,0,0,0,1,12,0,0,72,246,3,0,112,114,103,95,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,168,147,167,43,1,0,16,1,112,114,103,95,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,245,138,121,122,1,0,16,1,114,97,52,45,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,79,11,48,135,2,0,16,1,114,97,52,45,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,254,95,78,175,2,0,16,1,103,102,120,95,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,177,36,40,30,4,0,32,0,103,102,120,95,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,179,25,67,120,4,0,32,0,99,111,108,114,54,102,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,199,51,227,252,7,0,32,0,15,0,0,0,255,255,0,0,0,0,0,0,16,0,0,0,255,255,2,0,0,0,0,0,17,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,32,4,2,0,15,0,0,0,1,2,0,0,184,146,2,0,15,0,0,0,1,2,2,0,144,147,2,0,0,0,0,0,254,0,4,0,128,129,4,0,15,0,0,0,1,12,0,0,8,49,4,0,15,0,0,0,1,12,4,0,152,21,4,0,15,0,0,0,1,12,8,0,72,246,3,0,15,0,0,0,1,12,12,0,72,0,3,0,0,0,0,0,254,0,2,0,200,30,2,0,16,0,0,0,1,1,0,0,120,97,1,0,16,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,2,0,168,234,7,0,16,0,0,0,1,2,0,0,96,135,7,0,16,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,0,0,0,80,65,83,69,75,73,83,85,71,69,82,0,0,0,64,75,14,84,65,68,85,78,79,14,14,0,0,0,48,78,65,65,75,69,75,68,85,78,79,0,0,0,32,14,14,73,75,85,84,69,78,14,14,0,0,0,16,75,14,75,65,83,69,66,79,14,65,249,78,0,0,46,99,0,0,249,78,0,0,194,128,0,0,0,97,101,112,114,45,49,49,56,56,53,46,97,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,170,21,183,91,1,0,16,1,101,112,114,45,49,49,56,56,52,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,144,112,112,225,1,0,16,1,101,112,114,45,49,49,55,50,50,46,97,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,181,141,170,173,2,0,32,0,101,112,114,45,49,49,55,51,54,46,98,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,137,94,173,233,2,0,32,0,101,112,114,45,49,49,55,50,51,46,97,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,154,63,26,19,2,0,32,0,101,112,114,45,49,49,55,51,55,46,98,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,35,0,66,46,2,0,32,0,101,112,114,45,49,49,55,50,52,46,97,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,10,213,46,111,2,0,32,0,101,112,114,45,49,49,55,51,56,46,98,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,2,109,61,222,2,0,32,0,101,112,114,45,49,49,55,50,53,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,78,104,179,248,3,0,32,0,101,112,114,45,49,49,55,50,57,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,147,39,60,174,3,0,32,0,101,112,114,45,49,49,55,50,54,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,25,84,206,60,3,0,32,0,101,112,114,45,49,49,55,51,48,46,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,85,43,246,58,3,0,32,0,101,112,114,45,49,49,55,50,55,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,120,0,57,176,3,0,32,0,101,112,114,45,49,49,55,51,49,46,98,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,74,116,135,42,3,0,32,0,101,112,114,45,49,49,55,50,56,46,98,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,216,63,164,243,3,0,32,0,101,112,114,45,49,49,55,51,50,46,98,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,85,227,179,47,3,0,32,0,101,112,114,45,49,49,55,49,55,46,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,203,224,107,103,3,0,32,0,101,112,114,45,49,49,55,51,51,46,98,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,148,172,44,128,3,0,32,0,101,112,114,45,49,49,55,49,56,46,97,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,194,100,40,136,3,0,32,0,101,112,114,45,49,49,55,51,52,46,98,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,210,4,199,118,3,0,32,0,101,112,114,45,49,49,55,49,57,46,97,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,247,135,153,51,3,0,32,0,101,112,114,45,49,49,55,51,53,46,98,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,170,6,228,79,3,0,32,0,101,112,114,45,49,49,54,55,49,46,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,59,52,113,43,4,0,16,1,111,112,114,45,49,49,54,55,50,46,97,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,96,244,215,187,8,0,64,0,111,112,114,45,49,49,54,55,51,46,97,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,54,74,12,64,8,0,64,0,51,49,55,45,48,48,55,55,46,109,99,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,16,101,112,114,45,49,49,56,56,51,46,97,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,247,232,179,197,1,0,16,1,101,112,114,45,49,49,56,56,50,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,11,23,1,156,1,0,16,1,101,112,114,45,49,49,55,50,50,46,97,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,181,141,170,173,2,0,32,0,101,112,114,45,49,49,55,51,54,46,98,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,137,94,173,233,2,0,32,0,101,112,114,45,49,49,55,50,51,46,97,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,154,63,26,19,2,0,32,0,101,112,114,45,49,49,55,51,55,46,98,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,35,0,66,46,2,0,32,0,101,112,114,45,49,49,55,50,52,46,97,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,10,213,46,111,2,0,32,0,101,112,114,45,49,49,55,51,56,46,98,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,2,109,61,222,2,0,32,0,101,112,114,45,49,49,55,50,53,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,78,104,179,248,3,0,32,0,101,112,114,45,49,49,55,50,57,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,147,39,60,174,3,0,32,0,101,112,114,45,49,49,55,50,54,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,25,84,206,60,3,0,32,0,101,112,114,45,49,49,55,51,48,46,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,85,43,246,58,3,0,32,0,101,112,114,45,49,49,55,50,55,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,120,0,57,176,3,0,32,0,101,112,114,45,49,49,55,51,49,46,98,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,74,116,135,42,3,0,32,0,101,112,114,45,49,49,55,50,56,46,98,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,216,63,164,243,3,0,32,0,101,112,114,45,49,49,55,51,50,46,98,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,85,227,179,47,3,0,32,0,101,112,114,45,49,49,55,49,55,46,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,203,224,107,103,3,0,32,0,101,112,114,45,49,49,55,51,51,46,98,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,148,172,44,128,3,0,32,0,101,112,114,45,49,49,55,49,56,46,97,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,194,100,40,136,3,0,32,0,101,112,114,45,49,49,55,51,52,46,98,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,210,4,199,118,3,0,32,0,101,112,114,45,49,49,55,49,57,46,97,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,247,135,153,51,3,0,32,0,101,112,114,45,49,49,55,51,53,46,98,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,170,6,228,79,3,0,32,0,101,112,114,45,49,49,54,55,49,46,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,59,52,113,43,4,0,16,1,111,112,114,45,49,49,54,55,50,46,97,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,96,244,215,187,8,0,64,0,111,112,114,45,49,49,54,55,51,46,97,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,54,74,12,64,8,0,64,0,51,49,55,45,48,48,55,54,46,109,99,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,16,101,112,114,45,49,49,55,52,50,46,97,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,52,149,131,97,1,0,16,1,101,112,114,45,49,49,55,52,49,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,203,89,33,155,1,0,16,1,101,112,114,45,49,49,55,50,50,46,97,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,181,141,170,173,2,0,32,0,101,112,114,45,49,49,55,51,54,46,98,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,137,94,173,233,2,0,32,0,101,112,114,45,49,49,55,50,51,46,97,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,154,63,26,19,2,0,32,0,101,112,114,45,49,49,55,51,55,46,98,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,35,0,66,46,2,0,32,0,101,112,114,45,49,49,55,50,52,46,97,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,10,213,46,111,2,0,32,0,101,112,114,45,49,49,55,51])
.concat([56,46,98,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,2,109,61,222,2,0,32,0,101,112,114,45,49,49,55,50,53,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,78,104,179,248,3,0,32,0,101,112,114,45,49,49,55,50,57,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,147,39,60,174,3,0,32,0,101,112,114,45,49,49,55,50,54,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,25,84,206,60,3,0,32,0,101,112,114,45,49,49,55,51,48,46,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,85,43,246,58,3,0,32,0,101,112,114,45,49,49,55,50,55,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,120,0,57,176,3,0,32,0,101,112,114,45,49,49,55,51,49,46,98,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,74,116,135,42,3,0,32,0,101,112,114,45,49,49,55,50,56,46,98,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,216,63,164,243,3,0,32,0,101,112,114,45,49,49,55,51,50,46,98,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,85,227,179,47,3,0,32,0,101,112,114,45,49,49,55,49,55,46,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,203,224,107,103,3,0,32,0,101,112,114,45,49,49,55,51,51,46,98,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,148,172,44,128,3,0,32,0,101,112,114,45,49,49,55,49,56,46,97,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,194,100,40,136,3,0,32,0,101,112,114,45,49,49,55,51,52,46,98,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,210,4,199,118,3,0,32,0,101,112,114,45,49,49,55,49,57,46,97,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,247,135,153,51,3,0,32,0,101,112,114,45,49,49,55,51,53,46,98,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,170,6,228,79,3,0,32,0,101,112,114,45,49,49,54,55,49,46,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,59,52,113,43,4,0,16,1,111,112,114,45,49,49,54,55,50,46,97,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,96,244,215,187,8,0,64,0,111,112,114,45,49,49,54,55,51,46,97,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,54,74,12,64,8,0,64,0,51,49,55,45,48,48,54,57,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,106,37,158,149,5,0,16,1,101,112,114,45,49,49,55,52,48,46,97,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,66,117,34,206,1,0,16,1,101,112,114,45,49,49,55,51,57,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,101,235,102,228,1,0,16,1,101,112,114,45,49,49,55,50,50,46,97,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,181,141,170,173,2,0,32,0,101,112,114,45,49,49,55,51,54,46,98,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,137,94,173,233,2,0,32,0,101,112,114,45,49,49,55,50,51,46,97,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,154,63,26,19,2,0,32,0,101,112,114,45,49,49,55,51,55,46,98,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,35,0,66,46,2,0,32,0,101,112,114,45,49,49,55,50,52,46,97,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,10,213,46,111,2,0,32,0,101,112,114,45,49,49,55,51,56,46,98,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,2,109,61,222,2,0,32,0,101,112,114,45,49,49,55,50,53,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,78,104,179,248,3,0,32,0,101,112,114,45,49,49,55,50,57,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,147,39,60,174,3,0,32,0,101,112,114,45,49,49,55,50,54,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,25,84,206,60,3,0,32,0,101,112,114,45,49,49,55,51,48,46,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,85,43,246,58,3,0,32,0,101,112,114,45,49,49,55,50,55,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,120,0,57,176,3,0,32,0,101,112,114,45,49,49,55,51,49,46,98,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,74,116,135,42,3,0,32,0,101,112,114,45,49,49,55,50,56,46,98,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,216,63,164,243,3,0,32,0,101,112,114,45,49,49,55,51,50,46,98,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,85,227,179,47,3,0,32,0,101,112,114,45,49,49,55,49,55,46,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,203,224,107,103,3,0,32,0,101,112,114,45,49,49,55,51,51,46,98,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,148,172,44,128,3,0,32,0,101,112,114,45,49,49,55,49,56,46,97,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,194,100,40,136,3,0,32,0,101,112,114,45,49,49,55,51,52,46,98,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,210,4,199,118,3,0,32,0,101,112,114,45,49,49,55,49,57,46,97,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,247,135,153,51,3,0,32,0,101,112,114,45,49,49,55,51,53,46,98,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,170,6,228,79,3,0,32,0,101,112,114,45,49,49,54,56,54,46,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,179,69,138,130,4,0,16,1,111,112,114,45,49,49,54,55,50,46,97,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,96,244,215,187,8,0,64,0,111,112,114,45,49,49,54,55,51,46,97,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,54,74,12,64,8,0,64,0,51,49,55,45,48,48,54,54,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,84,160,133,237,5,0,16,1,101,112,114,45,49,49,55,48,53,46,97,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,122,92,220,87,1,0,16,1,101,112,114,45,49,49,55,48,52,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,7,207,187,51,1,0,16,1,111,112,114,45,49,49,54,55,52,46,97,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,213,102,122,165,2,0,32,0,111,112,114,45,49,49,54,55,53,46,97,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,68,241,242,46,2,0,32,0,111,112,114,45,49,49,54,55,54,46,97,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,172,172,4,12,2,0,32,0,101,112,114,45,49,49,54,55,55,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,205,37,20,160,3,0,32,0,101,112,114,45,49,49,54,56,49,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,99,51,224,217,3,0,32,0,101,112,114,45,49,49,54,55,56,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,83,252,169,23,3,0,32,0,101,112,114,45,49,49,54,56,50,46,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,94,124,247,227,3,0,32,0,101,112,114,45,49,49,54,55,57,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,69,194,220,20,3,0,32,0,101,112,114,45,49,49,54,56,51,46,98,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,6,15,166,249,3,0,32,0,101,112,114,45,49,49,54,56,48,46,98,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,236,205,61,244,3,0,32,0,101,112,114,45,49,49,54,56,52,46,98,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,219,14,12,178,3,0,32,0,101,112,114,45,49,49,54,56,54,46,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,179,69,138,130,4,0,16,1,111,112,114,45,49,49,54,55,50,46,97,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,96,244,215,187,8,0,64,0,111,112,114,45,49,49,54,55,51,46,97,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,54,74,12,64,8,0,64,0,51,49,55,45,48,48,54,54,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,84,160,133,237,5,0,16,1,101,112,114,45,49,48,55,50,48,97,46,97,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,147,8,146,27,1,0,16,1,101,112,114,45,49,48,55,49,55,97,46,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,88,227,42,151,1,0,16,1,101,112,114,45,49,48,55,50,49,97,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,195,209,210,244,1,0,16,1,101,112,114,45,49,48,55,49,56,97,46,97,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,27,246,155,199,1,0,16,1,101,112,114,45,49,48,55,50,50,97,46,97,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,170,144,7,29,1,0,16,1,101,112,114,45,49,48,55,49,57,97,46,97,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,183,134,117,30,1,0,16,1,101,112,114,45,49,48,55,48,50,46,98,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,19,200,59,57,2,0,32,0,101,112,114,45,49,48,55,48,51,46,98,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,245,217,109,107,2,0,32,0,101,112,114,45,49,48,55,48,52,46,98,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,188,126,30,145,2,0,32,0,101,112,114,45,49,48,55,48,57,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,144,10,223,173,3,0,32,0,101,112,114,45,49,48,55,49,51,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,58,222,236,236,3,0,32,0,101,112,114,45,49,48,55,49,48,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,235,105,35,153,3,0,32,0,101,112,114,45,49,48,55,49,52,46,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,251,66,191,145,3,0,32,0,101,112,114,45,49,48,55,49,49,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,246,110,22,41,3,0,32,0,101,112,114,45,49,48,55,49,53,46,98,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,132,115,197,167,3,0,32,0,101,112,114,45,49,48,55,49,50,46,98,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,25,208,106,135,3,0,32,0,101,112,114,45,49,48,55,49,54,46,98,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,72,29,186,64,3,0,32,0,101,112,114,45,49,48,55,50,51,46,97,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,38,53,149,153,4,0,16,1,101,112,114,45,49,48,55,50,52,46,97,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,23,168,113,249,8,0,64,0,101,112,114,45,49,48,55,50,53,46,97,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,143,224,80,106,8,0,64,0,101,112,114,45,49,48,55,50,54,46,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,54,119,11,213,8,0,64,0,51,49,55,45,48,48,51,51,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,229,130,232,73,5,0,16,1,17,0,0,0,255,255,253,0,0,0,0,0,18,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,168,234,7,0,17,0,0,0,1,2,2,0,96,135,7,0,17,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,17,0,0,0,1,12,8,0,208,75,4,0,17,0,0,0,1,12,12,0,8,49,4,0,17,0,0,0,1,12,4,0,152,21,4,0,17,0,0,0,1,12,0,0,176,77,2,0,0,0,0,0,254,0,4,0,216,238,6,0,17,0,0,0,1,48,0,0,120,148,5,0,17,0,0,0,1,48,16,0,232,146,5,0,17,0,0,0,1,48,32,0,96,143,5,0,17,0,0,0,1,48,48,0,128,140,5,0,0,0,0,0,254,0,4,0,72,202,5,0,17,0,0,0,1,192,128,0,80,246,3,0,17,0,0,0,1,192,192,0,248,38,7,0,17,0,0,0,1,192,64,0,112,212,3,0,17,0,0,0,1,192,0,0,248,160,5,0,0,0,0,0,254,0,16,0,200,87,7,0,18,0,0,0,1,15,7,0,80,252,6,0,18,0,0,0,1,15,8,0,16,242,7,0,18,0,0,0,1,15,9,0,104,236,7,0,18,0,0,0,1,15,5,0,176,51,4,0,18,0,0,0,1,15,4,0,56,24,4,0,18,0,0,0,1,15,15,0,128,230,7,0,18,0,0,0,1,15,1,0,72,216,3,0,18,0,0,0,1,15,2,0,24,188,3,0,18,0,0,0,1,15,3,0,176,162,3,0,18,0,0,0,1,15,6,0,120,211,6,0,18,0,0,0,1,15,14,0,184,164,6,0,18,0,0,0,1,15,13,0,80,74,6,0,18,0,0,0,1,15,12,0,192,32,6,0,18,0,0,0,1,15,11,0,192,234,2,0,18,0,0,0,1,15,10,0,32,242,5,0,18,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,18,0,0,0,1,240,112,0,80,252,6,0,18,0,0,0,1,240,128,0,16,242,7,0,18,0,0,0,1,240,144,0,104,236,7,0,18,0,0,0,1,240,80,0,176,51,4,0,18,0,0,0,1,240,64,0,56,24,4,0,18,0,0,0,1,240,240,0,128,230,7,0,18,0,0,0,1,240,16,0,72,216,3,0,18,0,0,0,1,240,32,0,24,188,3,0,18,0,0,0,1,240,48,0,176,162,3,0,18,0,0,0,1,240,96,0,120,211,6,0,18,0,0,0,1,240,224,0,184,164,6,0,18,0,0,0,1,240,208,0,80,74,6,0,18,0,0,0,1,240,192,0,192,32,6,0,18,0,0,0,1,240,176,0,192,234,2,0,18,0,0,0,1,240,160,0,32,242,5,0,18,0,0,0,1,240,0,0,208,236,2,0,101,112,114,45,49,49,48,56,51,46,97,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,179,217,42,203,1,0,16,1,101,112,114,45,49,49,48,56,48,46,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,217,120,115,254,1,0,16,1,101,112,114,45,49,49,48,56,52,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,177,199,30,46,1,0,16,1,101,112,114,45,49,49,48,56,49,46,97,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,99,238,8,19,1,0,16,1,101,112,114,45,49,49,48,56,53,46,97,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,57,143,247,207,1,0,16,1,101,112,114,45,49,49,48,56,50,46,97,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,20,42,220,156,1,0,16,1,101,112,114,45,49,48,55,48,50,46,98,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,19,200,59,57,2,0,32,0,101,112,114,45,49,48,55,48,51,46,98,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,245,217,109,107,2,0,32,0,101,112,114,45,49,48,55,48,52,46,98,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,188,126,30,145,2,0,32,0,101,112,114,45,49,48,55,48,57,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,144,10,223,173,3,0,32,0,101,112,114,45,49,48,55,49,51,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,58,222,236,236,3,0,32,0,101,112,114,45,49,48,55,49,48,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,235,105,35,153,3,0,32,0,101,112,114,45,49,48,55,49,52,46,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,251,66,191,145,3,0,32,0,101,112,114,45,49,48,55,49,49,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,246,110,22,41,3,0,32,0,101,112,114,45,49,48,55,49,53,46,98,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,132,115,197,167,3,0,32,0,101,112,114,45,49,48,55,49,50,46,98,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,25,208,106,135,3,0,32,0,101,112,114,45,49,48,55,49,54,46,98,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,72,29,186,64,3,0,32,0,101,112,114,45,49,49,48,56,54,46,97,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,40,220,253,199,4,0,16,1,101,112,114,45,49,48,55,50,52,46,97,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,23,168,113,249,8,0,64,0,101,112,114,45,49,48,55,50,53,46,97,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,143,224,80,106,8,0,64,0,101,112,114,45,49,48,55,50,54,46,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,54,119,11,213,8,0,64,0,51,49,55,45,48,48,120,120,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,205,112,179,118,5,0,16,1,101,112,114,45,49,48,56,48,52,46,52,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,131,139,247,35,1,0,16,1,101,112,114,45,49,48,56,48,50,46,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,189,104,103,153,1,0,16,1,101,112,114,45,49,48,56,48,53,46,52,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,80,254,215,83,1,0,16,1,101,112,114,45,49,48,56,48,51,46,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,51,221,54,5,1,0,16,1,101,112,114,45,49,48,55,51,50,46,52,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,252,43,113,197,1,0,16,1,101,112,114,45,49,48,55,50,57,46,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,48,14,82,62,1,0,16,1,101,112,114,45,49,48,55,51,57,46,57,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,7,194,158,162,2,0,32,0,101,112,114,45,49,48,55,52,48,46,57,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,21,48,249,71,2,0,32,0,101,112,114,45,49,48,55,52,49,46,57,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,156,115,112,73,2,0,32,0,101,112,114,45,49,48,55,48,57,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,144,10,223,173,3,0,32,0,101,112,114,45,49,48,55,49,51,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,58,222,236,236,3,0,32,0,101,112,114,45,49,48,55,49,48,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,235,105,35,153,3,0,32,0,101,112,114,45,49,48,55,49,52,46,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,251,66,191,145,3,0,32,0,101,112,114,45,49,48,55,49,49,46,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,246,110,22,41,3,0,32,0,101,112,114,45,49,48,55,49,53,46,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,132,115,197,167,3,0,32,0,101,112,114,45,49,48,55,49,50,46,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,25,208,106,135,3,0,32,0,101,112,114,45,49,48,55,49,54,46,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,72,29,186,64,3,0,32,0,101,112,114,45,49,48,55,48,53,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,158,116,123,119,4,0,16,1,55,55,53,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,252,52,149,106,6,0,16,1,101,112,114,45,49,48,55,48,54,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,204,74,17,170,7,0,64,0,101,112,114,45,49,48,55,48,55,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,130,29,12,128,7,0,64,0,101,112,114,45,49,48,55,48,56,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,82,239,33,89,7,0,64,0,51,49,55,45,48,48,51,55,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,229,130,232,73,5,0,16,1,101,112,114,45,49,48,56,49,54,46,97,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,4,83,191,23,1,0,16,1,101,112,114,45,49,48,56,49,52,46,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,223,52,209,76,1,0,16,1,101,112,114,45,49,48,56,49,55,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,176,145,183,200,1,0,16,1,101,112,114,45,49,48,56,49,53,46,97,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,48,74,207,189,1,0,16,1,101,112,114,45,49,48,56,50,50,97,46,97,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,170,144,7,29,1,0,16,1,101,112,114,45,49,48,56,49,57,97,46,97,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,183,134,117,30,1,0,16,1,101,112,114,45,49,48,55,48,50,46,98,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,19,200,59,57,2,0,32,0,101,112,114,45,49,48,55,48,51,46,98,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,245,217,109,107,2,0,32,0,101,112,114,45,49,48,55,48,52,46,98,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,188,126,30,145,2,0,32,0,101,112,114,45,49,48,55,48,57,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,144,10,223,173,3,0,32,0,101,112,114,45,49,48,55,49,51,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,58,222,236,236,3,0,32,0,101,112,114,45,49,48,55,49,48,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,235,105,35,153,3,0,32,0,101,112,114,45,49,48,55,49,52,46,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,251,66,191,145,3,0,32,0,101,112,114,45,49,48,55,49,49,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,246,110,22,41,3,0,32,0,101,112,114,45,49,48,55,49,53,46,98,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,132,115,197,167,3,0,32,0,101,112,114,45,49,48,55,49,50,46,98,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,25,208,106,135,3,0,32,0,101,112,114,45,49,48,55,49,54,46,98,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,72,29,186,64,3,0,32,0,101,112,114,45,49,48,55,50,51,46,97,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,38,53,149,153,4,0,16,1,101,112,114,45,49,48,55,50,52,46,97,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,23,168,113,249,8,0,64,0,101,112,114,45,49,48,55,50,53,46,97,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,143,224,80,106,8,0,64,0,101,112,114,45,49,48,55,50,54,46,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,54,119,11,213,8,0,64,0,51,49,55,45,48,48,51,51,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,229,130,232,73,5,0,16,1,101,112,114,45,49,48,56,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,159,146,105,230,1,0,16,1,101,112,114,45,49,48,56,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,221,143,127,159,1,0,16,1,101,112,114,45,49,48,56,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,25,73,66,154,1,0,16,1,101,112,114,45,49,48,56,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,48,53,44,61,1,0,16,1,101,112,114,45,49,48,55,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,81,23,23,146,1,0,16,1,101,112,114,45,49,48,54,57,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,192,253,228,193,1,0,16,1,49,48,55,51,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,7,194,158,162,2,0,32,0,49,48,55,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,21,48,249,71,2,0,32,0,49,48,55,52,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,156,115,112,73,2,0,32,0,49,48,55,48,57,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,144,10,223,173,3,0,32,0,49,48,55,49,51,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,58,222,236,236,3,0,32,0,49,48,55,49,48,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,235,105,35,153,3,0,32,0,49,48,55,49,52,46,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,251,66,191,145,3,0,32,0,49,48,55,49,49,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,246,110,22,41,3,0,32,0,49,48,55,49,53,46,98,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,132,115,197,167,3,0,32,0,49,48,55,49,50,46,98,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,25,208,106,135,3,0,32,0,49,48,55,49,54,46,98,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,72,29,186,64,3,0,32,0,49,48,55,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,158,116,123,119,4,0,16,1,55,55,53,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,252,52,149,106,6,0,16,1,49,48,55,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,204,74,17,170,7,0,64,0,49,48,55,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,130,29,12,128,7,0,64,0,49,48,55,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,82,239,33,89,7,0,64,0,51,49,55,45,48,48,51,51,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,229,130,232,73,5,0,16,1,29,0,0,0,255,255,3,0,0,0,0,0,0,0,0,0,101,112,114,45,49,48,52,50,57,46,52,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,202,158,244,189,1,0,16,1,101,112,114,45,49,48,52,50,55,46,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,41,221,227,246,1,0,16,1,101,112,114,45,49,48,52,51,48,46,52,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,159,67,227,137,1,0,16,1])
.concat([101,112,114,45,49,48,52,50,56,46,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,16,50,237,219,1,0,16,1,101,112,114,45,49,48,52,51,49,46,57,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,57,44,150,167,2,0,32,0,101,112,114,45,49,48,52,51,50,46,57,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,78,210,140,219,2,0,32,0,101,112,114,45,49,48,52,51,51,46,57,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,194,200,99,225,2,0,32,0,101,112,114,45,49,48,52,51,55,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,24,118,47,82,3,0,32,0,101,112,114,45,49,48,52,52,49,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,92,163,227,116,3,0,32,0,101,112,114,45,49,48,52,51,56,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,98,99,138,115,3,0,32,0,101,112,114,45,49,48,52,52,50,46,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,20,156,203,134,3,0,32,0,101,112,114,45,49,48,52,51,57,46,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,167,172,145,179,3,0,32,0,101,112,114,45,49,48,52,52,51,46,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,53,38,211,149,3,0,32,0,101,112,114,45,49,48,52,52,48,46,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,8,149,147,35,3,0,32,0,101,112,114,45,49,48,52,52,52,46,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,35,88,17,130,3,0,32,0,101,112,114,45,49,48,52,51,52,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,206,28,20,119,4,0,16,1,55,55,53,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,252,52,149,106,6,0,16,1,101,112,114,45,49,48,52,51,53,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,227,246,137,173,7,0,64,0,101,112,114,45,49,48,52,51,54,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,19,102,199,150,7,0,64,0,51,49,55,45,48,48,50,49,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,172,142,190,133,5,0,16,1,101,112,114,45,49,49,53,55,51,46,52,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,103,99,17,202,1,0,16,1,101,112,114,45,49,49,53,55,49,46,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,214,209,49,86,1,0,16,1,101,112,114,45,49,49,53,55,52,46,52,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,189,215,62,141,1,0,16,1,101,112,114,45,49,49,53,55,50,46,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,37,124,194,53,1,0,16,1,101,112,114,45,49,49,53,55,53,46,57,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,243,251,185,186,2,0,32,0,101,112,114,45,49,49,53,55,54,46,57,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,130,214,126,6,2,0,32,0,101,112,114,45,49,49,53,55,55,46,57,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,49,243,124,246,2,0,32,0,101,112,114,45,49,49,53,48,49,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,173,158,23,9,3,0,32,0,101,112,114,45,49,49,53,48,53,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,207,30,127,182,3,0,32,0,101,112,114,45,49,49,53,48,50,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,228,186,100,116,3,0,32,0,101,112,114,45,49,49,53,48,54,46,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,239,77,16,176,3,0,32,0,101,112,114,45,49,49,53,48,51,46,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,146,6,76,52,3,0,32,0,101,112,114,45,49,49,53,48,55,46,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,10,113,175,162,3,0,32,0,101,112,114,45,49,49,53,48,52,46,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,248,165,180,66,3,0,32,0,101,112,114,45,49,49,53,48,56,46,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,60,131,187,92,3,0,32,0,101,112,114,45,49,49,53,55,56,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,154,227,88,61,4,0,16,1,55,55,53,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,252,52,149,106,6,0,16,1,101,112,114,45,49,49,53,55,57,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,53,65,153,26,7,0,64,0,101,112,114,45,49,49,53,56,48,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,237,70,22,150,7,0,64,0,101,112,114,45,49,49,53,56,49,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,229,166,113,210,7,0,64,0,101,112,114,45,49,49,53,56,50,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,138,61,190,188,7,0,64,0,51,49,55,45,48,48,54,48,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,15,148,238,244,5,0,16,1,45,0,0,0,255,255,255,0,0,0,0,0,46,0,0,0,255,255,254,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,45,0,0,0,1,15,7,0,80,252,6,0,45,0,0,0,1,15,8,0,16,242,7,0,45,0,0,0,1,15,9,0,104,236,7,0,45,0,0,0,1,15,5,0,176,51,4,0,45,0,0,0,1,15,4,0,56,24,4,0,45,0,0,0,1,15,15,0,128,230,7,0,45,0,0,0,1,15,1,0,72,216,3,0,45,0,0,0,1,15,2,0,24,188,3,0,45,0,0,0,1,15,3,0,176,162,3,0,45,0,0,0,1,15,6,0,120,211,6,0,45,0,0,0,1,15,14,0,184,164,6,0,45,0,0,0,1,15,13,0,80,74,6,0,45,0,0,0,1,15,12,0,192,32,6,0,45,0,0,0,1,15,11,0,192,234,2,0,45,0,0,0,1,15,10,0,32,242,5,0,45,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,45,0,0,0,1,240,112,0,80,252,6,0,45,0,0,0,1,240,128,0,16,242,7,0,45,0,0,0,1,240,144,0,104,236,7,0,45,0,0,0,1,240,80,0,176,51,4,0,45,0,0,0,1,240,64,0,56,24,4,0,45,0,0,0,1,240,240,0,128,230,7,0,45,0,0,0,1,240,16,0,72,216,3,0,45,0,0,0,1,240,32,0,24,188,3,0,45,0,0,0,1,240,48,0,176,162,3,0,45,0,0,0,1,240,96,0,120,211,6,0,45,0,0,0,1,240,224,0,184,164,6,0,45,0,0,0,1,240,208,0,80,74,6,0,45,0,0,0,1,240,192,0,192,32,6,0,45,0,0,0,1,240,176,0,192,234,2,0,45,0,0,0,1,240,160,0,32,242,5,0,45,0,0,0,1,240,0,0,208,236,2,0,0,0,0,0,254,0,2,0,168,234,7,0,46,0,0,0,1,1,1,0,96,135,7,0,46,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,8,0,216,231,2,0,46,0,0,0,1,14,6,0,184,230,7,0,46,0,0,0,1,14,10,0,72,123,3,0,46,0,0,0,1,14,12,0,152,120,3,0,46,0,0,0,1,14,14,0,136,120,6,0,46,0,0,0,1,14,8,0,160,118,3,0,46,0,0,0,1,14,4,0,176,114,3,0,46,0,0,0,1,14,2,0,32,112,3,0,46,0,0,0,1,14,0,0,104,109,3,0,97,46,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,52,46,16,169,1,0,16,1,122,122,121,122,122,121,120,120,46,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,198,212,169,239,1,0,16,1,122,122,121,122,122,121,120,120,46,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,177,101,163,176,1,0,16,1,122,122,121,122,122,121,120,120,46,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,154,221,214,94,1,0,16,1,122,122,121,122,122,121,120,120,46,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,191,253,102,89,1,0,16,1,102,46,55,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,104,76,242,18,1,0,16,1,103,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,38,35,143,64,1,0,16,1,104,46,52,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,224,171,187,248,1,0,16,1,105,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,96,36,116,199,2,0,16,1,106,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,205,108,22,114,2,0,16,1,110,46,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,141,83,100,79,3,0,32,0,109,46,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,2,20,123,33,3,0,32,0,107,46,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,204,184,178,184,3,0,32,0,108,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,131,26,66,171,3,0,32,0,97,46,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,52,46,16,169,1,0,16,1,98,46,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,171,190,119,66,1,0,16,1,99,46,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,225,153,172,114,1,0,16,1,100,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,43,236,126,124,1,0,16,1,101,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,104,74,252,207,1,0,16,1,102,46,55,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,104,76,242,18,1,0,16,1,103,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,38,35,143,64,1,0,16,1,104,46,52,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,224,171,187,248,1,0,16,1,105,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,96,36,116,199,2,0,16,1,106,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,205,108,22,114,2,0,16,1,110,46,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,141,83,100,79,3,0,32,0,109,46,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,2,20,123,33,3,0,32,0,107,46,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,204,184,178,184,3,0,32,0,108,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,131,26,66,171,3,0,32,0,92,27,0,0,124,19,0,0,32,40,0,0,122,37,0,0,180,33,0,0,196,19,0,0,228,16,0,0,202,2,0,0,194,44,0,0,198,5,0,0,190,6,0,0,134,3,0,0,18,26,0,0,14,28,0,0,28,13,0,0,208,43,0,0,28,10,0,0,112,7,0,0,26,3,0,0,236,10,0,0,62,14,0,0,134,42,0,0,120,7,0,0,200,31,0,0,94,1,0,0,112,46,0,0,10,0,0,0,24,41,0,0,160,5,0,0,20,9,0,0,20,30,0,0,4,20,0,0,152,26,0,0,92,12,0,0,28,43,0,0,98,29,0,0,158,1,0,0,246,46,0,0,206,36,0,0,40,29,0,0,230,2,0,0,190,41,0,0,26,11,0,0,108,37,0,0,232,22,0,0,32,13,0,0,136,35,0,0,222,18,0,0,154,20,0,0,210,31,0,0,186,10,0,0,56,47,0,0,98,4,0,0,54,39,0,0,16,5,0,0,236,39,0,0,68,34,0,0,160,20,0,0,252,8,0,0,174,4,0,0,150,9,0,0,88,35,0,0,60,8,0,0,2,5,0,0,208,11,0,0,112,2,0,0,30,27,0,0,18,3,0,0,152,15,0,0,4,25,0,0,172,22,0,0,162,26,0,0,140,4,0,0,196,38,0,0,134,11,0,0,166,44,0,0,154,0,0,0,220,6,0,0,64,17,0,0,100,7,0,0,12,39,0,0,78,1,0,0,224,13,0,0,140,0,0,0,132,20,0,0,120,17,0,0,22,30,0,0,76,41,0,0,140,33,0,0,118,13,0,0,18,42,0,0,16,28,0,0,216,17,0,0,22,14,0,0,46,19,0,0,74,45,0,0,84,13,0,0,102,44,0,0,126,37,0,0,246,22,0,0,90,3,0,0,20,1,0,0,224,43,0,0,174,47,0,0,14,38,0,0,102,35,0,0,26,32,0,0,50,35,0,0,132,25,0,0,126,18,0,0,156,8,0,0,24,20,0,0,244,14,0,0,186,21,0,0,116,5,0,0,20,18,0,0,14,21,0,0,100,21,0,0,188,21,0,0,80,34,0,0,74,6,0,0,36,2,0,0,78,35,0,0,66,38,0,0,94,16,0,0,22,21,0,0,34,47,0,0,116,40,0,0,246,34,0,0,110,13,0,0,184,47,0,0,220,44,0,0,134,6,0,0,64,27,0,0,144,24,0,0,4,45,0,0,248,46,0,0,106,32,0,0,176,14,0,0,214,20,0,0,42,3,0,0,18,48,0,0,152,38,0,0,166,12,0,0,166,28,0,0,114,31,0,0,122,11,0,0,216,6,0,0,104,1,0,0,120,18,0,0,172,15,0,0,136,11,0,0,12,31,0,0,202,43,0,0,20,44,0,0,180,4,0,0,140,5,0,0,16,33,0,0,14,26,0,0,210,8,0,0,160,39,0,0,14,4,0,0,248,38,0,0,98,39,0,0,186,23,0,0,122,24,0,0,136,6,0,0,156,39,0,0,40,37,0,0,14,40,0,0,124,11,0,0,6,39,0,0,38,17,0,0,44,8,0,0,204,13,0,0,94,39,0,0,26,31,0,0,216,28,0,0,118,23,0,0,56,27,0,0,2,41,0,0,218,2,0,0,240,16,0,0,92,2,0,0,0,14,0,0,224,14,0,0,140,25,0,0,68,33,0,0,216,46,0,0,232,8,0,0,120,11,0,0,102,14,0,0,186,29,0,0,70,19,0,0,160,46,0,0,132,1,0,0,240,33,0,0,198,29,0,0,100,19,0,0,122,36,0,0,94,0,0,0,194,0,0,0,218,23,0,0,74,24,0,0,204,35,0,0,36,27,0,0,60,41,0,0,206,2,0,0,58,34,0,0,106,13,0,0,200,3,0,0,168,24,0,0,44,14,0,0,32,41,0,0,68,27,0,0,128,24,0,0,2,33,0,0,178,36,0,0,48,18,0,0,84,40,0,0,30,31,0,0,134,41,0,0,100,42,0,0,54,0,0,0,6,29,0,0,252,45,0,0,96,43,0,0,60,39,0,0,254,7,0,0,238,10,0,0,44,39,0,0,232,28,0,0,142,42,0,0,112,42,0,0,100,5,0,0,146,36,0,0,162,2,0,0,184,33,0,0,188,23,0,0,76,26,0,0,162,36,0,0,242,33,0,0,44,42,0,0,220,15,0,0,64,11,0,0,94,33,0,0,68,30,0,0,72,16,0,0,162,29,0,0,168,39,0,0,140,16,0,0,78,16,0,0,210,15,0,0,2,13,0,0,100,0,0,0,136,16,0,0,102,121,48,48,49,48,48,51,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,247,184,52,11,1,0,16,1,102,121,48,48,49,48,48,52,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,26,235,191,113,1,0,16,1,102,121,48,48,49,48,48,50,46,49,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,143,214,63,49,1,0,16,1,102,121,48,48,49,48,48,49,46,49,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,19,31,246,160,1,0,16,1,102,121,48,48,49,48,48,54,46,50,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,247,153,174,233,3,0,32,0,102,121,48,48,49,48,48,56,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,225,176,215,115,4,0,32,0,102,121,48,48,49,48,48,55,46,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,129,44,252,178,28,0,32,0,102,121,48,48,49,48,49,48,46,54,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,122,237,64,139,5,0,32,0,102,121,48,48,49,48,48,57,46,54,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,65,166,204,107,29,0,32,0,102,121,48,48,49,48,49,50,46,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,2,225,48,253,6,0,64,0,102,121,48,48,49,48,49,49,46,97,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,222,49,196,227,6,0,64,0,50,49,49,45,112,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,10,254,11,154,1,0,16,1,50,49,49,45,115,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,250,106,209,86,2,0,32,0,122,105,110,45,99,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,137,225,174,118,3,0,32,0,122,105,110,45,99,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,179,212,78,132,3,0,32,0,50,49,49,45,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,7,20,174,252,4,0,16,1,50,49,49,45,118,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,218,57,20,120,5,0,64,0,122,105,110,45,112,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,167,252,200,6,1,0,16,1,122,105,110,45,115,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,129,14,171,167,2,0,32,0,122,105,110,45,99,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,137,225,174,118,3,0,32,0,122,105,110,45,99,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,179,212,78,132,3,0,32,0,122,105,110,45,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,202,39,150,253,4,0,16,1,122,105,110,45,118,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,241,116,159,192,5,0,64,0,122,122,45,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,155,139,113,131,1,0,16,1,122,122,45,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,65,127,85,24,1,0,16,1,122,122,45,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,229,204,60,34,2,0,16,1,122,122,45,54,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,185,6,185,200,3,0,32,0,122,122,45,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,129,30,85,199,4,0,64,0,122,122,45,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,94,255,72,227,4,0,64,0,111,49,53,45,49,49,105,105,119,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,91,187,176,56,0,0,16,1,111,49,53,45,49,50,105,105,119,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,111,30,201,116,0,0,16,1,111,49,53,45,48,57,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,149,78,118,19,0,0,16,1,111,49,53,45,49,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,26,167,27,53,0,0,16,1,111,49,53,45,48,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,70,210,93,78,0,0,32,0,111,49,53,45,48,54,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,40,212,198,200,0,0,32,0,111,49,53,45,48,55,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,153,14,196,239,0,0,32,0,111,49,53,45,48,56,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,171,158,1,27,0,0,32,0,111,49,53,45,48,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,211,95,36,127,0,0,32,0,111,49,53,45,48,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,137,18,26,11,0,0,32,0,111,49,53,45,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,67,14,87,112,0,0,32,0,111,49,53,45,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,127,72,75,114,0,0,32,0,111,49,53,45,49,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,131,35,183,231,0,0,16,1,116,112,48,49,53,95,49,52,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,237,204,136,188,0,0,64,0,116,112,48,49,53,95,49,53,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,146,116,225,161,0,0,64,0,18,0,0,0,255,255,1,0,0,0,0,0,19,0,0,0,255,255,0,0,0,0,0,0,20,0,0,0,255,255,0,0,0,0,0,0,18,0,0,0,1,1,1,0,120,97,1,0,18,0,0,0,1,1,0,0,96,19,1,0,0,0,0,0,254,0,2,0,0,0,0,0,18,0,0,0,1,2,0,0,200,211,8,0,18,0,0,0,1,2,2,0,216,147,8,0,0,0,0,0,254,0,2,0,0,0,0,0,18,0,0,0,1,4,0,0,168,84,8,0,18,0,0,0,1,4,4,0,40,31,8,0,0,0,0,0,254,0,2,0,240,233,7,0,18,0,0,0,1,8,0,0,152,182,7,0,18,0,0,0,1,8,8,0,96,135,7,0,0,0,0,0,254,0,4,0,200,87,7,0,18,0,0,0,1,48,0,0,232,38,7,0,18,0,0,0,1,48,16,0,64,251,6,0,18,0,0,0,1,48,32,0,24,211,6,0,18,0,0,0,1,48,48,0,72,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,18,0,0,0,1,192,0,0,176,73,6,0,18,0,0,0,1,192,64,0,72,32,6,0,18,0,0,0,1,192,128,0,168,241,5,0,18,0,0,0,1,192,192,0,184,201,5,0,0,0,0,0,254,0,4,0,136,160,5,0,19,0,0,0,1,3,0,0,16,150,7,0,19,0,0,0,1,3,1,0,120,198,7,0,19,0,0,0,1,3,2,0,160,103,7,0,19,0,0,0,1,3,3,0,16,53,7,0,0,0,0,0,254,0,4,0,248,6,5,0,19,0,0,0,1,12,0,0,248,226,4,0,19,0,0,0,1,12,4,0,248,190,4,0,19,0,0,0,1,12,8,0,104,159,4,0,19,0,0,0,1,12,12,0,48,129,4,0,0,0,0,0,254,0,4,0,248,101,4,0,19,0,0,0,1,48,48,0,208,75,4,0,19,0,0,0,1,48,0,0,8,49,4,0,19,0,0,0,1,48,32,0,152,21,4,0,19,0,0,0,1,48,16,0,72,246,3,0,0,0,0,0,254,0,2,0,0,0,0,0,19,0,0,0,1,64,0,0,96,212,3,0,19,0,0,0,1,64,64,0,48,185,3,0,0,0,0,0,254,0,2,0,104,159,3,0,19,0,0,0,1,128,0,0,104,134,3,0,19,0,0,0,1,128,128,0,56,111,3,0,0,0,0,0,111,49,53,45,49,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,160,185,242,111,0,0,16,1,111,49,53,45,49,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,11,230,115,151,0,0,16,1,111,49,53,45,48,57,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,149,78,118,19,0,0,16,1,111,49,53,45,49,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,26,167,27,53,0,0,16,1,111,49,53,45,48,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,70,210,93,78,0,0,32,0,111,49,53,45,48,54,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,40,212,198,200,0,0,32,0,111,49,53,45,48,55,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,153,14,196,239,0,0,32,0,111,49,53,45,48,56,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,171,158,1,27,0,0,32,0,111,49,53,45,48,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,211,95,36,127,0,0,32,0,111,49,53,45,48,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,137,18,26,11,0,0,32,0,111,49,53,45,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,67,14,87,112,0,0,32,0,111,49,53,45,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,127,72,75,114,0,0,32,0,111,49,53,45,49,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,131,35,183,231,0,0,16,1,116,112,48,49,53,95,49,52,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,237,204,136,188,0,0,64,0,116,112,48,49,53,95,49,53,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,146,116,225,161,0,0,64,0,18,0,0,0,255,255,1,0,0,0,0,0,19,0,0,0,255,255,0,0,0,0,0,0,20,0,0,0,255,255,2,0,0,0,0,0,18,0,0,0,1,1,1,0,120,97,1,0,18,0,0,0,1,1,0,0,96,19,1,0,0,0,0,0,254,0,2,0,0,0,0,0,18,0,0,0,1,2,0,0,200,211,8,0,18,0,0,0,1,2,2,0,216,147,8,0,0,0,0,0,254,0,2,0,0,0,0,0,18,0,0,0,1,4,0,0,168,84,8,0,18,0,0,0,1,4,4,0,40,31,8,0,0,0,0,0,254,0,2,0,240,233,7,0,18,0,0,0,1,8,0,0,152,182,7,0,18,0,0,0,1,8,8,0,96,135,7,0,0,0,0,0,254,0,4,0,200,87,7,0,18,0,0,0,1,48,0,0,232,38,7,0,18,0,0,0,1,48,16,0,64,251,6,0,18,0,0,0,1,48,32,0,24,211,6,0,18,0,0,0,1,48,48,0,72,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,18,0,0,0,1,192,0,0,176,73,6,0,18,0,0,0,1,192,64,0,72,32,6,0,18,0,0,0,1,192,128,0,168,241,5,0,18,0,0,0,1,192,192,0,184,201,5,0,0,0,0,0,254,0,4,0,136,160,5,0,19,0,0,0,1,3,0,0,16,150,7,0,19,0,0,0,1,3,1,0,120,198,7,0,19,0,0,0,1,3,2,0,160,103,7,0,19,0,0,0,1,3,3,0,16,53,7,0,0,0,0,0,254,0,4,0,248,6,5,0,19,0,0,0,1,12,0,0,248,226,4,0,19,0,0,0,1,12,4,0,248,190,4,0,19,0,0,0,1,12,8,0,104,159,4,0,19,0,0,0,1,12,12,0,48,129,4,0,0,0,0,0,254,0,4,0,248,101,4,0,19,0,0,0,1,48,48,0,208,75,4,0,19,0,0,0,1,48,0,0,8,49,4,0,19,0,0,0,1,48,32,0,152,21,4,0,19,0,0,0,1,48,16,0,72,246,3,0,0,0,0,0,254,0,2,0,0,0,0,0,19,0,0,0,1,64,0,0,96,212,3,0,19,0,0,0,1,64,64,0,48,185,3,0,0,0,0,0,254,0,2,0,104,159,3,0,19,0,0,0,1,128,0,0,104,134,3,0,19,0,0,0,1,128,128,0,56,111,3,0,0,0,0,0,254,0,3,0,48,45,3,0,20,0,0,0,1,3,0,0,176,20,3,0,20,0,0,0,1,3,1,0,184,255,2,0,20,0,0,0,1,3,2,0,8,234,2,0,0,0,0,0,48,55,54,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,253,239,193,215,1,0,16,1,48,55,54,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,213,93,194,244,2,0,32,0,48,55,54,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,56,176,156,77,3,0,32,0,48,55,54,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,132,56,35,9,3,0,32,0,48,55,54,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,227,49,100,208,3,0,32,0,48,55,54,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,155,8,28,75,3,0,32,0,48,55,54,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,10,61,95,123,4,0,16,1,48,55,54,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,12,217,33,26,5,0,64,0,48,55,54,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,195,134,22,182,5,0,64,0,48,55,54,45,118,51,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,250,88,6,185,5,0,64,0,97,52,45,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,162,251,220,3,1,0,16,1,121,100,95,100,50,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,224,124,157,124,1,0,16,1,101,52,45,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,194,93,143,53,1,0,16,1,102,52,45,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,252,12,25,244,1,0,16,1,115,56,45,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,182,197,128,170,2,0,32,0,117,56,45,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,91,200,14,210,2,0,32,0,114,56,45,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,250,159,220,219,3,0,32,0,110,56,45,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,219,115,153,75,3,0,32,0,121,100,95,100,53,46,104,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,155,183,48,245,4,0,32,0,121,100,95,100,54,46,107,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,170,121,5,121,4,0,32,0,117,48,50,45,45,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,215,101,138,35,5,0,32,0,116,48,50,45,45,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,192,61,38,174,5,0,32,0,102,49,48,45,45,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,162,76,238,22,5,0,32,0,106,49,48,45,45,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,132,226,127,255,5,0,32,0,99,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,77,134,90,97,1,0,16,1,98,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,229,142,46,99,1,0,16,1,100,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,101,77,141,218,2,0,32,0,100,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,36,111,29,59,2,0,32,0,98,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,175,104,228,117,3,0,32,0,98,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,70,209,28,126,3,0,32,0,98,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,249,217,185,193,3,0,32,0,115,130,78,63,252,86,89,6,5,72,168,244,0,0,0,0,0,0,0,0,0,0,0,0,120,109,45,97,45,104,49,45,46,105,99,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,207,72,144,68,1,0,16,1,120,109,45,97,45,108,49,45,46,105,99,54,55,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,176,57,206,38,1,0,16,1,120,109,45,97,45,104,48,45,46,105,99,53,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,112,201,155,80,1,0,16,1,120,109,45,97,45,108,48,45,46,105,99,54,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,188,158,10,73,1,0,16,1,120,109,45,97,45,115,112,45,46,105,99,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,86,239,110,0,6,0,16,1,116,52,52,46,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,110,24,69,219,2,0,32,0,116,52,53,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,212,100,7,77,2,0,32,0,116,52,54,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,164,101,196,240,2,0,32,0,116,52,55,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,75,178,99,18,2,0,32,0,116,52,56,46,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,79,148,41,65,2,0,32,0,116,52,57,46,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,249,230,70,35,2,0,32,0,116,53,48,46,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,62,84,34,227,2,0,32,0,116,53,49,46,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,177,247,155,34,2,0,32,0,116,53,51,46,97,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,148,36,8,26,3,0,32,0,116,53,52,46,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,197,22,108,7,3,0,32,0,116,53,53,46,97,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,165,119,216,37,3,0,32,0,116,53,54,46,97,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,245,19,18,91,3,0,32,0,116,53,55,46,98,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,199,224,132,10,4,0,32,0,116,53,56,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,29,18,116,168,4,0,32,0,116,53,57,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,144,185,222,105,4,0,32,0,116,54,48,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,153,159,198,20,4,0,32,0,116,53,50,46,118,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,128,189,177,45,5,0,64,0,109,56,49,95,97,45,57,108,45,46,105,99,55,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,56,196,96,180,0,0,0,8,109,56,49,95,97,45,57,112,45,46,105,99,55,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,188,196,242,164,0,0,0,8,50,52,97,99,45,48,95,106,45,49,46,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,201,210,143,236,1,0,16,1,50,52,97,100,45,48,95,106,45,49,46,51,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,228,20,230,84,1,0,16,1,50,52,97,98,45,48,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,170,248,68,30,2,0,16,1,50,52,97,57,45,48,46,52,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,143,240,63,112,3,0,64,0,50,52,106,56,45,48,46,52,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,135,132,19,97,3,0,64,0,50,52,97,97,45,48,46,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,64,186,18,203,4,0,32,0,99,57,53,49,46,49,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,240,209,118,250,5,0,32,0,50,52,106,52,45,48,46,49,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,163,137,165,196,5,0,32,0,50,52,106,53,45,48,46,49,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,54,164,188,214,5,0,32,0,99,57,53,48,46,49,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,61,112,165,204,5,0,32,0,50,52,106,50,45,48,46,49,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,118,27,220,5,0,32,0,50,52,106,51,45,48,46,49,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,67,45,161,59,5,0,32,0,50,52,106,55,45,48,46,49,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,158,144,161,224,6,0,32,0,50,52,106,54,45,48,46,49,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,248,46,147,119,6,0,32,0,97,115,49,48,117,54,46,117,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,239,139,161,112,1,0,0,0,97,115,49,48,117,55,46,117,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,125,190,35,207,1,0,0,0,97,115,49,48,48,49,109,48,49,46,117,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,121,85,89,146,2,0,0,0,97,115,49,48,48,50,109,48,49,46,117,51,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,8,187,194,22,2,0,0,0,97,115,49,48,48,51,109,48,49,46,117,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,88,136,97,137,2,0,0,0,97,115,49,48,48,52,109,48,49,46,117,52,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,9,9,12,80,2,0,0,0,97,115,49,48,48,53,109,48,49,46,117,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,184,55,177,228,3,0,0,0,97,115,49,48,48,54,101,48,50,46,117,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,181,178,211,211,1,0,0,0,97,115,49,48,48,55,101,48,50,46,117,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,217,230,237,120,1,0,0,0,97,115,49,48,48,49,109,48,49,46,117,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,121,85,89,146,2,0,0,0,97,115,49,48,48,50,109,48,49,46,117,51,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,8,187,194,22,2,0,0,0,97,115,49,48,48,51,109,48,49,46,117,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,88,136,97,137,2,0,0,0,97,115,49,48,48,52,109,48,49,46,117,52,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,9,9,12,80,2,0,0,0,97,115,49,48,48,53,109,48,49,46,117,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,184,55,177,228,3,0,0,0,117,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,151,106,137,155,1,0,16,1,117,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,70,72,168,221,1,0,16,1,117,54,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,120,205,108,240,3,0,32,0,117,54,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,27,42,96,42,3,0,32,0,117,54,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,12,106,252,201,4,0,32,0,117,54,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,131,196,192,37,5,0,32,0,117,54,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,65,205,126,149,6,0,64,0,117,55,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,111,117,141,6,0,64,0,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,202,139,238,181,1,0,16,1,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,230,45,236,197,1,0,16,1,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,78,83,234,7,1,0,16,1,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,58,37,163,163,1,0,16,1,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,107,84,80,108,1,0,16,1,49,48,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,2,33,245,11,2,0,32,0,49,49,46,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,248,222,216,14,2,0,32,0,112,114,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,189,80,198,47,3,0,32,0,112,114,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,103,33,119,216,3,0,32,0,112,114,46,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,134,204,169,4,0,64,0,112,114,46,51,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,102,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,202,102,234,55,1,0,16,1,105,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,186,93,17,205,1,0,16,1,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,33,35,11,212,1,0,16,1,103,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,244,146,64,2,1,0,16,1,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,200,15,239,24,1,0,16,1,97,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,98,127,168,21,2,0,32,0,99,46,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,136,189,74,171,2,0,32,0,98,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,91,169,155,91,2,0,32,0,100,46,53,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,69,10,184,215,2,0,32,0,112,114,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,189,80,198,47,3,0,32,0,112,114,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,103,33,119,216,3,0,32,0,112,114,46,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,134,204,169,4,0,64,0,112,114,46,51,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,117,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,246,233,163,70,1,0,16,1,117,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,67,183,149,153,1,0,16,1,117,49,50,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,133,160,219,134,2,0,16,1,117,54,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,180,9,207,198,3,0,32,0,117,54,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,94,154,158,46,3,0,32,0,117,55,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,4,134,130,58,3,0,32,0,117,55,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,175,70,202,12,3,0,32,0,117,54,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,197,154,236,220,3,0,32,0,117,54,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,8,215,185,39,3,0,32,0,117,55,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,47,142,255,126,3,0,32,0,117,56,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,194,160,96,17,3,0,32,0,117,56,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,198,249,28,245,4,0,32,0,117,56,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,12,198,211,221,4,0,32,0,117,49,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,77,98,252,167,4,0,32,0,117,57,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,163,216,105,35,4,0,32,0,117,57,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,148,189,161,171,4,0,32,0,117,49,51,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,189,108,75,41,5,0,64,0,104,119,95,48,48,45,49,46,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,30,97,220,105,1,0,16,1,104,119,95,48,51,45,49,46,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,128,150,109,182,1,0,16,1,109,97,109,48,48,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,166,64,164,15,1,0,16,1,109,97,109,48,55,46,56,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,32,127,188,248,1,0,16,1,104,119,95,48,52,45,46,49,56,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,235,8,102,235,2,0,16,1,104,119,95,48,49,45,46,49,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,164,12,129,217,3,0,32,0,104,119,95,48,50,45,46,49,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,142,172,39,42,3,0,32,0,109,97,109,48,49,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,204,251,244,219,4,0,32,0,109,97,109,48,50,46,49,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,129,196,250,177,4,0,32,0,109,97,109,48,56,46,49,55,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,63,168,151,202,5,0,32,0,109,97,109,48,57,46,49,56,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,111,213,87,63,5,0,32,0,109,97,109,48,53,46,49,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,209,44,122,48,6,0,32,0,109,97,109,48,54,46,50,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,45,154,17,161,6,0,32,0,109,97,109,49,48,46,49,57,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,159,143,244,153,6,0,32,0,109,97,109,49,49,46,50,48,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,89,40,241,195,6,0,32,0,109,97,109,48,51,46,49,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,72,253,77,252,6,0,32,0,109,97,109,48,52,46,49,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,191,56,59,125,6,0,32,0,109,97,109,49,51,46,49,53,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,148,91,82,8,0,64,0,109,97,109,49,50,46,49,52,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,145,183,0,111,7,0,64,0,104,98,45,48,48,46,49,49,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,173,186,167,183,0,0,0,8,101,97,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,20,138,87,176,1,0,16,1,101,97,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,108,220,30,39,1,0,16,1,101,97,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,213,167,149,112,1,0,16,1,101,97,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,117,100,169,129,1,0,16,1,101,97,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,211,173,81,89,1,0,16,1,101,97,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,30,203,179,196,1,0,16,1,101,97,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,49,98,187,141,2,0,16,1,101,97,48,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,76,172,60,159,3,0,32,0,101,97,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,68,19,112,125,4,0,32,0,101,97,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,251,85,223,24,4,0,32,0,101,97,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,80,240,46,146,4,0,32,0,101,97,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,112,222,15,112,4,0,32,0,101,97,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,157,233,212,166,5,0,32,0,101,97,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,201,253,95,145,5,0,32,0,101,97,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,58,159,131,205,5,0,32,0,101,97,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,22,79,241,161,5,0,32,0,101,97,49,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,156,138,29,122,5,0,32,0,101,97,49,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,61,34,163,33,5,0,32,0,101,97,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,199,206,178,63,5,0,32,0,101,97,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,181,3,207,135,5,0,32,0,101,97,50,49,46,112,114,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,73,171,190,200,6,0,32,0,101,97,50,48,46,112,114,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,30,157,159,97,6,0,32,0,119,110,100,114,112,108,110,116,95,105,56,55,53,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,24,48,54,53,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,64,193,146,102,1,0,16,1,48,54,53,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,35,87,75,7,2,0,32,0,48,54,53,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,4,2,101,199,3,0,32,0,48,54,53,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,29,231,243,217,3,0,32,0,48,54,53,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,134,99,152,64,3,0,32,0,48,54,53,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,255,21,94,113,3,0,32,0,48,54,53,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,252,60,194,82,4,0,16,1,48,54,53,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,152,54,139,206,5,0,64,0,48,54,53,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,150,155,159,101,5,0,64,0,48,54,53,45,118,51,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,97,48,247,57,5,0,64,0,48,54,53,45,118,52,46,118,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,99,121,238,93,5,0,64,0,106,101,45,48,49,46,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,103,35,214,182,1,0,16,1,106,101,45,48,48,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,120,226,61,243,1,0,16,1,106,101,45,48,51,46,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,4,212,23,82,1,0,16,1,106,101,45,48,50,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,40,206,161,54,1,0,16,1,109,97,115,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,206,86,82,126,1,0,16,1,109,97,115,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,153,212,91,0,1,0,16,1,106,101,45,48,54,46,50,48,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,70,37,4,121,2,0,16,1,106,101,45,48,52,46,49,48,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,168,203,115,3,0,32,0,106,101,45,48,53,46,49,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,157,196,226,34,3,0,32,0,109,97,115,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,52,16,1,61,4,0,32,0,109,97,115,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,11,157,12,109,4,0,32,0,109,97,115,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,32,230,0,175,5,0,32,0,109,97,115,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,162,30,230,47,5,0,32,0,109,97,115,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,59,149,86,30,6,0,32,0,109,97,115,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,248,184,38,56,6,0,32,0,109,97,115,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,69,189,139,59,6,0,32,0,109,97,115,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,105,55,48,49,6,0,32,0,109,97,115,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,122,251,36,226,7,0,32,0,109,97,115,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,65,235,109,95,7,0,32,0,109,97,115,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,167,6,220,110,8,0,64,0,109,97,115,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,242,164,240,194,9,0,64,0,109,98,55,49,50,50,104,46,49,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,204,87,238,43,0,0,0,8,119,116,52,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,138,75,142,163,1,0,16,1,119,116,52,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,235,92,64,193,1,0,16,1,119,116,52,106,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,195,177,159,55,1,0,16,1,119,116,52,107,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,199,249,214,45,1,0,16,1,119,116,95,97,45,52,109,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,213,167,248,193,1,0,16,1,119,116,95,97,45,52,110,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,210,247,18,178,1,0,16,1,119,116,52,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,191,113,161,37,2,0,16,1,119,116,95,98,45,53,101,46])
.concat([98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,67,223,69,254,3,0,32,0,119,116,95,98,45,53,102,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,255,126,161,135,3,0,32,0,119,116,98,53,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,250,203,193,239,4,0,32,0,119,116,98,53,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,7,253,75,171,4,0,32,0,119,116,98,53,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,29,62,242,64,4,0,32,0,119,116,50,106,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,112,6,191,209,5,0,32,0,119,116,51,107,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,14,154,195,131,5,0,32,0,119,116,95,97,45,51,109,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,174,104,228,231,5,0,32,0,119,116,95,97,45,51,110,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,169,209,65,7,5,0,32,0,119,116,95,97,45,51,112,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,98,243,153,114,5,0,32,0,119,116,95,97,45,51,115,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,13,213,55,155,5,0,32,0,119,116,95,97,45,54,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,155,226,221,165,6,0,64,0,119,116,95,97,45,53,115,45,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,231,80,25,4,7,0,32,0,119,116,95,97,45,53,114,45,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,37,191,4,188,7,0,32,0,119,116,95,97,45,53,112,45,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,25,154,129,237,7,0,32,0,119,116,95,98,45,57,108,45,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,68,135,114,210,7,0,32,0,49,46,51,115,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,155,108,135,171,1,0,16,1,50,46,53,115,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,59,75,199,29,1,0,16,1,116,107,110,105,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,199,62,98,21,2,0,16,1,116,107,110,105,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,150,88,209,94,3,0,32,0,49,52,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,12,193,32,13,4,0,32,0,49,53,46,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,180,166,64,63,4,0,32,0,49,54,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,158,99,49,15,4,0,32,0,49,55,46,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,142,21,44,243,4,0,32,0,116,107,110,105,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,177,175,143,246,5,0,32,0,116,107,110,105,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,57,66,47,210,6,0,32,0,116,107,110,105,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,132,177,49,73,6,0,32,0,116,107,110,105,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,207,219,161,167,7,0,64,0,97,45,54,118,46,109,99,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,24,106,50,117,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,148,254,136,116,1,0,16,1,106,49,117,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,172,19,20,87,1,0,16,1,108,104,53,51,50,106,49,48,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,101,198,135,17,1,0,16,1,108,104,53,51,50,106,49,49,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,229,169,237,24,1,0,16,1,51,46,49,52,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,62,118,143,174,2,0,16,1,108,104,53,51,52,106,49,49,46,49,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,13,251,133,191,3,0,64,0,108,104,53,51,52,106,48,57,46,49,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,165,233,44,108,4,0,64,0,108,104,53,51,52,106,49,48,46,49,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,33,34,104,227,4,0,64,0,48,52,54,46,57,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,119,109,217,49,5,0,32,0,48,52,56,46,57,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,218,67,70,187,5,0,32,0,108,104,53,51,52,106,49,50,46,55,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,116,139,26,182,6,0,32,0,0,0,0,0,0,0,0,0,50,50,53,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,102,167,77,177,1,0,16,1,50,50,53,45,112,50,46,115,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,101,6,25,254,1,0,16,1,50,50,53,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,181,180,196,113,2,0,32,0,50,50,53,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,84,234,79,238,3,0,32,0,50,50,53,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,45,158,84,12,3,0,32,0,50,50,53,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,192,151,8,175,3,0,32,0,50,50,53,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,122,82,102,76,3,0,32,0,50,50,53,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,181,162,206,142,3,0,32,0,50,50,53,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,109,26,177,14,3,0,32,0,50,50,53,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,166,187,52,6,4,0,16,1,50,50,53,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,180,198,149,97,5,0,64,0,50,50,53,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,254,197,89,97,5,0,64,0,168,86,7,0,1,0,0,0,88,246,146,0,248,191,2,0,24,38,7,0,1,0,0,0,199,254,146,0,184,160,2,0,56,210,6,0,1,0,0,0,192,254,146,0,192,135,2,0,24,163,6,0,1,0,0,0,193,254,146,0,240,108,2,0,152,122,6,0,1,0,0,0,194,254,146,0,96,82,2,0,192,72,6,0,1,0,0,0,195,254,146,0,32,56,2,0,200,110,3,0,1,0,0,0,196,254,146,0,152,30,2,0,120,89,3,0,1,0,0,0,197,254,146,0,232,10,2,0,120,74,3,0,1,0,0,0,198,254,146,0,152,138,8,0,40,246,1,0,1,0,0,0,89,246,146,0,64,246,1,0,144,236,1,0,1,0,0,0,191,254,146,0,136,224,1,0,176,223,1,0,1,0,0,0,184,254,146,0,72,198,1,0,192,209,1,0,1,0,0,0,185,254,146,0,24,182,1,0,24,198,1,0,1,0,0,0,186,254,146,0,40,167,1,0,120,189,1,0,1,0,0,0,187,254,146,0,200,149,1,0,224,22,1,0,1,0,0,0,188,254,146,0,56,126,1,0,160,14,1,0,1,0,0,0,189,254,146,0,32,101,1,0,176,9,1,0,1,0,0,0,190,254,146,0,96,32,8,0,88,212,3,0,1,0,0,0,128,218,146,0,40,185,3,0,16,17,8,0,1,0,0,0,91,246,146,0,224,12,8,0,16,17,8,0,1,0,0,0,92,246,146,0,224,12,8,0,56,58,1,0,1,0,0,0,90,246,146,0,64,50,1,0,72,65,1,0,9,0,0,0,32,5,147,0,32,58,1,0,48,50,1,0,9,0,0,0,33,5,147,0,32,58,1,0,168,86,7,0,1,0,0,0,240,33,216,0,248,191,2,0,240,18,1,0,1,0,0,0,248,33,216,0,184,160,2,0,56,210,6,0,1,0,0,0,0,33,216,0,192,135,2,0,24,163,6,0,1,0,0,0,1,33,216,0,240,108,2,0,152,122,6,0,1,0,0,0,2,33,216,0,96,82,2,0,192,72,6,0,1,0,0,0,3,33,216,0,32,56,2,0,96,18,1,0,1,0,0,0,4,33,216,0,152,30,2,0,56,17,1,0,1,0,0,0,5,33,216,0,232,10,2,0,136,16,1,0,1,0,0,0,6,33,216,0,152,138,8,0,224,15,1,0,1,0,0,0,7,33,216,0,48,119,7,0,40,246,1,0,1,0,0,0,241,33,216,0,64,246,1,0,144,236,1,0,1,0,0,0,250,33,216,0,136,224,1,0,176,223,1,0,1,0,0,0,248,32,216,0,72,198,1,0,192,209,1,0,1,0,0,0,249,32,216,0,24,182,1,0,24,198,1,0,1,0,0,0,250,32,216,0,40,167,1,0,120,189,1,0,1,0,0,0,251,32,216,0,200,149,1,0,184,155,8,0,1,0,0,0,252,32,216,0,56,126,1,0,136,149,8,0,1,0,0,0,253,32,216,0,32,101,1,0,216,142,8,0,1,0,0,0,254,32,216,0,96,32,8,0,40,138,8,0,1,0,0,0,255,32,216,0,16,68,7,0,56,15,1,0,1,0,0,0,244,33,216,0,120,14,1,0,56,14,1,0,1,0,0,0,245,33,216,0,8,14,1,0,176,13,1,0,1,0,0,0,247,33,216,0,88,13,1,0,88,212,3,0,1,0,0,0,200,32,216,0,40,185,3,0,80,251,6,0,1,0,0,0,48,33,216,0,216,70,1,0,248,5,8,0,9,0,0,0,12,33,216,0,32,58,1,0,144,250,7,0,9,0,0,0,13,33,216,0,32,58,1,0,208,23,1,0,9,0,0,0,152,32,216,0,32,58,1,0,184,22,1,0,9,0,0,0,128,37,0,0,32,58,1,0,0,22,1,0,9,0,0,0,56,33,216,0,32,58,1,0,120,20,1,0,9,0,0,0,57,33,216,0,32,58,1,0,99,49,54,45,49,49,46,52,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,136,211,219,35,2,0,0,0,99,49,54,45,49,52,46,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,106,79,147,220,2,0,0,0,99,49,54,45,48,55,46,52,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,89,208,209,100,2,0,0,0,99,49,54,45,48,54,46,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,216,97,55,4,2,0,0,0,99,49,54,45,49,50,46,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,199,40,176,111,9,0,0,0,99,49,54,45,48,49,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,131,206,89,112,11,0,0,0,99,49,54,45,48,50,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,5,233,88,180,11,0,0,0,99,49,54,45,48,51,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,49,148,90,81,11,0,0,0,99,49,54,45,48,52,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,226,133,242,235,11,0,0,0,99,49,54,45,48,53,46,52,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,74,6,157,164,29,0,0,0,112,97,108,49,54,108,56,98,45,99,49,54,45,48,56,46,105,99,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,120,210,86,148,0,0,0,8,112,97,108,49,54,108,56,98,45,99,49,54,45,48,57,46,105,99,51,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,171,186,101,9,0,0,0,8,48,53,49,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,157,137,170,23,1,0,16,1,48,53,49,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,88,87,234,159,2,0,32,0,48,53,49,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,50,193,36,214,3,0,32,0,48,53,49,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,30,159,214,64,3,0,32,0,48,53,49,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,154,242,105,142,4,0,16,1,48,53,49,45,118,50,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,182,120,153,1,5,0,64,0,48,53,49,45,118,52,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,140,243,88,87,5,0,64,0,48,56,49,116,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,245,103,98,231,1,0,16,1,48,56,49,98,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,155,77,96,76,2,0,16,1,48,56,49,97,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,169,119,199,180,3,0,32,0,48,56,49,97,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,217,200,42,39,3,0,32,0,48,56,49,97,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,164,154,75,70,4,0,32,0,48,56,49,97,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,89,55,23,78,4,0,32,0,48,56,49,97,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,128,109,254,233,4,0,32,0,48,56,49,97,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,154,178,34,138,4,0,32,0,48,56,49,97,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,234,186,182,20,5,0,64,0,118,101,110,100,101,116,116,97,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,48,78,172,251,0,0,0,8,102,108,95,48,50,45,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,149,96,227,154,1,0,16,1,102,108,95,48,48,45,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,72,192,140,192,1,0,16,1,102,108,95,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,68,40,189,128,1,0,16,1,102,108,95,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,133,176,116,148,1,0,16,1,102,106,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,155,223,174,233,2,0,16,1,118,116,109,97,97,48,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,59,225,48,3,3,0,32,0,118,116,109,97,97,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,27,163,23,194,4,0,32,0,118,116,109,97,97,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,142,249,31,9,4,0,32,0,118,116,109,97,97,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,204,233,19,183,5,0,32,0,118,116,109,97,97,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,129,191,48,26,5,0,32,0,102,106,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,53,162,152,110,6,0,64,0,102,106,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,181,162,205,57,7,0,64,0,102,106,45,50,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,66,87,4,101,8,0,0,8,112,97,108,49,54,108,56,97,46,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,143,142,116,238,9,0,0,8,112,97,108,49,54,108,56,98,46,49,51,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,218,59,161,109,9,0,0,8,112,97,108,49,54,108,56,98,46,49,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,152,224,169,98,9,0,0,8,112,97,108,49,54,108,56,98,46,49,52,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,170,104,103,3,9,0,0,8,112,97,108,49,54,108,56,98,46,49,52,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,206,31,66,191,9,0,0,8,72,23,4,0,1,0,0,0,85,0,147,0,248,191,2,0,56,250,6,0,1,0,0,0,189,247,146,0,184,160,2,0,88,149,7,0,1,0,0,0,190,247,146,0,136,224,1,0,56,210,6,0,1,0,0,0,80,0,147,0,192,135,2,0,152,122,6,0,1,0,0,0,81,0,147,0,96,82,2,0,192,72,6,0,1,0,0,0,82,0,147,0,32,56,2,0,24,163,6,0,1,0,0,0,83,0,147,0,240,108,2,0,200,110,3,0,1,0,0,0,84,0,147,0,152,30,2,0,176,223,1,0,1,0,0,0,184,247,146,0,72,198,1,0,24,198,1,0,1,0,0,0,185,247,146,0,40,167,1,0,120,189,1,0,1,0,0,0,186,247,146,0,200,149,1,0,192,209,1,0,1,0,0,0,187,247,146,0,24,182,1,0,224,22,1,0,1,0,0,0,188,247,146,0,56,126,1,0,88,212,3,0,1,0,0,0,128,219,146,0,40,185,3,0,232,75,4,0,1,0,0,0,87,0,147,0,216,70,1,0,64,23,5,0,9,0,0,0,202,5,147,0,32,58,1,0,104,20,5,0,9,0,0,0,200,5,147,0,32,58,1,0,216,16,5,0,9,0,0,0,201,5,147,0,32,58,1,0,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,2,151,38,156,1,0,16,1,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,161,3,99,221,1,0,16,1,112,105,99,49,54,99,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,76,45,0,0,13,146,179,189,2,0,16,1,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,27,124,84,90,3,0,32,0,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,141,19,164,75,4,0,32,0,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,151,198,26,154,4,0,32,0,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,113,24,86,187,5,0,32,0,49,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,102,59,110,52,5,0,32,0,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,23,155,239,205,5,0,32,0,49,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,140,103,218,190,5,0,32,0,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,217,133,49,130,5,0,32,0,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,71,50,159,20,5,0,32,0,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,188,26,139,56,5,0,32,0,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,55,186,238,50,5,0,32,0,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,79,119,191,86,6,0,64,0,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,207,31,133,137,6,0,64,0,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,106,15,191,215,6,0,64,0,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,247,252,167,6,0,64,0,57,51,117,116,97,48,49,48,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,94,239,134,196,1,0,16,1,57,51,117,116,97,48,49,49,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,247,120,137,151,1,0,16,1,57,51,117,116,97,48,48,57,46,49,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,131,132,241,103,2,0,16,1,57,51,117,116,97,48,52,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,56,5,186,156,3,0,32,0,57,51,117,116,97,48,50,46,50,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,250,237,79,136,3,0,32,0,57,51,117,116,97,48,51,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,165,132,132,129,3,0,32,0,57,51,117,116,97,48,49,46,50,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,65,232,77,54,3,0,32,0,57,51,117,116,97,48,53,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,251,11,100,94,4,0,32,0,57,51,117,116,97,48,55,46,54,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,54,208,189,103,5,0,32,0,57,51,117,116,97,48,54,46,54,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,228,38,76,41,5,0,32,0,57,51,117,116,97,48,56,46,54,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,205,187,80,61,6,0,64,0,168,86,7,0,1,0,0,0,8,0,147,0,248,191,2,0,24,38,7,0,1,0,0,0,7,0,147,0,184,160,2,0,56,210,6,0,1,0,0,0,0,0,147,0,192,135,2,0,24,163,6,0,1,0,0,0,1,0,147,0,240,108,2,0,152,122,6,0,1,0,0,0,2,0,147,0,96,82,2,0,192,72,6,0,1,0,0,0,3,0,147,0,32,56,2,0,200,110,3,0,1,0,0,0,4,0,147,0,152,30,2,0,120,89,3,0,1,0,0,0,5,0,147,0,232,10,2,0,120,74,3,0,1,0,0,0,6,0,147,0,152,138,8,0,40,246,1,0,1,0,0,0,112,247,146,0,64,246,1,0,144,236,1,0,1,0,0,0,111,247,146,0,136,224,1,0,176,223,1,0,1,0,0,0,104,247,146,0,72,198,1,0,192,209,1,0,1,0,0,0,105,247,146,0,24,182,1,0,24,198,1,0,1,0,0,0,106,247,146,0,40,167,1,0,120,189,1,0,1,0,0,0,107,247,146,0,200,149,1,0,224,22,1,0,1,0,0,0,108,247,146,0,56,126,1,0,160,14,1,0,1,0,0,0,109,247,146,0,32,101,1,0,176,9,1,0,1,0,0,0,110,247,146,0,96,32,8,0,88,212,3,0,1,0,0,0,64,219,146,0,40,185,3,0,32,77,1,0,1,0,0,0,9,0,147,0,216,70,1,0,16,17,8,0,1,0,0,0,113,247,146,0,224,12,8,0,117,119,48,48,49,48,48,54,46,117,52,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,157,30,174,61,1,0,16,1,117,119,48,48,49,48,48,55,46,117,52,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,2,231,33,92,1,0,16,1,98,112,45,117,45,48,48,50,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,170,186,108,147,3,0,32,0,98,112,45,117,45,48,48,49,46,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,72,60,129,135,3,0,32,0,117,119,48,48,51,46,117,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,235,24,247,226,6,0,64,0,57,49,48,45,98,48,49,46,99,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,35,67,158,61,1,0,16,1,57,49,48,45,98,48,50,46,100,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,233,130,76,210,1,0,16,1,57,49,48,45,97,48,53,46,100,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,137,241,174,235,2,0,16,1,57,49,48,45,97,49,57,46,108,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,220,255,201,45,3,0,32,0,57,49,48,45,97,50,48,46,108,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,206,141,41,164,3,0,32,0,57,49,48,45,97,48,55,46,106,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,78,166,67,139,4,0,32,0,57,49,48,45,97,48,56,46,106,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,38,152,130,195,4,0,32,0,57,49,48,45,97,48,57,46,106,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,25,181,16,238,4,0,32,0,57,49,48,45,97,49,48,46,106,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,195,176,251,207,4,0,32,0,57,49,48,45,97,49,49,46,108,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,29,88,165,23,5,0,32,0,57,49,48,45,97,49,50,46,108,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,181,63,118,57,5,0,32,0,57,49,48,45,97,49,51,46,108,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,79,90,178,102,5,0,32,0,57,49,48,45,97,49,52,46,108,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,18,212,251,9,5,0,32,0,57,49,48,45,97,49,53,46,109,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,183,251,91,109,6,0,32,0,57,49,48,45,97,49,54,46,109,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,61,140,111,95,6,0,32,0,57,49,48,45,97,49,55,46,109,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,255,196,62,31,6,0,32,0,57,49,48,45,97,49,56,46,109,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,41,41,196,253,6,0,32,0,57,49,48,45,97,48,54,46,99,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,201,153,250,40,7,0,64,0,57,49,48,45,97,50,49,46,102,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,188,15,70,100,0,0,0,8,117,99,95,104,48,95,97,46,105,99,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,218,202,23,158,1,0,16,1,117,99,95,108,48,95,97,46,105,99,51,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,8,50,78,74,1,0,16,1,117,99,95,104,49,46,105,99,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,66,151,215,121,1,0,16,1,117,99,95,108,49,46,105,99,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,129,21,33,55,1,0,16,1,117,99,95,115,104,48,46,105,99,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,3,27,202,240,2,0,16,1,117,99,95,115,108,48,46,105,99,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,35,23,102,209,2,0,16,1,117,99,95,99,48,46,105,99,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,54,154,65,106,3,0,32,0,117,99,95,99,49,46,105,99,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,199,236,3,215,3,0,32,0,117,99,95,99,50,46,105,99,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,198,122,57,150,3,0,32,0,117,99,95,99,51,46,105,99,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,13,209,7,93,3,0,32,0,117,99,95,48,51,48,46,105,99,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,94,119,247,151,4,0,32,0,117,99,95,48,50,48,46,105,99,51,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,101,29,11,94,4,0,32,0,117,99,95,48,49,48,46,105,99,51,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,179,36,194,189,4,0,32,0,117,99,95,48,48,48,46,105,99,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,236,218,38,117,4,0,32,0,117,99,95,100,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,233,85,40,11,5,0,64,0,112,114,103,50,46,114,111,109,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,234,128,171,114,1,0,16,1,112,114,103,49,46,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,85,79,160,39,1,0,16,1,97,117,100,105,111,49,46,114,111,109,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,180,242,113,199,2,0,16,1,97,117,100,105,111,50,46,114,111,109,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,71,83,247,199,3,0,16,1,103,102,120,51,46,114,111,109,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,151,194,46,253,5,0,32,0,103,102,120,53,46,114,111,109,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,96,170,7,99,5,0,32,0,103,102,120,52,46,114,111,109,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,80,49,143,113,5,0,32,0,103,102,120,54,46,114,111,109,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,126,5,126,175,5,0,32,0,18,0,0,0,255,255,255,0,0,0,0,0,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,18,0,0,0,254,0,2,0,192,76,8,0,18,0,0,0,1,48,48,0,64,26,4,0,18,0,0,0,1,48,32,0,232,251,3,0,19,0,0,0,254,0,8,0,32,4,2,0,19,0,0,0,1,7,0,0,56,111,8,0,19,0,0,0,1,7,1,0,88,241,7,0,19,0,0,0,1,7,2,0,240,12,2,0,19,0,0,0,1,7,3,0,160,36,8,0,19,0,0,0,1,7,7,0,208,239,7,0,19,0,0,0,1,7,6,0,120,187,7,0,19,0,0,0,1,7,5,0,136,23,1,0,19,0,0,0,1,7,4,0,88,217,6,0,19,0,0,0,254,0,4,0,128,129,4,0,19,0,0,0,1,24,16,0,208,75,4,0,19,0,0,0,1,24,24,0,8,49,4,0,19,0,0,0,1,24,8,0,152,21,4,0,19,0,0,0,1,24,0,0,72,246,3,0,19,0,0,0,254,0,4,0,72,202,5,0,19,0,0,0,1,96,64,0,80,246,3,0,19,0,0,0,1,96,96,0,248,38,7,0,19,0,0,0,1,96,32,0,112,212,3,0,19,0,0,0,1,96,0,0,248,160,5,0,20,0,0,0,254,0,2,0,144,212,8,0,20,0,0,0,1,1,1,0,96,135,7,0,20,0,0,0,1,1,0,0,152,182,7,0,20,0,0,0,254,0,2,0,200,30,2,0,20,0,0,0,1,2,2,0,120,97,1,0,20,0,0,0,1,2,0,0,96,19,1,0,20,0,0,0,254,0,8,0,64,37,5,0,20,0,0,0,1,28,28,0,248,74,6,0,20,0,0,0,1,28,16,0,208,39,8,0,20,0,0,0,1,28,24,0,232,33,8,0,20,0,0,0,1,28,12,0,232,28,8,0,20,0,0,0,1,28,8,0,216,24,8,0,20,0,0,0,1,28,4,0,8,21,8,0,20,0,0,0,1,28,20,0,208,17,8,0,20,0,0,0,1,28,0,0,120,7,5,0,20,0,0,0,254,0,2,0,168,234,7,0,20,0,0,0,1,128,128,0,96,135,7,0,20,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,102,116,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,137,100,233,8,1,0,16,1,102,116,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,69,196,101,103,1,0,16,1,102,116,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,153,44,0,40,1,0,16,1,102,116,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,38,6,234,55,1,0,16,1,102,117,49,49,45,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,16,15,242,101,2,0,16,1,109,97,98,45,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,189,170,14,102,3,0,32,0,102,117,48,53,45,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,18,212,52,129,3,0,32,0,102,117,48,54,45,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,69,74,145,47,3,0,32,0,109,97,98,45,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,25,214,128,16,4,0,32,0,109,97,98,45,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,29,35,183,88,5,0,32,0,109,97,98,45,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,157,59,5,118,5,0,32,0,102,116,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,37,92,70,227,5,0,32,0,102,116,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,101,213,241,199,5,0,32,0,102,116,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,185,87,54,110,5,0,32,0,102,116,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,96,53,184,205,5,0,32,0,102,117,49,50,45,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,242,101,29,45,6,0,64,0,102,117,49,51,45,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,34,86,82,184,7,0,64,0,109,98,55,49,49,52,104,46,49,56,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,15,183,69,54,8,0,0,8,50,50,52,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,69,228,151,118,1,0,16,1,50,50,52,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,88,87,237,238,2,0,32,0,50,50,52,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,171,100,218,247,3,0,32,0,50,50,52,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,251,187,9,76,3,0,32,0,50,50,52,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,41,65,158,197,3,0,32,0,50,50,52,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,83,46,83,181,3,0,32,0,50,50,52,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,150,111,77,54,4,0,16,1,50,50,52,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,136,240,87,255,5,0,64,0,50,50,52,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,153,101,210,122,5,0,64,0,117,97,50,45,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,49,229,63,92,1,0,16,1,117,97,50,45,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,78,168,60,120,2,0,16,1,117,97,50,45,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,214,50,117,139,11,0,32,0,117,97,50,45,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,122,65,36,17,11,0,32,0,117,97,50,45,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,186,219,216,153,11,0,32,0,117,97,50,45,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,40,13,69,110,11,0,32,0,117,97,50,45,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,115,141,58,125,4,0,32,0,117,97,50,45,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,86,31,190,91,4,0,32,0,117,97,50,45,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,7,105,229,252,4,0,32,0,117,97,50,45,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,233,234,81,164,4,0,32,0,117,97,50,45,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,87,96,78,98,6,0,64,0,117,97,50,45,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,100,255,104,48,6,0,64,0,97,102,101,103,97,46,117,106,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,29,112,135,145,1,0,16,1,97,102,101,103,97,46,117,106,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,156,255,140,254,1,0,16,1,97,102,101,103,97,46,115,117,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,136,220,82,58,2,0,16,1,97,102,101,103,97,46,117,106,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,146,158,67,63,3,0,32,0,97,102,101,103,97,46,117,105,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,146,143,124,35,4,0,32,0,97,102,101,103,97,46,117,98,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,216,32,127,40,5,0,32,0,97,102,101,103,97,46,117,98,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,25,248,37,245,5,0,32,0,97,102,101,103,97,46,115,117,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,243,101,214,145,6,0,64,0,97,102,101,103,97,46,115,117,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,6,195,225,48,6,0,64,0,97,115,120,57,48,54,101,48,49,46,117,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,225,102,98,201,1,0,0,0,97,115,120,57,48,55,101,48,49,46,117,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,2,181,103,124,1,0,0,0,97,115,120,57,48,49,109,48,49,46,117,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,68,63,189,234,2,0,0,0,97,115,120,57,48,50,109,48,49,46,117,51,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,200,48,33,195,2,0,0,0,97,115,120,57,48,51,109,48,49,46,117,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,34,195,134,95,2,0,0,0,97,115,120,57,48,52,109,48,49,46,117,52,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,102,11,126,199,2,0,0,0,97,115,120,57,48,53,109,48,49,46,117,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,169,217,157,141,3,0,0,0,50,48,48,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,72,48,200,40,1,0,16,1,50,48,48,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,178,2,84,154,2,0,32,0,50,48,48,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,26,244,123,142,3,0,32,0,50,48,48,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,206,168,101,90,3,0,32,0,50,48,48,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,172,148,153,4,0,16,1,50,48,48,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,210,72,253,0,5,0,64,0,50,48,48,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,49,203,42,8,5,0,64,0,50,48,48,45,118,51,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,83,160,188,122,5,0,64,0,50,48,48,45,118,52,46,118,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,2,73,123,108,5,0,64,0,116,102,114,99,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,238,0,19,114,0,0,16,1,116,102,114,99,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,43,49,213,108,0,0,16,1,116,102,114,99,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,87,5,245,99,0,0,16,1,116,102,114,99,117,57,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,120,57,165,186,0,0,32,0,116,102,114,99,117,57,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,115,197,166,113,0,0,32,0,116,102,114,99,117,49,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,158,229,228,77,0,0,32,0,116,102,114,99,117,49,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,181,158,71,198,0,0,32,0,116,102,114,99,117,49,49,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,59,15,33,223,0,0,32,0,116,102,114,99,117,49,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,121,29,29,246,0,0,32,0,116,102,114,99,117,49,49,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,253,18,8,247,0,0,32,0,116,102,114,99,117,49,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,22,167,78,71,0,0,32,0,116,102,114,99,117,49,51,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,162,48,115,72,0,0,32,0,116,102,114,99,117,49,51,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,109,91,126,58,0,0,32,0,116,102,114,99,117,49,54,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,101,74,161,44,0,0,16,1,116,102,114,99,117,49,56,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,213,199,199,57,0,0,64,0,116,102,114,99,117,49,55,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,51,3,202,96,0,0,64,0,22,0,0,0,255,255,0,0,0,0,0,0,23,0,0,0,255,255,6,0,0,0,0,0,0,0,0,0,254,0,8,0,184,40,2,0,22,0,0,0,1,7,0,0,72,223,6,0,22,0,0,0,1,7,1,0,224,67,5,0,22,0,0,0,1,7,2,0,216,36,5,0,22,0,0,0,1,7,3,0,8,7,5,0,22,0,0,0,1,7,4,0,152,160,5,0,22,0,0,0,1,7,5,0,144,127,5,0,22,0,0,0,1,7,6,0,88,219,3,0,22,0,0,0,1,7,7,0,224,189,3,0,0,0,0,0])
.concat([254,0,2,0,24,172,6,0,22,0,0,0,1,8,0,0,96,135,7,0,22,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,2,0,72,209,1,0,22,0,0,0,1,16,0,0,176,111,1,0,22,0,0,0,1,16,16,0,232,78,1,0,0,0,0,0,254,0,2,0,112,242,7,0,22,0,0,0,1,32,0,0,240,242,5,0,22,0,0,0,1,32,32,0,8,140,6,0,0,0,0,0,254,0,2,0,40,73,5,0,22,0,0,0,1,64,0,0,96,135,7,0,22,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,16,17,8,0,22,0,0,0,1,128,0,0,96,135,7,0,22,0,0,0,1,128,128,0,152,182,7,0,0,0,0,0,254,0,2,0,128,147,2,0,23,0,0,0,1,1,0,0,96,135,7,0,23,0,0,0,1,1,1,0,152,182,7,0,0,0,0,0,254,0,8,0,72,202,5,0,23,0,0,0,1,14,0,0,72,198,6,0,23,0,0,0,1,14,2,0,208,75,4,0,23,0,0,0,1,14,4,0,8,49,4,0,23,0,0,0,1,14,6,0,72,195,6,0,23,0,0,0,1,14,8,0,72,246,3,0,23,0,0,0,1,14,10,0,72,0,3,0,23,0,0,0,1,14,12,0,64,47,7,0,23,0,0,0,1,14,14,0,48,173,6,0,0,0,0,0,254,0,2,0,128,129,4,0,23,0,0,0,1,16,0,0,8,49,4,0,23,0,0,0,1,16,16,0,208,75,4,0,0,0,0,0,254,0,2,0,64,37,5,0,23,0,0,0,1,32,0,0,200,143,2,0,23,0,0,0,1,32,32,0,240,159,4,0,104,107,48,48,45,49,46,102,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,61,77,62,45,1,0,16,1,104,107,48,49,45,49,46,102,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,42,145,86,1,0,16,1,104,108,48,50,45,46,102,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,136,184,202,165,2,0,16,1,109,97,112,45,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,38,170,206,223,3,0,32,0,109,97,112,45,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,9,250,31,232,4,0,32,0,109,97,112,45,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,254,156,135,140,4,0,32,0,104,108,48,51,45,46,106,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,160,29,184,1,5,0,64,0,106,117,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,58,105,124,254,1,0,16,1,106,117,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,211,35,87,152,1,0,16,1,106,117,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,200,155,214,44,1,0,16,1,106,117,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,99,236,232,48,1,0,16,1,106,117,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,60,202,5,15,2,0,16,1,106,117,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,235,236,255,193,2,0,16,1,106,117,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,181,118,204,45,2,0,16,1,106,117,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,36,118,212,39,3,0,32,0,106,117,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,36,118,212,39,3,0,32,0,116,112,48,50,52,95,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,238,230,207,245,0,0,16,1,116,112,48,50,52,95,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,158,68,92,128,0,0,32,0,116,112,48,50,52,95,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,100,113,88,71,0,0,32,0,116,112,48,50,52,95,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,228,202,246,242,0,0,64,0,20,0,0,0,255,254,0,0,0,0,0,0,21,0,0,0,255,255,0,0,0,0,0,0,22,0,0,0,255,15,2,0,0,0,0,0,0,0,0,0,254,0,2,0,0,0,0,0,20,0,0,0,1,2,0,0,200,211,8,0,20,0,0,0,1,2,2,0,216,147,8,0,0,0,0,0,254,0,2,0,0,0,0,0,20,0,0,0,1,4,0,0,168,84,8,0,20,0,0,0,1,4,4,0,208,87,7,0,0,0,0,0,254,0,2,0,240,233,7,0,20,0,0,0,1,8,0,0,152,182,7,0,20,0,0,0,1,8,8,0,96,135,7,0,0,0,0,0,254,0,4,0,200,87,7,0,20,0,0,0,130,48,0,0,232,38,7,0,22,0,0,0,0,15,2,0,0,0,0,0,20,0,0,0,130,48,16,0,120,164,6,0,22,0,0,0,0,15,2,0,0,0,0,0,20,0,0,0,130,48,32,0,224,123,6,0,22,0,0,0,0,15,2,0,0,0,0,0,20,0,0,0,130,48,48,0,16,74,6,0,22,0,0,0,0,15,2,0,0,0,0,0,0,0,0,0,254,0,4,0,160,123,6,0,20,0,0,0,130,192,0,0,232,38,7,0,22,0,0,0,0,15,2,0,0,0,0,0,20,0,0,0,130,192,64,0,120,164,6,0,22,0,0,0,0,15,2,0,0,0,0,0,20,0,0,0,130,192,128,0,224,123,6,0,22,0,0,0,0,15,2,0,0,0,0,0,20,0,0,0,130,192,192,0,16,74,6,0,22,0,0,0,0,15,2,0,0,0,0,0,0,0,0,0,254,0,4,0,200,87,7,0,20,0,0,0,2,48,0,0,232,38,7,0,22,0,0,0,0,15,2,0,0,0,0,0,20,0,0,0,2,48,16,0,224,123,6,0,22,0,0,0,0,15,2,0,0,0,0,0,20,0,0,0,2,48,32,0,200,241,5,0,22,0,0,0,0,15,2,0,0,0,0,0,20,0,0,0,2,48,48,0,200,241,5,0,22,0,0,0,0,15,2,0,0,0,0,0,0,0,0,0,254,0,4,0,160,123,6,0,20,0,0,0,2,192,0,0,120,164,6,0,22,0,0,0,0,15,2,0,0,0,0,0,20,0,0,0,2,192,64,0,232,201,5,0,22,0,0,0,0,15,2,0,0,0,0,0,20,0,0,0,2,192,128,0,168,241,5,0,22,0,0,0,0,15,2,0,0,0,0,0,20,0,0,0,2,192,192,0,208,127,5,0,22,0,0,0,0,15,2,0,0,0,0,0,0,0,0,0,254,0,4,0,136,160,5,0,21,0,0,0,1,3,0,0,16,150,7,0,21,0,0,0,1,3,1,0,120,198,7,0,21,0,0,0,1,3,2,0,160,103,7,0,21,0,0,0,1,3,3,0,16,53,7,0,0,0,0,0,254,0,4,0,56,191,4,0,21,0,0,0,1,12,0,0,128,7,5,0,21,0,0,0,1,12,4,0,160,227,4,0,21,0,0,0,1,12,8,0,160,191,4,0,21,0,0,0,1,12,12,0,240,159,4,0,0,0,0,0,254,0,4,0,248,101,4,0,21,0,0,0,1,48,0,0,8,49,4,0,21,0,0,0,1,48,1,0,72,246,3,0,21,0,0,0,1,48,2,0,152,21,4,0,21,0,0,0,1,48,3,0,208,75,4,0,0,0,0,0,254,0,2,0,0,0,0,0,21,0,0,0,1,64,0,0,136,159,3,0,21,0,0,0,1,64,64,0,192,212,3,0,0,0,0,0,254,0,2,0,104,82,2,0,21,0,0,0,1,128,0,0,152,182,7,0,21,0,0,0,1,128,128,0,96,135,7,0,0,0,0,0,254,0,7,0,224,159,3,0,22,0,0,0,1,15,0,0,176,20,3,0,22,0,0,0,1,15,1,0,24,4,2,0,22,0,0,0,1,15,2,0,8,234,2,0,22,0,0,0,1,15,3,0,192,20,3,0,22,0,0,0,1,15,4,0,56,50,1,0,22,0,0,0,1,15,5,0,80,65,1,0,22,0,0,0,1,15,6,0,32,192,2,0,22,0,0,0,1,15,7,0,24,4,2,0,22,0,0,0,1,15,8,0,192,20,3,0,22,0,0,0,1,15,9,0,56,50,1,0,22,0,0,0,1,15,10,0,24,4,2,0,22,0,0,0,1,15,11,0,176,123,145,0,22,0,0,0,1,15,12,0,176,123,145,0,22,0,0,0,1,15,13,0,176,123,145,0,22,0,0,0,1,15,14,0,176,123,145,0,22,0,0,0,1,15,15,0,176,20,3,0,116,114,105,55,51,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,167,58,137,150,1,0,16,1,116,114,105,54,50,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,101,220,153,50,1,0,16,1,116,114,105,53,50,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,94,118,239,39,1,0,16,1,116,114,105,51,51,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,29,6,239,215,1,0,16,1,116,114,105,52,53,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,177,19,184,81,1,0,16,1,116,114,105,50,53,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,45,81,100,142,1,0,16,1,116,112,49,99,107,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,163,67,236,114,1,0,16,1,116,114,105,115,110,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,139,75,92,148,2,0,16,1,116,114,105,49,48,53,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,60,117,106,54,3,0,32,0,116,114,105,57,51,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,130,55,33,53,3,0,32,0,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,33,56,235,6,1,0,16,1,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,110,196,165,55,1,0,16,1,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,165,140,204,152,11,0,32,0,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,15,241,168,99,11,0,32,0,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,36,247,110,39,11,0,32,0,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,130,242,176,32,11,0,32,0,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,104,16,13,76,12,0,32,0,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,78,169,219,12,0,32,0,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,114,187,68,137,13,0,32,0,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,145,93,74,147,13,0,32,0,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,48,169,134,193,6,0,64,0,102,103,45,49,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,90,53,56,114,1,0,16,1,102,103,45,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,171,81,5,28,1,0,16,1,102,103,45,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,74,222,167,75,1,0,16,1,102,103,45,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,99,238,233,157,2,0,16,1,102,103,45,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,242,73,251,21,3,0,32,0,102,103,45,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,35,150,12,226,3,0,32,0,102,103,45,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,215,235,67,17,4,0,32,0,102,103,45,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,122,71,107,75,4,0,32,0,102,103,45,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,3,200,246,107,4,0,32,0,102,103,45,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,69,228,145,19,4,0,32,0,102,103,45,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,173,169,60,61,4,0,32,0,102,103,45,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,206,36,157,107,4,0,32,0,102,103,45,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,172,247,135,73,4,0,32,0,102,103,45,48,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,66,36,35,65,4,0,32,0,102,103,45,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,135,60,234,124,5,0,32,0,102,103,45,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,143,62,127,94,5,0,32,0,102,103,45,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,5,63,177,139,5,0,32,0,102,103,45,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,195,255,122,13,5,0,32,0,102,103,45,49,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,5,13,171,240,6,0,64,0,116,104,117,110,116,45,49,46,102,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,140,133,53,11,1,0,16,1,116,104,117,110,116,45,50,46,102,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,81,90,48,103,1,0,16,1,116,104,117,110,116,45,51,46,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,195,105,169,215,1,0,16,1,116,104,117,110,116,45,52,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,77,241,131,36,1,0,16,1,116,104,117,110,116,45,53,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,33,94,157,198,1,0,16,1,116,104,117,110,116,45,54,46,55,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,73,61,191,17,1,0,16,1,116,104,117,110,116,45,55,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,121,98,45,124,1,0,16,1,116,104,117,110,116,45,56,46,52,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,251,134,59,247,1,0,16,1,106,103,107,46,106,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,30,220,194,2,0,16,1,116,104,117,110,116,45,49,51,46,97,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,9,31,63,224,3,0,32,0,116,104,117,110,116,45,49,50,46,97,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,235,233,78,218,3,0,32,0,116,104,117,110,116,45,49,48,46,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,52,121,236,81,3,0,32,0,116,104,117,110,116,45,49,49,46,97,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,67,17,120,249,3,0,32,0,116,111,116,99,45,112,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,57,69,96,153,1,0,16,1,116,111,116,99,45,115,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,65,238,63,10,2,0,32,0,116,111,116,99,45,99,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,15,96,214,205,3,0,32,0,116,111,116,99,45,99,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,113,194,98,243,3,0,32,0,116,111,116,99,45,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,206,58,178,24,4,0,16,1,116,111,116,99,45,118,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,230,249,199,21,5,0,64,0,116,111,116,99,45,118,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,89,69,38,27,5,0,64,0,116,111,116,99,45,118,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,93,44,182,132,5,0,64,0,116,114,95,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,177,35,71,181,1,0,16,1,116,114,95,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,121,36,67,171,1,0,16,1,116,114,95,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,98,110,190,62,2,0,16,1,116,114,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,140,240,169,116,3,0,32,0,116,114,45,48,49,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,89,46,170,168,4,0,32,0,116,114,45,48,52,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,60,166,99,136,4,0,32,0,116,114,45,48,50,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,137,95,44,26,4,0,32,0,116,114,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,179,83,244,91,4,0,32,0,116,114,45,48,51,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,234,55,5,30,4,0,32,0,116,114,45,48,54,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,58,194,54,182,4,0,32,0,116,114,45,48,55,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,77,125,144,95,4,0,32,0,116,114,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,226,53,238,173,4,0,32,0,116,114,45,48,57,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,30,173,152,61,5,0,32,0,116,114,45,49,48,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,215,3,111,143,5,0,32,0,116,114,45,49,49,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,229,82,145,205,5,0,32,0,116,114,45,49,50,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,208,153,138,125,5,0,32,0,116,114,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,235,225,155,167,6,0,32,0,116,114,112,114,111,109,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,54,174,128,236,7,0,32,8,116,114,95,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,239,7,24,234,8,0,16,1,116,115,95,48,50,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,219,29,254,178,1,0,16,1,116,115,95,48,52,46,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,61,0,122,66,1,0,16,1,116,115,95,48,51,46,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,182,75,240,39,1,0,16,1,116,115,95,48,53,46,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,177,71,21,192,1,0,16,1,116,115,95,48,49,46,52,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,23,121,160,142,2,0,16,1,116,115,95,48,56,46,56,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,158,55,173,150,3,0,32,0,116,115,95,48,55,46,53,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,178,248,205,37,4,0,32,0,116,115,95,48,54,46,52,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,45,177,79,49,4,0,32,0,116,115,95,49,50,46,49,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,158,97,180,228,5,0,32,0,116,115,95,49,49,46,49,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,122,35,48,171,5,0,32,0,116,115,95,49,55,46,49,55,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,228,87,182,222,5,0,32,0,116,115,95,49,54,46,49,53,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,249,181,99,211,5,0,32,0,116,115,95,49,51,46,49,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,4,160,245,168,5,0,32,0,116,115,95,49,56,46,49,56,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,140,148,54,59,5,0,32,0,116,115,95,50,51,46,49,56,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,138,229,251,187,5,0,32,0,116,115,95,50,52,46,49,56,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,100,229,86,241,5,0,32,0,116,115,95,49,48,46,49,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,5,125,88,195,6,0,32,0,116,115,95,48,57,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,242,238,99,107,6,0,32,0,116,115,95,49,53,46,49,51,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,176,235,140,219,6,0,32,0,116,115,95,49,52,46,49,49,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,191,26,228,226,6,0,32,0,116,115,95,50,48,46,49,51,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,149,166,209,191,6,0,32,0,116,115,95,49,57,46,49,49,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,158,102,139,146,6,0,32,0,116,115,95,50,50,46,49,55,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,154,93,224,63,6,0,32,0,116,115,95,50,49,46,49,53,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,124,187,169,39,6,0,32,0,54,51,115,49,52,49,46,49,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,35,0,141,181,0,0,0,8,99,56,55,53,49,104,45,56,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,24,48,52,54,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,41,158,250,105,1,0,16,1,48,52,54,45,112,50,46,115,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,62,203,130,241,1,0,16,1,48,52,54,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,123,29,176,20,2,0,32,0,48,52,54,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,74,10,114,250,3,0,32,0,48,52,54,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,5,194,0,201,3,0,32,0,48,52,54,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,37,60,14,136,3,0,32,0,48,52,54,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,170,72,34,122,3,0,32,0,48,52,54,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,69,94,115,75,3,0,32,0,48,52,54,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,223,113,49,39,3,0,32,0,48,52,54,45,99,55,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,76,156,130,18,3,0,32,0,48,52,54,45,99,56,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,61,224,68,201,3,0,32,0,48,52,54,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,159,187,132,63,4,0,16,1,48,52,54,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,219,194,249,193,5,0,64,0,48,52,54,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,100,74,37,86,5,0,64,0,48,52,54,45,118,51,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,177,63,17,88,5,0,64,0,48,52,54,45,118,52,46,118,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,135,193,84,79,5,0,64,0,48,54,51,117,100,97,48,50,46,101,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,58,254,223,170,0,0,16,1,48,54,51,117,100,97,48,51,46,103,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,168,135,86,18,0,0,16,1,48,54,51,117,100,97,48,52,46,101,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,237,125,92,251,0,0,16,1,48,54,51,117,100,97,48,53,46,103,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,102,254,64,60,0,0,16,1,48,54,51,98,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,138,84,79,54,0,0,16,1,48,54,51,98,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,25,61,40,211,0,0,32,0,48,54,51,98,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,21,12,188,110,0,0,32,0,48,54,51,98,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,42,157,122,45,0,0,32,0,48,54,51,98,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,110,41,221,242,0,0,32,0,48,54,51,98,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,191,231,190,217,0,0,32,0,48,54,51,98,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,111,227,26,59,0,0,32,0,48,54,51,98,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,165,10,81,30,0,0,64,0,116,109,110,116,50,95,117,100,97,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,51,141,146,68,0,0,0,8,48,54,51,101,98,97,48,50,46,101,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,148,144,64,153,0,0,16,1,48,54,51,101,98,97,48,51,46,103,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,15,101,101,77,0,0,16,1,48,54,51,101,98,97,48,52,46,101,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,199,185,227,246,0,0,16,1,48,54,51,101,98,97,48,53,46,103,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,150,102,173,27,0,0,16,1,48,54,51,98,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,138,84,79,54,0,0,16,1,48,54,51,98,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,25,61,40,211,0,0,32,0,48,54,51,98,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,21,12,188,110,0,0,32,0,48,54,51,98,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,42,157,122,45,0,0,32,0,48,54,51,98,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,110,41,221,242,0,0,32,0,48,54,51,98,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,191,231,190,217,0,0,32,0,48,54,51,98,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,111,227,26,59,0,0,32,0,48,54,51,98,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,165,10,81,30,0,0,64,0,116,109,110,116,50,95,101,98,97,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,80,237,163,192,0,0,0,8,6,78,249,0,0,34,196,0,65,71,69,80,82,79,84,69,67,84,32,83,84,65,82,84,0,0,0,0,0,0,0,0,97,101,112,114,103,101,45,50,46,112,97,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,214,83,228,37,1,0,16,1,97,101,112,114,103,111,45,50,46,112,97,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,8,0,16,149,213,34,1,0,16,1,97,101,115,112,114,103,45,50,46,122,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,182,10,85,67,2,0,16,1,97,101,49,48,48,104,46,97,104,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,43,37,190,6,3,0,32,0,97,101,49,48,48,46,97,108,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,244,223,156,0,3,0,32,0,97,101,49,48,49,104,46,98,104,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,255,158,70,242,3,0,32,0,97,101,49,48,49,46,98,108,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,187,145,119,219,3,0,32,0,97,101,49,48,50,104,46,99,104,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,67,163,210,249,3,0,32,0,97,101,49,48,50,46,99,108,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,137,232,27,104,3,0,32,0,97,101,49,48,52,46,101,108,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,152,183,49,228,3,0,32,0,97,101,49,48,53,46,102,108,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,193,235,249,183,3,0,32,0,97,101,49,48,54,46,103,108,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,75,55,80,124,3,0,32,0,97,101,51,48,48,119,51,54,46,98,100,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,158,242,41,232,4,0,32,0,97,101,50,48,48,119,55,52,46,98,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,65,80,100,193,5,0,32,0,97,101,50,48,49,119,55,53,46,98,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,255,189,99,63,6,0,32,0,97,101,50,48,50,119,55,54,46,98,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,202,87,200,92,7,0,32,0,97,101,52,48,48,116,50,51,46,121,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,67,176,255,198,8,0,64,0,97,101,52,48,49,116,50,52,46,121,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,115,26,63,216,8,0,64,0,97,101,53,48,48,119,48,55,46,97,100,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,44,249,52,55,9,0,64,0,116,107,100,101,110,115,104,111,95,54,56,104,99,49,49,97,56,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,16,116,107,100,101,110,115,104,111,95,54,56,104,99,49,49,97,56,46,101,101,112,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,16,116,103,114,114,111,97,100,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,7,126,200,20,1,0,16,1,116,103,114,114,111,97,100,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,76,37,4,9,1,0,16,1,116,103,114,114,111,97,100,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,70,31,219,206,1,0,16,1,116,103,114,114,111,97,100,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,177,240,23,225,1,0,16,1,116,114,117,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,191,201,167,249,2,0,16,1,116,114,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,140,240,169,116,3,0,32,0,116,114,45,48,49,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,89,46,170,168,4,0,32,0,116,114,45,48,52,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,60,166,99,136,4,0,32,0,116,114,45,48,50,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,137,95,44,26,4,0,32,0,116,114,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,179,83,244,91,4,0,32,0,116,114,45,48,51,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,234,55,5,30,4,0,32,0,116,114,45,48,54,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,58,194,54,182,4,0,32,0,116,114,45,48,55,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,77,125,144,95,4,0,32,0,116,103,114,114,111,97,100,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,204,57,117,63,4,0,32,0,116,103,114,114,111,97,100,46,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,203,83,224,226,4,0,32,0,116,114,45,48,57,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,30,173,152,61,5,0,32,0,116,114,45,49,48,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,215,3,111,143,5,0,32,0,116,114,45,49,49,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,229,82,145,205,5,0,32,0,116,114,45,49,50,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,208,153,138,125,5,0,32,0,116,114,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,235,225,155,167,6,0,32,0,116,114,112,114,111,109,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,54,174,128,236,7,0,32,8,116,114,117,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,149,58,40,141,1,0,16,1,116,114,117,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,32,239,226,114,1,0,16,1,116,114,117,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,191,201,167,249,2,0,16,1,116,114,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,140,240,169,116,3,0,32,0,116,114,45,48,49,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,89,46,170,168,4,0,32,0,116,114,45,48,52,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,60,166,99,136,4,0,32,0,116,114,45,48,50,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,137,95,44,26,4,0,32,0,116,114,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,179,83,244,91,4,0,32,0,116,114,45,48,51,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,234,55,5,30,4,0,32,0,116,114,45,48,54,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,58,194,54,182,4,0,32,0,116,114,45,48,55,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,77,125,144,95,4,0,32,0,116,114,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,226,53,238,173,4,0,32,0,116,114,45,48,57,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,30,173,152,61,5,0,32,0,116,114,45,49,48,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,215,3,111,143,5,0,32,0,116,114,45,49,49,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,229,82,145,205,5,0,32,0,116,114,45,49,50,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,208,153,138,125,5,0,32,0,116,114,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,235,225,155,167,6,0,32,0,116,114,112,114,111,109,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,54,174,128,236,7,0,32,8,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,115,221,89,202,0,0,16,1,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,219,84,189,56,0,0,16,1,97,52,55,95,48,50,46,56,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,75,50,61,99,0,0,16,1,97,52,55,95,49,51,46,56,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,126,126,154,115,0,0,32,0,97,52,55,95,49,50,46,54,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,219,236,100,192,0,0,32,0,97,52,55,95,49,49,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,155,174,79,116,0,0,32,0,97,52,55,95,49,48,46,54,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,78,132,207,225,0,0,32,0,97,52,55,95,48,53,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,73,91,50,197,0,0,32,0,97,52,55,95,48,52,46,54,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,142,98,89,205,0,0,32,0,97,52,55,95,48,57,46,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,168,232,250,49,0,0,32,0,97,52,55,95,48,56,46,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,43,175,57,229,0,0,32,0,97,52,55,95,48,55,46,54,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,41,212,253,2,0,0,32,0,97,52,55,95,48,54,46,54,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,140,204,251,17,0,0,32,0,56,50,115,49,50,57,46,49,50,113,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,13,53,105,44,0,0,32,0,56,50,115,49,50,57,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,114,233,66,113,0,0,32,0,56,50,115,49,50,57,46,49,50,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,242,115,242,37,0,0,32,0,97,52,55,95,48,51,46,49,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,15,38,5,209,0,0,16,1,114,111,109,48,48,95,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,104,140,115,239,0,0,16,1,97,52,55,95,48,49,46,56,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,82,33,223,101,0,0,16,1,114,111,109,48,50,95,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,185,80,226,54,0,0,16,1,97,52,55,95,49,51,46,56,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,126,126,154,115,0,0,32,0,97,52,55,95,49,50,46,54,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,219,236,100,192,0,0,32,0,97,52,55,95,49,49,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,155,174,79,116,0,0,32,0,97,52,55,95,49,48,46,54,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,78,132,207,225,0,0,32,0,97,52,55,95,48,53,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,73,91,50,197,0,0,32,0,97,52,55,95,48,52,46,54,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,142,98,89,205,0,0,32,0,97,52,55,95,48,57,46,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,168,232,250,49,0,0,32,0,97,52,55,95,48,56,46,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,43,175,57,229,0,0,32,0,97,52,55,95,48,55,46,54,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,41,212,253,2,0,0,32,0,97,52,55,95,48,54,46,54,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,140,204,251,17,0,0,32,0,56,50,115,49,50,57,46,49,50,113,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,13,53,105,44,0,0,32,0,56,50,115,49,50,57,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,114,233,66,113,0,0,32,0,56,50,115,49,50,57,46,49,50,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,242,115,242,37,0,0,32,0,97,52,55,95,48,51,46,49,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,15,38,5,209,0,0,16,1,98,48,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,60,225,231,106,0,0,16,1,97,52,55,95,48,49,46,56,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,82,33,223,101,0,0,16,1,97,52,55,95,48,50,46,56,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,75,50,61,99,0,0,16,1,97,52,55,95,49,51,46,56,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,126,126,154,115,0,0,32,0,97,52,55,95,49,50,46,54,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,219,236,100,192,0,0,32,0,97,52,55,95,49,49,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,155,174,79,116,0,0,32,0,97,52,55,95,49,48,46,54,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,78,132,207,225,0,0,32,0,97,52,55,95,48,53,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,73,91,50,197,0,0,32,0,97,52,55,95,48,52,46,54,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,142,98,89,205,0,0,32,0,97,52,55,95,48,57,46,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,168,232,250,49,0,0,32,0,97,52,55,95,48,56,46,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,43,175,57,229,0,0,32,0,97,52,55,95,48,55,46,54,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,41,212,253,2,0,0,32,0,97,52,55,95,48,54,46,54,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,140,204,251,17,0,0,32,0,56,50,115,49,50,57,46,49,50,113,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,13,53,105,44,0,0,32,0,56,50,115,49,50,57,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,114,233,66,113,0,0,32,0,56,50,115,49,50,57,46,49,50,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,242,115,242,37,0,0,32,0,97,52,55,95,48,51,46,49,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,15,38,5,209,0,0,16,1,168,86,7,0,1,0,0,0,166,219,148,0,248,191,2,0,24,38,7,0,1,0,0,0,164,219,148,0,184,160,2,0,56,210,6,0,1,0,0,0,168,219,148,0,192,135,2,0,24,163,6,0,1,0,0,0,169,219,148,0,240,108,2,0,152,122,6,0,1,0,0,0,171,219,148,0,96,82,2,0,192,72,6,0,1,0,0,0,170,219,148,0,32,56,2,0,200,110,3,0,1,0,0,0,161,219,148,0,152,30,2,0,120,89,3,0,1,0,0,0,160,219,148,0,232,10,2,0,40,246,1,0,1,0,0,0,167,219,148,0,64,246,1,0,144,236,1,0,1,0,0,0,165,219,148,0,136,224,1,0,176,223,1,0,1,0,0,0,172,219,148,0,72,198,1,0,192,209,1,0,1,0,0,0,173,219,148,0,24,182,1,0,24,198,1,0,1,0,0,0,175,219,148,0,40,167,1,0,120,189,1,0,1,0,0,0,174,219,148,0,200,149,1,0,224,22,1,0,1,0,0,0,163,219,148,0,56,126,1,0,160,14,1,0,1,0,0,0,162,219,148,0,32,101,1,0,88,212,3,0,1,0,0,0,168,38,149,0,40,185,3,0,72,65,1,0,9,0,0,0,178,38,149,0,32,58,1,0,48,50,1,0,9,0,0,0,179,38,149,0,32,58,1,0,56,55,51,45,115,48,51,46,107,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,153,38,236,42,1,0,16,1,56,55,51,45,115,48,50,46,107,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,58,51,25,102,1,0,16,1,56,55,51,45,102,48,49,46,102,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,163,255,53,234,2,0,16,1,56,55,51,99,48,54,97,46,102,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,103,11,52,14,3,0,32,0,56,55,51,99,48,54,99,46,102,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,205,114,14,239,3,0,32,0,56,55,51,99,48,54,98,46,101,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,46,32,173,151,3,0,32,0,56,55,51,99,48,54,100,46,101,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,46,212,147,131,3,0,32,0,56,55,51,99,48,55,97,46,102,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,79,184,170,168,3,0,32,0,56,55,51,99,48,55,99,46,102,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,154,0,33,37,3,0,32,0,56,55,51,99,48,55,98,46,101,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,186,184,162,18,3,0,32,0,56,55,51,99,48,55,100,46,101,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,101,249,233,250,3,0,32,0,56,55,51,99,48,52,97,46,102,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,243,11,116,247,4,0,32,0,56,55,51,99,48,52,99,46,102,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,43,189,172,93,4,0,32,0,56,55,51,99,48,52,98,46,101,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,218,129,197,154,4,0,32,0,56,55,51,99,48,52,100,46,101,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,140,102,164,68,4,0,32,0,56,55,51,99,48,53,97,46,102,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,125,16,62,215,4,0,32,0,56,55,51,99,48,53,99,46,102,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,50,144,89,4,0,32,0,56,55,51,99,48,53,98,46,101,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,153,155,5,129,4,0,32,0,56,55,51,99,48,53,100,46,101,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,223,215,163,127,4,0,32,0,56,55,51,97,48,56,46,102,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,27,154,208,226,6,0,0,8,109,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,98,148,107,30,1,0,16,1,109,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,62,121,130,126,1,0,16,1,116,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,42,99,154,89,11,0,32,0,116,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,28,249,238,58,11,0,32,0,116,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,86,123,122,185,11,0,32,0,116,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,190,7,199,121,11,0,32,0,114,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,93,97,67,160,6,0,64,0,114,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,163,37,132,203,6,0,64,0,103,122,48,49,45,49,46,97,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,166,13,37,32,1,0,16,1,103,122,48,51,45,49,46,97,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,208,250,149,53,1,0,16,1,103,116,48,48,46,97,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,117,113,39,183,1,0,16,1,103,116,48,50,46,97,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,53,30,227,205,1,0,16,1,103,122,49,48,45,49,46,97,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,215,134,29,129,2,0,16,1,103,122,48,56,45,49,46,97,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,30,171,97,143,2,0,16,1,103,116,49,49,45,49,46,97,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,222,35,203,128,2,0,16,1,103,116,48,57,45,49,46,97,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,225,167,143,10,2,0,16,1,103,116,48,52,46,102,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,191,158,194,129,3,0,16,1,103,116,48,53,46,104,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,106,153,174,10,4,0,32,0,103,116,48,54,46,104,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,61,240,253,78,4,0,32,0,109,97,106,45,48,50,46,104,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,55,188,59,56,5,0,32,0,109,97,106,45,48,49,46,99,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,4,162,64,152,6,0,32,0,109,97,106,45,48,48,46,99,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,22,141,234,135,6,0,32,0,109,97,106,45,48,52,46,114,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,25,155,228,54,7,0,32,0,109,97,106,45,48,53,46,114,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,204,113,252,128,7,0,32,0,109,97,106,45,48,54,46,114,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,75,104,122,46,7,0,32,0,109,97,106,45,48,55,46,114,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,120,31,204,58,7,0,32,0,109,97,106,45,48,56,46,115,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,109,163,88,25,7,0,32,0,109,97,106,45,48,57,46,115,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,161,135,16,194,7,0,32,0,109,97,106,45,49,48,46,115,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,65,166,47,160,7,0,32,0,109,97,106,45,49,49,46,115,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,5,147,190,218,7,0,32,0,103,116,49,50,46,110,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,21,160,134,154,8,0,32,0,103,116,49,51,46,110,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,5,153,112,244,8,0,32,0,103,116,49,52,46,110,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,35,197,15,117,8,0,32,0,103,116,49,53,46,110,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,61,221,78,241,8,0,32,0,103,116,48,55,46,104,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,93,126,11,117,9,0,64,0,109,97,106,45,48,51,46,104,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,195,250,220,49,10,0,64,0,109,98,55,49,50,56,121,46,49,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,162,128,231,189,11,0,0,8,109,98,55,49,50,56,121,46,49,54,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,81,39,77,196,11,0,0,8,112,97,108,49,54,114,56,97,32,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,12,0,0,16,112,97,108,49,54,108,56,98,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,12,0,0,16,112,97,108,49,54,108,56,98,46,55,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,253,131,158,25,12,0,0,8,112,97,108,49,54,108,56,98,46,55,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,12,0,0,16,112,97,108,49,54,108,56,98,46,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,12,0,0,16,112,97,108,49,54,108,56,98,46,56,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,12,0,0,16,112,97,108,49,54,108,56,98,46,57,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,12,0,0,16,112,97,108,49,54,108,56,98,46,49,48,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,12,0,0,16,48,55,51,45,106,97,45,107,48,50,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,45,139,12,0,0,16,1,48,55,51,45,106,97,45,107,48,51,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,39,180,3,56,0,0,16,1,48,55,51,45,99,48,49,46,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,60,232,235,68,0,0,16,1,48,55,51,45,99,48,54,46,49,54,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,66,43,226,36,0,0,32,0,48,55,51,45,99,48,53,46,49,50,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,95,147,42,149,0,0,32,0])
.concat([48,55,51,45,99,48,55,46,55,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,56,63,233,20,0,0,32,0,48,55,51,45,99,48,56,46,51,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,171,179,250,9,0,0,32,0,48,55,51,45,98,48,52,46,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,11,122,40,5,0,0,64,0,116,104,110,100,114,120,50,106,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,155,121,180,131,0,0,0,8,48,55,51,45,97,97,45,109,48,50,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,192,76,91,91,0,0,16,1,48,55,51,45,97,97,45,109,48,51,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,168,53,4,50,0,0,16,1,48,55,51,45,99,48,49,46,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,60,232,235,68,0,0,16,1,48,55,51,45,99,48,54,46,49,54,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,66,43,226,36,0,0,32,0,48,55,51,45,99,48,53,46,49,50,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,95,147,42,149,0,0,32,0,48,55,51,45,99,48,55,46,55,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,56,63,233,20,0,0,32,0,48,55,51,45,99,48,56,46,51,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,171,179,250,9,0,0,32,0,48,55,51,45,98,48,52,46,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,11,122,40,5,0,0,64,0,116,104,110,100,114,120,50,97,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,61,137,247,0,0,0,8,108,116,95,100,45,104,48,106,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,24,138,33,220,1,0,16,1,108,116,95,100,45,108,48,106,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,129,63,154,174,1,0,16,1,108,116,95,100,45,104,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,72,61,221,215,1,0,16,1,108,116,95,100,45,108,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,216,59,75,185,1,0,16,1,108,116,95,100,45,115,104,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,79,34,91,175,2,0,16,1,108,116,95,100,45,115,108,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,195,170,63,203,2,0,16,1,108,116,95,55,97,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,80,253,160,173,3,0,32,0,108,116,95,55,98,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,131,104,89,210,3,0,32,0,108,116,95,55,100,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,239,55,230,45,3,0,32,0,108,116,95,55,104,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,205,133,101,159,3,0,32,0,108,116,95,55,106,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,62,134,248,186,4,0,32,0,108,116,95,55,108,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,175,80,253,64,4,0,32,0,108,116,95,55,115,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,223,112,233,200,4,0,32,0,108,116,95,55,121,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,8,103,67,245,4,0,32,0,108,116,95,56,97,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,162,98,119,53,5,0,64,0,103,108,111,98,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,234,11,157,130,1,0,16,1,103,108,111,98,46,117,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,40,102,222,49,1,0,16,1,103,108,111,98,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,96,130,104,83,2,0,32,0,103,108,111,98,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,199,89,31,5,2,0,32,0,103,108,111,98,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,39,117,97,31,3,0,32,0,103,108,111,98,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,105,167,250,40,3,0,32,0,56,50,115,49,50,54,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,134,204,169,4,0,64,0,56,50,115,49,50,54,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,15,0,0,0,255,255,255,0,0,0,0,0,16,0,0,0,255,255,255,0,0,0,0,0,17,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,15,0,0,0,1,128,128,0,120,97,1,0,15,0,0,0,1,128,0,0,96,19,1,0,0,0,0,0,254,0,4,0,128,129,4,0,16,0,0,0,1,3,3,0,8,49,4,0,16,0,0,0,1,3,2,0,152,21,4,0,16,0,0,0,1,3,1,0,72,246,3,0,16,0,0,0,1,3,0,0,72,0,3,0,0,0,0,0,254,0,8,0,72,202,5,0,16,0,0,0,1,28,28,0,160,246,1,0,16,0,0,0,1,28,24,0,160,203,8,0,16,0,0,0,1,28,20,0,80,246,3,0,16,0,0,0,1,28,16,0,248,38,7,0,16,0,0,0,1,28,12,0,48,123,8,0,16,0,0,0,1,28,8,0,8,117,8,0,16,0,0,0,1,28,4,0,24,99,5,0,16,0,0,0,1,28,0,0,248,160,5,0,0,0,0,0,254,0,2,0,168,234,7,0,16,0,0,0,1,32,32,0,96,135,7,0,16,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,116,104,101,103,108,111,98,51,46,117,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,246,250,156,150,0,0,16,1,116,104,101,103,108,111,98,51,46,117,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,10,1,108,142,0,0,16,1,116,104,101,103,108,111,98,51,46,117,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,200,165,28,28,0,0,16,1,116,104,101,103,108,111,98,51,46,117,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,34,157,75,165,0,0,16,1,116,104,101,103,108,111,98,51,46,117,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,169,130,111,90,0,0,16,1,116,104,101,103,108,111,98,51,46,117,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,219,53,249,114,0,0,16,1,116,104,101,103,108,111,98,51,46,117,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,173,83,219,129,0,0,16,1,116,104,101,103,108,111,98,51,46,117,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,89,99,46,14,0,0,16,1,56,50,115,49,50,51,46,117,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,197,221,246,244,0,0,32,0,54,49,49,50,57,51,46,117,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,206,247,10,135,0,0,16,1,54,49,49,50,57,51,46,117,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,130,151,103,163,0,0,16,1,54,49,49,50,57,51,46,117,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,26,157,73,103,0,0,16,1,54,49,49,50,57,51,46,117,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,172,58,229,85,0,0,16,1,54,49,49,50,57,51,46,117,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,67,215,74,198,0,0,16,1,54,49,49,50,57,51,46,117,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,3,50,60,249,0,0,16,1,54,49,49,50,57,51,46,117,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,24,0,234,206,0,0,16,1,54,49,49,50,57,51,46,117,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,155,63,200,106,0,0,16,1,56,50,115,49,50,51,46,117,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,197,221,246,244,0,0,32,0,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,68,122,136,243,1,0,16,1,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,246,71,194,101,1,0,16,1,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,55,248,89,185,2,0,16,1,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,195,38,92,0,3,0,32,0,56,57,48,53,48,45,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,135,214,215,100,4,0,32,0,56,57,48,53,48,45,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,164,63,219,36,5,0,32,0,56,57,48,53,48,45,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,33,84,113,127,5,0,32,0,56,57,48,53,48,45,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,57,76,238,17,6,0,64,0,56,57,48,53,48,45,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,171,82,53,137,7,0,64,0,50,49,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,234,239,213,252,0,0,0,8,50,50,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,108,184,219,207,0,0,0,8,50,51,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,244,105,53,252,0,0,0,8,50,52,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,254,9,160,224,0,0,0,8,50,53,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,254,9,160,224,0,0,0,8,50,54,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,62,179,191,12,0,0,0,8,121,111,44,32,98,114,111,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,72,219,167,60,0,0,16,1,114,45,116,121,112,101,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,86,81,206,145,0,0,16,1,112,111,119,101,114,32,103,111,108,102,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,67,56,29,237,0,0,16,1,106,97,99,107,105,101,32,99,104,97,110,39,115,32,97,99,116,105,111,110,32,107,117,110,103,32,102,117,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,147,97,47,157,0,0,16,1,98,111,110,107,32,105,105,105,32,45,32,98,111,110,107,39,115,32,98,105,103,32,97,100,118,101,110,116,117,114,101,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,216,118,63,90,0,0,16,1,98,111,110,107,39,115,32,114,101,118,101,110,103,101,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,154,15,37,20,0,0,16,1,105,99,49,55,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,218,94,80,26,1,0,16,1,105,99,49,54,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,223,196,123,21,1,0,16,1,105,99,54,52,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,144,178,233,195,3,0,32,0,105,99,54,51,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,143,54,154,222,3,0,32,0,105,99,54,50,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,10,232,200,3,0,32,0,97,55,53,45,48,55,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,137,178,248,10,4,0,32,0,97,55,53,45,48,56,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,251,2,176,171,4,0,32,0,97,55,53,45,48,57,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,119,194,198,167,4,0,32,0,13,0,0,0,255,255,240,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,13,0,0,0,1,16,16,0,120,97,1,0,13,0,0,0,1,16,0,0,96,19,1,0,0,0,0,0,254,0,2,0,168,234,7,0,13,0,0,0,1,32,32,0,96,135,7,0,13,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,4,0,32,4,2,0,13,0,0,0,1,192,192,0,128,230,7,0,13,0,0,0,1,192,128,0,184,164,6,0,13,0,0,0,1,192,64,0,136,23,1,0,13,0,0,0,1,192,0,0,32,15,1,0,99,51,53,45,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,255,66,110,250,2,0,0,0,99,51,53,45,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,57,133,189,174,2,0,0,0,99,51,53,45,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,39,153,142,18,2,0,0,0,99,51,53,45,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,25,163,167,93,2,0,0,0,99,51,53,45,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,251,99,92,120,9,0,0,0,98,55,50,45,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,235,68,52,132,0,0,0,8,98,55,50,45,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,110,194,74,162,0,0,0,8,116,102,106,45,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,167,111,26,177,1,0,16,1,116,102,106,45,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,237,167,106,108,1,0,16,1,116,102,106,45,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,126,222,232,253,1,0,16,1,116,102,106,45,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,20,116,152,219,1,0,16,1,116,102,98,45,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,99,60,44,85,1,0,16,1,116,102,98,45,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,199,148,11,106,1,0,16,1,116,102,45,48,48,49,46,49,55,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,56,65,107,235,2,0,16,1,116,102,98,45,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,103,163,154,63,9,0,16,1,57,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,188,124,111,188,3,0,32,0,53,46,49,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,253,61,210,37,4,0,32,0,52,46,49,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,39,254,176,185,4,0,32,0,49,53,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,224,216,68,33,5,0,32,0,49,52,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,158,92,79,116,5,0,32,0,116,102,106,45,49,50,46,55,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,161,133,64,215,6,0,32,8,116,102,106,45,49,51,46,57,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,197,160,138,20,6,0,32,8,110,56,50,115,49,50,57,97,110,46,49,49,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,87,71,36,129,7,0,0,8,20,0,0,0,255,254,0,0,0,0,0,0,21,0,0,0,255,67,0,0,0,0,0,0,22,0,0,0,255,15,0,0,0,0,0,0,0,0,0,0,254,0,2,0,0,0,0,0,20,0,0,0,1,2,0,0,200,211,8,0,20,0,0,0,1,2,2,0,216,147,8,0,0,0,0,0,254,0,2,0,0,0,0,0,20,0,0,0,1,4,0,0,168,84,8,0,20,0,0,0,1,4,4,0,208,87,7,0,0,0,0,0,254,0,2,0,240,233,7,0,20,0,0,0,1,8,0,0,152,182,7,0,20,0,0,0,1,8,8,0,96,135,7,0,0,0,0,0,254,0,4,0,200,87,7,0,20,0,0,0,130,48,0,0,232,38,7,0,22,0,0,0,0,15,2,0,0,0,0,0,20,0,0,0,130,48,16,0,120,164,6,0,22,0,0,0,0,15,2,0,0,0,0,0,20,0,0,0,130,48,32,0,224,123,6,0,22,0,0,0,0,15,2,0,0,0,0,0,20,0,0,0,130,48,48,0,16,74,6,0,22,0,0,0,0,15,2,0,0,0,0,0,0,0,0,0,254,0,4,0,160,123,6,0,20,0,0,0,130,192,0,0,232,38,7,0,22,0,0,0,0,15,2,0,0,0,0,0,20,0,0,0,130,192,64,0,120,164,6,0,22,0,0,0,0,15,2,0,0,0,0,0,20,0,0,0,130,192,128,0,224,123,6,0,22,0,0,0,0,15,2,0,0,0,0,0,20,0,0,0,130,192,192,0,16,74,6,0,22,0,0,0,0,15,2,0,0,0,0,0,0,0,0,0,254,0,4,0,200,87,7,0,20,0,0,0,2,48,0,0,232,38,7,0,22,0,0,0,0,15,2,0,0,0,0,0,20,0,0,0,2,48,16,0,224,123,6,0,22,0,0,0,0,15,2,0,0,0,0,0,20,0,0,0,2,48,32,0,200,241,5,0,22,0,0,0,0,15,2,0,0,0,0,0,20,0,0,0,2,48,48,0,200,241,5,0,22,0,0,0,0,15,2,0,0,0,0,0,0,0,0,0,254,0,4,0,160,123,6,0,20,0,0,0,2,192,0,0,120,164,6,0,22,0,0,0,0,15,2,0,0,0,0,0,20,0,0,0,2,192,64,0,232,201,5,0,22,0,0,0,0,15,2,0,0,0,0,0,20,0,0,0,2,192,128,0,168,241,5,0,22,0,0,0,0,15,2,0,0,0,0,0,20,0,0,0,2,192,192,0,208,127,5,0,22,0,0,0,0,15,2,0,0,0,0,0,0,0,0,0,254,0,4,0,136,160,5,0,21,0,0,0,1,3,0,0,16,150,7,0,21,0,0,0,1,3,1,0,120,198,7,0,21,0,0,0,1,3,2,0,160,103,7,0,21,0,0,0,1,3,3,0,16,53,7,0,0,0,0,0,254,0,2,0,0,0,0,0,21,0,0,0,1,64,0,0,136,159,3,0,21,0,0,0,1,64,64,0,248,142,8,0,0,0,0,0,254,0,9,0,136,160,5,0,22,0,0,0,1,15,0,0,176,20,3,0,22,0,0,0,1,15,1,0,24,4,2,0,22,0,0,0,1,15,2,0,8,234,2,0,22,0,0,0,1,15,3,0,192,20,3,0,22,0,0,0,1,15,4,0,56,50,1,0,22,0,0,0,1,15,5,0,80,65,1,0,22,0,0,0,1,15,6,0,216,122,8,0,22,0,0,0,1,15,7,0,72,116,8,0,22,0,0,0,1,15,8,0,48,62,3,0,22,0,0,0,1,15,9,0,176,20,3,0,22,0,0,0,1,15,10,0,176,20,3,0,22,0,0,0,1,15,11,0,176,20,3,0,22,0,0,0,1,15,12,0,176,20,3,0,22,0,0,0,1,15,13,0,176,20,3,0,22,0,0,0,1,15,14,0,176,20,3,0,22,0,0,0,1,15,15,0,176,20,3,0,0,0,0,0,116,100,95,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,62,45,166,232,1,0,16,1,116,100,95,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,4,170,161,47,1,0,16,1,116,100,95,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,5,117,238,153,2,0,16,1,116,100,95,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,105,220,68,81,3,0,32,0,116,100,95,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,77,138,190,193,4,0,32,0,116,100,95,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,31,55,62,44,4,0,32,0,116,100,95,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,93,236,208,191,5,0,32,0,116,100,95,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,235,116,224,182,5,0,32,0,116,100,95,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,191,196,246,246,6,0,64,0,54,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,175,140,52,202,1,0,16,1,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,97,190,112,184,2,0,16,1,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,250,170,136,212,3,0,32,0,119,119,57,51,48,57,49,52,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,93,198,104,249,4,0,32,0,119,119,57,51,48,57,49,55,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,203,115,136,185,5,0,32,0,119,119,57,51,48,57,49,56,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,178,132,238,186,5,0,32,0,119,119,57,51,48,57,49,54,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,230,95,195,7,6,0,64,0,119,119,57,51,48,57,49,53,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,171,91,2,130,7,0,64,0,57,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,162,83,86,67,0,0,0,8,49,48,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,73,211,234,230,0,0,0,8,116,104,117,110,100,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,49,40,208,237,1,0,16,1,116,104,117,110,100,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,229,47,25,82,1,0,16,1,57,49,48,55,48,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,116,61,73,191,2,0,16,1,57,49,48,55,48,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,32,89,54,254,3,0,32,0,57,49,48,55,48,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,38,232,189,208,4,0,32,0,57,49,48,55,48,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,254,194,237,62,5,0,32,0,57,49,48,55,48,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,117,104,174,6,0,64,0,57,49,48,55,48,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,62,164,254,236,7,0,64,0,57,49,48,55,48,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,108,184,219,207,0,0,0,8,57,49,48,55,48,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,73,211,234,230,0,0,0,8,49,45,117,57,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,218,48,238,163,1,0,16,1,50,45,117,57,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,251,228,183,48,1,0,16,1,51,45,117,49,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,228,196,103,161,2,0,16,1,117,56,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,30,37,142,144,3,0,32,0,117,56,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,166,11,41,196,3,0,32,0,117,56,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,235,154,125,64,3,0,32,0,117,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,233,35,88,233,4,0,32,0,117,49,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,169,135,147,232,5,0,64,0,117,49,50,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,35,203,240,12,6,0,64,0,101,115,100,50,46,99,117,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,61,110,221,182,1,0,16,1,101,115,100,49,46,99,117,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,244,242,192,182,1,0,16,1,101,115,100,51,46,115,117,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,92,204,142,212,2,0,16,1,120,106,117,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,215,185,153,249,3,0,32,0,120,106,117,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,207,2,147,103,3,0,32,0,120,106,117,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,247,159,245,1,3,0,32,0,120,106,117,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,195,202,106,85,3,0,32,0,120,106,117,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,199,216,194,236,3,0,32,0,102,117,51,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,51,248,243,132,4,0,32,0,102,117,51,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,67,245,145,191,4,0,32,0,101,115,100,52,46,115,117,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,45,176,223,242,5,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,115,121,115,45,112,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,30,190,173,164,1,0,16,1,115,121,115,45,115,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,142,242,116,71,2,0,32,0,115,121,115,45,99,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,172,10,102,117,3,0,32,0,115,121,115,45,99,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,172,10,102,117,3,0,32,0,115,121,115,45,109,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,100,222,105,118,4,0,16,1,115,121,115,45,118,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,73,248,75,80,5,0,64,0,101,115,100,46,99,117,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,38,193,224,41,1,0,16,1,101,115,100,46,99,117,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,139,32,112,16,1,0,16,1,101,115,100,51,46,115,117,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,190,125,233,128,2,0,16,1,101,115,100,49,46,106,117,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,231,197,252,23,3,0,32,0,101,115,100,50,46,106,117,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,242,82,23,156,3,0,32,0,101,115,100,51,46,106,117,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,146,192,217,232,3,0,32,0,101,115,100,52,46,106,117,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,48,177,225,189,3,0,32,0,101,115,100,53,46,106,117,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,3,127,194,210,3,0,32,0,102,117,51,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,197,151,88,197,4,0,32,0,102,117,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,162,166,23,113,4,0,32,0,97,116,50,55,99,48,50,48])
.concat([46,115,117,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,194,254,62,196,5,0,64,0,115,118,98,45,100,117,56,46,49,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,97,210,213,255,1,0,16,1,115,118,98,45,100,117,53,46,49,51,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,245,67,233,193,1,0,16,1,115,118,98,45,100,117,57,46,49,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,46,74,224,112,1,0,16,1,115,118,98,45,100,117,54,46,49,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,43,135,179,172,1,0,16,1,115,112,115,95,49,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,136,150,184,72,2,0,16,1,115,112,115,95,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,117,190,10,26,3,0,32,0,115,112,115,95,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,117,144,39,54,3,0,32,0,115,112,115,95,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,217,231,237,124,3,0,32,0,115,112,115,95,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,215,230,37,100,3,0,32,0,115,112,115,95,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,137,21,43,161,3,0,32,0,115,112,115,95,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,18,29,103,176,4,0,32,0,115,112,115,95,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,126,149,49,194,4,0,32,0,115,112,115,95,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,9,119,75,144,4,0,32,0,115,112,115,95,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,172,255,48,84,4,0,32,0,115,112,115,95,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,120,98,74,65,4,0,32,0,97,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,225,223,146,221,4,0,32,0,115,112,115,95,50,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,109,32,231,201,5,0,32,0,115,112,115,95,50,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,5,200,21,123,5,0,32,0,115,112,115,95,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,50,242,194,138,5,0,32,0,115,112,115,95,50,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,227,84,199,252,5,0,32,0,115,112,115,95,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,12,143,108,77,5,0,32,0,115,112,115,95,50,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,66,139,210,157,5,0,32,0,115,112,115,95,49,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,54,15,109,69,6,0,64,0,115,112,115,95,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,95,65,63,243,6,0,64,0,97,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,249,59,171,219,1,0,16,1,97,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,111,213,175,146,1,0,16,1,97,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,74,156,248,216,1,0,16,1,97,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,203,213,61,222,1,0,16,1,115,112,115,95,49,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,136,150,184,72,2,0,16,1,115,112,115,95,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,117,190,10,26,3,0,32,0,115,112,115,95,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,117,144,39,54,3,0,32,0,115,112,115,95,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,217,231,237,124,3,0,32,0,115,112,115,95,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,215,230,37,100,3,0,32,0,115,112,115,95,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,137,21,43,161,3,0,32,0,115,112,115,95,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,18,29,103,176,4,0,32,0,115,112,115,95,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,126,149,49,194,4,0,32,0,115,112,115,95,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,9,119,75,144,4,0,32,0,115,112,115,95,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,172,255,48,84,4,0,32,0,115,112,115,95,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,120,98,74,65,4,0,32,0,97,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,225,223,146,221,4,0,32,0,115,112,115,95,50,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,109,32,231,201,5,0,32,0,115,112,115,95,50,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,5,200,21,123,5,0,32,0,115,112,115,95,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,50,242,194,138,5,0,32,0,115,112,115,95,50,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,227,84,199,252,5,0,32,0,115,112,115,95,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,12,143,108,77,5,0,32,0,115,112,115,95,50,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,66,139,210,157,5,0,32,0,115,112,115,95,49,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,54,15,109,69,6,0,64,0,115,112,115,95,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,95,65,63,243,6,0,64,0,115,118,99,45,112,49,115,112,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,47,144,1,38,1,0,16,1,115,118,99,45,112,50,115,112,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,5,51,161,12,1,0,16,1,115,118,99,45,115,49,115,112,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,57,100,61,35,2,0,32,0,115,118,99,45,99,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,137,107,130,167,3,0,32,0,115,118,99,45,99,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,137,32,60,237,3,0,32,0,115,118,99,45,99,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,99,128,237,113,3,0,32,0,115,118,99,45,99,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,45,222,11,37,3,0,32,0,115,118,99,45,99,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,130,192,23,152,3,0,32,0,115,118,99,45,99,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,127,48,192,43,3,0,32,0,115,118,99,45,99,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,185,215,88,67,3,0,32,0,115,118,99,45,99,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,229,238,109,54,3,0,32,0,115,118,99,45,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,195,40,67,128,4,0,16,1,115,118,99,45,118,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,135,114,9,181,5,0,64,0,115,118,99,45,118,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,31,57,58,189,5,0,64,0,115,118,99,45,118,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,55,11,252,51,5,0,64,0,115,118,99,45,118,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,160,73,152,170,5,0,64,0,115,118,99,45,112,50,112,108,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,226,172,49,114,1,0,16,1,115,118,99,45,112,49,112,108,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,68,65,180,22,1,0,16,1,115,118,99,45,115,49,112,108,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,94,115,60,202,2,0,32,0,115,118,99,45,99,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,137,107,130,167,3,0,32,0,115,118,99,45,99,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,137,32,60,237,3,0,32,0,115,118,99,45,99,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,99,128,237,113,3,0,32,0,115,118,99,45,99,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,45,222,11,37,3,0,32,0,115,118,99,45,99,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,130,192,23,152,3,0,32,0,115,118,99,45,99,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,127,48,192,43,3,0,32,0,115,118,99,45,99,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,185,215,88,67,3,0,32,0,115,118,99,45,99,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,229,238,109,54,3,0,32,0,115,118,99,45,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,195,40,67,128,4,0,16,1,115,118,99,45,118,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,135,114,9,181,5,0,64,0,115,118,99,45,118,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,31,57,58,189,5,0,64,0,115,118,99,45,118,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,55,11,252,51,5,0,64,0,115,118,99,45,118,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,160,73,152,170,5,0,64,0,101,112,114,45,53,50,50,54,97,46,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,104,35,176,51,1,0,16,1,101,112,114,45,53,50,50,55,97,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,80,127,230,165,1,0,16,1,101,112,114,45,53,50,50,56,46,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,138,130,151,165,1,0,16,1,101,112,114,45,53,50,50,50,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,7,114,165,10,2,0,16,1,101,112,114,45,53,50,50,53,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,129,254,113,229,3,0,32,0,101,112,114,45,53,50,50,52,46,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,60,249,48,97,3,0,32,0,101,112,114,45,53,50,50,51,46,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,78,0,3,59,3,0,32,0,101,112,114,45,53,50,50,57,46,53,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,211,62,45,238,4,0,32,0,101,112,114,45,53,50,51,48,46,53,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,80,75,74,240,4,0,32,0,112,114,45,53,50,50,48,46,49,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,229,140,12,123,5,0,32,0,112,114,45,53,50,49,57,46,56,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,203,2,75,29,5,0,32,0,112,114,45,53,50,50,49,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,79,103,186,137,0,0,0,8,117,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,36,19,20,192,0,0,16,1,117,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,40,129,190,88,0,0,16,1,117,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,22,140,8,109,0,0,16,1,117,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,3,130,118,178,0,0,16,1,117,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,70,143,108,151,0,0,16,1,117,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,144,82,15,52,0,0,16,1,117,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,137,213,59,23,0,0,16,1,117,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,13,116,91,212,0,0,16,1,56,50,115,49,50,51,46,117,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,197,221,246,244,0,0,32,0,48,49,49,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,68,249,199,1,0,16,1,115,112,50,46,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,175,79,26,129,1,0,16,1,48,49,49,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,150,219,95,236,2,0,32,0,48,49,49,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,87,190,231,202,3,0,32,0,48,49,49,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,134,217,41,158,3,0,32,0,48,49,49,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,242,47,131,20,3,0,32,0,48,49,49,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,98,49,246,183,3,0,32,0,48,49,49,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,27,31,102,202,4,0,16,1,48,49,49,45,118,49,49,46,118,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,92,77,103,92,5,0,64,0,48,49,49,45,118,49,50,46,118,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,90,61,81,159,5,0,64,0,48,49,49,45,118,50,49,46,118,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,64,208,108,66,6,0,64,0,112,114,111,109,97,116,95,53,49,50,45,49,46,101,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,135,158,127,204,1,0,16,1,112,114,111,109,97,116,95,53,49,50,45,50,46,101,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,49,114,140,94,1,0,16,1,112,114,111,109,97,116,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,123,215,120,128,2,0,16,1,112,114,111,109,97,116,95,49,109,45,52,46,106,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,159,201,219,67,3,0,32,0,112,114,111,109,97,116,95,49,109,45,53,46,106,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,176,68,147,192,3,0,32,0,112,114,111,109,97,116,95,49,109,45,54,46,106,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,186,248,131,125,3,0,32,0,112,114,111,109,97,116,95,49,109,45,55,46,106,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,42,249,77,115,3,0,32,0,112,114,111,109,97,116,95,50,109,45,49,46,100,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,42,225,251,39,6,0,64,0,103,107,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,97,237,174,174,1,0,16,1,103,107,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,235,164,197,43,1,0,16,1,103,99,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,244,192,230,224,2,0,16,1,109,97,101,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,160,204,21,167,3,0,32,0,109,97,101,48,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,148,48,4,48,4,0,32,0,109,97,101,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,251,243,74,67,4,0,32,0,103,99,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,255,70,34,47,5,0,64,0,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,121,233,22,225,1,0,16,1,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,245,53,38,42,1,0,16,1,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,144,77,134,105,1,0,16,1,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,115,147,76,23,1,0,16,1,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,30,203,91,17,1,0,16,1,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,23,170,76,67,1,0,16,1,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,130,139,198,103,1,0,16,1,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,6,48,182,245,1,0,16,1,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,236,138,207,103,2,0,16,1,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,91,76,44,249,3,0,32,0,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,206,131,7,59,3,0,32,0,115,45,115,109,97,114,116,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,171,206,245,161,1,0,16,0,115,45,115,109,97,114,116,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,93,97,63,38,1,0,16,0,115,50,45,53,46,49,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,30,23,75,202,2,0,16,0,115,50,45,55,46,49,53,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,229,223,190,34,3,0,32,0,115,50,45,56,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,171,112,28,106,3,0,32,0,115,116,115,109,97,114,116,46,57,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,126,154,39,168,4,0,32,0,115,116,115,109,97,114,116,46,57,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,161,26,2,47,4,0,32,0,115,116,115,109,97,114,116,46,57,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,247,70,115,22,4,0,32,0,115,116,115,109,97,114,116,46,57,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,18,175,5,195,4,0,32,0,115,116,115,109,97,114,116,46,57,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,53,109,193,115,4,0,32,0,115,116,115,109,97,114,116,46,57,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,226,180,190,165,4,0,32,0,115,50,45,54,46,49,56,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,5,22,219,71,5,0,64,0,115,50,45,49,118,101,114,50,46,49,52,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,115,71,95,101,1,0,16,0,115,50,45,50,118,101,114,50,46,49,52,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,35,72,174,239,1,0,16,0,115,50,45,53,46,49,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,30,23,75,202,2,0,16,0,115,50,45,57,46,50,53,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,103,172,182,9,3,0,32,0,115,50,45,49,48,46,50,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,111,238,228,137,3,0,32,0,115,116,115,109,97,114,116,46,57,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,126,154,39,168,4,0,32,0,115,116,115,109,97,114,116,46,57,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,161,26,2,47,4,0,32,0,115,116,115,109,97,114,116,46,57,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,247,70,115,22,4,0,32,0,115,116,115,109,97,114,116,46,57,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,18,175,5,195,4,0,32,0,115,116,115,109,97,114,116,46,57,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,53,109,193,115,4,0,32,0,115,116,115,109,97,114,116,46,57,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,226,180,190,165,4,0,32,0,115,50,45,54,46,49,56,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,5,22,219,71,5,0,64,0,112,108,50,48,108,49,48,97,46,49,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,204,0,0,0,0,0,0,0,0,0,0,16,115,50,118,49,106,95,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,60,65,49,240,1,0,16,0,115,50,118,49,106,95,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,11,164,3,228,1,0,16,0,115,50,45,53,46,49,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,30,23,75,202,2,0,16,0,115,50,45,55,46,49,53,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,229,223,190,34,3,0,32,0,115,50,45,56,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,171,112,28,106,3,0,32,0,115,116,115,109,97,114,116,46,57,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,126,154,39,168,4,0,32,0,115,116,115,109,97,114,116,46,57,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,161,26,2,47,4,0,32,0,115,116,115,109,97,114,116,46,57,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,247,70,115,22,4,0,32,0,115,116,115,109,97,114,116,46,57,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,18,175,5,195,4,0,32,0,115,116,115,109,97,114,116,46,57,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,53,109,193,115,4,0,32,0,115,116,115,109,97,114,116,46,57,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,226,180,190,165,4,0,32,0,115,50,45,54,46,49,56,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,5,22,219,71,5,0,64,0,115,50,45,49,118,101,114,49,46,57,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,197,84,147,181,1,0,16,0,115,50,45,50,118,101,114,49,46,49,48,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,139,182,72,228,1,0,16,0,115,50,45,53,46,49,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,30,23,75,202,2,0,16,0,115,50,45,55,46,49,53,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,229,223,190,34,3,0,32,0,115,50,45,56,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,171,112,28,106,3,0,32,0,115,116,115,109,97,114,116,46,57,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,126,154,39,168,4,0,32,0,115,116,115,109,97,114,116,46,57,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0])
.concat([161,26,2,47,4,0,32,0,115,116,115,109,97,114,116,46,57,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,247,70,115,22,4,0,32,0,115,116,115,109,97,114,116,46,57,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,18,175,5,195,4,0,32,0,115,116,115,109,97,114,116,46,57,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,53,109,193,115,4,0,32,0,115,116,115,109,97,114,116,46,57,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,226,180,190,165,4,0,32,0,115,50,45,54,46,49,56,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,5,22,219,71,5,0,64,0,108,115,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,46,88,77,191,1,0,16,1,108,115,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,212,157,115,22,1,0,16,1,108,115,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,222,40,60,8,1,0,16,1,108,115,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,59,126,146,176,1,0,16,1,108,115,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,78,92,210,204,1,0,16,1,108,115,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,167,7,169,7,1,0,16,1,108,115,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,133,57,51,77,2,0,16,1,108,115,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,252,83,183,53,2,0,16,1,105,109,53,54,50,51,46,102,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,247,62,121,8,3,0,32,0,105,109,53,54,50,51,46,102,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,247,62,121,8,3,0,32,0,15,0,0,0,255,255,32,0,0,0,0,0,0,0,0,0,254,0,2,0,128,129,4,0,15,0,0,0,1,1,0,0,8,49,4,0,15,0,0,0,1,1,1,0,72,246,3,0,0,0,0,0,254,0,2,0,56,202,1,0,15,0,0,0,1,2,0,0,56,111,3,0,15,0,0,0,1,2,2,0,104,134,3,0,0,0,0,0,254,0,4,0,224,176,1,0,15,0,0,0,1,12,0,0,208,75,4,0,15,0,0,0,1,12,4,0,8,49,4,0,15,0,0,0,1,12,8,0,152,21,4,0,15,0,0,0,1,12,12,0,72,246,3,0,0,0,0,0,254,0,3,0,56,154,1,0,15,0,0,0,1,16,0,0,112,143,1,0,15,0,0,0,1,16,16,0,16,130,1,0,0,0,0,0,254,0,2,0,200,30,2,0,15,0,0,0,1,32,32,0,120,97,1,0,15,0,0,0,1,32,0,0,96,19,1,0,0,0,0,0,254,0,2,0,144,212,8,0,15,0,0,0,1,64,0,0,96,135,7,0,15,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,15,0,0,0,1,128,0,0,96,135,7,0,15,0,0,0,1,128,128,0,152,182,7,0,106,48,45,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,116,130,199,147,1,0,16,1,106,48,45,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,45,176,178,147,1,0,16,1,106,48,45,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,181,172,95,101,1,0,16,1,106,48,45,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,59,126,146,176,1,0,16,1,106,48,45,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,217,120,33,157,1,0,16,1,106,48,45,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,252,143,17,121,1,0,16,1,98,48,45,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,133,57,51,77,2,0,16,1,106,48,45,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,48,168,22,52,2,0,16,1,105,109,53,54,50,51,46,102,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,247,62,121,8,3,0,32,0,105,109,53,54,50,51,46,102,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,247,62,121,8,3,0,32,0,115,97,95,49,95,48,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,79,196,184,127,1,0,16,1,115,97,95,49,95,48,51,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,43,117,28,150,1,0,16,1,115,97,95,49,95,48,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,34,48,4,164,1,0,16,1,115,97,95,49,95,48,51,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,134,50,42,245,1,0,16,1,115,97,95,49,95,48,49,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,122,57,214,8,1,0,16,1,115,97,95,49,95,48,51,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,245,121,48,16,1,0,16,1,115,97,95,49,95,48,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,52,137,5,86,2,0,16,1,103,108,45,48,56,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,180,162,51,3,0,32,0,103,108,45,48,57,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,82,71,45,90,3,0,32,0,109,97,103,45,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,154,198,137,222,4,0,32,0,109,97,103,45,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,51,93,240,168,5,0,32,0,109,97,103,45,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,237,158,57,91,5,0,32,0,109,97,103,45,48,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,159,235,32,34,6,0,32,0,109,97,103,45,48,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,84,50,165,86,6,0,32,0,109,97,103,45,48,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,204,148,75,20,6,0,32,0,109,97,103,45,48,54,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,73,71,212,130,6,0,32,0,115,97,95,49,95,48,54,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,202,243,136,33,7,0,64,0,50,50,55,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,210,1,241,218,1,0,16,1,50,50,55,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,98,68,140,42,2,0,32,0,50,50,55,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,244,42,108,125,3,0,32,0,50,50,55,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,57,45,64,126,3,0,32,0,50,50,55,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,96,214,223,147,3,0,32,0,50,50,55,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,58,164,254,126,3,0,32,0,50,50,55,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,249,224,229,200,4,0,16,1,50,50,55,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,129,65,242,184,5,0,64,0,50,50,55,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,96,226,57,238,5,0,64,0,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,155,146,85,133,1,0,16,1,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,172,99,11,91,1,0,16,1,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,142,242,140,93,2,0,16,1,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,54,61,70,70,4,0,32,0,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,131,118,143,4,5,0,32,0,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,119,74,29,5,5,0,32,0,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,51,206,17,233,6,0,64,0,114,97,45,109,97,45,48,49,95,48,49,46,117,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,132,159,37,146,0,0,16,1,114,97,45,109,97,48,49,45,114,111,109,50,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,149,189,226,84,0,0,32,0,114,97,45,109,97,48,49,45,114,111,109,51,46,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,143,55,205,33,0,0,32,0,114,97,45,109,97,45,48,49,95,48,53,46,117,56,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,65,136,181,136,0,0,32,0,114,97,45,109,97,45,48,49,95,48,50,46,117,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,109,164,191,234,0,0,16,1,114,97,45,109,97,48,49,45,114,111,109,49,46,117,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,184,42,219,110,0,0,64,0,114,97,45,109,97,95,48,49,95,48,49,46,117,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,29,213,143,112,0,0,16,1,114,97,45,109,97,48,49,45,114,111,109,50,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,149,189,226,84,0,0,32,0,114,97,45,109,97,48,49,45,114,111,109,51,46,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,143,55,205,33,0,0,32,0,114,97,45,109,97,45,48,49,95,48,53,46,117,56,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,65,136,181,136,0,0,32,0,114,97,45,109,97,45,48,49,95,48,50,46,117,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,109,164,191,234,0,0,16,1,114,97,45,109,97,48,49,45,114,111,109,49,46,117,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,184,42,219,110,0,0,64,0,102,51,45,104,48,45,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,218,185,63,182,1,0,16,1,102,51,45,108,48,45,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,162,97,147,65,1,0,16,1,102,51,45,104,49,45,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,25,246,217,227,1,0,16,1,102,51,45,108,49,45,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,150,195,181,140,1,0,16,1,102,51,95,115,104,48,46,115,104,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,94,94,181,144,2,0,16,1,102,51,95,115,108,48,46,115,108,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,87,109,193,119,2,0,16,1,102,51,95,119,53,48,46,99,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,238,136,231,71,3,0,32,0,102,51,95,119,53,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,63,94,83,142,3,0,32,0,102,51,95,119,53,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,86,46,235,166,3,0,32,0,102,51,95,119,53,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,7,40,153,47,3,0,32,0,102,51,95,119,51,55,46,48,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,3,218,76,253,4,0,32,0,102,51,95,119,51,56,46,48,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,16,171,91,117,4,0,32,0,102,51,95,119,51,57,46,48,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,146,237,28,178,4,0,32,0,102,51,95,119,52,48,46,48,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,137,104,144,46,4,0,32,0,102,51,95,119,52,49,46,48,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,16,93,69,2,4,0,32,0,102,51,95,119,52,50,46,48,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,185,137,69,18,4,0,32,0,102,51,95,119,52,51,46,48,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,122,50,231,218,4,0,32,0,102,51,95,119,52,52,46,48,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,172,132,252,208,4,0,32,0,102,51,95,119,57,53,46,100,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,43,67,202,247,5,0,64,0,115,115,109,49,52,46,49,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,116,27,166,237,1,0,16,1,115,115,109,49,53,46,49,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,39,89,241,175,1,0,16,1,115,115,109,49,49,46,49,56,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,227,220,230,139,2,0,16,1,115,115,109,49,54,46,49,55,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,31,235,246,92,3,0,32,0,115,115,109,49,55,46,49,52,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,85,132,194,201,4,0,32,0,115,115,109,49,56,46,49,52,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,214,170,253,235,4,0,32,0,115,115,109,50,48,46,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,77,108,193,160,5,0,32,0,115,115,109,49,57,46,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,87,54,148,177,5,0,32,0,115,115,109,49,51,46,49,57,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,240,102,143,97,6,0,64,0,115,115,109,49,50,46,49,56,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,131,156,33,232,6,0,64,0,115,115,109,45,112,114,50,46,49,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,108,184,219,207,0,0,0,8,115,115,109,45,112,114,49,46,49,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,114,208,11,237,0,0,0,8,50,49,53,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,163,75,155,81,1,0,16,1,50,49,53,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,54,92,254,240,2,0,32,0,50,49,53,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,245,68,244,143,3,0,32,0,50,49,53,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,55,80,21,91,3,0,32,0,50,49,53,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,58,7,106,69,3,0,32,0,50,49,53,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,225,130,193,67,3,0,32,0,50,49,53,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,236,151,111,12,3,0,32,0,50,49,53,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,27,94,156,50,3,0,32,0,50,49,53,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,29,8,50,169,4,0,16,1,50,49,53,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,9,20,125,135,5,0,64,0,50,49,53,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,139,33,250,27,5,0,64,0,48,56,49,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,61,122,194,107,1,0,16,1,48,56,49,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,52,218,38,118,2,0,32,0,48,56,49,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,190,142,182,31,3,0,32,0,48,56,49,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,143,146,141,178,3,0,32,0,48,56,49,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,232,114,37,59,3,0,32,0,48,56,49,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,124,106,210,71,3,0,32,0,48,56,49,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,13,47,212,23,3,0,32,0,48,56,49,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,117,251,83,107,3,0,32,0,48,56,49,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,99,216,252,130,4,0,16,1,48,56,49,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,225,161,31,32,5,0,64,0,48,56,49,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,150,157,242,172,5,0,64,0,48,56,49,45,118,51,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,21,228,36,229,5,0,64,0,48,54,49,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,220,224,105,89,1,0,16,1,48,54,49,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,104,27,109,34,2,0,32,0,48,54,49,45,99,49,45,49,54,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,79,71,38,166,3,0,32,0,48,54,49,45,99,50,45,49,54,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,174,66,190,195,3,0,32,0,48,54,49,45,99,51,45,49,54,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,185,152,123,42,3,0,32,0,48,54,49,45,99,52,45,49,54,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,31,154,190,192,3,0,32,0,48,54,49,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,81,105,111,21,4,0,16,1,48,54,49,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,211,200,129,240,5,0,64,0,48,54,49,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,2,51,214,124,5,0,64,0,114,99,48,52,46,49,52,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,156,232,140,166,1,0,16,1,114,99,48,51,40,95,95,115,114,117,109,98,108,101,114,51,41,46,49,51,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,43,153,33,10,1,0,16,1,114,99,48,50,46,49,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,216,98,154,0,1,0,16,1,114,99,48,49,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,29,141,196,42,1,0,16,1,114,99,48,57,46,49,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,114,62,242,100,1,0,16,1,114,99,48,56,40,95,95,115,114,117,109,98,108,101,114,51,41,46,49,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,92,181,97,227,1,0,16,1,114,99,48,55,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,118,80,120,222,1,0,16,1,114,99,48,54,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,212,79,15,167,1,0,16,1,114,99,48,53,46,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,7,250,4,234,2,0,16,1,114,99,49,48,46,54,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,113,226,171,173,3,0,32,0,114,99,49,49,46,49,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,186,66,160,95,4,0,32,0,114,99,49,50,46,49,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,175,100,219,162,4,0,32,0,114,99,49,51,46,49,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,153,84,223,241,4,0,32,0,114,99,49,52,46,49,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,179,49,43,178,4,0,32,0,114,99,49,53,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,243,58,58,202,4,0,32,0,114,99,49,54,46,49,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,17,74,154,196,4,0,32,0,114,99,49,55,46,49,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,171,170,128,170,4,0,32,0,114,99,49,56,46,49,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,142,134,103,206,4,0,32,0,114,99,50,48,46,49,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,97,200,36,57,5,0,32,0,114,99,49,57,46,49,52,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,41,145,143,255,5,0,32,0,114,99,50,50,46,49,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,28,22,100,171,5,0,32,0,114,99,50,49,46,49,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,209,188,100,253,5,0,32,0,114,99,50,52,46,49,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,62,175,114,201,5,0,32,0,114,99,50,51,46,49,52,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,87,191,154,140,5,0,32,0,114,99,50,54,46,49,53,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,47,115,241,212,5,0,32,0,114,99,50,53,46,49,52,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,79,234,164,210,5,0,32,0,54,51,115,49,52,49,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,111,120,33,132,6,0,16,1,54,51,115,49,52,49,46,49,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,63,88,72,96,6,0,16,1,54,51,115,49,52,49,46,56,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,255,167,137,26,0,0,0,8,114,99,48,52,46,49,52,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,156,232,140,166,1,0,16,1,114,99,48,51,40,95,95,115,114,117,109,98,108,101,114,50,41,46,49,51,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,212,120,47,232,1,0,16,1,114,99,48,50,46,49,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,216,98,154,0,1,0,16,1,114,99,48,49,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,29,141,196,42,1,0,16,1,114,99,48,57,46,49,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,114,62,242,100,1,0,16,1,114,99,48,56,40,95,95,115,114,117,109,98,108,101,114,50,41,46,49,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,7,16,199,116,1,0,16,1,114,99,48,55,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,118,80,120,222,1,0,16,1,114,99,48,54,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,212,79,15,167,1,0,16,1,114,99,48,53,46,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,7,250,4,234,2,0,16,1,114,99,49,48,46,54,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,113,226,171,173,3,0,32,0,114,99,49,49,46,49,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,186,66,160,95,4,0,32,0,114,99,49,50,46,49,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,175,100,219,162,4,0,32,0,114,99,49,51,46,49,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,153,84,223,241,4,0,32,0,114,99,49,52,46,49,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,179,49,43,178,4,0,32,0,114,99,49,53,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,243,58,58,202,4,0,32,0,114,99,49,54,46,49,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,17,74,154,196,4,0,32,0,114,99,49,55,46,49,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,171,170,128,170,4,0,32,0,114,99,49,56,46,49,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,142,134,103,206,4,0,32,0,114,99,50,48,46,49,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,97,200,36,57,5,0,32,0,114,99,49,57,46,49,52,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,41,145,143,255,5,0,32,0,114,99,50,50,46,49,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,28,22,100,171,5,0,32,0,114,99,50,49,46,49,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,209,188,100,253,5,0,32,0,114,99,50,52,46,49,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,62,175,114,201,5,0,32,0,114,99,50,51,46,49,52,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,87,191,154,140,5,0,32,0,114,99,50,54,46,49,53,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,47,115,241,212,5,0,32,0,114,99,50,53,46,49,52,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,79,234,164,210,5,0,32,0,54,51,115,49,52,49,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,111,120,33,132,6,0,16,1,54,51,115,49,52,49,46,49,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,63,88,72,96,6,0,16,1,54,51,115,49,52,49,46,56,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,255,167,137,26,0,0,0,8,114,99,48,52,46,49,52,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,156,232,140,166,1,0,16,1,114,99,48,51,40,95,95,115,114,117,109,98,108,101,114,41,46,49,51,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,18,168,189,135,1,0,16,1,114,99,48,50,40,95,95,115,114,117,109,98,108,101,114,41,46,49,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,202,156,96,216,1,0,16,1,114,99,48,49,40,95,95,115,114,117,109,98,108,101,114,41,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,118,71,236,39,1,0,16,1,114,99,48,57,40,95,95,115,114,117,109,98,108,101,114,41,46,49,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,29,16,70,33,1,0,16,1,114,99,48,56,40,95,95,115,114,117,109,98,108,101,114,41,46,49,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,166,105,131,131,1,0,16,1,114,99,48,55,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,118,80,120,222,1,0,16,1,114,99,48,54,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,212,79,15,167,1,0,16,1,114,99,48,53,40,95,95,115,114,117,109,98,108,101,114,41,46,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,190,206,119,1,2,0,16,1,114,99,49,48,46,54,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,113,226,171,173,3,0,32,0,114,99,49,49,46,49,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,186,66,160,95,4,0,32,0,114,99,49,50,46,49,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,175,100,219,162,4,0,32,0,114,99,49,51,46,49,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,153,84,223,241,4,0,32,0,114,99,49,52,46,49,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,179,49,43,178,4,0,32,0,114,99,49,53,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,243,58,58,202,4,0,32,0,114,99,49,54,46,49,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,17,74,154,196,4,0,32,0,114,99,49,55,46,49,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,171,170,128,170,4,0,32,0,114,99,49,56,46,49,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,142,134,103,206,4,0,32,0,114,99,50,48,46,49,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,97,200,36,57,5,0,32,0,114,99,49,57,46,49,52,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,41,145,143,255,5,0,32,0,114,99,50,50,46,49,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,28,22,100,171,5,0,32,0,114,99,50,49,46,49,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,209,188,100,253,5,0,32,0,114,99,50,52,46,49,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,62,175,114,201,5,0,32,0,114,99,50,51,46,49,52,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,87,191,154,140,5,0,32,0,114,99,50,54,46,49,53,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,47,115,241,212,5,0,32,0,114,99,50,53,46,49,52,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,79,234,164,210,5,0,32,0,54,51,115,49,52,49,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,111,120,33,132,6,0,16,1,54,51,115,49,52,49,46,49,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,63,88,72,96,6,0,16,1,54,51,115,49,52,49,46,56,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,255,167,137,26,0,0,0,8,100,121,95,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,255,228,238,30,1,0,0,0,100,121,48,48,46,98,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,97,180,246,43,1,0,0,0,100,121,48,52,46,100,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,28,89,227,42,2,0,0,0,100,121,48,53,46,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,163,232,128,135,3,0,0,0,100,121,48,55,46,104,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,96,186,234,151,4,0,0,0,100,121,48,54,46,104,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,27,84,121,194,4,0,0,0,100,121,48,57,46,107,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,69,23,13,211,4,0,0,0,100,121,48,56,46,107,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,253,69,214,113,4,0,0,0,100,121,49,49,46,107,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,91,204,156,253,4,0,0,0,100,121,49,48,46,107,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,184,10,119,136,4,0,0,0,100,121,48,51,46,98,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,249,164,242,68,5,0,0,0,100,121,48,50,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,158,154,45,82,5,0,0,0,105,100,56,55,53,49,104,46,109,99,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,6,0,0,16,100,121,49,50,46,102,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,217,174,250,235,7,0,0,0,100,121,48,49,45,101,46,98,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,153,146,110,23,1,0,0,0,100,121,48,48,46,98,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,97,180,246,43,1,0,0,0,100,121,48,52,46,100,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,28,89,227,42,2,0,0,0,100,121,48,53,46,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,163,232,128,135,3,0,0,0,100,121,48,55,46,104,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,96,186,234,151,4,0,0,0,100,121,48,54,46,104,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,27,84,121,194,4,0,0,0,100,121,48,57,46,107,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,69,23,13,211,4,0,0,0,100,121,48,56,46,107,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,253,69,214,113,4,0,0,0,100,121,49,49,46,107,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,91,204,156,253,4,0,0,0,100,121,49,48,46,107,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,184,10,119,136,4,0,0,0,100,121,48,51,46,98,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,249,164,242,68,5,0,0,0,100,121,48,50,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,158,154,45,82,5,0,0,0,105,100,56,55,53,49,104,46,109,99,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,6,0,0,16,100,121,49,50,46,102,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,217,174,250,235,7,0,0,0,103,108,111,98,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,234,11,157,130,1,0,16,1,103,108,111,98,46,117,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,40,102,222,49,1,0,16,1,53,101,95,50,53,51,50,46,100,97,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,9,97,161,26,2,0,32,0,53,102,95,50,53,51,50,46,100,97,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,137,42,231,175,2,0,32,0,103,108,111,98,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,39,117,97,31,3,0,32,0,103,108,111,98,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,105,167,250,40,3,0,32,0,56,50,115,49,50,54,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,134,204,169,4,0,64,0,56,50,115,49,50,54,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,105,99,56,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,115,32,223,162,1,0,16,1,105,99,55,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,217,34,44,61,1,0,16,1,105,99,49,53,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,127,4,82,162,1,0,16,1,105,99,49,52,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,241,129,250,126,1,0,16,1,105,99,57,50,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,77,72,79,229,2,0,32,0,105,99,55,56,46,112,114,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,39,117,97,31,3,0,32,0,105,99,56,56,46,112,114,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,105,167,250,40,3,0,32,0,105,99,53,49,46,112,114,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,39,234,157,194,4,0,64,0,105,99,55,48,46,112,114,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,48,54,50,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,170,161,171,55,1,0,16,1,48,54,50,45,112,50,46,115,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,119,171,37,240,1,0,16,1,48,54,50,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,190,43,158,40,2,0,32,0,48,54,50,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,162,90,55,169,3,0,32,0,48,54,50,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,88,183,115,14,3,0,32,0,48,54,50,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,101,228,81,223,3,0,32,0,48,54,50,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,144,126,81,56,3,0,32,0,48,54,50,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,146,214,171,123,3,0,32,0,48,54,50,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,229,173,229,205,3,0,32,0,48,54,50,45,99,55,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,192,215,47,187,3,0,32,0,48,54,50,45,99,56,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,51,233,123,141,3,0,32,0,48,54,50,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,47,139,16,118,4,0,16,1,48,54,50,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,239,26,40,204,5,0,64,0,105,99,57,56,46,117,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,103,118,15,58,0,0,16,1,105,99,49,48,52,46,117,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,49,175,224,160,0,0,16,1,105,99,57,51,46,117,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,41,48,247,12,0,0,16,1,105,99,57,52,46,117,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,38,196,247,92,0,0,16,1,105,99,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,58,207,24,227,0,0,32,0,105,99,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,116,246,113,224,0,0,32,0,105,99,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,85,90,61,166,0,0,32,0,105,99,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,61,145,204,125,0,0,32,0,105,99,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,127,175,132,13,0,0,32,0,105,99,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,78,172,63,214,0,0,32,0,105,99,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,75,68,96,90,0,0,32,0,105,99,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,243,208,239,27,0,0,32,0,105,99,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,74,248,194,0,0,32,0,105,99,51,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,163,225,168,235,0,0,32,0,105,99,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,126,170,245,94,0,0,32,0,105,99,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,170,238,36,219,0,0,32,0,105,99,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,244,91,2,151,0,0,32,0,105,99,49,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,65,218,90,98,0,0,16,1,105,99,49,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,36,240,37,16,0,0,16,1,105,99,49,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,58,6,13,110,0,0,64,0,105,99,49,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,251,29,98,230,0,0,64,0,101,112,108,49,54,112,56,98,112,46,105,99,49,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,1,0,0,0,0,0,0,0,0,0,24,101,112,108,49,54,112,56,98,112,46,105,99,49,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,1,0,0,0,0,0,0,0,0,0,24,101,112,108,49,54,112,56,98,112,46,105,99,49,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,1,0,0,0,0,0,0,0,0,0,24,101,112,108,49,54,112,56,98,112,46,105,99,57,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,1,0,0,0,0,0,0,0,0,0,24,103,97,108,49,54,118,56,97,46,105,99,49,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,0,0,0,0,0,0,24,103,97,108,49,54,118,56,97,46,105,99,57,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,0,0,0,0,0,0,24,105,99,57,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,112,191,194,54,0,0,16,1,105,99,49,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,88,225,167,52,0,0,16,1,105,99,57,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,131,70,111,114,0,0,16,1,105,99,57,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,3,94,56,196,0,0,16,1,105,99,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,58,207,24,227,0,0,32,0,105,99,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,116,246,113,224,0,0,32,0,105,99,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,85,90,61,166,0,0,32,0,105,99,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,61,145,204,125,0,0,32,0,105,99,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,127,175,132,13,0,0,32,0,105,99,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,78,172,63,214,0,0,32,0,105,99,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,75,68,96,90,0,0,32,0,105,99,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,243,208,239,27,0,0,32,0,105,99,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,74,248,194,0,0,32,0,105,99,51,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,163,225,168,235,0,0,32,0,105,99,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,126,170,245,94,0,0,32,0,105,99,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,170,238,36,219,0,0,32,0,105,99,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,244,91,2,151,0,0,32,0,105,99,49,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,65,218,90,98,0,0,16,1,105,99,49,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,36,240,37,16,0,0,16,1,105,99,49,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,58,6,13,110,0,0,64,0,105,99,49,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,251,29,98,230,0,0,64,0,101,112,108,49,54,112,56,98,112,46,105,99,49,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,1,0,0,0,0,0,0,0,0,0,24,101,112,108,49,54,112,56,98,112,46,105,99,49,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,1,0,0,0,0,0,0,0,0,0,24,101,112,108,49,54,112,56,98,112,46,105,99,49,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,1,0,0,0,0,0,0,0,0,0,24,101,112,108,49,54,112,56,98,112,46,105,99,57,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,1,0,0,0,0,0,0,0,0,0,24,103,97,108,49,54,118,56,97,46,105,99,49,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,0,0,0,0,0,0,24,103,97,108,49,54,118,56,97,46,105,99,57,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,0,0,0,0,0,0,24,19,0,0,0,255,255,0,0,0,0,0,0,20,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,19,0,0,0,1,15,0,0,232,13,2,0,19,0,0,0,1,15,1,0,216,5,2,0,19,0,0,0,1,15,2,0,8,250,1,0,19,0,0,0,1,15,3,0,216,239,1,0,19,0,0,0,1,15,4,0,32,228,1,0,19,0,0,0,1,15,5,0,8,213,1,0,19,0,0,0,1,15,6,0,232,201,1,0,19,0,0,0,1,15,7,0,104,191,1,0,19,0,0,0,1,15,8,0,192,183,1,0,19,0,0,0,1,15,9,0,152,176,1,0,19,0,0,0,1,15,10,0,24,170,1,0,19,0,0,0,1,15,11,0,96,161,1,0,19,0,0,0,1,15,12,0,184,153,1,0,19,0,0,0,1,15,13,0,16,143,1,0,19,0,0,0,1,15,14,0,104,129,1,0,19,0,0,0,1,15,15,0,96,115,1,0,0,0,0,0,254,0,16,0,200,87,7,0,19,0,0,0,1,240,0,0,232,13,2,0,19,0,0,0,1,240,16,0,216,5,2,0,19,0,0,0,1,240,32,0,8,250,1,0,19,0,0,0,1,240,48,0,216,239,1,0,19,0,0,0,1,240,64,0,32,228,1,0,19,0,0,0,1,240,80,0,8,213,1,0,19,0,0,0,1,240,96,0,232,201,1,0,19,0,0,0,1,240,112,0,104,191,1,0,19,0,0,0,1,240,128,0,192,183,1,0,19,0,0,0,1,240,144,0,152,176,1,0,19,0,0,0,1,240,160,0,24,170,1,0,19,0,0,0,1,240,176,0,96,161,1,0,19,0,0,0,1,240,192,0,184,153,1,0,19,0,0,0,1,240,208,0,16,143,1,0,19,0,0,0,1,240,224,0,104,129,1,0,19,0,0,0,1,240,240,0,96,115,1,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,3,0,0,248,38,7,0,20,0,0,0,1,3,1,0,80,246,3,0,20,0,0,0,1,3,2,0,112,212,3,0,20,0,0,0,1,3,3,0,248,160,5,0,0,0,0,0,106,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,14,105,61,106,0,0,16,1,106,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,250,147,149,134,0,0,16,1,106,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,18,57,227,51,0,0,16,1,106,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,208,97,202,22,0,0,16,1,105,99,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,58,207,24,227,0,0,32,0,105,99,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,116,246,113,224,0,0,32,0,105,99,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,85,90,61,166,0,0,32,0,105,99,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,61,145,204,125,0,0,32,0,105,99,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,127,175,132,13,0,0,32,0,105,99,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,78,172,63,214,0,0,32,0,105,99,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,75,68,96,90,0,0,32,0,105,99,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,243,208,239,27,0,0,32,0,105,99,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,74,248,194,0,0,32,0,105,99,51,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,163,225,168,235,0,0,32,0,105,99,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,126,170,245,94,0,0,32,0,105,99,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,170,238,36,219,0,0,32,0,105,99,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,244,91,2,151,0,0,32,0,105,99,49,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,65,218,90,98,0,0,16,1,105,99,49,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,36,240,37,16,0,0,16,1,105,99,49,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,58,6,13,110,0,0,64,0,105,99,49,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,251,29,98,230,0,0,64,0,101,112,108,49,54,112,56,98,112,46,105,99,49,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,1,0,0,0,0,0,0,0,0,0,24,101,112,108,49,54,112,56,98,112,46,105,99,49,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,1,0,0,0,0,0,0,0,0,0,24,101,112,108,49,54,112,56,98,112,46,105,99,49,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,1,0,0,0,0,0,0,0,0,0,24,101,112,108,49,54,112,56,98,112,46,105,99,57,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,1,0,0,0,0,0,0,0,0,0,24,103,97,108,49,54,118,56,97,46,105,99,49,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,0,0,0,0,0,0,24,103,97,108,49,54,118,56,97,46,105,99,57,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,0,0,0,0,0,0,24,115,109,97,110,45,112,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,232,207,181,102,1,0,16,1,115,109,97,110,45,112,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,234,42,8,114,1,0,16,1,115,109,97,110,45,115,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,94,178,184,99,2,0,32,0,115,109,97,110,45,99,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,221,207,92,142,3,0,32,0,115,109,97,110,45,99,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,91,111,64,166,3,0,32,0,115,109,97,110,45,99,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,38,249,255,173,3,0,32,0,115,109,97,110,45,99,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,127,48,140,6,3,0,32,0,115,109,97,110,45,99,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,166,247,92,154,3,0,32,0,115,109,97,110,45,99,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,192,3,79,147,3,0,32,0,115,109,97,110,45,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,29,203,2,106,4,0,16,1,115,109,97,110,45,118,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,97,9,0,218,56,193,149,5,0,64,0,116,99,104,45,115,115,49,46,117,55,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,91,180,182,65,1,0,16,1,116,99,104,45,115,115,50,46,117,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,12,253,17,70,2,0,16,1,116,99,104,45,115,115,51,46,117,57,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,94,235,157,28,3,0,64,0,116,99,104,45,115,115,52,46,117,55,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,89,120,81,65,4,0,32,0,116,99,104,45,115,115,53,46,117,54,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,52,47,43,131,4,0,32,0,116,99,104,45,115,115,54,46,117,54,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,137,114,253,241,4,0,32,0,116,99,104,45,115,115,55,46,117,53,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,67,133,149,196,4,0,32,0,116,99,104,45,115,115,56,46,117,51,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,109,177,39,47,5,0,32,0,116,99,104,45,115,115,57,46,117,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,236,248,114,195,5,0,32,0,115,112,101,97,107,114,101,115,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,234,228,38,96,1,0,16,1,115,112,101,97,107,114,101,115,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,218,212,240,147,1,0,16,1,115,112,101,97,107,114,101,115,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,4,67,135,163,1,0,16,1,115,112,101,97,107,114,101,115,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,58,190,132,244,1,0,16,1,115,112,101,97,107,114,101,115,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,103,42,177,97,1,0,16,1,115,112,101,97,107,114,101,115,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,178,10,14,34,1,0,16,1,115,112,101,97,107,114,101,115,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,19,190,23,212,2,0,16,1,115,112,101,97,107,114,101,115,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,96,93,72,82,2,0,16,1,105,109,53,54,50,51,46,102,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,247,62,121,8,3,0,32,0,105,109,53,54,50,51,46,102,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,247,62,121,8,3,0,32,0,15,0,0,0,255,255,32,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,15,0,0,0,1,3,0,0,8,49,4,0,15,0,0,0,1,3,1,0,152,21,4,0,15,0,0,0,1,3,2,0,72,246,3,0,15,0,0,0,1,3,3,0,72,0,3,0,0,0,0,0,254,0,4,0,224,176,1,0,15,0,0,0,1,12,0,0,208,75,4,0,15,0,0,0,1,12,4,0,8,49,4,0,15,0,0,0,1,12,8,0,152,21,4,0,15,0,0,0,1,12,12,0,72,246,3,0,0,0,0,0,254,0,3,0,64,37,5,0,15,0,0,0,1,16,0,0,136,120,6,0,15,0,0,0,1,16,16,0,32,112,3,0,0,0,0,0,254,0,2,0,200,30,2,0,15,0,0,0,1,32,32,0,120,97,1,0,15,0,0,0,1,32,0,0,96,19,1,0,0,0,0,0,254,0,2,0,144,212,8,0,15,0,0,0,1,64,0,0,96,135,7,0,15,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,15,0,0,0,1,128,0,0,96,135,7,0,15,0,0,0,1,128,128,0,152,182,7,0,0,0,0,0,101,112,114,49,48,49,50,53,46,99,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,198,56,253,191,1,0,16,1,101,112,114,49,48,49,50,48,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,153,159,57,214,1,0,16,1,101,112,114,49,48,49,50,49,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,96,21,134,212,1,0,16,1,101,112,114,49,48,49,50,50,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,27,255,27,122,1,0,16,1,101,112,114,49,48,49,50,51,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,37,41,237,106,1,0,16,1,101,112,114,49,48,49,50,52,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,107,174,215,161,1,0,16,1,101,112,114,49,48,49,50,54,46,100,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,82,248,23,171,2,0,16,1,101,112,114,49,48,49,51,51,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,9,102,46,100,3,0,32,0,101,112,114,49,48,49,51,53,46,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,250,196,133,6,4,0,32,0,101,112,114,49,48,49,51,52,46,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,136,255,116,198,4,0,32,0,101,112,114,49,48,49,51,50,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,189,177,248,45,5,0,32,0,101,112,114,49,48,49,51,49,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,23,56,34,222,5,0,32,0,101,112,114,49,48,49,51,48,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,54,203,143,182,5,0,32,0,101,112,114,49,48,49,50,57,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,35,16,242,166,6,0,32,0,101,112,114,49,48,49,50,56,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,23,56,34,222,6,0,32,0,101,112,114,49,48,49,50,55,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,54,203,143,182,6,0,32,0,54,51,115,48,56,49,110,46,117,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,39,134,185,54,0,0,0,8,100,56,57,45,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,249,231,47,12,2,0,0,0,100,56,57,45,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,164,11,10,127,2,0,0,0,100,56,57,45,48,55,46,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,52,116,189,9,0,0,0,100,56,57,45,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,241,134,223,83,11,0,0,0,100,56,57,45,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,19,76,196,11,0,0,0,100,56,57,45,48,51,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,164,49,143,33,24,0,0,0,100,56,57,45,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,30,117,34,113,2,0,0,0,100,56,57,45,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,175,56,22,190,2,0,0,0,100,56,57,45,48,55,46,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,52,116,189,9,0,0,0,100,56,57,45,48,50,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,185,68,101,195,11,0,0,0,100,56,57,45,48,49,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,96,6,250,255,11,0,0,0,100,56,57,45,48,51,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,164,49,143,33,24,0,0,0,112,97,108,49,54,108,56,45,100,55,50,45,48,53,46,105,99,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,126,203,212,195,0,0,0,8,112,97,108,49,54,108,56,45,100,55,50,45,48,54,46,105,99,53,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,55,127,107,233,0,0,0,8,112,97,108,99,101,50,48,118,56,45,100,55,50,45,48,55,46,105,99,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,87,1,0,0,76,230,89,99,0,0,0,8,112,97,108,99,101,50,48,118,56,45,100,55,50,45,48,57,46,105,99,52,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,87,1,0,0,253,96,23,222,0,0,0,8,112,97,108,99,101,49,54,118,56,45,100,55,50,45,49,48,46,105,99,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,162,27,24,165,0,0,0,8,112,97,108,50,48,108,56,98,45,100,56,57,45,48,52,46,105,99,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,1,0,0,0,0,0,0,0,0,0,24,114,111,109,46,97,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,206,77,215,64,1,0,16,1,114,111,109,46,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,79,163,240,165,1,0,16,1,114,111,109,46,97,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,203,58,187,203,1,0,16,1,114,111,109,46,97,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,202,80,16,49,1,0,16,1,114,111,109,46,97,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,3,56,148,40,1,0,16,1,114,111,109,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,40,159,28,133,1,0,16,1,114,111,109,46,98,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,157,104,69,219,2,0,16,1,114,111,109,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,87,65,7,30,2,0,16,1,114,111,109,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,32,139,10,213,2,0,16,1,105,109,53,54,50,51,46,102,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,247,62,121,8,3,0,32,0,105,109,53,54,50,51,46,102,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,247,62,121,8,3,0,32,0,48,51,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,209,223,117,209,1,0,16,1,48,52,46,49,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,124,71,114,32,1,0,16,1,115,98,48,50,48,46,49,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,147,236,245,186,2,0,16,1,48,50,46,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,81,20,123,51,3,0,32,0,48,49,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,84,221,16,250,4,0,32,0,48,48,46,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,239,20,90,211,4,0,32,0,115,98,48,51,48,46,49,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,72,63,164,30,5,0,64,0,48,57,55,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,29,18,71,5,1,0,16,1,48,57,55,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,67,103,214,141,2,0,32,0,48,57,55,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,137,213,208,51,3,0,32,0,48,57,55,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,67,139,111,24,3,0,32,0,48,57,55,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,245,255,57,195,3,0,32,0,48,57,55,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,110,12,164,132,3,0,32,0,48,57,55,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,145,66,14,178,4,0,16,1,48,57,55,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,82,81,136,111,5,0,64,0,48,57,55,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,104,232,89,51,5,0,64,0,48,55,53,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,56,23,135,146,1,0,16,1,48,55,53,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,103,195,238,201,2,0,32,0,48,55,53,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,62,231,120,50,3,0,32,0,48,55,53,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,214,85,99,254,3,0,32,0,48,55,53,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,241,56,180,193,3,0,32,0,48,55,53,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,6,114,119,31,3,0,32,0,48,55,53,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,241,141,130,187,4,0,16,1,48,55,53,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,73,233,119,117,5,0,64,0,48,55,53,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,205,96,23,2,5,0,64,0,50,45,112,114,111,103,95,108,46,117,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,4,155,23,207,1,0,16,1,49,45,112,114,111,103,95,104,46,117,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,196,209,103,244,1,0,16,1,52,108,46,117,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,105,242,185,158,2,0,32,0,52,104,46,117,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,231,207,118,124,2,0,32,0,53,108,46,117,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,88,104,156,197,2,0,32,0,53,104,46,117,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,208,102,188,115,2,0,32,0,54,108,46,117,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,110,129,27,240,2,0,32,0,54,104,46,117,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,97,115,213,253,2,0,32,0,115,111,117,110,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,69,141,143,233,3,0,64,0,48,48,49,45,48,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,202,163,10,157,1,0,16,1,48,48,49,45,48,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,95,239,242,150,1,0,16,1,48,48,49,45,48,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,151,168,155,171,3,0,32,0,48,48,49,45,48,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,64,53,202,52,4,0,32,0,48,48,49,45,48,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,141,214,149,43,28,0,32,0,48,48,49,45,48,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,103,199,250,236,6,0,64,0,48,51,49,45,112,103,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,167,52,240,23,1,0,16,1,48,51,49,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,116,113,17,76,2,0,32,0,48,51,49,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,184,78,10,189,3,0,32,0,48,51,49,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,130,83,222,239,3,0,32,0,48,51,49,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,51,127,15,88,3,0,32,0,48,51,49,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,232,125,41,237,3,0,32,0,48,51,49,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,124,66,55,203,4,0,16,1,48,51,49,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,126,73,120,204,5,0,64,0,48,51,49,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,198,67,160,221,5,0,64,0,112,114,111,45,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,65,227,126,76,0,0,16,1,114,111,109,50,45,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,169,102,211,233,0,0,32,0,114,111,109,50,45,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,98,122,171,154,0,0,32,0,114,111,109,51,45,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,50,227,6,235,0,0,32,0,114,111,109,51,45,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,42,149,74,223,0,0,32,0,114,111,109,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,30,52,143,99,0,0,64,0,32,0,0,0,255,255,0,0,0,0,0,0,33,0,0,0,255,255,0,0,0,0,0,0,34,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,240,98,1,0,32,0,0,0,1,1,0,0,248,38,7,0,32,0,0,0,1,1,1,0,208,212,8,0,0,0,0,0,254,0,2,0,144,212,8,0,32,0,0,0,1,2,0,0,96,135,7,0,32,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,32,0,0,0,1,4,0,0,96,135,7,0,32,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,32,0,0,0,1,8,8,0,96,135,7,0,32,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,20,0,0,0,130,48,0,0,232,38,7,0,22,0,0,0,0,15,8,0,0,0,0,0,20,0,0,0,130,48,16,0,120,164,6,0,22,0,0,0,0,15,8,0,0,0,0,0,20,0,0,0,130,48,32,0,224,123,6,0,22,0,0,0,0,15,8,0,0,0,0,0,20,0,0,0,130,48,48,0,16,74,6,0,22,0,0,0,0,15,8,0,0,0,0,0,0,0,0,0,254,0,4,0,160,123,6,0,20,0,0,0,130,192,0,0,232,38,7,0,22,0,0,0,0,15,8,0,0,0,0,0,20,0,0,0,130,192,64,0,120,164,6,0,22,0,0,0,0,15,8,0,0,0,0,0,20,0,0,0,130,192,128,0,224,123,6,0,22,0,0,0,0,15,8,0,0,0,0,0,20,0,0,0,130,192,192,0,16,74,6,0,22,0,0,0,0,15,8,0,0,0,0,0,0,0,0,0,254,0,4,0,200,87,7,0,20,0,0,0,2,48,0,0,232,38,7,0,22,0,0,0,0,15,8,0,0,0,0,0,20,0,0,0,2,48,16,0,224,123,6,0,22,0,0,0,0,15,8,0,0,0,0,0,20,0,0,0,2,48,32,0,200,241,5,0,22,0,0,0,0,15,8,0,0,0,0,0,20,0,0,0,2,48,48,0,200,241,5,0,22,0,0,0,0,15,8,0,0,0,0,0,0,0,0,0,254,0,4,0,160,123,6,0,20,0,0,0,2,192,0,0,120,164,6,0,22,0,0,0,0,15,8,0,0,0,0,0,20,0,0,0,2,192,64,0,232,201,5,0,22,0,0,0,0,15,8,0,0,0,0,0,20,0,0,0,2,192,128,0,168,241,5,0,22,0,0,0,0,15,8,0,0,0,0,0,20,0,0,0,2,192,192,0,208,127,5,0,22,0,0,0,0,15,8,0,0,0,0,0,0,0,0,0,254,0,4,0,72,202,5,0,33,0,0,0,1,3,1,0,80,246,3,0,33,0,0,0,1,3,0,0,248,38,7,0,33,0,0,0,1,3,2,0,112,212,3,0,33,0,0,0,1,3,3,0,24,99,5,0,0,0,0,0,254,0,4,0,64,37,5,0,33,0,0,0,1,12,4,0,96,37,5,0,33,0,0,0,1,12,0,0,216,135,2,0,33,0,0,0,1,12,8,0,176,227,4,0,33,0,0,0,1,12,12,0,120,7,5,0,0,0,0,0,254,0,4,0,128,129,4,0,33,0,0,0,1,48,48,0,192,255,2,0,33,0,0,0,1,48,32,0,208,75,4,0,33,0,0,0,1,48,0,0,8,49,4,0,33,0,0,0,1,48,16,0,152,21,4,0,0,0,0,0,254,0,2,0,224,21,4,0,33,0,0,0,1,64,0,0,248,38,7,0,33,0,0,0,1,64,64,0,160,246,3,0,0,0,0,0,254,0,2,0,216,212,3,0,33,0,0,0,1,128,128,0,208,75,4,0,33,0,0,0,1,128,0,0,152,21,4,0,0,0,0,0,254,0,7,0,120,185,3,0,34,0,0,0,1,28,8,0,8,234,2,0,34,0,0,0,1,28,16,0,192,20,3,0,34,0,0,0,1,28,0,0,176,20,3,0,34,0,0,0,1,28,12,0,56,50,1,0,34,0,0,0,1,28,24,0,32,192,2,0,34,0,0,0,1,28,20,0,80,65,1,0,34,0,0,0,1,28,4,0,160,134,3,0,0,0,0,0,254,0,2,0,232,20,3,0,34,0,0,0,1,32,0,0,56,111,3,0,34,0,0,0,1,32,32,0,104,134,3,0,0,0,0,0,115,106,49,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,218,252,48,107,1,0,16,1,115,106,50,46,100,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,209,136,16,31,1,0,16,1,115,106,51,46,101,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,58,95,214,237,1,0,16,1,115,106,52,46,104,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,146,17,72,244,1,0,16,1,115,106,53,46,106,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,5,125,255,27,1,0,16,1,115,106,54,46,107,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,223,62,121,33,1,0,16,1,115,106,57,46,102,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,199,17,32,255,2,0,32,0,115,106,48,46,104,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,187,186,151,240,2,0,32,0,115,106,56,46,108,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,182,5,241,183,3,0,32,0,115,106,55,46,109,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,168,3,219,28,3,0,32,0,49,48,45,50,46,107,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,209,157,189,203,4,0,32,0,49,48,45,49,46,102,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,210,251,22,91,4,0,32,0,49,48,45,51,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,80,58,250,39,4,0,0,8,97,55,55,95,48,48,46,56,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,15,14,76,103,0,0,16,1,97,55,55,95,48,49,46,56,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,167,228,66,60,0,0,16,1,97,55,55,95,49,50,46,56,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,151,211,69,133,0,0,32,0,97,55,55,95,49,49,46,55,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,37,185,183,177,0,0,32,0,97,55,55,95,49,48,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,107,148,45,66,0,0,32,0,97,55,55,95,48,57,46,55,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,174,19,113,88,0,0,32,0,97,55,55,95,48,52,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,67,185,199,42,0,0,32,0,97,55,55,95,48,51,46,54,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,147,220,202,51,0,0,32,0,97,55,55,95,48,56,46,54,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,5,131,53,182,0,0,32,0,97,55,55,95,48,55,46,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,96,157,45,233,0,0,32,0,97,55,55,95,48,54,46,54,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,163,238,174,95,0,0,32,0,97,55,55,95,48,53,46,54,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,169,46,78,151,0,0,32,0,50,49,95,56,50,115,49,50,57,46,49,50,113,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,153,175,239,160,0,0,32,0,50,48,95,56,50,115,49,50,57,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,229,87,109,165,0,0,32,0,49,57,95,56,50,115,49,50,57,46,49,50,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,159,191,92,0,0,32,0,97,55,55,95,48,50,46,49,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,90,112,244,135,0,0,16,1,97,55,55,95,49,51,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,217,129,12,167,0,0,16,1,17,0,0,0,255,255,128,0,0,0,0,0,18,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,0,0,0,0,17,0,0,0,1,128,128,0,192,159,4,0,17,0,0,0,1,128,0,0,8,148,8,0,0,0,0,0,254,0,2,0,0,0,0,0,17,0,0,0,1,64,0,0,200,211,8,0,17,0,0,0,1,64,64,0,216,147,8,0,0,0,0,0,254,0,2,0,0,0,0,0,17,0,0,0,1,32,0,0,136,159,3,0,17,0,0,0,1,32,32,0,40,31,8,0,0,0,0,0,254,0,2,0,240,233,7,0,17,0,0,0,1,16,0,0,152,182,7,0,17,0,0,0,1,16,16,0,96,135,7,0,0,0,0,0,254,0,4,0,200,87,7,0,17,0,0,0,1,12,0,0,232,38,7,0,17,0,0,0,1,12,8,0,120,164,6,0,17,0,0,0,1,12,4,0,224,123,6,0,17,0,0,0,1,12,12,0,16,74,6,0,0,0,0,0,254,0,4,0,160,123,6,0,17,0,0,0,1,3,0,0,232,38,7,0,17,0,0,0,1,3,2,0,120,164,6,0,17,0,0,0,1,3,1,0,224,123,6,0,17,0,0,0,1,3,3,0,16,74,6,0,0,0,0,0,254,0,4,0,136,160,5,0,18,0,0,0,1,192,0,0,16,150,7,0,18,0,0,0,1,192,128,0,120,198,7,0,18,0,0,0,1,192,64,0,160,103,7,0,18,0,0,0,1,192,192,0,16,53,7,0,0,0,0,0,254,0,4,0,56,191,4,0,18,0,0,0,1,48,0,0,144,175,2,0,18,0,0,0,1,48,32,0,8,161,2,0,18,0,0,0,1,48,16,0,176,147,2,0,18,0,0,0,1,48,48,0,216,135,2,0,0,0,0,0,254,0,4,0,96,123,2,0,18,0,0,0,1,12,0,0,8,49,4,0,18,0,0,0,1,12,8,0,72,246,3,0,18,0,0,0,1,12,4,0,192,255,2,0,18,0,0,0,1,12,12,0,208,75,4,0,0,0,0,0,254,0,2,0,0,0,0,0,18,0,0,0,1,2,0,0,136,159,3,0,18,0,0,0,1,2,2,0,64,56,2,0,107,49,45,49,48,46,117,57,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,175,71,254,46,0,0,16,1,107,49,45,48,57,46,117,56,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,197,135,193,23,0,0,16,1,107,49,45,48,56,46,117,56,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,127,249,90,148,0,0,16,1,107,49,45,48,55,46,117,56,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,167,228,66,60,0,0,16,1,107,49,45,49,53,46,117,54,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,151,211,69,133,0,0,32,0,107,49,45,49,51,46,117,53,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,37,185,183,177,0,0,32,0,107,49,45,49,52,46,117,53,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,107,148,45,66,0,0,32,0,107,49,45,49,50,46,117,52,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,174,19,113,88,0,0,32,0,107,49,45,48,50,46,117,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,67,185,199,42,0,0,32,0,107,49,45,48,51,46,117,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,147,220,202,51,0,0,32,0,107,49,45,48,49,46,117,52,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,5,131,53,182,0,0,32,0,107,49,45,48,52,46,117,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,96,157,45,233,0,0,32,0,107,49,45,48,53,46,117,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,163,238,174,95,0,0,32,0,107,49,45,48,54,46,117,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,169,46,78,151,0,0,32,0,115,102,95,99,111,108,50,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,153,175,239,160,0,0,32,0,115,102,95,99,111,108,50,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,229,87,109,165,0,0,32,0,115,102,95,99,111,108,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,159,191,92,0,0,32,0,107,49,45,49,49,46,117,56,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,90,112,244,135,0,0,16,1,115,102,95,114,49,57,101,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,175,71,254,46,0,0,16,1,115,102,95,114,50,48,101,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,81,121,44,244,0,0,16,1,115,102,95,114,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,167,228,66,60,0,0,16,1,115,102,95,114,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,151,211,69,133,0,0,32,0,115,102,95,114,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,37,185,183,177,0,0,32,0,115,102,95,114,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,107,148,45,66,0,0,32,0,115,102,95,114,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,174,19,113,88,0,0,32,0,115,102,95,114,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,67,185,199,42,0,0,32,0,115,102,95,114,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,147,220,202,51,0,0,32,0,115,102,95,114,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,5,131,53,182,0,0,32,0,115,102,95,114,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,96,157,45,233,0,0,32,0,115,102,95,114,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,163,238,174,95,0,0,32,0,115,102,95,114,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,169,46,78,151,0,0,32,0,115,102,95,99,111,108,50,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,153,175,239,160,0,0,32,0,115,102,95,99,111,108,50,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,229,87,109,165,0,0,32,0,115,102,95,99,111,108,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,159,191,92,0,0,32,0,115,102,95,114,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,90,112,244,135,0,0,16,1,115,102,95,114,49,57,106,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,179,200,122,154,0,0,16,1,115,102,95,114,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,167,228,66,60,0,0,16,1,115,102,95,114,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,151,211,69,133,0,0,32,0,115,102,95,114,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,37,185,183,177,0,0,32,0,115,102,95,114,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,107,148,45,66,0,0,32,0,115,102,95,114,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,174,19,113,88,0,0,32,0,115,102,95,114,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,67,185,199,42,0,0,32,0,115,102,95,114,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,147,220,202,51,0,0,32,0,115,102,95,114,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,5,131,53,182,0,0,32,0,115,102,95,114,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,96,157,45,233,0,0,32,0,115,102,95,114,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,163,238,174,95,0,0,32,0,115,102,95,114,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,169,46,78,151,0,0,32,0,115,102,95,99,111,108,50,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,153,175,239,160,0,0,32,0,115,102,95,99,111,108,50,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,229,87,109,165,0,0,32,0,115,102,95,99,111,108,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,159,191,92,0,0,32,0,115,102,95,114,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,90,112,244,135,0,0,16,1,114,111,109,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,8,211,193,233,1,0,16,1,114,111,109,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,151,152,127,134,1,0,16,1,114,111,109,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,40,103,100,211,1,0,16,1,114,111,109,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,77,219,9,210,1,0,16,1,114,111,109,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,207,148,177,117,2,0,16,1,114,111,109,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,190,65,178,251,3,0,32,0,114,111,109,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,129,222,60,173,3,0,32,0,114,111,109,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,207,238,165,176,4,0,32,0,114,111,109,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,93,218,188,27,5,0,32,0,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,246,134,153,230,6,0,64,0,49,115,108,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,94,49,11,232,1,0,16,1,50,115,108,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,123,86,112,157,1,0,16,1,51,115,108,46,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,87,148,195,100,1,0,16,1,52,115,108,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,165,105,68,155,2,0,32,0,53,115,108,46,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,52,161,175,41,2,0,32,0,49,56,115,48,51,48,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,203,186,69,230,3,0,32,0,15,0,0,0,255,255,32,0,0,0,0,0,16,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,72,4,1,0,15,0,0,0,1,32,32,0,96,135,7,0,15,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,16,0,0,0,1,3,3,0,208,239,7,0,16,0,0,0,1,3,2,0,120,187,7,0,16,0,0,0,1,3,1,0,136,23,1,0,16,0,0,0,1,3,0,0,80,177,6,0,0,0,0,0,254,0,4,0,160,123,6,0,16,0,0,0,1,12,8,0,160,36,8,0,16,0,0,0,1,12,12,0,208,239,7,0,16,0,0,0,1,12,4,0,16,79,1,0,16,0,0,0,1,12,0,0,80,177,6,0,0,0,0,0,254,0,2,0,128,129,4,0,16,0,0,0,1,48,48,0,192,255,2,0,16,0,0,0,1,48,32,0,208,75,4,0,16,0,0,0,1,48,16,0,8,49,4,0,16,0,0,0,1,48,0,0,152,21,4,0,0,0,0,0,254,0,2,0,64,37,5,0,16,0,0,0,1,64,64,0,80,110,6,0,16,0,0,0,1,64,0,0,120,7,5,0,0,0,0,0,254,0,2,0,200,30,2,0,16,0,0,0,1,128,0,0,120,97,1,0,16,0,0,0,1,128,128,0,96,19,1,0,49,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,36,88,213,130,1,0,16,1,50,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,130,166,243,223,1,0,16,1,51,46,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,230,110,0,124,1,0,16,1,52,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,7,222,142,15,2,0,32,0,53,46,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,112,192,206,36,2,0,32,0,49,56,115,48,51,48,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,203,186,69,230,3,0,32,0,15,0,0,0,255,255,32,0,0,0,0,0,16,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,72,4,1,0,15,0,0,0,1,32,32,0,96,135,7,0,15,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,16,0,0,0,1,3,3,0,208,239,7,0,16,0,0,0,1,3,2,0,120,187,7,0,16,0,0,0,1,3,1,0,136,23,1,0,16,0,0,0,1,3,0,0,80,177,6,0,0,0,0,0,254,0,4,0,160,123,6,0,16,0,0,0,1,12,8,0,160,36,8,0,16,0,0,0,1,12,12,0,208,239,7,0,16,0,0,0,1,12,4,0,16,79,1,0,16,0,0,0,1,12,0,0,80,177,6,0,0,0,0,0,254,0,2,0,128,129,4,0,16,0,0,0,1,48,48,0,8,49,4,0,16,0,0,0,1,48,32,0,152,21,4,0,16,0,0,0,1,48,16,0,72,246,3,0,16,0,0,0,1,48,0,0,176,108,5,0,0,0,0,0,254,0,2,0,64,37,5,0,16,0,0,0,1,64,64,0,208,98,2,0,16,0,0,0,1,64,0,0,200,15,5,0,0,0,0,0,254,0,2,0,200,30,2,0,16,0,0,0,1,128,0,0,120,97,1,0,16,0,0,0,1,128,128,0,96,19,1,0,105,115,45,104,48,45,100,46,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,187,10,148,128,1,0,16,1,105,115,45,108,48,45,100,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,214,238,75,184,1,0,16,1,105,115,45,104,49,46,53,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,242,225,168,155,1,0,16,1,105,115,45,108,49,46,53,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,38,6,224,228,1,0,16,1,109,116,50,115,104,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,67,234,203,30,2,0,16,1,109,116,50,115,108,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,49,181,213,143,2,0,16,1,99,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,181,228,97,126,3,0,32,0,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,100,117,102,10,3,0,32,0,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,18,67,180,94,3,0,32,0,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,148,98,134,242,3,0,32,0,107,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,120,38,154,140,4,0,32,0,107,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,120,223,85,84,4,0,32,0,107,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,65,140,37,58,4,0,32,0,107,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,20,26,233,193,4,0,32,0,100,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,159,158,59,113,5,0,64,0,109,116,50,101,101,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,113,249,138,32,6,0,16,1,112,97,108,49,54,108,56,45,109,57,50,45,97,45,51,109,46,105,99,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,7,0,0,16,112,97,108,49,54,108,56,45,109,57,50,45,97,45,55,106,46,105,99,52,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,7,0,0,16,112,97,108,49,54,108,56,45,109,57,50,45,97,45,57,106,46,105,99,53,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,7,0,0,16,112,97,108,49,54,108,56,45,109,57,50,45,98,45,50,108,46,105,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,7,0,0,16,112,97,108,49,54,108,56,45,109,57,50,45,98,45,55,104,46,105,99,52,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,7,0,0,16,48,55,50,45,103,48,50,46,49,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,214,225,12,88,1,0,16,1,48,55,50,45,103,48,49,46,49,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,239,61,132,159,1,0,16,1,48,55,50,45,106,49,51,46,49,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,189,42,222,170,1,0,16,1,48,55,50,45,106,49,50,46,49,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,242,18,158,71,1,0,16,1,48,55,50,45,101,48,51,46,54,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,53,122,107,134,2,0,16,1,48,55,50,45,98,48,55,46,49,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,16,201,30,186,3,0,32,0,48,55,50,45,98,48,54,46,49,54,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,171,188,43,207,3,0,32,0,48,55,50,45,98,48,56,46,51,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,173,0,229,125,4,0,32,0,48,55,50,45,98,48,57,46,56,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,147,80,8,170,4,0,32,0,48,55,50,45,98,49,48,46,49,50,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,83,189,125,87,4,0,32,0,48,55,50,45,98,49,49,46,49,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,93,176,250,85,4,0,32,0,48,55,50,45,100,48,53,46,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,59,167,151,19,5,0,64,0,48,55,50,45,100,48,52,46,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,19,128,119,120,5,0,64,0,115,105,109,112,115,111,110,115,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,73,4,63,236,0,0,0,8,115,105,108,107,119,111,114,109,106,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,34,223,243,109,1,0,16,1,115,105,108,107,119,111,114,109,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,81,187,199,166,1,0,16,1,115,105,108,107,119,111,114,109,106,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,208,72,152,183,2,0,16,1,115,105,108,107,119,111,114,109,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,217,28,10,232,3,0,32,0,115,105,108,107,119,111,114,109,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,89,209,56,17,4,0,32,0,115,105,108,107,119,111,114,109,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,247,20,98,217,4,0,32,0,115,105,108,107,119,111,114,109,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,142,179,148,4,4,0,32,0,115,105,108,107,119,111,114,109,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,245,205,227,140,4,0,32,0,115,105,108,107,119,111,114,109,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,187,56,113,140,5,0,32,0,115,105,108,107,119,111,114,109,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,118,196,3,108,5,0,32,0,115,105,108,107,119,111,114,109,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,143,86,15,187,5,0,32,0,115,105,108,107,119,111,114,109,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,164,208,58,119,5,0,32,0,115,105,108,107,119,111,114,109,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,75,246,157,64,6,0,32,0,115,105,108,107,119,111,114,109,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,201,82,64,110,6,0,32,0,115,105,108,107,119,111,114,109,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,99,237,146,146,6,0,32,0,115,105,108,107,119,111,114,109,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,61,86,164,63,6,0,32,0,115,105,108,107,119,111,114,109,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,68,54,85,91,7,0,64,0,115,105,108,107,119,111,114,109,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,206,124,39,165,1,0,16,1,115,105,108,107,119,111,114,109,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,81,187,199,166,1,0,16,1,115,105,108,107,119,111,114,109,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,135,245,137,181,2,0,16,1,115,105,108,107,119,111,114,109,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,217,28,10,232,3,0,32,0,115,105,108,107,119,111,114,109,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,89,209,56,17,4,0,32,0,115,105,108,107,119,111,114,109,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,247,20,98,217,4,0,32,0,115,105,108,107,119,111,114,109,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,142,179,148,4,4,0,32,0,115,105,108,107,119,111,114,109,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,245,205,227,140,4,0,32,0,115,105,108,107,119,111,114,109,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,187,56,113,140,5,0,32,0,115,105,108,107,119,111,114,109,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,118,196,3,108,5,0,32,0,115,105,108,107,119,111,114,109,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,143,86,15,187,5,0,32,0,115,105,108,107,119,111,114,109,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,164,208,58,119,5,0,32,0,115,105,108,107,119,111,114,109,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,75,246,157,64,6,0,32,0,115,105,108,107,119,111,114,109,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,201,82,64,110,6,0,32,0,115,105,108,107,119,111,114,109,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,99,237,146,146,6,0,32,0,115,105,108,107,119,111,114,109,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,61,86,164,63,6,0,32,0,115,105,108,107,119,111,114,109,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,68,54,85,91,7,0,64,0,114,111,109,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,252,0,82,78,1,0,16,0,114,111,109,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,140,199,204,115,1,0,16,0,114,111,109,49,50,46,114,111,109,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,4,61,57,150,2,0,32,0,114,111,109,48,56,46,114,111,109,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,98,212,241,35,2,0,32,0,114,111,109,48,52,46,114,111,109,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,215,187,240,217,2,0,32,0,114,111,109,49,51,46,114,111,109,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,142,105,161,76,2,0,32,0,114,111,109,48,57,46,114,111,109,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,244,91,11,239,2,0,32,0,114,111,109,48,53,46,114,111,109,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,37,110,45,81,2,0,32,0,114,111,109,49,52,46,114,111,109,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,196,25,11,208,2,0,32,0,114,111,109,49,48,46,114,111,109,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,128,66,50,125,2,0,32,0,114,111,109,48,54,46,114,111,109,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,96,96,194,58,2,0,32,0,114,111,109,48,55,46,114,111,109,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,157,255,198,159,2,0,32,0,114,111,109,49,49,46,114,111,109,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,28,175,171,17,2,0,32,0,114,111,109,49,53,46,114,111,109,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,104,177,163,38,2,0,32,0,114,111,109,48,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,171,167,11,177,3,0,64,0,114,111,109,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,85,180,140,219,4,0,64,0,101,97,115,116,45,49,50,45,49,46,105,99,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,98,211,131,88,2,0,0,0,101,97,115,116,45,49,52,45,49,46,105,99,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,213,188,103,50,2,0,0,0,101,97,115,116,45,49,49,46,105,99,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,40,68,218,53,2,0,0,0,101,97,115,116,45,48,57,46,105,99,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,74,177,5,47,2,0,0,0,101,97,115,116,45,49,51,46,105,99,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,171,97,24,101,9,0,0,0,101,97,115,116,45,48,52,46,105,99,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,23,114,35,83,11,0,0,0,101,97,115,116,45,48,54,46,105,99,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,167,223,230,230,11,0,0,0,101,97,115,116,45,48,51,46,105,99,51,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,70,40,155,27,11,0,0,0,101,97,115,116,45,48,53,46,105,99,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,197,114,36,224,11,0,0,0,101,97,115,116,45,48,49,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,26,255,31,180,24,0,0,0,101,97,115,116,45,48,50,46,105,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,57,92,222,224,25,0,0,0,101,97,115,116,45,49,50,45,49,46,105,99,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,98,211,131,88,2,0,0,0,101,97,115,116,45,49,48,45,49,46,105,99,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,252,6,67,88,2,0,0,0,101,97,115,116,45,49,49,46,105,99,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,40,68,218,53,2,0,0,0,101,97,115,116,45,48,57,46,105,99,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,74,177,5,47,2,0,0,0,101,97,115,116,45,49,51,46,105,99,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,171,97,24,101,9,0,0,0,101,97,115,116,45,48,52,46,105,99,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,23,114,35,83,11,0,0,0,101,97,115,116,45,48,54,46,105,99,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,167,223,230,230,11,0,0,0,101,97,115,116,45,48,51,46,105,99,51,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,70,40,155,27,11,0,0,0,101,97,115,116,45,48,53,46,105,99,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,197,114,36,224,11,0,0,0,101,97,115,116,45,48,49,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,26,255,31,180,24,0,0,0,101,97,115,116,45,48,50,46,105,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,57,92,222,224,25,0,0,0,50,51,56,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,111,69,119,86,1,0,16,1,50,51,56,45,112,50,46,115,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,197,9,74,91,1,0,16,1,50,51,56,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,2,0,219,206,149,31,2,0,32,0,50,51,56,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,129,161,198,144,3,0,32,0,50,51,56,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,240,32,135,136,3,0,32,0,50,51,56,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,163,58,57,44,3,0,32,0,50,51,56,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,235,9,233,185,3,0,32,0,50,51,56,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,235,104,44,194,3,0,32,0,50,51,56,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,205,35,147,17,3,0,32,0,50,51,56,45,99,55,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,237,231,44,167,3,0,32,0,50,51,56,45,99,56,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,251,46,124,28,3,0,32,0,50,51,56,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,24,149,91,7,4,0,16,1,50,51,56,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,239,11,12,38,5,0,64,0,50,51,56,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,158,213,215,74,5,0,64,0,50,52,54,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,129,119,75,109,1,0,16,1,50,52,54,45,112,50,46,115,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,195,4,234,114,1,0,16,1,50,52,54,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,55,6,54,42,2,0,32,0,50,52,54,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,197,158,172,71,3,0,32,0,50,52,54,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,79,182,202,123,3,0,32,0,50,52,54,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,232,115,47,219,3,0,32,0,50,52,54,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,78,133,3,85,3,0,32,0,50,52,54,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,1,55,91,5,3,0,32,0,50,52,54,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,225,170,44,126,3,0,32,0,50,52,54,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,209,74,96,208,4,0,16,1,50,52,54,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,198,111,152,22,5,0,64,0,50,52,54,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,131,30,164,173,5,0,64,0,50,52,54,45,118,51,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,219,165,91,160,5,0,64,0,121,117,110,115,117,110,49,54,46,117,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,33,85,21,138,1,0,16,1,121,117,110,115,117,110,49,54,46,117,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,16,140,153,196,1,0,16,1,121,117,110,115,117,110,49,54,46,117,54,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,196,178,15,227,3,0,32,0,121,117,110,115,117,110,49,54,46,117,54,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,56,37,112,125,3,0,32,0,121,117,110,115,117,110,49,54,46,117,54,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,127,68,151,3,0,32,0,121,117,110,115,117,110,49,54,46,117,55,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,149,120,31,27,3,0,32,0,121,117,110,115,117,110,49,54,46,117,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,208,153,70,18,4,0,32,0,121,117,110,115,117,110,49,54,46,117,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,162,41,234,78,4,0,32,0,121,117,110,115,117,110,49,54,46,117,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,136,3,219,214,4,0,32,0,121,117,110,115,117,110,49,54,46,117,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,46,59,163,31,4,0,32,0,121,117,110,115,117,110,49,54,46,49,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,140,187,161,208,5,0,64,0,109,97,48,50,114,111,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,73,177,120,166,0,0,16,1,109,97,48,50,114,111,109,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,18,162,38,242,0,0,16,1,109,97,48,50,114,111,109,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,66,113,121,14,0,0,32,0,109,97,48,50,114,111,109,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,83,250,166,114,0,0,32,0,109,97,48,50,114,111,109,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,89,229,106,17,0,0,32,0,109,97,48,50,114,111,109,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,126,165,232,221,0,0,16,1,109,97,48,50,114,111,109,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,174,124,158,25,0,0,64,0,20,0,0,0,255,255,0,0,0,0,0,0,21,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,0,0,0,0,20,0,0,0,1,1,0,0,144,202,5,0,20,0,0,0,1,1,1,0,40,182,1,0,0,0,0,0,254,0,2,0,40,214,8,0,20,0,0,0,1,2,0,0,248,38,7,0,20,0,0,0,1,2,2,0,144,86,8,0,0,0,0,0,254,0,2,0,0,0,0,0,20,0,0,0,1,4,0,0,168,84,8,0,20,0,0,0,1,4,4,0,208,87,7,0,0,0,0,0,254,0,2,0,240,233,7,0,20,0,0,0,1,8,0,0,152,182,7,0,20,0,0,0,1,8,8,0,96,135,7,0,0,0,0,0,254,0,4,0,200,87,7,0,20,0,0,0,1,48,0,0,232,38,7,0,20,0,0,0,1,48,16,0,120,164,6,0,20,0,0,0,1,48,32,0,224,123,6,0,20,0,0,0,1,48,48,0,16,74,6,0,0,0,0,0,254,0,4,0,160,123,6,0,20,0,0,0,1,192,0,0,232,38,7,0,20,0,0,0,1,192,64,0,120,164,6,0,20,0,0,0,1,192,128,0,224,123,6,0,20,0,0,0,1,192,192,0,16,74,6,0,0,0,0,0,254,0,4,0,136,160,5,0,21,0,0,0,1,3,0,0,16,68,5,0,21,0,0,0,1,3,1,0,248,36,5,0,21,0,0,0,1,3,2,0,40,7,5,0,21,0,0,0,1,3,3,0,96,128,5,0,0,0,0,0,254,0,4,0,248,6,5,0,21,0,0,0,1,12,0,0,216,129,4,0,21,0,0,0,1,12,4,0,208,102,4,0,21,0,0,0,1,12,8,0,176,227,4,0,21,0,0,0,1,12,12,0,248,75,4,0,0,0,0,0,254,0,4,0,224,149,1,0,21,0,0,0,1,48,0,0,8,49,4,0,21,0,0,0,1,48,16,0,72,246,3,0,21,0,0,0,1,48,32,0,208,75,4,0,21,0,0,0,1,48,48,0,192,255,2,0,0,0,0,0,254,0,2,0,48,185,3,0,21,0,0,0,1,64,0,0,96,135,7,0,21,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,0,0,0,0,21,0,0,0,1,128,0,0,104,82,2,0,21,0,0,0,1,128,128,0,40,247,3,0,0,0,0,0,115,104,97,100,111,119,119,95,49,46,51,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,135,163,251,254,1,0,16,1,115,104,97,100,111,119,119,95,50,46,52,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,24,107,157,155,1,0,16,1,103,97,105,100,101,110,95,51,46,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,106,62,253,117,2,0,16,1,103,97,105,100,101,110,95,53,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,247,53,64,141,3,0,32,0,49,52,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,170,221,207,30,4,0,32,0,49,53,46,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,150,166,145,18,4,0,32,0,49,54,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,202,71,11,20,4,0,32,0,49,55,46,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,203,204,56,118,4,0,32,0,49,56,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,214,175,173,63,5,0,32,0,49,57,46,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,91,157,174,221,5,0,32,0,50,48,46,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,147,122,207,8,5,0,32,0,50,49,46,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,245,146,200,26,5,0,32,0,54,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,159,223,204,231,6,0,32,0,56,46,51,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,128,248,247,126,6,0,32,0,49,48,46,51,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,236,29,69,166,6,0,32,0,115,104,97,100,111,119,119,95,49,50,97,46,120,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,49,119,176,155,6,0,32,0,115,104,97,100,111,119,119,95,49,50,98,46,120,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,162,80,169,164,6,0,32,0,55,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,149,236,107,1,6,0,32,0,57,46,49,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,211,127,155,110,6,0,32,0,49,49,46,49,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,94,223,191,127,6,0,32,0,115,104,97,100,111,119,119,95,49,51,97,46,120,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,165,47,109,153,6,0,32,0,115,104,97,100,111,119,119,95,49,51,98,46,120,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,52,138,223,184,6,0,32,0,52,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,249,250,224,176,7,0,64,0,51,50,97,49,50,45,48,49,49,46,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,8,30,4,12,0,0,16,1,51,50,97,49,51,45,48,49,48,46,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,97,83,152,0,0,0,16,1,51,50,97,49,52,45,48,49,48,46,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,37,202,3,234,0,0,16,1,51,50,106,49,53,45,48,49,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,74,168,195,61,0,0,16,1,51,50,106,49,48,45,48,46,52,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,117,244,218,101,0,0,16,1,51,50,106,49,49,45,48,46,53,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,147,217,82,114,0,0,32,0,51,50,106,52,45,48,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,182,165,190,30,0,0,32,0,51,50,106,53,45,48,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,181,38,0,96,0,0,32,0,51,50,106,54,45,48,46,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,190,142,222,108,0,0,32,0,51,50,106,55,45,48,46,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,34,121,179,188,0,0,32,0,51,50,106,56,45,48,46,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,246,235,27,32,0,0,32,0,51,50,106,49,45,48,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,64,167,204,241,0,0,32,0,51,50,106,50,45,48,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,62,172,95,0,0,32,0,51,50,106,51,45,48,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,94,146,151,210,0,0,32,0,51,50,106,57,45,48,46,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,129,30,0,22,0,0,64,0,51,50,97,49,50,45,48,49,46,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,152,17,80,4,0,0,16,1,51,50,97,49,51,45,48,49,46,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,92,160,248,184,0,0,16,1,51,50,97,49,52,45,48,46,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,233,155,39,8,0,0,16,1,51,50,97,49,53,45,48,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,234,223,202,191,0,0,16,1,51,50,106,49,48,45,48,46,52,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,117,244,218,101,0,0,16,1,51,50,97,49,49,45,48,46,53,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,119,94,175,207,0,0,32,0,51,50,106,52,45,48,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,182,165,190,30,0,0,32,0,51,50,106,53,45,48,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,181,38,0,96,0,0,32,0,51,50,106,54,45,48,46,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,190,142,222,108,0,0,32,0,51,50,106,55,45,48,46,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,34,121,179,188,0,0,32,0,51,50,106,56,45,48,46,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,246,235,27,32,0,0,32,0,51,50,106,49,45,48,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,64,167,204,241,0,0,32,0,51,50,106,50,45,48,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,62,172,95,0,0,32,0,51,50,106,51,45,48,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,94,146,151,210,0,0,32,0,51,50,106,57,45,48,46,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,129,30,0,22,0,0,64,0,25,0,0,0,255,255,0,0,0,0,0,0,26,0,0,0,255,255,0,0,0,0,0,0,27,0,0,0,255,255,0,0,0,0,0,0,28,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,40,96,7,0,25,0,0,0,1,4,0,0,96,135,7,0,25,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,26,0,0,0,1,3,0,0,248,38,7,0,26,0,0,0,1,3,1,0,112,212,3,0,26,0,0,0,1,3,2,0,80,246,3,0,26,0,0,0,1,3,3,0,248,160,5,0,0,0,0,0,254,0,4,0,32,251,5,0,26,0,0,0,1,12,0,0,56,207,5,0,26,0,0,0,1,12,4,0,104,167,5,0,26,0,0,0,1,12,8,0,88,132,5,0,26,0,0,0,1,12,12,0,248,104,5,0,0,0,0,0,254,0,4,0,32,4,2,0,27,0,0,0,1,6,0,0,16,42,5,0,27,0,0,0,1,6,2,0,152,11,5,0,27,0,0,0,1,6,4,0,56,233,4,0,27,0,0,0,1,6,6,0,208,196,4,0,0,0,0,0,254,0,2,0,48,112,3,0,27,0,0,0,1,8,0,0,96,135,7,0,27,0,0,0,1,8,128,0,152,182,7,0,0,0,0,0,254,0,2,0,16,227,4,0,27,0,0,0,1,16,0,0,96,135,7,0,27,0,0,0,1,16,16,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,27,0,0,0,1,32,0,0,96,135,7,0,27,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,28,0,0,0,1,1,0,0,96,135,7,0,28,0,0,0,1,1,1,0,152,182,7,0,0,0,0,0,254,0,2,0,184,89,6,0,28,0,0,0,1,2,0,0,96,135,7,0,28,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,100,107,45,48,50,46,49,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,133,250,248,135,1,0,0,0,100,107,45,48,54,46,55,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,209,98,173,105,1,0,0,0,100,107,45,48,53,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,40,209,141,89,1,0,0,0,100,107,45,48,52,46,49,48,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,212,5,211,54,1,0,0,0,100,107,45,48,51,46,49,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,209,15,217,111,1,0,0,0,100,107,45,48,49,46,49,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,218,59,254,113,2,0,0,0,100,107,45,48,55,46,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,204,75,126,136,3,0,0,0,100,107,45,48,48,46,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,170,117,185,105,5,0,0,0,100,107,45,49,50,46,49,53,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,113,35,92,97,6,0,0,0,100,107,45,49,51,46,49,52,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,3,165,154,71,6,0,0,0,100,107,45,49,52,46,49,51,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,70,66,194,205,6,0,0,0,100,107,45,49,53,46,49,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,27,129,219,136,6,0,0,0,100,107,45,49,54,46,49,48,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,189,118,26,6,6,0,0,0,100,107,45,49,55,46,57,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,175,216,197,166,6,0,0,0,100,107,45,49,56,46,56,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,87,103,70,77,6,0,0,0,100,107,45,49,57,46,54,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,62,232,17,25,6,0,0,0,100,107,45,49,49,46,49,50,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,159,113,245,92,7,0,0,0,100,107,45,49,48,46,49,52,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,8,109,142,64,7,0,0,0,100,107,45,48,57,46,49,53,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,172,127,85,193,7,0,0,0,100,107,45,48,56,46,49,55,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,245,233,84,94,7,0,0,0,100,107,46,49,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,4,0,0,16,100,107,45,50,48,46,57,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,136,213,60,255,0,0,0,8,49,57,52,49,32,45,32,99,111,117,110,116,101,114,32,97,116,116,97,99,107,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,226,136,69,140,0,0,16,1,115,102,105,105,105,51,95,101,117,114,111,46,50,57,102,52,48,48,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,147,242,187,48,0,0,0,3,115,102,105,105,105,51,40,95,95,57,57,48,53,49,50,41,45,115,105,109,109,49,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,53,98,230,102,0,0,16,1,115,102,105,105,105,51,40,95,95,57,57,48,53,49,50,41,45,115,105,109,109,49,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,95,140,110,24,0,0,16,1,115,102,105,105,105,51,40,95,95,57,57,48,53,49,50,41,45,115,105,109,109,49,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,171,140,225,188,0,0,16,1,115,102,105,105,105,51,40,95,95,57,57,48,53,49,50,41,45,115,105,109,109,49,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,201,194,157,18,0,0,16,1,115,102,105,105,105,51,45,115,105,109,109,50,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,158,150,235,6,0,0,16,1,115,102,105,105,105,51,45,115,105,109,109,50,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,130,159,3,231,0,0,16,1,115,102,105,105,105,51,45,115,105,109,109,50,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,247,150,92,100,0,0,16,1,115,102,105,105,105,51,45,115,105,109,109,50,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,177,250,14,97,0,0,16,1,115,102,105,105,105,51,45,115,105,109,109,51,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,121,31,170,123,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,51,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,254,248,75,35,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,51,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,8,195,235,217,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,51,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,119,186,60,41,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,51,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,71,231,85,96,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,51,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,252,166,154,73,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,51,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,158,135,19,108,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,51,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,222,142,79,207,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,52,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,186,213,31,9,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,52,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,23,137,202,11,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,52,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,139,87,253,160,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,52,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,153,198,248,75,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,52,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,133,135,123,19,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,52,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,113,6,183,79,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,52,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,164,116,35,131,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,52,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,109,87,136,28,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,53,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,144,145,125,198,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,53,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,104,152,183,108,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,53,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,14,147,105,223,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,53,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,224,84,55,51,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,53,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,23,212,246,120,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,53,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,177,217,202,140,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,53,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,229,89,222,133,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,53,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,179,41,126,238,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,54,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,66,144,166,141,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,54,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,196,122,140,28,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,54,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,29,52,113,166,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,54,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,73,2,153,26,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,54,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,172,57,203,32,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,54,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,47,75,132,95,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,54,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,40,141,14,69,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,54,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,135,65,95,204,0,0,32,0,98,104,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,226,226,82,200,1,0,16,0,98,104,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,161,164,4,188,1,0,16,0,98,104,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,11,167,156,186,1,0,16,0,98,104,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,223,93,188,234,1,0,16,0,98,104,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,118,250,226,83,2,0,16,0,98,104,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,73,176,241,176,3,0,32,0,98,104,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,167,219,77,23,3,0,32,0,98,104,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,174,240,184,31,4,0,32,0,98,104,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,7,196,139,253,4,0,32,0,98,104,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,195,172,48,29,4,0,32,0,98,104,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,103,55,128,124,4,0,32,0,98,104,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,67,124,222,238,4,0,32,0,98,104,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,217,92,120,159,4,0,32,0,98,104,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,75,17,166,7,5,0,64,0,98,104,50,118,101,114,51,106,46,57,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,2,0,114,177,247,126,1,0,16,0,98,104,51,118,101,114,51,106,46,49,48,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,147,167,222,63,1,0,16,0,98,104,119,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,102,0,182,98,1,0,16,0,98,104,119,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,92,82,216,22,1,0,16,0,98,104,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,118,250,226,83,2,0,16,0,98,104,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,73,176,241,176,3,0,32,0,98,104,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,167,219,77,23,3,0,32,0,98,104,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,174,240,184,31,4,0,32,0,98,104,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,7,196,139,253,4,0,32,0,98,104,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,195,172,48,29,4,0,32,0,98,104,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,103,55,128,124,4,0,32,0,98,104,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,67,124,222,238,4,0,32,0,98,104,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,217,92,120,159,4,0,32,0,98,104,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,75,17,166,7,5,0,64,0,48,49,55,45,104,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,224,202,236,51,1,0,16,1,48,49,55,45,112,50,46,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,179,187,36,48,1,0,16,1,48,49,55,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,77,32,70,178,2,0,32,0,48,49,55,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,161,130,235,180,3,0,32,0,48,49,55,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,13,85,92,213,3,0,32,0,48,49,55,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,101,239,81,237,3,0,32,0,48,49,55,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,203,201,243,244,3,0,32,0,48,49,55,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,198,52,79,155,4,0,16,1,48,49,55,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,149,50,102,35,5,0,64,0,48,49,55,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,101,103,30,246,5,0,64,0,50,54,49,45,112,104,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,10,188,212,224,1,0,16,1,50,54,49,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,156,77,216,222,3,0,32,0,50,54,49,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,72,67,235,184,3,0,32,0,50,54,49,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,74,3,226,132,3,0,32,0,50,54,49,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,83,174,69,11,3,0,32,0,50,54,49,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,57,28,80,125,4,0,16,1,50,54,49,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,129,0,195,100,5,0,64,0,50,54,49,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,71,156,42,57,5,0,64,0,50,54,49,45,118,51,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,227,235,167,193,5,0,64,0,50,54,49,45,118,52,46,118,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,133,208,0,144,5,0,64,0,48,52,48,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,194,2,222,109,1,0,16,1,48,52,48,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,163,2,152,205,2,0,32,0,48,52,48,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,153,234,168,250,3,0,32,0,48,52,48,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,101,236,208,135,3,0,32,0,48,52,48,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,128,186,181,36,3,0,32,0,48,52,48,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,48,153,158,28,3,0,32,0,48,52,48,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,202,75,222,212,4,0,16,1,48,52,48,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,93,75,203,113,5,0,64,0,48,52,48,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,206,206,197,5,0,64,0,115,101,45,48,50,46,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,227,200,240,8,2,0,0,0,115,101,45,48,49,46,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,75,166,108,160,2,0,0,0,115,101,45,48,51,46,51,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,190,152,89,103,9,0,0,0,115,101,45,48,52,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,209,10,146,11,0,0,0,115,101,45,48,53,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,149,201,151,210,11,0,0,0,115,101,45,48,54,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,114,231,213,128,24,0,0,0,54,99,95,115,122,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,37,81,88,105,1,0,16,1,55,99,95,115,122,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,184,97,241,34,1,0,16,1,57,99,95,115,122,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,237,17,113,76,1,0,16,1,49,49,101,95,115,122,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,102,53,7,166,2,0,16,1,57,104,95,115,122,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,46,186,115,49,4,0,32,0,51,101,95,115,122,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,48,46,120,99,5,0,32,0,49,101,95,115,122,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,19,159,125,213,5,0,32,0,51,100,95,115,122,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,127,77,61,27,5,0,32,0,49,100,95,115,122,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,159,162,179,245,5,0,32,0,51,98,95,115,122,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,253,125,212,17,5,0,32,0,49,98,95,115,122,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,104,59,112,223,5,0,32,0,51,102,95,115,122,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,247,155,187,54,5,0,32,0,49,102,95,115,122,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,201,6,143,218,5,0,32,0,51,106,95,115,122,49,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,74,178,247,141,6,0,32,0,49,106,95,115,122,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,84,76,93,104,6,0,32,0,51,104,95,115,122,49,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,187,242,15,80,6,0,32,0,49,104,95,115,122,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,68,210,179,0,6,0,32,0,109,98,55,49,49,52,101,46,49,53,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,152,204,107,217,0,0,0,8,117,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,158,254,55,1,0,16,1,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,59,81,120,130,1,0,16,1,117,49,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,12,225,186,133,2,0,16,1,48,46,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,207,13,165,40,3,0,32,0,50,46,117,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,25,110,212,48,3,0,32,0,49,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,36,232,196,249,3,0,32,0,51,46,117,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,47,20,159,97,3,0,32,0,117,56,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,203,52,174,43,4,0,32,0,117,56,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,240,115,183,92,4,0,32,0,117,49,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,94,177,173,232,4,0,32,0,117,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,54,181,239,103,4,0,32,0,117,57,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,38,56,182,247,4,0,32,0,117,49,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,36,117,3,205,5,0,64,0,117,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,221,227,124,40,1,0,16,1,117,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,51,240,116,181,1,0,16,1,117,49,50,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,12,225,186,133,2,0,16,1,117,54,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,125,123,11,27,3,0,32,0,117,54,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,170,178,24,174,3,0,32,0,117,55,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,22,135,127,171,3,0,32,0,117,55,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,131,139,44,127,3,0,32,0,117,54,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,60,144,42,50,3,0,32,0,117,54,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,248,234,70,213,3,0,32,0,117,55,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,132,77,19,230,3,0,32,0,117,56,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,9,22,154,3,0,32,0,117,56,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,71,198,161,197,4,0,32,0,117,56,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,98,174,178,37,4,0,32,0,117,49,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,240,126,32,180,4,0,32,0,117,57,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,138,129,64,140,4,0,32,0,117,57,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,49,242,199,93,4,0,32,0,117,49,51,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,35,94,16,73,5,0,64,0,98,104,119,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,56,1,67,225,1,0,16,0,98,104,119,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,116,147,31,238,1,0,16,0,98,104,119,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,102,0,182,98,1,0,16,0,98,104,119,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,92,82,216,22,1,0,16,0,98,104,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,118,250,226,83,2,0,16,0,98,104,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,73,176,241,176,3,0,32,0,98,104,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,167,219,77,23,3,0,32,0,98,104,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,174,240,184,31,4,0,32,0,98,104,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,7,196,139,253,4,0,32,0,98,104,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,195,172,48,29,4,0,32,0,98,104,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,103,55,128,124,4,0,32,0,98,104,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,67,124,222,238,4,0,32,0,98,104,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,217,92,120,159,4,0,32,0,98,104,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,75,17,166,7,5,0,64,0,57,49,49,45,97,48,49,46,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,93,145,98,51,1,0,16,1,57,49,49,45,97,48,50,46,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,133,130,199,251,1,0,16,1,57,49,49,45,97,48,51,46,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,242,180,36,108,1,0,16,1,57,49,49,45,97,48,52,46,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,22,215,249,111,1,0,16,1,57,49,49,45,97,48,53,46,48,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,6,84,69,144,2,0,16,1,57,49,49,45,97,48,56,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,35,72,224,231,3,0,32,0,57,49,49,45,97,48,55,46,55,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,169,212,64,111,3,0,32,0,57,49,49,45,97,49,50,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,182,187,118,137,4,0,32,0,57,49,49,45,97,49,49,46,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,16,120,59,63,5,0,32,0,57,49,49,45,97,49,51,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,74,88,138,243,6,0,32,0,57,49,49,45,97,49,48,46,55,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,251,65,227,128,7,0,32,0,57,49,49,45,97,48,57,46,55,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,25,69,243,152,7,0,32,0,57,49,49,45,97,48,54,46,57,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,64,148,199,18,8,0,64,0,98,110,100,45,48,48,55,46,56,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,110,100,247,150,0,0,0,8,115,122,45,48,49,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,253,73,223,152,1,0,16,1,55,99,95,115,122,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,184,97,241,34,1,0,16,1,115,122,45,48,51,106,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,191,122,84,148,1,0,16,1,49,49,101,95,115,122,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,102,53,7,166,2,0,16,1,57,104,95,115,122,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,46,186,115,49,4,0,32,0,51,101,95,115,122,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,48,46,120,99,5,0,32,0,49,101,95,115,122,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,19,159,125,213,5,0,32,0,51,100,95,115,122,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,127,77,61,27,5,0,32,0,49,100,95,115,122,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,159,162,179,245,5,0,32,0,51,98,95,115,122,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,253,125,212,17,5,0,32,0,49,98,95,115,122,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,104,59,112,223,5,0,32,0,51,102,95,115,122,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,247,155,187,54,5,0,32,0,49,102,95,115,122,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,201,6,143,218,5,0,32,0,51,106,95,115,122,49,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,74,178,247,141,6,0,32,0,49,106,95,115,122,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,84,76,93,104,6,0,32,0,51,104,95,115,122,49,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,187,242,15,80,6,0,32,0,49,104,95,115,122,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,68,210,179,0,6,0,32,0,109,98,55,49,49,52,101,46,49,53,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,152,204,107,217,0,0,0,8,103,120,53,52,53,95,103,48,51,95,49,50,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,211,224,8,184,1,0,16,1,103,120,53,52,53,95,103,48,50,95,49,48,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,134,5,44,178,1,0,16,1,103,120,53,52,53,95,103,48,49,95,56,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,101,204,167,70,2,0,16,1,103,120,53,52,53,95,103,48,53,95,53,102,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,156,52,108,133,3,0,32,0,103,120,53,52,53,95,103,48,54,95,54,102,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,1,118,173,20,4,0,32,0,103,120,53,52,53,95,104,48,52,95,52,102,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,163,17,108,192,4,0,32,0,103,120,53,52,53,95,54,51,48,49,95,49,102,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,111,88,132,245,5,0,32,0,103,120,53,52,53,95,54,51,48,49,95,50,102,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,177,77,70,173,5,0,32,0,103,120,53,52,53,95,54,51,48,49,95,51,102,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,35,93,71,189,5,0,32,0,103,120,53,52,53,95,54,51,48,49,95,55,102,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,51,210,12,43,5,0,32,0,103,120,53,52,53,95,54,51,48,49,95,56,102,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,88,207,199,193,5,0,32,0,55,55,53,45,102,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,167,51,89,141,1,0,16,1,55,55,53,45,102,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,128,61,246,30,1,0,16,1,55,55,53,45,99,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,90,120,237,12,2,0,16,1,55,55,53,45,97,48,55,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,243,189,22,231,3,0,32,0,55,55,53,45,97,48,55,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,165,227,134,9,3,0,32,0,55,55,53,45,102,48,55,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,21,9,179,176,3,0,32,0,55,55,53,45,102,48,55,103,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,125,130,237,251,3,0,32,0,55,55,53,45,102,48,55,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,142,190,132,241,3,0,32,0,55,55,53,45,102,48,55,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,72,195,86,123,3,0,32,0,55,55,53,45,97,48,56,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,164,17,221,61,3,0,32,0,55,55,53,45,97,48,56,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,99,217,7,16,3,0,32,0,55,55,53,45,102,48,56,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,236,218,171,83,3,0,32,0,55,55,53,45,102,48,56,103,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,110,90,248,61,3,0,32,0,55,55,53,45,102,48,56,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,206,202,45,16,3,0,32,0,55,55,53,45,102,48,56,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,22,112,157,173,3,0,32,0,55,55,53,45,97,48,53,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,69,112,118,160,4,0,32,0,55,55,53,45,97,48,53,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,8,111,101,47,4,0,32,0,55,55,53,45,97,48,53,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,253,212,138,171,4,0,32,0,55,55,53,45,97,48,53,102,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,182,177,14,28,4,0,32,0,55,55,53,45,102,48,53,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,30,118,71,86,4,0,32,0,55,55,53,45,102,48,53,103,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,202,44,105,161,4,0,32,0,55,55,53,45,102,48,53,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,111,106,103,173,4,0,32,0,55,55,53,45,102,48,53,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,207,91,146,63,4,0,32,0,55,55,53,45,97,48,54,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,208,74,163,119,4,0,32,0,55,55,53,45,97,48,54,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,148,12,145,138,4,0,32,0,55,55,53,45,97,48,54,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,101,181,63,86,4,0,32,0,55,55,53,45,97,48,54,102,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,192,149,73,225,4,0,32,0,55,55,53,45,102,48,54,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,193,243,230,94,4,0,32,0,55,55,53,45,102,48,54,103,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,77,39,69,38,4,0,32,0,55,55,53,45,102,48,54,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,250,100,183,200,4,0,32,0,55,55,53,45,102,48,54,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,89,95,89,214,4,0,32,0,55,55,53,45,97,48,52,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,15,46,251,126,5,0,64,0,55,55,53,45,97,48,52,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,51,43,26,244,5,0,64,0,55,55,53,45,97,48,52,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,20,143,229,228,5,0,64,0,55,55,53,45,97,48,52,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,246,54,103,212,5,0,64,0,55,55,53,45,102,48,52,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,99,227,247,251,5,0,64,0,55,55,53,45,102,48,52,102,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,45,239,49,176,5,0,64,0,55,55,53,45,102,48,52,103,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,187,123,16,238,5,0,64,0,55,55,53,45,102,48,52,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,70,171,15,251,5,0,64,0,55,55,53,97,48,57,46,98,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,223,224,209,70,6,0,0,8,115,114,48,48,49,106,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,255,243,49,237,1,0,16,1,115,114,48,48,54,106,46,56,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,93,250,156,158,1,0,16,1,115,114,48,49,51,46,49,56,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,187,12,192,74,2,0,16,1,115,114,48,48,50,45,55,52,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,123,92,225,151,3,0,32,0,115,114,48,48,51,45,55,52,46,49,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,113,121,54,234,3,0,32,0,115,114,48,48,55,46,49,55,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,199,128,111,136,4,0,32,0,115,114,48,48,56,46,49,56,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,144,188,76,167,4,0,32,0,115,114,48,48,52,46,49,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,161,52,84,226,5,0,32,0,115,114,48,48,53,46,50,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,59,3,48,22,5,0,32,0,115,114,48,48,57,46,49,57,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,47,152,157,123,5,0,32,0,115,114,48,49,48,46,50,48,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,82,83,158,110,5,0,32,0,115,114,48,49,50,46,49,53,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,77,61,132,56,7,0,64,0,115,114,48,49,49,46,49,52,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,22,86,128,129,6,0,64,0,104,98,45,48,48,46,49,49,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,173,186,167,183,0,0,0,8,53,46,52,113,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,231,249,5,200,1,0,16,1,54,46,52,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,55,165,167,237,1,0,16,1,115,106,50,48,49,45,110,119,46,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,66,202,100,90,1,0,16,1,57,46,56,113,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,18,226,103,135,2,0,16,1,56,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,14,22,203,155,3,0,32,0,55,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,157,198,80,178,3,0,32,0,52,46,52,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,211,54,99,170,4,0,32,0,51,46,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,181,134,45,126,4,0,32,0,50,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,56,73,37,195,5,0,32,0,49,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,250,166,22,93,5,0,32,0,115,106,52,48,50,45,110,119,46,56,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,6,61,211,182,6,0,32,0,115,106,52,48,51,45,110,119,46,55,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,86,63,20,7,6,0,32,0,115,106,52,48,52,45,110,119,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,40,65,19,143,7,0,32,0,115,106,52,48,53,45,110,119,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,153,22,216,111,7,0,32,0,115,106,52,48,54,45,110,119,46,55,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,230,51,78,99,7,0,32,0,115,106,52,48,55,45,110,119,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,6,255,102,92,7,0,32,0,115,106,52,48,56,45,110,119,46,55,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,161,30,59,106,7,0,32,0,115,106,52,48,57,45,110,119,46,55,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,19,66,118,216,7,0,32,0,115,106,52,48,49,45,110,119,46,49,48,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,89,171,223,37,8,0,16,1,50,46,117,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,38,154,129,87,1,0,16,1,49,46,117,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,71,232,136,195,1,0,16,1,48,108,46,117,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,81,172,228,183,2,0,32,0,48,104,46,117,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,39,108,94,35,2,0,32,0,49,108,46,117,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,140,196,136,60,2,0,32,0,49,104,46,117,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,110,106,98,21,2,0,32,0,50,108,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,100,47,233,65,2,0,32,0,50,104,46,117,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,132,46,230,74,2,0,32,0,51,108,46,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,15,95,186,67,2,0,32,0,51,104,46,117,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,18,187,1,255,2,0,32,0,52,108,46,117,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,147,213,145,228,2,0,32,0,52,104,46,117,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,122,55,221,123,2,0,32,0,115,111,117,110,100,46,117,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,105,255,203,133,3,0,64,0,101,101,112,114,111,109,45,115,98,111,109,98,101,114,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,70,136,195,122,0,0,0,8,101,101,48,52,101,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,66,244,202,192,1,0,16,1,101,101,48,51,101,46,49,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,225,10,215,156,1,0,16,1,101,101,48,50,101,46,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,104,99,78,160,1,0,16,1,101,101,48,49,101,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,82,249,211,147,2,0,16,1,101,101,48,48,101,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,95,249,114,89,3,0,32,0,104,48,49,95,101,101,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,29,92,166,150,4,0,32,0,97,48,51,95,101,101,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,209,189,57,96,5,0,32,0,97,48,50,95,101,101,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,82,130,45,179,5,0,32,0,106,49,49,95,101,101,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,101,226,131,188,6,0,32,0,106,49,50,95,101,101,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,13,48,15,14,6,0,32,0,99,48,49,95,101,101,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,141,166,37,54,7,0,32,0,104,48,52,95,101,101,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,7,201,87,96,7,0,32,0,48,50,100,95,101,45,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,53,89,13,141,8,0,32,0,48,51,100,95,101,45,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,252,126,193,211,8,0,32,0,48,52,100,95,101,45,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,76,150,186,88,8,0,32,0,48,54,102,95,101,45,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,121,53,160,53,8,0,32,0,108,48,52,95,101,45,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,122,216,250,29,8,0,32,0,99,48,52,95,101,45,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,224,100,0,133,8,0,32,0,108,48,57,95,101,45,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,16,135,182,43,8,0,32,0,108,49,48,95,101,45,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,239,132,49,23,8,0,32,0,48,54,108,95,101,45,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,8,197,42,113,0,0,0,8,107,48,54,95,101,45,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,88,81,175,14,0,0,0,8,108,48,51,95,101,45,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,88,133,150,13,0,0,0,8,48,51,101,95,101,45,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,118,227,206,26,0,0,0,8,48,53,57,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,192,233,212,1,1,0,16,1,48,53,57,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,202,120,137,224,2,0,32,0,48,53,57,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,17,166,59,118,3,0,32,0,48,53,57,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,166,140,94,224,3,0,32,0,48,53,57,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,75,186,78,62,3,0,32,0,48,53,57,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,8,56,42,60,3,0,32,0,48,53,57,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,158,63,1,89,3,0,32,0,48,53,57,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,239,93,141,28,3,0,32,0,48,53,57,45,99,55,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,53,112,143,200,3,0,32,0,48,53,57,45,99,56,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,186,227,76,72,3,0,32,0,48,53,57,45,109,49,46,109,49,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,186,46,153,41,4,0,16,1,48,53,57,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,253,80,12,83,5,0,64,0,48,53,57,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,219,28,111,235,5,0,64,0,48,53,57,45,118,51,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,249,194,56,112,5,0,64,0,114,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,142,214,166,24,1,0,16,1,114,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,101,38,221,167,1,0,16,1,114,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,145,167,207,185,1,0,16,1,114,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,231,151,169,197,1,0,16,1,114,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,77,68,67,1,0,16,1,114,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,246,33,72,77,1,0,16,1,114,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,47,224,67,221,2,0,16,1,114,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,119,8,157,127,2,0,16,1,114,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,97,125,152,53,3,0,32,0,114,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,218,127,106,202,3,0,32,0,114,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,93,110,78,110,4,0,32,0,114,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,158,4,252,70,4,0,32,0,114,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,50,140,62,139,4,0,32,0,52,45,117,49,50,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,202,17,153,140,0,0,16,1,53,45,117,49,50,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,240,62,12,210,0,0,16,1,117,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,203,70,165,0,0,0,32,0,117,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,145,77,160,17,0,0,32,0,117,51,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,216,91,167,230,0,0,32,0,117,51,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,100,1,202,196,0,0,32,0,51,45,117,53,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,118,92,15,49,0,0,16,1,117,54,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,52,108,127,154,0,0,64,0,21,0,0,0,255,255,0,0,0,0,0,0,22,0,0,0,255,255,2,0,0,0,0,0,0,0,0,0,254,0,2,0,120,109,4,0,21,0,0,0,130,1,0,0,176,111,1,0,21,0,0,0,0,255,255,0,0,0,0,0,21,0,0,0,130,1,1,0,232,78,1,0,21,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,254,0,9,0,184,40,2,0,21,0,0,0,1,14,0,0,240,255,3,0,21,0,0,0,1,14,2,0,168,222,3,0,21,0,0,0,1,14,4,0,120,192,3,0,21,0,0,0,1,14,8,0,32,167,3,0,21,0,0,0,1,14,6,0,56,141,3,0,21,0,0,0,1,14,10,0,248,117,3,0,21,0,0,0,1,14,12,0,216,94,3,0,21,0,0,0,130,14,14,0,32,80,3,0,21,0,0,0,0,255,255,0,0,0,0,0,21,0,0,0,1,255,255,0,40,182,1,0,0,0,0,0,254,0,9,0,184,164,8,0,21,0,0,0,130,112,0,0,240,255,3,0,21,0,0,0,0,255,255,0,0,0,0,0,21,0,0,0,130,112,16,0,168,222,3,0,21,0,0,0,0,255,255,0,0,0,0,0,21,0,0,0,130,112,32,0,120,192,3,0,21,0,0,0,0,255,255,0,0,0,0,0,21,0,0,0,130,112,64,0,32,167,3,0,21,0,0,0,0,255,255,0,0,0,0,0,21,0,0,0,130,112,48,0,56,141,3,0,21,0,0,0,0,255,255,0,0,0,0,0,21,0,0,0,130,112,80,0,248,117,3,0,21,0,0,0,0,255,255,0,0,0,0,0,21,0,0,0,130,112,96,0,216,94,3,0,21,0,0,0,0,255,255,0,0,0,0,0,21,0,0,0,130,112,112,0,32,80,3,0,21,0,0,0,0,255,255,0,0,0,0,0,21,0,0,0,130,255,255,0,40,182,1,0,21,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,160,176,7,0,21,0,0,0,130,128,0,0,168,84,8,0,21,0,0,0,0,255,255,0,0,0,0,0,21,0,0,0,130,128,128,0,232,239,2,0,21,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,96,192,7,0,22,0,0,0,1,1,0,0,144,86,8,0,22,0,0,0,1,1,1,0,248,38,7,0,0,0,0,0,254,0,2,0,200,135,2,0,22,0,0,0,1,2,0,0,96,135,7,0,22,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,22,0,0,0,1,12,0,0,248,38,7,0,22,0,0,0,1,12,4,0,80,246,3,0,22,0,0,0,1,12,8,0,112,212,3,0,22,0,0,0,1,12,12,0,136,180,7,0,0,0,0,0,254,0,4,0,0,177,7,0,22,0,0,0,1,48,0,0,8,49,4,0,22,0,0,0,1,48,16,0,192,255,2,0,22,0,0,0,1,48,32,0,208,75,4,0,22,0,0,0,1,48,48,0,152,21,4,0,0,0,0,0,254,0,2,0,248,172,7,0,22,0,0,0,1,64,0,0,208,198,7,0,22,0,0,0,1,64,64,0,216,79,1,0,0,0,0,0,254,0,2,0,208,87,7,0,22,0,0,0,1,128,0,0,96,135,7,0,22,0,0,0,1,128,128,0,152,182,7,0,50,55,48,45,112,49,99,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,137,96,149,191,1,0,16,1,50,55,48,45,112,50,99,46,115,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,29,107,58,148,1,0,16,1,50,55,48,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,172,255,255,20,3,0,32,0,50,55,48,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,153,114,31,64,3,0,32,0,50,55,48,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,96,2,143,131,3,0,32,0,50,55,48,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,165,96,21,4,3,0,32,0,50,55,48,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,45,181,48,189,3,0,32,0,50,55,48,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,112,156,166,134,3,0,32,0,50,55,48,45,99,55,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,60,188,143,210,3,0,32,0,50,55,48,45,99,56,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,166,48,197,2,3,0,32,0,50,55,48,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,26,144,201,73,4,0,16,1,50,55,48,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,235,52,228,98,5,0,64,0,50,55,48,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,154,60,15,24,5,0,64,0,115,115,118,45,112,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,127,6,35,80,1,0,16,1,115,115,118,45,112,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,134,227,203,182,1,0,16,1,115,115,118,45,115,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,208,103,246,112,2,0,32,0,115,115,118,45,99,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,74,86,156,3,0,32,0,115,115,118,45,99,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,218,184,115,75,3,0,32,0,115,115,118,45,99,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,181,155,159,2,3,0,32,0,115,115,118,45,99,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,48,36,114,117,3,0,32,0,115,115,118,45,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,177,79,17,24,4,0,16,1,115,115,118,45,118,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,97,151,96,163,5,0,64,0,115,115,118,45,118,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,213,235,214,203,5,0,64,0,115,115,118,45,118,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,3,39,28,111,5,0,64,0,115,115,118,45,118,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,85,192,32,80,5,0,64,0,50,50,50,45,112,49,107,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,93,162,224,6,1,0,16,1,50,50,50,45,112,50,46,115,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,139,205,35,176,1,0,16,1,50,50,50,45,115,49,107,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,125,104,19,211,2,0,32,0,50,50,50,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,149,237,242,104,3,0,32,0,50,50,50,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,240,175,233,166,3,0,32,0,50,50,50,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,244,64,27,201,3,0,32,0,50,50,50,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,164,16,149,53,3,0,32,0,50,50,50,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,45,178,251,156,3,0,32,0,50,50,50,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,50,252,94,104,3,0,32,0,50,50,50,45,99,55,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,13,111,248,208,3,0,32,0,50,50,50,45,99,56,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,227,80,252,173,3,0,32,0,50,50,50,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,27,188,21,118,4,0,16,1,50,50,50,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,95,169,107,125,5,0,64,0,50,50,50,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,93,187,51,108,5,0,64,0,50,50,50,45,118,51,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,192,168,30,131,5,0,64,0,48,56,55,45,112,103,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,110,51,42,40,1,0,16,1,48,56,55,45,112,50,46,115,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,224,39,190,155,1,0,16,1,48,56,55,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,159,125,236,116,2,0,32,0,48,56,55,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,188,51,162,7,3,0,32,0,48,56,55,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,146,53,65,122,3,0,32,0,48,56,55,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,150,55,121,139,3,0,32,0,48,56,55,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,17,191,143,114,3,0,32,0,48,56,55,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,128,177,42,23,3,0,32,0,48,56,55,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,243,248,47,0,3,0,32,0,48,56,55,45,99,55,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,61,14,69,174,3,0,32,0,48,56,55,45,99,56,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,23,39,232,169,3,0,32,0,48,56,55,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,235,64,100,142,4,0,16,1,48,56,55,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,160,217,189,132,5,0,64,0,48,56,55,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,26,38,15,172,5,0,64,0,48,54,51,45,112,49,45,107,97,110,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,215,198,124,20,1,0,16,1,48,54,51,45,115,49,45,107,97,110,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,11,248,8,255,2,0,32,0,48,54,51,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,124,48,205,134,3,0,32,0,48,54,51,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,202,196,252,205,3,0,32,0,48,54,51,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,199,204,99,122,3,0,32,0,48,54,51,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,206,37,16,117,3,0,32,0,48,54,51,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,117,164,211,32,3,0,32,0,48,54,51,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,136,10,76,174,3,0,32,0,48,54,51,45,99,55,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,207,203,243,45,3,0,32,0,48,54,51,45,99,56,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,250,109,252,31,3,0,32,0,48,54,51,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,152,80,103,86,4,0,16,1,48,54,51,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,145,63,112,55,5,0,64,0,48,54,51,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,232,189,66,1,5,0,64,0,48,54,51,45,118,51,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,202,165,127,208,5,0,64,0,48,54,51,45,118,52,46,118,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,187,180,170,36,5,0,64,0,48,54,51,45,101,112,49,45,107,97,110,46,101,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,216,226,50,250,0,0,16,1,48,54,51,45,101,112,50,45,107,97,110,46,101,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,217,164,177,112,0,0,16,1,50,55,50,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,186,107,122,251,1,0,16,1,50,55,50,45,112,50,46,115,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,166,46,73,99,1,0,16,1,50,55,50,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,26,102,151,79,3,0,32,0,50,55,50,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,79,218,175,163,3,0,32,0,50,55,50,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,2,117,60,140,3,0,32,0,50,55,50,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,226,226,213,50,3,0,32,0,50,55,50,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,188,133,224,108,3,0,32,0,50,55,50,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,142,220,200,5,3,0,32,0,50,55,50,45,99,55,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,66,183,23,20,3,0,32,0,50,55,50,45,99,56,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,205,115,151,212,3,0,32,0,50,55,50,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,64,191,238,173,4,0,16,1,50,55,50,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,39,65,169,118,5,0,64,0,50,55,50,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,241,7,165,75,5,0,64,0,111,49,55,95,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,55,228,105,63,0,0,16,1,111,49,55,95,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,10,62,114,78,0,0,16,1,111,49,55,95,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,1,209,7,190,0,0,16,1,111,49,55,95,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,17,136,105,239,0,0,16,1,111,49,55,95,48,53,46,49,50,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,248,21,83,86,0,0,32,0,111,49,55,95,48,54,46,49,51,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,76,45,38,149,0,0,32,0,111,49,55,95,48,55,46,49,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,92,115,75,76,0,0,32,0,111,49,55,95,48,56,46,49,51,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,108,88,198,149,0,0,32,0,111,49,55,95,48,49,46,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,145,228,18,234,0,0,32,0,111,49,55,95,48,50,46,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,159,58,161,50,0,0,32,0,111,49,55,95,48,51,46,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,201,61,114,104,0,0,32,0,111,49,55,95,48,52,46,55,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,19,203,14,254,0,0,32,0,112,114,111,109,49,52,46,50,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,237,204,136,188,0,0,32,0,112,114,111,109,49,53,46,50,48,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,146,116,225,161,0,0,32,0,104,100,54,52,55,49,56,48,46,48,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,24,98,112,115,109,57,52,53,97,46,117,52,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,21,149,140,137,0,0,16,1,98,112,115,109,46,117,52,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,128,78,8,50,0,0,16,1,98,112,115,109,57,52,53,97,46,117,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,72,229,141,67,0,0,16,1,98,112,115,109,46,117,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,186,165,67,162,0,0,32,0,98,112,115,109,46,117,55,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,172,164,121,81,0,0,32,0,98,112,115,109,46,117,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,131,95,177,185,0,0,32,0,98,112,115,109,46,117,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,157,103,0,143,0,0,32,0,98,112,115,109,46,117,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,99,123,190,134,0,0,32,0,98,112,115,109,46,117,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,59,168,187,224,0,0,32,0,98,112,115,109,46,117,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,172,191,227,161,0,0,32,0,98,112,115,109,46,117,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,82,75,1,106,0,0,32,0,98,112,115,109,46,117,54,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,192,104,36,153,0,0,32,0,98,112,115,109,46,117,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,181,183,15,246,0,0,32,0,98,112,115,109,46,117,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,28,211,89,101,0,0,32,0,98,112,115,109,46,117,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,180,86,122,213,0,0,32,0,98,112,115,109,46,117,52,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,209,78,142,73,0,0,64,0,98,112,115,109,46,117,52,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,185,1,41,15,0,0,64,0,115,97,105,108,111,114,109,110,95,101,117,114,111,112,101,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,80,220,167,89,0,0,16,1,105,99,55,54,46,115,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,207,178,176,178,1,0,16,1,105,99,55,53,46,115,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,183,135,126,54,1,0,16,1,105,99,51,53,46,115,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,157,201,123,235,3,0,32,0,105,99,51,50,46,115,98,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,5,34,198,36,4,0,32,0,105,99,49,48,48,46,115,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,110,22,15,178,5,0,32,0,105,99,51,48,46,115,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,175,7,132,40,6,0,64,0,105,99,50,55,46,115,98,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,126,58,227,67,7,0,64,0,0,0,0,0,0,1,17,112,37,37,37,0,1,0,17,224,50,95,112,114,111,103,108,46,117,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,95,56,93,93,1,0,16,1,49,95,112,114,111,103,104,46,117,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,90,138,27,1,0,16,1,51,95,100,97,116,97,46,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,211,247,245,143,1,0,16,1,48,108,46,117,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,44,213,160,112,2,0,32,0,48,104,46,117,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,180,34,205,77,2,0,32,0,49,108,46,117,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,255,66,16,222,2,0,32,0,49,104,46,117,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,48,68,26,181,2,0,32,0,50,108,46,117,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,202,45,176,35,2,0,32,0,50,104,46,117,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,4,171,51,153,2,0,32,0,51,108,46,117,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,140,67,147,246,2,0,32,0,51,104,46,117,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,79,51,12,45,2,0,32,0,115,111,117,110,100,46,117,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,235,75,55,197,3,0,64,0,101,101,112,114,111,109,45,115,49,57,52,53,105,105,105,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,4,54,159,179,0,0,0,8,114,121,117,107,101,110,100,110,95,49,46,51,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,226,165,3,98,1,0,16,1,114,121,117,107,101,110,100,110,95,50,46,52,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,34,245,153,158,1,0,16,1,51,46,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,105,107,104,107,2,0,16,1,104,110,50,55,53,49,50,112,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,170,123,94,118,3,0,32,0,49,52,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,170,221,207,30,4,0,32,0,49,53,46,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,150,166,145,18,4,0,32,0,49,54,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,202,71,11,20,4,0,32,0,49,55,46,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,203,204,56,118,4,0,32,0,49,56,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,214,175,173,63,5,0,32,0,49,57,46,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,91,157,174,221,5,0,32,0,50,48,46,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,147,122,207,8,5,0,32,0,50,49,46,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,245,146,200,26,5,0,32,0,54,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,159,223,204,231,6,0,32,0,56,46,51,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,128,248,247,126,6,0,32,0])
.concat([49,48,46,51,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,236,29,69,166,6,0,32,0,115,104,97,100,111,119,119,95,49,50,97,46,120,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,49,119,176,155,6,0,32,0,114,121,117,107,101,110,100,110,95,49,50,98,46,120,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,138,98,115,23,6,0,32,0,55,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,149,236,107,1,6,0,32,0,57,46,49,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,211,127,155,110,6,0,32,0,49,49,46,49,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,94,223,191,127,6,0,32,0,115,104,97,100,111,119,119,95,49,51,97,46,120,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,165,47,109,153,6,0,32,0,114,121,117,107,101,110,100,110,95,49,51,98,46,120,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,7,197,67,31,6,0,32,0,52,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,249,250,224,176,7,0,64,0,49,46,51,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,76,70,213,14,1,0,16,1,50,46,52,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,86,130,58,169,1,0,16,1,51,46,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,105,107,104,107,2,0,16,1,104,110,50,55,53,49,50,112,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,170,123,94,118,3,0,32,0,49,52,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,170,221,207,30,4,0,32,0,49,53,46,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,150,166,145,18,4,0,32,0,49,54,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,202,71,11,20,4,0,32,0,49,55,46,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,203,204,56,118,4,0,32,0,49,56,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,214,175,173,63,5,0,32,0,49,57,46,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,91,157,174,221,5,0,32,0,50,48,46,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,147,122,207,8,5,0,32,0,50,49,46,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,245,146,200,26,5,0,32,0,54,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,159,223,204,231,6,0,32,0,56,46,51,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,128,248,247,126,6,0,32,0,49,48,46,51,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,236,29,69,166,6,0,32,0,49,50,46,51,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,240,4,114,39,6,0,32,0,55,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,149,236,107,1,6,0,32,0,57,46,49,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,211,127,155,110,6,0,32,0,49,49,46,49,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,94,223,191,127,6,0,32,0,49,51,46,49,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,8,165,86,78,6,0,32,0,52,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,249,250,224,176,7,0,64,0,114,99,48,52,46,49,52,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,156,232,140,166,1,0,16,1,114,99,48,51,46,49,51,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,224,155,156,164,1,0,16,1,114,99,48,50,46,49,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,216,98,154,0,1,0,16,1,114,99,48,49,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,29,141,196,42,1,0,16,1,114,99,48,57,46,49,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,114,62,242,100,1,0,16,1,114,99,48,56,46,49,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,75,135,37,44,1,0,16,1,114,99,48,55,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,118,80,120,222,1,0,16,1,114,99,48,54,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,212,79,15,167,1,0,16,1,114,99,48,53,46,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,7,250,4,234,2,0,16,1,114,99,49,48,40,95,95,114,117,115,104,99,114,115,104,41,46,54,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,13,11,60,10,3,0,32,0,114,99,49,49,46,49,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,186,66,160,95,4,0,32,0,114,99,49,50,46,49,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,175,100,219,162,4,0,32,0,114,99,49,51,46,49,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,153,84,223,241,4,0,32,0,114,99,49,52,46,49,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,179,49,43,178,4,0,32,0,114,99,49,53,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,243,58,58,202,4,0,32,0,114,99,49,54,46,49,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,17,74,154,196,4,0,32,0,114,99,49,55,46,49,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,171,170,128,170,4,0,32,0,114,99,49,56,46,49,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,142,134,103,206,4,0,32,0,114,99,50,48,46,49,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,97,200,36,57,5,0,32,0,114,99,49,57,46,49,52,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,41,145,143,255,5,0,32,0,114,99,50,50,46,49,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,28,22,100,171,5,0,32,0,114,99,50,49,46,49,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,209,188,100,253,5,0,32,0,114,99,50,52,46,49,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,62,175,114,201,5,0,32,0,114,99,50,51,46,49,52,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,87,191,154,140,5,0,32,0,114,99,50,54,46,49,53,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,47,115,241,212,5,0,32,0,114,99,50,53,46,49,52,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,79,234,164,210,5,0,32,0,54,51,115,49,52,49,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,111,120,33,132,6,0,16,1,54,51,115,49,52,49,46,49,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,63,88,72,96,6,0,16,1,54,51,115,49,52,49,46,56,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,255,167,137,26,0,0,0,8,53,55,55,104,48,51,46,49,48,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,82,107,39,77,1,0,16,1,53,55,55,104,48,50,46,56,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,6,40,128,181,1,0,16,1,53,55,55,104,48,49,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,61,143,124,218,1,0,16,1,53,55,55,104,48,55,46,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,95,129,249,3,2,0,32,0,53,55,55,108,48,54,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,202,176,28,15,3,0,32,0,53,55,55,104,48,53,46,52,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,143,142,2,157,3,0,32,0,53,55,55,108,48,56,46,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,164,51,57,136,3,0,32,0,53,55,55,108,48,52,46,51,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,76,218,236,204,3,0,32,0,53,55,55,104,48,57,46,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,128,124,94,193,4,0,32,0,53,55,55,104,49,49,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,43,153,26,42,4,0,32,0,53,55,55,104,49,48,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,83,30,222,233,4,0,32,0,114,116,108,45,104,48,45,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,161,127,239,95,1,0,16,1,114,116,108,45,108,48,45,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,107,69,86,129,1,0,16,1,114,116,108,45,104,49,45,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,68,244,47,53,1,0,16,1,114,116,108,45,108,49,45,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,70,234,52,253,1,0,16,1,114,116,108,45,115,104,48,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,227,180,24,229,2,0,16,1,114,116,108,45,115,108,48,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,54,13,111,137,2,0,16,1,114,116,108,45,99,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,124,141,88,251,3,0,32,0,114,116,108,45,99,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,255,27,84,229,3,0,32,0,114,116,108,45,99,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,174,169,250,3,0,32,0,114,116,108,45,99,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,67,35,58,3,0,32,0,114,116,108,45,48,48,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,112,104,160,130,4,0,32,0,114,116,108,45,48,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,86,122,126,65,4,0,32,0,114,116,108,45,48,50,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,161,243,163,249,4,0,32,0,114,116,108,45,48,51,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,149,141,82,3,4,0,32,0,114,116,108,45,100,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,255,209,235,219,5,0,64,0,114,116,108,45,104,48,45,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,159,200,186,61,1,0,16,1,114,116,108,45,108,48,45,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,55,37,90,248,1,0,16,1,114,116,108,45,104,49,45,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,68,244,47,53,1,0,16,1,114,116,108,45,108,49,45,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,70,234,52,253,1,0,16,1,114,116,108,45,115,104,48,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,227,180,24,229,2,0,16,1,114,116,108,45,115,108,48,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,54,13,111,137,2,0,16,1,114,116,108,45,99,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,124,141,88,251,3,0,32,0,114,116,108,45,99,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,255,27,84,229,3,0,32,0,114,116,108,45,99,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,174,169,250,3,0,32,0,114,116,108,45,99,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,67,35,58,3,0,32,0,114,116,108,45,48,48,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,112,104,160,130,4,0,32,0,114,116,108,45,48,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,86,122,126,65,4,0,32,0,114,116,108,45,48,50,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,161,243,163,249,4,0,32,0,114,116,108,45,48,51,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,149,141,82,3,4,0,32,0,114,116,108,45,100,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,255,209,235,219,5,0,64,0,114,116,50,45,97,45,104,48,45,99,46,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,144,153,154,239,1,0,16,1,114,116,50,45,97,45,108,48,45,99,46,54,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,100,218,185,216,1,0,16,1,114,116,50,45,97,45,104,49,45,99,46,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,244,112,24,27,1,0,16,1,114,116,50,45,97,45,108,49,45,99,46,53,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,53,255,253,96,1,0,16,1,105,99,49,55,46,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,180,236,255,115,6,0,16,1,105,99,51,49,46,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,19,249,216,44,2,0,32,0,105,99,50,49,46,52,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,109,6,51,80,2,0,32,0,105,99,51,50,46,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,80,4,58,236,2,0,32,0,105,99,50,50,46,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,252,118,97,219,2,0,32,0,105,99,53,48,46,55,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,110,115,248,243,3,0,32,0,105,99,53,49,46,55,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,175,67,197,180,3,0,32,0,105,99,53,54,46,56,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,102,13,184,76,3,0,32,0,105,99,53,55,46,56,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,224,40,225,190,3,0,32,0,105,99,54,53,46,57,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,26,199,201,45,3,0,32,0,105,99,54,54,46,57,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,40,196,51,117,3,0,32,0,105,99,54,51,46,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,242,103,173,166,3,0,32,0,105,99,54,52,46,57,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,85,213,134,54,3,0,32,0,105,99,49,52,46,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,213,114,113,99,5,0,64,0,114,116,49,54,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,54,246,240,177,1,0,16,1,114,116,49,54,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,229,47,197,62,1,0,16,1,114,116,49,54,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,113,40,233,168,1,0,16,1,114,116,49,54,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,197,159,252,160,1,0,16,1,114,116,49,54,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,196,248,202,109,1,0,16,1,114,116,49,54,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,91,176,215,99,1,0,16,1,114,116,49,54,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,243,5,246,254,2,0,16,1,114,116,49,54,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,137,193,214,208,2,0,16,1,114,116,49,54,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,151,87,252,222,2,0,16,1,114,116,49,54,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,102,74,217,136,2,0,16,1,105,109,53,54,50,51,46,102,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,247,62,121,8,3,0,32,0,105,109,53,54,50,51,46,102,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,247,62,121,8,3,0,32,0,118,103,45,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,25,99,150,12,1,0,16,1,118,103,45,53,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,18,194,168,166,1,0,16,1,118,103,45,53,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,106,64,116,92,1,0,16,1,118,103,45,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,171,104,62,49,1,0,16,1,118,103,45,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,60,78,130,64,1,0,16,1,118,103,45,53,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,194,210,19,147,1,0,16,1,114,111,117,116,101,49,54,46,98,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,167,136,149,15,2,0,16,1,118,103,45,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,140,200,22,178,2,0,16,1,114,111,117,116,101,49,54,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,19,173,156,82,2,0,16,1,114,111,117,116,101,49,54,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,153,184,216,59,2,0,16,1,105,109,53,54,50,51,46,102,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,247,62,121,8,3,0,32,0,105,109,53,54,50,51,46,102,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,247,62,121,8,3,0,32,0,57,57,57,118,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,172,195,216,13,1,0,16,1,57,57,57,109,48,49,46,101,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,47,178,207,31,2,0,16,1,57,57,57,104,48,54,46,107,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,48,81,160,237,3,0,32,0,57,57,57,104,48,53,46,107,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,125,28,50,95,3,0,32,0,57,57,57,104,48,51,46,100,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,210,219,30,234,4,0,32,0,57,57,57,104,48,52,46,102,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,85,83,163,193,4,0,32,0,57,57,57,104,48,57,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,131,135,24,197,5,0,64,0,49,46,97,117,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,123,148,130,209,1,0,16,1,50,46,97,117,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,29,70,167,39,1,0,16,1,53,101,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,59,196,108,10,2,0,32,0,55,102,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,71,169,73,117,3,0,32,0,52,97,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,142,216,213,221,3,0,32,0,56,50,115,49,50,54,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,134,204,169,4,0,64,0,56,50,115,49,50,54,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,51,46,97,117,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,166,124,17,91,7,0,16,1,52,46,97,117,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,195,212,191,129,7,0,16,1,53,46,97,117,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,60,66,118,233,7,0,16,1,54,46,97,117,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,191,70,89,66,7,0,16,1,55,46,97,117,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,143,252,86,112,7,0,16,1,56,46,97,117,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,79,70,134,139,7,0,16,1,57,46,97,117,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,164,235,216,23,7,0,16,1,49,48,46,97,117,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,180,142,140,57,7,0,16,1,49,49,46,97,117,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,36,100,55,127,7,0,16,1,49,50,46,97,117,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,129,191,91,141,7,0,16,1,49,51,46,97,117,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,33,44,254,153,7,0,16,1,49,52,46,97,117,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,231,245,76,223,7,0,16,1,49,53,46,97,117,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,38,222,50,42,7,0,16,1,49,54,46,97,117,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,135,33,212,252,7,0,16,1,49,55,46,97,117,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,136,195,213,36,7,0,16,1,49,56,46,97,117,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,253,149,177,254,7,0,16,1,14,0,0,0,255,63,51,0,0,0,0,0,15,0,0,0,255,255,255,0,0,0,0,0,16,0,0,0,255,255,255,0,0,0,0,0,17,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,32,4,2,0,14,0,0,0,1,3,3,0,160,36,8,0,14,0,0,0,1,3,1,0,208,239,7,0,14,0,0,0,1,3,2,0,120,187,7,0,14,0,0,0,1,3,0,0,16,227,4,0,0,0,0,0,254,0,8,0,192,8,5,0,14,0,0,0,1,28,28,0,208,75,4,0,14,0,0,0,1,28,24,0,8,49,4,0,14,0,0,0,1,28,20,0,152,21,4,0,14,0,0,0,1,28,16,0,72,246,3,0,14,0,0,0,1,28,12,0,72,0,3,0,14,0,0,0,1,28,8,0,64,47,7,0,14,0,0,0,1,28,4,0,232,99,5,0,14,0,0,0,1,28,0,0,80,62,6,0,0,0,0,0,254,0,4,0,136,249,4,0,14,0,0,0,1,96,96,0,240,244,4,0,14,0,0,0,1,96,64,0,120,241,4,0,14,0,0,0,1,96,32,0,64,238,4,0,14,0,0,0,1,96,0,0,216,233,4,0,0,0,0,0,254,0,2,0,80,229,4,0,14,0,0,0,1,128,128,0,96,135,7,0,14,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,128,156,8,0,15,0,0,0,1,1,1,0,32,221,4,0,15,0,0,0,1,1,0,0,144,189,5,0,0,0,0,0,254,0,2,0,200,30,2,0,15,0,0,0,1,2,2,0,120,97,1,0,15,0,0,0,1,2,0,0,96,19,1,0,0,0,0,0,254,0,2,0,192,216,4,0,15,0,0,0,1,4,4,0,176,172,3,0,15,0,0,0,1,4,0,0,200,105,5,0,0,0,0,0,254,0,8,0,64,37,5,0,15,0,0,0,1,112,112,0,176,116,6,0,15,0,0,0,1,112,96,0,200,207,4,0,15,0,0,0,1,112,80,0,8,203,4,0,15,0,0,0,1,112,64,0,96,197,4,0,15,0,0,0,1,112,48,0,112,216,4,0,15,0,0,0,1,112,32,0,248,189,4,0,15,0,0,0,1,112,16,0,64,187,4,0,15,0,0,0,1,112,0,0,160,184,4,0,0,0,0,0,254,0,2,0,16,49,4,0,15,0,0,0,1,128,128,0,152,182,7,0,15,0,0,0,1,128,0,0,96,135,7,0,0,0,0,0,114,100,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,48,160,226,86,1,0,16,1,114,100,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,12,154,45,72,1,0,16,1,114,100,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,242,38,70,151,1,0,16,1,114,100,51,46,114,100,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,83,30,63,138,2,0,32,0,114,100,50,46,114,100,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,62,103,78,233,2,0,32,0,114,100,49,46,114,100,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,242,255,74,101,2,0,32,0,101,103,103,115,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,129,140,64,232,3,0,32,0,114,111,98,111,45,112,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,224,79,203,173,1,0,16,1,114,111,98,111,45,115,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,94,178,184,99,2,0,32,0,114,111,98,111,45,99,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,160,101,245,140,3,0,32,0,114,111,98,111,45,99,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,29,86,239,118,3,0,32,0,114,111,98,111,45,99,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,12,121,102,113,3,0,32,0,114,111,98,111,45,99,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,252,203,205,192,3,0,32,0,114,111,98,111,45,99,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,99,195,221,165,3,0,32,0,114,111,98,111,45,99,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,206,143,204,31,3,0,32,0,114,111,98,111,45,99,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,162,157,159,190,3,0,32,0,114,111,98,111,45,99,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,58,99,255,124,3,0,32,0,114,111,98,111,45,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,131,94,211,196,4,0,16,1,114,111,98,111,45,118,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,9,0,169,132,178,236,5,0,64,0,103,113,45,48,51,46,107,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,40,12,233,167,1,0,16,1,103,113,45,48,55,46,107,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,193,126,40,210,1,0,16,1,103,113,45,48,50,46,106,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,160,184,119,103,1,0,16,1,103,113,45,48,54,46,106,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,181,39,30,225,1,0,16,1,103,111,45,48,49,45,49,46,104,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,192,86,83,171,1,0,16,1,103,111,45,48,53,45,49,46,104,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,165,189,33,206,1,0,16,1,103,111,45,48,48,46,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,234,105,51,169,1,0,16,1,103,111,45,48,52,46,102,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,217,106,47,238,1,0,16,1,103,112,45,48,57,46,107,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,141,15,78,74,2,0,16,1,103,112,49,48,45,49,46,121,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,156,113,93,210,3,0,32,0,103,112,49,49,45,49,46,122,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,71,237,13,3,3,0,32,0,109,97,104,45,48,52,46,122,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,140,161,108,155,4,0,32,0,109,97,104,45,48,51,46,121,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,220,77,137,55,4,0,32,0,109,97,104,45,48,49,46,122,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,255,223,224,38,5,0,32,0,109,97,104,45,48,48,46,121,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,65,158,214,123,5,0,32,0,109,97,104,45,48,50,46,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,125,36,138,50,5,0,32,0,109,97,104,45,48,53,46,121,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,19,230,115,103,6,0,32,0,109,97,104,45,48,56,46,121,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,165,16,211,136,6,0,32,0,109,97,104,45,48,54,46,122,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,138,128,168,39,6,0,32,0,109,97,104,45,48,57,46,122,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,167,67,140,165,6,0,32,0,109,97,104,45,48,55,46,97,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,144,65,111,82,6,0,32,0,109,97,104,45,49,48,46,97,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,218,112,183,20,6,0,32,0,103,112,45,48,56,46,106,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,177,131,81,54,7,0,64,0,109,97,104,45,49,49,46,102,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,146,198,43,100,8,0,64,0,103,111,45,49,50,46,118,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,79,103,143,39,0,0,0,8,48,51,50,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,212,203,17,205,1,0,16,1,48,51,50,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,27,170,13,172,2,0,32,0,48,51,50,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,108,76,152,151,3,0,32,0,48,51,50,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,34,49,119,101,3,0,32,0,48,51,50,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,205,252,173,64,3,0,32,0,48,51,50,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,222,113,37,70,3,0,32,0,48,51,50,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,45,149,236,53,4,0,16,1,48,51,50,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,51,21,121,99,5,0,64,0,48,51,50,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,112,222,149,235,5,0,64,0,114,99,95,104,48,46,105,99,55,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,68,83,155,76,1,0,16,1,114,99,95,108,48,46,105,99,55,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,90,137,85,4,1,0,16,1,108,52,95,97,45,115,112,46,105,99,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,78,9,128,187,2,0,16,1,114,99,95,99,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,7,185,208,132,3,0,32,0,114,99,95,99,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,239,132,55,203,3,0,32,0,114,99,95,99,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,215,100,113,104,3,0,32,0,114,99,95,99,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,175,230,107,200,3,0,32,0,114,99,95,118,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,96,195,218,205,4,0,64,0,55,57,57,110,48,50,46,107,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,208,93,48,249,1,0,16,1,55,57,57,99,48,49,46,102,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,92,76,124,68,2,0,16,1,55,57,57,99,48,54,46,102,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,88,203,57,248,3,0,32,0,55,57,57,99,48,55,46,104,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,56,245,109,23,3,0,32,0,55,57,57,99,48,56,46,106,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,120,0,30,208,3,0,32,0,55,57,57,99,48,57,46,107,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,94,199,174,155,3,0,32,0,55,57,57,98,48,52,46,104,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,43,12,62,50,4,0,32,0,55,57,57,98,48,53,46,107,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,49,88,28,87,4,0,32,0,55,57,57,98,48,51,46,100,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,66,211,207,241,5,0,64,0,55,57,57,98,48,54,46,99,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,215,71,140,44,6,0,32,0,54,51,115,49,52,49,110,46,107,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,209,200,246,97,7,0,0,8,48,48,54,45,112,103,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,70,86,68,82,1,0,16,1,48,48,54,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,240,137,81,235,2,0,32,0,48,48,54,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,120,127,92,74,3,0,32,0,48,48,54,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,206,14,183,224,3,0,32,0,48,48,54,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,101,247,207,138,3,0,32,0,48,48,54,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,8,50,94,32,3,0,32,0,48,48,54,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,254,180,231,146,4,0,16,1,48,48,54,45,118,49,49,46,118,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,66,74,247,205,5,0,64,0,48,48,54,45,118,49,50,46,118,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,113,35,253,226,5,0,64,0,48,48,54,45,118,50,49,46,118,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,206,43,9,148,6,0,64,0,48,48,54,45,118,50,50,46,118,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,195,215,44,78,6,0,64,0,48,48,54,45,118,50,51,46,118,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,237,113,156,6,6,0,64,0,48,48,54,45,118,50,52,46,118,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,37,184,251,137,6,0,64,0,104,100,54,51,48,49,118,49,112,46,99,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,24,97,51,55,45,48,51,46,55,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,157,69,231,234,1,0,16,1,97,51,55,45,48,50,46,55,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,55,94,137,114,1,0,16,1,97,51,55,45,48,49,46,55,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,11,210,93,80,1,0,16,1,97,51,55,45,48,52,46,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,193,156,137,210,2,0,16,1,97,51,55,45,48,53,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,234,171,37,144,3,0,16,1,97,51,55,45,49,54,46,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,28,80,63,78,4,0,32,0,97,51,55,45,49,48,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,200,238,253,106,5,0,32,0,97,51,55,45,49,49,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,163,157,220,211,5,0,32,0,97,51,55,45,49,50,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,237,46,11,209,5,0,32,0,97,51,55,45,49,51,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,61,107,202,0,5,0,32,0,97,51,55,45,49,52,46,53,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,81,134,127,239,6,0,32,0,97,51,55,45,49,53,46,53,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,5,9,180,3,6,0,32,0,97,51,55,45,48,54,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,139,59,100,233,7,0,32,0,97,51,55,45,48,55,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,17,78,243,232,7,0,32,0,97,51,55,45,48,56,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,240,10,3,80,7,0,32,0,56,50,115,49,57,49,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,227,145,200,147,7,0,32,0,97,51,55,45,48,57,46,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,237,109,189,121,8,0,16,1,114,105,45,99,46,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,96,18,195,227,1,0,16,1,114,111,105,46,48,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,48,249,121,51,1,0,16,1,114,105,45,97,46,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,48,197,231,58,1,0,16,1,97,51,55,45,48,52,46,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,193,156,137,210,2,0,16,1,97,51,55,45,48,53,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,234,171,37,144,3,0,16,1,97,51,55,45,49,54,46,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,28,80,63,78,4,0,32,0,97,51,55,45,49,48,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,200,238,253,106,5,0,32,0,97,51,55,45,49,49,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,163,157,220,211,5,0,32,0,97,51,55,45,49,50,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,237,46,11,209,5,0,32,0,97,51,55,45,49,51,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,61,107,202,0,5,0,32,0,97,51,55,45,49,52,46,53,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,81,134,127,239,6,0,32,0,97,51,55,45,49,53,46,53,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,5,9,180,3,6,0,32,0,97,51,55,45,48,54,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,139,59,100,233,7,0,32,0,97,51,55,45,48,55,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,17,78,243,232,7,0,32,0,97,51,55,45,48,56,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,240,10,3,80,7,0,32,0,56,50,115,49,57,49,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,227,145,200,147,7,0,32,0,114,111,105,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,98,212,143,217,1,0,16,1,114,111,105,46,48,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,48,249,121,51,1,0,16,1,114,111,105,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,98,144,103,87,1,0,16,1,97,51,55,45,48,52,46,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,193,156,137,210,2,0,16,1,97,51,55,45,48,53,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,234,171,37,144,3,0,16,1,97,51,55,45,49,54,46,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,28,80,63,78,4,0,32,0,97,51,55,45,49,48,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,200,238,253,106,5,0,32,0,97,51,55,45,49,49,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,163,157,220,211,5,0,32,0,97,51,55,45,49,50,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,237,46,11,209,5,0,32,0,97,51,55,45,49,51,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,61,107,202,0,5,0,32,0,97,51,55,45,49,52,46,53,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,81,134,127,239,6,0,32,0,97,51,55,45,49,53,46,53,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,5,9,180,3,6,0,32,0,97,51,55,45,48,54,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,139,59,100,233,7,0,32,0,97,51,55,45,48,55,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,17,78,243,232,7,0,32,0,97,51,55,45,48,56,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,240,10,3,80,7,0,32,0,56,50,115,49,57,49,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,227,145,200,147,7,0,32,0,114,104,105,116,45,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,14,222,202,48,1,0,16,1,114,104,105,116,45,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,194,179,219,55,1,0,16,1,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,142,242,140,93,2,0,16,1,114,104,105,116,45,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,196,60,251,170,4,0,32,0,114,104,105,116,45,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,199,103,179,188,5,0,32,0,114,104,105,116,45,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,96,92,189,124,5,0,32,0,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,51,206,17,233,6,0,64,0,114,104,97,119,107,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,180,35,46,109,1,0,16,1,114,104,97,119,107,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,136,97,13,94,1,0,16,1,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,142,242,140,93,2,0,16,1,114,104,97,119,107,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,136,162,154,215,4,0,32,0,114,104,97,119,107,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,84,239,100,2,5,0,32,0,114,104,97,119,107,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,182,10,152,63,5,0,32,0,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,51,206,17,233,6,0,32,0,114,104,98,45,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,7,234,51,231,1,0,16,1,114,104,98,45,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,132,86,250,249,1,0,16,1,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,142,242,140,93,2,0,16,1,114,104,98,45,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,242,246,234,208,4,0,32,0,114,104,98,45,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,139,214,24,3,5,0,32,0,114,104,98,45,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,239,193,33,186,5,0,32,0,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,51,206,17,233,6,0,64,0,114,101,100,101,97,114,116,104,95,101,117,114,111,46,50,57,102,52,48,48,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,54,243,224,2,0,0,0,3,114,101,100,101,97,114,116,104,40,95,95,57,54,49,49,50,49,41,45,115,105,109,109,49,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,248,104,212,202,0,0,16,1,114,101,100,101,97,114,116,104,40,95,95,57,54,49,49,50,49,41,45,115,105,109,109,49,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,137,29,114,233,0,0,16,1,114,101,100,101,97,114,116,104,40,95,95,57,54,49,49,50,49,41,45,115,105,109,109,49,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,152,236,137,40,0,0,16,1,114,101,100,101,97,114,116,104,40,95,95,57,54,49,49,50,49,41,45,115,105,109,109,49,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,72,209,108,90,0,0,16,1,114,101,100,101,97,114,116,104,45,115,105,109,109,51,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,197,12,53,131,0,0,32,0,114,101,100,101,97,114,116,104,45,115,105,109,109,51,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,230,77,115,86,0,0,32,0,114,101,100,101,97,114,116,104,45,115,105,109,109,51,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,241,160,14,128,0,0,32,0,114,101,100,101,97,114,116,104,45,115,105,109,109,51,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,108,20,233,151,0,0,32,0,114,101,100,101,97,114,116,104,45,115,105,109,109,51,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,72,214,177,12,0,0,32,0,114,101,100,101,97,114,116,104,45,115,105,109,109,51,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,240,153,16,122,0,0,32,0,114,101,100,101,97,114,116,104,45,115,105,109,109,51,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,84,143,255,174,0,0,32,0,114,101,100,101,97,114,116,104,45,115,105,109,109,51,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,208,172,112,247,0,0,32,0,114,101,100,101,97,114,116,104,45,115,105,109,109,52,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,242,86,30,48,0,0,32,0,114,101,100,101,97,114,116,104,45,115,105,109,109,52,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,3,225,72,32,0,0,32,0,114,101,100,101,97,114,116,104,45,115,105,109,109,52,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,85,52,67,201,0,0,32,0,114,101,100,101,97,114,116,104,45,115,105,109,109,52,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,168,113,33,192,0,0,32,0,114,101,100,101,97,114,116,104,45,115,105,109,109,52,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,118,242,219,45,0,0,32,0,114,101,100,101,97,114,116,104,45,115,105,109,109,52,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,166,32,168,254,0,0,32,0,114,101,100,101,97,114,116,104,45,115,105,109,109,52,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,241,141,82,199,0,0,32,0,114,101,100,101,97,114,116,104,45,115,105,109,109,52,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,59,207,73,36,0,0,32,0,114,101,100,101,97,114,116,104,45,115,105,109,109,53,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,185,81,68,66,0,0,32,0,114,101,100,101,97,114,116,104,45,115,105,109,109,53,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,107,181,140,155,0,0,32,0,50,50,51,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,29,45,74,248,1,0,16,1,50,50,51,45,112,50,46,115,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,8,143,221,173,1,0,16,1,50,50,51,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,140,110,205,126,2,0,32,0,50,50,51,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,226,5,171,235,3,0,32,0,50,50,51,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,195,104,24,100,3,0,32,0,50,50,51,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,31,25,0,202,3,0,32,0,50,50,51,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,96,216,35,31,3,0,32,0,50,50,51,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,44,54,30,50,3,0,32,0,50,50,51,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,144,239,252,216,3,0,32,0,50,50,51,45,99,55,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,45,221,128,188,3,0,32,0,50,50,51,45,99,56,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,2,33,214,90,3,0,32,0,50,50,51,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,191,70,238,63,4,0,16,1,50,50,51,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,105,56,103,118,5,0,64,0,50,50,51,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,205,90,39,122,5,0,64,0,50,50,51,45,118,51,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,210,127,121,90,5,0,64,0,98,56,49,45,48,56,46,53,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,105,145,218,214,2,0,0,0,98,56,49,45,48,55,46,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,215,23,223,142,2,0,0,0,98,56,49,45,49,48,46,52,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,68,67,243,83,2,0,0,0,98,56,49,45,48,57,46,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,175,52,13,99,2,0,0,0,98,56,49,45,49,49,46,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,9,191,4,55,9,0,0,0,98,56,49,45,48,51,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,230,117,27,85,11,0,0,0,98,56,49,45,48,52,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,18,78,115,207,11,0,0,0,98,56,49,45,48,50,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,134,59,236,32,24,0,0,0,98,56,49,45,48,49,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,107,121,63,179,25,0,0,0,98,52,53,45,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,215,134,51,56,0,0,16,1,98,52,53,45,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,167,246,2,118,0,0,16,1,98,52,53,45,48,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,177,5,176,233,0,0,16,1,98,52,53,45,48,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,206,68,83,85,0,0,16,1,98,52,53,45,48,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,1,70,129,16,0,0,16,1,98,52,53,45,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,16,176,199,29,0,0,32,0,98,52,53,45,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,186,97,182,250,0,0,32,0,98,52,53,45,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,180,72,55,205,0,0,32,0,98,52,53,45,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,92,8,75,20,0,0,32,0,98,52,53,45,49,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,187,232,86,13,0,0,32,0,98,52,53,45,49,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,126,197,183,219,0,0,32,0,98,52,53,45,49,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,78,174,90,207,0,0,32,0,98,52,53,45,49,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,124,176,131,22,0,0,32,0,98,52,53,45,49,53,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,47,214,231,36,0,0,0,8,98,52,53,45,49,54,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,9,239,12,165,0,0,0,8,98,52,53,45,49,52,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,219,130,36,247,0,0,0,8,98,52,53,45,49,55,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,237,204,136,188,0,0,0,8,49,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,133,39,177,164,0,0,16,1,50,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,213,11,100,23,0,0,16,1,51,100,100,46,101,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,210,186,243,182,0,0,16,1,52,100,100,46,101,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,193,223,148,210,0,0,16,1,53,46,112,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,69,207,193,21,0,0,16,1,54,46,112,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,27,56,28,38,0,0,16,1,56,46,119,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,17,156,91,16,0,0,16,1,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,94,178,34,25,0,0,32,0,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,106,120,144,95,0,0,32,0,115,101,105,52,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,11,31,21,218,0,0,32,0,115,101,105,52,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,172,87,31,172,0,0,32,0,115,101,105,52,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,222,123,109,148,0,0,32,0,55,46,120,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,62,38,81,32,0,0,64,0,168,86,7,0,1,0,0,0,152,191,145,0,248,191,2,0,24,38,7,0,1,0,0,0,119,253,146,0,184,160,2,0,56,210,6,0,1,0,0,0,112,253,146,0,192,135,2,0,24,163,6,0,1,0,0,0,113,253,146,0,240,108,2,0,152,122,6,0,1,0,0,0,114,253,146,0,96,82,2,0,192,72,6,0,1,0,0,0,115,253,146,0,32,56,2,0,200,110,3,0,1,0,0,0,116,253,146,0,152,30,2,0,120,89,3,0,1,0,0,0,117,253,146,0,232,10,2,0,40,246,1,0,1,0,0,0,153,191,145,0,64,246,1,0,144,236,1,0,1,0,0,0,39,245,146,0,136,224,1,0,176,223,1,0,1,0,0,0,32,245,146,0,72,198,1,0,192,209,1,0,1,0,0,0,33,245,146,0,24,182,1,0,24,198,1,0,1,0,0,0,34,245,146,0,40,167,1,0,120,189,1,0,1,0,0,0,35,245,146,0,200,149,1,0,224,22,1,0,1,0,0,0,36,245,146,0,56,126,1,0,160,14,1,0,1,0,0,0,37,245,146,0,32,101,1,0,88,212,3,0,1,0,0,0,160,217,146,0,40,185,3,0,72,65,1,0,9,0,0,0,19,224,146,0,32,58,1,0,48,50,1,0,9,0,0,0,20,224,146,0,32,58,1,0,107,104,95,48,48,45,49,46,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,90,21,240,136,1,0,16,1,107,104,95,48,50,45,49,46,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,27,180,17,136,1,0,16,1,107,104,95,48,49,45,49,46,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,173,99,171,77,1,0,16,1,107,104,95,48,51,45,49,46,52,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,24,187,76,138,1,0,16,1,107,109,48,54,46,49,56,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,225,196,139,62,2,0,16,1,107,109,48,53,46,57,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,149,239,10,209,3,0,32,0,107,109,48,52,46,56,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,168,35,147,50,3,0,32,0,109,98,100,45,48,49,46,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,75,79,222,215,4,0,32,0,109,98,100,45,48,48,46,56,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,169,11,178,173,4,0,32,0,109,98,100,45,48,50,46,49,48,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,33,167,90,178,8,0,32,0,109,98,100,45,48,51,46,49,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,44,143,121,207,5,0,32,0,109,98,100,45,48,52,46,49,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,11,77,118,217,5,0,32,0,109,98,100,45,48,53,46,49,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,106,198,104,23,6,0,32,0,109,98,100,45,48,54,46,49,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,122,132,80,119,6,0,32,0,109,98,100,45,48,55,46,49,56,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,193,170,31,36,7,0,32,0,109,98,100,45,48,56,46,49,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,86,30,59,241,7,0,32,0,109,98,100,45,49,48,46,49,55,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,106,247,89,241,9,0,64,0,109,98,100,45,48,57,46,49,54,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,135,47,79,244,10,0,64,0,107,106,45,48,48,46,49,53,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,11,213,212,173,11,0,0,8,50,49,56,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,3,35,55,202,1,0,16,1,50,49,56,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,154,47,64,125,2,0,32,0,50,49,56,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,164,0,21,195,3,0,32,0,50,49,56,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,249,161,171,152,3,0,32,0,50,49,56,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,58,22,60,131,3,0,32,0,50,49,56,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,105,15,163,193,3,0,32,0,50,49,56,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,255,224,109,107,3,0,32,0,50,49,56,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,207,239,190,148,3,0,32,0,50,49,56,45,99,55,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,40,155,111,222,3,0,32,0,50,49,56,45,99,56,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,246,17,179,217,3,0,32,0,50,49,56,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,207,139,2,23,4,0,16,1,50,49,56,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,244,231,238,97,5,0,64,0,50,49,56,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,11,226,4,97,5,0,64,0,116,114,115,50,99,53,102,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,13,158,148,64,1,0,0,0,116,114,115,50,99,53,103,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,159,196,168,175,1,0,0,0,116,114,115,50,99,53,104,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,61,38,184,81,1,0,0,0,116,114,115,50,99,53,107,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,247,1,1,31,1,0,0,0,116,114,115,50,115,51,105,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,20,79,3,120,2,0,0,0,116,114,115,50,118,51,103,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,14,51,149,240,3,0,0,0,116,114,115,50,118,51,104,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,240,22,163,21,3,0,0,0,116,114,115,50,118,51,100,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,185,13,187,224,4,0,0,0,116,114,115,50,118,51,99,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,173,125,78,108,4,0,0,0,116,114,115,50,118,51,98,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,241,99,221,111,4,0,0,0,116,114,115,50,118,51,97,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,85,39,246,187,4,0,0,0,114,115,50,45,120,46,120,120,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,97,157,96,84,6,0,0,0,114,115,50,45,99,46,120,120,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,49,216,167,121,6,0,0,0,114,115,50,45,118,46,49,104,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,21,131,130,27,6,0,0,0,116,114,115,50,118,51,101,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,107,141,202,14,5,0,0,0,114,108,95,101,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,18,106,147,125,1,0,16,1,114,108,95,100,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,41,84,216,216,1,0,16,1,114,108,95,101,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,18,238,250,91,1,0,16,1,114,108,95,100,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,191,22,66,230,1,0,16,1,114,108,95,102,50,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,81,3,245,166,2,0,16,1,114,108,95,99,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,176,3,132,124,3,0,32,0,114,108,95,99,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,96,178,46,49,3,0,32,0,114,108,95,99,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,25,82,168,190,3,0,32,0,114,108,95,97,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,25,118,167,194,4,0,32,0,114,108,95,97,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,22,44,156,163,4,0,32,0,114,108,95,97,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,50,14,11,151,4,0,32,0,114,108,95,52,103,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,122,75,203,197,5,0,32,0,114,108,95,52,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,153,60,77,138,5,0,32,0,114,108,95,49,103,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,46,27,212,116,5,0,32,0,114,108,95,49,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,187,50,203,125,5,0,32,0,114,108,95,50,103,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,180,3,73,116,5,0,32,0,114,108,95,50,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,117,158,100,9,5,0,32,0,114,108,95,102,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,115,6,132,71,6,0,64,0,100,55,50,45,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,159,117,103,168,2,0,0,0,100,55,50,45,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,167,9,44,82,2,0,0,0,100,55,50,45,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,226,70,160,44,9,0,0,0,100,55,50,45,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,208,87,226,29,11,0,0,0,100,55,50,45,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,64,166,13,191,11,0,0,0,100,55,50,45,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,48,136,43,184,24,0,0,0,112,97,108,49,54,108,56,45,100,55,50,45,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,126,203,212,195,0,0,0,8,112,97,108,49,54,108,56,45,100,55,50,45,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,252,14,88,39,0,0,0,8,112,97,108,99,101,50,48,118,56,45,100,55,50,45,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,87,1,0,0,76,230,89,99,0,0,0,8,112,97,108,99,101,50,48,118,56,45,100,55,50,45,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,87,1,0,0,116,100,106,116,0,0,0,8,112,97,108,99,101,50,48,118,56,45,100,55,50,45,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,87,1,0,0,0,8,104,159,0,0,0,8,112,97,108,99,101,49,54,118,56,45,100,55,50,45,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,162,27,24,165,0,0,0,8,51,46,117,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,222,124,194,184,1,0,16,1,49,46,117,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,84,205,1,206,1,0,16,1,52,46,117,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,76,85,92,79,1,0,16,1,50,46,117,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,141,27,250,101,1,0,16,1,116,50,55,48,57,117,51,50,46,117,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,108,25,15,144,3,0,32,0,116,50,55,48,57,117,50,54,46,117,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,73,200,106,65,3,0,32,0,116,50,55,48,57,117,52,50,46,117,51,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,4,87,77,25,4,0,32,0,116,50,55,48,57,117,51,57,46,117,52,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,109,167,149,111,4,0,32,0,116,50,55,48,57,117,52,55,46,117,52,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,64,173,189,14,6,0,64,0,116,50,55,48,57,117,53,53,46,117,53,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,104,12,150,67,6,0,64,0,102,110,48,48,49,48,48,49,46,49,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,23,235,248,123,1,0,16,1,102,110,48,48,49,48,48,51,46,49,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,17,241,110,238,1,0,16,1,102,110,48,48,49,48,48,52,46,49,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,162,57,161,91,3,0,32,0,102,110,48,48,49,48,48,53,46,49,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,99,106,114,149,4,0,32,0,102,110,48,48,49,48,48,54,46,49,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,230,1,242,131,6,0,64,0,118,105,99,45,48,56,48,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,142,72,137,37,1,0,16,1,118,105,99,45,48,56,48,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,15,195,114,175,2,0,32,0,118,105,99,45,48,56,48,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,112,1,217,148,3,0,32,0,118,105,99,45,48,56,48,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,161,37,127,41,3,0,32,0,118,105,99,45,48,56,48,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,79,76,72,207,3,0,32,0,118,105,99,45,48,56,48,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,151,217,229,54,3,0,32,0,118,105,99,45,48,56,48,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,154,126,21,79,4,0,16,1,48,56,48,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,96,143,225,11,5,0,64,0,118,105,99,45,48,56,48,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,91,238,159,113,5,0,64,0,118,105,99,45,48,56,48,45,118,51,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,222,239,183,100,5,0,64,0,48,50,51,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,163,253,136,196,1,0,16,1,48,50,51,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,138,129,49,172,2,0,32,0,48,50,51,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,90,83,153,41,3,0,32,0,48,50,51,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,230,153,106,135,3,0,32,0,48,50,51,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,224,5,33,42,4,0,16,1,48,50,51,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,211,91,62,165,5,0,64,0,48,52,50,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,207,157,113,237,1,0,16,1,48,52,50,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,230,214,79,22,2,0,32,0,48,52,50,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,161,9,88,203,3,0,32,0,48,52,50,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,235,223,54,20,3,0,32,0,48,52,50,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,165,212,188,3,0,32,0,48,52,50,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,155,33,2,214,3,0,32,0,48,52,50,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,93,153,25,187,4,0,16,1,48,52,50,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,71,130,127,175,5,0,64,0,48,52,50,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,89,75,71,198,5,0,64,0,50,52,56,106,97,97,48,50,46,56,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,16,148,183,250,0,0,16,1,50,52,56,106,97,97,48,51,46,56,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,243,142,136,141,0,0,16,1,50,52,56,106,97,97,48,52,46,49,48,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,203,22,203,86,0,0,16,1,50,52,56,106,97,97,48,53,46,49,48,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,205,79,97,39,0,0,16,1,50,52,56,97,48,49,46,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,198,28,164,168,0,0,16,1,50,52,56,97,49,50,46,49,54,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,135,9,135,98,0,0,32,0,50,52,56,97,49,49,46,49,50,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,253,219,210,250,0,0,32,0,50,52,56,97,48,57,46,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,5,226,118,161,0,0,32,0,50,52,56,97,48,55,46,51,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,159,88,149,149,0,0,32,0,50,52,56,97,48,54,46,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,239,29,186,15,0,0,64,0,113,103,97,107,117,109,111,110,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,56,210,123,132,0,0,0,8,103,48,50,46,117,52,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,67,188,51,123,0,0,16,1,103,48,50,46,117,52,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,55,102,111,143,0,0,16,1,103,48,50,46,117,52,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,36,61,142,23,0,0,16,1,103,48,50,46,117,52,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,153,238,180,160,0,0,16,1,103,48,50,46,117,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,30,94,234,235,0,0,16,1,103,48,50,46,117,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,152,3,227,145,0,0,32,0,103,48,50,46,117,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,215,93,69,217,0,0,32,0,103,48,50,46,117,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,11,86,32,77,0,0,32,0,103,48,50,46,117,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,110,155,123,177,0,0,32,0,103,48,50,46,117,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,120,24,84,8,0,0,32,0,103,48,50,46,117,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,54,42,207,190,0,0,32,0,103,48,50,46,117,54,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,139,43,254,82,0,0,32,0,103,48,50,46,117,55,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,210,99,202,30,0,0,32,0,103,48,50,46,117,56,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,133,246,63,138,0,0,32,0,103,48,50,46,117,56,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,115,31,62,55,0,0,32,0,103,48,50,46,56,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,214,103,53,75,0,0,32,0,103,48,50,46,117,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,224,217,189,196,0,0,64,0,103,48,50,46,117,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,14,213,87,19,0,0,64,0,103,48,50,46,117,53,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,152,40,16,45,0,0,64,0,103,48,50,46,117,53,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,218,13,245,159,0,0,64,0,50,115,112,95,118,50,48,48,46,117,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,193,134,92,250,1,0,16,1,50,115,112,95,118,50,48,48,46,117,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,166,168,91,42,1,0,16,1,116,48,57,48,48,46,117,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,17,86,97,112,2,0,32,0,97,48,57,48,48,46,117,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,81,18,145,20,3,0,32,0,98,48,57,48,48,46,117,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,182,56,6,111,4,0,32,0,109,48,57,48,48,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,46,175,167,158,5,0,64,0,112,117,122,122,108,105,50,95,105,103,115,48,50,55,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,7,0,16,17,50,48,50,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,91,65,97,43,1,0,16,1,50,48,50,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,79,38,25,205,2,0,32,0,50,48,50,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,239,149,0,204,3,0,32,0,50,48,50,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,7,19,55,66,3,0,32,0,50,48,50,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,234,145,2,156,4,0,16,1,50,48,50,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,251,184,190,222,5,0,64,0,50,51,53,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,226,93,237,175,1,0,16,1,50,51,53,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,30,217,104,90,2,0,32,0,50,48,50,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,239,149,0,204,3,0,32,0,50,48,50,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,7,19,55,66,3,0,32,0,50,48,50,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,234,145,2,156,4,0,16,1,50,48,50,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,251,184,190,222,5,0,64,0,118,49,48,48,109,103,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,121,217,121,76,1,0,16,1,118,49,48,48,109,103,46,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,125,183,136,87,1,0,16,1,116,48,56,48,48,46,117,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,89,78,216,249,2,0,32,0,97,48,56,48,48,46,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,64,236,230,225,3,0,32,0,98,48,56,48,48,46,117,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,245,190,231,82,4,0,32,0,109,48,56,48,48,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,65,101,164,225,5,0,64,0,112,117,122,108,115,116,97,114,95,105,103,115,48,50,55,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,7,0,16,17,112,109,97,110,45,49,50,46,105,99,50,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,157,16,81,66,1,0,16,1,112,109,97,110,45,49,49,46,105,99,49,57,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,159,237,103,17,1,0,16,1,112,109,97,110,45,49,51,46,105,99,50,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,122,130,3,188,2,0,16,1,112,117,115,104,109,97,110,54,56,55,48,53,114,51,112,46,105,99,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,87,102,145,215,3,0,16,1,112,109,97,110,45,49,46,105,99,49,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,84,119,73,20,4,0,32,0,112,109,97,110,45,52,46,105,99,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,107,206,229,22,5,0,32,0,112,109,97,110,45,53,46,105,99,53,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,184,64,33,184,5,0,32,0,112,109,97,110,45,50,46,53,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,41,172,178,44,5,0,32,0,112,109,97,110,45,51,46,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,200,87,185,138,5,0,32,0,112,109,97,110,45,54,46,105,99,49,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,37,144,15,189,6,0,32,0,112,109,97,110,45,56,46,105,99,49,52,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,192,213,27,89,6,0,32,0,112,109,97,110,45,55,46,105,99,49,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,151,177,140,32,6,0,32,0,112,109,97,110,45,57,46,105,99,49,52,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,119,133,238,119,6,0,32,0,112,109,97,110,45,49,48,46,105,99,49,56,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,161,233,154,95,7,0,32,0,110,56,50,115,49,50,57,97,110,46,105,99,56,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,54,174,128,236,0,0,32,0,112,117,115,104,109,97,110,97,46,50,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,88,8,29,135,1,0,16,1,112,117,115,104,109,97,110,97,46,48,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,30,118,87,174,1,0,16,1,112,117,115,104,109,97,110,46,48,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,193,102,254,173,2,0,16,1,112,117,115,104,109,97,110,54,56,55,48,53,114,51,112,46,105,99,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,87,102,145,215,3,0,16,1,112,117,115,104,109,97,110,97,46,49,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,231,146,63,248,4,0,32,0,112,117,115,104,109,97,110,46,48,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,112,250,170,135,5,0,32,0,112,117,115,104,109,97,110,46,48,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,12,32,209,127,5,0,32,0,112,117,115,104,109,97,110,46,48,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,176,74,9,10,5,0,32,0,112,117,115,104,109,97,110,46,48,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,157,242,209,115,5,0,32,0,112,117,115,104,109,97,110,46,48,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,166,61,239,72,6,0,32,0,112,117,115,104,109,97,110,46,48,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,136,62,106,75,6,0,32,0,112,117,115,104,109,97,110,46,48,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,189,32,0,183,6,0,32,0,112,117,115,104,109,97,110,46,48,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,103,86,85,204,6,0,32,0,112,117,115,104,109,97,110,97,46,49,56,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,152,85,242,89,7,0,32,0,110,56,50,115,49,50,57,97,110,46,105,99,56,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,54,174,128,236,0,0,32,0,57,48,55,45,106,48,50,46,105,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,59,162,179,219,0,0,16,1,57,48,55,45,106,48,51,46,105,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,171,209,81,33,0,0,16,1,57,48,55,102,48,49,46,101,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,132,196,64,240,0,0,16,1,57,48,55,100,48,54,46,101,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,244,56,204,245,0,0,32,0,57,48,55,100,48,53,46,101,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,193,116,87,226,0,0,32,0,57,48,55,100,48,55,46,107,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,67,69,254,176,0,0,32,0,57,48,55,100,48,56,46,107,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,157,141,172,213,0,0,32,0,57,48,55,100,48,52,46,100,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,94,235,15,9,0,0,64,0,112,109,48,49,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,10,97,232,95,1,0,16,1,112,109,48,50,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,108,140,211,97,1,0,16,1,112,109,48,51,46,54,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,159,249,126,78,1,0,16,1,112,109,48,52,46,54,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,210,221,57,137,1,0,16,1,112,109,57,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,7,171,41,34,2,0,32,0,112,109,49,49,46,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,157,184,145,53,2,0,32,0,112,109,49,48,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,58,50,57,158,2,0,32,0,112,109,49,50,46,53,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,150,144,29,27,2,0,32,0,56,50,115,49,50,51,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,189,80,198,47,3,0,32,0,56,50,115,49,50,54,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,228,168,179,62,3,0,32,0,56,50,115,49,50,54,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,134,204,169,4,0,64,0,56,50,115,49,50,54,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,110,97,109,99,111,112,97,99,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,179,99,226,254,1,0,16,1,110,97,109,112,102,97,115,116,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,185,141,179,81,1,0,16,1,110,97,109,99,111,112,97,99,46,54,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,3,59,8,2,1,0,16,1,110,97,109,99,111,112,97,99,46,54,106,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,85,254,54,122,1,0,16,1,112,97,99,109,97,110,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,100,73,148,12,2,0,32,0,112,97,99,109,97,110,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,249,237,143,149,2,0,32,0,56,50,115,49,50,51,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,189,80,198,47,3,0,32,0,56,50,115,49,50,54,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,228,168,179,62,3,0,32,0,56,50,115,49,50,54,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,134,204,169,4,0,64,0,56,50,115,49,50,54,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,110,97,109,99,111,112,97,99,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,179,99,226,254,1,0,16,1,110,97,109,99,111,112,97,99,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,131,252,209,57,1,0,16,1,110,97,109,99,111,112,97,99,46,54,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,3,59,8,2,1,0,16,1,110,97,109,99,111,112,97,99,46,54,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,85,254,54,122,1,0,16,1,112,97,99,109,97,110,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,100,73,148,12,2,0,32,0,112,97,99,109,97,110,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,249,237,143,149,2,0,32,0,56,50,115,49,50,51,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,189,80,198,47,3,0,32,0,56,50,115,49,50,54,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,228,168,179,62,3,0,32,0,56,50,115,49,50,54,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,134,204,169,4,0,64,0,56,50,115,49,50,54,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,48,54,56,45,112,103,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,143,64,90,16,1,0,16,1,48,54,56,45,115,103,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,153,34,8,24,2,0,32,0,48,54,56,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,118,15,37,127,3,0,32,0,48,54,56,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,115,40,145,32,3,0,32,0,48,54,56,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,161,27,100,75,3,0,32,0,48,54,56,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,150,37,7,53,3,0,32,0,48,54,56,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,36,214,29,21,3,0,32,0,48,54,56,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,4,38,114,166,3,0,32,0,48,54,56,45,109,103,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,30,145,199,177,4,0,16,1,48,54,56,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,223,134,237,44,5,0,64,0,48,54,56,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,171,81,8,151,5,0,64,0,48,54,56,45,118,51,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,170,5,255,129,5,0,64,0,102,51,95,104,48,45,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,253,49,241,56,1,0,16,1,102,51,95,108,48,45,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,156,150,98,22,1,0,16,1,102,51,95,104,49,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,124,148,209,200,1,0,16,1,102,51,95,108,49,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,252,146,148,123,1,0,16,1,102,51,95,115,104,48,46,115,104,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,94,94,181,144,2,0,16,1,102,51,95,115,108,48,46,115,108,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,87,109,193,119,2,0,16,1,102,51,95,119,53,48,46,99,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,238,136,231,71,3,0,32,0,102,51,95,119,53,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,63,94,83,142,3,0,32,0,102,51,95,119,53,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,86,46,235,166,3,0,32,0,102,51,95,119,53,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,7,40,153,47,3,0,32,0,102,51,95,119,51,55,46,48,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,3,218,76,253,4,0,32,0,102,51,95,119,51,56,46,48,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,16,171,91,117,4,0,32,0,102,51,95,119,51,57,46,48,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,146,237,28,178,4,0,32,0,102,51,95,119,52,48,46,48,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,137,104,144,46,4,0,32,0,102,51,95,119,52,49,46,48,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,16,93,69,2,4,0,32,0,102,51,95,119,52,50,46,48,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,185,137,69,18,4,0,32,0,102,51,95,119,52,51,46,48,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,122,50,231,218,4,0,32,0,102,51,95,119,52,52,46,48,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,172,132,252,208,4,0,32,0,102,51,95,119,57,53,46,100,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,43,67,202,247,5,0,64,0,112,122,95,48,48,45,48,46,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,135,92,113,236,1,0,16,1,109,99,98,45,48,48,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,43,79,138,196,2,0,32,0,109,99,98,45,48,50,46,49,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,56,251,60,66,3,0,32,0,109,99,98,45,48,53,46,49,52,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,251,12,84,129,3,0,32,0,109,99,98,45,48,49,46,49,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,87,10,244,6,3,0,32,0,109,99,98,45,48,51,46,49,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,175,115,239,10,3,0,32,0,112,122,95,48,49,45,48,46,49,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,226,188,37,137,4,0,64,0,109,99,98,45,48,52,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,144,53,61,226,5,0,64,0,101,101,112,114,111,109,45,112,114,116,121,116,105,109,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,218,0,87,16,6,0,16,1,50,53,53,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,243,192,163,223,1,0,16,1,50,53,53,45,112,50,46,115,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,128,11,5,66,1,0,16,1,50,53,53,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,11,0,6,234,3,0,32,0,50,53,53,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,121,125,230,4,3,0,32,0,50,53,53,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,8,30,227,96,3,0,32,0,50,53,53,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,105,29,55,64,3,0,32,0,50,53,53,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,223,106,46,11,3,0,32,0,50,53,53,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,211,189,1,176,3,0,32,0,50,53,53,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,20,64,253,142,4,0,16,1,50,53,53,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,61,84,20,90,5,0,64,0,50,53,53,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,26,217,16,102,5,0,64,0,57,51,48,57,53,45,51,97,46,117,49,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,61,234,37,152,0,0,16,1,57,51,48,57,53,45,52,46,117,49,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,130,167,215,211,0,0,16,1,57,51,48,57,53,45,50,46,117,57,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,198,60,18,75,0,0,16,1,57,51,48,57,53,45,53,46,117,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,8,24,55,177,0,0,32,0,57,51,48,57,53,45,54,46,117,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,128,93,200,41,0,0,32,0,57,51,48,57,53,45,55,46,117,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,73,97,215,45,0,0,32,0,57,51,48,57,53,45,49,46,117,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,224,158,87,106,0,0,32,0,57,51,48,57,53,45,49,50,46,117,49,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,163,194,243,53,0,0,32,0,57,51,48,57,53,45,49,51,46,117,49,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,218,69,189,30,0,0,32,0,57,51,48,57,53,45,49,52,46,117,49,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,27,135,13,118,0,0,32,0,57,51,48,57,53,45,49,53,46,117,49,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,136,190,17,208,0,0,32,0,57,51,48,57,53,45,49,54,46,117,49,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,156,108,193,169,0,0,32,0,57,51,48,57,53,45,49,55,46,117,49,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,136,114,181,81,0,0,32,0,57,51,48,57,53,45,49,56,46,117,49,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,242,227,53,177,0,0,32,0,57,51,48,57,53,45,49,57,46,117,49,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,55,85,105,103,0,0,32,0,57,51,48,57,53,45,49,48,46,117,52,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,197,198,154,50,0,0,64,0,57,51,48,57,53,45,49,49,46,117,52,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,124,9,214,117,0,0,64,0,57,51,48,57,53,45,56,46,117,52,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,219,190,25,240,0,0,64,0,57,51,48,57,53,45,57,46,117,52,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,101,55,200,173,0,0,64,0,50,50,46,117,56,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,75,236,213,103,0,0,0,8,50,49,46,117,55,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,31,216,44,24,0,0,0,8,50,48,46,117,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,47,14,189,56,0,0,0,8,23,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,40,182,1,0,23,0,0,0,1,1,0,0,96,135,7,0,23,0,0,0,1,1,1,0,152,182,7,0,0,0,0,0,254,0,8,0,184,40,2,0,23,0,0,0,1,112,48,0,8,7,5,0,23,0,0,0,1,112,80,0,216,36,5,0,23,0,0,0,1,112,16,0,224,67,5,0,23,0,0,0,1,112,0,0,200,201,5,0,23,0,0,0,1,112,64,0,152,160,5,0,23,0,0,0,1,112,32,0,144,127,5,0,23,0,0,0,1,112,96,0,168,98,5,0,23,0,0,0,1,112,112,0,88,86,6,0,0,0,0,0,254,0,8,0,184,164,8,0,23,0,0,0,1,14,6,0,8,7,5,0,23,0,0,0])
.concat([1,14,10,0,216,36,5,0,23,0,0,0,1,14,2,0,224,67,5,0,23,0,0,0,1,14,0,0,200,201,5,0,23,0,0,0,1,14,8,0,152,160,5,0,23,0,0,0,1,14,4,0,144,127,5,0,23,0,0,0,1,14,12,0,168,98,5,0,23,0,0,0,1,14,14,0,88,86,6,0,0,0,0,0,254,0,2,0,96,228,6,0,23,0,0,0,1,128,0,0,96,135,7,0,23,0,0,0,1,128,128,0,152,182,7,0,0,0,0,0,57,51,48,57,53,45,51,106,46,117,49,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,251,163,80,48,0,0,16,1,57,51,48,57,53,45,52,46,117,49,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,130,167,215,211,0,0,16,1,57,51,48,57,53,45,50,46,117,57,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,198,60,18,75,0,0,16,1,57,51,48,57,53,45,53,46,117,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,8,24,55,177,0,0,32,0,57,51,48,57,53,45,54,46,117,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,128,93,200,41,0,0,32,0,57,51,48,57,53,45,55,46,117,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,73,97,215,45,0,0,32,0,57,51,48,57,53,45,49,46,117,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,224,158,87,106,0,0,32,0,57,51,48,57,53,45,49,50,46,117,49,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,163,194,243,53,0,0,32,0,57,51,48,57,53,45,49,51,46,117,49,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,218,69,189,30,0,0,32,0,57,51,48,57,53,45,49,52,46,117,49,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,27,135,13,118,0,0,32,0,57,51,48,57,53,45,49,53,46,117,49,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,136,190,17,208,0,0,32,0,57,51,48,57,53,45,49,54,46,117,49,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,156,108,193,169,0,0,32,0,57,51,48,57,53,45,49,55,46,117,49,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,136,114,181,81,0,0,32,0,57,51,48,57,53,45,49,56,46,117,49,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,242,227,53,177,0,0,32,0,57,51,48,57,53,45,49,57,46,117,49,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,55,85,105,103,0,0,32,0,57,51,48,57,53,45,49,48,46,117,52,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,197,198,154,50,0,0,64,0,57,51,48,57,53,45,49,49,46,117,52,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,124,9,214,117,0,0,64,0,57,51,48,57,53,45,56,46,117,52,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,219,190,25,240,0,0,64,0,57,51,48,57,53,45,57,46,117,52,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,101,55,200,173,0,0,64,0,50,50,46,117,56,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,75,236,213,103,0,0,0,8,50,49,46,117,55,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,31,216,44,24,0,0,0,8,50,48,46,117,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,47,14,189,56,0,0,0,8,24,0,0,0,255,255,4,0,0,0,0,0,0,0,0,0,254,0,2,0,88,210,5,0,24,0,0,0,1,2,0,0,96,135,7,0,24,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,2,0,80,105,6,0,24,0,0,0,1,4,0,0,96,135,7,0,24,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,254,0,2,0,192,125,6,0,24,0,0,0,1,8,8,0,96,135,7,0,24,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,107,5,0,24,0,0,0,1,16,0,0,120,76,7,0,24,0,0,0,1,16,16,0,240,72,7,0,0,0,0,0,254,0,2,0,88,14,5,0,24,0,0,0,1,32,0,0,248,38,7,0,24,0,0,0,1,32,32,0,56,252,3,0,0,0,0,0,254,0,4,0,72,202,5,0,24,0,0,0,1,192,128,0,80,246,3,0,24,0,0,0,1,192,0,0,248,38,7,0,24,0,0,0,1,192,64,0,112,212,3,0,24,0,0,0,1,192,192,0,248,160,5,0,0,0,0,0,50,113,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,42,63,191,17,0,0,16,1,50,114,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,190,33,214,216,0,0,16,1,49,102,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,198,60,18,75,0,0,16,1,49,51,107,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,184,180,117,25,0,0,32,0,49,51,108,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,25,73,110,55,0,0,32,0,49,51,111,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,50,245,95,13,0,0,32,0,49,51,113,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,145,87,178,153,0,0,32,0,49,51,114,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,73,97,215,45,0,0,32,0,54,110,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,224,158,87,106,0,0,32,0,49,52,103,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,201,137,155,139,0,0,32,0,49,49,103,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,123,18,77,0,0,32,0,49,51,103,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,14,181,142,41,0,0,32,0,49,49,105,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,131,210,230,87,0,0,32,0,49,50,103,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,103,65,24,251,0,0,32,0,49,49,106,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,77,42,117,27,0,0,32,0,49,52,109,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,123,186,38,47,0,0,32,0,49,49,107,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,155,216,99,2,0,0,32,0,49,52,110,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,148,50,99,196,0,0,32,0,49,49,108,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,85,86,75,94,0,0,32,0,49,52,112,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,78,14,75,77,0,0,32,0,49,49,111,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,43,45,159,126,0,0,32,0,49,51,112,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,242,113,118,14,0,0,32,0,49,49,112,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,177,89,238,0,0,32,0,49,50,112,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,140,153,177,154,0,0,32,0,49,49,113,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,138,200,176,26,0,0,32,0,52,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,78,130,214,140,0,0,64,0,52,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,77,224,26,227,0,0,64,0,52,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,153,245,201,196,0,0,64,0,52,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,225,240,169,240,0,0,64,0,53,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,2,117,85,98,0,0,64,0,53,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,215,107,200,219,0,0,64,0,53,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,189,162,57,88,0,0,64,0,53,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,195,157,111,68,0,0,64,0,56,50,115,49,50,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,75,236,213,103,0,0,0,8,56,50,115,49,52,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,66,133,129,215,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,214,132,108,184,0,0,16,1,114,111,109,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,130,167,215,211,0,0,16,1,114,111,109,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,128,15,193,182,0,0,32,0,114,111,109,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,73,97,215,45,0,0,32,0,114,111,109,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,224,158,87,106,0,0,32,0,114,111,109,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,232,80,173,239,0,0,32,0,114,111,109,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,146,149,34,8,0,0,32,0,114,111,109,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,109,221,47,176,0,0,32,0,114,111,109,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,150,153,171,146,0,0,32,0,114,111,109,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,143,156,87,136,0,0,64,0,24,0,0,0,255,255,4,0,0,0,0,0,0,0,0,0,254,0,2,0,48,140,3,0,24,0,0,0,1,1,0,0,240,116,3,0,24,0,0,0,1,1,1,0,216,93,3,0,0,0,0,0,254,0,2,0,88,210,5,0,24,0,0,0,1,2,0,0,96,135,7,0,24,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,2,0,80,105,6,0,24,0,0,0,1,4,0,0,96,135,7,0,24,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,254,0,2,0,192,125,6,0,24,0,0,0,1,8,8,0,96,135,7,0,24,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,107,5,0,24,0,0,0,1,16,0,0,120,76,7,0,24,0,0,0,1,16,16,0,240,72,7,0,0,0,0,0,254,0,2,0,88,14,5,0,24,0,0,0,1,32,0,0,248,38,7,0,24,0,0,0,1,32,32,0,56,252,3,0,0,0,0,0,254,0,4,0,72,202,5,0,24,0,0,0,1,192,128,0,80,246,3,0,24,0,0,0,1,192,0,0,248,38,7,0,24,0,0,0,1,192,64,0,112,212,3,0,24,0,0,0,1,192,192,0,248,160,5,0,97,102,101,103,97,52,46,117,49,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,98,23,25,219,1,0,16,1,97,102,101,103,97,53,46,117,49,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,139,196,224,23,1,0,16,1,97,102,101,103,97,49,46,117,57,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,142,242,140,93,2,0,16,1,97,102,101,103,97,51,46,117,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,210,213,157,243,3,0,32,0,97,102,101,103,97,54,46,117,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,151,108,80,109,4,0,32,0,97,102,101,103,97,55,46,117,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,222,249,215,2,4,0,32,0,97,102,101,103,97,50,46,117,57,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,172,238,216,236,6,0,64,0,50,51,55,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,79,228,150,190,1,0,16,1,50,51,55,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,149,245,28,182,2,0,32,0,50,51,55,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,102,45,164,237,3,0,32,0,50,51,55,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,101,60,99,94,3,0,32,0,50,51,55,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,221,70,201,212,4,0,16,1,50,51,55,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,235,27,203,237,5,0,64,0,112,112,111,107,111,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,103,118,7,73,1,0,16,1,112,112,111,107,111,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,26,120,1,81,1,0,16,1,112,112,111,107,111,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,34,237,144,215,1,0,16,1,112,112,111,107,111,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,105,144,68,78,1,0,16,1,112,112,111,107,111,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,125,61,202,84,1,0,16,1,112,112,111,107,111,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,224,199,85,48,1,0,16,1,112,112,111,107,111,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,202,71,190,60,1,0,16,1,112,112,111,107,111,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,125,226,155,179,1,0,16,1,112,112,111,107,111,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,6,26,62,183,2,0,32,0,112,112,111,107,111,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,93,155,6,98,2,0,32,0,56,50,115,49,50,51,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,189,80,198,47,3,0,32,0,56,50,115,49,50,54,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,228,168,179,62,3,0,32,0,56,50,115,49,50,54,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,134,204,169,4,0,64,0,56,50,115,49,50,54,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,50,48,48,51,45,112,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,238,33,4,117,1,0,16,1,50,48,48,51,45,115,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,47,109,162,2,0,32,0,50,48,48,51,45,99,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,183,178,95,3,0,32,0,50,48,48,51,45,99,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,227,112,181,242,3,0,32,0,110,110,112,45,109,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,100,222,105,118,4,0,16,1,110,110,112,45,118,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,73,248,75,80,5,0,64,0,97,57,56,45,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,6,158,127,16,1,0,16,1,97,57,56,45,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,242,106,110,223,1,0,16,1,97,57,56,45,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,92,119,86,188,2,0,16,1,112,108,109,112,56,55,52,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,3,0,0,16,97,57,56,45,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,202,61,3,243,4,0,32,0,97,57,56,45,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,12,123,209,242,4,0,32,0,97,57,56,45,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,10,155,81,26,4,0,32,0,97,57,56,45,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,161,1,69,182,4,0,32,0,97,57,56,45,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,99,105,195,69,4,0,32,0,97,57,56,45,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,27,52,117,224,4,0,32,0,97,57,56,45,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,129,205,22,142,4,0,32,0,97,57,56,45,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,154,96,167,191,4,0,32,0,97,57,56,45,49,51,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,165,45,222,124,5,0,32,0,97,57,56,45,49,50,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,167,157,220,144,5,0,32,0,100,49,50,46,117,52,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,61,46,138,237,0,0,16,1,100,49,51,46,117,52,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,49,23,130,37,0,0,16,1,100,49,52,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,2,20,203,194,0,0,16,1,100,49,54,46,117,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,62,198,161,80,0,0,16,1,100,49,53,46,117,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,192,206,82,99,0,0,16,1,100,49,55,46,117,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,216,16,248,122,0,0,16,1,100,49,57,46,117,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,89,132,89,71,0,0,16,1,103,48,50,46,117,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,152,3,227,145,0,0,32,0,103,48,50,46,117,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,215,93,69,217,0,0,32,0,103,48,50,46,117,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,11,86,32,77,0,0,32,0,103,48,50,46,117,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,110,155,123,177,0,0,32,0,103,48,50,46,117,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,120,24,84,8,0,0,32,0,103,48,50,46,117,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,54,42,207,190,0,0,32,0,97,116,103,115,46,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,169,52,111,170,0,0,32,0,97,116,103,115,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,39,218,62,85,0,0,32,0,97,116,103,115,46,117,55,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,203,14,113,22,0,0,32,0,97,116,103,115,46,117,56,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,145,202,42,203,0,0,32,0,97,116,103,115,46,117,56,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,15,90,244,101,0,0,32,0,116,101,120,116,46,117,56,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,234,51,115,245,0,0,32,0,103,48,50,46,117,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,224,217,189,196,0,0,64,0,103,48,50,46,117,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,14,213,87,19,0,0,64,0,103,48,50,46,117,53,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,152,40,16,45,0,0,64,0,103,48,50,46,117,53,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,218,13,245,159,0,0,64,0,112,103,117,110,119,97,114,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,243,62,127,53,1,0,16,1,112,103,117,110,119,97,114,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,158,228,146,0,1,0,16,1,112,107,119,97,114,46,48,51,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,234,235,250,86,1,0,16,1,112,107,119,97,114,46,48,49,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,146,59,141,66,2,0,32,0,112,107,119,97,114,46,48,50,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,188,167,29,206,2,0,32,0,112,103,117,110,119,97,114,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,67,52,164,162,2,0,32,0,112,107,119,97,114,46,48,52,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,168,252,29,6,2,0,32,0,112,107,119,97,114,46,99,111,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,226,197,15,175,3,0,32,0,107,101,48,48,45,50,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,58,175,75,176,1,0,16,1,109,97,122,45,48,50,46,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,89,90,211,201,2,0,32,0,109,97,122,45,48,48,46,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,244,113,48,250,3,0,32,0,109,97,122,45,48,49,46,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,33,254,52,73,3,0,32,0,107,101,48,49,46,49,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,99,98,16,138,4,0,64,0,109,97,122,45,48,51,46,49,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,100,201,19,163,5,0,64,0,112,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,252,27,206,198,1,0,16,1,112,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,51,90,101,162,1,0,16,1,112,105,114,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,84,105,203,98,1,0,16,1,112,105,114,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,188,0,7,203,1,0,16,1,112,105,114,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,229,191,63,132,1,0,16,1,112,105,114,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,94,77,8,115,1,0,16,1,112,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,209,164,99,147,1,0,16,1,112,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,156,151,105,39,1,0,16,1,112,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,99,117,235,148,2,0,32,0,112,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,115,105,96,163,2,0,32,0,112,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,44,90,22,132,2,0,32,0,112,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,158,186,153,38,2,0,32,0,56,50,115,49,50,51,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,189,80,198,47,3,0,32,0,112,105,114,97,110,104,97,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,123,68,201,8,3,0,32,0,56,50,115,49,50,54,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,134,204,169,4,0,64,0,56,50,115,49,50,54,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,112,114,49,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,36,208,90,188,1,0,16,1,112,97,99,109,97,110,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,212,178,111,26,1,0,16,1,112,114,51,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,157,55,60,71,1,0,16,1,112,114,52,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,149,248,251,99,1,0,16,1,112,114,53,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,12,3,196,63,2,0,32,0,112,114,55,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,16,160,185,48,2,0,32,0,112,114,54,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,213,201,233,243,2,0,32,0,112,114,56,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,13,114,61,19,2,0,32,0,56,50,115,49,50,51,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,189,80,198,47,3,0,32,0,56,50,115,49,50,54,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0])
.concat([228,168,179,62,3,0,32,0,56,50,115,49,50,54,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,134,204,169,4,0,64,0,56,50,115,49,50,54,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,116,112,48,50,53,45,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,89,134,234,178,0,0,16,1,116,112,48,50,53,45,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,57,185,83,220,0,0,16,1,116,112,48,50,53,45,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,68,247,151,171,0,0,32,0,116,112,48,50,53,45,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,30,16,22,123,0,0,32,0,116,112,48,50,53,45,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,229,253,143,191,0,0,16,1,112,48,55,48,49,95,118,49,48,53,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,224,66,177,250,1,0,16,1,116,48,55,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,77,59,148,147,2,0,32,0,97,48,55,48,48,46,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,156,174,169,38,3,0,32,0,97,48,55,48,48,46,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,193,31,188,121,3,0,32,0,97,48,55,48,49,46,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,129,127,96,35,3,0,32,0,97,48,55,48,49,46,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,55,253,46,95,3,0,32,0,97,48,55,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,27,158,35,66,3,0,32,0,98,48,55,48,48,46,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,4,105,9,175,4,0,32,0,98,48,55,48,48,46,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,38,222,83,109,4,0,32,0,99,103,118,49,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,62,236,2,218,4,0,32,0,109,48,55,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,206,175,199,172,5,0,64,0,105,103,115,48,50,55,97,95,112,104,111,116,111,121,50,107,95,118,49,48,48,95,99,104,105,110,97,46,97,115,105,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,246,104,11,26,7,0,16,1,46,0,0,0,255,255,3,0,0,0,0,0,0,0,0,0,254,0,7,0,144,165,4,0,46,0,0,0,1,15,0,0,80,65,1,0,46,0,0,0,1,15,1,0,232,41,1,0,46,0,0,0,1,15,2,0,176,20,3,0,46,0,0,0,1,15,3,0,224,32,1,0,46,0,0,0,1,15,4,0,56,50,1,0,46,0,0,0,1,15,5,0,192,20,3,0,46,0,0,0,1,15,6,0,96,125,4,0,0,0,0,0,112,101,115,116,46,49,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,33,7,213,128,1,0,0,0,112,101,115,116,46,50,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,204,129,54,156,1,0,0,0,112,101,115,116,46,51,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,34,57,133,73,1,0,0,0,112,101,115,116,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,248,165,93,113,2,0,0,0,112,101,115,116,46,111,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,206,158,147,3,3,0,0,0,112,101,115,116,46,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,223,206,202,42,3,0,0,0,112,101,115,116,46,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,62,7,96,231,4,0,0,0,112,101,115,116,46,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,110,52,88,25,4,0,0,0,112,101,115,116,46,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,23,60,153,58,4,0,0,0,112,101,115,116,46,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,163,242,8,191,4,0,0,0,110,56,50,115,49,50,57,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,95,243,48,3,5,0,0,0,110,56,50,115,49,50,57,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,27,49,136,186,5,0,0,0,115,110,55,52,115,50,56,56,110,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,202,242,166,165,5,0,0,0,112,101,115,116,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,86,43,149,40,1,0,0,0,0,0,0,0,0,0,0,0,114,111,109,51,97,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,122,160,90,136,1,0,16,1,114,111,109,52,97,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,172,222,251,155,1,0,16,1,114,111,109,49,46,49,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,248,39,205,37,2,0,16,1,114,111,109,49,48,46,49,54,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,132,142,126,214,3,0,32,0,114,111,109,49,50,46,49,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,51,183,232,107,3,0,32,0,114,111,109,49,49,46,49,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,164,1,37,103,3,0,32,0,114,111,109,49,51,46,49,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,231,92,114,252,3,0,32,0,114,111,109,56,46,56,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,241,26,101,4,0,32,0,114,111,109,57,46,56,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,214,180,53,37,4,0,32,0,114,111,109,55,46,49,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,108,83,247,4,0,32,0,114,111,109,54,46,57,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,138,7,60,4,0,32,0,114,111,109,53,46,57,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,248,226,234,32,4,0,32,0,114,111,109,50,46,49,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,209,122,249,79,4,0,64,0,121,117,117,32,121,117,117,32,106,105,110,115,101,105,32,45,32,118,105,99,116,111,114,121,32,108,105,102,101,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,169,92,144,192,0,0,16,1,110,101,119,32,122,101,97,108,97,110,100,32,115,116,111,114,121,44,32,116,104,101,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,168,117,77,142,0,0,16,1,108,101,103,101,110,100,32,111,102,32,104,101,114,111,32,116,111,110,109,97,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,138,13,139,194,0,0,16,1,107,108,97,120,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,201,251,79,199,0,0,16,1,102,49,32,116,114,105,112,108,101,32,98,97,116,116,108,101,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,9,4,191,19,0,0,16,1,100,57,54,45,48,55,46,101,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,20,202,2,97,1,0,16,1,100,57,54,45,48,52,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,56,229,170,156,2,0,32,0,48,54,56,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,118,15,37,127,3,0,32,0,48,54,56,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,115,40,145,32,3,0,32,0,48,54,56,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,161,27,100,75,3,0,32,0,48,54,56,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,150,37,7,53,3,0,32,0,100,57,54,45,48,50,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,148,212,154,232,3,0,32,0,100,57,54,45,48,51,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,235,215,66,75,3,0,32,0,100,57,54,45,48,54,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,138,54,36,244,4,0,16,1,48,54,56,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,223,134,237,44,5,0,64,0,48,54,56,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,171,81,8,151,5,0,64,0,100,57,54,45,48,49,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,196,203,64,8,5,0,64,0,100,57,54,45,48,53,46,118,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,72,137,84,10,5,0,64,0,50,52,56,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,84,7,108,157,1,0,16,1,50,52,56,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,65,238,63,10,2,0,32,0,50,52,56,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,39,83,17,217,3,0,32,0,50,52,56,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,172,253,249,119,3,0,32,0,50,52,56,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,124,191,144,136,3,0,32,0,50,52,56,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,63,173,254,142,3,0,32,0,50,52,56,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,169,151,48,136,4,0,16,1,50,52,56,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,250,225,253,87,5,0,64,0,50,52,56,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,243,110,150,75,5,0,64,0,57,53,53,108,48,49,46,102,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,235,88,166,73,1,0,16,1,57,53,53,108,48,50,46,104,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,34,115,29,22,1,0,16,1,57,53,53,101,48,51,46,100,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,86,163,10,148,2,0,16,1,57,53,53,100,48,55,46,107,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,63,71,137,3,0,32,0,57,53,53,100,48,56,46,107,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,161,205,213,67,3,0,32,0,57,53,53,100,48,53,46,107,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,224,85,30,122,4,0,32,0,57,53,53,100,48,54,46,107,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,117,40,37,244,4,0,32,0,57,53,53,100,48,52,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,26,73,113,230,5,0,64,0,117,51,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,189,58,243,145,1,0,16,1,117,51,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,236,63,90,173,1,0,16,1,117,54,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,158,11,234,3,0,32,0,117,54,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,221,244,127,107,3,0,32,0,117,54,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,148,146,116,6,3,0,32,0,117,55,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,248,205,218,10,3,0,32,0,117,55,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,196,143,23,105,3,0,32,0,117,55,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,185,132,51,124,3,0,32,0,117,55,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,62,193,251,115,3,0,32,0,117,55,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,17,218,175,241,3,0,32,0,117,50,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,107,173,176,204,4,0,32,0,117,50,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,240,173,91,18,4,0,32,0,117,50,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,199,153,100,67,4,0,32,0,117,50,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,254,128,130,53,4,0,32,0,117,49,51,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,18,170,247,188,5,0,64,0,48,55,51,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,173,86,195,173,1,0,16,1,48,55,51,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,126,222,118,184,2,0,32,0,48,55,51,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,181,225,130,133,3,0,32,0,48,55,51,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,59,9,90,225,3,0,32,0,48,55,51,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,136,93,223,60,4,0,16,1,48,55,51,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,47,109,200,127,5,0,64,0,48,55,51,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,199,223,42,8,5,0,64,0,0,0,0,0,0,0,0,0,0,0,41,74,49,140,57,206,66,16,74,82,82,148,90,214,99,24,0,0,57,222,123,222,1,192,2,128,0,24,0,30,0,0,123,222,0,30,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,30,0,30,0,30,0,30,0,30,0,30,0,30,0,30,0,30,0,30,0,30,0,30,0,30,0,30,0,30,0,30,3,222,3,222,3,222,3,222,3,222,3,222,3,222,3,222,3,222,3,222,3,222,3,222,3,222,3,222,3,222,3,222,3,222,0,14,74,158,0,0,66,16,123,222,82,148,41,74,57,206,2,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,123,222,3,222,1,94,2,94,123,192,0,0,123,222,88,0,121,64,122,64,123,64,123,212,0,0,0,0,0,0,0,0,1,6,9,138,26,14,42,146,59,22,123,222,90,214,57,206,33,8,0,0,0,12,8,82,2,26,3,158,57,206,0,0,123,222,3,222,1,94,2,94,123,192,0,0,123,222,88,0,121,64,122,64,123,64,123,212,0,0,0,0,0,0,0,0,0,20,2,128,104,0,0,0,1,94,2,94,3,30,3,222,57,206,57,206,57,206,57,206,57,206,57,206,57,206,120,0,8,66,82,16,98,148,115,24,115,90,123,222,99,24,74,82,57,206,33,8,0,22,0,16,1,210,3,222,66,10,0,0,123,222,3,222,1,94,2,94,123,192,0,0,123,222,88,0,121,64,122,64,123,64,123,212,0,0,0,0,0,0,0,0,56,192,73,64,89,192,106,64,122,192,0,0,33,8,49,156,66,16,115,156,2,30,2,26,0,12,2,64,1,192,0,0,123,222,3,222,1,94,2,94,123,192,0,0,123,222,88,0,121,64,122,64,123,64,123,212,0,0,0,0,0,0,0,0,123,222,0,30,3,192,66,16,3,222,0,0,90,214,57,206,49,140,41,74,120,0,123,192,2,30,120,30,3,192,0,0,0,206,1,82,1,214,2,90,2,222,0,0,33,8,49,140,66,16,115,156,3,30,2,26,0,12,1,158,0,14,0,0,123,222,3,222,1,94,2,94,123,192,0,0,123,222,88,0,121,64,122,64,123,64,123,212,0,0,0,0,0,0,0,0,1,14,1,80,1,146,1,212,2,22,0,18,0,22,8,66,33,8,49,140,66,16,107,90,1,128,2,0,2,154,0,0,123,222,3,222,1,94,2,94,123,192,0,0,123,222,88,0,121,64,122,64,123,64,123,212,0,0,0,0,0,0,0,0,0,0,41,74,57,206,123,222,1,64,2,64,3,192,1,158,0,30,120,0,0,14,1,84,64,0,3,222,0,22,0,0,33,138,50,10,58,76,74,142,75,80,3,210,3,192,8,66,33,8,49,140,66,16,107,90,1,128,2,0,91,84,0,0,123,222,3,222,1,94,2,94,123,192,0,0,123,222,88,0,121,64,122,64,123,64,123,212,0,0,0,0,0,0,120,0,8,66,82,16,98,148,115,24,115,90,123,222,99,24,74,82,57,206,33,8,0,22,0,16,1,210,3,222,66,10,0,0,123,222,3,222,1,94,2,94,123,192,0,0,123,222,88,0,121,64,122,64,123,64,123,212,0,0,0,0,0,0,120,0,8,66,82,16,98,148,115,24,115,90,123,222,99,24,74,82,57,206,33,8,0,22,0,16,1,210,3,222,66,10,0,0,8,66,41,80,49,148,57,216,74,90,82,158,98,88,75,222,57,142,33,8,0,22,0,16,1,210,0,30,66,10,0,0,123,222,3,222,1,94,2,94,123,192,0,0,123,222,88,0,121,64,122,64,123,64,123,212,0,0,0,0,0,0,0,0,0,0,56,0,41,74,57,206,82,148,24,146,82,158,1,192,3,192,0,30,0,20,0,12,1,74,104,6,114,70,0,0,123,222,3,222,1,94,2,94,123,192,0,0,123,222,88,0,121,64,122,64,123,64,123,212,0,0,0,0,0,0,0,0,123,222,0,30,3,192,66,16,3,222,0,0,90,214,57,206,49,140,41,74,120,0,123,192,2,30,120,30,3,192,0,0,0,0,56,0,41,74,57,206,82,148,24,146,123,222,1,192,3,192,3,222,3,20,1,204,1,74,104,6,114,70,0,0,123,222,3,222,1,94,2,94,123,192,0,0,123,222,88,0,121,64,122,64,123,64,123,212,0,0,0,0,0,0,80,0,1,128,1,192,2,0,2,192,67,208,115,156,74,82,57,206,49,140,8,66,3,222,2,156,96,30,0,26,0,16,0,0,123,222,3,222,1,94,2,94,123,192,0,0,123,222,88,0,121,64,122,64,123,64,123,212,0,0,0,0,0,0,0,0,123,222,0,30,3,192,66,16,3,222,0,0,90,214,57,206,49,140,41,74,120,0,123,192,2,30,120,30,3,192,0,0,1,140,1,206,2,16,42,214,75,222,115,156,2,82,1,206,1,140,8,66,3,222,2,156,96,30,0,26,0,16,0,0,123,222,3,222,1,94,2,94,123,192,0,0,123,222,88,0,121,64,122,64,123,64,123,212,0,0,0,0,0,0,0,0,0,0,56,0,41,74,57,206,82,148,24,146,123,222,1,192,3,192,3,222,3,20,1,204,1,74,104,6,114,70,0,0,123,222,3,222,1,94,2,94,123,192,0,0,123,222,88,0,121,64,122,64,123,64,123,212,0,0,0,0,0,0,0,0,123,222,0,30,3,192,66,16,3,222,0,0,90,214,57,206,49,140,41,74,120,0,123,192,2,30,120,30,3,192,0,0,0,0,56,0,41,74,1,84,2,156,24,146,123,222,3,0,3,192,2,94,1,222,1,82,0,210,104,6,114,70,0,0,123,222,3,222,1,94,2,94,123,192,0,0,123,222,88,0,121,64,122,64,123,64,123,212,0,0,0,0,0,0,0,0,72,16,80,18,88,20,96,22,24,212,2,158,3,194,8,66,41,74,49,140,66,16,120,30,107,22,56,12,104,24,0,0,123,222,3,222,1,94,2,94,123,192,0,0,123,222,88,0,121,64,122,64,123,64,123,212,0,0,0,0,0,0,0,0,123,222,0,30,3,192,66,16,3,222,0,0,90,214,57,206,49,140,41,74,120,0,123,192,2,30,120,30,3,192,0,0,0,22,33,26,41,92,57,222,24,212,2,158,3,194,8,66,41,74,49,140,66,16,66,30,107,24,16,146,49,158,0,0,123,222,3,222,1,94,2,94,123,192,0,0,123,222,88,0,121,64,122,64,123,64,123,212,0,0,0,0,0,0,0,0,66,16,57,206,49,140,74,82,90,214,41,74,0,0,0,30,0,16,1,158,2,94,3,94,56,0,56,14,0,0,0,0,123,222,3,222,1,94,2,94,123,192,0,0,123,222,88,0,121,64,122,64,123,64,123,212,0,0,0,0,0,0,0,0,123,222,0,30,3,192,66,16,3,222,0,0,90,214,57,206,49,140,41,74,120,0,123,192,2,30,120,30,3,192,0,0,2,82,2,16,25,206,50,148,67,24,17,140,0,0,0,30,0,16,1,158,2,94,3,94,56,0,56,14,0,0,0,0,123,222,3,222,1,94,2,94,123,192,0,0,123,222,88,0,121,64,122,64,123,64,123,212,0,0,0,0,0,0,0,0,56,192,73,64,89,192,106,64,122,192,8,66,33,8,49,140,66,16,115,156,3,30,2,26,0,12,96,24,120,30,0,0,123,222,3,222,1,94,2,94,123,192,0,0,123,222,88,0,121,64,122,64,123,64,123,212,0,0,0,0,0,0,0,0,0,0,41,74,57,206,123,222,1,64,2,64,3,192,1,158,0,30,120,0,0,14,1,84,64,0,3,222,0,22,0,0,1,128,2,0,2,128,3,0,3,128,8,66,33,8,49,140,66,16,115,156,0,30,2,92,0,12,96,24,120,30,0,0,123,222,3,222,1,94,2,94,123,192,0,0,123,222,88,0,121,64,122,64,123,64,123,212,0,0,0,0,0,0,0,0,82,158,40,144,40,148,40,152,40,158,8,66,123,222,3,222,2,156,58,192,99,0,107,88,82,146,49,138,49,94,0,0,123,222,3,222,1,94,2,94,123,192,0,0,123,222,88,0,121,64,122,64,123,64,123,212,0,0,0,0,0,0,0,0,123,222,0,30,3,192,66,16,3,222,0,0,90,214,57,206,49,140,41,74,120,0,123,192,2,30,120,30,3,192,99,2,82,158,88,128,121,8,121,140,122,16,8,66,123,222,1,222,1,30,58,192,99,0,107,88,82,146,49,138,122,82,0,0,123,222,3,222,1,94,2,94,123,192,0,0,123,222,88,0,121,64,122,64,123,64,123,212,0,0,0,0,0,0,0,0,0,18,0,22,0,26,1,158,33,128,41,192,50,0,58,128,8,66,33,8,66,16,90,214,115,156,3,222,2,92,0,0,123,222,3,222,1,94,2,94,123,192,0,0,123,222,88,0,121,64,122,64,123,64,123,212,0,0,0,0,0,0,0,0,123,222,0,30,3,192,66,16,3,222,0,0,90,214,57,206,49,140,41,74,120,0,123,192,2,30,120,30,3,192,0,0,2,82,2,214,3,90,3,222,33,128,41,192,50,0,58,128,8,66,33,8,66,16,90,214,115,156,3,222,2,92,0,0,123,222,3,222,1,94,2,94,123,192,0,0,123,222,88,0,121,64,122,64,123,64,123,212,0,0,0,0,0,0,0,0,66,16,57,206,49,140,74,82,90,214,41,74,0,0,0,30,0,16,33,140,41,206,57,0,56,0,56,14,56,0,0,0,123,222,3,222,1,94,2,94,123,192,0,0,123,222,88,0,121,64,122,64,123,64,123,212,0,0,0,0,0,0,0,0,123,222,0,30,3,192,66,16,3,222,0,0,90,214,57,206,49,140,41,74,120,0,123,192,2,30,120,30,3,192,0,0,2,16,1,206,1,140,2,82,2,214,1,74,0,0,0,30,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,123,222,3,222,1,94,2,94,123,192,0,0,123,222,88,0,121,64,122,64,123,64,123,212,0,0,0,0,0,0,0,0,56,192,73,64,89,192,106,64,122,192,8,66,33,8,49,140,66,16,115,156,3,30,2,26,0,12,96,24,120,30,0,0,123,222,3,222,1,94,2,94,123,192,0,0,123,222,88,0,121,64,122,64,123,64,123,212,0,0,0,0,0,0,0,0,0,0,41,74,57,206,123,222,1,64,2,64,3,192,1,158,0,30,120,0,0,14,1,84,64,0,3,222,0,22,0,0,1,192,2,64,2,128,2,192,2,192,1,0,1,192,1,146,2,192,3,192,3,0,2,128,1,64,2,192,3,64,0,0,123,222,3,222,1,94,2,94,123,192,0,0,123,222,88,0,121,64,122,64,123,64,123,212,0,0,0,0,0,0,0,0,8,64,41,0,65,198,82,76,115,84,123,222,99,24,74,82,57,206,33,8,1,156,0,18,1,128,2,192,57,206,0,0,123,222,3,222,1,94,2,94,123,192,0,0,123,222,88,0,121,64,122,64,123,64,123,212,0,0,0,0,0,0,0,0,0,0,41,74,57,206,123,222,1,64,2,64,3,192,1,158,0,30,120,0,0,14,1,84,64,0,3,222,0,22,0,0,8,66,57,12,97,208,122,84,114,20,123,222,123,222,123,24,122,148,33,8,121,158,64,16,121,128,122,192,0,0,0,0,123,222,3,222,1,94,2,94,123,192,0,0,123,222,88,0,121,64,122,64,123,64,123,212,0,0,0,0,0,0,0,0,74,16,65,206,57,140,82,82,98,214,49,74,0,0,0,30,0,16,1,158,2,30,2,222,0,0,0,0,0,0,0,0,123,222,3,222,1,94,2,94,123,192,0,0,123,222,88,0,121,64,122,64,123,64,123,212,0,0,0,0,0,0,0,0,74,16,65,206,57,140,82,82,98,214,49,74,0,0,0,30,0,16,1,158,2,30,2,222,0,0,0,0,0,0,0,0,42,214,2,16,1,206,59,90,123,222,49,74,0,0,0,30,0,16,1,158,2,30,2,222,56,0,56,14,0,0,117,116,50,45,48,48,49,45,48,48,49,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,183,56,51,8,1,0,16,1,117,116,50,45,48,48,49,45,48,48,50,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,174,138,216,57,1,0,16,1,117,116,50,45,48,48,49,45,48,48,52,46,53,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,38,123,196,253,3,0,32,0,117,116,50,45,48,48,49,45,48,48,53,46,53,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,162,148,111,7,3,0,32,0,117,116,50,45,48,48,49,45,48,48,51,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,169,25,2,144,6,0,64,0,112,97,105,110,116,114,108,114,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,181,32,109,85,1,0,16,1,112,97,105,110,116,114,108,114,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,101,169,152,69,1,0,16,1,112,97,105,110,116,114,108,114,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,129,156,162,45,1,0,16,1,112,97,105,110,116,114,108,114,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,84,28,86,31,1,0,16,1,112,97,105,110,116,114,108,114,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,133,183,149,230,1,0,16,1,112,97,105,110,116,114,108,114,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,192,238,230,0,1,0,16,1,112,97,105,110,116,114,108,114,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,75,136,213,15,1,0,16,1,112,97,105,110,116,114,108,114,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,74,17,0,73,1,0,16,1,116,112,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,152,113,97,199,2,0,32,0,109,98,114,117,115,104,46,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,103,105,91,193,2,0,32,0,109,98,114,117,115,104,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,184,92,188,213,2,0,32,0,116,112,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,175,28,93,211,2,0,32,0,56,50,115,49,50,51,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,189,80,198,47,3,0,32,0,50,115,49,52,48,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,39,185,239,99,3,0,32,0,56,50,115,49,50,54,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,134,204,169,4,0,64,0,56,50,115,49,50,54,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,77,75,64,242,1,0,16,1,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,150,182,117,122,2,0,32,0,56,50,115,49,50,51,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,189,80,198,47,3,0,32,0,56,50,115,49,50,54,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,228,168,179,62,3,0,32,0,56,50,115,49,50,54,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,134,204,169,4,0,64,0,56,50,115,49,50,54,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,112,108,49,45,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,153,174,56,169,1,0,16,1,112,108,49,45,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,181,59,228,63,1,0,16,1,112,108,49,95,51,46,56,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,57,167,159,170,1,0,16,1,112,108,49,95,52,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,144,90,137,43,1,0,16,1,112,108,49,95,53,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,98,246,122,1,0,16,1,112,108,49,95,54,46,56,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,169,89,30,176,1,0,16,1,112,108,49,95,55,46,51,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,174,236,91,140,2,0,16,1,99,117,115,54,48,45,54,48,97,49,46,109,99,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,42,168,110,7,2,0,16,1,112,108,49,95,49,50,46,54,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,206,251,89,193,3,0,32,0,112,108,49,95,49,51,46,54,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,174,217,94,108,4,0,32,0,112,108,49,45,57,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,43,150,213,245,5,0,32,0,112,108,49,45,56,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,74,250,235,162,5,0,32,0,112,108,49,45,49,48,46,55,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,4,25,207,199,5,0,32,0,112,108,49,45,49,49,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,26,54,33,102,5,0,32,0,112,108,49,45,50,46,49,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,222,133,40,71,6,0,32,0,112,108,49,45,49,46,49,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,175,189,142,167,6,0,32,0,112,108,49,45,53,46,53,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,18,231,126,75,6,0,32,0,112,108,49,45,52,46,52,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,24,228,123,58,6,0,32,0,112,108,49,45,51,46,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,168,141,85,128,6,0,32,0,112,108,54,95,48,49,46,56,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,28,225,150,76,1,0,16,1,112,108,54,95,48,50,46,56,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,141,189,245,140,1,0,16,1,112,108,49,95,51,46,56,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,57,167,159,170,1,0,16,1,112,108,49,95,52,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,144,90,137,43,1,0,16,1,112,108,49,95,53,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,98,246,122,1,0,16,1,112,108,49,95,54,46,56,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,169,89,30,176,1,0,16,1,112,108,49,95,55,46,51,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,174,236,91,140,2,0,16,1,99,117,115,54,48,45,54,48,97,49,46,109,99,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,42,168,110,7,2,0,16,1,112,108,54,95,49,50,46,54,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,171,97,203,200,3,0,32,0,112,108,49,95,49,51,46,54,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,174,217,94,108,4,0,32,0,112,108,49,95,57,98,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,135,138,118,128,5,0,32,0,112,108,49,95,56,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,109,228,32,43,5,0,32,0,112,108,49,95,49,48,98,46,55,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,110,214,217,255,5,0,32,0,112,108,49,95,49,49,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,216,117,151,197,5,0,32,0,112,108,49,45,50,46,49,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,222,133,40,71,6,0,32,0,112,108,49,45,49,46,49,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,175,189,142,167,6,0,32,0,112,108,49,45,53,46,53,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,18,231,126,75,6,0,32,0,112,108,49,45,52,46,52,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,24,228,123,58,6,0,32,0,112,108,49,45,51,46,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,168,141,85,128,6,0,32,0,112,97,99,104,101,97,114,116,49,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,121,182,68,216,1,0,16,1,112,97,99,104,101,97,114,116,46,112,103,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,56,42,21,185,1,0,16,1,112,97,99,104,101,97,114,116,50,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,83,120,23,125,1,0,16,1,112,97,99,104,101,97,114,116,46,112,103,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,116,101,45,132,1,0,16,1,112,97,99,104,101,97,114,116,51,46,54,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,76,164,69,144,1,0,16,1,112,97,99,104,101,97,114,116,55,46,54,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,62,60,143,136,1,0,16,1,112,97,99,104,101,97,114,116,46,112,103,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,16,92,38,245,1,0,16,1,112,97,99,104,101,97,114,116,46,112,103,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,129,163,33,26,1,0,16,1,112,97,99,104,101,97,114,116,46,99,104,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,191,186,43,198,2,0,32,0,99,104,103,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,157,184,145,53,2,0,32,0,112,97,99,104,101,97,114,116,46,99,104,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,76,24,140,202,2,0,32,0,112,97,99,104,101,97,114,116,46,99,104,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,150,144,29,27,2,0,32,0,56,50,115,49,50,51,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,189,80,198,47,3,0,32,0,56,50,115,49,50,54,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,228,168,179,62,3,0,32,0,56,50,115,49,50,54,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,134,204,169,4,0,64,0,56,50,115,49,50,54,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,116,112,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,72,29,90,168,0,0,16,1,116,112,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,175,68,204,216,0,0,16,1,114,111,109,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,182,199,78,198,0,0,32,0,114,111,109,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,172,197,182,100,0,0,32,0,114,111,109,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,22,45,183,107,0,0,32,0,114,111,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,45,120,52,9,0,0,32,0,114,111,109,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,7,60,144,236,0,0,32,0,114,111,109,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,168,241,203,80,0,0,32,0,116,112,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,31,4,86,221,0,0,16,1,116,112,48,49,56,95,49,48,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,237,204,136,188,0,0,64,0,116,112,48,49,56,95,49,49,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,146,116,225,161,0,0,64,0,20,0,0,0,255,255,0,0,0,0,0,0,21,0,0,0,255,255,0,0,0,0,0,0,22,0,0,0,255,255,2,0,0,0,0,0,0,0,0,0,254,0,2,0,0,0,0,0,20,0,0,0,1,2,0,0,200,211,8,0,20,0,0,0,1,2,2,0,216,147,8,0,0,0,0,0,254,0,2,0,0,0,0,0,20,0,0,0,1,4,0,0,168,84,8,0,20,0,0,0,1,4,4,0,40,31,8,0,0,0,0,0,254,0,2,0,240,233,7,0,20,0,0,0,1,8,0,0,152,182,7,0,20,0,0,0,1,8,8,0,96,135,7,0,0,0,0,0,254,0,4,0,200,87,7,0,20,0,0,0,1,48,0,0,232,38,7,0,20,0,0,0,1,48,16,0,64,251,6,0,20,0,0,0,1,48,32,0,24,211,6,0,20,0,0,0,1,48,48,0,120,33,6,0,0,0,0,0,254,0,4,0,160,123,6,0,20,0,0,0,1,192,0,0,176,73,6,0,20,0,0,0,1,192,64,0,72,32,6,0,20,0,0,0,1,192,128,0,168,241,5,0,20,0,0,0,1,192,192,0,184,201,5,0,0,0,0,0,254,0,4,0,136,160,5,0,21,0,0,0,1,3,0,0,16,150,7,0,21,0,0,0,1,3,1,0,120,198,7,0,21,0,0,0,1,3,2,0,160,103,7,0,21,0,0,0,1,3,3,0,16,53,7,0,0,0,0,0,254,0,4,0,248,6,5,0,21,0,0,0,1,12,0,0,216,129,4,0,21,0,0,0,1,12,4,0,208,102,4,0,21,0,0,0,1,12,8,0,104,76,4,0,21,0,0,0,1,12,12,0,248,75,4,0,0,0,0,0,254,0,4,0,72,22,4,0,21,0,0,0,1,48,0,0,8,49,4,0,21,0,0,0,1,48,16,0,72,246,3,0,21,0,0,0,1,48,32,0,208,75,4,0,21,0,0,0,1,48,48,0,192,255,2,0,0,0,0,0,254,0,2,0,48,185,3,0,21,0,0,0,1,64,0,0,96,135,7,0,21,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,9,0,48,45,3,0,22,0,0,0,1,15,0,0,176,20,3,0,22,0,0,0,1,15,1,0,24,4,2,0,22,0,0,0,1,15,2,0,8,234,2,0,22,0,0,0,1,15,3,0,192,20,3,0,22,0,0,0,1,15,4,0,56,50,1,0,22,0,0,0,1,15,5,0,80,65,1,0,22,0,0,0,1,15,6,0,128,234,2,0,22,0,0,0,1,15,7,0,200,246,3,0,22,0,0,0,1,15,8,0,104,192,2,0,112,114,103,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,215,56,122,18,0,0,16,1,112,114,103,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,22,219,4,151,0,0,16,1,114,111,109,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,182,199,78,198,0,0,32,0,114,111,109,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,172,197,182,100,0,0,32,0,114,111,109,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,22,45,183,107,0,0,32,0,114,111,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,45,120,52,9,0,0,32,0,114,111,109,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,7,60,144,236,0,0,32,0,114,111,109,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,168,241,203,80,0,0,32,0,114,111,109,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,53,226,216,115,0,0,16,1,116,112,48,49,56,95,49,48,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,237,204,136,188,0,0,64,0,116,112,48,49,56,95,49,49,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,146,116,225,161,0,0,64,0,20,0,0,0,255,255,0,0,0,0,0,0,21,0,0,0,255,255,0,0,0,0,0,0,22,0,0,0,255,255,2,0,0,0,0,0,0,0,0,0,254,0,2,0,0,0,0,0,20,0,0,0,1,2,0,0,200,211,8,0,20,0,0,0,1,2,2,0,216,147,8,0,0,0,0,0,254,0,2,0,0,0,0,0,20,0,0,0,1,4,0,0,168,84,8,0,20,0,0,0,1,4,4,0,40,31,8,0,0,0,0,0,254,0,2,0,240,233,7,0,20,0,0,0,1,8,0,0,152,182,7,0,20,0,0,0,1,8,8,0,96,135,7,0,0,0,0,0,254,0,4,0,200,87,7,0,20,0,0,0,1,48,0,0,232,38,7,0,20,0,0,0,1,48,16,0,64,251,6,0,20,0,0,0,1,48,32,0,24,211,6,0,20,0,0,0,1,48,48,0,120,33,6,0,0,0,0,0,254,0,4,0,160,123,6,0,20,0,0,0,1,192,0,0,232,38,7,0,20,0,0,0,1,192,64,0,72,32,6,0,20,0,0,0,1,192,128,0,168,241,5,0,20,0,0,0,1,192,192,0,184,201,5,0,0,0,0,0,254,0,4,0,136,160,5,0,21,0,0,0,1,3,0,0,16,150,7,0,21,0,0,0,1,3,1,0,120,198,7,0,21,0,0,0,1,3,2,0,160,103,7,0,21,0,0,0,1,3,3,0,16,53,7,0,0,0,0,0,254,0,4,0,248,6,5,0,21,0,0,0,1,12,0,0,216,129,4,0,21,0,0,0,1,12,4,0,208,102,4,0,21,0,0,0,1,12,8,0,104,76,4,0,21,0,0,0,1,12,12,0,248,75,4,0,0,0,0,0,254,0,4,0,72,22,4,0,21,0,0,0,1,48,0,0,8,49,4,0,21,0,0,0,1,48,16,0,72,246,3,0,21,0,0,0,1,48,32,0,208,75,4,0,21,0,0,0,1,48,48,0,192,255,2,0,0,0,0,0,254,0,2,0,48,185,3,0,21,0,0,0,1,64,0,0,96,135,7,0,21,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,9,0,48,45,3,0,22,0,0,0,1,15,0,0,176,20,3,0,22,0,0,0,1,15,1,0,24,4,2,0,22,0,0,0,1,15,2,0,8,234,2,0,22,0,0,0,1,15,3,0,192,20,3,0,22,0,0,0,1,15,4,0,56,50,1,0,22,0,0,0,1,15,5,0,80,65,1,0,22,0,0,0,1,15,6,0,128,234,2,0,22,0,0,0,1,15,7,0,200,246,3,0,22,0,0,0,1,15,8,0,104,192,2,0,114,111,109,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,216,37,110,147,0,0,16,1,114,111,109,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,207,62,155,209,0,0,16,1,114,111,109,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,182,199,78,198,0,0,32,0,114,111,109,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,172,197,182,100,0,0,32,0,114,111,109,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,22,45,183,107,0,0,32,0,114,111,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,45,120,52,9,0,0,32,0,114,111,109,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,7,60,144,236,0,0,32,0,114,111,109,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,168,241,203,80,0,0,32,0,114,111,109,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,53,226,216,115,0,0,16,1,116,112,48,49,56,95,49,48,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,237,204,136,188,0,0,64,0,116,112,48,49,56,95,49,49,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,146,116,225,161,0,0,64,0,20,0,0,0,255,255,0,0,0,0,0,0,21,0,0,0,255,255,0,0,0,0,0,0,22,0,0,0,255,255,2,0,0,0,0,0,0,0,0,0,254,0,2,0,0,0,0,0,20,0,0,0,1,2,0,0,200,211,8,0,20,0,0,0,1,2,2,0,216,147,8,0,0,0,0,0,254,0,2,0,0,0,0,0,20,0,0,0,1,4,0,0,168,84,8,0,20,0,0,0,1,4,4,0,40,31,8,0,0,0,0,0,254,0,2,0,240,233,7,0,20,0,0,0,1,8,0,0,152,182,7,0,20,0,0,0,1,8,8,0,96,135,7,0,0,0,0,0,254,0,4,0,200,87,7,0,20,0,0,0,1,48,0,0,232,38,7,0,20,0,0,0,1,48,16,0,64,251,6,0,20,0,0,0,1,48,32,0,24,211,6,0,20,0,0,0,1,48,48,0,120,33,6,0,0,0,0,0,254,0,4,0,160,123,6,0,20,0,0,0,1,192,0,0,232,38,7,0,20,0,0,0,1,192,64,0,72,32,6,0,20,0,0,0,1,192,128,0,168,241,5,0,20,0,0,0,1,192,192,0,184,201,5,0,0,0,0,0,254,0,4,0,136,160,5,0,21,0,0,0,1,3,0,0,16,150,7,0,21,0,0,0,1,3,1,0,120,198,7,0,21,0,0,0,1,3,2,0,160,103,7,0,21,0,0,0,1,3,3,0,16,53,7,0,0,0,0,0,254,0,4,0,248,6,5,0,21,0,0,0,1,12,0,0,216,129,4,0,21,0,0,0,1,12,4,0,208,102,4,0,21,0,0,0,1,12,8,0,104,76,4,0,21,0,0,0,1,12,12,0,248,75,4,0,0,0,0,0,254,0,4,0,72,22,4,0,21,0,0,0,1,48,0,0,8,49,4,0,21,0,0,0,1,48,16,0,72,246,3,0,21,0,0,0,1,48,32,0,208,75,4,0,21,0,0,0,1,48,48,0,192,255,2,0,0,0,0,0,254,0,2,0,48,185,3,0,21,0,0,0,1,64,0,0,96,135,7,0,21,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,8,0,48,45,3,0,22,0,0,0,1,15,0,0,176,20,3,0,22,0,0,0,1,15,1,0,24,4,2,0,22,0,0,0,1,15,2,0,8,234,2,0,22,0,0,0,1,15,3,0,192,20,3,0,22,0,0,0,1,15,4,0,56,50,1,0,22,0,0,0,1,15,5,0,80,65,1,0,22,0,0,0,1,15,6,0,224,175,2,0,22,0,0,0,1,15,7,0,224,175,2,0,0,0,0,0,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,187,113,161,49,0,0,16,1,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,209,207,78,128,0,0,16,1,114,111,109,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,182,199,78,198,0,0,32,0,114,111,109,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,172,197,182,100,0,0,32,0,114,111,109,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,22,45,183,107,0,0,32,0,114,111,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,45,120,52,9,0,0,32,0,114,111,109,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,7,60,144,236,0,0,32,0,114,111,109,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,168,241,203,80,0,0,32,0,114,111,109,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,53,226,216,115,0,0,16,1,116,112,48,49,56,95,49,48,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,237,204,136,188,0,0,64,0,116,112,48,49,56,95,49,49,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,146,116,225,161,0,0,64,0,112,48,49,48,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,67,53,233,213,1,0,16,1,116,48,49,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,30,94,66,97,2,0,32,0,97,48,49,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,138,216,59,139,3,0,32,0,97,48,49,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,68,150,158,59,3,0,32,0,97,48,49,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,56,44,158,6,3,0,32,0,97,48,49,48,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,253,163,96,68,3,0,32,0,97,48,49,48,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,86,187,138,95,3,0,32,0,97,48,49,48,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,71,113,122,161,3,0,32,0,98,48,49,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,140,228,210,105,4,0,32,0,98,48,49,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,243,123,88,13,4,0,32,0,98,48,49,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,30,60,130,67,4,0,32,0,109,48,49,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,131,108,195,229,5,0,64,0,46,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,72,123,4,0,46,0,0,0,2,1,0,0,96,135,7,0,46,0,0,0,2,1,1,0,152,182,7,0,0,0,0,0,254,0,3,0,144,165,4,0,46,0,0,0,1,3,0,0,224,32,1,0,46,0,0,0,1,3,2,0,56,50,1,0,46,0,0,0,1,3,3,0,232,41,1,0,46,0,0,0,255,255,2,0,0,0,0,0,0,0,0,0,254,0,2,0,144,165,4,0,46,0,0,0,1,3,0,0,192,20,3,0,46,0,0,0,1,3,2,0,232,41,1,0,46,0,0,0,255,255,2,0,0,0,0,0,0,0,0,0,97,53,50,45,48,49,45,49,46,52,48,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,2,203,221,255,1,0,0,0,97,53,50,45,48,50,45,49,46,52,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,13,21,151,218,1,0,0,0,97,53,50,45,48,51,45,49,46,52,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,83,154,116,185,1,0,0,0,97,53,50,45,49,50,46,48,56,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,150,128,244,40,2,0,0,0,97,53,50,45,49,51,46,48,57,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,243,22,59,77,2,0,0,0,97,53,50,45,49,52,46,49,48,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,232,244,166,144,2,0,0,0,97,53,50,45,49,53,46,51,55,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,208,33,252,90,2,0,0,0,97,53,50,45,49,54,46,51,56,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,238,42,244,204,2,0,0,0,97,53,50,45,48,52,46,49,49,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,148,98,18,91,3,0,0,0,97,53,50,45,48,54,46,49,48,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,33,71,17,120,3,0,0,0,97,53,50,45,48,56,46,48,57,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,69,55,41,74,3,0,0,0,97,53,50,45,49,48,46,48,56,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,219,180,231,139,3,0,0,0,97,53,50,45,48,53,46,51,53,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,136,149,169,161,3,0,0,0,97,53,50,45,48,55,46,51,52,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,242,32,244,11,3,0,0,0,97,53,50,45,48,57,46,51,51,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,181,67,197,57,3,0,0,0,97,53,50,45,49,49,46,51,50,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,179,166,221,209,3,0,0,0,97,53,50,45,49,55,46,53,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,4,0,0,16,114,121,45,48,56,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,133,123,88,228,1,0,0,0,114,121,45,48,55,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,21,165,253,111,1,0,0,0,114,121,45,48,54,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,168,205,239,111,1,0,0,0,97,53,50,45,49,50,46,48,56,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,150,128,244,40,2,0,0,0,97,53,50,45,49,51,46,48,57,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,243,22,59,77,2,0,0,0,97,53,50,45,49,52,46,49,48,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,232,244,166,144,2,0,0,0,97,53,50,45,49,53,46,51,55,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,208,33,252,90,2,0,0,0,97,53,50,45,49,54,46,51,56,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,238,42,244,204,2,0,0,0,97,53,50,45,48,52,46,49,49,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,148,98,18,91,3,0,0,0,97,53,50,45,48,54,46,49,48,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,33,71,17,120,3,0,0,0,97,53,50,45,48,56,46,48,57,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,69,55,41,74,3,0,0,0,97,53,50,45,49,48,46,48,56,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,219,180,231,139,3,0,0,0,97,53,50,45,48,53,46,51,53,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,136,149,169,161,3,0,0,0,97,53,50,45,48,55,46,51,52,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,242,32,244,11,3,0,0,0,97,53,50,45,48,57,46,51,51,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,181,67,197,57,3,0,0,0,97,53,50,45,49,49,46,51,50,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,179,166,221,209,3,0,0,0,97,53,50,45,49,55,46,53,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,4,0,0,16,112,48,53,51,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,70,114,63,146,1,0,16,1,116,48,53,51,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,176,187,87,130,2,0,32,0,97,48,53,51,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,210,111,148,87,3,0,32,0,97,48,53,51,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,184,160,89,52,3,0,32,0,97,48,53,51,48,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,133,93,71,19,3,0,32,0,97,48,53,51,48,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,166,247,62,240,3,0,32,0,98,48,53,51,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,3,245,152,253,4,0,32,0,98,48,53,51,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,168,148,96,159,4,0,32,0,109,48,53,51,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,188,131,236,134,5,0,64,0,111,108,100,115,112,108,117,115,95,105,103,115,48,50,55,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,7,0,16,17,112,48,53,48,48,46,118,49,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,20,46,227,23,1,0,16,1,116,48,53,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,108,114,129,216,2,0,32,0,116,48,53,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,100,104,16,210,2,0,32,0,97,48,53,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,151,145,165,128,3,0,32,0,97,48,53,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,177,49,201,152,3,0,32,0,97,48,53,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,29,223,252,195,3,0,32,0,97,48,53,48,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,236,255,109,6,3,0,32,0,97,48,53,48,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,131,117,51,69,3,0,32,0,97,48,53,48,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,165,243,140,91,3,0,32,0,97,48,53,48,54,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,12,198,122,8,3,0,32,0,98,48,53,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,116,127,224,205,4,0,32,0,98,48,53,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,233,194,70,21,4,0,32,0,98,48,53,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,195,49,123,233,4,0,32,0,98,48,53,48,51,46,117,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,228,152,29,228,4,0,32,0,109,48,53,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,221,140,146,55,5,0,64,0,112,48,53,48,48,46,118,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,135,252,129,137,1,0,16,1,116,48,53,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,108,114,129,216,2,0,32,0,116,48,53,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,100,104,16,210,2,0,32,0,97,48,53,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,151,145,165,128,3,0,32,0,97,48,53,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,177,49,201,152,3,0,32,0,97,48,53,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,29,223,252,195,3,0,32,0,97,48,53,48,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,236,255,109,6,3,0,32,0,97,48,53,48,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,131,117,51,69,3,0,32,0,97,48,53,48,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,165,243,140,91,3,0,32,0,97,48,53,48,54,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,12,198,122,8,3,0,32,0,98,48,53,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,116,127,224,205,4,0,32,0,98,48,53,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,233,194,70,21,4,0,32,0,98,48,53,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,195,49,123,233,4,0,32,0,98,48,53,48,51,46,117,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,228,152,29,228,4,0,32,0,109,48,53,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,221,140,146,55,5,0,64,0,107,100,45,117,54,46,53,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,218,61,97,231,0,0,16,1,115,115,49,117,50,48,48,46,118,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,175,59,229,245,1,0,16,1,115,115,49,117,50,48,49,46,118,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,174,245,127,122,1,0,16,1,115,115,49,117,51,48,54,46,118,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,84,167,67,206,3,0,32,0,115,115,49,117,51,48,55,46,118,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,183,112,33,3,0,32,0,115,115,49,117,51,48,52,46,118,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,65,181,106,84,3,0,32,0,115,115,49,117,51,48,53,46,118,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,139,224,51,42,3,0,32,0,115,115,49,117,50,51,46,118,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,9,166,159,4,0,32,0,115,115,49,117,50,52,46,118,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,179,180,14,193,4,0,32,0,115,115,49,117,50,53,46,118,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,40,7,132,86,5,0,32,0,115,115,49,117,50,54,46,118,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,107,51,82,212,6,0,64,0,115,115,49,117,50,55,46,118,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,29,146,254,23,6,0,64,0,99,45,104,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,178,250,3,134,1,0,16,1,99,45,108,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,53,250,32,229,1,0,16,1,110,105,110,45,99,45,104,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,134,5,193,203,1,0,16,1,110,105,110,45,99,45,108,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,77,154,92,183,1,0,16,1,110,105,110,45,99,45,104,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,250,24,216,138,1,0,16,1,110,105,110,45,99,45,108,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,140,167,44,197,1,0,16,1,99,45,104,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,97,58,182,149,1,0,16,1,99,45,108,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,122,168,84,231,1,0,16,1,110,105,110,45,114,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,11,211,97,95,2,0,32,0,110,105,110,45,114,49,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,7,209,170,12,2,0,32,0,110,105,110,45,114,50,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,211,23,54,239,2,0,32,0,110,105,110,45,114,51,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,36,42,93,23,2,0,32,0,110,105,110,45,98,45,97,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,88,246,248,99,3,0,32,0,110,105,110,45,98,45,97,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,6,131,235,117,3,0,32,0,110,105,110,45,98,45,97,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,114,33,83,223,3,0,32,0,110,105,110,45,98,45,97,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,76,214,237,77,3,0,32,0,110,105,110,45,98,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,166,8,14,27,4,0,32,0,110,105,110,45,98,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,240,39,135,114,4,0,32,0,110,105,110,45,98,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,117,253,126,248,4,0,32,0,110,105,110,45,98,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,180,108,133,152,4,0,32,0,110,105,110,45,118,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,175,140,46,163,5,0,64,0,110,105,110,95,99,45,112,114,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,10,68,45,128,0,0,0,8,105,99,55,54,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,136,89,7,38,1,0,16,1,105,99,55,53,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,205,130,171,117,1,0,16,1,105,99,51,53,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,177,195,208,3,3,0,32,0,105,99,51,50,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,253,84,212,136,4,0,32,0,105,99,49,48,48,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,78,226,211,36,5,0,32,0,105,99,51,48,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,244,52,234,254,6,0,64,0,105,99,50,55,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,237,253,105,138,7,0,64,0,106,108,48,49,45,52,46,100,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,228,20,4,1,0,16,1,106,108,48,48,45,52,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,204,43,158,221,1,0,16,1,106,108,48,51,45,52,46,100,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,197,74,38,234,1,0,16,1,106,108,48,50,45,52,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,151,121,4,116,1,0,16,1,106,108,48,53,45,50,46,100,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,32,250,32,184,1,0,16,1,106,108,48,52,45,50,46,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,91,153,216,31,1,0,16,1,106,108,48,56,46,114,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,225,63,217,147,2,0,16,1,106,108,48,54,46,100,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,142,102,207,145,3,0,32,0,106,108,48,55,46,100,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,66,14,29,230,3,0,32,0,109,97,118,48,48,46,98,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,151,93,120,52,4,0,32,0,109,97,118,48,49,46,98,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,22,27,83,139,4,0,32,0,109,97,118,48,50,46,98,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,247,59,114,32,5,0,32,0,109,97,118,48,51,46,101,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,240,149,97,239,5,0,32,0,109,97,118,48,53,46,101,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,156,118,45,217,6,0,32,0,109,97,118,48,52,46,98,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,133,131,164,139,6,0,32,0,109,97,118,48,55,46,101,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,205,12,193,95,6,0,32,0,109,97,118,48,54,46,98,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,165,1,98,174,6,0,32,0,109,97,118,48,57,46,101,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,26,181,231,28,7,0,32,0,109,97,118,48,56,46,98,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,118,101,150,100,7,0,32,0,109,97,118,49,48,46,114,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,176,52,215,138,8,0,64,0,109,97,118,49,49,46,114,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,8,57,81,239,9,0,64,0,106,110,45,48,48,46,49,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,132,123,199,106,0,0,0,8,50,49,55,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,105,237,151,62,1,0,16,1,50,49,55,45,112,50,46,115,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,136,202,31,25,1,0,16,1,50,49,55,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,240,130,247,143,2,0,32,0,50,49,55,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,196,123,233,95,3,0,32,0,50,49,55,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,102,13,110,136,3,0,32,0,50,49,55,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,95,82,232,89,3,0,32,0,50,49,55,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,210,173,33,133,3,0,32,0,50,49,55,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,229,150,24,251,3,0,32,0,50,49,55,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,75,197,152,28,3,0,32,0,50,49,55,45,99,55,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,46,222,14,139,3,0,32,0,50,49,55,45,99,56,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,97,187,133,160,3,0,32,0,50,49,55,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,175,178,15,208,4,0,16,1,50,49,55,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,19,224,52,28,5,0,64,0,50,49,55,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,129,198,241,34,5,0,64,0,110,103,102,116,100,95,112,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,144,113,216,132,1,0,16,1,110,103,102,116,100,95,115,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,147,181,69,165,2,0,32,0,110,103,102,116,100,95,99,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,148,169,251,178,3,0,32,0,110,103,102,116,100,95,99,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,178,90,73,55,3,0,32,0,110,103,102,116,100,95,109,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,190,22,162,94,4,0,16,1,110,103,102,116,100,95,118,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,235,135,60,208,5,0,64,0,112,117,99,107,109,97,110,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,197,35,174,168,1,0,16,1,112,97,99,109,97,110,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,212,178,111,26,1,0,16,1,112,117,99,107,109,97,110,46,54,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,248,67,116,25,1,0,16,1,112,117,99,107,109,97,110,46,54,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,186,163,100,46,1,0,16,1,112,97,99,109,97,110,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,100,73,148,12,2,0,32,0,112,97,99,109,97,110,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,249,237,143,149,2,0,32,0,56,50,115,49,50,51,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,189,80,198,47,3,0,32,0,56,50,115,49,50,54,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,228,168,179,62,3,0,32,0,56,50,115,49,50,54,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,134,204,169,4,0,64,0,56,50,115,49,50,54,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,110,112,50,98,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,74,124,2,157,1,0,16,1,54,107,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,28,192,143,21,1,0,16,1,54,102,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,83,120,23,125,1,0,16,1,54,109,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,207,12,129,112,1,0,16,1,110,112,50,98,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,177,178,228,245,1,0,16,1,54,110,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,88,12,37,63,1,0,16,1,110,112,50,98,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,9,224,104,240,1,0,16,1,110,112,50,98,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,47,204,173,31,1,0,16,1,53,101,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,183,160,102,32,2,0,32,0,53,104,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,211,112,124,119,2,0,32,0,53,102,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,76,24,140,202,2,0,32,0,53,106,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,129,90,199,125,2,0,32,0,56,50,115,49,50,51,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,189,80,198,47,3,0,32,0,56,50,115,49,50,54,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,228,168,179,62,3,0,32,0,56,50,115,49,50,54,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,134,204,169,4,0,64,0,56,50,115,49,50,54,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,98,98,109,50,45,104,48,45,97,46,55,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,130,134,133,125,1,0,16,1,98,98,109,50,45,108,48,45,97,46,55,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,49,128,86,199,1,0,16,1,98,98,109,50,45,115,112,46,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,158,104,193,107,2,0,16,1,98,98,109,50,45,99,48,46,56,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,138,5,206,231,3,0,32,0,98,98,109,50,45,99,49,46,56,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,169,120,106,99,3,0,32,0,98,98,109,50,45,99,50,46,56,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,47,20,194,154,3,0,32,0,98,98,109,50,45,99,51,46,56,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,80,23,175,71,3,0,32,0,98,98,109,50,45,118,48,46,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,237,137,216,74,4,0,64,0,116,104,117,110,100,95,112,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,87,7,5,247,1,0,16,1,116,104,117,110,100,95,115,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,147,181,69,165,2,0,32,0,116,104,117,110,100,95,99,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,110,18,185,72,3,0,32,0,116,104,117,110,100,95,99,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,46,246,77,33,3,0,32,0,116,104,117,110,100,95,109,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,234,145,2,156,4,0,16,1,116,104,117,110,100,95,118,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,251,184,190,222,5,0,64,0,112,114,105,95,112,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,129,251,21,163,1,0,16,1,112,114,105,95,115,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,147,181,69,165,2,0,32,0,112,114,105,95,99,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,225,65,137,214,3,0,32,0,112,114,105,95,99,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,159,53,126,223,3,0,32,0,112,114,105,95,109,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,234,145,2,156,4,0,16,1,112,114,105,95,118,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,251,184,190,222,5,0,64,0,110,112,49,48,95,112,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,215,36,183,49,1,0,16,1,112,111,110,103,95,115,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,79,38,25,205,2,0,32,0,110,112,49,48,95,99,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,130,114,88,215,3,0,32,0,110,112,49,48,95,99,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,6,157,252,254,3,0,32,0,110,112,49,48,95,109,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,234,145,2,156,4,0,16,1,110,112,49,48,95,118,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,251,184,190,222,5,0,64,0,110,110,112,45,112,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,113,34,121,138,1,0,16,1,110,110,112,45,115,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,125,254,230,147,2,0,32,0,110,110,112,45,99,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,227,138,113,74,3,0,32,0,110,110,112,45,99,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,37,188,44,14,3,0,32,0,110,110,112,45,109,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,100,222,105,118,4,0,16,1,110,110,112,45,118,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,73,248,75,80,5,0,64,0,168,86,7,0,1,0,0,0,240,33,216,0,248,191,2,0,24,38,7,0,1,0,0,0,248,33,216,0,184,160,2,0,120,36,5,0,1,0,0,0,249,33,216,0,96,78,4,0,56,210,6,0,1,0,0,0,0,33,216,0,192,135,2,0,24,163,6,0,1,0,0,0,1,33,216,0,240,108,2,0,152,122,6,0,1,0,0,0,2,33,216,0,96,82,2,0,192,72,6,0,1,0,0,0,3,33,216,0,32,56,2,0,136,30,2,0,1,0,0,0,4,33,216,0,152,30,2,0,224,19,2,0,1,0,0,0,5,33,216,0,232,10,2,0,216,10,2,0,1,0,0,0,6,33,216,0,152,138,8,0,248,3,2,0,1,0,0,0,7,33,216,0,48,119,7,0,40,246,1,0,1,0,0,0,241,33,216,0,64,246,1,0,144,236,1,0,1,0,0,0,250,33,216,0,136,224,1,0,128,149,1,0,1,0,0,0,251,33,216,0,24,60,1,0,176,223,1,0,1,0,0,0,248,32,216,0,72,198,1,0,192,209,1,0,1,0,0,0,249,32,216,0,24,182,1,0,24,198,1,0,1,0,0,0,250,32,216,0,40,167,1,0,120,189,1,0,1,0,0,0,251,32,216,0,200,149,1,0,184,155,8,0,1,0,0,0,252,32,216,0,56,126,1,0,136,149,8,0,1,0,0,0,253,32,216,0,32,101,1,0,216,142,8,0,1,0,0,0,254,32,216,0,96,32,8,0,40,138,8,0,1,0,0,0,255,32,216,0,16,68,7,0,88,212,3,0,1,0,0,0,200,32,216,0,40,185,3,0,80,251,6,0,1,0,0,0,48,33,216,0,216,70,1,0,16,17,8,0,1,0,0,0,242,33,216,0,224,12,8,0,248,5,8,0,9,0,0,0,12,33,216,0,32,58,1,0,144,250,7,0,9,0,0,0,13,33,216,0,32,58,1,0,208,23,1,0,9,0,0,0,152,32,216,0,32,58,1,0,184,22,1,0,9,0,0,0,128,37,0,0,32,58,1,0,0,22,1,0,9,0,0,0,56,33,216,0,32,58,1,0,120,20,1,0,9,0,0,0,57,33,216,0,32,58,1,0,103,97,108,95,112,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,92,219,38,114,1,0,16,1,103,97,108,95,115,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,73,116,85,144,2,0,32,0,103,97,108,95,99,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,246,198,232,109,3,0,32,0,103,97,108,95,99,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,29,12,95,250,3,0,32,0,103,97,108,95,109,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,234,145,2,156,4,0,16,1,103,97,108,95,118,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,251,184,190,222,5,0,64,0,50,49,51,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,152,215,151,227,1,0,16,1,50,49,51,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,188,97,107,183,2,0,32,0,50,49,51,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,211,139,220,62,3,0,32,0,50,49,51,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,22,95,174,70,3,0,32,0,50,49,51,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,241,69,0,32,4,0,16,1,50,49,51,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,118,192,33,164,5,0,64,0,50,49,51,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,217,125,60,35,5,0,64,0,50,52,52,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,165,183,253,248,1,0,16,1,50,52,52,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,151,182,221,155,2,0,32,0,50,52,52,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,35,43,166,199,3,0,32,0,50,52,52,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,53,15,170,51,3,0,32,0,50,52,52,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,118,178,1,167,4,0,16,1,50,52,52,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,109,244,222,121,5,0,64,0,50,52,52,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,47,144,49,178,5,0,64,0,99,115,116,108,118,95,112,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,242,217,108,141,1,0,16,1,99,115,116,108,118,95,115,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,149,1,149,190,2,0,32,0,99,115,116,108,118,95,99,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,20,116,10,150,3,0,32,0,99,115,116,108,118,95,99,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,208,97,169,36,3,0,32,0,99,115,116,108,118,95,109,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,96,20,199,137,4,0,16,1,99,115,116,108,118,95,118,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,251,184,190,222,5,0,64,0,48,57,51,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,13,29,167,161,1,0,16,1,48,57,51,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,25,161,63,75,2,0,32,0,48,57,51,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,248,40,243,209,3,0,32,0,48,57,51,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,64,149,196,130,3,0,32,0,48,57,51,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,197,120,117,227,3,0,32,0,48,57,51,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,131,103,130,89,3,0,32,0,48,57,51,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,11,120,30,232,4,0,16,1,48,57,51,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,176,212,171,2,5,0,64,0,48,57,51,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,61,139,43,169,5,0,64,0,98,112,57,50,51,48,48,49,46,117,52,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,115,235,10,13,1,0,16,1,98,112,57,50,51,48,48,50,46,117,52,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,188,251,49,151,1,0,16,1,98,112,57,50,51,45,48,48,51,46,117,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,161,152,202,145,3,0,32,0,98,112,57,50,51,45,48,48,52,46,117,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,227,120,198,21,3,0,32,0,98,112,57,50,51,45,48,48,53,46,117,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,190,55,14,124,6,0,64,0,168,86,7,0,1,0,0,0,240,33,216,0,248,191,2,0,24,38,7,0,1,0,0,0,248,33,216,0,184,160,2,0,120,36,5,0,1,0,0,0,249,33,216,0,96,78,4,0,56,210,6,0,1,0,0,0,0,33,216,0,192,135,2,0,24,163,6,0,1,0,0,0,1,33,216,0,240,108,2,0,152,122,6,0,1,0,0,0,2,33,216,0,96,82,2,0,192,72,6,0,1,0,0,0,3,33,216,0,32,56,2,0,136,30,2,0,1,0,0,0,4,33,216,0,152,30,2,0,224,19,2,0,1,0,0,0,5,33,216,0,232,10,2,0,216,10,2,0,1,0,0,0,6,33,216,0,152,138,8,0,248,3,2,0,1,0,0,0,7,33,216,0,48,119,7,0,40,246,1,0,1,0,0,0,241,33,216,0,64,246,1,0,144,236,1,0,1,0,0,0,250,33,216,0,136,224,1,0,128,149,1,0,1,0,0,0,251,33,216,0,24,60,1,0,176,223,1,0,1,0,0,0,248,32,216,0,72,198,1,0,192,209,1,0,1,0,0,0,249,32,216,0,24,182,1,0,24,198,1,0,1,0,0,0,250,32,216,0,40,167,1,0,120,189,1,0,1,0,0,0,251,32,216,0,200,149,1,0,184,155,8,0,1,0,0,0,252,32,216,0,56,126,1,0,136,149,8,0,1,0,0,0,253,32,216,0,32,101,1,0,216,142,8,0,1,0,0,0,254,32,216,0,96,32,8,0,40,138,8,0,1,0,0,0,255,32,216,0,16,68,7,0,88,212,3,0,1,0,0,0,200,32,216,0,40,185,3,0,80,251,6,0,1,0,0,0,48,33,216,0,216,70,1,0,16,17,8,0,1,0,0,0,242,33,216,0,224,12,8,0,248,5,8,0,9,0,0,0,12,33,216,0,32,58,1,0,144,250,7,0,9,0,0,0,13,33,216,0,32,58,1,0,208,23,1,0,9,0,0,0,152,32,216,0,32,58,1,0,0,22,1,0,9,0,0,0,56,33,216,0,32,58,1,0,120,20,1,0,9,0,0,0,57,33,216,0,32,58,1,0,110,101,111,51,100,95,112,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,66,96,31,121,1,0,16,1,110,101,111,51,100,95,115,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0])
.concat([79,38,25,205,2,0,32,0,110,101,111,51,100,95,99,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,118,202,234,167,3,0,32,0,110,101,111,51,100,95,99,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,222,44,47,4,3,0,32,0,110,101,111,51,100,95,109,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,31,204,116,126,4,0,16,1,110,101,111,51,100,95,118,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,251,184,190,222,5,0,64,0,152,5,0,0,90,4,0,0,18,1,0,0,244,5,0,0,176,5,0,0,44,3,0,0,184,4,0,0,48,1,0,0,136,1,0,0,20,2,0,0,134,3,0,0,238,3,0,0,30,0,0,0,82,3,0,0,84,1,0,0,248,4,0,0,42,0,0,0,76,0,0,0,78,2,0,0,210,3,0,0,92,4,0,0,134,4,0,0,160,0,0,0,202,1,0,0,106,4,0,0,54,5,0,0,204,2,0,0,106,2,0,0,36,2,0,0,158,2,0,0,20,6,0,0,14,0,0,0,144,4,0,0,4,6,0,0,146,4,0,0,90,0,0,0,8,0,0,0,230,2,0,0,78,0,0,0,132,5,0,0,250,4,0,0,62,5,0,0,164,3,0,0,100,1,0,0,164,5,0,0,218,3,0,0,80,3,0,0,110,2,0,0,32,6,0,0,52,2,0,0,130,4,0,0,72,1,0,0,254,0,0,0,212,3,0,0,148,2,0,0,238,4,0,0,210,2,0,0,120,1,0,0,206,3,0,0,50,3,0,0,112,3,0,0,142,3,0,0,188,1,0,0,242,4,0,0,62,0,0,0,206,0,0,0,124,0,0,0,64,4,0,0,146,2,0,0,82,5,0,0,94,4,0,0,198,3,0,0,186,2,0,0,102,2,0,0,58,0,0,0,42,6,0,0,42,1,0,0,128,3,0,0,38,5,0,0,98,0,0,0,50,6,0,0,110,3,0,0,224,2,0,0,74,0,0,0,172,4,0,0,242,0,0,0,48,2,0,0,6,2,0,0,42,4,0,0,178,2,0,0,12,0,0,0,228,3,0,0,34,0,0,0,30,3,0,0,116,0,0,0,20,3,0,0,10,4,0,0,248,2,0,0,76,5,0,0,150,1,0,0,218,2,0,0,94,3,0,0,188,3,0,0,188,3,0,0,142,5,0,0,190,5,0,0,196,1,0,0,82,2,0,0,212,2,0,0,74,2,0,0,178,0,0,0,0,6,0,0,216,4,0,0,126,5,0,0,36,3,0,0,136,0,0,0,44,4,0,0,204,0,0,0,124,3,0,0,124,2,0,0,190,2,0,0,216,0,0,0,184,2,0,0,4,2,0,0,70,5,0,0,84,5,0,0,88,3,0,0,118,1,0,0,72,0,0,0,112,2,0,0,98,1,0,0,88,2,0,0,246,3,0,0,192,4,0,0,10,6,0,0,192,1,0,0,12,2,0,0,108,5,0,0,2,6,0,0,226,4,0,0,146,0,0,0,36,1,0,0,240,2,0,0,252,1,0,0,154,1,0,0,184,1,0,0,194,2,0,0,218,1,0,0,52,5,0,0,20,0,0,0,2,5,0,0,16,6,0,0,92,1,0,0,194,1,0,0,48,0,0,0,14,2,0,0,178,1,0,0,34,2,0,0,38,0,0,0,24,3,0,0,96,1,0,0,16,0,0,0,58,5,0,0,188,2,0,0,92,2,0,0,244,4,0,0,16,1,0,0,34,5,0,0,22,5,0,0,74,1,0,0,214,2,0,0,32,3,0,0,78,5,0,0,40,3,0,0,118,3,0,0,34,1,0,0,248,0,0,0,150,2,0,0,96,0,0,0,152,3,0,0,192,0,0,0,130,5,0,0,74,4,0,0,182,2,0,0,146,3,0,0,132,1,0,0,140,3,0,0,60,4,0,0,172,2,0,0,116,1,0,0,104,5,0,0,18,4,0,0,198,4,0,0,70,4,0,0,108,2,0,0,226,2,0,0,102,0,0,0,32,0,0,0,26,1,0,0,16,2,0,0,160,5,0,0,102,4,0,0,64,0,0,0,196,0,0,0,94,2,0,0,160,2,0,0,220,0,0,0,196,3,0,0,236,5,0,0,152,4,0,0,186,3,0,0,188,4,0,0,220,3,0,0,170,4,0,0,62,1,0,0,138,3,0,0,116,4,0,0,116,4,0,0,116,4,0,0,116,4,0,0,116,4,0,0,116,4,0,0,116,4,0,0,116,4,0,0,200,3,0,0,122,4,0,0,148,5,0,0,234,5,0,0,142,4,0,0,82,4,0,0,174,4,0,0,252,4,0,0,54,4,0,0,126,0,0,0,60,2,0,0,130,3,0,0,222,2,0,0,106,5,0,0,110,5,0,0,128,0,0,0,26,5,0,0,86,5,0,0,104,0,0,0,240,0,0,0,86,1,0,0,224,5,0,0,130,2,0,0,114,1,0,0,118,5,0,0,212,0,0,0,14,4,0,0,162,5,0,0,204,1,0,0,144,0,0,0,150,5,0,0,22,6,0,0,208,1,0,0,86,0,0,0,16,4,0,0,60,0,0,0,6,4,0,0,6,6,0,0,250,0,0,0,122,1,0,0,236,0,0,0,32,5,0,0,44,6,0,0,68,3,0,0,244,2,0,0,72,3,0,0,52,4,0,0,232,5,0,0,214,0,0,0,126,3,0,0,194,4,0,0,208,4,0,0,56,2,0,0,156,4,0,0,44,2,0,0,170,5,0,0,112,1,0,0,28,2,0,0,100,0,0,0,116,5,0,0,198,0,0,0,54,0,0,0,48,3,0,0,46,6,0,0,6,1,0,0,118,2,0,0,116,2,0,0,246,2,0,0,252,2,0,0,2,1,0,0,232,2,0,0,208,5,0,0,98,4,0,0,104,4,0,0,88,5,0,0,162,0,0,0,8,5,0,0,80,2,0,0,238,5,0,0,54,3,0,0,186,5,0,0,64,1,0,0,204,3,0,0,90,5,0,0,22,2,0,0,112,5,0,0,38,4,0,0,230,5,0,0,110,0,0,0,86,4,0,0,72,2,0,0,14,1,0,0,112,4,0,0,190,4,0,0,18,5,0,0,28,1,0,0,156,0,0,0,212,4,0,0,106,0,0,0,132,3,0,0,122,5,0,0,8,4,0,0,72,4,0,0,56,5,0,0,18,3,0,0,172,1,0,0,248,5,0,0,140,0,0,0,156,3,0,0,202,2,0,0,48,6,0,0,162,2,0,0,2,3,0,0,230,0,0,0,40,1,0,0,30,5,0,0,140,2,0,0,52,3,0,0,166,4,0,0,38,2,0,0,240,4,0,0,70,3,0,0,110,4,0,0,150,0,0,0,172,0,0,0,158,3,0,0,8,6,0,0,192,3,0,0,88,1,0,0,34,4,0,0,108,4,0,0,4,3,0,0,50,2,0,0,166,3,0,0,4,3,0,0,4,3,0,0,16,5,0,0,18,0,0,0,180,3,0,0,154,4,0,0,250,1,0,0,194,0,0,0,68,2,0,0,22,4,0,0,136,4,0,0,246,4,0,0,224,4,0,0,134,1,0,0,218,0,0,0,248,3,0,0,202,3,0,0,92,0,0,0,188,5,0,0,192,2,0,0,186,1,0,0,232,1,0,0,126,4,0,0,234,0,0,0,164,2,0,0,24,1,0,0,38,3,0,0,142,1,0,0,252,5,0,0,160,3,0,0,78,4,0,0,238,2,0,0,242,1,0,0,58,6,0,0,86,3,0,0,178,3,0,0,138,4,0,0,62,6,0,0,24,2,0,0,60,1,0,0,54,2,0,0,40,6,0,0,120,5,0,0,94,1,0,0,6,0,0,0,90,2,0,0,214,3,0,0,166,1,0,0,224,1,0,0,44,5,0,0,202,4,0,0,246,0,0,0,70,0,0,0,124,5,0,0,210,1,0,0,166,0,0,0,200,4,0,0,182,3,0,0,84,4,0,0,54,1,0,0,10,0,0,0,244,0,0,0,56,1,0,0,36,6,0,0,60,3,0,0,168,0,0,0,174,5,0,0,114,4,0,0,78,3,0,0,222,3,0,0,156,1,0,0,150,3,0,0,88,0,0,0,184,0,0,0,152,2,0,0,114,3,0,0,228,1,0,0,212,5,0,0,52,6,0,0,4,0,0,0,246,1,0,0,134,5,0,0,220,2,0,0,26,6,0,0,198,1,0,0,86,2,0,0,164,1,0,0,66,1,0,0,112,0,0,0,144,2,0,0,244,1,0,0,28,0,0,0,30,4,0,0,144,5,0,0,216,2,0,0,118,0,0,0,124,1,0,0,66,4,0,0,26,4,0,0,114,2,0,0,102,3,0,0,158,1,0,0,210,4,0,0,160,1,0,0,122,0,0,0,230,4,0,0,208,2,0,0,252,3,0,0,60,6,0,0,196,5,0,0,250,5,0,0,228,2,0,0,0,1,0,0,128,4,0,0,12,1,0,0,12,1,0,0,12,1,0,0,12,1,0,0,12,1,0,0,12,1,0,0,12,1,0,0,12,1,0,0,130,1,0,0,58,4,0,0,168,1,0,0,242,2,0,0,2,2,0,0,40,0,0,0,178,5,0,0,226,0,0,0,170,1,0,0,106,3,0,0,92,3,0,0,60,5,0,0,14,5,0,0,186,0,0,0,68,4,0,0,202,5,0,0,0,2,0,0,4,3,0,0,252,0,0,0,214,4,0,0,104,2,0,0,58,3,0,0,108,0,0,0,6,3,0,0,30,6,0,0,66,0,0,0,36,4,0,0,68,0,0,0,138,0,0,0,122,3,0,0,66,3,0,0,50,5,0,0,48,53,48,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,64,124,9,78,1,0,16,1,48,53,48,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,142,156,143,219,2,0,32,0,48,53,48,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,10,26,66,135,3,0,32,0,48,53,48,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,72,85,207,196,3,0,32,0,48,53,48,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,30,44,66,3,3,0,32,0,48,53,48,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,219,234,69,8,3,0,32,0,48,53,48,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,211,7,207,111,4,0,16,1,48,53,48,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,66,171,195,35,5,0,64,0,48,53,48,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,132,169,184,128,5,0,64,0,48,48,57,45,112,103,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,221,10,159,142,1,0,16,1,48,48,57,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,232,254,154,212,2,0,32,0,48,48,57,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,142,131,204,51,3,0,32,0,48,48,57,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,235,127,135,38,3,0,32,0,48,48,57,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,93,160,96,59,3,0,32,0,48,48,57,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,57,208,194,57,3,0,32,0,48,48,57,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,78,52,164,103,3,0,32,0,48,48,57,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,25,139,202,46,3,0,32,0,48,48,57,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,99,152,129,181,4,0,16,1,48,48,57,45,118,49,49,46,118,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,156,165,50,207,5,0,64,0,48,48,57,45,118,49,50,46,118,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,183,136,53,123,5,0,64,0,48,48,57,45,118,49,51,46,118,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,1,90,80,5,0,64,0,48,48,57,45,118,50,49,46,118,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,17,144,95,54,6,0,64,0,255,255,255,255,0,0,0,0,114,111,109,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,205,198,217,123,1,0,16,1,114,111,109,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,166,4,63,168,1,0,16,1,114,111,109,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,20,55,199,70,1,0,16,1,114,111,109,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,163,184,248,52,1,0,16,1,114,111,109,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,252,44,210,191,1,0,16,1,114,111,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,56,62,22,251,1,0,16,1,109,115,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,6,56,200,133,2,0,32,0,109,115,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,171,198,70,177,2,0,32,0,109,115,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,77,248,37,208,2,0,32,0,109,115,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,181,21,80,216,2,0,32,0,109,115,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,137,93,118,83,2,0,32,0,109,115,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,39,229,158,145,2,0,32,0,109,115,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,29,51,216,114,3,0,32,0,109,115,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,155,31,90,132,3,0,32,0,109,115,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,176,116,40,130,3,0,32,0,109,115,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,60,229,148,69,3,0,32,0,109,115,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,15,11,71,47,3,0,32,0,109,115,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,27,109,150,56,3,0,32,0,105,99,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,207,214,2,232,4,0,32,0,109,115,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,95,192,172,109,1,0,16,1,109,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,247,109,84,163,1,0,16,1,109,115,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,130,97,188,67,1,0,16,1,109,115,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,43,34,34,147,1,0,16,1,109,115,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,155,254,206,71,1,0,16,1,109,115,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,43,225,122,179,1,0,16,1,109,115,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,6,56,200,133,2,0,32,0,109,115,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,171,198,70,177,2,0,32,0,109,115,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,77,248,37,208,2,0,32,0,109,115,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,181,21,80,216,2,0,32,0,109,115,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,137,93,118,83,2,0,32,0,109,115,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,39,229,158,145,2,0,32,0,109,115,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,29,51,216,114,3,0,32,0,109,115,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,155,31,90,132,3,0,32,0,109,115,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,176,116,40,130,3,0,32,0,109,115,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,60,229,148,69,3,0,32,0,109,115,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,15,11,71,47,3,0,32,0,109,115,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,27,109,150,56,3,0,32,0,105,99,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,207,214,2,232,4,0,32,0,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,88,42,191,120,1,0,16,1,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,247,109,84,163,1,0,16,1,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,130,97,188,67,1,0,16,1,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,43,34,34,147,1,0,16,1,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,155,254,206,71,1,0,16,1,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,43,225,122,179,1,0,16,1,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,6,56,200,133,2,0,32,0,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,171,198,70,177,2,0,32,0,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,77,248,37,208,2,0,32,0])
.concat([49,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,181,21,80,216,2,0,32,0,50,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,137,93,118,83,2,0,32,0,49,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,39,229,158,145,2,0,32,0,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,29,51,216,114,3,0,32,0,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,155,31,90,132,3,0,32,0,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,176,116,40,130,3,0,32,0,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,60,229,148,69,3,0,32,0,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,15,11,71,47,3,0,32,0,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,27,109,150,56,3,0,32,0,56,50,115,49,50,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,207,214,2,232,4,0,32,0,112,97,108,49,48,108,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,44,0,0,0,76,3,77,45,0,0,0,8,112,97,108,49,54,114,52,45,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,208,85,117,197,0,0,0,8,112,97,108,49,54,114,52,45,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,208,85,117,197,0,0,0,8,109,114,45,104,48,45,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,135,248,41,213,1,0,16,1,109,114,45,108,48,45,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,68,171,87,164,1,0,16,1,109,114,45,104,49,45,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,185,73,118,225,1,0,16,1,109,114,45,108,49,45,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,180,98,124,168,1,0,16,1,109,114,45,115,104,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,228,53,211,80,2,0,16,1,109,114,45,115,108,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,33,39,163,15,2,0,16,1,109,114,45,99,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,173,143,42,135,3,0,32,0,109,114,45,99,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,122,178,255,210,3,0,32,0,109,114,45,99,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,135,242,191,98,3,0,32,0,109,114,45,99,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,171,98,218,208,3,0,32,0,109,114,45,111,48,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,22,206,249,160,4,0,32,0,109,114,45,111,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,233,169,112,78,4,0,32,0,109,114,45,111,50,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,252,104,196,185,4,0,32,0,109,114,45,111,51,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,58,67,50,204,4,0,32,0,109,114,45,100,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,89,252,17,26,5,0,64,0,107,113,115,49,101,122,112,114,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,194,170,105,36,0,0,16,1,107,113,115,49,111,122,112,114,46,117,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,92,55,54,99,0,0,16,1,107,113,115,49,101,45,116,98,46,117,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,204,180,89,231,0,0,16,1,107,113,115,49,111,45,116,98,46,117,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,55,135,22,182,0,0,16,1,107,113,115,49,45,99,103,52,46,117,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,65,34,128,209,0,0,32,0,107,113,115,49,45,99,103,48,46,117,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,167,51,26,194,0,0,32,0,107,113,115,49,45,99,103,53,46,117,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,156,241,108,216,0,0,32,0,107,113,115,49,45,99,103,49,46,117,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,186,153,167,220,0,0,32,0,107,113,115,49,45,99,103,54,46,117,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,107,136,8,63,0,0,32,0,107,113,115,49,45,99,103,50,46,117,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,126,44,249,247,0,0,32,0,107,113,115,49,45,99,103,55,46,117,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,4,121,151,44,0,0,32,0,107,113,115,49,45,99,103,51,46,117,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,145,33,59,222,0,0,32,0,107,113,115,49,45,115,110,100,46,117,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,73,107,42,121,0,0,64,0,15,0,0,0,255,255,0,0,0,0,0,0,16,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,208,87,7,0,15,0,0,0,1,1,0,0,96,135,7,0,15,0,0,0,1,1,1,0,152,182,7,0,0,0,0,0,254,0,2,0,104,110,6,0,15,0,0,0,1,8,8,0,56,111,3,0,15,0,0,0,1,8,0,0,104,134,3,0,0,0,0,0,254,0,4,0,128,129,4,0,15,0,0,0,1,48,16,0,208,75,4,0,15,0,0,0,1,48,0,0,8,49,4,0,15,0,0,0,1,48,32,0,152,21,4,0,15,0,0,0,1,48,48,0,72,246,3,0,0,0,0,0,254,0,2,0,80,105,6,0,15,0,0,0,1,64,64,0,96,135,7,0,15,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,96,228,6,0,15,0,0,0,1,128,0,0,96,135,7,0,15,0,0,0,1,128,128,0,152,182,7,0,0,0,0,0,254,0,16,0,32,4,2,0,16,0,0,0,1,15,0,0,200,201,5,0,16,0,0,0,1,15,1,0,152,160,5,0,16,0,0,0,1,15,2,0,144,127,5,0,16,0,0,0,1,15,3,0,168,98,5,0,16,0,0,0,1,15,4,0,88,219,3,0,16,0,0,0,1,15,5,0,224,189,3,0,16,0,0,0,1,15,6,0,120,166,6,0,16,0,0,0,1,15,7,0,224,67,5,0,16,0,0,0,1,15,8,0,88,198,1,0,16,0,0,0,1,15,9,0,120,154,6,0,16,0,0,0,1,15,10,0,216,36,5,0,16,0,0,0,1,15,11,0,144,138,3,0,16,0,0,0,1,15,12,0,232,143,6,0,16,0,0,0,1,15,13,0,8,7,5,0,16,0,0,0,1,15,14,0,192,135,6,0,16,0,0,0,1,15,15,0,40,182,1,0,104,100,45,48,51,45,51,46,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,116,53,245,230,1,0,16,1,104,100,45,48,48,45,51,46,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,84,84,5,211,1,0,16,1,104,100,45,48,52,45,49,46,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,215,168,46,253,1,0,16,1,104,100,45,48,49,45,49,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,172,71,162,72,1,0,16,1,104,100,45,49,50,46,50,49,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,17,95,213,19,2,0,16,1,104,100,45,48,54,45,49,46,56,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,139,85,122,139,3,0,32,0,104,100,45,48,55,45,49,46,57,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,73,212,163,210,3,0,32,0,109,97,102,45,48,48,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,141,82,111,229,4,0,32,0,109,97,102,45,48,49,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,61,23,213,195,5,0,32,0,109,97,102,45,48,50,46,49,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,73,216,55,11,5,0,32,0,109,97,102,45,48,51,46,49,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,44,109,54,244,6,0,32,0,109,97,102,45,48,52,46,50,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,78,101,143,12,6,0,32,0,109,97,102,45,48,53,46,50,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,128,235,207,176,6,0,32,0,109,97,102,45,48,54,46,49,56,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,181,169,199,245,6,0,32,0,109,97,102,45,48,55,46,50,48,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,163,8,96,253,6,0,32,0,109,97,102,45,48,56,46,50,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,231,241,28,228,6,0,32,0,104,102,45,48,56,46,49,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,159,39,183,147,7,0,32,0,104,102,45,48,57,46,49,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,116,192,226,5,7,0,32,0,104,102,45,49,48,46,49,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,24,244,6,155,7,0,32,0,104,102,45,49,49,46,49,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,49,165,89,56,7,0,32,0,109,97,102,45,49,48,46,50,48,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,139,244,87,124,8,0,64,0,109,97,102,45,48,57,46,49,56,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,129,237,231,40,9,0,64,0,104,100,45,48,51,45,50,46,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,250,196,134,5,1,0,16,1,104,100,45,48,48,45,50,46,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,142,196,142,111,1,0,16,1,104,100,45,48,52,45,49,46,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,215,168,46,253,1,0,16,1,104,100,45,48,49,45,49,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,172,71,162,72,1,0,16,1,104,100,45,49,50,46,50,49,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,17,95,213,19,2,0,16,1,104,100,45,48,54,45,49,46,56,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,139,85,122,139,3,0,32,0,104,100,45,48,55,45,49,46,57,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,73,212,163,210,3,0,32,0,109,97,102,45,48,48,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,141,82,111,229,4,0,32,0,109,97,102,45,48,49,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,61,23,213,195,5,0,32,0,109,97,102,45,48,50,46,49,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,73,216,55,11,5,0,32,0,109,97,102,45,48,51,46,49,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,44,109,54,244,6,0,32,0,109,97,102,45,48,52,46,50,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,78,101,143,12,6,0,32,0,109,97,102,45,48,53,46,50,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,128,235,207,176,6,0,32,0,109,97,102,45,48,54,46,49,56,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,181,169,199,245,6,0,32,0,109,97,102,45,48,55,46,50,48,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,163,8,96,253,6,0,32,0,109,97,102,45,48,56,46,50,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,231,241,28,228,6,0,32,0,104,102,45,48,56,46,49,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,159,39,183,147,7,0,32,0,104,102,45,48,57,46,49,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,116,192,226,5,7,0,32,0,104,102,45,49,48,46,49,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,24,244,6,155,7,0,32,0,104,102,45,49,49,46,49,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,49,165,89,56,7,0,32,0,109,97,102,45,49,48,46,50,48,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,139,244,87,124,8,0,64,0,109,97,102,45,48,57,46,49,56,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,129,237,231,40,9,0,64,0,57,48,48,53,56,45,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,88,164,58,131,1,0,16,1,57,48,48,53,56,45,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,6,15,184,228,1,0,16,1,57,48,48,53,56,45,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,200,147,10,146,2,0,16,1,57,48,48,53,56,45,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,173,252,204,129,3,0,32,0,57,48,48,53,56,45,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,2,32,122,160,4,0,32,0,57,48,48,53,56,45,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,4,255,11,86,5,0,32,0,57,48,48,53,56,45,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,3,42,215,185,5,0,32,0,57,48,48,53,56,45,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,62,136,12,198,6,0,64,0,57,48,48,53,56,45,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,118,23,60,35,7,0,64,0,57,48,48,53,56,45,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,153,109,21,222,0,0,0,8,57,48,48,53,56,45,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,108,184,219,207,0,0,0,8,109,117,115,116,97,110,103,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,59,54,198,19,1,0,16,1,109,117,115,116,97,110,103,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,49,206,204,216,1,0,16,1,109,117,115,116,97,110,103,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,5,117,238,153,2,0,16,1,57,48,48,53,56,45,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,173,252,204,129,3,0,32,0,57,48,48,53,56,45,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,2,32,122,160,4,0,32,0,57,48,48,53,56,45,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,4,255,11,86,5,0,32,0,57,48,48,53,56,45,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,3,42,215,185,5,0,32,0,109,117,115,116,97,110,103,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,191,196,246,246,6,0,64,0,101,115,100,50,46,99,117,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,138,9,27,45,1,0,16,1,101,115,100,49,46,99,117,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,99,64,151,16,1,0,16,1,101,115,100,51,46,115,117,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,215,139,23,124,2,0,16,1,101,115,100,49,52,46,106,117,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,37,34,18,166,3,0,32,0,101,115,100,49,53,46,106,117,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,124,169,183,136,3,0,32,0,101,115,100,49,54,46,106,117,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,218,166,112,230,3,0,32,0,101,115,100,49,55,46,106,117,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,153,67,157,166,3,0,32,0,101,115,100,49,51,46,106,117,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,148,21,7,34,3,0,32,0,101,115,100,53,46,102,117,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,194,50,159,41,4,0,32,0,101,115,100,54,46,102,117,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,178,155,104,226,4,0,32,0,101,115,100,49,49,46,102,117,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,238,216,175,155,4,0,32,0,101,115,100,49,50,46,102,117,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,96,184,198,4,0,32,0,101,115,100,55,46,102,117,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,3,160,131,167,4,0,32,0,101,115,100,56,46,102,117,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,242,26,134,34,4,0,32,0,101,115,100,57,46,102,117,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,74,192,82,102,4,0,32,0,101,115,100,49,48,46,102,117,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,75,151,21,216,4,0,32,0,101,115,100,52,46,115,117,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,205,31,116,110,5,0,64,0,109,117,108,116,99,104,109,112,46,117,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,223,192,168,125,1,0,16,1,109,117,108,116,99,104,109,112,46,117,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,153,39,198,93,1,0,16,1,101,115,100,51,46,115,117,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,215,139,23,124,2,0,16,1,109,117,108,116,99,104,109,112,46,117,51,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,168,111,240,216,3,0,32,0,109,117,108,116,99,104,109,112,46,117,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,8,127,174,177,3,0,32,0,109,117,108,116,99,104,109,112,46,117,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,232,82,226,136,3,0,32,0,109,117,108,116,99,104,109,112,46,117,51,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,103,16,240,81,3,0,32,0,109,117,108,116,99,104,109,112,46,117,51,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,166,144,21,157,3,0,32,0,109,117,108,116,99,104,109,112,46,117,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,78,112,66,220,4,0,32,0,109,117,108,116,99,104,109,112,46,117,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,250,145,153,68,4,0,32,0,109,117,108,116,99,104,109,112,46,117,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,150,236,192,228,4,0,32,0,109,117,108,116,99,104,109,112,46,117,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,204,172,250,191,4,0,32,0,109,117,108,116,99,104,109,112,46,117,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,153,19,189,1,4,0,32,0,109,117,108,116,99,104,109,112,46,117,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,204,180,198,4,0,32,0,109,117,108,116,99,104,109,112,46,117,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,227,233,228,177,4,0,32,0,109,117,108,116,99,104,109,112,46,117,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,180,181,92,240,4,0,32,0,101,115,100,52,46,115,117,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,205,31,116,110,5,0,64,0,109,117,103,115,95,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,39,253,152,36,1,0,16,1,109,117,103,115,95,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,11,180,239,149,1,0,16,1,109,117,103,115,95,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,45,223,1,1,2,0,16,1,109,117,103,115,95,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,207,90,159,28,3,0,32,0,109,117,103,115,95,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,217,34,60,107,3,0,32,0,109,117,103,115,95,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,243,144,148,78,3,0,32,0,109,117,103,115,95,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,213,40,99,113,3,0,32,0,109,117,103,115,95,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,253,103,49,158,3,0,32,0,109,117,103,115,95,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,41,93,247,141,3,0,32,0,109,117,103,115,95,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,152,237,166,192,4,0,32,0,109,117,103,115,95,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,149,133,190,226,4,0,32,0,109,117,103,115,95,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,104,16,232,36,4,0,32,0,109,117,103,115,95,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,124,24,232,130,4,0,32,0,109,117,103,115,95,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,74,127,42,249,5,0,32,0,109,117,103,115,95,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,57,11,58,26,5,0,32,0,56,57,49,45,52,48,51,46,107,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,232,196,0,28,1,0,16,1,56,57,49,45,52,48,50,46,107,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,206,187,80,184,1,0,16,1,56,57,49,119,48,49,46,103,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,90,86,236,237,2,0,16,1,56,57,49,101,49,48,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,49,4,155,32,3,0,32,0,56,57,49,101,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,232,169,32,128,3,0,32,0,56,57,49,101,49,48,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,122,253,213,22,3,0,32,0,56,57,49,101,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,192,28,18,48,3,0,32,0,56,57,49,101,48,57,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,191,239,202,157,3,0,32,0,56,57,49,101,48,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,217,234,176,86,3,0,32,0,56,57,49,101,48,57,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,230,53,19,78,3,0,32,0,56,57,49,101,48,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,251,20,249,182,3,0,32,0,56,57,49,101,48,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,28,219,4,11,4,0,32,0,56,57,49,101,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,39,115,227,94,4,0,32,0,56,57,49,101,48,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,36,165,173,249,4,0,32,0,56,57,49,101,48,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,170,223,149,34,4,0,32,0,56,57,49,101,48,54,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,143,247,171,4,4,0,32,0,56,57,49,101,48,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,85,13,219,219,4,0,32,0,56,57,49,101,48,54,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,140,237,93,93,4,0,32,0,56,57,49,101,48,54,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,113,189,236,249,4,0,32,0,56,57,49,101,48,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,41,231,86,179,4,0,32,0,56,57,49,101,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,126,72,213,191,4,0,32,0,56,57,49,101,48,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,197,17,221,236,4,0,32,0,56,57,49,101,48,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,36,141,161,171,4,0,32,0,56,57,49,101,48,53,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,174,249,21,195,4,0,32,0,56,57,49,101,48,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,111,188,252,33,4,0,32,0,56,57,49,101,48,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,59,165,171,176,4,0,32,0])
.concat([56,57,49,101,48,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,134,248,211,246,4,0,32,0,56,57,49,101,48,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,57,185,216,184,5,0,32,0,56,57,49,101,48,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,45,249,178,131,5,0,32,0,56,57,49,101,48,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,191,103,246,206,6,0,32,0,56,57,49,101,48,56,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,122,74,193,247,6,0,32,0,56,57,49,101,48,56,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,60,127,107,117,6,0,32,0,56,57,49,101,48,56,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,5,115,13,205,6,0,32,0,56,57,49,101,48,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,116,188,235,218,7,0,32,0,56,57,49,101,48,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,209,154,251,95,7,0,32,0,56,57,49,101,48,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,107,241,187,45,7,0,32,0,56,57,49,101,48,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,204,210,12,139,7,0,32,0,56,57,49,98,49,49,46,102,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,170,84,184,236,8,0,0,8,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,241,143,33,149,1,0,16,1,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,108,217,167,126,1,0,16,1,117,50,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,107,224,251,22,2,0,64,0,117,53,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,152,23,116,151,3,0,32,0,117,53,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,27,69,17,20,3,0,32,0,117,52,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,83,113,56,43,4,0,32,0,117,52,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,147,106,160,175,4,0,32,0,117,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,18,63,230,217,1,0,16,1,117,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,119,198,63,156,1,0,16,1,117,50,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,56,58,34,10,2,0,64,0,117,53,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,194,227,94,80,3,0,32,0,117,53,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,120,108,107,61,3,0,32,0,117,52,50,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,58,171,135,83,4,0,32,0,117,52,50,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,66,144,58,245,4,0,32,0,117,52,50,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,230,146,248,195,4,0,32,0,117,52,50,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,218,232,39,201,4,0,32,0,98,111,111,116,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,183,49,107,209,1,0,16,1,109,115,112,97,99,97,116,107,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,49,157,240,10,1,0,16,1,98,111,111,116,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,11,238,33,24,1,0,16,1,98,111,111,116,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,216,157,90,22,1,0,16,1,109,115,112,97,99,97,116,107,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,84,105,224,230,1,0,16,1,109,115,112,97,99,97,116,107,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,8,179,93,59,1,0,16,1,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,1,29,40,92,2,0,32,0,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,9,249,90,97,2,0,32,0,56,50,115,49,50,51,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,189,80,198,47,3,0,32,0,56,50,115,49,50,54,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,228,168,179,62,3,0,32,0,56,50,115,49,50,54,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,134,204,169,4,0,64,0,56,50,115,49,50,54,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,112,97,99,109,97,110,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,16,171,230,193,1,0,16,1,112,97,99,102,97,115,116,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,238,195,13,114,1,0,16,1,112,97,99,109,97,110,46,54,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,235,27,221,188,1,0,16,1,112,97,99,109,97,110,46,54,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,227,148,125,129,1,0,16,1,117,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,205,187,95,244,1,0,16,1,117,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,112,14,169,1,0,16,1,117,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,20,215,44,200,1,0,16,1,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,1,29,40,92,2,0,32,0,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,9,249,90,97,2,0,32,0,56,50,115,49,50,51,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,189,80,198,47,3,0,32,0,56,50,115,49,50,54,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,228,168,179,62,3,0,32,0,56,50,115,49,50,54,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,134,204,169,4,0,64,0,56,50,115,49,50,54,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,98,111,111,116,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,183,49,107,209,1,0,16,1,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,134,196,230,4,1,0,16,1,98,111,111,116,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,11,238,33,24,1,0,16,1,98,111,111,116,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,216,157,90,22,1,0,16,1,98,111,111,116,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,230,109,62,140,1,0,16,1,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,35,150,106,32,1,0,16,1,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,1,29,40,92,2,0,32,0,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,9,249,90,97,2,0,32,0,56,50,115,49,50,51,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,189,80,198,47,3,0,32,0,56,50,115,49,50,54,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,228,168,179,62,3,0,32,0,56,50,115,49,50,54,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,134,204,169,4,0,64,0,56,50,115,49,50,54,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,112,97,99,109,97,110,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,16,171,230,193,1,0,16,1,112,97,99,109,97,110,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,212,178,111,26,1,0,16,1,112,97,99,109,97,110,46,54,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,235,27,221,188,1,0,16,1,112,97,99,109,97,110,46,54,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,227,148,125,129,1,0,16,1,117,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,205,187,95,244,1,0,16,1,117,54,112,97,99,97,116,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,77,63,216,246,1,0,16,1,117,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,20,215,44,200,1,0,16,1,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,1,29,40,92,2,0,32,0,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,9,249,90,97,2,0,32,0,56,50,115,49,50,51,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,189,80,198,47,3,0,32,0,56,50,115,49,50,54,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,228,168,179,62,3,0,32,0,56,50,115,49,50,54,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,134,204,169,4,0,64,0,56,50,115,49,50,54,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,112,97,99,109,97,110,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,16,171,230,193,1,0,16,1,112,97,99,109,97,110,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,212,178,111,26,1,0,16,1,112,97,99,109,97,110,46,54,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,235,27,221,188,1,0,16,1,112,97,99,109,97,110,46,54,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,227,148,125,129,1,0,16,1,117,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,205,187,95,244,1,0,16,1,117,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,112,14,169,1,0,16,1,117,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,20,215,44,200,1,0,16,1,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,1,29,40,92,2,0,32,0,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,9,249,90,97,2,0,32,0,56,50,115,49,50,51,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,189,80,198,47,3,0,32,0,56,50,115,49,50,54,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,228,168,179,62,3,0,32,0,56,50,115,49,50,54,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,134,204,169,4,0,64,0,56,50,115,49,50,54,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,14,0,0,0,255,255,201,0,0,0,0,0,15,0,0,0,255,255,255,0,0,0,0,0,16,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,32,4,2,0])
.concat([14,0,0,0,1,3,3,0,160,36,8,0,14,0,0,0,1,3,1,0,208,239,7,0,14,0,0,0,1,3,2,0,120,187,7,0,14,0,0,0,1,3,0,0,16,227,4,0,0,0,0,0,254,0,4,0,128,129,4,0,14,0,0,0,1,12,0,0,192,255,2,0,14,0,0,0,1,12,4,0,208,75,4,0,14,0,0,0,1,12,8,0,8,49,4,0,14,0,0,0,1,12,12,0,72,246,3,0,0,0,0,0,254,0,4,0,64,37,5,0,14,0,0,0,1,48,0,0,176,116,6,0,14,0,0,0,1,48,16,0,80,113,6,0,14,0,0,0,1,48,32,0,80,110,6,0,14,0,0,0,1,48,48,0,120,7,5,0,0,0,0,0,254,0,2,0,72,202,5,0,14,0,0,0,1,64,64,0,248,38,7,0,14,0,0,0,1,64,0,0,112,212,3,0,0,0,0,0,254,0,2,0,16,27,6,0,15,0,0,0,1,16,16,0,96,135,7,0,15,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,2,0,200,30,2,0,16,0,0,0,1,128,128,0,120,97,1,0,16,0,0,0,1,128,0,0,96,19,1,0,0,0,0,0,98,111,111,116,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,183,49,107,209,1,0,16,1,98,111,111,116,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,94,222,50,13,1,0,16,1,98,111,111,116,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,11,238,33,24,1,0,16,1,98,111,111,116,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,216,157,90,22,1,0,16,1,98,111,111,116,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,230,109,62,140,1,0,16,1,98,111,111,116,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,101,177,140,54,1,0,16,1,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,1,29,40,92,2,0,32,0,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,9,249,90,97,2,0,32,0,56,50,115,49,50,51,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,189,80,198,47,3,0,32,0,56,50,115,49,50,54,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,228,168,179,62,3,0,32,0,56,50,115,49,50,54,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,134,204,169,4,0,64,0,56,50,115,49,50,54,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,50,57,57,45,112,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,40,226,47,95,1,0,16,1,50,57,57,45,112,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,53,168,63,25,1,0,16,1,50,57,57,45,115,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,53,150,139,111,2,0,32,0,50,53,54,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,78,195,121,90,3,0,32,0,50,53,54,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,44,54,76,148,3,0,32,0,50,53,54,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,111,211,105,110,3,0,32,0,50,53,54,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,235,180,85,183,3,0,32,0,50,53,54,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,71,171,172,122,3,0,32,0,50,53,54,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,93,253,152,198,3,0,32,0,50,53,54,45,99,55,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,210,221,206,207,3,0,32,0,50,53,54,45,99,56,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,76,227,155,77,3,0,32,0,50,53,54,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,22,193,238,234,4,0,16,1,50,53,54,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,65,2,105,242,5,0,64,0,50,53,54,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,189,16,42,126,5,0,64,0,50,53,54,45,118,51,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,124,193,174,14,5,0,64,0,50,53,54,45,118,52,46,118,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,212,34,75,155,5,0,64,0,112,97,99,109,97,110,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,16,171,230,193,1,0,16,1,112,97,99,109,97,110,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,212,178,111,26,1,0,16,1,112,97,99,109,97,110,46,54,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,235,27,221,188,1,0,16,1,112,97,99,109,97,110,46,54,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,227,148,125,129,1,0,16,1,117,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,205,187,95,244,1,0,16,1,117,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,112,14,169,1,0,16,1,117,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,20,215,44,200,1,0,16,1,53,101,40,95,95,109,115,104,101,97,114,116,98,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,196,212,49,84,2,0,32,0,53,102,40,95,95,109,115,104,101,97,114,116,98,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,84,6,181,206,2,0,32,0,56,50,115,49,50,51,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,189,80,198,47,3,0,32,0,56,50,115,49,50,54,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,228,168,179,62,3,0,32,0,56,50,115,49,50,54,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,134,204,169,4,0,64,0,56,50,115,49,50,54,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,102,97,48,48,51,48,48,50,46,117,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,76,45,199,28,1,0,16,1,102,97,48,48,49,48,48,49,46,117,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,208,57,161,252,1,0,16,1,102,97,48,48,49,48,48,56,46,117,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,72,207,172,231,3,0,32,0,102,97,48,48,49,48,48,55,46,117,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,166,152,49,121,3,0,32,0,102,97,48,48,49,48,48,54,46,117,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,92,54,96,59,4,0,32,0,102,97,48,48,49,48,48,53,46,117,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,134,255,215,140,5,0,32,0,102,97,48,48,49,48,48,52,46,117,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,124,240,101,185,6,0,64,0,112,109,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,3,99,107,125,1,0,16,1,112,109,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,226,185,230,127,2,0,32,0,56,50,115,49,50,51,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,189,80,198,47,3,0,32,0,56,50,115,49,50,54,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,228,168,179,62,3,0,32,0,56,50,115,49,50,54,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,134,204,169,4,0,64,0,56,50,115,49,50,54,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,54,50,49,100,48,49,46,49,48,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,86,156,33,178,1,0,16,1,54,50,49,100,48,50,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,151,122,51,195,1,0,16,1,54,50,49,97,48,53,46,54,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,197,223,166,240,2,0,32,0,54,50,49,100,48,51,46,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,115,185,242,102,3,0,32,0,54,50,49,100,48,52,46,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,1,99,223,71,3,0,32,0,54,50,49,97,48,54,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,95,222,144,124,4,0,32,0,54,50,49,97,48,56,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,221,68,178,47,4,0,32,0,54,50,49,97,48,55,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,220,172,128,57,4,0,32,0,18,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,18,0,0,0,1,15,2,0,80,252,6,0,18,0,0,0,1,15,5,0,16,242,7,0,18,0,0,0,1,15,8,0,104,236,7,0,18,0,0,0,1,15,4,0,120,113,6,0,18,0,0,0,1,15,1,0,232,228,5,0,18,0,0,0,1,15,15,0,80,245,6,0,18,0,0,0,1,15,3,0,56,141,7,0,18,0,0,0,1,15,7,0,120,211,6,0,18,0,0,0,1,15,14,0,8,201,6,0,18,0,0,0,1,15,6,0,24,1,7,0,18,0,0,0,1,15,13,0,200,197,6,0,18,0,0,0,1,15,12,0,152,194,6,0,18,0,0,0,1,15,11,0,128,95,7,0,18,0,0,0,1,15,10,0,248,189,6,0,18,0,0,0,1,15,9,0,208,114,5,0,18,0,0,0,1,15,0,0,16,227,4,0,0,0,0,0,254,0,15,0,160,123,6,0,18,0,0,0,130,240,32,0,80,252,6,0,18,0,0,0,0,15,0,0,0,0,0,0,18,0,0,0,130,240,80,0,16,242,7,0,18,0,0,0,0,15,0,0,0,0,0,0,18,0,0,0,130,240,128,0,104,236,7,0,18,0,0,0,0,15,0,0,0,0,0,0,18,0,0,0,130,240,64,0,120,113,6,0,18,0,0,0,0,15,0,0,0,0,0,0,18,0,0,0,130,240,16,0,232,228,5,0,18,0,0,0,0,15,0,0,0,0,0,0,18,0,0,0,130,240,240,0,80,245,6,0,18,0,0,0,0,15,0,0,0,0,0,0,18,0,0,0,130,240,48,0,56,141,7,0,18,0,0,0,0,15,0,0,0,0,0,0,18,0,0,0,130,240,112,0,120,211,6,0,18,0,0,0,0,15,0,0,0,0,0,0,18,0,0,0,130,240,224,0,8,201,6,0,18,0,0,0,0,15,0,0,0,0,0,0,18,0,0,0,130,240,96,0,24,1,7,0,18,0,0,0,0,15,0,0,0,0,0,0,18,0,0,0,130,240,208,0,200,197,6,0,18,0,0,0,0,15,0,0,0,0,0,0,18,0,0,0,130,240,192,0,152,194,6,0,18,0,0,0,0,15,0,0,0,0,0,0,18,0,0,0,130,240,176,0,128,95,7,0,18,0,0,0,0,15,0,0,0,0,0,0,18,0,0,0,130,240,160,0,248,189,6,0,18,0,0,0,0,15,0,0,0,0,0,0,18,0,0,0,130,240,144,0,208,114,5,0,18,0,0,0,0,15,0,0,0,0,0,0,19,0,0,0,255,255,74,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,19,0,0,0,1,3,3,0,208,75,4,0,19,0,0,0,1,3,2,0,8,49,4,0,19,0,0,0,1,3,1,0,72,246,3,0,19,0,0,0,1,3,0,0,64,47,7,0,0,0,0,0,254,0,2,0,200,30,2,0,19,0,0,0,1,4,0,0,120,97,1,0,19,0,0,0,1,4,4,0,96,19,1,0,0,0,0,0,254,0,4,0,64,37,5,0,19,0,0,0,1,24,24,0,176,7,4,0,19,0,0,0,1,24,16,0,80,230,3,0,19,0,0,0,1,24,8,0,32,199,3,0,19,0,0,0,1,24,0,0,112,172,3,0,0,0,0,0,254,0,4,0,72,202,5,0,19,0,0,0,1,96,96,0,80,246,3,0,19,0,0,0,1,96,64,0,248,38,7,0,19,0,0,0,1,96,32,0,48,123,8,0,19,0,0,0,1,96,0,0,8,117,8,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,128,128,0,96,135,7,0,19,0,0,0,1,128,0,0,152,182,7,0,20,0,0,0,255,255,15,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,20,0,0,0,1,1,1,0,96,135,7,0,20,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,6,0,20,0,0,0,1,2,2,0,8,208,6,0,20,0,0,0,1,2,0,0,88,204,6,0,0,0,0,0,254,0,2,0,232,75,4,0,20,0,0,0,1,4,4,0,96,135,7,0,20,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,50,48,51,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,45,14,167,123,1,0,16,1,50,48,51,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,131,220,191,2,0,32,0,50,48,51,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,192,232,169,187,3,0,32,0,50,48,51,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,3,190,116,37,3,0,32,0,50,48,51,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,194,194,2,166,4,0,16,1,50,48,51,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,165,185,162,186,5,0,64,0,99,49,55,45,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,15,17,238,5,2,0,16,1,99,49,55,45,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,253,207,170,208,2,0,16,1,99,49,55,45,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,195,127,4,39,1,0,16,1,99,49,55,45,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,44,188,183,205,9,0,16,1,99,49,55,45,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,66,109,70,233,11,0,32,0,99,49,55,45,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,219,168,96,136,15,0,32,0,99,49,55,45,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,65,71,172,87,16,0,32,0,99,49,55,45,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,16,4,37,244,16,0,32,0,99,49,55,45,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,37,33,51,92,26,0,64,0,0,0,0,1,1,0,1,1,0,0,0,4,0,0,0,0,49,46,117,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,118,120,255,245,1,0,16,1,50,46,117,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,220,65,32,95,1,0,16,1,49,108,46,117,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,177,66,218,48,2,0,32,0,49,104,46,117,49,50,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,68,29,156,98,2,0,32,0,50,108,46,117,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,171,38,97,31,2,0,32,0,50,104,46,117,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,70,78,163,219,2,0,32,0,51,108,46,117,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,94,227,35,16,2,0,32,0,51,104,46,117,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,127,236,235,138,2,0,32,0,52,108,46,117,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,139,1,207,154,2,0,32,0,52,104,46,117,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,76,21,62,249,2,0,32,0,115,110,100,48,46,117,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,24,240,121,1,3,0,64,0,101,101,112,114,111,109,45,109,106,103,116,97,115,116,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,174,207,247,187,0,0,0,8,108,108,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,129,199,233,123,0,0,16,1,108,104,49,46,117,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,114,63,170,130,0,0,16,1,104,108,46,117,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,183,99,96,34,0,0,16,1,104,104,46,117,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,248,170,35,0,0,16,1,99,104,97,45,48,51,46,117,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,154,66,103,211,0,0,32,0,99,104,97,45,48,52,46,117,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,195,8,32,127,0,0,32,0,99,104,97,45,48,53,46,117,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,10,196,78,233,0,0,32,0,99,104,97,45,48,54,46,117,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,169,179,176,92,0,0,32,0,99,104,97,45,48,49,46,117,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,55,123,244,53,0,0,32,0,99,104,97,45,48,50,46,117,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,96,104,52,246,0,0,32,0,99,104,97,45,48,55,46,117,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,238,25,117,129,0,0,64,0,31,0,0,0,255,255,0,0,0,0,0,0,32,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,8,0,32,4,2,0,31,0,0,0,1,7,0,0,200,201,5,0,31,0,0,0,1,7,1,0,152,160,5,0,31,0,0,0,1,7,2,0,144,127,5,0,31,0,0,0,1,7,3,0,168,98,5,0,31,0,0,0,1,7,4,0,224,67,5,0,31,0,0,0,1,7,5,0,216,36,5,0,31,0,0,0,1,7,6,0,8,7,5,0,31,0,0,0,1,7,7,0,128,107,4,0,0,0,0,0,254,0,2,0,200,135,2,0,31,0,0,0,1,8,8,0,96,135,7,0,31,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,89,6,0,31,0,0,0,1,16,16,0,96,135,7,0,31,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,2,0,96,228,6,0,31,0,0,0,1,32,0,0,96,135,7,0,31,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,40,182,1,0,31,0,0,0,1,64,0,0,96,135,7,0,31,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,208,87,7,0,31,0,0,0,1,128,0,0,96,135,7,0,31,0,0,0,1,128,128,0,152,182,7,0,0,0,0,0,254,0,8,0,72,202,5,0,32,0,0,0,1,7,3,0,24,205,7,0,32,0,0,0,1,7,4,0,192,255,2,0,32,0,0,0,1,7,5,0,208,75,4,0,32,0,0,0,1,7,6,0,8,49,4,0,32,0,0,0,1,7,7,0,152,21,4,0,32,0,0,0,1,7,0,0,72,246,3,0,32,0,0,0,1,7,1,0,72,0,3,0,32,0,0,0,1,7,2,0,64,47,7,0,0,0,0,0,254,0,2,0,80,111,3,0,32,0,0,0,1,8,8,0,96,135,7,0,32,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,62,6,0,32,0,0,0,1,16,0,0,96,135,7,0,32,0,0,0,1,16,16,0,152,182,7,0,0,0,0,0,254,0,2,0,184,59,6,0,32,0,0,0,1,32,0,0,96,135,7,0,32,0,0,0,1,32,32,0,152,182,7,0,100,50,54,45,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,61,130,108,169,0,0,16,1,50,51,49,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,16,24,190,97,1,0,16,1,50,51,49,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,83,12,12,254,2,0,32,0,50,51,49,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,163,59,64,108,3,0,32,0,50,51,49,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,155,205,75,85,3,0,32,0,50,51,49,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,99,122,111,79,3,0,32,0,50,51,49,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,27,231,53,46,3,0,32,0,50,51,49,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,27,48,65,222,4,0,16,1,50,51,49,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,152,184,63,17,5,0,64,0,109,99,49,45,51,46,57,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,60,179,144,51,1,0,16,1,109,99,49,45,49,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,126,151,176,16,1,0,16,1,109,99,49,45,50,46,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,53,111,132,92,1,0,16,1,109,99,49,45,52,46,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,152,248,136,156,2,0,16,1,99,117,115,54,48,45,54,48,97,49,46,109,99,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,42,168,110,7,2,0,16,1,109,99,49,45,53,46,51,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,58,163,94,155,3,0,32,0,109,99,49,45,55,46,52,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,3,160,223,201,4,0,32,0,109,99,49,45,54,46,52,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,60,220,134,150,4,0,32,0,109,99,49,45,56,46,56,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,250,49,91,38,5,0,32,0,109,99,49,45,57,46,56,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,41,192,30,84,5,0,32,0,109,99,49,45,49,46,49,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,139,138,167,50,6,0,32,0,109,99,49,45,50,46,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,123,202,77,111,6,0,32,0,98,112,57,52,55,97,46,117,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,66,52,92,10,0,0,16,1,98,112,57,52,55,97,46,117,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,207,222,85,140,0,0,16,1,98,112,57,52,55,97,46,117,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,59,63,15,207,0,0,16,1,98,112,57,52,55,97,46,117,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,112,97,163,164,0,0,16,1,98,112,57,52,55,97,46,117,52,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,49,149,116,9,0,0,32,0,98,112,57,52,55,97,46,117,53,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,178,168,206,25,0,0,32,0,98,112,57,52,55,97,46,117,53,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,103,237,155,193,0,0,32,0,98,112,57,52,55,97,46,117,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,117,72,198,112,0,0,32,0,98,112,57,52,55,97,46,117,52,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,61,106,255,4,0,0,32,0,98,112,57,52,55,97,46,117,52,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,39,40,228,13,0,0,32,0,98,112,57,52,55,97,46,117,52,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,110,144,156,15,0,0,32,0,98,112,57,52,55,97,46,117,52,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,42,255,232,44,0,0,64,0,98,112,57,52,55,97,46,117,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,143,124,7,195,0,0,64,0,50,55,50,53,54,46,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,162,232,181,213,1,0,0,0,50,52,53,49,50,46,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,184,176,201,64,1,0,0,0,50,52,53,49,50,46,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,244,168,6,86,1,0,0,0,50,55,53,49,50,46,54,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,93,5,166,140,1,0,0,0,50,55,50,53,54,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,130,77,140,194,2,0,0,0,50,55,50,53,54,46,49,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,92,241,37,61,3,0,0,0,57,50,46,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,169,191,13,155,4,0,0,0,57,51,46,54,111,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,218,63,104,149,4,0,0,0,56,57,46,54,105,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,167,204,31,27,4,0,0,0,57,49,46,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,86,48,65,231,4,0,0,0,56,56,46,54,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,70,117,102,87,4,0,0,0,57,48,46,54,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,184,141,84,76,4,0,0,0,57,52,46,54,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,39,249,188,229,4,0,0,0,57,53,46,54,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,35,247,16,158,4,0,0,0,50,55,53,49,50,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,157,2,94,182,5,0,0,0,50,55,53,49,50,46,49,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,93,153,141,102,5,0,0,0,50,55,53,49,50,46,49,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,226,228,127,84,5,0,0,0,50,55,53,49,50,46,49,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,19,141,82,106,5,0,0,0,100,119,49,56,46,57,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,95,148,241,117,6,0,0,0,100,119,49,57,46,49,48,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,250,243,22,204,6,0,0,0,100,119,46,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,217,206,233,40,7,0,0,8,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,163,151,150,140,0,0,16,1,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,53,53,218,247,0,0,16,1,112,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,102,178,240,10,0,0,16,1,112,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,197,89,177,170,0,0,16,1,112,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,71,10,209,14,0,0,16,1,112,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,85,135,181,96,0,0,16,1,112,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,241,118,76,96,0,0,16,1,112,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,25,239,234,227,0,0,16,1,112,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,223,239,223,174,0,0,16,1,112,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,100,215,180,147,0,0,16,1,99,108,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,167,181,149,123,0,0,32,0,122,111,111,112,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,250,190,153,168,33,0,16,0,122,111,111,108,32,45,32,110,105,110,106,97,32,111,102,32,116,104,101,32,39,110,116,104,39,32,100,105,109,101,110,115,105,111,110,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,241,57,41,203,33,0,16,0,122,101,114,111,32,116,104,101,32,107,97,109,105,107,97,122,101,32,115,113,117,105,114,114,101,108,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,223,104,57,66,33,0,16,0,121,117,117,32,121,117,117,32,104,97,107,117,115,104,111,32,103,97,105,100,101,110,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,118,129,201,125,33,0,16,0,120,45,109,101,110,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,180,33,27,247,33,0,16,0,120,45,109,101,110,32,50,32,45,32,99,108,111,110,101,32,119,97,114,115,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,40,198,11,113,33,0,16,0,99,114,111,115,115,32,102,105,114,101,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,169,243,115,204,33,0,16,0,57,53,51,57,100,43,57,53,52,48,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,249,35,208,165,33,0,16,0,119,111,114,108,100,32,115,101,114,105,101,115,32,98,97,115,101,98,97,108,108,32,39,57,56,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,83,171,177,5,33,0,16,0,119,111,114,108,100,32,115,101,114,105,101,115,32,98,97,115,101,98,97,108,108,32,39,57,54,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,114,130,238,4,33,0,16,0,119,111,114,108,100,32,115,101,114,105,101,115,32,98,97,115,101,98,97,108,108,32,39,57,53,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,119,0,19,37,33,0,16,0,119,111,114,109,115,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,153,178,168,185,33,0,16,0,119,111,114,108,100,32,104,101,114,111,101,115,32,40,117,115,97,41,32,40,112,114,111,116,111,116,121,112,101,32,45,32,102,101,98,32,50,51,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,126,71,219,245,33,0,16,0,119,111,114,108,100,32,104,101,114,111,101,115,32,40,117,115,97,41,32,40,112,114,111,116,111,116,121,112,101,32,45,32,109,97,114,32,48,51,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,239,58,166,36,33,0,16,0,119,111,114,108,100,32,104,101,114,111,101,115,32,40,117,115,97,41,32,40,112,114,111,116,111,116,121,112,101,32,45,32,109,97,114,32,48,55,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,80,147,194,69,33,0,16,0,119,111,114,108,100,32,104,101,114,111,101,115,32,40,117,115,97,41,32,40,112,114,111,116,111,116,121,112,101,32,45,32,109,97,114,32,48,57,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,100,158,127,44,33,0,16,0,119,111,114,108,100,32,104,101,114,111,101,115,32,40,117,115,97,41,32,40,112,114,111,116,111,116,121,112,101,32,45,32,109,97,114,32,49,53,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,79,47,11,44,33,0,16,0,119,111,114,108,100,32,104,101,114,111,101,115,32,40,117,115,97,41,32,40,112,114,111,116,111,116,121,112,101,32,45,32,109,97,114,32,49,54,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,42,78,199,25,33,0,16,0,119,111,114,108,100,32,104,101,114,111,101,115,32,40,117,115,97,41,32,40,112,114,111,116,111,116,121,112,101,32,45,32,109,97,114,32,49,56,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,187,166,194,43,33,0,16,0,119,111,114,108,100,32,104,101,114,111,101,115,32,40,117,115,97,41,32,40,112,114,111,116,111,116,121,112,101,32,45,32,109,97,114,32,50,50,44,32,49,57,57,52,41,32,40,98,114,111,107,101,110,32,45,32,99,48,55,32,109,105,115,115,105,110,103,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,49,9,60,92,33,0,16,0,119,111,114,108,100,32,104,101,114,111,101,115,32,40,117,115,97,41,32,40,112,114,111,116,111,116,121,112,101,32,45,32,109,97,114,32,50,51,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,57,103,126,88,33,0,16,0,119,111,114,108,100,32,104,101,114,111,101,115,32,40,117,115,97,41,32,40,112,114,111,116,111,116,121,112,101,32,45,32,109,97,114,32,50,52,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,66,105,101,138,33,0,16,0,119,111,114,108,100,32,104,101,114,111,101,115,32,40,117,115,97,41,32,40,112,114,111,116,111,116,121,112,101,32,45,32,109,97,114,32,51,48,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,203,151,199,80,33,0,16,0,119,111,114,108,100,32,104,101,114,111,101,115,32,40,101,117,114,111,41,32,40,112,114,111,116,111,116,121,112,101,32,45,32,109,97,114,32,51,49,44,32,49,57,57,52,32,45,32,98,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,110,170,16,210,33,0,16,0,119,111,114,108,100,32,104,101,114,111,101,115,32,40,101,117,114,111,41,32,40,112,114,111,116,111,116,121,112,101,32,45,32,109,97,114,32,51,49,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,20,191,225,146,33,0,16,0,119,111,114,108,100,32,104,101,114,111,101,115,32,40,106,112,110,41,32,40,112,114,111,116,111,116,121,112,101,32,45,32,109,97,114,32,51,48,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,26,24,147,63,33,0,16,0,119,111,114,108,100,32,104,101,114,111,101,115,32,40,106,112,110,41,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,112,114,32,48,56,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,21,114,234,43,33,0,16,0,119,111,114,108,100,32,104,101,114,111,101,115,32,40,106,112,110,41,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,112,114,32,49,53,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,179,7,236,109,33,0,16,0,119,111,114,108,100,32,104,101,114,111,101,115,32,40,106,112,110,41,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,112,114,32,50,48,44,32,49,57,57,52,32,45,32,98,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,145,177,255,245,33,0,16,0,119,111,114,108,100,32,104,101,114,111,101,115,32,40,106,112,110,41,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,112,114,32,50,48,44,32,49,57,57,52,41,32,40,98,114,111,107,101,110,32,45,32,99,48,53,32,109,105,115,115,105,110,103,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,140,81,59,180,33,0,16,0,119,111,114,108,100,32,99,104,97,109,112,105,111,110,115,104,105,112,32,115,111,99,99,101,114,32,105,105,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,142,28,221,193,33,0,16,0,119,111,110,100,101,114,32,98,111,121,32,118,32,45,32,109,111,110,115,116,101,114,32,119,111,114,108,100,32,105,105,105,32,40,106,112,110,44,32,107,111,114,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,150,15,165,69,33,0,16,0,109,112,114,45,49,51,54,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,228,197,75,194,33,0,16,0,103,114,101,97,116,32,119,97,108,100,111,32,115,101,97,114,99,104,44,32,116,104,101,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,184,147,92,140,33,0,16,0,118,111,105,110,97,95,105,114,97,107,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,147,126,23,199,33,0,16,0,118,45,118,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,192,14,157,173,33,0,16,0,118,105,114,116,117,97,32,102,105,103,104,116,101,114,32,50,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,117,103,32,49,57,44,32,49,57,57,54,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,116,57,238,197,33,0,16,0,118,105,114,116,117,97,32,102,105,103,104,116,101,114,32,50,32,40,112,114,111,116,111,116,121,112,101,32,45,32,97,117,103,32,51,48,44,32,49,57,57,54,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,123,58,15,106,33,0,16,0,118,105,114,116,117,97,32,102,105,103,104,116,101,114,32,50,32,40,112,114,111,116,111,116,121,112,101,32,45,32,115,101,112,32,49,51,44,32,49,57,57,54,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,145,173,91,250,33,0,16,0,118,105,114,116,117,97,32,102,105,103,104,116,101,114,32,50,32,40,112,114,111,116,111,116,121,112,101,32,45,32,115,101,112,32,50,48,44,32,49,57,57,54,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,173,109,81,175,33,0,16,0,118,105,114,116,117,97,32,102,105,103,104,116,101,114,32,50,32,40,112,114,111,116,111,116,121,112,101,32,45,32,115,101,112,32,50,55,44,32,49,57,57,54,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,182,106,171,149,33,0,16,0,115,112,105,100,101,114,45,109,97,110,32,97,110,100,32,118,101,110,111,109,32,45,32,115,101,112,97,114,97,116,105,111,110,32,97,110,120,105,101,116,121,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,50,222,42,81,33,0,16,0,118,105,114,116,117,97,108,32,98,97,114,116,32,40,119,111,114,108,100,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,120,243,185,141,33,0,16,0,118,97,108,105,115,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,114,91,188,19,33,0,16,0,117,108,116,105,109,97,116,101,32,109,111,114,116,97,108,32,107,111,109,98,97,116,32,51,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,13,119,144,114,33,0,16,0,116,111,107,105,32,45,32,103,111,105,110,103,32,97,112,101,32,115,112,105,116,32,45,45,32,106,117,106,117,32,100,101,110,115,101,116,115,117,32,40,119,111,114,108,100,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,241,30,155,208,33,0,16,0,115,116,111,114,121,32,111,102,32,116,104,111,114,44,32,116,104,101,32,40,115,112,97,105,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,65,249,49,70,33,0,16,0,115,116,111,114,121,32,111,102,32,116,104,111,114,44,32,116,104,101,32,40,107,111,114,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,197,3,22,238,33,0,16,0,115,116,111,114,121,32,111,102,32,116,104,111,114,44,32,116,104,101,32,45,32,104,105,107,97,114,105,32,111,32,116,115,117,103,117,109,111,110,111,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,60,120,57,79,33,0,16,0,115,116,111,114,121,32,111,102,32,116,104,111,114,44,32,116,104,101,32,40,103,101,114,109,97,110,121,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,17,208,32,250,33,0,16,0,109,112,114,45,49,55,55,50,48,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,112,249,133,83,17,0,16,0,109,112,114,45,49,55,55,50,49,46,105,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,170,162,143,21,23,0,16,0,116,104,117,110,100,101,114,32,102,111,120,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,250,207,166,236,33,0,16,0,116,50,32,45,32,116,101,114,109,105,110,97,116,111,114,32,50,32,45,32,106,117,100,103,109,101,110,116,32,100,97,121,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,150,232,117,47,33,0,16,0,112,117,122,122,108,101,32,38,32,97,99,116,105,111,110,32,45,32,116,97,110,116,111,45,114,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,55,212,210,210,33,0,16,0,116,50,32,45,32,116,104,101,32,97,114,99,97,100,101,32,103,97,109,101,32,40,117,115,97,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,3,87,37,148,33,0,16,0,116,50,32,45,32,116,104,101,32,97,114,99,97,100,101,32,103,97,109,101,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,44,229,111,94,33,0,16,0,115,119,97,109,112,32,116,104,105,110,103,32,112,114,111,116,111,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,213,233,235,230,33,0,16,0,115,116,97,114,32,116,114,101,107,32,45,32,116,104,101,32,110,101,120,116,32,103,101,110,101,114,97,116,105,111,110,32,45,32,101,99,104,111,101,115,32,102,114,111,109,32,116,104,101,32,112,97,115,116,32,40,117,115,97,41,32,40,118,49,46,49,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,242,14,132,239,33,0,16,0,115,116,97,114,32,116,114,101,107,32,45,32,100,101,101,112,32,115,112,97,99,101,32,110,105,110,101,32,45,32,99,114,111,115,115,114,111,97,100,115,32,111,102,32,116,105,109,101,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,249,34,177,212,33,0,16,0,109,112,114,45,49,54,48,55,55,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,109,120,160,174,33,0,16,0,115,117,112,101,114,32,115,107,105,100,109,97,114,107,115,32,40,101,117,114,111,41,32,40,106,45,99,97,114,116,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,249,98,156,74,33,0,16,0,115,117,112,101,114,32,115,116,114,101,101,116,32,102,105,103,104,116,101,114,32,105,105,32,45,32,116,104,101,32,110,101,119,32,99,104,97,108,108,101,110,103,101,114,115,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,0,191,239,93,22,33,0,16,0,115,117,112,101,114,32,115,116,114,101,101,116,32,102,105,103,104,116,101,114,32,105,105,32,45,32,116,104,101,32,110,101,119,32,99,104,97,108,108,101,110,103,101,114,115,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,0,189,178,238,216,33,0,16,0,115,116,114,101,101,116,115,32,111,102,32,114,97,103,101,32,51,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,217,21,187,213,33,0,16,0,115,116,114,101,101,116,115,32,111,102,32,114,97,103,101,32,51,32,40,107,111,114,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,30,153,239,144,33,0,16,0,115,116,114,101,101,116,115,32,111,102,32,114,97,103,101,32,50,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,38,165,31,224,33,0,16,0,109,112,114,45,49,51,57,49,51,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,151,78,57,249,33,0,16,0,115,117,112,101,114,32,109,111,110,97,99,111,32,103,112,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,238,24,80,114,33,0,16,0,109,112,114,45,49,51,50,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,179,186,249,144,33,0,16,0,115,117,112,101,114,32,109,111,110,97,99,111,32,103,112,32,40,101,117,114,111,44,32,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,149,53,130,177,33,0,16,0,109,112,114,45,49,52,56,54,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,118,15,175,96,33,0,16,0,109,97,114,105,111,32,38,32,98,97,116,116,108,101,32,99,105,116,121,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,148,121,143,86,33,0,16,0,115,111,110,105,99,32,38,32,107,110,117,99,107,108,101,115,32,40,112,114,111,116,111,116,121,112,101,32,48,53,50,53,32,45,32,109,97,121,32,50,53,44,32,49,57,57,52,44,32,49,53,46,50,56,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,208,173,141,142,33,0,16,0,115,111,110,105,99,32,38,32,107,110,117,99,107,108,101,115,32,40,115,50,107,32,99,104,105,112,41,32,40,112,114,111,116,111,116,121,112,101,32,48,54,48,54,32,45,32,106,117,110,32,48,53,44,32,49,57,57,52,44,32,50,50,46,50,53,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,169,158,97,189,33,0,16,0,115,111,110,105,99,32,38,32,107,110,117,99,107,108,101,115,32,40,112,114,111,116,111,116,121,112,101,32,48,54,48,54,32,45,32,106,117,110,32,48,54,44,32,49,57,57,52,44,32,49,48,46,48,50,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,99,47,165,3,33,0,16,0,115,111,110,105,99,32,38,32,107,110,117,99,107,108,101,115,32,40,115,50,107,32,99,104,105,112,41,32,40,112,114,111,116,111,116,121,112,101,32,48,54,48,56,32,45,32,106,117,110,32,48,56,44,32,49,57,57,52,44,32,48,51,46,51,53,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,230,203,93,106,33,0,16,0,115,111,110,105,99,32,38,32,107,110,117,99,107,108,101,115,32,40,112,114,111,116,111,116,121,112,101,32,48,54,48,56,32,45,32,106,117,110,32,48,56,44,32,49,57,57,52,44,32,48,53,46,48,51,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,23,19,108,122,33,0,16,0,115,111,110,105,99,32,38,32,107,110,117,99,107,108,101,115,32,40,115,50,107,32,99,104,105,112,41,32,40,112,114,111,116,111,116,121,112,101,32,48,54,49,48,32,45,32,106,117,110,32,49,48,44,32,49,57,57,52,44,32,48,51,46,49,49,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,43,242,111,15,33,0,16,0,115,111,110,105,99,32,38,32,107,110,117,99,107,108,101,115,32,40,112,114,111,116,111,116,121,112,101,32,48,54,49,48,32,45,32,106,117,110,32,49,48,44,32,49,57,57,52,44,32,48,55,46,52,57,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,104,243,146,112,33,0,16,0,115,111,110,105,99,32,38,32,107,110,117,99,107,108,101,115,32,40,115,50,107,32,99,104,105,112,41,32,40,112,114,111,116,111,116,121,112,101,32,48,54,49,50,32,45,32,106,117,110,32,49,50,44,32,49,57,57,52,44,32,49,56,46,49,56,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,131,129,95,154,33,0,16,0,115,111,110,105,99,32,38,32,107,110,117,99,107,108,101,115,32,40,112,114,111,116,111,116,121,112,101,32,48,54,49,50,32,45,32,106,117,110,32,49,50,44,32,49,57,57,52,44,32,49,56,46,50,55,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,232,83,162,176,33,0,16,0,115,111,110,105,99,32,38,32,107,110,117,99,107,108,101,115,32,40,115,50,107,32,99,104,105,112,41,32,40,112,114,111,116,111,116,121,112,101,32,48,54,49,56,32,45,32,106,117,110,32,49,56,44,32,49,57,57,52,44,32,57,46,48,55,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,92,213,207,77,33,0,16,0,115,111,110,105,99,32,38,32,107,110,117,99,107,108,101,115,32,40,112,114,111,116,111,116,121,112,101,32,48,54,49,56,32,45,32,106,117,110,32,49,56,44,32,49,57,57,52,44,32,48,57,46,49,53,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,220,245,21,38,33,0,16,0,115,111,110,105,99,32,38,32,107,110,117,99,107,108,101,115,32,40,112,114,111,116,111,116,121,112,101,32,48,54,49,57,32,45,32,106,117,110,32,49,57,44,32,49,57,57,52,44,32,48,56,46,49,56,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,209,185,165,30,33,0,16,0,115,104,114,101,107,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,185,132,30,86,33,0,16,0,112,104,97,110,116,97,115,121,32,115,116,97,114,32,105,105,32,45,32,121,117,115,104,105,115,39,115,32,97,100,118,101,110,116,117,114,101,32,40,106,112,110,41,32,40,115,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,214,118,12,212,33,0,16,0,112,104,97,110,116,97,115,121,32,115,116,97,114,32,105,105,32,45,32,115,104,105,108,107,97,39,115,32,97,100,118,101,110,116,117,114,101,32,40,106,112,110,41,32,40,115,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,178,190,131,31,33,0,16,0,112,104,97,110,116,97,115,121,32,115,116,97,114,32,105,105,32,45,32,114,117,100,103,101,114,39,115,32,97,100,118,101,110,116,117,114,101,32,40,106,112,110,41,32,40,115,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,210,22,89,107,33,0,16,0,112,104,97,110,116,97,115,121,32,115,116,97,114,32,105,105,32,45,32,110,101,105,39,115,32,97,100,118,101,110,116,117,114,101,32,40,106,112,110,41,32,40,115,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,101,212,154,61,33,0,16,0,112,104,97,110,116,97,115,121,32,115,116,97,114,32,105,105,32,45,32,107,105,110,100,115,39,115,32,97,100,118,101,110,116,117,114,101,32,40,106,112,110,41,32,40,115,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,8,243,52,195,33,0,16,0,112,104,97,110,116,97,115,121,32,115,116,97,114,32,105,105,32,45,32,104,117,101,121,39,115,32,97,100,118,101,110,116,117,114,101,32,40,106,112,110,41,32,40,115,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,131,111,7,26,33,0,16,0,112,104,97,110,116,97,115,121,32,115,116,97,114,32,105,105,32,45,32,97,110,110,101,39])
.concat([115,32,97,100,118,101,110,116,117,114,101,32,40,106,112,110,41,32,40,115,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,111,91,250,250,33,0,16,0,112,104,97,110,116,97,115,121,32,115,116,97,114,32,105,105,32,45,32,97,109,105,97,39,115,32,97,100,118,101,110,116,117,114,101,32,40,106,112,110,41,32,40,115,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,170,36,167,163,33,0,16,0,112,114,111,32,113,117,97,114,116,101,114,98,97,99,107,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,105,43,139,204,33,0,16,0,112,105,110,111,99,99,104,105,111,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,220,75,1,40,33,0,16,0,112,105,110,107,32,103,111,101,115,32,116,111,32,104,111,108,108,121,119,111,111,100,32,40,117,115,97,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,255,124,8,86,33,0,16,0,112,103,97,57,54,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,222,187,152,150,33,0,16,0,112,103,97,32,116,111,117,114,32,103,111,108,102,32,105,105,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,74,122,91,192,33,0,16,0,112,103,97,95,116,111,117,114,95,103,111,108,102,95,112,103,116,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,180,11,152,141,17,0,16,0,112,101,108,101,32,105,105,32,45,32,119,111,114,108,100,32,116,111,117,114,110,97,109,101,110,116,32,115,111,99,99,101,114,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,233,134,164,5,33,0,16,0,112,114,111,32,97,99,116,105,111,110,32,114,101,112,108,97,121,32,50,32,40,101,117,114,111,41,32,40,97,108,116,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,97,154,102,230,33,0,16,0,111,117,116,32,111,102,32,116,104,105,115,32,119,111,114,108,100,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,90,144,173,58,33,0,16,0,111,110,32,100,97,108,32,106,97,110,103,32,103,111,111,110,32,40,107,111,114,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,202,177,204,103,33,0,16,0,110,111,114,109,121,39,115,32,98,101,97,99,104,32,98,97,98,101,45,111,45,114,97,109,97,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,32,130,106,181,33,0,16,0,110,104,108,32,97,108,108,45,115,116,97,114,32,104,111,99,107,101,121,32,39,57,53,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,139,33,192,230,33,0,16,0,110,104,108,32,57,56,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,152,205,100,123,33,0,16,0,110,104,108,32,57,55,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,3,193,103,240,33,0,16,0,110,104,108,32,57,54,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,44,112,53,129,33,0,16,0,110,104,108,32,57,53,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,126,145,238,232,33,0,16,0,110,104,108,57,52,95,104,108,57,52,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,37,210,236,172,17,0,16,0,110,102,108,32,113,117,97,114,116,101,114,98,97,99,107,32,99,108,117,98,32,40,119,111,114,108,100,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,175,46,84,148,33,0,16,0,110,102,108,32,57,56,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,76,197,62,247,33,0,16,0,110,102,108,32,39,57,53,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,129,74,142,181,33,0,16,0,110,102,108,32,102,111,111,116,98,97,108,108,32,39,57,52,32,115,116,97,114,114,105,110,103,32,106,111,101,32,109,111,110,116,97,110,97,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,213,110,72,13,33,0,16,0,110,105,103,104,116,109,97,114,101,32,99,105,114,99,117,115,32,40,98,114,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,23,50,218,6,33,0,16,0,110,98,97,32,50,48,48,48,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,80,105,239,44,33,0,16,0,110,97,109,99,111,116,95,109,102,110,95,109,98,56,51,56,50,48,48,45,50,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,42,6,98,71,33,0,16,0,109,112,114,45,49,51,50,56,53,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,158,31,206,17,33,0,16,0,114,111,103,101,114,32,99,108,101,109,101,110,116,115,32,109,118,112,32,98,97,115,101,98,97,108,108,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,52,158,105,131,33,0,16,0,109,117,115,104,97,32,45,32,109,101,116,97,108,108,105,99,32,117,110,105,102,114,97,109,101,32,115,117,112,101,114,32,104,121,98,114,105,100,32,97,114,109,111,114,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,180,247,167,88,33,0,16,0,109,105,103,104,116,121,32,109,111,114,112,104,105,110,32,112,111,119,101,114,32,114,97,110,103,101,114,115,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,169,88,81,113,33,0,16,0,109,108,98,112,97,32,98,97,115,101,98,97,108,108,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,77,6,168,20,33,0,16,0,109,112,114,45,49,53,54,53,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,215,165,176,112,33,0,16,0,109,112,114,45,49,52,50,52,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,114,58,17,22,33,0,16,0,109,97,116,101,110,32,110,111,32,115,111,117,109,101,116,115,117,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,5,161,4,184,33,0,16,0,109,112,114,45,49,54,56,50,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,5,185,7,35,33,0,16,0,109,97,102,105,97,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,52,8,230,237,33,0,16,0,107,117,117,103,97,32,45,32,111,112,101,114,97,116,105,111,110,32,99,111,100,101,32,39,118,97,112,111,114,32,116,114,97,105,108,39,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,186,182,182,131,33,0,16,0,107,105,110,103,32,111,102,32,116,104,101,32,109,111,110,115,116,101,114,115,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,6,212,144,243,33,0,16,0,107,105,110,103,32,111,102,32,116,104,101,32,109,111,110,115,116,101,114,115,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,78,231,247,58,33,0,16,0,107,105,110,103,32,111,102,32,116,104,101,32,109,111,110,115,116,101,114,115,32,50,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,172,56,22,238,33,0,16,0,116,104,101,32,107,105,110,103,32,111,102,32,102,105,103,104,116,101,114,115,32,57,57,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,17,140,99,84,33,0,16,0,107,105,110,103,32,111,102,32,102,105,103,104,116,101,114,115,32,39,57,56,44,32,116,104,101,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,234,142,195,203,33,0,16,0,107,105,110,103,32,111,102,32,102,105,103,104,116,101,114,115,32,50,48,48,48,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,93,172,203,52,33,0,16,0,107,108,97,120,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,218,193,252,26,33,0,16,0,106,97,109,101,115,95,112,111,110,100,95,117,49,95,106,97,109,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,102,180,231,208,17,0,16,0,109,112,114,45,49,53,54,55,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,246,65,131,68,33,0,16,0,109,112,114,45,49,54,50,54,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,121,211,190,10,33,0,16,0,106,46,32,108,101,97,103,117,101,32,112,114,111,32,115,116,114,105,107,101,114,32,40,106,112,110,41,32,40,118,49,46,48,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,86,145,34,236,33,0,16,0,109,112,114,45,49,54,56,53,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,2,16,231,159,33,0,16,0,109,112,114,45,49,53,51,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,100,83,99,102,17,0,16,0,105,116,99,104,121,32,97,110,100,32,115,99,114,97,116,99,104,121,32,103,97,109,101,44,32,116,104,101,32,40,117,115,97,41,32,40,112,114,111,116,111,116,121,112,101,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,93,114,183,129,33,0,16,0,105,110,116,101,114,110,97,116,105,111,110,97,108,32,115,117,112,101,114,115,116,97,114,32,115,111,99,99,101,114,32,100,101,108,117,120,101,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,128,177,179,155,33,0,16,0,112,117,122,122,108,101,32,38,32,97,99,116,105,111,110,32,45,32,105,99,104,105,100,97,110,116,111,45,114,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,98,199,222,123,33,0,16,0,104,111,111,107,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,18,231,72,44,33,0,16,0,109,112,114,45,49,52,57,57,54,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,135,67,13,170,33,0,16,0,109,100,99,104,32,57,54,52,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,13,210,230,118,33,0,16,0,103,114,111,119,108,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,67,241,14,246,33,0,16,0,103,111,111,102,121,39,115,32,104,121,115,116,101,114,105,99,97,108,32,104,105,115,116,111,114,121,32,116,111,117,114,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,51,200,28,78,33,0,16,0,103,111,100,115,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,205,76,35,253,33,0,16,0,103,111,100,115,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,6,2,245,228,33,0,16,0,103,45,108,111,99,32,97,105,114,32,98,97,116,116,108,101,32,40,119,111,114,108,100,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,99,126,92,23,33,0,16,0,103,97,114,111,117,32,100,101,110,115,101,116,115,117,32,45,32,115,104,117,107,117,109,101,105,32,110,111,32,116,97,116,97,107,97,105,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,164,63,62,191,33,0,16,0,102,105,110,97,108,32,122,111,110,101,32,45,45,32,102,122,32,115,101,110,107,105,32,97,120,105,115,32,40,117,115,97,44,32,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,161,164,31,115,33,0,16,0,102,108,105,110,116,115,116,111,110,101,115,44,32,116,104,101,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,93,132,33,33,0,16,0,102,108,105,110,107,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,244,164,249,190,33,0,16,0,102,49,32,45,32,119,111,114,108,100,32,99,104,97,109,112,105,111,110,115,104,105,112,32,101,100,105,116,105,111,110,32,40,101,117,114,111,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,107,237,105,34,33,0,16,0,102,45,49,49,55,32,115,116,101,97,108,116,104,32,45,32,111,112,101,114,97,116,105,111,110,32,110,105,103,104,116,32,115,116,111,114,109,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,26,66,110,234,33,0,16,0,101,120,105,108,101,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,194,157,86,27,33,0,16,0,109,112,114,45,49,51,49,57,50,97,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,54,138,47,231,33,0,16,0,101,97,114,116,104,119,111,114,109,32,106,105,109,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,89,207,58,223,33,0,16,0,101,97,114,116,104,119,111,114,109,32,106,105,109,32,50,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,223,95,35,175,33,0,16,0,109,112,114,45,49,53,55,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,77,48,32,101,33,0,16,0,101,99,99,111,32,45,32,116,104,101,32,116,105,100,101,115,32,111,102,32,116,105,109,101,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,156,248,27,123,33,0,16,0,100,117,110,101,32,45,32,116,104,101,32,98,97,116,116,108,101,32,102,111,114,32,97,114,114,97,107,105,115,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,186,64,234,77,33,0,16,0,100,117,110,101,32,105,105,32,45,32,98,97,116,116,108,101,32,102,111,114,32,97,114,114,97,107,105,115,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,29,231,138,181,33,0,16,0,100,97,118,105,100,32,114,111,98,105,110,115,111,110,32,98,97,115,107,101,116,98,97,108,108,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,75,22,86,33,0,16,0,100,114,97,103,111,110,39,115,32,108,97,105,114,32,40,117,115,97,44,32,112,114,111,116,111,116,121,112,101,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,34,181,62,163,33,0,16,0,109,112,114,45,49,52,53,54,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,154,116,14,134,33,0,16,0,109,112,114,45,49,54,57,57,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,119,235,254,61,33,0,16,0,100,114,97,103,111,110,39,115,32,102,117,114,121,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,198,123,3,88,33,0,16,0,100,97,102,102,121,32,100,117,99,107,32,105,110,32,104,111,108,108,121,119,111,111,100,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,176,102,220,31,33,0,16,0,99,117,114,115,101,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,169,249,251,164,33,0,16,0,99,114,97,115,104,32,98,97,110,100,105,99,111,111,116,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,68,217,107,224,33,0,16,0,99,111,110,103,111,32,40,117,110,107,110,111,119,110,41,32,40,112,114,111,116,111,116,121,112,101,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,54,125,15,0,22,103,116,19,33,0,16,0,109,112,114,45,49,56,51,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,35,233,24,19,33,0,16,0,99,104,105,107,105,32,99,104,105,107,105,32,98,111,121,115,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,98,125,58,129,33,0,16,0,99,104,101,115,115,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,221,14,56,71,33,0,16,0,99,97,114,115,32,50,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,103,217,212,79,33,0,16,0,99,97,108,105,98,101,114,32,46,53,48,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,5,250,244,68,33,0,16,0,98,117,98,115,121,32,105,110,32,99,108,97,119,115,32,101,110,99,111,117,110,116,101,114,115,32,111,102,32,116,104,101,32,102,117,114,114,101,100,32,107,105,110,100,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,101,211,48,62,33,0,16,0,98,117,98,98,97,39,110,39,115,116,105,120,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,46,67,103,180,33,0,16,0,98,97,116,116,108,101,116,101,99,104,32,45,32,97,32,103,97,109,101,32,111,102,32,97,114,109,111,114,101,100,32,99,111,109,98,97,116,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,20,93,158,64,33,0,16,0,98,101,110,32,49,48,32,40,117,110,108,41,91,114,117,115,93,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,38,11,190,200,33,0,16,0,115,104,97,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,39,92,56,189,33,0,16,0,98,97,98,121,39,115,32,100,97,121,32,111,117,116,32,40,117,115,97,41,32,40,112,114,111,116,111,116,121,112,101,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,73,204,231,178,33,0,16,0,97,119,111,114,103,32,40,106,112,110,41,32,40,115,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,193,39,156,6,33,0,16,0,109,112,114,45,49,51,51,57,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,68,132,159,212,33,0,16,0,109,112,114,45,49,53,49,53,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,151,226,88,33,0,16,0,97,114,99,117,115,32,111,100,121,115,115,101,121,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,32,155,77,188,33,0,16,0,97,101,114,111,32,116,104,101,32,97,99,114,111,45,98,97,116,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,181,168,167,163,33,0,16,0,97,101,114,111,32,116,104,101,32,97,99,114,111,45,98,97,116,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,16,75,209,220,33,0,16,0,109,112,114,45,49,55,51,48,51,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,161,249,81,164,33,0,16,0,49,54,32,116,111,110,32,40,106,112,110,41,32,40,115,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,182,4,127,83,33,0,16,0,49,50,45,105,110,45,49,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,84,244,139,169,33,0,16,0,118,101,114,48,49,48,54,95,101,115,100,50,46,99,117,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,253,179,152,234,1,0,16,1,118,101,114,48,49,48,54,95,101,115,100,49,46,99,117,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,107,84,228,198,1,0,16,1,101,115,100,51,46,115,117,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,140,86,34,27,2,0,16,1,118,101,114,48,49,48,54,95,106,117,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,119,73,122,178,3,0,32,0,118,101,114,48,49,48,54,95,106,117,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,144,29,132,85,3,0,32,0,118,101,114,48,49,48,54,95,101,115,100,53,46,106,117,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,135,200,58,122,3,0,32,0,114,111,109,46,102,117,51,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,220,243,70,186,4,0,32,0,114,111,109,46,102,117,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,9,207,149,40,4,0,32,0,118,101,114,48,49,48,54,95,101,115,100,52,46,115,117,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,9,224,138,172,5,0,64,0,101,115,100,50,46,99,117,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,44,128,202,76,1,0,16,1,101,115,100,49,46,99,117,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,10,205,241,10,1,0,16,1,101,115,100,51,46,115,117,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,140,86,34,27,2,0,16,1,114,111,109,46,106,117,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,194,159,116,26,3,0,32,0,114,111,109,46,106,117,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,50,227,135,126,3,0,32,0,101,115,100,53,46,106,117,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,204,113,200,108,3,0,32,0,114,111,109,46,102,117,51,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,220,243,70,186,4,0,32,0,114,111,109,46,102,117,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,9,207,149,40,4,0,32,0,101,115,100,52,46,115,117,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,171,148,190,47,5,0,64,0,117,51,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,66,47,118,5,1,0,16,1,117,50,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,72,214,89,76,1,0,16,1,117,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,113,81,160,253,2,0,16,1,109,99,97,45,117,56,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,70,215,1,95,3,0,32,0,109,99,97,45,117,56,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,166,229,27,78,3,0,32,0,109,99,97,45,117,56,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,144,39,32,223,3,0,32,0,109,99,97,45,117,56,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,210,113,87,168,3,0,32,0,117,56,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,237,37,55,45,3,0,32,0,117,56,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,8,254,222,77,3,0,32,0,109,99,97,45,117,53,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,226,134,129,58,4,0,32,0,109,99,97,45,117,54,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,20,38,148,200,5,0,32,0,109,99,97,45,117,54,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,201,102,175,81,5,0,32,0,117,49,48,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,218,17,195,226,5,0,32,0,109,99,97,45,117,53,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,5,110,199,100,6,0,64,0,109,122,112,45,48,46,117,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,159,39,164,67,0,0,16,1,109,122,112,45,49,46,57,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,186,172,64,219,0,0,16,1,109,122,115,46,117,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,237,247,180,197,0,0,16,1,98,112,57,52,51,97,45,50,46,117,53,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,89,57,225,151,0,0,32,0,98,112,57,52,51,97,45,51,46,117,53,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,221,87,73,156,0,0,32,0,98,112,57,52,51,97,45,49,46,117,54,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,21,116,50,70,0,0,32,0,98,112,57,52,51,97,45,48,46,117,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,138,217,254,193,0,0,32,0,98,112,57,52,51,97,45,52,46,117,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,154,242,199,63,0,0,64,0,109,97,122,105,110,103,101,114,95,119,111,114,108,100,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,198,37,98,79,0,0,16,1,50,54,54,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,199,45,76,93,1,0,16,1,50,54,54,45,112,50,46,115,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,6,25,75,161,1,0,16,1,109,97,114,116,45,99,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,86,86,89,165,3,0,32,0,109,97,114,116,45,99,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,195,247,197,3,0,32,0,109,97,114,116,45,99,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,125,253,78,87,3,0,32,0,109,97,114,116,45,99,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,217,84,157,16,3,0,32,0,109,97,114,116,45,99,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,130,232,201,21,3,0,32,0,109,97,114,116,45,99,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,151,123,73,119,3,0,32,0,109,97,114,116,45,99,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,182,27,72,171,3,0,32,0,109,97,114,116,45,99,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,103,242,108,144,3,0,32,0,109,97,114,116,45,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,177,106,169,62,4,0,16,1,109,97,114,116,45,118,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,7,10,43,53,5,0,64,0,109,97,114,116,45,118,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,158,213,155,30,5,0,64,0,109,97,114,116,45,118,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,204,47,54,232,5,0,64,0,109,97,114,116,45,118,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,25,155,199,200,5,0,64,0,115,105,115,50,45,104,48,45,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,172,86,37,154,1,0,16,1,115,105,115,50,45,108,48,45,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,138,148,93,211,1,0,16,1,115,105,115,50,45,115,112,45,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,58,255,192,111,2,0,16,1,105,99,56,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,143,184,124,90,3,0,32,0,105,99,56,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,44,133,167,84,3,0,32,0,105,99,56,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,198,93,214,43,3,0,32,0,105,99,56,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,219,95,109,135,3,0,32,0,98,55,50,95,48,54,46,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,255,142,132,174,2,0,0,0,98,55,50,95,49,49,46,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,230,254,113,6,2,0,0,0,98,55,50,95,48,52,46,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,76,150,30,20,2,0,0,0,98,55,50,95,48,51,46,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,150,52,82,244,2,0,0,0,98,55,50,95,48,55,46,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,111,148,26,43,9,0,0,0,98,55,50,45,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,90,246,25,197,11,0,0,0,98,55,50,45,48,49,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,110,194,74,162,11,0,0,0,98,55,50,95,48,54,46,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,255,142,132,174,2,0,0,0,98,55,50,95,48,53,46,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,92,175,120,159,2,0,0,0,98,55,50,95,48,52,46,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,76,150,30,20,2,0,0,0,98,55,50,95,48,51,46,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,150,52,82,244,2,0,0,0,98,55,50,95,48,55,46,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,111,148,26,43,9,0,0,0,98,55,50,45,48,50,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,235,68,52,132,11,0,0,0,98,55,50,45,48,49,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,110,194,74,162,11,0,0,0,50,48,54,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,30,210,62,195,1,0,16,1,50,48,54,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,128,135,182,240,2,0,32,0,50,48,54,45,99,49,46,99])
.concat([49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,142,78,110,132,3,0,32,0,50,48,54,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,109,135,186,28,3,0,32,0,50,48,54,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,72,43,170,121,3,0,32,0,50,48,54,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,77,49,225,85,3,0,32,0,50,48,54,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,46,144,34,14,4,0,16,1,50,48,54,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,168,236,133,83,5,0,64,0,50,48,54,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,4,84,197,248,5,0,64,0,118,49,48,52,95,51,50,109,46,117,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,244,223,217,207,1,0,16,1,116,49,48,48,48,46,117,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,181,121,248,187,2,0,32,0,97,49,48,48,48,46,117,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,200,122,87,67,3,0,32,0,97,49,48,48,49,46,117,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,111,71,122,254,3,0,32,0,97,49,48,48,50,46,117,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,56,61,227,98,3,0,32,0,97,49,48,48,51,46,117,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,90,148,196,178,3,0,32,0,97,49,48,48,52,46,117,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,253,245,211,159,3,0,32,0,98,49,48,48,48,46,117,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,111,31,150,197,4,0,32,0,98,49,48,48,49,46,117,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,6,28,126,11,4,0,32,0,109,49,48,48,48,46,117,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,232,122,64,237,5,0,64,0,109,49,48,48,49,46,117,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,72,45,45,102,5,0,64,0,109,97,114,116,105,97,108,95,109,97,115,116,101,114,115,95,118,49,48,50,95,117,115,97,46,97,115,105,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,140,130,192,166,7,0,16,1,118,49,48,50,95,49,54,109,46,117,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,230,69,183,24,8,0,16,1,46,0,0,0,255,255,6,0,0,0,0,0,0,0,0,0,254,0,7,0,144,165,4,0,46,0,0,0,1,7,0,0,232,41,1,0,46,0,0,0,1,7,1,0,80,65,1,0,46,0,0,0,1,7,2,0,232,41,1,0,46,0,0,0,1,7,3,0,56,50,1,0,46,0,0,0,1,7,4,0,192,20,3,0,46,0,0,0,1,7,5,0,224,32,1,0,46,0,0,0,1,7,6,0,160,134,3,0,0,0,0,0,49,45,117,51,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,84,49,71,7,1,0,16,1,50,45,117,51,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,193,216,172,4,1,0,16,1,51,45,117,49,52,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,250,250,245,123,2,0,16,1,49,50,45,117,51,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,56,84,59,65,3,0,32,0,53,45,117,57,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,230,153,102,83,4,0,32,0,52,45,117,57,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,64,38,175,40,4,0,32,0,56,45,117,53,52,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,119,222,238,3,5,0,32,0,49,48,45,117,56,54,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,111,33,171,158,5,0,32,0,57,45,117,53,51,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,64,160,207,223,5,0,32,0,49,49,45,117,56,53,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,213,125,116,254,5,0,32,0,54,45,117,49,51,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,117,174,164,121,6,0,64,0,55,45,117,49,51,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,94,135,219,33,6,0,64,0,117,50,48,48,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,11,96,35,24,0,0,0,8,117,55,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,108,184,219,207,0,0,0,8,117,49,48,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,154,86,155,142,0,0,0,8,117,49,50,48,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,132,89,108,87,0,0,0,8,100,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,178,202,14,116,1,0,16,1,100,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,41,39,196,198,1,0,16,1,102,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,43,88,246,231,2,0,32,0,102,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,174,165,67,202,2,0,32,0,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,232,18,161,252,2,0,32,0,102,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,232,158,130,110,2,0,32,0,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,214,242,87,37,3,0,64,0,109,97,107,101,116,114,97,120,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,74,251,80,1,1,0,16,1,109,97,107,101,116,114,97,120,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,145,22,83,119,1,0,16,1,109,97,107,101,116,114,120,98,46,54,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,201,66,211,106,1,0,16,1,109,97,107,101,116,114,120,98,46,54,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,41,247,39,190,1,0,16,1,109,97,107,101,116,114,97,120,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,218,210,186,145,2,0,32,0,109,97,107,101,116,114,97,120,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,85,159,167,174,2,0,32,0,56,50,115,49,50,51,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,189,80,198,47,3,0,32,0,50,115,49,52,48,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,39,185,239,99,3,0,32,0,56,50,115,49,50,54,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,134,204,169,4,0,64,0,56,50,115,49,50,54,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,109,97,107,101,116,114,97,120,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,74,251,80,1,1,0,16,1,109,97,107,101,116,114,97,120,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,145,22,83,119,1,0,16,1,109,97,107,101,116,114,97,120,46,54,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,30,197,205,162,1,0,16,1,109,97,107,101,116,114,97,120,46,54,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,10,94,75,11,1,0,16,1,109,97,107,101,116,114,97,120,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,218,210,186,145,2,0,32,0,109,97,107,101,116,114,97,120,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,85,159,167,174,2,0,32,0,56,50,115,49,50,51,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,189,80,198,47,3,0,32,0,50,115,49,52,48,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,39,185,239,99,3,0,32,0,56,50,115,49,50,54,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,134,204,169,4,0,64,0,56,50,115,49,50,54,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,14,0,0,0,255,63,49,0,0,0,0,0,15,0,0,0,255,255,239,0,0,0,0,0,16,0,0,0,255,111,111,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,15,0,0,0,1,16,0,0,120,97,1,0,15,0,0,0,1,16,16,0,96,19,1,0,0,0,0,0,254,0,4,0,32,4,2,0,14,0,0,0,1,3,3,0,160,36,8,0,14,0,0,0,1,3,1,0,208,239,7,0,14,0,0,0,1,3,2,0,120,187,7,0,14,0,0,0,1,3,0,0,16,227,4,0,0,0,0,0,254,0,4,0,128,129,4,0,14,0,0,0,1,12,0,0,8,49,4,0,14,0,0,0,1,12,4,0,152,21,4,0,14,0,0,0,1,12,8,0,72,246,3,0,14,0,0,0,1,12,12,0,72,0,3,0,0,0,0,0,254,0,2,0,184,112,3,0,14,0,0,0,1,48,16,0,80,246,3,0,14,0,0,0,1,48,0,0,112,212,3,0,0,0,0,0,254,0,2,0,184,109,3,0,14,0,0,0,1,32,32,0,96,135,7,0,14,0,0,0,1,32,0,0,152,182,7,0,109,116,95,104,48,45,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,103,219,170,54,1,0,16,1,109,116,95,108,48,45,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,66,98,27,46,1,0,16,1,109,116,95,104,49,45,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,34,42,64,225,1,0,16,1,109,116,95,108,49,45,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,154,64,250,14,1,0,16,1,109,116,95,115,112,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,169,96,66,228,6,0,16,1,109,116,95,110,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,220,205,24,86,2,0,32,0,109,116,95,110,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,59,135,59,72,2,0,32,0,109,116,95,110,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,91,102,93,79,2,0,32,0,109,116,95,110,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,73,21,87,131,2,0,32,0,109,116,95,99,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,2,122,14,120,3,0,32,0,109,116,95,99,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,129,19,173,69,3,0,32,0,109,116,95,99,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,109,133,245,93,3,0,32,0,109,116,95,99,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,200,108,49,245,3,0,32,0,109,116,95,102,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,213,5,94,45,14,0,32,0,109,116,95,102,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,95,214,140,198,14,0,32,0,109,116,95,102,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,45,235,31,167,14,0,32,0,109,116,95,102,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,98,117,159,23,14,0,32,0,109,116,95,118,111,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,44,187,36,235,5,0,64,0,109,116,50,45,104,48,45,98,46,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,46,177,99,177,1,0,16,1,109,116,50,45,108,48,45,98,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,157,93,59,111,1,0,16,1,105,115,45,104,49,46,53,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,242,225,168,155,1,0,16,1,105,115,45,108,49,46,53,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,38,6,224,228,1,0,16,1,109,116,50,115,104,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,67,234,203,30,2,0,16,1,109,116,50,115,108,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,49,181,213,143,2,0,16,1,99,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,181,228,97,126,3,0,32,0,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,100,117,102,10,3,0,32,0,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,18,67,180,94,3,0,32,0,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,148,98,134,242,3,0,32,0,107,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,120,38,154,140,4,0,32,0,107,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,120,223,85,84,4,0,32,0,107,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,65,140,37,58,4,0,32,0,107,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,20,26,233,193,4,0,32,0,100,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,159,158,59,113,5,0,64,0,109,116,50,101,101,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,113,249,138,32,6,0,16,1,112,97,108,49,54,108,56,45,109,57,50,45,97,45,51,109,46,105,99,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,7,0,0,16,112,97,108,49,54,108,56,45,109,57,50,45,97,45,55,106,46,105,99,52,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,7,0,0,16,112,97,108,49,54,108,56,45,109,57,50,45,97,45,57,106,46,105,99,53,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,7,0,0,16,112,97,108,49,54,108,56,45,109,57,50,45,98,45,50,108,46,105,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,7,0,0,16,112,97,108,49,54,108,56,45,109,57,50,45,98,45,55,104,46,105,99,52,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,7,0,0,16,55,57,57,102,48,50,46,107,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,107,89,67,193,1,0,16,1,55,57,57,99,48,49,46,102,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,92,76,124,68,2,0,16,1,55,57,57,99,48,54,46,102,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,88,203,57,248,3,0,32,0,55,57,57,99,48,55,46,104,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,56,245,109,23,3,0,32,0,55,57,57,99,48,56,46,106,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,120,0,30,208,3,0,32,0,55,57,57,99,48,57,46,107,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,94,199,174,155,3,0,32,0,55,57,57,98,48,52,46,104,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,43,12,62,50,4,0,32,0,55,57,57,98,48,53,46,107,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,49,88,28,87,4,0,32,0,55,57,57,98,48,51,46,100,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,66,211,207,241,5,0,64,0,55,57,57,98,48,54,46,99,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,215,71,140,44,6,0,32,0,54,51,115,49,52,49,110,46,107,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,209,200,246,97,7,0,0,8,48,48,52,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,219,83,111,252,1,0,16,1,48,48,52,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,6,90,208,43,2,0,32,0,48,48,52,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,188,22,174,241,3,0,32,0,48,48,52,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,32,53,193,189,3,0,32,0,48,48,52,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,55,26,87,156,3,0,32,0,48,48,52,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,41,203,129,126,3,0,32,0,48,48,52,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,59,187,31,199,4,0,16,1,48,48,52,45,118,49,49,46,118,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,83,33,251,178,5,0,64,0,48,48,52,45,118,49,50,46,118,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,123,49,3,133,5,0,64,0,48,48,52,45,118,50,49,46,118,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,251,153,73,6,0,64,0,48,48,52,45,118,50,50,46,118,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,162,162,111,119,6,0,64,0,48,48,52,45,118,50,51,46,118,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,234,238,231,179,6,0,64,0,114,97,95,109,97,95,48,49,95,48,49,46,117,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,92,204,12,151,0,0,16,1,114,97,45,109,97,48,49,45,114,111,109,50,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,149,189,226,84,0,0,32,0,114,97,45,109,97,48,49,45,114,111,109,51,46,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,143,55,205,33,0,0,32,0,114,97,95,109,97,95,48,49,95,48,53,46,117,56,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,128,30,13,192,0,0,32,0,114,97,45,109,97,45,48,49,95,48,50,46,117,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,109,164,191,234,0,0,16,1,114,97,45,109,97,48,49,45,114,111,109,49,46,117,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,184,42,219,110,0,0,64,0,48,48,53,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,197,67,144,89,1,0,16,1,48,48,53,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,162,105,83,28,2,0,32,0,48,48,53,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,52,238,106,128,3,0,32,0,48,48,53,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,134,154,170,52,3,0,32,0,48,48,53,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,38,185,194,196,3,0,32,0,48,48,53,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,244,220,70,156,3,0,32,0,48,48,53,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,109,8,105,3,0,32,0,48,48,53,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,66,193,122,171,3,0,32,0,48,48,53,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,15,159,37,38,4,0,16,1,48,48,53,45,118,49,49,46,118,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,253,85,4,204,5,0,64,0,48,48,53,45,118,50,49,46,118,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,183,181,74,249,6,0,64,0,48,48,53,45,118,50,50,46,118,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,4,253,44,35,6,0,64,0,109,97,103,98,117,98,108,101,46,117,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,130,213,253,24,1,0,16,1,109,97,103,98,117,98,108,101,46,117,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,4,112,234,246,1,0,16,1,109,97,103,98,117,98,108,101,46,49,52,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,83,39,25,4,2,0,16,1,109,97,103,98,117,98,108,101,46,117,54,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,125,229,85,99,3,0,32,0,109,97,103,98,117,98,108,101,46,117,54,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,43,108,174,83,3,0,32,0,109,97,103,98,117,98,108,101,46,117,54,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,76,230,146,184,3,0,32,0,109,97,103,98,117,98,108,101,46,117,55,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,55,72,121,55,3,0,32,0,109,97,103,98,117,98,108,101,46,117,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,140,59,14,247,4,0,32,0,109,97,103,98,117,98,108,101,46,117,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,243,44,8,173,4,0,32,0,109,97,103,98,117,98,108,101,46,117,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,122,223,104,124,4,0,32,0,109,97,103,98,117,98,108,101,46,117,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,193,63,118,199,4,0,32,0,109,97,103,98,117,98,108,101,46,49,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,137,78,224,3,5,0,64,0,114,122,48,48,45,49,46,101,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,57,246,202,40,1,0,16,1,109,99,99,45,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,236,3,107,100,2,0,32,0,109,99,99,45,48,49,46,97,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,69,135,216,19,3,0,32,0,109,99,99,45,48,50,46,97,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,38,113,249,208,3,0,32,0,109,99,99,45,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,222,106,238,134,4,0,64,0,109,99,99,45,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,160,187,46,218,5,0,64,0,101,101,112,114,111,109,46,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,221,158,61,209,6,0,16,1,50,51,51,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,250,23,30,147,1,0,16,1,50,51,51,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,138,230,153,115,2,0,32,0,50,51,51,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,196,244,227,101,3,0,32,0,50,51,51,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,201,166,222,53,3,0,32,0,50,51,51,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,2,197,162,11,3,0,32,0,50,51,51,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,109,189,219,112,3,0,32,0,50,51,51,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,78,243,234,91,4,0,16,1,50,51,51,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,152,146,131,88,5,0,64,0,50,51,51,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,244,13,227,213,5,0,64,0,50,50,49,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,83,35,232,123,1,0,16,1,50,50,49,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,163,99,64,42,2,0,32,0,50,50,49,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,20,42,134,31,3,0,32,0,50,50,49,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,54,5,185,20,3,0,32,0,50,50,49,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,40,230,218,189,4,0,16,1,50,50,49,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,228,83,94,126,5,0,64,0,102,113,48,48,49,48,48,50,46,50,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,17,168,134,66,1,0,16,1,102,113,48,48,49,48,48,49,46,50,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,173,160,191,56,1,0,16,1,102,113,48,48,49,48,48,52,46,50,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,94,27,106,229,3,0,32,0,102,113,48,48,49,48,48,54,46,49,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,228,232,197,59,4,0,32,0,102,113,48,48,49,48,48,53,46,50,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,74,109,108,95,28,0,32,0,102,113,48,48,49,48,48,55,46,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,19,60,179,228,6,0,64,0,109,99,114,115,50,106,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,254,24,166,54,1,0,16,1,109,99,114,115,50,106,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,199,138,170,180,2,0,16,1,109,99,114,115,50,106,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,16,116,65,199,3,0,32,0,98,112,57,51,50,97,110,46,97,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,240,127,215,196,4,0,32,0,98,112,57,51,50,97,110,46,97,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,185,33,27,170,5,0,32,0,98,112,57,51,50,97,110,46,97,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,1,41,235,103,5,0,32,0,98,112,57,51,50,97,110,46,97,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,192,254,15,239,6,0,64,0,98,112,57,51,50,97,110,46,97,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,187,90,51,181,7,0,64,0,109,99,114,115,50,98,112,114,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,162,83,86,67,0,0,0,8,109,99,114,115,50,98,112,114,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,73,211,234,230,0,0,0,8,97,95,48,54,99,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,56,167,104,32,1,0,16,1,97,95,48,55,99,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,196,237,162,214,1,0,16,1,57,99,95,108,119,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,1,194,92,236,1,0,16,1,49,49,101,95,108,119,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,162,55,3,162,2,0,16,1,57,104,95,108,119,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,60,146,29,9,4,0,32,0,98,95,48,51,101,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,39,48,110,23,5,0,32,0,98,95,48,49,101,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,35,86,210,245,5,0,32,0,98,95,48,51,100,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,53,170,28,0,5,0,32,0,98,95,48,49,100,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,195,8,160,11,5,0,32,0,98,95,48,51,98,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,233,130,129,79,5,0,32,0,98,95,48,49,98,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,116,115,97,241,5,0,32,0,98,95,48,51,102,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,204,77,55,155,5,0,32,0,98,95,48,49,102,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,10,78,101,35,5,0,32,0,98,95,48,51,106,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,58,118,60,143,6,0,32,0,98,95,48,49,106,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,29,10,201,124,6,0,32,0,98,95,48,51,104,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,50,245,88,125,6,0,32,0,98,95,48,49,104,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,218,110,57,62,6,0,32,0,54,51,115,49,52,49,46,49,53,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,152,204,107,217,0,0,0,8,114,111,109,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,158,68,251,196,1,0,16,1,114,111,109,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,26,106,68,93,1,0,16,1,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,229,204,60,34,2,0,16,1,114,111,109,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,186,148,235,238,3,0,32,0,114,111,109,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,129,30,85,199,4,0,64,0,114,111,109,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,94,255,72,227,4,0,64,0,108,111,118,101,114,46,114,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,65,78,236,255,1,0,16,1,108,111,118,101,114,46,114,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,98,34,5,4,1,0,16,1,108,111,118,101,114,46,114,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,73,59,95,206,1,0,16,1,108,111,118,101,114,46,114,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,183,121,157,131,1,0,16,1,108,111,118,101,114,46,115,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,28,17,56,236,2,0,16,1,108,111,118,101,114,46,112,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,143,156,81,26,3,0,32,0,108,111,118,101,114,46,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,47,55,101,228,3,0,32,0,108,111,118,101,114,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,126,216,160,205,3,0,32,0,99,111,108,111,114,46,110,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,174,22,74,207,4,0,32,0,99,111,108,111,114,46,110,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,33,172,17,75,4,0,32,0,108,111,103,105,99,112,114,111,46,114,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,132,212,6,197,1,0,16,1,108,111,103,105,99,112,114,111,46,114,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,98,207,164,213,1,0,16,1,108,111,103,105,99,112,114,111,46,114,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,75,98,13,0,2,0,16,1,108,111,103,105,99,112,114,111,46,114,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,201,24,223,222,3,0,32,0,108,111,103,105,99,112,114,111,46,114,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,194,209,203,62,3,0,32,0,108,111,103,105,99,112,114,111,46,114,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,33,85,19,71,3,0,32,0,108,111,103,105,99,112,114,111,46,114,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,210,193,139,169,4,0,32,0,108,111,103,105,99,112,114,111,46,114,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,152,98,228,29,4,0,32,0,108,111,103,105,99,112,114,111,46,114,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,212,196,254,161,5,0,64,0,108,112,50,45,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,191,128,24,204,1,0,16,1,108,112,50,45,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,84,233,213,70,1,0,16,1,108,111,103,50,45,98,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,7,158,120,254,3,0,32,0,108,111,103,50,45,98,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,205,81,12,30,3,0,32,0,108,111,103,50,45,98,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,40,41,111,145,3,0,32,0,111,98,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,5,243,33,242,4,0,32,0,108,111,103,50,45,115,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,53,196,117,40,5,0,64,0,49,98,46,117,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,134,34,233,250,1,0,16,1,50,98,46,117,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,192,36,36,254,1,0,16,1,48,108,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,93,133,174,204,2,0,32,0,48,104,46,117,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,89,108,20,122,2,0,32,0,49,108,46,117,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,30,210,156,122,2,0,32,0,49,104,46,117,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,13,13,244,120,2,0,32,0,115,110,100,48,46,117,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,143,120,163,45,3,0,64,0,184,40,2,0,1,0,0,0,85,0,147,0,248,191,2,0,184,164,8,0,1,0,0,0,87,0,147,0,64,246,1,0,56,250,6,0,1,0,0,0,189,247,146,0,184,160,2,0,88,149,7,0,1,0,0,0,190,247,146,0,136,224,1,0,56,210,6,0,1,0,0,0,80,0,147,0,192,135,2,0,152,122,6,0,1,0,0,0,81,0,147,0,96,82,2,0,192,72,6,0,1,0,0,0,82,0,147,0,32,56,2,0,24,163,6,0,1,0,0,0,83,0,147,0,240,108,2,0,200,110,3,0,1,0,0,0,188,247,146,0,152,30,2,0,176,223,1,0,1,0,0,0,184,247,146,0,72,198,1,0,24,198,1,0,1,0,0,0,185,247,146,0,40,167,1,0,120,189,1,0,1,0,0,0,186,247,146,0,200,149,1,0,192,209,1,0,1,0,0,0,187,247,146,0,24,182,1,0,224,22,1,0,1,0,0,0,191,247,146,0,56,126,1,0,88,212,3,0,1,0,0,0,128,219,146,0,40,185,3,0,232,75,4,0,1,0,0,0,84,0,147,0,216,70,1,0,56,58,1,0,1,0,0,0,86,0,147,0,64,50,1,0,160,193,3,0,9,0,0,0,202,5,147,0,32,58,1,0,104,20,5,0,9,0,0,0,200,5,147,0,32,58,1,0,216,16,5,0,9,0,0,0,201,5,147,0,32,58,1,0,88,12,5,0,9,0,0,0,203,5,147,0,32,58,1,0,102,108,97,115,104,46,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,147,68,196,142,1,0,16,1,109,97,105,110,95,112,105,99,49,50,99,53,48,56,97,46,117,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,126,10,79,168,2,0,16,8,115,117,98,95,112,105,99,49,50,99,53,48,56,97,46,117,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,196,189,46,229,2,0,16,8,102,108,97,115,104,46,117,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,241,86,235,214,3,0,32,0,102,108,97,115,104,46,117,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,115,216,159,76,3,0,32,0,102,108,97,115,104,46,117,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,50,21,168,218,3,0,32,0,102,108,97,115,104,46,117,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,199,168,64,181,3,0,32,0,50,55,99,52,48,57,54,46,117,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,232,29,18,37,4,0,32,0,102,108,97,115,104,46,117,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,146,39,6,220,5,0,64,0,57,51,57,107,48,50,46,101,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,83,250,254,45,0,0,16,1,57,51,57,107,48,51,46,101,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,84,196,240,20,0,0,16,1,57,51,57,101,48,49,46,100,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,72,200,95,74,0,0,16,1,57,51,57,97,48,55,46,107,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,207,223,85,121,0,0,32,0,57,51,57,97,48,56,46,107,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,133,179,149,237,0,0,32,0,57,51,57,97,48,54,46,107,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,6,194,147,227,0,0,32,0,57,51,57,97,48,53,46,107,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,122,212,98,54,0,0,32,0,57,51,57,97,48,52,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,110,43,78,194,0,0,64,0,108,116,95,100,45,104,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,53,137,198,32,1,0,16,1])
.concat([108,116,95,100,45,108,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,179,47,67,225,1,0,16,1,108,116,95,100,45,104,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,72,61,221,215,1,0,16,1,108,116,95,100,45,108,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,216,59,75,185,1,0,16,1,108,116,95,100,45,115,104,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,79,34,91,175,2,0,16,1,108,116,95,100,45,115,108,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,195,170,63,203,2,0,16,1,108,116,95,55,97,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,80,253,160,173,3,0,32,0,108,116,95,55,98,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,131,104,89,210,3,0,32,0,108,116,95,55,100,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,239,55,230,45,3,0,32,0,108,116,95,55,104,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,205,133,101,159,3,0,32,0,108,116,95,55,106,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,62,134,248,186,4,0,32,0,108,116,95,55,108,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,175,80,253,64,4,0,32,0,108,116,95,55,115,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,223,112,233,200,4,0,32,0,108,116,95,55,121,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,8,103,67,245,4,0,32,0,108,116,95,56,97,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,162,98,119,53,5,0,64,0,108,101,109,109,105,110,103,115,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,57,180,162,233,1,0,16,1,108,101,109,109,105,110,103,115,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,59,41,82,191,1,0,16,1,108,101,109,109,105,110,103,115,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,234,192,61,14,1,0,16,1,108,101,109,109,105,110,103,115,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,206,215,243,12,1,0,16,1,108,101,109,109,105,110,103,115,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,156,33,32,208,1,0,16,1,108,101,109,109,105,110,103,115,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,74,73,53,198,1,0,16,1,108,101,109,109,105,110,103,115,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,206,102,145,1,0,16,1,108,101,109,109,105,110,103,115,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,136,84,132,170,1,0,16,1,108,101,109,109,105,110,103,115,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,53,74,178,240,2,0,16,1,108,101,109,109,105,110,103,115,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,245,66,100,224,3,0,32,0,108,101,109,109,105,110,103,115,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,72,136,57,54,3,0,32,0,108,101,109,109,105,110,103,115,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,229,84,106,180,3,0,32,0,108,101,109,109,105,110,103,115,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,255,71,144,220,4,0,32,0,108,101,109,109,105,110,103,115,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,145,84,193,124,4,0,32,0,108,101,109,109,105,110,103,115,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,143,120,98,193,4,0,32,0,108,101,109,109,105,110,103,115,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,124,132,71,247,5,0,64,0,48,50,57,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,25,63,86,157,1,0,16,1,48,50,57,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,240,2,213,188,2,0,32,0,48,50,57,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,117,184,90,47,3,0,32,0,48,50,57,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,17,39,139,49,3,0,32,0,48,50,57,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,178,44,197,107,3,0,32,0,48,50,57,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,140,41,239,55,3,0,32,0,48,50,57,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,240,67,40,111,4,0,16,1,48,50,57,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,82,84,6,133,5,0,64,0,48,49,57,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,69,132,222,162,1,0,16,1,48,49,57,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,237,192,205,95,2,0,32,0,48,49,57,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,239,205,76,3,0,32,0,48,49,57,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,2,8,221,212,3,0,32,0,48,49,57,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,125,193,104,213,4,0,16,1,48,49,57,45,118,49,49,46,118,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,114,72,183,15,5,0,64,0,48,49,57,45,118,49,50,46,118,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,87,170,159,2,5,0,64,0,48,49,57,45,118,50,49,46,118,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,218,90,253,46,6,0,64,0,104,100,54,51,48,49,118,49,112,46,99,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,24,49,51,52,45,112,49,107,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,101,48,111,144,1,0,16,1,50,51,52,45,112,50,46,115,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,158,40,220,15,1,0,16,1,50,51,52,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,18,20,86,149,2,0,32,0,50,51,52,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,211,43,126,159,3,0,32,0,50,51,52,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,60,61,98,128,3,0,32,0,50,51,52,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,48,26,171,145,3,0,32,0,50,51,52,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,55,176,96,61,3,0,32,0,50,51,52,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,238,12,168,27,3,0,32,0,50,51,52,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,145,208,175,190,3,0,32,0,50,51,52,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,234,40,118,8,4,0,16,1,50,51,52,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,111,183,102,237,5,0,64,0,50,51,52,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,226,246,231,160,5,0,64,0,50,51,52,45,118,51,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,226,225,6,165,5,0,64,0,50,51,52,45,118,52,46,118,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,127,21,52,14,5,0,64,0,108,109,95,100,108,48,51,46,49,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,107,95,127,53,1,0,0,0,108,109,95,100,108,48,52,46,55,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,82,21,234,125,1,0,0,0,108,109,95,100,108,48,50,46,49,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,175,93,155,236,2,0,0,0,100,108,48,53,45,46,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,192,248,93,26,3,0,0,0,100,108,48,49,45,46,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,93,122,120,243,4,0,0,0,100,108,49,49,45,46,49,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,59,157,87,54,5,0,0,0,100,108,49,50,45,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,126,115,166,43,5,0,0,0,100,108,49,51,45,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,147,220,167,57,5,0,0,0,100,108,49,48,45,46,49,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,168,94,39,254,5,0,0,0,100,108,48,57,45,46,49,50,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,93,12,90,106,6,0,0,0,100,108,48,56,45,46,49,52,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,206,207,56,59,6,0,0,0,100,108,48,55,45,46,49,53,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,77,96,96,27,6,0,0,0,100,108,48,54,45,46,49,55,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,167,38,60,196,6,0,0,0,105,100,56,55,53,49,104,46,109,99,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,7,0,0,16,100,108,45,49,52,46,57,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,18,170,85,46,8,0,0,0,100,108,48,51,45,46,49,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,225,231,229,75,1,0,0,0,100,108,48,52,45,46,55,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,249,173,38,240,1,0,0,0,100,108,48,50,45,46,49,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,93,43,222,208,2,0,0,0,100,108,48,53,45,46,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,192,248,93,26,3,0,0,0,100,108,48,49,45,46,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,93,122,120,243,4,0,0,0,100,108,49,49,45,46,49,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,59,157,87,54,5,0,0,0,100,108,49,50,45,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,126,115,166,43,5,0,0,0,100,108,49,51,45,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,147,220,167,57,5,0,0,0,100,108,49,48,45,46,49,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,168,94,39,254,5,0,0,0,100,108,48,57,45,46,49,50,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,93,12,90,106,6,0,0,0,100,108,48,56,45,46,49,52,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,206,207,56,59,6,0,0,0,100,108,48,55,45,46,49,53,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,77,96,96,27,6,0,0,0,100,108,48,54,45,46,49,55,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,167,38,60,196,6,0,0,0,105,100,56,55,53,49,104,46,109,99,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,7,0,0,16,100,108,45,49,52,46,57,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,18,170,85,46,8,0,0,0,100,108,48,51,45,54,46,49,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,94,26,117,71,1,0,0,0,108,109,95,100,108,48,52,46,55,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,82,21,234,125,1,0,0,0,108,109,95,100,108,48,50,46,49,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,175,93,155,236,2,0,0,0,100,108,48,53,45,46,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,192,248,93,26,3,0,0,0,100,108,48,49,45,46,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,93,122,120,243,4,0,0,0,100,108,49,49,45,46,49,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,59,157,87,54,5,0,0,0,100,108,49,50,45,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,126,115,166,43,5,0,0,0,100,108,49,51,45,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,147,220,167,57,5,0,0,0,100,108,49,48,45,46,49,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,168,94,39,254,5,0,0,0,100,108,48,57,45,46,49,50,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,93,12,90,106,6,0,0,0,100,108,48,56,45,46,49,52,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,206,207,56,59,6,0,0,0,100,108,48,55,45,46,49,53,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,77,96,96,27,6,0,0,0,100,108,48,54,45,46,49,55,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,167,38,60,196,6,0,0,0,105,100,56,55,53,49,104,46,109,99,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,7,0,0,16,100,108,45,49,52,46,57,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,18,170,85,46,8,0,0,0,50,52,51,45,112,103,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,84,101,30,175,1,0,16,1,50,52,51,45,112,103,50,46,115,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,11,163,212,173,1,0,16,1,50,52,51,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,152,34,205,201,2,0,32,0,50,52,51,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,77,68,57,88,3,0,32,0,50,52,51,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,40,116,8,221,3,0,32,0,50,52,51,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,224,203,84,96,3,0,32,0,50,52,51,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,210,169,210,139,3,0,32,0,50,52,51,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,207,61,80,106,3,0,32,0,50,52,51,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,208,54,156,236,3,0,32,0,50,52,51,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,16,45,241,172,4,0,16,1,50,52,51,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,187,111,238,247,5,0,64,0,50,52,51,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,246,77,158,170,5,0,64,0,50,52,51,45,118,51,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,178,80,199,74,5,0,64,0,50,52,51,45,118,52,46,118,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,166,75,198,245,5,0,64,0,50,51,52,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,163,165,35,225,1,0,16,1,50,51,52,45,112,50,46,115,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,158,40,220,15,1,0,16,1,50,51,52,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,18,20,86,149,2,0,32,0,50,51,52,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,211,43,126,159,3,0,32,0,50,51,52,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,60,61,98,128,3,0,32,0,50,51,52,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,48,26,171,145,3,0,32,0,50,51,52,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,55,176,96,61,3,0,32,0,50,51,52,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,238,12,168,27,3,0,32,0,50,51,52,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,145,208,175,190,3,0,32,0,50,51,52,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,234,40,118,8,4,0,16,1,50,51,52,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,111,183,102,237,5,0,64,0,50,51,52,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,226,246,231,160,5,0,64,0,50,51,52,45,118,51,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,226,225,6,165,5,0,64,0,50,51,52,45,118,52,46,118,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,127,21,52,14,5,0,64,0,108,110,115,113,45,112,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,154,135,10,180,1,0,16,1,108,110,115,113,45,112,50,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,66,45,219,236,1,0,16,1,108,110,115,113,45,112,50,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,231,226,197,250,1,0,16,1,108,110,115,113,45,115,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,151,40,232,57,2,0,32,0,108,110,115,113,45,99,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,159,229,61,184,3,0,32,0,108,110,115,113,45,99,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,253,105,137,224,3,0,32,0,108,110,115,113,45,99,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,218,44,63,1,3,0,32,0,108,110,115,113,45,99,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,88,167,195,216,3,0,32,0,108,110,115,113,45,99,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,130,11,80,117,3,0,32,0,108,110,115,113,45,99,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,59,193,10,103,3,0,32,0,50,52,54,45,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,209,74,96,208,4,0,16,1,108,110,115,113,45,118,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,195,235,8,68,5,0,64,0,108,110,115,113,45,118,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,117,57,149,61,5,0,64,0,108,110,115,113,45,118,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,142,29,125,67,5,0,64,0,108,98,49,97,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,84,94,19,236,1,0,16,1,108,98,50,97,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,198,197,73,48,1,0,16,1,108,98,51,97,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,55,248,254,176,1,0,16,1,108,52,46,104,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,215,36,196,255,1,0,16,1,108,53,46,106,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,9,248,106,173,1,0,16,1,108,98,54,97,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,42,0,200,136,1,0,16,1,108,57,46,102,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,30,218,177,119,2,0,32,0,108,48,46,104,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,11,224,130,170,2,0,32,0,108,56,46,108,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,11,145,153,139,3,0,32,0,108,55,46,109,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,72,180,165,134,3,0,32,0,49,48,45,50,46,107,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,82,30,9,223,4,0,32,0,49,48,45,49,46,102,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,143,13,100,64,4,0,32,0,49,48,45,51,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,80,58,250,39,4,0,32,0,108,98,49,98,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,101,30,214,53,1,0,16,1,108,98,50,98,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,228,15,62,161,1,0,16,1,108,98,51,98,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,22,199,138,238,1,0,16,1,108,52,46,104,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,215,36,196,255,1,0,16,1,108,53,46,106,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,9,248,106,173,1,0,16,1,108,98,54,98,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,137,110,144,220,1,0,16,1,108,57,46,102,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,30,218,177,119,2,0,32,0,108,48,46,104,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,11,224,130,170,2,0,32,0,108,56,46,108,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,11,145,153,139,3,0,32,0,108,55,46,109,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,72,180,165,134,3,0,32,0,49,48,45,50,46,107,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,82,30,9,223,4,0,32,0,49,48,45,49,46,102,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,143,13,100,64,4,0,32,0,49,48,45,51,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,80,58,250,39,4,0,0,8,100,101,95,112,48,54,48,57,46,51,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,127,98,123,59,1,0,16,1,116,48,54,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,214,26,204,74,2,0,32,0,97,48,54,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,52,120,22,216,3,0,32,0,97,48,54,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,115,67,122,255,3,0,32,0,97,48,54,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,89,41,163,231,3,0,32,0,97,48,54,48,51,120,97,115,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,126,179,87,112,3,0,32,0,98,48,54,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,89,208,60,125,4,0,32,0,98,48,54,48,49,120,97,115,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,73,251,132,55,4,0,32,0,109,48,54,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,64,0,214,79,218,58,5,0,64,0,107,111,118,115,104,95,118,49,48,48,95,99,104,105,110,97,46,97,115,105,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,193,165,9,15,7,0,16,1,46,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,6,0,144,165,4,0,46,0,0,0,1,15,0,0,232,41,1,0,46,0,0,0,1,15,1,0,80,65,1,0,46,0,0,0,1,15,2,0,176,20,3,0,46,0,0,0,1,15,3,0,56,50,1,0,46,0,0,0,1,15,4,0,192,20,3,0,46,0,0,0,1,15,5,0,224,32,1,0,112,48,54,48,48,46,49,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,130,218,179,240,1,0,16,1,116,48,54,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,214,26,204,74,2,0,32,0,97,48,54,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,52,120,22,216,3,0,32,0,97,48,54,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,115,67,122,255,3,0,32,0,97,48,54,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,89,41,163,231,3,0,32,0,97,48,54,48,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,218,171,49,236,3,0,32,0,97,48,54,48,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,211,159,181,38,3,0,32,0,98,48,54,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,89,208,60,125,4,0,32,0,98,48,54,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,47,28,187,160,4,0,32,0,98,48,54,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,52,121,247,157,4,0,32,0,109,48,54,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,214,79,218,58,5,0,64,0,107,111,118,115,104,95,118,49,48,48,95,99,104,105,110,97,46,97,115,105,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,193,165,9,15,7,0,16,1,112,48,54,48,48,46,49,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,15,251,212,253,1,0,16,1,116,48,54,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,214,26,204,74,2,0,32,0,97,48,54,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,52,120,22,216,3,0,32,0,97,48,54,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,115,67,122,255,3,0,32,0,97,48,54,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,89,41,163,231,3,0,32,0,97,48,54,48,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,218,171,49,236,3,0,32,0,97,48,54,48,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,211,159,181,38,3,0,32,0,98,48,54,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,89,208,60,125,4,0,32,0,98,48,54,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,47,28,187,160,4,0,32,0,98,48,54,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,52,121,247,157,4,0,32,0,109,48,54,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,214,79,218,58,5,0,64,0,107,111,118,115,104,95,118,49,48,48,95,99,104,105,110,97,46,97,115,105,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,193,165,9,15,7,0,16,1,112,48,54,48,48,46,49,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,207,155,122,81,1,0,16,1,116,48,54,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,214,26,204,74,2,0,32,0,97,48,54,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,52,120,22,216,3,0,32,0,97,48,54,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,115,67,122,255,3,0,32,0,97,48,54,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,89,41,163,231,3,0,32,0,97,48,54,48,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,218,171,49,236,3,0,32,0,97,48,54,48,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,211,159,181,38,3,0,32,0,98,48,54,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,89,208,60,125,4,0,32,0,98,48,54,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,47,28,187,160,4,0,32,0,98,48,54,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,52,121,247,157,4,0,32,0,109,48,54,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,214,79,218,58,5,0,64,0,107,111,118,115,104,95,118,49,48,48,95,99,104,105,110,97,46,97,115,105,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,193,165,9,15,7,0,16,1,112,103,109,95,115,103,113,121,122,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,217,238,225,24,1,0,16,1,116,48,54,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,214,26,204,74,2,0,32,0,97,48,54,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,52,120,22,216,3,0,32,0,97,48,54,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,115,67,122,255,3,0,32,0,97,48,54,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,89,41,163,231,3,0,32,0,113,121,122,97,48,54,48,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,32,34,185,200,3,0,32,0,98,48,54,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,89,208,60,125,4,0,32,0,113,121,122,98,48,54,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,130,88,245,100,4,0,32,0,109,48,54,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,214,79,218,58,5,0,64,0,107,111,118,115,103,113,121,122,95,105,103,115,48,50,55,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,7,0,16,17,113,104,115,103,95,99,53,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,133,172,203,229,1,0,16,1,108,115,113,104,50,95,116,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,127,217,152,212,2,0,32,0,108,115,113,104,50,95,97,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,253,62,174,37,3,0,32,0,108,115,113,104,50,95,97,50,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,18,145,119,122,3,0,32,0,108,115,113,104,50,95,97,52,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,82,224,125,93,3,0,32,0,108,115,113,104,50,95,98,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,150,166,124,223,4,0,32,0,108,115,113,104,50,95,109,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,101,27,175,1,5,0,64,0,113,104,115,103,95,112,114,111,116,46,99,53,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,193,165,9,15,7,0,16,1,118,49,49,57,46,117,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,143,56,80,103,1,0,16,1,118,49,49,57,46,117,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,253,31,16,212,1,0,16,1,118,49,49,57,46,117,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,230,236,0,130,1,0,16,1,118,49,49,57,46,117,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,143,226,113,1,0,16,1,118,49,49,57,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,242,142,88,41,1,0,16,1,116,48,54,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,214,26,204,74,2,0,32,0,97,48,54,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,52,120,22,216,3,0,32,0,97,48,54,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,115,67,122,255,3,0,32,0,97,48,54,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,89,41,163,231,3,0,32,0,97,48,54,48,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,218,171,49,236,3,0,32,0,98,48,54,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,89,208,60,125,4,0,32,0,98,48,54,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,47,28,187,160,4,0,32,0,109,48,54,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,214,79,218,58,5,0,64,0,107,111,118,95,105,103,115,48,50,55,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,7,0,16,17,118,50,48,52,45,51,50,109,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,80,6,62,88,1,0,16,1,116,49,50,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,9,102,226,215,2,0,32,0,97,49,50,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,216,129,235,206,3,0,32,0,97,49,50,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,167,60,6,33,3,0,32,0,97,49,50,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,174,47,185,75,3,0,32,0,97,49,50,48,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,39,182,60,231,3,0,32,0,97,49,50,48,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,187,181,180,20,3,0,32,0,98,49,50,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,148,217,215,190,4,0,32,0,98,49,50,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,87,235,81,242,4,0,32,0,109,49,50,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,32,135,216,176,5,0,64,0,107,111,118,50,112,95,105,103,115,48,50,55,97,95,99,104,105,110,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,149,189,160,25,7,0,16,1,118,50,48,48,45,49,54,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,31,193,160,22,8,0,16,1,118,50,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,12,170,181,233,1,0,16,1,116,49,50,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,9,102,226,215,2,0,32,0,97,49,50,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,216,129,235,206,3,0,32,0,97,49,50,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,167,60,6,33,3,0,32,0,97,49,50,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,174,47,185,75,3,0,32,0,97,49,50,48,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,39,182,60,231,3,0,32,0,97,49,50,48,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,187,181,180,20,3,0,32,0,98,49,50,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,148,217,215,190,4,0,32,0,98,49,50,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,87,235,81,242,4,0,32,0,109,49,50,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,32,135,216,176,5,0,64,0,107,111,118,50,112,95,105,103,115,48,50,55,97,95,99,104,105,110,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,149,189,160,25,7,0,16,1,118,50,48,48,45,49,54,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,31,193,160,22,8,0,16,1,107,114,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,218,226,246,105,1,0,16,1,107,114,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,35,77,243,171,1,0,16,1,107,114,46,54,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,226,226,162,118,1,0,16,1,107,114,46,54,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,187,227,224,51,1,0,16,1,107,114,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,232,11,56,224,2,0,32,0,107,114,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,238,201,254,99,2,0,32,0,56,50,115,49,50,51,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,189,80,198,47,3,0,32,0,50,115,49,52,48,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,39,185,239,99,3,0,32,0,56,50,115,49,50,54,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,134,204,169,4,0,64,0,56,50,115,49,50,54,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,15,0,0,0,255,63,49,0,0,0,0,0,16,0,0,0,255,255,239,0,0,0,0,0,17,0,0,0,255,111,111,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,16,0,0,0,1,16,0,0,120,97,1,0,16,0,0,0,1,16,16,0,96,19,1,0,0,0,0,0,254,0,4,0,32,4,2,0,15,0,0,0,1,3,3,0,160,36,8,0,15,0,0,0,1,3,1,0,208,239,7,0,15,0,0,0,1,3,2,0,120,187,7,0,15,0,0,0,1,3,0,0,16,227,4,0,0,0,0,0,254,0,4,0,128,129,4,0,15,0,0,0,1,12,0,0,8,49,4,0,15,0,0,0,1,12,4,0,152,21,4,0,15,0,0,0,1,12,8,0,72,246,3,0,15,0,0,0,1,12,12,0,72,0,3,0,0,0,0,0,254,0,2,0,184,112,3,0,15,0,0,0,1,48,16,0,80,246,3,0,15,0,0,0,1,48,0,0,112,212,3,0,0,0,0,0,254,0,2,0,184,109,3,0,15,0,0,0,1,32,32,0,96,135,7,0,15,0,0,0,1,32,0,0,152,182,7,0,109,112,45,48,48,49,95,118,101,114,48,55,46,117,48,49,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,31,36,199,134,0,0,16,1,109,112,45,48,48,49,95,118,101,114,48,49,46,117,49,48,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,126,175,198,197,0,0,32,0,109,112,45,48,48,49,95,118,101,114,48,49,46,117,49,48,53,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,232,40,94,254,0,0,32,0,109,112,45,48,48,49,95,118,101,114,48,49,46,117,49,48,54,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,216,249,156,236,0,0,32,0,109,112,45,48,48,49,95,118,101,114,48,49,46,117,49,49,56,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,93,124,110,209,0,0,64,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,8,44,0,0,140,14,0,0,98,0,0,0,98,0,0,0,78,33,0,0,104,16,0,0,98,0,0,0,98,0,0,0,14,45,0,0,202,35,0,0,98,0,0,0,98,0,0,0,58,33,0,0,140,37,0,0,98,0,0,0,98,0,0,0,80,47,0,0,228,16,0,0,98,0,0,0,98,0,0,0,136,38,0,0,64,34,0,0,98,0,0,0,98,0,0,0,252,29,0,0,14,34,0,0,98,0,0,0,98,0,0,0,42,49,0,0,230,29,0,0,98,0,0,0,98,0,0,0,242,16,0,0,90,31,0,0,98,0,0,0,98,0,0,0,156,20,0,0,180,43,0,0,98,0,0,0,200,33,0,0,112,28,0,0,24,20,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,22,49,0,0,98,0,0,0,68,19,0,0,98,0,0,0,124,46,0,0,98,0,0,0,106,22,0,0,98,0,0,0,84,4,0,0,98,0,0,0,218,17,0,0,98,0,0,0,108,18,0,0,98,0,0,0,240,45,0,0,98,0,0,0,62,5,0,0,98,0,0,0,14,32,0,0,98,0,0,0,220,12,0,0,98,0,0,0,22,20,0,0,166,1,0,0,202,14,0,0,250,15,0,0,14,13,0,0,244,36,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,80,43,0,0,98,0,0,0,98,0,0,0,62,13,0,0,98,0,0,0,98,0,0,0,20,46,0,0,98,0,0,0,98,0,0,0,42,8,0,0,98,0,0,0,98,0,0,0,116,29,0,0,98,0,0,0,98,0,0,0,98,0,0,0,220,27,0,0,98,0,0,0,98,0,0,0,208,21,0,0,98,0,0,0,98,0,0,0,68,23,0,0,98,0,0,0,98,0,0,0,104,10,0,0,98,0,0,0,98,0,0,0,192,4,0,0,98,0,0,0,98,0,0,0,98,0,0,0,40,5,0,0,212,4,0,0,148,35,0,0,110,3,0,0,236,12,0,0,196,6,0,0,84,5,0,0,232,28,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,238,7,0,0,98,0,0,0,120,18,0,0,98,0,0,0,212,13,0,0,98,0,0,0,242,12,0,0,98,0,0,0,94,36,0,0,98,0,0,0,202,40,0,0,98,0,0,0,130,32,0,0,98,0,0,0,32,28,0,0,98,0,0,0,234,11,0,0,98,0,0,0,100,11,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,56,54,49,46,101,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,217,155,151,85,1,0,16,1,56,54,49,46,101,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,166,152,126,91,1,0,16,1,56,54,49,100,48,49,46,100,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,192,222,241,15,2,0,16,1,56,54,49,97,48,56,46,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,214,13,160,119,3,0,32,0,56,54,49,97,48,56,46,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,252,237,34,180,3,0,32,0,56,54,49,97,48,56,46,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,79,48,168,40,3,0,32,0,56,54,49,97,48,56,46,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,2,56,26,224,3,0,32,0,56,54,49,97,48,57,46,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,182,23,137,223,3,0,32,0,56,54,49,97,48,57,46,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,143,184,119,245,3,0,32,0,56,54,49,97,48,57,46,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,141,21,23,73,3,0,32,0,56,54,49,97,48,57,46,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,44,40,179,43,3,0,32,0,56,54,49,97,48,53,46,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,208,25,220,206,4,0,32,0,56,54,49,97,48,53,46,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,252,243,90,114,4,0,32,0,56,54,49,97,48,53,46,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,8,136,42,219,4,0,32,0,56,54,49,97,48,53,46,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,202,48,216,50,4,0,32,0,56,54,49,97,48,53,46,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,73,196,3,207,4,0,32,0,56,54,49,97,48,53,46,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,234,196,81,253,4,0,32,0,56,54,49,97,48,53,46,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,119,140,215,151,4,0,32,0,56,54,49,97,48,53,46,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,165,200,208,96,4,0,32,0,56,54,49,97,48,54,46,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,14,227,226,133,4,0,32,0,56,54,49,97,48,54,46,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,28,101,150,111,4,0,32,0,56,54,49,97,48,54,46,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,240,234,23,206,4,0,32,0,56,54,49,97,48,54,46,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,243,11,49,136,4,0,32,0,56,54,49,97,48,54,46,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,78,179,104,165,4,0,32,0,56,54,49,97,48,54,46,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,179,190,85,74,4,0,32,0,56,54,49,97,48,54,46,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,57,171,112,188,4,0,32,0,56,54,49,97,48,54,46,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,155,183,6,217,4,0,32,0,56,54,49,97,48,52,46,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,21,139,42,9,5,0,32,0,56,54,49,97,48,52,46,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,86,75,116,117,5,0,32,0,56,54,49,97,48,52,46,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,197,33,0,160,5,0,32,0,56,54,49,97,48,52,46,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,76,48,8,210,5,0,32,0,56,54,49,97,48,55,46,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,105,93,3,93,6,0,64,0,56,54,49,97,48,55,46,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,145,221,55,99,6,0,64,0,56,54,49,97,48,55,46,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,139,163,103,80,7,0,64,0,56,54,49,97,48,55,46,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,81,20,115,134,7,0,64,0,56,54,49,46,103,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,219,133,151,66,0,0,0,8,234,230,94,167,142,172,52,3,48,151,82,83,118,242,98,11,10,252,148,184,103,54,17,188,174,202,250,21,4,43,23,196,62,91,89,1,87,226,186,183,209,63,240,106,156,42,203,169,227,44,192,15,70,145,138,208,152,197,166,27,150,41,18,9,99,237,224,162,134,119,190,229,101,219,189,80,179,157,26,78,121,12,0,67,223,61,84,51,143,137,168,123,249,213,39,130,187,194,140,71,136,107,180,195,248,170,6,30,131,125,5,120,133,246,110,46,236,90,49,69,56,20,22,139,2,228,79,176,191,171,164,158,72,96,25,53,8,222,221,102,144,81,204,163,175,112,155,117,149,73,108,100,114,126,68,160,115,37,104,85,31,64,122,116,14,141,220,28,113,200,207,215,232,206,235,50,58,238,7,97,77,254,92,124,86,47,45,95,111,159,129,34,88,75,173,218,185,16,24,35,225,243,109,231,233,40,214,216,244,76,57,33,178,132,193,36,38,241,147,55,198,74,205,32,201,217,199,177,255,153,212,93,181,161,135,13,105,146,19,128,210,211,253,29,245,59,165,127,239,154,182,66,251,60,247,65,169,23,175,13,52,110,83,182,127,88,233,20,95,85,219,212,66,128,153,89,168,58,87,93,213,111,76,104,53,70,166,231,123,113,224,147,162,31,100,33,227,177,152,38,171,173,238,229,187,217,30,46,149,54,239,35,121,69,4,237,19,29,244,133,150,236,194,50,170,124,21,216,218,146,144,157,183,86,106,102,65,252,0,246,80,36,207,251,17,254,130,72,155,39,27,103,78,132,105,151,109,140,210,186,116,249,143,165,84,92,205,115,7,209,1,9,241,25,59,94,135,48,118,204,192,90,167,73,34,250,22,2,223,164,255,179,117,51,189,136,47,203,42,68,184,191,28,15,129,16,67,180,200,126,154,37,234,131,75,56,122,215,61,26,79,98,81,201,71,14,206,63,199,77,44,161,134,185,197,202,221,107,112,108,145,156,190,10,159,245,148,188,24,43,96,32,41,247,242,40,196,160,11,101,222,141,120,18,62,208,119,8,139,174,5,49,60,214,163,137,6,220,82,114,176,181,55,211,195,138,198,240,193,97,253,74,91,125,158,243,99,64,45,232,178,230,57,3,235,142,225,12,228,226,248,172,31,172,77,205,202,112,2,107,24,64,98,178,63,155,91,239,105,104,113,59,203,212,48,188,71,114,116,94,132,76,27,219,106,53,29,245,161,179,135,93,87,40,47,196,253,36,38,54,173,190,97,99,115,170,130,238,41,208,223,140,21,181,150,243,221,126,58,55,88,127,12,252,11,7,232,247,244,20,184,129,182,215,30,200,133,230,157,51,96,197,149,213,85,0,163,183,125,80,13,210,193,18,229,237,216,164,156,143,42,79,168,1,82,131,101,234,154,108,68,74,226,165,43,70,225,52,37,248,195,218,199,110,72,56,124,120,6,83,100,22,152,60,145,66,57,204,176,241,235,19,187,5,50,134,14,162,10,158,250,102,84,142,211,231,25,32,119,236,255,189,109,67,35,3,171,117,61,207,209,222,146,49,167,69,75,194,151,249,122,136,217,28,233,228,16,201,34,45,144,118,23,121,4,81,26,90,95,44,33,111,62,224,240,191,214,148,15,128,17,160,92,169,73,46,206,175,166,159,123,153,185,180,227,251,246,39,242,147,254,8,103,174,9,137,220,78,198,192,138,177,89,139,65,86,141,186,251,134,157,241,191,128,213,67,171,179,159,106,51,217,219,182,102,8,105,136,204,183,222,73,151,100,31,166,192,47,82,66,68,90,242,40,152,135,150,138,131,11,3,97,113,153,107,181,26,142,254,4,225,247,125,221,237,202,55,252,239,57,114,218,184,190,238,127,229,49,120,243,145,154,210,17,25,185,9,76,253,109,42,77,101,161,137,199,117,80,33,250,22,0,233,18,116,43,30,79,20,1,112,58,78,63,245,244,29,61,21,39,167,255,69,224,110,249,84,200,72,173,165,10,246,45,44,226,104,103,214,133,180,195,52,188,98,211,95,132,6,91,13,149,234,94,158,212,235,144,122,5,129,87,232,96,46,32,37,124,70,12,147,203,189,23,126,236,121,178,194,34,65,177,16,172,168,187,155,130,75,156,139,7,71,53,36,86,141,175,230,38,64,56,196,93,27,197,209,15,108,123,176,227,163,35,111,88,193,186,207,215,162,231,208,99,92,248,115,160,19,220,41,205,201,118,174,143,228,89,48,170,148,28,60,14,85,146,119,50,198,206,24,54,223,169,140,216,164,240,59,81,74,2,62,83,107,102,57,55,45,112,49,112,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,70,218,31,192,1,0,16,1,107,102,57,55,45,112,50,112,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,32,176,2,85,1,0,16,1,107,102,57,55,45,115,49,112,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,112,66,37,115,2,0,32,0,50,51,50,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,161,240,139,95,3,0,32,0,50,51,50,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,129,92,212,228,3,0,32,0,50,51,50,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,24,102,29,88,3,0,32,0,50,51,50,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,104,30,187,73,3,0,32,0,50,51,50,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,81,78,252,52,3,0,32,0,50,51,50,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,123,212,244,79,3,0,32,0,50,51,50,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,71,135,52,69,4,0,16,1,50,51,50,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,181,181,162,34,5,0,64,0,50,51,50,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,68,231,4,35,5,0,64,0,50,51,50,45,118,51,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,84,185,158,117,5,0,64,0,107,102,57,55,45,112,49,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,197,17,89,3,1,0,16,1,50,51,50,45,112,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,246,35,139,21,1,0,16,1,107,102,57,55,45,115,49,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,154,20,226,78,2,0,32,0,50,51,50,45,99,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,161,240,139,95,3,0,32,0,50,51,50,45,99,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,129,92,212,228,3,0,32,0,50,51,50,45,99,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,24,102,29,88,3,0,32,0,50,51,50,45,99,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,104,30,187,73,3,0,32,0,50,51,50,45,99,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,81,78,252,52,3,0,32,0,50,51,50,45,99,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,123,212,244,79,3,0,32,0,50,51,50,45,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,71,135,52,69,4,0,16,1,50,51,50,45,118,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,181,181,162,34,5,0,64,0,50,51,50,45,118,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,68,231,4,35,5,0,64,0,50,51,50,45,118,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,84,185,158,117,5,0,64,0,111,114,111,99,104,105,45,112,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,70,41,203,109,1,0,16,1,111,114,111,99,104,105,45,112,50,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,140,77,28,110,1,0,16,1,111,114,111,99,104,105,45,112,50,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,33,2,124,76,1,0,16,1,111,114,111,99,104,105,45,115,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,154,20,226,78,2,0,32,0,111,114,111,99,104,105,45,99,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,28,132,62,241,3,0,32,0,111,114,111,99,104,105,45,99,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,211,246,177,45,3,0,32,0,111,114,111,99,104,105,45,99,53,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,203,64,3,169,3,0,32,0,111,114,111,99,104,105,45,99,54,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,26,53,142,24,3,0,32,0,111,114,111,99,104,105,45,99,53,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,10,197,238,212,3,0,32,0,111,114,111,99,104,105,45,99,54,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,213,26,27,3,3,0,32,0,111,114,111,99,104,105,45,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,71,135,52,69,4,0,16,1,111,114,111,99,104,105,45,118,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,181,181,162,34,5,0,64,0,111,114,111,99,104,105,45,118,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,68,231,4,35,5,0,64,0,111,114,111,99,104,105,45,118,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,84,185,158,117,5,0,64,0,107,50,107,52,115,45,112,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,102,5,197,230,1,0,16,1,107,50,107,52,115,45,112,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,132,64,168,33,1,0,16,1,107,50,107,52,115,45,112,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,78,72,187,254,1,0,16,1,107,50,107,52,115,45,115,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,216,178,201,163,2,0,32,0,107,50,107,52,115,45,99,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,136,2,5,122,3,0,32,0,107,50,107,52,115,45,99,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,207,175,36,233,3,0,32,0,107,50,107,52,115,45,99,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,11,173,159,149,3,0,32,0,107,50,107,52,115,45,99,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,104,164,230,239,3,0,32,0,107,50,107,52,115,45,99,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,198,167,187,116,3,0,32,0,107,50,107,52,115,45,99,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,22,34,13,226,3,0,32,0,107,50,107,52,115,45,99,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,43,91,112,250,3,0,32,0,107,50,107,52,115,45,99,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,249,47,145,44,3,0,32,0,107,50,107,52,115,45,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,173,217,71,90,4,0,16,1,107,50,107,52,115,45,118,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,63,251,221,228,5,0,64,0,107,50,107,52,115,45,118,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,135,210,135,184,5,0,64,0,50,55,49,45,112,49,107,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,62,174,208,208,1,0,16,1,50,55,49,45,112,50,107,46,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,217,121,63,251,1,0,16,1,50,55,49,45,112,51,107,46,112,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,173,2,39,35,1,0,16,1,50,55,49,45,99,49,107,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,36,221,185,239,3,0,32,0,50,55,49,45,99,50,107,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,71,4,185,63,3,0,32,0,50,55,49,45,99,51,107,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,40,15,149,39,3,0,32,0,50,55,49,45,99,52,107,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,248,119,81,115,3,0,32,0,50,55,49,45,99,53,107,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,15,124,27,165,3,0,32,0,50,55,49,45,99,54,107,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,224,228,202,213,3,0,32,0,50,55,49,45,99,55,107,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,208,226,90,230,3,0,32,0,50,55,49,45,99,56,107,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,140,82,47,49,3,0,32,0,50,55,49,45,109,49,107,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,254,175,217,72,4,0,16,1,50,55,49,45,118,49,99,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,199,248,163,255,5,0,64,0,50,55,49,45,118,50,99,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,209,199,130,83,5,0,64,0,50,54,53,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,35,115,222,158,1,0,16,1,50,107,50,45,112,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,223,228,190,109,1,0,16,1,50,107,50,45,115,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,191,245,85,34,2,0,32,0,50,107,50,45,99,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,102,61,93,242,3,0,32,0,50,107,50,45,99,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,29,111,230,227,3,0,32,0,50,107,50,45,99,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,48,250,50,135,3,0,32,0,50,107,50,45,99,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,64,253,137,9,3,0,32,0,50,107,50,45,99,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,210,92,99,96,3,0,32,0,50,107,50,45,99,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,36,104,115,189,3,0,32,0,50,107,50,45,99,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,207,216,168,45,3,0,32,0,50,107,50,45,99,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,74,64,72,32,3,0,32,0,50,54,53,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,50,166,170,133,4,0,16,1,50,54,53,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,245,243,232,21,5,0,64,0,50,54,53,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,249,214,65,218,5,0,64,0,50,54,50,45,112,103,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,65,231,247,42,1,0,16,1,50,54,50,45,112,103,50,46,115,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,98,160,238,145,1,0,16,1,50,54,50,45,99,49,45,48,56,45,101,48,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,90,120,204,153,3,0,32,0,50,54,50,45,99,50,45,48,56,45,101,48,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,191,140,54,80,3,0,32,0,50,54,50,45,99,51,45,48,56,45,101,48,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,135,255,20,251,3,0,32,0,50,54,50,45,99,52,45,48,56,45,101,48,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,248,250,151,67,3,0,32,0,50,54,50,45,99,53,45,48,56,45,101,48,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,228,75,242,145,3,0,32,0,50,54,50,45,99,54,45,48,56,45,101,48,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,3,68,30,163,3,0,32,0,50,54,50,45,99,55,45,48,56,45,101,48,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,236,209,217,84,3,0,32,0,50,54,50,45,99,56,45,48,56,45,101,48,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,107,154,40,89,3,0,32,0,50,54,53,45,50,54,50,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,159,17,248,167,4,0,16,1,50,54,50,45,118,49,45,48,56,45,101,48,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,207,158,212,131,5,0,64,0,50,54,50,45,118,50,45,48,56,45,101,48,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,67,24,63,0,5,0,64,0,50,54,50,45,118,51,45,48,56,45,101,48,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,190,141,227,42,5,0,64,0,50,54,50,45,118,52,45,48,56,45,101,48,46,118,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,217,77,236,38,5,0,64,0,50,53,55,45,112,103,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,190,157,128,95,1,0,16,1,50,53,55,45,112,103,50,46,115,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,94,44,60,105,1,0,16,1,50,53,55,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,250,205,241,206,3,0,32,0,50,53,55,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,3,0,191,247,3,0,32,0,50,53,55,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,96,101,30,16,3,0,32,0,50,53,55,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,177,193,47,189,3,0,32,0,50,53,55,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,18,84,119,137,3,0,32,0,50,53,55,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,213,0,114,250,3,0,32,0,50,53,55,45,99,55,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,228,31,161,125,3,0,32,0,50,53,55,45,99,56,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,11,166,175,177,3,0,32,0,50,53,55,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,19,145,116,75,4,0,16,1,50,53,55,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,71,232,205,23,5,0,64,0,50,53,55,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,255,32,251,26,5,0,64,0,50,53,55,45,118,51,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,106,3,5,70,5,0,64,0,50,53,55,45,118,52,46,118,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,107,189,75,118,5,0,64,0,109,97,48,50,114,111,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,73,177,120,166,0,0,16,1,109,97,48,50,114,111,109,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,18,162,38,242,0,0,16,1,109,97,48,50,114,111,109,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,66,113,121,14,0,0,32,0,109,97,48,50,114,111,109,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,83,250,166,114,0,0,32,0,109,97,48,50,114,111,109,53,46,101,110,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,11,70,40,140,0,0,32,0,109,97,48,50,114,111,109,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,126,165,232,221,0,0,16,1,109,97,48,50,114,111,109,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,174,124,158,25,0,0,64,0,53,48,48,54,45,112,50,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,162,131,216,206,1,0,16,1,53,48,48,54,45,112,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,70,156,195,114,1,0,16,1,53,48,48,54,45,115,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,68,197,248,145,2,0,32,0,107,102,49,48,45,99,49,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,100,3,188,59,3,0,32,0,107,102,49,48,45,99,50,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,117,0,35,145,3,0,32,0,107,102,49,48,45,99,49,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,40,252,171,181,3,0,32,0,107,102,49,48,45,99,50,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,225,198,196,108,3,0,32,0,107,102,49,48,45,99,51,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,22,74,61,91,3,0,32,0,107,102,49,48,45,99,52,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,155,65,243,198,3,0,32,0,107,102,49,48,45,99,51,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,25,186,43,157,3,0,32,0,107,102,49,48,45,99,52,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,203,80,64,90,3,0,32,0,107,102,49,48,45,99,53,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,225,209,137,162,3,0,32,0,107,102,49,48,45,99,54,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,93,75,73,230,3,0,32,0,107,102,49,48,45,99,53,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,2,255,79,64,3,0,32,0,107,102,49,48,45,99,54,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,158,252,204,242,3,0,32,0,107,102,49,48,45,99,55,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,168,197,121,190,3,0,32,0,107,102,49,48,45,99,56,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,164,44,149,165,3,0,32,0,107,102,49,48,45,99,55,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,66,53,219,63,3,0,32,0,107,102,49,48,45,99,56,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,82,122,27,102,3,0,32,0,53,48,48,54,45,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,231,191,80,144,4,0,16,1,107,102,49,48,45,118,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,141,165,201,15,5,0,64,0,107,102,49,48,45,118,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,164,117,196,184,5,0,64,0,107,50,107,52,115,45,112,49,112,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,132,198,151,237,1,0,16,1,107,50,107,52,115,45,112,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,102,5,197,230,1,0,16,1,107,50,107,52,115,45,115,49,112,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,100,181,10,204,2,0,32,0,107,50,107,52,115,45,99,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,136,2,5,122,3,0,32,0,107,50,107,52,115,45,99,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,207,175,36,233,3,0,32,0,107,50,107,52,115,45,99,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,11,173,159,149,3,0,32,0,107,50,107,52,115,45,99,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,104,164,230,239,3,0,32,0,107,50,107,52,115,45,99,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,198,167,187,116,3,0,32,0,107,50,107,52,115,45,99,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,22,34,13,226,3,0,32,0,107,50,107,52,115,45,99,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,43,91,112,250,3,0,32,0,107,50,107,52,115,45,99,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,249,47,145,44,3,0,32,0,107,50,107,52,115,45,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,173,217,71,90,4,0,16,1,107,50,107,52,115,45,118,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,63,251,221,228,5,0,64,0,107,50,107,52,115,45,118,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,135,210,135,184,5,0,64,0,50,107,51,45,112,49,117,112,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,1,76,41,135,1,0,16,1,50,107,51,45,115,49,117,112,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,12,140,112,229,2,0,32,0,50,55,49,45,99,49,99,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,208,37,220,177,3,0,32,0,50,55,49,45,99,50,99,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,55,36,54,213,3,0,32,0,50,55,49,45,99,51,99,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,171,190,31,10,3,0,32,0,50,55,49,45,99,52,99,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,12,154,177,135,3,0,32,0,50,55,49,45,99,53,99,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,113,163,78,112,3,0,32,0,50,55,49,45,99,54,99,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,76,22,161,32,3,0,32,0,50,55,49,45,99,55,99,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,127,186,154,24,3,0,32,0,50,55,49,45,99,56,99,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,220,79,236,32,3,0,32,0,50,107,51,45,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,255,105,73,58,4,0,16,1,50,55,49,45,118,49,99,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,199,248,163,255,5,0,64,0,50,55,49,45,118,50,99,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,209,199,130,83,5,0,64,0,50,55,49,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,12,7,218,185,1,0,16,1,50,55,49,45,112,50,46,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,196,24,49,218,1,0,16,1,50,55,49,45,112,51,46,112,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,210,208,239,92,1,0,16,1,50,55,49,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,39,179,235,245,3,0,32,0,50,55,49,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,32,22,226,43,3,0,32,0,50,55,49,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,255,212,222,221,3,0,32,0,50,55,49,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,230,33,85,216,3,0,32,0,50,55,49,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,64,53,170,24,3,0,32,0,50,55,49,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,135,222,64,28,3,0,32,0,50,55,49,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,188,242,188,214,4,0,0,1,50,55,49,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,75,21,150,29,5,0,64,0,25,0,0,0,240,0,0,0,0,0,0,0,0,0,0,0,255,255,0,0,0,0,0,0,1,0,0,0,255,127,0,0,0,0,0,0,2,0,0,0,255,255,134,0,0,0,0,0,0,0,0,0,254,0,2,0,208,161,1,0,13,0,0,0,1,4,0,0,96,135,7,0,13,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,254,0,2,0,232,159,1,0,0,0,0,0,1,1,0,0,96,135,7,0,0,0,0,0,1,1,1,0,152,182,7,0,0,0,0,0,254,0,2,0,48,140,3,0,0,0,0,0,2,2,0,0,192,255,2,0,2,0,0,0,0,63,6,0,0,0,0,0,0,0,0,0,2,2,2,0,208,75,4,0,2,0,0,0,0,63,6,0,0,0,0,0,0,0,0,0,254,0,2,0,48,140,3,0,0,0,0,0,130,2,0,0,208,75,4,0,2,0,0,0,0,63,6,0,0,0,0,0,0,0,0,0,130,2,2,0,152,21,4,0,2,0,0,0,0,63,6,0,0,0,0,0,0,0,0,0,254,0,5,0,192,157,1,0,0,0,0,0,1,56,0,0,168,165,2,0,0,0,0,0,1,56,8,0,216,154,1,0,0,0,0,0,1,56,16,0,144,153,1,0,0,0,0,0,1,56,24,0,248,150,1,0,0,0,0,0,1,56,32,0,72,149,1,0,0,0,0,0,1,56,40,0,192,148,1,0,0,0,0,0,1,56,48,0,72,148,1,0,0,0,0,0,1,56,56,0,224,146,1,0,0,0,0,0,254,0,2,0,40,182,1,0,0,0,0,0,1,64,0,0,96,135,7,0,0,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,248,142,8,0,0,0,0,0,1,128,0,0,96,135,7,0,0,0,0,0,1,128,128,0,152,182,7,0,0,0,0,0,50,107,51,45,112,49,98,108,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,221,20,164,78,1,0,16,1,50,107,51,45,112,51,98,108,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,255,203,10,55,1,0,16,1,50,107,51,45,112,50,98,108,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,82,252,4,156,1,0,16,1,50,107,51,45,115,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,165,72,44,72,2,0,32,0,50,55,49,45,99,49,99,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,208,37,220,177,3,0,32,0,50,55,49,45,99,50,99,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,55,36,54,213,3,0,32,0,50,55,49,45,99,51,99,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,171,190,31,10,3,0,32,0,50,55,49,45,99,52,99,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,12,154,177,135,3,0,32,0,50,55,49,45,99,53,99,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,113,163,78,112,3,0,32,0,50,55,49,45,99,54,99,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,76,22,161,32,3,0,32,0,50,55,49,45,99,55,99,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,127,186,154,24,3,0,32,0,50,55,49,45,99,56,99,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,220,79,236,32,3,0,32,0,50,107,51,45,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,255,105,73,58,4,0,16,1,50,55,49,45,118,49,99,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,199,248,163,255,5,0,64,0,50,55,49,45,118,50,99,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,209,199,130,83,5,0,64,0,50,54,53,112,115,50,45,112,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,168,76,108,51,1,0,16,1,50,54,53,112,115,50,45,112,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,0,191,50,0,203,1,0,16,1,50,54,53,112,115,50,45,115,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,71,222,74,113,2,0,32,0,50,54,53,45,99,49,95,100,101,99,114,121,112,116,101,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,247,110,250,126,3,0,32,0,50,54,53,45,99,50,95,100,101,99,114,121,112,116,101,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,139,148,130,170,3,0,32,0,50,54,53,45,99,51,95,100,101,99,114,121,112,116,101,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,11,173,159,149,3,0,32,0,50,54,53,45,99,52,95,100,101,99,114,121,112,116,101,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,104,164,230,239,3,0,32,0,50,54,53,45,99,53,95,100,101,99,114,121,112,116,101,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,198,167,187,116,3,0,32,0,50,54,53,45,99,54,95,100,101,99,114,121,112,116,101,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,22,34,13,226,3,0,32,0,50,54,53,112,115,50,45,99,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,251,53,29,27,3,0,32,0,50,54,53,112,115,50,45,99,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,17,93,227,165,3,0,32,0,50,54,53,112,115,50,45,99,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,151,188,139,170,3,0,32,0,50,54,53,112,115,50,45,99,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,61,113,50,152,3,0,32,0,50,54,53,45,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,50,166,170,133,4,0,16,1,50,54,53,45,118,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,245,243,232,21,5,0,64,0,50,54,53,45,118,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,249,214,65,218,5,0,64,0,50,107,50,45,112,49,112,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,129,55,176,58,1,0,16,1,50,54,53,45,112,50,46,115,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,184,102,114,50,1,0,16,1,50,107,50,45,115,49,112,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,6,0,94,89,2,0,32,0,50,54,53,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,86,166,101,43,3,0,32,0,50,54,53,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,131,137,241,173,3,0,32,0,50,54,53,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,215,159,94,135,3,0,32,0,50,54,53,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,71,57,161,45,3,0,32,0,50,54,53,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,93,22,189,97,3,0,32,0,50,54,53,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,235,209,253,3,3,0,32,0,50,54,53,45,99,55,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,216,73,39,26,3,0,32,0,50,54,53,45,99,56,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,73,181,11,171,3,0,32,0,50,54,53,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,50,166,170,133,4,0,16,1,50,54,53,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,245,243,232,21,5,0,64,0,50,54,53,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,249,214,65,218,5,0,64,0,50,107,50,45,112,49,112,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,23,174,237,235,1,0,16,1,50,54,53,45,112,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,184,102,114,50,1,0,16,1,50,107,50,45,115,49,112,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,137,181,203,254,2,0,32,0,50,54,53,45,99,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,86,166,101,43,3,0,32,0,50,54,53,45,99,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,131,137,241,173,3,0,32,0,50,54,53,45,99,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,215,159,94,135,3,0,32,0,50,54,53,45,99,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,71,57,161,45,3,0,32,0,50,54,53,45,99,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,93,22,189,97,3,0,32,0,50,54,53,45,99,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,235,209,253,3,3,0,32,0,50,54,53,45,99,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,216,73,39,26,3,0,32,0,50,54,53,45,99,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,73,181,11,171,3,0,32,0,50,54,53,45,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,50,166,170,133,4,0,16,1,50,54,53,45,118,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,245,243,232,21,5,0,64,0,50,54,53,45,118,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,249,214,65,218,5,0,64,0,50,107,50,45,112,49,112,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,129,55,176,58,1,0,16,1,50,54,53,45,112,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,184,102,114,50,1,0,16,1,50,107,50,45,115,49,112,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,233,213,114,32,2,0,32,0,50,54,53,45,99,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,86,166,101,43,3,0,32,0,50,54,53,45,99,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,131,137,241,173,3,0,32,0,50,54,53,45,99,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,215,159,94,135,3,0,32,0,50,54,53,45,99,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,71,57,161,45,3,0,32,0,50,54,53,45,99,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,93,22,189,97,3,0,32,0,50,54,53,45,99,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,235,209,253,3,3,0,32,0,50,54,53,45,99,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,216,73,39,26,3,0,32,0,50,54,53,45,99,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,73,181,11,171,3,0,32,0,50,54,53,45,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,50,166,170,133,4,0,16,1,50,54,53,45,118,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,245,243,232,21,5,0,64,0,50,54,53,45,118,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,249,214,65,218,5,0,64,0,50,107,50,45,112,49,112,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,243,2,58,106,1,0,16,1,50,54,53,45,112,50,46,115,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,184,102,114,50,1,0,16,1,50,107,50,45,115,49,112,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,100,208,62,26,2,0,32,0,50,54,53,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,86,166,101,43,3,0,32,0,50,54,53,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,131,137,241,173,3,0,32,0,50,54,53,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,215,159,94,135,3,0,32,0,50,54,53,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,71,57,161,45,3,0,32,0,50,54,53,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,93,22,189,97,3,0,32,0,50,54,53,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,235,209,253,3,3,0,32,0,50,54,53,45,99,55,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,216,73,39,26,3,0,32,0,50,54,53,45,99,56,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,73,181,11,171,3,0,32,0,50,54,53,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,50,166,170,133,4,0,16,1,50,54,53,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,245,243,232,21,5,0,64,0,50,54,53,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,249,214,65,218,5,0,64,0,107,50,107,50,109,50,112,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,108,128,22,16,1,0,16,1,107,50,107,50,109,50,112,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,83,223,47,67,1,0,16,1,107,50,107,50,109,50,115,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,197,116,110,68,2,0,32,0,50,54,53,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,86,166,101,43,3,0,32,0,50,54,53,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,131,137,241,173,3,0,32,0,50,54,53,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,215,159,94,135,3,0,32,0,50,54,53,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,71,57,161,45,3,0,32,0,50,54,53,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,93,22,189,97,3,0,32,0,50,54,53,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,235,209,253,3,3,0,32,0,50,54,53,45,99,55,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,216,73,39,26,3,0,32,0,50,54,53,45,99,56,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,73,181,11,171,3,0,32,0,50,54,53,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,50,166,170,133,4,0,16,1,50,54,53,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,245,243,232,21,5,0,64,0,50,54,53,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,249,214,65,218,5,0,64,0,50,107,49,45,112,49,112,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,167,41,133,117,1,0,16,1,50,54,50,45,112,103,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,98,160,238,145,1,0,16,1,50,107,49,45,115,49,112,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,230,87,134,8,2,0,32,0,50,54,50,45,99,49,45,48,56,45,101,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,90,120,204,153,3,0,32,0,50,54,50,45,99,50,45,48,56,45,101,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,191,140,54,80,3,0,32,0,50,54,50,45,99,51,45,48,56,45,101,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,135,255,20,251,3,0,32,0,50,54,50,45,99,52,45,48,56,45,101,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,248,250,151,67,3,0,32,0,50,54,50,45,99,53,45,48,56,45,101,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,228,75,242,145,3,0,32,0,50,54,50,45,99,54,45,48,56,45,101,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,3,68,30,163,3,0,32,0,50,54,50,45,99,55,45,48,56,45,101,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,236,209,217,84,3,0,32,0,50,54,50,45,99,56,45,48,56,45,101,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,107,154,40,89,3,0,32,0,50,54,53,45,50,54,50,45,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,159,17,248,167,4,0,16,1,50,54,50,45,118,49,45,48,56,45,101,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,207,158,212,131,5,0,64,0,50,54,50,45,118,50,45,48,56,45,101,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,67,24,63,0,5,0,64,0,50,54,50,45,118,51,45,48,56,45,101,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,190,141,227,42,5,0,64,0,50,54,50,45,118,52,45,48,56,45,101,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,217,77,236,38,5,0,64,0,53,48,48,56,45,112,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,186,105,84,191,1,0,16,8,53,48,48,56,45,112,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,56,236,73,166,1,0,16,1,53,48,48,56,45,112,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,60,225,41,230,1,0,16,1,53,48,48,56,45,115,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,100,0,65,146,2,0,32,0,107,102,49,48,45,99,49,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,100,3,188,59,3,0,32,0,107,102,49,48,45,99,50,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,117,0,35,145,3,0,32,0,107,102,49,48,45,99,49,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,40,252,171,181,3,0,32,0,107,102,49,48,45,99,50,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,225,198,196,108,3,0,32,0,107,102,49,48,45,99,51,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,22,74,61,91,3,0,32,0,107,102,49,48,45,99,52,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,155,65,243,198,3,0,32,0,107,102,49,48,45,99,51,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,25,186,43,157,3,0,32,0,107,102,49,48,45,99,52,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,203,80,64,90,3,0,32,0,107,102,49,48,45,99,53,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,225,209,137,162,3,0,32,0,107,102,49,48,45,99,54,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,93,75,73,230,3,0,32,0,107,102,49,48,45,99,53,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,2,255,79,64,3,0,32,0,107,102,49,48,45,99,54,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,158,252,204,242,3,0,32,0,107,102,49,48,45,99,55,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,168,197,121,190,3,0,32,0,107,102,49,48,45,99,56,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,164,44,149,165,3,0,32,0,53,48,48,56,45,99,55,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,240,78,96,51,3,0,32,0,53,48,48,56,45,99,56,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,248,168,246,81,3,0,32,0,53,48,48,56,45,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,173,217,71,90,4,0,16,1,107,102,49,48,45,118,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,141,165,201,15,5,0,64,0,107,102,49,48,45,118,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,164,117,196,184,5,0,64,0,107,101,116,97,114,114,49,53,95,118,49,48,48,46,117,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,149,125,42,85,1,0,16,1,116,48,52,55,48,49,119,48,54,52,46,117,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,65,176,101,38,2,0,32,0,97,48,52,55,48,49,119,48,54,52,46,117,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,75,185,241,94,3,0,32,0,97,48,52,55,48,50,119,48,54,52,46,117,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,127,218,214,38,3,0,32,0,98,48,52,55,48,49,119,48,54,52,46,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,141,0,236,27,4,0,32,0,109,48,52,55,48,49,98,48,51,50,46,117,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,209,34,110,180,5,0,64,0,107,101,116,95,105,103,115,48,50,55,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,7,0,16,17,107,101,116,95,100,101,102,97,117,108,116,115,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,216,146,168,60,0,0,0,8,114,111,109,50,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,225,114,247,1,0,0,16,1,49,46,117,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,27,226,110,209,0,0,16,1,103,104,97,46,117,53,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,145,234,12,62,0,0,32,0,103,104,57,46,117,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,189,118,22,93,0,0,32,0,117,52,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,132,218,240,101,0,0,32,0,51,46,117,52,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,210,234,189,52,0,0,32,0,117,52,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,93,158,52,123,0,0,32,0,52,46,117,52,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,125,72,77,190,0,0,32,0,117,53,57,46,103,104,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,222,156,140,21,0,0,32,0,103,104,100,46,117,54,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,227,10,24,115,0,0,32,0,53,46,117,57,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,16,117,214,151,0,0,16,1,117,49,48,53,46,103,104,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,27,203,104,122,0,0,64,0,117,49,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,132,232,149,87,0,0,64,0,41,0,0,0,255,255,0,0,0,0,0,0,42,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,8,0,32,4,2,0,41,0,0,0,1,7,0,0,200,201,5,0,41,0,0,0,1,7,1,0,224,67,5,0,41,0,0,0,1,7,2,0,216,36,5,0,41,0,0,0,1,7,3,0,8,7,5,0,41,0,0,0,1,7,4,0,72,231,7,0,41,0,0,0,1,7,5,0,40,227,7,0,41,0,0,0,1,7,6,0,208,223,7,0,41,0,0,0,1,7,7,0,160,219,7,0,0,0,0,0,254,0,2,0,24,172,6,0,41,0,0,0,1,8,0,0,96,135,7,0,41,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,2,0,128,129,4,0,41,0,0,0,1,16,0,0,208,75,4,0,41,0,0,0,1,16,16,0,192,255,2,0,0,0,0,0,254,0,4,0,200,30,2,0,41,0,0,0,1,96,0,0,240,242,5,0,41,0,0,0,1,96,32,0,8,140,6,0,41,0,0,0,1,96,64,0,216,104,6,0,41,0,0,0,1,96,96,0,8,192,7,0,0,0,0,0,254,0,2,0,72,209,1,0,41,0,0,0,1,128,0,0,176,111,1,0,41,0,0,0,1,128,128,0,232,78,1,0,0,0,0,0,254,0,2,0,128,184,7,0,42,0,0,0,1,1,0,0,96,135,7,0,42,0,0,0,1,1,1,0,152,182,7,0,0,0,0,0,254,0,4,0,80,180,7,0,42,0,0,0,1,6,0,0,248,38,7,0,42,0,0,0,1,6,2,0,80,246,3,0,42,0,0,0,1,6,4,0,112,212,3,0,42,0,0,0,1,6,6,0,248,160,5,0,0,0,0,0,254,0,4,0,216,176,7,0,42,0,0,0,1,24,0,0,248,38,7,0,42,0,0,0,1,24,8,0,80,246,3,0,42,0,0,0,1,24,16,0,112,212,3,0,42,0,0,0,1,24,24,0,248,160,5,0,0,0,0,0,254,0,2,0,72,4,1,0,42,0,0,0,1,32,0,0,96,135,7,0,42,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,200,135,2,0,42,0,0,0,1,64,0,0,96,135,7,0,42,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,42,0,0,0,1,128,0,0,96,135,7,0,42,0,0,0,1,128,128,0,152,182,7,0,0,0,0,0,50,46,117,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,32,98,46,32,0,0,16,1,49,46,117,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,27,226,110,209,0,0,16,1,103,104,97,46,117,53,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,145,234,12,62,0,0,32,0,103,104,57,46,117,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,189,118,22,93,0,0,32,0,117,52,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,132,218,240,101,0,0,32,0,51,46,117,52,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,210,234,189,52,0,0,32,0,117,52,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,93,158,52,123,0,0,32,0,52,46,117,52,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,125,72,77,190,0,0,32,0,117,53,57,46,103,104,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,222,156,140,21,0,0,32,0,103,104,100,46,117,54,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,227,10,24,115,0,0,32,0,53,46,117,57,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,16,117,214,151,0,0,16,1,117,49,48,53,46,103,104,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,27,203,104,122,0,0,64,0,117,49,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,132,232,149,87,0,0,64,0,50,116,101,99,109,111,46,117,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,84,38,229,87,0,0,16,1,49,46,117,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,27,226,110,209,0,0,16,1,103,104,97,46,117,53,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,145,234,12,62,0,0,32,0,103,104,57,46,117,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,189,118,22,93,0,0,32,0,117,52,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,132,218,240,101,0,0,32,0,51,46,117,52,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,210,234,189,52,0,0,32,0,117,52,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,93,158,52,123,0,0,32,0,52,46,117,52,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,125,72,77,190,0,0,32,0,117,53,57,46,103,104,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,222,156,140,21,0,0,32,0,103,104,100,46,117,54,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,227,10,24,115,0,0,32,0,53,46,117,57,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,16,117,214,151,0,0,16,1,117,49,48,53,46,103,104,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,27,203,104,122,0,0,64,0,117,49,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,132,232,149,87,0,0,64,0,116,118,103,95,55,53,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,129,197,24,13,1,0,16,1,116,118,103,95,55,54,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,122,211,120,89,1,0,16,1,116,118,103,95,55,55,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,151,16,45,82,1,0,16,1,116,118,103,95,55,56,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,112,169,61,6,1,0,16,1,116,118,103,95,55,57,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,202,248,92,158,1,0,16,1,116,118,103,95,56,48,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,73,128,193,47,1,0,16,1,116,118,103,95,56,49,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,253,155,68,251,2,0,16,1,116,118,103,95,56,51,46,118])
.concat([48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,166,108,68,192,3,0,32,0,116,118,103,95,56,53,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,149,38,197,114,3,0,32,0,116,118,103,95,56,52,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,194,38,203,228,3,0,32,0,116,118,103,95,56,54,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,159,89,106,158,3,0,32,0,116,118,103,95,56,50,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,105,111,118,87,0,0,16,1,109,98,56,56,52,49,46,105,99,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,24,116,118,103,95,55,53,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,129,197,24,13,1,0,16,1,116,118,103,95,55,54,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,122,211,120,89,1,0,16,1,116,118,103,95,55,55,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,151,16,45,82,1,0,16,1,116,118,103,95,55,56,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,112,169,61,6,1,0,16,1,116,118,103,95,55,57,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,202,248,92,158,1,0,16,1,107,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,74,80,68,118,1,0,16,1,116,118,103,95,56,49,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,253,155,68,251,2,0,16,1,116,118,103,95,56,51,46,118,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,166,108,68,192,3,0,32,0,116,118,103,95,56,53,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,149,38,197,114,3,0,32,0,116,118,103,95,56,52,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,194,38,203,228,3,0,32,0,116,118,103,95,56,54,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,159,89,106,158,3,0,32,0,49,51,54,48,48,56,45,49,48,49,46,105,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,129,197,24,13,1,0,16,1,49,51,54,48,48,56,45,49,48,50,46,105,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,122,211,120,89,1,0,16,1,49,51,54,48,48,56,45,49,48,51,46,105,99,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,151,16,45,82,1,0,16,1,49,51,54,48,48,56,45,49,48,52,46,105,99,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,112,169,61,6,1,0,16,1,49,51,54,48,48,56,45,49,48,53,46,105,99,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,125,108,162,130,1,0,16,1,49,51,54,48,48,56,45,49,48,54,46,105,99,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,66,213,234,61,1,0,16,1,49,51,54,48,48,56,45,49,48,55,46,105,99,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,253,155,68,251,2,0,16,1,49,51,54,48,48,56,45,49,48,56,46,105,99,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,166,108,68,192,3,0,32,0,49,51,54,48,48,56,45,49,49,48,46,105,99,55,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,149,38,197,114,3,0,32,0,49,51,54,48,48,56,45,49,48,57,46,105,99,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,194,38,203,228,3,0,32,0,49,51,54,48,48,56,45,49,49,49,46,105,99,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,159,89,106,158,3,0,32,0,49,51,54,48,48,56,45,49,49,50,46,105,99,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,105,111,118,87,0,0,16,1,109,98,56,56,52,49,46,105,99,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,24,102,106,48,48,49,48,48,51,46,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,185,209,101,155,1,0,16,1,102,106,48,48,49,48,48,53,46,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,51,19,3,93,3,0,32,0,102,106,48,48,49,48,48,54,46,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,120,235,40,207,3,0,32,0,102,106,48,48,49,48,48,55,46,49,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,11,232,255,217,4,0,32,0,102,106,48,48,49,48,48,56,46,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,41,179,226,69,6,0,64,0,105,116,104,45,104,48,106,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,54,236,29,220,1,0,16,1,105,116,104,45,108,48,106,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,4,215,53,136,1,0,16,1,105,116,104,45,104,49,106,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,45,33,123,90,1,0,16,1,105,116,104,45,108,49,106,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,148,68,8,76,1,0,16,1,105,116,104,45,115,104,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,127,139,156,32,2,0,16,1,105,116,104,45,115,108,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,101,45,71,24,2,0,16,1,105,116,104,95,105,99,50,54,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,207,24,24,76,3,0,32,0,105,116,104,95,105,99,50,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,174,91,20,145,3,0,32,0,105,116,104,95,105,99,50,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,59,254,3,252,3,0,32,0,105,116,104,95,105,99,50,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,10,106,21,238,3,0,32,0,105,116,104,95,105,99,51,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,110,118,25,160,4,0,32,0,105,116,104,95,105,99,51,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,115,48,202,63,4,0,32,0,105,116,104,95,105,99,51,54,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,139,178,209,32,4,0,32,0,105,116,104,95,105,99,51,55,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,75,253,182,144,4,0,32,0,105,116,104,95,105,99,57,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,26,231,142,49,5,0,64,0,48,57,50,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,119,155,236,40,1,0,16,1,48,57,50,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,226,142,214,163,2,0,32,0,48,57,50,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,1,171,159,42,3,0,32,0,48,57,50,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,2,172,43,109,3,0,32,0,48,57,50,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,214,53,167,93,3,0,32,0,48,57,50,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,151,249,7,222,3,0,32,0,48,57,50,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,246,126,149,145,4,0,16,1,48,57,50,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,150,5,233,105,5,0,64,0,48,57,50,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,93,183,189,122,5,0,64,0,48,57,50,45,118,51,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,211,152,204,236,5,0,64,0,48,57,50,45,118,52,46,118,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,73,201,201,167,5,0,64,0,16,0,0,0,255,255,241,0,0,0,0,0,17,0,0,0,255,255,255,0,0,0,0,0,18,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,3,0,112,59,6,0,16,0,0,0,1,3,2,0,56,252,3,0,16,0,0,0,1,3,3,0,192,174,3,0,16,0,0,0,1,3,1,0,192,138,3,0,0,0,0,0,254,0,4,0,168,135,3,0,16,0,0,0,1,4,4,0,24,133,3,0,16,0,0,0,1,4,0,0,152,131,3,0,0,0,0,0,254,0,4,0,168,135,3,0,16,0,0,0,1,8,8,0,24,133,3,0,16,0,0,0,1,8,0,0,152,131,3,0,0,0,0,0,254,0,2,0,40,182,1,0,16,0,0,0,1,16,16,0,96,135,7,0,16,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,2,0,88,41,7,0,16,0,0,0,1,32,32,0,88,244,4,0,16,0,0,0,1,32,0,0,184,151,2,0,0,0,0,0,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,154,239,13,240,1,0,16,1,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,226,234,13,247,1,0,16,1,54,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,104,111,77,137,1,0,16,1,54,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,138,16,90,241,1,0,16,1,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,245,144,250,217,2,0,32,0,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,193,17,199,46,2,0,32,0,112,114,111,109,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,243,66,43,135,3,0,32,0,112,114,111,109,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,159,243,153,3,3,0,32,0,56,50,115,49,50,54,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,134,204,169,4,0,64,0,56,50,115,49,50,54,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,16,0,0,0,255,255,241,0,0,0,0,0,17,0,0,0,255,255,255,0,0,0,0,0,18,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,3,0,112,59,6,0,16,0,0,0,1,3,2,0,224,120,3,0,16,0,0,0,1,3,3,0,224,118,3,0,16,0,0,0,1,3,1,0,88,115,3,0,0,0,0,0,254,0,4,0,168,135,3,0,16,0,0,0,1,4,4,0,24,133,3,0,16,0,0,0,1,4,0,0,152,131,3,0,0,0,0,0,254,0,4,0,168,135,3,0,16,0,0,0,1,8,8,0,24,133,3,0,16,0,0,0,1,8,0,0,152,131,3,0,0,0,0,0,254,0,2,0,40,182,1,0,16,0,0,0,1,16,16,0,96,135,7,0,16,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,2,0,88,41,7,0,16,0,0,0,1,32,32,0,88,244,4,0,16,0,0,0,1,32,0,0,184,151,2,0,0,0,0,0,117,57,54,99,112,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,28,149,158,100,1,0,16,1,117,49,50,52,99,112,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,228,232,83,132,2,0,16,1,117,57,52,103,102,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,221,47,159,228,4,0,32,0,117,57,51,103,102,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,91,27,121,167,4,0,32,0,117,57,50,103,102,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,199,170,12,179,4,0,32,0,117,57,49,103,102,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,242,165,173,24,4,0,32,0,106,111,106,111,98,97,95,106,97,112,97,110,46,50,57,102,52,48,48,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,140,71,133,48,0,0,0,3,106,111,106,111,98,97,40,95,95,57,57,48,57,49,51,41,45,115,105,109,109,49,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,49,98,151,118,0,0,16,1,106,111,106,111,98,97,40,95,95,57,57,48,57,49,51,41,45,115,105,109,109,49,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,231,120,221,206,0,0,16,1,106,111,106,111,98,97,40,95,95,57,57,48,57,49,51,41,45,115,105,109,109,49,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,127,183,85,41,0,0,16,1,106,111,106,111,98,97,40,95,95,57,57,48,57,49,51,41,45,115,105,109,109,49,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,215,57,1,40,0,0,16,1,106,111,106,111,98,97,40,95,95,57,57,48,57,49,51,41,45,115,105,109,109,50,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,20,73,92,48,0,0,16,1,106,111,106,111,98,97,40,95,95,57,57,48,57,49,51,41,45,115,105,109,109,50,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,59,79,175,24,0,0,16,1,106,111,106,111,98,97,40,95,95,57,57,48,57,49,51,41,45,115,105,109,109,50,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,158,92,126,57,0,0,16,1,106,111,106,111,98,97,40,95,95,57,57,48,57,49,51,41,45,115,105,109,109,50,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,215,167,208,169,0,0,16,1,106,111,106,111,98,97,45,115,105,109,109,51,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,17,225,22,77,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,51,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,211,6,52,155,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,51,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,151,73,65,242,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,51,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,125,156,75,149,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,51,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,29,220,90,98,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,51,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,180,11,167,32,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,51,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,175,197,14,161,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,51,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,122,222,208,11,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,52,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,220,74,161,110,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,52,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,251,66,76,143,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,52,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,209,134,5,239,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,52,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,112,196,204,147,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,52,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,210,199,158,61,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,52,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,80,104,230,3,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,52,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,195,106,96,1,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,52,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,135,43,57,54,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,53,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,12,198,248,46,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,53,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,166,124,125,207,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,53,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,250,91,129,183,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,53,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,73,192,254,155,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,53,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,107,83,103,209,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,53,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,66,160,231,85,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,53,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,6,41,179,79,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,53,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,32,229,139,140,0,0,32,0,106,111,106,111,98,97,95,101,117,114,111,95,110,111,99,100,46,50,57,102,52,48,48,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,121,214,226,30,0,0,0,3,106,111,106,111,98,97,40,95,95,57,57,48,57,50,55,41,45,115,105,109,109,49,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,119,131,205,173,0,0,16,1,106,111,106,111,98,97,40,95,95,57,57,48,57,50,55,41,45,115,105,109,109,49,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,89,11,89,215,0,0,16,1,106,111,106,111,98,97,40,95,95,57,57,48,57,50,55,41,45,115,105,109,109,49,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,11,36,46,230,0,0,16,1,106,111,106,111,98,97,40,95,95,57,57,48,57,50,55,41,45,115,105,109,109,49,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,195,80,84,201,0,0,16,1,106,111,106,111,98,97,40,95,95,57,57,48,57,50,55,41,45,115,105,109,109,50,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,186,46,95,83,0,0,16,1,106,111,106,111,98,97,40,95,95,57,57,48,57,50,55,41,45,115,105,109,109,50,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,1,58,221,1,0,0,16,1,106,111,106,111,98,97,40,95,95,57,57,48,57,50,55,41,45,115,105,109,109,50,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,114,38,67,97,0,0,16,1,106,111,106,111,98,97,40,95,95,57,57,48,57,50,55,41,45,115,105,109,109,50,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,202,154,220,172,0,0,16,1,106,111,106,111,98,97,45,115,105,109,109,51,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,17,225,22,77,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,51,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,211,6,52,155,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,51,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,151,73,65,242,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,51,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,125,156,75,149,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,51,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,29,220,90,98,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,51,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,180,11,167,32,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,51,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,175,197,14,161,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,51,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,122,222,208,11,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,52,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,220,74,161,110,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,52,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,251,66,76,143,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,52,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,209,134,5,239,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,52,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,112,196,204,147,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,52,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,210,199,158,61,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,52,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,80,104,230,3,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,52,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,195,106,96,1,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,52,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,135,43,57,54,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,53,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,12,198,248,46,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,53,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,166,124,125,207,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,53,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,250,91,129,183,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,53,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,73,192,254,155,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,53,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,107,83,103,209,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,53,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,66,160,231,85,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,53,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,6,41,179,79,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,53,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,32,229,139,140,0,0,32,0,109,119,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,64,143,183,225,1,0,16,1,109,98,110,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,199,218,178,17,2,0,32,0,109,98,110,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,83,115,163,163,3,0,32,0,109,98,110,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,197,48,34,170,3,0,32,0,109,98,110,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,113,71,189,220,4,0,64,0,109,98,110,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,42,26,183,112,5,0,64,0,48,48,56,45,101,112,114,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,136,243,183,47,1,0,16,1,48,48,56,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,24,191,172,169,3,0,32,0,48,48,56,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,249,238,137,98,3,0,32,0,48,48,56,45,109,103,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,144,198,99,209,4,0,16,1,48,48,56,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,186,173,62,68,5,0,64,0,102,101,50,48,48,50,48,48,49,46,117,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,96,249,154,123,1,0,16,1,102,101,50,48,48,50,48,48,50,46,117,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,163,113,221,71,1,0,16,1,102,101,50,48,48,49,48,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,211,28,68,39,3,0,32,0,102,101,50,48,48,49,48,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,196,66,43,202,3,0,32,0,102,101,50,48,48,49,48,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,88,86,196,98,3,0,32,0,102,101,50,48,48,49,48,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,123,197,144,38,3,0,32,0,102,101,50,48,48,49,48,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,180,244,185,152,4,0,32,0,102,101,50,48,48,49,48,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,108,145,170,212,4,0,32,0,102,101,50,48,48,49,48,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,175,92,163,165,28,0,32,0,102,101,50,48,48,49,48,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,72,187,75,39,5,0,32,0,102,101,50,48,48,49,48,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,113,152,226,81,5,0,32,0,102,101,50,48,48,49,48,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,142,72,53,162,29,0,32,0,102,101,50,48,48,49,48,48,53,46,117,54,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,121,40,159,217,6,0,64,0,102,101,50,48,48,49,48,48,54,46,117,55,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,120,228,241,157,6,0,64,0,98,52,49,45,48,57,45,49,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,188,31,130,175,2,0,16,1,98,52,49,45,49,49,45,49,46,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,255,63,130,2,0,16,1,98,52,49,45,49,48,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,119,77,169,76,2,0,16,1,98,52,49,45,49,50,46,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,252,193,217,64,2,0,16,1,98,52,49,45,48,49,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,164,47,7,93,1,0,16,1,98,52,49,45,49,51,46,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,84,66,70,158,9,0,16,1,98,52,49,45,48,51,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,208,53,109,115,11,0,32,0,98,52,49,45,48,50,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,217,5,242,41,15,0,32,0,98,52,49,45,48,52,46,52,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,143,99,104,198,24,0,64,0,112,114,111,116,111,95,50,50,48,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,198,66,169,98,1,0,16,1,112,114,111,116,111,95,50,50,48,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,23,226,47,55,2,0,32,0,112,114,111,116,111,95,50,50,48,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,220,183,162,154,3,0,32,0,112,114,111,116,111,95,50,50,48,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,8,215,42,138,3,0,32,0,112,114,111,116,111,95,50,50,48,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,90,177,127,214,3,0,32,0,112,114,111,116,111,95,50,50,48,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,139,163,62,231,3,0,32,0,112,114,111,116,111,95,50,50,48,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,99,187,8,58,4,0,16,1,112,114,111,116,111,95,50,50,48,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,21,162,48,143,5,0,64,0,105,116,104,45,104,48,45,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,192,206,61,86,1,0,16,1,105,116,104,45,108,48,45,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,5,199,56,22,1,0,16,1,105,116,104,45,104,49,45,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,95,6,83,2,1,0,16,1,105,116,104,45,108,49,45,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,141,104,125,165,1,0,16,1,105,116,104,45,115,104,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,127,139,156,32,2,0,16,1,105,116,104,45,115,108,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,101,45,71,24,2,0,16,1,105,116,104,95,105,99,50,54,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,207,24,24,76,3,0,32,0,105,116,104,95,105,99,50,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,174,91,20,145,3,0,32,0,105,116,104,95,105,99,50,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,59,254,3,252,3,0,32,0,105,116,104,95,105,99,50,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,10,106,21,238,3,0,32,0,105,116,104,95,105,99,51,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,110,118,25,160,4,0,32,0,105,116,104,95,105,99,51,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,115,48,202,63,4,0,32,0,105,116,104,95,105,99,51,54,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,139,178,209,32,4,0,32,0,105,116,104,95,105,99,51,55,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,75,253,182,144,4,0,32,0,105,116,104,95,105,99,57,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,26,231,142,49,5,0,64,0,105,102,45,99,45,104,48,45,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,100,68,201,245,1,0,16,1,105,102,45,99,45,108,48,45,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,254,52,197,135,1,0,16,1,105,102,45,99,45,104,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,65,5,3,234,1,0,16,1,105,102,45,99,45,108,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,72,227,106,198,1,0,16,1,105,102,45,99,45,48,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,56,102,94,116,2,0,32,0,105,102,45,99,45,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,73,132,16,183,2,0,32,0,105,102,45,99,45,50,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,186,60,243,174,2,0,32,0,105,102,45,99,45,51,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,149,230,152,31,2,0,32,0,105,102,45,97,45,97,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,119,45,238,52,3,0,32,0,105,102,45,97,45,97,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,91,132,210,107,3,0,32,0,105,102,45,97,45,97,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,229,80,13,9,3,0,32,0,105,102,45,97,45,97,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,131,48,142,58,3,0,32,0,105,102,45,97,45,98,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,41,200,37,180,4,0,32,0,105,102,45,97,45,98,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,62,226,191,233,4,0,32,0,105,102,45,97,45,98,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,242,80,110,37,4,0,32,0,105,102,45,97,45,98,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,133,39,104,76,4,0,32,0,105,102,45,99,45,118,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,148,161,100,203,5,0,64,0,105,102,45,99,45,118,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,245,139,182,69,5,0,64,0,105,109,103,102,105,103,104,116,95,105,56,55,53,49,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,24,56,54,49,102,48,51,46,107,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,189,174,97,140,1,0,16,1,56,54,49,102,48,50,46,107,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,40,12,70,210,1,0,16,1,56,54,49,100,48,49,46,100,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,192,222,241,15,2,0,16,1,56,54,49,97,48,56,46,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,214,13,160,119,3,0,32,0,56,54,49,97,48,56,46,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,252,237,34,180,3,0,32,0,56,54,49,97,48,56,46,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,79,48,168,40,3,0,32,0,56,54,49,97,48,56,46,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,2,56,26,224,3,0,32,0,56,54,49,97,48,57,46,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,182,23,137,223,3,0,32,0,56,54,49,97,48,57,46,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,143,184,119,245,3,0,32,0,56,54,49,97,48,57,46,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,141,21,23,73,3,0,32,0,56,54,49,97,48,57,46,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,44,40,179,43,3,0,32,0,56,54,49,97,48,53,46,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,208,25,220,206,4,0,32,0,56,54,49,97,48,53,46,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,252,243,90,114,4,0,32,0,56,54,49,97,48,53,46,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,8,136,42,219,4,0,32,0,56,54,49,97,48,53,46,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,202,48,216,50,4,0,32,0,56,54,49,97,48,53,46,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,73,196,3,207,4,0,32,0,56,54,49,97,48,53,46,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,234,196,81,253,4,0,32,0,56,54,49,97,48,53,46,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,119,140,215,151,4,0,32,0,56,54,49,97,48,53,46,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,165,200,208,96,4,0,32,0,56,54,49,97,48,54,46,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,14,227,226,133,4,0,32,0,56,54,49,97,48,54,46,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,28,101,150,111,4,0,32,0,56,54,49,97,48,54,46,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,240,234,23,206,4,0,32,0,56,54,49,97,48,54,46,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,243,11,49,136,4,0,32,0,56,54,49,97,48,54,46,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,78,179,104,165,4,0,32,0,56,54,49,97,48,54,46,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,179,190,85,74,4,0,32,0,56,54,49,97,48,54,46,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,57,171,112,188,4,0,32,0,56,54,49,97,48,54,46,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,155,183,6,217,4,0,32,0,56,54,49,97,48,52,46,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,21,139,42,9,5,0,32,0,56,54,49,97,48,52,46,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,86,75,116,117,5,0,32,0,56,54,49,97,48,52,46,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,197,33,0,160,5,0,32,0,56,54,49,97,48,52,46,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,76,48,8,210,5,0,32,0,56,54,49,97,48,55,46,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,105,93,3,93,6,0,64,0,56,54,49,97,48,55,46,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,145,221,55,99,6,0,64,0,56,54,49,97,48,55,46,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,139,163,103,80,7,0,64,0,56,54,49,97,48,55,46,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,81,20,115,134,7,0,64,0,56,54,49,46,103,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,219,133,151,66,8,0,0,8,56,55,48,95,104,48,53,46,54,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,243,238,207,43,1,0,16,1,56,55,48,95,104,48,52,46,52,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,211,127,249,185,1,0,16,1,56,55,48,95,104,48,57,46,54,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,177,248,164,150,1,0,16,1,56,55,48,95,104,48,56,46,52,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,86,81,214,70,1,0,16,1,56,55,48,95,104,48,55,46,49,48,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,18,166,221,180,2,0,16,1,56,55,48,95,104,48,54,46,56,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,2,167,107,105,2,0,16,1,56,55,48,95,103,48,51,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,200,16,156,219,3,0,16,1,56,55,48,95,102,49,52,46,100,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,21,102,180,201,4,0,32,0,56,55,48,99,49,55,46,112,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,248,159,201,43,5,0,32,0,56,55,48,99,49,56,46,112,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,232,127,146,7,5,0,32,0,56,55,48,99,49,53,46,112,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,129,146,140,5,0,32,0,56,55,48,99,49,54,46,112,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,27,106,223,65,5,0,32,0,56,55,48,95,99,48,49,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,70,101,249,106,7,0,32,0,56,55,48,95,99,48,50,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,109,44,225,84,8,0,32,0,104,112,95,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,62,193,140,151,1,0,16,1,104,112,95,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,38,135,56,104,1,0,16,1,104,112,95,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,18,190,22,189,1,0,16,1,104,112,95,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,240,12,91,101,1,0,16,1,104,112,95,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,36,134,54,166,1,0,16,1,104,112,95,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,40,208,239,72,1,0,16,1,104,112,95,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,52,62,198,165,1,0,16,1,104,112,95,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,145,218,62,81,1,0,16,1,104,112,95,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,105,130,105,130,2,0,16,1,104,112,95,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,185,100,59,213,3,0,32,0,104,112,95,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,238,252,227,47,3,0,32,0,104,112,95,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,241,215,236,222,4,0,32,0,104,112,95,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,194,3,214,95,4,0,32,0,104,112,95,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,61,109,192,147,5,0,64,0,50,46,117,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,221,146,193,171,1,0,16,1,49,46,117,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,208,150,232,139,1,0,16,1,112,114,111,103,46,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,142,174,23,144,1,0,16,1,48,108,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,235,69,174,88,2,0,32,0,48,104,46,117,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,41,185,187,215,2,0,32,0,49,108,46,117,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,96,99,87,39,2,0,32,0,49,104,46,117,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,63,166,57,116,2,0,32,0,50,108,46,117,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,36,78,166,253,2,0,32,0,50,104,46,117,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,166,78,229,139,2,0,32,0,51,108,46,117,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,63,123,80,146,2,0,32,0,51,104,46,117,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,94,239,43,4,2,0,32,0,52,108,46,117,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,112,109,59,2,2,0,32,0,52,104,46,117,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,177,232,231,155,2,0,32,0,53,108,46,117,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,6,67,165,122,2,0,32,0,53,104,46,117,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,82,142,180,230,2,0,32,0,54,108,46,117,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,233,117,230,223,2,0,32,0,54,104,46,117,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,118,149,145,69,2,0,32,0,55,108,46,117,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,152,245,58,205,2,0,32,0,55,104,46,117,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,229,74,253,163,2,0,32,0,115,110,100,48,46,117,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,53,95,39,95,3,0,64,0,115,110,100,49,46,117,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,121,135,96,152,3,0,64,0,50,46,117,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,163,164,6,59,1,0,16,1,49,46,117,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,36,107,173,122,1,0,16,1,112,114,111,103,46,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,86,51,108,49,1,0,16,1,48,108,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,53,208,187,212,2,0,32,0,48,104,46,117,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,11,43,131,232,2,0,32,0,49,108,46,117,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,178,108,66,8,2,0,32,0,49,104,46,117,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,234,110,44,17,2,0,32,0,50,108,46,117,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,212,124,25,15,2,0,32,0,50,104,46,117,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,140,128,55,252,2,0,32,0,51,108,46,117,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,220,148,208,196,2,0,32,0,51,104,46,117,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,10,173,13,239,2,0,32,0,52,108,46,117,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,15,121,134,81,2,0,32,0,52,104,46,117,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,67,111,122,24,2,0,32,0,53,108,46,117,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,243,81,241,236,2,0,32,0,53,104,46,117,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,236,244,11,114,2,0,32,0,54,108,46,117,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,77,64,144,228,2,0,32,0,54,104,46,117,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,26,20,138,126,2,0,32,0,55,108,46,117,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,178,143,199,46,2,0,32,0,55,104,46,117,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,18,86,115,193,2,0,32,0,115,110,100,48,46,117,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,186,13,42,214,3,0,64,0,115,110,100,49,46,117,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,180,31,249,29,3,0,64,0,50,46,117,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,30,194,52,51,1,0,16,1,49,46,117,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,67,198,161,177,1,0,16,1,112,114,111,103,46,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,142,109,85,173,1,0,16,1,48,108,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,247,134,89,246,2,0,32,0,48,104,46,117,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,169,7,253,81,2,0,32,0,49,108,46,117,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,215,33,157,245,2,0,32,0,49,104,46,117,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,151,71,234,96,2,0,32,0,50,108,46,117,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,227,5,175,251,2,0,32,0,50,104,46,117,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,18,22,40,97,2,0,32,0,51,108,46,117,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,159,189,225,226,2,0,32,0,51,104,46,117,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,66,101,66,196,2,0,32,0,52,108,46,117,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,66,162,152,114,2,0,32,0,52,104,46,117,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,89,180,145,254,2,0,32,0,53,108,46,117,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,125,74,113,204,2,0,32,0,53,104,46,117,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,249,156,20,47,2,0,32,0,54,108,46,117,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,254,125,233,191,2,0,32,0,54,104,46,117,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,42,5,115,52,2,0,32,0,55,108,46,117,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,49,138,42,2,2,0,32,0,55,104,46,117,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,9,116,228,119,2,0,32,0,115,110,100,48,46,117,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,237,47,30,5,3,0,64,0,115,110,100,49,46,117,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,45,35,224,13,3,0,64,0,109,112,51,46,117,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,121,84,78,31,0,0,16,1,109,112,52,46,117,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,75,60,28,111,0,0,16,1,109,112,50,46,117,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,190,158,151,255,0,0,16,1,109,112,57,46,117,53,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,236,73,141,37,0,0,32,0,109,112,56,46,117,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,184,215,180,189,0,0,32,0,109,112,55,46,117,53,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,80,28,194,135,0,0,32,0,109,112,54,46,117,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,136,178,175,77,0,0,32,0,109,112,53,46,117,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,140,69,38,155,0,0,32,0,109,112,49,46,117,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,27,190,104,72,0,0,64,0,101,101,112,114,111,109,45,104,111,116,100,111,103,115,116,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,52,249,180,18,0,0,16,1,49,46,117,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,0,13,11,1,0,16,1,50,46,117,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,11,24,181,195,1,0,16,1,48,108,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,131,153,218,21,2,0,32,0,48,104,46,117,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,63,183,215,118,2,0,32,0,49,108,46,117,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,152,52,234,118,2,0,32,0,49,104,46,117,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,159,133,86,160,2,0,32,0,50,108,46,117,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,177,27,45,157,2,0,32,0,50,104,46,117,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,77,60,117,167,2,0,32,0,115,110,100,48,46,117,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,167,138,242,238,3,0,64,0,104,103,52,46,112,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,249,167,103,220,1,0,16,1,104,103,53,46,109,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,104,75,90,246,1,0,16,1,104,103,54,46,112,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,170,150,82,95,1,0,16,1,104,103,55,46,109,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,93,69,93,220,1,0,16,1,104,103,51,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,200,136,123,179,2,0,32,0,104,103,49,46,99,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,93,47,76,239,3,0,32,0,104,103,50,46,101,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,4,248,51,145,3,0,32,0,104,103,98,51,46,108,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,216,235,156,98,4,0,32,0,104,103,98,53,46,109,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,67,68,170,219,4,0,32,0,104,103,98,49,46,104,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,206,7,198,7,4,0,32,0,104,103,98,52,46,108,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,8,197,42,113,0,0,0,8,104,103,98,50,46,107,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,92,99,33,73,0,0,0,8,50,46,117,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,77,3,26,28,1,0,16,1,49,46,117,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,162,74,176,36,1,0,16,1,112,114,111,103,46,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,66,245,207,131,1,0,16,1,48,108,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,18,34,71,247,2,0,32,0,48,104,46,117,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,15,157,1,48,2,0,32,0,49,108,46,117,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,2,80,109,244,2,0,32,0,49,104,46,117,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,182,146,5,33,2,0,32,0,50,108,46,117,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,33,223,138,185,2,0,32,0,50,104,46,117,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,225,161,61,142,2,0,32,0,51,108,46,117,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,237,164,123,250,2,0,32,0,51,104,46,117,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,234,0,212,165,2,0,32,0,52,108,46,117,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,38,0,193,118,2,0,32,0,52,104,46,117,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,137,8,159,121,2,0,32,0,53,108,46,117,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,54,239,57,70,2,0,32,0,53,104,46,117,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,158,158,158,84,2,0,32,0,115,110,100,48,46,117,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,223,95,142,14,3,0,64,0,115,110,100,49,46,117,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,47,125,5,216,3,0,64,0,53,102,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,198,58,171,199,1,0,0,0,53,103,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,166,26,3,209,1,0,0,0,53,104,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,81,245,218,192,1,0,0,0,53,107,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,66,34,68,103,1,0,0,0,51,105,46,115,110,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,6,4,227,32,2,0,0,0,53,104,46,118,105,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,71,37,42,234,3,0,0,0,53,107,46,118,105,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,201,33,212,168,3,0,0,0,55,99,46,99,108,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,102,97,100,175,4,0,0,0,55,100,46,99,108,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,50,88,225,216,4,0,0,0,55,101,46,99,108,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,250,101,126,47,4,0,0,0,55,102,46,99,108,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,174,213,50,173,4,0,0,0,55,52,115,50,56,55,46,50,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,129,163,192,125,5,0,0,0,55,52,115,50,56,55,46,50,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,12,68,10,5,0,0,0,55,52,115,50,56,55,46,118,105,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,204,70,52,90,5,0,0,0,56,50,115,49,52,55,46,104,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,146,188,229,70,6,0,0,0,112,108,115,49,53,51,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,235,0,0,0,204,75,160,214,7,0,0,0,98,57,48,95,49,52,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,245,249,29,16,0,0,16,1,98,57,48,95,49,53,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,82,212,127,230,0,0,16,1,98,57,48,95,48,52,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,252,80,97,234,0,0,32,0,98,57,48,95,48,53,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,7,197,82,187,0,0,32,0,98,57,48,95,48,54,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,82,2,91,207,0,0,32,0,98,57,48,95,48,55,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,99,242,138,185,0,0,32,0,98,57,48,95,49,49,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,60,84,62,195,0,0,32,0,98,57,48,95,49,48,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,146,16,253,53,0,0,32,0,98,57,48,95,48,57,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,158,0,1,207,0,0,32,0,98,57,48,95,48,56,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,227,165,4,52,0,0,32,0,98,57,48,95,48,51,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,103,250,88,64,0,0,16,1,49,51,46,51,119,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,237,204,136,188,0,0,64,0,49,50,46,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,146,116,225,161,0,0,64,0,18,0,0,0,255,255,0,0,0,0,0,0,19,0,0,0,255,255,0,0,0,0,0,0,20,0,0,0,255,255,2,0,0,0,0,0,0,0,0,0,254,0,2,0,0,0,0,0,18,0,0,0,1,2,0,0,200,211,8,0,18,0,0,0,1,2,2,0,216,147,8,0,0,0,0,0,254,0,2,0,0,0,0,0,18,0,0,0,1,4,0,0,168,84,8,0,18,0,0,0,1,4,4,0,40,31,8,0,0,0,0,0,254,0,2,0,240,233,7,0,18,0,0,0,1,8,0,0,152,182,7,0,18,0,0,0,1,8,8,0,96,135,7,0,0,0,0,0,254,0,4,0,200,87,7,0,18,0,0,0,1,48,0,0,232,38,7,0,18,0,0,0,1,48,16,0,64,251,6,0,18,0,0,0,1,48,32,0,24,211,6,0,18,0,0,0,1,48,48,0,72,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,18,0,0,0,1,192,0,0,176,73,6,0,18,0,0,0,1,192,64,0,72,32,6,0,18,0,0,0,1,192,128,0,168,241,5,0,18,0,0,0,1,192,192,0,184,201,5,0,0,0,0,0,254,0,4,0,136,160,5,0,19,0,0,0,1,3,0,0,16,150,7,0,19,0,0,0,1,3,1,0,120,198,7,0,19,0,0,0,1,3,2,0,160,103,7,0,19,0,0,0,1,3,3,0,16,53,7,0,0,0,0,0,254,0,4,0,248,6,5,0,19,0,0,0,1,12,0,0,104,99,5,0,19,0,0,0,1,12,4,0,232,102,4,0,19,0,0,0,1,12,8,0,216,135,2,0,19,0,0,0,1,12,12,0,176,227,4,0,0,0,0,0,254,0,4,0,248,101,4,0,19,0,0,0,1,48,48,0,208,75,4,0,19,0,0,0,1,48,0,0,8,49,4,0,19,0,0,0,1,48,32,0,152,21,4,0,19,0,0,0,1,48,16,0,72,246,3,0,0,0,0,0,254,0,2,0,0,0,0,0,19,0,0,0,1,64,0,0,96,212,3,0,19,0,0,0,1,64,64,0,48,185,3,0,0,0,0,0,254,0,3,0,48,45,3,0,20,0,0,0,1,3,0,0,176,20,3,0,20,0,0,0,1,3,1,0,184,255,2,0,20,0,0,0,1,3,2,0,8,234,2,0,98,57,48,95,48,49,46,49,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,211,102,73,3,0,0,16,1,98,57,48,95,48,50,46,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,199,36,221,6,0,0,16,1,98,57,48,95,48,52,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,252,80,97,234,0,0,32,0,98,57,48,95,48,53,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,7,197,82,187,0,0,32,0,98,57,48,95,48,54,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,82,2,91,207,0,0,32,0,98,57,48,95,48,55,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,99,242,138,185,0,0,32,0,98,57,48,95,49,49,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,60,84,62,195,0,0,32,0,98,57,48,95,49,48,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,146,16,253,53,0,0,32,0,98,57,48,95,48,57,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,158,0,1,207,0,0,32,0,98,57,48,95,48,56,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,227,165,4,52,0,0,32,0,98,57,48,95,48,51,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,103,250,88,64,0,0,16,1,49,51,46,51,119,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,237,204,136,188,0,0,64,0,49,50,46,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,146,116,225,161,0,0,64,0,98,57,48,95,48,49,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,83,207,74,201,0,0,16,1,98,57,48,95,48,50,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,195,3,127,209,0,0,16,1,98,57,48,95,48,52,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,252,80,97,234,0,0,32,0,98,57,48,95,48,53,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,7,197,82,187,0,0,32,0,98,57,48,95,48,54,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,82,2,91,207,0,0,32,0,98,57,48,95,48,55,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,99,242,138,185,0,0,32,0,98,57,48,95,49,49,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,60,84,62,195,0,0,32,0,98,57,48,95,49,48,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,146,16,253,53,0,0,32,0,98,57,48,95,48,57,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,158,0,1,207,0,0,32,0,98,57,48,95,48,56,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,227,165,4,52,0,0,32,0,98,57,48,95,48,51,120,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,143,54,140,245,0,0,16,1,49,51,46,51,119,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,237,204,136,188,0,0,64,0,49,50,46,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,146,116,225,161,0,0,64,0,98,57,48,95,49,52,120,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,165,30,20,163,0,0,16,1,98,57,48,95,49,53,120,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,244,218,100,232,0,0,16,1,98,57,48,95,48,52,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,252,80,97,234,0,0,32,0,98,57,48,95,48,53,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,7,197,82,187,0,0,32,0,98,57,48,95,48,54,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,82,2,91,207,0,0,32,0,98,57,48,95,48,55,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,99,242,138,185,0,0,32,0,98,57,48,95,49,49,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,60,84,62,195,0,0,32,0,98,57,48,95,49,48,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,146,16,253,53,0,0,32,0,98,57,48,95,48,57,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,158,0,1,207,0,0,32,0,98,57,48,95,48,56,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,227,165,4,52,0,0,32,0,98,57,48,95,48,51,120,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,143,54,140,245,0,0,16,1,49,51,46,51,119,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,237,204,136,188,0,0,64,0,49,50,46,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,146,116,225,161,0,0,64,0,18,0,0,0,255,255,1,0,0,0,0,0,19,0,0,0,255,255,0,0,0,0,0,0,20,0,0,0,255,255,2,0,0,0,0,0,0,0,0,0,254,0,2,0,0,0,0,0,18,0,0,0,1,1,1,0,120,97,1,0,18,0,0,0,1,1,0,0,96,19,1,0,0,0,0,0,254,0,2,0,0,0,0,0,18,0,0,0,1,2,0,0,200,211,8,0,18,0,0,0,1,2,2,0,216,147,8,0,0,0,0,0,254,0,2,0,0,0,0,0,18,0,0,0,1,4,0,0,168,84,8,0,18,0,0,0,1,4,4,0,40,31,8,0,0,0,0,0,254,0,2,0,240,233,7,0,18,0,0,0,1,8,0,0,152,182,7,0,18,0,0,0,1,8,8,0,96,135,7,0,0,0,0,0,254,0,4,0,200,87,7,0,18,0,0,0,1,48,0,0,232,38,7,0,18,0,0,0,1,48,16,0,64,251,6,0,18,0,0,0,1,48,32,0,24,211,6,0,18,0,0,0,1,48,48,0,72,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,18,0,0,0,1,192,0,0,176,73,6,0,18,0,0,0,1,192,64,0,72,32,6,0,18,0,0,0,1,192,128,0,168,241,5,0,18,0,0,0,1,192,192,0,184,201,5,0,0,0,0,0,254,0,4,0,136,160,5,0,19,0,0,0,1,3,0,0,16,150,7,0,19,0,0,0,1,3,1,0,120,198,7,0,19,0,0,0,1,3,2,0,160,103,7,0,19,0,0,0,1,3,3,0,16,53,7,0,0,0,0,0,254,0,4,0,248,6,5,0,19,0,0,0,1,12,0,0,104,99,5,0,19,0,0,0,1,12,4,0,232,102,4,0,19,0,0,0,1,12,8,0,216,135,2,0,19,0,0,0,1,12,12,0,176,227,4,0,0,0,0,0,254,0,4,0,248,101,4,0,19,0,0,0,1,48,48,0,208,75,4,0,19,0,0,0,1,48,0,0,8,49,4,0,19,0,0,0,1,48,32,0,152,21,4,0,19,0,0,0,1,48,16,0,72,246,3,0,0,0,0,0,254,0,2,0,0,0,0,0,19,0,0,0,1,64,0,0,96,212,3,0,19,0,0,0,1,64,64,0,48,185,3,0,0,0,0,0,254,0,2,0,104,159,3,0,19,0,0,0,1,128,0,0,104,134,3,0,19,0,0,0,1,128,128,0,56,111,3,0,0,0,0,0,254,0,3,0,48,45,3,0,20,0,0,0,1,3,0,0,176,20,3,0,20,0,0,0,1,3,1,0,184,255,2,0,20,0,0,0,1,3,2,0,8,234,2,0,101,115,100,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,145,198,204,140,1,0,16,1,101,115,100,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,37,73,87,216,1,0,16,1,101,115,100,51,46,115,117,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,36,68,141,168,2,0,16,1,101,115,100,55,46,106,117,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,95,82,93,5,3,0,32,0,101,115,100,54,46,106,117,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,44,55,88,88,3,0,32,0,101,115,100,53,46,106,117,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,33,89,120,189,3,0,32,0,101,115,100,56,46,102,117,51,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,79,235,172,35,4,0,32,0,101,115,100,57,46,102,117,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,210,108,180,118,4,0,32,0,101,115,100,52,46,115,117,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,144,197,17,60,5,0,64,0,104,101,100,112,97,110,105,99,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,56,64,31,233,0,0,0,8,101,115,100,50,46,99,117,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,187,227,123,124,1,0,16,1,101,115,100,49,46,99,117,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,157,94,64,66,1,0,16,1,101,115,100,51,46,115,117,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,36,68,141,168,2,0,16,1,101,115,100,55,46,106,117,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,95,82,93,5,3,0,32,0,101,115,100,54,46,106,117,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,44,55,88,88,3,0,32,0,101,115,100,53,46,106,117,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,33,89,120,189,3,0,32,0,101,115,100,56,46,102,117,51,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,79,235,172,35,4,0,32,0,101,115,100,57,46,102,117,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,210,108,180,118,4,0,32,0,101,115,100,52,46,115,117,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,144,197,17,60,5,0,64,0,104,101,100,112,97,110,105,99,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,56,64,31,233,0,0,0,8,55,54,56,107,48,51,46,107,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,56,79,206,64,1,0,16,1,55,54,56,103,48,54,46,107,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,32,233,173,205,1,0,16,1,55,54,56,101,48,49,46,101,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,132,241,255,185,2,0,16,1,55,54,56,99,48,57,46,103,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,221,63,190,227,3,0,32,0,55,54,56,99,48,56,46,103,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,139,219,51,150,3,0,32,0,55,54,56,99,48,52,46,106,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,14,104,96,41,4,0,32,0,55,54,56,99,48,53,46,106,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,242,162,101,4,0,32,0,55,54,56,99,48,55,46,101,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,156,136,249,1,5,0,64,0,55,54,56,99,49,51,46,106,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,203,128,222,245,6,0,32,0,55,54,56,99,49,52,46,106,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,183,113,32,179,6,0,32,0,55,54,56,99,49,49,46,105,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,203,128,222,245,6,0,32,0,55,54,56,99,49,48,46,105,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,183,113,32,179,6,0,32,0,55,54,56,98,49,50,46,100,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,184,68,37,54,0,0,32,8,55,54,56,101,48,51,46,107,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,156,97,50,11,1,0,16,1,55,54,56,101,48,54,46,107,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,192,184,49,4,1,0,16,1,55,54,56,101,48,49,46,101,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,132,241,255,185,2,0,16,1,55,54,56,99,48,57,46,103,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,221,63,190,227,3,0,32,0,55,54,56,99,48,56,46,103,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,139,219,51,150,3,0,32,0,55,54,56,99,48,52,46,106,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,14,104,96,41,4,0,32,0,55,54,56,99,48,53,46,106,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,242,162,101,4,0,32,0,55,54,56,99,48,55,46,101,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,156,136,249,1,5,0,64,0,55,54,56,99,49,51,46,106,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,203,128,222,245,6,0,32,0,55,54,56,99,49,52,46,106,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,183,113,32,179,6,0,32,0,55,54,56,99,49,49,46,105,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,203,128,222,245,6,0,32,0,55,54,56,99,49,48,46,105,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,183,113,32,179,6,0,32,0,55,54,56,98,49,50,46,100,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,184,68,37,54,0,0,32,8,103,121,97,45,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,194,183,248,133,1,0,16,1,103,121,97,45,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,15,151,26,30,1,0,16,1,103,121,97,45,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,59,179,219,246,1,0,16,1,103,121,114,117,115,115,107,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,126,242,43,130,2,0,16,1,103,121,114,117,115,115,107,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,23,28,174,244,3,0,16,1,103,121,114,117,115,115,107,46,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,21,129,73,186,3,0,16,1,103,121,114,117,115,115,107,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,234,93,155,63,4,0,16,1,103,121,114,117,115,115,107,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,16,219,73,201,5,0,32,0,103,121,114,117,115,115,107,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,26,65,34,79,5,0,32,0,103,121,114,117,115,115,107,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,188,31,205,71,5,0,32,0,103,121,114,117,115,115,107,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,140,56,141,142,5,0,32,0,103,121,114,117,115,115,107,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,155,50,216,39,6,0,32,0,103,121,114,117,115,115,107,46,112,114,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,179,45,120,152,7,0,32,0,103,121,114,117,115,115,107,46,112,114,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,222,87,208,126,7,0,32,0,103,121,114,117,115,115,107,46,112,114,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,129,58,130,222,7,0,32,0,103,117,45,117,48,49,50,55,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,46,125,102,100,0,0,16,1,103,117,45,117,48,49,50,57,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,108,107,156,169,0,0,16,1,117,48,56,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,196,185,196,173,0,0,32,0,117,48,56,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,108,135,117,61,0,0,32,0,117,48,56,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,129,79,142,24,0,0,32,0,117,48,56,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,158,101,213,167,0,0,32,0,117,49,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,31,73,105,3,0,0,32,0,117,49,48,49,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,85,104,141,226,0,0,32,0,117,49,48,49,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,142,27,233,15,0,0,32,0,117,48,52,54,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,145,86,215,179,0,0,64,0,97,116,99,48,53,45,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,16,117,48,50,53,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,16,117,48,56,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,16,117,49,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,16,101,101,112,114,111,109,45,103,117,119,97,110,103,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,89,73,23,195,0,0,16,1,57,110,95,103,115,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,27,33,47,89,1,0,16,1,49,48,110,95,103,115,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,63,66,75,141,1,0,16,1,49,50,110,95,103,115,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,251,103,86,43,1,0,16,1,49,52,104,95,103,115,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,56,44,122,205,2,0,16,1,49,49,102,95,103,115,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,155,206,30,182,3,0,32,0,48,54,99,95,103,115,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,197,159,118,246,4,0,32,0,48,53,99,95,103,115,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,140,183,151,217,4,0,32,0,48,52,99,95,103,115,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,142,165,91,18,4,0,32,0,48,50,99,95,103,115,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,60,193,105,244,4,0,32,0,48,54,97,95,103,115,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,45,24,159,83,4,0,32,0,48,53,97,95,103,115,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,109,82,126,232,4,0,32,0,48,52,97,95,103,115,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,210,192,130,67,4,0,32,0,48,50,97,95,103,115,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,166,231,175,76,4,0,32,0,48,54,110,95,103,115,50,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,140,80,156,220,5,0,32,0,48,52,110,95,103,115,50,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,73,55,136,104,5,0,32,0,48,51,110,95,103,115,50,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,237,50,233,11,5,0,32,0,48,49,110,95,103,115,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,147,47,7,99,5,0,32,0,48,54,108,95,103,115,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,124,60,154,246,5,0,32,0,48,52,108,95,103,115,49,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,42,86,152,78,5,0,32,0,48,51,108,95,103,115,49,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,179,195,153,13,5,0,32,0,48,49,108,95,103,115,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,14,39,20,127,5,0,32,0,49,49,99,95,103,115,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,235,247,244,10,6,0,32,0,48,51,98,95,103,45,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,137,85,245,2,7,0,32,0,48,52,98,95,103,45,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,217,109,227,225,7,0,32,0,48,53,98,95,103,45,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,192,153,147,152,7,0,32,0,48,57,100,95,103,45,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,181,18,102,144,7,0,32,0,49,52,97,95,103,45,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,139,161,157,74,7,0,32,0,49,53,97,95,103,45,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,252,148,147,203,7,0,32,0,48,57,102,95,103,45,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,30,24,238,60,7,0,32,0,48,56,102,95,103,45,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,210,205,145,239,7,0,32,0,48,50,106,95,103,45,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,88,81,175,14,0,0,0,8,48,49,102,95,103,45,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,42,12,201,37,0,0,0,8,103,115,48,51,95,57,110,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,246,93,107,181,1,0,16,1,49,48,110,95,103,115,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,63,66,75,141,1,0,16,1,49,50,110,95,103,115,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,251,103,86,43,1,0,16,1,49,52,104,95,103,115,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,56,44,122,205,2,0,16,1,49,49,102,95,103,115,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,155,206,30,182,3,0,32,0,48,54,99,95,103,115,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,197,159,118,246,4,0,32,0,48,53,99,95,103,115,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,140,183,151,217,4,0,32,0,48,52,99,95,103,115,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,142,165,91,18,4,0,32,0,48,50,99,95,103,115,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,60,193,105,244,4,0,32,0,48,54,97,95,103,115,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,45,24,159,83,4,0,32,0,48,53,97,95,103,115,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,109,82,126,232,4,0,32,0,48,52,97,95,103,115,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,210,192,130,67,4,0,32,0,48,50,97,95,103,115,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,166,231,175,76,4,0,32,0,48,54,110,95,103,115,50,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,140,80,156,220,5,0,32,0,48,52,110,95,103,115,50,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,73,55,136,104,5,0,32,0,48,51,110,95,103,115,50,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,237,50,233,11,5,0,32,0,48,49,110,95,103,115,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,147,47,7,99,5,0,32,0,48,54,108,95,103,115,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,124,60,154,246,5,0,32,0,48,52,108,95,103,115,49,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,42,86,152,78,5,0,32,0,48,51,108,95,103,115,49,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,179,195,153,13,5,0,32,0,48,49,108,95,103,115,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,14,39,20,127,5,0,32,0,49,49,99,95,103,115,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,235,247,244,10,6,0,32,0,48,51,98,95,103,45,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,137,85,245,2,7,0,32,0,48,52,98,95,103,45,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,217,109,227,225,7,0,32,0,48,53,98,95,103,45,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,192,153,147,152,7,0,32,0,48,57,100,95,103,45,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,181,18,102,144,7,0,32,0,49,52,97,95,103,45,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,139,161,157,74,7,0,32,0,49,53,97,95,103,45,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,252,148,147,203,7,0,32,0,48,57,102,95,103,45,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,30,24,238,60,7,0,32,0,48,56,102,95,103,45,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,210,205,145,239,7,0,32,0,48,50,106,95,103,45,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,88,81,175,14,0,0,0,8,48,49,102,95,103,45,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,42,12,201,37,0,0,0,8,48,57,110,95,103,115,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,239,108,160,64,1,0,16,1,49,48,110,95,103,115,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,63,66,75,141,1,0,16,1,49,50,110,95,103,115,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,251,103,86,43,1,0,16,1,49,52,104,95,103,115,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,56,44,122,205,2,0,16,1,49,49,102,95,103,115,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,155,206,30,182,3,0,32,0,48,54,99,95,103,115,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,197,159,118,246,4,0,32,0,48,53,99,95,103,115,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,140,183,151,217,4,0,32,0,48,52,99,95,103,115,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,142,165,91,18,4,0,32,0,48,50,99,95,103,115,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,60,193,105,244,4,0,32,0,48,54,97,95,103,115,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,45,24,159,83,4,0,32,0,48,53,97,95,103,115,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,109,82,126,232,4,0,32,0,48,52,97,95,103,115,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,210,192,130,67,4,0,32,0,48,50,97,95,103,115,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,166,231,175,76,4,0,32,0,48,54,110,95,103,115,50,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,140,80,156,220,5,0,32,0,48,52,110,95,103,115,50,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,73,55,136,104,5,0,32,0,48,51,110,95,103,115,50,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,237,50,233,11,5,0,32,0,48,49,110,95,103,115,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,147,47,7,99,5,0,32,0,48,54,108,95,103,115,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,124,60,154,246,5,0,32,0,48,52,108,95,103,115,49,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,42,86,152,78,5,0,32,0,48,51,108,95,103,115,49,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,179,195,153,13,5,0,32,0,48,49,108,95,103,115,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,14,39,20,127,5,0,32,0,49,49,99,95,103,115,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,235,247,244,10,6,0,32,0,48,51,98,95,103,45,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,137,85,245,2,7,0,32,0,48,52,98,95,103,45,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,1,0,0,217,109,227,225,7,0,32,0,48,53,98,95,103,45,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,192,153,147,152,7,0,32,0,48,57,100,95,103,45,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,181,18,102,144,7,0,32,0,49,52,97,95,103,45,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,139,161,157,74,7,0,32,0,49,53,97,95,103,45,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,252,148,147,203,7,0,32,0,48,57,102,95,103,45,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,30,24,238,60,7,0,32,0,48,56,102,95,103,45,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,210,205,145,239,7,0,32,0,48,50,106,95,103,45,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,88,81,175,14,0,0,0,8,48,49,102,95,103,45,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,42,12,201,37,0,0,0,8,0,0,0,0,254,0,2,0,200,30,2,0,20,0,0,0,1,8,0,0,120,97,1,0,20,0,0,0,1,8,8,0,96,19,1,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,48,32,0,80,246,3,0,20,0,0,0,1,48,48,0,248,38,7,0,20,0,0,0,1,48,16,0,48,123,8,0,20,0,0,0,1,48,0,0,8,117,8,0,0,0,0,0,254,0,2,0,72,4,1,0,20,0,0,0,1,64,64,0,96,135,7,0,20,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,20,0,0,0,1,128,128,0,96,135,7,0,20,0,0,0,1,128,0,0,152,182,7,0,21,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,8,0,200,87,7,0,21,0,0,0,1,7,0,0,80,252,6,0,21,0,0,0,1,7,1,0,16,242,7,0,21,0,0,0,1,7,2,0,104,236,7,0,21,0,0,0,1,7,7,0,80,245,6,0,21,0,0,0,1,7,6,0,8,201,6,0,21,0,0,0,1,7,5,0,200,197,6,0,21,0,0,0,1,7,4,0,152,194,6,0,21,0,0,0,1,7,3,0,248,189,6,0,0,0,0,0,254,0,8,0,160,123,6,0,21,0,0,0,1,56,0,0,80,252,6,0,21,0,0,0,1,56,8,0,16,242,7,0,21,0,0,0,1,56,16,0,104,236,7,0,21,0,0,0,1,56,56,0,80,245,6,0,21,0,0,0,1,56,48,0,8,201,6,0,21,0,0,0,1,56,40,0,200,197,6,0,21,0,0,0,1,56,32,0,152,194,6,0,21,0,0,0,1,56,24,0,248,189,6,0,0,0,0,0,254,0,2,0,104,159,3,0,21,0,0,0,1,64,0,0,56,111,3,0,21,0,0,0,1,64,64,0,104,134,3,0,0,0,0,0,254,0,2,0,168,234,7,0,21,0,0,0,1,128,0,0,96,135,7,0,21,0,0,0,1,128,128,0,152,182,7,0,0,0,0,0,103,115,48,51,46,57,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,118,63,220,81,1,0,16,1,103,115,48,52,46,49,48,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,184,49,207,94,1,0,16,1,103,115,48,53,46,49,50,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,19,202,154,28,1,0,16,1,49,52,104,95,103,115,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,56,44,122,205,2,0,16,1,49,49,102,95,103,115,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,155,206,30,182,3,0,32,0,48,54,99,95,103,115,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,197,159,118,246,4,0,32,0,48,53,99,95,103,115,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,140,183,151,217,4,0,32,0,48,52,99,95,103,115,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,142,165,91,18,4,0,32,0,48,50,99,95,103,115,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,60,193,105,244,4,0,32,0,48,54,97,95,103,115,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,45,24,159,83,4,0,32,0,48,53,97,95,103,115,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,109,82,126,232,4,0,32,0,48,52,97,95,103,115,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,210,192,130,67,4,0,32,0,48,50,97,95,103,115,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,166,231,175,76,4,0,32,0,48,54,110,95,103,115,50,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,140,80,156,220,5,0,32,0,48,52,110,95,103,115,50,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,73,55,136,104,5,0,32,0,48,51,110,95,103,115,50,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,237,50,233,11,5,0,32,0,48,49,110,95,103,115,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,147,47,7,99,5,0,32,0,48,54,108,95,103,115,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,124,60,154,246,5,0,32,0,48,52,108,95,103,115,49,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,42,86,152,78,5,0,32,0,48,51,108,95,103,115,49,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,179,195,153,13,5,0,32,0,48,49,108,95,103,115,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,14,39,20,127,5,0,32,0,49,49,99,95,103,115,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,235,247,244,10,6,0,32,0,48,51,98,95,103,45,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,137,85,245,2,7,0,32,0,48,52,98,95,103,45,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,217,109,227,225,7,0,32,0,48,53,98,95,103,45,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,192,153,147,152,7,0,32,0,48,57,100,95,103,45,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,181,18,102,144,7,0,32,0,49,52,97,95,103,45,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,139,161,157,74,7,0,32,0,49,53,97,95,103,45,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,252,148,147,203,7,0,32,0,48,57,102,95,103,45,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,30,24,238,60,7,0,32,0,48,56,102,95,103,45,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,210,205,145,239,7,0,32,0,48,50,106,95,103,45,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,88,81,175,14,0,0,0,8,48,49,102,95,103,45,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,42,12,201,37,0,0,0,8,20,0,0,0,255,255,247,0,0,0,0,0,0,0,0,0,254,0,4,0,64,37,5,0,20,0,0,0,1,3,1,0,128,252,7,0,20,0,0,0,1,3,3,0,136,199,7,0,20,0,0,0,1,3,0,0,248,150,7,0,20,0,0,0,1,3,2,0,8,133,7,0,0,0,0,0,254,0,2,0,8,54,7,0,20,0,0,0,1,4,4,0,8,49,4,0,20,0,0,0,1,4,0,0,72,246,3,0,0,0,0,0,109,114,45,104,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,112,34,53,131,1,0,16,1,109,114,45,108,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,174,8,179,157,1,0,16,1,109,114,45,104,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,96,43,83,201,1,0,16,1,109,114,45,108,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,32,181,73,99,1,0,16,1,109,114,45,115,104,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,228,53,211,80,2,0,16,1,109,114,45,115,108,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,33,39,163,15,2,0,16,1,109,114,45,99,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,173,143,42,135,3,0,32,0,109,114,45,99,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,122,178,255,210,3,0,32,0,109,114,45,99,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,135,242,191,98,3,0,32,0,109,114,45,99,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,171,98,218,208,3,0,32,0,109,114,45,111,48,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,22,206,249,160,4,0,32,0,109,114,45,111,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,233,169,112,78,4,0,32,0,109,114,45,111,50,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,252,104,196,185,4,0,32,0,109,114,45,111,51,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,58,67,50,204,4,0,32,0,109,114,45,100,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,89,252,17,26,5,0,64,0,103,102,95,104,48,45,99,46,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,52,182,155,192,1,0,16,1,103,102,95,108,48,45,99,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,125,111,239,27,1,0,16,1,103,102,95,104,49,45,99,46,53,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,183,136,65,200,1,0,16,1,103,102,95,108,49,45,99,46,53,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,42,247,137,177,1,0,16,1,103,102,95,115,104,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,224,22,143,63,2,0,16,1,103,102,95,115,108,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,163,19,11,219,2,0,16,1,103,102,95,99,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,121,73,183,179,3,0,32,0,103,102,95,99,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,10,89,200,245,3,0,32,0,103,102,95,99,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,100,251,249,48,3,0,32,0,103,102,95,99,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,33,230,179,135,3,0,32,0,103,102,95,48,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,141,142,158,32,4,0,32,0,103,102,95,48,49,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,8,120,110,110,4,0,32,0,103,102,95,48,50,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,176,60,92,111,4,0,32,0,103,102,95,48,51,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,159,138,151,24,4,0,32,0,103,102,45,100,97,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,53,169,59,147,5,0,64,0,97,50,45,104,48,45,97,46,54,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,34,94,150,73,1,0,16,1,97,50,45,108,48,45,97,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,120,178,136,140,1,0,16,1,97,50,45,104,49,45,97,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,136,11,40,52,1,0,16,1,97,50,45,108,49,45,97,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,81,63,193,200,1,0,16,1,97,50,95,115,104,48,46,51,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,61,16,45,46,2,0,16,1,97,50,95,115,108,48,46,53,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,179,224,135,34,2,0,16,1,97,50,95,99,48,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,116,245,184,104,3,0,32,0,97,50,95,99,49,46,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,103,254,158,11,3,0,32,0,97,50,95,99,50,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,120,153,158,122,3,0,32,0,97,50,95,99,51,46,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,109,238,149,19,3,0,32,0,97,50,95,48,48,48,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,71,49,224,56,4,0,32,0,97,50,95,48,49,48,46,56,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,248,5,91,29,4,0,32,0,97,50,95,48,50,48,46,56,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,204,97,244,242,4,0,32,0,97,50,95,48,51,48,46,56,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,157,157,96,151,4,0,32,0,97,50,95,100,97,46,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,106,219,140,60,5,0,64,0,98,112,103,104,45,48,48,51,46,117,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,10,151,233,20,1,0,16,1,98,112,103,104,45,48,48,52])
.concat([46,117,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,88,198,223,150,1,0,16,1,98,112,103,104,45,48,48,50,46,49,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,226,88,47,49,1,0,16,1,98,112,103,104,45,48,48,49,46,49,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,60,162,35,141,1,0,16,1,98,112,103,104,45,48,48,56,46,117,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,114,210,217,126,3,0,32,0,98,112,103,104,45,48,48,54,46,50,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,29,65,129,90,3,0,32,0,98,112,103,104,45,48,48,55,46,117,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,123,206,73,170,3,0,32,0,98,112,103,104,45,48,48,53,46,50,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,102,130,19,116,3,0,32,0,98,112,103,104,45,48,49,48,46,117,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,184,240,66,183,4,0,32,0,98,112,103,104,45,48,48,57,46,117,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,102,230,104,183,28,0,32,0,98,112,103,104,45,48,49,50,46,117,54,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,149,165,253,237,5,0,32,0,98,112,103,104,45,48,49,49,46,117,54,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,112,242,175,73,29,0,32,0,98,112,103,104,45,48,49,51,46,117,55,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,3,213,165,15,6,0,64,0,107,97,48,48,50,48,48,50,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,216,246,80,232,0,0,16,1,107,97,48,48,50,48,48,52,46,117,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,8,18,251,192,0,0,16,1,107,97,48,48,50,48,48,49,46,117,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,107,190,62,85,0,0,16,1,107,97,48,48,50,48,48,51,46,117,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,170,133,97,148,0,0,16,1,107,97,48,48,49,48,48,53,46,117,55,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,61,29,240,0,0,16,1,107,97,48,48,49,48,48,57,46,117,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,147,141,125,153,0,0,32,0,107,97,48,48,49,48,49,48,46,117,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,202,103,27,129,0,0,32,0,107,97,48,48,49,48,49,49,46,117,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,39,167,8,0,0,32,0,107,97,48,48,49,48,49,50,46,117,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,168,228,137,183,0,0,32,0,107,97,48,48,49,48,49,51,46,117,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,31,32,160,216,0,0,32,0,107,97,48,48,49,48,49,52,46,117,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,38,224,53,118,0,0,32,0,107,97,48,48,49,48,48,54,46,117,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,47,47,172,106,0,0,32,0,107,97,48,48,49,48,48,55,46,117,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,99,157,143,88,0,0,32,0,107,97,48,48,49,48,48,56,46,117,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,10,166,85,219,0,0,32,0,107,97,48,48,49,48,49,53,46,117,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,59,132,162,173,0,0,64,0,101,101,112,114,111,109,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,72,226,248,128,0,0,0,8,49,107,46,117,52,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,238,92,116,0,0,16,1,50,107,46,117,51,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,251,50,150,102,0,0,16,1,117,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,138,126,125,0,0,32,0,117,50,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,157,252,63,94,0,0,32,0,117,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,181,191,39,168,0,0,32,0,117,50,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,12,46,101,239,0,0,32,0,117,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,178,174,5,9,0,0,32,0,117,51,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,107,78,73,84,0,0,32,0,107,51,46,117,55,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,85,64,153,17,0,0,16,1,117,54,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,79,237,135,225,0,0,64,0,117,53,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,77,16,7,158,0,0,64,0,49,46,117,52,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,105,189,74,71,0,0,16,1,50,46,117,51,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,31,102,62,62,0,0,16,1,117,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,138,126,125,0,0,32,0,117,50,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,157,252,63,94,0,0,32,0,117,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,181,191,39,168,0,0,32,0,117,50,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,12,46,101,239,0,0,32,0,117,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,178,174,5,9,0,0,32,0,117,51,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,107,78,73,84,0,0,32,0,51,46,117,55,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,186,228,104,33,0,0,16,1,117,54,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,79,237,135,225,0,0,64,0,117,53,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,77,16,7,158,0,0,64,0,50,95,112,114,111,103,95,108,46,117,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,240,52,249,118,1,0,16,1,49,95,112,114,111,103,95,104,46,117,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,191,216,40,115,1,0,16,1,51,95,112,100,97,116,97,46,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,230,151,182,165,1,0,16,1,48,108,46,117,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,200,107,130,92,2,0,32,0,48,104,46,117,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,108,203,240,61,2,0,32,0,49,108,46,117,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,141,53,88,21,2,0,32,0,49,104,46,117,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,59,16,224,78,2,0,32,0,50,108,46,117,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,184,167,199,225,2,0,32,0,50,104,46,117,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,223,65,138,188,2,0,32,0,51,108,46,117,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,127,211,41,2,2,0,32,0,51,104,46,117,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,43,191,27,244,2,0,32,0,115,111,117,110,100,46,117,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,171,150,151,241,3,0,64,0,101,101,112,114,111,109,45,103,117,110,98,105,114,100,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,70,136,195,122,0,0,0,8,103,115,95,49,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,32,169,87,26,0,0,16,1,103,115,95,49,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,119,142,95,128,0,0,16,1,97,54,56,95,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,23,218,103,53,0,0,16,1,97,54,56,45,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,130,178,63,100,0,0,32,0,97,54,56,45,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,50,78,247,17,0,0,32,0,97,54,56,45,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,207,88,65,242,0,0,32,0,97,54,56,45,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,208,30,22,131,0,0,32,0,97,54,56,95,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,231,9,212,227,0,0,32,0,97,54,56,95,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,212,201,90,110,0,0,32,0,97,54,56,95,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,46,204,147,162,0,0,32,0,97,54,56,95,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,117,35,102,55,0,0,32,0,97,54,56,95,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,76,150,26,207,0,0,32,0,97,54,56,95,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,154,235,249,5,0,0,32,0,114,111,109,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,77,11,54,214,0,0,32,0,114,111,109,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,135,24,160,76,0,0,32,0,114,111,109,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,240,36,50,81,0,0,32,0,97,54,56,45,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,76,164,218,24,0,0,16,1,103,115,95,114,98,95,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,224,215,250,154,0,0,16,1,103,115,95,114,98,95,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,96,10,235,95,0,0,16,1,103,115,95,114,98,95,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,186,177,207,227,0,0,16,1,97,54,56,45,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,130,178,63,100,0,0,32,0,97,54,56,45,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,50,78,247,17,0,0,32,0,97,54,56,45,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,207,88,65,242,0,0,32,0,97,54,56,45,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,208,30,22,131,0,0,32,0,97,54,56,95,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,231,9,212,227,0,0,32,0,97,54,56,95,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,212,201,90,110,0,0,32,0,97,54,56,95,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,46,204,147,162,0,0,32,0,97,54,56,95,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,117,35,102,55,0,0,32,0,97,54,56,95,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,76,150,26,207,0,0,32,0,97,54,56,95,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,154,235,249,5,0,0,32,0,114,111,109,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,77,11,54,214,0,0,32,0,114,111,109,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,135,24,160,76,0,0,32,0,114,111,109,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,240,36,50,81,0,0,32,0,97,54,56,45,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,76,164,218,24,0,0,16,1,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,144,247,35,73,0,0,16,1,116,112,48,50,55,95,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,232,69,123,135,0,0,32,0,116,112,48,50,55,95,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,98,99,252,177,0,0,32,0,116,112,48,50,55,45,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,146,3,140,141,0,0,16,1,116,112,48,50,55,95,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,232,69,123,135,0,0,32,0,116,112,48,50,55,95,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,98,99,252,177,0,0,32,0,97,102,101,103,97,52,46,117,49,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,58,113,68,34,1,0,16,1,97,102,101,103,97,53,46,117,49,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,6,200,21,88,1,0,16,1,97,102,101,103,97,55,46,117,57,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,142,242,140,93,2,0,16,1,97,102,101,103,97,49,46,117,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,134,240,126,158,3,0,32,0,97,102,101,103,97,95,97,102,49,45,98,50,46,117,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,194,136,133,214,4,0,32,0,97,102,101,103,97,95,97,102,49,45,98,49,46,117,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,168,0,178,248,4,0,32,0,97,102,101,103,97,51,46,117,99,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,124,1,24,2,5,0,32,0,97,102,101,103,97,49,46,117,57,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,51,206,17,233,6,0,64,0,57,52,53,95,49,51,46,102,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,107,254,116,153,1,0,16,1,57,52,53,95,49,50,46,101,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,145,27,119,233,1,0,16,1,57,52,53,95,109,48,57,46,114,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,37,223,166,180,2,0,16,1,57,52,53,95,109,48,56,46,110,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,210,129,233,116,2,0,16,1,57,52,53,95,108,48,54,98,46,114,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,4,35,119,131,2,0,16,1,57,52,53,95,108,48,54,97,46,110,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,182,117,253,225,2,0,16,1,57,52,53,95,108,48,55,99,46,114,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,182,153,227,193,2,0,16,1,57,52,53,95,108,48,55,97,46,110,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,4,45,34,150,2,0,16,1,57,52,53,95,108,48,55,100,46,114,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,189,212,22,76,2,0,16,1,57,52,53,95,108,48,55,98,46,110,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,1,157,32,94,2,0,16,1,57,52,53,95,109,48,53,46,100,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,101,83,196,200,3,0,16,1,57,52,53,95,97,48,50,46,108,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,116,253,255,77,4,0,32,0,57,52,53,95,108,48,52,97,46,107,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,238,33,78,136,4,0,32,0,57,52,53,95,108,48,52,99,46,109,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,33,217,188,69,4,0,32,0,57,52,53,95,108,48,52,98,46,107,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,125,198,59,132,4,0,32,0,57,52,53,95,108,48,52,100,46,109,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,142,208,152,10,4,0,32,0,57,52,53,95,97,48,49,46,104,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,210,109,157,51,4,0,32,0,57,52,53,95,108,48,51,97,46,101,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,135,240,126,166,4,0,32,0,57,52,53,95,108,48,51,99,46,104,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,122,225,107,165,4,0,32,0,57,52,53,95,108,48,51,98,46,101,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,185,104,62,147,4,0,32,0,57,52,53,95,108,48,51,100,46,104,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,123,232,117,243,4,0,32,0,57,52,53,95,97,49,48,46,98,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,16,62,8,29,5,0,64,0,57,52,53,95,108,49,49,97,46,99,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,235,244,67,96,5,0,64,0,57,52,53,95,108,49,49,98,46,99,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,175,59,234,137,5,0,64,0,57,52,53,108,49,52,46,106,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,137,193,120,199,6,0,0,8,55,56,53,95,120,48,53,46,54,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,184,167,35,138,1,0,16,1,55,56,53,95,120,48,52,46,52,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,206,102,228,136,1,0,16,1,55,56,53,95,120,48,57,46,54,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,122,125,61,63,1,0,16,1,55,56,53,95,120,48,56,46,52,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,253,142,156,195,1,0,16,1,55,56,53,95,112,48,55,46,49,48,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,157,84,109,104,2,0,16,1,55,56,53,95,112,48,54,46,56,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,238,75,201,112,2,0,16,1,55,56,53,95,112,49,51,46,49,48,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,10,219,143,71,2,0,16,1,55,56,53,95,112,49,50,46,56,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,42,64,234,56,2,0,16,1,55,56,53,95,103,48,51,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,13,181,163,103,3,0,16,1,55,56,53,95,103,49,52,46,100,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,157,173,205,157,4,0,32,0,103,114,50,46,112,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,130,123,122,78,5,0,32,0,103,114,50,46,112,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,154,78,96,63,5,0,32,0,103,114,50,46,112,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,172,57,210,91,5,0,32,0,103,114,50,46,112,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,163,184,198,149,5,0,32,0,55,56,53,95,102,48,49,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,158,214,216,160,7,0,64,0,55,56,53,95,102,48,50,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,164,92,159,195,8,0,64,0,48,50,48,45,104,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,206,1,219,124,1,0,16,1,48,50,48,45,112,50,46,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,172,34,203,237,1,0,16,1,48,50,48,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,83,61,216,166,2,0,32,0,48,50,48,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,142,231,111,189,3,0,32,0,48,50,48,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,92,146,74,95,3,0,32,0,48,50,48,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,208,47,228,209,3,0,32,0,48,50,48,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,155,67,222,237,3,0,32,0,48,50,48,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,119,147,64,72,4,0,16,1,48,50,48,45,118,49,49,46,118,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,139,108,82,27,5,0,64,0,48,50,48,45,118,49,50,46,118,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,3,111,158,74,5,0,64,0,48,50,48,45,118,50,49,46,118,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,61,17,191,122,6,0,64,0,48,57,52,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,69,149,1,51,1,0,16,1,48,57,52,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,162,72,135,47,2,0,32,0,48,57,52,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,245,106,47,4,3,0,32,0,48,57,52,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,70,208,188,15,3,0,32,0,48,57,52,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,161,186,191,88,3,0,32,0,48,57,52,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,115,238,81,148,3,0,32,0,48,57,52,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,140,244,156,255,3,0,32,0,48,57,52,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,24,217,187,49,3,0,32,0,48,57,52,45,99,55,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,4,236,145,32,3,0,32,0,48,57,52,45,99,56,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,65,210,13,216,3,0,32,0,48,57,52,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,203,81,200,120,4,0,16,1,48,57,52,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,60,34,49,108,5,0,64,0,48,57,52,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,108,119,219,142,5,0,64,0,48,57,52,45,118,51,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,133,146,59,198,5,0,64,0,0,15,66,64,8,10,0,0,1,6,66,89,0,0,0,0,49,45,112,114,111,103,95,104,46,117,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,150,252,136,101,1,0,16,1,50,45,112,114,111,103,95,108,46,117,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,156,205,54,193,1,0,16,1,54,108,46,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,168,225,50,4,2,0,32,0,54,104,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,234,163,15,249,2,0,32,0,55,108,46,117,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,88,154,191,54,2,0,32,0,55,104,46,117,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,216,175,62,75,2,0,32,0,56,108,46,117,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,218,84,103,2,2,0,32,0,56,104,46,117,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,160,170,215,140,2,0,32,0,57,108,46,117,52,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,254,102,192,2,2,0,32,0,57,104,46,117,52,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,90,56,51,84,2,0,32,0,115,110,100,48,46,117,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,107,67,16,123,3,0,64,0,101,101,112,114,111,109,45,103,110,98,97,114,105,99,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,47,244,91,15,0,0,0,8,0,0,0,0,0,0,0,0,103,110,95,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,47,1,78,74,1,0,16,1,103,110,95,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,203,111,37,48,1,0,16,1,103,110,95,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,231,16,110,231,2,0,16,1,103,110,95,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,251,201,138,27,3,0,32,0,103,110,95,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,104,230,63,231,3,0,32,0,103,110,95,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,233,161,52,193,4,0,32,0,103,110,95,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,33,236,59,29,4,0,32,0,103,110,95,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,45,27,55,174,5,0,32,0,103,110,95,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,53,88,198,189,6,0,32,0,103,110,95,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,254,234,184,194,6,0,32,0,103,110,95,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,24,60,199,247,6,0,32,0,103,110,95,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,59,124,224,165,6,0,32,0,103,110,95,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,5,230,208,240,7,0,32,0,103,110,95,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,59,19,217,14,8,0,64,0,103,110,95,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,44,34,186,241,8,0,64,0,112,114,111,116,111,95,50,50,56,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,46,23,51,96,1,0,16,1,112,114,111,116,111,95,50,50,56,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,129,78,194,131,2,0,32,0,112,114,111,116,111,95,50,50,56,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,254,158,201,191,3,0,32,0,112,114,111,116,111,95,50,50,56,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,130,128,120,105,3,0,32,0,112,114,111,116,111,95,50,50,56,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,51,59,131,253,4,0,16,1,112,114,111,116,111,95,50,50,56,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,230,252,3,198,5,0,64,0,97,54,56,95,48,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,67,1,26,173,0,0,16,1,97,54,56,95,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,124,235,38,52,0,0,16,1,97,54,56,95,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,23,218,103,53,0,0,16,1,97,54,56,45,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,130,178,63,100,0,0,32,0,97,54,56,45,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,50,78,247,17,0,0,32,0,97,54,56,45,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,207,88,65,242,0,0,32,0,97,54,56,45,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,208,30,22,131,0,0,32,0,97,54,56,95,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,231,9,212,227,0,0,32,0,97,54,56,95,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,212,201,90,110,0,0,32,0,97,54,56,95,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,46,204,147,162,0,0,32,0,97,54,56,95,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,117,35,102,55,0,0,32,0,97,54,56,95,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,76,150,26,207,0,0,32,0,97,54,56,95,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,154,235,249,5,0,0,32,0,114,111,109,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,77,11,54,214,0,0,32,0,114,111,109,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,135,24,160,76,0,0,32,0,114,111,109,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,240,36,50,81,0,0,32,0,97,54,56,45,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,76,164,218,24,0,0,16,1,54,56,55,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,16,24,103,101,111,45,104,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,9,141,229,155,1,0,16,1,103,101,111,45,108,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,93,183,171,89,1,0,16,1,97,50,45,104,49,45,97,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,136,11,40,52,1,0,16,1,97,50,45,108,49,45,97,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,81,63,193,200,1,0,16,1,97,50,95,115,104,48,46,51,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,61,16,45,46,2,0,16,1,97,50,95,115,108,48,46,53,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,179,224,135,34,2,0,16,1,97,50,95,99,48,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,116,245,184,104,3,0,32,0,97,50,95,99,49,46,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,103,254,158,11,3,0,32,0,97,50,95,99,50,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,120,153,158,122,3,0,32,0,97,50,95,99,51,46,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,109,238,149,19,3,0,32,0,97,50,95,48,48,48,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,71,49,224,56,4,0,32,0,97,50,95,48,49,48,46,56,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,248,5,91,29,4,0,32,0,97,50,95,48,50,48,46,56,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,204,97,244,242,4,0,32,0,97,50,95,48,51,48,46,56,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,157,157,96,151,4,0,32,0,97,50,95,100,97,46,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,106,219,140,60,5,0,64,0,56,55,56,110,48,50,46,107,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,170,122,105,81,1,0,16,1,56,55,56,106,48,51,46,107,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,101,160,67,57,1,0,16,1,56,55,56,104,48,49,46,102,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,170,175,254,150,2,0,16,1,56,55,56,99,48,55,46,104,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,44,145,237,238,3,0,32,0,56,55,56,99,48,56,46,107,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,109,98,20,77,3,0,32,0,56,55,56,99,48,53,46,104,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,165,174,244,1,4,0,32,0,56,55,56,99,48,54,46,107,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,175,170,250,237,4,0,32,0,56,55,56,99,48,52,46,100,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,28,45,152,158,5,0,64,0,56,55,56,97,48,57,46,102,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,27,154,208,226,6,0,0,8,56,55,56,95,48,50,46,107,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,20,132,23,87,1,0,16,1,56,55,56,95,48,51,46,107,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,96,230,89,108,1,0,16,1,56,55,56,104,48,49,46,102,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,170,175,254,150,2,0,16,1,56,55,56,99,48,55,46,104,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,44,145,237,238,3,0,32,0,56,55,56,99,48,56,46,107,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,109,98,20,77,3,0,32,0,56,55,56,99,48,53,46,104,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,165,174,244,1,4,0,32,0,56,55,56,99,48,54,46,107,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,175,170,250,237,4,0,32,0,56,55,56,99,48,52,46,100,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,28,45,152,158,5,0,64,0,56,55,56,97,48,57,46,102,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,27,154,208,226,6,0,0,8,103,98,95,48,52,45,52,46,106,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,253,11,58,142,1,0,16,1,103,98,95,48,49,45,52,46,104,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,131,211,15,141,1,0,16,1,103,98,95,48,48,46,104,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,161,22,140,168,1,0,16,1,103,98,95,48,53,46,106,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,20,126,45,37,1,0,16,1,102,122,95,48,54,45,49,46,106,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,109,138,130,196,2,0,16,1,102,122,95,48,50,46,106,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,18,48,156,60,3,0,32,0,102,122,95,48,51,46,106,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,237,144,75,38,3,0,32,0,109,97,99,45,48,51,46,104,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,220,243,150,153,4,0,32,0,109,97,99,45,48,50,46,101,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,137,78,80,73,5,0,32,0,109,97,99,45,48,48,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,214,241,172,82,6,0,32,0,109,97,99,45,48,49,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,132,117,143,178,6,0,32,0,102,122,95,48,56,46,108,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,225,104,191,201,7,0,64,0,102,122,95,48,55,46,107,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,203,211,141,88,8,0,64,0,103,98,95,48,52,46,106,49,50,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,43,189,59,76,1,0,16,1,103,98,95,48,49,46,104,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,244,103,227,89,1,0,16,1,103,98,95,48,48,46,104,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,161,22,140,168,1,0,16,1,103,98,95,48,53,46,106,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,20,126,45,37,1,0,16,1,102,122,95,48,54,45,49,46,106,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,109,138,130,196,2,0,16,1,102,122,95,48,50,46,106,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,18,48,156,60,3,0,32,0,102,122,95,48,51,46,106,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,237,144,75,38,3,0,32,0,109,97,99,45,48,51,46,104,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,220,243,150,153,4,0,32,0,109,97,99,45,48,50,46,101,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,137,78,80,73,5,0,32,0,109,97,99,45,48,48,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,214,241,172,82,6,0,32,0,109,97,99,45,48,49,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,132,117,143,178,6,0,32,0,102,122,95,48,56,46,108,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,225,104,191,201,7,0,64,0,102,122,95,48,55,46,107,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,203,211,141,88,8,0,64,0,100,118,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,5,175,234,204,1,0,0,0,100,118,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,138,193,63,195,1,0,0,0,100,118,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,231,108,226,249,1,0,0,0,100,118,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,153,214,216,85,1,0,0,0,100,118,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,238,0,61,237,1,0,0,0,100,118,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,127,52,124,201,2,0,0,0,100,118,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,129,197,43,251,3,0,0,0,100,118,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,126,54,240,206,4,0,0,0,100,118,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,183,47,4,144,4,0,0,0,100,118,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,140,45,26,69,4,0,0,0,100,118,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,91,71,225,20,4,0,0,0,100,118,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,173,190,67,112,4,0,0,0,100,118,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,215,73,244,40,4,0,0,0,100,118,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,30,151,228,55,4,0,0,0,100,118,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,172,182,65,202,4,0,0,0,100,118,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,21,62,193,137,5,0,0,0,100,118,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,35,90,52,106,5,0,0,0,100,118,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,32,42,181,30,5,0,0,0,100,118,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,248,110,52,231,5,0,0,0,100,118,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,244,90,186,70,5,0,0,0,100,118,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,253,109,175,167,5,0,0,0,100,118,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,92,215,182,104,5,0,0,0,100,118,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,238,138,148,181,5,0,0,0,100,118,95,95,46,109,99,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,198,206,202,55,6,0,0,8,114,100,95,48,48,45,48,46,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,187,67,15,248,1,0,16,1,109,99,98,45,48,48,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,43,79,138,196,2,0,32,0,109,99,98,45,48,50,46,49,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,56,251,60,66,3,0,32,0,109,99,98,45,48,53,46,49,52,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,251,12,84,129,3,0,32,0,109,99,98,45,48,49,46,49,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,87,10,244,6,3,0,32,0,109,99,98,45,48,51,46,49,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,175,115,239,10,3,0,32,0,114,100,95,48,49,45,48,46,49,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,198,24,253,112,4,0,64,0,109,99,98,45,48,52,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,144,53,61,226,5,0,64,0,101,101,112,114,111,109,45,103,97,110,103,111,110,116,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,165,96,186,39,6,0,16,1,55,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,191,137,1,206,1,0,16,1,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,68,135,10,155,1,0,16,1,56,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,135,240,226,238,1,0,16,1,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,137,132,41,86,1,0,16,1,57,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,76,150,228,217,1,0,16,1,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,228,30,231,165,1,0,16,1,49,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,229,225,32,58,1,0,16,1,54,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,32,125,146,148,1,0,16,1,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,167,136,230,250,2,0,16,1,49,55,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,1,87,67,125,3,0,32,0,49,56,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,172,218,106,19,3,0,32,0,49,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,13,132,235,75,4,0,32,0,49,54,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,16,198,211,147,4,0,32,0,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,61,109,192,147,5,0,64,0,103,109,45,112,114,103,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,83,7,167,50,2,0,16,1,103,109,45,112,114,103,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,164,70,229,250,2,0,16,1,103,109,45,51,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,7,164,162,77,1,0,16,1,103,109,45,115,110,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,33,108,245,214,9,0,16,1,103,109,45,115,99,110,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,129,5,171,59,11,0,32,0,103,109,45,111,98,106,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,21,19,74,122,15,0,32,0,48,55,56,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,9,99,144,69,1,0,16,1,48,55,56,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,62,146,248,114,2,0,32,0,48,55,56,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,192,199,144,200,3,0,32,0,48,55,56,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,25,84,210,182,3,0,32,0,48,55,56,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,97,231,135,157,3,0,32,0,48,55,56,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,184,124,93,118,3,0,32,0,48,55,56,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,106,126,183,230,3,0,32,0,48,55,56,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,129,161,121,215,3,0,32,0,48,55,56,45,99,55,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,128,213,39,79,3,0,32,0,48,55,56,45,99,56,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,216,192,124,10,3,0,32,0,48,55,56,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,16,59,158,142,4,0,16,1,48,55,56,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,172,53,183,227,5,0,64,0,48,55,56,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,194,120,142,106,5,0,64,0,48,55,56,45,118,51,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,86,166,188,112,5,0,64,0,97,46,117,98,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,221,156,121,78,1,0,16,1,102,46,117,103,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,61,22,215,100,2,0,32,0,103,46,117,104,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,184,226,145,104,2,0,32,0,104,46,117,103,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,40,117,127,202,2,0,32,0,105,46,117,104,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,198,142,96,35,2,0,32,0,108,46,117,103,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,67,129,207,10,2,0,32,0,109,46,117,104,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,156,141,237,85,2,0,32,0,110,46,117,103,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,104,139,57,82,2,0,32,0,111,46,117,104,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,178,49,110,68,2,0,32,0,100,46,117,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,188,235,183,3,0,32,0,101,46,117,103,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,150,195,175,40,3,0,32,0,106,46,117,103,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,205,135,134,158,3,0,32,0,107,46,117,103,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,16,232,240,99,3,0,32,0,112,46,115,117,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,77,157,22,51,4,0,16,1,98,46,115,117,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,244,128,215,162,5,0,64,0,99,46,115,117,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,105,146,126,31,5,0,64,0,50,46,117,98,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,63,193,132,214,1,0,16,1,55,46,117,103,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,123,61,96,135,2,0,32,0,56,46,117,104,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,189,49,96,171,2,0,32,0,57,46,117,103,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,255,82,131,14,2,0,32,0,49,48,46,117,104,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,86,211,125,223,2,0,32,0,49,51,46,117,103,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,213,189,87,159,2,0,32,0,49,52,46,117,104,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,163,94,193,42,2,0,32,0,49,53,46,117,103,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,166,102,94,154,2,0,32,0,49,54,46,117,104,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,179,96,128,33,2,0,32,0,53,46,117,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,188,235,183,3,0,32,0,54,46,117,103,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,150,195,175,40,3,0,32,0,49,49,46,117,103,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,205,135,134,158,3,0,32,0,49,50,46,117,103,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,16,232,240,99,3,0,32,0,49,46,115,117,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,77,157,22,51,4,0,16,1,51,46,115,117,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,244,128,215,162,5,0,64,0,52,46,115,117,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,105,146,126,31,5,0,64,0,106,107,48,48,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,193,137,32,113,1,0,16,1,106,107,48,49,46,49,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,215,32,57,190,1,0,16,1,106,107,48,50,46,49,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,216,11,140,116,2,0,16,1,109,97,116,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,126,76,185,228,3,0,32,0,109,97,116,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,141,58,9,36,4,0,32,0,109,97,116,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,40,2,218,251,4,0,32,0,106,107,48,51,46,49,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,247,234,160,105,5,0,64,0,102,117,110,107,121,98,101,101,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,51,203,114,51,1,0,16,1,102,117,110,107,121,98,101,101,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,47,198,247,123,1,0,16,1,102,117,110,107,121,98,101,101,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,142,254,192,140,1,0,16,1,102,117,110,107,121,98,101,101,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,38,172,26,30,1,0,16,1,102,117,110,107,121,98,101,101,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,85,102,18,134,2,0,32,0,102,117,110,107,121,98,101,101,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,35,211,255,95,2,0,32,0,102,117,110,107,121,98,101,101,46,99,108,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,226,95,207,226,3,0,32,0,15,0,0,0,255,255,32,0,0,0,0,0,16,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,72,4,1,0,15,0,0,0,1,32,32,0,96,135,7,0,15,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,16,0,0,0,1,3,3,0,208,239,7,0,16,0,0,0,1,3,2,0,120,187,7,0,16,0,0,0,1,3,1,0,136,23,1,0,16,0,0,0,1,3,0,0,88,217,6,0,0,0,0,0,254,0,4,0,160,123,6,0,16,0,0,0,1,12,8,0,160,36,8,0,16,0,0,0,1,12,12,0,208,239,7,0,16,0,0,0,1,12,4,0,16,79,1,0,16,0,0,0,1,12,0,0,80,177,6,0,0,0,0,0,254,0,2,0,128,129,4,0,16,0,0,0,1,48,48,0,8,49,4,0,16,0,0,0,1,48,32,0,152,21,4,0,16,0,0,0,1,48,16,0,72,246,3,0,16,0,0,0,1,48,0,0,72,0,3,0,0,0,0,0,254,0,2,0,64,37,5,0,16,0,0,0,1,64,64,0,80,110,6,0,16,0,0,0,1,64,0,0,120,7,5,0,0,0,0,0,254,0,2,0,200,30,2,0,16,0,0,0,1,128,0,0,120,97,1,0,16,0,0,0,1,128,128,0,96,19,1,0,115,101,110,122,97,95,111,114,99,97,46,102,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,133,127,46,127,1,0,16,1,102,117,110,107,121,98,101,101,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,47,198,247,123,1,0,16,1,102,117,110,107,121,98,101,101,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,142,254,192,140,1,0,16,1,115,101,110,122,97,95,111,114,99,97,46,102,98,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,59,219,194,83,1,0,16,1,102,117,110,107,121,98,101,101,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,85,102,18,134,2,0,32,0,102,117,110,107,121,98,101,101,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,35,211,255,95,2,0,32,0,102,117,110,107,121,98,101,101,46,99,108,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,226,95,207,226,3,0,32,0,15,0,0,0,255,255,32,0,0,0,0,0,16,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,72,4,1,0,15,0,0,0,1,32,32,0,96,135,7,0,15,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,16,0,0,0,1,3,3,0,208,239,7,0,16,0,0,0,1,3,2,0,120,187,7,0,16,0,0,0,1,3,1,0,136,23,1,0,16,0,0,0,1,3,0,0,88,217,6,0,0,0,0,0,254,0,4,0,160,123,6,0,16,0,0,0,1,12,8,0,160,36,8,0,16,0,0,0,1,12,12,0,208,239,7,0,16,0,0,0,1,12,4,0,16,79,1,0,16,0,0,0,1,12,0,0,80,177,6,0,0,0,0,0,254,0,2,0,128,129,4,0,16,0,0,0,1,48,48,0,192,255,2,0,16,0,0,0,1,48,32,0,208,75,4,0,16,0,0,0,1,48,16,0,8,49,4,0,16,0,0,0,1,48,0,0,152,21,4,0,0,0,0,0,254,0,2,0,64,37,5,0,16,0,0,0,1,64,64,0,80,110,6,0,16,0,0,0,1,64,0,0,120,7,5,0,0,0,0,0,254,0,2,0,200,30,2,0,16,0,0,0,1,128,0,0,120,97,1,0,16,0,0,0,1,128,128,0,96,19,1,0,52,112,108,97,121,95,112,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,27,116,61,60,1,0,16,1,52,112,108,97,121,95,115,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,118,128,130,222,2,0,32,0,52,112,108,97,121,95,99,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,205,205,232,126,3,0,32,0,52,112,108,97,121,95,99,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,205,205,232,126,3,0,32,0,52,112,108,97,121,95,109,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,14,88,50,81,4,0,16,1,52,112,108,97,121,95,118,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,205,205,232,126,5,0,64,0,116,118,103,95,54,52,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,3,136,114,175,1,0,16,1,116,118,103,95,54,53,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,107,158,149,113,1,0,16,1,116,118,103,95,54,54,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,212,104,207,92,1,0,16,1,116,118,103,95,54,55,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,111,243,143,147,1,0,16,1,116,118,103,95,54,56,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,190,178,107,211,2,0,16,1,116,118,103,95,54,57,46,118,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,11,45,83,205,3,0,32,0,116,118,103,95,55,49,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,19,151,156,165,3,0,32,0,116,118,103,95,55,48,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,241,142,48,253,3,0,32,0,116,118,103,95,55,50,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,132,181,233,106,3,0,32,0,99,112,117,45,97,52,53,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,105,201,63,240,1,0,0,0,99,112,117,45,97,52,53,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,46,168,26,49,1,0,0,0,99,112,117,45,97,52,53,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,125,209,181,162,1,0,0,0,97,52,53,95,49,50,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,251,147,245,214,2,0,0,0,97,52,53,95,49,51,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,249,146,31,69,2,0,0,0,118,105,100,45,97,52,53,46,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,158,246,8,111,3,0,0,0,118,105,100,45,97,52,53,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,117,106,133,220,3,0,0,0,118,105,100,45,97,52,53,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,202,40,176,208,3,0,0,0,118,105,100,45,97,52,53,46,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,52,223,14,27,3,0,0,0,118,105,100,45,97,52,53,46,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,201,45,87,43,3,0,0,0,118,105,100,45,97,52,53,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,98,7,75,170,3,0,0,0,118,105,100,45,97,52,53,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,88,190,54,131,3,0,0,0,118,105,100,45,97,52,53,46,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,209,43,56,252,3,0,0,0,97,52,53,46,109,99,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,60,37,120,83,4,0,0,0,50,52,55,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,148,144,119,149,1,0,16,1,50,52,55,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,92,24,0,99,2,0,32,0,50,52,55,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,178,220,238,201,3,0,32,0,50,52,55,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,135,110,109,125,3,0,32,0,50,52,55,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,68,1,254,169,4,0,16,1,50,52,55,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,61,116,236,66,5,0,64,0,116,112,45,48,50,54,45,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,106,116,177,247,0,0,16,1,116,112,45,48,50,54,45,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,152,141,87,229,0,0,32,0,116,112,45,48,50,54,45,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,83,203,96,183,0,0,32,0,116,112,45,48,50,54,45,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,31,63,6,133,0,0,64,0,57,51,99,52,53,46,117,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,240,93,215,64,0,0,16,1,102,105,120,101,105,103,104,116,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,208,37,233,2,0,0,16,1,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,111,14,199,240,0,0,16,1,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,119,61,37,157,0,0,16,1,111,49,55,95,49,49,105,105,46,55,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,120,195,234,107,0,0,16,1,111,49,55,95,49,50,105,105,46,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,181,110,219,106,0,0,16,1,111,49,55,95,48,53,46,49,50,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,248,21,83,86,0,0,32,0,111,49,55,95,48,54,46,49,51,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,76,45,38,149,0,0,32,0,111,49,55,95,48,55,46,49,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,92,115,75,76,0,0,32,0,111,49,55,95,48,56,46,49,51,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,108,88,198,149,0,0,32,0,111,49,55,95,48,49,46,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,145,228,18,234,0,0,32,0,111,49,55,95,48,50,46,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,159,58,161,50,0,0,32,0,111,49,55,95,48,51,46,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,201,61,114,104,0,0,32,0,111,49,55,95,48,52,46,55,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,19,203,14,254,0,0,32,0,112,114,111,109,49,52,46,50,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,237,204,136,188,0,0,32,0,112,114,111,109,49,53,46,50,48,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,146,116,225,161,0,0,32,0,104,100,54,52,55,49,56,48,46,48,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,24,102,104,97,119,107,95,112,49,46,117,53,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,80,26,215,214,1,0,16,1,102,104,97,119,107,95,112,50,46,117,54,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,69,210,53,159,1,0,16,1,102,104,97,119,107,95,115,49,46,117,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,57,156,96,198,2,0,16,1,102,104,97,119,107,95,103,49,46,117,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,107,176,176,42,4,0,32,0,102,104,97,119,107,95,103,50,46,117,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,32,250,27,209,4,0,32,0,102,104,97,119,107,95,103,51,46,117,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,244,47,231,202,5,0,32,0,102,104,97,119,107,95,115,50,46,117,51,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,173,170,106,209,6,0,64,0,102,104,97,119,107,95,115,51,46,117,52,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,194,250,220,63,7,0,64,0,48,54,48,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,80,75,16,42,1,0,16,1,48,54,48,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,4,33,1,127,2,0,32,0,48,54,48,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,249,255,8,137,3,0,32,0,48,54,48,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,146,148,100,198,3,0,32,0,48,54,48,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,55,180,86,9,3,0,32,0,48,54,48,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,98,59,111,2,3,0,32,0,48,54,48,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,101,78,124,11,4,0,16,1,48,54,48,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,21,194,23,244,5,0,64,0,48,54,48,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,207,247,207,239,5,0,64,0,102,98,49,52,46,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,83,40,3,130,1,0,16,1,102,98,49,51,46,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,15,223,6,83,1,0,16,1,102,98,49,50,46,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,212,16,146,238,1,0,16,1,102,98,49,48,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,186,239,71,107,1,0,16,1,102,98,48,57,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,135,224,105,190,1,0,16,1,102,98,48,55,46,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,189,45,67,80,2,0,16,1,102,98,48,56,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,184,215,28,39,3,0,32,0,102,98,50,49,46,50,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,145,53,132,2,4,0,32,0,102,98,50,50,46,50,51,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,231,216,81,205,4,0,32,0,102,98,50,51,46,50,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,135,172,188,98,4,0,32,0,102,98,49,54,46,51,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,82,22,223,165,5,0,32,0,102,98,49,53,46,51,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,6,222,196,89,5,0,32,0,102,98,49,56,46,51,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,215,220,61,194,5,0,32,0,102,98,49,55,46,51,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,19,128,178,125,5,0,32,0,102,98,50,48,46,50,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,248,72,27,26,5,0,32,0,102,98,49,57,46,51,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,33,227,247,127,5,0,32,0,102,98,48,54,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,153,223,163,190,6,0,64,0,102,98,95,114,46,57,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,186,200,205,197,7,0,32,0,102,98,95,103,46,49,48,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,54,201,96,20,7,0,32,0,102,98,95,98,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,14,191,165,252,7,0,32,0,102,98,48,49,46,52,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,32,178,0,18,8,0,64,0,102,98,48,50,46,52,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,130,170,103,11,8,0,64,0,102,98,48,51,46,52,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,237,105,18,199,8,0,64,0,102,98,48,52,46,51,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,45,196,221,2,8,0,64,0,102,98,48,53,46,51,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,73,107,234,114,8,0,64,0,0,0,0,0,0,0,0,0,99,118,48,49,45,117,51,52,46,115,111,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,230,60,239,36,0,0,16,1,99,118,48,49,45,117,51,51,46,115,111,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,253,115,255,100,0,0,16,1,99,118,48,49,45,117,50,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,93,169,246,166,0,0,32,0,99,118,48,49,45,117,50,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,42,182,237,50,0,0,32,0,99,118,48,49,45,117,53,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,23,68,52,122,0,0,32,0,99,118,48,49,45,117,52,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,167,221,28,210,0,0,32,0,99,118,48,49,45,117,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,218,20,85,95,0,0,64,0,101,101,112,114,111,109,45,102,101,118,101,114,115,111,115,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,170,3,3,216,0,0,16,1,48,51,52,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,25,107,239,205,1,0,16,1,48,51,52,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,68,237,114,132,2,0,32,0,48,51,52,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,120,110,197,145,3,0,32,0,48,51,52,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,47,234,67,151,3,0,32,0,48,51,52,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,245,101,170,229,3,0,32,0,48,51,52,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,204,56,177,14,3,0,32,0,48,51,52,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,184,22,27,244,4,0,16,1,48,51,52,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,221,208,201,80,5,0,64,0,48,51,52,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,134,86,161,90,5,0,64,0,48,54,57,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,188,251,188,168,1,0,16,1,48,54,57,45,115,112,50,46,115,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,237,99,233,219,1,0,16,1,48,54,57,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,168,51,11,2,0,32,0,48,54,57,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,60,249,2,227,3,0,32,0,48,54,57,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,85,164,83,16,3,0,32,0,48,54,57,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,47,222,15,28,3,0,32,0,48,54,57,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,208,195,95,162,3,0,32,0,48,54,57,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,166,111,236,179,3,0,32,0,48,54,57,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,65,4,33,105,3,0,32,0,48,54,57,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,38,41,231,252,4,0,16,1,48,54,57,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,219,212,219,43,5,0,64,0,48,54,57,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,135,164,152,166,5,0,64,0,48,54,57,45,118,51,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,4,83,28,88,5,0,64,0,48,52,55,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,105,187,253,236,1,0,16,1,48,52,55,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,57,191,219,215,2,0,32,0,48,52,55,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,158,147,42,247,3,0,32,0,48,52,55,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,13,154,17,5,3,0,32,0,48,52,55,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,56,7,224,1,3,0,32,0,48,52,55,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,50,116,226,159,3,0,32,0,48,52,55,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,167,11,11,130,4,0,16,1,48,52,55,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,132,7,208,217,5,0,64,0,48,52,55,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,51,75,154,44,5,0,64,0,48,51,51,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,47,220,235,71,1,0,16,1,48,51,51,45,112,50,46,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,28,175,115,196,1,0,16,1,48,51,51,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,140,223,59,60,2,0,32,0,48,51,51,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,84,126,49,116,3,0,32,0,48,51,51,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,243,82,185,91,3,0,32,0,48,51,51,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,124,74,113,155,3,0,32,0,48,51,51,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,106,71,151,147,3,0,32,0,48,51,51,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,253,15,225,91,4,0,16,1,48,51,51,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,13,210,47,33,5,0,64,0,48,51,51,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,127,228,42,250,5,0,64,0,48,53,56,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,162,91,88,47,1,0,16,1,48,53,56,45,112,50,46,115,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,107,26,199,215,1,0,16,1,48,53,56,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,151,49,240,45,2,0,32,0,48,53,56,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,60,177,74,4,3,0,32,0,48,53,56,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,150,191,230,17,3,0,32,0,48,53,56,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,213,56,121,111,3,0,32,0,48,53,56,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,255,102,208,74,3,0,32,0,48,53,56,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,191,224,197,73,3,0,32,0,48,53,56,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,61,244,241,143,3,0,32,0,48,53,56,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,110,24,197,204,4,0,16,1,48,53,56,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,132,206,215,85,5,0,64,0,48,53,56,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,16,11,8,238,5,0,64,0,48,53,56,45,118,51,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,74,61,235,249,5,0,64,0,102,49,100,95,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,173,235,63,144,1,0,16,1,102,49,100,95,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,167,162,111,102,1,0,16,1,102,49,100,95,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,76,60,151,152,1,0,16,1,102,49,100,95,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,138,199,33,61,1,0,16,1,49,50,107,95,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,36,117,154,75,2,0,16,1,49,48,100,95,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,175,28,54,3,0,32,0,48,51,102,95,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,60,228,19,188,4,0,32,0,48,49,102,95,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,217,122,97,247,4,0,32,0,48,51,104,95,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,56,212,60,227,4,0,32,0,48,50,102,95,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,215,156,164,74,4,0,32,0,49,55,102,95,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,85,33,98,202,4,0,32,0,48,50,104,95,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,30,150,99,42,4,0,32,0,48,51,98,95,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,145,227,84,94,5,0,32,0,48,50,98,95,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,253,25,209,205,5,0,32,0,48,51,100,95,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,34,46,31,129,5,0,32,0,48,50,100,95,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,51,18,154,170,5,0,32,0,48,55,108,95,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,183,88,135,151,6,0,32,0,48,57,101,95,116,114,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,54,174,128,236,7,0,32,8,122,97,99,98,95,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,160,215,169,164,1,0,16,1,122,97,99,98,95,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,115,63,43,195,1,0,16,1,122,97,99,98,95,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,115,148,91,25,1,0,16,1,122,97,99,98,95,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,203,134,40,41,1,0,16,1,122,97,99,98,95,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,21,176,148,255,1,0,16,1,122,97,99,98,95,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,140,197,113,146,1,0,16,1,122,97,99,98,95,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,43,243,92,150,1,0,16,1,122,97,99,98,95,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,46,233,84,194,1,0,16,1,120,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,46,226,220,89,2,0,32,0,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,55,165,167,170,2,0,32,0,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,43,121,105,25,2,0,32,0,112,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,48,75,175,153,2,0,32,0,56,50,115,49,50,51,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,189,80,198,47,3,0,32,0,56,50,115,49,50,57,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,41,136,215,216,3,0,32,0,56,50,115,49,50,54,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,134,204,169,4,0,64,0,56,50,115,49,50,54,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,122,97,99,98,95,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,42,96,193,105,0,0,16,0,98,48,54,45,50,48,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,31,252,227,4,1,0,16,1,98,48,54,45,50,49,46,57,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,162,214,20,22,1,0,16,1,98,48,54,45,50,50,46,52,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,132,44,79,116,2,0,16,1,101,120,116,114,56,55,52,50,46,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,3,0,0,16,98,48,54,45,48,49,46,49,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,126,191,175,210,4,0,32,0,98,48,54,45,48,50,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,122,117,194,224,4,0,32,0,98,48,54,45,48,51,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,157,171,128,238,4,0,32,0,98,48,54,45,48,52,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,228,172,151,54,4,0,32,0,98,48,54,45,48,57,46,49,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,97,179,136,243,5,0,32,0,98,48,54,45,48,56,46,49,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,195,170,201,16,5,0,32,0,98,48,54,45,48,53,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,227,31,142,145,1,0,16,1,98,48,54,45,48,54,46,57,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,5,225,66,136,1,0,16,1,98,48,54,45,49,57,46,52,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,217,62,228,141,2,0,16,1,101,120,116,114,56,55,52,50,46,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,3,0,0,16,98,48,54,45,48,49,46,49,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,126,191,175,210,4,0,32,0,98,48,54,45,48,50,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,122,117,194,224,4,0,32,0,98,48,54,45,48,51,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,157,171,128,238,4,0,32,0,98,48,54,45,48,52,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,228,172,151,54,4,0,32,0,98,48,54,45,48,57,46,49,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,97,179,136,243,5,0,32,0,98,48,54,45,48,56,46,49,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,195,170,201,16,5,0,32,0,98,48,54,45,48,53,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,227,31,142,145,1,0,16,1,98,48,54,45,48,54,46,57,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,5,225,66,136,1,0,16,1,98,48,54,45,48,55,46,52,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,179,184,127,179,2,0,16,1,101,120,116,114,56,55,52,50,46,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,3,0,0,16,98,48,54,45,48,49,46,49,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,126,191,175,210,4,0,32,0,98,48,54,45,48,50,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,122,117,194,224,4,0,32,0,98,48,54,45,48,51,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,157,171,128,238,4,0,32,0,98,48,54,45,48,52,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,228,172,151,54,4,0,32,0,98,48,54,45,48,57,46,49,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,97,179,136,243,5,0,32,0,98,48,54,45,48,56,46,49,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,195,170,201,16,5,0,32,0,102,119,48,48,49,48,48,50,46,50,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,36,25,210,36,1,0,16,1,102,119,48,48,49,48,48,49,46,50,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,139,162,18,251,1,0,16,1,102,119,48,48,49,48,48,51,46,50,48,50,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,213,49,155,172,3,0,32,0,102,119,48,48,49,48,48,52,46,50,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,114,29,203,13,4,0,32,0,102,119,48,48,49,48,48,53,46,50,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,241,178,51,92,28,0,32,0,102,119,48,48,49,48,48,54,46,49,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,221,141,14,208,5,0,32,0,102,119,48,48,49,48,48,55,46,48,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,122,77,216,22,6,0,64,0,49,45,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,93,42,247,93,1,0,16,1,115,107,121,102,111,120,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,99,2,94,225,1,0,16,1,115,107,121,102,111,120,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,245,59,40,11,2,0,16,1,49,45,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,129,147,14,69,3,0,32,0,115,107,121,102,111,120,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,187,83,128,53,3,0,32,0,49,45,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,96,140,163,80,3,0,32,0,115,107,121,102,111,120,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,93,225,55,204,3,0,32,0,49,45,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,92,254,187,201,3,0,32,0,115,107,121,102,111,120,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,73,220,62,14,3,0,32,0,115,107,121,102,111,120,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,156,143,245,25,4,0,32,0,115,102,111,120,114,112,114,109,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,127,60,145,121,5,0,32,0,115,102,111,120,103,112,114,109,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,52,212,115,251,5,0,32,0,115,102,111,120,98,112,114,109,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,65,171,210,96,5,0,32,0,49,49,109,95,101,101,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,189,13,20,68,1,0,16,1,49,48,109,95,101,101,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,186,207,114,191,1,0,16,1,48,57,109,95,101,101,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,47,94,217,122,1,0,16,1,49,49,101,95,101,101,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,178,243,205,115,2,0,16,1,48,53,99,95,101,101,48,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,189,117,219,202,3,0,32,0,104,48,49,95,101,101,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,29,92,166,150,4,0,32,0,97,48,51,95,101,101,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,209,189,57,96,5,0,32,0,97,48,50,95,101,101,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,82,130,45,179,5,0,32,0,106,49,49,95,101,101,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,101,226,131,188,6,0,32,0,106,49,50,95,101,101,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,13,48,15,14,6,0,32,0,99,48,49,95,101,101,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,141,166,37,54,7,0,32,0,104,48,52,95,101,101,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,7,201,87,96,7,0,32,0,48,50,100,95,101,45,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,53,89,13,141,8,0,32,0,48,51,100,95,101,45,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,252,126,193,211,8,0,32,0,48,52,100,95,101,45,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,76,150,186,88,8,0,32,0,48,54,102,95,101,45,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,121,53,160,53,8,0,32,0,108,48,52,95,101,45,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,122,216,250,29,8,0,32,0,99,48,52,95,101,45,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,224,100,0,133,8,0,32,0,108,48,57,95,101,45,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,16,135,182,43,8,0,32,0,108,49,48,95,101,45,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,239,132,49,23,8,0,32,0,48,54,108,95,101,45,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,8,197,42,113,0,0,0,8,107,48,54,95,101,45,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,88,81,175,14,0,0,0,8,108,48,51,95,101,45,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,88,133,150,13,0,0,0,8,48,51,101,95,101,45,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,118,227,206,26,0,0,0,8,117,52,50,95,118,101,114,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,66,60,208,117,0,0,16,1,117,52,49,95,118,101,114,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,240,62,75,115,0,0,16,1,101,115,112,95,117,54,51,46,117,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,44,233,47,47,0,0,32,0,101,115,112,95,117,54,52,46,117,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,164,61,26,73,0,0,32,0,101,115,112,95,117,54,53,46,117,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,254,62,86,6,0,0,32,0,101,115,112,95,117,54,54,46,117,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,252,76,190,123,0,0,32,0,101,115,112,95,117,53,52,46,117,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,54,105,202,231,0,0,32,0,101,115,112,95,117,53,53,46,117,53,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,79,217,59,245,0,0,32,0,101,115,112,95,117,53,50,46,117,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,180,231,171,231,0,0,32,0,101,115,112,95,117,53,51,46,117,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,145,243,160,81,0,0,32,0,101,115,112,95,117,53,49,46,117,53,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,92,135,155,11,0,0,32,0,101,115,112,95,117,49,57,46,117,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,171,28,75,245,0,0,64,0,101,101,112,114,111,109,45,101,115,112,114,97,100,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,70,181,95,49,0,0,16,1,57,55,53,114,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,114,85,92,123,1,0,16,1,57,55,53,102,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,41,178,79,153,2,0,16,1,57,55,53,99,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,14,33,82,188,3,0,32,0,57,55,53,99,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,86,146,255,252,3,0,32,0,57,55,53,99,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,111,138,104,21,4,0,32,0,57,55,53,99,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,183,59,243,31,4,0,32,0,57,55,53,99,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,249,16,212,54,4,0,32,0,57,55,53,99,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,30,84,236,151,4,0,32,0,57,55,53,99,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,7,23,74,220,5,0,64,0,101,115,99,107,105,100,115,106,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,45,42,94,152,0,0,0,8,48,50,53,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,176,76,52,67,1,0,16,1,48,50,53,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,43,32,2,164,2,0,32,0,48,50,53,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,164,22,94,85,3,0,32,0,48,50,53,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,195,81,238,225,3,0,32,0,48,50,53,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,176,213,35,9,3,0,32,0,48,50,53,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,123,166,236,227,3,0,32,0,48,50,53,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,76,3,39,153,4,0,16,1,48,50,53,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,138,85,88,69,5,0,64,0,48,50,53,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,233,82,224,197,5,0,64,0,117,121,50,45,117,52,46,117,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,197,73,242,241,1,0,16,1,117,121,50,45,117,51,46,117,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,24,134,45,111,1,0,16,1,117,54,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,46,255,97,245,3,0,32,0,117,54,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,102,131,63,76,3,0,32,0,117,54,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,127,43,173,111,4,0,32,0,117,54,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,34,173,122,193,5,0,32,0,117,55,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,163,103,219,223,6,0,64,0,117,54,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,241,8,236,130,6,0,64,0,0,0,0,0,0,0,0,0,103,101,45,48,48,45,50,46,107,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,60,64,210,179,1,0,16,1,103,101,45,48,52,45,50,46,107,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,214,36,150,138,1,0,16,1,103,101,45,48,49,45,50,46,106,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,35,1,54,132,1,0,16,1,103,101,45,48,53,45,50,46,106,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,157,93,248,11,1,0,16,1,103,101,45,48,50,46,104,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,187,159,150,194,1,0,16,1,103,101,45,48,54,46,104,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,24,100,46,92,1,0,16,1,103,101,45,48,51,46,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,168,25,123,94,1,0,16,1,103,101,45,48,55,46,102,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,161,25,184,94,1,0,16,1,103,101,45,48,57,46,107,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,11,198,148,159,2,0,16,1,103,101,45,49,48,46,121,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,149,215,40,37,3,0,32,0,103,101,45,49,49,46,122,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,30,147,74,227,3,0,32,0,109,97,100,45,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,206,250,118,108,4,0,32,0,109,97,100,45,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,45,178,53,55,5,0,32,0,109,97,100,45,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,28,62,177,123,5,0,32,0,109,97,100,45,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,146,248,191,192,6,0,32,0,109,97,100,45,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,149,207,44,63,6,0,32,0,109,97,100,45,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,185,62,79,70,6,0,32,0,109,97,100,45,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,119,31,135,96,6,0,32,0,109,97,100,45,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,110,70,3,172,6,0,32,0,109,97,100,45,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,200,14,66,27,6,0,32,0,109,97,100,45,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,240,142,218,66,6,0,32,0,109,97,100,45,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,130,249,193,3,6,0,32,0,109,97,100,45,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,73,15,147,6,0,32,0,109,97,100,45,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,182,98,189,160,6,0,32,0,103,101,45,48,56,46,106,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,123,140,226,223,7,0,64,0,109,97,100,45,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,186,142,178,106,8,0,64,0,103,101,45,49,50,46,118,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,79,103,143,39,0,0,0,8,103,103,48,48,45,49,46,107,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,74,204,41,160,1,0,16,1,103,103,48,52,45,49,46,107,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,164,40,121,139,1,0,16,1,103,103,48,49,45,49,46,106,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,35,1,54,132,1,0,16,1,103,103,48,53,45,49,46,106,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,157,93,248,11,1,0,16,1,103,101,45,48,50,46,104,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,187,159,150,194,1,0,16,1,103,101,45,48,54,46,104,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,24,100,46,92,1,0,16,1,103,101,45,48,51,46,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,168,25,123,94,1,0,16,1,103,101,45,48,55,46,102,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,161,25,184,94,1,0,16,1,103,101,45,48,57,46,107,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,11,198,148,159,2,0,16,1,103,103,45,49,48,46,121,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,190,108,108,185,3,0,32,0,103,103,45,49,49,46,122,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,72,116,86,238,3,0,32,0,109,97,100,45,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,206,250,118,108,4,0,32,0,109,97,100,45,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,45,178,53,55,5,0,32,0,109,97,100,45,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,28,62,177,123,5,0,32,0,109,97,100,45,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,146,248,191,192,6,0,32,0,109,97,100,45,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,149,207,44,63,6,0,32,0,109,97,100,45,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,185,62,79,70,6,0,32,0,109,97,100,45,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,119,31,135,96,6,0,32,0,109,97,100,45,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,110,70,3,172,6,0,32,0,109,97,100,45,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,200,14,66,27,6,0,32,0,109,97,100,45,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,240,142,218,66,6,0,32,0,109,97,100,45,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,130,249,193,3,6,0,32,0,109,97,100,45,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,73,15,147,6,0,32,0,109,97,100,45,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,182,98,189,160,6,0,32,0,103,101,45,48,56,46,106,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,123,140,226,223,7,0,64,0,109,97,100,45,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,186,142,178,106,8,0,64,0,103,101,45,49,50,46,118,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,79,103,143,39,0,0,0,8,49,46,107,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,170,205,132,241,1,0,16,1,53,46,107,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,129,75,58,126,1,0,16,1,50,46,106,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,147,213,44,33,1,0,16,1,54,46,106,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,7,251,150,74,1,0,16,1,103,101,45,48,50,46,104,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,187,159,150,194,1,0,16,1,103,101,45,48,54,46,104,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,24,100,46,92,1,0,16,1,103,101,45,48,51,46,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,168,25,123,94,1,0,16,1,103,101,45,48,55,46,102,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,161,25,184,94,1,0,16,1,103,101,45,48,57,46,107,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,11,198,148,159,2,0,16,1,103,101,45,49,48,46,121,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,149,215,40,37,3,0,32,0,103,101,45,49,49,46,122,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,30,147,74,227,3,0,32,0,109,97,100,45,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,206,250,118,108,4,0,32,0,109,97,100,45,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,45,178,53,55,5,0,32,0,109,97,100,45,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,28,62,177,123,5,0,32,0,109,97,100,45,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,146,248,191,192,6,0,32,0,109,97,100,45,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,149,207,44,63,6,0,32,0,109,97,100,45,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,185,62,79,70,6,0,32,0,109,97,100,45,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,119,31,135,96,6,0,32,0,109,97,100,45,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,110,70,3,172,6,0,32,0,109,97,100,45,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,200,14,66,27,6,0,32,0,109,97,100,45,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,240,142,218,66,6,0,32,0,109,97,100,45,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,130,249,193,3,6,0,32,0,109,97,100,45,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,73,15,147,6,0,32,0,109,97,100,45,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,182,98,189,160,6,0,32,0,103,101,45,48,56,46,106,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,123,140,226,223,7,0,64,0,109,97,100,45,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,186,142,178,106,8,0,64,0,103,101,45,49,50,46,118,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,79,103,143,39,0,0,0,8,101,106,95,51,98,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,194,111,216,189,2,0,16,1,101,106,95,51,97,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,198,80,128,156,2,0,16,1,101,106,95,51,48,101,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,127,247,209,73,1,0,16,1,101,106,95,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,102,37,186,66,9,0,16,1,101,106,95,99,104,114,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,151,82,103,172,11,0,32,0,101,106,95,111,98,106,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,71,172,33,95,15,0,32,0,101,106,95,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,219,145,72,203,16,0,32,0,101,106,95,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,111,8,18,182,16,0,32,0,49,46,99,100,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,90,169,226,165,1,0,16,1,50,46,99,100,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,34,175,81,126,1,0,16,1,100,100,51,46,101,102,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,146,134,111,165,1,0,16,1,100,100,52,46,101,102,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,179,135,75,238,1,0,16,1,53,46,112,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,156,49,61,136,2,0,16,1,54,46,112,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,255,180,76,217,2,0,16,1,56,46,119,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,11,72,41,60,3,0,16,1,57,46,53,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,244,154,188,242,4,0,32,0,49,48,46,51,52,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,155,241,169,194,4,0,32,0,100,100,46,97,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,63,52,143,89,5,0,32,0,100,100,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,141,8,169,65,5,0,32,0,100,100,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,66,27,52,204,5,0,32,0])
.concat([100,100,46,100,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,215,180,82,71,5,0,32,0,100,100,46,100,101,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,98,203,164,68,5,0,32,0,100,100,46,101,102,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,26,238,138,170,5,0,32,0,100,100,46,109,110,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,152,202,224,46,6,0,32,0,100,100,46,109,110,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,223,226,113,108,6,0,32,0,100,100,46,110,52,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,225,24,217,133,6,0,32,0,100,100,46,109,110,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,223,52,30,231,6,0,32,0,100,100,46,110,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,39,185,29,207,7,0,32,0,100,100,46,110,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,15,21,40,83,7,0,32,0,100,100,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,82,100,119,128,7,0,32,0,100,100,46,109,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,115,165,97,255,7,0,32,0,100,100,46,101,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,124,184,160,132,7,0,32,0,100,100,46,101,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,242,93,88,169,7,0,32,0,100,100,46,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,186,36,237,154,7,0,32,0,100,100,46,102,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,63,120,181,62,7,0,32,0,55,46,120,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,65,123,188,156,8,0,64,0,49,46,99,100,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,90,169,226,165,1,0,16,1,50,46,99,100,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,34,175,81,126,1,0,16,1,40,95,95,100,121,110,100,117,107,101,106,41,51,46,101,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,67,210,185,152,1,0,16,1,52,46,101,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,119,81,87,79,1,0,16,1,53,46,112,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,156,49,61,136,2,0,16,1,54,46,112,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,255,180,76,217,2,0,16,1,56,46,119,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,11,72,41,60,3,0,16,1,57,46,53,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,244,154,188,242,4,0,32,0,49,48,46,51,52,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,155,241,169,194,4,0,32,0,100,100,46,97,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,63,52,143,89,5,0,32,0,100,100,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,141,8,169,65,5,0,32,0,100,100,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,66,27,52,204,5,0,32,0,100,100,46,100,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,215,180,82,71,5,0,32,0,100,100,46,100,101,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,98,203,164,68,5,0,32,0,100,100,46,101,102,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,26,238,138,170,5,0,32,0,100,100,46,109,110,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,152,202,224,46,6,0,32,0,100,100,46,109,110,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,223,226,113,108,6,0,32,0,100,100,46,110,52,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,225,24,217,133,6,0,32,0,100,100,46,109,110,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,223,52,30,231,6,0,32,0,100,100,46,110,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,39,185,29,207,7,0,32,0,100,100,46,110,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,15,21,40,83,7,0,32,0,100,100,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,82,100,119,128,7,0,32,0,100,100,46,109,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,115,165,97,255,7,0,32,0,100,100,46,101,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,124,184,160,132,7,0,32,0,100,100,46,101,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,242,93,88,169,7,0,32,0,100,100,46,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,186,36,237,154,7,0,32,0,100,100,46,102,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,63,120,181,62,7,0,32,0,55,46,120,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,65,123,188,156,8,0,64,0,49,46,99,100,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,90,169,226,165,1,0,16,1,50,46,99,100,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,34,175,81,126,1,0,16,1,100,100,101,51,46,101,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,121,98,51,149,1,0,16,1,100,100,101,52,46,101,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,234,143,45,235,1,0,16,1,53,46,112,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,156,49,61,136,2,0,16,1,54,46,112,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,255,180,76,217,2,0,16,1,56,46,119,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,11,72,41,60,3,0,16,1,57,46,53,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,244,154,188,242,4,0,32,0,49,48,46,51,52,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,155,241,169,194,4,0,32,0,100,100,46,97,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,63,52,143,89,5,0,32,0,100,100,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,141,8,169,65,5,0,32,0,100,100,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,66,27,52,204,5,0,32,0,100,100,46,100,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,215,180,82,71,5,0,32,0,100,100,46,100,101,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,98,203,164,68,5,0,32,0,100,100,46,101,102,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,26,238,138,170,5,0,32,0,100,100,46,109,110,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,152,202,224,46,6,0,32,0,100,100,46,109,110,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,223,226,113,108,6,0,32,0,100,100,46,110,52,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,225,24,217,133,6,0,32,0,100,100,46,109,110,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,223,52,30,231,6,0,32,0,100,100,46,110,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,39,185,29,207,7,0,32,0,100,100,46,110,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,15,21,40,83,7,0,32,0,100,100,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,82,100,119,128,7,0,32,0,100,100,46,109,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,115,165,97,255,7,0,32,0,100,100,46,101,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,124,184,160,132,7,0,32,0,100,100,46,101,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,242,93,88,169,7,0,32,0,100,100,46,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,186,36,237,154,7,0,32,0,100,100,46,102,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,63,120,181,62,7,0,32,0,55,46,120,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,65,123,188,156,8,0,64,0,98,98,109,45,99,112,49,101,46,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,129,118,102,39,1,0,16,1,98,98,109,45,99,112,48,101,46,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,103,122,219,149,1,0,16,1,98,98,109,45,115,112,46,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,205,144,16,37,2,0,16,1,98,98,109,45,99,48,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,25,32,93,105,3,0,32,0,98,98,109,45,99,49,46,54,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,188,139,124,76,3,0,32,0,98,98,109,45,99,50,46,54,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,6,212,0,7,3,0,32,0,98,98,109,45,99,51,46,54,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,175,19,54,60,3,0,32,0,98,98,109,45,118,48,46,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,254,3,168,15,4,0,64,0,97,51,45,52,112,95,104,48,45,99,45,48,46,105,99,53,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,215,63,29,208,1,0,16,1,97,51,45,52,112,95,108,48,45,99,45,48,46,105,99,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,226,175,240,138,1,0,16,1,97,51,95,104,49,45,99,45,48,46,105,99,54,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,27,4,9,97,1,0,16,1,97,51,95,108,49,45,99,45,48,46,105,99,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,107,31,160,151,1,0,16,1,97,51,45,115,104,48,45,99,45,48,46,105,99,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,252,111,254,35,2,0,16,1,97,51,45,115,108,48,45,99,45,48,46,105,99,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,229,50,129,118,2,0,16,1,100,115,95,99,48,48,46,105,99,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,24,212,49,45,3,0,32,0,100,115,95,99,49,48,46,105,99,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,211,188,247,87,3,0,32,0,100,115,95,99,48,49,46,105,99,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,100,164,49,157,3,0,32,0,100,115,95,99,49,49,46,105,99,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,159,231,114,163,3,0,32,0,100,115,95,48,48,48,46,105,99,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,41,62,107,54,4,0,32,0,100,115,95,48,49,48,46,105,99,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,64,204,164,40,4,0,32,0,100,115,95,48,50,48,46,105,99,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,127,15,49,90,4,0,32,0,100,115,95,48,51,48,46,105,99,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,69,31,139,50,4,0,32,0,100,115,95,100,97,48,46,105,99,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,253,82,252,103,5,0,64,0,98,49,57,45,48,57,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,130,79,101,62,1,0,16,1,98,49,57,45,49,48,46,57,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,37,253,114,126,1,0,16,1,98,49,57,45,49,52,46,51,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,34,91,86,5,2,0,16,1,100,114,116,56,55,52,50,46,51,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,3,0,0,16,98,49,57,45,48,49,46,49,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,193,160,232,167,4,0,32,0,98,49,57,45,48,50,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,84,230,10,121,4,0,32,0,98,49,57,45,48,51,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,90,76,92,73,4,0,32,0,98,49,57,45,48,52,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,160,7,112,100,4,0,32,0,98,49,57,45,48,53,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,165,177,242,73,4,0,32,0,98,49,57,45,48,54,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,208,241,57,45,4,0,32,0,98,49,57,45,48,55,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,65,111,176,139,4,0,32,0,98,49,57,45,48,56,46,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,145,180,132,53,4,0,32,0,98,49,57,45,49,51,46,49,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,128,121,84,106,5,0,32,0,98,49,57,45,49,50,46,49,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,216,233,84,87,5,0,32,0,98,49,57,45,48,57,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,130,79,101,62,1,0,16,1,98,49,57,45,49,48,46,57,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,37,253,114,126,1,0,16,1,98,49,57,45,49,49,46,51,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,73,194,77,82,2,0,16,1,100,114,116,56,55,52,50,46,51,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,3,0,0,16,98,49,57,45,48,49,46,49,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,193,160,232,167,4,0,32,0,98,49,57,45,48,50,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,84,230,10,121,4,0,32,0,98,49,57,45,48,51,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,90,76,92,73,4,0,32,0,98,49,57,45,48,52,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,160,7,112,100,4,0,32,0,98,49,57,45,48,53,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,165,177,242,73,4,0,32,0,98,49,57,45,48,54,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,208,241,57,45,4,0,32,0,98,49,57,45,48,55,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,65,111,176,139,4,0,32,0,98,49,57,45,48,56,46,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,145,180,132,53,4,0,32,0,98,49,57,45,49,51,46,49,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,128,121,84,106,5,0,32,0,98,49,57,45,49,50,46,49,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,216,233,84,87,5,0,32,0,98,49,57,45,48,57,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,130,79,101,62,1,0,16,1,98,49,57,45,49,48,46,57,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,37,253,114,126,1,0,16,1,98,49,57,45,49,53,46,51,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,251,211,160,55,2,0,16,1,100,114,116,56,55,52,50,46,51,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,3,0,0,16,98,49,57,45,48,49,46,49,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,193,160,232,167,4,0,32,0,98,49,57,45,48,50,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,84,230,10,121,4,0,32,0,98,49,57,45,48,51,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,90,76,92,73,4,0,32,0,98,49,57,45,48,52,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,160,7,112,100,4,0,32,0,98,49,57,45,48,53,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,165,177,242,73,4,0,32,0,98,49,57,45,48,54,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,208,241,57,45,4,0,32,0,98,49,57,45,48,55,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,65,111,176,139,4,0,32,0,98,49,57,45,48,56,46,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,145,180,132,53,4,0,32,0,98,49,57,45,49,51,46,49,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,128,121,84,106,5,0,32,0,98,49,57,45,49,50,46,49,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,216,233,84,87,5,0,32,0,100,114,105,118,102,111,114,99,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,39,157,181,16,1,0,16,1,100,114,105,118,102,111,114,99,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,181,28,51,86,2,0,32,0,100,114,105,118,102,111,114,99,46,112,114,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,127,164,90,4,3,0,32,0,100,114,105,118,102,111,114,99,46,112,114,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,29,47,109,158,3,0,32,0,112,114,103,45,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,223,71,132,114,1,0,16,1,112,114,103,45,111,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,207,142,245,178,1,0,16,1,111,98,106,45,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,90,171,246,215,11,0,32,0,111,98,106,45,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,19,91,169,83,11,0,32,0,111,98,106,45,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,247,1,184,128,11,0,32,0,111,98,106,45,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,32,188,135,107,11,0,32,0,111,98,106,45,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,113,119,209,96,11,0,32,0,111,98,106,45,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,213,212,204,11,11,0,32,0,111,98,106,45,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,67,21,108,130,11,0,32,0,111,98,106,45,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,106,127,170,203,11,0,32,0,115,99,114,45,49,111,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,219,37,21,103,4,0,32,0,115,99,114,45,50,111,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,216,46,63,42,4,0,32,0,115,99,114,45,51,111,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,45,169,51,77,4,0,32,0,115,99,114,45,52,111,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,97,170,160,121,4,0,32,0,115,99,114,45,49,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,201,216,156,220,4,0,32,0,115,99,114,45,50,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,65,107,18,182,4,0,32,0,115,99,114,45,51,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,194,184,146,21,4,0,32,0,115,99,114,45,52,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,28,104,1,130,4,0,32,0,115,110,100,45,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,13,189,71,143,6,0,64,0,115,110,100,45,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,245,14,196,101,6,0,64,0,115,110,100,45,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,78,213,251,113,6,0,64,0,115,110,100,45,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,19,80,172,6,0,64,0,115,110,100,45,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,44,47,101,112,6,0,64,0,115,110,100,45,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,157,3,161,16,6,0,64,0,115,110,100,45,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,176,200,203,222,6,0,64,0,115,110,100,45,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,238,27,197,58,6,0,64,0,100,98,49,95,50,98,46,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,23,205,17,15,1,0,16,1,100,98,49,95,49,46,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,33,24,124,28,1,0,16,1,100,98,49,95,51,46,54,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,174,105,161,109,1,0,16,1,100,98,49,95,52,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,193,31,11,138,2,0,16,1,99,117,115,54,48,45,54,48,97,49,46,109,99,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,42,168,110,7,2,0,16,1,100,98,49,95,54,46,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,108,182,128,192,3,0,32,0,100,98,49,95,53,46,55,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,237,154,18,40,4,0,32,0,100,98,49,95,56,46,49,48,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,97,44,148,17,5,0,32,0,100,98,49,95,55,46,49,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,226,15,19,204,5,0,32,0,100,98,49,45,49,46,50,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,151,206,140,63,6,0,32,0,100,98,49,45,50,46,50,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,54,36,227,175,6,0,32,0,100,98,49,45,51,46,50,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,118,245,95,201,6,0,32,0,100,98,49,45,52,46,53,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,33,12,24,178,6,0,32,0,100,98,49,45,53,46,54,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,116,63,43,94,6,0,32,0,52,46,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,8,0,115,144,1,0,16,1,53,46,52,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,2,0,21,201,60,25,1,0,16,1,49,46,50,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,74,248,203,217,2,0,16,1,50,50,46,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,152,17,228,134,3,0,32,0,54,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,247,89,87,177,4,0,32,0,55,46,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,69,212,65,37,4,0,32,0,56,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,196,245,162,81,4,0,32,0,57,46,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,15,133,200,244,4,0,32,0,49,48,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,97,60,75,158,4,0,32,0,49,49,46,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,131,208,51,13,4,0,32,0,49,50,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,211,122,73,108,4,0,32,0,49,51,46,56,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,255,173,132,122,4,0,32,0,50,49,46,56,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,17,135,238,12,6,0,32,0,50,48,46,56,113,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,42,224,71,150,6,0,32,0,49,57,46,55,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,255,206,130,80,6,0,32,0,49,56,46,55,113,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,251,127,138,209,6,0,32,0,49,55,46,54,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,175,136,144,6,0,32,0,49,54,46,54,113,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,1,78,222,138,6,0,32,0,49,53,46,53,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,28,55,41,116,6,0,32,0,49,52,46,53,113,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,127,185,1,67,6,0,32,0,51,46,51,113,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,14,109,156,72,7,0,64,0,50,46,51,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,57,206,16,119,7,0,64,0,114,101,100,95,49,46,53,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,97,99,12,131,1,0,16,1,114,101,100,95,50,46,53,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,204,81,37,210,1,0,16,1,114,101,100,95,51,46,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,74,163,19,7,1,0,16,1,114,101,100,95,52,46,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,170,202,139,243,1,0,16,1,114,101,100,95,53,46,51,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,103,34,56,106,1,0,16,1,114,101,100,95,54,46,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,33,177,248,76,1,0,16,1,114,101,100,95,55,46,52,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,186,196,79,189,1,0,16,1,114,101,100,45,50,48,46,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,220,152,102,45,2,0,32,0,114,101,100,45,50,49,46,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,155,206,201,56,2,0,32,0,54,51,51,49,45,49,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,3,149,29,206,3,0,32,0,54,51,48,49,45,49,46,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,92,251,214,57,3,0,32,0,16,0,0,0,255,255,255,0,0,0,0,0,17,0,0,0,255,255,255,0,0,0,0,0,18,0,0,0,255,255,254,0,0,0,0,0,15,0,0,0,255,255,251,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,15,0,0,0,1,1,1,0,120,97,1,0,15,0,0,0,1,1,0,0,96,19,1,0,0,0,0,0,254,0,2,0,144,212,8,0,15,0,0,0,1,32,32,0,96,135,7,0,15,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,4,0,64,37,5,0,15,0,0,0,1,12,8,0,152,53,6,0,15,0,0,0,1,12,4,0,8,49,6,0,15,0,0,0,1,12,0,0,248,45,5,0,15,0,0,0,1,12,12,0,160,57,4,0,0,0,0,0,254,0,4,0,128,129,4,0,15,0,0,0,1,48,48,0,8,49,4,0,15,0,0,0,1,48,32,0,152,21,4,0,15,0,0,0,1,48,16,0,72,246,3,0,15,0,0,0,1,48,0,0,72,0,3,0,0,0,0,0,254,0,4,0,32,4,2,0,15,0,0,0,1,192,0,0,160,36,8,0,15,0,0,0,1,192,192,0,208,239,7,0,15,0,0,0,1,192,128,0,120,187,7,0,15,0,0,0,1,192,64,0,136,23,1,0,0,0,0,0,78,12,0,0,16,29,0,0,0,1,17,112,37,37,37,0,1,0,17,224,0,0,0,0,49,112,114,111,103,95,108,46,117,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,2,253,214,149,1,0,16,1,50,112,114,111,103,95,104,46,117,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,232,173,94,252,1,0,16,1,49,108,46,117,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,92,86,235,194,2,0,32,0,49,104,46,117,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,183,70,203,35,2,0,32,0,50,108,46,117,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,234,106,37,188,2,0,32,0,50,104,46,117,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,236,89,95,183,2,0,32,0,51,108,46,117,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,8,240,132,66,2,0,32,0,51,104,46,117,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,191,203,229,171,2,0,32,0,52,108,46,117,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,229,242,252,201,2,0,32,0,52,104,46,117,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,42,161,176,10,2,0,32,0,53,108,46,117,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,207,60,208,104,2,0,32,0,53,104,46,117,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,202,251,80,84,2,0,32,0,54,108,46,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,11,201,82,139,2,0,32,0,54,104,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,41,249,98,115,2,0,32,0,55,108,46,117,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,110,216,244,180,2,0,32,0,55,104,46,117,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,204,185,183,68,2,0,32,0,56,108,46,117,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,137,159,7,205,2,0,32,0,56,104,46,117,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,138,80,219,62,2,0,32,0,57,108,46,117,52,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,120,205,83,11,2,0,32,0,57,104,46,117,52,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,138,153,97,188,2,0,32,0,49,48,108,46,117,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,248,199,245,163,2,0,32,0,49,48,104,46,117,53,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,196,4,227,48,2,0,32,0,115,110,100,48,46,117,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,37,178,209,127,3,0,64,0,101,101,112,114,111,109,45,100,114,97,103,110,98,108,122,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,166,163,168,112,0,0,0,8,117,100,50,45,48,48,49,45,48,48,48,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,96,82,150,241,1,0,16,1,117,100,50,45,48,48,49,45,48,48,51,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,95,250,213,231,1,0,16,1,117,100,50,48,48,49,48,48,50,46,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,172,227,0,163,1,0,16,1,117,100,50,48,48,49,48,48,49,46,56,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,148,128,145,210,1,0,16,1,117,100,50,45,48,48,50,45,48,48,52,46,49,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,177,56,213,187,2,0,16,1,117,100,50,45,48,48,49,45,48,48,53,45,116,48,49,46,50,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,73,210,230,119,11,0,32,0,117,100,50,45,48,48,49,45,48,48,54,45,116,48,50,46,51,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,242,27,56,110,11,0,32,0,117,100,50,45,48,48,49,45,48,48,55,45,116,48,51,46,53,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,113,73,123,115,11,0,32,0,117,100,50,45,48,48,49,45,48,48,56,45,116,48,52,46,54,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,87,215,185,153,11,0,32,0,117,100,50,45,48,48,49,45,48,48,57,45,116,48,53,46,56,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,129,197,230,174,4,0,32,0,117,100,50,45,48,48,49,45,48,49,48,45,116,48,54,46,57,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,84,157,57,61,4,0,32,0,117,100,50,45,48,48,49,45,48,49,49,45,116,48,55,46,49,52,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,159,246,159,156,6,0,64,0,48,56,50,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,42,131,171,52,1,0,16,1,48,56,50,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,197,149,249,190,2,0,32,0,48,56,50,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,37,199,120,180,3,0,32,0,48,56,50,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,50,218,87,40,3,0,32,0,48,56,50,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,142,55,13,139,3,0,32,0,48,56,50,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,150,245,210,199,3,0,32,0,48,56,50,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,246,191,135,236,3,0,32,0,48,56,50,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,17,138,74,132,3,0,32,0,48,56,50,45,99,55,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,2,77,124,114,3,0,32,0,48,56,50,45,99,56,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,55,250,165,105,3,0,32,0,48,56,50,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,222,68,177,16,4,0,16,1,48,56,50,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,228,40,17,204,5,0,64,0,48,56,50,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,84,85,255,195,5,0,64,0,49,52,52,55,57,97,46,109,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,219,80,122,183,0,0,16,1,49,52,52,55,57,46,109,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,165,127,170,166,0,0,16,1,49,46,51,102,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,248,214,5,77,1,0,16,1,50,46,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,9,59,180,39,1,0,16,1,51,46,51,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,149,242,210,56,1,0,16,1,54,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,156,139,45,42,2,0,32,0,55,46,54,98,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,250,149,79,209,2,0,32,0,53,46,51,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,88,79,192,84,3,0,32,0,52,46,51,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,147,100,187,30,3,0,32,0,100,111,114,111,100,111,110,46,98,112,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,53,193,101,248,4,0,16,1,100,111,114,111,100,111,110,46,98,112,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,187,240,178,71,4,0,16,1,100,111,114,111,100,111,110,46,98,112,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,200,11,207,143,5,0,32,0,100,111,114,111,100,111,110,46,98,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,228,155,32,63,5,0,32,0,100,111,114,111,100,111,110,46,98,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,80,58,250,39,5,0,0,8,112,114,103,117,46,117,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,2,104,195,137,0,0,16,1,97,116,100,112,46,117,52,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,83,233,137,113,0,0,32,0,97,116,100,112,46,117,52,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,63,23,132,105,0,0,32,0,97,116,100,112,46,117,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,102,107,218,107,0,0,32,0,97,116,100,112,46,117,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,185,114,14,10,0,0,32,0,116,101,120,116,46,117,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,231,6,186,93,0,0,32,0,97,116,100,112,46,117,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,202,252,137,13,0,0,64,0,97,116,100,112,46,117,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,222,73,215,0,0,64,0,101,101,112,114,111,109,45,100,111,110,112,97,99,104,105,46,117,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,70,181,95,49,0,0,16,1,112,101,101,108,49,56,99,118,56,112,45,49,53,46,117,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,85,1,0,0,233,135,71,63,0,0,0,8,115,97,109,112,108,101,49,48,46,57,46,117,54,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,22,80,95,88,0,0,16,1,116,112,48,50,50,95,51,46,119,57,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,95,89,27,25,0,0,32,0,116,112,48,50,50,95,52,46,119,57,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,202,41,141,213,0,0,32,0,116,112,48,50,50,95,53,46,119,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,69,219,193,212,0,0,32,0,116,112,48,50,50,95,54,46,119,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,79,199,141,212,0,0,32,0,116,112,48,50,50,95,50,46,119,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,179,113,50,4,0,0,64,0,48,49,46,117,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,244,215,91,254,0,0,16,1,116,112,48,50,50,95,51,46,119,57,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,95,89,27,25,0,0,32,0,116,112,48,50,50,95,52,46,119,57,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,202,41,141,213,0,0,32,0,116,112,48,50,50,95,53,46,119,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,69,219,193,212,0,0,32,0,116,112,48,50,50,95,54,46,119,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,79,199,141,212,0,0,32,0,116,112,48,50,50,95,50,46,119,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,179,113,50,4,0,0,64,0,118,49,48,51,95,49,54,109,46,117,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,61,251,218,45,1,0,16,1,116,48,52,53,48,49,46,117,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,172,170,14,144,2,0,32,0,97,48,52,53,48,49,46,117,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,166,190,65,151,3,0,32,0,97,48,52,53,48,50,46,117,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,5,244,4,225,3,0,32,0,97,48,52,53,48,51,46,117,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,227,207,213,191,3,0,32,0,98,48,52,53,48,49,46,117,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,125,11,50,41,4,0,32,0,98,48,52,53,48,50,46,117,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,233,0,140,87,4,0,32,0,119,48,52,53,48,49,46,117,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,55,129,181,58,5,0,64,0,100,109,110,102,114,110,116,95,105,103,115,48,50,55,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,7,0,16,17,118,49,48,51,95,51,50,109,46,117,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,163,131,131,231,8,0,16,1,118,49,48,50,95,49,54,109,46,117,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,26,72,77,61,1,0,16,1,116,48,52,53,48,49,46,117,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,172,170,14,144,2,0,32,0,97,48,52,53,48,49,46,117,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,166,190,65,151,3,0,32,0,97,48,52,53,48,50,46,117,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,5,244,4,225,3,0,32,0,97,48,52,53,48,51,46,117,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,227,207,213,191,3,0,32,0,98,48,52,53,48,49,46,117,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,125,11,50,41,4,0,32,0,98,48,52,53,48,50,46,117,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,233,0,140,87,4,0,32,0,119,48,52,53,48,49,46,117,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,55,129,181,58,5,0,64,0,100,109,110,102,114,110,116,95,105,103,115,48,50,55,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,7,0,16,17,118,49,48,49,95,51,50,109,46,117,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,129,82,150,147,8,0,16,1,99,95,53,101,116,95,103,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,139,184,112,186,1,0,0,0,99,95,53,99,116,95,103,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,236,97,196,94,1,0,0,0,99,95,53,98,116,95,103,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,36,211,151,28,1,0,0,0,99,95,53,97,116,95,103,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,192,90,0,185,1,0,0,0,100,50,107,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,66,252,72,32,2,0,0,0,115,95,51,105,95,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,6,237,164,69,3,0,0,0,115,95,51,106,95,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,146,254,67,71,3,0,0,0,118,95,53,104,95,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,93,201,200,18,4,0,0,0,118,95,51,112,116,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,233,197,233,21,4,0,0,0,108,95,52,109,95,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,77,5,248,89,5,0,0,0,108,95,52,110,95,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,20,71,46,103,5,0,0,0,108,95,52,114,95,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,238,89,170,254,5,0,0,0,108,95,52,115,95,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,126,239,242,32,5,0,0,0,99,45,50,107,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,229,237,115,226,6,0,0,0,99,45,50,106,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,88,35,65,214,6,0,0,0,118,45,53,101,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,245,184,105,184,6,0,0,0,99,95,53,98,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,206,21,160,80,1,0,0,0,99,95,53,99,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,13,143,161,192,1,0,0,0,99,95,53,101,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,12,208,29,168,1,0,0,0,99,95,51,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,248,165,93,113,2,0,0,0,118,95,51,110,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,99,76,92,169,3,0,0,0,118,95,51,112,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,239,255,116,73,3,0,0,0,118,95,55,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,100,65,127,220,4,0,0,0,118,95,55,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,246,220,231,12,4,0,0,0,118,95,55,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,23,255,209,36,4,0,0,0,118,95,55,102,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,63,8,140,15,4,0,0,0,99,45,50,101,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,173,199,61,70,5,0,0,0,99,45,50,102,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,66,0,186,71,5,0,0,0,118,45,50,110,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,133,241,219,5,0,0,0,100,107,106,114,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,127,9,126,236,1,0,0,0,99,95,53,99,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,13,143,161,192,1,0,0,0,99,95,53,101,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,12,208,29,168,1,0,0,0,99,95,51,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,248,165,93,113,2,0,0,0,118,95,51,110,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,99,76,92,169,3,0,0,0,100,107,106,114,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,34,19,193,173,3,0,0,0,118,95,55,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,100,65,127,220,4,0,0,0,118,95,55,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,246,220,231,12,4,0,0,0,118,95,55,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,23,255,209,36,4,0,0,0,118,95,55,102,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,63,8,140,15,4,0,0,0,99,45,50,101,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,173,199,61,70,5,0,0,0,99,45,50,102,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,66,0,186,71,5,0,0,0,118,45,50,110,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,133,241,219,5,0,0,0,99,95,53,102,95,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,17,43,79,66,1,0,0,0,53,103,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,155,89,38,211,1,0,0,0,99,95,53,104,95,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,93,137,40,29,1,0,0,0,53,107,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,156,89,97,121,1,0,0,0,115,95,51,105,95,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,6,237,164,69,2,0,0,0,115,95,51,106,95,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,146,254,67,71,2,0,0,0,118,95,53,104,95,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,93,201,200,18,3,0,0,0,118,95,53,107,95,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,20,249,132,54,3,0,0,0,108,95,52,109,95,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,77,5,248,89,4,0,0,0,108,95,52,110,95,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,20,71,46,103,4,0,0,0,108,95,52,114,95,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,238,89,170,254,4,0,0,0,108,95,52,115,95,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,126,239,242,32,4,0,0,0,99,45,50,107,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,229,237,115,226,5,0,0,0,99,45,50,106,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,88,35,65,214,5,0,0,0,118,45,53,101,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,245,184,105,184,5,0,0,0,103,101,110,45,97,45,104,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,109,95,164,7,1,0,16,1,103,101,110,45,97,45,108,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,234,143,71,70,1,0,16,1,103,101,110,45,97,45,104,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,60,183,229,84,1,0,16,1,103,101,110,45,97,45,108,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,159,138,79,137,1,0,16,1,103,101,110,45,97,45,115,112,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,44,252,60,232,6,0,16,1,104,104,95,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,239,39,81,236,2,0,32,0,104,104,95,49,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,148,82,246,222,2,0,32,0,104,104,95,50,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,212,106,13,187,2,0,32,0,104,104,95,51,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,78,4,81,67,2,0,32,0,104,104,95,97,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,95,186,119,197,3,0,32,0,104,104,95,97,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,171,18,157,66,3,0,32,0,104,104,95,97,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,176,99,177,181,3,0,32,0,104,104,95,97,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,161,102,245,142,3,0,32,0,103,101,110,45,118,111,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,102,92,89,216,5,0,64,0,100,98,95,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,102,19,161,106,1,0,16,1,100,98,95,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,115,166,248,69,1,0,16,1,100,98,95,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,236,73,235,255,2,0,16,1,100,98,95,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,32,98,185,123,3,0,32,0,100,98,95,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,118,84,177,18,3,0,32,0,100,98,95,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,65,87,72,24,4,0,32,0,100,98,95,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,204,209,129,195,4,0,32,0,100,98,95,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,82,227,180,33,4,0,32,0,100,98,95,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,129,156,210,65,4,0,32,0,100,98,95,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,5,117,69,80,5,0,64,0,100,98,95,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,160,29,184,1,5,0,64,0,100,105,103,45,112,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,215,51,164,237,1,0,16,1,100,105,103,45,115,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,31,140,168,117,2,0,32,0,100,105,103,45,99,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,237,164,176,61,3,0,32,0,100,105,103,45,99,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,33,99,62,3,0,32,0,100,105,103,45,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,27,223,60,131,4,0,16,1,100,105,103,45,118,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,164,189,21,238,5,0,64,0,99,118,48,49,45,117,51,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,157,241,135,190,0,0,16,1,99,118,48,49,45,117,51,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,179,125,58,229,0,0,16,1,99,118,48,49,45,117,50,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,93,169,246,166,0,0,32,0,99,118,48,49,45,117,50,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,42,182,237,50,0,0,32,0,99,118,48,49,45,117,53,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,23,68,52,122,0,0,32,0,99,118,48,49,45,117,52,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,167,221,28,210,0,0,32,0,99,118,48,49,45,117,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,218,20,85,95,0,0,64,0,101,101,112,114,111,109,45,100,102,101,118,101,114,111,110,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,89,73,23,195,0,0,16,1,56,57,48,122,48,50,46,107,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,111,48,235,235,1,0,16,1,56,57,48,107,48,49,46,102,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,176,62,75,212,2,0,16,1,56,57,48,102,48,54,46,102,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,85,33,89,38,3,0,32,0,56,57,48,102,48,55,46,104,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,46,250,116,108,3,0,32,0,56,57,48,102,48,56,46,106,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,128,46,225,41,3,0,32,0,56,57,48,102,48,57,46,107,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,213,64,202,103,3,0,32,0,56,57,48,102,48,52,46,104,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,250,209,108,241,4,0,32,0,56,57,48,102,48,53,46,107,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,5,219,55,218,4,0,32,0,56,57,48,102,48,51,46,100,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,49,80,6,25,6,0,32,0,54,51,115,49,52,49,110,46,107,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,6,1,98,211,5,0,0,8,111,49,54,45,49,48,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,243,148,129,202,0,0,16,1,111,49,54,45,48,57,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,186,167,174,123,0,0,16,1,114,111,109,49,49,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,133,140,224,219,0,0,16,1,100,115,112,95,50,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,118,83,19,45,0,0,16,1,100,115,112,95,50,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,113,154,56,121,0,0,16,1,114,111,109,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,130,201,6,101,0,0,32,0,114,111,109,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,147,217,160,163,0,0,32,0,114,111,109,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,243,229,197,79,0,0,32,0,114,111,109,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,171,83,235,0,0,32,0,114,111,109,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,233,36,55,27,0,0,32,0,114,111,109,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,77,164,32,123,0,0,32,0,114,111,109,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,208,220,172,44,0,0,32,0,114,111,109,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,1,50,253,118,0,0,32,0,112,114,111,109,49,50,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,237,204,136,188,0,0,32,0,112,114,111,109,49,51,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,146,116,225,161,0,0,32,0,97,115,48,57,48,54,101,48,53,46,117,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,23,31,200,32,1,0,0,0,97,115,48,57,48,55,101,48,53,46,117,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,42,170,49,23,1,0,0,0,97,115,48,57,48,49,109,48,49,46,117,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,143,207,106,29,2,0,0,0,97,115,48,57,48,50,109,48,49,46,117,51,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,40,33,202,199,2,0,0,0,97,115,48,57,48,51,109,48,49,46,117,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,179,129,239,232,2,0,0,0,97,115,48,57,48,52,109,48,49,46,117,52,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,220,127,249,208,2,0,0,0,97,115,48,57,48,53,109,48,49,46,117,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,187,101,129,141,3,0,0,0,97,115,48,57,48,54,101,48,49,46,117,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,163,59,62,16,1,0,0,0,97,115,48,57,48,55,101,48,49,46,117,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,151,15,235,221,1,0,0,0,97,115,48,57,48,49,109,48,49,46,117,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,143,207,106,29,2,0,0,0,97,115,48,57,48,50,109,48,49,46,117,51,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,40,33,202,199,2,0,0,0,97,115,48,57,48,51,109,48,49,46,117,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,179,129,239,232,2,0,0,0,97,115,48,57,48,52,109,48,49,46,117,52,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,220,127,249,208,2,0,0,0,97,115,48,57,48,53,109,48,49,46,117,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,187,101,129,141,3,0,0,0,97,115,48,57,48,54,101,48,50,46,117,48,54,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,66,202,12,25,1,0,0,0,97,115,48,57,48,55,101,48,50,46,117,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,185,226,157,1,0,0,0,97,115,48,57,48,49,109,48,49,46,117,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,143,207,106,29,2,0,0,0,97,115,48,57,48,50,109,48,49,46,117,51,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,40,33,202,199,2,0,0,0,97,115,48,57,48,51,109,48,49,46,117,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,179,129,239,232,2,0,0,0,97,115,48,57,48,52,109,48,49,46,117,52,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,220,127,249,208,2,0,0,0,97,115,48,57,48,53,109,48,49,46,117,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,187,101,129,141,3,0,0,0,97,115,48,57,51,55,101,48,49,46,117,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,142,8,116,141,1,0,0,0,97,115,48,57,51,56,101,48,49,46,117,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,137,120,101,199,1,0,0,0,97,115,48,57,48,49,109,48,49,46,117,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,143,207,106,29,2,0,0,0,97,115,48,57,48,50,109,48,49,46,117,51,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,40,33,202,199,2,0,0,0,97,115,48,57,48,51,109,48,49,46,117,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,179,129,239,232,2,0,0,0,97,115,48,57,48,52,109,48,49,46,117,52,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,220,127,249,208,2,0,0,0,97,115,48,57,48,53,109,48,49,46,117,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,187,101,129,141,3,0,0,0,97,115,48,57,48,54,101,48,52,46,117,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,74,182,217,7,1,0,0,0,97,115,48,57,48,55,101,48,52,46,117,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,8,61,151,25,1,0,0,0,97,115,48,57,48,49,109,48,49,46,117,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,143,207,106,29,2,0,0,0,97,115,48,57,48,50,109,48,49,46,117,51,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,40,33,202,199,2,0,0,0,97,115,48,57,48,51,109,48,49,46,117,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,179,129,239,232,2,0,0,0,97,115,48,57,48,52,109,48,49,46,117,52,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,220,127,249,208,2,0,0,0,97,115,48,57,48,53,109,48,49,46,117,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,187,101,129,141,3,0,0,0,97,115,48,57,48,54,101,48,52,45,118,52,95,50,46,117,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,111,243,58,187,1,0,0,0,97,115,48,57,48,55,101,48,52,45,118,52,95,50,46,117,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,23,33,240,131,1,0,0,0,97,115,48,57,48,49,109,48,49,46,117,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,143,207,106,29,2,0,0,0,97,115,48,57,48,50,109,48,49,46,117,51,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,40,33,202,199,2,0,0,0,97,115,48,57,48,51,109,48,49,46,117,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,179,129,239,232,2,0,0,0,97,115,48,57,48,52,109,48,49,46,117,52,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,220,127,249,208,2,0,0,0,97,115,48,57,48,53,109,48,49,46,117,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,187,101,129,141,3,0,0,0,104,102,45,48,51,45,50,46,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,243,255,134,251,1,0,16,1,104,102,45,48,48,45,50,46,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,34,164,154,9,1,0,16,1,104,100,45,48,52,45,49,46,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,215,168,46,253,1,0,16,1,104,100,45,48,49,45,49,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,172,71,162,72,1,0,16,1,104,100,45,49,50,46,50,49,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,17,95,213,19,2,0,16,1,104,100,45,48,54,45,49,46,56,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,139,85,122,139,3,0,32,0,104,100,45,48,55,45,49,46,57,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,73,212,163,210,3,0,32,0,109,97,102,45,48,48,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,141,82,111,229,4,0,32,0,109,97,102,45,48,49,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,61,23,213,195,5,0,32,0,109,97,102,45,48,50,46,49,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,73,216,55,11,5,0,32,0,109,97,102,45,48,51,46,49,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,44,109,54,244,6,0,32,0,109,97,102,45,48,52,46,50,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,78,101,143,12,6,0,32,0,109,97,102,45,48,53,46,50,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,128,235,207,176,6,0,32,0,109,97,102,45,48,54,46,49,56,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,181,169,199,245,6,0,32,0,109,97,102,45,48,55,46,50,48,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,163,8,96,253,6,0,32,0,109,97,102,45,48,56,46,50,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,231,241,28,228,6,0,32,0,104,102,45,48,56,46,49,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,159,39,183,147,7,0,32,0,104,102,45,48,57,46,49,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,116,192,226,5,7,0,32,0,104,102,45,49,48,46,49,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,24,244,6,155,7,0,32,0,104,102,45,49,49,46,49,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,49,165,89,56,7,0,32,0,109,97,102,45,49,48,46,50,48,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,139,244,87,124,8,0,64,0,109,97,102,45,48,57,46,49,56,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,129,237,231,40,9,0,64,0,100,100,98,49,48,46,117,52,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,16,85,179,114,1,0,16,1,116,48,52,52,48,49,119,48,54,52,46,117,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,156,241,149,58,2,0,32,0,97,48,52,52,48,49,119,48,54,52,46,117,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,148,151,34,237,3,0,32,0,97,48,52,52,48,50,119,48,54,52,46,117,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,176,103,33,117,3,0,32,0,98,48,52,52,48,49,119,48,54,52,46,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,102,240,191,140,4,0,32,0,109,48,52,52,48,49,98,48,51,50,46,117,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,118,189,13,90,5,0,64,0,100,100,112,51,95,105,103,115,48,50,55,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,7,0,16,17,100,100,112,51,98,108,107,95,100,101,102,97,117,108,116,115,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,4,25,101,161,0,0,0,8,112,103,109,95,116,48,49,115,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,160,35,113,26,0,0,32,2,112,103,109,95,109,48,49,115,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,89,113,174,69,0,0,64,2,100,100,112,51,95,98,105,111,115,46,117,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,143,92,204,179,0,0,16,2,118,49,48,49,95,49,54,109,46,117,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,253,134,87,94,1,0,16,1,100,100,112,50,95,105,103,115,48,50,55,97,95,116,97,105,119,97,110,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,220,75,211,29,7,0,16,1,116,49,51,48,48,46,117,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,203,240,72,231,2,0,32,0,97,49,51,48,48,46,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,5,164,135,252,3,0,32,0,97,49,51,48,49,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,218,32,133,12,3,0,32,0,98,49,51,48,48,46,117,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,4,102,100,239,4,0,32,0,109,49,51,48,48,46,117,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,93,1,212,130,5,0,64,0,118,49,48,48,46,117,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,41,221,195,6,8,0,16,1,118,49,48,49,95,49,54,109,46,117,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,253,134,87,94,1,0,16,1,100,100,112,50,95,105,103,115,48,50,55,97,95,107,111,114,101,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,23,28,168,229,7,0,16,1,116,49,51,48,48,46,117,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,203,240,72,231,2,0,32,0,97,49,51,48,48,46,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,5,164,135,252,3,0,32,0,97,49,51,48,49,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,218,32,133,12,3,0,32,0,98,49,51,48,48,46,117,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,4,102,100,239,4,0,32,0,109,49,51,48,48,46,117,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,93,1,212,130,5,0,64,0,118,49,48,48,46,117,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,41,221,195,6,8,0,16,1,118,49,48,49,95,49,54,109,46,117,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,253,134,87,94,1,0,16,1,100,100,112,50,95,105,103,115,48,50,55,97,95,106,97,112,97,110,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,210,52,45,116,7,0,16,1,116,49,51,48,48,46,117,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,203,240,72,231,2,0,32,0,97,49,51,48,48,46,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,5,164,135,252,3,0,32,0,97,49,51,48,49,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,218,32,133,12,3,0,32,0,98,49,51,48,48,46,117,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,4,102,100,239,4,0,32,0,109,49,51,48,48,46,117,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,93,1,212,130,5,0,64,0,118,49,48,48,46,117,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,41,221,195,6,8,0,16,1,118,49,48,49,95,49,54,109,46,117,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,253,134,87,94,1,0,16,1,100,100,112,50,95,105,103,115,48,50,55,97,95,99,104,105,110,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,25,99,86,140,7,0,16,1,116,49,51,48,48,46,117,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,203,240,72,231,2,0,32,0,97,49,51,48,48,46,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,5,164,135,252,3,0,32,0,97,49,51,48,49,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,218,32,133,12,3,0,32,0,98,49,51,48,48,46,117,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,4,102,100,239,4,0,32,0,109,49,51,48,48,46,117,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,93,1,212,130,5,0,64,0,118,49,48,48,46,117,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,41,221,195,6,8,0,16,1,118,49,48,48,46,117,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,234,168,138,12,1,0,16,1,100,100,112,50,95,105,103,115,48,50,55,97,95,116,97,105,119,97,110,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,220,75,211,29,7,0,16,1,116,49,51,48,48,46,117,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,203,240,72,231,2,0,32,0,97,49,51,48,48,46,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,5,164,135,252,3,0,32,0,97,49,51,48,49,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,218,32,133,12,3,0,32,0,98,49,51,48,48,46,117,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,4,102,100,239,4,0,32,0,109,49,51,48,48,46,117,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,93,1,212,130,5,0,64,0,118,49,48,48,46,117,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,41,221,195,6,8,0,16,1,118,49,48,48,46,117,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,234,168,138,12,1,0,16,1,100,100,112,50,95,105,103,115,48,50,55,97,95,107,111,114,101,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,23,28,168,229,7,0,16,1,116,49,51,48,48,46,117,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,203,240,72,231,2,0,32,0,97,49,51,48,48,46,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,5,164,135,252,3,0,32,0,97,49,51,48,49,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,218,32,133,12,3,0,32,0,98,49,51,48,48,46,117,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,4,102,100,239,4,0,32,0,109,49,51,48,48,46,117,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,93,1,212,130,5,0,64,0,118,49,48,48,46,117,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,41,221,195,6,8,0,16,1,118,49,48,48,46,117,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,234,168,138,12,1,0,16,1,100,100,112,50,95,105,103,115,48,50,55,97,95,106,97,112,97,110,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,210,52,45,116,7,0,16,1,116,49,51,48,48,46,117,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,203,240,72,231,2,0,32,0,97,49,51,48,48,46,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,5,164,135,252,3,0,32,0,97,49,51,48,49,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,218,32,133,12,3,0,32,0,98,49,51,48,48,46,117,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,4,102,100,239,4,0,32,0,109,49,51,48,48,46,117,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,93,1,212,130,5,0,64,0,118,49,48,48,46,117,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,41,221,195,6,8,0,16,1,118,49,48,48,46,117,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,234,168,138,12,1,0,16,1,100,100,112,50,95,105,103,115,48,50,55,97,95,99,104,105,110,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,25,99,86,140,7,0,16,1,116,49,51,48,48,46,117,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,203,240,72,231,2,0,32,0,97,49,51,48,48,46,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,5,164,135,252,3,0,32,0,97,49,51,48,49,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,218,32,133,12,3,0,32,0,98,49,51,48,48,46,117,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,4,102,100,239,4,0,32,0,109,49,51,48,48,46,117,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,93,1,212,130,5,0,64,0,118,49,48,48,46,117,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,41,221,195,6,8,0,16,1,98,49,46,117,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,211,200,205,181,0,0,16,1,98,50,46,117,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,58,6,187,107,0,0,16,1,117,53,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,236,96,178,20,0,0,32,0,117,53,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,206,140,186,231,0,0,32,0,117,53,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,224,46,73,2,0,0,32,0,117,53,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,240,16,76,203,0,0,32,0,117,54,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,167,150,48,144,0,0,32,0,117,54,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,49,118,155,216,0,0,32,0,117,54,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,107,251,43,41,0,0,32,0,117,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,175,175,253,157,0,0,64,0,117,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,213,23,91,121,0,0,64,0,101,101,112,114,111,109,45,100,100,111,110,112,97,99,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,70,181,95,49,0,0,16,1,117,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,2,158,92,176,1,0,16,1,117,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,190,92,179,202,1,0,16,1,117,50,49,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,92,151,95,211,2,0,64,0,117,53,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,52,133,123,181,3,0,32,0,117,53,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,255,19,237,116,3,0,32,0,117,52,50,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,31,39,233,176,4,0,32,0,117,52,50,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,232,137,39,37,4,0,32,0,100,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,217,27,188,68,1,0,16,1,100,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,27,49,90,98,1,0,16,1,100,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,92,151,95,211,2,0,64,0,100,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,181,61,148,65,3,0,32,0,100,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,81,154,137,107,3,0,32,0,100,49,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,88,1,234,175,4,0,32,0,100,49,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,220,113,201,4,0,32,0,48,49,46,97,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,167,126,241,20,1,0,16,1,48,51,46,97,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,12,185,209,190,1,0,16,1,103,115,48,48,46,97,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,117,113,39,183,1,0,16,1,103,115,48,50,46,97,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,53,30,227,205,1,0,16,1,104,99,49,48,45,49,46,97,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,112,199,90,172,2,0,16,1,104,99,48,56,45,49,46,97,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,86,202,77,134,2,0,16,1,103,115,49,49,46,97,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,222,35,203,128,2,0,16,1,103,115,48,57,46,97,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,225,167,143,10,2,0,16,1,103,115,48,52,46,102,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,191,158,194,129,3,0,16,1,103,115,48,53,46,104,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,106,153,174,10,4,0,32,0,103,115,48,54,46,104,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,61,240,253,78,4,0,32,0,109,97,106,45,48,50,46,104,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,55,188,59,56,5,0,32,0,109,97,106,45,48,49,46,99,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,4,162,64,152,6,0,32,0,109,97,106,45,48,48,46,99,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,22,141,234,135,6,0,32,0,109,97,106,45,48,52,46,114,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,25,155,228,54,7,0,32,0,109,97,106,45,48,53,46,114,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,204,113,252,128,7,0,32,0,109,97,106,45,48,54,46,114,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,75,104,122,46,7,0,32,0,109,97,106,45,48,55,46,114,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,120,31,204,58,7,0,32,0,109,97,106,45,48,56,46,115,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,109,163,88,25,7,0,32,0,109,97,106,45,48,57,46,115,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,161,135,16,194,7,0,32,0,109,97,106,45,49,48,46,115,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,65,166,47,160,7,0,32,0,109,97,106,45,49,49,46,115,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,5,147,190,218,7,0,32,0,103,115,49,50,46,110,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,21,160,134,154,8,0,32,0,103,115,49,51,46,110,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,5,153,112,244,8,0,32,0,103,115,49,52,46,110,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,35,197,15,117,8,0,32,0,103,115,49,53,46,110,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,61,221,78,241,8,0,32,0,103,115,48,55,46,104,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,93,126,11,117,9,0,64,0,109,97,106,45,48,51,46,104,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,195,250,220,49,10,0,64,0,109,98,55,49,50,56,121,46,49,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,162,128,231,189,11,0,0,8,109,98,55,49,50,56,121,46,49,54,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,81,39,77,196,11,0,0,8,109,98,55,49,50,56,121,46,49,54,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,81,39,77,196,11,0,0,8,109,98,55,49,50,56,121,46,49,55,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,81,39,77,196,11,0,0,8,112,97,108,49,54,114,56,97])
.concat([32,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,12,0,0,16,112,97,108,49,54,108,56,98,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,12,0,0,16,112,97,108,49,54,108,56,98,46,55,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,253,131,158,25,12,0,0,8,112,97,108,49,54,108,56,98,46,55,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,12,0,0,16,112,97,108,49,54,108,56,98,46,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,12,0,0,16,112,97,108,49,54,108,56,98,46,56,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,12,0,0,16,112,97,108,49,54,108,56,98,46,57,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,12,0,0,16,112,97,108,49,54,108,56,98,46,49,48,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,12,0,0,16,103,97,95,48,52,45,51,46,106,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,86,213,250,186,1,0,16,1,103,97,95,48,49,45,51,46,104,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,14,5,9,244,1,0,16,1,103,97,95,48,48,46,104,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,99,172,243,251,1,0,16,1,103,97,95,48,53,46,106,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,174,227,213,1,0,16,1,102,122,95,48,54,45,49,46,106,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,109,138,130,196,2,0,16,1,102,122,95,48,50,46,106,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,18,48,156,60,3,0,32,0,102,122,95,48,51,46,106,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,237,144,75,38,3,0,32,0,109,97,99,45,48,51,46,104,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,220,243,150,153,4,0,32,0,109,97,99,45,48,50,46,101,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,137,78,80,73,5,0,32,0,109,97,99,45,48,48,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,214,241,172,82,6,0,32,0,109,97,99,45,48,49,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,132,117,143,178,6,0,32,0,102,122,95,48,56,46,108,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,225,104,191,201,7,0,64,0,102,122,95,48,55,46,107,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,203,211,141,88,8,0,64,0,102,122,95,48,52,45,52,46,106,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,44,170,127,129,1,0,16,1,102,122,95,48,49,45,52,46,104,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,238,174,60,55,1,0,16,1,102,122,95,48,48,45,50,46,104,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,167,154,185,26,1,0,16,1,102,122,95,48,53,45,50,46,106,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,140,239,116,51,1,0,16,1,102,122,95,48,54,45,49,46,106,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,109,138,130,196,2,0,16,1,102,122,95,48,50,46,106,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,18,48,156,60,3,0,32,0,102,122,95,48,51,46,106,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,237,144,75,38,3,0,32,0,109,97,99,45,48,51,46,104,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,220,243,150,153,4,0,32,0,109,97,99,45,48,50,46,101,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,137,78,80,73,5,0,32,0,109,97,99,45,48,48,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,214,241,172,82,6,0,32,0,109,97,99,45,48,49,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,132,117,143,178,6,0,32,0,102,122,95,48,56,46,108,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,225,104,191,201,7,0,64,0,102,122,95,48,55,46,107,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,203,211,141,88,8,0,64,0,103,97,95,48,52,46,106,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,169,133,169,161,1,0,16,1,103,97,95,48,49,46,104,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,64,41,189,152,1,0,16,1,103,97,95,48,48,46,104,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,99,172,243,251,1,0,16,1,103,97,95,48,53,46,106,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,174,227,213,1,0,16,1,102,122,95,48,54,45,49,46,106,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,109,138,130,196,2,0,16,1,102,122,95,48,50,46,106,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,18,48,156,60,3,0,32,0,102,122,95,48,51,46,106,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,237,144,75,38,3,0,32,0,109,97,99,45,48,51,46,104,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,220,243,150,153,4,0,32,0,109,97,99,45,48,50,46,101,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,137,78,80,73,5,0,32,0,109,97,99,45,48,48,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,214,241,172,82,6,0,32,0,109,97,99,45,48,49,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,132,117,143,178,6,0,32,0,102,122,95,48,56,46,108,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,225,104,191,201,7,0,64,0,102,122,95,48,55,46,107,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,203,211,141,88,8,0,64,0,112,49,97,46,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,22,189,26,190,1,0,16,1,112,50,97,46,51,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,154,200,144,82,1,0,16,1,115,117,98,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,235,162,20,56,2,0,16,1,115,117,98,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,88,173,247,26,2,0,16,1,115,115,53,46,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,11,22,186,195,3,0,16,1,115,115,49,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,148,207,209,39,4,0,64,0,115,115,51,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,142,72,39,163,4,0,64,0,115,115,50,46,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,148,207,209,39,5,0,64,0,115,115,52,46,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,142,72,39,163,5,0,64,0,115,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,12,71,230,105,6,0,32,0,115,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,68,15,35,119,6,0,32,0,115,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,13,152,218,191,6,0,32,0,115,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,250,252,17,138,6,0,32,0,115,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,8,96,219,189,7,0,32,0,115,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,165,15,91,214,7,0,32,0,115,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,103,5,34,112,7,0,32,0,115,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,203,79,140,152,7,0,32,0,115,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,44,69,19,101,8,0,32,0,115,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,59,14,39,58,8,0,32,0,115,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,102,255,78,88,8,0,32,0,115,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,2,84,186,81,8,0,32,0,114,111,97,100,95,99,104,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,156,16,43,134,9,0,32,0,114,111,97,100,95,99,104,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,136,201,237,157,9,0,32,0,99,48,49,46,57,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,226,61,238,181,10,0,32,0,99,48,50,46,57,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,121,125,133,31,10,0,32,0,99,48,51,46,57,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,226,147,10,215,10,0,32,0,99,48,52,46,57,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,194,253,214,4,10,0,32,0,99,48,53,46,49,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,144,116,83,63,10,0,32,0,99,48,54,46,49,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,164,198,105,255,10,0,32,0,99,48,55,46,49,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,117,186,142,94,10,0,32,0,99,48,56,46,57,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,221,13,130,240,10,0,32,0,99,48,57,46,49,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,195,135,15,8,10,0,32,0,99,49,48,46,49,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,98,106,124,119,10,0,32,0,99,49,49,46,49,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,161,165,12,51,10,0,32,0,99,49,50,46,49,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,97,142,236,193,10,0,32,0,99,49,51,46,49,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,224,167,34,78,10,0,32,0,99,49,52,46,49,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,50,98,189,189,10,0,32,0,99,49,53,46,49,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,104,215,99,241,10,0,32,0,99,49,54,46,49,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,196,23,80,94,10,0,32,0,116,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,18,5,137,36,11,0,0,8,116,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,13,72,16,90,11,0,0,8,116,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,220,244,74,69,11,0,0,8,116,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,169,246,30,14,11,0,0,8,116,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,188,81,235,18,12,0,0,8,116,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,188,81,235,18,12,0,0,8,105,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,71,164,210,170,13,0,0,8,105,99,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,44,140,95,13,0,0,8,105,99,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,113,205,21,189,13,0,0,8,105,99,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,99,117,35,47,13,0,0,8,105,99,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,15,44,179,149,13,0,0,8,105,99,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,63,3,182,43,13,0,0,8,48,49,48,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,45,180,166,105,1,0,16,1,48,49,48,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,100,82,163,121,2,0,32,0,48,49,48,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,19,81,186,139,3,0,32,0,48,49,48,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,50,100,246,203,3,0,32,0,48,49,48,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,252,110,248,228,3,0,32,0,48,49,48,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,116,70,190,247,3,0,32,0,48,49,48,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,160,109,7,232,3,0,32,0,48,49,48,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,103,197,149,196,3,0,32,0,48,49,48,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,120,160,227,139,4,0,16,1,48,49,48,45,118,49,49,46,118,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,34,77,34,144,5,0,64,0,48,49,48,45,118,49,50,46,118,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,52,24,207,160,5,0,64,0,48,49,48,45,118,49,51,46,118,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,132,188,56,174,5,0,64,0,48,49,48,45,118,49,52,46,118,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,210,155,137,112,5,0,64,0,48,49,48,45,118,50,49,46,118,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,178,76,111,88,6,0,64,0,57,48,51,95,101,48,53,46,54,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,32,98,85,139,1,0,16,1,57,48,51,95,101,48,52,46,52,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,39,121,156,191,1,0,16,1,57,48,51,95,101,48,57,46,54,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,77,85,119,42,1,0,16,1,57,48,51,95,101,48,56,46,52,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,193,48,164,192,1,0,16,1,57,48,51,95,100,48,55,46,49,48,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,231,220,14,252,2,0,16,1,57,48,51,95,100,48,54,46,56,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,254,246,206,178,2,0,16,1,57,48,51,95,101,49,51,46,49,48,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,128,251,181,79,2,0,16,1,57,48,51,95,101,49,50,46,56,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,151,48,62,136,2,0,16,1,57,48,51,95,100,48,51,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,90,133,94,69,3,0,16,1,57,48,51,95,101,49,52,46,100,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,213,187,190,221,4,0,32,0,57,48,51,95,101,49,49,46,49,48,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,248,250,65,92,6,0,32,0,57,48,51,95,101,49,48,46,56,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,212,118,117,65,6,0,32,0,99,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,74,124,2,157,1,0,16,1,99,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,211,70,152,243,1,0,16,1,99,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,168,73,161,175,1,0,16,1,99,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,30,70,245,186,1,0,16,1,99,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,161,130,178,107,1,0,16,1,99,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,245,64,33,250,1,0,16,1,99,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,14,30,201,134,1,0,16,1,99,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,78,19,40,61,1,0,16,1,99,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,190,23,70,28,2,0,32,0,99,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,239,47,247,70,2,0,32,0,99,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,153,193,158,186,2,0,32,0,99,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,85,150,192,65,2,0,32,0,56,50,115,49,50,51,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,189,80,198,47,3,0,32,0,56,50,115,49,50,54,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,228,168,179,62,3,0,32,0,56,50,115,49,50,54,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,134,204,169,4,0,64,0,56,50,115,49,50,54,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,50,52,57,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,24,97,56,201,1,0,16,1,50,52,57,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,114,179,158,220,2,0,32,0,50,52,57,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,238,184,31,4,3,0,32,0,50,52,57,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,244,205,243,116,3,0,32,0,50,52,57,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,71,138,50,128,4,0,16,1,50,52,57,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,39,143,124,222,5,0,64,0,50,52,57,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,25,1,228,200,5,0,64,0,53,48,48,51,45,112,49,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,57,254,133,17,1,0,16,1,53,48,48,51,45,112,50,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,247,250,113,234,1,0,16,1,53,48,48,51,45,115,49,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,253,207,76,23,2,0,32,0,53,48,48,51,45,99,49,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,99,197,144,220,3,0,32,0,53,48,48,51,45,99,50,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,49,211,8,123,3,0,32,0,53,48,48,51,45,99,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,113,255,74,172,3,0,32,0,53,48,48,51,45,99,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,102,93,239,175,3,0,32,0,53,48,48,51,45,99,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,80,174,193,199,3,0,32,0,53,48,48,51,45,99,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,249,151,49,97,3,0,32,0,53,48,48,51,45,99,55,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,179,114,45,173,3,0,32,0,53,48,48,51,45,99,56,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,181,193,63,140,3,0,32,0,53,48,48,51,45,109,49,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,71,196,124,163,4,0,16,1,50,54,50,45,118,49,45,48,56,45,101,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,207,158,212,131,5,0,64,0,53,48,48,51,45,118,50,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,73,132,73,43,5,0,64,0,50,54,50,45,118,51,45,48,56,45,101,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,190,141,227,42,5,0,64,0,50,54,50,45,118,52,45,48,56,45,101,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,217,77,236,38,5,0,64,0,53,48,48,51,45,112,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,193,2,118,187,1,0,16,1,53,48,48,51,45,112,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,43,194,193,173,1,0,16,1,53,48,48,51,45,115,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,171,154,162,91,2,0,32,0,53,48,48,51,45,99,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,103,75,245,104,3,0,32,0,53,48,48,51,45,99,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,213,73,136,47,3,0,32,0,53,48,48,51,45,99,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,113,255,74,172,3,0,32,0,53,48,48,51,45,99,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,102,93,239,175,3,0,32,0,53,48,48,51,45,99,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,80,174,193,199,3,0,32,0,53,48,48,51,45,99,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,249,151,49,97,3,0,32,0,53,48,48,51,45,99,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,15,254,221,100,3,0,32,0,53,48,48,51,45,99,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,57,20,122,145,3,0,32,0,53,48,48,51,45,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,75,39,140,26,4,0,16,1,50,54,50,45,118,49,45,48,56,45,101,48,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,207,158,212,131,5,0,64,0,50,54,50,45,118,50,45,48,56,45,101,48,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,67,24,63,0,5,0,64,0,50,54,50,45,118,51,45,48,56,45,101,48,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,190,141,227,42,5,0,64,0,50,54,50,45,118,52,45,48,56,45,101,48,46,118,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,217,77,236,38,5,0,64,0,100,120,48,51,45,51,46,97,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,252,140,221,2,1,0,0,0,100,120,48,49,46,97,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,12,181,15,87,1,0,0,0,100,120,48,50,46,97,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,144,88,98,88,1,0,0,0,100,120,48,52,45,49,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0])
.concat([145,38,67,41,2,0,0,0,100,120,48,53,46,97,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,37,207,50,235,3,0,0,0,100,120,48,48,46,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,133,249,30,240,4,0,0,0,100,120,49,52,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,21,121,240,128,5,0,0,0,100,120,49,51,46,98,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,231,2,44,211,5,0,0,0,100,120,49,50,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,107,183,120,172,5,0,0,0,100,120,48,54,46,97,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,140,32,251,182,6,0,0,0,100,120,48,55,46,97,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,23,24,62,238,6,0,0,0,100,120,48,56,46,97,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,254,0,89,112,6,0,0,0,100,120,48,57,46,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,29,87,146,49,6,0,0,0,100,120,49,48,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,50,122,247,62,6,0,0,0,100,120,49,49,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,184,213,243,156,6,0,0,0,105,100,56,55,53,49,104,46,109,99,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,7,0,0,16,109,112,45,48,48,51,118,101,114,48,49,46,117,48,49,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,107,110,245,164,0,0,16,1,109,112,45,48,48,51,118,101,114,48,49,46,117,49,48,54,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,33,73,138,38,0,0,32,0,109,112,45,48,48,51,118,101,114,48,49,46,117,49,48,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,110,122,231,121,0,0,32,0,109,112,45,48,48,51,118,101,114,48,49,46,117,49,48,54,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,62,137,97,118,0,0,32,0,109,112,45,48,48,51,118,101,114,48,49,46,117,49,49,56,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,69,183,174,195,0,0,64,0,109,112,45,48,48,51,118,101,114,48,49,46,117,49,49,56,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,151,36,49,217,0,0,64,0,99,114,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,218,196,236,225,1,0,16,1,99,114,102,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,96,57,25,181,1,0,16,1,99,114,103,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,36,159,75,150,1,0,16,1,99,114,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,14,56,210,223,1,0,16,1,99,114,49,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,152,113,97,199,2,0,32,0,99,114,51,46,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,103,105,91,193,2,0,32,0,99,114,50,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,184,92,188,213,2,0,32,0,99,114,52,46,53,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,175,28,93,211,2,0,32,0,55,52,115,50,56,56,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,70,68,52,255,3,0,32,0,50,115,49,52,48,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,39,185,239,99,3,0,32,0,56,50,115,49,50,54,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,134,204,169,4,0,64,0,56,50,115,49,50,54,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,99,114,53,46,55,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,29,213,84,73,1,0,16,1,99,114,54,46,55,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,153,66,235,39,1,0,16,1,99,114,55,46,55,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,142,16,151,210,1,0,16,1,99,114,56,46,55,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,175,14,196,188,1,0,16,1,99,114,49,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,152,113,97,199,2,0,32,0,99,114,51,46,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,103,105,91,193,2,0,32,0,99,114,50,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,184,92,188,213,2,0,32,0,99,114,52,46,53,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,175,28,93,211,2,0,32,0,55,52,115,50,56,56,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,70,68,52,255,3,0,32,0,50,115,49,52,48,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,39,185,239,99,3,0,32,0,56,50,115,49,50,54,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,134,204,169,4,0,64,0,56,50,115,49,50,54,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,183,79,227,33,1,0,16,1,119,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,37,115,223,165,1,0,16,1,119,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,109,102,157,252,1,0,16,1,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,15,144,10,231,2,0,16,1,104,56,57,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,195,147,173,54,3,0,32,0,119,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,13,249,93,177,4,0,32,0,119,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,147,107,50,40,4,0,32,0,119,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,209,106,5,212,4,0,32,0,104,56,57,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,40,1,35,227,5,0,32,0,104,56,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,51,2,246,255,5,0,32,0,104,56,57,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,193,0,51,213,6,0,64,0,104,56,57,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,99,59,81,50,6,0,64,0,98,109,95,100,45,104,48,46,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,33,88,138,162,1,0,16,1,98,109,95,100,45,108,48,46,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,160,241,4,165,1,0,16,1,98,109,95,100,45,104,49,46,51,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,71,108,218,24,1,0,16,1,98,109,95,100,45,108,49,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,66,27,92,166,1,0,16,1,98,109,95,100,45,115,104,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,91,7,124,159,2,0,16,1,98,109,95,100,45,115,108,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,137,124,168,31,2,0,16,1,98,109,95,99,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,184,102,201,44,3,0,32,0,98,109,95,99,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,62,119,223,70,3,0,32,0,98,109,95,99,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,189,103,184,5,3,0,32,0,98,109,95,99,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,164,39,34,10,3,0,32,0,98,109,95,48,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,243,201,159,51,4,0,32,0,98,109,95,48,49,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,125,55,20,106,4,0,32,0,98,109,95,48,50,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,152,33,83,49,4,0,32,0,98,109,95,48,51,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,211,65,160,209,4,0,32,0,98,109,95,100,97,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,152,87,206,98,5,0,64,0,112,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,173,186,203,11,1,0,16,1,112,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,4,210,71,9,1,0,16,1,115,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,76,34,26,214,2,0,16,1,115,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,34,205,158,159,3,0,64,0,114,111,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,187,66,80,144,4,0,32,0,114,111,109,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,233,129,67,188,4,0,32,0,114,111,109,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,206,31,110,204,5,0,32,0,114,111,109,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,148,212,145,154,5,0,32,0,114,111,109,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,197,77,163,83,5,0,32,0,114,111,109,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,130,48,99,156,5,0,32,0,112,49,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,171,160,15,44,1,0,16,1,112,53,46,54,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,241,162,236,175,1,0,16,1,112,50,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,83,120,23,125,1,0,16,1,112,54,46,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,76,145,232,211,1,0,16,1,112,51,46,54,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,76,164,69,144,1,0,16,1,112,55,46,54,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,197,68,243,147,1,0,16,1,112,52,46,54,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,119,160,212,190,1,0,16,1,112,56,46,54,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,30,228,11,128,1,0,16,1,112,57,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,196,24,2,161,2,0,32,0,112,49,49,46,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,157,184,145,53,2,0,32,0,112,49,48,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,58,50,57,158,2,0,32,0,112,49,50,46,53,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,150,144,29,27,2,0,32,0,56,50,115,49,50,51,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,189,80,198,47,3,0,32,0,56,50,115,49,50,54,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,228,168,179,62,3,0,32,0,56,50,115,49,50,54,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,134,204,169,4,0,64,0,56,50,115,49,50,54,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,56,50,49,112,48,50,46,102,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,225,162,63,243,1,0,16,1,56,50,49,108,48,49,46,104,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,158,168,172,15,2,0,16,1,56,50,49,107,48,54,46,107,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,36,219,234,161,3,0,32,0,56,50,49,107,48,55,46,107,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,250,25,0,6,3,0,32,0,56,50,49,107,48,52,46,107,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,27,41,224,0,4,0,32,0,56,50,49,107,48,53,46,107,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,93,160,158,224,4,0,32,0,56,50,49,107,48,51,46,101,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,90,80,248,254,5,0,64,0,56,50,49,97,48,56,46,105,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,88,165,125,6,0,0,8,56,50,49,114,48,50,46,102,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,35,217,205,78,1,0,16,1,56,50,49,108,48,49,46,104,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,158,168,172,15,2,0,16,1,56,50,49,107,48,54,46,107,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,36,219,234,161,3,0,32,0,56,50,49,107,48,55,46,107,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,250,25,0,6,3,0,32,0,56,50,49,107,48,52,46,107,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,27,41,224,0,4,0,32,0,56,50,49,107,48,53,46,107,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,93,160,158,224,4,0,32,0,56,50,49,107,48,51,46,101,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,90,80,248,254,5,0,64,0,56,50,49,97,48,56,46,105,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,88,165,125,6,0,0,8,56,50,49,108,48,50,46,102,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,166,125,142,88,1,0,16,1,56,50,49,108,48,49,46,104,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,158,168,172,15,2,0,16,1,56,50,49,107,48,54,46,107,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,36,219,234,161,3,0,32,0,56,50,49,107,48,55,46,107,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,250,25,0,6,3,0,32,0,56,50,49,107,48,52,46,107,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,27,41,224,0,4,0,32,0,56,50,49,107,48,53,46,107,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,93,160,158,224,4,0,32,0,56,50,49,107,48,51,46,101,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,90,80,248,254,5,0,64,0,56,50,49,97,48,56,46,105,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,88,165,125,6,0,0,8,114,111,109,46,117,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,117,62,51,191,1,0,16,1,114,111,109,46,117,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,71,157,94,80,1,0,16,1,114,111,109,46,117,50,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,142,97,129,113,3,0,32,0,114,111,109,46,117,50,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,242,181,5,121,3,0,32,0,114,111,109,46,117,50,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,52,14,33,239,3,0,32,0,114,111,109,46,117,50,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,25,68,27,69,3,0,32,0,114,111,109,46,117,54,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,49,104,140,236,4,0,32,0,114,111,109,46,117,54,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,46,49,36,33,4,0,32,0,114,111,109,46,117,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,49,130,68,88,5,0,32,0,114,111,109,46,117,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,91,115,247,198,5,0,32,0,114,111,109,46,117,56,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,187,208,149,123,6,0,64,0,56,55,56,109,48,50,46,107,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,82,159,28,156,1,0,16,1,56,55,56,106,48,51,46,107,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,101,160,67,57,1,0,16,1,56,55,56,104,48,49,46,102,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,170,175,254,150,2,0,16,1,56,55,56,99,48,55,46,104,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,44,145,237,238,3,0,32,0,56,55,56,99,48,56,46,107,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,109,98,20,77,3,0,32,0,56,55,56,99,48,53,46,104,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,165,174,244,1,4,0,32,0,56,55,56,99,48,54,46,107,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,175,170,250,237,4,0,32,0,56,55,56,99,48,52,46,100,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,28,45,152,158,5,0,64,0,56,55,56,97,48,57,46,102,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,27,154,208,226,6,0,0,8,99,99,45,100,45,104,48,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,1,139,149,56,1,0,16,1,99,99,45,100,45,108,48,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,112,127,248,239,1,0,16,1,99,99,45,100,45,115,112,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,96,206,58,62,6,0,16,1,99,99,45,99,45,48,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,170,222,153,157,2,0,32,0,99,99,45,99,45,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,237,131,176,126,2,0,32,0,99,99,45,99,45,50,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,158,72,33,148,2,0,32,0,99,99,45,99,45,51,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,53,199,14,146,2,0,32,0,99,99,45,100,45,103,48,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,114,215,243,231,3,0,32,0,99,99,45,100,45,103,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,76,78,139,65,3,0,32,0,99,99,45,100,45,103,50,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,235,88,181,164,3,0,32,0,99,99,45,100,45,103,51,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,102,49,74,246,3,0,32,0,99,99,45,99,45,118,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,222,186,71,98,5,0,64,0,50,48,48,48,45,112,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,141,136,201,198,1,0,16,1,50,48,48,48,45,115,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,168,40,154,8,2,0,32,0,50,48,48,48,45,99,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,171,156,87,154,3,0,32,0,50,48,48,48,45,99,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,67,64,209,145,3,0,32,0,110,110,112,45,109,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,100,222,105,118,4,0,16,1,110,110,112,45,118,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,73,248,75,80,5,0,64,0,101,108,49,49,45,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,5,139,10,175,1,0,0,0,101,108,49,50,45,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,56,239,68,122,1,0,0,0,101,108,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,203,90,80,4,1,0,0,0,101,108,49,48,45,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,24,209,250,237,2,0,0,0,101,108,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,119,97,36,71,3,0,0,0,101,108,48,48,45,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,168,162,45,18,4,0,0,0,101,108,48,49,45,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,91,112,191,39,4,0,0,0,101,108,48,50,45,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,230,237,111,200,4,0,0,0,101,108,48,51,45,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,91,133,138,29,4,0,0,0,101,108,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,76,207,13,203,5,0,0,0,101,108,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,231,91,174,31,5,0,0,0,101,108,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,51,96,79,28,6,0,0,0,101,108,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,148,167,75,210,6,0,0,0,101,108,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,206,73,10,216,6,0,0,0,101,108,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,195,31,119,109,6,0,0,0,101,104,45,49,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,225,55,134,134,1,0,0,0,101,104,45,49,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,131,138,135,124,1,0,0,0,101,108,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,203,90,80,4,1,0,0,0,101,104,45,49,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,137,94,202,98,2,0,0,0,101,108,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,119,97,36,71,3,0,0,0,101,104,45,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,151,103,107,217,4,0,0,0,101,104,45,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,2,156,239,63,4,0,0,0,101,104,45,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,52,108,174,191,4,0,0,0,101,104,45,48,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,248,144,103,213,4,0,0,0,101,108,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,76,207,13,203,5,0,0,0,101,108,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,231,91,174,31,5,0,0,0,101,108,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,51,96,79,28,6,0,0,0,101,108,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,148,167,75,210,6,0,0,0,101,108,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,206,73,10,216,6,0,0,0,101,108,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,195,31,119,109,6,0,0,0,106,111,101,32,109,97,99,32,51,46,54,56,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,128,29,147,220,1,0,16,1,106,111,101,32,109,97,99,32,52,46,54,56,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,224,223,232,1,0,16,1,106,111,101,32,109,97,99,32,53,46,122,56,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,215,185,145,215,2,0,16,1,106,111,101,32,109,97,99,32,49,46,103,102,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,49,89,234,23,3,0,32,0,106,111,101,32,109,97,99,32,50,46,103,102,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,123,49,149,204,3,0,32,0,106,111,101,32,109,97,99,32,54,46,115,97,109,112,108,101,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,131,173,236,219,4,0,64,0,98,52,52,45,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,8,224,105,140,1,0,16,1,98,52,52,45,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,148,64,72,50,1,0,16,1,98,52,52,45,49,50,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,92,253,9,159,2,0,16,1,98,52,52,45,56,55,52,50,46,109,99,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,159,63,255,125,3,0,16,8,98,52,52,45,48,49,46,97,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,213,179,231,170,4,0,32,0,98,52,52,45,48,50,46,97,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,104,149,11,127,4,0,32,0,98,52,52,45,48,51,46,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,185,163,84,90,4,0,32,0,98,52,52,45,48,52,46,97,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,75,84,95,60,4,0,32,0,98,52,52,45,48,53,46,97,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,20,227,183,209,4,0,32,0,98,52,52,45,48,54,46,97,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,168,120,153,38,4,0,32,0,98,52,52,45,48,55,46,97,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,126,115,14,62,4,0,32,0,98,52,52,45,48,56,46,97,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,252,232,177,108,4,0,32,0,98,52,52,45,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,8,224,105,140,1,0,16,1,98,52,52,45,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,148,64,72,50,1,0,16,1,98,52,52,45,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,230,172,0,6,2,0,16,1,98,52,52,45,56,55,52,50,46,109,99,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,159,63,255,125,3,0,16,8,98,52,52,45,48,49,46,97,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,213,179,231,170,4,0,32,0,98,52,52,45,48,50,46,97,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,104,149,11,127,4,0,32,0,98,52,52,45,48,51,46,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,185,163,84,90,4,0,32,0,98,52,52,45,48,52,46,97,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,75,84,95,60,4,0,32,0,98,52,52,45,48,53,46,97,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,20,227,183,209,4,0,32,0,98,52,52,45,48,54,46,97,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,168,120,153,38,4,0,32,0,98,52,52,45,48,55,46,97,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,126,115,14,62,4,0,32,0,98,52,52,45,48,56,46,97,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,252,232,177,108,4,0,32,0,98,52,52,45,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,8,224,105,140,1,0,16,1,98,52,52,45,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,148,64,72,50,1,0,16,1,98,52,52,45,49,50,119,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,202,205,14,232,2,0,16,1,98,52,52,45,56,55,52,50,46,109,99,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,159,63,255,125,3,0,16,8,98,52,52,45,48,49,46,97,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,213,179,231,170,4,0,32,0,98,52,52,45,48,50,46,97,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,104,149,11,127,4,0,32,0,98,52,52,45,48,51,46,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,185,163,84,90,4,0,32,0,98,52,52,45,48,52,46,97,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,75,84,95,60,4,0,32,0,98,52,52,45,48,53,46,97,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,20,227,183,209,4,0,32,0,98,52,52,45,48,54,46,97,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,168,120,153,38,4,0,32,0,98,52,52,45,48,55,46,97,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,126,115,14,62,4,0,32,0,98,52,52,45,48,56,46,97,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,252,232,177,108,4,0,32,0,103,118,95,48,48,45,46,102,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,93,234,167,46,1,0,16,1,103,118,95,48,49,45,46,102,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,199,3,171,188,1,0,16,1,103,118,95,48,50,45,46,102,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,132,29,21,149,2,0,16,1,109,97,107,45,48,50,46,104,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,80,44,91,116,3,0,32,0,109,97,107,45,48,48,46,97,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,27,204,232,24,4,0,32,0,109,97,107,45,48,49,46,97,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,189,142,216,4,0,32,0,103,118,95,48,51,45,46,106,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,146,175,143,148,5,0,64,0,101,101,48,56,45,97,46,106,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,123,179,47,47,1,0,16,1,101,101,49,49,45,97,46,106,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,95,208,6,243,1,0,16,1,101,101,48,55,45,97,46,106,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,86,237,105,156,1,0,16,1,101,101,49,48,45,97,46,106,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,75,254,197,213,1,0,16,1,101,101,48,54,45,101,46,106,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,219,175,172,85,1,0,16,1,101,101,48,57,45,101,46,106,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,44,37,62,48,1,0,16,1,101,101,48,53,45,46,102,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,180,54,137,106,2,0,16,1,101,101,48,48,45,101,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,107,92,110,224,3,0,32,0,101,101,48,52,45,46,100,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,149,79,136,150,4,0,32,0,101,101,48,49,45,46,99,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,87,64,181,244,4,0,32,0,101,101,48,51,45,46,100,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,130,225,120,113,4,0,32,0,101,101,48,50,45,46,99,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,174,69,124,157,4,0,32,0,101,101,49,50,45,46,102,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,165,83,28,155,5,0,32,0,101,101,49,51,45,46,102,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,62,174,184,114,5,0,32,0,101,101,49,52,45,46,102,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,222,187,244,216,5,0,32,0,101,101,49,53,45,46,102,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,139,230,227,129,5,0,32,0,101,101,50,49,46,107,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,134,101,219,177,6,0,32,0,101,101,50,48,46,108,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,50,97,129,65,6,0,32,0,99,104,101,108,110,111,118,117,95,105,56,55,53,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,24,97,45,106,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,82,203,120,25,1,0,16,1,97,45,106,50,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,153,61,237,224,1,0,16,1,97,45,106,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,134,84,70,81,1,0,16,1,97,45,106,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,51,218,157,208,1,0,16,1,97,45,106,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,7,21,153,205,1,0,16,1,97,45,106,49,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,28,96,127,151,1,0,16,1,101,101,48,53,45,46,102,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,180,54,137,106,2,0,16,1,97,45,99,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,109,44,191,26,3,0,32,0,101,101,48,52,45,46,100,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,149,79,136,150,4,0,32,0,101,101,48,49,45,46,99,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,87,64,181,244,4,0,32,0,101,101,48,51,45,46,100,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,130,225,120,113,4,0,32,0,101,101,48,50,45,46,99,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,174,69,124,157,4,0,32,0,101,101,49,50,45,46,102,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,165,83,28,155,5,0,32,0,101,101,49,51,45,46,102,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,62,174,184,114,5,0,32,0,101,101,49,52,45,46,102,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,222,187,244,216,5,0,32,0,101,101,49,53,45,46,102,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,139,230,227,129,5,0,32,0,97,45,107,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,216,73,156,48,6,0,32,0,101,101,50,48,46,108,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,50,97,129,65,6,0,32,0,99,104,101,108,110,111,118,106,95,105,56,55,53,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,24,110,100,48,48,45,49,46,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,35,75,143,241,1,0,16,1,109,98,114,45,48,48,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,240,199,242,236,2,0,32,0,109,98,114,45,48,49,46,49,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,21,2,201,70,3,0,32,0,109,98,114,45,48,51,46,49,52,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,138,166,72,196,3,0,32,0,110,100,48,49,45,48,46,49,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,10,16,90,99,4,0,64,0,109,98,114,45,48,50,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,51,211,103,79,5,0,64,0,97,111,52,95,48,49,46,105,99,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,200,225,111,56,1,0,16,1,97,111,52,95,48,50,46,105,99,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,167,166,98,85,1,0,16,1,97,111,52,95,48,51,46,105,99,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,156,10,47,62,1,0,16,1,97,111,52,95,48,52,46,105,99,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,212,199,9,82,1,0,16,1,97,111,52,95,48,53,46,105,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,36,224,32,135,1,0,16,1,97,111,52,95,48,54,46,105,99,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,2,0,0,16,97,111,52,95,48,56,46,105,99,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,33,160,117,85,3,0,32,0,97,111,52,95,48,55,46,105,99,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,24,124,104,174,3,0,32,0,97,111,52,95,48,57,46,105,99,57,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,58,114,122,117,4,0,32,0,97,111,52,95,49,48,46,105,99,57,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,8,214,63,62,4,0,32,0,97,111,52,45,49,49,46,105,99,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,95,232,240,155,5,0,32,0,97,111,52,45,49,50,46,105,99,57,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,252,232,76,149,5,0,32,0,101,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,239,64,131,138,1,0,16,1,109,99,99,45,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,236,3,107,100,2,0,32,0,117,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,33,151,101,146,3,0,32,0,117,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,50,235,4,227,3,0,32,0,117,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,234,1,111,27,3,0,32,0,117,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,242,86,26,83,3,0,32,0,109,99,99,45,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,222,106,238,134,4,0,64,0,109,99,99,45,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,160,187,46,218,5,0,64,0,101,101,112,114,111,109,45,99,104,97,105,110,114,101,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,191,63,218,182,6,0,16,1,52,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,44,25,211,225,1,0,16,1,49,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,116,73,248,62,1,0,16,1,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,146,201,5,121,1,0,16,1,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,30,108,190,71,1,0,16,1,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,214,16,177,31,1,0,16,1,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,91,193,36,0,1,0,16,1,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,190,117,1,254,2,0,16,1,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,242,24,223,93,2,0,16,1,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,102,82,71,127,3,0,32,0,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,6,57,221,203,4,0,32,0,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,192,19,166,178,4,0,32,0,49,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,215,178,75,226,5,0,32,0,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,84,69,131,86,5,0,32,0,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,190,56,248,75,6,0,32,0,49,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,197,101,162,33,6,0,32,0,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,153,201,110,107,6,0,32,0,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,173,164,38,244,6,0,32,0,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,15,38,13,116,7,0,32,8,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,20,234,34,121,1,0,16,1,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,103,237,199,42,1,0,16,1,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,146,201,5,121,1,0,16,1,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,30,108,190,71,1,0,16,1,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,214,16,177,31,1,0,16,1,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,91,193,36,0,1,0,16,1,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,190,117,1,254,2,0,16,1,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,242,24,223,93,2,0,16,1,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,102,82,71,127,3,0,32,0,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,6,57,221,203,4,0,32,0,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,192,19,166,178,4,0,32,0,49,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,215,178,75,226,5,0,32,0,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,84,69,131,86,5,0,32,0,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,190,56,248,75,6,0,32,0,49,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,197,101,162,33,6,0,32,0,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,153,201,110,107,6,0,32,0,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,173,164,38,244,6,0,32,0,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,15,38,13,116,7,0,32,8,102,117,48,49,45,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,248,224,3,2,1,0,16,1,102,117,48,48,45,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,109,98,88,156,1,0,16,1,102,117,48,51,45,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,86,105,244,222,1,0,16,1,102,117,48,50,45,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,56,51,156,100,1,0,16,1,102,117,49,49,45,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,16,15,242,101,2,0,16,1,109,97,98,45,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,189,170,14,102,3,0,32,0,102,117,48,53,45,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,18,212,52,129,3,0,32,0,102,117,48,54,45,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,69,74,145,47,3,0,32,0,109,97,98,45,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,25,214,128,16,4,0,32,0,109,97,98,45,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,29,35,183,88,5,0,32,0,109,97,98,45,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,157,59,5,118,5,0,32,0,102,117,48,55,45,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,179,11,141,202,5,0,32,0,102,117,48,56,45,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,200,197,175,198,5,0,32,0,102,117,48,57,45,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,202,9,104,82,5,0,32,0,102,117,49,48,45,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,14,213,230,107,5,0,32,0,102,117,49,50,45,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,242,101,29,45,6,0,64,0,102,117,49,51,45,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,34,86,82,184,7,0,64,0,109,98,55,49,49,52,104,46,49,56,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,15,183,69,54,8,0,0,8,102,114,48,49,45,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,79,1,60,175,1,0,16,1,102,114,48,48,45,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,82,173,102,246,1,0,16,1,102,114,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,24,97,192,2,1,0,16,1,102,114,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,50,67,195,182,1,0,16,1,102,117,49,49,45,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,16,15,242,101,2,0,16,1,109,97,98,45,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,189,170,14,102,3,0,32,0,102,117,48,53,45,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,18,212,52,129,3,0,32,0,102,117,48,54,45,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,69,74,145,47,3,0,32,0,109,97,98,45,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,25,214,128,16,4,0,32,0,109,97,98,45,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,29,35,183,88,5,0,32,0,109,97,98,45,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,157,59,5,118,5,0,32,0,102,114,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,24,83,200,82,5,0,32,0,102,114,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,172,251,37,234,5,0,32,0,102,114,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,36,52,54,248,5,0,32,0,102,114,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,96,87,29,36,5,0,32,0,102,117,49,50,45,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,242,101,29,45,6,0,64,0,102,117,49,51,45,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,34,86,82,184,7,0,64,0,109,98,55,49,49,52,104,46,49,56,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,15,183,69,54,8,0,0,8,49,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,129,199,12,158,1,0,16,1,50,46,100,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,80,185,229,92,1,0,16,1,51,46,101,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,141,33,40,188,1,0,16,1,52,46,104,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,245,233,50,43,1,0,16,1,53,46,106,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,62,21,23,209,1,0,16,1,54,46,107,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,203,102,211,199,1,0,16,1,57,46,102,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,133,119,53,99,2,0,32,0,48,46,104,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,51,17,173,82,2,0,32,0,56,46,108,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,45,191,34,176,3,0,32,0,49,48,45,50,46,107,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,213,77,162,66,4,0,32,0,49,48,45,49,46,102,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,222,184,54,215,4,0,32,0,49,48,45,51,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,80,58,250,39,4,0,0,8,110,49,45,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,199,120,136,198,1,0,16,1,110,50,45,54,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,165,81,57,255,1,0,16,1,110,51,45,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,157,7,41,35,1,0,16,1,110,52,45,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,203,126,197,252,1,0,16,1,110,53,45,54,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,157,108,132,82,1,0,16,1,110,54,45,54,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,221,144,232,89,1,0,16,1,122,49,45,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,224,121,87,18,2,0,32,0,122,51,45,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,192,102,248,120,2,0,32,0,122,50,45,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,157,201,210,251,2,0,32,0,122,52,45,53,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,4,201,52,135,2,0,32,0,99,111,108,111,114,112,114,111,109,95,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,126,174,248,8,3,0,32,0,99,111,108,111,114,112,114,111,109,95,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,220,21,154,53,3,0,32,0,56,50,115,49,50,54,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,134,204,169,4,0,64,0,56,50,115,49,50,54,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,15,0,0,0,255,255,255,0,0,0,0,0,16,0,0,0,255,255,255,0,0,0,0,0,17,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,224,222,6,0,15,0,0,0,1,3,3,0,152,186,3,0,15,0,0,0,1,3,1,0,216,183,3,0,15,0,0,0,1,3,2,0,80,181,3,0,15,0,0,0,1,3,0,0,120,7,5,0,0,0,0,0,254,0,2,0,200,30,2,0,15,0,0,0,1,4,4,0,120,97,1,0,15,0,0,0,1,4,0,0,96,19,1,0,0,0,0,0,254,0,4,0,128,129,4,0,15,0,0,0,1,24,0,0,8,49,4,0,15,0,0,0,1,24,8,0,152,21,4,0,15,0,0,0,1,24,16,0,72,246,3,0,15,0,0,0,1,24,24,0,72,0,3,0,115,97,48,48,45,48,46,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,87,50,107,236,1,0,16,1,109,99,102,45,48,48,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,220,18,119,36,2,0,32,0,109,99,102,45,48,50,46,49,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,51,27,37,33,3,0,32,0,109,99,102,45,48,52,46,49,52,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,119,85,165,79,3,0,32,0,109,99,102,45,48,49,46,49,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,37,30,136,131,3,0,32,0,109,99,102,45,48,51,46,49,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,29,213,241,250,3,0,32,0,115,97,48,49,45,48,46,49,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,142,54,168,206,4,0,64,0,109,99,102,45,48,53,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,118,211,7,240,5,0,64,0,101,101,112,114,111,109,45,99,97,110,100,97,110,99,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,107,143,10,10,6,0,16,1,117,104,48,48,50,48,48,49,46,117,52,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,237,231,146,235,1,0,16,1,117,104,48,48,50,48,48,52,46,117,52,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,30,211,14,90,1,0,16,1,117,104,48,48,49,48,48,51,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,159,208,48,13,1,0,16,1,117,104,48,48,49,48,48,50,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,249,195,236,122,1,0,16,1,117,104,48,48,49,48,48,53,46,117,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,133,192,84,74,2,0,16,1,117,104,48,48,49,48,48,54,46,117,120,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,145,47,245,255,11,0,32,0,117,104,48,48,49,48,48,55,46,117,120,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,113,159,193,182,11,0,32,0,117,104,48,48,49,48,48,56,46,117,120,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,239,7,174,122,11,0,32,0,117,104,48,48,49,48,48,57,46,117,120,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,197,162,93,248,11,0,32,0,117,104,48,48,49,48,49,48,46,117,51,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,122,87,134,249,4,0,32,0,117,104,48,48,49,48,49,49,46,117,53,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,0,98,8,4,0,32,0,117,104,48,48,49,48,49,51,46,117,54,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,13,236,9,6,0,64,0,117,104,48,48,49,48,49,50,46,117,52,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,71,101,153,187,6,0,64,0,98,119,99,95,117,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,104,168,238,226,1,0,16,1,98,119,99,95,117,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,30,87,53,169,1,0,16,1,98,119,99,95,53,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,30,192,52,227,2,0,32,0,97,99,97,95,55,102,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,68,183,59,19,3,0,32,0,97,99,97,95,52,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,143,32,41,142,3,0,32,0,56,50,115,49,50,54,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,134,204,169,4,0,64,0,56,50,115,49,50,54,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,15,0,0,0,255,255,127,0,0,0,0,0,16,0,0,0,255,255,255,0,0,0,0,0,17,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,15,0,0,0,1,128,0,0,120,97,1,0,15,0,0,0,1,128,128,0,96,19,1,0,0,0,0,0,254,0,16,0,24,153,4,0,16,0,0,0,1,30,30,0,8,49,4,0,16,0,0,0,1,30,28,0,152,21,4,0,16,0,0,0,1,30,26,0,72,246,3,0,16,0,0,0,1,30,24,0,72,0,3,0,16,0,0,0,1,30,22,0,64,47,7,0,16,0,0,0,1,30,20,0,232,99,5,0,16,0,0,0,1,30,18,0,80,62,6,0,16,0,0,0,1,30,16,0,208,7,8,0,16,0,0,0,1,30,14,0,168,148,4,0,16,0,0,0,1,30,12,0,176,2,8,0,16,0,0,0,1,30,10,0,160,142,4,0,16,0,0,0,1,30,7,0,216,138,4,0,16,0,0,0,1,30,6,0,216,202,4,0,16,0,0,0,1,30,4,0,240,28,4,0,16,0,0,0,1,30,2,0,216,127,4,0,16,0,0,0,1,30,0,0,80,0,4,0,0,0,0,0,254,0,2,0,168,234,7,0,16,0,0,0,1,32,32,0,96,135,7,0,16,0,0,0,1,32,0,0,152,182,7,0,48,49,56,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,219,200,146,64,1,0,16,1,48,49,56,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,13,234,153,103,2,0,32,0,48,49,56,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,155,94,162,37,3,0,32,0,48,49,56,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,118,136,55,212,3,0,32,0,48,49,56,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,218,96,43,134,3,0,32,0,48,49,56,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,247,175,224,226,3,0,32,0,48,49,56,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,226,158,147,12,4,0,16,1,48,49,56,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,252,159,140,80,5,0,64,0,48,49,56,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,119,242,78,133,5,0,64,0,97,118,95,48,52,97,46,49,48,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,20,198,31,54,1,0,16,1,97,118,95,48,54,97,46,49,51,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,44,113,26,73,1,0,16,1,97,118,95,48,53,46,49,50,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,66,75,33,154,1,0,16,1,48,50,46,49,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,23,46,122,16,2,0,16,1,48,49,46,54,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,88,210,229,193,3,0,16,1,48,51,46,56,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,62,136,181,239,4,0,32,0,49,51,46,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,5,243,95,155,5,0,32,0,48,57,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,85,51,50,8,5,0,32,0,49,50,46,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,186,97,82,109,5,0,32,0,48,56,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,84,159,61,161,5,0,32,0,49,49,46,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,139,29,145,162,5,0,32,0,48,55,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,50,141,231,205,5,0,32,0,49,52,46,56,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,113,38,172,68,5,0,32,0,49,48,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,203,23,167,177,5,0,32,0,49,56,46,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,23,106,135,60,6,0,32,0,49,54,46,51,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,172,243,31,75,6,0,32,0,49,55,46,53,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,239,67,181,78,6,0,32,0,49,53,46,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,127,222,65,128,6,0,32,0,50,50,46,55,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,34,139,170,189,6,0,32,0,50,48,46,51,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,89,48,110,86,6,0,32,0,50,49,46,53,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,170,89,16,48,6,0,32,0,49,57,46,50,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,236,133,4,160,6,0,32,0,97,118,95,50,53,46,49,53,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,167,5,165,136,7,0,32,0,97,118,95,50,52,46,49,51,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,200,99,68,31,7,0,32,0,50,51,46,57,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,246,62,169,192,8,0,32,0,116,98,98,95,50,98,112,114,46,55,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,152,204,107,217,0,0,0,8,116,98,98,95,49,98,112,114,46,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,157,250,82,80,0,0,0,8,114,111,109,49,48,46,49,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,215,96,249,135,1,0,16,1,114,111,109,49,49,46,49,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,26,4,134,179,1,0,16,1,114,111,109,48,49,46,57,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,142,242,140,93,2,0,16,1,114,111,109,48,51,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,136,85,193,244,3,0,32,0,114,111,109,48,54,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,245,171,26,172,4,0,32,0,114,111,109,48,55,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,105,247,175,105,4,0,32,0,114,111,109,49,51,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,38,114,91,58,4,0,32,0,114,111,109,48,52,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,84,208,172,70,4,0,32,0,114,111,109,48,53,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,161,182,222,55,4,0,32,0,114,111,109,49,50,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,221,89,220,31,4,0,32,0,114,111,109,48,56,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,130,253,157,81,5,0,32,0,114,111,109,48,57,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,198,181,252,4,5,0,32,0,114,111,109,48,50,46,57,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,229,134,154,133,6,0,64,0,52,45,117,52,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,180,40,122,138,0,0,16,1,53,45,117,51,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,250,97,53,147,0,0,16,1,117,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,195,137,45,40,0,0,32,0,117,50,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,209,211,233,187,0,0,32,0,117,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,124,176,209,212,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,117,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,237,65,213,48,0,0,32,0,117,51,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,241,119,133,76,0,0,32,0,51,45,117,55,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,171,31,65,34,0,0,16,1,117,54,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,159,4,51,15,0,0,64,0,117,53,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,130,54,215,81,0,0,64,0,116,105,98,112,97,108,49,54,108,56,46,117,54,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,0,0,0,16,116,105,98,112,97,108,49,54,108,56,46,117,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,0,0,0,16,27,0,0,0,255,255,0,0,0,0,0,0,28,0,0,0,255,255,2,0,0,0,0,0,29,0,0,0,255,255,15,0,0,0,0,0,30,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,120,109,4,0,27,0,0,0,130,1,0,0,176,111,1,0,27,0,0,0,0,255,255,0,0,0,0,0,27,0,0,0,130,1,1,0,232,78,1,0,27,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,254,0,9,0,184,40,2,0,27,0,0,0,1,14,0,0,240,255,3,0,27,0,0,0,1,14,2,0,168,222,3,0,27,0,0,0,1,14,4,0,120,192,3,0,27,0,0,0,1,14,8,0,32,167,3,0,27,0,0,0,1,14,6,0,56,141,3,0,27,0,0,0,1,14,10,0,248,117,3,0,27,0,0,0,1,14,12,0,216,94,3,0,27,0,0,0,130,14,14,0,32,80,3,0,27,0,0,0,0,255,255,0,0,0,0,0,27,0,0,0,1,255,255,0,40,182,1,0,0,0,0,0,254,0,9,0,184,164,8,0,27,0,0,0,130,112,0,0,240,255,3,0,27,0,0,0,0,255,255,0,0,0,0,0,27,0,0,0,130,112,16,0,168,222,3,0,27,0,0,0,0,255,255,0,0,0,0,0,27,0,0,0,130,112,32,0,120,192,3,0,27,0,0,0,0,255,255,0,0,0,0,0,27,0,0,0,130,112,64,0,32,167,3,0,27,0,0,0,0,255,255,0,0,0,0,0,27,0,0,0,130,112,48,0,56,141,3,0,27,0,0,0,0,255,255,0,0,0,0,0,27,0,0,0,130,112,80,0,248,117,3,0,27,0,0,0,0,255,255,0,0,0,0,0,27,0,0,0,130,112,96,0,216,94,3,0,27,0,0,0,0,255,255,0,0,0,0,0,27,0,0,0,130,112,112,0,32,80,3,0,27,0,0,0,0,255,255,0,0,0,0,0,27,0,0,0,130,255,255,0,40,182,1,0,27,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,160,176,7,0,27,0,0,0,130,128,0,0,168,84,8,0,27,0,0,0,0,255,255,0,0,0,0,0,27,0,0,0,130,128,128,0,232,239,2,0,27,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,0,0,0,0,28,0,0,0,1,1,0,0,200,211,8,0,28,0,0,0,1,1,1,0,216,147,8,0,0,0,0,0,254,0,2,0,80,105,6,0,28,0,0,0,1,2,0,0,168,165,2,0,28,0,0,0,1,2,2,0,96,151,2,0,0,0,0,0,254,0,4,0,72,202,5,0,28,0,0,0,1,12,0,0,248,38,7,0,28,0,0,0,1,12,4,0,80,246,3,0,28,0,0,0,1,12,8,0,112,212,3,0,28,0,0,0,1,12,12,0,248,160,5,0,0,0,0,0,254,0,2,0,176,51,1,0,28,0,0,0,1,64,0,0,96,135,7,0,28,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,208,87,7,0,28,0,0,0,1,128,0,0,96,135,7,0,28,0,0,0,1,128,128,0,152,182,7,0,0,0,0,0,254,0,6,0,48,45,3,0,29,0,0,0,1,255,0,0,176,20,3,0,29,0,0,0,1,255,1,0,248,43,1,0,29,0,0,0,1,255,3,0,56,50,1,0,29,0,0,0,1,255,5,0,192,20,3,0,29,0,0,0,1,255,9,0,80,65,1,0,29,0,0,0,1,255,15,0,224,32,1,0,0,0,0,0,254,0,2,0,0,35,1,0,30,0,0,0,130,128,0,0,96,135,7,0,28,0,0,0,0,64,0,0,0,0,0,0,30,0,0,0,130,128,128,0,152,182,7,0,28,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,5,16,135,50,1,0,16,1,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,182,13,224,172,1,0,16,1,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,77,64,238,37,1,0,16,1,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,20,16,19,26,1,0,16,1,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,188,233,122,223,2,0,16,1,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,202,61,39,43,3,0,16,1,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,123,184,115,107,4,0,16,1,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,212,91,36,165,5,0,32,0,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,194,101,183,253,5,0,32,0,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,127,39,130,14,5,0,32,0,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,75,232,44,212,5,0,32,0,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,54,33,205,150,5,0,32,0,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,33,77,169,28,5,0,32,0,38,0,0,0,255,255,255,0,0,0,0,0,39,0,0,0,255,255,255,0,0,0,0,0,40,0,0,0,255,255,255,0,0,0,0,0,38,0,0,0,254,0,8,0,32,4,2,0,38,0,0,0,1,7,0,0,88,241,7,0,38,0,0,0,1,7,1,0,240,12,2,0,38,0,0,0,1,7,2,0,160,36,8,0,38,0,0,0,1,7,7,0,208,239,7,0,38,0,0,0,1,7,6,0,120,187,7,0,38,0,0,0,1,7,5,0,136,23,1,0,38,0,0,0,1,7,4,0,88,217,6,0,38,0,0,0,1,7,3,0,32,15,1,0,38,0,0,0,254,0,4,0,72,202,5,0,38,0,0,0,1,24,16,0,80,246,3,0,38,0,0,0,1,24,24,0,248,38,7,0,38,0,0,0,1,24,8,0,112,212,3,0,38,0,0,0,1,24,0,0,160,41,2,0,38,0,0,0,254,0,2,0,168,234,7,0,38,0,0,0,1,32,0,0,96,135,7,0,38,0,0,0,1,32,32,0,152,182,7,0,38,0,0,0,254,0,2,0,144,212,8,0,38,0,0,0,1,64,64,0,96,135,7,0,38,0,0,0,1,64,0,0,152,182,7,0,39,0,0,0,254,0,4,0,224,41,5,0,39,0,0,0,1,3,3,0,64,106,4,0,39,0,0,0,1,3,2,0,248,232,4,0,39,0,0,0,1,3,1,0,160,196,4,0,39,0,0,0,1,3,0,0,120,164,4,0,39,0,0,0,254,0,4,0,208,133,4,0,39,0,0,0,1,12,12,0,64,106,4,0,39,0,0,0,1,12,8,0,248,232,4,0,39,0,0,0,1,12,4,0,160,196,4,0,39,0,0,0,1,12,0,0,120,164,4,0,39,0,0,0,254,0,4,0,232,106,4,0,39,0,0,0,1,48,48,0,64,106,4,0,39,0,0,0,1,48,32,0,248,232,4,0,39,0,0,0,1,48,16,0,160,196,4,0,39,0,0,0,1,48,0,0,120,164,4,0,39,0,0,0,254,0,4,0,56,80,4,0,39,0,0,0,1,192,192,0,64,106,4,0,39,0,0,0,1,192,128,0,248,232,4,0,39,0,0,0,1,192,64,0,160,196,4,0,39,0,0,0,1,192,0,0,120,164,4,0,40,0,0,0,254,0,2,0,192,76,8,0,40,0,0,0,1,1,1,0,64,26,4,0,40,0,0,0,1,1,0,0,232,251,3,0,100,106,48,50,45,50,46,49,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,185,86,152,193,1,0,0,0,100,106,48,54,45,50,46,55,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,2,234,96,40,1,0,0,0,100,106,48,53,45,50,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,94,145,221,15,1,0,0,0,100,106,48,52,45,50,46,49,48,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,121,101,3,113,1,0,0,0,100,106,48,51,45,50,46,49,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,147,72,143,48,1,0,0,0,100,106,49,45,50,121,46,49,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,35,182,159,61,2,0,0,0,100,106,48,55,45,49,46,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,56,28,71,74,3,0,0,0,100,106,45,48,48,46,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,26,137,90,129,5,0,0,0,100,106,49,50,46,49,53,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,242,52,118,43,6,0,0,0,100,106,49,51,46,49,52,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,82,169,48,69,6,0,0,0,100,106,49,52,46,49,51,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,51,136,194,135,6,0,0,0,100,106,49,53,46,49,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,77,58,180,191,6,0,0,0,100,106,49,54,46,49,48,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,196,140,132,249,6,0,0,0,100,106,49,55,46,57,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,24,210,163,186,6,0,0,0,100,106,49,56,46,56,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,51,229,175,18,6,0,0,0,100,106,49,57,46,54,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,85,55,55,3,6,0,0,0,100,106,49,49,46,49,50,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,67,42,126,6,7,0,0,0,100,106,49,48,46,49,52,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,170,51,151,193,7,0,0,0,100,106,48,57,46,49,53,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,190,93,125,227,7,0,0,0,100,106,48,56,46,49,55,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,15,136,238,190,7,0,0,0,100,106,46,49,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,4,0,0,16,100,107,45,50,48,46,57,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,136,213,60,255,0,0,0,8,50,52,53,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,109,135,40,200,1,0,16,1,50,52,53,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,93,10,102,231,2,0,32,0,50,52,53,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,118,174,212,104,3,0,32,0,50,52,53,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,205,5,238,253,3,0,32,0,50,52,53,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,243,119,80,100,3,0,32,0,50,52,53,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,76,183,174,99,3,0,32,0,50,52,53,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,127,14,244,181,3,0,32,0,50,52,53,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,40,115,51,208,3,0,32,0,50,52,53,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,102,28,243,0,4,0,16,1,50,52,53,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,108,68,85,226,5,0,64,0,50,52,53,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,138,25,104,144,5,0,64,0,50,51,48,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,230,166,36,237,1,0,16,1,50,51,48,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,76,182,111,7,2,0,32,0,50,51,48,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,118,174,212,104,3,0,32,0,50,51,48,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,205,5,238,253,3,0,32,0,50,51,48,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,243,119,80,100,3,0,32,0,50,51,48,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,76,183,174,99,3,0,32,0,50,51,48,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,193,161,81,57,4,0,16,1,50,51,48,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,121,210,158,127,5,0,64,0,50,51,48,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,32,228,67,29,5,0,64,0,56,57,49,110,48,51,46,107,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,243,63,8,139,1,0,16,1,56,57,49,110,48,50,46,107,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,212,158,77,212,1,0,16,1,56,57,49,106,48,49,46,103,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,168,160,176,49,2,0,16,1,56,57,49,101,49,48,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,49,4,155,32,3,0,32,0,56,57,49,101,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,232,169,32,128,3,0,32,0,56,57,49,101,49,48,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,122,253,213,22,3,0,32,0,56,57,49,101,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,192,28,18,48,3,0,32,0,56,57,49,101,48,57,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,191,239,202,157,3,0,32,0,56,57,49,101,48,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,217,234,176,86,3,0,32,0,56,57,49,101,48,57,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,230,53,19,78,3,0,32,0,56,57,49,101,48,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,251,20,249,182,3,0,32,0,56,57,49,101,48,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,28,219,4,11,4,0,32,0,56,57,49,101,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,39,115,227,94,4,0,32,0,56,57,49,101,48,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,36,165,173,249,4,0,32,0,56,57,49,101,48,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,170,223,149,34,4,0,32,0,56,57,49,101,48,54,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,143,247,171,4,4,0,32,0,56,57,49,101,48,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,85,13,219,219,4,0,32,0,56,57,49,101,48,54,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,140,237,93,93,4,0,32,0,56,57,49,101,48,54,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,113,189,236,249,4,0,32,0,56,57,49,101,48,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,41,231,86,179,4,0,32,0,56,57,49,101,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,126,72,213,191,4,0,32,0,56,57,49,101,48,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,197,17,221,236,4,0,32,0,56,57,49,101,48,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,36,141,161,171,4,0,32,0,56,57,49,101,48,53,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,174,249,21,195,4,0,32,0,56,57,49,101,48,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,111,188,252,33,4,0,32,0,56,57,49,101,48,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,59,165,171,176,4,0,32,0,56,57,49,101,48,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,134,248,211,246,4,0,32,0,56,57,49,101,48,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,57,185,216,184,5,0,32,0,56,57,49,101,48,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,45,249,178,131,5,0,32,0,56,57,49,101,48,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,191,103,246,206,6,0,32,0,56,57,49,101,48,56,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,122,74,193,247,6,0,32,0,56,57,49,101,48,56,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,60,127,107,117,6,0,32,0,56,57,49,101,48,56,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,5,115,13,205,6,0,32,0,56,57,49,101,48,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,116,188,235,218,7,0,32,0,56,57,49,101,48,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,209,154,251,95,7,0,32,0,56,57,49,101,48,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,107,241,187,45,7,0,32,0,56,57,49,101,48,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,204,210,12,139,7,0,32,0,56,57,49,98,49,49,46,102,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,170,84,184,236,8,0,0,8,107,110,95,48,48,45,50,46,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,185,146,136,227,1,0,16,1,107,110,95,48,50,45,50,46,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,239,239,38,132,1,0,16,1,107,110,95,48,49,45,50,46,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,76,181,212,58,1,0,16,1,107,110,95,48,51,45,50,46,52,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,74,31,182,16,1,0,16,1,107,109,48,54,46,49,56,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,225,196,139,62,2,0,16,1,107,109,48,53,46,57,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,149,239,10,209,3,0,32,0,107,109,48,52,46,56,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,168,35,147,50,3,0,32,0,109,98,100,45,48,49,46,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,75,79,222,215,4,0,32,0,109,98,100,45,48,48,46,56,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,169,11,178,173,4,0,32,0,109,98,100,45,48,50,46,49,48,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,33,167,90,178,8,0,32,0,109,98,100,45,48,51,46,49,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,44,143,121,207,5,0,32,0,109,98,100,45,48,52,46,49,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,11,77,118,217,5,0,32,0,109,98,100,45,48,53,46,49,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,106,198,104,23,6,0,32,0,109,98,100,45,48,54,46,49,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,122,132,80,119,6,0,32,0,109,98,100,45,48,55,46,49,56,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,193,170,31,36,7,0,32,0,109,98,100,45,48,56,46,49,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,86,30,59,241,7,0,32,0,109,98,100,45,49,48,46,49,55,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,106,247,89,241,9,0,64,0,109,98,100,45,48,57,46,49,54,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,135,47,79,244,10,0,64,0,107,106,45,48,48,46,49,53,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,11,213,212,173,11,0,0,8,98,52,49,45,48,57,45,49,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,188,31,130,175,2,0,16,1,98,52,49,45,49,49,45,49,46,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,255,63,130,2,0,16,1,98,52,49,45,49,48,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,119,77,169,76,2,0,16,1,98,52,49,45,49,53,46,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,208,160,215,174,2,0,16,1,98,52,49,45,48,49,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,164,47,7,93,1,0,16,1,98,52,49,45,49,51,46,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,84,66,70,158,9,0,16,1,98,52,49,45,48,51,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,208,53,109,115,11,0,32,0,98,52,49,45,48,50,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,217,5,242,41,15,0,32,0,98,52,49,45,48,52,46,52,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,143,99,104,198,24,0,64,0,98,98,109,45,112,49,46,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,102,209,43,152,1,0,16,1,98,98,109,45,112,48,46,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,204,175,32,10,1,0,16,1,98,98,109,45,115,112,46,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,205,144,16,37,2,0,16,1,98,98,109,45,99,48,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,25,32,93,105,3,0,32,0,98,98,109,45,99,49,46,54,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,188,139,124,76,3,0,32,0,98,98,109,45,99,50,46,54,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,6,212,0,7,3,0,32,0,98,98,109,45,99,51,46,54,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,175,19,54,60,3,0,32,0,98,98,109,45,118,48,46,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,254,3,168,15,4,0,64,0,98,107,95,117,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,191,80,235,214,1,0,16,1,98,107,95,117,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,162,136,83,213,1,0,16,1,98,107,95,117,54,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,54,245,98,25,3,0,32,0,98,107,95,117,54,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,164,117,12,216,3,0,32,0,98,107,95,117,54,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,111,30,94,97,3,0,32,0,98,107,95,117,55,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,241,126,129,89,3,0,32,0,98,107,95,117,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,63,62,184,194,4,0,32,0,98,107,95,117,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,146,1,137,214,4,0,32,0,98,107,95,117,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,108,196,56,149,4,0,32,0,98,107,95,117,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,61,31,131,227,4,0,32,0,98,107,95,117,49,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,50,87,204,34,5,0,64,0,98,112,45,49,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,166,105,0,178,1,0,16,1,98,112,45,50,46,49,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,46,48,48,74,1,0,16,1,98,112,45,51,46,49,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,7,202,102,104,1,0,16,1,98,112,45,52,46,49,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,195,250,60,93,1,0,16,1,98,112,45,53,46,49,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,196,202,86,165,1,0,16,1,115,110,100,45,49,46,51,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,122,119,56,253,2,0,16,1,115,110,100,45,50,46,51,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,91,191,213,51,2,0,16,1,98,103,45,49,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,188,97,42,172,3,0,32,0,98,103,45,50,46,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,215,133,254,129,3,0,32,0,114,101,100,46,49,55,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,131,100,59,167,4,0,32,0,98,108,117,101,46,49,56,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,80,37,98,125,4,0,32,0,103,114,101,101,110,46,50,48,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,38,79,203,47,4,0,32,0,98,112,45,49,106,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,147,102,116,46,1,0,16,1,98,112,45,50,106,46,49,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,142,11,235,160,1,0,16,1,98,112,45,51,106,46,49,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,187,129,73,195,1,0,16,1,98,112,45,52,106,46,49,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,181,119,94,82,1,0,16,1,98,112,45,53,106,46,49,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,95,1,26,67,1,0,16,1,115,110,100,45,49,46,51,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,122,119,56,253,2,0,16,1,115,110,100,45,50,46,51,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,91,191,213,51,2,0,16,1,98,103,45,49,106,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,52,140,113,67,3,0,32,0,98,103,45,50,106,46,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,125,7,206,211,3,0,32,0,114,101,100,106,46,49,55,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,143,16,218,131,4,0,32,0,98,108,117,101,106,46,49,56,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,47,243,64,180,4,0,32,0,103,114,101,101,110,106,46,50,48,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,101,103,2,35,4,0,32,0,50,106,46,117,48,50,49,46,55,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,228,195,253,192,1,0,16,1,49,106,46,117,48,50,50,46,56,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,223,15,126,45,1,0,16,1,98,98,95,48,52,46,117,48,50,51,46,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,44,28,149,253,1,0,16,1,98,98,95,48,51,46,117,48,50,52,46,56,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,96,196,211,24,1,0,16,1,98,98,95,48,55,46,117,49,48,49,54,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,232,148,27,65,2,0,16,1,98,98,95,48,53,46,117,48,54,49,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,25,109,186,4,3,0,32,0,98,98,95,48,54,46,117,48,54,51,46,54,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,91,227,146,112,3,0,32,0,98,108,111,111,100,95,98,114,111,115,95,98,107,95,95,40,99,41,49,57,57,48,95,116,97,100,95,99,111,114,112,46,117,48,54,52,46,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,230,126,168,26,4,0,32,0,98,108,111,111,100,95,98,114,111,115,95,111,98,106,95,95,40,99,41,49,57,57,48,95,116,97,100,95,99,111,114,112,46,117,48,55,56,46,50,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,82,57,124,210,5,0,32,0,98,98,95,48,56,46,117,48,57,53,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,117,185,177,222,6,0,64,0,98,111,50,57,97,48,45,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,39,52,16,176,1,0,16,1,98,111,50,57,97,49,45,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,162,213,132,89,1,0,16,1,98,111,50,57,101,51,45,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,120,31,160,62,2,0,16,1,98,111,50,57,101,50,45,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,157,169,197,21,3,0,64,0,109,98,55,49,49,52,104,46,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,167,189,91,178,0,0,0,8,117,49,46,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,251,19,67,1,0,16,1,117,52,46,97,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,109,25,55,34,1,0,16,1,98,108,45,99,104,114,45,48,46,106,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,202,0,51,163,3,0,32,0,98,108,45,99,104,114,45,49,46,108,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,8,232,61,86,3,0,32,0,98,108,45,115,110,100,45,48,46,97,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,175,171,45,169,6,0,64,0,98,100,117,45,48,49,97,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,34,143,249,168,1,0,16,1,98,100,117,45,48,50,97,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,232,150,239,123,1,0,16,1,98,100,117,45,48,51,97,46,56,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,87,225,137,64,1,0,16,1,98,100,45,48,52,46,57,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,236,246,106,237,1,0,16,1,98,100,45,48,53,46,49,48,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,46,183,89,174,1,0,16,1,98,100,45,48,54,46,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,116,66,245,44,2,0,16,1,98,100,45,49,53,46,50,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,120,93,23,112,3,0,32,0,98,100,45,49,50,46,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,147,73,82,196,4,0,32,0,98,100,45,49,49,46,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,111,200,50,121,4,0,32,0,98,100,45,49,52,46,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,58,89,73,220,4,0,32,0,98,100,45,49,51,46,56,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,34,161,215,126,4,0,32,0,98,100,45,48,56,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,56,116,241,226,5,0,32,0,98,100,45,48,55,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,39,189,204,95,5,0,32,0,98,100,45,49,48,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,198,204,51,252,5,0,32,0,98,100,45,48,57,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,222,73,244,5,0,32,0,98,100,48,49,46,56,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,229,89,180,41,6,0,0,8,98,100,48,50,46,57,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,30,116,139,6,0,0,8,98,100,48,51,46,49,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,117,28,32,39,6,0,0,8,98,100,48,52,46,49,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,104,11,73,229,6,0,0,8,98,100,46,54,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,241,20,125,172,7,0,16,8,98,108,107,104,114,116,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,192,72,210,91,1,0,16,1,98,108,107,104,114,116,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,13,229,73,100,1,0,16,1,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,149,162,239,124,2,0,16,1,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,22,58,171,161,3,0,32,0,57,48,48,54,56,45,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,36,79,171,161,4,0,32,0,57,48,48,54,56,45,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,178,4,50,157,5,0,32,0,57,48,48,54,56,45,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,132,49,88,58,6,0,64,0,57,48,48,54,56,45,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,210,105,175,231,7,0,64,0,57,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,151,28,237,152,0,0,0,8,49,48,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,108,184,219,207,0,0,0,8,98,100,95,48,49,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,188,223,204,39,1,0,16,1,98,100,95,48,50,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,111,194,57,125,1,0,16,1,98,100,95,48,51,46,56,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,87,55,191,209,1,0,16,1,98,100,95,48,52,46,57,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,128,102,29,77,1,0,16,1,98,100,95,48,53,46,49,48,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,94,196,208,200,1,0,16,1,98,100,95,48,54,46,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,116,66,245,44,2,0,16,1,98,100,95,49,53,46,50,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,41,171,33,56,3,0,32,0,98,100,95,49,50,46,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,176,164,208,34,4,0,32,0,98,100,95,49,49,46,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,82,252,181,200,4,0,32,0,98,100,95,49,52,46,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,120,195,152,148,4,0,32,0,98,100,95,49,51,46,56,98])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,206,248,13,91,4,0,32,0,98,100,95,48,56,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,56,116,241,226,5,0,32,0,98,100,95,48,55,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,39,189,204,95,5,0,32,0,98,100,95,49,48,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,198,204,51,252,5,0,32,0,98,100,95,48,57,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,222,73,244,5,0,32,0,98,100,48,49,46,56,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,229,89,180,41,6,0,0,8,98,100,48,50,46,57,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,30,116,139,6,0,0,8,98,100,48,51,46,49,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,117,28,32,39,6,0,0,8,98,100,48,52,46,49,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,104,11,73,229,6,0,0,8,98,100,46,54,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,241,20,125,172,7,0,16,8,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,101,240,108,225,1,0,16,1,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,163,40,11,149,1,0,16,1,98,111,50,57,101,51,45,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,120,31,160,62,2,0,16,1,98,111,50,57,101,50,45,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,157,169,197,21,3,0,64,0,109,98,55,49,49,52,104,46,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,167,189,91,178,0,0,0,8,50,57,97,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,30,147,95,96,1,0,16,1,50,57,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,112,240,56,1,0,16,1,98,111,50,57,101,51,45,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,120,31,160,62,2,0,16,1,98,111,50,57,101,50,45,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,157,169,197,21,3,0,64,0,109,98,55,49,49,52,104,46,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,167,189,91,178,0,0,0,8,50,51,57,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,248,130,54,24,1,0,16,1,50,51,57,45,112,50,46,115,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,84,65,159,154,1,0,16,1,50,51,57,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,152,180,108,213,2,0,32,0,50,51,57,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,132,213,246,132,3,0,32,0,50,51,57,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,34,203,160,5,3,0,32,0,50,51,57,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,158,156,182,95,3,0,32,0,50,51,57,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,196,40,224,11,3,0,32,0,50,51,57,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,248,229,186,116,3,0,32,0,50,51,57,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,210,0,7,78,3,0,32,0,50,51,57,45,99,55,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,253,244,15,1,3,0,32,0,50,51,57,45,99,56,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,14,70,96,219,3,0,32,0,50,51,57,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,234,58,26,211,4,0,16,1,50,51,57,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,247,91,141,27,5,0,64,0,50,51,57,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,112,10,207,116,5,0,64,0,112,114,103,45,101,118,101,110,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,232,48,205,126,1,0,16,1,112,114,103,45,111,100,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,21,108,184,66,1,0,16,1,116,98,108,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,184,158,183,105,1,0,16,1,116,98,108,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,80,211,47,207,1,0,16,1,111,45,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,240,183,103,76,11,0,32,0,111,45,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,85,133,123,94,11,0,32,0,111,45,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,139,231,190,64,11,0,32,0,111,45,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,132,71,99,124,11,0,32,0,111,45,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,196,199,127,56,11,0,32,0,111,45,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,73,187,105,198,11,0,32,0,111,45,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,74,176,119,252,11,0,32,0,111,45,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,67,41,136,146,11,0,32,0,118,49,45,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,94,115,36,213,4,0,32,0,118,49,45,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,219,12,68,235,4,0,32,0,118,49,45,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,95,247,189,9,4,0,32,0,118,49,45,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,229,17,57,128,4,0,32,0,118,49,45,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,72,117,97,115,4,0,32,0,118,49,45,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,251,228,24,127,4,0,32,0,118,50,45,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,56,86,241,196,5,0,32,0,118,50,45,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,34,118,229,194,5,0,32,0,118,50,45,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,56,86,241,196,5,0,32,0,118,50,45,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,48,33,236,22,5,0,32,0,118,50,45,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,169,235,5,91,5,0,32,0,118,50,45,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,59,12,173,128,5,0,32,0,115,45,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,8,228,253,165,6,0,64,0,115,45,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,196,249,131,48,6,0,64,0,115,45,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,239,201,145,165,6,0,64,0,115,45,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,157,108,130,104,6,0,64,0,115,45,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,194,200,125,28,6,0,64,0,115,45,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,106,20,176,75,6,0,64,0,115,45,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,238,52,143,159,6,0,64,0,115,45,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,57,221,119,224,6,0,64,0,112,114,103,48,117,48,50,50,46,110,101,119,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,211,56,141,250,0,0,16,1,112,114,103,50,117,48,50,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,86,134,186,255,0,0,16,1,112,114,103,49,117,48,50,51,46,110,101,119,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,100,170,233,74,0,0,16,1,112,114,103,51,117,48,50,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,214,138,75,131,0,0,16,1,103,102,120,117,48,53,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,70,52,202,156,0,0,32,0,103,102,120,117,48,53,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,213,129,162,162,0,0,32,0,103,102,120,117,48,53,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,192,114,100,225,0,0,32,0,103,102,120,117,48,53,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,160,53,182,139,0,0,32,0,115,110,100,117,48,55,50,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,70,178,42,230,0,0,16,1,114,111,109,54,46,56,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,160,180,72,136,0,0,64,0,114,111,109,55,46,56,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,103,66,34,214,0,0,64,0,114,111,109,56,46,56,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,176,223,1,161,0,0,64,0,101,101,112,114,111,109,45,98,98,97,107,114,97,105,100,45,110,101,119,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,90,39,201,53,0,0,16,0,48,50,50,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,74,109,47,106,1,0,16,1,48,50,50,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,36,54,60,132,2,0,32,0,48,50,50,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,140,164,71,77,3,0,32,0,48,50,50,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,26,73,193,232,3,0,32,0,48,50,50,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,83,151,230,102,3,0,32,0,48,50,50,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,138,212,191,113,3,0,32,0,48,50,50,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,182,74,29,142,4,0,16,1,48,50,50,45,118,49,49,46,118,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,145,173,180,44,5,0,64,0,48,50,50,45,118,50,50,46,118,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,19,77,165,101,5,0,64,0,116,115,117,95,48,50,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,8,143,82,242,1,0,16,1,116,115,117,95,48,52,46,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,228,199,177,56,1,0,16,1,116,115,117,95,48,51,46,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,111,183,195,114,1,0,16,1,116,115,117,95,48,53,46,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,131,31,98,112,1,0,16,1,116,115,95,48,49,98,46,52,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,250,202,166,169,2,0,16,1,116,115,117,95,48,56,46,56,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,162,183,240,155,3,0,32,0,116,115,117,95,48,55,46,53,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,164,239,105,148,4,0,32,0,116,115,117,95,48,54,46,52,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,180,14,191,64,4,0,32,0,116,115,95,49,50,46,49,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,158,97,180,228,5,0,32,0,116,115,95,49,49,46,49,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,122,35,48,171,5,0,32,0,116,115,95,49,55,46,49,55,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,228,87,182,222,5,0,32,0,116,115,95,49,54,46,49,53,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,249,181,99,211,5,0,32,0,116,115,95,49,51,46,49,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,4,160,245,168,5,0,32,0,116,115,95,49,56,46,49,56,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,140,148,54,59,5,0,32,0,116,115,95,50,51,46,49,56,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,138,229,251,187,5,0,32,0,116,115,95,50,52,46,49,56,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,100,229,86,241,5,0,32,0,116,115,117,95,49,48,46,49,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,2,13,24,241,6,0,32,0,116,115,117,95,48,57,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,146,146,4,106,6,0,32,0,116,115,117,95,49,53,46,49,51,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,1,39,145,234,6,0,32,0,116,115,117,95,49,52,46,49,49,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,131,173,178,70,6,0,32,0,116,115,117,95,50,48,46,49,51,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,210,122,133,23,6,0,32,0,116,115,117,95,49,57,46,49,49,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,34,39,200,181,6,0,32,0,116,115,117,95,50,50,46,49,55,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,106,174,225,94,6,0,32,0,116,115,117,95,50,49,46,49,53,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,6,112,119,152,6,0,32,0,54,51,115,49,52,49,46,49,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,35,0,141,181,0,0,0,8,99,56,55,53,49,104,45,56,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,24,116,115,117,95,48,50,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,10,90,150,207,1,0,16,1,116,115,117,95,48,52,98,46,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,251,75,136,201,1,0,16,1,116,115,117,95,48,51,98,46,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,226,122,21,78,1,0,16,1,116,115,117,95,48,53,98,46,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,249,160,108,230,1,0,16,1,116,115,95,48,49,98,46,52,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,250,202,166,169,2,0,16,1,116,115,117,95,48,56,46,56,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,162,183,240,155,3,0,32,0,116,115,117,95,48,55,46,53,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,164,239,105,148,4,0,32,0,116,115,117,95,48,54,46,52,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,180,14,191,64,4,0,32,0,116,115,95,49,50,46,49,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,158,97,180,228,5,0,32,0,116,115,95,49,49,46,49,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,122,35,48,171,5,0,32,0,116,115,95,49,55,46,49,55,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,228,87,182,222,5,0,32,0,116,115,95,49,54,46,49,53,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,249,181,99,211,5,0,32,0,116,115,95,49,51,46,49,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,4,160,245,168,5,0,32,0,116,115,95,49,56,46,49,56,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,140,148,54,59,5,0,32,0,116,115,95,50,51,46,49,56,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,138,229,251,187,5,0,32,0,116,115,95,50,52,46,49,56,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,100,229,86,241,5,0,32,0,116,115,117,95,49,48,46,49,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,2,13,24,241,6,0,32,0,116,115,117,95,48,57,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,146,146,4,106,6,0,32,0,116,115,117,95,49,53,46,49,51,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,1,39,145,234,6,0,32,0,116,115,117,95,49,52,46,49,49,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,131,173,178,70,6,0,32,0,116,115,117,95,50,48,46,49,51,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,210,122,133,23,6,0,32,0,116,115,117,95,49,57,46,49,49,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,34,39,200,181,6,0,32,0,116,115,117,95,50,50,46,49,55,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,106,174,225,94,6,0,32,0,116,115,117,95,50,49,46,49,53,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,6,112,119,152,6,0,32,0,54,51,115,49,52,49,46,49,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,35,0,141,181,0,0,0,8,99,56,55,53,49,104,45,56,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,24,98,105,111,109,116,111,121,97,46,100,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,189,205,182,57,1,0,16,1,98,105,111,109,116,111,121,97,46,100,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,113,6,52,171,1,0,16,1,104,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,41,167,22,148,2,0,32,0,106,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,139,114,35,233,2,0,32,0,104,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,123,77,152,156,2,0,32,0,106,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,194,250,24,14,2,0,32,0,104,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,103,31,140,2,0,32,0,106,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,80,240,147,28,2,0,32,0,104,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,43,112,161,172,2,0,32,0,106,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,204,150,62,142,2,0,32,0,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,126,222,2,15,3,0,64,0,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,188,75,78,145,3,0,64,0,100,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,115,156,251,68,1,0,16,1,100,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,221,223,121,255,1,0,16,1,104,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,255,57,226,32,2,0,32,0,104,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,85,40,68,171,2,0,32,0,104,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,163,229,220,131,2,0,32,0,104,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,36,75,232,36,2,0,32,0,100,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,209,74,68,38,3,0,64,0,100,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,197,185,115,59,4,0,16,1,112,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,201,193,166,238,1,0,16,1,109,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,99,115,143,187,1,0,16,1,53,101,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,55,44,68,24,2,0,32,0,56,50,115,49,50,51,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,189,80,198,47,3,0,32,0,56,50,115,49,50,54,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,228,168,179,62,3,0,32,0,56,50,115,49,50,54,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,134,204,169,4,0,64,0,56,50,115,49,50,54,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,114,111,109,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,95,120,183,144,7,0,16,1,114,111,109,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,119,45,23,96,7,0,16,1,114,111,109,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,32,115,32,162,7,0,16,1,114,111,109,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,249,193,116,90,7,0,16,1,114,111,109,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,128,16,188,147,7,0,16,1,114,111,109,54,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,63,66,162,238,7,0,16,1,114,111,109,55,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,85,64,105,150,7,0,16,1,114,111,109,56,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,142,191,142,230,7,0,16,1,114,111,109,57,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,29,146,32,253,7,0,16,1,114,111,109,49,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,81,185,145,80,7,0,16,1,114,111,109,49,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,219,40,81,112,7,0,16,1,114,111,109,49,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,231,118,199,116,7,0,16,1,12,0,0,0,255,255,255,0,0,0,0,0,13,0,0,0,255,255,255,0,0,0,0,0,14,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,184,173,4,0,12,0,0,0,1,16,0,0,96,135,7,0,12,0,0,0,1,16,16,0,152,182,7,0,0,0,0,0,254,0,2,0,32,170,4,0,13,0,0,0,1,1,0,0,56,165,4,0,13,0,0,0,1,1,1,0,48,161,4,0,0,0,0,0,254,0,2,0,248,157,4,0,13,0,0,0,1,2,0,0,96,135,7,0,13,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,2,0,136,155,4,0,13,0,0,0,1,4,0,0,96,135,7,0,13,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,13,0,0,0,1,8,0,0,96,135,7,0,13,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,2,0,32,4,2,0,13,0,0,0,1,16,0,0,160,36,8,0,13,0,0,0,1,16,16,0,208,239,7,0,0,0,0,0,254,0,2,0,200,30,2,0,13,0,0,0,1,32,32,0,120,97,1,0,13,0,0,0,1,32,0,0,96,19,1,0,103,97,114,101,103,103,97,95,112,114,103,48,46,117,49,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,5,116,91,35,0,0,16,1,103,97,114,101,103,103,97,95,112,114,103,49,46,117,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,106,207,156,194,0,0,16,1,114,111,109,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,31,216,51,179,0,0,32,0,114,111,109,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,251,235,185,81,0,0,32,0,114,111,109,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,226,229,48,179,0,0,32,0,114,111,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,112,221,175,126,0,0,32,0,116,101,120,116,46,117,56,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,52,213,127,230,0,0,32,0,115,110,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,82,41,99,104,0,0,16,1,114,111,109,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,99,152,212,246,0,0,64,0,112,114,103,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,153,64,9,132,0,0,16,1,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,228,47,249,70,0,0,16,1,114,111,109,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,31,216,51,179,0,0,32,0,114,111,109,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,251,235,185,81,0,0,32,0,114,111,109,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,226,229,48,179,0,0,32,0,114,111,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,112,221,175,126,0,0,32,0,116,101,120,116,46,117,56,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,52,213,127,230,0,0,32,0,115,110,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,82,41,99,104,0,0,16,1,114,111,109,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,99,152,212,246,0,0,64,0,112,114,103,95,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,7,204,30,149,0,0,16,1,112,114,103,95,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,198,96,154,114,0,0,16,1,114,111,109,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,31,216,51,179,0,0,32,0,114,111,109,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,251,235,185,81,0,0,32,0,114,111,109,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,226,229,48,179,0,0,32,0,114,111,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,112,221,175,126,0,0,32,0,116,101,120,116,46,117,56,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,52,213,127,230,0,0,32,0,115,110,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,82,41,99,104,0,0,16,1,114,111,109,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,99,152,212,246,0,0,64,0,112,114,103,95,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,158,1,224,38,0,0,16,1,112,114,103,95,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,30,221,207,44,0,0,16,1,114,111,109,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,31,216,51,179,0,0,32,0,114,111,109,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,251,235,185,81,0,0,32,0,114,111,109,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,226,229,48,179,0,0,32,0,114,111,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,112,221,175,126,0,0,32,0,116,101,120,116,46,117,56,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,52,213,127,230,0,0,32,0,115,110,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,82,41,99,104,0,0,16,1,114,111,109,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,99,152,212,246,0,0,64,0,112,114,103,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,194,47,12,248,0,0,16,1,112,114,103,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,30,221,207,44,0,0,16,1,114,111,109,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,31,216,51,179,0,0,32,0,114,111,109,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,251,235,185,81,0,0,32,0,114,111,109,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,226,229,48,179,0,0,32,0,114,111,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,112,221,175,126,0,0,32,0,116,101,120,116,46,117,56,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,52,213,127,230,0,0,32,0,115,110,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,82,41,99,104,0,0,16,1,114,111,109,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,99,152,212,246,0,0,64,0,20,0,0,0,255,255,0,0,0,0,0,0,21,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,208,87,7,0,20,0,0,0,1,1,0,0,248,38,7,0,20,0,0,0,1,1,1,0,80,251,6,0,0,0,0,0,254,0,2,0,40,211,6,0,20,0,0,0,1,2,0,0,88,164,6,0,20,0,0,0,1,2,2,0,168,123,6,0,0,0,0,0,254,0,8,0,184,40,2,0,20,0,0,0,1,28,0,0,200,201,5,0,20,0,0,0,1,28,4,0,152,160,5,0,20,0,0,0,1,28,8,0,144,127,5,0,20,0,0,0,1,28,12,0,144,127,5,0,20,0,0,0,1,28,16,0,224,67,5,0,20,0,0,0,1,28,20,0,216,36,5,0,20,0,0,0,1,28,24,0,8,7,5,0,20,0,0,0,1,28,28,0,16,227,4,0,0,0,0,0,254,0,7,0,184,164,8,0,20,0,0,0,130,224,0,0,200,201,5,0,20,0,0,0,0,28,28,0,0,0,0,0,20,0,0,0,130,224,32,0,152,160,5,0,20,0,0,0,0,28,28,0,0,0,0,0,20,0,0,0,130,224,64,0,144,127,5,0,20,0,0,0,0,28,28,0,0,0,0,0,20,0,0,0,130,224,96,0,144,127,5,0,20,0,0,0,0,28,28,0,0,0,0,0,20,0,0,0,130,224,128,0,224,67,5,0,20,0,0,0,0,28,28,0,0,0,0,0,20,0,0,0,130,224,160,0,216,36,5,0,20,0,0,0,0,28,28,0,0,0,0,0,20,0,0,0,130,224,192,0,8,7,5,0,20,0,0,0,0,28,28,0,0,0,0,0,20,0,0,0,130,224,4,0,200,201,5,0,20,0,0,0,0,28,28,0,0,0,0,0,0,0,0,0,254,0,2,0,192,73,6,0,20,0,0,0,2,32,0,0,88,32,6,0,20,0,0,0,0,28,28,0,0,0,0,0,20,0,0,0,2,32,32,0,248,38,7,0,20,0,0,0,0,28,28,0,0,0,0,0,0,0,0,0,254,0,2,0,152,129,4,0,20,0,0,0,2,64,0,0,96,135,7,0,20,0,0,0,0,28,28,0,0,0,0,0,20,0,0,0,2,64,64,0,152,182,7,0,20,0,0,0,0,28,28,0,0,0,0,0,0,0,0,0,254,0,2,0,16,49,4,0,20,0,0,0,2,128,0,0,96,135,7,0,20,0,0,0,0,28,28,0,0,0,0,0,20,0,0,0,2,128,128,0,152,182,7,0,20,0,0,0,0,28,28,0,0,0,0,0,0,0,0,0,254,0,4,0,72,202,5,0,21,0,0,0,1,3,0,0,248,38,7,0,21,0,0,0,1,3,1,0,80,246,3,0,21,0,0,0,1,3,2,0,112,212,3,0,21,0,0,0,1,3,3,0,72,185,3,0,0,0,0,0,254,0,2,0,128,147,2,0,21,0,0,0,1,4,0,0,96,135,7,0,21,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,254,0,2,0,200,135,2,0,21,0,0,0,1,8,0,0,152,182,7,0,21,0,0,0,1,8,8,0,96,135,7,0,0,0,0,0,254,0,8,0,192,74,3,0,21,0,0,0,1,112,0,0,8,49,4,0,21,0,0,0,1,112,16,0,152,21,4,0,21,0,0,0,1,112,32,0,208,75,4,0,21,0,0,0,1,112,48,0,192,255,2,0,21,0,0,0,1,112,64,0,72,246,3,0,21,0,0,0,1,112,80,0,72,0,3,0,21,0,0,0,1,112,96,0,112,234,2,0,21,0,0,0,1,112,112,0,112,69,2,0,0,0,0,0,254,0,2,0,16,234,2,0,21,0,0,0,2,128,0,0,0,192,2,0,22,0,0,0,0,1,0,0,0,0,0,0,21,0,0,0,2,128,128,0,24,161,2,0,22,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,254,0,2,0,16,234,2,0,21,0,0,0,2,128,128,0,112,175,2,0,22,0,0,0,0,1,1,0,0,0,0,0,21,0,0,0,2,128,0,0,232,135,2,0,22,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,254,0,2,0,104,82,2,0,22,0,0,0,1,4,0,0,152,182,7,0,22,0,0,0,1,4,4,0,96,135,7,0,117,49,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,106,230,164,136,0,0,16,1,117,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,163,50,234,93,0,0,16,1,114,111,109,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,31,216,51,179,0,0,32,0,114,111,109,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,251,235,185,81,0,0,32,0,114,111,109,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,226,229,48,179,0,0,32,0,114,111,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,112,221,175,126,0,0,32,0,116,101,120,116,46,117,56,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,52,213,127,230,0,0,32,0,115,110,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,82,41,99,104,0,0,16,1,114,111,109,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,99,152,212,246,0,0,64,0,0,0,0,0,0,0,0,0,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,148,25,116,6,1,0,16,1,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,236,61,132,66,1,0,16,1,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,38,143,187,226,1,0,16,1,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,10,226,101,211,1,0,16,1,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,230,101,146,187,2,0,16,1,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,107,95,68,221,3,0,16,1,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,234,148,25,177,5,0,32,0,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,245,30,180,55,5,0,32,0,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,115,139,24,22,5,0,32,0,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,107,224,92,118,5,0,32,0,49,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,234,205,70,220,6,0,32,0,49,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,87,221,250,198,6,0,32,0,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,196,58,40,35,6,0,32,0,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,9,70,76,103,6,0,32,0,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,83,251,16,194,6,0,32,0,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,199,102,17,59,6,0,32,0,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,195,235,62,50,6,0,32,0,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,118,129,124,202,6,0,32,0,56,50,115,49,50,57,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,187,206,191,16,0,0,0,8,56,50,115,49,50,57,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,187,206,191,16,0,0,0,8,26,0,0,0,255,255,255,0,0,0,0,0,27,0,0,0,255,255,255,0,0,0,0,0,26,0,0,0,254,0,8,0,32,4,2,0,26,0,0,0,1,7,0,0,56,111,8,0,26,0,0,0,1,7,1,0,88,241,7,0,26,0,0,0,1,7,2,0,240,12,2,0,26,0,0,0,1,7,3,0,160,36,8,0,26,0,0,0,1,7,7,0,208,239,7,0,26,0,0,0,1,7,6,0,120,187,7,0,26,0,0,0,1,7,5,0,136,23,1,0,26,0,0,0,1,7,4,0,88,217,6,0,26,0,0,0,254,0,4,0,72,202,5,0,26,0,0,0,1,24,24,0,80,246,3,0,26,0,0,0,1,24,16,0,248,38,7,0,26,0,0,0,1,24,8,0,112,212,3,0,26,0,0,0,1,24,0,0,248,160,5,0,26,0,0,0,254,0,2,0,168,191,7,0,26,0,0,0,1,32,0,0,96,135,7,0,26,0,0,0,1,32,32,0,152,182,7,0,26,0,0,0,254,0,2,0,168,234,7,0,26,0,0,0,1,128,128,0,96,135,7,0,26,0,0,0,1,128,0,0,152,182,7,0,27,0,0,0,254,0,2,0,144,212,8,0,27,0,0,0,1,1,1,0,96,135,7,0,27,0,0,0,1,1,0,0,152,182,7,0,27,0,0,0,254,0,4,0,80,184,7,0,27,0,0,0,1,6,6,0,40,164,4,0,27,0,0,0,1,6,4,0,104,133,4,0,27,0,0,0,1,6,2,0,64,106,4,0,27,0,0,0,1,6,0,0,152,79,4,0,99,45,104,48,45,98,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,22,171,254,242,1,0,16,1,99,45,108,48,45,98,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,150,112,136,159,1,0,16,1,99,45,104,49,45,98,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,79,214,149,169,1,0,16,1,99,45,108,49,45,98,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,153,169,221,65,1,0,16,1,99,45,104,51,45,98,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,202,81,148,171,1,0,16,1,99,45,108,51,45,98,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,33,34,86,17,1,0,16,1,99,45,48,48,45,97,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,96,230,230,246,2,0,32,0,99,45,48,49,45,98,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,55,221,140,112,2,0,32,0,99,45,49,48,45,97,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,32,133,44,41,2,0,32,0,99,45,49,49,45,98,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,243,76,144,32,2,0,32,0,99,45,50,48,45,97,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,35,12,181,26,2,0,32,0,99,45,50,49,45,98,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,76,211,35,200,2,0,32,0,99,45,51,48,45,97,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,107,197,246,17,2,0,32,0,99,45,51,49,45,98,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,197,78,19,35,2,0,32,0,98,45,97,48,45,98,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,191,215,110,228,3,0,32,0,98,45,97,49,45,98,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,255,5,6,89,3,0,32,0,98,45,97,50,45,98,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,38,130,21,248,3,0,32,0,98,45,97,51,45,98,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,183,185,7,15,3,0,32,0,98,45,98,48,45,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,118,87,185,181,4,0,32,0,98,45,98,49,45,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,238,22,202,116,4,0,32,0,98,45,98,50,45,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,4,202,44,184,4,0,32,0,98,45,98,51,45,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,32,201,175,167,4,0,32,0,99,45,118,48,45,98,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,88,126,194,208,5,0,64,0,98,99,104,111,112,112,101,114,95,105,56,55,53,49,46,109,99,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,24,21,0,0,0,255,255,0,0,0,0,0,0,22,0,0,0,255,255,0,0,0,0,0,0,23,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,208,87,7,0,21,0,0,0,1,1,0,0,248,38,7,0,21,0,0,0,1,1,1,0,80,251,6,0,0,0,0,0,254,0,2,0,40,211,6,0,21,0,0,0,130,2,0,0,88,164,6,0,21,0,0,0,0,28,28,0,0,0,0,0,21,0,0,0,130,2,2,0,168,123,6,0,21,0,0,0,0,28,28,0,0,0,0,0,0,0,0,0,254,0,2,0,192,73,6,0,21,0,0,0,2,2,0,0,248,38,7,0,21,0,0,0,0,28,28,0,0,0,0,0,21,0,0,0,2,2,2,0,88,32,6,0,21,0,0,0,0,28,28,0,0,0,0,0,0,0,0,0,254,0,8,0,184,40,2,0,21,0,0,0,1,28,0,0,200,201,5,0,21,0,0,0,1,28,4,0,152,160,5,0,21,0,0,0,1,28,8,0,144,127,5,0,21,0,0,0,1,28,12,0,168,98,5,0,21,0,0,0,1,28,16,0,224,67,5,0,21,0,0,0,1,28,20,0,216,36,5,0,21,0,0,0,1,28,24,0,8,7,5,0,21,0,0,0,1,28,28,0,16,227,4,0,0,0,0,0,254,0,7,0,184,164,8,0,21,0,0,0,130,224,0,0,200,201,5,0,21,0,0,0,0,28,28,0,0,0,0,0,21,0,0,0,130,224,32,0,152,160,5,0,21,0,0,0,0,28,28,0,0,0,0,0,21,0,0,0,130,224,64,0,144,127,5,0,21,0,0,0,0,28,28,0,0,0,0,0,21,0,0,0,130,224,96,0,168,98,5,0,21,0,0,0,0,28,28,0,0,0,0,0,21,0,0,0,130,224,128,0,224,67,5,0,21,0,0,0,0,28,28,0,0,0,0,0,21,0,0,0,130,224,160,0,216,36,5,0,21,0,0,0,0,28,28,0,0,0,0,0,21,0,0,0,130,224,192,0,8,7,5,0,21,0,0,0,0,28,28,0,0,0,0,0,21,0,0,0,130,224,4,0,200,201,5,0,21,0,0,0,0,28,28,0,0,0,0,0,0,0,0,0,254,0,2,0,120,159,4,0,21,0,0,0,2,32,0,0,96,135,7,0,21,0,0,0,0,28,28,0,0,0,0,0,21,0,0,0,2,32,32,0,152,182,7,0,21,0,0,0,0,28,28,0,0,0,0,0,0,0,0,0,254,0,2,0,216,75,4,0,21,0,0,0,2,64,0,0,96,135,7,0,21,0,0,0,0,28,28,0,0,0,0,0,21,0,0,0,2,64,64,0,152,182,7,0,21,0,0,0,0,28,28,0,0,0,0,0,0,0,0,0,254,0,2,0,16,49,4,0,21,0,0,0,2,128,0,0,96,135,7,0,21,0,0,0,0,28,28,0,0,0,0,0,21,0,0,0,2,128,128,0,152,182,7,0,21,0,0,0,0,28,28,0,0,0,0,0,0,0,0,0,254,0,4,0,160,21,4,0,22,0,0,0,1,3,0,0,248,38,7,0,22,0,0,0,1,3,1,0,80,246,3,0,22,0,0,0,1,3,2,0,112,212,3,0,22,0,0,0,1,3,3,0,72,185,3,0,0,0,0,0,254,0,4,0,120,159,3,0,22,0,0,0,1,12,0,0,248,38,7,0,22,0,0,0,1,12,4,0,112,134,3,0,22,0,0,0,1,12,8,0,64,111,3,0,22,0,0,0,1,12,12,0,208,89,3,0,0,0,0,0,254,0,4,0,192,74,3,0,22,0,0,0,1,48,0,0,8,49,4,0,22,0,0,0,1,48,16,0,152,21,4,0,22,0,0,0,1,48,32,0,208,75,4,0,22,0,0,0,1,48,48,0,192,255,2,0,0,0,0,0,254,0,4,0,16,234,2,0,22,0,0,0,1,192,0,0,112,175,2,0,22,0,0,0,1,192,64,0,248,89,3,0,22,0,0,0,1,192,128,0,48,75,3,0,22,0,0,0,1,192,192,0,200,160,2,0,0,0,0,0,254,0,2,0,128,147,2,0,23,0,0,0,1,1,0,0,96,135,7,0,23,0,0,0,1,1,1,0,152,182,7,0,0,0,0,0,254,0,2,0,200,135,2,0,23,0,0,0,1,2,0,0,152,182,7,0,23,0,0,0,1,2,2,0,96,135,7,0,0,0,0,0,254,0,2,0,80,123,2,0,23,0,0,0,1,4,0,0,248,108,2,0,23,0,0,0,1,4,4,0,136,98,2,0,0,0,0,0,254,0,2,0,104,82,2,0,23,0,0,0,1,8,0,0,136,98,2,0,23,0,0,0,1,8,8,0,248,108,2,0,0,0,0,0,254,0,2,0,112,69,2,0,23,0,0,0,1,16,0,0,96,135,7,0,23,0,0,0,1,16,16,0,152,182,7,0,0,0,0,0,254,0,2,0,56,161,2,0,23,0,0,0,1,32,0,0,240,147,2,0,23,0,0,0,1,32,32,0,248,135,2,0,0,0,0,0,116,112,48,51,48,45,115,112,46,117,54,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,205,160,114,128,0,0,16,1,116,112,48,51,48,95,51,108,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,147,183,36,48,0,0,32,0,116,112,48,51,48,95,51,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,11,115,117,237,0,0,32,0,116,112,48,51,48,95,52,108,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,97,152,219,254,0,0,32,0,116,112,48,51,48,95,52,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,139,148,130,212,0,0,32,0,116,112,48,51,48,95,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,5,186,245,188,0,0,32,0,116,112,48,51,48,95,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,205,254,102,6,0,0,32,0,116,112,48,51,48,95,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,245,70,97,39,0,0,64,0,116,112,48,51,48,95,49,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,84,69,29,203,0,0,16,1,116,112,48,51,48,95,51,108,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,147,183,36,48,0,0,32,0,116,112,48,51,48,95,51,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,11,115,117,237,0,0,32,0,116,112,48,51,48,95,52,108,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,97,152,219,254,0,0,32,0,116,112,48,51,48,95,52,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,139,148,130,212,0,0,32,0,116,112,48,51,48,95,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,5,186,245,188,0,0,32,0,116,112,48,51,48,95,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,205,254,102,6,0,0,32,0,116,112,48,51,48,95,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,245,70,97,39,0,0,64,0,20,0,0,0,255,255,0,0,0,0,0,0,21,0,0,0,255,255,0,0,0,0,0,0,22,0,0,0,255,15,0,0,0,0,0,0,0,0,0,0,254,0,2,0,0,0,0,0,20,0,0,0,1,1,0,0,64,85,8,0,20,0,0,0,1,1,1,0,144,31,8,0,0,0,0,0,254,0,2,0,0,0,0,0,20,0,0,0,1,2,0,0,200,211,8,0,20,0,0,0,1,2,2,0,216,147,8,0,0,0,0,0,254,0,2,0,0,0,0,0,20,0,0,0,1,4,0,0,168,84,8,0,20,0,0,0,1,4,4,0,208,87,7,0,0,0,0,0,254,0,2,0,240,233,7,0,20,0,0,0,1,8,0,0,152,182,7,0,20,0,0,0,1,8,8,0,96,135,7,0,0,0,0,0,254,0,4,0,200,87,7,0,20,0,0,0,130,48,0,0,232,38,7,0,22,0,0,0,0,14,8,0,0,0,0,0,20,0,0,0,130,48,16,0,120,164,6,0,22,0,0,0,0,14,8,0,0,0,0,0,20,0,0,0,130,48,32,0,224,123,6,0,22,0,0,0,0,14,8,0,0,0,0,0,20,0,0,0,130,48,48,0,16,74,6,0,22,0,0,0,0,14,8,0,0,0,0,0,0,0,0,0,254,0,4,0,160,123,6,0,20,0,0,0,130,192,0,0,232,38,7,0,22,0,0,0,0,14,8,0,0,0,0,0,20,0,0,0,130,192,64,0,120,164,6,0,22,0,0,0,0,14,8,0,0,0,0,0,20,0,0,0,130,192,128,0,224,123,6,0,22,0,0,0,0,14,8,0,0,0,0,0,20,0,0,0,130,192,192,0,16,74,6,0,22,0,0,0,0,14,8,0,0,0,0,0,0,0,0,0,254,0,4,0,200,87,7,0,20,0,0,0,2,48,0,0,232,38,7,0,22,0,0,0,0,14,8,0,0,0,0,0,20,0,0,0,2,48,16,0,224,123,6,0,22,0,0,0,0,14,8,0,0,0,0,0,20,0,0,0,2,48,32,0,200,241,5,0,22,0,0,0,0,14,8,0,0,0,0,0,20,0,0,0,2,48,48,0,200,241,5,0,22,0,0,0,0,14,8,0,0,0,0,0,0,0,0,0,254,0,4,0,160,123,6,0,20,0,0,0,2,192,0,0,120,164,6,0,22,0,0,0,0,14,8,0,0,0,0,0,20,0,0,0,2,192,64,0,232,201,5,0,22,0,0,0,0,14,8,0,0,0,0,0,20,0,0,0,2,192,128,0,168,241,5,0,22,0,0,0,0,14,8,0,0,0,0,0,20,0,0,0,2,192,192,0,208,127,5,0,22,0,0,0,0,14,8,0,0,0,0,0,0,0,0,0,254,0,4,0,136,160,5,0,21,0,0,0,1,3,0,0,16,68,5,0,21,0,0,0,1,3,1,0,248,36,5,0,21,0,0,0,1,3,2,0,40,7,5,0,21,0,0,0,1,3,3,0,56,227,4,0,0,0,0,0,254,0,4,0,56,191,4,0,21,0,0,0,1,12,0,0,120,102,4,0,21,0,0,0,1,12,4,0,40,76,4,0,21,0,0,0,1,12,8,0,112,49,4,0,21,0,0,0,1,12,12,0,248,75,4,0,0,0,0,0,254,0,4,0,248,101,4,0,21,0,0,0,1,48,0,0,8,49,4,0,21,0,0,0,1,48,1,0,72,246,3,0,21,0,0,0,1,48,2,0,208,75,4,0,21,0,0,0,1,48,3,0,192,255,2,0,0,0,0,0,254,0,2,0,0,0,0,0,21,0,0,0,1,64,0,0,136,159,3,0,21,0,0,0,1,64,64,0,120,134,3,0,0,0,0,0,254,0,2,0,80,111,3,0,21,0,0,0,1,128,0,0,152,182,7,0,21,0,0,0,1,128,128,0,96,135,7,0,0,0,0,0,254,0,14,0,48,45,3,0,22,0,0,0,1,15,0,0,112,45,3,0,22,0,0,0,1,15,1,0,56,50,1,0,22,0,0,0,1,15,2,0,16,0,3,0,22,0,0,0,1,15,3,0,192,20,3,0,22,0,0,0,1,15,4,0,152,210,2,0,22,0,0,0,1,15,5,0,80,65,1,0,22,0,0,0,1,15,6,0,160,175,2,0,22,0,0,0,1,15,7,0,32,192,2,0,22,0,0,0,1,15,8,0,208,147,2,0,22,0,0,0,1,15,9,0,8,234,2,0,22,0,0,0,1,15,10,0,112,123,2,0,22,0,0,0,1,15,11,0,168,147,2,0,22,0,0,0,1,15,13,0,144,98,2,0,22,0,0,0,1,15,15,0,176,20,3,0,0,0,0,0,116,112,48,51,48,95,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,221,215,115,56,0,0,16,1,116,112,48,51,48,95,51,108,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,147,183,36,48,0,0,32,0,116,112,48,51,48,95,51,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,11,115,117,237,0,0,32,0,116,112,48,51,48,95,52,108,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,97,152,219,254,0,0,32,0,116,112,48,51,48,95,52,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,139,148,130,212,0,0,32,0,116,112,48,51,48,95,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,5,186,245,188,0,0,32,0,116,112,48,51,48,95,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,205,254,102,6,0,0,32,0,116,112,48,51,48,95,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,245,70,97,39,0,0,64,0,117,50,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,14,130,53,177,0,0,16,1,112,114,103,50,46,117,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,191,95,170,189,0,0,16,1,112,114,103,49,46,117,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,146,245,231,138,0,0,16,1,112,114,103,51,46,117,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,65,249,169,122,0,0,16,1,114,111,109,45,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,162,156,246,13,0,0,32,0,114,111,109,45,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,56,125,22,96,0,0,32,0,114,111,109,45,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,147,165,254,27,0,0,32,0,114,111,109,45,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,148,60,224,190,0,0,32,0,115,110,100,46,117,55,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,150,38,104,86,0,0,16,1,114,111,109,45,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,246,218,116,66,0,0,64,0,114,111,109,45,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,38,36,28,42,0,0,64,0,112,114,103,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,124,162,62,249,0,0,16,1,112,114,103,50,46,117,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,191,95,170,189,0,0,16,1,112,114,103,49,46,117,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,146,245,231,138,0,0,16,1,112,114,103,51,46,117,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,65,249,169,122,0,0,16,1,114,111,109,45,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,162,156,246,13,0,0,32,0,114,111,109,45,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,56,125,22,96,0,0,32,0,114,111,109,45,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,147,165,254,27,0,0,32,0,114,111,109,45,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,148,60,224,190,0,0,32,0,115,110,100,46,117,55,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,150,38,104,86,0,0,16,1,114,111,109,45,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,246,218,116,66,0,0,64,0,114,111,109,45,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,38,36,28,42,0,0,64,0,21,0,0,0,255,255,0,0,0,0,0,0,22,0,0,0,255,255,0,0,0,0,0,0,23,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,208,87,7,0,21,0,0,0,1,1,0,0,248,38,7,0,21,0,0,0,1,1,1,0,80,251,6,0,0,0,0,0,254,0,2,0,40,211,6,0,21,0,0,0,130,2,0,0,88,164,6,0,21,0,0,0,0,28,28,0,0,0,0,0,21,0,0,0,130,2,2,0,168,123,6,0,21,0,0,0,0,28,28,0,0,0,0,0,0,0,0,0,254,0,2,0,192,73,6,0,21,0,0,0,2,2,0,0,248,38,7,0,21,0,0,0,0,28,28,0,0,0,0,0,21,0,0,0,2,2,2,0,88,32,6,0,21,0,0,0,0,28,28,0,0,0,0,0,0,0,0,0,254,0,8,0,184,40,2,0,21,0,0,0,1,28,0,0,200,201,5,0,21,0,0,0,1,28,4,0,152,160,5,0,21,0,0,0,1,28,8,0,144,127,5,0,21,0,0,0,1,28,12,0,168,98,5,0,21,0,0,0,1,28,16,0,224,67,5,0,21,0,0,0,1,28,20,0,216,36,5,0,21,0,0,0,1,28,24,0,8,7,5,0,21,0,0,0,1,28,28,0,16,227,4,0,0,0,0,0,254,0,7,0,184,164,8,0,21,0,0,0,130,224,0,0,200,201,5,0,21,0,0,0,0,28,28,0,0,0,0,0,21,0,0,0,130,224,32,0,152,160,5,0,21,0,0,0,0,28,28,0,0,0,0,0,21,0,0,0,130,224,64,0,144,127,5,0,21,0,0,0,0,28,28,0,0,0,0,0,21,0,0,0,130,224,96,0,168,98,5,0,21,0,0,0,0,28,28,0,0,0,0,0,21,0,0,0,130,224,128,0,224,67,5,0,21,0,0,0,0,28,28,0,0,0,0,0,21,0,0,0,130,224,160,0,216,36,5,0,21,0,0,0,0,28,28,0,0,0,0,0,21,0,0,0,130,224,192,0,8,7,5,0,21,0,0,0,0,28,28,0,0,0,0,0,21,0,0,0,130,224,224,0,200,201,5,0,21,0,0,0,0,28,28,0,0,0,0,0,0,0,0,0,254,0,2,0,120,159,4,0,21,0,0,0,2,32,0,0,96,135,7,0,21,0,0,0,0,28,28,0,0,0,0,0,21,0,0,0,2,32,32,0,152,182,7,0,21,0,0,0,0,28,28,0,0,0,0,0,0,0,0,0,254,0,2,0,216,75,4,0,21,0,0,0,2,64,0,0,96,135,7,0,21,0,0,0,0,28,28,0,0,0,0,0,21,0,0,0,2,64,64,0,152,182,7,0,21,0,0,0,0,28,28,0,0,0,0,0,0,0,0,0,254,0,2,0,16,49,4,0,21,0,0,0,2,128,0,0,96,135,7,0,21,0,0,0,0,28,28,0,0,0,0,0,21,0,0,0,2,128,128,0,152,182,7,0,21,0,0,0,0,28,28,0,0,0,0,0,0,0,0,0,254,0,4,0,160,21,4,0,22,0,0,0,1,3,0,0,248,38,7,0,22,0,0,0,1,3,1,0,80,246,3,0,22,0,0,0,1,3,2,0,112,212,3,0,22,0,0,0,1,3,3,0,72,185,3,0,0,0,0,0,254,0,4,0,120,159,3,0,22,0,0,0,1,12,0,0,248,38,7,0,22,0,0,0,1,12,4,0,112,134,3,0,22,0,0,0,1,12,8,0,64,111,3,0,22,0,0,0,1,12,12,0,208,89,3,0,0,0,0,0,254,0,4,0,192,74,3,0,22,0,0,0,1,48,0,0,8,49,4,0,22,0,0,0,1,48,16,0,152,21,4,0,22,0,0,0,1,48,32,0,208,75,4,0,22,0,0,0,1,48,48,0,192,255,2,0,0,0,0,0,254,0,4,0,16,234,2,0,22,0,0,0,1,192,0,0,80,210,2,0,22,0,0,0,1,192,64,0,0,192,2,0,22,0,0,0,1,192,128,0,112,175,2,0,22,0,0,0,1,192,192,0,200,160,2,0,0,0,0,0,254,0,2,0,128,147,2,0,23,0,0,0,1,1,0,0,96,135,7,0,23,0,0,0,1,1,1,0,152,182,7,0])
.concat([0,0,0,0,254,0,2,0,200,135,2,0,23,0,0,0,1,2,0,0,152,182,7,0,23,0,0,0,1,2,2,0,96,135,7,0,0,0,0,0,254,0,2,0,80,123,2,0,23,0,0,0,1,4,0,0,248,108,2,0,23,0,0,0,1,4,4,0,136,98,2,0,0,0,0,0,254,0,2,0,104,82,2,0,23,0,0,0,1,8,0,0,136,98,2,0,23,0,0,0,1,8,8,0,248,108,2,0,0,0,0,0,254,0,2,0,112,69,2,0,23,0,0,0,1,16,0,0,96,135,7,0,23,0,0,0,1,16,16,0,152,182,7,0,0,0,0,0,254,0,2,0,48,56,2,0,23,0,0,0,2,32,0,0,248,108,2,0,21,0,0,0,0,28,28,0,0,0,0,0,23,0,0,0,2,32,32,0,136,98,2,0,21,0,0,0,0,28,28,0,0,0,0,0,0,0,0,0,254,0,2,0,192,40,2,0,23,0,0,0,2,64,0,0,248,108,2,0,21,0,0,0,0,28,28,0,0,0,0,0,23,0,0,0,2,64,64,0,136,98,2,0,21,0,0,0,0,28,28,0,0,0,0,0,0,0,0,0,254,0,2,0,184,30,2,0,23,0,0,0,2,128,0,0,248,108,2,0,21,0,0,0,0,28,28,0,0,0,0,0,23,0,0,0,2,128,128,0,136,98,2,0,21,0,0,0,0,28,28,0,0,0,0,0,0,0,0,0,253,0,26,0,48,45,3,0,24,0,0,0,1,31,0,0,248,10,2,0,24,0,0,0,1,31,1,0,24,4,2,0,24,0,0,0,1,31,2,0,8,234,2,0,24,0,0,0,1,31,3,0,160,236,1,0,24,0,0,0,1,31,4,0,176,224,1,0,24,0,0,0,1,31,5,0,224,209,1,0,24,0,0,0,1,31,6,0,80,198,1,0,24,0,0,0,1,31,7,0,136,189,1,0,24,0,0,0,1,31,8,0,32,182,1,0,24,0,0,0,1,31,9,0,200,174,1,0,24,0,0,0,1,31,10,0,64,167,1,0,24,0,0,0,1,31,11,0,40,160,1,0,24,0,0,0,1,31,12,0,216,149,1,0,24,0,0,0,1,31,13,0,152,140,1,0,24,0,0,0,1,31,14,0,72,126,1,0,24,0,0,0,1,31,15,0,40,112,1,0,24,0,0,0,1,31,16,0,64,101,1,0,24,0,0,0,1,31,17,0,24,92,1,0,24,0,0,0,1,31,18,0,160,85,1,0,24,0,0,0,1,31,19,0,48,77,1,0,24,0,0,0,1,31,20,0,224,70,1,0,24,0,0,0,1,31,21,0,80,65,1,0,24,0,0,0,1,31,22,0,40,58,1,0,24,0,0,0,1,31,23,0,56,50,1,0,24,0,0,0,1,31,24,0,232,41,1,0,24,0,0,0,1,31,25,0,224,32,1,0,98,100,49,95,51,46,57,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,144,167,46,234,1,0,16,1,98,100,49,95,49,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,220,43,159,78,1,0,16,1,98,100,49,95,50,46,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,205,127,97,64,1,0,16,1,98,100,49,95,52,98,46,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,50,205,126,164,2,0,16,1,99,117,115,54,48,45,54,48,97,49,46,109,99,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,42,168,110,7,2,0,16,1,98,100,49,95,53,46,51,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,238,127,107,112,3,0,32,0,98,100,49,95,56,46,52,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,16,7,187,176,4,0,32,0,98,100,49,95,55,46,52,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,201,190,126,13,4,0,32,0,98,100,49,95,54,46,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,150,8,218,229,4,0,32,0,98,100,49,95,57,46,56,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,204,154,162,135,5,0,32,0,98,100,49,95,49,48,46,56,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,12,210,182,114,5,0,32,0,98,100,49,95,49,49,46,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,156,175,118,48,5,0,32,0,98,100,49,95,49,50,46,56,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,163,9,76,139,5,0,32,0,98,100,49,45,49,46,49,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,198,235,120,13,6,0,32,0,98,100,49,45,50,46,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,31,36,247,3,6,0,32,0,50,53,57,45,112,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,139,127,163,136,1,0,16,1,50,53,57,45,115,49,112,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,45,251,80,187,2,0,32,0,50,53,57,45,99,49,112,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,68,158,145,227,3,0,32,0,50,53,57,45,99,50,112,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,32,163,245,186,3,0,32,0,50,53,57,45,99,51,112,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,87,33,229,200,3,0,32,0,50,53,57,45,99,52,112,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,96,142,250,105,3,0,32,0,50,53,57,45,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,233,142,102,133,4,0,16,1,50,53,57,45,118,49,112,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,133,147,123,233,5,0,64,0,50,53,57,45,118,50,112,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,10,215,203,176,5,0,64,0,50,53,57,45,118,51,112,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,233,143,82,151,5,0,64,0,50,53,57,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,139,127,163,136,1,0,16,1,50,53,57,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,116,127,83,31,3,0,32,0,50,53,57,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,255,152,253,14,3,0,32,0,50,53,57,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,233,142,102,133,4,0,16,1,50,53,57,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,171,184,142,8,5,0,64,0,50,53,57,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,233,143,82,151,5,0,64,0,48,51,54,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,250,182,102,28,1,0,16,1,48,51,54,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,133,68,239,243,2,0,32,0,48,51,54,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,16,16,127,254,3,0,32,0,48,51,54,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,245,3,240,187,3,0,32,0,48,51,54,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,142,112,192,154,3,0,32,0,48,51,54,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,34,125,87,242,3,0,32,0,48,51,54,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,150,91,56,241,4,0,16,1,48,51,54,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,206,93,51,28,5,0,64,0,48,51,54,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,66,147,247,187,5,0,64,0,98,53,45,101,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,77,189,179,10,1,0,16,1,98,52,45,102,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,73,105,11,21,1,0,16,1,98,50,45,101,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,79,197,42,155,2,0,16,1,98,51,45,99,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,159,114,206,8,3,0,32,0,98,54,45,99,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,69,94,194,200,4,0,32,0,98,55,45,100,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,87,106,251,37,4,0,32,0,98,56,45,101,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,78,172,204,107,4,0,32,0,98,57,45,104,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,184,153,106,86,4,0,32,0,98,49,51,45,112,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,187,56,113,140,5,0,32,0,98,49,50,45,112,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,118,196,3,108,5,0,32,0,98,49,49,45,112,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,75,75,200,11,5,0,32,0,98,49,48,45,112,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,195,158,20,236,5,0,32,0,98,49,55,45,115,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,75,246,157,64,6,0,32,0,98,49,54,45,115,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,201,82,64,110,6,0,32,0,98,49,53,45,115,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,14,194,108,43,6,0,32,0,98,49,52,45,115,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,122,99,41,77,6,0,32,0,114,97,48,48,45,48,46,50,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,105,160,13,121,1,0,16,1,114,97,48,49,45,48,46,51,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,123,181,124,68,1,0,16,1,109,98,122,45,48,48,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,4,213,152,16,2,0,32,0,109,98,122,45,48,49,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,92,30,184,25,2,0,32,0,109,98,122,45,48,50,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,161,176,210,43,3,0,32,0,109,98,122,45,48,51,46,49,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,105,133,129,46,4,0,32,0,109,98,122,45,48,52,46,49,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,177,175,189,103,4,0,32,0,109,98,122,45,48,51,46,49,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,105,133,129,46,5,0,32,0,109,98,122,45,48,52,46,49,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,177,175,189,103,5,0,32,0,109,98,122,45,48,53,46,49,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,166,29,124,148,6,0,64,0,109,98,122,45,48,54,46,49,57,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,53,198,56,74,6,0,64,0,103,97,108,49,54,118,56,98,46,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,0,0,0,7,0,0,16,103,97,108,49,54,118,56,98,46,54,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,0,0,0,7,0,0,16,103,97,108,49,54,118,56,98,46,49,50,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,0,0,0,7,0,0,16,48,55,49,45,112,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,125,25,135,118,1,0,16,1,48,55,49,45,115,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,84,241,229,68,2,0,32,0,48,55,49,45,99,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,122,74,216,35,3,0,32,0,48,55,49,45,99,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,72,98,123,206,3,0,32,0,48,55,49,45,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,173,57,167,109,4,0,16,1,48,55,49,45,118,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,176,255,254,80,5,0,64,0,48,52,46,49,48,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,204,173,74,169,1,0,16,1,48,54,46,49,51,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,189,128,205,57,1,0,16,1,48,53,46,49,50,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,201,206,177,6,1,0,16,1,48,50,46,49,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,23,46,122,16,2,0,16,1,48,49,46,54,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,88,210,229,193,3,0,16,1,48,51,46,56,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,62,136,181,239,4,0,32,0,49,51,46,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,5,243,95,155,5,0,32,0,48,57,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,85,51,50,8,5,0,32,0,49,50,46,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,186,97,82,109,5,0,32,0,48,56,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,84,159,61,161,5,0,32,0,49,49,46,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,139,29,145,162,5,0,32,0,48,55,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,50,141,231,205,5,0,32,0,49,52,46,56,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,113,38,172,68,5,0,32,0,49,48,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,203,23,167,177,5,0,32,0,49,56,46,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,23,106,135,60,6,0,32,0,49,54,46,51,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,172,243,31,75,6,0,32,0,49,55,46,53,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,239,67,181,78,6,0,32,0,49,53,46,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,127,222,65,128,6,0,32,0,50,50,46,55,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,34,139,170,189,6,0,32,0,50,48,46,51,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,89,48,110,86,6,0,32,0,50,49,46,53,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,170,89,16,48,6,0,32,0,49,57,46,50,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,236,133,4,160,6,0,32,0,50,53,46,49,53,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,48,158,13,35,7,0,32,0,50,52,46,49,51,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,36,64,53,166,7,0,32,0,50,51,46,57,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,246,62,169,192,8,0,32,0,116,98,98,95,50,98,112,114,46,55,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,152,204,107,217,0,0,0,8,116,98,98,95,49,98,112,114,46,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,157,250,82,80,0,0,0,8,97,118,103,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,197,122,234,15,1,0,16,1,97,118,95,48,54,97,46,49,51,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,44,113,26,73,1,0,16,1,97,118,95,48,53,46,49,50,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,66,75,33,154,1,0,16,1,48,50,46,49,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,23,46,122,16,2,0,16,1,48,49,46,54,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,88,210,229,193,3,0,16,1,48,51,46,56,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,62,136,181,239,4,0,32,0,49,51,46,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,5,243,95,155,5,0,32,0,48,57,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,85,51,50,8,5,0,32,0,49,50,46,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,186,97,82,109,5,0,32,0,48,56,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,84,159,61,161,5,0,32,0,49,49,46,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,139,29,145,162,5,0,32,0,48,55,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,50,141,231,205,5,0,32,0,49,52,46,56,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,113,38,172,68,5,0,32,0,49,48,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,203,23,167,177,5,0,32,0,49,56,46,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,23,106,135,60,6,0,32,0,49,54,46,51,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,172,243,31,75,6,0,32,0,49,55,46,53,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,239,67,181,78,6,0,32,0,49,53,46,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,127,222,65,128,6,0,32,0,50,50,46,55,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,34,139,170,189,6,0,32,0,50,48,46,51,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,89,48,110,86,6,0,32,0,50,49,46,53,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,170,89,16,48,6,0,32,0,49,57,46,50,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,236,133,4,160,6,0,32,0,50,53,46,49,53,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,48,158,13,35,7,0,32,0,50,52,46,49,51,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,36,64,53,166,7,0,32,0,50,51,46,57,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,246,62,169,192,8,0,32,0,116,98,98,95,50,98,112,114,46,55,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,152,204,107,217,0,0,0,8,116,98,98,95,49,98,112,114,46,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,157,250,82,80,0,0,0,8,98,98,109,45,99,112,48,100,46,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,121,4,12,134,1,0,16,1,98,98,109,45,99,112,49,100,46,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,116,191,87,190,1,0,16,1,98,98,109,45,115,112,46,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,205,144,16,37,2,0,16,1,98,98,109,45,99,48,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,25,32,93,105,3,0,32,0,98,98,109,45,99,49,46,54,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,188,139,124,76,3,0,32,0,98,98,109,45,99,50,46,54,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,6,212,0,7,3,0,32,0,98,98,109,45,99,51,46,54,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,175,19,54,60,3,0,32,0,98,98,109,45,118,48,46,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,254,3,168,15,4,0,64,0,119,116,95,97,45,52,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,133,129,151,247,1,0,16,1,119,116,95,97,45,52,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,11,149,169,12,1,0,16,1,119,116,95,97,45,52,106,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,101,188,173,27,1,0,16,1,119,116,95,97,45,52,107,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,117,31,52,90,1,0,16,1,119,116,95,97,45,52,109,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,213,167,248,193,1,0,16,1,119,116,95,97,45,52,110,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,210,247,18,178,1,0,16,1,119,116,95,97,45,52,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,30,54,67,61,2,0,16,1,119,116,95,98,45,53,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,67,223,69,254,3,0,32,0,119,116,95,98,45,53,102,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,255,126,161,135,3,0,32,0,119,116,95,98,45,53,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,82,196,34,218,4,0,32,0,119,116,95,98,45,53,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,31,90,178,79,4,0,32,0,119,116,95,98,45,53,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,4,38,190,117,4,0,32,0,119,116,95,97,45,51,106,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,143,163,12,179,5,0,32,0,119,116,95,97,45,51,107,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,115,235,119,154,5,0,32,0,119,116,95,97,45,51,109,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,174,104,228,231,5,0,32,0,119,116,95,97,45,51,110,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,169,209,65,7,5,0,32,0,119,116,95,97,45,51,112,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,98,243,153,114,5,0,32,0,119,116,95,97,45,51,115,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,13,213,55,155,5,0,32,0,119,116,95,97,45,54,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,155,226,221,165,6,0,64,0,119,116,95,97,45,53,115,45,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,231,80,25,4,7,0,32,0,119,116,95,97,45,53,114,45,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,37,191,4,188,7,0,32,0,119,116,95,97,45,53,112,45,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,25,154,129,237,7,0,32,0,119,116,95,98,45,57,108,45,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,68,135,114,210,7,0,32,0,116,101,116,99,107,116,108,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,74,31,253,154,1,0,16,1,49,51,54,48,54,54,45,49,49,48,51,46,51,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,147,127,42,236,2,0,32,0,116,101,116,114,105,115,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,246,21,77,148,1,0,16,1,116,101,116,114,105,115,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,88,114,78,92,2,0,32,0,116,101,116,114,105,115,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,11,140,97,38,0,0,0,8,100,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,7,177,202,43,1,0,16,1,49,51,54,48,54,54,45,49,49,48,49,46,51,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,159,147,161,132,2,0,32,0,112,103,109,51,46,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,113,82,107,44,1,0,16,1,112,103,109,50,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,148,134,143,1,0,16,1,112,103,109,49,46,117,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,15,15,4,10,1,0,16,1,112,103,109,48,46,117,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,216,233,113,155,1,0,16,1,115,114,111,109,46,117,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,137,163,141,54,2,0,16,1,111,112,109,46,117,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,228,91,176,49,3,0,64,0,98,103,49,49,49,51,46,117,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,230,87,134,95,4,0,32,0,98,103,49,48,49,50,46,117,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,240,154,251,227,4,0,32,0,98,103,50,49,50,51,46,117,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,107,184,235,196,5,0,32,0,98,103,50,48,50,50,46,117])
.concat([50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,82,218,110,244,5,0,32,0,109,97,112,46,117,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,197,157,23,189,6,0,32,0,115,112,48,49,46,117,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,99,164,222,94,7,0,32,0,115,112,50,51,46,117,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,222,176,177,145,7,0,32,0,115,112,52,53,46,117,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,172,154,198,150,7,0,32,0,115,112,54,55,46,117,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,191,131,61,124,7,0,32,0,115,112,56,57,46,117,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,248,20,30,203,7,0,32,0,115,112,97,98,46,117,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,141,96,164,229,7,0,32,0,115,112,99,100,46,117,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,50,190,191,153,7,0,32,0,115,112,101,102,46,117,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,204,153,199,201,7,0,32,0,112,103,109,51,46,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,88,151,62,5,1,0,16,1,112,103,109,50,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,202,86,182,22,1,0,16,1,112,103,109,49,46,117,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,68,16,53,1,0,16,1,112,103,109,48,46,117,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,151,84,97,104,1,0,16,1,115,114,111,109,46,117,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,137,235,29,187,2,0,16,1,112,99,109,46,117,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,90,34,114,172,3,0,64,0,98,103,49,49,49,51,46,117,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,103,130,51,148,4,0,32,0,98,103,49,48,49,50,46,117,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,161,160,23,215,4,0,32,0,98,103,50,49,50,51,46,117,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,105,196,207,74,5,0,32,0,98,103,50,48,50,50,46,117,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,211,44,49,238,5,0,32,0,109,97,112,46,117,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,94,21,129,230,6,0,32,0,115,112,50,51,46,117,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,235,146,244,125,7,0,32,0,115,112,52,53,46,117,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,42,244,144,24,7,0,32,0,115,112,54,55,46,117,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,240,30,143,164,7,0,32,0,115,112,56,57,46,117,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,98,67,2,107,7,0,32,0,115,112,97,98,46,117,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,140,45,61,128,7,0,32,0,115,112,99,100,46,117,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,110,194,229,66,7,0,32,0,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,105,21,30,198,1,0,16,1,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,56,99,161,192,1,0,16,1,115,106,50,48,49,45,110,119,46,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,66,202,100,90,1,0,16,1,57,46,56,113,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,18,226,103,135,2,0,16,1,56,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,14,22,203,155,3,0,32,0,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,66,252,30,126,3,0,32,0,52,46,52,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,211,54,99,170,4,0,32,0,51,46,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,181,134,45,126,4,0,32,0,50,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,56,73,37,195,5,0,32,0,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,240,133,245,27,5,0,32,0,115,106,52,48,50,45,110,119,46,56,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,6,61,211,182,6,0,32,0,115,106,52,48,51,45,110,119,46,55,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,86,63,20,7,6,0,32,0,115,106,52,48,52,45,110,119,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,40,65,19,143,7,0,32,0,115,106,52,48,53,45,110,119,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,153,22,216,111,7,0,32,0,115,106,52,48,54,45,110,119,46,55,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,230,51,78,99,7,0,32,0,115,106,52,48,55,45,110,119,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,6,255,102,92,7,0,32,0,115,106,52,48,56,45,110,119,46,55,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,161,30,59,106,7,0,32,0,115,106,52,48,57,45,110,119,46,55,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,19,66,118,216,7,0,32,0,115,106,52,48,49,45,110,119,46,49,48,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,89,171,223,37,8,0,16,1,105,99,56,49,46,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,111,43,10,110,1,0,16,1,105,99,56,50,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,86,221,151,90,1,0,16,1,49,45,105,99,51,51,46,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,186,116,139,3,3,0,32,0,50,45,105,99,51,52,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,153,225,250,113,3,0,32,0,51,45,105,99,51,53,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,226,116,99,199,3,0,32,0,105,99,55,51,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,137,178,248,10,4,0,32,0,105,99,55,52,46,49,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,251,2,176,171,4,0,32,0,105,99,55,53,46,49,51,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,119,194,198,167,4,0,32,0,11,0,0,0,255,255,63,0,0,0,0,0,0,0,0,0,254,0,2,0,104,159,3,0,11,0,0,0,1,1,1,0,56,111,3,0,11,0,0,0,1,1,0,0,104,134,3,0,0,0,0,0,254,0,2,0,144,212,8,0,11,0,0,0,1,2,2,0,96,135,7,0,11,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,72,202,5,0,11,0,0,0,1,8,8,0,80,246,3,0,11,0,0,0,1,8,0,0,112,212,3,0,0,0,0,0,254,0,2,0,64,37,5,0,11,0,0,0,1,16,16,0,216,138,8,0,11,0,0,0,1,16,0,0,112,133,8,0,0,0,0,0,254,0,2,0,128,129,4,0,11,0,0,0,1,32,32,0,208,75,4,0,11,0,0,0,1,32,0,0,8,49,4,0,0,0,0,0,254,0,2,0,32,4,2,0,11,0,0,0,1,64,0,0,104,236,7,0,11,0,0,0,1,64,64,0,128,230,7,0,0,0,0,0,254,0,2,0,200,30,2,0,11,0,0,0,1,128,0,0,120,97,1,0,11,0,0,0,1,128,128,0,96,19,1,0,97,55,53,45,48,49,45,49,46,105,99,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,176,163,205,91,1,0,16,1,97,55,53,45,49,48,46,105,99,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,21,158,118,161,1,0,16,1,97,55,53,45,48,54,46,105,99,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,182,119,93,81,2,0,16,1,97,55,53,45,48,51,46,105,99,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,186,116,139,3,3,0,32,0,97,55,53,45,48,52,46,105,99,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,153,225,250,113,3,0,32,0,97,55,53,45,48,53,46,105,99,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,226,116,99,199,3,0,32,0,97,55,53,45,48,55,46,105,99,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,137,178,248,10,4,0,32,0,97,55,53,45,48,56,46,105,99,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,251,2,176,171,4,0,32,0,97,55,53,45,48,57,46,105,99,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,119,194,198,167,4,0,32,0,97,55,53,45,49,57,46,105,99,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,215,55,173,211,1,0,16,1,97,55,53,45,49,56,46,105,99,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,1,131,192,205,1,0,16,1,97,55,53,45,50,48,46,105,99,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,71,142,81,222,2,0,16,1,97,55,53,45,48,51,46,105,99,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,186,116,139,3,3,0,32,0,97,55,53,45,48,52,46,105,99,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,153,225,250,113,3,0,32,0,97,55,53,45,48,53,46,105,99,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,226,116,99,199,3,0,32,0,97,55,53,45,48,55,46,105,99,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,137,178,248,10,4,0,32,0,97,55,53,45,48,56,46,105,99,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,251,2,176,171,4,0,32,0,97,55,53,45,48,57,46,105,99,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,119,194,198,167,4,0,32,0,97,55,53,45,50,49,46,105,99,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,252,85,4,191,1,0,16,1,97,55,53,45,50,50,46,105,99,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,211,136,38,58,1,0,16,1,97,55,53,45,50,51,46,105,99,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,246,190,74,10,2,0,16,1,97,55,53,45,48,51,46,105,99,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,186,116,139,3,3,0,32,0,97,55,53,45,48,52,46,105,99,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,153,225,250,113,3,0,32,0,97,55,53,45,48,53,46,105,99,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,226,116,99,199,3,0,32,0,97,55,53,45,48,55,46,105,99,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,137,178,248,10,4,0,32,0,97,55,53,45,48,56,46,105,99,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,251,2,176,171,4,0,32,0,97,55,53,45,48,57,46,105,99,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,119,194,198,167,4,0,32,0,11,0,0,0,255,255,127,0,0,0,0,0,0,0,0,0,254,0,2,0,104,159,3,0,11,0,0,0,1,1,1,0,56,111,3,0,11,0,0,0,1,1,0,0,104,134,3,0,0,0,0,0,254,0,2,0,144,212,8,0,11,0,0,0,1,2,2,0,96,135,7,0,11,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,72,202,5,0,11,0,0,0,1,8,8,0,80,246,3,0,11,0,0,0,1,8,0,0,112,212,3,0,0,0,0,0,254,0,2,0,64,37,5,0,11,0,0,0,1,16,16,0,96,68,8,0,11,0,0,0,1,16,0,0,224,64,8,0,0,0,0,0,254,0,2,0,128,129,4,0,11,0,0,0,1,32,32,0,8,49,4,0,11,0,0,0,1,32,0,0,72,246,3,0,0,0,0,0,254,0,2,0,32,4,2,0,11,0,0,0,1,64,64,0,128,230,7,0,11,0,0,0,1,64,0,0,184,164,6,0,0,0,0,0,254,0,2,0,200,30,2,0,11,0,0,0,1,128,0,0,120,97,1,0,11,0,0,0,1,128,128,0,96,19,1,0,98,48,56,95,48,53,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,157,223,110,19,1,0,16,1,98,48,56,95,49,51,46,51,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,241,94,3,232,2,0,16,1,97,114,107,50,56,55,52,50,46,51,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,3,0,0,16,98,48,56,45,48,49,46,49,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,180,134,204,44,4,0,32,0,98,48,56,45,48,50,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,95,152,106,5,4,0,32,0,98,48,56,45,48,51,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,95,121,74,39,4,0,32,0,98,48,56,45,48,52,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,3,247,84,151,4,0,32,0,98,48,56,45,48,56,46,49,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,217,235,247,164,5,0,32,0,98,48,56,45,48,55,46,49,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,247,217,52,234,5,0,32,0,98,48,56,95,49,49,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,49,82,85,153,1,0,16,1,98,48,56,95,49,50,46,51,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,125,226,132,220,2,0,16,1,97,114,107,50,56,55,52,50,46,51,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,3,0,0,16,98,48,56,45,48,49,46,49,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,180,134,204,44,4,0,32,0,98,48,56,45,48,50,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,95,152,106,5,4,0,32,0,98,48,56,45,48,51,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,95,121,74,39,4,0,32,0,98,48,56,45,48,52,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,3,247,84,151,4,0,32,0,98,48,56,45,48,56,46,49,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,217,235,247,164,5,0,32,0,98,48,56,45,48,55,46,49,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,247,217,52,234,5,0,32,0,98,48,56,95,48,53,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,157,223,110,19,1,0,16,1,98,48,56,95,48,54,46,51,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,12,212,252,173,2,0,16,1,97,114,107,50,56,55,52,50,46,51,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,3,0,0,16,98,48,56,45,48,49,46,49,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,180,134,204,44,4,0,32,0,98,48,56,45,48,50,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,95,152,106,5,4,0,32,0,98,48,56,45,48,51,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,95,121,74,39,4,0,32,0,98,48,56,45,48,52,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,3,247,84,151,4,0,32,0,98,48,56,45,48,56,46,49,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,217,235,247,164,5,0,32,0,98,48,56,45,48,55,46,49,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,247,217,52,234,5,0,32,0,98,111,111,116,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,176,223,71,56,1,0,16,1,98,48,56,95,49,51,46,51,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,241,94,3,232,2,0,16,1,97,114,107,50,56,55,52,50,46,51,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,3,0,0,16,98,48,56,45,48,49,46,49,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,180,134,204,44,4,0,32,0,98,48,56,45,48,50,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,95,152,106,5,4,0,32,0,98,48,56,45,48,51,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,95,121,74,39,4,0,32,0,98,48,56,45,48,52,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,3,247,84,151,4,0,32,0,98,48,56,45,48,56,46,49,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,217,235,247,164,5,0,32,0,98,48,56,45,48,55,46,49,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,247,217,52,234,5,0,32,0,101,49,46,54,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,114,43,79,221,1,0,16,1,101,50,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,235,60,195,187,1,0,16,1,97,55,53,45,48,54,46,105,99,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,182,119,93,81,2,0,16,1,97,55,53,45,48,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,186,116,139,3,3,0,32,0,97,55,53,45,48,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,153,225,250,113,3,0,32,0,97,55,53,45,48,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,226,116,99,199,3,0,32,0,97,55,53,45,48,55,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,137,178,248,10,4,0,32,0,97,55,53,45,48,56,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,251,2,176,171,4,0,32,0,97,55,53,45,48,57,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,119,194,198,167,4,0,32,0,54,56,55,48,53,112,51,46,54,105,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,251,140,154,56,0,0,16,8,97,114,107,45,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,222,21,224,11,1,0,16,1,97,114,107,103,99,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,84,71,13,159,1,0,16,1,97,55,53,45,48,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,186,116,139,3,3,0,32,0,97,55,53,45,48,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,153,225,250,113,3,0,32,0,97,55,53,45,48,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,226,116,99,199,3,0,32,0,97,55,53,45,48,55,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,137,178,248,10,4,0,32,0,97,55,53,45,48,56,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,251,2,176,171,4,0,32,0,97,55,53,45,48,57,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,119,194,198,167,4,0,32,0,98,108,111,99,107,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,225,103,230,91,1,0,16,1,98,108,111,99,107,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,241,62,136,79,1,0,16,1,97,55,53,45,48,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,186,116,139,3,3,0,32,0,97,55,53,45,48,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,153,225,250,113,3,0,32,0,97,55,53,45,48,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,226,116,99,199,3,0,32,0,97,55,53,45,48,55,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,137,178,248,10,4,0,32,0,97,55,53,45,48,56,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,251,2,176,171,4,0,32,0,97,55,53,45,48,57,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,119,194,198,167,4,0,32,0,97,55,53,45,50,55,46,105,99,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,245,250,184,227,1,0,16,1,97,55,53,45,50,56,46,105,99,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,77,202,106,50,1,0,16,1,97,55,53,45,51,50,46,105,99,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,89,149,36,211,2,0,16,1,97,55,53,45,50,57,46,105,99,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,207,163,222,93,3,0,32,0,97,55,53,45,51,48,46,105,99,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,133,46,207,95,3,0,32,0,97,55,53,45,51,49,46,105,99,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,146,177,118,123,3,0,32,0,97,55,53,45,51,51,46,105,99,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,129,60,191,180,4,0,32,0,97,55,53,45,51,52,46,105,99,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,3,168,133,222,4,0,32,0,97,55,53,45,51,53,46,105,99,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,59,253,172,56,4,0,32,0,105,99,56,49,45,118,46,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,111,44,78,21,1,0,16,1,105,99,56,50,45,119,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,250,206,168,79,1,0,16,1,49,45,105,99,51,51,46,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,186,116,139,3,3,0,32,0,50,45,105,99,51,52,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,153,225,250,113,3,0,32,0,51,45,105,99,51,53,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,226,116,99,199,3,0,32,0,105,99,55,51,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,137,178,248,10,4,0,32,0,105,99,55,52,46,49,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,251,2,176,171,4,0,32,0,105,99,55,53,46,49,51,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,119,194,198,167,4,0,32,0,97,55,53,45,48,49,45,49,46,105,99,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,176,163,205,91,1,0,16,1,97,55,53,45,49,49,46,105,99,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,145,113,253,234,1,0,16,1,97,55,53,45,48,54,46,105,99,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,182,119,93,81,2,0,16,1,97,55,53,45,48,51,46,105,99,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,186,116,139,3,3,0,32,0,97,55,53,45,48,52,46,105,99,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,153,225,250,113,3,0,32,0,97,55,53,45,48,53,46,105,99,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,226,116,99,199,3,0,32,0,97,55,53,45,48,55,46,105,99,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,137,178,248,10,4,0,32,0,97,55,53,45,48,56,46,105,99,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,251,2,176,171,4,0,32,0,97,55,53,45,48,57,46,105,99,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,119,194,198,167,4,0,32,0,97,114,107,97,110,111,105,100,49,95,54,56,55,48,53,112,51,46,105,99,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,216,226,104,27,0,0,16,8,97,114,107,97,110,111,105,100,95,109,99,117,46,105,99,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,10,181,68,78,0,0,16,8,97,114,107,97,110,111,105,100,95,54,56,55,48,53,112,53,46,105,99,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,71,54,232,11,0,0,16,8,11,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,104,159,3,0,11,0,0,0,1,1,1,0,56,111,3,0,11,0,0,0,1,1,0,0,104,134,3,0,0,0,0,0,254,0,2,0,144,212,8,0,11,0,0,0,1,2,2,0,96,135,7,0,11,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,72,202,5,0,11,0,0,0,1,8,8,0,80,246,3,0,11,0,0,0,1,8,0,0,112,212,3,0,0,0,0,0,254,0,2,0,64,37,5,0,11,0,0,0,1,16,16,0,96,68,8,0,11,0,0,0,1,16,0,0,224,64,8,0,0,0,0,0,254,0,2,0,128,129,4,0,11,0,0,0,1,32,32,0,8,49,4,0,11,0,0,0,1,32,0,0,72,246,3,0,0,0,0,0,254,0,4,0,32,4,2,0,11,0,0,0,1,192,64,0,104,236,7,0,11,0,0,0,1,192,192,0,128,230,7,0,11,0,0,0,1,192,128,0,184,164,6,0,11,0,0,0,1,192,0,0,32,242,5,0,0,0,0,0,49,46,56,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,150,185,110,189,1,0,16,1,50,46,56,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,82,228,219,41,1,0,16,1,97,55,53,45,48,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,186,116,139,3,3,0,32,0,97,55,53,45,48,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0])
.concat([153,225,250,113,3,0,32,0,97,55,53,45,48,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,226,116,99,199,3,0,32,0,97,55,53,45,48,55,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,137,178,248,10,4,0,32,0,97,55,53,45,48,56,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,251,2,176,171,4,0,32,0,97,55,53,45,48,57,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,119,194,198,167,4,0,32,0,11,0,0,0,255,255,127,0,0,0,0,0,0,0,0,0,254,0,2,0,176,76,8,0,11,0,0,0,1,1,1,0,0,71,8,0,11,0,0,0,1,1,0,0,248,38,7,0,0,0,0,0,254,0,2,0,144,212,8,0,11,0,0,0,1,2,2,0,96,135,7,0,11,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,72,202,5,0,11,0,0,0,1,8,8,0,80,246,3,0,11,0,0,0,1,8,0,0,112,212,3,0,0,0,0,0,254,0,2,0,64,37,5,0,11,0,0,0,1,16,16,0,96,68,8,0,11,0,0,0,1,16,0,0,224,64,8,0,0,0,0,0,254,0,2,0,128,129,4,0,11,0,0,0,1,32,32,0,8,49,4,0,11,0,0,0,1,32,0,0,72,246,3,0,0,0,0,0,254,0,2,0,32,4,2,0,11,0,0,0,1,64,64,0,128,230,7,0,11,0,0,0,1,64,0,0,184,164,6,0,0,0,0,0,254,0,2,0,200,30,2,0,11,0,0,0,1,128,0,0,120,97,1,0,11,0,0,0,1,128,128,0,96,19,1,0,97,45,49,46,55,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,114,43,79,221,1,0,16,1,50,112,97,108,108,105,110,101,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,171,98,107,237,1,0,16,1,97,55,53,45,48,54,46,105,99,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,182,119,93,81,2,0,16,1,97,45,51,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,186,116,139,3,3,0,32,0,97,45,52,46,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,153,225,250,113,3,0,32,0,97,45,53,46,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,226,116,99,199,3,0,32,0,97,55,53,45,48,55,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,137,178,248,10,4,0,32,0,97,55,53,45,48,56,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,251,2,176,171,4,0,32,0,97,55,53,45,48,57,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,119,194,198,167,4,0,32,0,11,0,0,0,255,255,127,0,0,0,0,0,0,0,0,0,254,0,2,0,104,159,3,0,11,0,0,0,1,1,1,0,56,111,3,0,11,0,0,0,1,1,0,0,104,134,3,0,0,0,0,0,254,0,2,0,144,212,8,0,11,0,0,0,1,2,2,0,96,135,7,0,11,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,72,202,5,0,11,0,0,0,1,8,8,0,80,246,3,0,11,0,0,0,1,8,0,0,112,212,3,0,0,0,0,0,254,0,2,0,64,37,5,0,11,0,0,0,1,16,16,0,32,81,8,0,11,0,0,0,1,16,0,0,112,133,8,0,0,0,0,0,254,0,2,0,128,129,4,0,11,0,0,0,1,32,32,0,192,255,2,0,11,0,0,0,1,32,0,0,208,75,4,0,0,0,0,0,254,0,2,0,32,4,2,0,11,0,0,0,1,64,64,0,128,230,7,0,11,0,0,0,1,64,0,0,184,164,6,0,0,0,0,0,254,0,2,0,200,30,2,0,11,0,0,0,1,128,0,0,120,97,1,0,11,0,0,0,1,128,128,0,96,19,1,0,117,107,45,48,48,49,45,48,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,44,138,135,238,1,0,16,1,117,107,45,48,48,49,45,48,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,227,180,43,144,1,0,16,1,117,107,54,48,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,74,58,199,72,2,0,16,1,117,107,48,48,49,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,70,87,199,17,11,0,32,0,117,107,48,48,49,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,199,102,177,1,11,0,32,0,117,107,48,48,49,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,163,11,214,120,11,0,32,0,117,107,48,48,49,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,224,138,116,180,11,0,32,0,117,107,45,48,48,49,45,48,49,48,45,116,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,35,248,226,193,4,0,32,0,117,107,45,48,48,49,45,48,49,49,45,116,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,106,229,223,9,4,0,32,0,117,107,45,48,48,49,45,48,49,50,45,116,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,133,64,138,129,4,0,32,0,117,107,45,48,48,49,45,48,49,51,45,116,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,100,161,31,119,4,0,32,0,117,107,45,48,48,49,45,48,49,53,45,116,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,221,245,157,206,6,0,64,0,117,107,45,48,48,49,45,48,49,52,45,116,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,74,132,107,1,6,0,64,0,116,118,103,45,56,55,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,177,166,233,81,0,0,16,1,116,118,103,45,56,56,46,105,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,171,193,220,28,0,0,16,1,116,118,103,45,56,57,46,105,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,160,250,183,183,0,0,16,1,116,118,103,45,57,48,46,105,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,97,217,222,219,0,0,16,1,116,118,103,45,57,49,46,105,99,56,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,34,120,99,196,0,0,32,0,116,118,103,45,57,50,46,105,99,56,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,109,134,198,247,0,0,32,0,116,118,103,45,57,51,46,105,99,56,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,141,212,172,113,0,0,32,0,116,118,103,45,57,52,46,105,99,56,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,154,11,22,130,0,0,32,0,115,117,110,45,56,50,49,50,46,105,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,30,97,105,136,0,0,0,8,97,113,117,97,114,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,161,9,69,52,1,0,16,1,97,113,117,97,114,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,225,91,85,250,2,0,16,1,97,113,117,97,114,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,172,246,93,87,3,0,32,0,97,113,117,97,114,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,70,177,101,144,3,0,32,0,97,113,117,97,114,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,5,27,7,170,4,0,32,0,97,113,117,97,114,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,60,139,117,20,5,0,32,0,97,113,117,97,114,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,196,32,85,145,6,0,32,0,97,113,117,97,114,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,130,43,107,185,6,0,32,0,97,113,117,97,114,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,49,245,74,154,7,0,64,0,49,49,52,50,56,46,99,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,210,172,218,144,1,0,16,1,49,49,52,50,52,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,246,151,89,181,1,0,16,1,49,49,52,50,53,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,222,89,147,41,1,0,16,1,49,49,52,50,54,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,211,139,173,95,1,0,16,1,49,49,52,50,55,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,116,12,146,239,1,0,16,1,49,49,52,50,57,46,100,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,102,10,165,12,2,0,16,1,49,49,52,52,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,112,36,5,69,3,0,32,0,49,49,52,52,56,46,104,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,38,182,218,5,4,0,32,0,49,49,52,52,55,46,102,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,179,197,175,179,4,0,32,0,49,49,52,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,40,182,32,165,5,0,32,0,49,49,52,51,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,22,178,154,70,5,0,32,0,49,49,52,51,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,69,194,248,176,5,0,32,0,49,49,52,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,245,129,222,203,5,0,32,0,49,49,52,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,20,164,63,182,5,0,32,0,49,49,52,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,123,116,220,0,5,0,32,0,49,49,52,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,175,37,32,172,5,0,32,0,49,49,52,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,158,248,64,214,5,0,32,0,49,49,52,52,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,40,182,32,165,6,0,32,0,49,49,52,52,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,22,178,154,70,6,0,32,0,49,49,52,52,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,69,194,248,176,6,0,32,0,49,49,52,52,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,245,129,222,203,6,0,32,0,49,49,52,52,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,20,164,63,182,6,0,32,0,49,49,52,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,123,116,220,0,6,0,32,0,49,49,52,51,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,175,37,32,172,6,0,32,0,49,49,52,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,158,248,64,214,6,0,32,0,54,51,115,48,56,49,110,46,117,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,39,134,185,54,7,0,0,8,48,52,57,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,162,125,133,59,1,0,16,1,48,52,57,45,112,50,46,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,9,34,6,47,1,0,16,1,48,52,57,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,93,222,73,99,2,0,32,0,48,52,57,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,179,109,206,122,3,0,32,0,48,52,57,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,247,36,112,177,3,0,32,0,48,52,57,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,244,172,210,237,4,0,16,1,48,52,57,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,137,203,67,206,5,0,64,0,112,114,111,116,111,95,48,48,55,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,42,229,99,199,1,0,16,1,112,114,111,116,111,95,48,48,55,45,112,50,46,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,92,67,11,122,1,0,16,1,112,114,111,116,111,95,48,48,55,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,46,174,201,239,2,0,32,0,112,114,111,116,111,95,48,48,55,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,57,22,132,36,3,0,32,0,112,114,111,116,111,95,48,48,55,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,171,99,39,145,3,0,32,0,112,114,111,116,111,95,48,48,55,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,226,189,67,7,3,0,32,0,112,114,111,116,111,95,48,48,55,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,18,2,36,97,3,0,32,0,112,114,111,116,111,95,48,48,55,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,83,76,159,207,3,0,32,0,112,114,111,116,111,95,48,48,55,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,25,59,144,61,3,0,32,0,112,114,111,116,111,95,48,48,55,45,99,55,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,117,56,30,228,3,0,32,0,112,114,111,116,111,95,48,48,55,45,99,56,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,207,226,131,68,3,0,32,0,112,114,111,116,111,95,48,48,55,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,100,180,118,89,4,0,16,1,112,114,111,116,111,95,48,48,55,45,118,49,49,46,118,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,225,169,234,24,5,0,64,0,112,114,111,116,111,95,48,48,55,45,118,49,50,46,118,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,149,212,135,36,5,0,64,0,112,114,111,116,111,95,48,48,55,45,118,49,51,46,118,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,37,15,230,37,5,0,64,0,112,114,111,116,111,95,48,48,55,45,118,50,49,46,118,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,90,183,68,172,5,0,64,0,56,55,53,95,106,50,95,50,46,101,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,82,73,184,75,1,0,16,1,56,55,53,95,109,48,49,46,99,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,220,211,99,22,1,0,16,1,56,55,53,95,107,48,51,46,103,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,77,38,134,189,2,0,16,1,56,55,53,98,49,49,46,107,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,133,200,197,137,3,0,32,0,56,55,53,98,48,55,46,106,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,102,109,197,233,3,0,32,0,56,55,53,98,49,50,46,107,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,23,220,107,234,3,0,32,0,56,55,53,98,48,56,46,106,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,102,121,56,249,3,0,32,0,56,55,53,98,49,48,46,107,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,177,53,16,11,4,0,32,0,56,55,53,98,48,54,46,106,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,102,5,26,8,4,0,32,0,56,55,53,98,48,57,46,107,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,25,60,107,231,4,0,32,0,56,55,53,98,48,53,46,106,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,242,97,162,25,4,0,32,0,56,55,53,98,48,52,46,101,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,200,154,32,78,5,0,64,0,56,50,49,97,48,56,46,104,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,88,165,125,6,0,0,8,98,100,49,95,51,46,57,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,144,167,46,234,1,0,16,1,98,100,50,95,49,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,135,154,10,154,1,0,16,1,98,100,50,95,50,46,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,88,84,62,56,1,0,16,1,98,100,49,95,52,46,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,231,15,218,171,2,0,16,1,99,117,115,54,48,45,54,48,97,49,46,109,99,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,42,168,110,7,2,0,16,1,98,100,49,95,53,46,51,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,238,127,107,112,3,0,32,0,98,100,50,95,56,46,52,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,217,215,43,67,4,0,32,0,98,100,49,95,55,46,52,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,201,190,126,13,4,0,32,0,98,100,50,95,54,46,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,96,223,193,244,4,0,32,0,98,100,49,95,57,46,56,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,204,154,162,135,5,0,32,0,98,100,49,95,49,48,46,56,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,12,210,182,114,5,0,32,0,98,100,49,95,49,49,46,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,156,175,118,48,5,0,32,0,98,100,49,95,49,50,46,56,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,163,9,76,139,5,0,32,0,98,100,49,45,49,46,49,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,198,235,120,13,6,0,32,0,98,100,49,45,50,46,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,31,36,247,3,6,0,32,0,105,103,115,99,48,49,48,50,46,117,56,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,227,43,67,227,1,0,16,1,104,102,104,95,115,46,117,56,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,237,169,40,87,2,0,16,1,105,103,115,116,48,49,48,49,46,117,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,123,45,225,44,3,0,32,0,105,103,115,116,48,49,48,50,46,117,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,160,118,42,84,3,0,32,0,105,103,115,116,48,49,48,51,46,117,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,138,105,245,173,3,0,32,0,105,103,115,98,48,49,48,49,46,117,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,126,95,153,92,4,0,32,0,105,103,115,98,48,49,48,50,46,117,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,175,155,174,162,4,0,32,0,105,103,115,98,48,49,48,51,46,117,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,175,39,185,17,4,0,32,0,105,103,115,97,48,49,48,49,46,117,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,196,7,77,55,5,0,32,0,105,103,115,97,48,49,48,50,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,172,231,238,219,5,0,32,0,105,103,115,97,48,49,48,51,46,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,65,144,241,229,5,0,32,0,104,102,104,95,103,46,117,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,87,155,70,236,6,0,64,0,104,102,104,95,103,46,117,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,142,217,252,124,7,0,64,0,121,114,119,56,48,49,45,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,67,141,157,42,8,0,64,0,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,170,1,215,56,1,0,16,1,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,243,53,14,61,1,0,16,1,54,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,137,238,59,130,1,0,16,1,54,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,47,3,77,71,1,0,16,1,97,98,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,172,74,47,174,1,0,16,1,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,87,3,141,67,1,0,16,1,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,248,184,188,133,2,0,32,0,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,98,8,229,56,2,0,32,0,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,134,92,113,181,2,0,32,0,53,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,179,134,48,113,2,0,32,0,56,50,115,49,50,51,46,101,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,189,80,198,47,3,0,32,0,56,50,115,49,50,57,46,97,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,228,168,179,62,3,0,32,0,56,50,115,49,50,54,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,134,204,169,4,0,64,0,56,50,115,49,50,54,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,97,98,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,245,78,41,82,0,0,0,8,55,54,56,112,48,51,46,107,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,64,227,9,213,1,0,16,1,55,54,56,106,48,54,46,107,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,62,60,40,66,1,0,16,1,55,54,56,101,48,49,46,101,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,132,241,255,185,2,0,16,1,55,54,56,99,48,57,46,103,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,221,63,190,227,3,0,32,0,55,54,56,99,48,56,46,103,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,139,219,51,150,3,0,32,0,55,54,56,99,48,52,46,106,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,14,104,96,41,4,0,32,0,55,54,56,99,48,53,46,106,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,242,162,101,4,0,32,0,55,54,56,99,48,55,46,101,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,156,136,249,1,5,0,64,0,55,54,56,99,49,51,46,106,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,203,128,222,245,6,0,32,0,55,54,56,99,49,52,46,106,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,183,113,32,179,6,0,32,0,55,54,56,99,49,49,46,105,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,203,128,222,245,6,0,32,0,55,54,56,99,49,48,46,105,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,183,113,32,179,6,0,32,0,55,54,56,98,49,50,46,100,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,184,68,37,54,0,0,32,8,112,114,49,50,46,104,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,178,46,54,145,1,0,16,1,112,114,49,51,46,108,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,123,37,178,19,2,0,16,1,112,114,45,50,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,240,93,10,110,3,0,16,1,105,56,48,99,53,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,4,0,0,16,112,114,45,48,48,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,13,143,166,140,5,0,32,0,112,114,45,48,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,119,179,108,126,6,0,32,0,112,114,45,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,70,94,189,107,6,0,32,0,112,114,45,50,48,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,144,51,221,164,7,0,64,0,117,99,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,186,212,55,24,1,0,16,1,117,101,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,216,185,222,113,1,0,16,1,51,46,115,117,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,112,35,53,62,2,0,16,1,52,46,117,108,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,180,42,54,233,3,0,32,0,57,46,117,119,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,102,153,229,134,4,0,32,0,49,48,46,117,120,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,4,141,44,18,4,0,32,0,56,46,117,111,56,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,216,227,131,154,5,0,32,0,55,46,117,111,56,49,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,113,214,56,60,5,0,32,0,50,46,115,117,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,91,97,171,147,6,0,64,0,49,46,115,117,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,187,54,168,9,6,0,64,0,56,50,115,49,50,57,46,117,103,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,108,184,219,207,0,0,0,8,56,50,115,49,52,55,46,117,104,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,114,208,11,237,0,0,0,8,98,112,57,54,50,97,46,117,52,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,70,80,129,36,0,0,16,1,98,112,57,54,50,97,46,117,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,190,221,202,6,0,0,16,1,98,112,57,54,50,97,46,117,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,57,164,141,133,0,0,32,0,98,112,57,54,50,97,46,117,55,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,94,163,43,234,0,0,32,0,98,112,57,54,50,97,46,117,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,7,161,217,252,0,0,32,0,98,112,57,54,50,97,46,117,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,9,52,250,12,0,0,32,0,98,112,57,54,50,97,46,117,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,87,137,96,109,0,0,32,0,98,112,57,54,50,97,46,117,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,154,207,95,19,0,0,32,0,98,112,57,54,50,97,46,117,52,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,206,161,0,174,0,0,64,0,98,112,57,54,50,97,46,117,52,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,55,151,78,109,0,0,64,0,97,103,97,108,108,101,116,95,117,115,97,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,86,80,230,114,0,0,16,1,98,112,57,54,50,97,46,117,52,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,70,80,129,36,0,0,16,1,98,112,57,54,50,97,46,117,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,190,221,202,6,0,0,16,1,98,112,57,54,50,97,46,117,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,57,164,141,133,0,0,32,0,98,112,57,54,50,97,46,117,55,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,94,163,43,234,0,0,32,0,98,112,57,54,50,97,46,117,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,7,161,217,252,0,0,32,0,98,112,57,54,50,97,46,117,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,9,52,250,12,0,0,32,0,98,112,57,54,50,97,46,117,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,87,137,96,109,0,0,32,0,98,112,57,54,50,97,46,117,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,154,207,95,19,0,0,32,0,98,112,57,54,50,97,46,117,52,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,206,161,0,174,0,0,64,0,98,112,57,54,50,97,46,117,52,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,55,151,78,109,0,0,64,0,97,103,97,108,108,101,116,95,116,97,105,119,97,110,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,66,103,244,10,0,0,16,1,98,112,57,54,50,97,46,117,52,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,70,80,129,36,0,0,16,1,98,112,57,54,50,97,46,117,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,190,221,202,6,0,0,16,1,98,112,57,54,50,97,46,117,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,57,164,141,133,0,0,32,0,98,112,57,54,50,97,46,117,55,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,94,163,43,234,0,0,32,0,98,112,57,54,50,97,46,117,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,7,161,217,252,0,0,32,0,98,112,57,54,50,97,46,117,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,9,52,250,12,0,0,32,0,98,112,57,54,50,97,46,117,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,87,137,96,109,0,0,32,0,98,112,57,54,50,97,46,117,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,154,207,95,19,0,0,32,0,98,112,57,54,50,97,46,117,52,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,206,161,0,174,0,0,64,0,98,112,57,54,50,97,46,117,52,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,55,151,78,109,0,0,64,0,97,103,97,108,108,101,116,95,107,111,114,101,97,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,83,194,65,127,0,0,16,1,98,112,57,54,50,97,46,117,52,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,70,80,129,36,0,0,16,1,98,112,57,54,50,97,46,117,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,190,221,202,6,0,0,16,1,98,112,57,54,50,97,46,117,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,57,164,141,133,0,0,32,0,98,112,57,54,50,97,46,117,55,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,94,163,43,234,0,0,32,0,98,112,57,54,50,97,46,117,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,7,161,217,252,0,0,32,0,98,112,57,54,50,97,46,117,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,9,52,250,12,0,0,32,0,98,112,57,54,50,97,46,117,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,87,137,96,109,0,0,32,0,98,112,57,54,50,97,46,117,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,154,207,95,19,0,0,32,0,98,112,57,54,50,97,46,117,52,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,206,161,0,174,0,0,64,0,98,112,57,54,50,97,46,117,52,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,55,151,78,109,0,0,64,0,97,103,97,108,108,101,116,95,106,97,112,97,110,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,71,245,83,7,0,0,16,1,98,112,57,54,50,97,46,117,52,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,70,80,129,36,0,0,16,1,98,112,57,54,50,97,46,117,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,190,221,202,6,0,0,16,1,98,112,57,54,50,97,46,117,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,57,164,141,133,0,0,32,0,98,112,57,54,50,97,46,117,55,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,94,163,43,234,0,0,32,0,98,112,57,54,50,97,46,117,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,7,161,217,252,0,0,32,0,98,112,57,54,50,97,46,117,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,9,52,250,12,0,0,32,0,98,112,57,54,50,97,46,117,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,87,137,96,109,0,0,32,0,98,112,57,54,50,97,46,117,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,154,207,95,19,0,0,32,0,98,112,57,54,50,97,46,117,52,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,206,161,0,174,0,0,64,0,98,112,57,54,50,97,46,117,52,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,55,151,78,109,0,0,64,0,97,103,97,108,108,101,116,95,104,111,110,103,107,111,110,103,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,116,26,141,153,0,0,16,1,118,50,46,49,52,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,198,174,135,241,0,0,16,1,118,49,46,49,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,25,75,104,158,0,0,16,1,105,116,45,49,57,45,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,164,161,235,133,0,0,32,0,105,116,45,49,57,45,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,186,248,87,79,0,0,32,0,105,116,45,49,57,45,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,31,156,50,59,0,0,32,0,105,116,45,49,57,45,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,175,37,181,2,0,0,32,0,103,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,200,203,137,77,0,0,32,0,103,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,210,193,114,128,0,0,32,0,50,46,49,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,236,100,239,161,0,0,16,1,105,116,45,49,57,45,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,61,114,66,109,0,0,64,0,105,116,45,49,57,45,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,29,219,187,205,0,0,64,0,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,240,233,157,92,0,0,16,1,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,244,220,193,137,0,0,16,1,105,116,45,49,57,45,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,164,161,235,133,0,0,32,0,105,116,45,49,57,45,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,186,248,87,79,0,0,32,0,105,116,45,49,57,45,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,31,156,50,59,0,0,32,0,105,116,45,49,57,45,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,175,37,181,2,0,0,32,0,103,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,200,203,137,77,0,0,32,0,103,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,210,193,114,128,0,0,32,0,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,244,140,177,203,0,0,16,1,105,116,45,49,57,45,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,61,114,66,109,0,0,64,0,105,116,45,49,57,45,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,29,219,187,205,0,0,64,0,20,0,0,0,255,255,15,0,0,0,0,0,0,0,0,0,254,0,5,0,48,45,3,0,20,0,0,0,1,15,0,0,160,134,3,0,20,0,0,0,1,15,1,0,56,50,1,0,20,0,0,0,1,15,2,0,192,20,3,0,20,0,0,0,1,15,4,0,80,65,1,0,20,0,0,0,1,15,15,0,224,135,6,0,0,0,0,0,102,101,48,56,45,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,250,251,54,13,1,0,16,1,102,101,48,57,45,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,177,43,206,39,1,0,16,1,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,55,209,186,202,1,0,16,1,49,55,45,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,6,209,154,40,2,0,16,1,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,30,242,186,161,3,0,32,0,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,48,71,230,34,3,0,32,0,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,252,14,219,177,4,0,32,0,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,79,224,19,243,4,0,32,0,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,135,221,182,140,4,0,32,0,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,239,93,52,221,4,0,32,0,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,80,149,10,213,4,0,32,0,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,147,94,147,52,4,0,32,0,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,149,23,244,188,4,0,32,0,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,170,148,139,211,4,0,32,0,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,32,116,69,214,5,0,32,0,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,122,123,120,8,5,0,32,0,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,220,55,12,195,5,0,32,0,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,159,109,0,31,5,0,32,0,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,66,178,85,92,6,0,64,0,48,50,95,105,99,49,48,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,244,135,228,63,1,0,16,1,48,49,95,105,99,49,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,83,87,23,23,1,0,16,1,48,52,95,105,99,55,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,251,5,105,23,2,0,16,1,48,51,95,105,99,55,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,110,24,108,216,3,0,32,0,48,57,95,105,99,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,237,175,18,124,4,0,32,0,48,55,95,105,99,52,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,170,189,114,86,5,0,32,0,48,56,95,105,99,50,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,227,172,192,180,5,0,32,0,48,53,95,105,99,53,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,14,43,140,59,6,0,64,0,48,54,95,105,99,53,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,212,124,81,193,7,0,64,0,49,48,95,105,99,56,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,108,184,219,207,0,0,0,8,49,49,95,105,99,56,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,201,177,58,99,0,0,0,8,184,40,2,0,1,0,0,0,85,0,147,0,248,191,2,0,200,110,3,0,1,0,0,0,80,0,147,0,152,30,2,0,120,89,3,0,1,0,0,0,81,0,147,0,232,10,2,0,120,74,3,0,1,0,0,0,82,0,147,0,152,138,8,0,192,61,3,0,1,0,0,0,83,0,147,0,48,119,7,0,120,194,6,0,1,0,0,0,189,247,146,0,112,109,7,0,96,189,6,0,1,0,0,0,190,247,146,0,24,133,7,0,200,97,4,0,1,0,0,0,84,0,147,0,216,70,1,0,216,95,4,0,1,0,0,0,188,247,146,0,216,70,1,0,88,212,3,0,1,0,0,0,128,219,146,0,40,185,3,0,64,23,5,0,9,0,0,0,202,5,147,0,32,58,1,0,104,20,5,0,9,0,0,0,201,5,147,0,32,58,1,0,216,16,5,0,9,0,0,0,200,5,147,0,32,58,1,0,10,0,0,0,255,255,0,0,0,0,0,0,11,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,4,0,32,4,2,0,10,0,0,0,1,3,1,0,224,67,5,0,10,0,0,0,1,3,3,0,192,135,6,0,10,0,0,0,1,3,0,0,200,201,5,0,10,0,0,0,1,3,2,0,144,127,5,0,0,0,0,0,254,0,2,0,128,129,4,0,10,0,0,0,1,4,0,0,8,49,4,0,10,0,0,0,1,4,4,0,208,75,4,0,0,0,0,0,254,0,2,0,200,155,7,0,10,0,0,0,1,8,0,0,96,135,7,0,10,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,10,0,0,0,1,16,16,0,96,135,7,0,10,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,2,0,200,30,2,0,10,0,0,0,1,32,32,0,120,97,1,0,10,0,0,0,1,32,0,0,96,19,1,0,0,0,0,0,254,0,2,0,16,227,4,0,10,0,0,0,1,128,0,0,96,135,7,0,10,0,0,0,1,128,128,0,152,182,7,0,0,0,0,0,254,0,2,0,64,37,5,0,11,0,0,0,1,3,2,0,120,7,5,0,11,0,0,0,1,3,0,0,80,2,4,0,11,0,0,0,1,3,1,0,184,133,7,0,11,0,0,0,1,3,3,0,72,130,7,0,0,0,0,0,254,0,2,0,64,127,7,0,11,0,0,0,1,4,0,0,56,111,3,0,11,0,0,0,1,4,4,0,104,134,3,0,0,0,0,0,254,0,2,0,8,124,7,0,11,0,0,0,1,8,0,0,208,75,4,0,11,0,0,0,1,8,8,0,8,49,4,0,0,0,0,0,254,0,2,0,96,120,7,0,11,0,0,0,1,16,0,0,80,246,3,0,11,0,0,0,1,16,16,0,112,212,3,0,0,0,0,0,254,0,2,0,88,116,7,0,11,0,0,0,1,32,0,0,56,111,3,0,11,0,0,0,1,32,32,0,104,134,3,0,0,0,0,0,254,0,3,0,88,116,7,0,11,0,0,0,1,192,0,0,200,110,7,0,11,0,0,0,1,192,128,0,104,104,7,0,11,0,0,0,1,192,64,0,120,7,5,0,0,0,0,0,14,0,0,0,255,255,253,0,0,0,0,0,15,0,0,0,255,255,255,0,0,0,0,0,16,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,24,140,2,0,14,0,0,0,1,1,1,0,96,135,7,0,14,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,184,138,2,0,14,0,0,0,1,2,0,0,96,135,7,0,14,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,14,0,0,0,1,4,0,0,96,135,7,0,14,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,14,0,0,0,1,24,16,0,80,246,3,0,14,0,0,0,1,24,24,0,248,38,7,0,14,0,0,0,1,24,8,0,112,212,3,0,14,0,0,0,1,24,0,0,248,160,5,0,0,0,0,0,254,0,2,0,104,159,3,0,14,0,0,0,1,32,0,0,96,135,7,0,14,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,14,0,0,0,1,128,128,0,96,135,7,0,14,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,8,0,200,87,7,0,15,0,0,0,1,7,5,0,40,88,7,0,15,0,0,0,1,7,6,0,96,39,7,0,15,0,0,0,1,7,7,0,144,251,6,0,15,0,0,0,1,7,4,0,184,164,6,0,15,0,0,0,1,7,3,0,80,74,6,0,15,0,0,0,1,7,2,0,192,32,6,0,15,0,0,0,1,7,1,0,192,234,2,0,15,0,0,0,1,7,0,0,32,242,5,0,0,0,0,0,254,0,8,0,160,123,6,0,15,0,0,0,1,56,40,0,40,88,7,0,15,0,0,0,1,56,48,0,96,39,7,0,15,0,0,0,1,56,56,0,144,251,6,0,15,0,0,0,1,56,32,0,184,164,6,0,15,0,0,0,1,56,24,0,80,74,6,0,15,0,0,0,1,56,16,0,192,32,6,0,15,0,0,0,1,56,8,0,192,234,2,0,15,0,0,0,1,56,0,0,32,242,5,0,0,0,0,0,254,0,2,0,24,172,6,0,15,0,0,0,1,64,64,0,56,111,3,0,15,0,0,0,1,64,0,0,104,134,3,0,184,40,2,0,1,0,0,0,40,39,216,0,248,191,2,0,56,250,6,0,1,0,0,0,32,39,216,0,184,160,2,0,88,149,7,0,1,0,0,0,33,39,216,0,136,224,1,0,240,167,7,0,1,0,0,0,45,39,216,0,192,135,2,0,176,163,7,0,1,0,0,0,46,39,216,0,240,108,2,0,208,158,7,0,1,0,0,0,42,39,216,0,96,82,2,0,184,154,7,0,1,0,0,0,43,39,216,0,32,56,2,0,176,108,2,0,1,0,0,0,44,39,216,0,152,30,2,0,8,96,7,0,1,0,0,0,37,39,216,0,72,198,1,0,48,89,7,0,1,0,0,0,47,39,216,0,24,182,1,0,16,83,7,0,1,0,0,0,34,39,216,0,40,167,1,0,96,79,7,0,1,0,0,0,35,39,216,0,200,149,1,0,48,76,7,0,1,0,0,0,36,39,216,0,56,126,1,0,88,212,3,0,1,0,0,0,48,38,216,0,40,185,3,0,248,5,8,0,9,0,0,0,112,39,216,0,32,58,1,0,144,250,7,0,9,0,0,0,113,39,216,0,32,58,1,0,248,241,7,0,9,0,0,0,114,39,216,0,32,58,1,0,122,116,45,112,48,49,99,46,48,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,97,188,162,144,1,0,16,1,122,116,45,50,46,48,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,126,6,51,164,1,0,16,1,122,116,45,51,46,48,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,212,56,240,170,1,0,16,1,122,116,45,52,46,48,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,10,105,109,120,1,0,16,1,122,116,45,53,46,48,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,215,96,146,175,1,0,16,1,122,116,99,45,50,46,48,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,5,202,19,27,4,0,32,0,122,116,99,45,49,46,48,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,3,223,215,92,4,0,32,0,54,108,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,103,148,172,195,7,0,32,0,12,0,0,0,255,255,0,0,0,0,0,0,13,0,0,0,255,255,64,0,0,0,0,0,14,0,0,0,255,255,3,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,12,0,0,0,1,32,0,0,120,97,1,0,12,0,0,0,1,32,32,0,96,19,1,0,0,0,0,0,254,0,2,0,232,75,4,0,12,0,0,0,1,64,0,0,96,135,7,0,12,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,4,0,32,4,2,0,13,0,0,0,1,192,64,0,48,59,1,0,13,0,0,0,1,192,192,0,8,58,1,0,13,0,0,0,1,192,0,0,160,57,1,0,13,0,0,0,1,192,128,0,24,57,1,0,0,0,0,0,254,0,4,0,64,37,5,0,14,0,0,0,1,3,3,0,160,118,3,0,14,0,0,0,1,3,2,0,176,114,3,0,14,0,0,0,1,3,1,0,104,109,3,0,14,0,0,0,1,3,0,0,120,7,5,0,0,0,0,0,254,0,2,0,128,129,4,0,14,0,0,0,1,4,0,0,8,49,4,0,14,0,0,0,1,4,4,0,72,246,3,0,0,0,0,0,254,0,2,0,72,202,5,0,14,0,0,0,1,8,0,0,80,246,3,0,14,0,0,0,1,8,8,0,112,212,3,0,0,0,0,0,117,110,105,99,111,95,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,86,151,141,9,0,0,16,1,117,110,105,99,111,95,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,243,5,225,88,0,0,16,1,117,110,105,99,111,95,122,112,111,98,106,95,122,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,163,104,39,31,0,0,32,0,117,110,105,99,111,95,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,238,54,156,82,0,0,32,0,117,110,105,99,111,95,122,112,111,98,106,95,122,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,247,87,166,215,0,0,32,0,117,110,105,99,111,95,122,112,111,98,106,95,122,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,141,47,236,58,0,0,32,0,117,110,105,99,111,95,122,112,115,99,114,95,122,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,240,60,229,225,0,0,32,0,117,110,105,99,111,95,122,112,115,99,114,95,122,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,80,72,125,13,0,0,32,0,117,110,105,99,111,95,122,112,115,99,114,95,122,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,50,143,23,187,0,0,32,0,117,110,105,99,111,95,122,112,115,99,114,95,122,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,229,2,47,103,0,0,32,0,117,110,105,99,111,95,49,46,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,250,132,35,253,0,0,64,0,117,110,105,99,111,50,46,114,111,109,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,163,188,95,40,0,0,16,1,117,110,105,99,111,51,46,114,111,109,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,41,49,123,173,0,0,16,1,117,110,105,99,111,95,122,112,111,98,106,95,122,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,163,104,39,31,0,0,32,0,117,110,105,99,111,95,122,112,111,98,106,95,122,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,58,243,52,222,0,0,32,0,117,110,105,99,111,95,122,112,111,98,106,95,122,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,247,87,166,215,0,0,32,0,117,110,105,99,111,95,122,112,111,98,106,95,122,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,141,47,236,58,0,0,32,0,117,110,105,99,111,95,122,112,115,99,114,95,122,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,240,60,229,225,0,0,32,0,117,110,105,99,111,95,122,112,115,99,114,95,122,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,80,72,125,13,0,0,32,0,117,110,105,99,111,95,122,112,115,99,114,95,122,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,50,143,23,187,0,0,32,0,117,110,105,99,111,95,122,112,115,99,114,95,122,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,229,2,47,103,0,0,32,0,117,110,105,99,111,95,49,46,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,250,132,35,253,0,0,64,0,100,49,54,45,100,51,49,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,219,79,49,72,0,0,16,1,100,48,45,100,49,53,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,30,21,196,94,0,0,16,1,100,98,48,100,98,49,122,112,46,50,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,12,70,75,71,0,0,32,0,100,98,50,100,98,51,122,112,46,50,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,136,10,29,10,0,0,32,0,100,98,52,100,98,53,122,112,46,50,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,220,105,113,34,0,0,32,0,100,98,54,100,98,55,122,112,46,50,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,219,108,48,166,0,0,32,0,97,48,45,97,49,122,112,46,50,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,14,156,202,247,0,0,32,0,97,50,45,97,51,122,112,46,50,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,254,200,129,5,0,0,32,0,97,52,45,97,53,122,112,46,50,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,239,145,208,221,0,0,32,0,97,54,45,97,55,122,112,46,50,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,19,97,212,63,0,0,32,0,117,122,112,50,45,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,237,102,9,237,0,0,64,0,117,122,112,50,45,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,85,180,140,219,0,0,64,0,13,0,0,0,255,255,255,0,0,0,0,0,14,0,0,0,255,255,253,0,0,0,0,0,0,0,0,0,254,0,2,0,16,227,4,0,13,0,0,0,1,1,1,0,96,135,7,0,13,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,64,132,5,0,13,0,0,0,1,2,0,0,192,255,2,0,13,0,0,0,1,2,2,0,208,75,4,0,0,0,0,0,254,0,3,0,0,42,5,0,13,0,0,0,1,12,8,0,56,111,3,0,13,0,0,0,1,12,4,0,104,134,3,0,13,0,0,0,1,12,12,0,192,196,4,0,0,0,0,0,254,0,2,0,128,112,3,0,13,0,0,0,1,16,16,0,168,22,4,0,13,0,0,0,1,16,0,0,224,247,3,0,0,0,0,0,254,0,8,0,32,4,2,0,13,0,0,0,1,224,0,0,104,54,4,0,13,0,0,0,1,224,32,0,80,252,6,0,13,0,0,0,1,224,64,0,16,242,7,0,13,0,0,0,1,224,96,0,104,236,7,0,13,0,0,0,1,224,224,0,128,230,7,0,13,0,0,0,1,224,192,0,184,164,6,0,13,0,0,0,1,224,160,0,80,74,6,0,13,0,0,0,1,224,128,0,192,32,6,0,0,0,0,0,254,0,2,0,144,92,3,0,14,0,0,0,1,1,1,0,96,135,7,0,14,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,14,0,0,0,1,2,2,0,96,135,7,0,14,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,5,0,128,129,4,0,14,0,0,0,1,28,16,0,208,75,4,0,14,0,0,0,1,28,12,0,8,49,4,0,14,0,0,0,1,28,28,0,152,21,4,0,14,0,0,0,1,28,24,0,72,246,3,0,14,0,0,0,1,28,20,0,72,0,3,0,0,0,0,0,254,0,4,0,72,202,5,0,14,0,0,0,1,192,128,0,80,246,3,0,14,0,0,0,1,192,192,0,248,38,7,0,14,0,0,0,1,192,64,0,112,212,3,0,14,0,0,0,1,192,0,0,248,160,5,0,0,0,0,0,99,56,51,45,49,48,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,3,93,24,77,2,0,16,1,99,56,51,45,48,57,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,146,39,137,249,2,0,16,1,99,56,51,45,48,51,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,194,172,217,238,1,0,16,1,99,56,51,45,49,49,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,42,112,30,70,9,0,16,1,99,56,51,45,48,53,46,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,177,127,165,236,11,0,32,0,99,56,51,45,48,49,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,22,212,240,139,16,0,32,0,99,56,51,45,48,50,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,21,28,187,32,16,0,32,0,99,56,51,45,48,52,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,58,9,0,38,24,0,64,0,17,0,0,0,255,255,255,0,0,0,0,0,18,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,17,0,0,0,1,2,2,0,96,135,7,0,17,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,17,0,0,0,1,4,4,0,96,135,7,0,17,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,17,0,0,0,1,48,0,0,16,242,7,0,17,0,0,0,1,48,16,0,104,236,7,0,17,0,0,0,1,48,48,0,128,230,7,0,17,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,17,0,0,0,1,192,0,0,16,242,7,0,17,0,0,0,1,192,64,0,104,236,7,0,17,0,0,0,1,192,192,0,128,230,7,0,17,0,0,0,1,192,128,0,184,164,6,0,0,0,0,0,254,0,4,0,72,202,5,0,18,0,0,0,1,3,2,0,80,246,3,0,18,0,0,0,1,3,3,0,80,124,6,0,18,0,0,0,1,3,1,0,112,212,3,0,18,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,2,0,104,159,3,0,18,0,0,0,1,64,0,0,96,135,7,0,18,0,0,0,1,64,64,0,152,182,7,0,121,106,117,95,97,52,101,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,220,107,53,13,0,0,16,1,121,106,117,95,97,52,100,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,19,190,105,193,0,0,16,1,121,106,117,95,112,52,99,98,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,177,243,186,96,0,0,16,1,121,106,117,95,112,52,101,98,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,248,33,5,141,0,0,16,1,121,106,117,95,97,51,102,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,48,128,92,225,0,0,16,1,121,106,117,95,112,51,98,98,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,60,145,23,192,0,0,32,0,121,106,117,95,112,49,98,98,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,35,117,98,148,0,0,32,0,121,106,117,95,112,49,99,98,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,86,140,55,106,0,0,32,0,121,106,117,95,98,52,107,97,46,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,74,134,187,27,0,0,32,0,121,106,117,95,98,52,102,97,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,36,221,180,20,0,0,32,0,121,106,117,95,98,51,110,97,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,33,147,135,104,0,0,32,0,121,106,117,95,98,52,110,97,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,139,166,96,40,0,0,32,0,121,106,117,95,98,52,99,97,46,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,41,88,54,171,0,0,32,0,121,106,117,95,98,52,101,97,46,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,228,49,108,179,0,0,32,0,121,106,117,95,112,52,108,98,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,155,141,135,135,0,0,32,0,121,106,117,95,112,52,109,98,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,9,13,26,30,0,0,32,0,121,106,117,95,112,52,112,98,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,11,82,171,180,0,0,32,0,121,106,117,95,112,50,106,98,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,49,54,72,164,0,0,32,0,121,106,117,95,98,49,109,97,46,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,19,14,52,168,0,0,32,0,121,106,117,95,112,50,107,98,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,3,17,72,133,0,0,32,0,121,106,117,95,98,49,110,97,46,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,65,188,180,245,0,0,32,0,121,106,117,95,112,50,104,98,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,92,53,253,166,0,0,32,0,121,106,117,95,98,49,108,97,46,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,145,4,225,69,0,0,32,0,121,106,117,95,98,45,53,112,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,163,230,149,32,0,0,32,0,121,106,117,95,98,45,54,102,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,18,13,194,130,0,0,32,0,121,106,117,95,112,45,56,100,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,189,15,239,108,0,0,0,8,121,106,117,95,98,45,112,97,108,49,54,114,52,97,45,56,109,46,112,97,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,97,142,206,62,0,0,0,8,18,0,0,0,255,255,255,0,0,0,0,0,19,0,0,0,255,255,253,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,18,0,0,0,1,3,2,0,208,75,4,0,18,0,0,0,1,3,3,0,8,49,4,0,18,0,0,0,1,3,1,0,152,21,4,0,18,0,0,0,1,3,0,0,72,246,3,0,0,0,0,0,254,0,16,0,32,4,2,0,18,0,0,0,2,240,160,0,8,32,4,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,176,0,96,164,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,192,0,144,102,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,208,0,176,45,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,16,0,112,169,3,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,224,0,224,127,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,32,0,192,119,3,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,48,0,136,252,1,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,240,0,32,123,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,64,0,248,116,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,144,0,192,110,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,128,0,96,102,7,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,112,0,184,105,6,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,96,0,152,96,3,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,80,0,192,100,6,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,0,0,104,151,6,0,19,0,0,0,0,4,4,0,0,0,0,0,0,0,0,0,254,0,4,0,200,87,7,0,18,0,0,0,130,48,0,0,96,164,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,130,48,16,0,176,45,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,130,48,32,0,224,127,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,130,48,48,0,32,123,8,0,19,0,0,0,0,4,4,0,0,0,0,0,0,0,0,0,254,0,4,0,160,123,6,0,18,0,0,0,130,192,192,0,192,110,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,130,192,128,0,96,102,7,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,130,192,64,0,152,96,3,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,130,192,0,0,192,100,6,0,19,0,0,0,0,4,4,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,1,1,0,96,135,7,0,19,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,200,30,2,0,19,0,0,0,1,2,0,0,120,97,1,0,19,0,0,0,1,2,2,0,96,19,1,0,0,0,0,0,254,0,2,0,96,46,8,0,19,0,0,0,1,4,4,0,208,233,4,0,19,0,0,0,1,4,0,0,72,197,4,0,0,0,0,0,254,0,2,0,64,37,5,0,19,0,0,0,1,8,8,0,208,168,3,0,19,0,0,0,1,8,0,0,8,192,1,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,16,0,0,96,135,7,0,19,0,0,0,1,16,16,0,152,182,7,0,0,0,0,0,254,0,2,0,32,228,8,0,19,0,0,0,1,32,32,0,96,135,7,0,19,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,246,3,0,19,0,0,0,1,64,64,0,96,135,7,0,19,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,128,128,0,96,135,7,0,19,0,0,0,1,128,0,0,152,182,7,0,184,40,2,0,1,0,0,0,178,148,215,0,248,191,2,0,184,164,8,0,1,0,0,0,179,148,215,0,64,246,1,0,48,123,2,0,1,0,0,0,184,148,215,0,152,30,2,0,96,69,2,0,1,0,0,0,185,148,215,0,232,10,2,0,248,187,8,0,1,0,0,0,186,148,215,0,56,126,1,0,184,179,8,0,1,0,0,0,187,148,215,0,32,101,1,0,88,212,3,0,1,0,0,0,200,147,215,0,40,185,3,0,16,17,8,0,1,0,0,0,177,148,215,0,224,12,8,0,56,58,1,0,1,0,0,0,176,148,215,0,64,50,1,0,248,5,8,0,9,0,0,0,96,149,215,0,32,58,1,0,144,250,7,0,9,0,0,0,97,149,215,0,32,58,1,0,107,121,95,97,45,52,101,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,214,210,58,199,0,0,16,1,107,121,95,97,45,52,100,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,40,248,26,64,0,0,16,1,107,121,95,116,45,56,107,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,136,222,103,233,0,0,16,1,107,121,95,116,45,56,108,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,11,17,41,169,0,0,16,1,107,121,95,97,45,51,97,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,59,95,54,203,0,0,16,1,100,114,48,49,46,51,99,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,189,151,104,230,0,0,16,1,100,114,48,50,46,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,38,30,227,249,0,0,16,1,107,121,95,116,45,50,99,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,252,97,151,203,0,0,32,0,107,121,95,116,45,50,100,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,65,39,115,89,0,0,32,0,107,121,95,116,45,50,97,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,130,253,112,3,0,0,32,0,107,121,95,98,45,52,107,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,16,157,58,38,0,0,32,0,107,121,95,98,45,52,102,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,168,212,227,134,0,0,32,0,107,121,95,98,45,52,108,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,88,117,250,25,0,0,32,0,107,121,95,98,45,52,104,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,92,102,230,147,0,0,32,0,107,121,95,98,45,51,110,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,37,197,135,2,0,0,32,0,107,121,95,98,45,52,110,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,224,70,73,118,0,0,32,0,107,121,95,98,45,52,109,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,185,93,237,236,0,0,32,0,107,121,95,98,45,51,109,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,68,238,108,190,0,0,32,0,107,121,95,98,45,52,99,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,93,182,214,132,0,0,32,0,107,121,95,98,45,52,101,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,115,146,31,249,0,0,32,0,107,121,95,98,45,52,100,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,240,21,252,162,0,0,32,0,107,121,95,98,45,52,97,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,138,156,43,255,0,0,32,0,107,121,95,116,45,52,108,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,83,146,10,29,0,0,32,0,107,121,95,116,45,52,109,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,150,195,117,64,0,0,32,0,107,121,95,116,45,52,110,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,255,242,100,117,0,0,32,0,100,114,50,53,46,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,11,67,145,142,0,0,32,0,100,114,51,48,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,99,50,199,40,0,0,32,0,100,114,50,54,46,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,63,185,99,181,0,0,32,0,100,114,51,49,46,49,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,14,33,41,53,0,0,32,0,100,114,50,55,46,51,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,239,104,214,112,0,0,32,0,100,114,50,57,46,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,84,167,115,17,0,0,32,0,100,114,51,50,46,53,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,46,31,205,17,0,0,32,0,100,114,51,51,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,60,141,216,52,0,0,32,0,100,114,50,56,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,189,15,239,108,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,255,255,199,0,0,0,0,0,0,0,0,0,254,0,8,0,32,4,2,0,17,0,0,0,1,7,0,0,40,88,7,0,17,0,0,0,1,7,1,0,232,216,6,0,17,0,0,0,1,7,7,0,144,251,6,0,17,0,0,0,1,7,6,0,184,164,6,0,17,0,0,0,1,7,5,0,80,74,6,0,17,0,0,0,1,7,4,0,192,32,6,0,17,0,0,0,1,7,3,0,192,234,2,0,17,0,0,0,1,7,2,0,32,242,5,0,0,0,0,0,254,0,2,0,168,234,7,0,17,0,0,0,1,8,8,0,96,135,7,0,17,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,17,0,0,0,1,96,64,0,80,246,3,0,17,0,0,0,1,96,96,0,248,38,7,0,17,0,0,0,1,96,32,0,112,212,3,0,17,0,0,0,1,96,0,0,248,160,5,0,0,0,0,0,254,0,2,0,232,75,4,0,17,0,0,0,1,128,128,0,96,135,7,0,17,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,120,118,115,117,46,48,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,90,21,129,84,1,0,16,1,120,118,115,117,46,48,52,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,136,99,35,30,1,0,16,1,120,118,115,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,93,2,182,125,1,0,16,1,120,118,115,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,92,199,226,232,1,0,16,1,120,118,115,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,237,171,240,8,1,0,16,1,120,118,115,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,117,150,146,129,1,0,16,1,120,118,115,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,107,243,65,150,1,0,16,1,120,118,115,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,253,78,104,246,5,0,32,0,120,118,115,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,33,146,16,41,5,0,32,0,120,118,115,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,116,52,219,146,5,0,32,0,120,118,115,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,60,71,51,55,5,0,32,0,120,118,115,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,65,46,172,188,5,0,32,0,120,118,115,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,114,162,4,234,5,0,32,0,120,118,115,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,106,248,222,176,5,0,32,0,120,118,115,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,159,255,64,75,5,0,32,0,120,118,115,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,58,233,153,57,10,0,16,1,120,118,115,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,233,222,27,16,10,0,16,1,120,118,115,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,188,205,173,156,12,0,64,0,120,118,115,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,96,228,17,123,12,0,64,0,120,118,115,117,100,46,48,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,183,118,46,78,1,0,16,1,120,118,115,117,100,46,48,52,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,167,97,12,41,1,0,16,1,120,118,115,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,93,2,182,125,1,0,16,1,120,118,115,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,92,199,226,232,1,0,16,1,120,118,115,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,237,171,240,8,1,0,16,1,120,118,115,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,117,150,146,129,1,0,16,1,120,118,115,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,107,243,65,150,1,0,16,1,120,118,115,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,253,78,104,246,5,0,32,0,120,118,115,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,33,146,16,41,5,0,32,0,120,118,115,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,116,52,219,146,5,0,32,0,120,118,115,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,60,71,51,55,5,0,32,0,120,118,115,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,65,46,172,188,5,0,32,0,120,118,115,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,114,162,4,234,5,0,32,0,120,118,115,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,106,248,222,176,5,0,32,0,120,118,115,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,159,255,64,75,5,0,32,0,120,118,115,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,58,233,153,57,10,0,16,1,120,118,115,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,233,222,27,16,10,0,16,1,120,118,115,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,188,205,173,156,12,0,64,0,120,118,115,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,96,228,17,123,12,0,64,0,120,118,115,106,46,48,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,161,86,6,24,1,0,16,1,120,118,115,106,46,48,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,28,129,50,88,1,0,16,1,120,118,115,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,30,14,14,3,1,0,16,1,120,118,115,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,255,168,4,93,1,0,16,1,120,118,115,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,237,171,240,8,1,0,16,1,120,118,115,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,117,150,146,129,1,0,16,1,120,118,115,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,107,243,65,150,1,0,16,1,120,118,115,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,253,78,104,246,5,0,32,0,120,118,115,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,33,146,16,41,5,0,32,0,120,118,115,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,116,52,219,146,5,0,32,0,120,118,115,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,60,71,51,55,5,0,32,0,120,118,115,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,65,46,172,188,5,0,32,0,120,118,115,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,114,162,4,234,5,0,32,0,120,118,115,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,106,248,222,176,5,0,32,0,120,118,115,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,159,255,64,75,5,0,32,0,120,118,115,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,58,233,153,57,10,0,16,1,120,118,115,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,233,222,27,16,10,0,16,1,120,118,115,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,188,205,173,156,12,0,64,0,120,118,115,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,96,228,17,123,12,0,64,0,120,118,115,106,46,48,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,233,29,184,190,1,0,16,1,120,118,115,106,46,48,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,113,18,209,35,1,0,16,1,120,118,115,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,93,2,182,125,1,0,16,1,120,118,115,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,92,199,226,232,1,0,16,1,120,118,115,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,237,171,240,8,1,0,16,1,120,118,115,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,117,150,146,129,1,0,16,1,120,118,115,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,107,243,65,150,1,0,16,1,120,118,115,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,253,78,104,246,5,0,32,0,120,118,115,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,33,146,16,41,5,0,32,0,120,118,115,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,116,52,219,146,5,0,32,0,120,118,115,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,60,71,51,55,5,0,32,0,120,118,115,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,65,46,172,188,5,0,32,0,120,118,115,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,114,162,4,234,5,0,32,0,120,118,115,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,106,248,222,176,5,0,32,0,120,118,115,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,159,255,64,75,5,0,32,0,120,118,115,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,58,233,153,57,10,0,16,1,120,118,115,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,233,222,27,16,10,0,16,1,120,118,115,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,188,205,173,156,12,0,64,0,120,118,115,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,96,228,17,123,12,0,64,0,120,118,115,97,46,48,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,215,79,22,43,1,0,16,1,120,118,115,97,46,48,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,57,240,50,45,1,0,16,1,120,118,115,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,93,2,182,125,1,0,16,1,120,118,115,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,92,199,226,232,1,0,16,1,120,118,115,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,237,171,240,8,1,0,16,1,120,118,115,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,117,150,146,129,1,0,16,1,120,118,115,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,107,243,65,150,1,0,16,1,120,118,115,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,253,78,104,246,5,0,32,0,120,118,115,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,33,146,16,41,5,0,32,0,120,118,115,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,116,52,219,146,5,0,32,0,120,118,115,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,60,71,51,55,5,0,32,0,120,118,115,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,65,46,172,188,5,0,32,0,120,118,115,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,114,162,4,234,5,0,32,0,120,118,115,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,106,248,222,176,5,0,32,0,120,118,115,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,159,255,64,75,5,0,32,0,120,118,115,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,58,233,153,57,10,0,16,1,120,118,115,97,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,76,46,39,25,10,0,16,1,120,118,115,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,188,205,173,156,12,0,64,0,120,118,115,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,96,228,17,123,12,0,64,0,120,118,115,97,46,48,51,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,28,226,221,155,1,0,16,1,120,118,115,97,46,48,52,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,14,48,51,1,0,16,1,120,118,115,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,93,2,182,125,1,0,16,1,120,118,115,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,92,199,226,232,1,0,16,1,120,118,115,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,237,171,240,8,1,0,16,1,120,118,115,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,117,150,146,129,1,0,16,1,120,118,115,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,107,243,65,150,1,0,16,1,120,118,115,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,253,78,104,246,5,0,32,0,120,118,115,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,33,146,16,41,5,0,32,0,120,118,115,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,116,52,219,146,5,0,32,0,120,118,115,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,60,71,51,55,5,0,32,0,120,118,115,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,65,46,172,188,5,0,32,0,120,118,115,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,114,162,4,234,5,0,32,0,120,118,115,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,106,248,222,176,5,0,32,0,120,118,115,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,159,255,64,75,5,0,32,0,120,118,115,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,58,233,153,57,10,0,16,1,120,118,115,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,233,222,27,16,10,0,16,1,120,118,115,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,188,205,173,156,12,0,64,0,120,118,115,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,96,228,17,123,12,0,64,0,22,0,0,0,255,255,255,0,0,0,0,0,23,0,0,0,255,255,253,0,0,0,0,0,0,0,0,0,254,0,4,0,72,202,5,0,22,0,0,0,1,3,2,0,160,203,8,0,22,0,0,0,1,3,1,0,80,246,3,0,22,0,0,0,1,3,3,0,248,38,7,0,22,0,0,0,1,3,0,0,112,212,3,0,0,0,0,0,254,0,4,0,128,129,4,0,22,0,0,0,1,12,8,0,192,255,2,0,22,0,0,0,1,12,4,0,208,75,4,0,22,0,0,0,1,12,12,0,8,49,4,0,22,0,0,0,1,12,0,0,152,21,4,0,0,0,0,0,254,0,4,0,200,30,2,0,23,0,0,0,1,2,0,0,128,71,7,0,23,0,0,0,1,2,2,0,96,19,1,0,23,0,0,0,1,2,0,0,8,67,7,0,23,0,0,0,1,2,2,0,24,62,7,0,0,0,0,0,254,0,2,0,168,234,7,0,23,0,0,0,1,8,0,0,96,135,7,0,23,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,2,0,32,56,7,0,23,0,0,0,1,16,16,0,96,135,7,0,23,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,23,0,0,0,1,32,0,0,56,111,3,0,23,0,0,0,1,32,32,0,104,134,3,0,168,86,7,0,1,0,0,0,103,249,146,0,248,191,2,0,24,38,7,0,1,0,0,0,72,241,146,0,184,160,2,0,56,210,6,0,1,0,0,0,96,249,146,0,192,135,2,0,24,163,6,0,1,0,0,0,97,249,146,0,240,108,2,0,152,122,6,0,1,0,0,0,98,249,146,0,96,82,2,0,192,72,6,0,1,0,0,0,99,249,146,0,32,56,2,0,200,110,3,0,1,0,0,0,100,249,146,0,152,30,2,0,120,89,3,0,1,0,0,0,101,249,146,0,232,10,2,0,120,74,3,0,1,0,0,0,102,249,146,0,152,138,8,0,40,246,1,0,1,0,0,0,39,2,147,0,64,246,1,0,144,236,1,0,1,0,0,0,73,241,146,0,136,224,1,0,176,223,1,0,1,0,0,0,32,2,147,0,72,198,1,0,192,209,1,0,1,0,0,0,33,2,147,0,24,182,1,0,24,198,1,0,1,0,0,0,34,2,147,0,40,167,1,0,120,189,1,0,1,0,0,0,35,2,147,0,200,149,1,0,224,22,1,0,1,0,0,0,36,2,147,0,56,126,1,0,160,14,1,0,1,0,0,0,37,2,147,0,32,101,1,0,176,9,1,0,1,0,0,0,38,2,147,0,96,32,8,0,88,212,3,0,1,0,0,0,152,221,146,0,40,185,3,0,32,77,1,0,1,0,0,0,78,241,146,0,216,70,1,0,56,122,5,0,1,0,0,0,64,241,146,0,224,12,8,0,0,105,5,0,1,0,0,0,65,241,146,0,128,176,7,0,120,109,110,101,46,48,51,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,9,155,160,169,1,0,16,1,120,109,110,101,46,48,52,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,6,33,250,82,1,0,16,1,120,109,110,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,89,119,13,172,1,0,16,1,120,109,110,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,40,163,134,27,1,0,16,1,120,109,110,46,48,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,68,42,20,44,1,0,16,1,120,109,110,46,48,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,79,212,18,247,1,0,16,1,120,109,110,46,48,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,232,202,65,146,1,0,16,1,120,109,110,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,185,234,192,83,1,0,16,1,120,109,110,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,115,240,77,191,5,0,32,0,120,109,110,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,239,76,126,77,5,0,32,0,120,109,110,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,23,234,62,81,5,0,32,0,120,109,110,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,252,151,56,210,5,0,32,0,120,109,110,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,183,55,130,119,5,0,32,0,120,109,110,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,72,105,179,103,5,0,32,0,120,109,110,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,76,124,90,1,5,0,32,0,120,109,110,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,88,39,222,157,5,0,32,0,120,109,110,46,48,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,234,121,244,64,10,0,16,1,120,109,110,46,48,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,173,181,217,57,10,0,16,1,120,109,110,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,188,166,72,200,12,0,64,0,120,109,110,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,143,24,156,114,12,0,64,0,120,109,110,111,46,48,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,207,154,177,122,1,0,16,1,120,109,110,111,46,48,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,33,221,21,118,1,0,16,1,120,109,110,111,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,114,214,3,3,1,0,16,1,120,109,110,111,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,165,57,40,51,1,0,16,1,120,109,110,111,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,213,232,85,98,1,0,16,1,120,109,110,111,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,124,231,235,184,1,0,16,1,120,109,110,111,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,80,217,64,84,1,0,16,1,120,109,110,111,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,102,105,41,184,1,0,16,1,120,109,110,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,115,240,77,191,5,0,32,0,120,109,110,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,239,76,126,77,5,0,32,0,120,109,110,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,23,234,62,81,5,0,32,0,120,109,110,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,252,151,56,210,5,0,32,0,120,109,110,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,183,55,130,119,5,0,32,0,120,109,110,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,72,105,179,103,5,0,32,0,120,109,110,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,76,124,90,1,5,0,32,0,120,109,110,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,88,39,222,157,5,0,32,0,120,109,110,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,110,51,120,113,10,0,16,1,120,109,110,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,1,133,197,14,10,0,16,1,120,109,110,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,188,166,72,200,12,0,64,0,120,109,110,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,143,24,156,114,12,0,64,0,120,109,110,106,46,48,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,17,22,118,0,1,0,16,1,120,109,110,106,46,48,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,96,63,77,97,1,0,16,1,120,109,110,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,162,98,237,195,1,0,16,1,120,109,110,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,225,82,60,240,1,0,16,1,120,109,110,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,177,38,86,50,1,0,16,1,120,109,110,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,16,234,148,113,1,0,16,1,120,109,110,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,243,109,148,174,1,0,16,1,120,109,110,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,29,190,166,50,1,0,16,1,120,109,110,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,115,240,77,191,5,0,32,0,120,109,110,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,239,76,126,77,5,0,32,0,120,109,110,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,23,234,62,81,5,0,32,0,120,109,110,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,252,151,56,210,5,0,32,0,120,109,110,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,183,55,130,119,5,0,32,0,120,109,110,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,72,105,179,103,5,0,32,0,120,109,110,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,76,124,90,1,5,0,32,0,120,109,110,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,88,39,222,157,5,0,32,0,120,109,110,46,48,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,234,121,244,64,10,0,16,1,120,109,110,46,48,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,173,181,217,57,10,0,16,1,120,109,110,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,188,166,72,200,12,0,64,0,120,109,110,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,143,24,156,114,12,0,64,0,120,109,110,106,46,48,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,179,95,23,200,1,0,16,1,120,109,110,106,46,48,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,163,251,179,84,1,0,16,1,120,109,110,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,162,98,237,195,1,0,16,1,120,109,110,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,225,82,60,240,1,0,16,1,120,109,110,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,177,38,86,50,1,0,16,1,120,109,110,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,16,234,148,113,1,0,16,1,120,109,110,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,243,109,148,174,1,0,16,1,120,109,110,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,29,190,166,50,1,0,16,1,120,109,110,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,115,240,77,191,5,0,32,0,120,109,110,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,239,76,126,77,5,0,32,0,120,109,110,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,23,234,62,81,5,0,32,0,120,109,110,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,252,151,56,210,5,0,32,0,120,109,110,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,183,55,130,119,5,0,32,0,120,109,110,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,72,105,179,103,5,0,32,0,120,109,110,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,76,124,90,1,5,0,32,0,120,109,110,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,88,39,222,157,5,0,32,0,120,109,110,46,48,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,234,121,244,64,10,0,16,1,120,109,110,46,48,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,173,181,217,57,10,0,16,1,120,109,110,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,188,166,72,200,12,0,64,0,120,109,110,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,143,24,156,114,12,0,64,0,120,109,110,106,46,48,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,98,109,8,121,1,0,16,1,120,109,110,106,46,48,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,19,214,238,56,1,0,16,1,120,109,110,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,162,98,237,195,1,0,16,1,120,109,110,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,225,82,60,240,1,0,16,1,120,109,110,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,177,38,86,50,1,0,16,1,120,109,110,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,16,234,148,113,1,0,16,1,120,109,110,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,243,109,148,174,1,0,16,1,120,109,110,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,29,190,166,50,1,0,16,1,120,109,110,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,115,240,77,191,5,0,32,0,120,109,110,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,239,76,126,77,5,0,32,0,120,109,110,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,23,234,62,81,5,0,32,0,120,109,110,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,252,151,56,210,5,0,32,0,120,109,110,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,183,55,130,119,5,0,32,0,120,109,110,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,72,105,179,103,5,0,32,0,120,109,110,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,76,124,90,1,5,0,32,0,120,109,110,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,88,39,222,157,5,0,32,0,120,109,110,46,48,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,234,121,244,64,10,0,16,1,120,109,110,46,48,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,173,181,217,57,10,0,16,1,120,109,110,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,188,166,72,200,12,0,64,0,120,109,110,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,143,24,156,114,12,0,64,0,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,8,0,200,87,7,0,19,0,0,0,1,7,0,0,32,136,7,0,19,0,0,0,1,7,1,0,40,88,7,0,19,0,0,0,1,7,2,0,96,39,7,0,19,0,0,0,1,7,7,0,144,251,6,0,19,0,0,0,1,7,6,0,184,164,6,0,19,0,0,0,1,7,5,0,80,74,6,0,19,0,0,0,1,7,4,0,192,32,6,0,19,0,0,0,1,7,3,0,192,234,2,0,0,0,0,0,254,0,8,0,160,123,6,0,19,0,0,0,1,56,0,0,32,136,7,0,19,0,0,0,1,56,8,0,40,88,7,0,19,0,0,0,1,56,16,0,96,39,7,0,19,0,0,0,1,56,56,0,144,251,6,0,19,0,0,0,1,56,48,0,184,164,6,0,19,0,0,0,1,56,40,0,80,74,6,0,19,0,0,0,1,56,32,0,192,32,6,0,19,0,0,0,1,56,24,0,192,234,2,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,128,128,0,96,135,7,0,19,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,3,1,0,80,246,3,0,20,0,0,0,1,3,3,0,248,38,7,0,20,0,0,0,1,3,2,0,112,212,3,0,20,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,2,0,168,234,7,0,20,0,0,0,1,4,0,0,96,135,7,0,20,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,254,0,2,0,128,169,4,0,20,0,0,0,1,8,8,0,248,38,7,0,20,0,0,0,1,8,0,0,112,212,3,0,0,0,0,0,254,0,4,0,112,59,6,0,20,0,0,0,1,48,32,0,224,109,4,0,20,0,0,0,1,48,48,0,80,155,7,0,20,0,0,0,1,48,16,0,248,56,4,0,20,0,0,0,1,48,0,0,120,29,4,0,0,0,0,0,254,0,2,0,136,0,4,0,20,0,0,0,1,128,128,0,56,111,3,0,20,0,0,0,1,128,0,0,104,134,3,0,101,112,114,45,49,52,55,51,48,97,46,97,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,14,136,167,218,1,0,16,1,101,112,114,45,49,52,55,51,49,97,46,97,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,59,53,54,94,1,0,16,1,109,112,114,45,49,52,55,49,57,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,67,199,88,139,2,0,32,0,109,112,114,45,49,52,55,50,48,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,244,25,109,249,2,0,32,0,109,112,114,45,49,52,55,50,49,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,29,217,206,196,2,0,32,0,109,112,114,45,49,52,55,50,54,46,99,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,211,209,19,114,3,0,32,0,109,112,114,45,49,52,55,51,50,46,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,73,213,206,4,3,0,32,0,109,112,114,45,49,52,55,50,55,46,99,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,240,224,116,59,3,0,32,0,109,112,114,45,49,52,55,51,51,46,97,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,79,68,160,109,3,0,32,0,109,112,114,45,49,52,55,50,56,46,99,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,135,21,146,91,3,0,32,0,109,112,114,45,49,52,55,51,52,46,97,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,217,94,63,111,3,0,32,0,101,112,114,45,49,52,55,50,53,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,79,104,41,43,4,0,16,1,109,112,114,45,49,52,55,50,52,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,134,234,203,71,19,0,64,0,109,112,114,45,49,52,55,50,51,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,220,90,188,19,0,64,0,109,112,114,45,49,52,55,50,50,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,248,129,208,27,19,0,64,0,51,49,55,45,48,49,57,55,97,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,161,169,182,47,5,0,16,1,184,40,2,0,1,0,0,0,208,155,215,0,248,191,2,0,56,250,6,0,1,0,0,0,212,155,215,0,184,160,2,0,184,164,8,0,1,0,0,0,209,155,215,0,64,246,1,0,88,149,7,0,1,0,0,0,213,155,215,0,136,224,1,0,56,210,6,0,1,0,0,0,203,155,215,0,192,135,2,0,24,163,6,0,1,0,0,0,204,155,215,0,240,108,2,0,152,122,6,0,1,0,0,0,201,155,215,0,96,82,2,0,192,72,6,0,1,0,0,0,202,155,215,0,32,56,2,0,48,123,2,0,1,0,0,0,200,155,215,0,152,30,2,0,176,223,1,0,1,0,0,0,195,155,215,0,72,198,1,0,192,209,1,0,1,0,0,0,196,155,215,0,24,182,1,0,24,198,1,0,1,0,0,0,193,155,215,0,40,167,1,0,120,189,1,0,1,0,0,0,194,155,215,0,200,149,1,0,248,187,8,0,1,0,0,0,192,155,215,0,56,126,1,0,16,17,8,0,1,0,0,0,211,155,215,0,224,12,8,0,32,77,1,0,1,0,0,0,210,155,215,0,216,70,1,0,88,212,3,0,1,0,0,0,200,154,215,0,40,185,3,0,248,5,8,0,9,0,0,0,0,156,215,0,32,58,1,0,144,250,7,0,9,0,0,0,1,156,215,0,32,58,1,0,21,0,0,0,255,255,255,0,0,0,0,0,22,0,0,0,255,255,255,0,0,0,0,0,23,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,21,0,0,0,1,1,1,0,96,135,7,0,21,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,21,0,0,0,1,2,0,0,96,135,7,0,21,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,2,0,176,37,2,0,21,0,0,0,1,8,8,0,96,135,7,0,21,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,0,0,232,75,4,0,21,0,0,0,1,128,128,0,96,135,7,0,21,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,0,0,128,129,4,0,22,0,0,0,1,3,2,0,208,75,4,0,22,0,0,0,1,3,3,0,8,49,4,0,22,0,0,0,1,3,1,0,152,21,4,0,22,0,0,0,1,3,0,0,72,246,3,0,0,0,0,0,254,0,0,0,72,202,5,0,22,0,0,0,1,12,8,0,80,246,3,0,22,0,0,0,1,12,12,0,248,38,7,0,22,0,0,0,1,12,4,0,112,212,3,0,22,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,2,0,32,4,2,0,22,0,0,0,1,240,160,0,144,160,3,0,22,0,0,0,1,240,176,0,96,135,3,0,22,0,0,0,1,240,192,0,32,136,7,0,22,0,0,0,1,240,208,0,40,88,7,0,22,0,0,0,1,240,16,0,40,28,4,0,22,0,0,0,1,240,224,0,96,39,7,0,22,0,0,0,1,240,32,0,192,24,7,0,22,0,0,0,1,240,48,0,120,113,6,0,22,0,0,0,1,240,240,0,144,251,6,0,22,0,0,0,1,240,64,0,120,211,6,0,22,0,0,0,1,240,144,0,184,164,6,0,22,0,0,0,1,240,128,0,80,74,6,0,22,0,0,0,1,240,112,0,192,32,6,0,22,0,0,0,1,240,96,0,192,234,2,0,22,0,0,0,1,240,80,0,32,242,5,0,22,0,0,0,1,240,0,0,16,227,4,0,101,112,114,45,49,50,51,55,50,46,97,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,38,161,171,238,1,0,16,1,101,112,114,45,49,50,51,55,49,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,10,96,20,103,1,0,16,1,101,112,114,45,49,50,49,52,54,46,97,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,101,166,123,183,1,0,16,1,101,112,114,45,49,50,49,52,52,46,97,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,203,117,240,221,1,0,16,1,109,112,114,45,49,50,49,53,48,46,97,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,185,26,130,106,2,0,32,0,109,112,114,45,49,50,49,53,49,46,97,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,81,7,26,43,2,0,32,0,109,112,114,45,49,50,49,53,50,46,97,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,254,144,225,246,2,0,32,0,109,112,114,45,49,50,49,53,51,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,104,211,167,255,3,0,32,0,109,112,114,45,49,50,49,53,55,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,193,148,119,141,3,0,32,0,109,112,114,45,49,50,49,53,52,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,242,67,211,14,3,0,32,0,109,112,114,45,49,50,49,53,56,46,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,88,141,69,153,3,0,32,0,109,112,114,45,49,50,49,53,53,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,77,16,135,48,3,0,32,0,109,112,114,45,49,50,49,53,57,46,98,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,237,155,207,171,3,0,32,0,111,112,114,45,49,50,49,53,54,46,98,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,139,6,182,65,3,0,32,0,111,112,114,45,49,50,49,54,48,46,98,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,100,193,234,151,3,0,32,0,111,112,114,45,49,50,49,52,49,46,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,197,17,3,38,3,0,32,0,111,112,114,45,49,50,49,54,49,46,98,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,177,177,164,53,3,0,32,0,111,112,114,45,49,50,49,52,50,46,97,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,92,138,227,18,3,0,32,0,111,112,114,45,49,50,49,54,50,46,98,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,36,253,6,250,3,0,32,0,101,112,114,45,49,50,49,52,55,46,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,7,150,96,195,4,0,16,1,109,112,114,45,49,50,49,52,56,46,97,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,41,127,154,251,8,0,64,0,109,112,114,45,49,50,49,52,57,46,97,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,25,123,97,214,8,0,64,0,51,49,55,45,48,49,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,245,16,7,170,0,0,0,8,19,0,0,0,255,255,253,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,2,2,0,96,135,7,0,19,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,4,0,72,232,5,0,19,0,0,0,1,12,0,0,80,167,5,0,19,0,0,0,1,12,12,0,128,161,5,0,19,0,0,0,1,12,8,0,40,157,5,0,19,0,0,0,1,12,4,0,224,154,5,0,0,0,0,0,254,0,2,0,104,159,3,0,19,0,0,0,1,32,0,0,56,111,3,0,19,0,0,0,1,32,32,0,104,134,3,0,0,0,0,0,254,0,4,0,72,202,5,0,19,0,0,0,1,192,128,0,80,246,3,0,19,0,0,0,1,192,192,0,248,38,7,0,19,0,0,0,1,192,64,0,112,212,3,0,19,0,0,0,1,192,0,0,248,160,5,0,0,0,0,0,254,0,16,0,200,87,7,0,20,0,0,0,1,15,7,0,80,252,6,0,20,0,0,0,1,15,8,0,16,242,7,0,20,0,0,0,1,15,9,0,104,236,7,0,20,0,0,0,1,15,5,0,176,51,4,0,20,0,0,0,1,15,4,0,56,24,4,0,20,0,0,0,1,15,15,0,128,230,7,0,20,0,0,0,1,15,1,0,72,216,3,0,20,0,0,0,1,15,2,0,24,188,3,0,20,0,0,0,1,15,3,0,176,162,3,0,20,0,0,0,1,15,6,0,120,211,6,0,20,0,0,0,1,15,14,0,184,164,6,0,20,0,0,0,1,15,13,0,80,74,6,0,20,0,0,0,1,15,12,0,192,32,6,0,20,0,0,0,1,15,11,0,192,234,2,0,20,0,0,0,1,15,10,0,32,242,5,0,20,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,20,0,0,0,1,240,112,0,80,252,6,0,20,0,0,0,1,240,128,0,16,242,7,0,20,0,0,0,1,240,144,0,104,236,7,0,20,0,0,0,1,240,80,0,176,51,4,0,20,0,0,0,1,240,64,0,56,24,4,0,20,0,0,0,1,240,240,0,128,230,7,0,20,0,0,0,1,240,16,0,72,216,3,0,20,0,0,0,1,240,32,0,24,188,3,0,20,0,0,0,1,240,48,0,176,162,3,0,20,0,0,0,1,240,96,0,120,211,6,0,20,0,0,0,1,240,224,0,184,164,6,0,20,0,0,0,1,240,208,0,80,74,6,0,20,0,0,0,1,240,192,0,192,32,6,0,20,0,0,0,1,240,176,0,192,234,2,0,20,0,0,0,1,240,160,0,32,242,5,0,20,0,0,0,1,240,0,0,208,236,2,0,101,112,45,52,48,48,49,32,52,50,55,53,48,48,48,49,32,117,56,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,210,66,153,0,0,16,1,101,112,45,52,48,48,49,32,52,50,55,53,48,48,48,49,32,117,56,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,235,158,53,23,0,0,16,1,101,112,45,48,54,49,32,52,51,55,53,48,48,48,50,32,45,32,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,65,232,24,195,0,0,16,1,101,112,45,48,54,49,32,52,51,55,53,48,48,48,50,32,45,32,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,58,220,113,136,0,0,16,1,101,112,45,52,48,48,49,32,52,50,55,53,48,48,48,49,32,117,49,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,31,202,119,62,0,0,32,0,101,112,45,52,48,48,49,32,52,50,55,53,48,48,48,49,32,117,49,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,4,182,244,81,0,0,32,0,101,112,45,52,48,48,49,32,52,50,55,53,48,48,48,49,32,117,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,158,136,220,6,0,0,64,0,101,112,45,52,48,48,49,32,52,50,55,53,48,48,48,49,32,117,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,194,103,65,134,0,0,64,0,16,0,0,0,255,255,255,0,0,0,0,0,17,0,0,0,255,255,253,0,0,0,0,0,16,0,0,0,254,0,2,0,208,128,1,0,16,0,0,0,1,16,16,0,8,49,4,0,16,0,0,0,1,16,0,0,72,246,3,0,16,0,0,0,254,0,2,0,128,129,4,0,16,0,0,0,1,32,32,0,8,49,4,0,16,0,0,0,1,32,0,0,72,246,3,0,16,0,0,0,254,0,4,0,32,4,2,0,16,0,0,0,1,192,0,0,240,12,2,0,16,0,0,0,1,192,64,0,160,36,8,0,16,0,0,0,1,192,192,0,208,239,7,0,16,0,0,0,1,192,128,0,120,187,7,0,17,0,0,0,254,0,2,0,232,75,4,0,17,0,0,0,1,1,1,0,96,135,7,0,17,0,0,0,1,1,0,0,152,182,7,0,17,0,0,0,254,0,2,0,168,234,7,0,17,0,0,0,1,2,2,0,96,135,7,0,17,0,0,0,1,2,0,0,152,182,7,0,17,0,0,0,254,0,4,0,72,202,5,0,17,0,0,0,1,192,128,0,80,246,3,0,17,0,0,0,1,192,192,0,248,38,7,0,17,0,0,0,1,192,64,0,112,212,3,0,17,0,0,0,1,192,0,0,248,160,5,0,114,116,117,95,51,48,97,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,2,0,216,111,21,11,1,0,16,1,114,116,117,95,51,53,97,46,49,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,244,11,53,87,1,0,16,1,114,116,117,95,51,49,97,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,204,63,114,14,1,0,16,1,114,116,117,95,51,54,97,46,49,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,220,69,58,82,1,0,16,1,114,116,95,50,56,97,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,200,55,65,5,1,0,16,1,114,116,95,51,51,97,46,57,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,27,203,100,114,1,0,16,1,114,116,117,95,50,57,97,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,32,62,186,55,1,0,16,1,114,116,117,95,51,52,97,46,49,48,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,192,70,159,249,1,0,16,1,114,116,45,53,109,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,4,248,174,134,4,0,32,0,114,116,45,55,109,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,16,113,5,79,4,0,32,0,114,116,45,49,109,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,208,137,36,144,4,0,32,0,114,116,45,51,109,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,32,231,92,227,4,0,32,0,114,116,45,54,109,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,124,14,203,19,4,0,32,0,114,116,45,56,109,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,20,80,5,31,4,0,32,0,114,116,45,50,109,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,244,52,160,233,4,0,32,0,114,116,45,52,109,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,139,234,14,223,4,0,32,0,114,116,95,57,46,49,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,101,161,252,171,3,0,16,0,114,116,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,171,17,178,38,5,0,64,0,114,116,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,208,74,230,219,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,114,116,50,52,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,89,81,184,84,0,0,0,8,105,111,98,49,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,105,111,99,49,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,129,32,24,13,0,0,0,8,50,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,132,24,7,230,1,0,16,1,50,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,183,71,132,162,1,0,16,1,50,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,101,61,253,1,0,16,1,50,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,61,186,156,153,1,0,16,1,114,116,95,50,56,97,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,200,55,65,5,1,0,16,1,114,116,95,51,51,97,46,57,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,27,203,100,114,1,0,16,1,114,116,101,95,50,57,97,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,25,169,218,205,1,0,16,1,114,116,101,95,51,52,97,46,49,48,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,229,231,82,237,1,0,16,1,49,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,162,188,151,201,4,0,32,0,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,26,50,234,62,4,0,32,0,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,212,223,172,152,4,0,32,0,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,249,166,156,220,4,0,32,0,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,7,96,138,13,4,0,32,0,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,185,99,85,215,4,0,32,0,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,40,154,54,132,4,0,32,0,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,120,21,131,212,4,0,32,0,49,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,245,223,14,4,4,0,32,0,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,140,70,192,199,4,0,32,0,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,79,17,239,159,4,0,32,0,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,165,251,203,72,4,0,32,0,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,209,215,195,143,4,0,32,0,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,134,154,94,198,4,0,32,0,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,26,52,57,242,4,0,32,0,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,68,201,122,148,4,0,32,0,114,116,95,57,46,49,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,101,161,252,171,3,0,16,0,114,116,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,171,17,178,38,5,0,64,0,114,116,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,208,74,230,219,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,114,116,50,52,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,89,81,184,84,0,0,0,8,105,111,98,49,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,105,111,99,49,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,129,32,24,13,0,0,0,8,50,55,52,48,48,49,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,243,124,136,71,1,0,16,1,50,55,52,48,48,49,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,179,172,158,231,1,0,16,1,50,55,52,48,48,49,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,251,141,207,71,4,0,32,0,50,55,52,48,48,49,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,5,118,210,160,4,0,32,0,50,55,52,48,48,49,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,180,187,18,129,4,0,32,0,50,55,52,48,48,49,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,157,117,115,203,4,0,32,0,50,55,52,48,48,49,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,94,239,194,59,4,0,32,0,50,55,52,48,48,49,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,12,121,45,49,4,0,32,0,50,55,52,48,48,49,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,103,113,48,88,4,0,32,0,50,55,52,48,48,49,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,232,90,118,63,4,0,32,0,50,55,53,49,50,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,101,161,252,171,3,0,16,0,50,55,48,50,48,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,207,72,67,60,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,114,116,50,52,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,89,81,184,84,0,0,0,8,105,111,98,49,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,105,111,99,49,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,129,32,24,13,0,0,0,8,168,86,7,0,1,0,0,0,232,47,216,0,248,191,2,0,24,38,7,0,1,0,0,0,236,47,216,0,184,160,2,0,56,210,6,0,1,0,0,0,35,48,216,0,192,135,2,0,24,163,6,0,1,0,0,0,34,48,216,0,240,108,2,0,152,122,6,0,1,0,0,0,33,48,216,0,96,82,2,0,192,72,6,0,1,0,0,0,32,48,216,0,32,56,2,0,152,31,6,0,1,0,0,0,36,48,216,0,152,30,2,0,248,97,5,0,1,0,0,0,37,48,216,0,232,10,2,0,40,246,1,0,1,0,0,0,233,47,216,0,64,246,1,0,144,236,1,0,1,0,0,0,237,47,216,0,136,224,1,0,176,223,1,0,1,0,0,0,43,48,216,0,72,198,1,0,192,209,1,0,1,0,0,0,42,48,216,0,24,182,1,0,24,198,1,0,1,0,0,0,41,48,216,0,40,167,1,0,120,189,1,0,1,0,0,0,40,48,216,0,200,149,1,0,8,182,1,0,1,0,0,0,44,48,216,0,56,126,1,0,32,167,1,0,1,0,0,0,45,48,216,0,32,101,1,0,168,132,8,0,1,0,0,0,222,47,216,0,232,209,1,0,72,126,8,0,1,0,0,0,223,47,216,0,144,189,1,0,192,122,8,0,1,0,0,0,219,47,216,0,208,174,1,0,40,116,8,0,1,0,0,0,218,47,216,0,48,160,1,0,72,110,8,0,1,0,0,0,217,47,216,0,160,140,1,0,184,102,8,0,1,0,0,0,216,47,216,0,56,112,1,0,248,93,8,0,1,0,0,0,220,47,216,0,32,92,1,0,152,86,8,0,1,0,0,0,221,47,216,0,64,77,1,0,88,212,3,0,1,0,0,0,144,46,216,0,40,185,3,0,240,152,1,0,1,0,0,0,238,47,216,0,216,70,1,0,16,17,8,0,1,0,0,0,234,47,216,0,224,12,8,0,224,41,1,0,9,0,0,0,216,48,216,0,32,58,1,0,168,86,7,0,1,0,0,0,232,47,216,0,248,191,2,0,24,38,7,0,1,0,0,0,236,47,216,0,184,160,2,0,56,210,6,0,1,0,0,0,35,48,216,0,192,135,2,0,24,163,6,0,1,0,0,0,34,48,216,0,240,108,2,0,152,122,6,0,1,0,0,0,33,48,216,0,96,82,2,0,192,72,6,0,1,0,0,0,32,48,216,0,32,56,2,0,152,31,6,0,1,0,0,0,36,48,216,0,152,30,2,0,248,97,5,0,1,0,0,0,37,48,216,0,232,10,2,0,112,135,2,0,1,0,0,0,38,48,216,0,152,138,8,0,40,246,1,0,1,0,0,0,233,47,216,0,64,246,1,0,144,236,1,0,1,0,0,0,237,47,216,0,136,224,1,0,176,223,1,0,1,0,0,0,43,48,216,0,72,198,1,0,192,209,1,0,1,0,0,0,42,48,216,0,24,182,1,0,24,198,1,0,1,0,0,0,41,48,216,0,40,167,1,0,120,189,1,0,1,0,0,0,40,48,216,0,200,149,1,0,8,182,1,0,1,0,0,0,44,48,216,0,56,126,1,0,32,167,1,0,1,0,0,0,45,48,216,0,32,101,1,0,16,193,8,0,1,0,0,0,46,48,216,0,96,32,8,0,72,126,8,0,1,0,0,0,167,47,216,0,144,189,1,0,192,122,8,0,1,0,0,0,163,47,216,0,208,174,1,0,40,116,8,0,1,0,0,0,162,47,216,0,48,160,1,0,72,110,8,0,1,0,0,0,161,47,216,0,160,140,1,0,184,102,8,0,1,0,0,0,160,47,216,0,56,112,1,0,248,93,8,0,1,0,0,0,164,47,216,0,32,92,1,0,152,86,8,0,1,0,0,0,165,47,216,0,64,77,1,0,88,18,2,0,1,0,0,0,166,47,216,0,112,157,4,0,88,212,3,0,1,0,0,0,144,46,216,0,40,185,3,0,16,17,8,0,1,0,0,0,234,47,216,0,224,12,8,0,72,65,1,0,9,0,0,0,232,48,216,0,32,58,1,0,48,50,1,0,9,0,0,0,224,48,216,0,32,58,1,0,224,41,1,0,9,0,0,0,216,48,216,0,32,58,1,0,20,0,0,0,255,255,111,0,0,0,0,0,21,0,0,0,255,255,211,0,0,0,0,0,0,0,0,0,254,0,4,0,160,123,6,0,20,0,0,0,1,3,0,0,96,39,7,0,20,0,0,0,1,3,3,0,144,251,6,0,20,0,0,0,1,3,2,0,184,164,6,0,20,0,0,0,1,3,1,0,80,74,6,0,0,0,0,0,254,0,4,0,200,87,7,0,20,0,0,0,1,12,0,0,96,39,7,0,20,0,0,0,1,12,12,0,144,251,6,0,20,0,0,0,1,12,8,0,184,164,6,0,20,0,0,0,1,12,4,0,80,74,6,0,0,0,0,0,254,0,2,0,168,234,7,0,20,0,0,0,1,32,0,0,96,135,7,0,20,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,20,0,0,0,1,64,64,0,96,135,7,0,20,0,0,0])
.concat([1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,200,30,2,0,20,0,0,0,1,128,0,0,120,97,1,0,20,0,0,0,1,128,128,0,96,19,1,0,0,0,0,0,254,0,4,0,128,129,4,0,21,0,0,0,1,3,1,0,192,255,2,0,21,0,0,0,1,3,3,0,8,49,4,0,21,0,0,0,1,3,2,0,72,246,3,0,21,0,0,0,1,3,0,0,48,176,2,0,0,0,0,0,254,0,2,0,104,159,3,0,21,0,0,0,1,16,0,0,56,111,3,0,21,0,0,0,1,16,16,0,104,134,3,0,0,0,0,0,254,0,4,0,72,202,5,0,21,0,0,0,1,192,128,0,80,246,3,0,21,0,0,0,1,192,192,0,248,38,7,0,21,0,0,0,1,192,64,0,112,212,3,0,21,0,0,0,1,192,0,0,248,160,5,0,184,40,2,0,1,0,0,0,128,93,148,0,248,191,2,0,56,250,6,0,1,0,0,0,132,93,148,0,184,160,2,0,184,164,8,0,1,0,0,0,129,93,148,0,64,246,1,0,88,149,7,0,1,0,0,0,133,93,148,0,136,224,1,0,192,119,7,0,1,0,0,0,149,93,148,0,192,135,2,0,16,110,7,0,1,0,0,0,148,93,148,0,240,108,2,0,160,96,7,0,1,0,0,0,151,93,148,0,96,82,2,0,152,83,7,0,1,0,0,0,150,93,148,0,32,56,2,0,176,76,7,0,1,0,0,0,145,93,148,0,152,30,2,0,160,68,7,0,1,0,0,0,144,93,148,0,232,10,2,0,88,59,7,0,1,0,0,0,147,93,148,0,152,138,8,0,208,47,7,0,1,0,0,0,146,93,148,0,48,119,7,0,48,123,2,0,1,0,0,0,134,93,148,0,112,109,7,0,8,30,7,0,1,0,0,0,141,93,148,0,72,198,1,0,160,24,7,0,1,0,0,0,140,93,148,0,24,182,1,0,232,14,7,0,1,0,0,0,143,93,148,0,40,167,1,0,32,3,7,0,1,0,0,0,142,93,148,0,200,149,1,0,232,248,6,0,1,0,0,0,137,93,148,0,56,126,1,0,112,241,6,0,1,0,0,0,136,93,148,0,32,101,1,0,16,236,6,0,1,0,0,0,139,93,148,0,96,32,8,0,64,228,6,0,1,0,0,0,138,93,148,0,16,68,7,0,248,187,8,0,1,0,0,0,135,93,148,0,240,58,7,0,88,212,3,0,1,0,0,0,248,26,149,0,40,185,3,0,16,17,8,0,1,0,0,0,131,93,148,0,224,12,8,0,80,251,6,0,1,0,0,0,130,93,148,0,216,70,1,0,248,5,8,0,9,0,0,0,112,99,215,0,32,58,1,0,144,250,7,0,9,0,0,0,113,99,215,0,32,58,1,0,18,0,0,0,255,255,255,0,0,0,0,0,19,0,0,0,255,255,127,0,0,0,0,0,0,0,0,0,254,0,8,0,200,87,7,0,18,0,0,0,1,7,0,0,40,88,7,0,18,0,0,0,1,7,1,0,96,39,7,0,18,0,0,0,1,7,7,0,144,251,6,0,18,0,0,0,1,7,6,0,184,164,6,0,18,0,0,0,1,7,5,0,80,74,6,0,18,0,0,0,1,7,4,0,192,32,6,0,18,0,0,0,1,7,3,0,192,234,2,0,18,0,0,0,1,7,2,0,32,242,5,0,0,0,0,0,254,0,8,0,160,123,6,0,18,0,0,0,1,56,0,0,40,88,7,0,18,0,0,0,1,56,8,0,96,39,7,0,18,0,0,0,1,56,56,0,144,251,6,0,18,0,0,0,1,56,48,0,184,164,6,0,18,0,0,0,1,56,40,0,80,74,6,0,18,0,0,0,1,56,32,0,192,32,6,0,18,0,0,0,1,56,24,0,192,234,2,0,18,0,0,0,1,56,16,0,32,242,5,0,0,0,0,0,254,0,2,0,144,212,8,0,18,0,0,0,1,64,64,0,96,135,7,0,18,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,152,184,3,0,18,0,0,0,1,128,128,0,96,135,7,0,18,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,19,0,0,0,1,3,0,0,208,75,4,0,19,0,0,0,1,3,1,0,8,49,4,0,19,0,0,0,1,3,3,0,152,21,4,0,19,0,0,0,1,3,2,0,72,246,3,0,0,0,0,0,254,0,4,0,72,202,5,0,19,0,0,0,1,12,8,0,80,246,3,0,19,0,0,0,1,12,12,0,248,38,7,0,19,0,0,0,1,12,4,0,112,212,3,0,19,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,4,0,112,149,8,0,19,0,0,0,1,48,0,0,96,131,8,0,19,0,0,0,1,48,16,0,248,81,6,0,19,0,0,0,1,48,48,0,248,38,7,0,19,0,0,0,1,48,32,0,176,64,8,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,128,128,0,96,135,7,0,19,0,0,0,1,128,0,0,152,182,7,0,16,0,0,0,255,255,1,0,0,0,0,0,17,0,0,0,255,255,2,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,16,0,0,0,1,3,0,0,208,75,4,0,16,0,0,0,1,3,1,0,8,49,4,0,16,0,0,0,1,3,2,0,152,21,4,0,16,0,0,0,1,3,3,0,72,246,3,0,0,0,0,0,254,0,4,0,40,219,1,0,16,0,0,0,1,12,0,0,248,38,7,0,16,0,0,0,1,12,4,0,200,193,1,0,16,0,0,0,1,12,8,0,64,13,2,0,16,0,0,0,1,12,12,0,104,179,1,0,0,0,0,0,254,0,4,0,200,87,7,0,16,0,0,0,1,48,32,0,40,88,7,0,16,0,0,0,1,48,16,0,96,39,7,0,16,0,0,0,1,48,0,0,144,251,6,0,16,0,0,0,1,48,48,0,16,227,4,0,0,0,0,0,254,0,4,0,160,123,6,0,16,0,0,0,1,192,0,0,184,164,6,0,16,0,0,0,1,192,64,0,80,74,6,0,16,0,0,0,1,192,128,0,192,234,2,0,16,0,0,0,1,192,192,0,32,242,5,0,0,0,0,0,254,0,16,0,32,4,2,0,16,0,0,0,1,240,96,0,224,185,3,0,16,0,0,0,1,240,80,0,144,160,3,0,16,0,0,0,1,240,64,0,96,135,3,0,16,0,0,0,1,240,48,0,32,136,7,0,16,0,0,0,1,240,32,0,40,88,7,0,16,0,0,0,1,240,16,0,96,39,7,0,16,0,0,0,1,240,0,0,144,251,6,0,16,0,0,0,1,240,128,0,184,164,6,0,16,0,0,0,1,240,144,0,80,74,6,0,16,0,0,0,1,240,160,0,192,32,6,0,16,0,0,0,1,240,176,0,192,234,2,0,16,0,0,0,1,240,192,0,32,242,5,0,16,0,0,0,1,240,208,0,176,192,2,0,16,0,0,0,1,240,224,0,248,175,2,0,16,0,0,0,1,240,112,0,144,68,1,0,16,0,0,0,1,240,240,0,16,227,4,0,0,0,0,0,254,0,2,0,144,212,8,0,17,0,0,0,1,1,0,0,96,135,7,0,17,0,0,0,1,1,1,0,152,182,7,0,0,0,0,0,254,0,2,0,200,30,2,0,17,0,0,0,1,2,2,0,120,97,1,0,17,0,0,0,1,2,0,0,96,19,1,0,0,0,0,0,254,0,2,0,96,46,8,0,17,0,0,0,1,4,0,0,208,233,4,0,17,0,0,0,1,4,4,0,72,197,4,0,0,0,0,0,254,0,0,0,56,30,1,0,17,0,0,0,1,16,0,0,96,135,7,0,17,0,0,0,1,16,16,0,152,182,7,0,0,0,0,0,254,0,2,0,112,109,2,0,17,0,0,0,1,64,0,0,96,135,7,0,17,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,0,0,232,75,4,0,17,0,0,0,1,128,0,0,96,135,7,0,17,0,0,0,1,128,128,0,152,182,7,0,0,0,0,0,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,1,0,0,96,135,7,0,19,0,0,0,1,1,1,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,2,2,0,96,135,7,0,19,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,8,0,200,87,7,0,19,0,0,0,1,224,0,0,104,54,4,0,19,0,0,0,1,224,128,0,232,228,5,0,19,0,0,0,1,224,64,0,16,242,7,0,19,0,0,0,1,224,32,0,104,236,7,0,19,0,0,0,1,224,224,0,128,230,7,0,19,0,0,0,1,224,96,0,184,164,6,0,19,0,0,0,1,224,160,0,80,74,6,0,19,0,0,0,1,224,192,0,192,32,6,0,0,0,0,0,254,0,8,0,160,123,6,0,19,0,0,0,1,28,0,0,104,54,4,0,19,0,0,0,1,28,16,0,232,228,5,0,19,0,0,0,1,28,8,0,16,242,7,0,19,0,0,0,1,28,4,0,104,236,7,0,19,0,0,0,1,28,28,0,128,230,7,0,19,0,0,0,1,28,12,0,184,164,6,0,19,0,0,0,1,28,20,0,80,74,6,0,19,0,0,0,1,28,24,0,192,32,6,0,0,0,0,0,254,0,2,0,128,94,5,0,20,0,0,0,1,1,1,0,40,189,8,0,20,0,0,0,1,1,0,0,232,183,8,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,2,12,12,0,80,246,3,0,20,0,0,0,0,1,1,0,0,0,0,0,20,0,0,0,2,12,4,0,248,38,7,0,20,0,0,0,0,1,1,0,0,0,0,0,20,0,0,0,2,12,8,0,112,212,3,0,20,0,0,0,0,1,1,0,0,0,0,0,20,0,0,0,2,12,0,0,248,160,5,0,20,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,2,48,48,0,80,246,3,0,20,0,0,0,0,1,0,0,0,0,0,0,20,0,0,0,2,48,16,0,248,38,7,0,20,0,0,0,0,1,0,0,0,0,0,0,20,0,0,0,2,48,32,0,112,212,3,0,20,0,0,0,0,1,0,0,0,0,0,0,20,0,0,0,2,48,0,0,248,160,5,0,20,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,254,0,3,0,128,129,4,0,20,0,0,0,1,192,128,0,192,255,2,0,20,0,0,0,1,192,192,0,208,75,4,0,20,0,0,0,1,192,64,0,8,49,4,0,0,0,0,0,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,251,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,19,0,0,0,1,15,6,0,104,54,4,0,19,0,0,0,1,15,7,0,80,252,6,0,19,0,0,0,1,15,8,0,16,242,7,0,19,0,0,0,1,15,9,0,104,236,7,0,19,0,0,0,1,15,4,0,192,13,2,0,19,0,0,0,1,15,3,0,184,5,2,0,19,0,0,0,1,15,15,0,128,230,7,0,19,0,0,0,1,15,1,0,152,239,1,0,19,0,0,0,1,15,2,0,240,227,1,0,19,0,0,0,1,15,0,0,208,212,1,0,19,0,0,0,1,15,5,0,120,211,6,0,19,0,0,0,1,15,14,0,184,164,6,0,19,0,0,0,1,15,13,0,80,74,6,0,19,0,0,0,1,15,12,0,192,32,6,0,19,0,0,0,1,15,11,0,192,234,2,0,19,0,0,0,1,15,10,0,32,242,5,0,0,0,0,0,254,0,16,0,160,123,6,0,19,0,0,0,1,240,96,0,104,54,4,0,19,0,0,0,1,240,112,0,80,252,6,0,19,0,0,0,1,240,128,0,16,242,7,0,19,0,0,0,1,240,144,0,104,236,7,0,19,0,0,0,1,240,64,0,192,13,2,0,19,0,0,0,1,240,48,0,184,5,2,0,19,0,0,0,1,240,240,0,128,230,7,0,19,0,0,0,1,240,16,0,152,239,1,0,19,0,0,0,1,240,32,0,240,227,1,0,19,0,0,0,1,240,0,0,208,212,1,0,19,0,0,0,1,240,80,0,120,211,6,0,19,0,0,0,1,240,224,0,184,164,6,0,19,0,0,0,1,240,208,0,80,74,6,0,19,0,0,0,1,240,192,0,192,32,6,0,19,0,0,0,1,240,176,0,192,234,2,0,19,0,0,0,1,240,160,0,32,242,5,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,3,2,0,80,246,3,0,20,0,0,0,1,3,3,0,248,38,7,0,20,0,0,0,1,3,1,0,112,212,3,0,20,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,2,0,96,46,8,0,20,0,0,0,1,4,4,0,136,79,1,0,20,0,0,0,1,4,0,0,40,72,1,0,0,0,0,0,254,0,2,0,168,234,7,0,20,0,0,0,1,8,0,0,96,135,7,0,20,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,20,0,0,0,1,64,64,0,96,135,7,0,20,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,20,0,0,0,1,128,128,0,96,135,7,0,20,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,184,40,2,0,1,0,0,0,167,129,148,0,248,191,2,0,56,250,6,0,1,0,0,0,166,129,148,0,184,160,2,0,184,164,8,0,1,0,0,0,159,129,148,0,64,246,1,0,88,149,7,0,1,0,0,0,158,129,148,0,136,224,1,0,56,210,6,0,1,0,0,0,163,129,148,0,192,135,2,0,24,163,6,0,1,0,0,0,162,129,148,0,240,108,2,0,152,122,6,0,1,0,0,0,161,129,148,0,96,82,2,0,192,72,6,0,1,0,0,0,160,129,148,0,32,56,2,0,48,123,2,0,1,0,0,0,164,129,148,0,152,30,2,0,96,69,2,0,1,0,0,0,165,129,148,0,232,10,2,0,176,223,1,0,1,0,0,0,155,129,148,0,72,198,1,0,192,209,1,0,1,0,0,0,154,129,148,0,24,182,1,0,24,198,1,0,1,0,0,0,153,129,148,0,40,167,1,0,120,189,1,0,1,0,0,0,152,129,148,0,200,149,1,0,248,187,8,0,1,0,0,0,156,129,148,0,56,126,1,0,184,179,8,0,1,0,0,0,157,129,148,0,32,101,1,0,88,212,3,0,1,0,0,0,32,69,215,0,40,185,3,0,248,5,8,0,9,0,0,0,16,157,145,0,32,58,1,0,144,250,7,0,9,0,0,0,17,157,145,0,32,58,1,0,119,98,100,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,215,219,190,161,0,0,16,1,105,99,49,51,48,95,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,222,62,70,86,0,0,16,1,119,98,100,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,76,189,205,111,0,0,16,1,105,99,49,51,50,95,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,8,39,146,123,0,0,16,1,119,98,100,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,2,41,176,246,0,0,16,1,119,98,100,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,254,33,223,67,0,0,16,1,101,112,114,55,52,57,56,97,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,92,32,152,193,0,0,16,1,101,112,114,45,55,52,57,55,46,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,202,9,214,8,0,0,32,0,101,112,114,45,55,52,57,54,46,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,241,253,97,111,0,0,32,0,101,112,114,45,55,52,57,53,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,45,44,13,106,0,0,32,0,101,112,114,45,55,52,57,52,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,199,129,226,168,0,0,32,0,101,112,114,45,55,52,57,51,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,244,93,48,137,0,0,32,0,101,112,114,45,55,52,57,50,46,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,177,6,248,96,0,0,32,0,101,112,114,45,55,52,56,53,46,49,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,34,23,137,194,0,0,32,0,101,112,114,45,55,52,56,55,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,27,66,58,45,0,0,32,0,101,112,114,45,55,52,56,54,46,49,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,80,44,98,141,0,0,32,0,101,112,114,45,55,52,56,56,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,27,47,124,0,0,0,32,0,112,114,45,53,51,49,55,46,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,184,80,131,100,0,0,0,8,15,0,0,0,255,255,255,0,0,0,0,0,16,0,0,0,255,255,124,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,15,0,0,0,1,15,7,0,80,252,6,0,15,0,0,0,1,15,8,0,16,242,7,0,15,0,0,0,1,15,9,0,104,236,7,0,15,0,0,0,1,15,5,0,192,54,8,0,15,0,0,0,1,15,4,0,56,24,4,0,15,0,0,0,1,15,15,0,128,230,7,0,15,0,0,0,1,15,0,0,128,230,7,0,15,0,0,0,1,15,3,0,176,162,3,0,15,0,0,0,1,15,2,0,24,188,3,0,15,0,0,0,1,15,1,0,72,216,3,0,15,0,0,0,1,15,6,0,120,211,6,0,15,0,0,0,1,15,14,0,184,164,6,0,15,0,0,0,1,15,13,0,80,74,6,0,15,0,0,0,1,15,12,0,192,32,6,0,15,0,0,0,1,15,11,0,192,234,2,0,15,0,0,0,1,15,10,0,32,242,5,0,0,0,0,0,254,0,16,0,160,123,6,0,15,0,0,0,1,240,112,0,80,252,6,0,15,0,0,0,1,240,128,0,16,242,7,0,15,0,0,0,1,240,144,0,104,236,7,0,15,0,0,0,1,240,80,0,192,54,8,0,15,0,0,0,1,240,64,0,56,24,4,0,15,0,0,0,1,240,240,0,128,230,7,0,15,0,0,0,1,240,0,0,128,230,7,0,15,0,0,0,1,240,48,0,176,162,3,0,15,0,0,0,1,240,32,0,24,188,3,0,15,0,0,0,1,240,16,0,72,216,3,0,15,0,0,0,1,240,96,0,120,211,6,0,15,0,0,0,1,240,224,0,184,164,6,0,15,0,0,0,1,240,208,0,80,74,6,0,15,0,0,0,1,240,192,0,192,32,6,0,15,0,0,0,1,240,176,0,192,234,2,0,15,0,0,0,1,240,160,0,32,242,5,0,0,0,0,0,254,0,2,0,200,30,2,0,16,0,0,0,1,1,0,0,120,97,1,0,16,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,2,0,168,234,7,0,16,0,0,0,1,2,2,0,96,135,7,0,16,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,16,0,0,0,1,12,12,0,8,49,4,0,16,0,0,0,1,12,8,0,152,21,4,0,16,0,0,0,1,12,4,0,72,246,3,0,16,0,0,0,1,12,0,0,104,151,6,0,0,0,0,0,254,0,2,0,64,37,5,0,16,0,0,0,1,16,16,0,32,148,6,0,16,0,0,0,1,16,0,0,208,143,6,0,0,0,0,0,254,0,2,0,104,159,3,0,16,0,0,0,1,32,0,0,96,135,7,0,16,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,72,202,5,0,16,0,0,0,1,64,64,0,80,246,3,0,16,0,0,0,1,64,0,0,112,212,3,0,0,0,0,0,254,0,2,0,160,135,6,0,16,0,0,0,1,128,0,0,248,81,6,0,16,0,0,0,1,128,128,0,176,64,8,0,0,0,0,0,114,111,109,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,32,167,191,191,0,0,16,1,114,111,109,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,1,155,255,172,0,0,16,1,114,111,109,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,17,195,229,231,0,0,32,0,114,111,109,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,110,206,39,253,0,0,32,0,114,111,109,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,173,192,44,18,0,0,32,0,114,111,109,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,6,167,162,34,0,0,32,0,114,111,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,231,222,136,127,0,0,64,0,17,0,0,0,255,255,223,0,0,0,0,0,18,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,72,202,5,0,17,0,0,0,1,3,2,0,80,246,3,0,17,0,0,0,1,3,3,0,248,38,7,0,17,0,0,0,1,3,1,0,112,212,3,0,17,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,2,0,168,234,7,0,17,0,0,0,1,32,32,0,96,135,7,0,17,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,17,0,0,0,1,128,128,0,96,135,7,0,17,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,8,0,200,87,7,0,18,0,0,0,1,7,7,0,128,230,7,0,18,0,0,0,1,7,0,0,56,141,7,0,18,0,0,0,1,7,1,0,120,211,6,0,18,0,0,0,1,7,6,0,184,164,6,0,18,0,0,0,1,7,5,0,80,74,6,0,18,0,0,0,1,7,4,0,192,32,6,0,18,0,0,0,1,7,3,0,192,234,2,0,18,0,0,0,1,7,2,0,32,242,5,0,0,0,0,0,254,0,8,0,160,123,6,0,18,0,0,0,1,56,16,0,176,73,5,0,18,0,0,0,1,56,24,0,104,54,4,0,18,0,0,0,1,56,32,0,80,252,6,0,18,0,0,0,1,56,40,0,16,242,7,0,18,0,0,0,1,56,48,0,104,236,7,0,18,0,0,0,1,56,8,0,120,113,6,0,18,0,0,0,1,56,0,0,232,228,5,0,18,0,0,0,1,56,56,0,128,230,7,0,0,0,0,0,100,50,52,95,50,48,45,49,46,55,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,37,220,82,68,2,0,16,1,100,50,52,95,49,57,45,49,46,55,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,22,96,193,21,2,0,16,1,100,50,52,95,50,49,45,49,46,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,225,248,62,120,2,0,16,1,100,50,52,95,49,56,45,49,46,55,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,96,219,2,69,2,0,16,1,100,50,52,45,48,57,46,55,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,89,204,229,236,1,0,16,1,100,50,52,95,49,55,46,54,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,174,74,30,228,9,0,16,1,100,50,52,45,48,50,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,113,194,80,159,11,0,32,0,100,50,52,45,48,49,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,169,204,109,50,11,0,32,0,100,50,52,45,48,55,46,52,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,113,194,80,159,13,0,32,0,100,50,52,45,48,56,46,52,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,40,21,109,30,13,0,32,0,100,50,52,45,48,54,46,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,254,134,132,145,17,0,32,0,100,50,52,45,48,51,46,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,215,159,219,70,17,0,32,0,100,50,52,45,48,52,46,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,147,4,142,20,17,0,32,0,100,50,52,45,48,53,46,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,23,67,65,159,17,0,32,0,100,50,52,45,49,50,46,49,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,161,3,146,39,24,0,64,0,100,50,52,45,49,48,46,57,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,109,113,12,14,24,0,64,0,100,50,52,45,49,49,46,49,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,115,37,54,21,24,0,64,0,100,50,52,45,49,51,46,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,179,142,161,60,0,0,0,8,100,50,52,45,49,52,46,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,147,161,242,186,0,0,0,8,22,0,0,0,255,255,255,0,0,0,0,0,23,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,136,168,6,0,22,0,0,0,1,3,2,0,40,71,8,0,22,0,0,0,1,3,3,0,248,38,7,0,22,0,0,0,1,3,1,0,144,68,8,0,22,0,0,0,1,3,0,0,192,246,5,0,0,0,0,0,254,0,2,0,232,75,4,0,22,0,0,0,1,4,4,0,96,135,7,0,22,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,22,0,0,0,1,8,0,0,96,135,7,0,22,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,22,0,0,0,1,48,0,0,16,242,7,0,22,0,0,0,1,48,16,0,104,236,7,0,22,0,0,0,1,48,48,0,128,230,7,0,22,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,22,0,0,0,1,192,0,0,16,242,7,0,22,0,0,0,1,192,64,0,104,236,7,0,22,0,0,0,1,192,192,0,128,230,7,0,22,0,0,0,1,192,128,0,184,164,6,0,0,0,0,0,254,0,4,0,72,202,5,0,23,0,0,0,1,3,2,0,80,246,3,0,23,0,0,0,1,3,3,0,80,124,6,0,23,0,0,0,1,3,1,0,112,212,3,0,23,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,2,0,120,249,3,0,23,0,0,0,1,4,4,0,152,99,2,0,23,0,0,0,1,4,0,0,216,187,3,0,0,0,0,0,254,0,2,0,136,162,3,0,23,0,0,0,1,8,8,0,48,136,3,0,23,0,0,0,1,8,0,0,80,113,3,0,0,0,0,0,254,0,2,0,224,90,3,0,23,0,0,0,1,16,16,0,248,38,7,0,23,0,0,0,1,16,0,0,32,76,3,0,0,0,0,0,254,0,2,0,104,63,3,0,23,0,0,0,1,32,32,0,16,47,3,0,23,0,0,0,1,32,0,0,48,24,3,0,0,0,0,0,254,0,2,0,104,159,3,0,23,0,0,0,1,64,0,0,96,135,7,0,23,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,240,235,2,0,23,0,0,0,1,128,128,0,240,211,2,0,23,0,0,0,1,128,0,0,200,193,2,0,119,97,114,111,102,98,117,103,46,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,227,183,223,184,1,0,16,1,119,97,114,111,102,98,117,103,46,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,224,84,136,253,1,0,16,1,119,97,114,111,102,98,117,103,46,119,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,20,170,149,68,1,0,16,1,119,97,114,111,102,98,117,103,46,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,31,84,74,193,1,0,16,1,119,97,114,111,102,98,117,103,46,122,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,85,254,103,193,1,0,16,1,119,97,114,111,102,98,117,103,46,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,133,250,0,129,4,0,32,0,119,97,114,111,102,98,117,103,46,49,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,233,10,34,209,4,0,32,0,119,97,114,111,102,98,117,103,46,99,108,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,75,230,136,134,7,0,32,0,15,0,0,0,255,255,0,0,0,0,0,0,16,0,0,0,255,255,0,0,0,0,0,0,17,0,0,0,255,255,10,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,15,0,0,0,1,32,0,0,120,97,1,0,15,0,0,0,1,32,32,0,96,19,1,0,0,0,0,0,254,0,3,0,32,4,2,0,16,0,0,0,1,192,64,0,224,127,8,0,16,0,0,0,1,192,0,0,32,123,8,0,16,0,0,0,1,192,192,0,104,151,6,0,0,0,0,0,254,0,4,0,128,129,4,0,17,0,0,0,1,3,0,0,192,255,2,0,17,0,0,0,1,3,1,0,208,75,4,0,17,0,0,0,1,3,2,0,8,49,4,0,17,0,0,0,1,3,3,0,152,21,4,0,0,0,0,0,254,0,2,0,64,37,5,0,17,0,0,0,1,8,8,0,232,130,1,0,17,0,0,0,1,8,0,0,184,64,1,0,99,48,52,45,49,50,45,49,46,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,88,160,182,175,2,0,16,1,99,48,52,45,48,56,45,49,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,107,230,247,25,2,0,16,1,99,48,52,45,49,49,45,49,46,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,155,110,175,26,2,0,16,1,99,48,52,45,50,52,45,49,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,111,52,153,196,2,0,16,1,99,48,52,45,50,48,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,31,101,234,10,2,0,16,1,99,48,52,45,50,50,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,101,212,5,244,2,0,16,1,99,48,52,45,49,57,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,174,147,20,35,2,0,16,1,99,48,52,45,50,49,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,142,211,152,133,2,0,16,1,99,48,52,45,48,54,46,55,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,178,6,1,183,9,0,16,1,99,48,52,45,49,54,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,239,118,36,140,16,0,32,0,99,48,52,45,49,56,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,44,33,101,118,16,0,32,0,99,48,52,45,49,53,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,120,185,80,124,16,0,32,0,99,48,52,45,49,55,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,184,222,47,198,16,0,32,0,99,48,52,45,49,48,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,73,107,155,66,16,0,32,0,99,48,52,45,48,57,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,87,240,140,199,16,0,32,0,99,48,52,45,49,48,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,73,107,155,66,16,0,32,0,99,48,52,45,48,57,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,87,240,140,199,16,0,32,0,99,48,52,45,52,45,49,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,101,174,159,171,0,0,0,8,99,48,52,45,53,46,55,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,137,236,99,39,0,0,0,8,17,0,0,0,255,255,254,0,0,0,0,0,18,0,0,0,255,255,127,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,17,0,0,0,1,1,0,0,120,97,1,0,17,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,2,0,144,212,8,0,17,0,0,0,1,2,2,0,96,135,7,0,17,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,17,0,0,0,1,4,4,0,96,135,7,0,17,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,17,0,0,0,1,8,0,0,96,135,7,0,17,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,32,4,2,0,17,0,0,0,1,48,0,0,80,252,6,0,17,0,0,0,1,48,16,0,16,242,7,0,17,0,0,0,1,48,32,0,104,236,7,0,17,0,0,0,1,48,48,0,128,230,7,0,0,0,0,0,254,0,4,0,64,37,5,0,18,0,0,0,1,3,2,0,24,175,1,0,18,0,0,0,1,3,3,0,40,168,1,0,18,0,0,0,1,3,1,0,176,160,1,0,18,0,0,0,1,3,0,0,80,68,8,0,0,0,0,0,254,0,4,0,72,202,5,0,18,0,0,0,1,12,8,0,80,246,3,0,18,0,0,0,1,12,12,0,80,124,6,0,18,0,0,0,1,12,4,0,112,212,3,0,18,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,5,0,128,129,4,0,18,0,0,0,1,112,112,0,8,49,4,0,18,0,0,0,1,112,96,0,152,21,4,0,18,0,0,0,1,112,80,0,72,246,3,0,18,0,0,0,1,112,64,0,72,0,3,0,18,0,0,0,1,112,0,0,112,50,1,0,0,0,0,0,254,0,2,0,128,112,3,0,18,0,0,0,1,128,128,0,224,247,3,0,18,0,0,0,1,128,0,0,168,22,4,0,99,48,52,45,49,50,45,49,46,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,88,160,182,175,2,0,16,1,99,48,52,45,48,56,45,49,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,107,230,247,25,2,0,16,1,99,48,52,45,49,49,45,49,46,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,155,110,175,26,2,0,16,1,99,48,52,45,48,55,45,49,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,213,101,144,93,2,0,16,1,99,48,52,45,50,48,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,31,101,234,10,2,0,16,1,99,48,52,45,50,50,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,101,212,5,244,2,0,16,1,99,48,52,45,49,57,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,174,147,20,35,2,0,16,1,99,48,52,45,50,49,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,142,211,152,133,2,0,16,1,99,48,52,45,48,54,46,55,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,178,6,1,183,9,0,16,1,99,48,52,45,49,54,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,239,118,36,140,16,0,32,0,99,48,52,45,49,56,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,44,33,101,118,16,0,32,0,99,48,52,45,49,53,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,120,185,80,124,16,0,32,0,99,48,52,45,49,55,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,184,222,47,198,16,0,32,0,99,48,52,45,49,48,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,73,107,155,66,16,0,32,0,99,48,52,45,48,57,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,87,240,140,199,16,0,32,0,99,48,52,45,49,48,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,73,107,155,66,16,0,32,0,99,48,52,45,48,57,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,87,240,140,199,16,0,32,0,99,48,52,45,52,45,49,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,101,174,159,171,0,0,0,8,99,48,52,45,53,46,55,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,137,236,99,39,0,0,0,8,17,0,0,0,255,255,254,0,0,0,0,0,18,0,0,0,255,255,127,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,17,0,0,0,1,1,0,0,120,97,1,0,17,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,2,0,144,212,8,0,17,0,0,0,1,2,2,0,96,135,7,0,17,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,17,0,0,0,1,4,4,0,96,135,7,0,17,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,17,0,0,0,1,8,0,0,96,135,7,0,17,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,17,0,0,0,1,48,16,0,104,236,7,0,17,0,0,0,1,48,48,0,128,230,7,0,17,0,0,0,1,48,0,0,120,211,6,0,17,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,17,0,0,0,1,192,64,0,104,236,7,0,17,0,0,0,1,192,192,0,128,230,7,0,17,0,0,0,1,192,0,0,120,211,6,0,17,0,0,0,1,192,128,0,184,164,6,0,0,0,0,0,254,0,4,0,64,37,5,0,18,0,0,0,1,3,2,0,24,175,1,0,18,0,0,0,1,3,3,0,40,168,1,0,18,0,0,0,1,3,1,0,176,160,1,0,18,0,0,0,1,3,0,0,80,68,8,0,0,0,0,0,254,0,4,0,72,202,5,0,18,0,0,0,1,12,8,0,80,246,3,0,18,0,0,0,1,12,12,0,80,124,6,0,18,0,0,0,1,12,4,0,112,212,3,0,18,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,5,0,128,129,4,0,18,0,0,0,1,112,112,0,8,49,4,0,18,0,0,0,1,112,96,0,152,21,4,0,18,0,0,0,1,112,80,0,72,246,3,0,18,0,0,0,1,112,64,0,72,0,3,0,18,0,0,0,1,112,0,0,112,50,1,0,0,0,0,0,254,0,2,0,128,112,3,0,18,0,0,0,1,128,128,0,224,247,3,0,18,0,0,0,1,128,0,0,168,22,4,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,21,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,0,0,144,212,8,0,20,0,0,0,1,2,2,0,96,135,7,0,20,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,20,0,0,0,1,4,4,0,96,135,7,0,20,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,20,0,0,0,1,8,0,0,96,135,7,0,20,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,2,0,200,87,7,0,20,0,0,0,1,48,0,0,32,136,7,0,20,0,0,0,1,48,16,0,40,88,7,0,20,0,0,0,1,48,32,0,96,39,7,0,20,0,0,0,1,48,48,0,144,251,6,0,0,0,0,0,254,0,4,0,160,123,6,0,20,0,0,0,1,192,192,0,184,164,6,0,20,0,0,0,1,192,128,0,80,74,6,0,20,0,0,0,1,192,64,0,192,32,6,0,20,0,0,0,1,192,0,0,32,242,5,0,0,0,0,0,254,0,4,0,72,202,5,0,21,0,0,0,1,3,2,0,80,246,3,0,21,0,0,0,1,3,3,0,80,124,6,0,21,0,0,0,1,3,1,0,112,212,3,0,21,0,0,0,1,3,0,0,248,160,5,0,168,86,7,0,1,0,0,0,59,238,146,0,248,191,2,0,24,38,7,0,1,0,0,0,61,238,146,0,184,160,2,0,56,210,6,0,1,0,0,0,104,251,146,0,192,135,2,0,24,163,6,0,1,0,0,0,105,251,146,0,240,108,2,0,152,122,6,0,1,0,0,0,106,251,146,0,96,82,2,0,192,72,6,0,1,0,0,0,107,251,146,0,32,56,2,0,200,110,3,0,1,0,0,0,108,251,146,0,152,30,2,0,120,89,3,0,1,0,0,0,109,251,146,0,232,10,2,0,120,74,3,0,1,0,0,0,110,251,146,0,152,138,8,0,40,246,1,0,1,0,0,0,60,238,146,0,64,246,1,0,144,236,1,0,1,0,0,0,62,238,146,0,136,224,1,0,176,223,1,0,1,0,0,0,56,243,146,0,72,198,1,0,192,209,1,0,1,0,0,0,57,243,146,0,24,182,1,0,24,198,1,0,1,0,0,0,58,243,146,0,40,167,1,0,120,189,1,0,1,0,0,0,59,243,146,0,200,149,1,0,224,22,1,0,1,0,0,0,60,243,146,0,56,126,1,0,160,14,1,0,1,0,0,0,61,243,146,0,32,101,1,0,176,9,1,0,1,0,0,0,62,243,146,0,96,32,8,0,88,212,3,0,1,0,0,0,32,216,146,0,40,185,3,0,16,17,8,0,1,0,0,0,56,238,146,0,224,12,8,0,56,58,1,0,1,0,0,0,57,238,146,0,64,50,1,0,72,65,1,0,9,0,0,0,184,3,147,0,32,58,1,0,48,50,1,0,9,0,0,0,185,3,147,0,32,58,1,0,224,41,1,0,9,0,0,0,186,3,147,0,32,58,1,0,118,112,104,106,46,48,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,169,63,156,103,1,0,16,1,118,112,104,106,46,48,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,228,113,110,235,1,0,16,1,118,112,104,106,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,234,52,246,234,1,0,16,1,118,112,104,106,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,190,198,12,183,1,0,16,1,118,112,104,106,46,48,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,125,144,171,70,1,0,16,1,118,112,104,106,46,48,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,94,53,0,28,1,0,16,1,118,112,104,106,46,48,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,130,111,110,2,1,0,16,1,118,112,104,106,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,234,179,223,170,1,0,16,1,118,112,104,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,153,175,27,197,5,0,32,0,118,112,104,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,119,60,232,60,5,0,32,0,118,112,104,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,224,8,36,79,5,0,32,0,118,112,104,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,80,2,246,159,5,0,32,0,118,112,104,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,221,26,14,122,5,0,32,0,118,112,104,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,117,202,65,47,5,0,32,0,118,112,104,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,237,142,73,100,5,0,32,0,118,112,104,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,63,67,242,23,5,0,32,0,118,112,104,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,172,220,69,80,10,0,16,1,118,112,104,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,89,14,182,134,10,0,16,1,118,112,104,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,51,125,131,225,12,0,64,0,118,112,104,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,144,205,211,251,12,0,64,0,118,112,104,106,46,48,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,42,104,107,96,1,0,16,1,118,112,104,106,46,48,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,147,3,180,163,1,0,16,1,118,112,104,106,46,48,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,88,85,205,252,1,0,16,1,118,112,104,106,46,48,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,115,10,225,7,1,0,16,1,118,112,104,106,46,48,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,159,48,97,7,1,0,16,1,118,112,104,106,46,48,56,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,245,43,92,90,1,0,16,1,118,112,104,106,46,48,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,153,109,61,130,1,0,16,1,118,112,104,106,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,240,216,199,50,1,0,16,1,118,112,104,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,153,175,27,197,5,0,32,0,118,112,104,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,119,60,232,60,5,0,32,0,118,112,104,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0])
.concat([224,8,36,79,5,0,32,0,118,112,104,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,80,2,246,159,5,0,32,0,118,112,104,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,221,26,14,122,5,0,32,0,118,112,104,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,117,202,65,47,5,0,32,0,118,112,104,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,237,142,73,100,5,0,32,0,118,112,104,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,63,67,242,23,5,0,32,0,118,112,104,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,172,220,69,80,10,0,16,1,118,112,104,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,89,14,182,134,10,0,16,1,118,112,104,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,51,125,131,225,12,0,64,0,118,112,104,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,144,205,211,251,12,0,64,0,118,104,50,106,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,19,235,95,26,1,0,16,1,118,104,50,106,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,165,17,70,67,1,0,16,1,118,104,50,106,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,36,246,52,222,1,0,16,1,118,104,50,106,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,151,152,59,106,1,0,16,1,118,104,50,106,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,41,192,33,176,1,0,16,1,118,104,50,106,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,255,61,135,172,1,0,16,1,118,104,50,106,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,156,206,239,234,1,0,16,1,118,104,50,106,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,9,115,17,1,0,16,1,118,104,50,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,170,221,2,59,5,0,32,0,118,104,50,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,102,222,64,78,5,0,32,0,118,104,50,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,201,0,29,179,5,0,32,0,118,104,50,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,171,227,155,20,5,0,32,0,118,104,50,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,99,189,9,205,5,0,32,0,118,104,50,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,21,44,24,224,5,0,32,0,118,104,50,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,246,196,141,119,5,0,32,0,118,104,50,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,29,157,93,96,5,0,32,0,118,104,50,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,121,247,185,103,10,0,16,1,118,104,50,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,203,95,241,170,10,0,16,1,118,104,50,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,253,46,146,56,12,0,64,0,118,104,50,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,175,48,36,110,12,0,64,0,17,0,0,0,255,255,127,0,0,0,0,0,18,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,17,0,0,0,1,3,0,0,208,75,4,0,17,0,0,0,1,3,3,0,8,49,4,0,17,0,0,0,1,3,2,0,152,21,4,0,17,0,0,0,1,3,1,0,72,246,3,0,0,0,0,0,254,0,4,0,72,202,5,0,17,0,0,0,1,12,8,0,80,246,3,0,17,0,0,0,1,12,12,0,248,38,7,0,17,0,0,0,1,12,4,0,112,212,3,0,17,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,4,0,64,37,5,0,17,0,0,0,1,48,32,0,216,26,6,0,17,0,0,0,1,48,48,0,224,235,5,0,17,0,0,0,1,48,16,0,32,113,6,0,17,0,0,0,1,48,0,0,120,7,5,0,0,0,0,0,254,0,2,0,104,159,3,0,17,0,0,0,1,64,0,0,56,111,3,0,17,0,0,0,1,64,64,0,104,134,3,0,0,0,0,0,254,0,2,0,168,234,7,0,17,0,0,0,1,128,128,0,96,135,7,0,17,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,8,0,200,87,7,0,18,0,0,0,1,7,0,0,40,88,7,0,18,0,0,0,1,7,1,0,96,39,7,0,18,0,0,0,1,7,7,0,144,251,6,0,18,0,0,0,1,7,6,0,184,164,6,0,18,0,0,0,1,7,5,0,80,74,6,0,18,0,0,0,1,7,4,0,192,32,6,0,18,0,0,0,1,7,3,0,192,234,2,0,18,0,0,0,1,7,2,0,32,242,5,0,0,0,0,0,254,0,8,0,160,123,6,0,18,0,0,0,1,56,0,0,40,88,7,0,18,0,0,0,1,56,8,0,96,39,7,0,18,0,0,0,1,56,56,0,144,251,6,0,18,0,0,0,1,56,48,0,184,164,6,0,18,0,0,0,1,56,40,0,80,74,6,0,18,0,0,0,1,56,32,0,192,32,6,0,18,0,0,0,1,56,24,0,192,234,2,0,18,0,0,0,1,56,16,0,32,242,5,0,0,0,0,0,254,0,2,0,144,212,8,0,18,0,0,0,1,64,64,0,96,135,7,0,18,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,18,0,0,0,1,128,128,0,96,135,7,0,18,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,21,0,0,0,255,255,255,0,0,0,0,0,22,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,20,0,0,0,1,15,2,0,32,136,7,0,20,0,0,0,1,15,5,0,40,88,7,0,20,0,0,0,1,15,8,0,96,39,7,0,20,0,0,0,1,15,4,0,120,113,6,0,20,0,0,0,1,15,1,0,232,228,5,0,20,0,0,0,1,15,15,0,144,251,6,0,20,0,0,0,1,15,3,0,56,141,7,0,20,0,0,0,1,15,7,0,120,211,6,0,20,0,0,0,1,15,14,0,184,164,6,0,20,0,0,0,1,15,6,0,24,1,7,0,20,0,0,0,1,15,13,0,80,74,6,0,20,0,0,0,1,15,12,0,192,32,6,0,20,0,0,0,1,15,11,0,192,234,2,0,20,0,0,0,1,15,10,0,32,242,5,0,20,0,0,0,1,15,9,0,176,192,2,0,20,0,0,0,1,15,0,0,16,227,4,0,0,0,0,0,254,0,16,0,160,123,6,0,20,0,0,0,1,240,32,0,32,136,7,0,20,0,0,0,1,240,80,0,40,88,7,0,20,0,0,0,1,240,128,0,96,39,7,0,20,0,0,0,1,240,0,0,192,24,7,0,20,0,0,0,1,240,64,0,120,113,6,0,20,0,0,0,1,240,16,0,232,228,5,0,20,0,0,0,1,240,240,0,144,251,6,0,20,0,0,0,1,240,48,0,56,141,7,0,20,0,0,0,1,240,112,0,120,211,6,0,20,0,0,0,1,240,224,0,184,164,6,0,20,0,0,0,1,240,96,0,24,1,7,0,20,0,0,0,1,240,208,0,80,74,6,0,20,0,0,0,1,240,192,0,192,32,6,0,20,0,0,0,1,240,176,0,192,234,2,0,20,0,0,0,1,240,160,0,32,242,5,0,20,0,0,0,1,240,144,0,176,192,2,0,0,0,0,0,254,0,4,0,128,129,4,0,21,0,0,0,1,3,0,0,192,255,2,0,21,0,0,0,1,3,2,0,208,75,4,0,21,0,0,0,1,3,3,0,8,49,4,0,21,0,0,0,1,3,1,0,152,21,4,0,0,0,0,0,254,0,4,0,72,202,5,0,21,0,0,0,1,12,8,0,80,246,3,0,21,0,0,0,1,12,12,0,248,38,7,0,21,0,0,0,1,12,4,0,112,212,3,0,21,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,2,0,144,212,8,0,21,0,0,0,1,16,16,0,96,135,7,0,21,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,21,0,0,0,1,32,0,0,96,135,7,0,21,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,64,37,5,0,21,0,0,0,1,64,64,0,0,64,7,0,21,0,0,0,1,64,0,0,248,231,2,0,0,0,0,0,254,0,2,0,232,75,4,0,21,0,0,0,1,128,128,0,96,135,7,0,21,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,101,112,114,45,53,54,55,57,46,49,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,194,249,242,196,0,0,16,1,101,112,114,45,53,54,56,48,46,49,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,28,2,127,131,0,0,16,1,101,112,114,45,53,54,56,49,46,49,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,126,255,199,225,0,0,16,1,101,112,114,45,53,54,56,50,46,49,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,30,220,94,74,0,0,16,1,101,112,114,45,53,53,50,48,46,49,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,223,251,141,32,0,0,16,1,101,112,114,45,53,54,56,52,46,49,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,218,149,250,50,0,0,16,1,101,112,114,45,53,53,50,56,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,171,68,205,0,0,0,16,1,101,112,114,45,53,53,50,55,46,56,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,241,22,214,178,0,0,32,0,101,112,114,45,53,53,50,54,46,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,194,51,139,138,0,0,32,0,101,112,114,45,53,53,50,53,46,56,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,239,197,73,231,0,0,32,0,101,112,114,45,53,53,50,52,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,82,105,136,139,0,0,32,0,101,112,114,45,53,53,50,51,46,56,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,217,53,222,222,0,0,32,0,101,112,114,45,53,53,50,50,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,255,157,109,94,0,0,32,0,101,112,114,45,53,53,49,52,46,56,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,139,168,192,252,0,0,32,0,101,112,114,45,53,53,49,53,46,57,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,56,136,144,96,0,0,32,0,112,114,45,53,51,49,55,46,49,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,184,80,131,100,0,0,0,8,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,21,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,1,1,0,96,135,7,0,19,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,2,0,0,96,135,7,0,19,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,2,0,128,111,8,0,19,0,0,0,1,8,8,0,96,135,7,0,19,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,128,128,0,96,135,7,0,19,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,3,2,0,192,255,2,0,20,0,0,0,1,3,3,0,208,75,4,0,20,0,0,0,1,3,1,0,8,49,4,0,20,0,0,0,1,3,0,0,152,21,4,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,12,8,0,80,246,3,0,20,0,0,0,1,12,12,0,248,38,7,0,20,0,0,0,1,12,4,0,112,212,3,0,20,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,16,0,32,4,2,0,20,0,0,0,1,240,160,0,144,160,3,0,20,0,0,0,1,240,176,0,96,135,3,0,20,0,0,0,1,240,192,0,32,136,7,0,20,0,0,0,1,240,208,0,40,88,7,0,20,0,0,0,1,240,16,0,40,28,4,0,20,0,0,0,1,240,224,0,96,39,7,0,20,0,0,0,1,240,32,0,192,24,7,0,20,0,0,0,1,240,48,0,120,113,6,0,20,0,0,0,1,240,240,0,144,251,6,0,20,0,0,0,1,240,64,0,120,211,6,0,20,0,0,0,1,240,144,0,184,164,6,0,20,0,0,0,1,240,128,0,80,74,6,0,20,0,0,0,1,240,112,0,192,32,6,0,20,0,0,0,1,240,96,0,192,234,2,0,20,0,0,0,1,240,80,0,32,242,5,0,20,0,0,0,1,240,0,0,16,227,4,0,21,0,0,0,255,255,255,0,0,0,0,0,22,0,0,0,255,255,116,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,21,0,0,0,1,15,2,0,80,252,6,0,21,0,0,0,1,15,5,0,16,242,7,0,21,0,0,0,1,15,8,0,104,236,7,0,21,0,0,0,1,15,4,0,120,113,6,0,21,0,0,0,1,15,1,0,232,228,5,0,21,0,0,0,1,15,15,0,128,230,7,0,21,0,0,0,1,15,3,0,56,141,7,0,21,0,0,0,1,15,7,0,120,211,6,0,21,0,0,0,1,15,14,0,184,164,6,0,21,0,0,0,1,15,6,0,24,1,7,0,21,0,0,0,1,15,13,0,80,74,6,0,21,0,0,0,1,15,12,0,192,32,6,0,21,0,0,0,1,15,11,0,192,234,2,0,21,0,0,0,1,15,10,0,32,242,5,0,21,0,0,0,1,15,9,0,176,192,2,0,21,0,0,0,1,15,0,0,16,227,4,0,0,0,0,0,254,0,16,0,160,123,6,0,21,0,0,0,1,240,32,0,80,252,6,0,21,0,0,0,1,240,80,0,16,242,7,0,21,0,0,0,1,240,128,0,104,236,7,0,21,0,0,0,1,240,64,0,120,113,6,0,21,0,0,0,1,240,16,0,232,228,5,0,21,0,0,0,1,240,240,0,128,230,7,0,21,0,0,0,1,240,48,0,56,141,7,0,21,0,0,0,1,240,112,0,120,211,6,0,21,0,0,0,1,240,224,0,184,164,6,0,21,0,0,0,1,240,96,0,24,1,7,0,21,0,0,0,1,240,208,0,80,74,6,0,21,0,0,0,1,240,192,0,192,32,6,0,21,0,0,0,1,240,176,0,192,234,2,0,21,0,0,0,1,240,160,0,32,242,5,0,21,0,0,0,1,240,144,0,176,192,2,0,21,0,0,0,1,240,0,0,136,143,5,0,0,0,0,0,254,0,2,0,104,159,3,0,22,0,0,0,1,4,0,0,56,111,3,0,22,0,0,0,1,4,4,0,104,134,3,0,0,0,0,0,254,0,2,0,168,234,7,0,22,0,0,0,1,8,8,0,96,135,7,0,22,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,22,0,0,0,1,48,16,0,80,246,3,0,22,0,0,0,1,48,48,0,248,38,7,0,22,0,0,0,1,48,32,0,112,212,3,0,22,0,0,0,1,48,0,0,24,99,5,0,0,0,0,0,254,0,2,0,144,212,6,0,22,0,0,0,1,64,64,0,8,208,6,0,22,0,0,0,1,64,0,0,88,204,6,0,117,101,99,106,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,76,10,196,148,1,0,16,1,117,101,99,106,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,9,58,110,141,1,0,16,1,117,101,99,106,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,215,236,4,134,1,0,16,1,117,101,99,106,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,31,211,225,183,1,0,16,1,117,101,99,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,54,20,175,220,5,0,32,0,117,101,99,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,65,223,7,40,5,0,32,0,117,101,99,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,2,141,112,138,5,0,32,0,117,101,99,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,239,224,123,222,5,0,32,0,117,101,99,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,88,53,0,26,5,0,32,0,117,101,99,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,249,166,248,79,5,0,32,0,117,101,99,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,18,174,103,177,5,0,32,0,117,101,99,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,194,189,100,16,5,0,32,0,117,101,99,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,21,189,53,194,10,0,16,1,117,101,99,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,57,93,178,129,12,0,64,0,117,101,99,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,82,158,114,39,12,0,64,0,98,56,55,45,49,49,46,117,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,153,163,132,252,2,0,16,1,98,56,55,45,49,48,46,117,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,6,23,24,23,2,0,16,1,98,56,55,45,48,55,46,49,51,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,160,239,224,226,9,0,16,1,98,56,55,45,48,50,46,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,160,67,173,137,15,0,32,0,98,56,55,45,48,49,46,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,225,42,232,129,15,0,32,0,98,56,55,45,48,52,46,51,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,182,52,132,149,15,0,32,0,98,56,55,45,48,51,46,51,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,224,90,21,206,15,0,32,0,21,0,0,0,255,255,255,0,0,0,0,0,22,0,0,0,255,255,127,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,21,0,0,0,1,2,2,0,96,135,7,0,21,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,21,0,0,0,1,4,4,0,96,135,7,0,21,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,21,0,0,0,1,8,0,0,96,135,7,0,21,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,21,0,0,0,1,48,0,0,80,252,6,0,21,0,0,0,1,48,16,0,16,242,7,0,21,0,0,0,1,48,32,0,104,236,7,0,21,0,0,0,1,48,48,0,128,230,7,0,0,0,0,0,254,0,4,0,160,123,6,0,21,0,0,0,1,192,192,0,8,201,6,0,21,0,0,0,1,192,128,0,200,197,6,0,21,0,0,0,1,192,64,0,152,194,6,0,21,0,0,0,1,192,0,0,248,189,6,0,0,0,0,0,254,0,4,0,72,202,5,0,22,0,0,0,1,3,2,0,80,246,3,0,22,0,0,0,1,3,3,0,80,124,6,0,22,0,0,0,1,3,1,0,112,212,3,0,22,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,64,37,5,0,22,0,0,0,1,12,12,0,248,46,3,0,22,0,0,0,1,12,8,0])
.concat([224,23,3,0,22,0,0,0,1,12,4,0,152,99,2,0,22,0,0,0,1,12,0,0,240,191,4,0,0,0,0,0,254,0,4,0,128,129,4,0,22,0,0,0,1,48,0,0,208,75,4,0,22,0,0,0,1,48,48,0,8,49,4,0,22,0,0,0,1,48,16,0,152,21,4,0,22,0,0,0,1,48,32,0,72,246,3,0,0,0,0,0,254,0,2,0,104,159,3,0,22,0,0,0,1,128,128,0,96,135,7,0,22,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,19,0,0,0,255,255,247,0,0,0,0,0,20,0,0,0,255,255,243,0,0,0,0,0,21,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,192,76,8,0,19,0,0,0,1,1,1,0,64,246,3,0,19,0,0,0,1,1,0,0,248,201,3,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,2,2,0,96,135,7,0,19,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,4,4,0,96,135,7,0,19,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,200,30,2,0,19,0,0,0,1,8,0,0,120,97,1,0,19,0,0,0,1,8,8,0,96,19,1,0,0,0,0,0,254,0,4,0,200,87,7,0,19,0,0,0,1,48,16,0,96,39,7,0,19,0,0,0,1,48,48,0,144,251,6,0,19,0,0,0,1,48,0,0,120,211,6,0,19,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,19,0,0,0,1,192,64,0,96,39,7,0,19,0,0,0,1,192,192,0,144,251,6,0,19,0,0,0,1,192,0,0,120,211,6,0,19,0,0,0,1,192,128,0,184,164,6,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,3,3,0,248,38,7,0,20,0,0,0,1,3,2,0,80,246,3,0,20,0,0,0,1,3,1,0,112,212,3,0,20,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,64,37,5,0,20,0,0,0,1,12,12,0,48,129,4,0,20,0,0,0,1,12,8,0,64,190,3,0,20,0,0,0,1,12,4,0,112,186,3,0,20,0,0,0,1,12,0,0,192,183,3,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,48,16,0,192,255,2,0,20,0,0,0,1,48,0,0,208,75,4,0,20,0,0,0,1,48,48,0,8,49,4,0,20,0,0,0,1,48,32,0,72,246,3,0,0,0,0,0,254,0,2,0,192,76,8,0,20,0,0,0,1,64,64,0,144,237,7,0,20,0,0,0,1,64,64,0,16,77,4,0,0,0,0,0,254,0,2,0,32,176,1,0,20,0,0,0,1,128,128,0,192,255,2,0,20,0,0,0,1,128,0,0,208,75,4,0,117,104,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,56,199,188,224,0,0,16,1,117,105,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,81,100,238,163,0,0,16,1,117,97,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,155,244,175,165,0,0,32,0,117,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,151,59,59,248,0,0,32,0,117,97,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,185,255,252,77,0,0,32,0,117,104,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,8,205,90,61,0,0,64,0,115,114,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,196,82,244,130,0,0,64,0,115,114,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,230,81,158,16,0,0,64,0,18,0,0,0,255,255,255,0,0,0,0,0,19,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,168,234,7,0,18,0,0,0,1,2,0,0,96,135,7,0,18,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,8,0,160,123,6,0,18,0,0,0,1,28,16,0,32,136,7,0,18,0,0,0,1,28,8,0,40,88,7,0,18,0,0,0,1,28,24,0,96,39,7,0,18,0,0,0,1,28,28,0,144,251,6,0,18,0,0,0,1,28,12,0,184,164,6,0,18,0,0,0,1,28,20,0,80,74,6,0,18,0,0,0,1,28,4,0,192,32,6,0,18,0,0,0,1,28,0,0,16,227,4,0,0,0,0,0,254,0,8,0,200,87,7,0,18,0,0,0,1,224,128,0,32,136,7,0,18,0,0,0,1,224,64,0,40,88,7,0,18,0,0,0,1,224,192,0,96,39,7,0,18,0,0,0,1,224,224,0,144,251,6,0,18,0,0,0,1,224,96,0,184,164,6,0,18,0,0,0,1,224,160,0,80,74,6,0,18,0,0,0,1,224,32,0,192,32,6,0,18,0,0,0,1,224,0,0,16,227,4,0,0,0,0,0,254,0,4,0,72,202,5,0,19,0,0,0,1,12,12,0,80,246,3,0,19,0,0,0,1,12,4,0,248,38,7,0,19,0,0,0,1,12,8,0,112,212,3,0,19,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,4,0,128,129,4,0,19,0,0,0,1,192,64,0,208,75,4,0,19,0,0,0,1,192,192,0,8,49,4,0,19,0,0,0,1,192,128,0,152,21,4,0,19,0,0,0,1,192,0,0,72,246,3,0,0,0,0,0,10,0,0,0,255,255,255,0,0,0,0,0,11,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,8,0,200,87,7,0,10,0,0,0,1,7,5,0,184,220,8,0,10,0,0,0,1,7,6,0,200,92,8,0,10,0,0,0,1,7,7,0,56,37,8,0,10,0,0,0,1,7,4,0,96,240,7,0,10,0,0,0,1,7,3,0,128,188,7,0,10,0,0,0,1,7,2,0,184,46,7,0,10,0,0,0,1,7,1,0,120,251,7,0,10,0,0,0,1,7,0,0,248,140,7,0,0,0,0,0,254,0,8,0,200,87,7,0,10,0,0,0,1,56,40,0,184,220,8,0,10,0,0,0,1,56,48,0,200,92,8,0,10,0,0,0,1,56,56,0,56,37,8,0,10,0,0,0,1,56,32,0,96,240,7,0,10,0,0,0,1,56,24,0,128,188,7,0,10,0,0,0,1,56,16,0,184,46,7,0,10,0,0,0,1,56,8,0,120,251,7,0,10,0,0,0,1,56,0,0,248,140,7,0,0,0,0,0,254,0,2,0,80,237,7,0,10,0,0,0,1,64,64,0,96,135,7,0,10,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,10,0,0,0,1,128,128,0,96,135,7,0,10,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,40,153,1,0,11,0,0,0,1,1,1,0,96,135,7,0,11,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,160,142,1,0,11,0,0,0,1,2,2,0,96,135,7,0,11,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,11,0,0,0,1,4,0,0,96,135,7,0,11,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,11,0,0,0,1,24,16,0,80,246,3,0,11,0,0,0,1,24,24,0,248,38,7,0,11,0,0,0,1,24,8,0,112,212,3,0,11,0,0,0,1,24,0,0,248,160,5,0,0,0,0,0,254,0,2,0,200,71,1,0,11,0,0,0,1,32,32,0,120,76,7,0,11,0,0,0,1,32,0,0,248,63,7,0,0,0,0,0,254,0,2,0,128,129,4,0,11,0,0,0,1,64,64,0,208,75,4,0,11,0,0,0,1,64,0,0,8,49,4,0,0,0,0,0,254,0,2,0,208,24,1,0,11,0,0,0,1,128,128,0,192,15,1,0,11,0,0,0,1,128,0,0,248,10,1,0,0,0,0,0,116,104,117,109,98,112,111,112,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,225,22,176,52,0,0,16,1,116,104,117,109,98,112,111,112,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,113,28,80,137,0,0,16,1,116,104,117,109,98,112,111,112,46,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,180,170,149,7,0,0,32,0,116,104,117,109,98,112,111,112,46,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,67,223,88,173,0,0,32,0,109,97,112,45,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,9,250,31,232,0,0,32,0,109,97,112,45,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,254,156,135,140,0,0,32,0,116,104,117,109,98,112,111,112,46,115,110,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,93,241,187,250,0,0,64,0,112,105,99,95,49,54,99,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,76,45,0,0,0,0,0,0,0,0,0,16,17,0,0,0,255,255,28,0,0,0,0,0,18,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,3,0,200,30,2,0,17,0,0,0,1,3,0,0,72,60,1,0,17,0,0,0,1,3,2,0,88,51,1,0,17,0,0,0,1,3,3,0,96,19,1,0,0,0,0,0,254,0,8,0,40,148,2,0,17,0,0,0,1,28,16,0,208,168,3,0,17,0,0,0,1,28,12,0,176,109,2,0,17,0,0,0,1,28,8,0,64,119,3,0,17,0,0,0,1,28,28,0,88,229,1,0,17,0,0,0,1,28,24,0,176,123,2,0,17,0,0,0,1,28,20,0,184,202,1,0,17,0,0,0,1,28,4,0,8,192,1,0,17,0,0,0,1,28,0,0,120,7,5,0,0,0,0,0,254,0,4,0,0,70,2,0,18,0,0,0,1,3,0,0,56,233,4,0,18,0,0,0,1,3,3,0,16,42,5,0,18,0,0,0,1,3,2,0,152,11,5,0,18,0,0,0,1,3,1,0,24,27,4,0,0,0,0,0,254,0,4,0,192,56,2,0,18,0,0,0,1,12,0,0,176,193,3,0,18,0,0,0,1,12,4,0,208,196,4,0,18,0,0,0,1,12,8,0,56,233,4,0,18,0,0,0,1,12,12,0,16,42,5,0,0,0,0,0,254,0,4,0,128,129,4,0,18,0,0,0,1,48,32,0,208,75,4,0,18,0,0,0,1,48,48,0,8,49,4,0,18,0,0,0,1,48,16,0,152,21,4,0,18,0,0,0,1,48,0,0,72,246,3,0,0,0,0,0,254,0,2,0,232,80,3,0,18,0,0,0,1,64,64,0,96,135,7,0,18,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,72,217,6,0,18,0,0,0,1,128,0,0,56,111,3,0,18,0,0,0,1,128,128,0,104,134,3,0,116,100,52,46,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,106,212,166,21,1,0,16,1,116,99,51,46,50,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,192,210,38,188,1,0,16,1,116,101,50,46,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,16,92,2,2,1,0,16,1,116,100,49,46,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,43,196,171,233,1,0,16,1,116,97,54,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,111,189,28,213,4,0,32,0,116,97,55,46,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,89,0,28,242,4,0,32,0,116,97,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,223,117,79,98,7,0,32,0,20,0,0,0,255,255,127,0,0,0,0,0,21,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,200,87,7,0,20,0,0,0,1,3,0,0,40,88,7,0,20,0,0,0,1,3,1,0,96,39,7,0,20,0,0,0,1,3,3,0,144,251,6,0,20,0,0,0,1,3,2,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,20,0,0,0,1,12,0,0,40,88,7,0,20,0,0,0,1,12,4,0,96,39,7,0,20,0,0,0,1,12,12,0,144,251,6,0,20,0,0,0,1,12,8,0,184,164,6,0,0,0,0,0,254,0,0,0,168,234,7,0,20,0,0,0,1,32,0,0,96,135,7,0,20,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,21,0,0,0,1,3,0,0,232,99,5,0,21,0,0,0,1,3,1,0,208,7,8,0,21,0,0,0,1,3,3,0,176,2,8,0,21,0,0,0,1,3,2,0,216,138,4,0,0,0,0,0,254,0,4,0,160,154,5,0,21,0,0,0,1,12,8,0,216,123,5,0,21,0,0,0,1,12,12,0,224,93,5,0,21,0,0,0,1,12,4,0,184,63,5,0,21,0,0,0,1,12,0,0,216,31,5,0,0,0,0,0,254,0,2,0,112,1,5,0,21,0,0,0,1,16,0,0,208,75,4,0,21,0,0,0,1,16,16,0,8,49,4,0,17,0,0,0,255,255,0,0,0,0,0,0,18,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,4,0,160,123,6,0,17,0,0,0,1,3,1,0,224,67,5,0,17,0,0,0,1,3,3,0,192,135,6,0,17,0,0,0,1,3,0,0,200,201,5,0,17,0,0,0,1,3,2,0,144,127,5,0,0,0,0,0,254,0,4,0,200,87,7,0,17,0,0,0,1,12,8,0,216,36,5,0,17,0,0,0,1,12,4,0,224,67,5,0,17,0,0,0,1,12,12,0,192,135,6,0,17,0,0,0,1,12,0,0,200,201,5,0,0,0,0,0,254,0,2,0,128,129,4,0,17,0,0,0,1,16,0,0,8,49,4,0,17,0,0,0,1,16,16,0,72,246,3,0,0,0,0,0,254,0,2,0,64,37,5,0,17,0,0,0,1,32,0,0,104,91,7,0,17,0,0,0,1,32,32,0,144,84,7,0,0,0,0,0,254,0,2,0,72,202,5,0,17,0,0,0,1,64,0,0,104,80,7,0,17,0,0,0,1,64,64,0,152,77,7,0,0,0,0,0,254,0,2,0,136,73,7,0,17,0,0,0,1,128,0,0,72,246,3,0,17,0,0,0,1,128,128,0,248,168,7,0,0,0,0,0,254,0,2,0,200,30,2,0,18,0,0,0,1,1,1,0,120,97,1,0,18,0,0,0,1,1,0,0,96,19,1,0,0,0,0,0,254,0,2,0,112,109,2,0,18,0,0,0,1,64,0,0,96,135,7,0,18,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,4,0,200,59,7,0,18,0,0,0,1,128,0,0,96,135,7,0,18,0,0,0,1,128,128,0,152,182,7,0,0,0,0,0,11,0,0,0,255,255,255,0,0,0,0,0,12,0,0,0,255,255,219,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,11,0,0,0,1,15,7,0,80,252,6,0,11,0,0,0,1,15,8,0,16,242,7,0,11,0,0,0,1,15,9,0,104,236,7,0,11,0,0,0,1,15,5,0,176,51,4,0,11,0,0,0,1,15,4,0,56,24,4,0,11,0,0,0,1,15,15,0,128,230,7,0,11,0,0,0,1,15,1,0,72,216,3,0,11,0,0,0,1,15,2,0,24,188,3,0,11,0,0,0,1,15,3,0,176,162,3,0,11,0,0,0,1,15,6,0,120,211,6,0,11,0,0,0,1,15,14,0,184,164,6,0,11,0,0,0,1,15,13,0,80,74,6,0,11,0,0,0,1,15,12,0,192,32,6,0,11,0,0,0,1,15,11,0,192,234,2,0,11,0,0,0,1,15,10,0,32,242,5,0,11,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,11,0,0,0,1,240,112,0,80,252,6,0,11,0,0,0,1,240,128,0,16,242,7,0,11,0,0,0,1,240,144,0,104,236,7,0,11,0,0,0,1,240,80,0,176,51,4,0,11,0,0,0,1,240,64,0,56,24,4,0,11,0,0,0,1,240,240,0,128,230,7,0,11,0,0,0,1,240,16,0,72,216,3,0,11,0,0,0,1,240,32,0,24,188,3,0,11,0,0,0,1,240,48,0,176,162,3,0,11,0,0,0,1,240,96,0,120,211,6,0,11,0,0,0,1,240,224,0,184,164,6,0,11,0,0,0,1,240,208,0,80,74,6,0,11,0,0,0,1,240,192,0,192,32,6,0,11,0,0,0,1,240,176,0,192,234,2,0,11,0,0,0,1,240,160,0,32,242,5,0,11,0,0,0,1,240,0,0,208,236,2,0,0,0,0,0,254,0,1,0,200,30,2,0,12,0,0,0,1,3,3,0,120,247,1,0,0,0,0,0,254,0,2,0,168,234,7,0,12,0,0,0,1,4,4,0,96,135,7,0,12,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,208,26,7,0,12,0,0,0,1,8,0,0,96,238,1,0,12,0,0,0,1,8,8,0,152,124,2,0,0,0,0,0,254,0,4,0,56,154,6,0,12,0,0,0,1,48,32,0,200,99,2,0,12,0,0,0,1,48,48,0,32,84,2,0,12,0,0,0,1,48,16,0,16,71,2,0,12,0,0,0,1,48,0,0,168,57,2,0,0,0,0,0,254,0,4,0,72,202,5,0,12,0,0,0,1,192,128,0,80,246,3,0,12,0,0,0,1,192,192,0,248,38,7,0,12,0,0,0,1,192,64,0,112,212,3,0,12,0,0,0,1,192,0,0,248,160,5,0,101,112,114,45,49,50,53,48,57,46,49,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,138,110,34,222,1,0,16,1,101,112,114,45,49,50,53,48,56,46,49,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,32,252,162,159,1,0,16,1,101,112,114,45,49,50,53,49,49,46,49,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,15,242,127,173,1,0,16,1,101,112,114,45,49,50,53,49,48,46,49,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,150,97,237,160,1,0,16,1,101,112,114,45,49,50,50,57,51,46,49,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,234,30,50,244,1,0,16,1,101,112,114,45,49,50,50,57,50,46,49,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,240,138,217,81,1,0,16,1,111,112,114,45,49,50,50,57,53,46,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,132,58,58,212,9,0,16,1,111,112,114,45,49,50,50,57,52,46,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,211,207,205,39,9,0,16,1,111,112,114,45,49,50,50,57,55,46,55,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,119,86,155,29,9,0,16,1,111,112,114,45,49,50,50,57,54,46,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,113,54,81,10,9,0,16,1,111,112,114,45,49,50,51,50,51,46,49,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,111,58,228,77,2,0,32,0,111,112,114,45,49,50,51,50,52,46,49,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,85,122,96,36,2,0,32,0,111,112,114,45,49,50,51,50,53,46,49,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,122,19,5,20,2,0,32,0,109,112,114,45,49,50,51,51,54,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,199,101,164,221,3,0,32,0,109,112,114,45,49,50,51,51,55,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,209,51,130,130,3,0,32,0,109,112,114,45,49,50,51,51,56,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,244,181,180,70,3,0,32,0,109,112,114,45,49,50,51,51,57,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,171,59,126,13,3,0,32,0,109,112,114,45,49,50,51,54,52,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,101,62,184,164,3,0,32,0,109,112,114,45,49,50,51,54,53,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,169,178,128,74,3,0,32,0,109,112,114,45,49,50,51,54,54,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,171,179,92,56,3,0,32,0,109,112,114,45,49,50,51,54,55,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,74,37,48,73,3,0,32,0,101,112,114,45,49,50,50,57,57,46,52,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,27,196,155,252,10,0,32,0,101,112,114,45,49,50,50,57,56,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,27,196,155,252,10,0,32,0,101,112,114,45,49,50,51,48,48,46,56,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,17,112,255,232,4,0,16,1,111,112,114,45,49,50,51,48,49,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,21,173,120,110,11,0,64,0,111,112,114,45,49,50,51,48,50,46,54,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,175,40,41,231,11,0,64,0,111,112,114,45,49,50,51,48,51,46,54,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,92,32,132,131,11,0,64,0,111,112,114,45,49,50,51,48,52,46,54,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,195,42,118,225,11,0,64,0,111,112,114,45,49,50,51,48,53,46,55,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,119,230,156,186,11,0,64,0,111,112,114,45,49,50,51,48,54,46,55,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,253,73,146,228,11,0,64,0,51,49,55,45,48,49,49,55,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,62,56,172,220,5,0,16,1,11,0,0,0,255,255,255,0,0,0,0,0,12,0,0,0,255,255,216,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,11,0,0,0,1,15,7,0,80,252,6,0,11,0,0,0,1,15,8,0,16,242,7,0,11,0,0,0,1,15,9,0,104,236,7,0,11,0,0,0,1,15,5,0,176,51,4,0,11,0,0,0,1,15,4,0,56,24,4,0,11,0,0,0,1,15,15,0,128,230,7,0,11,0,0,0,1,15,1,0,72,216,3,0,11,0,0,0,1,15,2,0,24,188,3,0,11,0,0,0,1,15,3,0,176,162,3,0,11,0,0,0,1,15,6,0,120,211,6,0,11,0,0,0,1,15,14,0,184,164,6,0,11,0,0,0,1,15,13,0,80,74,6,0,11,0,0,0,1,15,12,0,192,32,6,0,11,0,0,0,1,15,11,0,192,234,2,0,11,0,0,0,1,15,10,0,32,242,5,0,11,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,11,0,0,0,1,240,112,0,80,252,6,0,11,0,0,0,1,240,128,0,16,242,7,0,11,0,0,0,1,240,144,0,104,236,7,0,11,0,0,0,1,240,80,0,176,51,4,0,11,0,0,0,1,240,64,0,56,24,4,0,11,0,0,0,1,240,240,0,128,230,7,0,11,0,0,0,1,240,16,0,72,216,3,0,11,0,0,0,1,240,32,0,24,188,3,0,11,0,0,0,1,240,48,0,176,162,3,0,11,0,0,0,1,240,96,0,120,211,6,0,11,0,0,0,1,240,224,0,184,164,6,0,11,0,0,0,1,240,208,0,80,74,6,0,11,0,0,0,1,240,192,0,192,32,6,0,11,0,0,0,1,240,176,0,192,234,2,0,11,0,0,0,1,240,160,0,32,242,5,0,11,0,0,0,1,240,0,0,208,236,2,0,0,0,0,0,254,0,1,0,200,30,2,0,12,0,0,0,1,3,0,0,80,46,8,0,0,0,0,0,254,0,2,0,168,234,7,0,12,0,0,0,1,4,4,0,96,135,7,0,12,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,1,0,208,26,7,0,12,0,0,0,1,8,8,0,152,124,2,0,0,0,0,0,254,0,4,0,56,154,6,0,12,0,0,0,1,48,32,0,200,99,2,0,12,0,0,0,1,48,48,0,32,84,2,0,12,0,0,0,1,48,16,0,16,71,2,0,12,0,0,0,1,48,0,0,168,57,2,0,0,0,0,0,254,0,4,0,72,202,5,0,12,0,0,0,1,192,128,0,80,246,3,0,12,0,0,0,1,192,192,0,248,38,7,0,12,0,0,0,1,192,64,0,112,212,3,0,12,0,0,0,1,192,0,0,248,160,5,0,0,0,0,0,101,112,114,45,49,50,52,49,48,46,49,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,233,243,116,170,1,0,16,1,101,112,114,45,49,50,52,48,57,46,49,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,247,142,28,193,1,0,16,1,101,112,114,45,49,50,52,49,50,46,49,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,71,70,83,176,1,0,16,1,101,112,114,45,49,50,52,49,49,46,49,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,131,13,187,18,1,0,16,1,101,112,114,45,49,50,50,57,51,46,49,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,234,30,50,244,1,0,16,1,101,112,114,45,49,50,50,57,50,46,49,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,240,138,217,81,1,0,16,1,111,112,114,45,49,50,50,57,53,46,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,132,58,58,212,9,0,16,1,111,112,114,45,49,50,50,57,52,46,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,211,207,205,39,9,0,16,1,111,112,114,45,49,50,50,57,55,46,55,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,119,86,155,29,9,0,16,1,111,112,114,45,49,50,50,57,54,46,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,113,54,81,10,9,0,16,1,111,112,114,45,49,50,51,50,51,46,49,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,111,58,228,77,2,0,32,0,111,112,114,45,49,50,51,50,52,46,49,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,85,122,96,36,2,0,32,0,111,112,114,45,49,50,51,50,53,46,49,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,122,19,5,20,2,0,32,0,111,112,114,45,49,50,51,48,55,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,9,207,125,67,3,0,32,0,111,112,114,45,49,50,51,48,56,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,194,12,231,13,3,0,32,0,111,112,114,45,49,50,51,48,57,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,66,194,184,222,3,0,32,0,111,112,114,45,49,50,51,49,48,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,126,21,207,69,3,0,32,0,111,112,114,45,49,50,51,49,49,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,57,214,43,174,3,0,32,0,111,112,114,45,49,50,51,49,50,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,231,0,96,98,3,0,32,0,111,112,114,45,49,50,51,49,51,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,55,12,135,82,3,0,32,0,111,112,114,45,49,50,51,49,52,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,234,97,196,64,3,0,32,0,111,112,114,45,49,50,51,49,53,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,163,163,249,63,3,0,32,0,111,112,114,45,49,50,51,49,54,46,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,200,109,30,138,3,0,32,0,111,112,114,45,49,50,51,49,55,46,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,212,130,227,119,3,0,32,0,111,112,114,45,49,50,51,49,56,46,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,169,222,175,209,3,0,32,0,111,112,114,45,49,50,51,49,57,46,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,249,186,35,223,3,0,32,0,111,112,114,45,49,50,51,50,48,46,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,70,228,49,121,3,0,32,0,111,112,114,45,49,50,51,50,49,46,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,212,172,11,131,3,0,32,0,111,112,114,45,49,50,51,50,50,46,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,146,36,129,139,3,0,32,0,101,112,114,45,49,50,50,57,57,46,52,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,27,196,155,252,10,0,32,0,101,112,114,45,49,50,50,57,56,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,27,196,155,252,10,0,32,0,101,112,114,45,49,50,51,48,48,46,56,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,17,112,255,232,4,0,16,1,111,112,114,45,49,50,51,48,49,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,21,173,120,110,11,0,64,0,111,112,114,45,49,50,51,48,50,46,54,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,175,40,41,231,11,0,64,0,111,112,114,45,49,50,51,48,51,46,54,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,92,32,132,131,11,0,64,0,111,112,114,45,49,50,51,48,52,46,54,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,195,42,118,225,11,0,64,0,111,112,114,45,49,50,51,48,53,46,55,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,119,230,156,186,11,0,64,0,111,112,114,45,49,50,51,48,54,46,55,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,253,73,146,228,11,0,64,0,51,49,55,45,48,49,48,55,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,174,50,230,51,5,0,16,1,101,112,114,45,49,50,50,56,57,46,49,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,53,208,47,129,1,0,16,1,101,112,114,45,49,50,50,56,56,46,49,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,187,81,17,47,1,0,16,1,101,112,114,45,49,50,50,57,49,46,49,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,210,132,162,140,1,0,16,1,101,112,114,45,49,50,50,57,48,46,49,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,203,243,219,68,1,0,16,1,101,112,114,45,49,50,50,57,51,46,49,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,234,30,50,244,1,0,16,1,101,112,114,45,49,50,50,57,50,46,49,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,240,138,217,81,1,0,16,1,111,112,114,45,49,50,50,57,53,46,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,132,58,58,212,9,0,16,1,111,112,114,45,49,50,50,57,52,46,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,211,207,205,39,9,0,16,1,111,112,114,45,49,50,50,57,55,46,55,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,119,86,155,29,9,0,16,1,111,112,114,45,49,50,50,57,54,46,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,113,54,81,10,9,0,16,1,111,112,114,45,49,50,51,50,51,46,49,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,111,58,228,77,2,0,32,0,111,112,114,45,49,50,51,50,52,46,49,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,85,122,96,36,2,0,32,0,111,112,114,45,49,50,51,50,53,46,49,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,122,19,5,20,2,0,32,0,111,112,114,45,49,50,51,48,55,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,9,207,125,67,3,0,32,0,111,112,114,45,49,50,51,48,56,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,194,12,231,13,3,0,32,0,111,112,114,45,49,50,51,48,57,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,66,194,184,222,3,0,32,0,111,112,114,45,49,50,51,49,48,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,126,21,207,69,3,0,32,0,111,112,114,45,49,50,51,49,49,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,57,214,43,174,3,0,32,0,111,112,114,45,49,50,51,49,50,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,231,0,96,98,3,0,32,0,111,112,114,45,49,50,51,49,51,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,55,12,135,82,3,0,32,0,111,112,114,45,49,50,51,49,52,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,234,97,196,64,3,0,32,0,111,112,114,45,49,50,51,49,53,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,163,163,249,63,3,0,32,0,111,112,114,45,49,50,51,49,54,46,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,200,109,30,138,3,0,32,0,111,112,114,45,49,50,51,49,55,46,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,212,130,227,119,3,0,32,0,111,112,114,45,49,50,51,49,56,46,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,169,222,175,209,3,0,32,0,111,112,114,45,49,50,51,49,57,46,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,249,186,35,223,3,0,32,0,111,112,114,45,49,50,51,50,48,46,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,70,228,49,121,3,0,32,0,111,112,114,45,49,50,51,50,49,46,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,212,172,11,131,3,0,32,0,111,112,114,45,49,50,51,50,50,46,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,146,36,129,139,3,0,32,0,101,112,114,45,49,50,50,57,57,46,52,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,27,196,155,252,10,0,32,0,101,112,114,45,49,50,50,57,56,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,27,196,155,252,10,0,32,0,101,112,114,45,49,50,51,48,48,46,56,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,17,112,255,232,4,0,16,1,111,112,114,45,49,50,51,48,49,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,21,173,120,110,11,0,64,0,111,112,114,45,49,50,51,48,50,46,54,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,175,40,41,231,11,0,64,0,111,112,114,45,49,50,51,48,51,46,54,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,92,32,132,131,11,0,64,0,111,112,114,45,49,50,51,48,52,46,54,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,195,42,118,225,11,0,64,0,111,112,114,45,49,50,51,48,53,46,55,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,119,230,156,186,11,0,64,0,111,112,114,45,49,50,51,48,54,46,55,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,253,73,146,228,11,0,64,0,51,49,55,45,48,49,48,57,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,120,110,42,225,5,0,16,1,101,112,114,45,49,55,54,56,57,46,97,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,25,238,13,79,1,0,16,1,101,112,114,45,49,55,54,56,56,46,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,199,129,125,113,1,0,16,1,101,112,114,45,49,55,55,48,48,46,98,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,55,139,40,143,2,0,32,0,101,112,114,45,49,55,55,48,49,46,98,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,91,2,251,109,2,0,32,0,101,112,114,45,49,55,55,48,50,46,98,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,171,126,11,174,2,0,32,0,101,112,114,45,49,55,54,57,50,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,39,67,60,84,3,0,32,0,101,112,114,45,49,55,54,57,53,46,98,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,68,242,96,238,3,0,32,0,101,112,114,45,49,55,54,57,51,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,62,11,53,74,3,0,32,0,101,112,114,45,49,55,54,57,54,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,241,84,219,110,3,0,32,0,101,112,114,45,49,55,54,57,52,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,29,215,150,178,3,0,32,0,101,112,114,45,49,55,54,57,55,46,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,40,123,203,108,3,0,32,0,101,112,114,45,49,55,54,57,56,46,98,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,130,251,77,205,3,0,32,0,101,112,114,45,49,55,54,57,57,46,98,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,206,236,148,38,3,0,32,0,101,112,114,45,49,55,54,57,49,46,97,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,136,83,32,20,4,0,16,1])
.concat([101,112,114,45,49,55,54,57,48,46,97,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,228,164,155,79,8,0,64,0,17,0,0,0,255,255,254,0,0,0,0,0,18,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,168,234,7,0,17,0,0,0,1,1,1,0,96,135,7,0,17,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,32,92,5,0,17,0,0,0,1,16,16,0,192,255,2,0,17,0,0,0,1,16,0,0,8,49,4,0,0,0,0,0,254,0,8,0,72,202,5,0,17,0,0,0,1,224,192,0,80,246,3,0,17,0,0,0,1,224,224,0,248,38,7,0,17,0,0,0,1,224,160,0,112,212,3,0,17,0,0,0,1,224,128,0,64,90,5,0,17,0,0,0,1,224,96,0,216,87,5,0,17,0,0,0,1,224,64,0,208,83,5,0,17,0,0,0,1,224,32,0,16,81,5,0,17,0,0,0,1,224,0,0,208,77,5,0,0,0,0,0,254,0,16,0,200,87,7,0,18,0,0,0,1,15,7,0,80,252,6,0,18,0,0,0,1,15,8,0,16,242,7,0,18,0,0,0,1,15,9,0,104,236,7,0,18,0,0,0,1,15,5,0,176,51,4,0,18,0,0,0,1,15,4,0,56,24,4,0,18,0,0,0,1,15,15,0,128,230,7,0,18,0,0,0,1,15,1,0,72,216,3,0,18,0,0,0,1,15,2,0,24,188,3,0,18,0,0,0,1,15,3,0,176,162,3,0,18,0,0,0,1,15,6,0,120,211,6,0,18,0,0,0,1,15,14,0,184,164,6,0,18,0,0,0,1,15,13,0,80,74,6,0,18,0,0,0,1,15,12,0,192,32,6,0,18,0,0,0,1,15,11,0,192,234,2,0,18,0,0,0,1,15,10,0,32,242,5,0,18,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,18,0,0,0,1,240,112,0,80,252,6,0,18,0,0,0,1,240,128,0,16,242,7,0,18,0,0,0,1,240,144,0,104,236,7,0,18,0,0,0,1,240,80,0,176,51,4,0,18,0,0,0,1,240,64,0,56,24,4,0,18,0,0,0,1,240,240,0,128,230,7,0,18,0,0,0,1,240,16,0,72,216,3,0,18,0,0,0,1,240,32,0,24,188,3,0,18,0,0,0,1,240,48,0,176,162,3,0,18,0,0,0,1,240,96,0,120,211,6,0,18,0,0,0,1,240,224,0,184,164,6,0,18,0,0,0,1,240,208,0,80,74,6,0,18,0,0,0,1,240,192,0,192,32,6,0,18,0,0,0,1,240,176,0,192,234,2,0,18,0,0,0,1,240,160,0,32,242,5,0,18,0,0,0,1,240,0,0,208,236,2,0,0,0,0,0,17,0,0,0,255,255,255,0,0,0,0,0,18,0,0,0,255,255,251,0,0,0,0,0,0,0,0,0,254,0,8,0,160,123,6,0,17,0,0,0,1,7,0,0,184,220,8,0,17,0,0,0,1,7,1,0,88,154,8,0,17,0,0,0,1,7,2,0,200,92,8,0,17,0,0,0,1,7,7,0,56,37,8,0,17,0,0,0,1,7,6,0,96,240,7,0,17,0,0,0,1,7,5,0,128,188,7,0,17,0,0,0,1,7,4,0,184,46,7,0,17,0,0,0,1,7,3,0,248,140,7,0,0,0,0,0,254,0,8,0,200,87,7,0,17,0,0,0,1,56,0,0,184,220,8,0,17,0,0,0,1,56,8,0,88,154,8,0,17,0,0,0,1,56,16,0,200,92,8,0,17,0,0,0,1,56,56,0,56,37,8,0,17,0,0,0,1,56,48,0,96,240,7,0,17,0,0,0,1,56,40,0,128,188,7,0,17,0,0,0,1,56,32,0,184,46,7,0,17,0,0,0,1,56,24,0,248,140,7,0,0,0,0,0,254,0,2,0,232,75,4,0,17,0,0,0,1,64,0,0,152,182,7,0,17,0,0,0,1,64,64,0,96,135,7,0,0,0,0,0,254,0,2,0,144,212,8,0,17,0,0,0,1,128,128,0,96,135,7,0,17,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,18,0,0,0,1,3,3,0,8,49,4,0,18,0,0,0,1,3,2,0,152,21,4,0,18,0,0,0,1,3,1,0,72,246,3,0,18,0,0,0,1,3,0,0,64,47,7,0,0,0,0,0,254,0,2,0,200,30,2,0,18,0,0,0,1,4,0,0,120,97,1,0,18,0,0,0,1,4,4,0,96,19,1,0,0,0,0,0,254,0,2,0,64,37,5,0,18,0,0,0,1,8,8,0,8,240,2,0,18,0,0,0,1,8,0,0,120,217,2,0,0,0,0,0,254,0,2,0,200,196,2,0,18,0,0,0,1,16,16,0,56,111,3,0,18,0,0,0,1,16,0,0,104,134,3,0,0,0,0,0,254,0,4,0,72,202,5,0,18,0,0,0,1,96,64,0,80,246,3,0,18,0,0,0,1,96,96,0,248,38,7,0,18,0,0,0,1,96,32,0,48,123,8,0,18,0,0,0,1,96,0,0,8,117,8,0,0,0,0,0,254,0,2,0,104,159,3,0,18,0,0,0,1,128,0,0,56,111,3,0,18,0,0,0,1,128,128,0,104,134,3,0,98,49,52,45,54,55,45,49,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,22,118,241,35,2,0,16,1,98,49,52,45,54,56,45,49,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,217,89,86,131,2,0,16,1,98,49,52,45,53,52,46,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,213,36,41,23,2,0,16,1,98,49,52,45,53,50,46,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,161,178,181,225,2,0,16,1,98,49,52,45,53,53,46,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,153,84,241,161,2,0,16,1,98,49,52,45,53,51,46,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,95,79,160,4,2,0,16,1,98,49,52,45,54,57,46,56,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,227,82,214,6,0,16,1,98,49,52,45,55,48,46,56,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,43,89,32,183,6,0,16,1,98,49,52,45,50,53,46,54,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,239,40,171,158,9,0,16,1,98,49,52,45,48,55,46,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,255,95,2,198,12,0,32,0,98,49,52,45,48,54,46,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,110,83,226,180,12,0,32,0,98,49,52,45,52,56,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,101,242,199,48,18,0,32,0,98,49,52,45,52,57,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,101,66,186,50,18,0,32,0,98,49,52,45,53,48,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,17,243,30,236,18,0,32,0,98,49,52,45,53,49,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,95,28,4,53,18,0,32,0,98,49,52,45,52,52,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,14,3,108,159,18,0,32,0,98,49,52,45,52,53,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,3,206,228,99,18,0,32,0,98,49,52,45,52,54,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,242,173,137,212,18,0,32,0,98,49,52,45,52,55,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,91,247,161,179,18,0,32,0,98,49,52,45,52,48,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,179,60,42,250,18,0,32,0,98,49,52,45,52,49,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,20,90,69,9,18,0,32,0,98,49,52,45,52,50,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,60,245,81,171,18,0,32,0,98,49,52,45,52,51,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,56,43,109,30,18,0,32,0,98,49,52,45,51,54,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,184,193,167,32,18,0,32,0,98,49,52,45,51,55,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,59,112,27,128,18,0,32,0,98,49,52,45,51,56,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,62,33,12,222,18,0,32,0,98,49,52,45,51,57,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,197,40,140,121,18,0,32,0,98,49,52,45,51,48,46,56,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,127,12,203,220,23,0,32,0,98,49,52,45,50,56,46,49,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,174,208,17,223,26,0,64,0,98,49,52,45,50,57,46,49,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,231,131,217,122,26,0,64,0,98,49,52,45,51,49,46,57,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,61,1,107,92,0,0,0,8,15,0,0,0,255,255,255,0,0,0,0,0,16,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,200,30,2,0,15,0,0,0,1,3,3,0,224,6,8,0,15,0,0,0,1,3,2,0,120,97,1,0,15,0,0,0,1,3,1,0,128,2,8,0,15,0,0,0,1,3,0,0,240,250,7,0,0,0,0,0,254,0,2,0,232,75,4,0,15,0,0,0,1,4,4,0,96,135,7,0,15,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,15,0,0,0,1,8,0,0,96,135,7,0,15,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,15,0,0,0,1,48,0,0,80,252,6,0,15,0,0,0,1,48,16,0,16,242,7,0,15,0,0,0,1,48,32,0,104,236,7,0,15,0,0,0,1,48,48,0,128,230,7,0,0,0,0,0,254,0,4,0,160,123,6,0,15,0,0,0,1,192,192,0,8,201,6,0,15,0,0,0,1,192,128,0,200,197,6,0,15,0,0,0,1,192,64,0,152,194,6,0,15,0,0,0,1,192,0,0,248,189,6,0,0,0,0,0,254,0,4,0,56,242,7,0,16,0,0,0,1,12,0,0,160,236,7,0,16,0,0,0,1,12,4,0,168,230,7,0,16,0,0,0,1,12,12,0,176,226,7,0,16,0,0,0,1,12,8,0,40,223,7,0,0,0,0,0,254,0,4,0,80,219,7,0,16,0,0,0,1,48,32,0,208,75,4,0,16,0,0,0,1,48,48,0,8,49,4,0,16,0,0,0,1,48,16,0,152,21,4,0,16,0,0,0,1,48,0,0,72,246,3,0,0,0,0,0,254,0,2,0,104,159,3,0,16,0,0,0,1,64,64,0,96,135,7,0,16,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,48,112,3,0,16,0,0,0,1,128,0,0,80,245,6,0,16,0,0,0,1,128,128,0,240,240,6,0,0,0,0,0,117,104,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,153,214,90,111,0,0,16,1,117,105,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,225,167,245,202,0,0,16,1,117,97,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,207,123,87,169,0,0,32,0,117,97,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,45,211,121,113,0,0,32,0,117,97,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,177,229,52,72,0,0,32,0,117,97,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,153,208,61,102,0,0,32,0,117,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,71,9,245,7,0,0,64,0,117,106,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,215,207,186,163,0,0,64,0,56,55,99,53,50,46,109,99,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,16,112,114,111,116,100,97,116,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,199,230,4,7,0,0,16,1,19,0,0,0,255,255,254,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,40,111,8,0,19,0,0,0,1,1,1,0,96,135,7,0,19,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,8,0,232,24,7,0,19,0,0,0,1,28,0,0,232,151,6,0,19,0,0,0,1,28,4,0,168,241,6,0,19,0,0,0,1,28,8,0,224,19,7,0,19,0,0,0,1,28,12,0,64,15,7,0,19,0,0,0,1,28,28,0,224,9,7,0,19,0,0,0,1,28,20,0,88,239,6,0,19,0,0,0,1,28,24,0,144,3,7,0,19,0,0,0,1,28,16,0,224,166,6,0,0,0,0,0,254,0,4,0,72,202,5,0,19,0,0,0,1,96,0,0,80,246,3,0,19,0,0,0,1,96,96,0,248,38,7,0,19,0,0,0,1,96,64,0,112,212,3,0,19,0,0,0,1,96,32,0,248,160,5,0,0,0,0,0,254,0,2,0,128,156,8,0,19,0,0,0,1,128,128,0,32,182,8,0,19,0,0,0,1,128,0,0,80,251,6,0,0,0,0,0,254,0,4,0,16,144,6,0,20,0,0,0,1,3,0,0,208,75,4,0,20,0,0,0,1,3,3,0,8,49,4,0,20,0,0,0,1,3,2,0,152,21,4,0,20,0,0,0,1,3,1,0,72,246,3,0,0,0,0,0,254,0,4,0,48,142,4,0,20,0,0,0,1,12,4,0,160,236,7,0,20,0,0,0,1,12,8,0,168,230,7,0,20,0,0,0,1,12,12,0,176,226,7,0,20,0,0,0,1,12,0,0,40,223,7,0,0,0,0,0,254,0,2,0,216,120,6,0,20,0,0,0,1,32,32,0,96,135,7,0,20,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,8,117,6,0,20,0,0,0,1,64,64,0,96,135,7,0,20,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,16,227,4,0,20,0,0,0,1,128,128,0,96,135,7,0,20,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,184,40,2,0,1,0,0,0,72,234,148,0,248,191,2,0,56,250,6,0,1,0,0,0,143,233,148,0,184,160,2,0,184,164,8,0,1,0,0,0,73,234,148,0,64,246,1,0,88,149,7,0,1,0,0,0,207,232,148,0,136,224,1,0,56,210,6,0,1,0,0,0,138,233,148,0,192,135,2,0,24,163,6,0,1,0,0,0,139,233,148,0,240,108,2,0,152,122,6,0,1,0,0,0,136,233,148,0,96,82,2,0,192,72,6,0,1,0,0,0,137,233,148,0,32,56,2,0,48,123,2,0,1,0,0,0,140,233,148,0,152,30,2,0,96,69,2,0,1,0,0,0,141,233,148,0,232,10,2,0,176,223,1,0,1,0,0,0,202,232,148,0,72,198,1,0,192,209,1,0,1,0,0,0,203,232,148,0,24,182,1,0,24,198,1,0,1,0,0,0,200,232,148,0,40,167,1,0,120,189,1,0,1,0,0,0,201,232,148,0,200,149,1,0,248,187,8,0,1,0,0,0,204,232,148,0,56,126,1,0,184,179,8,0,1,0,0,0,205,232,148,0,32,101,1,0,88,212,3,0,1,0,0,0,248,221,146,0,40,185,3,0,56,122,5,0,1,0,0,0,76,234,148,0,224,12,8,0,0,105,5,0,1,0,0,0,77,234,148,0,128,176,7,0,248,5,8,0,9,0,0,0,240,94,147,0,32,58,1,0,144,250,7,0,9,0,0,0,241,94,147,0,32,58,1,0,248,241,7,0,9,0,0,0,242,94,147,0,32,58,1,0,0,0,0,0,0,0,0,0,101,112,114,45,49,48,56,53,51,46,97,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,251,197,215,36,1,0,16,1,101,112,114,45,49,48,56,53,48,46,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,50,87,87,241,1,0,16,1,101,112,114,45,49,48,56,53,52,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,55,178,208,130,1,0,16,1,101,112,114,45,49,48,56,53,49,46,97,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,27,39,206,245,1,0,16,1,101,112,114,45,49,48,56,53,53,46,97,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,83,90,233,99,1,0,16,1,101,112,114,45,49,48,56,53,50,46,97,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,43,56,209,124,1,0,16,1,101,112,114,45,49,48,53,52,51,46,98,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,55,204,220,7,2,0,32,0,101,112,114,45,49,48,53,52,52,46,98,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,58,154,251,132,2,0,32,0,101,112,114,45,49,48,53,52,53,46,98,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,192,75,105,200,2,0,32,0,101,112,114,45,49,48,53,52,56,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,53,7,21,170,3,0,32,0,101,112,114,45,49,48,53,53,50,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,247,185,203,111,3,0,32,0,101,112,114,45,49,48,53,52,57,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,103,240,89,47,3,0,32,0,101,112,114,45,49,48,53,53,51,46,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,159,10,34,138,3,0,32,0,101,112,114,45,49,48,53,53,48,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,255,105,80,240,3,0,32,0,101,112,114,45,49,48,53,53,52,46,98,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,9,248,100,220,3,0,32,0,101,112,114,45,49,48,53,53,49,46,98,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,31,129,93,67,3,0,32,0,101,112,114,45,49,48,53,53,53,46,98,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,113,196,67,33,3,0,32,0,101,112,114,45,49,48,53,54,50,46,97,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,191,40,80,63,4,0,16,1,101,112,114,45,49,48,53,54,51,46,97,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,223,237,183,157,8,0,64,0,19,0,0,0,255,255,245,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,21,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,19,0,0,0,1,1,0,0,96,19,1,0,19,0,0,0,1,1,1,0,120,97,1,0,0,0,0,0,254,0,16,0,200,73,5,0,19,0,0,0,1,30,22,0,24,69,5,0,19,0,0,0,1,30,20,0,96,66,5,0,19,0,0,0,1,30,18,0,40,64,5,0,19,0,0,0,1,30,16,0,80,61,5,0,19,0,0,0,1,30,28,0,56,59,5,0,19,0,0,0,1,30,30,0,168,56,5,0,19,0,0,0,1,30,26,0,16,54,5,0,19,0,0,0,1,30,24,0,0,51,5,0,19,0,0,0,1,30,14,0,24,46,5,0,19,0,0,0,1,30,12,0,40,42,5,0,19,0,0,0,1,30,10,0,0,38,5,0,19,0,0,0,1,30,8,0,176,34,5,0,19,0,0,0,1,30,6,0,128,32,5,0,19,0,0,0,1,30,4,0,216,29,5,0,19,0,0,0,1,30,2,0,208,27,5,0,19,0,0,0,1,30,0,0,120,7,5,0,0,0,0,0,254,0,2,0,192,25,5,0,19,0,0,0,1,32,0,0,96,135,7,0,19,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,232,22,5,0,19,0,0,0,1,64,64,0,240,19,5,0,19,0,0,0,1,64,0,0,72,16,5,0,0,0,0,0,254,0,2,0,128,129,4,0,19,0,0,0,1,128,128,0,8,49,4,0,19,0,0,0,1,128,0,0,72,246,3,0,0,0,0,0,254,0,16,0,200,87,7,0,20,0,0,0,1,15,7,0,80,252,6,0,20,0,0,0,1,15,8,0,16,242,7,0,20,0,0,0,1,15,9,0,104,236,7,0,20,0,0,0,1,15,5,0,176,51,4,0,20,0,0,0,1,15,4,0,56,24,4,0,20,0,0,0,1,15,15,0,128,230,7,0,20,0,0,0,1,15,1,0,72,216,3,0,20,0,0,0,1,15,2,0,24,188,3,0,20,0,0,0,1,15,3,0,176,162,3,0,20,0,0,0,1,15,6,0,120,211,6,0,20,0,0,0,1,15,14,0,184,164,6,0,20,0,0,0,1,15,13,0,80,74,6,0,20,0,0,0,1,15,12,0,192,32,6,0,20,0,0,0,1,15,11,0,192,234,2,0,20,0,0,0,1,15,10,0,32,242,5,0,20,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,20,0,0,0,1,240,112,0,80,252,6,0,20,0,0,0,1,240,128,0,16,242,7,0,20,0,0,0,1,240,144,0,104,236,7,0,20,0,0,0,1,240,80,0,176,51,4,0,20,0,0,0,1,240,64,0,56,24,4,0,20,0,0,0,1,240,240,0,128,230,7,0,20,0,0,0,1,240,16,0,72,216,3,0,20,0,0,0,1,240,32,0,24,188,3,0,20,0,0,0,1,240,48,0,176,162,3,0,20,0,0,0,1,240,96,0,120,211,6,0,20,0,0,0,1,240,224,0,184,164,6,0,20,0,0,0,1,240,208,0,80,74,6,0,20,0,0,0,1,240,192,0,192,32,6,0,20,0,0,0,1,240,176,0,192,234,2,0,20,0,0,0,1,240,160,0,32,242,5,0,20,0,0,0,1,240,0,0,208,236,2,0,0,0,0,0,254,0,2,0,144,212,8,0,21,0,0,0,1,1,1,0,96,135,7,0,21,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,56,8,5,0,21,0,0,0,1,2,2,0,136,5,5,0,21,0,0,0,1,2,0,0,40,2,5,0,0,0,0,0,254,0,4,0,88,32,6,0,21,0,0,0,1,12,8,0,16,252,4,0])
.concat([21,0,0,0,1,12,12,0,16,249,4,0,21,0,0,0,1,12,4,0,88,244,4,0,21,0,0,0,1,12,0,0,8,241,4,0,0,0,0,0,254,0,2,0,104,159,3,0,21,0,0,0,1,16,0,0,56,111,3,0,21,0,0,0,1,16,16,0,104,134,3,0,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,245,0,0,0,0,0,21,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,19,0,0,0,1,15,7,0,80,252,6,0,19,0,0,0,1,15,8,0,16,242,7,0,19,0,0,0,1,15,9,0,104,236,7,0,19,0,0,0,1,15,5,0,176,51,4,0,19,0,0,0,1,15,4,0,56,24,4,0,19,0,0,0,1,15,15,0,128,230,7,0,19,0,0,0,1,15,1,0,72,216,3,0,19,0,0,0,1,15,2,0,24,188,3,0,19,0,0,0,1,15,3,0,176,162,3,0,19,0,0,0,1,15,6,0,120,211,6,0,19,0,0,0,1,15,14,0,184,164,6,0,19,0,0,0,1,15,13,0,80,74,6,0,19,0,0,0,1,15,12,0,192,32,6,0,19,0,0,0,1,15,11,0,192,234,2,0,19,0,0,0,1,15,10,0,32,242,5,0,19,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,19,0,0,0,1,240,112,0,80,252,6,0,19,0,0,0,1,240,128,0,16,242,7,0,19,0,0,0,1,240,144,0,104,236,7,0,19,0,0,0,1,240,80,0,176,51,4,0,19,0,0,0,1,240,64,0,56,24,4,0,19,0,0,0,1,240,240,0,128,230,7,0,19,0,0,0,1,240,16,0,72,216,3,0,19,0,0,0,1,240,32,0,24,188,3,0,19,0,0,0,1,240,48,0,176,162,3,0,19,0,0,0,1,240,96,0,120,211,6,0,19,0,0,0,1,240,224,0,184,164,6,0,19,0,0,0,1,240,208,0,80,74,6,0,19,0,0,0,1,240,192,0,192,32,6,0,19,0,0,0,1,240,176,0,192,234,2,0,19,0,0,0,1,240,160,0,32,242,5,0,19,0,0,0,1,240,0,0,208,236,2,0,0,0,0,0,254,0,2,0,200,30,2,0,20,0,0,0,1,1,0,0,96,19,1,0,20,0,0,0,1,1,1,0,120,97,1,0,0,0,0,0,254,0,16,0,200,73,5,0,20,0,0,0,1,30,22,0,24,69,5,0,20,0,0,0,1,30,20,0,96,66,5,0,20,0,0,0,1,30,18,0,40,64,5,0,20,0,0,0,1,30,16,0,80,61,5,0,20,0,0,0,1,30,28,0,56,59,5,0,20,0,0,0,1,30,30,0,168,56,5,0,20,0,0,0,1,30,26,0,16,54,5,0,20,0,0,0,1,30,24,0,0,51,5,0,20,0,0,0,1,30,14,0,24,46,5,0,20,0,0,0,1,30,12,0,40,42,5,0,20,0,0,0,1,30,10,0,0,38,5,0,20,0,0,0,1,30,8,0,176,34,5,0,20,0,0,0,1,30,6,0,128,32,5,0,20,0,0,0,1,30,4,0,216,29,5,0,20,0,0,0,1,30,2,0,208,27,5,0,20,0,0,0,1,30,0,0,120,7,5,0,0,0,0,0,254,0,2,0,192,25,5,0,20,0,0,0,1,32,0,0,96,135,7,0,20,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,232,22,5,0,20,0,0,0,1,64,64,0,240,19,5,0,20,0,0,0,1,64,0,0,72,16,5,0,0,0,0,0,254,0,2,0,128,129,4,0,20,0,0,0,1,128,128,0,8,49,4,0,20,0,0,0,1,128,0,0,72,246,3,0,0,0,0,0,254,0,2,0,144,212,8,0,21,0,0,0,1,1,1,0,96,135,7,0,21,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,56,8,5,0,21,0,0,0,1,2,2,0,136,5,5,0,21,0,0,0,1,2,0,0,40,2,5,0,0,0,0,0,254,0,4,0,88,32,6,0,21,0,0,0,1,12,8,0,16,252,4,0,21,0,0,0,1,12,12,0,16,249,4,0,21,0,0,0,1,12,4,0,88,244,4,0,21,0,0,0,1,12,0,0,8,241,4,0,0,0,0,0,254,0,2,0,104,159,3,0,21,0,0,0,1,16,0,0,56,111,3,0,21,0,0,0,1,16,16,0,104,134,3,0,116,112,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,112,62,139,186,1,0,16,1,116,112,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,192,88,97,121,1,0,16,1,116,112,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,152,28,106,254,1,0,16,1,116,112,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,133,49,247,239,1,0,16,1,116,112,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,74,62,2,133,1,0,16,1,116,112,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,249,170,184,182,1,0,16,1,116,112,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,44,52,87,95,4,0,32,0,116,112,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,114,215,111,99,4,0,32,0,116,112,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,139,196,195,45,4,0,32,0,116,112,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,12,69,123,178,4,0,32,0,112,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,32,16,9,0,0,0,255,255,64,0,0,0,0,0,10,0,0,0,255,255,0,0,0,0,0,0,11,0,0,0,255,255,3,0,0,0,0,0,0,0,0,0,254,0,2,0,160,146,1,0,9,0,0,0,1,32,0,0,96,135,7,0,9,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,56,146,1,0,9,0,0,0,1,64,0,0,96,135,7,0,9,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,32,4,2,0,10,0,0,0,1,64,0,0,32,123,8,0,10,0,0,0,1,64,64,0,224,127,8,0,0,0,0,0,254,0,2,0,128,129,4,0,10,0,0,0,1,128,0,0,8,49,4,0,10,0,0,0,1,128,128,0,72,246,3,0,0,0,0,0,254,0,4,0,64,37,5,0,11,0,0,0,1,12,0,0,80,2,4,0,11,0,0,0,1,12,4,0,208,98,2,0,11,0,0,0,1,12,8,0,24,225,3,0,11,0,0,0,1,12,12,0,208,168,3,0,17,0,0,0,255,255,255,0,0,0,0,0,18,0,0,0,255,255,251,0,0,0,0,0,0,0,0,0,254,0,8,0,160,123,6,0,17,0,0,0,1,7,0,0,184,220,8,0,17,0,0,0,1,7,1,0,88,154,8,0,17,0,0,0,1,7,2,0,200,92,8,0,17,0,0,0,1,7,7,0,56,37,8,0,17,0,0,0,1,7,6,0,96,240,7,0,17,0,0,0,1,7,5,0,128,188,7,0,17,0,0,0,1,7,4,0,184,46,7,0,17,0,0,0,1,7,3,0,248,140,7,0,0,0,0,0,254,0,8,0,200,87,7,0,17,0,0,0,1,56,0,0,184,220,8,0,17,0,0,0,1,56,8,0,88,154,8,0,17,0,0,0,1,56,16,0,200,92,8,0,17,0,0,0,1,56,56,0,56,37,8,0,17,0,0,0,1,56,48,0,96,240,7,0,17,0,0,0,1,56,40,0,128,188,7,0,17,0,0,0,1,56,32,0,184,46,7,0,17,0,0,0,1,56,24,0,248,140,7,0,0,0,0,0,254,0,2,0,232,75,4,0,17,0,0,0,1,64,0,0,152,182,7,0,17,0,0,0,1,64,64,0,96,135,7,0,0,0,0,0,254,0,2,0,144,212,8,0,17,0,0,0,1,128,128,0,96,135,7,0,17,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,18,0,0,0,1,3,3,0,8,49,4,0,18,0,0,0,1,3,2,0,152,21,4,0,18,0,0,0,1,3,1,0,72,246,3,0,18,0,0,0,1,3,0,0,64,47,7,0,0,0,0,0,254,0,2,0,200,30,2,0,18,0,0,0,1,4,0,0,120,97,1,0,18,0,0,0,1,4,4,0,96,19,1,0,0,0,0,0,254,0,4,0,64,37,5,0,18,0,0,0,1,24,24,0,8,240,2,0,18,0,0,0,1,24,16,0,120,217,2,0,18,0,0,0,1,24,8,0,216,139,2,0,18,0,0,0,1,24,0,0,0,129,2,0,0,0,0,0,254,0,4,0,72,202,5,0,18,0,0,0,1,96,32,0,248,80,6,0,18,0,0,0,1,96,64,0,80,246,3,0,18,0,0,0,1,96,96,0,248,38,7,0,18,0,0,0,1,96,0,0,48,123,8,0,0,0,0,0,254,0,2,0,72,217,6,0,18,0,0,0,1,128,0,0,56,111,3,0,18,0,0,0,1,128,128,0,104,134,3,0,0,0,0,0,99,50,56,45,49,51,45,49,46,53,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,19,112,176,172,2,0,16,1,99,50,56,45,49,54,45,49,46,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,91,213,67,30,2,0,16,1,99,50,56,45,48,56,46,53,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,241,56,224,56,2,0,16,1,99,50,56,45,48,55,46,51,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,187,154,65,36,2,0,16,1,99,50,56,45,49,52,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,22,54,239,69,9,0,16,1,99,50,56,45,48,50,46,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,157,160,48,98,11,0,32,0,99,50,56,45,48,49,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,37,43,85,68,13,0,32,0,99,50,56,45,48,51,46,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,175,199,189,81,16,0,32,0,99,50,56,45,48,52,46,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,53,213,126,186,16,0,32,0,99,50,56,45,48,54,46,52,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,219,131,105,219,24,0,64,0,99,50,56,45,48,53,46,52,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,250,56,178,211,25,0,64,0,112,97,108,49,54,108,56,98,45,98,56,57,45,48,49,46,105,99,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,122,185,149,64,0,0,0,8,112,97,108,49,54,108,56,98,45,98,56,57,45,48,51,46,105,99,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,226,146,69,99,0,0,0,8,112,97,108,49,54,118,56,98,45,98,56,57,45,48,52,46,105,99,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,226,106,19,252,0,0,0,8,112,97,108,49,54,108,56,98,45,99,50,56,45,48,57,46,105,99,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,5,115,62,56,0,0,0,8,112,97,108,49,54,108,56,98,45,99,50,56,45,49,48,46,105,99,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,7,204,252,71,0,0,0,8,112,97,108,49,54,108,56,98,45,99,50,56,45,49,49,46,105,99,51,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,232,79,65,51,0,0,0,8,21,0,0,0,255,255,255,0,0,0,0,0,22,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,21,0,0,0,1,2,2,0,96,135,7,0,21,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,21,0,0,0,1,4,4,0,96,135,7,0,21,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,21,0,0,0,1,8,0,0,96,135,7,0,21,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,21,0,0,0,1,48,0,0,80,252,6,0,21,0,0,0,1,48,16,0,16,242,7,0,21,0,0,0,1,48,32,0,104,236,7,0,21,0,0,0,1,48,48,0,128,230,7,0,0,0,0,0,254,0,4,0,160,123,6,0,21,0,0,0,1,192,192,0,8,201,6,0,21,0,0,0,1,192,128,0,200,197,6,0,21,0,0,0,1,192,64,0,152,194,6,0,21,0,0,0,1,192,0,0,248,189,6,0,0,0,0,0,254,0,4,0,72,202,5,0,22,0,0,0,1,3,2,0,80,246,3,0,22,0,0,0,1,3,3,0,80,124,6,0,22,0,0,0,1,3,1,0,112,212,3,0,22,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,2,0,216,238,6,0,22,0,0,0,1,4,0,0,96,135,7,0,22,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,22,0,0,0,1,48,32,0,208,75,4,0,22,0,0,0,1,48,48,0,8,49,4,0,22,0,0,0,1,48,16,0,152,21,4,0,22,0,0,0,1,48,0,0,72,246,3,0,0,0,0,0,254,0,2,0,104,159,3,0,22,0,0,0,1,64,0,0,96,135,7,0,22,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,6,0,22,0,0,0,1,128,0,0,8,208,6,0,22,0,0,0,1,128,128,0,88,204,6,0,18,0,0,0,255,255,255,0,0,0,0,0,19,0,0,0,255,255,82,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,18,0,0,0,1,15,2,0,80,252,6,0,18,0,0,0,1,15,5,0,16,242,7,0,18,0,0,0,1,15,8,0,104,236,7,0,18,0,0,0,1,15,4,0,120,113,6,0,18,0,0,0,1,15,1,0,232,228,5,0,18,0,0,0,1,15,15,0,128,230,7,0,18,0,0,0,1,15,3,0,56,141,7,0,18,0,0,0,1,15,7,0,120,211,6,0,18,0,0,0,1,15,14,0,184,164,6,0,18,0,0,0,1,15,6,0,24,1,7,0,18,0,0,0,1,15,13,0,80,74,6,0,18,0,0,0,1,15,12,0,192,32,6,0,18,0,0,0,1,15,11,0,192,234,2,0,18,0,0,0,1,15,10,0,32,242,5,0,18,0,0,0,1,15,9,0,176,192,2,0,18,0,0,0,1,15,0,0,16,227,4,0,0,0,0,0,254,0,15,0,160,123,6,0,18,0,0,0,1,240,32,0,80,252,6,0,18,0,0,0,1,240,80,0,16,242,7,0,18,0,0,0,1,240,128,0,104,236,7,0,18,0,0,0,1,240,64,0,120,113,6,0,18,0,0,0,1,240,16,0,232,228,5,0,18,0,0,0,1,240,240,0,128,230,7,0,18,0,0,0,1,240,48,0,56,141,7,0,18,0,0,0,1,240,112,0,120,211,6,0,18,0,0,0,1,240,224,0,184,164,6,0,18,0,0,0,1,240,96,0,24,1,7,0,18,0,0,0,1,240,208,0,80,74,6,0,18,0,0,0,1,240,192,0,192,32,6,0,18,0,0,0,1,240,176,0,192,234,2,0,18,0,0,0,1,240,160,0,32,242,5,0,18,0,0,0,1,240,144,0,176,192,2,0,0,0,0,0,254,0,4,0,128,129,4,0,19,0,0,0,1,3,3,0,208,75,4,0,19,0,0,0,1,3,2,0,8,49,4,0,19,0,0,0,1,3,1,0,72,246,3,0,19,0,0,0,1,3,0,0,64,47,7,0,0,0,0,0,254,0,2,0,96,8,4,0,19,0,0,0,1,4,4,0,56,111,3,0,19,0,0,0,1,4,0,0,104,134,3,0,0,0,0,0,254,0,4,0,64,37,5,0,19,0,0,0,1,24,24,0,88,148,3,0,19,0,0,0,1,24,16,0,248,242,2,0,19,0,0,0,1,24,8,0,152,53,6,0,19,0,0,0,1,24,0,0,8,49,6,0,0,0,0,0,254,0,4,0,72,202,5,0,19,0,0,0,1,96,96,0,80,246,3,0,19,0,0,0,1,96,64,0,248,38,7,0,19,0,0,0,1,96,32,0,48,123,8,0,19,0,0,0,1,96,0,0,8,117,8,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,128,128,0,96,135,7,0,19,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,20,0,0,0,1,4,4,0,96,135,7,0,20,0,0,0,1,4,0,0,152,182,7,0,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,233,0,0,0,0,0,21,0,0,0,255,255,239,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,19,0,0,0,1,15,12,0,32,136,7,0,19,0,0,0,1,15,13,0,40,88,7,0,19,0,0,0,1,15,8,0,200,116,6,0,19,0,0,0,1,15,14,0,96,39,7,0,19,0,0,0,1,15,9,0,120,113,6,0,19,0,0,0,1,15,4,0,232,228,5,0,19,0,0,0,1,15,0,0,64,189,7,0,19,0,0,0,1,15,5,0,192,107,2,0,19,0,0,0,1,15,10,0,232,216,6,0,19,0,0,0,1,15,15,0,144,251,6,0,19,0,0,0,1,15,1,0,56,141,7,0,19,0,0,0,1,15,6,0,120,211,6,0,19,0,0,0,1,15,2,0,160,157,2,0,19,0,0,0,1,15,11,0,184,164,6,0,19,0,0,0,1,15,7,0,80,74,6,0,19,0,0,0,1,15,3,0,192,32,6,0,0,0,0,0,254,0,16,0,160,123,6,0,19,0,0,0,1,240,192,0,32,136,7,0,19,0,0,0,1,240,208,0,40,88,7,0,19,0,0,0,1,240,128,0,200,116,6,0,19,0,0,0,1,240,224,0,96,39,7,0,19,0,0,0,1,240,144,0,120,113,6,0,19,0,0,0,1,240,64,0,232,228,5,0,19,0,0,0,1,240,0,0,64,189,7,0,19,0,0,0,1,240,80,0,192,107,2,0,19,0,0,0,1,240,160,0,232,216,6,0,19,0,0,0,1,240,240,0,144,251,6,0,19,0,0,0,1,240,16,0,56,141,7,0,19,0,0,0,1,240,96,0,120,211,6,0,19,0,0,0,1,240,32,0,160,157,2,0,19,0,0,0,1,240,176,0,184,164,6,0,19,0,0,0,1,240,112,0,80,74,6,0,19,0,0,0,1,240,48,0,192,32,6,0,0,0,0,0,254,0,2,0,232,75,4,0,20,0,0,0,1,1,1,0,96,135,7,0,20,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,20,0,0,0,1,2,0,0,96,135,7,0,20,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,2,0,200,30,2,0,20,0,0,0,1,4,0,0,120,97,1,0,20,0,0,0,1,4,4,0,96,19,1,0,0,0,0,0,254,0,2,0,0,150,8,0,20,0,0,0,1,8,8,0,208,75,4,0,20,0,0,0,1,8,0,0,192,255,2,0,0,0,0,0,254,0,2,0,168,234,7,0,20,0,0,0,1,16,16,0,96,135,7,0,20,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,2,0,128,129,4,0,20,0,0,0,1,32,32,0,8,49,4,0,20,0,0,0,1,32,0,0,208,75,4,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,192,128,0,80,246,3,0,20,0,0,0,1,192,192,0,248,38,7,0,20,0,0,0,1,192,64,0,112,212,3,0,20,0,0,0,1,192,0,0,248,160,5,0,0,0,0,0,254,0,2,0,72,106,2,0,21,0,0,0,1,16,0,0,96,135,7,0,21,0,0,0,1,16,16,0,152,182,7,0,0,0,0,0,254,0,5,0,192,76,8,0,21,0,0,0,1,224,128,0,224,120,4,0,21,0,0,0,1,224,192,0,40,105,2,0,21,0,0,0,1,224,224,0,144,104,2,0,21,0,0,0,1,224,160,0,40,52,7,0,21,0,0,0,1,224,96,0,120,7,5,0,0,0,0,0,32,0,0,0,255,255,255,0,0,0,0,0,33,0,0,0,255,255,127,0,0,0,0,0,0,0,0,0,254,0,8,0,200,87,7,0,32,0,0,0,1,7,0,0,40,88,7,0,32,0,0,0,1,7,1,0,96,39,7,0,32,0,0,0,1,7,7,0,144,251,6,0,32,0,0,0,1,7,6,0,184,164,6,0,32,0,0,0,1,7,5,0,80,74,6,0,32,0,0,0,1,7,4,0,192,32,6,0,32,0,0,0,1,7,3,0,192,234,2,0,32,0,0,0,1,7,2,0,32,242,5,0,0,0,0,0,254,0,8,0,160,123,6,0,32,0,0,0,1,56,0,0,40,88,7,0,32,0,0,0,1,56,8,0,96,39,7,0,32,0,0,0,1,56,56,0,144,251,6,0,32,0,0,0,1,56,48,0,184,164,6,0,32,0,0,0,1,56,40,0,80,74,6,0,32,0,0,0,1,56,32,0,192,32,6,0,32,0,0,0,1,56,24,0,192,234,2,0,32,0,0,0,1,56,16,0,32,242,5,0,0,0,0,0,254,0,2,0,144,212,8,0,32,0,0,0,1,64,64,0,96,135,7,0,32,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,24,172,6,0,32,0,0,0,1,128,128,0,96,135,7,0,32,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,33,0,0,0,1,12,8,0,80,246,3,0,33,0,0,0,1,12,12,0,248,38,7,0,33,0,0,0,1,12,4,0,112,212,3,0,33,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,2,0,216,212,3,0,33,0,0,0,1,32,32,0,208,75,4,0,33,0,0,0,1,32,0,0,152,21,4,0,0,0,0,0,254,0,2,0,168,234,7,0,33,0,0,0,1,128,128,0,96,135,7,0,33,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,101,112,114,45,49,49,52,48,53,46,105,99,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,90,221,87,224,1,0,16,1,101,112,114,45,49,49,52,48,54,46,105,99,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,184,148,185,198,1,0,16,1,101,112,114,45,49,49,51,48,54,46,105,99,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,180,242,149,75,1,0,16,1,101,112,114,45,49,49,51,48,55,46,105,99,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,228,51,104,45,1,0,16,1,101,112,114,45,49,49,51,57,48,46,105,99,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,219,143,152,237,9,0,16,1,101,112,114,45,49,49,51,57,49,46,105,99,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,193,59,82,18,9,0,16,1,101,112,114,45,49,49,51,49,48,46,105,99,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,44,160,159,93,9,0,16,1,101,112,114,45,49,49,51,49,49,46,105,99,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,27,226,61,72,9,0,16,1,101,112,114,45,49,49,51,49,52,46,105,99,49,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,169,84,249,212,2,0,32,0,101,112,114,45,49,49,51,49,53,46,105,99,49,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,136,48,129,53,2,0,32,0,101,112,114,45,49,49,51,49,54,46,105,99,49,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,255,13,41,132,2,0,32,0,101,112,114,45,49,49,51,50,51,46,105,99,57,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,53,7,228,39,3,0,32,0,101,112,114,45,49,49,51,50,50,46,105,99,57,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,116,77,54,16,3,0,32,0,101,112,114,45,49,49,51,50,49,46,105,99,57,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,88,143,115,142,3,0,32,0,101,112,114,45,49,49,51,50,48,46,105,99,49,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,184,118,92,169,3,0,32,0,101,112,114,45,49,49,51,50,55,46,105,99,57,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,241,144,174,222,3,0,32,0,101,112,114,45,49,49,51,50,54,46,105,99,57,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,3,132,25,41,3,0,32,0,101,112,114,45,49,49,51,50,53,46,105,99,57,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,233,138,233,185,3,0,32,0,101,112,114,45,49,49,51,50,52,46,105,99,49,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,82,181,66,151,3,0,32,0,101,112,114,45,49,49,51,51,49,46,105,99,57,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,46,4,44,58,3,0,32,0,101,112,114,45,49,49,51,51,48,46,105,99,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,197,112,124,170,3,0,32,0,101,112,114,45,49,49,51,50,57,46,105,99,49,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,87,2,178,49,3,0,32,0,101,112,114,45,49,49,51,50,56,46,105,99,49,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,156,232,57,218,3,0,32,0,101,112,114,45,49,49,51,57,53,46,105,99,57,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,121,85,119,144,3,0,32,0,101,112,114,45,49,49,51,57,52,46,105,99,57,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,2,0,190,131,39,95,3,0,32,0,101,112,114,45,49,49,51,57,51,46,105,99,49,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,29,46,94,82,3,0,32,0,101,112,114,45,49,49,51,57,50,46,105,99,49,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,247,130,163,180,3,0,32,0,101,112,114,45,49,49,51,49,51,46,105,99,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,195,196,86,106,10,0,32,0,101,112,114,45,49,49,51,57,54,46,105,99,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,164,84,123,211,4,0,16,1,101,112,114,45,49,49,51,49,55,46,105,99,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,31,172,231,212,11,0,64,0,101,112,114,45,49,49,51,49,56,46,105,99,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,44,240,211,112,11,0,64,0,101,112,114,45,49,49,51,49,57,46,105,99,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,46,36,217,80,11,0,64,0,51,49,55,45,48,48,53,54,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,197,210,12,180,5,0,16,1,11,0,0,0,255,255,255,0,0,0,0,0,12,0,0,0,255,255,253,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,11,0,0,0,1,15,7,0,80,252,6,0,11,0,0,0,1,15,8,0,16,242,7,0,11,0,0,0,1,15,9,0,104,236,7,0,11,0,0,0,1,15,5,0,176,51,4,0,11,0,0,0,1,15,4,0,56,24,4,0,11,0,0,0,1,15,15,0,128,230,7,0,11,0,0,0,1,15,1,0,72,216,3,0,11,0,0,0,1,15,2,0,24,188,3,0,11,0,0,0,1,15,3,0,176,162,3,0,11,0,0,0,1,15,6,0,120,211,6,0,11,0,0,0,1,15,14,0,184,164,6,0,11,0,0,0,1,15,13,0,80,74,6,0,11,0,0,0,1,15,12,0,192,32,6,0,11,0,0,0,1,15,11,0,192,234,2,0,11,0,0,0,1,15,10,0,32,242,5,0,11,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,11,0,0,0,1,240,112,0,80,252,6,0,11,0,0,0,1,240,128,0,16,242,7,0,11,0,0,0,1,240,144,0,104,236,7,0,11,0,0,0,1,240,80,0,176,51,4,0,11,0,0,0,1,240,64,0,56,24,4,0,11,0,0,0,1,240,240,0,128,230,7,0,11,0,0,0,1,240,16,0,72,216,3,0,11,0,0,0,1,240,32,0,24,188,3,0,11,0,0,0,1,240,48,0,176,162,3,0,11,0,0,0,1,240,96,0,120,211,6,0,11,0,0,0,1,240,224,0,184,164,6,0,11,0,0,0,1,240,208,0,80,74,6,0,11,0,0,0,1,240,192,0,192,32,6,0,11,0,0,0,1,240,176,0,192,234,2,0,11,0,0,0,1,240,160,0,32,242,5,0,11,0,0,0,1,240,0,0,208,236,2,0,0,0,0,0,254,0,2,0,64,251,5,0,12,0,0,0,1,1,1,0,104,24,1,0,12,0,0,0,1,1,0,0,96,128,8,0,0,0,0,0,254,0,2,0,168,234,7,0,12,0,0,0,1,2,2,0,96,135,7,0,12,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,112,59,6,0,12,0,0,0,1,4,4,0,40,161,1,0,12,0,0,0,1,4,0,0,184,152,1,0,0,0,0,0,254,0,4,0,128,129,4,0,12,0,0,0,1,24,8,0,208,75,4,0,12,0,0,0,1,24,24,0,8,49,4,0,12,0,0,0,1,24,16,0,152,21,4,0,12,0,0,0,1,24,0,0,72,246,3,0,0,0,0,0,254,0,2,0,104,159,3,0,12,0,0,0,1,32,0,0,56,111,3,0,12,0,0,0,1,32,32,0,104,134,3,0,0,0,0,0,254,0,4,0,72,202,5,0,12,0,0,0,1,192,64,0,80,246,3,0,12,0,0,0,1,192,192,0,248,38,7,0,12,0,0,0,1,192,128,0,112,212,3,0,12,0,0,0,1,192,0,0,248,160,5,0,101,112,114,45,54,48,55,49,46,49,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,249,125,181,150,0,0,16,1,101,112,114,45,54,48,55,50,46,49,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,208,173,186,247,0,0,16,1,101,112,114,45,54,48,55,51,46,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,102,241,26,114,0,0,16,1,101,112,114,45,54,48,55,55,46,49,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,2,118,163,2,0,0,16,1,101,112,114,45,54,48,56,57,46,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,255,229,131,161,0,0,32,0,101,112,114,45,54,48,56,56,46,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,166,180,25,185,0,0,32,0,101,112,114,45,54,48,56,55,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,44,116,119,38,0,0,32,0,101,112,114,45,54,48,56,54,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,132,160,181,118,0,0,32,0,101,112,114,45,54,48,56,53,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,98,220,61,156,0,0,32,0,101,112,114,45,54,48,56,52,46,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,95,250,225,144,0,0,32,0,101,112,114,45,54,48,54,57,46,49,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,65,30,105,254,0,0,32,0,101,112,114,45,54,48,55,48,46,49,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,223,128,240,52,0,0,32,0,112,114,45,53,51,49,55,46,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,184,80,131,100,0,0,0,8,184,40,2,0,1,0,0,0,47,39,216,0,248,191,2,0,56,250,6,0,1,0,0,0,39,39,216,0,184,160,2,0,184,164,8,0,1,0,0,0,46,39,216,0,64,246,1,0,88,149,7,0,1,0,0,0,38,39,216,0,136,224,1,0,208,158,7,0,1,0,0,0,45,39,216,0,96,82,2,0,184,154,7,0,1,0,0,0,44,39,216,0,32,56,2,0,176,108,2,0,1,0,0,0,43,39,216,0,152,30,2,0,128,98,2,0,1,0,0,0,41,39,216,0,232,10,2,0,16,83,7,0,1,0,0,0,37,39,216,0,40,167,1,0,96,79,7,0,1,0,0,0,36,39,216,0,200,149,1,0,48,76,7,0,1,0,0,0,35,39,216,0,56,126,1,0,144,72,7,0,1,0,0,0,34,39,216,0,32,101,1,0,88,212,3,0,1,0,0,0,48,38,216,0,40,185,3,0,16,17,8,0,1,0,0,0,42,39,216,0,224,12,8,0,248,5,8,0,9,0,0,0,112,39,216,0,32,58,1,0,144,250,7,0,9,0,0,0,113,39,216,0,32,58,1,0,248,241,7,0,9,0,0,0,114,39,216,0,32,58,1,0,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,2,0,0,96,135,7,0,19,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,8,0,160,123,6,0,19,0,0,0,1,28,16,0,32,136,7,0,19,0,0,0,1,28,8,0,40,88,7,0,19,0,0,0,1,28,24,0,96,39,7,0,19,0,0,0,1,28,28,0,144,251,6,0,19,0,0,0,1,28,12,0,184,164,6,0,19,0,0,0,1,28,20,0,80,74,6,0,19,0,0,0,1,28,4,0,192,32,6,0,19,0,0,0,1,28,0,0,16,227,4,0,0,0,0,0,254,0,8,0,200,87,7,0,19,0,0,0,1,224,128,0,32,136,7,0,19,0,0,0,1,224,64,0,40,88,7,0,19,0,0,0,1,224,192,0,96,39,7,0,19,0,0,0,1,224,224,0,144,251,6,0,19,0,0,0,1,224,96,0,184,164,6,0,19,0,0,0,1,224,160,0,80,74,6,0,19,0,0,0,1,224,32,0,192,32,6,0,19,0,0,0,1,224,0,0,16,227,4,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,12,4,0,80,246,3,0,20,0,0,0,1,12,12,0,248,38,7,0,20,0,0,0,1,12,8,0,112,212,3,0,20,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,4,0,64,37,5,0,20,0,0,0,1,48,48,0,120,124,5,0,20,0,0,0,1,48,32,0,72,122,5,0,20,0,0,0,1,48,0,0,216,119,5,0,20,0,0,0,1,48,16,0,120,7,5,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,192,64,0,208,75,4,0,20,0,0,0,1,192,192,0,8,49,4,0,20,0,0,0,1,192,128,0,152,21,4,0,20,0,0,0,1,192,0,0,72,246,3,0,114,111,109,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,56,92,22,77,1,0,16,1,114,111,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,49,33,145,30,1,0,16,1,101,112,114,49,50,49,54,53,46,98,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,33,2,100,98,2,0,32,0,101,112,114,49,50,49,54,54,46,98,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,59,24,189,154,2,0,32,0,101,112,114,49,50,49,54,55,46,98,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,78,253,149,36,2,0,32,0,111,98,106,48,45,111,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,128,136,179,47,3,0,32,0,111,98,106,48,45,101,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,186,44,160,214,3,0,32,0,101,112,114,49,50,49,54,56,46,97,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,27,160,155,189,4,0,16,1,101,112,114,45,54,55,51,57,46,49,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,105,126,163,129,0,0,16,1,101,112,114,45,54,55,52,48,46,49,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,169,136,83,113,0,0,16,1,101,112,114,45,54,55,52,49,46,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,95,79,167,229,0,0,16,1,101,112,114,45,54,55,52,56,46,49,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,207,161,37,147,0,0,16,1,101,112,114,45,54,55,52,55,46,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,167,172,229,160,0,0,32,0,101,112,114,45,54,55,52,54,46,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,81,126,183,205,0,0,32,0,101,112,114,45,54,55,52,53,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,195,117,171,12,0,0,32,0,101,112,114,45,54,55,52,52,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,205,210,248,14,0,0,32,0,101,112,114,45,54,55,52,51,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,181,98,48,195,0,0,32,0,101,112,114,45,54,55,52,50,46,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,197,232,87,196,0,0,32,0,101,112,114,45,54,55,51,53,46,49,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,151,90,227,27,0,0,32,0,101,112,114,45,54,55,51,55,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,122,170,83,107,0,0,32,0,101,112,114,45,54,55,51,54,46,49,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,208,37,92,86,0,0,32,0,101,112,114,45,54,55,51,56,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,95,40,22,225,0,0,32,0,112,114,45,53,51,49,55,46,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,184,80,131,100,0,0,0,8,18,0,0,0,255,255,255,0,0,0,0,0,19,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,18,0,0,0,1,3,0,0,192,255,2,0,18,0,0,0,1,3,2,0,208,75,4,0,18,0,0,0,1,3,3,0,8,49,4,0,18,0,0,0,1,3,1,0,152,21,4,0,0,0,0,0,254,0,4,0,72,202,5,0,18,0,0,0,1,48,32,0,80,246,3,0,18,0,0,0,1,48,48,0,248,38,7,0,18,0,0,0,1,48,16,0,112,212,3,0,18,0,0,0,1,48,0,0,248,160,5,0,0,0,0,0,254,0,8,0,200,87,7,0,19,0,0,0,1,7,4,0,32,136,7,0,19,0,0,0,1,7,5,0,40,88,7,0,19,0,0,0,1,7,6,0,96,39,7,0,19,0,0,0,1,7,7,0,144,251,6,0,19,0,0,0,1,7,3,0,184,164,6,0,19,0,0,0,1,7,2,0,80,74,6,0,19,0,0,0,1,7,1,0,192,32,6,0,19,0,0,0,1,7,0,0,16,227,4,0,0,0,0,0,254,0,8,0,160,123,6,0,19,0,0,0,1,56,32,0,32,136,7,0,19,0,0,0,1,56,40,0,40,88,7,0,19,0,0,0,1,56,48,0,96,39,7,0,19,0,0,0,1,56,56,0,144,251,6,0,19,0,0,0,1,56,24,0,184,164,6,0,19,0,0,0,1,56,16,0,80,74,6,0,19,0,0,0,1,56,8,0,192,32,6,0,19,0,0,0,1,56,0,0,16,227,4,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,64,0,0,96,135,7,0,19,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,21,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,232,75,4,0,20,0,0,0,1,1,1,0,96,135,7,0,20,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,20,0,0,0,1,2,0,0,96,135,7,0,20,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,48,16,0,80,246,3,0,20,0,0,0,1,48,48,0,248,38,7,0,20,0,0,0,1,48,32,0,112,212,3,0,20,0,0,0,1,48,0,0,248,160,5,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,192,0,0,192,255,2,0,20,0,0,0,1,192,64,0,208,75,4,0,20,0,0,0,1,192,192,0,8,49,4,0,20,0,0,0,1,192,128,0,152,21,4,0,0,0,0,0,254,0,16,0,160,123,6,0,21,0,0,0,1,15,4,0,32,136,7,0,21,0,0,0,1,15,10,0,40,88,7,0,21,0,0,0,1,15,1,0,96,39,7,0,21,0,0,0,1,15,0,0,192,24,7,0,21,0,0,0,1,15,2,0,120,113,6,0,21,0,0,0,1,15,8,0,232,228,5,0,21,0,0,0,1,15,15,0,144,251,6,0,21,0,0,0,1,15,12,0,56,141,7,0,21,0,0,0,1,15,14,0,120,211,6,0,21,0,0,0,1,15,7,0,184,164,6,0,21,0,0,0,1,15,6,0,24,1,7,0,21,0,0,0,1,15,11,0,80,74,6,0,21,0,0,0,1,15,3,0,192,32,6,0,21,0,0,0,1,15,13,0,192,234,2,0,21,0,0,0,1,15,5,0,32,242,5,0,21,0,0,0,1,15,9,0,176,192,2,0,0,0,0,0,254,0,16,0,200,87,7,0,21,0,0,0,1,240,64,0,32,136,7,0,21,0,0,0,1,240,160,0,40,88,7,0,21,0,0,0,1,240,16,0,96,39,7,0,21,0,0,0,1,240,32,0,120,113,6,0,21,0,0,0,1,240,128,0,232,228,5,0,21,0,0,0,1,240,240,0,144,251,6,0,21,0,0,0,1,240,192,0,56,141,7,0,21,0,0,0,1,240,224,0,120,211,6,0,21,0,0,0,1,240,112,0,184,164,6,0,21,0,0,0,1,240,96,0,24,1,7,0,21,0,0,0,1,240,176,0,80,74,6,0,21,0,0,0,1,240,48,0,192,32,6,0,21,0,0,0,1,240,208,0,192,234,2,0,21,0,0,0,1,240,80,0,32,242,5,0,21,0,0,0,1,240,144,0,176,192,2,0,21,0,0,0,1,240,0,0,16,227,4,0,184,40,2,0,1,0,0,0,40,39,216,0,248,191,2,0,56,250,6,0,1,0,0,0,32,39,216,0,184,160,2,0,184,164,8,0,1,0,0,0,41,39,216,0,64,246,1,0,88,149,7,0,1,0,0,0,33,39,216,0,136,224,1,0,240,167,7,0,1,0,0,0,47,39,216,0,192,135,2,0,176,163,7,0,1,0,0,0,45,39,216,0,240,108,2,0,208,158,7,0,1,0,0,0,42,39,216,0,96,82,2,0,184,154,7,0,1,0,0,0,43,39,216,0,32,56,2,0,176,108,2,0,1,0,0,0,44,39,216,0,152,30,2,0,88,212,3,0,1,0,0,0,48,38,216,0,40,185,3,0,16,17,8,0,1,0,0,0,47,39,216,0,224,12,8,0,248,5,8,0,9,0,0,0,112,39,216,0,32,58,1,0,144,250,7,0,9,0,0,0,113,39,216,0,32,58,1,0,248,241,7,0,9,0,0,0,114,39,216,0,32,58,1,0,116,97,122,122,109,49,46,52,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,161,128,68,161,1,0,16,1,116,97,122,122,109,50,46,53,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,219,245,9,86,1,0,16,1,116,97,122,122,109,51,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,2,112,127,254,1,0,16,1,116,97,122,122,109,52,46,55,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,10,29,202,201,1,0,16,1,116,97,122,122,109,53,46,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,166,216,12,245,1,0,16,1,116,97,122,122,109,54,46,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,210,231,242,92,1,0,16,1,116,97,122,109,56,46,49,108,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,43,97,91,44,4,0,32,0,116,97,122,122,109,55,46,49,106,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,172,243,95,63,4,0,32,0,112,114,111,109,46,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,135,125,12,106,7,0,32,0,15,0,0,0,255,255,0,0,0,0,0,0,16,0,0,0,255,255,0,0,0,0,0,0,17,0,0,0,255,255,4,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,17,0,0,0,1,1,0,0,120,97,1,0,17,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,4,0,32,4,2,0,17,0,0,0,1,6,0,0,232,66,1,0,17,0,0,0,1,6,2,0,120,66,1,0,17,0,0,0,1,6,6,0,232,65,1,0,17,0,0,0,1,6,4,0,16,223,1,0,0,0,0,0,50,99,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,6,90,44,147,1,0,16,1,50,101,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,101,206,23,239,1,0,16,1,50,102,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,157,195,199,67,1,0,16,1,50,104,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,148,150,130,190,1,0,16,1,50,106,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,113,114,25,110,1,0,16,1,50,107,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,59,69,235,161,1,0,16,1,114,111,109,48,46,115,110,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,241,65,215,184,2,0,16,1,53,102,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,43,97,91,44,4,0,32,0,53,104,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,172,243,95,63,4,0,32,0,99,111,108,114,54,102,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,199,51,227,252,7,0,32,0,50,99,107,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,191,146,4,191,1,0,16,1,50,101,107,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,208,196,54,102,1,0,16,1,50,102,107,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,123,165,89,206,1,0,16,1,50,104,107,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,128,51,218,139,1,0,16,1,50,106,107,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,53,94,9,164,1,0,16,1,50,107,107,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,54,202,8,243,1,0,16,1,114,111,109,48,46,115,110,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,241,65,215,184,2,0,16,1,53,102,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,43,97,91,44,4,0,32,0,53,104,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,172,243,95,63,4,0,32,0,99,111,108,114,54,102,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,199,51,227,252,7,0,32,0,21,0,0,0,255,255,255,0,0,0,0,0,22,0,0,0,255,255,255,0,0,0,0,0,23,0,0,0,255,255,255,0,0,0,0,0,24,0,0,0,255,255,8,0,0,0,0,0,0,0,0,0,254,0,2,0,72,209,1,0,21,0,0,0,1,1,1,0,176,111,1,0,21,0,0,0,1,1,0,0,232,78,1,0,0,0,0,0,254,0,8,0,32,4,2,0,21,0,0,0,2,14,10,0,16,242,7,0,21,0,0,0,0,1,0,0,0,0,0,0,21,0,0,0,2,14,12,0,104,236,7,0,21,0,0,0,0,1,0,0,0,0,0,0,21,0,0,0,2,14,14,0,80,245,6,0,21,0,0,0,0,1,0,0,0,0,0,0,21,0,0,0,2,14,8,0,8,201,6,0,21,0,0,0,0,1,0,0,0,0,0,0,21,0,0,0,2,14,6,0,200,197,6,0,21,0,0,0,0,1,0,0,0,0,0,0,21,0,0,0,2,14,4,0,152,194,6,0,21,0,0,0,0,1,0,0,0,0,0,0,21,0,0,0,2,14,2,0,128,95,7,0,21,0,0,0,0,1,0,0,0,0,0,0,21,0,0,0,2,14,0,0,248,189,6,0,21,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,254,0,8,0,184,40,2,0,21,0,0,0,2,14,10,0,16,242,7,0,21,0,0,0,0,1,1,0,0,0,0,0,21,0,0,0,2,14,12,0,104,236,7,0,21,0,0,0,0,1,1,0,0,0,0,0,21,0,0,0,2,14,14,0,80,245,6,0,21,0,0,0,0,1,1,0,0,0,0,0,21,0,0,0,2,14,8,0,8,201,6,0,21,0,0,0,0,1,1,0,0,0,0,0,21,0,0,0,2,14,6,0,200,197,6,0,21,0,0,0,0,1,1,0,0,0,0,0,21,0,0,0,2,14,4,0,152,194,6,0,21,0,0,0,0,1,1,0,0,0,0,0,21,0,0,0,2,14,2,0,128,95,7,0,21,0,0,0,0,1,1,0,0,0,0,0,21,0,0,0,2,14,0,0,248,189,6,0,21,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,254,0,8,0,184,164,8,0,21,0,0,0,2,112,80,0,16,242,7,0,21,0,0,0,0,1,1,0,0,0,0,0,21,0,0,0,2,112,96,0,104,236,7,0,21,0,0,0,0,1,1,0,0,0,0,0,21,0,0,0,2,112,112,0,80,245,6,0,21,0,0,0,0,1,1,0,0,0,0,0,21,0,0,0,2,112,64,0,8,201,6,0,21,0,0,0,0,1,1,0,0,0,0,0,21,0,0,0,2,112,48,0,200,197,6,0,21,0,0,0,0,1,1,0,0,0,0,0,21,0,0,0,2,112,32,0,152,194,6,0,21,0,0,0,0,1,1,0,0,0,0,0,21,0,0,0,2,112,16,0,128,95,7,0,21,0,0,0,0,1,1,0,0,0,0,0,21,0,0,0,2,112,0,0,248,189,6,0,21,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,254,0,2,0,24,172,6,0,21,0,0,0,1,128,128,0,96,135,7,0,21,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,22,0,0,0,1,2,0,0,96,135,7,0,22,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,2,0,16,227,4,0,22,0,0,0,1,4,4,0,96,135,7,0,22,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,22,0,0,0,1,24,16,0,80,246,3,0,22,0,0,0,1,24,24,0,248,38,7,0,22,0,0,0,1,24,8,0,112,212,3,0,22,0,0,0,1,24,0,0,248,160,5,0,0,0,0,0,254,0,2,0,232,75,4,0,22,0,0,0,1,32,32,0,96,135,7,0,22,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,112,11,5,0,23,0,0,0,1,1,0,0,96,135,7,0,23,0,0,0,1,1,1,0,152,182,7,0,0,0,0,0,254,0,2,0,0,233,4,0,23,0,0,0,1,2,0,0,56,111,3,0,23,0,0,0,1,2,2,0,104,134,3,0,0,0,0,0,254,0,5,0,224,133,4,0,24,0,0,0,1,15,0,0,184,255,2,0,24,0,0,0,1,15,1,0,176,20,3,0,24,0,0,0,1,15,2,0,64,54,4,0,24,0,0,0,1,15,4,0,56,50,1,0,24,0,0,0,1,15,8,0,224,32,1,0,0,0,0,0,114,111,109,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,157,229,2,65,0,0,16,1,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,195,131,58,204,0,0,16,1,114,111,109,52,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,109,169,106,70,0,0,16,1,114,111,109,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,228,250,45,205,0,0,32,0,114,111,109,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,100,218,100,78,0,0,32,0,114,111,109,57,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,55,244,69,204,0,0,32,0,114,111,109,56,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,105,1,201,155,0,0,32,0,114,111,109,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,86,199,199,191,0,0,32,0,114,111,109,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,175,153,52,187,0,0,32,0,114,111,109,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,201,126,234,52,0,0,64,0,114,111,109,51,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,59,35,115,27,0,0,64,0,18,0,0,0,255,255,16,0,0,0,0,0,0,0,0,0,254,0,8,0,200,87,7,0,18,0,0,0,1,7,6,0,104,54,4,0,18,0,0,0,1,7,5,0,80,252,6,0,18,0,0,0,1,7,4,0,16,242,7,0,18,0,0,0,1,7,3,0,104,236,7,0,18,0,0,0,1,7,0,0,128,230,7,0,18,0,0,0,1,7,1,0,184,164,6,0,18,0,0,0,1,7,2,0,80,74,6,0,18,0,0,0,1,7,7,0,16,227,4,0,0,0,0,0,254,0,4,0,128,129,4,0,18,0,0,0,1,24,0,0,192,255,2,0,18,0,0,0,1,24,8,0,208,75,4,0,18,0,0,0,1,24,16,0,8,49,4,0,18,0,0,0,1,24,24,0,72,246,3,0,0,0,0,0,254,0,2,0,72,202,5,0,18,0,0,0,1,32,0,0,248,38,7,0,18,0,0,0,1,32,32,0,112,212,3,0,0,0,0,0,254,0,2,0,64,37,5,0,18,0,0,0,1,64,0,0,8,49,6,0,18,0,0,0,1,64,64,0,176,210,4,0,0,0,0,0,254,0,2,0,232,75,4,0,18,0,0,0,1,128,0,0,96,135,7,0,18,0,0,0,1,128,128,0,152,182,7,0,18,0,0,0,255,255,64,0,0,0,0,0,19,0,0,0,255,255,124,0,0,0,0,0,0,0,0,0,254,0,8,0,200,87,7,0,18,0,0,0,1,7,7,0,112,31,1,0,18,0,0,0,1,7,6,0,184,220,8,0,18,0,0,0,1,7,5,0,88,154,8,0,18,0,0,0,1,7,4,0,200,92,8,0,18,0,0,0,1,7,0,0,56,37,8,0,18,0,0,0,1,7,1,0,96,240,7,0,18,0,0,0,1,7,2,0,128,188,7,0,18,0,0,0,1,7,3,0,248,140,7,0,0,0,0,0,254,0,8,0,160,123,6,0,18,0,0,0,1,56,56,0,112,31,1,0,18,0,0,0,1,56,48,0,184,220,8,0,18,0,0,0,1,56,40,0,88,154,8,0,18,0,0,0,1,56,32,0,200,92,8,0,18,0,0,0,1,56,0,0,56,37,8,0,18,0,0,0,1,56,8,0,96,240,7,0,18,0,0,0,1,56,16,0,128,188,7,0,18,0,0,0,1,56,24,0,248,140,7,0,0,0,0,0,254,0,4,0,128,129,4,0,18,0,0,0,1,192,0,0,208,75,4,0,18,0,0,0,1,192,64,0,8,49,4,0,18,0,0,0,1,192,128,0,152,21,4,0,18,0,0,0,1,192,192,0,72,246,3,0,0,0,0,0,254,0,4,0,64,37,5,0,19,0,0,0,1,3,0,0,80,110,6,0,19,0,0,0,1,3,1,0,152,53,6,0,19,0,0,0,1,3,2,0,112,216,4,0,19,0,0,0,1,3,3,0,8,49,6,0,0,0,0,0,254,0,2,0,16,227,4,0,19,0,0,0,1,8,8,0,96,135,7,0,19,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,2,0,72,202,5,0,19,0,0,0,1,16,16,0,80,246,3,0,19,0,0,0,1,16,0,0,112,212,3,0,0,0,0,0,254,0,2,0,224,195,4,0,19,0,0,0,1,32,32,0,96,135,7,0,19,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,0,164,4,0,19,0,0,0,1,64,0,0,96,135,7,0,19,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,200,30,2,0,19,0,0,0,1,128,0,0,120,97,1,0,19,0,0,0,1,128,128,0,96,19,1,0,0,0,0,0,101,112,114,45,49,49,49,51,51,46,97,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,55,47,215,238,1,0,16,1,101,112,114,45,49,49,49,51,48,46,97,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,118,22,69,226,1,0,16,1,101,112,114,45,49,49,49,51,52,46,97,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,245,87,216,204,1,0,16,1,101,112,114,45,49,49,49,51,49,46,97,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,204,194,120,155,1,0,16,1,101,112,114,45,49,49,49,51,53,46,97,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,225,224,53,55,1,0,16,1,101,112,114,45,49,49,49,51,50,46,97,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,37,147,25,255,1,0,16,1,101,112,114,45,49,49,49,51,54,46,98,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,228,12,134,195,2,0,32,0,101,112,114,45,49,49,49,51,55,46,98,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,135,97,217,146,2,0,32,0,101,112,114,45,49,49,49,51,56,46,98,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,115,199,29,192,2,0,32,0,101,112,114,45,49,49,49,52,52,46,98,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,28,229,29,179,3,0,32,0,101,112,114,45,49,49,49,52,56,46,98,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,9,19,110,18,3,0,32,0,101,112,114,45,49,49,49,52,53,46,98,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,195,210,35,66,3,0,32,0,101,112,114,45,49,49,49,52,57,46,98,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,101,55,77,105,3,0,32,0,101,112,114,45,49,49,49,52,54,46,98,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,182,89,3,191,3,0,32,0,101,112,114,45,49,49,49,53,48,46,98,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,237,173,192,159,3,0,32,0,101,112,114,45,49,49,49,52,55,46,98,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,114,39,89,62,3,0,32,0,101,112,114,45,49,49,49,53,49,46,98,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,105,81,233,157,3,0,32,0,101,112,114,45,49,49,49,51,57,46,97,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,218,153,189,156,4,0,16,1,101,112,114,45,49,49,49,52,48,46,97,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,27,55,151,178,8,0,64,0,101,112,114,45,49,49,49,52,49,46,97,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,166,106,117,25,8,0,64,0,101,112,114,45,49,49,49,52,50,46,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,102,108,210,37,8,0,64,0,101,112,114,45,49,49,49,52,51,46,97,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,119,123,139,132,8,0,64,0,51,49,55,45,48,48,52,53,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,46,204,148,5,5,0,16,1,49,46,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,216,65,81,178,1,0,16,1,115,99,111,98,114,97,50,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,77,228,112,162,1,0,16,1,115,99,111,98,114,97,50,102,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,70,3,215,189,1,0,16,1,115,99,111,98,114,97,50,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,49,236,165,220,1,0,16,1,115,99,111,98,114,97,50,106,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,110,107,143,13,1,0,16,1,54,46,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,217,116,164,16,1,0,16,1,101,112,114,49,50,55,53,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,211,13,235,222,2,0,16,1,101,112,114,49,50,55,54,46,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,116,26,44,135,2,0,16,1,57,46,57,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,243,184,105,43,2,0,16,1,101,112,114,49,50,55,52,46,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,180,19,209,100,4,0,32,0,101,112,114,49,50,55,51,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,211,22,99,169,4,0,32,0,107,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,97,197,53,253,7,0,32,0,9,0,0,0,255,255,0,0,0,0,0,0,10,0,0,0,255,255,190,0,0,0,0,0,0,0,0,0,254,0,2,0,32,4,2,0,9,0,0,0,1,1,0,0,56,37,8,0,9,0,0,0,1,1,1,0,96,240,7,0,0,0,0,0,254,0,2,0,64,37,5,0,9,0,0,0,1,8,0,0,248,240,1,0,9,0,0,0,1,8,8,0,104,229,1,0,0,0,0,0,254,0,8,0,72,202,5,0,9,0,0,0,1,38,0,0,192,255,2,0,9,0,0,0,1,38,2,0,208,75,4,0,9,0,0,0,1,38,32,0,8,49,4,0,9,0,0,0,1,38,34,0,152,21,4,0,9,0,0,0,1,38,4,0,72,246,3,0,9,0,0,0,1,38,6,0,72,0,3,0,9,0,0,0,1,38,36,0,64,47,7,0,9,0,0,0,1,38,38,0,232,99,5,0,0,0,0,0,254,0,4,0,128,129,4,0,9,0,0,0,1,80,0,0,8,49,4,0,9,0,0,0,1,80,16,0,152,21,4,0,9,0,0,0,1,80,64,0,72,246,3,0,9,0,0,0,1,80,80,0,72,0,3,0,0,0,0,0,254,0,2,0,168,234,7,0,9,0,0,0,1,128,128,0,96,135,7,0,9,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,112,114,111,103,50,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,116,126,75,113,0,0,16,1,112,114,111,103,49,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,222,88,184,11,0,0,16,1,105,45,115,99,114,50,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,206,192,126,208,0,0,16,1,105,45,115,99,114,49,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,222,139,106,169,0,0,16,1,105,45,115,99,114,52,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,202,89,233,0,0,16,1,105,45,115,99,114,51,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,130,224,245,75,0,0,16,1,105,45,115,99,114,54,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,194,55,19,231,0,0,16,1,105,45,115,99,114,53,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,251,205,28,100,0,0,16,1,105,45,115,99,114,56,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,200,19,24,124,0,0,16,1,105,45,115,99,114,55,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,104,50,199,25,0,0,16,1,111,98,106,49,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,81,212,44,131,0,0,32,0,109,117,115,105,99,49,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,85,102,31,43,0,0,64,0,109,117,115,105,99,50,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,90,230,202,204,0,0,64,0,98,54,49,95,48,57,46,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,88,29,15,100,2,0,16,1,98,54,49,95,48,55,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,83,153,219,253,2,0,16,1,98,54,49,95,48,56,46,97,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,142,2,252,121,2,0,16,1,98,54,49,95,49,51,46,97,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,68,106,68,159,2,0,16,1,98,54,49,95,49,48,46,100,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,232,121,254,110,9,0,16,1,98,54,49,45,49,52,46,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,62,140,54,137,15,0,32,0,98,54,49,45,49,53,46,104,49,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,249,196,12,145,15,0,32,0,98,54,49,45,49,54,46,106,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,47,237,34,54,15,0,32,0,98,54,49,45,49,55,46,107,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,224,39,79,195,15,0,32,0,98,54,49,45,48,49,46,101,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,134,151,249,60,25,0,64,0,98,54,49,95,49,49,46,109,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,16,17,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,2,2,0,96,135,7,0,19,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,4,4,0,96,135,7,0,19,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,8,0,0,96,135,7,0,19,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,19,0,0,0,1,48,0,0,80,252,6,0,19,0,0,0,1,48,16,0,16,242,7,0,19,0,0,0,1,48,32,0,104,236,7,0,19,0,0,0,1,48,48,0,128,230,7,0,0,0,0,0,254,0,4,0,160,123,6,0,19,0,0,0,1,192,192,0,8,201,6,0,19,0,0,0,1,192,128,0,200,197,6,0,19,0,0,0,1,192,64,0,152,194,6,0,19,0,0,0,1,192,0,0,248,189,6,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,3,2,0,80,246,3,0,20,0,0,0,1,3,3,0,80,124,6,0,20,0,0,0,1,3,1,0,112,212,3,0,20,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,48,32,0,208,75,4,0,20,0,0,0,1,48,48,0,8,49,4,0,20,0,0,0,1,48,16,0,152,21,4,0,20,0,0,0,1,48,0,0,72,246,3,0,0,0,0,0,100,52,54,45,51,53,43,46,105,99,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,167,201,117,21,4,0,16,1,100,52,54,45,51,52,43,46,105,99,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,43,77,42,199,4,0,16,1,100,52,54,45,51,51,43,46,105,99,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,208,188,148,48,4,0,16,1,100,52,54,45,51,50,43,46,105,99,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,53,179,190,79,4,0,16,1,100,52,54,45,50,52,46,105,99,49,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,161,186,6,160,6,0,16,1,100,52,54,45,50,51,46,105,99,49,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,208,219,105,154,6,0,16,1,100,52,54,45,51,55,46,105,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,145,27,181,96,8,0,16,1,100,52,54,45,51,54,46,105,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,118,162,122,143,8,0,16,1,100,52,54,45,48,53,46,105,99,56,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,76,14,13,21,12,0,32,0,100,52,54,45,48,54,46,105,99,56,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,190,8,19,50,12,0,32,0,100,52,54,45,48,52,46,105,99,54,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,169,105,39,131,17,0,32,0,100,52,54,45,48,51,46,105,99,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,253,203,233,224,17,0,32,0,100,52,54,45,48,50,46,105,99,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,46,168,60,168,17,0,32,0,100,52,54,45,48,49,46,105,99,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,45,233,42,92,17,0,32,0,100,52,54,45,48,55,46,105,99,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,147,176,184,195,23,0,32,0,100,52,54,45,49,48,46,105,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,190,86,98,48,31,0,64,0,100,52,54,45,49,50,46,105,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,168,83,74,162,31,0,64,0,100,52,54,45,49,49,46,105,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,86,15,234,212,31,0,64,0,101,101,112,114,111,109,45,115,117,112,101,114,99,104,115,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,83,7,15,35,32,0,16,0,112,97,108,49,54,108,56,98,99,110,45,100,52,54,45,49,51,46,105,99,56,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,137,232,50,47,0,0,0,8,112,97,108,49,54,108,56,98,99,110,45,100,52,54,45,49,52,46,105,99,56,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,248,181,200,90,0,0,0,8,112,97,108,49,54,108,56,98,99,110,45,100,52,54,45,49,53,46,105,99,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,54,159,234,56,0,0,0,8,112,97,108,99,101,50,48,118,56,104,45,100,52,54,45,49,54,46,105,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,87,1,0,0,159,255,225,100,0,0,0,8,112,97,108,99,101,50,48,118,56,104,45,100,52,54,45,49,55,46,105,99,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,87,1,0,0,225,148,157,92,0,0,0,8,112,97,108,99,101,49,54,118,56,104,45,100,52,54,45,49,56,46,105,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,148,184,129,117,0,0,0,8,112,97,108,99,101,49,54,118,56,104,45,100,52,54,45,49,57,46,105,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,208,99,216,165,0,0,0,8,112,97,108,99,101,50,48,118,56,104,45,100,52,54,45,50,48,46,105,99,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,87,1,0,0,17,188,140,131,0,0,0,8,112,97,108,99,101,50,48,118,56,104,45,100,52,54,45,50,49,46,105,99,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,87,1,0,0,194,170,197,147,0,0,0,8,112,97,108,99,101,50,48,118,56,104,45,100,52,54,45,50,50,46,105,99,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,87,1,0,0,6,11,161,198,0,0,0,8,50,100,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,24,186,192,96,1,0,16,1,50,101,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,191,68,207,221,1,0,16,1,50,102,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,213,194,102,187,1,0,16,1,50,104,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,77,240,244,116,1,0,16,1,50,106,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,8,251,239,120,1,0,16,1,50,108,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,189,236,220,233,1,0,16,1,50,109,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,126,51,208,62,1,0,16,1,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,42,190,153,184,2,0,16,1,53,100,46,115,110,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,4,10,100,128,2,0,16,1,53,102,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,134,70,157,91,4,0,32,0,53,104,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,39,153,194,88,4,0,32,0,56,50,115,49,50,51,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,13,249,135,155,7,0,32,0,11,0,0,0,255,255,0,0,0,0,0,0,12,0,0,0,255,255,2,0,0,0,0,0,13,0,0,0,255,255,4,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,12,0,0,0,1,3,2,0,8,49,4,0,12,0,0,0,1,3,1,0,72,246,3,0,12,0,0,0,1,3,0,0,16,227,4,0,12,0,0,0,1,3,3,0,144,246,3,0,0,0,0,0,254,0,4,0,32,4,2,0,13,0,0,0,1,6,4,0,128,103,7,0,13,0,0,0,1,6,6,0,56,52,2,0,13,0,0,0,1,6,2,0,224,44,2,0,13,0,0,0,1,6,0,0,224,43,2,0,0,0,0,0,17,0,0,0,255,255,255,0,0,0,0,0,18,0,0,0,255,255,254,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,17,0,0,0,1,2,2,0,96,135,7,0,17,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,8,0,160,123,6,0,17,0,0,0,1,28,0,0,40,88,7,0,17,0,0,0,1,28,16,0,96,39,7,0,17,0,0,0,1,28,28,0,144,251,6,0,17,0,0,0,1,28,12,0,184,164,6,0,17,0,0,0,1,28,20,0,80,74,6,0,17,0,0,0,1,28,4,0,192,32,6,0,17,0,0,0,1,28,24,0,192,234,2,0,17,0,0,0,1,28,8,0,32,242,5,0,0,0,0,0,254,0,8,0,200,87,7,0,17,0,0,0,1,224,0,0,40,88,7,0,17,0,0,0,1,224,128,0,96,39,7,0,17,0,0,0,1,224,224,0,144,251,6,0,17,0,0,0,1,224,96,0,184,164,6,0,17,0,0,0,1,224,160,0,80,74,6,0,17,0,0,0,1,224,32,0,192,32,6,0,17,0,0,0,1,224,192,0,192,234,2,0,17,0,0,0,1,224,64,0,32,242,5,0,0,0,0,0,254,0,2,0,168,234,7,0,18,0,0,0,1,1,1,0,96,135,7,0,18,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,18,0,0,0,1,2,0,0,56,111,3,0,18,0,0,0,1,2,2,0,104,134,3,0,0,0,0,0,254,0,4,0,72,202,5,0,18,0,0,0,1,48,16,0,80,246,3,0,18,0,0,0,1,48,48,0,248,38,7,0,18,0,0,0,1,48,32,0,112,212,3,0,18,0,0,0,1,48,0,0,248,160,5,0,0,0,0,0,254,0,3,0,128,129,4,0,18,0,0,0,1,192,128,0,192,255,2,0,18,0,0,0,1,192,0,0,208,75,4,0,18,0,0,0,1,192,192,0,8,49,4,0,10,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,4,0,32,4,2,0,10,0,0,0,1,3,0,0,80,245,6,0,10,0,0,0,1,3,1,0,8,201,6,0,10,0,0,0,1,3,2,0,200,197,6,0,10,0,0,0,1,3,3,0,152,194,6,0,0,0,0,0,254,0,2,0,200,30,2,0,10,0,0,0,1,4,0,0,120,97,1,0,10,0,0,0,1,4,4,0,96,19,1,0,0,0,0,0,254,0,2,0,144,212,8,0,10,0,0,0,1,8,0,0,96,135,7,0,10,0,0,0,1,8,8,0,152,182,7,0,101,112,114,45,49,51,56,50,52,46,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,12,97,242,44,1,0,16,1,101,112,114,45,49,51,56,50,51,46,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,47,36,152,44,1,0,16,1,101,112,114,45,49,51,56,50,54,46,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,85,234,52,61,1,0,16,1,101,112,114,45,49,51,56,50,53,46,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,131,141,33,254,1,0,16,1,101,112,114,45,49,51,56,51,48,46,56,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,209,201,173,249,9,0,16,1,101,112,114,45,49,51,56,50,57,46,56,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,221,133,205,197,9,0,16,1,101,112,114,45,49,51,56,50,56,46,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,95,207,112,36,17,0,16,1,101,112,114,45,49,51,56,50,55,46,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,125,207,208,169,17,0,16,1,101,112,114,45,49,51,56,51,50,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,84,151,103,65,3,0,32,0,101,112,114,45,49,51,56,51,51,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,26,225,72,97,3,0,32,0,101,112,114,45,49,51,48,51,56,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,109,219,46,11,3,0,32,0,101,112,114,45,49,51,48,52,48,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,133,58,235,74,3,0,32,0,101,112,114,45,49,51,48,52,56,46,54,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,221,176,30,254,18,0,32,0,101,112,114,45,49,51,48,53,54,46,55,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,230,248,4,89,18,0,32,0,101,112,114,45,49,51,48,52,52,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,137,31,147,77,18,0,32,0,101,112,114,45,49,51,48,53,50,46,55,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,64,240,145,2,18,0,32,0,101,112,114,45,49,51,48,54,52,46,56,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,27,101,142,95,18,0,32,0,101,112,114,45,49,51,48,55,50,46,49,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,26,100,133,107,18,0,32,0,101,112,114,45,49,51,48,54,48,46,56,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,151,173,22,238,18,0,32,0,101,112,114,45,49,51,48,54,56,46,49,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,187,43,213,100,18,0,32,0,101,112,114,45,49,51,48,52,55,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,50,8,52,83,18,0,32,0,101,112,114,45,49,51,48,53,53,46,55,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,101,182,182,57,18,0,32,0,101,112,114,45,49,51,48,52,51,46,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,253,22,143,32,18,0,32,0,101,112,114,45,49,51,48,53,49,46,55,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,212,203,98,173,18,0,32,0,101,112,114,45,49,51,48,54,51,46,56,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,109,191,128,197,18,0,32,0,101,112,114,45,49,51,48,55,49,46,49,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,153,239,153,223,18,0,32,0,101,112,114,45,49,51,48,53,57,46,56,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,88,37,152,76,18,0,32,0,101,112,114,45,49,51,48,54,55,46,49,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,25,97,127,249,18,0,32,0,101,112,114,45,49,51,48,52,54,46,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,233,134,90,199,18,0,32,0,101,112,114,45,49,51,48,53,52,46,55,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,154,84,52,41,18,0,32,0,101,112,114,45,49,51,48,52,50,46,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,175,151,237,83,18,0,32,0,101,112,114,45,49,51,48,53,48,46,54,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,104,144,66,4,18,0,32,0,101,112,114,45,49,51,48,54,50,46,56,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,227,78,219,79,18,0,32,0,101,112,114,45,49,51,48,55,48,46,49,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,14,19,234,82,18,0,32,0,101,112,114,45,49,51,48,53,56,46,56,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,38,22,255,25,18,0,32,0,101,112,114,45,49,51,48,54,54,46,49,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,80,162,112,188,18,0,32,0,101,112,114,45,49,51,48,52,53,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,109,188,213,84,18,0,32,0,101,112,114,45,49,51,48,53,51,46,55,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,19,175,2,149,18,0,32,0,101,112,114,45,49,51,48,52,49,46,54,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,44,64,167,208,18,0,32,0,101,112,114,45,49,51,48,52,57,46,54,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,108,11,156,91,18,0,32,0,101,112,114,45,49,51,48,54,49,46,56,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,59,236,149,123,18,0,32,0,101,112,114,45,49,51,48,54,57,46,49,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,240,56,245,225,18,0,32,0,101,112,114,45,49,51,48,53,55,46,55,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,238,239,186,115,18,0,32,0,101,112,114,45,49,51,48,54,53,46,49,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,85,166,55,137,18,0,32,0,101,112,114,45,49,51,56,51,49,46,49,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,161,206,187,218,4,0,16,1,109,112,114,45,49,51,48,51,54,46,49,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,108,194,144,120,11,0,64,0,109,112,114,45,49,51,48,51,53,46,49,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,62,161,159,0,11,0,64,0,109,112,114,45,49,51,48,51,52,46,49,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,93,217,34,205,11,0,64,0,12,0,0,0,255,255,91,0,0,0,0,0,13,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,72,202,5,0,12,0,0,0,1,3,2,0,80,246,3,0,12,0,0,0,1,3,3,0,248,38,7,0,12,0,0,0,1,3,1,0,112,212,3,0,12,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,2,0,168,234,7,0,12,0,0,0,1,4,4,0,96,135,7,0,12,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,12,0,0,0,1,8,0,0,56,111,3,0,12,0,0,0,1,8,8,0,104,134,3,0,0,0,0,0,254,0,4,0,56,154,6,0,12,0,0,0,1,48,16,0,184,30,3,0,12,0,0,0,1,48,48,0,0,28,3,0,12,0,0,0,1,48,32,0,144,188,3,0,12,0,0,0,1,48,0,0,176,163,3,0,0,0,0,0,254,0,3,0,200,30,2,0,12,0,0,0,1,192,192,0,120,247,1,0,12,0,0,0,1,192,128,0,80,46,8,0,12,0,0,0,1,192,64,0,120,97,1,0,0,0,0,0,254,0,16,0,200,87,7,0,13,0,0,0,1,15,7,0,80,252,6,0,13,0,0,0,1,15,8,0,16,242,7,0,13,0,0,0,1,15,9,0,104,236,7,0,13,0,0,0,1,15,5,0,176,51,4,0,13,0,0,0,1,15,4,0,56,24,4,0,13,0,0,0,1,15,15,0,128,230,7,0,13,0,0,0,1,15,1,0,72,216,3,0,13,0,0,0,1,15,2,0,24,188,3,0,13,0,0,0,1,15,3,0,176,162,3,0,13,0,0,0,1,15,6,0,120,211,6,0,13,0,0,0,1,15,14,0,184,164,6,0,13,0,0,0,1,15,13,0,80,74,6,0,13,0,0,0,1,15,12,0,192,32,6,0,13,0,0,0,1,15,11,0,192,234,2,0,13,0,0,0,1,15,10,0,32,242,5,0,13,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,13,0,0,0,1,240,112,0,80,252,6,0,13,0,0,0,1,240,128,0,16,242,7,0,13,0,0,0,1,240,144,0,104,236,7,0,13,0,0,0,1,240,80,0,176,51,4,0,13,0,0,0,1,240,64,0,56,24,4,0,13,0,0,0,1,240,240,0,128,230,7,0,13,0,0,0,1,240,16,0,72,216,3,0,13,0,0,0,1,240,32,0,24,188,3,0,13,0,0,0,1,240,48,0,176,162,3,0,13,0,0,0,1,240,96,0,120,211,6,0,13,0,0,0,1,240,224,0,184,164,6,0,13,0,0,0,1,240,208,0,80,74,6,0,13,0,0,0,1,240,192,0,192,32,6,0,13,0,0,0,1,240,176,0,192,234,2,0,13,0,0,0,1,240,160,0,32,242,5,0,13,0,0,0,1,240,0,0,208,236,2,0,115,116,104,95,51,54,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,6,176,199,83,1,0,16,1,115,116,104,95,52,50,46,49,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,95,246,55,64,1,0,16,1,115,116,104,95,51,55,46,49,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,125,135,232,128,1,0,16,1,115,116,104,95,52,51,46,49,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,102,164,63,107,1,0,16,1,115,116,104,95,51,52,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,181,112,167,190,1,0,16,1,115,116,104,95,52,48,46,49,48,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,220,34,185,67,1,0,16,1,115,116,104,95,51,53,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,218,41,196,92,1,0,16,1,115,116,104,95,52,49,46,49,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,127,69,175,80,1,0,16,1,115,116,104,95,48,57,46,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,189,191,246,30,4,0,32,0,115,116,104,95,48,49,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,193,176,33,30,4,0,32,0,115,116,104,95,49,51,46,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,174,99,50,6,4,0,32,0,115,116,104,95,48,53,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,20,135,159,236,4,0,32,0,115,116,104,95,50,52,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,210,244,86,99,4,0,32,0,115,116,104,95,49,55,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,134,61,247,180,4,0,32,0,115,116,104,95,51,56,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,194,191,90,238,4,0,32,0,115,116,104,95,51,50,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,163,6,162,68,4,0,32,0,115,116,104,95,49,48,46,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,188,211,61,223,4,0,32,0,115,116,104,95,48,50,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,160,158,95,199,4,0,32,0,115,116,104,95,49,52,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,157,225,3,108,4,0,32,0,115,116,104,95,48,54,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,120,84,79,216,4,0,32,0,115,116,104,95,50,53,46,55,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,106,80,30,146,4,0,32,0,115,116,104,95,49,56,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,86,137,49,91,4,0,32,0,115,116,104,95,51,57,46,57,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,170,214,33,147,4,0,32,0,115,116,104,95,51,51,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,199,223,125,180,4,0,32,0,115,116,104,95,49,49,46,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,65,242,132,36,4,0,32,0,115,116,104,95,48,51,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,69,114,160,170,4,0,32,0,115,116,104,95,49,53,46,49,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,67,217,21,228,4,0,32,0,115,116,104,95,48,55,46,49,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,210,114,208,151,4,0,32,0,115,116,104,95,50,54,46,56,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,2,203,191,14,4,0,32,0,115,116,104,95,49,57,46,56,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,131,230,124,37,4,0,32,0,115,116,104,95,50,56,46,49,48,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,209,140,172,152,4,0,32,0,115,116,104,95,50,49,46,49,48,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,35,148,141,83,4,0,32,0,115,116,104,95,49,50,46,56,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,119,164,112,246,4,0,32,0,115,116,104,95,48,52,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,1,62,61,133,4,0,32,0,115,116,104,95,49,54,46,49,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,159,1,146,64,4,0,32,0,115,116,104,95,48,56,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,199,180,233,44,4,0,32,0,115,116,104,95,50,55,46,57,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,217,136,44,248,4,0,32,0,115,116,104,95,50,48,46,57,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,212,77,88,235,4,0,32,0,115,116,104,95,50,57,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,151,41,174,52,4,0,32,0,115,116,104,95,50,50,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,72,156,221,120,4,0,32,0,115,116,104,95,50,51,46,49,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,188,3,212,46,3,0,16,0,115,116,104,95,51,48,46,49,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,128,188,134,67,5,0,64,0,115,116,104,95,51,49,46,49,51,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,215,54,69,68,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,115,116,50,50,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,85,204,254,104,0,0,0,8,108,119,105,111,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,12,185,82,173,0,0,0,8,49,46,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,160,170,2,177,1,0,16,1,50,46,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,3,87,21,212,1,0,16,1,51,46,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,137,140,86,169,1,0,16,1,52,46,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,53,108,59,102,1,0,16,1,53,46,50,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,28,169,25,73,1,0,16,1,54,46,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,227,106,198,78,1,0,16,1,55,46,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,146,1,235,15,1,0,16,1,56,46,50,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,66,97,10,40,1,0,16,1,111,116,49,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,240,151,210,188,2,0,16,1,111,116,50,46,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,218,18,121,222,2,0,16,1,111,116,51,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,51,169,47,186,2,0,16,1,57,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,37,255,190,58,4,0,32,0,49,48,46,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,190,172,236,121,4,0,32,0,99,48,49,115,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,171,174,60,78,7,0,32,0,18,0,0,0,255,255,0,0,0,0,0,0,19,0,0,0,255,255,3,0,0,0,0,0,20,0,0,0,255,255,14,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,19,0,0,0,1,3,3,0,8,49,4,0,19,0,0,0,1,3,2,0,152,21,4,0,19,0,0,0,1,3,1,0,72,246,3,0,19,0,0,0,1,3,0,0,200,28,2,0,0,0,0,0,254,0,4,0,32,4,2,0,20,0,0,0,1,6,6,0,64,181,1,0,20,0,0,0,1,6,4,0,152,180,1,0,20,0,0,0,1,6,2,0,56,180,1,0,20,0,0,0,1,6,0,0,136,179,1,0,0,0,0,0,254,0,2,0,200,30,2,0,20,0,0,0,1,8,8,0,120,97,1,0,20,0,0,0,1,8,0,0,96,19,1,0,20,0,0,0,255,255,0,0,0,0,0,0,21,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,3,2,0,192,255,2,0,20,0,0,0,1,3,0,0,208,75,4,0,20,0,0,0,1,3,1,0,8,49,4,0,20,0,0,0,1,3,3,0,152,21,4,0,0,0,0,0,254,0,4,0,112,171,4,0,20,0,0,0,1,12,8,0,104,236,7,0,20,0,0,0,1,12,0,0,128,230,7,0,20,0,0,0,1,12,4,0,184,164,6,0,20,0,0,0,1,12,12,0,16,227,4,0,0,0,0,0,254,0,2,0,112,31,4,0,20,0,0,0,1,20,0,0,232,2,4,0,20,0,0,0,1,20,20,0,136,225,3,0,0,0,0,0,254,0,2,0,144,212,8,0,20,0,0,0,1,128,0,0,96,135,7,0,20,0,0,0,1,128,128,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,21,0,0,0,1,1,0,0,96,135,7,0,21,0,0,0,1,1,1,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,21,0,0,0,1,2,2,0,56,111,3,0,21,0,0,0,1,2,0,0,104,134,3,0,0,0,0,0,254,0,4,0,64,37,5,0,21,0,0,0,1,12,0,0,136,6,2,0,21,0,0,0,1,12,8,0,240,251,1,0,21,0,0,0,1,12,4,0,24,241,1,0,21,0,0,0,1,12,12,0,120,7,5,0,0,0,0,0,254,0,4,0,168,79,2,0,21,0,0,0,1,48,20,0,8,167,2,0,21,0,0,0,1,48,0,0,208,152,2,0,21,0,0,0,1,48,48,0,72,4,1,0,21,0,0,0,1,48,16,0,224,195,4,0,0,0,0,0,254,0,4,0,72,202,5,0,21,0,0,0,1,192,128,0,80,246,3,0,21,0,0,0,1,192,0,0,248,38,7,0,21,0,0,0,1,192,64,0,112,212,3,0,21,0,0,0,1,192,192,0,248,160,5,0,0,0,0,0,20,0,0,0,255,255,0,0,0,0,0,0,21,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,3,2,0,192,255,2,0,20,0,0,0,1,3,0,0,208,75,4,0,20,0,0,0,1,3,1,0,8,49,4,0,20,0,0,0,1,3,3,0,152,21,4,0,0,0,0,0,254,0,4,0,112,171,4,0,20,0,0,0,1,12,12,0,64,34,2,0,20,0,0,0,1,12,4,0,32,24,2,0,20,0,0,0,1,12,8,0,184,14,2,0,20,0,0,0,1,12,0,0,80,245,6,0,0,0,0,0,254,0,2,0,112,31,4,0,20,0,0,0,1,20,0,0,232,2,4,0,20,0,0,0,1,20,20,0,136,225,3,0,0,0,0,0,254,0,2,0,144,212,8,0,20,0,0,0,1,128,0,0,96,135,7,0,20,0,0,0,1,128,128,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,21,0,0,0,1,1,0,0,96,135,7,0,21,0,0,0,1,1,1,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,21,0,0,0,1,2,2,0,56,111,3,0,21,0,0,0,1,2,0,0,104,134,3,0,0,0,0,0,254,0,4,0,64,37,5,0,21,0,0,0,1,12,0,0,136,6,2,0,21,0,0,0,1,12,8,0,240,251,1,0,21,0,0,0])
.concat([1,12,4,0,24,241,1,0,21,0,0,0,1,12,12,0,120,7,5,0,0,0,0,0,254,0,4,0,168,79,2,0,21,0,0,0,1,48,20,0,8,167,2,0,21,0,0,0,1,48,0,0,208,152,2,0,21,0,0,0,1,48,48,0,72,4,1,0,21,0,0,0,1,48,16,0,224,195,4,0,0,0,0,0,254,0,4,0,72,202,5,0,21,0,0,0,1,192,128,0,80,246,3,0,21,0,0,0,1,192,0,0,248,38,7,0,21,0,0,0,1,192,64,0,112,212,3,0,21,0,0,0,1,192,192,0,248,160,5,0,0,0,0,0,115,107,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,203,108,134,200,1,0,16,1,115,107,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,155,162,174,124,1,0,16,1,115,107,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,118,250,75,123,1,0,16,1,115,107,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,33,201,111,5,1,0,16,1,115,107,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,12,30,127,210,5,0,32,0,115,107,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,136,149,8,167,6,0,32,0,115,107,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,7,150,231,188,7,0,32,0,12,0,0,0,255,255,0,0,0,0,0,0,13,0,0,0,255,255,64,0,0,0,0,0,14,0,0,0,255,255,6,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,12,0,0,0,1,32,0,0,120,97,1,0,12,0,0,0,1,32,32,0,96,19,1,0,0,0,0,0,254,0,4,0,64,37,5,0,13,0,0,0,1,192,64,0,176,116,6,0,13,0,0,0,1,192,129,0,80,113,6,0,13,0,0,0,1,192,192,0,80,110,6,0,13,0,0,0,1,192,0,0,120,7,5,0,0,0,0,0,254,0,4,0,32,4,2,0,14,0,0,0,1,3,0,0,224,127,8,0,14,0,0,0,1,3,2,0,32,123,8,0,14,0,0,0,1,3,1,0,192,110,8,0,14,0,0,0,1,3,3,0,104,151,6,0,0,0,0,0,254,0,4,0,128,129,4,0,14,0,0,0,1,12,12,0,192,255,2,0,14,0,0,0,1,12,8,0,208,75,4,0,14,0,0,0,1,12,4,0,8,49,4,0,14,0,0,0,1,12,0,0,72,246,3,0,0,0,0,0,50,99,95,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,55,18,192,238,1,0,16,1,50,101,95,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,213,178,108,146,1,0,16,1,50,102,95,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,4,37,158,132,1,0,16,1,50,104,95,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,155,6,100,138,1,0,16,1,50,106,95,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,152,184,185,120,1,0,16,1,50,108,95,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,20,228,186,32,1,0,16,1,115,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,184,93,58,113,2,0,16,1,115,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,17,148,7,70,2,0,16,1,53,102,95,99,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,121,182,33,113,4,0,32,0,53,104,95,99,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,145,173,5,209,4,0,32,0,115,116,114,97,116,101,103,121,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,225,41,166,81,7,0,32,0,115,116,114,97,116,101,103,121,46,49,48,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,24,3,92,217,7,0,32,0,18,0,0,0,255,255,0,0,0,0,0,0,19,0,0,0,255,255,3,0,0,0,0,0,20,0,0,0,255,255,8,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,19,0,0,0,1,3,3,0,8,49,4,0,19,0,0,0,1,3,2,0,152,21,4,0,19,0,0,0,1,3,1,0,72,246,3,0,19,0,0,0,1,3,0,0,200,28,2,0,0,0,0,0,254,0,2,0,200,30,2,0,20,0,0,0,1,8,8,0,120,97,1,0,20,0,0,0,1,8,0,0,96,19,1,0,0,0,0,0,50,99,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,43,175,170,242,1,0,16,1,50,101,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,200,253,115,88,1,0,16,1,50,102,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,79,96,45,83,1,0,16,1,50,104,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,94,217,177,130,1,0,16,1,50,106,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,222,76,232,102,1,0,16,1,50,108,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,208,50,176,98,1,0,16,1,115,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,184,93,58,113,2,0,16,1,115,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,17,148,7,70,2,0,16,1,53,102,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,221,93,170,244,4,0,32,0,53,104,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,53,70,142,84,4,0,32,0,115,116,114,97,116,101,103,121,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,225,41,166,81,7,0,32,0,115,116,114,97,116,101,103,121,46,49,48,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,24,3,92,217,7,0,32,0,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,254,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,19,0,0,0,1,15,7,0,80,252,6,0,19,0,0,0,1,15,8,0,16,242,7,0,19,0,0,0,1,15,9,0,104,236,7,0,19,0,0,0,1,15,5,0,192,54,8,0,19,0,0,0,1,15,4,0,56,24,4,0,19,0,0,0,1,15,15,0,128,230,7,0,19,0,0,0,1,15,0,0,128,230,7,0,19,0,0,0,1,15,3,0,176,162,3,0,19,0,0,0,1,15,2,0,24,188,3,0,19,0,0,0,1,15,1,0,72,216,3,0,19,0,0,0,1,15,6,0,120,211,6,0,19,0,0,0,1,15,14,0,184,164,6,0,19,0,0,0,1,15,13,0,80,74,6,0,19,0,0,0,1,15,12,0,192,32,6,0,19,0,0,0,1,15,11,0,192,234,2,0,19,0,0,0,1,15,10,0,32,242,5,0,0,0,0,0,254,0,16,0,160,123,6,0,19,0,0,0,1,240,112,0,80,252,6,0,19,0,0,0,1,240,128,0,16,242,7,0,19,0,0,0,1,240,144,0,104,236,7,0,19,0,0,0,1,240,80,0,192,54,8,0,19,0,0,0,1,240,64,0,56,24,4,0,19,0,0,0,1,240,240,0,128,230,7,0,19,0,0,0,1,240,0,0,128,230,7,0,19,0,0,0,1,240,48,0,176,162,3,0,19,0,0,0,1,240,32,0,24,188,3,0,19,0,0,0,1,240,16,0,72,216,3,0,19,0,0,0,1,240,96,0,120,211,6,0,19,0,0,0,1,240,224,0,184,164,6,0,19,0,0,0,1,240,208,0,80,74,6,0,19,0,0,0,1,240,192,0,192,32,6,0,19,0,0,0,1,240,176,0,192,234,2,0,19,0,0,0,1,240,160,0,32,242,5,0,0,0,0,0,254,0,2,0,200,30,2,0,20,0,0,0,1,1,0,0,120,97,1,0,20,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,6,6,0,8,49,4,0,20,0,0,0,1,6,4,0,152,21,4,0,20,0,0,0,1,6,2,0,72,246,3,0,20,0,0,0,1,6,0,0,112,49,6,0,0,0,0,0,254,0,2,0,80,207,5,0,20,0,0,0,1,8,8,0,8,208,6,0,20,0,0,0,1,8,0,0,0,199,5,0,0,0,0,0,254,0,4,0,64,37,5,0,20,0,0,0,1,48,48,0,144,195,5,0,20,0,0,0,1,48,32,0,168,192,5,0,20,0,0,0,1,48,16,0,120,189,5,0,20,0,0,0,1,48,0,0,160,185,5,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,192,192,0,80,246,3,0,20,0,0,0,1,192,128,0,80,124,6,0,20,0,0,0,1,192,64,0,112,212,3,0,20,0,0,0,1,192,0,0,248,160,5,0,0,0,0,0,101,112,114,53,51,50,48,98,46,49,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,205,46,183,122,0,0,16,1,101,112,114,53,51,50,49,97,46,49,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,80,144,185,56,0,0,16,1,101,112,114,53,51,50,50,97,46,49,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,91,89,58,16,0,0,16,1,101,112,114,45,53,51,50,51,46,49,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,88,13,175,70,0,0,16,1,101,112,114,45,53,51,50,52,46,49,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,226,239,137,30,0,0,16,1,101,112,114,45,53,51,50,53,46,49,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,161,121,227,214,0,0,16,1,101,112,114,45,53,51,51,50,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,61,171,114,122,0,0,16,1,101,112,114,45,53,51,51,49,46,56,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,143,137,29,37,0,0,32,0,101,112,114,45,53,51,51,48,46,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,69,135,4,235,0,0,32,0,101,112,114,45,53,51,50,57,46,56,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,237,202,139,62,0,0,32,0,101,112,114,45,53,51,50,56,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,159,132,215,158,0,0,32,0,101,112,114,45,53,51,50,55,46,56,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,177,44,233,121,0,0,32,0,101,112,114,45,53,51,50,54,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,71,43,126,186,0,0,32,0,101,112,114,45,53,51,49,56,46,56,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,211,31,46,111,0,0,32,0,101,112,114,45,53,51,49,57,46,57,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,153,73,238,235,0,0,32,0,112,114,45,53,51,49,55,46,49,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,184,80,131,100,0,0,0,8,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,246,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,19,0,0,0,1,15,7,0,80,252,6,0,19,0,0,0,1,15,8,0,16,242,7,0,19,0,0,0,1,15,9,0,104,236,7,0,19,0,0,0,1,15,5,0,192,54,8,0,19,0,0,0,1,15,4,0,56,24,4,0,19,0,0,0,1,15,15,0,128,230,7,0,19,0,0,0,1,15,0,0,128,230,7,0,19,0,0,0,1,15,3,0,176,162,3,0,19,0,0,0,1,15,2,0,24,188,3,0,19,0,0,0,1,15,1,0,72,216,3,0,19,0,0,0,1,15,6,0,120,211,6,0,19,0,0,0,1,15,14,0,184,164,6,0,19,0,0,0,1,15,13,0,80,74,6,0,19,0,0,0,1,15,12,0,192,32,6,0,19,0,0,0,1,15,11,0,192,234,2,0,19,0,0,0,1,15,10,0,32,242,5,0,0,0,0,0,254,0,16,0,160,123,6,0,19,0,0,0,1,240,112,0,80,252,6,0,19,0,0,0,1,240,128,0,16,242,7,0,19,0,0,0,1,240,144,0,104,236,7,0,19,0,0,0,1,240,80,0,192,54,8,0,19,0,0,0,1,240,64,0,56,24,4,0,19,0,0,0,1,240,240,0,128,230,7,0,19,0,0,0,1,240,0,0,128,230,7,0,19,0,0,0,1,240,48,0,176,162,3,0,19,0,0,0,1,240,32,0,24,188,3,0,19,0,0,0,1,240,16,0,72,216,3,0,19,0,0,0,1,240,96,0,120,211,6,0,19,0,0,0,1,240,224,0,184,164,6,0,19,0,0,0,1,240,208,0,80,74,6,0,19,0,0,0,1,240,192,0,192,32,6,0,19,0,0,0,1,240,176,0,192,234,2,0,19,0,0,0,1,240,160,0,32,242,5,0,0,0,0,0,254,0,2,0,200,30,2,0,20,0,0,0,1,1,0,0,120,97,1,0,20,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,6,6,0,8,49,4,0,20,0,0,0,1,6,4,0,152,21,4,0,20,0,0,0,1,6,2,0,72,246,3,0,20,0,0,0,1,6,0,0,112,49,6,0,0,0,0,0,254,0,8,0,64,37,5,0,20,0,0,0,1,56,56,0,192,182,5,0,20,0,0,0,1,56,40,0,16,179,5,0,20,0,0,0,1,56,24,0,112,172,5,0,20,0,0,0,1,56,8,0,216,167,5,0,20,0,0,0,1,56,48,0,24,162,5,0,20,0,0,0,1,56,32,0,144,195,5,0,20,0,0,0,1,56,16,0,168,192,5,0,20,0,0,0,1,56,0,0,120,189,5,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,192,192,0,80,246,3,0,20,0,0,0,1,192,128,0,80,124,6,0,20,0,0,0,1,192,64,0,112,212,3,0,20,0,0,0,1,192,0,0,248,160,5,0,115,101,105,45,115,102,45,97,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,230,89,40,50,1,0,16,1,115,101,105,45,115,102,45,97,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,84,6,237,127,1,0,16,1,115,101,105,45,115,102,45,98,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,53,116,95,147,1,0,16,1,115,101,105,45,115,102,45,99,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,105,72,213,41,1,0,16,1,115,101,105,45,115,102,45,100,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,166,204,38,145,1,0,16,1,115,101,105,45,115,102,45,101,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,97,66,57,157,1,0,16,1,115,101,105,45,115,102,45,102,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,221,97,241,148,1,0,16,1,115,101,105,45,115,102,45,102,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,128,127,237,108,1,0,16,1,115,101,105,45,115,102,45,106,104,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,205,163,219,142,4,0,32,0,115,101,105,45,115,102,45,106,104,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,169,113,168,245,4,0,32,0,115,101,105,45,115,102,45,108,107,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,106,240,176,68,4,0,32,0,115,101,105,45,115,102,45,108,107,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,230,30,59,119,4,0,32,0,112,114,111,109,45,115,110,55,52,115,50,56,56,110,45,55,49,46,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,135,125,12,106,7,0,32,0,106,97,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,139,85,171,198,1,0,16,1,106,98,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,237,159,185,52,1,0,16,1,106,99,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,22,128,226,48,1,0,16,1,106,100,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,112,119,126,222,1,0,16,1,106,101,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,25,201,22,169,1,0,16,1,106,102,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,43,136,117,145,1,0,16,1,106,103,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,2,15,124,112,1,0,16,1,106,104,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,97,100,210,93,1,0,16,1,106,105,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,147,254,81,102,1,0,16,1,106,106,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,185,33,199,18,1,0,16,1,107,49,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,207,55,126,151,4,0,32,0,107,50,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,206,135,227,21,4,0,32,0,109,109,105,54,51,51,49,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,196,43,101,36,7,0,32,0,18,0,0,0,255,255,255,0,0,0,0,0,19,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,232,75,4,0,18,0,0,0,1,1,1,0,96,135,7,0,18,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,18,0,0,0,1,2,0,0,96,135,7,0,18,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,18,0,0,0,1,192,0,0,192,255,2,0,18,0,0,0,1,192,128,0,208,75,4,0,18,0,0,0,1,192,192,0,8,49,4,0])
.concat([18,0,0,0,1,192,64,0,72,246,3,0,0,0,0,0,254,0,4,0,72,202,5,0,19,0,0,0,1,24,8,0,80,246,3,0,19,0,0,0,1,24,24,0,248,38,7,0,19,0,0,0,1,24,16,0,112,212,3,0,19,0,0,0,1,24,0,0,248,160,5,0,0,0,0,0,254,0,8,0,32,4,2,0,19,0,0,0,1,224,0,0,32,136,7,0,19,0,0,0,1,224,128,0,40,88,7,0,19,0,0,0,1,224,64,0,96,39,7,0,19,0,0,0,1,224,192,0,120,113,6,0,19,0,0,0,1,224,224,0,144,251,6,0,19,0,0,0,1,224,32,0,120,211,6,0,19,0,0,0,1,224,96,0,184,164,6,0,19,0,0,0,1,224,160,0,80,74,6,0,0,0,0,0,115,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,151,40,247,47,1,0,16,1,115,115,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,128,120,94,86,1,0,16,1,115,115,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,239,157,147,161,1,0,16,1,115,115,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,18,224,50,163,1,0,16,1,115,115,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,83,132,229,185,1,0,16,1,115,115,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,200,91,187,124,1,0,16,1,115,115,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,145,59,113,87,1,0,16,1,115,115,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,152,232,87,200,1,0,16,1,115,115,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,234,184,149,42,4,0,32,0,115,115,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,48,76,44,185,4,0,32,0,115,115,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,132,224,97,54,4,0,32,0,115,115,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,72,48,97,149,4,0,32,0,109,109,105,54,51,51,49,46,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,135,125,12,106,7,0,32,0,48,54,52,101,97,99,48,50,46,56,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,244,37,84,90,0,0,16,1,48,54,52,101,97,99,48,51,46,56,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,251,0,60,9,0,0,16,1,48,54,52,101,97,98,48,52,46,49,48,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,189,21,35,239,0,0,16,1,48,54,52,101,97,98,48,53,46,49,48,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,196,251,214,81,0,0,16,1,48,54,52,101,48,49,46,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,82,188,185,68,0,0,16,1,48,54,52,101,49,50,46,49,54,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,25,198,189,226,0,0,32,0,48,54,52,101,49,49,46,49,50,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,176,168,140,45,0,0,32,0,48,54,52,101,48,57,46,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,114,195,96,65,0,0,32,0,48,54,52,101,48,55,46,51,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,60,103,221,100,0,0,32,0,48,54,52,101,48,54,46,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,249,13,129,89,0,0,64,0,115,115,114,105,100,101,114,115,95,101,97,99,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,167,65,214,246,0,0,0,8,17,0,0,0,255,255,255,0,0,0,0,0,18,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,72,202,5,0,17,0,0,0,1,12,4,0,80,246,3,0,17,0,0,0,1,12,12,0,248,38,7,0,17,0,0,0,1,12,8,0,112,212,3,0,17,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,4,0,128,129,4,0,17,0,0,0,1,192,0,0,192,255,2,0,17,0,0,0,1,192,64,0,208,75,4,0,17,0,0,0,1,192,192,0,8,49,4,0,17,0,0,0,1,192,128,0,152,21,4,0,0,0,0,0,254,0,2,0,168,234,7,0,18,0,0,0,1,2,0,0,96,135,7,0,18,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,8,0,32,4,2,0,18,0,0,0,1,224,32,0,32,136,7,0,18,0,0,0,1,224,160,0,40,88,7,0,18,0,0,0,1,224,96,0,96,39,7,0,18,0,0,0,1,224,224,0,144,251,6,0,18,0,0,0,1,224,192,0,184,164,6,0,18,0,0,0,1,224,64,0,80,74,6,0,18,0,0,0,1,224,128,0,192,32,6,0,18,0,0,0,1,224,0,0,16,227,4,0,115,102,120,117,46,48,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,53,163,228,134,1,0,16,1,115,102,120,117,46,48,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,253,95,43,83,1,0,16,1,115,102,120,117,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,222,198,163,255,1,0,16,1,115,102,120,117,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,153,76,192,228,1,0,16,1,115,102,120,117,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,65,158,25,216,1,0,16,1,115,102,120,117,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,16,24,199,179,1,0,16,1,115,102,120,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,63,174,47,100,1,0,16,1,115,102,120,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,117,210,148,207,5,0,32,0,115,102,120,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,175,3,183,94,5,0,32,0,115,102,120,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,15,14,166,255,5,0,32,0,115,102,120,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,197,37,232,52,5,0,32,0,115,102,120,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,231,50,204,183,5,0,32,0,115,102,120,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,24,173,118,131,5,0,32,0,115,102,120,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,54,179,177,245,5,0,32,0,115,102,120,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,107,92,157,69,5,0,32,0,115,102,120,46,50,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,175,84,40,227,5,0,32,0,115,102,120,46,50,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,39,41,15,118,5,0,32,0,115,102,120,46,50,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,8,2,233,30,5,0,32,0,115,102,120,46,50,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,15,64,20,248,5,0,32,0,115,102,120,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,53,136,123,180,10,0,16,1,115,102,120,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,99,34,0,10,0,16,1,115,102,120,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,118,212,219,155,12,0,64,0,115,102,120,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,171,58,94,160,12,0,64,0,115,115,102,101,46,48,51,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,52,142,1,30,1,0,16,1,115,115,102,101,46,48,52,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,175,239,146,172,1,0,16,1,115,115,102,101,46,48,53,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,68,100,156,106,1,0,16,1,115,115,102,101,46,48,54,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,43,86,66,244,1,0,16,1,115,115,102,101,46,48,55,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,130,71,159,44,1,0,16,1,115,115,102,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,117,210,148,207,5,0,32,0,115,115,102,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,175,3,183,94,5,0,32,0,115,115,102,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,15,14,166,255,5,0,32,0,115,115,102,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,197,37,232,52,5,0,32,0,115,115,102,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,231,50,204,183,5,0,32,0,115,115,102,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,24,173,118,131,5,0,32,0,115,115,102,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,54,179,177,245,5,0,32,0,115,115,102,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,107,92,157,69,5,0,32,0,115,115,102,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,140,126,36,235,10,0,16,1,115,115,102,46,113,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,92,218,249,166,12,0,64,0,115,115,102,46,113,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,38,174,102,140,12,0,64,0,115,115,102,46,113,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,202,194,92,105,12,0,64,0,115,115,102,46,113,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,50,190,158,157,12,0,64,0,115,115,102,46,113,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,183,231,112,71,12,0,64,0,115,115,102,46,113,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,81,201,121,78,12,0,64,0,115,115,102,46,113,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,19,67,209,205,12,0,64,0,115,115,102,46,113,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,140,8,90,111,12,0,64,0,101,112,114,54,57,50,53,98,46,49,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,236,220,84,255,0,0,16,1,101,112,114,54,57,50,54,97,46,49,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,168,238,65,92,0,0,16,1,101,112,114,45,54,57,50,55,46,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,100,175,187,60,0,0,16,1,101,112,114,45,54,57,51,52,46,49,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,35,114,70,175,0,0,16,1,101,112,114,45,54,57,51,51,46,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,54,64,48,231,0,0,32,0,101,112,114,45,54,57,51,50,46,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,218,191,207,245,0,0,32,0,101,112,114,45,54,57,51,49,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,135,127,157,89,0,0,32,0,101,112,114,45,54,57,51,48,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,194,22,102,203,0,0,32,0,101,112,114,45,54,57,50,57,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,86,104,161,39,0,0,32,0,101,112,114,45,54,57,50,56,46,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,164,207,201,192,0,0,32,0,101,112,114,45,54,57,50,49,46,49,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,161,5,158,241,0,0,32,0,101,112,114,45,54,57,50,51,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,195,173,136,121,0,0,32,0,101,112,114,45,54,57,50,50,46,49,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,120,122,247,55,0,0,32,0,101,112,114,45,54,57,50,52,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,246,200,189,66,0,0,32,0,112,114,45,53,51,49,55,46,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,184,80,131,100,0,0,0,8,101,112,114,45,54,51,49,48,46,49,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,1,55,180,38,0,0,16,1,101,112,114,45,54,51,49,49,46,49,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,32,198,43,203,0,0,16,1,101,112,114,45,54,51,49,50,46,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,71,91,177,113,0,0,16,1,101,112,114,45,54,51,49,54,46,49,50,48,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,17,85,249,29,0,0,16,1,101,112,114,45,54,51,50,56,46,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,50,40,191,162,0,0,32,0,101,112,114,45,54,51,50,55,46,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,9,129,41,83,0,0,32,0,101,112,114,45,54,51,50,54,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,76,187,159,38,0,0,32,0,101,112,114,45,54,51,50,53,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,69,135,3,191,0,0,32,0,101,112,114,45,54,51,50,52,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,99,181,179,138,0,0,32,0,101,112,114,45,54,51,50,51,46,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,60,103,148,3,0,0,32,0,101,112,114,45,54,51,48,54,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,50,225,113,232,0,0,32,0,101,112,114,45,54,51,48,56,46,49,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,14,217,194,153,0,0,32,0,101,112,114,45,54,51,48,55,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,67,213,90,10,0,0,32,0,101,112,114,45,54,51,48,57,46,49,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,152,173,35,116,0,0,32,0,112,114,45,53,51,49,55,46,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,184,80,131,100,0,0,0,8,17,0,0,0,255,255,255,0,0,0,0,0,18,0,0,0,255,255,115,0,0,0,0,0,0,0,0,0,254,0,8,0,160,123,6,0,17,0,0,0,1,7,0,0,32,136,7,0,17,0,0,0,1,7,1,0,40,88,7,0,17,0,0,0,1,7,2,0,96,39,7,0,17,0,0,0,1,7,7,0,144,251,6,0,17,0,0,0,1,7,6,0,184,164,6,0,17,0,0,0,1,7,5,0,80,74,6,0,17,0,0,0,1,7,4,0,192,32,6,0,17,0,0,0,1,7,3,0,32,242,5,0,0,0,0,0,254,0,8,0,200,87,7,0,17,0,0,0,1,56,0,0,32,136,7,0,17,0,0,0,1,56,8,0,40,88,7,0,17,0,0,0,1,56,16,0,96,39,7,0,17,0,0,0,1,56,56,0,144,251,6,0,17,0,0,0,1,56,48,0,184,164,6,0,17,0,0,0,1,56,40,0,80,74,6,0,17,0,0,0,1,56,32,0,192,32,6,0,17,0,0,0,1,56,24,0,32,242,5,0,0,0,0,0,254,0,2,0,232,75,4,0,17,0,0,0,1,64,64,0,96,135,7,0,17,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,17,0,0,0,1,128,128,0,96,135,7,0,17,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,18,0,0,0,1,3,3,0,8,49,4,0,18,0,0,0,1,3,2,0,152,21,4,0,18,0,0,0,1,3,1,0,72,246,3,0,18,0,0,0,1,3,0,0,64,47,7,0,0,0,0,0,254,0,2,0,200,30,2,0,18,0,0,0,1,4,0,0,120,97,1,0,18,0,0,0,1,4,4,0,96,19,1,0,0,0,0,0,254,0,4,0,64,37,5,0,18,0,0,0,1,24,24,0,240,140,4,0,18,0,0,0,1,24,16,0,120,112,4,0,18,0,0,0,1,24,8,0,232,140,2,0,18,0,0,0,1,24,0,0,208,129,2,0,0,0,0,0,254,0,4,0,72,202,5,0,18,0,0,0,1,96,64,0,80,246,3,0,18,0,0,0,1,96,96,0,248,38,7,0,18,0,0,0,1,96,32,0,48,123,8,0,18,0,0,0,1,96,0,0,8,117,8,0,0,0,0,0,254,0,2,0,104,159,3,0,18,0,0,0,1,128,0,0,56,111,3,0,18,0,0,0,1,128,128,0,104,134,3,0,0,0,0,0,53,46,116,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,140,180,130,166,0,0,16,1,55,46,116,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,140,197,25,23,0,0,16,1,49,46,116,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,94,89,72,220,0,0,16,1,51,46,116,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,232,225,107,33,0,0,16,1,49,53,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,253,247,97,73,0,0,32,0,49,55,46,57,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,88,20,33,65,0,0,32,0,49,56,46,49,48,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,212,204,14,116,0,0,32,0,49,54,46,49,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,219,165,244,193,0,0,32,0,49,52,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,71,4,76,61,0,0,32,0,49,51,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,103,74,65,34,0,0,32,0,49,50,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,131,66,227,97,0,0,32,0,49,49,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,239,255,186,187,0,0,32,0,49,48,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,151,79,86,222,0,0,32,0,57,46,49,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,21,200,13,137,0,0,32,0,109,114,46,49,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,110,67,10,17,0,0,32,0,109,103,46,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,240,217,191,15,0,0,32,0,109,98,46,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,12,137,66,163,0,0,32,0,109,50,46,53,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,173,85,10,25,0,0,32,0,109,49,46,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,1,146,163,131,0,0,32,0,18,0,0,0,255,255,191,0,0,0,0,0,19,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,18,0,0,0,1,3,3,0,8,49,4,0,18,0,0,0,1,3,2,0,152,21,4,0,18,0,0,0,1,3,1,0,72,246,3,0,18,0,0,0,1,3,0,0,72,0,3,0,0,0,0,0,254,0,2,0,24,167,2,0,18,0,0,0,1,4,4,0,8,153,2,0,18,0,0,0,1,4,0,0,248,140,2,0,0,0,0,0,254,0,2,0,232,129,2,0,18,0,0,0,1,8,8,0,96,135,7,0,18,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,246,3,0,18,0,0,0,1,16,16,0,96,135,7,0,18,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,2,0,112,104,5,0,18,0,0,0,1,32,32,0,96,135,7,0,18,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,200,30,2,0,18,0,0,0,1,64,0,0,120,97,1,0,18,0,0,0,1,64,64,0,96,19,1,0,0,0,0,0,254,0,2,0,72,4,1,0,18,0,0,0,1,128,128,0,96,135,7,0,18,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,8,0,200,87,7,0,19,0,0,0,1,7,2,0,224,127,8,0,19,0,0,0,1,7,1,0,136,252,1,0,19,0,0,0,1,7,7,0,32,123,8,0,19,0,0,0,1,7,6,0,192,110,8,0,19,0,0,0,1,7,5,0,96,102,7,0,19,0,0,0,1,7,4,0,184,105,6,0,19,0,0,0,1,7,3,0,192,100,6,0,19,0,0,0,1,7,0,0,104,151,6,0,0,0,0,0,254,0,8,0,160,123,6,0,19,0,0,0,1,56,0,0,96,164,8,0,19,0,0,0,1,56,8,0,144,102,8,0,19,0,0,0,1,56,16,0,176,45,8,0,19,0,0,0,1,56,24,0,224,127,8,0,19,0,0,0,1,56,56,0,32,123,8,0,19,0,0,0,1,56,32,0,232,143,1,0,19,0,0,0,1,56,48,0,192,110,8,0,19,0,0,0,1,56,40,0,96,102,7,0,0,0,0,0,16,0,0,0,255,255,127,0,0,0,0,0,17,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,200,87,7,0,16,0,0,0,1,3,0,0,88,154,8,0,16,0,0,0,1,3,1,0,200,92,8,0,16,0,0,0,1,3,3,0,56,37,8,0,16,0,0,0,1,3,2,0,96,240,7,0,0,0,0,0,254,0,4,0,160,123,6,0,16,0,0,0,1,12,0,0,88,154,8,0,16,0,0,0,1,12,4,0,200,92,8,0,16,0,0,0,1,12,12,0,56,37,8,0,16,0,0,0,1,12,8,0,96,240,7,0,0,0,0,0,254,0,2,0,168,234,7,0,16,0,0,0,1,32,0,0,96,135,7,0,16,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,16,0,0,0,1,64,64,0,96,135,7,0,16,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,200,30,2,0,16,0,0,0,1,128,0,0,120,97,1,0,16,0,0,0,1,128,128,0,96,19,1,0,0,0,0,0,254,0,4,0,128,129,4,0,17,0,0,0,1,3,1,0,192,255,2,0,17,0,0,0,1,3,3,0,8,49,4,0,17,0,0,0,1,3,2,0,72,246,3,0,17,0,0,0,1,3,0,0,56,79,7,0,0,0,0,0,254,0,4,0,72,202,5,0,17,0,0,0,1,12,4,0,80,246,3,0,17,0,0,0,1,12,12,0,248,38,7,0,17,0,0,0,1,12,8,0,112,212,3,0,17,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,2,0,224,117,5,0,17,0,0,0,1,128,0,0,96,135,7,0,17,0,0,0,1,128,128,0,152,182,7,0,115,112,114,105,110,103,101,114,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,58,16,148,7,0,0,16,1,115,112,114,105,110,103,101,114,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,154,205,174,244,0,0,16,1,115,112,114,105,110,103,101,114,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,113,35,69,47,0,0,16,1,115,112,114,105,110,103,101,114,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,245,27,157,133,0,0,16,1,115,112,114,105,110,103,101,114,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,227,187,173,114,0,0,16,1,115,112,114,105,110,103,101,114,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,51,24,150,106,0,0,32,0,115,112,114,105,110,103,101,114,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,192,143,171,149,0,0,32,0,115,112,114,105,110,103,101,114,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,220,175,75,165,0,0,32,0,115,112,114,105,110,103,101,114,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,117,39,48,250,0,0,32,0,49,98,46,118,105,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,170,53,249,162,0,0,32,0,49,99,46,118,105,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,244,33,84,185,0,0,32,0,115,112,114,97,46,52,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,1,18,129,207,0,0,16,1,115,112,114,97,46,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,79,170,79,187,0,0,16,1,115,112,114,109,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,226,151,97,251,0,0,16,1,115,112,114,109,46,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,164,37,187,38,0,0,16,1,115,112,114,97,46,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,60,54,16,65,0,0,16,1,115,112,114,97,46,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,230,210,169,103,0,0,16,1,115,112,114,109,46,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,137,174,247,78,0,0,32,0,115,112,114,109,46,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,128,81,117,163,0,0,32,0,115,112,114,109,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,106,142,0,180,0,0,32,0,115,112,114,109,46,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,18,240,28,246,0,0,32,0,115,112,114,109,46,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,118,28,178,88,0,0,32,0,115,112,114,109,46,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,229,179,92,169,0,0,32,0,115,112,114,98,46,52,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,97,232,240,231,0,0,32,0,115,112,114,98,46,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,151,48,102,50,0,0,32,0,115,112,114,98,46,51,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,115,243,186,143,0,0,32,0,115,112,114,98,46,52,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,118,155,6,55,0,0,32,0,115,112,114,98,46,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,136,106,228,207,0,0,32,0,115,112,114,98,46,52,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,121,137,196,17,0,0,32,0,115,112,114,109,46,52,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,99,46,254,77,0,0,32,0,115,112,114,109,46,52,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,212,44,159,35,0,0,32,0,115,112,114,109,46,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,112,125,208,214,0,0,32,0,115,112,114,109,46,50,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,145,169,143,253,0,0,32,0,115,112,114,98,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,173,204,140,141,0,0,32,0,115,112,114,109,46,50,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,180,144,56,14,0,0,32,0,115,112,114,98,46,49,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,178,28,14,196,0,0,32,0,115,112,114,109,46,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,43,8,120,4,0,0,32,0,115,112,114,98,46,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,72,98,196,62,0,0,32,0,115,112,114,98,46,53,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,56,98,108,116,0,0,32,0,115,112,114,98,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,60,141,216,52,0,0,32,0,115,112,114,109,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,66,196,92,135,0,0,0,8,18,0,0,0,255,255,255,0,0,0,0,0,19,0,0,0,255,255,245,0,0,0,0,0,0,0,0,0,254,0,4,0,136,219,8,0,18,0,0,0,1,3,3,0,248,81,6,0,18,0,0,0,1,3,2,0,80,124,6,0,18,0,0,0,1,3,1,0,176,64,8,0,18,0,0,0,1,3,0,0,128,65,6,0,0,0,0,0,254,0,4,0,128,129,4,0,18,0,0,0,1,12,8,0,208,75,4,0,18,0,0,0,1,12,12,0,8,49,4,0,18,0,0,0,1,12,4,0,152,21,4,0,18,0,0,0,1,12,0,0,72,246,3,0,0,0,0,0,254,0,16,0,32,4,2,0,18,0,0,0,2,240,160,0,8,32,4,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,176,0,96,164,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,192,0,144,102,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,208,0,176,45,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,16,0,112,169,3,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,224,0,224,127,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,32,0,192,119,3,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,48,0,136,252,1,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,240,0,32,123,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,64,0,248,116,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,144,0,192,110,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,128,0,96,102,7,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,112,0,184,105,6,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,96,0,152,96,3,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,80,0,192,100,6,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,0,0,104,151,6,0,19,0,0,0,0,4,4,0,0,0,0,0,0,0,0,0,254,0,4,0,200,87,7,0,18,0,0,0,130,48,0,0,96,164,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,130,48,16,0,176,45,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,130,48,32,0,224,127,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,130,48,48,0,32,123,8,0,19,0,0,0,0,4,4,0,0,0,0,0,0,0,0,0,254,0,4,0,160,123,6,0,18,0,0,0,130,192,192,0,192,110,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,130,192,128,0,96,102,7,0,19,0,0,0,0,4,4,0])
.concat([0,0,0,0,18,0,0,0,130,192,64,0,152,96,3,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,130,192,0,0,192,100,6,0,19,0,0,0,0,4,4,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,1,1,0,96,135,7,0,19,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,200,30,2,0,19,0,0,0,1,2,0,0,120,97,1,0,19,0,0,0,1,2,2,0,96,19,1,0,0,0,0,0,254,0,2,0,96,46,8,0,19,0,0,0,1,4,4,0,208,233,4,0,19,0,0,0,1,4,0,0,72,197,4,0,0,0,0,0,254,0,2,0,104,159,3,0,19,0,0,0,1,8,8,0,96,135,7,0,19,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,2,0,176,186,8,0,19,0,0,0,1,16,16,0,96,135,7,0,19,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,2,0,72,4,1,0,19,0,0,0,1,32,32,0,96,135,7,0,19,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,246,3,0,19,0,0,0,1,64,64,0,96,135,7,0,19,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,128,128,0,96,135,7,0,19,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,115,112,50,45,97,46,52,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,187,75,192,150,0,0,16,1,115,112,50,45,97,46,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,255,194,56,203,0,0,16,1,115,112,50,45,114,46,55,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,234,55,136,85,0,0,16,1,115,112,50,45,114,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,98,1,56,75,0,0,16,1,115,112,50,45,114,46,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,254,161,9,119,0,0,16,1,115,112,50,45,97,46,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,226,199,158,131,0,0,16,1,115,112,50,45,97,46,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,152,232,60,173,0,0,16,1,115,112,50,45,114,46,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,201,164,159,193,0,0,32,0,115,112,50,45,114,46,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,175,4,102,54,0,0,32,0,115,112,50,45,114,46,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,71,77,12,58,0,0,32,0,115,112,50,45,98,46,52,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,23,122,182,108,0,0,32,0,115,112,50,45,98,46,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,111,22,161,228,0,0,32,0,115,112,50,45,98,46,51,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,118,139,158,245,0,0,32,0,115,112,50,45,98,46,52,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,201,186,101,250,0,0,32,0,115,112,50,45,98,46,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,19,112,175,28,0,0,32,0,115,112,50,45,98,46,52,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,59,70,10,120,0,0,32,0,115,112,50,45,114,46,52,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,139,45,75,106,0,0,32,0,115,112,50,45,114,46,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,97,139,54,225,0,0,32,0,115,112,50,45,114,46,52,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,19,142,19,252,0,0,32,0,115,112,50,45,114,46,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,220,188,193,49,0,0,32,0,115,112,50,45,114,46,50,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,126,152,245,28,0,0,32,0,115,112,50,45,114,46,50,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,165,226,203,26,0,0,32,0,115,112,50,45,98,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,199,4,97,144,0,0,32,0,115,112,50,45,98,46,49,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,6,76,86,90,0,0,32,0,115,112,50,45,98,46,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,60,46,74,143,0,0,32,0,115,112,50,45,98,46,53,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,106,111,18,205,0,0,32,0,115,112,50,45,98,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,60,141,216,52,0,0,32,0,115,112,50,45,114,46,56,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,66,196,92,135,0,0,0,8,97,109,112,97,108,49,54,114,52,97,45,115,112,50,45,114,45,51,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,0,0,0,24,18,0,0,0,255,255,255,0,0,0,0,0,19,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,136,219,8,0,18,0,0,0,1,3,3,0,248,81,6,0,18,0,0,0,1,3,2,0,80,124,6,0,18,0,0,0,1,3,1,0,176,64,8,0,18,0,0,0,1,3,0,0,128,65,6,0,0,0,0,0,254,0,4,0,128,129,4,0,18,0,0,0,1,12,8,0,208,75,4,0,18,0,0,0,1,12,12,0,8,49,4,0,18,0,0,0,1,12,4,0,152,21,4,0,18,0,0,0,1,12,0,0,72,246,3,0,0,0,0,0,254,0,16,0,32,4,2,0,18,0,0,0,2,240,160,0,8,32,4,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,176,0,96,164,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,192,0,144,102,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,208,0,176,45,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,16,0,112,169,3,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,224,0,224,127,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,32,0,192,119,3,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,48,0,136,252,1,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,240,0,32,123,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,64,0,248,116,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,144,0,192,110,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,128,0,96,102,7,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,112,0,184,105,6,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,96,0,152,96,3,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,80,0,192,100,6,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,0,0,104,151,6,0,19,0,0,0,0,4,4,0,0,0,0,0,0,0,0,0,254,0,4,0,200,87,7,0,18,0,0,0,130,48,0,0,96,164,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,130,48,16,0,176,45,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,130,48,32,0,224,127,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,130,48,48,0,32,123,8,0,19,0,0,0,0,4,4,0,0,0,0,0,0,0,0,0,254,0,4,0,160,123,6,0,18,0,0,0,130,192,192,0,192,110,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,130,192,128,0,96,102,7,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,130,192,64,0,152,96,3,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,130,192,0,0,192,100,6,0,19,0,0,0,0,4,4,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,1,1,0,96,135,7,0,19,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,200,30,2,0,19,0,0,0,1,2,0,0,120,97,1,0,19,0,0,0,1,2,2,0,96,19,1,0,0,0,0,0,254,0,2,0,96,46,8,0,19,0,0,0,1,4,4,0,208,233,4,0,19,0,0,0,1,4,0,0,72,197,4,0,0,0,0,0,254,0,2,0,104,159,3,0,19,0,0,0,1,8,0,0,96,135,7,0,19,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,16,0,0,96,135,7,0,19,0,0,0,1,16,16,0,152,182,7,0,0,0,0,0,254,0,2,0,72,4,1,0,19,0,0,0,1,32,32,0,96,135,7,0,19,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,246,3,0,19,0,0,0,1,64,64,0,96,135,7,0,19,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,128,128,0,96,135,7,0,19,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,19,0,0,0,1,15,1,0,96,135,3,0,19,0,0,0,1,15,4,0,32,136,7,0,19,0,0,0,1,15,7,0,40,88,7,0,19,0,0,0,1,15,0,0,248,225,8,0,19,0,0,0,1,15,10,0,96,39,7,0,19,0,0,0,1,15,6,0,120,113,6,0,19,0,0,0,1,15,3,0,232,228,5,0,19,0,0,0,1,15,15,0,144,251,6,0,19,0,0,0,1,15,2,0,232,192,7,0,19,0,0,0,1,15,5,0,192,172,7,0,19,0,0,0,1,15,9,0,120,211,6,0,19,0,0,0,1,15,14,0,184,164,6,0,19,0,0,0,1,15,8,0,24,1,7,0,19,0,0,0,1,15,13,0,80,74,6,0,19,0,0,0,1,15,12,0,192,32,6,0,19,0,0,0,1,15,11,0,192,234,2,0,0,0,0,0,254,0,16,0,160,123,6,0,19,0,0,0,1,240,16,0,96,135,3,0,19,0,0,0,1,240,64,0,32,136,7,0,19,0,0,0,1,240,112,0,40,88,7,0,19,0,0,0,1,240,0,0,248,225,8,0,19,0,0,0,1,240,160,0,96,39,7,0,19,0,0,0,1,240,96,0,120,113,6,0,19,0,0,0,1,240,48,0,232,228,5,0,19,0,0,0,1,240,240,0,144,251,6,0,19,0,0,0,1,240,32,0,232,192,7,0,19,0,0,0,1,240,80,0,192,172,7,0,19,0,0,0,1,240,144,0,120,211,6,0,19,0,0,0,1,240,224,0,184,164,6,0,19,0,0,0,1,240,128,0,24,1,7,0,19,0,0,0,1,240,208,0,80,74,6,0,19,0,0,0,1,240,192,0,192,32,6,0,19,0,0,0,1,240,176,0,192,234,2,0,0,0,0,0,254,0,2,0,88,40,6,0,20,0,0,0,1,1,0,0,96,135,7,0,20,0,0,0,1,1,1,0,152,182,7,0,0,0,0,0,254,0,2,0,88,169,5,0,20,0,0,0,1,2,2,0,128,133,5,0,20,0,0,0,1,2,0,0,200,105,5,0,0,0,0,0,254,0,4,0,96,74,5,0,20,0,0,0,1,12,12,0,24,43,5,0,20,0,0,0,1,12,8,0,136,12,5,0,20,0,0,0,1,12,4,0,248,233,4,0,20,0,0,0,1,12,0,0,120,197,4,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,48,32,0,80,246,3,0,20,0,0,0,1,48,48,0,248,38,7,0,20,0,0,0,1,48,16,0,112,212,3,0,20,0,0,0,1,48,0,0,248,160,5,0,0,0,0,0,254,0,2,0,168,234,7,0,20,0,0,0,1,64,0,0,96,135,7,0,20,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,20,0,0,0,1,128,128,0,96,135,7,0,20,0,0,0,1,128,0,0,152,182,7,0,116,115,115,97,45,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,163,183,170,69,1,0,16,1,116,115,115,97,45,55,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,72,143,50,139,1,0,16,1,116,115,115,97,45,55,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,171,176,162,41,1,0,16,1,116,115,115,97,45,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,109,22,201,153,1,0,16,1,116,115,115,97,45,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,97,98,123,121,1,0,16,1,116,115,115,97,45,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,44,105,37,72,1,0,16,1,116,115,115,97,45,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,232,241,90,180,1,0,16,1,116,115,115,97,45,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,133,123,183,201,1,0,16,1,116,115,115,98,45,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,242,225,35,125,4,0,32,0,116,115,115,98,45,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,51,120,151,228,4,0,32,0,116,115,115,98,45,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,195,103,146,155,4,0,32,0,116,115,115,98,45,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,51,226,165,92,4,0,32,0,108,48,54,95,112,114,111,109,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,135,125,12,106,7,0,32,0,18,0,0,0,255,255,255,0,0,0,0,0,19,0,0,0,255,255,171,0,0,0,0,0,20,0,0,0,255,255,128,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,18,0,0,0,1,15,2,0,32,136,7,0,18,0,0,0,1,15,5,0,40,88,7,0,18,0,0,0,1,15,8,0,96,39,7,0,18,0,0,0,1,15,4,0,120,113,6,0,18,0,0,0,1,15,1,0,232,228,5,0,18,0,0,0,1,15,15,0,144,251,6,0,18,0,0,0,1,15,3,0,56,141,7,0,18,0,0,0,1,15,7,0,120,211,6,0,18,0,0,0,1,15,14,0,184,164,6,0,18,0,0,0,1,15,6,0,24,1,7,0,18,0,0,0,1,15,13,0,80,74,6,0,18,0,0,0,1,15,12,0,192,32,6,0,18,0,0,0,1,15,11,0,192,234,2,0,18,0,0,0,1,15,10,0,32,242,5,0,18,0,0,0,1,15,9,0,176,192,2,0,18,0,0,0,1,15,0,0,16,227,4,0,0,0,0,0,254,0,16,0,160,123,6,0,18,0,0,0,1,240,0,0,96,135,7,0,18,0,0,0,1,240,32,0,32,136,7,0,18,0,0,0,1,240,80,0,40,88,7,0,18,0,0,0,1,240,128,0,96,39,7,0,18,0,0,0,1,240,64,0,120,113,6,0,18,0,0,0,1,240,16,0,232,228,5,0,18,0,0,0,1,240,240,0,144,251,6,0,18,0,0,0,1,240,48,0,56,141,7,0,18,0,0,0,1,240,112,0,120,211,6,0,18,0,0,0,1,240,224,0,184,164,6,0,18,0,0,0,1,240,96,0,24,1,7,0,18,0,0,0,1,240,208,0,80,74,6,0,18,0,0,0,1,240,192,0,192,32,6,0,18,0,0,0,1,240,176,0,192,234,2,0,18,0,0,0,1,240,160,0,32,242,5,0,18,0,0,0,1,240,144,0,176,192,2,0,0,0,0,0,254,0,2,0,104,159,3,0,19,0,0,0,1,1,1,0,56,111,3,0,19,0,0,0,1,1,0,0,104,134,3,0,0,0,0,0,254,0,2,0,64,41,5,0,19,0,0,0,1,2,2,0,248,38,7,0,19,0,0,0,1,2,0,0,112,212,3,0,0,0,0,0,254,0,4,0,248,195,4,0,19,0,0,0,1,12,0,0,40,164,4,0,19,0,0,0,1,12,4,0,104,133,4,0,19,0,0,0,1,12,8,0,64,106,4,0,19,0,0,0,1,12,12,0,152,79,4,0,0,0,0,0,254,0,4,0,176,53,4,0,19,0,0,0,1,48,48,0,248,81,6,0,19,0,0,0,1,48,32,0,248,38,7,0,19,0,0,0,1,48,16,0,176,64,8,0,19,0,0,0,1,48,0,0,128,65,6,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,64,64,0,96,135,7,0,19,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,20,0,0,0,1,128,128,0,96,135,7,0,20,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,49,46,55,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,57,152,204,56,1,0,16,1,50,46,55,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,228,10,224,41,1,0,16,1,51,46,55,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,239,157,147,161,1,0,16,1,52,46,55,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,48,136,143,6,1,0,16,1,53,46,49,48,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,220,154,205,50,1,0,16,1,54,46,49,48,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,197,103,219,80,1,0,16,1,55,46,49,48,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,113,82,65,34,1,0,16,1,56,46,49,48,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,71,216,154,21,1,0,16,1,97,50,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,221,66,176,56,4,0,32,0,97,52,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,234,23,75,90,4,0,32,0,97,49,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,179,26,68,36,4,0,32,0,97,51,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,189,204,237,224,4,0,32,0,112,114,111,109,95,54,51,51,49,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,135,125,12,106,7,0,32,0,97,45,52,101,45,99,45,106,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,166,169,160,50,0,0,16,1,97,45,52,100,45,99,45,106,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,120,234,115,49,0,0,16,1,97,45,51,101,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,176,122,232,88,0,0,16,1,97,45,51,102,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,234,49,30,200,0,0,16,1,97,45,51,104,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,149,185,159,217,0,0,16,1,103,45,52,99,45,97,45,106,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,166,197,249,138,0,0,32,0,103,45,52,100,45,97,45,106,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,114,12,48,184,0,0,32,0,103,45,52,101,45,97,45,106,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,205,41,4,181,0,0,32,0,98,45,52,107,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,80,81,251,22,0,0,32,0,98,45,52,102,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,51,90,116,103,0,0,32,0,98,45,52,108,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,97,34,28,189,0,0,32,0,98,45,52,104,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,58,237,197,138,0,0,32,0,98,45,51,110,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,170,19,162,40,0,0,32,0,98,45,52,110,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,243,141,34,213,0,0,32,0,98,45,52,109,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,242,228,109,177,0,0,32,0,98,45,51,109,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,107,214,160,235,0,0,32,0,98,45,52,99,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,133,136,41,1,0,0,32,0,98,45,52,101,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,212,135,123,199,0,0,32,0,98,45,52,100,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,95,97,112,106,0,0,32,0,98,45,52,97,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,38,214,137,97,0,0,32,0,103,45,49,106,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,202,107,142,102,0,0,32,0,98,45,49,109,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,156,90,192,118,0,0,32,0,103,45,49,102,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,149,100,75,150,0,0,32,0,98,45,49,110,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,153,107,240,35,0,0,32,0,103,45,49,104,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,225,99,5,85,0,0,32,0,98,45,49,108,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,33,80,228,53,0,0,32,0,98,45,53,102,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,61,28,96,122,0,0,32,0,98,45,54,102,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,18,13,194,130,0,0,32,0,117,119,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,146,251,100,124,1,0,16,1,117,119,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,195,20,237,178,1,0,16,1,117,119,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,96,65,95,148,1,0,16,1,117,119,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,96,80,136,132,1,0,16,1,117,119,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,29,55,66,227,1,0,16,1,117,119,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,137,163,21,217,1,0,16,1,117,119,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,70,83,36,201,1,0,16,1,117,119,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,148,195,55,162,1,0,16,1,117,119,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,186,156,6,175,4,0,32,0,117,119,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,175,50,97,194,4,0,32,0,117,119,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,213,32,44,255,4,0,32,0,117,119,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,59,179,194,220,4,0,32,0,109,109,105,54,51,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,135,125,12,106,7,0,32,0,99,53,55,45,49,56,46,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,46,213,215,25,2,0,16,1,99,53,55,45,50,48,46,55,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,37,88,46,2,0,16,1,99,53,55,45,49,55,46,53,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,184,237,151,225,2,0,16,1,99,53,55,45,50,50,46,55,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,227,253,85,88,2,0,16,1,99,53,55,45,49,53,43,46,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,241,184,110,179,6,0,16,1,99,53,55,45,49,54,43,46,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,231,209,181,191,6,0,16,1,99,53,55,45,48,54,46,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,91,221,186,78,11,0,32,0,99,53,55,45,48,49,46,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,78,176,1,249,17,0,32,0,99,53,55,45,48,50,46,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,51,70,238,33,17,0,32,0,99,53,55,45,48,51,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,111,168,252,250,17,0,32,0,99,53,55,45,48,52,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,144,112,120,169,17,0,32,0,99,53,55,45,48,53,46,51,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,46,235,112,106,23,0,32,0,99,53,55,45,48,55,46,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,193,61,101,173,24,0,64,0,99,53,55,45,48,56,46,55,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,80,53,89,34,25,0,64,0,112,97,108,49,54,108,56,45,99,53,55,45,48,57,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,30,22,147,234,0,0,0,8,112,97,108,50,48,108,56,45,99,53,55,45,49,48,46,52,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,1,0,0,136,104,229,62,0,0,0,8,112,97,108,49,54,108,56,45,99,53,55,45,49,49,46,52,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,46,55,180,107,0,0,0,8,112,97,108,50,48,108,56,45,99,53,55,45,49,50,46,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,1,0,0,19,219,189,222,0,0,0,8,112,97,108,49,54,108,56,45,99,53,55,45,49,51,46,55,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,62,242,105,19,0,0,0,8,112,97,108,49,54,114,52,45,99,53,55,45,49,52,46,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,97,191,225,117,0,0,0,8,16,0,0,0,255,255,255,0,0,0,0,0,17,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,208,198,1,0,16,0,0,0,1,2,2,0,96,135,7,0,16,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,16,0,0,0,1,4,4,0,96,135,7,0,16,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,16,0,0,0,1,8,0,0,96,135,7,0,16,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,16,0,0,0,1,48,0,0,80,252,6,0,16,0,0,0,1,48,16,0,16,242,7,0,16,0,0,0,1,48,32,0,104,236,7,0,16,0,0,0,1,48,48,0,128,230,7,0,0,0,0,0,254,0,4,0,160,123,6,0,16,0,0,0,1,192,192,0,8,201,6,0,16,0,0,0,1,192,128,0,200,197,6,0,16,0,0,0,1,192,64,0,152,194,6,0,16,0,0,0,1,192,0,0,248,189,6,0,0,0,0,0,254,0,4,0,72,202,5,0,17,0,0,0,1,3,2,0,80,246,3,0,17,0,0,0,1,3,3,0,248,38,7,0,17,0,0,0,1,3,1,0,112,212,3,0,17,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,2,0,104,159,3,0,17,0,0,0,1,64,0,0,96,135,7,0,17,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,40,15,1,0,17,0,0,0,1,128,128,0,96,135,7,0,17,0,0,0,1,128,0,0,152,182,7,0,41,0,0,0,255,255,254,0,0,0,0,0,42,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,41,0,0,0,1,1,0,0,120,97,1,0,41,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,2,0,144,212,8,0,41,0,0,0,1,2,2,0,96,135,7,0,41,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,41,0,0,0,1,4,4,0,96,135,7,0,41,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,41,0,0,0,1,8,0,0,96,135,7,0,41,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,41,0,0,0,1,48,0,0,40,88,7,0,41,0,0,0,1,48,16,0,96,39,7,0,41,0,0,0,1,48,48,0,144,251,6,0,41,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,41,0,0,0,1,192,0,0,40,88,7,0,41,0,0,0,1,192,64,0,96,39,7,0,41,0,0,0,1,192,192,0,144,251,6,0,41,0,0,0,1,192,128,0,184,164,6,0,0,0,0,0,254,0,4,0,72,202,5,0,42,0,0,0,1,3,2,0,80,246,3,0,42,0,0,0,1,3,3,0,80,124,6,0,42,0,0,0,1,3,1,0,112,212,3,0,42,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,232,209,7,0,42,0,0,0,1,12,8,0,152,21,4,0,42,0,0,0,1,12,12,0,8,49,4,0,42,0,0,0,1,12,4,0,72,246,3,0,42,0,0,0,1,12,0,0,208,75,4,0,0,0,0,0,254,0,4,0,128,129,4,0,42,0,0,0,1,48,48,0,8,49,4,0,42,0,0,0,1,48,32,0,152,21,4,0,42,0,0,0,1,48,16,0,72,246,3,0,42,0,0,0,1,48,0,0,72,0,3,0,0,0,0,0,254,0,2,0,64,37,5,0,42,0,0,0,1,64,64,0,72,168,7,0,42,0,0,0,1,64,0,0,8,164,7,0,0,0,0,0,254,0,2,0,224,21,4,0,42,0,0,0,1,128,128,0,64,155,7,0,42,0,0,0,1,128,0,0,136,149,7,0,0,0,0,0,115,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,16,175,117,217,1,0,16,1,115,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,195,20,237,178,1,0,16,1,115,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,96,65,95,148,1,0,16,1,115,98,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,92,131,41,130,1,0,16,1,115,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,48,249,30,245,1,0,16,1,115,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,137,163,21,217,1,0,16,1,115,98,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,70,83,36,201,1,0,16,1,115,98,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,174,241,159,229,1,0,16,1,115,98,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,89,201,19,131,4,0,32,0,115,98,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,175,50,97,194,4,0,32,0,115,98,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,126,83,212,201,4,0,32,0,115,98,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,128,67,69,146,4,0,32,0,54,108,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,103,148,172,195,7,0,32,0,12,0,0,0,255,255,0,0,0,0,0,0,13,0,0,0,255,255,0,0,0,0,0,0,14,0,0,0,255,255,1,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,12,0,0,0,1,32,0,0,120,97,1,0,12,0,0,0,1,32,32,0,96,19,1,0,0,0,0,0,254,0,2,0,232,75,4,0,12,0,0,0,1,64,0,0,96,135,7,0,12,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,4,0,32,4,2,0,13,0,0,0,1,192,64,0,144,147,2,0,13,0,0,0,1,192,0,0,200,209,1,0,13,0,0,0,1,192,128,0,104,69,1,0,13,0,0,0,1,192,192,0,104,151,6,0,0,0,0,0,254,0,4,0,64,37,5,0,14,0,0,0,1,3,1,0,152,120,3,0,14,0,0,0,1,3,2,0,136,120,6,0,14,0,0,0,1,3,3,0,176,114,3,0,14,0,0,0,1,3,0,0,120,7,5,0,0,0,0,0,254,0,2,0,128,129,4,0,14,0,0,0,1,4,0,0,8,49,4,0,14,0,0,0,1,4,4,0,72,246,3,0,115,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,16,175,117,217,1,0,16,1,115,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,195,20,237,178,1,0,16,1,115,98,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,193,228,92,194,1,0,16,1,115,98,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,92,131,41,130,1,0,16,1,115,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,48,249,30,245,1,0,16,1,115,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,137,163,21,217,1,0,16,1,115,98,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,70,83,36,201,1,0,16,1,115,98,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,174,241,159,229,1,0,16,1,115,98,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,89,201,19,131,4,0,32,0,115,98,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,175,50,97,194,4,0,32,0,115,98,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,126,83,212,201,4,0,32,0,107,48,49,95,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,59,179,194,220,4,0,32,0,108,48,54,95,112,114,111,109,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,135,125,12,106,7,0,32,0,20,0,0,0,255,255,255,0,0,0,0,0,21,0,0,0,255,255,237,0,0,0,0,0,0,0,0,0,254,0,2,0,232,75,4,0,20,0,0,0,1,1,1,0,96,135,7,0,20,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,20,0,0,0,1,2,2,0,96,135,7,0,20,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,8,0,160,123,6,0,20,0,0,0,1,28,0,0,40,88,7,0,20,0,0,0,1,28,16,0,96,39,7,0,20,0,0,0,1,28,28,0,144,251,6,0,20,0,0,0,1,28,12,0,184,164,6,0,20,0,0,0,1,28,20,0,80,74,6,0,20,0,0,0,1,28,4,0,192,32,6,0,20,0,0,0,1,28,24,0,192,234,2,0,20,0,0,0,1,28,8,0,32,242,5,0,0,0,0,0,254,0,8,0,200,87,7,0,20,0,0,0,1,224,0,0,40,88,7,0,20,0,0,0,1,224,128,0,96,39,7,0,20,0,0,0,1,224,224,0,144,251,6,0,20,0,0,0,1,224,96,0,184,164,6,0,20,0,0,0,1,224,160,0,80,74,6,0,20,0,0,0,1,224,32,0,192,32,6,0,20,0,0,0,1,224,192,0,192,234,2,0,20,0,0,0,1,224,64,0,32,242,5,0,0,0,0,0,254,0,0,0,168,234,7,0,21,0,0,0,1,2,2,0,96,135,7,0,21,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,128,129,4,0,21,0,0,0,1,12,4,0,192,255,2,0,21,0,0,0,1,12,8,0,208,75,4,0,21,0,0,0,1,12,12,0,8,49,4,0,21,0,0,0,1,12,0,0,152,21,4,0,0,0,0,0,254,0,4,0,72,202,5,0,21,0,0,0,1,48,48,0,80,246,3,0,21,0,0,0,1,48,32,0,248,38,7,0,21,0,0,0,1,48,16,0,112,212,3,0,21,0,0,0,1,48,0,0,248,160,5,0,0,0,0,0,254,0,4,0,16,227,4,0,21,0,0,0,1,64,64,0,96,135,7,0,21,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,72,4,1,0,21,0,0,0,1,128,128,0,96,135,7,0,21,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,168,86,7,0,1,0,0,0,156,240,146,0,248,191,2,0,24,38,7,0,1,0,0,0,152,240,146,0,184,160,2,0,56,210,6,0,1,0,0,0])
.concat([100,1,147,0,192,135,2,0,24,163,6,0,1,0,0,0,101,1,147,0,240,108,2,0,152,122,6,0,1,0,0,0,98,1,147,0,96,82,2,0,192,72,6,0,1,0,0,0,99,1,147,0,32,56,2,0,200,110,3,0,1,0,0,0,96,1,147,0,152,30,2,0,40,246,1,0,1,0,0,0,157,240,146,0,64,246,1,0,144,236,1,0,1,0,0,0,153,240,146,0,136,224,1,0,176,223,1,0,1,0,0,0,180,248,146,0,72,198,1,0,192,209,1,0,1,0,0,0,181,248,146,0,24,182,1,0,24,198,1,0,1,0,0,0,178,248,146,0,40,167,1,0,120,189,1,0,1,0,0,0,179,248,146,0,200,149,1,0,224,22,1,0,1,0,0,0,176,248,146,0,56,126,1,0,88,212,3,0,1,0,0,0,216,220,146,0,40,185,3,0,72,65,1,0,9,0,0,0,184,6,147,0,32,58,1,0,48,50,1,0,9,0,0,0,185,6,147,0,32,58,1,0,53,46,102,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,207,198,210,224,0,0,16,1,54,46,104,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,54,3,13,58,0,0,16,1,55,46,106,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,233,168,87,0,0,16,1,49,46,102,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,33,198,133,196,0,0,16,1,50,46,104,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,134,168,198,179,0,0,16,1,51,46,106,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,76,49,126,25,0,0,16,1,52,46,107,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,161,149,54,79,0,0,16,1,49,52,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,139,155,133,179,0,0,32,0,49,53,46,57,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,105,52,33,201,0,0,32,0,49,54,46,49,48,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,158,211,229,125,0,0,32,0,49,55,46,49,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,44,247,165,11,0,0,32,0,56,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,126,117,159,14,0,0,32,0,57,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,80,230,210,247,0,0,32,0,49,48,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,244,186,23,231,0,0,32,0,49,49,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,11,37,178,4,0,0,32,0,49,50,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,64,225,16,209,0,0,32,0,49,51,46,49,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,60,113,220,143,0,0,32,0,98,46,49,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,49,84,163,62,0,0,32,0,103,46,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,158,166,215,172,0,0,32,0,114,46,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,65,139,244,183,0,0,32,0,109,49,46,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,1,146,163,131,0,0,32,0,18,0,0,0,255,255,191,0,0,0,0,0,19,0,0,0,255,255,191,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,18,0,0,0,1,3,3,0,8,49,4,0,18,0,0,0,1,3,2,0,152,21,4,0,18,0,0,0,1,3,1,0,72,246,3,0,18,0,0,0,1,3,0,0,72,0,3,0,0,0,0,0,254,0,2,0,64,37,5,0,18,0,0,0,1,4,4,0,200,201,3,0,18,0,0,0,1,4,0,0,248,104,1,0,0,0,0,0,254,0,2,0,232,129,2,0,18,0,0,0,1,8,8,0,96,135,7,0,18,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,246,3,0,18,0,0,0,1,16,16,0,96,135,7,0,18,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,2,0,112,104,5,0,18,0,0,0,1,32,32,0,96,135,7,0,18,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,200,30,2,0,18,0,0,0,1,64,0,0,120,97,1,0,18,0,0,0,1,64,64,0,96,19,1,0,0,0,0,0,254,0,2,0,72,4,1,0,18,0,0,0,1,128,128,0,96,135,7,0,18,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,8,0,200,87,7,0,19,0,0,0,1,7,2,0,224,127,8,0,19,0,0,0,1,7,1,0,136,252,1,0,19,0,0,0,1,7,7,0,32,123,8,0,19,0,0,0,1,7,6,0,192,110,8,0,19,0,0,0,1,7,5,0,96,102,7,0,19,0,0,0,1,7,4,0,184,105,6,0,19,0,0,0,1,7,3,0,192,100,6,0,19,0,0,0,1,7,0,0,104,151,6,0,0,0,0,0,254,0,8,0,160,123,6,0,19,0,0,0,1,56,0,0,96,164,8,0,19,0,0,0,1,56,8,0,144,102,8,0,19,0,0,0,1,56,16,0,176,45,8,0,19,0,0,0,1,56,24,0,224,127,8,0,19,0,0,0,1,56,56,0,32,123,8,0,19,0,0,0,1,56,32,0,232,143,1,0,19,0,0,0,1,56,48,0,192,110,8,0,19,0,0,0,1,56,40,0,96,102,7,0,0,0,0,0,254,0,4,0,72,202,5,0,19,0,0,0,1,192,192,0,80,246,3,0,19,0,0,0,1,192,128,0,248,38,7,0,19,0,0,0,1,192,64,0,112,212,3,0,19,0,0,0,1,192,0,0,248,160,5,0,101,112,114,45,49,49,51,52,50,46,97,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,241,147,70,69,1,0,16,1,101,112,114,45,49,49,51,52,48,46,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,237,63,186,3,1,0,16,1,101,112,114,45,49,49,51,52,51,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,212,183,254,237,1,0,16,1,101,112,114,45,49,49,51,52,49,46,97,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,113,247,56,3,1,0,16,1,111,112,114,45,49,49,51,52,52,46,98,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,64,249,169,89,2,0,32,0,111,112,114,45,49,49,51,52,53,46,98,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,139,6,76,180,2,0,32,0,111,112,114,45,49,49,51,52,54,46,98,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,108,166,173,229,2,0,32,0,111,112,114,45,49,49,51,53,48,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,223,161,91,82,3,0,32,0,111,112,114,45,49,49,51,53,52,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,172,163,63,121,3,0,32,0,111,112,114,45,49,49,51,53,49,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,202,241,177,99,3,0,32,0,111,112,114,45,49,49,51,53,53,46,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,50,163,15,254,3,0,32,0,111,112,114,45,49,49,51,53,50,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,176,164,127,4,3,0,32,0,111,112,114,45,49,49,51,53,54,46,98,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,157,195,163,174,3,0,32,0,111,112,114,45,49,49,51,53,51,46,98,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,248,145,7,78,3,0,32,0,111,112,114,45,49,49,51,53,55,46,98,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,65,234,197,167,3,0,32,0,101,112,114,45,49,49,51,52,55,46,97,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,237,12,31,180,4,0,16,1,101,112,114,45,49,49,51,52,56,46,97,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,136,69,146,137,8,0,64,0,101,112,114,45,49,49,51,52,57,46,97,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,4,98,75,142,8,0,64,0,51,49,55,45,48,48,53,51,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,136,12,200,145,5,0,16,1,19,0,0,0,255,255,127,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,8,0,72,202,5,0,19,0,0,0,1,7,6,0,80,246,3,0,19,0,0,0,1,7,7,0,248,38,7,0,19,0,0,0,1,7,5,0,168,237,4,0,19,0,0,0,1,7,4,0,80,233,4,0,19,0,0,0,1,7,3,0,152,228,4,0,19,0,0,0,1,7,2,0,32,225,4,0,19,0,0,0,1,7,1,0,232,220,4,0,19,0,0,0,1,7,0,0,248,160,5,0,0,0,0,0,254,0,4,0,128,129,4,0,19,0,0,0,1,24,16,0,208,75,4,0,19,0,0,0,1,24,24,0,8,49,4,0,19,0,0,0,1,24,8,0,152,21,4,0,19,0,0,0,1,24,0,0,72,246,3,0,0,0,0,0,254,0,4,0,64,37,5,0,19,0,0,0,1,96,64,0,152,53,6,0,19,0,0,0,1,96,96,0,112,216,4,0,19,0,0,0,1,96,32,0,8,49,6,0,19,0,0,0,1,96,0,0,176,210,4,0,0,0,0,0,254,0,2,0,200,30,2,0,19,0,0,0,1,128,0,0,120,97,1,0,19,0,0,0,1,128,128,0,96,19,1,0,0,0,0,0,254,0,16,0,200,87,7,0,20,0,0,0,1,15,7,0,80,252,6,0,20,0,0,0,1,15,8,0,16,242,7,0,20,0,0,0,1,15,9,0,104,236,7,0,20,0,0,0,1,15,5,0,176,51,4,0,20,0,0,0,1,15,4,0,56,24,4,0,20,0,0,0,1,15,15,0,128,230,7,0,20,0,0,0,1,15,1,0,72,216,3,0,20,0,0,0,1,15,2,0,24,188,3,0,20,0,0,0,1,15,3,0,176,162,3,0,20,0,0,0,1,15,6,0,120,211,6,0,20,0,0,0,1,15,14,0,184,164,6,0,20,0,0,0,1,15,13,0,80,74,6,0,20,0,0,0,1,15,12,0,192,32,6,0,20,0,0,0,1,15,11,0,192,234,2,0,20,0,0,0,1,15,10,0,32,242,5,0,20,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,20,0,0,0,1,240,112,0,80,252,6,0,20,0,0,0,1,240,128,0,16,242,7,0,20,0,0,0,1,240,144,0,104,236,7,0,20,0,0,0,1,240,80,0,176,51,4,0,20,0,0,0,1,240,64,0,56,24,4,0,20,0,0,0,1,240,240,0,128,230,7,0,20,0,0,0,1,240,16,0,72,216,3,0,20,0,0,0,1,240,32,0,24,188,3,0,20,0,0,0,1,240,48,0,176,162,3,0,20,0,0,0,1,240,96,0,120,211,6,0,20,0,0,0,1,240,224,0,184,164,6,0,20,0,0,0,1,240,208,0,80,74,6,0,20,0,0,0,1,240,192,0,192,32,6,0,20,0,0,0,1,240,176,0,192,234,2,0,20,0,0,0,1,240,160,0,32,242,5,0,20,0,0,0,1,240,0,0,208,236,2,0,115,108,109,110,95,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,255,33,212,228,0,0,16,1,115,108,109,110,95,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,56,126,45,213,0,0,16,1,115,108,109,110,95,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,98,209,36,185,0,0,16,1,115,108,109,110,95,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,46,86,110,250,0,0,16,1,115,108,109,110,95,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,203,223,38,170,0,0,32,0,115,108,109,110,95,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,175,210,148,111,0,0,32,0,115,108,109,110,95,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,161,194,16,131,0,0,32,0,115,108,109,110,95,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,66,108,126,171,0,0,32,0,115,108,109,110,95,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,227,43,250,128,0,0,32,0,115,108,109,110,95,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,180,6,97,35,0,0,32,0,115,108,109,110,95,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,217,229,143,8,0,0,32,0,115,108,109,110,95,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,42,35,102,131,0,0,32,0,99,57,49,45,48,53,46,53,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,124,14,38,193,2,0,16,1,99,57,49,45,48,57,46,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,102,82,43,216,2,0,16,1,99,57,49,45,48,55,46,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,90,160,113,228,9,0,16,1,99,57,49,45,48,51,46,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,18,218,101,137,11,0,32,0,99,57,49,45,48,49,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,78,63,15,15,0,32,0,99,57,49,45,48,50,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,142,185,74,225,15,0,32,0,99,57,49,45,48,52,46,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,101,16,11,57,24,0,64,0,112,97,108,49,54,108,56,98,45,99,55,52,45,48,54,46,105,99,52,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,22,220,104,200,0,0,0,8,21,0,0,0,255,255,255,0,0,0,0,0,22,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,21,0,0,0,1,2,2,0,96,135,7,0,21,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,21,0,0,0,1,4,4,0,96,135,7,0,21,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,21,0,0,0,1,8,0,0,96,135,7,0,21,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,21,0,0,0,1,48,0,0,80,252,6,0,21,0,0,0,1,48,16,0,16,242,7,0,21,0,0,0,1,48,32,0,104,236,7,0,21,0,0,0,1,48,48,0,128,230,7,0,0,0,0,0,254,0,4,0,160,123,6,0,21,0,0,0,1,192,192,0,8,201,6,0,21,0,0,0,1,192,128,0,200,197,6,0,21,0,0,0,1,192,64,0,152,194,6,0,21,0,0,0,1,192,0,0,248,189,6,0,0,0,0,0,254,0,4,0,72,202,5,0,22,0,0,0,1,3,2,0,80,246,3,0,22,0,0,0,1,3,3,0,80,124,6,0,22,0,0,0,1,3,1,0,112,212,3,0,22,0,0,0,1,3,0,0,248,160,5,0,20,0,0,0,255,255,96,0,0,0,0,0,21,0,0,0,255,255,1,0,0,0,0,0,0,0,0,0,254,0,2,0,232,75,4,0,20,0,0,0,1,32,32,0,96,135,7,0,20,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,192,3,0,20,0,0,0,1,64,64,0,96,135,7,0,20,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,48,45,3,0,21,0,0,0,1,1,0,0,176,20,3,0,21,0,0,0,1,1,1,0,224,32,1,0,0,0,0,0,16,0,0,0,255,255,255,0,0,0,0,0,17,0,0,0,255,255,255,0,0,0,0,0,18,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,16,0,0,0,1,1,1,0,96,135,7,0,16,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,16,0,0,0,1,2,0,0,96,135,7,0,16,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,16,0,0,0,1,12,8,0,80,246,3,0,16,0,0,0,1,12,12,0,248,38,7,0,16,0,0,0,1,12,4,0,112,212,3,0,16,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,2,0,16,227,4,0,16,0,0,0,1,16,16,0,96,135,7,0,16,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,16,0,0,0,1,128,128,0,96,135,7,0,16,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,8,0,200,87,7,0,17,0,0,0,1,7,5,0,40,88,7,0,17,0,0,0,1,7,6,0,96,39,7,0,17,0,0,0,1,7,7,0,144,251,6,0,17,0,0,0,1,7,4,0,184,164,6,0,17,0,0,0,1,7,3,0,80,74,6,0,17,0,0,0,1,7,2,0,192,32,6,0,17,0,0,0,1,7,1,0,192,234,2,0,17,0,0,0,1,7,0,0,32,242,5,0,0,0,0,0,254,0,8,0,160,123,6,0,17,0,0,0,1,56,40,0,40,88,7,0,17,0,0,0,1,56,48,0,96,39,7,0,17,0,0,0,1,56,56,0,144,251,6,0,17,0,0,0,1,56,32,0,184,164,6,0,17,0,0,0,1,56,24,0,80,74,6,0,17,0,0,0,1,56,16,0,192,32,6,0,17,0,0,0,1,56,8,0,192,234,2,0,17,0,0,0,1,56,0,0,32,242,5,0,0,0,0,0,254,0,2,0,144,209,2,0,17,0,0,0,1,64,64,0,56,111,3,0,17,0,0,0,1,64,0,0,104,134,3,0,0,0,0,0,254,0,2,0,232,75,4,0,18,0,0,0,1,8,8,0,96,135,7,0,18,0,0,0,1,8,0,0,152,182,7,0,115,110,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,207,221,153,72,0,0,16,1,115,110,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,13,49,173,0,0,16,1,115,98,114,111,115,45,49,46,52,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,58,107,240,22,0,0,32,0,115,98,114,111,115,45,52,46,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,228,180,234,230,0,0,64,0,21,0,0,0,255,255,1,0,0,0,0,0,22,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,224,133,4,0,21,0,0,0,1,1,1,0,40,145,8,0,21,0,0,0,1,1,0,0,64,140,8,0,0,0,0,0,254,0,2,0,144,212,8,0,21,0,0,0,1,2,2,0,88,170,1,0,21,0,0,0,1,2,0,0,160,161,1,0,0,0,0,0,254,0,2,0,184,89,6,0,21,0,0,0,1,4,0,0,96,135,7,0,21,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,21,0,0,0,1,8,8,0,232,103,1,0,21,0,0,0,1,8,0,0,176,93,1,0,0,0,0,0,254,0,4,0,200,87,7,0,21,0,0,0,1,48,48,0,56,73,7,0,21,0,0,0,1,48,32,0,208,68,7,0,21,0,0,0,1,48,16,0,96,64,7,0,21,0,0,0,1,48,0,0,128,103,7,0,0,0,0,0,254,0,4,0,160,123,6,0,21,0,0,0,1,192,0,0,208,36,7,0,21,0,0,0,1,192,64,0,40,41,7,0,21,0,0,0,1,192,128,0,240,47,7,0,21,0,0,0,1,192,192,0,104,59,7,0,0,0,0,0,254,0,4,0,72,202,5,0,22,0,0,0,1,3,1,0,232,34,1,0,22,0,0,0,1,3,0,0,136,25,1,0,22,0,0,0,1,3,2,0,64,16,1,0,22,0,0,0,1,3,3,0,80,11,1,0,0,0,0,0,254,0,4,0,64,37,5,0,22,0,0,0,1,12,12,0,104,0,1,0,22,0,0,0,1,12,0,0,56,253,8,0,22,0,0,0,1,12,8,0,48,247,8,0,22,0,0,0,1,12,4,0,64,240,8,0,0,0,0,0,254,0,4,0,128,129,4,0,22,0,0,0,1,48,16,0,96,225,8,0,22,0,0,0,1,48,48,0,24,217,8,0,22,0,0,0,1,48,0,0,120,208,8,0,22,0,0,0,1,48,32,0,8,204,8,0,0,0,0,0,254,0,2,0,144,246,3,0,22,0,0,0,1,64,64,0,56,194,8,0,22,0,0,0,1,64,0,0,96,212,3,0,0,0,0,0,254,0,2,0,104,159,3,0,22,0,0,0,1,128,0,0,160,175,8,0,22,0,0,0,1,128,128,0,120,167,8,0,0,0,0,0,115,110,111,119,98,114,111,115,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,158,79,80,63,0,0,16,1,115,110,111,119,98,114,111,115,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,188,2,75,133,0,0,16,1,115,98,114,111,115,45,49,46,52,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,58,107,240,22,0,0,32,0,115,98,114,111,115,45,52,46,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,228,180,234,230,0,0,64,0,21,0,0,0,255,255,0,0,0,0,0,0,22,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,64,251,5,0,21,0,0,0,1,1,1,0,160,191,1,0,21,0,0,0,1,1,0,0,240,183,1,0,0,0,0,0,254,0,2,0,144,212,8,0,21,0,0,0,1,2,2,0,88,170,1,0,21,0,0,0,1,2,0,0,160,161,1,0,0,0,0,0,254,0,2,0,184,89,6,0,21,0,0,0,1,4,0,0,96,135,7,0,21,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,21,0,0,0,1,8,8,0,232,103,1,0,21,0,0,0,1,8,0,0,176,93,1,0,0,0,0,0,254,0,4,0,200,87,7,0,21,0,0,0,1,48,48,0,176,96,7,0,21,0,0,0,1,48,32,0,96,64,7,0,21,0,0,0,1,48,16,0,208,36,7,0,21,0,0,0,1,48,0,0,128,103,7,0,0,0,0,0,254,0,4,0,160,123,6,0,21,0,0,0,1,192,192,0,176,96,7,0,21,0,0,0,1,192,128,0,96,64,7,0,21,0,0,0,1,192,64,0,208,36,7,0,21,0,0,0,1,192,0,0,128,103,7,0,0,0,0,0,254,0,4,0,72,202,5,0,22,0,0,0,1,3,1,0,232,34,1,0,22,0,0,0,1,3,0,0,136,25,1,0,22,0,0,0,1,3,2,0,64,16,1,0,22,0,0,0,1,3,3,0,80,11,1,0,0,0,0,0,254,0,4,0,64,37,5,0,22,0,0,0,1,12,12,0,104,0,1,0,22,0,0,0,1,12,0,0,56,253,8,0,22,0,0,0,1,12,8,0,48,247,8,0,22,0,0,0,1,12,4,0,64,240,8,0,0,0,0,0,254,0,4,0,128,129,4,0,22,0,0,0,1,48,16,0,96,225,8,0,22,0,0,0,1,48,48,0,24,217,8,0,22,0,0,0,1,48,0,0,120,208,8,0,22,0,0,0,1,48,32,0,8,204,8,0,0,0,0,0,254,0,2,0,144,246,3,0,22,0,0,0,1,64,64,0,56,194,8,0,22,0,0,0,1,64,0,0,96,212,3,0,0,0,0,0,254,0,2,0,104,159,3,0,22,0,0,0,1,128,0,0,160,175,8,0,22,0,0,0,1,128,128,0,120,167,8,0,0,0,0,0,115,98,107,95,51,45,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,64,77,23,151,0,0,16,1,115,98,107,95,50,45,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,229,128,204,128,0,0,16,1,115,98,114,111,115,45,49,46,52,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,58,107,240,22,0,0,32,0,115,98,114,111,115,45,52,46,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,228,180,234,230,0,0,64,0,51,45,97,46,105,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,107,52,188,225,0,0,16,1,50,45,97,46,105,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,157,127,226,27,0,0,16,1,115,98,114,111,115,45,49,46,52,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,58,107,240,22,0,0,32,0,115,98,114,111,115,45,52,46,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,228,180,234,230,0,0,64,0,115,98,114,111,115,51,45,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,214,39,22,48,0,0,16,1,115,98,114,111,115,50,45,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,65,159,104,246,0,0,16,1,115,98,114,111,115,45,49,46,52,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,58,107,240,22,0,0,32,0,115,98,114,111,115,45,52,46,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,228,180,234,230,0,0,64,0,115,98,114,111,115,45,51,97,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,225,55,203,16,0,0,16,1,115,98,114,111,115,45,50,97,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,30,204,145,171,0,0,16,1,115,98,114,111,115,45,49,46,52,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,58,107,240,22,0,0,32,0,115,98,114,111,115,45,52,46,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,228,180,234,230,0,0,64,0,117,114,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,253,63,193,25,0,0,16,1,117,114,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,21,250,50,63,0,0,16,1,117,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,133,227,4,6,0,0,32,0,117,110,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,76,218,121,74,0,0,32,0,117,110,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,164,97,69,122,0,0,32,0,117,115,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,239,104,99,124,0,0,64,0,115,111,117,110,100,46,109,99,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,16,16,18,0,0,0,255,255,247,0,0,0,0,0,19,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,72,202,5,0,18,0,0,0,1,3,3,0,80,246,3,0,18,0,0,0,1,3,2,0,80,124,6,0,18,0,0,0,1,3,1,0,112,212,3,0,18,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,2,0,224,172,5,0,18,0,0,0,1,4,0,0,32,137,5,0,18,0,0,0,1,4,4,0,224,109,5,0,0,0,0,0,254,0,2,0,200,30,2,0,18,0,0,0,1,8,0,0,120,97,1,0,18,0,0,0,1,8,8,0,96,19,1,0,0,0,0,0,254,0,4,0,128,129,4,0,18,0,0,0,1,192,0,0,208,75,4,0,18,0,0,0,1,192,192,0,8,49,4,0,18,0,0,0,1,192,128,0,152,21,4,0,18,0,0,0,1,192,64,0,72,246,3,0,0,0,0,0,254,0,11,0,160,123,6,0,19,0,0,0,1,15,5,0,32,136,7,0,19,0,0,0,1,15,7,0,40,88,7,0,19,0,0,0,1,15,10,0,96,39,7,0,19,0,0,0,1,15,6,0,120,113,6,0,19,0,0,0,1,15,9,0,232,216,6,0,19,0,0,0,1,15,15,0,144,251,6,0,19,0,0,0,1,15,8,0,120,211,6,0,19,0,0,0,1,15,14,0,184,164,6,0,19,0,0,0,1,15,13,0,80,74,6,0,19,0,0,0,1,15,12,0,192,32,6,0,19,0,0,0,1,15,11,0,192,234,2,0,0,0,0,0,254,0,11,0,200,87,7,0,19,0,0,0,1,240,80,0,32,136,7,0,19,0,0,0,1,240,112,0,40,88,7,0,19,0,0,0,1,240,160,0,96,39,7,0,19,0,0,0,1,240,96,0,120,113,6,0,19,0,0,0,1,240,144,0,232,216,6,0,19,0,0,0,1,240,240,0,144,251,6,0,19,0,0,0,1,240,128,0,120,211,6,0,19,0,0,0,1,240,224,0,184,164,6,0,19,0,0,0,1,240,208,0,80,74,6,0,19,0,0,0,1,240,192,0,192,32,6,0,19,0,0,0,1,240,176,0,192,234,2,0,57,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,148,185,197,85,1,0,16,1,57,50,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,211,38,174,119,1,0,16,1,57,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,16,170,110,113,1,0,16,1,57,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,242,100,168,206,1,0,16,1,57,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,81,95,44,112,1,0,16,1,57,51,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,159,3,162,230,1,0,16,1,57,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,238,60,120,115,1,0,16,1,57,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,162,74,161,193,1,0,16,1,101,112,114,50,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,97,181,38,190,4,0,32,0,109,99,115,95,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,21,42,147,19,4,0,32,0,101,112,114,50,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,232,199,38,4,0,32,0,109,99,115,95,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,69,209,207,36,4,0,32,0,109,109,105,54,51,51,49,46,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,135,125,12,106,7,0,32,0,8,0,0,0,255,255,0,0,0,0,0,0,9,0,0,0,255,255,192,0,0,0,0,0,16,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,8,0,0,0,1,32,0,0,120,97,1,0,8,0,0,0,1,32,32,0,96,19,1,0,0,0,0,0,254,0,2,0,72,202,5,0,9,0,0,0,1,64,64,0,80,246,3,0,9,0,0,0,1,64,0,0,112,212,3,0,0,0,0,0,254,0,2,0,16,98,1,0,9,0,0,0,1,128,0,0,248,81,6,0,9,0,0,0,1,128,128,0,176,64,8,0,0,0,0,0,254,0,4,0,200,87,7,0,16,0,0,0,1,3,3,0,144,102,8,0,16,0,0,0,1,3,2,0,176,45,8,0,16,0,0,0,1,3,1,0,224,127,8,0,16,0,0,0,1,3,0,0,32,123,8,0,0,0,0,0,254,0,4,0,160,123,6,0,16,0,0,0,1,12,0,0,128,103,7,0,16,0,0,0,1,12,4,0,80,196,7,0,16,0,0,0,1,12,8,0,0,90,2,0,16,0,0,0,1,12,12,0,104,151,6,0,115,109,98,106,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,16,251,234,82,1,0,16,1,115,109,98,106,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,120,128,110,170,1,0,16,1,115,109,98,106,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,95,125,158,182,1,0,16,1,115,109,98,106,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,86,123,133,141,1,0,16,1,115,109,98,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,119,21,161,185,1,0,16,1,115,109,98,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,107,183,49,249,1,0,16,1,115,109,98,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,222,209,178,217,5,0,32,0,115,109,98,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,146,109,118,154,5,0,32,0,115,109,98,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,15,15,128,81,5,0,32,0,115,109,98,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,150,126,117,53,5,0,32,0,115,109,98,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,231,208,191,229,5,0,32,0,115,109,98,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,102,8,108,197,5,0,32,0,115,109,98,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,16,57,237,77,5,0,32,0,115,109,98,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,197,30,234,38,5,0,32,0,115,109,98,46,50,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,252,197,8,10,5,0,32,0,115,109,98,46,50,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,196,182,17,9,5,0,32,0,115,109,98,46,50,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,196,214,130,5,0,32,0,115,109,98,46,50,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,139,103,72,155,5,0,32,0,115,109,98,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,154,34,188,10,10,0,16,1,115,109,98,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,154,103,81,208,10,0,16,1,115,109,98,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,249,53,105,197,12,0,64,0,115,109,98,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,130,7,91,149,12,0,64,0,100,55,49,45,49,53,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,63,21,112,20,2,0,16,1,100,55,49,45,49,54,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,224,102,54,241,2,0,16,1,100,55,49,45,48,55,46,55,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,12,103,95,221,9,0,16,1,100,55,49,45,48,52,46,55,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,28,184,39,183,12,0,32,0,100,55,49,45,48,53,46,56,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,109,93,15,123,12,0,32,0,100,55,49,45,48,54,46,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,136,65,50,243,24,0,64,0,100,55,49,45,48,49,46,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,39,140,30,11,0,0,32,0,100,55,49,45,48,50,46,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,45,234,170,204,0,0,32,0,100,55,49,45,48,51,46,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,236,249,206,220,0,0,32,0,20,0,0,0,255,255,16,0,0,0,0,0,0,0,0,0,254,0,2,0,232,75,4,0,20,0,0,0,1,16,16,0,96,135,7,0,20,0,0,0,1,16,0,0,152,182,7,0,109,98,101,95,50,51,101,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,122,5,148,83,2,0,16,1,109,98,101,95,50,52,98,46,57,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,41,231,213,149,1,0,16,1,109,98,101,95,50,56,98,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,203,203,199,177,1,0,16,1,109,98,101,95,50,53,98,46,49,48,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,212,63,13,165,1,0,16,1,109,98,101,95,50,57,98,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,86,46,227,8,1,0,16,1,109,98,101,95,50,49,97,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,5,123,0,213,2,0,16,1,109,98,101,95,50,48,97,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,176,87,181,174,2,0,16,1,109,98,45,49,109,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,6,142,70,65,4,0,32,0,109,98,45,51,109,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,158,170,83,244,4,0,32,0,109,98,45,50,109,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,254,251,47,4,0,32,0,109,98,45,52,109,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,29,132,185,30,4,0,32,0,109,98,45,53,109,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,201,157,107,80,4,0,32,0,109,98,45,55,109,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,251,194,248,175,4,0,32,0,109,98,45,54,109,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,233,112,108,183,4,0,32,0,109,98,45,56,109,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,86,149,12,230,4,0,32,0,109,98,45,49,48,109,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,245,111,151,151,4,0,32,0,109,98,45,49,50,109,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,64,168,80,179,4,0,32,0,109,98,45,49,49,109,46,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,67,71,185,143,4,0,32,0,109,98,45,49,51,109,46,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,95,13,129,218,4,0,32,0,109,98,95,113,97,46,53,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,196,3,26,226,3,0,16,1,109,98,45,113,49,46,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,206,195,48,6,6,0,64,0,109,98,45,113,50,46,50,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,33,156,79,53,6,0,64,0,109,98,45,113,51,46,51,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,124,72,56,120,6,0,64,0,109,98,45,113,52,46,52,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,135,224,102,171,6,0,64,0,109,98,45,113,53,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,242,254,137,199,6,0,64,0,109,98,45,113,54,46,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,27,184,236,6,0,64,0,109,98,45,113,55,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,186,73,30,4,6,0,64,0,109,98,45,113,56,46,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,42,112,254,89,6,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,154,135,134,67,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,109,98,54,51,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,2,47,57,184,0,0,0,8,105,111,98,49,46,49,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,98,112,114,103,49,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,167,61,121,49,0,0,0,8,105,111,99,49,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,129,32,24,13,0,0,0,8,100,55,108,49,46,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,13,65,183,39,0,0,0,8,100,56,108,49,46,56,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,218,199,159,83,0,0,0,8,100,57,107,50,46,57,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,86,161,133,205,0,0,0,8,100,49,48,102,49,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,148,196,25,102,0,0,0,8,35,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,72,4,1,0,35,0,0,0,1,8,8,0,96,135,7,0,35,0,0,0,1,8,0,0,152,182,7,0,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,200,110,168,116,0,0,16,1,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,222,67,33,240,0,0,16,1,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,10,221,124,120,0,0,16,1,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,20,200,162,7,0,0,16,1,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,172,61,109,184,0,0,32,0,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,122,191,123,252,0,0,32,0,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,171,16,55,26,0,0,32,0,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,154,52,132,161,0,0,32,0,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,232,18,102,8,0,0,32,0,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,189,234,155,58,0,0,32,0,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,142,101,131,189,0,0,32,0,56,50,115,49,50,57,45,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,163,178,148,106,0,0,32,0,56,50,115,49,50,57,45,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,211,35,9,236,0,0,32,0,56,50,115,49,50,57,45,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,82,112,233,173,0,0,32,0,55,52,115,50,56,56,45,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,173,85,10,25,0,0,32,0,55,52,115,50,56,56,45,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,21,45,219,93,0,0,32,0,122,56,48,95,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,218,123,219,52,0,0,16,1,48,55,115,95,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,5,169,128,198,0,0,16,1,48,56,115,95,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,38,191,102,61,0,0,16,1,48,52,97,95,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,170,233,157,33,0,0,32,0,48,57,104,95,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,31,126,229,37,0,0,32,0,49,48,104,95,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,233,229,13,207,0,0,32,0,49,49,104,95,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,72,192,80,64,0,0,32,0,48,54,97,95,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,131,147,128,28,0,0,32,0,48,55,97,95,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,116,215,101,86,0,0,32,0,48,56,97,95,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,42,143,218,109,0,0,32,0,48,57,97,95,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,184,221,33,106,0,0,32,0,49,48,97,95,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,224,72,229,242,0,0,32,0,49,49,97,95,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,18,177,129,134,0,0,32,0,48,49,106,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,163,178,148,106,0,0,32,0,48,49,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,211,35,9,236,0,0,32,0,48,49,102,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,82,112,233,173,0,0,32,0,109,49,46,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,1,146,163,131,0,0,32,0,18,0,0,0,255,255,255,0,0,0,0,0,19,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,96,46,8,0,18,0,0,0,1,1,1,0,192,255,2,0,18,0,0,0,1,1,0,0,208,75,4,0,0,0,0,0,254,0,16,0,32,4,2,0,18,0,0,0,2,30,20,0,176,73,5,0,18,0,0,0,0,1,1,0,0,0,0,0,18,0,0,0,2,30,22,0,104,54,4,0,18,0,0,0,0,1,1,0,0,0,0,0,18,0,0,0,2,30,24,0,80,252,6,0,18,0,0,0,0,1,1,0,0,0,0,0,18,0,0,0,2,30,26,0,16,242,7,0,18,0,0,0,0,1,1,0,0,0,0,0,18,0,0,0,2,30,2,0,40,28,4,0,18,0,0,0,0,1,1,0,0,0,0,0,18,0,0,0,2,30,28,0,104,236,7,0,18,0,0,0,0,1,1,0,0,0,0,0,18,0,0,0,2,30,4,0,192,24,7,0,18,0,0,0,0,1,1,0,0,0,0,0,18,0,0,0,2,30,6,0,120,113,6,0,18,0,0,0,0,1,1,0,0,0,0,0,18,0,0,0,2,30,30,0,128,230,7,0,18,0,0,0,0,1,1,0,0,0,0,0,18,0,0,0,2,30,8,0,120,211,6,0,18,0,0,0,0,1,1,0,0,0,0,0,18,0,0,0,2,30,18,0,184,164,6,0,18,0,0,0,0,1,1,0,0,0,0,0,18,0,0,0,2,30,16,0,80,74,6,0,18,0,0,0,0,1,1,0,0,0,0,0,18,0,0,0,2,30,14,0,192,32,6,0,18,0,0,0,0,1,1,0,0,0,0,0,18,0,0,0,2,30,12,0,192,234,2,0,18,0,0,0,0,1,1,0,0,0,0,0,18,0,0,0,2,30,10,0,32,242,5,0,18,0,0,0,0,1,1,0,0,0,0,0,18,0,0,0,2,30,0,0,16,227,4,0,18,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,254,0,4,0,200,87,7,0,18,0,0,0,2,6,0,0,104,54,4,0,18,0,0,0,0,1,0,0,0,0,0,0,18,0,0,0,2,6,2,0,16,242,7,0,18,0,0,0,0,1,0,0,0,0,0,0,18,0,0,0,2,6,4,0,104,236,7,0,18,0,0,0,0,1,0,0,0,0,0,0,18,0,0,0,2,6,6,0,128,230,7,0,18,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,254,0,4,0,160,123,6,0,18,0,0,0,2,24,24,0,8,201,6,0,18,0,0,0,0,1,0,0,0,0,0,0,18,0,0,0,2,24,16,0,200,197,6,0,18,0,0,0,0,1,0,0,0,0,0,0,18,0,0,0,2,24,8,0,128,95,7,0,18,0,0,0,0,1,0,0,0,0,0,0,18,0,0,0,2,24,0,0,248,189,6,0,18,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,254,0,2,0,72,222,3,0,18,0,0,0,1,32,32,0,248,38,7,0,18,0,0,0,1,32,0,0,200,200,1,0,0,0,0,0,254,0,4,0,128,129,4,0,19,0,0,0,1,3,2,0,208,75,4,0,19,0,0,0,1,3,3,0,8,49,4,0,19,0,0,0,1,3,1,0,72,246,3,0,19,0,0,0,1,3,0,0,112,49,6,0,0,0,0,0,254,0,4,0,64,37,5,0,19,0,0,0,1,12,12,0,160,49,3,0,19,0,0,0,1,12,8,0,224,29,3,0,19,0,0,0,1,12,4,0,104,5,3,0,19,0,0,0,1,12,0,0,80,239,2,0,0,0,0,0,254,0,4,0,72,202,5,0,19,0,0,0,1,48,0,0,80,246,3,0,19,0,0,0,1,48,48,0,248,38,7,0,19,0,0,0,1,48,32,0,112,212,3,0,19,0,0,0,1,48,16,0,24,99,5,0,0,0,0,0,254,0,2,0,104,159,3,0,19,0,0,0,1,64,0,0,56,111,3,0,19,0,0,0,1,64,64,0,104,134,3,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,128,0,0,96,135,7,0,19,0,0,0,1,128,128,0,152,182,7,0,102,48,55,95,49,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,16,175,117,217,1,0,16,1,104,48,55,95,50,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,195,20,237,178,1,0,16,1,107,48,55,95,51,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,96,65,95,148,1,0,16,1,115,114,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,248,209,97,159,1,0,16,1,115,114,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,10,175,82,67,1,0,16,1,115,114,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,137,163,21,217,1,0,16,1,109,48,56,112,95,55,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,70,83,36,201,1,0,16,1,110,48,56,112,95,56,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,199,69,125,121,1,0,16,1,115,114,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,186,156,6,175,4,0,32,0,104,48,49,95,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,175,50,97,194,4,0,32,0,115,114,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,213,32,44,255,4,0,32,0,107,48,49,95,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,59,179,194,220,4,0,32,0,117,110,105,119,97,114,115,46,99,108,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,24,149,199,37,7,0,32,0,168,86,7,0,1,0,0,0,153,248,146,0,248,191,2,0,24,38,7,0,1,0,0,0,155,248,146,0,184,160,2,0,56,210,6,0,1,0,0,0,131,240,146,0,192,135,2,0,24,163,6,0,1,0,0,0,130,240,146,0,240,108,2,0,152,122,6,0,1,0,0,0,128,240,146,0,96,82,2,0,192,72,6,0,1,0,0,0,129,240,146,0,32,56,2,0,200,110,3,0,1,0,0,0,132,240,146,0,152,30,2,0,120,89,3,0,1,0,0,0,67,1,147,0,232,10,2,0,40,246,1,0,1,0,0,0,154,248,146,0,64,246,1,0,144,236,1,0,1,0,0,0,156,248,146,0,136,224,1,0,176,223,1,0,1,0,0,0,107,237,146,0,72,198,1,0,192,209,1,0,1,0,0,0,106,237,146,0,24,182,1,0,24,198,1,0,1,0,0,0,104,237,146,0,40,167,1,0,120,189,1,0,1,0,0,0,105,237,146,0,200,149,1,0,224,22,1,0,1,0,0,0,108,237,146,0,56,126,1,0,160,14,1,0,1,0,0,0,66,1,147,0,32,101,1,0,88,212,3,0,1,0,0,0,168,220,146,0,40,185,3,0,16,17,8,0,1,0,0,0,152,248,146,0,224,12,8,0,72,65,1,0,9,0,0,0,152,6,147,0,32,58,1,0,48,50,1,0,9,0,0,0,153,6,147,0,32,58,1,0,224,41,1,0,9,0,0,0,154,6,147,0,32,58,1,0,168,86,7,0,1,0,0,0,72,247,146,0,248,191,2,0,24,38,7,0,1,0,0,0,214,255,146,0,184,160,2,0,56,210,6,0,1,0,0,0,208,255,146,0,192,135,2,0,24,163,6,0,1,0,0,0,209,255,146,0,240,108,2,0,152,122,6,0,1,0,0,0,211,255,146,0,96,82,2,0,192,72,6,0,1,0,0,0,210,255,146,0,32,56,2,0,200,110,3,0,1,0,0,0,213,255,146,0,152,30,2,0,120,89,3,0,1,0,0,0,212,255,146,0,232,10,2,0,88,212,3,0,1,0,0,0,40,219,146,0,40,185,3,0,72,65,1,0,9,0,0,0,136,5,147,0,32,58,1,0,48,50,1,0,9,0,0,0,137,5,147,0,32,58,1,0,224,41,1,0,9,0,0,0,138,5,147,0,32,58,1,0,101,112,114,45,49,50,50,53,49,46,52,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,11,205,243,26,1,0,16,1,101,112,114,45,49,50,50,52,57,46,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,125,70,61,116,1,0,16,1,101,112,114,45,49,50,50,53,50,46,52,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,214,9,227,122,1,0,16,1,101,112,114,45,49,50,50,53,48,46,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,25,15,196,82,1,0,16,1,49,50,50,50,52,45,57,53,46,98,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,161,123,193,234,2,0,32,0,49,50,50,50,53,45,57,52,46,98,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,152,252,16,35,2,0,32,0,49,50,50,50,54,45,57,51,46,98,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,153,105,14,33,2,0,32,0,49,50,50,51,50,45,49,48,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,43,198,222,10,3,0,32,0,49,50,50,51,54,45,49,49,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,248,154,107,40,3,0,32,0,49,50,50,51,51,45,49,55,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,156,150,69,62,3,0,32,0,49,50,50,51,55,45,49,56,46,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,150,142,5,229,3,0,32,0,49,50,50,51,52,45,50,51,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,239,84,141,140,3,0,32,0,49,50,50,51,56,45,50,52,46,98,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,4,51,218,122,3,0,32,0,49,50,50,51,53,45,50,57,46,98,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,17,213,69,250,3,0,32,0,49,50,50,51,57,45,51,48,46,98,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,139,12,247,145,3,0,32,0,101,112,114,45,49,50,50,50,55,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,157,64,18,91,4,0,16,1,55,55,53,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,252,52,149,106,6,0,16,1,101,112,114,45,49,50,50,50,56,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,239,106,46,107,7,0,64,0,101,112,114,45,49,50,50,50,57,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,92,1,170,183,7,0,64,0,101,112,114,45,49,50,50,51,48,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,212,31,246,208,7,0,64,0,101,112,114,45,49,50,50,51,49,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,87,220,11,120,7,0,64,0,51,49,55,45,53,48,50,49,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,55,41,227,195,5,0,16,1,28,0,0,0,255,255,255,0,0,0,0,0,29,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,28,0,0,0,1,15,7,0,80,252,6,0,28,0,0,0,1,15,8,0,16,242,7,0,28,0,0,0,1,15,9,0,104,236,7,0,28,0,0,0,1,15,5,0,176,51,4,0,28,0,0,0,1,15,4,0,56,24,4,0,28,0,0,0,1,15,15,0,128,230,7,0,28,0,0,0,1,15,1,0,72,216,3,0,28,0,0,0,1,15,2,0,24,188,3,0,28,0,0,0,1,15,3,0,176,162,3,0,28,0,0,0,1,15,6,0,120,211,6,0,28,0,0,0,1,15,14,0,184,164,6,0,28,0,0,0,1,15,13,0,80,74,6,0,28,0,0,0,1,15,12,0,192,32,6,0,28,0,0,0,1,15,11,0,192,234,2,0,28,0,0,0,1,15,10,0,32,242,5,0,28,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,28,0,0,0,1,240,112,0,80,252,6,0,28,0,0,0,1,240,128,0,16,242,7,0,28,0,0,0,1,240,144,0,104,236,7,0,28,0,0,0,1,240,80,0,176,51,4,0,28,0,0,0,1,240,64,0,56,24,4,0,28,0,0,0,1,240,240,0,128,230,7,0,28,0,0,0,1,240,16,0,72,216,3,0,28,0,0,0,1,240,32,0,24,188,3,0,28,0,0,0,1,240,48,0,176,162,3,0,28,0,0,0,1,240,96,0,120,211,6,0,28,0,0,0,1,240,224,0,184,164,6,0,28,0,0,0,1,240,208,0,80,74,6,0,28,0,0,0,1,240,192,0,192,32,6,0,28,0,0,0,1,240,176,0,192,234,2,0,28,0,0,0,1,240,160,0,32,242,5,0,28,0,0,0,1,240,0,0,208,236,2,0,117,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,222,160,75,131,0,0,16,1,117,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,58,238,228,7,0,0,16,1,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,14,196,248,203,0,0,16,1,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,58,225,119,244,0,0,32,0,118,116,49,49,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,72,27,46,123,0,0,32,0,118,116,49,50,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,211,23,180,129,0,0,32,0,118,116,49,51,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,210,219,18,86,0,0,32,0,118,116,49,52,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,54,238,45,43,0,0,32,0,118,116,49,53,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,191,186,112,222,0,0,32,0,118,116,49,54,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,55,130,23,20,0,0,32,0,117,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,51,201,151,42,0,0,32,0,118,116,48,54,46,101,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,33,229,254,38,0,0,32,0,118,116,48,55,46,101,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,253,189,136,202,0,0,32,0,117,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,46,170,180,214,0,0,32,0,118,116,48,57,46,104,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,130,57,112,152,0,0,32,0,118,116,49,48,46,104,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,248,210,105,240,0,0,32,0,118,116,98,49,46,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,161,21,186,58,0,0,32,0,118,116,98,50,46,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,84,87,134,136,0,0,32,0,118,116,98,51,46,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,246,195,20,76,0,0,32,0,118,116,98,52,46,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,70,194,136,179,0,0,32,0,118,116,98,53,46,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,8,197,42,113,0,0,32,0,118,116,98,54,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,88,81,175,14,0,0,32,0,20,0,0,0,255,255,8,0,0,0,0,0,0,0,0,0,254,0,2,0,232,75,4,0,20,0,0,0,1,8,8,0,96,135,7,0,20,0,0,0,1,8,0,0,152,182,7,0,19,0,0,0,255,255,0,0,0,0,0,0,20,0,0,0,255,255,0,0,0,0,0,0,21,0,0,0,255,255,0,0,0,0,0,0,22,0,0,0,255,255,0,0,0,0,0,0,19,0,0,0,254,0,4,0,200,87,7,0,19,0,0,0,1,3,1,0,160,36,8,0,19,0,0,0,1,3,0,0,208,239,7,0,19,0,0,0,1,3,2,0,120,187,7,0,19,0,0,0,1,3,3,0,136,23,1,0,19,0,0,0,254,0,4,0,160,123,6,0,19,0,0,0,1,12,4,0,160,36,8,0,19,0,0,0,1,12,0,0,208,239,7,0,19,0,0,0,1,12,8,0,120,187,7,0,19,0,0,0,1,12,12,0,136,23,1,0,20,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,3,3,0,208,75,4,0,20,0,0,0,1,3,0,0,8,49,4,0,20,0,0,0,1,3,1,0,152,21,4,0,20,0,0,0,1,3,2,0,72,246,3,0,20,0,0,0,254,0,2,0,168,234,7,0,20,0,0,0,1,8,0,0,96,135,7,0,20,0,0,0,1,8,8,0,152,182,7,0,21,0,0,0,254,0,8,0,64,37,5,0,21,0,0,0,1,7,0,0,200,140,8,0,21,0,0,0,1,7,1,0,48,209,8,0,21,0,0,0,1,7,2,0,88,8,3,0,21,0,0,0,1,7,3,0,72,130,7,0,21,0,0,0,1,7,4,0,8,49,6,0,21,0,0,0,1,7,5,0,160,191,4,0,21,0,0,0,1,7,6,0,240,159,4,0,21,0,0,0,1,7,7,0,120,7,5,0,22,0,0,0,254,0,6,0,72,202,5,0,22,0,0,0,1,7,0,0,24,205,7,0,22,0,0,0,1,7,1,0,192,255,2,0,22,0,0,0,1,7,2,0,208,75,4,0,22,0,0,0,1,7,3,0,8,49,4,0,22,0,0,0,1,7,4,0,152,21,4,0,22,0,0,0,1,7,5,0,72,246,3,0,22,0,0,0,254,0,2,0,104,159,3,0,22,0,0,0,1,8,8,0,56,111,3,0,22,0,0,0,1,8,0,0,104,134,3,0,0,0,0,0,39,0,0,0,255,255,255,0,0,0,0,0,40,0,0,0,255,255,191,0,0,0,0,0,0,0,0,0,254,0,0,0,144,212,8,0,39,0,0,0,1,2,2,0,96,135,7,0,39,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,0,0,232,75,4,0,39,0,0,0,1,4,4,0,96,135,7,0,39,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,39,0,0,0,1,8,0,0,96,135,7,0,39,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,2,0,200,87,7,0,39,0,0,0,1,48,16,0,96,39,7,0,39,0,0,0,1,48,48,0,144,251,6,0,39,0,0,0,1,48,0,0,120,211,6,0,39,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,39,0,0,0,1,192,64,0,96,39,7,0,39,0,0,0,1,192,192,0,144,251,6,0,39,0,0,0,1,192,0,0,120,211,6,0,39,0,0,0,1,192,128,0,184,164,6,0,0,0,0,0,254,0,4,0,72,202,5,0,40,0,0,0,1,3,2,0,80,246,3,0,40,0,0,0,1,3,3,0,80,124,6,0,40,0,0,0,1,3,1,0,112,212,3,0,40,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,144,246,3,0,40,0,0,0,1,4,4,0,96,135,7,0,40,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,56,161,6,0,40,0,0,0,1,8,8,0,96,135,7,0,40,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,2,0,16,158,6,0,40,0,0,0,1,16,16,0,96,135,7,0,40,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,2,0,56,154,6,0,40,0,0,0,1,32,32,0,232,150,6,0,40,0,0,0,1,32,0,0,184,147,6,0,0,0,0,0,254,0,2,0,104,143,6,0,40,0,0,0,1,192,192,0,8,140,6,0,40,0,0,0,1,192,128,0,240,242,5,0,40,0,0,0,1,192,64,0,0,130,6,0,40,0,0,0,1,192,0,0,64,125,6,0,0,0,0,0,14,0,0,0,255,255,255,0,0,0,0,0,15,0,0,0,255,255,191,0,0,0,0,0,0,0,0,0,254,0,8,0,32,4,2,0,14,0,0,0,1,7,1,0,40,88,7,0,14,0,0,0,1,7,2,0,96,39,7,0,14,0,0,0,1,7,3,0,120,113,6,0,14,0,0,0,1,7,7,0,144,251,6,0,14,0,0,0,1,7,4,0,120,211,6,0,14,0,0,0,1,7,6,0,184,164,6,0,14,0,0,0,1,7,5,0,80,74,6,0,14,0,0,0,1,7,0,0,16,227,4,0,0,0,0,0,254,0,0,0,72,202,5,0,15,0,0,0,1,7,4,0,160,246,1,0,15,0,0,0,1,7,5,0,120,103,7,0,15,0,0,0,1,7,6,0,80,246,3,0,15,0,0,0,1,7,7,0,248,38,7,0,15,0,0,0,1,7,3,0,80,124,6,0,15,0,0,0,1,7,2,0,112,212,3,0,15,0,0,0,1,7,1,0,48,90,7,0,15,0,0,0,1,7,0,0,248,160,5,0,0,0,0,0,254,0,0,0,128,129,4,0,15,0,0,0,1,48,32,0,208,75,4,0,15,0,0,0,1,48,48,0,8,49,4,0,15,0,0,0,1,48,16,0,152,21,4,0,15,0,0,0,1,48,0,0,72,246,3,0,0,0,0,0,254,0,0,0,168,234,7,0,15,0,0,0,1,64,64,0,96,135,7,0,15,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,15,0,0,0,1,128,128,0,96,135,7,0,15,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,70,150,229,56,1,0,16,1,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,146,209,41,133,1,0,16,1,98,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,189,32,166,162,1,0,16,1,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,82,218,206,163,1,0,16,1,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,125,126,98,70,2,0,32,0,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,33,243,208,135,2,0,32,0,98,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,135,175,180,239,2,0,32,0,98,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,58,65,31,97,3,0,32,0,98,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,193,15,176,94,3,0,32,0,98,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,192,151,7,60,3,0,32,0,98,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,248,126,48,37,3,0,32,0,98,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,78,195,154,194,3,0,32,0,98,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,248,55,164,4,3,0,32,0,98,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,54,189,152,126,3,0,32,0,98,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,66,207,21,3,3,0,32,0,98,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,69,183,80,221,4,0,16,1,55,55,53,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,252,52,149,106,6,0,16,1,98,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,218,102,121,109,7,0,64,0,52,46,51,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,156,163,120,193,1,0,16,1,50,46,51,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,242,235,216,90,1,0,16,1,53,46,50,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,189,32,166,162,1,0,16,1,51,46,50,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,82,218,206,163,1,0,16,1,56,46,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,125,126,98,70,2,0,32,0,55,46,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,33,243,208,135,2,0,32,0,54,46,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,135,175,180,239,2,0,32,0,57,46,54,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,58,65,31,97,3,0,32,0,49,51,46,56,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,193,15,176,94,3,0,32,0,49,48,46,54,113,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,192,151,7,60,3,0,32,0,49,52,46,56,113,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,248,126,48,37,3,0,32,0,49,49,46,54,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,78,195,154,194,3,0,32,0,49,53,46,56,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,248,55,164,4,3,0,32,0,49,50,46,54,110,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,99,16,244,65,3,0,32,0,49,54,46,56,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,114,253,225,182,3,0,32,0,49,46,53,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,69,183,80,221,4,0,16,1,55,55,53,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,252,52,149,106,6,0,16,1,98,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,218,102,121,109,7,0,64,0,49,55,46,54,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,12,137,166,183,0,0,64,8,101,112,114,45,49,49,51,54,48,46,97,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,185,122,246,177,1,0,16,1,101,112,114,45,49,49,51,53,57,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,225,6,3,15,1,0,16,1,101,112,114,45,49,49,51,54,51,46,97,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,104,65,145,64,2,0,32,0,101,112,114,45,49,49,51,54,52,46,97,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,164,73,54,230,2,0,32,0,101,112,114,45,49,49,51,54,53,46,97,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,32,93,245,30,2,0,32,0,101,112,114,45,49,49,51,54,54,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,115,222,158,49,3,0,32,0,101,112,114,45,49,49,51,54,56,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,206,215,119,3,3,0,32,0,101,112,114,45,49,49,51,54,55,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,199,197,6,29,3,0,32,0,101,112,114,45,49,49,51,54,57,46,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,162,210,81,215,3,0,32,0,101,112,114,45,49,49,51,54,49,46,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,203,235,71,31,4,0,16,1,101,112,114,45,49,49,51,54,50,46,97,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,73,247,106,37,8,0,64,0,101,112,114,45,49,49,51,54,48,46,97,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,185,122,246,177,1,0,16,1,101,112,114,45,49,49,51,53,57,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,225,6,3,15,1,0,16,1,101,112,114,45,49,49,51,54,51,46,97,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,104,65,145,64,2,0,32,0,101,112,114,45,49,49,51,54,52,46,97,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,164,73,54,230,2,0,32,0,101,112,114,45,49,49,51,54,53,46,97,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,32,93,245,30,2,0,32,0,101,112,114,45,49,49,51,54,54,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,115,222,158,49,3,0,32,0,101,112,114,45,49,49,51,54,56,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,206,215,119,3,3,0,32,0,101,112,114,45,49,49,51,54,55,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,199,197,6,29,3,0,32,0,101,112,114,45,49,49,51,54,57,46,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,162,210,81,215,3,0,32,0,101,112,114,45,49,49,51,55,55,46,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,52,175,182,15,4,0,16,1,101,112,114,45,49,49,51,54,50,46,97,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,73,247,106,37,8,0,64,0,51,49,55,45,48,48,53,52,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,53,69,253,57,5,0,16,1,101,112,114,45,49,49,50,57,57,46,97,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,157,57,48,185,1,0,16,1,101,112,114,45,49,49,50,57,56,46,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,70,76,63,52,1,0,16,1,101,112,114,45,49,49,50,56,51,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,7,231,70,157,1,0,16,1,101,112,114,45,49,49,50,56,49,46,97,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,126,208,97,121,1,0,16,1,101,112,114,45,49,49,50,56,52,46,98,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,99,225,98,95,2,0,32,0,101,112,114,45,49,49,50,56,53,46,98,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,201,251,248,117,2,0,32,0,101,112,114,45,49,49,50,56,54,46,98,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,185,139,80,6,2,0,32,0,101,112,114,45,49,49,50,57,48,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,58,65,31,97,3,0,32,0,101,112,114,45,49,49,50,57,52,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,193,15,176,94,3,0,32,0,101,112,114,45,49,49,50,57,49,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,192,151,7,60,3,0,32,0,101,112,114,45,49,49,50,57,53,46,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,248,126,48,37,3,0,32,0,101,112,114,45,49,49,50,57,50,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,78,195,154,194,3,0,32,0,101,112,114,45,49,49,50,57,54,46,98,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,248,55,164,4,3,0,32,0,101,112,114,45,49,49,50,57,51,46,98,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,99,16,244,65,3,0,32,0,101,112,114,45,49,49,50,57,55,46,98,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,114,253,225,182,3,0,32,0,101,112,114,45,49,49,51,55,50,46,97,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,154,38,36,8,4,0,16,1,101,112,114,45,49,49,50,56,56,46,97,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,96,132,223,200,8,0,64,0,101,112,114,45,49,49,50,56,57,46,97,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,48,207,164,229,8,0,64,0,51,49,55,45,48,48,53,52,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,53,69,253,57,5,0,16,1,101,112,114,45,49,49,50,56,50,46,97,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,36,85,46,95,1,0,16,1,101,112,114,45,49,49,50,56,48,46,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,56,92,254,189,1,0,16,1,101,112,114,45,49,49,50,56,51,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,7,231,70,157,1,0,16,1,101,112,114,45,49,49,50,56,49,46,97,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,126,208,97,121,1,0,16,1,101,112,114,45,49,49,50,56,52,46,98,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,99,225,98,95,2,0,32,0,101,112,114,45,49,49,50,56,53,46,98,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,201,251,248,117,2,0,32,0,101,112,114,45,49,49,50,56,54,46,98,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,185,139,80,6,2,0,32,0,101,112,114,45,49,49,50,57,48,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,58,65,31,97,3,0,32,0,101,112,114,45,49,49,50,57,52,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,193,15,176,94,3,0,32,0,101,112,114,45,49,49,50,57,49,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,192,151,7,60,3,0,32,0,101,112,114,45,49,49,50,57,53,46,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,248,126,48,37,3,0,32,0,101,112,114,45,49,49,50,57,50,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,78,195,154,194,3,0,32,0,101,112,114,45,49,49,50,57,54,46,98,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,248,55,164,4,3,0,32,0,101,112,114,45,49,49,50,57,51,46,98,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,99,16,244,65,3,0,32,0,101,112,114,45,49,49,50,57,55,46,98,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,114,253,225,182,3,0,32,0,101,112,114,45,49,49,50,56,55,46,97,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,66,205,204,232,4,0,16,1,101,112,114,45,49,49,50,56,56,46,97,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,96,132,223,200,8,0,64,0,101,112,114,45,49,49,50,56,57,46,97,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,48,207,164,229,8,0,64,0,51,49,55,45,48,48,52,57,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,79,130,172,143,5,0,16,1,101,112,114,45,49,49,50,54,50,46,52,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,18,223,184,212,1,0,16,1,101,112,114,45,49,49,50,54,48,46,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,93,201,53,40,1,0,16,1,101,112,114,45,49,49,50,54,51,46,52,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,189,32,166,162,1,0,16,1,101,112,114,45,49,49,50,54,49,46,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,82,218,206,163,1,0,16,1,101,112,114,45,49,49,50,54,52,46,57,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,125,126,98,70,2,0,32,0,101,112,114,45,49,49,50,54,53,46,57,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,33,243,208,135,2,0,32,0,101,112,114,45,49,49,50,54,54,46,57,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,135,175,180,239,2,0,32,0,101,112,114,45,49,49,50,57,48,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,58,65,31,97,3,0,32,0,101,112,114,45,49,49,50,57,52,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,193,15,176,94,3,0,32,0,101,112,114,45,49,49,50,57,49,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,192,151,7,60,3,0,32,0,101,112,114,45,49,49,50,57,53,46,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,248,126,48,37,3,0,32,0,101,112,114,45,49,49,50,57,50,46,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,78,195,154,194,3,0,32,0,101,112,114,45,49,49,50,57,54,46,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,248,55,164,4,3,0,32,0,101,112,114,45,49,49,50,57,51,46,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,99,16,244,65,3,0,32,0,101,112,114,45,49,49,50,57,55,46,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,114,253,225,182,3,0,32,0,101,112,114,45,49,49,50,54,55,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,69,183,80,221,4,0,16,1,55,55,53,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,252,52,149,106,6,0,16,1,101,112,114,45,49,49,50,54,56,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,218,102,121,109,7,0,64,0,51,49,55,45,48,48,53,48,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,237,156,195,130,5,0,16,1,115,104,100,97,110,99,101,114,46,97,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,169,63,91,61,1,0,16,1,115,104,100,97,110,99,101,114,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,78,0,150,37,1,0,16,1,109,112,114,45,49,50,55,49,50,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,61,190,218,155,2,0,32,0,109,112,114,45,49,50,55,49,51,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,28,43,45,133,2,0,32,0,109,112,114,45,49,50,55,49,52,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,206,38,130,68,2,0,32,0,109,112,114,45,49,50,55,49,57,46,98,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,52,133,136,214,3,0,32,0,109,112,114,45,49,50,55,50,54,46,97,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,69,73,52,255,3,0,32,0,109,112,114,45,49,50,55,49,56,46,98,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,12,252,46,186,3,0,32,0,109,112,114,45,49,50,55,50,53,46,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,23,12,138,38,3,0,32,0,109,112,114,45,49,50,55,49,55,46,98,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,248,196,28,200,3,0,32,0,109,112,114,45,49,50,55,50,52,46,97,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,220,3,73,15,3,0,32,0,101,112,114,45,49,50,55,49,54,46,98,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,41,230,112,168,3,0,32,0,101,112,114,45,49,50,55,50,51,46,97,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,144,207,6,198,3,0,32,0,101,112,114,45,49,50,55,50,48,46,97,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,225,141,13,122,4,0,16,1,109,112,114,45,49,50,55,49,53,46,98,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,82,26,5,7,19,0,64,0,22,0,0,0,255,255,255,0,0,0,0,0,23,0,0,0,255,255,253,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,22,0,0,0,1,15,7,0,80,252,6,0,22,0,0,0,1,15,8,0,16,242,7,0,22,0,0,0,1,15,9,0,104,236,7,0,22,0,0,0,1,15,5,0,176,51,4,0,22,0,0,0,1,15,4,0,56,24,4,0,22,0,0,0,1,15,15,0,128,230,7,0,22,0,0,0,1,15,1,0,72,216,3,0,22,0,0,0,1,15,2,0,24,188,3,0,22,0,0,0,1,15,3,0,176,162,3,0,22,0,0,0,1,15,6,0,120,211,6,0,22,0,0,0,1,15,14,0,184,164,6,0,22,0,0,0,1,15,13,0,80,74,6,0,22,0,0,0,1,15,12,0,192,32,6,0,22,0,0,0,1,15,11,0,192,234,2,0,22,0,0,0,1,15,10,0,32,242,5,0,22,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,22,0,0,0,1,240,112,0,80,252,6,0,22,0,0,0,1,240,128,0,16,242,7,0,22,0,0,0,1,240,144,0,104,236,7,0,22,0,0,0,1,240,80,0,176,51,4,0,22,0,0,0,1,240,64,0,56,24,4,0,22,0,0,0,1,240,240,0,128,230,7,0,22,0,0,0,1,240,16,0,72,216,3,0,22,0,0,0,1,240,32,0,24,188,3,0,22,0,0,0,1,240,48,0,176,162,3,0,22,0,0,0,1,240,96,0,120,211,6,0,22,0,0,0,1,240,224,0,184,164,6,0,22,0,0,0,1,240,208,0,80,74,6,0,22,0,0,0,1,240,192,0,192,32,6,0,22,0,0,0,1,240,176,0,192,234,2,0,22,0,0,0,1,240,160,0,32,242,5,0,22,0,0,0,1,240,0,0,208,236,2,0,0,0,0,0,254,0,2,0,88,131,3,0,23,0,0,0,1,1,1,0,96,135,7,0,23,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,23,0,0,0,1,2,2,0,96,135,7,0,23,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,23,0,0,0,1,12,0,0,208,75,4,0,23,0,0,0,1,12,12,0,8,49,4,0,23,0,0,0,1,12,8,0,152,21,4,0,23,0,0,0,1,12,4,0,72,246,3,0,0,0,0,0,254,0,4,0,72,202,5,0,23,0,0,0,1,48,32,0,80,246,3,0,23,0,0,0,1,48,48,0,248,38,7,0,23,0,0,0,1,48,16,0,112,212,3,0,23,0,0,0,1,48,0,0,248,160,5,0,0,0,0,0,254,0,4,0,40,252,8,0,23,0,0,0,1,192,0,0,184,24,8,0,23,0,0,0,1,192,64,0,232,20,8,0,23,0,0,0,1,192,192,0,176,17,8,0,23,0,0,0,1,192,128,0,208,13,8,0,0,0,0,0,101,112,114,45,55,49,56,56,97,46,105,99,57,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,195,115,225,69,1,0,16,1,101,112,114,45,55,49,56,52,97,46,105,99,56,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,81,74,147,225,1,0,16,1,101,112,114,45,55,49,56,57,46,105,99,57,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,159,48,177,64,1,0,16,1,101,112,114,45,55,49,56,53,46,105,99,56,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,92,4,120,206,1,0,16,1,101,112,114,45,55,49,57,48,46,105,99,57,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,145,16,57,246,1,0,16,1,101,112,114,45,55,49,56,54,46,105,99,56,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,215,103,179,121,1,0,16,1,101,112,114,45,55,49,57,49,46,105,99,49,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,211,233,113,97,1,0,16,1,101,112,114,45,55,49,56,55,46,105,99,56,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,239,114,203,112,1,0,16,1,101,112,114,45,55,49,56,50,46,105,99,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,182,53,197,215,9,0,16,1,101,112,114,45,55,49,56,51,46,105,99,54,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,248,58,21,166,9,0,16,1,101,112,114,45,55,49,57,54,46,105,99,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,37,163,127,52,2,0,32,0,101,112,114,45,55,49,57,55,46,105,99,52,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,209,139,217,57,2,0,32,0,101,112,114,45,55,49,57,56,46,105,99,54,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,107,234,163,61,2,0,32,0,101,112,114,45,55,50,51,48,46,105,99,51,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,100,210,226,147,3,0,32,0,101,112,114,45,55,50,50,50,46,105,99,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,195,95,191,237,3,0,32,0,101,112,114,45,55,50,49,52,46,105,99,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,216,55,197,232,3,0,32,0,101,112,114,45,55,50,48,54,46,105,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,164,79,132,34,3,0,32,0,101,112,114,45,55,50,50,57,46,105,99,51,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,117,110,205,3,0,32,0,101,112,114,45,55,50,50,49,46,105,99,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,156,90,242,65,3,0,32,0,101,112,114,45,55,50,49,51,46,105,99,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,103,154,176,91,3,0,32,0,101,112,114,45,55,50,48,53,46,105,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,191,46,170,220,3,0,32,0,101,112,114,45,55,50,50,56,46,105,99,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,102,94,225,213,3,0,32,0,101,112,114,45,55,50,50,48,46,105,99,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,46,174,98,172,3,0,32,0,101,112,114,45,55,50,49,50,46,105,99,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,149,34,120,156,3,0,32,0,101,112,114,45,55,50,48,52,46,105,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,92,16,17,55,3,0,32,0,101,112,114,45,55,50,50,55,46,105,99,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,187,193,215,96,3,0,32,0,101,112,114,45,55,50,49,57,46,105,99,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,56,0,51,246,3,0,32,0,101,112,114,45,55,50,49,49,46,105,99,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,152,123,115,96,3,0,32,0,101,112,114,45,55,50,48,51,46,105,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,187,94,251,112,3,0,32,0,101,112,114,45,55,50,50,54,46,105,99,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,151,92,123,109,3,0,32,0,101,112,114,45,55,50,49,56,46,105,99,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,124,121,191,206,3,0,32,0,101,112,114,45,55,50,49,48,46,105,99,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,139,106,89,36,3,0,32,0,101,112,114,45,55,50,48,50,46,105,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,130,208,55,181,3,0,32,0,101,112,114,45,55,50,50,53,46,105,99,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,113,66,120,94,3,0,32,0,101,112,114,45,55,50,49,55,46,105,99,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,16,94,14,81,3,0,32,0,101,112,114,45,55,50,48,57,46,105,99,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,21,173,45,122,3,0,32,0,101,112,114,45,55,50,48,49,46,105,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,8,78,186,245,3,0,32,0,101,112,114,45,55,50,50,52,46,105,99,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,239,201,66,236,3,0,32,0,101,112,114,45,55,50,49,54,46,105,99,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,122,125,74,109,3,0,32,0,101,112,114,45,55,50,48,56,46,105,99,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,23,39,115,15,3,0,32,0,101,112,114,45,55,50,48,48,46,105,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,243,248,59,252,3,0,32,0,101,112,114,45,55,50,50,51,46,105,99,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,196,253,81,237,3,0,32,0,101,112,114,45,55,50,49,53,46,105,99,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,61,95,231,223,3,0,32,0,101,112,114,45,55,50,48,55,46,105,99,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,65,119,192,162,3,0,32,0,101,112,114,45,55,49,57,57,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,47,226,145,177,3,0,32,0,101,112,114,45,55,49,56,49,46,105,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,25,4,116,180,10,0,32,0,101,112,114,45,55,50,51,52,46,105,99,55,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,51,121,57,214,4,0,16,1,101,112,114,45,55,50,51,51,46,105,99,55,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,217,118,78,80,4,0,16,1,101,112,114,45,55,50,51,49,46,105,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,20,107,28,135,11,0,64,0,101,112,114,45,55,50,51,50,46,105,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,12,52,89,75,11,0,64,0,101,112,114,45,54,56,52,52,46,105,99,49,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,214,123,236,227,16,0,32,0,51,49,53,45,53,49,54,51,97,46,105,99,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,16,11,0,0,0,255,255,255,0,0,0,0,0,12,0,0,0,255,255,252,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,11,0,0,0,1,15,7,0,80,252,6,0,11,0,0,0,1,15,8,0,16,242,7,0,11,0,0,0,1,15,9,0,104,236,7,0,11,0,0,0,1,15,5,0,176,51,4,0,11,0,0,0,1,15,4,0,56,24,4,0,11,0,0,0,1,15,15,0,128,230,7,0,11,0,0,0,1,15,1,0,72,216,3,0,11,0,0,0,1,15,2,0,24,188,3,0,11,0,0,0,1,15,3,0,176,162,3,0,11,0,0,0,1,15,6,0,120,211,6,0,11,0,0,0,1,15,14,0,184,164,6,0,11,0,0,0,1,15,13,0,80,74,6,0,11,0,0,0,1,15,12,0,192,32,6,0,11,0,0,0,1,15,11,0,192,234,2,0,11,0,0,0,1,15,10,0,32,242,5,0,11,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,11,0,0,0,1,240,112,0,80,252,6,0,11,0,0,0,1,240,128,0,16,242,7,0,11,0,0,0,1,240,144,0,104,236,7,0,11,0,0,0,1,240,80,0,176,51,4,0,11,0,0,0,1,240,64,0,56,24,4,0,11,0,0,0,1,240,240,0,128,230,7,0,11,0,0,0,1,240,16,0,72,216,3,0,11,0,0,0,1,240,32,0,24,188,3,0,11,0,0,0,1,240,48,0,176,162,3,0,11,0,0,0,1,240,96,0,120,211,6,0,11,0,0,0,1,240,224,0,184,164,6,0,11,0,0,0,1,240,208,0,80,74,6,0,11,0,0,0,1,240,192,0,192,32,6,0,11,0,0,0,1,240,176,0,192,234,2,0,11,0,0,0,1,240,160,0,32,242,5,0,11,0,0,0,1,240,0,0,208,236,2,0,0,0,0,0,254,0,2,0,200,30,2,0,12,0,0,0,1,1,0,0,120,97,1,0,12,0,0,0,1,1,1,0,120,247,1,0,0,0,0,0,254,0,2,0,168,234,7,0,12,0,0,0,1,2,2,0,96,135,7,0,12,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,12,0,0,0,1,12,8,0,208,75,4,0,12,0,0,0,1,12,12,0,8,49,4,0,12,0,0,0,1,12,4,0,152,21,4,0,12,0,0,0,1,12,0,0,72,246,3,0,0,0,0,0,254,0,2,0,64,37,5,0,12,0,0,0,1,16,16,0,32,150,2,0,12,0,0,0,1,16,0,0,96,138,2,0,0,0,0,0,254,0,2,0,248,126,2,0,12,0,0,0,1,32,32,0,96,135,7,0,12,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,12,0,0,0,1,192,128,0,80,246,3,0,12,0,0,0,1,192,192,0,80,124,6,0,12,0,0,0,1,192,64,0,112,212,3,0,12,0,0,0,1,192,0,0,248,160,5,0,101,112,114,45,49,48,55,56,57,46,49,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,206,197,146,96,1,0,16,1,101,112,114,45,49,48,55,56,56,46,49,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,234,161,216,195,1,0,16,1,101,112,114,45,49,48,54,51,55,97,46,49,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,8,19,108,173,1,0,16,1,101,112,114,45,49,48,54,51,53,97,46,49,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,149,85,65,162,1,0,16,1,101,112,114,45,49,48,55,57,50,46,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,37,157,41,22,9,0,16,1,101,112,114,45,49,48,55,57,48,46,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,193,203,70,34,9,0,16,1,101,112,114,45,49,48,55,57,51,46,55,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,39,84,82,217,9,0,16,1,101,112,114,45,49,48,55,57,49,46,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,190,76,175,95,9,0,16,1,101,112,114,45,49,48,54,53,50,46,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,249,134,2,38,2,0,32,0,101,112,114,45,49,48,54,53,49,46,53,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,123,238,9,198,2,0,32,0,101,112,114,45,49,48,54,53,48,46,53,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,3,164,54,178,2,0,32,0,101,112,114,45,49,48,54,55,53,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,43,1,172,214,3,0,32,0,101,112,114,45,49,48,54,56,50,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,80,50,216,217,3,0,32,0,101,112,114,45,49,48,54,55,54,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,197,242,235,37,3,0,32,0,101,112,114,45,49,48,54,56,51,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,233,210,101,99,3,0,32,0,101,112,114,45,49,48,54,55,55,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,214,184,87,138,3,0,32,0,101,112,114,45,49,48,54,56,52,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,16,137,255,58,3,0,32,0,101,112,114,45,49,48,54,55,56,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,152,48,71,175,3,0,32,0,101,112,114,45,49,48,54,56,53,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,239,254,186,128,3,0,32,0,101,112,114,45,49,48,54,55,57,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,120,72,188,3,3,0,32,0,101,112,114,45,49,48,54,56,54,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,78,115,75,39,3,0,32,0,101,112,114,45,49,48,54,56,48,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,237,119,6,159,3,0,32,0,101,112,114,45,49,48,54,56,55,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,71,138,80,3,0,32,0,101,112,114,45,49,48,54,56,49,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,114,234,118,177,3,0,32,0,101,112,114,45,49,48,54,56,56,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,29,213,252,66,3,0,32,0,101,112,114,45,49,48,54,52,50,46,52,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,195,188,54,120,10,0,32,0,101,112,114,45,49,48,54,52,57,97,46,56,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,15,51,56,191,4,0,16,1,101,112,114,45,49,48,54,52,51,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,100,83,245,6,11,0,64,0,101,112,114,45,49,48,54,52,52,46,54,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,29,84,29,180,11,0,64,0,101,112,114,45,49,48,54,52,53,46,54,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,255,171,13,166,11,0,64,0,101,112,114,45,49,48,54,52,54,46,54,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,17,196,60,71,11,0,64,0,51,49,55,45,48,48,51,52,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,115,167,60,38,5,0,16,1,101,112,114,45,49,48,54,51,54,97,46,49,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,79,79,166,116,1,0,16,1,101,112,114,45,49,48,54,51,52,97,46,49,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,74,203,8,22,1,0,16,1,101,112,114,45,49,48,54,51,55,97,46,49,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,8,19,108,173,1,0,16,1,101,112,114,45,49,48,54,51,53,97,46,49,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,149,85,65,162,1,0,16,1,101,112,114,45,49,48,54,52,48,46,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,219,104,190,2,9,0,16,1,101,112,114,45,49,48,54,51,56,46,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,238,139,62,241,9,0,16,1,101,112,114,45,49,48,54,52,49,46,55,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,8,248,195,56,9,0,16,1,101,112,114,45,49,48,54,51,57,46,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,232,205,219,140,9,0,16,1,101,112,114,45,49,48,54,53,50,46,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,249,134,2,38,2,0,32,0,101,112,114,45,49,48,54,53,49,46,53,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,123,238,9,198,2,0,32,0,101,112,114,45,49,48,54,53,48,46,53,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,3,164,54,178,2,0,32,0,101,112,114,45,49,48,54,55,53,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,43,1,172,214,3,0,32,0,101,112,114,45,49,48,54,56,50,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,80,50,216,217,3,0,32,0,101,112,114,45,49,48,54,55,54,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,197,242,235,37,3,0,32,0,101,112,114,45,49,48,54,56,51,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,233,210,101,99,3,0,32,0,101,112,114,45,49,48,54,55,55,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,214,184,87,138,3,0,32,0,101,112,114,45,49,48,54,56,52,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,16,137,255,58,3,0,32,0,101,112,114,45,49,48,54,55,56,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,152,48,71,175,3,0,32,0,101,112,114,45,49,48,54,56,53,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,239,254,186,128,3,0,32,0,101,112,114,45,49,48,54,55,57,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,120,72,188,3,3,0,32,0,101,112,114,45,49,48,54,56,54,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,78,115,75,39,3,0,32,0,101,112,114,45,49,48,54,56,48,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,237,119,6,159,3,0,32,0,101,112,114,45,49,48,54,56,55,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,71,138,80,3,0,32,0,101,112,114,45,49,48,54,56,49,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,114,234,118,177,3,0,32,0,101,112,114,45,49,48,54,56,56,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,29,213,252,66,3,0,32,0,101,112,114,45,49,48,54,52,50,46,52,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,195,188,54,120,10,0,32,0,105,99,56,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,166,239,84,18,4,0,16,1,101,112,114,45,49,48,54,52,51,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,100,83,245,6,11,0,64,0,101,112,114,45,49,48,54,52,52,46,54,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,29,84,29,180,11,0,64,0,101,112,114,45,49,48,54,52,53,46,54,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,255,171,13,166,11,0,64,0,101,112,114,45,49,48,54,52,54,46,54,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,17,196,60,71,11,0,64,0,51,49,55,45,48,48,51,52,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,115,167,60,38,5,0,16,1,17,0,0,0,255,255,247,0,0,0,0,0,18,0,0,0,255,255,127,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,17,0,0,0,1,1,1,0,96,135,7,0,17,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,120,39,8,0,17,0,0,0,1,16,16,0,96,135,7,0,17,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,2,0,72,4,1,0,17,0,0,0,1,128,128,0,96,135,7,0,17,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,16,0,192,192,5,0,18,0,0,0,1,15,7,0,56,132,5,0,18,0,0,0,1,15,11,0,248,77,3,0,18,0,0,0,1,15,3,0,104,102,8,0,18,0,0,0,1,15,13,0,72,242,7,0,18,0,0,0,1,15,5,0,152,136,4,0,18,0,0,0,1,15,9,0,40,32,8,0,18,0,0,0,1,15,1,0,96,28,8,0,18,0,0,0,1,15,14,0,224,23,8,0,18,0,0,0,1,15,15,0,88,207,5,0,18,0,0,0,1,15,6,0,184,230,7,0,18,0,0,0,1,15,10,0,72,123,3,0,18,0,0,0,1,15,2,0,152,120,3,0,18,0,0,0,1,15,12,0,136,120,6,0,18,0,0,0,1,15,4,0,160,118,3,0,18,0,0,0,1,15,8,0,176,114,3,0,18,0,0,0,1,15,0,0,32,112,3,0,0,0,0,0,254,0,4,0,72,202,5,0,18,0,0,0,1,48,48,0,248,38,7,0,18,0,0,0,1,48,32,0,112,212,3,0,18,0,0,0,1,48,16,0,24,99,5,0,18,0,0,0,1,48,0,0,248,160,5,0,0,0,0,0,254,0,2,0,168,234,7,0,18,0,0,0,1,128,128,0,96,135,7,0,18,0,0,0,1,128,0,0,152,182,7,0,115,122,51,106,95,100,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,81,97,67,176,1,0,16,1,115,122,51,106,95,100,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,112,129,45,100,1,0,16,1,115,122,51,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,138,81,33,155,1,0,16,1,115,122,51,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,167,195,166,231,1,0,16,1,115,122,51,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,253,12,76,236,1,0,16,1,115,122,51,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,64,114,126,92,1,0,16,1,115,122,51,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,83,149,88,197,1,0,16,1,115,122,51,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,114,113,169,1,0,16,1,115,122,51,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,217,96,122,15,5,0,32,0,115,122,51,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,65,55,147,142,5,0,32,0,115,122,51,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,71,129,233,214,5,0,32,0,115,122,51,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,138,114,26,243,5,0,32,0,115,122,51,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,151,130,249,95,5,0,32,0,115,122,51,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,238,189,181,82,5,0,32,0,115,122,51,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,213,30,99,64,5,0,32,0,115,122,51,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,180,9,52,118,5,0,32,0,115,122,51,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,132,0,129,222,10,0,16,1,115,122,51,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,196,93,68,114,10,0,16,1,115,122,51,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,209,238,137,28,12,0,64,0,115,122,51,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,58,177,146,243,12,0,64,0,168,86,7,0,1,0,0,0,224,47,216,0,248,191,2,0,24,38,7,0,1,0,0,0,228,47,216,0,184,160,2,0,56,210,6,0,1,0,0,0,35,48,216,0,192,135,2,0,24,163,6,0,1,0,0,0,34,48,216,0,240,108,2,0,152,122,6,0,1,0,0,0,33,48,216,0,96,82,2,0,192,72,6,0,1,0,0,0,32,48,216,0,32,56,2,0,152,226,4,0,1,0,0,0,36,48,216,0,152,30,2,0,168,190,4,0,1,0,0,0,37,48,216,0,232,10,2,0,240,158,4,0,1,0,0,0,38,48,216,0,152,138,8,0,136,128,4,0,1,0,0,0,168,47,216,0,48,119,7,0,176,101,4,0,1,0,0,0,169,47,216,0,112,109,7,0,136,75,4,0,1,0,0,0,170,47,216,0,24,133,7,0,40,246,1,0,1,0,0,0,225,47,216,0,64,246,1,0,144,236,1,0,1,0,0,0,229,47,216,0,136,224,1,0,176,223,1,0,1,0,0,0,43,48,216,0,72,198,1,0,192,209,1,0,1,0,0,0,42,48,216,0,24,182,1,0,24,198,1,0,1,0,0,0,41,48,216,0,40,167,1,0,120,189,1,0,1,0,0,0,40,48,216,0,200,149,1,0,40,126,1,0,1,0,0,0,44,48,216,0,56,126,1,0,0,112,1,0,1,0,0,0,45,48,216,0,32,101,1,0,0,101,1,0,1,0,0,0,46,48,216,0,96,32,8,0,248,91,1,0,1,0,0,0,172,47,216,0,16,68,7,0,128,85,1,0,1,0,0,0,173,47,216,0,240,58,7,0,248,76,1,0,1,0,0,0,174,47,216,0,200,42,1,0,88,212,3,0,1,0,0,0,144,46,216,0,40,185,3,0,240,152,1,0,1,0,0,0,230,47,216,0,216,70,1,0,16,17,8,0,1,0,0,0,226,47,216,0,224,12,8,0,72,65,1,0,9,0,0,0,232,48,216,0,32,58,1,0,48,50,1,0,9,0,0,0,224,48,216,0,32,58,1,0,224,41,1,0,9,0,0,0,216,48,216,0,32,58,1,0,50,50,95,48,56,45,57,50,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,62,204,251,149,2,0,16,1,50,49,95,48,56,45,57,50,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,164,204,241,153,2,0,16,1,50,51,95,48,56,45,57,50,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,187,134,196,82,2,0,16,1,115,57,50,95,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,216,176,3,4,0,32,0,115,57,50,95,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,137,2,132,4,0,32,0,115,57,50,95,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,240,181,205,4,0,32,0,115,57,50,95,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,114,148,121,226,4,0,32,0,115,57,50,95,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,39,138,186,4,0,32,0,115,57,50,95,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,191,132,229,4,0,32,0,115,57,50,95,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,125,248,227,33,4,0,32,0,115,57,50,95,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,71,252,190,4,0,32,0,115,57,50,95,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,213,135,6,150,4,0,32,0,115,57,50,95,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,205,142,151,4,0,32,0,115,57,50,95,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,10,154,236,214,4,0,32,0,115,57,50,95,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,103,44,237,4,0,32,0,115,57,50,95,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,14,182,246,8,3,0,16,0,115,57,50,95,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0])
.concat([9,32,22,127,5,0,64,0,115,57,50,95,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,229,173,190,5,0,64,0,115,102,51,103,45,49,46,48,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,165,89,5,201,1,0,16,1,115,102,51,103,45,51,46,48,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,130,102,243,129,1,0,16,1,115,102,51,103,45,50,46,48,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,161,32,238,158,1,0,16,1,115,102,51,103,45,52,46,48,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,117,216,195,106,1,0,16,1,115,57,50,95,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,216,176,3,4,0,32,0,115,57,50,95,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,137,2,132,4,0,32,0,115,57,50,95,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,240,181,205,4,0,32,0,115,57,50,95,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,114,148,121,226,4,0,32,0,115,57,50,95,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,39,138,186,4,0,32,0,115,57,50,95,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,191,132,229,4,0,32,0,115,57,50,95,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,125,248,227,33,4,0,32,0,115,57,50,95,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,71,252,190,4,0,32,0,115,57,50,95,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,213,135,6,150,4,0,32,0,115,57,50,95,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,205,142,151,4,0,32,0,115,57,50,95,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,10,154,236,214,4,0,32,0,115,57,50,95,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,103,44,237,4,0,32,0,115,57,50,95,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,14,182,246,8,3,0,16,0,115,57,50,95,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,32,22,127,5,0,64,0,115,57,50,95,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,229,173,190,5,0,64,0,54,46,97,109,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,117,162,133,58,8,0,32,0,57,46,97,109,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,47,71,86,145,8,0,32,0,56,46,97,109,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,59,8,219,236,8,0,32,0,49,48,46,97,109,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,132,131,234,143,8,0,32,0,115,102,49,49,45,49,46,48,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,189,199,175,1,0,16,1,115,102,49,49,45,51,46,48,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,196,209,44,136,1,0,16,1,115,102,49,49,45,50,46,48,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,83,205,165,248,1,0,16,1,115,102,49,49,45,52,46,48,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,114,31,126,219,1,0,16,1,115,57,50,95,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,216,176,3,4,0,32,0,115,57,50,95,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,137,2,132,4,0,32,0,115,57,50,95,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,240,181,205,4,0,32,0,115,57,50,95,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,114,148,121,226,4,0,32,0,115,57,50,95,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,39,138,186,4,0,32,0,115,57,50,95,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,191,132,229,4,0,32,0,115,57,50,95,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,125,248,227,33,4,0,32,0,115,57,50,95,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,71,252,190,4,0,32,0,115,57,50,95,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,213,135,6,150,4,0,32,0,115,57,50,95,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,205,142,151,4,0,32,0,115,57,50,95,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,10,154,236,214,4,0,32,0,115,57,50,95,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,103,44,237,4,0,32,0,115,57,50,95,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,14,182,246,8,3,0,16,0,115,57,50,95,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,32,22,127,5,0,64,0,115,57,50,95,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,229,173,190,5,0,64,0,54,46,97,109,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,117,162,133,58,8,0,32,0,57,46,97,109,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,47,71,86,145,8,0,32,0,56,46,97,109,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,59,8,219,236,8,0,32,0,49,48,46,97,109,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,132,131,234,143,8,0,32,0,116,108,52,109,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,189,199,175,1,0,16,1,116,108,52,109,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,196,209,44,136,1,0,16,1,117,50,50,49,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,52,113,112,209,1,0,16,1,117,49,57,53,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,102,86,29,205,1,0,16,1,115,57,50,95,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,216,176,3,4,0,32,0,115,57,50,95,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,137,2,132,4,0,32,0,115,57,50,95,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,240,181,205,4,0,32,0,115,57,50,95,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,114,148,121,226,4,0,32,0,115,57,50,95,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,39,138,186,4,0,32,0,115,57,50,95,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,191,132,229,4,0,32,0,115,57,50,95,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,125,248,227,33,4,0,32,0,115,57,50,95,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,71,252,190,4,0,32,0,115,57,50,95,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,213,135,6,150,4,0,32,0,115,57,50,95,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,205,142,151,4,0,32,0,115,57,50,95,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,10,154,236,214,4,0,32,0,115,57,50,95,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,103,44,237,4,0,32,0,115,57,50,95,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,14,182,246,8,3,0,16,0,115,57,50,95,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,32,22,127,5,0,64,0,115,57,50,95,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,229,173,190,5,0,64,0,54,46,97,109,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,117,162,133,58,8,0,32,0,57,46,97,109,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,47,71,86,145,8,0,32,0,56,46,97,109,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,59,8,219,236,8,0,32,0,49,48,46,97,109,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,132,131,234,143,8,0,32,0,116,108,52,109,116,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,202,53,134,21,1,0,16,1,116,108,52,109,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,196,209,44,136,1,0,16,1,117,50,50,49,116,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,182,183,115,16,1,0,16,1,117,49,57,53,116,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,114,31,126,219,1,0,16,1,115,57,50,95,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,216,176,3,4,0,32,0,115,57,50,95,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,137,2,132,4,0,32,0,115,57,50,95,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,240,181,205,4,0,32,0,115,57,50,95,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,114,148,121,226,4,0,32,0,115,57,50,95,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,39,138,186,4,0,32,0,115,57,50,95,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,191,132,229,4,0,32,0,115,57,50,95,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,125,248,227,33,4,0,32,0,115,57,50,95,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,71,252,190,4,0,32,0,115,57,50,95,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,213,135,6,150,4,0,32,0,115,57,50,95,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,205,142,151,4,0,32,0,115,57,50,95,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,10,154,236,214,4,0,32,0,115,57,50,95,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,103,44,237,4,0,32,0,115,57,50,95,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,14,182,246,8,3,0,16,0,115,57,50,95,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,32,22,127,5,0,64,0,115,57,50,95,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,229,173,190,5,0,64,0,54,46,97,109,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,117,162,133,58,8,0,32,0,57,46,97,109,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,47,71,86,145,8,0,32,0,56,46,97,109,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,59,8,219,236,8,0,32,0,49,48,46,97,109,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,132,131,234,143,8,0,32,0,49,55,95,51,48,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,24,109,205,211,1,0,16,1,49,55,95,51,55,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,110,113,146,232,1,0,16,1,115,102,50,117,95,51,49,98,46,49,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,61,20,115,166,1,0,16,1,115,102,50,117,95,51,56,98,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,247,206,44,76,1,0,16,1,115,102,50,117,95,50,56,98,46,57,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,94,149,9,64,1,0,16,1,115,102,50,117,95,51,53,98,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,148,57,31,140,1,0,16,1,49,55,95,50,57,46,49,48,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,77,181,48,136,1,0,16,1,49,55,95,51,54,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,163,173,19,63,1,0,16,1,115,102,50,95,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,142,204,201,34,4,0,32,0,115,102,50,95,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,232,59,33,87,4,0,32,0,115,102,50,95,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,79,155,82,186,4,0,32,0,115,102,50,95,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,51,27,75,4,0,32,0,115,102,50,95,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,41,34,126,44,4,0,32,0,115,102,50,95,49,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,23,143,84,181,4,0,32,0,115,102,50,95,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,18,67,184,20,4,0,32,0,115,102,50,95,49,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,154,216,156,94,4,0,32,0,115,102,50,95,50,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,88,250,75,153,4,0,32,0,115,102,50,95,50,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,157,173,102,62,4,0,32,0,115,102,50,95,50,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,250,190,193,4,0,32,0,115,102,50,95,50,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,49,200,39,6,4,0,32,0,115,102,50,95,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,27,58,130,164,3,0,16,0,115,102,50,95,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,32,22,127,5,0,64,0,115,102,50,95,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,229,173,190,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,115,102,51,97,45,49,46,48,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,138,5,109,158,1,0,16,1,115,102,51,97,45,51,46,48,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,4,132,141,81,1,0,16,1,115,102,51,97,45,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,30,252,164,252,1,0,16,1,115,102,51,97,45,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,84,111,221,207,1,0,16,1,115,57,50,95,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,216,176,3,4,0,32,0,115,57,50,95,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,137,2,132,4,0,32,0,115,57,50,95,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,240,181,205,4,0,32,0,115,57,50,95,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,114,148,121,226,4,0,32,0,115,57,50,95,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,39,138,186,4,0,32,0,115,57,50,95,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,191,132,229,4,0,32,0,115,57,50,95,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,125,248,227,33,4,0,32,0,115,57,50,95,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,71,252,190,4,0,32,0,115,57,50,95,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,213,135,6,150,4,0,32,0,115,57,50,95,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,205,142,151,4,0,32,0,115,57,50,95,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,10,154,236,214,4,0,32,0,115,57,50,95,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,103,44,237,4,0,32,0,115,57,50,95,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,14,182,246,8,3,0,16,0,115,57,50,95,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,32,22,127,5,0,64,0,115,57,50,95,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,229,173,190,5,0,64,0,54,46,97,109,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,117,162,133,58,8,0,32,0,57,46,97,109,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,47,71,86,145,8,0,32,0,56,46,97,109,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,59,8,219,236,8,0,32,0,49,48,46,97,109,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,132,131,234,143,8,0,32,0,117,50,50,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,154,167,54,146,1,0,16,1,117,49,57,54,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,157,134,58,178,1,0,16,1,117,50,50,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,145,224,230,100,1,0,16,1,117,49,57,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,67,68,94,201,1,0,16,1,117,55,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,31,248,160,186,4,0,32,0,117,54,56,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,90,249,223,142,4,0,32,0,117,54,57,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,177,98,137,70,4,0,32,0,117,54,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,54,245,101,129,4,0,32,0,117,49,57,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,211,99,215,57,4,0,32,0,117,49,56,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,174,66,236,147,4,0,32,0,115,57,50,95,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,14,182,246,8,3,0,16,0,115,57,50,95,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,32,22,127,5,0,64,0,115,57,50,95,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,229,173,190,5,0,64,0,115,102,49,50,45,49,46,48,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,179,92,111,236,1,0,16,1,115,102,49,50,45,51,46,48,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,43,197,154,14,1,0,16,1,115,102,49,50,45,50,46,48,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,52,113,112,209,1,0,16,1,115,102,49,50,45,52,46,48,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,102,86,29,205,1,0,16,1,115,57,50,95,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,216,176,3,4,0,32,0,115,57,50,95,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,137,2,132,4,0,32,0,115,57,50,95,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,240,181,205,4,0,32,0,115,57,50,95,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,114,148,121,226,4,0,32,0,115,57,50,95,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,39,138,186,4,0,32,0,115,57,50,95,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,191,132,229,4,0,32,0,115,57,50,95,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,125,248,227,33,4,0,32,0,115,57,50,95,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,71,252,190,4,0,32,0,115,50,116,95,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,134,38,4,60,4,0,32,0,115,50,116,95,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,131,113,126,139,4,0,32,0,115,50,116,95,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,140,136,60,41,4,0,32,0,115,50,116,95,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,164,53,43,132,4,0,32,0,115,57,50,95,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,14,182,246,8,3,0,16,0,115,57,50,95,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,32,22,127,5,0,64,0,115,57,50,95,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,229,173,190,5,0,64,0,49,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,55,250,255,25,2,0,16,1,49,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,164,204,241,153,2,0,16,1,49,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,25,199,194,101,2,0,16,1,115,57,50,45,49,109,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,216,176,3,4,0,32,0,115,57,50,45,51,109,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,137,2,132,4,0,32,0,115,57,50,45,50,109,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,240,181,205,4,0,32,0,115,57,50,45,52,109,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,114,148,121,226,4,0,32,0,115,57,50,45,53,109,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,39,138,186,4,0,32,0,115,57,50,45,55,109,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,191,132,229,4,0,32,0,115,57,50,45,54,109,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,125,248,227,33,4,0,32,0,115,57,50,45,56,109,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,71,252,190,4,0,32,0,115,57,50,45,49,48,109,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,213,135,6,150,4,0,32,0,115,57,50,45,49,50,109,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,205,142,151,4,0,32,0,115,57,50,45,49,49,109,46,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,10,154,236,214,4,0,32,0,115,57,50,45,49,51,109,46,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,103,44,237,4,0,32,0,115,57,50,95,48,57,46,49,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,14,182,246,8,3,0,16,0,115,57,50,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,32,22,127,5,0,64,0,115,57,50,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,229,173,190,5,0,64,0,116,117,114,98,111,105,105,46,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,32,228,191,155,2,0,16,1,116,117,114,98,111,105,105,46,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,25,186,87,62,2,0,16,1,116,117,114,98,111,105,105,46,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,189,134,65,237,2,0,16,1,115,57,50,95,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,216,176,3,4,0,32,0,115,57,50,95,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,137,2,132,4,0,32,0,115,57,50,95,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,240,181,205,4,0,32,0,115,57,50,95,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,114,148,121,226,4,0,32,0,115,57,50,95,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,39,138,186,4,0,32,0,115,57,50,95,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,191,132,229,4,0,32,0,115,57,50,95,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,125,248,227,33,4,0,32,0,115,57,50,95,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,71,252,190,4,0,32,0,115,57,50,95,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,213,135,6,150,4,0,32,0,115,57,50,95,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,205,142,151,4,0,32,0,115,57,50,95,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,10,154,236,214,4,0,32,0,115,57,50,95,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,103,44,237,4,0,32,0,115,57,50,95,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,14,182,246,8,3,0,16,0,115,57,50,95,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,32,22,127,5,0,64,0,115,57,50,95,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,229,173,190,5,0,64,0,115,102,50,99,97,45,50,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,47,186,195,54,2,0,16,1,115,102,50,99,97,45,50,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,61,69,80,5,2,0,16,1,115,102,50,99,97,45,50,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,186,67,28,76,2,0,16,1,115,57,50,95,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,216,176,3,4,0,32,0,115,57,50,95,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,137,2,132,4,0,32,0,115,57,50,95,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,240,181,205,4,0,32,0,115,57,50,95,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,114,148,121,226,4,0,32,0,115,57,50,95,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,39,138,186,4,0,32,0,115,57,50,95,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,191,132,229,4,0,32,0,115,57,50,95,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,125,248,227,33,4,0,32,0,115,57,50,95,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,71,252,190,4,0,32,0,115,57,50,95,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,213,135,6,150,4,0,32,0,115,57,50,95,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,205,142,151,4,0,32,0,115,57,50,95,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,10,154,236,214,4,0,32,0,115,57,50,95,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,103,44,237,4,0,32,0,115,57,50,95,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,14,182,246,8,3,0,16,0,115,57,50,95,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,32,22,127,5,0,64,0,115,57,50,95,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,229,173,190,5,0,64,0,105,99,54,50,46,54,56,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,195,129,234,133,0,0,16,1,105,99,51,53,46,54,56,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,5,150,36,210,0,0,16,1,105,99,50,49,46,122,56,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,208,100,92,217,0,0,16,1,112,114,111,116,100,97,116,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,99,33,191,236,0,0,16,1,105,99,49,48,57,46,103,102,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,131,233,134,43,0,0,32,0,105,99,49,49,51,46,103,102,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,16,102,155,227,0,0,32,0,105,99,49,49,48,46,103,102,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,21,160,164,187,0,0,32,0,105,99,49,49,49,46,103,102,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,99,59,19,97,0,0,32,0,105,99,49,48,48,46,103,102,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,42,209,195,1,0,0,32,0,105,99,49,48,54,46,103,102,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,194,42,40,219,0,0,32,0,105,99,57,57,46,103,102,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,33,248,157,52,0,0,32,0,105,99,49,48,53,46,103,102,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,28,168,202,247,0,0,32,0,105,99,49,48,52,46,103,102,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,138,211,165,81,0,0,32,0,105,99,49,48,56,46,103,102,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,14,214,83,178,0,0,32,0,105,99,49,48,50,46,103,102,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,151,254,174,60,0,0,32,0,105,99,49,48,55,46,103,102,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,152,152,16,104,0,0,32,0,105,99,54,52,46,115,110,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,156,100,96,138,0,0,64,0,56,55,99,53,50,46,109,99,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,16,21,0,0,0,255,255,127,0,0,0,0,0,22,0,0,0,255,255,223,0,0,0,0,0,0,0,0,0,254,0,2,0,232,75,4,0,21,0,0,0,1,1,1,0,96,135,7,0,21,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,8,0,72,202,5,0,21,0,0,0,1,14,4,0,192,255,2,0,21,0,0,0,1,14,8,0,208,75,4,0,21,0,0,0,1,14,0,0,8,49,4,0,21,0,0,0,1,14,14,0,152,21,4,0,21,0,0,0,1,14,6,0,72,246,3,0,21,0,0,0,1,14,10,0,72,0,3,0,21,0,0,0,1,14,2,0,64,47,7,0,21,0,0,0,1,14,12,0,232,99,5,0,0,0,0,0,254,0,8,0,32,4,2,0,21,0,0,0,1,112,0,0,104,54,4,0,21,0,0,0,1,112,64,0,80,252,6,0,21,0,0,0,1,112,32,0,16,242,7,0,21,0,0,0,1,112,96,0,104,236,7,0,21,0,0,0,1,112,112,0,128,230,7,0,21,0,0,0,1,112,80,0,120,211,6,0,21,0,0,0,1,112,48,0,184,164,6,0,21,0,0,0,1,112,16,0,80,74,6,0,0,0,0,0,254,0,2,0,168,234,7,0,21,0,0,0,1,128,128,0,96,135,7,0,21,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,16,227,4,0,22,0,0,0,1,1,1,0,96,135,7,0,22,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,80,29,8,0,22,0,0,0,1,32,32,0,72,25,8,0,22,0,0,0,1,32,0,0,56,21,8,0,0,0,0,0,254,0,2,0,0,18,8,0,22,0,0,0,1,64,64,0,48,14,8,0,22,0,0,0,1,64,0,0,200,8,8,0,0,0,0,0,254,0,2,0,56,3,8,0,22,0,0,0,1,128,0,0,248,251,7,0,22,0,0,0,1,128,128,0,72,244,7,0,21,0,0,0,255,255,255,0,0,0,0,0,22,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,0,0,144,212,8,0,21,0,0,0,1,2,2,0,96,135,7,0,21,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,0,0,232,75,4,0,21,0,0,0,1,4,4,0,96,135,7,0,21,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,21,0,0,0,1,8,0,0,96,135,7,0,21,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,2,0,200,87,7,0,21,0,0,0,1,48,0,0,40,88,7,0,21,0,0,0,1,48,16,0,96,39,7,0,21,0,0,0,1,48,48,0,144,251,6,0,21,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,21,0,0,0,1,192,0,0,40,88,7,0,21,0,0,0,1,192,64,0,96,39,7,0,21,0,0,0,1,192,192,0,144,251,6,0,21,0,0,0,1,192,128,0,184,164,6,0,0,0,0,0,254,0,4,0,72,202,5,0,22,0,0,0,1,3,2,0,80,246,3,0,22,0,0,0,1,3,3,0,80,124,6,0,22,0,0,0,1,3,1,0,112,212,3,0,22,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,64,37,5,0,22,0,0,0,1,12,12,0,240,191,4,0,22,0,0,0,1,12,8,0,144,227,4,0,22,0,0,0,1,12,4,0,32,113,6,0,22,0,0,0,1,12,0,0,32,110,6,0,0,0,0,0,254,0,4,0,128,129,4,0,22,0,0,0,1,48,0,0,192,255,2,0,22,0,0,0,1,48,16,0,208,75,4,0,22,0,0,0,1,48,48,0,8,49,4,0,22,0,0,0,1,48,32,0,152,21,4,0,101,112,114,45,46,49,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,208,201,208,165,0,0,16,1,101,112,114,45,46,49,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,92,119,230,185,0,0,16,1,101,112,114,45,54,53,53,50,46,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,216,176,238,242,0,0,16,1,101,112,114,45,54,53,53,57,46,49,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,238,112,21,90,0,0,16,1,101,112,114,45,54,53,53,56,46,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,235,234,249,42,0,0,32,0,101,112,114,45,54,53,57,50,46,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,134,219,4,120,0,0,32,0,101,112,114,45,54,53,53,54,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,247,38,253,121,0,0,32,0,101,112,114,45,54,53,57,48,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,173,140,133,191,0,0,32,0,101,112,114,45,54,53,53,52,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,5,210,201,90,0,0,32,0,101,112,114,45,54,53,56,56,46,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,187,29,147,220,0,0,32,0,101,112,114,45,54,53,52,54,46,49,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,146,86,120,164,0,0,32,0,101,112,114,45,54,53,52,56,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,193,120,242,189,0,0,32,0,101,112,114,45,54,53,52,55,46,49,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,8,27,69,52,0,0,32,0,101,112,114,45,54,53,52,57,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,104,118,5,210,0,0,32,0,112,114,45,53,51,49,55,46,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,184,80,131,100,0,0,0,8,21,0,0,0,255,255,255,0,0,0,0,0,22,0,0,0,255,255,220,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,21,0,0,0,1,15,7,0,80,252,6,0,21,0,0,0,1,15,8,0,16,242,7,0,21,0,0,0,1,15,9,0,104,236,7,0,21,0,0,0,1,15,5,0,192,54,8,0,21,0,0,0,1,15,4,0,56,24,4,0,21,0,0,0,1,15,15,0,128,230,7,0,21,0,0,0,1,15,0,0,128,230,7,0,21,0,0,0,1,15,3,0,176,162,3,0,21,0,0,0,1,15,2,0,24,188,3,0,21,0,0,0,1,15,1,0,72,216,3,0,21,0,0,0,1,15,6,0,120,211,6,0,21,0,0,0,1,15,14,0,184,164,6,0,21,0,0,0,1,15,13,0,80,74,6,0,21,0,0,0,1,15,12,0,192,32,6,0,21,0,0,0,1,15,11,0,192,234,2,0,21,0,0,0,1,15,10,0,32,242,5,0,0,0,0,0,254,0,16,0,160,123,6,0,21,0,0,0,1,240,112,0,80,252,6,0,21,0,0,0,1,240,128,0,16,242,7,0,21,0,0,0,1,240,144,0,104,236,7,0,21,0,0,0,1,240,80,0,192,54,8,0,21,0,0,0,1,240,64,0,56,24,4,0,21,0,0,0,1,240,240,0,128,230,7,0,21,0,0,0,1,240,0,0,128,230,7,0,21,0,0,0,1,240,48,0,176,162,3,0,21,0,0,0,1,240,32,0,24,188,3,0,21,0,0,0,1,240,16,0,72,216,3,0,21,0,0,0,1,240,96,0])
.concat([120,211,6,0,21,0,0,0,1,240,224,0,184,164,6,0,21,0,0,0,1,240,208,0,80,74,6,0,21,0,0,0,1,240,192,0,192,32,6,0,21,0,0,0,1,240,176,0,192,234,2,0,21,0,0,0,1,240,160,0,32,242,5,0,0,0,0,0,254,0,2,0,200,30,2,0,22,0,0,0,1,1,0,0,120,97,1,0,22,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,2,0,168,234,7,0,22,0,0,0,1,2,2,0,96,135,7,0,22,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,22,0,0,0,1,12,8,0,208,75,4,0,22,0,0,0,1,12,12,0,8,49,4,0,22,0,0,0,1,12,4,0,152,21,4,0,22,0,0,0,1,12,0,0,40,130,6,0,0,0,0,0,254,0,2,0,64,37,5,0,22,0,0,0,1,16,16,0,176,136,5,0,22,0,0,0,1,16,0,0,120,132,5,0,0,0,0,0,254,0,2,0,104,159,3,0,22,0,0,0,1,32,32,0,96,135,7,0,22,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,72,202,5,0,22,0,0,0,1,64,64,0,80,246,3,0,22,0,0,0,1,64,0,0,112,212,3,0,17,0,0,0,255,255,255,0,0,0,0,0,18,0,0,0,255,255,63,0,0,0,0,0,0,0,0,0,254,0,2,0,232,75,4,0,17,0,0,0,1,1,1,0,96,135,7,0,17,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,80,3,0,17,0,0,0,1,2,2,0,96,135,7,0,17,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,17,0,0,0,1,12,4,0,208,75,4,0,17,0,0,0,1,12,12,0,8,49,4,0,17,0,0,0,1,12,8,0,152,21,4,0,17,0,0,0,1,12,0,0,72,246,3,0,0,0,0,0,254,0,4,0,0,70,2,0,17,0,0,0,1,48,0,0,176,193,3,0,17,0,0,0,1,48,32,0,208,196,4,0,17,0,0,0,1,48,16,0,56,233,4,0,17,0,0,0,1,48,48,0,16,42,5,0,0,0,0,0,254,0,4,0,192,56,2,0,17,0,0,0,1,192,0,0,56,233,4,0,17,0,0,0,1,192,192,0,16,42,5,0,17,0,0,0,1,192,64,0,152,11,5,0,17,0,0,0,1,192,128,0,24,27,4,0,0,0,0,0,254,0,2,0,72,217,6,0,18,0,0,0,1,1,0,0,56,111,3,0,18,0,0,0,1,1,1,0,104,134,3,0,0,0,0,0,254,0,4,0,72,202,5,0,18,0,0,0,1,6,2,0,80,246,3,0,18,0,0,0,1,6,6,0,248,38,7,0,18,0,0,0,1,6,4,0,112,212,3,0,18,0,0,0,1,6,0,0,144,196,4,0,0,0,0,0,254,0,8,0,40,148,2,0,18,0,0,0,1,56,56,0,208,98,2,0,18,0,0,0,1,56,24,0,208,168,3,0,18,0,0,0,1,56,40,0,176,109,2,0,18,0,0,0,1,56,8,0,88,229,1,0,18,0,0,0,1,56,48,0,176,123,2,0,18,0,0,0,1,56,16,0,184,202,1,0,18,0,0,0,1,56,32,0,176,225,8,0,18,0,0,0,1,56,0,0,120,7,5,0,0,0,0,0,254,0,3,0,200,30,2,0,18,0,0,0,1,192,0,0,128,217,8,0,18,0,0,0,1,192,64,0,192,208,8,0,18,0,0,0,1,192,192,0,96,19,1,0,102,98,49,52,45,51,46,49,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,144,172,230,155,0,0,16,1,102,98,49,50,45,51,46,57,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,107,75,144,40,0,0,16,1,102,98,49,53,46,49,57,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,108,178,107,16,0,0,16,1,102,98,49,51,46,49,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,19,52,82,144,0,0,16,1,102,97,49,48,46,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,37,255,210,223,0,0,16,1,102,97,48,53,46,49,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,36,41,128,9,0,0,32,0,102,97,48,52,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,149,184,37,236,0,0,32,0,102,97,48,55,46,49,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,139,38,50,233,0,0,32,0,102,97,48,54,46,49,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,192,56,221,196,0,0,32,0,102,97,48,57,46,50,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,190,233,149,19,0,0,32,0,102,97,48,56,46,50,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,219,100,116,77,0,0,32,0,102,97,48,49,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,146,205,176,153,0,0,32,0,102,97,48,51,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,77,167,126,14,0,0,32,0,102,97,48,48,46,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,215,63,223,247,0,0,32,0,102,97,48,50,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,157,218,232,132,0,0,32,0,102,97,49,49,46,49,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,173,123,84,78,0,0,64,0,109,98,55,49,49,52,104,46,50,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,212,232,38,173,0,0,0,8,16,0,0,0,255,255,255,0,0,0,0,0,17,0,0,0,255,255,247,0,0,0,0,0,16,0,0,0,254,0,4,0,72,84,4,0,16,0,0,0,1,3,3,0,16,208,8,0,16,0,0,0,1,3,2,0,248,81,6,0,16,0,0,0,1,3,1,0,176,64,8,0,16,0,0,0,1,3,0,0,128,65,6,0,16,0,0,0,254,0,4,0,208,128,1,0,16,0,0,0,1,12,12,0,192,255,2,0,16,0,0,0,1,12,8,0,208,75,4,0,16,0,0,0,1,12,4,0,8,49,4,0,16,0,0,0,1,12,0,0,152,21,4,0,16,0,0,0,254,0,4,0,128,129,4,0,16,0,0,0,1,48,32,0,8,49,4,0,16,0,0,0,1,48,16,0,152,21,4,0,16,0,0,0,1,48,48,0,72,246,3,0,16,0,0,0,1,48,0,0,72,0,3,0,16,0,0,0,254,0,4,0,32,4,2,0,16,0,0,0,1,192,0,0,240,12,2,0,16,0,0,0,1,192,64,0,160,36,8,0,16,0,0,0,1,192,192,0,208,239,7,0,16,0,0,0,1,192,128,0,120,187,7,0,17,0,0,0,254,0,2,0,232,75,4,0,17,0,0,0,1,1,1,0,96,135,7,0,17,0,0,0,1,1,0,0,152,182,7,0,17,0,0,0,254,0,4,0,16,227,7,0,17,0,0,0,1,6,6,0,168,223,7,0,17,0,0,0,1,6,4,0,144,219,7,0,17,0,0,0,1,6,2,0,200,215,7,0,17,0,0,0,1,6,0,0,48,210,7,0,17,0,0,0,254,0,8,0,128,112,3,0,17,0,0,0,1,56,56,0,72,93,8,0,17,0,0,0,1,56,48,0,168,22,4,0,17,0,0,0,1,56,40,0,224,247,3,0,17,0,0,0,1,56,32,0,72,180,7,0,17,0,0,0,1,56,24,0,176,176,7,0,17,0,0,0,1,56,16,0,72,93,8,0,17,0,0,0,1,56,8,0,72,93,8,0,17,0,0,0,1,56,0,0,72,93,8,0,17,0,0,0,254,0,2,0,176,172,7,0,17,0,0,0,1,64,0,0,40,71,8,0,17,0,0,0,1,64,64,0,144,68,8,0,17,0,0,0,254,0,2,0,128,159,7,0,17,0,0,0,1,128,0,0,40,71,8,0,17,0,0,0,1,128,128,0,144,68,8,0,0,0,0,0,16,0,0,0,255,255,255,0,0,0,0,0,17,0,0,0,255,255,221,0,0,0,0,0,0,0,0,0,254,0,4,0,72,84,4,0,16,0,0,0,1,3,3,0,16,208,8,0,16,0,0,0,1,3,2,0,248,81,6,0,16,0,0,0,1,3,1,0,176,64,8,0,16,0,0,0,1,3,0,0,128,65,6,0,16,0,0,0,254,0,4,0,208,128,1,0,16,0,0,0,1,12,12,0,192,255,2,0,16,0,0,0,1,12,8,0,208,75,4,0,16,0,0,0,1,12,4,0,8,49,4,0,16,0,0,0,1,12,0,0,152,21,4,0,16,0,0,0,254,0,4,0,128,129,4,0,16,0,0,0,1,48,32,0,8,49,4,0,16,0,0,0,1,48,16,0,152,21,4,0,16,0,0,0,1,48,48,0,72,246,3,0,16,0,0,0,1,48,0,0,72,0,3,0,16,0,0,0,254,0,4,0,32,4,2,0,16,0,0,0,1,192,0,0,240,12,2,0,16,0,0,0,1,192,64,0,160,36,8,0,16,0,0,0,1,192,192,0,208,239,7,0,16,0,0,0,1,192,128,0,120,187,7,0,17,0,0,0,254,0,2,0,232,75,4,0,17,0,0,0,1,1,1,0,96,135,7,0,17,0,0,0,1,1,0,0,152,182,7,0,17,0,0,0,254,0,2,0,168,234,7,0,17,0,0,0,1,2,2,0,96,135,7,0,17,0,0,0,1,2,0,0,152,182,7,0,17,0,0,0,254,0,2,0,128,112,3,0,17,0,0,0,1,32,0,0,168,22,4,0,17,0,0,0,1,32,32,0,72,93,8,0,17,0,0,0,254,0,2,0,128,159,7,0,17,0,0,0,1,128,0,0,40,71,8,0,17,0,0,0,1,128,128,0,144,68,8,0,18,0,0,0,255,255,255,0,0,0,0,0,19,0,0,0,255,255,223,0,0,0,0,0,0,0,0,0,254,0,16,0,160,123,6,0,18,0,0,0,1,15,4,0,32,136,7,0,18,0,0,0,1,15,10,0,40,88,7,0,18,0,0,0,1,15,1,0,96,39,7,0,18,0,0,0,1,15,0,0,192,24,7,0,18,0,0,0,1,15,2,0,120,113,6,0,18,0,0,0,1,15,8,0,232,228,5,0,18,0,0,0,1,15,15,0,144,251,6,0,18,0,0,0,1,15,12,0,56,141,7,0,18,0,0,0,1,15,14,0,120,211,6,0,18,0,0,0,1,15,7,0,184,164,6,0,18,0,0,0,1,15,6,0,24,1,7,0,18,0,0,0,1,15,11,0,80,74,6,0,18,0,0,0,1,15,3,0,192,32,6,0,18,0,0,0,1,15,13,0,192,234,2,0,18,0,0,0,1,15,5,0,32,242,5,0,18,0,0,0,1,15,9,0,176,192,2,0,0,0,0,0,254,0,16,0,200,87,7,0,18,0,0,0,1,240,64,0,32,136,7,0,18,0,0,0,1,240,160,0,40,88,7,0,18,0,0,0,1,240,16,0,96,39,7,0,18,0,0,0,1,240,32,0,120,113,6,0,18,0,0,0,1,240,128,0,232,228,5,0,18,0,0,0,1,240,240,0,144,251,6,0,18,0,0,0,1,240,192,0,56,141,7,0,18,0,0,0,1,240,224,0,120,211,6,0,18,0,0,0,1,240,112,0,184,164,6,0,18,0,0,0,1,240,96,0,24,1,7,0,18,0,0,0,1,240,176,0,80,74,6,0,18,0,0,0,1,240,48,0,192,32,6,0,18,0,0,0,1,240,208,0,192,234,2,0,18,0,0,0,1,240,80,0,32,242,5,0,18,0,0,0,1,240,144,0,176,192,2,0,18,0,0,0,1,240,0,0,16,227,4,0,0,0,0,0,254,0,4,0,128,129,4,0,19,0,0,0,1,3,2,0,208,75,4,0,19,0,0,0,1,3,3,0,8,49,4,0,19,0,0,0,1,3,1,0,152,21,4,0,19,0,0,0,1,3,0,0,72,0,3,0,0,0,0,0,254,0,2,0,104,159,3,0,19,0,0,0,1,32,32,0,56,111,3,0,19,0,0,0,1,32,0,0,104,134,3,0,115,49,46,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,170,204,53,234,1,0,16,1,115,50,46,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,179,161,187,231,1,0,16,1,115,51,46,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,62,252,215,18,1,0,16,1,115,52,46,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,235,96,147,181,1,0,16,1,115,53,46,50,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,28,169,25,73,1,0,16,1,115,54,46,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,123,84,164,38,1,0,16,1,115,55,46,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,112,148,180,11,1,0,16,1,115,56,46,50,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,229,64,87,106,1,0,16,1,111,116,49,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,240,151,210,188,2,0,16,1,111,116,50,46,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,218,18,121,222,2,0,16,1,111,116,51,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,51,169,47,186,2,0,16,1,99,50,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,91,132,8,71,4,0,32,0,99,49,46,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,135,40,253,17,4,0,32,0,99,48,49,115,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,171,174,60,78,7,0,32,0,18,0,0,0,255,255,0,0,0,0,0,0,19,0,0,0,255,255,3,0,0,0,0,0,20,0,0,0,255,255,14,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,19,0,0,0,1,3,3,0,8,49,4,0,19,0,0,0,1,3,2,0,152,21,4,0,19,0,0,0,1,3,1,0,72,246,3,0,19,0,0,0,1,3,0,0,200,28,2,0,0,0,0,0,254,0,4,0,32,4,2,0,20,0,0,0,1,6,6,0,136,178,1,0,20,0,0,0,1,6,4,0,144,177,1,0,20,0,0,0,1,6,2,0,176,176,1,0,20,0,0,0,1,6,0,0,248,175,1,0,0,0,0,0,254,0,2,0,200,30,2,0,20,0,0,0,1,8,8,0,120,97,1,0,20,0,0,0,1,8,0,0,96,19,1,0,115,99,114,97,109,98,108,101,46,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,74,92,2,158,1,0,16,1,115,99,114,97,109,98,108,101,46,50,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,62,120,111,48,1,0,16,1,115,99,114,97,109,98,108,101,46,51,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,1,183,0,5,1,0,16,1,115,99,114,97,109,98,108,101,46,52,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,34,10,56,221,1,0,16,1,115,99,114,97,109,98,108,101,46,53,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,72,150,11,223,1,0,16,1,115,99,114,97,109,98,108,101,46,49,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,60,123,192,184,1,0,16,1,115,99,114,97,109,98,108,101,46,50,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,160,7,172,136,1,0,16,1,115,99,114,97,109,98,108,101,46,51,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,202,87,125,198,1,0,16,1,53,102,46,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,91,132,8,71,4,0,32,0,53,104,46,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,135,40,253,17,4,0,32,0,56,50,115,49,50,51,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,171,174,60,78,7,0,32,0,16,0,0,0,255,255,0,0,0,0,0,0,17,0,0,0,255,255,0,0,0,0,0,0,18,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,17,0,0,0,1,64,0,0,120,97,1,0,17,0,0,0,1,64,64,0,96,19,1,0,0,0,0,0,254,0,4,0,32,4,2,0,18,0,0,0,1,3,0,0,128,103,7,0,18,0,0,0,1,3,1,0,80,196,7,0,18,0,0,0,1,3,2,0,0,90,2,0,18,0,0,0,1,3,3,0,72,74,2,0,0,0,0,0,254,0,4,0,128,129,4,0,18,0,0,0,1,12,0,0,8,49,4,0,18,0,0,0,1,12,4,0,152,21,4,0,18,0,0,0,1,12,8,0,72,246,3,0,18,0,0,0,1,12,12,0,200,28,2,0,16,0,0,0,255,255,255,0,0,0,0,0,17,0,0,0,255,255,93,0,0,0,0,0,18,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,16,0,0,0,1,15,2,0,32,136,7,0,16,0,0,0,1,15,5,0,40,88,7,0,16,0,0,0,1,15,8,0,96,39,7,0,16,0,0,0,1,15,4,0,120,113,6,0,16,0,0,0,1,15,1,0,232,228,5,0,16,0,0,0,1,15,15,0,144,251,6,0,16,0,0,0,1,15,3,0,56,141,7,0,16,0,0,0,1,15,7,0,120,211,6,0,16,0,0,0,1,15,14,0,184,164,6,0,16,0,0,0,1,15,6,0,24,1,7,0,16,0,0,0,1,15,13,0,80,74,6,0,16,0,0,0,1,15,12,0,192,32,6,0,16,0,0,0,1,15,11,0,192,234,2,0,16,0,0,0,1,15,10,0,32,242,5,0,16,0,0,0,1,15,9,0,176,192,2,0,16,0,0,0,1,15,0,0,224,170,7,0,0,0,0,0,254,0,16,0,160,123,6,0,16,0,0,0,1,240,32,0,32,136,7,0,16,0,0,0,1,240,80,0,40,88,7,0,16,0,0,0,1,240,128,0,96,39,7,0,16,0,0,0,1,240,64,0,120,113,6,0,16,0,0,0,1,240,16,0,232,228,5,0,16,0,0,0,1,240,240,0,144,251,6,0,16,0,0,0,1,240,48,0,56,141,7,0,16,0,0,0,1,240,112,0,120,211,6,0,16,0,0,0,1,240,224,0,184,164,6,0,16,0,0,0,1,240,96,0,24,1,7,0,16,0,0,0,1,240,208,0,80,74,6,0,16,0,0,0,1,240,192,0,192,32,6,0,16,0,0,0,1,240,176,0,192,234,2,0,16,0,0,0,1,240,160,0,32,242,5,0,16,0,0,0,1,240,144,0,176,192,2,0,16,0,0,0,1,240,0,0,224,170,7,0,0,0,0,0,254,0,4,0,128,129,4,0,17,0,0,0,1,3,3,0,208,75,4,0,17,0,0,0,1,3,2,0,8,49,4,0,17,0,0,0,1,3,1,0,152,21,4,0,17,0,0,0,1,3,0,0,72,246,3,0,0,0,0,0,254,0,2,0,64,37,5,0,17,0,0,0,1,8,8,0,48,46,1,0,17,0,0,0,1,8,0,0,32,55,5,0,0,0,0,0,254,0,4,0,72,202,5,0,17,0,0,0,1,48,48,0,80,246,3,0,17,0,0,0,1,48,32,0,248,38,7,0,17,0,0,0,1,48,16,0,48,123,8,0,17,0,0,0,1,48,0,0,8,117,8,0,0,0,0,0,254,0,2,0,168,234,7,0,17,0,0,0,1,128,128,0,96,135,7,0,17,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,18,0,0,0,1,1,1,0,96,135,7,0,18,0,0,0,1,1,0,0,152,182,7,0,49,46,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,180,25,18,186,1,0,16,1,50,46,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,182,154,144,195,1,0,16,1,51,46,50,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,82,19,38,67,1,0,16,1,52,46,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,106,39,162,171,1,0,16,1,53,46,50,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,242,120,47,149,1,0,16,1,105,103,114,95,115,99,111,114,112,105,111,110,95,51,50,95,97,52,46,105,99,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,54,138,27,54,2,0,16,1,105,103,114,95,115,99,111,114,112,105,111,110,95,51,50,95,97,53,46,105,99,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,212,205,222,173,2,0,16,1,105,103,114,95,115,99,111,114,112,105,111,110,95,51,50,95,102,53,46,105,99,55,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,214,169,93,30,4,0,32,0,105,103,114,95,115,99,111,114,112,105,111,110,95,51,50,95,104,53,46,105,99,55,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,10,219,122,165,4,0,32,0,109,109,105,54,51,51,49,95,54,101,46,105,99,53,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,171,174,60,78,7,0,32,0,105,103,114,95,115,99,111,114,112,105,111,110,95,51,50,95,97,51,46,105,99,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,120,241,171,4,0,0,64,8,105,103,114,95,115,99,111,114,112,105,111,110,95,51,50,95,97,50,46,105,99,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,212,45,53,144,0,0,64,8,105,103,114,95,115,99,111,114,112,105,111,110,95,51,50,95,97,49,46,105,99,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,45,69,242,59,0,0,64,8,17,0,0,0,255,255,0,0,0,0,0,0,18,0,0,0,255,255,0,0,0,0,0,0,19,0,0,0,255,255,4,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,18,0,0,0,1,4,0,0,8,49,4,0,18,0,0,0,1,4,1,0,152,21,4,0,18,0,0,0,1,4,2,0,72,246,3,0,18,0,0,0,1,4,3,0,200,28,2,0,0,0,0,0,254,0,2,0,200,30,2,0,19,0,0,0,1,4,4,0,120,97,1,0,19,0,0,0,1,4,0,0,96,19,1,0,0,0,0,0,254,0,2,0,32,4,2,0,19,0,0,0,1,8,0,0,16,223,1,0,19,0,0,0,1,8,8,0,80,221,1,0,0,0,0,0,254,0,4,0,72,202,5,0,19,0,0,0,1,160,0,0,248,38,7,0,19,0,0,0,1,160,32,0,80,124,6,0,19,0,0,0,1,160,128,0,112,212,3,0,19,0,0,0,1,160,160,0,24,99,5,0,0,0,0,0,101,112,114,49,50,54,53,46,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,63,75,116,160,1,0,16,1,101,112,114,49,50,54,54,46,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,121,98,48,101,1,0,16,1,101,112,114,49,50,54,55,46,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,251,230,164,71,1,0,16,1,101,112,114,49,50,54,56,46,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,242,202,238,83,1,0,16,1,101,112,114,49,50,54,57,46,50,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,1,168,248,225,1,0,16,1,101,112,114,49,50,55,48,46,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,16,151,112,247,1,0,16,1,101,112,114,49,50,55,53,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,211,13,235,222,2,0,16,1,101,112,114,49,50,55,54,46,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,116,26,44,135,2,0,16,1,101,112,114,49,50,55,55,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,16,161,215,204,2,0,16,1,101,112,114,49,50,55,52,46,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,180,19,209,100,4,0,32,0,101,112,114,49,50,55,51,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,211,22,99,169,4,0,32,0,112,114,49,50,55,56,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,97,197,53,253,7,0,32,0,105,99,51,55,46,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,156,21,251,51,2,0,16,1,105,99,52,48,46,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,242,243,125,101,2,0,16,1,105,99,51,56,46,52,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,11,185,9,10,2,0,16,1,105,99,52,49,46,51,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,42,123,22,67,2,0,16,1,99,48,57,45,51,51,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,91,108,78,207,6,0,16,1,99,48,57,45,51,50,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,25,55,113,164,6,0,16,1,99,48,57,45,50,55,46,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,202,29,22,205,9,0,16,1,99,48,57,45,48,53,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,240,56,11,137,11,0,32,0,99,48,57,45,48,52,46,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,155,60,187,44,17,0,32,0,99,48,57,45,48,50,46,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,137,3,58,168,17,0,32,0,99,48,57,45,48,51,46,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,128,14,29,163,17,0,32,0,99,48,57,45,48,49,46,53,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,16,234,191,100,17,0,32,0,99,48,57,45,48,55,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,43,200,59,150,22,0,32,0,99,48,57,45,48,54,46,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,123,109,223,18,23,0,32,0,99,48,57,45,49,48,46,52,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,70,191,120,173,24,0,64,0,99,48,57,45,48,57,46,52,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,92,101,106,24,0,64,0,99,48,57,45,48,56,46,52,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,22,195,223,125,24,0,64,0,99,48,57,45,49,49,46,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,225,17,26,107,25,0,64,0,99,48,57,45,49,54,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,246,166,69,114,0,0,0,8,99,48,57,45,50,48,46,55,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,128,253,143,205,0,0,0,8,99,48,57,45,50,51,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,48,31,248,251,0,0,0,8,20,0,0,0,255,255,255,0,0,0,0,0,21,0,0,0,255,255,255,0,0,0,0,0,22,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,8,0,200,87,7,0,20,0,0,0,1,7,0,0,40,88,7,0,20,0,0,0,1,7,1,0,96,39,7,0,20,0,0,0,1,7,7,0,144,251,6,0,20,0,0,0,1,7,6,0,184,164,6,0,20,0,0,0,1,7,5,0,80,74,6,0,20,0,0,0,1,7,4,0,192,32,6,0,20,0,0,0,1,7,3,0,192,234,2,0,20,0,0,0,1,7,2,0,32,242,5,0,0,0,0,0,254,0,8,0,160,123,6,0,20,0,0,0,1,56,0,0,40,88,7,0,20,0,0,0,1,56,8,0,96,39,7,0,20,0,0,0,1,56,56,0,144,251,6,0,20,0,0,0,1,56,48,0,184,164,6,0,20,0,0,0,1,56,40,0,80,74,6,0,20,0,0,0,1,56,32,0,192,32,6,0,20,0,0,0,1,56,24,0,192,234,2,0,20,0,0,0,1,56,16,0,32,242,5,0,0,0,0,0,254,0,2,0,144,212,8,0,20,0,0,0,1,64,64,0,96,135,7,0,20,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,20,0,0,0,1,128,128,0,96,135,7,0,20,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,21,0,0,0,1,4,0,0,96,135,7,0,21,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,254,0,2,0,224,173,8,0,22,0,0,0,1,32,32,0,96,135,7,0,22,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,98,98,98,45,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,42,21,4,243,0,0,16,1,98,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,177,142,17,19,0,0,16,1,98,98,98,45,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,145,85,199,148,0,0,16,1,97,55,56,45,48,56,46,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,123,160,17,174,0,0,16,1,97,55,56,45,48,55,46,52,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,232,38,154,79,0,0,16,1,97,55,56,45,48,57,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,34,140,53,32,0,0,32,0,97,55,56,45,49,48,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,169,104,1,147,0,0,32,0,97,55,56,45,49,49,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,18,229,115,151,0,0,32,0,97,55,56,45,49,50,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,155,84,69,208,0,0,32,0,97,55,56,45,49,51,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,197,53,175,208,0,0,32,0,97,55,56,45,49,52,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,168,105,83,123,0,0,32,0,97,55,56,45,49,53,46,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,19,164,97,107,0,0,32,0,97,55,56,45,49,54,46,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,151,45,73,181,0,0,32,0,97,55,56,45,49,55,46,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,213,98,151,214,0,0,32,0,97,55,56,45,49,56,46,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,104,59,36,159,0,0,32,0,97,55,56,45,49,57,46,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,140,67,233,102,0,0,32,0,97,55,56,45,50,48,46,51,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,173,99,248,158,0,0,32,0,97,55,49,45,50,53,46,52,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,69,133,15,45,0,0,32,0,15,0,0,0,255,255,254,0,0,0,0,0,16,0,0,0,255,255,63,0,0,0,0,0,0,0,0,0,254,0,2,0,32,182,8,0,15,0,0,0,1,1,1,0,64,17,8,0,15,0,0,0,1,1,0,0,24,13,8,0,0,0,0,0,254,0,2,0,144,212,8,0,15,0,0,0,1,2,2,0,96,135,7,0,15,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,15,0,0,0,1,4,4,0,96,135,7,0,15,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,15,0,0,0,1,8,0,0,96,135,7,0,15,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,15,0,0,0,1,48,16,0,224,127,8,0,15,0,0,0,1,48,48,0,32,123,8,0,15,0,0,0,1,48,0,0,248,116,8,0,15,0,0,0,1,48,32,0,192,110,8,0,0,0,0,0,254,0,4,0,160,123,6,0,15,0,0,0,1,192,64,0,224,127,8,0,15,0,0,0,1,192,192,0,32,123,8,0,15,0,0,0,1,192,0,0,248,116,8,0,15,0,0,0,1,192,128,0,192,110,8,0,0,0,0,0,254,0,4,0,72,202,5,0,16,0,0,0,1,3,2,0,80,246,3,0,16,0,0,0,1,3,3,0,248,38,7,0,16,0,0,0,1,3,1,0,112,212,3,0,16,0,0,0,1,3,0,0,24,99,5,0,0,0,0,0,254,0,4,0,64,37,5,0,16,0,0,0,1,12,8,0,24,71,8,0,16,0,0,0,1,12,12,0,128,68,8,0,16,0,0,0,1,12,4,0,0,65,8,0,16,0,0,0,1,12,0,0,184,59,8,0,0,0,0,0,254,0,4,0,128,129,4,0,16,0,0,0,1,48,16,0,192,255,2,0,16,0,0,0,1,48,0,0,208,75,4,0,16,0,0,0,1,48,48,0,8,49,4,0,16,0,0,0,1,48,32,0,72,246,3,0,0,0,0,0,254,0,4,0,96,33,8,0,16,0,0,0,1,192,0,0,248,38,7,0,16,0,0,0,1,192,64,0,80,124,6,0,16,0,0,0,1,192,128,0,64,111,3,0,16,0,0,0,1,192,192,0,152,20,8,0,49,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,42,21,4,243,0,0,16,1,49,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,156,32,101,8,0,0,16,1,49,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,192,181,41,31,0,0,16,1,49,101,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,123,160,17,174,0,0,16,1,49,100,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,232,38,154,79,0,0,16,1,49,108,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,34,140,53,32,0,0,32,0,49,109,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,169,104,1,147,0,0,32,0,49,110,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,18,229,115,151,0,0,32,0,49,111,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,155,84,69,208,0,0,32,0,49,112,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,197,53,175,208,0,0,32,0,49,113,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,168,105,83,123,0,0,32,0,49,102,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,19,164,97,107,0,0,32,0,49,103,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,151,45,73,181,0,0,32,0,49,104,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,213,98,151,214,0,0,32,0,49,105,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,104,59,36,159,0,0,32,0,49,106,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,140,67,233,102,0,0,32,0,49,107,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,173,99,248,158,0,0,32,0,97,55,49,45,50,53,46,52,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,69,133,15,45,0,0,32,0,168,86,7,0,1,0,0,0,32,1,147,0,248,191,2,0,24,38,7,0,1,0,0,0,33,1,147,0,184,160,2,0,56,210,6,0,1,0,0,0,38,1,147,0,192,135,2,0,24,163,6,0,1,0,0,0,39,1,147,0,240,108,2,0,152,122,6,0,1,0,0,0,36,1,147,0,96,82,2,0,192,72,6,0,1,0,0,0,37,1,147,0,32,56,2,0,200,110,3,0,1,0,0,0,35,1,147,0,152,30,2,0,120,89,3,0,1,0,0,0,34,1,147,0,232,10,2,0,40,246,1,0,1,0,0,0,120,248,146,0,64,246,1,0,144,236,1,0,1,0,0,0,121,248,146,0,136,224,1,0,176,223,1,0,1,0,0,0,126,248,146,0,72,198,1,0,192,209,1,0,1,0,0,0,127,248,146,0,24,182,1,0,24,198,1,0,1,0,0,0,124,248,146,0,40,167,1,0,120,189,1,0,1,0,0,0,125,248,146,0,200,149,1,0,224,22,1,0,1,0,0,0,123,248,146,0,56,126,1,0,160,14,1,0,1,0,0,0,122,248,146,0,32,101,1,0,88,212,3,0,1,0,0,0,128,220,146,0,40,185,3,0,72,65,1,0,9,0,0,0,128,6,147,0,32,58,1,0,48,50,1,0,9,0,0,0,129,6,147,0,32,58,1,0,19,0,0,0,255,255,1,0,0,0,0,0,20,0,0,0,255,255,0,0,0,0,0,0,21,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,19,0,0,0,1,1,1,0,120,97,1,0,19,0,0,0,1,1,0,0,96,19,1,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,2,0,0,96,135,7,0,19,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,8,8,0,96,135,7,0,19,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,3,1,0,80,246,3,0,20,0,0,0,1,3,0,0,80,124,6,0,20,0,0,0,1,3,2,0,112,212,3,0,20,0,0,0,1,3,3,0,248,160,5,0,0,0,0,0,254,0,4,0,64,37,5,0,20,0,0,0,1,12,4,0,112,37,5,0,20,0,0,0,1,12,0,0,192,7,5,0,20,0,0,0,1,12,8,0,208,227,4,0,20,0,0,0,1,12,12,0,120,7,5,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,48,48,0,208,75,4,0,20,0,0,0,1,48,0,0,8,49,4,0,20,0,0,0,1,48,32,0,152,21,4,0,20,0,0,0,1,48,16,0,72,246,3,0,0,0,0,0,254,0,2,0,144,246,3,0,20,0,0,0,1,64,0,0,96,135,7,0,20,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,20,0,0,0,1,128,128,0,56,111,3,0,20,0,0,0,1,128,0,0,104,134,3,0,0,0,0,0,19,0,0,0,255,255,1,0,0,0,0,0,20,0,0,0,255,255,0,0,0,0,0,0,21,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,19,0,0,0,1,1,1,0,120,97,1,0,19,0,0,0,1,1,0,0,96,19,1,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,2,0,0,96,135,7,0,19,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,8,8,0,96,135,7,0,19,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,3,1,0,80,246,3,0,20,0,0,0,1,3,0,0,80,124,6,0,20,0,0,0,1,3,2,0,112,212,3,0,20,0,0,0,1,3,3,0,248,160,5,0,0,0,0,0,254,0,4,0,64,37,5,0,20,0,0,0,1,12,4,0,112,37,5,0,20,0,0,0,1,12,0,0,192,7,5,0,20,0,0,0,1,12,8,0,208,227,4,0,20,0,0,0,1,12,12,0,120,7,5,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,48,48,0,208,75,4,0,20,0,0,0,1,48,0,0,8,49,4,0,20,0,0,0,1,48,32,0,152,21,4,0,20,0,0,0,1,48,16,0,72,246,3,0,0,0,0,0,254,0,2,0,144,246,3,0,20,0,0,0,1,64,0,0,96,135,7,0,20,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,20,0,0,0,1,128,128,0,56,111,3,0,20,0,0,0,1,128,0,0,104,134,3,0,0,0,0,0,254,0,2,0,32,160,3,0,21,0,0,0,1,1,1,0,56,111,3,0,21,0,0,0,1,1,0,0,104,134,3,0,18,0,0,0,255,255,255,0,0,0,0,0,19,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,128,112,3,0,18,0,0,0,1,2,2,0,224,247,3,0,18,0,0,0,1,2,0,0,168,22,4,0,0,0,0,0,254,0,4,0,72,202,5,0,18,0,0,0,1,12,8,0,80,246,3,0,18,0,0,0,1,12,12,0,248,38,7,0,18,0,0,0,1,12,4,0,112,212,3,0,18,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,4,0,128,129,4,0,18,0,0,0,1,192,0,0,192,255,2,0,18,0,0,0,1,192,64,0,208,75,4,0,18,0,0,0,1,192,192,0,8,49,4,0,18,0,0,0,1,192,128,0,152,21,4,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,2,0,0,96,135,7,0,19,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,8,0,160,123,6,0,19,0,0,0,1,28,16,0,32,136,7,0,19,0,0,0,1,28,8,0,40,88,7,0,19,0,0,0,1,28,24,0,96,39,7,0,19,0,0,0,1,28,28,0,144,251,6,0,19,0,0,0,1,28,12,0,184,164,6,0,19,0,0,0,1,28,20,0,80,74,6,0,19,0,0,0,1,28,4,0,192,32,6,0,19,0,0,0,1,28,0,0,16,227,4,0,0,0,0,0,254,0,8,0,200,87,7,0,19,0,0,0,1,224,128,0,32,136,7,0,19,0,0,0,1,224,64,0,40,88,7,0,19,0,0,0,1,224,192,0,96,39,7,0,19,0,0,0,1,224,224,0,144,251,6,0,19,0,0,0,1,224,96,0,184,164,6,0,19,0,0,0,1,224,160,0,80,74,6,0,19,0,0,0,1,224,32,0,192,32,6,0,19,0,0,0,1,224,0,0,16,227,4,0,20,0,0,0,255,255,96,0,0,0,0,0,21,0,0,0,255,255,1,0,0,0,0,0,0,0,0,0,254,0,2,0,232,75,4,0,20,0,0,0,1,32,32,0,96,135,7,0,20,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,192,3,0,20,0,0,0,1,64,64,0,96,135,7,0,20,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,48,45,3,0,21,0,0,0,1,3,0,0,176,20,3,0,21,0,0,0,1,3,2,0,240,94,3,0,21,0,0,0,1,3,1,0,56,80,3,0,184,40,2,0,1,0,0,0,208,155,215,0,248,191,2,0,56,250,6,0,1,0,0,0,212,155,215,0,184,160,2,0,184,164,8,0,1,0,0,0,209,155,215,0,64,246,1,0,88,149,7,0,1,0,0,0,213,155,215,0,136,224,1,0,56,210,6,0,1,0,0,0,205,155,215,0,192,135,2,0,24,163,6,0,1,0,0,0,204,155,215,0,240,108,2,0,152,122,6,0,1,0,0,0,207,155,215,0,96,82,2,0,192,72,6,0,1,0,0,0,206,155,215,0,32,56,2,0,48,123,2,0,1,0,0,0,201,155,215,0,152,30,2,0,96,69,2,0,1,0,0,0,202,155,215,0,232,10,2,0,16,17,8,0,1,0,0,0,211,155,215,0,224,12,8,0,32,77,1,0,1,0,0,0,210,155,215,0,216,70,1,0,88,212,3,0,1,0,0,0,200,154,215,0,40,185,3,0,248,5,8,0,9,0,0,0,0,156,215,0,32,58,1,0,144,250,7,0,9,0,0,0,1,156,215,0,32,58,1,0,18,0,0,0,255,255,175,0,0,0,0,0,19,0,0,0,255,255,253,0,0,0,0,0,20,0,0,0,255,255,240,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,18,0,0,0,1,3,2,0,208,75,4,0,18,0,0,0,1,3,3,0,8,49,4,0,18,0,0,0,1,3,1,0,152,21,4,0,18,0,0,0,1,3,0,0,72,246,3,0,0,0,0,0,254,0,4,0,72,202,5,0,18,0,0,0])
.concat([1,12,0,0,160,203,8,0,18,0,0,0,1,12,8,0,80,246,3,0,18,0,0,0,1,12,12,0,248,38,7,0,18,0,0,0,1,12,4,0,112,212,3,0,0,0,0,0,254,0,2,0,104,159,3,0,18,0,0,0,1,32,0,0,56,111,3,0,18,0,0,0,1,32,32,0,104,134,3,0,0,0,0,0,254,0,2,0,168,234,7,0,18,0,0,0,1,64,64,0,96,135,7,0,18,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,18,0,0,0,1,128,128,0,96,135,7,0,18,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,1,1,0,96,135,7,0,19,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,88,160,1,0,19,0,0,0,1,4,4,0,136,86,1,0,19,0,0,0,1,4,0,0,184,147,6,0,0,0,0,0,254,0,2,0,96,46,8,0,19,0,0,0,1,8,8,0,192,255,2,0,19,0,0,0,1,8,0,0,208,75,4,0,0,0,0,0,254,0,16,0,32,4,2,0,19,0,0,0,1,240,160,0,144,160,3,0,19,0,0,0,1,240,176,0,96,135,3,0,19,0,0,0,1,240,192,0,32,136,7,0,19,0,0,0,1,240,208,0,40,88,7,0,19,0,0,0,1,240,224,0,96,39,7,0,19,0,0,0,1,240,16,0,32,202,2,0,19,0,0,0,1,240,48,0,120,113,6,0,19,0,0,0,1,240,32,0,232,228,5,0,19,0,0,0,1,240,240,0,144,251,6,0,19,0,0,0,1,240,64,0,120,211,6,0,19,0,0,0,1,240,144,0,184,164,6,0,19,0,0,0,1,240,128,0,80,74,6,0,19,0,0,0,1,240,112,0,192,32,6,0,19,0,0,0,1,240,96,0,192,234,2,0,19,0,0,0,1,240,80,0,32,242,5,0,19,0,0,0,1,240,0,0,16,227,4,0,168,86,7,0,1,0,0,0,164,240,146,0,248,191,2,0,24,38,7,0,1,0,0,0,165,240,146,0,184,160,2,0,56,210,6,0,1,0,0,0,104,1,147,0,192,135,2,0,24,163,6,0,1,0,0,0,105,1,147,0,240,108,2,0,152,122,6,0,1,0,0,0,106,1,147,0,96,82,2,0,192,72,6,0,1,0,0,0,107,1,147,0,32,56,2,0,200,110,3,0,1,0,0,0,108,1,147,0,152,30,2,0,120,89,3,0,1,0,0,0,109,1,147,0,232,10,2,0,40,246,1,0,1,0,0,0,163,240,146,0,64,246,1,0,144,236,1,0,1,0,0,0,166,240,146,0,136,224,1,0,176,223,1,0,1,0,0,0,184,248,146,0,72,198,1,0,192,209,1,0,1,0,0,0,185,248,146,0,24,182,1,0,24,198,1,0,1,0,0,0,186,248,146,0,40,167,1,0,120,189,1,0,1,0,0,0,187,248,146,0,200,149,1,0,224,22,1,0,1,0,0,0,188,248,146,0,56,126,1,0,160,14,1,0,1,0,0,0,189,248,146,0,32,101,1,0,88,212,3,0,1,0,0,0,232,220,146,0,40,185,3,0,16,17,8,0,1,0,0,0,160,240,146,0,224,12,8,0,72,65,1,0,9,0,0,0,192,6,147,0,32,58,1,0,48,50,1,0,9,0,0,0,193,6,147,0,32,58,1,0,114,99,109,95,50,51,97,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,178,108,217,239,2,0,16,1,114,99,109,95,50,50,97,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,137,166,41,135,2,0,16,1,114,99,109,95,50,49,97,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,226,205,124,81,2,0,16,1,114,99,109,95,48,49,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,63,241,205,110,4,0,32,0,114,99,109,95,48,50,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,15,79,77,148,4,0,32,0,114,99,109,95,48,51,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,60,7,243,54,4,0,32,0,114,99,109,95,48,52,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,255,34,230,84,4,0,32,0,114,99,109,95,48,53,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,253,49,209,93,4,0,32,0,114,99,109,95,48,54,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,19,248,250,240,4,0,32,0,114,99,109,95,48,55,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,19,224,109,130,4,0,32,0,114,99,109,95,48,56,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,207,100,255,251,4,0,32,0,114,99,109,95,49,48,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,169,173,200,77,4,0,32,0,114,99,109,95,49,49,46,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,6,238,185,242,4,0,32,0,114,99,109,95,49,50,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,3,242,213,254,4,0,32,0,114,99,109,95,49,51,46,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,169,212,105,80,4,0,32,0,114,99,109,95,49,52,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,189,227,59,48,4,0,32,0,114,99,109,95,49,53,46,56,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,47,55,45,79,4,0,32,0,114,99,109,95,49,54,46,57,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,222,127,217,147,4,0,32,0,114,99,109,95,49,55,46,49,48,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,66,16,55,146,4,0,32,0,114,99,109,95,48,57,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,239,214,50,150,3,0,16,0,114,99,109,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,170,248,241,128,5,0,64,0,114,99,109,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,225,219,87,242,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,114,99,109,54,51,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,148,212,172,132,0,0,0,8,105,111,98,49,46,49,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,98,112,114,103,49,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,167,61,121,49,0,0,0,8,105,111,99,49,46,105,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,129,32,24,13,0,0,0,8,99,54,51,50,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,112,146,189,15,0,0,0,8,21,0,0,0,255,255,0,0,0,0,0,0,22,0,0,0,255,255,1,0,0,0,0,0,23,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,19,0,32,4,2,0,21,0,0,0,1,31,0,0,128,230,7,0,21,0,0,0,1,31,1,0,184,164,6,0,21,0,0,0,1,31,2,0,80,74,6,0,21,0,0,0,1,31,3,0,192,32,6,0,21,0,0,0,1,31,4,0,192,234,2,0,21,0,0,0,1,31,5,0,32,242,5,0,21,0,0,0,1,31,6,0,176,192,2,0,21,0,0,0,1,31,7,0,248,175,2,0,21,0,0,0,1,31,8,0,144,68,1,0,21,0,0,0,1,31,9,0,104,236,7,0,21,0,0,0,1,31,10,0,16,242,7,0,21,0,0,0,1,31,11,0,80,252,6,0,21,0,0,0,1,31,12,0,104,54,4,0,21,0,0,0,1,31,13,0,176,73,5,0,21,0,0,0,1,31,14,0,16,95,1,0,21,0,0,0,1,31,15,0,48,94,1,0,21,0,0,0,1,31,16,0,136,93,1,0,21,0,0,0,1,31,17,0,144,92,1,0,21,0,0,0,1,31,18,0,16,227,4,0,0,0,0,0,254,0,4,0,88,160,1,0,21,0,0,0,1,96,64,0,8,92,1,0,21,0,0,0,1,96,0,0,64,91,1,0,21,0,0,0,1,96,32,0,0,91,1,0,0,0,0,0,254,0,4,0,72,202,5,0,22,0,0,0,1,3,0,0,80,246,3,0,22,0,0,0,1,3,1,0,248,38,7,0,22,0,0,0,1,3,2,0,112,212,3,0,22,0,0,0,1,3,3,0,248,160,5,0,0,0,0,0,254,0,4,0,112,59,6,0,22,0,0,0,1,12,0,0,80,167,5,0,22,0,0,0,1,12,4,0,80,150,7,0,22,0,0,0,1,12,8,0,104,142,4,0,22,0,0,0,1,12,12,0,176,63,4,0,0,0,0,0,254,0,2,0,144,212,8,0,23,0,0,0,1,1,0,0,96,135,7,0,23,0,0,0,1,1,1,0,152,182,7,0,0,0,0,0,254,0,2,0,40,111,8,0,23,0,0,0,1,2,2,0,96,135,7,0,23,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,23,0,0,0,1,4,4,0,96,135,7,0,23,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,79,2,0,23,0,0,0,1,128,0,0,32,182,8,0,23,0,0,0,1,128,128,0,80,251,6,0,0,0,0,0,108,99,48,49,46,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,141,174,1,134,1,0,16,1,108,99,48,50,46,97,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,76,157,222,45,1,0,16,1,108,99,48,51,46,97,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,103,138,196,130,1,0,16,1,108,99,48,52,46,97,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,74,160,211,124,1,0,16,1,108,99,48,53,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,73,33,84,94,1,0,16,1,108,99,48,54,46,97,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,100,202,189,178,1,0,16,1,108,99,48,56,46,97,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,239,225,24,127,4,0,32,0,108,99,48,55,46,97,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,172,80,139,241,4,0,32,0,108,99,49,48,46,99,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,27,120,197,222,4,0,32,0,108,99,48,57,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,222,181,192,6,4,0,32,0,108,99,49,49,46,102,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,135,125,12,106,7,0,32,0,108,99,49,50,46,101,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,71,101,231,246,7,0,32,0,108,99,49,51,46,103,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,43,95,71,25,0,0,32,0,108,99,49,52,46,103,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,219,209,150,204,0,0,32,0,13,0,0,0,255,255,64,0,0,0,0,0,14,0,0,0,255,255,192,0,0,0,0,0,15,0,0,0,255,255,0,0,0,0,0,0,16,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,64,37,5,0,14,0,0,0,1,64,0,0,152,53,6,0,14,0,0,0,1,64,64,0,8,49,6,0,0,0,0,0,254,0,2,0,88,160,1,0,14,0,0,0,1,128,128,0,192,255,2,0,14,0,0,0,1,128,0,0,208,75,4,0,0,0,0,0,254,0,4,0,128,129,4,0,15,0,0,0,1,3,0,0,8,49,4,0,15,0,0,0,1,3,1,0,152,21,4,0,15,0,0,0,1,3,2,0,72,246,3,0,15,0,0,0,1,3,3,0,72,0,3,0,0,0,0,0,254,0,16,0,200,87,7,0,16,0,0,0,1,15,0,0,152,152,1,0,16,0,0,0,1,15,1,0,88,27,2,0,16,0,0,0,1,15,2,0,176,79,8,0,16,0,0,0,1,15,3,0,8,32,4,0,16,0,0,0,1,15,4,0,96,164,8,0,16,0,0,0,1,15,5,0,144,102,8,0,16,0,0,0,1,15,6,0,176,45,8,0,16,0,0,0,1,15,7,0,224,127,8,0,16,0,0,0,1,15,15,0,32,123,8,0,16,0,0,0,1,15,14,0,192,110,8,0,16,0,0,0,1,15,13,0,96,102,7,0,16,0,0,0,1,15,12,0,184,105,6,0,16,0,0,0,1,15,11,0,152,96,3,0,16,0,0,0,1,15,10,0,192,100,6,0,16,0,0,0,1,15,9,0,64,1,1,0,16,0,0,0,1,15,8,0,184,69,8,0,0,0,0,0,254,0,16,0,160,123,6,0,16,0,0,0,1,240,0,0,152,152,1,0,16,0,0,0,1,240,16,0,88,27,2,0,16,0,0,0,1,240,32,0,176,79,8,0,16,0,0,0,1,240,48,0,8,32,4,0,16,0,0,0,1,240,64,0,96,164,8,0,16,0,0,0,1,240,80,0,144,102,8,0,16,0,0,0,1,240,96,0,176,45,8,0,16,0,0,0,1,240,112,0,224,127,8,0,16,0,0,0,1,240,240,0,32,123,8,0,16,0,0,0,1,240,224,0,192,110,8,0,16,0,0,0,1,240,208,0,96,102,7,0,16,0,0,0,1,240,192,0,184,105,6,0,16,0,0,0,1,240,176,0,152,96,3,0,16,0,0,0,1,240,160,0,192,100,6,0,16,0,0,0,1,240,144,0,64,1,1,0,16,0,0,0,1,240,128,0,184,69,8,0,0,0,0,0,101,112,48,53,45,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,132,191,105,186,0,0,16,1,101,112,48,49,45,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,44,110,159,42,0,0,16,1,101,112,48,52,45,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,120,23,24,57,0,0,16,1,101,112,48,48,45,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,31,84,40,225,0,0,16,1,101,112,48,51,45,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,36,75,22,91,0,0,16,1,101,110,95,50,52,46,97,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,152,202,226,184,0,0,16,1,101,112,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,177,74,126,167,0,0,32,0,101,112,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,3,105,189,159,0,0,32,0,101,112,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,184,56,141,29,0,0,32,0,101,112,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,178,41,121,24,0,0,32,0,101,112,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,94,11,88,182,0,0,32,0,101,112,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,199,1,173,155,0,0,32,0,101,112,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,218,206,86,202,0,0,32,0,101,112,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,156,38,69,169,0,0,32,0,101,112,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,88,77,250,231,0,0,32,0,101,112,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,157,232,170,132,0,0,32,0,101,112,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,207,117,93,73,0,0,32,0,101,112,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,226,50,174,162,0,0,32,0,101,112,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,90,66,250,98,0,0,32,0,101,112,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,149,189,227,204,0,0,32,0,101,112,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,86,214,190,17,0,0,32,0,101,112,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,76,123,92,196,0,0,32,0,101,112,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,40,159,202,143,0,0,32,0,101,112,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,195,208,209,60,0,0,32,0,101,112,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,111,228,28,113,0,0,64,0,101,112,48,53,45,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,61,203,229,141,0,0,16,1,101,112,48,49,45,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,2,188,198,179,0,0,16,1,101,112,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,1,0,24,157,139,195,0,0,16,1,101,112,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,170,145,76,55,0,0,16,1,101,112,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,184,234,137,16,0,0,16,1,101,110,95,50,52,46,97,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,152,202,226,184,0,0,16,1,101,112,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,177,74,126,167,0,0,32,0,101,112,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,3,105,189,159,0,0,32,0,101,112,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,184,56,141,29,0,0,32,0,101,112,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,178,41,121,24,0,0,32,0,101,112,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,94,11,88,182,0,0,32,0,101,112,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,199,1,173,155,0,0,32,0,101,112,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,218,206,86,202,0,0,32,0,101,112,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,156,38,69,169,0,0,32,0,101,112,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,88,77,250,231,0,0,32,0,101,112,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,157,232,170,132,0,0,32,0,101,112,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,207,117,93,73,0,0,32,0,101,112,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,226,50,174,162,0,0,32,0,101,112,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,90,66,250,98,0,0,32,0,101,112,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,149,189,227,204,0,0,32,0,101,112,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,86,214,190,17,0,0,32,0,101,112,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,76,123,92,196,0,0,32,0,101,112,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,40,159,202,143,0,0,32,0,101,112,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,195,208,209,60,0,0,32,0,101,112,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,111,228,28,113,0,0,64,0,101,109,48,53,45,49,46,99,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,244,168,78,149,0,0,16,1,101,109,48,49,45,49,46,98,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,34,182,135,27,0,0,16,1,101,112,48,52,45,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,120,23,24,57,0,0,16,1,101,112,48,48,45,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,31,84,40,225,0,0,16,1,101,112,48,51,45,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,36,75,22,91,0,0,16,1,101,110,95,50,52,46,97,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,152,202,226,184,0,0,16,1,101,112,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,177,74,126,167,0,0,32,0,101,112,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,3,105,189,159,0,0,32,0,101,112,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,184,56,141,29,0,0,32,0,101,112,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,178,41,121,24,0,0,32,0,101,112,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,94,11,88,182,0,0,32,0,101,112,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,199,1,173,155,0,0,32,0,101,112,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,218,206,86,202,0,0,32,0,101,112,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,156,38,69,169,0,0,32,0,101,112,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,88,77,250,231,0,0,32,0,101,112,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,157,232,170,132,0,0,32,0,101,112,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,207,117,93,73,0,0,32,0,101,112,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,226,50,174,162,0,0,32,0,101,112,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,90,66,250,98,0,0,32,0,101,112,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,149,189,227,204,0,0,32,0,101,112,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,86,214,190,17,0,0,32,0,101,112,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,76,123,92,196,0,0,32,0,101,112,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,40,159,202,143,0,0,32,0,101,112,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,195,208,209,60,0,0,32,0,101,112,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,111,228,28,113,0,0,64,0,114,111,98,111,112,95,48,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,155,62,239,188,0,0,16,1,114,111,98,111,112,95,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,133,54,128,201,0,0,16,1,114,111,98,111,112,95,48,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,224,121,123,157,0,0,16,1,114,111,98,111,112,95,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,171,100,186,128,0,0,16,1,101,112,48,51,45,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,36,75,22,91,0,0,16,1,101,112,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,177,74,126,167,0,0,32,0,101,112,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,3,105,189,159,0,0,32,0,101,112,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,184,56,141,29,0,0,32,0,101,112,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,178,41,121,24,0,0,32,0,101,112,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,94,11,88,182,0,0,32,0,101,112,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,199,1,173,155,0,0,32,0,101,112,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,218,206,86,202,0,0,32,0,101,112,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,156,38,69,169,0,0,32,0,101,112,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,88,77,250,231,0,0,32,0,101,112,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,157,232,170,132,0,0,32,0,101,112,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,207,117,93,73,0,0,32,0,101,112,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,226,50,174,162,0,0,32,0,101,112,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,90,66,250,98,0,0,32,0,101,112,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,149,189,227,204,0,0,32,0,101,112,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,86,214,190,17,0,0,32,0,101,112,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,76,123,92,196,0,0,32,0,101,112,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,40,159,202,143,0,0,32,0,101,112,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,195,208,209,60,0,0,32,0,101,112,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,111,228,28,113,0,0,64,0,20,0,0,0,255,255,191,0,0,0,0,0,21,0,0,0,255,255,127,0,0,0,0,0,22,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,8,0,200,87,7,0,20,0,0,0,1,7,0,0,40,88,7,0,20,0,0,0,1,7,1,0,96,39,7,0,20,0,0,0,1,7,7,0,144,251,6,0,20,0,0,0,1,7,6,0,184,164,6,0,20,0,0,0,1,7,5,0,80,74,6,0,20,0,0,0,1,7,4,0,192,32,6,0,20,0,0,0,1,7,3,0,192,234,2,0,20,0,0,0,1,7,2,0,32,242,5,0,0,0,0,0,254,0,8,0,160,123,6,0,20,0,0,0,1,56,0,0,40,88,7,0,20,0,0,0,1,56,8,0,96,39,7,0,20,0,0,0,1,56,56,0,144,251,6,0,20,0,0,0,1,56,48,0,184,164,6,0,20,0,0,0,1,56,40,0,80,74,6,0,20,0,0,0,1,56,32,0,192,32,6,0,20,0,0,0,1,56,24,0,192,234,2,0,20,0,0,0,1,56,16,0,32,242,5,0,0,0,0,0,254,0,2,0,144,212,8,0,20,0,0,0,1,64,0,0,96,135,7,0,20,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,21,0,0,0,1,3,1,0,192,255,2,0,21,0,0,0,1,3,0,0,208,75,4,0,21,0,0,0,1,3,3,0,8,49,4,0,21,0,0,0,1,3,2,0,152,21,4,0,0,0,0,0,254,0,4,0,112,59,6,0,21,0,0,0,1,12,8,0,240,133,2,0,21,0,0,0,1,12,12,0,192,121,2,0,21,0,0,0,1,12,4,0,56,107,2,0,21,0,0,0,1,12,0,0,144,96,2,0,0,0,0,0,254,0,4,0,88,79,2,0,21,0,0,0,1,48,0,0,216,127,4,0,21,0,0,0,1,48,16,0,152,195,2,0,21,0,0,0,1,48,48,0,88,39,2,0,21,0,0,0,1,48,32,0,200,68,4,0,0,0,0,0,254,0,2,0,224,117,5,0,21,0,0,0,1,64,0,0,96,135,7,0,21,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,21,0,0,0,1,128,128,0,96,135,7,0,21,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,4,0,216,246,4,0,22,0,0,0,1,3,0,0,216,244,1,0,22,0,0,0,1,3,1,0,40,71,8,0,22,0,0,0,1,3,3,0,248,38,7,0,22,0,0,0,1,3,2,0,144,68,8,0,0,0,0,0,254,0,4,0,224,195,1,0,22,0,0,0,1,12,8,0,248,81,6,0,22,0,0,0,1,12,12,0,248,38,7,0,22,0,0,0,1,12,4,0,176,64,8,0,22,0,0,0,1,12,0,0,128,65,6,0,0,0,0,0,254,0,4,0,64,166,1,0,22,0,0,0,1,48,32,0,40,71,8,0,22,0,0,0,1,48,48,0,248,38,7,0,22,0,0,0,1,48,16,0,144,68,8,0,22,0,0,0,1,48,0,0,192,246,5,0,0,0,0,0,254,0,2,0,88,148,1,0,22,0,0,0,1,64,64,0,248,38,7,0,22,0,0,0,1,64,0,0,176,64,8,0,0,0,0,0,254,0,2,0,232,137,1,0,22,0,0,0,1,128,128,0,96,135,7,0,22,0,0,0,1,128,0,0,152,182,7,0,114,99,109,106,46,48,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,96,159,85,48,1,0,16,1,114,99,109,106,46,48,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,102,147,252,94,1,0,16,1,114,99,109,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,226,205,124,81,1,0,16,1,114,99,109,46,55,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,4,110,76,119,5,0,32,0,114,99,109,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,98,124,173,172,5,0,32,0,114,99,109,46,56,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,153,4,243,106,5,0,32,0,114,99,109,46,57,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,102,81,90,122,5,0,32,0,114,99,109,46,55,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,37,199,78,0,5,0,32,0,114,99,109,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,78,70,192,101,5,0,32,0,114,99,109,46,56,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,204,151,48,251,5,0,32,0,114,99,109,46,57,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,122,85,22,46,5,0,32,0,114,99,109,46,55,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,153,63,167,112,5,0,32,0,114,99,109,46,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,61,173,237,236,5,0,32,0,114,99,109,46,56,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,216,134,97,61,5,0,32,0,114,99,109,46,57,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,241,0,119,140,5,0,32,0,114,99,109,46,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,173,137,168,137,5,0,32,0,114,99,109,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,123,235,0,19,5,0,32,0,114,99,109,46,56,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,189,78,151,109,5,0,32,0,114,99,109,46,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,36,205,164,125,5,0,32,0,114,99,109,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,163,248,12,214,10,0,16,1,114,99,109,46,53,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,128,112,208,182,12,0,64,0,114,99,109,46,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,147,196,221,223,12,0,64,0,114,99,109,46,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,58,174,98,96,12,0,64,0,114,99,109,46,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,191,243,198,8,12,0,64,0,114,99,109,46,53,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,204,252,125,249,12,0,64,0,114,99,109,46,53,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,188,117,228,173,12,0,64,0,114,99,109,46,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,179,255,94,7,12,0,64,0,114,99,109,46,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,123,248,193,246,12,0,64,0,18,0,0,0,255,255,191,0,0,0,0,0,19,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,18,0,0,0,1,3,2,0,208,75,4,0,18,0,0,0,1,3,3,0,8,49,4,0,18,0,0,0,1,3,1,0,152,21,4,0,18,0,0,0,1,3,0,0,72,246,3,0,0,0,0,0,254,0,4,0,72,202,5,0,18,0,0,0,1,12,8,0,80,246,3,0,18,0,0,0,1,12,12,0,80,124,6,0,18,0,0,0,1,12,4,0,112,212,3,0,18,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,2,0,168,234,7,0,18,0,0,0,1,64,64,0,96,135,7,0,18,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,18,0,0,0,1,128,128,0,96,135,7,0,18,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,1,1,0,96,135,7,0,19,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,88,160,1,0,19,0,0,0,1,4,4,0,136,86,1,0,19,0,0,0,1,4,0,0,184,147,6,0,0,0,0,0,254,0,2,0,96,46,8,0,19,0,0,0,1,8,8,0,192,255,2,0,19,0,0,0,1,8,0,0,208,75,4,0,0,0,0,0,254,0,16,0,32,4,2,0,19,0,0,0,1,240,160,0,144,160,3,0,19,0,0,0,1,240,176,0,96,135,3,0,19,0,0,0,1,240,192,0,32,136,7,0,19,0,0,0,1,240,208,0,40,88,7,0,19,0,0,0,1,240,224,0,96,39,7,0,19,0,0,0,1,240,16,0,32,202,2,0,19,0,0,0,1,240,48,0,120,113,6,0,19,0,0,0,1,240,32,0,232,228,5,0,19,0,0,0,1,240,240,0,144,251,6,0,19,0,0,0,1,240,64,0,120,211,6,0,19,0,0,0,1,240,144,0,184,164,6,0,19,0,0,0,1,240,128,0,80,74,6,0,19,0,0,0,1,240,112,0,192,32,6,0,19,0,0,0,1,240,96,0,192,234,2,0,19,0,0,0,1,240,80,0,32,242,5,0,19,0,0,0,1,240,0,0,16,227,4,0,101,112,114,45,49,52,54,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,236,49,179,161,1,0,16,1,101,112,114,45,49,52,54,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,80,44,79,205,1,0,16,1,101,112,114,45,49,52,54,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,76,223,89,6,1,0,16,1,101,112,114,45,49,52,54,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,11,248,230,217,1,0,16,1,101,112,114,45,49,52,54,49,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,104,3,211,70,2,0,32,0,101,112,114,45,49,52,54,50,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,254,128,251,171,2,0,32,0,101,112,114,45,49,52,54,49,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,249,64,78,136,2,0,32,0,101,112,114,45,49,52,54,50,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,70,88,245,78,2,0,32,0,101,112,114,45,49,52,54,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,14,38,235,0,2,0,32,0,101,112,114,45,49,52,54,50,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,130,95,30,150,2,0,32,0,101,112,114,45,49,52,54,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,247,94,43,111,3,0,32,0,101,112,114,45,49,52,54,50,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,13,228,167,124,3,0,32,0,101,112,114,45,49,52,54,50,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,51,51,24,102,3,0,32,0,101,112,114,45,49,52,54,50,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,73,0,99,152,3,0,32,0,101,112,114,45,49,52,54,50,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,14,130,242,192,3,0,32,0,101,112,114,45,49,52,54,50,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,72,132,166,209,3,0,32,0,101,112,114,45,49,52,54,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,154,198,92,198,4,0,16,1,101,112,114,45,49,52,54,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,177,61,101,70,8,0,64,0,19,0,0,0,255,255,253,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,88,131,3,0,19,0,0,0,1,1,1,0,96,135,7,0,19,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,2,2,0,96,135,7,0,19,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,19,0,0,0,1,12,0,0,192,255,2,0,19,0,0,0,1,12,12,0,208,75,4,0,19,0,0,0,1,12,8,0,8,49,4,0,19,0,0,0,1,12,4,0,152,21,4,0,0,0,0,0,254,0,4,0,64,37,5,0,19,0,0,0,1,48,32,0,80,246,3,0,19,0,0,0,1,48,48,0,248,38,7,0,19,0,0,0,1,48,16,0,112,212,3,0,19,0,0,0,1,48,0,0,248,160,5,0,0,0,0,0,254,0,2,0,72,202,5,0,19,0,0,0,1,64,64,0,248,38,7,0,19,0,0,0,1,64,0,0,112,212,3,0,0,0,0,0,254,0,2,0,160,129,3,0,19,0,0,0,1,128,128,0,96,135,7,0,19,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,16,0,200,87,7,0,20,0,0,0,1,15,7,0,80,252,6,0,20,0,0,0,1,15,8,0,16,242,7,0,20,0,0,0,1,15,9,0,104,236,7,0,20,0,0,0,1,15,5,0,176,51,4,0,20,0,0,0,1,15,4,0,56,24,4,0,20,0,0,0,1,15,15,0,128,230,7,0,20,0,0,0,1,15,1,0,72,216,3,0,20,0,0,0,1,15,2,0,24,188,3,0,20,0,0,0,1,15,3,0,176,162,3,0,20,0,0,0,1,15,6,0,120,211,6,0,20,0,0,0,1,15,14,0,184,164,6,0,20,0,0,0,1,15,13,0,80,74,6,0,20,0,0,0,1,15,12,0,192,32,6,0,20,0,0,0,1,15,11,0,192,234,2,0,20,0,0,0,1,15,10,0,32,242,5,0,20,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,20,0,0,0,1,240,112,0,80,252,6,0,20,0,0,0,1,240,128,0,16,242,7,0,20,0,0,0,1,240,144,0,104,236,7,0,20,0,0,0,1,240,80,0,176,51,4,0,20,0,0,0,1,240,64,0,56,24,4,0,20,0,0,0,1,240,240,0,128,230,7,0,20,0,0,0,1,240,16,0,72,216,3,0,20,0,0,0,1,240,32,0,24,188,3,0,20,0,0,0,1,240,48,0,176,162,3,0,20,0,0,0,1,240,96,0,120,211,6,0,20,0,0,0,1,240,224,0,184,164,6,0,20,0,0,0,1,240,208,0,80,74,6,0,20,0,0,0,1,240,192,0,192,32,6,0,20,0,0,0,1,240,176,0,192,234,2,0,20,0,0,0,1,240,160,0,32,242,5,0,20,0,0,0,1,240,0,0,208,236,2,0,115,109,98,101,100,46,48,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,205,164,251,246,1,0,16,1,115,109,98,101,100,46,48,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,147,196,59,25,1,0,16,1,115,109,98,101,100,46,48,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,187,204,140,22,1,0,16,1,115,109,98,101,100,46,48,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,98,50,103,4,1,0,16,1,115,109,98,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,119,21,161,185,1,0,16,1,115,109,98,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,107,183,49,249,1,0,16,1,115,109,98,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,222,209,178,217,5,0,32,0,115,109,98,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,146,109,118,154,5,0,32,0,115,109,98,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,15,15,128,81,5,0,32,0,115,109,98,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,150,126,117,53,5,0,32,0,115,109,98,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,231,208,191,229,5,0,32,0,115,109,98,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,102,8,108,197,5,0,32,0,115,109,98,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,16,57,237,77,5,0,32,0,115,109,98,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,197,30,234,38,5,0,32,0,115,109,98,46,50,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,252,197,8,10,5,0,32,0,115,109,98,46,50,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,196,182,17,9,5,0,32,0,115,109,98,46,50,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,196,214,130,5,0,32,0,115,109,98,46,50,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,139,103,72,155,5,0,32,0,115,109,98,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,154,34,188,10,10,0,16,1,115,109,98,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,154,103,81,208,10,0,16,1,115,109,98,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,249,53,105,197,12,0,64,0,115,109,98,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,130,7,91,149,12,0,64,0,115,109,98,101,46,48,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,120,98,1,184,1,0,16,1,115,109,98,101,46,48,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,71,196,196,24,1,0,16,1,115,109,98,101,46,48,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,127,218,235,24,1,0,16,1,115,109,98,101,46,48,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,7,0,200,137,1,0,16,1,115,109,98,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,119,21,161,185,1,0,16,1,115,109,98,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,107,183,49,249,1,0,16,1,115,109,98,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,222,209,178,217,5,0,32,0,115,109,98,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,146,109,118,154,5,0,32,0,115,109,98,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,15,15,128,81,5,0,32,0,115,109,98,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,150,126,117,53,5,0,32,0,115,109,98,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,231,208,191,229,5,0,32,0,115,109,98,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,102,8,108,197,5,0,32,0,115,109,98,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,16,57,237,77,5,0,32,0,115,109,98,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,197,30,234,38,5,0,32,0,115,109,98,46,50,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,252,197,8,10,5,0,32,0,115,109,98,46,50,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,196,182,17,9,5,0,32,0,115,109,98,46,50,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,196,214,130,5,0,32,0,115,109,98,46,50,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,139,103,72,155,5,0,32,0,115,109,98,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,154,34,188,10,10,0,16,1,115,109,98,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,154,103,81,208,10,0,16,1,115,109,98,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,249,53,105,197,12,0,64,0,115,109,98,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,130,7,91,149,12,0,64,0,13,0,0,0,255,255,111,0,0,0,0,0,14,0,0,0,255,255,0,0,0,0,0,0,15,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,64,37,5,0,13,0,0,0,1,3,3,0,24,125,6,0,13,0,0,0,1,3,2,0,88,75,6,0,13,0,0,0,1,3,1,0,192,33,6,0,13,0,0,0,1,3,0,0,120,7,5,0,0,0,0,0,254,0,2,0,16,227,4,0,13,0,0,0,1,4,4,0,56,111,3,0,13,0,0,0,1,4,0,0,104,134,3,0,0,0,0,0,254,0,4,0,128,129,4,0,13,0,0,0,1,24,24,0,192,255,2,0,13,0,0,0,1,24,16,0,208,75,4,0,13,0,0,0,1,24,8,0,8,49,4,0,13,0,0,0,1,24,0,0,64,228,4,0,0,0,0,0,254,0,2,0,144,212,8,0,13,0,0,0,1,64,64,0,96,135,7,0,13,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,200,30,2,0,13,0,0,0,1,128,0,0,120,97,1,0,13,0,0,0,1,128,128,0,96,19,1,0,0,0,0,0,254,0,16,0,200,87,7,0,14,0,0,0,1,15,15,0,120,247,3,0,14,0,0,0,1,15,14,0,104,213,3,0,14,0,0,0,1,15,13,0,224,185,3,0,14,0,0,0,1,15,12,0,144,160,3,0,14,0,0,0,1,15,11,0,96,135,3,0,14,0,0,0,1,15,10,0,32,136,7,0,14,0,0,0,1,15,9,0,40,88,7,0,14,0,0,0,1,15,8,0,96,39,7,0,14,0,0,0,1,15,0,0,144,251,6,0,14,0,0,0,1,15,1,0,184,164,6,0,14,0,0,0,1,15,2,0,80,74,6,0,14,0,0,0,1,15,3,0])
.concat([192,32,6,0,14,0,0,0,1,15,4,0,192,234,2,0,14,0,0,0,1,15,5,0,32,242,5,0,14,0,0,0,1,15,6,0,176,192,2,0,14,0,0,0,1,15,7,0,248,175,2,0,0,0,0,0,254,0,16,0,160,123,6,0,14,0,0,0,1,240,240,0,120,247,3,0,14,0,0,0,1,240,224,0,104,213,3,0,14,0,0,0,1,240,208,0,224,185,3,0,14,0,0,0,1,240,192,0,144,160,3,0,14,0,0,0,1,240,176,0,96,135,3,0,14,0,0,0,1,240,160,0,32,136,7,0,14,0,0,0,1,240,144,0,40,88,7,0,14,0,0,0,1,240,128,0,96,39,7,0,14,0,0,0,1,240,0,0,144,251,6,0,14,0,0,0,1,240,16,0,184,164,6,0,14,0,0,0,1,240,32,0,80,74,6,0,14,0,0,0,1,240,48,0,192,32,6,0,14,0,0,0,1,240,64,0,192,234,2,0,14,0,0,0,1,240,80,0,32,242,5,0,14,0,0,0,1,240,96,0,176,192,2,0,14,0,0,0,1,240,112,0,248,175,2,0,0,0,0,0,254,0,2,0,248,147,2,0,15,0,0,0,1,1,1,0,96,135,7,0,15,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,0,136,2,0,15,0,0,0,1,16,0,0,56,111,3,0,15,0,0,0,1,16,16,0,104,134,3,0,0,0,0,0,254,0,2,0,144,123,2,0,15,0,0,0,1,32,0,0,56,111,3,0,15,0,0,0,1,32,32,0,104,134,3,0,0,0,0,0,254,0,2,0,112,109,2,0,15,0,0,0,1,64,64,0,96,135,7,0,15,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,32,4,2,0,15,0,0,0,1,128,128,0,168,82,2,0,15,0,0,0,1,128,0,0,240,69,2,0,0,0,0,0,184,40,2,0,1,0,0,0,47,39,216,0,248,191,2,0,56,250,6,0,1,0,0,0,24,39,216,0,184,160,2,0,184,164,8,0,1,0,0,0,46,39,216,0,64,246,1,0,88,149,7,0,1,0,0,0,30,39,216,0,136,224,1,0,168,188,8,0,1,0,0,0,42,39,216,0,192,135,2,0,24,175,8,0,1,0,0,0,43,39,216,0,240,108,2,0,240,156,8,0,1,0,0,0,45,39,216,0,96,82,2,0,80,144,8,0,1,0,0,0,44,39,216,0,32,56,2,0,64,38,2,0,1,0,0,0,34,39,216,0,72,198,1,0,136,37,2,0,1,0,0,0,35,39,216,0,24,182,1,0,56,36,2,0,1,0,0,0,37,39,216,0,40,167,1,0,96,34,2,0,1,0,0,0,36,39,216,0,200,149,1,0,176,108,2,0,1,0,0,0,40,39,216,0,56,126,1,0,88,212,3,0,1,0,0,0,48,38,216,0,40,185,3,0,248,5,8,0,9,0,0,0,112,39,216,0,32,58,1,0,144,250,7,0,9,0,0,0,113,39,216,0,32,58,1,0,248,241,7,0,9,0,0,0,114,39,216,0,32,58,1,0,72,82,8,0,9,0,0,0,80,39,216,0,32,58,1,0,88,121,10,0,152,121,10,0,216,121,10,0,0,0,0,0,24,122,10,0,88,122,10,0,152,122,10,0,0,0,0,0,216,122,10,0,240,122,10,0,101,112,114,45,53,57,53,48,46,49,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,103,123,4,59,0,0,16,1,101,112,114,45,53,57,53,49,46,49,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,171,83,100,214,0,0,16,1,101,112,114,45,53,57,53,50,46,49,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,138,21,208,243,0,0,16,1,101,112,114,45,53,57,53,51,46,49,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,68,79,173,169,0,0,16,1,101,112,114,45,53,54,52,52,46,49,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,125,91,208,255,0,0,16,1,101,112,114,45,53,57,53,53,46,49,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,163,178,221,101,0,0,16,1,101,112,114,45,53,54,53,50,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,152,203,237,116,0,0,16,1,101,112,114,45,53,54,53,49,46,56,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,130,62,127,240,0,0,32,0,101,112,114,45,53,54,53,48,46,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,162,186,193,132,0,0,32,0,101,112,114,45,53,54,52,57,46,56,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,149,200,116,103,0,0,32,0,101,112,114,45,53,54,52,56,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,42,233,105,12,0,0,32,0,101,112,114,45,53,54,52,55,46,56,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,181,247,48,147,0,0,32,0,101,112,114,45,53,54,52,54,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,188,203,250,77,0,0,32,0,101,112,114,45,53,54,51,56,46,56,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,221,99,115,97,0,0,32,0,101,112,114,45,53,54,51,57,46,57,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,49,81,236,164,0,0,32,0,112,114,45,53,51,49,55,46,49,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,184,80,131,100,0,0,0,8,101,112,114,45,53,54,52,48,46,49,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,212,208,36,131,0,0,16,1,101,112,114,45,53,54,52,49,46,49,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,199,245,9,10,0,0,16,1,101,112,114,45,53,54,52,50,46,49,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,246,178,39,255,0,0,16,1,101,112,114,45,53,54,52,51,46,49,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,240,125,134,13,0,0,16,1,101,112,114,45,53,54,52,52,46,49,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,125,91,208,255,0,0,16,1,101,112,114,45,53,54,52,53,46,49,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,180,180,162,87,0,0,16,1,101,112,114,45,53,54,53,50,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,152,203,237,116,0,0,16,1,101,112,114,45,53,54,53,49,46,56,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,130,62,127,240,0,0,32,0,101,112,114,45,53,54,53,48,46,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,162,186,193,132,0,0,32,0,101,112,114,45,53,54,52,57,46,56,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,149,200,116,103,0,0,32,0,101,112,114,45,53,54,52,56,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,42,233,105,12,0,0,32,0,101,112,114,45,53,54,52,55,46,56,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,181,247,48,147,0,0,32,0,101,112,114,45,53,54,52,54,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,188,203,250,77,0,0,32,0,101,112,114,45,53,54,51,56,46,56,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,221,99,115,97,0,0,32,0,101,112,114,45,53,54,51,57,46,57,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,49,81,236,164,0,0,32,0,112,114,45,53,51,49,55,46,49,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,184,80,131,100,0,0,0,8,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,254,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,19,0,0,0,1,15,7,0,80,252,6,0,19,0,0,0,1,15,8,0,16,242,7,0,19,0,0,0,1,15,9,0,104,236,7,0,19,0,0,0,1,15,5,0,192,54,8,0,19,0,0,0,1,15,4,0,56,24,4,0,19,0,0,0,1,15,15,0,128,230,7,0,19,0,0,0,1,15,0,0,128,230,7,0,19,0,0,0,1,15,3,0,176,162,3,0,19,0,0,0,1,15,2,0,24,188,3,0,19,0,0,0,1,15,1,0,72,216,3,0,19,0,0,0,1,15,6,0,120,211,6,0,19,0,0,0,1,15,14,0,184,164,6,0,19,0,0,0,1,15,13,0,80,74,6,0,19,0,0,0,1,15,12,0,192,32,6,0,19,0,0,0,1,15,11,0,192,234,2,0,19,0,0,0,1,15,10,0,32,242,5,0,0,0,0,0,254,0,16,0,160,123,6,0,19,0,0,0,1,240,112,0,80,252,6,0,19,0,0,0,1,240,128,0,16,242,7,0,19,0,0,0,1,240,144,0,104,236,7,0,19,0,0,0,1,240,80,0,192,54,8,0,19,0,0,0,1,240,64,0,56,24,4,0,19,0,0,0,1,240,240,0,128,230,7,0,19,0,0,0,1,240,0,0,128,230,7,0,19,0,0,0,1,240,48,0,176,162,3,0,19,0,0,0,1,240,32,0,24,188,3,0,19,0,0,0,1,240,16,0,72,216,3,0,19,0,0,0,1,240,96,0,120,211,6,0,19,0,0,0,1,240,224,0,184,164,6,0,19,0,0,0,1,240,208,0,80,74,6,0,19,0,0,0,1,240,192,0,192,32,6,0,19,0,0,0,1,240,176,0,192,234,2,0,19,0,0,0,1,240,160,0,32,242,5,0,0,0,0,0,254,0,2,0,200,30,2,0,20,0,0,0,1,1,0,0,120,97,1,0,20,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,12,12,0,8,49,4,0,20,0,0,0,1,12,8,0,152,21,4,0,20,0,0,0,1,12,4,0,72,246,3,0,20,0,0,0,1,12,0,0,112,49,6,0,0,0,0,0,254,0,2,0,72,202,5,0,20,0,0,0,1,64,64,0,80,246,3,0,20,0,0,0,1,64,0,0,112,212,3,0,0,0,0,0,18,0,0,0,255,255,0,0,0,0,0,0,19,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,168,234,7,0,18,0,0,0,1,2,2,0,96,135,7,0,18,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,18,0,0,0,1,192,192,0,192,255,2,0,18,0,0,0,1,192,64,0,208,75,4,0,18,0,0,0,1,192,0,0,8,49,4,0,18,0,0,0,1,192,128,0,72,246,3,0,0,0,0,0,254,0,2,0,232,21,1,0,19,0,0,0,1,4,0,0,96,135,7,0,19,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,19,0,0,0,1,24,16,0,80,246,3,0,19,0,0,0,1,24,0,0,248,38,7,0,19,0,0,0,1,24,8,0,112,212,3,0,19,0,0,0,1,24,24,0,248,160,5,0,0,0,0,0,254,0,8,0,32,4,2,0,19,0,0,0,1,224,224,0,32,136,7,0,19,0,0,0,1,224,96,0,40,88,7,0,19,0,0,0,1,224,160,0,96,39,7,0,19,0,0,0,1,224,32,0,120,113,6,0,19,0,0,0,1,224,0,0,144,251,6,0,19,0,0,0,1,224,192,0,120,211,6,0,19,0,0,0,1,224,128,0,184,164,6,0,19,0,0,0,1,224,64,0,80,74,6,0,0,0,0,0,184,40,2,0,1,0,0,0,212,155,215,0,248,191,2,0,56,250,6,0,1,0,0,0,215,155,215,0,184,160,2,0,184,164,8,0,1,0,0,0,213,155,215,0,64,246,1,0,88,149,7,0,1,0,0,0,214,155,215,0,136,224,1,0,168,10,1,0,4,0,0,0,112,156,215,0,152,210,1,0,224,255,0,0,4,0,0,0,104,156,215,0,208,189,1,0,48,123,2,0,1,0,0,0,209,155,215,0,248,174,1,0,32,232,8,0,4,0,0,0,96,156,215,0,136,7,4,0,48,216,8,0,4,0,0,0,88,156,215,0,136,113,1,0,248,187,8,0,1,0,0,0,208,155,215,0,56,126,1,0,16,17,8,0,1,0,0,0,211,155,215,0,224,12,8,0,32,77,1,0,1,0,0,0,210,155,215,0,216,70,1,0,88,212,3,0,1,0,0,0,200,154,215,0,40,185,3,0,248,5,8,0,9,0,0,0,0,156,215,0,32,58,1,0,144,250,7,0,9,0,0,0,1,156,215,0,32,58,1,0,98,50,50,45,49,48,45,49,46,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,202,80,74,227,2,0,16,1,98,50,50,45,49,49,45,49,46,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,147,160,49,106,2,0,16,1,98,50,50,45,48,56,45,49,46,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,122,225,214,21,2,0,16,1,98,50,50,45,48,57,45,49,46,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,188,102,78,69,2,0,16,1,98,50,50,45,48,51,46,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,184,15,187,62,2,0,16,1,98,50,50,45,48,52,46,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,127,94,98,145,2,0,16,1,98,50,50,45,49,52,46,52,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,91,26,60,17,9,0,16,1,98,50,50,45,48,49,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,104,145,108,183,11,0,32,0,98,50,50,45,48,50,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,240,236,135,27,15,0,32,0,98,50,50,45,49,50,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,198,109,167,103,16,0,32,0,98,50,50,45,49,51,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,159,9,218,47,16,0,32,0,99,99,104,105,112,95,98,50,50,45,49,53,46,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,24,15,0,0,0,255,255,254,0,0,0,0,0,16,0,0,0,255,255,191,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,15,0,0,0,1,1,0,0,120,97,1,0,15,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,2,0,144,212,8,0,15,0,0,0,1,2,2,0,96,135,7,0,15,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,15,0,0,0,1,4,4,0,96,135,7,0,15,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,15,0,0,0,1,8,0,0,96,135,7,0,15,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,15,0,0,0,1,48,16,0,104,236,7,0,15,0,0,0,1,48,48,0,128,230,7,0,15,0,0,0,1,48,0,0,120,211,6,0,15,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,15,0,0,0,1,192,64,0,104,236,7,0,15,0,0,0,1,192,192,0,128,230,7,0,15,0,0,0,1,192,0,0,120,211,6,0,15,0,0,0,1,192,128,0,184,164,6,0,0,0,0,0,254,0,4,0,72,202,5,0,16,0,0,0,1,3,2,0,80,246,3,0,16,0,0,0,1,3,3,0,80,124,6,0,16,0,0,0,1,3,1,0,112,212,3,0,16,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,2,0,64,37,5,0,16,0,0,0,1,4,4,0,184,79,7,0,16,0,0,0,1,4,0,0,120,7,5,0,0,0,0,0,254,0,2,0,248,72,7,0,16,0,0,0,1,8,8,0,56,68,7,0,16,0,0,0,1,8,0,0,0,64,7,0,0,0,0,0,254,0,4,0,128,129,4,0,16,0,0,0,1,48,16,0,192,255,2,0,16,0,0,0,1,48,0,0,208,75,4,0,16,0,0,0,1,48,48,0,8,49,4,0,16,0,0,0,1,48,32,0,152,21,4,0,0,0,0,0,254,0,2,0,128,112,3,0,16,0,0,0,1,64,0,0,168,22,4,0,16,0,0,0,1,64,64,0,224,247,3,0,0,0,0,0,98,48,52,45,49,52,46,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,9,201,138,163,2,0,16,1,98,48,52,45,49,51,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,114,8,214,186,2,0,16,1,98,48,52,45,49,54,45,49,46,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,96,158,181,0,2,0,16,1,98,48,52,45,49,53,45,49,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,138,1,158,255,2,0,16,1,98,48,52,45,49,56,45,49,46,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,57,196,38,182,2,0,16,1,98,48,52,45,49,55,45,49,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,22,165,40,201,2,0,16,1,98,48,52,45,49,57,46,52,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,216,253,129,238,9,0,16,1,98,48,52,45,48,49,46,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,25,222,48,205,11,0,32,0,98,48,52,45,48,51,46,51,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,100,224,103,171,11,0,32,0,98,48,52,45,48,50,46,54,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,236,15,4,84,11,0,32,0,98,48,52,45,48,52,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,147,126,115,148,11,0,32,0,98,48,52,45,48,53,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,172,148,45,194,15,0,32,0,98,48,52,45,48,55,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,81,42,99,181,15,0,32,0,98,48,52,45,48,54,46,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,57,207,44,0,15,0,32,0,98,48,52,45,48,56,46,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,5,202,175,254,15,0,32,0,98,48,52,45,50,48,46,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,204,52,26,253,26,0,64,0,19,0,0,0,255,255,254,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,19,0,0,0,1,1,0,0,120,97,1,0,19,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,2,2,0,96,135,7,0,19,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,4,4,0,96,135,7,0,19,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,8,0,0,96,135,7,0,19,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,19,0,0,0,1,48,16,0,104,236,7,0,19,0,0,0,1,48,48,0,128,230,7,0,19,0,0,0,1,48,0,0,120,211,6,0,19,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,19,0,0,0,1,192,64,0,104,236,7,0,19,0,0,0,1,192,192,0,128,230,7,0,19,0,0,0,1,192,0,0,120,211,6,0,19,0,0,0,1,192,128,0,184,164,6,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,3,2,0,80,246,3,0,20,0,0,0,1,3,3,0,80,124,6,0,20,0,0,0,1,3,1,0,112,212,3,0,20,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,64,37,5,0,20,0,0,0,1,12,12,0,168,114,7,0,20,0,0,0,1,12,8,0,152,109,7,0,20,0,0,0,1,12,4,0,16,103,7,0,20,0,0,0,1,12,0,0,72,96,7,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,48,48,0,8,49,4,0,20,0,0,0,1,48,32,0,152,21,4,0,20,0,0,0,1,48,16,0,72,246,3,0,20,0,0,0,1,48,0,0,72,0,3,0,0,0,0,0,254,0,2,0,104,159,3,0,20,0,0,0,1,64,0,0,96,135,7,0,20,0,0,0,1,64,64,0,152,182,7,0,19,0,0,0,255,255,63,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,0,0,144,212,8,0,19,0,0,0,1,2,2,0,96,135,7,0,19,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,4,4,0,96,135,7,0,19,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,8,0,0,96,135,7,0,19,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,2,0,200,87,7,0,19,0,0,0,1,48,16,0,96,39,7,0,19,0,0,0,1,48,48,0,144,251,6,0,19,0,0,0,1,48,0,0,120,211,6,0,19,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,3,2,0,80,246,3,0,20,0,0,0,1,3,3,0,80,124,6,0,20,0,0,0,1,3,1,0,112,212,3,0,20,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,64,37,5,0,20,0,0,0,1,12,12,0,240,191,4,0,20,0,0,0,1,12,8,0,200,213,4,0,20,0,0,0,1,12,4,0,144,227,4,0,20,0,0,0,1,12,0,0,200,178,5,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,48,32,0,192,255,2,0,20,0,0,0,1,48,16,0,208,75,4,0,20,0,0,0,1,48,48,0,8,49,4,0,20,0,0,0,1,48,0,0,72,246,3,0,0,0,0,0,254,0,4,0,104,159,3,0,20,0,0,0,1,64,0,0,96,135,7,0,20,0,0,0,1,64,64,0,152,182,7,0,98,48,52,45,49,52,46,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,9,201,138,163,2,0,16,1,98,48,52,45,50,49,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,154,222,141,124,2,0,16,1,98,48,52,45,50,51,46,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,206,61,75,37,2,0,16,1,98,48,52,45,50,50,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,207,237,232,152,2,0,16,1,98,48,52,45,50,53,46,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,238,173,229,209,2,0,16,1,98,48,52,45,50,52,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,6,193,220,163,2,0,16,1,98,48,52,45,49,57,46,52,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,216,253,129,238,9,0,16,1,98,48,52,45,48,49,46,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,25,222,48,205,11,0,32,0,98,48,52,45,48,51,46,51,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,100,224,103,171,11,0,32,0,98,48,52,45,48,50,46,54,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,236,15,4,84,11,0,32,0,98,48,52,45,48,52,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,147,126,115,148,11,0,32,0,98,48,52,45,48,53,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,172,148,45,194,15,0,32,0,98,48,52,45,48,55,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,81,42,99,181,15,0,32,0,98,48,52,45,48,54,46,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,57,207,44,0,15,0,32,0,98,48,52,45,48,56,46,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,5,202,175,254,15,0,32,0,98,48,52,45,50,48,46,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,204,52,26,253,26,0,64,0,98,48,52,45,51,56,46,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,177,219,145,28,2,0,16,1,98,48,52,45,51,55,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,221,11,242,236,2,0,16,1,98,48,52,45,52,53,46,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,221,18,40,54,2,0,16,1,98,48,52,45,52,52,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,8,85,204,81,2,0,16,1,98,48,52,45,52,50,46,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,203,167,87,24,2,0,16,1,98,48,52,45,52,49,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,196,161,76,180,2,0,16,1,98,48,52,45,49,57,46,52,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,216,253,129,238,9,0,16,1,98,48,52,45,48,49,46,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,25,222,48,205,11,0,32,0,98,48,52,45,48,51,46,51,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,100,224,103,171,11,0,32,0,98,48,52,45,48,50,46,54,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,236,15,4,84,11,0,32,0,98,48,52,45,48,52,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,147,126,115,148,11,0,32,0,98,48,52,45,48,53,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,172,148,45,194,15,0,32,0,98,48,52,45,48,55,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,81,42,99,181,15,0,32,0,98,48,52,45,48,54,46,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,57,207,44,0,15,0,32,0,98,48,52,45,48,56,46,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,5,202,175,254,15,0,32,0,98,48,52,45,50,48,46,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,204,52,26,253,26,0,64,0,184,40,2,0,1,0,0,0,165,148,215,0,248,191,2,0,56,250,6,0,1,0,0,0,163,148,215,0,184,160,2,0,184,164,8,0,1,0,0,0,166,148,215,0,64,246,1,0,88,149,7,0,1,0,0,0,164,148,215,0,136,224,1,0,56,210,6,0,1,0,0,0,184,148,215,0,192,135,2,0,24,163,6,0,1,0,0,0,185,148,215,0,240,108,2,0,152,122,6,0,1,0,0,0,186,148,215,0,96,82,2,0,192,72,6,0,1,0,0,0,187,148,215,0,32,56,2,0,48,123,2,0,1,0,0,0,188,148,215,0,152,30,2,0,96,69,2,0,1,0,0,0,189,148,215,0,232,10,2,0,176,223,1,0,1,0,0,0,176,148,215,0,72,198,1,0,192,209,1,0,1,0,0,0,177,148,215,0,24,182,1,0,24,198,1,0,1,0,0,0,178,148,215,0,40,167,1,0,120,189,1,0,1,0,0,0,179,148,215,0,200,149,1,0,248,187,8,0,1,0,0,0,180,148,215,0,56,126,1,0,184,179,8,0,1,0,0,0,181,148,215,0,32,101,1,0,88,212,3,0,1,0,0,0,200,147,215,0,40,185,3,0,16,17,8,0,1,0,0,0,160,148,215,0,224,12,8,0,56,58,1,0,1,0,0,0,162,148,215,0,64,50,1,0,248,5,8,0,9,0,0,0,96,149,215,0,32,58,1,0,144,250,7,0,9,0,0,0,97,149,215,0,32,58,1,0,49,54,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,219,56,146,239,0,0,16,1,49,54,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,86,182,190,124,0,0,16,1,49,54,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,66,16,75,51,0,0,16,1,49,54,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,82,43,133,180,0,0,16,1,49,55,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,78,242,105,61,0,0,16,1,49,55,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,22,15,116,233,0,0,16,1,49,55,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,242,9,49,132,0,0,16,1,49,55,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,129,26,91,59,0,0,16,1,49,55,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,226,36,162,80,0,0,32,0,49,55,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,82,245,223,104,0,0,32,0,114,120,49,45,54,46,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,44,246,22,60,0,0,32,0,114,120,49,45,49,46,49,49,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,52,84,134,199,0,0,32,0,114,120,49,45,55,46,56,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,218,79,77,131,0,0,32,0,114,120,49,45,50,46,52,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,21,72,87,143,0,0,32,0,114,120,49,45,51,46,55,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,150,16,134,184,0,0,32,0,114,120,49,45,53,46,51,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,23,112,173,75,0,0,64,0,114,120,49,45,52,46,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,0,19,0,0,0,255,255,1,0,0,0,0,0,20,0,0,0,255,255,32,0,0,0,0,0,21,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,19,0,0,0,1,1,1,0,120,97,1,0,19,0,0,0,1,1,0,0,96,19,1,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,2,0,0,96,135,7,0,19,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,8,8,0,96,135,7,0,19,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,19,0,0,0,1,48,32,0,96,39,7,0,19,0,0,0,1,48,0,0,144,251,6,0,19,0,0,0,1,48,48,0,120,211,6,0,19,0,0,0,1,48,16,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,19,0,0,0,1,192,128,0,96,39,7,0,19,0,0,0,1,192,0,0,144,251,6,0,19,0,0,0,1,192,192,0,120,211,6,0,19,0,0,0,1,192,64,0,184,164,6,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,3,1,0,80,246,3,0,20,0,0,0,1,3,0,0,80,124,6,0,20,0,0,0,1,3,2,0,112,212,3,0,20,0,0,0,1,3,3,0,248,160,5,0,0,0,0,0,254,0,4,0,88,242,5,0,20,0,0,0,1,48,32,0,88,202,5,0,20,0,0,0,1,48,16,0,0,161,5,0,20,0,0,0,1,48,0,0,24,128,5,0,20,0,0,0,1,48,48,0,248,98,5,0,0,0,0,0,254,0,2,0,96,68,5,0,20,0,0,0,1,64,0,0,96,135,7,0,20,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,20,0,0,0,1,128,128,0,56,111,3,0,20,0,0,0,1,128,0,0,104,134,3,0,101,112,114,45,55,52,49,49,46,49,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,198,198,160,136,0,0,16,1,101,112,114,45,55,52,49,50,46,49,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,223,205,184,211,0,0,16,1,101,112,114,45,55,52,49,51,46,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,179,136,230,183,0,0,16,1,101,112,114,45,55,52,50,48,46,49,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,102,118,56,20,0,0,16,1,101,112,114,45,55,52,49,57,46,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,76,243,213,191,0,0,32,0,101,112,114,45,55,52,49,56,46,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,182,201,203,248,0,0,32,0,101,112,114,45,55,52,49,55,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,188,1,53,230,0,0,32,0,101,112,114,45,55,52,49,54,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,147,86,62,9,0,0,32,0,101,112,114,45,55,52,49,53,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,214,107,141,26,0,0,32,0,101,112,114,45,55,52,49,52,46,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,24,242,32,93,0,0,32,0,101,112,114,45,55,52,48,55,46,49,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,87,192,159,240,0,0,32,0,101,112,114,45,55,52,48,57,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,184,237,159,129,0,0,32,0,101,112,114,45,55,52,48,56,46,49,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,60,243,137,49,0,0,32,0,101,112,114,45,55,52,49,48,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,137,71,215,206,0,0,32,0,112,114,45,53,51,49,55,46,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,184,80,131,100,0,0,0,8,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,252,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,19,0,0,0,1,15,7,0,80,252,6,0,19,0,0,0,1,15,8,0,16,242,7,0,19,0,0,0,1,15,9,0,104,236,7,0,19,0,0,0,1,15,5,0,192,54,8,0,19,0,0,0,1,15,4,0,56,24,4,0,19,0,0,0,1,15,15,0,128,230,7,0,19,0,0,0,1,15,0,0,128,230,7,0,19,0,0,0,1,15,3,0,176,162,3,0,19,0,0,0,1,15,2,0,24,188,3,0,19,0,0,0,1,15,1,0,72,216,3,0,19,0,0,0,1,15,6,0,120,211,6,0,19,0,0,0,1,15,14,0,184,164,6,0,19,0,0,0,1,15,13,0,80,74,6,0,19,0,0,0,1,15,12,0,192,32,6,0,19,0,0,0,1,15,11,0,192,234,2,0,19,0,0,0,1,15,10,0,32,242,5,0,0,0,0,0,254,0,16,0,160,123,6,0,19,0,0,0,1,240,112,0,80,252,6,0,19,0,0,0,1,240,128,0,16,242,7,0,19,0,0,0,1,240,144,0,104,236,7,0,19,0,0,0,1,240,80,0,192,54,8,0,19,0,0,0,1,240,64,0,56,24,4,0,19,0,0,0,1,240,240,0,128,230,7,0,19,0,0,0,1,240,0,0,128,230,7,0,19,0,0,0,1,240,48,0,176,162,3,0,19,0,0,0,1,240,32,0,24,188,3,0,19,0,0,0,1,240,16,0,72,216,3,0,19,0,0,0,1,240,96,0,120,211,6,0,19,0,0,0,1,240,224,0,184,164,6,0,19,0,0,0,1,240,208,0,80,74,6,0,19,0,0,0,1,240,192,0,192,32,6,0,19,0,0,0,1,240,176,0,192,234,2,0,19,0,0,0,1,240,160,0,32,242,5,0,0,0,0,0,254,0,2,0,200,30,2,0,20,0,0,0,1,1,0,0,120,97,1,0,20,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,2,0,168,234,7,0,20,0,0,0,1,2,2,0,96,135,7,0,20,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,12,12,0,8,49,4,0,20,0,0,0,1,12,8,0,152,21,4,0,20,0,0,0,1,12,4,0,72,246,3,0,20,0,0,0,1,12,0,0,112,49,6,0,0,0,0,0,254,0,4,0,64,37,5,0,20,0,0,0,1,48,48,0,96,124,5,0,20,0,0,0,1,48,32,0,32,122,5,0,20,0,0,0,1,48,16,0,192,119,5,0,20,0,0,0,1,48,0,0,120,7,5,0,10,0,0,0,255,255,128,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,10,0,0,0,1,3,0,0,8,49,4,0,10,0,0,0,1,3,1,0,152,21,4,0,10,0,0,0,1,3,2,0,72,246,3,0,10,0,0,0,1,3,3,0,72,0,3,0,0,0,0,0,254,0,4,0,64,37,5,0,10,0,0,0,1,12,0,0,176,114,3,0,10,0,0,0,1,12,4,0,176,116,6,0,10,0,0,0,1,12,8,0,80,113,6,0,10,0,0,0,1,12,12,0,80,110,6,0,0,0,0,0,254,0,8,0,32,4,2,0,10,0,0,0,1,112,112,0,96,135,3,0,10,0,0,0,1,112,80,0,32,136,7,0,10,0,0,0,1,112,48,0,40,88,7,0,10,0,0,0,1,112,16,0,96,39,7,0,10,0,0,0,1,112,0,0,144,251,6,0,10,0,0,0,1,112,32,0,184,164,6,0,10,0,0,0,1,112,64,0,80,74,6,0,10,0,0,0,1,112,96,0,192,32,6,0,0,0,0,0,254,0,2,0,200,30,2,0,10,0,0,0,1,128,128,0,120,97,1,0,10,0,0,0,1,128,0,0,96,19,1,0,0,0,0,0,104,111,114,122,95,103,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,213,154,6,151,4,0,32,0,104,111,114,122,95,114,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,75,232,100,255,4,0,32,0,56,50,115,49,50,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,191,2,120,115,7,0,32,0,104,111,114,122,95,112,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,67,91,202,50,8,0,16,1,56,50,115,49,52,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,165,127,206,170,0,0,0,8,10,0,0,0,255,255,0,0,0,0,0,0,11,0,0,0,255,255,0,0,0,0,0,0,12,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,18,0,0,0,255,255,0,0,0,0,0,0,19,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,12,0,200,87,7,0,18,0,0,0,1,15,13,0,40,88,7,0,18,0,0,0,1,15,12,0,96,39,7,0,18,0,0,0,1,15,5,0,128,13,7,0,18,0,0,0,1,15,0,0,144,251,6,0,18,0,0,0,1,15,3,0,40,183,6,0,18,0,0,0,1,15,2,0,232,192,7,0,18,0,0,0,1,15,6,0,120,211,6,0,18,0,0,0,1,15,8,0,184,164,6,0,18,0,0,0,1,15,9,0,80,74,6,0,18,0,0,0,1,15,10,0,192,32,6,0,18,0,0,0,1,15,11,0,192,234,2,0,18,0,0,0,1,15,4,0,32,242,5,0,0,0,0,0,254,0,12,0,160,123,6,0,18,0,0,0,1,240,208,0,40,88,7,0,18,0,0,0,1,240,192,0,96,39,7,0,18,0,0,0,1,240,80,0,128,13,7,0,18,0,0,0,1,240,0,0,144,251,6,0,18,0,0,0,1,240,48,0,40,183,6,0,18,0,0,0,1,240,32,0,232,192,7,0,18,0,0,0,1,240,96,0,120,211,6,0,18,0,0,0,1,240,128,0,184,164,6,0,18,0,0,0,1,240,144,0,80,74,6,0,18,0,0,0,1,240,160,0,192,32,6,0,18,0,0,0,1,240,176,0,192,234,2,0,18,0,0,0,1,240,64,0,32,242,5,0,0,0,0,0,254,0,4,0,72,202,5,0,19,0,0,0,1,3,2,0,80,246,3,0,19,0,0,0,1,3,0,0,248,38,7,0,19,0,0,0,1,3,1,0,112,212,3,0,19,0,0,0,1,3,3,0,248,160,5,0,0,0,0,0,254,0,2,0,128,129,4,0,19,0,0,0,1,4,0,0,8,49,4,0,19,0,0,0,1,4,4,0,208,75,4,0,0,0,0,0,254,0,2,0,16,190,6,0,19,0,0,0,1,8,0,0,48,153,2,0,19,0,0,0,1,8,8,0,200,105,5,0,0,0,0,0,254,0,2,0,32,141,2,0,19,0,0,0,1,16,0,0,72,130,2,0,19,0,0,0,1,16,16,0,64,46,2,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,32,32,0,96,135,7,0,19,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,224,117,5,0,19,0,0,0,1,64,64,0,96,135,7,0,19,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,128,0,0,96,135,7,0,19,0,0,0,1,128,128,0,152,182,7,0,0,0,0,0,29,0,0,0,255,255,128,0,0,0,0,0,0,0,0,0,254,0,2,0,16,208,6,0,29,0,0,0,1,128,128,0,96,135,7,0,29,0,0,0,1,128,0,0,152,182,7,0,15,0,0,0,255,255,255,0,0,0,0,0,16,0,0,0,255,255,255,0,0,0,0,0,17,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,136,19,2,0,15,0,0,0,1,4,4,0,96,135,7,0,15,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,15,0,0,0,1,32,32,0,96,135,7,0,15,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,15,0,0,0,1,64,0,0,96,135,7,0,15,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,15,0,0,0,1,128,128,0,96,135,7,0,15,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,8,0,200,87,7,0,16,0,0,0,1,7,4,0,32,136,7,0,16,0,0,0,1,7,5,0,40,88,7,0,16,0,0,0,1,7,6,0,96,39,7,0,16,0,0,0,1,7,7,0,144,251,6,0,16,0,0,0,1,7,1,0,120,211,6,0,16,0,0,0,1,7,3,0,184,164,6,0,16,0,0,0,1,7,2,0,80,74,6,0,16,0,0,0,1,7,0,0,16,227,4,0,0,0,0,0,254,0,4,0])
.concat([72,202,5,0,16,0,0,0,1,48,32,0,80,246,3,0,16,0,0,0,1,48,48,0,248,38,7,0,16,0,0,0,1,48,16,0,112,212,3,0,16,0,0,0,1,48,0,0,24,99,5,0,0,0,0,0,254,0,4,0,128,129,4,0,16,0,0,0,1,192,128,0,208,75,4,0,16,0,0,0,1,192,192,0,8,49,4,0,16,0,0,0,1,192,64,0,152,21,4,0,16,0,0,0,1,192,0,0,72,246,3,0,14,0,0,0,255,255,255,0,0,0,0,0,15,0,0,0,255,255,255,0,0,0,0,0,16,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,136,19,2,0,14,0,0,0,1,4,4,0,96,135,7,0,14,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,40,19,2,0,14,0,0,0,1,8,8,0,96,135,7,0,14,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,15,0,0,0,1,32,32,0,96,135,7,0,15,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,14,0,0,0,1,64,0,0,96,135,7,0,14,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,14,0,0,0,1,128,128,0,96,135,7,0,14,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,8,0,32,4,2,0,15,0,0,0,1,7,4,0,32,136,7,0,15,0,0,0,1,7,5,0,40,88,7,0,15,0,0,0,1,7,6,0,96,39,7,0,15,0,0,0,1,7,7,0,144,251,6,0,15,0,0,0,1,7,0,0,120,211,6,0,15,0,0,0,1,7,3,0,184,164,6,0,15,0,0,0,1,7,2,0,80,74,6,0,15,0,0,0,1,7,1,0,192,32,6,0,0,0,0,0,254,0,2,0,16,227,4,0,15,0,0,0,1,8,8,0,96,135,7,0,15,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,15,0,0,0,1,48,48,0,80,246,3,0,15,0,0,0,1,48,32,0,248,38,7,0,15,0,0,0,1,48,16,0,112,212,3,0,15,0,0,0,1,48,0,0,248,160,5,0,0,0,0,0,254,0,4,0,128,129,4,0,15,0,0,0,1,192,128,0,208,75,4,0,15,0,0,0,1,192,192,0,8,49,4,0,15,0,0,0,1,192,64,0,152,21,4,0,15,0,0,0,1,192,0,0,72,246,3,0,100,49,57,45,48,54,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,85,142,140,222,2,0,16,1,100,49,57,45,48,53,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,208,153,208,198,2,0,16,1,100,49,57,45,48,51,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,192,146,27,92,1,0,16,1,100,49,57,45,48,55,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,132,95,147,168,9,0,16,1,100,49,57,45,48,50,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,242,226,220,242,11,0,32,0,100,49,57,45,48,49,46,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,208,66,67,108,15,0,32,0,100,49,57,45,48,52,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,5,73,196,211,24,0,64,0,112,97,108,49,54,108,56,98,45,100,49,57,45,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,16,13,36,198,0,0,0,8,112,97,108,49,54,108,56,98,45,100,49,57,45,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,185,93,111,87,0,0,0,8,112,97,108,49,54,108,56,98,45,100,49,57,45,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,165,50,18,234,0,0,0,8,17,0,0,0,255,255,254,0,0,0,0,0,18,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,17,0,0,0,1,1,0,0,120,97,1,0,17,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,2,0,144,212,8,0,17,0,0,0,1,2,2,0,96,135,7,0,17,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,17,0,0,0,1,4,4,0,96,135,7,0,17,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,17,0,0,0,1,48,0,0,16,242,7,0,17,0,0,0,1,48,16,0,104,236,7,0,17,0,0,0,1,48,48,0,128,230,7,0,17,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,17,0,0,0,1,192,0,0,16,242,7,0,17,0,0,0,1,192,64,0,104,236,7,0,17,0,0,0,1,192,192,0,128,230,7,0,17,0,0,0,1,192,128,0,184,164,6,0,0,0,0,0,254,0,4,0,72,202,5,0,18,0,0,0,1,3,2,0,80,246,3,0,18,0,0,0,1,3,3,0,80,124,6,0,18,0,0,0,1,3,1,0,112,212,3,0,18,0,0,0,1,3,0,0,248,160,5,0,184,40,2,0,1,0,0,0,170,148,215,0,248,191,2,0,56,250,6,0,1,0,0,0,191,148,215,0,184,160,2,0,184,164,8,0,1,0,0,0,171,148,215,0,64,246,1,0,88,149,7,0,1,0,0,0,183,148,215,0,136,224,1,0,48,123,2,0,1,0,0,0,184,148,215,0,152,30,2,0,96,69,2,0,1,0,0,0,185,148,215,0,232,10,2,0,144,55,2,0,1,0,0,0,187,148,215,0,152,138,8,0,80,123,7,0,1,0,0,0,186,148,215,0,48,119,7,0,112,114,7,0,1,0,0,0,188,148,215,0,112,109,7,0,248,187,8,0,1,0,0,0,176,148,215,0,56,126,1,0,184,179,8,0,1,0,0,0,177,148,215,0,32,101,1,0,240,173,8,0,1,0,0,0,179,148,215,0,96,32,8,0,208,72,7,0,1,0,0,0,178,148,215,0,16,68,7,0,216,63,7,0,1,0,0,0,180,148,215,0,240,58,7,0,88,212,3,0,1,0,0,0,200,147,215,0,40,185,3,0,16,17,8,0,1,0,0,0,169,148,215,0,224,12,8,0,56,58,1,0,1,0,0,0,168,148,215,0,64,50,1,0,248,5,8,0,9,0,0,0,96,149,215,0,32,58,1,0,144,250,7,0,9,0,0,0,97,149,215,0,32,58,1,0,168,86,7,0,1,0,0,0,178,241,146,0,248,191,2,0,24,38,7,0,1,0,0,0,176,241,146,0,184,160,2,0,56,210,6,0,1,0,0,0,147,2,147,0,192,135,2,0,24,163,6,0,1,0,0,0,146,2,147,0,240,108,2,0,152,122,6,0,1,0,0,0,145,2,147,0,96,82,2,0,192,72,6,0,1,0,0,0,144,2,147,0,32,56,2,0,200,110,3,0,1,0,0,0,151,2,147,0,152,30,2,0,120,89,3,0,1,0,0,0,150,2,147,0,232,10,2,0,120,74,3,0,1,0,0,0,149,2,147,0,152,138,8,0,192,61,3,0,1,0,0,0,148,2,147,0,48,119,7,0,40,246,1,0,1,0,0,0,179,241,146,0,64,246,1,0,144,236,1,0,1,0,0,0,177,241,146,0,136,224,1,0,176,223,1,0,1,0,0,0,211,249,146,0,72,198,1,0,192,209,1,0,1,0,0,0,210,249,146,0,24,182,1,0,24,198,1,0,1,0,0,0,209,249,146,0,40,167,1,0,120,189,1,0,1,0,0,0,208,249,146,0,200,149,1,0,224,22,1,0,1,0,0,0,215,249,146,0,56,126,1,0,160,14,1,0,1,0,0,0,214,249,146,0,32,101,1,0,176,9,1,0,1,0,0,0,213,249,146,0,96,32,8,0,200,3,1,0,1,0,0,0,212,249,146,0,16,68,7,0,88,212,3,0,1,0,0,0,0,222,146,0,40,185,3,0,16,17,8,0,1,0,0,0,180,241,146,0,224,12,8,0,72,65,1,0,9,0,0,0,152,7,147,0,32,58,1,0,48,50,1,0,9,0,0,0,153,7,147,0,32,58,1,0,101,112,114,45,55,52,53,56,46,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,159,73,150,0,1,0,16,1,101,112,114,45,55,52,53,53,46,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,144,67,147,218,1,0,16,1,101,112,114,45,55,52,53,57,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,97,207,48,209,1,0,16,1,101,112,114,45,55,52,53,54,46,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,159,20,71,120,1,0,16,1,101,112,114,45,55,52,54,48,46,49,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,19,234,68,164,1,0,16,1,101,112,114,45,55,52,53,55,46,56,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,35,44,40,59,1,0,16,1,101,112,114,45,55,52,54,49,46,57,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,242,7,175,246,2,0,32,0,101,112,114,45,55,52,54,50,46,49,48,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,40,175,20,121,2,0,32,0,101,112,114,45,55,52,54,51,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,3,86,124,130,2,0,32,0,101,112,114,45,55,52,54,53,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,215,183,26,138,3,0,32,0,101,112,114,45,55,52,54,57,46,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,79,174,101,203,3,0,32,0,101,112,114,45,55,52,54,54,46,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,243,244,211,178,3,0,32,0,101,112,114,45,55,52,55,48,46,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,177,103,252,22,3,0,32,0,101,112,114,45,55,52,54,55,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,226,141,246,10,3,0,32,0,101,112,114,45,55,52,55,49,46,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,172,213,250,19,3,0,32,0,101,112,114,45,55,52,54,56,46,56,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,192,64,253,221,3,0,32,0,101,112,114,45,55,52,55,50,46,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,236,98,39,142,3,0,32,0,101,112,114,45,55,52,54,52,46,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,6,19,41,159,4,0,16,1,55,55,53,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,252,52,149,106,6,0,16,1,101,112,114,45,55,52,55,51,46,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,250,117,236,6,7,0,64,0,101,112,114,45,55,52,55,53,46,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,6,18,189,122,7,0,64,0,101,112,114,45,55,52,55,52,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,184,83,248,219,7,0,64,0,101,112,114,45,55,52,55,54,46,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,90,101,186,94,7,0,64,0,51,49,53,45,53,49,57,52,46,109,99,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,16,112,97,108,49,54,114,54,97,46,50,50,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,0,0,0,16,112,97,108,49,54,114,54,97,46,50,51,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,0,0,0,16,112,108,115,49,53,51,46,56,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,235,0,0,0,253,238,225,15,0,0,0,8,101,112,114,45,55,54,57,53,46,98,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,216,124,23,103,1,0,16,1,101,112,114,45,55,54,57,50,46,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,8,11,245,80,1,0,16,1,101,112,114,45,55,54,57,54,46,98,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,183,195,115,66,1,0,16,1,101,112,114,45,55,54,57,51,46,98,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,187,55,163,10,1,0,16,1,101,112,114,45,55,54,57,55,46,98,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,93,55,106,58,1,0,16,1,101,112,114,45,55,54,57,52,46,98,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,162,44,123,216,1,0,16,1,101,112,114,45,55,54,57,56,46,99,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,88,96,122,84,2,0,32,0,101,112,114,45,55,54,57,57,46,99,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,29,144,236,119,2,0,32,0,101,112,114,45,55,55,48,48,46,99,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,206,140,52,126,2,0,32,0,101,112,114,45,55,52,54,53,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,215,183,26,138,3,0,32,0,101,112,114,45,55,52,54,57,46,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,79,174,101,203,3,0,32,0,101,112,114,45,55,52,54,54,46,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,243,244,211,178,3,0,32,0,101,112,114,45,55,52,55,48,46,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,177,103,252,22,3,0,32,0,101,112,114,45,55,52,54,55,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,226,141,246,10,3,0,32,0,101,112,114,45,55,52,55,49,46,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,172,213,250,19,3,0,32,0,101,112,114,45,55,52,54,56,46,56,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,192,64,253,221,3,0,32,0,101,112,114,45,55,52,55,50,46,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,236,98,39,142,3,0,32,0,101,112,114,45,55,52,54,52,46,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,6,19,41,159,4,0,16,1,55,55,53,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,252,52,149,106,6,0,16,1,101,112,114,45,55,52,55,51,46,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,250,117,236,6,7,0,64,0,101,112,114,45,55,52,55,53,46,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,6,18,189,122,7,0,64,0,101,112,114,45,55,52,55,52,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,184,83,248,219,7,0,64,0,101,112,114,45,55,52,55,54,46,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,90,101,186,94,7,0,64,0,51,49,55,45,48,48,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,234,51,32,140,0,0,16,8,99,52,49,45,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,35,82,191,15,2,0,16,1,99,52,49,45,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,219,213,75,23,2,0,16,1,109,97,115,107,45,53,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,202,74,225,18,2,0,16,1,109,97,115,107,45,53,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,243,102,239,179,2,0,16,1,99,52,49,45,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,216,152,58,117,9,0,16,1,99,52,49,45,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,109,211,220,5,16,0,32,0,99,52,49,45,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,60,4,255,57,16,0,32,0,99,52,49,45,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,137,142,193,178,24,0,64,0,15,0,0,0,255,255,255,0,0,0,0,0,16,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,15,0,0,0,1,2,2,0,96,135,7,0,15,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,15,0,0,0,1,4,4,0,96,135,7,0,15,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,15,0,0,0,1,48,0,0,104,236,7,0,15,0,0,0,1,48,48,0,128,230,7,0,15,0,0,0,1,48,0,0,120,211,6,0,15,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,15,0,0,0,1,192,64,0,104,236,7,0,15,0,0,0,1,192,192,0,128,230,7,0,15,0,0,0,1,192,0,0,120,211,6,0,15,0,0,0,1,192,128,0,184,164,6,0,0,0,0,0,254,0,4,0,72,202,5,0,16,0,0,0,1,3,2,0,80,246,3,0,16,0,0,0,1,3,3,0,80,124,6,0,16,0,0,0,1,3,1,0,112,212,3,0,16,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,128,129,4,0,16,0,0,0,1,48,16,0,192,255,2,0,16,0,0,0,1,48,32,0,208,75,4,0,16,0,0,0,1,48,48,0,8,49,4,0,16,0,0,0,1,48,0,0,152,21,4,0,0,0,0,0,254,0,2,0,216,33,6,0,16,0,0,0,1,64,64,0,96,135,7,0,16,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,184,40,2,0,1,0,0,0,231,233,148,0,248,191,2,0,56,250,6,0,1,0,0,0,34,233,148,0,184,160,2,0,88,149,7,0,1,0,0,0,106,232,148,0,136,224,1,0,48,123,2,0,1,0,0,0,39,233,148,0,152,30,2,0,96,69,2,0,1,0,0,0,38,233,148,0,232,10,2,0,144,55,2,0,1,0,0,0,37,233,148,0,152,138,8,0,80,123,7,0,1,0,0,0,36,233,148,0,48,119,7,0,248,187,8,0,1,0,0,0,111,232,148,0,56,126,1,0,184,179,8,0,1,0,0,0,110,232,148,0,32,101,1,0,240,173,8,0,1,0,0,0,109,232,148,0,96,32,8,0,208,72,7,0,1,0,0,0,108,232,148,0,16,68,7,0,88,212,3,0,1,0,0,0,80,219,146,0,40,185,3,0,16,17,8,0,1,0,0,0,230,233,148,0,224,12,8,0,32,77,1,0,1,0,0,0,25,232,148,0,216,70,1,0,113,52,45,48,53,99,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,180,16,208,225,0,0,16,1,113,52,45,48,54,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,73,24,48,160,0,0,16,1,113,52,45,48,55,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,2,0,91,239,65,41,0,0,16,1,113,52,45,48,56,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,203,198,132,220,0,0,32,0,113,52,45,48,57,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,76,35,182,203,0,0,32,0,113,52,45,49,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,168,39,10,194,0,0,32,0,113,52,45,49,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,237,106,246,79,0,0,32,0,113,52,45,49,56,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,165,206,58,202,0,0,32,0,113,52,45,49,57,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,125,43,217,31,0,0,32,0,113,52,45,50,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,161,198,45,176,0,0,32,0,113,52,45,50,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,193,29,43,67,0,0,32,0,113,52,45,49,54,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,32,35,52,119,0,0,32,0,113,52,45,49,55,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,54,196,117,18,0,0,32,0,113,52,45,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,216,7,13,93,0,0,64,0,100,54,51,45,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,56,90,68,15,2,0,16,1,100,54,51,45,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,82,87,69,116,2,0,16,1,100,54,51,45,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,180,56,46,135,1,0,16,1,100,54,51,45,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,229,201,122,44,9,0,16,1,100,54,51,45,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,175,67,72,210,11,0,32,0,100,54,51,45,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,168,228,177,88,15,0,32,0,100,54,51,45,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,101,225,42,22,24,0,64,0,17,0,0,0,255,255,255,0,0,0,0,0,18,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,17,0,0,0,1,2,2,0,96,135,7,0,17,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,17,0,0,0,1,4,4,0,96,135,7,0,17,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,17,0,0,0,1,48,0,0,16,242,7,0,17,0,0,0,1,48,16,0,104,236,7,0,17,0,0,0,1,48,48,0,128,230,7,0,17,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,17,0,0,0,1,192,0,0,16,242,7,0,17,0,0,0,1,192,64,0,104,236,7,0,17,0,0,0,1,192,192,0,128,230,7,0,17,0,0,0,1,192,128,0,184,164,6,0,0,0,0,0,254,0,4,0,72,202,5,0,18,0,0,0,1,3,2,0,80,246,3,0,18,0,0,0,1,3,3,0,80,124,6,0,18,0,0,0,1,3,1,0,112,212,3,0,18,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,2,0,72,30,6,0,18,0,0,0,1,128,128,0,120,26,6,0,18,0,0,0,1,128,0,0,120,23,6,0,112,108,50,106,46,48,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,6,184,118,59,1,0,16,1,112,108,50,106,46,48,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,42,164,120,136,1,0,16,1,112,108,50,106,46,48,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,164,30,8,81,1,0,16,1,112,108,50,106,46,48,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,148,132,198,81,1,0,16,1,112,108,50,45,115,105,109,109,46,48,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,167,19,123,19,6,0,32,0,112,108,50,45,115,105,109,109,46,48,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,7,21,219,162,6,0,32,0,112,108,50,45,115,105,109,109,46,48,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,142,255,128,126,6,0,32,0,112,108,50,45,115,105,109,109,46,48,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,237,230,147,205,6,0,32,0,112,108,50,45,115,105,109,109,46,48,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,202,187,82,15,6,0,32,0,112,108,50,45,115,105,109,109,46,48,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,195,18,39,166,6,0,32,0,112,108,50,45,115,105,109,109,46,48,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,142,159,12,182,6,0,32,0,112,108,50,45,115,105,109,109,46,48,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,132,242,254,131,6,0,32,0,112,108,50,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,105,117,105,53,10,0,16,1,112,108,50,45,115,105,109,109,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,232,251,216,133,13,0,64,0,112,108,50,45,115,105,109,109,46,48,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,132,37,214,30,13,0,64,0,52,46,117,104,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,128,79,240,179,0,0,16,1,53,46,117,105,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,160,152,194,19,0,0,16,1,50,46,117,97,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,90,112,17,210,0,0,32,0,51,46,117,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,233,115,219,108,0,0,32,0,48,46,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,183,70,214,26,0,0,64,0,49,46,117,106,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,124,231,250,219,0,0,64,0,56,55,99,53,50,46,109,99,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,16,112,114,111,116,100,97,116,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,148,183,44,9,0,0,16,1,99,55,56,95,50,54,45,50,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,46,235,200,37,2,0,16,1,99,55,56,95,50,56,45,50,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,177,14,80,169,2,0,16,1,99,55,56,95,50,55,45,50,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,251,207,210,8,2,0,16,1,99,55,56,95,50,57,45,50,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,4,128,96,225,2,0,16,1,99,55,56,45,51,48,45,49,46,51,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,24,172,106,2,6,0,16,1,99,55,56,45,51,49,45,49,46,51,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,232,35,206,103,6,0,16,1,99,55,56,45,51,50,46,52,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,156,25,148,20,9,0,16,1,99,55,56,45,49,48,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,124,137,177,68,12,0,32,0,99,55,56,45,49,49,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,163,212,179,125,12,0,32,0,99,55,56,45,48,56,46,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,17,82,114,108,17,0,32,0,99,55,56,45,48,55,46,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,91,13,160,157,17,0,32,0,99,55,56,45,48,54,46,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,27,233,9,131,17,0,32,0,99,55,56,45,48,53,46,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,104,31,0,144,17,0,32,0,99,55,56,45,48,57,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,245,230,189,13,22,0,32,0,99,55,56,45,48,52,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,124,163,26,204,23,0,32,0,99,55,56,45,48,49,46,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,114,30,255,144,24,0,64,0,99,55,56,45,48,50,46,52,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,183,210,130,136,24,0,64,0,99,55,56,45,48,51,46,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,47,106,146,155,25,0,64,0,99,55,56,45,50,53,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,246,166,69,114,0,0,0,8,99,55,56,45,49,53,46,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,48,31,248,251,0,0,0,8,99,55,56,45,50,49,46,55,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,39,191,38,41,0,0,0,8,99,56,52,45,49,48,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,252,139,62,100,0,0,0,8,99,56,52,45,49,49,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,83,136,114,16,0,0,0,8,33,0,0,0,255,255,255,0,0,0,0,0,34,0,0,0,255,255,127,0,0,0,0,0,35,0,0,0,255,255,240,0,0,0,0,0,0,0,0,0,254,0,16,0,32,4,2,0,33,0,0,0,1,15,0,0,104,54,4,0,33,0,0,0,1,15,2,0,80,252,6,0,33,0,0,0,1,15,5,0,16,242,7,0,33,0,0,0,1,15,8,0,104,236,7,0,33,0,0,0,1,15,4,0,120,113,6,0,33,0,0,0,1,15,1,0,232,228,5,0,33,0,0,0,1,15,15,0,128,230,7,0,33,0,0,0,1,15,3,0,56,141,7,0,33,0,0,0,1,15,7,0,120,211,6,0,33,0,0,0,1,15,14,0,184,164,6,0,33,0,0,0,1,15,6,0,24,1,7,0,33,0,0,0,1,15,13,0,80,74,6,0,33,0,0,0,1,15,12,0,192,32,6,0,33,0,0,0,1,15,11,0,192,234,2,0,33,0,0,0,1,15,10,0,32,242,5,0,33,0,0,0,1,15,9,0,176,192,2,0,0,0,0,0,254,0,2,0,80,111,3,0,33,0,0,0,1,16,16,0,248,38,7,0,33,0,0,0,1,16,0,0,0,212,5,0,0,0,0,0,254,0,4,0,104,115,3,0,34,0,0,0,1,3,3,0,192,160,4,0,34,0,0,0,1,3,2,0,200,68,4,0,34,0,0,0,1,3,1,0,136,66,4,0,34,0,0,0,1,3,0,0,176,63,4,0,0,0,0,0,254,0,4,0,64,225,7,0,34,0,0,0,1,12,12,0,224,120,3,0,34,0,0,0,1,12,8,0,224,118,3,0,34,0,0,0,1,12,4,0,88,115,3,0,34,0,0,0,1,12,0,0,152,221,7,0,0,0,0,0,254,0,4,0,72,202,5,0,34,0,0,0,1,96,96,0,80,246,3,0,34,0,0,0,1,96,64,0,80,124,6,0,34,0,0,0,1,96,32,0,112,212,3,0,34,0,0,0,1,96,0,0,248,160,5,0,0,0,0,0,254,0,2,0,168,234,7,0,34,0,0,0,1,128,128,0,96,135,7,0,34,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,35,0,0,0,1,16,16,0,96,135,7,0,35,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,35,0,0,0,1,64,64,0,96,135,7,0,35,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,72,4,1,0,35,0,0,0,1,128,128,0,96,135,7,0,35,0,0,0,1,128,0,0,152,182,7,0,112,115,101,95,50,54,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,210,153,154,56,1,0,16,1,112,115,101,95,51,48,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,172,6,251,104,1,0,16,1,112,115,101,95,50,55,46,49,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,195,129,177,62,1,0,16,1,112,115,101,95,51,49,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,123,142,16,55,1,0,16,1,112,115,101,95,50,52,46,57,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,20,68,67,15,1,0,16,1,112,115,101,95,50,56,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,93,52,50,183,1,0,16,1,112,115,101,95,50,53,46,49,48,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,226,2,113,183,1,0,16,1,112,115,101,95,50,57,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,206,123,3,236,1,0,16,1,112,115,95,50,49,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,169,165,255,138,2,0,16,1,112,115,45,49,109,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,171,204,183,119,4,0,32,0,112,115,45,51,109,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,11,114,34,1,4,0,32,0,112,115,45,50,109,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,212,88,250,100,4,0,32,0,112,115,45,52,109,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,200,66,218,96,4,0,32,0,112,115,45,53,109,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,57,168,78,197,4,0,32,0,112,115,45,55,109,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,189,172,197,4,4,0,32,0,112,115,45,54,109,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,204,244,68,165,4,0,32,0,112,115,45,56,109,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,54,244,2,143,4,0,32,0,112,115,95,113,46,53,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,70,68,255,73,3,0,16,0,112,115,45,113,49,46,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,38,135,253,49,6,0,64,0,112,115,45,113,50,46,50,107,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,239,158,10,152,6,0,64,0,112,115,45,113,51,46,51,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,145,68,212,13,6,0,64,0,112,115,45,113,52,46,52,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,3,47,212,190,6,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,154,135,134,67,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,112,115,54,51,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,176,88,167,3,0,0,0,8,105,111,98,49,46,49,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,98,112,114,103,49,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,167,61,121,49,0,0,0,8,105,111,99,49,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,129,32,24,13,0,0,0,8,100,55,108,49,46,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,13,65,183,39,0,0,0,8,100,56,108,49,46,56,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,218,199,159,83,0,0,0,8,100,57,107,50,46,57,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,86,161,133,205,0,0,0,8,100,49,48,102,49,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,148,196,25,102,0,0,0,8,112,115,98,53,98,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,5,44,244,88,1,0,16,1,112,115,98,51,98,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,180,61,17,144,1,0,16,1,112,115,98,52,97,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,133,84,90,102,1,0,16,1,112,115,98,50,97,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,57,63,177,215,1,0,16,1,112,115,98,45,97,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,227,245,240,87,4,0,32,0,112,115,98,45,98,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,126,134,235,217,4,0,32,0,112,114,103,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,99,21,21,195,1,0,16,1,112,114,103,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,172,147,37,140,1,0,16,1,112,114,103,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,133,84,90,102,1,0,16,1,112,114,103,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,57,63,177,215,1,0,16,1,112,117,49,49,50,53,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,234,250,129,101,4,0,32,0,112,117,49,51,52,55,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,228,61,97,97,4,0,32,0,112,105,99,49,54,99,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,7,0,16,16,115,111,117,110,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,198,157,236,174,5,0,64,0,57,51,99,52,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,125,78,171,54,0,0,0,8,99,57,56,45,49,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,222,108,109,129,2,0,16,1,99,57,56,45,49,54,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,119,92,223,89,2,0,16,1,99,57,56,45,48,54,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,69,27,167,100,2,0,16,1,99,57,56,45,48,55,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,192,91,25,144,2,0,16,1,99,57,56,45,49,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,124,225,88,168,9,0,16,1,99,57,56,45,48,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,178,227,31,14,11,0,32,0,99,57,56,45,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,179,210,42,74,15,0,32,0,99,57,56,45,48,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,143,103,154,88,15,0,32,0,99,57,56,45,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,245,102,127,25,24,0,64,0,99,57,56,45,48,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,57,156,221,157,28,0,32,0,21,0,0,0,255,255,255,0,0,0,0,0,22,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,21,0,0,0,1,2,2,0,96,135,7,0,21,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,21,0,0,0,1,4,4,0,96,135,7,0,21,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,21,0,0,0,1,8,0,0,96,135,7,0,21,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,21,0,0,0,1,48,0,0,80,252,6,0,21,0,0,0,1,48,16,0,16,242,7,0,21,0,0,0,1,48,32,0,104,236,7,0,21,0,0,0,1,48,48,0,128,230,7,0,0,0,0,0,254,0,4,0,160,123,6,0,21,0,0,0,1,192,192,0,8,201,6,0,21,0,0,0,1,192,128,0,200,197,6,0,21,0,0,0,1,192,64,0,152,194,6,0,21,0,0,0,1,192,0,0,248,189,6,0,0,0,0,0,254,0,4,0,72,202,5,0,22,0,0,0,1,3,2,0,80,246,3,0,22,0,0,0,1,3,3,0,80,124,6,0,22,0,0,0,1,3,1,0,112,212,3,0,22,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,3,0,80,1,6,0,22,0,0,0,1,12,12,0,8,49,4,0,22,0,0,0,1,12,8,0,152,21,4,0,22,0,0,0,1,12,4,0,72,246,3,0,0,0,0,0,254,0,4,0,128,129,4,0,22,0,0,0,1,48,32,0,208,75,4,0,22,0,0,0,1,48,48,0,8,49,4,0,22,0,0,0,1,48,16,0,152,21,4,0,22,0,0,0,1,48,0,0,72,246,3,0,0,0,0,0,254,0,2,0,144,212,6,0,22,0,0,0,1,128,0,0,8,208,6,0,22,0,0,0,1,128,128,0,88,204,6,0,26,0,0,0,255,255,159,0,0,0,0,0,27,0,0,0,255,255,253,0,0,0,0,0,0,0,0,0,254,0,2,0,72,8,1,0,26,0,0,0,1,32,32,0,56,111,3,0,26,0,0,0,1,32,0,0,104,134,3,0,0,0,0,0,254,0,2,0,168,234,7,0,26,0,0,0,1,64,64,0,96,135,7,0,26,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,26,0,0,0,1,128,128,0,96,135,7,0,26,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,27,0,0,0,1,1,1,0,96,135,7,0,27,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,88,160,1,0,27,0,0,0,1,4,4,0,136,86,1,0,27,0,0,0,1,4,0,0,184,147,6,0,0,0,0,0,254,0,2,0,96,46,8,0,27,0,0,0,1,8,8,0,192,255,2,0,27,0,0,0,1,8,0,0,208,75,4,0,0,0,0,0,254,0,16,0,32,4,2,0,27,0,0,0,1,240,160,0,144,160,3,0,27,0,0,0,1,240,176,0,96,135,3,0,27,0,0,0,1,240,192,0,32,136,7,0,27,0,0,0,1,240,208,0,40,88,7,0,27,0,0,0,1,240,224,0,96,39,7,0,27,0,0,0,1,240,16,0,32,202,2,0,27,0,0,0,1,240,48,0,120,113,6,0,27,0,0,0,1,240,32,0,232,228,5,0,27,0,0,0,1,240,240,0,144,251,6,0,27,0,0,0,1,240,64,0,120,211,6,0,27,0,0,0,1,240,144,0,184,164,6,0,27,0,0,0,1,240,128,0,80,74,6,0,27,0,0,0,1,240,112,0,192,32,6,0,27,0,0,0,1,240,96,0,192,234,2,0,27,0,0,0,1,240,80,0,32,242,5,0,27,0,0,0,1,240,0,0,16,227,4,0,0,0,0,0,112,103,97,106,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,84,186,219,6,1,0,16,1,112,103,97,106,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,188,241,241,161,1,0,16,1,112,103,97,45,115,105,109,109,46,48,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,176,152,47,69,6,0,32,0,112,103,97,45,115,105,109,109,46,48,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,146,32,103,158,6,0,32,0,112,103,97,45,115,105,109,109,46,48,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,254,218,157,174,6,0,32,0,112,103,97,45,115,105,109,109,46,48,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,148,45,215,148,6,0,32,0,112,103,97,45,115,105,109,109,46,48,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,109,136,161,72,6,0,32,0,112,103,97,45,115,105,109,109,46,48,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,55,126,45,23,6,0,32,0,112,103,97,45,115,105,109,109,46,48,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,152,61,227,158,6,0,32,0,112,103,97,45,115,105,109,109,46,48,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,50,238,141,132,6,0,32,0,112,103,97,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,146,169,191,189,10,0,16,1,112,103,97,45,115,105,109,109,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,12,200,170,192,13,0,64,0,112,103,97,45,115,105,109,109,46,48,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,134,93,166,55,13,0,64,0,112,103,97,45,115,105,109,109,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,52,233,241,211,13,0,64,0,112,103,97,45,115,105,109,109,46,48,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,154,72,57,139,13,0,64,0,112,103,97,97,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,206,226,230,37,1,0,16,1,112,103,97,97,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,126,48,4,129,1,0,16,1,112,103,97,45,115,105,109,109,46,48,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,176,152,47,69,6,0,32,0,112,103,97,45,115,105,109,109,46,48,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,146,32,103,158,6,0,32,0,112,103,97,45,115,105,109,109,46,48,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,254,218,157,174,6,0,32,0,112,103,97,45,115,105,109,109,46,48,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,148,45,215,148,6,0,32,0,112,103,97,45,115,105,109,109,46,48,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,109,136,161,72,6,0,32,0,112,103,97,45,115,105,109,109,46,48,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,55,126,45,23,6,0,32,0,112,103,97,45,115,105,109,109,46,48,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,152,61,227,158,6,0,32,0,112,103,97,45,115,105,109,109,46,48,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,50,238,141,132,6,0,32,0,112,103,97,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,146,169,191,189,10,0,16,1,112,103,97,45,115,105,109,109,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,12,200,170,192,13,0,64,0,112,103,97,45,115,105,109,109,46,48,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,134,93,166,55,13,0,64,0,112,103,97,45,115,105,109,109,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,52,233,241,211,13,0,64,0,112,103,97,45,115,105,109,109,46,48,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,154,72,57,139,13,0,64,0,103,116,45,117,50,46,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,187,73,79,161,0,0,16,1,103,116,45,117,51,46,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,126,117,101,241,0,0,16,1,103,116,49,53,46,98,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,18,36,101,172,0,0,32,0,112,105,56,57,49,52,46,98,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,135,97,125,32,0,0,32,0,112,105,56,57,49,54,46,104,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,246,224,255,124,0,0,32,0,112,105,56,57,49,48,46,107,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,11,27,16,90,0,0,32,0,103,116,53,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,115,178,58,61,0,0,32,0,103,116,49,49,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,240,252,240,180,0,0,32,0,103,116,49,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,147,192,164,128,0,0,64,0,103,116,52,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,236,185,223,133,0,0,64,0,103,116,45,107,50,46,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,77,84,211,242,0,0,16,1,103,116,45,107,51,46,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,155,67,247,235,0,0,16,1,103,116,49,53,46,98,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,18,36,101,172,0,0,32,0,112,105,56,57,49,52,46,98,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,135,97,125,32,0,0,32,0,112,105,56,57,49,54,46,104,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,246,224,255,124,0,0,32,0,112,105,56,57,49,48,46,107,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,11,27,16,90,0,0,32,0,103,116,53,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,115,178,58,61,0,0,32,0,103,116,49,49,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,240,252,240,180,0,0,32,0,103,116,49,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,147,192,164,128,0,0,64,0,103,116,52,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,236,185,223,133,0,0,64,0,103,116,45,101,50,46,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,90,36,131,112,0,0,16,1,103,116,45,101,51,46,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,88,223,140,109,0,0,16,1,103,116,49,53,46,98,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,18,36,101,172,0,0,32,0,112,105,56,57,49,52,46,98,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,135,97,125,32,0,0,32,0,112,105,56,57,49,54,46,104,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,246,224,255,124,0,0,32,0,112,105,56,57,49,48,46,107,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,11,27,16,90,0,0,32,0,103,116,53,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,115,178,58,61,0,0,32,0,103,116,49,49,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,240,252,240,180,0,0,32,0,103,116,49,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,147,192,164,128,0,0,64,0,103,116,52,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,236,185,223,133,0,0,64,0,22,0,0,0,255,255,255,0,0,0,0,0,23,0,0,0,255,255,127,0,0,0,0,0,0,0,0,0,254,0,2,0,224,222,6,0,22,0,0,0,1,1,1,0,248,38,7,0,22,0,0,0,1,1,0,0,88,135,6,0,0,0,0,0,254,0,2,0,104,81,2,0,22,0,0,0,1,2,2,0,96,135,7,0,22,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,200,73,5,0,22,0,0,0,1,4,4,0,40,172,5,0,22,0,0,0,1,4,0,0,112,136,5,0,0,0,0,0,254,0,4,0,32,4,2,0,22,0,0,0,1,48,48,0,192,77,5,0,22,0,0,0,1,48,32,0,8,46,5,0,22,0,0,0,1,48,16,0,56,16,5,0,22,0,0,0,1,48,0,0,136,237,4,0,0,0,0,0,254,0,4,0,32,202,4,0,22,0,0,0,1,192,128,0,208,75,4,0,22,0,0,0,1,192,192,0,8,49,4,0,22,0,0,0,1,192,64,0,152,21,4,0,22,0,0,0,1,192,0,0,72,246,3,0,0,0,0,0,254,0,4,0,16,57,4,0,23,0,0,0,1,3,2,0,144,29,4,0,23,0,0,0,1,3,3,0,184,0,4,0,23,0,0,0,1,3,1,0,88,223,3,0,23,0,0,0,1,3,0,0,32,193,3,0,0,0,0,0,254,0,4,0,168,79,2,0,23,0,0,0,1,12,8,0,248,141,3,0,23,0,0,0,1,12,12,0,144,118,3,0,23,0,0,0,1,12,0,0,144,95,3,0,23,0,0,0,1,12,4,0,120,80,3,0,0,0,0,0,254,0,4,0,176,65,3,0,23,0,0,0,1,48,48,0,16,50,3,0,23,0,0,0,1,48,32,0,168,30,3,0,23,0,0,0,1,48,16,0,184,6,3,0,23,0,0,0,1,48,0,0,88,240,2,0,0,0,0,0,254,0,2,0,80,111,3,0,23,0,0,0,1,64,0,0,96,135,7,0,23,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,184,40,2,0,1,0,0,0,40,39,216,0,248,191,2,0,184,164,8,0,1,0,0,0,41,39,216,0,64,246,1,0,240,167,7,0,1,0,0,0,44,39,216,0,192,135,2,0,176,163,7,0,1,0,0,0,47,39,216,0,240,108,2,0,208,158,7,0,1,0,0,0,42,39,216,0,96,82,2,0,184,154,7,0,1,0,0,0,43,39,216,0,32,56,2,0,176,108,2,0,1,0,0,0,32,39,216,0,152,30,2,0,8,96,7,0,1,0,0,0,36,39,216,0,72,198,1,0,48,89,7,0,1,0,0,0,39,39,216,0,24,182,1,0,16,83,7,0,1,0,0,0,34,39,216,0,40,167,1,0,96,79,7,0,1,0,0,0,35,39,216,0,200,149,1,0,48,76,7,0,1,0,0,0,33,39,216,0,56,126,1,0,88,212,3,0,1,0,0,0,48,38,216,0,40,185,3,0,248,5,8,0,9,0,0,0,112,39,216,0,32,58,1,0,144,250,7,0,9,0,0,0,113,39,216,0,32,58,1,0,248,241,7,0,9,0,0,0,114,39,216,0,32,58,1,0,18,0,0,0,255,255,250,0,0,0,0,0,19,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,168,234,7,0,18,0,0,0,1,2,0,0,96,135,7,0,18,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,19,0,0,0,1,24,16,0,80,246,3,0,19,0,0,0,1,24,24,0,248,38,7,0,19,0,0,0,1,24,8,0,112,212,3,0,19,0,0,0,1,24,0,0,248,160,5,0,0,0,0,0,254,0,8,0,32,4,2,0,19,0,0,0,1,224,0,0,32,136,7,0,19,0,0,0,1,224,32,0,40,88,7,0,19,0,0,0,1,224,64,0,96,39,7,0,19,0,0,0,1,224,96,0,120,113,6,0,19,0,0,0,1,224,224,0,144,251,6,0,19,0,0,0,1,224,128,0,120,211,6,0,19,0,0,0,1,224,192,0,184,164,6,0,19,0,0,0,1,224,160,0,80,74,6,0,0,0,0,0,112,119,106,95,48,54,46,49,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,38,100,10,74,0,0,16,1,112,119,106,95,48,55,46,49,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,32,36,64,169,0,0,16,1,112,119,95,48,50,46,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,228,146,89,75,0,0,32,0,98,98,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,8,237,168,121,0,0,32,0,112,119,106,95,48,52,46,49,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,129,144,228,1,0,0,32,0,98,98,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,108,219,179,47,0,0,32,0,98,98,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,110,79,186,253,0,0,32,0,98,98,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,99,122,244,57,0,0,32,0,98,98,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,142,91,46,197,0,0,64,0,168,86,7,0,1,0,0,0,232,47,216,0,248,191,2,0,24,38,7,0,1,0,0,0,236,47,216,0,184,160,2,0,56,210,6,0,1,0,0,0,35,48,216,0,192,135,2,0,24,163,6,0,1,0,0,0,34,48,216,0,240,108,2,0,152,122,6,0,1,0,0,0,33,48,216,0,96,82,2,0,192,72,6,0,1,0,0,0,32,48,216,0,32,56,2,0,240,13,7,0,1,0,0,0,36,48,216,0,152,30,2,0,64,2,7,0,1,0,0,0,37,48,216,0,232,10,2,0,40,246,1,0,1,0,0,0,233,47,216,0,64,246,1,0,144,236,1,0,1,0,0,0,237,47,216,0,136,224,1,0,176,223,1,0,1,0,0,0,43,48,216,0,72,198,1,0,192,209,1,0,1,0,0,0,42,48,216,0,24,182,1,0,24,198,1,0,1,0,0,0,41,48,216,0,40,167,1,0,120,189,1,0,1,0,0,0,40,48,216,0,200,149,1,0,8,9,7,0,1,0,0,0,44,48,216,0,56,126,1,0,248,251,6,0,1,0,0,0,45,48,216,0,32,101,1,0,88,212,3,0,1,0,0,0,144,46,216,0,40,185,3,0,240,152,1,0,1,0,0,0,238,47,216,0,216,70,1,0,16,17,8,0,1,0,0,0,234,47,216,0,224,12,8,0,72,65,1,0,9,0,0,0,232,48,216,0,32,58,1,0,48,50,1,0,9,0,0,0,224,48,216,0,32,58,1,0,224,41,1,0,9,0,0,0,216,48,216,0,32,58,1,0,13,0,0,0,255,255,255,0,0,0,0,0,14,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,13,0,0,0,1,1,0,0,120,97,1,0,13,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,2,0,144,212,8,0,13,0,0,0,1,2,2,0,96,135,7,0,13,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,13,0,0,0,1,4,4,0,96,135,7,0,13,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,13,0,0,0,1,8,0,0,96,135,7,0,13,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,13,0,0,0,1,48,16,0,96,39,7,0,13,0,0,0,1,48,48,0,144,251,6,0,13,0,0,0,1,48,0,0,120,211,6,0,13,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,13,0,0,0,1,192,64,0,96,39,7,0,13,0,0,0,1,192,192,0,144,251,6,0,13,0,0,0,1,192,0,0,120,211,6,0,13,0,0,0,1,192,128,0,184,164,6,0,0,0,0,0,254,0,4,0,72,202,5,0,14,0,0,0,1,3,2,0,80,246,3,0,14,0,0,0,1,3,3,0,80,124,6,0,14,0,0,0,1,3,1,0,112,212,3,0,14,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,64,37,5,0,14,0,0,0,1,12,8,0,120,160,1,0,14,0,0,0,1,12,12,0,104,150,1,0,14,0,0,0,1,12,4,0,40,141,1,0,14,0,0,0,1,12,0,0,160,126,1,0,0,0,0,0,254,0,0,0,128,129,4,0,14,0,0,0,1,48,32,0,208,75,4,0,14,0,0,0,1,48,48,0,8,49,4,0,14,0,0,0,1,48,16,0,152,21,4,0,14,0,0,0,1,48,0,0,72,246,3,0,0,0,0,0,254,0,2,0,104,159,3,0,12,0,0,0,1,128,0,0,56,111,3,0,12,0,0,0,1,128,128,0,104,134,3,0,20,0,0,0,255,255,255,0,0,0,0,0,21,0,0,0,255,255,127,0,0,0,0,0,0,0,0,0,254,0,8,0,200,87,7,0,20,0,0,0,1,7,0,0,40,88,7,0,20,0,0,0,1,7,1,0,96,39,7,0,20,0,0,0,1,7,7,0,144,251,6,0,20,0,0,0,1,7,6,0,184,164,6,0,20,0,0,0,1,7,5,0,80,74,6,0,20,0,0,0,1,7,4,0,192,32,6,0,20,0,0,0,1,7,3,0,192,234,2,0,20,0,0,0,1,7,2,0,32,242,5,0,0,0,0,0,254,0,8,0,160,123,6,0,20,0,0,0,1,56,0,0,40,88,7,0,20,0,0,0,1,56,8,0,96,39,7,0,20,0,0,0,1,56,56,0,144,251,6,0,20,0,0,0,1,56,48,0,184,164,6,0,20,0,0,0,1,56,40,0,80,74,6,0,20,0,0,0,1,56,32,0,192,32,6,0,20,0,0,0,1,56,24,0,192,234,2,0,20,0,0,0,1,56,16,0,32,242,5,0,0,0,0,0,254,0,2,0,144,212,8,0,20,0,0,0,1,64,64,0,96,135,7,0,20,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,24,172,6,0,20,0,0,0,1,128,128,0,96,135,7,0,20,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,21,0,0,0,1,3,0,0,208,75,4,0,21,0,0,0,1,3,1,0,8,49,4,0,21,0,0,0,1,3,3,0,152,21,4,0,21,0,0,0,1,3,2,0,72,246,3,0,0,0,0,0,254,0,4,0,112,59,6,0,21,0,0,0,1,12,0,0,176,63,4,0,21,0,0,0,1,12,4,0,56,43,1,0,21,0,0,0,1,12,12,0,80,167,5,0,21,0,0,0,1,12,8,0,40,157,5,0,0,0,0,0,254,0,2,0,16,227,4,0,21,0,0,0,1,32,32,0,96,135,7,0,21,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,21,0,0,0,1,128,128,0,96,135,7,0,21,0,0,0,1,128,0,0,152,182,7,0,112,107,111,45,112,114,103,49,46,49,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,148,90,88,134,0,0,16,1,112,107,111,45,112,114,103,50,46,49,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,45,232,203,134,0,0,16,1,112,107,111,45,48,48,49,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,155,93,173,30,0,0,32,0,112,107,111,45,48,48,51,46,56,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,230,180,154,51,0,0,32,0,112,107,111,45,48,48,50,46,57,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,134,37,240,28,0,0,32,0,112,107,111,45,48,48,52,46,57,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,66,180,204,9,0,0,32,0,112,107,111,45,99,104,114,49,46,50,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,205,51,206,49,0,0,32,0,112,107,111,45,99,104,114,50,46,51,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,95,5,126,173,0,0,32,0,112,107,111,45,118,111,105,49,46,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,49,245,224,7,0,0,64,0,112,107,111,45,118,111,105,50,46,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,246,139,57,24,0,0,64,0,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,222,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,19,0,0,0,1,15,7,0,80,252,6,0,19,0,0,0,1,15,8,0,16,242,7,0,19,0,0,0,1,15,9,0,104,236,7,0,19,0,0,0,1,15,5,0,192,54,8,0,19,0,0,0,1,15,4,0,56,24,4,0,19,0,0,0,1,15,15,0,128,230,7,0,19,0,0,0,1,15,0,0,128,230,7,0,19,0,0,0,1,15,3,0,176,162,3,0,19,0,0,0,1,15,2,0,24,188,3,0,19,0,0,0,1,15,1,0,72,216,3,0,19,0,0,0,1,15,6,0,120,211,6,0,19,0,0,0,1,15,14,0,184,164,6,0,19,0,0,0,1,15,13,0,80,74,6,0,19,0,0,0,1,15,12,0,192,32,6,0,19,0,0,0,1,15,11,0,192,234,2,0,19,0,0,0,1,15,10,0,32,242,5,0,0,0,0,0,254,0,16,0,160,123,6,0,19,0,0,0,1,240,112,0,80,252,6,0,19,0,0,0,1,240,128,0,16,242,7,0,19,0,0,0,1,240,144,0,104,236,7,0,19,0,0,0,1,240,80,0,192,54,8,0,19,0,0,0,1,240,64,0,56,24,4,0,19,0,0,0,1,240,240,0,128,230,7,0,19,0,0,0,1,240,0,0,128,230,7,0,19,0,0,0,1,240,48,0,176,162,3,0,19,0,0,0,1,240,32,0,24,188,3,0,19,0,0,0,1,240,16,0,72,216,3,0,19,0,0,0,1,240,96,0,120,211,6,0,19,0,0,0,1,240,224,0,184,164,6,0,19,0,0,0,1,240,208,0,80,74,6,0,19,0,0,0,1,240,192,0,192,32,6,0,19,0,0,0,1,240,176,0,192,234,2,0,19,0,0,0,1,240,160,0,32,242,5,0,0,0,0,0,254,0,2,0,200,30,2,0,20,0,0,0,1,1,0,0,120,97,1,0,20,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,6,6,0,8,49,4,0,20,0,0,0,1,6,4,0,152,21,4,0,20,0,0,0,1,6,2,0,72,246,3,0,20,0,0,0,1,6,0,0,112,49,6,0,0,0,0,0,254,0,4,0,0,118,5,0,20,0,0,0,1,24,24,0,192,255,2,0,20,0,0,0,1,24,16,0,208,75,4,0,20,0,0,0,1,24,8,0,8,49,4,0,20,0,0,0,1,24,0,0,152,21,4,0,0,0,0,0,254,0,2,0,104,159,3,0,20,0,0,0,1,32,32,0,96,135,7,0,20,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,112,59,6,0,20,0,0,0,1,64,0,0,8,134,4,0,20,0,0,0,1,64,64,0,136,127,4,0,0,0,0,0,101,112,114,54,52,53,54,97,46,49,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,107,64,200,188,0,0,16,1,101,112,114,54,52,53,55,97,46,49,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,42,253,22,160,0,0,16,1,101,112,114,54,52,53,56,97,46,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,232,179,48,92,0,0,16,1,101,112,114,45,54,52,54,50,46,49,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,133,145,187,134,0,0,16,1,101,112,114,54,52,55,52,97,46,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,185,17,23,159,0,0,32,0,101,112,114,54,52,55,51,97,46,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,221,184,83,142,0,0,32,0,101,112,114,54,52,55,50,97,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,17,74,243,224,0,0,32,0,101,112,114,54,52,55,49,97,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,92,128,188,213,0,0,32,0,101,112,114,54,52,55,48,97,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,159,114,57,20,0,0,32,0,101,112,114,54,52,54,57,97,46,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,33,105,172,228,0,0,32,0,101,112,114,54,52,53,52,97,46,49,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,128,103,217,165,0,0,32,0,101,112,114,45,54,52,53,53,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,161,100,238,50,0,0,32,0,112,114,45,53,51,49,55,46,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,184,80,131,100,0,0,0,8,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,220,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,19,0,0,0,1,15,7,0,80,252,6,0,19,0,0,0,1,15,8,0,16,242,7,0,19,0,0,0,1,15,9,0,104,236,7,0,19,0,0,0,1,15,5,0,192,54,8,0,19,0,0,0,1,15,4,0,56,24,4,0,19,0,0,0,1,15,15,0,128,230,7,0,19,0,0,0,1,15,0,0,128,230,7,0,19,0,0,0,1,15,3,0,176,162,3,0,19,0,0,0,1,15,2,0,24,188,3,0,19,0,0,0,1,15,1,0,72,216,3,0,19,0,0,0,1,15,6,0,120,211,6,0,19,0,0,0,1,15,14,0,184,164,6,0,19,0,0,0,1,15,13,0,80,74,6,0,19,0,0,0,1,15,12,0,192,32,6,0,19,0,0,0,1,15,11,0,192,234,2,0,19,0,0,0,1,15,10,0,32,242,5,0,0,0,0,0,254,0,16,0,160,123,6,0,19,0,0,0,1,240,112,0,80,252,6,0,19,0,0,0,1,240,128,0,16,242,7,0,19,0,0,0,1,240,144,0,104,236,7,0,19,0,0,0,1,240,80,0,192,54,8,0,19,0,0,0,1,240,64,0,56,24,4,0,19,0,0,0,1,240,240,0,128,230,7,0,19,0,0,0,1,240,0,0,128,230,7,0,19,0,0,0,1,240,48,0,176,162,3,0,19,0,0,0,1,240,32,0,24,188,3,0,19,0,0,0,1,240,16,0,72,216,3,0,19,0,0,0,1,240,96,0,120,211,6,0,19,0,0,0,1,240,224,0,184,164,6,0,19,0,0,0,1,240,208,0,80,74,6,0,19,0,0,0,1,240,192,0,192,32,6,0,19,0,0,0,1,240,176,0,192,234,2,0,19,0,0,0,1,240,160,0,32,242,5,0,0,0,0,0,254,0,2,0,200,30,2,0,20,0,0,0,1,1,0,0,120,97,1,0,20,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,2,0,168,234,7,0,20,0,0,0,1,2,2,0,96,135,7,0,20,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,12,12,0,8,49,4,0,20,0,0,0,1,12,8,0,152,21,4,0,20,0,0,0,1,12,4,0,72,246,3,0,20,0,0,0,1,12,0,0,112,49,6,0,0,0,0,0,254,0,2,0,64,37,5,0,20,0,0,0,1,16,16,0,120,176,7,0,20,0,0,0,1,16,0,0,152,172,7,0,0,0,0,0,254,0,2,0,104,159,3,0,20,0,0,0,1,32,32,0,96,135,7,0,20,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,112,59,6,0,20,0,0,0,1,64,0,0,8,134,4,0,20,0,0,0,1,64,64,0,136,127,4,0,184,40,2,0,1,0,0,0,41,39,216,0,248,191,2,0,56,250,6,0,1,0,0,0,32,39,216,0,184,160,2,0,184,164,8,0,1,0,0,0,40,39,216,0,64,246,1,0,88,149,7,0,1,0,0,0,33,39,216,0,136,224,1,0,208,158,7,0,1,0,0,0,42,39,216,0,96,82,2,0,184,154,7,0,1,0,0,0,43,39,216,0,32,56,2,0,176,108,2,0,1,0,0,0,44,39,216,0,152,30,2,0,16,83,7,0,1,0,0,0,34,39,216,0,40,167,1,0,96,79,7,0,1,0,0,0,35,39,216,0,200,149,1,0,48,76,7,0,1,0,0,0,36,39,216,0,56,126,1,0,88,212,3,0,1,0,0,0,48,38,216,0,40,185,3,0,248,5,8,0,9,0,0,0,112,39,216,0,32,58,1,0,144,250,7,0,9,0,0,0,113,39,216,0,32,58,1,0,248,241,7,0,9,0,0,0,114,39,216,0,32,58,1,0,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,81,253,220,246,1,0,16,1,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,54,25,149,222,1,0,16,1,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,218,242,58,122,1,0,16,1,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,50,173,32,200,1,0,16,1,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,51,50,232,8,1,0,16,1,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,214,185,31,243,1,0,16,1,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,193,128,164,211,1,0,16,1,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,158,119,249,237,1,0,16,1,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,22,0,87,155,5,0,32,0,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,31,123,101,26,5,0,32,0,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,68,98,149,115,6,0,32,0,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,229,72,43,122,6,0,32,0,115,110,55,52,115,50,56,56,110,46,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,135,125,12,106,7,0,32,0,15,0,0,0,255,255,0,0,0,0,0,0,16,0,0,0,255,255,192,0,0,0,0,0,17,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,200,87,7,0,16,0,0,0,1,64,0,0,224,127,8,0,16,0,0,0,1,64,64,0,32,123,8,0,0,0,0,0,254,0,2,0,160,123,6,0,16,0,0,0,1,128,128,0,0,90,2,0,16,0,0,0,1,128,0,0,104,61,2,0,0,0,0,0,254,0,2,0,72,202,5,0,17,0,0,0,1,2,0,0,80,246,3,0,17,0,0,0,1,2,2,0,112,212,3,0,0,0,0,0,254,0,2,0,128,129,4,0,17,0,0,0,1,4,0,0,8,49,4,0,17,0,0,0,1,4,4,0,72,246,3,0,0,0,0,0,254,0,2,0,200,30,2,0,17,0,0,0,1,8,0,0,120,97,1,0,17,0,0,0,1,8,8,0,96,19,1,0,14,0,0,0,255,255,32,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,14,0,0,0,1,3,0,0,8,49,4,0,14,0,0,0,1,3,1,0,152,21,4,0,14,0,0,0,1,3,2,0,72,246,3,0,14,0,0,0,1,3,3,0,72,0,3,0,0,0,0,0,254,0,8,0,32,4,2,0,14,0,0,0,1,28,8,0,40,88,7,0,14,0,0,0,1,28,16,0,96,39,7,0,14,0,0,0,1,28,0,0,144,251,6,0,14,0,0,0,1,28,24,0,184,164,6,0,14,0,0,0,1,28,4,0,80,74,6,0,14,0,0,0,1,28,12,0,192,32,6,0,14,0,0,0,1,28,20,0,192,234,2,0,14,0,0,0,1,28,28,0,32,242,5,0,0,0,0,0,254,0,2,0,88,41,7,0,14,0,0,0,1,32,0,0,88,244,4,0,14,0,0,0,1,32,32,0,184,151,2,0,0,0,0,0,254,0,4,0,64,37,5,0,14,0,0,0,1,192,0,0,80,110,6,0,14,0,0,0,1,192,64,0,152,53,6,0,14,0,0,0,1,192,128,0,112,216,4,0,14,0,0,0,1,192,192,0,144,138,7,0,0,0,0,0,101,112,114,45,49,49,56,53,51,46,97,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,231,55,179,250,1,0,16,1,101,112,114,45,49,49,56,53,50,46,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,252,129,42,137,1,0,16,1,111,112,114,45,49,49,56,53,52,46,98,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,108,11,28,211,2,0,32,0,111,112,114,45,49,49,56,53,53,46,98,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,180,98,135,183,2,0,32,0,111,112,114,45,49,49,56,53,54,46,98,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,102,246,73,234,2,0,32,0,111,112,114,45,49,49,56,54,50,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,39,71,233,182,3,0,32,0,111,112,114,45,49,49,56,54,53,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,213,213,232,23,3,0,32,0,111,112,114,45,49,49,56,54,51,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,152,0,103,62,3,0,32,0,111,112,114,45,49,49,56,54,54,46,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,204,113,235,80,3,0,32,0,111,112,114,45,49,49,56,54,52,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,168,60,115,5,3,0,32,0,111,112,114,45,49,49,56,54,55,46,98,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,151,150,228,129,3,0,32,0,101,112,114,45,49,49,56,53,55,46,97,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,6,220,158,120,4,0,16,1,101,112,114,45,49,49,56,53,56,46,97,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,24,0,171,8,8,0,64,0,101,112,114,45,49,49,56,53,57,46,97,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,27,224,115,134,8,0,64,0,101,112,114,45,49,49,56,54,48,46,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,70,55,38,16,8,0,64,0,101,112,114,45,49,49,56,54,49,46,97,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,113,74,181,56,8,0,64,0,51,49,55,45,48,48,55,48,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,170,8,3,93,5,0,16,1,56,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,57,193,77,184,1,0,16,1,53,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,223,41,254,239,1,0,16,1,111,112,114,45,49,49,56,53,52,46,98,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,108,11,28,211,2,0,32,0,111,112,114,45,49,49,56,53,53,46,98,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,180,98,135,183,2,0,32,0,111,112,114,45,49,49,56,53,54,46,98,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,102,246,73,234,2,0,32,0,111,112,114,45,49,49,56,54,50,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,39,71,233,182,3,0,32,0,111,112,114,45,49,49,56,54,53,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,213,213,232,23,3,0,32,0,111,112,114,45,49,49,56,54,51,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,152,0,103,62,3,0,32,0,111,112,114,45,49,49,56,54,54,46,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,204,113,235,80,3,0,32,0,111,112,114,45,49,49,56,54,52,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,168,60,115,5,3,0,32,0,111,112,114,45,49,49,56,54,55,46,98,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,151,150,228,129,3,0,32,0,101,112,114,45,49,49,56,53,55,46,97,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,6,220,158,120,4,0,16,1,101,112,114,45,49,49,56,53,56,46,97,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,24,0,171,8,8,0,64,0,101,112,114,45,49,49,56,53,57,46,97,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,27,224,115,134,8,0,64,0,101,112,114,45,49,49,56,54,48,46,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,70,55,38,16,8,0,64,0,101,112,114,45,49,49,56,54,49,46,97,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,113,74,181,56,8,0,64,0,51,49,55,45,48,48,55,52,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,45,35,189,113,5,0,16,1,41,0,0,0,255,255,240,0,0,0,0,0,42,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,168,234,7,0,41,0,0,0,1,1,1,0,96,135,7,0,41,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,8,0,184,127,3,0,41,0,0,0,1,14,6,0,184,230,7,0,41,0,0,0,1,14,10,0,72,123,3,0,41,0,0,0,1,14,12,0,152,120,3,0,41,0,0,0,1,14,14,0,136,120,6,0,41,0,0,0,1,14,8,0,160,118,3,0,41,0,0,0,1,14,4,0,176,114,3,0,41,0,0,0,1,14,2,0,32,112,3,0,41,0,0,0,1,14,0,0,104,109,3,0,0,0,0,0,254,0,4,0,112,107,3,0,41,0,0,0,1,48,32,0,80,246,3,0,41,0,0,0,1,48,48,0,248,38,7,0,41,0,0,0,1,48,16,0,112,212,3,0,41,0,0,0,1,48,0,0,248,160,5,0,0,0,0,0,254,0,4,0,72,202,5,0,41,0,0,0,1,192,128,0,80,246,3,0,41,0,0,0,1,192,192,0,248,38,7,0,41,0,0,0,1,192,64,0,112,212,3,0,41,0,0,0,1,192,0,0,248,160,5,0,0,0,0,0,254,0,16,0,200,87,7,0,42,0,0,0,1,15,7,0,80,252,6,0,42,0,0,0,1,15,8,0,16,242,7,0,42,0,0,0,1,15,9,0,104,236,7,0,42,0,0,0,1,15,5,0,176,51,4,0,42,0,0,0,1,15,4,0,56,24,4,0,42,0,0,0,1,15,15,0,128,230,7,0,42,0,0,0,1,15,1,0,72,216,3,0,42,0,0,0,1,15,2,0,24,188,3,0,42,0,0,0,1,15,3,0,176,162,3,0,42,0,0,0,1,15,6,0,120,211,6,0,42,0,0,0,1,15,14,0,184,164,6,0,42,0,0,0,1,15,13,0,80,74,6,0,42,0,0,0,1,15,12,0,192,32,6,0,42,0,0,0,1,15,11,0,192,234,2,0,42,0,0,0,1,15,10,0,32,242,5,0,42,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,42,0,0,0,1,240,112,0,80,252,6,0,42,0,0,0,1,240,128,0,16,242,7,0,42,0,0,0,1,240,144,0,104,236,7,0,42,0,0,0,1,240,80,0,176,51,4,0,42,0,0,0,1,240,64,0,56,24,4,0,42,0,0,0,1,240,240,0,128,230,7,0,42,0,0,0,1,240,16,0,72,216,3,0,42,0,0,0,1,240,32,0,24,188,3,0,42,0,0,0,1,240,48,0,176,162,3,0,42,0,0,0,1,240,96,0,120,211,6,0,42,0,0,0,1,240,224,0,184,164,6,0,42,0,0,0,1,240,208,0,80,74,6,0,42,0,0,0,1,240,192,0,192,32,6,0,42,0,0,0,1,240,176,0,192,234,2,0,42,0,0,0,1,240,160,0,32,242,5,0,42,0,0,0,1,240,0,0,208,236,2,0,21,0,0,0,255,255,255,0,0,0,0,0,22,0,0,0,255,255,90,0,0,0,0,0,23,0,0,0,255,255,240,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,21,0,0,0,1,15,2,0,80,252,6,0,21,0,0,0,1,15,5,0,16,242,7,0,21,0,0,0,1,15,8,0,104,236,7,0,21,0,0,0,1,15,4,0,120,113,6,0,21,0,0,0,1,15,1,0,232,228,5,0,21,0,0,0,1,15,15,0,128,230,7,0,21,0,0,0,1,15,3,0,56,141,7,0,21,0,0,0,1,15,7,0,120,211,6,0,21,0,0,0,1,15,14,0,184,164,6,0,21,0,0,0,1,15,6,0,24,1,7,0,21,0,0,0,1,15,13,0,80,74,6,0,21,0,0,0,1,15,12,0,192,32,6,0,21,0,0,0,1,15,11,0,192,234,2,0,21,0,0,0,1,15,10,0,32,242,5,0,21,0,0,0,1,15,9,0,176,192,2,0,21,0,0,0,1,15,0,0,16,227,4,0,0,0,0,0,254,0,15,0,160,123,6,0,21,0,0,0,1,240,32,0,80,252,6,0,21,0,0,0,1,240,80,0,16,242,7,0,21,0,0,0,1,240,128,0,104,236,7,0,21,0,0,0,1,240,64,0,120,113,6,0,21,0,0,0,1,240,16,0,232,228,5,0,21,0,0,0,1,240,240,0,128,230,7,0,21,0,0,0,1,240,48,0,56,141,7,0,21,0,0,0,1,240,112,0,120,211,6,0,21,0,0,0,1,240,224,0,184,164,6,0,21,0,0,0,1,240,96,0,24,1,7,0,21,0,0,0,1,240,208,0,80,74,6,0,21,0,0,0,1,240,192,0,192,32,6,0,21,0,0,0,1,240,176,0,192,234,2,0,21,0,0,0,1,240,160,0,32,242,5,0,21,0,0,0,1,240,144,0,176,192,2,0,0,0,0,0,254,0,4,0,128,129,4,0,22,0,0,0,1,3,3,0,208,75,4,0,22,0,0,0,1,3,2,0,8,49,4,0,22,0,0,0,1,3,1,0,152,21,4,0,22,0,0,0,1,3,0,0,64,47,7,0,0,0,0,0,254,0,4,0,64,37,5,0,22,0,0,0,1,24,24,0,64,119,3,0,22,0,0,0,1,24,16,0,40,136,2,0,22,0,0,0,1,24,8,0,80,110,6,0,22,0,0,0,1,24,0,0,248,45,5,0,0,0,0,0,254,0,4,0,72,202,5,0,22,0,0,0,1,96,96,0,80,246,3,0,22,0,0,0,1,96,64,0,248,38,7,0,22,0,0,0,1,96,32,0,48,123,8,0,22,0,0,0,1,96,0,0,8,117,8,0,0,0,0,0,254,0,2,0,168,234,7,0,22,0,0,0,1,128,128,0,96,135,7,0,22,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,6,0,23,0,0,0,1,32,32,0,8,208,6,0,23,0,0,0,1,32,0,0,88,204,6,0,0,0,0,0,254,0,2,0,232,75,4,0,23,0,0,0,1,64,64,0,96,135,7,0,23,0,0,0,1,64,0,0,152,182,7,0,88,212,3,0,1,0,0,0,16,70,215,0,40,185,3,0,14,0,0,0,255,255,155,0,0,0,0,0,15,0,0,0,255,255,167,0,0,0,0,0,0,0,0,0,254,0,4,0,32,4,2,0,14,0,0,0,1,3,0,0,40,88,7,0,14,0,0,0,1,3,1,0,96,39,7,0,14,0,0,0,1,3,3,0,144,251,6,0,14,0,0,0,1,3,2,0,184,164,6,0,0,0,0,0,254,0,2,0,128,112,3,0,14,0,0,0,1,8,0,0,72,93,8,0,14,0,0,0,1,8,8,0,168,22,4,0,0,0,0,0,254,0,2,0,232,235,2,0,14,0,0,0,1,16,0,0,80,119,7,0,14,0,0,0,1,16,16,0,16,60,1,0,0,0,0,0,254,0,4,0,112,59,6,0,14,0,0,0,1,192,0,0,56,43,1,0,14,0,0,0,1,192,64,0,80,167,5,0,14,0,0,0,1,192,128,0,40,157,5,0,14,0,0,0,1,192,192,0,120,148,5,0,0,0,0,0,254,0,8,0,72,202,5,0,15,0,0,0,1,7,4,0,160,246,1,0,15,0,0,0,1,7,5,0,120,103,7,0,15,0,0,0,1,7,6,0,80,246,3,0,15,0,0,0,1,7,7,0,248,38,7,0,15,0,0,0,1,7,3,0,80,124,6,0,15,0,0,0,1,7,2,0,112,212,3,0,15,0,0,0,1,7,1,0,48,90,7,0,15,0,0,0,1,7,0,0,248,160,5,0,0,0,0,0,254,0,4,0,128,129,4,0,15,0,0,0,1,48,32,0,8,49,4,0,15,0,0,0,1,48,48,0,208,75,4,0,15,0,0,0,1,48,16,0,152,21,4,0,15,0,0,0,1,48,0,0,72,246,3,0,0,0,0,0,254,0,2,0,168,234,7,0,15,0,0,0,1,64,64,0,96,135,7,0,15,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,8,11,1,0,15,0,0,0,1,128,128,0,96,135,7,0,15,0,0,0,1,128,0,0,152,182,7,0,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,102,102,67,69,0,0,16,1,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,231,203,37,39,0,0,16,1,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,200,254,185,162,0,0,32,0,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,185,215,89,79,0,0,32,0,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,241,196,187,30,0,0,32,0,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,115,65,84,205,0,0,32,0,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,224,161,15,234,0,0,32,0,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,73,254,165,29,0,0,32,0,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,177,46,40,79,0,0,32,0,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,249,77,105,0,0,0,32,0,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,2,187,34,231,0,0,64,0,112,105,99,95,49,54,99,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,76,45,0,0,180,21,165,28,0,0,0,8,52,46,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,165,136,143,246,0,0,16,1,50,46,51,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,97,187,21,63,0,0,16,1,51,46,53,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,228,117,99,206,0,0,16,1,57,46,49,48,111,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,245,131,88,58,0,0,32,0,49,48,46,49,52,111,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,8,237,168,121,0,0,32,0,49,49,46,49,55,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,174,22,106,22,0,0,32,0,49,50,46,50,48,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,108,219,179,47,0,0,32,0,56,46,55,111,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,161,138,24,243,0,0,32,0,55,46,53,111,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,75,161,29,1,0,0,32,0,54,46,51,111,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,151,231,37,14,0,0,32,0,53,46,49,111,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,39,78,170,109,0,0,32,0,49,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,7,57,70,182,0,0,64,0,100,46,116,46,49,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,50,29,4,215,2,0,16,1,100,46,116,46,49,48,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,131,164,233,27,2,0,16,1,109,120,50,55,99,52,49,48,48,46,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,196,52,201,34,4,0,32,0,109,120,50,55,99,52,49,48,48,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,155,94,200,7,4,0,32,0,109,120,50,55,99,52,49,48,48,46,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,70,154,17,172,4,0,32,0,109,120,50,55,99,52,49,48,48,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,151,50,209,74,4,0,32,0,109,120,50,55,99,52,49,48,48,46,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,128,17,3,81,4,0,32,0,109,120,50,55,99,52,49,48,48,46,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,122,101,205,233,4,0,32,0,109,120,50,55,99,52,49,48,48,46,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,242,53,29,46,4,0,32,0,109,120,50,55,99,52,49,48,48,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,210,12,109,2,4,0,32,0,100,46,116,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,162,35,20,203,3,0,16,0,100,46,116,46,49,48,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,93,13,161,115,5,0,64,0,100,46,116,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,130,79,250,175,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,99,112,49,98,49,102,46,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,227,184,121,57,0,0,0,8,99,112,49,98,56,107,46,56,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,122,234,82,138,0,0,0,8,99,112,49,98,57,107,46,57,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,195,189,84,167,0,0,0,8,105,111,99,49,46,105,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,129,32,24,13,0,0,0,8,99,54,51,50,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,112,146,189,15,0,0,0,8,112,101,97,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,145,218,169,130,1,0,16,1,112,101,98,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,156,180,89,204,1,0,16,1,112,101,99,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,101,161,197,59,1,0,16,1,112,101,100,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,208,73,1,197,1,0,16,1,112,101,48,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,113,24,70,203,1,0,16,1,112,101,48,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,219,168,87,241,1,0,16,1,112,101,48,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,182,92,8,117,1,0,16,1,112,101,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,199,69,125,121,1,0,16,1,112,101,48,55,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,224,65,41,1,4,0,32,0,112,101,48,57,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,175,50,97,194,4,0,32,0,112,101,48,54,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,253,88,139,252,4,0,32,0,112,101,48,56,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,59,179,194,220,4,0,32,0,117,110,105,119,97,114,115,46,99,108,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,24,149,199,37,7,0,32,0,19,0,0,0,255,255,253,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,21,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,1,1,0,96,135,7,0,19,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,2,2,0,96,135,7,0,19,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,128,128,0,96,135,7,0,19,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,12,8,0,80,246,3,0,20,0,0,0,1,12,12,0,248,38,7,0,20,0,0,0,1,12,4,0,112,212,3,0,20,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,16,0,32,4,2,0,20,0,0,0,1,240,160,0,144,160,3,0,20,0,0,0,1,240,176,0,96,135,3,0,20,0,0,0,1,240,192,0,32,136,7,0,20,0,0,0,1,240,208,0,40,88,7,0,20,0,0,0,1,240,16,0,40,28,4,0,20,0,0,0,1,240,224,0,96,39,7,0,20,0,0,0,1,240,32,0,192,24,7,0,20,0,0,0,1,240,48,0,120,113,6,0,20,0,0,0,1,240,240,0,144,251,6,0,20,0,0,0,1,240,64,0,120,211,6,0,20,0,0,0,1,240,144,0,184,164,6,0,20,0,0,0,1,240,128,0,80,74,6,0,20,0,0,0,1,240,112,0,192,32,6,0,20,0,0,0,1,240,96,0,192,234,2,0,20,0,0,0,1,240,80,0,32,242,5,0,20,0,0,0,1,240,0,0,16,227,4,0,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,66,223,24,103,1,0,16,1,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,72,54,190,51,1,0,16,1,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,235,12,140,249,1,0,16,1,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,130,0,205,169,1,0,16,1,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,252,90,71,109,1,0,16,1,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,211,99,232,203,1,0,16,1,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,88,247,174,125,1,0,16,1,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,11,50,237,178,5,0,32,0,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,196,178,136,171,5,0,32,0,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,114,91,164,68,6,0,32,0,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,159,101,132,250,6,0,32,0,115,110,55,52,115,50,56,56,110,46,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,196,43,101,36,7,0,32,0,13,0,0,0,255,255,0,0,0,0,0,0,14,0,0,0,255,255,192,0,0,0,0,0,15,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,200,87,7,0,14,0,0,0,1,64,0,0,224,127,8,0,14,0,0,0,1,64,64,0,32,123,8,0,0,0,0,0,254,0,2,0,160,123,6,0,14,0,0,0,1,128,128,0,0,90,2,0,14,0,0,0,1,128,0,0,104,61,2,0,0,0,0,0,254,0,2,0,64,37,5,0,15,0,0,0,1,1,0,0,80,113,6,0,15,0,0,0,1,1,1,0,80,110,6,0,0,0,0,0,254,0,2,0,72,202,5,0,15,0,0,0,1,2,0,0,80,246,3,0,15,0,0,0,1,2,2,0,112,212,3,0,0,0,0,0,254,0,2,0,128,129,4,0,15,0,0,0,1,4,0,0,8,49,4,0,15,0,0,0,1,4,4,0,72,246,3,0,0,0,0,0,254,0,2,0,200,30,2,0,15,0,0,0,1,8,0,0,120,97,1,0,15,0,0,0,1,8,8,0,96,19,1,0,0,0,0,0,101,112,114,45,49,48,51,56,48,97,46,49,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,188,173,79,67,1,0,16,1,101,112,114,45,49,48,51,56,50,97,46,49,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,78,192,220,29,1,0,16,1,101,112,114,45,49,48,51,56,49,97,46,49,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,43,65,140,190,1,0,16,1,101,112,114,45,49,48,51,56,51,97,46,49,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,231,134,197,220,1,0,16,1,101,112,114,45,49,48,51,50,55,97,46,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,175,91,138,226,9,0,16,1,101,112,114,45,49,48,51,50,57,97,46,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,129,28,19,218,9,0,16,1,101,112,114,45,49,48,51,50,56,97,46,55,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,93,94,236,213,9,0,16,1,101,112,114,45,49,48,51,51,48,97,46,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,42,200,158,186,9,0,16,1,111,112,114,45,49,48,50,54,56,46,57,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,4,75,52,149,2,0,32,0,111,112,114,45,49,48,50,51,50,46,49,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,235,161,107,119,2,0,32,0,111,112,114,45,49,48,50,54,55,46,49,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,35,184,91,168,2,0,32,0,111,112,114,45,49,48,50,51,49,46,49,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,191,188,8,137,2,0,32,0,111,112,114,45,49,48,50,54,54,46,49,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,116,26,111,159,2,0,32,0,111,112,114,45,49,48,50,51,48,46,49,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,80,94,111,104,2,0,32,0,109,112,114,45,49,48,51,55,49,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,8,98,200,124,3,0,32,0,109,112,114,45,49,48,51,55,51,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,201,106,210,176,3,0,32,0,109,112,114,45,49,48,51,55,53,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,215,11,182,89,3,0,32,0,109,112,114,45,49,48,51,55,55,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,74,176,161,23,3,0,32,0,109,112,114,45,49,48,51,55,50,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,140,7,87,181,3,0,32,0,109,112,114,45,49,48,51,55,52,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,23,229,81,128,3,0,32,0,109,112,114,45,49,48,51,55,54,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,24,243,184,243,3,0,32,0,109,112,114,45,49,48,51,55,56,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,132,41,6,161,3,0,32,0,111,112,114,45,49,48,49,56,54,46,52,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,38,68,121,34,10,0,32,0,111,112,114,45,49,48,49,56,53,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,38,68,121,34,10,0,32,0,101,112,114,45,49,48,49,56,55,46,56,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,169,186,10,161,4,0,16,1,111,112,114,45,49,48,49,57,51,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,222,13,209,188,11,0,64,0,111,112,114,45,49,48,49,57,50,46,54,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,112,18,15,119,11,0,64,0,111,112,114,45,49,48,49,57,49,46,54,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,171,132,162,32,11,0,64,0,111,112,114,45,49,48,49,57,48,46,54,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,226,112,171,124,11,0,64,0,111,112,114,45,49,48,49,56,57,46,55,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,84,107,54,1,11,0,64,0,111,112,114,45,49,48,49,56,56,46,55,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,217,10,211,186,11,0,64,0,101,112,114,45,49,48,49,56,51,46,49,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,150,35,153,61,1,0,16,1,101,112,114,45,49,48,50,54,49,46,49,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,71,72,3,29,1,0,16,1,101,112,114,45,49,48,49,56,52,46,49,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,70,220,115,26,1,0,16,1,101,112,114,45,49,48,50,54,50,46,49,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,179,182,134,83,1,0,16,1,101,112,114,45,49,48,50,53,56,46,49,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,79,142,64,57,1,0,16,1,101,112,114,45,49,48,50,54,51,46,49,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,214,95,166,237,1,0,16,1,101,112,114,45,49,48,50,53,57,46,49,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,26,11,16,149,1,0,16,1,101,112,114,45,49,48,50,54,52,46,49,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,2,177,148,204,1,0,16,1,101,112,114,45,49,48,49,55,51,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,192,117,39,108,9,0,16,1,101,112,114,45,49,48,49,55,56,46,56,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,5,190,54,109,9,0,16,1,101,112,114,45,49,48,49,55,52,46,54,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,173,239,231,170,9,0,16,1,101,112,114,45,49,48,49,55,57,46,56,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,65,208,15,24,9,0,16,1,101,112,114,45,49,48,49,55,53,46,54,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,99,96,199,49,9,0,16,1,101,112,114,45,49,48,49,56,48,46,56,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0])
.concat([100,178,19,71,9,0,16,1,101,112,114,45,49,48,49,55,54,46,54,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,144,31,129,167,9,0,16,1,101,112,114,45,49,48,49,56,49,46,56,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,77,160,9,224,9,0,16,1,111,112,114,45,49,48,50,54,56,46,57,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,4,75,52,149,2,0,32,0,111,112,114,45,49,48,50,51,50,46,49,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,235,161,107,119,2,0,32,0,111,112,114,45,49,48,50,54,55,46,49,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,35,184,91,168,2,0,32,0,111,112,114,45,49,48,50,51,49,46,49,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,191,188,8,137,2,0,32,0,111,112,114,45,49,48,50,54,54,46,49,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,116,26,111,159,2,0,32,0,111,112,114,45,49,48,50,51,48,46,49,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,80,94,111,104,2,0,32,0,101,112,114,45,49,48,49,57,52,46,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,189,163,237,240,3,0,32,0,101,112,114,45,49,48,50,48,51,46,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,34,166,69,132,3,0,32,0,101,112,114,45,49,48,50,49,50,46,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,49,231,231,222,3,0,32,0,101,112,114,45,49,48,50,50,49,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,135,19,67,67,3,0,32,0,101,112,114,45,49,48,49,57,53,46,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,221,92,231,13,3,0,32,0,101,112,114,45,49,48,50,48,52,46,51,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,187,90,75,95,3,0,32,0,101,112,114,45,49,48,50,49,51,46,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,240,34,27,29,3,0,32,0,101,112,114,45,49,48,50,50,50,46,54,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,6,199,84,162,3,0,32,0,101,112,114,45,49,48,49,57,54,46,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,89,187,136,134,3,0,32,0,101,112,114,45,49,48,50,48,53,46,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,202,147,189,116,3,0,32,0,101,112,114,45,49,48,50,49,52,46,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,24,126,82,87,3,0,32,0,101,112,114,45,49,48,50,50,51,46,54,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,14,105,80,56,3,0,32,0,101,112,114,45,49,48,49,57,55,46,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,166,101,145,0,3,0,32,0,101,112,114,45,49,48,50,48,54,46,52,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,197,66,69,149,3,0,32,0,101,112,114,45,49,48,50,49,53,46,53,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,108,90,190,105,3,0,32,0,101,112,114,45,49,48,50,50,52,46,54,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,70,195,255,92,3,0,32,0,101,112,114,45,49,48,49,57,56,46,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,46,153,148,216,3,0,32,0,101,112,114,45,49,48,50,48,55,46,52,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,164,206,97,202,3,0,32,0,101,112,114,45,49,48,50,49,54,46,53,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,77,19,148,211,3,0,32,0,101,112,114,45,49,48,50,50,53,46,55,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,43,31,93,10,3,0,32,0,101,112,114,45,49,48,49,57,57,46,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,246,106,55,134,3,0,32,0,101,112,114,45,49,48,50,48,56,46,52,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,250,183,48,104,3,0,32,0,101,112,114,45,49,48,50,49,55,46,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,118,155,44,191,3,0,32,0,101,112,114,45,49,48,50,50,54,46,55,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,116,36,69,90,3,0,32,0,101,112,114,45,49,48,50,48,48,46,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,115,79,93,30,3,0,32,0,101,112,114,45,49,48,50,48,57,46,52,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,158,65,21,92,3,0,32,0,101,112,114,45,49,48,50,49,56,46,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,57,219,75,219,3,0,32,0,101,112,114,45,49,48,50,50,55,46,55,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,146,243,222,199,3,0,32,0,101,112,114,45,49,48,50,48,49,46,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,156,75,157,29,3,0,32,0,101,112,114,45,49,48,50,49,48,46,52,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,49,41,66,57,3,0,32,0,101,112,114,45,49,48,50,49,57,46,53,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,36,146,59,231,3,0,32,0,101,112,114,45,49,48,50,50,56,46,55,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,120,57,128,37,3,0,32,0,111,112,114,45,49,48,49,56,54,46,52,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,38,68,121,34,10,0,32,0,111,112,114,45,49,48,49,56,53,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,38,68,121,34,10,0,32,0,101,112,114,45,49,48,49,56,55,46,56,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,169,186,10,161,4,0,16,1,111,112,114,45,49,48,49,57,51,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,222,13,209,188,11,0,64,0,111,112,114,45,49,48,49,57,50,46,54,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,112,18,15,119,11,0,64,0,111,112,114,45,49,48,49,57,49,46,54,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,171,132,162,32,11,0,64,0,111,112,114,45,49,48,49,57,48,46,54,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,226,112,171,124,11,0,64,0,111,112,114,45,49,48,49,56,57,46,55,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,84,107,54,1,11,0,64,0,111,112,114,45,49,48,49,56,56,46,55,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,217,10,211,186,11,0,64,0,10,0,0,0,255,255,255,0,0,0,0,0,11,0,0,0,255,255,252,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,10,0,0,0,1,15,7,0,80,252,6,0,10,0,0,0,1,15,8,0,16,242,7,0,10,0,0,0,1,15,9,0,104,236,7,0,10,0,0,0,1,15,5,0,176,51,4,0,10,0,0,0,1,15,4,0,56,24,4,0,10,0,0,0,1,15,15,0,128,230,7,0,10,0,0,0,1,15,1,0,72,216,3,0,10,0,0,0,1,15,2,0,24,188,3,0,10,0,0,0,1,15,3,0,176,162,3,0,10,0,0,0,1,15,6,0,120,211,6,0,10,0,0,0,1,15,14,0,184,164,6,0,10,0,0,0,1,15,13,0,80,74,6,0,10,0,0,0,1,15,12,0,192,32,6,0,10,0,0,0,1,15,11,0,192,234,2,0,10,0,0,0,1,15,10,0,32,242,5,0,10,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,10,0,0,0,1,240,112,0,80,252,6,0,10,0,0,0,1,240,128,0,16,242,7,0,10,0,0,0,1,240,144,0,104,236,7,0,10,0,0,0,1,240,80,0,176,51,4,0,10,0,0,0,1,240,64,0,56,24,4,0,10,0,0,0,1,240,240,0,128,230,7,0,10,0,0,0,1,240,16,0,72,216,3,0,10,0,0,0,1,240,32,0,24,188,3,0,10,0,0,0,1,240,48,0,176,162,3,0,10,0,0,0,1,240,96,0,120,211,6,0,10,0,0,0,1,240,224,0,184,164,6,0,10,0,0,0,1,240,208,0,80,74,6,0,10,0,0,0,1,240,192,0,192,32,6,0,10,0,0,0,1,240,176,0,192,234,2,0,10,0,0,0,1,240,160,0,32,242,5,0,10,0,0,0,1,240,0,0,208,236,2,0,0,0,0,0,254,0,2,0,200,30,2,0,11,0,0,0,1,1,0,0,96,239,8,0,11,0,0,0,1,1,1,0,120,247,1,0,0,0,0,0,254,0,2,0,168,234,7,0,11,0,0,0,1,2,2,0,96,135,7,0,11,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,4,0,40,252,8,0,11,0,0,0,1,48,32,0,80,246,3,0,11,0,0,0,1,48,48,0,248,38,7,0,11,0,0,0,1,48,16,0,112,212,3,0,11,0,0,0,1,48,0,0,248,160,5,0,0,0,0,0,254,0,4,0,72,202,5,0,11,0,0,0,1,192,128,0,80,246,3,0,11,0,0,0,1,192,192,0,248,38,7,0,11,0,0,0,1,192,64,0,112,212,3,0,11,0,0,0,1,192,0,0,248,160,5,0,184,40,2,0,1,0,0,0,214,155,215,0,248,191,2,0,56,250,6,0,1,0,0,0,211,155,215,0,184,160,2,0,184,164,8,0,1,0,0,0,215,155,215,0,64,246,1,0,240,190,7,0,4,0,0,0,112,156,215,0,208,13,4,0,208,240,5,0,4,0,0,0,104,156,215,0,152,30,2,0,32,201,5,0,4,0,0,0,96,156,215,0,232,10,2,0,32,160,5,0,1,0,0,0,224,155,215,0,152,138,8,0,16,17,8,0,1,0,0,0,210,155,215,0,224,12,8,0,32,77,1,0,1,0,0,0,209,155,215,0,216,70,1,0,88,212,3,0,1,0,0,0,200,154,215,0,40,185,3,0,248,5,8,0,9,0,0,0,0,156,215,0,32,58,1,0,144,250,7,0,9,0,0,0,1,156,215,0,32,58,1,0,98,54,55,45,50,48,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,162,158,67,33,2,0,16,1,98,54,55,45,50,51,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,170,157,158,120,2,0,16,1,98,54,55,45,49,52,46,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,36,215,61,127,2,0,16,1,98,54,55,45,49,53,46,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,208,98,79,232,2,0,16,1,98,54,55,45,49,51,46,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,177,180,54,41,9,0,16,1,98,54,55,45,48,54,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,100,141,163,185,11,0,32,0,98,54,55,45,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,203,154,173,129,17,0,32,0,98,54,55,45,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,251,210,12,194,17,0,32,0,98,54,55,45,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,237,25,144,188,17,0,32,0,98,54,55,45,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,175,200,244,42,17,0,32,0,98,54,55,45,48,53,46,52,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,43,228,147,149,23,0,32,0,98,54,55,45,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,251,65,143,69,24,0,64,0,98,54,55,45,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,87,67,131,79,25,0,64,0,101,101,112,114,111,109,45,111,116,104,117,110,100,101,114,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,68,184,41,55,32,0,16,0,112,108,104,115,49,56,112,56,98,45,98,54,55,45,48,57,46,105,99,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,73,1,0,0,135,84,3,98,0,0,0,8,112,97,108,49,54,108,56,97,45,98,54,55,45,49,49,46,105,99,51,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,6,251,119,49,0,0,0,8,112,97,108,50,48,108,56,98,45,98,54,55,45,49,50,46,105,99,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,1,0,0,152,39,124,164,0,0,0,8,112,97,108,50,48,108,56,98,45,98,54,55,45,49,48,46,105,99,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,1,0,0,199,9,237,76,0,0,0,8,14,0,0,0,255,255,255,0,0,0,0,0,15,0,0,0,255,255,127,0,0,0,0,0,16,0,0,0,255,255,7,0,0,0,0,0,0,0,0,0,254,0,2,0,104,159,3,0,14,0,0,0,1,2,0,0,96,135,7,0,14,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,14,0,0,0,1,4,4,0,96,135,7,0,14,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,14,0,0,0,1,8,0,0,96,135,7,0,14,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,14,0,0,0,1,48,0,0,80,252,6,0,14,0,0,0,1,48,16,0,16,242,7,0,14,0,0,0,1,48,32,0,104,236,7,0,14,0,0,0,1,48,48,0,128,230,7,0,0,0,0,0,254,0,4,0,160,123,6,0,14,0,0,0,1,192,192,0,8,201,6,0,14,0,0,0,1,192,128,0,200,197,6,0,14,0,0,0,1,192,64,0,152,194,6,0,14,0,0,0,1,192,0,0,248,189,6,0,0,0,0,0,254,0,4,0,72,202,5,0,15,0,0,0,1,3,2,0,80,246,3,0,15,0,0,0,1,3,3,0,80,124,6,0,15,0,0,0,1,3,1,0,112,212,3,0,15,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,24,100,5,0,15,0,0,0,1,12,12,0,80,69,5,0,15,0,0,0,1,12,8,0,72,38,5,0,15,0,0,0,1,12,4,0,112,8,5,0,15,0,0,0,1,12,0,0,192,228,4,0,0,0,0,0,254,0,4,0,200,192,4,0,15,0,0,0,1,48,0,0,192,160,4,0,15,0,0,0,1,48,16,0,0,71,4,0,15,0,0,0,1,48,48,0,200,68,4,0,15,0,0,0,1,48,32,0,136,66,4,0,0,0,0,0,254,0,2,0,144,212,8,0,15,0,0,0,1,128,0,0,168,22,4,0,15,0,0,0,1,128,128,0,224,247,3,0,0,0,0,0,254,0,4,0,0,214,3,0,16,0,0,0,1,7,7,0,32,186,3,0,16,0,0,0,1,7,3,0,64,111,3,0,16,0,0,0,1,7,1,0,80,124,6,0,16,0,0,0,1,7,0,0,112,134,3,0,0,0,0,0,111,114,98,105,116,114,111,110,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,155,156,159,65,1,0,16,1,111,114,98,105,116,114,111,110,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,172,86,173,68,1,0,16,1,111,114,98,105,116,114,111,110,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,104,81,63,218,1,0,16,1,111,114,98,105,116,114,111,110,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,252,19,184,163,1,0,16,1,111,114,98,105,116,114,111,110,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,184,139,205,32,1,0,16,1,111,114,98,105,116,114,111,110,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,63,184,145,44,4,0,32,0,111,114,98,105,116,114,111,110,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,164,204,244,70,4,0,32,0,108,48,54,95,112,114,111,109,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,135,125,12,106,7,0,32,0,15,0,0,0,255,255,0,0,0,0,0,0,16,0,0,0,255,255,64,0,0,0,0,0,17,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,32,4,2,0,16,0,0,0,1,96,0,0,144,147,2,0,16,0,0,0,1,96,64,0,200,209,1,0,0,0,0,0,254,0,2,0,128,129,4,0,17,0,0,0,1,4,4,0,208,75,4,0,17,0,0,0,1,4,0,0,8,49,4,0,0,0,0,0,254,0,2,0,200,30,2,0,17,0,0,0,1,8,0,0,120,97,1,0,17,0,0,0,1,8,8,0,96,19,1,0,184,40,2,0,1,0,0,0,184,148,215,0,248,191,2,0,56,250,6,0,1,0,0,0,180,148,215,0,184,160,2,0,184,164,8,0,1,0,0,0,185,148,215,0,64,246,1,0,152,225,1,0,4,0,0,0,104,150,215,0,152,210,1,0,152,198,1,0,4,0,0,0,96,150,215,0,208,189,1,0,48,123,2,0,1,0,0,0,176,148,215,0,248,174,1,0,96,69,2,0,1,0,0,0,177,148,215,0,104,160,1,0,88,212,3,0,1,0,0,0,200,147,215,0,40,185,3,0,16,17,8,0,1,0,0,0,178,148,215,0,224,12,8,0,56,58,1,0,1,0,0,0,179,148,215,0,64,50,1,0,248,5,8,0,9,0,0,0,96,149,215,0,32,58,1,0,144,250,7,0,9,0,0,0,97,149,215,0,32,58,1,0,100,55,52,95,49,54,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,241,143,25,2,0,16,1,100,55,52,95,50,48,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,146,216,15,150,2,0,16,1,100,55,52,95,49,56,46,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,219,124,93,189,2,0,16,1,100,55,52,95,49,55,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,114,166,53,172,2,0,16,1,100,55,52,95,49,57,46,55,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,6,63,213,5,9,0,16,1,100,55,52,95,48,53,46,56,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,204,100,234,133,12,0,32,0,100,55,52,95,48,54,46,56,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,141,224,161,47,12,0,32,0,100,55,52,95,48,49,46,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,224,19,83,17,24,0,64,0,100,55,52,95,48,50,46,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,50,99,184,170,0,0,32,0,100,55,52,95,48,51,46,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,22,137,57,63,0,0,32,0,100,55,52,95,48,52,46,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,56,86,56,47,0,0,32,0,19,0,0,0,255,255,224,0,0,0,0,0,20,0,0,0,255,255,0,0,0,0,0,0,21,0,0,0,255,255,128,0,0,0,0,0,0,0,0,0,254,0,4,0,64,37,5,0,19,0,0,0,1,3,0,0,112,215,8,0,19,0,0,0,1,3,1,0,112,207,8,0,19,0,0,0,1,3,2,0,48,203,8,0,19,0,0,0,1,3,3,0,160,198,8,0,0,0,0,0,254,0,2,0,16,227,4,0,19,0,0,0,1,4,0,0,96,135,7,0,19,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,19,0,0,0,1,24,16,0,192,255,2,0,19,0,0,0,1,24,8,0,208,75,4,0,19,0,0,0,1,24,0,0,8,49,4,0,19,0,0,0,1,24,24,0,48,235,2,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,64,64,0,96,135,7,0,19,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,200,30,2,0,19,0,0,0,1,128,128,0,120,97,1,0,19,0,0,0,1,128,0,0,96,19,1,0,0,0,0,0,254,0,16,0,200,87,7,0,20,0,0,0,1,15,15,0,120,247,3,0,20,0,0,0,1,15,14,0,104,213,3,0,20,0,0,0,1,15,13,0,224,185,3,0,20,0,0,0,1,15,12,0,144,160,3,0,20,0,0,0,1,15,11,0,96,135,3,0,20,0,0,0,1,15,10,0,32,136,7,0,20,0,0,0,1,15,9,0,40,88,7,0,20,0,0,0,1,15,8,0,96,39,7,0,20,0,0,0,1,15,0,0,144,251,6,0,20,0,0,0,1,15,1,0,184,164,6,0,20,0,0,0,1,15,2,0,80,74,6,0,20,0,0,0,1,15,3,0,192,32,6,0,20,0,0,0,1,15,4,0,192,234,2,0,20,0,0,0,1,15,5,0,32,242,5,0,20,0,0,0,1,15,6,0,176,192,2,0,20,0,0,0,1,15,7,0,248,175,2,0,0,0,0,0,254,0,16,0,160,123,6,0,20,0,0,0,1,240,240,0,120,247,3,0,20,0,0,0,1,240,224,0,104,213,3,0,20,0,0,0,1,240,208,0,224,185,3,0,20,0,0,0,1,240,192,0,144,160,3,0,20,0,0,0,1,240,176,0,96,135,3,0,20,0,0,0,1,240,160,0,32,136,7,0,20,0,0,0,1,240,144,0,40,88,7,0,20,0,0,0,1,240,128,0,96,39,7,0,20,0,0,0,1,240,0,0,144,251,6,0,20,0,0,0,1,240,16,0,184,164,6,0,20,0,0,0,1,240,32,0,80,74,6,0,20,0,0,0,1,240,48,0,192,32,6,0,20,0,0,0,1,240,64,0,192,234,2,0,20,0,0,0,1,240,80,0,32,242,5,0,20,0,0,0,1,240,96,0,176,192,2,0,20,0,0,0,1,240,112,0,248,175,2,0,0,0,0,0,254,0,2,0,112,109,2,0,21,0,0,0,1,1,0,0,96,135,7,0,21,0,0,0,1,1,1,0,152,182,7,0,0,0,0,0,254,0,2,0,32,150,8,0,21,0,0,0,1,2,0,0,96,135,7,0,21,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,2,0,72,4,1,0,21,0,0,0,1,8,0,0,96,135,7,0,21,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,2,0,136,198,1,0,21,0,0,0,1,16,16,0,96,135,7,0,21,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,21,0,0,0,1,96,32,0,80,246,3,0,21,0,0,0,1,96,0,0,248,38,7,0,21,0,0,0,1,96,64,0,48,123,8,0,21,0,0,0,1,96,96,0,8,117,8,0,0,0,0,0,254,0,2,0,32,4,2,0,21,0,0,0,1,128,128,0,168,82,2,0,21,0,0,0,1,128,0,0,240,69,2,0,18,0,0,0,255,255,251,0,0,0,0,0,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,72,202,5,0,18,0,0,0,1,3,2,0,80,246,3,0,18,0,0,0,1,3,3,0,248,38,7,0,18,0,0,0,1,3,1,0,112,212,3,0,18,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,2,0,168,234,7,0,18,0,0,0,1,4,4,0,96,135,7,0,18,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,18,0,0,0,1,128,128,0,96,135,7,0,18,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,8,0,200,87,7,0,19,0,0,0,1,7,0,0,96,135,3,0,19,0,0,0,1,7,1,0,32,136,7,0,19,0,0,0,1,7,2,0,40,88,7,0,19,0,0,0,1,7,3,0,96,39,7,0,19,0,0,0,1,7,7,0,144,251,6,0,19,0,0,0,1,7,6,0,184,164,6,0,19,0,0,0,1,7,5,0,80,74,6,0,19,0,0,0,1,7,4,0,192,32,6,0,0,0,0,0,254,0,8,0,160,123,6,0,19,0,0,0,1,56,0,0,96,135,3,0,19,0,0,0,1,56,8,0,32,136,7,0,19,0,0,0,1,56,16,0,40,88,7,0,19,0,0,0,1,56,24,0,96,39,7,0,19,0,0,0,1,56,56,0,144,251,6,0,19,0,0,0,1,56,48,0,184,164,6,0,19,0,0,0,1,56,40,0,80,74,6,0,19,0,0,0,1,56,32,0,192,32,6,0,101,112,114,45,54,54,49,50,46,49,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,111,151,48,27,0,0,16,1,101,112,114,45,54,54,49,51,46,49,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,39,31,40,24,0,0,16,1,101,112,114,45,54,54,49,52,46,49,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,115,61,252,105,0,0,16,1,101,112,114,45,54,54,49,53,46,49,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,200,116,3,29,0,0,16,1,101,112,114,45,54,53,55,55,46,49,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,3,110,97,115,0,0,16,1,101,112,114,45,54,54,49,55,46,49,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,149,248,182,32,0,0,16,1,101,112,114,45,54,53,53,57,46,49,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,238,112,21,90,0,0,16,1,101,112,114,45,54,53,53,56,46,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,235,234,249,42,0,0,32,0,101,112,114,45,54,53,53,55,46,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,208,49,177,110,0,0,32,0,101,112,114,45,54,53,53,54,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,247,38,253,121,0,0,32,0,101,112,114,45,54,53,53,53,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,172,154,102,127,0,0,32,0,101,112,114,45,54,53,53,52,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,5,210,201,90,0,0,32,0,101,112,114,45,54,53,53,51,46,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,254,168,130,235,0,0,32,0,101,112,114,45,54,53,52,54,46,49,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,146,86,120,164,0,0,32,0,101,112,114,45,54,53,52,56,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,193,120,242,189,0,0,32,0,101,112,114,45,54,53,52,55,46,49,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,8,27,69,52,0,0,32,0,101,112,114,45,54,53,52,57,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,104,118,5,210,0,0,32,0,112,114,45,53,51,49,55,46,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,184,80,131,100,0,0,0,8,18,0,0,0,255,255,255,0,0,0,0,0,19,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,0,44,6,0,18,0,0,0,1,3,2,0,248,81,6,0,18,0,0,0,1,3,3,0,248,38,7,0,18,0,0,0,1,3,1,0,176,64,8,0,18,0,0,0,1,3,0,0,128,172,6,0,0,0,0,0,254,0,4,0,72,202,5,0,18,0,0,0,1,12,8,0,80,246,3,0,18,0,0,0,1,12,12,0,248,38,7,0,18,0,0,0,1,12,4,0,112,212,3,0,18,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,2,0,16,227,4,0,18,0,0,0,1,16,16,0,96,135,7,0,18,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,8,0,32,4,2,0,18,0,0,0,1,224,32,0,32,136,7,0,18,0,0,0,1,224,160,0,40,88,7,0,18,0,0,0,1,224,96,0,96,39,7,0,18,0,0,0,1,224,224,0,144,251,6,0,18,0,0,0,1,224,0,0,120,211,6,0,18,0,0,0,1,224,192,0,184,164,6,0,18,0,0,0,1,224,64,0,80,74,6,0,18,0,0,0,1,224,128,0,192,32,6,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,64,0,0,96,135,7,0,19,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,128,128,0,96,135,7,0,19,0,0,0,1,128,0,0,152,182,7,0,23,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,25,0,0,0,255,255,255,0,0,0,0,0,26,0,0,0,255,255,127,0,0,0,0,0,0,0,0,0,254,0,8,0,200,87,7,0,25,0,0,0,1,7,0,0,40,88,7,0,25,0,0,0,1,7,1,0,96,39,7,0,25,0,0,0,1,7,7,0,144,251,6,0,25,0,0,0,1,7,6,0,184,164,6,0,25,0,0,0,1,7,5,0,80,74,6,0,25,0,0,0,1,7,4,0,192,32,6,0,25,0,0,0,1,7,3,0,192,234,2,0,25,0,0,0,1,7,2,0,32,242,5,0,0,0,0,0,254,0,8,0,160,123,6,0,25,0,0,0,1,56,0,0,40,88,7,0,25,0,0,0,1,56,8,0,96,39,7,0,25,0,0,0,1,56,56,0,144,251,6,0,25,0,0,0,1,56,48,0,184,164,6,0,25,0,0,0,1,56,40,0,80,74,6,0,25,0,0,0,1,56,32,0,192,32,6,0,25,0,0,0,1,56,24,0,192,234,2,0,25,0,0,0,1,56,16,0,32,242,5,0,0,0,0,0,254,0,2,0,144,212,8,0,25,0,0,0,1,64,64,0,96,135,7,0,25,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,152,184,3,0,25,0,0,0,1,128,128,0,96,135,7,0,25,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,26,0,0,0,1,3,1,0,192,255,2,0,26,0,0,0,1,3,0,0,208,75,4,0,26,0,0,0,1,3,3,0,8,49,4,0,26,0,0,0,1,3,2,0,152,21,4,0,0,0,0,0,254,0,4,0,8,99,2,0,26,0,0,0,1,12,8,0,80,246,3,0,26,0,0,0,1,12,12,0,248,38,7,0,26,0,0,0,1,12,4,0,112,212,3,0,26,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,2,0,48,210,2,0,26,0,0,0,1,16,16,0,96,135,7,0,26,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,2,0,216,77,5,0,26,0,0,0,1,32,32,0,208,75,4,0,26,0,0,0,1,32,0,0,8,49,4,0,0,0,0,0,254,0,2,0,32,175,2,0,26,0,0,0,1,64,64,0,96,135,7,0,26,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,26,0,0,0,1,128,128,0,96,135,7,0,26,0,0,0,1,128,0,0,152,182,7,0,184,40,2,0,1,0,0,0,172,148,215,0,248,191,2,0,56,250,6,0,1,0,0,0,191,148,215,0,184,160,2,0,184,164,8,0,1,0,0,0,173,148,215,0,64,246,1,0,88,149,7,0,1,0,0,0,183,148,215,0,136,224,1,0,104,28,8,0,1,0,0,0,174,148,215,0,232,209,1,0,248,23,7,0,1,0,0,0,167,148,215,0,144,189,1,0,64,183,7,0,1,0,0,0,175,148,215,0,104,195,5,0,48,19,7,0,1,0,0,0,159,148,215,0,32,245,8,0,56,210,6,0,1,0,0,0,184,148,215,0,192,135,2,0,24,163,6,0,1,0,0,0,185,148,215,0,240,108,2,0,152,122,6,0,1,0,0,0,186,148,215,0,96,82,2,0,192,72,6,0,1,0,0,0,187,148,215,0,32,56,2,0,48,123,2,0,1,0,0,0,188,148,215,0,152,30,2,0,96,69,2,0,1,0,0,0,189,148,215,0,232,10,2,0,176,223,1,0,1,0,0,0,176,148,215,0,72,198,1,0,192,209,1,0,1,0,0,0,177,148,215,0,24,182,1,0,24,198,1,0,1,0,0,0,178,148,215,0,40,167,1,0,120,189,1,0,1,0,0,0,179,148,215,0,200,149,1,0,248,187,8,0,1,0,0,0,180,148,215,0,56,126,1,0,184,179,8,0,1,0,0,0,181,148,215,0,32,101,1,0,192,122,8,0,1,0,0,0,160,148,215,0,208,174,1,0,40,116,8,0,1,0,0,0,161,148,215,0,48,160,1,0,72,110,8,0,1,0,0,0,162,148,215,0,160,140,1,0,184,102,8,0,1,0,0,0,163,148,215,0,56,112,1,0,240,45,8,0,1,0,0,0,164,148,215,0,32,92,1,0,40,38,8,0,1,0,0,0,165,148,215,0,64,77,1,0,248,16,8,0,1,0,0,0,152,148,215,0,32,231,8,0,192,12,8,0,1,0,0,0,153,148,215,0,88,214,8,0,224,5,8,0,1,0,0,0,154,148,215,0,224,202,8,0,144,1,8,0,1,0,0,0,155,148,215,0,72,193,8,0,72,204,7,0,1,0,0,0,156,148,215,0,144,180,8,0,208,196,7,0,1,0,0,0,157,148,215,0,208,164,8,0,88,212,3,0,1,0,0,0,200,147,215,0,40,185,3,0,16,17,8,0,1,0,0,0,169,148,215,0,224,12,8,0,0,105,5,0,1,0,0,0,170,148,215,0,192,99,5,0,56,58,1,0,1,0,0,0,168,148,215,0,64,50,1,0,248,5,8,0,9,0,0,0,96,149,215,0,32,58,1,0,144,250,7,0,9,0,0,0,97,149,215,0,32,58,1,0,168,86,7,0,1,0,0,0,212,47,216,0,248,191,2,0,24,38,7,0,1,0,0,0,208,47,216,0,184,160,2,0,56,210,6,0,1,0,0,0,35,48,216,0,192,135,2,0,24,163,6,0,1,0,0,0,34,48,216,0,240,108,2,0,152,122,6,0,1,0,0,0,33,48,216,0,96,82,2,0,192,72,6,0,1,0,0,0,32,48,216,0,32,56,2,0,232,158,3,0,1,0,0,0,36,48,216,0,152,30,2,0,40,147,2,0,1,0,0,0,37,48,216,0,232,10,2,0,40,246,1,0,1,0,0,0,213,47,216,0,64,246,1,0,144,236,1,0,1,0,0,0,209,47,216,0,136,224,1,0,176,223,1,0,1,0,0,0,43,48,216,0,72,198,1,0,192,209,1,0,1,0,0,0,42,48,216,0,24,182,1,0,24,198,1,0,1,0,0,0,41,48,216,0,40,167,1,0,120,189,1,0,1,0,0,0,40,48,216,0,200,149,1,0,200,32,1,0,1,0,0,0,44,48,216,0,56,126,1,0,200,197,8,0,1,0,0,0,45,48,216,0,32,101,1,0,88,212,3,0,1,0,0,0,144,46,216,0,40,185,3,0,240,152,1,0,1,0,0,0,201,47,216,0,216,70,1,0,16,17,8,0,1,0,0,0,202,47,216,0,224,12,8,0,136,67,2,0,1,0,0,0,176,48,216,0,152,138,8,0,8,66,2,0,1,0,0,0,184,48,216,0,48,119,7,0,110,102,102,117,97,100,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,66,142,24,120,1,0,16,1,110,102,102,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,110,198,161,219,1,0,16,1,110,102,102,117,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,183,62,129,234,1,0,16,1,110,102,102,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,65,167,252,201,5,0,32,0,110,102,102,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,152,216,9,248,5,0,32,0,110,102,102,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,7,69,186,21,5,0,32,0,110,102,102,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,140,27,212,61,5,0,32,0,110,102,102,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,75,165,227,63,5,0,32,0,110,102,102,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,49,210,92,86,5,0,32,0,110,102,102,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,136,89,202,99,5,0,32,0,110,102,102,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,59,143,235,33,5,0,32,0,110,102,102,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,24,67,228,210,10,0,16,1,110,102,102,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,5,78,62,36,12,0,64,0,110,102,102,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,22,207,79,12,0,64,0,98,57,49,45,52,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,33,52,214,122,2,0,16,1,98,57,49,45,52,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,223,10,195,75,2,0,16,1,98,57,49,45,52,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,122,114,111,62,2,0,16,1,98,57,49,45,52,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,3,142,119,159,2,0,16,1,98,57,49,45,51,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,174,35,91,114,6,0,16,1,98,57,49,45,52,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,77,54,251,129,6,0,16,1,98,57,49,45,52,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,66,187,148,38,9,0,16,1,98,57,49,45,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,49,206,248,255,11,0,32,0,98,57,49,45,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,13,151,161,140,17,0,32,0,98,57,49,45,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,57,237,95,205,17,0,32,0,98,57,49,45,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,184,100,124,69,17,0,32,0,98,57,49,45,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,79,217,49,55,17,0,32,0,98,57,49,45,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,52,92,243,102,21,0,32,0,98,57,49,45,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,207,198,142,77,21,0,32,0,98,57,49,45,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,57,200,77,163,21,0,32,0,98,57,49,45,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,144,172,114,94,21,0,32,0,98,57,49,45,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,180,5,143,29,22,0,32,0,98,57,49,45,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,162,124,36,95,23,0,32,0,98,57,49,45,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,245,240,123,140,24,0,64,0,98,57,49,45,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,175,199,119,218,24,0,64,0,98,57,49,45,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,211,20,195,107,25,0,64,0,98,57,49,45,50,54,46,98,105,110,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,79,42,104,119,0,0,0,8,98,57,49,45,50,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,13,73,248,163,0,0,0,8,98,57,49,45,50,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,14,132,47,250,0,0,0,8,98,57,49,45,50,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,232,91,104,173,0,0,0,8,98,57,49,45,51,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,121,31,204,48,0,0,0,8,98,57,49,45,51,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,28,120,137,193,0,0,0,8,98,57,49,45,51,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,48,31,248,251,0,0,0,8,98,57,49,45,51,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,23,157,113,137,0,0,0,8,11,0,0,0,255,255,254,0,0,0,0,0,12,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,11,0,0,0,1,1,1,0,80,46,8,0,11,0,0,0,1,1,0,0,120,97,1,0,0,0,0,0,254,0,2,0,232,75,4,0,11,0,0,0,1,4,4,0,96,135,7,0,11,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,11,0,0,0,1,8,0,0,96,135,7,0,11,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,11,0,0,0,1,48,0,0,80,252,6,0,11,0,0,0,1,48,16,0,16,242,7,0,11,0,0,0,1,48,32,0,104,236,7,0,11,0,0,0,1,48,48,0,128,230,7,0,0,0,0,0,254,0,4,0,160,123,6,0,11,0,0,0,1,192,192,0,8,201,6,0,11,0,0,0,1,192,128,0,200,197,6,0,11,0,0,0,1,192,64,0,152,194,6,0,11,0,0,0,1,192,0,0,248,189,6,0,0,0,0,0,254,0,4,0,72,202,5,0,12,0,0,0,1,3,2,0,80,246,3,0,12,0,0,0,1,3,3,0,248,38,7,0,12,0,0,0,1,3,1,0,112,212,3,0,12,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,128,52,7,0,12,0,0,0,1,12,8,0,8,49,4,0,12,0,0,0,1,12,4,0,208,75,4,0,12,0,0,0,1,12,12,0,192,255,2,0,12,0,0,0,1,12,0,0,120,7,5,0,0,0,0,0,254,0,4,0,192,99,6,0,12,0,0,0,1,48,0,0,8,49,4,0,12,0,0,0,1,48,16,0,152,21,4,0,12,0,0,0,1,48,48,0,72,246,3,0,12,0,0,0,1,48,32,0,72,0,3,0,0,0,0,0,254,0,2,0,104,159,3,0,12,0,0,0,1,64,0,0,96,135,7,0,12,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,16,24,7,0,12,0,0,0,1,128,128,0,72,19,7,0,12,0,0,0,1,128,0,0,88,14,7,0,112,114,111,103,50,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,87,164,67,222,0,0,16,1,112,114,111,103,49,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,190,69,11,55,0,0,16,1,105,115,99,114,50,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,235,162,45,79,0,0,16,1,105,115,99,114,49,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,79,137,198,99,0,0,16,1,105,115,99,114,52,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,65,87,114,0,0,16,1,105,115,99,114,51,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,98,179,214,81,0,0,16,1,105,115,99,114,54,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,243,46,139,23,0,0,16,1,105,115,99,114,53,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,250,197,181,210,0,0,16,1,105,115,99,114,56,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,40,133,20,244,0,0,16,1,105,115,99,114,55,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,49,12,238,45,0,0,16,1,111,98,106,49,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,81,212,44,131,0,0,32,0,109,117,115,99,49,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,206,127,52,16,0,0,64,0,109,117,115,99,50,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,140,106,100,185,0,0,64,0,17,0,0,0,255,255,255,0,0,0,0,0,18,0,0,0,255,255,255,0,0,0,0,0,19,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,17,0,0,0,1,1,1,0,96,135,7,0,17,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,17,0,0,0,1,2,0,0,96,135,7,0,17,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,2,0,128,111,8,0,17,0,0,0,1,8,8,0,96,135,7,0,17,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,17,0,0,0,1,128,128,0,96,135,7,0,17,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,18,0,0,0,1,3,2,0,192,255,2,0,18,0,0,0,1,3,3,0,208,75,4,0,18,0,0,0,1,3,1,0,8,49,4,0,18,0,0,0,1,3,0,0,152,21,4,0,0,0,0,0,254,0,4,0,72,202,5,0,18,0,0,0,1,12,8,0,80,246,3,0,18,0,0,0,1,12,12,0,248,38,7,0,18,0,0,0,1,12,4,0,112,212,3,0,18,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,16,0,32,4,2,0,18,0,0,0,1,240,160,0,144,160,3,0,18,0,0,0,1,240,176,0,96,135,3,0,18,0,0,0,1,240,192,0,32,136,7,0,18,0,0,0,1,240,208,0,40,88,7,0,18,0,0,0,1,240,16,0,40,28,4,0,18,0,0,0,1,240,224,0,96,39,7,0,18,0,0,0,1,240,32,0,192,24,7,0,18,0,0,0,1,240,48,0,120,113,6,0,18,0,0,0,1,240,240,0,144,251,6,0,18,0,0,0,1,240,64,0,120,211,6,0,18,0,0,0,1,240,144,0,184,164,6,0,18,0,0,0,1,240,128,0,80,74,6,0,18,0,0,0,1,240,112,0,192,32,6,0,18,0,0,0,1,240,96,0,192,234,2,0,18,0,0,0,1,240,80,0,32,242,5,0,18,0,0,0,1,240,0,0,16,227,4,0,52,49,117,95,51,48,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,208,57,84,190,1,0,16,1,52,49,117,95,51,53,46,49,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,149,101,201,106,1,0,16,1,52,49,117,95,51,49,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,235,214,17,152,1,0,16,1,52,49,117,95,51,54,46,49,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,55,97,126,168,1,0,16,1,52,49,45,51,50,109,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,202,72,150,78,2,0,16,1,52,49,45,53,109,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,17,203,209,1,4,0,32,0,52,49,45,55,109,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,9,53,170,174,4,0,32,0,52,49,45,49,109,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,90,152,119,255,4,0,32,0,52,49,45,51,109,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,143,229,59,152,4,0,32,0,52,49,95,57,46,49,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,39,133,157,15,3,0,16,0,52,49,101,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,235,90,241,209,5,0,64,0,52,49,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,166,195,174,21,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,121,105,50,52,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,223,220,4,48,0,0,0,8,105,111,98,49,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,52,49,95,51,54,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,171,66,189,127,1,0,16,1,52,49,95,52,50,46,49,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,137,31,120,199,1,0,16,1,52,49,95,51,55,46,49,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,11,75,70,198,1,0,16,1,52,49,95,52,51,46,49,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,181,192,15,68,1,0,16,1,52,49,95,51,52,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,236,65,243,181,1,0,16,1,52,49,95,52,48,46,49,48,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,125,131,121,57,1,0,16,1,52,49,95,51,53,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,154,151,204,149,1,0,16,1,52,49,95,52,49,46,49,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,25,104,73,87,1,0,16,1,52,49,95,48,57,46,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,194,107,27,190,4,0,32,0,52,49,95,48,49,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,193,111,148,216,4,0,32,0,52,49,95,49,51,46,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,236,208,6,46,4,0,32,0,52,49,95,48,53,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,224,40,186,216,4,0,32,0,52,49,95,50,52,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,238,60,164,90,4,0,32,0,52,49,95,49,55,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,2,249,239,187,4,0,32,0,52,49,95,51,56,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,170,192,137,136,4,0,32,0,52,49,95,51,50,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,73,130,22,240,4,0,32,0,52,49,95,49,48,46,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,109,106,235,183,4,0,32,0,52,49,95,48,50,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,83,129,46,128,4,0,32,0,52,49,95,49,52,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,118,246,51,90,4,0,32,0,52,49,95,48,54,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,11,101,83,78,4,0,32,0,52,49,95,50,53,46,55,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,96,211,173,148,4,0,32,0,52,49,95,49,56,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,243,193,225,165,4,0,32,0,52,49,95,51,57,46,57,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,73,57,92,91,4,0,32,0,52,49,95,51,51,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,226,176,49,122,4,0,32,0,52,49,95,50,51,46,49,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,39,133,157,15,3,0,16,0,52,49,95,51,48,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,235,90,241,209,5,0,64,0,52,49,95,51,49,46,49,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,166,195,174,21,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,121,105,50,50,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,0,0,0,0,0,0,24,108,119,105,111,46,49,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,12,185,82,173,0,0,0,8,18,0,0,0,255,255,191,0,0,0,0,0,19,0,0,0,255,255,253,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,18,0,0,0,1,3,2,0,208,75,4,0,18,0,0,0,1,3,3,0,8,49,4,0,18,0,0,0,1,3,1,0,152,21,4,0,18,0,0,0,1,3,0,0,72,246,3,0,0,0,0,0,254,0,4,0,72,202,5,0,18,0,0,0,1,12,8,0,80,246,3,0,18,0,0,0,1,12,12,0,248,38,7,0,18,0,0,0,1,12,4,0,112,212,3,0,18,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,2,0,64,37,5,0,18,0,0,0,1,16,0,0,240,45,6,0,18,0,0,0,1,16,16,0,48,41,6,0,0,0,0,0,254,0,2,0,104,159,3,0,18,0,0,0,1,32,0,0,56,111,3,0,18,0,0,0,1,32,32,0,104,134,3,0,0,0,0,0,254,0,2,0,168,234,7,0,18,0,0,0,1,64,64,0,96,135,7,0,18,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,18,0,0,0,1,128,128,0,96,135,7,0,18,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,1,1,0,96,135,7,0,19,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,88,160,1,0,19,0,0,0,1,4,4,0,136,86,1,0,19,0,0,0,1,4,0,0,184,147,6,0,0,0,0,0,254,0,2,0,96,46,8,0,19,0,0,0,1,8,8,0,192,255,2,0,19,0,0,0,1,8,0,0,208,75,4,0,0,0,0,0,254,0,16,0,32,4,2,0,19,0,0,0,1,240,160,0,144,160,3,0,19,0,0,0,1,240,176,0,96,135,3,0,19,0,0,0,1,240,192,0,32,136,7,0,19,0,0,0,1,240,208,0,40,88,7,0,19,0,0,0,1,240,224,0,96,39,7,0,19,0,0,0,1,240,16,0,32,202,2,0,19,0,0,0,1,240,48,0,120,113,6,0,19,0,0,0,1,240,32,0,232,228,5,0,19,0,0,0,1,240,240,0,144,251,6,0,19,0,0,0,1,240,64,0,120,211,6,0,19,0,0,0,1,240,144,0,184,164,6,0,19,0,0,0,1,240,128,0,80,74,6,0,19,0,0,0,1,240,112,0,192,32,6,0,19,0,0,0,1,240,96,0,192,234,2,0,19,0,0,0,1,240,80,0,32,242,5,0,19,0,0,0,1,240,0,0,16,227,4,0,184,40,2,0,1,0,0,0,128,93,148,0,248,191,2,0,56,250,6,0,1,0,0,0,132,93,148,0,184,160,2,0,184,164,8,0,1,0,0,0,129,93,148,0,64,246,1,0,88,149,7,0,1,0,0,0,133,93,148,0,136,224,1,0,56,210,6,0,1,0,0,0,149,93,148,0,192,135,2,0,24,163,6,0,1,0,0,0,148,93,148,0,240,108,2,0,152,122,6,0,1,0,0,0,151,93,148,0,96,82,2,0,192,72,6,0,1,0,0,0,150,93,148,0,32,56,2,0,48,123,2,0,1,0,0,0,145,93,148,0,152,30,2,0,96,69,2,0,1,0,0,0,146,93,148,0,232,10,2,0,176,223,1,0,1,0,0,0,141,93,148,0,72,198,1,0,192,209,1,0,1,0,0,0,140,93,148,0,24,182,1,0,24,198,1,0,1,0,0,0,143,93,148,0,40,167,1,0,120,189,1,0,1,0,0,0,142,93,148,0,200,149,1,0,248,187,8,0,1,0,0,0,137,93,148,0,56,126,1,0,184,179,8,0,1,0,0,0,138,93,148,0,32,101,1,0,88,212,3,0,1,0,0,0,248,26,149,0,40,185,3,0,16,17,8,0,1,0,0,0,131,93,148,0,224,12,8,0,80,251,6,0,1,0,0,0,130,93,148,0,216,70,1,0,248,5,8,0,9,0,0,0,112,99,215,0,32,58,1,0,144,250,7,0,9,0,0,0,113,99,215,0,32,58,1,0,18,0,0,0,255,255,255,0,0,0,0,0,19,0,0,0,255,255,255,0,0,0,0,0])
.concat([18,0,0,0,254,0,2,0,32,176,1,0,18,0,0,0,1,2,2,0,192,255,2,0,18,0,0,0,1,2,0,0,208,75,4,0,18,0,0,0,254,0,2,0,168,234,7,0,18,0,0,0,1,4,4,0,96,135,7,0,18,0,0,0,1,4,0,0,152,182,7,0,18,0,0,0,254,0,2,0,144,212,8,0,18,0,0,0,1,8,8,0,96,135,7,0,18,0,0,0,1,8,0,0,152,182,7,0,18,0,0,0,254,0,4,0,200,87,7,0,18,0,0,0,1,48,16,0,160,36,8,0,18,0,0,0,1,48,48,0,208,239,7,0,18,0,0,0,1,48,0,0,16,79,1,0,18,0,0,0,1,48,32,0,120,187,7,0,18,0,0,0,254,0,4,0,160,123,6,0,18,0,0,0,1,192,64,0,160,36,8,0,18,0,0,0,1,192,192,0,208,239,7,0,18,0,0,0,1,192,0,0,16,79,1,0,18,0,0,0,1,192,128,0,120,187,7,0,19,0,0,0,254,0,4,0,72,202,5,0,19,0,0,0,1,3,2,0,80,246,3,0,19,0,0,0,1,3,3,0,248,38,7,0,19,0,0,0,1,3,1,0,112,212,3,0,19,0,0,0,1,3,0,0,248,160,5,0,19,0,0,0,254,0,4,0,128,129,4,0,19,0,0,0,1,12,0,0,208,75,4,0,19,0,0,0,1,12,12,0,8,49,4,0,19,0,0,0,1,12,8,0,152,21,4,0,19,0,0,0,1,12,4,0,72,246,3,0,19,0,0,0,254,0,2,0,200,252,8,0,19,0,0,0,1,16,16,0,8,49,4,0,19,0,0,0,1,16,0,0,152,21,4,0,19,0,0,0,254,0,2,0,16,227,4,0,19,0,0,0,1,32,32,0,96,135,7,0,19,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,225,0,0,0,0,0,21,0,0,0,255,255,218,0,0,0,0,0,22,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,176,68,2,0,19,0,0,0,1,16,16,0,96,135,7,0,19,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,32,1,0,19,0,0,0,1,32,32,0,96,135,7,0,19,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,20,0,0,0,1,1,1,0,96,135,7,0,20,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,8,0,32,4,2,0,20,0,0,0,1,14,12,0,184,220,8,0,20,0,0,0,1,14,10,0,88,154,8,0,20,0,0,0,1,14,8,0,200,92,8,0,20,0,0,0,1,14,0,0,56,37,8,0,20,0,0,0,1,14,2,0,96,240,7,0,20,0,0,0,1,14,4,0,128,188,7,0,20,0,0,0,1,14,6,0,184,46,7,0,20,0,0,0,1,14,14,0,16,227,4,0,0,0,0,0,254,0,2,0,72,217,6,0,20,0,0,0,1,16,16,0,56,111,3,0,20,0,0,0,1,16,0,0,104,134,3,0,0,0,0,0,254,0,2,0,112,104,5,0,20,0,0,0,1,32,32,0,96,135,7,0,20,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,40,73,5,0,21,0,0,0,1,1,1,0,96,135,7,0,21,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,21,0,0,0,1,6,0,0,192,255,2,0,21,0,0,0,1,6,2,0,208,75,4,0,21,0,0,0,1,6,4,0,8,49,4,0,21,0,0,0,1,6,6,0,152,21,4,0,0,0,0,0,254,0,4,0,72,202,5,0,21,0,0,0,1,48,0,0,248,80,6,0,21,0,0,0,1,48,16,0,80,246,3,0,21,0,0,0,1,48,32,0,112,212,3,0,21,0,0,0,1,48,48,0,144,196,4,0,0,0,0,0,254,0,2,0,104,164,4,0,22,0,0,0,1,1,1,0,96,135,7,0,22,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,72,4,1,0,22,0,0,0,1,2,2,0,96,135,7,0,22,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,168,86,7,0,1,0,0,0,232,47,216,0,248,191,2,0,24,38,7,0,1,0,0,0,236,47,216,0,184,160,2,0,56,210,6,0,1,0,0,0,35,48,216,0,192,135,2,0,24,163,6,0,1,0,0,0,34,48,216,0,240,108,2,0,152,122,6,0,1,0,0,0,33,48,216,0,96,82,2,0,192,72,6,0,1,0,0,0,32,48,216,0,32,56,2,0,152,31,6,0,1,0,0,0,36,48,216,0,152,30,2,0,248,97,5,0,1,0,0,0,37,48,216,0,232,10,2,0,104,184,3,0,1,0,0,0,38,48,216,0,152,138,8,0,40,246,1,0,1,0,0,0,233,47,216,0,64,246,1,0,144,236,1,0,1,0,0,0,237,47,216,0,136,224,1,0,176,223,1,0,1,0,0,0,43,48,216,0,72,198,1,0,192,209,1,0,1,0,0,0,42,48,216,0,24,182,1,0,24,198,1,0,1,0,0,0,41,48,216,0,40,167,1,0,120,189,1,0,1,0,0,0,40,48,216,0,200,149,1,0,8,182,1,0,1,0,0,0,44,48,216,0,56,126,1,0,32,167,1,0,1,0,0,0,45,48,216,0,32,101,1,0,208,41,1,0,1,0,0,0,46,48,216,0,96,32,8,0,88,212,3,0,1,0,0,0,144,46,216,0,40,185,3,0,240,152,1,0,1,0,0,0,238,47,216,0,216,70,1,0,16,17,8,0,1,0,0,0,234,47,216,0,224,12,8,0,72,65,1,0,9,0,0,0,232,48,216,0,32,58,1,0,48,50,1,0,9,0,0,0,224,48,216,0,32,58,1,0,224,41,1,0,9,0,0,0,216,48,216,0,32,58,1,0,109,115,95,51,48,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,120,240,193,33,1,0,16,1,109,115,95,51,53,46,49,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,58,167,64,165,1,0,16,1,109,115,95,51,49,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,181,98,231,215,1,0,16,1,109,115,95,51,54,46,49,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,219,220,242,102,1,0,16,1,109,115,45,51,50,109,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,252,221,117,36,2,0,16,1,109,115,45,53,109,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,226,231,15,192,4,0,32,0,109,115,45,55,109,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,197,202,202,76,4,0,32,0,109,115,45,49,109,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,190,43,13,4,0,32,0,109,115,45,51,109,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,244,91,26,58,4,0,32,0,109,115,95,48,57,46,49,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,25,149,178,87,3,0,16,0,109,115,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,13,233,100,251,5,0,64,0,109,115,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,185,146,248,116,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,109,115,50,52,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,109,190,109,99,0,0,0,8,105,111,98,49,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,168,86,7,0,1,0,0,0,232,47,216,0,248,191,2,0,24,38,7,0,1,0,0,0,236,47,216,0,184,160,2,0,56,210,6,0,1,0,0,0,35,48,216,0,192,135,2,0,24,163,6,0,1,0,0,0,34,48,216,0,240,108,2,0,152,122,6,0,1,0,0,0,33,48,216,0,96,82,2,0,192,72,6,0,1,0,0,0,32,48,216,0,32,56,2,0,152,31,6,0,1,0,0,0,36,48,216,0,152,30,2,0,248,97,5,0,1,0,0,0,37,48,216,0,232,10,2,0,144,55,2,0,1,0,0,0,38,48,216,0,152,138,8,0,40,246,1,0,1,0,0,0,233,47,216,0,64,246,1,0,144,236,1,0,1,0,0,0,237,47,216,0,136,224,1,0,176,223,1,0,1,0,0,0,43,48,216,0,72,198,1,0,192,209,1,0,1,0,0,0,42,48,216,0,24,182,1,0,24,198,1,0,1,0,0,0,41,48,216,0,40,167,1,0,120,189,1,0,1,0,0,0,40,48,216,0,200,149,1,0,8,182,1,0,1,0,0,0,44,48,216,0,56,126,1,0,32,167,1,0,1,0,0,0,45,48,216,0,32,101,1,0,240,173,8,0,1,0,0,0,46,48,216,0,96,32,8,0,88,212,3,0,1,0,0,0,144,46,216,0,40,185,3,0,240,152,1,0,1,0,0,0,238,47,216,0,216,70,1,0,16,17,8,0,1,0,0,0,234,47,216,0,224,12,8,0,72,65,1,0,9,0,0,0,232,48,216,0,32,58,1,0,48,50,1,0,9,0,0,0,224,48,216,0,32,58,1,0,224,41,1,0,9,0,0,0,216,48,216,0,32,58,1,0,109,119,45,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,180,31,229,196,0,0,16,1,109,119,45,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,169,254,196,18,0,0,16,1,109,119,45,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,21,175,163,40,0,0,32,0,109,119,45,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,159,126,223,255,0,0,32,0,109,119,45,54,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,163,115,215,30,0,0,32,0,109,119,45,55,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,92,82,183,142,0,0,32,0,109,119,45,56,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,60,42,185,185,0,0,32,0,109,119,45,57,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,117,51,252,117,0,0,32,0,109,119,45,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,104,106,12,17,0,0,64,0,21,0,0,0,255,255,176,0,0,0,0,0,0,0,0,0,254,0,8,0,32,4,2,0,21,0,0,0,1,7,3,0,112,225,8,0,21,0,0,0,1,7,2,0,72,217,8,0,21,0,0,0,1,7,1,0,136,208,8,0,21,0,0,0,1,7,0,0,40,204,8,0,21,0,0,0,1,7,4,0,112,199,8,0,21,0,0,0,1,7,5,0,96,194,8,0,21,0,0,0,1,7,6,0,136,189,8,0,21,0,0,0,1,7,7,0,224,184,8,0,0,0,0,0,254,0,4,0,128,129,4,0,21,0,0,0,1,24,0,0,192,255,2,0,21,0,0,0,1,24,8,0,208,75,4,0,21,0,0,0,1,24,16,0,8,49,4,0,21,0,0,0,1,24,24,0,152,21,4,0,0,0,0,0,254,0,4,0,72,202,5,0,21,0,0,0,1,96,0,0,80,246,3,0,21,0,0,0,1,96,32,0,248,38,7,0,21,0,0,0,1,96,64,0,112,212,3,0,21,0,0,0,1,96,96,0,248,160,5,0,0,0,0,0,254,0,2,0,168,234,7,0,21,0,0,0,1,128,0,0,96,135,7,0,21,0,0,0,1,128,128,0,152,182,7,0,0,0,0,0,18,0,0,0,255,255,255,0,0,0,0,0,19,0,0,0,255,255,73,0,0,0,0,0,20,0,0,0,255,255,240,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,18,0,0,0,1,15,2,0,80,252,6,0,18,0,0,0,1,15,5,0,16,242,7,0,18,0,0,0,1,15,8,0,104,236,7,0,18,0,0,0,1,15,4,0,120,113,6,0,18,0,0,0,1,15,1,0,232,228,5,0,18,0,0,0,1,15,15,0,128,230,7,0,18,0,0,0,1,15,0,0,232,192,7,0,18,0,0,0,1,15,3,0,56,141,7,0,18,0,0,0,1,15,7,0,120,211,6,0,18,0,0,0,1,15,14,0,184,164,6,0,18,0,0,0,1,15,6,0,24,1,7,0,18,0,0,0,1,15,13,0,80,74,6,0,18,0,0,0,1,15,12,0,192,32,6,0,18,0,0,0,1,15,11,0,192,234,2,0,18,0,0,0,1,15,10,0,32,242,5,0,18,0,0,0,1,15,9,0,176,192,2,0,0,0,0,0,254,0,16,0,160,123,6,0,18,0,0,0,1,240,32,0,80,252,6,0,18,0,0,0,1,240,80,0,16,242,7,0,18,0,0,0,1,240,128,0,104,236,7,0,18,0,0,0,1,240,64,0,120,113,6,0,18,0,0,0,1,240,16,0,232,228,5,0,18,0,0,0,1,240,240,0,128,230,7,0,18,0,0,0,1,240,0,0,232,192,7,0,18,0,0,0,1,240,48,0,56,141,7,0,18,0,0,0,1,240,112,0,120,211,6,0,18,0,0,0,1,240,224,0,184,164,6,0,18,0,0,0,1,240,96,0,24,1,7,0,18,0,0,0,1,240,208,0,80,74,6,0,18,0,0,0,1,240,192,0,192,32,6,0,18,0,0,0,1,240,176,0,192,234,2,0,18,0,0,0,1,240,160,0,32,242,5,0,18,0,0,0,1,240,144,0,176,192,2,0,0,0,0,0,254,0,4,0,168,143,5,0,19,0,0,0,1,3,3,0,248,114,5,0,19,0,0,0,1,3,2,0,0,84,5,0,19,0,0,0,1,3,1,0,64,54,5,0,19,0,0,0,1,3,0,0,16,23,5,0,0,0,0,0,254,0,4,0,160,244,4,0,19,0,0,0,1,12,12,0,200,210,4,0,19,0,0,0,1,12,8,0,240,176,4,0,19,0,0,0,1,12,4,0,240,144,4,0,19,0,0,0,1,12,0,0,120,115,4,0,0,0,0,0,254,0,4,0,72,202,5,0,19,0,0,0,1,96,96,0,80,246,3,0,19,0,0,0,1,96,64,0,248,38,7,0,19,0,0,0,1,96,32,0,48,123,8,0,19,0,0,0,1,96,0,0,8,117,8,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,128,128,0,96,135,7,0,19,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,20,0,0,0,1,64,64,0,96,135,7,0,20,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,96,100,3,0,20,0,0,0,1,128,128,0,248,38,7,0,20,0,0,0,1,128,0,0,176,172,3,0,0,0,0,0,14,0,0,0,255,255,254,0,0,0,0,0,0,0,0,0,254,0,4,0,104,22,2,0,14,0,0,0,1,3,3,0,24,205,7,0,14,0,0,0,1,3,2,0,192,255,2,0,14,0,0,0,1,3,1,0,208,75,4,0,14,0,0,0,1,3,0,0,8,49,4,0,0,0,0,0,254,0,4,0,32,4,2,0,14,0,0,0,1,12,0,0,96,39,7,0,14,0,0,0,1,12,12,0,144,251,6,0,14,0,0,0,1,12,8,0,184,164,6,0,14,0,0,0,1,12,4,0,80,74,6,0,0,0,0,0,254,0,2,0,112,104,5,0,14,0,0,0,1,16,16,0,96,135,7,0,14,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,2,0,48,212,1,0,14,0,0,0,1,32,32,0,96,135,7,0,14,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,80,11,5,0,14,0,0,0,1,64,64,0,96,135,7,0,14,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,14,0,0,0,1,128,128,0,96,135,7,0,14,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,109,118,115,117,46,48,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,106,166,96,174,1,0,16,1,109,118,115,117,46,48,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,138,125,246,145,1,0,16,1,109,118,115,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,203,224,93,26,1,0,16,1,109,118,115,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,48,48,159,149,1,0,16,1,109,118,115,46,48,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,219,91,145,127,1,0,16,1,109,118,115,46,48,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,132,56,129,194,1,0,16,1,109,118,115,46,48,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,136,160,59,1,0,16,1,109,118,115,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,152,186,13,207,1,0,16,1,109,118,115,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,217,95,176,41,5,0,32,0,109,118,115,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,241,204,221,250,5,0,32,0,109,118,115,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,199,244,170,151,5,0,32,0,109,118,115,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,21,233,112,203,5,0,32,0,109,118,115,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,45,151,177,179,5,0,32,0,109,118,115,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,93,219,170,8,5,0,32,0,109,118,115,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,53,139,34,193,5,0,32,0,109,118,115,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,194,198,108,54,5,0,32,0,109,118,115,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,36,35,37,104,10,0,16,1,109,118,115,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,61,119,78,179,10,0,16,1,109,118,115,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,112,151,33,134,12,0,64,0,109,118,115,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,104,127,253,242,12,0,64,0,109,118,115,106,46,48,51,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,38,126,250,253,1,0,16,1,109,118,115,106,46,48,52,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,95,130,33,201,1,0,16,1,109,118,115,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,203,224,93,26,1,0,16,1,109,118,115,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,48,48,159,149,1,0,16,1,109,118,115,46,48,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,219,91,145,127,1,0,16,1,109,118,115,46,48,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,132,56,129,194,1,0,16,1,109,118,115,46,48,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,136,160,59,1,0,16,1,109,118,115,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,152,186,13,207,1,0,16,1,109,118,115,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,217,95,176,41,5,0,32,0,109,118,115,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,241,204,221,250,5,0,32,0,109,118,115,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,199,244,170,151,5,0,32,0,109,118,115,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,21,233,112,203,5,0,32,0,109,118,115,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,45,151,177,179,5,0,32,0,109,118,115,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,93,219,170,8,5,0,32,0,109,118,115,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,53,139,34,193,5,0,32,0,109,118,115,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,194,198,108,54,5,0,32,0,109,118,115,46,48,49,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,36,35,37,104,10,0,16,1,109,118,115,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,61,119,78,179,10,0,16,1,109,118,115,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,112,151,33,134,12,0,64,0,109,118,115,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,104,127,253,242,12,0,64,0,109,118,115,106,46,48,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,95,17,226,251,1,0,16,1,109,118,115,106,46,48,52,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,103,163,40,181,1,0,16,1,109,118,115,46,48,53,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,69,162,21,149,1,0,16,1,109,118,115,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,48,48,159,149,1,0,16,1,109,118,115,46,48,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,219,91,145,127,1,0,16,1,109,118,115,46,48,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,132,56,129,194,1,0,16,1,109,118,115,46,48,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,136,160,59,1,0,16,1,109,118,115,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,152,186,13,207,1,0,16,1,109,118,115,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,217,95,176,41,5,0,32,0,109,118,115,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,241,204,221,250,5,0,32,0,109,118,115,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,199,244,170,151,5,0,32,0,109,118,115,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,21,233,112,203,5,0,32,0,109,118,115,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,45,151,177,179,5,0,32,0,109,118,115,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,93,219,170,8,5,0,32,0,109,118,115,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,53,139,34,193,5,0,32,0,109,118,115,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,194,198,108,54,5,0,32,0,109,118,115,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,36,35,37,104,10,0,16,1,109,118,115,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,61,119,78,179,10,0,16,1,109,118,115,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,112,151,33,134,12,0,64,0,109,118,115,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,104,127,253,242,12,0,64,0,109,118,115,98,46,48,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,80,185,75,156,1,0,16,1,109,118,115,98,46,48,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,19,13,50,211,1,0,16,1,109,118,115,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,203,224,93,26,1,0,16,1,109,118,115,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,48,48,159,149,1,0,16,1,109,118,115,46,48,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,219,91,145,127,1,0,16,1,109,118,115,46,48,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,132,56,129,194,1,0,16,1,109,118,115,46,48,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,136,160,59,1,0,16,1,109,118,115,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,152,186,13,207,1,0,16,1,109,118,115,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,217,95,176,41,5,0,32,0,109,118,115,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,241,204,221,250,5,0,32,0,109,118,115,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,199,244,170,151,5,0,32,0,109,118,115,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,21,233,112,203,5,0,32,0,109,118,115,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,45,151,177,179,5,0,32,0,109,118,115,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,93,219,170,8,5,0,32,0,109,118,115,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,53,139,34,193,5,0,32,0,109,118,115,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,194,198,108,54,5,0,32,0,109,118,115,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,36,35,37,104,10,0,16,1,109,118,115,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,61,119,78,179,10,0,16,1,109,118,115,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,112,151,33,134,12,0,64,0,109,118,115,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,104,127,253,242,12,0,64,0,109,118,115,97,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,51,25,239,146,1,0,16,1,109,118,115,97,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,60,55,36,75,1,0,16,1,109,118,115,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,28,12,24,172,1,0,16,1,109,118,115,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,48,48,159,149,1,0,16,1,109,118,115,46,48,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,219,91,145,127,1,0,16,1,109,118,115,46,48,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,132,56,129,194,1,0,16,1,109,118,115,46,48,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,136,160,59,1,0,16,1,109,118,115,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,152,186,13,207,1,0,16,1,109,118,115,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,217,95,176,41,5,0,32,0,109,118,115,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,241,204,221,250,5,0,32,0,109,118,115,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,199,244,170,151,5,0,32,0,109,118,115,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,21,233,112,203,5,0,32,0,109,118,115,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,45,151,177,179,5,0,32,0,109,118,115,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,93,219,170,8,5,0,32,0,109,118,115,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,53,139,34,193,5,0,32,0,109,118,115,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,194,198,108,54,5,0,32,0,109,118,115,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,36,35,37,104,10,0,16,1,109,118,115,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,61,119,78,179,10,0,16,1,109,118,115,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,112,151,33,134,12,0,64,0,109,118,115,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,104,127,253,242,12,0,64,0,109,121,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,241,74,87,131,1,0,16,1,109,121,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,200,226,250,28,1,0,16,1,109,121,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,104,163,184,200,1,0,16,1,109,121,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,110,238,174,182,1,0,16,1,109,121,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,220,42,248,222,1,0,16,1,109,121,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,128,179,1,54,4,0,32,0,109,121,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,50,233,89,182,4,0,32,0,109,121,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,205,6,43,153,4,0,32,0,109,121,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,206,230,96,216,4,0,32,0,109,115,99,112,114,111,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,240,26,13,234,7,0,32,0,109,121,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,32,41,42,82,0,0,64,8,109,121,48,54,40,95,95,101,110,103,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,242,21,100,70,0,0,64,8,13,0,0,0,255,255,0,0,0,0,0,0,14,0,0,0,255,255,128,0,0,0,0,0,15,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,232,75,4,0,14,0,0,0,1,64,0,0,96,135,7,0,14,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,200,30,2,0,14,0,0,0,1,128,128,0,120,97,1,0,14,0,0,0,1,128,0,0,96,19,1,0,0,0,0,0,254,0,4,0,128,129,4,0,15,0,0,0,1,3,0,0,8,49,4,0,15,0,0,0,1,3,1,0,152,21,4,0,15,0,0,0,1,3,2,0,72,246,3,0,15,0,0,0,1,3,3,0,72,0,3,0,0,0,0,0,254,0,2,0,64,37,5,0,15,0,0,0,1,4,0,0,80,110,6,0,15,0,0,0,1,4,4,0,152,53,6,0,0,0,0,0,254,0,4,0,200,87,7,0,14,0,0,0,1,24,24,0,176,45,8,0,14,0,0,0,1,24,16,0,176,45,8,0,14,0,0,0,1,24,8,0,224,127,8,0,14,0,0,0,1,24,0,0,32,123,8,0,0,0,0,0,254,0,4,0,160,123,6,0,14,0,0,0,1,96,0,0,128,103,7,0,14,0,0,0,1,96,32,0,80,196,7,0,14,0,0,0,1,96,64,0,0,90,2,0,14,0,0,0,1,96,96,0,72,74,2,0,0,0,0,0,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,21,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,8,0,200,87,7,0,19,0,0,0,1,7,0,0,32,136,7,0,19,0,0,0,1,7,1,0,40,88,7,0,19,0,0,0,1,7,2,0,96,39,7,0,19,0,0,0,1,7,7,0,144,251,6,0,19,0,0,0,1,7,6,0,184,164,6,0,19,0,0,0,1,7,5,0,80,74,6,0,19,0,0,0,1,7,3,0,192,32,6,0,19,0,0,0,1,7,4,0,192,234,2,0,0,0,0,0,254,0,8,0,160,123,6,0,19,0,0,0,1,56,0,0,32,136,7,0,19,0,0,0,1,56,8,0,40,88,7,0,19,0,0,0,1,56,16,0,96,39,7,0,19,0,0,0,1,56,56,0,144,251,6,0,19,0,0,0,1,56,48,0,184,164,6,0,19,0,0,0,1,56,40,0,80,74,6,0,19,0,0,0,1,56,24,0,192,32,6,0,19,0,0,0,1,56,32,0,192,234,2,0,0,0,0,0,254,0,2,0,16,227,4,0,19,0,0,0,1,128,128,0,96,135,7,0,19,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,20,0,0,0,1,1,0,0,96,135,7,0,20,0,0,0,1,1,1,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,6,4,0,80,246,3,0,20,0,0,0,1,6,6,0,248,38,7,0,20,0,0,0,1,6,2,0,112,212,3,0,20,0,0,0,1,6,0,0,248,160,5,0,0,0,0,0,254,0,2,0,144,212,8,0,20,0,0,0,1,16,16,0,96,135,7,0,20,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,2,0,112,38,2,0,20,0,0,0,1,32,32,0,96,135,7,0,20,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,20,0,0,0,1,128,128,0,96,135,7,0,20,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,128,112,3,0,21,0,0,0,1,128,128,0,168,22,4,0,21,0,0,0,1,128,0,0,224,247,3,0,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,21,0,0,0,255,255,127,0,0,0,0,0,0,0,0,0,254,0,8,0,200,87,7,0,19,0,0,0,1,7,0,0,32,136,7,0,19,0,0,0,1,7,1,0,40,88,7,0,19,0,0,0,1,7,2,0,96,39,7,0,19,0,0,0,1,7,7,0,144,251,6,0,19,0,0,0,1,7,6,0,184,164,6,0,19,0,0,0,1,7,5,0,80,74,6,0,19,0,0,0,1,7,3,0,192,32,6,0,19,0,0,0,1,7,4,0,192,234,2,0,0,0,0,0,254,0,8,0,160,123,6,0,19,0,0,0,1,56,0,0,32,136,7,0,19,0,0,0,1,56,8,0,40,88,7,0,19,0,0,0,1,56,16,0,96,39,7,0,19,0,0,0,1,56,56,0,144,251,6,0,19,0,0,0,1,56,48,0,184,164,6,0,19,0,0,0,1,56,40,0,80,74,6,0,19,0,0,0,1,56,24,0,192,32,6,0,19,0,0,0,1,56,32,0,192,234,2,0,0,0,0,0,254,0,2,0,16,227,4,0,19,0,0,0,1,128,128,0,96,135,7,0,19,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,20,0,0,0,1,1,0,0,96,135,7,0,20,0,0,0,1,1,1,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,6,4,0,80,246,3,0,20,0,0,0,1,6,6,0,248,38,7,0,20,0,0,0,1,6,2,0,112,212,3,0,20,0,0,0,1,6,0,0,248,160,5,0,0,0,0,0,254,0,2,0,144,212,8,0,20,0,0,0,1,16,16,0,96,135,7,0,20,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,2,0,112,38,2,0,20,0,0,0,1,32,32,0,96,135,7,0,20,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,20,0,0,0,1,128,128,0,96,135,7,0,20,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,1,0,128,112,3,0,21,0,0,0,1,128,0,0,224,247,3,0,0,0,0,0,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,124,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,19,0,0,0,1,15,7,0,80,252,6,0,19,0,0,0,1,15,8,0,16,242,7,0,19,0,0,0,1,15,9,0,104,236,7,0,19,0,0,0,1,15,5,0,192,54,8,0,19,0,0,0,1,15,4,0,56,24,4,0,19,0,0,0,1,15,15,0,128,230,7,0,19,0,0,0,1,15,0,0,128,230,7,0,19,0,0,0,1,15,3,0,176,162,3,0,19,0,0,0,1,15,2,0,24,188,3,0,19,0,0,0,1,15,1,0,72,216,3,0,19,0,0,0,1,15,6,0,120,211,6,0,19,0,0,0,1,15,14,0,184,164,6,0,19,0,0,0,1,15,13,0,80,74,6,0,19,0,0,0,1,15,12,0,192,32,6,0,19,0,0,0,1,15,11,0,192,234,2,0,19,0,0,0,1,15,10,0,32,242,5,0,0,0,0,0,254,0,16,0,160,123,6,0,19,0,0,0,1,240,112,0,80,252,6,0,19,0,0,0,1,240,128,0,16,242,7,0,19,0,0,0,1,240,144,0,104,236,7,0,19,0,0,0,1,240,80,0,192,54,8,0,19,0,0,0,1,240,64,0,56,24,4,0,19,0,0,0,1,240,240,0,128,230,7,0,19,0,0,0,1,240,0,0,128,230,7,0,19,0,0,0,1,240,48,0,176,162,3,0,19,0,0,0,1,240,32,0,24,188,3,0,19,0,0,0,1,240,16,0,72,216,3,0,19,0,0,0,1,240,96,0])
.concat([120,211,6,0,19,0,0,0,1,240,224,0,184,164,6,0,19,0,0,0,1,240,208,0,80,74,6,0,19,0,0,0,1,240,192,0,192,32,6,0,19,0,0,0,1,240,176,0,192,234,2,0,19,0,0,0,1,240,160,0,32,242,5,0,0,0,0,0,254,0,2,0,200,30,2,0,20,0,0,0,1,1,0,0,120,97,1,0,20,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,12,12,0,8,49,4,0,20,0,0,0,1,12,8,0,152,21,4,0,20,0,0,0,1,12,4,0,72,246,3,0,20,0,0,0,1,12,0,0,112,49,6,0,0,0,0,0,254,0,4,0,64,37,5,0,20,0,0,0,1,48,48,0,48,92,5,0,20,0,0,0,1,48,32,0,72,90,5,0,20,0,0,0,1,48,16,0,224,87,5,0,20,0,0,0,1,48,0,0,216,83,5,0,0,0,0,0,254,0,2,0,72,202,5,0,20,0,0,0,1,64,64,0,80,246,3,0,20,0,0,0,1,64,0,0,112,212,3,0,101,112,114,45,53,56,55,51,46,49,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,36,22,210,20,0,0,16,1,101,112,114,45,53,56,55,52,46,49,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,135,222,247,109,0,0,16,1,101,112,114,45,53,56,55,53,46,49,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,97,34,172,0,0,16,1,101,112,114,45,53,56,55,54,46,49,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,220,177,125,231,0,0,16,1,101,112,114,45,53,55,53,53,46,49,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,225,42,214,237,0,0,16,1,101,112,114,45,53,55,53,54,46,49,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,64,64,151,17,0,0,16,1,101,112,114,45,53,55,54,51,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,13,40,18,215,0,0,16,1,101,112,114,45,53,55,54,50,46,56,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,138,208,145,74,0,0,32,0,101,112,114,45,53,55,54,49,46,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,101,27,214,247,0,0,32,0,101,112,114,45,53,55,54,48,46,56,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,32,88,4,149,0,0,32,0,101,112,114,45,53,55,53,57,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,78,174,155,95,0,0,32,0,101,112,114,45,53,55,53,56,46,56,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,6,231,142,128,0,0,32,0,101,112,114,45,53,55,53,55,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,116,112,15,72,0,0,32,0,101,112,114,45,53,55,52,57,46,56,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,205,130,70,226,0,0,32,0,101,112,114,45,53,55,53,48,46,57,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,173,209,100,101,0,0,32,0,112,114,45,53,51,49,55,46,49,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,184,80,131,100,0,0,0,8,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,124,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,19,0,0,0,1,15,7,0,80,252,6,0,19,0,0,0,1,15,8,0,16,242,7,0,19,0,0,0,1,15,9,0,104,236,7,0,19,0,0,0,1,15,5,0,192,54,8,0,19,0,0,0,1,15,4,0,56,24,4,0,19,0,0,0,1,15,15,0,128,230,7,0,19,0,0,0,1,15,0,0,128,230,7,0,19,0,0,0,1,15,3,0,176,162,3,0,19,0,0,0,1,15,2,0,24,188,3,0,19,0,0,0,1,15,1,0,72,216,3,0,19,0,0,0,1,15,6,0,120,211,6,0,19,0,0,0,1,15,14,0,184,164,6,0,19,0,0,0,1,15,13,0,80,74,6,0,19,0,0,0,1,15,12,0,192,32,6,0,19,0,0,0,1,15,11,0,192,234,2,0,19,0,0,0,1,15,10,0,32,242,5,0,0,0,0,0,254,0,16,0,160,123,6,0,19,0,0,0,1,240,112,0,80,252,6,0,19,0,0,0,1,240,128,0,16,242,7,0,19,0,0,0,1,240,144,0,104,236,7,0,19,0,0,0,1,240,80,0,192,54,8,0,19,0,0,0,1,240,64,0,56,24,4,0,19,0,0,0,1,240,240,0,128,230,7,0,19,0,0,0,1,240,0,0,128,230,7,0,19,0,0,0,1,240,48,0,176,162,3,0,19,0,0,0,1,240,32,0,24,188,3,0,19,0,0,0,1,240,16,0,72,216,3,0,19,0,0,0,1,240,96,0,120,211,6,0,19,0,0,0,1,240,224,0,184,164,6,0,19,0,0,0,1,240,208,0,80,74,6,0,19,0,0,0,1,240,192,0,192,32,6,0,19,0,0,0,1,240,176,0,192,234,2,0,19,0,0,0,1,240,160,0,32,242,5,0,0,0,0,0,254,0,2,0,200,30,2,0,20,0,0,0,1,1,0,0,120,97,1,0,20,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,2,0,24,81,5,0,20,0,0,0,1,2,2,0,80,62,6,0,20,0,0,0,1,2,0,0,120,65,6,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,12,12,0,8,49,4,0,20,0,0,0,1,12,8,0,152,21,4,0,20,0,0,0,1,12,4,0,72,246,3,0,20,0,0,0,1,12,0,0,112,49,6,0,0,0,0,0,254,0,4,0,64,37,5,0,20,0,0,0,1,48,48,0,48,92,5,0,20,0,0,0,1,48,32,0,72,90,5,0,20,0,0,0,1,48,16,0,224,87,5,0,20,0,0,0,1,48,0,0,216,83,5,0,0,0,0,0,254,0,2,0,72,202,5,0,20,0,0,0,1,64,64,0,80,246,3,0,20,0,0,0,1,64,0,0,112,212,3,0,0,0,0,0,109,114,107,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,185,172,147,252,1,0,16,1,112,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,81,119,1,200,1,0,16,1,112,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,132,25,146,184,1,0,16,1,112,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,76,117,201,179,1,0,16,1,112,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,188,173,148,141,1,0,16,1,112,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,255,33,201,172,1,0,16,1,97,116,119,45,54,119,45,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,113,163,66,175,2,0,16,1,97,116,119,45,54,121,45,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,2,137,43,134,2,0,16,1,97,116,119,45,54,122,45,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,200,108,57,160,2,0,16,1,103,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,22,209,207,14,4,0,32,0,103,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,198,163,191,0,4,0,32,0,97,116,119,45,112,114,111,109,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,136,177,93,198,7,0,32,0,50,55,51,50,45,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,251,15,6,253,1,0,16,1,50,55,51,50,45,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,104,216,5,158,1,0,16,1,50,55,51,50,45,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,54,197,199,203,1,0,16,1,97,116,119,45,54,119,45,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,113,163,66,175,2,0,16,1,97,116,119,45,54,121,45,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,2,137,43,134,2,0,16,1,97,116,119,45,54,122,45,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,200,108,57,160,2,0,16,1,50,55,51,50,45,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,67,29,239,96,4,0,32,0,99,48,49,115,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,171,174,60,78,7,0,32,0,12,0,0,0,255,255,0,0,0,0,0,0,13,0,0,0,255,255,3,0,0,0,0,0,14,0,0,0,255,255,14,0,0,0,0,0,0,0,0,0,254,0,2,0,200,87,7,0,13,0,0,0,1,2,0,0,224,127,8,0,13,0,0,0,1,2,2,0,32,123,8,0,0,0,0,0,254,0,2,0,160,123,6,0,13,0,0,0,1,1,1,0,96,102,7,0,13,0,0,0,1,1,0,0,152,96,3,0,0,0,0,0,254,0,2,0,200,30,2,0,14,0,0,0,1,2,2,0,120,97,1,0,14,0,0,0,1,2,0,0,96,19,1,0,0,0,0,0,254,0,2,0,128,129,4,0,14,0,0,0,1,4,4,0,8,49,4,0,14,0,0,0,1,4,0,0,72,246,3,0,0,0,0,0,254,0,2,0,72,202,5,0,14,0,0,0,1,8,0,0,80,246,3,0,14,0,0,0,1,8,8,0,112,212,3,0,109,109,112,95,117,53,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,178,249,186,102,0,0,16,1,109,109,112,95,117,55,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,229,237,111,124,0,0,16,1,109,109,112,95,117,55,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,78,130,158,175,0,0,32,0,109,109,112,95,117,55,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,100,240,42,196,0,0,32,0,109,109,112,95,117,55,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,225,150,115,29,0,0,32,0,109,109,112,95,117,55,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,11,216,8,85,0,0,32,0,109,109,112,95,117,51,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,173,140,9,77,0,0,64,0,109,109,112,95,117,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,102,37,26,33,0,0,64,0,56,55,99,53,50,46,109,99,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,16,112,114,111,116,100,97,116,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,170,210,45,120,0,0,16,1,117,53,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,70,178,164,206,0,0,16,1,117,55,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,136,203,205,42,0,0,16,1,117,55,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,92,129,113,214,0,0,32,0,117,55,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,232,121,212,224,0,0,32,0,117,55,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,218,129,162,96,0,0,32,0,117,55,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,78,59,114,226,0,0,32,0,117,51,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,252,149,220,146,0,0,64,0,117,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,136,0,88,144,0,0,64,0,56,55,99,53,50,46,109,99,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,16,112,114,111,116,100,97,116,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,170,210,45,120,0,0,16,1,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,52,183,32,188,1,0,16,1,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,194,254,111,219,1,0,16,1,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,184,49,137,55,1,0,16,1,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,44,188,29,3,1,0,16,1,109,119,50,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,235,49,98,194,2,0,16,1,109,119,50,46,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,70,166,72,187,2,0,16,1,109,119,50,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,160,26,250,197,4,0,32,0,109,119,50,46,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,82,198,204,166,4,0,32,0,109,111,111,110,119,97,114,97,46,99,108,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,88,79,141,245,7,0,32,0,13,0,0,0,255,255,0,0,0,0,0,0,14,0,0,0,255,255,3,0,0,0,0,0,15,0,0,0,255,255,14,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,14,0,0,0,1,3,3,0,8,49,4,0,14,0,0,0,1,3,2,0,152,21,4,0,14,0,0,0,1,3,1,0,72,246,3,0,14,0,0,0,1,3,0,0,16,227,4,0,0,0,0,0,254,0,4,0,32,4,2,0,15,0,0,0,1,6,6,0,128,103,7,0,15,0,0,0,1,6,4,0,80,196,7,0,15,0,0,0,1,6,2,0,0,90,2,0,15,0,0,0,1,6,0,0,72,74,2,0,0,0,0,0,254,0,2,0,200,30,2,0,15,0,0,0,1,8,8,0,120,97,1,0,15,0,0,0,1,8,0,0,96,19,1,0,109,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,122,74,149,125,1,0,16,1,109,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,250,124,187,68,1,0,16,1,109,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,4,33,65,156,1,0,16,1,109,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,181,26,155,126,1,0,16,1,109,99,53,46,55,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,175,89,199,22,1,0,16,1,109,99,54,46,56,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,219,175,188,105,1,0,16,1,109,99,55,46,56,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,70,188,13,181,1,0,16,1,109,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,43,49,202,24,1,0,16,1,109,99,115,95,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,129,31,15,251,4,0,32,0,109,99,115,95,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,21,42,147,19,4,0,32,0,109,99,115,95,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,90,187,30,99,4,0,32,0,109,99,115,95,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,69,209,207,36,4,0,32,0,109,109,105,54,51,51,49,46,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,135,125,12,106,7,0,32,0,11,0,0,0,255,255,0,0,0,0,0,0,12,0,0,0,255,255,128,0,0,0,0,0,13,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,11,0,0,0,1,32,0,0,120,97,1,0,11,0,0,0,1,32,32,0,96,19,1,0,0,0,0,0,254,0,2,0,64,37,5,0,12,0,0,0,1,64,0,0,152,53,6,0,12,0,0,0,1,64,64,0,8,49,6,0,0,0,0,0,254,0,2,0,128,112,3,0,12,0,0,0,1,128,128,0,168,22,4,0,12,0,0,0,1,128,0,0,224,247,3,0,0,0,0,0,254,0,4,0,200,87,7,0,13,0,0,0,1,3,3,0,144,102,8,0,13,0,0,0,1,3,2,0])
.concat([176,45,8,0,13,0,0,0,1,3,1,0,224,127,8,0,13,0,0,0,1,3,0,0,32,123,8,0,0,0,0,0,254,0,4,0,160,123,6,0,13,0,0,0,1,12,0,0,128,103,7,0,13,0,0,0,1,12,4,0,80,196,7,0,13,0,0,0,1,12,8,0,0,90,2,0,13,0,0,0,1,12,12,0,104,151,6,0,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,175,164,124,166,1,0,16,1,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,62,206,237,22,1,0,16,1,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,239,157,147,161,1,0,16,1,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,48,136,143,6,1,0,16,1,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,45,97,174,40,1,0,16,1,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,135,169,61,128,1,0,16,1,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,252,192,154,142,1,0,16,1,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,47,142,10,2,1,0,16,1,109,99,115,95,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,129,31,15,251,4,0,32,0,109,99,115,95,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,21,42,147,19,4,0,32,0,109,99,115,95,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,90,187,30,99,4,0,32,0,109,99,115,95,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,69,209,207,36,4,0,32,0,109,109,105,54,51,51,49,46,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,135,125,12,106,7,0,32,0,11,0,0,0,255,255,0,0,0,0,0,0,12,0,0,0,255,255,192,0,0,0,0,0,13,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,11,0,0,0,1,32,0,0,120,97,1,0,11,0,0,0,1,32,32,0,96,19,1,0,0,0,0,0,254,0,2,0,72,202,5,0,12,0,0,0,1,64,64,0,80,246,3,0,12,0,0,0,1,64,0,0,112,212,3,0,0,0,0,0,254,0,2,0,16,112,1,0,12,0,0,0,1,128,0,0,248,81,6,0,12,0,0,0,1,128,128,0,176,64,8,0,0,0,0,0,254,0,4,0,200,87,7,0,13,0,0,0,1,3,3,0,144,102,8,0,13,0,0,0,1,3,2,0,176,45,8,0,13,0,0,0,1,3,1,0,224,127,8,0,13,0,0,0,1,3,0,0,32,123,8,0,0,0,0,0,254,0,4,0,160,123,6,0,13,0,0,0,1,12,0,0,128,103,7,0,13,0,0,0,1,12,4,0,80,196,7,0,13,0,0,0,1,12,8,0,0,90,2,0,13,0,0,0,1,12,12,0,104,151,6,0,11,0,0,0,255,255,0,0,0,0,0,0,12,0,0,0,255,255,0,0,0,0,0,0,13,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,11,0,0,0,1,32,0,0,120,97,1,0,11,0,0,0,1,32,32,0,96,19,1,0,0,0,0,0,254,0,2,0,64,37,5,0,12,0,0,0,1,64,0,0,152,53,6,0,12,0,0,0,1,64,64,0,8,49,6,0,0,0,0,0,254,0,4,0,200,87,7,0,13,0,0,0,1,3,3,0,144,102,8,0,13,0,0,0,1,3,2,0,176,45,8,0,13,0,0,0,1,3,1,0,224,127,8,0,13,0,0,0,1,3,0,0,32,123,8,0,0,0,0,0,254,0,4,0,160,123,6,0,13,0,0,0,1,12,0,0,128,103,7,0,13,0,0,0,1,12,4,0,80,196,7,0,13,0,0,0,1,12,8,0,0,90,2,0,13,0,0,0,1,12,12,0,104,151,6,0,0,0,0,0,98,101,112,114,49,57,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,109,236,35,106,1,0,16,1,98,101,112,114,49,57,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,242,47,38,238,1,0,16,1,102,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,171,176,162,41,1,0,16,1,102,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,109,90,106,76,1,0,16,1,101,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,166,120,211,6,1,0,16,1,98,101,112,114,49,57,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,39,169,132,110,1,0,16,1,101,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,232,241,90,180,1,0,16,1,98,101,112,114,50,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,213,85,218,102,1,0,16,1,101,112,114,50,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,97,181,38,190,4,0,32,0,109,99,115,95,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,21,42,147,19,4,0,32,0,101,112,114,50,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,232,199,38,4,0,32,0,109,99,115,95,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,69,209,207,36,4,0,32,0,109,109,105,54,51,51,49,46,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,135,125,12,106,7,0,32,0,11,0,0,0,255,255,0,0,0,0,0,0,12,0,0,0,255,255,128,0,0,0,0,0,13,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,11,0,0,0,1,32,0,0,120,97,1,0,11,0,0,0,1,32,32,0,96,19,1,0,0,0,0,0,254,0,2,0,64,37,5,0,12,0,0,0,1,64,0,0,152,53,6,0,12,0,0,0,1,64,64,0,8,49,6,0,0,0,0,0,254,0,2,0,128,112,3,0,12,0,0,0,1,128,128,0,168,22,4,0,12,0,0,0,1,128,0,0,224,247,3,0,0,0,0,0,254,0,4,0,32,4,2,0,13,0,0,0,1,12,0,0,128,103,7,0,13,0,0,0,1,12,4,0,80,196,7,0,13,0,0,0,1,12,8,0,0,90,2,0,13,0,0,0,1,12,12,0,104,151,6,0,0,0,0,0,109,111,111,110,99,114,115,52,46,55,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,65,16,32,94,1,0,16,1,109,111,111,110,99,114,115,52,46,55,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,142,124,224,141,1,0,16,1,109,111,111,110,99,114,115,52,46,55,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,97,109,140,136,1,0,16,1,109,111,111,110,99,114,115,52,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,1,155,47,73,1,0,16,1,109,111,111,110,99,114,115,52,46,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,165,167,8,245,4,0,32,0,109,111,111,110,99,114,115,52,46,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,19,147,84,155,4,0,32,0,112,114,111,109,46,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,135,125,12,106,7,0,32,0,98,49,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,138,205,40,11,1,0,16,1,98,50,46,55,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,202,240,166,116,1,0,16,1,98,51,46,55,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,201,76,179,238,1,0,16,1,98,52,46,55,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,229,48,67,113,1,0,16,1,111,46,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,5,167,141,82,4,0,32,0,113,46,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,234,23,75,90,4,0,32,0,112,46,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,107,255,121,78,4,0,32,0,114,46,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,189,204,237,224,4,0,32,0,109,109,105,54,51,51,49,46,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,135,125,12,106,7,0,32,0,102,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,229,3,96,211,1,0,16,1,98,101,112,114,49,57,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,242,47,38,238,1,0,16,1,102,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,171,176,162,41,1,0,16,1,102,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,109,90,106,76,1,0,16,1,101,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,166,120,211,6,1,0,16,1,98,101,112,114,49,57,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,39,169,132,110,1,0,16,1,101,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,232,241,90,180,1,0,16,1,109,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,120,224,126,149,1,0,16,1,49,104,95,49,95,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,5,167,141,82,4,0,32,0,49,50,46,99,104,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,234,23,75,90,4,0,32,0,49,107,95,49,95,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,107,255,121,78,4,0,32,0,49,49,46,99,104,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,189,204,237,224,4,0,32,0,109,109,105,54,51,51,49,46,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,135,125,12,106,7,0,32,0,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,11,66,207,132,1,0,16,1,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,161,97,42,76,1,0,16,1,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,58,82,98,25,1,0,16,1,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,150,168,220,117,1,0,16,1,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,57,48,72,50,1,0,16,1,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,137,171,242,67,1,0,16,1,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,140,22,156,30,1,0,16,1,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,148,218,9,94,1,0,16,1,49,104,95,49,95,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,5,167,141,82,4,0,32,0,49,50,46,99,104,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,234,23,75,90,4,0,32,0,57,46,99,104,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,92,82,223,112,4,0,32,0,49,49,46,99,104,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,189,204,237,224,4,0,32,0,108,48,54,95,112,114,111,109,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,135,125,12,106,7,0,32,0,11,0,0,0,255,255,0,0,0,0,0,0,12,0,0,0,255,255,192,0,0,0,0,0,13,0,0,0,255,255,1,0,0,0,0,0,0,0,0,0,254,0,2,0,200,87,7,0,12,0,0,0,1,64,0,0,224,127,8,0,12,0,0,0,1,64,64,0,32,123,8,0,0,0,0,0,254,0,2,0,160,123,6,0,12,0,0,0,1,128,128,0,0,90,2,0,12,0,0,0,1,128,0,0,104,61,2,0,0,0,0,0,254,0,2,0,64,37,5,0,13,0,0,0,1,1,1,0,152,53,6,0,13,0,0,0,1,1,0,0,8,49,6,0,0,0,0,0,254,0,2,0,200,30,2,0,13,0,0,0,1,8,0,0,120,97,1,0,13,0,0,0,1,8,8,0,96,19,1,0,0,0,0,0,101,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,175,164,124,166,1,0,16,1,101,103,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,14,20,123,181,1,0,16,1,101,103,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,239,157,147,161,1,0,16,1,101,103,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,48,136,143,6,1,0,16,1,101,103,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,220,154,205,50,1,0,16,1,101,103,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,217,98,75,58,1,0,16,1,101,103,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,113,82,65,34,1,0,16,1,101,103,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,5,193,156,123,1,0,16,1,101,103,95,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,129,31,15,251,4,0,32,0,101,103,95,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,21,42,147,19,4,0,32,0,101,103,95,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,90,187,30,99,4,0,32,0,101,103,95,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,69,209,207,36,4,0,32,0,112,114,111,109,95,54,51,51,49,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,135,125,12,106,7,0,32,0,11,0,0,0,255,255,0,0,0,0,0,0,12,0,0,0,255,255,192,0,0,0,0,0,13,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,11,0,0,0,1,32,0,0,120,97,1,0,11,0,0,0,1,32,32,0,96,19,1,0,0,0,0,0,254,0,2,0,72,202,5,0,12,0,0,0,1,64,64,0,80,246,3,0,12,0,0,0,1,64,0,0,112,212,3,0,0,0,0,0,254,0,2,0,16,112,1,0,12,0,0,0,1,128,0,0,248,81,6,0,12,0,0,0,1,128,128,0,176,64,8,0,0,0,0,0,254,0,13,0,32,4,2,0,13,0,0,0,1,15,0,0,160,111,1,0,13,0,0,0,1,15,1,0,72,110,1,0,13,0,0,0,1,15,2,0,152,109,1,0])
.concat([13,0,0,0,1,15,3,0,160,108,1,0,13,0,0,0,1,15,4,0,192,107,1,0,13,0,0,0,1,15,5,0,56,106,1,0,13,0,0,0,1,15,6,0,232,104,1,0,13,0,0,0,1,15,7,0,184,103,1,0,13,0,0,0,1,15,8,0,232,102,1,0,13,0,0,0,1,15,9,0,48,101,1,0,13,0,0,0,1,15,10,0,48,100,1,0,13,0,0,0,1,15,11,0,0,99,1,0,13,0,0,0,1,15,12,0,16,227,4,0,109,99,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,213,124,241,22,1,0,16,1,109,99,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,5,136,18,226,1,0,16,1,109,99,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,16,170,110,113,1,0,16,1,109,99,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,143,205,69,189,1,0,16,1,109,99,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,40,5,30,154,1,0,16,1,109,99,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,72,0,35,240,1,0,16,1,109,99,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,2,77,253,234,1,0,16,1,109,99,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,248,50,238,204,1,0,16,1,109,99,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,5,167,141,82,4,0,32,0,109,99,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,234,23,75,90,4,0,32,0,109,99,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,107,255,121,78,4,0,32,0,109,99,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,189,204,237,224,4,0,32,0,109,109,105,54,51,51,49,46,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,135,125,12,106,7,0,32,0,8,0,0,0,255,255,0,0,0,0,0,0,9,0,0,0,255,255,192,0,0,0,0,0,16,0,0,0,255,255,3,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,8,0,0,0,1,32,0,0,120,97,1,0,8,0,0,0,1,32,32,0,96,19,1,0,0,0,0,0,254,0,2,0,72,202,5,0,9,0,0,0,1,64,64,0,80,246,3,0,9,0,0,0,1,64,0,0,112,212,3,0,0,0,0,0,254,0,2,0,16,98,1,0,9,0,0,0,1,128,0,0,248,81,6,0,9,0,0,0,1,128,128,0,176,64,8,0,0,0,0,0,254,0,4,0,200,87,7,0,16,0,0,0,1,3,0,0,192,110,8,0,16,0,0,0,1,3,1,0,248,116,8,0,16,0,0,0,1,3,2,0,232,143,1,0,16,0,0,0,1,3,3,0,8,97,1,0,0,0,0,0,254,0,4,0,160,123,6,0,16,0,0,0,1,12,0,0,128,103,7,0,16,0,0,0,1,12,4,0,80,196,7,0,16,0,0,0,1,12,8,0,0,90,2,0,16,0,0,0,1,12,12,0,104,151,6,0,97,108,105,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,180,202,206,13,1,0,16,1,97,108,105,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,167,117,238,198,1,0,16,1,109,100,45,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,135,177,24,131,1,0,16,1,97,108,105,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,29,246,60,111,1,0,16,1,97,108,105,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,50,212,105,225,1,0,16,1,97,108,105,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,115,75,246,65,1,0,16,1,97,108,105,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,118,232,46,247,1,0,16,1,97,108,105,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,60,118,251,183,1,0,16,1,97,108,105,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,121,145,5,177,1,0,16,1,109,100,45,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,224,115,201,156,1,0,16,1,97,108,105,49,51,46,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,246,123,40,161,4,0,32,0,97,108,105,49,50,46,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,129,20,143,82,4,0,32,0,54,108,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,103,148,172,195,7,0,32,0,168,86,7,0,1,0,0,0,183,240,146,0,248,191,2,0,24,38,7,0,1,0,0,0,134,1,147,0,184,160,2,0,56,210,6,0,1,0,0,0,128,1,147,0,192,135,2,0,24,163,6,0,1,0,0,0,129,1,147,0,240,108,2,0,152,122,6,0,1,0,0,0,131,1,147,0,96,82,2,0,192,72,6,0,1,0,0,0,130,1,147,0,32,56,2,0,200,110,3,0,1,0,0,0,132,1,147,0,152,30,2,0,120,89,3,0,1,0,0,0,133,1,147,0,232,10,2,0,144,236,1,0,1,0,0,0,135,1,147,0,136,224,1,0,176,223,1,0,1,0,0,0,208,248,146,0,72,198,1,0,192,209,1,0,1,0,0,0,209,248,146,0,24,182,1,0,24,198,1,0,1,0,0,0,211,248,146,0,40,167,1,0,120,189,1,0,1,0,0,0,210,248,146,0,200,149,1,0,224,22,1,0,1,0,0,0,212,248,146,0,56,126,1,0,160,14,1,0,1,0,0,0,213,248,146,0,32,101,1,0,88,212,3,0,1,0,0,0,0,221,146,0,40,185,3,0,72,65,1,0,9,0,0,0,208,6,147,0,32,58,1,0,48,50,1,0,9,0,0,0,209,6,147,0,32,58,1,0,224,41,1,0,9,0,0,0,210,6,147,0,32,58,1,0,168,86,7,0,1,0,0,0,248,1,147,0,248,191,2,0,24,38,7,0,1,0,0,0,63,249,146,0,184,160,2,0,56,210,6,0,1,0,0,0,58,249,146,0,192,135,2,0,24,163,6,0,1,0,0,0,59,249,146,0,240,108,2,0,152,122,6,0,1,0,0,0,56,249,146,0,96,82,2,0,192,72,6,0,1,0,0,0,57,249,146,0,32,56,2,0,200,110,3,0,1,0,0,0,60,249,146,0,152,30,2,0,120,89,3,0,1,0,0,0,61,249,146,0,232,10,2,0,120,74,3,0,1,0,0,0,62,249,146,0,152,138,8,0,40,246,1,0,1,0,0,0,249,1,147,0,64,246,1,0,144,236,1,0,1,0,0,0,31,241,146,0,136,224,1,0,176,223,1,0,1,0,0,0,26,241,146,0,72,198,1,0,192,209,1,0,1,0,0,0,27,241,146,0,24,182,1,0,24,198,1,0,1,0,0,0,24,241,146,0,40,167,1,0,120,189,1,0,1,0,0,0,25,241,146,0,200,149,1,0,224,22,1,0,1,0,0,0,28,241,146,0,56,126,1,0,160,14,1,0,1,0,0,0,29,241,146,0,32,101,1,0,176,9,1,0,1,0,0,0,30,241,146,0,96,32,8,0,168,132,8,0,1,0,0,0,250,1,147,0,232,209,1,0,72,126,8,0,1,0,0,0,159,237,146,0,144,189,1,0,192,122,8,0,1,0,0,0,154,237,146,0,208,174,1,0,40,116,8,0,1,0,0,0,155,237,146,0,48,160,1,0,72,110,8,0,1,0,0,0,152,237,146,0,160,140,1,0,184,102,8,0,1,0,0,0,153,237,146,0,56,112,1,0,248,67,8,0,1,0,0,0,156,237,146,0,32,92,1,0,136,64,8,0,1,0,0,0,157,237,146,0,64,77,1,0,128,58,8,0,1,0,0,0,158,237,146,0,112,157,4,0,232,23,8,0,1,0,0,0,251,1,147,0,104,195,5,0,160,19,8,0,1,0,0,0,167,236,146,0,32,245,8,0,248,16,8,0,1,0,0,0,162,236,146,0,32,231,8,0,192,12,8,0,1,0,0,0,163,236,146,0,88,214,8,0,224,5,8,0,1,0,0,0,160,236,146,0,224,202,8,0,144,1,8,0,1,0,0,0,161,236,146,0,72,193,8,0,176,222,7,0,1,0,0,0,164,236,146,0,144,180,8,0,176,218,7,0,1,0,0,0,165,236,146,0,208,164,8,0,248,214,7,0,1,0,0,0,166,236,146,0,160,152,4,0,88,212,3,0,1,0,0,0,112,221,146,0,40,185,3,0,32,77,1,0,1,0,0,0,192,7,147,0,216,70,1,0,56,122,5,0,1,0,0,0,252,1,147,0,224,12,8,0,0,105,5,0,1,0,0,0,253,1,147,0,128,176,7,0,152,120,4,0,1,0,0,0,254,1,147,0,248,114,7,0,112,109,5,0,1,0,0,0,255,1,147,0,32,105,5,0,19,0,0,0,255,255,254,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,19,0,0,0,1,1,0,0,120,97,1,0,19,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,2,2,0,96,135,7,0,19,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,8,0,0,96,135,7,0,19,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,3,2,0,80,246,3,0,20,0,0,0,1,3,3,0,80,124,6,0,20,0,0,0,1,3,1,0,112,212,3,0,20,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,64,37,5,0,20,0,0,0,1,12,12,0,152,28,8,0,20,0,0,0,1,12,8,0,120,24,8,0,20,0,0,0,1,12,4,0,128,114,7,0,20,0,0,0,1,12,0,0,120,7,5,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,48,0,0,208,75,4,0,20,0,0,0,1,48,48,0,8,49,4,0,20,0,0,0,1,48,16,0,152,21,4,0,20,0,0,0,1,48,32,0,72,246,3,0,0,0,0,0,254,0,2,0,144,246,3,0,20,0,0,0,1,64,64,0,96,135,7,0,20,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,8,13,8,0,20,0,0,0,1,128,0,0,0,7,8,0,20,0,0,0,1,128,128,0,144,2,8,0,109,109,120,106,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,19,226,93,29,1,0,16,1,109,109,120,106,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,57,163,67,217,1,0,16,1,109,109,120,106,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,187,74,139,12,1,0,16,1,109,109,120,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,24,135,116,4,5,0,32,0,109,109,120,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,68,79,7,56,5,0,32,0,109,109,120,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,53,94,99,228,5,0,32,0,109,109,120,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,242,163,0,68,5,0,32,0,109,109,120,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,145,244,43,213,5,0,32,0,109,109,120,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,128,7,247,35,5,0,32,0,109,109,120,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,213,201,98,37,5,0,32,0,109,109,120,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,135,150,58,88,5,0,32,0,109,109,120,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,113,129,126,197,10,0,16,1,109,109,120,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,159,179,128,65,12,0,64,0,109,109,120,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,89,42,226,149,12,0,64,0,109,109,120,117,100,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,96,30,113,54,1,0,16,1,109,109,120,117,100,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,111,34,135,70,1,0,16,1,109,109,120,117,100,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,152,67,18,82,1,0,16,1,109,109,120,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,24,135,116,4,5,0,32,0,109,109,120,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,68,79,7,56,5,0,32,0,109,109,120,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,53,94,99,228,5,0,32,0,109,109,120,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,242,163,0,68,5,0,32,0,109,109,120,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,145,244,43,213,5,0,32,0,109,109,120,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,128,7,247,35,5,0,32,0,109,109,120,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,213,201,98,37,5,0,32,0,109,109,120,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,135,150,58,88,5,0,32,0,109,109,120,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,113,129,126,197,10,0,16,1,109,109,120,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,159,179,128,65,12,0,64,0,109,109,120,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,89,42,226,149,12,0,64,0,114,99,109,117,46,48,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,127,3,159,195,1,0,16,1,114,99,109,117,46,48,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,153,94,111,205,1,0,16,1,114,99,109,46,48,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,149,234,118,67,1,0,16,1,114,99,109,46,55,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,4,110,76,119,5,0,32,0,114,99,109,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,98,124,173,172,5,0,32,0,114,99,109,46,56,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,153,4,243,106,5,0,32,0,114,99,109,46,57,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,102,81,90,122,5,0,32,0,114,99,109,46,55,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,37,199,78,0,5,0,32,0,114,99,109,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,78,70,192,101,5,0,32,0,114,99,109,46,56,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,204,151,48,251,5,0,32,0,114,99,109,46,57,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,122,85,22,46,5,0,32,0,114,99,109,46,55,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,153,63,167,112,5,0,32,0,114,99,109,46,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,61,173,237,236,5,0,32,0,114,99,109,46,56,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,216,134,97,61,5,0,32,0,114,99,109,46,57,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,241,0,119,140,5,0,32,0,114,99,109,46,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,173,137,168,137,5,0,32,0,114,99,109,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,123,235,0,19,5,0,32,0,114,99,109,46,56,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,189,78,151,109,5,0,32,0,114,99,109,46,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,36,205,164,125,5,0,32,0,114,99,109,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,163,248,12,214,10,0,16,1,114,99,109,46,53,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,128,112,208,182,12,0,64,0,114,99,109,46,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,8,0,147,196,221,223,12,0,64,0,114,99,109,46,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,58,174,98,96,12,0,64,0,114,99,109,46,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,191,243,198,8,12,0,64,0,114,99,109,46,53,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,204,252,125,249,12,0,64,0,114,99,109,46,53,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,188,117,228,173,12,0,64,0,114,99,109,46,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,179,255,94,7,12,0,64,0,114,99,109,46,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,123,248,193,246,12,0,64,0,99,55,55,45,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,1,93,0,10,2,0,16,1,99,55,55,45,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,117,247,68,66,2,0,16,1,99,55,55,45,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,56,224,231,194,1,0,16,1,99,55,55,45,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,30,44,107,241,9,0,16,1,99,55,55,45,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,5,18,165,91,11,0,32,0,99,55,55,45,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,64,48,111,106,11,0,32,0,99,55,55,45,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,120,70,165,197,15,0,32,0,99,55,55,45,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,177,23,47,49,24,0,64,0,25,0,0,0,255,255,255,0,0,0,0,0,26,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,25,0,0,0,1,2,2,0,96,135,7,0,25,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,25,0,0,0,1,4,4,0,96,135,7,0,25,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,25,0,0,0,1,8,0,0,96,135,7,0,25,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,25,0,0,0,1,48,0,0,16,242,7,0,25,0,0,0,1,48,16,0,104,236,7,0,25,0,0,0,1,48,48,0,128,230,7,0,25,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,25,0,0,0,1,192,0,0,16,242,7,0,25,0,0,0,1,192,64,0,104,236,7,0,25,0,0,0,1,192,192,0,128,230,7,0,25,0,0,0,1,192,128,0,184,164,6,0,0,0,0,0,254,0,4,0,72,202,5,0,26,0,0,0,1,3,2,0,80,246,3,0,26,0,0,0,1,3,3,0,80,124,6,0,26,0,0,0,1,3,1,0,112,212,3,0,26,0,0,0,1,3,0,0,248,160,5,0,101,112,114,45,55,52,48,52,46,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,181,85,22,236,1,0,16,1,101,112,114,45,55,52,48,49,46,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,224,165,239,43,1,0,16,1,101,112,114,45,55,52,48,53,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,56,78,79,122,1,0,16,1,101,112,114,45,55,52,48,50,46,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,98,247,190,183,1,0,16,1,101,112,114,45,55,52,48,54,97,46,49,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,57,54,116,187,1,0,16,1,101,112,114,45,55,52,48,51,97,46,56,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,208,164,57,10,1,0,16,1,101,112,114,45,55,48,53,49,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,90,37,202,16,2,0,32,0,101,112,114,45,55,48,53,50,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,14,219,80,37,2,0,32,0,101,112,114,45,55,48,53,51,46,49,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,56,160,254,91,2,0,32,0,101,112,114,45,55,48,53,53,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,189,96,184,31,3,0,32,0,101,112,114,45,55,48,53,57,46,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,29,9,20,61,3,0,32,0,101,112,114,45,55,48,53,54,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,104,217,93,179,3,0,32,0,101,112,114,45,55,48,54,48,46,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,87,55,187,97,3,0,32,0,101,112,114,45,55,48,53,55,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,111,43,90,62,3,0,32,0,101,112,114,45,55,48,54,49,46,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,213,218,8,200,3,0,32,0,101,112,114,45,55,48,53,56,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,95,103,67,181,3,0,32,0,101,112,114,45,55,48,54,50,46,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,71,235,104,145,3,0,32,0,101,112,114,45,55,48,53,52,99,46,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,68,183,67,68,4,0,16,1,55,55,53,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,252,52,149,106,6,0,16,1,101,112,114,45,55,48,54,51,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,138,144,216,69,7,0,64,0,101,112,114,45,55,48,54,53,46,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,255,140,143,140,7,0,64,0,101,112,114,45,55,48,54,52,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,54,102,159,21,7,0,64,0,101,112,114,45,55,48,54,54,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,31,169,207,245,7,0,64,0,27,0,0,0,255,255,255,0,0,0,0,0,28,0,0,0,255,255,240,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,27,0,0,0,1,15,7,0,80,252,6,0,27,0,0,0,1,15,8,0,16,242,7,0,27,0,0,0,1,15,9,0,104,236,7,0,27,0,0,0,1,15,5,0,176,51,4,0,27,0,0,0,1,15,4,0,56,24,4,0,27,0,0,0,1,15,15,0,128,230,7,0,27,0,0,0,1,15,1,0,72,216,3,0,27,0,0,0,1,15,2,0,24,188,3,0,27,0,0,0,1,15,3,0,176,162,3,0,27,0,0,0,1,15,6,0,120,211,6,0,27,0,0,0,1,15,14,0,184,164,6,0,27,0,0,0,1,15,13,0,80,74,6,0,27,0,0,0,1,15,12,0,192,32,6,0,27,0,0,0,1,15,11,0,192,234,2,0,27,0,0,0,1,15,10,0,32,242,5,0,27,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,27,0,0,0,1,240,112,0,80,252,6,0,27,0,0,0,1,240,128,0,16,242,7,0,27,0,0,0,1,240,144,0,104,236,7,0,27,0,0,0,1,240,80,0,176,51,4,0,27,0,0,0,1,240,64,0,56,24,4,0,27,0,0,0,1,240,240,0,128,230,7,0,27,0,0,0,1,240,16,0,72,216,3,0,27,0,0,0,1,240,32,0,24,188,3,0,27,0,0,0,1,240,48,0,176,162,3,0,27,0,0,0,1,240,96,0,120,211,6,0,27,0,0,0,1,240,224,0,184,164,6,0,27,0,0,0,1,240,208,0,80,74,6,0,27,0,0,0,1,240,192,0,192,32,6,0,27,0,0,0,1,240,176,0,192,234,2,0,27,0,0,0,1,240,160,0,32,242,5,0,27,0,0,0,1,240,0,0,208,236,2,0,0,0,0,0,254,0,2,0,200,30,2,0,28,0,0,0,1,1,0,0,120,97,1,0,28,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,2,0,168,234,7,0,28,0,0,0,1,2,2,0,96,135,7,0,28,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,4,0,216,231,2,0,28,0,0,0,1,12,12,0,184,230,7,0,28,0,0,0,1,12,8,0,72,123,3,0,28,0,0,0,1,12,4,0,136,120,6,0,28,0,0,0,1,12,0,0,176,116,6,0,0,0,0,0,254,0,2,0,160,216,4,0,28,0,0,0,1,16,2,0,96,135,7,0,28,0,0,0,1,16,16,0,152,182,7,0,99,52,57,45,48,57,46,105,99,52,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,185,158,224,106,2,0,16,1,99,52,57,45,49,49,46,105,99,52,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,110,190,210,66,2,0,16,1,99,52,57,45,49,48,46,105,99,52,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,224,242,190,80,2,0,16,1,99,52,57,45,49,51,46,105,99,52,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,249,219,24,37,2,0,16,1,99,52,57,45,48,56,46,105,99,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,12,49,60,65,9,0,16,1,99,52,57,45,48,51,46,105,99,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,155,79,54,195,11,0,32,0,99,52,57,45,48,49,46,105,99,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,99,49,204,103,15,0,32,0,99,52,57,45,48,50,46,105,99,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,16,7,64,210,15,0,32,0,99,52,57,45,48,52,46,105,99,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,164,69,77,71,24,0,64,0,109,109,119,57,54,95,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,217,28,237,69,0,0,16,1,109,109,119,57,54,95,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,93,158,236,82,0,0,16,1,109,109,119,57,54,95,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,5,139,69,108,0,0,16,1,109,109,119,57,54,95,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,85,149,21,72,0,0,16,1,109,109,119,57,54,95,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,7,43,199,29,0,0,16,1,109,109,119,57,54,95,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,250,24,62,252,0,0,16,1,109,109,119,57,54,95,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,191,114,21,0,0,0,16,1,109,109,119,57,54,95,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,37,64,32,34,0,0,16,1,109,109,119,57,54,95,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,140,31,73,125,0,0,32,0,109,119,57,54,95,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,158,101,138,231,0,0,64,0,109,119,57,54,95,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,12,250,96,0,0,64,0,109,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,196,160,153,3,1,0,16,1,109,109,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,30,151,94,44,1,0,16,1,109,109,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,227,28,206,36,1,0,16,1,109,109,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,57,182,63,200,1,0,16,1,109,109,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,252,45,241,169,1,0,16,1,109,109,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,12,164,146,228,1,0,16,1,109,109,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,141,146,57,83,1,0,16,1,109,109,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,46,161,231,238,1,0,16,1,109,109,115,111,117,110,100,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,39,197,20,45,2,0,16,1,109,109,115,110,100,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,150,15,237,53,2,0,16,1,109,109,103,102,120,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,55,115,244,74,4,0,32,0,109,109,103,102,120,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,168,125,244,222,4,0,32,0,99,48,49,115,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,171,174,60,78,7,0,32,0,102,114,97,95,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,121,115,122,142,1,0,16,1,102,114,97,95,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,254,203,8,171,1,0,16,1,102,114,97,95,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,77,162,77,45,1,0,16,1,102,114,97,95,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,124,252,136,141,1,0,16,1,102,114,97,95,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,45,195,229,180,1,0,16,1,102,114,97,95,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,196,54,144,64,1,0,16,1,102,114,97,95,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,250,8,156,17,1,0,16,1,102,114,97,95,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,3,253,0,215,1,0,16,1,109,109,115,111,117,110,100,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,39,197,20,45,2,0,16,1,109,109,115,110,100,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,150,15,237,53,2,0,16,1,109,109,103,102,120,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,55,115,244,74,4,0,32,0,109,109,103,102,120,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,168,125,244,222,4,0,32,0,56,50,115,49,50,51,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,171,174,60,78,7,0,32,0,17,0,0,0,255,255,0,0,0,0,0,0,18,0,0,0])
.concat([255,255,1,0,0,0,0,0,19,0,0,0,255,255,174,0,0,0,0,0,0,0,0,0,254,0,2,0,128,129,4,0,18,0,0,0,1,3,3,0,192,255,2,0,18,0,0,0,1,3,2,0,208,75,4,0,18,0,0,0,1,3,1,0,8,49,4,0,18,0,0,0,1,3,0,0,152,21,4,0,0,0,0,0,254,0,4,0,32,4,2,0,19,0,0,0,1,6,0,0,176,45,8,0,19,0,0,0,1,6,4,0,224,127,8,0,19,0,0,0,1,6,6,0,32,123,8,0,19,0,0,0,1,6,2,0,192,110,8,0,0,0,0,0,254,0,2,0,200,30,2,0,19,0,0,0,1,8,8,0,120,97,1,0,19,0,0,0,1,8,0,0,96,19,1,0,0,0,0,0,254,0,2,0,144,3,8,0,19,0,0,0,1,32,32,0,96,135,7,0,19,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,109,109,49,46,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,177,241,25,144,1,0,16,1,109,109,50,46,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,214,151,62,4,1,0,16,1,109,109,51,46,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,106,114,82,16,1,0,16,1,109,109,52,46,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,255,53,63,123,1,0,16,1,109,109,53,46,50,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,45,195,229,180,1,0,16,1,109,109,54,46,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,196,54,144,64,1,0,16,1,109,109,55,46,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,250,8,156,17,1,0,16,1,109,109,56,46,50,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,4,159,152,247,1,0,16,1,109,109,49,51,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,39,197,20,45,2,0,16,1,109,109,49,52,46,49,48,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,150,15,237,53,2,0,16,1,109,109,49,50,46,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,18,132,58,247,4,0,32,0,109,109,49,48,46,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,219,201,40,56,4,0,32,0,109,109,49,49,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,137,146,14,158,4,0,32,0,109,109,57,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,12,91,8,146,4,0,32,0,56,50,115,49,50,51,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,171,174,60,78,7,0,32,0,17,0,0,0,255,255,0,0,0,0,0,0,18,0,0,0,255,255,3,0,0,0,0,0,19,0,0,0,255,255,174,0,0,0,0,0,0,0,0,0,254,0,2,0,128,129,4,0,18,0,0,0,1,3,3,0,8,49,4,0,18,0,0,0,1,3,2,0,152,21,4,0,18,0,0,0,1,3,1,0,72,246,3,0,18,0,0,0,1,3,0,0,72,0,3,0,0,0,0,0,254,0,4,0,32,4,2,0,19,0,0,0,1,6,0,0,176,45,8,0,19,0,0,0,1,6,4,0,224,127,8,0,19,0,0,0,1,6,6,0,32,123,8,0,19,0,0,0,1,6,2,0,192,110,8,0,0,0,0,0,254,0,2,0,200,30,2,0,19,0,0,0,1,8,8,0,120,97,1,0,19,0,0,0,1,8,0,0,96,19,1,0,0,0,0,0,254,0,2,0,144,3,8,0,19,0,0,0,1,32,32,0,96,135,7,0,19,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,184,40,2,0,1,0,0,0,216,232,148,0,248,191,2,0,56,250,6,0,1,0,0,0,95,234,148,0,184,160,2,0,184,164,8,0,1,0,0,0,217,232,148,0,64,246,1,0,88,149,7,0,1,0,0,0,159,233,148,0,136,224,1,0,240,167,7,0,1,0,0,0,88,234,148,0,192,135,2,0,176,163,7,0,1,0,0,0,89,234,148,0,240,108,2,0,208,158,7,0,1,0,0,0,90,234,148,0,96,82,2,0,184,154,7,0,1,0,0,0,91,234,148,0,32,56,2,0,176,108,2,0,1,0,0,0,92,234,148,0,152,30,2,0,128,98,2,0,1,0,0,0,93,234,148,0,232,10,2,0,48,82,2,0,1,0,0,0,94,234,148,0,152,138,8,0,176,126,8,0,1,0,0,0,88,84,148,0,48,119,7,0,136,116,8,0,1,0,0,0,89,84,148,0,112,109,7,0,8,96,7,0,1,0,0,0,152,233,148,0,72,198,1,0,48,89,7,0,1,0,0,0,153,233,148,0,24,182,1,0,16,83,7,0,1,0,0,0,154,233,148,0,40,167,1,0,96,79,7,0,1,0,0,0,155,233,148,0,200,149,1,0,48,76,7,0,1,0,0,0,156,233,148,0,56,126,1,0,144,72,7,0,1,0,0,0,157,233,148,0,32,101,1,0,224,67,7,0,1,0,0,0,158,233,148,0,96,32,8,0,32,24,8,0,1,0,0,0,90,84,148,0,16,68,7,0,24,17,8,0,1,0,0,0,91,84,148,0,240,58,7,0,88,212,3,0,1,0,0,0,16,216,146,0,40,185,3,0,16,17,8,0,1,0,0,0,218,232,148,0,224,12,8,0,248,5,8,0,9,0,0,0,32,94,147,0,32,58,1,0,144,250,7,0,9,0,0,0,33,94,147,0,32,58,1,0,109,99,49,48,48,101,48,50,46,117,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,53,19,106,36,0,0,16,1,109,99,49,48,49,101,48,50,46,117,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,220,161,142,112,0,0,16,1,109,99,48,48,48,46,117,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,244,246,172,40,0,0,32,0,109,99,48,48,49,46,117,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,61,196,91,0,0,0,32,0,109,99,48,48,50,101,48,50,46,117,51,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,86,16,172,39,0,0,32,0,109,99,48,49,48,46,117,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,114,39,7,133,0,0,32,0,109,99,48,50,48,46,117,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,241,47,169,30,0,0,32,0,109,99,48,51,48,46,117,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,46,150,101,193,0,0,64,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,20,0,0,0,1,1,1,0,96,135,7,0,20,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,20,0,0,0,1,2,2,0,96,135,7,0,20,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,109,103,50,45,120,102,46,49,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,45,93,22,200,0,0,16,1,109,103,50,45,121,46,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,20,204,187,117,0,0,16,1,109,103,50,45,122,46,51,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,97,169,219,191,0,0,16,1,109,103,50,45,97,46,49,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,94,197,160,49,0,0,32,0,109,103,50,45,98,46,49,52,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,250,136,132,193,0,0,32,0,109,103,50,45,99,46,49,54,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,100,179,37,148,0,0,32,0,109,103,50,45,100,46,49,55,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,186,238,201,108,0,0,32,0,109,103,50,45,102,46,52,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,254,201,114,49,0,0,32,0,109,103,50,45,103,46,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,28,182,184,25,0,0,32,0,109,103,50,45,101,46,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,9,8,253,112,0,0,64,0,16,0,0,0,255,255,255,0,0,0,0,0,17,0,0,0,255,255,255,0,0,0,0,0,18,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,160,123,6,0,16,0,0,0,1,3,0,0,40,88,7,0,16,0,0,0,1,3,1,0,96,39,7,0,16,0,0,0,1,3,3,0,144,251,6,0,16,0,0,0,1,3,2,0,184,164,6,0,0,0,0,0,254,0,2,0,104,159,3,0,16,0,0,0,1,4,0,0,56,111,3,0,16,0,0,0,1,4,4,0,104,134,3,0,0,0,0,0,254,0,4,0,72,202,5,0,16,0,0,0,1,24,16,0,80,246,3,0,16,0,0,0,1,24,24,0,248,38,7,0,16,0,0,0,1,24,8,0,112,212,3,0,16,0,0,0,1,24,0,0,24,99,5,0,0,0,0,0,254,0,4,0,200,87,7,0,16,0,0,0,1,96,0,0,40,88,7,0,16,0,0,0,1,96,32,0,96,39,7,0,16,0,0,0,1,96,96,0,144,251,6,0,16,0,0,0,1,96,64,0,184,164,6,0,0,0,0,0,254,0,2,0,232,75,4,0,16,0,0,0,1,128,128,0,96,135,7,0,16,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,72,4,1,0,17,0,0,0,1,32,32,0,96,135,7,0,17,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,176,110,8,0,17,0,0,0,1,64,64,0,96,135,7,0,17,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,17,0,0,0,1,128,0,0,96,135,7,0,17,0,0,0,1,128,128,0,152,182,7,0,0,0,0,0,102,105,114,115,116,45,52,46,117,98,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,77,73,122,102,0,0,16,1,102,105,114,115,116,45,51,46,117,98,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,210,78,191,135,0,0,16,1,102,105,114,115,116,45,50,46,117,97,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,223,94,80,73,0,0,16,1,112,114,111,116,100,97,116,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,169,23,170,23,0,0,16,1,102,105,114,115,116,45,53,46,114,111,109,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,70,247,74,221,0,0,32,0,102,105,114,115,116,45,54,46,114,111,109,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,11,14,139,128,0,0,32,0,102,105,114,115,116,45,55,46,117,111,114,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,71,103,129,166,0,0,32,0,102,105,114,115,116,45,56,46,117,111,114,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,229,32,112,55,0,0,32,0,102,105,114,115,116,45,57,46,117,111,114,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,183,27,207,252,0,0,32,0,102,105,114,115,116,45,49,48,46,117,111,114,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,123,88,43,162,0,0,32,0,102,105,114,115,116,45,49,46,117,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,203,218,67,233,0,0,64,0,56,55,99,53,50,46,109,99,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,16,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,19,0,0,0,1,12,0,0,208,75,4,0,19,0,0,0,1,12,12,0,8,49,4,0,19,0,0,0,1,12,8,0,152,21,4,0,19,0,0,0,1,12,4,0,72,246,3,0,0,0,0,0,254,0,8,0,32,4,2,0,19,0,0,0,1,112,0,0,104,54,4,0,19,0,0,0,1,112,16,0,80,252,6,0,19,0,0,0,1,112,32,0,16,242,7,0,19,0,0,0,1,112,48,0,104,236,7,0,19,0,0,0,1,112,112,0,128,230,7,0,19,0,0,0,1,112,96,0,184,164,6,0,19,0,0,0,1,112,80,0,80,74,6,0,19,0,0,0,1,112,64,0,192,234,2,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,128,0,0,96,135,7,0,19,0,0,0,1,128,128,0,152,182,7,0,0,0,0,0,254,0,2,0,128,112,3,0,20,0,0,0,1,8,8,0,168,22,4,0,20,0,0,0,1,8,0,0,72,93,8,0,0,0,0,0,254,0,4,0,88,236,6,0,20,0,0,0,1,48,0,0,72,232,6,0,20,0,0,0,1,48,48,0,168,103,1,0,20,0,0,0,1,48,32,0,160,223,6,0,20,0,0,0,1,48,16,0,64,218,6,0,0,0,0,0,254,0,4,0,112,59,6,0,20,0,0,0,1,192,64,0,216,213,6,0,20,0,0,0,1,192,128,0,200,208,6,0,20,0,0,0,1,192,192,0,208,6,8,0,20,0,0,0,1,192,0,0,200,204,6,0,115,111,50,95,51,48,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,247,155,127,225,1,0,16,1,115,111,50,95,51,53,46,49,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,97,223,119,68,1,0,16,1,115,111,50,95,51,49,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,54,77,32,81,1,0,16,1,115,111,50,95,51,54,46,49,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,180,168,251,156,1,0,16,1,115,111,50,45,51,50,109,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,12,207,181,46,2,0,16,1,115,111,50,45,54,109,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,175,2,97,170,4,0,32,0,115,111,50,45,56,109,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,105,104,158,131,4,0,32,0,115,111,50,45,50,109,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,117,40,124,89,4,0,32,0,115,111,50,45,52,109,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,160,156,42,145,4,0,32,0,115,111,50,95,50,52,46,55,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,254,78,37,63,4,0,32,0,115,111,50,95,49,52,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,94,144,168,245,4,0,32,0,115,111,50,95,50,54,46,57,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,74,90,170,243,4,0,32,0,115,111,50,95,49,54,46,57,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,168,209,60,180,4,0,32,0,115,111,50,95,50,48,46,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,163,81,167,140,4,0,32,0,115,111,50,95,49,48,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,253,105,245,233,4,0,32,0,115,111,50,95,50,50,46,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,119,163,233,252,4,0,32,0,115,111,50,95,49,50,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,6,138,223,183,4,0,32,0,115,111,50,95,48,57,46,49,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,122,124,157,208,3,0,16,0,115,111,50,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,67,22,234,187,5,0,64,0,115,111,50,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,113,170,88,172,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,111,50,50,52,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,205,200,17,194,0,0,0,8,105,111,98,49,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,99,54,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,0,0,0,0,0,0,24,114,109,50,117,100,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,37,95,99,211,1,0,16,1,114,109,50,117,100,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,5,23,138,118,1,0,16,1,114,109,50,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0])
.concat([252,158,238,2,1,0,16,1,114,109,50,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,180,0,31,155,5,0,32,0,114,109,50,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,36,12,187,194,5,0,32,0,114,109,50,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,81,114,37,18,5,0,32,0,114,109,50,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,134,231,182,249,5,0,32,0,114,109,50,46,48,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,89,120,142,209,10,0,16,1,114,109,50,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,224,236,99,196,10,0,16,1,114,109,50,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,77,23,6,33,12,0,64,0,114,109,50,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,54,22,108,84,12,0,64,0,114,99,109,97,95,50,51,98,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,151,163,228,97,2,0,16,1,114,99,109,97,95,50,50,98,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,196,104,130,112,2,0,16,1,114,99,109,97,95,50,49,97,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,149,234,118,67,2,0,16,1,114,99,109,95,48,49,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,63,241,205,110,4,0,32,0,114,99,109,95,48,50,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,15,79,77,148,4,0,32,0,114,99,109,95,48,51,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,60,7,243,54,4,0,32,0,114,99,109,95,48,52,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,255,34,230,84,4,0,32,0,114,99,109,95,48,53,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,253,49,209,93,4,0,32,0,114,99,109,95,48,54,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,19,248,250,240,4,0,32,0,114,99,109,95,48,55,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,19,224,109,130,4,0,32,0,114,99,109,95,48,56,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,207,100,255,251,4,0,32,0,114,99,109,95,49,48,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,169,173,200,77,4,0,32,0,114,99,109,95,49,49,46,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,6,238,185,242,4,0,32,0,114,99,109,95,49,50,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,3,242,213,254,4,0,32,0,114,99,109,95,49,51,46,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,169,212,105,80,4,0,32,0,114,99,109,95,49,52,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,189,227,59,48,4,0,32,0,114,99,109,95,49,53,46,56,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,47,55,45,79,4,0,32,0,114,99,109,95,49,54,46,57,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,222,127,217,147,4,0,32,0,114,99,109,95,49,55,46,49,48,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,66,16,55,146,4,0,32,0,114,99,109,95,48,57,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,239,214,50,150,3,0,16,0,114,99,109,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,170,248,241,128,5,0,64,0,114,99,109,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,225,219,87,242,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,114,99,109,54,51,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,148,212,172,132,0,0,0,8,105,111,98,49,46,49,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,98,112,114,103,49,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,167,61,121,49,0,0,0,8,105,111,99,49,46,105,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,129,32,24,13,0,0,0,8,99,54,51,50,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,112,146,189,15,0,0,0,8,114,109,50,117,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,209,44,252,143,1,0,16,1,114,109,50,117,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,58,8,48,187,1,0,16,1,114,109,50,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,252,158,238,2,1,0,16,1,114,109,50,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,180,0,31,155,5,0,32,0,114,109,50,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,36,12,187,194,5,0,32,0,114,109,50,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,81,114,37,18,5,0,32,0,114,109,50,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,134,231,182,249,5,0,32,0,114,109,50,46,48,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,89,120,142,209,10,0,16,1,114,109,50,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,224,236,99,196,10,0,16,1,114,109,50,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,77,23,6,33,12,0,64,0,114,109,50,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,54,22,108,84,12,0,64,0,99,49,49,45,48,55,46,53,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,182,40,210,17,2,0,16,1,99,49,49,45,48,56,46,51,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,202,77,157,167,2,0,16,1,99,49,49,45,48,54,46,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,148,152,36,124,2,0,16,1,99,49,49,45,49,49,46,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,249,203,62,38,2,0,16,1,99,49,49,45,49,50,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,241,148,16,177,9,0,16,1,99,49,49,45,48,53,46,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,142,109,62,115,11,0,32,0,99,49,49,45,48,51,46,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,122,140,113,70,16,0,32,0,99,49,49,45,48,52,46,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,204,51,63,102,16,0,32,0,99,49,49,45,48,49,46,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,50,165,30,253,24,0,64,0,99,49,49,45,48,50,46,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,135,193,28,69,25,0,64,0,112,97,108,49,54,108,56,98,45,98,56,57,45,48,49,46,105,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,122,185,149,64,0,0,0,8,112,97,108,49,54,108,56,98,45,98,56,57,45,48,50,46,105,99,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,89,181,48,100,0,0,0,8,112,97,108,49,54,108,56,98,45,98,56,57,45,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,226,146,69,99,0,0,0,8,112,97,108,99,101,49,54,118,56,45,98,56,57,45,48,52,46,105,99,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,226,106,19,252,0,0,0,8,112,97,108,49,54,108,56,98,45,99,49,49,45,49,51,46,105,99,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,168,126,29,66,0,0,0,8,112,97,108,49,54,108,56,98,45,99,49,49,45,49,52,46,105,99,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,238,10,116,92,0,0,0,8,19,0,0,0,255,255,254,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,19,0,0,0,1,1,0,0,120,97,1,0,19,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,2,2,0,96,135,7,0,19,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,4,4,0,96,135,7,0,19,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,8,0,0,96,135,7,0,19,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,19,0,0,0,1,48,0,0,80,252,6,0,19,0,0,0,1,48,16,0,16,242,7,0,19,0,0,0,1,48,32,0,104,236,7,0,19,0,0,0,1,48,48,0,128,230,7,0,0,0,0,0,254,0,4,0,160,123,6,0,19,0,0,0,1,192,192,0,8,201,6,0,19,0,0,0,1,192,128,0,200,197,6,0,19,0,0,0,1,192,64,0,152,194,6,0,19,0,0,0,1,192,0,0,248,189,6,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,3,2,0,80,246,3,0,20,0,0,0,1,3,3,0,80,124,6,0,20,0,0,0,1,3,1,0,112,212,3,0,20,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,64,37,5,0,20,0,0,0,1,12,12,0,240,191,4,0,20,0,0,0,1,12,4,0,200,213,4,0,20,0,0,0,1,12,8,0,144,227,4,0,20,0,0,0,1,12,0,0,120,7,5,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,48,16,0,192,255,2,0,20,0,0,0,1,48,0,0,208,75,4,0,20,0,0,0,1,48,48,0,8,49,4,0,20,0,0,0,1,48,32,0,152,21,4,0,0,0,0,0,254,0,2,0,144,212,6,0,20,0,0,0,1,64,0,0,8,208,6,0,20,0,0,0,1,64,64,0,88,204,6,0,109,98,100,106,95,50,54,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,28,69,183,114,1,0,16,1,109,98,100,106,95,51,48,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,207,49,255,190,1,0,16,1,109,98,100,106,95,50,55,46,49,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,52,245,134,64,1,0,16,1,109,98,100,106,95,51,49,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,240,71,95,8,1,0,16,1,109,98,100,106,95,50,52,46,57,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,165,149,8,194,1,0,16,1,109,98,100,106,95,50,56,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,225,213,24,38,1,0,16,1,109,98,100,106,95,50,53,46,49,48,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,17,107,219,155,1,0,16,1,109,98,100,106,95,50,57,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,229,213,82,63,1,0,16,1,109,98,100,106,95,50,49,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,106,2,12,105,2,0,16,1,109,98,100,106,95,50,48,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,155,19,178,184,2,0,16,1,109,98,95,48,49,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,129,28,59,165,4,0,32,0,109,98,95,48,50,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,16,254,35,4,0,32,0,109,98,95,48,51,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,47,108,134,203,4,0,32,0,109,98,95,48,52,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,117,62,20,201,4,0,32,0,109,98,95,48,53,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,201,157,107,80,4,0,32,0,109,98,95,48,54,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,251,194,248,175,4,0,32,0,109,98,95,48,55,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,233,112,108,183,4,0,32,0,109,98,95,48,56,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,86,149,12,230,4,0,32,0,109,98,95,49,48,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,245,111,151,151,4,0,32,0,109,98,95,49,49,46,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,8,0,64,168,80,179,4,0,32,0,109,98,95,49,50,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,67,71,185,143,4,0,32,0,109,98,95,49,51,46,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,95,13,129,218,4,0,32,0,109,98,95,113,97,46,53,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,196,3,26,226,3,0,16,1,109,98,45,113,49,46,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,206,195,48,6,6,0,64,0,109,98,45,113,50,46,50,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,33,156,79,53,6,0,64,0,109,98,45,113,51,46,51,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,124,72,56,120,6,0,64,0,109,98,45,113,52,46,52,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,135,224,102,171,6,0,64,0,109,98,45,113,53,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,242,254,137,199,6,0,64,0,109,98,45,113,54,46,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,27,184,236,6,0,64,0,109,98,45,113,55,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,186,73,30,4,6,0,64,0,109,98,45,113,56,46,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,42,112,254,89,6,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,154,135,134,67,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,109,98,54,51,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,2,47,57,184,0,0,0,8,105,111,98,49,46,49,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,98,112,114,103,49,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,167,61,121,49,0,0,0,8,105,111,99,49,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,129,32,24,13,0,0,0,8,100,55,108,49,46,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,13,65,183,39,0,0,0,8,100,56,108,49,46,56,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,218,199,159,83,0,0,0,8,100,57,107,50,46,57,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,86,161,133,205,0,0,0,8,100,49,48,102,49,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,148,196,25,102,0,0,0,8,109,98,106,95,50,51,101,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,106,3,6,13,2,0,16,1,109,98,106,95,50,50,98,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,120,132,211,172,2,0,16,1,109,98,106,95,50,49,97,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,5,123,0,213,2,0,16,1,109,98,106,95,50,48,97,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,176,87,181,174,2,0,16,1,109,98,95,48,49,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,129,28,59,165,4,0,32,0,109,98,95,48,50,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,16,254,35,4,0,32,0,109,98,95,48,51,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,47,108,134,203,4,0,32,0,109,98,95,48,52,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,117,62,20,201,4,0,32,0,109,98,95,48,53,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,201,157,107,80,4,0,32,0,109,98,95,48,54,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,251,194,248,175,4,0,32,0,109,98,95,48,55,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,233,112,108,183,4,0,32,0,109,98,95,48,56,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,86,149,12,230,4,0,32,0,109,98,95,49,48,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,245,111,151,151,4,0,32,0,109,98,95,49,49,46,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,64,168,80,179,4,0,32,0,109,98,95,49,50,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,67,71,185,143,4,0,32,0,109,98,95,49,51,46,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,95,13,129,218,4,0,32,0,109,98,95,113,97,46,53,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,196,3,26,226,3,0,16,1,109,98,45,113,49,46,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,206,195,48,6,6,0,64,0,109,98,45,113,50,46,50,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,33,156,79,53,6,0,64,0,109,98,45,113,51,46,51,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,124,72,56,120,6,0,64,0,109,98,45,113,52,46,52,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,135,224,102,171,6,0,64,0,109,98,45,113,53,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,242,254,137,199,6,0,64,0,109,98,45,113,54,46,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,27,184,236,6,0,64,0,109,98,45,113,55,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,186,73,30,4,6,0,64,0,109,98,45,113,56,46,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,42,112,254,89,6,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,154,135,134,67,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,109,98,54,51,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,2,47,57,184,0,0,0,8,105,111,98,49,46,49,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,98,112,114,103,49,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,167,61,121,49,0,0,0,8,105,111,99,49,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,129,32,24,13,0,0,0,8,100,55,108,49,46,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,13,65,183,39,0,0,0,8,100,56,108,49,46,56,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,218,199,159,83,0,0,0,8,100,57,107,50,46,57,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,86,161,133,205,0,0,0,8,100,49,48,102,49,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,148,196,25,102,0,0,0,8,20,0,0,0,255,255,255,0,0,0,0,0,21,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,168,212,4,0,20,0,0,0,1,1,0,0,96,135,7,0,20,0,0,0,1,1,1,0,152,182,7,0,0,0,0,0,254,0,2,0,240,47,2,0,20,0,0,0,1,2,2,0,96,37,2,0,20,0,0,0,1,2,0,0,72,27,2,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,12,0,0,24,99,5,0,20,0,0,0,1,12,4,0,112,212,3,0,20,0,0,0,1,12,12,0,248,38,7,0,20,0,0,0,1,12,8,0,80,246,3,0,0,0,0,0,254,0,4,0,72,84,4,0,20,0,0,0,1,48,0,0,24,99,5,0,20,0,0,0,1,48,16,0,112,212,3,0,20,0,0,0,1,48,48,0,248,38,7,0,20,0,0,0,1,48,32,0,80,246,3,0,0,0,0,0,254,0,2,0,40,17,2,0,20,0,0,0,1,64,64,0,88,8,2,0,20,0,0,0,1,64,0,0,224,0,2,0,0,0,0,0,254,0,2,0,232,75,4,0,20,0,0,0,1,128,128,0,96,135,7,0,20,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,21,0,0,0,1,1,1,0,96,135,7,0,21,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,3,0,128,112,3,0,21,0,0,0,1,6,6,0,168,22,4,0,21,0,0,0,1,6,4,0,176,224,1,0,21,0,0,0,1,6,2,0,72,93,8,0,0,0,0,0,254,0,2,0,96,46,8,0,21,0,0,0,1,8,8,0,192,255,2,0,21,0,0,0,1,8,0,0,208,75,4,0,0,0,0,0,254,0,16,0,32,4,2,0,21,0,0,0,1,240,160,0,144,160,3,0,21,0,0,0,1,240,176,0,96,135,3,0,21,0,0,0,1,240,192,0,32,136,7,0,21,0,0,0,1,240,208,0,40,88,7,0,21,0,0,0,1,240,224,0,96,39,7,0,21,0,0,0,1,240,16,0,32,202,2,0,21,0,0,0,1,240,48,0,120,113,6,0,21,0,0,0,1,240,32,0,232,228,5,0,21,0,0,0,1,240,240,0,144,251,6,0,21,0,0,0,1,240,64,0,120,211,6,0,21,0,0,0,1,240,144,0,184,164,6,0,21,0,0,0,1,240,128,0,80,74,6,0,21,0,0,0,1,240,112,0,192,32,6,0,21,0,0,0,1,240,96,0,192,234,2,0,21,0,0,0,1,240,80,0,32,242,5,0,21,0,0,0,1,240,0,0,16,227,4,0,0,0,0,0,17,0,0,0,255,255,24,0,0,0,0,0,18,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,176,152,5,0,17,0,0,0,1,1,0,0,96,135,7,0,17,0,0,0,1,1,1,0,152,182,7,0,0,0,0,0,254,0,2,0,24,149,5,0,17,0,0,0,1,2,0,0,168,22,4,0,17,0,0,0,1,2,2,0,224,247,3,0,0,0,0,0,254,0,2,0,168,234,7,0,17,0,0,0,1,4,4,0,96,135,7,0,17,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,200,30,2,0,17,0,0,0,1,8,8,0,120,97,1,0,17,0,0,0,1,8,0,0,96,19,1,0,0,0,0,0,254,0,2,0,232,75,4,0,17,0,0,0,1,16,16,0,96,135,7,0,17,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,17,0,0,0,1,96,96,0,80,246,3,0,17,0,0,0,1,96,0,0,248,38,7,0,17,0,0,0,1,96,32,0,112,212,3,0,17,0,0,0,1,96,64,0,248,160,5,0,0,0,0,0,254,0,8,0,200,87,7,0,18,0,0,0,1,7,7,0,96,135,3,0,18,0,0,0,1,7,6,0,32,136,7,0,18,0,0,0,1,7,5,0,40,88,7,0,18,0,0,0,1,7,4,0,96,39,7,0,18,0,0,0,1,7,0,0,144,251,6,0,18,0,0,0,1,7,1,0,184,164,6,0,18,0,0,0,1,7,2,0,80,74,6,0,18,0,0,0,1,7,3,0,192,32,6,0,0,0,0,0,254,0,8,0,160,123,6,0,18,0,0,0,1,56,56,0,96,135,3,0,18,0,0,0,1,56,48,0,32,136,7,0,18,0,0,0,1,56,40,0,40,88,7,0,18,0,0,0,1,56,32,0,96,39,7,0,18,0,0,0,1,56,0,0,144,251,6,0,18,0,0,0,1,56,8,0,184,164,6,0,18,0,0,0,1,56,16,0,80,74,6,0,18,0,0,0,1,56,24,0,192,32,6,0,0,0,0,0,254,0,4,0,200,136,5,0,18,0,0,0,1,192,192,0,160,132,5,0,18,0,0,0,1,192,0,0,248,38,7,0,18,0,0,0,1,192,64,0,48,129,5,0,18,0,0,0,1,192,128,0,40,126,5,0,0,0,0,0,100,56,45,100,49,53,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,182,209,33,145,0,0,16,1,100,48,45,100,55,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,42,253,92,169,0,0,16,1,100,48,45,100,55,46,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,47,27,85,216,0,0,32,0,100,56,45,100,49,53,46,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,196,105,178,0,0,32,0,100,49,54,45,100,50,51,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,231,165,78,175,0,0,32,0,100,50,52,45,100,51,49,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,136,53,140,87,0,0,32,0,17,0,0,0,255,255,255,0,0,0,0,0,18,0,0,0,255,255,245,0,0,0,0,0,0,0,0,0,254,0,11,0,200,87,7,0,17,0,0,0,1,15,7,0,32,136,7,0,17,0,0,0,1,15,8,0,40,88,7,0,17,0,0,0,1,15,9,0,96,39,7,0,17,0,0,0,1,15,15,0,144,251,6,0,17,0,0,0,1,15,6,0,120,211,6,0,17,0,0,0,1,15,14,0,184,164,6,0,17,0,0,0,1,15,13,0,80,74,6,0,17,0,0,0,1,15,12,0,192,32,6,0,17,0,0,0,1,15,11,0,192,234,2,0,17,0,0,0,1,15,10,0,32,242,5,0,17,0,0,0,1,15,0,0,8,75,5,0,0,0,0,0,254,0,11,0,160,123,6,0,17,0,0,0,1,240,112,0,32,136,7,0,17,0,0,0,1,240,128,0,40,88,7,0,17,0,0,0,1,240,144,0,96,39,7,0,17,0,0,0,1,240,240,0,144,251,6,0,17,0,0,0,1,240,96,0,120,211,6,0,17,0,0,0,1,240,224,0,184,164,6,0,17,0,0,0,1,240,208,0,80,74,6,0,17,0,0,0,1,240,192,0,192,32,6,0,17,0,0,0,1,240,176,0,192,234,2,0,17,0,0,0,1,240,160,0,32,242,5,0,17,0,0,0,1,240,0,0,144,44,2,0,0,0,0,0,254,0,2,0,232,75,4,0,18,0,0,0,1,1,1,0,96,135,7,0,18,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,18,0,0,0,1,4,0,0,96,135,7,0,18,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,254,0,2,0,8,23,2,0,18,0,0,0,1,8,0,0,80,242,7,0,18,0,0,0,1,8,8,0,96,39,8,0,0,0,0,0,254,0,4,0,72,202,5,0,18,0,0,0,1,192,64,0,80,246,3,0,18,0,0,0,1,192,192,0,248,38,7,0,18,0,0,0,1,192,128,0,112,212,3,0,18,0,0,0,1,192,0,0,248,160,5,0,49,48,110,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,224,103,229,129,0,0,16,1,56,110,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,108,214,18,150,0,0,16,1,49,50,110,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,123,169,166,101,0,0,16,1,103,103,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,111,91,95,97,0,0,16,1,103,103,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,7,207,252,236,0,0,32,0,103,103,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,169,111,213,221,0,0,32,0,103,103,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,157,82,2,115,0,0,32,0,103,103,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,218,91,3,32,0,0,32,0,103,103,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,113,162,43,241,0,0,32,0,103,103,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,125,32,37,229,0,0,32,0,103,103,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,178,233,119,45,0,0,32,0,103,110,103,49,51,46,110,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,220,175,19,70,0,0,32,0,103,103,49,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,202,229,215,6,0,0,32,0,103,103,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,45,224,31,188,0,0,32,0,103,110,103,49,54,46,108,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,213,104,141,96,0,0,32,0,103,103,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,202,63,12,232,0,0,32,0,103,103,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,37,169,128,119,0,0,32,0,116,98,112,50,52,115,49,48,46,49,52,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,88,81,175,14,0,0,32,0,54,51,115,49,52,49,46,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,164,133,18,74,0,0,32,0,109,106,48,52,103,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,211,148,124,117,0,0,16,1,109,106,48,51,103,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,187,67,176,97,0,0,16,1,109,106,48,53,103,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,245,204,253,242,0,0,16,1,103,103,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,111,91,95,97,0,0,16,1,103,103,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,7,207,252,236,0,0,32,0,103,103,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,169,111,213,221,0,0,32,0,103,103,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,157,82,2,115,0,0,32,0,103,103,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,218,91,3,32,0,0,32,0,103,103,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,113,162,43,241,0,0,32,0,103,103,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,125,32,37,229,0,0,32,0,103,103,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,178,233,119,45,0,0,32,0,103,110,103,49,51,46,110,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,220,175,19,70,0,0,32,0,103,103,49,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,202,229,215,6,0,0,32,0,103,103,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,45,224,31,188,0,0,32,0,103,110,103,49,54,46,108,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,213,104,141,96,0,0,32,0,103,103,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,202,63,12,232,0,0,32,0,103,103,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,37,169,128,119,0,0,32,0,116,98,112,50,52,115,49,48,46,49,52,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,88,81,175,14,0,0,32,0,54,51,115,49,52,49,46,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,164,133,18,74,0,0,32,0,109,106,48,52,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,177,237,148,18,0,0,16,1,109,106,48,51,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,45,51,67,211,0,0,16,1,109,106,48,53,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,194,66,83,83,0,0,16,1,103,103,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,111,91,95,97,0,0,16,1,103,103,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,7,207,252,236,0,0,32,0,103,103,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,169,111,213,221,0,0,32,0,103,103,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,157,82,2,115,0,0,32,0,103,103,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,218,91,3,32,0,0,32,0,103,103,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,113,162,43,241,0,0,32,0,103,103,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,125,32,37,229,0,0,32,0,103,103,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,178,233,119,45,0,0,32,0,103,110,103,49,51,46,110,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,220,175,19,70,0,0,32,0,103,103,49,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,202,229,215,6,0,0,32,0,103,103,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,45,224,31,188,0,0,32,0,103,110,103,49,54,46,108,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,213,104,141,96,0,0,32,0,103,103,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,202,63,12,232,0,0,32,0,103,103,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,37,169,128,119,0,0,32,0,116,98,112,50,52,115,49,48,46,49,52,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,88,81,175,14,0,0,32,0,54,51,115,49,52,49,46,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,164,133,18,74,0,0,32,0,34,0,0,0,255,255,159,0,0,0,0,0,35,0,0,0,255,255,253,0,0,0,0,0,36,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,168,107,1,0,34,0,0,0,1,1,0,0,192,255,2,0,34,0,0,0,1,1,1,0,208,75,4,0,0,0,0,0,254,0,2,0,0,83,1,0,34,0,0,0,1,2,0,0,192,255,2,0,34,0,0,0,1,2,2,0,208,75,4,0,0,0,0,0,254,0,2,0,72,202,5,0,34,0,0,0,1,4,4,0,248,38,7,0,34,0,0,0,1,4,0,0,112,212,3,0,0,0,0,0,254,0,2,0,8,55,1,0,34,0,0,0,1,8,8,0,120,97,1,0,34,0,0,0,1,8,0,0,96,19,1,0,0,0,0,0,254,0,2,0,80,30,1,0,34,0,0,0,1,16,16,0,128,183,8,0,34,0,0,0,1,16,0,0,56,13,1,0,0,0,0,0,254,0,2,0,72,8,1,0,34,0,0,0,1,32,32,0,56,111,3,0,34,0,0,0,1,32,0,0,104,134,3,0,0,0,0,0,254,0,2,0,168,234,7,0,34,0,0,0,1,64,64,0,96,135,7,0,34,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,34,0,0,0,1,128,128,0,96,135,7,0,34,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,35,0,0,0,1,1,1,0,96,135,7,0,35,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,200,30,2,0,35,0,0,0,1,2,0,0,120,97,1,0,35,0,0,0,1,2,2,0,96,19,1,0,0,0,0,0,254,0,2,0,88,160,1,0,35,0,0,0,1,4,4,0,136,86,1,0,35,0,0,0,1,4,0,0,184,147,6,0,0,0,0,0,254,0,2,0,96,46,8,0,35,0,0,0,1,8,8,0,192,255,2,0,35,0,0,0,1,8,0,0,208,75,4,0,0,0,0,0,254,0,16,0,32,4,2,0,35,0,0,0,1,240,160,0,144,160,3,0,35,0,0,0,1,240,176,0,96,135,3,0,35,0,0,0,1,240,192,0,32,136,7,0,35,0,0,0,1,240,208,0,40,88,7,0,35,0,0,0,1,240,224,0,96,39,7,0,35,0,0,0,1,240,16,0,32,202,2,0,35,0,0,0,1,240,48,0,120,113,6,0,35,0,0,0,1,240,32,0,232,228,5,0,35,0,0,0,1,240,240,0,144,251,6,0,35,0,0,0,1,240,64,0,120,211,6,0,35,0,0,0,1,240,144,0,184,164,6,0,35,0,0,0,1,240,128,0,80,74,6,0,35,0,0,0,1,240,112,0,192,32,6,0,35,0,0,0,1,240,96,0,192,234,2,0,35,0,0,0,1,240,80,0,32,242,5,0,35,0,0,0,1,240,0,0,16,227,4,0,0,0,0,0,254,0,2,0,152,74,8,0,36,0,0,0,1,1,1,0,96,135,7,0,36,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,4,0,200,69,8,0,36,0,0,0,1,6,6,0,208,66,8,0,36,0,0,0,1,6,4,0,104,63,8,0,36,0,0,0,1,6,2,0,232,56,8,0,36,0,0,0,1,6,0,0,168,50,8,0,0,0,0,0,254,0,2,0,96,43,8,0,36,0,0,0,1,128,128,0,8,36,8,0,36,0,0,0,1,128,0,0,120,30,8,0,0,0,0,0,99,54,52,45,48,55,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,201,213,158,242,2,0,16,1,99,54,52,45,48,56,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,213,51,253,221,2,0,16,1,99,54,52,45,48,54,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,172,113,220,24,2,0,16,1,99,54,52,45,48,53,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,192,102,24,182,2,0,16,1,99,54,52,45,48,57,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,92,246,215,136,9,0,16,1,99,54,52,45,48,49,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,134,244,180,161,15,0,32,0,99,54,52,45,48,50,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,7,185,176,60,24,0,64,0,19,0,0,0,255,255,254,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,19,0,0,0,1,1,0,0,120,97,1,0,19,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,2,2,0,96,135,7,0,19,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,4,4,0,96,135,7,0,19,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,8,0,0,96,135,7,0,19,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,19,0,0,0,1,48,0,0,16,242,7,0,19,0,0,0,1,48,16,0,104,236,7,0,19,0,0,0,1,48,48,0,128,230,7,0,19,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,19,0,0,0,1,192,0,0,16,242,7,0,19,0,0,0,1,192,64,0,104,236,7,0,19,0,0,0,1,192,192,0,128,230,7,0,19,0,0,0,1,192,128,0,184,164,6,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,3,2,0,80,246,3,0,20,0,0,0,1,3,3,0,80,124,6,0,20,0,0,0,1,3,1,0,112,212,3,0,20,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,192,99,6,0,20,0,0,0,1,12,0,0,120,7,5,0,20,0,0,0,1,12,12,0,192,255,2,0,20,0,0,0,1,12,4,0,208,75,4,0,20,0,0,0,1,12,8,0,8,49,4,0,0,0,0,0,254,0,2,0,128,129,4,0,20,0,0,0,1,16,0,0,208,75,4,0,20,0,0,0,1,16,16,0,8,49,4,0,0,0,0,0,254,0,4,0,208,81,6,0,20,0,0,0,1,160,160,0,128,75,6,0,20,0,0,0,1,160,128,0,16,70,6,0,20,0,0,0,1,160,0,0,104,65,6,0,20,0,0,0,1,160,32,0,64,62,6,0,0,0,0,0,254,0,2,0,104,159,3,0,20,0,0,0,1,64,0,0,96,135,7,0,20,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,14,0,0,0,255,255,191,0,0,0,0,0,15,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,8,0,32,4,2,0,14,0,0,0,1,7,2,0,40,88,7,0,14,0,0,0,1,7,4,0,96,39,7,0,14,0,0,0,1,7,1,0,120,113,6,0,14,0,0,0,1,7,7,0,144,251,6,0,14,0,0,0,1,7,3,0,120,211,6,0,14,0,0,0,1,7,6,0,184,164,6,0,14,0,0,0,1,7,5,0,80,74,6,0,14,0,0,0,1,7,0,0,16,227,4,0,0,0,0,0,254,0,4,0,72,202,5,0,14,0,0,0,1,24,16,0,80,246,3,0,14,0,0,0,1,24,24,0,248,38,7,0,14,0,0,0,1,24,8,0,112,212,3,0,14,0,0,0,1,24,0,0,24,99,5,0,0,0,0,0,254,0,0,0,168,234,7,0,14,0,0,0,1,64,64,0,96,135,7,0,14,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,0,0,232,75,4,0,14,0,0,0,1,128,128,0,96,135,7,0,14,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,80,232,8,0,15,0,0,0,1,12,8,0,144,117,8,0,15,0,0,0,1,12,12,0,232,74,4,0,15,0,0,0,1,12,4,0,40,208,8,0,15,0,0,0,1,12,0,0,216,203,8,0,0,0,0,0,254,0,0,0,16,199,8,0,15,0,0,0,1,16,0,0,144,117,8,0,15,0,0,0,1,16,16,0,232,74,4,0,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,21,0,0,0,255,255,127,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,1,1,0,96,135,7,0,19,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,2,0,0,96,135,7,0,19,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,0,0,64,37,5,0,19,0,0,0,1,24,24,0,32,179,5,0,19,0,0,0,1,24,8,0,72,14,5,0,19,0,0,0,1,24,16,0,72,40,2,0,19,0,0,0,1,24,0,0,56,111,3,0,0,0,0,0,254,0,4,0,72,202,5,0,19,0,0,0,1,96,64,0,80,246,3,0,19,0,0,0,1,96,96,0,248,38,7,0,19,0,0,0,1,96,32,0,112,212,3,0,19,0,0,0,1,96,0,0,248,160,5,0,0,0,0,0,254,0,4,0,232,75,4,0,19,0,0,0,1,128,128,0,96,135,7,0,19,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,128,129,4,0,20,0,0,0,1,3,2,0,208,75,4,0,20,0,0,0,1,3,3,0,8,49,4,0,20,0,0,0,1,3,1,0,152,21,4,0,20,0,0,0,1,3,0,0,72,246,3,0,0,0,0,0,254,0,4,0,200,87,7,0,20,0,0,0,1,28,4,0,32,136,7,0,20,0,0,0,1,28,8,0,40,88,7,0,20,0,0,0,1,28,16,0,96,39,7,0,20,0,0,0,1,28,28,0,144,251,6,0,20,0,0,0,1,28,12,0,120,211,6,0,20,0,0,0,1,28,24,0,184,164,6,0,20,0,0,0,1,28,20,0,80,74,6,0,20,0,0,0,1,28,0,0,192,32,6,0,0,0,0,0,254,0,8,0,200,87,7,0,20,0,0,0,1,224,32,0,32,136,7,0,20,0,0,0,1,224,64,0,40,88,7,0,20,0,0,0,1,224,128,0,96,39,7,0,20,0,0,0,1,224,224,0,144,251,6,0,20,0,0,0,1,224,96,0,120,211,6,0,20,0,0,0,1,224,192,0,184,164,6,0,20,0,0,0,1,224,160,0,80,74,6,0,20,0,0,0,1,224,0,0,192,32,6,0,0,0,0,0,254,0,2,0,224,133,4,0,21,0,0,0,1,128,128,0,176,20,3,0,21,0,0,0,1,128,0,0,224,32,1,0,18,0,0,0,255,255,247,0,0,0,0,0,19,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,232,75,4,0,18,0,0,0,1,1,1,0,96,135,7,0,18,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,18,0,0,0,1,2,0,0,96,135,7,0,18,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,2,0,128,112,3,0,18,0,0,0,1,8,0,0,168,22,4,0,18,0,0,0,1,8,8,0,224,247,3,0,0,0,0,0,254,0,4,0,72,202,5,0,18,0,0,0,1,48,16,0,80,246,3,0,18,0,0,0,1,48,48,0,248,38,7,0,18,0,0,0,1,48,32,0,112,212,3,0,18,0,0,0,1,48,0,0,248,160,5,0,0,0,0,0,254,0,16,0,160,123,6,0,19,0,0,0,1,15,4,0,32,136,7,0,19,0,0,0,1,15,10,0,40,88,7,0,19,0,0,0,1,15,1,0,96,39,7,0,19,0,0,0,1,15,0,0,192,24,7,0,19,0,0,0,1,15,2,0,120,113,6,0,19,0,0,0,1,15,8,0,232,228,5,0,19,0,0,0,1,15,15,0,144,251,6,0,19,0,0,0,1,15,12,0,56,141,7,0,19,0,0,0,1,15,14,0,120,211,6,0,19,0,0,0,1,15,7,0,184,164,6,0,19,0,0,0,1,15,6,0,24,1,7,0,19,0,0,0,1,15,11,0,80,74,6,0,19,0,0,0,1,15,3,0,192,32,6,0,19,0,0,0,1,15,13,0,192,234,2,0,19,0,0,0,1,15,5,0,32,242,5,0,19,0,0,0,1,15,9,0,176,192,2,0,0,0,0,0,254,0,16,0,200,87,7,0,19,0,0,0,1,240,64,0,32,136,7,0,19,0,0,0,1,240,160,0,40,88,7,0,19,0,0,0,1,240,16,0,96,39,7,0,19,0,0,0,1,240,32,0,120,113,6,0,19,0,0,0,1,240,128,0,232,228,5,0,19,0,0,0,1,240,240,0,144,251,6,0,19,0,0,0,1,240,192,0,56,141,7,0,19,0,0,0,1,240,224,0,120,211,6,0,19,0,0,0,1,240,112,0,184,164,6,0,19,0,0,0,1,240,96,0,24,1,7,0,19,0,0,0,1,240,176,0,80,74,6,0,19,0,0,0,1,240,48,0,192,32,6,0,19,0,0,0,1,240,208,0,192,234,2,0,19,0,0,0,1,240,80,0,32,242,5,0,19,0,0,0,1,240,144,0,176,192,2,0,19,0,0,0,1,240,0,0,16,227,4,0,108,116,112,114,111,103,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,185,137,195,89,1,0,16,1,108,116,112,114,111,103,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,177,147,56,172,1,0,16,1,108,116,99,104,97,114,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,220,59,215,140,4,0,32,0,108,116,99,104,97,114,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,70,153,186,181,4,0,32,0,55,52,115,50,56,56,46,99,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,196,43,101,36,7,0,32,0,7,0,0,0,255,255,0,0,0,0,0,0,8,0,0,0,255,255,0,0,0,0,0,0,9,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,49,57,57,57,46,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,159,192,207,227,0,0,16,1,49,57,57,57,46,52,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,225,198,88,253,0,0,16,1,55,46,106,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,233,168,87,0,0,16,1,49,46,102,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,33,198,133,196,0,0,16,1,50,46,104,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,134,168,198,179,0,0,16,1,51,46,106,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,76,49,126,25,0,0,16,1,114,101,112,117,108,115,101,46,98,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0])
.concat([243,103,178,134,0,0,16,1,49,57,57,57,45,49,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,114,80,153,180,0,0,32,0,49,53,46,57,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,105,52,33,201,0,0,32,0,49,54,46,49,48,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,158,211,229,125,0,0,32,0,49,55,46,49,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,44,247,165,11,0,0,32,0,56,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,126,117,159,14,0,0,32,0,57,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,80,230,210,247,0,0,32,0,49,48,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,244,186,23,231,0,0,32,0,49,49,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,11,37,178,4,0,0,32,0,49,50,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,64,225,16,209,0,0,32,0,49,51,46,49,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,60,113,220,143,0,0,32,0,98,46,49,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,49,84,163,62,0,0,32,0,103,46,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,158,166,215,172,0,0,32,0,114,46,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,65,139,244,183,0,0,32,0,109,49,46,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,1,146,163,131,0,0,32,0,49,57,57,57,45,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,159,68,12,12,0,0,32,0,52,102,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,141,144,226,239,0,0,16,1,52,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,66,195,121,91,0,0,16,1,52,106,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,27,44,166,210,0,0,16,1,50,102,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,145,130,157,203,0,0,16,1,50,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,195,221,219,36,0,0,16,1,50,106,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,76,156,135,22,0,0,16,1,114,101,112,117,108,115,101,46,98,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,243,103,178,134,0,0,16,1,49,57,57,57,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,62,56,162,73,0,0,32,0,57,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,39,60,153,89,0,0,32,0,49,48,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,128,2,191,223,0,0,32,0,49,49,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,192,159,242,228,0,0,32,0,54,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,16,68,212,152,0,0,32,0,55,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,129,210,84,76,0,0,32,0,56,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,1,129,1,129,0,0,32,0,57,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,253,145,123,52,0,0,32,0,49,48,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,250,228,125,240,0,0,32,0,49,49,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,72,79,160,52,0,0,32,0,98,46,49,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,49,84,163,62,0,0,32,0,103,46,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,158,166,215,172,0,0,32,0,114,46,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,65,139,244,183,0,0,32,0,109,49,46,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,1,146,163,131,0,0,32,0,49,57,57,57,46,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,159,192,207,227,0,0,16,1,49,57,57,57,46,52,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,225,198,88,253,0,0,16,1,55,46,106,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,233,168,87,0,0,16,1,49,46,102,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,33,198,133,196,0,0,16,1,50,46,104,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,134,168,198,179,0,0,16,1,51,46,106,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,76,49,126,25,0,0,16,1,114,101,112,117,108,115,101,46,98,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,243,103,178,134,0,0,16,1,49,57,57,57,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,62,56,162,73,0,0,32,0,49,53,46,57,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,105,52,33,201,0,0,32,0,49,54,46,49,48,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,158,211,229,125,0,0,32,0,49,55,46,49,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,44,247,165,11,0,0,32,0,56,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,126,117,159,14,0,0,32,0,57,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,80,230,210,247,0,0,32,0,49,48,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,244,186,23,231,0,0,32,0,49,49,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,11,37,178,4,0,0,32,0,49,50,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,64,225,16,209,0,0,32,0,49,51,46,49,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,60,113,220,143,0,0,32,0,98,46,49,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,49,84,163,62,0,0,32,0,103,46,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,158,166,215,172,0,0,32,0,114,46,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,65,139,244,183,0,0,32,0,109,49,46,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,1,146,163,131,0,0,32,0,15,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,15,0,200,87,7,0,15,0,0,0,1,15,12,0,80,252,6,0,15,0,0,0,1,15,8,0,16,242,7,0,15,0,0,0,1,15,13,0,144,44,1,0,15,0,0,0,1,15,4,0,104,236,7,0,15,0,0,0,1,15,9,0,104,11,2,0,15,0,0,0,1,15,14,0,88,26,1,0,15,0,0,0,1,15,15,0,168,16,1,0,15,0,0,0,1,15,10,0,24,12,1,0,15,0,0,0,1,15,5,0,240,5,1,0,15,0,0,0,1,15,0,0,208,238,1,0,15,0,0,0,1,15,11,0,176,253,8,0,15,0,0,0,1,15,6,0,192,4,2,0,15,0,0,0,1,15,7,0,192,240,8,0,15,0,0,0,1,15,1,0,96,233,8,0,15,0,0,0,1,15,2,0,192,225,8,0,15,0,0,0,1,15,3,0,168,217,8,0,0,0,0,0,254,0,2,0,200,73,5,0,15,0,0,0,1,32,0,0,88,204,8,0,15,0,0,0,1,32,32,0,168,199,8,0,0,0,0,0,254,0,2,0,128,129,4,0,15,0,0,0,1,64,0,0,8,49,4,0,15,0,0,0,1,64,64,0,72,246,3,0,0,0,0,0,254,0,2,0,200,30,2,0,15,0,0,0,1,128,128,0,120,97,1,0,15,0,0,0,1,128,0,0,96,19,1,0,0,0,0,0,108,119,95,49,49,99,46,49,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,70,37,228,103,1,0,16,1,108,119,95,49,53,99,46,49,52,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,70,42,46,64,1,0,16,1,108,119,95,49,48,99,46,49,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,215,121,100,196,1,0,16,1,108,119,95,49,52,99,46,49,51,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,74,15,103,151,1,0,16,1,108,119,45,48,55,46,49,51,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,38,42,37,253,2,0,16,1,108,119,45,48,49,46,57,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,152,242,24,3,4,0,32,0,108,119,45,48,56,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,60,228,168,37,4,0,32,0,108,119,45,48,53,46,57,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,215,47,85,228,4,0,32,0,108,119,45,49,50,46,57,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,43,131,106,142,4,0,32,0,108,119,45,48,50,46,49,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,200,197,230,67,4,0,32,0,108,119,45,48,57,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,173,180,156,137,4,0,32,0,108,119,45,48,54,46,49,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,252,223,158,91,4,0,32,0,108,119,45,49,51,46,49,50,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,245,142,5,142,4,0,32,0,108,119,95,48,48,98,46,49,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,99,42,223,89,3,0,16,0,108,119,45,48,51,46,49,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,231,89,33,206,5,0,64,0,108,119,45,48,52,46,49,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,54,85,48,57,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,108,119,99,104,114,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,57,76,237,84,0,0,0,8,108,119,105,111,46,49,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,12,185,82,173,0,0,0,8,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,44,109,23,214,1,0,16,1,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,74,95,245,165,1,0,16,1,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,60,250,105,1,1,0,16,1,50,104,45,101,97,115,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,182,129,68,5,1,0,16,1,50,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,64,224,158,36,1,0,16,1,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,8,230,210,199,1,0,16,1,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,177,197,75,188,1,0,16,1,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,42,190,153,184,2,0,16,1,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,49,175,7,105,2,0,16,1,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,231,55,241,97,4,0,32,0,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,95,222,129,85,4,0,32,0,108,116,112,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,22,184,8,17,7,0,32,0,14,0,0,0,255,255,0,0,0,0,0,0,15,0,0,0,255,255,2,0,0,0,0,0,16,0,0,0,255,255,4,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,15,0,0,0,1,3,2,0,8,49,4,0,15,0,0,0,1,3,1,0,72,246,3,0,15,0,0,0,1,3,0,0,16,227,4,0,15,0,0,0,1,3,3,0,144,246,3,0,0,0,0,0,254,0,4,0,32,4,2,0,16,0,0,0,1,6,4,0,128,103,7,0,16,0,0,0,1,6,6,0,56,52,2,0,16,0,0,0,1,6,2,0,224,44,2,0,16,0,0,0,1,6,0,0,224,43,2,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,8,0,32,4,2,0,20,0,0,0,1,7,2,0,88,154,8,0,20,0,0,0,1,7,1,0,200,92,8,0,20,0,0,0,1,7,4,0,152,141,7,0,20,0,0,0,1,7,7,0,104,172,6,0,20,0,0,0,1,7,6,0,24,46,7,0,20,0,0,0,1,7,3,0,216,129,6,0,20,0,0,0,1,7,5,0,184,81,6,0,20,0,0,0,1,7,0,0,16,227,4,0,0,0,0,0,254,0,4,0,80,184,7,0,20,0,0,0,1,24,8,0,248,81,6,0,20,0,0,0,1,24,24,0,248,38,7,0,20,0,0,0,1,24,16,0,176,64,8,0,20,0,0,0,1,24,0,0,128,65,6,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,96,32,0,80,246,3,0,20,0,0,0,1,96,96,0,248,38,7,0,20,0,0,0,1,96,64,0,112,212,3,0,20,0,0,0,1,96,0,0,248,160,5,0,0,0,0,0,254,0,2,0,168,234,7,0,20,0,0,0,1,128,0,0,96,135,7,0,20,0,0,0,1,128,128,0,152,182,7,0,0,0,0,0,101,112,114,45,49,50,56,52,55,97,46,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,237,180,14,197,1,0,16,1,101,112,114,45,49,50,56,52,56,97,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,64,134,255,248,1,0,16,1,101,112,114,45,49,50,56,48,52,46,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,14,72,83,184,9,0,16,1,101,112,114,45,49,50,56,48,53,46,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,195,0,114,74,9,0,16,1,101,112,114,45,49,50,56,48,50,46,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,57,187,70,215,9,0,16,1,101,112,114,45,49,50,56,48,51,46,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,81,231,217,193,9,0,16,1,111,112,114,45,49,50,55,57,49,46,49,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,186,105,250,172,2,0,32,0,111,112,114,45,49,50,55,57,50,46,49,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,60,114,6,229,2,0,32,0,111,112,114,45,49,50,55,57,51,46,49,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,227,204,232,12,2,0,32,0,101,112,114,45,49,50,55,56,55,46,57,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,166,163,49,100,3,0,32,0,101,112,114,45,49,50,55,56,56,46,57,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,206,160,130,25,3,0,32,0,101,112,114,45,49,50,55,56,57,46,57,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,116,50,208,151,3,0,32,0,101,112,114,45,49,50,55,57,48,46,49,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,230,118,110,129,3,0,32,0,101,112,114,45,49,50,55,56,51,46,57,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,169,238,63,193,3,0,32,0,101,112,114,45,49,50,55,56,52,46,57,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,101,76,185,57,3,0,32,0,101,112,114,45,49,50,55,56,53,46,57,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,89,0,237,5,3,0,32,0,101,112,114,45,49,50,55,56,54,46,49,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,101,49,18,164,3,0,32,0,101,112,114,45,49,50,55,55,57,46,57,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,124,175,88,174,3,0,32,0,101,112,114,45,49,50,55,56,48,46,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,30,12,103,238,3,0,32,0,101,112,114,45,49,50,55,56,49,46,49,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,197,107,143,83,3,0,32,0,101,112,114,45,49,50,55,56,50,46,49,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,247,52,204,90,3,0,32,0,101,112,114,45,49,50,55,55,53,46,57,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,236,86,48,105,3,0,32,0,101,112,114,45,49,50,55,55,54,46,57,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,253,189,239,97,3,0,32,0,101,112,114,45,49,50,55,55,55,46,49,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,83,185,213,41,3,0,32,0,101,112,114,45,49,50,55,55,56,46,49,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,7,142,182,47,3,0,32,0,101,112,114,45,49,50,55,57,56,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,141,115,135,5,4,0,16,1,101,112,114,45,49,50,55,57,57,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,28,24,96,188,11,0,64,0,101,112,114,45,49,50,56,48,48,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,163,193,88,17,11,0,64,0,101,112,114,45,49,50,56,48,49,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,196,103,101,45,11,0,64,0,51,49,55,45,48,49,51,53,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,25,208,58,197,5,0,16,1,101,112,114,45,49,50,55,57,52,46,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,146,137,88,30,1,0,16,1,101,112,114,45,49,50,55,57,53,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,39,116,61,212,1,0,16,1,101,112,114,45,49,50,56,48,52,46,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,14,72,83,184,9,0,16,1,101,112,114,45,49,50,56,48,53,46,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,195,0,114,74,9,0,16,1,101,112,114,45,49,50,56,48,50,46,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,57,187,70,215,9,0,16,1,101,112,114,45,49,50,56,48,51,46,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,81,231,217,193,9,0,16,1,111,112,114,45,49,50,55,57,49,46,49,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,186,105,250,172,2,0,32,0,111,112,114,45,49,50,55,57,50,46,49,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,60,114,6,229,2,0,32,0,111,112,114,45,49,50,55,57,51,46,49,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,227,204,232,12,2,0,32,0,101,112,114,45,49,50,55,56,55,46,57,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,166,163,49,100,3,0,32,0,101,112,114,45,49,50,55,56,56,46,57,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,206,160,130,25,3,0,32,0,101,112,114,45,49,50,55,56,57,46,57,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,116,50,208,151,3,0,32,0,101,112,114,45,49,50,55,57,48,46,49,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,230,118,110,129,3,0,32,0,101,112,114,45,49,50,55,56,51,46,57,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,169,238,63,193,3,0,32,0,101,112,114,45,49,50,55,56,52,46,57,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,101,76,185,57,3,0,32,0,101,112,114,45,49,50,55,56,53,46,57,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,89,0,237,5,3,0,32,0,101,112,114,45,49,50,55,56,54,46,49,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,101,49,18,164,3,0,32,0,101,112,114,45,49,50,55,55,57,46,57,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,124,175,88,174,3,0,32,0,101,112,114,45,49,50,55,56,48,46,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,30,12,103,238,3,0,32,0,101,112,114,45,49,50,55,56,49,46,49,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,197,107,143,83,3,0,32,0,101,112,114,45,49,50,55,56,50,46,49,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,247,52,204,90,3,0,32,0,101,112,114,45,49,50,55,55,53,46,57,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,236,86,48,105,3,0,32,0,101,112,114,45,49,50,55,55,54,46,57,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,253,189,239,97,3,0,32,0,101,112,114,45,49,50,55,55,55,46,49,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,83,185,213,41,3,0,32,0,101,112,114,45,49,50,55,55,56,46,49,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,7,142,182,47,3,0,32,0,101,112,114,45,49,50,55,57,56,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,141,115,135,5,4,0,16,1,101,112,114,45,49,50,55,57,57,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,28,24,96,188,11,0,64,0,101,112,114,45,49,50,56,48,48,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,163,193,88,17,11,0,64,0,101,112,114,45,49,50,56,48,49,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,196,103,101,45,11,0,64,0,51,49,55,45,48,49,51,52,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,212,38,38,115,5,0,16,1,39,0,0,0,255,255,96,0,0,0,0,0,40,0,0,0,255,255,1,0,0,0,0,0,0,0,0,0,254,0,2,0,232,75,4,0,39,0,0,0,1,32,32,0,96,135,7,0,39,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,192,3,0,39,0,0,0,1,64,64,0,96,135,7,0,39,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,48,45,3,0,40,0,0,0,1,3,0,0,240,79,1,0,40,0,0,0,1,3,1,0,168,72,1,0,0,0,0,0,17,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,72,4,1,0,17,0,0,0,1,128,128,0,96,135,7,0,17,0,0,0,1,128,0,0,152,182,7,0,99,52,57,45,48,57,46,105,99,52,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,185,158,224,106,2,0,16,1,99,52,57,45,49,49,46,105,99,52,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,110,190,210,66,2,0,16,1,99,52,57,45,49,48,46,105,99,52,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,224,242,190,80,2,0,16,1,99,52,57,45,49,52,46,105,99,52,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,67,138,17,188,2,0,16,1,99,52,57,45,48,56,46,105,99,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,12,49,60,65,9,0,16,1,99,52,57,45,48,51,46,105,99,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,155,79,54,195,11,0,32,0,99,52,57,45,48,49,46,105,99,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,99,49,204,103,15,0,32,0,99,52,57,45,48,50,46,105,99,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,16,7,64,210,15,0,32,0,99,52,57,45,48,52,46,105,99,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,164,69,77,71,24,0,64,0,19,0,0,0,255,255,254,0,0,0,0,0,20,0,0,0,255,255,127,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,19,0,0,0,1,1,0,0,120,97,1,0,19,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,2,2,0,96,135,7,0,19,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,4,4,0,96,135,7,0,19,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,8,0,0,96,135,7,0,19,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,32,4,2,0,19,0,0,0,1,48,0,0,80,252,6,0,19,0,0,0,1,48,16,0,16,242,7,0,19,0,0,0,1,48,32,0,104,236,7,0,19,0,0,0,1,48,48,0,128,230,7,0,0,0,0,0,254,0,4,0,168,248,6,0,19,0,0,0,1,192,0,0,16,242,7,0,19,0,0,0,1,192,64,0,104,236,7,0,19,0,0,0,1,192,128,0,80,245,6,0,19,0,0,0,1,192,192,0,240,240,6,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,3,2,0,80,246,3,0,20,0,0,0,1,3,3,0,80,124,6,0,20,0,0,0,1,3,1,0,112,212,3,0,20,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,64,37,5,0,20,0,0,0,1,12,12,0,56,207,4,0,20,0,0,0,1,12,8,0,16,202,4,0,20,0,0,0,1,12,4,0,216,196,4,0,20,0,0,0,1,12,0,0,144,192,4,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,48,32,0,208,75,4,0,20,0,0,0,1,48,48,0,8,49,4,0,20,0,0,0,1,48,0,0,152,21,4,0,20,0,0,0,1,48,16,0,72,246,3,0,0,0,0,0,254,0,2,0,104,159,3,0,20,0,0,0,1,64,0,0,96,135,7,0,20,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,6,0,20,0,0,0,1,128,128,0,8,208,6,0,20,0,0,0,1,128,0,0,88,204,6,0,0,0,0,0,20,0,0,0,255,255,94,0,0,0,0,0,21,0,0,0,255,255,255,0,0,0,0,0,22,0,0,0,255,255,253,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,3,3,0,208,75,4,0,20,0,0,0,1,3,2,0,8,49,4,0,20,0,0,0,1,3,1,0,72,246,3,0,20,0,0,0,1,3,0,0,64,47,7,0,0,0,0,0,254,0,4,0,64,37,5,0,20,0,0,0,1,24,24,0,72,10,6,0,20,0,0,0,1,24,16,0,136,3,6,0,20,0,0,0,1,24,8,0,240,159,4,0,20,0,0,0,1,24,0,0,120,7,5,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,96,96,0,80,246,3,0,20,0,0,0,1,96,64,0,80,124,6,0,20,0,0,0,1,96,32,0,112,212,3,0,20,0,0,0,1,96,0,0,248,160,5,0,0,0,0,0,254,0,2,0,168,234,7,0,20,0,0,0,1,128,128,0,96,135,7,0,20,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,16,0,200,87,7,0,21,0,0,0,1,15,2,0,80,252,6,0,21,0,0,0,1,15,5,0,16,242,7,0,21,0,0,0,1,15,8,0,104,236,7,0,21,0,0,0,1,15,4,0,120,113,6,0,21,0,0,0,1,15,1,0,232,228,5,0,21,0,0,0,1,15,15,0,128,230,7,0,21,0,0,0,1,15,3,0,56,141,7,0,21,0,0,0,1,15,7,0,120,211,6,0,21,0,0,0,1,15,14,0,184,164,6,0,21,0,0,0,1,15,6,0,24,1,7,0,21,0,0,0,1,15,13,0,80,74,6,0,21,0,0,0,1,15,12,0,192,32,6,0,21,0,0,0,1,15,11,0,192,234,2,0,21,0,0,0,1,15,10,0,32,242,5,0,21,0,0,0,1,15,9,0,176,192,2,0,21,0,0,0,1,15,0,0,16,227,4,0,0,0,0,0,254,0,16,0,160,123,6,0,21,0,0,0,1,240,32,0,80,252,6,0,21,0,0,0,1,240,80,0,16,242,7,0,21,0,0,0,1,240,128,0,104,236,7,0,21,0,0,0,1,240,64,0,120,113,6,0,21,0,0,0,1,240,16,0,232,228,5,0,21,0,0,0,1,240,240,0,128,230,7,0,21,0,0,0,1,240,48,0,56,141,7,0,21,0,0,0,1,240,112,0,120,211,6,0,21,0,0,0,1,240,224,0,184,164,6,0,21,0,0,0,1,240,96,0,24,1,7,0,21,0,0,0,1,240,208,0,80,74,6,0,21,0,0,0,1,240,192,0,192,32,6,0,21,0,0,0,1,240,176,0,192,234,2,0,21,0,0,0,1,240,160,0,32,242,5,0,21,0,0,0,1,240,144,0,176,192,2,0,21,0,0,0,1,240,0,0,136,143,5,0,0,0,0,0,254,0,2,0,144,212,8,0,22,0,0,0,1,1,1,0,96,135,7,0,22,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,160,94,8,0,22,0,0,0,1,2,2,0,96,39,8,0,22,0,0,0,1,2,0,0,80,242,7,0,0,0,0,0,254,0,2,0,232,75,4,0,22,0,0,0,1,4,4,0,96,135,7,0,22,0,0,0,1,4,0,0,152,182,7,0,184,40,2,0,1,0,0,0,208,155,215,0,248,191,2,0,184,164,8,0,1,0,0,0,209,155,215,0,64,246,1,0,104,28,8,0,1,0,0,0,215,155,215,0,232,209,1,0,192,76,7,0,4,0,0,0,112,156,215,0,152,210,1,0,176,68,7,0,4,0,0,0,104,156,215,0,208,189,1,0,48,123,2,0,1,0,0,0,200,155,215,0,248,174,1,0,96,69,2,0,1,0,0,0,201,155,215,0,104,160,1,0,224,47,7,0,4,0,0,0,96,156,215,0,136,7,4,0,192,36,7,0,4,0,0,0,88,156,215,0,136,113,1,0,248,187,8,0,1,0,0,0,202,155,215,0,56,126,1,0,184,179,8,0,1,0,0,0,203,155,215,0,32,101,1,0])
.concat([24,30,7,0,4,0,0,0,80,156,215,0,56,27,7,0,176,24,7,0,4,0,0,0,72,156,215,0,176,19,7,0,240,45,8,0,1,0,0,0,207,155,215,0,32,92,1,0,40,38,8,0,1,0,0,0,206,155,215,0,64,77,1,0,16,17,8,0,1,0,0,0,212,155,215,0,224,12,8,0,0,105,5,0,1,0,0,0,213,155,215,0,128,176,7,0,152,120,4,0,1,0,0,0,214,155,215,0,248,114,7,0,32,77,1,0,1,0,0,0,210,155,215,0,216,70,1,0,88,212,3,0,1,0,0,0,200,154,215,0,40,185,3,0,248,5,8,0,9,0,0,0,0,156,215,0,32,58,1,0,144,250,7,0,9,0,0,0,1,156,215,0,32,58,1,0,184,40,2,0,1,0,0,0,40,39,216,0,248,191,2,0,56,250,6,0,1,0,0,0,32,39,216,0,184,160,2,0,184,164,8,0,1,0,0,0,37,39,216,0,64,246,1,0,88,149,7,0,1,0,0,0,33,39,216,0,136,224,1,0,56,210,6,0,1,0,0,0,47,39,216,0,192,135,2,0,24,163,6,0,1,0,0,0,46,39,216,0,240,108,2,0,152,122,6,0,1,0,0,0,42,39,216,0,96,82,2,0,192,72,6,0,1,0,0,0,43,39,216,0,32,56,2,0,176,223,1,0,1,0,0,0,41,39,216,0,72,198,1,0,192,209,1,0,1,0,0,0,39,39,216,0,24,182,1,0,24,198,1,0,1,0,0,0,34,39,216,0,40,167,1,0,120,189,1,0,1,0,0,0,35,39,216,0,200,149,1,0,88,212,3,0,1,0,0,0,48,38,216,0,40,185,3,0,248,5,8,0,9,0,0,0,112,39,216,0,32,58,1,0,144,250,7,0,9,0,0,0,113,39,216,0,32,58,1,0,248,241,7,0,9,0,0,0,114,39,216,0,32,58,1,0,18,0,0,0,255,255,191,0,0,0,0,0,19,0,0,0,255,255,253,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,18,0,0,0,1,3,2,0,208,75,4,0,18,0,0,0,1,3,3,0,8,49,4,0,18,0,0,0,1,3,1,0,152,21,4,0,18,0,0,0,1,3,0,0,72,246,3,0,0,0,0,0,254,0,4,0,72,202,5,0,18,0,0,0,1,12,0,0,160,203,8,0,18,0,0,0,1,12,8,0,80,246,3,0,18,0,0,0,1,12,12,0,248,38,7,0,18,0,0,0,1,12,4,0,112,212,3,0,0,0,0,0,254,0,2,0,240,158,6,0,18,0,0,0,1,16,0,0,96,135,7,0,18,0,0,0,1,16,16,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,18,0,0,0,1,32,0,0,56,111,3,0,18,0,0,0,1,32,32,0,104,134,3,0,0,0,0,0,254,0,2,0,168,234,7,0,18,0,0,0,1,64,64,0,96,135,7,0,18,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,18,0,0,0,1,128,128,0,96,135,7,0,18,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,1,1,0,96,135,7,0,19,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,88,160,1,0,19,0,0,0,1,4,4,0,136,86,1,0,19,0,0,0,1,4,0,0,184,147,6,0,0,0,0,0,254,0,2,0,96,46,8,0,19,0,0,0,1,8,8,0,192,255,2,0,19,0,0,0,1,8,0,0,208,75,4,0,0,0,0,0,254,0,16,0,32,4,2,0,19,0,0,0,1,240,160,0,144,160,3,0,19,0,0,0,1,240,176,0,96,135,3,0,19,0,0,0,1,240,192,0,32,136,7,0,19,0,0,0,1,240,208,0,40,88,7,0,19,0,0,0,1,240,224,0,96,39,7,0,19,0,0,0,1,240,16,0,32,202,2,0,19,0,0,0,1,240,48,0,120,113,6,0,19,0,0,0,1,240,32,0,232,228,5,0,19,0,0,0,1,240,240,0,144,251,6,0,19,0,0,0,1,240,64,0,120,211,6,0,19,0,0,0,1,240,144,0,184,164,6,0,19,0,0,0,1,240,128,0,80,74,6,0,19,0,0,0,1,240,112,0,192,32,6,0,19,0,0,0,1,240,96,0,192,234,2,0,19,0,0,0,1,240,80,0,32,242,5,0,19,0,0,0,1,240,0,0,16,227,4,0,0,0,0,0,254,0,4,0,64,37,5,0,20,0,0,0,1,3,2,0,112,149,6,0,20,0,0,0,1,3,3,0,208,145,6,0,20,0,0,0,1,3,0,0,184,141,6,0,20,0,0,0,1,3,1,0,112,137,6,0,17,0,0,0,255,255,4,0,0,0,0,0,18,0,0,0,255,255,255,0,0,0,0,0,19,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,232,75,4,0,17,0,0,0,1,4,4,0,96,135,7,0,17,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,4,0,96,140,8,0,18,0,0,0,1,3,3,0,192,255,2,0,18,0,0,0,1,3,2,0,208,75,4,0,18,0,0,0,1,3,1,0,8,49,4,0,18,0,0,0,1,3,0,0,152,21,4,0,0,0,0,0,254,0,4,0,16,130,7,0,18,0,0,0,1,12,12,0,192,255,2,0,18,0,0,0,1,12,8,0,208,75,4,0,18,0,0,0,1,12,4,0,8,49,4,0,18,0,0,0,1,12,0,0,152,21,4,0,0,0,0,0,254,0,4,0,48,80,7,0,18,0,0,0,1,48,48,0,192,255,2,0,18,0,0,0,1,48,32,0,208,75,4,0,18,0,0,0,1,48,16,0,8,49,4,0,18,0,0,0,1,48,0,0,152,21,4,0,0,0,0,0,254,0,2,0,16,227,4,0,18,0,0,0,1,128,128,0,96,135,7,0,18,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,8,0,200,87,7,0,19,0,0,0,1,7,7,0,144,251,6,0,19,0,0,0,1,7,6,0,184,164,6,0,19,0,0,0,1,7,5,0,80,74,6,0,19,0,0,0,1,7,4,0,192,32,6,0,19,0,0,0,1,7,3,0,192,234,2,0,19,0,0,0,1,7,2,0,32,242,5,0,19,0,0,0,1,7,1,0,176,192,2,0,19,0,0,0,1,7,0,0,248,175,2,0,0,0,0,0,254,0,8,0,160,123,6,0,19,0,0,0,1,56,56,0,144,251,6,0,19,0,0,0,1,56,48,0,184,164,6,0,19,0,0,0,1,56,40,0,80,74,6,0,19,0,0,0,1,56,32,0,192,32,6,0,19,0,0,0,1,56,24,0,192,234,2,0,19,0,0,0,1,56,16,0,32,242,5,0,19,0,0,0,1,56,8,0,176,192,2,0,19,0,0,0,1,56,0,0,248,175,2,0,108,115,117,45,48,52,46,56,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,121,240,162,86,0,0,16,1,108,115,117,45,48,51,46,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,192,8,100,155,0,0,16,1,108,115,45,48,50,46,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,94,40,192,5,0,0,16,1,108,115,45,48,49,46,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,221,52,249,139,0,0,16,1,108,115,45,48,55,46,49,52,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,56,120,175,152,0,0,16,1,108,115,45,48,56,46,49,48,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,73,207,3,136,0,0,32,0,108,115,45,49,50,46,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,108,44,27,108,0,0,32,0,108,115,45,49,49,46,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,100,28,248,107,0,0,32,0,108,115,45,48,57,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,29,94,135,128,0,0,32,0,108,115,45,49,48,46,49,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,147,63,153,197,0,0,32,0,108,115,45,48,54,46,49,48,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,91,154,211,136,0,0,64,0,108,115,45,48,53,46,49,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,181,3,110,176,0,0,64,0,50,57,46,49,52,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,30,46,134,127,0,0,32,0,101,112,114,45,49,50,48,52,54,46,105,99,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,26,58,79,249,1,0,16,1,101,112,114,45,49,50,48,52,55,46,105,99,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,22,193,69,27,1,0,16,1,101,112,114,45,49,50,48,52,56,46,105,99,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,202,56,142,100,1,0,16,1,101,112,114,45,49,50,48,52,57,46,105,99,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,83,71,92,108,1,0,16,1,101,112,114,45,49,50,48,53,48,46,105,99,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,54,15,90,152,9,0,16,1,101,112,114,45,49,50,48,53,49,46,105,99,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,168,213,103,249,9,0,16,1,101,112,114,45,49,50,48,53,50,46,105,99,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,77,66,122,159,9,0,16,1,101,112,114,45,49,50,48,53,51,46,105,99,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,246,48,207,239,9,0,16,1,101,112,114,45,49,50,48,53,53,46,105,99,49,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,164,20,0,21,2,0,32,0,101,112,114,45,49,50,48,53,54,46,105,99,49,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,6,195,212,60,2,0,32,0,101,112,114,45,49,50,48,53,55,46,105,99,49,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,112,23,233,55,2,0,32,0,109,112,114,45,49,50,48,54,52,46,105,99,57,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,105,42,86,132,3,0,32,0,109,112,114,45,49,50,48,54,51,46,105,99,57,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,124,114,99,209,3,0,32,0,109,112,114,45,49,50,48,54,50,46,105,99,57,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,59,131,87,107,3,0,32,0,109,112,114,45,49,50,48,54,49,46,105,99,49,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,186,213,7,137,3,0,32,0,101,112,114,45,49,50,48,54,56,46,105,99,57,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,66,211,18,139,3,0,32,0,101,112,114,45,49,50,48,54,55,46,105,99,57,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,137,221,28,26,3,0,32,0,101,112,114,45,49,50,48,54,54,46,105,99,57,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,181,22,29,169,3,0,32,0,101,112,114,45,49,50,48,54,53,46,105,99,49,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,198,20,206,244,3,0,32,0,101,112,114,45,49,50,48,55,50,46,105,99,57,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,200,100,32,34,3,0,32,0,101,112,114,45,49,50,48,55,49,46,105,99,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,140,183,41,163,3,0,32,0,101,112,114,45,49,50,48,55,48,46,105,99,49,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,6,103,204,151,3,0,32,0,101,112,114,45,49,50,48,54,57,46,105,99,49,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,110,166,59,44,3,0,32,0,101,112,114,45,49,50,48,55,54,46,105,99,57,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,225,40,246,36,3,0,32,0,101,112,114,45,49,50,48,55,53,46,105,99,57,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,127,80,179,105,3,0,32,0,101,112,114,45,49,50,48,55,52,46,105,99,49,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,115,187,108,238,3,0,32,0,101,112,114,45,49,50,48,55,51,46,105,99,49,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,66,99,126,22,3,0,32,0,101,112,114,45,49,50,48,53,52,46,105,99,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,22,146,179,233,4,0,16,1,101,112,114,45,49,50,48,53,56,46,105,99,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,70,203,113,70,11,0,64,0,101,112,114,45,49,50,48,53,57,46,105,99,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,244,175,153,140,11,0,64,0,101,112,114,45,49,50,48,54,48,46,105,99,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,179,130,211,126,11,0,64,0,51,49,55,45,48,48,56,51,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,204,185,160,220,5,0,16,1,20,0,0,0,255,255,255,0,0,0,0,0,21,0,0,0,255,255,191,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,20,0,0,0,1,15,7,0,80,252,6,0,20,0,0,0,1,15,8,0,16,242,7,0,20,0,0,0,1,15,9,0,104,236,7,0,20,0,0,0,1,15,5,0,176,51,4,0,20,0,0,0,1,15,4,0,56,24,4,0,20,0,0,0,1,15,15,0,128,230,7,0,20,0,0,0,1,15,1,0,72,216,3,0,20,0,0,0,1,15,2,0,24,188,3,0,20,0,0,0,1,15,3,0,176,162,3,0,20,0,0,0,1,15,6,0,120,211,6,0,20,0,0,0,1,15,14,0,184,164,6,0,20,0,0,0,1,15,13,0,80,74,6,0,20,0,0,0,1,15,12,0,192,32,6,0,20,0,0,0,1,15,11,0,192,234,2,0,20,0,0,0,1,15,10,0,32,242,5,0,20,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,20,0,0,0,1,240,112,0,80,252,6,0,20,0,0,0,1,240,128,0,16,242,7,0,20,0,0,0,1,240,144,0,104,236,7,0,20,0,0,0,1,240,80,0,176,51,4,0,20,0,0,0,1,240,64,0,56,24,4,0,20,0,0,0,1,240,240,0,128,230,7,0,20,0,0,0,1,240,16,0,72,216,3,0,20,0,0,0,1,240,32,0,24,188,3,0,20,0,0,0,1,240,48,0,176,162,3,0,20,0,0,0,1,240,96,0,120,211,6,0,20,0,0,0,1,240,224,0,184,164,6,0,20,0,0,0,1,240,208,0,80,74,6,0,20,0,0,0,1,240,192,0,192,32,6,0,20,0,0,0,1,240,176,0,192,234,2,0,20,0,0,0,1,240,160,0,32,242,5,0,20,0,0,0,1,240,0,0,208,236,2,0,0,0,0,0,254,0,4,0,232,126,7,0,21,0,0,0,1,3,3,0,192,255,2,0,21,0,0,0,1,3,2,0,208,75,4,0,21,0,0,0,1,3,1,0,8,49,4,0,21,0,0,0,1,3,0,0,152,21,4,0,0,0,0,0,254,0,3,0,72,83,7,0,21,0,0,0,1,12,12,0,96,135,7,0,21,0,0,0,1,12,8,0,224,119,7,0,21,0,0,0,1,12,4,0,8,115,7,0,0,0,0,0,254,0,4,0,72,202,5,0,21,0,0,0,1,48,32,0,80,246,3,0,21,0,0,0,1,48,48,0,248,38,7,0,21,0,0,0,1,48,16,0,112,212,3,0,21,0,0,0,1,48,0,0,248,160,5,0,0,0,0,0,254,0,2,0,168,234,7,0,21,0,0,0,1,64,64,0,96,135,7,0,21,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,8,93,1,0,21,0,0,0,1,128,128,0,8,208,6,0,21,0,0,0,1,128,0,0,72,5,2,0,19,0,0,0,255,255,207,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,200,87,7,0,19,0,0,0,1,3,0,0,88,154,8,0,19,0,0,0,1,3,1,0,200,92,8,0,19,0,0,0,1,3,3,0,56,37,8,0,19,0,0,0,1,3,2,0,96,240,7,0,0,0,0,0,254,0,4,0,160,123,6,0,19,0,0,0,1,12,0,0,88,154,8,0,19,0,0,0,1,12,4,0,200,92,8,0,19,0,0,0,1,12,12,0,56,37,8,0,19,0,0,0,1,12,8,0,96,240,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,16,16,0,96,135,7,0,19,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,2,0,200,30,2,0,19,0,0,0,1,32,0,0,120,97,1,0,19,0,0,0,1,32,32,0,96,19,1,0,0,0,0,0,254,0,2,0,88,226,7,0,19,0,0,0,1,64,64,0,96,135,7,0,19,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,222,7,0,19,0,0,0,1,128,128,0,96,135,7,0,19,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,128,129,4,0,20,0,0,0,1,1,1,0,8,49,4,0,20,0,0,0,1,1,0,0,72,246,3,0,0,0,0,0,254,0,4,0,64,37,5,0,20,0,0,0,1,6,6,0,224,214,7,0,20,0,0,0,1,6,4,0,208,208,7,0,20,0,0,0,1,6,2,0,216,203,7,0,20,0,0,0,1,6,0,0,152,99,2,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,24,8,0,80,246,3,0,20,0,0,0,1,24,24,0,248,38,7,0,20,0,0,0,1,24,16,0,112,212,3,0,20,0,0,0,1,24,0,0,248,160,5,0,0,0,0,0,19,0,0,0,255,255,207,0,0,0,0,0,20,0,0,0,255,255,127,0,0,0,0,0,0,0,0,0,254,0,4,0,200,87,7,0,19,0,0,0,1,3,0,0,88,154,8,0,19,0,0,0,1,3,1,0,200,92,8,0,19,0,0,0,1,3,3,0,56,37,8,0,19,0,0,0,1,3,2,0,96,240,7,0,0,0,0,0,254,0,4,0,160,123,6,0,19,0,0,0,1,12,0,0,88,154,8,0,19,0,0,0,1,12,4,0,200,92,8,0,19,0,0,0,1,12,12,0,56,37,8,0,19,0,0,0,1,12,8,0,96,240,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,16,16,0,96,135,7,0,19,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,2,0,200,30,2,0,19,0,0,0,1,32,0,0,120,97,1,0,19,0,0,0,1,32,32,0,96,19,1,0,0,0,0,0,254,0,2,0,88,226,7,0,19,0,0,0,1,64,64,0,96,135,7,0,19,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,222,7,0,19,0,0,0,1,128,128,0,96,135,7,0,19,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,128,129,4,0,20,0,0,0,1,1,1,0,8,49,4,0,20,0,0,0,1,1,0,0,72,246,3,0,0,0,0,0,254,0,4,0,64,37,5,0,20,0,0,0,1,6,6,0,208,208,7,0,20,0,0,0,1,6,4,0,64,179,7,0,20,0,0,0,1,6,2,0,216,175,7,0,20,0,0,0,1,6,0,0,152,99,2,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,24,8,0,80,246,3,0,20,0,0,0,1,24,24,0,248,38,7,0,20,0,0,0,1,24,16,0,112,212,3,0,20,0,0,0,1,24,0,0,248,160,5,0,0,0,0,0,254,0,2,0,104,159,3,0,20,0,0,0,1,128,128,0,56,111,3,0,20,0,0,0,1,128,0,0,104,134,3,0,108,100,117,95,48,54,98,46,49,51,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,175,172,113,14,0,0,16,1,108,100,117,95,48,53,98,46,49,50,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,234,91,168,71,0,0,16,1,108,100,117,95,48,52,98,46,49,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,240,75,170,0,0,16,1,108,100,117,95,48,51,98,46,57,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,171,200,170,187,0,0,16,1,108,100,95,48,50,46,49,54,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,12,77,131,145,0,0,16,1,108,100,95,48,49,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,135,111,60,173,0,0,32,0,108,100,45,49,53,46,54,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,117,161,119,217,0,0,32,0,108,100,45,49,51,46,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,159,114,37,188,0,0,32,0,108,100,45,49,52,46,49,53,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,57,55,101,208,0,0,32,0,108,100,45,49,49,46,49,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,189,219,212,73,0,0,32,0,108,100,45,48,57,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,116,219,250,110,0,0,32,0,108,100,45,49,50,46,49,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,56,83,62,49,0,0,32,0,108,100,45,49,48,46,49,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,227,178,211,184,0,0,32,0,108,100,46,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,220,29,154,114,0,0,32,0,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,21,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,8,0,200,87,7,0,19,0,0,0,1,7,0,0,144,102,8,0,19,0,0,0,1,7,1,0,176,45,8,0,19,0,0,0,1,7,2,0,224,127,8,0,19,0,0,0,1,7,7,0,32,123,8,0,19,0,0,0,1,7,6,0,192,110,8,0,19,0,0,0,1,7,5,0,96,102,7,0,19,0,0,0,1,7,4,0,184,105,6,0,19,0,0,0,1,7,3,0,192,100,6,0,0,0,0,0,254,0,8,0,160,123,6,0,19,0,0,0,1,56,0,0,144,102,8,0,19,0,0,0,1,56,8,0,176,45,8,0,19,0,0,0,1,56,16,0,224,127,8,0,19,0,0,0,1,56,56,0,32,123,8,0,19,0,0,0,1,56,48,0,192,110,8,0,19,0,0,0,1,56,40,0,96,102,7,0,19,0,0,0,1,56,32,0,184,105,6,0,19,0,0,0,1,56,24,0,192,100,6,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,3,2,0,80,246,3,0,20,0,0,0,1,3,3,0,248,38,7,0,20,0,0,0,1,3,1,0,48,123,8,0,20,0,0,0,1,3,0,0,8,117,8,0,0,0,0,0,254,0,4,0,64,37,5,0,20,0,0,0,1,48,32,0,248,217,8,0,20,0,0,0,1,48,48,0,24,209,8,0,20,0,0,0,1,48,16,0,144,204,8,0,20,0,0,0,1,48,0,0,208,199,8,0,0,0,0,0,254,0,4,0,128,129,4,0,21,0,0,0,1,3,3,0,8,49,4,0,21,0,0,0,1,3,2,0,152,21,4,0,21,0,0,0,1,3,1,0,72,0,3,0,21,0,0,0])
.concat([1,3,0,0,232,99,5,0,0,0,0,0,254,0,2,0,232,157,8,0,21,0,0,0,1,4,4,0,8,152,8,0,21,0,0,0,1,4,0,0,112,145,8,0,0,0,0,0,254,0,2,0,168,234,7,0,21,0,0,0,1,32,0,0,96,135,7,0,21,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,192,125,6,0,21,0,0,0,1,64,0,0,56,111,3,0,21,0,0,0,1,64,64,0,104,134,3,0,0,0,0,0,254,0,2,0,144,212,8,0,21,0,0,0,1,128,128,0,96,135,7,0,21,0,0,0,1,128,0,0,152,182,7,0,108,98,117,103,103,120,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,29,36,126,230,1,0,16,1,108,98,117,103,103,120,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,154,251,177,60,1,0,16,1,108,98,117,103,103,120,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,158,0,55,9,1,0,16,1,108,98,117,103,103,120,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,98,63,119,62,1,0,16,1,108,98,117,103,103,120,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,229,66,13,43,1,0,16,1,108,98,117,103,103,120,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,51,148,159,21,1,0,16,1,108,98,117,103,103,120,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,213,6,190,242,1,0,16,1,108,98,117,103,103,120,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,159,231,111,100,1,0,16,1,108,98,117,103,103,120,46,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,197,157,251,126,4,0,32,0,108,98,117,103,103,120,46,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,220,77,29,53,4,0,32,0,108,98,117,103,103,120,46,99,108,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,171,174,60,78,7,0,32,0,15,0,0,0,255,255,0,0,0,0,0,0,16,0,0,0,255,255,0,0,0,0,0,0,17,0,0,0,255,255,1,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,16,0,0,0,1,64,0,0,120,97,1,0,16,0,0,0,1,64,64,0,96,19,1,0,0,0,0,0,254,0,2,0,32,4,2,0,16,0,0,0,1,128,0,0,184,146,2,0,16,0,0,0,1,128,128,0,144,147,2,0,0,0,0,0,254,0,4,0,72,202,5,0,17,0,0,0,1,3,0,0,160,246,1,0,17,0,0,0,1,3,1,0,80,246,3,0,17,0,0,0,1,3,2,0,112,212,3,0,17,0,0,0,1,3,3,0,248,160,5,0,0,0,0,0,254,0,2,0,128,129,4,0,17,0,0,0,1,4,0,0,8,49,4,0,17,0,0,0,1,4,4,0,152,21,4,0,0,0,0,0,254,0,2,0,64,37,5,0,17,0,0,0,1,8,0,0,80,110,6,0,17,0,0,0,1,8,8,0,112,216,4,0,112,101,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,150,95,43,8,2,0,16,1,112,111,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,30,54,0,1,2,0,16,1,105,99,46,49,56,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,136,183,207,146,9,0,16,1,109,45,56,45,51,46,117,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,230,132,64,28,15,0,32,0,109,45,56,45,50,46,117,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,77,28,162,173,15,0,32,0,109,45,56,45,49,46,117,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,214,170,149,157,15,0,32,0,109,45,56,45,48,46,117,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,211,110,251,13,15,0,32,0,109,45,56,45,53,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,10,14,217,217,24,0,64,0,109,45,56,45,52,46,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,122,4,246,211,25,0,64,0,21,0,0,0,255,255,223,0,0,0,0,0,22,0,0,0,255,255,128,0,0,0,0,0,0,0,0,0,254,0,4,0,200,87,7,0,21,0,0,0,1,3,1,0,104,236,7,0,21,0,0,0,1,3,3,0,128,230,7,0,21,0,0,0,1,3,0,0,120,211,6,0,21,0,0,0,1,3,2,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,21,0,0,0,1,12,4,0,104,236,7,0,21,0,0,0,1,12,12,0,128,230,7,0,21,0,0,0,1,12,0,0,120,211,6,0,21,0,0,0,1,12,8,0,184,164,6,0,0,0,0,0,254,0,4,0,72,202,5,0,21,0,0,0,1,96,96,0,80,246,3,0,21,0,0,0,1,96,64,0,80,124,6,0,21,0,0,0,1,96,32,0,112,212,3,0,21,0,0,0,1,96,0,0,248,160,5,0,0,0,0,0,254,0,2,0,160,165,8,0,21,0,0,0,1,128,128,0,96,135,7,0,21,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,22,0,0,0,1,1,1,0,96,135,7,0,22,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,22,0,0,0,1,2,0,0,96,135,7,0,22,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,22,0,0,0,1,4,4,0,96,135,7,0,22,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,22,0,0,0,1,24,24,0,8,49,4,0,22,0,0,0,1,24,16,0,152,21,4,0,22,0,0,0,1,24,8,0,72,246,3,0,22,0,0,0,1,24,0,0,72,0,3,0,0,0,0,0,254,0,2,0,0,150,8,0,22,0,0,0,1,32,32,0,8,208,6,0,22,0,0,0,1,32,0,0,88,204,6,0,0,0,0,0,254,0,2,0,128,112,3,0,22,0,0,0,1,64,0,0,168,22,4,0,22,0,0,0,1,64,64,0,224,247,3,0,0,0,0,0,254,0,2,0,232,75,4,0,22,0,0,0,1,128,128,0,96,135,7,0,22,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,115,110,120,95,97,45,52,101,45,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,70,10,51,252,0,0,16,1,115,110,120,95,97,45,52,100,45,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,47,211,47,27,0,0,16,1,115,110,120,95,97,45,51,100,45,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,86,121,202,133,0,0,16,1,115,110,120,95,97,45,51,102,45,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,10,16,241,62,0,0,16,1,103,45,52,99,45,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,200,201,44,107,0,0,32,0,103,45,52,100,45,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,88,245,72,198,0,0,32,0,103,45,52,101,45,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,110,39,233,251,0,0,32,0,115,110,120,95,98,45,52,107,45,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,178,29,89,133,0,0,32,0,115,110,120,95,98,45,52,102,45,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,123,157,113,237,0,0,32,0,115,110,120,95,98,45,51,110,45,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,139,206,252,5,0,0,32,0,115,110,120,95,98,45,52,110,45,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,3,80,103,220,0,0,32,0,115,110,120,95,98,45,52,99,45,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,129,29,241,29,0,0,32,0,115,110,120,95,98,45,52,101,45,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,221,105,59,45,0,0,32,0,103,45,49,106,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,202,107,142,102,0,0,32,0,98,45,49,109,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,156,90,192,118,0,0,32,0,103,45,49,102,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,149,100,75,150,0,0,32,0,98,45,49,110,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,153,107,240,35,0,0,32,0,103,45,49,104,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,225,99,5,85,0,0,32,0,98,45,49,108,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,33,80,228,53,0,0,32,0,98,45,53,102,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,61,28,96,122,0,0,32,0,98,45,54,102,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,18,13,194,130,0,0,32,0,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,29,121,142,93,0,0,16,1,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,184,226,0,64,0,0,16,1,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,176,122,232,88,0,0,16,1,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,234,49,30,200,0,0,16,1,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,149,185,159,217,0,0,16,1,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,200,201,44,107,0,0,32,0,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,88,245,72,198,0,0,32,0,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,110,39,233,251,0,0,32,0,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,178,29,89,133,0,0,32,0,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,123,157,113,237,0,0,32,0,49,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,139,206,252,5,0,0,32,0,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,3,80,103,220,0,0,32,0,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,129,29,241,29,0,0,32,0,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,221,105,59,45,0,0,32,0,103,45,49,106,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,202,107,142,102,0,0,32,0,98,45,49,109,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,156,90,192,118,0,0,32,0,103,45,49,102,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,149,100,75,150,0,0,32,0,98,45,49,110,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,153,107,240,35,0,0,32,0,103,45,49,104,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,225,99,5,85,0,0,32,0,98,45,49,108,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,33,80,228,53,0,0,32,0,98,45,53,102,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,61,28,96,122,0,0,32,0,98,45,54,102,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,18,13,194,130,0,0,32,0,107,102,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,63,49,101,63,0,0,16,1,107,102,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,243,37,163,158,0,0,16,1,97,45,51,101,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,176,122,232,88,0,0,16,1,97,45,51,102,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,234,49,30,200,0,0,16,1,97,45,51,104,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,149,185,159,217,0,0,16,1,103,45,52,99,45,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,200,201,44,107,0,0,32,0,103,45,52,100,45,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,88,245,72,198,0,0,32,0,103,45,52,101,45,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,110,39,233,251,0,0,32,0,98,45,52,107,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,80,81,251,22,0,0,32,0,98,45,52,102,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,51,90,116,103,0,0,32,0,98,45,52,108,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,97,34,28,189,0,0,32,0,98,45,52,104,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,58,237,197,138,0,0,32,0,98,45,51,110,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,170,19,162,40,0,0,32,0,98,45,52,110,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,243,141,34,213,0,0,32,0,98,45,52,109,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,242,228,109,177,0,0,32,0,98,45,51,109,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,107,214,160,235,0,0,32,0,98,45,52,99,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,133,136,41,1,0,0,32,0,98,45,52,101,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,212,135,123,199,0,0,32,0,98,45,52,100,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,95,97,112,106,0,0,32,0,98,45,52,97,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,38,214,137,97,0,0,32,0,103,45,49,106,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,202,107,142,102,0,0,32,0,98,45,49,109,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,156,90,192,118,0,0,32,0,103,45,49,102,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,149,100,75,150,0,0,32,0,98,45,49,110,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,153,107,240,35,0,0,32,0,103,45,49,104,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,225,99,5,85,0,0,32,0,98,45,49,108,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,33,80,228,53,0,0,32,0,98,45,53,102,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,61,28,96,122,0,0,32,0,98,45,54,102,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,18,13,194,130,0,0,32,0,8,0,0,0,255,255,32,0,0,0,0,0,0,0,0,0,254,0,2,0,232,75,4,0,8,0,0,0,1,32,0,0,152,182,7,0,8,0,0,0,1,32,32,0,96,135,7,0,107,110,111,99,107,111,117,116,46,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,142,132,170,234,1,0,16,1,107,110,111,99,107,111,117,116,46,50,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,192,210,38,188,1,0,16,1,107,110,111,99,107,111,117,116,46,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,16,92,2,2,1,0,16,1,107,110,111,99,107,111,117,116,46,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,43,196,171,233,1,0,16,1,116,114,105,112,108,101,112,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,111,189,28,213,4,0,32,0,116,114,105,112,108,101,112,46,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,89,0,28,242,4,0,32,0,116,114,105,112,112,114,111,109,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,223,117,79,98,7,0,32,0,107,114,95,50,51,117,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,186,194,43,37,2,0,16,1,107,114,95,50,50,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,169,113,182,208,2,0,16,1,107,114,45,53,109,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,164,193,54,158,4,0,32,0,107,114,45,55,109,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,174,44,131,197,4,0,32,0,107,114,45,49,109,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,45,190,149,240,4,0,32,0,107,114,45,51,109,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,150,253,157,23,4,0,32,0,107,114,45,54,109,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,210,152,66,31,4,0,32,0,107,114,45,56,109,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,81,135,250,55,4,0,32,0,107,114,45,50,109,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,61,188,0,2,4,0,32,0,107,114,45,52,109,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,231,180,178,11,4,0,32,0,107,114,95,48,57,46,49,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,238,217,68,94,3,0,16,0,107,114,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,95,209,105,218,5,0,64,0,107,114,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,233,84,198,191,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,107,114,54,51,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,34,101,91,253,0,0,0,8,105,111,98,49,46,49,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,98,112,114,103,49,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,167,61,121,49,0,0,0,8,105,111,99,49,46,105,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,129,32,24,13,0,0,0,8,99,54,51,50,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,112,146,189,15,0,0,0,8,107,114,95,50,51,106,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,127,65,231,234,2,0,16,1,107,114,95,50,50,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,169,113,182,208,2,0,16,1,107,114,95,48,49,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,164,193,54,158,4,0,32,0,107,114,95,48,50,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,174,44,131,197,4,0,32,0,107,114,95,48,51,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,45,190,149,240,4,0,32,0,107,114,95,48,52,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,150,253,157,23,4,0,32,0,107,114,95,48,53,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,210,152,66,31,4,0,32,0,107,114,95,48,54,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,81,135,250,55,4,0,32,0,107,114,95,48,55,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,61,188,0,2,4,0,32,0,107,114,95,48,56,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,231,180,178,11,4,0,32,0,107,114,95,48,57,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,238,217,68,94,3,0,16,0,107,114,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,95,209,105,218,5,0,64,0,107,114,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,233,84,198,191,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,107,114,54,51,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,34,101,91,253,0,0,0,8,105,111,98,49,46,49,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,98,112,114,103,49,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,167,61,121,49,0,0,0,8,105,111,99,49,46,105,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,129,32,24,13,0,0,0,8,99,54,51,50,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,112,146,189,15,0,0,0,8,107,114,104,95,50,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,61,246,47,250,2,0,16,1,107,114,104,95,50,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,112,208,56,20,2,0,16,1,107,114,95,103,102,120,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,164,193,54,158,4,0,32,0,107,114,95,103,102,120,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,174,44,131,197,4,0,32,0,107,114,95,103,102,120,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,45,190,149,240,4,0,32,0,107,114,95,103,102,120,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,150,253,157,23,4,0,32,0,107,114,95,103,102,120,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,210,152,66,31,4,0,32,0,107,114,95,103,102,120,55,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,81,135,250,55,4,0,32,0,107,114,95,103,102,120,54,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,61,188,0,2,4,0,32,0,107,114,95,103,102,120,56,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,231,180,178,11,4,0,32,0,107,114,95,48,57,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,238,217,68,94,3,0,16,0,107,114,95,49,56,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,95,209,105,218,5,0,64,0,107,114,95,49,57,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,233,84,198,191,5,0,64,0,53,46,105,99,49,55,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,24,17,217,127,1,0,16,1,51,46,105,99,49,55,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,32,231,198,201,1,0,16,1,52,46,105,99,49,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,3,39,53,175,1,0,16,1,50,46,105,99,49,55,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,67,19,185,30,1,0,16,1,107,114,95,103,102,120,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,164,193,54,158,4,0,32,0,107,114,95,103,102,120,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,174,44,131,197,4,0,32,0,107,114,95,103,102,120,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,45,190,149,240,4,0,32,0,107,114,95,103,102,120,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,150,253,157,23,4,0,32,0,107,114,95,103,102,120,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,210,152,66,31,4,0,32,0,107,114,95,103,102,120,55,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,81,135,250,55,4,0,32,0,107,114,95,103,102,120,54,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,61,188,0,2,4,0,32,0,107,114,95,103,102,120,56,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,231,180,178,11,4,0,32,0,49,46,105,99,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,193,156,111,189,3,0,16,0,112,114,103,49,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,70,144,180,108,1,0,16,1,112,114,103,50,46,55,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,22,180,35,194,1,0,16,1,112,114,103,51,46,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,192,52,54,69,1,0,16,1,107,98,101,49,46,105,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,10,200,226,91,2,0,16,1,107,98,101,50,46,105,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,101,233,89,187,2,0,16,1,107,98,101,51,46,105,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,49,221,148,28,2,0,16,1,107,98,101,50,46,105,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,101,233,89,187,2,0,16,1,99,104,103,49,46,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,231,80,213,156,4,0,32,0,99,104,103,50,46,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,125,117,6,162,4,0,32,0,107,98,50,45,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,22,91,221,21,7,0,32,0,12,0,0,0,255,255,0,0,0,0,0,0,13,0,0,0,255,255,64,0,0,0,0,0,14,0,0,0,255,255,4,0,0,0,0,0,15,0,0,0,255,255,2,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,12,0,0,0,1,32,0,0,120,97,1,0,12,0,0,0,1,32,32,0,96,19,1,0,0,0,0,0,254,0,4,0,32,4,2,0,13,0,0,0,1,192,192,0,224,127,8,0,13,0,0,0,1,192,64,0,32,123,8,0,13,0,0,0,1,192,128,0,192,110,8,0,13,0,0,0,1,192,0,0,104,151,6,0,0,0,0,0,254,0,4,0,64,37,5,0,14,0,0,0,1,3,0,0,176,116,6,0,14,0,0,0,1,3,1,0,32,160,1,0,14,0,0,0,1,3,2,0,80,113,6,0,14,0,0,0,1,3,3,0,120,7,5,0,0,0,0,0,254,0,2,0,128,129,4,0,14,0,0,0,1,4,0,0,208,75,4,0,14,0,0,0,1,4,4,0,8,49,4,0,0,0,0,0,254,0,2,0,232,75,4,0,15,0,0,0,1,1,0,0,96,135,7,0,15,0,0,0,1,1,1,0,152,182,7,0,0,0,0,0,254,0,2,0,200,159,1,0,15,0,0,0,1,2,0,0,96,135,7,0,15,0,0,0,1,2,2,0,152,182,7,0,109,113,106,45,112,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,74,57,239,156,0,0,16,1,109,113,106,45,98,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,205,244,188,217,0,0,16,1,109,113,106,45,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,225,171,160,84,0,0,16,1,109,113,106,45,115,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,130,53,207,187,0,0,16,1,109,113,106,45,99,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,197,133,85,151,0,0,32,0,109,113,106,45,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,109,147,217,73,0,0,32,0,109,113,106,45,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,143,197,176,127,0,0,32,0,109,113,106,45,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,5,146,24,58,0,0,32,0,109,113,106,45,118,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,86,41,118,84,0,0,64,0,56,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,18,187,121,115,0,0,32,0,54,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,187,12,206,250,0,0,32,0,55,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,187,12,206,250,0,0,32,0,17,0,0,0,255,255,255,0,0,0,0,0,18,0,0,0,255,255,213,0,0,0,0,0,0,0,0,0,254,0,4,0,72,202,5,0,17,0,0,0,1,3,2,0,80,246,3,0,17,0,0,0,1,3,3,0,80,124,6,0,17,0,0,0,1,3,1,0,112,212,3,0,17,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,128,129,4,0,17,0,0,0,1,12,8,0,192,255,2,0,17,0,0,0,1,12,4,0,208,75,4,0,17,0,0,0,1,12,12,0,8,49,4,0,17,0,0,0,1,12,0,0,152,21,4,0,0,0,0,0,254,0,12,0,32,4,2,0,17,0,0,0,1,240,160,0,8,32,4,0,17,0,0,0,1,240,176,0,96,164,8,0,17,0,0,0,1,240,192,0,144,102,8,0,17,0,0,0,1,240,208,0,176,45,8,0,17,0,0,0,1,240,224,0,224,127,8,0,17,0,0,0,1,240,240,0,32,123,8,0,17,0,0,0,1,240,112,0,192,110,8,0,17,0,0,0,1,240,96,0,96,102,7,0,17,0,0,0,1,240,80,0,184,105,6,0,17,0,0,0,1,240,64,0,152,96,3,0,17,0,0,0,1,240,48,0,192,100,6,0,17,0,0,0,1,240,0,0,104,151,6,0,0,0,0,0,254,0,2,0,144,212,8,0,18,0,0,0,1,1,1,0,96,135,7,0,18,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,200,30,2,0,18,0,0,0,1,2,0,0,120,97,1,0,18,0,0,0,1,2,2,0,96,19,1,0,0,0,0,0,254,0,2,0,96,46,8,0,18,0,0,0,1,4,4,0,208,233,4,0,18,0,0,0,1,4,0,0,72,197,4,0,0,0,0,0,254,0,2,0,168,234,7,0,18,0,0,0,1,8,8,0,96,135,7,0,18,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,246,3,0,18,0,0,0,1,16,16,0,96,135,7,0,18,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,2,0,104,81,2,0,18,0,0,0,1,32,32,0,96,135,7,0,18,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,184,196,8,0,18,0,0,0,1,64,64,0,96,135,7,0,18,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,18,0,0,0,1,128,128,0,96,135,7,0,18,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,100,114,48,52,46,52,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,88,24,67,128,0,0,16,1,100,114,48,51,46,52,99,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,52,9,162,219,0,0,16,1,100,114,49,49,46,56,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,147,45,216,4,0,0,16,1,100,114,49,50,46,56,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,253,85,178,192,0,0,16,1,100,114,48,48,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,247,9,131,69,0,0,16,1,100,114,48,49,46,51,99,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,189,151,104,230,0,0,16,1,100,114,48,50,46,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,38,30,227,249,0,0,16,1,100,114,48,54,46,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,15,151,154,77,0,0,32,0,100,114,48,55,46,50,100,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,196,164,89,171,0,0,32,0,100,114,48,53,46,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,12,173,109,46,0,0,32,0,100,114,50,49,46,52,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,154,234,108,160,0,0,32,0,100,114,49,57,46,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,173,5,70,179,0,0,32,0,100,114,50,50,46,52,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,232,61,48,65,0,0,32,0,100,114,50,48,46,52,106,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,97,111,190,95,0,0,32,0,100,114,49,52,46,51,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,188,188,207,118,0,0,32,0,100,114,50,52,46,52,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,181,141,28,213,0,0,32,0,100,114,50,51,46,52,110,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,248,157,70,3,0,0,32,0,100,114,49,51,46,51,110,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,224,223,195,213,0,0,32,0,100,114,49,54,46,52,99,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,147,187,209,241,0,0,32,0,100,114,49,56,46,52,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,91,242,183,237,0,0,32,0,100,114,49,55,46,52,100,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,104,120,184,79,0,0,32,0,100,114,49,53,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,229,141,184,224,0,0,32,0,100,114,48,56,46,52,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,67,6,213,50,0,0,32,0,100,114,48,57,46,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,149,111,223,23,0,0,32,0,100,114,49,48,46,52,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,82,226,12,130,0,0,32,0,100,114,50,53,46,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,11,67,145,142,0,0,32,0,100,114,51,48,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,99,50,199,40,0,0,32,0,100,114,50,54,46,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,63,185,99,181,0,0,32,0,100,114,51,49,46,49,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,14,33,41,53,0,0,32,0,100,114,50,55,46,51,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,239,104,214,112,0,0,32,0,100,114,50,57,46,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,84,167,115,17,0,0,32,0,100,114,51,50,46,53,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,46,31,205,17,0,0,32,0,100,114,51,51,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,60,141,216,52,0,0,32,0,100,114,50,56,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,189,15,239,108,0,0,0,8,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,64,0,0,0,65,0,0,0,66,0,0,0,67,0,0,0,68,0,0,0,69,0,0,0,70,0,0,0,71,0,0,0,168,86,7,0,1,0,0,0,67,191,145,0,248,191,2,0,24,38,7,0,1,0,0,0,69,191,145,0,184,160,2,0,56,210,6,0,1,0,0,0,64,251,146,0,192,135,2,0,24,163,6,0,1,0,0,0,65,251,146,0,240,108,2,0,152,122,6,0,1,0,0,0,66,251,146,0,96,82,2,0,192,72,6,0,1,0,0,0,67,251,146,0,32,56,2,0,200,110,3,0,1,0,0,0,68,251,146,0,152,30,2,0,120,89,3,0,1,0,0,0,69,251,146,0,232,10,2,0,120,74,3,0,1,0,0,0,70,251,146,0,152,138,8,0,40,246,1,0,1,0,0,0,68,191,145,0,64,246,1,0,144,236,1,0,1,0,0,0,70,191,145,0,136,224,1,0,176,223,1,0,1,0,0,0,16,243,146,0,72,198,1,0,192,209,1,0,1,0,0,0,17,243,146,0,24,182,1,0,24,198,1,0,1,0,0,0,18,243,146,0,40,167,1,0,120,189,1,0,1,0,0,0,19,243,146,0,200,149,1,0,224,22,1,0,1,0,0,0,20,243,146,0,56,126,1,0,160,14,1,0,1,0,0,0,21,243,146,0,32,101,1,0,176,9,1,0,1,0,0,0,22,243,146,0,96,32,8,0,88,212,3,0,1,0,0,0,240,215,146,0,40,185,3,0,16,17,8,0,1,0,0,0,64,191,145,0,224,12,8,0,56,58,1,0,1,0,0,0,65,191,145,0,64,50,1,0,72,65,1,0,9,0,0,0,115,223,146,0,32,58,1,0,48,50,1,0,9,0,0,0,116,223,146,0,32,58,1,0,224,41,1,0,9,0,0,0,117,223,146,0,32,58,1,0,168,86,7,0,1,0,0,0,242,237,146,0,248,191,2,0,24,38,7,0,1,0,0,0,82,242,146,0,184,160,2,0,56,210,6,0,1,0,0,0,120,250,146,0,192,135,2,0,24,163,6,0,1,0,0,0,121,250,146,0,240,108,2,0,152,122,6,0,1,0,0,0,122,250,146,0,96,82,2,0,192,72,6,0,1,0,0,0,123,250,146,0,32,56,2,0,200,110,3,0,1,0,0,0,124,250,146,0,152,30,2,0,120,89,3,0,1,0,0,0,125,250,146,0,232,10,2,0,120,74,3,0,1,0,0,0,126,250,146,0,152,138,8,0,40,246,1,0,1,0,0,0,241,237,146,0,64,246,1,0,144,236,1,0,1,0,0,0,83,242,146,0,136,224,1,0,176,223,1,0,1,0,0,0,128,250,146,0,72,198,1,0,192,209,1,0,1,0,0,0,129,250,146,0,24,182,1,0,24,198,1,0,1,0,0,0,130,250,146,0,40,167,1,0,120,189,1,0,1,0,0,0,131,250,146,0,200,149,1,0,224,22,1,0,1,0,0,0,132,250,146,0,56,126,1,0,160,14,1,0,1,0,0,0,133,250,146,0,32,101,1,0,176,9,1,0,1,0,0,0,134,250,146,0,96,32,8,0,88,212,3,0,1,0,0,0,96,215,146,0,40,185,3,0,16,17,8,0,1,0,0,0,240,237,146,0,224,12,8,0,72,65,1,0,9,0,0,0,24,94,147,0,32,58,1,0,48,50,1,0,9,0,0,0,25,94,147,0,32,58,1,0,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,21,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,1,1,0,96,135,7,0,19,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,152,39,2,0,19,0,0,0,1,64,0,0,96,135,7,0,19,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,128,128,0,96,135,7,0,19,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,16,0,32,4,2,0,20,0,0,0,1,15,5,0,144,160,3,0,20,0,0,0,1,15,13,0,96,135,3,0,20,0,0,0,1,15,3,0,32,136,7,0,20,0,0,0,1,15,11,0,40,88,7,0,20,0,0,0,1,15,8,0,40,28,4,0,20,0,0,0,1,15,7,0,96,39,7,0,20,0,0,0,1,15,4,0,192,24,7,0,20,0,0,0,1,15,12,0,120,113,6,0,20,0,0,0,1,15,15,0,144,251,6,0,20,0,0,0,1,15,2,0,120,211,6,0,20,0,0,0,1,15,9,0,184,164,6,0,20,0,0,0,1,15,1,0,80,74,6,0,20,0,0,0,1,15,14,0,192,32,6,0,20,0,0,0,1,15,6,0,192,234,2,0,20,0,0,0,1,15,10,0,32,242,5,0,20,0,0,0,1,15,0,0,16,227,4,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,48,16,0,80,246,3,0,20,0,0,0,1,48,48,0,248,38,7,0,20,0,0,0,1,48,32,0,112,212,3,0,20,0,0,0,1,48,0,0,248,160,5,0,0,0,0,0,254,0,2,0,224,133,4,0,21,0,0,0,1,128,128,0,160,134,3,0,21,0,0,0,1,128,0,0,176,20,3,0,0,0,0,0,109,97,106,106,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,178,163,20,70,1,0,16,1,109,97,106,49,95,100,46,115,105,109,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,123,226,15,186,6,0,32,0,109,97,106,49,95,99,46,115,105,109,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,191,65,209,44,6,0,32,0,109,97,106,49,95,98,46,115,105,109,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,38,76,158,226,6,0,32,0,109,97,106,49,95,97,46,115,105,109,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,138,184,104,127,6,0,32,0,109,97,106,51,95,100,46,115,105,109,109,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,11,185,174,58,6,0,32,0,109,97,106,51,95,99,46,115,105,109,109,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,234,76,137,151,6,0,32,0,109,97,106,51,95,98,46,115,105,109,109,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,157,125,115,236,6,0,32,0,109,97,106,51,95,97,46,115,105,109,109,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,34,111,59,194,6,0,32,0,109,97,106,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,19,194,232,31,10,0,16,1,109,97,106,53,95,97,46,115,105,109,109,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,83,238,217,90,14,0,64,0,109,97,106,53,95,98,46,115,105,109,109,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,251,219,179,239,14,0,64,0,101,115,100,50,46,99,117,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,147,208,45,48,0,0,16,1,101,115,100,49,46,99,117,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,186,146,51,136,0,0,16,1,97,116,50,55,99,48,50,48,46,115,117,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,36,68,141,168,0,0,16,1,101,115,100,55,46,106,117,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,224,112,41,156,0,0,32,0,101,115,100,56,46,106,117,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,176,153,191,51,0,0,32,0,101,115,100,57,46,106,117,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,253,33,29,103,0,0,32,0,101,115,100,49,48,46,106,117,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,115,204,163,133,0,0,32,0,101,115,100,53,46,102,117,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,33,248,71,13,0,0,32,0,101,115,100,54,46,102,117,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,13,244,26,192,0,0,32,0,101,115,100,52,46,102,117,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,190,9,180,151,0,0,32,0,101,115,100,51,46,102,117,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,147,166,88,51,0,0,32,0,97,116,50,55,99,48,50,48,46,115,117,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,167,48,111,6,0,0,64,0,50,51,45,105,99,50,57,46,49,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,145,30,161,107,0,0,16,1,50,52,45,105,99,51,48,46,49,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,139,217,149,87,0,0,16,1,50,50,45,105,99,49,57,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,48,149,97,189,0,0,16,1,51,48,45,105,99,49,50,53,46,49,53,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,137,160,185,68,0,0,32,0,50,57,45,105,99,49,50,52,46,49,51,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,105,236,152,63,0,0,32,0,50,53,45,105,99,54,57,46,49,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,87,232,106,23,0,0,32,0,50,56,45,105,99,49,51,49,46,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,87,119,131,237,0,0,32,0,50,54,45,105,99,55,48,46,50,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,128,73,179,232,0,0,32,0,50,55,45,105,99,49,48,48,46,49,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,163,221,24,57,0,0,32,0,50,49,45,105,99,49,55,46,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,117,79,9,229,0,0,64,0,105,99,49,56,46,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,195,54,55,166,0,0,64,0,106,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,183,161,90,65,1,0,16,1,106,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,16,117,194,177,1,0,16,1,106,98,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,15,138,139,203,1,0,16,1,106,98,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,18,29,117,102,1,0,16,1,106,98,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,226,181,83,117,1,0,16,1,106,98,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,67,152,190,71,1,0,16,1,106,98,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,97,237,10,70,1,0,16,1,106,98,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,10,27,9,154,4,0,32,0,106,98,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,130,192,15,138,4,0,32,0,106,98,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,224,134,81,21,4,0,32,0,106,98,105,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,17,177,73,119,4,0,32,0,106,98,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,223,215,232,6,4,0,32,0,106,98,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,243,221,219,184,4,0,32,0,108,48,54,95,112,114,111,109,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,135,125,12,106,7,0,32,0,11,0,0,0,255,255,255,0,0,0,0,0,12,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,11,0,0,0,1,1,0,0,120,97,1,0,11,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,2,0,144,212,8,0,11,0,0,0,1,2,2,0,96,135,7,0,11,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,11,0,0,0,1,4,4,0,96,135,7,0,11,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,11,0,0,0,1,8,0,0,96,135,7,0,11,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,12,0,0,0,1,3,2,0,80,246,3,0,12,0,0,0,1,3,3,0,80,124,6,0,12,0,0,0,1,3,1,0,112,212,3,0,12,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,0,0,64,37,5,0,12,0,0,0,1,12,8,0,120,160,1,0,12,0,0,0,1,12,12,0,104,150,1,0,12,0,0,0,1,12,4,0,40,141,1,0,12,0,0,0,1,12,0,0,160,126,1,0,0,0,0,0,254,0,0,0,128,129,4,0,12,0,0,0,1,48,32,0,208,75,4,0,12,0,0,0,1,48,48,0,8,49,4,0,12,0,0,0,1,48,16,0,152,21,4,0,12,0,0,0,1,48,0,0,72,246,3,0,0,0,0,0,254,0,2,0,104,159,3,0,12,0,0,0,1,128,0,0,56,111,3,0,12,0,0,0,1,128,128,0,104,134,3,0,0,0,0,0,64,0,0,0,128,0,0,0,192,0,0,0,0,1,0,0,64,1,0,0,128,1,0,0,192,1,0,0,0,0,0,0,16,0,0,0,8,0,0,0,24,0,0,0,32,0,0,0,48,0,0,0,40,0,0,0,56,0,0,0,168,86,7,0,1,0,0,0,80,240,146,0,248,191,2,0,120,248,6,0,1,0,0,0,82,240,146,0,184,160,2,0,56,210,6,0,1,0,0,0,248,0,147,0,192,135,2,0,24,163,6,0,1,0,0,0,249,0,147,0,240,108,2,0,192,72,6,0,1,0,0,0,250,0,147,0,32,56,2,0,152,122,6,0,1,0,0,0,251,0,147,0,96,82,2,0,40,246,1,0,1,0,0,0,81,240,146,0,64,246,1,0,48,245,6,0,1,0,0,0,83,240,146,0,136,224,1,0,176,223,1,0,1,0,0,0,88,248,146,0,72,198,1,0,192,209,1,0,1,0,0,0,89,248,146,0,24,182,1,0,120,189,1,0,1,0,0,0,90,248,146,0,200,149,1,0,24,198,1,0,1,0,0,0,91,248,146,0,40,167,1,0,88,212,3,0,1,0,0,0,64,220,146,0,40,185,3,0,248,5,8,0,9,0,0,0,96,6,147,0,32,58,1,0,144,250,7,0,9,0,0,0,97,6,147,0,32,58,1,0,18,0,0,0,255,255,191,0,0,0,0,0,19,0,0,0,255,255,239,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,8,0,200,87,7,0,18,0,0,0,1,7,1,0,32,136,7,0,18,0,0,0,1,7,2,0,40,88,7,0,18,0,0,0,1,7,4,0,96,39,7,0,18,0,0,0,1,7,7,0,144,251,6,0,18,0,0,0,1,7,3,0,120,211,6,0,18,0,0,0,1,7,6,0,184,164,6,0,18,0,0,0,1,7,5,0,80,74,6,0,18,0,0,0,1,7,0,0,16,227,4,0,0,0,0,0,254,0,8,0,160,123,6,0,18,0,0,0,1,56,8,0,32,136,7,0,18,0,0,0,1,56,16,0,40,88,7,0,18,0,0,0,1,56,32,0,96,39,7,0,18,0,0,0,1,56,56,0,144,251,6,0,18,0,0,0,1,56,24,0,120,211,6,0,18,0,0,0,1,56,48,0,184,164,6,0,18,0,0,0,1,56,40,0,80,74,6,0,18,0,0,0,1,56,0,0,16,227,4,0,0,0,0,0,254,0,2,0,168,234,7,0,18,0,0,0,1,64,64,0,96,135,7,0,18,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,1,1,0,96,135,7,0,19,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,2,2,0,96,135,7,0,19,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,19,0,0,0,1,12,8,0,80,246,3,0,19,0,0,0,1,12,12,0,248,38,7,0,19,0,0,0,1,12,4,0,112,212,3,0,19,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,4,0,104,115,3,0,19,0,0,0,1,48,32,0,208,75,4,0,19,0,0,0,1,48,48,0,8,49,4,0,19,0,0,0,1,48,16,0,152,21,4,0,19,0,0,0,1,48,0,0,72,246,3,0,0,0,0,0,254,0,4,0,64,37,5,0,19,0,0,0,1,192,128,0,96,187,2,0,19,0,0,0,1,192,192,0,32,186,2,0,19,0,0,0,1,192,64,0,112,184,2,0,19,0,0,0,1,192,0,0,216,32,3,0,0,0,0,0,19,0,0,0,255,255,254,0,0,0,0,0,20,0,0,0,255,255,188,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,19,0,0,0,1,1,0,0,120,97,1,0,19,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,2,2,0,96,135,7,0,19,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,4,4,0,96,135,7,0,19,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,8,0,0,96,135,7,0,19,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,19,0,0,0,1,48,16,0,96,39,7,0,19,0,0,0,1,48,48,0,144,251,6,0,19,0,0,0,1,48,0,0,120,211,6,0,19,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,19,0,0,0,1,192,64,0,96,39,7,0,19,0,0,0,1,192,192,0,144,251,6,0,19,0,0,0,1,192,0,0,120,211,6,0,19,0,0,0,1,192,128,0,184,164,6,0,0,0,0,0,254,0,4,0,64,37,5,0,20,0,0,0,1,12,8,0,136,136,2,0,20,0,0,0,1,12,12,0,152,126,7,0,20,0,0,0,1,12,4,0,40,110,2,0,20,0,0,0,1,12,0,0,88,99,2,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,48,32,0,208,75,4,0,20,0,0,0,1,48,48,0,8,49,4,0,20,0,0,0,1,48,16,0,152,21,4,0,20,0,0,0,1,48,0,0,72,246,3,0,0,0,0,0,254,0,2,0,104,159,3,0,20,0,0,0,1,64,64,0,56,111,3,0,20,0,0,0,1,64,0,0,104,134,3,0,0,0,0,0,101,112,114,45,54,54,52,55,46,49,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,93,145,93,204,0,0,16,1,101,112,114,45,54,54,52,56,46,49,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,96,77,87,55,0,0,16,1,101,112,114,45,54,54,52,57,46,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,238,189,89,95,0,0,16,1,101,112,114,45,54,54,53,54,46,49,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,133,214,227,37,0,0,16,1,101,112,114,45,54,54,53,53,46,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,47,118,31,190,0,0,32,0,101,112,114,45,54,54,53,52,46,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,200,127,95,237,0,0,32,0,101,112,114,45,54,54,53,51,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,167,69,72,139,0,0,32,0,101,112,114,45,54,54,53,50,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,203,104,29,0,0,0,32,0,101,112,114,45,54,54,53,49,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,230,181,233,78,0,0,32,0,101,112,114,45,54,54,53,48,46,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,20,68,202,63,0,0,32,0,101,112,114,45,54,54,52,53,46,49,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,238,103,161,27,0,0,32,0,101,112,114,45,54,54,52,54,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,214,122,218,237,0,0,32,0,112,114,45,53,51,49,55,46,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,184,80,131,100,0,0,0,8,22,0,0,0,255,255,255,0,0,0,0,0,23,0,0,0,255,255,229,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,22,0,0,0,1,3,2,0,208,75,4,0,22,0,0,0,1,3,3,0,8,49,4,0,22,0,0,0,1,3,1,0,152,21,4,0,22,0,0,0,1,3,0,0,72,246,3,0,0,0,0,0,254,0,4,0,72,202,5,0,22,0,0,0,1,12,12,0,248,38,7,0,22,0,0,0,1,12,8,0,112,212,3,0,22,0,0,0,1,12,4,0,248,160,5,0,22,0,0,0,1,12,0,0,144,86,7,0,0,0,0,0,254,0,2,0,200,30,2,0,23,0,0,0,1,2,0,0,120,97,1,0,23,0,0,0,1,2,2,0,96,19,1,0,0,0,0,0,254,0,2,0,168,234,7,0,23,0,0,0,1,8,8,0,96,135,7,0,23,0,0,0,1,8,0,0,152,182,7,0,104,121,112,101,114,112,97,99,46,104,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,26,83,240,44,0,0,16,1,104,121,112,101,114,112,97,99,46,105,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,184,133,125,156,0,0,16,1,104,121,112,101,114,112,97,99,46,97,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,218,115,134,189,0,0,32,0,104,121,112,101,114,112,97,99,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,130,205,144,93,0,0,32,0,104,121,112,101,114,112,97,99,46,97,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,99,110,216,97,0,0,32,0,104,121,112,101,114,112,97,99,46,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,142,248,250,3,0,0,64,0,104,121,112,101,114,112,97,99,46,106,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,141,70,159,251,0,0,64,0,97,116,56,57,99,53,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,38,147,31,41,0,0,16,8,19,0,0,0,255,255,252,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,40,111,8,0,19,0,0,0,1,1,1,0,96,135,7,0,19,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,128,129,4,0,19,0,0,0,1,2,2,0,8,49,4,0,19,0,0,0,1,2,0,0,72,246,3,0,0,0,0,0,254,0,8,0,232,24,7,0,19,0,0,0,1,28,0,0,232,151,6,0,19,0,0,0,1,28,4,0,168,241,6,0,19,0,0,0,1,28,8,0,224,19,7,0,19,0,0,0,1,28,12,0,64,15,7,0,19,0,0,0,1,28,28,0,224,9,7,0,19,0,0,0,1,28,20,0,88,239,6,0,19,0,0,0,1,28,24,0,144,3,7,0,19,0,0,0,1,28,16,0,224,166,6,0,0,0,0,0,254,0,4,0,72,202,5,0,19,0,0,0,1,96,0,0,80,246,3,0,19,0,0,0,1,96,96,0,248,38,7,0,19,0,0,0,1,96,64,0,112,212,3,0,19,0,0,0,1,96,32,0,24,99,5,0,0,0,0,0,254,0,2,0,128,156,8,0,19,0,0,0,1,128,128,0,32,182,8,0,19,0,0,0,1,128,0,0,80,251,6,0,0,0,0,0,101,112,114,45,49,49,49,53,50,46,97,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,98,206,176,138,1,0,16,1,101,112,114,45,49,49,49,53,51,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,222,67,167,132,1,0,16,1,101,112,114,45,49,49,50,48,50,46,97,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,227,237,148,124,2,0,32,0,101,112,114,45,49,49,50,49,51,46,98,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,216,169,170,174,2,0,32,0,101,112,114,45,49,49,50,48,51,46,97,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,247,84,119,50,2,0,32,0,101,112,114,45,49,49,50,49,52,46,98,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,250,42,168,99,2,0,32,0,101,112,114,45,49,49,50,48,52,46,97,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,51,205,196,223,2,0,32,0,101,112,114,45,49,49,50,49,53,46,98,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,168,148,132,91,2,0,32,0,101,112,114,45,49,49,50,48,53,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,19,138,9,252,3,0,32,0,101,112,114,45,49,49,50,48,57,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,168,52,185,93,3,0,32,0,101,112,114,45,49,49,50,48,54,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,116,238,39,31,3,0,32,0,101,112,114,45,49,49,50,49,48,46,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,241,92,106,138,3,0,32,0,101,112,114,45,49,49,50,48,55,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,130,186,178,192,3,0,32,0,101,112,114,45,49,49,50,49,49,46,98,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,123,145,199,214,3,0,32,0,101,112,114,45,49,49,50,48,56,46,98,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,75,228,201,53,3,0,32,0,101,112,114,45,49,49,50,49,50,46,98,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,210,249,232,87,3,0,32,0,101,112,114,45,49,49,49,53,52,46,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,117,18,121,101,4,0,16,1,101,112,114,45,49,49,50,48,48,46,97,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,138,166,65,92,8,0,64,0,101,112,114,45,49,49,50,48,49,46,97,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,32,49,153,154,8,0,64,0,51,49,55,45,48,48,52,54,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,139,63,139,72,5,0,16,1,112,108,115,49,53,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,235,0,0,0,18,114,180,57,0,0,0,8,101,112,114,97,54,55,57,48,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,185,91,25,89,0,0,16,1,101,112,114,97,54,55,56,57,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,138,209,225,131,0,0,16,1,101,112,114,97,54,55,56,56,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,87,253,206,110,0,0,16,1,101,112,114,54,55,56,55,46,49,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,240,199,74,182,0,0,16,1,101,112,114,54,55,57,53,46,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,56,208,163,88,0,0,32,0,101,112,114,54,55,57,54,46,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,85,138,176,216,0,0,32,0,101,112,114,54,55,57,51,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,194,7,116,72,0,0,32,0,101,112,114,54,55,57,52,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,147,55,235,137,0,0,32,0,101,112,114,54,55,57,49,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,66,208,220,167,0,0,32,0,101,112,114,54,55,57,50,46,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,51,94,190,208,0,0,32,0,101,112,114,54,55,55,56,46,49,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,238,26,246,10,0,0,32,0,101,112,114,54,55,55,55,46,49,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,151,161,215,145,0,0,32,0,101,112,114,54,55,56,48,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,245,29,179,85,0,0,32,0,101,112,114,54,55,55,57,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,40,43,58,224,0,0,32,0,112,114,55,48,51,54,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,251,22,111,20,0,0,32,0,112,114,55,48,51,53,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,237,1,178,80,0,0,32,0,112,114,55,48,51,52,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,57,241,181,223,0,0,32,0,112,114,53,51,49,55,112,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,184,80,131,100,0,0,0,8,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,253,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,19,0,0,0,1,15,7,0,80,252,6,0,19,0,0,0,1,15,8,0,16,242,7,0,19,0,0,0,1,15,9,0,104,236,7,0,19,0,0,0,1,15,5,0,192,54,8,0,19,0,0,0,1,15,4,0,56,24,4,0,19,0,0,0,1,15,15,0,128,230,7,0,19,0,0,0,1,15,0,0,128,230,7,0,19,0,0,0,1,15,3,0,176,162,3,0,19,0,0,0,1,15,2,0,24,188,3,0,19,0,0,0,1,15,1,0,72,216,3,0,19,0,0,0,1,15,6,0,120,211,6,0,19,0,0,0,1,15,14,0,184,164,6,0,19,0,0,0,1,15,13,0,80,74,6,0,19,0,0,0,1,15,12,0,192,32,6,0,19,0,0,0,1,15,11,0,192,234,2,0,19,0,0,0,1,15,10,0,32,242,5,0,0,0,0,0,254,0,16,0,160,123,6,0,19,0,0,0,1,240,112,0,80,252,6,0,19,0,0,0,1,240,128,0,16,242,7,0,19,0,0,0,1,240,144,0,104,236,7,0,19,0,0,0,1,240,80,0,192,54,8,0,19,0,0,0,1,240,64,0,56,24,4,0,19,0,0,0,1,240,240,0,128,230,7,0,19,0,0,0,1,240,0,0,128,230,7,0,19,0,0,0,1,240,48,0,176,162,3,0,19,0,0,0,1,240,32,0,24,188,3,0,19,0,0,0,1,240,16,0,72,216,3,0,19,0,0,0,1,240,96,0,120,211,6,0,19,0,0,0,1,240,224,0,184,164,6,0,19,0,0,0,1,240,208,0,80,74,6,0,19,0,0,0,1,240,192,0,192,32,6,0,19,0,0,0,1,240,176,0,192,234,2,0,19,0,0,0,1,240,160,0,32,242,5,0,0,0,0,0,254,0,2,0,168,234,7,0,20,0,0,0,1,2,2,0,96,135,7,0,20,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,12,12,0,8,49,4,0,20,0,0,0,1,12,8,0,152,21,4,0,20,0,0,0,1,12,4,0,72,246,3,0,20,0,0,0,1,12,0,0,112,49,6,0,0,0,0,0,254,0,4,0,64,37,5,0,20,0,0,0,1,48,48,0,208,73,5,0,20,0,0,0,1,48,32,0,48,69,5,0,20,0,0,0,1,48,16,0,120,66,5,0,20,0,0,0,1,48,0,0,0,64,7,0,0,0,0,0,254,0,2,0,72,202,5,0,20,0,0,0,1,64,64,0,80,246,3,0,20,0,0,0,1,64,0,0,112,212,3,0,0,0,0,0,254,0,2,0,104,159,3,0,20,0,0,0,1,128,128,0,96,135,7,0,20,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,104,117,115,116,108,101,114,46,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,169,198,26,58,1,0,16,1,104,117,115,116,108,101,114,46,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,236,82,103,220,1,0,16,1,104,117,115,116,108,101,114,46,50,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,248,224,193,39,1,0,16,1,104,117,115,116,108,101,114,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,222,191,89,181,2,0,16,1,104,117,115,116,108,101,114,46,49,48,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,251,108,249,110,2,0,16,1,104,117,115,116,108,101,114,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,14,173,223,11,4,0,32,0,104,117,115,116,108,101,114,46,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,119,33,6,142,4,0,32,0,104,117,115,116,108,101,114,46,99,108,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,94,127,31,170,7,0,32,0,104,111,45,103,112,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,167,205,23,79,0,0,16,1,104,111,45,103,112,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,199,82,250,112,0,0,16,1,104,111,45,103,112,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,177,52,25,147,0,0,16,1,104,111,45,103,112,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,1,213,92,175,0,0,16,1,104,111,45,103,112,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,116,137,142,101,0,0,16,1,104,111,45,115,100,112,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,253,63,251,62,0,0,16,1,104,111,45,115,112,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,30,155,211,63,0,0,64,0,104,111,45,99,112,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,70,61,199,198,0,0,32,0,104,111,45,99,112,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,28,55,150,229,0,0,32,0,104,111,45,99,112,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,207,225,250,17,0,0,32,0,53,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,36,166,85,240,0,0,64,0,56,50,115,49,56,53,46,49,48,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,166,188,5,194,0,0,32,0,56,50,115,49,50,51,46,49,48,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,236,28,34,181,0,0,32,0,49,49,100,95,115,110,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,134,96,34,136,1,0,16,1,53,102,95,104,98,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,61,156,72,219,4,0,32,0,53,104,95,104,98,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,14,101,119,57,4,0,32,0,54,101,95,112,114,111,109,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,63,77,0,1,7,0,32,0,50,99,95,104,98,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,52,216,235,139,8,0,16,1,50,101,95,104,98,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,41,66,222,7,8,0,16,1,50,102,95,104,98,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,252,13,90,183,8,0,16,1,50,104,95,104,98,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,100,98,32,243,8,0,16,1,50,106,95,104,98,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,40,135,183,27,8,0,16,1,50,108,95,104,98,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,128,214,94,242,8,0,16,1,50,109,95,104,98,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,23,14,46,199,8,0,16,1,50,112,95,104,98,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,176,135,32,65,8,0,16,1,17,0,0,0,255,255,0,0,0,0,0,0,18,0,0,0,255,255,2,0,0,0,0,0,19,0,0,0,255,255,14,0,0,0,0,0,0,0,0,0,254,0,2,0,128,129,4,0,18,0,0,0,1,1,0,0,8,49,4,0,18,0,0,0,1,1,1,0,72,246,3,0,0,0,0,0,254,0,4,0,32,4,2,0,18,0,0,0,1,2,0,0,144,147,2,0,18,0,0,0,1,2,2,0,184,146,2,0,0,0,0,0,254,0,4,0,64,37,5,0,19,0,0,0,1,6,6,0,176,116,6,0,19,0,0,0,1,6,4,0,80,110,6,0,19,0,0,0,1,6,2,0,112,216,4,0,19,0,0,0,1,6,0,0,184,43,6,0,0,0,0,0,254,0,2,0,200,30,2,0,20,0,0,0,1,8,8,0,120,97,1,0,20,0,0,0,1,8,0,0,96,19,1,0,0,0,0,0,103,97,108,95,104,98,95,107,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,14,101,119,57,4,0,32,0,103,97,108,95,104,98,95,104,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,61,156,72,219,4,0,32,0,103,97,108,95,104,98,95,99,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,98,103,255,203,7,0,32,0,103,97,108,95,104,98,95,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,155,14,89,70,8,0,16,1,103,97,108,95,104,98,95,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,28,103,110,78,8,0,16,1,103,97,108,95,104,98,95,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,66,194,157,210,8,0,16,1,103,97,108,95,104,98,95,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,146,210,9,212,8,0,16,1,103,97,108,95,104,98,95,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,196,168,211,41,8,0,16,1,103,97,108,95,104,98,95,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,21,253,22,176,8,0,16,1,103,97,108,95,104,98,95,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,39,29,115,210,8,0,16,1,103,97,108,95,104,98,95,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,102,166,177,228,8,0,16,1,12,0,0,0,255,255,0,0,0,0,0,0,13,0,0,0,255,255,0,0,0,0,0,0,14,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,14,0,0,0,1,1,0,0,120,97,1,0,14,0,0,0,1,1,1,0,96,19,1,0,104,98,45,103,112,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,84,29,128,175,0,0,16,1,104,98,45,103,112,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,142,204,72,180,0,0,16,1,104,98,45,103,112,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,123,234,198,87,0,0,16,1,104,98,45,103,112,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,123,40,145,127,0,0,16,1,104,98,45,103,112,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,92,117,213,29,0,0,16,1,54,99,46,115,100,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,84,40,186,249,0,0,16,1,56,97,46,115,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,1,210,28,237,0,0,64,0,49,49,97,46,99,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,71,176,86,242,0,0,32,0,49,48,97,46,99,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,79,198,112,184,0,0,32,0,57,97,46,99,112,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,136,171,125,154,0,0,32,0,53,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,36,166,85,240,0,0,64,0,56,50,115,49,56,53,46,49,48,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,166,188,5,194,0,0,32,0,56,50,115,49,50,51,46,49,48,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,236,28,34,181,0,0,32,0,112,48,52,46,98,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,58,72,145,105,0,0,16,1,112,48,51,46,98,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,64,76,241,239,0,0,16,1,112,48,50,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,134,49,160,197,0,0,16,1,112,114,111,116,100,97,116,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,182,173,39,91,0,0,16,1,112,48,54,115,114,111,109,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,13,187,44,61,0,0,32,0,112,48,55,115,114,111,109,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,156,148,7,2,0,0,32,0,112,48,56,117,111,114,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,182,231,17,104,0,0,32,0,112,48,57,117,111,114,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,207,73,101,28,0,0,32,0,112,49,48,117,111,114,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,224,230,98,100,0,0,32,0,112,49,49,117,111,114,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,152,29,81,156,0,0,32,0,112,48,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,41,104,192,24,0,0,64,0,56,55,99,53,50,46,109,99,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,16,17,0,0,0,255,255,255,0,0,0,0,0,18,0,0,0,255,255,127,0,0,0,0,0,0,0,0,0,254,0,2,0,232,75,4,0,18,0,0,0,1,1,1,0,96,135,7,0,18,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,18,0,0,0,1,6,0,0,80,246,3,0,18,0,0,0,1,6,6,0,248,38,7,0,18,0,0,0,1,6,2,0,112,212,3,0,18,0,0,0,1,6,4,0,24,99,5,0,0,0,0,0,254,0,8,0,32,4,2,0,18,0,0,0,1,56,0,0,104,54,4,0,18,0,0,0,1,56,32,0,80,252,6,0,18,0,0,0,1,56,16,0,16,242,7,0,18,0,0,0,1,56,48,0,104,236,7,0,18,0,0,0,1,56,56,0,128,230,7,0,18,0,0,0,1,56,40,0,120,211,6,0,18,0,0,0,1,56,24,0,184,164,6,0,18,0,0,0,1,56,8,0,80,74,6,0,0,0,0,0,254,0,2,0,200,218,3,0,18,0,0,0,1,64,64,0,96,135,7,0,18,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,18,0,0,0,1,128,128,0,96,135,7,0,18,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,48,100,46,108,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,235,234,138,62,1,0,16,1,49,100,46,108,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,70,50,171,14,1,0,16,1,50,100,46,108,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,227,189,70,230,1,0,16,1,51,100,46,108,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,18,147,222,91,1,0,16,1,54,100,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,81,38,224,197,2,0,16,1,55,100,46,98,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,61,17,220,73,2,0,16,1,52,100,46,104,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,14,133,28,117,4,0,32,0,53,100,46,104,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,46,40,116,252,4,0,32,0,49,56,115,48,51,48,46,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,171,174,60,78,7,0,32,0,11,0,0,0,255,255,0,0,0,0,0,0,12,0,0,0,255,255,0,0,0,0,0,0,13,0,0,0,255,255,0,0,0,0,0,0,14,0,0,0,255,255,5,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,13,0,0,0,1,240,128,0,224,127,8,0,13,0,0,0,1,240,144,0,240,169,3,0,13,0,0,0,1,240,0,0,32,123,8,0,13,0,0,0,1,240,160,0,248,116,8,0,13,0,0,0,1,240,176,0,152,81,3,0,13,0,0,0,1,240,16,0,192,110,8,0,13,0,0,0,1,240,192,0,168,36,1,0,13,0,0,0,1,240,208,0,40,242,1,0,13,0,0,0,1,240,32,0,96,102,7,0,13,0,0,0,1,240,224,0,0,240,1,0,13,0,0,0,1,240,240,0,192,238,1,0,13,0,0,0,1,240,48,0,184,105,6,0,13,0,0,0,1,240,64,0,152,96,3,0,13,0,0,0,1,240,80,0,192,100,6,0,13,0,0,0,1,240,96,0,64,1,1,0,13,0,0,0,1,240,112,0,184,69,8,0,0,0,0,0,254,0,16,0,160,123,6,0,13,0,0,0,1,15,8,0,224,127,8,0,13,0,0,0,1,15,9,0,240,169,3,0,13,0,0,0,1,15,0,0,32,123,8,0,13,0,0,0,1,15,10,0,248,116,8,0,13,0,0,0,1,15,11,0,152,81,3,0,13,0,0,0,1,15,1,0,192,110,8,0,13,0,0,0,1,15,12,0,168,36,1,0,13,0,0,0,1,15,13,0,40,242,1,0,13,0,0,0,1,15,2,0,96,102,7,0,13,0,0,0,1,15,14,0,0,240,1,0,13,0,0,0,1,15,15,0,192,238,1,0,13,0,0,0,1,15,3,0,184,105,6,0,13,0,0,0,1,15,4,0,152,96,3,0,13,0,0,0,1,15,5,0,192,100,6,0,13,0,0,0,1,15,6,0,64,1,1,0,13,0,0,0,1,15,7,0,184,69,8,0,0,0,0,0,254,0,4,0,128,129,4,0,14,0,0,0,1,3,0,0,208,75,4,0,14,0,0,0,1,3,1,0,8,49,4,0,14,0,0,0,1,3,2,0,152,21,4,0,14,0,0,0,1,3,3,0,72,246,3,0,0,0,0,0,254,0,2,0,128,112,3,0,14,0,0,0,1,4,4,0,168,22,4,0,14,0,0,0,1,4,0,0,176,176,7,0,0,0,0,0,254,0,4,0,64,37,5,0,14,0,0,0,1,24,0,0,200,205,3,0,14,0,0,0,1,24,8,0,24,145,2,0,14,0,0,0,1,24,16,0,240,159,4,0,14,0,0,0,1,24,24,0,120,7,5,0,0,0,0,0,254,0,2,0,200,30,2,0,14,0,0,0,1,128,0,0,120,97,1,0,14,0,0,0,1,128,128,0,96,19,1,0,27,0,0,0,255,255,96,0,0,0,0,0,0,0,0,0,254,0,2,0,232,75,4,0,27,0,0,0,1,32,32,0,96,135,7,0,27,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,192,3,0,27,0,0,0,1,64,64,0,96,135,7,0,27,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,107,110,104,104,100,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,199,25,102,120,0,0,16,1,107,110,104,104,100,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,91,71,187,59,0,0,16,1,104,111,114,101,107,105,100,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,80,12,92,55,0,0,16,1,104,111,114,101,107,105,100,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,187,82,125,238,0,0,16,1,104,111,114,101,107,105,100,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,129,59,205,73,0,0,16,1,104,111,114,101,107,105,100,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,56,169,234,193,0,0,16,1,104,111,114,101,107,105,100,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,2,199,43,10,0,0,16,1,104,111,114,101,107,105,100,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,204,119,75,16,0,0,32,0,104,111,114,101,107,105,100,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,16,174,37,218,0,0,32,0,104,111,114,101,107,105,100,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,33,67,110,97,0,0,32,0,104,111,114,101,107,105,100,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,226,43,125,140,0,0,32,0,104,111,114,101,107,105,100,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,2,107,6,160,0,0,32,0,104,111,114,101,107,105,100,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,122,160,202,163,0,0,32,0,104,111,114,101,107,105,100,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,142,255,72,14,0,0,32,0,104,111,114,101,107,105,100,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,122,116,0,227,0,0,32,0,104,111,114,101,107,105,100,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,65,87,16,81,0,0,32,0,107,105,100,95,112,114,111,109,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,35,206,19,202,0,0,32,0,107,105,100,95,112,114,111,109,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,90,40,68,251,0,0,32,0,107,105,100,95,112,114,111,109,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,55,18,212,64,0,0,32,0,107,105,100,95,112,114,111,109,46,50,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,237,224,155,75,0,0,32,0,107,105,100,95,112,114,111,109,46,52,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,238,84,251,228,0,0,32,0,104,111,114,101,107,105,100,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,43,89,141,29,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,117,78,117,78,117,78,117,78,117,78,117,78,117,78,117,78,0,24,100,45,49,54,46,117,104,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,227,162,225,206,0,0,16,1,100,45,49,55,46,117,105,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,84,65,196,202,0,0,16,1,100,45,49,51,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,251,87,106,255,0,0,32,0,100,45,49,52,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,111,153,120,33,0,0,32,0,100,45,49,53,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,158,35,41,102,0,0,32,0,100,45,49,56,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,122,80,16,2,0,0,32,0,100,45,49,57,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,213,117,115,210,0,0,32,0,100,45,49,50,46,117,104,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,99,27,111,56,0,0,64,0,100,45,49,49,46,117,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,97,72,238,243,0,0,64,0,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,239,0,0,0,0,0,0,0,0,0,254,0,4,0,32,4,2,0,19,0,0,0,1,3,0,0,16,242,7,0,19,0,0,0,1,3,1,0,104,236,7,0,19,0,0,0,1,3,3,0,128,230,7,0,19,0,0,0,1,3,2,0,184,164,6,0,0,0,0,0,254,0,2,0,248,103,7,0,19,0,0,0,1,4,0,0,96,135,7,0,19,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,254,0,2,0,40,111,8,0,19,0,0,0,1,16,0,0,96,135,7,0,19,0,0,0,1,16,16,0,152,182,7,0,0,0,0,0,254,0,2,0,104,81,2,0,19,0,0,0,1,64,64,0,96,135,7,0,19,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,40,84,7,0,19,0,0,0,1,128,128,0,96,135,7,0,19,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,3,3,0,248,38,7,0,20,0,0,0,1,3,2,0,112,212,3,0,20,0,0,0,1,3,1,0,48,90,7,0,20,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,0,164,2,0,20,0,0,0,1,12,12,0,248,38,7,0,20,0,0,0,1,12,8,0,176,64,8,0,20,0,0,0,1,12,4,0,120,54,8,0,20,0,0,0,1,12,0,0,128,65,6,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,48,0,0,192,255,2,0,20,0,0,0,1,48,16,0,208,75,4,0,20,0,0,0,1,48,32,0,8,49,4,0,20,0,0,0,1,48,48,0,72,246,3,0,0,0,0,0,254,0,2,0,104,27,7,0,20,0,0,0,1,128,128,0,8,49,4,0,20,0,0,0,1,128,0,0,192,255,2,0,0,0,0,0,104,110,99,104,111,108,121,109,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,117,135,117,231,1,0,16,1,104,110,99,104,111,108,121,109,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,66,53,173,117,4,0,32,0,104,110,99,104,111,108,121,109,46,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,211,157,236,111,4,0,32,0,112,114,111,109,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,171,174,60,78,7,0,32,0,104,110,99,104,111,108,121,109,46,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,156,63,69,251,8,0,16,1,104,110,99,104,111,108,121,109,46,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,32,148,66,177,8,0,16,1,104,110,99,104,111,108,121,109,46,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,40,142,201,175,8,0,16,1,104,110,99,104,111,108,121,109,46,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,23,191,133,103,8,0,16,1,104,110,99,104,111,108,121,109,46,50,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,51,65,30,14,8,0,16,1,104,110,99,104,111,108,121,109,46,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,9,38,152,110,8,0,16,1,104,110,99,104,111,108,121,109,46,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,20,25,20,185,8,0,16,1,104,110,99,104,111,108,121,109,46,50,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,91,181,55,202,8,0,16,1,56,50,115,49,52,55,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,139,164,97,212,0,0,0,8,168,86,7,0,1,0,0,0,132,151,215,0,248,191,2,0,24,38,7,0,1,0,0,0,130,151,215,0,184,160,2,0,56,210,6,0,1,0,0,0,120,151,215,0,192,135,2,0,24,163,6,0,1,0,0,0,121,151,215,0,240,108,2,0,152,122,6,0,1,0,0,0,122,151,215,0,96,82,2,0,192,72,6,0,1,0,0,0,123,151,215,0,32,56,2,0,200,110,3,0,1,0,0,0,136,151,215,0,152,30,2,0,120,89,3,0,1,0,0,0,137,151,215,0,232,10,2,0,120,74,3,0,1,0,0,0,138,151,215,0,152,138,8,0,40,246,1,0,1,0,0,0,133,151,215,0,64,246,1,0,144,236,1,0,1,0,0,0,131,151,215,0,136,224,1,0,176,223,1,0,1,0,0,0,124,151,215,0,72,198,1,0,192,209,1,0,1,0,0,0,125,151,215,0,24,182,1,0,24,198,1,0,1,0,0,0,126,151,215,0,40,167,1,0,120,189,1,0,1,0,0,0,127,151,215,0,200,149,1,0,224,22,1,0,1,0,0,0,139,151,215,0,56,126,1,0,160,14,1,0,1,0,0,0,140,151,215,0,32,101,1,0,176,9,1,0,1,0,0,0,141,151,215,0,96,32,8,0,72,126,8,0,1,0,0,0,167,148,215,0,144,189,1,0,192,122,8,0,1,0,0,0,160,148,215,0,208,174,1,0,40,116,8,0,1,0,0,0,161,148,215,0,48,160,1,0,72,110,8,0,1,0,0,0,162,148,215,0,160,140,1,0,184,102,8,0,1,0,0,0,163,148,215,0,56,112,1,0,248,67,8,0,1,0,0,0,164,148,215,0,32,92,1,0,136,64,8,0,1,0,0,0,165,148,215,0,64,77,1,0,128,58,8,0,1,0,0,0,166,148,215,0,112,157,4,0,160,19,8,0,1,0,0,0,159,148,215,0,32,245,8,0,248,16,8,0,1,0,0,0,152,148,215,0,32,231,8,0,192,12,8,0,1,0,0,0,153,148,215,0,88,214,8,0,224,5,8,0,1,0,0,0,154,148,215,0,224,202,8,0,144,1,8,0,1,0,0,0,155,148,215,0,72,193,8,0,176,222,7,0,1,0,0,0,156,148,215,0,144,180,8,0,176,218,7,0,1,0,0,0,157,148,215,0,208,164,8,0,248,214,7,0,1,0,0,0,158,148,215,0,160,152,4,0,88,212,3,0,1,0,0,0,200,147,215,0,40,185,3,0,16,17,8,0,1,0,0,0,129,151,215,0,224,12,8,0,56,58,1,0,1,0,0,0,128,151,215,0,64,50,1,0,72,65,1,0,9,0,0,0,152,151,215,0,32,58,1,0,48,50,1,0,9,0,0,0,153,151,215,0,32,58,1,0,101,119,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,198,125,13,223,0,0,16,1,101,119,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,167,10,103,213,0,0,16,1,101,119,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,236,101,109,199,0,0,16,1,101,119,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,166,39,180,233,0,0,16,1,101,119,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,141,185,113,152,0,0,16,1,101,119,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,52,5,1,83,0,0,16,1,101,119,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,61,89,202,113,0,0,32,0,101,119,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,167,95,190,134,0,0,32,0,101,119,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,163,215,128,107,0,0,32,0,101,119,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,100,215,211,120,0,0,32,0,101,119,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,227,93,159,206,0,0,32,0,101,119,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,162,123,122,72,0,0,32,0,101,119,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,164,194,27,78,0,0,32,0,101,119,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,251,125,180,158,0,0,32,0,101,119,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,158,71,207,158,0,0,32,0,101,119,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,170,105,86,229,0,0,32,0,101,119,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,20,57,66,149,0,0,32,0,101,119,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,119,49,35,150,0,0,32,0,101,119,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,232,223,37,76,0,0,32,0,101,119,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,252,7,224,242,0,0,32,0,101,119,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,153,129,187,228,0,0,32,0,101,119,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,137,105,11,71,0,0,32,0,101,119,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,87,199,151,140,0,0,32,0,101,119,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,188,68,210,162,0,0,32,0,101,119,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,77,146,6,182,0,0,64,0,24,0,0,0,255,255,255,0,0,0,0,0,25,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,200,87,7,0,24,0,0,0,1,3,0,0,176,45,8,0,24,0,0,0,1,3,1,0,224,127,8,0,24,0,0,0,1,3,3,0,32,123,8,0,24,0,0,0,1,3,2,0,192,110,8,0,0,0,0,0,254,0,4,0,160,123,6,0,24,0,0,0,1,12,0,0,176,45,8,0,24,0,0,0,1,12,4,0,224,127,8,0,24,0,0,0,1,12,12,0,32,123,8,0,24,0,0,0,1,12,8,0,192,110,8,0,0,0,0,0,254,0,2,0,168,234,7,0,24,0,0,0,1,32,0,0,96,135,7,0,24,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,24,0,0,0,1,64,64,0,96,135,7,0,24,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,25,0,0,0,1,3,1,0,192,255,2,0,25,0,0,0,1,3,3,0,208,75,4,0,25,0,0,0,1,3,2,0,8,49,4,0,25,0,0,0,1,3,0,0,72,246,3,0,0,0,0,0,254,0,4,0,72,202,5,0,25,0,0,0,1,12,8,0,80,246,3,0,25,0,0,0,1,12,12,0,248,38,7,0,25,0,0,0,1,12,4,0,112,212,3,0,25,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,4,0,24,219,7,0,25,0,0,0,1,48,16,0,112,67,8,0,25,0,0,0,1,48,32,0,112,134,3,0,25,0,0,0,1,48,48,0,80,124,6,0,25,0,0,0,1,48,0,0,64,111,3,0,0,0,0,0,254,0,2,0,168,209,7,0,25,0,0,0,1,64,64,0,152,204,7,0,25,0,0,0,1,64,0,0,192,190,7,0,114,111,109,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,128,126,37,126,4,0,32,0,114,111,109,46,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,30,133,240,197,4,0,32,0,56,50,115,49,50,51,46,49,49,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,244,252,178,222,7,0,32,0,114,111,109,46,52,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,141,1,168,44,8,0,16,1,56,50,115,49,52,55,46,53,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,30,107,73,207,0,0,0,8,56,50,115,49,53,51,46,54,112,114,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,235,0,0,0,154,147,7,188,0,0,0,8,168,86,7,0,1,0,0,0,8,241,146,0,248,191,2,0,24,38,7,0,1,0,0,0,239,1,147,0,184,160,2,0,56,210,6,0,1,0,0,0,234,1,147,0,192,135,2,0,24,163,6,0,1,0,0,0,235,1,147,0,240,108,2,0,152,122,6,0,1,0,0,0,232,1,147,0,96,82,2,0,192,72,6,0,1,0,0,0,233,1,147,0,32,56,2,0,200,110,3,0,1,0,0,0,236,1,147,0,152,30,2,0,120,89,3,0,1,0,0,0,237,1,147,0,232,10,2,0,40,246,1,0,1,0,0,0,9,241,146,0,64,246,1,0,144,236,1,0,1,0,0,0,47,249,146,0,136,224,1,0,176,223,1,0,1,0,0,0,42,249,146,0,72,198,1,0,192,209,1,0,1,0,0,0,43,249,146,0,24,182,1,0,24,198,1,0,1,0,0,0,40,249,146,0,40,167,1,0,120,189,1,0,1,0,0,0,41,249,146,0,200,149,1,0,224,22,1,0,1,0,0,0,44,249,146,0,56,126,1,0,160,14,1,0,1,0,0,0,45,249,146,0,32,101,1,0,88,212,3,0,1,0,0,0,96,221,146,0,40,185,3,0,16,17,8,0,1,0,0,0,10,241,146,0,224,12,8,0,72,65,1,0,9,0,0,0,40,7,147,0,32,58,1,0,48,50,1,0,9,0,0,0,41,7,147,0,32,58,1,0,224,41,1,0,9,0,0,0,42,7,147,0,32,58,1,0,168,86,7,0,1,0,0,0,31,240,146,0,248,191,2,0,24,38,7,0,1,0,0,0,26,240,146,0,184,160,2,0,56,210,6,0,1,0,0,0,154,0,147,0,192,135,2,0,24,163,6,0,1,0,0,0,155,0,147,0,240,108,2,0,152,122,6,0,1,0,0,0,153,0,147,0,96,82,2,0,192,72,6,0,1,0,0,0,152,0,147,0,32,56,2,0,200,110,3,0,1,0,0,0,156,0,147,0,152,30,2,0,120,89,3,0,1,0,0,0,157,0,147,0,232,10,2,0,144,236,1,0,1,0,0,0,27,240,146,0,136,224,1,0,176,223,1,0,1,0,0,0,2,248,146,0,72,198,1,0,192,209,1,0,1,0,0,0,3,248,146,0,24,182,1,0,24,198,1,0,1,0,0,0,1,248,146,0,40,167,1,0,120,189,1,0,1,0,0,0,0,248,146,0,200,149,1,0,224,22,1,0,1,0,0,0,4,248,146,0,56,126,1,0,160,14,1,0,1,0,0,0,5,248,146,0,32,101,1,0,88,212,3,0,1,0,0,0,208,219,146,0,40,185,3,0,72,65,1,0,9,0,0,0,8,6,147,0,32,58,1,0,14,0,0,0,255,255,128,0,0,0,0,0,0,0,0,0,254,0,8,0,32,4,2,0,14,0,0,0,1,112,112,0,96,135,3,0,14,0,0,0,1,112,80,0,32,136,7,0,14,0,0,0,1,112,48,0,40,88,7,0,14,0,0,0,1,112,16,0,96,39,7,0,14,0,0,0,1,112,0,0,144,251,6,0,14,0,0,0,1,112,32,0,184,164,6,0,14,0,0,0,1,112,64,0,80,74,6,0,14,0,0,0,1,112,96,0,192,32,6,0,0,0,0,0,254,0,2,0,200,30,2,0,14,0,0,0,1,128,128,0,120,97,1,0,14,0,0,0,1,128,0,0,96,19,1,0,0,0,0,0,104,98,95,101,99,48,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,219,195,27,208,0,0,16,1,104,98,95,101,99,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,174,248,86,103,0,0,16,1,104,98,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,112,213,135,32,0,0,16,1,104,98,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,174,54,85,129,0,0,16,1,104,98,95,101,99,48,54,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,216,32,236,97,0,0,16,1,104,98,95,101,99,48,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,19,107,12,114,0,0,16,1,104,98,95,101,99,48,55,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,170,161,165,22,0,0,16,1,104,98,95,101,99,50,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,162,50,87,46,0,0,32,0,104,98,95,101,99,50,54,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,77,44,26,22,0,0,32,0,104,98,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,115,67,102,239,0,0,32,0,104,98,49,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,172,134,241,164,0,0,32,0,104,98,50,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,224,59,193,47,0,0,32,0,104,98,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,105,120,180,214,0,0,32,0,104,98,50,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,173,161,214,80,0,0,32,0,104,98,50,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,197,117,29,240,0,0,32,0,104,98,50,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,97,115,55,174,0,0,32,0,104,98,50,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,113,247,218,187,0,0,32,0,104,98,50,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,150,178,20,85,0,0,32,0,104,98,51,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,239,232,85,88,0,0,32,0,104,98,50,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,156,123,219,153,0,0,32,0,104,98,50,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,26,43,206,51,0,0,32,0,104,98,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,7,103,129,33,0,0,32,0,104,98,49,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,116,69,104,165,0,0,32,0,104,98,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,21,131,118,92,0,0,32,0,104,98,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,164,215,100,139,0,0,32,0,104,98,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,101,237,227,86,0,0,32,0,104,98,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,243,231,223,190,0,0,32,0,104,98,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,160,14,36,38,0,0,32,0,104,98,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,71,84,217,71,0,0,32,0,104,98,95,101,99,48,56,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,9,166,89,33,0,0,64,0,101,99,51,49,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,174,162,20,170,0,0,16,8,184,40,2,0,1,0,0,0,208,155,215,0,248,191,2,0,56,250,6,0,1,0,0,0,212,155,215,0,184,160,2,0,184,164,8,0,1,0,0,0,209,155,215,0,64,246,1,0,240,190,7,0,4,0,0,0,112,156,215,0,208,13,4,0,208,240,5,0,4,0,0,0,104,156,215,0,152,30,2,0,32,201,5,0,4,0,0,0,96,156,215,0,232,10,2,0,16,17,8,0,1,0,0,0,211,155,215,0,224,12,8,0,32,77,1,0,1,0,0,0,210,155,215,0,216,70,1,0,88,212,3,0,1,0,0,0,200,154,215,0,40,185,3,0,248,5,8,0,9,0,0,0,0,156,215,0,32,58,1,0,144,250,7,0,9,0,0,0,1,156,215,0,32,58,1,0,16,0,0,0,255,255,255,0,0,0,0,0,17,0,0,0,255,255,59,0,0,0,0,0,18,0,0,0,255,255,32,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,16,0,0,0,1,15,2,0,184,220,8,0,16,0,0,0,1,15,5,0,88,154,8,0,16,0,0,0,1,15,8,0,200,92,8,0,16,0,0,0,1,15,4,0,152,141,7,0,16,0,0,0,1,15,1,0,80,65,7,0,16,0,0,0,1,15,15,0,104,172,6,0,16,0,0,0,1,15,3,0,192,233,6,0,16,0,0,0,1,15,7,0,24,46,7,0,16,0,0,0,1,15,14,0,216,129,6,0,16,0,0,0,1,15,6,0,208,168,7,0,16,0,0,0,1,15,13,0,184,81,6,0,16,0,0,0,1,15,12,0,48,39,6,0,16,0,0,0,1,15,11,0,160,221,5,0,16,0,0,0,1,15,10,0,96,183,5,0,16,0,0,0,1,15,9,0,96,144,5,0,16,0,0,0,1,15,0,0,16,227,4,0,0,0,0,0,254,0,16,0,160,123,6,0,16,0,0,0,1,240,32,0,184,220,8,0,16,0,0,0,1,240,80,0,88,154,8,0,16,0,0,0,1,240,128,0,200,92,8,0,16,0,0,0,1,240,64,0,152,141,7,0,16,0,0,0,1,240,16,0,80,65,7,0,16,0,0,0,1,240,240,0,104,172,6,0,16,0,0,0,1,240,48,0,192,233,6,0,16,0,0,0,1,240,112,0,24,46,7,0,16,0,0,0,1,240,224,0,216,129,6,0,16,0,0,0,1,240,96,0,208,168,7,0,16,0,0,0,1,240,208,0,184,81,6,0,16,0,0,0,1,240,192,0,48,39,6,0,16,0,0,0,1,240,176,0,160,221,5,0,16,0,0,0,1,240,160,0,96,183,5,0,16,0,0,0,1,240,144,0,96,144,5,0,16,0,0,0,1,240,0,0,16,227,4,0,0,0,0,0,254,0,4,0,128,129,4,0,17,0,0,0,1,3,3,0,8,49,4,0,17,0,0,0,1,3,2,0,152,21,4,0,17,0,0,0,1,3,1,0,72,246,3,0,17,0,0,0,1,3,0,0,216,128,5,0,0,0,0,0,254,0,2,0,200,30,2,0,17,0,0,0,1,4,0,0,120,97,1,0,17,0,0,0,1,4,4,0,96,19,1,0,0,0,0,0,254,0,0,0,64,37,5,0,0,0,0,0,254,0,2,0,64,37,5,0,17,0,0,0,1,8,8,0,240,35,4,0,17,0,0,0,1,8,0,0,80,9,4,0,0,0,0,0,254,0,8,0,72,202,5,0,17,0,0,0,1,112,112,0,72,198,6,0,17,0,0,0,1,112,96,0,208,75,4,0,17,0,0,0,1,112,80,0,8,49,4,0,17,0,0,0,1,112,64,0,152,21,4,0,17,0,0,0,1,112,48,0,200,148,3,0,17,0,0,0,1,112,32,0,72,0,3,0,17,0,0,0,1,112,16,0,64,47,7,0,17,0,0,0,1,112,0,0,48,173,6,0,0,0,0,0,254,0,2,0,168,234,7,0,17,0,0,0,1,128,128,0,96,135,7,0,17,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,112,167,5,0,18,0,0,0,1,1,1,0,96,135,7,0,18,0,0,0,1,1,0,0,152,182,7,0,168,86,7,0,1,0,0,0,96,2,147,0,248,191,2,0,24,38,7,0,1,0,0,0,99,2,147,0,184,160,2,0,56,210,6,0,1,0,0,0,162,249,146,0,192,135,2,0,24,163,6,0,1,0,0,0,163,249,146,0,240,108,2,0,152,122,6,0,1,0,0,0,160,249,146,0,96,82,2,0,192,72,6,0,1,0,0,0,161,249,146,0,32,56,2,0,200,110,3,0,1,0,0,0,164,249,146,0,152,30,2,0,40,246,1,0,1,0,0,0,97,2,147,0,64,246,1,0,144,236,1,0,1,0,0,0,100,2,147,0,136,224,1,0,176,223,1,0,1,0,0,0,130,241,146,0,72,198,1,0,192,209,1,0,1,0,0,0,131,241,146,0,24,182,1,0,24,198,1,0,1,0,0,0,128,241,146,0,40,167,1,0,120,189,1,0,1,0,0,0,129,241,146,0,200,149,1,0,224,22,1,0,1,0,0,0,132,241,146,0,56,126,1,0,88,212,3,0,1,0,0,0,200,221,146,0,40,185,3,0,16,17,8,0,1,0,0,0,98,2,147,0,224,12,8,0,72,65,1,0,9,0,0,0,120,7,147,0,32,58,1,0,48,50,1,0,9,0,0,0,121,7,147,0,32,58,1,0,224,41,1,0,9,0,0,0,122,7,147,0,32,58,1,0,114,111,109,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,56,234,221,133,0,0,16,1,97,50,49,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,189,35,147,78,0,0,16,1,97,50,49,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,212,89,230,87,0,0,16,1,97,50,49,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,243,147,114,30,0,0,16,1,97,50,49,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,162,10,206,178,0,0,16,1,97,50,49,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,208,24,186,173,0,0,32,0,97,50,49,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,201,241,125,165,0,0,32,0,97,50,49,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,163,59,98,99,0,0,32,0,97,50,49,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,169,105,201,76,0,0,32,0,97,50,49,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,91,77,92,156,0,0,32,0,97,50,49,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,173,90,107,211,0,0,32,0,97,50,49,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,162,174,135,243,0,0,32,0,97,50,49,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,125,125,150,135,0,0,32,0,97,50,49,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,180,10,100,89,0,0,32,0,97,50,49,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,216,136,173,34,0,0,32,0,97,50,49,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,86,251,37,204,0,0,32,0,97,50,49,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,72,68,5,202,0,0,32,0,97,50,49,46,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,73,196,192,35,0,0,32,0,97,50,49,46,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,94,152,196,239,0,0,32,0,109,49,46,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,1,146,163,131,0,0,32,0,18,0,0,0,255,255,191,0,0,0,0,0,19,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,18,0,0,0,1,3,3,0,8,49,4,0,18,0,0,0,1,3,2,0,152,21,4,0,18,0,0,0,1,3,1,0,72,246,3,0,18,0,0,0,1,3,0,0,72,0,3,0,0,0,0,0,254,0,2,0,72,202,5,0,18,0,0,0,1,16,16,0,80,246,3,0,18,0,0,0,1,16,0,0,112,212,3,0,0,0,0,0,254,0,2,0,64,37,5,0,18,0,0,0,1,32,32,0,208,98,2,0,18,0,0,0,1,32,0,0,200,15,5,0,0,0,0,0,254,0,2,0,200,30,2,0,18,0,0,0,1,64,0,0,120,97,1,0,18,0,0,0,1,64,64,0,96,19,1,0,0,0,0,0,254,0,2,0,72,4,1,0,18,0,0,0,1,128,128,0,96,135,7,0,18,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,8,0,200,87,7,0,19,0,0,0,1,7,2,0,224,127,8,0,19,0,0,0,1,7,1,0,136,252,1,0,19,0,0,0,1,7,7,0,32,123,8,0,19,0,0,0,1,7,6,0,192,110,8,0,19,0,0,0,1,7,5,0,96,102,7,0,19,0,0,0,1,7,4,0,184,105,6,0,19,0,0,0,1,7,3,0,192,100,6,0,19,0,0,0,1,7,0,0,104,151,6,0,0,0,0,0,254,0,8,0,160,123,6,0,19,0,0,0,1,56,0,0,96,164,8,0,19,0,0,0,1,56,8,0,144,102,8,0,19,0,0,0,1,56,16,0,176,45,8,0,19,0,0,0,1,56,24,0,224,127,8,0,19,0,0,0,1,56,56,0,32,123,8,0,19,0,0,0,1,56,32,0,232,143,1,0,19,0,0,0])
.concat([1,56,48,0,192,110,8,0,19,0,0,0,1,56,40,0,96,102,7,0,0,0,0,0,99,55,49,45,48,57,46,105,99,52,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,162,68,165,16,2,0,16,1,99,55,49,45,48,56,46,105,99,52,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,160,192,125,193,2,0,16,1,99,55,49,45,49,48,46,105,99,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,6,10,156,243,2,0,16,1,99,55,49,45,49,52,46,105,99,51,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,54,160,45,49,2,0,16,1,99,55,49,45,49,54,46,105,99,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,212,194,188,27,2,0,16,1,99,55,49,45,49,53,46,105,99,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,187,0,62,223,2,0,16,1,99,55,49,45,49,50,46,105,99,52,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,248,199,56,0,9,0,16,1,99,55,49,45,48,50,46,105,99,53,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,146,12,96,42,11,0,32,0,99,55,49,45,48,51,46,105,99,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,5,198,51,145,15,0,32,0,99,55,49,45,48,49,46,105,99,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,90,16,115,14,24,0,64,0,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,2,2,0,96,135,7,0,19,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,4,4,0,96,135,7,0,19,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,8,0,0,96,135,7,0,19,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,19,0,0,0,1,48,0,0,80,252,6,0,19,0,0,0,1,48,16,0,16,242,7,0,19,0,0,0,1,48,32,0,104,236,7,0,19,0,0,0,1,48,48,0,128,230,7,0,0,0,0,0,254,0,4,0,160,123,6,0,19,0,0,0,1,192,192,0,8,201,6,0,19,0,0,0,1,192,128,0,200,197,6,0,19,0,0,0,1,192,64,0,152,194,6,0,19,0,0,0,1,192,0,0,248,189,6,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,3,2,0,80,246,3,0,20,0,0,0,1,3,3,0,80,124,6,0,20,0,0,0,1,3,1,0,112,212,3,0,20,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,64,37,5,0,20,0,0,0,1,12,8,0,128,189,4,0,20,0,0,0,1,12,12,0,216,186,4,0,20,0,0,0,1,12,4,0,8,184,4,0,20,0,0,0,1,12,0,0,32,182,4,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,48,32,0,192,255,2,0,20,0,0,0,1,48,16,0,208,75,4,0,20,0,0,0,1,48,48,0,8,49,4,0,20,0,0,0,1,48,0,0,72,246,3,0,0,0,0,0,254,0,2,0,104,159,3,0,20,0,0,0,1,64,0,0,96,135,7,0,20,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,6,0,20,0,0,0,1,128,0,0,8,208,6,0,20,0,0,0,1,128,128,0,88,204,6,0,18,0,0,0,255,255,191,0,0,0,0,0,19,0,0,0,255,255,253,0,0,0,0,0,20,0,0,0,255,255,240,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,18,0,0,0,1,3,2,0,208,75,4,0,18,0,0,0,1,3,3,0,8,49,4,0,18,0,0,0,1,3,1,0,152,21,4,0,18,0,0,0,1,3,0,0,72,246,3,0,0,0,0,0,254,0,4,0,72,202,5,0,18,0,0,0,1,12,0,0,160,203,8,0,18,0,0,0,1,12,8,0,80,246,3,0,18,0,0,0,1,12,12,0,248,38,7,0,18,0,0,0,1,12,4,0,112,212,3,0,0,0,0,0,254,0,2,0,64,37,5,0,18,0,0,0,1,16,0,0,72,127,6,0,18,0,0,0,1,16,16,0,120,122,6,0,0,0,0,0,254,0,2,0,104,159,3,0,18,0,0,0,1,32,0,0,56,111,3,0,18,0,0,0,1,32,32,0,104,134,3,0,0,0,0,0,254,0,2,0,168,234,7,0,18,0,0,0,1,64,64,0,96,135,7,0,18,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,18,0,0,0,1,128,128,0,96,135,7,0,18,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,1,1,0,96,135,7,0,19,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,88,160,1,0,19,0,0,0,1,4,4,0,136,86,1,0,19,0,0,0,1,4,0,0,184,147,6,0,0,0,0,0,254,0,2,0,96,46,8,0,19,0,0,0,1,8,8,0,192,255,2,0,19,0,0,0,1,8,0,0,208,75,4,0,0,0,0,0,254,0,16,0,32,4,2,0,19,0,0,0,1,240,160,0,144,160,3,0,19,0,0,0,1,240,176,0,96,135,3,0,19,0,0,0,1,240,192,0,32,136,7,0,19,0,0,0,1,240,208,0,40,88,7,0,19,0,0,0,1,240,224,0,96,39,7,0,19,0,0,0,1,240,16,0,32,202,2,0,19,0,0,0,1,240,48,0,120,113,6,0,19,0,0,0,1,240,32,0,232,228,5,0,19,0,0,0,1,240,240,0,144,251,6,0,19,0,0,0,1,240,64,0,120,211,6,0,19,0,0,0,1,240,144,0,184,164,6,0,19,0,0,0,1,240,128,0,80,74,6,0,19,0,0,0,1,240,112,0,192,32,6,0,19,0,0,0,1,240,96,0,192,234,2,0,19,0,0,0,1,240,80,0,32,242,5,0,19,0,0,0,1,240,0,0,16,227,4,0,0,0,0,0,18,0,0,0,255,255,191,0,0,0,0,0,19,0,0,0,255,255,253,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,18,0,0,0,1,3,2,0,8,49,4,0,18,0,0,0,1,3,3,0,208,75,4,0,18,0,0,0,1,3,1,0,152,21,4,0,18,0,0,0,1,3,0,0,192,255,2,0,0,0,0,0,254,0,4,0,72,202,5,0,18,0,0,0,1,12,0,0,160,203,8,0,18,0,0,0,1,12,8,0,80,246,3,0,18,0,0,0,1,12,12,0,248,38,7,0,18,0,0,0,1,12,4,0,112,212,3,0,0,0,0,0,254,0,2,0,64,37,5,0,18,0,0,0,1,16,0,0,72,127,6,0,18,0,0,0,1,16,16,0,120,122,6,0,0,0,0,0,254,0,2,0,104,159,3,0,18,0,0,0,1,32,0,0,56,111,3,0,18,0,0,0,1,32,32,0,104,134,3,0,0,0,0,0,254,0,2,0,168,234,7,0,18,0,0,0,1,64,64,0,96,135,7,0,18,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,18,0,0,0,1,128,128,0,96,135,7,0,18,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,1,1,0,96,135,7,0,19,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,88,160,1,0,19,0,0,0,1,4,4,0,136,86,1,0,19,0,0,0,1,4,0,0,184,147,6,0,0,0,0,0,254,0,2,0,96,46,8,0,19,0,0,0,1,8,8,0,192,255,2,0,19,0,0,0,1,8,0,0,208,75,4,0,0,0,0,0,254,0,16,0,32,4,2,0,19,0,0,0,1,240,160,0,144,160,3,0,19,0,0,0,1,240,176,0,96,135,3,0,19,0,0,0,1,240,192,0,32,136,7,0,19,0,0,0,1,240,208,0,40,88,7,0,19,0,0,0,1,240,224,0,96,39,7,0,19,0,0,0,1,240,16,0,32,202,2,0,19,0,0,0,1,240,48,0,120,113,6,0,19,0,0,0,1,240,32,0,232,228,5,0,19,0,0,0,1,240,240,0,144,251,6,0,19,0,0,0,1,240,64,0,120,211,6,0,19,0,0,0,1,240,144,0,184,164,6,0,19,0,0,0,1,240,128,0,80,74,6,0,19,0,0,0,1,240,112,0,192,32,6,0,19,0,0,0,1,240,96,0,192,234,2,0,19,0,0,0,1,240,80,0,32,242,5,0,19,0,0,0,1,240,0,0,16,227,4,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,21,0,0,0,255,255,255,0,0,0,0,0,22,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,20,0,0,0,1,15,2,0,32,136,7,0,20,0,0,0,1,15,5,0,40,88,7,0,20,0,0,0,1,15,8,0,96,39,7,0,20,0,0,0,1,15,4,0,120,113,6,0,20,0,0,0,1,15,1,0,232,228,5,0,20,0,0,0,1,15,15,0,144,251,6,0,20,0,0,0,1,15,3,0,56,141,7,0,20,0,0,0,1,15,7,0,120,211,6,0,20,0,0,0,1,15,14,0,184,164,6,0,20,0,0,0,1,15,6,0,24,1,7,0,20,0,0,0,1,15,13,0,80,74,6,0,20,0,0,0,1,15,12,0,192,32,6,0,20,0,0,0,1,15,11,0,192,234,2,0,20,0,0,0,1,15,10,0,32,242,5,0,20,0,0,0,1,15,9,0,176,192,2,0,20,0,0,0,1,15,0,0,16,227,4,0,0,0,0,0,254,0,4,0,160,123,6,0,20,0,0,0,1,48,0,0,40,88,7,0,20,0,0,0,1,48,16,0,96,39,7,0,20,0,0,0,1,48,48,0,144,251,6,0,20,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,2,0,128,112,3,0,20,0,0,0,1,192,192,0,224,247,3,0,20,0,0,0,1,192,0,0,168,22,4,0,0,0,0,0,254,0,4,0,72,202,5,0,21,0,0,0,1,3,2,0,80,246,3,0,21,0,0,0,1,3,3,0,248,38,7,0,21,0,0,0,1,3,1,0,112,212,3,0,21,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,128,129,4,0,21,0,0,0,1,12,8,0,192,255,2,0,21,0,0,0,1,12,12,0,208,75,4,0,21,0,0,0,1,12,4,0,8,49,4,0,21,0,0,0,1,12,0,0,152,21,4,0,0,0,0,0,254,0,4,0,64,37,5,0,21,0,0,0,1,48,48,0,248,74,6,0,21,0,0,0,1,48,32,0,232,142,2,0,21,0,0,0,1,48,16,0,232,33,8,0,21,0,0,0,1,48,0,0,120,7,5,0,0,0,0,0,254,0,2,0,168,234,7,0,21,0,0,0,1,64,0,0,96,135,7,0,21,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,21,0,0,0,1,128,128,0,96,135,7,0,21,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,22,0,0,0,1,8,8,0,96,135,7,0,22,0,0,0,1,8,0,0,152,182,7,0,22,0,0,0,255,255,255,0,0,0,0,0,23,0,0,0,255,255,255,0,0,0,0,0,24,0,0,0,255,255,32,0,0,0,0,0,0,0,0,0,254,0,2,0,168,234,7,0,22,0,0,0,1,1,0,0,96,135,7,0,22,0,0,0,1,1,1,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,22,0,0,0,1,6,4,0,80,246,3,0,22,0,0,0,1,6,6,0,248,38,7,0,22,0,0,0,1,6,2,0,112,212,3,0,22,0,0,0,1,6,0,0,248,160,5,0,0,0,0,0,254,0,0,0,144,212,8,0,22,0,0,0,1,16,16,0,96,135,7,0,22,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,2,0,72,4,1,0,22,0,0,0,1,32,32,0,96,135,7,0,22,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,200,191,7,0,22,0,0,0,1,64,64,0,96,135,7,0,22,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,22,0,0,0,1,128,128,0,96,135,7,0,22,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,200,87,7,0,23,0,0,0,1,7,0,0,184,220,8,0,23,0,0,0,1,7,1,0,88,154,8,0,23,0,0,0,1,7,2,0,200,92,8,0,23,0,0,0,1,7,7,0,56,37,8,0,23,0,0,0,1,7,6,0,96,240,7,0,23,0,0,0,1,7,5,0,128,188,7,0,23,0,0,0,1,7,3,0,184,46,7,0,23,0,0,0,1,7,4,0,120,251,7,0,0,0,0,0,254,0,8,0,160,123,6,0,23,0,0,0,1,56,56,0,56,37,8,0,23,0,0,0,1,56,16,0,24,46,7,0,23,0,0,0,1,56,0,0,192,172,7,0,23,0,0,0,1,56,48,0,96,240,7,0,23,0,0,0,1,56,8,0,208,168,7,0,23,0,0,0,1,56,40,0,128,188,7,0,23,0,0,0,1,56,24,0,184,46,7,0,23,0,0,0,1,56,32,0,120,251,7,0,0,0,0,0,254,0,8,0,160,165,8,0,23,0,0,0,1,64,64,0,96,135,7,0,23,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,16,227,4,0,23,0,0,0,1,128,128,0,96,135,7,0,23,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,128,112,3,0,24,0,0,0,1,32,32,0,168,22,4,0,24,0,0,0,1,32,0,0,224,247,3,0,20,0,0,0,255,255,96,0,0,0,0,0,21,0,0,0,255,255,2,0,0,0,0,0,0,0,0,0,254,0,2,0,232,75,4,0,20,0,0,0,1,32,32,0,96,135,7,0,20,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,192,3,0,20,0,0,0,1,64,64,0,96,135,7,0,20,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,48,45,3,0,21,0,0,0,1,3,0,0,176,20,3,0,21,0,0,0,1,3,1,0,240,94,3,0,21,0,0,0,1,3,2,0,56,80,3,0,102,48,55,95,49,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,16,175,117,217,1,0,16,1,104,48,55,95,50,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,195,20,237,178,1,0,16,1,107,48,55,95,51,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,96,65,95,148,1,0,16,1,109,48,55,95,52,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,197,11,200,221,1,0,16,1,100,48,56,112,95,53,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,81,67,53,98,1,0,16,1,101,48,56,112,95,54,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,137,163,21,217,1,0,16,1,109,48,56,112,95,55,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,70,83,36,201,1,0,16,1,110,48,56,112,95,56,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,199,69,125,121,1,0,16,1,104,48,49,95,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,89,201,19,131,4,0,32,0,104,48,49,95,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,175,50,97,194,4,0,32,0,107,48,49,95,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,126,83,212,201,4,0,32,0,107,48,49,95,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,59,179,194,220,4,0,32,0,108,48,54,95,112,114,111,109,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,135,125,12,106,7,0,32,0,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,47,37,0,191,1,0,16,1,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,213,183,18,247,1,0,16,1,107,48,55,95,51,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,96,65,95,148,1,0,16,1,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,168,57,138,128,1,0,16,1,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,103,110,254,54,1,0,16,1,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,232,103,234,197,1,0,16,1,109,48,56,112,95,55,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,70,83,36,201,1,0,16,1,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,41,50,223,40,1,0,16,1,104,48,49,95,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,89,201,19,131,4,0,32,0,104,48,49,95,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,175,50,97,194,4,0,32,0,107,48,49,95,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,126,83,212,201,4,0,32,0,107,48,49,95,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,59,179,194,220,4,0,32,0,108,48,54,95,112,114,111,109,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,135,125,12,106,7,0,32,0,11,0,0,0,255,255,0,0,0,0,0,0,12,0,0,0,255,255,192,0,0,0,0,0,13,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,200,87,7,0,12,0,0,0,1,64,0,0,224,127,8,0,12,0,0,0,1,64,64,0,32,123,8,0,0,0,0,0,254,0,2,0,160,123,6,0,12,0,0,0,1,128,128,0,0,90,2,0,12,0,0,0,1,128,0,0,104,61,2,0,0,0,0,0,254,0,2,0,64,37,5,0,13,0,0,0,1,1,0,0,176,114,3,0,13,0,0,0,1,1,1,0,120,7,5,0,0,0,0,0,254,0,2,0,128,129,4,0,13,0,0,0,1,4,0,0,8,49,4,0,13,0,0,0,1,4,4,0,72,246,3,0,0,0,0,0,254,0,2,0,200,30,2,0,13,0,0,0,1,8,0,0,120,97,1,0,13,0,0,0,1,8,8,0,96,19,1,0,57,52,103,110,111,103,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,53,50,236,103,1,0,16,1,57,50,103,110,111,103,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,242,65,60,129,1,0,16,1,107,48,55,95,51,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,96,65,95,148,1,0,16,1,49,103,110,111,103,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,88,150,255,73,1,0,16,1,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,103,110,254,54,1,0,16,1,101,48,56,112,95,54,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,137,163,21,217,1,0,16,1,109,48,56,112,95,55,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,70,83,36,201,1,0,16,1,57,56,103,110,111,103,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,60,173,212,233,1,0,16,1,104,48,49,95,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,89,201,19,131,4,0,32,0,104,48,49,95,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,175,50,97,194,4,0,32,0,107,48,49,95,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,126,83,212,201,4,0,32,0,107,48,49,95,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,59,179,194,220,4,0,32,0,108,48,54,95,112,114,111,109,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,135,125,12,106,7,0,32,0,11,0,0,0,255,255,0,0,0,0,0,0,12,0,0,0,255,255,192,0,0,0,0,0,13,0,0,0,255,255,8,0,0,0,0,0,0,0,0,0,254,0,2,0,200,87,7,0,12,0,0,0,1,64,0,0,224,127,8,0,12,0,0,0,1,64,64,0,32,123,8,0,0,0,0,0,254,0,2,0,160,123,6,0,12,0,0,0,1,128,128,0,0,90,2,0,12,0,0,0,1,128,0,0,104,61,2,0,0,0,0,0,254,0,2,0,64,37,5,0,13,0,0,0,1,1,0,0,176,114,3,0,13,0,0,0,1,1,1,0,120,7,5,0,0,0,0,0,254,0,2,0,128,129,4,0,13,0,0,0,1,4,0,0,8,49,4,0,13,0,0,0,1,4,4,0,72,246,3,0,0,0,0,0,254,0,2,0,200,30,2,0,13,0,0,0,1,8,8,0,120,97,1,0,13,0,0,0,1,8,0,0,96,19,1,0,18,0,0,0,255,255,255,0,0,0,0,0,19,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,232,75,4,0,18,0,0,0,1,1,1,0,96,135,7,0,18,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,18,0,0,0,1,2,0,0,96,135,7,0,18,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,2,0,16,227,4,0,18,0,0,0,1,4,4,0,96,135,7,0,18,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,240,167,5,0,18,0,0,0,1,8,8,0,208,75,4,0,18,0,0,0,1,8,0,0,8,49,4,0,0,0,0,0,254,0,0,0,128,129,4,0,18,0,0,0,1,192,0,0,192,255,2,0,18,0,0,0,1,192,128,0,208,75,4,0,18,0,0,0,1,192,192,0,8,49,4,0,18,0,0,0,1,192,64,0,72,246,3,0,0,0,0,0,254,0,2,0,72,202,5,0,19,0,0,0,1,24,8,0,80,246,3,0,19,0,0,0,1,24,24,0,248,38,7,0,19,0,0,0,1,24,16,0,112,212,3,0,19,0,0,0,1,24,0,0,248,160,5,0,0,0,0,0,254,0,2,0,32,4,2,0,19,0,0,0,1,224,0,0,32,136,7,0,19,0,0,0,1,224,128,0,40,88,7,0,19,0,0,0,1,224,64,0,96,39,7,0,19,0,0,0,1,224,192,0,120,113,6,0,19,0,0,0,1,224,224,0,144,251,6,0,19,0,0,0,1,224,32,0,120,211,6,0,19,0,0,0,1,224,96,0,184,164,6,0,19,0,0,0,1,224,160,0,80,74,6,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,21,0,0,0,255,255,90,0,0,0,0,0,22,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,20,0,0,0,1,15,2,0,80,252,6,0,20,0,0,0,1,15,5,0,16,242,7,0,20,0,0,0,1,15,8,0,104,236,7,0,20,0,0,0,1,15,4,0,120,113,6,0,20,0,0,0,1,15,1,0,232,228,5,0,20,0,0,0,1,15,15,0,128,230,7,0,20,0,0,0,1,15,3,0,56,141,7,0,20,0,0,0,1,15,7,0,120,211,6,0,20,0,0,0,1,15,14,0,184,164,6,0,20,0,0,0,1,15,6,0,24,1,7,0,20,0,0,0,1,15,13,0,80,74,6,0,20,0,0,0,1,15,12,0,192,32,6,0,20,0,0,0,1,15,11,0,192,234,2,0,20,0,0,0,1,15,10,0,32,242,5,0,20,0,0,0,1,15,9,0,176,192,2,0,20,0,0,0,1,15,0,0,16,227,4,0,0,0,0,0,254,0,15,0,160,123,6,0,20,0,0,0,1,240,32,0,80,252,6,0,20,0,0,0,1,240,80,0,16,242,7,0,20,0,0,0,1,240,128,0,104,236,7,0,20,0,0,0,1,240,64,0,120,113,6,0,20,0,0,0,1,240,16,0,232,228,5,0,20,0,0,0,1,240,240,0,128,230,7,0,20,0,0,0,1,240,48,0,56,141,7,0,20,0,0,0,1,240,112,0,120,211,6,0,20,0,0,0,1,240,224,0,184,164,6,0,20,0,0,0,1,240,96,0,24,1,7,0,20,0,0,0,1,240,208,0,80,74,6,0,20,0,0,0,1,240,192,0,192,32,6,0,20,0,0,0,1,240,176,0,192,234,2,0,20,0,0,0,1,240,160,0,32,242,5,0,20,0,0,0,1,240,144,0,176,192,2,0,0,0,0,0,254,0,4,0,128,129,4,0,21,0,0,0,1,3,3,0,208,75,4,0,21,0,0,0,1,3,2,0,8,49,4,0,21,0,0,0,1,3,1,0,72,246,3,0,21,0,0,0,1,3,0,0,64,47,7,0,0,0,0,0,254,0,4,0,64,37,5,0,21,0,0,0,1,24,24,0,24,94,1,0,21,0,0,0,1,24,16,0,232,8,4,0,21,0,0,0,1,24,8,0,8,49,6,0,21,0,0,0,1,24,0,0,160,191,4,0,0,0,0,0,254,0,4,0,72,202,5,0,21,0,0,0,1,96,96,0,80,246,3,0,21,0,0,0,1,96,64,0,248,38,7,0,21,0,0,0,1,96,32,0,112,212,3,0,21,0,0,0,1,96,0,0,248,160,5,0,0,0,0,0,254,0,2,0,168,234,7,0,21,0,0,0,1,128,128,0,96,135,7,0,21,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,6,0,22,0,0,0,1,2,2,0,8,208,6,0,22,0,0,0,1,2,0,0,88,204,6,0,0,0,0,0,254,0,2,0,232,75,4,0,22,0,0,0,1,4,4,0,96,135,7,0,22,0,0,0,1,4,0,0,152,182,7,0,20,0,0,0,255,255,255,0,0,0,0,0,21,0,0,0,255,255,90,0,0,0,0,0,22,0,0,0,255,255,253,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,20,0,0,0,1,15,2,0,248,223,6,0,20,0,0,0,1,15,5,0,88,179,6,0])
.concat([20,0,0,0,1,15,8,0,32,136,6,0,20,0,0,0,1,15,4,0,120,113,6,0,20,0,0,0,1,15,1,0,232,228,5,0,20,0,0,0,1,15,15,0,120,90,6,0,20,0,0,0,1,15,3,0,56,141,7,0,20,0,0,0,1,15,7,0,120,211,6,0,20,0,0,0,1,15,14,0,184,164,6,0,20,0,0,0,1,15,6,0,24,1,7,0,20,0,0,0,1,15,13,0,80,74,6,0,20,0,0,0,1,15,12,0,192,32,6,0,20,0,0,0,1,15,11,0,192,234,2,0,20,0,0,0,1,15,10,0,32,242,5,0,20,0,0,0,1,15,9,0,176,192,2,0,20,0,0,0,1,15,0,0,16,227,4,0,0,0,0,0,254,0,16,0,160,123,6,0,20,0,0,0,1,240,32,0,248,223,6,0,20,0,0,0,1,240,80,0,88,179,6,0,20,0,0,0,1,240,128,0,32,136,6,0,20,0,0,0,1,240,64,0,120,113,6,0,20,0,0,0,1,240,16,0,232,228,5,0,20,0,0,0,1,240,240,0,120,90,6,0,20,0,0,0,1,240,48,0,56,141,7,0,20,0,0,0,1,240,112,0,120,211,6,0,20,0,0,0,1,240,224,0,184,164,6,0,20,0,0,0,1,240,96,0,24,1,7,0,20,0,0,0,1,240,208,0,80,74,6,0,20,0,0,0,1,240,192,0,192,32,6,0,20,0,0,0,1,240,176,0,192,234,2,0,20,0,0,0,1,240,160,0,32,242,5,0,20,0,0,0,1,240,144,0,176,192,2,0,20,0,0,0,1,240,0,0,168,165,2,0,0,0,0,0,254,0,4,0,128,129,4,0,21,0,0,0,1,3,3,0,208,75,4,0,21,0,0,0,1,3,2,0,8,49,4,0,21,0,0,0,1,3,1,0,152,21,4,0,21,0,0,0,1,3,0,0,64,47,7,0,0,0,0,0,254,0,2,0,200,30,2,0,21,0,0,0,1,4,0,0,120,97,1,0,21,0,0,0,1,4,4,0,96,19,1,0,0,0,0,0,254,0,4,0,64,37,5,0,21,0,0,0,1,24,24,0,80,219,8,0,21,0,0,0,1,24,16,0,168,210,8,0,21,0,0,0,1,24,8,0,224,64,8,0,21,0,0,0,1,24,0,0,56,201,8,0,0,0,0,0,254,0,4,0,72,202,5,0,21,0,0,0,1,96,96,0,80,246,3,0,21,0,0,0,1,96,64,0,248,38,7,0,21,0,0,0,1,96,32,0,48,123,8,0,21,0,0,0,1,96,0,0,8,117,8,0,0,0,0,0,254,0,2,0,168,234,7,0,21,0,0,0,1,128,128,0,96,135,7,0,21,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,22,0,0,0,1,1,1,0,96,135,7,0,22,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,6,0,22,0,0,0,1,2,2,0,8,208,6,0,22,0,0,0,1,2,0,0,88,204,6,0,0,0,0,0,254,0,2,0,232,75,4,0,22,0,0,0,1,4,4,0,96,135,7,0,22,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,101,112,114,45,49,51,52,48,55,46,105,99,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,189,62,85,3,1,0,16,1,101,112,114,45,49,51,52,48,54,46,105,99,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,31,113,44,18,1,0,16,1,101,112,114,45,49,51,51,57,53,46,105,99,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,199,250,204,214,9,0,16,1,101,112,114,45,49,51,51,57,52,46,105,99,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,236,85,74,145,9,0,16,1,101,112,114,45,49,51,51,57,51,46,105,99,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,204,35,208,8,9,0,16,1,101,112,114,45,49,51,51,57,50,46,105,99,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,66,205,39,249,9,0,16,1,101,112,114,45,49,51,51,56,51,46,105,99,49,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,167,151,248,36,2,0,32,0,101,112,114,45,49,51,51,56,52,46,105,99,49,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,189,56,130,254,2,0,32,0,101,112,114,45,49,51,51,56,53,46,105,99,49,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,149,185,241,109,2,0,32,0,101,112,114,45,49,51,51,56,50,46,105,99,57,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,194,218,1,3,0,32,0,101,112,114,45,49,51,51,56,49,46,105,99,57,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,49,217,80,58,3,0,32,0,101,112,114,45,49,51,51,56,48,46,105,99,57,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,200,36,16,173,3,0,32,0,101,112,114,45,49,51,51,55,57,46,105,99,49,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,37,118,193,26,3,0,32,0,101,112,114,45,49,51,51,55,56,46,105,99,57,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,103,184,201,80,3,0,32,0,101,112,114,45,49,51,51,55,55,46,105,99,57,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,192,245,18,155,3,0,32,0,101,112,114,45,49,51,51,55,54,46,105,99,57,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,24,197,154,68,3,0,32,0,101,112,114,45,49,51,51,55,53,46,105,99,49,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,255,169,137,84,3,0,32,0,101,112,114,45,49,51,51,55,52,46,105,99,57,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,79,158,49,106,3,0,32,0,101,112,114,45,49,51,51,55,51,46,105,99,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,139,88,165,236,3,0,32,0,101,112,114,45,49,51,51,55,50,46,105,99,49,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,51,164,69,11,3,0,32,0,101,112,114,45,49,51,51,55,49,46,105,99,49,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,255,76,143,182,3,0,32,0,101,112,114,45,49,51,51,55,48,46,105,99,57,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,32,102,39,120,3,0,32,0,101,112,114,45,49,51,51,54,57,46,105,99,57,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,15,191,37,134,3,0,32,0,101,112,114,45,49,51,51,54,56,46,105,99,49,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,108,113,80,15,3,0,32,0,101,112,114,45,49,51,51,54,55,46,105,99,49,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,31,181,27,75,3,0,32,0,101,112,114,45,49,51,51,56,56,46,105,99,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,228,129,101,112,4,0,16,1,101,112,114,45,49,51,51,57,49,46,105,99,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,103,200,48,140,11,0,64,0,101,112,114,45,49,51,51,57,48,46,105,99,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,5,205,147,140,11,0,64,0,101,112,114,45,49,51,51,56,57,46,105,99,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,142,117,76,78,11,0,64,0,51,49,55,45,48,49,54,50,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,83,222,103,128,5,0,16,1,101,112,114,45,49,51,51,56,55,46,105,99,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,197,178,232,161,1,0,16,1,101,112,114,45,49,51,51,56,54,46,105,99,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,102,158,190,216,1,0,16,1,101,112,114,45,49,51,51,57,53,46,105,99,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,199,250,204,214,9,0,16,1,101,112,114,45,49,51,51,57,52,46,105,99,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,236,85,74,145,9,0,16,1,101,112,114,45,49,51,51,57,51,46,105,99,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,204,35,208,8,9,0,16,1,101,112,114,45,49,51,51,57,50,46,105,99,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,66,205,39,249,9,0,16,1,101,112,114,45,49,51,51,56,51,46,105,99,49,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,167,151,248,36,2,0,32,0,101,112,114,45,49,51,51,56,52,46,105,99,49,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,189,56,130,254,2,0,32,0,101,112,114,45,49,51,51,56,53,46,105,99,49,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,149,185,241,109,2,0,32,0,101,112,114,45,49,51,51,56,50,46,105,99,57,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,194,218,1,3,0,32,0,101,112,114,45,49,51,51,56,49,46,105,99,57,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,49,217,80,58,3,0,32,0,101,112,114,45,49,51,51,56,48,46,105,99,57,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,200,36,16,173,3,0,32,0,101,112,114,45,49,51,51,55,57,46,105,99,49,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,37,118,193,26,3,0,32,0,101,112,114,45,49,51,51,55,56,46,105,99,57,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,103,184,201,80,3,0,32,0,101,112,114,45,49,51,51,55,55,46,105,99,57,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,192,245,18,155,3,0,32,0,101,112,114,45,49,51,51,55,54,46,105,99,57,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,24,197,154,68,3,0,32,0,101,112,114,45,49,51,51,55,53,46,105,99,49,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,255,169,137,84,3,0,32,0,101,112,114,45,49,51,51,55,52,46,105,99,57,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,79,158,49,106,3,0,32,0,101,112,114,45,49,51,51,55,51,46,105,99,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,139,88,165,236,3,0,32,0,101,112,114,45,49,51,51,55,50,46,105,99,49,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,51,164,69,11,3,0,32,0,101,112,114,45,49,51,51,55,49,46,105,99,49,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,255,76,143,182,3,0,32,0,101,112,114,45,49,51,51,55,48,46,105,99,57,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,32,102,39,120,3,0,32,0,101,112,114,45,49,51,51,54,57,46,105,99,57,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,15,191,37,134,3,0,32,0,101,112,114,45,49,51,51,54,56,46,105,99,49,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,108,113,80,15,3,0,32,0,101,112,114,45,49,51,51,54,55,46,105,99,49,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,31,181,27,75,3,0,32,0,101,112,114,45,49,51,51,56,56,46,105,99,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,228,129,101,112,4,0,16,1,101,112,114,45,49,51,51,57,49,46,105,99,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,103,200,48,140,11,0,64,0,101,112,114,45,49,51,51,57,48,46,105,99,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,5,205,147,140,11,0,64,0,101,112,114,45,49,51,51,56,57,46,105,99,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,142,117,76,78,11,0,64,0,51,49,55,45,48,49,54,49,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,22,220,141,227,5,0,16,1,200,87,7,0,1,0,0,0,200,245,146,0,248,191,2,0,160,123,6,0,1,0,0,0,201,245,146,0,64,246,1,0,24,38,7,0,1,0,0,0,19,254,146,0,184,160,2,0,200,110,3,0,1,0,0,0,16,254,146,0,152,30,2,0,120,89,3,0,1,0,0,0,17,254,146,0,232,10,2,0,120,74,3,0,1,0,0,0,18,254,146,0,152,138,8,0,144,236,1,0,1,0,0,0,23,254,146,0,136,224,1,0,224,22,1,0,1,0,0,0,20,254,146,0,56,126,1,0,160,14,1,0,1,0,0,0,21,254,146,0,32,101,1,0,176,9,1,0,1,0,0,0,22,254,146,0,96,32,8,0,72,126,8,0,1,0,0,0,27,254,146,0,144,189,1,0,248,67,8,0,1,0,0,0,24,254,146,0,32,92,1,0,136,64,8,0,1,0,0,0,25,254,146,0,64,77,1,0,128,58,8,0,1,0,0,0,26,254,146,0,112,157,4,0,88,212,3,0,1,0,0,0,16,218,146,0,40,185,3,0,72,65,1,0,9,0,0,0,216,4,147,0,32,58,1,0,48,50,1,0,9,0,0,0,217,4,147,0,32,58,1,0,101,112,114,45,49,50,53,52,53,46,105,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,77,78,124,169,1,0,16,1,101,112,114,45,49,50,53,52,52,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,104,246,56,94,1,0,16,1,101,112,114,45,49,50,51,56,53,46,105,99,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,224,231,164,184,2,0,32,0,101,112,114,45,49,50,51,56,54,46,105,99,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,121,215,215,37,2,0,32,0,101,112,114,45,49,50,51,56,55,46,105,99,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,243,173,252,199,2,0,32,0,109,112,114,45,49,50,51,55,56,46,105,99,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,130,90,158,17,3,0,32,0,109,112,114,45,49,50,51,55,57,46,105,99,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,87,140,14,26,3,0,32,0,109,112,114,45,49,50,51,56,48,46,105,99,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,83,8,44,187,3,0,32,0,109,112,114,45,49,50,51,56,49,46,105,99,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,204,110,186,129,3,0,32,0,109,112,114,45,49,50,51,56,50,46,105,99,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,111,28,96,129,3,0,32,0,109,112,114,45,49,50,51,56,51,46,105,99,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,122,207,186,93,3,0,32,0,101,112,114,45,49,50,51,57,48,46,105,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,245,197,159,57,4,0,16,1,109,112,114,45,49,50,51,56,52,46,105,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,231,216,24,98,8,0,64,0,51,49,55,45,48,49,50,51,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,16,21,0,0,0,255,255,253,0,0,0,0,0,22,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,104,251,2,0,21,0,0,0,1,1,1,0,184,30,3,0,21,0,0,0,1,1,0,0,0,28,3,0,0,0,0,0,254,0,2,0,168,234,7,0,21,0,0,0,1,2,2,0,96,135,7,0,21,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,21,0,0,0,1,12,8,0,192,255,2,0,21,0,0,0,1,12,12,0,208,75,4,0,21,0,0,0,1,12,4,0,8,49,4,0,21,0,0,0,1,12,0,0,72,246,3,0,0,0,0,0,254,0,4,0,40,250,2,0,21,0,0,0,1,48,32,0,208,75,4,0,21,0,0,0,1,48,48,0,8,49,4,0,21,0,0,0,1,48,16,0,152,21,4,0,21,0,0,0,1,48,0,0,72,246,3,0,0,0,0,0,254,0,16,0,200,87,7,0,22,0,0,0,1,15,7,0,80,252,6,0,22,0,0,0,1,15,8,0,16,242,7,0,22,0,0,0,1,15,9,0,104,236,7,0,22,0,0,0,1,15,5,0,176,51,4,0,22,0,0,0,1,15,4,0,56,24,4,0,22,0,0,0,1,15,15,0,128,230,7,0,22,0,0,0,1,15,1,0,72,216,3,0,22,0,0,0,1,15,2,0,24,188,3,0,22,0,0,0,1,15,3,0,176,162,3,0,22,0,0,0,1,15,6,0,120,211,6,0,22,0,0,0,1,15,14,0,184,164,6,0,22,0,0,0,1,15,13,0,80,74,6,0,22,0,0,0,1,15,12,0,192,32,6,0,22,0,0,0,1,15,11,0,192,234,2,0,22,0,0,0,1,15,10,0,32,242,5,0,22,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,22,0,0,0,1,240,112,0,80,252,6,0,22,0,0,0,1,240,128,0,16,242,7,0,22,0,0,0,1,240,144,0,104,236,7,0,22,0,0,0,1,240,80,0,176,51,4,0,22,0,0,0,1,240,64,0,56,24,4,0,22,0,0,0,1,240,240,0,128,230,7,0,22,0,0,0,1,240,16,0,72,216,3,0,22,0,0,0,1,240,32,0,24,188,3,0,22,0,0,0,1,240,48,0,176,162,3,0,22,0,0,0,1,240,96,0,120,211,6,0,22,0,0,0,1,240,224,0,184,164,6,0,22,0,0,0,1,240,208,0,80,74,6,0,22,0,0,0,1,240,192,0,192,32,6,0,22,0,0,0,1,240,176,0,192,234,2,0,22,0,0,0,1,240,160,0,32,242,5,0,22,0,0,0,1,240,0,0,208,236,2,0,101,112,114,45,49,51,54,50,51,46,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,231,16,173,88,1,0,16,1,101,112,114,45,49,51,54,50,50,46,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,191,141,230,196,1,0,16,1,101,112,114,45,49,51,51,50,51,97,46,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,2,0,51,74,226,2,1,0,16,1,101,112,114,45,49,51,51,50,50,97,46,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,64,119,246,148,1,0,16,1,101,112,114,45,49,51,51,50,55,46,56,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,249,54,112,98,9,0,16,1,101,112,114,45,49,51,51,50,54,46,56,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,51,194,42,22,9,0,16,1,101,112,114,45,49,51,51,50,53,97,46,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,229,7,163,171,17,0,16,1,101,112,114,45,49,51,51,50,52,97,46,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,229,25,27,235,17,0,16,1,101,112,114,45,49,51,48,51,55,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,80,162,1,184,3,0,32,0,101,112,114,45,49,51,48,51,57,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,109,38,225,215,3,0,32,0,101,112,114,45,49,51,48,51,56,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,109,219,46,11,3,0,32,0,101,112,114,45,49,51,48,52,48,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,133,58,235,74,3,0,32,0,101,112,114,45,49,51,48,52,56,46,54,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,221,176,30,254,18,0,32,0,101,112,114,45,49,51,48,53,54,46,55,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,230,248,4,89,18,0,32,0,101,112,114,45,49,51,48,52,52,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,137,31,147,77,18,0,32,0,101,112,114,45,49,51,48,53,50,46,55,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,64,240,145,2,18,0,32,0,101,112,114,45,49,51,48,54,52,46,56,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,27,101,142,95,18,0,32,0,101,112,114,45,49,51,48,55,50,46,49,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,26,100,133,107,18,0,32,0,101,112,114,45,49,51,48,54,48,46,56,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,151,173,22,238,18,0,32,0,101,112,114,45,49,51,48,54,56,46,49,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,187,43,213,100,18,0,32,0,101,112,114,45,49,51,48,52,55,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,50,8,52,83,18,0,32,0,101,112,114,45,49,51,48,53,53,46,55,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,101,182,182,57,18,0,32,0,101,112,114,45,49,51,48,52,51,46,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,253,22,143,32,18,0,32,0,101,112,114,45,49,51,48,53,49,46,55,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,212,203,98,173,18,0,32,0,101,112,114,45,49,51,48,54,51,46,56,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,109,191,128,197,18,0,32,0,101,112,114,45,49,51,48,55,49,46,49,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,153,239,153,223,18,0,32,0,101,112,114,45,49,51,48,53,57,46,56,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,88,37,152,76,18,0,32,0,101,112,114,45,49,51,48,54,55,46,49,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,25,97,127,249,18,0,32,0,101,112,114,45,49,51,51,51,49,46,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,190,254,168,142,18,0,32,0,101,112,114,45,49,51,51,51,51,46,55,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,212,55,205,91,18,0,32,0,101,112,114,45,49,51,51,51,48,46,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,93,50,30,18,0,32,0,101,112,114,45,49,51,51,51,50,46,54,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,126,6,216,143,18,0,32,0,101,112,114,45,49,51,51,51,53,46,56,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,11,66,234,152,18,0,32,0,101,112,114,45,49,51,51,51,55,46,49,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,164,0,95,245,18,0,32,0,101,112,114,45,49,51,51,51,52,46,56,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,96,80,114,114,18,0,32,0,101,112,114,45,49,51,51,51,54,46,49,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,119,212,212,226,18,0,32,0,101,112,114,45,49,51,48,52,53,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,109,188,213,84,18,0,32,0,101,112,114,45,49,51,48,53,51,46,55,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,19,175,2,149,18,0,32,0,101,112,114,45,49,51,48,52,49,46,54,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,44,64,167,208,18,0,32,0,101,112,114,45,49,51,48,52,57,46,54,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,108,11,156,91,18,0,32,0,101,112,114,45,49,51,48,54,49,46,56,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,59,236,149,123,18,0,32,0,101,112,114,45,49,51,48,54,57,46,49,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,240,56,245,225,18,0,32,0,101,112,114,45,49,51,48,53,55,46,55,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,238,239,186,115,18,0,32,0,101,112,114,45,49,51,48,54,53,46,49,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,85,166,55,137,18,0,32,0,101,112,114,45,49,51,54,50,52,46,49,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,45,63,243,239,4,0,16,1,101,112,114,45,49,51,48,51,54,46,49,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,108,194,144,120,11,0,64,0,101,112,114,45,49,51,48,51,53,46,49,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,62,161,159,0,11,0,64,0,101,112,114,45,49,51,54,50,53,46,49,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,210,31,231,250,11,0,64,0,12,0,0,0,255,255,243,0,0,0,0,0,13,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,3,0,224,21,4,0,12,0,0,0,1,3,2,0,128,47,8,0,12,0,0,0,1,3,3,0,160,39,8,0,12,0,0,0,1,3,1,0,176,33,8,0,0,0,0,0,254,0,2,0,168,234,7,0,12,0,0,0,1,4,4,0,96,135,7,0,12,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,9,0,112,123,8,0,12,0,0,0,1,240,240,0,192,255,2,0,12,0,0,0,1,240,224,0,208,75,4,0,12,0,0,0,1,240,208,0,8,49,4,0,12,0,0,0,1,240,192,0,152,21,4,0,12,0,0,0,1,240,176,0,72,246,3,0,12,0,0,0,1,240,160,0,72,0,3,0,12,0,0,0,1,240,144,0,232,99,5,0,12,0,0,0,1,240,128,0,208,7,8,0,12,0,0,0,1,240,112,0,176,2,8,0,0,0,0,0,254,0,16,0,200,87,7,0,13,0,0,0,1,15,15,0,128,230,7,0,13,0,0,0,1,15,14,0,184,164,6,0,13,0,0,0,1,15,13,0,80,74,6,0,13,0,0,0,1,15,12,0,192,32,6,0,13,0,0,0,1,15,11,0,192,234,2,0,13,0,0,0,1,15,10,0,32,242,5,0,13,0,0,0,1,15,9,0,176,192,2,0,13,0,0,0,1,15,8,0,248,175,2,0,13,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,13,0,0,0,1,240,240,0,128,230,7,0,13,0,0,0,1,240,224,0,184,164,6,0,13,0,0,0,1,240,208,0,80,74,6,0,13,0,0,0,1,240,192,0,192,32,6,0,13,0,0,0,1,240,176,0,192,234,2,0,13,0,0,0,1,240,160,0,32,242,5,0,13,0,0,0,1,240,144,0,176,192,2,0,13,0,0,0,1,240,128,0,248,175,2,0,13,0,0,0,1,240,0,0,208,236,2,0,0,0,0,0,17,0,0,0,255,255,255,0,0,0,0,0,18,0,0,0,255,255,247,0,0,0,0,0,0,0,0,0,254,0,8,0,200,87,7,0,17,0,0,0,1,7,0,0,96,135,3,0,17,0,0,0,1,7,4,0,32,136,7,0,17,0,0,0,1,7,2,0,40,88,7,0,17,0,0,0,1,7,6,0,96,39,7,0,17,0,0,0,1,7,7,0,144,251,6,0,17,0,0,0,1,7,3,0,184,164,6,0,17,0,0,0,1,7,5,0,80,74,6,0,17,0,0,0,1,7,1,0,192,32,6,0,0,0,0,0,254,0,8,0,160,123,6,0,17,0,0,0,1,56,0,0,96,135,3,0,17,0,0,0,1,56,32,0,32,136,7,0,17,0,0,0,1,56,16,0,40,88,7,0,17,0,0,0,1,56,48,0,96,39,7,0,17,0,0,0,1,56,56,0,144,251,6,0,17,0,0,0,1,56,24,0,184,164,6,0,17,0,0,0,1,56,40,0,80,74,6,0,17,0,0,0,1,56,8,0,192,32,6,0,0,0,0,0,254,0,2,0,144,3,8,0,17,0,0,0,1,64,64,0,96,135,7,0,17,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,50,5,0,17,0,0,0,1,128,128,0,96,135,7,0,17,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,18,0,0,0,1,3,0,0,208,75,4,0,18,0,0,0,1,3,3,0,8,49,4,0,18,0,0,0,1,3,1,0,152,21,4,0,18,0,0,0,1,3,2,0,72,246,3,0,0,0,0,0,254,0,2,0,168,234,7,0,18,0,0,0,1,4,0,0,96,135,7,0,18,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,254,0,2,0,200,30,2,0,18,0,0,0,1,8,0,0,120,97,1,0,18,0,0,0,1,8,8,0,96,19,1,0,0,0,0,0,254,0,2,0,144,212,8,0,18,0,0,0,1,64,64,0,96,135,7,0,18,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,160,226,3,0,18,0,0,0,1,128,128,0,96,135,7,0,18,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,103,103,119,117,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,178,94,114,172,1,0,16,1,103,103,119,117,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,65,47,57,1,0,16,1,103,103,119,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,66,214,57,50,1,0,16,1,103,103,119,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,164,48,85,16,5,0,32,0,103,103,119,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,185,74,119,158,5,0,32,0,103,103,119,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,164,11,110,70,5,0,32,0,103,103,119,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,234,141,12,132,5,0,32,0,103,103,119,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,213,81,99,76,10,0,16,1,103,103,119,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,245,172,114,225,12,0,64,0,103,103,119,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,143,78,238,75,12,0,64,0,101,97,115,116,95,49,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,229,228,116,174,2,0,16,1,101,97,115,116,95,51,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,22,33,207,139,2,0,16,1,101,97,115,116,95,50,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,208,180,148,221,2,0,16,1,101,97,115,116,95,52,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,10,49,71,166,2,0,16,1,101,97,115,116,95,53,46,49,55,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,244,181,74,178,9,0,16,1,101,97,115,116,95,56,46,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,40,206,238,117,15,0,32,0,101,97,115,116,95,55,46,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,106,167,121,177,15,0,32,0,101,97,115,116,95,57,46,51,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,152,104,94,92,15,0,32,0,101,97,115,116,95,54,46,51,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,233,48,219,82,15,0,32,0,101,97,115,116,45,49,49,46,49,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,150,31,17,146,24,0,64,0,101,97,115,116,45,49,48,46,49,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,25,196,10,202,25,0,64,0,21,0,0,0,255,255,223,0,0,0,0,0,22,0,0,0,255,255,152,0,0,0,0,0,0,0,0,0,254,0,4,0,200,87,7,0,21,0,0,0,1,3,1,0,104,236,7,0,21,0,0,0,1,3,3,0,128,230,7,0,21,0,0,0,1,3,0,0,120,211,6,0,21,0,0,0,1,3,2,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,21,0,0,0,1,12,4,0,104,236,7,0,21,0,0,0,1,12,12,0,128,230,7,0,21,0,0,0,1,12,0,0,120,211,6,0,21,0,0,0,1,12,8,0,184,164,6,0,0,0,0,0,254,0,4,0,72,202,5,0,21,0,0,0,1,96,96,0,80,246,3,0,21,0,0,0,1,96,64,0,80,124,6,0,21,0,0,0,1,96,32,0,112,212,3,0,21,0,0,0,1,96,0,0,248,160,5,0,0,0,0,0,254,0,2,0,160,165,8,0,21,0,0,0,1,128,128,0,96,135,7,0,21,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,22,0,0,0,1,1,1,0,96,135,7,0,22,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,22,0,0,0,1,2,0,0,96,135,7,0,22,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,22,0,0,0,1,4,4,0,96,135,7,0,22,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,22,0,0,0,1,24,24,0,8,49,4,0,22,0,0,0,1,24,16,0,152,21,4,0,22,0,0,0,1,24,8,0,72,246,3,0,22,0,0,0,1,24,0,0,72,0,3,0,0,0,0,0,254,0,2,0,0,150,8,0,22,0,0,0,1,32,32,0,8,208,6,0,22,0,0,0,1,32,0,0,88,204,6,0,0,0,0,0,254,0,2,0,128,112,3,0,22,0,0,0,1,64,0,0,168,22,4,0,22,0,0,0,1,64,64,0,224,247,3,0,0,0,0,0,254,0,2,0,232,75,4,0,22,0,0,0,1,128,128,0,96,135,7,0,22,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,115,121,115,95,114,111,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,16,94,170,46,0,0,16,1,99,103,95,114,111,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,65,166,85,237,0,0,32,0,99,103,95,114,111,109,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,5,140,145,99,0,0,32,0,112,99,109,95,114,111,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,171,84,168,65,0,0,64,0,56,57,99,52,48,53,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,16,16,168,86,7,0,1,0,0,0,232,47,216,0,248,191,2,0,24,38,7,0,1,0,0,0,236,47,216,0,184,160,2,0,56,210,6,0,1,0,0,0,35,48,216,0,192,135,2,0,24,163,6,0,1,0,0,0,34,48,216,0,240,108,2,0,152,122,6,0,1,0,0,0,33,48,216,0,96,82,2,0,192,72,6,0,1,0,0,0,32,48,216,0,32,56,2,0,112,135,2,0,1,0,0,0,36,48,216,0,152,30,2,0,248,97,5,0,1,0,0,0,37,48,216,0,232,10,2,0,40,246,1,0,1,0,0,0,233,47,216,0,64,246,1,0,144,236,1,0,1,0,0,0,237,47,216,0,136,224,1,0,176,223,1,0,1,0,0,0,43,48,216,0,72,198,1,0,192,209,1,0,1,0,0,0,42,48,216,0,24,182,1,0,24,198,1,0,1,0,0,0,41,48,216,0,40,167,1,0,120,189,1,0,1,0,0,0,40,48,216,0,200,149,1,0,16,193,8,0,1,0,0,0,44,48,216,0,56,126,1,0,32,167,1,0,1,0,0,0,45,48,216,0,32,101,1,0,88,212,3,0,1,0,0,0,144,46,216,0,40,185,3,0,16,17,8,0,1,0,0,0,234,47,216,0,224,12,8,0,72,65,1,0,9,0,0,0,232,48,216,0,32,58,1,0,48,50,1,0,9,0,0,0,224,48,216,0,32,58,1,0,224,41,1,0,9,0,0,0,216,48,216,0,32,58,1,0,112,97,99,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,112,140,51,25,1,0,16,1,112,97,99,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,77,7,219,24,1,0,16,1,112,97,99,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,29,139,185,171,1,0,16,1,112,97,99,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,142,199,3,36,1,0,16,1,98,108,112,97,99,49,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,11,50,237,178,5,0,32,0,98,108,112,97,99,49,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,196,178,136,171,5,0,32,0,98,108,112,97,99,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,114,91,164,68,6,0,32,0,98,108,112,97,99,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,159,101,132,250,6,0,32,0,103,104,111,115,116,109,117,110,46,99,108,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,227,71,150,117,7,0,32,0,12,0,0,0,255,255,0,0,0,0,0,0,13,0,0,0,255,255,64,0,0,0,0,0,14,0,0,0,255,255,6,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,12,0,0,0,1,32,0,0,120,97,1,0,12,0,0,0,1,32,32,0,96,19,1,0,0,0,0,0,254,0,4,0,64,37,5,0,13,0,0,0,1,192,64,0,176,116,6,0,13,0,0,0,1,192,128,0,80,113,6,0,13,0,0,0,1,192,192,0,80,110,6,0,13,0,0,0,1,192,0,0,120,7,5,0,0,0,0,0,254,0,4,0,32,4,2,0,14,0,0,0,1,3,0,0,224,127,8,0,14,0,0,0,1,3,2,0,32,123,8,0,14,0,0,0,1,3,1,0,192,110,8,0,14,0,0,0,1,3,3,0,104,151,6,0,0,0,0,0,254,0,4,0,128,129,4,0,14,0,0,0,1,12,12,0,192,255,2,0,14,0,0,0,1,12,8,0,208,75,4,0,14,0,0,0,1,12,4,0,8,49,4,0,14,0,0,0,1,12,0,0,152,21,4,0,0,0,0,0,168,86,7,0,1,0,0,0,195,236,146,0,248,191,2,0,24,38,7,0,1,0,0,0,208,237,146,0,184,160,2,0,56,210,6,0,1,0,0,0,136,250,146,0,192,135,2,0,24,163,6,0,1,0,0,0,137,250,146,0,240,108,2,0,152,122,6,0,1,0,0,0,138,250,146,0,96,82,2,0,192,72,6,0,1,0,0,0,139,250,146,0,32,56,2,0,200,110,3,0,1,0,0,0,140,250,146,0,152,30,2,0,120,89,3,0,1,0,0,0,141,250,146,0,232,10,2,0,40,246,1,0,1,0,0,0,194,236,146,0,64,246,1,0,144,236,1,0,1,0,0,0,209,237,146,0,136,224,1,0,176,223,1,0,1,0,0,0,96,242,146,0,72,198,1,0,192,209,1,0,1,0,0,0,97,242,146,0,24,182,1,0,24,198,1,0,1,0,0,0,98,242,146,0,40,167,1,0,120,189,1,0,1,0,0,0,99,242,146,0,200,149,1,0,224,22,1,0,1,0,0,0,100,242,146,0,56,126,1,0,160,14,1,0,1,0,0,0,101,242,146,0,32,101,1,0,88,212,3,0,1,0,0,0,104,215,146,0,40,185,3,0,72,65,1,0,9,0,0,0,112,3,147,0,32,58,1,0,48,50,1,0,9,0,0,0,113,3,147,0,32,58,1,0,101,112,114,45,49,49,53,49,49,46,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,214,134,10,216,1,0,16,1,101,112,114,45,49,49,53,49,48,46,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,244,190,177,210,1,0,16,1,101,112,114,45,49,49,53,49,53,46,56,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,207,117,88,216,9,0,16,1,101,112,114,45,49,49,53,49,52,46,56,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,25,105,204,61,9,0,16,1,101,112,114,45,49,49,53,49,51,46,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,119,193,139,225,17,0,16,1,101,112,114,45,49,49,53,49,50,46,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,62,230,16,96,17,0,16,1,109,112,114,45,49,49,52,54,56,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,165,156,202,116,3,0,32,0,109,112,114,45,49,49,52,54,55,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,54,231,96,110,3,0,32,0,101,112,114,45,49,49,54,57,53,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,190,100,168,56,3,0,32,0,101,112,114,45,49,49,54,57,52,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,132,123,41,126,3,0,32,0,109,112,114,45,49,49,52,54,57,46,54,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,153,34,122,237,18,0,32,0,109,112,114,45,49,49,52,55,48,46,55,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,80,165,222,52,18,0,32,0,109,112,114,45,49,49,52,55,55,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,83,70,120,162,18,0,32,0,109,112,114,45,49,49,52,55,56,46,55,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,147,137,119,139,18,0,32,0,109,112,114,45,49,49,52,55,49,46,56,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,105,64,151,241,18,0,32,0,109,112,114,45,49,49,52,55,50,46,49,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,154,64,36,13,18,0,32,0,109,112,114,45,49,49,52,55,57,46,56,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,138,19,214,236,18,0,32,0,109,112,114,45,49,49,52,56,48,46,49,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,197,102,173,100,18,0,32,0,109,112,114,45,49,49,52,55,51,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,236,198,56,5,18,0,32,0,109,112,114,45,49,49,52,55,52,46,55,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,80,60,146,235,18,0,32,0,109,112,114,45,49,49,52,56,49,46,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,182,82,230,120,18,0,32,0,109,112,114,45,49,49,52,56,50,46,55,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,102,151,135,47,18,0,32,0,109,112,114,45,49,49,52,55,53,46,56,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,137,236,207,105,18,0,32,0,109,112,114,45,49,49,52,55,54,46,49,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,121,155,11,166,18,0,32,0,109,112,114,45,49,49,52,56,51,46,56,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,5,165,211,213,18,0,32,0,109,112,114,45,49,49,52,56,52,46,49,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,80,106,165,184,18,0,32,0,101,112,114,45,49,49,54,57,54,46,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,158,228,232,153,18,0,32,0,101,112,114,45,49,49,54,57,55,46,55,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,46,197,69,117,18,0,32,0,101,112,114,45,49,49,55,48,48,46,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,193,57,56,225,18,0,32,0,101,112,114,45,49,49,55,48,49,46,54,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,101,211,179,159,18,0,32,0,101,112,114,45,49,49,54,57,56,46,56,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,226,163,235,207,18,0,32,0,101,112,114,45,49,49,54,57,57,46,49,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,74,83,0,74,18,0,32,0,101,112,114,45,49,49,55,48,50,46,56,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,39,198,9,42,18,0,32,0,101,112,114,45,49,49,55,48,51,46,49,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,159,125,187,67,18,0,32,0,101,112,114,45,49,49,53,50,52,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,159,132,53,93,18,0,32,0,101,112,114,45,49,49,53,50,53,46,55,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,82,117,228,154,18,0,32,0,101,112,114,45,49,49,53,51,50,46,54,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,219,93,86,179,18,0,32,0,101,112,114,45,49,49,53,51,51,46,54,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,138,110,209,245,18,0,32,0,101,112,114,45,49,49,53,50,54,46,56,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,240,179,76,9,18,0,32,0,101,112,114,45,49,49,53,50,55,46,49,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,68,161,33,232,18,0,32,0,101,112,114,45,49,49,53,51,52,46,55,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,124,173,240,183,18,0,32,0,101,112,114,45,49,49,53,51,53,46,49,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,70,122,218,149,18,0,32,0,101,112,114,45,49,49,54,57,51,46,49,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,92,120,151,4,4,0,16,1,109,112,114,45,49,49,52,54,53,46,49,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,171,109,67,225,11,0,64,0,101,112,114,45,49,49,53,49,54,46,49,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,127,225,208,25,11,0,64,0,101,112,114,45,49,49,56,49,52,46,49,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,118,211,5,11,11,0,64,0,103,116,45,106,50,46,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,107,11,218,162,0,0,16,1,103,116,45,106,51,46,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,142,174,160,193,0,0,16,1,103,116,49,53,46,98,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,18,36,101,172,0,0,32,0,112,105,56,57,49,52,46,98,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,135,97,125,32,0,0,32,0,112,105,56,57,49,54,46,104,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,246,224,255,124,0,0,32,0,112,105,56,57,49,48,46,107,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,11,27,16,90,0,0,32,0,103,116,53,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,115,178,58,61,0,0,32,0,103,116,49,49,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,240,252,240,180,0,0,32,0,103,116,49,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,147,192,164,128,0,0,64,0,103,116,52,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,236,185,223,133,0,0,64,0,184,40,2,0,1,0,0,0,18,236,146,0,248,191,2,0,184,164,8,0,1,0,0,0,19,236,146,0,64,246,1,0,24,38,7,0,1,0,0,0,16,236,146,0,184,160,2,0,152,122,6,0,1,0,0,0,120,1,147,0,96,82,2,0,192,72,6,0,1,0,0,0,121,1,147,0,32,56,2,0,24,163,6,0,1,0,0,0,122,1,147,0,240,108,2,0,56,210,6,0,1,0,0,0,123,1,147,0,192,135,2,0,200,110,3,0,1,0,0,0,201,248,146,0,152,30,2,0,120,89,3,0,1,0,0,0,200,248,146,0,232,10,2,0,144,236,1,0,1,0,0,0,17,236,146,0,136,224,1,0,24,198,1,0,1,0,0,0,168,240,146,0,40,167,1,0,120,189,1,0,1,0,0,0,169,240,146,0,200,149,1,0,192,209,1,0,1,0,0,0,170,240,146,0,24,182,1,0,176,223,1,0,1,0,0,0,171,240,146,0,72,198,1,0,224,22,1,0,1,0,0,0,121,237,146,0,56,126,1,0,160,14,1,0,1,0,0,0,120,237,146,0,32,101,1,0,88,212,3,0,1,0,0,0,248,220,146,0,40,185,3,0,248,5,8,0,9,0,0,0,206,187,145,0,32,58,1,0,144,250,7,0,9,0,0,0,207,187,145,0,32,58,1,0,248,241,7,0,9,0,0,0,208,187,145,0,32,58,1,0,72,82,8,0,9,0,0,0,209,187,145,0,32,58,1,0,18,0,0,0,255,255,255,0,0,0,0,0,19,0,0,0,255,255,86,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,18,0,0,0,1,15,2,0,80,252,6,0,18,0,0,0,1,15,5,0,16,242,7,0,18,0,0,0,1,15,8,0,104,236,7,0,18,0,0,0,1,15,4,0,120,113,6,0,18,0,0,0,1,15,1,0,232,228,5,0,18,0,0,0,1,15,15,0,128,230,7,0,18,0,0,0,1,15,3,0,56,141,7,0,18,0,0,0,1,15,7,0,120,211,6,0,18,0,0,0,1,15,14,0,184,164,6,0,18,0,0,0,1,15,6,0,24,1,7,0,18,0,0,0,1,15,13,0,80,74,6,0,18,0,0,0,1,15,12,0,192,32,6,0,18,0,0,0,1,15,11,0,192,234,2,0,18,0,0,0,1,15,10,0,32,242,5,0,18,0,0,0,1,15,9,0,176,192,2,0,18,0,0,0,1,15,0,0,16,227,4,0,0,0,0,0,254,0,15,0,160,123,6,0,18,0,0,0,1,240,32,0,80,252,6,0,18,0,0,0,1,240,80,0,16,242,7,0,18,0,0,0,1,240,128,0,104,236,7,0,18,0,0,0,1,240,64,0,120,113,6,0,18,0,0,0,1,240,16,0,232,228,5,0,18,0,0,0,1,240,240,0,128,230,7,0,18,0,0,0,1,240,48,0,56,141,7,0,18,0,0,0,1,240,112,0,120,211,6,0,18,0,0,0,1,240,224,0,184,164,6,0,18,0,0,0,1,240,96,0,24,1,7,0,18,0,0,0,1,240,208,0,80,74,6,0,18,0,0,0,1,240,192,0,192,32,6,0,18,0,0,0,1,240,176,0,192,234,2,0,18,0,0,0,1,240,160,0,32,242,5,0,18,0,0,0,1,240,144,0,176,192,2,0,0,0,0,0,254,0,4,0,128,129,4,0,19,0,0,0,1,3,3,0,208,75,4,0,19,0,0,0,1,3,2,0,8,49,4,0,19,0,0,0,1,3,1,0,72,246,3,0,19,0,0,0,1,3,0,0,64,47,7,0,0,0,0,0,254,0,2,0,216,246,4,0,19,0,0,0,1,4,4,0,136,66,4,0,19,0,0,0,1,4,0,0,176,63,4,0,0,0,0,0,254,0,4,0,64,37,5,0,19,0,0,0,1,24,24,0,96,116,4,0,19,0,0,0,1,24,16,0,184,91,4,0,19,0,0,0,1,24,8,0,208,26,6,0,19,0,0,0,1,24,0,0,48,20,6,0,0,0,0,0,254,0,4,0,72,202,5,0,19,0,0,0,1,96,96,0,80,246,3,0,19,0,0,0,1,96,64,0,248,38,7,0,19,0,0,0,1,96,32,0,48,123,8,0,19,0,0,0,1,96,0,0,8,117,8,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,128,128,0,96,135,7,0,19,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,20,0,0,0,1,4,4,0,96,135,7,0,20,0,0,0,1,4,0,0,152,182,7,0,49,51,54,48,51,55,45,49,51,48,55,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,67,135,254,70,0,0,16,1,49,51,54,48,51,55,45,49,51,48,56,46,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,196,21,110,39,0,0,16,1,49,51,54,48,51,55,45,50,48,53,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,81,237,153,109,0,0,16,1,49,51,54,48,51,55,45,50,48,54,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,145,173,94,84,0,0,16,1,49,51,54,48,51,55,45,49,52,48,57,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,156,65,184,111,0,0,16,1,49,51,54,48,51,55,45,49,52,49,48,46,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,160,210,27,147,0,0,16,1,49,51,54,48,51,55,45,49,50,48,46,49,54,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,204,243,231,110,0,0,16,1,49,51,54,48,51,55,45,49,49,57,46,49,54,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,31,134,25,250,0,0,16,1,49,51,54,48,51,55,45,49,48,52,46,54,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,89,91,42,158,0,0,32,0,49,51,54,48,51,55,45,49,49,49,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,51,15,112,145,0,0,32,0,49,51,54,48,51,55,45,49,49,50,46,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,190,48,147,134,0,0,32,0,49,51,54,48,51,55,45,49,49,51,46,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,168,208,151,212,0,0,32,0,49,51,54,48,51,55,45,49,49,52,46,49,109,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,130,152,239,41,0,0,32,0,49,51,54,48,51,55,45,49,49,53,46,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,152,184,16,149,0,0,32,0,49,51,54,48,51,55,45,49,49,54,46,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,91,172,224,17,0,0,32,0,49,51,54,48,51,55,45,49,49,55,46,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,65,219,165,41,0,0,32,0,49,51,54,48,51,55,45,49,49,56,46,50,109,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,99,178,243,139,0,0,32,0,55,52,115,52,55,50,45,49,51,54,48,51,55,45,49,48,49,46,55,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,111,247,100,41,0,0,32,0,55,52,115,52,55,50,45,49,51,54,48,51,55,45,49,48,50,46,53,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,108,236,79,77,0,0,32,0,55,52,115,50,56,55,45,49,51,54,48,51,55,45,49,48,51,46,52,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,8,207,92,108,0,0,32,0,49,51,54,48,51,55,45,49,51,48,55,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,67,135,254,70,0,0,16,1,49,51,54,48,51,55,45,49,51,48,56,46,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,196,21,110,39,0,0,16,1,49,51,54,48,52,51,45,49,49,48,53,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,71,218,223,69,0,0,16,1,49,51,54,48,52,51,45,49,49,48,54,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,156,2,60,52,0,0,16,1,49,51,54,48,52,52,45,50,49,48,57,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,150,171,2,17,0,0,16,1,49,51,54,48,52,52,45,50,49,49,48,46,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,43,58,32,210,0,0,16,1,49,51,54,48,52,52,45,50,49,50,49,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,215,130,57,117,0,0,16,1,49,51,54,48,52,52,45,50,49,50,50,46,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,234,73,145,135,0,0,16,1,49,51,54,48,52,51,45,49,49,50,48,46,49,54,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,6,16,115,92,0,0,16,1,49,51,54,48,52,51,45,49,49,49,57,46,49,54,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,231,145,53,220,0,0,16,1,49,51,54,48,52,51,45,49,49,48,52,46,54,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,111,207,67,19,0,0,32,0,49,51,54,48,52,51,45,49,49,49,49,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,35,110,223,9,0,0,32,0,49,51,54,48,51,55,45,49,49,50,46,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,190,48,147,134,0,0,32,0,49,51,54,48,52,51,45,49,49,50,51,46,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,1,143,201,228,0,0,32,0,49,51,54,48,52,51,45,49,49,49,51,46,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,110,71,203,51,0,0,32,0,49,51,54,48,51,55,45,49,49,52,46,49,109,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,130,152,239,41,0,0,32,0,49,51,54,48,52,51,45,49,49,50,52,46,49,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,121,120,133,196,0,0,32,0,49,51,54,48,52,51,45,49,49,49,53,46,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,3,37,30,247,0,0,32,0,49,51,54,48,51,55,45,49,49,54,46,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,91,172,224,17,0,0,32,0,49,51,54,48,52,51,45,49,49,50,53,46,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,209,194,194,217,0,0,32,0,49,51,54,48,52,51,45,49,49,49,55,46,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,233,178,48,158,0,0,32,0,49,51,54,48,51,55,45,49,49,56,46,50,109,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,99,178,243,139,0,0,32,0,49,51,54,48,52,51,45,49,49,50,54,46,50,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,42,115,44,163,0,0,32,0,55,52,115,52,55,50,45,49,51,54,48,51,55,45,49,48,49,46,55,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,111,247,100,41,0,0,32,0,55,52,115,52,55,50,45,49,51,54,48,51,55,45,49,48,50,46,53,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,108,236,79,77,0,0,32,0,55,52,115,50,56,55,45,49,51,54,48,51,55,45,49,48,51,46,52,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,8,207,92,108,0,0,32,0,17,0,0,0,255,255,255,0,0,0,0,0,18,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,200,87,7,0,17,0,0,0,1,3,0,0,88,154,8,0,17,0,0,0,1,3,1,0,200,92,8,0,17,0,0,0,1,3,3,0,56,37,8,0,17,0,0,0,1,3,2,0,96,240,7,0,0,0,0,0,254,0,4,0,160,123,6,0,17,0,0,0,1,12,0,0,88,154,8,0,17,0,0,0,1,12,4,0,200,92,8,0,17,0,0,0,1,12,12,0,56,37,8,0,17,0,0,0,1,12,8,0,96,240,7,0,0,0,0,0,254,0,2,0,168,234,7,0,17,0,0,0,1,32,0,0,96,135,7,0,17,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,17,0,0,0,1,64,64,0,96,135,7,0,17,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,128,129,4,0,18,0,0,0,1,1,1,0,8,49,4,0,18,0,0,0,1,1,0,0,72,246,3,0,0,0,0,0,254,0,2,0,232,21,1,0,18,0,0,0,1,2,2,0,96,135,7,0,18,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,18,0,0,0,1,12,4,0,80,246,3,0,18,0,0,0,1,12,12,0,248,38,7,0,18,0,0,0,1,12,8,0,112,212,3,0,18,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,103,97,108,116,117,114,98,111,46,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,103,170,243,232,1,0,16,1,103,97,108,120,46,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,78,6,22,188,1,0,16,1,115,117,112,101,114,103,46,119,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,174,189,234,221,1,0,16,1,103,97,108,116,117,114,98,111,46,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,15,69,79,164,1,0,16,1,103,97,108,116,117,114,98,111,46,122,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,212,243,71,50,1,0,16,1,103,97,108,116,117,114,98,111,46,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,26,253,19,167,4,0,32,0,103,97,108,116,117,114,98,111,46,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,144,23,81,40,4,0,32,0,54,108,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,103,148,172,195,7,0,32,0,7,0,0,0,255,255,255,0,0,0,0,0,8,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,72,202,5,0,7,0,0,0,1,3,2,0,80,246,3,0,7,0,0,0,1,3,3,0,248,38,7,0,7,0,0,0,1,3,1,0,112,212,3,0,7,0,0,0,1,3,0,0,24,99,5,0,0,0,0,0,254,0,4,0,152,194,7,0,7,0,0,0,1,12,4,0,64,146,7,0,7,0,0,0,1,12,12,0,80,99,7,0,7,0,0,0,1,12,8,0,96,49,7,0,7,0,0,0,1,12,0,0,120,7,5,0,0,0,0,0,254,0,2,0,64,219,6,0,7,0,0,0,1,16,16,0,248,38,7,0,7,0,0,0,1,16,0,0,112,212,3,0,0,0,0,0,254,0,2,0,8,175,6,0,7,0,0,0,1,32,32,0,96,135,7,0,7,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,7,0,0,0,1,64,0,0,96,135,7,0,7,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,0,0,200,87,7,0,8,0,0,0,1,7,2,0,32,136,7,0,8,0,0,0,1,7,3,0,40,88,7,0,8,0,0,0,1,7,4,0,96,39,7,0,8,0,0,0,1,7,1,0,96,106,5,0,8,0,0,0,1,7,7,0,144,251,6,0,8,0,0,0,1,7,6,0,216,43,5,0,8,0,0,0,1,7,0,0,248,13,5,0,8,0,0,0,1,7,5,0,184,164,6,0,0,0,0,0,254,0,8,0,160,123,6,0,8,0,0,0,1,56,16,0,32,136,7,0,8,0,0,0,1,56,24,0,40,88,7,0,8,0,0,0,1,56,32,0,96,39,7,0,8,0,0,0,1,56,8,0,96,106,5,0,8,0,0,0,1,56,56,0,144,251,6,0,8,0,0,0,1,56,48,0,216,43,5,0,8,0,0,0,1,56,0,0,248,13,5,0,8,0,0,0,1,56,40,0,184,164,6,0,0,0,0,0,254,0,8,0,72,167,4,0,8,0,0,0,1,192,0,0,208,75,4,0,8,0,0,0,1,192,192,0,8,49,4,0,8,0,0,0,1,192,128,0,152,21,4,0,8,0,0,0,1,192,64,0,72,246,3,0,112,109,49,49,48,46,52,109,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,23,107,174,0,0,16,1,112,109,49,48,57,46,52,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,45,121,93,184,0,0,16,1,112,109,49,49,50,46,115,117,98,105,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,88,43,151,123,0,0,16,1,112,109,49,49,49,46,115,117,98,105,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,141,41,183,78,0,0,16,1,112,109,48,48,52,101,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,188,82,175,211,0,0,16,1,112,109,48,48,53,101,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,12,101,236,215,0,0,16,1,112,109,48,48,48,101,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,63,15,34,93,0,0,16,1,112,109,48,48,49,101,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,177,62,67,144,0,0,16,1,112,109,48,48,50,101,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,152,232,62,113,0,0,16,1,112,109,48,48,51,101,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,253,96,176,107,0,0,16,1,112,109,48,48,54,101,46,54,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,55,192,174,87,0,0,32,0,112,109,48,48,56,101,46,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,155,55,217,0,0,64,0,112,109,48,48,55,101,46,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,80,121,237,199,0,0,64,0,17,0,0,0,255,255,0,0,0,0,0,0,18,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,136,101,2,0,17,0,0,0,1,4,0,0,96,135,7,0,17,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,254,0,4,0,184,40,2,0,17,0,0,0,1,48,0,0,200,201,5,0,17,0,0,0,1,48,16,0,224,67,5,0,17,0,0,0,1,48,32,0,216,36,5,0,17,0,0,0,1,48,48,0,8,7,5,0,0,0,0,0,254,0,4,0,184,164,8,0,17,0,0,0,1,192,0,0,152,160,5,0,17,0,0,0,1,192,64,0,144,127,5,0,17,0,0,0,1,192,128,0,168,98,5,0,17,0,0,0,1,192,192,0,224,189,3,0,0,0,0,0,254,0,4,0,72,202,5,0,18,0,0,0,1,3,0,0,248,38,7,0,18,0,0,0,1,3,1,0,80,246,3,0,18,0,0,0,1,3,2,0,112,212,3,0,18,0,0,0,1,3,3,0,248,160,5,0,0,0,0,0,254,0,4,0,128,129,4,0,18,0,0,0,1,48,0,0,8,49,4,0,18,0,0,0,1,48,16,0,152,21,4,0,18,0,0,0,1,48,32,0,208,75,4,0,18,0,0,0,1,48,48,0,72,246,3,0,0,0,0,0,254,0,2,0,136,60,8,0,18,0,0,0,1,128,0,0,96,135,7,0,18,0,0,0,1,128,128,0,152,182,7,0,19,0,0,0,255,255,247,0,0,0,0,0,20,0,0,0,255,255,251,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,2,2,0,96,135,7,0,19,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,4,4,0,96,135,7,0,19,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,8,8,0,96,135,7,0,19,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,8,0,200,87,7,0,19,0,0,0,1,48,0,0,32,136,7,0,19,0,0,0,1,48,16,0,40,88,7,0,19,0,0,0,1,48,16,0,96,39,7,0,19,0,0,0,1,48,32,0,96,39,7,0,19,0,0,0,1,48,48,0,144,251,6,0,19,0,0,0,1,48,48,0,144,251,6,0,19,0,0,0,1,48,0,0,120,211,6,0,19,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,8,0,160,123,6,0,19,0,0,0,1,192,64,0,96,39,7,0,19,0,0,0,1,192,192,0,144,251,6,0,19,0,0,0,1,192,0,0,120,211,6,0,19,0,0,0,1,192,128,0,184,164,6,0,19,0,0,0,1,192,192,0,184,164,6,0,19,0,0,0,1,192,128,0,80,74,6,0,19,0,0,0,1,192,64,0,192,32,6,0,19,0,0,0,1,192,0,0,32,242,5,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,3,2,0,80,246,3,0,20,0,0,0,1,3,3,0,80,124,6,0,20,0,0,0,1,3,1,0,112,212,3,0,20,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,64,37,5,0,20,0,0,0,1,12,8,0,112,68,8,0,20,0,0,0,1,12,12,0,232,64,8,0,20,0,0,0,1,12,4,0,160,59,8,0,20,0,0,0,1,12,0,0,128,54,8,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,48,32,0,192,255,2,0,20,0,0,0,1,48,16,0,208,75,4,0,20,0,0,0,1,48,48,0,8,49,4,0,20,0,0,0,1,48,0,0,152,21,4,0,0,0,0,0,254,0,2,0,96,46,8,0,20,0,0,0,1,128,128,0,80,39,8,0,20,0,0,0,1,128,0,0,80,33,8,0,0,0,0,0,117,101,49,55,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,187,61,88,178,0,0,16,1,117,100,49,55,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,104,54,10,71,0,0,16,1,103,97,108,104,115,116,108,53,46,117,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,21,143,161,68,0,0,32,0,103,97,108,104,115,116,108,49,46,117,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,144,135,132,35,0,0,64,0,103,97,108,104,115,116,108,50,46,117,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,74,229,104,33,0,0,64,0,19,0,0,0,255,255,0,0,0,0,0,0,20,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,19,0,0,0,1,3,3,0,72,0,3,0,19,0,0,0,1,3,2,0,64,47,7,0,19,0,0,0,1,3,0,0,232,99,5,0,19,0,0,0,1,3,1,0,208,7,8,0,0,0,0,0,254,0,2,0,200,135,2,0,19,0,0,0,1,64,64,0,96,135,7,0,19,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,136,101,2,0,19,0,0,0,1,128,0,0,96,135,7,0,19,0,0,0,1,128,128,0,152,182,7,0,0,0,0,0,254,0,8,0,32,4,2,0,20,0,0,0,1,7,0,0,200,201,5,0,20,0,0,0,1,7,1,0,152,160,5,0,20,0,0,0,1,7,2,0,144,127,5,0,20,0,0,0,1,7,3,0,144,138,3,0,20,0,0,0,1,7,4,0,88,198,1,0,20,0,0,0,1,7,5,0,224,67,5,0,20,0,0,0,1,7,6,0,216,36,5,0,20,0,0,0,1,7,7,0,8,7,5,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,24,8,0,80,246,3,0,20,0,0,0,1,24,0,0,248,38,7,0,20,0,0,0,1,24,16,0,112,212,3,0,20,0,0,0,1,24,24,0,248,160,5,0,0,0,0,0,254,0,4,0,96,239,1,0,20,0,0,0,1,96,96,0,176,227,1,0,20,0,0,0,1,96,64,0,168,212,1,0,20,0,0,0,1,96,0,0,96,201,1,0,20,0,0,0,1,96,32,0,8,191,1,0,103,97,108,109,105,100,119,46,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,97,45,94,116,1,0,16,1,103,97,108,109,105,100,119,46,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,64,154,153,156,1,0,16,1,103,97,108,109,105,100,119,46,119,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,37,73,137,181,1,0,16,1,103,97,108,109,105,100,119,46,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,11,161,60,107,1,0,16,1,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,7,50,147,27,1,0,16,1,49,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,164,67,251,57,4,0,32,0,49,107,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,162,86,63,126,4,0,32,0,54,108,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,103,148,172,195,7,0,32,0,12,0,0,0,255,255,0,0,0,0,0,0,13,0,0,0,255,255,0,0,0,0,0,0,14,0,0,0,255,255,4,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,12,0,0,0,1,32,0,0,120,97,1,0,12,0,0,0,1,32,32,0,96,19,1,0,0,0,0,0,254,0,2,0,232,75,4,0,12,0,0,0,1,64,0,0,96,135,7,0,12,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,4,0,32,4,2,0,13,0,0,0,1,192,64,0,224,127,8,0,13,0,0,0,1,192,0,0,32,123,8,0,13,0,0,0,1,192,128,0,192,110,8,0,13,0,0,0,1,192,192,0,104,151,6,0,0,0,0,0,254,0,4,0,64,37,5,0,14,0,0,0,1,3,0,0,176,114,3,0,14,0,0,0,1,3,1,0,176,116,6,0,14,0,0,0,1,3,2,0,32,160,1,0,14,0,0,0,1,3,3,0,80,110,6,0,0,0,0,0,254,0,2,0,128,129,4,0,14,0,0,0,1,4,0,0,208,75,4,0,14,0,0,0,1,4,4,0,8,49,4,0,49,46,98,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,116,183,55,204,1,0,16,1,50,46,98,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,3,31,210,198,1,0,16,1,51,46,98,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,22,128,226,48,1,0,16,1,52,46,98,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,112,119,126,222,1,0,16,1,53,46,98,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,25,201,22,169,1,0,16,1,54,46,98,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,43,136,117,145,1,0,16,1,55,46,98,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,218,185,55,18,1,0,16,1,56,46,98,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,7,54,197,120,1,0,16,1,57,46,98,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,204,148,24,144,1,0,16,1,49,48,46,98,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,149,246,118,88,1,0,16,1,49,49,46,98,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,164,67,251,57,4,0,32,0,49,50,46,98,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,162,86,63,126,4,0,32,0,54,108,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,103,148,172,195,7,0,32,0,51,50,48,48,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,83,176,240,62,0,0,16,1,51,51,48,48,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,49,8,40,27,0,0,16,1,51,52,48,48,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,51,61,35,22,0,0,16,1,51,53,48,48,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,35,92,175,10,0,0,16,1,51,54,48,48,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,118,110,85,188,0,0,16,1,51,55,48,48,103,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,164,10,127,176,0,0,16,1,50,54,48,48,106,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,124,244,178,88,0,0,32,0,50,56,48,48,108,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,128,124,68,173,0,0,32,0,50,55,48,48,107,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,252,26,111,221,0,0,32,0,112,114,111,109,45,53,46,53,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,107,60,96,84,0,0,32,0,112,114,111,109,45,52,46,50,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,171,237,182,89,0,0,32,0,112,114,111,109,45,51,46,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,107,187,4,74,0,0,32,0,112,114,111,109,45,49,46,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,180,21,40,122,0,0,32,0,112,114,111,109,45,50,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,32,0,12,0,0,0,255,255,128,0,0,0,0,0,13,0,0,0,255,255,247,0,0,0,0,0,14,0,0,0,255,255,151,0,0,0,0,0,0,0,0,0,254,0,2,0,232,75,4,0,12,0,0,0,1,128,128,0,96,135,7,0,12,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,160,226,6,0,13,0,0,0,1,1,0,0,0,183,6,0,13,0,0,0,1,1,1,0,240,242,5,0,0,0,0,0,254,0,4,0,72,202,5,0,13,0,0,0,1,6,6,0,80,246,3,0,13,0,0,0,1,6,0,0,80,124,6,0,13,0,0,0,1,6,2,0,112,212,3,0,13,0,0,0,1,6,4,0,248,160,5,0,0,0,0,0,254,0,2,0,168,234,7,0,13,0,0,0,1,8,8,0,96,135,7,0,13,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,2,0,72,4,1,0,13,0,0,0,1,16,16,0,96,135,7,0,13,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,2,0,32,150,8,0,13,0,0,0,1,32,32,0,96,135,7,0,13,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,200,30,2,0,13,0,0,0,1,128,128,0,120,97,1,0,13,0,0,0,1,128,0,0,96,19,1,0,0,0,0,0,254,0,8,0,32,4,2,0,14,0,0,0,1,7,4,0,144,102,8,0,14,0,0,0,1,7,2,0,176,45,8,0,14,0,0,0,1,7,6,0,224,127,8,0,14,0,0,0,1,7,7,0,32,123,8,0,14,0,0,0,1,7,1,0,248,116,8,0,14,0,0,0,1,7,3,0,192,110,8,0,14,0,0,0,1,7,5,0,96,102,7,0,14,0,0,0,1,7,0,0,104,151,6,0,0,0,0,0,254,0,8,0,64,37,5,0,14,0,0,0,1,56,32,0,184,45,5,0,14,0,0,0,1,56,24,0,24,144,3,0,14,0,0,0,1,56,16,0,232,15,5,0,14,0,0,0,1,56,48,0,88,97,3,0,14,0,0,0,1,56,56,0,136,81,3,0,14,0,0,0,1,56,8,0,112,67,3,0,14,0,0,0,1,56,40,0,152,52,3,0,14,0,0,0,1,56,0,0,120,7,5,0,0,0,0,0,254,0,4,0,128,129,4,0,14,0,0,0,1,192,0,0,208,75,4,0,14,0,0,0,1,192,128,0,8,49,4,0,14,0,0,0,1,192,64,0,152,21,4,0,14,0,0,0,1,192,192,0,72,246,3,0,0,0,0,0,109,107,50,45,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,226,161,206,35,0,0,16,1,109,107,50,45,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,26,91,105,137,0,0,16,1,51,52,48,48,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,51,61,35,22,0,0,16,1,109,107,50,45,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,245,103,183,36,0,0,16,1,103,103,49,45,53,46,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,205,252,2,49,0,0,16,1,103,103,49,45,55,98,46,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,107,104,22,208,0,0,16,1,103,103,49,45,57,46,52,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,124,244,178,88,0,0,32,0,103,103,49,45,49,49,46,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,128,124,68,173,0,0,32,0,103,103,49,45,49,48,46,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,252,26,111,221,0,0,32,0,112,114,111,109,45,53,46,53,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,107,60,96,84,0,0,32,0,112,114,111,109,45,52,46,50,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,171,237,182,89,0,0,32,0,112,114,111,109,45,51,46,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,107,187,4,74,0,0,32,0,112,114,111,109,45,49,46,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,180,21,40,122,0,0,32,0,112,114,111,109,45,50,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,32,0,51,50,48,48,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,83,176,240,62,0,0,16,1,51,51,48,48,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,49,8,40,27,0,0,16,1,51,52,48,48,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,51,61,35,22,0,0,16,1,51,53,48,48,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,35,92,175,10,0,0,16,1,51,54,48,48,102,97,115,116,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,229,134,213,35,0,0,16,1,51,55,48,48,103,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,164,10,127,176,0,0,16,1,50,54,48,48,106,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,124,244,178,88,0,0,32,0,50,56,48,48,108,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,128,124,68,173,0,0,32,0,50,55,48,48,107,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,252,26,111,221,0,0,32,0,112,114,111,109,45,53,46,53,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,107,60,96,84,0,0,32,0,112,114,111,109,45,52,46,50,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,171,237,182,89,0,0,32,0,112,114,111,109,45,51,46,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,107,187,4,74,0,0,32,0,112,114,111,109,45,49,46,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,180,21,40,122,0,0,32,0,112,114,111,109,45,50,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,32,0,15,0,0,0,255,255,63,0,0,0,0,0,0,0,0,0,254,0,8,0,0,70,2,0,15,0,0,0,1,7,1,0,88,154,8,0,15,0,0,0,1,7,2,0,200,92,8,0,15,0,0,0,1,7,3,0,152,141,7,0,15,0,0,0,1,7,7,0,56,37,8,0,15,0,0,0,1,7,4,0,24,46,7,0,15,0,0,0,1,7,6,0,96,240,7,0,15,0,0,0,1,7,5,0,128,188,7,0,15,0,0,0,1,7,0,0,200,82,2,0,0,0,0,0,254,0,7,0,72,202,5,0,15,0,0,0,1,56,48,0,248,80,6,0,15,0,0,0,1,56,40,0,80,246,3,0,15,0,0,0,1,56,56,0,248,38,7,0,15,0,0,0,1,56,32,0,168,237,4,0,15,0,0,0,1,56,24,0,80,233,4,0,15,0,0,0,1,56,16,0,152,228,4,0,15,0,0,0,1,56,8,0,32,225,4,0,0,0,0,0,254,0,2,0,40,73,5,0,15,0,0,0,1,64,64,0,96,135,7,0,15,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,208,20,3,0,15,0,0,0,1,128,128,0,72,196,4,0,15,0,0,0,1,128,0,0,32,76,3,0,20,0,0,0,255,255,255,0,0,0,0,0,21,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,232,75,4,0,20,0,0,0,1,1,1,0,96,135,7,0,20,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,20,0,0,0,1,2,2,0,96,135,7,0,20,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,8,0,160,123,6,0,20,0,0,0,1,28,0,0,40,88,7,0,20,0,0,0,1,28,16,0,96,39,7,0,20,0,0,0,1,28,28,0,144,251,6,0,20,0,0,0,1,28,12,0,184,164,6,0,20,0,0,0,1,28,20,0,80,74,6,0,20,0,0,0,1,28,4,0,192,32,6,0,20,0,0,0,1,28,24,0,192,234,2,0,20,0,0,0,1,28,8,0,32,242,5,0,0,0,0,0,254,0,8,0,200,87,7,0,20,0,0,0,1,224,0,0,40,88,7,0,20,0,0,0,1,224,128,0,96,39,7,0,20,0,0,0,1,224,224,0,144,251,6,0,20,0,0,0,1,224,96,0,184,164,6,0,20,0,0,0,1,224,160,0,80,74,6,0,20,0,0,0,1,224,32,0,192,32,6,0,20,0,0,0,1,224,192,0,192,234,2,0,20,0,0,0,1,224,64,0,32,242,5,0,0,0,0,0,254,0,2,0,168,234,7,0,21,0,0,0,1,1,0,0,96,135,7,0,21,0,0,0,1,1,1,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,21,0,0,0,1,2,0,0,56,111,3,0,21,0,0,0,1,2,2,0,104,134,3,0,0,0,0,0,254,0,2,0,16,227,4,0,21,0,0,0,1,4,4,0,96,135,7,0,21,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,72,4,1,0,21,0,0,0,1,8,8,0,96,135,7,0,21,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,21,0,0,0,1,48,16,0,80,246,3,0,21,0,0,0,1,48,48,0,248,38,7,0,21,0,0,0,1,48,32,0,112,212,3,0,21,0,0,0,1,48,0,0,248,160,5,0,0,0,0,0,254,0,4,0,128,129,4,0,21,0,0,0,1,192,128,0,192,255,2,0,21,0,0,0,1,192,192,0,208,75,4,0,21,0,0,0,1,192,64,0,8,49,4,0,21,0,0,0,1,192,0,0,152,21,4,0,98,49,52,45,54,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,63,148,76,40,2,0,16,1,98,49,52,45,54,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,150,97,207,84,2,0,16,1,98,49,52,45,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,216,233,87,101,1,0,16,1,98,49,52,45,54,57,46,56,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,227,82,214,6,0,16,1,98,49,52,45,55,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,39,23,8,247,6,0,16,1,98,49,52,45,50,53,46,54,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,239,40,171,158,9,0,16,1,98,49,52,45,48,55,46,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,255,95,2,198,12,0,32,0,98,49,52,45,48,54,46,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,110,83,226,180,12,0,32,0,98,49,52,45,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,55,111,165,132,17,0,32,0,98,49,52,45,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,107,24,137,104,17,0,32,0,98,49,52,45,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,113,158,237,209,17,0,32,0,98,49,52,45,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,25,5,63,182,17,0,32,0,98,49,52,45,51,48,46,56,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,127,12,203,220,23,0,32,0,98,49,52,45,50,56,46,49,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,174,208,17,223,26,0,64,0,98,49,52,45,50,57,46,49,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,231,131,217,122,26,0,64,0,98,49,52,45,51,49,46,57,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,61,1,107,92,0,0,0,8,15,0,0,0,255,255,255,0,0,0,0,0,16,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,200,30,2,0,15,0,0,0,1,3,3,0,224,6,8,0,15,0,0,0,1,3,2,0,120,97,1,0,15,0,0,0,1,3,1,0,128,2,8,0,15,0,0,0,1,3,0,0,240,250,7,0,0,0,0,0,254,0,2,0,232,75,4,0,15,0,0,0,1,4,4,0,96,135,7,0,15,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,15,0,0,0,1,8,0,0,96,135,7,0,15,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,15,0,0,0,1,48,16,0,104,236,7,0,15,0,0,0,1,48,48,0,128,230,7,0,15,0,0,0,1,48,0,0,120,211,6,0,15,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,15,0,0,0,1,192,64,0,104,236,7,0,15,0,0,0,1,192,192,0,128,230,7,0,15,0,0,0,1,192,0,0,120,211,6,0,15,0,0,0,1,192,128,0,184,164,6,0,0,0,0,0,254,0,4,0,56,242,7,0,16,0,0,0,1,12,0,0,160,236,7,0,16,0,0,0,1,12,4,0,168,230,7,0,16,0,0,0,1,12,12,0,176,226,7,0,16,0,0,0,1,12,8,0,40,223,7,0,0,0,0,0,254,0,4,0,80,219,7,0,16,0,0,0,1,48,32,0,208,75,4,0,16,0,0,0,1,48,48,0,8,49,4,0,16,0,0,0,1,48,16,0,152,21,4,0,16,0,0,0,1,48,0,0,72,246,3,0,0,0,0,0,254,0,2,0,104,159,3,0,16,0,0,0,1,64,64,0,96,135,7,0,16,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,48,112,3,0,16,0,0,0,1,128,0,0,80,245,6,0,16,0,0,0,1,128,128,0,240,240,6,0,0,0,0,0,102,115,116,97,114,102,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,230,29,199,148,0,0,16,1,102,115,116,97,114,102,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,97,119,160,177,0,0,16,1,102,115,116,97,114,102,48,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,53,83,55,84,0,0,32,0,102,115,116,97,114,102,48,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,231,129,162,119,0,0,32,0,102,115,116,97,114,102,48,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,13,146,138,57,0,0,32,0,102,115,116,97,114,102,48,57,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,210,65,19,213,0,0,32,0,102,115,116,97,114,102,48,54,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,135,14,228,7,0,0,32,0,102,115,116,97,114,102,48,55,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,225,93,173,224,0,0,80,0,102,115,116,97,114,102,48,56,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,147,86,173,240,0,0,64,0,17,0,0,0,255,255,255,0,0,0,0,0,18,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,120,183,1,0,17,0,0,0,1,3,3,0,80,245,6,0,17,0,0,0,1,3,2,0,8,201,6,0,17,0,0,0,1,3,1,0,200,197,6,0,17,0,0,0,1,3,0,0,152,194,6,0,0,0,0,0,254,0,4,0,96,176,1,0,17,0,0,0,1,12,0,0,80,252,6,0,17,0,0,0,1,12,4,0,16,242,7,0,17,0,0,0,1,12,8,0,104,236,7,0,17,0,0,0,1,12,12,0,80,245,6,0,0,0,0,0,254,0,2,0,48,5,1,0,17,0,0,0,1,16,16,0,96,135,7,0,17,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,2,0,16,115,7,0,17,0,0,0,1,32,0,0,96,135,7,0,17,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,8,253,8,0,17,0,0,0,1,64,0,0,96,135,7,0,17,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,16,227,4,0,17,0,0,0,1,128,128,0,96,135,7,0,17,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,4,0,248,239,8,0,18,0,0,0,1,3,0,0,208,75,4,0,18,0,0,0,1,3,3,0,8,49,4,0,18,0,0,0,1,3,2,0,152,21,4,0,18,0,0,0,1,3,1,0,72,246,3,0,0,0,0,0,254,0,4,0,72,202,5,0,18,0,0,0,1,12,8,0,80,246,3,0,18,0,0,0,1,12,12,0,80,124,6,0,18,0,0,0,1,12,4,0,112,212,3,0,18,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,4,0,32,224,8,0,18,0,0,0,1,48,0,0,16,208,8,0,18,0,0,0,1,48,16,0,248,81,6,0,18,0,0,0,1,48,48,0,176,64,8,0,18,0,0,0,1,48,32,0,128,65,6,0,0,0,0,0,254,0,4,0,64,37,5,0,18,0,0,0,1,192,192,0,64,189,8,0,18,0,0,0,1,192,128,0,24,184,8,0,18,0,0,0,1,192,64,0,96,175,8,0,18,0,0,0,1,192,0,0,216,166,8,0,118,105,100,95,100,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,110,6,3,193,1,0,16,1,118,105,100,95,101,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,148,192,139,240,1,0,16,1,118,105,100,95,102,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,248,47,122,99,1,0,16,1,118,105,100,95,104,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,165,39,192,4,1,0,16,1,118,105,100,95,106,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,116,190,223,251,1,0,16,1,118,105,100,95,108,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,225,137,67,138,1,0,16,1,102,114,111,103,103,101,114,46,54,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,86,2,171,232,2,0,16,1,102,114,111,103,103,101,114,46,54,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,143,164,128,115,2,0,16,1,102,114,111,103,103,101,114,46,54,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,39,235,215,49,2,0,16,1,102,114,111,103,103,101,114,46,54,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,131,216,247,5,4,0,32,0,101,112,114,45,49,48,51,54,46,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,248,69,135,101,4,0,32,0,112,114,45,57,49,46,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,191,3,55,65,7,0,32,0,72,23,4,0,1,0,0,0,253,0,147,0,248,191,2,0,56,250,6,0,1,0,0,0,248,0,147,0,184,160,2,0,88,149,7,0,1,0,0,0,249,0,147,0,136,224,1,0,192,72,6,0,1,0,0,0,88,248,146,0,32,56,2,0,152,122,6,0,1,0,0,0,89,248,146,0,96,82,2,0,200,110,3,0,1,0,0,0,81,240,146,0,152,30,2,0,120,89,3,0,1,0,0,0,80,240,146,0,232,10,2,0,88,212,3,0,1,0,0,0,64,220,146,0,40,185,3,0,248,5,8,0,9,0,0,0,96,6,147,0,32,58,1,0,102,108,112,111,105,110,116,46,48,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,20,245,109,77,1,0,16,1,102,108,112,111,105,110,116,46,48,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,232,46,255,77,1,0,16,1,102,108,112,111,105,110,116,46,48,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,125,114,57,197,2,0,32,0,102,108,112,111,105,110,116,46,48,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,176,184,192,130,2,0,32,0,102,108,112,111,105,110,116,46,48,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,174,38,36,82,2,0,32,0,49,50,53,57,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,243,65,64,74,3,0,32,0,49,50,53,57,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,118,230,97,105,3,0,32,0,102,108,112,111,105,110,116,46,48,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,254,224,184,197,4,0,16,1,98,111,111,116,50,46,48,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,176,209,0,108,1,0,16,1,98,111,111,116,50,46,48,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,4,215,252,193,1,0,16,1,102,108,112,111,105,110,116,46,48,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,125,114,57,197,2,0,32,0,102,108,112,111,105,110,116,46,48,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,176,184,192,130,2,0,32,0,102,108,112,111,105,110,116,46,48,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,174,38,36,82,2,0,32,0,49,50,53,57,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,243,65,64,74,3,0,32,0,49,50,53,57,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,118,230,97,105,3,0,32,0,102,108,112,111,105,110,116,46,48,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,254,224,184,197,4,0,16,1,56,50,115,49,50,57,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,150,45,194,167,0,0,0,8,56,50,115,49,50,51,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,189,248,188,88,0,0,0,8,102,112,111,105,110,116,98,106,95,103,97,108,49,54,118,56,95,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,44,41,127,186,0,0,0,8,102,112,111,105,110,116,98,106,95,103,97,108,49,54,118,56,95,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,225,177,26,206,0,0,0,8,102,112,111,105,110,116,98,106,95,103,97,108,50,48,118,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,24,0,0,0,0,32,0,0,0,64,0,0,0,96,0,0,0,128,0,0,0,160,0,0,0,192,0,0,0,224,0,0,0,0,2,0,0,32,2,0,0,64,2,0,0,96,2,0,0,128,2,0,0,160,2,0,0,192,2,0,0,224,2,0,0,0,0,0,0,4,0,0,0,8,0,0,0,12,0,0,0,16,0,0,0,20,0,0,0,24,0,0,0,28,0,0,0,0,1,0,0,4,1,0,0,8,1,0,0,12,1,0,0,16,1,0,0,20,1,0,0,24,1,0,0,28,1,0,0,108,119,49,49,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,183,32,233,115,1,0,16,1,108,119,49,53,46,49,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,45,1,215,80,1,0,16,1,108,119,49,48,46,49,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,148,89,164,190,1,0,16,1,108,119,49,52,46,49,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,57,35,155,83,1,0,16,1,108,119,45,48,55,46,49,48,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,38,42,37,253,2,0,16,1,108,119,95,50,46,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,238,95,215,75,4,0,32,0,108,119,95,49,46,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,133,20,244,101,4,0,32,0,108,119,45,48,56,46,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,60,228,168,37,4,0,32,0,108,119,45,48,53,46,54,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,215,47,85,228,4,0,32,0,108,119,95,51,48,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,78,149,133,179,4,0,32,0,108,119,95,50,57,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,198,26,218,123,4,0,32,0,108,119,95,52,46,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,127,117,207,80,4,0,32,0,108,119,95,51,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,120,242,62,192,4,0,32,0,108,119,95,51,50,46,57,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,21,122,150,48,4,0,32,0,108,119,95,51,49,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,251,55,157,196,4,0,32,0,108,119,45,48,50,46,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,200,197,230,67,4,0,32,0,108,119,95,49,52,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,206,44,134,130,4,0,32,0,108,119,95,49,51,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,150,14,28,184,4,0,32,0,108,119,45,48,54,46,57,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,252,223,158,91,4,0,32,0,108,119,95,50,54,46,49,48,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,50,208,188,87,4,0,32,0,108,119,95,50,53,46,49,48,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,84,21,201,186,4,0,32,0,108,119,95,49,54,46,49,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,84,101,178,64,4,0,32,0,108,119,95,49,53,46,49,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,7,46,125,27,4,0,32,0,108,119,95,50,56,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,48,173,5,168,4,0,32,0,108,119,95,50,55,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,210,27,60,16,4,0,32,0,108,119,95,48,48,46,49,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,99,42,223,89,3,0,16,0,108,119,45,48,51,117,46,49,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,31,5,125,128,5,0,64,0,108,119,45,48,52,117,46,49,51,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,142,9,205,230,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,108,119,54,50,49,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,233,108,236,94,0,0,0,8,108,119,105,111,46,49,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,12,185,82,173,0,0,0,8,18,0,0,0,255,255,0,0,0,0,0,0,19,0,0,0,255,255,3,0,0,0,0,0,20,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,8,0,200,87,7,0,18,0,0,0,1,7,7,0,80,252,6,0,18,0,0,0,1,7,6,0,16,242,7,0,18,0,0,0,1,7,5,0,104,236,7,0,18,0,0,0,1,7,0,0,128,230,7,0,18,0,0,0,1,7,1,0,184,164,6,0,18,0,0,0,1,7,2,0,80,74,6,0,18,0,0,0,1,7,3,0,192,32,6,0,18,0,0,0,1,7,4,0,32,242,5,0,0,0,0,0,254,0,8,0,160,123,6,0,18,0,0,0,1,56,56,0,80,252,6,0,18,0,0,0,1,56,48,0,16,242,7,0,18,0,0,0,1,56,40,0,104,236,7,0,18,0,0,0,1,56,0,0,128,230,7,0,18,0,0,0,1,56,8,0,184,164,6,0,18,0,0,0,1,56,16,0,80,74,6,0,18,0,0,0,1,56,24,0,192,32,6,0,18,0,0,0,1,56,32,0,32,242,5,0,0,0,0,0,254,0,2,0,40,111,8,0,18,0,0,0,1,64,64,0,96,135,7,0,18,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,120,207,1,0,18,0,0,0,1,128,0,0,96,135,7,0,18,0,0,0,1,128,128,0,152,182,7,0,0,0,0,0,254,0,8,0,72,202,5,0,19,0,0,0,1,7,0,0,72,198,6,0,19,0,0,0,1,7,1,0,208,75,4,0,19,0,0,0,1,7,2,0,8,49,4,0,19,0,0,0,1,7,3,0,72,195,6,0,19,0,0,0,1,7,4,0,72,246,3,0,19,0,0,0,1,7,5,0,72,0,3,0,19,0,0,0,1,7,6,0,64,47,7,0,19,0,0,0,1,7,7,0,48,173,6,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,64,0,0,96,135,7,0,19,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,72,4,1,0,19,0,0,0,1,128,0,0,96,135,7,0,19,0,0,0,1,128,128,0,152,182,7,0,99,56,48,45,49,49,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,251,48,134,247,2,0,16,1,99,56,48,45,49,48,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,203,9,193,50,2,0,16,1,99,56,48,45,49,50,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,239,111,212,128,2,0,16,1,99,56,48,45,49,52,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,40,72,172,64,2,0,16,1,99,56,48,45,49,53,46,55,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,215,127,170,5,9,0,16,1,99,56,48,45,48,52,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,140,254,23,154,12,0,32,0,99,56,48,45,48,53,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,113,112,222,172,12,0,32,0,99,56,48,45,48,49,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,230,130,55,244,15,0,32,0,99,56,48,45,48,50,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,97,139,10,6,15,0,32,0,99,56,48,45,48,51,46,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,213,56,153,96,24,0,64,0,37,0,0,0,255,255,254,0,0,0,0,0,38,0,0,0,255,255,127,0,0,0,0,0,0,0,0,0,254,0,2,0,128,150,4,0,37,0,0,0,1,1,1,0,56,148,4,0,37,0,0,0,1,1,0,0,136,144,4,0,0,0,0,0,254,0,2,0,144,212,8,0,37,0,0,0,1,2,2,0,96,135,7,0,37,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,37,0,0,0,1,4,4,0,96,135,7,0,37,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,37,0,0,0,1,8,0,0,96,135,7,0,37,0,0,0,1,8,8,0,152,182,7,0])
.concat([0,0,0,0,254,0,4,0,200,87,7,0,37,0,0,0,1,48,0,0,80,252,6,0,37,0,0,0,1,48,16,0,16,242,7,0,37,0,0,0,1,48,32,0,104,236,7,0,37,0,0,0,1,48,48,0,128,230,7,0,0,0,0,0,254,0,4,0,160,123,6,0,37,0,0,0,1,192,192,0,8,201,6,0,37,0,0,0,1,192,128,0,200,197,6,0,37,0,0,0,1,192,64,0,152,194,6,0,37,0,0,0,1,192,0,0,248,189,6,0,0,0,0,0,254,0,4,0,72,202,5,0,38,0,0,0,1,3,2,0,80,246,3,0,38,0,0,0,1,3,3,0,248,38,7,0,38,0,0,0,1,3,1,0,112,212,3,0,38,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,48,142,4,0,38,0,0,0,1,12,0,0,56,138,4,0,38,0,0,0,1,12,12,0,8,134,4,0,38,0,0,0,1,12,4,0,24,130,4,0,38,0,0,0,1,12,8,0,136,127,4,0,0,0,0,0,254,0,4,0,200,30,2,0,38,0,0,0,1,48,48,0,240,242,5,0,38,0,0,0,1,48,32,0,136,176,4,0,38,0,0,0,1,48,16,0,72,173,4,0,38,0,0,0,1,48,0,0,80,169,4,0,0,0,0,0,254,0,2,0,104,159,3,0,38,0,0,0,1,64,0,0,96,135,7,0,38,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,168,124,4,0,38,0,0,0,1,128,0,0,248,38,7,0,38,0,0,0,1,128,128,0,160,122,4,0,0,0,0,0,101,112,114,45,54,54,50,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,70,245,31,178,0,0,16,1,101,112,114,45,54,54,50,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,241,139,58,19,0,0,16,1,101,112,114,45,53,56,54,57,46,49,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,78,13,34,109,0,0,16,1,101,112,114,45,53,56,54,56,46,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,107,37,2,116,0,0,32,0,101,112,114,45,53,56,54,55,46,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,48,233,92,47,0,0,32,0,101,112,114,45,53,56,54,54,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,154,29,127,150,0,0,32,0,101,112,114,45,53,56,54,53,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,76,163,217,3,0,0,32,0,101,112,114,45,53,56,54,52,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,88,243,89,230,0,0,32,0,101,112,114,45,53,56,54,51,46,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,21,202,150,164,0,0,32,0,101,112,114,45,53,56,53,53,46,49,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,161,148,248,181,0,0,32,0,101,112,114,45,53,56,53,54,46,49,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,143,247,106,38,0,0,32,0,112,114,45,53,51,49,55,46,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,184,80,131,100,0,0,0,8,105,99,49,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,92,39,17,112,0,0,16,1,105,99,49,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,45,1,237,231,0,0,16,1,105,99,49,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,209,140,233,197,0,0,16,1,105,99,49,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,194,34,81,14,0,0,16,1,101,112,114,45,53,56,54,57,46,49,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,78,13,34,109,0,0,16,1,101,112,114,45,53,56,54,56,46,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,107,37,2,116,0,0,32,0,101,112,114,45,53,56,54,55,46,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,48,233,92,47,0,0,32,0,101,112,114,45,53,56,54,54,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,154,29,127,150,0,0,32,0,101,112,114,45,53,56,54,53,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,76,163,217,3,0,0,32,0,101,112,114,45,53,56,54,52,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,88,243,89,230,0,0,32,0,101,112,114,45,53,56,54,51,46,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,21,202,150,164,0,0,32,0,101,112,114,45,53,56,53,53,46,49,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,161,148,248,181,0,0,32,0,101,112,114,45,53,56,53,54,46,49,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,143,247,106,38,0,0,32,0,112,114,45,53,51,49,55,46,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,184,80,131,100,0,0,0,8,184,40,2,0,1,0,0,0,128,93,148,0,248,191,2,0,56,250,6,0,1,0,0,0,132,93,148,0,184,160,2,0,184,164,8,0,1,0,0,0,129,93,148,0,64,246,1,0,88,149,7,0,1,0,0,0,133,93,148,0,136,224,1,0,152,122,6,0,1,0,0,0,151,93,148,0,96,82,2,0,192,72,6,0,1,0,0,0,150,93,148,0,32,56,2,0,48,123,2,0,1,0,0,0,146,93,148,0,152,30,2,0,24,198,1,0,1,0,0,0,143,93,148,0,40,167,1,0,120,189,1,0,1,0,0,0,142,93,148,0,200,149,1,0,248,187,8,0,1,0,0,0,138,93,148,0,56,126,1,0,88,212,3,0,1,0,0,0,248,26,149,0,40,185,3,0,16,17,8,0,1,0,0,0,131,93,148,0,224,12,8,0,80,251,6,0,1,0,0,0,130,93,148,0,216,70,1,0,248,5,8,0,9,0,0,0,112,99,215,0,32,58,1,0,144,250,7,0,9,0,0,0,113,99,215,0,32,58,1,0,101,112,114,45,55,49,54,55,46,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,51,215,90,207,0,0,16,1,101,112,114,45,55,49,54,56,46,52,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,31,133,196,0,0,0,16,1,101,112,114,45,55,49,54,57,46,52,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,247,184,240,30,0,0,16,1,101,112,114,45,55,49,55,48,46,52,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,222,83,93,136,0,0,16,1,101,112,114,45,55,49,54,51,46,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,77,19,226,238,0,0,16,1,101,112,114,45,55,49,54,52,46,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,34,205,224,229,0,0,16,1,101,112,114,45,55,49,54,53,46,50,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,94,254,211,76,0,0,16,1,101,112,114,45,55,49,54,54,46,50,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,57,163,44,85,0,0,16,1,101,112,114,45,55,49,55,55,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,47,5,169,220,0,0,32,0,101,112,114,45,55,49,55,56,46,57,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,192,98,91,47,0,0,32,0,101,112,114,45,55,49,55,57,46,49,48,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,181,73,187,143,0,0,32,0,101,112,114,45,55,49,56,48,46,49,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,195,229,168,38,0,0,32,0,101,112,114,45,55,49,55,49,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,161,242,202,98,0,0,32,0,101,112,114,45,55,49,55,50,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,16,138,247,16,0,0,32,0,101,112,114,45,55,49,55,51,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,89,29,234,54,0,0,32,0,101,112,114,45,55,49,55,52,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,55,216,39,245,0,0,32,0,101,112,114,45,55,49,55,53,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,193,228,118,186,0,0,32,0,101,112,114,45,55,49,55,54,46,49,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,25,214,149,240,0,0,32,0,55,49,54,49,46,49,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,63,4,196,2,0,0,32,0,55,49,54,48,46,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,209,56,89,34,0,0,32,0,55,49,53,57,46,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,211,28,10,30,0,0,32,0,55,49,54,50,46,53,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,159,226,226,204,0,0,32,0,98,112,114,46,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,1,146,163,131,0,0,32,0,18,0,0,0,255,255,175,0,0,0,0,0,19,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,18,0,0,0,1,3,3,0,8,49,4,0,18,0,0,0,1,3,2,0,152,21,4,0,18,0,0,0,1,3,1,0,72,246,3,0,18,0,0,0,1,3,0,0,72,0,3,0,0,0,0,0,254,0,2,0,64,37,5,0,18,0,0,0,1,4,4,0,200,201,3,0,18,0,0,0,1,4,0,0,248,104,1,0,0,0,0,0,254,0,2,0,232,129,2,0,18,0,0,0,1,8,8,0,96,135,7,0,18,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,18,0,0,0,1,16,16,0,96,135,7,0,18,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,2,0,112,104,5,0,18,0,0,0,1,32,32,0,96,135,7,0,18,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,200,30,2,0,18,0,0,0,1,64,0,0,120,97,1,0,18,0,0,0,1,64,64,0,96,19,1,0,0,0,0,0,254,0,2,0,72,4,1,0,18,0,0,0,1,128,128,0,96,135,7,0,18,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,8,0,200,87,7,0,19,0,0,0,1,7,2,0,224,127,8,0,19,0,0,0,1,7,1,0,136,252,1,0,19,0,0,0,1,7,7,0,32,123,8,0,19,0,0,0,1,7,6,0,192,110,8,0,19,0,0,0,1,7,5,0,96,102,7,0,19,0,0,0,1,7,4,0,184,105,6,0,19,0,0,0,1,7,3,0,192,100,6,0,19,0,0,0,1,7,0,0,104,151,6,0,0,0,0,0,254,0,8,0,160,123,6,0,19,0,0,0,1,56,0,0,96,164,8,0,19,0,0,0,1,56,8,0,144,102,8,0,19,0,0,0,1,56,16,0,176,45,8,0,19,0,0,0,1,56,24,0,224,127,8,0,19,0,0,0,1,56,56,0,32,123,8,0,19,0,0,0,1,56,32,0,232,143,1,0,19,0,0,0,1,56,48,0,192,110,8,0,19,0,0,0,1,56,40,0,96,102,7,0,0,0,0,0,26,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,232,75,4,0,26,0,0,0,1,4,0,0,96,135,7,0,26,0,0,0,1,4,4,0,152,182,7,0,19,0,0,0,255,255,1,0,0,0,0,0,20,0,0,0,255,255,0,0,0,0,0,0,21,0,0,0,255,255,2,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,19,0,0,0,1,1,1,0,120,97,1,0,19,0,0,0,1,1,0,0,96,19,1,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,2,0,0,96,135,7,0,19,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,8,8,0,96,135,7,0,19,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,19,0,0,0,1,48,48,0,32,136,7,0,19,0,0,0,1,48,32,0,40,88,7,0,19,0,0,0,1,48,16,0,96,39,7,0,19,0,0,0,1,48,0,0,144,251,6,0,0,0,0,0,254,0,4,0,160,123,6,0,19,0,0,0,1,192,0,0,184,164,6,0,19,0,0,0,1,192,64,0,80,74,6,0,19,0,0,0,1,192,128,0,192,32,6,0,19,0,0,0,1,192,192,0,32,242,5,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,3,1,0,80,246,3,0,20,0,0,0,1,3,0,0,80,124,6,0,20,0,0,0,1,3,2,0,112,212,3,0,20,0,0,0,1,3,3,0,248,160,5,0,0,0,0,0,254,0,4,0,64,37,5,0,20,0,0,0,1,12,4,0,112,37,5,0,20,0,0,0,1,12,0,0,192,7,5,0,20,0,0,0,1,12,8,0,208,227,4,0,20,0,0,0,1,12,12,0,120,7,5,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,48,48,0,208,75,4,0,20,0,0,0,1,48,0,0,8,49,4,0,20,0,0,0,1,48,32,0,152,21,4,0,20,0,0,0,1,48,16,0,72,246,3,0,0,0,0,0,254,0,2,0,144,246,3,0,20,0,0,0,1,64,0,0,96,135,7,0,20,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,20,0,0,0,1,128,128,0,56,111,3,0,20,0,0,0,1,128,0,0,104,134,3,0,0,0,0,0,254,0,3,0,120,185,3,0,21,0,0,0,1,6,2,0,8,234,2,0,21,0,0,0,1,6,4,0,160,134,3,0,21,0,0,0,1,6,0,0,112,111,3,0,0,0,0,0,18,0,0,0,255,255,255,0,0,0,0,0,19,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,232,75,4,0,18,0,0,0,1,1,1,0,96,135,7,0,18,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,6,0,72,202,5,0,18,0,0,0,1,14,6,0,160,203,8,0,18,0,0,0,1,14,8,0,80,246,3,0,18,0,0,0,1,14,14,0,248,38,7,0,18,0,0,0,1,14,2,0,112,212,3,0,18,0,0,0,1,14,4,0,248,160,5,0,18,0,0,0,1,14,12,0,24,99,5,0,0,0,0,0,254,0,2,0,168,234,7,0,18,0,0,0,1,16,0,0,96,135,7,0,18,0,0,0,1,16,16,0,152,182,7,0,0,0,0,0,254,0,2,0,240,235,5,0,18,0,0,0,1,32,32,0,208,75,4,0,18,0,0,0,1,32,0,0,8,49,4,0,0,0,0,0,254,0,4,0,128,129,4,0,18,0,0,0,1,192,0,0,192,255,2,0,18,0,0,0,1,192,128,0,208,75,4,0,18,0,0,0,1,192,192,0,8,49,4,0,18,0,0,0,1,192,64,0,152,21,4,0,0,0,0,0,254,0,2,0,48,45,3,0,19,0,0,0,1,2,2,0,168,22,4,0,19,0,0,0,1,2,0,0,232,41,1,0,0,0,0,0,254,0,2,0,16,227,4,0,19,0,0,0,1,4,4,0,96,135,7,0,19,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,4,0,16,217,5,0,19,0,0,0,1,24,24,0,0,212,5,0,19,0,0,0,1,24,8,0,168,207,5,0,19,0,0,0,1,24,16,0,112,203,5,0,19,0,0,0,1,24,0,0,8,199,5,0,0,0,0,0,254,0,8,0,32,4,2,0,19,0,0,0,1,224,0,0,32,136,7,0,19,0,0,0,1,224,128,0,40,88,7,0,19,0,0,0,1,224,64,0,96,39,7,0,19,0,0,0,1,224,192,0,120,113,6,0,19,0,0,0,1,224,224,0,144,251,6,0,19,0,0,0,1,224,32,0,120,211,6,0,19,0,0,0,1,224,96,0,184,164,6,0,19,0,0,0,1,224,160,0,80,74,6,0,0,0,0,0,49,48,46,55,111,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,229,131,204,238,0,0,16,1,57,46,53,111,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,14,100,211,88,0,0,16,1,53,46,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,243,80,164,100,0,0,32,0,54,46,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,204,163,129,114,0,0,32,0,55,46,49,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,66,244,128,236,0,0,32,0,57,46,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,109,49,189,46,0,0,32,0,49,50,46,53,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,97,19,194,75,0,0,64,0,49,49,46,55,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,34,16,51,46,0,0,64,0,56,55,99,53,50,46,109,99,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,16,112,114,111,116,100,97,116,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,6,176,187,213,0,0,16,1,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,40,111,8,0,19,0,0,0,1,1,0,0,96,135,7,0,19,0,0,0,1,1,1,0,152,182,7,0,0,0,0,0,254,0,7,0,232,24,7,0,19,0,0,0,1,56,0,0,168,241,6,0,19,0,0,0,1,56,16,0,224,19,7,0,19,0,0,0,1,56,48,0,64,15,7,0,19,0,0,0,1,56,56,0,224,9,7,0,19,0,0,0,1,56,32,0,88,239,6,0,19,0,0,0,1,56,40,0,144,3,7,0,19,0,0,0,1,56,8,0,80,236,6,0,0,0,0,0,254,0,4,0,112,59,6,0,20,0,0,0,1,12,0,0,176,226,7,0,20,0,0,0,1,12,12,0,144,223,6,0,20,0,0,0,1,12,8,0,48,218,6,0,20,0,0,0,1,12,4,0,200,213,6,0,184,40,2,0,1,0,0,0,122,151,215,0,248,191,2,0,56,250,6,0,1,0,0,0,143,151,215,0,184,160,2,0,184,164,8,0,1,0,0,0,123,151,215,0,64,246,1,0,88,149,7,0,1,0,0,0,135,151,215,0,136,224,1,0,56,210,6,0,1,0,0,0,136,151,215,0,192,135,2,0,24,163,6,0,1,0,0,0,137,151,215,0,240,108,2,0,152,122,6,0,1,0,0,0,138,151,215,0,96,82,2,0,192,72,6,0,1,0,0,0,139,151,215,0,32,56,2,0,48,123,2,0,1,0,0,0,140,151,215,0,152,30,2,0,96,69,2,0,1,0,0,0,141,151,215,0,232,10,2,0,144,55,2,0,1,0,0,0,142,151,215,0,152,138,8,0,80,123,7,0,1,0,0,0,124,151,215,0,48,119,7,0,112,114,7,0,1,0,0,0,125,151,215,0,112,109,7,0,176,223,1,0,1,0,0,0,128,151,215,0,72,198,1,0,192,209,1,0,1,0,0,0,129,151,215,0,24,182,1,0,24,198,1,0,1,0,0,0,130,151,215,0,40,167,1,0,120,189,1,0,1,0,0,0,131,151,215,0,200,149,1,0,248,187,8,0,1,0,0,0,132,151,215,0,56,126,1,0,184,179,8,0,1,0,0,0,133,151,215,0,32,101,1,0,240,173,8,0,1,0,0,0,134,151,215,0,96,32,8,0,208,72,7,0,1,0,0,0,126,151,215,0,16,68,7,0,216,63,7,0,1,0,0,0,127,151,215,0,240,58,7,0,88,212,3,0,1,0,0,0,200,147,215,0,40,185,3,0,16,17,8,0,1,0,0,0,121,151,215,0,224,12,8,0,56,58,1,0,1,0,0,0,120,151,215,0,64,50,1,0,248,5,8,0,9,0,0,0,152,151,215,0,32,58,1,0,144,250,7,0,9,0,0,0,153,151,215,0,32,58,1,0,15,0,0,0,255,255,196,0,0,0,0,0,0,0,0,0,254,0,4,0,200,87,7,0,15,0,0,0,1,3,3,0,40,88,7,0,15,0,0,0,1,3,1,0,96,39,7,0,15,0,0,0,1,3,0,0,144,251,6,0,15,0,0,0,1,3,2,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,15,0,0,0,1,12,4,0,144,251,6,0,15,0,0,0,1,12,0,0,184,164,6,0,15,0,0,0,1,12,8,0,192,32,6,0,15,0,0,0,1,12,12,0,24,193,6,0,0,0,0,0,254,0,2,0,16,146,6,0,15,0,0,0,1,32,0,0,248,81,6,0,15,0,0,0,1,32,32,0,144,55,6,0,0,0,0,0,254,0,2,0,200,30,2,0,15,0,0,0,1,64,64,0,120,97,1,0,15,0,0,0,1,64,0,0,96,19,1,0,0,0,0,0,254,0,2,0,168,234,7,0,15,0,0,0,1,128,0,0,96,135,7,0,15,0,0,0,1,128,128,0,152,182,7,0,102,102,117,95,51,48,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,119,137,152,237,1,0,16,1,102,102,117,95,51,53,46,49,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,33,28,191,7,1,0,16,1,102,102,117,95,51,49,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,118,164,165,219,1,0,16,1,102,102,117,95,51,54,46,49,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,66,245,137,77,1,0,16,1,102,102,45,51,50,109,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,110,105,71,199,2,0,16,1,102,102,45,53,109,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,8,65,40,156,4,0,32,0,102,102,45,55,109,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,251,77,88,167,4,0,32,0,102,102,45,49,109,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,68,94,96,11,4,0,32,0,102,102,45,51,109,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,210,28,41,82,4,0,32,0,102,102,95,50,51,46,49,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,181,126,54,184,3,0,16,0,102,102,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,231,102,92,55,5,0,64,0,102,102,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,249,55,241,30,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,115,50,50,52,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,62,65,196,205,0,0,0,8,105,111,98,49,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,102,102,117,95,51,54,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,249,138,164,226,1,0,16,1,102,102,117,95,52,50,46,49,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,14,72,187,244,1,0,16,1,102,102,117,95,51,55,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,103,198,113,195,1,0,16,1,102,102,117,95,52,51,40,95,95,102,102,105,103,104,116,117,97,41,46,49,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,249,113,87,47,1,0,16,1,102,102,45,51,50,109,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,110,105,71,199,2,0,16,1,102,102,45,53,109,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,8,65,40,156,4,0,32,0,102,102,45,55,109,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,251,77,88,167,4,0,32,0,102,102,45,49,109,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,68,94,96,11,4,0,32,0,102,102,45,51,109,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,210,28,41,82,4,0,32,0,102,102,95,48,57,46,49,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,181,126,54,184,3,0,16,0,102,102,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,231,102,92,55,5,0,64,0,102,102,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,249,55,241,30,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,115,50,50,52,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,62,65,196,205,0,0,0,8,105,111,98,49,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,102,102,95,51,54,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,131,206,165,249,1,0,16,1,102,102,95,52,50,46,49,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,21,18,241,101,1,0,16,1,102,102,95,51,55,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,132,55,3,225,1,0,16,1,102,102,117,95,52,51,46,49,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,71,89,166,76,1,0,16,1,102,102,95,51,52,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,252,195,141,12,1,0,16,1,102,102,95,52,48,46,57,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,185,186,117,128,1,0,16,1,102,102,95,51,53,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,33,65,147,74,1,0,16,1,102,102,95,52,49,46,49,48,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,84,129,246,42,1,0,16,1,102,102,45,53,109,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,8,65,40,156,4,0,32,0,102,102,45,55,109,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,251,77,88,167,4,0,32,0,102,102,45,49,109,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,68,94,96,11,4,0,32,0,102,102,45,51,109,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,210,28,41,82,4,0,32,0,102,102,95,48,57,46,49,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,181,126,54,184,3,0,16,0,102,102,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,231,102,92,55,5,0,64,0,102,102,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,249,55,241,30,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,115,50,50,52,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,62,65,196,205,0,0,0,8,105,111,98,49,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,102,102,95,50,51,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,127,218,61,174,2,0,16,1,102,102,95,50,50,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,170,163,213,178,2,0,16,1,102,102,95,49,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,226,24,157,150,4,0,32,0,102,102,95,50,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,153,159,181,2,4,0,32,0,102,102,95,51,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,174,7,213,1,4,0,32,0,102,102,95,52,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,176,206,196,247,4,0,32,0,102,102,95,57,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,181,126,54,184,3,0,16,0,102,102,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,231,102,92,55,5,0,64,0,102,102,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,249,55,241,30,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,103,97,108,49,54,118,56,97,45,49,53,108,112,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,0,0,0,0,0,0,24,105,111,98,49,46,49,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,98,112,114,103,49,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,167,61,121,49,0,0,0,8,105,111,99,49,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,129,32,24,13,0,0,0,8,102,102,106,95,51,54,97,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,201,209,142,8,1,0,16,1,102,102,106,95,52,50,97,46,49,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,230,145,196,196,1,0,16,1,102,102,106,95,51,55,97,46,49,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,255,87,133,112,1,0,16,1,102,102,106,95,52,51,97,46,49,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,74,0,4,192,1,0,16,1,102,102,95,51,52,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,252,195,141,12,1,0,16,1,102,102,95,52,48,46,49,48,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,185,186,117,128,1,0,16,1,102,102,95,51,53,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,33,65,147,74,1,0,16,1,102,102,95,52,49,46,49,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,84,129,246,42,1,0,16,1,102,102,95,48,57,46,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,13,109,17,91,4,0,32,0,102,102,95,48,49,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,151,23,91,129,4,0,32,0,102,102,95,49,51,46,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,218,167,33,135,4,0,32,0,102,102,95,48,53,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,181,212,252,208,4,0,32,0,102,102,95,50,52,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,122,96,171,161,4,0,32,0,102,102,95,49,55,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,244,140,193,45,4,0,32,0,102,102,95,51,56,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,127,165,53,101,4,0,32,0,102,102,95,51,50,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,87,74,188,200,4,0,32,0,102,102,95,49,48,46,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,74,146,74,98,4,0,32,0,102,102,95,48,50,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,148,246,145,93,4,0,32,0,102,102,95,49,52,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,1,145,46,10,4,0,32,0,102,102,95,48,54,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,66,240,24,28,4,0,32,0,102,102,95,50,53,46,55,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,234,129,129,110,4,0,32,0,102,102,95,49,56,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,89,222,158,177,4,0,32,0,102,102,95,51,57,46,57,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,119,180,22,148,4,0,32,0,102,102,95,51,51,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,7,250,105,115,4,0,32,0,102,102,95,50,51,46,49,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,181,126,54,184,3,0,16,0,102,102,95,51,48,46,49,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,231,102,92,55,5,0,64,0,102,102,95,51,49,46,49,51,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,249,55,241,30,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,115,50,50,50,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,0,0,0,0,0,0,24,108,119,105,111,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,12,185,82,173,0,0,0,8,102,102,106,95,51,54,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,249,138,164,226,1,0,16,1,102,102,106,95,52,50,46,49,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,14,72,187,244,1,0,16,1,102,102,106,95,51,55,46,49,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,103,198,113,195,1,0,16,1,102,102,106,95,52,51,46,49,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,148,241,129,111,1,0,16,1,102,102,106,95,51,52,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,252,195,141,12,1,0,16,1,102,102,106,95,52,48,46,49,48,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,185,186,117,128,1,0,16,1,102,102,106,95,51,53,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,33,65,147,74,1,0,16,1,102,102,106,95,52,49,46,49,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,84,129,246,42,1,0,16,1,102,102,106,95,48,57,46,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,13,109,17,91,4,0,32,0,102,102,106,95,48,49,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,151,23,91,129,4,0,32,0,102,102,106,95,49,51,46,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,218,167,33,135,4,0,32,0,102,102,106,95,48,53,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,181,212,252,208,4,0,32,0,102,102,106,95,50,52,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,122,96,171,161,4,0,32,0,102,102,106,95,49,55,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,244,140,193,45,4,0,32,0,102,102,106,95,51,56,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,127,165,53,101,4,0,32,0,102,102,106,95,51,50,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,87,74,188,200,4,0,32,0,102,102,106,95,49,48,46,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,74,146,74,98,4,0,32,0,102,102,106,95,48,50,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,148,246,145,93,4,0,32,0,102,102,106,95,49,52,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,1,145,46,10,4,0,32,0,102,102,106,95,48,54,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,66,240,24,28,4,0,32,0,102,102,106,95,50,53,46,55,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,234,129,129,110,4,0,32,0,102,102,106,95,49,56,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,89,222,158,177,4,0,32,0,102,102,106,95,51,57,46,57,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,119,180,22,148,4,0,32,0,102,102,106,95,51,51,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,7,250,105,115,4,0,32,0,102,102,95,50,51,46,49,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,181,126,54,184,3,0,16,0,102,102,106,95,51,48,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,231,102,92,55,5,0,64,0,102,102,106,95,51,49,46,49,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,249,55,241,30,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,115,50,50,50,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,0,0,0,0,0,0,24,108,119,105,111,46,49,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,12,185,82,173,0,0,0,8,102,103,45,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,126,242,204,248,1,0,16,1,102,103,45,102,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,178,118,108,217,1,0,16,1,102,103,45,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,99,248,3,67,4,0,32,0,102,103,45,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,45,205,223,209,4,0,32,0,102,103,45,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,151,192,242,34,4,0,32,0,102,103,45,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,44,155,168,22,4,0,32,0,102,102,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,20,108,39,91,3,0,16,0,168,86,7,0,1,0,0,0,232,47,216,0,248,191,2,0,24,38,7,0,1,0,0,0,236,47,216,0,184,160,2,0,56,210,6,0,1,0,0,0,35,48,216,0,192,135,2,0,24,163,6,0,1,0,0,0,34,48,216,0,240,108,2,0,152,122,6,0,1,0,0,0,33,48,216,0,96,82,2,0,192,72,6,0,1,0,0,0,32,48,216,0,32,56,2,0,152,31,6,0,1,0,0,0,36,48,216,0,152,30,2,0,248,97,5,0,1,0,0,0,37,48,216,0,232,10,2,0,104,184,3,0,1,0,0,0,38,48,216,0,152,138,8,0,40,246,1,0,1,0,0,0,233,47,216,0,64,246,1,0,144,236,1,0,1,0,0,0,237,47,216,0,136,224,1,0,176,223,1,0,1,0,0,0,43,48,216,0,72,198,1,0,192,209,1,0,1,0,0,0,42,48,216,0,24,182,1,0,24,198,1,0,1,0,0,0,41,48,216,0,40,167,1,0,120,189,1,0,1,0,0,0,40,48,216,0,200,149,1,0,8,182,1,0,1,0,0,0,44,48,216,0,56,126,1,0,32,167,1,0,1,0,0,0,45,48,216,0,32,101,1,0,208,41,1,0,1,0,0,0,46,48,216,0,96,32,8,0,88,212,3,0,1,0,0,0,144,46,216,0,40,185,3,0,16,17,8,0,1,0,0,0,234,47,216,0,224,12,8,0,72,65,1,0,9,0,0,0,232,48,216,0,32,58,1,0,48,50,1,0,9,0,0,0,224,48,216,0,32,58,1,0,224,41,1,0,9,0,0,0,216,48,216,0,32,58,1,0,102,102,45,48,50,45,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,167,34,252,41,0,0,16,1,102,102,45,48,49,45,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,180,124,97,159,0,0,16,1,101,119,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,236,101,109,199,0,0,16,1,101,119,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,166,39,180,233,0,0,16,1,101,119,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,141,185,113,152,0,0,16,1,101,119,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,52,5,1,83,0,0,16,1,101,118,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,193,114,111,104,0,0,32,0,101,118,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,201,220,135,183,0,0,32,0,101,119,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,163,215,128,107,0,0,32,0,101,119,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,100,215,211,120,0,0,32,0,101,119,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,227,93,159,206,0,0,32,0,101,119,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,162,123,122,72,0,0,32,0,101,119,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,164,194,27,78,0,0,32,0,101,119,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,251,125,180,158,0,0,32,0,101,119,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,158,71,207,158,0,0,32,0,101,119,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,170,105,86,229,0,0,32,0,101,118,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,151,247,128,29,0,0,32,0,101,119,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,119,49,35,150,0,0,32,0,101,118,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,107,17,231,196,0,0,32,0,101,119,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,252,7,224,242,0,0,32,0,101,118,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,26,79,121,108,0,0,32,0,101,119,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,137,105,11,71,0,0,32,0,101,118,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,212,9,85,4,0,0,32,0,101,119,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,188,68,210,162,0,0,32,0,101,119,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,77,146,6,182,0,0,64,0,24,0,0,0,255,255,255,0,0,0,0,0,25,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,200,87,7,0,24,0,0,0,1,3,0,0,176,45,8,0,24,0,0,0,1,3,1,0,224,127,8,0,24,0,0,0,1,3,3,0,32,123,8,0,24,0,0,0,1,3,2,0,192,110,8,0,0,0,0,0,254,0,4,0,160,123,6,0,24,0,0,0,1,12,0,0,176,45,8,0,24,0,0,0,1,12,4,0,224,127,8,0,24,0,0,0,1,12,12,0,32,123,8,0,24,0,0,0,1,12,8,0,192,110,8,0,0,0,0,0,254,0,2,0,168,234,7,0,24,0,0,0,1,32,0,0,96,135,7,0,24,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,24,0,0,0,1,64,64,0,96,135,7,0,24,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,25,0,0,0,1,3,1,0,192,255,2,0,25,0,0,0,1,3,3,0,208,75,4,0,25,0,0,0,1,3,2,0,8,49,4,0,25,0,0,0,1,3,0,0,72,246,3,0,0,0,0,0,254,0,4,0,72,202,5,0,25,0,0,0,1,12,8,0,80,246,3,0,25,0,0,0,1,12,12,0,248,38,7,0,25,0,0,0,1,12,4,0,112,212,3,0,25,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,4,0,24,219,7,0,25,0,0,0,1,48,16,0,112,67,8,0,25,0,0,0,1,48,32,0,112,134,3,0,25,0,0,0,1,48,48,0,80,124,6,0,25,0,0,0,1,48,0,0,64,111,3,0,0,0,0,0,254,0,2,0,168,209,7,0,25,0,0,0,1,64,64,0,152,204,7,0,25,0,0,0,1,64,0,0,120,7,5,0,101,112,114,45,55,51,56,53,97,46,52,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,66,175,145,64,1,0,16,1,101,112,114,45,55,51,56,50,97,46,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0])
.concat([253,123,214,119,1,0,16,1,101,112,114,45,55,51,56,54,97,46,52,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,208,124,166,176,1,0,16,1,101,112,114,45,55,51,56,51,97,46,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,169,178,121,95,1,0,16,1,101,112,114,45,55,51,56,55,46,52,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,93,51,205,10,1,0,16,1,101,112,114,45,55,51,56,52,46,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,65,147,144,253,1,0,16,1,101,112,114,45,55,51,56,56,46,57,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,107,47,176,142,2,0,32,0,101,112,114,45,55,51,56,57,46,57,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,184,113,79,47,2,0,32,0,101,112,114,45,55,51,57,48,46,57,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,198,9,6,217,2,0,32,0,101,112,114,45,55,51,57,50,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,182,200,183,91,3,0,32,0,101,112,114,45,55,51,57,54,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,87,75,174,116,3,0,32,0,101,112,114,45,55,51,57,51,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,130,126,252,20,3,0,32,0,101,112,114,45,55,51,57,55,46,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,37,30,90,224,3,0,32,0,101,112,114,45,55,51,57,52,46,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,63,161,28,83,3,0,32,0,101,112,114,45,55,51,57,56,46,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,73,123,128,104,3,0,32,0,101,112,114,45,55,53,51,53,97,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,250,116,19,188,4,0,16,1,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,252,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,19,0,0,0,1,15,7,0,80,252,6,0,19,0,0,0,1,15,8,0,16,242,7,0,19,0,0,0,1,15,9,0,104,236,7,0,19,0,0,0,1,15,5,0,176,51,4,0,19,0,0,0,1,15,4,0,56,24,4,0,19,0,0,0,1,15,15,0,128,230,7,0,19,0,0,0,1,15,1,0,72,216,3,0,19,0,0,0,1,15,2,0,24,188,3,0,19,0,0,0,1,15,3,0,176,162,3,0,19,0,0,0,1,15,6,0,120,211,6,0,19,0,0,0,1,15,14,0,184,164,6,0,19,0,0,0,1,15,13,0,80,74,6,0,19,0,0,0,1,15,12,0,192,32,6,0,19,0,0,0,1,15,11,0,192,234,2,0,19,0,0,0,1,15,10,0,32,242,5,0,19,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,19,0,0,0,1,240,112,0,80,252,6,0,19,0,0,0,1,240,128,0,16,242,7,0,19,0,0,0,1,240,144,0,104,236,7,0,19,0,0,0,1,240,80,0,176,51,4,0,19,0,0,0,1,240,64,0,56,24,4,0,19,0,0,0,1,240,240,0,128,230,7,0,19,0,0,0,1,240,16,0,72,216,3,0,19,0,0,0,1,240,32,0,24,188,3,0,19,0,0,0,1,240,48,0,176,162,3,0,19,0,0,0,1,240,96,0,120,211,6,0,19,0,0,0,1,240,224,0,184,164,6,0,19,0,0,0,1,240,208,0,80,74,6,0,19,0,0,0,1,240,192,0,192,32,6,0,19,0,0,0,1,240,176,0,192,234,2,0,19,0,0,0,1,240,160,0,32,242,5,0,19,0,0,0,1,240,0,0,208,236,2,0,0,0,0,0,254,0,2,0,200,30,2,0,20,0,0,0,1,1,0,0,120,97,1,0,20,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,2,0,168,234,7,0,20,0,0,0,1,2,2,0,96,135,7,0,20,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,12,8,0,208,75,4,0,20,0,0,0,1,12,12,0,8,49,4,0,20,0,0,0,1,12,4,0,152,21,4,0,20,0,0,0,1,12,0,0,40,130,6,0,0,0,0,0,254,0,4,0,104,125,6,0,20,0,0,0,1,48,48,0,136,120,6,0,20,0,0,0,1,48,32,0,176,116,6,0,20,0,0,0,1,48,16,0,80,113,6,0,20,0,0,0,1,48,0,0,80,110,6,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,192,128,0,80,246,3,0,20,0,0,0,1,192,192,0,248,38,7,0,20,0,0,0,1,192,64,0,112,212,3,0,20,0,0,0,1,192,0,0,248,160,5,0,0,0,0,0,102,122,49,95,115,49,54,98,95,116,97,46,112,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,122,83,208,186,1,0,16,1,102,122,49,95,115,49,54,98,46,115,99,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,185,216,236,16,2,0,32,0,102,122,49,95,115,49,54,98,95,116,97,46,111,98,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,143,67,253,81,3,0,32,0,102,122,49,95,115,49,54,98,46,115,110,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,251,1,7,160,4,0,16,1,102,122,50,46,97,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,11,95,192,148,1,0,16,1,102,122,50,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,149,104,82,243,1,0,16,1,102,122,50,46,97,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,178,235,178,1,0,16,1,102,122,50,46,97,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,70,245,51,104,1,0,16,1,102,122,50,46,97,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,55,69,10,28,2,0,32,0,102,122,50,46,97,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,68,51,147,43,2,0,32,0,102,122,50,46,97,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,161,129,50,230,2,0,32,0,102,122,50,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,21,166,187,70,3,0,32,0,102,122,50,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,93,238,190,190,3,0,32,0,102,122,50,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,182,167,129,102,3,0,32,0,102,122,50,46,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,31,36,211,66,3,0,32,0,102,122,50,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,111,146,99,88,3,0,32,0,102,122,50,46,98,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,16,5,131,205,3,0,32,0,102,122,50,46,98,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,182,165,143,185,3,0,32,0,102,122,50,46,98,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,104,143,36,232,3,0,32,0,102,122,50,46,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,243,65,47,157,3,0,32,0,102,122,50,46,98,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,51,234,134,118,3,0,32,0,102,122,50,46,97,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,183,80,64,59,3,0,32,0,102,122,50,46,98,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,220,149,138,218,3,0,32,0,102,122,50,46,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,36,41,201,146,4,0,16,1,102,122,50,46,97,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,185,27,100,140,8,0,64,0,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,19,0,0,0,1,12,8,0,208,75,4,0,19,0,0,0,1,12,12,0,8,49,4,0,19,0,0,0,1,12,4,0,152,21,4,0,19,0,0,0,1,12,0,0,40,130,6,0,0,0,0,0,254,0,4,0,72,202,5,0,19,0,0,0,1,192,128,0,80,246,3,0,19,0,0,0,1,192,192,0,248,38,7,0,19,0,0,0,1,192,64,0,112,212,3,0,19,0,0,0,1,192,0,0,248,160,5,0,112,114,111,103,50,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,167,77,104,30,0,0,16,1,112,114,111,103,49,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,107,79,78,220,0,0,16,1,105,45,115,99,114,50,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,255,86,135,171,0,0,16,1,105,45,115,99,114,49,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,119,239,226,216,0,0,16,1,105,45,115,99,114,52,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,35,235,82,78,0,0,16,1,105,45,115,99,114,51,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,248,49,119,121,0,0,16,1,105,45,115,99,114,54,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,57,82,142,111,0,0,16,1,105,45,115,99,114,53,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,63,14,66,133,0,0,16,1,105,45,115,99,114,56,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,119,129,219,51,0,0,16,1,105,45,115,99,114,55,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,221,98,134,0,0,16,1,111,98,106,49,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,81,212,44,131,0,0,32,0,109,117,115,105,99,49,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,239,226,23,49,0,0,64,0,109,117,115,105,99,50,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,249,9,17,12,0,0,64,0,112,114,111,103,50,46,103,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,114,153,197,87,0,0,16,1,112,114,111,103,49,46,102,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,38,154,45,191,0,0,16,1,115,99,114,50,46,103,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,197,27,123,136,0,0,16,1,115,99,114,49,46,102,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,130,49,186,203,0,0,16,1,115,99,114,52,46,103,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,17,228,151,206,0,0,16,1,115,99,114,51,46,102,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,232,194,12,72,0,0,16,1,115,99,114,54,46,103,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,222,73,157,178,0,0,16,1,115,99,114,53,46,102,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,131,139,248,213,0,0,16,1,115,99,114,56,46,103,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,179,226,74,105,0,0,16,1,115,99,114,55,46,102,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,44,113,104,96,0,0,16,1,111,98,106,49,46,49,105,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,42,135,230,82,0,0,32,0,111,98,106,50,46,50,105,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,56,110,234,0,0,32,0,109,117,115,105,99,50,46,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,156,79,204,35,0,0,64,0,109,117,115,105,99,49,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,194,103,65,134,0,0,64,0,102,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,99,56,226,211,1,0,16,1,102,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,73,65,250,99,1,0,16,1,102,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,171,176,162,41,1,0,16,1,102,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,109,90,106,76,1,0,16,1,102,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,161,92,253,117,1,0,16,1,102,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,212,45,218,228,1,0,16,1,102,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,70,150,134,66,1,0,16,1,102,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,176,127,141,164,1,0,16,1,49,104,95,49,95,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,5,167,141,82,4,0,32,0,109,99,115,95,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,21,42,147,19,4,0,32,0,49,107,95,49,95,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,107,255,121,78,4,0,32,0,109,99,115,95,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,69,209,207,36,4,0,32,0,102,97,110,116,97,122,105,97,46,99,108,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,175,240,79,168,7,0,32,0,11,0,0,0,255,255,0,0,0,0,0,0,12,0,0,0,255,255,0,0,0,0,0,0,13,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,11,0,0,0,1,32,0,0,120,97,1,0,11,0,0,0,1,32,32,0,96,19,1,0,0,0,0,0,254,0,2,0,64,37,5,0,12,0,0,0,1,64,0,0,152,53,6,0,12,0,0,0,1,64,64,0,8,49,6,0,0,0,0,0,254,0,4,0,160,123,6,0,13,0,0,0,1,3,3,0,144,102,8,0,13,0,0,0,1,3,2,0,176,45,8,0,13,0,0,0,1,3,1,0,224,127,8,0,13,0,0,0,1,3,0,0,32,123,8,0,0,0,0,0,254,0,4,0,200,87,7,0,13,0,0,0,1,12,0,0,128,103,7,0,13,0,0,0,1,12,4,0,80,196,7,0,13,0,0,0,1,12,8,0,0,90,2,0,13,0,0,0,1,12,12,0,104,151,6,0,0,0,0,0,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,183,240,25,128,1,0,16,1,102,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,198,155,138,152,1,0,16,1,102,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,16,0,0,11,204,192,163,1,0,16,1,102,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,232,27,54,193,1,0,16,1,102,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,63,233,135,103,1,0,16,1,102,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,174,41,112,89,1,0,16,1,102,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,154,141,224,141,1,0,16,1,102,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,183,47,158,72,1,0,16,1,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,73,247,84,58,4,0,32,0,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,100,18,183,136,4,0,32,0,112,114,111,109,45,55,52,103,49,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,24,87,15,128,7,0,32,0,7,0,0,0,255,255,64,0,0,0,0,0,8,0,0,0,255,255,0,0,0,0,0,0,9,0,0,0,255,255,1,0,0,0,0,0,0,0,0,0,254,0,2,0,232,75,4,0,7,0,0,0,1,32,0,0,96,135,7,0,7,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,56,146,1,0,7,0,0,0,1,64,0,0,96,135,7,0,7,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,32,4,2,0,8,0,0,0,1,192,0,0,32,123,8,0,8,0,0,0,1,192,128,0,224,127,8,0,0,0,0,0,254,0,2,0,128,129,4,0,8,0,0,0,1,128,0,0,8,49,4,0,8,0,0,0,1,128,128,0,72,246,3,0,0,0,0,0,254,0,4,0,72,202,5,0,9,0,0,0,1,3,0,0,80,246,3,0,9,0,0,0,1,3,1,0,80,124,6,0,9,0,0,0,1,3,2,0,112,212,3,0,9,0,0,0,1,3,3,0,248,160,5,0,0,0,0,0,254,0,4,0,64,37,5,0,9,0,0,0,1,12,0,0,64,119,3,0,9,0,0,0,1,12,4,0,184,202,1,0,9,0,0,0,1,12,8,0,32,138,1,0,9,0,0,0,1,12,12,0,8,137,1,0,0,0,0,0,49,54,46,112,114,111,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,87,108,124,226,0,0,16,1,49,51,46,112,114,111,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,19,116,210,104,0,0,16,1,57,46,98,103,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,147,131,88,42,0,0,16,1,53,46,98,103,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,240,224,96,97,0,0,16,1,56,46,98,103,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,67,183,118,247,0,0,16,1,52,46,98,103,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,242,223,240,93,0,0,16,1,55,46,98,103,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,216,7,87,0,0,16,1,51,46,98,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,26,129,203,54,0,0,16,1,49,48,46,105,109,97,103,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,149,163,20,31,0,0,16,1,54,46,105,109,97,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,228,112,248,250,0,0,16,1,49,55,46,115,99,114,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,183,110,219,170,0,0,32,0,50,46,109,117,115,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,251,94,149,34,0,0,64,0,49,46,109,117,115,105,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,195,214,212,76,0,0,64,0,49,53,46,111,98,106,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,104,103,102,70,0,0,0,8,49,50,46,111,98,106,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,230,91,210,75,0,0,0,8,49,52,46,111,98,106,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,212,110,126,78,0,0,0,8,49,49,46,111,98,106,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,197,164,0,109,0,0,0,8,18,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,136,101,2,0,18,0,0,0,1,4,0,0,96,135,7,0,18,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,254,0,2,0,216,128,8,0,18,0,0,0,1,8,0,0,208,233,4,0,18,0,0,0,1,8,8,0,72,197,4,0,0,0,0,0,254,0,4,0,184,40,2,0,18,0,0,0,2,48,0,0,200,201,5,0,18,0,0,0,0,8,0,0,0,0,0,0,18,0,0,0,2,48,16,0,224,67,5,0,18,0,0,0,0,8,0,0,0,0,0,0,18,0,0,0,2,48,32,0,152,160,5,0,18,0,0,0,0,8,0,0,0,0,0,0,18,0,0,0,2,48,48,0,224,189,3,0,18,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,254,0,4,0,184,164,8,0,18,0,0,0,2,192,0,0,200,201,5,0,18,0,0,0,0,8,0,0,0,0,0,0,18,0,0,0,2,192,64,0,224,67,5,0,18,0,0,0,0,8,0,0,0,0,0,0,18,0,0,0,2,192,128,0,152,160,5,0,18,0,0,0,0,8,0,0,0,0,0,0,18,0,0,0,2,192,192,0,224,189,3,0,18,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,254,0,4,0,184,40,2,0,18,0,0,0,2,48,0,0,200,201,5,0,18,0,0,0,0,8,8,0,0,0,0,0,18,0,0,0,2,48,16,0,224,67,5,0,18,0,0,0,0,8,8,0,0,0,0,0,18,0,0,0,2,48,32,0,144,127,5,0,18,0,0,0,0,8,8,0,0,0,0,0,18,0,0,0,2,48,48,0,168,98,5,0,18,0,0,0,0,8,8,0,0,0,0,0,0,0,0,0,254,0,4,0,184,164,8,0,18,0,0,0,2,192,0,0,200,201,5,0,18,0,0,0,0,8,8,0,0,0,0,0,18,0,0,0,2,192,64,0,224,67,5,0,18,0,0,0,0,8,8,0,0,0,0,0,18,0,0,0,2,192,128,0,144,127,5,0,18,0,0,0,0,8,8,0,0,0,0,0,18,0,0,0,2,192,192,0,168,98,5,0,18,0,0,0,0,8,8,0,0,0,0,0,0,0,0,0,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,19,0,0,0,1,1,0,0,120,97,1,0,19,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,2,2,0,96,135,7,0,19,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,4,4,0,96,135,7,0,19,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,19,0,0,0,1,48,16,0,96,39,7,0,19,0,0,0,1,48,48,0,144,251,6,0,19,0,0,0,1,48,0,0,120,211,6,0,19,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,19,0,0,0,1,192,64,0,96,39,7,0,19,0,0,0,1,192,192,0,144,251,6,0,19,0,0,0,1,192,0,0,120,211,6,0,19,0,0,0,1,192,128,0,184,164,6,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,3,2,0,80,246,3,0,20,0,0,0,1,3,3,0,80,124,6,0,20,0,0,0,1,3,1,0,112,212,3,0,20,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,128,109,7,0,20,0,0,0,1,192,192,0,240,102,7,0,20,0,0,0,1,192,128,0,56,96,7,0,20,0,0,0,1,192,64,0,184,89,7,0,20,0,0,0,1,192,0,0,64,83,7,0,0,0,0,0,12,0,0,0,255,255,255,0,0,0,0,0,13,0,0,0,255,255,255,0,0,0,0,0,14,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,12,0,0,0,1,1,1,0,96,135,7,0,12,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,12,0,0,0,1,2,0,0,96,135,7,0,12,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,12,0,0,0,1,12,8,0,80,246,3,0,12,0,0,0,1,12,12,0,248,38,7,0,12,0,0,0,1,12,4,0,112,212,3,0,12,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,2,0,16,227,4,0,12,0,0,0,1,16,16,0,96,135,7,0,12,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,2,0,200,30,2,0,12,0,0,0,1,32,32,0,120,97,1,0,12,0,0,0,1,32,0,0,96,19,1,0,0,0,0,0,254,0,2,0,0,150,8,0,12,0,0,0,1,64,64,0,208,75,4,0,12,0,0,0,1,64,0,0,192,255,2,0,0,0,0,0,254,0,2,0,232,75,4,0,12,0,0,0,1,128,128,0,96,135,7,0,12,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,8,0,200,87,7,0,13,0,0,0,1,7,5,0,40,88,7,0,13,0,0,0,1,7,6,0,96,39,7,0,13,0,0,0,1,7,7,0,144,251,6,0,13,0,0,0,1,7,4,0,184,164,6,0,13,0,0,0,1,7,3,0,80,74,6,0,13,0,0,0,1,7,2,0,192,32,6,0,13,0,0,0,1,7,1,0,192,234,2,0,13,0,0,0,1,7,0,0,32,242,5,0,0,0,0,0,254,0,8,0,160,123,6,0,13,0,0,0,1,56,40,0,40,88,7,0,13,0,0,0,1,56,48,0,96,39,7,0,13,0,0,0,1,56,56,0,144,251,6,0,13,0,0,0,1,56,32,0,184,164,6,0,13,0,0,0,1,56,24,0,80,74,6,0,13,0,0,0,1,56,16,0,192,32,6,0,13,0,0,0,1,56,8,0,192,234,2,0,13,0,0,0,1,56,0,0,32,242,5,0,0,0,0,0,254,0,2,0,56,180,7,0,13,0,0,0,1,64,64,0,0,205,2,0,13,0,0,0,1,64,0,0,16,203,2,0,0,0,0,0,254,0,2,0,168,79,2,0,13,0,0,0,1,128,128,0,16,200,2,0,13,0,0,0,1,128,0,0,48,197,2,0,0,0,0,0,254,0,2,0,88,195,2,0,14,0,0,0,1,8,8,0,96,135,7,0,14,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,3,0,224,133,4,0,14,0,0,0,1,48,48,0,224,32,1,0,14,0,0,0,1,48,16,0,160,134,3,0,14,0,0,0,1,48,0,0,176,20,3,0,0,0,0,0,49,48,108,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,38,246,173,213,1,0,16,1,57,108,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,136,39,227,72,1,0,16,1,56,108,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,222,219,219,192,1,0,16,1,55,108,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,39,210,48,155,1,0,16,1,51,102,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,207,24,175,159,2,0,16,1,52,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,195,181,16,233,2,0,16,1,99,50,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,91,132,8,71,4,0,32,0,99,49,46,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,135,40,253,17,4,0,32,0,99,48,49,115,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,171,174,60,78,7,0,32,0,11,0,0,0,255,255,0,0,0,0,0,0,12,0,0,0,255,255,0,0,0,0,0,0,13,0,0,0,255,255,0,0,0,0,0,0,14,0,0,0,255,255,1,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,13,0,0,0,1,15,8,0,224,127,8,0,13,0,0,0,1,15,9,0,240,169,3,0,13,0,0,0,1,15,0,0,32,123,8,0,13,0,0,0,1,15,10,0,248,116,8,0,13,0,0,0,1,15,11,0,152,81,3,0,13,0,0,0,1,15,1,0,192,110,8,0,13,0,0,0,1,15,12,0,168,36,1,0,13,0,0,0,1,15,13,0,40,242,1,0,13,0,0,0,1,15,2,0,96,102,7,0,13,0,0,0,1,15,14,0,0,240,1,0,13,0,0,0,1,15,15,0,192,238,1,0,13,0,0,0,1,15,3,0,184,105,6,0,13,0,0,0,1,15,4,0,152,96,3,0,13,0,0,0,1,15,5,0,192,100,6,0,13,0,0,0,1,15,6,0,64,1,1,0,13,0,0,0,1,15,7,0,184,69,8,0,0,0,0,0,254,0,16,0,160,123,6,0,13,0,0,0,1,240,128,0,224,127,8,0,13,0,0,0,1,240,144,0,240,169,3,0,13,0,0,0,1,240,0,0,32,123,8,0,13,0,0,0,1,240,160,0,248,116,8,0,13,0,0,0,1,240,176,0,152,81,3,0,13,0,0,0,1,240,16,0,192,110,8,0,13,0,0,0,1,240,192,0,168,36,1,0,13,0,0,0,1,240,208,0,40,242,1,0,13,0,0,0,1,240,32,0,96,102,7,0,13,0,0,0,1,240,224,0,0,240,1,0,13,0,0,0,1,240,240,0,192,238,1,0,13,0,0,0,1,240,48,0,184,105,6,0,13,0,0,0,1,240,64,0,152,96,3,0,13,0,0,0,1,240,80,0,192,100,6,0,13,0,0,0,1,240,96,0,64,1,1,0,13,0,0,0,1,240,112,0,184,69,8,0,0,0,0,0,254,0,4,0,128,129,4,0,14,0,0,0,1,3,0,0,208,75,4,0,14,0,0,0,1,3,1,0,8,49,4,0,14,0,0,0,1,3,2,0,152,21,4,0,14,0,0,0,1,3,3,0,72,246,3,0,0,0,0,0,254,0,8,0,64,37,5,0,14,0,0,0,1,28,4,0,176,116,6,0,14,0,0,0,1,28,12,0,80,113,6,0,14,0,0,0,1,28,20,0,80,110,6,0,14,0,0,0,1,28,28,0,8,203,4,0,14,0,0,0,1,28,0,0,152,53,6,0,14,0,0,0,1,28,8,0,8,49,6,0,14,0,0,0,1,28,16,0,248,45,5,0,14,0,0,0,1,28,24,0,184,43,6,0,0,0,0,0,254,0,2,0,232,75,4,0,14,0,0,0,1,128,0,0,96,135,7,0,14,0,0,0,1,128,128,0,152,182,7,0,0,0,0,0,116,115,49,48,48,101,46,117,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,133,169,132,204,0,0,16,1,116,115,49,48,49,101,46,117,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,183,175,244,136,0,0,16,1,116,115,48,48,49,101,46,117,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,126,110,182,112,0,0,32,0,116,115,48,48,48,101,46,117,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,67,65,169,167,0,0,32,0,116,115,48,48,50,101,46,117,51,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,230,113,18,97,0,0,32,0,116,115,48,49,48,46,117,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,36,83,147,223,0,0,32,0,116,115,48,50,48,46,117,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,93,195,88,235,0,0,32,0,116,115,48,51,48,46,117,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,209,233,104,29,0,0,64,0,18,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,232,75,4,0,18,0,0,0,1,2,2,0,96,135,7,0,18,0,0,0,1,2,0,0,152,182,7,0,101,112,114,45,49,49,57,51,57,46,97,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,143,217,125,17,1,0,16,1,101,112,114,45,49,49,57,51,54,46,97,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,96,222,99,8,1,0,16,1,101,112,114,45,49,49,57,52,48,46,97,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,116,50,200,222,1,0,16,1,101,112,114,45,49,49,57,51,55,46,97,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,103,163,189,78,1,0,16,1,101,112,114,45,49,49,57,52,49,46,97,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,81,212,242,77,1,0,16,1,101,112,114,45,49,49,57,51,56,46,97,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,71,141,192,7,1,0,16,1,101,112,114,45,49,49,57,52,50,46,98,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,39,232,112,235,2,0,32,0,101,112,114,45,49,49,57,52,51,46,98,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,130,137,124,217,2,0,32,0,101,112,114,45,49,49,57,52,52,46,98,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,128,174,92,167,2,0,32,0,101,112,114,45,49,49,57,53,48,46,98,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,73,120,73,175,3,0,32,0,101,112,114,45,49,49,57,53,52,46,98,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,108,16,162,95,3,0,32,0,101,112,114,45,49,49,57,53,49,46,98,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,116,169,79,192,3,0,32,0,101,112,114,45,49,49,57,53,53,46,98,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,104,195,160,134,3,0,32,0,101,112,114,45,49,49,57,53,50,46,98,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,97,151,74,230,3,0,32,0,101,112,114,45,49,49,57,53,54,46,98,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,250,194,245,175,3,0,32,0,101,112,114,45,49,49,57,53,51,46,98,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,153,57,174,76,3,0,32,0,101,112,114,45,49,49,57,53,55,46,98,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,91,131,143,33,3,0,32,0,101,112,114,45,49,49,57,52,53,46,97,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,18,48,168,194,4,0,16,1,101,112,114,45,49,49,49,52,48,46,97,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,27,55,151,178,8,0,64,0,101,112,114,45,49,49,49,52,49,46,97,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,166,106,117,25,8,0,64,0,101,112,114,45,49,49,49,52,50,46,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,102,108,210,37,8,0,64,0,101,112,114,45,49,49,49,52,51,46,97,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,119,123,139,132,8,0,64,0,51,49,55,45,48,48,55,57,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,28,250,254,239,5,0,16,1,37,0,0,0,255,255,254,0,0,0,0,0,38,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,168,234,7,0,37,0,0,0,1,1,1,0,96,135,7,0,37,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,8,0,216,231,2,0,37,0,0,0,1,14,6,0,184,230,7,0,37,0,0,0,1,14,10,0,72,123,3,0,37,0,0,0,1,14,12,0,152,120,3,0,37,0,0,0,1,14,14,0,136,120,6,0,37,0,0,0,1,14,8,0,160,118,3,0,37,0,0,0,1,14,4,0,176,114,3,0,37,0,0,0,1,14,2,0,32,112,3,0,37,0,0,0,1,14,0,0,104,109,3,0,0,0,0,0,254,0,4,0,72,202,5,0,37,0,0,0,1,48,32,0,80,246,3,0,37,0,0,0,1,48,48,0,248,38,7,0,37,0,0,0,1,48,16,0,112,212,3,0,37,0,0,0,1,48,0,0,248,160,5,0,0,0,0,0,254,0,4,0,112,107,3,0,37,0,0,0,1,192,128,0,80,246,3,0,37,0,0,0,1,192,192,0,248,38,7,0,37,0,0,0,1,192,64,0,112,212,3,0,37,0,0,0,1,192,0,0,248,160,5,0,0,0,0,0,254,0,16,0,200,87,7,0,38,0,0,0,1,15,7,0,80,252,6,0,38,0,0,0,1,15,8,0,16,242,7,0,38,0,0,0,1,15,9,0,104,236,7,0,38,0,0,0,1,15,5,0])
.concat([176,51,4,0,38,0,0,0,1,15,4,0,56,24,4,0,38,0,0,0,1,15,15,0,128,230,7,0,38,0,0,0,1,15,1,0,72,216,3,0,38,0,0,0,1,15,2,0,24,188,3,0,38,0,0,0,1,15,3,0,176,162,3,0,38,0,0,0,1,15,6,0,120,211,6,0,38,0,0,0,1,15,14,0,184,164,6,0,38,0,0,0,1,15,13,0,80,74,6,0,38,0,0,0,1,15,12,0,192,32,6,0,38,0,0,0,1,15,11,0,192,234,2,0,38,0,0,0,1,15,10,0,32,242,5,0,38,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,38,0,0,0,1,240,112,0,80,252,6,0,38,0,0,0,1,240,128,0,16,242,7,0,38,0,0,0,1,240,144,0,104,236,7,0,38,0,0,0,1,240,80,0,176,51,4,0,38,0,0,0,1,240,64,0,56,24,4,0,38,0,0,0,1,240,240,0,128,230,7,0,38,0,0,0,1,240,16,0,72,216,3,0,38,0,0,0,1,240,32,0,24,188,3,0,38,0,0,0,1,240,48,0,176,162,3,0,38,0,0,0,1,240,96,0,120,211,6,0,38,0,0,0,1,240,224,0,184,164,6,0,38,0,0,0,1,240,208,0,80,74,6,0,38,0,0,0,1,240,192,0,192,32,6,0,38,0,0,0,1,240,176,0,192,234,2,0,38,0,0,0,1,240,160,0,32,242,5,0,38,0,0,0,1,240,0,0,208,236,2,0,50,50,40,95,95,101,120,99,101,108,115,114,97,41,46,117,51,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,218,162,220,85,0,0,16,1,49,57,40,95,95,101,120,99,101,108,115,114,97,41,46,117,51,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,144,57,209,0,0,16,1,50,49,46,117,51,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,100,189,249,253,0,0,16,1,49,56,46,117,51,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,14,126,81,254,0,0,16,1,50,48,46,117,51,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,233,175,146,134,0,0,16,1,49,55,46,117,51,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,107,154,143,151,0,0,16,1,112,105,99,49,54,99,53,55,45,104,115,46,105,48,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,76,45,0,0,65,105,44,2,0,0,16,1,50,54,46,117,51,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,89,192,113,193,0,0,32,0,51,48,46,117,51,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,16,197,164,180,0,0,32,0,50,53,46,117,51,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,27,236,126,102,0,0,32,0,50,57,46,117,51,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,69,7,203,74,0,0,32,0,50,52,46,117,51,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,37,104,244,23,0,0,32,0,50,56,46,117,51,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,189,242,35,168,0,0,32,0,50,51,46,117,51,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,59,69,225,216,0,0,32,0,50,55,46,117,51,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,121,192,162,236,0,0,32,0,49,54,46,105,48,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,93,218,217,126,0,0,64,0,101,99,57,50,95,50,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,2,34,72,152,2,0,16,1,101,99,57,50,95,50,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,233,117,94,174,2,0,16,1,101,99,57,50,95,50,54,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,178,204,134,185,2,0,16,1,101,99,57,50,95,50,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,172,148,29,179,2,0,16,1,101,99,57,50,95,50,55,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,101,142,180,45,9,0,16,1,101,99,57,50,95,50,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,55,237,89,87,12,0,32,0,101,99,57,50,95,50,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,142,211,160,217,12,0,32,0,101,99,57,50,95,49,57,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,165,65,145,33,15,0,32,0,99,56,48,45,48,50,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,97,139,10,6,15,0,32,0,99,56,48,45,48,51,46,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,213,56,153,96,24,0,64,0,98,53,56,45,49,55,46,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,145,1,170,161,2,0,16,1,98,53,56,45,49,57,46,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,163,61,244,64,2,0,16,1,98,53,56,45,49,54,46,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,92,200,35,232,6,0,16,1,98,53,56,45,49,56,46,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,62,138,50,101,6,0,16,1,98,53,56,45,51,50,46,52,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,202,142,253,243,9,0,16,1,98,53,56,45,48,57,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,49,91,253,159,11,0,32,0,98,53,56,45,48,52,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,141,240,130,148,17,0,32,0,98,53,56,45,48,51,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,64,196,139,21,17,0,32,0,98,53,56,45,48,50,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,124,48,110,106,17,0,32,0,98,53,56,45,48,49,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,240,233,1,17,0,32,0,98,53,56,45,48,54,46,49,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,112,93,73,179,22,0,32,0,98,53,56,45,48,53,46,55,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,27,153,244,209,23,0,32,0,98,53,56,45,48,55,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,8,186,181,238,24,0,64,0,98,53,56,45,48,56,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,207,67,146,4,24,0,64,0,98,53,56,45,49,48,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,193,12,206,237,25,0,64,0,98,53,56,45,50,54,46,49,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,127,12,203,220,0,0,0,8,98,53,56,45,50,55,46,53,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,61,1,107,92,0,0,0,8,98,53,56,45,50,51,46,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,244,143,125,123,0,0,0,8,98,53,56,45,50,52,46,53,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,48,31,248,251,0,0,0,8,98,53,56,45,50,53,46,55,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,66,115,84,222,0,0,0,8,12,0,0,0,255,255,255,0,0,0,0,0,13,0,0,0,255,255,239,0,0,0,0,0,0,0,0,0,254,0,2,0,232,75,4,0,12,0,0,0,1,4,4,0,96,135,7,0,12,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,12,0,0,0,1,8,0,0,96,135,7,0,12,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,12,0,0,0,1,48,16,0,104,236,7,0,12,0,0,0,1,48,48,0,128,230,7,0,12,0,0,0,1,48,0,0,120,211,6,0,12,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,12,0,0,0,1,192,64,0,104,236,7,0,12,0,0,0,1,192,192,0,128,230,7,0,12,0,0,0,1,192,0,0,120,211,6,0,12,0,0,0,1,192,128,0,184,164,6,0,0,0,0,0,254,0,2,0,176,235,6,0,13,0,0,0,1,16,16,0,176,231,6,0,13,0,0,0,1,16,0,0,248,38,7,0,0,0,0,0,101,112,114,45,55,54,51,48,46,105,99,57,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,171,173,189,161,1,0,16,1,101,112,114,45,55,54,50,57,46,105,99,56,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,105,65,15,245,1,0,16,1,101,112,114,45,55,54,52,49,46,105,99,57,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,124,174,3,37,1,0,16,1,101,112,114,45,55,54,51,55,46,105,99,56,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,140,122,162,130,1,0,16,1,101,112,114,45,55,54,52,50,46,105,99,57,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,234,59,69,28,1,0,16,1,101,112,114,45,55,54,51,56,46,105,99,56,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,121,71,84,112,1,0,16,1,101,112,114,45,55,54,51,52,46,105,99,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,50,253,7,62,9,0,16,1,101,112,114,45,55,54,51,53,46,105,99,54,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,171,98,247,34,9,0,16,1,101,112,114,45,55,54,52,52,46,105,99,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,144,255,164,231,2,0,32,0,101,112,114,45,55,54,52,53,46,105,99,52,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,149,0,170,76,2,0,32,0,101,112,114,45,55,54,52,54,46,105,99,54,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,131,38,67,126,2,0,32,0,101,112,114,45,55,54,55,56,46,105,99,51,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,86,230,181,159,3,0,32,0,101,112,114,45,55,54,55,48,46,105,99,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,110,47,190,219,3,0,32,0,101,112,114,45,55,54,54,50,46,105,99,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,197,19,12,203,3,0,32,0,101,112,114,45,55,54,53,52,46,49,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,13,82,182,45,3,0,32,0,101,112,114,45,55,54,55,55,46,105,99,51,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,91,118,100,119,3,0,32,0,101,112,114,45,55,54,54,57,46,105,99,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,170,95,82,249,3,0,32,0,101,112,114,45,55,54,54,49,46,105,99,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,155,167,147,254,3,0,32,0,101,112,114,45,55,54,53,51,46,105,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,20,33,165,70,3,0,32,0,101,112,114,45,55,54,55,54,46,105,99,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,212,224,66,46,3,0,32,0,101,112,114,45,55,54,54,56,46,105,99,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,51,206,21,225,3,0,32,0,101,112,114,45,55,54,54,48,46,105,99,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,104,187,223,134,3,0,32,0,101,112,114,45,55,54,53,50,46,105,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,219,207,128,40,3,0,32,0,101,112,114,45,55,54,55,53,46,105,99,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,97,45,205,5,3,0,32,0,101,112,114,45,55,54,54,55,46,105,99,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,157,222,59,146,3,0,32,0,101,112,114,45,55,54,53,57,46,105,99,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,206,200,157,98,3,0,32,0,101,112,114,45,55,54,53,49,46,105,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,173,43,144,215,3,0,32,0,101,112,114,45,55,54,55,52,46,105,99,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,207,154,18,26,3,0,32,0,101,112,114,45,55,54,54,54,46,105,99,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,87,114,105,35,3,0,32,0,101,112,114,45,55,54,53,56,46,105,99,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,79,242,119,22,3,0,32,0,101,112,114,45,55,54,53,48,46,105,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,236,53,38,100,3,0,32,0,101,112,114,45,55,54,55,51,46,105,99,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,148,35,96,130,3,0,32,0,101,112,114,45,55,54,54,53,46,105,99,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,7,118,215,18,3,0,32,0,101,112,114,45,55,54,53,55,46,105,99,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,156,131,88,129,3,0,32,0,101,112,114,45,55,54,52,57,46,105,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,76,161,219,78,3,0,32,0,101,112,114,45,55,54,55,50,46,105,99,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,247,82,20,209,3,0,32,0,101,112,114,45,55,54,54,52,46,105,99,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,173,207,242,13,3,0,32,0,101,112,114,45,55,54,53,54,46,105,99,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,114,18,116,108,3,0,32,0,101,112,114,45,55,54,52,56,46,105,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,48,168,62,152,3,0,32,0,101,112,114,45,55,54,55,49,46,105,99,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,198,253,199,176,3,0,32,0])
.concat([101,112,114,45,55,54,54,51,46,105,99,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,8,143,11,43,3,0,32,0,101,112,114,45,55,54,53,53,46,105,99,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,123,254,51,52,3,0,32,0,101,112,114,45,55,54,52,55,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,192,190,127,46,3,0,32,0,101,112,114,45,55,54,51,51,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,16,98,20,111,10,0,32,0,101,112,114,45,55,55,54,53,46,105,99,55,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,201,47,200,129,4,0,16,1,101,112,114,45,55,55,54,52,46,105,99,55,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,173,253,91,117,4,0,16,1,101,112,114,45,55,55,54,50,46,105,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,18,77,12,188,11,0,64,0,101,112,114,45,55,55,54,51,46,105,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,140,60,123,98,11,0,64,0,101,112,114,45,54,56,52,52,46,105,99,49,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,214,123,236,227,16,0,32,0,51,49,55,45,48,48,49,51,97,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,55,103,94,41,5,0,16,1,55,46,49,51,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,183,180,214,241,1,0,16,1,52,46,49,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,115,248,191,67,1,0,16,1,56,46,49,52,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,74,21,83,33,1,0,16,1,53,46,49,52,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,44,153,151,10,1,0,16,1,57,46,49,53,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,28,255,59,219,1,0,16,1,54,46,49,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,90,136,177,84,1,0,16,1,101,112,114,45,55,54,51,52,46,105,99,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,50,253,7,62,9,0,16,1,101,112,114,45,55,54,51,53,46,105,99,54,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,171,98,247,34,9,0,16,1,101,112,114,45,55,54,52,52,46,105,99,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,144,255,164,231,2,0,32,0,101,112,114,45,55,54,52,53,46,105,99,52,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,149,0,170,76,2,0,32,0,101,112,114,45,55,54,52,54,46,105,99,54,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,131,38,67,126,2,0,32,0,101,112,114,45,55,54,55,56,46,105,99,51,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,86,230,181,159,3,0,32,0,101,112,114,45,55,54,55,48,46,105,99,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,110,47,190,219,3,0,32,0,101,112,114,45,55,54,54,50,46,105,99,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,197,19,12,203,3,0,32,0,101,112,114,45,55,54,53,52,46,49,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,13,82,182,45,3,0,32,0,101,112,114,45,55,54,55,55,46,105,99,51,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,91,118,100,119,3,0,32,0,101,112,114,45,55,54,54,57,46,105,99,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,170,95,82,249,3,0,32,0,101,112,114,45,55,54,54,49,46,105,99,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,155,167,147,254,3,0,32,0,101,112,114,45,55,54,53,51,46,105,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,20,33,165,70,3,0,32,0,101,112,114,45,55,54,55,54,46,105,99,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,212,224,66,46,3,0,32,0,101,112,114,45,55,54,54,56,46,105,99,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,51,206,21,225,3,0,32,0,101,112,114,45,55,54,54,48,46,105,99,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,104,187,223,134,3,0,32,0,101,112,114,45,55,54,53,50,46,105,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,219,207,128,40,3,0,32,0,101,112,114,45,55,54,55,53,46,105,99,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,97,45,205,5,3,0,32,0,101,112,114,45,55,54,54,55,46,105,99,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,157,222,59,146,3,0,32,0,101,112,114,45,55,54,53,57,46,105,99,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,206,200,157,98,3,0,32,0,101,112,114,45,55,54,53,49,46,105,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,173,43,144,215,3,0,32,0,101,112,114,45,55,54,55,52,46,105,99,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,207,154,18,26,3,0,32,0,101,112,114,45,55,54,54,54,46,105,99,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,87,114,105,35,3,0,32,0,101,112,114,45,55,54,53,56,46,105,99,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,79,242,119,22,3,0,32,0,101,112,114,45,55,54,53,48,46,105,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,236,53,38,100,3,0,32,0,101,112,114,45,55,54,55,51,46,105,99,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,148,35,96,130,3,0,32,0,101,112,114,45,55,54,54,53,46,105,99,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,7,118,215,18,3,0,32,0,101,112,114,45,55,54,53,55,46,105,99,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,156,131,88,129,3,0,32,0,101,112,114,45,55,54,52,57,46,105,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,76,161,219,78,3,0,32,0,101,112,114,45,55,54,55,50,46,105,99,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,247,82,20,209,3,0,32,0,101,112,114,45,55,54,54,52,46,105,99,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,173,207,242,13,3,0,32,0,101,112,114,45,55,54,53,54,46,105,99,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,114,18,116,108,3,0,32,0,101,112,114,45,55,54,52,56,46,105,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,48,168,62,152,3,0,32,0,101,112,114,45,55,54,55,49,46,105,99,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,198,253,199,176,3,0,32,0,101,112,114,45,55,54,54,51,46,105,99,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,8,143,11,43,3,0,32,0,101,112,114,45,55,54,53,53,46,105,99,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,123,254,51,52,3,0,32,0,101,112,114,45,55,54,52,55,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,192,190,127,46,3,0,32,0,101,112,114,45,55,54,51,51,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,16,98,20,111,10,0,32,0,101,112,114,45,55,55,54,53,46,105,99,55,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,201,47,200,129,4,0,16,1,101,112,114,45,55,55,54,52,46,105,99,55,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,173,253,91,117,4,0,16,1,101,112,114,45,55,55,54,50,46,105,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,18,77,12,188,11,0,64,0,101,112,114,45,55,55,54,51,46,105,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,140,60,123,98,11,0,64,0,101,112,114,45,54,56,52,52,46,105,99,49,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,214,123,236,227,16,0,32,0,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,123,0,0,0,0,0,21,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,8,0,200,87,7,0,19,0,0,0,1,7,4,0,32,136,7,0,19,0,0,0,1,7,5,0,40,88,7,0,19,0,0,0,1,7,6,0,96,39,7,0,19,0,0,0,1,7,7,0,144,251,6,0,19,0,0,0,1,7,3,0,184,164,6,0,19,0,0,0,1,7,2,0,80,74,6,0,19,0,0,0,1,7,1,0,192,32,6,0,19,0,0,0,1,7,0,0,16,227,4,0,0,0,0,0,254,0,8,0,160,123,6,0,19,0,0,0,1,56,32,0,32,136,7,0,19,0,0,0,1,56,40,0,40,88,7,0,19,0,0,0,1,56,48,0,96,39,7,0,19,0,0,0,1,56,56,0,144,251,6,0,19,0,0,0,1,56,24,0,184,164,6,0,19,0,0,0,1,56,16,0,80,74,6,0,19,0,0,0,1,56,8,0,192,32,6,0,19,0,0,0,1,56,0,0,16,227,4,0,0,0,0,0,254,0,2,0,120,36,2,0,19,0,0,0,1,64,0,0,96,135,7,0,19,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,0,147,7,0,19,0,0,0,1,128,128,0,192,255,2,0,19,0,0,0,1,128,0,0,208,75,4,0,0,0,0,0,254,0,2,0,232,75,4,0,20,0,0,0,1,1,1,0,96,135,7,0,20,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,20,0,0,0,1,2,2,0,96,135,7,0,20,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,20,0,0,0,1,4,4,0,96,135,7,0,20,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,24,16,0,80,246,3,0,20,0,0,0,1,24,24,0,248,38,7,0,20,0,0,0,1,24,8,0,112,212,3,0,20,0,0,0,1,24,0,0,248,160,5,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,96,64,0,208,75,4,0,20,0,0,0,1,96,96,0,8,49,4,0,20,0,0,0,1,96,32,0,152,21,4,0,20,0,0,0,1,96,0,0,72,246,3,0,0,0,0,0,254,0,2,0,128,112,3,0,20,0,0,0,1,128,0,0,168,22,4,0,20,0,0,0,1,128,128,0,224,247,3,0,0,0,0,0,117,101,99,101,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,55,17,44,236,1,0,16,1,117,101,99,101,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,219,153,95,179,1,0,16,1,117,101,99,101,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,49,45,212,217,1,0,16,1,117,101,99,101,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,207,113,151,157,1,0,16,1,117,101,99,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,54,20,175,220,5,0,32,0,117,101,99,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,65,223,7,40,5,0,32,0,117,101,99,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,2,141,112,138,5,0,32,0,117,101,99,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,239,224,123,222,5,0,32,0,117,101,99,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,88,53,0,26,5,0,32,0,117,101,99,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,249,166,248,79,5,0,32,0,117,101,99,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,18,174,103,177,5,0,32,0,117,101,99,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,194,189,100,16,5,0,32,0,117,101,99,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,21,189,53,194,10,0,16,1,117,101,99,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,57,93,178,129,12,0,64,0,117,101,99,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,82,158,114,39,12,0,64,0,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,243,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,2,2,0,96,135,7,0,19,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,4,4,0,96,135,7,0,19,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,8,0,0,96,135,7,0,19,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,19,0,0,0,1,48,16,0,96,39,7,0,19,0,0,0,1,48,48,0,144,251,6,0,19,0,0,0,1,48,0,0,120,211,6,0,19,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,19,0,0,0,1,192,64,0,96,39,7,0,19,0,0,0,1,192,192,0,144,251,6,0,19,0,0,0,1,192,0,0,120,211,6,0,19,0,0,0,1,192,128,0,184,164,6,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,3,2,0,80,246,3,0,20,0,0,0,1,3,3,0,80,124,6,0,20,0,0,0,1,3,1,0,112,212,3,0,20,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,64,37,5,0,20,0,0,0,1,12,0,0,8,192,4,0,20,0,0,0,1,12,8,0,240,191,4,0,20,0,0,0,1,12,4,0,144,227,4,0,20,0,0,0,1,12,12,0,120,7,5,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,48,0,0,192,255,2,0,20,0,0,0,1,48,48,0,208,75,4,0,20,0,0,0,1,48,32,0,8,49,4,0,20,0,0,0,1,48,16,0,152,21,4,0,0,0,0,0,254,0,2,0,192,76,8,0,20,0,0,0,1,64,64,0,40,52,7,0,20,0,0,0,1,64,0,0,8,71,8,0,0,0,0,0,116,107,49,106,95,50,51,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,9,48,138,8,2,0,16,1,116,107,49,106,95,50,50,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,207,75,101,147,2,0,16,1,116,107,49,95,48,49,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,160,182,75,246,4,0,32,0,116,107,49,95,48,50,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,116,98,254,33,4,0,32,0,116,107,49,95,48,51,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,203,40,242,11,4,0,32,0,116,107,49,95,48,52,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,177,223,85,18,4,0,32,0,116,107,49,95,48,53,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,30,102,247,68,4,0,32,0,116,107,49,95,48,54,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0])
.concat([93,81,76,165,4,0,32,0,116,107,49,95,48,55,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,124,104,92,202,4,0,32,0,116,107,49,95,48,56,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,145,101,254,249,4,0,32,0,116,107,49,95,48,57,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,153,216,119,219,3,0,16,0,116,107,49,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,180,108,95,126,5,0,64,0,116,107,49,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,55,199,48,74,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,116,107,49,54,51,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,0,0,0,0,0,0,24,105,111,98,49,46,49,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,98,112,114,103,49,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,167,61,121,49,0,0,0,8,105,111,99,49,46,105,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,129,32,24,13,0,0,0,8,99,54,51,50,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,112,146,189,15,0,0,0,8,168,86,7,0,1,0,0,0,232,47,216,0,248,191,2,0,24,38,7,0,1,0,0,0,236,47,216,0,184,160,2,0,56,210,6,0,1,0,0,0,35,48,216,0,192,135,2,0,24,163,6,0,1,0,0,0,34,48,216,0,240,108,2,0,152,122,6,0,1,0,0,0,33,48,216,0,96,82,2,0,192,72,6,0,1,0,0,0,32,48,216,0,32,56,2,0,200,207,6,0,1,0,0,0,36,48,216,0,152,30,2,0,40,204,6,0,1,0,0,0,37,48,216,0,232,10,2,0,104,184,3,0,1,0,0,0,38,48,216,0,152,138,8,0,40,246,1,0,1,0,0,0,233,47,216,0,64,246,1,0,144,236,1,0,1,0,0,0,237,47,216,0,136,224,1,0,176,223,1,0,1,0,0,0,43,48,216,0,72,198,1,0,192,209,1,0,1,0,0,0,42,48,216,0,24,182,1,0,24,198,1,0,1,0,0,0,41,48,216,0,40,167,1,0,120,189,1,0,1,0,0,0,40,48,216,0,200,149,1,0,240,200,6,0,1,0,0,0,44,48,216,0,56,126,1,0,168,197,6,0,1,0,0,0,45,48,216,0,32,101,1,0,208,41,1,0,1,0,0,0,46,48,216,0,96,32,8,0,88,212,3,0,1,0,0,0,144,46,216,0,40,185,3,0,16,17,8,0,1,0,0,0,234,47,216,0,224,12,8,0,72,65,1,0,9,0,0,0,232,48,216,0,32,58,1,0,48,50,1,0,9,0,0,0,224,48,216,0,32,58,1,0,224,41,1,0,9,0,0,0,216,48,216,0,32,58,1,0,34,0,0,0,255,255,191,0,0,0,0,0,35,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,34,0,0,0,1,3,2,0,208,75,4,0,34,0,0,0,1,3,3,0,8,49,4,0,34,0,0,0,1,3,1,0,152,21,4,0,34,0,0,0,1,3,0,0,72,246,3,0,0,0,0,0,254,0,4,0,72,202,5,0,34,0,0,0,1,12,8,0,80,246,3,0,34,0,0,0,1,12,12,0,80,124,6,0,34,0,0,0,1,12,4,0,112,212,3,0,34,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,2,0,184,123,7,0,34,0,0,0,1,16,16,0,8,214,7,0,34,0,0,0,1,16,0,0,88,207,7,0,0,0,0,0,254,0,2,0,104,159,3,0,34,0,0,0,1,32,0,0,56,111,3,0,34,0,0,0,1,32,32,0,104,134,3,0,0,0,0,0,254,0,2,0,168,234,7,0,34,0,0,0,1,64,64,0,96,135,7,0,34,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,34,0,0,0,1,128,128,0,96,135,7,0,34,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,35,0,0,0,1,1,1,0,96,135,7,0,35,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,4,0,200,30,2,0,35,0,0,0,1,6,4,0,224,228,7,0,35,0,0,0,1,6,6,0,80,225,7,0,35,0,0,0,1,6,2,0,168,221,7,0,35,0,0,0,1,6,0,0,96,19,1,0,0,0,0,0,254,0,2,0,96,46,8,0,35,0,0,0,1,8,8,0,192,255,2,0,35,0,0,0,1,8,0,0,208,75,4,0,0,0,0,0,254,0,16,0,32,4,2,0,35,0,0,0,1,240,160,0,144,160,3,0,35,0,0,0,1,240,176,0,96,135,3,0,35,0,0,0,1,240,192,0,32,136,7,0,35,0,0,0,1,240,208,0,40,88,7,0,35,0,0,0,1,240,224,0,96,39,7,0,35,0,0,0,1,240,16,0,32,202,2,0,35,0,0,0,1,240,48,0,120,113,6,0,35,0,0,0,1,240,32,0,232,228,5,0,35,0,0,0,1,240,240,0,144,251,6,0,35,0,0,0,1,240,64,0,120,211,6,0,35,0,0,0,1,240,144,0,184,164,6,0,35,0,0,0,1,240,128,0,80,74,6,0,35,0,0,0,1,240,112,0,192,32,6,0,35,0,0,0,1,240,96,0,192,234,2,0,35,0,0,0,1,240,80,0,32,242,5,0,35,0,0,0,1,240,0,0,16,227,4,0,101,112,114,45,49,48,52,55,48,46,97,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,31,118,96,140,1,0,16,1,101,112,114,45,49,48,52,54,55,46,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,20,65,119,41,1,0,16,1,101,112,114,45,49,48,52,55,49,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,20,115,119,34,1,0,16,1,101,112,114,45,49,48,52,54,56,46,97,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,122,249,213,226,1,0,16,1,101,112,114,45,49,48,52,55,50,46,97,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,166,39,96,32,1,0,16,1,101,112,114,45,49,48,52,54,57,46,97,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,129,43,68,170,1,0,16,1,101,112,114,45,49,48,52,56,53,46,98,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,41,218,109,241,2,0,32,0,101,112,114,45,49,48,52,56,54,46,98,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,60,151,29,49,2,0,32,0,101,112,114,45,49,48,52,56,55,46,98,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,159,23,251,168,2,0,32,0,101,112,114,45,49,48,52,55,55,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,203,178,211,249,3,0,32,0,101,112,114,45,49,48,52,56,49,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,201,75,176,254,3,0,32,0,101,112,114,45,49,48,52,55,56,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,146,92,92,91,3,0,32,0,101,112,114,45,49,48,52,56,50,46,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,24,118,192,91,3,0,32,0,101,112,114,45,49,48,52,55,57,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,160,144,65,232,3,0,32,0,101,112,114,45,49,48,52,56,51,46,98,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,158,79,171,124,3,0,32,0,101,112,114,45,49,48,52,56,48,46,98,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,221,217,255,93,3,0,32,0,101,112,114,45,49,48,52,56,52,46,98,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,201,252,181,188,3,0,32,0,101,112,114,45,49,48,52,55,51,46,97,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,39,90,31,127,4,0,16,1,101,112,114,45,49,48,52,55,52,46,97,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,110,101,154,65,8,0,64,0,101,112,114,45,49,48,52,55,53,46,97,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,133,94,213,23,8,0,64,0,101,112,114,45,49,48,52,55,54,46,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,86,9,190,166,8,0,64,0,51,49,55,45,48,48,50,50,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,109,198,237,78,5,0,16,1,33,0,0,0,255,255,253,0,0,0,0,0,34,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,168,234,7,0,33,0,0,0,1,2,2,0,96,135,7,0,33,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,4,0,104,153,2,0,33,0,0,0,1,12,8,0,136,151,2,0,33,0,0,0,1,12,12,0,56,150,2,0,33,0,0,0,1,12,4,0,56,148,2,0,33,0,0,0,1,12,0,0,224,146,2,0,0,0,0,0,254,0,4,0,72,202,5,0,33,0,0,0,1,48,32,0,80,246,3,0,33,0,0,0,1,48,48,0,248,38,7,0,33,0,0,0,1,48,16,0,112,212,3,0,33,0,0,0,1,48,0,0,248,160,5,0,0,0,0,0,254,0,2,0,56,146,2,0,33,0,0,0,1,64,64,0,96,135,7,0,33,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,16,0,200,87,7,0,34,0,0,0,1,15,7,0,80,252,6,0,34,0,0,0,1,15,8,0,16,242,7,0,34,0,0,0,1,15,9,0,104,236,7,0,34,0,0,0,1,15,5,0,176,51,4,0,34,0,0,0,1,15,4,0,56,24,4,0,34,0,0,0,1,15,15,0,128,230,7,0,34,0,0,0,1,15,1,0,72,216,3,0,34,0,0,0,1,15,2,0,24,188,3,0,34,0,0,0,1,15,3,0,176,162,3,0,34,0,0,0,1,15,6,0,120,211,6,0,34,0,0,0,1,15,14,0,184,164,6,0,34,0,0,0,1,15,13,0,80,74,6,0,34,0,0,0,1,15,12,0,192,32,6,0,34,0,0,0,1,15,11,0,192,234,2,0,34,0,0,0,1,15,10,0,32,242,5,0,34,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,34,0,0,0,1,240,112,0,80,252,6,0,34,0,0,0,1,240,128,0,16,242,7,0,34,0,0,0,1,240,144,0,104,236,7,0,34,0,0,0,1,240,80,0,176,51,4,0,34,0,0,0,1,240,64,0,56,24,4,0,34,0,0,0,1,240,240,0,128,230,7,0,34,0,0,0,1,240,16,0,72,216,3,0,34,0,0,0,1,240,32,0,24,188,3,0,34,0,0,0,1,240,48,0,176,162,3,0,34,0,0,0,1,240,96,0,120,211,6,0,34,0,0,0,1,240,224,0,184,164,6,0,34,0,0,0,1,240,208,0,80,74,6,0,34,0,0,0,1,240,192,0,192,32,6,0,34,0,0,0,1,240,176,0,192,234,2,0,34,0,0,0,1,240,160,0,32,242,5,0,34,0,0,0,1,240,0,0,208,236,2,0,101,112,114,45,55,55,48,52,97,46,98,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,123,108,222,150,1,0,16,1,101,112,114,45,55,55,48,49,97,46,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,9,16,109,120,1,0,16,1,101,112,114,45,55,55,48,53,97,46,98,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,145,67,88,252,1,0,16,1,101,112,114,45,55,55,48,50,97,46,98,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,253,168,65,34,1,0,16,1,101,112,114,45,55,55,48,54,97,46,98,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,208,201,188,107,1,0,16,1,101,112,114,45,55,55,48,51,97,46,98,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,64,205,176,252,1,0,16,1,101,112,114,45,55,55,48,55,97,46,99,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,56,135,49,69,2,0,32,0,101,112,114,45,55,55,48,56,97,46,99,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,164,233,27,65,2,0,32,0,101,112,114,45,55,55,48,57,97,46,99,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,168,181,206,116,2,0,32,0,101,112,114,45,55,55,49,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,64,224,71,191,3,0,32,0,101,112,114,45,55,55,49,57,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,108,93,92,250,3,0,32,0,101,112,114,45,49,48,48,49,51,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,197,25,9,154,3,0,32,0,101,112,114,45,49,48,48,49,55,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,149,253,170,98,3,0,32,0,101,112,114,45,55,55,49,55,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,109,200,100,250,3,0,32,0,101,112,114,45,55,55,50,49,46,98,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,62,20,169,98,3,0,32,0,101,112,114,45,49,48,48,49,53,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,106,59,45,88,3,0,32,0,101,112,114,45,49,48,48,49,57,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,139,195,32,224,3,0,32,0,101,112,114,45,55,55,49,48,97,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,168,139,155,161,4,0,16,1,55,55,53,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,252,52,149,106,6,0,16,1,101,112,114,45,55,55,49,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,189,170,169,239,7,0,64,0,101,112,114,45,55,55,49,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,207,133,205,123,7,0,64,0,101,112,114,45,55,55,49,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,231,146,242,51,7,0,64,0,101,112,114,45,55,55,49,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,71,140,212,143,7,0,64,0,51,49,55,45,48,48,49,49,97,46,109,99,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,16,118,97,109,117,46,48,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,249,153,136,98,1,0,16,1,118,97,109,117,46,48,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,37,155,109,105,1,0,16,1,118,97,109,117,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,10,213,62,103,1,0,16,1,118,97,109,117,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,231,123,55,242,1,0,16,1,118,97,109,117,46,48,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,196,152,244,216,1,0,16,1,118,97,109,117,46,48,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,160,161,168,230,1,0,16,1,118,97,109,117,46,48,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,36,91,213,141,1,0,16,1,118,97,109,117,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,190,217,163,193,1,0,16,1,118,97,109,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,153,175,27,197,5,0,32,0,118,97,109,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,119,60,232,60,5,0,32,0,118,97,109,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,224,8,36,79,5,0,32,0,118,97,109,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,80,2,246,159,5,0,32,0,118,97,109,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,60,36,135,189,5,0,32,0,118,97,109,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,95,133,236,175,5,0,32,0,118,97,109,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,37,54,3,58,5,0,32,0,118,97,109,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0])
.concat([137,106,255,43,5,0,32,0,118,97,109,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,213,133,182,100,10,0,16,1,118,97,109,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,199,151,124,207,10,0,16,1,118,97,109,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,178,222,57,74,12,0,64,0,118,97,109,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,3,92,62,26,12,0,64,0,118,97,109,117,100,46,48,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,128,166,183,71,1,0,16,1,118,97,109,117,100,46,48,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,57,73,122,59,1,0,16,1,118,97,109,117,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,10,213,62,103,1,0,16,1,118,97,109,117,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,231,123,55,242,1,0,16,1,118,97,109,117,46,48,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,196,152,244,216,1,0,16,1,118,97,109,117,46,48,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,160,161,168,230,1,0,16,1,118,97,109,117,100,46,48,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,25,58,51,139,1,0,16,1,118,97,109,117,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,190,217,163,193,1,0,16,1,118,97,109,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,153,175,27,197,5,0,32,0,118,97,109,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,119,60,232,60,5,0,32,0,118,97,109,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,224,8,36,79,5,0,32,0,118,97,109,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,80,2,246,159,5,0,32,0,118,97,109,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,60,36,135,189,5,0,32,0,118,97,109,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,95,133,236,175,5,0,32,0,118,97,109,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,37,54,3,58,5,0,32,0,118,97,109,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,137,106,255,43,5,0,32,0,118,97,109,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,213,133,182,100,10,0,16,1,118,97,109,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,199,151,124,207,10,0,16,1,118,97,109,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,178,222,57,74,12,0,64,0,118,97,109,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,3,92,62,26,12,0,64,0,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,104,208,89,72,0,0,16,1,52,45,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,137,69,58,35,0,0,16,1,49,45,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,110,232,40,237,0,0,16,1,103,103,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,111,91,95,97,0,0,16,1,103,103,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,7,207,252,236,0,0,32,0,103,103,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,169,111,213,221,0,0,32,0,103,103,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,157,82,2,115,0,0,32,0,103,103,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,218,91,3,32,0,0,32,0,103,103,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,113,162,43,241,0,0,32,0,103,103,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,125,32,37,229,0,0,32,0,103,103,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,178,233,119,45,0,0,32,0,103,103,49,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,143,10,229,147,0,0,32,0,103,103,49,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,202,229,215,6,0,0,32,0,103,103,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,45,224,31,188,0,0,32,0,103,103,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,249,18,175,106,0,0,32,0,103,103,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,202,63,12,232,0,0,32,0,103,103,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,37,169,128,119,0,0,32,0,116,98,112,50,52,115,49,48,46,49,52,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,88,81,175,14,0,0,32,0,54,51,115,49,52,49,46,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,164,133,18,74,0,0,32,0,103,103,45,112,97,108,49,48,108,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,44,0,0,0,224,183,241,135,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,19,0,0,0,255,255,254,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,19,0,0,0,1,1,0,0,120,97,1,0,19,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,2,2,0,96,135,7,0,19,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,4,4,0,96,135,7,0,19,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,8,0,0,96,135,7,0,19,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,19,0,0,0,1,48,16,0,96,39,7,0,19,0,0,0,1,48,48,0,144,251,6,0,19,0,0,0,1,48,0,0,120,211,6,0,19,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,19,0,0,0,1,192,64,0,96,39,7,0,19,0,0,0,1,192,192,0,144,251,6,0,19,0,0,0,1,192,0,0,120,211,6,0,19,0,0,0,1,192,128,0,184,164,6,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,3,2,0,80,246,3,0,20,0,0,0,1,3,3,0,80,124,6,0,20,0,0,0,1,3,1,0,112,212,3,0,20,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,64,37,5,0,20,0,0,0,1,12,12,0,32,143,7,0,20,0,0,0,1,12,0,0,48,137,7,0,20,0,0,0,1,12,4,0,8,133,7,0,20,0,0,0,1,12,8,0,112,129,7,0,0,0,0,0,254,0,0,0,128,129,4,0,20,0,0,0,1,48,32,0,208,75,4,0,20,0,0,0,1,48,48,0,8,49,4,0,20,0,0,0,1,48,16,0,152,21,4,0,20,0,0,0,1,48,0,0,72,246,3,0,0,0,0,0,19,0,0,0,255,255,254,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,19,0,0,0,1,1,0,0,120,97,1,0,19,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,2,2,0,96,135,7,0,19,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,4,4,0,96,135,7,0,19,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,8,0,0,96,135,7,0,19,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,19,0,0,0,1,48,0,0,32,136,7,0,19,0,0,0,1,48,16,0,40,88,7,0,19,0,0,0,1,48,32,0,96,39,7,0,19,0,0,0,1,48,48,0,144,251,6,0,0,0,0,0,254,0,4,0,160,123,6,0,19,0,0,0,1,192,192,0,184,164,6,0,19,0,0,0,1,192,128,0,80,74,6,0,19,0,0,0,1,192,64,0,192,32,6,0,19,0,0,0,1,192,0,0,32,242,5,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,3,2,0,80,246,3,0,20,0,0,0,1,3,3,0,80,124,6,0,20,0,0,0,1,3,1,0,112,212,3,0,20,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,64,37,5,0,20,0,0,0,1,12,12,0,32,143,7,0,20,0,0,0,1,12,0,0,48,137,7,0,20,0,0,0,1,12,4,0,8,133,7,0,20,0,0,0,1,12,8,0,112,129,7,0,0,0,0,0,254,0,0,0,128,129,4,0,20,0,0,0,1,48,32,0,208,75,4,0,20,0,0,0,1,48,48,0,8,49,4,0,20,0,0,0,1,48,16,0,152,21,4,0,20,0,0,0,1,48,0,0,72,246,3,0,0,0,0,0,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,80,103,10,48,4,0,32,0,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,196,20,78,240,4,0,32,0,116,98,112,49,56,115,48,51,48,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,174,221,16,49,7,0,32,0,116,98,112,49,56,115,48,51,48,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,175,130,7,15,7,0,32,0,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,203,4,182,154,8,0,16,1,116,98,112,50,52,115,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,109,136,13,140,0,0,0,8,116,98,112,50,56,115,52,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,10,49,143,155,0,0,0,8,7,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,100,102,103,106,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,231,241,25,142,4,0,32,0,100,102,103,106,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,168,12,182,134,4,0,32,0,100,102,103,108,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,89,153,94,234,4,0,32,0,100,102,103,108,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,92,25,237,183,4,0,32,0,116,111,112,46,99,108,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,174,221,16,49,7,0,32,0,98,111,116,46,99,108,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,175,130,7,15,7,0,32,0,100,102,103,112,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,125,231,213,82,8,0,16,1,100,102,103,112,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,206,219,244,156,8,0,16,1,100,102,103,112,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,98,63,118,121,8,0,16,1,100,102,103,112,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,139,51,149,221,8,0,16,1,7,0,0,0,255,255,0,0,0,0,0,0,8,0,0,0,255,255,0,0,0,0,0,0,9,0,0,0,255,255,0,0,0,0,0,0,10,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,32,4,2,0,8,0,0,0,1,64,64,0,144,147,2,0,8,0,0,0,1,64,0,0,184,146,2,0,0,0,0,0,100,102,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,224,61,220,138,4,0,32,0,100,102,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,53,236,149,109,4,0,32,0,116,111,112,46,99,108,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,174,221,16,49,7,0,32,0,98,111,116,46,99,108,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,175,130,7,15,7,0,32,0,100,102,112,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,29,152,178,181,8,0,16,1,100,114,105,118,101,111,117,116,46,48,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,78,30,67,220,2,0,16,1,100,114,105,118,101,111,117,116,46,48,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,244,99,144,111,2,0,16,1,100,114,105,118,101,111,117,116,46,48,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,46,235,170,153,9,0,16,1,100,114,105,118,101,111,117,116,46,48,56,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,32,196,10,83,16,0,32,0,100,114,105,118,101,111,117,116,46,48,56,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,158,62,154,14,16,0,32,0,100,111,95,112,105,118,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,247,18,240,196,28,0,32,0,100,114,105,118,101,111,117,116,46,48,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,102,11,222,203,29,0,64,0,100,114,105,118,101,111,117,116,46,48,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,38,32,186,10,29,0,64,0,105,99,52,54,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,56,55,48,113,2,0,16,1,105,99,52,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,202,30,248,67,2,0,16,1,100,111,95,53,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,36,1,225,255,9,0,16,1,100,111,95,111,98,106,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,196,241,145,84,15,0,32,0,100,111,95,115,110,100,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,43,184,222,242,24,0,64,0,100,111,95,112,105,118,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,247,18,240,196,28,0,32,0,12,0,0,0,255,255,255,0,0,0,0,0,13,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,12,0,0,0,1,2,2,0,96,135,7,0,12,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,12,0,0,0,1,4,4,0,96,135,7,0,12,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,12,0,0,0,1,8,0,0,96,135,7,0,12,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,12,0,0,0,1,48,0,0,104,236,7,0,12,0,0,0,1,48,48,0,128,230,7,0,12,0,0,0,1,48,0,0,120,211,6,0,12,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,4,0])
.concat([160,123,6,0,12,0,0,0,1,192,64,0,104,236,7,0,12,0,0,0,1,192,192,0,128,230,7,0,12,0,0,0,1,192,0,0,120,211,6,0,12,0,0,0,1,192,128,0,184,164,6,0,0,0,0,0,254,0,4,0,72,202,5,0,13,0,0,0,1,3,2,0,80,246,3,0,13,0,0,0,1,3,3,0,80,124,6,0,13,0,0,0,1,3,1,0,112,212,3,0,13,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,24,113,4,0,13,0,0,0,1,12,12,0,120,26,6,0,13,0,0,0,1,12,8,0,216,109,4,0,13,0,0,0,1,12,4,0,120,26,6,0,13,0,0,0,1,12,0,0,56,107,4,0,0,0,0,0,21,0,0,0,255,255,254,0,0,0,0,0,22,0,0,0,255,255,255,0,0,0,0,0,23,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,72,202,5,0,21,0,0,0,1,3,3,0,80,246,3,0,21,0,0,0,1,3,2,0,248,38,7,0,21,0,0,0,1,3,1,0,112,212,3,0,21,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,64,37,5,0,21,0,0,0,1,12,8,0,64,18,2,0,21,0,0,0,1,12,12,0,128,17,2,0,21,0,0,0,1,12,4,0,72,16,2,0,21,0,0,0,1,12,0,0,64,15,2,0,0,0,0,0,254,0,4,0,128,129,4,0,21,0,0,0,1,48,0,0,192,255,2,0,21,0,0,0,1,48,16,0,208,75,4,0,21,0,0,0,1,48,48,0,8,49,4,0,21,0,0,0,1,48,32,0,72,246,3,0,0,0,0,0,254,0,2,0,144,212,8,0,22,0,0,0,1,2,2,0,96,135,7,0,22,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,0,0,168,234,7,0,22,0,0,0,1,4,4,0,40,14,2,0,22,0,0,0,1,4,0,0,112,13,2,0,0,0,0,0,254,0,2,0,232,75,4,0,22,0,0,0,1,8,8,0,96,135,7,0,22,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,2,0,200,87,7,0,22,0,0,0,1,48,16,0,96,39,7,0,22,0,0,0,1,48,48,0,144,251,6,0,22,0,0,0,1,48,0,0,120,211,6,0,22,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,2,0,160,123,6,0,22,0,0,0,1,192,64,0,96,39,7,0,22,0,0,0,1,192,192,0,144,251,6,0,22,0,0,0,1,192,0,0,120,211,6,0,22,0,0,0,1,192,128,0,184,164,6,0,0,0,0,0,254,0,4,0,32,176,1,0,23,0,0,0,1,16,16,0,192,255,2,0,23,0,0,0,1,16,0,0,208,75,4,0,0,0,0,0,254,0,4,0,128,94,5,0,23,0,0,0,1,32,32,0,64,11,2,0,23,0,0,0,1,32,0,0,128,10,2,0,0,0,0,0,254,0,2,0,48,10,2,0,23,0,0,0,1,192,192,0,200,9,2,0,23,0,0,0,1,192,128,0,80,9,2,0,23,0,0,0,1,192,64,0,120,8,2,0,23,0,0,0,1,192,0,0,200,7,2,0,101,103,48,52,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,248,179,184,65,0,0,16,1,101,103,48,49,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,133,104,142,224,0,0,16,1,101,103,48,54,46,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,247,250,129,43,0,0,16,1,101,103,48,51,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,157,46,44,197,0,0,16,1,101,103,48,55,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,81,47,29,0,0,0,16,1,101,103,50,53,46,49,53,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,25,123,85,221,0,0,32,0,101,103,50,54,46,49,54,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,143,252,117,93,0,0,32,0,101,103,49,56,46,49,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,229,195,207,5,0,0,32,0,101,103,50,48,46,49,55,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,143,152,30,225,0,0,32,0,101,103,50,50,46,49,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,128,216,147,184,0,0,32,0,101,103,50,52,46,49,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,218,109,34,111,0,0,32,0,101,103,51,48,46,57,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,126,230,56,36,0,0,32,0,101,103,50,56,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,179,42,105,92,0,0,32,0,101,103,49,53,46,49,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,127,214,23,86,0,0,32,0,101,103,49,54,46,49,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,51,38,228,23,0,0,32,0,101,103,49,49,46,49,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,216,232,131,186,0,0,32,0,101,103,49,50,46,49,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,52,161,162,254,0,0,32,0,101,103,49,51,46,49,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,142,224,145,253,0,0,32,0,101,103,49,52,46,49,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,10,118,60,232,0,0,32,0,101,103,48,57,46,49,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,35,123,27,96,0,0,32,0,101,103,49,48,46,49,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,26,138,238,238,0,0,32,0,101,103,48,56,46,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,22,201,242,146,0,0,64,0,105,56,55,53,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,16,16,18,0,0,0,255,255,255,0,0,0,0,0,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,2,0,0,0,0,0,0,0,0,0,254,0,4,0,160,123,6,0,18,0,0,0,1,3,0,0,40,88,7,0,18,0,0,0,1,3,1,0,96,39,7,0,18,0,0,0,1,3,3,0,144,251,6,0,18,0,0,0,1,3,2,0,184,164,6,0,0,0,0,0,254,0,2,0,72,4,1,0,18,0,0,0,1,4,4,0,96,135,7,0,18,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,112,47,6,0,18,0,0,0,1,8,8,0,96,135,7,0,18,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,18,0,0,0,1,16,0,0,96,135,7,0,18,0,0,0,1,16,16,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,18,0,0,0,1,96,0,0,40,88,7,0,18,0,0,0,1,96,32,0,96,39,7,0,18,0,0,0,1,96,96,0,144,251,6,0,18,0,0,0,1,96,64,0,184,164,6,0,0,0,0,0,254,0,2,0,232,75,4,0,18,0,0,0,1,128,128,0,96,135,7,0,18,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,19,0,0,0,1,1,1,0,56,111,3,0,19,0,0,0,1,1,0,0,104,134,3,0,0,0,0,0,254,0,2,0,248,49,5,0,19,0,0,0,1,2,2,0,32,76,3,0,19,0,0,0,1,2,0,0,64,240,4,0,0,0,0,0,254,0,4,0,48,206,4,0,19,0,0,0,1,12,0,0,176,108,5,0,19,0,0,0,1,12,8,0,8,141,4,0,19,0,0,0,1,12,4,0,144,112,4,0,19,0,0,0,1,12,12,0,120,7,5,0,0,0,0,0,254,0,4,0,192,60,4,0,19,0,0,0,1,48,0,0,232,146,5,0,19,0,0,0,1,48,48,0,192,3,4,0,19,0,0,0,1,48,16,0,32,226,3,0,19,0,0,0,1,48,32,0,176,108,5,0,0,0,0,0,254,0,2,0,128,195,3,0,19,0,0,0,1,64,64,0,248,38,7,0,19,0,0,0,1,64,0,0,48,123,8,0,0,0,0,0,254,0,2,0,232,119,3,0,19,0,0,0,1,128,128,0,248,38,7,0,19,0,0,0,1,128,0,0,48,123,8,0,0,0,0,0,254,0,2,0,200,30,2,0,20,0,0,0,1,2,2,0,120,97,1,0,20,0,0,0,1,2,0,0,96,19,1,0,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,1,0,0,96,135,7,0,19,0,0,0,1,1,1,0,152,182,7,0,0,0,0,0,254,0,8,0,200,87,7,0,19,0,0,0,1,224,0,0,104,54,4,0,19,0,0,0,1,224,128,0,232,228,5,0,19,0,0,0,1,224,64,0,16,242,7,0,19,0,0,0,1,224,32,0,104,236,7,0,19,0,0,0,1,224,224,0,128,230,7,0,19,0,0,0,1,224,96,0,184,164,6,0,19,0,0,0,1,224,160,0,80,74,6,0,19,0,0,0,1,224,192,0,192,32,6,0,0,0,0,0,254,0,8,0,160,123,6,0,19,0,0,0,1,28,0,0,104,54,4,0,19,0,0,0,1,28,16,0,232,228,5,0,19,0,0,0,1,28,8,0,16,242,7,0,19,0,0,0,1,28,4,0,104,236,7,0,19,0,0,0,1,28,28,0,128,230,7,0,19,0,0,0,1,28,12,0,184,164,6,0,19,0,0,0,1,28,20,0,80,74,6,0,19,0,0,0,1,28,24,0,192,32,6,0,0,0,0,0,254,0,4,0,104,115,3,0,20,0,0,0,1,48,0,0,208,75,4,0,20,0,0,0,1,48,48,0,8,49,4,0,20,0,0,0,1,48,16,0,152,21,4,0,20,0,0,0,1,48,32,0,72,246,3,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,192,0,0,192,255,2,0,20,0,0,0,1,192,192,0,208,75,4,0,20,0,0,0,1,192,64,0,8,49,4,0,20,0,0,0,1,192,128,0,152,21,4,0,0,0,0,0,20,0,0,0,255,255,32,0,0,0,0,0,21,0,0,0,255,255,1,0,0,0,0,0,0,0,0,0,254,0,2,0,232,75,4,0,20,0,0,0,1,32,32,0,96,135,7,0,20,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,48,45,3,0,21,0,0,0,1,1,0,0,176,20,3,0,21,0,0,0,1,1,1,0,224,32,1,0,21,0,0,0,255,255,246,0,0,0,0,0,22,0,0,0,255,255,189,0,0,0,0,0,23,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,80,14,3,0,21,0,0,0,1,1,1,0,240,11,3,0,21,0,0,0,1,1,0,0,224,32,1,0,0,0,0,0,254,0,2,0,144,212,8,0,21,0,0,0,1,2,2,0,96,135,7,0,21,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,21,0,0,0,1,4,4,0,96,135,7,0,21,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,21,0,0,0,1,8,8,0,96,135,7,0,21,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,21,0,0,0,1,48,16,0,96,39,7,0,21,0,0,0,1,48,48,0,144,251,6,0,21,0,0,0,1,48,0,0,120,211,6,0,21,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,21,0,0,0,1,192,64,0,96,39,7,0,21,0,0,0,1,192,192,0,144,251,6,0,21,0,0,0,1,192,0,0,120,211,6,0,21,0,0,0,1,192,128,0,184,164,6,0,0,0,0,0,254,0,4,0,72,202,5,0,22,0,0,0,1,3,2,0,80,246,3,0,22,0,0,0,1,3,3,0,248,38,7,0,22,0,0,0,1,3,1,0,112,212,3,0,22,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,64,37,5,0,22,0,0,0,1,12,12,0,48,129,4,0,22,0,0,0,1,12,8,0,8,7,3,0,22,0,0,0,1,12,4,0,216,32,3,0,22,0,0,0,1,12,0,0,176,38,3,0,0,0,0,0,254,0,4,0,128,129,4,0,22,0,0,0,1,48,16,0,208,75,4,0,22,0,0,0,1,48,48,0,8,49,4,0,22,0,0,0,1,48,0,0,152,21,4,0,22,0,0,0,1,48,32,0,72,246,3,0,0,0,0,0,254,0,2,0,80,3,3,0,22,0,0,0,1,64,64,0,224,120,4,0,22,0,0,0,1,64,0,0,64,246,3,0,0,0,0,0,254,0,2,0,32,176,1,0,22,0,0,0,1,128,128,0,192,255,2,0,22,0,0,0,1,128,0,0,208,75,4,0,6,0,0,0,7,0,0,0,98,57,53,45,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,122,232,252,208,2,0,16,1,98,57,53,45,49,49,45,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,211,12,212,218,2,0,16,1,98,57,53,45,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,11,31,110,164,2,0,16,1,98,57,53,45,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,81,19,78,110,2,0,16,1,98,57,53,45,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,225,73,170,181,9,0,16,1,98,57,53,45,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,121,233,180,103,11,0,32,0,98,57,53,45,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,206,118,193,81,15,0,32,0,98,57,53,45,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,22,23,76,172,24,0,64,0,98,57,53,45,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,209,160,58,84,28,0,32,0,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,2,2,0,96,135,7,0,19,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,4,4,0,96,135,7,0,19,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,8,0,0,96,135,7,0,19,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,19,0,0,0,1,48,0,0,80,252,6,0,19,0,0,0,1,48,16,0,16,242,7,0,19,0,0,0,1,48,32,0,104,236,7,0,19,0,0,0,1,48,48,0,128,230,7,0,0,0,0,0,254,0,4,0,160,123,6,0,19,0,0,0,1,192,192,0,8,201,6,0,19,0,0,0,1,192,128,0,200,197,6,0,19,0,0,0,1,192,64,0,152,194,6,0,19,0,0,0,1,192,0,0,248,189,6,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,3,2,0,80,246,3,0,20,0,0,0,1,3,3,0,80,124,6,0,20,0,0,0,1,3,1,0,112,212,3,0,20,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,64,37,5,0,20,0,0,0,1,12,12,0,96,103,4,0,20,0,0,0,1,12,8,0,0,101,4,0,20,0,0,0,1,12,4,0,48,99,4,0,20,0,0,0,1,12,0,0,96,97,4,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,48,32,0,208,75,4,0,20,0,0,0,1,48,48,0,8,49,4,0,20,0,0,0,1,48,0,0,152,21,4,0,20,0,0,0,1,48,16,0,72,246,3,0,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,233,134,148,41,1,0,16,1,97,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,59,25,74,167,1,0,16,1,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,54,242,196,123,1,0,16,1,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,33,76,89,15,1,0,16,1,100,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,150,114,125,207,1,0,16,1,101,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,82,138,82,247,1,0,16,1,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,197,76,29,155,1,0,16,1,118,95,51,112,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,239,255,116,73,4,0,32,0,97,50,46,103,102,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,175,94,132,81,4,0,32,0,118,95,51,110,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,99,76,92,169,4,0,32,0,98,50,46,103,102,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,208,195,57,123,4,0,32,0,104,117,115,116,108,101,114,46,99,108,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,94,127,31,170,7,0,32,0,14,0,0,0,255,255,0,0,0,0,0,0,15,0,0,0,255,255,0,0,0,0,0,0,16,0,0,0,255,255,8,0,0,0,0,0,0,0,0,0,254,0,4,0,32,4,2,0,15,0,0,0,1,192,192,0,176,45,8,0,15,0,0,0,1,192,64,0,224,127,8,0,15,0,0,0,1,192,0,0,32,123,8,0,15,0,0,0,1,192,128,0,192,110,8,0,0,0,0,0,254,0,2,0,176,128,1,0,16,0,0,0,1,1,0,0,192,211,1,0,16,0,0,0,1,1,1,0,200,200,1,0,0,0,0,0,254,0,4,0,128,129,4,0,16,0,0,0,1,6,0,0,8,49,4,0,16,0,0,0,1,6,2,0,152,21,4,0,16,0,0,0,1,6,4,0,72,246,3,0,16,0,0,0,1,6,6,0,72,0,3,0,0,0,0,0,254,0,2,0,200,30,2,0,16,0,0,0,1,8,8,0,120,97,1,0,16,0,0,0,1,8,0,0,96,19,1,0,0,0,0,0,114,117,110,48,49,46,119,97,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,114,117,110,48,50,46,119,97,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,114,117,110,48,51,46,119,97,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,106,117,109,112,46,119,97,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,100,107,115,116,111,109,112,46,119,97,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,86,7,0,1,0,0,0,5,248,146,0,248,191,2,0,24,38,7,0,1,0,0,0,157,0,147,0,184,160,2,0,56,210,6,0,1,0,0,0,154,0,147,0,192,135,2,0,24,163,6,0,1,0,0,0,155,0,147,0,240,108,2,0,152,122,6,0,1,0,0,0,153,0,147,0,96,82,2,0,192,72,6,0,1,0,0,0,152,0,147,0,32,56,2,0,200,110,3,0,1,0,0,0,156,0,147,0,152,30,2,0,40,246,1,0,1,0,0,0,6,248,146,0,64,246,1,0,144,236,1,0,1,0,0,0,158,0,147,0,136,224,1,0,176,223,1,0,1,0,0,0,2,248,146,0,72,198,1,0,192,209,1,0,1,0,0,0,3,248,146,0,24,182,1,0,24,198,1,0,1,0,0,0,1,248,146,0,40,167,1,0,120,189,1,0,1,0,0,0,0,248,146,0,200,149,1,0,224,22,1,0,1,0,0,0,4,248,146,0,56,126,1,0,88,212,3,0,1,0,0,0,208,219,146,0,40,185,3,0,72,65,1,0,9,0,0,0,8,6,147,0,32,58,1,0,48,50,1,0,9,0,0,0,9,6,147,0,32,58,1,0,18,0,0,0,255,255,184,0,0,0,0,0,0,0,0,0,254,0,8,0,32,4,2,0,18,0,0,0,1,7,7,0,32,136,7,0,18,0,0,0,1,7,6,0,40,88,7,0,18,0,0,0,1,7,5,0,96,39,7,0,18,0,0,0,1,7,0,0,144,251,6,0,18,0,0,0,1,7,1,0,184,164,6,0,18,0,0,0,1,7,2,0,80,74,6,0,18,0,0,0,1,7,3,0,192,32,6,0,18,0,0,0,1,7,4,0,32,242,5,0,0,0,0,0,254,0,2,0,128,129,4,0,18,0,0,0,1,8,0,0,208,75,4,0,18,0,0,0,1,8,8,0,8,49,4,0,0,0,0,0,254,0,2,0,0,46,7,0,18,0,0,0,1,16,0,0,56,111,3,0,18,0,0,0,1,16,16,0,104,134,3,0,0,0,0,0,254,0,4,0,72,202,5,0,18,0,0,0,1,96,0,0,80,246,3,0,18,0,0,0,1,96,32,0,248,38,7,0,18,0,0,0,1,96,64,0,112,212,3,0,18,0,0,0,1,96,96,0,248,160,5,0,0,0,0,0,254,0,2,0,16,227,4,0,18,0,0,0,1,128,128,0,56,111,3,0,18,0,0,0,1,128,0,0,104,134,3,0,0,0,0,0,254,0,2,0,168,234,7,0,22,0,0,0,1,64,64,0,96,135,7,0,22,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,22,0,0,0,1,128,128,0,96,135,7,0,22,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,23,0,0,0,1,1,1,0,96,135,7,0,23,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,96,46,8,0,23,0,0,0,1,8,8,0,208,233,4,0,23,0,0,0,1,8,0,0,72,197,4,0,0,0,0,0,254,0,16,0,32,4,2,0,23,0,0,0,1,240,160,0,144,160,3,0,23,0,0,0,1,240,176,0,96,135,3,0,23,0,0,0,1,240,192,0,32,136,7,0,23,0,0,0,1,240,208,0,40,88,7,0,23,0,0,0,1,240,224,0,96,39,7,0,23,0,0,0,1,240,16,0,200,121,7,0,23,0,0,0,1,240,48,0,120,113,6,0,23,0,0,0,1,240,32,0,232,228,5,0,23,0,0,0,1,240,240,0,144,251,6,0,23,0,0,0,1,240,64,0,120,211,6,0,23,0,0,0,1,240,144,0,184,164,6,0,23,0,0,0,1,240,128,0,80,74,6,0,23,0,0,0,1,240,112,0,192,32,6,0,23,0,0,0,1,240,96,0,192,234,2,0,23,0,0,0,1,240,80,0,32,242,5,0,23,0,0,0,1,240,0,0,16,227,4,0,0,0,0,0,0,0,0,0,254,0,16,0,32,4,2,0,22,0,0,0,1,240,160,0,144,160,3,0,22,0,0,0,1,240,176,0,96,135,3,0,22,0,0,0,1,240,192,0,32,136,7,0,22,0,0,0,1,240,208,0,40,88,7,0,22,0,0,0,1,240,16,0,40,28,4,0,22,0,0,0,1,240,224,0,96,39,7,0,22,0,0,0,1,240,32,0,192,24,7,0,22,0,0,0,1,240,48,0,120,113,6,0,22,0,0,0,1,240,240,0,144,251,6,0,22,0,0,0,1,240,64,0,120,211,6,0,22,0,0,0,1,240,144,0,184,164,6,0,22,0,0,0,1,240,128,0,80,74,6,0,22,0,0,0,1,240,112,0,192,32,6,0,22,0,0,0,1,240,96,0,192,234,2,0,22,0,0,0,1,240,80,0,32,242,5,0,22,0,0,0,1,240,0,0,16,227,4,0,0,0,0,0,254,0,2,0,144,212,8,0,23,0,0,0,1,1,1,0,96,135,7,0,23,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,96,46,8,0,23,0,0,0,1,4,4,0,208,233,4,0,23,0,0,0,1,4,0,0,72,197,4,0,0,0,0,0,254,0,2,0,88,63,8,0,23,0,0,0,1,32,32,0,96,135,7,0,23,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,23,0,0,0,1,128,128,0,96,135,7,0,23,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,99,100,45,100,46,56,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,21,41,123,42,2,0,16,1,99,100,45,101,46,56,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,38,2,55,232,2,0,16,1,99,100,45,97,46,49,54,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,179,159,79,126,4,0,32,0,99,100,45,98,46,49,54,48,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,133,45,83,137,4,0,32,0,100,51,57,45,49,52,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,172,253,170,230,2,0,16,1,100,51,57,45,49,53,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,59,114,150,254,2,0,16,1,100,51,57,45,48,52,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,109,80,0,56,1,0,16,1,100,51,57,45,48,53,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,93,59,236,226,1,0,16,1,100,51,57,45,49,50,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,193,199,146,130,9,0,16,1,100,51,57,45,48,54,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,53,40,246,82,11,0,32,0,100,51,57,45,48,49,46,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,125,156,14,209,15,0,32,0,100,51,57,45,48,50,46,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,3,68,48,108,15,0,32,0,100,51,57,45,48,51,46,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,180,218,156,252,15,0,32,0,100,51,57,45,48,55,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,22,40,38,40,24,0,64,0,100,51,57,45,48,56,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,123,139,123,55,25,0,64,0,100,51,57,45,49,52,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,172,253,170,230,2,0,16,1,100,51,57,45,49,51,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,47,107,73,174,2,0,16,1,100,51,57,45,48,52,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,109,80,0,56,1,0,16,1,100,51,57,45,48,53,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,93,59,236,226,1,0,16,1,100,51,57,45,49,50,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,193,199,146,130,9,0,16,1,100,51,57,45,48,54,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,53,40,246,82,11,0,32,0,100,51,57,45,48,49,46,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,125,156,14,209,15,0,32,0,100,51,57,45,48,50,46,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,3,68,48,108,15,0,32,0,100,51,57,45,48,51,46,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,180,218,156,252,15,0,32,0,100,51,57,45,48,55,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,22,40,38,40,24,0,64,0,100,51,57,45,48,56,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,123,139,123,55,25,0,64,0,21,0,0,0,255,255,255,0,0,0,0,0,22,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,21,0,0,0,1,2,2,0,96,135,7,0,21,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,21,0,0,0,1,4,4,0,96,135,7,0,21,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,21,0,0,0,1,8,0,0,96,135,7,0,21,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,21,0,0,0,1,12,0,0,16,242,7,0,21,0,0,0,1,12,8,0,104,236,7,0,21,0,0,0,1,12,12,0,128,230,7,0,21,0,0,0,1,12,4,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,21,0,0,0,1,3,0,0,16,242,7,0,21,0,0,0,1,3,2,0,104,236,7,0,21,0,0,0,1,3,3,0,128,230,7,0,21,0,0,0,1,3,1,0,184,164,6,0,0,0,0,0,254,0,4,0,72,202,5,0,22,0,0,0,1,3,2,0,80,246,3,0,22,0,0,0,1,3,3,0,80,124,6,0,22,0,0,0,1,3,1,0,112,212,3,0,22,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,120,95,4,0,22,0,0,0,1,12,8,0,56,94,4,0,22,0,0,0,1,12,12,0,248,38,7,0,22,0,0,0,1,12,4,0,176,90,4,0,22,0,0,0,1,12,0,0,192,87,4,0,0,0,0,0,254,0,2,0,72,84,4,0,22,0,0,0,1,16,16,0,248,38,7,0,22,0,0,0,1,16,0,0,176,64,8,0,0,0,0,0,254,0,2,0,160,76,4,0,22,0,0,0,1,32,32,0,232,74,4,0,22,0,0,0,1,32,0,0,8,208,6,0,0,0,0,0,254,0,2,0,208,81,6,0,22,0,0,0,1,64,64,0,120,97,1,0,22,0,0,0,1,64,0,0,96,19,1,0,0,0,0,0,254,0,2,0,144,212,6,0,22,0,0,0,1,128,0,0,8,208,6,0,22,0,0,0,1,128,128,0,88,204,6,0,0,0,0,0,50,55,99,52,48,48,48,45,109,49,53,51,55,55,45,97,45,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,241,203,223,150,1,0,16,1,50,55,99,52,48,48,48,45,109,49,53,50,54,50,45,97,45,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,8,235,223,19,1,0,16,1,50,55,99,52,48,48,48,45,109,49,53,50,57,53,45,97,45,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,73,243,51,97,1,0,16,1,50,55,99,52,48,48,48,45,109,49,53,50,54,51,45,97,45,49,45,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,186,88,64,14,1,0,16,1,50,55,99,52,48,48,48,45,109,49,53,50,54,51,45,97,45,49,45,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,141,201,194,243,4,0,32,0,50,55,99,52,48,48,48,45,109,49,53,50,54,50,45,97,45,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,224,246,225,160,4,0,32,0,50,55,99,52,48,48,48,45,109,49,53,50,55,57,45,97,45,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,220,10,239,85,4,0,32,0,50,55,99,52,48,48,48,45,109,49,53,50,55,57,45,97,45,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,252,5,8,204,4,0,32,0,50,55,99,52,48,48,48,45,109,49,53,48,49,51,45,98,45,49,45,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,20,247,113,19,4,0,32,0,50,55,99,52,48,48,48,45,109,49,53,50,54,51,45,97,45,49,45,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,167,196,132,178,4,0,32,0,50,55,99,52,48,48,48,45,109,49,53,51,55,55,45,97,45,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,148,51,173,183,4,0,32,0,50,55,99,52,48,48,48,45,109,49,53,50,55,57,45,97,45,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,5,119,132,136,4,0,32,0,112,105,99,49,54,99,53,55,45,114,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,16,0,0,170,46,38,77,7,0,16,0,50,55,99,52,48,48,48,45,109,49,53,51,56,56,45,97,45,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,9,19,146,125,5,0,64,0,99,97,116,57,51,99,52,54,112,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,81,163,159,212,0,0,0,8,103,97,108,50,48,118,56,97,45,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,87,1,0,0,71,202,153,205,0,0,0,8,103,97,108,50,48,118,56,97,45,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,87,1,0,0,185,22,208,96,0,0,0,8,103,97,108,50,48,118,56,97,45,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,87,1,0,0,79,127,155,4,0,0,0,8,112,97,108,99,101,49,54,118,56,104,45,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,102,60,37,72,0,0,0,8,112,97,108,99,101,49,54,118,56,104,45,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,186,117,227,154,0,0,0,8,50,55,99,52,48,48,48,45,109,49,50,52,56,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,241,203,223,150,1,0,16,1,50,55,99,52,48,48,48,45,109,49,50,51,55,52,114,45,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,8,235,223,19,1,0,16,1,50,55,99,52,48,48,48,45,109,49,50,51,55,52,114,45,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,73,243,51,97,1,0,16,1,50,55,99,52,48,48,48,45,109,49,50,51,55,52,114,45,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,186,88,64,14,1,0,16,1,50,55,99,52,48,48,48,45,109,49,50,52,56,49,45,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,141,201,194,243,4,0,32,0,50,55,99,52,48,48,48,45,109,49,50,52,56,49,45,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,252,190,116,213,4,0,32,0,50,55,99,52,48,48,48,45,109,49,50,52,56,49,45,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,220,10,239,85,4,0,32,0,50,55,99,52,48,48,48,45,109,49,50,52,56,49,45,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,252,5,8,204,4,0,32,0,50,55,99,52,48,48,48,45,109,49,50,52,56,49,45,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,20,247,113,19,4,0,32,0,50,55,99,52,48,48,48,45,109,49,50,52,56,49,45,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,167,196,132,178,4,0,32,0,50,55,99,52,48,48,48,45,109,49,50,52,56,49,45,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,148,51,173,183,4,0,32,0,50,55,99,52,48,48,48,45,109,49,50,52,56,49,45,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,5,119,132,136,4,0,32,0,112,105,99,49,54,99,53,55,45,120,116,46,104,101,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,204,38,0,0,196,234,165,166,7,0,16,0,50,55,99,52,48,48,48,45,109,49,50,54,50,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,9,19,146,125,5,0,64,0,99,97,116,57,51,99,52,54,112,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,81,163,159,212,0,0,0,8,103,97,108,50,48,118,56,97,45,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,87,1,0,0,71,202,153,205,0,0,0,8,103,97,108,50,48,118,56,97,45,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,87,1,0,0,185,22,208,96,0,0,0,8,103,97,108,50,48,118,56,97,45,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,87,1,0,0,79,127,155,4,0,0,0,8,112,97,108,99,101,49,54,118,56,104,45,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,102,60,37,72,0,0,0,8,112,97,108,99,101,49,54,118,56,104,45,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,186,117,227,154,0,0,0,8,117,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,93,220,93,141,2,0,16,1,117,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,25,210,44,247,2,0,16,1,117,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,118,91,39,188,2,0,16,1,117,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,117,201,135,137,2,0,16,1,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,159,26,160,4,0,32,0,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,23,44,240,189,4,0,32,0,117,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,250,238,139,5,4,0,32,0,117,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,241,169,40,80,4,0,32,0,117,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,234,137,127,215,4,0,32,0,117,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,52,176,188,191,4,0,32,0,117,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,78,77,84,162,4,0,32,0,117,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,177,187,105,136,4,0,32,0,117,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,131,106,177,46,3,0,16,0,117,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,186,153,40,141,5,0,64,0,117,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,66,75,74,179,5,0,64,0,103,109,100,117,100,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,53,132,136,18,1,0,16,1,103,109,100,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,103,85,72,55,1,0,16,1,103,109,100,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,251,159,38,218,1,0,16,1,103,109,100,117,100,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,218,239,37,216,1,0,16,1,103,109,100,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,240,25,221,128,5,0,32,0,103,109,100,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,120,58,217,223,5,0,32,0,103,109,100,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,32,101,53,22,5,0,32,0,103,109,100,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,49,48,195,223,5,0,32,0,103,109,100,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0])
.concat([133,201,155,63,10,0,16,1,103,109,100,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,222,157,211,63,10,0,16,1,103,109,100,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,66,85,166,6,12,0,64,0,103,109,100,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,49,122,188,80,12,0,64,0,103,109,100,117,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,95,177,188,67,1,0,16,1,103,109,100,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,103,85,72,55,1,0,16,1,103,109,100,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,251,159,38,218,1,0,16,1,103,109,100,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,201,131,180,85,1,0,16,1,103,109,100,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,240,25,221,128,5,0,32,0,103,109,100,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,120,58,217,223,5,0,32,0,103,109,100,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,32,101,53,22,5,0,32,0,103,109,100,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,49,48,195,223,5,0,32,0,103,109,100,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,133,201,155,63,10,0,16,1,103,109,100,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,222,157,211,63,10,0,16,1,103,109,100,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,66,85,166,6,12,0,64,0,103,109,100,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,49,122,188,80,12,0,64,0,168,86,7,0,1,0,0,0,48,251,146,0,248,191,2,0,24,38,7,0,1,0,0,0,7,243,146,0,184,160,2,0,56,210,6,0,1,0,0,0,0,243,146,0,192,135,2,0,24,163,6,0,1,0,0,0,1,243,146,0,240,108,2,0,152,122,6,0,1,0,0,0,2,243,146,0,96,82,2,0,192,72,6,0,1,0,0,0,3,243,146,0,32,56,2,0,200,110,3,0,1,0,0,0,4,243,146,0,152,30,2,0,120,89,3,0,1,0,0,0,5,243,146,0,232,10,2,0,120,74,3,0,1,0,0,0,6,243,146,0,152,138,8,0,40,246,1,0,1,0,0,0,49,251,146,0,64,246,1,0,144,236,1,0,1,0,0,0,15,243,146,0,136,224,1,0,176,223,1,0,1,0,0,0,8,243,146,0,72,198,1,0,192,209,1,0,1,0,0,0,9,243,146,0,24,182,1,0,24,198,1,0,1,0,0,0,10,243,146,0,40,167,1,0,120,189,1,0,1,0,0,0,11,243,146,0,200,149,1,0,224,22,1,0,1,0,0,0,12,243,146,0,56,126,1,0,160,14,1,0,1,0,0,0,13,243,146,0,32,101,1,0,176,9,1,0,1,0,0,0,14,243,146,0,96,32,8,0,88,212,3,0,1,0,0,0,232,215,146,0,40,185,3,0,16,17,8,0,1,0,0,0,50,251,146,0,224,12,8,0,72,65,1,0,9,0,0,0,168,3,147,0,32,58,1,0,48,50,1,0,9,0,0,0,169,3,147,0,32,58,1,0,18,0,0,0,255,255,255,0,0,0,0,0,19,0,0,0,255,255,94,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,18,0,0,0,1,15,2,0,80,252,6,0,18,0,0,0,1,15,5,0,16,242,7,0,18,0,0,0,1,15,8,0,104,236,7,0,18,0,0,0,1,15,4,0,120,113,6,0,18,0,0,0,1,15,1,0,232,228,5,0,18,0,0,0,1,15,15,0,128,230,7,0,18,0,0,0,1,15,3,0,56,141,7,0,18,0,0,0,1,15,7,0,120,211,6,0,18,0,0,0,1,15,14,0,184,164,6,0,18,0,0,0,1,15,6,0,24,1,7,0,18,0,0,0,1,15,13,0,80,74,6,0,18,0,0,0,1,15,12,0,192,32,6,0,18,0,0,0,1,15,11,0,192,234,2,0,18,0,0,0,1,15,10,0,32,242,5,0,18,0,0,0,1,15,9,0,176,192,2,0,18,0,0,0,1,15,0,0,16,227,4,0,0,0,0,0,254,0,15,0,160,123,6,0,18,0,0,0,1,240,32,0,80,252,6,0,18,0,0,0,1,240,80,0,16,242,7,0,18,0,0,0,1,240,128,0,104,236,7,0,18,0,0,0,1,240,64,0,120,113,6,0,18,0,0,0,1,240,16,0,232,228,5,0,18,0,0,0,1,240,240,0,128,230,7,0,18,0,0,0,1,240,48,0,56,141,7,0,18,0,0,0,1,240,112,0,120,211,6,0,18,0,0,0,1,240,224,0,184,164,6,0,18,0,0,0,1,240,96,0,24,1,7,0,18,0,0,0,1,240,208,0,80,74,6,0,18,0,0,0,1,240,192,0,192,32,6,0,18,0,0,0,1,240,176,0,192,234,2,0,18,0,0,0,1,240,160,0,32,242,5,0,18,0,0,0,1,240,144,0,176,192,2,0,0,0,0,0,254,0,4,0,128,129,4,0,19,0,0,0,1,3,3,0,208,75,4,0,19,0,0,0,1,3,2,0,8,49,4,0,19,0,0,0,1,3,1,0,72,246,3,0,19,0,0,0,1,3,0,0,64,47,7,0,0,0,0,0,254,0,4,0,64,37,5,0,19,0,0,0,1,24,24,0,232,68,3,0,19,0,0,0,1,24,16,0,200,55,3,0,19,0,0,0,1,24,8,0,88,36,3,0,19,0,0,0,1,24,0,0,136,11,3,0,0,0,0,0,254,0,4,0,72,202,5,0,19,0,0,0,1,96,96,0,80,246,3,0,19,0,0,0,1,96,64,0,248,38,7,0,19,0,0,0,1,96,32,0,112,212,3,0,19,0,0,0,1,96,0,0,24,99,5,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,128,128,0,96,135,7,0,19,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,20,0,0,0,1,1,1,0,96,135,7,0,20,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,20,0,0,0,1,4,4,0,96,135,7,0,20,0,0,0,1,4,0,0,152,182,7,0,168,86,7,0,1,0,0,0,56,2,147,0,248,191,2,0,56,210,6,0,1,0,0,0,122,249,146,0,192,135,2,0,24,163,6,0,1,0,0,0,123,249,146,0,240,108,2,0,152,122,6,0,1,0,0,0,120,249,146,0,96,82,2,0,192,72,6,0,1,0,0,0,121,249,146,0,32,56,2,0,200,110,3,0,1,0,0,0,124,249,146,0,152,30,2,0,120,89,3,0,1,0,0,0,125,249,146,0,232,10,2,0,120,74,3,0,1,0,0,0,126,249,146,0,152,138,8,0,40,246,1,0,1,0,0,0,57,2,147,0,64,246,1,0,176,223,1,0,1,0,0,0,90,241,146,0,72,198,1,0,192,209,1,0,1,0,0,0,91,241,146,0,24,182,1,0,24,198,1,0,1,0,0,0,88,241,146,0,40,167,1,0,120,189,1,0,1,0,0,0,89,241,146,0,200,149,1,0,224,22,1,0,1,0,0,0,92,241,146,0,56,126,1,0,160,14,1,0,1,0,0,0,93,241,146,0,32,101,1,0,176,9,1,0,1,0,0,0,94,241,146,0,96,32,8,0,88,212,3,0,1,0,0,0,168,221,146,0,40,185,3,0,16,17,8,0,1,0,0,0,62,2,147,0,224,12,8,0,208,66,7,0,1,0,0,0,59,2,147,0,128,176,7,0,72,65,1,0,9,0,0,0,88,7,147,0,32,58,1,0,48,50,1,0,9,0,0,0,89,7,147,0,32,58,1,0,224,41,1,0,9,0,0,0,90,7,147,0,32,58,1,0,117,50,54,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,113,125,4,236,1,0,16,1,117,53,54,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,233,173,56,1,1,0,16,1,117,54,57,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,252,179,208,93,1,0,16,1,117,57,56,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,69,183,208,222,1,0,16,1,117,49,49,52,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,118,1,212,95,1,0,16,1,117,49,51,51,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,54,131,83,3,1,0,16,1,117,49,52,51,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,129,96,103,100,1,0,16,1,117,49,54,51,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,112,103,61,188,1,0,16,1,117,51,57,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,46,126,152,9,2,0,16,1,117,53,49,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,113,20,43,30,2,0,16,1,117,55,56,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,170,154,39,69,2,0,16,1,117,55,50,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,142,80,6,84,4,0,32,0,117,49,48,49,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,182,24,64,140,4,0,32,0,99,48,49,115,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,171,174,60,78,7,0,32,0,15,0,0,0,255,255,0,0,0,0,0,0,16,0,0,0,255,255,3,0,0,0,0,0,17,0,0,0,255,255,2,0,0,0,0,0,0,0,0,0,254,0,2,0,64,37,5,0,16,0,0,0,1,1,1,0,176,116,6,0,16,0,0,0,1,1,0,0,80,113,6,0,0,0,0,0,254,0,2,0,200,30,2,0,16,0,0,0,1,2,2,0,120,97,1,0,16,0,0,0,1,2,0,0,96,19,1,0,0,0,0,0,254,0,2,0,128,129,4,0,17,0,0,0,1,2,2,0,152,21,4,0,17,0,0,0,1,2,0,0,72,246,3,0,0,0,0,0,254,0,2,0,200,87,7,0,17,0,0,0,1,4,4,0,224,127,8,0,17,0,0,0,1,4,0,0,32,123,8,0,0,0,0,0,254,0,2,0,160,123,6,0,17,0,0,0,1,8,0,0,0,90,2,0,17,0,0,0,1,8,8,0,104,61,2,0,100,102,105,115,104,49,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,152,150,177,42,1,0,16,1,100,102,105,115,104,50,46,55,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,151,240,119,78,1,0,16,1,100,102,105,115,104,51,46,55,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,198,164,22,63,1,0,16,1,100,102,105,115,104,52,46,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,89,126,252,17,1,0,16,1,100,102,105,115,104,53,46,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,31,227,230,172,4,0,32,0,100,102,105,115,104,54,46,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,196,196,166,215,4,0,32,0,56,50,115,49,50,51,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,171,174,60,78,7,0,32,0,15,0,0,0,255,255,0,0,0,0,0,0,16,0,0,0,255,255,192,0,0,0,0,0,17,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,200,87,7,0,16,0,0,0,1,64,0,0,224,127,8,0,16,0,0,0,1,64,64,0,32,123,8,0,0,0,0,0,254,0,2,0,160,123,6,0,16,0,0,0,1,128,128,0,0,90,2,0,16,0,0,0,1,128,0,0,104,61,2,0,0,0,0,0,254,0,2,0,64,37,5,0,17,0,0,0,1,1,0,0,176,116,6,0,17,0,0,0,1,1,1,0,80,113,6,0,0,0,0,0,254,0,2,0,128,129,4,0,17,0,0,0,1,4,0,0,152,21,4,0,17,0,0,0,1,4,4,0,72,246,3,0,0,0,0,0,254,0,2,0,200,30,2,0,17,0,0,0,1,8,0,0,120,97,1,0,17,0,0,0,1,8,8,0,96,19,1,0,48,54,48,95,106,48,50,46,101,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,172,97,183,17,0,0,16,1,48,54,48,95,106,48,51,46,103,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,140,88,11,141,0,0,16,1,48,54,48,95,106,48,57,46,101,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,95,241,165,242,0,0,16,1,48,54,48,95,106,49,48,46,103,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,188,253,238,54,0,0,16,1,48,54,48,106,48,49,46,102,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,115,166,217,249,0,0,16,1,48,54,48,101,48,55,46,107,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,243,237,0,196,0,0,32,0,48,54,48,101,48,56,46,107,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,161,219,221,112,0,0,32,0,48,54,48,101,48,54,46,107,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,146,20,56,9,0,0,32,0,48,54,48,101,48,53,46,107,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,65,66,69,50,0,0,32,0,48,54,48,101,48,52,46,100,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,93,57,128,198,0,0,64,0,98,108,115,119,104,115,116,108,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,63,78,67,135,0,0,0,8,101,112,114,45,49,52,56,48,50,46,97,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,188,60,185,154,1,0,16,1,101,112,114,45,49,52,57,48,50,46,97,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,177,231,36,103,1,0,16,1,101,112,114,45,49,52,55,57,51,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,243,122,157,220,1,0,16,1,101,112,114,45,49,52,55,57,53,46,97,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,217,247,91,126,1,0,16,1,109,112,114,45,49,52,55,56,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,170,215,247,196,2,0,32,0,109,112,114,45,49,52,55,56,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,5,141,201,204,2,0,32,0,109,112,114,45,49,52,55,56,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,236,43,32,239,2,0,32,0,109,112,114,45,49,52,55,56,56,46,99,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,54,85,176,181,3,0,32,0,109,112,114,45,49,52,55,57,54,46,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,10,34,51,192,3,0,32,0,109,112,114,45,49,52,55,56,57,46,99,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,151,203,155,15,3,0,32,0,109,112,114,45,49,52,55,57,55,46,97,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,201,28,48,76,3,0,32,0,109,112,114,45,49,52,55,57,48,46,99,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,39,172,7,106,3,0,32,0,109,112,114,45,49,52,55,57,56,46,97,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,37,70,99,80,3,0,32,0,109,112,114,45,49,52,55,57,49,46,99,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,43,53,174,164,3,0,32,0,109,112,114,45,49,52,55,57,57,46,97,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,37,176,183,174,3,0,32,0,101,112,114,45,49,52,55,56,55,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,199,238,111,204,4,0,16,1,109,112,114,45,49,52,55,56,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,242,73,131,204,19,0,64,0,109,112,114,45,49,52,55,56,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,19,186,171,123,19,0,64,0,109,112,114,45,49,52,55,56,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,228,120,56,7,19,0,64,0,51,49,55,45,48,49,57,54,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,98,34,148,203,5,0,16,1,30,0,0,0,255,255,255,0,0,0,0,0,31,0,0,0,255,255,253,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,30,0,0,0,1,15,7,0,80,252,6,0,30,0,0,0,1,15,8,0,16,242,7,0,30,0,0,0,1,15,9,0,104,236,7,0,30,0,0,0,1,15,5,0,176,51,4,0,30,0,0,0,1,15,4,0,56,24,4,0,30,0,0,0,1,15,15,0,128,230,7,0,30,0,0,0,1,15,1,0,72,216,3,0,30,0,0,0,1,15,2,0,24,188,3,0,30,0,0,0,1,15,3,0,176,162,3,0,30,0,0,0,1,15,6,0,120,211,6,0,30,0,0,0,1,15,14,0,184,164,6,0,30,0,0,0,1,15,13,0,80,74,6,0,30,0,0,0,1,15,12,0,192,32,6,0,30,0,0,0,1,15,11,0,192,234,2,0,30,0,0,0,1,15,10,0,32,242,5,0,30,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,30,0,0,0,1,240,112,0,80,252,6,0,30,0,0,0,1,240,128,0,16,242,7,0,30,0,0,0,1,240,144,0,104,236,7,0,30,0,0,0,1,240,80,0,176,51,4,0,30,0,0,0,1,240,64,0,56,24,4,0,30,0,0,0,1,240,240,0,128,230,7,0,30,0,0,0,1,240,16,0,72,216,3,0,30,0,0,0,1,240,32,0,24,188,3,0,30,0,0,0,1,240,48,0,176,162,3,0,30,0,0,0,1,240,96,0,120,211,6,0,30,0,0,0,1,240,224,0,184,164,6,0,30,0,0,0,1,240,208,0,80,74,6,0,30,0,0,0,1,240,192,0,192,32,6,0,30,0,0,0,1,240,176,0,192,234,2,0,30,0,0,0,1,240,160,0,32,242,5,0,30,0,0,0,1,240,0,0,208,236,2,0,0,0,0,0,254,0,2,0,88,131,3,0,23,0,0,0,1,1,1,0,96,135,7,0,23,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,31,0,0,0,1,2,2,0,96,135,7,0,31,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,112,242,7,0,31,0,0,0,1,8,0,0,240,242,5,0,31,0,0,0,1,8,8,0,8,140,6,0,0,0,0,0,254,0,2,0,8,93,1,0,21,0,0,0,1,16,16,0,136,86,1,0,21,0,0,0,1,16,0,0,232,78,1,0,0,0,0,0,254,0,2,0,48,3,7,0,21,0,0,0,1,32,32,0,176,252,6,0,21,0,0,0,1,32,0,0,232,21,1,0,0,0,0,0,254,0,4,0,72,202,5,0,31,0,0,0,1,192,128,0,80,246,3,0,31,0,0,0,1,192,192,0,248,38,7,0,31,0,0,0,1,192,64,0,112,212,3,0,31,0,0,0,1,192,0,0,248,160,5,0,21,0,0,0,255,255,0,0,0,0,0,0,22,0,0,0,255,255,0,0,0,0,0,0,23,0,0,0,255,255,1,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,21,0,0,0,1,2,0,0,96,135,7,0,21,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,21,0,0,0,1,8,8,0,96,135,7,0,21,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,21,0,0,0,1,48,48,0,32,136,7,0,21,0,0,0,1,48,32,0,40,88,7,0,21,0,0,0,1,48,16,0,96,39,7,0,21,0,0,0,1,48,0,0,144,251,6,0,0,0,0,0,254,0,4,0,160,123,6,0,21,0,0,0,1,192,0,0,184,164,6,0,21,0,0,0,1,192,64,0])
.concat([80,74,6,0,21,0,0,0,1,192,128,0,192,32,6,0,21,0,0,0,1,192,192,0,32,242,5,0,0,0,0,0,254,0,4,0,72,202,5,0,22,0,0,0,1,3,1,0,80,246,3,0,22,0,0,0,1,3,0,0,80,124,6,0,22,0,0,0,1,3,2,0,112,212,3,0,22,0,0,0,1,3,3,0,248,160,5,0,0,0,0,0,254,0,4,0,64,37,5,0,22,0,0,0,1,12,0,0,224,7,5,0,22,0,0,0,1,12,4,0,0,228,4,0,22,0,0,0,1,12,8,0,88,192,4,0,22,0,0,0,1,12,12,0,120,7,5,0,0,0,0,0,254,0,4,0,128,129,4,0,22,0,0,0,1,48,48,0,192,255,2,0,22,0,0,0,1,48,32,0,208,75,4,0,22,0,0,0,1,48,0,0,8,49,4,0,22,0,0,0,1,48,16,0,72,246,3,0,0,0,0,0,254,0,2,0,144,246,3,0,22,0,0,0,1,64,0,0,96,135,7,0,22,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,232,21,1,0,22,0,0,0,1,128,0,0,96,135,7,0,22,0,0,0,1,128,128,0,152,182,7,0,0,0,0,0,254,0,2,0,88,242,5,0,23,0,0,0,1,1,1,0,160,150,4,0,23,0,0,0,1,1,0,0,24,128,5,0,0,0,0,0,21,0,0,0,255,255,0,0,0,0,0,0,22,0,0,0,255,255,0,0,0,0,0,0,23,0,0,0,255,255,2,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,21,0,0,0,1,2,0,0,96,135,7,0,21,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,21,0,0,0,1,8,8,0,96,135,7,0,21,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,21,0,0,0,1,48,48,0,32,136,7,0,21,0,0,0,1,48,32,0,40,88,7,0,21,0,0,0,1,48,16,0,96,39,7,0,21,0,0,0,1,48,0,0,144,251,6,0,0,0,0,0,254,0,4,0,160,123,6,0,21,0,0,0,1,192,0,0,184,164,6,0,21,0,0,0,1,192,64,0,80,74,6,0,21,0,0,0,1,192,128,0,192,32,6,0,21,0,0,0,1,192,192,0,32,242,5,0,0,0,0,0,254,0,4,0,72,202,5,0,22,0,0,0,1,3,1,0,80,246,3,0,22,0,0,0,1,3,0,0,80,124,6,0,22,0,0,0,1,3,2,0,112,212,3,0,22,0,0,0,1,3,3,0,248,160,5,0,0,0,0,0,254,0,4,0,64,37,5,0,22,0,0,0,1,12,0,0,224,7,5,0,22,0,0,0,1,12,4,0,0,228,4,0,22,0,0,0,1,12,8,0,88,192,4,0,22,0,0,0,1,12,12,0,120,7,5,0,0,0,0,0,254,0,4,0,128,129,4,0,22,0,0,0,1,48,48,0,192,255,2,0,22,0,0,0,1,48,32,0,208,75,4,0,22,0,0,0,1,48,0,0,8,49,4,0,22,0,0,0,1,48,16,0,72,246,3,0,0,0,0,0,254,0,2,0,144,246,3,0,22,0,0,0,1,64,0,0,96,135,7,0,22,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,232,21,1,0,22,0,0,0,1,128,0,0,96,135,7,0,22,0,0,0,1,128,128,0,152,182,7,0,0,0,0,0,254,0,4,0,88,242,5,0,23,0,0,0,1,3,2,0,88,160,3,0,23,0,0,0,1,3,3,0,24,135,3,0,23,0,0,0,1,3,1,0,184,111,3,0,23,0,0,0,1,3,0,0,24,128,5,0,0,0,0,0,10,0,0,0,255,255,255,0,0,0,0,0,11,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,8,0,200,87,7,0,10,0,0,0,1,7,5,0,184,220,8,0,10,0,0,0,1,7,6,0,200,92,8,0,10,0,0,0,1,7,7,0,56,37,8,0,10,0,0,0,1,7,4,0,96,240,7,0,10,0,0,0,1,7,3,0,128,188,7,0,10,0,0,0,1,7,2,0,184,46,7,0,10,0,0,0,1,7,1,0,120,251,7,0,10,0,0,0,1,7,0,0,248,140,7,0,0,0,0,0,254,0,8,0,200,87,7,0,10,0,0,0,1,56,40,0,184,220,8,0,10,0,0,0,1,56,48,0,200,92,8,0,10,0,0,0,1,56,56,0,56,37,8,0,10,0,0,0,1,56,32,0,96,240,7,0,10,0,0,0,1,56,24,0,128,188,7,0,10,0,0,0,1,56,16,0,184,46,7,0,10,0,0,0,1,56,8,0,120,251,7,0,10,0,0,0,1,56,0,0,248,140,7,0,0,0,0,0,254,0,2,0,80,237,7,0,10,0,0,0,1,64,64,0,96,135,7,0,10,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,10,0,0,0,1,128,128,0,96,135,7,0,10,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,40,153,1,0,11,0,0,0,1,1,1,0,96,135,7,0,11,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,160,142,1,0,11,0,0,0,1,2,2,0,96,135,7,0,11,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,11,0,0,0,1,4,0,0,96,135,7,0,11,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,11,0,0,0,1,24,16,0,80,246,3,0,11,0,0,0,1,24,24,0,248,38,7,0,11,0,0,0,1,24,8,0,112,212,3,0,11,0,0,0,1,24,0,0,248,160,5,0,0,0,0,0,254,0,2,0,200,71,1,0,11,0,0,0,1,32,32,0,120,76,7,0,11,0,0,0,1,32,0,0,248,63,7,0,0,0,0,0,254,0,2,0,128,129,4,0,11,0,0,0,1,64,64,0,8,49,4,0,11,0,0,0,1,64,0,0,152,21,4,0,0,0,0,0,254,0,2,0,208,24,1,0,11,0,0,0,1,128,128,0,192,15,1,0,11,0,0,0,1,128,0,0,248,10,1,0,0,0,0,0,168,86,7,0,1,0,0,0,102,248,146,0,248,191,2,0,200,110,3,0,1,0,0,0,96,248,146,0,152,30,2,0,120,89,3,0,1,0,0,0,97,248,146,0,232,10,2,0,120,74,3,0,1,0,0,0,98,248,146,0,152,138,8,0,192,61,3,0,1,0,0,0,99,248,146,0,48,119,7,0,120,194,6,0,1,0,0,0,100,248,146,0,112,109,7,0,96,189,6,0,1,0,0,0,101,248,146,0,24,133,7,0,88,212,3,0,1,0,0,0,72,220,146,0,40,185,3,0,72,65,1,0,9,0,0,0,104,6,147,0,32,58,1,0,48,50,1,0,9,0,0,0,105,6,147,0,32,58,1,0,100,50,56,45,48,54,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,81,255,75,91,2,0,16,1,100,50,56,45,49,50,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,49,230,116,155,2,0,16,1,100,50,56,45,48,57,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,193,12,58,20,2,0,16,1,100,50,56,45,48,56,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,217,43,135,76,2,0,16,1,100,50,56,45,49,48,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,116,93,128,64,9,0,16,1,100,50,56,45,48,52,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,107,194,171,220,12,0,32,0,100,50,56,45,48,53,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,101,150,47,134,12,0,32,0,100,50,56,45,48,49,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,105,123,29,24,15,0,32,0,100,50,56,45,48,50,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,28,119,1,211,15,0,32,0,100,50,56,45,48,51,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,82,75,128,161,24,0,64,0,21,0,0,0,255,255,254,0,0,0,0,0,22,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,21,0,0,0,1,1,0,0,120,97,1,0,21,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,2,0,144,212,8,0,21,0,0,0,1,2,2,0,96,135,7,0,21,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,21,0,0,0,1,4,4,0,96,135,7,0,21,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,21,0,0,0,1,8,0,0,96,135,7,0,21,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,21,0,0,0,1,48,0,0,80,252,6,0,21,0,0,0,1,48,16,0,16,242,7,0,21,0,0,0,1,48,32,0,104,236,7,0,21,0,0,0,1,48,48,0,128,230,7,0,0,0,0,0,254,0,4,0,160,123,6,0,21,0,0,0,1,192,192,0,8,201,6,0,21,0,0,0,1,192,128,0,200,197,6,0,21,0,0,0,1,192,64,0,152,194,6,0,21,0,0,0,1,192,0,0,248,189,6,0,0,0,0,0,254,0,4,0,72,202,5,0,22,0,0,0,1,3,2,0,80,246,3,0,22,0,0,0,1,3,3,0,80,124,6,0,22,0,0,0,1,3,1,0,112,212,3,0,22,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,120,95,4,0,22,0,0,0,1,24,16,0,56,94,4,0,22,0,0,0,1,24,24,0,248,38,7,0,22,0,0,0,1,24,8,0,176,90,4,0,22,0,0,0,1,24,0,0,192,87,4,0,0,0,0,0,254,0,2,0,224,21,4,0,22,0,0,0,1,128,0,0,48,224,5,0,22,0,0,0,1,128,128,0,0,220,5,0,0,0,0,0,100,97,100,117,46,48,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,119,241,19,68,1,0,16,1,100,97,100,117,46,48,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,48,226,141,22,1,0,16,1,100,97,100,117,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,145,158,211,3,1,0,16,1,100,97,100,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,86,62,170,19,1,0,16,1,100,97,100,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,221,182,28,67,1,0,16,1,100,97,100,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,214,183,60,218,5,0,32,0,100,97,100,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,114,49,182,146,5,0,32,0,100,97,100,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,245,87,135,185,5,0,32,0,100,97,100,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,70,206,33,129,5,0,32,0,100,97,100,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,63,111,126,131,5,0,32,0,100,97,100,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,219,107,145,240,5,0,32,0,100,97,100,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,239,147,243,206,5,0,32,0,100,97,100,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,158,254,83,137,5,0,32,0,100,97,100,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,36,36,94,63,10,0,16,1,100,97,100,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,103,155,73,12,12,0,64,0,100,97,100,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,78,90,11,47,12,0,64,0,100,97,100,106,46,48,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,220,56,22,113,1,0,16,1,100,97,100,106,46,48,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,156,99,105,72,1,0,16,1,100,97,100,106,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,250,14,76,72,1,0,16,1,100,97,100,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,86,62,170,19,1,0,16,1,100,97,100,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,221,182,28,67,1,0,16,1,100,97,100,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,214,183,60,218,5,0,32,0,100,97,100,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,114,49,182,146,5,0,32,0,100,97,100,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,245,87,135,185,5,0,32,0,100,97,100,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,70,206,33,129,5,0,32,0,100,97,100,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,63,111,126,131,5,0,32,0,100,97,100,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,219,107,145,240,5,0,32,0,100,97,100,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,239,147,243,206,5,0,32,0,100,97,100,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,158,254,83,137,5,0,32,0,100,97,100,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,36,36,94,63,10,0,16,1,100,97,100,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,103,155,73,12,12,0,64,0,100,97,100,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,78,90,11,47,12,0,64,0,100,97,100,106,46,48,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,133,107,96,135,1,0,16,1,100,97,100,106,46,48,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,117,149,212,36,1,0,16,1,100,97,100,106,46,48,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,247,81,206,86,1,0,16,1,100,97,100,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,86,62,170,19,1,0,16,1,100,97,100,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,221,182,28,67,1,0,16,1,100,97,100,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,214,183,60,218,5,0,32,0,100,97,100,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,114,49,182,146,5,0,32,0,100,97,100,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,245,87,135,185,5,0,32,0,100,97,100,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,70,206,33,129,5,0,32,0,100,97,100,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,63,111,126,131,5,0,32,0,100,97,100,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,219,107,145,240,5,0,32,0,100,97,100,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,239,147,243,206,5,0,32,0,100,97,100,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,158,254,83,137,5,0,32,0,100,97,100,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,36,36,94,63,10,0,16,1,100,97,100,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,103,155,73,12,12,0,64,0,100,97,100,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,78,90,11,47,12,0,64,0,100,97,100,104,46,48,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,163,74,208,67,1,0,16,1,100,97,100,104,46,48,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,108,41,141,139,1,0,16,1,100,97,100,104,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,20,107,174,218,1,0,16,1,100,97,100,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,86,62,170,19,1,0,16,1,100,97,100,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,221,182,28,67,1,0,16,1,100,97,100,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,214,183,60,218,5,0,32,0,100,97,100,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,114,49,182,146,5,0,32,0,100,97,100,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,245,87,135,185,5,0,32,0,100,97,100,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,70,206,33,129,5,0,32,0,100,97,100,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,63,111,126,131,5,0,32,0,100,97,100,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,219,107,145,240,5,0,32,0,100,97,100,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,239,147,243,206,5,0,32,0,100,97,100,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,158,254,83,137,5,0,32,0,100,97,100,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,36,36,94,63,10,0,16,1,100,97,100,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,103,155,73,12,12,0,64,0])
.concat([100,97,100,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,78,90,11,47,12,0,64,0,100,97,100,104,46,48,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,142,185,12,174,1,0,16,1,100,97,100,104,46,48,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,99,67,119,181,1,0,16,1,100,97,100,104,46,48,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,133,164,226,108,1,0,16,1,100,97,100,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,86,62,170,19,1,0,16,1,100,97,100,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,221,182,28,67,1,0,16,1,100,97,100,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,214,183,60,218,5,0,32,0,100,97,100,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,114,49,182,146,5,0,32,0,100,97,100,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,245,87,135,185,5,0,32,0,100,97,100,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,70,206,33,129,5,0,32,0,100,97,100,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,63,111,126,131,5,0,32,0,100,97,100,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,219,107,145,240,5,0,32,0,100,97,100,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,239,147,243,206,5,0,32,0,100,97,100,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,158,254,83,137,5,0,32,0,100,97,100,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,36,36,94,63,10,0,16,1,100,97,100,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,103,155,73,12,12,0,64,0,100,97,100,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,78,90,11,47,12,0,64,0,100,97,100,97,46,48,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,215,45,111,252,1,0,16,1,100,97,100,97,46,48,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,9,64,190,212,1,0,16,1,100,97,100,97,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,207,209,18,103,1,0,16,1,100,97,100,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,86,62,170,19,1,0,16,1,100,97,100,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,221,182,28,67,1,0,16,1,100,97,100,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,214,183,60,218,5,0,32,0,100,97,100,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,114,49,182,146,5,0,32,0,100,97,100,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,245,87,135,185,5,0,32,0,100,97,100,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,70,206,33,129,5,0,32,0,100,97,100,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,63,111,126,131,5,0,32,0,100,97,100,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,219,107,145,240,5,0,32,0,100,97,100,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,239,147,243,206,5,0,32,0,100,97,100,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,158,254,83,137,5,0,32,0,100,97,100,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,36,36,94,63,10,0,16,1,100,97,100,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,103,155,73,12,12,0,64,0,100,97,100,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,78,90,11,47,12,0,64,0,100,100,50,117,46,48,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,132,13,112,15,1,0,16,1,100,100,50,117,46,48,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,84,178,158,185,1,0,16,1,100,100,50,46,48,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,243,97,48,178,1,0,16,1,100,100,50,46,48,54,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,206,216,241,139,1,0,16,1,100,100,50,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,139,11,154,144,1,0,16,1,100,100,50,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,77,60,229,1,0,16,1,100,100,50,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,159,39,134,95,1,0,16,1,100,100,50,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,38,76,149,173,1,0,16,1,100,100,50,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,110,78,107,164,5,0,32,0,100,100,50,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,252,80,252,213,5,0,32,0,100,100,50,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,103,8,124,131,5,0,32,0,100,100,50,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,28,194,14,187,5,0,32,0,100,100,50,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,226,76,130,109,5,0,32,0,100,100,50,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,229,42,104,121,5,0,32,0,100,100,50,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,73,209,221,172,5,0,32,0,100,100,50,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,192,176,127,17,5,0,32,0,100,100,50,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,229,87,214,153,10,0,16,1,100,100,50,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,36,56,122,17,10,0,16,1,100,100,50,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,37,195,208,152,12,0,64,0,100,100,50,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,250,231,162,94,12,0,64,0,100,100,50,106,46,48,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,229,116,93,150,1,0,16,1,100,100,50,106,46,48,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,243,184,142,149,1,0,16,1,100,100,50,46,48,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,202,113,133,211,1,0,16,1,100,100,50,46,48,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,187,59,90,109,1,0,16,1,100,100,50,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,139,11,154,144,1,0,16,1,100,100,50,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,77,60,229,1,0,16,1,100,100,50,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,159,39,134,95,1,0,16,1,100,100,50,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,38,76,149,173,1,0,16,1,100,100,50,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,110,78,107,164,5,0,32,0,100,100,50,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,252,80,252,213,5,0,32,0,100,100,50,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,103,8,124,131,5,0,32,0,100,100,50,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,28,194,14,187,5,0,32,0,100,100,50,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,226,76,130,109,5,0,32,0,100,100,50,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,229,42,104,121,5,0,32,0,100,100,50,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,73,209,221,172,5,0,32,0,100,100,50,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,192,176,127,17,5,0,32,0,100,100,50,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,229,87,214,153,10,0,16,1,100,100,50,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,36,56,122,17,10,0,16,1,100,100,50,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,37,195,208,152,12,0,64,0,100,100,50,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,250,231,162,94,12,0,64,0,101,112,114,45,49,52,49,51,56,46,97,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,27,11,40,223,1,0,16,1,101,112,114,45,49,52,49,52,48,46,97,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,238,35,242,72,1,0,16,1,109,112,114,45,49,52,49,51,57,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,49,21,195,6,1,0,16,1,109,112,114,45,49,52,49,52,49,46,97,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,75,73,10,8,1,0,16,1,101,112,114,45,49,52,49,50,55,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,136,205,40,34,2,0,32,0,101,112,114,45,49,52,49,50,56,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,16,142,186,237,2,0,32,0,101,112,114,45,49,52,49,50,57,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,5,195,236,232,2,0,32,0,109,112,114,45,49,52,49,51,52,46,99,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,75,106,218,79,3,0,32,0,109,112,114,45,49,52,49,52,50,46,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,42,31,191,60,3,0,32,0,109,112,114,45,49,52,49,51,53,46,99,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,118,72,199,233,3,0,32,0,109,112,114,45,49,52,49,52,51,46,97,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,49,44,2,89,3,0,32,0,109,112,114,45,49,52,49,51,54,46,99,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,88,152,13,114,3,0,32,0,109,112,114,45,49,52,49,52,52,46,97,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,212,253,117,119,3,0,32,0,101,112,114,45,49,52,49,51,55,46,99,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,101,66,108,132,3,0,32,0,101,112,114,45,49,52,49,52,53,46,97,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,151,199,118,14,3,0,32,0,101,112,114,45,49,52,49,51,51,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,101,102,249,207,4,0,16,1,109,112,114,45,49,52,49,51,50,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,32,2,174,31,19,0,64,0,109,112,114,45,49,52,49,51,49,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,11,125,90,190,19,0,64,0,101,112,114,45,49,52,49,51,48,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,161,52,143,148,19,0,64,0,51,49,55,45,48,49,56,50,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,1,54,138,46,5,0,16,1,184,40,2,0,1,0,0,0,208,155,215,0,248,191,2,0,56,250,6,0,1,0,0,0,212,155,215,0,184,160,2,0,184,164,8,0,1,0,0,0,209,155,215,0,64,246,1,0,88,149,7,0,1,0,0,0,213,155,215,0,136,224,1,0,104,28,8,0,1,0,0,0,215,155,215,0,232,209,1,0,248,23,7,0,1,0,0,0,187,155,215,0,144,189,1,0,56,210,6,0,1,0,0,0,205,155,215,0,192,135,2,0,24,163,6,0,1,0,0,0,204,155,215,0,240,108,2,0,152,122,6,0,1,0,0,0,207,155,215,0,96,82,2,0,192,72,6,0,1,0,0,0,206,155,215,0,32,56,2,0,48,123,2,0,1,0,0,0,200,155,215,0,152,30,2,0,96,69,2,0,1,0,0,0,201,155,215,0,232,10,2,0,176,223,1,0,1,0,0,0,197,155,215,0,72,198,1,0,192,209,1,0,1,0,0,0,196,155,215,0,24,182,1,0,24,198,1,0,1,0,0,0,199,155,215,0,40,167,1,0,120,189,1,0,1,0,0,0,198,155,215,0,200,149,1,0,248,187,8,0,1,0,0,0,192,155,215,0,56,126,1,0,184,179,8,0,1,0,0,0,193,155,215,0,32,101,1,0,192,122,8,0,1,0,0,0,189,155,215,0,208,174,1,0,40,116,8,0,1,0,0,0,188,155,215,0,48,160,1,0,72,110,8,0,1,0,0,0,191,155,215,0,160,140,1,0,184,102,8,0,1,0,0,0,190,155,215,0,56,112,1,0,240,45,8,0,1,0,0,0,184,155,215,0,32,92,1,0,40,38,8,0,1,0,0,0,185,155,215,0,64,77,1,0,16,17,8,0,1,0,0,0,211,155,215,0,224,12,8,0,32,77,1,0,1,0,0,0,210,155,215,0,216,70,1,0,88,212,3,0,1,0,0,0,200,154,215,0,40,185,3,0,248,5,8,0,9,0,0,0,0,156,215,0,32,58,1,0,144,250,7,0,9,0,0,0,1,156,215,0,32,58,1,0,16,0,0,0,255,255,251,0,0,0,0,0,0,0,0,0,254,0,4,0,32,4,2,0,16,0,0,0,1,3,0,0,40,88,7,0,16,0,0,0,1,3,1,0,96,39,7,0,16,0,0,0,1,3,3,0,144,251,6,0,16,0,0,0,1,3,2,0,184,164,6,0,0,0,0,0,254,0,4,0,72,202,5,0,16,0,0,0,1,12,12,0,80,246,3,0,16,0,0,0,1,12,8,0,248,38,7,0,16,0,0,0,1,12,4,0,112,212,3,0,16,0,0,0,1,12,0,0,24,99,5,0,0,0,0,0,254,0,2,0,112,104,5,0,16,0,0,0,1,16,16,0,96,135,7,0,16,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,2,0,80,11,5,0,16,0,0,0,1,32,32,0,96,135,7,0,16,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,16,0,0,0,1,128,128,0,96,135,7,0,16,0,0,0,1,128,0,0,152,182,7,0,99,55,56,95,52,49,45,49,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,228,127,41,207,2,0,16,1,99,55,56,95,52,51,45,49,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,214,186,168,56,2,0,16,1,99,55,56,95,52,50,45,49,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,43,171,36,65,2,0,16,1,99,55,56,95,52,52,45,49,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,110,91,165,80,2,0,16,1,99,55,56,45,51,48,45,49,46,51,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,24,172,106,2,6,0,16,1,99,55,56,45,51,49,45,49,46,51,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,232,35,206,103,6,0,16,1,99,55,56,45,51,52,46,99,52,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,67,105,24,242,9,0,16,1,99,55,56,45,49,48,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,124,137,177,68,12,0,32,0,99,55,56,45,49,49,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,163,212,179,125,12,0,32,0,99,55,56,45,48,56,46,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,17,82,114,108,17,0,32,0,99,55,56,45,48,55,46,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,91,13,160,157,17,0,32,0,99,55,56,45,48,54,46,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,27,233,9,131,17,0,32,0,99,55,56,45,48,53,46,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,104,31,0,144,17,0,32,0,99,55,56,45,48,57,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,245,230,189,13,22,0,32,0,99,55,56,45,48,52,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,124,163,26,204,23,0,32,0,99,55,56,45,49,50,46,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,4,116,38,176,24,0,64,0,99,55,56,45,49,51,46,52,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,162,58,54,27,24,0,64,0,99,55,56,45,49,52,46,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,251,77,173,156,25,0,64,0,99,55,56,45,50,53,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,246,166,69,114,0,0,0,8,99,55,56,45,49,53,46,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,48,31,248,251,0,0,0,8,99,55,56,45,50,49,46,55,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,39,191,38,41,0,0,0,8,99,56,52,45,49,48,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,252,139,62,100,0,0,0,8,99,56,52,45,49,49,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,83,136,114,16,0,0,0,8,32,0,0,0,255,255,255,0,0,0,0,0,33,0,0,0,255,255,127,0,0,0,0,0,0,0,0,0,254,0,8,0,200,87,7,0,32,0,0,0,1,7,0,0,40,88,7,0,32,0,0,0,1,7,1,0,96,39,7,0,32,0,0,0,1,7,7,0,144,251,6,0,32,0,0,0,1,7,6,0,184,164,6,0,32,0,0,0,1,7,5,0,80,74,6,0,32,0,0,0,1,7,4,0,192,32,6,0,32,0,0,0,1,7,3,0,192,234,2,0,32,0,0,0,1,7,2,0,32,242,5,0,0,0,0,0,254,0,8,0,160,123,6,0,32,0,0,0,1,56,0,0,40,88,7,0,32,0,0,0,1,56,8,0,96,39,7,0,32,0,0,0,1,56,56,0,144,251,6,0,32,0,0,0,1,56,48,0,184,164,6,0,32,0,0,0,1,56,40,0,80,74,6,0,32,0,0,0,1,56,32,0,192,32,6,0,32,0,0,0,1,56,24,0,192,234,2,0,32,0,0,0,1,56,16,0,32,242,5,0,0,0,0,0,254,0,2,0,144,212,8,0,32,0,0,0,1,64,64,0,96,135,7,0,32,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,24,172,6,0,32,0,0,0,1,128,128,0,96,135,7,0,32,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,33,0,0,0,1,12,8,0,80,246,3,0,33,0,0,0,1,12,12,0,248,38,7,0,33,0,0,0,1,12,4,0,112,212,3,0,33,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,3,0,216,212,3,0,33,0,0,0,1,48,48,0,208,75,4,0,33,0,0,0,1,48,32,0,8,49,4,0,33,0,0,0,1,48,16,0,152,21,4,0,0,0,0,0,254,0,2,0,168,234,7,0,33,0,0,0,1,128,128,0,96,135,7,0,33,0,0,0,1,128,0,0,152,182,7,0,100,116,46,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,114,164,52,129,0,0,16,1,50,49,106,45,50,45,51,46,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,94,112,121,87,0,0,16,1,100,116,46,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,19,84,58,82,0,0,16,1,54,51,55,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,3,45,35,245,0,0,16,1,50,49,106,45,48,45,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,187,149,250,158,0,0,16,1,54,56,55,48,53,112,114,116,46,109,99,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,211,178,203,52,0,0,16,1,100,116,46,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,152,2,11,134,0,0,32,0,100,116,46,49,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,250,208,13,117,0,0,32,0,100,116,46,49,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,123,168,207,34,0,0,32,0,100,116,46,49,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,52,28,159,138,0,0,32,0,50,49,106,45,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,27,35,79,203,0,0,32,0,100,116,46,49,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,156,191,75,123,0,0,32,0,100,116,46,49,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,212,9,55,223,0,0,32,0,100,116,46,49,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,84,33,3,89,0,0,32,0,50,49,106,45,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,125,81,199,101,0,0,32,0,100,116,46,55,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,4,86,193,114,0,0,32,0,50,49,106,45,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,237,10,100,198,0,0,32,0,100,116,46,49,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,98,203,189,21,0,0,32,0,50,49,106,45,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,124,46,180,95,0,0,32,0,50,49,106,45,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,227,93,117,52,0,0,32,0,50,49,106,45,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,248,230,77,144,0,0,32,0,50,49,106,45,107,45,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,169,48,177,253,0,0,32,0,50,49,106,45,108,45,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,41,149,51,70,0,0,32,0,20,0,0,0,255,255,0,0,0,0,0,0,21,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,20,0,0,0,1,15,3,0,144,102,8,0,20,0,0,0,1,15,2,0,176,45,8,0,20,0,0,0,1,15,7,0,96,87,4,0,20,0,0,0,1,15,1,0,224,127,8,0,20,0,0,0,1,15,6,0,136,252,1,0,20,0,0,0,1,15,11,0,0,67,1,0,20,0,0,0,1,15,15,0,144,226,3,0,20,0,0,0,1,15,10,0,232,195,3,0,20,0,0,0,1,15,5,0,240,169,3,0,20,0,0,0,1,15,0,0,32,123,8,0,20,0,0,0,1,15,14,0,232,143,1,0,20,0,0,0,1,15,9,0,248,116,8,0,20,0,0,0,1,15,13,0,152,81,3,0,20,0,0,0,1,15,4,0,192,110,8,0,20,0,0,0,1,15,8,0,96,102,7,0,20,0,0,0,1,15,12,0,184,105,6,0,0,0,0,0,254,0,16,0,160,123,6,0,20,0,0,0,1,240,48,0,144,102,8,0,20,0,0,0,1,240,32,0,176,45,8,0,20,0,0,0,1,240,112,0,96,87,4,0,20,0,0,0,1,240,16,0,224,127,8,0,20,0,0,0,1,240,96,0,136,252,1,0,20,0,0,0,1,240,176,0,0,67,1,0,20,0,0,0,1,240,240,0,144,226,3,0,20,0,0,0,1,240,160,0,232,195,3,0,20,0,0,0,1,240,80,0,240,169,3,0,20,0,0,0,1,240,0,0,32,123,8,0,20,0,0,0,1,240,224,0,232,143,1,0,20,0,0,0,1,240,144,0,248,116,8,0,20,0,0,0,1,240,208,0,152,81,3,0,20,0,0,0,1,240,64,0,192,110,8,0,20,0,0,0,1,240,128,0,96,102,7,0,20,0,0,0,1,240,192,0,184,105,6,0,17,0,0,0,255,255,255,0,0,0,0,0,18,0,0,0,255,255,127,0,0,0,0,0,0,0,0,0,254,0,8,0,200,87,7,0,17,0,0,0,1,7,0,0,16,242,7,0,17,0,0,0,1,7,1,0,104,236,7,0,17,0,0,0,1,7,7,0,128,230,7,0,17,0,0,0,1,7,6,0,184,164,6,0,17,0,0,0,1,7,5,0,80,74,6,0,17,0,0,0,1,7,4,0,192,32,6,0,17,0,0,0,1,7,3,0,192,234,2,0,17,0,0,0,1,7,2,0,32,242,5,0,0,0,0,0,254,0,8,0,160,123,6,0,17,0,0,0,1,56,0,0,16,242,7,0,17,0,0,0,1,56,8,0,104,236,7,0,17,0,0,0,1,56,56,0,128,230,7,0,17,0,0,0,1,56,48,0,184,164,6,0,17,0,0,0,1,56,40,0,80,74,6,0,17,0,0,0,1,56,32,0,192,32,6,0,17,0,0,0,1,56,24,0,192,234,2,0,17,0,0,0,1,56,16,0,32,242,5,0,0,0,0,0,254,0,2,0,144,212,8,0,17,0,0,0,1,64,64,0,96,135,7,0,17,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,0,0,128,129,4,0,18,0,0,0,1,3,0,0,192,255,2,0,18,0,0,0,1,3,1,0,208,75,4,0,18,0,0,0,1,3,3,0,8,49,4,0,18,0,0,0,1,3,2,0,152,21,4,0,0,0,0,0,254,0,4,0,72,202,5,0,18,0,0,0,1,12,8,0,80,246,3,0,18,0,0,0,1,12,12,0,248,38,7,0,18,0,0,0,1,12,4,0,112,212,3,0,18,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,4,0,104,115,3,0,18,0,0,0,1,48,0,0,208,75,4,0,18,0,0,0,1,48,16,0,8,50,4,0,18,0,0,0,1,48,48,0,8,49,4,0,18,0,0,0,1,48,32,0,152,21,4,0,0,0,0,0,254,0,4,0,104,159,3,0,18,0,0,0,1,64,0,0,56,111,3,0,18,0,0,0,1,64,64,0,104,134,3,0,0,0,0,0,254,0,2,0,168,234,7,0,18,0,0,0,1,128,128,0,96,135,7,0,18,0,0,0,1,128,0,0,152,182,7,0,100,114,107,112,108,116,50,99,46,100,97,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,89,165,12,90,1,0,16,1,100,114,107,112,108,116,50,101,46,100,97,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,125,17,226,82,1,0,16,1,100,114,107,112,108,116,50,103,46,100,97,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,156,33,147,64,1,0,16,1,100,114,107,112,108,116,50,106,46,100,97,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,141,199,116,185,1,0,16,1,100,114,107,112,108,116,50,107,46,100,97,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,133,115,163,113,1,0,16,1,100,114,107,112,108,116,50,108,46,100,97,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,84,81,210,90,1,0,16,1,100,114,107,112,108,116,50,109,46,100,97,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,34,1,47,141,1,0,16,1,100,114,107,112,108,116,50,112,46,100,97,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,59,37,102,45,1,0,16,1,53,99,46,115,110,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,84,148,43,103,2,0,16,1,100,114,107,112,108,116,53,102,46,100,97,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,102,238,240,42,4,0,32,0,100,114,107,112,108,116,53,104,46,100,97,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,37,50,239,102,4,0,32,0,54,101,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,36,225,182,134,7,0,32,0,8,0,0,0,255,255,0,0,0,0,0,0,9,0,0,0,255,255,2,0,0,0,0,0,10,0,0,0,255,255,12,0,0,0,0,0,0,0,0,0,254,0,2,0,120,33,2,0,9,0,0,0,1,1,0,0,96,32,2,0,9,0,0,0,1,1,1,0,168,30,2,0,0,0,0,0,254,0,2,0,128,129,4,0,9,0,0,0,1,2,2,0,192,255,2,0,9,0,0,0,1,2,0,0,208,75,4,0,0,0,0,0,254,0,4,0,32,4,2,0,10,0,0,0,1,6,4,0,128,103,7,0,10,0,0,0,1,6,6,0,56,52,2,0,10,0,0,0,1,6,2,0,224,44,2,0,10,0,0,0,1,6,0,0,224,43,2,0,0,0,0,0,254,0,2,0,64,37,5,0,10,0,0,0,1,8,8,0,160,191,4,0,10,0,0,0,1,8,0,0,240,159,4,0,0,0,0,0,184,40,2,0,1,0,0,0,168,148,215,0,248,191,2,0,56,250,6,0,1,0,0,0,170,148,215,0,184,160,2,0,184,164,8,0,1,0,0,0,169,148,215,0,64,246,1,0,88,149,7,0,1,0,0,0,171,148,215,0,136,224,1,0,56,210,6,0,1,0,0,0,184,148,215,0,192,135,2,0,24,163,6,0,1,0,0,0,185,148,215,0,240,108,2,0,152,122,6,0,1,0,0,0,187,148,215,0,96,82,2,0,192,72,6,0,1,0,0,0,186,148,215,0,32,56,2,0,48,123,2,0,1,0,0,0,188,148,215,0,152,30,2,0,96,69,2,0,1,0,0,0,189,148,215,0,232,10,2,0,176,223,1,0,1,0,0,0,176,148,215,0,72,198,1,0,192,209,1,0,1,0,0,0,177,148,215,0,24,182,1,0,24,198,1,0,1,0,0,0,179,148,215,0,40,167,1,0,120,189,1,0,1,0,0,0,178,148,215,0,200,149,1,0,248,187,8,0,1,0,0,0,180,148,215,0,56,126,1,0,184,179,8,0,1,0,0,0,181,148,215,0,32,101,1,0,88,212,3,0,1,0,0,0,200,147,215,0,40,185,3,0,16,17,8,0,1,0,0,0,172,148,215,0,224,12,8,0,56,58,1,0,1,0,0,0,173,148,215,0,64,50,1,0,248,5,8,0,9,0,0,0,96,149,215,0,32,58,1,0,144,250,7,0,9,0,0,0,97,149,215,0,32,58,1,0,99,48,55,95,50,48,45,50,46,55,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,184,69,243,160,2,0,16,1,99,48,55,95,49,57,45,50,46,55,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,198,18,84,146,2,0,16,1,99,48,55,95,50,49,45,50,46,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,55,14,214,189,2,0,16,1,99,48,55,95,49,56,45,50,46,55,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,155,216,252,35,2,0,16,1,99,48,55,45,48,57,46,55,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,206,194,105,204,1,0,16,1,99,48,55,95,49,55,46,54,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,5,201,22,174,9,0,16,1,99,48,55,45,48,51,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,206,175,155,24,11,0,32,0,99,48,55,45,48,52,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,129,30,66,80,11,0,32,0,99,48,55,45,48,54,46,50])
.concat([55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,214,188,235,94,17,0,32,0,99,48,55,45,48,53,46,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,80,5,109,251,17,0,32,0,99,48,55,45,48,56,46,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,70,200,125,160,17,0,32,0,99,48,55,45,48,55,46,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,116,158,159,253,17,0,32,0,99,48,55,45,49,48,46,57,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,217,14,190,75,24,0,64,0,99,48,55,45,49,49,46,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,153,86,129,60,24,0,64,0,99,48,55,45,49,50,46,49,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,88,18,183,224,25,0,64,0,99,48,55,45,49,51,46,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,179,142,161,60,0,0,0,8,99,48,55,45,49,52,46,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,147,161,242,186,0,0,0,8,20,0,0,0,255,255,254,0,0,0,0,0,21,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,96,19,7,0,20,0,0,0,1,2,2,0,248,38,7,0,20,0,0,0,1,2,0,0,176,64,8,0,0,0,0,0,254,0,2,0,232,75,4,0,20,0,0,0,1,4,4,0,96,135,7,0,20,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,20,0,0,0,1,8,0,0,96,135,7,0,20,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,20,0,0,0,1,48,16,0,104,236,7,0,20,0,0,0,1,48,48,0,128,230,7,0,20,0,0,0,1,48,0,0,120,211,6,0,20,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,20,0,0,0,1,192,64,0,104,236,7,0,20,0,0,0,1,192,192,0,128,230,7,0,20,0,0,0,1,192,0,0,120,211,6,0,20,0,0,0,1,192,128,0,184,164,6,0,0,0,0,0,254,0,4,0,72,202,5,0,21,0,0,0,1,3,2,0,80,246,3,0,21,0,0,0,1,3,3,0,80,124,6,0,21,0,0,0,1,3,1,0,112,212,3,0,21,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,64,37,5,0,21,0,0,0,1,12,12,0,184,174,8,0,21,0,0,0,1,12,8,0,176,165,8,0,21,0,0,0,1,12,4,0,136,156,8,0,21,0,0,0,1,12,0,0,16,150,8,0,0,0,0,0,254,0,4,0,128,129,4,0,21,0,0,0,1,48,48,0,8,49,4,0,21,0,0,0,1,48,32,0,152,21,4,0,21,0,0,0,1,48,16,0,72,246,3,0,21,0,0,0,1,48,0,0,72,0,3,0,0,0,0,0,254,0,2,0,104,159,3,0,21,0,0,0,1,128,0,0,96,135,7,0,21,0,0,0,1,128,128,0,152,182,7,0,0,0,0,0,100,98,49,49,97,46,112,114,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,251,211,123,66,1,0,16,1,100,98,57,97,46,112,114,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,99,69,22,87,1,0,16,1,100,98,49,48,97,46,112,114,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,94,156,91,7,1,0,16,1,100,98,49,50,97,46,112,114,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,139,166,1,237,1,0,16,1,100,98,56,97,46,112,114,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,244,31,4,253,1,0,16,1,100,98,54,97,46,112,114,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,75,181,141,68,1,0,16,1,100,98,55,97,46,112,114,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,94,31,91,103,1,0,16,1,100,98,53,97,46,112,114,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,204,158,101,117,1,0,16,1,100,98,51,97,46,112,114,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,16,151,154,158,4,0,32,0,100,98,49,97,46,112,114,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,205,100,185,76,4,0,32,0,100,98,52,97,46,112,114,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,51,223,210,217,4,0,32,0,100,98,50,97,46,112,114,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,245,106,10,10,4,0,32,0,109,105,45,55,54,48,51,45,53,46,105,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,47,249,49,241,7,0,32,0,109,105,45,55,54,48,51,45,53,46,105,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,71,76,165,226,0,0,0,8,12,0,0,0,255,255,0,0,0,0,0,0,13,0,0,0,255,255,0,0,0,0,0,0,14,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,136,85,2,0,12,0,0,0,1,32,0,0,96,135,7,0,12,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,12,0,0,0,1,64,0,0,96,135,7,0,12,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,192,78,2,0,13,0,0,0,1,64,0,0,96,135,7,0,13,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,32,4,2,0,13,0,0,0,1,128,128,0,224,127,8,0,13,0,0,0,1,128,0,0,32,123,8,0,0,0,0,0,254,0,4,0,128,129,4,0,14,0,0,0,1,3,0,0,8,49,4,0,14,0,0,0,1,3,1,0,152,21,4,0,14,0,0,0,1,3,2,0,72,246,3,0,14,0,0,0,1,3,3,0,72,0,3,0,0,0,0,0,254,0,2,0,168,72,2,0,14,0,0,0,1,4,0,0,96,135,7,0,14,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,254,0,2,0,192,71,2,0,14,0,0,0,1,8,8,0,96,135,7,0,14,0,0,0,1,8,0,0,152,182,7,0,98,56,55,45,48,54,46,117,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,97,35,207,2,0,16,1,98,56,55,45,48,53,46,117,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,199,237,21,127,2,0,16,1,98,56,55,45,48,55,46,49,51,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,160,239,224,226,9,0,16,1,98,56,55,45,48,50,46,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,160,67,173,137,15,0,32,0,98,56,55,45,48,49,46,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,225,42,232,129,15,0,32,0,98,56,55,45,48,52,46,51,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,182,52,132,149,15,0,32,0,98,56,55,45,48,51,46,51,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,224,90,21,206,15,0,32,0,21,0,0,0,255,255,254,0,0,0,0,0,22,0,0,0,255,255,127,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,21,0,0,0,1,1,0,0,120,97,1,0,21,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,2,0,144,212,8,0,21,0,0,0,1,2,2,0,96,135,7,0,21,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,21,0,0,0,1,4,4,0,96,135,7,0,21,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,21,0,0,0,1,8,0,0,96,135,7,0,21,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,21,0,0,0,1,48,16,0,104,236,7,0,21,0,0,0,1,48,48,0,128,230,7,0,21,0,0,0,1,48,0,0,120,211,6,0,21,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,21,0,0,0,1,192,64,0,104,236,7,0,21,0,0,0,1,192,192,0,128,230,7,0,21,0,0,0,1,192,0,0,120,211,6,0,21,0,0,0,1,192,128,0,184,164,6,0,0,0,0,0,254,0,4,0,72,202,5,0,22,0,0,0,1,3,2,0,80,246,3,0,22,0,0,0,1,3,3,0,80,124,6,0,22,0,0,0,1,3,1,0,112,212,3,0,22,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,64,37,5,0,22,0,0,0,1,12,8,0,248,46,3,0,22,0,0,0,1,12,12,0,224,23,3,0,22,0,0,0,1,12,4,0,240,191,4,0,22,0,0,0,1,12,0,0,120,7,5,0,0,0,0,0,254,0,4,0,128,129,4,0,22,0,0,0,1,48,0,0,208,75,4,0,22,0,0,0,1,48,48,0,8,49,4,0,22,0,0,0,1,48,16,0,152,21,4,0,22,0,0,0,1,48,32,0,72,246,3,0,0,0,0,0,254,0,2,0,104,159,3,0,22,0,0,0,1,128,128,0,96,135,7,0,22,0,0,0,1,128,0,0,152,182,7,0,100,109,106,95,51,56,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,152,23,253,130,1,0,16,1,100,109,106,95,51,57,46,49,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,204,108,54,53,1,0,16,1,100,109,106,95,52,48,46,49,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,10,23,124,161,1,0,16,1,100,109,106,95,52,49,46,49,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,145,179,240,106,1,0,16,1,100,109,95,51,51,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,196,96,77,56,1,0,16,1,100,109,95,51,52,46,49,48,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,15,227,171,25,1,0,16,1,100,109,95,51,53,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,200,133,75,192,1,0,16,1,100,109,95,51,54,46,49,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,222,131,190,137,1,0,16,1,100,109,95,48,50,46,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,72,220,152,139,4,0,32,0,100,109,95,48,49,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,51,108,137,128,4,0,32,0,100,109,95,49,48,46,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,239,217,231,194,4,0,32,0,100,109,95,48,57,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,165,175,196,201,4,0,32,0,100,109,95,49,56,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,153,219,160,26,4,0,32,0,100,109,95,49,55,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,173,216,110,220,4,0,32,0,100,109,95,51,48,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,189,248,211,217,4,0,32,0,100,109,95,50,57,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,150,135,164,73,4,0,32,0,100,109,95,48,52,46,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,240,248,244,164,4,0,32,0,100,109,95,48,51,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,98,62,3,177,4,0,32,0,100,109,95,49,50,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,106,215,253,16,4,0,32,0,100,109,95,49,49,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,4,203,64,144,4,0,32,0,100,109,95,50,48,46,55,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,62,11,29,40,4,0,32,0,100,109,95,49,57,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,47,181,35,38,4,0,32,0,100,109,95,51,50,46,57,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,68,35,105,153,4,0,32,0,100,109,95,51,49,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,41,183,172,84,4,0,32,0,100,109,95,48,54,46,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,25,187,36,174,4,0,32,0,100,109,95,48,53,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,26,39,78,211,4,0,32,0,100,109,95,49,52,46,49,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,55,221,112,63,4,0,32,0,100,109,95,49,51,46,49,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,230,226,105,126,4,0,32,0,100,109,95,50,50,46,56,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,198,182,201,55,4,0,32,0,100,109,95,50,49,46,56,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,180,69,19,47,4,0,32,0,100,109,95,50,54,46,49,48,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,42,33,42,60,4,0,32,0,100,109,95,50,53,46,49,48,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,5,172,154,136,4,0,32,0,100,109,95,48,56,46,56,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,140,242,192,188,4,0,32,0,100,109,95,48,55,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,106,22,64,42,4,0,32,0,100,109,95,49,54,46,49,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,3,92,248,32,4,0,32,0,100,109,95,49,53,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,75,20,38,132,4,0,32,0,100,109,95,50,52,46,57,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,97,141,8,218,4,0,32,0,100,109,95,50,51,46,57,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,240,29,225,23,4,0,32,0,100,109,95,50,56,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,28,186,135,241,4,0,32,0,100,109,95,50,55,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,120,156,247,41,4,0,32,0,51,55,46,49,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,229,246,146,54,3,0,16,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,100,109,50,50,97,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,0,0,0,0,0,0,24,108,119,105,111,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,12,185,82,173,0,0,0,8,18,0,0,0,255,255,0,0,0,0,0,0,19,0,0,0,255,255,0,0,0,0,0,0,20,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,8,0,200,87,7,0,18,0,0,0,1,7,7,0,80,252,6,0,18,0,0,0,1,7,6,0,16,242,7,0,18,0,0,0,1,7,5,0,104,236,7,0,18,0,0,0,1,7,0,0,128,230,7,0,18,0,0,0,1,7,1,0,184,164,6,0,18,0,0,0,1,7,2,0,80,74,6,0,18,0,0,0,1,7,3,0,192,32,6,0,18,0,0,0,1,7,4,0,32,242,5,0,0,0,0,0,254,0,8,0,160,123,6,0,18,0,0,0,1,56,56,0,80,252,6,0,18,0,0,0,1,56,48,0,16,242,7,0,18,0,0,0,1,56,40,0,104,236,7,0,18,0,0,0,1,56,0,0,128,230,7,0,18,0,0,0,1,56,8,0,184,164,6,0,18,0,0,0,1,56,16,0])
.concat([80,74,6,0,18,0,0,0,1,56,24,0,192,32,6,0,18,0,0,0,1,56,32,0,32,242,5,0,0,0,0,0,254,0,3,0,200,30,2,0,18,0,0,0,1,192,0,0,72,60,1,0,18,0,0,0,1,192,64,0,88,51,1,0,18,0,0,0,1,192,192,0,96,19,1,0,0,0,0,0,254,0,8,0,72,202,5,0,19,0,0,0,1,7,3,0,72,198,6,0,19,0,0,0,1,7,2,0,208,75,4,0,19,0,0,0,1,7,1,0,8,49,4,0,19,0,0,0,1,7,0,0,72,195,6,0,19,0,0,0,1,7,4,0,72,246,3,0,19,0,0,0,1,7,5,0,72,0,3,0,19,0,0,0,1,7,6,0,64,47,7,0,19,0,0,0,1,7,7,0,48,173,6,0,0,0,0,0,254,0,4,0,64,37,5,0,19,0,0,0,1,48,16,0,200,75,1,0,19,0,0,0,1,48,32,0,48,75,1,0,19,0,0,0,1,48,0,0,144,74,1,0,19,0,0,0,1,48,48,0,32,73,1,0,0,0,0,0,254,0,2,0,72,4,1,0,19,0,0,0,1,128,0,0,96,135,7,0,19,0,0,0,1,128,128,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,3,0,0,8,49,4,0,20,0,0,0,1,3,1,0,152,21,4,0,20,0,0,0,1,3,2,0,72,246,3,0,20,0,0,0,1,3,3,0,72,0,3,0,0,0,0,0,254,0,2,0,120,207,1,0,20,0,0,0,1,16,0,0,96,135,7,0,20,0,0,0,1,16,16,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,20,0,0,0,1,64,64,0,96,135,7,0,20,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,79,2,0,20,0,0,0,1,128,0,0,32,182,8,0,20,0,0,0,1,128,128,0,80,251,6,0,99,121,98,117,95,100,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,251,96,117,238,1,0,16,1,99,121,98,117,95,100,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,160,37,116,126,1,0,16,1,99,121,98,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,142,64,64,236,1,0,16,1,99,121,98,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,210,190,208,26,1,0,16,1,99,121,98,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,154,163,69,98,1,0,16,1,99,121,98,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,35,226,72,75,1,0,16,1,99,121,98,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,56,82,225,1,0,16,1,99,121,98,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,59,0,244,117,1,0,16,1,99,121,98,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,146,225,220,240,5,0,32,0,99,121,98,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,156,163,122,24,5,0,32,0,99,121,98,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,18,75,14,138,5,0,32,0,99,121,98,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,18,38,182,52,5,0,32,0,99,121,98,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,87,121,83,193,5,0,32,0,99,121,98,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,134,158,52,21,5,0,32,0,99,121,98,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,125,151,62,216,5,0,32,0,99,121,98,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,92,173,205,119,5,0,32,0,99,121,98,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,121,176,15,156,10,0,16,1,99,121,98,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,78,12,203,81,10,0,16,1,99,121,98,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,178,202,44,54,12,0,64,0,99,121,98,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,204,233,102,112,12,0,64,0,99,121,98,106,95,100,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,113,64,179,158,1,0,16,1,99,121,98,106,95,100,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,215,60,34,207,1,0,16,1,99,121,98,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,142,64,64,236,1,0,16,1,99,121,98,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,210,190,208,26,1,0,16,1,99,121,98,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,154,163,69,98,1,0,16,1,99,121,98,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,35,226,72,75,1,0,16,1,99,121,98,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,56,82,225,1,0,16,1,99,121,98,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,59,0,244,117,1,0,16,1,99,121,98,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,146,225,220,240,5,0,32,0,99,121,98,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,156,163,122,24,5,0,32,0,99,121,98,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,18,75,14,138,5,0,32,0,99,121,98,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,18,38,182,52,5,0,32,0,99,121,98,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,87,121,83,193,5,0,32,0,99,121,98,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,134,158,52,21,5,0,32,0,99,121,98,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,125,151,62,216,5,0,32,0,99,121,98,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,92,173,205,119,5,0,32,0,99,121,98,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,121,176,15,156,10,0,16,1,99,121,98,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,78,12,203,81,10,0,16,1,99,121,98,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,178,202,44,54,12,0,64,0,99,121,98,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,204,233,102,112,12,0,64,0,168,86,7,0,1,0,0,0,212,47,216,0,248,191,2,0,24,38,7,0,1,0,0,0,208,47,216,0,184,160,2,0,56,210,6,0,1,0,0,0,35,48,216,0,192,135,2,0,24,163,6,0,1,0,0,0,34,48,216,0,240,108,2,0,152,122,6,0,1,0,0,0,33,48,216,0,96,82,2,0,192,72,6,0,1,0,0,0,32,48,216,0,32,56,2,0,56,142,7,0,1,0,0,0,36,48,216,0,152,30,2,0,200,136,7,0,1,0,0,0,37,48,216,0,232,10,2,0,40,129,7,0,1,0,0,0,38,48,216,0,152,138,8,0,216,132,7,0,1,0,0,0,39,48,216,0,48,119,7,0,40,246,1,0,1,0,0,0,213,47,216,0,64,246,1,0,144,236,1,0,1,0,0,0,209,47,216,0,136,224,1,0,176,223,1,0,1,0,0,0,43,48,216,0,72,198,1,0,192,209,1,0,1,0,0,0,42,48,216,0,24,182,1,0,24,198,1,0,1,0,0,0,41,48,216,0,40,167,1,0,120,189,1,0,1,0,0,0,40,48,216,0,200,149,1,0,88,126,7,0,1,0,0,0,44,48,216,0,56,126,1,0,8,123,7,0,1,0,0,0,45,48,216,0,32,101,1,0,56,114,7,0,1,0,0,0,46,48,216,0,96,32,8,0,8,119,7,0,1,0,0,0,47,48,216,0,16,68,7,0,88,212,3,0,1,0,0,0,144,46,216,0,40,185,3,0,240,152,1,0,1,0,0,0,201,47,216,0,216,70,1,0,16,17,8,0,1,0,0,0,202,47,216,0,224,12,8,0,136,67,2,0,1,0,0,0,176,48,216,0,112,109,7,0,8,66,2,0,1,0,0,0,184,48,216,0,24,133,7,0,14,0,0,0,255,255,8,0,0,0,0,0,15,0,0,0,255,255,228,0,0,0,0,0,16,0,0,0,255,255,255,0,0,0,0,0,17,0,0,0,255,255,255,0,0,0,0,0,18,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,232,75,4,0,14,0,0,0,1,8,8,0,96,135,7,0,14,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,15,0,0,0,1,1,1,0,96,135,7,0,15,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,15,0,0,0,1,2,2,0,96,135,7,0,15,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,15,0,0,0,1,12,12,0,160,203,8,0,15,0,0,0,1,12,4,0,80,246,3,0,15,0,0,0,1,12,8,0,112,212,3,0,15,0,0,0,1,12,0,0,24,99,5,0,0,0,0,0,254,0,2,0,200,139,4,0,15,0,0,0,1,16,16,0,24,111,4,0,15,0,0,0,1,16,0,0,224,85,4,0,0,0,0,0,254,0,2,0,232,75,4,0,15,0,0,0,1,64,64,0,96,135,7,0,15,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,88,131,3,0,15,0,0,0,1,128,128,0,96,135,7,0,15,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,16,0,200,87,7,0,16,0,0,0,1,15,2,0,32,136,7,0,16,0,0,0,1,15,5,0,40,88,7,0,16,0,0,0,1,15,8,0,96,39,7,0,16,0,0,0,1,15,4,0,120,113,6,0,16,0,0,0,1,15,1,0,232,228,5,0,16,0,0,0,1,15,15,0,144,251,6,0,16,0,0,0,1,15,3,0,56,141,7,0,16,0,0,0,1,15,7,0,120,211,6,0,16,0,0,0,1,15,14,0,184,164,6,0,16,0,0,0,1,15,6,0,24,1,7,0,16,0,0,0,1,15,13,0,80,74,6,0,16,0,0,0,1,15,12,0,192,32,6,0,16,0,0,0,1,15,11,0,192,234,2,0,16,0,0,0,1,15,10,0,32,242,5,0,16,0,0,0,1,15,9,0,176,192,2,0,16,0,0,0,1,15,0,0,16,227,4,0,0,0,0,0,254,0,16,0,160,123,6,0,16,0,0,0,1,240,32,0,32,136,7,0,16,0,0,0,1,240,80,0,40,88,7,0,16,0,0,0,1,240,128,0,96,39,7,0,16,0,0,0,1,240,0,0,192,24,7,0,16,0,0,0,1,240,64,0,120,113,6,0,16,0,0,0,1,240,16,0,232,228,5,0,16,0,0,0,1,240,240,0,144,251,6,0,16,0,0,0,1,240,48,0,56,141,7,0,16,0,0,0,1,240,112,0,120,211,6,0,16,0,0,0,1,240,224,0,184,164,6,0,16,0,0,0,1,240,96,0,24,1,7,0,16,0,0,0,1,240,208,0,80,74,6,0,16,0,0,0,1,240,192,0,192,32,6,0,16,0,0,0,1,240,176,0,192,234,2,0,16,0,0,0,1,240,160,0,32,242,5,0,16,0,0,0,1,240,144,0,176,192,2,0,113,53,95,51,54,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,153,128,160,56,1,0,16,1,113,53,95,52,50,46,49,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,164,179,41,77,1,0,16,1,113,53,95,51,55,46,49,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,188,126,84,235,1,0,16,1,113,53,95,52,51,46,49,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,168,94,246,62,1,0,16,1,113,53,95,51,52,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,23,19,204,127,1,0,16,1,113,53,95,52,48,46,49,48,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,180,183,20,127,1,0,16,1,113,53,95,51,53,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,38,238,172,171,1,0,16,1,113,53,95,52,49,46,49,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,103,64,101,211,1,0,16,1,113,53,95,48,57,46,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,128,109,73,72,4,0,32,0,113,53,95,48,49,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,86,63,69,197,4,0,32,0,113,53,95,49,51,46,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,82,172,65,199,4,0,32,0,113,53,95,48,53,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,143,6,62,20,4,0,32,0,113,53,95,50,52,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,57,209,25,180,4,0,32,0,113,53,95,49,55,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,17,77,59,189,4,0,32,0,113,53,95,51,56,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,12,103,36,156,4,0,32,0,113,53,95,51,50,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,194,199,249,62,4,0,32,0,113,53,95,49,48,46,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,147,94,158,17,4,0,32,0,113,53,95,48,50,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,190,220,202,162,4,0,32,0,113,53,95,49,52,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,130,95,117,168,4,0,32,0,113,53,95,48,54,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,252,145,42,201,4,0,32,0,113,53,95,50,53,46,55,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,203,55,146,151,4,0,32,0,113,53,95,49,56,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,60,160,125,197,4,0,32,0,113,53,95,51,57,46,57,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,37,155,131,165,4,0,32,0,113,53,95,51,51,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,48,57,208,4,4,0,32,0,113,53,95,50,51,46,49,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,36,197,77,225,3,0,16,0,113,53,95,51,48,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,104,27,12,209,5,0,64,0,113,53,95,51,49,46,49,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,150,228,23,125,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,113,53,50,50,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,0,0,0,0,0,0,24,108,119,105,111,46,49,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,12,185,82,173,0,0,0,8,105,111,99,49,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,129,32,24,13,0,0,0,8,15,0,0,0,255,255,0,0,0,0,0,0,16,0,0,0,255,255,1,0,0,0,0,0,17,0,0,0,255,255,96,0,0,0,0,0,0,0,0,0,254,0,8,0,32,4,2,0,15,0,0,0,1,7,7,0,80,252,6,0,15,0,0,0,1,7,6,0,16,242,7,0,15,0,0,0,1,7,5,0,104,236,7,0,15,0,0,0,1,7,0,0,128,230,7,0,15,0,0,0,1,7,1,0,184,164,6,0,15,0,0,0,1,7,2,0,80,74,6,0,15,0,0,0,1,7,3,0,192,32,6,0,15,0,0,0,1,7,4,0,32,242,5,0,0,0,0,0,254,0,2,0,64,232,1,0,15,0,0,0,1,64,0,0,96,135,7,0,15,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,40,39,1,0,15,0,0,0,1,128,0,0,96,135,7,0,15,0,0,0,1,128,128,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,16,0,0,0,1,7,1,0,24,205,7,0,16,0,0,0,1,7,2,0])
.concat([192,255,2,0,16,0,0,0,1,7,3,0,208,75,4,0,16,0,0,0,1,7,4,0,8,49,4,0,16,0,0,0,1,7,5,0,152,21,4,0,0,0,0,0,254,0,3,0,56,191,4,0,16,0,0,0,1,24,24,0,16,53,7,0,16,0,0,0,1,24,8,0,128,9,7,0,16,0,0,0,1,24,0,0,88,136,5,0,0,0,0,0,254,0,5,0,128,129,4,0,16,0,0,0,1,224,224,0,192,255,2,0,16,0,0,0,1,224,96,0,208,75,4,0,16,0,0,0,1,224,0,0,8,49,4,0,16,0,0,0,1,224,64,0,152,21,4,0,16,0,0,0,1,224,32,0,72,246,3,0,0,0,0,0,254,0,2,0,16,227,4,0,17,0,0,0,1,4,0,0,96,135,7,0,17,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,254,0,2,0,72,4,1,0,17,0,0,0,1,8,0,0,96,135,7,0,17,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,2,0,120,207,1,0,17,0,0,0,1,16,0,0,96,135,7,0,17,0,0,0,1,16,16,0,152,182,7,0,0,0,0,0,254,0,2,0,40,111,8,0,17,0,0,0,1,32,0,0,96,135,7,0,17,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,17,0,0,0,1,64,0,0,96,135,7,0,17,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,168,79,2,0,17,0,0,0,1,128,0,0,32,182,8,0,17,0,0,0,1,128,128,0,80,251,6,0,57,48,51,100,50,53,46,103,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,99,86,87,141,0,0,16,1,57,48,51,100,50,52,46,102,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,93,98,115,41,0,0,16,1,57,48,51,99,50,57,46,107,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,109,152,218,250,0,0,32,0,57,48,51,99,50,55,46,107,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,225,184,212,91,0,0,32,0,57,48,51,99,50,56,46,107,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,175,191,210,128,0,0,32,0,57,48,51,99,50,54,46,107,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,61,250,8,248,0,0,32,0,57,48,51,100,50,51,46,107,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,253,201,159,195,0,0,32,0,57,48,51,100,50,49,46,107,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,205,248,123,60,0,0,32,0,57,48,51,100,50,50,46,107,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,145,133,173,149,0,0,32,0,57,48,51,100,50,48,46,107,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,187,161,114,40,0,0,32,0,20,0,0,0,255,255,255,0,0,0,0,0,21,0,0,0,255,255,90,0,0,0,0,0,22,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,20,0,0,0,1,15,2,0,248,223,6,0,20,0,0,0,1,15,5,0,88,179,6,0,20,0,0,0,1,15,8,0,32,136,6,0,20,0,0,0,1,15,4,0,120,113,6,0,20,0,0,0,1,15,1,0,232,228,5,0,20,0,0,0,1,15,15,0,120,90,6,0,20,0,0,0,1,15,3,0,56,141,7,0,20,0,0,0,1,15,7,0,120,211,6,0,20,0,0,0,1,15,14,0,184,164,6,0,20,0,0,0,1,15,6,0,24,1,7,0,20,0,0,0,1,15,13,0,80,74,6,0,20,0,0,0,1,15,12,0,192,32,6,0,20,0,0,0,1,15,11,0,192,234,2,0,20,0,0,0,1,15,10,0,32,242,5,0,20,0,0,0,1,15,9,0,176,192,2,0,20,0,0,0,1,15,0,0,16,227,4,0,0,0,0,0,254,0,16,0,160,123,6,0,20,0,0,0,1,240,32,0,248,223,6,0,20,0,0,0,1,240,80,0,88,179,6,0,20,0,0,0,1,240,128,0,32,136,6,0,20,0,0,0,1,240,64,0,120,113,6,0,20,0,0,0,1,240,16,0,232,228,5,0,20,0,0,0,1,240,240,0,120,90,6,0,20,0,0,0,1,240,48,0,56,141,7,0,20,0,0,0,1,240,112,0,120,211,6,0,20,0,0,0,1,240,224,0,184,164,6,0,20,0,0,0,1,240,96,0,24,1,7,0,20,0,0,0,1,240,208,0,80,74,6,0,20,0,0,0,1,240,192,0,192,32,6,0,20,0,0,0,1,240,176,0,192,234,2,0,20,0,0,0,1,240,160,0,32,242,5,0,20,0,0,0,1,240,144,0,176,192,2,0,20,0,0,0,1,240,0,0,168,165,2,0,0,0,0,0,254,0,4,0,128,129,4,0,21,0,0,0,1,3,3,0,192,255,2,0,21,0,0,0,1,3,2,0,208,75,4,0,21,0,0,0,1,3,1,0,8,49,4,0,21,0,0,0,1,3,0,0,152,21,4,0,0,0,0,0,254,0,2,0,200,30,2,0,21,0,0,0,1,4,0,0,120,97,1,0,21,0,0,0,1,4,4,0,96,19,1,0,0,0,0,0,254,0,4,0,136,0,2,0,21,0,0,0,1,24,24,0,120,7,5,0,21,0,0,0,1,24,16,0,88,232,1,0,21,0,0,0,1,24,8,0,80,218,1,0,21,0,0,0,1,24,0,0,208,204,1,0,0,0,0,0,254,0,4,0,72,202,5,0,21,0,0,0,1,96,96,0,80,246,3,0,21,0,0,0,1,96,64,0,248,38,7,0,21,0,0,0,1,96,32,0,112,212,3,0,21,0,0,0,1,96,0,0,248,160,5,0,0,0,0,0,254,0,2,0,168,234,7,0,21,0,0,0,1,128,128,0,96,135,7,0,21,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,22,0,0,0,1,1,1,0,96,135,7,0,22,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,6,0,22,0,0,0,1,2,2,0,8,208,6,0,22,0,0,0,1,2,0,0,88,204,6,0,0,0,0,0,254,0,2,0,232,75,4,0,22,0,0,0,1,4,4,0,96,135,7,0,22,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,128,156,8,0,22,0,0,0,1,8,8,0,8,49,4,0,22,0,0,0,1,8,0,0,152,21,4,0,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,127,153,250,156,0,0,16,1,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,129,134,206,46,0,0,16,1,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,189,109,44,140,0,0,16,1,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,45,223,1,1,0,0,16,1,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,241,115,183,168,0,0,32,0,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,252,48,117,97,0,0,32,0,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,33,168,240,206,0,0,32,0,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,9,218,79,184,0,0,32,0,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,206,215,25,39,0,0,32,0,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,83,79,58,117,0,0,32,0,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,225,31,224,89,0,0,32,0,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,243,180,154,166,0,0,32,0,51,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,14,143,73,91,0,0,32,0,51,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,73,144,215,20,0,0,32,0,51,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,35,234,49,150,0,0,32,0,51,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,185,211,168,12,0,0,32,0,51,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,219,173,47,151,0,0,32,0,50,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,234,232,154,71,0,0,32,0,50,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,191,139,89,149,0,0,32,0,50,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,109,0,61,74,0,0,32,0,50,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,203,163,52,170,0,0,32,0,50,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,116,179,58,235,0,0,32,0,50,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,240,191,11,214,0,0,32,0,50,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,71,92,89,217,0,0,32,0,50,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,17,169,25,90,0,0,32,0,50,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,249,96,19,7,0,0,32,0,50,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,151,172,2,198,0,0,32,0,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,106,115,34,141,0,0,32,0,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,34,120,21,15,0,0,32,0,49,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,36,200,72,127,0,0,32,0,49,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,213,155,30,205,0,0,32,0,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,229,216,161,77,0,0,32,0,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,74,127,42,249,0,0,64,0,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,57,11,58,26,0,0,64,0,99,115,99,106,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,162,218,77,236,1,0,16,1,99,115,99,106,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,187,50,198,96,1,0,16,1,99,115,99,106,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,3,32,4,173,1,0,16,1,99,115,99,106,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,64,77,158,22,1,0,16,1,99,115,99,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,170,92,176,1,1,0,16,1,99,115,99,46,55,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,195,7,95,51,7,0,32,0,99,115,99,46,55,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,87,83,33,171,7,0,32,0,99,115,99,46,55,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,129,115,54,162,7,0,32,0,99,115,99,46,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,31,172,138,114,7,0,32,0,99,115,99,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,202,184,17,55,7,0,32,0,99,115,99,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,216,6,138,130,7,0,32,0,99,115,99,46,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,105,69,238,134,7,0,32,0,99,115,99,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,127,87,79,194,7,0,32,0,99,115,99,46,56,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,42,209,80,7,7,0,32,0,99,115,99,46,56,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,57,47,169,144,7,0,32,0,99,115,99,46,56,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,18,176,138,208,7,0,32,0,99,115,99,46,56,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,131,37,101,65,7,0,32,0,99,115,99,46,57,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,247,199,86,167,7,0,32,0,99,115,99,46,57,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,115,204,124,251,7,0,32,0,99,115,99,46,57,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,151,66,1,77,7,0,32,0,99,115,99,46,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,239,177,84,103,7,0,32,0,99,115,99,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,17,33,22,238,10,0,16,1,99,115,99,46,53,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,213,175,82,90,12,0,64,0,99,115,99,46,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,17,168,8,20,12,0,64,0,99,115,99,46,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,124,245,185,79,12,0,64,0,99,115,99,46,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,64,143,154,12,0,64,0,99,115,99,46,53,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,145,154,82,145,12,0,64,0,99,115,99,46,53,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,52,83,52,154,12,0,64,0,99,115,99,46,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,242,39,220,174,12,0,64,0,99,115,99,46,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,179,183,0,35,12,0,64,0,168,86,7,0,1,0,0,0,212,47,216,0,248,191,2,0,24,38,7,0,1,0,0,0,208,47,216,0,184,160,2,0,56,210,6,0,1,0,0,0,35,48,216,0,192,135,2,0,24,163,6,0,1,0,0,0,34,48,216,0,240,108,2,0,152,122,6,0,1,0,0,0,33,48,216,0,96,82,2,0,192,72,6,0,1,0,0,0,32,48,216,0,32,56,2,0,200,110,3,0,1,0,0,0,36,48,216,0,152,30,2,0,120,89,3,0,1,0,0,0,37,48,216,0,232,10,2,0,120,74,3,0,1,0,0,0,38,48,216,0,152,138,8,0,40,246,1,0,1,0,0,0,213,47,216,0,64,246,1,0,144,236,1,0,1,0,0,0,209,47,216,0,136,224,1,0,176,223,1,0,1,0,0,0,43,48,216,0,72,198,1,0,192,209,1,0,1,0,0,0,42,48,216,0,24,182,1,0,24,198,1,0,1,0,0,0,41,48,216,0,40,167,1,0,120,189,1,0,1,0,0,0,40,48,216,0,200,149,1,0,224,22,1,0,1,0,0,0,44,48,216,0,56,126,1,0,160,14,1,0,1,0,0,0,45,48,216,0,32,101,1,0,176,9,1,0,1,0,0,0,46,48,216,0,96,32,8,0,88,212,3,0,1,0,0,0,144,46,216,0,40,185,3,0,240,152,1,0,1,0,0,0,201,47,216,0,216,70,1,0,16,17,8,0,1,0,0,0,202,47,216,0,224,12,8,0,136,67,2,0,1,0,0,0,176,48,216,0,48,119,7,0,8,66,2,0,1,0,0,0,184,48,216,0,112,109,7,0,99,115,99,101,95,100,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,230,198,237,90,1,0,16,1,99,115,99,101,95,100,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,37,170,217,163,1,0,16,1,99,115,99,101,95,100,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,209,201,21,9,1,0,16,1,99,115,99,101,95,100,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,153,125,199,9,1,0,16,1,99,115,99,95,100,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,37,142,71,119,1,0,16,1,99,115,99,46,55,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,195,7,95,51,7,0,32,0,99,115,99,46,55,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,87,83,33,171,7,0,32,0,99,115,99,46,55,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,129,115,54,162,7,0,32,0,99,115,99,46,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,31,172,138,114,7,0,32,0,99,115,99,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,202,184,17,55,7,0,32,0,99,115,99,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,216,6,138,130,7,0,32,0,99,115,99,46,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,105,69,238,134,7,0,32,0,99,115,99,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,127,87,79,194,7,0,32,0,99,115,99,46,56,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,42,209,80,7,7,0,32,0,99,115,99,46,56,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,57,47,169,144,7,0,32,0,99,115,99,46,56,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,18,176,138,208,7,0,32,0,99,115,99,46,56,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,131,37,101,65,7,0,32,0,99,115,99,46,57,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,247,199,86,167,7,0,32,0,99,115,99,46,57,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,115,204,124,251,7,0,32,0,99,115,99,46,57,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,151,66,1,77,7,0,32,0,99,115,99,46,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,239,177,84,103,7,0,32,0,99,115,99,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,17,33,22,238,10,0,16,1,99,115,99,46,53,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,213,175,82,90,12,0,64,0,99,115,99,46,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,17,168,8,20,12,0,64,0,99,115,99,46,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,124,245,185,79,12,0,64,0,99,115,99,46,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,64,143,154,12,0,64,0,99,115,99,46,53,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,145,154,82,145,12,0,64,0,99,115,99,46,53,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,52,83,52,154,12,0,64,0,99,115,99,46,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,242,39,220,174,12,0,64,0,99,115,99,46,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,179,183,0,35,12,0,64,0,30,0,0,0,255,255,255,0,0,0,0,0,31,0,0,0,255,255,255,0,0,0,0,0,32,0,0,0,255,255,255,0,0,0,0,0,33,0,0,0,255,255,1,0,0,0,0,0,0,0,0,0,254,0,2,0,168,234,7,0,30,0,0,0,1,2,0,0,96,135,7,0,30,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,2,0,16,227,4,0,30,0,0,0,1,4,4,0,96,135,7,0,30,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,30,0,0,0,1,8,8,0,96,135,7,0,30,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,30,0,0,0,1,192,128,0,80,246,3,0,30,0,0,0,1,192,192,0,248,38,7,0,30,0,0,0,1,192,64,0,112,212,3,0,30,0,0,0,1,192,0,0,248,160,5,0,0,0,0,0,254,0,2,0,72,209,1,0,31,0,0,0,1,1,1,0,176,111,1,0,31,0,0,0,1,1,0,0,232,78,1,0,0,0,0,0,254,0,8,0,32,4,2,0,31,0,0,0,2,14,10,0,16,242,7,0,31,0,0,0,0,1,0,0,0,0,0,0,31,0,0,0,2,14,12,0,104,236,7,0,31,0,0,0,0,1,0,0,0,0,0,0,31,0,0,0,2,14,14,0,128,230,7,0,31,0,0,0,0,1,0,0,0,0,0,0,31,0,0,0,2,14,8,0,184,164,6,0,31,0,0,0,0,1,0,0,0,0,0,0,31,0,0,0,2,14,6,0,80,74,6,0,31,0,0,0,0,1,0,0,0,0,0,0,31,0,0,0,2,14,4,0,192,32,6,0,31,0,0,0,0,1,0,0,0,0,0,0,31,0,0,0,2,14,2,0,192,234,2,0,31,0,0,0,0,1,0,0,0,0,0,0,31,0,0,0,2,14,0,0,32,242,5,0,31,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,254,0,8,0,200,87,7,0,31,0,0,0,2,14,10,0,16,242,7,0,31,0,0,0,0,1,1,0,0,0,0,0,31,0,0,0,2,14,12,0,104,236,7,0,31,0,0,0,0,1,1,0,0,0,0,0,31,0,0,0,2,14,14,0,128,230,7,0,31,0,0,0,0,1,1,0,0,0,0,0,31,0,0,0,2,14,8,0,184,164,6,0,31,0,0,0,0,1,1,0,0,0,0,0,31,0,0,0,2,14,6,0,80,74,6,0,31,0,0,0,0,1,1,0,0,0,0,0,31,0,0,0,2,14,4,0,192,32,6,0,31,0,0,0,0,1,1,0,0,0,0,0,31,0,0,0,2,14,2,0,192,234,2,0,31,0,0,0,0,1,1,0,0,0,0,0,31,0,0,0,2,14,0,0,32,242,5,0,31,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,254,0,8,0,160,123,6,0,31,0,0,0,2,112,80,0,16,242,7,0,31,0,0,0,0,1,1,0,0,0,0,0,31,0,0,0,2,112,96,0,104,236,7,0,31,0,0,0,0,1,1,0,0,0,0,0,31,0,0,0,2,112,112,0,128,230,7,0,31,0,0,0,0,1,1,0,0,0,0,0,31,0,0,0,2,112,64,0,184,164,6,0,31,0,0,0,0,1,1,0,0,0,0,0,31,0,0,0,2,112,48,0,80,74,6,0,31,0,0,0,0,1,1,0,0,0,0,0,31,0,0,0,2,112,32,0,192,32,6,0,31,0,0,0,0,1,1,0,0,0,0,0,31,0,0,0,2,112,16,0,192,234,2,0,31,0,0,0,0,1,1,0,0,0,0,0,31,0,0,0,2,112,0,0,32,242,5,0,31,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,254,0,2,0,24,172,6,0,31,0,0,0,1,128,128,0,96,135,7,0,31,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,80,165,4,0,32,0,0,0,1,128,0,0,56,111,3,0,32,0,0,0,1,128,128,0,104,134,3,0,0,0,0,0,254,0,5,0,224,133,4,0,33,0,0,0,1,15,1,0,224,32,1,0,33,0,0,0,1,15,8,0,32,27,4,0,33,0,0,0,1,15,0,0,176,20,3,0,33,0,0,0,1,15,2,0,56,50,1,0,33,0,0,0,1,15,4,0,80,190,3,0,17,0,0,0,255,255,126,0,0,0,0,0,18,0,0,0,255,255,247,0,0,0,0,0,0,0,0,0,254,0,4,0,32,4,2,0,17,0,0,0,1,3,0,0,16,242,7,0,17,0,0,0,1,3,1,0,104,236,7,0,17,0,0,0,1,3,2,0,80,245,6,0,17,0,0,0,1,3,3,0,8,201,6,0,0,0,0,0,254,0,2,0,56,134,6,0,17,0,0,0,1,32,0,0,192,255,2,0,17,0,0,0,1,32,32,0,208,75,4,0,0,0,0,0,254,0,4,0,88,0,6,0,17,0,0,0,1,192,192,0,192,255,2,0,17,0,0,0,1,192,128,0,208,75,4,0,17,0,0,0,1,192,64,0,8,49,4,0,17,0,0,0,1,192,0,0,152,21,4,0,0,0,0,0,254,0,4,0,152,135,5,0,18,0,0,0,1,24,24,0,8,49,4,0,18,0,0,0,1,24,16,0,152,21,4,0,18,0,0,0,1,24,8,0,72,246,3,0,18,0,0,0,1,24,0,0,72,0,3,0,0,0,0,0,254,0,2,0,232,75,4,0,18,0,0,0,1,64,64,0,96,135,7,0,18,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,21,0,0,0,255,255,255,0,0,0,0,0,22,0,0,0,255,255,95,0,0,0,0,0,23,0,0,0,255,255,251,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,21,0,0,0,1,15,2,0,80,252,6,0,21,0,0,0,1,15,5,0,16,242,7,0,21,0,0,0,1,15,8,0,104,236,7,0,21,0,0,0,1,15,4,0,120,113,6,0,21,0,0,0,1,15,1,0,232,228,5,0,21,0,0,0,1,15,15,0,128,230,7,0,21,0,0,0,1,15,3,0,56,141,7,0,21,0,0,0,1,15,7,0,120,211,6,0,21,0,0,0,1,15,14,0,184,164,6,0,21,0,0,0,1,15,6,0,24,1,7,0,21,0,0,0,1,15,13,0,80,74,6,0,21,0,0,0,1,15,12,0,192,32,6,0,21,0,0,0,1,15,11,0,192,234,2,0,21,0,0,0,1,15,10,0,32,242,5,0,21,0,0,0,1,15,9,0,176,192,2,0,21,0,0,0,1,15,0,0,16,227,4,0,0,0,0,0,254,0,16,0,160,123,6,0,21,0,0,0,1,240,32,0,80,252,6,0,21,0,0,0,1,240,80,0,16,242,7,0,21,0,0,0,1,240,128,0,104,236,7,0,21,0,0,0,1,240,64,0,120,113,6,0,21,0,0,0,1,240,16,0,232,228,5,0,21,0,0,0,1,240,240,0,128,230,7,0,21,0,0,0,1,240,48,0,56,141,7,0,21,0,0,0,1,240,112,0,120,211,6,0,21,0,0,0,1,240,224,0,184,164,6,0,21,0,0,0,1,240,96,0,24,1,7,0,21,0,0,0,1,240,208,0,80,74,6,0,21,0,0,0,1,240,192,0,192,32,6,0,21,0,0,0,1,240,176,0,192,234,2,0,21,0,0,0,1,240,160,0,32,242,5,0,21,0,0,0,1,240,144,0,176,192,2,0,21,0,0,0,1,240,0,0,112,182,5,0,0,0,0,0,254,0,4,0,128,129,4,0,22,0,0,0,1,3,3,0,192,255,2,0,22,0,0,0,1,3,2,0,208,75,4,0,22,0,0,0,1,3,1,0,8,49,4,0,22,0,0,0,1,3,0,0,152,21,4,0,0,0,0,0,254,0,4,0,72,202,5,0,22,0,0,0,1,96,96,0,80,246,3,0,22,0,0,0,1,96,64,0,248,38,7,0,22,0,0,0,1,96,32,0,48,123,8,0,22,0,0,0,1,96,0,0,8,117,8,0,0,0,0,0,254,0,2,0,168,234,7,0,22,0,0,0,1,128,128,0,96,135,7,0,22,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,23,0,0,0,1,4,0,0,96,135,7,0,23,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,33,0,0,0,255,255,255,0,0,0,0,0,34,0,0,0,255,255,95,0,0,0,0,0,35,0,0,0,255,255,251,0,0,0,0,0,0,0,0,0,254,0,16,0,32,4,2,0,33,0,0,0,1,15,2,0,80,252,6,0,33,0,0,0,1,15,5,0,16,242,7,0,33,0,0,0,1,15,8,0,104,236,7,0,33,0,0,0,1,15,4,0,120,113,6,0,33,0,0,0,1,15,1,0,232,228,5,0,33,0,0,0,1,15,15,0,128,230,7,0,33,0,0,0,1,15,3,0,56,141,7,0,33,0,0,0,1,15,7,0,120,211,6,0,33,0,0,0,1,15,14,0,184,164,6,0,33,0,0,0,1,15,6,0,24,1,7,0,33,0,0,0,1,15,13,0,80,74,6,0,33,0,0,0,1,15,12,0,192,32,6,0,33,0,0,0,1,15,11,0,192,234,2,0,33,0,0,0,1,15,10,0,32,242,5,0,33,0,0,0,1,15,9,0,176,192,2,0,33,0,0,0,1,15,0,0,176,67,1,0,0,0,0,0,254,0,4,0,72,202,5,0,34,0,0,0,1,96,96,0,80,246,3,0,34,0,0,0,1,96,64,0,248,38,7,0,34,0,0,0,1,96,32,0,48,123,8,0,34,0,0,0,1,96,0,0,232,199,8,0,0,0,0,0,254,0,2,0,168,234,7,0,34,0,0,0,1,128,128,0,96,135,7,0,34,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,35,0,0,0,1,4,0,0,96,135,7,0,35,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,9,0,0,0,255,255,63,0,0,0,0,0,10,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,8,0,200,87,7,0,9,0,0,0,1,7,0,0,32,136,7,0,9,0,0,0,1,7,1,0,40,88,7,0,9,0,0,0,1,7,2,0,96,39,7,0,9,0,0,0,1,7,7,0,144,251,6,0,9,0,0,0,1,7,6,0,184,164,6,0,9,0,0,0,1,7,5,0,80,74,6,0,9,0,0,0,1,7,4,0,192,32,6,0,9,0,0,0,1,7,3,0,192,234,2,0,0,0,0,0,254,0,8,0,160,123,6,0,9,0,0,0,1,56,0,0,32,136,7,0,9,0,0,0,1,56,8,0,40,88,7,0,9,0,0,0,1,56,16,0,96,39,7,0,9,0,0,0,1,56,56,0,144,251,6,0,9,0,0,0,1,56,48,0,184,164,6,0,9,0,0,0,1,56,40,0,80,74,6,0,9,0,0,0,1,56,32,0,192,32,6,0,9,0,0,0,1,56,24,0,192,234,2,0,0,0,0,0,254,0,4,0,128,184,7,0,9,0,0,0,1,192,192,0,72,246,3,0,9,0,0,0,1,192,128,0,208,7,8,0,9,0,0,0,1,192,64,0,216,202,4,0,9,0,0,0,1,192,0,0,248,168,7,0,0,0,0,0,254,0,2,0,232,75,4,0,10,0,0,0,1,1,1,0,96,135,7,0,10,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,4,0,8,99,2,0,10,0,0,0,1,12,12,0,24,205,7,0,10,0,0,0,1,12,8,0,192,255,2,0,10,0,0,0,1,12,4,0,208,75,4,0,10,0,0,0,1,12,0,0,8,49,4,0,0,0,0,0,254,0,4,0,104,115,3,0,10,0,0,0,1,48,16,0,152,195,2,0,10,0,0,0,1,48,32,0,104,178,2,0,10,0,0,0,1,48,48,0,176,173,4,0,10,0,0,0,1,48,0,0,80,167,5,0,0,0,0,0,254,0,4,0,16,165,4,0,10,0,0,0,1,192,192,0,24,205,7,0,10,0,0,0,1,192,128,0,192,255,2,0,10,0,0,0,1,192,64,0,208,75,4,0,10,0,0,0,1,192,0,0,8,49,4,0,0,0,0,0,102,114,111,103,51,48,45,51,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,190,221,184,142,1,0,16,1,102,114,111,103,51,53,45,52,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,136,169,181,172,1,0,16,1,102,114,111,103,51,49,45,51,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,204,3,72,21,1,0,16,1,102,114,111,103,51,54,45,52,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,204,3,72,21,1,0,16,1,102,114,111,103,51,50,45,51,50,109,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,172,10,102,117,2,0,16,1,102,114,111,103,48,53,45,48,53,109,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,84,75,188,123,4,0,32,0,102,114,111,103,48,55,45,48,55,109,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,128,221,234,11,4,0,32,0,102,114,111,103,48,49,45,48,49,109,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,187,2,77,248,4,0,32,0,102,114,111,103,48,51,45,48,51,109,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,176,165,132,215,4,0,32,0,102,114,111,103,48,57,45,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,92,251,199,58,3,0,16,0,102,114,111,103,49,56,45,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,7,239,209,101,5,0,64,0,102,114,111,103,49,57,45,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,205,205,232,126,5,0,64,0,99,100,51,48,45,51,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,214,23,182,94,1,0,16,1,99,100,51,53,45,52,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,98,10,28,31,1,0,16,1,99,100,51,49,45,51,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,205,205,232,126,1,0,16,1,99,100,51,54,45,52,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,205,205,232,126,1,0,16,1,102,102,45,51,50,109,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,110,105,71,199,2,0,16,1,99,100,48,53,45,48,53,109,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,83,97,220,53,4,0,32,0,99,100,48,55,45,48,55,109,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,56,138,240,186,4,0,32,0,99,100,48,49,45,48,49,109,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,144,231,216,58,4,0,32,0,99,100,48,51,45,48,51,109,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,243,134,81,251,4,0,32,0,102,102,95,48,57,46,49,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,181,126,54,184,3,0,16,0,102,102,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,231,102,92,55,5,0,64,0,102,102,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,249,55,241,30,5,0,64,0,101,112,114,45,49,51,56,53,56,97,46,97,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,254,66,111,39,1,0,16,1,101,112,114,45,49,51,56,53,54,97,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,231,181,230,20,1,0,16,1,101,112,114,45,49,51,56,53,57,97,46,97,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,157,239,3,71,1,0,16,1,101,112,114,45,49,51,56,53,55,97,46,97,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,39,229,55,222,1,0,16,1,111,112,114,45,49,51,56,54,50,46,97,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,182,84,115,164,2,0,32,0,111,112,114,45,49,51,56,55,55,46,98,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,181,36,132,211,2,0,32,0,111,112,114,45,49,51,56,54,51,46,97,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,38,0,153,140,2,0,32,0,111,112,114,45,49,51,56,55,56,46,98,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,138,91,193,33,2,0,32,0,111,112,114,45,49,51,56,54,52,46,97,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,191,117,177,210,2,0,32,0,111,112,114,45,49,51,56,55,57,46,98,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,49,37,214,185,2,0,32,0,111,112,114,45,49,51,56,54,53,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,4,244,36,112,3,0,32,0,111,112,114,45,49,51,56,54,57,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,104,52,75,171,3,0,32,0,111,112,114,45,49,51,56,54,54,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,164,187,105,97,3,0,32,0,111,112,114,45,49,51,56,55,48,46,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,195,26,180,105,3,0,32,0,111,112,114,45,49,51,56,54,55,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,45,240,20,176,3,0,32,0,111,112,114,45,49,51,56,55,49,46,98,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,2,207,1,8,3,0,32,0,111,112,114,45,49,51,56,54,56,46,98,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,214,124,42,230,3,0,32,0,111,112,114,45,49,51,56,55,50,46,98,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,21,243,102,240,3,0,32,0,111,112,114,45,49,51,56,53,50,46,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,139,186,58,148,3,0,32,0,111,112,114,45,49,51,56,55,51,46,98,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,243,69,209,27,3,0,32,0,111,112,114,45,49,51,56,53,51,46,97,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,50,169,126,3,0,32,0,111,112,114,45,49,51,56,55,52,46,98,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,255,155,213,79,3,0,32,0,111,112,114,45,49,51,56,53,52,46,97,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,144,33,148,28,3,0,32,0,111,112,114,45,49,51,56,55,53,46,98,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,141,134,102,106,3,0,32,0,111,112,114,45,49,51,56,53,53,46,97,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,226,62,111,133,3,0,32,0,111,112,114,45,49,51,56,55,54,46,98,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,216,250,95,28,3,0,32,0,101,112,114,45,49,51,56,54,48,46,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,39,176,87,106,4,0,16,1,111,112,114,45,49,51,48,54,49,46,97,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,21,33,77,8,0,64,0,51,49,55,45,48,49,55,57,97,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,211,150,128,72,5,0,16,1,117,53,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,147,72,19,101,0,0,16,1,117,55,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,53,132,171,196,0,0,16,1,117,55,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,200,217,228,203,0,0,32,0,117,55,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,87,123,225,27,0,0,32,0,117,55,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,13,96,35,120,0,0,32,0,117,51,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,152,42,253,93,0,0,64,0,117,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,136,146,191,229,0,0,64,0,56,55,99,53,50,46,109,99,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,16,112,114,111,116,100,97,116,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,168,185,25,200,0,0,16,1,19,0,0,0,255,255,238,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,40,111,8,0,19,0,0,0,1,1,1,0,96,135,7,0,19,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,8,0,232,24,7,0,19,0,0,0,1,14,0,0,232,151,6,0,19,0,0,0,1,14,2,0,168,241,6,0,19,0,0,0,1,14,4,0,224,19,7,0,19,0,0,0,1,14,6,0,64,15,7,0,19,0,0,0,1,14,14,0,224,9,7,0,19,0,0,0,1,14,10,0,88,239,6,0,19,0,0,0,1,14,12,0,144,3,7,0,19,0,0,0,1,14,8,0,224,166,6,0,0,0,0,0,254,0,8,0,72,202,5,0,19,0,0,0,1,112,32,0,160,113,6,0,19,0,0,0,1,112,16,0,176,110,6,0,19,0,0,0,1,112,0,0,160,105,6,0,19,0,0,0,1,112,112,0,184,100,6,0,19,0,0,0,1,112,96,0,8,96,6,0,19,0,0,0,1,112,80,0,112,90,6,0,19,0,0,0,1,112,64,0,224,82,6,0,19,0,0,0,1,112,48,0,128,76,6,0,0,0,0,0,254,0,2,0,128,156,8,0,19,0,0,0,1,128,128,0,32,182,8,0,19,0,0,0,1,128,0,0,80,251,6,0,0,0,0,0,254,0,2,0,16,227,4,0,20,0,0,0,1,128,128,0,96,135,7,0,20,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,99,111,111,107,98,105,98,50,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,96,148,144,178,0,0,16,1,99,111,111,107,98,105,98,50,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,226,253,170,101,0,0,16,1,99,111,111,107,98,105,98,50,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,206,56,251,137,0,0,32,0,99,111,111,107,98,105,98,50,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,31,17,64,242,0,0,32,0,99,111,111,107,98,105,98,50,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,33,72,96,225,0,0,32,0,99,111,111,107,98,105,98,50,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,154,28,159,245,0,0,64,0,99,111,111,107,98,105,98,50,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,184,118,111,94,0,0,64,0,56,55,99,53,50,46,109,99,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,16,112,114,111,116,100,97,116,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,213,142,109,174,0,0,16,1,19,0,0,0,255,255,252,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,40,111,8,0,19,0,0,0,1,1,1,0,96,135,7,0,19,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,184,70,6,0,19,0,0,0,1,2,2,0,8,49,4,0,19,0,0,0,1,2,0,0,192,255,2,0,0,0,0,0,254,0,8,0,232,24,7,0,19,0,0,0,1,28,0,0,232,151,6,0,19,0,0,0,1,28,4,0,168,241,6,0,19,0,0,0,1,28,8,0,224,19,7,0,19,0,0,0,1,28,12,0,64,15,7,0,19,0,0,0,1,28,28,0,224,9,7,0,19,0,0,0,1,28,20,0,88,239,6,0,19,0,0,0,1,28,24,0,144,3,7,0,19,0,0,0,1,28,16,0,224,166,6,0,0,0,0,0,254,0,4,0,72,202,5,0,19,0,0,0,1,96,0,0,80,246,3,0,19,0,0,0,1,96,96,0,248,38,7,0,19,0,0,0,1,96,64,0,112,212,3,0,19,0,0,0,1,96,32,0,24,99,5,0,0,0,0,0,254,0,2,0,128,156,8,0,19,0,0,0,1,128,128,0,32,182,8,0,19,0,0,0,1,128,0,0,80,251,6,0,0,0,0,0,98,51,51,45,119,119,46,105,99,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,66,46,201,245,2,0,16,1,98,51,51,45,120,120,46,105,99,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,250,209,193,231,2,0,16,1,98,51,51,45,121,121,46,105,99,51,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,45,47,82,22,6,0,16,1,99,99,95,51,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,165,46,115,161,6,0,16,1,98,51,51,45,51,48,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,52,98,116,216,9,0,16,1,98,51,51,45,48,50,46,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,162,59,251,246,11,0,32,0,98,51,51,45,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,153,5,180,44,17,0,32,0,98,51,51,45,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,234,158,223,189,17,0,32,0,98,51,51,45,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,162,102,248,141,17,0,32,0,98,51,51,45,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,217,54,108,79,17,0,32,0,98,51,51,45,48,49,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,232,43,31,241,22,0,32,0,98,51,51,45,48,55,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,31,30,21,23,0,32,0,98,51,51,45,48,57,46,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,36,103,30,24,0,64,0,98,51,51,45,49,48,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,171,3,206,233,24,0,64,0,98,51,51,45,48,56,46,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,200,196,161,202,25,0,64,0,98,49,52,45,51,48,46,57,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,127,12,203,220,0,0,0,8,98,49,52,45,51,49,46,53,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,61,1,107,92,0,0,0,8,98,51,51,45,49,55,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,244,143,125,123,0,0,0,8,98,51,51,45,49,56,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,48,31,248,251,0,0,0,8,14,0,0,0,255,255,255,0,0,0,0,0,15,0,0,0,255,255,223,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,14,0,0,0,1,1,1,0,120,97,1,0,14,0,0,0,1,1,0,0,80,46,8,0,0,0,0,0,254,0,2,0,232,75,4,0,14,0,0,0,1,4,4,0,96,135,7,0,14,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,14,0,0,0,1,8,0,0,96,135,7,0,14,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,14,0,0,0,1,48,0,0,80,252,6,0,14,0,0,0,1,48,16,0,16,242,7,0,14,0,0,0,1,48,32,0,104,236,7,0,14,0,0,0,1,48,48,0,128,230,7,0,0,0,0,0,254,0,4,0,160,123,6,0,14,0,0,0,1,192,192,0,8,201,6,0,14,0,0,0,1,192,128,0,200,197,6,0,14,0,0,0,1,192,64,0,152,194,6,0,14,0,0,0,1,192,0,0,248,189,6,0,0,0,0,0,254,0,4,0,248,150,6,0,15,0,0,0,1,3,2,0,80,246,3,0,15,0,0,0,1,3,3,0,248,38,7,0,15,0,0,0,1,3,1,0,112,212,3,0,15,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,200,147,6,0,15,0,0,0,1,12,8,0,80,246,3,0,15,0,0,0,1,12,12,0,248,38,7,0,15,0,0,0,1,12,4,0,112,212,3,0,15,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,2,0,56,107,4,0,15,0,0,0,1,16,16,0,64,96,7,0,15,0,0,0,1,16,0,0,192,89,7,0,0,0,0,0,254,0,2,0,0,241,6,0,15,0,0,0,1,32,0,0,96,135,7,0,15,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,168,86,7,0,1,0,0,0,92,238,146,0,248,191,2,0,24,38,7,0,1,0,0,0,199,251,146,0,184,160,2,0,56,210,6,0,1,0,0,0,194,251,146,0,192,135,2,0,24,163,6,0,1,0,0,0,195,251,146,0,240,108,2,0,152,122,6,0,1,0,0,0,192,251,146,0,96,82,2,0,192,72,6,0,1,0,0,0,193,251,146,0,32,56,2,0,200,110,3,0,1,0,0,0,196,251,146,0,152,30,2,0,120,89,3,0,1,0,0,0,197,251,146,0,232,10,2,0,40,246,1,0,1,0,0,0,93,238,146,0,64,246,1,0,144,236,1,0,1,0,0,0,143,243,146,0,136,224,1,0,176,223,1,0,1,0,0,0,138,243,146,0,72,198,1,0,192,209,1,0,1,0,0,0,139,243,146,0,24,182,1,0,24,198,1,0,1,0,0,0,136,243,146,0,40,167,1,0,120,189,1,0,1,0,0,0,137,243,146,0,200,149,1,0,224,22,1,0,1,0,0,0,140,243,146,0,56,126,1,0,160,14,1,0,1,0,0,0,141,243,146,0,32,101,1,0,88,212,3,0,1,0,0,0,120,216,146,0,40,185,3,0,16,17,8,0,1,0,0,0,88,238,146,0,224,12,8,0,56,58,1,0,1,0,0,0,89,238,146,0,64,50,1,0,72,65,1,0,9,0,0,0,216,3,147,0,32,58,1,0,48,50,1,0,9,0,0,0,217,3,147,0,32,58,1,0,168,86,7,0,1,0,0,0,122,151,215,0,248,191,2,0,24,38,7,0,1,0,0,0,126,151,215,0,184,160,2,0,56,210,6,0,1,0,0,0,136,151,215,0,192,135,2,0,24,163,6,0,1,0,0,0,137,151,215,0,240,108,2,0,152,122,6,0,1,0,0,0,138,151,215,0,96,82,2,0,192,72,6,0,1,0,0,0,139,151,215,0,32,56,2,0,200,110,3,0,1,0,0,0,140,151,215,0,152,30,2,0,120,89,3,0,1,0,0,0,141,151,215,0,232,10,2,0,40,246,1,0,1,0,0,0,123,151,215,0,64,246,1,0,144,236,1,0,1,0,0,0,127,151,215,0,136,224,1,0,176,223,1,0,1,0,0,0,128,151,215,0,72,198,1,0,192,209,1,0,1,0,0,0,129,151,215,0,24,182,1,0,24,198,1,0,1,0,0,0,130,151,215,0,40,167,1,0,120,189,1,0,1,0,0,0,131,151,215,0,200,149,1,0,224,22,1,0,1,0,0,0,132,151,215,0,56,126,1,0,160,14,1,0,1,0,0,0,133,151,215,0,32,101,1,0,88,212,3,0,1,0,0,0,200,147,215,0,40,185,3,0,16,17,8,0,1,0,0,0,121,151,215,0,224,12,8,0,56,58,1,0,1,0,0,0,120,151,215,0,64,50,1,0,72,65,1,0,9,0,0,0,152,151,215,0,32,58,1,0,48,50,1,0,9,0,0,0,153,151,215,0,32,58,1,0,168,86,7,0,1,0,0,0,96,253,146,0,248,191,2,0,24,38,7,0,1,0,0,0,99,253,146,0,184,160,2,0,56,210,6,0,1,0,0,0,19,245,146,0,192,135,2,0,24,163,6,0,1,0,0,0,18,245,146,0,240,108,2,0,152,122,6,0,1,0,0,0,17,245,146,0,96,82,2,0,192,72,6,0,1,0,0,0,16,245,146,0,32,56,2,0,200,110,3,0,1,0,0,0,20,245,146,0,152,30,2,0,120,89,3,0,1,0,0,0,21,245,146,0,232,10,2,0,40,246,1,0,1,0,0,0,97,253,146,0,64,246,1,0,144,236,1,0,1,0,0,0,100,253,146,0,136,224,1,0,176,223,1,0,1,0,0,0,27,245,146,0,72,198,1,0,192,209,1,0,1,0,0,0,26,245,146,0,24,182,1,0,24,198,1,0,1,0,0,0,25,245,146,0,40,167,1,0,120,189,1,0,1,0,0,0,24,245,146,0,200,149,1,0,224,22,1,0,1,0,0,0,28,245,146,0,56,126,1,0,160,14,1,0,1,0,0,0,29,245,146,0,32,101,1,0,88,212,3,0,1,0,0,0,152,217,146,0,40,185,3,0,16,17,8,0,1,0,0,0,98,253,146,0,224,12,8,0,72,65,1,0,9,0,0,0,144,4,147,0,32,58,1,0,48,50,1,0,9,0,0,0,145,4,147,0,32,58,1,0,168,86,7,0,1,0,0,0,194,241,146,0,248,191,2,0,24,38,7,0,1,0,0,0,192,241,146,0,184,160,2,0,56,210,6,0,1,0,0,0,171,2,147,0,192,135,2,0,24,163,6,0,1,0,0,0,170,2,147,0,240,108,2,0,152,122,6,0,1,0,0,0,169,2,147,0,96,82,2,0,192,72,6,0,1,0,0,0,168,2,147,0,32,56,2,0,200,110,3,0,1,0,0,0,175,2,147,0,152,30,2,0,120,89,3,0,1,0,0,0,174,2,147,0,232,10,2,0,120,74,3,0,1,0,0,0,173,2,147,0,152,138,8,0,192,61,3,0,1,0,0,0,172,2,147,0,48,119,7,0,40,246,1,0,1,0,0,0,195,241,146,0,64,246,1,0,144,236,1,0,1,0,0,0,193,241,146,0,136,224,1,0,176,223,1,0,1,0,0,0,235,249,146,0,72,198,1,0,192,209,1,0,1,0,0,0,234,249,146,0,24,182,1,0,24,198,1,0,1,0,0,0,233,249,146,0,40,167,1,0,120,189,1,0,1,0,0,0,232,249,146,0,200,149,1,0,224,22,1,0,1,0,0,0,239,249,146,0,56,126,1,0,160,14,1,0,1,0,0,0,238,249,146,0,32,101,1,0,176,9,1,0,1,0,0,0,237,249,146,0,96,32,8,0,200,3,1,0,1,0,0,0,236,249,146,0,16,68,7,0,88,212,3,0,1,0,0,0,32,222,146,0,40,185,3,0,16,17,8,0,1,0,0,0,196,241,146,0,224,12,8,0,72,65,1,0,9,0,0,0,168,7,147,0,32,58,1,0,48,50,1,0,9,0,0,0,169,7,147,0,32,58,1,0,17,0,0,0,255,255,127,0,0,0,0,0,18,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,200,87,7,0,17,0,0,0,1,3,0,0,88,154,8,0,17,0,0,0,1,3,1,0,200,92,8,0,17,0,0,0,1,3,3,0,56,37,8,0,17,0,0,0,1,3,2,0,96,240,7,0,0,0,0,0,254,0,4,0,160,123,6,0,17,0,0,0,1,12,0,0,88,154,8,0,17,0,0,0,1,12,4,0,200,92,8,0,17,0,0,0,1,12,12,0,56,37,8,0,17,0,0,0,1,12,8,0,96,240,7,0,0,0,0,0,254,0,2,0,168,234,7,0,17,0,0,0,1,32,0,0,96,135,7,0,17,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,17,0,0,0,1,64,64,0,96,135,7,0,17,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,200,30,2,0,17,0,0,0,1,128,0,0,120,97,1,0,17,0,0,0,1,128,128,0,96,19,1,0,0,0,0,0,254,0,4,0,128,129,4,0,18,0,0,0,1,3,3,0,8,49,4,0,18,0,0,0,1,3,2,0,152,21,4,0,18,0,0,0,1,3,1,0,72,246,3,0,18,0,0,0,1,3,0,0,48,176,2,0,0,0,0,0,254,0,4,0,72,202,5,0,18,0,0,0,1,12,4,0,80,246,3,0,18,0,0,0,1,12,12,0,248,38,7,0,18,0,0,0,1,12,8,0,112,212,3,0,18,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,2,0,104,159,3,0,18,0,0,0,1,16,0,0,56,111,3,0,18,0,0,0,1,16,16,0,104,134,3,0,0,0,0,0,254,0,2,0,64,37,5,0,18,0,0,0,1,32,32,0,184,67,7,0,18,0,0,0,1,32,0,0,48,63,7,0,0,0,0,0,101,112,114,45,49,51,55,57,52,46,97,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,51,2,216,200,1,0,16,1,101,112,114,45,49,51,55,57,53,46,97,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,103,11,182,176,1,0,16,1,101,112,114,45,49,51,55,56,52,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,13,24,200,128,1,0,16,1,101,112,114,45,49,51,55,56,54,46,97,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,192,218,149,48,1,0,16,1,109,112,114,45,49,51,55,55,51,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,229,0,198,63,2,0,32,0,109,112,114,45,49,51,55,55,52,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,36,168,17,36,2,0,32,0,109,112,114,45,49,51,55,55,53,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,123,82,207,2,0,32,0,109,112,114,45,49,51,55,55,57,46,99,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,22,244,7,199,3,0,32,0,109,112,114,45,49,51,55,56,55,46,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,198,104,92,240,3,0,32,0,109,112,114,45,49,51,55,56,48,46,99,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,224,65,195,164,3,0,32,0,109,112,114,45,49,51,55,56,56,46,97,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,166,254,6,1,3,0,32,0,109,112,114,45,49,51,55,56,49,46,99,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,175,19,59,243,3,0,32,0,109,112,114,45,49,51,55,56,57,46,97,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,53,136,186,9,3,0,32,0,101,112,114,45,49,51,55,57,51,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,68,25,211,163,4,0,16,1,101,112,114,45,49,51,55,57,50,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,149,150,143,128,19,0,64,0,101,112,114,45,49,51,55,57,49,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,128,109,193,53,19,0,64,0,51,49,55,45,48,49,55,54,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,48,36,7,155,5,0,16,1,22,0,0,0,255,255,255,0,0,0,0,0,23,0,0,0,255,255,253,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,22,0,0,0,1,15,7,0,80,252,6,0,22,0,0,0,1,15,8,0,16,242,7,0,22,0,0,0,1,15,9,0,104,236,7,0,22,0,0,0,1,15,5,0,176,51,4,0,22,0,0,0,1,15,4,0,56,24,4,0,22,0,0,0,1,15,15,0,128,230,7,0,22,0,0,0,1,15,1,0,72,216,3,0,22,0,0,0,1,15,2,0,24,188,3,0,22,0,0,0,1,15,3,0,176,162,3,0,22,0,0,0,1,15,6,0,120,211,6,0,22,0,0,0,1,15,14,0,184,164,6,0,22,0,0,0,1,15,13,0,80,74,6,0,22,0,0,0,1,15,12,0,192,32,6,0,22,0,0,0,1,15,11,0,192,234,2,0,22,0,0,0,1,15,10,0,32,242,5,0,22,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,22,0,0,0,1,240,112,0,80,252,6,0,22,0,0,0,1,240,128,0,16,242,7,0,22,0,0,0,1,240,144,0,104,236,7,0,22,0,0,0,1,240,80,0,176,51,4,0,22,0,0,0,1,240,64,0,56,24,4,0,22,0,0,0,1,240,240,0,128,230,7,0,22,0,0,0,1,240,16,0,72,216,3,0,22,0,0,0,1,240,32,0,24,188,3,0,22,0,0,0,1,240,48,0,176,162,3,0,22,0,0,0,1,240,96,0,120,211,6,0,22,0,0,0,1,240,224,0,184,164,6,0,22,0,0,0,1,240,208,0,80,74,6,0,22,0,0,0,1,240,192,0,192,32,6,0,22,0,0,0,1,240,176,0,192,234,2,0,22,0,0,0,1,240,160,0,32,242,5,0,22,0,0,0,1,240,0,0,208,236,2,0,0,0,0,0,254,0,2,0,88,131,3,0,23,0,0,0,1,1,1,0,96,135,7,0,23,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,23,0,0,0,1,2,2,0,96,135,7,0,23,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,4,0,64,105,6,0,23,0,0,0,1,12,4,0,88,100,6,0,23,0,0,0,1,12,0,0,176,95,6,0,23,0,0,0,1,12,8,0,200,89,6,0,23,0,0,0,1,12,12,0,40,82,6,0,0,0,0,0,254,0,4,0,224,75,6,0,23,0,0,0,1,48,16,0,88,70,6,0,23,0,0,0,1,48,0,0,168,65,6,0,23,0,0,0,1,48,32,0,136,62,6,0,23,0,0,0,1,48,48,0,160,59,6,0,0,0,0,0,254,0,4,0,72,202,5,0,23,0,0,0,1,192,64,0,160,246,1,0,23,0,0,0,1,192,128,0,80,246,3,0,23,0,0,0,1,192,192,0,248,38,7,0,23,0,0,0,1,192,0,0,112,212,3,0,0,0,0,0,184,40,2,0,1,0,0,0,47,39,216,0,248,191,2,0,56,250,6,0,1,0,0,0,39,39,216,0,184,160,2,0,184,164,8,0,1,0,0,0,46,39,216,0,64,246,1,0,88,149,7,0,1,0,0,0,38,39,216,0,136,224,1,0,240,167,7,0,1,0,0,0,28,39,216,0,192,135,2,0,176,163,7,0,1,0,0,0,30,39,216,0,240,108,2,0,208,158,7,0,1,0,0,0,45,39,216,0,96,82,2,0,184,154,7,0,1,0,0,0,44,39,216,0,32,56,2,0,176,108,2,0,1,0,0,0,43,39,216,0,152,30,2,0,8,96,7,0,1,0,0,0,41,39,216,0,72,198,1,0,48,89,7,0,1,0,0,0,24,39,216,0,24,182,1,0,16,83,7,0,1,0,0,0,37,39,216,0,40,167,1,0,96,79,7,0,1,0,0,0,36,39,216,0,200,149,1,0,48,76,7,0,1,0,0,0,35,39,216,0,56,126,1,0,88,212,3,0,1,0,0,0,48,38,216,0,40,185,3,0,248,5,8,0,9,0,0,0,112,39,216,0,32,58,1,0,144,250,7,0,9,0,0,0,113,39,216,0,32,58,1,0,248,241,7,0,9,0,0,0,114,39,216,0,32,58,1,0,184,40,2,0,1,0,0,0,40,39,216,0,248,191,2,0,56,250,6,0,1,0,0,0,32,39,216,0,184,160,2,0,88,149,7,0,1,0,0,0,33,39,216,0,136,224,1,0,240,167,7,0,1,0,0,0,44,39,216,0,192,135,2,0,176,163,7,0,1,0,0,0,45,39,216,0,240,108,2,0,208,158,7,0,1,0,0,0,42,39,216,0,96,82,2,0,184,154,7,0,1,0,0,0,43,39,216,0,32,56,2,0,176,108,2,0,1,0,0,0,47,39,216,0,152,30,2,0,128,98,2,0,1,0,0,0,46,39,216,0,232,10,2,0,8,96,7,0,1,0,0,0,41,39,216,0,72,198,1,0,48,89,7,0,1,0,0,0,37,39,216,0,24,182,1,0,16,83,7,0,1,0,0,0,34,39,216,0,40,167,1,0,96,79,7,0,1,0,0,0,35,39,216,0,200,149,1,0,48,76,7,0,1,0,0,0,36,39,216,0,56,126,1,0,88,212,3,0,1,0,0,0,48,38,216,0,40,185,3,0,248,5,8,0,9,0,0,0,112,39,216,0,32,58,1,0,144,250,7,0,9,0,0,0,113,39,216,0,32,58,1,0,248,241,7,0,9,0,0,0,114,39,216,0,32,58,1,0,19,0,0,0,255,255,254,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,19,0,0,0,1,1,0,0,120,97,1,0,19,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,2,2,0,96,135,7,0,19,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,4,4,0,96,135,7,0,19,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,8,0,0,96,135,7,0,19,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,19,0,0,0,1,48,16,0,96,39,7,0,19,0,0,0,1,48,48,0,144,251,6,0,19,0,0,0,1,48,0,0,120,211,6,0,19,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,19,0,0,0,1,192,64,0,96,39,7,0,19,0,0,0,1,192,192,0,144,251,6,0,19,0,0,0,1,192,0,0,120,211,6,0,19,0,0,0,1,192,128,0,184,164,6,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,3,2,0,80,246,3,0,20,0,0,0,1,3,3,0,80,124,6,0,20,0,0,0,1,3,1,0,112,212,3,0,20,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,64,37,5,0,20,0,0,0,1,12,8,0,48,155,7,0,20,0,0,0,1,12,0,0,120,149,7,0,20,0,0,0,1,12,12,0,240,70,8,0,20,0,0,0,1,12,4,0,80,68,8,0,0,0,0,0,254,0,0,0,128,129,4,0,20,0,0,0,1,48,32,0,208,75,4,0,20,0,0,0,1,48,48,0,8,49,4,0,20,0,0,0,1,48,16,0,152,21,4,0,20,0,0,0,1,48,0,0,72,246,3,0,0,0,0,0,19,0,0,0,255,255,254,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,19,0,0,0,1,1,0,0,120,97,1,0,19,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,2,2,0,96,135,7,0,19,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,4,4,0,96,135,7,0,19,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,8,0,0,96,135,7,0,19,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,19,0,0,0,1,48,0,0,32,136,7,0,19,0,0,0,1,48,16,0,40,88,7,0,19,0,0,0,1,48,32,0,96,39,7,0,19,0,0,0,1,48,48,0,144,251,6,0,0,0,0,0,254,0,4,0,160,123,6,0,19,0,0,0,1,192,192,0,184,164,6,0,19,0,0,0,1,192,128,0,80,74,6,0,19,0,0,0,1,192,64,0,192,32,6,0,19,0,0,0,1,192,0,0,32,242,5,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,3,2,0,80,246,3,0,20,0,0,0,1,3,3,0,80,124,6,0,20,0,0,0,1,3,1,0,112,212,3,0,20,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,64,37,5,0,20,0,0,0,1,12,8,0,48,155,7,0,20,0,0,0,1,12,0,0,120,149,7,0,20,0,0,0,1,12,12,0,240,70,8,0,20,0,0,0,1,12,4,0,80,68,8,0,0,0,0,0,254,0,0,0,128,129,4,0,20,0,0,0,1,48,32,0,208,75,4,0,20,0,0,0,1,48,48,0,8,49,4,0,20,0,0,0,1,48,16,0,152,21,4,0,20,0,0,0,1,48,0,0,72,246,3,0,0,0,0,0,117,98,49,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,202,69,219,236,0,0,16,1,117,98,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,42,133,131,177,0,0,16,1,117,98,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,29,23,194,48,0,0,16,1,112,114,111,116,100,97,116,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,52,152,211,11,0,0,16,1,115,114,111,109,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,184,8,102,131,0,0,32,0,115,114,111,109,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,93,113,213,49,0,0,32,0,117,111,114,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,42,100,214,222,0,0,32,0,117,111,114,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,22,149,63,73,0,0,32,0,117,111,114,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,18,62,220,226,0,0,32,0,117,111,114,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,48,117,55,111,0,0,32,0,117,99,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,189,122,245,243,0,0,64,0,56,55,99,53,50,46,109,99,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,16,17,0,0,0,255,255,255,0,0,0,0,0,18,0,0,0,255,255,127,0,0,0,0,0,0,0,0,0,254,0,2,0,232,19,7,0,17,0,0,0,1,1,0,0,208,75,4,0,17,0,0,0,1,1,1,0,8,49,4,0,0,0,0,0,254,0,2,0,112,59,6,0,17,0,0,0,1,32,32,0,208,6,8,0,17,0,0,0,1,32,0,0,232,9,7,0,0,0,0,0,254,0,4,0,152,3,7,0,17,0,0,0,1,192,0,0,8,49,4,0,17,0,0,0,1,192,192,0,152,21,4,0,17,0,0,0,1,192,64,0,72,246,3,0,17,0,0,0,1,192,128,0,72,0,3,0,0,0,0,0,254,0,2,0,232,75,4,0,18,0,0,0,1,1,1,0,96,135,7,0,18,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,18,0,0,0,1,6,0,0,80,246,3,0,18,0,0,0,1,6,6,0,248,38,7,0,18,0,0,0,1,6,2,0,112,212,3,0,18,0,0,0,1,6,4,0,24,99,5,0,0,0,0,0,254,0,8,0,32,4,2,0,18,0,0,0,1,56,0,0,104,54,4,0,18,0,0,0,1,56,32,0,80,252,6,0,18,0,0,0,1,56,16,0,16,242,7,0,18,0,0,0,1,56,48,0,104,236,7,0,18,0,0,0,1,56,56,0,128,230,7,0,18,0,0,0,1,56,40,0,120,211,6,0,18,0,0,0,1,56,24,0,184,164,6,0,18,0,0,0,1,56,8,0,80,74,6,0,0,0,0,0,254,0,2,0,168,234,7,0,18,0,0,0,1,128,128,0,96,135,7,0,18,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,17,0,0,0,255,255,255,0,0,0,0,0,18,0,0,0,255,255,254,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,17,0,0,0,1,2,2,0,96,135,7,0,17,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,8,0,160,123,6,0,17,0,0,0,1,28,0,0,40,88,7,0,17,0,0,0,1,28,16,0,96,39,7,0,17,0,0,0,1,28,28,0,144,251,6,0,17,0,0,0,1,28,12,0,184,164,6,0,17,0,0,0,1,28,20,0,80,74,6,0,17,0,0,0,1,28,4,0,192,32,6,0,17,0,0,0,1,28,24,0,192,234,2,0,17,0,0,0,1,28,8,0,32,242,5,0,0,0,0,0,254,0,8,0,200,87,7,0,17,0,0,0,1,224,0,0,40,88,7,0,17,0,0,0,1,224,128,0,96,39,7,0,17,0,0,0,1,224,224,0,144,251,6,0,17,0,0,0,1,224,96,0,184,164,6,0,17,0,0,0,1,224,160,0,80,74,6,0,17,0,0,0,1,224,32,0,192,32,6,0,17,0,0,0,1,224,192,0,192,234,2,0,17,0,0,0,1,224,64,0,32,242,5,0,0,0,0,0,254,0,2,0,168,234,7,0,18,0,0,0,1,1,1,0,96,135,7,0,18,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,18,0,0,0,1,48,16,0,80,246,3,0,18,0,0,0,1,48,48,0,248,38,7,0,18,0,0,0,1,48,32,0,112,212,3,0,18,0,0,0,1,48,0,0,248,160,5,0,0,0,0,0,254,0,4,0,112,59,6,0,18,0,0,0,1,192,0,0,176,236,7,0,18,0,0,0,1,192,128,0,184,230,7,0,18,0,0,0,1,192,192,0,192,226,7,0,18,0,0,0,1,192,64,0,72,123,3,0,20,0,0,0,255,255,111,0,0,0,0,0,21,0,0,0,255,255,223,0,0,0,0,0,0,0,0,0,254,0,4,0,160,123,6,0,20,0,0,0,1,3,0,0,96,39,7,0,20,0,0,0,1,3,3,0,144,251,6,0,20,0,0,0,1,3,2,0,184,164,6,0,20,0,0,0,1,3,1,0,80,74,6,0,0,0,0,0,254,0,4,0,200,87,7,0,20,0,0,0,1,12,0,0,96,39,7,0,20,0,0,0,1,12,12,0,144,251,6,0,20,0,0,0,1,12,8,0,184,164,6,0,20,0,0,0,1,12,4,0,80,74,6,0,0,0,0,0,254,0,2,0,168,234,7,0,20,0,0,0,1,32,0,0,96,135,7,0,20,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,20,0,0,0,1,64,64,0,96,135,7,0,20,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,200,30,2,0,20,0,0,0,1,128,0,0,120,97,1,0,20,0,0,0,1,128,128,0,96,19,1,0,0,0,0,0,254,0,4,0,128,129,4,0,21,0,0,0,1,3,1,0,192,255,2,0,21,0,0,0,1,3,3,0,8,49,4,0,21,0,0,0,1,3,2,0,72,246,3,0,21,0,0,0,1,3,0,0,48,176,2,0,0,0,0,0,254,0,4,0,72,202,5,0,21,0,0,0,1,12,4,0,80,246,3,0,21,0,0,0,1,12,12,0,248,38,7,0,21,0,0,0,1,12,8,0,112,212,3,0,21,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,2,0,104,159,3,0,21,0,0,0,1,16,0,0,56,111,3,0,21,0,0,0,1,16,16,0,104,134,3,0,0,0,0,0,254,0,2,0,72,4,1,0,21,0,0,0,1,64,64,0,96,135,7,0,21,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,99,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,40,221,203,232,1,0,16,1,99,109,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,77,45,67,184,1,0,16,1,99,109,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,97,127,169,21,1,0,16,1,99,109,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,192,236,18,140,1,0,16,1,99,109,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,214,207,82,35,1,0,16,1,99,109,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,232,163,9,11,2,0,16,1,99,109,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,190,67,240,71,2,0,16,1,99,109,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,160,204,27,141,4,0,32,0,99,109,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,81,199,213,60,4,0,32,0,99,104,101,99,107,109,97,110,46,99,108,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,87,80,164,87,7,0,32,0,15,0,0,0,255,255,0,0,0,0,0,0,16,0,0,0,255,255,0,0,0,0,0,0,17,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,32,4,2,0,16,0,0,0,1,64,64,0,144,147,2,0,16,0,0,0,1,64,0,0,200,209,1,0,0,0,0,0,254,0,2,0,200,30,2,0,16,0,0,0,1,128,0,0,120,97,1,0,16,0,0,0,1,128,128,0,96,19,1,0,0,0,0,0,254,0,4,0,128,129,4,0,17,0,0,0,1,3,0,0,8,49,4,0,17,0,0,0,1,3,1,0,152,21,4,0,17,0,0,0,1,3,2,0,72,246,3,0,17,0,0,0,1,3,3,0,72,0,3,0,0,0,0,0,254,0,2,0,64,37,5,0,17,0,0,0,1,4,0,0,160,191,4,0,17,0,0,0,1,4,4,0,240,159,4,0,0,0,0,0,254,0,2,0,80,159,1,0,17,0,0,0,1,8,8,0,8,49,4,0,17,0,0,0,1,8,0,0,72,246,3,0,98,53,50,45,49,51,56,46,51,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,81,254,113,139,2,0,16,1,98,53,50,45,49,51,53,46,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,124,106,165,91,2,0,16,1,98,53,50,45,49,51,49,46,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,131,93,148,170,2,0,16,1,98,53,50,45,49,50,57,46,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,8,188,174,14,2,0,16,1,98,53,50,45,49,51,50,46,51,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,137,71,245,162,6,0,16,1,98,53,50,45,49,51,51,46,53,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,149,47,35,18,6,0,16,1,98,53,50,45,49,51,55,46,53,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,74,183,171,55,9,0,16,1,98,53,50,45,50,57,46,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,124,210,102,131,11,0,32,0,98,53,50,45,51,52,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,54,206,141,125,17,0,32,0,98,53,50,45,51,53,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,13,236,238,120,17,0,32,0,98,53,50,45,51,54,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,145,158,232,97,17,0,32,0,98,53,50,45,51,55,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,185,71,46,240,17,0,32,0,98,53,50,45,51,48,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,71,198,140,27,21,0,32,0,98,53,50,45,51,49,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,32,142,153,241,21,0,32,0,98,53,50,45,51,50,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,12,120,32,134,21,0,32,0,98,53,50,45,51,51,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,196,184,244,230,21,0,32,0,98,53,50,45,50,56,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,43,200,59,150,22,0,32,0,98,53,50,45,51,56,46,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,247,91,91,23,0,32,0,98,53,50,45,49,49,53,46,55,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,147,126,17,78,24,0,64,0,98,53,50,45,49,49,52,46,55,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,177,214,115,58,24,0,64,0,98,53,50,45,49,49,51,46,55,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,5,58,106,44,24,0,64,0,98,53,50,45,49,49,54,46,55,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,60,152,70,173,25,0,64,0,98,53,50,45,48,49,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,23,157,113,137,0,0,0,8,98,53,50,45,48,51,46,49,51,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,13,73,248,163,0,0,0,8,98,53,50,45,48,54,46,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,48,31,248,251,0,0,0,8,98,53,50,45,49,56,46,57,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,26,175,189,96,0,0,0,8,98,53,50,45,49,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,13,190,113,98,0,0,0,8,98,53,50,45,52,57,46,54,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,209,46,221,96,0,0,0,8,98,53,50,45,53,48,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,28,120,137,193,0,0,0,8,98,53,50,45,53,49,46,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,121,31,204,48,0,0,0,8,98,53,50,45,49,50,54,46,49,51,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,14,132,47,250,0,0,0,8,98,53,50,45,49,50,55,46,49,53,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,79,42,104,119,0,0,0,8,112,97,108,50,48,108,56,98,45,98,53,50,45,49,55,46,105,99,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,1,0,0,109,49,81,72,0,0,0,8,112,97,108,50,48,108,56,98,45,98,53,50,45,49,55,46,105,99,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,1,0,0])
.concat([109,49,81,72,0,0,0,8,112,97,108,50,48,108,56,98,45,98,53,50,45,49,55,46,105,99,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,1,0,0,109,49,81,72,0,0,0,8,112,97,108,50,48,108,56,98,45,98,53,50,45,49,55,46,105,99,53,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,1,0,0,109,49,81,72,0,0,0,8,112,97,108,49,54,108,56,98,45,98,53,50,45,49,57,46,105,99,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,220,146,162,59,0,0,0,8,112,97,108,49,54,108,56,98,45,98,53,50,45,50,48,46,105,99,51,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,115,173,57,189,0,0,0,8,112,97,108,49,54,108,56,98,45,98,53,50,45,50,49,46,105,99,53,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,164,106,231,47,0,0,0,8,112,97,108,50,48,108,56,98,45,98,53,50,45,50,53,46,105,99,49,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,1,0,0,45,99,43,55,0,0,0,8,112,97,108,50,48,108,56,98,45,98,53,50,45,50,54,46,105,99,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,1,0,0,194,43,79,217,0,0,0,8,112,97,108,50,48,108,56,98,45,98,53,50,45,50,54,46,105,99,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,1,0,0,194,43,79,217,0,0,0,8,112,97,108,50,48,108,56,98,45,98,53,50,45,50,54,46,105,99,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,1,0,0,194,43,79,217,0,0,0,8,112,97,108,50,48,108,56,98,45,98,53,50,45,50,54,46,105,99,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,1,0,0,194,43,79,217,0,0,0,8,112,97,108,50,48,108,56,98,45,98,53,50,45,50,55,46,105,99,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,1,0,0,38,171,194,97,0,0,0,8,112,97,108,50,48,108,56,98,45,98,53,50,45,49,49,56,46,105,99,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,1,0,0,175,228,95,156,0,0,0,8,112,97,108,50,48,108,56,98,45,98,53,50,45,49,49,57,46,105,99,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,1,0,0,6,33,142,139,0,0,0,8,112,97,108,49,54,108,56,98,45,98,53,50,45,49,50,48,46,105,99,53,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,160,255,126,62,0,0,0,8,112,97,108,50,48,108,56,98,45,98,53,50,45,49,50,49,46,105,99,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,1,0,0,29,253,86,112,0,0,0,8,112,97,108,49,54,108,56,98,45,98,53,50,45,49,50,50,46,105,99,49,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,4,251,192,4,0,0,0,8,112,97,108,49,54,108,56,98,45,98,53,50,45,49,50,51,46,105,99,49,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,200,209,101,56,0,0,0,8,112,97,108,49,54,108,56,98,45,98,53,50,45,49,50,52,46,105,99,49,56,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,0,0,0,24,112,97,108,49,54,108,56,98,45,98,53,50,45,49,50,53,46,105,99,49,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,87,197,40,118,0,0,0,8,98,53,50,45,49,52,48,46,51,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,75,138,41,193,2,0,16,1,98,53,50,45,49,51,57,46,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,46,115,127,153,2,0,16,1,98,53,50,45,49,51,49,46,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,131,93,148,170,2,0,16,1,98,53,50,45,49,50,57,46,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,8,188,174,14,2,0,16,1,98,53,50,45,49,51,50,46,51,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,137,71,245,162,6,0,16,1,98,53,50,45,49,51,51,46,53,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,149,47,35,18,6,0,16,1,98,53,50,45,49,51,52,46,53,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,127,172,250,145,9,0,16,1,98,53,50,45,50,57,46,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,124,210,102,131,11,0,32,0,98,53,50,45,51,52,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,54,206,141,125,17,0,32,0,98,53,50,45,51,53,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,13,236,238,120,17,0,32,0,98,53,50,45,51,54,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,145,158,232,97,17,0,32,0,98,53,50,45,51,55,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,185,71,46,240,17,0,32,0,98,53,50,45,51,48,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,71,198,140,27,21,0,32,0,98,53,50,45,51,49,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,32,142,153,241,21,0,32,0,98,53,50,45,51,50,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,12,120,32,134,21,0,32,0,98,53,50,45,51,51,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,196,184,244,230,21,0,32,0,98,53,50,45,50,56,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,43,200,59,150,22,0,32,0,98,53,50,45,51,56,46,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,247,91,91,23,0,32,0,98,53,50,45,52,49,46,55,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,12,136,4,130,24,0,64,0,98,53,50,45,52,48,46,55,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,85,16,85,240,24,0,64,0,98,53,50,45,51,57,46,55,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,211,187,156,172,24,0,64,0,98,53,50,45,52,50,46,55,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,241,125,97,110,25,0,64,0,98,53,50,45,48,49,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,23,157,113,137,0,0,0,8,98,53,50,45,48,51,46,49,51,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,13,73,248,163,0,0,0,8,98,53,50,45,48,54,46,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,48,31,248,251,0,0,0,8,98,53,50,45,49,56,46,57,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,26,175,189,96,0,0,0,8,98,53,50,45,49,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,13,190,113,98,0,0,0,8,98,53,50,45,52,57,46,54,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,209,46,221,96,0,0,0,8,98,53,50,45,53,48,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,28,120,137,193,0,0,0,8,98,53,50,45,53,49,46,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,121,31,204,48,0,0,0,8,98,53,50,45,49,50,54,46,49,51,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,14,132,47,250,0,0,0,8,98,53,50,45,49,50,55,46,49,53,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,79,42,104,119,0,0,0,8,112,97,108,50,48,108,56,98,45,98,53,50,45,49,55,46,105,99,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,1,0,0,109,49,81,72,0,0,0,8,112,97,108,50,48,108,56,98,45,98,53,50,45,49,55,46,105,99,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,1,0,0,109,49,81,72,0,0,0,8,112,97,108,50,48,108,56,98,45,98,53,50,45,49,55,46,105,99,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,1,0,0,109,49,81,72,0,0,0,8,112,97,108,50,48,108,56,98,45,98,53,50,45,49,55,46,105,99,53,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,1,0,0,109,49,81,72,0,0,0,8,112,97,108,49,54,108,56,98,45,98,53,50,45,49,57,46,105,99,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,220,146,162,59,0,0,0,8,112,97,108,49,54,108,56,98,45,98,53,50,45,50,48,46,105,99,51,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,115,173,57,189,0,0,0,8,112,97,108,49,54,108,56,98,45,98,53,50,45,50,49,46,105,99,53,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,164,106,231,47,0,0,0,8,112,97,108,50,48,108,56,98,45,98,53,50,45,50,53,46,105,99,49,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,1,0,0,45,99,43,55,0,0,0,8,112,97,108,50,48,108,56,98,45,98,53,50,45,50,54,46,105,99,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,1,0,0,194,43,79,217,0,0,0,8,112,97,108,50,48,108,56,98,45,98,53,50,45,50,54,46,105,99,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,1,0,0,194,43,79,217,0,0,0,8,112,97,108,50,48,108,56,98,45,98,53,50,45,50,54,46,105,99,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,1,0,0,194,43,79,217,0,0,0,8,112,97,108,50,48,108,56,98,45,98,53,50,45,50,54,46,105,99,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,1,0,0,194,43,79,217,0,0,0,8,112,97,108,50,48,108,56,98,45,98,53,50,45,50,55,46,105,99,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,1,0,0,38,171,194,97,0,0,0,8,112,97,108,50,48,108,56,98,45,98,53,50,45,49,49,56,46,105,99,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,1,0,0,175,228,95,156,0,0,0,8,112,97,108,50,48,108,56,98,45,98,53,50,45,49,49,57,46,105,99,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,1,0,0,6,33,142,139,0,0,0,8,112,97,108,49,54,108,56,98,45,98,53,50,45,49,50,48,46,105,99,53,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,160,255,126,62,0,0,0,8,112,97,108,50,48,108,56,98,45,98,53,50,45,49,50,49,46,105,99,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,1,0,0,29,253,86,112,0,0,0,8,112,97,108,49,54,108,56,98,45,98,53,50,45,49,50,50,46,105,99,49,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,4,251,192,4,0,0,0,8,112,97,108,49,54,108,56,98,45,98,53,50,45,49,50,51,46,105,99,49,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,200,209,101,56,0,0,0,8,112,97,108,49,54,108,56,98,45,98,53,50,45,49,50,52,46,105,99,49,56,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,0,0,0,24,112,97,108,49,54,108,56,98,45,98,53,50,45,49,50,53,46,105,99,49,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,87,197,40,118,0,0,0,8,11,0,0,0,255,255,255,0,0,0,0,0,12,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,200,30,2,0,11,0,0,0,1,3,3,0,152,116,6,0,11,0,0,0,1,3,2,0,48,113,6,0,11,0,0,0,1,3,1,0,48,110,6,0,11,0,0,0,1,3,0,0,232,104,6,0,0,0,0,0,254,0,2,0,232,75,4,0,11,0,0,0,1,4,4,0,96,135,7,0,11,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,11,0,0,0,1,8,0,0,96,135,7,0,11,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,11,0,0,0,1,48,16,0,104,236,7,0,11,0,0,0,1,48,48,0,128,230,7,0,11,0,0,0,1,48,0,0,120,211,6,0,11,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,11,0,0,0,1,192,64,0,104,236,7,0,11,0,0,0,1,192,192,0,128,230,7,0,11,0,0,0,1,192,0,0,120,211,6,0,11,0,0,0,1,192,128,0,184,164,6,0,0,0,0,0,254,0,4,0,72,202,5,0,12,0,0,0,1,3,2,0,80,246,3,0,12,0,0,0,1,3,3,0,248,38,7,0,12,0,0,0,1,3,1,0,112,212,3,0,12,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,136,20,8,0,12,0,0,0,1,12,8,0,48,17,8,0,12,0,0,0,1,12,4,0,248,12,8,0,12,0,0,0,1,12,12,0,208,6,8,0,12,0,0,0,1,12,0,0,112,2,8,0,0,0,0,0,254,0,2,0,216,250,7,0,12,0,0,0,1,16,16,0,8,49,4,0,12,0,0,0,1,16,0,0,72,246,3,0,0,0,0,0,254,0,2,0,216,99,6,0,12,0,0,0,1,32,32,0,96,135,7,0,12,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,48,219,7,0,12,0,0,0,1,64,0,0,96,135,7,0,12,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,12,0,0,0,1,128,0,0,96,135,7,0,12,0,0,0,1,128,128,0,152,182,7,0,0,0,0,0,19,0,0,0,255,255,0,0,0,0,0,0,20,0,0,0,255,255,79,0,0,0,0,0,21,0,0,0,255,255,125,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,19,0,0,0,1,15,15,0,120,247,3,0,19,0,0,0,1,15,14,0,104,213,3,0,19,0,0,0,1,15,13,0,224,185,3,0,19,0,0,0,1,15,12,0,144,160,3,0,19,0,0,0,1,15,11,0,96,135,3,0,19,0,0,0,1,15,10,0,32,136,7,0,19,0,0,0,1,15,9,0,40,88,7,0,19,0,0,0,1,15,8,0,96,39,7,0,19,0,0,0,1,15,0,0,144,251,6,0,19,0,0,0,1,15,1,0,184,164,6,0,19,0,0,0,1,15,2,0,80,74,6,0,19,0,0,0,1,15,3,0,192,32,6,0,19,0,0,0,1,15,4,0,192,234,2,0,19,0,0,0,1,15,5,0,32,242,5,0,19,0,0,0,1,15,6,0,176,192,2,0,19,0,0,0,1,15,7,0,248,175,2,0,0,0,0,0,254,0,16,0,160,123,6,0,19,0,0,0,1,240,240,0,120,247,3,0,19,0,0,0,1,240,224,0,104,213,3,0,19,0,0,0,1,240,208,0,224,185,3,0,19,0,0,0,1,240,192,0,144,160,3,0,19,0,0,0,1,240,176,0,96,135,3,0,19,0,0,0,1,240,160,0,32,136,7,0,19,0,0,0,1,240,144,0,40,88,7,0,19,0,0,0,1,240,128,0,96,39,7,0,19,0,0,0,1,240,0,0,144,251,6,0,19,0,0,0,1,240,16,0,184,164,6,0,19,0,0,0,1,240,32,0,80,74,6,0,19,0,0,0,1,240,48,0,192,32,6,0,19,0,0,0,1,240,64,0,192,234,2,0,19,0,0,0,1,240,80,0,32,242,5,0,19,0,0,0,1,240,96,0,176,192,2,0,19,0,0,0,1,240,112,0,248,175,2,0,0,0,0,0,254,0,4,0,64,37,5,0,20,0,0,0,1,3,0,0,72,129,5,0,20,0,0,0,1,3,1,0,152,100,5,0,20,0,0,0,1,3,2,0,112,69,5,0,20,0,0,0,1,3,3,0,128,38,5,0,0,0,0,0,254,0,2,0,16,227,4,0,20,0,0,0,1,4,4,0,96,135,7,0,20,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,24,0,0,72,0,3,0,20,0,0,0,1,24,8,0,8,49,4,0,20,0,0,0,1,24,16,0,208,75,4,0,20,0,0,0,1,24,24,0,192,255,2,0,0,0,0,0,254,0,2,0,232,22,4,0,20,0,0,0,1,32,32,0,48,248,3,0,20,0,0,0,1,32,0,0,80,214,3,0,0,0,0,0,254,0,2,0,200,30,2,0,20,0,0,0,1,128,0,0,120,97,1,0,20,0,0,0,1,128,128,0,96,19,1,0,0,0,0,0,254,0,2,0,128,112,3,0,21,0,0,0,1,1,0,0,168,22,4,0,21,0,0,0,1,1,1,0,224,247,3,0,0,0,0,0,254,0,2,0,168,234,7,0,21,0,0,0,1,2,2,0,96,135,7,0,21,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,8,46,3,0,21,0,0,0,1,4,4,0,112,21,3,0,21,0,0,0,1,4,0,0,200,0,3,0,0,0,0,0,254,0,2,0,48,235,2,0,21,0,0,0,1,8,8,0,96,135,7,0,21,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,2,0,120,211,2,0,21,0,0,0,1,16,0,0,96,135,7,0,21,0,0,0,1,16,16,0,152,182,7,0,0,0,0,0,254,0,2,0,0,193,2,0,21,0,0,0,1,32,0,0,96,135,7,0,21,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,48,176,2,0,21,0,0,0,1,64,64,0,96,135,7,0,21,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,32,4,2,0,21,0,0,0,1,128,0,0,120,148,2,0,21,0,0,0,1,128,128,0,72,136,2,0,23,0,0,0,255,255,207,0,0,0,0,0,24,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,23,0,0,0,1,3,3,0,8,49,4,0,23,0,0,0,1,3,2,0,152,21,4,0,23,0,0,0,1,3,1,0,72,246,3,0,23,0,0,0,1,3,0,0,72,0,3,0,0,0,0,0,254,0,2,0,232,168,4,0,23,0,0,0,1,4,4,0,192,33,6,0,23,0,0,0,1,4,0,0,232,23,6,0,0,0,0,0,254,0,2,0,240,83,4,0,23,0,0,0,1,8,8,0,48,20,6,0,23,0,0,0,1,8,0,0,120,7,5,0,0,0,0,0,254,0,4,0,64,37,5,0,23,0,0,0,1,12,12,0,32,130,1,0,23,0,0,0,1,12,8,0,8,116,1,0,23,0,0,0,1,12,4,0,112,129,7,0,23,0,0,0,1,12,0,0,224,93,1,0,0,0,0,0,254,0,2,0,72,202,5,0,23,0,0,0,1,64,64,0,80,246,3,0,23,0,0,0,1,64,0,0,248,38,7,0,0,0,0,0,254,0,0,0,200,87,7,0,24,0,0,0,1,3,1,0,96,39,7,0,24,0,0,0,1,3,3,0,144,251,6,0,24,0,0,0,1,3,2,0,184,164,6,0,24,0,0,0,1,3,0,0,16,227,4,0,0,0,0,0,254,0,4,0,160,123,6,0,24,0,0,0,1,12,4,0,96,39,7,0,24,0,0,0,1,12,12,0,144,251,6,0,24,0,0,0,1,12,0,0,120,211,6,0,24,0,0,0,1,12,8,0,184,164,6,0,0,0,0,0,254,0,4,0,104,159,3,0,24,0,0,0,1,16,0,0,56,111,3,0,24,0,0,0,1,16,16,0,120,170,1,0,0,0,0,0,254,0,2,0,144,212,8,0,24,0,0,0,1,32,32,0,96,135,7,0,24,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,16,80,1,0,24,0,0,0,1,64,64,0,96,135,7,0,24,0,0,0,1,64,0,0,152,182,7,0,99,97,101,95,51,48,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,213,92,48,35,1,0,16,1,99,97,101,95,51,53,46,49,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,19,145,65,105,1,0,16,1,99,97,101,95,51,49,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,179,223,8,144,1,0,16,1,99,97,101,95,51,54,46,49,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,142,111,191,77,1,0,16,1,99,97,45,51,50,109,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,212,55,72,12,2,0,16,1,99,97,45,53,109,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,55,204,212,102,4,0,32,0,99,97,45,55,109,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,242,150,248,182,4,0,32,0,99,97,45,49,109,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,253,32,6,77,4,0,32,0,99,97,45,51,109,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,195,65,3,11,4,0,32,0,99,97,101,95,48,57,46,49,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,133,116,254,150,3,0,16,0,99,97,101,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,44,58,97,74,5,0,64,0,99,97,101,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,147,68,88,116,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,99,97,50,52,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,28,11,236,118,0,0,0,8,105,111,98,49,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,99,97,119,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,240,211,37,129,1,0,16,1,99,97,119,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,206,16,155,177,1,0,16,1,99,97,119,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,137,198,69,160,4,0,32,0,99,97,119,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,124,47,25,97,4,0,32,0,99,97,119,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,219,120,221,48,4,0,32,0,99,97,119,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,65,252,55,73,4,0,32,0,99,97,119,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,220,108,225,255,3,0,16,0,56,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,140,112,85,246,1,0,16,1,52,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,170,181,47,160,1,0,16,1,55,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,48,116,108,140,1,0,16,1,51,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,44,191,133,245,1,0,16,1,54,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,110,144,218,95,1,0,16,1,50,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,53,24,108,115,1,0,16,1,53,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,131,128,69,118,1,0,16,1,49,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,52,63,82,211,1,0,16,1,49,55,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,98,128,83,11,4,0,32,0,49,57,46,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,17,35,214,58,4,0,32,0,50,49,46,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,152,42,135,27,4,0,32,0,50,51,46,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,205,238,73,173,4,0,32,0,57,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,91,223,212,140,4,0,32,0,49,49,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,138,65,20,191,4,0,32,0,49,51,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,184,170,241,206,4,0,32,0,49,53,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,220,37,119,57,4,0,32,0,49,56,46,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,237,247,20,155,4,0,32,0,50,48,46,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,187,193,188,89,4,0,32,0,50,50,46,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,122,100,220,35,4,0,32,0,50,52,46,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,107,250,169,237,4,0,32,0,49,48,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,73,66,23,23,4,0,32,0,49,50,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,178,64,4,73,4,0,32,0,49,52,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,112,130,74,52,4,0,32,0,49,54,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,145,173,145,185,4,0,32,0,53,46,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,220,108,225,255,3,0,16,0,168,86,7,0,1,0,0,0,232,47,216,0,248,191,2,0,24,38,7,0,1,0,0,0,236,47,216,0,184,160,2,0,56,210,6,0,1,0,0,0,35,48,216,0,192,135,2,0,24,163,6,0,1,0,0,0,34,48,216,0,240,108,2,0,152,122,6,0,1,0,0,0,33,48,216,0,96,82,2,0,192,72,6,0,1,0,0,0,32,48,216,0,32,56,2,0,232,158,3,0,1,0,0,0,36,48,216,0,152,30,2,0,104,184,3,0,1,0,0,0,37,48,216,0,232,10,2,0,144,55,2,0,1,0,0,0,38,48,216,0,152,138,8,0,40,246,1,0,1,0,0,0,233,47,216,0,64,246,1,0,144,236,1,0,1,0,0,0,237,47,216,0,136,224,1,0,176,223,1,0,1,0,0,0,43,48,216,0,72,198,1,0,192,209,1,0,1,0,0,0,42,48,216,0,24,182,1,0,24,198,1,0,1,0,0,0,41,48,216,0,40,167,1,0,120,189,1,0,1,0,0,0,40,48,216,0,200,149,1,0,200,32,1,0,1,0,0,0,44,48,216,0,56,126,1,0,208,41,1,0,1,0,0,0,45,48,216,0,32,101,1,0,240,173,8,0,1,0,0,0,46,48,216,0,96,32,8,0,88,212,3,0,1,0,0,0,144,46,216,0,40,185,3,0,240,152,1,0,1,0,0,0,238,47,216,0,216,70,1,0,16,17,8,0,1,0,0,0,234,47,216,0,224,12,8,0,72,65,1,0,9,0,0,0,232,48,216,0,32,58,1,0,48,50,1,0,9,0,0,0,224,48,216,0,32,58,1,0,224,41,1,0,9,0,0,0,216,48,216,0,32,58,1,0,18,0,0,0,255,255,199,0,0,0,0,0,19,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,72,202,5,0,18,0,0,0,1,3,3,0,80,246,3,0,18,0,0,0,1,3,2,0,80,124,6,0,18,0,0,0,1,3,1,0,112,212,3,0,18,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,2,0,224,172,5,0,18,0,0,0,1,4,0,0,32,137,5,0,18,0,0,0,1,4,4,0,224,109,5,0,0,0,0,0,254,0,2,0,200,30,2,0,18,0,0,0,1,8,0,0,120,97,1,0,18,0,0,0,1,8,8,0,96,19,1,0,0,0,0,0,254,0,4,0,224,25,1,0,18,0,0,0,1,48,0,0,24,205,7,0,18,0,0,0,1,48,48,0,136,120,6,0,18,0,0,0,1,48,32,0,32,112,3,0,18,0,0,0,1,48,16,0,176,116,6,0,0,0,0,0,254,0,4,0,128,129,4,0,18,0,0,0,1,192,0,0,208,75,4,0,18,0,0,0,1,192,192,0,8,49,4,0,18,0,0,0,1,192,128,0,152,21,4,0,18,0,0,0,1,192,64,0,72,246,3,0,0,0,0,0,254,0,10,0,160,123,6,0,19,0,0,0,1,15,6,0,32,136,7,0,19,0,0,0,1,15,8,0,40,88,7,0,19,0,0,0,1,15,10,0,96,39,7,0,19,0,0,0,1,15,7,0,120,113,6,0,19,0,0,0,1,15,15,0,144,251,6,0,19,0,0,0,1,15,9,0,120,211,6,0,19,0,0,0,1,15,14,0,184,164,6,0,19,0,0,0,1,15,13,0,80,74,6,0,19,0,0,0,1,15,12,0,192,32,6,0,19,0,0,0,1,15,11,0,192,234,2,0,0,0,0,0,254,0,10,0,200,87,7,0,19,0,0,0,1,240,96,0,32,136,7,0,19,0,0,0,1,240,128,0,40,88,7,0,19,0,0,0,1,240,160,0,96,39,7,0,19,0,0,0,1,240,112,0,120,113,6,0,19,0,0,0,1,240,240,0,144,251,6,0,19,0,0,0,1,240,144,0,120,211,6,0,19,0,0,0,1,240,224,0,184,164,6,0,19,0,0,0,1,240,208,0,80,74,6,0,19,0,0,0,1,240,192,0,192,32,6,0,19,0,0,0,1,240,176,0,192,234,2,0,0,0,0,0,99,97,116,97,99,111,109,98,46,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,210,40,204,53,1,0,16,1,99,97,116,97,99,111,109,98,46,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,51,225,28,29,1,0,16,1,99,97,116,97,99,111,109,98,46,119,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,231,189,155,71,1,0,16,1,99,97,116,97,99,111,109,98,46,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,52,165,61,94,1,0,16,1,99,97,116,45,103,102,120,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,92,230,113,232,4,0,32,0,99,97,116,45,103,102,120,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,170,175,77,177,4,0,32,0,109,109,105,54,51,51,49,46,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,135,125,12,106,7,0,32,0,11,0,0,0,255,255,0,0,0,0,0,0,12,0,0,0,255,255,64,0,0,0,0,0,13,0,0,0,255,255,4,0,0,0,0,0,0,0,0,0,254,0,2,0,200,87,7,0,12,0,0,0,1,64,0,0,224,127,8,0,12,0,0,0,1,64,64,0,32,123,8,0,0,0,0,0,254,0,2,0,160,123,6,0,12,0,0,0,1,128,0,0,0,90,2,0,12,0,0,0,1,128,128,0,104,61,2,0,0,0,0,0,254,0,2,0,128,129,4,0,13,0,0,0,1,4,4,0,8,49,4,0,13,0,0,0,1,4,0,0,72,246,3,0,99,99,101,95,50,51,102,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,197,20,200,66,2,0,16,1,99,99,95,50,50,102,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,149,65,211,15,2,0,16,1,99,99,95,50,52,102,46,57,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,37,79,121,58,1,0,16,1,99,99,95,50,56,102,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,6,41,60,252,1,0,16,1,99,99,45,53,109,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,186,216,97,114,4,0,32,0,99,99,45,55,109,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,73,249,96,106,4,0,32,0,99,99,45,49,109,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,2,115,99,0,4,0,32,0,99,99,45,51,109,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,207,135,204,4,0,32,0,99,99,45,54,109,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,237,139,113,40,4,0,32,0,99,99,45,56,109,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,58,197,172,212,4,0,32,0,99,99,45,50,109,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,81,241,105,12,4,0,32,0,99,99,45,52,109,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,151,187,158,31,4,0,32,0,99,99,95,48,57,46,49,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,88,139,142,105,3,0,16,0,99,99,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,219,194,226,109,5,0,64,0,99,99,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,174,145,144,185,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,99,99,54,51,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,249,240,232,202,0,0,0,8,105,111,98,49,46,49,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,99,99,112,114,103,49,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,196,37,194,225,0,0,0,8,105,111,99,49,46,105,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,129,32,24,13,0,0,0,8,99,54,51,50,98,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,112,146,189,15,0,0,0,8,35,0,0,0,255,255,0,0,0,0,0,0,36,0,0,0,255,255,11,0,0,0,0,0,37,0,0,0,255,255,96,0,0,0,0,0,0,0,0,0,254,0,8,0,32,4,2,0,35,0,0,0,1,7,7,0])
.concat([80,252,6,0,35,0,0,0,1,7,6,0,16,242,7,0,35,0,0,0,1,7,5,0,104,236,7,0,35,0,0,0,1,7,0,0,128,230,7,0,35,0,0,0,1,7,1,0,184,164,6,0,35,0,0,0,1,7,2,0,80,74,6,0,35,0,0,0,1,7,3,0,192,32,6,0,35,0,0,0,1,7,4,0,32,242,5,0,0,0,0,0,254,0,2,0,64,232,1,0,35,0,0,0,1,64,0,0,96,135,7,0,35,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,8,0,72,202,5,0,36,0,0,0,1,7,0,0,72,198,6,0,36,0,0,0,1,7,1,0,208,75,4,0,36,0,0,0,1,7,2,0,8,49,4,0,36,0,0,0,1,7,3,0,72,195,6,0,36,0,0,0,1,7,4,0,72,246,3,0,36,0,0,0,1,7,5,0,72,0,3,0,36,0,0,0,1,7,6,0,64,47,7,0,36,0,0,0,1,7,7,0,48,173,6,0,0,0,0,0,254,0,4,0,176,33,1,0,36,0,0,0,1,24,0,0,80,246,3,0,36,0,0,0,1,24,8,0,248,38,7,0,36,0,0,0,1,24,16,0,112,212,3,0,36,0,0,0,1,24,24,0,248,160,5,0,0,0,0,0,254,0,4,0,112,242,7,0,36,0,0,0,1,192,128,0,0,183,6,0,36,0,0,0,1,192,0,0,96,90,6,0,36,0,0,0,1,192,64,0,24,106,1,0,36,0,0,0,1,192,192,0,72,25,1,0,0,0,0,0,254,0,4,0,128,129,4,0,37,0,0,0,1,3,3,0,192,255,2,0,37,0,0,0,1,3,0,0,208,75,4,0,37,0,0,0,1,3,1,0,8,49,4,0,37,0,0,0,1,3,2,0,152,21,4,0,0,0,0,0,254,0,2,0,16,227,4,0,37,0,0,0,1,4,0,0,96,135,7,0,37,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,254,0,2,0,72,4,1,0,37,0,0,0,1,8,0,0,96,135,7,0,37,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,2,0,120,207,1,0,37,0,0,0,1,16,0,0,96,135,7,0,37,0,0,0,1,16,16,0,152,182,7,0,0,0,0,0,254,0,2,0,40,111,8,0,37,0,0,0,1,32,0,0,96,135,7,0,37,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,37,0,0,0,1,64,0,0,96,135,7,0,37,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,168,79,2,0,37,0,0,0,1,128,0,0,32,182,8,0,37,0,0,0,1,128,128,0,80,251,6,0,0,0,0,0,99,51,56,45,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,160,45,23,190,2,0,16,1,99,51,56,45,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,222,48,164,255,2,0,16,1,99,51,56,45,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,115,136,247,127,9,0,16,1,99,51,56,45,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,54,255,112,193,15,0,32,0,99,51,56,45,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,167,89,250,89,24,0,64,0,99,51,56,45,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,75,113,17,26,28,0,32,0,11,0,0,0,255,255,254,0,0,0,0,0,12,0,0,0,255,255,127,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,11,0,0,0,1,1,0,0,120,97,1,0,11,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,2,0,144,212,8,0,11,0,0,0,1,2,2,0,96,135,7,0,11,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,11,0,0,0,1,4,4,0,96,135,7,0,11,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,11,0,0,0,1,8,0,0,96,135,7,0,11,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,32,4,2,0,11,0,0,0,1,48,0,0,80,252,6,0,11,0,0,0,1,48,16,0,16,242,7,0,11,0,0,0,1,48,32,0,104,236,7,0,11,0,0,0,1,48,48,0,128,230,7,0,0,0,0,0,254,0,4,0,168,248,6,0,11,0,0,0,1,192,0,0,16,242,7,0,11,0,0,0,1,192,64,0,104,236,7,0,11,0,0,0,1,192,128,0,80,245,6,0,11,0,0,0,1,192,192,0,240,240,6,0,0,0,0,0,254,0,4,0,72,202,5,0,12,0,0,0,1,3,2,0,80,246,3,0,12,0,0,0,1,3,3,0,80,124,6,0,12,0,0,0,1,3,1,0,112,212,3,0,12,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,144,72,4,0,12,0,0,0,1,12,0,0,0,71,4,0,12,0,0,0,1,12,4,0,200,68,4,0,12,0,0,0,1,12,12,0,136,66,4,0,12,0,0,0,1,12,8,0,176,63,4,0,0,0,0,0,254,0,4,0,184,61,4,0,12,0,0,0,1,48,0,0,240,56,4,0,12,0,0,0,1,48,16,0,128,54,4,0,12,0,0,0,1,48,48,0,232,49,4,0,12,0,0,0,1,48,32,0,200,46,4,0,0,0,0,0,254,0,2,0,104,159,3,0,12,0,0,0,1,64,0,0,96,135,7,0,12,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,6,0,12,0,0,0,1,128,128,0,8,208,6,0,12,0,0,0,1,128,0,0,88,204,6,0,0,0,0,0,11,0,0,0,255,255,254,0,0,0,0,0,12,0,0,0,255,255,127,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,11,0,0,0,1,1,0,0,120,97,1,0,11,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,2,0,144,212,8,0,11,0,0,0,1,2,2,0,96,135,7,0,11,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,11,0,0,0,1,4,4,0,96,135,7,0,11,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,11,0,0,0,1,8,0,0,96,135,7,0,11,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,11,0,0,0,1,48,0,0,104,236,7,0,11,0,0,0,1,48,48,0,128,230,7,0,11,0,0,0,1,48,0,0,120,211,6,0,11,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,11,0,0,0,1,192,64,0,104,236,7,0,11,0,0,0,1,192,192,0,128,230,7,0,11,0,0,0,1,192,0,0,120,211,6,0,11,0,0,0,1,192,128,0,184,164,6,0,0,0,0,0,254,0,4,0,72,202,5,0,12,0,0,0,1,3,2,0,80,246,3,0,12,0,0,0,1,3,3,0,80,124,6,0,12,0,0,0,1,3,1,0,112,212,3,0,12,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,144,72,4,0,12,0,0,0,1,12,0,0,0,71,4,0,12,0,0,0,1,12,4,0,200,68,4,0,12,0,0,0,1,12,12,0,136,66,4,0,12,0,0,0,1,12,8,0,176,63,4,0,0,0,0,0,254,0,4,0,184,61,4,0,12,0,0,0,1,48,0,0,240,56,4,0,12,0,0,0,1,48,16,0,128,54,4,0,12,0,0,0,1,48,48,0,232,49,4,0,12,0,0,0,1,48,32,0,200,46,4,0,0,0,0,0,254,0,2,0,104,159,3,0,12,0,0,0,1,64,0,0,96,135,7,0,12,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,6,0,12,0,0,0,1,128,128,0,8,208,6,0,12,0,0,0,1,128,0,0,88,204,6,0,0,0,0,0,21,0,0,0,255,255,254,0,0,0,0,0,22,0,0,0,255,255,253,0,0,0,0,0,23,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,240,122,4,0,21,0,0,0,1,1,1,0,224,120,4,0,21,0,0,0,1,1,0,0,176,118,4,0,0,0,0,0,254,0,2,0,144,212,8,0,21,0,0,0,1,2,2,0,96,135,7,0,21,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,21,0,0,0,1,4,4,0,96,135,7,0,21,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,21,0,0,0,1,8,0,0,96,135,7,0,21,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,21,0,0,0,1,48,16,0,96,39,7,0,21,0,0,0,1,48,48,0,144,251,6,0,21,0,0,0,1,48,0,0,120,211,6,0,21,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,21,0,0,0,1,192,64,0,96,39,7,0,21,0,0,0,1,192,192,0,144,251,6,0,21,0,0,0,1,192,0,0,120,211,6,0,21,0,0,0,1,192,128,0,184,164,6,0,0,0,0,0,254,0,4,0,72,202,5,0,22,0,0,0,1,3,3,0,160,246,1,0,22,0,0,0,1,3,2,0,80,246,3,0,22,0,0,0,1,3,1,0,248,38,7,0,22,0,0,0,1,3,0,0,112,212,3,0,0,0,0,0,254,0,2,0,200,95,4,0,22,0,0,0,1,4,4,0,64,47,7,0,22,0,0,0,1,4,0,0,8,49,4,0,0,0,0,0,254,0,2,0,128,129,4,0,22,0,0,0,1,8,8,0,8,49,4,0,22,0,0,0,1,8,0,0,152,21,4,0,0,0,0,0,254,0,2,0,232,84,4,0,22,0,0,0,1,16,0,0,96,135,7,0,22,0,0,0,1,16,16,0,152,182,7,0,0,0,0,0,254,0,2,0,24,81,4,0,22,0,0,0,1,32,0,0,96,135,7,0,22,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,240,122,4,0,22,0,0,0,1,64,64,0,16,77,4,0,22,0,0,0,1,64,64,0,64,246,3,0,0,0,0,0,168,86,7,0,1,0,0,0,120,151,215,0,248,191,2,0,24,38,7,0,1,0,0,0,123,151,215,0,184,160,2,0,56,210,6,0,1,0,0,0,143,151,215,0,192,135,2,0,24,163,6,0,1,0,0,0,142,151,215,0,240,108,2,0,152,122,6,0,1,0,0,0,141,151,215,0,96,82,2,0,192,72,6,0,1,0,0,0,140,151,215,0,32,56,2,0,200,110,3,0,1,0,0,0,139,151,215,0,152,30,2,0,120,89,3,0,1,0,0,0,138,151,215,0,232,10,2,0,40,246,1,0,1,0,0,0,121,151,215,0,64,246,1,0,144,236,1,0,1,0,0,0,122,151,215,0,136,224,1,0,176,223,1,0,1,0,0,0,135,151,215,0,72,198,1,0,192,209,1,0,1,0,0,0,134,151,215,0,24,182,1,0,24,198,1,0,1,0,0,0,133,151,215,0,40,167,1,0,120,189,1,0,1,0,0,0,132,151,215,0,200,149,1,0,224,22,1,0,1,0,0,0,131,151,215,0,56,126,1,0,160,14,1,0,1,0,0,0,130,151,215,0,32,101,1,0,88,212,3,0,1,0,0,0,200,147,215,0,40,185,3,0,16,17,8,0,1,0,0,0,124,151,215,0,224,12,8,0,56,58,1,0,1,0,0,0,125,151,215,0,64,50,1,0,72,65,1,0,9,0,0,0,152,151,215,0,32,58,1,0,48,50,1,0,9,0,0,0,153,151,215,0,32,58,1,0,98,120,45,114,111,109,50,46,112,103,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,200,32,17,248,0,0,16,1,98,120,45,114,111,109,51,46,112,103,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,130,78,11,8,0,0,16,1,98,120,45,114,111,109,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,31,227,76,247,0,0,32,0,98,120,45,114,111,109,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,35,202,86,111,0,0,32,0,98,120,45,114,111,109,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,121,157,242,51,0,0,32,0,98,120,45,114,111,109,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,146,112,54,36,0,0,32,0,98,120,45,114,111,109,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,234,189,246,175,0,0,32,0,98,120,45,114,111,109,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,210,254,106,36,0,0,32,0,98,120,45,114,111,109,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,106,23,141,137,0,0,32,0,98,120,45,114,111,109,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,35,20,238,253,0,0,32,0,98,120,45,114,111,109,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,115,51,65,48,0,0,32,0,98,120,45,114,111,109,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,159,201,127,142,0,0,32,0,98,120,45,114,111,109,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,205,171,14,212,0,0,32,0,98,120,45,114,111,109,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,117,60,131,120,0,0,32,0,98,120,45,114,111,109,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,63,99,105,241,0,0,32,0,98,120,45,114,111,109,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,15,22,235,113,0,0,32,0,98,120,45,114,111,109,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,187,52,218,0,0,32,0,98,120,45,114,111,109,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,249,142,178,85,0,0,32,0,98,120,45,114,111,109,49,46,115,110,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,56,113,230,138,0,0,64,0,21,0,0,0,255,255,247,0,0,0,0,0,22,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,184,89,6,0,21,0,0,0,1,1,1,0,96,135,7,0,21,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,16,227,4,0,21,0,0,0,1,2,2,0,96,135,7,0,21,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,21,0,0,0,1,8,8,0,96,135,7,0,21,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,8,0,32,4,2,0,21,0,0,0,1,224,0,0,104,54,4,0,21,0,0,0,1,224,32,0,80,252,6,0,21,0,0,0,1,224,64,0,16,242,7,0,21,0,0,0,1,224,96,0,104,236,7,0,21,0,0,0,1,224,224,0,128,230,7,0,21,0,0,0,1,224,192,0,184,164,6,0,21,0,0,0,1,224,160,0,80,74,6,0,21,0,0,0,1,224,128,0,192,32,6,0,0,0,0,0,254,0,4,0,64,37,5,0,22,0,0,0,1,3,2,0,120,7,5,0,22,0,0,0,1,3,3,0,120,198,7,0,22,0,0,0,1,3,1,0,16,150,7,0,22,0,0,0,1,3,0,0,160,103,7,0,0,0,0,0,254,0,2,0,80,109,5,0,22,0,0,0,1,128,0,0,208,75,4,0,22,0,0,0,1,128,128,0,8,49,4,0,0,0,0,0,254,0,4,0,72,202,5,0,22,0,0,0,1,48,32,0,80,246,3,0,22,0,0,0,1,48,48,0,248,38,7,0,22,0,0,0,1,48,16,0,112,212,3,0,22,0,0,0,1,48,0,0,248,160,5,0,0,0,0,0,254,0,4,0,128,129,4,0,22,0,0,0,1,192,128,0,208,75,4,0,22,0,0,0,1,192,192,0,8,49,4,0,22,0,0,0,1,192,64,0,152,21,4,0,22,0,0,0,1,192,0,0,72,246,3,0,184,40,2,0,1,0,0,0,208,155,215,0,248,191,2,0,56,250,6,0,1,0,0,0,212,155,215,0,184,160,2,0,184,164,8,0,1,0,0,0,209,155,215,0,64,246,1,0,88,149,7,0,1,0,0,0,213,155,215,0,136,224,1,0,104,28,8,0,1,0,0,0,215,155,215,0,232,209,1,0,248,23,7,0,1,0,0,0,214,155,215,0,144,189,1,0,120,138,2,0,1,0,0,0,201,155,215,0,192,135,2,0,56,136,2,0,1,0,0,0,200,155,215,0,240,108,2,0,32,135,2,0,1,0,0,0,203,155,215,0,96,82,2,0,152,134,2,0,1,0,0,0,202,155,215,0,32,56,2,0,192,133,2,0,1,0,0,0,205,155,215,0,24,133,2,0,96,132,2,0,1,0,0,0,204,155,215,0,144,131,2,0,200,130,2,0,1,0,0,0,207,155,215,0,72,129,2,0,32,127,2,0,1,0,0,0,206,155,215,0,192,123,2,0,208,122,2,0,1,0,0,0,193,155,215,0,72,198,1,0,48,122,2,0,1,0,0,0,192,155,215,0,24,182,1,0,112,121,2,0,1,0,0,0,195,155,215,0,40,167,1,0,208,120,2,0,1,0,0,0,194,155,215,0,200,149,1,0,24,120,2,0,1,0,0,0,197,155,215,0,184,118,2,0,152,116,2,0,1,0,0,0,196,155,215,0,32,114,2,0,128,112,2,0,1,0,0,0,199,155,215,0,192,109,2,0,40,108,2,0,1,0,0,0,198,155,215,0,176,107,2,0,192,106,2,0,1,0,0,0,185,155,215,0,208,174,1,0,208,105,2,0,1,0,0,0,184,155,215,0,48,160,1,0,24,105,2,0,1,0,0,0,187,155,215,0,160,140,1,0,112,104,2,0,1,0,0,0,186,155,215,0,56,112,1,0,56,103,2,0,1,0,0,0,189,155,215,0,128,102,2,0,0,101,2,0,1,0,0,0,188,155,215,0,224,98,2,0,56,98,2,0,1,0,0,0,191,155,215,0,40,97,2,0,56,96,2,0,1,0,0,0,190,155,215,0,224,94,2,0,16,17,8,0,1,0,0,0,211,155,215,0,224,12,8,0,32,77,1,0,1,0,0,0,210,155,215,0,216,70,1,0,88,212,3,0,1,0,0,0,200,154,215,0,40,185,3,0,248,5,8,0,9,0,0,0,0,156,215,0,32,58,1,0,144,250,7,0,9,0,0,0,1,156,215,0,32,58,1,0,49,49,46,117,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,111,126,29,191,0,0,16,1,49,50,46,117,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,168,59,48,135,0,0,16,1,49,46,117,49,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,195,248,101,235,0,0,16,1,55,46,117,50,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,23,197,227,149,0,0,32,0,56,46,117,49,56,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,171,119,35,254,0,0,32,0,51,46,117,49,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,95,67,220,22,0,0,32,0,52,46,117,56,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,151,191,227,79,0,0,32,0,54,46,117,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,127,239,138,7,0,0,32,0,53,46,117,55,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,144,250,80,246,0,0,32,0,57,46,117,52,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,251,136,97,12,0,0,32,0,49,48,46,117,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,248,63,56,45,0,0,32,0,50,46,117,55,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,172,29,238,54,0,0,64,0,112,114,111,109,49,46,117,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,94,131,36,195,0,0,32,0,112,114,111,109,52,46,117,55,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,244,110,80,230,0,0,32,0,112,114,111,109,51,46,117,56,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,79,9,61,180,0,0,32,0,112,114,111,109,50,46,117,57,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,105,136,170,224,0,0,32,0,112,97,108,49,54,108,56,46,117,49,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,0,0,32,16,112,97,108,49,54,108,56,46,117,49,53,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,0,0,32,16,112,97,108,49,54,108,56,46,117,52,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,0,0,32,16,17,0,0,0,255,255,47,0,0,0,0,0,18,0,0,0,255,255,255,0,0,0,0,0,19,0,0,0,255,255,127,0,0,0,0,0,0,0,0,0,254,0,2,0,232,75,4,0,17,0,0,0,1,1,1,0,96,135,7,0,17,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,12,0,200,87,7,0,18,0,0,0,1,15,4,0,144,102,8,0,18,0,0,0,1,15,7,0,176,45,8,0,18,0,0,0,1,15,0,0,144,55,5,0,18,0,0,0,1,15,10,0,224,127,8,0,18,0,0,0,1,15,6,0,136,252,1,0,18,0,0,0,1,15,3,0,0,67,1,0,18,0,0,0,1,15,15,0,32,123,8,0,18,0,0,0,1,15,5,0,120,205,1,0,18,0,0,0,1,15,14,0,192,110,8,0,18,0,0,0,1,15,13,0,96,102,7,0,18,0,0,0,1,15,12,0,184,105,6,0,18,0,0,0,1,15,11,0,152,96,3,0,0,0,0,0,254,0,12,0,160,123,6,0,18,0,0,0,1,240,64,0,144,102,8,0,18,0,0,0,1,240,112,0,176,45,8,0,18,0,0,0,1,240,0,0,144,55,5,0,18,0,0,0,1,240,160,0,224,127,8,0,18,0,0,0,1,240,96,0,136,252,1,0,18,0,0,0,1,240,48,0,0,67,1,0,18,0,0,0,1,240,240,0,32,123,8,0,18,0,0,0,1,240,80,0,120,205,1,0,18,0,0,0,1,240,224,0,192,110,8,0,18,0,0,0,1,240,208,0,96,102,7,0,18,0,0,0,1,240,192,0,184,105,6,0,18,0,0,0,1,240,176,0,152,96,3,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,1,1,0,96,135,7,0,19,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,19,0,0,0,1,6,6,0,208,75,4,0,19,0,0,0,1,6,4,0,8,49,4,0,19,0,0,0,1,6,2,0,152,21,4,0,19,0,0,0,1,6,0,0,72,246,3,0,0,0,0,0,254,0,4,0,72,202,5,0,19,0,0,0,1,24,24,0,248,38,7,0,19,0,0,0,1,24,8,0,80,124,6,0,19,0,0,0,1,24,16,0,112,212,3,0,19,0,0,0,1,24,0,0,216,13,3,0,0,0,0,0,254,0,2,0,200,30,2,0,19,0,0,0,1,32,32,0,120,97,1,0,19,0,0,0,1,32,0,0,96,19,1,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,64,0,0,96,135,7,0,19,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,19,0,0,0,1,128,128,0,96,135,7,0,19,0,0,0,1,128,0,0,152,182,7,0,108,99,97,118,101,48,54,95,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,25,194,92,24,0,0,16,1,108,99,97,118,101,48,53,95,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,243,45,176,182,0,0,16,1,108,99,97,118,101,48,56,95,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,98,78,209,197,0,0,16,1,97,55,56,45,48,55,46,52,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,232,38,154,79,0,0,16,1,97,55,56,45,48,49,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,61,181,191,177,0,0,16,1,108,99,97,118,101,48,57,95,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,239,126,11,185,0,0,32,0,108,99,97,118,101,49,48,95,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,5,47,178,79,0,0,32,0,97,55,56,45,49,49,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,18,229,115,151,0,0,32,0,108,99,97,118,101,49,50,95,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,158,180,158,228,0,0,32,0,108,99,97,118,101,49,51,95,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,52,151,145,97,0,0,32,0,108,99,97,118,101,49,52,95,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,189,19,58,126,0,0,32,0,108,99,97,118,101,49,53,95,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,58,199,83,194,0,0,32,0,108,99,97,118,101,49,54,95,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,238,146,108,230,0,0,32,0,97,55,56,45,49,55,46,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,213,98,151,214,0,0,32,0,108,99,97,118,101,49,56,95,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,68,37,238,71,0,0,32,0,108,99,97,118,101,49,57,95,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,250,177,238,28,0,0,32,0,108,99,97,118,101,50,48,95,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,36,46,50,100,0,0,32,0,97,55,49,45,50,53,46,52,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,69,133,15,45,0,0,32,0,97,55,56,45,50,53,46,53,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,157,28,144,45,0,0,16,1,97,55,56,45,50,52,46,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,196,237,175,183,0,0,16,1,97,55,56,45,48,56,46,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,123,160,17,174,0,0,16,1,97,55,56,45,48,55,46,52,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,232,38,154,79,0,0,16,1,97,55,56,45,48,49,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,61,181,191,177,0,0,16,1,97,55,56,45,48,57,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,34,140,53,32,0,0,32,0,97,55,56,45,49,48,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,169,104,1,147,0,0,32,0,97,55,56,45,49,49,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,18,229,115,151,0,0,32,0,97,55,56,45,49,50,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,155,84,69,208,0,0,32,0,97,55,56,45,49,51,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,197,53,175,208,0,0,32,0,97,55,56,45,49,52,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,168,105,83,123,0,0,32,0,97,55,56,45,49,53,46,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,19,164,97,107,0,0,32,0,97,55,56,45,49,54,46,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,151,45,73,181,0,0,32,0,97,55,56,45,49,55,46,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,213,98,151,214,0,0,32,0,97,55,56,45,49,56,46,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,104,59,36,159,0,0,32,0,97,55,56,45,49,57,46,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,140,67,233,102,0,0,32,0,97,55,56,45,50,48,46,51,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,173,99,248,158,0,0,32,0,97,55,49,45,50,53,46,52,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,69,133,15,45,0,0,32,0,112,97,108,49,54,108,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,24,112,97,108,49,54,108,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,24,112,97,108,49,54,114,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,24,97,55,56,45,48,54,45,49,46,53,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,182,52,121,86,0,0,16,1,97,55,56,45,48,53,45,49,46,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,66,226,142,159,0,0,16,1,97,55,56,45,48,56,46,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,123,160,17,174,0,0,16,1,97,55,56,45,48,55,46,52,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,232,38,154,79,0,0,16,1,97,55,56,45,48,49,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,61,181,191,177,0,0,16,1,97,55,56,45,48,57,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,34,140,53,32,0,0,32,0,97,55,56,45,49,48,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,169,104,1,147,0,0,32,0,97,55,56,45,49,49,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,18,229,115,151,0,0,32,0,97,55,56,45,49,50,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,155,84,69,208,0,0,32,0,97,55,56,45,49,51,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,197,53,175,208,0,0,32,0,97,55,56,45,49,52,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,168,105,83,123,0,0,32,0,97,55,56,45,49,53,46,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,19,164,97,107,0,0,32,0,97,55,56,45,49,54,46,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,151,45,73,181,0,0,32,0,97,55,56,45,49,55,46,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,213,98,151,214,0,0,32,0,97,55,56,45,49,56,46,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,104,59,36,159,0,0,32,0,97,55,56,45,49,57,46,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,140,67,233,102,0,0,32,0,97,55,56,45,50,48,46,51,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,173,99,248,158,0,0,32,0,97,55,49,45,50,53,46,52,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,69,133,15,45,0,0,32,0,112,97,108,49,54,108,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,24,112,97,108,49,54,108,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,24,112,97,108,49,54,114,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,24,15,0,0,0,255,255,254,0,0,0,0,0,16,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,128,156,8,0,15,0,0,0,1,5,4,0,240,149,8,0,15,0,0,0,1,5,5,0,0,144,8,0,15,0,0,0,1,5,1,0,232,138,8,0,15,0,0,0,1,5,0,0,128,76,7,0,0,0,0,0,254,0,2,0,144,212,8,0,15,0,0,0,1,2,2,0,96,135,7,0,15,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,15,0,0,0,1,8,0,0,96,135,7,0,15,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,15,0,0,0,1,48,16,0,224,127,8,0,15,0,0,0,1,48,48,0,32,123,8,0,15,0,0,0,1,48,0,0,248,116,8,0,15,0,0,0,1,48,32,0,192,110,8,0,0,0,0,0,254,0,4,0,160,123,6,0,15,0,0,0,1,192,64,0,224,127,8,0,15,0,0,0,1,192,192,0,32,123,8,0,15,0,0,0,1,192,0,0,248,116,8,0,15,0,0,0,1,192,128,0,192,110,8,0,0,0,0,0,254,0,4,0,72,202,5,0,16,0,0,0,1,3,2,0,80,246,3,0,16,0,0,0,1,3,3,0,248,38,7,0,16,0,0,0,1,3,1,0,112,212,3,0,16,0,0,0,1,3,0,0,24,99,5,0,0,0,0,0,254,0,4,0,64,37,5,0,16,0,0,0,1,12,8,0,24,71,8,0,16,0,0,0,1,12,12,0,128,68,8,0,16,0,0,0,1,12,4,0,0,65,8,0,16,0,0,0,1,12,0,0,184,59,8,0,0,0,0,0,254,0,4,0,128,129,4,0,16,0,0,0,1,48,16,0,192,255,2,0,16,0,0,0,1,48,0,0,208,75,4,0,16,0,0,0,1,48,48,0,8,49,4,0,16,0,0,0,1,48,32,0,72,246,3,0,0,0,0,0,254,0,2,0,8,73,7,0,16,0,0,0,1,128,128,0,64,68,7,0,16,0,0,0,1,128,0,0,8,64,7,0,0,0,0,0,97,55,56,45,48,54,46,53,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,91,48,200,50,0,0,16,1,97,55,56,45,48,53,46,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,110,188,244,83,0,0,16,1,97,55,56,45,48,56,46,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,123,160,17,174,0,0,16,1,97,55,56,45,48,55,46,52,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,232,38,154,79,0,0,16,1,97,55,56,45,48,49,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,61,181,191,177,0,0,16,1,97,55,56,45,48,57,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,34,140,53,32,0,0,32,0,97,55,56,45,49,48,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,169,104,1,147,0,0,32,0,97,55,56,45,49,49,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,18,229,115,151,0,0,32,0,97,55,56,45,49,50,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,155,84,69,208,0,0,32,0,97,55,56,45,49,51,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,197,53,175,208,0,0,32,0,97,55,56,45,49,52,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,168,105,83,123,0,0,32,0,97,55,56,45,49,53,46,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,19,164,97,107,0,0,32,0,97,55,56,45,49,54,46,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,151,45,73,181,0,0,32,0,97,55,56,45,49,55,46,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,213,98,151,214,0,0,32,0,97,55,56,45,49,56,46,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,104,59,36,159,0,0,32,0,97,55,56,45,49,57,46,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,140,67,233,102,0,0,32,0,97,55,56,45,50,48,46,51,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,173,99,248,158,0,0,32,0,97,55,49,45,50,53,46,52,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,69,133,15,45,0,0,32,0,112,97,108,49,54,108,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,24,112,97,108,49,54,108,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,24,112,97,108,49,54,114,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,24,18,0,0,0,255,255,255,0,0,0,0,0,19,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,72,202,5,0,18,0,0,0,1,12,8,0,80,246,3,0,18,0,0,0,1,12,12,0,248,38,7,0,18,0,0,0,1,12,4,0,112,212,3,0,18,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,4,0,152,189,5,0,18,0,0,0,1,192,128,0,184,185,5,0,18,0,0,0,1,192,192,0,208,182,5,0,18,0,0,0,1,192,64,0,32,179,5,0,18,0,0,0,1,192,0,0,128,172,5,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,2,0,0,96,135,7,0,19,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,7,0,160,123,6,0,19,0,0,0,1,28,16,0,32,136,7,0,19,0,0,0,1,28,8,0,40,88,7,0,19,0,0,0,1,28,24,0,96,39,7,0,19,0,0,0,1,28,28,0,144,251,6,0,19,0,0,0,1,28,12,0,184,164,6,0,19,0,0,0,1,28,20,0,80,74,6,0,19,0,0,0,1,28,4,0,192,32,6,0,0,0,0,0,254,0,7,0,200,87,7,0,19,0,0,0,1,224,128,0,32,136,7,0,19,0,0,0,1,224,64,0,40,88,7,0,19,0,0,0,1,224,192,0,96,39,7,0,19,0,0,0,1,224,224,0,144,251,6,0,19,0,0,0,1,224,96,0,184,164,6,0,19,0,0,0,1,224,160,0,80,74,6,0,19,0,0,0,1,224,32,0,192,32,6,0,0,0,0,0,97,55,56,45,48,54,46,53,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,91,48,200,50,0,0,16,1,97,55,56,45,50,49,46,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,61,3,68,40,0,0,16,1,97,55,56,45,48,56,46,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,123,160,17,174,0,0,16,1,97,55,56,45,48,55,46,52,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,232,38,154,79,0,0,16,1,97,55,56,45,48,49,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,61,181,191,177,0,0,16,1,97,55,56,45,48,57,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,34,140,53,32,0,0,32,0,97,55,56,45,49,48,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,169,104,1,147,0,0,32,0,97,55,56,45,49,49,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,18,229,115,151,0,0,32,0,97,55,56,45,49,50,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,155,84,69,208,0,0,32,0,97,55,56,45,49,51,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,197,53,175,208,0,0,32,0,97,55,56,45,49,52,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,168,105,83,123,0,0,32,0,97,55,56,45,49,53,46,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,19,164,97,107,0,0,32,0])
.concat([97,55,56,45,49,54,46,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,151,45,73,181,0,0,32,0,97,55,56,45,49,55,46,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,213,98,151,214,0,0,32,0,97,55,56,45,49,56,46,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,104,59,36,159,0,0,32,0,97,55,56,45,49,57,46,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,140,67,233,102,0,0,32,0,97,55,56,45,50,48,46,51,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,173,99,248,158,0,0,32,0,97,55,49,45,50,53,46,52,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,69,133,15,45,0,0,32,0,112,97,108,49,54,108,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,24,112,97,108,49,54,108,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,24,112,97,108,49,54,114,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,24,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,91,48,200,50,0,0,16,1,51,45,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,21,38,12,152,0,0,16,1,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,242,152,198,230,0,0,16,1,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,123,160,17,174,0,0,16,1,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,232,38,154,79,0,0,16,1,97,55,56,45,48,57,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,34,140,53,32,0,0,32,0,97,55,56,45,49,48,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,169,104,1,147,0,0,32,0,97,55,56,45,49,49,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,18,229,115,151,0,0,32,0,97,55,56,45,49,50,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,155,84,69,208,0,0,32,0,97,55,56,45,49,51,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,197,53,175,208,0,0,32,0,97,55,56,45,49,52,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,168,105,83,123,0,0,32,0,97,55,56,45,49,53,46,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,19,164,97,107,0,0,32,0,97,55,56,45,49,54,46,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,151,45,73,181,0,0,32,0,97,55,56,45,49,55,46,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,213,98,151,214,0,0,32,0,97,55,56,45,49,56,46,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,104,59,36,159,0,0,32,0,97,55,56,45,49,57,46,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,140,67,233,102,0,0,32,0,97,55,56,45,50,48,46,51,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,173,99,248,158,0,0,32,0,97,55,49,45,50,53,46,52,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,69,133,15,45,0,0,32,0,54,56,55,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,53,166,202,120,0,0,16,1,184,40,2,0,1,0,0,0,137,151,215,0,248,191,2,0,56,250,6,0,1,0,0,0,120,151,215,0,184,160,2,0,184,164,8,0,1,0,0,0,136,151,215,0,64,246,1,0,88,149,7,0,1,0,0,0,121,151,215,0,136,224,1,0,88,62,6,0,4,0,0,0,104,150,215,0,208,13,4,0,120,59,6,0,4,0,0,0,96,150,215,0,184,198,5,0,176,108,2,0,1,0,0,0,126,151,215,0,152,30,2,0,128,98,2,0,1,0,0,0,127,151,215,0,232,10,2,0,88,212,3,0,1,0,0,0,200,147,215,0,40,185,3,0,16,17,8,0,1,0,0,0,138,151,215,0,224,12,8,0,56,58,1,0,1,0,0,0,139,151,215,0,64,50,1,0,248,5,8,0,9,0,0,0,152,151,215,0,32,58,1,0,144,250,7,0,9,0,0,0,153,151,215,0,32,58,1,0,102,119,45,49,53,45,50,46,49,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,103,169,25,202,0,0,16,1,102,119,45,49,50,45,50,46,57,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,42,220,43,36,0,0,16,1,102,119,45,49,54,45,50,46,49,57,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,101,114,33,183,0,0,16,1,102,119,45,49,51,45,50,46,49,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,244,158,32,25,0,0,16,1,102,119,45,49,55,45,50,46,50,48,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,161,50,166,120,0,0,16,1,102,119,45,49,52,45,50,46,49,51,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,45,17,182,105,0,0,16,1,102,110,45,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,231,6,65,199,0,0,16,1,102,110,45,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,96,167,245,64,0,0,32,0,102,110,45,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,104,33,79,130,0,0,32,0,102,110,45,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,179,163,198,234,0,0,32,0,102,110,45,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,146,226,238,63,0,0,32,0,102,110,45,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,210,123,178,194,0,0,32,0,102,110,45,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,120,113,201,90,0,0,32,0,102,110,45,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,27,18,51,147,0,0,32,0,102,110,45,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,15,166,75,37,0,0,32,0,102,110,45,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,152,208,24,236,0,0,32,0,102,110,45,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,186,12,6,79,0,0,32,0,102,110,45,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,217,216,15,153,0,0,64,0,116,97,45,49,54,46,50,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,212,232,38,173,0,0,0,8,20,0,0,0,255,255,127,0,0,0,0,0,21,0,0,0,255,255,127,0,0,0,0,0,0,0,0,0,254,0,8,0,200,87,7,0,20,0,0,0,1,7,0,0,176,45,8,0,20,0,0,0,1,7,1,0,224,127,8,0,20,0,0,0,1,7,7,0,32,123,8,0,20,0,0,0,1,7,6,0,192,110,8,0,20,0,0,0,1,7,5,0,96,102,7,0,20,0,0,0,1,7,4,0,184,105,6,0,20,0,0,0,1,7,3,0,152,96,3,0,20,0,0,0,1,7,2,0,192,100,6,0,0,0,0,0,254,0,8,0,160,123,6,0,20,0,0,0,1,56,0,0,176,45,8,0,20,0,0,0,1,56,8,0,224,127,8,0,20,0,0,0,1,56,56,0,32,123,8,0,20,0,0,0,1,56,48,0,192,110,8,0,20,0,0,0,1,56,40,0,96,102,7,0,20,0,0,0,1,56,32,0,184,105,6,0,20,0,0,0,1,56,24,0,152,96,3,0,20,0,0,0,1,56,16,0,192,100,6,0,0,0,0,0,254,0,2,0,144,212,8,0,20,0,0,0,1,64,64,0,96,135,7,0,20,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,200,30,2,0,20,0,0,0,1,128,0,0,120,97,1,0,20,0,0,0,1,128,128,0,96,19,1,0,0,0,0,0,254,0,4,0,128,129,4,0,21,0,0,0,1,3,0,0,208,75,4,0,21,0,0,0,1,3,3,0,8,49,4,0,21,0,0,0,1,3,2,0,152,21,4,0,21,0,0,0,1,3,1,0,72,246,3,0,0,0,0,0,254,0,4,0,72,202,5,0,21,0,0,0,1,12,8,0,80,246,3,0,21,0,0,0,1,12,12,0,248,38,7,0,21,0,0,0,1,12,4,0,112,212,3,0,21,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,2,0,216,102,7,0,21,0,0,0,1,32,32,0,32,96,7,0,21,0,0,0,1,32,0,0,160,89,7,0,0,0,0,0,254,0,2,0,192,125,6,0,21,0,0,0,1,64,0,0,56,111,3,0,21,0,0,0,1,64,64,0,104,134,3,0,0,0,0,0,254,0,2,0,168,234,7,0,21,0,0,0,1,32,128,0,96,135,7,0,21,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,21,0,0,0,255,255,127,0,0,0,0,0,0,0,0,0,254,0,8,0,200,87,7,0,20,0,0,0,1,7,0,0,40,88,7,0,20,0,0,0,1,7,1,0,96,39,7,0,20,0,0,0,1,7,7,0,144,251,6,0,20,0,0,0,1,7,6,0,184,164,6,0,20,0,0,0,1,7,5,0,80,74,6,0,20,0,0,0,1,7,4,0,192,32,6,0,20,0,0,0,1,7,3,0,192,234,2,0,20,0,0,0,1,7,2,0,32,242,5,0,0,0,0,0,254,0,8,0,160,123,6,0,20,0,0,0,1,56,0,0,40,88,7,0,20,0,0,0,1,56,8,0,96,39,7,0,20,0,0,0,1,56,56,0,144,251,6,0,20,0,0,0,1,56,48,0,184,164,6,0,20,0,0,0,1,56,40,0,80,74,6,0,20,0,0,0,1,56,32,0,192,32,6,0,20,0,0,0,1,56,24,0,192,234,2,0,20,0,0,0,1,56,16,0,32,242,5,0,0,0,0,0,254,0,2,0,144,212,8,0,20,0,0,0,1,64,64,0,96,135,7,0,20,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,56,180,7,0,20,0,0,0,1,128,128,0,16,159,5,0,20,0,0,0,1,128,0,0,144,126,5,0,0,0,0,0,254,0,4,0,128,129,4,0,21,0,0,0,1,3,1,0,192,255,2,0,21,0,0,0,1,3,3,0,208,75,4,0,21,0,0,0,1,3,2,0,8,49,4,0,21,0,0,0,1,3,0,0,152,21,4,0,0,0,0,0,254,0,4,0,72,202,5,0,21,0,0,0,1,12,8,0,80,246,3,0,21,0,0,0,1,12,12,0,248,38,7,0,21,0,0,0,1,12,4,0,112,212,3,0,21,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,2,0,88,160,1,0,21,0,0,0,1,16,16,0,136,86,1,0,21,0,0,0,1,16,0,0,232,78,1,0,0,0,0,0,254,0,2,0,184,211,3,0,21,0,0,0,1,32,32,0,32,184,3,0,21,0,0,0,1,32,0,0,128,158,3,0,0,0,0,0,254,0,2,0,168,234,7,0,21,0,0,0,1,128,128,0,96,135,7,0,21,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,49,45,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,199,25,102,120,0,0,16,1,49,45,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,91,71,187,59,0,0,16,1,49,45,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,80,12,92,55,0,0,16,1,49,45,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,187,82,125,238,0,0,16,1,49,45,105,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,129,59,205,73,0,0,16,1,49,45,106,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,56,169,234,193,0,0,16,1,49,45,107,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,2,199,43,10,0,0,16,1,49,45,112,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,204,119,75,16,0,0,32,0,49,45,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,16,174,37,218,0,0,32,0,49,45,102,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,33,67,110,97,0,0,32,0,49,45,103,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,226,43,125,140,0,0,32,0,49,45,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,2,107,6,160,0,0,32,0,49,45,108,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,122,160,202,163,0,0,32,0,49,45,109,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,223,203,182,21,0,0,32,0,49,45,110,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,122,116,0,227,0,0,32,0,49,45,111,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,108,106,220,205,0,0,32,0,107,105,100,95,112,114,111,109,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,35,206,19,202,0,0,32,0,107,105,100,95,112,114,111,109,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,90,40,68,251,0,0,32,0,107,105,100,95,112,114,111,109,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,55,18,212,64,0,0,32,0,107,105,100,95,112,114,111,109,46,50,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,237,224,155,75,0,0,32,0,107,105,100,95,112,114,111,109,46,52,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,238,84,251,228,0,0,32,0,19,0,0,0,255,255,254,0,0,0,0,0,20,0,0,0,255,255,188,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,19,0,0,0,1,1,0,0,120,97,1,0,19,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,2,2,0,96,135,7,0,19,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,4,4,0,96,135,7,0,19,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,8,0,0,96,135,7,0,19,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,19,0,0,0,1,48,0,0,32,136,7,0,19,0,0,0,1,48,16,0,40,88,7,0,19,0,0,0,1,48,32,0,96,39,7,0,19,0,0,0,1,48,48,0,144,251,6,0,0,0,0,0,254,0,4,0,160,123,6,0,19,0,0,0,1,192,192,0,184,164,6,0,19,0,0,0,1,192,128,0,80,74,6,0,19,0,0,0,1,192,64,0,192,32,6,0,19,0,0,0,1,192,0,0,32,242,5,0,0,0,0,0,254,0,4,0,64,37,5,0,20,0,0,0,1,12,8,0,136,136,2,0,20,0,0,0,1,12,12,0,152,126,7,0,20,0,0,0,1,12,4,0,40,110,2,0,20,0,0,0,1,12,0,0,88,99,2,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,48,32,0,208,75,4,0,20,0,0,0,1,48,48,0,8,49,4,0,20,0,0,0,1,48,16,0,152,21,4,0,20,0,0,0,1,48,0,0,72,246,3,0,0,0,0,0,254,0,2,0,104,159,3,0,20,0,0,0,1,64,64,0,56,111,3,0,20,0,0,0,1,64,0,0,104,134,3,0,0,0,0,0,18,0,0,0,255,255,175,0,0,0,0,0,19,0,0,0,255,255,249,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,18,0,0,0,1,3,2,0,208,75,4,0,18,0,0,0,1,3,3,0,8,49,4,0,18,0,0,0,1,3,1,0,152,21,4,0,18,0,0,0,1,3,0,0,72,246,3,0,0,0,0,0,254,0,4,0,72,202,5,0,18,0,0,0,1,12,8,0,80,246,3,0,18,0,0,0,1,12,12,0,80,124,6,0,18,0,0,0,1,12,4,0,112,212,3,0,18,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,2,0,104,159,3,0,18,0,0,0,1,32,0,0,56,111,3,0,18,0,0,0,1,32,32,0,104,134,3,0,0,0,0,0,254,0,2,0,168,234,7,0,18,0,0,0,1,64,64,0,96,135,7,0,18,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,18,0,0,0,1,128,128,0,96,135,7,0,18,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,1,1,0,96,135,7,0,19,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,96,46,8,0,19,0,0,0,1,8,8,0,192,255,2,0,19,0,0,0,1,8,0,0,208,75,4,0,0,0,0,0,254,0,16,0,32,4,2,0,19,0,0,0,1,240,160,0,144,160,3,0,19,0,0,0,1,240,176,0,96,135,3,0,19,0,0,0,1,240,192,0,32,136,7,0,19,0,0,0,1,240,208,0,40,88,7,0,19,0,0,0,1,240,224,0,96,39,7,0,19,0,0,0,1,240,16,0,32,202,2,0,19,0,0,0,1,240,48,0,120,113,6,0,19,0,0,0,1,240,32,0,232,228,5,0,19,0,0,0,1,240,240,0,144,251,6,0,19,0,0,0,1,240,64,0,120,211,6,0,19,0,0,0,1,240,144,0,184,164,6,0,19,0,0,0,1,240,128,0,80,74,6,0,19,0,0,0,1,240,112,0,192,32,6,0,19,0,0,0,1,240,96,0,192,234,2,0,19,0,0,0,1,240,80,0,32,242,5,0,19,0,0,0,1,240,0,0,16,227,4,0,18,0,0,0,255,255,159,0,0,0,0,0,19,0,0,0,255,255,175,0,0,0,0,0,0,0,0,0,254,0,8,0,32,4,2,0,18,0,0,0,1,7,2,0,40,88,7,0,18,0,0,0,1,7,4,0,96,39,7,0,18,0,0,0,1,7,1,0,120,113,6,0,18,0,0,0,1,7,7,0,144,251,6,0,18,0,0,0,1,7,3,0,120,211,6,0,18,0,0,0,1,7,6,0,184,164,6,0,18,0,0,0,1,7,5,0,80,74,6,0,18,0,0,0,1,7,0,0,16,227,4,0,0,0,0,0,254,0,4,0,72,202,5,0,18,0,0,0,1,24,16,0,80,246,3,0,18,0,0,0,1,24,24,0,248,38,7,0,18,0,0,0,1,24,8,0,112,212,3,0,18,0,0,0,1,24,0,0,24,99,5,0,0,0,0,0,254,0,2,0,72,12,5,0,18,0,0,0,1,32,32,0,208,75,4,0,18,0,0,0,1,32,0,0,8,49,4,0,0,0,0,0,254,0,2,0,168,234,7,0,18,0,0,0,1,64,64,0,96,135,7,0,18,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,18,0,0,0,1,128,128,0,96,135,7,0,18,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,19,0,0,0,1,3,0,0,208,75,4,0,19,0,0,0,1,3,3,0,8,49,4,0,19,0,0,0,1,3,2,0,152,21,4,0,19,0,0,0])
.concat([1,3,1,0,72,246,3,0,48,57,95,106,48,49,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,48,220,104,198,0,0,16,1,49,48,95,108,48,49,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,251,229,161,82,0,0,16,1,49,49,95,109,48,49,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,42,6,138,182,0,0,16,1,49,50,95,110,48,49,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,229,206,62,29,0,0,16,1,49,51,46,49,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,77,36,224,112,0,0,16,1,48,51,95,101,48,56,116,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,213,112,4,159,0,0,32,0,48,52,95,104,48,56,116,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,230,18,236,129,0,0,32,0,48,53,95,107,48,56,116,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,177,200,126,232,0,0,32,0,49,52,95,106,48,55,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,141,133,28,16,0,0,32,0,49,53,95,108,48,55,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,242,88,63,1,0,0,32,0,49,54,95,109,48,55,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,151,64,105,148,0,0,32,0,48,54,95,108,48,56,116,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,137,189,238,81,0,0,32,0,48,55,95,110,48,56,116,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,157,142,217,157,0,0,32,0,48,56,95,114,48,56,116,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,125,238,85,49,0,0,32,0,48,50,95,112,48,52,116,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,2,74,141,57,0,0,32,0,48,49,95,104,48,51,116,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,125,145,7,132,0,0,64,1,48,57,95,106,48,49,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,48,220,104,198,0,0,16,1,49,48,95,108,48,49,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,251,229,161,82,0,0,16,1,49,49,95,109,48,49,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,42,6,138,182,0,0,16,1,49,50,95,110,48,49,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,229,206,62,29,0,0,16,1,49,51,95,114,48,49,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,41,221,175,188,0,0,16,1,48,51,95,101,48,56,116,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,213,112,4,159,0,0,32,0,48,52,95,104,48,56,116,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,230,18,236,129,0,0,32,0,48,53,95,107,48,56,116,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,177,200,126,232,0,0,32,0,49,52,95,106,48,55,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,141,133,28,16,0,0,32,0,49,53,95,108,48,55,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,242,88,63,1,0,0,32,0,49,54,95,109,48,55,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,151,64,105,148,0,0,32,0,48,54,95,108,48,56,116,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,137,189,238,81,0,0,32,0,48,55,95,110,48,56,116,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,157,142,217,157,0,0,32,0,48,56,95,114,48,56,116,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,125,238,85,49,0,0,32,0,48,50,95,112,48,52,116,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,2,74,141,57,0,0,32,0,48,49,95,104,48,51,116,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,125,145,7,132,0,0,64,1,101,112,114,45,49,48,48,54,54,46,98,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,144,50,213,108,1,0,16,1,101,112,114,45,49,48,48,54,51,46,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,22,154,132,221,1,0,16,1,101,112,114,45,49,48,48,54,55,46,98,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,206,165,34,219,1,0,16,1,101,112,114,45,49,48,48,54,52,46,98,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,224,183,214,83,1,0,16,1,101,112,114,45,49,48,48,54,56,46,98,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,101,198,204,21,1,0,16,1,101,112,114,45,49,48,48,54,53,46,98,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,20,163,95,14,1,0,16,1,101,112,114,45,49,48,51,50,49,46,99,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,186,124,62,205,2,0,32,0,101,112,114,45,49,48,51,50,50,46,99,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,23,50,61,181,2,0,32,0,101,112,114,45,49,48,51,50,51,46,99,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,97,62,90,145,2,0,32,0,101,112,114,45,49,48,48,49,50,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,232,36,8,153,3,0,32,0,101,112,114,45,49,48,48,49,54,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,47,199,93,175,3,0,32,0,101,112,114,45,49,48,48,49,51,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,197,25,9,154,3,0,32,0,101,112,114,45,49,48,48,49,55,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,149,253,170,98,3,0,32,0,101,112,114,45,49,48,48,50,55,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,199,87,28,63,3,0,32,0,101,112,114,45,49,48,48,50,56,46,98,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,109,148,212,128,3,0,32,0,101,112,114,45,49,48,48,49,53,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,106,59,45,88,3,0,32,0,101,112,114,45,49,48,48,49,57,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,139,195,32,224,3,0,32,0,101,112,114,45,49,48,48,50,54,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,184,105,59,18,4,0,16,1,55,55,53,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,252,52,149,106,6,0,16,1,101,112,114,45,49,48,48,50,57,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,131,202,74,126,7,0,64,0,101,112,114,45,49,48,48,51,48,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,11,223,193,220,7,0,64,0,101,112,114,45,49,48,48,51,49,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,114,68,60,234,7,0,64,0,101,112,114,45,49,48,48,51,50,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,206,235,171,10,7,0,64,0,51,49,55,45,48,48,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,226,105,56,131,0,0,16,8,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,252,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,19,0,0,0,1,15,7,0,80,252,6,0,19,0,0,0,1,15,8,0,16,242,7,0,19,0,0,0,1,15,9,0,104,236,7,0,19,0,0,0,1,15,5,0,176,51,4,0,19,0,0,0,1,15,4,0,56,24,4,0,19,0,0,0,1,15,15,0,128,230,7,0,19,0,0,0,1,15,1,0,72,216,3,0,19,0,0,0,1,15,2,0,24,188,3,0,19,0,0,0,1,15,3,0,176,162,3,0,19,0,0,0,1,15,6,0,120,211,6,0,19,0,0,0,1,15,14,0,184,164,6,0,19,0,0,0,1,15,13,0,80,74,6,0,19,0,0,0,1,15,12,0,192,32,6,0,19,0,0,0,1,15,11,0,192,234,2,0,19,0,0,0,1,15,10,0,32,242,5,0,19,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,19,0,0,0,1,240,112,0,80,252,6,0,19,0,0,0,1,240,128,0,16,242,7,0,19,0,0,0,1,240,144,0,104,236,7,0,19,0,0,0,1,240,80,0,176,51,4,0,19,0,0,0,1,240,64,0,56,24,4,0,19,0,0,0,1,240,240,0,128,230,7,0,19,0,0,0,1,240,16,0,72,216,3,0,19,0,0,0,1,240,32,0,24,188,3,0,19,0,0,0,1,240,48,0,176,162,3,0,19,0,0,0,1,240,96,0,120,211,6,0,19,0,0,0,1,240,224,0,184,164,6,0,19,0,0,0,1,240,208,0,80,74,6,0,19,0,0,0,1,240,192,0,192,32,6,0,19,0,0,0,1,240,176,0,192,234,2,0,19,0,0,0,1,240,160,0,32,242,5,0,19,0,0,0,1,240,0,0,208,236,2,0,0,0,0,0,254,0,2,0,168,234,7,0,20,0,0,0,1,2,2,0,96,135,7,0,20,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,98,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,54,25,248,1,0,0,16,1,98,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,177,142,17,19,0,0,16,1,98,98,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,216,153,218,175,0,0,16,1,97,55,56,45,48,56,46,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,123,160,17,174,0,0,16,1,97,55,56,45,48,55,46,52,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,232,38,154,79,0,0,16,1,97,55,56,45,48,57,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,34,140,53,32,0,0,32,0,97,55,56,45,49,48,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,169,104,1,147,0,0,32,0,97,55,56,45,49,49,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,18,229,115,151,0,0,32,0,97,55,56,45,49,50,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,155,84,69,208,0,0,32,0,97,55,56,45,49,51,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,197,53,175,208,0,0,32,0,97,55,56,45,49,52,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,168,105,83,123,0,0,32,0,97,55,56,45,49,53,46,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,19,164,97,107,0,0,32,0,97,55,56,45,49,54,46,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,151,45,73,181,0,0,32,0,97,55,56,45,49,55,46,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,213,98,151,214,0,0,32,0,97,55,56,45,49,56,46,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,104,59,36,159,0,0,32,0,97,55,56,45,49,57,46,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,140,67,233,102,0,0,32,0,97,55,56,45,50,48,46,51,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,173,99,248,158,0,0,32,0,97,55,49,45,50,53,46,52,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,69,133,15,45,0,0,32,0,112,97,108,49,54,114,52,46,117,51,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,172,38,254,34,0,0,0,8,112,97,108,49,54,108,56,46,117,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,99,150,45,192,0,0,0,8,112,97,108,49,54,108,56,46,117,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,168,32,125,7,0,0,0,8,15,0,0,0,255,255,254,0,0,0,0,0,16,0,0,0,255,255,63,0,0,0,0,0,0,0,0,0,254,0,4,0,128,156,8,0,15,0,0,0,1,5,4,0,240,149,8,0,15,0,0,0,1,5,5,0,0,144,8,0,15,0,0,0,1,5,1,0,232,138,8,0,15,0,0,0,1,5,0,0,120,133,8,0,0,0,0,0,254,0,2,0,144,212,8,0,15,0,0,0,1,2,2,0,96,135,7,0,15,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,15,0,0,0,1,8,0,0,96,135,7,0,15,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,15,0,0,0,1,48,16,0,224,127,8,0,15,0,0,0,1,48,48,0,32,123,8,0,15,0,0,0,1,48,0,0,248,116,8,0,15,0,0,0,1,48,32,0,192,110,8,0,0,0,0,0,254,0,4,0,160,123,6,0,15,0,0,0,1,192,64,0,224,127,8,0,15,0,0,0,1,192,192,0,32,123,8,0,15,0,0,0,1,192,0,0,248,116,8,0,15,0,0,0,1,192,128,0,192,110,8,0,0,0,0,0,254,0,4,0,72,202,5,0,16,0,0,0,1,3,2,0,80,246,3,0,16,0,0,0,1,3,3,0,248,38,7,0,16,0,0,0,1,3,1,0,112,212,3,0,16,0,0,0,1,3,0,0,24,99,5,0,0,0,0,0,254,0,4,0,64,37,5,0,16,0,0,0,1,12,8,0,24,71,8,0,16,0,0,0,1,12,12,0,128,68,8,0,16,0,0,0,1,12,4,0,0,65,8,0,16,0,0,0,1,12,0,0,184,59,8,0,0,0,0,0,254,0,4,0,128,129,4,0,16,0,0,0,1,48,16,0,192,255,2,0,16,0,0,0,1,48,0,0,208,75,4,0,16,0,0,0,1,48,48,0,8,49,4,0,16,0,0,0,1,48,32,0,72,246,3,0,0,0,0,0,254,0,4,0,96,33,8,0,16,0,0,0,1,192,0,0,248,38,7,0,16,0,0,0,1,192,64,0,80,124,6,0,16,0,0,0,1,192,128,0,64,111,3,0,16,0,0,0,1,192,192,0,152,20,8,0,0,0,0,0,17,0,0,0,255,255,195,0,0,0,0,0,18,0,0,0,255,255,213,0,0,0,0,0,0,0,0,0,254,0,4,0,64,37,5,0,17,0,0,0,1,6,0,0,224,64,8,0,17,0,0,0,1,6,2,0,144,164,8,0,17,0,0,0,1,6,4,0,160,102,8,0,17,0,0,0,1,6,6,0,208,45,8,0,0,0,0,0,254,0,2,0,16,227,4,0,17,0,0,0,1,8,0,0,96,135,7,0,17,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,2,0,200,14,2,0,17,0,0,0,1,16,0,0,152,6,2,0,17,0,0,0,1,16,16,0,120,252,1,0,0,0,0,0,254,0,2,0,200,87,7,0,17,0,0,0,1,32,32,0,200,92,8,0,17,0,0,0,1,32,0,0,56,37,8,0,0,0,0,0,254,0,2,0,160,123,6,0,17,0,0,0,1,64,64,0,128,188,7,0,17,0,0,0,1,64,0,0,120,251,7,0,0,0,0,0,254,0,4,0,128,129,4,0,18,0,0,0,1,3,0,0,208,75,4,0,18,0,0,0,1,3,1,0,8,49,4,0,18,0,0,0,1,3,2,0,152,21,4,0,18,0,0,0,1,3,3,0,72,246,3,0,0,0,0,0,254,0,2,0,200,30,2,0,18,0,0,0,1,8,0,0,120,97,1,0,18,0,0,0,1,8,8,0,96,19,1,0,0,0,0,0,254,0,4,0,72,202,5,0,18,0,0,0,1,48,0,0,160,113,6,0,18,0,0,0,1,48,16,0,176,110,6,0,18,0,0,0,1,48,32,0,160,105,6,0,18,0,0,0,1,48,48,0,184,100,6,0,48,54,48,95,108,48,50,46,101,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,52,178,183,232,0,0,16,1,48,54,48,95,108,48,51,46,103,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,129,210,38,60,0,0,16,1,48,54,48,95,108,48,57,46])
.concat([101,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,54,135,98,20,0,0,16,1,48,54,48,95,108,49,48,46,103,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,74,173,56,247,0,0,16,1,48,54,48,106,48,49,46,102,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,115,166,217,249,0,0,16,1,48,54,48,101,48,55,46,107,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,243,237,0,196,0,0,32,0,48,54,48,101,48,56,46,107,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,161,219,221,112,0,0,32,0,48,54,48,101,48,54,46,107,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,146,20,56,9,0,0,32,0,48,54,48,101,48,53,46,107,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,65,66,69,50,0,0,32,0,48,54,48,101,48,52,46,100,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,93,57,128,198,0,0,64,0,98,108,115,119,104,115,116,108,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,63,78,67,135,0,0,0,8,111,102,112,48,102,51,46,53,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,21,218,147,12,0,0,16,1,111,102,112,49,102,51,46,53,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,229,203,78,137,0,0,16,1,111,102,100,48,120,51,46,49,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,5,32,159,57,0,0,16,8,111,102,45,50,48,48,45,48,50,48,49,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,37,48,166,187,0,0,32,0,111,102,45,50,48,49,45,48,50,48,50,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,220,157,253,79,0,0,32,0,111,102,45,50,48,50,45,48,50,48,51,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,99,83,204,251,0,0,32,0,111,102,45,50,48,51,45,48,50,48,52,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,233,140,129,142,0,0,32,0,111,102,45,50,48,52,45,48,50,48,53,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,107,167,196,112,0,0,32,0,111,102,45,50,48,53,45,48,50,48,54,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,187,103,198,128,0,0,32,0,111,102,45,50,48,54,45,48,50,48,55,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,151,140,2,194,0,0,32,0,111,102,45,50,48,55,45,48,50,48,56,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,97,12,243,177,0,0,32,0,111,102,45,50,48,56,45,48,50,48,57,46,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,69,149,242,168,0,0,32,0,111,102,45,50,48,57,101,45,48,50,49,48,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,104,132,1,147,0,0,32,0,111,102,45,50,48,57,48,45,50,48,49,49,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,161,38,178,63,0,0,32,0,111,102,45,50,49,48,101,45,48,50,49,50,46,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,27,250,243,128,0,0,32,0,111,102,45,50,49,48,48,45,48,50,49,51,46,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,214,163,163,140,0,0,32,0,111,102,45,50,49,49,101,45,48,50,49,52,46,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,247,150,61,141,0,0,32,0,111,102,45,50,49,49,48,45,48,50,49,53,46,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,48,130,38,120,0,0,32,0,111,102,45,50,49,50,101,45,48,50,49,54,46,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,153,61,1,90,0,0,32,0,111,102,45,50,49,50,48,45,48,50,49,55,46,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,189,37,237,132,0,0,32,0,111,102,45,50,49,51,101,45,48,50,49,56,46,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,177,197,27,134,0,0,32,0,111,102,45,50,49,51,48,45,48,50,49,57,46,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,25,129,155,167,0,0,32,0,111,102,45,50,49,52,101,45,48,50,50,48,46,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,222,34,198,67,0,0,32,0,111,102,45,50,49,52,48,45,48,50,50,49,46,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,60,240,11,209,0,0,32,0,111,102,45,51,48,48,45,48,50,50,53,46,53,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,138,192,195,251,0,0,32,0,111,102,45,51,48,49,45,48,50,50,54,46,53,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,222,21,242,252,0,0,32,0,111,102,45,49,48,49,45,102,45,48,50,50,51,46,49,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,147,60,95,41,0,0,64,0,111,102,45,49,48,48,45,48,50,50,50,46,57,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,105,34,177,66,0,0,64,0,23,0,0,0,255,255,1,0,0,0,0,0,0,0,0,0,254,0,2,0,40,111,8,0,23,0,0,0,1,1,0,0,96,135,7,0,23,0,0,0,1,1,1,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,23,0,0,0,1,2,0,0,96,135,7,0,23,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,2,0,192,2,8,0,23,0,0,0,1,4,0,0,248,38,7,0,23,0,0,0,1,4,4,0,32,158,6,0,0,0,0,0,254,0,8,0,72,202,5,0,23,0,0,0,1,56,0,0,24,237,7,0,23,0,0,0,1,56,8,0,208,75,4,0,23,0,0,0,1,56,16,0,8,49,4,0,23,0,0,0,1,56,24,0,152,21,4,0,23,0,0,0,1,56,32,0,72,246,3,0,23,0,0,0,1,56,40,0,72,0,3,0,23,0,0,0,1,56,48,0,64,47,7,0,23,0,0,0,1,56,56,0,64,205,7,0,0,0,0,0,254,0,2,0,24,198,7,0,23,0,0,0,1,64,64,0,152,191,7,0,23,0,0,0,1,64,0,0,56,184,7,0,0,0,0,0,254,0,2,0,56,180,7,0,23,0,0,0,1,128,0,0,248,38,7,0,23,0,0,0,1,128,128,0,160,176,7,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,21,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,96,46,8,0,20,0,0,0,1,1,1,0,192,255,2,0,20,0,0,0,1,1,0,0,208,75,4,0,0,0,0,0,254,0,16,0,32,4,2,0,20,0,0,0,2,30,20,0,176,73,5,0,20,0,0,0,0,1,1,0,0,0,0,0,20,0,0,0,2,30,22,0,104,54,4,0,20,0,0,0,0,1,1,0,0,0,0,0,20,0,0,0,2,30,24,0,80,252,6,0,20,0,0,0,0,1,1,0,0,0,0,0,20,0,0,0,2,30,26,0,16,242,7,0,20,0,0,0,0,1,1,0,0,0,0,0,20,0,0,0,2,30,2,0,40,28,4,0,20,0,0,0,0,1,1,0,0,0,0,0,20,0,0,0,2,30,28,0,104,236,7,0,20,0,0,0,0,1,1,0,0,0,0,0,20,0,0,0,2,30,4,0,192,24,7,0,20,0,0,0,0,1,1,0,0,0,0,0,20,0,0,0,2,30,6,0,120,113,6,0,20,0,0,0,0,1,1,0,0,0,0,0,20,0,0,0,2,30,30,0,128,230,7,0,20,0,0,0,0,1,1,0,0,0,0,0,20,0,0,0,2,30,8,0,120,211,6,0,20,0,0,0,0,1,1,0,0,0,0,0,20,0,0,0,2,30,18,0,184,164,6,0,20,0,0,0,0,1,1,0,0,0,0,0,20,0,0,0,2,30,16,0,80,74,6,0,20,0,0,0,0,1,1,0,0,0,0,0,20,0,0,0,2,30,14,0,192,32,6,0,20,0,0,0,0,1,1,0,0,0,0,0,20,0,0,0,2,30,12,0,192,234,2,0,20,0,0,0,0,1,1,0,0,0,0,0,20,0,0,0,2,30,10,0,32,242,5,0,20,0,0,0,0,1,1,0,0,0,0,0,20,0,0,0,2,30,0,0,16,227,4,0,20,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,254,0,4,0,200,87,7,0,20,0,0,0,2,6,0,0,104,54,4,0,20,0,0,0,0,1,0,0,0,0,0,0,20,0,0,0,2,6,2,0,16,242,7,0,20,0,0,0,0,1,0,0,0,0,0,0,20,0,0,0,2,6,4,0,104,236,7,0,20,0,0,0,0,1,0,0,0,0,0,0,20,0,0,0,2,6,6,0,128,230,7,0,20,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,254,0,4,0,160,123,6,0,20,0,0,0,2,24,24,0,8,201,6,0,20,0,0,0,0,1,0,0,0,0,0,0,20,0,0,0,2,24,16,0,200,197,6,0,20,0,0,0,0,1,0,0,0,0,0,0,20,0,0,0,2,24,8,0,128,95,7,0,20,0,0,0,0,1,0,0,0,0,0,0,20,0,0,0,2,24,0,0,248,189,6,0,20,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,254,0,2,0,72,222,3,0,20,0,0,0,1,32,32,0,248,38,7,0,20,0,0,0,1,32,0,0,200,200,1,0,0,0,0,0,254,0,4,0,128,129,4,0,21,0,0,0,1,3,0,0,192,255,2,0,21,0,0,0,1,3,2,0,208,75,4,0,21,0,0,0,1,3,3,0,8,49,4,0,21,0,0,0,1,3,1,0,72,246,3,0,0,0,0,0,254,0,4,0,64,37,5,0,21,0,0,0,1,12,12,0,216,232,8,0,21,0,0,0,1,12,8,0,56,225,8,0,21,0,0,0,1,12,4,0,64,190,3,0,21,0,0,0,1,12,0,0,120,7,5,0,0,0,0,0,254,0,4,0,72,202,5,0,21,0,0,0,1,48,32,0,80,246,3,0,21,0,0,0,1,48,48,0,248,38,7,0,21,0,0,0,1,48,16,0,112,212,3,0,21,0,0,0,1,48,0,0,24,99,5,0,0,0,0,0,254,0,2,0,104,159,3,0,21,0,0,0,1,64,0,0,56,111,3,0,21,0,0,0,1,64,64,0,104,134,3,0,0,0,0,0,254,0,2,0,168,234,7,0,21,0,0,0,1,128,0,0,96,135,7,0,21,0,0,0,1,128,128,0,152,182,7,0,22,0,0,0,255,255,255,0,0,0,0,0,23,0,0,0,255,255,63,0,0,0,0,0,0,0,0,0,254,0,4,0,32,4,2,0,22,0,0,0,1,3,0,0,88,154,8,0,22,0,0,0,1,3,1,0,200,92,8,0,22,0,0,0,1,3,3,0,56,37,8,0,22,0,0,0,1,3,2,0,96,240,7,0,0,0,0,0,254,0,2,0,112,154,1,0,22,0,0,0,1,16,16,0,96,135,7,0,22,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,22,0,0,0,1,32,0,0,96,135,7,0,22,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,72,202,5,0,23,0,0,0,1,3,2,0,80,246,3,0,23,0,0,0,1,3,3,0,248,38,7,0,23,0,0,0,1,3,1,0,112,212,3,0,23,0,0,0,1,3,0,0,24,99,5,0,0,0,0,0,254,0,2,0,128,143,1,0,23,0,0,0,1,4,0,0,208,75,4,0,23,0,0,0,1,4,4,0,8,49,4,0,0,0,0,0,98,108,101,95,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,54,69,42,250,0,0,16,1,98,108,102,95,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,222,235,20,225,0,0,16,1,98,108,101,95,48,55,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,19,79,17,29,0,0,16,1,98,108,95,48,56,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,241,79,15,170,0,0,32,0,98,108,95,48,57,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,134,193,168,111,0,0,32,0,98,108,95,49,56,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,175,175,172,192,0,0,32,0,98,108,95,49,57,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,245,66,233,26,0,0,32,0,98,108,95,49,54,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,247,175,220,250,0,0,32,0,98,108,95,49,55,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,66,171,140,95,0,0,32,0,98,108,95,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,187,42,236,194,0,0,64,0,98,103,46,49,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,26,35,155,169,0,0,16,1,98,103,46,49,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,213,115,181,166,0,0,16,1,98,103,46,49,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,255,250,72,216,0,0,16,1,98,103,46,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,235,164,62,126,0,0,32,0,98,103,46,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,157,211,211,77,0,0,32,0,98,103,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,99,134,54,23,0,0,32,0,98,103,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,4,196,139,12,0,0,32,0,98,103,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,250,196,125,43,0,0,32,0,98,103,46,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,6,19,18,237,0,0,32,0,98,103,46,49,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,32,201,156,233,0,0,32,0,98,103,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,248,87,48,33,0,0,32,0,98,103,46,49,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,44,129,76,6,0,0,32,0,98,103,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,64,176,224,2,0,0,32,0,112,114,53,51,49,55,46,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,184,80,131,100,0,0,0,8,51,49,55,45,48,48,50,57,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,147,127,13,53,0,0,16,1,12,0,0,0,255,255,215,0,0,0,0,0,13,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,12,0,0,0,1,1,0,0,120,97,1,0,12,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,2,0,168,234,7,0,12,0,0,0,1,2,0,0,96,135,7,0,12,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,2,0,128,129,4,0,12,0,0,0,1,8,8,0,208,75,4,0,12,0,0,0,1,8,0,0,8,49,4,0,0,0,0,0,254,0,2,0,64,37,5,0,12,0,0,0,1,16,16,0,24,38,5,0,12,0,0,0,1,16,0,0,200,34,5,0,0,0,0,0,254,0,2,0,104,159,3,0,12,0,0,0,1,32,32,0,96,135,7,0,12,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,12,0,0,0,1,128,128,0,96,135,7,0,12,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,16,0,200,87,7,0,13,0,0,0,1,15,7,0,80,252,6,0,13,0,0,0,1,15,8,0,16,242,7,0,13,0,0,0,1,15,9,0,104,236,7,0,13,0,0,0,1,15,5,0,192,54,8,0,13,0,0,0,1,15,4,0,56,24,4,0,13,0,0,0,1,15,15,0,128,230,7,0,13,0,0,0,1,15,0,0,128,230,7,0,13,0,0,0,1,15,3,0,176,162,3,0,13,0,0,0,1,15,2,0,24,188,3,0,13,0,0,0,1,15,1,0,72,216,3,0,13,0,0,0,1,15,6,0,120,211,6,0,13,0,0,0,1,15,14,0,184,164,6,0,13,0,0,0,1,15,13,0,80,74,6,0,13,0,0,0,1,15,12,0,192,32,6,0,13,0,0,0,1,15,11,0,192,234,2,0,13,0,0,0,1,15,10,0,32,242,5,0,0,0,0,0,254,0,16,0,160,123,6,0,13,0,0,0,1,240,112,0,80,252,6,0,13,0,0,0,1,240,128,0,16,242,7,0,13,0,0,0,1,240,144,0,104,236,7,0,13,0,0,0,1,240,80,0,192,54,8,0,13,0,0,0,1,240,64,0,56,24,4,0,13,0,0,0,1,240,240,0,128,230,7,0,13,0,0,0,1,240,0,0,128,230,7,0,13,0,0,0,1,240,48,0,176,162,3,0,13,0,0,0,1,240,32,0,24,188,3,0,13,0,0,0,1,240,16,0,72,216,3,0,13,0,0,0,1,240,96,0,120,211,6,0,13,0,0,0,1,240,224,0,184,164,6,0,13,0,0,0,1,240,208,0,80,74,6,0,13,0,0,0,1,240,192,0,192,32,6,0,13,0,0,0,1,240,176,0,192,234,2,0,13,0,0,0,1,240,160,0,32,242,5,0,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,21,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,72,202,5,0,19,0,0,0,1,3,2,0,80,246,3,0,19,0,0,0,1,3,3,0,248,38,7,0,19,0,0,0,1,3,1,0,112,212,3,0,19,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,64,37,5,0,19,0,0,0,1,12,12,0,216,122,2,0,19,0,0,0,1,12,4,0,64,122,2,0,19,0,0,0,1,12,8,0,128,121,2,0,19,0,0,0,1,12,0,0,224,120,2,0,0,0,0,0,254,0,4,0,128,129,4,0,19,0,0,0,1,48,0,0,192,255,2,0,19,0,0,0,1,48,48,0,208,75,4,0,19,0,0,0,1,48,32,0,8,49,4,0,19,0,0,0,1,48,16,0,152,21,4,0,0,0,0,0,254,0,2,0,16,227,4,0,19,0,0,0,1,128,128,0,96,135,7,0,19,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,20,0,0,0,1,2,2,0,96,135,7,0,20,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,20,0,0,0,1,4,0,0,96,135,7,0,20,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,20,0,0,0,1,48,16,0,96,39,7,0,20,0,0,0,1,48,48,0,144,251,6,0,20,0,0,0,1,48,0,0,120,211,6,0,20,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,20,0,0,0,1,192,64,0,96,39,7,0,20,0,0,0,1,192,192,0,144,251,6,0,20,0,0,0,1,192,0,0,120,211,6,0,20,0,0,0,1,192,128,0,184,164,6,0,0,0,0,0,254,0,2,0,128,94,5,0,21,0,0,0,1,16,16,0,40,120,2,0,21,0,0,0,1,16,0,0,200,118,2,0,18,0,0,0,255,255,255,0,0,0,0,0,19,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,232,75,4,0,18,0,0,0,1,2,2,0,96,135,7,0,18,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,18,0,0,0,1,12,12,0,80,246,3,0,18,0,0,0,1,12,8,0,248,38,7,0,18,0,0,0,1,12,4,0,112,212,3,0,18,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,4,0,128,129,4,0,18,0,0,0,1,192,64,0,208,75,4,0,18,0,0,0,1,192,192,0,8,49,4,0,18,0,0,0,1,192,128,0,152,21,4,0,18,0,0,0,1,192,0,0,72,246,3,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,2,0,0,96,135,7,0,19,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,8,0,160,123,6,0,19,0,0,0,1,28,16,0,32,136,7,0,19,0,0,0,1,28,8,0,40,88,7,0,19,0,0,0,1,28,24,0,96,39,7,0,19,0,0,0,1,28,28,0,144,251,6,0,19,0,0,0,1,28,12,0,184,164,6,0,19,0,0,0,1,28,20,0,80,74,6,0,19,0,0,0,1,28,4,0,192,32,6,0,19,0,0,0,1,28,0,0,16,227,4,0,0,0,0,0,254,0,8,0,200,87,7,0,19,0,0,0,1,224,128,0,32,136,7,0,19,0,0,0,1,224,64,0,40,88,7,0,19,0,0,0,1,224,192,0,96,39,7,0,19,0,0,0,1,224,224,0,144,251,6,0,19,0,0,0,1,224,96,0,184,164,6,0,19,0,0,0,1,224,160,0,80,74,6,0,19,0,0,0,1,224,32,0,192,32,6,0,19,0,0,0,1,224,0,0,16,227,4,0,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,192,80,235,183,1,0,16,1,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,197,225,143,152,1,0,16,1])
.concat([99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,147,231,141,123,1,0,16,1,104,117,115,116,108,101,114,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,68,101,148,122,2,0,16,1,104,117,115,116,108,101,114,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,81,115,181,61,2,0,16,1,104,117,115,116,108,101,114,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,14,173,223,11,4,0,32,0,104,117,115,116,108,101,114,46,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,119,33,6,142,4,0,32,0,104,117,115,116,108,101,114,46,99,108,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,94,127,31,170,7,0,32,0,18,0,0,0,255,255,255,0,0,0,0,0,19,0,0,0,255,255,206,0,0,0,0,0,20,0,0,0,255,255,254,0,0,0,0,0,0,0,0,0,254,0,11,0,200,87,7,0,18,0,0,0,1,15,7,0,32,136,7,0,18,0,0,0,1,15,8,0,40,88,7,0,18,0,0,0,1,15,9,0,96,39,7,0,18,0,0,0,1,15,15,0,144,251,6,0,18,0,0,0,1,15,6,0,120,211,6,0,18,0,0,0,1,15,14,0,184,164,6,0,18,0,0,0,1,15,13,0,80,74,6,0,18,0,0,0,1,15,12,0,192,32,6,0,18,0,0,0,1,15,11,0,192,234,2,0,18,0,0,0,1,15,10,0,32,242,5,0,18,0,0,0,1,15,0,0,8,75,5,0,0,0,0,0,254,0,11,0,160,123,6,0,18,0,0,0,1,240,112,0,32,136,7,0,18,0,0,0,1,240,128,0,40,88,7,0,18,0,0,0,1,240,144,0,96,39,7,0,18,0,0,0,1,240,240,0,144,251,6,0,18,0,0,0,1,240,96,0,120,211,6,0,18,0,0,0,1,240,224,0,184,164,6,0,18,0,0,0,1,240,208,0,80,74,6,0,18,0,0,0,1,240,192,0,192,32,6,0,18,0,0,0,1,240,176,0,192,234,2,0,18,0,0,0,1,240,160,0,32,242,5,0,18,0,0,0,1,240,0,0,144,44,2,0,0,0,0,0,254,0,8,0,72,202,5,0,19,0,0,0,1,7,7,0,24,205,7,0,19,0,0,0,1,7,6,0,192,255,2,0,19,0,0,0,1,7,5,0,208,75,4,0,19,0,0,0,1,7,4,0,8,49,4,0,19,0,0,0,1,7,3,0,152,21,4,0,19,0,0,0,1,7,2,0,72,246,3,0,19,0,0,0,1,7,1,0,72,0,3,0,19,0,0,0,1,7,0,0,64,47,7,0,0,0,0,0,254,0,4,0,128,129,4,0,19,0,0,0,1,24,24,0,192,255,2,0,19,0,0,0,1,24,16,0,208,75,4,0,19,0,0,0,1,24,8,0,8,49,4,0,19,0,0,0,1,24,0,0,152,21,4,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,32,32,0,96,135,7,0,19,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,56,189,8,0,19,0,0,0,1,64,0,0,96,135,7,0,19,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,128,128,0,96,135,7,0,19,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,0,184,8,0,20,0,0,0,1,2,2,0,96,135,7,0,20,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,117,50,51,95,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,206,38,181,118,0,0,16,1,117,51,57,95,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,242,126,250,120,0,0,16,1,98,119,48,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,96,114,146,188,0,0,32,0,98,119,48,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,101,84,63,34,0,0,32,0,98,119,51,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,122,115,88,178,0,0,32,0,98,119,48,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,45,183,180,251,0,0,32,0,98,119,48,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,77,195,0,83,0,0,32,0,98,119,48,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,47,47,175,154,0,0,32,0,98,119,48,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,67,109,219,22,0,0,32,0,98,119,48,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,176,160,81,17,0,0,32,0,98,119,48,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,31,93,163,115,0,0,32,0,98,119,48,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,194,223,71,244,0,0,32,0,98,119,48,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,135,92,248,151,0,0,32,0,98,119,48,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,37,130,164,176,0,0,32,0,98,119,48,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,157,134,254,216,0,0,64,0,22,0,0,0,255,255,255,0,0,0,0,0,23,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,40,134,8,0,22,0,0,0,1,1,1,0,248,38,7,0,22,0,0,0,1,1,0,0,32,158,6,0,0,0,0,0,254,0,8,0,72,27,7,0,22,0,0,0,1,28,28,0,128,230,7,0,22,0,0,0,1,28,24,0,168,126,7,0,22,0,0,0,1,28,20,0,8,15,7,0,22,0,0,0,1,28,16,0,104,9,7,0,22,0,0,0,1,28,12,0,104,236,7,0,22,0,0,0,1,28,8,0,184,252,6,0,22,0,0,0,1,28,4,0,16,242,7,0,22,0,0,0,1,28,0,0,80,252,6,0,0,0,0,0,254,0,8,0,136,241,6,0,22,0,0,0,1,224,224,0,128,230,7,0,22,0,0,0,1,224,192,0,168,126,7,0,22,0,0,0,1,224,160,0,8,15,7,0,22,0,0,0,1,224,128,0,104,9,7,0,22,0,0,0,1,224,96,0,104,236,7,0,22,0,0,0,1,224,64,0,184,252,6,0,22,0,0,0,1,224,32,0,192,234,2,0,22,0,0,0,1,224,0,0,32,242,5,0,0,0,0,0,254,0,4,0,32,232,6,0,23,0,0,0,1,3,3,0,136,128,8,0,23,0,0,0,1,3,2,0,80,246,3,0,23,0,0,0,1,3,1,0,48,123,8,0,23,0,0,0,1,3,0,0,8,117,8,0,0,0,0,0,254,0,4,0,232,119,7,0,23,0,0,0,1,12,12,0,8,49,4,0,23,0,0,0,1,12,8,0,208,75,4,0,23,0,0,0,1,12,4,0,72,246,3,0,23,0,0,0,1,12,0,0,64,47,7,0,0,0,0,0,254,0,4,0,40,213,6,0,23,0,0,0,1,48,48,0,168,22,4,0,23,0,0,0,1,48,32,0,152,140,1,0,23,0,0,0,1,48,16,0,120,201,6,0,23,0,0,0,1,48,0,0,56,198,6,0,0,0,0,0,254,0,2,0,16,115,7,0,23,0,0,0,1,64,0,0,96,135,7,0,23,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,56,195,6,0,23,0,0,0,1,128,128,0,96,212,3,0,23,0,0,0,1,128,0,0,232,184,6,0,22,0,0,0,255,255,251,0,0,0,0,0,23,0,0,0,255,255,253,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,22,0,0,0,1,3,0,0,192,255,2,0,22,0,0,0,1,3,2,0,208,75,4,0,22,0,0,0,1,3,3,0,8,49,4,0,22,0,0,0,1,3,1,0,152,21,4,0,0,0,0,0,254,0,2,0,168,234,7,0,22,0,0,0,1,4,4,0,96,135,7,0,22,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,64,37,5,0,22,0,0,0,1,8,8,0,112,78,7,0,22,0,0,0,1,8,0,0,104,75,7,0,0,0,0,0,254,0,2,0,200,30,2,0,23,0,0,0,1,2,0,0,120,97,1,0,23,0,0,0,1,2,2,0,96,19,1,0,0,0,0,0,254,0,2,0,72,202,5,0,23,0,0,0,1,8,8,0,248,38,7,0,23,0,0,0,1,8,0,0,112,212,3,0,0,0,0,0,254,0,2,0,104,159,3,0,23,0,0,0,1,16,0,0,56,111,3,0,23,0,0,0,1,16,16,0,104,134,3,0,0,0,0,0,254,0,2,0,144,246,3,0,23,0,0,0,1,64,64,0,96,135,7,0,23,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,168,86,7,0,1,0,0,0,190,245,146,0,248,191,2,0,24,38,7,0,1,0,0,0,184,245,146,0,184,160,2,0,56,210,6,0,1,0,0,0,3,254,146,0,192,135,2,0,24,163,6,0,1,0,0,0,2,254,146,0,240,108,2,0,152,122,6,0,1,0,0,0,1,254,146,0,96,82,2,0,192,72,6,0,1,0,0,0,0,254,146,0,32,56,2,0,200,110,3,0,1,0,0,0,4,254,146,0,152,30,2,0,120,89,3,0,1,0,0,0,5,254,146,0,232,10,2,0,40,246,1,0,1,0,0,0,191,245,146,0,64,246,1,0,144,236,1,0,1,0,0,0,185,245,146,0,136,224,1,0,176,223,1,0,1,0,0,0,11,254,146,0,72,198,1,0,192,209,1,0,1,0,0,0,10,254,146,0,24,182,1,0,24,198,1,0,1,0,0,0,9,254,146,0,40,167,1,0,120,189,1,0,1,0,0,0,8,254,146,0,200,149,1,0,224,22,1,0,1,0,0,0,12,254,146,0,56,126,1,0,160,14,1,0,1,0,0,0,13,254,146,0,32,101,1,0,88,212,3,0,1,0,0,0,8,218,146,0,40,185,3,0,16,17,8,0,1,0,0,0,189,245,146,0,224,12,8,0,72,65,1,0,9,0,0,0,208,4,147,0,32,58,1,0,48,50,1,0,9,0,0,0,209,4,147,0,32,58,1,0,101,112,114,45,49,50,53,49,55,46,97,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,169,40,103,67,1,0,16,1,101,112,114,45,49,50,53,49,54,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,53,240,79,1,0,16,1,101,112,114,45,49,50,52,53,56,46,97,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,106,71,199,231,1,0,16,1,101,112,114,45,49,50,52,53,54,46,97,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,175,46,220,37,1,0,16,1,111,112,114,45,49,50,52,54,50,46,97,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,181,67,153,161,2,0,32,0,111,112,114,45,49,50,52,54,51,46,97,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,13,32,248,98,2,0,32,0,111,112,114,45,49,50,52,54,52,46,97,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,3,151,197,200,2,0,32,0,109,112,114,45,49,50,52,54,53,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,69,27,214,17,3,0,32,0,109,112,114,45,49,50,52,54,55,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,192,228,180,195,3,0,32,0,109,112,114,45,49,50,52,54,54,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,111,35,127,165,3,0,32,0,109,112,114,45,49,50,52,54,56,46,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,222,119,156,216,3,0,32,0,101,112,114,45,49,50,52,53,57,46,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,208,41,29,62,4,0,16,1,109,112,114,45,49,50,52,54,48,46,97,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,13,87,174,11,8,0,64,0,109,112,114,45,49,50,52,54,49,46,97,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,70,139,59,176,8,0,64,0,51,49,55,45,48,49,49,54,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,73,238,120,135,5,0,16,1,21,0,0,0,255,255,253,0,0,0,0,0,22,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,104,159,3,0,21,0,0,0,1,1,0,0,96,135,7,0,21,0,0,0,1,1,1,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,21,0,0,0,1,2,2,0,96,135,7,0,21,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,21,0,0,0,1,12,4,0,192,255,2,0,21,0,0,0,1,12,12,0,8,49,4,0,21,0,0,0,1,12,8,0,72,246,3,0,21,0,0,0,1,12,0,0,184,112,5,0,0,0,0,0,254,0,4,0,64,37,5,0,21,0,0,0,1,48,48,0,160,191,4,0,21,0,0,0,1,48,32,0,24,145,2,0,21,0,0,0,1,48,16,0,240,159,4,0,21,0,0,0,1,48,0,0,120,7,5,0,0,0,0,0,254,0,4,0,72,202,5,0,21,0,0,0,1,192,192,0,80,246,3,0,21,0,0,0,1,192,128,0,248,38,7,0,21,0,0,0,1,192,64,0,112,212,3,0,21,0,0,0,1,192,0,0,248,160,5,0,0,0,0,0,254,0,16,0,200,87,7,0,22,0,0,0,1,15,7,0,80,252,6,0,22,0,0,0,1,15,8,0,16,242,7,0,22,0,0,0,1,15,9,0,104,236,7,0,22,0,0,0,1,15,5,0,176,51,4,0,22,0,0,0,1,15,4,0,56,24,4,0,22,0,0,0,1,15,15,0,128,230,7,0,22,0,0,0,1,15,1,0,72,216,3,0,22,0,0,0,1,15,2,0,24,188,3,0,22,0,0,0,1,15,3,0,176,162,3,0,22,0,0,0,1,15,6,0,120,211,6,0,22,0,0,0,1,15,14,0,184,164,6,0,22,0,0,0,1,15,13,0,80,74,6,0,22,0,0,0,1,15,12,0,192,32,6,0,22,0,0,0,1,15,11,0,192,234,2,0,22,0,0,0,1,15,10,0,32,242,5,0,22,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,22,0,0,0,1,240,112,0,80,252,6,0,22,0,0,0,1,240,128,0,16,242,7,0,22,0,0,0,1,240,144,0,104,236,7,0,22,0,0,0,1,240,80,0,176,51,4,0,22,0,0,0,1,240,64,0,56,24,4,0,22,0,0,0,1,240,240,0,128,230,7,0,22,0,0,0,1,240,16,0,72,216,3,0,22,0,0,0,1,240,32,0,24,188,3,0,22,0,0,0,1,240,48,0,176,162,3,0,22,0,0,0,1,240,96,0,120,211,6,0,22,0,0,0,1,240,224,0,184,164,6,0,22,0,0,0,1,240,208,0,80,74,6,0,22,0,0,0,1,240,192,0,192,32,6,0,22,0,0,0,1,240,176,0,192,234,2,0,22,0,0,0,1,240,160,0,32,242,5,0,22,0,0,0,1,240,0,0,208,236,2,0,0,0,0,0,98,114,45,97,45,52,101,46,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,104,71,241,155,0,0,16,1,98,114,45,97,45,52,100,46,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,39,22,202,57,0,0,16,1,98,114,45,97,45,52,98,46,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,34,187,101,24,0,0,16,1,98,114,45,97,45,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,33,28,182,101,0,0,16,1,98,114,45,99,45,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,82,202,30,46,0,0,16,1,98,114,45,99,45,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,120,133,23,242,0,0,16,1,98,114,45,99,45,55,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,48,250,169,58,0,0,16,1,98,114,45,99,45,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,11,185,49,11,0,0,16,1,98,114,45,99,45,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,128,0,59,236,0,0,16,1,98,114,45,99,45,55,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,127,95,199,237,0,0,16,1,98,114,45,97,45,51,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,113,8,20,167,0,0,16,1,98,114,45,97,45,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,48,27,181,27,0,0,16,1,98,114,45,97,45,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,131,224,179,175,0,0,16,1,98,114,45,99,45,54,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,28,132,80,202,0,0,32,0,98,114,45,99,45,54,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,58,22,83,125,0,0,32,0,98,114,45,99,45,54,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,42,225,81,89,0,0,32,0,98,114,45,98,45,52,107,46,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,91,232,197,211,0,0,32,0,98,114,45,98,45,52,102,46,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,42,35,84,67,0,0,32,0,98,114,45,98,45,51,110,46,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,239,219,104,38,0,0,32,0,98,114,45,98,45,52,110,46,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,36,163,25,199,0,0,32,0,98,114,45,98,45,52,99,46,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,191,147,49,11,0,0,32,0,98,114,45,98,45,52,101,46,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,251,232,98,54,0,0,32,0,98,114,45,99,45,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,30,145,136,128,0,0,32,0,98,114,45,99,45,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,83,182,120,61,0,0,32,0,98,114,45,99,45,51,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,121,237,234,172,0,0,32,0,98,114,45,98,45,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,125,12,211,59,0,0,32,0,98,114,45,99,45,51,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,128,243,246,124,0,0,32,0,98,114,45,98,45,49,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,59,220,243,183,0,0,32,0,98,114,45,99,45,51,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,84,74,14,217,0,0,32,0,98,114,45,98,45,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,216,199,113,82,0,0,32,0,98,114,45,98,45,53,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,55,105,116,206,0,0,32,0,98,114,45,98,45,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,18,13,194,130,0,0,32,0,98,114,45,99,45,49,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,119,93,235,120,0,0,32,0,18,0,0,0,255,255,255,0,0,0,0,0,19,0,0,0,255,255,253,0,0,0,0,0,0,0,0,0,254,0,4,0])
.concat([56,27,8,0,18,0,0,0,1,3,3,0,248,81,6,0,18,0,0,0,1,3,2,0,80,124,6,0,18,0,0,0,1,3,1,0,176,64,8,0,18,0,0,0,1,3,0,0,128,65,6,0,0,0,0,0,254,0,2,0,72,202,5,0,18,0,0,0,1,4,4,0,80,246,3,0,18,0,0,0,1,4,0,0,112,212,3,0,0,0,0,0,254,0,15,0,32,4,2,0,18,0,0,0,2,240,144,0,176,79,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,160,0,8,32,4,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,176,0,96,164,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,192,0,144,102,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,208,0,176,45,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,224,0,224,127,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,240,0,32,123,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,112,0,192,110,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,96,0,96,102,7,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,80,0,184,105,6,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,64,0,152,96,3,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,48,0,192,100,6,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,32,0,64,1,1,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,16,0,184,69,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,0,0,104,151,6,0,19,0,0,0,0,4,4,0,0,0,0,0,0,0,0,0,254,0,4,0,200,87,7,0,18,0,0,0,130,48,16,0,176,45,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,130,48,32,0,224,127,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,130,48,48,0,32,123,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,130,48,0,0,16,227,4,0,19,0,0,0,0,4,4,0,0,0,0,0,0,0,0,0,254,0,4,0,160,123,6,0,18,0,0,0,130,192,192,0,192,110,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,130,192,128,0,96,102,7,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,130,192,64,0,152,96,3,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,130,192,0,0,192,100,6,0,19,0,0,0,0,4,4,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,1,1,0,96,135,7,0,19,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,200,30,2,0,19,0,0,0,1,2,0,0,120,97,1,0,19,0,0,0,1,2,2,0,96,19,1,0,0,0,0,0,254,0,2,0,96,46,8,0,19,0,0,0,1,4,4,0,208,233,4,0,19,0,0,0,1,4,0,0,72,197,4,0,0,0,0,0,254,0,2,0,72,4,1,0,19,0,0,0,1,16,16,0,96,135,7,0,19,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,246,3,0,19,0,0,0,1,64,64,0,96,135,7,0,19,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,128,128,0,96,135,7,0,19,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,168,86,7,0,1,0,0,0,212,47,216,0,248,191,2,0,24,38,7,0,1,0,0,0,208,47,216,0,184,160,2,0,56,210,6,0,1,0,0,0,35,48,216,0,192,135,2,0,24,163,6,0,1,0,0,0,34,48,216,0,240,108,2,0,152,122,6,0,1,0,0,0,33,48,216,0,96,82,2,0,192,72,6,0,1,0,0,0,32,48,216,0,32,56,2,0,152,31,6,0,1,0,0,0,36,48,216,0,152,30,2,0,248,97,5,0,1,0,0,0,37,48,216,0,232,10,2,0,40,246,1,0,1,0,0,0,213,47,216,0,64,246,1,0,144,236,1,0,1,0,0,0,209,47,216,0,136,224,1,0,176,223,1,0,1,0,0,0,43,48,216,0,72,198,1,0,192,209,1,0,1,0,0,0,42,48,216,0,24,182,1,0,24,198,1,0,1,0,0,0,41,48,216,0,40,167,1,0,120,189,1,0,1,0,0,0,40,48,216,0,200,149,1,0,8,182,1,0,1,0,0,0,44,48,216,0,56,126,1,0,32,167,1,0,1,0,0,0,45,48,216,0,32,101,1,0,168,132,8,0,1,0,0,0,214,47,216,0,232,209,1,0,72,126,8,0,1,0,0,0,210,47,216,0,144,189,1,0,192,122,8,0,1,0,0,0,251,47,216,0,208,174,1,0,40,116,8,0,1,0,0,0,250,47,216,0,48,160,1,0,72,110,8,0,1,0,0,0,249,47,216,0,160,140,1,0,184,102,8,0,1,0,0,0,248,47,216,0,56,112,1,0,248,93,8,0,1,0,0,0,252,47,216,0,32,92,1,0,152,86,8,0,1,0,0,0,253,47,216,0,64,77,1,0,232,23,8,0,1,0,0,0,215,47,216,0,104,195,5,0,160,19,8,0,1,0,0,0,211,47,216,0,32,245,8,0,248,16,8,0,1,0,0,0,3,48,216,0,32,231,8,0,192,12,8,0,1,0,0,0,2,48,216,0,88,214,8,0,224,5,8,0,1,0,0,0,1,48,216,0,224,202,8,0,144,1,8,0,1,0,0,0,0,48,216,0,72,193,8,0,96,250,7,0,1,0,0,0,4,48,216,0,144,180,8,0,120,241,7,0,1,0,0,0,5,48,216,0,208,164,8,0,88,212,3,0,1,0,0,0,144,46,216,0,40,185,3,0,240,152,1,0,1,0,0,0,201,47,216,0,216,70,1,0,16,17,8,0,1,0,0,0,202,47,216,0,224,12,8,0,136,67,2,0,1,0,0,0,176,48,216,0,152,138,8,0,8,66,2,0,1,0,0,0,184,48,216,0,48,119,7,0,16,0,0,0,255,255,255,0,0,0,0,0,17,0,0,0,255,255,255,0,0,0,0,0,18,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,0,0,160,123,6,0,16,0,0,0,1,3,0,0,40,88,7,0,16,0,0,0,1,3,1,0,96,39,7,0,16,0,0,0,1,3,3,0,144,251,6,0,16,0,0,0,1,3,2,0,184,164,6,0,0,0,0,0,254,0,4,0,168,234,7,0,16,0,0,0,1,4,0,0,96,135,7,0,16,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,254,0,2,0,200,87,7,0,16,0,0,0,1,24,0,0,40,88,7,0,16,0,0,0,1,24,8,0,96,39,7,0,16,0,0,0,1,24,24,0,144,251,6,0,16,0,0,0,1,24,16,0,184,164,6,0,0,0,0,0,254,0,4,0,128,129,4,0,16,0,0,0,1,96,64,0,208,75,4,0,16,0,0,0,1,96,96,0,8,49,4,0,16,0,0,0,1,96,32,0,152,21,4,0,16,0,0,0,1,96,0,0,72,246,3,0,0,0,0,0,254,0,4,0,232,75,4,0,16,0,0,0,1,128,128,0,96,135,7,0,16,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,17,0,0,0,1,2,2,0,96,135,7,0,17,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,0,0,72,4,1,0,17,0,0,0,1,4,4,0,96,135,7,0,17,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,176,110,8,0,17,0,0,0,1,8,8,0,96,135,7,0,17,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,2,0,72,202,5,0,17,0,0,0,1,48,32,0,80,246,3,0,17,0,0,0,1,48,48,0,248,38,7,0,17,0,0,0,1,48,16,0,112,212,3,0,17,0,0,0,1,48,0,0,24,99,5,0,0,0,0,0,254,0,2,0,64,37,5,0,17,0,0,0,1,192,128,0,88,111,4,0,17,0,0,0,1,192,192,0,8,86,4,0,17,0,0,0,1,192,64,0,192,182,5,0,17,0,0,0,1,192,0,0,120,7,5,0,0,0,0,0,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,88,232,240,74,2,0,16,1,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,105,58,152,11,2,0,16,1,56,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,175,21,197,209,9,0,16,1,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,55,5,62,236,15,0,32,0,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,23,23,68,187,15,0,32,0,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,36,214,150,129,15,0,32,0,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,229,132,197,28,15,0,32,0,101,97,115,116,45,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,150,31,17,146,24,0,64,0,101,97,115,116,45,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,25,196,10,202,25,0,64,0,21,0,0,0,255,255,223,0,0,0,0,0,22,0,0,0,255,255,134,0,0,0,0,0,0,0,0,0,254,0,4,0,200,87,7,0,21,0,0,0,1,3,1,0,104,236,7,0,21,0,0,0,1,3,3,0,128,230,7,0,21,0,0,0,1,3,0,0,120,211,6,0,21,0,0,0,1,3,2,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,21,0,0,0,1,12,4,0,104,236,7,0,21,0,0,0,1,12,12,0,128,230,7,0,21,0,0,0,1,12,0,0,120,211,6,0,21,0,0,0,1,12,8,0,184,164,6,0,0,0,0,0,254,0,4,0,72,202,5,0,21,0,0,0,1,96,96,0,80,246,3,0,21,0,0,0,1,96,64,0,80,124,6,0,21,0,0,0,1,96,32,0,112,212,3,0,21,0,0,0,1,96,0,0,248,160,5,0,0,0,0,0,254,0,2,0,168,234,7,0,22,0,0,0,1,1,1,0,96,135,7,0,22,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,22,0,0,0,1,2,2,0,96,135,7,0,22,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,22,0,0,0,1,4,0,0,96,135,7,0,22,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,254,0,2,0,128,112,3,0,22,0,0,0,1,32,0,0,168,22,4,0,22,0,0,0,1,32,32,0,224,247,3,0,0,0,0,0,254,0,2,0,208,76,8,0,22,0,0,0,1,64,0,0,40,71,8,0,22,0,0,0,1,64,64,0,144,68,8,0,0,0,0,0,254,0,2,0,232,75,4,0,22,0,0,0,1,128,128,0,96,135,7,0,22,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,116,115,49,48,48,106,46,117,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,253,164,192,140,0,0,16,1,116,115,49,48,49,106,46,117,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,149,33,169,174,0,0,16,1,116,115,48,48,49,106,46,117,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,126,110,182,112,0,0,32,0,116,115,48,48,48,106,46,117,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,67,65,169,167,0,0,32,0,116,115,48,48,50,106,46,117,51,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,230,113,18,97,0,0,32,0,116,115,48,49,48,46,117,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,36,83,147,223,0,0,32,0,116,115,48,50,48,46,117,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,93,195,88,235,0,0,32,0,116,115,48,51,48,46,117,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,209,233,104,29,0,0,64,0,15,0,0,0,255,255,0,0,0,0,0,0,16,0,0,0,255,255,128,0,0,0,0,0,17,0,0,0,255,255,126,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,16,0,0,0,1,128,128,0,120,97,1,0,16,0,0,0,1,128,0,0,96,19,1,0,0,0,0,0,254,0,4,0,128,129,4,0,17,0,0,0,1,3,3,0,208,75,4,0,17,0,0,0,1,3,2,0,8,49,4,0,17,0,0,0,1,3,1,0,152,21,4,0,17,0,0,0,1,3,0,0,72,246,3,0,0,0,0,0,254,0,2,0,32,4,2,0,17,0,0,0,1,4,0,0,0,124,1,0,17,0,0,0,1,4,4,0,184,122,1,0,0,0,0,0,254,0,4,0,72,202,5,0,17,0,0,0,1,24,24,0,80,246,3,0,17,0,0,0,1,24,16,0,80,124,6,0,17,0,0,0,1,24,8,0,112,212,3,0,17,0,0,0,1,24,0,0,248,160,5,0,0,0,0,0,254,0,2,0,128,112,3,0,17,0,0,0,1,32,32,0,168,22,4,0,17,0,0,0,1,32,0,0,80,122,1,0,0,0,0,0,254,0,2,0,64,37,5,0,17,0,0,0,1,64,64,0,152,53,6,0,17,0,0,0,1,64,0,0,112,216,4,0,0,0,0,0,98,97,103,109,97,110,109,50,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,190,158,118,83,1,0,16,1,98,97,103,109,97,110,109,50,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,135,187,53,148,1,0,16,1,98,97,103,109,97,110,109,50,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,246,167,123,243,1,0,16,1,98,97,103,109,97,110,109,50,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,158,13,231,241,4,0,32,0,98,97,103,109,97,110,109,50,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,196,72,126,119,4,0,32,0,98,97,103,109,97,110,109,99,46,99,108,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,135,125,12,106,7,0,32,0,101,105,48,52,45,49,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,167,88,241,75,0,0,16,1,101,105,48,49,45,49,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,12,17,245,116,0,0,16,1,101,105,48,54,46,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,87,218,248,63,0,0,16,1,101,105,48,51,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,148,189,242,248,0,0,16,1,101,105,48,55,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,75,239,177,159,0,0,16,1,101,105,50,53,46,49,53,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,105,154,245,188,0,0,32,0,101,105,50,54,46,49,54,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,184,103,255,154,0,0,32,0,101,105,49,56,46,49,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,229,195,207,5,0,0,32,0,101,105,50,48,46,49,55,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,143,152,30,225,0,0,32,0,101,105,50,50,46,49,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,128,216,147,184,0,0,32,0,101,105,50,52,46,49,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,218,109,34,111,0,0,32,0,101,105,51,48,46,57,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,209,160,45,152,0,0,32,0,101,105,50,56,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,59,187,30,240,0,0,32,0,101,105,49,53,46,49,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,48,125,138,163,0,0,32,0,101,105,49,54,46,49,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,51,38,228,23,0,0,32,0,101,105,49,49,46,49,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,108,50,119,58,0,0,32,0,101,105,49,50,46,49,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,52,161,162,254,0,0,32,0,101,105,49,51,46,49,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,81,39,174,229,0,0,32,0,101,105,49,52,46,49,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,10,118,60,232,0,0,32,0,101,105,48,57,46,49,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,40,230,1,105,0,0,32,0,101,105,49,48,46,49,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,26,138,238,238,0,0,32,0,101,105,48,56,46,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,62,70,135,60,0,0,64,0,101,105,51,49,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,16,16,24,0,0,0,255,255,255,0,0,0,0,0,25,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,200,87,7,0,24,0,0,0,1,3,0,0,176,45,8,0,24,0,0,0,1,3,1,0,224,127,8,0,24,0,0,0,1,3,3,0,32,123,8,0,24,0,0,0,1,3,2,0,192,110,8,0,0,0,0,0,254,0,4,0,160,123,6,0,24,0,0,0,1,12,0,0,176,45,8,0,24,0,0,0,1,12,4,0,224,127,8,0,24,0,0,0,1,12,12,0,32,123,8,0,24,0,0,0,1,12,8,0,192,110,8,0,0,0,0,0,254,0,2,0,232,75,4,0,24,0,0,0,1,16,16,0,96,135,7,0,24,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,24,0,0,0,1,32,0,0,96,135,7,0,24,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,24,0,0,0,1,64,64,0,96,135,7,0,24,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,25,0,0,0,1,3,1,0,192,255,2,0,25,0,0,0,1,3,3,0,8,49,4,0,25,0,0,0,1,3,2,0,72,246,3,0,25,0,0,0,1,3,0,0,112,49,6,0,0,0,0,0,254,0,4,0,72,202,5,0,25,0,0,0,1,12,8,0,80,246,3,0,25,0,0,0,1,12,12,0,248,38,7,0,25,0,0,0,1,12,4,0,112,212,3,0,25,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,2,0,192,125,6,0,25,0,0,0,1,16,16,0,56,111,3,0,25,0,0,0,1,16,0,0,104,134,3,0,19,0,0,0,255,255,0,0,0,0,0,0,20,0,0,0,255,255,16,0,0,0,0,0,21,0,0,0,255,255,0,0,0,0,0,0,22,0,0,0,255,255,0,0,0,0,0,0,19,0,0,0,254,0,4,0,200,87,7,0,19,0,0,0,1,3,0,0,208,239,7,0,19,0,0,0,1,3,1,0,120,187,7,0,19,0,0,0,1,3,2,0,136,23,1,0,19,0,0,0,1,3,3,0,80,177,6,0,19,0,0,0,254,0,4,0,160,123,6,0,19,0,0,0,1,12,4,0,160,36,8,0,19,0,0,0,1,12,0,0,208,239,7,0,19,0,0,0,1,12,8,0,120,187,7,0,19,0,0,0,1,12,12,0,136,23,1,0,20,0,0,0,254,0,2,0,200,30,2,0,20,0,0,0,1,16,16,0,120,97,1,0,20,0,0,0,1,16,0,0,96,19,1,0,21,0,0,0,254,0,8,0,64,37,5,0,21,0,0,0,1,7,0,0,64,218,8,0,21,0,0,0,1,7,1,0,48,209,8,0,21,0,0,0,1,7,2,0,176,204,8,0,21,0,0,0,1,7,3,0,72,130,7,0,21,0,0,0,1,7,4,0,8,49,6,0,21,0,0,0,1,7,5,0,160,191,4,0,21,0,0,0,1,7,6,0,240,159,4,0,21,0,0,0,1,7,7,0,120,7,5,0,21,0,0,0,254,0,6,0,72,202,5,0,21,0,0,0,1,56,0,0,24,205,7,0,21,0,0,0,1,56,8,0,192,255,2,0,21,0,0,0,1,56,16,0,208,75,4,0,21,0,0,0,1,56,24,0,8,49,4,0,21,0,0,0,1,56,32,0,152,21,4,0,21,0,0,0,1,56,40,0,72,246,3,0,22,0,0,0,254,0,2,0,104,159,3,0,22,0,0,0,1,4,4,0,56,111,3,0,22,0,0,0,1,4,0,0,104,134,3,0,22,0,0,0,254,0,2,0,24,176,8,0,22,0,0,0,1,8,8,0,56,111,3,0,22,0,0,0,1,8,0,0,104,134,3,0,0,0,0,0,26,0,0,0,255,255,8,0,0,0,0,0,0,0,0,0,254,0,2,0,232,75,4,0,26,0,0,0,1,8,8,0,96,135,7,0,26,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,2,0,240,87,7,0,26,0,0,0,1,128,0,0,96,135,7,0,26,0,0,0,1,128,128,0,152,182,7,0,0,0,0,0,17,0,0,0,255,255,255,0,0,0,0,0,18,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,232,75,4,0,18,0,0,0,1,1,1,0,96,135,7,0,18,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,80,3,0,18,0,0,0,1,2,2,0,96,135,7,0,18,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,8,0,192,56,2,0,18,0,0,0,1,28,0,0,176,193,3,0,18,0,0,0,1,28,16,0,208,196,4,0,18,0,0,0,1,28,8,0,56,233,4,0,18,0,0,0,1,28,28,0,16,42,5,0,18,0,0,0,1,28,12,0,152,11,5,0,18,0,0,0,1,28,20,0,24,27,4,0,18,0,0,0,1,28,4,0,48,31,3,0,18,0,0,0,1,28,24,0,32,143,3,0,0,0,0,0,254,0,8,0,0,70,2,0,18,0,0,0,1,224,0,0,176,193,3,0,18,0,0,0,1,224,128,0,208,196,4,0,18,0,0,0,1,224,64,0,56,233,4,0,18,0,0,0,1,224,224,0,16,42,5,0,18,0,0,0,1,224,96,0,152,11,5,0,18,0,0,0,1,224,160,0,24,27,4,0,18,0,0,0,1,224,32,0,48,31,3,0,18,0,0,0,1,224,192,0,32,143,3,0,0,0,0,0,254,0,2,0,72,217,6,0,17,0,0,0,1,1,0,0,56,111,3,0,17,0,0,0,1,1,1,0,104,134,3,0,0,0,0,0,254,0,2,0,40,73,5,0,17,0,0,0,1,2,0,0,96,135,7,0,17,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,17,0,0,0,1,12,4,0,80,246,3,0,17,0,0,0,1,12,12,0,248,38,7,0,17,0,0,0,1,12,8,0,112,212,3,0,17,0,0,0,1,12,0,0,144,196,4,0,0,0,0,0,254,0,4,0,40,148,2,0,17,0,0,0,1,48,48,0,0,167,2,0,17,0,0,0,1,48,16,0,200,152,2,0,17,0,0,0,1,48,32,0,232,140,2,0,17,0,0,0,1,48,0,0,208,129,2,0,0,0,0,0,254,0,4,0,128,129,4,0,17,0,0,0,1,192,192,0,8,49,4,0,17,0,0,0,1,192,64,0,152,21,4,0,17,0,0,0,1,192,128,0,72,246,3,0,17,0,0,0,1,192,0,0,72,0,3,0,0,0,0,0,34,0,0,0,255,255,191,0,0,0,0,0,35,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,34,0,0,0,1,3,2,0,208,75,4,0,34,0,0,0,1,3,3,0,8,49,4,0,34,0,0,0,1,3,1,0,152,21,4,0,34,0,0,0,1,3,0,0,72,246,3,0,0,0,0,0,254,0,4,0,72,202,5,0,34,0,0,0,1,12,8,0,80,246,3,0,34,0,0,0,1,12,12,0,80,124,6,0,34,0,0,0,1,12,4,0,112,212,3,0,34,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,2,0,128,184,7,0,34,0,0,0,1,16,16,0,96,135,7,0,34,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,34,0,0,0,1,32,0,0,56,111,3,0,34,0,0,0,1,32,32,0,104,134,3,0,0,0,0,0,254,0,2,0,168,234,7,0,34,0,0,0,1,64,64,0,96,135,7,0,34,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,34,0,0,0,1,128,128,0,96,135,7,0,34,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,35,0,0,0,1,1,1,0,96,135,7,0,35,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,4,0,200,30,2,0,35,0,0,0,1,6,4,0,224,228,7,0,35,0,0,0,1,6,6,0,80,225,7,0,35,0,0,0,1,6,2,0,168,221,7,0,35,0,0,0,1,6,0,0,96,19,1,0,0,0,0,0,254,0,2,0,96,46,8,0,35,0,0,0,1,8,8,0,192,255,2,0,35,0,0,0,1,8,0,0,208,75,4,0,0,0,0,0,254,0,16,0,32,4,2,0,35,0,0,0,1,240,160,0,144,160,3,0,35,0,0,0,1,240,176,0,96,135,3,0,35,0,0,0,1,240,192,0,32,136,7,0,35,0,0,0,1,240,208,0,40,88,7,0,35,0,0,0,1,240,224,0,96,39,7,0,35,0,0,0,1,240,16,0,32,202,2,0,35,0,0,0,1,240,48,0,120,113,6,0,35,0,0,0,1,240,32,0,232,228,5,0,35,0,0,0,1,240,240,0,144,251,6,0,35,0,0,0,1,240,64,0,120,211,6,0,35,0,0,0,1,240,144,0,184,164,6,0,35,0,0,0,1,240,128,0,80,74,6,0,35,0,0,0,1,240,112,0,192,32,6,0,35,0,0,0,1,240,96,0,192,234,2,0,35,0,0,0,1,240,80,0,32,242,5,0,35,0,0,0,1,240,0,0,16,227,4,0,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,154,91,72,14,1,0,16,1,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,19,5,100,193,1,0,16,1,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,238,101,194,238,1,0,16,1,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,66,228,210,165,1,0,16,1,50,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,52,207,247,69,1,0,16,1,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,107,185,53,243,1,0,16,1,111,116,49,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,240,151,210,188,2,0,16,1,111,116,50,46,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,218,18,121,222,2,0,16,1,111,116,51,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,51,169,47,186,2,0,16,1,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,185,198,249,87,4,0,32,0,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,37,243,137,233,4,0,32,0,99,48,49,115,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,171,174,60,78,7,0,32,0,17,0,0,0,255,255,0,0,0,0,0,0,18,0,0,0,255,255,1,0,0,0,0,0,19,0,0,0,255,255,14,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,18,0,0,0,1,1,1,0,120,97,1,0,18,0,0,0,1,1,0,0,96,19,1,0,0,0,0,0,254,0,2,0,128,129,4,0,18,0,0,0,1,2,0,0,8,49,4,0,18,0,0,0,1,2,2,0,72,246,3,0,0,0,0,0,254,0,3,0,32,4,2,0,19,0,0,0,1,14,12,0,216,186,1,0,19,0,0,0,1,14,14,0,24,186,1,0,19,0,0,0,1,14,10,0,128,184,1,0,0,0,0,0,11,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,72,4,1,0,11,0,0,0,1,4,0,0,96,135,7,0,11,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,254,0,2,0,32,181,6,0,11,0,0,0,1,8,0,0,96,135,7,0,11,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,0,0,120,137,6,0,11,0,0,0,1,32,0,0,96,135,7,0,11,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,11,0,0,0,1,128,0,0,96,135,7,0,11,0,0,0,1,128,128,0,152,182,7,0,0,0,0,0,20,0,0,0,255,255,63,0,0,0,0,0,21,0,0,0,255,255,127,0,0,0,0,0,22,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,232,75,4,0,20,0,0,0,1,1,1,0,96,135,7,0,20,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,40,242,7,0,20,0,0,0,1,2,2,0,120,76,7,0,20,0,0,0,1,2,0,0,48,68,7,0,0,0,0,0,254,0,4,0,216,238,6,0,20,0,0,0,1,48,0,0,248,81,6,0,20,0,0,0,1,48,48,0,80,124,6,0,20,0,0,0,1,48,16,0,176,64,8,0,20,0,0,0,1,48,32,0,128,172,6,0,0,0,0,0,254,0,2,0,240,129,6,0,20,0,0,0,1,192,192,0,224,81,6,0,20,0,0,0,1,192,0,0,72,39,6,0,0,0,0,0,254,0,8,0,80,251,5,0,21,0,0,0,1,14,0,0,24,205,7,0,21,0,0,0,1,14,8,0,192,255,2,0,21,0,0,0,1,14,4,0,208,75,4,0,21,0,0,0,1,14,12,0,8,49,4,0,21,0,0,0,1,14,14,0,152,21,4,0,21,0,0,0,1,14,2,0,72,246,3,0,21,0,0,0,1,14,10,0,72,0,3,0,21,0,0,0,1,14,6,0,64,47,7,0,0,0,0,0,254,0,4,0,120,95,4,0,21,0,0,0,1,48,32,0,184,164,4,0,21,0,0,0,1,48,48,0,112,134,3,0,21,0,0,0,1,48,16,0,80,124,6,0,21,0,0,0,1,48,0,0,64,111,3,0,0,0,0,0,254,0,3,0,112,80,4,0,21,0,0,0,1,192,0,0,192,255,2,0,21,0,0,0,1,192,64,0,8,49,4,0,21,0,0,0,1,192,128,0,72,246,3,0,0,0,0,0,254,0,9,0,160,123,6,0,22,0,0,0,1,15,8,0,128,26,4,0,22,0,0,0,1,15,9,0,16,252,3,0,22,0,0,0,1,15,10,0,160,218,3,0,22,0,0,0,1,15,11,0,112,31,1,0,22,0,0,0,1,15,12,0,184,220,8,0,22,0,0,0,1,15,13,0,88,154,8,0,22,0,0,0,1,15,14,0,200,92,8,0,22,0,0,0,1,15,15,0,104,172,6,0,22,0,0,0,1,15,0,0,16,227,4,0,0,0,0,0,254,0,9,0,200,87,7,0,22,0,0,0,1,240,128,0,128,26,4,0,22,0,0,0,1,240,144,0,16,252,3,0,22,0,0,0,1,240,160,0,160,218,3,0,22,0,0,0,1,240,176,0,112,31,1,0,22,0,0,0,1,240,192,0,184,220,8,0,22,0,0,0,1,240,208,0,88,154,8,0,22,0,0,0,1,240,224,0,200,92,8,0,22,0,0,0,1,240,240,0,104,172,6,0,22,0,0,0,1,240,0,0,16,227,4,0,0,0,0,0,97,115,116,114,105,97,110,115,46,55,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,208,163,235,33,1,0,16,1,97,115,116,114,105,97,110,115,46,55,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,205,54,164,243,1,0,16,1,97,115,116,114,105,97,110,115,46,55,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,139,227,21,41,1,0,16,1,97,115,116,114,105,97,110,115,46,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,47,107,181,45,1,0,16,1,97,115,116,114,105,97,110,115,46,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,251,94,7,65,1,0,16,1,97,115,116,114,105,97,110,115,46,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,180,116,192,119,4,0,32,0,97,115,116,114,105,97,110,115,46,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,70,204,15,195,4,0,32,0,112,114,111,109,46,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,135,125,12,106,7,0,32,0,184,40,2,0,1,0,0,0,215,155,215,0,248,191,2,0,56,250,6,0,1,0,0,0,212,155,215,0,184,160,2,0,184,164,8,0,1,0,0,0,209,155,215,0,64,246,1,0,88,149,7,0,1,0,0,0,213,155,215,0,136,224,1,0,104,28,8,0,1,0,0,0,208,155,215,0,232,209,1,0,248,23,7,0,1,0,0,0,214,155,215,0,144,189,1,0,56,210,6,0,1,0,0,0,205,155,215,0,192,135,2,0,24,163,6,0,1,0,0,0,204,155,215,0,240,108,2,0,152,122,6,0,1,0,0,0,207,155,215,0,96,82,2,0,192,72,6,0,1,0,0,0,206,155,215,0,32,56,2,0,48,123,2,0,1,0,0,0,200,155,215,0,152,30,2,0,96,69,2,0,1,0,0,0,201,155,215,0,232,10,2,0,144,55,2,0,1,0,0,0,202,155,215,0,152,138,8,0,8,198,7,0,1,0,0,0,203,155,215,0,48,119,7,0,176,223,1,0,1,0,0,0,197,155,215,0,72,198,1,0,192,209,1,0,1,0,0,0,196,155,215,0,24,182,1,0,24,198,1,0,1,0,0,0,199,155,215,0,40,167,1,0,120,189,1,0,1,0,0,0,198,155,215,0,200,149,1,0,248,187,8,0,1,0,0,0,192,155,215,0,56,126,1,0,184,179,8,0,1,0,0,0,193,155,215,0,32,101,1,0,240,173,8,0,1,0,0,0,194,155,215,0,96,32,8,0,40,180,7,0,1,0,0,0,195,155,215,0,16,68,7,0,192,122,8,0,1,0,0,0,189,155,215,0,208,174,1,0,40,116,8,0,1,0,0,0,188,155,215,0,48,160,1,0,72,110,8,0,1,0,0,0,191,155,215,0,160,140,1,0,184,102,8,0,1,0,0,0,190,155,215,0,56,112,1,0,240,45,8,0,1,0,0,0,184,155,215,0,32,92,1,0,40,38,8,0,1,0,0,0,185,155,215,0,64,77,1,0,48,32,8,0,1,0,0,0,186,155,215,0,112,157,4,0,208,119,7,0,1,0,0,0,187,155,215,0,176,194,6,0,16,17,8,0,1,0,0,0,211,155,215,0,224,12,8,0,32,77,1,0,1,0,0,0,210,155,215,0,216,70,1,0,88,212,3,0,1,0,0,0,200,154,215,0,40,185,3,0,248,5,8,0,9,0,0,0,0,156,215,0,32,58,1,0,144,250,7,0,9,0,0,0,1,156,215,0,32,58,1,0,22,0,0,0,255,255,255,0,0,0,0,0,23,0,0,0,255,255,253,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,22,0,0,0,1,15,7,0,80,252,6,0,22,0,0,0,1,15,8,0,16,242,7,0,22,0,0,0,1,15,9,0,104,236,7,0,22,0,0,0,1,15,5,0,176,51,4,0,22,0,0,0,1,15,4,0,56,24,4,0,22,0,0,0,1,15,15,0,128,230,7,0,22,0,0,0,1,15,1,0,72,216,3,0,22,0,0,0,1,15,2,0,24,188,3,0,22,0,0,0,1,15,3,0,176,162,3,0,22,0,0,0,1,15,6,0,120,211,6,0,22,0,0,0,1,15,14,0,184,164,6,0,22,0,0,0,1,15,13,0,80,74,6,0,22,0,0,0,1,15,12,0,192,32,6,0,22,0,0,0,1,15,11,0,192,234,2,0,22,0,0,0,1,15,10,0,32,242,5,0,22,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,22,0,0,0,1,240,112,0,80,252,6,0,22,0,0,0,1,240,128,0,16,242,7,0,22,0,0,0,1,240,144,0,104,236,7,0,22,0,0,0,1,240,80,0,176,51,4,0,22,0,0,0,1,240,64,0,56,24,4,0,22,0,0,0,1,240,240,0,128,230,7,0,22,0,0,0,1,240,16,0,72,216,3,0,22,0,0,0,1,240,32,0,24,188,3,0,22,0,0,0,1,240,48,0,176,162,3,0,22,0,0,0,1,240,96,0,120,211,6,0,22,0,0,0,1,240,224,0,184,164,6,0,22,0,0,0,1,240,208,0,80,74,6,0,22,0,0,0,1,240,192,0,192,32,6,0,22,0,0,0,1,240,176,0,192,234,2,0,22,0,0,0,1,240,160,0,32,242,5,0,22,0,0,0,1,240,0,0,208,236,2,0,0,0,0,0,254,0,2,0,88,131,3,0,23,0,0,0,1,1,1,0,96,135,7,0,23,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,23,0,0,0,1,2,2,0,96,135,7,0,23,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,8,0,72,202,5,0,23,0,0,0,1,28,4,0,160,246,1,0,23,0,0,0,1,28,8,0,120,103,7,0,23,0,0,0,1,28,12,0,80,246,3,0,23,0,0,0,1,28,28,0,248,38,7,0,23,0,0,0,1,28,16,0,112,212,3,0,23,0,0,0,1,28,20,0,48,90,7,0,23,0,0,0,1,28,24,0,248,160,5,0,23,0,0,0,1,28,0,0,88,32,6,0,0,0,0,0,254,0,2,0,232,53,6,0,23,0,0,0,1,32,0,0,192,255,2,0,23,0,0,0,1,32,32,0,208,75,4,0,49,52,48,49,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,145,218,169,130,1,0,16,1,49,51,48,50,46,55,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,156,180,89,204,1,0,16,1,49,50,48,51,46,55,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,101,161,197,59,1,0,16,1,49,49,48,52,46,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,208,73,1,197,1,0,16,1,53,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,158,12,114,23,1,0,16,1,54,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,219,168,87,241,1,0,16,1,55,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,182,92,8,117,1,0,16,1,56,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,199,69,125,121,1,0,16,1,117,49,48,46,106,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,224,65,41,1,4,0,32,0,117,49,50,46,106,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,175,50,97,194,4,0,32,0,117,57,46,108,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,253,88,139,252,4,0,32,0,117,49,49,46,108,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,59,179,194,220,4,0,32,0,117,110,105,119,97,114,115,46,99,108,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,24,149,199,37,7,0,32,0,12,0,0,0,255,255,0,0,0,0,0,0,13,0,0,0,255,255,64,0,0,0,0,0,14,0,0,0,255,255,1,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,12,0,0,0,1,32,0,0,120,97,1,0,12,0,0,0,1,32,32,0,96,19,1,0,0,0,0,0,254,0,2,0,232,75,4,0,12,0,0,0,1,64,0,0,96,135,7,0,12,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,4,0,32,4,2,0,13,0,0,0,1,192,64,0,128,103,7,0,13,0,0,0,1,192,0,0,16,70,1,0,13,0,0,0,1,192,128,0,152,69,1,0,13,0,0,0,1,192,192,0,104,151,6,0,0,0,0,0,254,0,4,0,64,37,5,0,14,0,0,0,1,3,0,0,120,7,5,0,14,0,0,0,1,3,1,0,152,120,3,0,14,0,0,0,1,3,2,0,136,120,6,0,14,0,0,0,1,3,3,0,176,114,3,0,0,0,0,0,254,0,2,0,128,129,4,0,14,0,0,0,1,4,0,0,152,21,4,0,14,0,0,0,1,4,4,0,72,246,3,0,18,0,0,0,255,255,0,0,0,0,0,0,19,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,18,0,0,0,1,1,0,0,120,97,1,0,18,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,2,0,144,212,8,0,18,0,0,0,1,2,0,0,96,135,7,0,18,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,18,0,0,0,1,4,0,0,96,135,7,0,18,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,18,0,0,0,1,8,8,0,96,135,7,0,18,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,4,0,32,4,2,0,18,0,0,0,1,48,32,0,96,39,7,0,18,0,0,0,1,48,0,0,144,251,6,0,18,0,0,0,1,48,48,0,120,211,6,0,18,0,0,0,1,48,16,0,184,164,6,0,0,0,0,0,254,0,4,0,72,202,5,0,19,0,0,0,1,3,1,0,80,246,3,0,19,0,0,0,1,3,0,0,248,38,7,0,19,0,0,0,1,3,2,0,80,124,6,0,19,0,0,0,1,3,3,0,112,212,3,0,0,0,0,0,254,0,2,0,120,162,5,0,19,0,0,0,1,4,0,0,208,75,4,0,19,0,0,0,1,4,4,0,192,255,2,0,0,0,0,0,112,119,103,117,46,48,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,177,151,211,115,1,0,16,1,112,119,103,117,46,48,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,21,226,29,31,1,0,16,1,112,119,103,117,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,115,190,95,131,1,0,16,1,112,119,103,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,232,12,166,135,1,0,16,1,112,119,103,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,72,177,247,1,0,16,1,112,119,103,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,62,130,98,204,1,0,16,1,112,119,103,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,166,92,200,221,1,0,16,1,112,119,103,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,40,251,196,7,1,0,16,1,112,119,103,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,142,224,143,174,5,0,32,0,112,119,103,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,88,15,86,219,5,0,32,0,112,119,103,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,148,91,71,188,5,0,32,0,112,119,103,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,247,159,67,7,5,0,32,0,112,119,103,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,99,186,249,195,5,0,32,0,112,119,103,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,123,14,91,129,5,0,32,0,112,119,103,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,27,199,9,1,5,0,32,0,112,119,103,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,190,255,117,235,5,0,32,0,112,119,103,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,228,192,165,24,10,0,16,1,112,119,103,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,166,255,223,201,10,0,16,1,112,119,103,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,51,116,143,167,12,0,64,0,112,119,103,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,208,142,67,119,12,0,64,0,112,119,103,101,46,48,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,233,227,34,232,1,0,16,1,112,119,103,101,46,48,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,57,222,137,79,1,0,16,1,112,119,103,101,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,229,36,223,131,1,0,16,1,112,119,103,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,232,12,166,135,1,0,16,1,112,119,103,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,72,177,247,1,0,16,1,112,119,103,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,62,130,98,204,1,0,16,1,112,119,103,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,166,92,200,221,1,0,16,1,112,119,103,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,40,251,196,7,1,0,16,1,112,119,103,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,142,224,143,174,5,0,32,0,112,119,103,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,88,15,86,219,5,0,32,0,112,119,103,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,148,91,71,188,5,0,32,0,112,119,103,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,247,159,67,7,5,0,32,0,112,119,103,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,99,186,249,195,5,0,32,0,112,119,103,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,123,14,91,129,5,0,32,0,112,119,103,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,27,199,9,1,5,0,32,0,112,119,103,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,190,255,117,235,5,0,32,0,112,119,103,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,228,192,165,24,10,0,16,1,112,119,103,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,166,255,223,201,10,0,16,1,112,119,103,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,51,116,143,167,12,0,64,0,112,119,103,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,208,142,67,119,12,0,64,0,168,86,7,0,1,0,0,0,212,47,216,0,248,191,2,0,24,38,7,0,1,0,0,0,208,47,216,0,184,160,2,0,56,210,6,0,1,0,0,0,35,48,216,0,192,135,2,0,24,163,6,0,1,0,0,0,34,48,216,0,240,108,2,0,152,122,6,0,1,0,0,0,33,48,216,0,96,82,2,0,192,72,6,0,1,0,0,0,32,48,216,0,32,56,2,0,152,31,6,0,1,0,0,0,36,48,216,0,152,30,2,0,248,97,5,0,1,0,0,0,37,48,216,0,232,10,2,0,232,158,3,0,1,0,0,0,38,48,216,0,152,138,8,0,40,246,1,0,1,0,0,0,213,47,216,0,64,246,1,0,144,236,1,0,1,0,0,0,209,47,216,0,136,224,1,0,176,223,1,0,1,0,0,0,43,48,216,0,72,198,1,0,192,209,1,0,1,0,0,0,42,48,216,0,24,182,1,0,24,198,1,0,1,0,0,0,41,48,216,0,40,167,1,0,120,189,1,0,1,0,0,0,40,48,216,0,200,149,1,0,8,182,1,0,1,0,0,0,44,48,216,0,56,126,1,0,32,167,1,0,1,0,0,0,45,48,216,0,32,101,1,0,200,32,1,0,1,0,0,0,46,48,216,0,96,32,8,0,168,132,8,0,1,0,0,0,214,47,216,0,232,209,1,0,72,126,8,0,1,0,0,0,210,47,216,0,144,189,1,0,192,122,8,0,1,0,0,0,251,47,216,0,208,174,1,0,40,116,8,0,1,0,0,0,250,47,216,0,48,160,1,0,72,110,8,0,1,0,0,0,249,47,216,0,160,140,1,0,184,102,8,0,1,0,0,0,248,47,216,0,56,112,1,0,248,93,8,0,1,0,0,0,252,47,216,0,32,92,1,0,152,86,8,0,1,0,0,0,253,47,216,0,64,77,1,0,176,103,1,0,1,0,0,0,254,47,216,0,112,157,4,0,88,212,3,0,1,0,0,0,144,46,216,0,40,185,3,0,240,152,1,0,1,0,0,0,201,47,216,0,216,70,1,0,16,17,8,0,1,0,0,0,202,47,216,0,224,12,8,0,136,67,2,0,1,0,0,0,176,48,216,0,48,119,7,0,8,66,2,0,1,0,0,0,184,48,216,0,112,109,7,0,112,119,103,101,100,46,48,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,131,212,107,73,1,0,16,1,112,119,103,101,100,46,48,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,143,163,214,155,1,0,16,1,112,119,103,101,100,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,15,211,17,76,1,0,16,1,112,119,103,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,232,12,166,135,1,0,16,1,112,119,103,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,72,177,247,1,0,16,1,112,119,103,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,62,130,98,204,1,0,16,1,112,119,103,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,166,92,200,221,1,0,16,1,112,119,103,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,40,251,196,7,1,0,16,1,112,119,103,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,142,224,143,174,5,0,32,0,112,119,103,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,88,15,86,219,5,0,32,0,112,119,103,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,148,91,71,188,5,0,32,0,112,119,103,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,247,159,67,7,5,0,32,0,112,119,103,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,99,186,249,195,5,0,32,0,112,119,103,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,123,14,91,129,5,0,32,0,112,119,103,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,27,199,9,1,5,0,32,0,112,119,103,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,190,255,117,235,5,0,32,0,112,119,103,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,228,192,165,24,10,0,16,1,112,119,103,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,166,255,223,201,10,0,16,1,112,119,103,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,51,116,143,167,12,0,64,0,112,119,103,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,208,142,67,119,12,0,64,0,99,112,117,46,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,251,253,123,13,1,0,16,1,99,112,117,46,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,19,50,70,118,1,0,16,1,99,112,117,46,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,240,213,198,44,1,0,16,1,99,112,117,46,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,187,141,39,97,1,0,16,1,99,112,117,46,50,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,140,141,21,251,1,0,16,1,115,111,117,110,100,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,83,119,238,84,2,0,16,1,115,111,117,110,100,46,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,192,254,24,82,2,0,16,1,99,112,117,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,209,164,61,138,4,0,32,0,99,112,117,46,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,19,177,189,133,4,0,32,0,56,50,115,49,50,51,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,13,249,135,155,7,0,32,0,17,0,0,0,255,255,0,0,0,0,0,0,18,0,0,0,255,255,2,0,0,0,0,0,19,0,0,0,255,255,4,0,0,0,0,0,0,0,0,0,254,0,2,0,128,129,4,0,18,0,0,0,1,1,0,0,8,49,4,0,18,0,0,0,1,1,1,0,72,246,3,0,0,0,0,0,254,0,2,0,168,234,7,0,18,0,0,0,1,2,0,0,96,135,7,0,18,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,4,0,32,4,2,0,19,0,0,0,1,6,4,0,128,103,7,0,19,0,0,0,1,6,6,0,56,52,2,0,19,0,0,0,1,6,2,0,224,44,2,0,19,0,0,0,1,6,0,0,224,43,2,0,0,0,0,0,254,0,2,0,200,30,2,0,19,0,0,0,1,8,0,0,120,97,1,0,19,0,0,0,1,8,8,0,96,19,1,0,0,0,0,0,168,86,7,0,1,0,0,0,250,255,146,0,248,191,2,0,24,38,7,0,1,0,0,0,248,255,146,0,184,160,2,0,56,210,6,0,1,0,0,0,240,255,146,0,192,135,2,0,24,163,6,0,1,0,0,0,241,255,146,0,240,108,2,0,152,122,6,0,1,0,0,0,242,255,146,0,96,82,2,0,192,72,6,0,1,0,0,0,243,255,146,0,32,56,2,0,200,110,3,0,1,0,0,0,244,255,146,0,152,30,2,0,120,89,3,0,1,0,0,0,245,255,146,0,232,10,2,0,120,74,3,0,1,0,0,0,246,255,146,0,152,138,8,0,40,246,1,0,1,0,0,0,251,255,146,0,64,246,1,0,144,236,1,0,1,0,0,0,249,255,146,0,136,224,1,0,176,223,1,0,1,0,0,0,88,247,146,0,72,198,1,0,192,209,1,0,1,0,0,0,89,247,146,0,24,182,1,0,24,198,1,0,1,0,0,0,90,247,146,0,40,167,1,0,120,189,1,0,1,0,0,0,91,247,146,0,200,149,1,0,224,22,1,0,1,0,0,0,92,247,146,0,56,126,1,0,160,14,1,0,1,0,0,0,93,247,146,0,32,101,1,0,176,9,1,0,1,0,0,0,94,247,146,0,96,32,8,0,88,212,3,0,1,0,0,0,56,219,146,0,40,185,3,0,16,17,8,0,1,0,0,0,96,247,146,0,224,12,8,0,56,58,1,0,1,0,0,0,98,247,146,0,64,50,1,0,72,65,1,0,9,0,0,0,144,5,147,0,32,58,1,0,48,50,1,0,9,0,0,0,145,5,147,0,32,58,1,0,11,0,0,0,255,255,254,0,0,0,0,0,12,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,11,0,0,0,1,1,0,0,120,97,1,0,11,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,2,0,144,212,8,0,11,0,0,0,1,2,2,0,96,135,7,0,11,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,11,0,0,0,1,4,4,0,96,135,7,0,11,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,11,0,0,0,1,8,0,0,96,135,7,0,11,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,11,0,0,0,1,48,0,0,32,136,7,0,11,0,0,0,1,48,16,0,40,88,7,0,11,0,0,0,1,48,32,0,96,39,7,0,11,0,0,0,1,48,48,0,144,251,6,0,0,0,0,0,254,0,4,0,160,123,6,0,11,0,0,0,1,192,192,0,184,164,6,0,11,0,0,0,1,192,128,0,80,74,6,0,11,0,0,0,1,192,64,0,192,32,6,0,11,0,0,0,1,192,0,0,32,242,5,0,0,0,0,0,254,0,4,0,72,202,5,0,12,0,0,0,1,3,2,0,80,246,3,0,12,0,0,0,1,3,3,0,80,124,6,0,12,0,0,0,1,3,1,0,112,212,3,0,12,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,64,37,5,0,12,0,0,0,1,12,0,0,152,126,7,0,12,0,0,0,1,12,12,0,96,123,7,0,12,0,0,0,1,12,4,0,64,119,7,0,12,0,0,0,1,12,8,0,128,114,7,0,0,0,0,0,254,0,0,0,128,129,4,0,12,0,0,0,1,48,32,0,208,75,4,0,12,0,0,0,1,48,48,0,8,49,4,0,12,0,0,0,1,48,16,0,152,21,4,0,12,0,0,0,1,48,0,0,72,246,3,0,0,0,0,0,254,0,2,0,104,159,3,0,12,0,0,0,1,128,0,0,56,111,3,0,12,0,0,0,1,128,128,0,104,134,3,0,11,0,0,0,255,255,254,0,0,0,0,0,12,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,11,0,0,0,1,1,0,0,120,97,1,0,11,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,2,0,144,212,8,0,11,0,0,0,1,2,2,0,96,135,7,0,11,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,11,0,0,0,1,4,4,0,96,135,7,0,11,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,11,0,0,0,1,8,0,0,96,135,7,0,11,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,11,0,0,0,1,48,16,0,96,39,7,0,11,0,0,0,1,48,48,0,144,251,6,0,11,0,0,0,1,48,0,0,120,211,6,0,11,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,11,0,0,0,1,192,64,0,96,39,7,0,11,0,0,0,1,192,192,0,144,251,6,0,11,0,0,0,1,192,0,0,120,211,6,0,11,0,0,0,1,192,128,0,184,164,6,0,0,0,0,0,254,0,4,0,72,202,5,0,12,0,0,0,1,3,2,0,80,246,3,0,12,0,0,0,1,3,3,0,80,124,6,0,12,0,0,0,1,3,1,0,112,212,3,0,12,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,64,37,5,0,12,0,0,0,1,12,0,0,152,126,7,0,12,0,0,0,1,12,12,0,96,123,7,0,12,0,0,0,1,12,4,0,64,119,7,0,12,0,0,0,1,12,8,0,128,114,7,0,0,0,0,0,254,0,0,0,128,129,4,0,12,0,0,0,1,48,32,0,208,75,4,0,12,0,0,0,1,48,48,0,8,49,4,0,12,0,0,0,1,48,16,0,152,21,4,0,12,0,0,0,1,48,0,0,72,246,3,0,0,0,0,0,254,0,2,0,104,159,3,0,12,0,0,0,1,128,0,0,56,111,3,0,12,0,0,0,1,128,128,0,104,134,3,0,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,191,0,0,0,0,0,21,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,240,122,4,0,19,0,0,0,1,1,0,0,64,246,3,0,19,0,0,0,1,1,1,0,8,56,3,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,2,2,0,96,135,7,0,19,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,4,4,0,96,135,7,0,19,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,8,0,0,96,135,7,0,19,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,19,0,0,0,1,48,16,0,96,39,7,0,19,0,0,0,1,48,48,0,144,251,6,0,19,0,0,0,1,48,0,0,120,211,6,0,19,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,19,0,0,0,1,192,64,0,96,39,7,0,19,0,0,0,1,192,192,0,144,251,6,0,19,0,0,0,1,192,0,0,120,211,6,0,19,0,0,0,1,192,128,0,184,164,6,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,3,3,0,80,246,3,0,20,0,0,0,1,3,2,0,112,212,3,0,20,0,0,0,1,3,1,0,48,90,7,0,20,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,64,37,5,0,20,0,0,0,1,12,12,0,48,129,4,0,20,0,0,0,1,12,8,0,80,42,3,0,20,0,0,0,1,12,4,0,176,41,3,0,20,0,0,0,1,12,0,0,232,40,3,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,48,16,0,192,255,2,0,20,0,0,0,1,48,0,0,208,75,4,0,20,0,0,0,1,48,48,0,8,49,4,0,20,0,0,0,1,48,32,0,72,246,3,0,0,0,0,0,254,0,1,0,240,122,4,0,20,0,0,0,1,64,64,0,224,120,4,0,0,0,0,0,254,0,2,0,32,176,1,0,20,0,0,0,1,128,128,0,192,255,2,0,20,0,0,0,1,128,0,0,208,75,4,0,0,0,0,0,16,0,0,0,255,255,6,0,0,0,0,0,17,0,0,0,255,255,13,0,0,0,0,0,0,0,0,0,254,0,2,0,128,129,4,0,16,0,0,0,1,1,0,0,8,49,4,0,16,0,0,0,1,1,1,0,72,246,3,0,0,0,0,0,254,0,2,0,200,30,2,0,16,0,0,0,1,2,2,0,120,97,1,0,16,0,0,0,1,2,0,0,96,19,1,0,0,0,0,0,254,0,2,0,144,212,8,0,16,0,0,0,1,4,4,0,96,135,7,0,16,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,72,202,5,0,16,0,0,0,1,8,0,0,80,246,3,0,16,0,0,0,1,8,8,0,112,212,3,0,0,0,0,0,254,0,16,0,32,4,2,0,16,0,0,0,1,240,16,0,200,252,3,0,16,0,0,0,1,240,32,0,208,244,3,0,16,0,0,0,1,240,0,0,240,235,3,0,16,0,0,0,1,240,48,0,176,110,4,0,16,0,0,0,1,240,64,0,32,227,3,0,16,0,0,0,1,240,80,0,200,215,5,0,16,0,0,0,1,240,96,0,48,224,3,0,16,0,0,0,1,240,112,0,144,219,3,0,16,0,0,0,1,240,128,0,128,214,3,0,16,0,0,0,1,240,144,0,240,79,5,0,16,0,0,0,1,240,160,0,32,50,5,0,16,0,0,0,1,240,224,0,16,19,5,0,16,0,0,0,1,240,176,0,104,240,4,0,16,0,0,0,1,240,192,0,88,206,4,0,16,0,0,0,1,240,208,0,96,172,4,0,16,0,0,0,1,240,240,0,16,227,4,0,0,0,0,0,254,0,2,0,152,112,4,0,17,0,0,0,1,1,1,0,192,255,2,0,17,0,0,0,1,1,0,0,208,75,4,0,0,0,0,0,254,0,2,0,168,234,7,0,17,0,0,0,1,2,2,0,96,135,7,0,17,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,4,0,64,37,5,0,17,0,0,0,1,12,12,0,40,226,3,0,17,0,0,0,1,12,4,0,152,195,3,0,17,0,0,0,1,12,8,0,160,169,3,0,17,0,0,0,1,12,0,0,120,7,5,0,18,0,0,0,255,255,255,0,0,0,0,0,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,72,202,5,0,18,0,0,0,1,3,2,0,80,246,3,0,18,0,0,0,1,3,3,0,248,38,7,0,18,0,0,0,1,3,1,0,112,212,3,0,18,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,3,0,208,155,8,0,18,0,0,0,1,12,12,0,24,94,8,0,18,0,0,0,1,12,8,0,88,190,6,0,18,0,0,0,1,12,4,0,176,241,7,0,0,0,0,0,254,0,3,0,88,190,7,0,18,0,0,0,1,48,48,0,24,94,8,0,18,0,0,0,1,48,32,0,88,190,6,0,18,0,0,0,1,48,16,0,176,241,7,0,0,0,0,0,254,0,8,0,32,4,2,0,19,0,0,0,1,7,0,0,112,31,1,0,19,0,0,0,1,7,1,0,184,220,8,0,19,0,0,0,1,7,2,0,88,154,8,0,19,0,0,0,1,7,3,0,200,92,8,0,19,0,0,0,1,7,7,0,104,172,6,0,19,0,0,0,1,7,6,0,216,129,6,0,19,0,0,0,1,7,5,0,184,81,6,0,19,0,0,0,1,7,4,0,48,39,6,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,16,16,0,96,135,7,0,19,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,32,0,0,96,135,7,0,19,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,128,112,3,0,20,0,0,0,1,255,0,0,224,247,3,0,20,0,0,0,1,255,255,0,168,22,4,0,98,55,55,45,50,50,46,105,99,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,222,13,64,103,2,0,16,1,98,55,55,45,50,54,46,105,99,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,105,9,77,205,2,0,16,1,98,55,55,45,50,52,46,105,99,54,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,237,67,230,149,6,0,16,1,98,55,55,45,50,51,46,105,99,54,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,28,125,90,57,6,0,16,1,98,55,55,45,50,48,46,105,99,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,183,84,186,132,9,0,16,1,98,55,55,45,48,53,46,105,99,49,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,255,240,56,114,11,0,32,0,98,55,55,45,48,52,46,105,99,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,108,190,208,190,17,0,32,0,98,55,55,45,48,51,46,105,99,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,167,48,48,154,17,0,32,0,98,55,55,45,48,50,46,105,99,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,46,13,234,218,17,0,32,0,98,55,55,45,48,49,46,105,99,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,13,0,171,205,17,0,32,0,98,55,55,45,48,55,46,105,99,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,94,252,177,125,22,0,32,0,98,55,55,45,48,54,46,105,99,51,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,237,42,206,23,0,32,0,98,55,55,45,48,57,46,105,99,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,217,90,142,148,24,0,64,0,98,55,55,45,48,56,46,105,99,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,133,148,155,17,25,0,64,0,98,55,55,45,49,55,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,48,31,248,251,0,0,0,8,98,55,55,45,49,56,46,105,99,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,244,143,125,123,0,0,0,8,14,0,0,0,255,255,127,0,0,0,0,0,15,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,14,0,0,0,1,128,128,0,80,46,8,0,14,0,0,0,1,128,0,0,120,97,1,0,0,0,0,0,254,0,2,0,232,75,4,0,14,0,0,0,1,32,32,0,96,135,7,0,14,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,14,0,0,0,1,16,0,0,96,135,7,0,14,0,0,0,1,16,16,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,14,0,0,0,1,12,0,0,80,252,6,0,14,0,0,0,1,12,8,0,16,242,7,0,14,0,0,0,1,12,4,0,104,236,7,0,14,0,0,0,1,12,12,0,128,230,7,0,0,0,0,0,254,0,4,0,160,123,6,0,14,0,0,0,1,3,3,0,8,201,6,0,14,0,0,0,1,3,1,0,200,197,6,0,14,0,0,0,1,3,2,0,152,194,6,0,14,0,0,0,1,3,0,0,248,189,6,0,0,0,0,0,254,0,4,0,72,202,5,0,15,0,0,0,1,192,64,0,80,246,3,0,15,0,0,0,1,192,192,0,248,38,7,0,15,0,0,0,1,192,128,0,112,212,3,0,15,0,0,0,1,192,0,0,248,160,5,0,0,0,0,0,254,0,4,0,64,37,5,0,15,0,0,0,1,48,0,0,152,53,6,0,15,0,0,0,1,48,48,0,8,49,6,0,15,0,0,0,1,48,16,0,184,43,6,0,15,0,0,0,1,48,32,0,160,191,4,0,0,0,0,0,254,0,4,0,128,129,4,0,15,0,0,0,1,12,8,0,192,255,2,0,15,0,0,0,1,12,4,0,208,75,4,0,15,0,0,0,1,12,12,0,8,49,4,0,15,0,0,0,1,12,0,0,72,246,3,0,114,97,49,45,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,147,147,188,88,1,0,16,1,114,97,49,45,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,246,198,79,87,1,0,16,1,114,97,49,45,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,229,31,124,47,1,0,16,1,114,97,49,45,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,163,93,138,174,1,0,16,1,114,97,52,45,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,79,11,48,135,2,0,16,1,114,97,52,45,53,100,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,254,95,78,175,2,0,16,1,114,97,54,45,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,8,138,63,76,4,0,32,0,114,97,54,45,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,159,124,12,179,4,0,32,0,99,111,108,114,54,102,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,199,51,227,252,7,0,32,0,15,0,0,0,255,255,0,0,0,0,0,0,16,0,0,0,255,255,2,0,0,0,0,0,17,0,0,0,255,255,4,0,0,0,0,0,0,0,0,0,254,0,2,0,128,129,4,0,16,0,0,0,1,1,0,0,8,49,4,0,16,0,0,0,1,1,1,0,72,246,3,0,0,0,0,0,254,0,2,0,168,234,7,0,16,0,0,0,1,2,0,0,96,135,7,0,16,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,4,0,32,4,2,0,17,0,0,0,1,6,4,0,128,103,7,0,17,0,0,0,1,6,6,0,56,52,2,0,17,0,0,0,1,6,2,0,224,44,2,0,17,0,0,0,1,6,0,0,224,43,2,0,0,0,0,0,254,0,2,0,200,30,2,0,17,0,0,0,1,8,0,0,120,97,1,0,17,0,0,0,1,8,8,0,96,19,1,0,0,0,0,0,22,0,0,0,255,255,255,0,0,0,0,0,23,0,0,0,255,255,248,0,0,0,0,0,24,0,0,0,255,255,128,0,0,0,0,0,0,0,0,0,254,0,10,0,160,123,6,0,22,0,0,0,1,15,7,0,32,136,7,0,22,0,0,0,1,15,8,0,40,88,7,0,22,0,0,0,1,15,9,0,96,39,7,0,22,0,0,0,1,15,15,0,144,251,6,0,22,0,0,0,1,15,14,0,184,164,6,0,22,0,0,0,1,15,13,0,80,74,6,0,22,0,0,0,1,15,12,0,192,32,6,0,22,0,0,0,1,15,11,0,192,234,2,0,22,0,0,0,1,15,10,0,32,242,5,0,22,0,0,0,1,15,0,0,16,227,4,0,0,0,0,0,254,0,10,0,200,87,7,0,22,0,0,0,1,240,112,0,32,136,7,0,22,0,0,0,1,240,128,0,40,88,7,0,22,0,0,0,1,240,144,0,96,39,7,0,22,0,0,0,1,240,240,0,144,251,6,0,22,0,0,0,1,240,224,0,184,164,6,0,22,0,0,0,1,240,208,0,80,74,6,0,22,0,0,0,1,240,192,0,192,32,6,0,22,0,0,0,1,240,176,0,192,234,2,0,22,0,0,0,1,240,160,0,32,242,5,0,22,0,0,0,1,240,0,0,16,227,4,0,0,0,0,0,254,0,2,0,248,33,1,0,23,0,0,0,1,2,0,0,8,49,4,0,23,0,0,0,1,2,2,0,208,7,8,0,0,0,0,0,254,0,4,0,64,37,5,0,23,0,0,0,1,12,12,0,192,4,1,0,23,0,0,0,1,12,8,0,240,255,0,0,23,0,0,0,1,12,4,0,160,252,8,0,23,0,0,0,1,12,0,0,120,7,5,0,0,0,0,0,254,0,4,0,128,129,4,0,23,0,0,0,1,48,48,0,8,49,4,0,23,0,0,0,1,48,32,0,152,21,4,0,23,0,0,0,1,48,16,0,72,246,3,0,23,0,0,0,1,48,0,0,80,42,2,0,0,0,0,0,254,0,4,0,72,202,5,0,23,0,0,0,1,192,192,0,160,203,8,0,23,0,0,0,1,192,64,0,80,246,3,0,23,0,0,0,1,192,128,0,112,212,3,0,23,0,0,0,1,192,0,0,24,99,5,0,0,0,0,0,254,0,2,0,232,75,4,0,24,0,0,0,1,128,0,0,152,182,7,0,24,0,0,0,1,128,128,0,96,135,7,0,184,40,2,0,1,0,0,0,47,39,216,0,248,191,2,0,56,250,6,0,1,0,0,0,39,39,216,0,184,160,2,0,184,164,8,0,1,0,0,0,46,39,216,0,64,246,1,0,88,149,7,0,1,0,0,0,38,39,216,0,136,224,1,0,240,167,7,0,1,0,0,0,28,39,216,0,192,135,2,0,176,163,7,0,1,0,0,0,30,39,216,0,240,108,2,0,208,158,7,0,1,0,0,0,45,39,216,0,96,82,2,0,184,154,7,0,1,0,0,0,44,39,216,0,32,56,2,0,176,108,2,0,1,0,0,0,43,39,216,0,152,30,2,0,8,96,7,0,1,0,0,0,40,39,216,0,72,198,1,0,48,89,7,0,1,0,0,0,24,39,216,0,24,182,1,0,16,83,7,0,1,0,0,0,37,39,216,0,40,167,1,0,96,79,7,0,1,0,0,0,36,39,216,0,200,149,1,0,48,76,7,0,1,0,0,0,35,39,216,0,56,126,1,0,88,212,3,0,1,0,0,0,48,38,216,0,40,185,3,0,16,17,8,0,1,0,0,0,42,39,216,0,224,12,8,0,248,5,8,0,9,0,0,0,112,39,216,0,32,58,1,0,144,250,7,0,9,0,0,0,113,39,216,0,32,58,1,0,248,241,7,0,9,0,0,0,114,39,216,0,32,58,1,0,72,82,8,0,9,0,0,0,115,39,216,0,32,58,1,0,168,86,7,0,1,0,0,0,119,1,147,0,248,191,2,0,24,38,7,0,1,0,0,0,117,1,147,0,184,160,2,0,56,210,6,0,1,0,0,0,192,248,146,0,192,135,2,0,24,163,6,0,1,0,0,0,193,248,146,0,240,108,2,0,152,122,6,0,1,0,0,0,194,248,146,0,96,82,2,0,192,72,6,0,1,0,0,0,195,248,146,0,32,56,2,0,200,110,3,0,1,0,0,0,113,1,147,0,152,30,2,0,120,89,3,0,1,0,0,0,112,1,147,0,232,10,2,0,40,246,1,0,1,0,0,0,118,1,147,0,64,246,1,0,144,236,1,0,1,0,0,0,116,1,147,0,136,224,1,0,176,223,1,0,1,0,0,0,196,248,146,0,72,198,1,0,192,209,1,0,1,0,0,0,197,248,146,0,24,182,1,0,24,198,1,0,1,0,0,0,198,248,146,0,40,167,1,0,120,189,1,0,1,0,0,0,199,248,146,0,200,149,1,0,224,22,1,0,1,0,0,0,115,1,147,0,56,126,1,0,160,14,1,0,1,0,0,0,114,1,147,0,32,101,1,0,88,212,3,0,1,0,0,0,240,220,146,0,40,185,3,0,72,65,1,0,9,0,0,0,200,6,147,0,32,58,1,0,184,40,2,0,1,0,0,0,122,232,148,0,248,191,2,0,56,250,6,0,1,0,0,0,121,232,148,0,184,160,2,0,184,164,8,0,1,0,0,0,123,232,148,0,64,246,1,0,88,149,7,0,1,0,0,0,120,232,148,0,136,224,1,0,56,210,6,0,1,0,0,0,240,233,148,0,192,135,2,0,24,163,6,0,1,0,0,0,241,233,148,0,240,108,2,0,152,122,6,0,1,0,0,0,242,233,148,0,96,82,2,0,192,72,6,0,1,0,0,0,243,233,148,0,32,56,2,0,48,123,2,0,1,0,0,0,244,233,148,0,152,30,2,0,96,69,2,0,1,0,0,0,245,233,148,0,232,10,2,0,176,223,1,0,1,0,0,0,48,233,148,0,72,198,1,0,192,209,1,0,1,0,0,0,49,233,148,0,24,182,1,0,24,198,1,0,1,0,0,0,50,233,148,0,40,167,1,0,120,189,1,0,1,0,0,0,51,233,148,0,200,149,1,0,248,187,8,0,1,0,0,0,52,233,148,0,56,126,1,0,184,179,8,0,1,0,0,0,53,233,148,0,32,101,1,0,88,212,3,0,1,0,0,0,224,219,146,0,40,185,3,0,16,17,8,0,1,0,0,0,124,232,148,0,224,12,8,0,248,5,8,0,9,0,0,0,136,94,147,0,32,58,1,0,144,250,7,0,9,0,0,0,137,94,147,0,32,58,1,0,248,241,7,0,9,0,0,0,138,94,147,0,32,58,1,0,97,49,49,46,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,11,109,34,61,0,0,16,1,97,57,46,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,29,210,160,226,0,0,16,1,97,49,50,46,54,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,81,124,96,230,0,0,16,1,97,49,48,46,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,180,241,193,219,0,0,16,1,49,46,49,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,231,181,168,85,0,0,16,1,50,46,49,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,202,124,122,66,0,0,16,1,51,46,49,56,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,247,234,204,184,0,0,16,1,97,56,46,49,54,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,2,33,186,174,0,0,32,0,49,51,46,49,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,217,244,95,65,0,0,32,0,49,52,46,49,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,72,92,43,73,0,0,32,0,49,53,46,49,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,157,11,172,177,0,0,32,0,52,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,122,237,124,247,0,0,32,0,97,53,46,55,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,22,154,191,95,0,0,32,0,54,46,54,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,65,201,110,147,0,0,32,0,55,46,55,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,142,113,221,102,0,0,32,0,99,108,114,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,65,179,64,100,0,0,32,0,99,108,114,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,127,148,30,39,0,0,32,0,99,108,114,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,27,98,56,125,0,0,32,0,50,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,185,22,202,68,0,0,32,0,52,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,123,44,95,3,0,0,32,0,49,54,46,49,56,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,43,89,141,29,0,0,0,8,101,112,114,45,49,49,57,48,55,46,97,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,173,195,224,41,1,0,16,1,101,112,114,45,49,49,57,48,54,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,216,156,158,76,1,0,16,1,111,112,114,45,49,49,54,55,52,46,97,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,213,102,122,165,2,0,32,0,111,112,114,45,49,49,54,55,53,46,97,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,68,241,242,46,2,0,32,0,111,112,114,45,49,49,54,55,54,46,97,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,172,172,4,12,2,0,32,0,101,112,114,45,49,49,54,55,55,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,205,37,20,160,3,0,32,0,101,112,114,45,49,49,54,56,49,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,99,51,224,217,3,0,32,0,101,112,114,45,49,49,54,55,56,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,83,252,169,23,3,0,32,0,101,112,114,45,49,49,54,56,50,46,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,94,124,247,227,3,0,32,0,101,112,114,45,49,49,54,55,57,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,69,194,220,20,3,0,32,0,101,112,114,45,49,49,54,56,51,46,98,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,6,15,166,249,3,0,32,0,101,112,114,45,49,49,54,56,48,46,98,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,236,205,61,244,3,0,32,0,101,112,114,45,49,49,54,56,52,46,98,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,219,14,12,178,3,0,32,0,101,112,114,45,49,49,54,55,49,46,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,59,52,113,43,4,0,16,1,111,112,114,45,49,49,54,55,50,46,97,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,96,244,215,187,8,0,64,0,111,112,114,45,49,49,54,55,51,46,97,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,54,74,12,64,8,0,64,0,51,49,55,45,48,48,55,56,46,109,99,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,16,21,0,0,0,255,255,253,0,0,0,0,0,22,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,104,251,2,0,21,0,0,0,1,1,1,0,184,30,3,0,21,0,0,0,1,1,0,0,0,28,3,0,0,0,0,0,254,0,2,0,168,234,7,0,21,0,0,0,1,2,2,0,96,135,7,0,21,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,21,0,0,0,1,12,8,0,208,75,4,0,21,0,0,0,1,12,12,0,8,49,4,0,21,0,0,0,1,12,4,0,152,21,4,0,21,0,0,0,1,12,0,0,40,130,6,0,0,0,0,0,254,0,4,0,40,250,2,0,21,0,0,0,1,48,32,0,208,75,4,0,21,0,0,0,1,48,48,0,8,49,4,0,21,0,0,0,1,48,16,0,152,21,4,0,21,0,0,0,1,48,0,0,72,246,3,0,0,0,0,0,254,0,4,0,72,202,5,0,21,0,0,0,1,192,128,0,80,246,3,0,21,0,0,0,1,192,192,0,248,38,7,0,21,0,0,0,1,192,64,0,112,212,3,0,21,0,0,0,1,192,0,0,248,160,5,0,0,0,0,0,254,0,16,0,200,87,7,0,22,0,0,0,1,15,7,0,80,252,6,0,22,0,0,0,1,15,8,0,16,242,7,0,22,0,0,0,1,15,9,0,104,236,7,0,22,0,0,0,1,15,5,0,176,51,4,0,22,0,0,0,1,15,4,0,56,24,4,0,22,0,0,0,1,15,15,0,128,230,7,0,22,0,0,0,1,15,1,0,72,216,3,0,22,0,0,0,1,15,2,0,24,188,3,0,22,0,0,0,1,15,3,0,176,162,3,0,22,0,0,0,1,15,6,0,120,211,6,0,22,0,0,0,1,15,14,0,184,164,6,0,22,0,0,0,1,15,13,0,80,74,6,0,22,0,0,0,1,15,12,0,192,32,6,0,22,0,0,0,1,15,11,0,192,234,2,0,22,0,0,0,1,15,10,0,32,242,5,0,22,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,22,0,0,0,1,240,112,0,80,252,6,0,22,0,0,0,1,240,128,0,16,242,7,0,22,0,0,0,1,240,144,0,104,236,7,0,22,0,0,0,1,240,80,0,176,51,4,0,22,0,0,0,1,240,64,0,56,24,4,0,22,0,0,0,1,240,240,0,128,230,7,0,22,0,0,0,1,240,16,0,72,216,3,0,22,0,0,0,1,240,32,0,24,188,3,0,22,0,0,0,1,240,48,0,176,162,3,0,22,0,0,0,1,240,96,0,120,211,6,0,22,0,0,0,1,240,224,0,184,164,6,0,22,0,0,0,1,240,208,0,80,74,6,0,22,0,0,0,1,240,192,0,192,32,6,0,22,0,0,0,1,240,176,0,192,234,2,0,22,0,0,0,1,240,160,0,32,242,5,0,22,0,0,0,1,240,0,0,208,236,2,0,0,0,0,0,101,112,114,45,49,49,48,56,51,46,97,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,179,217,42,203,1,0,16,1,101,112,114,45,49,49,48,56,48,46,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,217,120,115,254,1,0,16,1,101,112,114,45,49,49,48,56,52,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,177,199,30,46,1,0,16,1,101,112,114,45,49,49,48,56,49,46,97,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,99,238,8,19,1,0,16,1,101,112,114,45,49,49,48,56,53,46,97,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,57,143,247,207,1,0,16,1,101,112,114,45,49,49,48,56,50,46,97,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,20,42,220,156,1,0,16,1,101,112,114,45,49,48,55,48,50,46,98,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,19,200,59,57,2,0,32,0,101,112,114,45,49,48,55,48,51,46,98,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,245,217,109,107,2,0,32,0,101,112,114,45,49,48,55,48,52,46,98,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,188,126,30,145,2,0,32,0,101,112,114,45,49,48,55,48,57,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,144,10,223,173,3,0,32,0,101,112,114,45,49,48,55,49,51,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,58,222,236,236,3,0,32,0,101,112,114,45,49,48,55,49,48,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,235,105,35,153,3,0,32,0,101,112,114,45,49,48,55,49,52,46,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,251,66,191,145,3,0,32,0,101,112,114,45,49,48,55,49,49,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,246,110,22,41,3,0,32,0,101,112,114,45,49,48,55,49,53,46,98,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,132,115,197,167,3,0,32,0,101,112,114,45,49,48,55,49,50,46,98,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,25,208,106,135,3,0,32,0,101,112,114,45,49,48,55,49,54,46,98,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,72,29,186,64,3,0,32,0,101,112,114,45,49,48,55,50,51,46,97,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,38,53,149,153,4,0,16,1,101,112,114,45,49,48,55,50,52,46,97,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,23,168,113,249,8,0,64,0,101,112,114,45,49,48,55,50,53,46,97,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,143,224,80,106,8,0,64,0,101,112,114,45,49,48,55,50,54,46,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,54,119,11,213,8,0,64,0,17,0,0,0,255,255,253,0,0,0,0,0,18,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,168,234,7,0,17,0,0,0,1,2,2,0,96,135,7,0,17,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,17,0,0,0,1,12,8,0,208,75,4,0,17,0,0,0,1,12,12,0,8,49,4,0,17,0,0,0,1,12,4,0,152,21,4,0,17,0,0,0,1,12,0,0,176,77,2,0,0,0,0,0,254,0,4,0,216,238,6,0,17,0,0,0,1,48,0,0,40,157,5,0,17,0,0,0,1,48,16,0,224,154,5,0,17,0,0,0,1,48,32,0,96,152,5,0,17,0,0,0,1,48,48,0,120,148,5,0,0,0,0,0,254,0,4,0,72,202,5,0,17,0,0,0,1,192,128,0,80,246,3,0,17,0,0,0,1,192,192,0,248,38,7,0,17,0,0,0,1,192,64,0,112,212,3,0,17,0,0,0,1,192,0,0,248,160,5,0,0,0,0,0,254,0,16,0,200,87,7,0,18,0,0,0,1,15,7,0,80,252,6,0,18,0,0,0,1,15,8,0,16,242,7,0,18,0,0,0,1,15,9,0,104,236,7,0,18,0,0,0,1,15,5,0,176,51,4,0,18,0,0,0,1,15,4,0,56,24,4,0,18,0,0,0,1,15,15,0,128,230,7,0,18,0,0,0,1,15,1,0,72,216,3,0,18,0,0,0,1,15,2,0,24,188,3,0,18,0,0,0,1,15,3,0,176,162,3,0,18,0,0,0,1,15,6,0,120,211,6,0,18,0,0,0,1,15,14,0,184,164,6,0,18,0,0,0,1,15,13,0,80,74,6,0,18,0,0,0,1,15,12,0,192,32,6,0,18,0,0,0,1,15,11,0,192,234,2,0,18,0,0,0,1,15,10,0,32,242,5,0,18,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,18,0,0,0,1,240,112,0,80,252,6,0,18,0,0,0,1,240,128,0,16,242,7,0,18,0,0,0,1,240,144,0,104,236,7,0,18,0,0,0,1,240,80,0,176,51,4,0,18,0,0,0,1,240,64,0,56,24,4,0,18,0,0,0,1,240,240,0,128,230,7,0,18,0,0,0,1,240,16,0,72,216,3,0,18,0,0,0,1,240,32,0,24,188,3,0,18,0,0,0,1,240,48,0,176,162,3,0,18,0,0,0,1,240,96,0,120,211,6,0,18,0,0,0,1,240,224,0,184,164,6,0,18,0,0,0,1,240,208,0,80,74,6,0,18,0,0,0,1,240,192,0,192,32,6,0,18,0,0,0,1,240,176,0,192,234,2,0,18,0,0,0,1,240,160,0,32,242,5,0,18,0,0,0,1,240,0,0,208,236,2,0,17,0,0,0,255,255,255,0,0,0,0,0,18,0,0,0,255,255,253,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,17,0,0,0,1,15,7,0,80,252,6,0,17,0,0,0,1,15,8,0,16,242,7,0,17,0,0,0,1,15,9,0,104,236,7,0,17,0,0,0,1,15,5,0,176,51,4,0,17,0,0,0,1,15,4,0,56,24,4,0,17,0,0,0,1,15,15,0,128,230,7,0,17,0,0,0,1,15,1,0,72,216,3,0,17,0,0,0,1,15,2,0,24,188,3,0,17,0,0,0,1,15,3,0,176,162,3,0,17,0,0,0,1,15,6,0,120,211,6,0,17,0,0,0])
.concat([1,15,14,0,184,164,6,0,17,0,0,0,1,15,13,0,80,74,6,0,17,0,0,0,1,15,12,0,192,32,6,0,17,0,0,0,1,15,11,0,192,234,2,0,17,0,0,0,1,15,10,0,32,242,5,0,17,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,17,0,0,0,1,240,112,0,80,252,6,0,17,0,0,0,1,240,128,0,16,242,7,0,17,0,0,0,1,240,144,0,104,236,7,0,17,0,0,0,1,240,80,0,176,51,4,0,17,0,0,0,1,240,64,0,56,24,4,0,17,0,0,0,1,240,240,0,128,230,7,0,17,0,0,0,1,240,16,0,72,216,3,0,17,0,0,0,1,240,32,0,24,188,3,0,17,0,0,0,1,240,48,0,176,162,3,0,17,0,0,0,1,240,96,0,120,211,6,0,17,0,0,0,1,240,224,0,184,164,6,0,17,0,0,0,1,240,208,0,80,74,6,0,17,0,0,0,1,240,192,0,192,32,6,0,17,0,0,0,1,240,176,0,192,234,2,0,17,0,0,0,1,240,160,0,32,242,5,0,17,0,0,0,1,240,0,0,208,236,2,0,0,0,0,0,254,0,2,0,168,234,7,0,18,0,0,0,1,2,2,0,96,135,7,0,18,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,18,0,0,0,1,12,8,0,208,75,4,0,18,0,0,0,1,12,12,0,8,49,4,0,18,0,0,0,1,12,4,0,152,21,4,0,18,0,0,0,1,12,0,0,176,77,2,0,0,0,0,0,254,0,4,0,216,238,6,0,18,0,0,0,1,48,0,0,120,148,5,0,18,0,0,0,1,48,16,0,232,146,5,0,18,0,0,0,1,48,32,0,96,143,5,0,18,0,0,0,1,48,48,0,128,140,5,0,0,0,0,0,254,0,4,0,72,202,5,0,18,0,0,0,1,192,128,0,80,246,3,0,18,0,0,0,1,192,192,0,248,38,7,0,18,0,0,0,1,192,64,0,112,212,3,0,18,0,0,0,1,192,0,0,248,160,5,0,168,86,7,0,1,0,0,0,190,1,147,0,248,191,2,0,24,38,7,0,1,0,0,0,191,1,147,0,184,160,2,0,56,210,6,0,1,0,0,0,186,1,147,0,192,135,2,0,24,163,6,0,1,0,0,0,187,1,147,0,240,108,2,0,152,122,6,0,1,0,0,0,184,1,147,0,96,82,2,0,192,72,6,0,1,0,0,0,185,1,147,0,32,56,2,0,200,110,3,0,1,0,0,0,188,1,147,0,152,30,2,0,120,89,3,0,1,0,0,0,189,1,147,0,232,10,2,0,40,246,1,0,1,0,0,0,254,248,146,0,64,246,1,0,144,236,1,0,1,0,0,0,255,248,146,0,136,224,1,0,176,223,1,0,1,0,0,0,250,248,146,0,72,198,1,0,192,209,1,0,1,0,0,0,251,248,146,0,24,182,1,0,24,198,1,0,1,0,0,0,248,248,146,0,40,167,1,0,120,189,1,0,1,0,0,0,249,248,146,0,200,149,1,0,224,22,1,0,1,0,0,0,252,248,146,0,56,126,1,0,160,14,1,0,1,0,0,0,253,248,146,0,32,101,1,0,88,212,3,0,1,0,0,0,56,221,146,0,40,185,3,0,16,17,8,0,1,0,0,0,220,240,146,0,224,12,8,0,72,65,1,0,9,0,0,0,0,7,147,0,32,58,1,0,48,50,1,0,9,0,0,0,1,7,147,0,32,58,1,0,224,41,1,0,9,0,0,0,2,7,147,0,32,58,1,0,26,0,0,0,255,255,255,0,0,0,0,0,27,0,0,0,255,255,255,0,0,0,0,0,28,0,0,0,255,255,255,0,0,0,0,0,29,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,0,147,7,0,26,0,0,0,1,1,1,0,192,255,2,0,26,0,0,0,1,1,0,0,208,75,4,0,0,0,0,0,254,0,8,0,200,87,7,0,26,0,0,0,1,14,0,0,96,135,3,0,26,0,0,0,1,14,2,0,32,136,7,0,26,0,0,0,1,14,4,0,40,88,7,0,26,0,0,0,1,14,6,0,96,39,7,0,26,0,0,0,1,14,14,0,144,251,6,0,26,0,0,0,1,14,12,0,184,164,6,0,26,0,0,0,1,14,10,0,80,74,6,0,26,0,0,0,1,14,8,0,192,32,6,0,0,0,0,0,254,0,8,0,160,123,6,0,26,0,0,0,1,112,0,0,96,135,3,0,26,0,0,0,1,112,16,0,32,136,7,0,26,0,0,0,1,112,32,0,40,88,7,0,26,0,0,0,1,112,48,0,96,39,7,0,26,0,0,0,1,112,112,0,144,251,6,0,26,0,0,0,1,112,96,0,184,164,6,0,26,0,0,0,1,112,80,0,80,74,6,0,26,0,0,0,1,112,64,0,192,32,6,0,0,0,0,0,254,0,2,0,88,160,1,0,26,0,0,0,1,128,128,0,192,255,2,0,26,0,0,0,1,128,0,0,208,75,4,0,0,0,0,0,254,0,4,0,72,202,5,0,27,0,0,0,1,3,3,0,24,205,7,0,27,0,0,0,1,3,2,0,192,255,2,0,27,0,0,0,1,3,1,0,208,75,4,0,27,0,0,0,1,3,0,0,8,49,4,0,0,0,0,0,254,0,2,0,232,75,4,0,27,0,0,0,1,4,4,0,96,135,7,0,27,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,72,232,5,0,27,0,0,0,1,8,0,0,160,108,4,0,27,0,0,0,1,8,8,0,224,82,4,0,0,0,0,0,254,0,2,0,168,234,7,0,27,0,0,0,1,16,0,0,96,135,7,0,27,0,0,0,1,16,16,0,152,182,7,0,0,0,0,0,254,0,2,0,16,227,4,0,27,0,0,0,1,32,32,0,96,135,7,0,27,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,253,3,0,27,0,0,0,1,64,0,0,56,111,3,0,27,0,0,0,1,64,64,0,104,134,3,0,0,0,0,0,254,0,2,0,104,159,3,0,27,0,0,0,1,128,0,0,56,111,3,0,27,0,0,0,1,128,128,0,104,134,3,0,0,0,0,0,254,0,3,0,88,140,3,0,28,0,0,0,1,3,1,0,8,49,4,0,28,0,0,0,1,3,2,0,152,21,4,0,28,0,0,0,1,3,3,0,72,0,3,0,0,0,0,0,254,0,2,0,120,79,3,0,28,0,0,0,1,4,0,0,8,49,4,0,28,0,0,0,1,4,4,0,72,246,3,0,0,0,0,0,254,0,2,0,56,49,3,0,29,0,0,0,1,1,0,0,168,22,4,0,29,0,0,0,1,1,1,0,72,180,7,0,0,0,0,0,254,0,2,0,240,238,2,0,29,0,0,0,1,2,0,0,168,22,4,0,29,0,0,0,1,2,2,0,72,180,7,0,0,0,0,0,254,0,2,0,128,94,5,0,29,0,0,0,1,4,0,0,8,196,2,0,29,0,0,0,1,4,4,0,136,179,2,0,0,0,0,0,101,112,114,45,49,48,52,52,55,46,52,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,113,127,232,41,1,0,16,1,101,112,114,45,49,48,52,52,53,46,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,111,91,206,37,1,0,16,1,101,112,114,45,49,48,52,52,56,46,52,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,181,237,186,5,1,0,16,1,101,112,114,45,49,48,52,52,54,46,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,60,210,97,205,1,0,16,1,101,112,114,45,49,48,52,51,49,46,57,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,57,44,150,167,2,0,32,0,101,112,114,45,49,48,52,51,50,46,57,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,78,210,140,219,2,0,32,0,101,112,114,45,49,48,52,51,51,46,57,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,194,200,99,225,2,0,32,0,101,112,114,45,49,48,52,51,55,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,24,118,47,82,3,0,32,0,101,112,114,45,49,48,52,52,49,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,92,163,227,116,3,0,32,0,101,112,114,45,49,48,52,51,56,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,98,99,138,115,3,0,32,0,101,112,114,45,49,48,52,52,50,46,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,20,156,203,134,3,0,32,0,101,112,114,45,49,48,52,51,57,46,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,167,172,145,179,3,0,32,0,101,112,114,45,49,48,52,52,51,46,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,53,38,211,149,3,0,32,0,101,112,114,45,49,48,52,52,48,46,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,8,149,147,35,3,0,32,0,101,112,114,45,49,48,52,52,52,46,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,35,88,17,130,3,0,32,0,101,112,114,45,49,48,52,51,52,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,206,28,20,119,4,0,16,1,55,55,53,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,252,52,149,106,6,0,16,1,101,112,114,45,49,48,52,51,53,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,227,246,137,173,7,0,64,0,101,112,114,45,49,48,52,51,54,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,19,102,199,150,7,0,64,0,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,252,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,19,0,0,0,1,15,7,0,80,252,6,0,19,0,0,0,1,15,8,0,16,242,7,0,19,0,0,0,1,15,9,0,104,236,7,0,19,0,0,0,1,15,5,0,176,51,4,0,19,0,0,0,1,15,4,0,56,24,4,0,19,0,0,0,1,15,15,0,128,230,7,0,19,0,0,0,1,15,1,0,72,216,3,0,19,0,0,0,1,15,2,0,24,188,3,0,19,0,0,0,1,15,3,0,176,162,3,0,19,0,0,0,1,15,6,0,120,211,6,0,19,0,0,0,1,15,14,0,184,164,6,0,19,0,0,0,1,15,13,0,80,74,6,0,19,0,0,0,1,15,12,0,192,32,6,0,19,0,0,0,1,15,11,0,192,234,2,0,19,0,0,0,1,15,10,0,32,242,5,0,19,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,19,0,0,0,1,240,112,0,80,252,6,0,19,0,0,0,1,240,128,0,16,242,7,0,19,0,0,0,1,240,144,0,104,236,7,0,19,0,0,0,1,240,80,0,176,51,4,0,19,0,0,0,1,240,64,0,56,24,4,0,19,0,0,0,1,240,240,0,128,230,7,0,19,0,0,0,1,240,16,0,72,216,3,0,19,0,0,0,1,240,32,0,24,188,3,0,19,0,0,0,1,240,48,0,176,162,3,0,19,0,0,0,1,240,96,0,120,211,6,0,19,0,0,0,1,240,224,0,184,164,6,0,19,0,0,0,1,240,208,0,80,74,6,0,19,0,0,0,1,240,192,0,192,32,6,0,19,0,0,0,1,240,176,0,192,234,2,0,19,0,0,0,1,240,160,0,32,242,5,0,19,0,0,0,1,240,0,0,208,236,2,0,0,0,0,0,254,0,2,0,224,117,5,0,20,0,0,0,1,1,1,0,192,152,4,0,20,0,0,0,1,1,0,0,184,112,5,0,0,0,0,0,254,0,2,0,168,234,7,0,20,0,0,0,1,2,2,0,96,135,7,0,20,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,12,12,0,8,49,4,0,20,0,0,0,1,12,8,0,152,21,4,0,20,0,0,0,1,12,4,0,72,246,3,0,20,0,0,0,1,12,0,0,40,130,6,0,0,0,0,0,254,0,4,0,64,37,5,0,20,0,0,0,1,48,32,0,176,116,6,0,20,0,0,0,1,48,48,0,80,110,6,0,20,0,0,0,1,48,16,0,112,216,4,0,20,0,0,0,1,48,0,0,120,7,5,0,0,0,0,0,254,0,4,0,248,144,4,0,20,0,0,0,1,192,128,0,104,142,4,0,20,0,0,0,1,192,192,0,176,63,4,0,20,0,0,0,1,192,64,0,136,66,4,0,20,0,0,0,1,192,0,0,200,68,4,0,0,0,0,0,97,105,114,119,111,108,102,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,135,133,26,188,0,0,16,1,97,105,114,119,111,108,102,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,92,175,199,163,0,0,16,1,97,105,114,119,111,108,102,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,233,1,10,91,0,0,32,0,97,105,114,119,111,108,102,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,31,126,229,37,0,0,32,0,97,105,114,119,111,108,102,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,233,229,13,207,0,0,32,0,97,105,114,119,111,108,102,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,72,192,80,64,0,0,32,0,97,105,114,119,111,108,102,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,210,199,251,232,0,0,32,0,97,105,114,119,111,108,102,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,107,21,212,197,0,0,32,0,97,105,114,119,111,108,102,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,177,223,145,222,0,0,32,0,48,49,106,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,163,178,148,106,0,0,32,0,48,49,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,211,35,9,236,0,0,32,0,48,49,102,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,82,112,233,173,0,0,32,0,109,49,46,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,1,146,163,131,0,0,32,0,112,97,108,49,54,108,56,97,46,50,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,0,0,0,24,101,112,108,49,50,112,54,97,46,57,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,52,0,0,0,20,143,128,25,0,0,0,8,101,112,108,49,50,112,54,97,46,57,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,52,0,0,0,133,173,172,245,0,0,0,8,18,0,0,0,255,255,255,0,0,0,0,0,19,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,232,75,4,0,18,0,0,0,1,4,4,0,96,135,7,0,18,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,96,46,8,0,18,0,0,0,1,8,8,0,208,233,4,0,18,0,0,0,1,8,0,0,72,197,4,0,0,0,0,0,254,0,8,0,200,87,7,0,18,0,0,0,1,48,32,0,96,39,7,0,18,0,0,0,1,48,48,0,144,251,6,0,18,0,0,0,1,48,16,0,184,164,6,0,18,0,0,0,1,48,0,0,32,242,5,0,18,0,0,0,1,48,32,0,96,39,7,0,18,0,0,0,1,48,48,0,144,251,6,0,18,0,0,0,1,48,16,0,80,74,6,0,18,0,0,0,1,48,0,0,192,32,6,0,0,0,0,0,254,0,8,0,160,123,6,0,18,0,0,0,1,192,128,0,96,39,7,0,18,0,0,0,1,192,192,0,144,251,6,0,18,0,0,0,1,192,64,0,184,164,6,0,18,0,0,0,1,192,0,0,32,242,5,0,18,0,0,0,1,192,128,0,96,39,7,0,18,0,0,0,1,192,192,0,144,251,6,0,18,0,0,0,1,192,64,0,80,74,6,0,18,0,0,0,1,192,0,0,192,32,6,0,0,0,0,0,254,0,4,0,72,202,5,0,19,0,0,0,1,3,2,0,80,246,3,0,19,0,0,0,1,3,3,0,248,38,7,0,19,0,0,0,1,3,1,0,48,123,8,0,19,0,0,0,1,3,0,0,8,117,8,0,0,0,0,0,254,0,2,0,72,4,1,0,19,0,0,0,1,8,8,0,96,135,7,0,19,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,19,0,0,0,1,48,48,0,8,49,4,0,19,0,0,0,1,48,32,0,152,21,4,0,19,0,0,0,1,48,16,0,72,246,3,0,19,0,0,0,1,48,0,0,64,47,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,64,0,0,96,135,7,0,19,0,0,0,1,64,64,0,152,182,7,0,18,0,0,0,255,255,255,0,0,0,0,0,19,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,232,75,4,0,18,0,0,0,1,4,4,0,96,135,7,0,18,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,18,0,0,0,1,48,16,0,96,39,7,0,18,0,0,0,1,48,48,0,144,251,6,0,18,0,0,0,1,48,0,0,120,211,6,0,18,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,18,0,0,0,1,192,64,0,96,39,7,0,18,0,0,0,1,192,192,0,144,251,6,0,18,0,0,0,1,192,0,0,120,211,6,0,18,0,0,0,1,192,128,0,184,164,6,0,0,0,0,0,254,0,4,0,72,202,5,0,19,0,0,0,1,3,2,0,80,246,3,0,19,0,0,0,1,3,3,0,248,38,7,0,19,0,0,0,1,3,1,0,48,123,8,0,19,0,0,0,1,3,0,0,8,117,8,0,0,0,0,0,254,0,2,0,72,4,1,0,19,0,0,0,1,8,8,0,96,135,7,0,19,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,19,0,0,0,1,48,48,0,8,49,4,0,19,0,0,0,1,48,32,0,152,21,4,0,19,0,0,0,1,48,16,0,72,246,3,0,19,0,0,0,1,48,0,0,64,47,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,64,0,0,96,135,7,0,19,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,101,112,114,45,49,48,51,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,201,125,117,90,1,0,16,1,101,112,114,45,49,48,51,53,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,63,107,205,242,1,0,16,1,101,112,114,45,49,48,51,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,67,177,171,248,1,0,16,1,101,112,114,45,49,48,51,52,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,55,76,67,75,1,0,16,1,101,112,114,45,49,48,51,53,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,141,29,226,237,1,0,16,1,101,112,114,45,49,48,51,52,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,18,48,30,229,1,0,16,1,101,112,114,45,49,48,50,56,49,46,57,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,218,44,233,48,2,0,32,0,101,112,114,45,49,48,50,56,50,46,57,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,16,137,123,182,2,0,32,0,101,112,114,45,49,48,50,56,51,46,57,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,45,253,219,231,2,0,32,0,101,112,114,45,49,48,50,56,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,4,61,170,152,3,0,32,0,101,112,114,45,49,48,50,56,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,152,27,157,197,3,0,32,0,101,112,114,45,49,48,50,56,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,207,80,160,141,3,0,32,0,101,112,114,45,49,48,50,57,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,35,66,53,57,3,0,32,0,101,112,114,45,49,48,50,56,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,74,183,137,121,3,0,32,0,101,112,114,45,49,48,50,57,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,92,36,75,110,3,0,32,0,101,112,114,45,49,48,50,56,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,26,85,206,211,3,0,32,0,101,112,114,45,49,48,50,57,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,163,137,242,206,3,0,32,0,101,112,114,45,49,48,50,56,52,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,22,145,240,143,4,0,16,1,51,49,55,45,48,48,49,56,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,232,75,224,254,5,0,16,1,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,252,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,19,0,0,0,1,15,7,0,80,252,6,0,19,0,0,0,1,15,8,0,16,242,7,0,19,0,0,0,1,15,9,0,104,236,7,0,19,0,0,0,1,15,5,0,176,51,4,0,19,0,0,0,1,15,4,0,56,24,4,0,19,0,0,0,1,15,15,0,128,230,7,0,19,0,0,0,1,15,1,0,72,216,3,0,19,0,0,0,1,15,2,0,24,188,3,0,19,0,0,0,1,15,3,0,176,162,3,0,19,0,0,0,1,15,6,0,120,211,6,0,19,0,0,0,1,15,14,0,184,164,6,0,19,0,0,0,1,15,13,0,80,74,6,0,19,0,0,0,1,15,12,0,192,32,6,0,19,0,0,0,1,15,11,0,192,234,2,0,19,0,0,0,1,15,10,0,32,242,5,0,19,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,19,0,0,0,1,240,112,0,80,252,6,0,19,0,0,0,1,240,128,0,16,242,7,0,19,0,0,0,1,240,144,0,104,236,7,0,19,0,0,0,1,240,80,0,176,51,4,0,19,0,0,0,1,240,64,0,56,24,4,0,19,0,0,0,1,240,240,0,128,230,7,0,19,0,0,0,1,240,16,0,72,216,3,0,19,0,0,0,1,240,32,0,24,188,3,0,19,0,0,0,1,240,48,0,176,162,3,0,19,0,0,0,1,240,96,0,120,211,6,0,19,0,0,0,1,240,224,0,184,164,6,0,19,0,0,0,1,240,208,0,80,74,6,0,19,0,0,0,1,240,192,0,192,32,6,0,19,0,0,0,1,240,176,0,192,234,2,0,19,0,0,0,1,240,160,0,32,242,5,0,19,0,0,0,1,240,0,0,208,236,2,0,0,0,0,0,254,0,2,0,200,30,2,0,20,0,0,0,1,1,0,0,120,97,1,0,20,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,2,0,168,234,7,0,20,0,0,0,1,2,2,0,96,135,7,0,20,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,12,8,0,208,75,4,0,20,0,0,0,1,12,12,0,8,49,4,0,20,0,0,0,1,12,4,0,152,21,4,0,20,0,0,0,1,12,0,0,112,49,6,0,0,0,0,0,254,0,4,0,64,37,5,0,20,0,0,0,1,48,48,0,200,124,4,0,20,0,0,0,1,48,32,0,192,122,4,0,20,0,0,0,1,48,16,0,184,120,4,0,20,0,0,0,1,48,0,0,128,118,4,0,0,0,0,0,254,0,2,0,72,202,5,0,20,0,0,0,1,64,64,0,248,38,7,0,20,0,0,0,1,64,0,0,112,212,3,0,0,0,0,0,254,0,2,0,104,159,3,0,20,0,0,0,1,128,0,0,56,111,3,0,20,0,0,0,1,128,128,0,104,134,3,0,184,40,2,0,1,0,0,0,35,39,216,0,248,191,2,0,56,250,6,0,1,0,0,0,39,39,216,0,184,160,2,0,184,164,8,0,1,0,0,0,34,39,216,0,64,246,1,0,88,149,7,0,1,0,0,0,38,39,216,0,136,224,1,0,240,167,7,0,1,0,0,0,40,39,216,0,192,135,2,0,176,163,7,0,1,0,0,0,42,39,216,0,240,108,2,0,208,158,7,0,1,0,0,0,45,39,216,0,96,82,2,0,184,154,7,0,1,0,0,0,44,39,216,0,32,56,2,0,176,108,2,0,1,0,0,0,43,39,216,0,152,30,2,0,88,212,3,0,1,0,0,0,48,38,216,0,40,185,3,0,16,17,8,0,1,0,0,0,36,39,216,0,224,12,8,0,248,5,8,0,9,0,0,0,112,39,216,0,32,58,1,0,144,250,7,0,9,0,0,0,113,39,216,0,32,58,1,0,248,241,7,0,9,0,0,0,114,39,216,0,32,58,1,0,72,82,8,0,9,0,0,0,115,39,216,0,32,58,1,0,18,0,0,0,255,255,127,0,0,0,0,0,19,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,200,87,7,0,18,0,0,0,1,3,0,0,40,88,7,0,18,0,0,0,1,3,1,0])
.concat([96,39,7,0,18,0,0,0,1,3,3,0,144,251,6,0,18,0,0,0,1,3,2,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,18,0,0,0,1,12,0,0,40,88,7,0,18,0,0,0,1,12,4,0,96,39,7,0,18,0,0,0,1,12,12,0,144,251,6,0,18,0,0,0,1,12,8,0,184,164,6,0,0,0,0,0,254,0,0,0,168,234,7,0,18,0,0,0,1,32,0,0,96,135,7,0,18,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,128,129,4,0,19,0,0,0,1,3,3,0,8,49,4,0,19,0,0,0,1,3,2,0,152,21,4,0,19,0,0,0,1,3,1,0,72,246,3,0,19,0,0,0,1,3,0,0,104,39,8,0,0,0,0,0,254,0,4,0,72,202,5,0,19,0,0,0,1,12,4,0,80,246,3,0,19,0,0,0,1,12,12,0,248,38,7,0,19,0,0,0,1,12,8,0,112,212,3,0,19,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,4,0,64,37,5,0,19,0,0,0,1,32,32,0,32,70,1,0,19,0,0,0,1,32,0,0,120,7,5,0,19,0,0,0,255,255,254,0,0,0,0,0,20,0,0,0,255,255,247,0,0,0,0,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,1,1,0,96,135,7,0,19,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,8,0,160,123,6,0,19,0,0,0,1,28,0,0,96,135,3,0,19,0,0,0,1,28,16,0,32,136,7,0,19,0,0,0,1,28,8,0,40,88,7,0,19,0,0,0,1,28,24,0,96,39,7,0,19,0,0,0,1,28,28,0,144,251,6,0,19,0,0,0,1,28,12,0,184,164,6,0,19,0,0,0,1,28,20,0,80,74,6,0,19,0,0,0,1,28,4,0,192,32,6,0,0,0,0,0,254,0,8,0,200,87,7,0,19,0,0,0,1,224,0,0,96,135,3,0,19,0,0,0,1,224,128,0,32,136,7,0,19,0,0,0,1,224,64,0,40,88,7,0,19,0,0,0,1,224,192,0,96,39,7,0,19,0,0,0,1,224,224,0,144,251,6,0,19,0,0,0,1,224,96,0,184,164,6,0,19,0,0,0,1,224,160,0,80,74,6,0,19,0,0,0,1,224,32,0,192,32,6,0,0,0,0,0,254,0,2,0,232,75,4,0,20,0,0,0,1,1,1,0,96,135,7,0,20,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,4,0,64,37,5,0,20,0,0,0,1,6,2,0,48,239,6,0,20,0,0,0,1,6,6,0,48,236,6,0,20,0,0,0,1,6,4,0,48,232,6,0,20,0,0,0,1,6,0,0,120,7,5,0,0,0,0,0,254,0,2,0,128,112,3,0,20,0,0,0,1,8,0,0,168,22,4,0,20,0,0,0,1,8,8,0,224,247,3,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,48,0,0,248,160,5,0,20,0,0,0,1,48,16,0,80,246,3,0,20,0,0,0,1,48,32,0,112,212,3,0,20,0,0,0,1,48,48,0,248,38,7,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,192,64,0,208,75,4,0,20,0,0,0,1,192,192,0,8,49,4,0,20,0,0,0,1,192,128,0,152,21,4,0,20,0,0,0,1,192,0,0,72,246,3,0,101,112,114,45,49,49,52,57,49,46,97,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,54,156,193,243,1,0,16,1,101,112,114,45,49,49,52,56,57,46,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,197,35,230,187,1,0,16,1,101,112,114,45,49,49,52,57,50,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,57,49,189,216,1,0,16,1,101,112,114,45,49,49,52,57,48,46,97,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,65,58,203,56,1,0,16,1,101,112,114,45,49,49,52,57,51,46,98,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,217,133,68,101,2,0,32,0,101,112,114,45,49,49,52,57,52,46,98,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,171,113,121,182,2,0,32,0,101,112,114,45,49,49,52,57,53,46,98,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,97,171,135,182,2,0,32,0,101,112,114,45,49,49,53,48,49,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,173,158,23,9,3,0,32,0,101,112,114,45,49,49,53,48,53,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,207,30,127,182,3,0,32,0,101,112,114,45,49,49,53,48,50,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,184,54,238,163,3,0,32,0,101,112,114,45,49,49,53,48,54,46,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,239,77,16,176,3,0,32,0,101,112,114,45,49,49,53,48,51,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,146,6,76,52,3,0,32,0,101,112,114,45,49,49,53,48,55,46,98,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,10,113,175,162,3,0,32,0,101,112,114,45,49,49,53,48,52,46,98,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,32,121,174,124,3,0,32,0,101,112,114,45,49,49,53,48,56,46,98,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,60,131,187,92,3,0,32,0,101,112,114,45,49,49,52,57,54,46,97,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,169,64,203,130,4,0,16,1,101,112,114,45,49,49,52,57,55,46,97,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,204,98,79,176,8,0,64,0,101,112,114,45,49,49,52,57,56,46,97,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,43,245,186,151,8,0,64,0,101,112,114,45,49,49,52,57,57,46,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,102,40,51,234,8,0,64,0,101,112,114,45,49,49,53,48,48,46,97,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,49,28,223,45,8,0,64,0,51,49,55,45,48,48,53,57,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,5,0,16,17,101,112,114,45,49,49,49,48,55,46,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,183,186,135,109,1,0,16,1,101,112,114,45,49,49,49,48,56,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,29,62,42,32,1,0,16,1,101,112,114,45,49,49,49,48,57,46,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,7,254,160,133,9,0,16,1,101,112,114,45,49,49,49,49,48,46,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,124,121,214,243,9,0,16,1,101,112,114,45,49,49,49,49,53,46,49,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,33,41,227,232,2,0,32,0,101,112,114,45,49,49,49,49,52,46,49,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,51,246,151,46,2,0,32,0,101,112,114,45,49,49,49,49,51,46,49,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,140,140,5,54,2,0,32,0,109,112,114,45,49,48,57,51,50,46,57,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,214,33,8,204,3,0,32,0,109,112,114,45,49,48,57,51,52,46,57,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,250,177,81,74,3,0,32,0,109,112,114,45,49,48,57,51,54,46,57,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,100,13,167,173,3,0,32,0,109,112,114,45,49,48,57,51,56,46,49,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,175,91,103,231,3,0,32,0,109,112,114,45,49,48,57,51,51,46,57,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,195,178,239,200,3,0,32,0,109,112,114,45,49,48,57,51,53,46,57,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,33,53,226,193,3,0,32,0,109,112,114,45,49,48,57,51,55,46,57,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,88,150,25,240,3,0,32,0,109,112,114,45,49,48,57,51,57,46,49,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,128,148,212,160,3,0,32,0,101,112,114,45,49,49,49,48,51,46,57,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,162,13,214,189,3,0,32,0,101,112,114,45,49,49,49,48,52,46,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,206,95,163,6,3,0,32,0,101,112,114,45,49,49,49,48,53,46,49,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,137,6,123,2,3,0,32,0,101,112,114,45,49,49,49,48,54,46,49,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,236,31,158,3,0,32,0,101,112,114,45,49,49,49,49,54,46,57,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,186,193,180,73,3,0,32,0,101,112,114,45,49,49,49,49,55,46,57,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,113,187,31,130,3,0,32,0,101,112,114,45,49,49,49,49,56,46,49,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,11,84,56,143,3,0,32,0,101,112,114,45,49,49,49,49,57,46,49,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,142,58,52,208,3,0,32,0,101,112,114,45,49,48,57,50,50,46,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,212,131,145,180,10,0,32,0,101,112,114,45,49,49,49,49,50,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,109,252,119,215,4,0,16,1,109,112,114,45,49,48,57,51,49,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,143,6,9,146,11,0,64,0,109,112,114,45,49,48,57,51,48,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,139,54,147,100,11,0,64,0,101,112,114,45,49,49,49,48,50,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,141,199,7,108,11,0,64,0,11,0,0,0,255,255,255,0,0,0,0,0,12,0,0,0,255,255,205,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,11,0,0,0,1,15,7,0,80,252,6,0,11,0,0,0,1,15,8,0,16,242,7,0,11,0,0,0,1,15,9,0,104,236,7,0,11,0,0,0,1,15,5,0,176,51,4,0,11,0,0,0,1,15,4,0,56,24,4,0,11,0,0,0,1,15,15,0,128,230,7,0,11,0,0,0,1,15,1,0,72,216,3,0,11,0,0,0,1,15,2,0,24,188,3,0,11,0,0,0,1,15,3,0,176,162,3,0,11,0,0,0,1,15,6,0,120,211,6,0,11,0,0,0,1,15,14,0,184,164,6,0,11,0,0,0,1,15,13,0,80,74,6,0,11,0,0,0,1,15,12,0,192,32,6,0,11,0,0,0,1,15,11,0,192,234,2,0,11,0,0,0,1,15,10,0,32,242,5,0,11,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,11,0,0,0,1,240,112,0,80,252,6,0,11,0,0,0,1,240,128,0,16,242,7,0,11,0,0,0,1,240,144,0,104,236,7,0,11,0,0,0,1,240,80,0,176,51,4,0,11,0,0,0,1,240,64,0,56,24,4,0,11,0,0,0,1,240,240,0,128,230,7,0,11,0,0,0,1,240,16,0,72,216,3,0,11,0,0,0,1,240,32,0,24,188,3,0,11,0,0,0,1,240,48,0,176,162,3,0,11,0,0,0,1,240,96,0,120,211,6,0,11,0,0,0,1,240,224,0,184,164,6,0,11,0,0,0,1,240,208,0,80,74,6,0,11,0,0,0,1,240,192,0,192,32,6,0,11,0,0,0,1,240,176,0,192,234,2,0,11,0,0,0,1,240,160,0,32,242,5,0,11,0,0,0,1,240,0,0,208,236,2,0,0,0,0,0,254,0,4,0,64,251,5,0,12,0,0,0,1,3,3,0,32,236,6,0,12,0,0,0,1,3,2,0,16,232,6,0,12,0,0,0,1,3,1,0,80,228,6,0,12,0,0,0,1,3,0,0,16,223,6,0,0,0,0,0,254,0,2,0,24,213,6,0,12,0,0,0,1,4,0,0,56,111,3,0,12,0,0,0,1,4,4,0,104,134,3,0,0,0,0,0,254,0,2,0,128,129,4,0,12,0,0,0,1,8,8,0,8,49,4,0,12,0,0,0,1,8,0,0,152,21,4,0,0,0,0,0,254,0,2,0,96,208,6,0,12,0,0,0,1,16,16,0,56,111,3,0,12,0,0,0,1,16,0,0,104,134,3,0,0,0,0,0,254,0,2,0,104,159,3,0,12,0,0,0,1,32,32,0,56,111,3,0,12,0,0,0,1,32,0,0,104,134,3,0,0,0,0,0,254,0,4,0,72,202,5,0,12,0,0,0,1,192,128,0,80,246,3,0,12,0,0,0,1,192,192,0,248,38,7,0,12,0,0,0,1,192,64,0,112,212,3,0,12,0,0,0,1,192,0,0,248,160,5,0,117,121,48,48,49,48,48,49,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,236,135,22,26,1,0,16,1,117,121,48,48,49,48,48,50,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,196,176,227,98,1,0,16,1,117,121,48,48,49,48,48,54,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,216,167,228,70,3,0,32,0,117,121,48,48,49,48,48,53,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,142,18,172,74,3,0,32,0,117,121,48,48,49,48,48,56,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,75,124,255,29,4,0,32,0,117,121,48,48,49,48,48,55,46,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,185,58,91,236,28,0,32,0,117,121,48,48,49,48,49,48,46,54,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,3,223,188,189,5,0,32,0,117,121,48,48,49,48,49,49,46,55,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,85,95,132,189,6,0,64,0,48,54,53,45,106,97,97,48,52,46,49,48,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,57,99,116,102,1,0,16,1,48,54,53,45,106,97,97,48,53,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,6,183,21,18,1,0,16,1,48,54,53,45,97,48,50,46,57,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,76,196,29,179,1,0,16,1,48,54,53,45,97,48,51,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,230,47,132,19,1,0,16,1,48,54,53,45,97,48,49,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,77,58,125,20,2,0,16,1,48,54,53,45,97,48,56,46,49,53,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,202,154,100,107,3,0,32,0,48,54,53,45,97,48,55,46,49,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,196,143,220,197,3,0,32,0,48,54,53,45,97,48,57,46,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,47,213,5,234,4,0,32,0,48,54,53,45,97,49,48,46,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,2,24,185,150,4,0,32,0,48,54,53,45,97,49,50,46,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,122,208,30,50,4,0,32,0,48,54,53,45,97,49,49,46,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,142,148,218,70,4,0,32,0,48,54,53,45,97,48,54,46,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,224,206,219,90,5,0,64,0,120,109,101,110,95,106,97,97,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,25,158,154,132,0,0,0,8,48,54,53,45,101,97,97,48,52,46,49,48,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,231,97,40,80,1,0,16,1,48,54,53,45,101,97,97,48,53,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,191,113,96,202,1,0,16,1,48,54,53,45,97,48,50,46,57,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,76,196,29,179,1,0,16,1,48,54,53,45,97,48,51,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,230,47,132,19,1,0,16,1,48,54,53,45,97,48,49,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,77,58,125,20,2,0,16,1,48,54,53,45,97,48,56,46,49,53,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,202,154,100,107,3,0,32,0,48,54,53,45,97,48,55,46,49,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,196,143,220,197,3,0,32,0,48,54,53,45,97,48,57,46,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,47,213,5,234,4,0,32,0])
.concat([48,54,53,45,97,49,48,46,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,2,24,185,150,4,0,32,0,48,54,53,45,97,49,50,46,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,122,208,30,50,4,0,32,0,48,54,53,45,97,49,49,46,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,142,148,218,70,4,0,32,0,48,54,53,45,97,48,54,46,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,224,206,219,90,5,0,64,0,120,109,101,110,95,101,97,97,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,83,182,188,28,0,0,0,8,48,54,53,45,97,97,97,48,52,46,49,48,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,194,39,139,127,1,0,16,1,48,54,53,45,97,97,97,48,53,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,54,214,30,132,1,0,16,1,48,54,53,45,97,48,50,46,57,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,76,196,29,179,1,0,16,1,48,54,53,45,97,48,51,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,230,47,132,19,1,0,16,1,48,54,53,45,97,48,49,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,77,58,125,20,2,0,16,1,48,54,53,45,97,48,56,46,49,53,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,202,154,100,107,3,0,32,0,48,54,53,45,97,48,55,46,49,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,196,143,220,197,3,0,32,0,48,54,53,45,97,48,57,46,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,47,213,5,234,4,0,32,0,48,54,53,45,97,49,48,46,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,2,24,185,150,4,0,32,0,48,54,53,45,97,49,50,46,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,122,208,30,50,4,0,32,0,48,54,53,45,97,49,49,46,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,142,148,218,70,4,0,32,0,48,54,53,45,97,48,54,46,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,224,206,219,90,5,0,64,0,120,109,101,110,95,97,97,97,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,71,212,15,117,0,0,0,8,97,115,49,48,48,54,101,48,51,46,117,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,119,22,208,10,1,0,0,0,97,115,49,48,48,55,101,48,51,46,117,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,240,36,38,87,1,0,0,0,97,115,49,48,48,49,109,48,49,46,117,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,121,85,89,146,2,0,0,0,97,115,49,48,48,50,109,48,49,46,117,51,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,8,187,194,22,2,0,0,0,97,115,49,48,48,51,109,48,49,46,117,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,88,136,97,137,2,0,0,0,97,115,49,48,48,52,109,48,49,46,117,52,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,9,9,12,80,2,0,0,0,97,115,49,48,48,53,109,48,49,46,117,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,184,55,177,228,3,0,0,0,16,0,0,0,255,255,255,0,0,0,0,0,17,0,0,0,255,255,193,0,0,0,0,0,18,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,16,27,6,0,16,0,0,0,1,16,16,0,96,135,7,0,16,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,4,0,32,4,2,0,17,0,0,0,1,3,3,0,160,36,8,0,17,0,0,0,1,3,1,0,208,239,7,0,17,0,0,0,1,3,2,0,120,187,7,0,17,0,0,0,1,3,0,0,16,227,4,0,0,0,0,0,254,0,4,0,128,129,4,0,17,0,0,0,1,12,0,0,8,49,4,0,17,0,0,0,1,12,4,0,152,21,4,0,17,0,0,0,1,12,8,0,72,246,3,0,17,0,0,0,1,12,12,0,72,0,3,0,0,0,0,0,254,0,4,0,64,37,5,0,17,0,0,0,1,48,0,0,136,120,6,0,17,0,0,0,1,48,16,0,176,116,6,0,17,0,0,0,1,48,32,0,80,113,6,0,17,0,0,0,1,48,48,0,120,7,5,0,0,0,0,0,254,0,2,0,200,30,2,0,17,0,0,0,1,64,64,0,120,97,1,0,17,0,0,0,1,64,0,0,96,19,1,0,119,104,111,111,112,101,101,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,126,46,136,40,0,0,16,1,119,104,111,111,112,101,101,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,51,241,150,103,0,0,16,1,116,112,48,50,53,45,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,68,247,151,171,0,0,32,0,116,112,48,50,53,45,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,30,16,22,123,0,0,32,0,104,100,54,52,55,49,56,48,46,48,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,16,0,0,16,19,0,0,0,255,255,0,0,0,0,0,0,20,0,0,0,255,255,0,0,0,0,0,0,21,0,0,0,255,255,246,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,2,0,0,96,135,7,0,19,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,4,0,0,96,135,7,0,19,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,8,8,0,96,135,7,0,19,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,7,0,200,87,7,0,19,0,0,0,1,48,48,0,32,136,7,0,19,0,0,0,1,48,32,0,40,88,7,0,19,0,0,0,1,48,16,0,96,39,7,0,19,0,0,0,1,48,32,0,96,39,7,0,19,0,0,0,1,48,0,0,144,251,6,0,19,0,0,0,1,48,48,0,120,211,6,0,19,0,0,0,1,48,16,0,184,164,6,0,0,0,0,0,254,0,8,0,160,123,6,0,19,0,0,0,1,192,128,0,96,39,7,0,19,0,0,0,1,192,0,0,144,251,6,0,19,0,0,0,1,192,192,0,120,211,6,0,19,0,0,0,1,192,64,0,184,164,6,0,19,0,0,0,1,192,0,0,184,164,6,0,19,0,0,0,1,192,64,0,80,74,6,0,19,0,0,0,1,192,128,0,192,32,6,0,19,0,0,0,1,192,192,0,32,242,5,0,0,0,0,0,254,0,0,0,72,202,5,0,20,0,0,0,1,3,3,0,248,160,5,0,20,0,0,0,1,3,2,0,112,212,3,0,20,0,0,0,1,3,0,0,248,38,7,0,20,0,0,0,1,3,1,0,80,246,3,0,0,0,0,0,254,0,4,0,64,37,5,0,20,0,0,0,1,12,12,0,120,7,5,0,20,0,0,0,1,12,8,0,144,227,4,0,20,0,0,0,1,12,0,0,136,191,4,0,20,0,0,0,1,12,4,0,216,159,4,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,48,48,0,192,255,2,0,20,0,0,0,1,48,32,0,208,75,4,0,20,0,0,0,1,48,0,0,8,49,4,0,20,0,0,0,1,48,16,0,72,246,3,0,0,0,0,0,254,0,4,0,144,246,3,0,20,0,0,0,1,64,0,0,96,135,7,0,20,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,48,45,3,0,21,0,0,0,1,7,6,0,8,234,2,0,21,0,0,0,1,7,7,0,184,159,3,0,21,0,0,0,1,7,4,0,160,134,3,0,21,0,0,0,1,7,5,0,112,111,3,0,21,0,0,0,1,7,0,0,176,20,3,0,21,0,0,0,1,7,1,0,160,236,1,0,21,0,0,0,1,7,2,0,48,62,3,0,21,0,0,0,1,7,3,0,80,65,1,0,0,0,0,0,254,0,0,0,208,20,3,0,21,0,0,0,1,8,8,0,112,134,3,0,21,0,0,0,1,8,0,0,64,234,2,0,0,0,0,0,119,97,114,122,97,114,100,95,106,97,112,97,110,46,50,57,102,52,48,48,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,198,240,226,248,0,0,0,3,114,101,100,101,97,114,116,104,40,95,95,57,54,49,49,50,49,41,45,115,105,109,109,49,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,248,104,212,202,0,0,16,1,114,101,100,101,97,114,116,104,40,95,95,57,54,49,49,50,49,41,45,115,105,109,109,49,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,137,29,114,233,0,0,16,1,114,101,100,101,97,114,116,104,40,95,95,57,54,49,49,50,49,41,45,115,105,109,109,49,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,152,236,137,40,0,0,16,1,114,101,100,101,97,114,116,104,40,95,95,57,54,49,49,50,49,41,45,115,105,109,109,49,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,72,209,108,90,0,0,16,1,114,101,100,101,97,114,116,104,45,115,105,109,109,51,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,197,12,53,131,0,0,32,0,114,101,100,101,97,114,116,104,45,115,105,109,109,51,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,230,77,115,86,0,0,32,0,114,101,100,101,97,114,116,104,45,115,105,109,109,51,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,241,160,14,128,0,0,32,0,114,101,100,101,97,114,116,104,45,115,105,109,109,51,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,108,20,233,151,0,0,32,0,114,101,100,101,97,114,116,104,45,115,105,109,109,51,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,72,214,177,12,0,0,32,0,114,101,100,101,97,114,116,104,45,115,105,109,109,51,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,240,153,16,122,0,0,32,0,114,101,100,101,97,114,116,104,45,115,105,109,109,51,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,84,143,255,174,0,0,32,0,114,101,100,101,97,114,116,104,45,115,105,109,109,51,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,208,172,112,247,0,0,32,0,114,101,100,101,97,114,116,104,45,115,105,109,109,52,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,242,86,30,48,0,0,32,0,114,101,100,101,97,114,116,104,45,115,105,109,109,52,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,3,225,72,32,0,0,32,0,114,101,100,101,97,114,116,104,45,115,105,109,109,52,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,85,52,67,201,0,0,32,0,114,101,100,101,97,114,116,104,45,115,105,109,109,52,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,168,113,33,192,0,0,32,0,114,101,100,101,97,114,116,104,45,115,105,109,109,52,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,118,242,219,45,0,0,32,0,114,101,100,101,97,114,116,104,45,115,105,109,109,52,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,166,32,168,254,0,0,32,0,114,101,100,101,97,114,116,104,45,115,105,109,109,52,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,241,141,82,199,0,0,32,0,114,101,100,101,97,114,116,104,45,115,105,109,109,52,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,59,207,73,36,0,0,32,0,114,101,100,101,97,114,116,104,45,115,105,109,109,53,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,185,81,68,66,0,0,32,0,114,101,100,101,97,114,116,104,45,115,105,109,109,53,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,107,181,140,155,0,0,32,0,49,45,52,110,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,165,92,90,254,1,0,16,1,49,45,53,110,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,127,67,126,132,1,0,16,1,49,45,54,110,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,54,196,102,70,1,0,16,1,49,45,55,110,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,249,151,32,255,1,0,16,1,49,45,56,110,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,65,202,165,108,1,0,16,1,49,45,49,49,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,244,172,210,59,2,0,16,1,49,45,51,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,165,215,197,139,3,0,32,0,50,45,50,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,161,172,10,225,4,0,32,0,50,45,51,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,218,32,165,141,4,0,32,0,50,45,52,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,241,19,106,32,4,0,32,0,50,45,53,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,132,25,216,182,4,0,32,0,50,45,54,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,143,179,38,90,4,0,32,0,50,45,55,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,115,167,28,30,4,0,32,0,50,45,50,110,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,13,177,177,109,5,0,32,0,50,45,51,110,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,236,52,140,93,5,0,32,0,50,45,52,110,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,227,162,113,0,5,0,32,0,50,45,53,110,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,236,161,35,64,5,0,32,0,101,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,6,54,168,6,6,0,32,0,101,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,60,241,172,190,6,0,32,0,101,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,33,182,31,222,6,0,32,0,100,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,13,8,121,113,6,0,32,0,106,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,41,32,132,208,6,0,32,0,99,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,214,11,31,122,6,0,32,0,56,50,115,49,50,54,46,57,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,33,5,177,50,0,0,0,8,56,50,115,49,50,57,46,56,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,92,99,33,73,0,0,0,8,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,98,255,24,62,1,0,16,1,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,130,13,101,180,1,0,16,1,118,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,92,53,38,91,1,0,16,1,118,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,14,241,167,76,1,0,16,1,49,45,56,110,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,65,202,165,108,1,0,16,1,49,45,49,49,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,244,172,210,59,2,0,16,1,49,45,51,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,165,215,197,139,3,0,32,0,50,45,50,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,161,172,10,225,4,0,32,0,50,45,51,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,218,32,165,141,4,0,32,0,50,45,52,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,241,19,106,32,4,0,32,0,50,45,53,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,132,25,216,182,4,0,32,0,50,45,54,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,143,179,38,90,4,0,32,0,50,45,55,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,115,167,28,30,4,0,32,0,50,45,50,110,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,13,177,177,109,5,0,32,0,50,45,51,110,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,236,52,140,93,5,0,32,0,50,45,52,110,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,227,162,113,0,5,0,32,0,50,45,53,110,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,236,161,35,64,5,0,32,0,101,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,6,54,168,6,6,0,32,0,101,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,60,241,172,190,6,0,32,0,101,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,33,182,31,222,6,0,32,0,100,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,13,8,121,113,6,0,32,0,106,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,41,32,132,208,6,0,32,0,99,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,214,11,31,122,6,0,32,0,56,50,115,49,50,54,46,57,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,33,5,177,50,0,0,0,8,56,50,115,49,50,57,46,56,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,92,99,33,73,0,0,0,8,55,56,53,95,110,48,53,46,54,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,117,212,113,99,1,0,16,1,55,56,53,95,110,48,52,46,52,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,158,75,242,182,1,0,16,1,55,56,53,95,114,48,57,46,54,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,67,21,253,251,1,0,16,1,55,56,53,95,114,48,56,46,52,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,225,27,187,54,1,0,16,1,55,56,53,95,103,48,55,46,49,48,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,93,221,9,238,2,0,16,1,55,56,53,95,103,48,54,46,56,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,247,122,171,133,2,0,16,1,55,56,53,95,103,49,51,46,49,48,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,93,50,79,39,2,0,16,1,55,56,53,95,103,49,50,46,56,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,51,249,37,22,2,0,16,1,55,56,53,95,103,48,51,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,13,181,163,103,3,0,16,1,55,56,53,95,104,49,52,46,100,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,111,177,244,2,4,0,32,0,55,56,53,102,49,55,46,112,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,164,193,190,143,5,0,32,0,55,56,53,102,49,56,46,112,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,56,30,214,80,5,0,32,0,55,56,53,102,49,53,46,112,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,243,174,150,175,5,0,32,0,55,56,53,102,49,54,46,112,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,31,223,88,184,5,0,32,0,55,56,53,95,102,48,49,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,158,214,216,160,7,0,64,0,55,56,53,95,102,48,50,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,164,92,159,195,8,0,64,0,55,56,53,95,114,48,53,46,54,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,123,165,119,23,1,0,16,1,55,56,53,95,114,48,52,46,52,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,243,189,12,121,1,0,16,1,55,56,53,95,117,48,57,46,54,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,16,112,186,26,1,0,16,1,55,56,53,95,107,48,56,46,52,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,225,27,187,54,1,0,16,1,55,56,53,95,112,48,55,46,49,48,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,157,84,109,104,2,0,16,1,55,56,53,95,112,48,54,46,56,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,238,75,201,112,2,0,16,1,55,56,53,95,112,49,51,46,49,48,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,10,219,143,71,2,0,16,1,55,56,53,95,112,49,50,46,56,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,42,64,234,56,2,0,16,1,55,56,53,95,103,48,51,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,13,181,163,103,3,0,16,1,55,56,53,95,104,49,52,46,100,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,111,177,244,2,4,0,32,0,55,56,53,102,49,55,46,112,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,164,193,190,143,5,0,32,0,55,56,53,102,49,56,46,112,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,56,30,214,80,5,0,32,0,55,56,53,102,49,53,46,112,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,243,174,150,175,5,0,32,0,55,56,53,102,49,54,46,112,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,31,223,88,184,5,0,32,0,55,56,53,95,102,48,49,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,158,214,216,160,7,0,64,0,55,56,53,95,102,48,50,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,164,92,159,195,8,0,64,0,118,109,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,78,132,239,67,1,0,16,1,118,109,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,177,42,41,203,1,0,16,1,49,46,117,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,104,193,112,180,2,0,32,0,50,46,117,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,96,141,111,179,2,0,32,0,51,46,117,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,101,167,252,0,2,0,32,0,52,46,117,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,156,164,37,90,2,0,32,0,56,46,117,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,28,0,76,193,3,0,64,0,55,46,117,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,241,82,140,168,4,0,64,0,101,112,114,95,53,52,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,252,46,23,1,0,16,1,115,45,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,49,140,45,151,2,0,32,0,99,45,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,192,247,24,81,3,0,32,0,99,45,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,62,179,233,239,3,0,32,0,109,45,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,209,183,146,155,4,0,16,1,116,112,48,49,57,45,48,55,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,242,143,136,120,0,0,16,1,116,112,48,49,57,45,48,56,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,60,220,210,108,0,0,16,1,118,105,109,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,141,135,134,40,0,0,32,0,118,105,109,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,122,61,166,97,0,0,32,0,118,105,109,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,104,87,81,176,0,0,32,0,118,105,109,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,49,145,83,11,0,0,32,0,118,105,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,205,38,222,205,0,0,32,0,118,105,109,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,193,191,29,0,0,32,0,116,112,48,49,57,45,48,57,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,237,204,136,188,0,0,32,0,116,112,48,49,57,45,49,48,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,146,116,225,161,0,0,32,0,104,100,54,52,55,49,56,48,46,48,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,24,118,105,109,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,132,234,250,30,0,0,16,1,118,105,109,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,239,125,91,228,0,0,16,1,118,105,109,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,141,135,134,40,0,0,32,0,118,105,109,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,122,61,166,97,0,0,32,0,118,105,109,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,104,87,81,176,0,0,32,0,118,105,109,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,49,145,83,11,0,0,32,0,118,105,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,205,38,222,205,0,0,32,0,118,105,109,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,193,191,29,0,0,32,0,116,112,48,49,57,45,48,57,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,237,204,136,188,0,0,32,0,116,112,48,49,57,45,49,48,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,146,116,225,161,0,0,32,0,104,100,54,52,55,49,56,48,46,48,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,24,168,86,7,0,1,0,0,0,11,191,145,0,248,191,2,0,24,38,7,0,1,0,0,0,13,191,145,0,184,160,2,0,56,210,6,0,1,0,0,0,224,250,146,0,192,135,2,0,24,163,6,0,1,0,0,0,225,250,146,0,240,108,2,0,152,122,6,0,1,0,0,0,226,250,146,0,96,82,2,0,192,72,6,0,1,0,0,0,227,250,146,0,32,56,2,0,200,110,3,0,1,0,0,0,228,250,146,0,152,30,2,0,120,89,3,0,1,0,0,0,229,250,146,0,232,10,2,0,120,74,3,0,1,0,0,0,230,250,146,0,152,138,8,0,40,246,1,0,1,0,0,0,12,191,145,0,64,246,1,0,144,236,1,0,1,0,0,0,14,191,145,0,136,224,1,0,176,223,1,0,1,0,0,0,184,242,146,0,72,198,1,0,192,209,1,0,1,0,0,0,185,242,146,0,24,182,1,0,24,198,1,0,1,0,0,0,186,242,146,0,40,167,1,0,120,189,1,0,1,0,0,0,187,242,146,0,200,149,1,0,224,22,1,0,1,0,0,0,188,242,146,0,56,126,1,0,160,14,1,0,1,0,0,0,189,242,146,0,32,101,1,0,176,9,1,0,1,0,0,0,190,242,146,0,96,32,8,0,88,212,3,0,1,0,0,0,160,215,146,0,40,185,3,0,32,77,1,0,1,0,0,0,8,191,145,0,216,70,1,0,72,65,1,0,9,0,0,0,59,223,146,0,32,58,1,0,48,50,1,0,9,0,0,0,60,223,146,0,32,58,1,0,224,41,1,0,9,0,0,0,61,223,146,0,32,58,1,0,118,97,110,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,149,130,244,0,1,0,16,1,118,97,110,45,50,46,53,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,203,225,88,223,1,0,16,1,118,97,110,45,51,46,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,36,30,87,21,1,0,16,1,118,97,110,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,213,126,179,248,1,0,16,1,118,97,110,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,137,224,193,184,1,0,16,1,118,97,110,45,50,48,46,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,102,190,239,96,2,0,32,0,118,97,110,45,50,49,46,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,35,55,213,93,2,0,32,0,54,51,51,49,45,49,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,3,149,29,206,3,0,32,0,54,51,48,49,45,49,46,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,159,61,128,75,3,0,32,0,118,118,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,240,45,27,207,1,0,16,1,118,118,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,165,166,236,128,1,0,16,1,118,118,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,36,30,87,21,1,0,16,1,118,118,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,6,64,240,177,1,0,16,1,118,118,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,76,65,103,219,1,0,16,1,118,118,50,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,81,203,86,235,2,0,32,0,118,118,50,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,35,55,213,93,2,0,32,0,54,51,51,49,45,49,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,3,149,29,206,3,0,32,0,54,51,48,49,45,49,46,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,159,61,128,75,3,0,32,0,118,100,107,45,49,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,89,28,208,193,1,0,16,1,118,100,107,45,50,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,194,28,116,157,1,0,16,1,118,100,107,45,52,46,49,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,240,68,165,235,2,0,16,1,118,100,107,45,51,46,50,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,27,124,84,90,3,0,32,0,118,100,107,45,48,49,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,190,36,90,25,4,0,32,0,118,100,107,45,48,55,46,50,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,6,31,212,66,5,0,32,0,118,100,107,45,48,54,46,50,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,34,71,213,5,0,32,0,118,100,107,45,48,52,46,50,45,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,71,5,115,10,5,0,32,0,118,100,107,45,48,53,46,51,45,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,109,69,186,5,0,32,0,118,100,107,45,48,50,46,49,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,116,50,16,178,6,0,64,0,118,100,107,45,48,51,46,49,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,211,118,23,99,7,0,64,0,105,99,49,48,48,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,151,28,237,152,0,0,0,8,105,99,49,48,49,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,108,184,219,207,0,0,0,8,117,50,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,80,192,238,231,0,0,16,1,117,50,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,17,98,203,104,0,0,16,1,117,51,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,210,42,20,93,0,0,32,0,117,52,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,187,17,251,18,0,0,32,0,117,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,85,215,208,162,0,0,64,0,101,101,112,114,111,109,45,117,111,112,111,107,111,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,149,75,162,244,0,0,16,1,49,46,117,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,67,65,140,132,0,0,16,1,50,46,117,52,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,211,11,110,158,0,0,16,1,51,46,117,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,234,4,11,208,0,0,32,0,52,46,117,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,61,58,18,74,0,0,32,0,53,46,117,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,210,114,242,68,0,0,32,0,117,99,95,104,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,247,165,10,36,1,0,16,1,117,99,95,108,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,38,72,154,223,1,0,16,1,117,99,95,104,49,45,103,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,222,162,140,107,1,0,16,1,117,99,95,108,49,45,103,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,221,199,222,43,1,0,16,1,117,99,95,115,104,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,152,177,144,223,2,0,16,1,117,99,95,115,108,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,172,26,193,150,2,0,16,1,117,99,95,119,51,56,109,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,229,64,10,19,3,0,32,0,117,99,95,119,51,57,109,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,68,161,44,228,3,0,32,0,117,99,95,119,52,48,109,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,72,22,150,194,3,0,32,0,117,99,95,119,52,49,109,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,128,75,51,245,3,0,32,0,117,99,95,107,49,54,109,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,9,95,34,74,4,0,32,0,117,99,95,107,49,55,109,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,84,154,237,228,4,0,32,0,117,99,95,107,49,56,109,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,18,235,38,166,4,0,32,0,117,99,95,107,49,57,109,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,73,101,244,93,4,0,32,0,117,99,95,119,52,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,214,63,125,209,5,0,64,0,117,99,95,104,48,95,97,46,105,99,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,218,202,23,158,1,0,16,1,117,99,95,108,48,95,97,46,105,99,51,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,8,50,78,74,1,0,16,1,117,99,95,104,49,95,97,46,105,99,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,234,141,247,131,1,0,16,1,117,99,95,108,49,95,97,46,105,99,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,128,130,98,25,1,0,16,1,117,99,95,115,104,48,46,105,99,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,3,27,202,240,2,0,16,1,117,99,95,115,108,48,46,105,99,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,35,23,102,209,2,0,16,1,117,99,95,99,48,46,105,99,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,54,154,65,106,3,0,32,0,117,99,95,99,49,46,105,99,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,199,236,3,215,3,0,32,0,117,99,95,99,50,46,105,99,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,198,122,57,150,3,0,32,0,117,99,95,99,51,46,105,99,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,13,209,7,93,3,0,32,0,117,99,95,48,51,48,46,105,99,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,94,119,247,151,4,0,32,0,117,99,95,48,50,48,46,105,99,51,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,101,29,11,94,4,0,32,0,117,99,95,48,49,48,46,105,99,51,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,179,36,194,189,4,0,32,0,117,99,95,48,48,48,46,105,99,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,236,218,38,117,4,0,32,0,117,99,95,100,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,233,85,40,11,5,0,64,0,55,55,48,95,107,48,49,46,110,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,34,74,167,91,1,0,16,1,55,55,48,95,107,48,50,46,110,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,42,120,207,59,1,0,16,1,55,55,48,95,107,48,53,46,105,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,187,235,27,15,2,0,16,1,55,55,48,95,102,48,52,46,103,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,156,236,228,224,2,0,16,1,55,55,48,95,104,48,51,46,102,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,252,42,253,47,3,0,16,1,55,55,48,99,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,78,202,89,184,4,0,32,0,55,55,48,99,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,114,75,209,80,4,0,32,0,55,55,48,99,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,255,167,180,26,5,0,32,0,55,55,48,99,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,134,5,232,168,5,0,32,0,55,55,48,99,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,238,146,197,208,6,0,32,0,55,55,48,99,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,177,159,57,11,6,0,32,0,55,55,48,99,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,95,130,172,127,7,0,64,0,55,55,48,99,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,90,97,154,41,8,0,64,0,54,51,115,50,52,49,46,106,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,159,113,221,155,9,0,0,8,104,108,48,48,45,49,46,102,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,27,124,105,253,1,0,16,1,104,108,48,49,45,49,46,102,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,63,42,166,213,1,0,16,1,104,108,48,50,45,46,102,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,136,184,202,165,2,0,16,1,109,97,112,45,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,38,170,206,223,3,0,32,0,109,97,112,45,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,9,250,31,232,4,0,32,0,109,97,112,45,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,254,156,135,140,4,0,32,0,104,108,48,51,45,46,106,49])
.concat([53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,160,29,184,1,5,0,64,0,98,54,53,95,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,154,55,98,26,0,0,16,1,98,54,53,95,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,93,25,245,175,0,0,16,1,98,54,53,95,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,55,91,49,210,0,0,32,0,98,54,53,95,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,42,37,131,251,0,0,32,0,98,54,53,95,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,190,220,206,54,0,0,32,0,98,54,53,95,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,241,149,205,129,0,0,32,0,98,54,53,95,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,97,244,111,140,0,0,32,0,98,54,53,95,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,11,53,177,88,0,0,32,0,98,54,53,95,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,97,81,213,29,0,0,32,0,98,54,53,95,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,127,147,116,233,0,0,32,0,98,54,53,95,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,16,244,192,241,0,0,16,1,98,54,53,95,49,50,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,237,204,136,188,0,0,64,0,98,54,53,95,49,51,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,146,116,225,161,0,0,64,0,18,0,0,0,255,255,1,0,0,0,0,0,19,0,0,0,255,255,0,0,0,0,0,0,20,0,0,0,255,255,2,0,0,0,0,0,0,0,0,0,254,0,2,0,0,0,0,0,18,0,0,0,1,1,1,0,120,97,1,0,18,0,0,0,1,1,0,0,96,19,1,0,0,0,0,0,254,0,2,0,0,0,0,0,18,0,0,0,1,2,0,0,200,211,8,0,18,0,0,0,1,2,2,0,216,147,8,0,0,0,0,0,254,0,2,0,0,0,0,0,18,0,0,0,1,4,0,0,168,84,8,0,18,0,0,0,1,4,4,0,40,31,8,0,0,0,0,0,254,0,2,0,240,233,7,0,18,0,0,0,1,8,0,0,152,182,7,0,18,0,0,0,1,8,8,0,96,135,7,0,0,0,0,0,254,0,4,0,200,87,7,0,18,0,0,0,1,48,0,0,232,38,7,0,18,0,0,0,1,48,16,0,176,73,6,0,18,0,0,0,1,48,32,0,64,251,6,0,18,0,0,0,1,48,48,0,80,165,6,0,0,0,0,0,254,0,4,0,160,123,6,0,18,0,0,0,1,192,0,0,232,38,7,0,18,0,0,0,1,192,64,0,176,73,6,0,18,0,0,0,1,192,128,0,64,251,6,0,18,0,0,0,1,192,192,0,80,165,6,0,0,0,0,0,254,0,4,0,136,160,5,0,19,0,0,0,1,3,0,0,16,150,7,0,19,0,0,0,1,3,1,0,120,198,7,0,19,0,0,0,1,3,2,0,160,103,7,0,19,0,0,0,1,3,3,0,16,53,7,0,0,0,0,0,254,0,4,0,248,6,5,0,19,0,0,0,1,12,0,0,104,99,5,0,19,0,0,0,1,12,4,0,176,68,5,0,19,0,0,0,1,12,8,0,216,135,2,0,19,0,0,0,1,12,12,0,248,75,4,0,0,0,0,0,254,0,4,0,72,22,4,0,19,0,0,0,1,48,48,0,208,75,4,0,19,0,0,0,1,48,0,0,8,49,4,0,19,0,0,0,1,48,32,0,152,21,4,0,19,0,0,0,1,48,16,0,72,246,3,0,0,0,0,0,254,0,2,0,96,68,5,0,19,0,0,0,1,64,0,0,96,135,7,0,19,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,19,0,0,0,1,128,0,0,104,134,3,0,19,0,0,0,1,128,128,0,56,111,3,0,0,0,0,0,254,0,5,0,48,45,3,0,20,0,0,0,1,7,0,0,24,128,5,0,20,0,0,0,1,7,1,0,72,160,3,0,20,0,0,0,1,7,2,0,0,135,3,0,20,0,0,0,1,7,4,0,184,111,3,0,20,0,0,0,1,7,6,0,224,89,3,0,97,115,49,49,48,54,101,48,49,46,117,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,130,8,149,180,1,0,0,0,97,115,49,49,48,55,101,48,49,46,117,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,203,103,238,25,1,0,0,0,97,115,49,49,48,49,109,48,49,46,117,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,117,214,94,133,2,0,0,0,97,115,49,49,48,50,109,48,49,46,117,51,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,113,210,134,209,2,0,0,0,97,115,49,49,48,51,109,48,49,46,117,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,78,165,248,173,2,0,0,0,97,115,49,49,48,52,109,48,49,46,117,52,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,233,130,120,56,2,0,0,0,97,115,49,49,48,53,109,48,49,46,117,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,248,13,61,99,3,0,0,0,116,98,48,52,46,49,48,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,39,15,103,146,1,0,16,1,116,98,48,54,46,49,51,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,115,17,149,164,1,0,16,1,116,98,48,53,46,49,50,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,100,178,115,146,1,0,16,1,116,98,48,50,46,49,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,151,71,21,33,2,0,16,1,116,98,48,49,46,54,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,178,145,15,28,3,0,16,1,116,98,48,51,46,56,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,76,43,26,88,4,0,32,0,116,98,49,51,46,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,43,5,90,40,5,0,32,0,116,98,48,57,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,247,147,182,174,5,0,32,0,116,98,49,50,46,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,92,254,176,223,5,0,32,0,116,98,48,56,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,209,201,164,211,5,0,32,0,116,98,49,49,46,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,253,244,240,0,5,0,32,0,116,98,48,55,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,2,238,242,223,5,0,32,0,116,98,49,52,46,56,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,24,172,191,20,5,0,32,0,116,98,49,48,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,109,138,186,113,5,0,32,0,116,98,49,56,46,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,19,71,44,134,6,0,32,0,116,98,49,54,46,51,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,189,140,111,216,6,0,32,0,116,98,49,55,46,53,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,63,59,167,18,6,0,32,0,116,98,49,53,46,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,105,39,26,187,6,0,32,0,116,98,50,50,46,55,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,212,175,218,57,6,0,32,0,116,98,50,48,46,51,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,42,93,97,148,6,0,32,0,116,98,50,49,46,53,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,189,66,198,102,6,0,32,0,116,98,49,57,46,50,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,54,171,213,129,6,0,32,0,116,98,50,53,46,49,53,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,250,198,56,110,7,0,32,0,116,98,50,52,46,49,51,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,242,108,252,20,7,0,32,0,116,98,50,51,46,57,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,14,60,161,237,8,0,32,0,116,98,112,50,52,115,49,48,46,55,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,152,204,107,217,0,0,0,8,109,98,55,49,49,52,101,46,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,157,250,82,80,0,0,0,8,116,114,111,106,45,48,52,46,49,48,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,73,127,90,11,1,0,16,1,116,114,111,106,45,48,54,46,49,51,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,146,237,230,222,1,0,16,1,116,98,48,53,46,49,50,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,100,178,115,146,1,0,16,1,116,98,48,50,46,49,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,151,71,21,33,2,0,16,1,116,98,48,49,46,54,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,178,145,15,28,3,0,16,1,116,98,48,51,46,56,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,76,43,26,88,4,0,32,0,116,98,49,51,46,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,43,5,90,40,5,0,32,0,116,98,48,57,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,247,147,182,174,5,0,32,0,116,98,49,50,46,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,92,254,176,223,5,0,32,0,116,98,48,56,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,209,201,164,211,5,0,32,0,116,98,49,49,46,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,253,244,240,0,5,0,32,0,116,98,48,55,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,2,238,242,223,5,0,32,0,116,98,49,52,46,56,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,24,172,191,20,5,0,32,0,116,98,49,48,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,109,138,186,113,5,0,32,0,116,98,49,56,46,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,19,71,44,134,6,0,32,0,116,98,49,54,46,51,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,189,140,111,216,6,0,32,0,116,98,49,55,46,53,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,63,59,167,18,6,0,32,0,116,98,49,53,46,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,105,39,26,187,6,0,32,0,116,98,50,50,46,55,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,212,175,218,57,6,0,32,0,116,98,50,48,46,51,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,42,93,97,148,6,0,32,0,116,98,50,49,46,53,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,189,66,198,102,6,0,32,0,116,98,49,57,46,50,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,54,171,213,129,6,0,32,0,116,98,50,53,46,49,53,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,250,198,56,110,7,0,32,0,116,98,50,52,46,49,51,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,242,108,252,20,7,0,32,0,116,98,50,51,46,57,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,14,60,161,237,8,0,32,0,116,98,112,50,52,115,49,48,46,55,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,152,204,107,217,0,0,0,8,109,98,55,49,49,52,101,46,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,157,250,82,80,0,0,0,8,116,98,52,46,49,48,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,81,165,19,1,1,0,16,1,116,98,54,46,49,51,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,91,122,18,170,1,0,16,1,116,98,48,53,46,49,50,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,100,178,115,146,1,0,16,1,116,98,48,50,46,49,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,151,71,21,33,2,0,16,1,116,98,48,49,46,54,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,178,145,15,28,3,0,16,1,116,98,48,51,46,56,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,76,43,26,88,4,0,32,0,116,98,49,51,46,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,43,5,90,40,5,0,32,0,116,98,48,57,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,247,147,182,174,5,0,32,0,116,98,49,50,46,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,92,254,176,223,5,0,32,0,116,98,48,56,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,209,201,164,211,5,0,32,0,116,98,49,49,46,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0])
.concat([253,244,240,0,5,0,32,0,116,98,48,55,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,2,238,242,223,5,0,32,0,116,98,49,52,46,56,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,24,172,191,20,5,0,32,0,116,98,49,48,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,109,138,186,113,5,0,32,0,116,98,49,56,46,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,19,71,44,134,6,0,32,0,116,98,49,54,46,51,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,189,140,111,216,6,0,32,0,116,98,49,55,46,53,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,63,59,167,18,6,0,32,0,116,98,49,53,46,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,105,39,26,187,6,0,32,0,116,98,50,50,46,55,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,212,175,218,57,6,0,32,0,116,98,50,48,46,51,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,42,93,97,148,6,0,32,0,116,98,50,49,46,53,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,189,66,198,102,6,0,32,0,116,98,49,57,46,50,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,54,171,213,129,6,0,32,0,116,98,50,53,46,49,53,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,250,198,56,110,7,0,32,0,116,98,50,52,46,49,51,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,242,108,252,20,7,0,32,0,116,98,50,51,46,57,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,14,60,161,237,8,0,32,0,116,98,112,50,52,115,49,48,46,55,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,152,204,107,217,0,0,0,8,109,98,55,49,49,52,101,46,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,157,250,82,80,0,0,0,8,116,114,105,55,51,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,167,58,137,150,1,0,16,1,116,114,105,54,50,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,101,220,153,50,1,0,16,1,116,114,105,53,50,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,94,118,239,39,1,0,16,1,116,114,105,51,51,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,29,6,239,215,1,0,16,1,116,114,105,52,53,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,177,19,184,81,1,0,16,1,116,114,105,50,53,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,45,81,100,142,1,0,16,1,116,114,105,49,51,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,155,142,38,173,1,0,16,1,116,114,105,115,110,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,139,75,92,148,2,0,16,1,116,114,105,49,48,53,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,60,117,106,54,3,0,32,0,116,114,105,57,51,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,130,55,33,53,3,0,32,0,116,107,110,105,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,168,218,33,145,1,0,16,1,116,107,110,105,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,135,205,105,102,1,0,16,1,116,107,110,105,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,199,62,98,21,2,0,16,1,116,107,110,105,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,150,88,209,94,3,0,32,0,116,107,110,105,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,134,66,77,75,4,0,32,0,116,107,110,105,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,177,175,143,246,5,0,32,0,116,107,110,105,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,57,66,47,210,6,0,32,0,116,107,110,105,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,132,177,49,73,6,0,32,0,116,107,110,105,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,207,219,161,167,7,0,64,0,97,45,54,118,46,109,99,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,24,17,0,0,0,32,167,32,0,24,167,32,0,191,250,33,93,116,117,112,95,112,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,177,173,134,190,1,0,16,1,116,117,112,95,115,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,147,181,69,165,2,0,32,0,116,117,112,95,99,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,10,48,154,193,3,0,32,0,116,117,112,95,99,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,237,247,179,253,3,0,32,0,116,117,112,95,109,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,17,93,121,254,4,0,16,1,116,117,112,95,118,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,123,244,184,19,5,0,64,0,116,117,112,95,118,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,61,102,221,111,5,0,64,0,97,52,55,95,48,48,46,56,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,204,227,219,203,0,0,16,1,97,52,55,95,48,49,46,56,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,82,33,223,101,0,0,16,1,97,52,55,95,48,50,46,56,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,75,50,61,99,0,0,16,1,97,52,55,95,49,51,46,56,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,126,126,154,115,0,0,32,0,97,52,55,95,49,50,46,54,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,219,236,100,192,0,0,32,0,97,52,55,95,49,49,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,155,174,79,116,0,0,32,0,97,52,55,95,49,48,46,54,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,78,132,207,225,0,0,32,0,97,52,55,95,48,53,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,73,91,50,197,0,0,32,0,97,52,55,95,48,52,46,54,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,142,98,89,205,0,0,32,0,97,52,55,95,48,57,46,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,168,232,250,49,0,0,32,0,97,52,55,95,48,56,46,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,43,175,57,229,0,0,32,0,97,52,55,95,48,55,46,54,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,41,212,253,2,0,0,32,0,97,52,55,95,48,54,46,54,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,140,204,251,17,0,0,32,0,56,50,115,49,50,57,46,49,50,113,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,13,53,105,44,0,0,32,0,56,50,115,49,50,57,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,114,233,66,113,0,0,32,0,56,50,115,49,50,57,46,49,50,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,242,115,242,37,0,0,32,0,97,52,55,95,48,51,46,49,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,15,38,5,209,0,0,16,1,97,52,55,95,49,52,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,159,72,66,64,0,0,16,1,48,55,51,45,101,97,45,108,48,50,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,81,43,224,234,0,0,16,1,48,55,51,45,101,97,45,108,48,51,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,7,208,142,115,0,0,16,1,48,55,51,45,99,48,49,46,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,60,232,235,68,0,0,16,1,48,55,51,45,99,48,54,46,49,54,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,66,43,226,36,0,0,32,0,48,55,51,45,99,48,53,46,49,50,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,95,147,42,149,0,0,32,0,48,55,51,45,99,48,55,46,55,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,56,63,233,20,0,0,32,0,48,55,51,45,99,48,56,46,51,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,171,179,250,9,0,0,32,0,48,55,51,45,98,48,52,46,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,11,122,40,5,0,0,64,0,116,104,110,100,114,120,50,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,152,62,97,202,0,0,0,8,116,45,104,101,114,111,45,101,112,109,49,46,117,48,49,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,149,113,219,9,0,0,16,1,116,45,104,101,114,111,45,101,112,109,48,46,117,48,49,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,16,51,78,45,0,0,16,1,116,45,104,101,114,111,45,111,98,106,49,46,117,48,55,51,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,124,15,9,53,0,0,32,0,116,45,104,101,114,111,45,111,98,106,50,46,117,48,55,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,8,81,96,113,0,0,32,0,116,45,104,101,114,111,45,98,103,49,46,117,48,57,57,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,64,251,176,71,0,0,32,0,116,45,104,101,114,111,45,98,103,50,46,117,48,57,57,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,161,55,98,177,0,0,32,0,116,45,104,101,114,111,45,98,103,51,46,117,48,57,57,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,4,86,235,8,0,0,32,0,99,114,118,115,97,100,101,114,115,45,115,110,100,49,46,117,48,52,52,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,82,10,119,146,0,0,64,0,99,114,118,115,97,100,101,114,115,45,115,110,100,50,46,117,48,52,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,207,225,154,50,0,0,64,0,116,45,104,101,114,111,45,115,110,100,51,46,117,48,52,53,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,192,178,176,82,0,0,64,0,23,0,0,0,255,255,4,0,0,0,0,0,24,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,80,157,8,0,23,0,0,0,1,1,0,0,96,135,7,0,23,0,0,0,1,1,1,0,152,182,7,0,0,0,0,0,254,0,2,0,200,135,2,0,23,0,0,0,1,2,2,0,96,135,7,0,23,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,128,112,3,0,23,0,0,0,1,4,0,0,72,180,7,0,23,0,0,0,1,4,4,0,168,22,4,0,0,0,0,0,254,0,9,0,72,23,4,0,23,0,0,0,1,120,0,0,200,201,5,0,23,0,0,0,1,120,8,0,152,160,5,0,23,0,0,0,1,120,16,0,144,127,5,0,23,0,0,0,1,120,24,0,224,67,5,0,23,0,0,0,1,120,32,0,88,198,1,0,23,0,0,0,1,120,40,0,216,36,5,0,23,0,0,0,1,120,48,0,8,7,5,0,23,0,0,0,1,120,56,0,136,207,5,0,23,0,0,0,1,120,64,0,40,182,1,0,23,0,0,0,1,120,72,0,40,182,1,0,23,0,0,0,1,120,80,0,40,182,1,0,23,0,0,0,1,120,88,0,40,182,1,0,23,0,0,0,1,120,96,0,40,182,1,0,23,0,0,0,1,120,104,0,40,182,1,0,23,0,0,0,1,120,112,0,40,182,1,0,23,0,0,0,1,120,120,0,40,182,1,0,0,0,0,0,254,0,2,0,80,111,3,0,23,0,0,0,1,128,128,0,96,135,7,0,23,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,4,0,16,57,4,0,24,0,0,0,1,192,64,0,248,73,5,0,24,0,0,0,1,192,0,0,80,124,6,0,24,0,0,0,1,192,128,0,0,12,5,0,24,0,0,0,1,192,192,0,248,160,5,0,0,0,0,0,254,0,2,0,56,191,4,0,24,0,0,0,2,4,4,0,208,164,4,0,24,0,0,0,0,192,0,0,0,0,0,0,24,0,0,0,2,4,0,0,40,134,4,0,24,0,0,0,0,192,0,0,0,0,0,0,0,0,0,0,254,0,2,0,56,191,4,0,24,0,0,0,2,4,4,0,208,164,4,0,24,0,0,0,0,192,64,0,0,0,0,0,24,0,0,0,2,4,0,0,112,107,4,0,24,0,0,0,0,192,64,0,0,0,0,0,0,0,0,0,254,0,2,0,56,191,4,0,24,0,0,0,2,4,4,0,208,164,4,0,24,0,0,0,0,192,128,0,0,0,0,0,24,0,0,0,2,4,0,0,160,80,4,0,24,0,0,0,0,192,128,0,0,0,0,0,0,0,0,0,254,0,2,0,56,191,4,0,24,0,0,0,2,4,4,0,208,164,4,0,24,0,0,0,0,192,192,0,0,0,0,0,24,0,0,0,2,4,0,0,176,54,4,0,24,0,0,0,0,192,192,0,0,0,0,0,0,0,0,0,254,0,4,0,200,26,4,0,24,0,0,0,1,3,2,0,112,252,3,0,24,0,0,0,1,3,3,0,40,219,3,0,24,0,0,0,1,3,0,0,192,189,3,0,24,0,0,0,1,3,1,0,112,164,3,0,0,0,0,0,254,0,4,0,120,95,4,0,24,0,0,0,1,24,0,0,200,114,3,0,24,0,0,0,1,24,8,0,176,92,3,0,24,0,0,0,1,24,16,0,40,78,3,0,24,0,0,0,1,24,24,0,160,64,3,0,103,108,111,98,117,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,149,180,253,8,0,0,16,1,103,108,111,98,117,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,108,213,124,130,0,0,16,1,103,108,111,98,117,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,102,153,33,209,0,0,16,1,103,108,111,98,117,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,167,157,100,177,0,0,16,1,103,108,111,98,117,54,46,98,105,110,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,103,126,69,179,0,0,16,1,103,108,111,98,117,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,205,130,213,137,0,0,16,1,103,108,111,98,117,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,235,253,233,126,0,0,16,1,103,108,111,98,117,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,227,222,5,158,0,0,16,1,56,50,115,49,50,51,46,117,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,197,221,246,244,0,0,32,0,108,101,103,101,110,100,32,111,102,32,104,101,114,111,32,116,111,110,109,97,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,134,20,19,60,0,0,16,1,107,108,97,120,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,180,89,27,15,0,0,16,1,98,111,110,107,39,115,32,97,100,118,101,110,116,117,114,101,32,40,117,115,97,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,155,173,158,89,0,0,16,1,99,49,50,45,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,65,237,241,56,2,0,0,0,99,49,50,45,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,188,48,149,237,2,0,0,0,99,49,50,45,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,39,153,142,18,2,0,0,0,99,49,50,45,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,25,163,167,93,2,0,0,0,99,49,50,45,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,56,75,129,242,9,0,0,0,116,102,45,56,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,100,221,166,254,1,0,16,1,116,102,45,51,46,54,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,90,208,249,2,1,0,16,1,116,102,45,55,46,52,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,126,222,232,253,1,0,16,1,116,102,45,50,46,52,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,20,116,152,219,1,0,16,1,116,102,45,54,46,51,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,163,155,30,185,1,0,16,1,116,102,45,49,46,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,117,35,226,214,1,0,16,1,116,102,45,48,48,49,46,49,55,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,56,65,107,235,2,0,16,1,57,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,188,124,111,188,3,0,32,0,53,46,49,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,253,61,210,37,4,0,32,0,52,46,49,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,39,254,176,185,4,0,32,0,49,53,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,224,216,68,33,5,0,32,0,49,52,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,158,92,79,116,5,0,32,0,116,102,45,48,48,51,46,55,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,161,133,64,215,6,0,32,0,116,102,45,48,48,50,46,57,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,197,160,138,20,6,0,32,0,49,48,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,18,88,112,172,7,0,32,8,110,56,50,115,49,50,57,97,110,46,49,49,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,87,71,36,129,8,0,0,8,102,45,49,52,46,52,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,127,85,95,142,1,0,16,1,102,45,49,49,46,51,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,42,22,32,83,1,0,16,1,102,45,49,51,46,52,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,224,81,105,168,1,0,16,1,102,45,57,46,51,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,59,244,181,88,1,0,16,1,102,45,49,50,46,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,118,29,14,79,1,0,16,1,102,45,56,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,128,66,1,209,1,0,16,1,102,45,49,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,56,65,107,235,2,0,16,1,102,45,49,49,46,52,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,188,124,111,188,3,0,32,0,102,45,54,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,253,61,210,37,4,0,32,0,102,45,55,46,51,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,39,254,176,185,4,0,32,0,102,45,52,46,57,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,224,216,68,33,5,0,32,0,102,45,53,46,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,158,92,79,116,5,0,32,0,102,45,51,46,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,161,133,64,215,6,0,32,0,102,45,50,46,54,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,197,160,138,20,6,0,32,0,50,45,117,52,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,138,229,111,171,0,0,16,1,51,45,117,52,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,57,46,228,2,0,0,16,1,117,50,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,115,239,66,237,0,0,32,0,117,50,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,238,202,33,141,0,0,32,0,117,50,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,237,78,227,239,0,0,32,0,117,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,85,125,29,104,0,0,32,0,117,51,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,235,46,46,42,0,0,32,0,49,45,117,54,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,135,227,37,32,0,0,16,1,117,54,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,197,51,54,166,0,0,64,0,117,54,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,87,195,208,58,0,0,64,0,52,45,117,53,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,16,57,49,48,55,48,95,54,56,107,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,231,58,28,18,1,0,16,1,57,49,48,55,48,95,54,56,107,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,142,77,21,110,1,0,16,1,57,49,48,55,48,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,116,61,73,191,2,0,16,1,57,49,48,55,48,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,32,89,54,254,3,0,32,0,57,49,48,55,48,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,38,232,189,208,4,0,32,0,57,49,48,55,48,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,254,194,237,62,5,0,32,0,57,49,48,55,48,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,117,104,174,6,0,64,0,57,49,48,55,48,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,62,164,254,236,7,0,64,0,57,49,48,55,48,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,108,184,219,207,0,0,0,8,57,49,48,55,48,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,73,211,234,230,0,0,0,8,115,112,115,95,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,207,93,188,47,1,0,16,1,115,112,115,95,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,201,37,176,81,1,0,16,1,115,112,115,95,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,34,1,99,231,1,0,16,1,115,112,115,95,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,16,73,178,182,1,0,16,1,115,112,115,95,49,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,136,150,184,72,2,0,16,1,115,112,115,95,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,117,190,10,26,3,0,32,0,115,112,115,95,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,117,144,39,54,3,0,32,0,115,112,115,95,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,217,231,237,124,3,0,32,0,115,112,115,95,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,215,230,37,100,3,0,32,0,115,112,115,95,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,137,21,43,161,3,0,32,0,115,112,115,95,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,18,29,103,176,4,0,32,0,115,112,115,95,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,126,149,49,194,4,0,32,0,115,112,115,95,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,9,119,75,144,4,0,32,0,115,112,115,95,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,172,255,48,84,4,0,32,0,115,112,115,95,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,120,98,74,65,4,0,32,0,115,112,115,95,50,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,109,32,231,201,5,0,32,0,115,112,115,95,50,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,5,200,21,123,5,0,32,0,115,112,115,95,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,50,242,194,138,5,0,32,0,115,112,115,95,50,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,227,84,199,252,5,0,32,0,115,112,115,95,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,12,143,108,77,5,0,32,0,115,112,115,95,50,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,66,139,210,157,5,0,32,0,115,112,115,95,49,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,54,15,109,69,6,0,64,0,115,112,115,95,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,95,65,63,243,6,0,64,0,115,118,99,45,112,50,112,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,183,226,192,80,1,0,16,1,115,118,99,45,112,51,112,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,147,194,205,88,1,0,16,1,115,118,99,45,112,49,112,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,66,216,148,161,1,0,16,1,115,118,99,45,115,49,112,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,17,71,52,115,2,0,32,0,115,118,99,45,99,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,137,107,130,167,3,0,32,0,115,118,99,45,99,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,137,32,60,237,3,0,32,0,115,118,99,45,99,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,99,128,237,113,3,0,32,0,115,118,99,45,99,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,45,222,11,37,3,0,32,0,115,118,99,45,99,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,130,192,23,152,3,0,32,0,115,118,99,45,99,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,127,48,192,43,3,0,32,0,115,118,99,45,99,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,185,215,88,67,3,0,32,0,115,118,99,45,99,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,229,238,109,54,3,0,32,0,115,118,99,45,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,195,40,67,128,4,0,16,1,115,118,99,45,118,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,135,114,9,181,5,0,64,0,115,118,99,45,118,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,31,57,58,189,5,0,64,0,115,118,99,45,118,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,55,11,252,51,5,0,64,0,115,118,99,45,118,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,160,73,152,170,5,0,64,0,50,54,57,45,112,49,97,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,94,0,226,56,1,0,16,1,50,54,57,45,112,50,97,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,124,121,19,109,1,0,16,1,50,54,57,45,99,49,97,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,12,43,77,230,3,0,32,0,50,54,57,45,99,50,97,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,194,137,144,36,3,0,32,0,50,54,57,45,99,51,97,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,171,47,47,211,3,0,32,0,50,54,57,45,99,52,97,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,120,232,119,191,3,0,32,0,50,54,57,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,157,129,246,4,0,16,1,50,54,57,45,118,49,97,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,83,71,175,166,5,0,64,0,115,118,99,45,112,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,98,241,72,3,1,0,16,1,115,118,99,45,115,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,241,77,180,112,2,0,32,0,115,118,99,45,99,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,137,107,130,167,3,0,32,0,115,118,99,45,99,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,137,32,60,237,3,0,32,0,115,118,99,45,99,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,99,128,237,113,3,0,32,0,115,118,99,45,99,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,45,222,11,37,3,0,32,0,115,118,99,45,99,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,130,192,23,152,3,0,32,0,115,118,99,45,99,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,127,48,192,43,3,0,32,0,115,118,99,45,99,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,185,215,88,67,3,0,32,0,115,118,99,45,99,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,229,238,109,54,3,0,32,0,115,118,99,45,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,195,40,67,128,4,0,16,1,115,118,99,45,118,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,135,114,9,181,5,0,64,0,115,118,99,45,118,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,31,57,58,189,5,0,64,0,115,118,99,45,118,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,55,11,252,51,5,0,64,0,115,118,99,45,118,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,160,73,152,170,5,0,64,0,57,49,49,109,48,49,46,102,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,200,44,91,238,1,0,16,1,57,49,49,109,48,50,46,104,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,168,72,65,93,1,0,16,1,57,49,49,100,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,25,35,141,48,2,0,32,0,57,49,49,100,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,50,155,204,145,2,0,32,0,57,49,49,100,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,130,241,79,227,3,0,32,0,57,49,49,100,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,210,11,112,32,3,0,32,0,57,49,49,106,48,49,46,102,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,129,120,100,30,1,0,16,1,57,49,49,108,48,50,46,104,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,136,130,219,17,1,0,16,1,57,49,49,100,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,25,35,141,48,2,0,32,0,57,49,49,100,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,50,155,204,145,2,0,32,0,57,49,49,100,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,130,241,79,227,3,0,32,0,57,49,49,100,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,210,11,112,32,3,0,32,0,48,55,57,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,142,50,120,94,1,0,16,1,48,55,57,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,101,102,192,58,2,0,32,0,48,55,57,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,42,199,129,5,3,0,32,0,48,55,57,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,182,143,155,91,3,0,32,0,48,55,57,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,98,187,101,205,3,0,32,0,48,55,57,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,19,2,201,164,3,0,32,0,48,55,57,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,90,69,227,190,4,0,16,1,48,55,57,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,36,138,113,5,0,64,0,48,55,57,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,235,116,7,114,5,0,64,0,49,46,51,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,164,34,8,6,1,0,16,1,50,46,52,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,250,88,147,51,1,0,16,1,97,45,52,98,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,149,92,101,24,2,0,16,1,98,45,55,97,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,241,75,46,109,3,0,32,0,98,45,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,210,27,29,120,4,0,32,0,98,45,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,132,139,70,137,5,0,32,0,98,45,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,50,236,148,87,6,0,32,0,98,45,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,237,13,222,176,6,0,32,0,97,45,52,97,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,207,205,154,239,7,0,64,0,97,45,54,118,46,109,99,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,16,114,111,109,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,239,34,10,248,1,0,16,1,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,252,203,46,128,1,0,16,1,115,116,114,97,104,108,45,52,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,196,153,167,96,2,0,16,1,115,116,114,97,104,108,45,51,46,55,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,62,179,115,34,3,0,32,0,115,116,114,55,98,50,114,48,46,50,55,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,225,227,105,87,4,0,32,0,115,116,114,108,51,45,48,49,46,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,21,127,51,216,5,0,32,0,115,116,114,108,52,45,48,50,46,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,43,85,56,42,5,0,32,0,115,116,114,108,53,45,48,51,46,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,16,210,231,160,5,0,32,0,115,116,114,54,98,49,119,49,46,55,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,85,177,27,187,9,0,32,0,115,116,114,56,112,109,119,49,46,53,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,106,187,214,1,6,0,64,0,115,116,114,57,112,101,119,49,46,54,51,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,159,235,179,107,7,0,64,0,48,56,56,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,246,20,88,189,1,0,16,1,48,56,56,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,8,178,60,7,2,0,32,0,48,56,56,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,33,52,115,110,3,0,32,0,48,56,56,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,71,83,134,77,3,0,32,0,48,56,56,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,235,169,165,143,3,0,32,0,48,56,56,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,220,240,4,70,3,0,32,0,48,56,56,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,153,244,225,47,4,0,16,1,48,56,56,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,35,80,120,183,5,0,64,0,48,53,50,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,86,114,217,156,1,0,16,1,48,53,50,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,4,152,104,151,2,0,32,0,48,53,50,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,2,192,225,83,3,0,32,0,48,53,50,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,31,45,106,119,3,0,32,0,48,53,50,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,45,125,241,73,4,0,16,1,48,53,50,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,165,151,192,34,5,0,64,0])
.concat([115,114,97,105,100,51,46,114,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,116,151,56,15,1,0,16,1,115,114,97,105,100,50,46,110,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,176,141,164,56,1,0,16,1,115,114,97,105,100,49,46,109,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,78,42,48,47,1,0,16,1,115,114,97,105,100,45,115,52,46,104,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,18,58,23,87,2,0,16,1,115,114,97,105,100,45,115,53,46,106,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,121,145,69,90,2,0,16,1,115,114,97,105,100,45,115,54,46,108,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,93,162,58,234,2,0,16,1,115,114,97,105,100,45,115,48,46,107,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,9,57,55,160,3,0,32,0,115,114,97,105,100,115,49,49,46,108,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,73,217,34,186,3,0,32,0,115,114,97,105,100,45,115,55,46,109,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,7,142,159,41,4,0,32,0,115,114,97,105,100,45,115,56,46,110,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,136,136,186,87,4,0,32,0,115,114,97,105,100,45,115,57,46,102,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,15,185,128,35,5,0,32,0,115,114,112,114,49,48,45,49,46,97,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,153,219,31,18,6,0,32,0,115,114,112,114,49,48,45,50,46,108,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,112,126,182,136,6,0,32,0,115,114,112,114,49,48,45,51,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,80,58,250,39,6,0,0,8,100,56,57,45,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,30,117,34,113,2,0,0,0,100,56,57,45,120,120,46,105,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,108,190,176,86,2,0,0,0,100,56,57,45,48,55,46,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,52,116,189,9,0,0,0,100,56,57,45,48,50,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,185,68,101,195,11,0,0,0,100,56,57,45,48,49,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,96,6,250,255,11,0,0,0,100,56,57,45,48,51,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,164,49,143,33,24,0,0,0,112,97,108,49,54,108,56,45,100,55,50,45,48,53,46,105,99,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,126,203,212,195,0,0,0,8,112,97,108,49,54,108,56,45,100,55,50,45,48,54,46,105,99,53,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,55,127,107,233,0,0,0,8,112,97,108,99,101,50,48,118,56,45,100,55,50,45,48,55,46,105,99,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,87,1,0,0,76,230,89,99,0,0,0,8,112,97,108,99,101,50,48,118,56,45,100,55,50,45,48,57,46,105,99,52,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,87,1,0,0,253,96,23,222,0,0,0,8,112,97,108,99,101,49,54,118,56,45,100,55,50,45,49,48,46,105,99,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,162,27,24,165,0,0,0,8,112,97,108,50,48,108,56,98,45,100,56,57,45,48,52,46,105,99,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,1,0,0,0,0,0,0,0,0,0,24,115,115,95,48,46,108,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,143,22,92,112,1,0,16,1,115,115,95,49,46,106,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,125,181,3,15,1,0,16,1,115,115,95,50,46,108,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,93,161,67,162,1,0,16,1,115,115,95,51,46,106,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,26,104,100,203,1,0,16,1,115,115,95,52,46,108,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,65,148,62,76,1,0,16,1,115,115,95,53,46,106,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,12,102,127,132,1,0,16,1,115,115,95,54,46,99,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,138,196,53,17,2,0,16,1,115,115,95,55,46,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,177,144,8,153,3,0,32,0,115,115,95,56,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,130,255,136,147,3,0,32,0,115,115,95,57,46,109,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,207,202,177,140,4,0,32,0,115,115,95,49,48,46,109,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,94,129,2,248,4,0,32,0,115,115,95,49,49,46,109,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,138,216,186,77,4,0,32,0,115,115,95,49,50,46,109,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,135,230,5,170,4,0,32,0,115,115,95,49,51,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,250,155,17,102,4,0,32,0,115,115,95,49,52,46,109,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,78,245,78,225,4,0,32,0,115,115,98,52,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,52,242,234,200,5,0,32,0,115,115,98,53,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,221,74,67,14,5,0,32,0,115,115,98,50,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,198,33,51,197,5,0,32,0,115,115,98,51,46,104,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,74,50,44,125,5,0,32,0,115,115,98,49,46,107,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,254,12,75,160,0,0,0,8,50,46,49,52,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,186,150,27,61,0,0,16,1,49,46,49,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,148,159,208,163,0,0,16,1,105,116,45,49,57,45,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,164,161,235,133,0,0,32,0,105,116,45,49,57,45,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,186,248,87,79,0,0,32,0,105,116,45,49,57,45,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,31,156,50,59,0,0,32,0,105,116,45,49,57,45,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,175,37,181,2,0,0,32,0,103,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,200,203,137,77,0,0,32,0,103,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,210,193,114,128,0,0,32,0,50,46,49,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,236,100,239,161,0,0,16,1,105,116,45,49,57,45,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,61,114,66,109,0,0,64,0,105,116,45,49,57,45,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,29,219,187,205,0,0,64,0,49,45,117,49,50,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,248,178,69,108,0,0,16,1,50,45,117,49,50,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,96,103,90,132,0,0,16,1,117,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,203,70,165,0,0,0,32,0,117,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,145,77,160,17,0,0,32,0,117,51,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,216,91,167,230,0,0,32,0,117,51,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,100,1,202,196,0,0,32,0,51,45,117,53,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,118,92,15,49,0,0,16,1,117,54,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,52,108,127,154,0,0,64,0,115,107,50,97,46,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,114,38,73,104,1,0,16,1,115,107,49,97,46,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,37,190,106,225,1,0,16,1,115,107,49,95,51,46,54,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,101,135,75,49,1,0,16,1,115,107,50,95,52,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,224,208,96,164,2,0,16,1,99,117,115,54,51,45,54,51,97,49,46,109,99,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,179,143,240,110,2,0,16,1,115,107,49,95,54,46,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,185,49,183,88,3,0,32,0,115,107,49,95,53,46,55,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,142,73,58,195,4,0,32,0,115,107,49,95,56,46,49,48,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,117,115,187,68,5,0,32,0,115,107,49,95,55,46,49,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,29,103,84,52,5,0,32,0,115,107,49,45,49,46,50,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,38,231,24,2,6,0,32,0,115,107,49,45,50,46,50,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,133,91,13,252,6,0,32,0,115,107,49,45,51,46,50,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,11,98,107,208,6,0,32,0,115,107,49,45,52,46,53,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,114,172,151,198,6,0,32,0,115,107,49,45,53,46,54,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,164,20,21,22,6,0,32,0,115,107,50,95,50,46,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,34,88,138,234,1,0,16,1,115,107,49,95,49,46,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,212,73,10,7,1,0,16,1,115,107,49,95,51,46,54,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,101,135,75,49,1,0,16,1,115,107,50,95,52,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,224,208,96,164,2,0,16,1,99,117,115,54,51,45,54,51,97,49,46,109,99,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,179,143,240,110,2,0,16,1,115,107,49,95,54,46,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,185,49,183,88,3,0,32,0,115,107,49,95,53,46,55,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,142,73,58,195,4,0,32,0,115,107,49,95,56,46,49,48,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,117,115,187,68,5,0,32,0,115,107,49,95,55,46,49,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,29,103,84,52,5,0,32,0,115,107,49,45,49,46,50,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,38,231,24,2,6,0,32,0,115,107,49,45,50,46,50,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,133,91,13,252,6,0,32,0,115,107,49,45,51,46,50,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,11,98,107,208,6,0,32,0,115,107,49,45,52,46,53,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,114,172,151,198,6,0,32,0,115,107,49,45,53,46,54,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,164,20,21,22,6,0,32,0,115,107,49,95,50,46,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,26,103,112,131,1,0,16,1,115,107,49,95,49,46,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,212,73,10,7,1,0,16,1,115,107,49,95,51,46,54,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,101,135,75,49,1,0,16,1,115,107,49,95,52,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,204,55,113,136,2,0,16,1,99,117,115,54,48,45,54,48,97,49,46,109,99,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,42,168,110,7,2,0,16,1,115,107,49,95,54,46,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,185,49,183,88,3,0,32,0,115,107,49,95,53,46,55,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,142,73,58,195,4,0,32,0,115,107,49,95,56,46,49,48,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,117,115,187,68,5,0,32,0,115,107,49,95,55,46,49,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,29,103,84,52,5,0,32,0,115,107,49,45,49,46,50,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,38,231,24,2,6,0,32,0,115,107,49,45,50,46,50,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,133,91,13,252,6,0,32,0,115,107,49,45,51,46,50,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,11,98,107,208,6,0,32,0,115,107,49,45,52,46,53,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,114,172,151,198,6,0,32,0,115,107,49,45,53,46,54,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,164,20,21,22,6,0,32,0,100,45,49,51,95,117,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,89,108,16,70,1,0,16,1,100,45,49,52,95,117,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,202,30,66,101,1,0,16,1,100,45,49,49,95,117,122,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,230,137,18,180,2,0,16,1,100,45,49,50,95,117,122,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,169,216,112,161,3,0,64,0,100,45,49,54,95,117,52,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,5,166,94,255,4,0,32,0,100,45,49,53,95,117,52,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,204,214,114,95,4,0,32,0,100,45,49,55,95,112,97,116,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,241,179,172,47,4,0,32,0,100,45,50,48,95,112,97,116,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,73,59,77,204,4,0,32,0,100,45,49,56,95,112,97,116,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,55,178,41,164,4,0,32,0,100,45,49,55,95,112,97,116,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,82,220,173,4,0,32,0,100,45,49,57,95,112,97,116,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,206,7,37,175,4,0,32,0,100,45,49,56,95,112,97,116,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,7,196,185,54,4,0,32,0,100,45,49,55,95,117,53,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,218,123,23,77,5,0,32,0,100,45,49,56,95,117,53,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,113,68,140,33,5,0,32,0,100,45,49,57,95,117,53,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,33,117,80,89,5,0,32,0,100,45,50,48,95,117,53,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,125,44,124,230,5,0,32,0,101,97,115,116,45,49,50,45,49,46,105,99,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,98,211,131,88,2,0,0,0,101,97,115,116,45,49,53,45,49,46,105,99,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,174,114,10,140,2,0,0,0,101,97,115,116,45,49,49,46,105,99,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,40,68,218,53,2,0,0,0,101,97,115,116,45,48,57,46,105,99,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,74,177,5,47,2,0,0,0,101,97,115,116,45,49,51,46,105,99,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,171,97,24,101,9,0,0,0,101,97,115,116,45,48,52,46,105,99,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,23,114,35,83,11,0,0,0,101,97,115,116,45,48,54,46,105,99,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,167,223,230,230,11,0,0,0,101,97,115,116,45,48,51,46,105,99,51,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,70,40,155,27,11,0,0,0,101,97,115,116,45,48,53,46,105,99,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,197,114,36,224,11,0,0,0,101,97,115,116,45,48,49,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,26,255,31,180,24,0,0,0,101,97,115,116,45,48,50,46,105,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,57,92,222,224,25,0,0,0,115,105,115,50,45,104,48,45,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,234,10,174,111,1,0,16,1,115,105,115,50,45,108,48,45,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,130,81,242,42,1,0,16,1,115,105,115,50,45,115,112,45,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,58,255,192,111,2,0,16,1,105,99,56,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,143,184,124,90,3,0,32,0,105,99,56,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,44,133,167,84,3,0,32,0,105,99,56,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,198,93,214,43,3,0,32,0,105,99,56,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,219,95,109,135,3,0,32,0,115,104,97,100,111,119,97,95,49,46,51,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,103,213,144,130,1,0,16,1,115,104,97,100,111,119,97,95,50,46,52,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,33,137,240,243,1,0,16,1,103,97,105,100,101,110,95,51,46,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,106,62,253,117,2,0,16,1,103,97,105,100,101,110,95,53,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,247,53,64,141,3,0,32,0,49,52,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,170,221,207,30,4,0,32,0,49,53,46,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,150,166,145,18,4,0,32,0,49,54,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,202,71,11,20,4,0,32,0,49,55,46,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,203,204,56,118,4,0,32,0,49,56,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,214,175,173,63,5,0,32,0,49,57,46,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,91,157,174,221,5,0,32,0,50,48,46,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,147,122,207,8,5,0,32,0,50,49,46,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,245,146,200,26,5,0,32,0,54,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,159,223,204,231,6,0,32,0,56,46,51,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,128,248,247,126,6,0,32,0,49,48,46,51,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,236,29,69,166,6,0,32,0,115,104,97,100,111,119,119,95,49,50,97,46,120,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,49,119,176,155,6,0,32,0,115,104,97,100,111,119,119,95,49,50,98,46,120,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,162,80,169,164,6,0,32,0,55,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,149,236,107,1,6,0,32,0,57,46,49,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,211,127,155,110,6,0,32,0,49,49,46,49,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,94,223,191,127,6,0,32,0,115,104,97,100,111,119,119,95,49,51,97,46,120,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,165,47,109,153,6,0,32,0,115,104,97,100,111,119,119,95,49,51,98,46,120,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,52,138,223,184,6,0,32,0,52,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,249,250,224,176,7,0,64,0,115,102,105,105,105,51,95,117,115,97,46,50,57,102,52,48,48,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,193,69,197,236,0,0,0,3,115,102,105,105,105,51,40,95,95,57,57,48,54,48,56,41,45,115,105,109,109,49,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,205,211,223,17,0,0,16,1,115,102,105,105,105,51,40,95,95,57,57,48,54,48,56,41,45,115,105,109,109,49,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,230,133,5,197,0,0,16,1,115,102,105,105,105,51,40,95,95,57,57,48,54,48,56,41,45,115,105,109,109,49,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,155,29,1,142,0,0,16,1,115,102,105,105,105,51,40,95,95,57,57,48,54,48,56,41,45,115,105,109,109,49,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,47,217,168,220,0,0,16,1,115,102,105,105,105,51,45,115,105,109,109,50,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,158,150,235,6,0,0,16,1,115,102,105,105,105,51,45,115,105,109,109,50,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,130,159,3,231,0,0,16,1,115,102,105,105,105,51,45,115,105,109,109,50,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,247,150,92,100,0,0,16,1,115,102,105,105,105,51,45,115,105,109,109,50,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,177,250,14,97,0,0,16,1,115,102,105,105,105,51,45,115,105,109,109,51,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,121,31,170,123,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,51,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,254,248,75,35,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,51,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,8,195,235,217,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,51,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,119,186,60,41,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,51,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,71,231,85,96,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,51,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,252,166,154,73,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,51,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,158,135,19,108,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,51,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,222,142,79,207,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,52,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,186,213,31,9,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,52,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,32,0,23,137,202,11,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,52,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,139,87,253,160,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,52,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,153,198,248,75,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,52,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,133,135,123,19,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,52,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,113,6,183,79,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,52,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,164,116,35,131,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,52,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,109,87,136,28,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,53,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,144,145,125,198,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,53,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,104,152,183,108,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,53,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,14,147,105,223,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,53,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,224,84,55,51,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,53,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,23,212,246,120,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,53,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,177,217,202,140,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,53,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,229,89,222,133,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,53,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,179,41,126,238,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,54,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,66,144,166,141,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,54,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,196,122,140,28,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,54,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,29,52,113,166,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,54,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,73,2,153,26,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,54,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,172,57,203,32,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,54,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,47,75,132,95,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,54,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,40,141,14,69,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,54,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,135,65,95,204,0,0,32,0,115,102,105,105,105,51,95,106,97,112,97,110,95,110,111,99,100,46,50,57,102,52,48,48,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,102,99,220,30,0,0,0,3,115,102,105,105,105,51,40,95,95,57,57,48,54,48,56,41,45,115,105,109,109,49,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,205,211,223,17,0,0,16,1,115,102,105,105,105,51,40,95,95,57,57,48,54,48,56,41,45,115,105,109,109,49,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,230,133,5,197,0,0,16,1,115,102,105,105,105,51,40,95,95,57,57,48,54,48,56,41,45,115,105,109,109,49,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,155,29,1,142,0,0,16,1,115,102,105,105,105,51,40,95,95,57,57,48,54,48,56,41,45,115,105,109,109,49,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,47,217,168,220,0,0,16,1,115,102,105,105,105,51,45,115,105,109,109,50,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,158,150,235,6,0,0,16,1,115,102,105,105,105,51,45,115,105,109,109,50,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,130,159,3,231,0,0,16,1,115,102,105,105,105,51,45,115,105,109,109,50,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,247,150,92,100,0,0,16,1,115,102,105,105,105,51,45,115,105,109,109,50,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,177,250,14,97,0,0,16,1,115,102,105,105,105,51,45,115,105,109,109,51,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,121,31,170,123,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,51,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,254,248,75,35,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,51,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,8,195,235,217,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,51,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,119,186,60,41,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,51,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,71,231,85,96,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,51,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,252,166,154,73,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,51,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,158,135,19,108,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,51,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,222,142,79,207,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,52,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,186,213,31,9,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,52,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,23,137,202,11,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,52,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,139,87,253,160,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,52,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,153,198,248,75,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,52,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,133,135,123,19,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,52,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,113,6,183,79,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,52,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,164,116,35,131,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,52,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,109,87,136,28,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,53,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,144,145,125,198,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,53,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,104,152,183,108,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,53,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,14,147,105,223,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,53,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,224,84,55,51,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,53,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,23,212,246,120,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,53,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,177,217,202,140,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,53,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,229,89,222,133,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,53,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,179,41,126,238,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,54,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,66,144,166,141,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,54,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,196,122,140,28,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,54,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,29,52,113,166,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,54,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,73,2,153,26,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,54,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,172,57,203,32,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,54,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,47,75,132,95,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,54,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,40,141,14,69,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,54,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,135,65,95,204,0,0,32,0,115,102,105,105,105,50,95,97,115,105,97,95,110,111,99,100,46,50,57,102,52,48,48,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,13,124,41,253,0,0,0,3,115,102,105,105,105,50,45,115,105,109,109,49,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,11,111,102,45,0,0,16,1,115,102,105,105,105,50,45,115,105,109,109,49,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,246,142,58,42,0,0,16,1,115,102,105,105,105,50,45,115,105,109,109,49,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,6,34,29,22,0,0,16,1,115,102,105,105,105,50,45,115,105,109,109,49,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,163,216,222,135,0,0,16,1,115,102,105,105,105,50,45,115,105,109,109,50,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,15,206,164,148,0,0,16,1,115,102,105,105,105,50,45,115,105,109,109,50,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,51,80,88,103,0,0,16,1,115,102,105,105,105,50,45,115,105,109,109,50,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,213,252,191,250,0,0,16,1,115,102,105,105,105,50,45,115,105,109,109,50,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,202,9,60,98,0,0,16,1,115,102,105,105,105,50,45,115,105,109,109,51,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,102,215,178,218,0,0,32,0,115,102,105,105,105,50,45,115,105,109,109,51,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,75,163,42,31,0,0,32,0,115,102,105,105,105,50,45,115,105,109,109,51,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,235,4,26,111,0,0,32,0,115,102,105,105,105,50,45,115,105,109,109,51,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,5,242,94,224,0,0,32,0,115,102,105,105,105,50,45,115,105,109,109,51,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,79,7,251,175,0,0,32,0,115,102,105,105,105,50,45,115,105,109,109,51,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,46,135,98,105,0,0,32,0,115,102,105,105,105,50,45,115,105,109,109,51,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,222,135,237,110,0,0,32,0,115,102,105,105,105,50,45,115,105,109,109,51,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,158,71,143,225,0,0,32,0,115,102,105,105,105,50,45,115,105,109,109,52,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,3,37,76,118,0,0,32,0,115,102,105,105,105,50,45,115,105,109,109,52,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,110,175,22,62,0,0,32,0,115,102,105,105,105,50,45,115,105,109,109,52,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,230,5,87,33,0,0,32,0,115,102,105,105,105,50,45,115,105,109,109,52,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,156,189,12,227,0,0,32,0,115,102,105,105,105,50,45,115,105,109,109,52,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,217,222,133,65,0,0,32,0,115,102,105,105,105,50,45,115,105,109,109,52,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,19,176,141,78,0,0,32,0,115,102,105,105,105,50,45,115,105,109,109,52,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,206,72,223,8,0,0,32,0,115,102,105,105,105,50,45,115,105,109,109,52,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,165,128,143,187,0,0,32,0,115,102,105,105,105,50,45,115,105,109,109,53,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,135,71,220,235,0,0,32,0,115,102,105,105,105,50,45,115,105,109,109,53,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,14,85,124,107,0,0,32,0,115,102,105,105,105,50,45,115,105,109,109,53,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,80,140,255,86,0,0,32,0,115,102,105,105,105,50,45,115,105,109,109,53,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,233,195,42,63,0,0,32,0,115,102,105,105,105,50,45,115,105,109,109,53,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,14,165,205,72,0,0,32,0,115,102,105,105,105,50,45,115,105,109,109,53,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,246,10,12,82,0,0,32,0,115,102,105,105,105,50,45,115,105,109,109,53,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,134,89,220,46,0,0,32,0,115,102,105,105,105,50,45,115,105,109,109,53,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,153,161,255,147,0,0,32,0,115,102,105,105,105,50,95,106,97,112,97,110,46,50,57,102,52,48,48,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,62,10,234,250,0,0,0,3,115,102,105,105,105,50,45,115,105,109,109,49,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,11,111,102,45,0,0,16,1,115,102,105,105,105,50,45,115,105,109,109,49,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,246,142,58,42,0,0,16,1,115,102,105,105,105,50,45,115,105,109,109,49,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,6,34,29,22,0,0,16,1,115,102,105,105,105,50,45,115,105,109,109,49,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,163,216,222,135,0,0,16,1,115,102,105,105,105,50,45,115,105,109,109,50,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,15,206,164,148,0,0,16,1,115,102,105,105,105,50,45,115,105,109,109,50,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,51,80,88,103,0,0,16,1,115,102,105,105,105,50,45,115,105,109,109,50,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,213,252,191,250,0,0,16,1,115,102,105,105,105,50,45,115,105,109,109,50,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,202,9,60,98,0,0,16,1,115,102,105,105,105,50,45,115,105,109,109,51,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,102,215,178,218,0,0,32,0,115,102,105,105,105,50,45,115,105,109,109,51,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,75,163,42,31,0,0,32,0,115,102,105,105,105,50,45,115,105,109,109,51,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,235,4,26,111,0,0,32,0,115,102,105,105,105,50,45,115,105,109,109,51,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,5,242,94,224,0,0,32,0,115,102,105,105,105,50,45,115,105,109,109,51,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,79,7,251,175,0,0,32,0,115,102,105,105,105,50,45,115,105,109,109,51,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,46,135,98,105,0,0,32,0,115,102,105,105,105,50,45,115,105,109,109,51,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,222,135,237,110,0,0,32,0,115,102,105,105,105,50,45,115,105,109,109,51,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,158,71,143,225,0,0,32,0,115,102,105,105,105,50,45,115,105,109,109,52,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,3,37,76,118,0,0,32,0,115,102,105,105,105,50,45,115,105,109,109,52,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,110,175,22,62,0,0,32,0,115,102,105,105,105,50,45,115,105,109,109,52,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,230,5,87,33,0,0,32,0,115,102,105,105,105,50,45,115,105,109,109,52,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,156,189,12,227,0,0,32,0,115,102,105,105,105,50,45,115,105,109,109,52,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,217,222,133,65,0,0,32,0,115,102,105,105,105,50,45,115,105,109,109,52,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,19,176,141,78,0,0,32,0,115,102,105,105,105,50,45,115,105,109,109,52,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,206,72,223,8,0,0,32,0,115,102,105,105,105,50,45,115,105,109,109,52,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,165,128,143,187,0,0,32,0,115,102,105,105,105,50,45,115,105,109,109,53,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,135,71,220,235,0,0,32,0,115,102,105,105,105,50,45,115,105,109,109,53,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,14,85,124,107,0,0,32,0,115,102,105,105,105,50,45,115,105,109,109,53,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,80,140,255,86,0,0,32,0,115,102,105,105,105,50,45,115,105,109,109,53,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,233,195,42,63,0,0,32,0,115,102,105,105,105,50,45,115,105,109,109,53,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,14,165,205,72,0,0,32,0,115,102,105,105,105,50,45,115,105,109,109,53,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,246,10,12,82,0,0,32,0,115,102,105,105,105,50,45,115,105,109,109,53,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,134,89,220,46,0,0,32,0,115,102,105,105,105,50,45,115,105,109,109,53,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,153,161,255,147,0,0,32,0,48,49,55,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,131,57,166,248,1,0,16,1,48,49,55,45,112,50,46,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,179,187,36,48,1,0,16,1,48,49,55,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,77,32,70,178,2,0,32,0,48,49,55,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,161,130,235,180,3,0,32,0,48,49,55,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,13,85,92,213,3,0,32,0,48,49,55,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,101,239,81,237,3,0,32,0,48,49,55,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,203,201,243,244,3,0,32,0,48,49,55,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,198,52,79,155,4,0,16,1,48,49,55,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,149,50,102,35,5,0,64,0,48,49,55,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,101,103,30,246,5,0,64,0,50,48,56,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,50,61,127,18,1,0,16,1,50,48,56,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,179,214,171,100,2,0,32,0,50,48,56,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,155,97,216,147,3,0,32,0,50,48,56,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,182,123,115,28,3,0,32,0,50,48,56,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,3,23,203,20,3,0,32,0,50,48,56,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,25,95,22,199,3,0,32,0,50,48,56,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,37,51,95,10,4,0,16,1,50,48,56,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,36,154,137,231,5,0,64,0,55,55,53,45,101,48,50,46,107,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,173,14,28,166,1,0,16,1,55,55,53,45,101,48,51,46,107,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,34,38,176,0,1,0,16,1,55,55,53,45,99,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,90,120,237,12,2,0,16,1,55,55,53,45,97,48,55,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,243,189,22,231,3,0,32,0,55,55,53,45,97,48,55,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,165,227,134,9,3,0,32,0,55,55,53,45,102,48,55,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,21,9,179,176,3,0,32,0,55,55,53,45,102,48,55,103,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,125,130,237,251,3,0,32,0,55,55,53,45,102,48,55,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,142,190,132,241,3,0,32,0,55,55,53,45,102,48,55,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,72,195,86,123,3,0,32,0,55,55,53,45,97,48,56,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,164,17,221,61,3,0,32,0,55,55,53,45,97,48,56,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,99,217,7,16,3,0,32,0,55,55,53,45,102,48,56,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,236,218,171,83,3,0,32,0,55,55,53,45,102,48,56,103,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,110,90,248,61,3,0,32,0,55,55,53,45,102,48,56,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,206,202,45,16,3,0,32,0,55,55,53,45,102,48,56,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,22,112,157,173,3,0,32,0,55,55,53,45,97,48,53,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,69,112,118,160,4,0,32,0,55,55,53,45,97,48,53,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,8,111,101,47,4,0,32,0,55,55,53,45,97,48,53,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,253,212,138,171,4,0,32,0,55,55,53,45,97,48,53,102,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,182,177,14,28,4,0,32,0,55,55,53,45,102,48,53,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,30,118,71,86,4,0,32,0,55,55,53,45,102,48,53,103,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,202,44,105,161,4,0,32,0,55,55,53,45,102,48,53,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,111,106,103,173,4,0,32,0,55,55,53,45,102,48,53,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,207,91,146,63,4,0,32,0,55,55,53,45,97,48,54,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,208,74,163,119,4,0,32,0,55,55,53,45,97,48,54,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,148,12,145,138,4,0,32,0,55,55,53,45,97,48,54,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,101,181,63,86,4,0,32,0,55,55,53,45,97,48,54,102,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,192,149,73,225,4,0,32,0,55,55,53,45,102,48,54,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,193,243,230,94,4,0,32,0,55,55,53,45,102,48,54,103,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,77,39,69,38,4,0,32,0,55,55,53,45,102,48,54,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,250,100,183,200,4,0,32,0,55,55,53,45,102,48,54,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,89,95,89,214,4,0,32,0,55,55,53,45,97,48,52,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,15,46,251,126,5,0,64,0,55,55,53,45,97,48,52,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,51,43,26,244,5,0,64,0,55,55,53,45,97,48,52,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,20,143,229,228,5,0,64,0,55,55,53,45,97,48,52,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,246,54,103,212,5,0,64,0,55,55,53,45,102,48,52,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,99,227,247,251,5,0,64,0,55,55,53,45,102,48,52,102,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,45,239,49,176,5,0,64,0,55,55,53,45,102,48,52,103,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,187,123,16,238,5,0,64,0,55,55,53,45,102,48,52,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,70,171,15,251,5,0,64,0,55,55,53,97,48,57,46,98,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,223,224,209,70,6,0,0,8,49,49,46,105,99,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,11,21,22,121,1,0,16,1,49,48,46,105,99,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,184,204,122,29,1,0,16,1,54,46,105,99,49,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,128,169,57,95,2,0,16,1,55,46,105,99,52,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,128,127,183,242,3,0,32,0,115,98,115,45,103,95,48,49,46,105,99,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,120,46,48,33,4,0,32,0,115,98,115,45,103,95,48,51,46,105,99,49,57,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,123,13,224,96,5,0,32,0,115,98,115,45,103,95,48,50,46,105,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,104,182,30,243,9,0,32,0,56,46,105,99,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,234,111,164,117,10,0,32,0,57,46,105,99,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,238,72,20,217,10,0,32,0,115,98,115,45,103,95,48,52,46,105,99,49,51,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,78,204,116,124,6,0,64,0,115,98,115,45,103,95,48,53,46,105,99,49,54,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,227,130,167,240,7,0,64,0,56,50,115,49,51,53,46,105,99,57,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,151,28,237,152,0,0,0,8,56,50,115,49,50,57,46,105,99,54,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,108,184,219,207,0,0,0,8,56,50,115,49,50,51,46,105,99,49,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,199,159,120,15,0,0,0,8,49,45,98,95,112,114,95,108,46,117,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,37,34,209,82,1,0,16,1,49,45,98,95,112,114,95,104,46,117,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,69,3,189,27,1,0,16,1,48,108,46,117,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,81,172,228,183,2,0,32,0,48,104,46,117,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,39,108,94,35,2,0,32,0,49,108,46,117,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,140,196,136,60,2,0,32,0,49,104,46,117,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,110,106,98,21,2,0,32,0,50,108,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,100,47,233,65,2,0,32,0,50,104,46,117,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,132,46,230,74,2,0,32,0,51,108,46,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,15,95,186,67,2,0,32,0,51,104,46,117,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,18,187,1,255,2,0,32,0,52,108,46,117,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,147,213,145,228,2,0,32,0,52,104,46,117,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,122,55,221,123,2,0,32,0,115,111,117,110,100,46,117,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,105,255,203,133,3,0,64,0,101,101,112,114,111,109,45,115,98,111,109,98,101,114,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,70,136,195,122,0,0,0,8,48,52,53,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,240,27,229,223,1,0,16,1,48,52,53,45,112,50,46,115,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,169,155,238,56,1,0,16,1,48,52,53,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,211,164,66,145,2,0,32,0,48,52,53,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,164,115,88,46,3,0,32,0,48,52,53,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,16,187,254,4,3,0,32,0,48,52,53,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,30,189,218,243,3,0,32,0,48,52,53,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,240,98,92,147,3,0,32,0,48,52,53,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,132,130,187,162,3,0,32,0,48,52,53,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,18,167,79,3,0,32,0,48,52,53,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,64,6,23,149,4,0,16,1,48,52,53,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,155,138,247,55,5,0,64,0,48,52,53,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,207,32,139,86,5,0,64,0,50,55,48,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,230,9,42,74,1,0,16,1,50,55,48,45,112,50,46,115,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,133,76,199,224,1,0,16,1,50,55,48,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,172,255,255,20,3,0,32,0,50,55,48,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,153,114,31,64,3,0,32,0,50,55,48,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,96,2,143,131,3,0,32,0,50,55,48,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,165,96,21,4,3,0,32,0,50,55,48,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,45,181,48,189,3,0,32,0,50,55,48,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,112,156,166,134,3,0,32,0,50,55,48,45,99,55,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,60,188,143,210,3,0,32,0,50,55,48,45,99,56,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,166,48,197,2,3,0,32,0,50,55,48,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,26,144,201,73,4,0,16,1,50,55,48,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,235,52,228,98,5,0,64,0,50,55,48,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,154,60,15,24,5,0,64,0,50,50,50,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,109,181,92,26,1,0,16,1,50,50,50,45,112,50,46,115,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,139,205,35,176,1,0,16,1,50,50,50,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,249,59,61,141,2,0,32,0,50,50,50,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,149,237,242,104,3,0,32,0,50,50,50,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,240,175,233,166,3,0,32,0,50,50,50,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,244,64,27,201,3,0,32,0,50,50,50,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,164,16,149,53,3,0,32,0,50,50,50,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,45,178,251,156,3,0,32,0,50,50,50,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,50,252,94,104,3,0,32,0,50,50,50,45,99,55,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,13,111,248,208,3,0,32,0,50,50,50,45,99,56,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,227,80,252,173,3,0,32,0,50,50,50,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,27,188,21,118,4,0,16,1,50,50,50,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,95,169,107,125,5,0,64,0,50,50,50,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,93,187,51,108,5,0,64,0,50,50,50,45,118,51,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,192,168,30,131,5,0,64,0,48,56,55,45,101,112,114,46,101,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,184,155,224,35,1,0,16,1,48,56,55,45,101,112,114,46,101,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,2,83,111,37,1,0,16,1,48,56,55,45,101,112,114,46,101,112,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,221,181,45,191,1,0,16,1,48,56,55,45,101,112,114,46,101,112,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,88,12,230,83,1,0,16,1,48,56,55,45,112,53,46,112,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,175,164,108,232,1,0,16,1,48,56,55,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,159,125,236,116,2,0,32,0,48,56,55,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,188,51,162,7,3,0,32,0,48,56,55,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,146,53,65,122,3,0,32,0,48,56,55,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,150,55,121,139,3,0,32,0,48,56,55,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,17,191,143,114,3,0,32,0,48,56,55,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,128,177,42,23,3,0,32,0,48,56,55,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,243,248,47,0,3,0,32,0,48,56,55,45,99,55,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,61,14,69,174,3,0,32,0,48,56,55,45,99,56,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,23,39,232,169,3,0,32,0,48,56,55,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,235,64,100,142,4,0,16,1,48,56,55,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,160,217,189,132,5,0,64,0,48,56,55,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,26,38,15,172,5,0,64,0,48,54,51,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,146,136,54,34,1,0,16,1,48,54,51,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,102,205,165,100,2,0,32,0,48,54,51,45,99,49,46,99,49,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,124,48,205,134,3,0,32,0,48,54,51,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,202,196,252,205,3,0,32,0,48,54,51,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,199,204,99,122,3,0,32,0,48,54,51,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,206,37,16,117,3,0,32,0,48,54,51,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,117,164,211,32,3,0,32,0,48,54,51,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,136,10,76,174,3,0,32,0,48,54,51,45,99,55,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,207,203,243,45,3,0,32,0,48,54,51,45,99,56,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,250,109,252,31,3,0,32,0,48,54,51,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,152,80,103,86,4,0,16,1,48,54,51,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,145,63,112,55,5,0,64,0,48,54,51,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,232,189,66,1,5,0,64,0,48,54,51,45,118,51,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,202,165,127,208,5,0,64,0,48,54,51,45,118,52,46,118,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,187,180,170,36,5,0,64,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,9,0,0,0,10,0,0,0,11,0,0,0,12,0,0,0,13,0,0,0,14,0,0,0,15,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,15,0,0,0,16,0,0,0,24,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,9,0,0,0,10,0,0,0,11,0,0,0,12,0,0,0,25,0,0,0,26,0,0,0,15,0,0,0,16,0,0,0,27,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,9,0,0,0,10,0,0,0,11,0,0,0,12,0,0,0,28,0,0,0,29,0,0,0,15,0,0,0,16,0,0,0,30,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,9,0,0,0,10,0,0,0,11,0,0,0,12,0,0,0,31,0,0,0,32,0,0,0,15,0,0,0,16,0,0,0,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,9,0,0,0,10,0,0,0,11,0,0,0,12,0,0,0,34,0,0,0,35,0,0,0,15,0,0,0,16,0,0,0,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,9,0,0,0,10,0,0,0,11,0,0,0,12,0,0,0,13,0,0,0,14,0,0,0,15,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,9,0,0,0,10,0,0,0,11,0,0,0,12,0,0,0,13,0,0,0,14,0,0,0,15,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,15,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,9,0,0,0,10,0,0,0,11,0,0,0,12,0,0,0,23,0,0,0,24,0,0,0,15,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,9,0,0,0,10,0,0,0,11,0,0,0,12,0,0,0,25,0,0,0,26,0,0,0,15,0,0,0,49,45,117,52,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,134,128,250,69,0,0,16,1,50,45,117,51,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,140,171,82,1,0,0,16,1,117,50,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,238,127,162,40,0,0,32,0,117,50,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,50,42,21,202,0,0,32,0,117,50,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,169,14,214,197,0,0,32,0,117,50,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,50,3,113,72,0,0,32,0,117,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,84,38,226,222,0,0,32,0,117,51,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,35,62,248,170,0,0,32,0,51,45,117,55,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,189,102,227,227,0,0,16,1,117,54,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,155,74,74,164,0,0,64,0,117,53,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,194,18,19,254,0,0,64,0,50,95,112,114,111,103,95,108,46,117,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,184,17,169,32,1,0,16,1,49,95,112,114,111,103,95,104,46,117,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,94,232,15,76,1,0,16,1,48,108,46,117,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,141,249,172,191,2,0,32,0,48,104,46,117,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,124,246,102,18,2,0,32,0,49,108,46,117,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,201,50,51,45,2,0,32,0,49,104,46,117,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,62,44,179,39,2,0,32,0,50,108,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,35,109,186,145,2,0,32,0,50,104,46,117,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,52,67,191,250,2,0,32,0,51,108,46,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,78,112,195,166,2,0,32,0,51,104,46,117,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,112,202,211,76,2,0,32,0,115,111,117,110,100,46,117,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,167,12,104,186,3,0,64,0,101,101,112,114,111,109,45,115,49,57,52,53,105,105,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,70,136,195,122,0,0,0,8,100,98,95,98,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,65,81,134,193,1,0,16,1,100,98,95,97,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,144,189,210,90,1,0,16,1,100,98,95,98,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,126,64,246,180,1,0,16,1,100,98,95,97,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,111,216,152,96,1,0,16,1,114,116,95,114,45,48,48,46,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,192,59,213,218,2,0,32,0,114,116,95,114,45,48,49,46,49,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,127,30,68,94,2,0,32,0,114,116,95,114,45,49,48,46,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,152,98,166,214,2,0,32,0,114,116,95,114,45,49,49,46,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,248,244,29,121,2,0,32,0,114,116,95,114,45,50,48,46,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,138,124,36,252,2,0,32,0,114,116,95,114,45,50,49,46,51,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,65,56,121,237,2,0,32,0,114,116,95,114,45,51,48,46,51,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,203,161,2,235,2,0,32,0,114,116,95,114,45,51,49,46,51,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,93,53,88,133,2,0,32,0,114,116,95,98,45,97,48,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,176,47,33,78,3,0,32,0,114,116,95,98,45,97,49,46,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,255,189,101,138,3,0,32,0,114,116,95,98,45,97,50,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,185,229,74,90,3,0,32,0,114,116,95,98,45,97,51,46,51,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,6,118,50,115,3,0,32,0,114,116,95,98,45,98,48,46,51,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,145,116,177,167,4,0,32,0,114,116,95,98,45,98,49,46,51,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,134,150,112,185,4,0,32,0,114,116,95,98,45,98,50,46,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,154,34,59,67,4,0,32,0,114,116,95,98,45,98,51,46,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,114,176,137,173,4,0,32,0,114,116,50,45,97,45,104,48,46,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,246,204,87,120,1,0,16,1,114,116,50,45,97,45,108,48,46,54,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,110,205,34,203,1,0,16,1,114,116,50,45,97,45,104,49,46,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,40,93,231,73,1,0,16,1,114,116,50,45,97,45,108,49,46,53,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,118,22,236,18,1,0,16,1,105,99,49,55,46,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,180,236,255,115,6,0,16,1,105,99,51,49,46,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,19,249,216,44,2,0,32,0,105,99,50,49,46,52,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,109,6,51,80,2,0,32,0,105,99,51,50,46,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,80,4,58,236,2,0,32,0,105,99,50,50,46,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,252,118,97,219,2,0,32,0,105,99,53,48,46,55,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,110,115,248,243,3,0,32,0,105,99,53,49,46,55,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,175,67,197,180,3,0,32,0,105,99,53,54,46,56,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,102,13,184,76,3,0,32,0,105,99,53,55,46,56,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,224,40,225,190,3,0,32,0,105,99,54,53,46,57,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,26,199,201,45,3,0,32,0,105,99,54,54,46,57,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,40,196,51,117,3,0,32,0,105,99,54,51,46,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,242,103,173,166,3,0,32,0,105,99,54,52,46,57,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,85,213,134,54,3,0,32,0,105,99,49,52,46,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,213,114,113,99,5,0,64,0,114,111,117,116,101,49,54,46,97,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,189,1,145,143,1,0,16,1,114,111,117,116,101,49,54,46,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,119,192,155,56,1,0,16,1,114,111,117,116,101,49,54,46,97,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,104,164,101,16,1,0,16,1,114,111,117,116,101,49,54,46,97,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,243,135,25,11,1,0,16,1,114,111,117,116,101,49,54,46,97,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,58,133,125,246,1,0,16,1])
.concat([114,111,117,116,101,49,54,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,88,247,92,216,1,0,16,1,114,111,117,116,101,49,54,46,98,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,167,136,149,15,2,0,16,1,114,111,117,116,101,49,54,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,249,108,50,43,2,0,16,1,114,111,117,116,101,49,54,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,19,173,156,82,2,0,16,1,114,111,117,116,101,49,54,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,153,184,216,59,2,0,16,1,105,109,53,54,50,51,46,102,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,247,62,121,8,3,0,32,0,105,109,53,54,50,51,46,102,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,247,62,121,8,3,0,32,0,57,57,57,109,48,50,46,103,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,147,219,248,61,1,0,16,1,57,57,57,109,48,49,46,101,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,47,178,207,31,2,0,16,1,57,57,57,104,48,54,46,107,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,48,81,160,237,3,0,32,0,57,57,57,104,48,53,46,107,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,125,28,50,95,3,0,32,0,57,57,57,104,48,51,46,100,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,210,219,30,234,4,0,32,0,57,57,57,104,48,52,46,102,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,85,83,163,193,4,0,32,0,57,57,57,104,48,57,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,131,135,24,197,5,0,64,0,48,48,54,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,151,245,170,212,1,0,16,1,48,48,54,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,240,137,81,235,2,0,32,0,48,48,54,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,120,127,92,74,3,0,32,0,48,48,54,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,206,14,183,224,3,0,32,0,48,48,54,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,101,247,207,138,3,0,32,0,48,48,54,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,8,50,94,32,3,0,32,0,48,48,54,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,254,180,231,146,4,0,16,1,48,48,54,45,118,49,49,46,118,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,66,74,247,205,5,0,64,0,48,48,54,45,118,49,50,46,118,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,113,35,253,226,5,0,64,0,48,48,54,45,118,50,49,46,118,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,206,43,9,148,6,0,64,0,48,48,54,45,118,50,50,46,118,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,195,215,44,78,6,0,64,0,48,48,54,45,118,50,51,46,118,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,237,113,156,6,6,0,64,0,48,48,54,45,118,50,52,46,118,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,37,184,251,137,6,0,64,0,104,100,54,51,48,49,118,49,112,46,99,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,24,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,38,243,245,62,1,0,16,1,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,239,16,58,155,1,0,16,1,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,142,242,140,93,2,0,16,1,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,138,123,66,214,4,0,32,0,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,109,151,168,102,5,0,32,0,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,100,1,86,97,5,0,32,0,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,51,206,17,233,6,0,32,0,114,104,112,57,52,48,57,57,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,5,79,155,236,1,0,16,1,114,104,112,57,52,48,57,57,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,225,236,1,254,2,0,16,1,114,104,112,57,52,48,57,57,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,17,160,167,85,3,0,32,0,114,104,112,57,52,48,57,57,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,123,238,110,7,4,0,32,0,114,104,112,57,52,48,57,57,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,7,47,137,73,5,0,32,0,114,104,112,57,52,48,57,57,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,240,71,46,234,5,0,32,0,114,104,112,57,52,48,57,57,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,57,184,44,81,5,0,32,0,114,104,112,57,52,48,57,57,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,126,84,153,13,6,0,64,0,114,104,112,57,52,48,57,57,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,147,186,94,81,7,0,64,0,114,104,112,57,52,48,57,57,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,90,14,168,241,7,0,64,0,114,104,112,57,52,48,57,57,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,126,84,153,13,7,0,64,0,114,104,112,57,52,48,57,57,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,126,84,153,13,7,0,64,0,112,114,111,109,49,46,117,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,110,119,153,66,0,0,0,8,112,114,111,109,50,46,117,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,73,211,234,230,0,0,0,8,112,114,111,109,51,46,117,54,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,198,152,79,48,0,0,0,8,114,97,109,98,51,45,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,71,34,196,28,2,0,0,0,114,97,109,98,51,45,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,183,76,150,10,2,0,0,0,114,97,109,98,51,45,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,111,255,115,201,2,0,0,0,114,97,109,98,51,45,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,213,63,61,168,2,0,0,0,114,97,109,98,51,45,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,32,192,139,177,9,0,0,0,114,97,109,98,51,45,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,65,140,128,245,11,0,0,0,114,97,109,98,51,45,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,206,49,120,197,11,0,0,0,114,97,109,98,51,45,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,84,207,95,197,11,0,0,0,114,97,109,98,51,45,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,198,20,208,157,11,0,0,0,114,97,109,98,51,45,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,64,220,121,1,24,0,0,0,114,51,45,48,101,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,119,65,250,62,2,0,0,0,114,51,45,48,111,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,146,141,195,85,2,0,0,0,114,51,45,49,101,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,199,99,227,64,2,0,0,0,114,51,45,49,111,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,171,230,31,127,2,0,0,0,114,51,45,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,214,110,122,223,9,0,0,0,114,51,45,99,104,49,108,108,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,252,165,110,200,12,0,0,0,114,51,45,99,104,49,108,104,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,240,140,86,117,12,0,0,0,114,51,45,99,104,49,104,108,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,146,235,37,117,12,0,0,0,114,51,45,99,104,49,104,104,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,55,255,156,227,12,0,0,0,114,51,45,99,104,51,108,108,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,30,75,229,171,12,0,0,0,114,51,45,99,104,51,108,104,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,4,92,21,90,12,0,0,0,114,51,45,99,104,51,104,108,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,126,100,229,128,12,0,0,0,114,51,45,99,104,51,104,104,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,219,143,229,171,12,0,0,0,114,51,45,99,104,48,108,108,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,191,241,22,180,12,0,0,0,114,51,45,99,104,48,108,104,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,162,48,163,118,12,0,0,0,114,51,45,99,104,48,104,108,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,109,211,202,164,12,0,0,0,114,51,45,99,104,48,104,104,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,81,151,198,77,12,0,0,0,114,51,45,99,104,50,108,108,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,81,48,206,208,12,0,0,0,114,51,45,99,104,50,108,104,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,143,196,59,223,12,0,0,0,114,51,45,99,104,50,104,108,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,119,134,125,131,12,0,0,0,114,51,45,99,104,50,104,104,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,172,223,55,191,12,0,0,0,114,51,45,97,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,25,250,150,67,24,0,0,0,114,51,45,97,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,168,83,254,65,24,0,0,0,114,51,45,97,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,186,73,146,232,24,0,0,0,114,51,45,97,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,27,194,244,156,24,0,0,0,49,46,117,48,50,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,133,39,177,164,0,0,16,1,50,46,117,48,50,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,213,11,100,23,0,0,16,1,51,97,46,117,48,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,221,219,250,168,0,0,16,1,52,97,46,117,48,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,141,38,251,186,0,0,16,1,53,46,117,48,52,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,46,86,3,237,0,0,16,1,54,46,117,48,52,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,93,91,157,161,0,0,16,1,56,46,117,50,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,199,85,224,203,0,0,16,1,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,94,178,34,25,0,0,32,0,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,106,120,144,95,0,0,32,0,115,101,105,52,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,11,31,21,218,0,0,32,0,115,101,105,52,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,172,87,31,172,0,0,32,0,115,101,105,52,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,222,123,109,148,0,0,32,0,55,46,117,50,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,34,120,146,143,0,0,64,0,49,46,117,48,50,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,133,39,177,164,0,0,16,1,50,46,117,48,50,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,213,11,100,23,0,0,16,1,51,46,117,48,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,208,9,175,246,0,0,16,1,52,116,46,117,48,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,177,250,238,97,0,0,16,1,53,46,117,48,52,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,46,86,3,237,0,0,16,1,54,46,117,48,52,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,93,91,157,161,0,0,16,1,56,46,117,50,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,199,85,224,203,0,0,16,1,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,94,178,34,25,0,0,32,0,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,106,120,144,95,0,0,32,0,115,101,105,52,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,11,31,21,218,0,0,32,0,115,101,105,52,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,172,87,31,172,0,0,32,0,115,101,105,52,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,222,123,109,148,0,0,32,0,55,46,117,50,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,34,120,146,143,0,0,64,0,49,46,117,48,50,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,133,39,177,164,0,0,16,1,50,46,117,48,50,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,213,11,100,23,0,0,16,1,51,46,117,48,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,208,9,175,246,0,0,16,1,52,107,46,117,48,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,218,36,223,253,0,0,16,1,53,46,117,48,52,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,46,86,3,237,0,0,16,1,54,46,117,48,52,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,93,91,157,161,0,0,16,1,56,98,46,117,50,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,5,117,238,153,0,0,16,1,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,94,178,34,25,0,0,32,0,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,106,120,144,95,0,0,32,0,115,101,105,52,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,11,31,21,218,0,0,32,0,115,101,105,52,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,172,87,31,172,0,0,32,0,115,101,105,52,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,222,123,109,148,0,0,32,0,55,46,117,50,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,34,120,146,143,0,0,64,0,49,46,117,48,50,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,133,39,177,164,0,0,16,1,50,46,117,48,50,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,213,11,100,23,0,0,16,1,51,95,95,40,114,97,105,100,101,110,98,41,46,117,48,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,245,91,115,157,0,0,16,1,52,95,95,40,114,97,105,100,101,110,98,41,46,117,48,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,153,75,24,141,0,0,16,1,53,95,95,40,114,97,105,100,101,110,98,41,46,117,48,52,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,97,109,202,122,0,0,16,1,54,95,95,40,114,97,105,100,101,110,98,41,46,117,48,52,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,194,92,211,227,0,0,16,1,114,97,105,54,46,117,50,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,59,72,58,114,0,0,16,1,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,94,178,34,25,0,0,32,0,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,106,120,144,95,0,0,32,0,115,101,105,52,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,11,31,21,218,0,0,32,0,115,101,105,52,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,172,87,31,172,0,0,32,0,115,101,105,52,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,222,123,109,148,0,0,32,0,55,46,117,50,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,34,120,146,143,0,0,64,0,101,112,57,49,48,112,99,45,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,132,8,0,0,0,0,0,0,0,0,0,16,101,112,57,49,48,112,99,45,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,132,8,0,0,0,0,0,0,0,0,0,16,49,46,117,48,50,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,133,39,177,164,0,0,16,1,50,46,117,48,50,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,213,11,100,23,0,0,16,1,51,46,117,48,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,208,9,175,246,0,0,16,1,52,46,117,48,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,22,212,223,107,0,0,16,1,53,46,117,48,52,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,46,86,3,237,0,0,16,1,54,46,117,48,52,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,93,91,157,161,0,0,16,1,56,46,117,50,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,199,85,224,203,0,0,16,1,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,94,178,34,25,0,0,32,0,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,106,120,144,95,0,0,32,0,115,101,105,52,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,11,31,21,218,0,0,32,0,115,101,105,52,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,172,87,31,172,0,0,32,0,115,101,105,52,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,222,123,109,148,0,0,32,0,55,46,117,50,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,34,120,146,143,0,0,64,0,107,104,95,48,48,45,50,46,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,159,23,62,85,1,0,16,1,107,104,95,48,50,45,50,46,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,192,158,117,108,1,0,16,1,107,104,95,48,49,45,50,46,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,112,238,223,18,1,0,16,1,107,104,95,48,51,45,50,46,52,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,24,234,111,7,1,0,16,1,107,109,48,54,46,49,56,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,225,196,139,62,2,0,16,1,107,109,48,53,46,57,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,149,239,10,209,3,0,32,0,107,109,48,52,46,56,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,168,35,147,50,3,0,32,0,109,98,100,45,48,49,46,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,75,79,222,215,4,0,32,0,109,98,100,45,48,48,46,56,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,169,11,178,173,4,0,32,0,109,98,100,45,48,50,46,49,48,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,33,167,90,178,8,0,32,0,109,98,100,45,48,51,46,49,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,44,143,121,207,5,0,32,0,109,98,100,45,48,52,46,49,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,11,77,118,217,5,0,32,0,109,98,100,45,48,53,46,49,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,106,198,104,23,6,0,32,0,109,98,100,45,48,54,46,49,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,122,132,80,119,6,0,32,0,109,98,100,45,48,55,46,49,56,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,193,170,31,36,7,0,32,0,109,98,100,45,48,56,46,49,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,86,30,59,241,7,0,32,0,109,98,100,45,49,48,46,49,55,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,106,247,89,241,9,0,64,0,109,98,100,45,48,57,46,49,54,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,135,47,79,244,10,0,64,0,107,106,45,48,48,46,49,53,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,11,213,212,173,11,0,0,8,48,56,48,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,94,49,64,68,1,0,16,1,48,56,48,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,2,97,184,215,2,0,32,0,48,56,48,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,74,118,29,234,3,0,32,0,48,56,48,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,164,212,49,211,3,0,32,0,48,56,48,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,254,27,133,180,3,0,32,0,48,56,48,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,96,84,111,202,3,0,32,0,48,56,48,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,114,65,244,245,4,0,16,1,48,56,48,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,96,143,225,11,5,0,64,0,48,56,48,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,255,227,189,74,5,0,64,0,48,56,48,45,118,51,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,226,68,40,240,5,0,64,0,49,45,105,99,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,54,67,166,16,1,0,16,1,50,45,105,99,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,49,180,33,139,1,0,16,1,105,99,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,163,83,20,80,1,0,16,1,105,99,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,15,132,182,153,1,0,16,1,51,45,105,99,49,52,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,227,114,211,114,2,0,16,1,105,99,49,50,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,201,251,146,122,3,0,64,0,105,99,49,50,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,207,149,73,238,4,0,64,0,105,99,49,50,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,195,88,111,7,4,0,64,0,105,99,57,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,94,124,56,77,5,0,32,0,105,99,57,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,100,241,226,107,5,0,32,0,105,99,55,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,209,111,59,175,6,0,32,0,105,99,55,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,243,222,187,68,6,0,32,0,105,99,55,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,105,225,33,215,6,0,32,0,107,117,112,45,117,48,54,46,105,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,172,3,78,49,0,0,16,1,107,117,112,45,117,48,55,46,105,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,4,58,66,160,0,0,16,1,107,117,99,45,117,51,56,46,105,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,114,65,178,61,0,0,32,0,107,117,99,45,117,51,57,46,105,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,155,97,38,155,0,0,32,0,107,117,99,45,117,52,48,46,105,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,207,162,73,126,0,0,32,0,107,117,99,45,117,52,49,46,105,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,155,241,235,47,0,0,32,0,107,117,115,45,117,49,56,46,105,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,207,223,177,226,0,0,64,0,21,0,0,0,255,255,0,0,0,0,0,0,22,0,0,0,255,255,128,0,0,0,0,0,0,0,0,0,254,0,2,0,208,87,7,0,21,0,0,0,1,1,0,0,96,135,7,0,21,0,0,0,1,1,1,0,152,182,7,0,0,0,0,0,254,0,2,0,200,135,2,0,21,0,0,0,1,2,2,0,96,135,7,0,21,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,96,228,6,0,21,0,0,0,1,4,0,0,96,135,7,0,21,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,254,0,8,0,72,202,5,0,21,0,0,0,1,56,8,0,160,246,1,0,21,0,0,0,1,56,16,0,120,103,7,0,21,0,0,0,1,56,24,0,80,246,3,0,21,0,0,0,1,56,0,0,248,38,7,0,21,0,0,0,1,56,32,0,112,212,3,0,21,0,0,0,1,56,40,0,48,90,7,0,21,0,0,0,1,56,48,0,72,185,3,0,21,0,0,0,1,56,56,0,248,160,5,0,0,0,0,0,254,0,4,0,112,208,6,0,21,0,0,0,1,192,128,0,192,255,2,0,21,0,0,0,1,192,0,0,208,75,4,0,21,0,0,0,1,192,64,0,8,49,4,0,21,0,0,0,1,192,192,0,72,246,3,0,0,0,0,0,254,0,16,0,32,4,2,0,22,0,0,0,1,15,0,0,200,201,5,0,22,0,0,0,1,15,1,0,152,160,5,0,22,0,0,0,1,15,2,0,144,127,5,0,22,0,0,0,1,15,3,0,168,98,5,0,22,0,0,0,1,15,4,0,88,219,3,0,22,0,0,0,1,15,5,0,224,189,3,0,22,0,0,0,1,15,6,0,120,166,6,0,22,0,0,0,1,15,7,0,224,67,5,0,22,0,0,0,1,15,8,0,88,198,1,0,22,0,0,0,1,15,9,0,120,154,6,0,22,0,0,0,1,15,10,0,216,36,5,0,22,0,0,0,1,15,11,0,144,138,3,0,22,0,0,0,1,15,12,0,232,143,6,0,22,0,0,0,1,15,13,0,8,7,5,0,22,0,0,0,1,15,14,0,192,135,6,0,22,0,0,0,1,15,15,0,40,182,1,0,0,0,0,0,254,0,2,0,192,125,6,0,22,0,0,0,1,16,16,0,56,111,3,0,22,0,0,0,1,16,0,0,104,134,3,0,0,0,0,0,254,0,2,0,144,113,6,0,22,0,0,0,1,32,32,0,56,111,3,0,22,0,0,0,1,32,0,0,104,134,3,0,0,0,0,0,254,0,2,0,128,112,3,0,22,0,0,0,1,128,0,0,224,247,3,0,22,0,0,0,1,128,128,0,168,22,4,0,0,0,0,0,118,49,48,48,46,117,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,149,69,187,26,1,0,16,1,116,48,57,48,48,46,117,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,17,86,97,112,2,0,32,0,97,48,57,48,48,46,117,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,81,18,145,20,3,0,32,0,98,48,57,48,48,46,117,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,182,56,6,111,4,0,32,0,109,48,57,48,48,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,46,175,167,158,5,0,64,0,112,117,122,122,108,105,50,95,105,103,115,48,50,55,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,7,0,16,17,46,0,0,0,255,255,5,0,0,0,0,0,0,0,0,0,254,0,6,0,144,165,4,0,46,0,0,0,1,15,0,0,80,65,1,0,46,0,0,0,1,15,1,0,232,41,1,0,46,0,0,0,1,15,2,0,176,20,3,0,46,0,0,0,1,15,3,0,56,50,1,0,46,0,0,0,1,15,4,0,192,20,3,0,46,0,0,0,1,15,5,0,224,32,1,0,112,117,115,104,109,97,110,46,48,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,188,98,7,51,1,0,16,1,112,117,115,104,109,97,110,46,48,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,150,103,99,98,1,0,16,1,112,117,115,104,109,97,110,46,48,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,193,102,254,173,2,0,16,1,112,117,115,104,109,97,110,54,56,55,48,53,114,51,112,46,105,99,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,87,102,145,215,3,0,16,1,112,117,115,104,109,97,110,46,48,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,101,88,110,98,4,0,32,0,112,117,115,104,109,97,110,46,48,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,112,250,170,135,5,0,32,0,112,117,115,104,109,97,110,46,48,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,12,32,209,127,5,0,32,0,112,117,115,104,109,97,110,46,48,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,176,74,9,10,5,0,32,0,112,117,115,104,109,97,110,46,48,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,157,242,209,115,5,0,32,0,112,117,115,104,109,97,110,46,48,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,166,61,239,72,6,0,32,0,112,117,115,104,109,97,110,46,48,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,136,62,106,75,6,0,32,0,112,117,115,104,109,97,110,46,48,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,189,32,0,183,6,0,32,0,112,117,115,104,109,97,110,46,48,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,103,86,85,204,6,0,32,0,112,117,115,104,109,97,110,46,48,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,45,19,0,165,7,0,32,0,110,56,50,115,49,50,57,97,110,46,105,99,56,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,54,174,128,236,0,0,32,0,48,56,57,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,162,71,88,94,1,0,16,1,48,56,57,45,112,50,46,115,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,76,119,139,2,1,0,16,1,48,56,57,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,200,194,159,199,2,0,32,0,48,56,57,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,50,115,233,244,3,0,32,0,48,56,57,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,218,20,109,131,3,0,32,0,48,56,57,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,196,17,54,145,3,0,32,0,48,56,57,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,227,240,206,68,3,0,32,0,48,56,57,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,215,161,186,137,3,0,32,0,48,56,57,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,86,77,89,178,3,0,32,0,48,56,57,45,99,55,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,202,24,86,106,3,0,32,0,48,56,57,45,99,56,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,45,87,35,162,3,0,32,0,48,56,57,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,199,247,61,255,4,0,16,1,48,56,57,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,203,110,114,111,5,0,64,0,48,56,57,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,81,181,45,157,5,0,64,0,110,97,109,99,111,112,97,99,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,179,99,226,254,1,0,16,1,110,97,109,99,111,112,97,99,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,131,252,209,57,1,0,16,1,110,97,109,99,111,112,97,99,46,54,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,3,59,8,2,1,0,16,1,110,112,97,99,109,111,100,46,54,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,245,213,152,125,1,0,16,1,112,97,99,109,97,110,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,100,73,148,12,2,0,32,0,112,97,99,109,97,110,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,249,237,143,149,2,0,32,0,56,50,115,49,50,51,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,189,80,198,47,3,0,32,0,56,50,115,49,50,54,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,228,168,179,62,3,0,32,0,56,50,115,49,50,54,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,134,204,169,4,0,64,0,56,50,115,49,50,54,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,112,109,49,95,112,114,103,49,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,171,136,110,243,1,0,16,1,112,109,49,95,112,114,103,50,46,54,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,179,217,139,97,1,0,16,1,112,109,49,95,112,114,103,51,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,83,120,23,125,1,0,16,1,112,109,49,95,112,114,103,52,46,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,76,145,232,211,1,0,16,1,112,109,49,95,112,114,103,53,46,54,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,37,246,244,107,1,0,16,1,112,109,49,95,112,114,103,54,46,54,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,131,206,72,169,1,0,16,1,112,109,49,95,112,114,103,55,46,54,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,38,155,40,182,1,0,16,1,112,109,49,95,112,114,103,56,46,54,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,19,140,168,23,1,0,16,1,112,109,49,95,99,104,103,49,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,183,160,102,32,2,0,32,0,112,109,49,95,99,104,103,50,46,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,157,184,145,53,2,0,32,0,112,109,49,95,99,104,103,51,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,58,50,57,158,2,0,32,0,112,109,49,95,99,104,103,52,46,53,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,150,144,29,27,2,0,32,0,112,109,49,45,49,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,189,80,198,47,3,0,32,0,112,109,49,45,52,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,228,168,179,62,3,0,32,0,112,109,49,45,51,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,134,204,169,4,0,64,0,112,109,49,45,50,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,117,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,194,15,108,245,1,0,16,1,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,220,255,65,169,1,0,16,1,117,122,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,107,225,246,244,2,0,16,1,117,52,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,209,33,181,240,3,0,32,0,117,52,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,142,145,7,17,3,0,32,0,117,52,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,51,125,86,63,3,0,32,0,117,52,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,126,73,163,24,3,0,32,0,117,53,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,179,70,14,22,4,0,32,0,117,53,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,28,182,81,115,4,0,32,0,117,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,239,197,216,163,4,0,32,0,117,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,196,101,202,16,4,0,32,0,117,122,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,76,39,150,61,5,0,64,0,105,99,50,50,95,97,52,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,215,231,106,145,1,0,16,1,105,99,50,51,95,97,53,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,97,140,227,143,1,0,16,1,105,99,50,52,95,97,54,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,138,33,96,38,1,0,16,1,105,99,50,53,95,97,55,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,173,16,42,61,1,0,16,1,120,120,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,104,179,226,251,2,0,16,1,120,120,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,61,91,121,225,2,0,16,1,105,99,49,51,95,103,49,48,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,169,174,51,116,3,0,32,0,105,99,49,52,95,103,57,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,158,120,193,135,3,0,32,0,54,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,33,193,216,178,4,0,32,0,53,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,182,194,151,16,4,0,32,0,112,111,111,121,97,110,46,112,114,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,14,109,106,160,5,0,32,0,112,111,111,121,97,110,46,112,114,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,96,205,212,140,5,0,32,0,112,111,111,121,97,110,46,112,114,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,11,140,116,130,5,0,32,0,112,112,111,107,111,106,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,4,192,163,255,1,0,16,1,112,112,111,107,111,106,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,102,104,73,74,1,0,16,1,112,112,111,107,111,106,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,163,108,218,23,1,0,16,1,112,112,111,107,111,106,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,101,165,57,157,1,0,16,1,112,112,111,107,111,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,125,61,202,84,1,0,16,1,112,112,111,107,111,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,224,199,85,48,1,0,16,1,112,112,111,107,111,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,202,71,190,60,1,0,16,1,112,112,111,107,111,106,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,198,63,182,4,1,0,16,1,112,112,111,107,111,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,6,26,62,183,2,0,32,0,112,112,111,107,111,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,93,155,6,98,2,0,32,0,56,50,115,49,50,51,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,189,80,198,47,3,0,32,0,56,50,115,49,50,54,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,228,168,179,62,3,0,32,0,56,50,115,49,50,54,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,134,204,169,4,0,64,0,56,50,115,49,50,54,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,16,0,0,0,255,255,209,0,0,0,0,0,17,0,0,0,255,255,177,0,0,0,0,0,18,0,0,0,255,255,224,0,0,0,0,0,19,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,4,0,64,37,5,0,16,0,0,0,1,3,0,0,176,116,6,0,16,0,0,0,1,3,1,0,152,53,6,0,16,0,0,0,1,3,2,0,8,49,6,0,16,0,0,0,1,3,3,0,120,7,5,0,0,0,0,0,254,0,4,0,128,129,4,0,16,0,0,0,1,48,0,0,208,75,4,0,16,0,0,0,1,48,16,0,8,49,4,0,16,0,0,0,1,48,32,0,152,21,4,0,16,0,0,0,1,48,48,0,72,246,3,0,0,0,0,0,254,0,2,0,200,30,2,0,16,0,0,0,1,64,64,0,120,97,1,0,16,0,0,0,1,64,0,0,96,19,1,0,0,0,0,0,254,0,16,0,32,4,2,0,17,0,0,0,1,15,4,0,136,8,4,0,17,0,0,0,1,15,14,0,192,4,4,0,17,0,0,0,1,15,15,0,184,1,4,0,17,0,0,0,1,15,2,0,200,252,3,0,17,0,0,0,1,15,13,0,112,248,3,0,17,0,0,0,1,15,7,0,208,244,3,0,17,0,0,0,1,15,11,0,184,241,3,0,17,0,0,0,1,15,12,0,112,239,3,0,17,0,0,0,1,15,1,0,240,235,3,0,17,0,0,0,1,15,6,0,208,233,3,0,17,0,0,0,1,15,5,0,208,230,3,0,17,0,0,0,1,15,10,0,32,227,3,0,17,0,0,0,1,15,8,0,48,224,3,0,17,0,0,0,1,15,9,0,144,219,3,0,17,0,0,0,1,15,3,0,128,214,3,0,17,0,0,0,1,15,0,0,16,227,4,0,0,0,0,0,254,0,2,0,168,234,7,0,17,0,0,0,1,64,64,0,96,135,7,0,17,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,112,107,119,97,114,46,48,49,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,123,44,45,206,1,0,16,1,112,107,119,97,114,46,48,50,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,97,246,193,171,1,0,16,1,112,107,119,97,114,46,48,51,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,234,235,250,86,1,0,16,1,112,107,119,97,114,46,48,49,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,146,59,141,66,2,0,32,0,112,107,119,97,114,46,48,50,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,188,167,29,206,2,0,32,0,112,107,119,97,114,46,48,51,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,68,32,99,2,0,32,0,112,107,119,97,114,46,48,52,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,168,252,29,6,2,0,32,0,112,107,119,97,114,46,99,111,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,226,197,15,175,3,0,32,0,114,95,52,52,57,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,218,238,74,34,1,0,16,1,108,95,53,99,49,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,4,2,116,70,1,0,16,1,112,52,95,52,100,52,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,22,162,253,137,2,0,32,0,112,50,95,53,100,55,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,180,105,224,64,2,0,32,0,112,49,95,55,98,51,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,133,215,38,2,0,32,0,112,56,95,57,102,52,102,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,234,150,22,243,2,0,32,0,115,49,95,54,101,56,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,111,39,138,199,3,0,32,0,115,50,95,54,100,102,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,150,173,11,159,3,0,32,0,115,52,95,102,100,99,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,221,22,137,3,0,32,0,115,56,95,52,98,55,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,44,189,65,28,3,0,32,0,115,56,57,95,52,57,100,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,57,167,99,4,0,64,0,112,105,114,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,234,230,163,105,1,0,16,1,112,105,114,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,63,117,94,36,1,0,16,1,112,105,114,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,84,105,203,98,1,0,16,1,112,105,114,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,188,0,7,203,1,0,16,1,112,105,114,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,229,191,63,132,1,0,16,1,112,105,114,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,94,77,8,115,1,0,16,1,112,105,114,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,4,103,223,76,1,0,16,1,112,105,114,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,179,237,111,184,1,0,16,1,112,105,114,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,40,235,25,15,2,0,32,0,112,105,114,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,190,218,139,95,2,0,32,0,112,105,114,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,251,153,147,209,2,0,32,0,112,105,114,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,61,64,180,207,2,0,32,0,56,50,115,49,50,51,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,189,80,198,47,3,0,32,0,112,105,114,97,110,104,97,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,123,68,201,8,3,0,32,0,56,50,115,49,50,54,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,134,204,169,4,0,64,0,56,50,115,49,50,54,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,112,48,49,48,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,141,158,236,205,1,0,16,1,116,48,49,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,216,182,88,143,2,0,32,0,97,48,49,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,230,175,30,220,3,0,32,0,98,48,49,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,111,182,68,61,4,0,32,0,109,48,49,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,97,247,226,5,5,0,64,0,112,48,49,48,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,69,236,246,211,1,0,16,1,116,48,49,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,154,165,150,5,2,0,32,0,97,48,49,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,161,143,14,93,3,0,32,0,98,48,49,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,31,25,221,21,4,0,32,0,109,48,49,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,126,135,137,141,5,0,64,0,112,48,49,48,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,107,165,175,108,1,0,16,1,116,48,49,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,221,121,185,66,2,0,32,0,97,48,49,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,238,124,93,16,3,0,32,0,98,48,49,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,115,115,18,180,4,0,32,0,109,48,49,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,126,135,137,141,5,0,64,0,101,112,53,49,50,48,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,96,251,26,240,1,0,16,1,101,112,53,49,50,49,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,83,131,179,46,1,0,16,1,101,112,53,49,50,50,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,215,0,52,195,1,0,16,1,101,112,53,49,50,51,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,162,198,133,106,1,0,16,1,101,112,53,49,50,52,46,50,49,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,255,84,243,149,1,0,16,1,101,112,53,49,50,53,46,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,15,49,66,26,1,0,16,1,101,112,53,49,50,54,46,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,40,7,146,229,1,0,16,1,101,112,53,49,50,55,46,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,214,209,211,167,1,0,16,1,101,112,49,54,52,48,46,57,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,205,198,238,215,2,0,32,0,101,112,49,54,57,53,46,49,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,233,38,253,91,2,0,32,0,112,114,49,54,51,51,46,55,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,236,68,88,58,3,0,32,0,112,114,49,54,51,52,46,56,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,155,19,107,118,3,0,32,0,112,114,49,54,51,53,46,53,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,39,234,157,194,4,0,64,0,112,114,49,54,51,54,46,55,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,101,112,114,53,49,50,56,46,117,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,14,178,254,61,1,0,16,1,101,112,114,53,49,50,57,46,117,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,189,65,179,29,1,0,16,1,101,112,114,53,49,51,48,46,117,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,213,66,40,124,1,0,16,1,101,112,114,53,49,51,49,46,117,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,47,31,60,110,1,0,16,1,101,112,53,49,50,52,46,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,255,84,243,149,1,0,16,1,101,112,114,53,49,51,51,46,117,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,184,4,219,15,1,0,16,1,101,112,53,49,50,54,46,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,40,7,146,229,1,0,16,1,101,112,114,53,49,51,53,46,117,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,237,71,222,19,1,0,16,1,101,112,49,54,52,48,46,57,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,205,198,238,215,2,0,32,0,101,112,49,54,57,53,46,49,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,233,38,253,91,2,0,32,0,112,114,49,54,51,51,46,55,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,236,68,88,58,3,0,32,0,112,114,49,54,51,52,46,56,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,155,19,107,118,3,0,32,0,112,114,49,54,51,53,46,53,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,39,234,157,194,4,0,64,0,112,114,49,54,51,54,46,55,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,117,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,172,255,189,123,0,0,16,1,117,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,95,218,12,213,0,0,16,1,117,51,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,158,179,71,66,0,0,32,0,117,51,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,175,127,240,249,0,0,32,0,117,52,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,150,10,158,220,0,0,32,0,117,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,226,101,78,222,0,0,64,0,19,0,0,0,255,255,0,0,0,0,0,0,20,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,208,87,7,0,19,0,0,0,1,1,0,0,96,135,7,0,19,0,0,0,1,1,1,0,152,182,7,0,0,0,0,0,254,0,2,0,40,214,8,0,19,0,0,0,1,2,0,0,248,38,7,0,19,0,0,0,1,2,2,0,32,158,6,0,0,0,0,0,254,0,2,0,200,135,2,0,19,0,0,0,1,8,8,0,96,135,7,0,19,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,19,0,0,0,1,48,16,0,200,241,5,0,19,0,0,0,1,48,32,0,224,123,6,0,19,0,0,0,1,48,0,0,232,38,7,0,19,0,0,0,1,48,48,0,120,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,19,0,0,0,1,192,64,0,200,241,5,0,19,0,0,0,1,192,128,0,224,123,6,0,19,0,0,0,1,192,0,0,232,38,7,0,19,0,0,0,1,192,192,0,120,164,6,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,3,1,0,80,246,3,0,20,0,0,0,1,3,0,0,248,38,7,0,20,0,0,0,1,3,2,0,112,212,3,0,20,0,0,0,1,3,3,0,72,185,3,0,0,0,0,0,254,0,4,0,32,15,7,0,20,0,0,0,1,12,12,0,208,75,4,0,20,0,0,0,1,12,0,0,8,49,4,0,20,0,0,0,1,12,8,0,152,21,4,0,20,0,0,0,1,12,4,0,72,246,3,0,0,0,0,0,254,0,4,0,56,191,4,0,20,0,0,0,1,48,32,0,248,252,6,0,20,0,0,0,1,48,0,0,0,249,6,0,20,0,0,0,1,48,48,0,152,245,6,0,20,0,0,0,1,48,16,0,120,7,5,0,0,0,0,0,254,0,4,0,64,239,6,0,20,0,0,0,1,192,0,0,208,75,4,0,20,0,0,0,1,192,128,0,8,49,4,0,20,0,0,0,1,192,64,0,152,21,4,0,20,0,0,0,1,192,192,0,72,246,3,0,0,0,0,0,114,111,109,51,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,109,142,226,98,1,0,16,1,114,111,109,52,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,65,171,29,181,1,0,16,1,114,111,109,49,46,49,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,248,39,205,37,2,0,16,1,114,111,109,49,48,46,49,54,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,132,142,126,214,3,0,32,0,114,111,109,49,50,46,49,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,51,183,232,107,3,0,32,0,114,111,109,49,49,46,49,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,164,1,37,103,3,0,32,0,114,111,109,49,51,46,49,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,231,92,114,252,3,0,32,0,114,111,109,56,46,56,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,241,26,101,4,0,32,0,114,111,109,57,46,56,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,214,180,53,37,4,0,32,0,114,111,109,55,46,49,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,108,83,247,4,0,32,0,114,111,109,54,46,57,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,138,7,60,4,0,32,0,114,111,109,53,46,57,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,248,226,234,32,4,0,32,0,114,111,109,50,46,49,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,209,122,249,79,4,0,64,0,115,112,101,99,105,97,108,32,99,114,105,109,105,110,97,108,32,105,110,118,101,115,116,105,103,97,116,105,111,110,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,204,191,160,9,0,0,16,1,112,45,52,55,32,45,32,116,104,101,32,102,114,101,101,100,111,109,32,102,105,103,104,116,101,114,32,40,106,97,112,97,110,41,46,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,144,219,50,118,0,0,16,1,112,98,45,49,99,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,73,79,225,93,2,0,0,0,112,98,45,105,99,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,209,7,190,42,2,0,0,0,112,98,45,105,99,50,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,196,164,239,38,9,0,0,0,112,98,45,105,99,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,164,14,249,85,11,0,0,0,112,98,45,105,99,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,201,170,83,50,11,0,0,0,112,98,45,105,99,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,196,203,64,8,24,0,0,0,112,97,100,100,108,101,50,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,60,51,134,162,1,0,16,1,112,97,100,100,108,101,50,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,181,172,194,4,1,0,16,1,97,55,53,45,48,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,186,116,139,3,3,0,32,0,97,55,53,45,48,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,153,225,250,113,3,0,32,0,97,55,53,45,48,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,226,116,99,199,3,0,32,0,97,55,53,45,48,55,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,137,178,248,10,4,0,32,0,97,55,53,45,48,56,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,251,2,176,171,4,0,32,0,97,55,53,45,48,57,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,119,194,198,167,4,0,32,0,11,0,0,0,255,255,95,0,0,0,0,0,0,0,0,0,254,0,2,0,176,110,8,0,11,0,0,0,1,1,1,0,96,135,7,0,11,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,11,0,0,0,1,2,2,0,96,135,7,0,11,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,80,103,8,0,11,0,0,0,1,4,4,0,248,38,7,0,11,0,0,0,1,4,0,0,40,87,8,0,0,0,0,0,254,0,2,0,72,202,5,0,11,0,0,0,1,8,8,0,80,246,3,0,11,0,0,0,1,8,0,0,112,212,3,0,0,0,0,0,254,0,2,0,64,37,5,0,11,0,0,0,1,16,16,0,216,138,8,0,11,0,0,0,1,16,0,0,112,133,8,0,0,0,0,0,254,0,2,0,128,129,4,0,11,0,0,0,1,32,0,0,208,75,4,0,11,0,0,0,1,32,32,0,8,49,4,0,0,0,0,0,254,0,2,0,32,4,2,0,11,0,0,0,1,64,64,0,128,230,7,0,11,0,0,0,1,64,0,0,184,164,6,0,0,0,0,0,254,0,2,0,200,30,2,0,11,0,0,0,1,128,0,0,120,97,1,0,11,0,0,0,1,128,128,0,96,19,1,0,0,0,0,0,112,97,99,117,109,97,110,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,216,30,140,236,1,0,16,1,112,97,99,117,109,97,110,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,86,175,237,64,1,0,16,1,112,97,99,117,109,97,110,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,43,112,79,219,1,0,16,1,112,97,99,117,109,97,110,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,125,37,247,40,1,0,16,1,112,97,99,117,109,97,110,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,65,203,42,33,1,0,16,1,112,97,99,117,109,97,110,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,185,209,61,231,1,0,16,1,112,97,99,117,109,97,110,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,178,44,138,144,1,0,16,1,112,97,99,117,109,97,110,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,108,162,75,207,1,0,16,1,112,109,49,99,104,103,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,183,160,102,32,2,0,32,0,112,109,49,99,104,103,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,157,184,145,53,2,0,32,0,112,109,49,99,104,103,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,58,50,57,158,2,0,32,0,112,109,49,99,104,103,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,150,144,29,27,2,0,32,0,56,50,115,49,50,51,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,189,80,198,47,3,0,32,0,56,50,115,49,50,54,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,228,168,179,62,3,0,32,0,56,50,115,49,50,54,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,134,204,169,4,0,64,0,56,50,115,49,50,54,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,112,97,99,112,108,117,115,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,104,239,17,214,1,0,16,1,112,97,99,112,108,117,115,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,86,117,32,199,1,0,16,1,112,97,99,112,108,117,115,46,54,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,48,148,55,174,1,0,16,1,112,97,99,112,108,117,115,46,54,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,123,255,109,90,1,0,16,1,112,97,99,112,108,117,115,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,218,53,44,2,2,0,32,0,112,97,99,112,108,117,115,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,221,92,230,77,2,0,32,0,112,97,99,112,108,117,115,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,58,213,61,6,3,0,32,0,112,97,99,112,108,117,115,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,161,113,226,3,0,32,0,56,50,115,49,50,54,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,134,204,169,4,0,64,0,56,50,115,49,50,54,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,112,97,99,109,97,110,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,16,171,230,193,1,0,16,1,112,97,99,102,97,115,116,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,238,195,13,114,1,0,16,1,112,97,99,109,97,110,46,54,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,235,27,221,188,1,0,16,1,112,97,99,109,97,110,46,54,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,227,148,125,129,1,0,16,1,112,97,99,109,97,110,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,100,73,148,12,2,0,32,0,112,97,99,109,97,110,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,249,237,143,149,2,0,32,0,56,50,115,49,50,51,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,189,80,198,47,3,0,32,0,56,50,115,49,50,54,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,228,168,179,62,3,0,32,0,56,50,115,49,50,54,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,134,204,169,4,0,64,0,56,50,115,49,50,54,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,112,108,53,95,48,49,98,46,56,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,49,118,234,176,1,0,16,1,112,108,53,95,48,50,46,56,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,78,232,3,217,1,0,16,1,112,108,49,95,51,46,56,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,57,167,159,170,1,0,16,1,112,108,49,95,52,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,144,90,137,43,1,0,16,1,112,108,49,95,53,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,98,246,122,1,0,16,1,112,108,51,95,54,46,56,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,25,51,254,47,1,0,16,1,112,108,49,95,55,46,51,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,174,236,91,140,2,0,16,1,99,117,115,54,48,45,54,48,97,49,46,109,99,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,42,168,110,7,2,0,16,1,112,108,50,95,49,50,46,54,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,38,135,60,166,3,0,32,0,112,108,52,95,49,51,46,54,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,253,130,229,58,4,0,32,0,112,108,49,45,57,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,43,150,213,245,5,0,32,0,112,108,49,45,56,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,74,250,235,162,5,0,32,0,112,108,49,45,49,48,46,55,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,4,25,207,199,5,0,32,0,112,108,49,45,49,49,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,26,54,33,102,5,0,32,0,112,108,49,45,50,46,49,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,222,133,40,71,6,0,32,0,112,108,49,45,49,46,49,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,175,189,142,167,6,0,32,0,112,108,49,45,53,46,53,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,18,231,126,75,6,0,32,0,112,108,49,45,52,46,52,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,24,228,123,58,6,0,32,0,112,108,49,45,51,46,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,168,141,85,128,6,0,32,0,50,49,50,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,169,99,192,22,1,0,16,1,50,49,50,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,220,61,29,72,2,0,32,0,50,49,50,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,135,48,244,80,3,0,32,0,50,49,50,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,7,152,179,165,3,0,32,0,50,49,50,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,2,234,82,146,3,0,32,0,50,49,50,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,153,166,65,95,3,0,32,0,50,49,50,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,239,139,133,252,3,0,32,0,50,49,50,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,94,193,137,5,3,0,32,0,50,49,50,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,145,97,171,252,4,0,16,1,50,49,50,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,249,78,61,1,5,0,64,0,116,112,48,49,56,95,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,45,192,42,12,0,0,16,1,116,112,48,49,56,95,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,170,72,126,202,0,0,16,1,114,111,109,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,182,199,78,198,0,0,32,0,114,111,109,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,172,197,182,100,0,0,32,0,114,111,109,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,22,45,183,107,0,0,32,0,114,111,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,45,120,52,9,0,0,32,0,114,111,109,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,7,60,144,236,0,0,32,0,114,111,109,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,168,241,203,80,0,0,32,0,114,111,109,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,53,226,216,115,0,0,16,1,116,112,48,49,56,95,49,48,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,237,204,136,188,0,0,64,0,116,112,48,49,56,95,49,49,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,146,116,225,161,0,0,64,0,20,0,0,0,255,255,0,0,0,0,0,0,21,0,0,0,255,255,0,0,0,0,0,0,22,0,0,0,255,255,2,0,0,0,0,0,0,0,0,0,254,0,2,0,0,0,0,0,20,0,0,0,1,2,0,0,200,211,8,0,20,0,0,0,1,2,2,0,216,147,8,0,0,0,0,0,254,0,2,0,0,0,0,0,20,0,0,0,1,4,0,0,168,84,8,0,20,0,0,0,1,4,4,0,40,31,8,0,0,0,0,0,254,0,2,0,240,233,7,0,20,0,0,0,1,8,0,0,152,182,7,0,20,0,0,0,1,8,8,0,96,135,7,0,0,0,0,0,254,0,4,0,200,87,7,0,20,0,0,0,1,48,0,0,232,38,7,0,20,0,0,0,1,48,16,0,64,251,6,0,20,0,0,0,1,48,32,0,24,211,6,0,20,0,0,0,1,48,48,0,120,33,6,0,0,0,0,0,254,0,4,0,160,123,6,0,20,0,0,0,1,192,0,0,232,38,7,0,20,0,0,0,1,192,64,0,72,32,6,0,20,0,0,0,1,192,128,0,168,241,5,0,20,0,0,0,1,192,192,0,184,201,5,0,0,0,0,0,254,0,4,0,136,160,5,0,21,0,0,0,1,3,0,0,16,150,7,0,21,0,0,0,1,3,1,0,120,198,7,0,21,0,0,0,1,3,2,0,160,103,7,0,21,0,0,0,1,3,3,0,16,53,7,0,0,0,0,0,254,0,4,0,248,6,5,0,21,0,0,0,1,12,0,0,216,129,4,0,21,0,0,0,1,12,4,0,208,102,4,0,21,0,0,0,1,12,8,0,104,76,4,0,21,0,0,0,1,12,12,0,248,75,4,0,0,0,0,0,254,0,4,0,72,22,4,0,21,0,0,0,1,48,0,0,8,49,4,0,21,0,0,0,1,48,16,0,72,246,3,0,21,0,0,0,1,48,32,0,208,75,4,0,21,0,0,0,1,48,48,0,192,255,2,0,0,0,0,0,254,0,2,0,48,185,3,0,21,0,0,0,1,64,0,0,96,135,7,0,21,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,9,0,48,45,3,0,22,0,0,0,1,15,0,0,176,20,3,0,22,0,0,0,1,15,1,0,24,4,2,0,22,0,0,0,1,15,2,0,8,234,2,0,22,0,0,0,1,15,3,0,192,20,3,0,22,0,0,0,1,15,4,0,56,50,1,0,22,0,0,0,1,15,5,0,80,65,1,0,22,0,0,0,1,15,6,0,32,22,4,0,22,0,0,0,1,15,7,0,200,246,3,0,22,0,0,0,1,15,8,0,32,109,2,0,100,117,49,48,45,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,141,137,78,17,1,0,0,0,101,100,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,169,187,212,226,1,0,0,0,100,117,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,64,196,69,255,2,0,0,0,101,100,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,197,49,32,67,3,0,0,0,101,100,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,100,194,138,48,4,0,0,0,101,100,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,27,121,106,65,5,0,0,0,101,100,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,49,164,219,252,5,0,0,0,101,100,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,188,190,80,125,5,0,0,0,101,100,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,165,15,223,143,5,0,0,0,101,100,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,158,142,165,211,6,0,0,0,101,100,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,15,251,196,79,6,0,0,0,101,100,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,45,31,32,172,6,0,0,0,101,100,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,81,86,220,125,6,0,0,0,105,100,56,55,53,49,104,46,109,99,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,7,0,0,16,100,117,45,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,126,248,161,190,8,0,0,0,100,117,49,48,45,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,122,159,188,78,1,0,0,0,101,100,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,169,187,212,226,1,0,0,0,100,117,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,64,196,69,255,2,0,0,0,101,100,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,197,49,32,67,3,0,0,0,101,100,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,100,194,138,48,4,0,0,0,101,100,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,27,121,106,65,5,0,0,0,101,100,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,49,164,219,252,5,0,0,0,101,100,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,188,190,80,125,5,0,0,0,101,100,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,165,15,223,143,5,0,0,0,101,100,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,158,142,165,211,6,0,0,0,101,100,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,15,251,196,79,6,0,0,0,101,100,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,45,31,32,172,6,0,0,0,101,100,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,81,86,220,125,6,0,0,0,105,100,56,55,53,49,104,46,109,99,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,7,0,0,16,100,117,45,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,126,248,161,190,8,0,0,0,118,49,48,48,45,117,50,46,48,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,6,42,124,81,1,0,16,1,118,49,48,48,45,117,51,46,48,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,65,183,226,208,1,0,16,1,118,49,48,48,45,117,52,46,48,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,189,189,166,50,1,0,16,1,118,49,48,48,45,117,53,46,48,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,251,202,161,180,1,0,16,1,118,49,48,48,45,117,49,46,48,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,117,78,234,55,1,0,16,1,116,48,53,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,108,114,129,216,2,0,32,0,116,48,53,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,100,104,16,210,2,0,32,0,97,48,53,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,151,145,165,128,3,0,32,0,97,48,53,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,177,49,201,152,3,0,32,0,97,48,53,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,29,223,252,195,3,0,32,0,97,48,53,48,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,236,255,109,6,3,0,32,0,97,48,53,48,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,131,117,51,69,3,0,32,0,97,48,53,48,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,165,243,140,91,3,0,32,0,97,48,53,48,54,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,12,198,122,8,3,0,32,0,98,48,53,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,116,127,224,205,4,0,32,0,98,48,53,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,233,194,70,21,4,0,32,0,98,48,53,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,195,49,123,233,4,0,32,0,98,48,53,48,51,46,117,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,228,152,29,228,4,0,32,0,109,48,53,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,221,140,146,55,5,0,64,0,107,100,45,117,54,46,53,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,218,61,97,231,0,0,16,1,110,105,110,45,99,45,104,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,250,146,86,3,1,0,16,1,110,105,110,45,99,45,108,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,152,88,64,154,1,0,16,1,110,105,110,45,99,45,104,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,134,5,193,203,1,0,16,1,110,105,110,45,99,45,108,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,77,154,92,183,1,0,16,1,110,105,110,45,99,45,104,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,250,24,216,138,1,0,16,1,110,105,110,45,99,45,108,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,140,167,44,197,1,0,16,1,110,105,110,45,99,45,104,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,239,4,17,80,1,0,16,1,110,105,110,45,99,45,108,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,184,8,116,253,1,0,16,1,110,105,110,45,114,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,11,211,97,95,2,0,32,0,110,105,110,45,114,49,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,7,209,170,12,2,0,32,0,110,105,110,45,114,50,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,211,23,54,239,2,0,32,0,110,105,110,45,114,51,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,36,42,93,23,2,0,32,0,110,105,110,45,98,45,97,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,88,246,248,99,3,0,32,0,110,105,110,45,98,45,97,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,6,131,235,117,3,0,32,0,110,105,110,45,98,45,97,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,114,33,83,223,3,0,32,0,110,105,110,45,98,45,97,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,76,214,237,77,3,0,32,0,110,105,110,45,98,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,166,8,14,27,4,0,32,0,110,105,110,45,98,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,240,39,135,114,4,0,32,0,110,105,110,45,98,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,117,253,126,248,4,0,32,0,110,105,110,45,98,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,180,108,133,152,4,0,32,0,110,105,110,45,118,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,175,140,46,163,5,0,64,0,110,115,112,105,114,105,116,95,105,56,55,53,49,46,109,99,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,24,110,97,117,109,111,117,115,101,46,100,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,250,236,71,228,1,0,16,1,110,97,117,109,111,117,115,101,46,100,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,217,19,111,46,1,0,16,1,110,97,117,109,111,117,115,101,46,101,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,151,15,168,68,1,0,16,1,110,97,117,109,111,117,115,101,46,101,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,189,70,122,156,1,0,16,1,115,110,97,116,99,104,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,137,163,90,64,1,0,16,1,115,110,97,116,99,104,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,244,125,142,245,1,0,16,1,115,110,97,116,99,104,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,236,24,251,6,1,0,16,1,115,110,97,116,99,104,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,43,184,135,209,1,0,16,1,110,97,117,109,111,117,115,101,46,100,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,63,204,167,46,2,0,32,0,110,97,117,109,111,117,115,101,46,104,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,234,252,17,5,2,0,32,0,110,97,117,109,111,117,115,101,46,101,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,205,39,166,245,2,0,32,0,115,110,97,116,99,104,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,165,48,2,51,2,0,32,0,56,50,115,49,50,51,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,189,80,198,47,3,0,32,0,110,97,117,109,111,117,115,101,46,97,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,103,33,119,216,3,0,32,0,56,50,115,49,50,54,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,134,204,169,4,0,64,0,56,50,115,49,50,54,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,98,112,57,52,55,97,95,110,46,117,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,20,197,140,116,0,0,16,1,98,112,57,52,55,97,46,117,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,207,222,85,140,0,0,16,1,98,112,57,52,55,97,46,117,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,59,63,15,207,0,0,16,1,98,112,57,52,55,97,46,117,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,112,97,163,164,0,0,16,1,98,112,57,52,55,97,46,117,52,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,49,149,116,9,0,0,32,0,98,112,57,52,55,97,46,117,53,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,178,168,206,25,0,0,32,0,98,112,57,52,55,97,46,117,53,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,103,237,155,193,0,0,32,0,98,112,57,52,55,97,46,117,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,117,72,198,112,0,0,32,0,98,112,57,52,55,97,46,117,52,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,61,106,255,4,0,0,32,0,98,112,57,52,55,97,46,117,52,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,39,40,228,13,0,0,32,0,98,112,57,52,55,97,46,117,52,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,110,144,156,15,0,0,32,0,98,112,57,52,55,97,46,117,52,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,42,255,232,44,0,0,64,0,98,112,57,52,55,97,46,117,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,143,124,7,195,0,0,64,0,184,185,186,187,188,189,190,191,192,193,194,195,196,197,198,199,200,201,202,203,204,205,206,207,208,209,210,211,212,213,214,215,216,217,218,219,220,221,222,223,224,225,226,227,228,229,230,231,232,0,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57,58,59,60,61,62,63,64,65,66,67,68,69,70,71,72,73,184,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,54,101,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,152,106,73,105,1,0,16,1,54,107,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,28,192,143,21,1,0,16,1,54,102,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,83,120,23,125,1,0,16,1,54,109,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,207,12,129,112,1,0,16,1,54,104,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,232,157,113,129,1,0,16,1,54,110,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,88,12,37,63,1,0,16,1,54,106,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,54,87,103,230,1,0,16,1,54,112,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,101,231,129,31,1,0,16,1,53,101,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,183,160,102,32,2,0,32,0,53,104,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,211,112,124,119,2,0,32,0,53,102,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,76,24,140,202,2,0,32,0,53,106,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,129,90,199,125,2,0,32,0,56,50,115,49,50,51,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,189,80,198,47,3,0,32,0,56,50,115,49,50,54,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,228,168,179,62,3,0,32,0,56,50,115,49,50,54,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,134,204,169,4,0,64,0,56,50,115,49,50,54,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,112,111,110,103,95,112,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,157,226,53,159,1,0,16,1,112,111,110,103,95,115,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,79,38,25,205,2,0,32,0,112,111,110,103,95,99,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,26,125,165,245,3,0,32,0,112,111,110,103,95,99,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,78,230,253,175,3,0,32,0,112,111,110,103,95,109,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,203,81,200,120,4,0,16,1,112,111,110,103,95,118,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,60,34,49,108,5,0,64,0,50,48,55,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,30,165,78,51,1,0,16,1,50,48,55,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,206,175,235,106,2,0,32,0,50,48,55,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,157,27,84,199,3,0,32,0,50,48,55,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,210,102,113,245,3,0,32,0,50,48,55,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,149,74,183,181,4,0,16,1,50,48,55,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,82,192,67,65,5,0,64,0,49,0,0,0,240,0,0,0,0,0,0,0,0,0,0,0,255,255,0,0,0,0,0,0,1,0,0,0,255,127,0,0,0,0,0,0,2,0,0,0,255,255,128,0,0,0,0,0,3,0,0,0,255,255,1,0,0,0,0,0,0,0,0,0,254,0,2,0,208,161,1,0,0,0,0,0,1,4,0,0,96,135,7,0,0,0,0,0,1,4,4,0,152,182,7,0,100,101,109,111,45,112,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,164,226,252,251,1,0,16,1,100,101,109,111,45,115,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,79,38,25,205,2,0,32,0,100,101,109,111,45,99,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,234,40,11,135,3,0,32,0,100,101,109,111,45,99,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,40,129,207,30,3,0,32,0,50,48,50,45,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,234,145,2,156,4,0,16,1,50,48,50,45,118,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,251,184,190,222,5,0,64,0,2,0,0,0,255,255,128,0,0,0,0,0,0,0,0,0,253,0,26,0,184,144,1,0,2,0,0,0,1,31,0,0,176,143,1,0,2,0,0,0,1,31,1,0,208,142,1,0,2,0,0,0,1,31,2,0,104,141,1,0,2,0,0,0,1,31,3,0,96,140,1,0,2,0,0,0,1,31,4,0,192,138,1,0,2,0,0,0,1,31,5,0,184,137,1,0,2,0,0,0,1,31,6,0,152,136,1,0,2,0,0,0,1,31,7,0,64,135,1,0,2,0,0,0,1,31,8,0,40,134,1,0,2,0,0,0,1,31,9,0,144,132,1,0,2,0,0,0,1,31,10,0,160,130,1,0,2,0,0,0,1,31,11,0,40,129,1,0,2,0,0,0,1,31,12,0,32,127,1,0,2,0,0,0,1,31,13,0,208,125,1,0,2,0,0,0,1,31,14,0,24,125,1,0,2,0,0,0,1,31,15,0,200,123,1,0,2,0,0,0,1,31,16,0,120,122,1,0,2,0,0,0,1,31,17,0,216,121,1,0,2,0,0,0,1,31,18,0,200,120,1,0,2,0,0,0,1,31,19,0,32,118,1,0,2,0,0,0,1,31,20,0,208,116,1,0,2,0,0,0,1,31,21,0,56,115,1,0,2,0,0,0,1,31,22,0,232,113,1,0,2,0,0,0,1,31,23,0,200,111,1,0,2,0,0,0,1,31,24,0,160,110,1,0,2,0,0,0,1,31,25,0,232,109,1,0,0,0,0,0,253,0,2,0,40,109,1,0,2,0,0,0,1,128,128,0,64,108,1,0,2,0,0,0,1,128,0,0,120,107,1,0,0,0,0,0,253,0,2,0,176,105,1,0,2,0,0,0,1,64,64,0,80,104,1,0,2,0,0,0,1,64,0,0,248,38,7,0,24,38,7,0,1,0,0,0,248,33,216,0,184,160,2,0,120,36,5,0,1,0,0,0,249,33,216,0,96,78,4,0,56,210,6,0,1,0,0,0,0,33,216,0,192,135,2,0,24,163,6,0,1,0,0,0,1,33,216,0,240,108,2,0,152,122,6,0,1,0,0,0,2,33,216,0,96,82,2,0,192,72,6,0,1,0,0,0,3,33,216,0,32,56,2,0,136,30,2,0,1,0,0,0,4,33,216,0,152,30,2,0,224,19,2,0,1,0,0,0,5,33,216,0,232,10,2,0,216,10,2,0,1,0,0,0,6,33,216,0,152,138,8,0,248,3,2,0,1,0,0,0,7,33,216,0,48,119,7,0,144,236,1,0,1,0,0,0,250,33,216,0,136,224,1,0,128,149,1,0,1,0,0,0,251,33,216,0,24,60,1,0,176,223,1,0,1,0,0,0,248,32,216,0,72,198,1,0,192,209,1,0,1,0,0,0,249,32,216,0,24,182,1,0,24,198,1,0,1,0,0,0,250,32,216,0,40,167,1,0,120,189,1,0,1,0,0,0,251,32,216,0,200,149,1,0,184,155,8,0,1,0,0,0,252,32,216,0,56,126,1,0,136,149,8,0,1,0,0,0,253,32,216,0,32,101,1,0,216,142,8,0,1,0,0,0,254,32,216,0,96,32,8,0,40,138,8,0,1,0,0,0,255,32,216,0,16,68,7,0,88,212,3,0,1,0,0,0,200,32,216,0,40,185,3,0,80,251,6,0,1,0,0,0,48,33,216,0,216,70,1,0,208,23,1,0,9,0,0,0,152,32,216,0,32,58,1,0,50,53,48,48,45,112,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,216,192,33,35,1,0,16,1,50,53,48,48,45,115,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,92,146,55,26,2,0,32,0,50,53,48,48,45,99,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,86,75,48,140,3,0,32,0,50,53,48,48,45,99,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,214,88,7,154,3,0,32,0,50,48,50,45,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,234,145,2,156,4,0,16,1,50,48,50,45,118,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,251,184,190,222,5,0,64,0,48,48,57,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,191,207,95,180,1,0,16,1,48,48,57,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,232,254,154,212,2,0,32,0,48,48,57,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,142,131,204,51,3,0,32,0,48,48,57,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,235,127,135,38,3,0,32,0,48,48,57,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,93,160,96,59,3,0,32,0,48,48,57,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,57,208,194,57,3,0,32,0,48,48,57,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,78,52,164,103,3,0,32,0,48,48,57,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,25,139,202,46,3,0,32,0,48,48,57,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,99,152,129,181,4,0,16,1,48,48,57,45,118,49,49,46,118,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,156,165,50,207,5,0,64,0,48,48,57,45,118,49,50,46,118,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,183,136,53,123,5,0,64,0,48,48,57,45,118,49,51,46,118,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,1,90,80,5,0,64,0,48,48,57,45,118,50,49,46,118,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,17,144,95,54,6,0,64,0,98,56,49,45,48,56,46,53,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,105,145,218,214,2,0,0,0,98,56,49,45,49,50,46,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,65,39,216,249,2,0,0,0,98,56,49,45,49,48,46,52,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,68,67,243,83,2,0,0,0,98,56,49,45,48,57,46,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,175,52,13,99,2,0,0,0,98,56,49,45,49,49,46,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,9,191,4,55,9,0,0,0,98,56,49,45,48,51,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,230,117,27,85,11,0,0,0,98,56,49,45,48,52,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,18,78,115,207,11,0,0,0,98,56,49,45,48,50,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,134,59,236,32,24,0,0,0,98,56,49,45,48,49,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,107,121,63,179,25,0,0,0,48,48,49,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,81,201,159,204,1,0,16,1,48,48,49,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,81,186,136,121,2,0,32,0,48,48,49,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,225,152,234,50,3,0,32,0,48,48,49,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,76,6,196,203,3,0,32,0,48,48,49,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,76,5,81,1,3,0,32,0,48,48,49,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,13,87,50,10,3,0,32,0,48,48,49,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,194,76,183,144,3,0,32,0,48,48,49,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,88,237,43,230,3,0,32,0,48,48,49,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,99,68,135,186,4,0,16,1,48,48,49,45,118,49,49,46,118,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,229,213,195,167,5,0,64,0,48,48,49,45,118,50,49,46,118,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,179,112,230,85,6,0,64,0,48,48,49,45,118,50,50,46,118,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,104,131,13,171,6,0,64,0,48,48,49,45,118,50,51,46,118,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,40,142,70,223,6,0,64,0,0,0,0,0,0,0,0,0,107,113,49,45,112,114,103,101,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,192,212,55,97,0,0,16,1,107,113,49,45,112,114,103,111,46,117,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,216,16,173,74,0,0,16,1,107,113,49,45,116,98,108,101,46,117,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,20,165,50,227,0,0,16,1,107,113,49,45,116,98,108,111,46,117,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,21,171,12,118,0,0,16,1,107,113,49,45,99,103,50,46,117,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,222,232,180,128,0,0,32,0,107,113,49,45,99,103,48,46,117,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,5,154,174,248,0,0,32,0,107,113,49,45,99,103,51,46,117,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,201,53,220,155,0,0,32,0,107,113,49,45,99,103,49,46,117,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,164,126,189,35,0,0,32,0,107,113,49,45,99,103,54,46,117,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,18,207,90,178,0,0,32,0,107,113,49,45,99,103,52,46,117,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,242,248,167,220,0,0,32,0,107,113,49,45,99,103,55,46,117,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,44,56,72,159,0,0,32,0,107,113,49,45,99,103,53,46,117,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,22,69,188,164,0,0,32,0,107,113,49,45,115,110,100,46,117,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,73,180,161,140,0,0,64,0,0,0,0,0,254,0,2,0,120,100,6,0,16,0,0,0,1,128,0,0,56,111,3,0,16,0,0,0,1,128,128,0,104,134,3,0,0,0,0,0,104,100,45,48,51,45,52,46,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,69,149,133,148,1,0,16,1,104,100,45,48,48,45,52,46,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,143,100,219,60,1,0,16,1,104,100,45,48,52,45,49,46,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,215,168,46,253,1,0,16,1,104,100,45,48,49,45,49,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,172,71,162,72,1,0,16,1,104,100,45,49,50,46,50,49,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,17,95,213,19,2,0,16,1,104,100,45,48,54,45,49,46,56,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,139,85,122,139,3,0,32,0,104,100,45,48,55,45,49,46,57,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,73,212,163,210,3,0,32,0,109,97,102,45,48,48,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,141,82,111,229,4,0,32,0,109,97,102,45,48,49,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,61,23,213,195,5,0,32,0,109,97,102,45,48,50,46,49,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,73,216,55,11,5,0,32,0,109,97,102,45,48,51,46,49,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,44,109,54,244,6,0,32,0,109,97,102,45,48,52,46,50,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,78,101,143,12,6,0,32,0,109,97,102,45,48,53,46,50,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,128,235,207,176,6,0,32,0,109,97,102,45,48,54,46,49,56,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,181,169,199,245,6,0,32,0,109,97,102,45,48,55,46,50,48,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,163,8,96,253,6,0,32,0,109,97,102,45,48,56,46,50,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,231,241,28,228,6,0,32,0,104,102,45,48,56,46,49,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,159,39,183,147,7,0,32,0,104,102,45,48,57,46,49,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,116,192,226,5,7,0,32,0,104,102,45,49,48,46,49,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,24,244,6,155,7,0,32,0,104,102,45,49,49,46,49,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,49,165,89,56,7,0,32,0])
.concat([109,97,102,45,49,48,46,50,48,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,139,244,87,124,8,0,64,0,109,97,102,45,48,57,46,49,56,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,129,237,231,40,9,0,64,0,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,137,124,159,189,1,0,16,1,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,165,54,236,14,1,0,16,1,57,48,48,53,56,45,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,200,147,10,146,2,0,16,1,57,48,48,53,56,45,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,173,252,204,129,3,0,32,0,57,48,48,53,56,45,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,2,32,122,160,4,0,32,0,57,48,48,53,56,45,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,4,255,11,86,5,0,32,0,57,48,48,53,56,45,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,3,42,215,185,5,0,32,0,57,48,48,53,56,45,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,62,136,12,198,6,0,64,0,57,48,48,53,56,45,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,118,23,60,35,7,0,64,0,49,48,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,201,177,58,99,0,0,0,8,57,48,48,53,56,45,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,108,184,219,207,0,0,0,8,50,54,56,45,112,49,99,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,10,105,54,54,1,0,16,1,50,54,56,45,112,50,99,46,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,162,71,252,141,1,0,16,1,50,54,56,45,99,49,99,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,154,56,124,171,3,0,32,0,50,54,56,45,99,50,99,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,27,136,96,53,3,0,32,0,50,54,56,45,99,51,99,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,234,85,249,58,3,0,32,0,50,54,56,45,99,52,99,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,115,195,41,195,3,0,32,0,50,54,56,45,99,53,99,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,119,129,156,149,3,0,32,0,50,54,56,45,99,54,99,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,27,131,10,1,3,0,32,0,50,54,56,45,99,55,99,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,105,169,114,109,3,0,32,0,50,54,56,45,99,56,99,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,14,114,29,85,3,0,32,0,50,54,56,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,14,110,90,74,4,0,16,1,50,54,56,45,118,49,99,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,12,214,49,174,5,0,64,0,50,54,56,45,118,50,99,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,237,19,6,196,5,0,64,0,109,115,53,45,112,49,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,0,234,83,88,208,1,0,16,1,50,54,56,45,99,49,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,154,56,124,171,3,0,32,0,50,54,56,45,99,50,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,27,136,96,53,3,0,32,0,50,54,56,45,99,51,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,234,85,249,58,3,0,32,0,50,54,56,45,99,52,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,115,195,41,195,3,0,32,0,50,54,56,45,99,53,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,119,129,156,149,3,0,32,0,50,54,56,45,99,54,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,27,131,10,1,3,0,32,0,50,54,56,45,99,55,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,105,169,114,109,3,0,32,0,50,54,56,45,99,56,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,14,114,29,85,3,0,32,0,50,54,56,45,109,49,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,14,110,90,74,4,0,16,1,50,54,56,45,118,49,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,12,214,49,174,5,0,64,0,50,54,56,45,118,50,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,237,19,6,196,5,0,64,0,50,54,51,45,112,104,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,141,92,127,198,1,0,16,1,50,54,51,45,112,104,50,46,115,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,158,200,62,188,1,0,16,1,50,54,51,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,138,95,134,132,3,0,32,0,50,54,51,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,242,151,223,129,3,0,32,0,50,54,51,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,35,51,52,26,3,0,32,0,50,54,51,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,68,251,44,148,3,0,32,0,50,54,51,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,79,133,72,167,3,0,32,0,50,54,51,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,22,161,139,92,3,0,32,0,50,54,51,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,40,130,172,70,4,0,16,1,50,54,51,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,205,185,233,1,5,0,64,0,50,54,51,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,129,191,178,74,5,0,64,0,50,53,54,45,112,104,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,133,202,66,156,1,0,16,1,50,53,54,45,112,104,50,46,115,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,232,140,61,31,1,0,16,1,50,53,54,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,78,195,121,90,3,0,32,0,50,53,54,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,44,54,76,148,3,0,32,0,50,53,54,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,111,211,105,110,3,0,32,0,50,53,54,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,235,180,85,183,3,0,32,0,50,53,54,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,71,171,172,122,3,0,32,0,50,53,54,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,93,253,152,198,3,0,32,0,50,53,54,45,99,55,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,210,221,206,207,3,0,32,0,50,53,54,45,99,56,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,76,227,155,77,3,0,32,0,50,53,54,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,22,193,238,234,4,0,16,1,50,53,54,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,65,2,105,242,5,0,64,0,50,53,54,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,189,16,42,126,5,0,64,0,50,53,54,45,118,51,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,124,193,174,14,5,0,64,0,50,53,54,45,118,52,46,118,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,212,34,75,155,5,0,64,0,57,102,103,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,19,161,219,4,1,0,16,1,56,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,83,95,67,23,2,0,32,0,56,50,115,49,50,51,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,189,80,198,47,3,0,32,0,56,50,115,49,50,54,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,228,168,179,62,3,0,32,0,56,50,115,49,50,54,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,134,204,169,4,0,64,0,56,50,115,49,50,54,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,14,0,0,0,255,255,201,0,0,0,0,0,15,0,0,0,255,255,255,0,0,0,0,0,16,0,0,0,255,255,255,0,0,0,0,0,17,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,16,27,6,0,15,0,0,0,1,16,16,0,96,135,7,0,15,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,2,0,200,30,2,0,16,0,0,0,1,128,128,0,120,97,1,0,16,0,0,0,1,128,0,0,96,19,1,0,0,0,0,0,254,0,4,0,32,4,2,0,14,0,0,0,1,3,3,0,160,36,8,0,14,0,0,0,1,3,1,0,208,239,7,0,14,0,0,0,1,3,2,0,120,187,7,0,14,0,0,0,1,3,0,0,16,227,4,0,0,0,0,0,254,0,4,0,128,129,4,0,14,0,0,0,1,12,0,0,192,255,2,0,14,0,0,0,1,12,4,0,208,75,4,0,14,0,0,0,1,12,8,0,8,49,4,0,14,0,0,0,1,12,12,0,72,246,3,0,0,0,0,0,254,0,4,0,64,37,5,0,14,0,0,0,1,48,0,0,176,116,6,0,14,0,0,0,1,48,16,0,80,113,6,0,14,0,0,0,1,48,32,0,80,110,6,0,14,0,0,0,1,48,48,0,120,7,5,0,0,0,0,0,254,0,2,0,72,202,5,0,14,0,0,0,1,64,64,0,248,38,7,0,14,0,0,0,1,64,0,0,112,212,3,0,0,0,0,0,254,0,2,0,32,182,8,0,17,0,0,0,1,1,1,0,16,86,3,0,17,0,0,0,1,1,0,0,184,84,3,0,0,0,0,0,117,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,137,109,235,110,1,0,16,1,117,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,181,212,93,241,1,0,16,1,117,50,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,105,31,1,85,2,0,64,0,117,53,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,103,212,70,138,3,0,32,0,117,53,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,46,62,253,213,3,0,32,0,117,52,50,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,171,33,63,183,4,0,32,0,117,52,50,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,117,145,254,194,4,0,32,0,109,115,53,45,112,49,112,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,111,39,107,16,1,0,16,1,109,115,53,45,112,50,112,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,232,88,164,214,1,0,16,1,109,115,53,45,112,51,112,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,49,192,158,67,1,0,16,1,109,115,53,45,115,49,112,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,50,68,224,33,2,0,32,0,50,54,56,45,99,49,99,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,154,56,124,171,3,0,32,0,50,54,56,45,99,50,99,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,27,136,96,53,3,0,32,0,50,54,56,45,99,51,99,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,234,85,249,58,3,0,32,0,50,54,56,45,99,52,99,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,115,195,41,195,3,0,32,0,50,54,56,45,99,53,99,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,119,129,156,149,3,0,32,0,50,54,56,45,99,54,99,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,27,131,10,1,3,0,32,0,50,54,56,45,99,55,99,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,105,169,114,109,3,0,32,0,50,54,56,45,99,56,99,46])
.concat([99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,14,114,29,85,3,0,32,0,50,54,56,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,14,110,90,74,4,0,16,1,50,54,56,45,118,49,99,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,12,214,49,174,5,0,64,0,50,54,56,45,118,50,99,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,237,19,6,196,5,0,64,0,109,115,52,45,112,49,112,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,4,110,106,128,1,0,16,1,50,54,51,45,112,50,46,115,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,216,174,183,253,1,0,16,1,109,115,52,45,115,49,112,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,206,135,255,7,2,0,32,0,50,54,51,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,138,95,134,132,3,0,32,0,50,54,51,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,242,151,223,129,3,0,32,0,50,54,51,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,35,51,52,26,3,0,32,0,50,54,51,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,68,251,44,148,3,0,32,0,50,54,51,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,79,133,72,167,3,0,32,0,50,54,51,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,22,161,139,92,3,0,32,0,50,54,51,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,40,130,172,70,4,0,16,1,50,54,51,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,205,185,233,1,5,0,64,0,50,54,51,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,129,191,178,74,5,0,64,0,100,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,89,147,205,61,1,0,16,1,100,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,216,88,0,113,1,0,16,1,100,111,102,105,120,46,100,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,155,3,125,58,1,0,16,1,100,111,102,105,120,46,100,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,95,132,219,50,1,0,16,1,100,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,102,254,76,222,2,0,32,0,100,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,139,243,194,166,2,0,32,0,114,56,45,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,250,159,220,219,3,0,32,0,110,56,45,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,219,115,153,75,3,0,32,0,104,53,45,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,197,140,33,225,4,0,32,0,107,53,45,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,4,139,246,177,4,0,32,0,117,48,50,45,45,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,215,101,138,35,5,0,32,0,116,48,50,45,45,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,192,61,38,174,5,0,32,0,102,49,48,45,45,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,162,76,238,22,5,0,32,0,106,49,48,45,45,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,132,226,127,255,5,0,32,0,48,50,55,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,19,56,200,1,0,16,1,48,50,55,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,170,75,130,229,2,0,32,0,48,50,55,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,148,111,8,208,3,0,32,0,48,50,55,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,166,245,97,218,3,0,32,0,48,50,55,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,40,18,223,8,3,0,32,0,48,50,55,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,150,118,232,84,3,0,32,0,48,50,55,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,38,162,213,173,4,0,16,1,48,50,55,45,118,49,49,46,118,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,89,68,173,89,5,0,64,0,48,50,55,45,118,50,49,46,118,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,235,78,91,223,6,0,64,0,112,49,48,48,51,49,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,161,230,214,79,1,0,16,1,112,49,48,48,52,49,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,154,108,53,182,1,0,16,1,117,112,48,48,49,48,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,135,201,145,206,1,0,16,1,117,112,48,48,49,48,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,5,165,183,13,1,0,16,1,117,112,48,48,49,48,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,227,227,197,42,2,0,16,1,112,49,48,48,54,49,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,124,156,246,128,11,0,32,0,112,49,48,48,55,49,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,163,225,55,209,11,0,32,0,112,49,48,48,56,49,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,43,79,73,87,11,0,32,0,112,49,48,48,57,49,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,210,175,68,131,11,0,32,0,117,112,48,48,49,48,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,114,180,186,191,4,0,32,0,117,112,48,48,49,48,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,129,163,206,38,4,0,32,0,117,112,48,48,49,48,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,249,197,210,254,4,0,32,0,117,112,48,48,49,48,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,234,249,171,173,4,0,32,0,117,112,48,48,49,48,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,159,227,32,46,6,0,64,0,117,112,48,48,49,48,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,94,49,166,252,6,0,64,0,100,119,48,49,45,53,46,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,57,12,97,135,1,0,0,0,100,119,48,50,46,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,184,176,201,64,1,0,0,0,100,119,48,51,46,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,244,168,6,86,1,0,0,0,100,119,48,52,46,54,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,54,12,92,35,1,0,0,0,100,119,48,53,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,130,77,140,194,2,0,0,0,100,119,48,48,46,49,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,92,241,37,61,3,0,0,0,100,119,49,52,46,49,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,169,191,13,155,4,0,0,0,100,119,49,53,46,49,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,218,63,104,149,4,0,0,0,100,119,49,49,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,167,204,31,27,4,0,0,0,100,119,49,51,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,86,48,65,231,4,0,0,0,100,119,49,48,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,70,117,102,87,4,0,0,0,100,119,49,50,46,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,184,141,84,76,4,0,0,0,100,119,49,54,46,49,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,39,249,188,229,4,0,0,0,100,119,49,55,46,49,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,35,247,16,158,4,0,0,0,100,119,48,54,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,157,2,94,182,5,0,0,0,100,119,48,55,46,49,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,93,153,141,102,5,0,0,0,100,119,48,56,46,49,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,160,244,44,187,5,0,0,0,100,119,48,57,46,49,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,19,141,82,106,5,0,0,0,100,119,49,56,46,57,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,95,148,241,117,6,0,0,0,100,119,49,57,46,49,48,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,250,243,22,204,6,0,0,0,100,119,46,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,217,206,233,40,7,0,0,8,50,55,51,50,117,49,48,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,128,190,143,175,0,0,16,1,50,55,51,50,117,48,57,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,115,30,125,9,0,0,16,1,50,55,51,50,117,48,56,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,218,132,103,82,0,0,16,1,50,55,51,50,117,48,55,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,16,9,6,91,0,0,16,1,50,55,51,50,117,48,54,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,109,175,200,138,0,0,16,1,50,55,51,50,117,48,53,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,3,182,43,5,0,0,16,1,50,55,51,50,117,48,52,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,146,126,139,155,0,0,16,1,50,55,49,54,117,49,49,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,97,139,155,89,0,0,16,1,55,52,115,50,56,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,153,234,121,199,0,0,32,0,109,112,114,45,49,56,53,54,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,171,198,218,47,33,0,16,0,109,112,114,45,49,50,56,48,55,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,101,105,77,114,33,0,16,0,122,111,111,108,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,3,139,229,30,33,0,16,0,122,101,114,111,32,116,104,101,32,107,97,109,105,107,97,122,101,32,115,113,117,105,114,114,101,108,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,75,11,255,69,33,0,16,0,121,115,32,45,32,119,97,110,100,101,114,101,114,115,32,102,114,111,109,32,121,115,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,118,78,218,82,33,0,16,0,109,112,114,45,49,53,53,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,151,202,120,11,33,0,16,0,119,105,110,120,32,40,114,117,115,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,224,227,189,22,33,0,16,0,119,111,114,108,100,32,99,117,112,32,115,111,99,99,101,114,32,45,45,32,119,111,114,108,100,32,99,104,97,109,112,105,111,110,115,104,105,112,32,115,111,99,99,101,114,32,40,117,115,97,44,32,106,112,110,41])
.concat([46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,112,61,28,176,33,0,16,0,119,111,114,108,100,32,99,117,112,32,115,111,99,99,101,114,32,45,45,32,119,111,114,108,100,32,99,104,97,109,112,105,111,110,115,104,105,112,32,115,111,99,99,101,114,32,40,117,115,97,44,32,106,112,110,41,32,40,118,49,46,50,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,230,237,132,191,33,0,16,0,119,111,114,108,100,32,99,104,97,109,112,105,111,110,115,104,105,112,32,115,111,99,99,101,114,32,105,105,32,40,101,117,114,111,112,101,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,77,119,101,96,33,0,16,0,109,112,114,45,49,57,51,54,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,73,9,93,169,33,0,16,0,112,97,108,95,117,108,116,105,109,97,116,101,95,109,107,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,180,92,251,236,33,0,16,0,109,112,114,45,49,53,53,55,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,27,149,201,203,33,0,16,0,109,112,114,45,49,52,52,54,52,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,244,195,98,115,33,0,16,0,110,101,119,32,122,101,97,108,97,110,100,32,115,116,111,114,121,44,32,116,104,101,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,33,173,119,28,33,0,16,0,116,105,99,107,44,32,116,104,101,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,240,50,81,66,33,0,16,0,109,112,114,45,49,55,53,56,56,43,109,112,114,45,49,55,54,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,219,176,16,17,33,0,16,0,116,104,117,110,100,101,114,32,102,111,120,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,15,245,99,84,33,0,16,0,116,104,117,110,100,101,114,32,102,111,114,99,101,32,105,118,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,128,100,96,141,33,0,16,0,116,104,117,110,100,101,114,32,102,111,114,99,101,32,105,105,32,109,100,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,224,195,94,231,33,0,16,0,116,51,32,45,32,116,104,101,32,97,114,99,97,100,101,32,103,97,109,101,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,119,239,181,210,33,0,16,0,109,112,114,45,49,53,50,51,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,23,79,38,161,33,0,16,0,115,117,112,101,114,32,115,116,114,101,101,116,32,102,105,103,104,116,101,114,32,105,105,32,45,32,116,104,101,32,110,101,119,32,99,104,97,108,108,101,110,103,101,114,115,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,0,47,25,44,104,33,0,16,0,109,112,114,45,49,52,49,50,53,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,198,39,242,191,33,0,16,0,109,112,114,45,49,54,56,51,52,43,109,112,114,45,49,54,56,51,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,95,19,120,59,33,0,16,0,109,112,114,45,49,53,51,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,220,239,227,66,33,0,16,0,109,112,114,45,49,51,50,53,48,97,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,138,178,145,190,33,0,16,0,115,117,112,101,114,32,109,97,114,105,111,32,119,111,114,108,100,32,40,117,110,108,41,32,40,112,105,114,97,116,101,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,94,105,194,151,33,0,16,0,115,117,112,101,114,32,109,97,114,105,111,32,119,111,114,108,100,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,166,11,84,207,33,0,16,0,109,112,114,45,49,54,57,49,48,45,117,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,145,246,88,6,33,0,16,0,115,111,110,105,99,32,116,104,101,32,104,101,100,103,101,104,111,103,32,51,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,206,146,193,155,39,0,16,0,109,112,114,45,49,54,57,49,48,45,117,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,145,246,88,6,33,0,16,0,109,112,114,45,49,54,57,49,49,45,115,46,105,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,92,213,207,77,40,0,16,0,109,112,114,45,49,53,48,48,48,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,131,83,144,123,39,0,16,0,109,112,114,45,49,54,57,49,48,45,117,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,145,246,88,6,33,0,16,0,109,112,114,45,49,51,57,49,51,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,151,78,57,249,39,0,16,0,115,104,105,112,32,40,112,114,111,116,111,116,121,112,101,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,22,159,220,76,33,0,16,0,115,116,114,101,101,116,32,102,105,103,104,116,101,114,32,105,105,39,32,45,32,115,112,101,99,105,97,108,32,99,104,97,109,112,105,111,110,32,101,100,105,116,105,111,110,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,161,8,254,19,33,0,16,0,115,116,114,101,101,116,32,102,105,103,104,116,101,114,32,105,105,39,32,112,108,117,115,32,40,106,112,110,44,32,97,115,105,97,44,32,107,111,114,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,227,126,72,46,33,0,16,0,114,105,99,104,97,114,100,32,115,99,97,114,114,121,39,115,32,98,117,115,121,116,111,119,110,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,63,12,182,123,33,0,16,0,114,111,108,111,32,116,111,32,116,104,101,32,114,101,115,99,117,101,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,162,97,104,48,33,0,16,0,114,105,115,107,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,13,109,65,128,33,0,16,0,114,101,118,111,108,117,116,105,111,110,32,120,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,212,197,176,95,33,0,16,0,114,101,115,113,32,40,101,117,114,111,41,32,40,112,114,111,116,111,116,121,112,101,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,224,53,142,85,33,0,16,0,109,112,114,45,49,54,48,54,53,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,113,71,128,181,33,0,16,0,112,103,97,32,116,111,117,114,32,103,111,108,102,32,40,101,117,114,111,44,32,117,115,97,41,32,40,118,49,46,49,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,142,255,137,4,33,0,16,0,112,103,97,32,116,111,117,114,32,103,111,108,102,32,105,105,105,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,95,246,179,174,33,0,16,0,112,103,97,32,116,111,117,114,32,103,111,108,102,32,105,105,32,40,101,117,114,111,44,32,117,115,97,41,32,40,118,49,46,49,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,6,134,43,232,33,0,16,0,112,101,108,101,33,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,81,190,138,90,33,0,16,0,112,114,111,32,97,99,116,105,111,110,32,114,101,112,108,97,121,32,50,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,39,189,58,167,33,0,16,0,111,111,122,101,44,32,116,104,101,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,44,16,107,225,33,0,16,0,111,117,116,32,111,102,32,116,104,105,115,32,119,111,114,108,100,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,110,163,45,33,0,16,0,110,101,101,100,32,102,111,114,32,115,112,101,101,100,32,117,110,100,101,114,99,111,118,101,114,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,147,142,27,190,33,0,16,0,102,105,110,100,105,110,103,32,110,101,109,111,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,102,47,185,137,33,0,16,0,109,105,103,104,116,121,32,109,111,114,112,104,105,110,32,112,111,119,101,114,32,114,97,110,103,101,114,115,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,99,230,150,127,33,0,16,0,109,107,32,53,32,45,32,109,111,114,116,97,108,32,99,111,109,98,97,116,32,45,32,115,117,98,122,101,114,111,32,40,117,110,108,41,32,40,112,105,114,97,116,101,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,6,48,32,65,33,0,16,0,109,111,114,116,97,108,32,107,111,109,98,97,116,32,51,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,246,138,99,221,33,0,16,0,108,111,114,100,32,111,102,32,116,104,101,32,114,105,110,103,115,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,42,52,162,226,33,0,16,0,108,111,110,103,32,40,99,104,105,41,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,35,230,134,27,33,0,16,0,108,111,98,111,32,40,117,115,97,41,32,40,112,114,111,116,111,116,121,112,101,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,56,147,224,181,33,0,16,0,108,104,120,32,97,116,116,97,99,107,32,99,104,111,112,112,101,114,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,3,241,79,34,33,0,16,0,108,101,116,104,97,108,32,101,110,102,111,114,99,101,114,115,32,105,105,32,45,32,103,117,110,32,102,105,103,104,116,101,114,115,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,139,210,253,229,33,0,16,0,107,105,110,103,32,111,102,32,116,104,101,32,109,111,110,115,116,101,114,115,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,73,253,148,122,33,0,16,0,107,108,97,120,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,158,208,140,36,33,0,16,0,106,46,32,108,101,97,103,117,101,32,112,114,111,32,115,116,114,105,107,101,114,32,40,106,112,110,41,32,40,118,49,46,51,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,17,122,91,45,33,0,16,0,106,46,32,108,101,97,103,117,101,32,99,104,97,109,112,105,111,110,32,115,111,99,99,101,114,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,94,64,60,69,33,0,16,0,105,110,99,114,101,100,105,98,108,101,32,104,117,108,107,44,32,116,104,101,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,220,162,165,132,33,0,16,0,104,111,111,107,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,58,67,84,161,33,0,16,0,103,111,100,115,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,22,80,65,108,33,0,16,0,109,112,114,45,49,53,51,50,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,110,136,175,242,33,0,16,0,103,114,101,97,116,101,115,116,32,104,101,97,118,121,119,101,105,103,104,116,115,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,213,33,54,110,33,0,16,0,103,114,101,97,116,101,115,116,32,104,101,97,118,121,119,101,105,103,104,116,115,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,98,177,248,126,33,0,16,0,103,101,109,115,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,88,176,235,152,33,0,16,0,102,108,117,120,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,140,160,29,42,33,0,16,0,115,111,99,99,101,114,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,99,183,219,189,33,0,16,0,102,45,50,50,32,105,110,116,101,114,99,101,112,116,111,114,32,40,101,117,114,111,44,32,117,115,97,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,164,128,168,214,33,0,16,0,102,45,50,50,32,105,110,116,101,114,99,101,112,116,111,114,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,133,199,85,251,33,0,16,0,102,45,50,50,95,105,110,116,101,114,99,101,112,116,95,102,45,50,48,50,45,52,46,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,248,113,151,100,17,0,16,0,102,45,50,50,95,105,110,116,101,114,99,101,112,116,95,102,45,50,48,50,45,49,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,184,203,215,211,52,0,16,0,102,49,32,45,32,119,111,114,108,100,32,99,104,97,109,112,105,111,110,115,104,105,112,32,101,100,105,116,105,111,110,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,167,224,206,116,33,0,16,0,102,45,49,49,55,32,110,105,103,104,116,32,115,116,111,114,109,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,7,122,246,27,33,0,16,0,101,97,114,116,104,119,111,114,109,32,106,105,109,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,55,179,7,28,33,0,16,0,109,112,114,45,49,53,50,54,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,144,115,84,69,33,0,16,0,109,112,114,45,49,52,56,51,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,153,117,43,81,33,0,16,0,100,114,97,103,111,110,32,98,97,108,108,32,122,32,45,32,108,39,97,112,112,101,108,32,100,117,32,100,101,115,116,105,110,32,40,102,114,97,110,99,101,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,55,199,53,240,33,0,16,0,99,108,117,101,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,150,162,83,119,33,0,16,0,100,105,115,110,101,121,39,115,32,99,97,114,115,32,40,114,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,48,37,95,108,33,0,16,0,98,46,111,46,98,46,32,40,117,115,97,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,30,66,232,227,33,0,16,0,98,97,114,101,32,107,110,117,99,107,108,101,32,105,105,105,32,40,106,112,110,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,219,153,255,231,33,0,16,0,98,97,114,101,32,107,110,117,99,107,108,101,32,105,105,32,40,106,112,110,41,32,40,98,101,116,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,19,0,190,172,242,12,33,0,16,0,97,114,116,32,111,102,32,102,105,103,104,116,105,110,103,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,7,126,165,201,33,0,16,0,97,114,116,32,111,102,32,102,105,103,104,116,105,110,103,32,40,112,114,111,116,111,116,121,112,101,32,45,32,106,117,108,32,49,49,44,32,49,57,57,52,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,125,86,206,25,33,0,16,0,109,112,114,45,49,54,54,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,87,175,62,26,33,0,16,0,54,45,112,97,107,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,220,69,111,26,33,0,16,0,109,99,97,45,117,51,48,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,101,187,47,198,1,0,16,1,109,99,97,45,117,50,57,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,124,34,33,207,1,0,16,1,117,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,113,81,160,253,2,0,16,1,109,99,97,45,117,56,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,70,215,1,95,3,0,32,0,109,99,97,45,117,56,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0])
.concat([166,229,27,78,3,0,32,0,109,99,97,45,117,56,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,144,39,32,223,3,0,32,0,109,99,97,45,117,56,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,210,113,87,168,3,0,32,0,109,99,97,45,117,56,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,218,241,123,1,3,0,32,0,109,99,97,45,117,56,55,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,185,201,157,188,3,0,32,0,109,99,97,45,117,53,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,226,134,129,58,4,0,32,0,109,99,97,45,117,54,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,20,38,148,200,5,0,32,0,109,99,97,45,117,54,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,201,102,175,81,5,0,32,0,109,99,97,45,117,49,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,176,241,115,178,5,0,32,0,109,99,97,45,117,53,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,5,110,199,100,6,0,64,0,98,55,50,95,48,54,46,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,255,142,132,174,2,0,0,0,98,55,50,95,49,50,46,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,112,206,118,113,2,0,0,0,98,55,50,95,48,52,46,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,76,150,30,20,2,0,0,0,98,55,50,95,48,51,46,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,150,52,82,244,2,0,0,0,98,55,50,95,48,55,46,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,111,148,26,43,9,0,0,0,98,55,50,45,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,90,246,25,197,11,0,0,0,98,55,50,45,48,49,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,110,194,74,162,11,0,0,0,58,1,58,3,58,5,58,7,58,8,58,9,58,11,58,13,58,15,58,16,186,16,250,16,58,17,122,17,186,17,250,17,58,18,186,18,250,18,58,19,122,19,186,19,250,19,58,20,186,20,250,20,58,21,122,21,186,21,58,22,186,22,250,22,58,23,122,23,186,23,58,24,186,24,250,24,58,25,122,25,186,25,58,26,186,26,250,26,58,27,122,27,186,27,58,28,186,28,250,28,58,29,122,29,186,29,58,30,186,30,250,30,58,31,122,31,186,31,58,32,122,32,186,32,250,32,58,33,122,33,186,33,250,33,58,34,122,34,186,34,250,34,58,35,122,35,186,35,250,35,58,36,122,36,186,36,250,36,58,37,122,37,186,37,58,38,122,38,186,38,250,38,58,39,122,39,186,39,58,40,122,40,186,40,250,40,58,41,122,41,186,41,58,42,122,42,186,42,250,42,58,43,122,43,186,43,58,44,122,44,186,44,250,44,58,45,122,45,186,45,58,46,122,46,186,46,250,46,58,47,122,47,186,47,58,48,122,48,186,48,250,48,58,49,122,49,186,49,250,49,58,50,122,50,186,50,250,50,58,51,122,51,186,51,250,51,58,52,122,52,186,52,250,52,58,53,122,53,186,53,58,54,122,54,186,54,250,54,58,55,122,55,186,55,58,56,122,56,186,56,250,56,58,57,122,57,186,57,58,58,122,58,186,58,250,58,58,59,122,59,186,59,58,60,122,60,186,60,250,60,58,61,122,61,186,61,58,62,122,62,186,62,250,62,58,63,122,63,186,63,186,65,186,67,250,68,186,69,250,70,186,71,186,73,186,75,186,76,250,76,186,77,186,79,58,128,122,128,186,128,250,128,250,129,58,130,122,130,186,130,250,130,250,131,58,132,122,132,186,132,250,132,250,133,58,134,122,134,186,134,250,134,250,135,58,136,122,136,186,136,250,136,250,137,58,138,122,138,186,138,250,138,250,139,58,140,122,140,186,140,250,140,250,141,58,142,122,142,186,142,250,142,250,143,58,144,122,144,186,144,250,144,250,145,58,146,122,146,186,146,250,146,250,147,58,148,122,148,186,148,250,148,250,149,58,150,122,150,186,150,250,150,250,151,58,152,122,152,186,152,250,152,250,153,58,154,122,154,186,154,250,154,250,155,58,156,122,156,186,156,250,156,250,157,58,158,122,158,186,158,250,158,250,159,58,176,122,176,186,176,250,176,250,177,58,178,122,178,186,178,250,178,250,179,58,180,122,180,186,180,250,180,250,181,58,182,122,182,186,182,250,182,250,183,58,184,122,184,186,184,250,184,250,185,58,186,122,186,186,186,250,186,250,187,58,188,122,188,186,188,250,188,250,189,58,190,122,190,186,190,250,190,250,191,58,192,122,192,186,192,250,192,250,193,58,194,122,194,186,194,250,194,250,195,58,196,122,196,186,196,250,196,250,197,58,198,122,198,186,198,250,198,250,199,58,200,122,200,186,200,250,200,250,201,58,202,122,202,186,202,250,202,250,203,58,204,122,204,186,204,250,204,250,205,58,206,122,206,186,206,250,206,250,207,58,208,122,208,186,208,250,208,250,209,58,210,122,210,186,210,250,210,250,211,58,212,122,212,186,212,250,212,250,213,58,214,122,214,186,214,250,214,250,215,58,216,122,216,186,216,250,216,250,217,58,218,122,218,186,218,250,218,250,219,58,220,122,220,186,220,250,220,250,221,58,222,122,222,186,222,250,222,250,223,0,0,116,118,51,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,55,22,57,89,1,0,16,1,116,118,103,52,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,206,188,55,24,1,0,16,1,116,118,103,53,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,2,166,29,101,1,0,16,1,116,118,103,49,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,102,151,41,197,2,0,16,1,116,118,103,50,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,10,48,22,178,2,0,16,1,116,118,103,54,46,56,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,229,58,147,171,3,0,32,0,116,118,103,55,46,56,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,167,221,142,206,3,0,32,0,116,118,103,56,46,56,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,106,83,209,116,3,0,32,0,116,118,103,57,46,56,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,117,134,22,66,4,0,32,0,116,118,103,49,48,46,56,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,103,235,159,250,4,0,32,0,116,118,103,49,49,46,56,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,73,221,243,113,4,0,32,0,49,52,45,51,46,57,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,38,145,208,137,5,0,32,0,49,52,45,52,46,49,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,108,254,202,225,5,0,32,0,49,52,45,53,46,49,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,166,79,68,45,5,0,32,0,49,52,45,49,46,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,109,48,216,58,5,0,32,0,49,52,45,50,46,49,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,255,241,164,18,5,0,32,0,97,102,101,103,97,57,46,117,49,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,165,23,21,11,1,0,16,1,97,102,101,103,97,49,48,46,117,49,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,61,243,208,177,1,0,16,1,115,111,117,110,100,46,117,57,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,170,249,196,190,2,0,16,1,97,102,101,103,97,53,46,117,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,224,97,50,199,4,0,32,0,97,102,101,103,97,52,46,117,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,23,9,148,115,4,0,32,0,97,102,101,103,97,54,46,117,99,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,48,252,158,151,5,0,32,0,97,102,101,103,97,55,46,117,99,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,56,204,203,197,5,0,32,0,97,102,101,103,97,50,46,117,57,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,249,193,200,120,6,0,64,0,55,57,57,121,48,50,46,107,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,213,219,231,226,1,0,16,1,55,57,57,99,48,49,46,102,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,92,76,124,68,2,0,16,1,55,57,57,99,48,54,46,102,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,88,203,57,248,3,0,32,0,55,57,57,99,48,55,46,104,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,56,245,109,23,3,0,32,0,55,57,57,99,48,56,46,106,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,120,0,30,208,3,0,32,0,55,57,57,99,48,57,46,107,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,94,199,174,155,3,0,32,0,55,57,57,98,48,52,46,104,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,43,12,62,50,4,0,32,0,55,57,57,98,48,53,46,107,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,49,88,28,87,4,0,32,0,55,57,57,98,48,51,46,100,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,66,211,207,241,5,0,64,0,55,57,57,98,48,54,46,99,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,215,71,140,44,6,0,32,0,54,51,115,49,52,49,110,46,107,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,209,200,246,97,7,0,0,8,48,48,53,45,112,103,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,45,73,10,189,1,0,16,1,48,48,53,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,162,105,83,28,2,0,32,0,48,48,53,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,52,238,106,128,3,0,32,0,48,48,53,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,134,154,170,52,3,0,32,0,48,48,53,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,38,185,194,196,3,0,32,0,48,48,53,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,244,220,70,156,3,0,32,0,48,48,53,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,109,8,105,3,0,32,0,48,48,53,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,66,193,122,171,3,0,32,0,48,48,53,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,15,159,37,38,4,0,16,1,48,48,53,45,118,49,49,46,118,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,253,85,4,204,5,0,64,0,48,48,53,45,118,50,49,46,118,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,183,181,74,249,6,0,64,0,48,48,53,45,118,50,50,46,118,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,4,253,44,35,6,0,64,0,114,101,48,48,45,50,46,101,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,15,241,56,113,1,0,16,1,109,99,99,45,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,236,3,107,100,2,0,32,0,109,99,99,45,48,49,46,97,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,69,135,216,19,3,0,32,0,109,99,99,45,48,50,46,97,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,38,113,249,208,3,0,32,0,109,99,99,45,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,222,106,238,134,4,0,64,0,109,99,99,45,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,160,187,46,218,5,0,64,0,57,51,99,52,53,46,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,45,141,206,22,6,0,16,1,57,50,49,97,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,85,141,49,51,1,0,16,1,57,50,49,97,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,199,130,192,119,2,0,16,1,57,50,49,97,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,45,36,216,187,3,0,32,0,57,50,49,97,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,187,228,2,64,4,0,32,0,57,50,49,97,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,18,241,43,125,5,0,32,0,57,50,49,97,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,221,237,161,213,6,0,64,0,57,50,49,97,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,15,29,70,137,7,0,64,0,57,50,49,97,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,108,184,219,207,0,0,0,8,57,50,49,97,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,201,177,58,99,0,0,0,8,57,50,49,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,45,228,113,131,0,0,0,8,105,99,49,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,35,136,138,254,1,0,16,1,105,99,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,232,205,0,42,1,0,16,1,105,99,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,1,194,92,236,1,0,16,1,105,99,51,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,162,55,3,162,2,0,16,1,105,99,54,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,60,146,29,9,4,0,32,0,105,99,53,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,44,57,54,84,5,0,32,0,105,99,52,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,105,221,219,255,5,0,32,0,105,99,50,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,138,144,209,253,5,0,32,0,105,99,50,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,6,212,115,92,5,0,32,0,105,99,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,60,123,225,50,5,0,32,0,105,99,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,193,51,229,82,5,0,32,0,105,99,54,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,186,52,225,153,5,0,32,0,105,99,54,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,119,135,242,200,5,0,32,0,105,99,57,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,218,70,57,22,6,0,32,0,105,99,57,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,29,10,201,124,6,0,32,0,105,99,56,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,172,117,162,188,6,0,32,0,105,99,56,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,218,110,57,62,6,0,32,0,54,51,115,49,52,49,46,49,53,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,152,204,107,217,0,0,0,8,117,49,51,45,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,28,192,105,48,1,0,16,1,117,49,52,45,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,40,200,145,93,1,0,16,1,57,99,95,108,119,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,1,194,92,236,1,0,16,1,49,49,101,95,108,119,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,162,55,3,162,2,0,16,1,57,104,95,108,119,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,60,146,29,9,4,0,32,0,98,95,48,51,101,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,39,48,110,23,5,0,32,0,98,95,48,49,101,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,35,86,210,245,5,0,32,0,98,95,48,51,100,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,53,170,28,0,5,0,32,0,98,95,48,49,100,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,195,8,160,11,5,0,32,0,98,95,48,51,98,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,233,130,129,79,5,0,32,0,98,95,48,49,98,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,116,115,97,241,5,0,32,0,98,95,48,51,102,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,204,77,55,155,5,0,32,0,98,95,48,49,102,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,10,78,101,35,5,0,32,0,98,95,48,51,106,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,58,118,60,143,6,0,32,0,98,95,48,49,106,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,29,10,201,124,6,0,32,0,98,95,48,51,104,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,50,245,88,125,6,0,32,0,98,95,48,49,104,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,218,110,57,62,6,0,32,0,54,51,115,49,52,49,46,49,53,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,152,204,107,217,0,0,0,8,48,50,52,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,151,171,196,137,1,0,16,1,48,50,52,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,198,92,239,92,2,0,32,0,48,50,52,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,220,194,23,54,3,0,32,0,48,50,52,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,216,127,10,63,3,0,32,0,48,50,52,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,248,69,247,233,3,0,32,0,48,50,52,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,251,254,130,115,3,0,32,0,48,50,52,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,66,151,193,206,4,0,16,1,48,50,52,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,99,160,223,239,5,0,64,0,48,50,52,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,192,151,121,60,5,0,64,0,108,111,114,100,103,117,110,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,239,119,218,172,1,0,16,1,108,111,114,100,103,117,110,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,84,18,166,161,1,0,16,1,108,111,114,100,103,117,110,46,57,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,40,94,155,213,2,0,16,1,105,103,115,116,48,48,49,46,49,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,243,150,221,54,3,0,32,0,105,103,115,116,48,48,50,46,49,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,101,118,106,129,3,0,32,0,105,103,115,116,48,48,51,46,49,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,67,229,254,203,3,0,32,0,105,103,115,98,48,48,49,46,56,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,28,222,150,48,4,0,32,0,105,103,115,98,48,48,50,46,57,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,30,83,52,34,4,0,32,0,105,103,115,98,48,48,51,46,57,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,172,33,191,108,4,0,32,0,105,103,115,97,48,48,49,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,51,190,10,64,5,0,32,0,105,103,115,97,48,48,52,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,100,114,104,82,5,0,32,0,105,103,115,97,48,48,50,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,56,14,129,164,5,0,32,0,105,103,115,97,48,48,53,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,227,121,46,227,5,0,32,0,105,103,115,97,48,48,51,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,217,72,158,100,5,0,32,0,105,103,115,97,48,48,54,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,182,142,40,57,5,0,32,0,108,111,114,100,103,117,110,46,49,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,7,250,224,180,6,0,64,0,97,53,52,45,48,49,46,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,197,178,234,52,1,0,16,1,97,53,52,45,48,50,46,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,138,29,71,234,1,0,16,1,97,53,52,45,48,52,46,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,154,175,31,84,2,0,16,1,97,53,52,45,48,51,46,53,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,216,118,62,73,3,0,16,1,97,53,52,45,48,53,46,56,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,82,62,117,118,4,0,32,0,97,53,52,45,48,54,46,56,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,92,1,60,243,4,0,32,0,97,53,52,45,48,55,46,56,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,232,194,2,14,4,0,32,0,97,53,52,45,48,56,46,56,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,115,240,245,78,4,0,32,0,97,53,52,45,49,48,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,20,189,223,23,5,0,0,8,97,53,52,45,48,57,46,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,70,136,139,14,6,0,16,8,112,97,108,49,54,108,56,45,97,53,52,45,49,49,46,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,19,33,35,86,7,0,0,8,112,97,108,49,54,108,56,45,97,53,52,45,49,50,46,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,137,60,124,229,7,0,0,8,112,97,108,49,54,108,56,97,45,97,53,52,45,49,51,46,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,142,147,177,201,7,0,0,8,112,97,108,49,54,108,56,97,45,97,53,52,45,49,52,46,51,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,78,100,156,168,7,0,0,8,122,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,136,196,202,96,1,0,16,1,122,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,23,95,201,34,1,0,16,1,97,53,52,45,48,52,46,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,154,175,31,84,2,0,16,1,97,53,52,45,48,51,46,53,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,216,118,62,73,3,0,16,1,105,99,57,51,95,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,82,62,117,118,4,0,32,0,105,99,57,52,95,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,92,1,60,243,4,0,32,0,105,99,57,53,95,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,232,194,2,14,4,0,32,0,105,99,57,54,95,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,115,240,245,78,4,0,32,0,97,53,52,45,49,48,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,20,189,223,23,5,0,0,8,108,111,107,46,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,147,247,109,134,1,0,16,1,108,111,107,46,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,15,64,169,251,1,0,16,1,97,53,52,45,48,52,46,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,154,175,31,84,2,0,16,1,97,53,52,45,48,51,46,53,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,216,118,62,73,3,0,16,1,105,99,57,51,95,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,82,62,117,118,4,0,32,0,105,99,57,52,95,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,92,1,60,243,4,0,32,0,105,99,57,53,95,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,232,194,2,14,4,0,32,0,105,99,57,54,95,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,115,240,245,78,4,0,32,0,97,53,52,45,49,48,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,20,189,223,23,5,0,0,8,108,101,103,105,111,110,46,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,96,102,34,33,1,0,16,1,108,101,103,105,111,110,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,29,218,12,140,1,0,16,1,108,101,103,105,111,110,46,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,1,0,30,94,228,194,1,0,16,1,108,101,103,105,111,110,46,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,10,102,6,195,1,0,16,1,108,101,103,105,111,110,46,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,240,247,164,44,2,0,16,1,108,101,103,105,111,110,46,49,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,37,1,11,197,3,0,32,0,108,101,103,105,111,110,46,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,175,15,215,169,4,0,32,0,108,101,103,105,111,110,46,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,59,49,24,240,4,0,32,0,108,101,103,105,111,110,46,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,170,173,184,41,5,0,32,0,108,101,103,105,111,110,46,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,185,13,90,255,6,0,32,0,108,101,103,105,111,110,46,49,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,200,32,226,186,6,0,32,0,108,101,103,105,111,110,46,49,105,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,39,168,244,121,0,0,0,8,108,49,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,219,10,158,208,1,0,16,1,108,50,46,100,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,10,74,188,136,1,0,16,1,108,51,46,101,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,206,239,233,83,1,0,16,1,108,52,46,104,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,215,36,196,255,1,0,16,1,108,53,46,106,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,9,248,106,173,1,0,16,1,108,54,46,107,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,164,204,26,207,1,0,16,1,108,57,46,102,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,30,218,177,119,2,0,32,0,108,48,46,104,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,11,224,130,170,2,0,32,0,108,56,46,108,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,11,145,153,139,3,0,32,0,108,55,46,109,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,72,180,165,134,3,0,32,0,49,48,45,50,46,107,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,82,30,9,223,4,0,32,0,49,48,45,49,46,102,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,143,13,100,64,4,0,32,0,49,48,45,51,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,80,58,250,39,4,0,0,8,121,116,122,121,95,118,50,48,49,99,110,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,160,94,112,243,1,0,16,1,116,48,54,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,214,26,204,74,2,0,32,0,97,48,54,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,52,120,22,216,3,0,32,0,97,48,54,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,115,67,122,255,3,0,32,0,97,48,54,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,89,41,163,231,3,0,32,0,97,48,53,52,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,62,65,211,79,3,0,32,0,98,48,54,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,89,208,60,125,4,0,32,0,98,48,53,52,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,87,151,153,96,4,0,32,0,109,48,54,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,214,79,218,58,5,0,64,0,107,111,118,115,104,95,118,49,48,48,95,99,104,105,110,97,46,97,115,105,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,193,165,9,15,7,0,16,1,112,48,54,48,48,104,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,228,232,81,226,1,0,16,1,116,48,54,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,214,26,204,74,2,0,32,0,97,48,54,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,52,120,22,216,3,0,32,0,97,48,54,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,115,67,122,255,3,0,32,0,97,48,54,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,89,41,163,231,3,0,32,0,97,48,53,52,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,62,65,211,79,3,0,32,0,98,48,54,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,89,208,60,125,4,0,32,0,98,48,53,52,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,87,151,153,96,4,0,32,0,109,48,54,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,214,79,218,58,5,0,64,0,107,111,118,115,104,95,118,49,48,48,95,99,104,105,110,97,46,97,115,105,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,193,165,9,15,7,0,16,1,112,48,54,48,48,46,49,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,93,135,176,228,1,0,16,1,116,48,54,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,214,26,204,74,2,0,32,0,97,48,54,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,52,120,22,216,3,0,32,0,97,48,54,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,115,67,122,255,3,0,32,0,97,48,54,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,89,41,163,231,3,0,32,0,97,48,54,48,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,218,171,49,236,3,0,32,0,98,48,54,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,89,208,60,125,4,0,32,0,98,48,54,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,47,28,187,160,4,0,32,0,109,48,54,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,214,79,218,58,5,0,64,0,107,111,118,95,105,103,115,48,50,55,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,7,0,16,17,117,49,56,46,49,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,217,26,5,64,1,0,16,1,116,49,50,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,9,102,226,215,2,0,32,0,97,49,50,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,216,129,235,206,3,0,32,0,97,49,50,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,167,60,6,33,3,0,32,0,97,49,50,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,174,47,185,75,3,0,32,0,97,49,50,48,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,39,182,60,231,3,0,32,0,97,49,50,48,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,187,181,180,20,3,0,32,0,98,49,50,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,148,217,215,190,4,0,32,0,98,49,50,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,87,235,81,242,4,0,32,0,109,49,50,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,32,135,216,176,5,0,64,0,107,111,118,50,95,118,49,48,48,95,104,111,110,103,107,111,110,103,46,97,115,105,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,159,103,215,224,7,0,16,1,117,49,57,46,49,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,128,41,46,70,8,0,16,1,117,49,56,46,49,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,118,47,195,152,1,0,16,1,116,49,50,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,9,102,226,215,2,0,32,0,97,49,50,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,216,129,235,206,3,0,32,0,97,49,50,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,167,60,6,33,3,0,32,0,97,49,50,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,174,47,185,75,3,0,32,0,97,49,50,48,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,39,182,60,231,3,0,32,0,97,49,50,48,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,187,181,180,20,3,0,32,0,98,49,50,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,148,217,215,190,4,0,32,0,98,49,50,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,87,235,81,242,4,0,32,0,109,49,50,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,32,135,216,176,5,0,64,0,107,111,118,50,95,118,49,48,48,95,104,111,110,103,107,111,110,103,46,97,115,105,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,159,103,215,224,7,0,16,1,117,49,57,46,49,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,254,242,53,140,8,0,16,1,117,49,56,46,49,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,55,156,72,162,1,0,16,1,116,49,50,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,9,102,226,215,2,0,32,0,97,49,50,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,216,129,235,206,3,0,32,0,97,49,50,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,167,60,6,33,3,0,32,0,97,49,50,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,174,47,185,75,3,0,32,0,97,49,50,48,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,39,182,60,231,3,0,32,0,97,49,50,48,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,187,181,180,20,3,0,32,0,98,49,50,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,148,217,215,190,4,0,32,0,98,49,50,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,87,235,81,242,4,0,32,0,109,49,50,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,32,135,216,176,5,0,64,0,107,111,118,50,95,118,49,48,48,95,104,111,110,103,107,111,110,103,46,97,115,105,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,159,103,215,224,7,0,16,1,117,49,57,46,49,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,254,242,53,140,8,0,16,1,117,49,56,46,49,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,53,111,146,201,1,0,16,1,116,49,50,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,9,102,226,215,2,0,32,0,97,49,50,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,216,129,235,206,3,0,32,0,97,49,50,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,167,60,6,33,3,0,32,0,97,49,50,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,174,47,185,75,3,0,32,0,97,49,50,48,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,39,182,60,231,3,0,32,0,97,49,50,48,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,187,181,180,20,3,0,32,0,98,49,50,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,148,217,215,190,4,0,32,0,98,49,50,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,87,235,81,242,4,0,32,0,109,49,50,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,32,135,216,176,5,0,64,0,107,111,118,50,95,118,49,48,48,95,104,111,110,103,107,111,110,103,46,97,115,105,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,159,103,215,224,7,0,16,1,117,49,57,46,49,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,254,242,53,140,8,0,16,1,105,103,115,95,117,49,56,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,121,88,32,134,1,0,16,1,116,49,50,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,9,102,226,215,2,0,32,0,97,49,50,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,216,129,235,206,3,0,32,0,97,49,50,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,167,60,6,33,3,0,32,0,97,49,50,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,174,47,185,75,3,0,32,0,97,49,50,48,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,39,182,60,231,3,0,32,0,97,49,50,48,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,187,181,180,20,3,0,32,0,98,49,50,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,148,217,215,190,4,0,32,0,98,49,50,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,87,235,81,242,4,0,32,0,109,49,50,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,32,135,216,176,5,0,64,0,107,111,118,50,95,118,49,48,48,95,104,111,110,103,107,111,110,103,46,97,115,105,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,159,103,215,224,7,0,16,1,117,49,57,46,49,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,34,153,213,237,8,0,16,1,56,48,48,98,48,49,46,49,48,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,220,131,15,82,1,0,16,1,56,48,48,97,48,50,46,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,113,65,96,109,2,0,32,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,34,18,0,0,74,49,0,0,224,21,0,0,166,34,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,190,10,0,0,146,25,0,0,98,0,0,0,98,0,0,0,128,10,0,0,226,19,0,0,98,0,0,0,98,0,0,0,10,25,0,0,48,31,0,0,98,0,0,0,98,0,0,0,106,10,0,0,66,17,0,0,98,0,0,0,98,0,0,0,28,27,0,0,120,12,0,0,98,0,0,0,98,0,0,0,40,4,0,0,206,29,0,0,98,0,0,0,98,0,0,0,128,34,0,0,64,0,0,0,98,0,0,0,98,0,0,0,222,19,0,0,138,9,0,0,98,0,0,0,98,0,0,0,4,25,0,0,46,27,0,0,98,0,0,0,98,0,0,0,34,37,0,0,130,39,0,0,98,0,0,0,118,13,0,0,58,24,0,0,114,24,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,22,7,0,0,98,0,0,0,62,36,0,0,98,0,0,0,124,35,0,0,98,0,0,0,62,1,0,0,98,0,0,0,200,49,0,0,98,0,0,0,194,44,0,0,98,0,0,0,92,31,0,0,98,0,0,0,46,29,0,0,98,0,0,0,146,44,0,0,98,0,0,0,12,2,0,0,98,0,0,0,92,42,0,0,98,0,0,0,98,49,0,0,134,6,0,0,56,3,0,0,54,36,0,0,150,42,0,0,42,20,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,242,22,0,0,98,0,0,0,98,0,0,0,190,42,0,0,98,0,0,0,98,0,0,0,230,28,0,0,98,0,0,0,98,0,0,0,22,10,0,0,98,0,0,0,98,0,0,0,96,37,0,0,98,0,0,0,98,0,0,0,98,0,0,0,88,7,0,0,98,0,0,0,98,0,0,0,122,26,0,0,98,0,0,0,98,0,0,0,10,46,0,0,98,0,0,0,98,0,0,0,192,5,0,0,98,0,0,0,98,0,0,0,20,35,0,0,98,0,0,0,98,0,0,0,98,0,0,0,16,5,0,0,188,9,0,0,246,5,0,0,148,45,0,0,114,8,0,0,44,1,0,0,242,34,0,0,102,9,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,2,25,0,0,98,0,0,0,18,23,0,0,98,0,0,0,130,36,0,0,98,0,0,0,112,17,0,0,98,0,0,0,244,2,0,0,98,0,0,0,80,20,0,0,98,0,0,0,226,15,0,0,98,0,0,0,238,29,0,0,98,0,0,0,216,38,0,0,98,0,0,0,200,31,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,53,50,51,50,45,112,49,112,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,83,244,56,3,1,0,16,1,53,50,51,50,45,112,50,112,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,32,176,2,85,1,0,16,1,53,50,51,50,45,115,49,112,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,186,233,113,98,2,0,32,0,53,50,51,50,45,99,49,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,10,155,171,78,3,0,32,0,53,50,51,50,45,99,50,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,208,143,127,105,3,0,32,0,53,50,51,50,45,99,49,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,243,253,67,17,3,0,32,0,53,50,51,50,45,99,50,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,143,207,130,234,3,0,32,0,53,50,51,50,45,99,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,7,190,209,171,3,0,32,0,53,50,51,50,45,99,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,123,150,189,210,3,0,32,0,50,51,50,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,71,135,52,69,4,0,16,1,50,51,50,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,181,181,162,34,5,0,64,0,50,51,50,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,68,231,4,35,5,0,64,0,50,51,50,45,118,51,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,84,185,158,117,5,0,64,0,50,52,50,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,137,223,147,136,1,0,16,1,50,52,50,45,112,50,46,115,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,76,186,10,152,1,0,16,1,50,52,50,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,5,72,123,127,2,0,32,0,50,52,50,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,214,236,100,229,3,0,32,0,50,52,50,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,96,155,149,189,3,0,32,0,50,52,50,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,79,123,18,34,3,0,32,0,50,52,50,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,68,160,79,11,3,0,32,0,50,52,50,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,211,190,16,157,3,0,32,0,50,52,50,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,162,182,7,218,3,0,32,0,50,52,50,45,99,55,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,138,163,215,246,3,0,32,0,50,52,50,45,99,56,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,69,224,35,200,3,0,32,0,50,52,50,45,109,103,49,107,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,124,176,159,206,4,0,16,1,50,52,50,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,81,128,234,185,5,0,64,0,50,52,50,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,110,16,17,204,5,0,64,0,50,52,50,45,118,51,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,225,164,78,4,5,0,64,0,50,52,50,45,118,52,46,118,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,48,234,133,121,5,0,64,0,50,52,50,45,112,49,97,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,102,140,24,201,1,0,16,1,50,52,50,45,112,50,97,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,0,107,172,159,96,1,0,16,1,50,52,50,45,115,49,97,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,192,229,254,241,2,0,32,0,50,52,50,45,99,49,97,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,201,207,25,3,3,0,32,0,50,52,50,45,99,50,97,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,20,103,63,85,3,0,32,0,50,52,50,45,99,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,79,123,18,34,3,0,32,0,50,52,50,45,99,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,68,160,79,11,3,0,32,0,50,52,50,45,99,53,97,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,24,23,100,113,3,0,32,0,50,52,50,45,99,54,97,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,179,162,43,152,3,0,32,0,50,52,50,45,99,55,97,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,82,85,73,141,3,0,32,0,50,52,50,45,99,56,97,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,23,52,252,139,3,0,32,0,50,52,50,45,99,57,97,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,209,86,130,18,3,0,32,0,50,52,50,45,99,57,49,97,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,45,65,216,75,3,0,32,0,50,52,50,45,99,57,50,97,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,127,39,147,232,3,0,32,0,50,52,50,45,99,57,51,97,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,158,88,101,241,3,0,32,0,50,52,50,45,109,49,97,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,40,5,222,154,4,0,16,1,50,52,50,45,118,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,81,128,234,185,5,0,64,0,50,52,50,45,118,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,110,16,17,204,5,0,64,0,50,52,50,45,118,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,225,164,78,4,5,0,64,0,50,52,50,45,118,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,48,234,133,121,5,0,64,0,50,52,50,45,118,53,97,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,96,150,221,175,5,0,64,0,50,51,50,120,116,45,112,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,59,78,79,46,1,0,16,1,50,51,50,120,116,45,112,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,206,3,69,109,1,0,16,1,50,51,50,120,116,45,115,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,111,22,254,214,2,0,32,0,50,51,50,120,116,45,99,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,74,191,4,213,3,0,32,0,50,51,50,120,116,45,99,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,8,167,46,148,3,0,32,0,50,51,50,45,99,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,24,102,29,88,3,0,32,0,50,51,50,45,99,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,104,30,187,73,3,0,32,0,50,51,50,120,116,45,99,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,117,35,189,193,3,0,32,0,50,51,50,120,116,45,99,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,106,80,200,167,3,0,32,0,50,51,50,45,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,71,135,52,69,4,0,16,1,50,51,50,45,118,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,181,181,162,34,5,0,64,0,50,51,50,45,118,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,68,231,4,35,5,0,64,0,50,51,50,45,118,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,84,185,158,117,5,0,64,0,50,51,50,99,110,45,112,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,200,51,41,8,1,0,16,1,50,51,50,99,110,45,112,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,96,0,163,60,45,210,1,0,16,1,50,51,50,99,110,45,115,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,120,210,90,222,2,0,32,0,50,51,50,99,110,45,99,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,12,44,61,140,3,0,32,0,50,51,50,99,110,45,99,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,174,105,206,67,3,0,32,0,50,51,50,45,99,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,24,102,29,88,3,0,32,0,50,51,50,45,99,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,104,30,187,73,3,0,32,0,50,51,50,45,99,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,81,78,252,52,3,0,32,0,50,51,50,45,99,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,123,212,244,79,3,0,32,0,50,51,50,45,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,71,135,52,69,4,0,16,1,50,51,50,45,118,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,181,181,162,34,5,0,64,0,50,51,50,45,118,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,68,231,4,35,5,0,64,0,50,51,50,45,118,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,84,185,158,117,5,0,64,0,50,49,52,45,112,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,116,93,117,82,1,0,16,1,50,49,52,45,112,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,115,203,44,0,1,0,16,1,50,49,52,45,115,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,219,203,84,18,2,0,32,0,50,49,52,45,99,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,162,74,207,126,3,0,32,0,50,49,52,45,99,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,55,79,181,5,3,0,32,0,50,49,52,45,99,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,101,154,152,100,3,0,32,0,50,49,52,45,99,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,21,165,190,175,3,0,32,0,50,49,52,45,99,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,38,189,59,42,3,0,32,0,50,49,52,45,99,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,199,13,211,68,3,0,32,0,50,49,52,45,99,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,27,51,135,54,3,0,32,0,50,49,52,45,99,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,173,97,20,250,3,0,32,0,50,49,52,45,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,124,66,188,218,4,0,16,1,50,49,52,45,118,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,69,176,247,99,5,0,64,0,50,49,52,45,118,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,89,144,146,37,5,0,64,0,50,49,52,45,118,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,125,37,162,146,5,0,64,0,107,111,102,57,54,109,95,101,112,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,67,251,242,229,0,0,16,1,50,49,52,99,110,45,112,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,10,95,194,168,1,0,16,1,50,49,52,99,110,45,112,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,229,172,223,14,1,0,16,1,50,49,52,99,110,45,112,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,0,65,164,36,135,1,0,16,1,50,49,52,99,110,45,115,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,122,82,23,249,2,0,32,0,50,49,52,45,99,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,162,74,207,126,3,0,32,0,50,49,52,45,99,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,55,79,181,5,3,0,32,0,50,49,52,45,99,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,101,154,152,100,3,0,32,0,50,49,52,45,99,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,21,165,190,175,3,0,32,0,50,49,52,45,99,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,38,189,59,42,3,0,32,0,50,49,52,45,99,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,199,13,211,68,3,0,32,0,50,49,52,45,99,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,27,51,135,54,3,0,32,0,50,49,52,45,99,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,173,97,20,250,3,0,32,0,50,49,52,99,110,45,99,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,210,17,248,169,3,0,32,0,50,49,52,99,110,45,99,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,106,64,71,17,3,0,32,0,50,49,52,45,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,124,66,188,218,4,0,16,1,50,49,52,45,118,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,69,176,247,99,5,0,64,0,50,49,52,45,118,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,89,144,146,37,5,0,64,0,50,49,52,45,118,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,125,37,162,146,5,0,64,0,50,49,52,97,101,45,112,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,124,14,102,71,1,0,16,1,50,49,52,97,101,45,112,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,235,243,79,130,1,0,16,1,50,49,52,97,101,45,115,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,175,58,59,32,2,0,32,0,50,49,52,97,101,45,99,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,249,193,8,179,3,0,32,0,50,49,52,97,101,45,99,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,178,146,10,34,3,0,32,0,50,49,52,45,99,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,101,154,152,100,3,0,32,0,50,49,52,45,99,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,21,165,190,175,3,0,32,0,50,49,52,97,101,45,99,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,12,203,3,110,3,0,32,0,50,49,52,97,101,45,99,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,93,197,11,169,3,0,32,0,50,49,52,97,101,45,99,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,214,31,2,8,3,0,32,0,50,49,52,97,101,45,99,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,8,27,210,187,3,0,32,0,50,49,52,97,101,45,99,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,128,191,229,87,3,0,32,0,50,49,52,97,101,45,99,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,129,76,228,203,3,0,32,0,50,49,52,97,101,45,99,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,139,220,125,92,3,0,32,0,50,49,52,97,101,45,99,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,116,181,216,72,3,0,32,0,50,49,52,97,101,45,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,72,3,221,201,4,0,16,1,50,49,52,45,118,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,69,176,247,99,5,0,64,0,50,49,52,45,118,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,89,144,146,37,5,0,64,0,50,49,52,97,101,45,118,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,167,35,57,20,5,0,64,0,50,55,49,45,112,49,99,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,20,204,14,83,1,0,16,1,50,55,49,45,112,50,99,46,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,169,141,86,253,1,0,16,1,50,55,49,45,112,51,99,46,112,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,169,180,197,174,1,0,16,1,50,55,49,45,99,49,99,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,208,37,220,177,3,0,32,0,50,55,49,45,99,50,99,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,55,36,54,213,3,0,32,0,50,55,49,45,99,51,99,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,171,190,31,10,3,0,32,0,50,55,49,45,99,52,99,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,12,154,177,135,3,0,32,0,50,55,49,45,99,53,99,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,113,163,78,112,3,0,32,0,50,55,49,45,99,54,99,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,76,22,161,32,3,0,32,0,50,55,49,45,99,55,99,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,127,186,154,24,3,0,32,0,50,55,49,45,99,56,99,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,220,79,236,32,3,0,32,0,50,55,49,45,109,49,99,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,41,86,81,245,4,0,16,1,50,55,49,45,118,49,99,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,199,248,163,255,5,0,64,0,50,55,49,45,118,50,99,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,209,199,130,83,5,0,64,0,50,54,53,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,35,115,222,158,1,0,16,1,50,54,53,45,112,50,46,115,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,184,102,114,50,1,0,16,1,50,54,53,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,86,166,101,43,3,0,32,0,50,54,53,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,131,137,241,173,3,0,32,0,50,54,53,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,215,159,94,135,3,0,32,0,50,54,53,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,71,57,161,45,3,0,32,0,50,54,53,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,93,22,189,97,3,0,32,0,50,54,53,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,235,209,253,3,3,0,32,0])
.concat([50,54,53,45,99,55,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,216,73,39,26,3,0,32,0,50,54,53,45,99,56,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,73,181,11,171,3,0,32,0,50,54,53,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,50,166,170,133,4,0,16,1,50,54,53,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,245,243,232,21,5,0,64,0,50,54,53,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,249,214,65,218,5,0,64,0,50,54,50,45,112,49,45,48,56,45,101,48,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,13,117,129,147,1,0,16,1,50,54,50,45,112,50,45,48,56,45,101,48,46,115,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,41,131,13,142,1,0,16,1,50,54,50,45,99,49,45,48,56,45,101,48,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,90,120,204,153,3,0,32,0,50,54,50,45,99,50,45,48,56,45,101,48,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,191,140,54,80,3,0,32,0,50,54,50,45,99,51,45,48,56,45,101,48,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,135,255,20,251,3,0,32,0,50,54,50,45,99,52,45,48,56,45,101,48,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,248,250,151,67,3,0,32,0,50,54,50,45,99,53,45,48,56,45,101,48,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,228,75,242,145,3,0,32,0,50,54,50,45,99,54,45,48,56,45,101,48,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,3,68,30,163,3,0,32,0,50,54,50,45,99,55,45,48,56,45,101,48,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,236,209,217,84,3,0,32,0,50,54,50,45,99,56,45,48,56,45,101,48,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,107,154,40,89,3,0,32,0,50,54,53,45,50,54,50,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,159,17,248,167,4,0,16,1,50,54,50,45,118,49,45,48,56,45,101,48,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,207,158,212,131,5,0,64,0,50,54,50,45,118,50,45,48,56,45,101,48,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,67,24,63,0,5,0,64,0,50,54,50,45,118,51,45,48,56,45,101,48,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,190,141,227,42,5,0,64,0,50,54,50,45,118,52,45,48,56,45,101,48,46,118,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,217,77,236,38,5,0,64,0,110,101,111,45,115,109,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,187,230,198,113,9,0,16,1,50,53,55,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,76,123,148,96,1,0,16,1,50,53,55,45,112,50,46,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,21,196,126,27,1,0,16,1,50,53,55,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,250,205,241,206,3,0,32,0,50,53,55,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,3,0,191,247,3,0,32,0,50,53,55,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,96,101,30,16,3,0,32,0,50,53,55,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,177,193,47,189,3,0,32,0,50,53,55,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,18,84,119,137,3,0,32,0,50,53,55,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,213,0,114,250,3,0,32,0,50,53,55,45,99,55,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,228,31,161,125,3,0,32,0,50,53,55,45,99,56,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,11,166,175,177,3,0,32,0,50,53,55,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,19,145,116,75,4,0,16,1,50,53,55,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,71,232,205,23,5,0,64,0,50,53,55,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,255,32,251,26,5,0,64,0,50,53,55,45,118,51,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,106,3,5,70,5,0,64,0,50,53,55,45,118,52,46,118,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,107,189,75,118,5,0,64,0,107,102,49,48,45,112,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,67,12,253,177,1,0,16,1,107,102,49,48,45,99,49,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,100,3,188,59,3,0,32,0,107,102,49,48,45,99,50,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,117,0,35,145,3,0,32,0,107,102,49,48,45,99,49,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,40,252,171,181,3,0,32,0,107,102,49,48,45,99,50,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,225,198,196,108,3,0,32,0,107,102,49,48,45,99,51,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,22,74,61,91,3,0,32,0,107,102,49,48,45,99,52,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,155,65,243,198,3,0,32,0,107,102,49,48,45,99,51,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,25,186,43,157,3,0,32,0,107,102,49,48,45,99,52,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,203,80,64,90,3,0,32,0,107,102,49,48,45,99,53,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,225,209,137,162,3,0,32,0,107,102,49,48,45,99,54,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,93,75,73,230,3,0,32,0,107,102,49,48,45,99,53,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,2,255,79,64,3,0,32,0,107,102,49,48,45,99,54,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,158,252,204,242,3,0,32,0,107,102,49,48,45,99,55,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,168,197,121,190,3,0,32,0,107,102,49,48,45,99,56,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,164,44,149,165,3,0,32,0,107,102,49,48,45,99,55,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,66,53,219,63,3,0,32,0,107,102,49,48,45,99,56,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,82,122,27,102,3,0,32,0,107,102,49,48,45,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,89,184,250,246,4,0,16,1,107,102,49,48,45,118,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,141,165,201,15,5,0,64,0,107,102,49,48,45,118,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,164,117,196,184,5,0,64,0,112,48,51,48,48,95,118,49,48,57,46,117,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,21,226,206,47,1,0,16,1,116,48,51,48,48,46,117,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,217,247,34,9,2,0,32,0,97,48,51,48,48,46,117,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,211,85,148,63,3,0,32,0,97,48,51,48,49,46,117,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,137,104,119,146,3,0,32,0,97,48,51,48,51,46,117,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,105,204,245,51,3,0,32,0,97,48,51,48,54,46,117,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,142,138,1,204,3,0,32,0,97,48,51,48,55,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,57,46,119,188,3,0,32,0,98,48,51,48,48,46,117,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,129,105,135,127,4,0,32,0,98,48,51,48,50,46,117,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,2,197,169,238,4,0,32,0,98,48,51,48,51,46,117,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,46,101,169,119,4,0,32,0,109,48,51,48,48,46,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,149,150,21,147,5,0,64,0,107,98,95,117,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,99,174,62,222,0,0,16,1,46,0,0,0,255,255,23,0,0,0,0,0,0,0,0,0,254,0,6,0,144,165,4,0,46,0,0,0,1,255,22,0,80,65,1,0,46,0,0,0,1,255,23,0,232,41,1,0,46,0,0,0,1,255,24,0,192,20,3,0,46,0,0,0,1,255,25,0,176,20,3,0,46,0,0,0,1,255,32,0,56,50,1,0,46,0,0,0,1,255,33,0,224,32,1,0,50,107,51,45,112,49,112,108,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,18,65,184,7,1,0,16,1,50,107,51,45,112,51,98,108,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,255,203,10,55,1,0,16,1,50,107,51,45,112,50,98,108,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,82,252,4,156,1,0,16,1,50,107,51,45,115,49,112,108,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,54,138,84,173,2,0,32,0,50,55,49,45,99,49,99,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,208,37,220,177,3,0,32,0,50,55,49,45,99,50,99,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,55,36,54,213,3,0,32,0,50,55,49,45,99,51,99,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,171,190,31,10,3,0,32,0,50,55,49,45,99,52,99,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,12,154,177,135,3,0,32,0,50,55,49,45,99,53,99,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,113,163,78,112,3,0,32,0,50,55,49,45,99,54,99,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,76,22,161,32,3,0,32,0,50,55,49,45,99,55,99,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,127,186,154,24,3,0,32,0,50,55,49,45,99,56,99,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,220,79,236,32,3,0,32,0,50,107,51,45,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,255,105,73,58,4,0,16,1,50,55,49,45,118,49,99,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,199,248,163,255,5,0,64,0,50,55,49,45,118,50,99,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,209,199,130,83,5,0,64,0,50,107,51,45,112,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,227,110,237,146,1,0,16,1,50,107,51,45,112,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,179,139,61,93,1,0,16,1,50,107,51,45,115,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,165,72,44,72,2,0,32,0,50,55,49,45,99,49,99,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,208,37,220,177,3,0,32,0,50,55,49,45,99,50,99,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,55,36,54,213,3,0,32,0,50,55,49,45,99,51,99,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,171,190,31,10,3,0,32,0,50,55,49,45,99,52,99,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,12,154,177,135,3,0,32,0,50,55,49,45,99,53,99,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,113,163,78,112,3,0,32,0,50,55,49,45,99,54,99,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,76,22,161,32,3,0,32,0,50,55,49,45,99,55,99,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,127,186,154,24,3,0,32,0,50,55,49,45,99,56,99,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,220,79,236,32,3,0,32,0,50,107,51,45,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,255,105,73,58,4,0,16,1,50,55,49,45,118,49,99,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,199,248,163,255,5,0,64,0,50,55,49,45,118,50,99,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,209,199,130,83,5,0,64,0,107,102,48,50,109,45,112,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,192,110,124,255,1,0,16,1,107,102,48,50,109,45,112,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,22,71,88,145,1,0,16,1,107,102,48,50,109,45,115,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,44,111,141,52,2,0,32,0,50,54,53,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,86,166,101,43,3,0,32,0,50,54,53,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,131,137,241,173,3,0,32,0,50,54,53,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,215,159,94,135,3,0,32,0,50,54,53,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,71,57,161,45,3,0,32,0,50,54,53,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,93,22,189,97,3,0,32,0,50,54,53,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,235,209,253,3,3,0,32,0,50,54,53,45,99,55,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,216,73,39,26,3,0,32,0,50,54,53,45,99,56,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,73,181,11,171,3,0,32,0,50,54,53,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,50,166,170,133,4,0,16,1,50,54,53,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,245,243,232,21,5,0,64,0,50,54,53,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,249,214,65,218,5,0,64,0,50,107,49,45,112,49,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,111,27,167,248,1,0,16,1,50,54,50,45,112,103,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,98,160,238,145,1,0,16,1,50,107,49,45,115,49,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,235,110,152,80,2,0,32,0,50,54,50,45,99,49,45,48,56,45,101,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,90,120,204,153,3,0,32,0,50,54,50,45,99,50,45,48,56,45,101,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,191,140,54,80,3,0,32,0,50,54,50,45,99,51,45,48,56,45,101,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,135,255,20,251,3,0,32,0,50,54,50,45,99,52,45,48,56,45,101,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,248,250,151,67,3,0,32,0,50,54,50,45,99,53,45,48,56,45,101,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,228,75,242,145,3,0,32,0,50,54,50,45,99,54,45,48,56,45,101,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,3,68,30,163,3,0,32,0,50,54,50,45,99,55,45,48,56,45,101,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,236,209,217,84,3,0,32,0,50,54,50,45,99,56,45,48,56,45,101,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,107,154,40,89,3,0,32,0,50,54,53,45,50,54,50,45,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,159,17,248,167,4,0,16,1,50,54,50,45,118,49,45,48,56,45,101,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,207,158,212,131,5,0,64,0,50,54,50,45,118,50,45,48,56,45,101,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,67,24,63,0,5,0,64,0,50,54,50,45,118,51,45,48,56,45,101,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,190,141,227,42,5,0,64,0,50,54,50,45,118,52,45,48,56,45,101,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,217,77,236,38,5,0,64,0,102,116,45,48,48,49,45,48,48,49,46,117,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,125,30,134,55,1,0,16,1,102,116,45,48,48,49,45,48,48,50,46,117,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,239,212,49,245,1,0,16,1,102,116,45,48,48,49,45,48,48,51,46,117,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,251,34,251,98,3,0,32,0,102,116,45,48,48,49,45,48,48,52,46,117,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,152,140,144,105,3,0,32,0,102,116,45,48,48,49,45,48,48,53,46,117,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,50,100,222,3,0,32,0,102,116,45,48,48,49,45,48,48,54,46,117,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,174,14,80,156,3,0,32,0,102,116,45,48,48,49,45,48,48,55,46,117,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,240,172,141,201,6,0,64,0,102,116,45,48,48,49,45,48,48,56,46,117,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,55,182,196,185,6,0,64,0,168,86,7,0,1,0,0,0,91,191,145,0,248,191,2,0,24,38,7,0,1,0,0,0,93,191,145,0,184,160,2,0,56,210,6,0,1,0,0,0,96,251,146,0,192,135,2,0,24,163,6,0,1,0,0,0,97,251,146,0,240,108,2,0,152,122,6,0,1,0,0,0,98,251,146,0,96,82,2,0,192,72,6,0,1,0,0,0,99,251,146,0,32,56,2,0,200,110,3,0,1,0,0,0,100,251,146,0,152,30,2,0,120,89,3,0,1,0,0,0,101,251,146,0,232,10,2,0,120,74,3,0,1,0,0,0,102,251,146,0,152,138,8,0,40,246,1,0,1,0,0,0,92,191,145,0,64,246,1,0,144,236,1,0,1,0,0,0,94,191,145,0,136,224,1,0,176,223,1,0,1,0,0,0,48,243,146,0,72,198,1,0,192,209,1,0,1,0,0,0,49,243,146,0,24,182,1,0,24,198,1,0,1,0,0,0,50,243,146,0,40,167,1,0,120,189,1,0,1,0,0,0,51,243,146,0,200,149,1,0,224,22,1,0,1,0,0,0,52,243,146,0,56,126,1,0,160,14,1,0,1,0,0,0,53,243,146,0,32,101,1,0,176,9,1,0,1,0,0,0,54,243,146,0,96,32,8,0,88,212,3,0,1,0,0,0,24,216,146,0,40,185,3,0,32,77,1,0,1,0,0,0,88,191,145,0,216,70,1,0,72,65,1,0,9,0,0,0,139,223,146,0,32,58,1,0,48,50,1,0,9,0,0,0,140,223,146,0,32,58,1,0,224,41,1,0,9,0,0,0,141,223,146,0,32,58,1,0,48,54,54,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,34,253,134,140,1,0,16,1,48,54,54,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,229,213,229,186,2,0,32,0,48,54,54,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,97,224,223,9,3,0,32,0,48,54,54,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,42,104,246,224,3,0,32,0,48,54,54,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,247,180,115,166,3,0,32,0,48,54,54,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,244,197,61,203,3,0,32,0,48,54,54,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,93,120,40,154,3,0,32,0,48,54,54,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,237,1,92,193,3,0,32,0,48,54,54,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,228,234,11,3,4,0,16,1,48,54,54,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,122,163,126,11,5,0,64,0,107,97,114,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,104,226,23,62,1,0,16,1,107,97,114,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,109,147,124,65,1,0,16,1,100,110,48,55,45,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,27,41,20,252,1,0,16,1,100,110,49,48,45,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,55,78,163,164,1,0,16,1,107,97,114,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,149,225,65,198,1,0,16,1,107,97,114,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,141,101,32,212,1,0,16,1,107,97,114,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,241,88,145,124,2,0,16,1,100,110,48,48,45,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,109,124,215,14,3,0,32,0,100,110,48,52,45,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,83,22,18,169,4,0,32,0,100,110,48,49,45,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,158,124,105,24,4,0,32,0,100,110,48,51,45,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,156,221,217,144,4,0,32,0,100,110,48,50,45,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,185,215,4,30,4,0,32,0,100,110,49,50,45,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,44,119,6,152,5,0,32,0,107,97,114,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,149,149,179,198,5,0,32,0,100,110,49,51,45,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,249,8,51,160,5,0,32,0,107,97,114,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,192,202,114,47,5,0,32,0,100,110,49,54,45,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,17,58,230,85,5,0,32,0,107,97,114,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,15,199,81,120,5,0,32,0,100,110,49,56,45,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,19,50,213,42,5,0,32,0,107,97,114,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,187,116,193,123,5,0,32,0,107,97,114,110,112,114,111,109,46,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,147,187,176,170,6,0,32,0,107,97,114,110,112,114,111,109,46,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,251,143,247,2,6,0,32,0,107,97,114,110,111,118,106,95,105,56,55,53,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,24,100,110,48,56,45,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,100,194,146,219,1,0,16,1,100,110,49,49,45,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,75,155,102,5,1,0,16,1,100,110,48,55,45,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,27,41,20,252,1,0,16,1,100,110,49,48,45,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,55,78,163,164,1,0,16,1,100,110,48,54,45,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,66,78,214,41,1,0,16,1,100,110,48,57,45,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,73,124,45,7,1,0,16,1,100,110,48,53,45,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,168,49,26,250,2,0,16,1,100,110,48,48,45,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,109,124,215,14,3,0,32,0,100,110,48,52,45,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,83,22,18,169,4,0,32,0,100,110,48,49,45,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,158,124,105,24,4,0,32,0,100,110,48,51,45,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,156,221,217,144,4,0,32,0,100,110,48,50,45,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,185,215,4,30,4,0,32,0,100,110,49,50,45,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,44,119,6,152,5,0,32,0,100,110,49,52,45,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,50,103,158,172,5,0,32,0,100,110,49,51,45,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,249,8,51,160,5,0,32,0,100,110,49,53,45,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,184,252,51,137,5,0,32,0,100,110,49,54,45,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,17,58,230,85,5,0,32,0,100,110,49,55,45,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,80,233,10,183,5,0,32,0,100,110,49,56,45,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,19,50,213,42,5,0,32,0,100,110,49,57,45,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,64,250,212,143,5,0,32,0,107,97,114,110,112,114,111,109,46,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,147,187,176,170,6,0,32,0,107,97,114,110,112,114,111,109,46,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,251,143,247,2,6,0,32,0,107,97,114,110,111,118,95,105,56,55,53,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,24,101,118,101,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,56,226,12,253,1,0,16,1,111,100,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,220,60,23,190,1,0,16,1,115,110,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,117,51,221,254,2,0,16,1,98,107,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,138,85,184,92,3,0,32,0,98,107,103,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,124,41,255,149,3,0,32,0,98,107,103,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,178,241,129,108,3,0,32,0,111,98,106,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,169,117,141,95,4,0,32,0,111,98,106,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,125,233,126,150,4,0,32,0,111,98,106,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,249,34,252,233,4,0,32,0,111,98,106,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,78,176,158,211,4,0,32,0,111,98,106,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,165,53,236,193,4,0,32,0,111,98,106,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,135,172,193,106,4,0,32,0,118,111,105,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,128,106,80,198,5,0,64,0,98,51,53,45,48,57,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,213,55,150,130,1,0,16,1,98,51,53,45,49,48,46,57,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,125,69,80,177,1,0,16,1,98,51,53,45,49,49,46,52,51,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,252,147,208,100,2,0,16,1,98,51,53,45,48,49,46,49,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,105,58,216,1,4,0,32,0,98,51,53,45,48,50,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,172,71,175,216,4,0,32,0,98,51,53,45,48,51,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,151,135,182,60,4,0,32,0,98,51,53,45,48,52,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,145,63,192,113,4,0,32,0,98,51,53,45,48,53,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,8,12,226,164,4,0,32,0,98,51,53,45,48,54,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,88,182,138,63,4,0,32,0,98,51,53,45,48,55,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,73,240,74,27,4,0,32,0,98,51,53,45,48,56,46,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,140,38,178,222,4,0,32,0,98,51,53,45,49,50,46,57,56,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,241,9,68,24,6,0,64,0,98,51,53,95,49,54,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,3,118,246,28,1,0,16,1,98,51,53,45,49,48,46,57,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,125,69,80,177,1,0,16,1,98,51,53,45,49,49,46,52,51,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,252,147,208,100,2,0,16,1,98,51,53,45,48,49,46,49,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,105,58,216,1,4,0,32,0,98,51,53,45,48,50,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,172,71,175,216,4,0,32,0,98,51,53,45,48,51,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,151,135,182,60,4,0,32,0,98,51,53,45,48,52,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,145,63,192,113,4,0,32,0,98,51,53,45,48,53,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,8,12,226,164,4,0,32,0,98,51,53,45,48,54,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,88,182,138,63,4,0,32,0,98,51,53,45,48,55,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,73,240,74,27,4,0,32,0,98,51,53,45,48,56,46,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,140,38,178,222,4,0,32,0,98,51,53,45,49,50,46,57,56,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,241,9,68,24,6,0,64,0,106,111,106,111,95,97,115,105,97,95,110,111,99,100,46,50,57,102,52,48,48,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,83,249,180,5,0,0,0,3,106,111,106,111,40,95,95,57,56,49,50,48,50,41,45,115,105,109,109,49,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,134,168,107,224,0,0,16,1,106,111,106,111,40,95,95,57,56,49,50,48,50,41,45,115,105,109,109,49,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,200,119,209,109,0,0,16,1,106,111,106,111,40,95,95,57,56,49,50,48,50,41,45,115,105,109,109,49,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,224,21,90,211,0,0,16,1,106,111,106,111,40,95,95,57,56,49,50,48,50,41,45,115,105,109,109,49,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,172,101,216,102,0,0,16,1,106,111,106,111,40,95,95,57,56,49,50,48,50,41,45,115,105,109,109,50,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,193,93,126,65,0,0,16,1,106,111,106,111,40,95,95,57,56,49,50,48,50,41,45,115,105,109,109,50,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,135,200,145,200,0,0,16,1,106,111,106,111,40,95,95,57,56,49,50,48,50,41,45,115,105,109,109,50,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,48,31,16,30,0,0,16,1,106,111,106,111,40,95,95,57,56,49,50,48,50,41,45,115,105,109,109,50,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,228,211,209,31,0,0,16,1,106,111,106,111,45,115,105,109,109,51,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,193,201,127,222,0,0,32,0,106,111,106,111,45,115,105,109,109,51,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,211,83,208,67,0,0,32,0,106,111,106,111,45,115,105,109,109,51,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,165,127,253,47,0,0,32,0,106,111,106,111,45,115,105,109,109,51,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,91,152,164,77,0,0,32,0,106,111,106,111,45,115,105,109,109,51,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,114,141,233,253,0,0,32,0,106,111,106,111,45,115,105,109,109,51,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,102,162,178,237,0,0,32,0,106,111,106,111,45,115,105,109,109,51,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,25,243,124,190,0,0,32,0,106,111,106,111,45,115,105,109,109,51,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,159,26,254,86,0,0,32,0,106,111,106,111,45,115,105,109,109,52,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,104,191,231,196,0,0,32,0,106,111,106,111,45,115,105,109,109,52,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,25,39,43,182,0,0,32,0,106,111,106,111,45,115,105,109,109,52,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,9,88,209,24,0,0,32,0,106,111,106,111,45,115,105,109,109,52,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,121,173,240,154,0,0,32,0,106,111,106,111,45,115,105,109,109,52,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,240,193,36,65,0,0,32,0,106,111,106,111,45,115,105,109,109,52,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,209,31,0,94,0,0,32,0,106,111,106,111,45,115,105,109,109,52,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,59,162,255,154,0,0,32,0,106,111,106,111,45,115,105,109,109,52,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,42,87,17,37,0,0,32,0,106,111,106,111,45,115,105,109,109,53,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,252,21,118,121,0,0,32,0,106,111,106,111,45,115,105,109,109,53,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,98,209,79,115,0,0,32,0,106,111,106,111,95,97,115,105,97,95,110,111,99,100,46,50,57,102,52,48,48,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,83,249,180,5,0,0,0,3,106,111,106,111,40,95,95,57,57,48,49,48,56,41,45,115,105,109,109,49,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,214,56,188,207,0,0,16,1,106,111,106,111,40,95,95,57,57,48,49,48,56,41,45,115,105,109,109,49,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,148,141,87,66,0,0,16,1,106,111,106,111,40,95,95,57,57,48,49,48,56,41,45,115,105,109,109,49,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,102,197,64,27,0,0,16,1,106,111,106,111,40,95,95,57,57,48,49,48,56,41,45,115,105,109,109,49,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,180,9,167,187,0,0,16,1,106,111,106,111,40,95,95,57,57,48,49,48,56,41,45,115,105,109,109,50,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,193,93,126,65,0,0,16,1,106,111,106,111,40,95,95,57,57,48,49,48,56,41,45,115,105,109,109,50,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,125,38,179,211,0,0,16,1,106,111,106,111,40,95,95,57,57,48,49,48,56,41,45,115,105,109,109,50,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,177,150,109,198,0,0,16,1,106,111,106,111,40,95,95,57,57,48,49,48,56,41,45,115,105,109,109,50,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,133,204,52,170,0,0,16,1,106,111,106,111,45,115,105,109,109,51,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,193,201,127,222,0,0,32,0,106,111,106,111,45,115,105,109,109,51,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,211,83,208,67,0,0,32,0,106,111,106,111,45,115,105,109,109,51,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,165,127,253,47,0,0,32,0,106,111,106,111,45,115,105,109,109,51,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,91,152,164,77,0,0,32,0,106,111,106,111,45,115,105,109,109,51,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,114,141,233,253,0,0,32,0,106,111,106,111,45,115,105,109,109,51,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,102,162,178,237,0,0,32,0,106,111,106,111,45,115,105,109,109,51,46,54,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,25,243,124,190,0,0,32,0,106,111,106,111,45,115,105,109,109,51,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,159,26,254,86,0,0,32,0,106,111,106,111,45,115,105,109,109,52,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,104,191,231,196,0,0,32,0,106,111,106,111,45,115,105,109,109,52,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,25,39,43,182,0,0,32,0,106,111,106,111,45,115,105,109,109,52,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,9,88,209,24,0,0,32,0,106,111,106,111,45,115,105,109,109,52,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,121,173,240,154,0,0,32,0,106,111,106,111,45,115,105,109,109,52,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,240,193,36,65,0,0,32,0,106,111,106,111,45,115,105,109,109,52,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,209,31,0,94,0,0,32,0,106,111,106,111,45,115,105,109,109,52,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,59,162,255,154,0,0,32,0,106,111,106,111,45,115,105,109,109,52,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,42,87,17,37,0,0,32,0,106,111,106,111,45,115,105,109,109,53,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,252,21,118,121,0,0,32,0,106,111,106,111,45,115,105,109,109,53,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,98,209,79,115,0,0,32,0,106,111,106,111,95,106,97,112,97,110,46,50,57,102,52,48,48,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,96,143,119,2,0,0,0,3,106,111,106,111,40,95,95,57,56,49,50,48,50,41,45,115,105,109,109,49,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,134,168,107,224,0,0,16,1,106,111,106,111,40,95,95,57,56,49,50,48,50,41,45,115,105,109,109,49,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,200,119,209,109,0,0,16,1,106,111,106,111,40,95,95,57,56,49,50,48,50,41,45,115,105,109,109,49,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,224,21,90,211,0,0,16,1,106,111,106,111,40,95,95,57,56,49,50,48,50,41,45,115,105,109,109,49,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,172,101,216,102,0,0,16,1,106,111,106,111,40,95,95,57,56,49,50,48,50,41,45,115,105,109,109,50,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,193,93,126,65,0,0,16,1,106,111,106,111,40,95,95,57,56,49,50,48,50,41,45,115,105,109,109,50,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,135,200,145,200,0,0,16,1,106,111,106,111,40,95,95,57,56,49,50,48,50,41,45,115,105,109,109,50,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,48,31,16,30,0,0,16,1,106,111,106,111,40,95,95,57,56,49,50,48,50,41,45,115,105,109,109,50,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,228,211,209,31,0,0,16,1,106,111,106,111,45,115,105,109,109,51,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,193,201,127,222,0,0,32,0,106,111,106,111,45,115,105,109,109,51,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,211,83,208,67,0,0,32,0,106,111,106,111,45,115,105,109,109,51,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,165,127,253,47,0,0,32,0,106,111,106,111,45,115,105,109,109,51,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,91,152,164,77,0,0,32,0,106,111,106,111,45,115,105,109,109,51,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,114,141,233,253,0,0,32,0,106,111,106,111,45,115,105,109,109,51,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,102,162,178,237,0,0,32,0,106,111,106,111,45,115,105,109,109,51,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,25,243,124,190,0,0,32,0,106,111,106,111,45,115,105,109,109,51,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,159,26,254,86,0,0,32,0,106,111,106,111,45,115,105,109,109,52,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,104,191,231,196,0,0,32,0,106,111,106,111,45,115,105,109,109,52,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,25,39,43,182,0,0,32,0,106,111,106,111,45,115,105,109,109,52,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,9,88,209,24,0,0,32,0,106,111,106,111,45,115,105,109,109,52,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,121,173,240,154,0,0,32,0,106,111,106,111,45,115,105,109,109,52,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,240,193,36,65,0,0,32,0,106,111,106,111,45,115,105,109,109,52,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,209,31,0,94,0,0,32,0,106,111,106,111,45,115,105,109,109,52,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,59,162,255,154,0,0,32,0,106,111,106,111,45,115,105,109,109,52,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,42,87,17,37,0,0,32,0,106,111,106,111,45,115,105,109,109,53,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,252,21,118,121,0,0,32,0,106,111,106,111,45,115,105,109,109,53,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,98,209,79,115,0,0,32,0,106,111,106,111,95,106,97,112,97,110,46,50,57,102,52,48,48,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,96,143,119,2,0,0,0,3,106,111,106,111,40,95,95,57,57,48,49,48,56,41,45,115,105,109,109,49,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,214,56,188,207,0,0,16,1,106,111,106,111,40,95,95,57,57,48,49,48,56,41,45,115,105,109,109,49,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,148,141,87,66,0,0,16,1,106,111,106,111,40,95,95,57,57,48,49,48,56,41,45,115,105,109,109,49,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,102,197,64,27,0,0,16,1,106,111,106,111,40,95,95,57,57,48,49,48,56,41,45,115,105,109,109,49,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,180,9,167,187,0,0,16,1,106,111,106,111,40,95,95,57,57,48,49,48,56,41,45,115,105,109,109,50,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,193,93,126,65,0,0,16,1,106,111,106,111,40,95,95,57,57,48,49,48,56,41,45,115,105,109,109,50,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,125,38,179,211,0,0,16,1,106,111,106,111,40,95,95,57,57,48,49,48,56,41,45,115,105,109,109,50,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,177,150,109,198,0,0,16,1,106,111,106,111,40,95,95,57,57,48,49,48,56,41,45,115,105,109,109,50,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,133,204,52,170,0,0,16,1,106,111,106,111,45,115,105,109,109,51,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,193,201,127,222,0,0,32,0,106,111,106,111,45,115,105,109,109,51,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,211,83,208,67,0,0,32,0,106,111,106,111,45,115,105,109,109,51,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,165,127,253,47,0,0,32,0,106,111,106,111,45,115,105,109,109,51,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,91,152,164,77,0,0,32,0,106,111,106,111,45,115,105,109,109,51,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,114,141,233,253,0,0,32,0,106,111,106,111,45,115,105,109,109,51,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,102,162,178,237,0,0,32,0,106,111,106,111,45,115,105,109,109,51,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,25,243,124,190,0,0,32,0,106,111,106,111,45,115,105,109,109,51,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,159,26,254,86,0,0,32,0,106,111,106,111,45,115,105,109,109,52,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,104,191,231,196,0,0,32,0,106,111,106,111,45,115,105,109,109,52,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,25,39,43,182,0,0,32,0,106,111,106,111,45,115,105,109,109,52,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,9,88,209,24,0,0,32,0,106,111,106,111,45,115,105,109,109,52,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,121,173,240,154,0,0,32,0,106,111,106,111,45,115,105,109,109,52,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,240,193,36,65,0,0,32,0,106,111,106,111,45,115,105,109,109,52,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,209,31,0,94,0,0,32,0,106,111,106,111,45,115,105,109,109,52,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,59,162,255,154,0,0,32,0,106,111,106,111,45,115,105,109,109,52,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,42,87,17,37,0,0,32,0,106,111,106,111,45,115,105,109,109,53,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,252,21,118,121,0,0,32,0,106,111,106,111,45,115,105,109,109,53,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,98,209,79,115,0,0,32,0,106,111,106,111,98,97,95,106,97,112,97,110,95,110,111,99,100,46,50,57,102,52,48,48,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,245,25,171,77,0,0,0,3,106,111,106,111,98,97,40,95,95,57,57,48,57,50,55,41,45,115,105,109,109,49,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,119,131,205,173,0,0,16,1,106,111,106,111,98,97,40,95,95,57,57,48,57,50,55,41,45,115,105,109,109,49,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,89,11,89,215,0,0,16,1,106,111,106,111,98,97,40,95,95,57,57,48,57,50,55,41,45,115,105,109,109,49,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,11,36,46,230,0,0,16,1,106,111,106,111,98,97,40,95,95,57,57,48,57,50,55,41,45,115,105,109,109,49,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,195,80,84,201,0,0,16,1,106,111,106,111,98,97,40,95,95,57,57,48,57,50,55,41,45,115,105,109,109,50,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,186,46,95,83,0,0,16,1,106,111,106,111,98,97,40,95,95,57,57,48,57,50,55,41,45,115,105,109,109,50,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,1,58,221,1,0,0,16,1,106,111,106,111,98,97,40,95,95,57,57,48,57,50,55,41,45,115,105,109,109,50,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,114,38,67,97,0,0,16,1,106,111,106,111,98,97,40,95,95,57,57,48,57,50,55,41,45,115,105,109,109,50,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,202,154,220,172,0,0,16,1,106,111,106,111,98,97,45,115,105,109,109,51,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,17,225,22,77,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,51,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,211,6,52,155,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,51,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,151,73,65,242,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,51,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,125,156,75,149,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,51,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,29,220,90,98,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,51,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,180,11,167,32,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,51,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,175,197,14,161,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,51,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,122,222,208,11,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,52,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,220,74,161,110,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,52,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,251,66,76,143,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,52,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,209,134,5,239,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,52,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,112,196,204,147,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,52,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,210,199,158,61,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,52,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,80,104,230,3,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,52,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,195,106,96,1,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,52,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,135,43,57,54,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,53,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,12,198,248,46,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,53,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,166,124,125,207,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,53,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,250,91,129,183,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,53,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,73,192,254,155,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,53,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,107,83,103,209,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,53,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,66,160,231,85,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,53,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,6,41,179,79,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,53,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,32,229,139,140,0,0,32,0,48,53,46,117,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,88,161,233,116,1,0,16,1,48,49,46,117,56,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,193,162,164,77,2,0,32,0,48,50,46,117,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,219,8,44,100,2,0,32,0,109,98,110,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,83,115,163,163,3,0,32,0,109,98,110,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,197,48,34,170,3,0,32,0,109,98,110,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,113,71,189,220,4,0,64,0,109,98,110,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,42,26,183,112,5,0,64,0,48,52,56,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,187,140,129,250,1,0,16,1,48,52,56,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,90,178,133,130,2,0,32,0,48,52,56,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,233,144,168,63,3,0,32,0,48,52,56,45,99,50,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,216,138,196,89,3,0,32,0,48,52,56,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,199,103,4,49,4,0,16,1,48,52,56,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,43,125,148,241,5,0,64,0,50,51,54,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,96,246,47,76,1,0,16,1,50,51,54,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,64,166,28,93,2,0,32,0,50,51,54,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,2,121,212,193,3,0,32,0,50,51,54,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,46,151,95,225,3,0,32,0,50,51,54,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,189,26,10,136,4,0,16,1,50,51,54,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,180,195,137,95,5,0,64,0,50,51,54,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,103,53,132,30,6,0,64,0,105,116,104,45,104,48,45,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,166,231,248,82,1,0,16,1,105,116,104,45,108,48,45,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,183,158,183,93,1,0,16,1,105,116,104,45,104,49,45,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,223,153,40,252,1,0,16,1,105,116,104,45,108,49,45,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,90,96,90,149,1,0,16,1,105,116,104,45,115,104,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,127,139,156,32,2,0,16,1,105,116,104,45,115,108,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,101,45,71,24,2,0,16,1,105,116,104,95,105,99,50,54,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,207,24,24,76,3,0,32,0,105,116,104,95,105,99,50,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,174,91,20,145,3,0,32,0,105,116,104,95,105,99,50,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,59,254,3,252,3,0,32,0,105,116,104,95,105,99,50,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,10,106,21,238,3,0,32,0,105,116,104,95,105,99,51,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,110,118,25,160,4,0,32,0,105,116,104,95,105,99,51,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,115,48,202,63,4,0,32,0,105,116,104,95,105,99,51,54,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,139,178,209,32,4,0,32,0,105,116,104,95,105,99,51,55,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,75,253,182,144,4,0,32,0,105,116,104,95,105,99,57,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,26,231,142,49,5,0,64,0,98,57,55,45,48,51,46,117,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,135,243,238,24,1,0,16,1,98,57,55,45,48,55,46,117,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,201,40,75,50,2,0,16,1,98,57,55,45,48,49,46,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,177,148,2,208,4,0,32,0,98,57,55,45,48,50,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,52,116,90,219,4,0,32,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,1,2,0,1,1,1,1,3,1,2,1,3,1,0,3,5,19,5,3,4,4,4,4,7,4,5,4,6,4,5,1,2,1,2,0,1,1,1,1,3,1,2,1,3,1,2,5,5,19,5,3,4,4,4,4,7,4,5,4,6,4,19,1,2,1,2,0,1,1,1,1,3,1,2,1,3,1,1,4,5,19,5,3,4,4,4,4,7,4,5,4,6,4,19,1,2,1,2,0,1,1,1,1,3,1,2,1,3,1,1,4,5,19,5,3,4,4,4,4,7,4,5,4,6,4,19,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,3,2,3,0,1,1,1,1,4,1,4,1,5,4,0,3,6,20,6,3,4,4,4,4,7,4,7,4,8,7,5,2,3,2,3,0,1,1,1,1,4,1,4,1,5,4,5,5,6,20,6,3,4,4,4,4,7,4,7,4,8,7,20,2,3,2,3,0,1,1,1,1,4,1,4,1,5,4,3,4,6,20,6,3,4,4,4,4,7,4,7,4,8,7,20,2,3,2,3,0,1,1,1,1,4,1,4,1,5,4,3,4,6,20,6,3,4,4,4,4,7,4,7,4,8,7,20,105,107,51,45,50,46,99,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,205,77,179,167,1,0,16,0,105,107,51,45,51,46,99,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,61,184,242,80,1,0,16,0,105,107,51,45,49,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,86,210,228,71,1,0,16,0,105,107,51,45,52,46,99,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,181,246,58,164,1,0,16,0,105,107,51,45,53,46,49,54,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,252,6,103,206,2,0,16,0,105,107,51,45,55,46,49,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,223,4,72,11,3,0,32,0,105,107,51,45,56,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,80,78,171,16,3,0,32,0,105,107,51,45,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,50,189,86,154,4,0,32,0,105,107,51,45,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,10,161,230,12,4,0,32,0,105,107,51,45,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,67,190,226,228,4,0,32,0,105,107,51,45,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,114,35,34,172,4,0,32,0,105,107,51,45,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,194,113,57,195,4,0,32,0,105,107,51,45,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,119,234,59,69,4,0,32,0,105,107,51,45,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,252,129,26,120,4,0,32,0,105,107,51,45,49,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,11,64,186,128,4,0,32,0,105,107,51,45,49,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,74,206,195,12,4,0,32,0,105,107,51,45,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,69,98,16,186,4,0,32,0,105,107,51,45,50,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,119,92,253,208,4,0,32,0,105,107,51,45,50,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,131,216,120,72,4,0,32,0,105,107,51,45,50,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,240,251,208,80,4,0,32,0,105,107,51,45,50,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,252,30,133,154,4,0,32,0,105,107,51,45,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,137,186,189,78,4,0,32,0,105,107,51,45,50,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,104,109,178,233,4,0,32,0,105,107,51,45,50,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,241,3,59,7,4,0,32,0,105,107,51,45,50,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,97,53,97,156,4,0,32,0,105,107,51,45,50,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,126,34,221,22,4,0,32,0,105,107,51,45,50,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,174,21,23,113,4,0,32,0,105,107,51,45,54,46,49,56,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,164,86,210,89,5,0,64,0,105,107,51,45,50,107,46,99,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,34,34,93,161,1,0,16,0,105,107,51,45,51,107,46,99,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,110,0,252,227,1,0,16,0,105,107,51,45,49,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,86,210,228,71,1,0,16,0,105,107,51,45,52,46,99,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,181,246,58,164,1,0,16,0,105,107,51,45,53,46,49,54,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,252,6,103,206,2,0,16,0,105,107,51,45,55,107,46,49,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,155,57,251,139,3,0,32,0,105,107,51,45,56,107,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,118,229,15,63,3,0,32,0,105,107,51,45,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,50,189,86,154,4,0,32,0,105,107,51,45,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,10,161,230,12,4,0,32,0,105,107,51,45,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,67,190,226,228,4,0,32,0,105,107,51,45,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,114,35,34,172,4,0,32,0,105,107,51,45,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,194,113,57,195,4,0,32,0,105,107,51,45,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,119,234,59,69,4,0,32,0,105,107,51,45,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,252,129,26,120,4,0,32,0,105,107,51,45,49,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,11,64,186,128,4,0,32,0,105,107,51,45,49,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,74,206,195,12,4,0,32,0,105,107,51,45,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,69,98,16,186,4,0,32,0,105,107,51,45,50,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,119,92,253,208,4,0,32,0,105,107,51,45,50,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,131,216,120,72,4,0,32,0,105,107,51,45,50,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,240,251,208,80,4,0,32,0,105,107,51,45,50,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,252,30,133,154,4,0,32,0,105,107,51,45,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,137,186,189,78,4,0,32,0,105,107,51,45,50,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,104,109,178,233,4,0,32,0,105,107,51,45,50,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,241,3,59,7,4,0,32,0,105,107,51,45,50,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,97,53,97,156,4,0,32,0,105,107,51,45,50,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,126,34,221,22,4,0,32,0,105,107,51,45,50,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,174,21,23,113,4,0,32,0,105,107,51,45,54,46,49,56,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,164,86,210,89,5,0,64,0,105,107,51,45,50,45,106,46,99,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,228,75,27,123,1,0,16,0,105,107,51,45,51,45,106,46,99,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,169,42,110,142,1,0,16,0,105,107,51,45,49,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,86,210,228,71,1,0,16,0,105,107,51,45,52,46,99,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,181,246,58,164,1,0,16,0,105,107,51,45,53,46,49,54,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,252,6,103,206,2,0,16,0,105,107,51,45,55,46,49,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,223,4,72,11,3,0,32,0,105,107,51,45,56,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,80,78,171,16,3,0,32,0,105,107,51,45,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,50,189,86,154,4,0,32,0,105,107,51,45,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,10,161,230,12,4,0,32,0,105,107,51,45,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,67,190,226,228,4,0,32,0,105,107,51,45,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,114,35,34,172,4,0,32,0,105,107,51,45,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,194,113,57,195,4,0,32,0,105,107,51,45,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,119,234,59,69,4,0,32,0,105,107,51,45,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,252,129,26,120,4,0,32,0,105,107,51,45,49,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,11,64,186,128,4,0,32,0,105,107,51,45,49,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,74,206,195,12,4,0,32,0,105,107,51,45,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,69,98,16,186,4,0,32,0,105,107,51,45,50,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,119,92,253,208,4,0,32,0,105,107,51,45,50,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,131,216,120,72,4,0,32,0,105,107,51,45,50,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,240,251,208,80,4,0,32,0,105,107,51,45,50,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,252,30,133,154,4,0,32,0,105,107,51,45,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,137,186,189,78,4,0,32,0,105,107,51,45,50,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,104,109,178,233,4,0,32,0,105,107,51,45,50,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,241,3,59,7,4,0,32,0,105,107,51,45,50,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,97,53,97,156,4,0,32,0,105,107,51,45,50,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,126,34,221,22,4,0,32,0,105,107,51,45,50,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,174,21,23,113,4,0,32,0,105,107,51,45,54,46,49,56,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,164,86,210,89,5,0,64,0,50,45,117,50,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,165,74,237,35,1,0,16,1,49,45,117,50,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,159,100,179,93,1,0,16,1,112,114,111,103,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,27,107,15,80,1,0,16,1,48,108,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,96,186,249,145,2,0,32,0,48,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,183,0,168,191,2,0,32,0,49,108,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,9,8,103,75,2,0,32,0,49,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,77,58,81,171,2,0,32,0,50,108,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,233,81,125,26,2,0,32,0,50,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,34,98,134,191,2,0,32,0,51,108,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,247,70,166,168,2,0,32,0,51,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,205,190,50,140,2,0,32,0,115,110,100,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,26,213,144,192,3,0,64,0,115,110,100,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,181,67,66,194,3,0,64,0,99,50,46,117,99,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,93,185,23,121,1,0,16,1,99,49,46,117,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,233,64,178,123,1,0,16,1,115,49,46,117,99,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,142,242,140,93,2,0,16,1,116,49,46,117,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,147,58,104,206,3,0,32,0,99,114,53,46,117,99,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,89,81,189,101,4,0,32,0,99,114,55,46,117,99,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,228,156,157,168,4,0,32,0,99,114,54,46,117,99,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,60,82,214,153,4,0,32,0,99,114,49,46,117,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,210,1,145,252,4,0,32,0,99,114,51,46,117,99,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,164,65,200,4,0,32,0,99,114,50,46,117,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,200,111,173,39,4,0,32,0,98,114,49,46,117,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,228,141,193,111,5,0,32,0,98,114,51,46,117,99,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,64,114,103,187,5,0,32,0,115,50,46,117,99,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,15,152,28,64,6,0,64,0,99,53,57,45,50,51,46,52,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,204,143,149,1,2,0,0,0,99,53,57,45,50,53,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,118,76,152,113,2,0,0,0,99,53,57,45,50,50,46,52,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,64,97,200,194,2,0,0,0,99,53,57,45,50,52,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,9,244,200,38,2,0,0,0,99,53,57,45,48,56,46,53,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,11,193,203,211,9,0,0,0,99,53,57,45,48,51,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,72,48,81,158,11,0,0,0,99,53,57,45,48,50,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,7,94,251,175,11,0,0,0,99,53,57,45,48,49,46,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,29,41,174,70,29,0,0,0,112,97,108,50,48,108,56,98,45,99,53,57,45,48,52,46,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,1,0,0,124,240,188,46,0,0,0,8,112,97,108,49,54,108,56,98,45,99,53,57,45,48,53,46,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,92,124,182,55,0,0,0,8,112,97,108,50,48,108,56,98,45,99,53,57,45,48,54,46,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,1,0,0,117,104,23,191,0,0,0,8,112,97,108,49,54,114,52,98,45,99,53,57,45,48,55,46,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,149,189,100,207,0,0,0,8,97,45,104,111,45,117,46,56,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,85,247,231,237,1,0,16,1,97,45,108,111,45,117,46,57,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,174,38,7,223,1,0,16,1,97,45,104,49,45,102,46,56,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,197,65,183,49,1,0,16,1,97,45,108,49,45,102,46,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,108,150,62,178,1,0,16,1,97,45,115,112,45,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,231,16,226,128,6,0,16,1,104,104,95,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,239,39,81,236,2,0,32,0,104,104,95,49,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,148,82,246,222,2,0,32,0,104,104,95,50,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,212,106,13,187,2,0,32,0,104,104,95,51,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,78,4,81,67,2,0,32,0,104,104,95,97,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,2,0,95,186,119,197,3,0,32,0,104,104,95,97,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,171,18,157,66,3,0,32,0,104,104,95,97,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,176,99,177,181,3,0,32,0,104,104,95,97,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,161,102,245,142,3,0,32,0,97,45,118,48,45,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,255,202,170,250,5,0,64,0,117,97,48,50,46,106,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,142,156,43,219,1,0,16,1,117,97,48,51,46,106,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,232,1,159,222,1,0,16,1,117,115,48,50,46,114,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,250,5,204,199,2,0,16,1,117,115,48,56,46,117,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,137,117,23,174,3,0,64,0,117,99,48,55,46,116,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,133,216,30,77,4,0,32,0,117,99,48,56,46,114,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,105,238,44,36,4,0,32,0,117,100,49,52,46,112,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,116,181,194,79,5,0,32,0,117,100,49,53,46,109,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,166,135,97,29,5,0,32,0,117,100,49,54,46,108,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,62,196,190,234,5,0,32,0,117,100,49,55,46,106,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,113,65,176,198,5,0,32,0,50,55,54,52,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,83,224,156,152,1,0,0,0,50,55,54,52,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,116,0,94,131,1,0,0,0,50,55,49,54,46,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,239,123,245,202,2,0,0,0,112,110,107,46,51,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,122,253,77,87,3,0,0,0,98,108,107,46,51,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,64,192,247,22,3,0,0,0,103,111,108,100,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,237,130,82,95,4,0,0,0,111,114,97,110,103,101,46,55,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,245,153,93,7,4,0,0,0,121,101,108,108,111,119,46,55,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,150,46,39,246,4,0,0,0,118,105,111,108,101,116,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,133,6,2,202,4,0,0,0,56,50,115,49,50,57,46,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,230,71,75,218,5,0,0,0,56,50,115,49,50,57,46,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,164,19,226,150,5,0,0,0,56,50,115,49,50,54,46,50,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,75,206,174,55,5,0,0,0,56,50,115,49,52,55,46,112,114,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,146,188,229,70,6,0,0,0,112,108,115,49,53,51,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,235,0,0,0,0,0,0,0,7,0,0,16,109,48,51,46,107,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,61,116,94,216,1,0,16,1,98,48,54,46,107,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,102,120,208,171,1,0,16,1,55,54,56,101,48,49,46,101,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,132,241,255,185,2,0,16,1,55,54,56,99,48,57,46,103,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,221,63,190,227,3,0,32,0,55,54,56,99,48,56,46,103,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,139,219,51,150,3,0,32,0,55,54,56,99,48,52,46,106,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,14,104,96,41,4,0,32,0,55,54,56,99,48,53,46,106,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,242,162,101,4,0,32,0,55,54,56,99,48,55,46,101,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,156,136,249,1,5,0,64,0,55,54,56,99,49,51,46,106,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,203,128,222,245,6,0,32,0,55,54,56,99,49,52,46,106,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,183,113,32,179,6,0,32,0,55,54,56,99,49,49,46,105,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,203,128,222,245,6,0,32,0,55,54,56,99,49,48,46,105,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,183,113,32,179,6,0,32,0,55,54,56,98,49,50,46,100,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,184,68,37,54,0,0,32,8,104,109,49,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,74,124,2,157,1,0,16,1,104,109,53,46,54,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,137,113,76,25,1,0,16,1,104,97,110,103,108,121,50,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,187,40,162,91,1,0,16,1,104,97,110,103,108,121,50,46,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,30,70,245,186,1,0,16,1,104,109,51,46,54,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,74,156,65,8,1,0,16,1,104,109,55,46,54,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,31,181,116,171,1,0,16,1,104,109,52,46,54,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,130,176,57,80,1,0,16,1,104,109,56,46,54,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,215,112,23,147,1,0,16,1,104,109,57,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,204,227,75,95,2,0,32,0,104,109,49,49,46,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,157,184,145,53,2,0,32,0,104,109,49,48,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,58,50,57,158,2,0,32,0,104,109,49,50,46,53,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,150,144,29,27,2,0,32,0,56,50,115,49,50,51,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,189,80,198,47,3,0,32,0,56,50,115,49,50,54,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,228,168,179,62,3,0,32,0,56,50,115,49,50,54,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,134,204,169,4,0,64,0,56,50,115,49,50,54,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,104,97,110,103,108,121,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,10,97,232,95,1,0,16,1,104,97,110,103,108,121,50,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,187,40,162,91,1,0,16,1,104,97,110,103,108,121,50,46,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,30,70,245,186,1,0,16,1,104,97,110,103,108,121,46,54,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,159,249,126,78,1,0,16,1,104,97,110,103,108,121,50,46,54,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,116,83,48,81,1,0,16,1,104,97,110,103,108,121,50,46,54,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,77,157,124,66,1,0,16,1,112,97,99,109,97,110,104,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,122,177,159,41,2,0,32,0,112,97,99,109,97,110,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,249,237,143,149,2,0,32,0,56,50,115,49,50,51,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,189,80,198,47,3,0,32,0,56,50,115,49,50,54,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,228,168,179,62,3,0,32,0,56,50,115,49,50,54,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,134,204,169,4,0,64,0,56,50,115,49,50,54,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,55,46,57,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,49,124,132,157,1,0,16,1,54,46,57,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,160,8,100,222,1,0,16,1,49,46,55,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,252,72,111,158,2,0,16,1,53,46,57,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,162,4,251,41,3,0,32,0,57,49,48,55,54,45,52,46,49,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,164,83,150,223,4,0,32,0,57,49,48,55,54,45,56,46,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,86,245,208,127,5,0,32,0,57,49,48,55,54,45,50,46,52,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,242,103,30,63,6,0,64,0,57,49,48,55,54,45,51,46,52,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,59,217,94,178,7,0,64,0,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,16,28,194,107,1,0,16,1,103,121,114,117,115,115,107,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,228,3,236,164,1,0,16,1,103,121,114,117,115,115,107,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,152,74,69,39,1,0,16,1,103,121,114,117,115,115,107,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,126,242,43,130,2,0,16,1,103,121,114,117,115,115,107,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,23,28,174,244,3,0,16,1,103,121,114,117,115,115,107,46,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,21,129,73,186,3,0,16,1,103,121,114,117,115,115,107,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,234,93,155,63,4,0,16,1,103,121,114,117,115,115,107,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,16,219,73,201,5,0,32,0,103,121,114,117,115,115,107,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,26,65,34,79,5,0,32,0,103,121,114,117,115,115,107,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,188,31,205,71,5,0,32,0,103,121,114,117,115,115,107,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,140,56,141,142,5,0,32,0,103,121,114,117,115,115,107,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,155,50,216,39,6,0,32,0,103,121,114,117,115,115,107,46,112,114,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,179,45,120,152,7,0,32,0,103,121,114,117,115,115,107,46,112,114,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,222,87,208,126,7,0,32,0,103,121,114,117,115,115,107,46,112,114,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,129,58,130,222,7,0,32,0,103,117,45,117,48,49,50,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,147,82,107,248,0,0,16,1,103,117,45,117,48,49,50,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,147,59,14,108,0,0,16,1,117,48,56,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,196,185,196,173,0,0,32,0,117,48,56,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,108,135,117,61,0,0,32,0,117,48,56,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,129,79,142,24,0,0,32,0,117,48,56,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,158,101,213,167,0,0,32,0,117,49,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,31,73,105,3,0,0,32,0,117,49,48,49,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,85,104,141,226,0,0,32,0,117,49,48,49,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,142,27,233,15,0,0,32,0,117,48,52,54,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,145,86,215,179,0,0,64,0,97,116,99,48,53,45,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,16,117,48,50,53,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,16,117,48,56,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,16,117,49,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,16,101,101,112,114,111,109,45,103,117,119,97,110,103,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,89,73,23,195,0,0,16,1,48,54,55,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,73,138,234,76,1,0,16,1,48,54,55,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,235,225,25,177,2,0,32,0,48,54,55,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,38,97,134,53,3,0,32,0,48,54,55,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,132,64,182,157,3,0,32,0,48,54,55,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,40,99,60,158,4,0,16,1,48,54,55,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,208,175,35,207,5,0,64,0,51,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,178,133,217,97,1,0,16,1,51,111,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,156,232,20,241,1,0,16,1,57,50,48,55,55,95,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,248,85,78,205,2,0,16,1,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,244,169,0,61,3,0,32,0,57,50,48,55,55,45,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,4,40,234,169,4,0,32,0,57,50,48,55,55,45,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,179,105,145,212,5,0,32,0,57,50,48,55,55,45,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,115,60,184,254,6,0,64,0,57,50,48,55,55,45,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,13,63,19,109,7,0,64,0,56,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,110,119,153,66,0,0,0,8,57,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,201,177,58,99,0,0,0,8,49,48,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,200,3,1,198,0,0,0,8,52,46,117,52,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,157,201,142,183,0,0,16,1,53,46,117,51,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,93,9,95,146,0,0,16,1,117,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,138,126,125,0,0,32,0,117,50,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,157,252,63,94,0,0,32,0,117,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,181,191,39,168,0,0,32,0,117,50,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,12,46,101,239,0,0,32,0,117,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,178,174,5,9,0,0,32,0,117,51,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,107,78,73,84,0,0,32,0,51,46,117,55,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,186,228,104,33,0,0,16,1,117,54,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,79,237,135,225,0,0,64,0,117,53,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,77,16,7,158,0,0,64,0,51,48,50,48,46,117,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,24,51,48,50,49,46,117,54,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,24,21,0,0,0,255,255,0,0,0,0,0,0,22,0,0,0,255,255,2,0,0,0,0,0,0,0,0,0,254,0,2,0,120,109,4,0,21,0,0,0,130,1,0,0,176,111,1,0,21,0,0,0,0,255,255,0,0,0,0,0,21,0,0,0,130,1,1,0,232,78,1,0,21,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,254,0,9,0,184,40,2,0,21,0,0,0,1,14,0,0,240,255,3,0,21,0,0,0,1,14,2,0,168,222,3,0,21,0,0,0,1,14,4,0,120,192,3,0,21,0,0,0,1,14,8,0,32,167,3,0,21,0,0,0,1,14,6,0,56,141,3,0,21,0,0,0,1,14,10,0,248,117,3,0,21,0,0,0,1,14,12,0,216,94,3,0,21,0,0,0,130,14,14,0,32,80,3,0,21,0,0,0,0,255,255,0,0,0,0,0,21,0,0,0,1,255,255,0,40,182,1,0,0,0,0,0,254,0,9,0,184,164,8,0,21,0,0,0,130,112,0,0,240,255,3,0,21,0,0,0,0,255,255,0,0,0,0,0,21,0,0,0,130,112,16,0,168,222,3,0,21,0,0,0,0,255,255,0,0,0,0,0,21,0,0,0,130,112,32,0,120,192,3,0,21,0,0,0,0,255,255,0,0,0,0,0,21,0,0,0,130,112,64,0,32,167,3,0,21,0,0,0,0,255,255,0,0,0,0,0,21,0,0,0,130,112,48,0,56,141,3,0,21,0,0,0,0,255,255,0,0,0,0,0,21,0,0,0,130,112,80,0,248,117,3,0,21,0,0,0,0,255,255,0,0,0,0,0,21,0,0,0,130,112,96,0,216,94,3,0,21,0,0,0,0,255,255,0,0,0,0,0,21,0,0,0,130,112,112,0,32,80,3,0,21,0,0,0,0,255,255,0,0,0,0,0,21,0,0,0,130,255,255,0,40,182,1,0,21,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,160,176,7,0,21,0,0,0,130,128,0,0,168,84,8,0,21,0,0,0,0,255,255,0,0,0,0,0,21,0,0,0,130,128,128,0,232,239,2,0,21,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,40,214,8,0,22,0,0,0,1,1,0,0,248,38,7,0,22,0,0,0,1,1,1,0,32,158,6,0,0,0,0,0,254,0,2,0,200,135,2,0,22,0,0,0,1,2,0,0,96,135,7,0,22,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,22,0,0,0,1,12,0,0,248,38,7,0,22,0,0,0,1,12,4,0,80,246,3,0,22,0,0,0,1,12,8,0,48,123,8,0,22,0,0,0,1,12,12,0,0,104,1,0,0,0,0,0,254,0,4,0,200,93,1,0,22,0,0,0,1,48,0,0,8,49,4,0,22,0,0,0,1,48,16,0,192,255,2,0,22,0,0,0,1,48,32,0,208,75,4,0,22,0,0,0,1,48,48,0,152,21,4,0,0,0,0,0,254,0,2,0,168,87,1,0,22,0,0,0,1,64,0,0,208,198,7,0,22,0,0,0,1,64,64,0,216,79,1,0,0,0,0,0,254,0,2,0,208,87,7,0,22,0,0,0,1,128,0,0,96,135,7,0,22,0,0,0,1,128,128,0,152,182,7,0,106,99,48,49,46,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,152,169,191,97,1,0,16,1,106,99,48,48,46,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,116,143,186,115,1,0,16,1,106,99,48,51,46,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,18,22,35,25,1,0,16,1,106,99,48,50,46,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,76,243,84,162,1,0,16,1,106,99,48,53,45,51,46,54,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,9,167,80,247,1,0,16,1,106,99,48,52,45,51,46,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,103,23,113,173,1,0,16,1,106,108,48,56,46,114,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,225,63,217,147,2,0,16,1,106,108,48,54,46,100,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,142,102,207,145,3,0,32,0,106,108,48,55,46,100,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,66,14,29,230,3,0,32,0,109,97,118,48,48,46,98,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,151,93,120,52,4,0,32,0,109,97,118,48,49,46,98,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,22,27,83,139,4,0,32,0,109,97,118,48,50,46,98,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,247,59,114,32,5,0,32,0,109,97,118,48,51,46,101,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,240,149,97,239,5,0,32,0,109,97,118,48,53,46,101,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,156,118,45,217,6,0,32,0,109,97,118,48,52,46,98,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,133,131,164,139,6,0,32,0,109,97,118,48,55,46,101,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,205,12,193,95,6,0,32,0,109,97,118,48,54,46,98,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,165,1,98,174,6,0,32,0,109,97,118,48,57,46,101,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,26,181,231,28,7,0,32,0,109,97,118,48,56,46,98,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,118,101,150,100,7,0,32,0,109,97,118,49,48,46,114,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,176,52,215,138,8,0,64,0,109,97,118,49,49,46,114,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,8,57,81,239,9,0,64,0,106,110,45,48,48,46,49,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,132,123,199,106,0,0,0,8,54,51,51,103,50,46,49,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,189,119,202,146,1,0,16,1,54,51,51,103,51,46,49,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,94,233,217,187,1,0,16,1,54,51,51,101,48,49,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,85,146,84,209,2,0,16,1,54,51,51,101,48,52,46,55,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,66,197,221,20,3,0,32,0,54,51,51,101,48,53,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,68,80,24,66,3,0,32,0,54,51,51,101,48,54,46,49,54,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,174,250,246,156,4,0,32,0,54,51,51,101,48,55,46,49,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,56,102,208,242,4,0,32,0,54,51,51,101,48,56,46,49,48,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,250,73,9,159,5,0,32,0,54,51,51,101,48,57,46,49,50,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,25,94,202,20,5,0,32,0,54,51,51,102,49,48,46,49,56,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,132,77,36,43,5,0,32,0,54,51,51,102,49,49,46,50,48,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,25,94,202,20,5,0,32,0,48,48,55,55,54,54,46,50,48,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,16,57,52,53,95,114,49,51,46,102,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,16,253,207,1,0,16,1,57,52,53,95,114,49,50,46,101,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,246,142,150,11,1,0,16,1,57,52,53,95,109,48,57,46,114,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,37,223,166,180,2,0,16,1,57,52,53,95,109,48,56,46,110,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,210,129,233,116,2,0,16,1,57,52,53,95,108,48,54,98,46,114,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,2,0,4,35,119,131,2,0,16,1,57,52,53,95,108,48,54,97,46,110,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,182,117,253,225,2,0,16,1,57,52,53,95,108,48,55,99,46,114,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,182,153,227,193,2,0,16,1,57,52,53,95,108,48,55,97,46,110,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,4,45,34,150,2,0,16,1,57,52,53,95,108,48,55,100,46,114,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,189,212,22,76,2,0,16,1,57,52,53,95,108,48,55,98,46,110,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,1,157,32,94,2,0,16,1,57,52,53,95,114,48,53,46,100,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,101,83,196,200,3,0,16,1,57,52,53,95,97,48,50,46,108,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,116,253,255,77,4,0,32,0,57,52,53,95,108,48,52,97,46,107,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,238,33,78,136,4,0,32,0,57,52,53,95,108,48,52,99,46,109,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,33,217,188,69,4,0,32,0,57,52,53,95,108,48,52,98,46,107,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,125,198,59,132,4,0,32,0,57,52,53,95,108,48,52,100,46,109,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,142,208,152,10,4,0,32,0,57,52,53,95,97,48,49,46,104,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,210,109,157,51,4,0,32,0,57,52,53,95,108,48,51,97,46,101,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,135,240,126,166,4,0,32,0,57,52,53,95,108,48,51,99,46,104,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,122,225,107,165,4,0,32,0,57,52,53,95,108,48,51,98,46,101,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,185,104,62,147,4,0,32,0,57,52,53,95,108,48,51,100,46,104,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,123,232,117,243,4,0,32,0,57,52,53,95,97,49,48,46,98,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,16,62,8,29,5,0,64,0,57,52,53,95,108,49,49,97,46,99,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,235,244,67,96,5,0,64,0,57,52,53,95,108,49,49,98,46,99,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,175,59,234,137,5,0,64,0,57,52,53,108,49,52,46,106,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,137,193,120,199,6,0,0,8,117,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,242,198,173,54,0,0,16,1,117,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,22,244,4,39,0,0,16,1,117,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,123,68,82,187,0,0,16,1,117,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,59,74,22,156,0,0,16,1,117,49,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,101,242,101,106,0,0,32,0,117,50,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,183,106,34,167,0,0,32,0,117,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,205,45,103,1,0,0,32,0,117,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,160,152,201,192,0,0,32,0,117,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,244,171,123,150,0,0,32,0,117,50,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,122,153,57,98,0,0,32,0,117,49,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,41,6,173,15,0,0,32,0,117,50,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,102,228,149,111,0,0,32,0,117,51,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,23,48,15,207,0,0,64,0,21,0,0,0,255,255,0,0,0,0,0,0,22,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,4,0,72,202,5,0,21,0,0,0,1,3,1,0,80,246,3,0,21,0,0,0,1,3,0,0,248,38,7,0,21,0,0,0,1,3,2,0,112,212,3,0,21,0,0,0,1,3,3,0,248,160,5,0,0,0,0,0,254,0,2,0,128,94,5,0,21,0,0,0,1,8,0,0,88,92,5,0,21,0,0,0,1,8,8,0,112,90,5,0,0,0,0,0,254,0,4,0,128,129,4,0,21,0,0,0,1,48,16,0,192,255,2,0,21,0,0,0,1,48,0,0,208,75,4,0,21,0,0,0,1,48,32,0,8,49,4,0,21,0,0,0,1,48,48,0,152,21,4,0,0,0,0,0,254,0,2,0,208,87,7,0,21,0,0,0,1,64,0,0,96,135,7,0,21,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,80,105,6,0,21,0,0,0,1,128,128,0,96,135,7,0,21,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,16,0,184,40,2,0,22,0,0,0,1,15,0,0,200,201,5,0,22,0,0,0,1,15,1,0,152,160,5,0,22,0,0,0,1,15,2,0,144,127,5,0,22,0,0,0,1,15,3,0,168,98,5,0,22,0,0,0,1,15,4,0,88,219,3,0,22,0,0,0,1,15,5,0,224,189,3,0,22,0,0,0,1,15,6,0,120,166,6,0,22,0,0,0,1,15,7,0,224,67,5,0,22,0,0,0,1,15,8,0,88,198,1,0,22,0,0,0,1,15,9,0,120,154,6,0,22,0,0,0,1,15,10,0,216,36,5,0,22,0,0,0,1,15,11,0,144,138,3,0,22,0,0,0,1,15,12,0,232,143,6,0,22,0,0,0,1,15,13,0,8,7,5,0,22,0,0,0,1,15,14,0,192,135,6,0,22,0,0,0,1,15,15,0,40,182,1,0,0,0,0,0,254,0,16,0,184,164,8,0,22,0,0,0,1,240,0,0,200,201,5,0,22,0,0,0,1,240,16,0,152,160,5,0,22,0,0,0,1,240,32,0,144,127,5,0,22,0,0,0,1,240,48,0,168,98,5,0,22,0,0,0,1,240,64,0,88,219,3,0,22,0,0,0,1,240,80,0,224,189,3,0,22,0,0,0,1,240,96,0,120,166,6,0,22,0,0,0,1,240,112,0,224,67,5,0,22,0,0,0,1,240,128,0,88,198,1,0,22,0,0,0,1,240,144,0,120,154,6,0,22,0,0,0,1,240,160,0,216,36,5,0,22,0,0,0,1,240,176,0,144,138,3,0,22,0,0,0,1,240,192,0,232,143,6,0,22,0,0,0,1,240,208,0,8,7,5,0,22,0,0,0,1,240,224,0,192,135,6,0,22,0,0,0,1,240,240,0,40,182,1,0,0,0,0,0,48,50,48,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,100,254,242,230,1,0,16,1,48,50,48,45,112,50,46,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,172,34,203,237,1,0,16,1,48,50,48,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,83,61,216,166,2,0,32,0,48,50,48,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,142,231,111,189,3,0,32,0,48,50,48,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,92,146,74,95,3,0,32,0,48,50,48,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,208,47,228,209,3,0,32,0,48,50,48,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,155,67,222,237,3,0,32,0,48,50,48,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,119,147,64,72,4,0,16,1,48,50,48,45,118,49,49,46,118,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,139,108,82,27,5,0,64,0,48,50,48,45,118,49,50,46,118,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,3,111,158,74,5,0,64,0,48,50,48,45,118,50,49,46,118,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,61,17,191,122,6,0,64,0,103,111,114,107,97,110,115,56,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,24,11,16,85,1,0,16,1,103,111,114,107,97,110,115,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,191,4,198,181,1,0,16,1,103,111,114,107,97,110,115,55,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,244,222,198,184,1,0,16,1,103,111,114,107,97,110,115,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,64,200,2,70,1,0,16,1,103,111,114,107,97,110,115,54,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,98,42,65,33,1,0,16,1,103,111,114,107,97,110,115,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,11,49,19,160,1,0,16,1,103,111,114,107,97,110,115,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,178,105,41,18,1,0,16,1,103,111,114,107,97,110,115,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,17,75,82,242,1,0,16,1,103,111,114,107,103,102,120,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,188,13,205,57,2,0,32,0,103,111,114,107,103,102,120,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,53,37,213,51,2,0,32,0,103,111,114,107,103,102,120,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,112,121,107,75,2,0,32,0,103,111,114,107,103,102,120,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,60,187,112,237,2,0,32,0,103,111,114,107,112,114,111,109,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,189,80,198,47,3,0,32,0,103,111,114,107,112,114,111,109,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,228,168,179,62,3,0,32,0,103,111,114,107,112,114,111,109,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,134,204,169,4,0,64,0,103,111,114,107,112,114,111,109,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,103,104,111,115,116,98,45,112,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,95,239,105,175,1,0,16,1,103,104,111,115,116,98,45,112,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,63,57,126,245,1,0,16,1,103,104,111,115,116,98,45,115,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,94,178,184,99,2,0,32,0,103,104,111,115,116,98,45,99,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,205,254,129,66,3,0,32,0,103,104,111,115,116,98,45,99,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,140,1,7,15,3,0,32,0,103,104,111,115,116,98,45,99,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,42,155,88,164,3,0,32,0,103,104,111,115,116,98,45,99,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,4,189,114,42,3,0,32,0,103,104,111,115,116,98,45,99,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,249,114,59,173,3,0,32,0,103,104,111,115,116,98,45,99,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,65,9,62,150,3,0,32,0,103,104,111,115,116,98,45,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,66,230,36,102,4,0,16,1,103,104,111,115,116,98,45,118,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,74,9,0,97,71,134,68,5,0,64,0,100,122,48,49,45,51,98,46,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,42,134,204,200,1,0,0,0,100,122,48,50,46,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,65,117,17,142,1,0,0,0,100,122,48,51,46,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,244,168,6,86,1,0,0,0,100,122,48,52,45,49,46,54,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,159,176,62,60,1,0,0,0,100,122,48,53,45,49,46,55,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,51,29,151,180,1,0,0,0,100,122,48,54,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,223,86,143,121,2,0,0,0,100,122,48,48,46,49,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,49,79,43,153,3,0,0,0,100,122,49,53,46,49,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,217,95,26,160,4,0,0,0,100,122,49,54,46,49,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,74,52,154,90,4,0,0,0,100,122,49,50,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,153,174,127,129,4,0,0,0,100,122,49,52,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,109,247,187,10,4,0,0,0,100,122,49,49,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,36,156,225,165,4,0,0,0,100,122,49,51,46,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,5,4,124,62,4,0,0,0,100,122,49,55,46,49,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,139,27,54,64,4,0,0,0,100,122,49,56,46,49,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,137,148,33,141,4,0,0,0,100,122,48,55,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,103,81,69,231,5,0,0,0,100,122,48,56,46,49,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,254,221,249,50,5,0,0,0,100,122,48,57,46,49,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,2,252,110,187,5,0,0,0,100,122,49,48,46,49,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,59,150,249,110,5,0,0,0,100,122,49,57,97,46,49,48,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,59,248,225,71,6,0,0,0,100,122,50,48,97,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,153,45,254,216,6,0,0,0,100,122,46,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,230,225,183,24,7,0,0,0,97,54,56,95,48,48,45,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,108,220,139,106,0,0,16,1,97,54,56,95,48,49,45,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,60,219,232,235,0,0,16,1,97,54,56,95,48,50,45,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,21,132,62,52,0,0,16,1,97,54,56,45,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,130,178,63,100,0,0,32,0,97,54,56,45,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,50,78,247,17,0,0,32,0,97,54,56,45,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,207,88,65,242,0,0,32,0,97,54,56,45,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,208,30,22,131,0,0,32,0,97,54,56,95,48,53,45,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,7,1,246,6,0,0,32,0,97,54,56,95,48,52,45,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,119,242,200,31,0,0,32,0,97,54,56,95,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,46,204,147,162,0,0,32,0,97,54,56,95,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,117,35,102,55,0,0,32,0,97,54,56,95,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,76,150,26,207,0,0,32,0,97,54,56,95,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,154,235,249,5,0,0,32,0,114,111,109,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,77,11,54,214,0,0,32,0,114,111,109,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,135,24,160,76,0,0,32,0,114,111,109,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,240,36,50,81,0,0,32,0,97,54,56,45,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,76,164,218,24,0,0,16,1,97,54,56,95,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,16,24,17,0,0,0,255,255,16,0,0,0,0,0,0,0,0,0,254,0,2,0,0,0,0,0,17,0,0,0,1,64,0,0,136,159,3,0,17,0,0,0,1,64,64,0,208,40,2,0,0,0,0,0,254,0,2,0,0,0,0,0,17,0,0,0,1,32,0,0,200,211,8,0,17,0,0,0,1,32,32,0,216,147,8,0,0,0,0,0,254,0,2,0,200,30,2,0,17,0,0,0,1,16,16,0,120,97,1,0,17,0,0,0,1,16,0,0,0,11,2,0,0,0,0,0,254,0,2,0,240,233,7,0,17,0,0,0,1,8,0,0,152,182,7,0,17,0,0,0,1,8,8,0,96,135,7,0,0,0,0,0,254,0,7,0,32,4,2,0,17,0,0,0,1,7,0,0,200,201,5,0,17,0,0,0,1,7,1,0,152,160,5,0,17,0,0,0,1,7,2,0,144,127,5,0,17,0,0,0,1,7,3,0,224,67,5,0,17,0,0,0,1,7,4,0,88,198,1,0,17,0,0,0,1,7,5,0,216,36,5,0,17,0,0,0,1,7,7,0,40,182,1,0,17,0,0,0,1,7,6,0,216,36,5,0,0,0,0,0,254,0,2,0,56,191,4,0,18,0,0,0,1,16,0,0,216,174,1,0,18,0,0,0,1,16,16,0,80,167,1,0,0,0,0,0,254,0,4,0,136,160,5,0,18,0,0,0,1,12,0,0,24,205,7,0,18,0,0,0,1,12,4,0,192,255,2,0,18,0,0,0,1,12,8,0,208,75,4,0,18,0,0,0,1,12,12,0,8,49,4,0,50,45,105,99,56,50,46,49,48,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,148,180,111,109,1,0,16,1,51,45,105,99,56,49,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,10,10,82,241,1,0,16,1,49,45,105,99,57,50,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,135,156,24,176,2,0,32,0,55,45,49,99,56,46,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,34,69,51,134,3,0,32,0,54,45,105,99,57,46,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,62,13,165,189,3,0,32,0,53,45,105,99,49,48,46,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,129,56,123,106,3,0,32,0,52,45,105,99,49,49,46,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,201,134,177,63,3,0,32,0,53,55,55,104,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,128,124,94,193,4,0,32,0,53,55,55,104,49,49,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,43,153,26,42,4,0,32,0,53,55,55,104,49,48,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,83,30,222,233,4,0,32,0,105,99,51,53,46,53,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,24,11,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,11,0,0,0,1,15,2,0,80,252,6,0,11,0,0,0,1,15,5,0,16,242,7,0,11,0,0,0,1,15,8,0,104,236,7,0,11,0,0,0,1,15,4,0,120,113,6,0,11,0,0,0,1,15,1,0,232,228,5,0,11,0,0,0,1,15,15,0,80,245,6,0,11,0,0,0,1,15,3,0,56,141,7,0,11,0,0,0,1,15,7,0,120,211,6,0,11,0,0,0,1,15,14,0,8,201,6,0,11,0,0,0,1,15,6,0,24,1,7,0,11,0,0,0,1,15,13,0,200,197,6,0,11,0,0,0,1,15,12,0,152,194,6,0,11,0,0,0,1,15,11,0,128,95,7,0,11,0,0,0,1,15,10,0,248,189,6,0,11,0,0,0,1,15,9,0,208,114,5,0,11,0,0,0,1,15,0,0,16,227,4,0,0,0,0,0,254,0,15,0,160,123,6,0,11,0,0,0,130,240,32,0,80,252,6,0,11,0,0,0,0,15,0,0,0,0,0,0,11,0,0,0,130,240,80,0,16,242,7,0,11,0,0,0,0,15,0,0,0,0,0,0,11,0,0,0,130,240,128,0,104,236,7,0,11,0,0,0,0,15,0,0,0,0,0,0,11,0,0,0,130,240,64,0,120,113,6,0,11,0,0,0,0,15,0,0,0,0,0,0,11,0,0,0,130,240,16,0,232,228,5,0,11,0,0,0,0,15,0,0,0,0,0,0,11,0,0,0,130,240,240,0,80,245,6,0,11,0,0,0,0,15,0,0,0,0,0,0,11,0,0,0,130,240,48,0,56,141,7,0,11,0,0,0,0,15,0,0,0,0,0,0,11,0,0,0,130,240,112,0,120,211,6,0,11,0,0,0,0,15,0,0,0,0,0,0,11,0,0,0,130,240,224,0,8,201,6,0,11,0,0,0,0,15,0,0,0,0,0,0,11,0,0,0,130,240,96,0,24,1,7,0,11,0,0,0,0,15,0,0,0,0,0,0,11,0,0,0,130,240,208,0,200,197,6,0,11,0,0,0,0,15,0,0,0,0,0,0,11,0,0,0,130,240,192,0,152,194,6,0,11,0,0,0,0,15,0,0,0,0,0,0,11,0,0,0,130,240,176,0,128,95,7,0,11,0,0,0,0,15,0,0,0,0,0,0,11,0,0,0,130,240,160,0,248,189,6,0,11,0,0,0,0,15,0,0,0,0,0,0,11,0,0,0,130,240,144,0,208,114,5,0,11,0,0,0,0,15,0,0,0,0,0,0,12,0,0,0,255,255,74,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,12,0,0,0,1,3,3,0,208,75,4,0,12,0,0,0,1,3,2,0,8,49,4,0,12,0,0,0,1,3,1,0,72,246,3,0,12,0,0,0,1,3,0,0,64,47,7,0,0,0,0,0,254,0,2,0,200,30,2,0,12,0,0,0,1,4,0,0,120,97,1,0,12,0,0,0,1,4,4,0,96,19,1,0,0,0,0,0,254,0,4,0,64,37,5,0,12,0,0,0,1,24,24,0,80,155,2,0,12,0,0,0,1,24,16,0,176,142,2,0,12,0,0,0,1,24,8,0,128,131,2,0,12,0,0,0,1,24,0,0,168,118,2,0,0,0,0,0,254,0,4,0,72,202,5,0,12,0,0,0,1,96,96,0,80,246,3,0,12,0,0,0,1,96,64,0,248,38,7,0,12,0,0,0,1,96,32,0,48,123,8,0,12,0,0,0,1,96,0,0,8,117,8,0,0,0,0,0,254,0,2,0,168,234,7,0,12,0,0,0,1,128,128,0,96,135,7,0,12,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,103,97,114,111,117,45,112,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,89,109,68,253,1,0,16,1,103,97,114,111,117,45,112,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,132,10,177,63,1,0,16,1,103,97,114,111,117,45,115,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,51,14,114,223,2,0,32,0,103,97,114,111,117,45,99,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,250,131,172,226,3,0,32,0,103,97,114,111,117,45,99,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,36,75,52,124,3,0,32,0,103,97,114,111,117,45,99,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,166,197,174,211,3,0,32,0,103,97,114,111,117,45,99,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,45,36,42,224,3,0,32,0,103,97,114,111,117,45,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,2,208,81,124,4,0,16,1,103,97,114,111,117,45,118,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,228,54,215,152,5,0,64,0,103,97,114,111,117,45,118,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,63,192,67,235,5,0,64,0,103,97,114,111,117,45,118,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,20,248,160,16,5,0,64,0,103,97,114,111,117,45,118,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,211,253,24,137,5,0,64,0,112,49,46,117,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,248,39,86,155,1,0,16,1,112,50,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,113,242,47,29,1,0,16,1,114,111,109,46,117,49,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,206,49,123,17,2,0,16,1,56,46,117,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,50,45,21,45,3,0,32,0,49,49,46,117,54,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,103,127,236,96,3,0,32,0,57,46,117,55,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,25,99,177,164,3,0,32,0,49,51,46,117,55,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,182,79,193,45,3,0,32,0,54,46,117,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,71,117,252,160,3,0,32,0,49,48,46,117,54,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,195,54,220,229,3,0,32,0,55,46,117,55,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,141,79,87,160,3,0,32,0,49,50,46,117,56,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,105,97,214,148,3,0,32,0,52,46,117,56,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,255,70,29,61,4,0,32,0,53,46,117,56,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,181,47,123,42,4,0,32,0,51,46,117,49,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,156,227,32,205,4,0,32,0,50,46,117,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,2,181,243,77,4,0,32,0,49,46,117,57,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,254,62,27,89,4,0,32,0,115,46,117,49,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,26,194,173,62,5,0,64,0,56,54,49,109,48,49,46,107,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,89,41,78,74,1,0,16,1,56,54,49,109,48,50,46,107,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,246,21,159,225,1,0,16,1,56,54,49,100,48,49,46,100,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,192,222,241,15,2,0,16,1,56,54,49,97,48,56,46,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,214,13,160,119,3,0,32,0,56,54,49,97,48,56,46,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,252,237,34,180,3,0,32,0,56,54,49,97,48,56,46,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,79,48,168,40,3,0,32,0,56,54,49,97,48,56,46,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,2,56,26,224,3,0,32,0,56,54,49,97,48,57,46,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,182,23,137,223,3,0,32,0,56,54,49,97,48,57,46,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,143,184,119,245,3,0,32,0,56,54,49,97,48,57,46,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,141,21,23,73,3,0,32,0,56,54,49,97,48,57,46,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,44,40,179,43,3,0,32,0,56,54,49,97,48,53,46,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,208,25,220,206,4,0,32,0,56,54,49,97,48,53,46,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,252,243,90,114,4,0,32,0,56,54,49,97,48,53,46,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,8,136,42,219,4,0,32,0,56,54,49,97,48,53,46,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0])
.concat([202,48,216,50,4,0,32,0,56,54,49,97,48,53,46,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,73,196,3,207,4,0,32,0,56,54,49,97,48,53,46,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,234,196,81,253,4,0,32,0,56,54,49,97,48,53,46,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,119,140,215,151,4,0,32,0,56,54,49,97,48,53,46,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,165,200,208,96,4,0,32,0,56,54,49,97,48,54,46,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,14,227,226,133,4,0,32,0,56,54,49,97,48,54,46,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,28,101,150,111,4,0,32,0,56,54,49,97,48,54,46,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,240,234,23,206,4,0,32,0,56,54,49,97,48,54,46,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,243,11,49,136,4,0,32,0,56,54,49,97,48,54,46,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,78,179,104,165,4,0,32,0,56,54,49,97,48,54,46,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,179,190,85,74,4,0,32,0,56,54,49,97,48,54,46,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,57,171,112,188,4,0,32,0,56,54,49,97,48,54,46,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,155,183,6,217,4,0,32,0,56,54,49,97,48,52,46,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,21,139,42,9,5,0,32,0,56,54,49,97,48,52,46,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,86,75,116,117,5,0,32,0,56,54,49,97,48,52,46,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,197,33,0,160,5,0,32,0,56,54,49,97,48,52,46,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,76,48,8,210,5,0,32,0,56,54,49,97,48,55,46,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,105,93,3,93,6,0,64,0,56,54,49,97,48,55,46,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,145,221,55,99,6,0,64,0,56,54,49,97,48,55,46,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,139,163,103,80,7,0,64,0,56,54,49,97,48,55,46,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,81,20,115,134,7,0,64,0,56,54,49,46,103,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,219,133,151,66,0,0,0,8,20,0,0,0,255,255,240,0,0,0,0,0,21,0,0,0,255,255,255,0,0,0,0,0,22,0,0,0,255,255,123,0,0,0,0,0,0,0,0,0,254,0,2,0,32,8,8,0,20,0,0,0,1,32,32,0,88,210,7,0,20,0,0,0,1,32,0,0,168,159,7,0,0,0,0,0,254,0,2,0,232,75,4,0,20,0,0,0,1,64,64,0,96,135,7,0,20,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,16,0,200,87,7,0,21,0,0,0,1,15,2,0,80,252,6,0,21,0,0,0,1,15,5,0,16,242,7,0,21,0,0,0,1,15,8,0,104,236,7,0,21,0,0,0,1,15,4,0,120,113,6,0,21,0,0,0,1,15,1,0,232,228,5,0,21,0,0,0,1,15,15,0,128,230,7,0,21,0,0,0,1,15,3,0,56,141,7,0,21,0,0,0,1,15,7,0,120,211,6,0,21,0,0,0,1,15,14,0,184,164,6,0,21,0,0,0,1,15,6,0,24,1,7,0,21,0,0,0,1,15,13,0,80,74,6,0,21,0,0,0,1,15,12,0,192,32,6,0,21,0,0,0,1,15,11,0,192,234,2,0,21,0,0,0,1,15,10,0,32,242,5,0,21,0,0,0,1,15,9,0,176,192,2,0,21,0,0,0,1,15,0,0,16,227,4,0,0,0,0,0,254,0,16,0,160,123,6,0,21,0,0,0,1,240,32,0,80,252,6,0,21,0,0,0,1,240,80,0,16,242,7,0,21,0,0,0,1,240,128,0,104,236,7,0,21,0,0,0,1,240,64,0,120,113,6,0,21,0,0,0,1,240,16,0,232,228,5,0,21,0,0,0,1,240,240,0,128,230,7,0,21,0,0,0,1,240,48,0,56,141,7,0,21,0,0,0,1,240,112,0,120,211,6,0,21,0,0,0,1,240,224,0,184,164,6,0,21,0,0,0,1,240,96,0,24,1,7,0,21,0,0,0,1,240,208,0,80,74,6,0,21,0,0,0,1,240,192,0,192,32,6,0,21,0,0,0,1,240,176,0,192,234,2,0,21,0,0,0,1,240,160,0,32,242,5,0,21,0,0,0,1,240,144,0,176,192,2,0,21,0,0,0,1,240,0,0,136,143,5,0,0,0,0,0,254,0,4,0,72,202,5,0,22,0,0,0,1,96,96,0,80,246,3,0,22,0,0,0,1,96,64,0,248,38,7,0,22,0,0,0,1,96,32,0,112,212,3,0,22,0,0,0,1,96,0,0,248,160,5,0,0,0,0,0,254,0,2,0,168,234,7,0,22,0,0,0,1,128,128,0,96,135,7,0,22,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,49,56,55,45,112,49,107,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,117,192,231,200,1,0,16,1,48,56,55,45,112,50,46,115,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,224,39,190,155,1,0,16,1,48,56,55,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,159,125,236,116,2,0,32,0,48,56,55,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,188,51,162,7,3,0,32,0,48,56,55,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,146,53,65,122,3,0,32,0,48,56,55,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,150,55,121,139,3,0,32,0,48,56,55,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,17,191,143,114,3,0,32,0,48,56,55,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,128,177,42,23,3,0,32,0,48,56,55,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,243,248,47,0,3,0,32,0,48,56,55,45,99,55,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,61,14,69,174,3,0,32,0,48,56,55,45,99,56,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,23,39,232,169,3,0,32,0,48,56,55,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,235,64,100,142,4,0,16,1,48,56,55,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,160,217,189,132,5,0,64,0,48,56,55,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,26,38,15,172,5,0,64,0,56,55,48,95,108,50,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,25,58,26,226,1,0,16,1,56,55,48,95,108,50,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,111,120,233,12,1,0,16,1,56,55,48,95,102,48,51,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,39,199,69,166,3,0,16,1,56,55,48,95,102,49,52,46,100,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,21,102,180,201,4,0,16,1,56,55,48,99,49,56,46,112,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,232,127,146,7,5,0,32,0,56,55,48,99,49,55,46,112,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,248,159,201,43,5,0,32,0,56,55,48,99,49,54,46,112,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,27,106,223,65,5,0,32,0,56,55,48,99,49,53,46,112,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,129,146,140,5,0,32,0,56,55,48,95,99,48,49,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,70,101,249,106,7,0,32,0,56,55,48,95,99,48,50,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,109,44,225,84,8,0,32,0,99,112,117,45,97,52,53,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,105,201,63,240,1,0,0,0,99,112,117,45,97,52,53,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,46,168,26,49,1,0,0,0,99,112,117,45,97,52,53,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,125,209,181,162,1,0,0,0,115,110,100,46,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,29,32,139,213,2,0,0,0,115,110,100,46,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,157,253,231,37,2,0,0,0,118,105,100,45,97,52,53,46,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,158,246,8,111,3,0,0,0,118,105,100,45,97,52,53,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,117,106,133,220,3,0,0,0,118,105,100,45,97,52,53,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,202,40,176,208,3,0,0,0,118,105,100,45,97,52,53,46,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,52,223,14,27,3,0,0,0,118,105,100,45,97,52,53,46,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,201,45,87,43,3,0,0,0,118,105,100,45,97,52,53,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,98,7,75,170,3,0,0,0,118,105,100,45,97,52,53,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,88,190,54,131,3,0,0,0,118,105,100,45,97,52,53,46,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,209,43,56,252,3,0,0,0,97,52,53,46,109,99,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,60,37,120,83,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,1,0,0,0,0,0,0,3,0,0,0,0,0,48,54,106,95,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,151,198,46,60,1,0,16,1,48,54,107,95,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,145,173,235,133,1,0,16,1,49,50,107,95,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,36,117,154,75,2,0,16,1,49,48,100,95,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,175,28,54,3,0,32,0,48,51,102,95,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,60,228,19,188,4,0,32,0,48,49,102,95,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,217,122,97,247,4,0,32,0,48,51,104,95,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,56,212,60,227,4,0,32,0,48,50,102,95,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,215,156,164,74,4,0,32,0,49,55,102,95,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,85,33,98,202,4,0,32,0,48,50,104,95,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,30,150,99,42,4,0,32,0,48,51,98,95,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,145,227,84,94,5,0,32,0,48,50,98,95,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,253,25,209,205,5,0,32,0,48,51,100,95,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,34,46,31,129,5,0,32,0,48,50,100,95,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,51,18,154,170,5,0,32,0,48,55,108,95,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,183,88,135,151,6,0,32,0,48,57,101,95,116,114,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,54,174,128,236,7,0,32,8,99,56,55,53,49,104,45,56,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,24,117,52,50,46,105,110,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,115,10,81,59,0,0,16,1,117,52,49,46,105,110,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,73,182,193,151,0,0,16,1,101,115,112,95,117,54,51,46,117,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,44,233,47,47,0,0,32,0,101,115,112,95,117,54,52,46,117,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,164,61,26,73,0,0,32,0,101,115,112,95,117,54,53,46,117,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,254,62,86,6,0,0,32,0,101,115,112,95,117,54,54,46,117,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,252,76,190,123,0,0,32,0,101,115,112,95,117,53,52,46,117,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,54,105,202,231,0,0,32,0,101,115,112,95,117,53,53,46,117,53,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,79,217,59,245,0,0,32,0,101,115,112,95,117,53,50,46,117,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,180,231,171,231,0,0,32,0,101,115,112,95,117,53,51,46,117,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,145,243,160,81,0,0,32,0,101,115,112,95,117,53,49,46,117,53,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,92,135,155,11,0,0,32,0,101,115,112,95,117,49,57,46,117,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,171,28,75,245,0,0,64,0,101,101,112,114,111,109,45,101,115,112,114,97,100,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,70,181,95,49,0,0,16,1,49,55,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,156,169,251,157,1,0,16,1,57,55,53,102,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,41,178,79,153,2,0,16,1,57,55,53,99,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,14,33,82,188,3,0,32,0,57,55,53,99,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,86,146,255,252,3,0,32,0,57,55,53,99,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,111,138,104,21,4,0,32,0,57,55,53,99,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,183,59,243,31,4,0,32,0,57,55,53,99,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,249,16,212,54,4,0,32,0,57,55,53,99,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,30,84,236,151,4,0,32,0,57,55,53,99,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,7,23,74,220,5,0,64,0,101,115,99,107,105,100,115,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,31,46,82,168,0,0,0,8,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,81,209,28,207,0,0,16,1,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,231,27,236,249,0,0,16,1,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,82,37,249,135,0,0,32,0,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,147,55,10,43,0,0,32,0,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,54,8,148,246,0,0,32,0,49,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,82,35,189,220,0,0,32,0,112,114,103,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,69,113,100,235,1,0,16,1,114,111,109,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,195,27,167,136,2,0,16,1,114,111,109,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,73,172,81,157,3,0,32,0,114,111,109,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,65,48,198,65,3,0,32,0,114,111,109,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,151,203,150,111,3,0,32,0,114,111,109,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,75,29,164,181,3,0,32,0,114,111,109,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,87,251,67,27,4,0,32,0,114,111,109,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,13,45,18,248,4,0,32,0,114,111,109,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,254,15,250,219,4,0,32,0,114,111,109,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,116,252,245,20,4,0,32,0,114,111,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,188,137,53,240,5,0,64,0,103,103,45,48,48,45,50,46,107,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,100,169,27,206,1,0,16,1,103,103,45,48,52,45,50,46,107,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,25,237,202,36,1,0,16,1,103,103,45,48,49,45,50,46,106,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,128,123,103,51,1,0,16,1,103,103,45,48,53,45,50,46,106,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,166,140,166,121,1,0,16,1,103,101,45,48,50,46,104,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,187,159,150,194,1,0,16,1,103,101,45,48,54,46,104,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,24,100,46,92,1,0,16,1,103,101,45,48,51,46,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,168,25,123,94,1,0,16,1,103,101,45,48,55,46,102,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,161,25,184,94,1,0,16,1,103,101,45,48,57,46,107,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,11,198,148,159,2,0,16,1,103,103,45,49,48,46,121,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,190,108,108,185,3,0,32,0,103,103,45,49,49,46,122,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,72,116,86,238,3,0,32,0,109,97,100,45,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,206,250,118,108,4,0,32,0,109,97,100,45,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,45,178,53,55,5,0,32,0,109,97,100,45,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,28,62,177,123,5,0,32,0,109,97,100,45,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,146,248,191,192,6,0,32,0,109,97,100,45,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,149,207,44,63,6,0,32,0,109,97,100,45,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,185,62,79,70,6,0,32,0,109,97,100,45,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,119,31,135,96,6,0,32,0,109,97,100,45,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,110,70,3,172,6,0,32,0,109,97,100,45,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,200,14,66,27,6,0,32,0,109,97,100,45,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,240,142,218,66,6,0,32,0,109,97,100,45,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,130,249,193,3,6,0,32,0,109,97,100,45,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,73,15,147,6,0,32,0,109,97,100,45,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,182,98,189,160,6,0,32,0,103,101,45,48,56,46,106,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,123,140,226,223,7,0,64,0,109,97,100,45,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,186,142,178,106,8,0,64,0,103,101,45,49,50,46,118,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,79,103,143,39,0,0,0,8,49,46,99,100,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,90,169,226,165,1,0,16,1,50,46,99,100,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,34,175,81,126,1,0,16,1,51,46,101,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,146,134,111,165,1,0,16,1,52,101,46,101,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,53,6,76,56,1,0,16,1,53,46,112,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,156,49,61,136,2,0,16,1,54,46,112,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,255,180,76,217,2,0,16,1,56,46,119,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,11,72,41,60,3,0,16,1,57,46,53,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,244,154,188,242,4,0,32,0,49,48,46,51,52,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,155,241,169,194,4,0,32,0,100,100,46,97,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,63,52,143,89,5,0,32,0,100,100,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,141,8,169,65,5,0,32,0,100,100,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,66,27,52,204,5,0,32,0,100,100,46,100,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,215,180,82,71,5,0,32,0,100,100,46,100,101,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,98,203,164,68,5,0,32,0,100,100,46,101,102,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,26,238,138,170,5,0,32,0,100,100,46,109,110,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,152,202,224,46,6,0,32,0,100,100,46,109,110,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,223,226,113,108,6,0,32,0,100,100,46,110,52,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,225,24,217,133,6,0,32,0,100,100,46,109,110,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,223,52,30,231,6,0,32,0,100,100,46,110,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,39,185,29,207,7,0,32,0,100,100,46,110,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,15,21,40,83,7,0,32,0,100,100,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,82,100,119,128,7,0,32,0,100,100,46,109,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,115,165,97,255,7,0,32,0,100,100,46,101,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,124,184,160,132,7,0,32,0,100,100,46,101,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,242,93,88,169,7,0,32,0,100,100,46,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,186,36,237,154,7,0,32,0,100,100,46,102,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,63,120,181,62,7,0,32,0,55,46,120,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,65,123,188,156,8,0,64,0,50,55,54,52,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,5,50,163,217,1,0,0,0,50,55,54,52,46,117,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,53,58,88,105,1,0,0,0,50,55,49,54,46,51,104,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,22,192,110,42,2,0,0,0,50,55,49,54,46,51,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,154,127,14,234,3,0,0,0,50,55,49,54,46,51,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,104,27,245,70,3,0,0,0,50,55,49,54,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,45,220,37,41,4,0,0,0])
.concat([50,55,49,54,46,55,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,180,177,246,189,4,0,0,0,50,55,49,54,46,55,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,47,230,98,77,4,0,0,0,50,55,49,54,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,229,0,210,129,4,0,0,0,56,50,115,49,50,54,46,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,118,95,244,63,5,0,0,0,56,50,115,49,50,54,46,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,190,5,249,56,5,0,0,0,56,50,115,49,50,54,46,50,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,155,59,52,60,5,0,0,0,100,109,49,48,48,48,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,172,125,70,41,1,0,16,1,100,109,49,48,48,48,111,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,207,233,72,186,1,0,16,1,100,109,49,48,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,129,14,161,12,2,0,32,0,100,109,49,48,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,181,29,43,76,2,0,32,0,100,109,49,48,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,73,194,154,26,2,0,32,0,100,109,49,48,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,252,166,109,196,2,0,32,0,100,109,49,48,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,196,129,173,213,3,0,32,0,100,109,49,48,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,227,43,87,184,3,0,32,0,112,105,99,49,54,99,53,53,46,104,101,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,123,11,0,0,231,17,112,241,4,0,16,1,100,109,49,48,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,127,111,86,99,5,0,64,0,100,109,49,48,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,78,135,26,15,6,0,64,0,50,55,54,52,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,5,50,163,217,1,0,0,0,50,55,54,52,46,117,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,53,58,88,105,1,0,0,0,50,55,49,54,46,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,91,163,137,52,2,0,0,0,50,55,49,54,46,51,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,154,127,14,234,3,0,0,0,50,55,49,54,46,51,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,104,27,245,70,3,0,0,0,50,55,49,54,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,45,220,37,41,4,0,0,0,50,55,49,54,46,55,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,180,177,246,189,4,0,0,0,50,55,49,54,46,55,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,47,230,98,77,4,0,0,0,50,55,49,54,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,229,0,210,129,4,0,0,0,56,50,115,49,50,54,46,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,118,95,244,63,5,0,0,0,56,50,115,49,50,54,46,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,190,5,249,56,5,0,0,0,56,50,115,49,50,54,46,50,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,155,59,52,60,5,0,0,0,100,111,114,111,100,111,110,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,38,175,10,70,1,0,16,1,100,111,114,111,100,111,110,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,182,30,69,210,1,0,16,1,100,111,114,111,100,111,110,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,108,238,198,211,1,0,16,1,100,111,114,111,100,111,110,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,133,43,238,94,2,0,32,0,100,111,114,111,100,111,110,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,90,194,90,57,2,0,32,0,100,111,114,111,100,111,110,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,10,181,11,215,3,0,32,0,100,111,114,111,100,111,110,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,230,89,78,228,3,0,32,0,100,111,114,111,100,111,110,46,98,112,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,53,193,101,248,4,0,16,1,100,111,114,111,100,111,110,46,98,112,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,187,240,178,71,4,0,16,1,100,111,114,111,100,111,110,46,98,112,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,200,11,207,143,5,0,32,0,100,111,114,111,100,111,110,46,98,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,228,155,32,63,5,0,32,0,100,111,114,111,100,111,110,46,98,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,80,58,250,39,5,0,0,8,116,112,48,50,50,95,48,49,46,114,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,41,36,235,121,0,0,16,1,116,112,48,50,50,95,51,46,119,57,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,95,89,27,25,0,0,32,0,116,112,48,50,50,95,52,46,119,57,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,202,41,141,213,0,0,32,0,116,112,48,50,50,95,53,46,119,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,69,219,193,212,0,0,32,0,116,112,48,50,50,95,54,46,119,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,79,199,141,212,0,0,32,0,116,112,48,50,50,95,50,46,119,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,179,113,50,4,0,0,64,0,20,0,0,0,255,255,0,0,0,0,0,0,21,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,0,0,0,0,20,0,0,0,1,1,0,0,144,202,5,0,20,0,0,0,1,1,1,0,40,182,1,0,0,0,0,0,254,0,2,0,0,0,0,0,20,0,0,0,1,2,0,0,200,211,8,0,20,0,0,0,1,2,2,0,216,147,8,0,0,0,0,0,254,0,2,0,0,0,0,0,20,0,0,0,1,4,0,0,168,84,8,0,20,0,0,0,1,4,4,0,208,87,7,0,0,0,0,0,254,0,2,0,240,233,7,0,20,0,0,0,1,8,0,0,152,182,7,0,20,0,0,0,1,8,8,0,96,135,7,0,0,0,0,0,254,0,4,0,200,87,7,0,20,0,0,0,130,48,0,0,232,38,7,0,22,0,0,0,0,15,3,0,0,0,0,0,20,0,0,0,130,48,16,0,120,164,6,0,22,0,0,0,0,15,3,0,0,0,0,0,20,0,0,0,130,48,32,0,224,123,6,0,22,0,0,0,0,15,3,0,0,0,0,0,20,0,0,0,130,48,48,0,16,74,6,0,22,0,0,0,0,15,3,0,0,0,0,0,0,0,0,0,254,0,4,0,160,123,6,0,20,0,0,0,130,192,0,0,232,38,7,0,22,0,0,0,0,15,3,0,0,0,0,0,20,0,0,0,130,192,64,0,120,164,6,0,22,0,0,0,0,15,3,0,0,0,0,0,20,0,0,0,130,192,128,0,224,123,6,0,22,0,0,0,0,15,3,0,0,0,0,0,20,0,0,0,130,192,192,0,16,74,6,0,22,0,0,0,0,15,3,0,0,0,0,0,0,0,0,0,254,0,4,0,200,87,7,0,20,0,0,0,2,48,0,0,232,38,7,0,22,0,0,0,0,15,3,0,0,0,0,0,20,0,0,0,2,48,16,0,224,123,6,0,22,0,0,0,0,15,3,0,0,0,0,0,20,0,0,0,2,48,32,0,200,241,5,0,22,0,0,0,0,15,3,0,0,0,0,0,20,0,0,0,2,48,48,0,200,241,5,0,22,0,0,0,0,15,3,0,0,0,0,0,0,0,0,0,254,0,4,0,160,123,6,0,20,0,0,0,2,192,0,0,120,164,6,0,22,0,0,0,0,15,3,0,0,0,0,0,20,0,0,0,2,192,64,0,232,201,5,0,22,0,0,0,0,15,3,0,0,0,0,0,20,0,0,0,2,192,128,0,168,241,5,0,22,0,0,0,0,15,3,0,0,0,0,0,20,0,0,0,2,192,192,0,208,127,5,0,22,0,0,0,0,15,3,0,0,0,0,0,0,0,0,0,254,0,4,0,136,160,5,0,21,0,0,0,1,3,0,0,16,68,5,0,21,0,0,0,1,3,1,0,248,36,5,0,21,0,0,0,1,3,2,0,40,7,5,0,21,0,0,0,1,3,3,0,56,227,4,0,0,0,0,0,254,0,4,0,56,191,4,0,21,0,0,0,1,12,0,0,56,102,4,0,21,0,0,0,1,12,4,0,48,0,3,0,21,0,0,0,1,12,8,0,88,234,2,0,21,0,0,0,1,12,12,0,248,75,4,0,0,0,0,0,254,0,4,0,248,101,4,0,21,0,0,0,1,48,0,0,8,49,4,0,21,0,0,0,1,48,1,0,72,246,3,0,21,0,0,0,1,48,2,0,208,75,4,0,21,0,0,0,1,48,3,0,192,255,2,0,0,0,0,0,254,0,2,0,0,0,0,0,21,0,0,0,1,64,0,0,136,159,3,0,21,0,0,0,1,64,64,0,120,134,3,0,0,0,0,0,254,0,2,0,104,82,2,0,21,0,0,0,1,128,0,0,152,182,7,0,21,0,0,0,1,128,128,0,96,135,7,0,0,0,0,0,118,49,48,53,95,49,54,109,46,117,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,189,131,160,189,1,0,16,1,116,48,52,53,48,49,46,117,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,172,170,14,144,2,0,32,0,97,48,52,53,48,49,46,117,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,166,190,65,151,3,0,32,0,97,48,52,53,48,50,46,117,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,5,244,4,225,3,0,32,0,97,48,52,53,48,51,46,117,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,227,207,213,191,3,0,32,0,98,48,52,53,48,49,46,117,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,125,11,50,41,4,0,32,0,98,48,52,53,48,50,46,117,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,233,0,140,87,4,0,32,0,119,48,52,53,48,49,46,117,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,55,129,181,58,5,0,64,0,100,109,110,102,114,110,116,95,105,103,115,48,50,55,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,7,0,16,17,118,49,48,53,95,51,50,109,46,117,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,239,194,152,199,8,0,16,1,100,107,106,46,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,88,129,162,222,1,0,0,0,100,107,106,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,246,250,181,111,1,0,0,0,100,107,106,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,168,182,66,208,1,0,0,0,99,95,51,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,248,165,93,113,2,0,0,0,100,107,106,46,51,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,169,172,81,141,3,0,0,0,100,107,106,46,51,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,165,75,246,78,3,0,0,0,118,95,55,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,100,65,127,220,4,0,0,0,118,95,55,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,246,220,231,12,4,0,0,0,118,95,55,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,23,255,209,36,4,0,0,0,118,95,55,102,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,63,8,140,15,4,0,0,0,99,45,50,101,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,173,199,61,70,5,0,0,0,99,45,50,102,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,66,0,186,71,5,0,0,0,118,45,50,110,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,133,241,219,5,0,0,0,99,95,53,102,95,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,17,43,79,66,1,0,0,0,99,95,53,103,95,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,53,102,42,59,1,0,0,0,99,95,53,104,95,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,93,137,40,29,1,0,0,0,99,95,53,107,95,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,7,96,77,57,1,0,0,0,115,95,51,105,95,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,6,237,164,69,2,0,0,0,115,95,51,106,95,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,146,254,67,71,2,0,0,0,118,95,53,104,95,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,93,201,200,18,3,0,0,0,118,95,53,107,95,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,20,249,132,54,3,0,0,0,108,95,52,109,95,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,77,5,248,89,4,0,0,0,108,95,52,110,95,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,20,71,46,103,4,0,0,0,108,95,52,114,95,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,238,89,170,254,4,0,0,0,108,95,52,115,95,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,126,239,242,32,4,0,0,0,99,45,50,107,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,229,237,115,226,5,0,0,0,99,45,50,106,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,88,35,65,214,5,0,0,0,118,45,53,101,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,245,184,105,184,5,0,0,0,100,107,51,99,46,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,142,243,213,56,1,0,0,0,100,107,51,99,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,121,67,19,201,1,0,0,0,100,107,51,99,46,55,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,33,41,46,210,1,0,0,0,100,107,51,99,106,46,55,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,35,190,181,37,1,0,0,0,100,107,51,99,46,53,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,133,136,248,127,2,0,0,0,100,107,51,99,46,54,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,12,32,215,54,3,0,0,0,100,107,51,118,46,51,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,199,153,90,65,4,0,0,0,100,107,51,118,46,51,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,160,78,116,37,4,0,0,0,100,107,51,118,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,55,23,250,143,5,0,0,0,100,107,51,118,46,55,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,134,70,200,154,5,0,0,0,100,107,51,118,46,55,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,251,243,10,12,5,0,0,0,100,107,51,118,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,98,134,197,85,5,0,0,0,100,107,99,49,45,99,46,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,252,190,84,223,6,0,0,0,100,107,99,49,45,99,46,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,64,127,167,102,6,0,0,0,100,107,99,49,45,118,46,50,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,52,52,227,80,6,0,0,0,100,107,99,49,45,118,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,248,234,226,211,7,0,0,0,53,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,188,121,153,84,1,0,0,0,53,99,45,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,230,186,220,185,1,0,0,0,53,101,45,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,143,134,97,90,1,0,0,0,51,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,248,165,93,113,2,0,0,0,51,110,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,53,125,214,254,3,0,0,0,51,112,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,206,135,27,61,3,0,0,0,55,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,55,23,250,143,4,0,0,0,55,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,134,70,200,154,4,0,0,0,55,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,251,243,10,12,4,0,0,0,55,102,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,98,134,197,85,4,0,0,0,100,107,51,98,45,99,46,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,252,190,84,223,5,0,0,0,100,107,51,98,45,99,46,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,64,127,167,102,5,0,0,0,100,107,51,98,45,118,46,50,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,52,52,227,80,5,0,0,0,53,99,45,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,214,18,160,119,1,0,0,0,53,101,45,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,103,215,94,116,1,0,0,0,49,46,55,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,141,187,7,189,1,0,0,0,50,46,55,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,17,236,251,1,1,0,0,0,51,46,55,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,12,208,29,168,1,0,0,0,52,46,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,248,165,93,113,2,0,0,0,53,46,54,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,157,102,20,207,3,0,0,0,54,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,94,209,254,206,3,0,0,0,55,46,50,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,100,65,127,220,4,0,0,0,56,46,50,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,246,220,231,12,4,0,0,0,57,46,50,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,23,255,209,36,4,0,0,0,49,48,46,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,63,8,140,15,4,0,0,0,109,98,55,48,53,50,46,57,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,68,212,242,73,5,0,0,0,109,98,55,48,53,50,46,57,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,171,19,117,72,5,0,0,0,109,98,55,48,53,50,46,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,133,241,219,5,0,0,0,109,98,55,48,53,49,46,56,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,202,242,166,165,5,0,0,0,106,120,95,48,48,45,46,52,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,79,224,157,26,1,0,16,1,106,120,95,48,49,45,46,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,200,151,192,121,1,0,16,1,106,120,95,48,50,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,165,146,52,78,2,0,16,1,109,97,121,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,141,31,77,35,3,0,32,0,109,97,121,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,4,125,165,45,4,0,32,0,109,97,121,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,19,167,102,58,4,0,32,0,109,97,121,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,174,43,228,182,5,0,64,0,112,97,108,49,54,108,56,98,95,118,100,45,48,48,46,54,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,6,0,0,16,112,97,108,49,54,108,56,98,95,118,100,45,48,49,46,55,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,6,0,0,16,112,97,108,49,54,114,54,97,95,118,100,45,48,50,46,49,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,6,0,0,16,106,119,95,48,48,45,50,46,52,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,73,108,186,230,1,0,16,1,106,119,95,48,49,45,50,46,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,87,61,74,104,1,0,16,1,106,119,95,48,50,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,165,146,52,78,2,0,16,1,109,97,121,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,141,31,77,35,3,0,32,0,109,97,121,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,4,125,165,45,4,0,32,0,109,97,121,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,19,167,102,58,4,0,32,0,109,97,121,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,174,43,228,182,5,0,64,0,112,97,108,49,54,108,56,98,95,118,100,45,48,48,46,54,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,6,0,0,16,112,97,108,49,54,108,56,98,95,118,100,45,48,49,46,55,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,6,0,0,16,112,97,108,49,54,114,54,97,95,118,100,45,48,50,46,49,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,6,0,0,16,106,121,95,48,48,45,49,46,52,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,125,19,206,139,1,0,16,1,106,121,95,48,49,45,49,46,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,80,4,165,236,1,0,16,1,106,121,95,48,50,46,109,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,165,146,52,78,2,0,16,1,109,97,121,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,141,31,77,35,3,0,32,0,109,97,121,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,4,125,165,45,4,0,32,0,109,97,121,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,19,167,102,58,4,0,32,0,109,97,121,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,174,43,228,182,5,0,64,0,112,97,108,49,54,108,56,98,95,118,100,45,48,48,46,54,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,6,0,0,16,112,97,108,49,54,108,56,98,95,118,100,45,48,49,46,55,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,6,0,0,16,112,97,108,49,54,114,54,97,95,118,100,45,48,50,46,49,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,6,0,0,16,100,100,98,95,49,100,111,116,46,117,52,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,205,38,95,38,1,0,16,1,116,48,52,52,48,49,119,48,54,52,46,117,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,156,241,149,58,2,0,32,0,97,48,52,52,48,49,119,48,54,52,46,117,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,148,151,34,237,3,0,32,0,97,48,52,52,48,50,119,48,54,52,46,117,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,176,103,33,117,3,0,32,0,98,48,52,52,48,49,119,48,54,52,46,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,102,240,191,140,4,0,32,0,109,48,52,52,48,49,98,48,51,50,46,117,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,118,189,13,90,5,0,64,0,100,100,112,51,95,105,103,115,48,50,55,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,7,0,16,17,100,100,112,51,98,108,107,95,100,101,102,97,117,108,116,115,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,4,25,101,161,0,0,0,8,118,49,48,49,95,49,54,109,46,117,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,253,134,87,94,1,0,16,1,100,100,112,50,95,105,103,115,48,50,55,97,95,119,111,114,108,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,11,226,84,54,7,0,16,1,116,49,51,48,48,46,117,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,203,240,72,231,2,0,32,0,97,49,51,48,48,46,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,5,164,135,252,3,0,32,0,97,49,51,48,49,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,218,32,133,12,3,0,32,0,98,49,51,48,48,46,117,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,4,102,100,239,4,0,32,0,109,49,51,48,48,46,117,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,93,1,212,130,5,0,64,0,118,49,48,48,46,117,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,41,221,195,6,8,0,16,1,118,49,48,48,46,117,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,234,168,138,12,1,0,16,1,100,100,112,50,95,105,103,115,48,50,55,97,95,119,111,114,108,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,11,226,84,54,7,0,16,1,116,49,51,48,48,46,117,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,203,240,72,231,2,0,32,0,97,49,51,48,48,46,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,5,164,135,252,3,0,32,0,97,49,51,48,49,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,218,32,133,12,3,0,32,0,98,49,51,48,48,46,117,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,4,102,100,239,4,0,32,0,109,49,51,48,48,46,117,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,93,1,212,130,5,0,64,0,118,49,48,48,46,117,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,41,221,195,6,8,0,16,1,234,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,46,99,100,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,90,169,226,165,1,0,16,1,50,46,99,100,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,34,175,81,126,1,0,16,1,100,100,51,120,46,56,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,40,80,120,155,1,0,16,1,100,100,52,120,46,55,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,80,99,15,13,1,0,16,1,53,120,46,112,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,25,215,86,234,2,0,16,1,54,120,46,112,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,205,14,250,159,2,0,16,1,56,120,46,119,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,129,96,6,244,3,0,16,1,57,120,46,53,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,227,9,55,145,4,0,32,0,49,48,120,46,51,52,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,203,170,93,64,4,0,32,0,100,100,46,97,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,63,52,143,89,5,0,32,0,100,100,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,141,8,169,65,5,0,32,0,100,100,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,66,27,52,204,5,0,32,0,100,100,46,100,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,215,180,82,71,5,0,32,0,100,100,46,100,101,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,98,203,164,68,5,0,32,0,100,100,46,101,102,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,26,238,138,170,5,0,32,0,100,100,46,109,110,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,152,202,224,46,6,0,32,0,100,100,46,109,110,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,223,226,113,108,6,0,32,0,100,100,46,110,52,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,225,24,217,133,6,0,32,0,100,100,46,109,110,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,223,52,30,231,6,0,32,0,100,100,46,110,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,39,185,29,207,7,0,32,0,100,100,46,110,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,15,21,40,83,7,0,32,0,100,100,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,82,100,119,128,7,0,32,0,100,100,46,109,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,115,165,97,255,7,0,32,0,100,100,46,101,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,124,184,160,132,7,0,32,0,100,100,46,101,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,242,93,88,169,7,0,32,0,100,100,46,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,186,36,237,154,7,0,32,0,100,100,46,102,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,63,120,181,62,7,0,32,0,55,46,120,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,65,123,188,156,8,0,64,0,49,46,99,100,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,90,169,226,165,1,0,16,1,50,46,99,100,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,34,175,81,126,1,0,16,1,51,120,46,101,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,254,177,61,99,1,0,16,1,52,120,46,101,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,99,226,158,220,1,0,16,1,53,120,46,112,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,25,215,86,234,2,0,16,1,54,120,46,112,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,205,14,250,159,2,0,16,1,56,120,46,119,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,129,96,6,244,3,0,16,1,57,120,46,53,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,227,9,55,145,4,0,32,0,49,48,120,46,51,52,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,203,170,93,64,4,0,32,0,100,100,46,97,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,63,52,143,89,5,0,32,0,100,100,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,141,8,169,65,5,0,32,0,100,100,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,66,27,52,204,5,0,32,0,100,100,46,100,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,215,180,82,71,5,0,32,0,100,100,46,100,101,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,98,203,164,68,5,0,32,0,100,100,46,101,102,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,26,238,138,170,5,0,32,0,100,100,46,109,110,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,152,202,224,46,6,0,32,0,100,100,46,109,110,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,223,226,113,108,6,0,32,0,100,100,46,110,52,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,225,24,217,133,6,0,32,0,100,100,46,109,110,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,223,52,30,231,6,0,32,0,100,100,46,110,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,39,185,29,207,7,0,32,0,100,100,46,110,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,15,21,40,83,7,0,32,0,100,100,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,82,100,119,128,7,0,32,0,100,100,46,109,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,115,165,97,255,7,0,32,0,100,100,46,101,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,124,184,160,132,7,0,32,0,100,100,46,101,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,242,93,88,169,7,0,32,0,100,100,46,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,186,36,237,154,7,0,32,0,100,100,46,102,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,63,120,181,62,7,0,32,0,55,46,120,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,65,123,188,156,8,0,64,0,54,56,55,95,110,48,53,46,54,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,11,91,25,169,1,0,16,1,54,56,55,95,110,48,52,46,52,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,5,81,181,101,1,0,16,1,54,56,55,95,110,48,57,46,54,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,76,89,107,28,1,0,16,1,54,56,55,95,110,48,56,46,52,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,150,49,96,169,1,0,16,1,54,56,55,95,110,48,55,46,49,48,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,42,50,84,97,2,0,16,1,54,56,55,95,110,48,54,46,56,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,139,46,167,55,2,0,16,1,54,56,55,95,110,49,51,46,49,48,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,175,82,194,241,2,0,16,1,54,56,55,95,110,49,50,46,56,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,68,25,34,218,2,0,16,1,54,56,55,95,110,48,51,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,47,104,76,162,3,0,16,1,54,56,55,95,110,49,52,46,100,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,210,198,106,199,4,0,32,0,54,56,55,105,49,55,46,112,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,35,57,203,102,5,0,32,0,54,56,55,105,49,56,46,112,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,219,208,199,161,5,0,32,0,54,56,55,105,49,53,46,112,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,178,197,200,238,5,0,32,0,54,56,55,105,49,54,46,112,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,139,244,108,116,5,0,32,0,54,56,55,95,108,49,49,46,49,48,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,232,238,157,57,6,0,32,0,54,56,55,95,108,49,48,46,56,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,238,145,124,17,6,0,32,0,54,56,55,95,105,48,49,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,251,45,153,212,7,0,64,0,54,56,55,95,105,48,50,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,1,117,148,229,8,0,64,0,53,48,48,51,45,112,49,115,112,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,224,77,92,171,1,0,16,1,53,48,48,51,45,112,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,43,194,193,173,1,0,16,1,53,48,48,51,45,115,49,115,112,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,180,90,53,108,2,0,32,0,53,48,48,51,45,99,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,103,75,245,104,3,0,32,0,53,48,48,51,45,99,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,213,73,136,47,3,0,32,0,53,48,48,51,45,99,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,113,255,74,172,3,0,32,0,53,48,48,51,45,99,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,102,93,239,175,3,0,32,0,53,48,48,51,45,99,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,80,174,193,199,3,0,32,0,53,48,48,51,45,99,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,249,151,49,97,3,0,32,0,53,48,48,51,45,99,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,15,254,221,100,3,0,32,0,53,48,48,51,45,99,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,57,20,122,145,3,0,32,0,53,48,48,51,45,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,75,39,140,26,4,0,16,1,50,54,50,45,118,49,45,48,56,45,101,48,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,207,158,212,131,5,0,64,0,50,54,50,45,118,50,45,48,56,45,101,48,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,67,24,63,0,5,0,64,0,50,54,50,45,118,51,45,48,56,45,101,48,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,190,141,227,42,5,0,64,0,50,54,50,45,118,52,45,48,56,45,101,48,46,118,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,217,77,236,38,5,0,64,0,53,48,48,51,45,112,49,115,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,157,80,58,1,1,0,16,1,53,48,48,51,45,112,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,43,194,193,173,1,0,16,1,53,48,48,51,45,115,49,115,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,174,126,31,78,2,0,32,0,53,48,48,51,45,99,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,103,75,245,104,3,0,32,0,53,48,48,51,45,99,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,213,73,136,47,3,0,32,0,53,48,48,51,45,99,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,113,255,74,172,3,0,32,0,53,48,48,51,45,99,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,102,93,239,175,3,0,32,0,53,48,48,51,45,99,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,80,174,193,199,3,0,32,0,53,48,48,51,45,99,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,249,151,49,97,3,0,32,0,53,48,48,51,45,99,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,15,254,221,100,3,0,32,0,53,48,48,51,45,99,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,57,20,122,145,3,0,32,0,53,48,48,51,45,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,75,39,140,26,4,0,16,1,50,54,50,45,118,49,45,48,56,45,101,48,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,207,158,212,131,5,0,64,0,50,54,50,45,118,50,45,48,56,45,101,48,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,67,24,63,0,5,0,64,0,50,54,50,45,118,51,45,48,56,45,101,48,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,190,141,227,42,5,0,64,0,50,54,50,45,118,52,45,48,56,45,101,48,46,118,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,217,77,236,38,5,0,64,0,100,120,48,51,45,49,50,46,49,56,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,124,110,146,45,1,0,0,0,100,120,48,49,46,49,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,12,181,15,87,1,0,0,0,100,120,48,50,46,49,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,144,88,98,88,1,0,0,0,100,120,48,52,45,49,46,49,57,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,145,38,67,41,2,0,0,0,100,120,48,53,46,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,37,207,50,235,3,0,0,0,100,120,48,48,46,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,133,249,30,240,4,0,0,0,100,120,49,52,46,49,53,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,21,121,240,128,5,0,0,0,100,120,49,51,46,49,51,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,231,2,44,211,5,0,0,0,100,120,49,50,46,49,48,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,107,183,120,172,5,0,0,0,100,120,48,54,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,140,32,251,182,6,0,0,0,100,120,48,55,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,23,24,62,238,6,0,0,0,100,120,48,56,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,254,0,89,112,6,0,0,0,100,120,48,57,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,29,87,146,49,6,0,0,0,100,120,49,48,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,50,122,247,62,6,0,0,0,100,120,49,49,46,49,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,184,213,243,156,6,0,0,0,105,100,56,55,53,49,104,46,109,99,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,7,0,0,16,99,114,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,209,76,232,226,1,0,16,1,99,114,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,111,14,2,236,1,0,16,1,99,114,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,39,95,69,212,1,0,16,1,99,114,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,6,174,54,153,1,0,16,1,109,97,107,101,116,114,97,120,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,218,210,186,145,2,0,32,0,109,97,107,101,116,114,97,120,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,85,159,167,174,2,0,32,0,56,50,115,49,50,51,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,189,80,198,47,3,0,32,0,50,115,49,52,48,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,39,185,239,99,3,0,32,0,56,50,115,49,50,54,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,134,204,169,4,0,64,0,56,50,115,49,50,54,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,48,51,55,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,60,85,242,231,1,0,16,1,48,51,55,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,39,31,101,116,2,0,32,0,48,51,55,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,146,104,223,9,3,0,32,0,48,51,55,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,120,42,18,172,3,0,32,0,48,51,55,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,202,209,126,157,3,0,32,0,48,51,55,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,93,57,36,74,3,0,32,0,48,51,55,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,198,178,4,149,4,0,16,1,48,51,55,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,101,223,254,97,5,0,64,0,114,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,94,5,201,3,1,0,16,1,114,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,246,228,138,169,1,0,16,1,108,111,103,105,99,112,114,111,46,114,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,75,98,13,0,2,0,16,1,108,111,103,105,99,112,114,111,46,114,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,201,24,223,222,3,0,32,0,108,111,103,105,99,112,114,111,46,114,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,194,209,203,62,3,0,32,0,108,111,103,105,99,112,114,111,46,114,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,33,85,19,71,3,0,32,0,108,111,103,105,99,112,114,111,46,114,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,210,193,139,169,4,0,32,0,108,111,103,105,99,112,114,111,46,114,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,152,98,228,29,4,0,32,0,108,111,103,105,99,112,114,111,46,114,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,212,196,254,161,5,0,64,0,98,57,57,45,48,55,46,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,230,134,232,38,2,0,0,0,98,57,57,45,48,53,46,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,157,154,127,255,2,0,0,0,98,57,57,45,48,54,46,51,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,146,170,38,31,2,0,0,0,98,57,57,45,49,51,46,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,65,132,207,6,2,0,0,0,98,57,57,45,48,56,46,52,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,81,84,19,38,9,0,0,0,98,57,57,45,48,50,46,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,38,74,93,42,11,0,0,0,98,57,57,45,48,49,46,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,58,55,158,161,11,0,0,0,98,57,57,45,48,51,46,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,247,13,161,221,24,0,0,0,98,57,57,45,48,55,46,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,230,134,232,38,2,0,0,0,98,57,57,45,48,53,46,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,157,154,127,255,2,0,0,0,98,57,57,45,48,54,46,51,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,146,170,38,31,2,0,0,0,98,57,57,45,49,53,46,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,109,229,193,232,2,0,0,0,98,57,57,45,48,56,46,52,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,81,84,19,38,9,0,0,0,98,57,57,45,48,50,46,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,38,74,93,42,11,0,0,0,98,57,57,45,48,49,46,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,58,55,158,161,11,0,0,0,98,57,57,45,48,51,46,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,247,13,161,221,24,0,0,0,48,52,51,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,40,217,189,255,1,0,16,1,48,52,51,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,132,212,98,195,2,0,32,0,48,52,51,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,127,214,210,186,3,0,32,0,48,52,51,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,149,218,251,167,3,0,32,0,48,52,51,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,17,224,11,240,3,0,32,0,48,52,51,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,192,229,135,24,3,0,32,0,48,52,51,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,203,89,171,126,4,0,16,1,48,52,51,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,232,140,104,99,5,0,64,0,48,52,51,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,123,130,154,198,5,0,64,0,54,51,51,110,48,51,46,49,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,104,181,218,254,1,0,16,1,54,51,51,107,48,50,46,49,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,56,116,95,93,1,0,16,1,54,51,51,101,48,49,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,85,146,84,209,2,0,16,1,54,51,51,101,48,52,46,55,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,66,197,221,20,3,0,32,0,54,51,51,101,48,53,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,68,80,24,66,3,0,32,0,54,51,51,101,48,54,46,49,54,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,174,250,246,156,4,0,32,0,54,51,51,101,48,55,46,49,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,56,102,208,242,4,0,32,0,54,51,51,101,48,56,46,49,48,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,250,73,9,159,5,0,32,0,54,51,51,101,48,57,46,49,50,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,25,94,202,20,5,0,32,0,54,51,51,102,49,48,46,49,56,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,132,77,36,43,5,0,32,0,54,51,51,102,49,49,46,50,48,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,25,94,202,20,5,0,32,0,48,48,55,55,54,54,46,50,48,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,16,51,46,105,99,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,218,225,69,208,1,0,16,1,49,46,105,99,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,154,189,247,178,1,0,16,1,51,46,105,99,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,85,146,84,209,2,0,16,1,55,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,210,103,244,87,3,0,32,0,49,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,133,150,219,230,3,0,32,0,57,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,222,97,92,135,3,0,32,0,56,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,214,101,39,100,3,0,32,0,49,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,75,50,162,218,3,0,32,0,49,54,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,53,200,124,226,3,0,32,0,49,55,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,185,48,67,206,3,0,32,0,49,56,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,66,206,113,21,3,0,32,0,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,44,229,199,44,4,0,32,0,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,156,91,26,224,4,0,32,0,54,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,68,103,234,174,4,0,32,0,49,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,199,253,90,118,4,0,32,0,49,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,44,169,155,189,4,0,32,0,49,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,194,126,190,208,4,0,32,0,49,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,18,61,81,43,4,0,32,0,54,51,51,101,48,56,46,49,48,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,250,73,9,159,5,0,32,0,54,51,51,101,48,57,46,49,50,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,25,94,202,20,5,0,32,0,54,51,51,102,49,48,46,49,56,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,132,77,36,43,5,0,32,0,54,51,51,102,49,49,46,50,48,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,25,94,202,20,5,0,32,0,99,111,110,112,114,111,109,46,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,126,218,161,5,0,0,0,8,54,51,51,105,48,51,46,49,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,207,216,192,127,1,0,16,1,54,51,51,105,48,50,46,49,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,154,189,247,178,1,0,16,1,54,51,51,101,48,49,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,85,146,84,209,2,0,16,1,54,51,51,101,48,52,46,55,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,66,197,221,20,3,0,32,0,54,51,51,101,48,53,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,68,80,24,66,3,0,32,0,54,51,51,101,48,54,46,49,54,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,174,250,246,156,4,0,32,0,54,51,51,101,48,55,46,49,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,56,102,208,242,4,0,32,0,54,51,51,101,48,56,46,49,48,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,250,73,9,159,5,0,32,0,54,51,51,101,48,57,46,49,50,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,25,94,202,20,5,0,32,0,54,51,51,102,49,48,46,49,56,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,132,77,36,43,5,0,32,0,54,51,51,102,49,49,46,50,48,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,25,94,202,20,5,0,32,0,48,48,55,55,54,54,46,50,48,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,16,184,40,2,0,1,0,0,0,21,252,146,0,248,191,2,0,184,164,8,0,1,0,0,0,22,252,146,0,64,246,1,0,104,28,8,0,1,0,0,0,114,238,146,0,232,209,1,0,24,38,7,0,1,0,0,0,221,243,146,0,184,160,2,0,144,236,1,0,1,0,0,0,222,243,146,0,136,224,1,0,56,210,6,0,1,0,0,0,16,252,146,0,192,135,2,0,24,163,6,0,1,0,0,0,18,252,146,0,240,108,2,0,200,110,3,0,1,0,0,0,20,252,146,0,152,30,2,0,120,89,3,0,1,0,0,0,23,252,146,0,232,10,2,0,120,74,3,0,1,0,0,0,112,238,146,0,152,138,8,0,176,223,1,0,1,0,0,0,216,243,146,0,72,198,1,0,192,209,1,0,1,0,0,0,218,243,146,0,24,182,1,0,224,22,1,0,1,0,0,0,220,243,146,0,56,126,1,0,160,14,1,0,1,0,0,0,223,243,146,0,32,101,1,0,176,9,1,0,1,0,0,0,113,238,146,0,96,32,8,0,88,212,3,0,1,0,0,0,184,216,146,0,40,185,3,0,248,5,8,0,9,0,0,0,0,4,147,0,32,58,1,0,103,109,45,48,50,45,51,46,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,177,195,49,217,1,0,16,1,103,109,45,48,53,45,50,46,51,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,251,211,23,116,1,0,16,1,103,109,45,48,49,45,50,46,49,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,126,31,4,114,1,0,16,1,103,109,45,48,52,45,50,46,51,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,5,208,4,33,1,0,16,1,103,110,45,48,48,46,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,22,11,17,11,1,0,16,1,103,110,45,48,51,46,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,151,230,40,30,1,0,16,1,103,108,45,48,55,46,49,51,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,150,239,139,202,2,0,16,1,103,108,45,48,56,46,54,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,180,162,51,3,0,32,0,103,108,45,48,57,46,54,122,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,82,71,45,90,3,0,32,0,109,97,103,45,48,50,46,52,122,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,154,198,137,222,4,0,32,0,109,97,103,45,48,48,46,49,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,51,93,240,168,5,0,32,0,109,97,103,45,48,49,46,49,122,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,237,158,57,91,5,0,32,0,109,97,103,45,48,51,46,57,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,159,235,32,34,6,0,32,0,109,97,103,45,48,53,46,49,50,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,84,50,165,86,6,0,32,0,109,97,103,45,48,52,46,57,122,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,204,148,75,20,6,0,32,0,109,97,103,45,48,54,46,49,50,122,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,73,71,212,130,6,0,32,0,103,108,45,48,54,46,49,51,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,157,81,46,217,7,0,64,0,109,97,103,45,48,55,46,49,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,100,82,235,8,8,0,64,0,109,98,55,49,50,50,104,46,55,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,54,115,38,161,0,0,0,8,103,110,45,48,50,46,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,89,9,196,166,1,0,16,1,103,110,45,48,53,46,51,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,228,203,2,160,1,0,16,1,103,110,45,48,49,46,49,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,124,82,240,24,1,0,16,1,103,110,45,48,52,46,51,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,83,109,75,234,1,0,16,1,103,110,45,48,48,46,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,22,11,17,11,1,0,16,1,103,110,45,48,51,46,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,151,230,40,30,1,0,16,1,103,108,45,48,55,46,49,51,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,150,239,139,202,2,0,16,1,103,108,45,48,56,46,54,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,180,162,51,3,0,32,0,103,108,45,48,57,46,54,122,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,82,71,45,90,3,0,32,0,109,97,103,45,48,50,46,52,122,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,154,198,137,222,4,0,32,0,109,97,103,45,48,48,46,49,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,51,93,240,168,5,0,32,0,109,97,103,45,48,49,46,49,122,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,237,158,57,91,5,0,32,0,109,97,103,45,48,51,46,57,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,159,235,32,34,6,0,32,0,109,97,103,45,48,53,46,49,50,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,84,50,165,86,6,0,32,0,109,97,103,45,48,52,46,57,122,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,204,148,75,20,6,0,32,0,109,97,103,45,48,54,46,49,50,122,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,73,71,212,130,6,0,32,0,103,108,45,48,54,46,49,51,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,157,81,46,217,7,0,64,0,109,97,103,45,48,55,46,49,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,100,82,235,8,8,0,64,0,109,98,55,49,50,50,104,46,55,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,54,115,38,161,0,0,0,8,101,101,48,56,45,101,46,106,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,58,204,117,130,1,0,16,1,101,101,49,49,45,101,46,106,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,160,64,158,136,1,0,16,1,97,45,106,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,134,84,70,81,1,0,16,1,97,45,106,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,51,218,157,208,1,0,16,1,101,101,48,54,45,101,46,106,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,219,175,172,85,1,0,16,1,101,101,48,57,45,101,46,106,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,44,37,62,48,1,0,16,1,101,101,48,53,45,46,102,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,180,54,137,106,2,0,16,1,101,101,48,48,45,101,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,107,92,110,224,3,0,32,0,101,101,48,52,45,46,100,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,149,79,136,150,4,0,32,0,101,101,48,49,45,46,99,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,87,64,181,244,4,0,32,0,101,101,48,51,45,46,100,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,130,225,120,113,4,0,32,0,101,101,48,50,45,46,99,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,174,69,124,157,4,0,32,0,101,101,49,50,45,46,102,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,165,83,28,155,5,0,32,0,101,101,49,51,45,46,102,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,62,174,184,114,5,0,32,0,101,101,49,52,45,46,102,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,222,187,244,216,5,0,32,0,101,101,49,53,45,46,102,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,139,230,227,129,5,0,32,0,101,101,50,49,46,107,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,134,101,219,177,6,0,32,0,101,101,50,48,46,108,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,50,97,129,65,6,0,32,0,99,104,101,108,110,111,118,95,105,56,55,53,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,24,102,120,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,131,109,174,221,1,0,16,1,102,120,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,222,192,194,91,1,0,16,1,102,120,48,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,249,91,214,195,1,0,16,1,102,120,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,107,38,117,184,1,0,16,1,102,117,49,49,45,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,16,15,242,101,2,0,16,1,109,97,98,45,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,189,170,14,102,3,0,32,0,102,117,48,53,45,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,18,212,52,129,3,0,32,0,102,117,48,54,45,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,69,74,145,47,3,0,32,0,109,97,98,45,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,25,214,128,16,4,0,32,0,109,97,98,45,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,29,35,183,88,5,0,32,0,109,97,98,45,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,157,59,5,118,5,0,32,0,102,117,48,55,45,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,179,11,141,202,5,0,32,0,102,117,48,56,45,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,200,197,175,198,5,0,32,0,102,117,48,57,45,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,202,9,104,82,5,0,32,0,102,117,49,48,45,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,14,213,230,107,5,0,32,0,102,117,49,50,45,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,242,101,29,45,6,0,64,0,102,117,49,51,45,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,34,86,82,184,7,0,64,0,109,98,55,49,49,52,104,46,49,56,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,15,183,69,54,8,0,0,8,99,50,49,45,49,52,45,50,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,24,212,35,248,2,0,16,1,99,50,49,45,49,54,45,50,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,119,85,22,144,2,0,16,1,99,50,49,45,49,51,45,50,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,174,195,220,146,2,0,16,1,99,50,49,45,49,53,45,50,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,106,210,21,249,2,0,16,1,99,50,49,45,48,56,46,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,160,149,164,220,9,0,16,1,99,50,49,45,48,50,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,185,131,88,32,11,0,32,0,99,50,49,45,48,49,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,156,243,246,31,15,0,32,0,99,50,49,45,48,55,46,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,189,146,34,240,0,0,16,8,99,50,49,45,48,52,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,229,235,34,204,2,0,16,1,99,50,49,45,48,54,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,4,51,224,38,2,0,16,1,99,50,49,45,48,51,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,237,136,72,197,2,0,16,1,99,50,49,45,48,53,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,210,24,64,131,2,0,16,1,99,50,49,45,48,56,46,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,160,149,164,220,9,0,16,1,99,50,49,45,48,50,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,185,131,88,32,11,0,32,0,99,50,49,45,48,49,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,156,243,246,31,15,0,32,0,99,50,49,45,48,55,46,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,189,146,34,240,0,0,16,8,99,50,49,45,49,52,105,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,19,230,217,209,2,0,16,1,99,50,49,45,49,54,105,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,239,86,34,20,2,0,16,1,99,50,49,45,49,51,105,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,48,110,207,201,2,0,16,1,99,50,49,45,49,55,105,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,221,201,31,100,2,0,16,1,99,50,49,45,48,56,46,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,160,149,164,220,9,0,16,1,99,50,49,45,48,50,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,185,131,88,32,11,0,32,0,99,50,49,45,48,49,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,156,243,246,31,15,0,32,0,99,50,49,45,48,55,46,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,189,146,34,240,0,0,16,8,99,50,49,45,50,51,45,49,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,190,186,221,48,2,0,16,1,99,50,49,45,50,53,45,49,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,17,6,225,36,2,0,16,1,99,50,49,45,50,50,45,49,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,45,139,245,218,2,0,16,1,99,50,49,45,50,52,45,49,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,62,185,89,35,2,0,16,1,99,50,49,45,48,56,46,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,160,149,164,220,9,0,16,1,99,50,49,45,48,50,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,185,131,88,32,11,0,32,0,99,50,49,45,48,49,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,156,243,246,31,15,0,32,0,99,50,49,45,48,55,46,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,189,146,34,240,0,0,16,8,99,50,49,45,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,59,84,112,77,2,0,16,1,99,50,49,45,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,80,153,91,14,2,0,16,1,99,50,49,45,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,155,229,25,138,2,0,16,1,99,50,49,45,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,217,207,106,185,2,0,16,1,99,50,49,45,48,56,46,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,160,149,164,220,9,0,16,1,99,50,49,45,48,50,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,185,131,88,32,11,0,32,0,99,50,49,45,48,49,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,156,243,246,31,15,0,32,0,99,50,49,45,48,55,46,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,189,146,34,240,0,0,16,8,98,117,99,49,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,171,160,15,44,1,0,16,1,98,117,99,53,46,54,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,241,162,236,175,1,0,16,1,98,117,99,50,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,169,173,83,107,1,0,16,1,98,117,99,54,46,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,132,202,243,53,1,0,16,1,98,117,99,51,46,54,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,76,164,69,144,1,0,16,1,98,117,99,55,46,54,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,62,60,143,136,1,0,16,1,98,117,99,52,46,54,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,97,225,45,41,1,0,16,1,98,117,99,56,46,54,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,88,248,74,136,1,0,16,1,98,117,99,57,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,119,192,96,64,2,0,32,0,98,117,99,49,49,46,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,131,18,134,227,2,0,32,0,98,117,99,49,48,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,236,109,246,9,2,0,32,0,98,117,99,49,50,46,53,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,231,20,51,101,2,0,32,0,56,50,115,49,50,51,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,189,80,198,47,3,0,32,0,56,50,115,49,50,54,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,228,168,179,62,3,0,32,0,56,50,115,49,50,54,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,134,204,169,4,0,64,0,56,50,115,49,50,54,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,48,48,50,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,14,121,199,59,1,0,16,1,48,48,50,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,198,208,127,26,2,0,32,0,48,48,50,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,69,42,255,170,3,0,32,0,48,48,50,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,228,247,160,59,3,0,32,0,48,48,50,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,250,253,240,150,3,0,32,0,48,48,50,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,47,127,216,95,3,0,32,0,48,48,50,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,59,216,126,128,3,0,32,0,48,48,50,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,65,173,60,90,3,0,32,0,48,48,50,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,238,164,202,78,4,0,16,1,48,48,50,45,118,49,49,46,118,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,189,37,185,183,5,0,64,0,48,48,50,45,118,49,50,46,118,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,252,38,159,50,5,0,64,0,48,48,50,45,118,49,51,46,118,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,200,243,57,12,5,0,64,0,48,48,50,45,118,49,52,46,118,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,56,28,225,199,5,0,64,0,48,48,50,45,118,50,49,46,118,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,209,51,167,4,6,0,64,0,48,52,49,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,253,103,53,82,1,0,16,1,48,52,49,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,148,92,92,1,2,0,32,0,48,52,49,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,225,18,154,179,3,0,32,0,48,52,49,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,47,252,108,118,3,0,32,0,48,52,49,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,157,51,49,251,3,0,32,0,48,52,49,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,12,122,69,112,3,0,32,0,48,52,49,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,166,119,193,21,4,0,16,1,48,52,49,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,147,160,29,203,5,0,64,0,48,52,49,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,157,74,149,28,5,0,64,0,48,52,49,45,118,51,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,128,1,170,175,5,0,64,0,56,57,49,110,48,51,46,107,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,243,63,8,139,1,0,16,1,56,57,49,45,116,48,50,46,107,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,210,206,16,44,1,0,16,1,56,57,49,106,48,49,46,103,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,168,160,176,49,2,0,16,1,56,57,49,101,49,48,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,49,4,155,32,3,0,32,0,56,57,49,101,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,232,169,32,128,3,0,32,0,56,57,49,101,49,48,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,122,253,213,22,3,0,32,0,56,57,49,101,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,192,28,18,48,3,0,32,0,56,57,49,101,48,57,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,191,239,202,157,3,0,32,0,56,57,49,101,48,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,217,234,176,86,3,0,32,0,56,57,49,101,48,57,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,230,53,19,78,3,0,32,0,56,57,49,101,48,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,251,20,249,182,3,0,32,0,56,57,49,101,48,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,28,219,4,11,4,0,32,0,56,57,49,101,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,39,115,227,94,4,0,32,0,56,57,49,101,48,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,36,165,173,249,4,0,32,0,56,57,49,101,48,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,170,223,149,34,4,0,32,0,56,57,49,101,48,54,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,143,247,171,4,4,0,32,0,56,57,49,101,48,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,85,13,219,219,4,0,32,0,56,57,49,101,48,54,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,140,237,93,93,4,0,32,0,56,57,49,101,48,54,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,113,189,236,249,4,0,32,0,56,57,49,101,48,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,41,231,86,179,4,0,32,0,56,57,49,101,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,126,72,213,191,4,0,32,0,56,57,49,101,48,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,197,17,221,236,4,0,32,0,56,57,49,101,48,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,36,141,161,171,4,0,32,0,56,57,49,101,48,53,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,174,249,21,195,4,0,32,0,56,57,49,101,48,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,111,188,252,33,4,0,32,0,56,57,49,101,48,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,59,165,171,176,4,0,32,0,56,57,49,101,48,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,134,248,211,246,4,0,32,0,56,57,49,101,48,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,57,185,216,184,5,0,32,0,56,57,49,101,48,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,45,249,178,131,5,0,32,0,56,57,49,101,48,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,191,103,246,206,6,0,32,0,56,57,49,101,48,56,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,122,74,193,247,6,0,32,0,56,57,49,101,48,56,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,60,127,107,117,6,0,32,0,56,57,49,101,48,56,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,5,115,13,205,6,0,32,0,56,57,49,101,48,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,116,188,235,218,7,0,32,0,56,57,49,101,48,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,209,154,251,95,7,0,32,0,56,57,49,101,48,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,107,241,187,45,7,0,32,0,56,57,49,101,48,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,204,210,12,139,7,0,32,0,56,57,49,98,49,49,46,102,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,170,84,184,236,8,0,0,8,224,139,113,142,2,1,2,1,0,3,12,1,2,2,2,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,32,0,107,79,5,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,130,0,130,111,140,98,144,180,171,108,98,109,95,100,45,104,48,45,98,46,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,199,87,178,73,1,0,16,1,98,109,95,100,45,108,48,45,98,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,62,82,115,168,1,0,16,1,98,109,95,100,45,104,49,45,98,46,53,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,88,113,43,8,1,0,16,1,98,109,95,100,45,108,49,45,98,46,53,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,78,192,240,111,1,0,16,1,98,109,95,100,45,115,104,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,91,7,124,159,2,0,16,1,98,109,95,100,45,115,108,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,137,124,168,31,2,0,16,1,98,109,95,99,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,184,102,201,44,3,0,32,0,98,109,95,99,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,62,119,223,70,3,0,32,0,98,109,95,99,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,189,103,184,5,3,0,32,0,98,109,95,99,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,164,39,34,10,3,0,32,0,98,109,95,48,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,243,201,159,51,4,0,32,0,98,109,95,48,49,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,125,55,20,106,4,0,32,0,98,109,95,48,50,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,152,33,83,49,4,0,32,0,98,109,95,48,51,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,211,65,160,209,4,0,32,0,98,109,95,100,97,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,152,87,206,98,5,0,64,0,57,55,51,108,48,50,46,101,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,154,132,79,225,1,0,16,1,57,55,51,100,48,49,46,103,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,146,157,238,238,2,0,16,1,57,55,51,102,48,55,46,107,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,180,217,140,26,3,0,32,0,57,55,51,102,48,56,46,107,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,166,81,43,149,3,0,32,0,57,55,51,102,48,57,46,107,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,148,21,132,119,3,0,32,0,57,55,51,102,49,48,46,107,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,171,159,3,9,3,0,32,0,57,55,51,102,48,54,46,107,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,182,253,172,81,4,0,32,0,57,55,51,102,48,53,46,107,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,152,162,254,76,4,0,32,0,57,55,51,102,48,52,46,107,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,189,65,202,105,4,0,32,0,57,55,51,102,48,51,46,107,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,114,132,233,33,4,0,32,0,57,55,51,97,49,49,46,104,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,233,143,210,70,5,0,0,8,117,120,48,48,49,48,48,49,46,117,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,243,161,118,35,1,0,16,1,117,120,48,48,49,48,48,50,46,117,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,114,225,21,185,1,0,16,1,117,120,48,48,49,48,48,51,46,117,50,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,99,44,5,152,1,0,16,1,117,120,48,48,49,48,48,56,46,117,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0])
.concat([182,71,54,65,3,0,32,0,117,120,48,48,49,48,48,55,46,117,50,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,209,253,64,68,3,0,32,0,117,120,48,48,49,48,48,54,46,117,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,247,28,192,171,3,0,32,0,117,120,48,48,49,48,48,53,46,117,50,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,165,196,160,190,3,0,32,0,117,120,48,48,49,48,48,57,46,117,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,234,106,111,188,4,0,32,0,117,120,48,48,49,48,49,48,46,117,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,20,118,127,189,4,0,32,0,117,120,48,48,49,48,49,49,46,117,54,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,151,3,254,94,5,0,32,0,117,120,48,48,49,48,49,50,46,117,48,54,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,89,153,242,5,0,32,0,117,120,48,48,49,48,49,51,46,117,54,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,205,115,210,92,6,0,64,0,117,120,48,48,49,48,49,52,46,117,55,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,78,155,180,134,6,0,64,0,112,114,103,48,117,48,50,50,95,117,115,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,253,47,251,149,0,0,16,1,112,114,103,50,117,48,50,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,86,134,186,255,0,0,16,1,112,114,103,49,117,48,50,51,46,110,101,119,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,100,170,233,74,0,0,16,1,112,114,103,51,117,48,50,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,214,138,75,131,0,0,16,1,103,102,120,117,48,53,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,70,52,202,156,0,0,32,0,103,102,120,117,48,53,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,213,129,162,162,0,0,32,0,103,102,120,117,48,53,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,192,114,100,225,0,0,32,0,103,102,120,117,48,53,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,160,53,182,139,0,0,32,0,115,110,100,117,48,55,50,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,70,178,42,230,0,0,16,1,114,111,109,54,46,56,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,160,180,72,136,0,0,64,0,114,111,109,55,46,56,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,103,66,34,214,0,0,64,0,114,111,109,56,46,56,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,176,223,1,161,0,0,64,0,101,101,112,114,111,109,45,98,98,97,107,114,97,105,100,45,110,101,119,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,90,39,201,53,0,0,16,0,112,114,103,48,117,48,50,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,18,149,213,13,0,0,16,1,112,114,103,50,117,48,50,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,86,134,186,255,0,0,16,1,112,114,103,49,117,48,50,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,35,226,205,254,0,0,16,1,112,114,103,51,117,48,50,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,214,138,75,131,0,0,16,1,103,102,120,117,48,53,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,70,52,202,156,0,0,32,0,103,102,120,117,48,53,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,213,129,162,162,0,0,32,0,103,102,120,117,48,53,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,192,114,100,225,0,0,32,0,103,102,120,117,48,53,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,160,53,182,139,0,0,32,0,115,110,100,117,48,55,50,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,70,178,42,230,0,0,16,1,114,111,109,54,46,56,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,160,180,72,136,0,0,64,0,114,111,109,55,46,56,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,103,66,34,214,0,0,64,0,114,111,109,56,46,56,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,176,223,1,161,0,0,64,0,101,101,112,114,111,109,45,98,98,97,107,114,97,105,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,71,211,151,127,0,0,16,0,57,51,48,56,55,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,142,61,43,200,1,0,16,1,57,51,48,56,55,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,71,236,225,155,1,0,16,1,57,51,48,56,55,45,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,124,223,19,170,3,0,32,0,57,51,48,56,55,45,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,208,38,79,138,4,0,32,0,57,51,48,56,55,45,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,93,36,6,187,5,0,32,0,57,51,48,56,55,45,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,221,70,45,55,6,0,64,0,57,51,48,56,55,45,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,8,120,166,141,7,0,64,0,56,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,201,177,58,99,0,0,0,8,57,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,162,83,86,67,0,0,0,8,50,46,105,99,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,251,106,245,172,1,0,16,1,49,46,105,99,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,3,243,14,130,1,0,16,1,54,46,105,99,49,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,128,169,57,95,2,0,16,1,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,16,90,63,47,3,0,32,0,115,98,115,45,103,95,48,49,46,105,99,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,120,46,48,33,4,0,32,0,115,98,115,45,103,95,48,51,46,105,99,49,57,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,123,13,224,96,5,0,32,0,115,98,115,45,103,95,48,50,46,105,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,104,182,30,243,9,0,32,0,56,46,105,99,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,234,111,164,117,10,0,32,0,57,46,105,99,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,238,72,20,217,10,0,32,0,115,98,115,45,103,95,48,52,46,105,99,49,51,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,78,204,116,124,6,0,64,0,115,98,115,45,103,95,48,53,46,105,99,49,54,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,227,130,167,240,7,0,64,0,56,50,115,49,51,53,46,105,99,57,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,151,28,237,152,0,0,0,8,56,50,115,49,50,57,46,105,99,54,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,108,184,219,207,0,0,0,8,56,50,115,49,50,51,46,105,99,49,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,199,159,120,15,0,0,0,8,116,115,101,95,48,50,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,170,239,174,228,1,0,16,1,116,115,101,95,48,52,46,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,117,236,200,208,1,0,16,1,116,115,101,95,48,51,46,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,69,10,172,178,1,0,16,1,116,115,101,95,48,53,46,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,6,180,156,167,1,0,16,1,116,115,95,48,49,98,46,52,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,250,202,166,169,2,0,16,1,116,115,117,95,48,56,46,56,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,162,183,240,155,3,0,32,0,116,115,117,95,48,55,46,53,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,164,239,105,148,4,0,32,0,116,115,117,95,48,54,46,52,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,180,14,191,64,4,0,32,0,116,115,95,49,50,46,49,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,158,97,180,228,5,0,32,0,116,115,95,49,49,46,49,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,122,35,48,171,5,0,32,0,116,115,95,49,55,46,49,55,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,228,87,182,222,5,0,32,0,116,115,95,49,54,46,49,53,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,249,181,99,211,5,0,32,0,116,115,95,49,51,46,49,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,4,160,245,168,5,0,32,0,116,115,95,49,56,46,49,56,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,140,148,54,59,5,0,32,0,116,115,95,50,51,46,49,56,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,138,229,251,187,5,0,32,0,116,115,95,50,52,46,49,56,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,100,229,86,241,5,0,32,0,116,115,101,95,49,48,46,49,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,204,234,142,210,6,0,32,0,116,115,117,95,48,57,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,146,146,4,106,6,0,32,0,116,115,101,95,49,53,46,49,51,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,192,147,85,155,6,0,32,0,116,115,117,95,49,52,46,49,49,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,131,173,178,70,6,0,32,0,116,115,101,95,50,48,46,49,51,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,120,183,61,176,6,0,32,0,116,115,117,95,49,57,46,49,49,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,34,39,200,181,6,0,32,0,116,115,101,95,50,50,46,49,55,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,179,222,222,212,6,0,32,0,116,115,117,95,50,49,46,49,53,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,6,112,119,152,6,0,32,0,54,51,115,49,52,49,46,49,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,35,0,141,181,0,0,0,8,99,56,55,53,49,104,45,56,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,24,100,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,100,206,105,69,1,0,16,1,100,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,189,73,148,115,1,0,16,1,104,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,41,167,22,148,2,0,32,0,106,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,139,114,35,233,2,0,32,0,104,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,123,77,152,156,2,0,32,0,106,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,194,250,24,14,2,0,32,0,104,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,103,31,140,2,0,32,0,106,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,80,240,147,28,2,0,32,0,104,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,43,112,161,172,2,0,32,0,106,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,204,150,62,142,2,0,32,0,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,126,222,2,15,3,0,64,0,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,188,75,78,145,3,0,64,0,101,112,114,111,109,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,122,149,229,40,1,0,16,1,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,97,190,112,184,2,0,16,1,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,250,170,136,212,3,0,32,0,119,119,57,51,48,57,49,52,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,93,198,104,249,4,0,32,0,119,119,57,51,48,57,49,55,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,203,115,136,185,5,0,32,0,119,119,57,51,48,57,49,56,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,178,132,238,186,5,0,32,0,119,119,57,51,48,57,49,54,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,230,95,195,7,6,0,64,0,119,119,57,51,48,57,49,53,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,171,91,2,130,7,0,64,0,57,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,162,83,86,67,0,0,0,8,49,48,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,73,211,234,230,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,98,98,109,50,45,104,48,46,55,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,145,123,64,225,1,0,16,1,98,98,109,50,45,108,48,46,55,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,73,59,135,32,1,0,16,1,98,98,109,50,45,115,112,45,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,140,16,216,184,2,0,16,1,98,98,109,50,45,99,48,46,56,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,138,5,206,231,3,0,32,0,98,98,109,50,45,99,49,46,56,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,169,120,106,99,3,0,32,0,98,98,109,50,45,99,50,46,56,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,47,20,194,154,3,0,32,0,98,98,109,50,45,99,51,46,56,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,80,23,175,71,3,0,32,0,98,98,109,50,45,118,48,45,98,46,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,255,85,230,10,4,0,64,0,48,51,48,45,112,103,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,215,72,208,18,1,0,16,1,48,51,48,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,252,184,21,112,2,0,32,0,48,51,48,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,189,25,94,79,3,0,32,0,48,51,48,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,240,75,49,214,3,0,32,0,48,51,48,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,238,223,253,71,3,0,32,0,48,51,48,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,78,28,13,120,3,0,32,0,48,51,48,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,236,102,244,76,4,0,16,1,48,51,48,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,78,54,202,212,5,0,64,0,48,51,48,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,85,68,153,84,5,0,64,0,48,51,48,45,101,112,114,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,221,227,155,197,1,0,16,1,48,51,48,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,252,184,21,112,2,0,32,0,48,51,48,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,189,25,94,79,3,0,32,0,48,51,48,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,240,75,49,214,3,0,32,0,48,51,48,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,238,223,253,71,3,0,32,0,48,51,48,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,78,28,13,120,3,0,32,0,48,51,48,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,236,102,244,76,4,0,16,1,48,51,48,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,78,54,202,212,5,0,64,0,48,51,48,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,85,68,153,84,5,0,64,0,112,114,103,48,95,117,115,97,46,117,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,7,208,73,32,0,0,16,1,112,114,103,50,46,117,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,191,95,170,189,0,0,16,1,112,114,103,49,98,46,117,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,146,180,112,142,0,0,16,1,112,114,103,51,46,117,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,65,249,169,122,0,0,16,1,114,111,109,45,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,162,156,246,13,0,0,32,0,114,111,109,45,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,56,125,22,96,0,0,32,0,114,111,109,45,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,147,165,254,27,0,0,32,0,114,111,109,45,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,148,60,224,190,0,0,32,0,115,110,100,46,117,55,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,150,38,104,86,0,0,16,1,114,111,109,45,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,246,218,116,66,0,0,64,0,114,111,109,45,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,38,36,28,42,0,0,64,0,112,114,103,48,95,107,111,114,101,97,46,117,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,7,201,216,217,0,0,16,1,112,114,103,50,46,117,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,191,95,170,189,0,0,16,1,112,114,103,49,98,46,117,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,146,180,112,142,0,0,16,1,112,114,103,51,46,117,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,65,249,169,122,0,0,16,1,114,111,109,45,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,162,156,246,13,0,0,32,0,114,111,109,45,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,56,125,22,96,0,0,32,0,114,111,109,45,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,147,165,254,27,0,0,32,0,114,111,109,45,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,148,60,224,190,0,0,32,0,115,110,100,46,117,55,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,150,38,104,86,0,0,16,1,114,111,109,45,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,246,218,116,66,0,0,64,0,114,111,109,45,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,38,36,28,42,0,0,64,0,112,114,103,48,98,46,117,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,41,199,63,79,0,0,16,1,112,114,103,50,46,117,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,191,95,170,189,0,0,16,1,112,114,103,49,98,46,117,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,146,180,112,142,0,0,16,1,112,114,103,51,46,117,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,65,249,169,122,0,0,16,1,114,111,109,45,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,162,156,246,13,0,0,32,0,114,111,109,45,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,56,125,22,96,0,0,32,0,114,111,109,45,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,147,165,254,27,0,0,32,0,114,111,109,45,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,148,60,224,190,0,0,32,0,115,110,100,46,117,55,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,150,38,104,86,0,0,16,1,114,111,109,45,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,246,218,116,66,0,0,64,0,114,111,109,45,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,38,36,28,42,0,0,64,0,112,114,103,48,95,99,104,105,110,97,46,117,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,126,31,185,195,0,0,16,1,112,114,103,50,46,117,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,191,95,170,189,0,0,16,1,112,114,103,49,98,46,117,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,146,180,112,142,0,0,16,1,112,114,103,51,46,117,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,65,249,169,122,0,0,16,1,114,111,109,45,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,162,156,246,13,0,0,32,0,114,111,109,45,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,56,125,22,96,0,0,32,0,114,111,109,45,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,147,165,254,27,0,0,32,0,114,111,109,45,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,148,60,224,190,0,0,32,0,115,110,100,46,117,55,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,150,38,104,86,0,0,16,1,114,111,109,45,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,246,218,116,66,0,0,64,0,114,111,109,45,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,38,36,28,42,0,0,64,0,184,40,2,0,1,0,0,0,21,252,146,0,248,191,2,0,184,164,8,0,1,0,0,0,22,252,146,0,64,246,1,0,104,28,8,0,1,0,0,0,114,238,146,0,232,209,1,0,24,38,7,0,1,0,0,0,221,243,146,0,184,160,2,0,144,236,1,0,1,0,0,0,222,243,146,0,136,224,1,0,152,122,6,0,1,0,0,0,19,252,146,0,96,82,2,0,192,72,6,0,1,0,0,0,17,252,146,0,32,56,2,0,200,110,3,0,1,0,0,0,20,252,146,0,152,30,2,0,120,89,3,0,1,0,0,0,23,252,146,0,232,10,2,0,120,74,3,0,1,0,0,0,112,238,146,0,152,138,8,0,24,198,1,0,1,0,0,0,219,243,146,0,40,167,1,0,120,189,1,0,1,0,0,0,217,243,146,0,200,149,1,0,224,22,1,0,1,0,0,0,220,243,146,0,56,126,1,0,160,14,1,0,1,0,0,0,223,243,146,0,32,101,1,0,176,9,1,0,1,0,0,0,113,238,146,0,96,32,8,0,88,212,3,0,1,0,0,0,184,216,146,0,40,185,3,0,248,5,8,0,9,0,0,0,0,4,147,0,32,58,1,0,108,56,95,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,24,218,248,37,1,0,16,1,110,56,95,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,38,6,226,4,1,0,16,1,108,55,95,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,76,36,14,35,1,0,16,1,110,55,95,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,151,38,177,55,1,0,16,1,108,54,95,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,157,251,147,18,1,0,16,1,110,54,95,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,106,32,44,113,1,0,16,1,108,53,95,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,1,101,58,116,1,0,16,1,110,53,95,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,153,191,92,166,1,0,16,1,108,52,95,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,161,176,241,156,1,0,16,1,110,52,95,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,213,128,0,95,1,0,16,1,108,51,95,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,250,247,199,140,1,0,16,1,110,51,95,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,118,35,69,64,1,0,16,1,106,52,95,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,205,223,151,232,2,0,16,1,106,51,95,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,119,222,22,64,2,0,16,1,119,116,95,97,45,52,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,133,129,151,247,1,0,16,1,119,116,95,97,45,52,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,11,149,169,12,1,0,16,1,119,116,95,97,45,52,106,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,101,188,173,27,1,0,16,1,119,116,95,97,45,52,107,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,117,31,52,90,1,0,16,1,119,116,95,97,45,52,109,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,213,167,248,193,1,0,16,1,119,116,95,97,45,52,110,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,210,247,18,178,1,0,16,1,119,116,95,97,45,52,100,45,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,63,165,62,121,2,0,16,1,119,116,95,98,45,53,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,67,223,69,254,3,0,32,0,119,116,95,98,45,53,102,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,255,126,161,135,3,0,32,0,119,116,95,98,45,53,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,82,196,34,218,4,0,32,0,119,116,95,98,45,53,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,31,90,178,79,4,0,32,0,119,116,95,98,45,53,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,4,38,190,117,4,0,32,0,119,116,95,97,45,51,106,45,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,241,112,100,153,5,0,32,0,119,116,95,97,45,51,107,45,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,92,196,78,143,5,0,32,0,119,116,95,97,45,51,109,45,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,88,3,196,74,5,0,32,0,119,116,95,97,45,51,110,45,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,91,239,158,112,5,0,32,0,119,116,95,97,45,51,112,45,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,64,184,24,48,5,0,32,0,119,116,95,97,45,51,115,45,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,212,81,162,5,5,0,32,0,119,116,95,97,45,54,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,155,226,221,165,6,0,64,0,119,116,95,97,45,53,115,45,98,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,4,42,30,153,7,0,32,0,119,116,95,97,45,53,114,45,98,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,183,34,56,251,7,0,32,0,119,116,95,97,45,53,112,45,98,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,125,159,132,149,7,0,32,0,119,116,95,98,45,57,108,45,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,68,135,114,210,7,0,32,0,49,51,54,48,54,54,45,49,49,48,48,46,52,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,9,219,203,42,1,0,16,1,49,51,54,48,54,54,45,49,49,48,49,46,51,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,159,147,161,132,2,0,32,0,102,115,48,48,49,48,48,49,46,101,118,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,115,242,241,74,1,0,16,1,102,115,48,48,49,48,48,50,46,111,100,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,133,122,202,199,1,0,16,1,102,115,48,48,49,48,48,51,46,103,102,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,49,228,23,139,3,0,32,0,102,115,48,48,49,48,48,52,46,112,99,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,229,76,52,249,6,0,64,0,99,52,51,45,49,49,46,53,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,155,252,174,213,2,0,0,0,99,52,51,45,48,57,46,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,177,10,29,233,2,0,0,0,99,52,51,45,49,48,46,52,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,234,231,24,194,2,0,0,0,99,52,51,45,48,56,46,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,159,241,244,94,2,0,0,0,99,52,51,45,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,225,252,38,203,9,0,0,0,99,52,51,45,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,174,34,87,16,11,0,0,0,99,52,51,45,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,186,6,102,66,11,0,0,0,99,52,51,45,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,55,63,149,219,24,0,0,0,99,52,51,45,48,55,45,49,46,53,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,15,178,206,213,2,0,0,0,99,52,51,45,48,53,45,49,46,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,55,187,243,166,2,0,0,0,99,52,51,45,48,54,45,49,46,52,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,2,24,51,15,2,0,0,0,99,52,51,45,48,52,45,49,46,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,20,36,106,224,2,0,0,0,99,52,51,45,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,225,252,38,203,9,0,0,0,99,52,51,45,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,174,34,87,16,11,0,0,0,99,52,51,45,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,186,6,102,66,11,0,0,0,99,52,51,45,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,55,63,149,219,24,0,0,0,97,102,95,48,54,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,3,102,50,197,1,0,16,1,97,102,95,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,66,149,142,69,1,0,16,1,97,102,95,48,55,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,245,23,133,204,1,0,16,1,97,102,95,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,32,242,78,33,1,0,16,1,97,102,95,48,56,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,54,212,209,1,0,16,1,97,102,95,48,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,45,254,225,187,1,0,16,1,97,102,95,49,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,135,203,234,197,2,0,16,1,97,102,95,48,57,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,45,233,37,112,3,0,32,0,97,102,95,48,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,79,175,211,68,4,0,32,0,97,102,95,48,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,171,108,7,146,4,0,32,0,97,102,95,49,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,167,197,93,140,5,0,32,0,97,102,95,49,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,163,88,106,19,5,0,32,0,97,102,95,49,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,60,71,108,180,6,0,32,0,97,102,95,49,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,254,107,203,35,6,0,32,0,49,54,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,57,247,176,1,0,16,1,49,55,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,151,242,39,152,1,0,16,1,97,55,53,45,48,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,186,116,139,3,3,0,32,0,97,55,53,45,48,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,153,225,250,113,3,0,32,0,97,55,53,45,48,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,226,116,99,199,3,0,32,0,56,50,115,49,50,57,46,53,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,77,182,112,250,4,0,32,0,56,50,115,49,50,57,46,53,106,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,132,152,166,204,4,0,32,0,56,50,115,49,50,57,46,53,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,245,43,77,62,4,0,32,0,56,50,115,49,50,57,46,53,107,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,90,98,93,8,4,0,32,0,56,50,115,49,50,57,46,53,109,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,8,177,224,15,4,0,32,0,54,51,115,49,52,49,46,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,117,246,83,85,4,0,32,0,112,97,108,49,54,114,56,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,23,25,71,54,0,0,32,8,11,0,0,0,255,255,95,0,0,0,0,0,0,0,0,0,254,0,2,0,176,110,8,0,11,0,0,0,1,1,1,0,96,135,7,0,11,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,11,0,0,0,1,2,2,0,96,135,7,0,11,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,72,202,5,0,11,0,0,0,1,8,8,0,80,246,3,0,11,0,0,0,1,8,0,0,112,212,3,0,0,0,0,0,254,0,2,0,64,37,5,0,11,0,0,0,1,16,16,0,32,81,8,0,11,0,0,0,1,16,0,0,112,133,8,0,0,0,0,0,254,0,2,0,128,129,4,0,11,0,0,0,1,32,0,0,208,75,4,0,11,0,0,0,1,32,32,0,8,49,4,0,0,0,0,0,254,0,2,0,200,30,2,0,11,0,0,0,1,128,0,0,120,97,1,0,11,0,0,0,1,128,128,0,96,19,1,0,0,0,0,0,97,114,107,103,99,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,230,50,66,197,1,0,16,1,97,114,107,103,99,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,84,71,13,159,1,0,16,1,97,55,53,45,48,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,186,116,139,3,3,0,32,0,97,55,53,45,48,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,153,225,250,113,3,0,32,0,97,55,53,45,48,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,226,116,99,199,3,0,32,0,97,55,53,45,48,55,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,137,178,248,10,4,0,32,0,97,55,53,45,48,56,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,251,2,176,171,4,0,32,0,97,55,53,45,48,57,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,119,194,198,167,4,0,32,0,11,0,0,0,255,255,127,0,0,0,0,0,0,0,0,0,254,0,2,0,176,76,8,0,11,0,0,0,1,1,1,0,248,38,7,0,11,0,0,0,1,1,0,0,120,54,8,0,0,0,0,0,254,0,2,0,144,212,8,0,11,0,0,0])
.concat([1,2,2,0,96,135,7,0,11,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,72,202,5,0,11,0,0,0,1,8,8,0,80,246,3,0,11,0,0,0,1,8,0,0,112,212,3,0,0,0,0,0,254,0,2,0,64,37,5,0,11,0,0,0,1,16,16,0,96,68,8,0,11,0,0,0,1,16,0,0,224,64,8,0,0,0,0,0,254,0,2,0,128,129,4,0,11,0,0,0,1,32,32,0,8,49,4,0,11,0,0,0,1,32,0,0,72,246,3,0,0,0,0,0,254,0,2,0,32,4,2,0,11,0,0,0,1,64,64,0,128,230,7,0,11,0,0,0,1,64,0,0,184,164,6,0,0,0,0,0,254,0,2,0,200,30,2,0,11,0,0,0,1,128,0,0,120,97,1,0,11,0,0,0,1,128,128,0,96,19,1,0,97,114,99,97,100,105,97,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,9,214,70,139,1,0,16,1,114,104,112,57,52,48,57,57,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,225,236,1,254,2,0,16,1,97,114,99,97,100,105,97,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,8,64,44,28,3,0,32,0,114,104,112,57,52,48,57,57,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,123,238,110,7,4,0,32,0,114,104,112,57,52,48,57,57,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,7,47,137,73,5,0,32,0,114,104,112,57,52,48,57,57,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,240,71,46,234,5,0,32,0,114,104,112,57,52,48,57,57,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,57,184,44,81,5,0,32,0,114,104,112,57,52,48,57,57,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,126,84,153,13,6,0,64,0,114,104,112,57,52,48,57,57,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,147,186,94,81,7,0,64,0,114,104,112,57,52,48,57,57,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,90,14,168,241,7,0,64,0,114,104,112,57,52,48,57,57,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,126,84,153,13,7,0,64,0,114,104,112,57,52,48,57,57,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,126,84,153,13,7,0,64,0,112,114,111,109,49,46,117,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,110,119,153,66,0,0,0,8,112,114,111,109,50,46,117,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,73,211,234,230,0,0,0,8,112,114,111,109,51,46,117,54,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,198,152,79,48,0,0,0,8,105,99,49,114,101,118,50,46,56,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,184,152,28,94,0,0,16,1,105,99,50,114,101,118,50,46,56,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,126,88,47,9,0,0,16,1,105,99,51,114,101,118,50,46,56,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,35,95,20,21,0,0,16,1,105,99,52,114,101,118,50,46,57,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,68,123,183,50,0,0,16,1,116,118,103,45,57,49,46,105,99,56,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,34,120,99,196,0,0,32,0,116,118,103,45,57,50,46,105,99,56,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,109,134,198,247,0,0,32,0,116,118,103,45,57,51,46,105,99,56,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,141,212,172,113,0,0,32,0,116,118,103,45,57,52,46,105,99,56,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,154,11,22,130,0,0,32,0,115,117,110,45,56,50,49,50,46,105,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,30,97,105,136,0,0,0,8,110,49,95,104,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,180,51,8,60,0,0,16,1,97,109,98,117,115,104,46,103,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,9,20,41,144,0,0,16,1,97,109,98,117,115,104,46,102,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,41,202,35,208,0,0,16,1,97,109,98,117,115,104,46,101,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,238,211,194,108,0,0,16,1,97,109,98,117,115,104,46,110,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,133,220,192,236,0,0,32,0,97,109,98,117,115,104,46,109,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,138,169,108,232,0,0,32,0,97,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,17,245,39,95,0,0,32,0,98,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,59,253,3,27,0,0,0,8,49,51,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,15,151,126,84,0,0,0,8,49,52,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,231,140,42,98,0,0,0,8,97,109,98,117,115,104,46,104,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,99,101,48,206,0,0,16,1,97,109,98,117,115,104,46,103,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,9,20,41,144,0,0,16,1,97,109,98,117,115,104,46,102,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,41,202,35,208,0,0,16,1,97,109,98,117,115,104,46,101,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,238,211,194,108,0,0,16,1,97,109,98,117,115,104,46,110,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,133,220,192,236,0,0,32,0,97,109,98,117,115,104,46,109,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,138,169,108,232,0,0,32,0,97,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,17,245,39,95,0,0,32,0,98,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,59,253,3,27,0,0,0,8,49,51,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,15,151,126,84,0,0,0,8,49,52,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,231,140,42,98,0,0,0,8,97,49,95,104,97,99,107,46,105,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,157,20,205,167,0,0,16,1,97,50,46,103,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,138,216,40,131,0,0,16,1,97,51,46,102,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,181,122,181,141,0,0,16,1,97,52,46,101,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,164,210,52,74,0,0,16,1,102,97,50,46,110,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,186,52,241,231,0,0,32,0,102,97,49,46,109,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,158,150,16,173,0,0,32,0,97,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,17,245,39,95,0,0,32,0,98,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,59,253,3,27,0,0,0,8,49,51,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,15,151,126,84,0,0,0,8,49,52,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,231,140,42,98,0,0,0,8,48,48,55,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,71,111,38,91,1,0,16,1,48,48,55,45,112,50,46,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,68,16,156,235,1,0,16,1,48,48,55,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,207,154,236,133,2,0,32,0,48,48,55,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,243,143,186,143,3,0,32,0,48,48,55,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,69,41,173,77,3,0,32,0,48,48,55,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,78,153,194,104,3,0,32,0,48,48,55,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,73,131,88,125,3,0,32,0,48,48,55,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,205,226,223,40,4,0,16,1,48,48,55,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,49,185,93,205,5,0,64,0,48,48,55,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,116,181,233,99,5,0,64,0,56,55,53,95,110,48,50,46,101,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,46,97,221,36,1,0,16,1,56,55,53,95,110,48,49,46,99,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,156,245,108,16,1,0,16,1,56,55,53,95,98,48,51,46,103,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,131,210,196,26,2,0,16,1,56,55,53,98,49,49,46,107,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,133,200,197,137,3,0,32,0,56,55,53,98,48,55,46,106,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,102,109,197,233,3,0,32,0,56,55,53,98,49,50,46,107,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,23,220,107,234,3,0,32,0,56,55,53,98,48,56,46,106,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,102,121,56,249,3,0,32,0,56,55,53,98,49,48,46,107,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,177,53,16,11,4,0,32,0,56,55,53,98,48,54,46,106,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,102,5,26,8,4,0,32,0,56,55,53,98,48,57,46,107,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,25,60,107,231,4,0,32,0,56,55,53,98,48,53,46,106,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,242,97,162,25,4,0,32,0,56,55,53,98,48,52,46,101,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,200,154,32,78,5,0,64,0,56,50,49,97,48,56,46,104,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,88,165,125,6,0,0,8,56,55,53,95,109,48,50,46,101,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,229,116,167,84,1,0,16,1,56,55,53,95,109,48,49,46,99,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,220,211,99,22,1,0,16,1,56,55,53,95,107,48,51,46,103,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,77,38,134,189,2,0,16,1,56,55,53,98,49,49,46,107,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,133,200,197,137,3,0,32,0,56,55,53,98,48,55,46,106,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,102,109,197,233,3,0,32,0,56,55,53,98,49,50,46,107,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,23,220,107,234,3,0,32,0,56,55,53,98,48,56,46,106,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,102,121,56,249,3,0,32,0,56,55,53,98,49,48,46,107,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,177,53,16,11,4,0,32,0,56,55,53,98,48,54,46,106,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,102,5,26,8,4,0,32,0,56,55,53,98,48,57,46,107,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,25,60,107,231,4,0,32,0,56,55,53,98,48,53,46,106,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,242,97,162,25,4,0,32,0,56,55,53,98,48,52,46,101,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,200,154,32,78,5,0,64,0,56,50,49,97,48,56,46,104,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,88,165,125,6,0,0,8,56,55,53,95,114,48,50,46,101,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,17,79,62,151,1,0,16,1,56,55,53,95,109,48,49,46,99,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,220,211,99,22,1,0,16,1,56,55,53,95,107,48,51,46,103,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,77,38,134,189,2,0,16,1,56,55,53,98,49,49,46,107,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,133,200,197,137,3,0,32,0,56,55,53,98,48,55,46,106,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,102,109,197,233,3,0,32,0,56,55,53,98,49,50,46,107,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,23,220,107,234,3,0,32,0,56,55,53,98,48,56,46,106,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,102,121,56,249,3,0,32,0,56,55,53,98,49,48,46,107,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,177,53,16,11,4,0,32,0,56,55,53,98,48,54,46,106,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,102,5,26,8,4,0,32,0,56,55,53,98,48,57,46,107,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,25,60,107,231,4,0,32,0,56,55,53,98,48,53,46,106,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,242,97,162,25,4,0,32,0,56,55,53,98,48,52,46,101,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,200,154,32,78,5,0,64,0,56,50,49,97,48,56,46,104,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,88,165,125,6,0,0,8,56,55,53,95,119,51,95,50,46,101,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,181,247,23,249,1,0,16,1,56,55,53,95,119,51,95,49,46,99,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,251,6,0,60,1,0,16,1,56,55,53,95,98,48,51,46,103,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,131,210,196,26,2,0,16,1,56,55,53,98,49,49,46,107,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,133,200,197,137,3,0,32,0,56,55,53,98,48,55,46,106,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,102,109,197,233,3,0,32,0,56,55,53,98,49,50,46,107,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,23,220,107,234,3,0,32,0,56,55,53,98,48,56,46,106,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,102,121,56,249,3,0,32,0,56,55,53,98,49,48,46,107,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,177,53,16,11,4,0,32,0,56,55,53,98,48,54,46,106,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,102,5,26,8,4,0,32,0,56,55,53,98,48,57,46,107,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,25,60,107,231,4,0,32,0,56,55,53,98,48,53,46,106,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,242,97,162,25,4,0,32,0,56,55,53,98,48,52,46,101,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,200,154,32,78,5,0,64,0,56,50,49,97,48,56,46,104,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,88,165,125,6,0,0,8,56,55,53,95,112,48,50,46,101,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,125,112,221,78,1,0,16,1,56,55,53,95,110,48,49,46,99,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,156,245,108,16,1,0,16,1,56,55,53,95,98,48,51,46,103,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,131,210,196,26,2,0,16,1,56,55,53,98,49,49,46,107,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,133,200,197,137,3,0,32,0,56,55,53,98,48,55,46,106,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,102,109,197,233,3,0,32,0,56,55,53,98,49,50,46,107,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,23,220,107,234,3,0,32,0,56,55,53,98,48,56,46,106,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,102,121,56,249,3,0,32,0,56,55,53,98,49,48,46,107,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,177,53,16,11,4,0,32,0,56,55,53,98,48,54,46,106,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,102,5,26,8,4,0,32,0,56,55,53,98,48,57,46,107,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,25,60,107,231,4,0,32,0,56,55,53,98,48,53,46,106,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,242,97,162,25,4,0,32,0,56,55,53,98,48,52,46,101,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,200,154,32,78,5,0,64,0,56,50,49,97,48,56,46,104,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,88,165,125,6,0,0,8,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,170,1,215,56,1,0,16,1,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,243,53,14,61,1,0,16,1,54,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,137,238,59,130,1,0,16,1,54,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,47,3,77,71,1,0,16,1,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,193,21,179,90,1,0,16,1,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,87,3,141,67,1,0,16,1,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,248,184,188,133,2,0,32,0,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,98,8,229,56,2,0,32,0,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,134,92,113,181,2,0,32,0,53,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,179,134,48,113,2,0,32,0,56,50,115,49,50,51,46,101,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,189,80,198,47,3,0,32,0,56,50,115,49,50,57,46,97,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,228,168,179,62,3,0,32,0,56,50,115,49,50,54,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,134,204,169,4,0,64,0,56,50,115,49,50,54,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,97,98,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,245,78,41,82,0,0,0,8,15,0,0,0,255,255,255,0,0,0,0,0,16,0,0,0,255,255,255,0,0,0,0,0,17,0,0,0,255,255,217,0,0,0,0,0,18,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,16,27,6,0,15,0,0,0,1,16,16,0,96,135,7,0,15,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,2,0,200,30,2,0,16,0,0,0,1,128,128,0,120,97,1,0,16,0,0,0,1,128,0,0,96,19,1,0,0,0,0,0,254,0,4,0,32,4,2,0,17,0,0,0,1,3,3,0,160,36,8,0,17,0,0,0,1,3,1,0,208,239,7,0,17,0,0,0,1,3,2,0,120,187,7,0,17,0,0,0,1,3,0,0,16,227,4,0,0,0,0,0,254,0,4,0,128,129,4,0,17,0,0,0,1,12,0,0,192,255,2,0,17,0,0,0,1,12,4,0,208,75,4,0,17,0,0,0,1,12,8,0,8,49,4,0,17,0,0,0,1,12,12,0,72,246,3,0,0,0,0,0,254,0,4,0,64,37,5,0,17,0,0,0,1,48,0,0,176,116,6,0,17,0,0,0,1,48,16,0,80,113,6,0,17,0,0,0,1,48,32,0,80,110,6,0,17,0,0,0,1,48,48,0,120,7,5,0,0,0,0,0,254,0,2,0,72,202,5,0,17,0,0,0,1,64,64,0,248,38,7,0,17,0,0,0,1,64,0,0,112,212,3,0,97,100,45,99,45,104,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,118,2,20,18,1,0,16,1,97,100,45,99,45,108,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,29,185,192,74,1,0,16,1,97,100,45,99,45,104,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,163,252,124,159,1,0,16,1,97,100,45,99,45,108,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,247,67,211,157,1,0,16,1,97,100,45,48,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,155,89,13,47,2,0,32,0,97,100,45,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,107,133,101,152,2,0,32,0,97,100,45,50,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,242,174,146,211,2,0,32,0,97,100,45,51,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,195,64,50,146,2,0,32,0,97,100,45,97,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,71,75,19,206,3,0,32,0,97,100,45,97,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,83,216,127,9,3,0,32,0,97,100,45,97,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,185,193,148,106,3,0,32,0,97,100,45,97,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,73,195,55,102,3,0,32,0,97,100,45,98,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,71,75,19,206,4,0,32,0,97,100,45,98,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,83,216,127,9,4,0,32,0,97,100,45,98,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,185,193,148,106,4,0,32,0,97,100,45,98,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,73,195,55,102,4,0,32,0,97,100,45,118,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,77,71,159,51,5,0,64,0,97,105,114,100,117,101,108,95,105,56,55,53,49,46,109,99,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,24,112,97,108,99,111,49,46,105,99,56,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,117,81,135,161,1,0,16,1,112,97,108,99,111,50,46,105,99,57,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,195,130,49,171,1,0,16,1,112,97,108,99,111,51,46,105,99,55,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,125,201,33,42,2,0,16,1,112,97,108,99,111,52,46,105,99,55,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,254,156,253,157,3,0,64,0,112,114,111,109,50,57,45,109,98,55,49,49,52,104,46,105,99,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,167,189,91,178,0,0,0,8,98,112,57,54,50,97,46,117,52,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,70,80,129,36,0,0,16,1,98,112,57,54,50,97,46,117,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,190,221,202,6,0,0,16,1,98,112,57,54,50,97,46,117,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,57,164,141,133,0,0,32,0,98,112,57,54,50,97,46,117,55,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,94,163,43,234,0,0,32,0,98,112,57,54,50,97,46,117,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,7,161,217,252,0,0,32,0,98,112,57,54,50,97,46,117,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,9,52,250,12,0,0,32,0,98,112,57,54,50,97,46,117,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,87,137,96,109,0,0,32,0,98,112,57,54,50,97,46,117,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,154,207,95,19,0,0,32,0,98,112,57,54,50,97,46,117,52,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,206,161,0,174,0,0,64,0,98,112,57,54,50,97,46,117,52,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,55,151,78,109,0,0,64,0,97,103,97,108,108,101,116,95,101,117,114,111,112,101,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,101,191,56,236,0,0,16,1,49,46,117,52,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,162,240,223,111,0,0,16,1,53,51,56,97,53,52,46,49,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,242,77,44,77,0,0,32,0,49,53,51,56,97,53,52,46,49,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,158,16,109,40,0,0,32,0,53,51,56,97,53,51,46,117,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,11,142,13,99,0,0,32,0,53,51,52,103,56,102,46,117,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,38,9,206,118,0,0,32,0,50,46,49,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,236,100,239,161,0,0,16,1,105,116,45,49,57,45,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,61,114,66,109,0,0,64,0,105,116,45,49,57,45,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,29,219,187,205,0,0,64,0,18,0,0,0,255,255,0,0,0,0,0,0,19,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,72,209,1,0,18,0,0,0,1,1,0,0,176,111,1,0,18,0,0,0,1,1,1,0,232,78,1,0,0,0,0,0,254,0,8,0,184,40,2,0,18,0,0,0,1,14,0,0,184,108,4,0,18,0,0,0,1,14,2,0,248,82,4,0,18,0,0,0,1,14,4,0,208,55,4,0,18,0,0,0,1,14,6,0,152,160,5,0,18,0,0,0,1,14,8,0,248,253,3,0,18,0,0,0,1,14,10,0,104,221,3,0,18,0,0,0,1,14,12,0,80,191,3,0,18,0,0,0,1,14,14,0,160,165,3,0,0,0,0,0,254,0,8,0,184,164,8,0,18,0,0,0,1,112,0,0,184,108,4,0,18,0,0,0,1,112,16,0,248,82,4,0,18,0,0,0,1,112,32,0,208,55,4,0,18,0,0,0,1,112,48,0,152,160,5,0,18,0,0,0,1,112,64,0,248,253,3,0,18,0,0,0,1,112,80,0,104,221,3,0,18,0,0,0,1,112,96,0,80,191,3,0,18,0,0,0,1,112,112,0,160,165,3,0,0,0,0,0,254,0,2,0,24,172,6,0,18,0,0,0,1,128,0,0,96,135,7,0,18,0,0,0,1,128,128,0,152,182,7,0,0,0,0,0,254,0,2,0,128,147,2,0,19,0,0,0,1,1,0,0,96,135,7,0,19,0,0,0,1,1,1,0,152,182,7,0,0,0,0,0,254,0,2,0,200,135,2,0,19,0,0,0,1,2,0,0,96,135,7,0,19,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,19,0,0,0,1,12,0,0,248,38,7,0,19,0,0,0,1,12,4,0,80,246,3,0,19,0,0,0,1,12,8,0,112,212,3,0,19,0,0,0,1,12,12,0,248,160,5,0,0,0,0,0,254,0,4,0,128,129,4,0,19,0,0,0,1,48,0,0,8,49,4,0,19,0,0,0,1,48,16,0,192,255,2,0,19,0,0,0,1,48,32,0,208,75,4,0,19,0,0,0,1,48,48,0,152,21,4,0,0,0,0,0,254,0,2,0,64,37,5,0,19,0,0,0,1,64,0,0,240,159,4,0,19,0,0,0,1,64,64,0,200,143,2,0,0,0,0,0,254,0,2,0,16,17,8,0,19,0,0,0,1,128,0,0,96,135,7,0,19,0,0,0,1,128,128,0,152,182,7,0,168,86,7,0,1,0,0,0,205,255,146,0,248,191,2,0,56,210,6,0,1,0,0,0,200,255,146,0,192,135,2,0,24,163,6,0,1,0,0,0,203,255,146,0,240,108,2,0,152,122,6,0,1,0,0,0,201,255,146,0,96,82,2,0,192,72,6,0,1,0,0,0,202,255,146,0,32,56,2,0,200,110,3,0,1,0,0,0,69,247,146,0,152,30,2,0,120,89,3,0,1,0,0,0,70,247,146,0,232,10,2,0,40,246,1,0,1,0,0,0,206,255,146,0,64,246,1,0,176,223,1,0,1,0,0,0,64,247,146,0,72,198,1,0,192,209,1,0,1,0,0,0,67,247,146,0,24,182,1,0,24,198,1,0,1,0,0,0,65,247,146,0,40,167,1,0,120,189,1,0,1,0,0,0,66,247,146,0,200,149,1,0,224,22,1,0,1,0,0,0,68,247,146,0,56,126,1,0,88,212,3,0,1,0,0,0,32,219,146,0,40,185,3,0,16,17,8,0,1,0,0,0,207,255,146,0,224,12,8,0,72,65,1,0,9,0,0,0,128,5,147,0,32,58,1,0,18,0,0,0,255,255,255,0,0,0,0,0,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,18,0,0,0,1,1,1,0,96,135,7,0,18,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,18,0,0,0,1,2,0,0,96,135,7,0,18,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,0,0,232,75,4,0,18,0,0,0,1,128,128,0,96,135,7,0,18,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,0,0,128,129,4,0,19,0,0,0,1,3,2,0,208,75,4,0,19,0,0,0,1,3,3,0,8,49,4,0,19,0,0,0,1,3,1,0,152,21,4,0,19,0,0,0,1,3,0,0,72,246,3,0,0,0,0,0,254,0,0,0,72,202,5,0,19,0,0,0,1,12,8,0,80,246,3,0,19,0,0,0,1,12,12,0,248,38,7,0,19,0,0,0,1,12,4,0,112,212,3,0,19,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,0,0,32,4,2,0,19,0,0,0,1,240,160,0,144,160,3,0,19,0,0,0,1,240,176,0,96,135,3,0,19,0,0,0,1,240,192,0,32,136,7,0,19,0,0,0,1,240,208,0,40,88,7,0,19,0,0,0,1,240,16,0,40,28,4,0,19,0,0,0,1,240,224,0,96,39,7,0,19,0,0,0,1,240,32,0,192,24,7,0,19,0,0,0,1,240,48,0,120,113,6,0,19,0,0,0,1,240,240,0,144,251,6,0,19,0,0,0,1,240,64,0,120,211,6,0,19,0,0,0,1,240,144,0,184,164,6,0,19,0,0,0,1,240,128,0,80,74,6,0,19,0,0,0,1,240,112,0,192,32,6,0,19,0,0,0,1,240,96,0,192,234,2,0,19,0,0,0,1,240,80,0,32,242,5,0,19,0,0,0,1,240,0,0,16,227,4,0,0,0,0,0,122,49,46,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,154,52,40,76,1,0,16,1,122,122,95,100,50,46,55,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,69,141,109,50,1,0,16,1,122,122,95,100,52,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,42,217,78,169,1,0,16,1,122,122,95,100,51,46,55,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,122,94,206,1,0,16,1,122,122,95,54,46,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,42,22,12,120,4,0,32,0,122,122,95,53,46,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,197,254,205,243,4,0,32,0,122,122,98,112,114,95,101,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,208,109,72,170,7,0,32,0,117,110,105,99,111,95,50,46,114,111,109,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,9,149,89,30,0,0,16,1,117,110,105,99,111,95,51,46,114,111,109,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,247,238,138,88,0,0,16,1,117,110,105,99,111,95,122,112,111,98,106,95,122,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,163,104,39,31,0,0,32,0,117,110,105,99,111,95,122,112,111,98,106,95,122,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,58,243,52,222,0,0,32,0,117,110,105,99,111,95,122,112,111,98,106,95,122,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,247,87,166,215,0,0,32,0,117,110,105,99,111,95,122,112,111,98,106,95,122,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,141,47,236,58,0,0,32,0,117,110,105,99,111,95,122,112,115,99,114,95,122,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,240,60,229,225,0,0,32,0,117,110,105,99,111,95,122,112,115,99,114,95,122,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,80,72,125,13,0,0,32,0,117,110,105,99,111,95,122,112,115,99,114,95,122,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,50,143,23,187,0,0,32,0,117,110,105,99,111,95,122,112,115,99,114,95,122,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,229,2,47,103,0,0,32,0,117,110,105,99,111,95,49,46,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,250,132,35,253,0,0,64,0,13,0,0,0,255,255,8,0,0,0,0,0,14,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,16,227,4,0,13,0,0,0,1,2,0,0,96,135,7,0,13,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,13,0,0,0,1,8,0,0,96,135,7,0,13,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,8,0,32,4,2,0,13,0,0,0,1,224,224,0,104,54,4,0,13,0,0,0,1,224,192,0,80,252,6,0,13,0,0,0,1,224,160,0,16,242,7,0,13,0,0,0,1,224,128,0,104,236,7,0,13,0,0,0,1,224,0,0,128,230,7,0,13,0,0,0,1,224,32,0,184,164,6,0,13,0,0,0,1,224,64,0,80,74,6,0,13,0,0,0,1,224,96,0,192,32,6,0,0,0,0,0,254,0,3,0,72,202,5,0,14,0,0,0,1,48,16,0,80,246,3,0,14,0,0,0,1,48,0,0,248,38,7,0,14,0,0,0,1,48,32,0,112,212,3,0,0,0,0,0,254,0,4,0,128,129,4,0,14,0,0,0,1,192,64,0,208,75,4,0,14,0,0,0,1,192,0,0,8,49,4,0,14,0,0,0,1,192,128,0,152,21,4,0,14,0,0,0,1,192,192,0,72,246,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,118,115,101,46,48,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,59,189,229,90,1,0,16,1,120,118,115,101,46,48,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,46,192,185,94,1,0,16,1,120,118,115,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,93,2,182,125,1,0,16,1,120,118,115,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,92,199,226,232,1,0,16,1,120,118,115,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,237,171,240,8,1,0,16,1,120,118,115,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,117,150,146,129,1,0,16,1,120,118,115,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,107,243,65,150,1,0,16,1,120,118,115,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,253,78,104,246,5,0,32,0,120,118,115,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,33,146,16,41,5,0,32,0,120,118,115,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,116,52,219,146,5,0,32,0,120,118,115,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,60,71,51,55,5,0,32,0,120,118,115,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,65,46,172,188,5,0,32,0,120,118,115,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,114,162,4,234,5,0,32,0,120,118,115,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,106,248,222,176,5,0,32,0,120,118,115,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,159,255,64,75,5,0,32,0,120,118,115,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,58,233,153,57,10,0,16,1,120,118,115,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,233,222,27,16,10,0,16,1,120,118,115,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,188,205,173,156,12,0,64,0,120,118,115,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,96,228,17,123,12,0,64,0,120,109,110,117,46,48,51,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,14,235,175,11,1,0,16,1,120,109,110,117,46,48,52,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,227,218,155,194,1,0,16,1,120,109,110,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,89,119,13,172,1,0,16,1,120,109,110,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,40,163,134,27,1,0,16,1,120,109,110,46,48,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,68,42,20,44,1,0,16,1,120,109,110,46,48,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,79,212,18,247,1,0,16,1,120,109,110,46,48,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,232,202,65,146,1,0,16,1,120,109,110,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,185,234,192,83,1,0,16,1,120,109,110,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,115,240,77,191,5,0,32,0,120,109,110,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,239,76,126,77,5,0,32,0,120,109,110,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,23,234,62,81,5,0,32,0,120,109,110,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,252,151,56,210,5,0,32,0,120,109,110,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,183,55,130,119,5,0,32,0,120,109,110,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,72,105,179,103,5,0,32,0,120,109,110,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,76,124,90,1,5,0,32,0,120,109,110,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,88,39,222,157,5,0,32,0,120,109,110,46,48,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,234,121,244,64,10,0,16,1,120,109,110,46,48,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,173,181,217,57,10,0,16,1,120,109,110,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,188,166,72,200,12,0,64,0,120,109,110,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,143,24,156,114,12,0,64,0,120,109,110,106,46,48,51,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,95,159,242,13,1,0,16,1,120,109,110,106,46,48,52,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,59,131,101,74,1,0,16,1,120,109,110,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,89,119,13,172,1,0,16,1,120,109,110,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,40,163,134,27,1,0,16,1,120,109,110,46,48,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,68,42,20,44,1,0,16,1,120,109,110,46,48,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,79,212,18,247,1,0,16,1,120,109,110,46,48,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,232,202,65,146,1,0,16,1,120,109,110,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,185,234,192,83,1,0,16,1,120,109,110,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,115,240,77,191,5,0,32,0,120,109,110,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,239,76,126,77,5,0,32,0,120,109,110,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,23,234,62,81,5,0,32,0,120,109,110,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,252,151,56,210,5,0,32,0,120,109,110,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,183,55,130,119,5,0,32,0,120,109,110,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,72,105,179,103,5,0,32,0,120,109,110,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,76,124,90,1,5,0,32,0,120,109,110,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,88,39,222,157,5,0,32,0,120,109,110,46,48,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,234,121,244,64,10,0,16,1,120,109,110,46,48,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,173,181,217,57,10,0,16,1,120,109,110,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,188,166,72,200,12,0,64,0,120,109,110,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,143,24,156,114,12,0,64,0,120,109,110,104,46,48,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,144,90,184,228,1,0,16,1,120,109,110,104,46,48,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,6,20,254,125,1,0,16,1,120,109,110,104,46,48,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,15,237,176,135,1,0,16,1,120,109,110,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,40,163,134,27,1,0,16,1,120,109,110,46,48,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,68,42,20,44,1,0,16,1,120,109,110,46,48,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,79,212,18,247,1,0,16,1,120,109,110,46,48,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,232,202,65,146,1,0,16,1,120,109,110,104,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,164,176,54,203,1,0,16,1,120,109,110,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,115,240,77,191,5,0,32,0,120,109,110,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,239,76,126,77,5,0,32,0,120,109,110,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,23,234,62,81,5,0,32,0,120,109,110,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,252,151,56,210,5,0,32,0,120,109,110,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,183,55,130,119,5,0,32,0,120,109,110,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,72,105,179,103,5,0,32,0,120,109,110,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,76,124,90,1,5,0,32,0,120,109,110,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,88,39,222,157,5,0,32,0,120,109,110,46,48,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,234,121,244,64,10,0,16,1,120,109,110,46,48,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,173,181,217,57,10,0,16,1,120,109,110,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,188,166,72,200,12,0,64,0,120,109,110,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,143,24,156,114,12,0,64,0,120,109,110,97,46,48,51,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,231,230,173,241,1,0,16,1,120,109,110,97,46,48,52,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,61,132,168,181,1,0,16,1,120,109,110,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,89,119,13,172,1,0,16,1,120,109,110,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,40,163,134,27,1,0,16,1,120,109,110,46,48,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,68,42,20,44,1,0,16,1,120,109,110,46,48,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,79,212,18,247,1,0,16,1,120,109,110,46,48,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,232,202,65,146,1,0,16,1,120,109,110,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,185,234,192,83,1,0,16,1,120,109,110,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,115,240,77,191,5,0,32,0,120,109,110,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,239,76,126,77,5,0,32,0,120,109,110,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,23,234,62,81,5,0,32,0,120,109,110,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,252,151,56,210,5,0,32,0,120,109,110,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,183,55,130,119,5,0,32,0,120,109,110,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,72,105,179,103,5,0,32,0,120,109,110,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,76,124,90,1,5,0,32,0,120,109,110,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,88,39,222,157,5,0,32,0,120,109,110,46,48,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,234,121,244,64,10,0,16,1,120,109,110,46,48,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,173,181,217,57,10,0,16,1,120,109,110,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,188,166,72,200,12,0,64,0,120,109,110,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,143,24,156,114,12,0,64,0,101,112,114,45,49,52,55,51,48,98,46,97,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,122,193,43,231,1,0,16,1,101,112,114,45,49,52,55,51,49,98,46,97,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,185,53,50,110,1,0,16,1,109,112,114,45,49,52,55,49,57,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,67,199,88,139,2,0,32,0,109,112,114,45,49,52,55,50,48,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,244,25,109,249,2,0,32,0,109,112,114,45,49,52,55,50,49,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,29,217,206,196,2,0,32,0,109,112,114,45,49,52,55,50,54,46,99,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,211,209,19,114,3,0,32,0,109,112,114,45,49,52,55,51,50,46,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,73,213,206,4,3,0,32,0,109,112,114,45,49,52,55,50,55,46,99,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,240,224,116,59,3,0,32,0,109,112,114,45,49,52,55,51,51,46,97,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,79,68,160,109,3,0,32,0,109,112,114,45,49,52,55,50,56,46,99,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,135,21,146,91,3,0,32,0,109,112,114,45,49,52,55,51,52,46,97,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,217,94,63,111,3,0,32,0,101,112,114,45,49,52,55,50,53,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,79,104,41,43,4,0,16,1,109,112,114,45,49,52,55,50,52,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,134,234,203,71,19,0,64,0,109,112,114,45,49,52,55,50,51,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,220,90,188,19,0,64,0,109,112,114,45,49,52,55,50,50,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,248,129,208,27,19,0,64,0,51,49,55,45,48,49,57,55,98,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,180,197,183,245,5,0,16,1,18,0,0,0,255,255,255,0,0,0,0,0,19,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,18,0,0,0,1,15,9,0,72,101,2,0,18,0,0,0,1,15,8,0,192,86,2,0,18,0,0,0,1,15,7,0,24,72,2,0,18,0,0,0,1,15,6,0,112,59,2,0,18,0,0,0,1,15,12,0,40,44,2,0,18,0,0,0,1,15,11,0,200,32,2,0,18,0,0,0,1,15,10,0,144,22,2,0,18,0,0,0,1,15,14,0,80,13,2,0,18,0,0,0,1,15,13,0,96,5,2,0,18,0,0,0,1,15,15,0,128,249,1,0,18,0,0,0,1,15,5,0,24,239,1,0,18,0,0,0,1,15,4,0,96,227,1,0,18,0,0,0,1,15,3,0,112,212,1,0,18,0,0,0,1,15,2,0,32,201,1,0,18,0,0,0,1,15,1,0,184,190,1,0,18,0,0,0,1,15,0,0,16,227,4,0,0,0,0,0,254,0,0,0,232,75,4,0,18,0,0,0,1,128,128,0,96,135,7,0,18,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,0,0,40,153,1,0,19,0,0,0,1,1,1,0,96,135,7,0,19,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,0,0,160,142,1,0,19,0,0,0,1,2,2,0,96,135,7,0,19,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,4,0,0,96,135,7,0,19,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,254,0,2,0,72,202,5,0,19,0,0,0,1,24,16,0,80,246,3,0,19,0,0,0,1,24,24,0,248,38,7,0,19,0,0,0,1,24,8,0,112,212,3,0,19,0,0,0,1,24,0,0,248,160,5,0,0,0,0,0,254,0,2,0,128,129,4,0,19,0,0,0,1,64,64,0,208,75,4,0,19,0,0,0,1,64,0,0,8,49,4,0,0,0,0,0,254,0,2,0,208,24,1,0,19,0,0,0,1,128,128,0,192,15,1,0,19,0,0,0,1,128,0,0,248,10,1,0,117,98,49,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,60,224,216,65,0,0,16,1,117,98,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,175,99,73,14,0,0,16,1,117,98,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,196,25,157,217,0,0,16,1,112,114,111,116,100,97,116,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,30,139,87,215,0,0,16,1,115,114,111,109,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,195,16,128,219,0,0,32,0,115,114,111,109,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,84,78,54,47,0,0,32,0,117,111,114,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,187,238,233,225,0,0,32,0,117,111,114,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,131,254,235,221,0,0,32,0,117,111,114,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,103,77,254,126,0,0,32,0,117,111,114,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,209,150,21,123,0,0,32,0,117,99,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,230,19,121,14,0,0,64,0,19,0,0,0,255,255,127,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,16,227,4,0,19,0,0,0,1,1,1,0,96,135,7,0,19,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,128,110,7,0,19,0,0,0,1,16,16,0,240,72,7,0,19,0,0,0,1,16,0,0,48,68,7,0,0,0,0,0,254,0,2,0,0,91,7,0,19,0,0,0,1,32,32,0,72,25,8,0,19,0,0,0,1,32,0,0,56,21,8,0,0,0,0,0,254,0,2,0,64,84,7,0,19,0,0,0,1,64,0,0,48,14,8,0,19,0,0,0,1,64,64,0,200,8,8,0,0,0,0,0,254,0,2,0,56,3,8,0,19,0,0,0,1,128,128,0,248,251,7,0,19,0,0,0,1,128,0,0,72,244,7,0,0,0,0,0,254,0,8,0,72,202,5,0,20,0,0,0,1,14,4,0,160,113,6,0,20,0,0,0,1,14,8,0,176,110,6,0,20,0,0,0,1,14,0,0,160,105,6,0,20,0,0,0,1,14,14,0,184,100,6,0,20,0,0,0,1,14,6,0,8,96,6,0,20,0,0,0,1,14,10,0,112,90,6,0,20,0,0,0,1,14,2,0,224,82,6,0,20,0,0,0,1,14,12,0,128,76,6,0,0,0,0,0,254,0,8,0,32,4,2,0,20,0,0,0,1,112,0,0,104,54,4,0,20,0,0,0,1,112,64,0,80,252,6,0,20,0,0,0,1,112,32,0,16,242,7,0,20,0,0,0,1,112,96,0,104,236,7,0,20,0,0,0,1,112,112,0,128,230,7,0,20,0,0,0,1,112,80,0,120,211,6,0,20,0,0,0,1,112,48,0,184,164,6,0,20,0,0,0,1,112,16,0,80,74,6,0,0,0,0,0,114,116,106,95,51,54,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,71,18,116,227,1,0,16,1,114,116,106,95,52,50,46,49,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,23,161,186,180,1,0,16,1,114,116,106,95,51,55,46,49,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,176,119,246,161,1,0,16,1,114,116,106,95,52,51,46,49,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,71,122,51,133,1,0,16,1,114,116,95,51,52,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,200,55,65,5,1,0,16,1,114,116,95,52,48,46,49,48,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,27,203,100,114,1,0,16,1,114,116,106,95,51,53,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,163,158,47,231,1,0,16,1,114,116,106,95,52,49,46,49,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0])
.concat([152,233,30,161,1,0,16,1,114,116,95,48,57,46,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,128,228,64,44,4,0,32,0,114,116,95,48,49,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,205,248,17,62,4,0,32,0,114,116,95,49,51,46,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,23,145,0,81,4,0,32,0,114,116,95,48,53,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,112,212,63,40,4,0,32,0,114,116,95,50,52,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,206,132,68,238,4,0,32,0,114,116,95,49,55,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,235,221,220,229,4,0,32,0,114,116,95,51,56,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,45,12,148,178,4,0,32,0,114,116,95,51,50,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,88,183,226,8,4,0,32,0,114,116,95,49,48,46,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,148,255,243,227,4,0,32,0,114,116,95,48,50,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,60,215,255,252,4,0,32,0,114,116,95,49,52,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,154,109,84,92,4,0,32,0,114,116,95,48,54,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,196,11,101,217,4,0,32,0,114,116,95,50,53,46,55,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,49,136,178,17,4,0,32,0,114,116,95,49,56,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,124,251,26,206,4,0,32,0,114,116,95,51,57,46,57,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,238,201,122,234,4,0,32,0,114,116,95,51,51,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,132,147,169,214,4,0,32,0,114,116,95,49,49,46,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,152,194,243,4,4,0,32,0,114,116,95,48,51,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,8,126,8,152,4,0,32,0,114,116,95,49,53,46,49,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,101,165,171,182,4,0,32,0,114,116,95,48,55,46,49,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,161,239,45,198,4,0,32,0,114,116,95,50,54,46,56,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,46,84,47,83,4,0,32,0,114,116,95,49,57,46,56,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,189,114,15,31,4,0,32,0,114,116,95,50,56,46,49,48,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,153,228,100,96,4,0,32,0,114,116,95,50,49,46,49,48,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,220,45,1,32,4,0,32,0,114,116,95,49,50,46,56,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,204,100,70,229,4,0,32,0,114,116,95,48,52,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,26,154,123,77,4,0,32,0,114,116,95,49,54,46,49,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,252,108,201,55,4,0,32,0,114,116,95,48,56,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,91,151,244,117,4,0,32,0,114,116,95,50,55,46,57,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,15,220,110,236,4,0,32,0,114,116,95,50,48,46,57,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,89,38,229,79,4,0,32,0,114,116,95,50,57,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,159,127,167,143,4,0,32,0,114,116,95,50,50,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,74,13,138,34,4,0,32,0,114,116,95,50,51,46,49,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,101,161,252,171,3,0,16,0,114,116,95,51,48,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,171,17,178,38,5,0,64,0,114,116,95,51,49,46,49,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,208,74,230,219,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,114,116,50,50,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,106,13,86,137,0,0,0,8,105,111,98,49,46,49,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,105,111,99,49,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,129,32,24,13,0,0,0,8,24,38,7,0,1,0,0,0,236,47,216,0,184,160,2,0,56,210,6,0,1,0,0,0,35,48,216,0,192,135,2,0,24,163,6,0,1,0,0,0,34,48,216,0,240,108,2,0,152,122,6,0,1,0,0,0,33,48,216,0,96,82,2,0,192,72,6,0,1,0,0,0,32,48,216,0,32,56,2,0,152,31,6,0,1,0,0,0,36,48,216,0,152,30,2,0,248,97,5,0,1,0,0,0,37,48,216,0,232,10,2,0,144,236,1,0,1,0,0,0,237,47,216,0,136,224,1,0,176,223,1,0,1,0,0,0,43,48,216,0,72,198,1,0,192,209,1,0,1,0,0,0,42,48,216,0,24,182,1,0,24,198,1,0,1,0,0,0,41,48,216,0,40,167,1,0,120,189,1,0,1,0,0,0,40,48,216,0,200,149,1,0,8,182,1,0,1,0,0,0,44,48,216,0,56,126,1,0,32,167,1,0,1,0,0,0,45,48,216,0,32,101,1,0,72,126,8,0,1,0,0,0,111,47,216,0,144,189,1,0,192,122,8,0,1,0,0,0,107,47,216,0,208,174,1,0,40,116,8,0,1,0,0,0,106,47,216,0,48,160,1,0,72,110,8,0,1,0,0,0,105,47,216,0,160,140,1,0,184,102,8,0,1,0,0,0,104,47,216,0,56,112,1,0,248,93,8,0,1,0,0,0,108,47,216,0,32,92,1,0,152,86,8,0,1,0,0,0,109,47,216,0,64,77,1,0,88,212,3,0,1,0,0,0,144,46,216,0,40,185,3,0,51,106,115,46,56,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,146,47,129,2,0,16,1,107,54,97,46,49,54,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,13,24,33,161,4,0,32,0,107,54,98,46,49,54,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,196,150,219,164,4,0,32,0,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,151,138,254,134,3,0,16,0,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,32,231,75,192,5,0,64,0,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,193,216,184,251,5,0,64,0,99,120,50,46,48,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,47,109,26,192,1,0,16,1,99,120,49,46,48,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,119,230,149,253,1,0,16,1,116,120,45,97,46,49,54,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,162,141,52,174,4,0,32,0,116,120,45,98,46,49,54,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,176,109,74,56,4,0,32,0,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,151,138,254,134,3,0,16,0,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,32,231,75,192,5,0,64,0,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,193,216,184,251,5,0,64,0,28,0,0,0,255,255,0,0,0,0,0,0,29,0,0,0,255,255,0,0,0,0,0,0,30,0,0,0,255,255,19,0,0,0,0,0,0,0,0,0,254,0,3,0,88,160,1,0,28,0,0,0,1,3,2,0,128,38,2,0,28,0,0,0,1,3,1,0,200,37,2,0,28,0,0,0,1,3,0,0,208,36,2,0,0,0,0,0,254,0,4,0,32,4,2,0,29,0,0,0,1,3,0,0,80,245,6,0,29,0,0,0,1,3,1,0,8,201,6,0,29,0,0,0,1,3,2,0,200,197,6,0,29,0,0,0,1,3,3,0,152,194,6,0,0,0,0,0,254,0,8,0,72,202,5,0,30,0,0,0,1,7,0,0,160,64,2,0,30,0,0,0,1,7,1,0,160,203,8,0,30,0,0,0,1,7,2,0,80,246,3,0,30,0,0,0,1,7,3,0,248,38,7,0,30,0,0,0,1,7,4,0,112,212,3,0,30,0,0,0,1,7,5,0,24,99,5,0,30,0,0,0,1,7,6,0,40,53,2,0,30,0,0,0,1,7,7,0,248,160,5,0,0,0,0,0,254,0,8,0,128,129,4,0,30,0,0,0,1,112,112,0,104,48,2,0,30,0,0,0,1,112,96,0,120,47,2,0,30,0,0,0,1,112,80,0,152,46,2,0,30,0,0,0,1,112,64,0,64,45,2,0,30,0,0,0,1,112,48,0,72,44,2,0,30,0,0,0,1,112,32,0,240,41,2,0,30,0,0,0,1,112,16,0,88,40,2,0,30,0,0,0,1,112,0,0,168,39,2,0,119,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,103,151,113,185,0,0,16,1,119,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,152,137,72,164,0,0,16,1,119,98,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,141,117,190,83,0,0,16,1,119,98,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,46,41,142,252,0,0,16,1,119,98,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,222,33,105,66,0,0,32,0,119,98,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,55,73,32,104,0,0,32,0,119,98,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,199,4,78,239,0,0,32,0,119,98,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,120,9,244,83,0,0,32,0,119,98,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,99,69,203,65,0,0,32,0,119,98,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,140,184,151,148,0,0,32,0,119,98,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,30,43,162,95,0,0,32,0,119,98,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,202,24,231,155,0,0,32,0,119,98,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,223,89,254,83,0,0,64,0,119,108,117,95,51,48,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,177,219,4,214,1,0,16,1,119,108,117,95,51,53,46,49,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,254,114,238,218,1,0,16,1,119,108,117,95,51,49,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,131,138,180,14,1,0,16,1,119,108,117,95,51,54,46,49,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,2,16,54,1,0,16,1,119,108,109,45,51,50,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,67,246,217,223,2,0,16,1,119,108,109,45,55,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,115,75,167,175,4,0,32,0,119,108,109,45,53,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,11,220,160,18,4,0,32,0,119,108,109,45,51,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,206,171,242,198,4,0,32,0,119,108,109,45,49,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,211,198,164,74,4,0,32,0,119,108,95,50,52,46,55,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,229,222,10,111,4,0,32,0,119,108,95,49,52,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,125,2,243,156,4,0,32,0,119,108,95,50,54,46,57,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,207,142,156,240,4,0,32,0,119,108,95,49,54,46,57,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,170,7,84,227,4,0,32,0,119,108,95,50,48,46,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,80,35,153,132,4,0,32,0,119,108,95,49,48,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,54,90,123,184,4,0,32,0,119,108,95,50,50,46,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,240,137,63,253,4,0,32,0])
.concat([119,108,95,49,50,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,105,157,164,125,4,0,32,0,119,108,95,48,57,46,49,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,96,208,179,246,3,0,16,0,119,108,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,77,61,226,189,5,0,64,0,119,108,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,245,152,56,104,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,119,108,50,52,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,241,205,1,113,0,0,0,8,108,119,105,111,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,12,185,82,173,0,0,0,8,119,108,95,51,54,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,188,124,13,43,1,0,16,1,119,108,95,52,50,46,49,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,21,150,195,26,1,0,16,1,119,108,95,51,55,46,49,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,250,23,167,48,1,0,16,1,119,108,95,52,51,46,49,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,158,220,221,208,1,0,16,1,119,108,95,51,52,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,122,79,168,35,1,0,16,1,119,108,95,52,48,46,49,48,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,33,237,160,199,1,0,16,1,119,108,95,51,53,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,81,121,255,94,1,0,16,1,119,108,95,52,49,46,49,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,163,119,100,141,1,0,16,1,119,108,95,48,57,46,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,180,113,170,5,4,0,32,0,119,108,95,48,49,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,18,223,194,8,4,0,32,0,119,108,95,49,51,46,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,205,135,124,31,4,0,32,0,119,108,95,48,53,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,242,75,37,245,4,0,32,0,119,108,95,50,52,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,161,59,215,217,4,0,32,0,119,108,95,49,55,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,12,243,82,166,4,0,32,0,119,108,95,51,56,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,27,17,249,246,4,0,32,0,119,108,95,51,50,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,39,64,246,16,4,0,32,0,119,108,95,49,48,46,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,10,186,219,4,0,32,0,119,108,95,48,50,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,165,167,251,134,4,0,32,0,119,108,95,49,52,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,178,152,87,125,4,0,32,0,119,108,95,48,54,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,72,41,5,31,4,0,32,0,119,108,95,50,53,46,55,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,210,23,125,133,4,0,32,0,119,108,95,49,56,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,188,127,108,49,4,0,32,0,119,108,95,51,57,46,57,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,176,233,252,230,4,0,32,0,119,108,95,51,51,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,23,85,93,161,4,0,32,0,119,108,95,49,49,46,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,229,222,10,111,4,0,32,0,119,108,95,48,51,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,125,2,243,156,4,0,32,0,119,108,95,49,53,46,49,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,207,142,156,240,4,0,32,0,119,108,95,48,55,46,49,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,170,7,84,227,4,0,32,0,119,108,95,50,54,46,56,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,80,35,153,132,4,0,32,0,119,108,95,49,57,46,56,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,54,90,123,184,4,0,32,0,119,108,95,50,56,46,49,48,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,240,137,63,253,4,0,32,0,119,108,95,50,49,46,49,48,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,105,157,164,125,4,0,32,0,119,108,95,50,51,46,49,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,96,208,179,246,3,0,16,0,119,108,95,51,48,46,49,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,77,61,226,189,5,0,64,0,119,108,95,51,49,46,49,51,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,245,152,56,104,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,119,108,50,50,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,0,0,0,0,0,0,24,108,119,105,111,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,12,185,82,173,0,0,0,8,184,40,2,0,1,0,0,0,212,0,147,0,248,191,2,0,184,164,8,0,1,0,0,0,213,0,147,0,64,246,1,0,104,28,8,0,1,0,0,0,214,0,147,0,232,209,1,0,136,204,6,0,1,0,0,0,215,0,147,0,184,160,2,0,200,110,3,0,1,0,0,0,211,0,147,0,152,30,2,0,120,89,3,0,1,0,0,0,208,0,147,0,232,10,2,0,240,251,8,0,4,0,0,0,24,8,147,0,208,13,4,0,16,17,8,0,1,0,0,0,214,0,147,0,224,12,8,0,88,212,3,0,1,0,0,0,24,220,146,0,40,185,3,0,248,5,8,0,9,0,0,0,64,6,147,0,32,58,1,0,144,250,7,0,9,0,0,0,65,6,147,0,32,58,1,0,99,48,52,45,49,50,45,49,46,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,88,160,182,175,2,0,16,1,99,48,52,45,48,56,45,49,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,107,230,247,25,2,0,16,1,99,48,52,45,49,49,45,49,46,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,155,110,175,26,2,0,16,1,99,48,52,45,50,53,45,49,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,249,4,158,179,2,0,16,1,99,48,52,45,50,48,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,31,101,234,10,2,0,16,1,99,48,52,45,50,50,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,101,212,5,244,2,0,16,1,99,48,52,45,49,57,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,174,147,20,35,2,0,16,1,99,48,52,45,50,49,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,142,211,152,133,2,0,16,1,99,48,52,45,48,54,46,55,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,178,6,1,183,9,0,16,1,99,48,52,45,49,54,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,239,118,36,140,16,0,32,0,99,48,52,45,49,56,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,44,33,101,118,16,0,32,0,99,48,52,45,49,53,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,120,185,80,124,16,0,32,0,99,48,52,45,49,55,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,184,222,47,198,16,0,32,0,99,48,52,45,49,48,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,73,107,155,66,16,0,32,0,99,48,52,45,48,57,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,87,240,140,199,16,0,32,0,99,48,52,45,49,48,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,73,107,155,66,16,0,32,0,99,48,52,45,48,57,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,87,240,140,199,16,0,32,0,99,48,52,45,52,45,49,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,101,174,159,171,0,0,0,8,99,48,52,45,53,46,55,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,137,236,99,39,0,0,0,8,17,0,0,0,255,255,254,0,0,0,0,0,18,0,0,0,255,255,127,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,17,0,0,0,1,1,0,0,120,97,1,0,17,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,2,0,144,212,8,0,17,0,0,0,1,2,2,0,96,135,7,0,17,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,17,0,0,0,1,4,4,0,96,135,7,0,17,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,17,0,0,0,1,8,0,0,96,135,7,0,17,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,17,0,0,0,1,48,0,0,80,252,6,0,17,0,0,0,1,48,16,0,16,242,7,0,17,0,0,0,1,48,32,0,104,236,7,0,17,0,0,0,1,48,48,0,128,230,7,0,0,0,0,0,254,0,4,0,160,123,6,0,17,0,0,0,1,192,192,0,8,201,6,0,17,0,0,0,1,192,128,0,200,197,6,0,17,0,0,0,1,192,64,0,152,194,6,0,17,0,0,0,1,192,0,0,248,189,6,0,0,0,0,0,254,0,4,0,64,37,5,0,18,0,0,0,1,3,2,0,24,175,1,0,18,0,0,0,1,3,3,0,40,168,1,0,18,0,0,0,1,3,1,0,176,160,1,0,18,0,0,0,1,3,0,0,80,68,8,0,0,0,0,0,254,0,4,0,72,202,5,0,18,0,0,0,1,12,8,0,80,246,3,0,18,0,0,0,1,12,12,0,80,124,6,0,18,0,0,0,1,12,4,0,112,212,3,0,18,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,5,0,128,129,4,0,18,0,0,0,1,112,112,0,8,49,4,0,18,0,0,0,1,112,96,0,152,21,4,0,18,0,0,0,1,112,80,0,72,246,3,0,18,0,0,0,1,112,64,0,72,0,3,0,18,0,0,0,1,112,0,0,112,50,1,0,0,0,0,0,254,0,2,0,128,112,3,0,18,0,0,0,1,128,128,0,224,247,3,0,18,0,0,0,1,128,0,0,168,22,4,0,0,0,0,0,21,0,0,0,255,255,0,0,0,0,0,0,22,0,0,0,255,255,0,0,0,0,0,0,23,0,0,0,255,255,2,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,21,0,0,0,1,2,0,0,96,135,7,0,21,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,22,0,0,0,1,3,1,0,80,246,3,0,22,0,0,0,1,3,0,0,80,124,6,0,22,0,0,0,1,3,2,0,112,212,3,0,22,0,0,0,1,3,3,0,248,160,5,0,0,0,0,0,254,0,4,0,64,37,5,0,22,0,0,0,1,12,0,0,240,211,6,0,22,0,0,0,1,12,4,0,64,165,6,0,22,0,0,0,1,12,8,0,208,227,4,0,22,0,0,0,1,12,12,0,248,74,6,0,0,0,0,0,254,0,4,0,128,129,4,0,22,0,0,0,1,48,48,0,208,75,4,0,22,0,0,0,1,48,0,0,8,49,4,0,22,0,0,0,1,48,32,0,152,21,4,0,22,0,0,0,1,48,16,0,72,246,3,0,0,0,0,0,254,0,2,0,144,246,3,0,22,0,0,0,1,64,0,0,96,135,7,0,22,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,22,0,0,0,1,128,128,0,56,111,3,0,22,0,0,0,1,128,0,0,104,134,3,0,0,0,0,0,254,0,9,0,216,227,4,0,23,0,0,0,1,15,0,0,24,192,4,0,23,0,0,0,1,15,1,0,184,255,2,0,23,0,0,0,1,15,2,0,160,129,4,0,23,0,0,0,1,15,3,0,192,20,3,0,23,0,0,0,1,15,4,0,56,50,1,0,23,0,0,0,1,15,5,0,80,65,1,0,23,0,0,0,1,15,6,0,32,22,4,0,23,0,0,0,1,15,7,0,200,246,3,0,23,0,0,0,1,15,8,0,248,212,3,0,0,0,0,0,118,104,50,106,95,100,46,48,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,87,1,110,105,1,0,16,1,118,104,50,106,95,100,46,48,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,163,187,217,206,1,0,16,1,118,104,50,106,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,36,246,52,222,1,0,16,1,118,104,50,106,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,151,152,59,106,1,0,16,1,118,104,50,106,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,41,192,33,176,1,0,16,1,118,104,50,106,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,255,61,135,172,1,0,16,1,118,104,50,106,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,156,206,239,234,1,0,16,1,118,104,50,106,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,9,115,17,1,0,16,1,118,104,50,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,170,221,2,59,5,0,32,0,118,104,50,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,102,222,64,78,5,0,32,0,118,104,50,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,201,0,29,179,5,0,32,0,118,104,50,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,171,227,155,20,5,0,32,0,118,104,50,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,99,189,9,205,5,0,32,0,118,104,50,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,21,44,24,224,5,0,32,0,118,104,50,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,246,196,141,119,5,0,32,0,118,104,50,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,29,157,93,96,5,0,32,0,118,104,50,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,121,247,185,103,10,0,16,1,118,104,50,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,203,95,241,170,10,0,16,1,118,104,50,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,253,46,146,56,12,0,64,0,118,104,50,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,175,48,36,110,12,0,64,0,118,97,101,95,51,48,97,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,145,0,205,127,1,0,16,1,118,97,101,95,51,53,97,46,49,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,149,207,53,1,0,16,1,118,97,101,95,51,49,97,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,129,238,229,21,1,0,16,1,118,97,101,95,51,54,97,46,49,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,30,32,58,21,1,0,16,1,118,97,101,95,50,56,97,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,37,13,14,122,1,0,16,1,118,97,101,95,51,51,97,46,57,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,34,89,54,242,1,0,16,1,118,97,101,95,50,57,97,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,195,210,44,94,1,0,16,1,118,97,101,95,51,52,97,46,49,48,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,131,223,155,61,1,0,16,1,118,97,45,53,109,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,110,114,251,177,4,0,32,0,118,97,45,55,109,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,205,136,101,76,4,0,32,0,118,97,45,49,109,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,55,206,26,11,4,0,32,0,118,97,45,51,109,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,6,231,223,68,4,0,32,0,118,97,95,48,57,46,49,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,110,68,153,122,3,0,16,0,118,97,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,14,81,48,222,5,0,64,0,118,97,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,172,164,16,6,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,118,97,50,52,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,80,102,71,204,0,0,0,8,105,111,98,49,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,168,86,7,0,1,0,0,0,232,47,216,0,248,191,2,0,24,38,7,0,1,0,0,0,236,47,216,0,184,160,2,0,56,210,6,0,1,0,0,0,35,48,216,0,192,135,2,0,24,163,6,0,1,0,0,0,34,48,216,0,240,108,2,0,152,122,6,0,1,0,0,0,33,48,216,0,96,82,2,0,192,72,6,0,1,0,0,0,32,48,216,0,32,56,2,0,232,158,3,0,1,0,0,0,36,48,216,0,152,30,2,0,40,147,2,0,1,0,0,0,37,48,216,0,232,10,2,0,144,55,2,0,1,0,0,0,38,48,216,0,152,138,8,0,40,246,1,0,1,0,0,0,233,47,216,0,64,246,1,0,144,236,1,0,1,0,0,0,237,47,216,0,136,224,1,0,176,223,1,0,1,0,0,0,43,48,216,0,72,198,1,0,192,209,1,0,1,0,0,0,42,48,216,0,24,182,1,0,24,198,1,0,1,0,0,0,41,48,216,0,40,167,1,0,120,189,1,0,1,0,0,0,40,48,216,0,200,149,1,0,200,32,1,0,1,0,0,0,44,48,216,0,56,126,1,0,200,197,8,0,1,0,0,0,45,48,216,0,32,101,1,0,240,173,8,0,1,0,0,0,46,48,216,0,96,32,8,0,88,212,3,0,1,0,0,0,144,46,216,0,40,185,3,0,240,152,1,0,1,0,0,0,238,47,216,0,216,70,1,0,16,17,8,0,1,0,0,0,234,47,216,0,224,12,8,0,72,65,1,0,9,0,0,0,232,48,216,0,32,58,1,0,48,50,1,0,9,0,0,0,224,48,216,0,32,58,1,0,224,41,1,0,9,0,0,0,216,48,216,0,32,58,1,0,18,0,0,0,255,255,255,0,0,0,0,0,19,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,128,129,4,0,18,0,0,0,1,1,0,0,208,75,4,0,18,0,0,0,1,1,1,0,8,49,4,0,0,0,0,0,254,0,2,0,232,75,4,0,18,0,0,0,1,8,8,0,96,135,7,0,18,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,18,0,0,0,1,32,0,0,96,135,7,0,18,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,18,0,0,0,1,192,0,0,80,246,3,0,18,0,0,0,1,192,192,0,248,38,7,0,18,0,0,0,1,192,64,0,112,212,3,0,18,0,0,0,1,192,128,0,248,160,5,0,0,0,0,0,254,0,8,0,160,123,6,0,19,0,0,0,1,28,0,0,96,135,3,0,19,0,0,0,1,28,16,0,32,136,7,0,19,0,0,0,1,28,8,0,40,88,7,0,19,0,0,0,1,28,24,0,96,39,7,0,19,0,0,0,1,28,28,0,144,251,6,0,19,0,0,0,1,28,12,0,184,164,6,0,19,0,0,0,1,28,20,0,80,74,6,0,19,0,0,0,1,28,4,0,192,32,6,0,0,0,0,0,254,0,8,0,200,87,7,0,19,0,0,0,1,224,0,0,96,135,3,0,19,0,0,0,1,224,128,0,32,136,7,0,19,0,0,0,1,224,64,0,40,88,7,0,19,0,0,0,1,224,192,0,96,39,7,0,19,0,0,0,1,224,224,0,144,251,6,0,19,0,0,0,1,224,96,0,184,164,6,0,19,0,0,0,1,224,160,0,80,74,6,0,19,0,0,0,1,224,32,0,192,32,6,0,118,97,109,106,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,119,191,149,136,1,0,16,1,118,97,109,106,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,61,219,39,80,1,0,16,1,118,97,109,106,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,219,111,198,151,1,0,16,1,118,97,109,106,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,38,52,76,155,1,0,16,1,118,97,109,106,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,253,196,59,48,1,0,16,1,118,97,109,106,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,70,54,234,61,1,0,16,1,118,97,109,106,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,168,25,193,1,0,16,1,118,97,109,106,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,121,59,89,70,1,0,16,1,118,97,109,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,153,175,27,197,5,0,32,0,118,97,109,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,119,60,232,60,5,0,32,0,118,97,109,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,224,8,36,79,5,0,32,0,118,97,109,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,80,2,246,159,5,0,32,0,118,97,109,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,60,36,135,189,5,0,32,0,118,97,109,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,95,133,236,175,5,0,32,0,118,97,109,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,37,54,3,58,5,0,32,0,118,97,109,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,137,106,255,43,5,0,32,0,118,97,109,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,213,133,182,100,10,0,16,1,118,97,109,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,199,151,124,207,10,0,16,1,118,97,109,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,178,222,57,74,12,0,64,0,118,97,109,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,3,92,62,26,12,0,64,0,101,112,114,53,53,49,54,97,46,49,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,218,130,140,3,0,0,16,1,101,112,114,53,53,49,55,97,46,49,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,222,225,48,105,0,0,16,1,101,112,114,45,53,53,49,56,46,49,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,153,12,55,42,0,0,16,1,101,112,114,45,53,53,49,57,46,49,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,88,74,102,157,0,0,16,1,101,112,114,45,53,53,50,48,46,49,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,223,251,141,32,0,0,16,1,101,112,114,45,53,53,50,49,46,49,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,122,216,184,231,0,0,16,1,101,112,114,45,53,53,51,53,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,69,76,78,207,0,0,16,1,101,112,114,45,53,53,50,55,46,56,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,241,22,214,178,0,0,32,0,101,112,114,45,53,53,50,54,46,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,194,51,139,138,0,0,32,0,101,112,114,45,53,53,50,53,46,56,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,239,197,73,231,0,0,32,0,101,112,114,45,53,53,50,52,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,82,105,136,139,0,0,32,0,101,112,114,45,53,53,50,51,46,56,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,217,53,222,222,0,0,32,0,101,112,114,45,53,53,50,50,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,255,157,109,94,0,0,32,0,101,112,114,45,53,53,49,52,46,56,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,139,168,192,252,0,0,32,0,101,112,114,45,53,53,49,53,46,57,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,56,136,144,96,0,0,32,0,112,114,45,53,51,49,55,46,49,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,184,80,131,100,0,0,0,8,17,0,0,0,255,255,255,0,0,0,0,0,18,0,0,0,255,255,254,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,17,0,0,0,1,15,7,0,80,252,6,0,17,0,0,0,1,15,8,0,16,242,7,0,17,0,0,0,1,15,9,0,104,236,7,0,17,0,0,0,1,15,5,0,192,54,8,0,17,0,0,0,1,15,4,0,56,24,4,0,17,0,0,0,1,15,15,0,128,230,7,0,17,0,0,0,1,15,0,0,128,230,7,0,17,0,0,0,1,15,3,0,176,162,3,0,17,0,0,0,1,15,2,0,24,188,3,0,17,0,0,0,1,15,1,0,72,216,3,0,17,0,0,0,1,15,6,0,120,211,6,0,17,0,0,0,1,15,14,0,184,164,6,0,17,0,0,0,1,15,13,0,80,74,6,0,17,0,0,0,1,15,12,0,192,32,6,0,17,0,0,0,1,15,11,0,192,234,2,0,17,0,0,0,1,15,10,0,32,242,5,0,0,0,0,0,254,0,16,0,160,123,6,0,17,0,0,0,1,240,112,0,80,252,6,0,17,0,0,0,1,240,128,0,16,242,7,0,17,0,0,0,1,240,144,0,104,236,7,0,17,0,0,0,1,240,80,0,192,54,8,0,17,0,0,0,1,240,64,0,56,24,4,0,17,0,0,0,1,240,240,0,128,230,7,0,17,0,0,0,1,240,0,0,128,230,7,0,17,0,0,0,1,240,48,0,176,162,3,0,17,0,0,0,1,240,32,0,24,188,3,0,17,0,0,0,1,240,16,0,72,216,3,0,17,0,0,0,1,240,96,0,120,211,6,0,17,0,0,0,1,240,224,0,184,164,6,0,17,0,0,0,1,240,208,0,80,74,6,0,17,0,0,0,1,240,192,0,192,32,6,0,17,0,0,0,1,240,176,0,192,234,2,0,17,0,0,0,1,240,160,0,32,242,5,0,0,0,0,0,254,0,2,0,200,30,2,0,18,0,0,0,1,1,0,0,120,97,1,0,18,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,4,0,128,129,4,0,18,0,0,0,1,6,6,0,8,49,4,0,18,0,0,0,1,6,4,0,152,21,4,0,18,0,0,0,1,6,2,0,72,246,3,0,18,0,0,0,1,6,0,0,112,49,6,0,0,0,0,0,254,0,8,0,64,37,5,0,18,0,0,0,1,56,56,0,232,43,6,0,18,0,0,0,1,56,48,0,160,39,6,0,18,0,0,0,1,56,40,0,192,33,6,0,18,0,0,0,1,56,32,0,160,30,6,0,18,0,0,0,1,56,24,0,208,26,6,0,18,0,0,0,1,56,16,0,232,23,6,0,18,0,0,0,1,56,8,0,48,20,6,0,18,0,0,0,1,56,0,0,120,7,5,0,0,0,0,0,254,0,4,0,72,202,5,0,18,0,0,0,1,192,192,0,80,246,3,0,18,0,0,0,1,192,128,0,80,124,6,0,18,0,0,0,1,192,64,0,112,212,3,0,18,0,0,0,1,192,0,0,248,160,5,0,97,114,117,95,51,48,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,141,248,216,36,1,0,16,1,97,114,117,95,51,53,46,49,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,89,75,149,139,1,0,16,1,97,114,117,95,51,49,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,75,105,233,51,1,0,16,1,97,114,117,95,51,54,46,49,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,158,251,200,124,1,0,16,1,97,114,45,51,50,109,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,176,127,29,174,2,0,16,1,97,114,45,53,109,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,216,117,69,191,4,0,32,0,97,114,45,55,109,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,244,69,41,160,4,0,32,0,97,114,45,49,109,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,141,202,101,89,4,0,32,0,97,114,45,51,109,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,125,177,109,172,4,0,32,0,97,114,95,48,57,46,49,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,103,19,221,243,3,0,16,0,97,114,117,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,169,67,75,88,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,97,114,50,52,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,113,18,165,9,0,0,0,8,108,119,105,111,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,12,185,82,173,0,0,0,8,21,0,0,0,255,255,0,0,0,0,0,0,22,0,0,0,255,255,3,0,0,0,0,0,23,0,0,0,255,255,96,0,0,0,0,0,0,0,0,0,254,0,8,0,200,87,7,0,21,0,0,0,1,7,6,0,80,252,6,0,21,0,0,0,1,7,5,0,16,242,7,0,21,0,0,0,1,7,4,0,104,236,7,0,21,0,0,0,1,7,7,0,104,9,2,0,21,0,0,0,1,7,0,0,128,230,7,0,21,0,0,0,1,7,1,0,184,164,6,0,21,0,0,0,1,7,2,0,80,74,6,0,21,0,0,0,1,7,3,0,192,32,6,0,0,0,0,0,254,0,8,0,160,123,6,0,21,0,0,0,1,56,48,0,80,252,6,0,21,0,0,0,1,56,40,0,16,242,7,0,21,0,0,0,1,56,32,0,104,236,7,0,21,0,0,0,1,56,56,0,104,9,2,0,21,0,0,0,1,56,0,0,128,230,7,0,21,0,0,0,1,56,8,0,184,164,6,0,21,0,0,0,1,56,16,0,80,74,6,0,21,0,0,0,1,56,24,0,192,32,6,0,0,0,0,0,254,0,8,0,72,202,5,0,22,0,0,0,1,7,0,0,72,198,6,0,22,0,0,0,1,7,1,0,208,75,4,0,22,0,0,0,1,7,2,0,8,49,4,0,22,0,0,0,1,7,3,0,72,195,6,0,22,0,0,0,1,7,4,0,72,246,3,0,22,0,0,0,1,7,5,0,72,0,3,0,22,0,0,0,1,7,6,0,64,47,7,0,22,0,0,0,1,7,7,0,48,173,6,0,0,0,0,0,254,0,4,0,120,95,4,0,22,0,0,0,1,24,8,0,56,94,4,0,22,0,0,0,1,24,0,0,248,38,7,0,22,0,0,0,1,24,16,0,176,90,4,0,22,0,0,0,1,24,24,0,192,87,4,0,0,0,0,0,254,0,2,0,16,227,4,0,23,0,0,0,1,4,0,0,96,135,7,0,23,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,254,0,2,0,72,4,1,0,23,0,0,0,1,8,0,0,96,135,7,0,23,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,2,0,120,207,1,0,23,0,0,0,1,16,0,0,96,135,7,0,23,0,0,0,1,16,16,0,152,182,7,0,0,0,0,0,254,0,2,0,40,111,8,0,23,0,0,0,1,32,0,0,96,135,7,0,23,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,23,0,0,0,1,64,0,0,96,135,7,0,23,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,168,79,2,0,23,0,0,0,1,128,0,0,32,182,8,0,23,0,0,0,1,128,128,0,80,251,6,0,0,0,0,0,9,0,0,0,255,255,255,0,0,0,0,0,10,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,64,44,1,0,9,0,0,0,1,128,0,0,96,135,7,0,9,0,0,0,1,128,128,0,152,182,7,0,0,0,0,0,254,0,2,0,16,105,8,0,10,0,0,0,1,1,0,0,96,135,7,0,10,0,0,0,1,1,1,0,152,182,7,0,0,0,0,0,254,0,2,0,160,48,8,0,10,0,0,0,1,2,0,0,96,135,7,0,10,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,2,0,48,252,7,0,10,0,0,0,1,4,0,0,96,135,7,0,10,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,254,0,2,0,0,199,7,0,10,0,0,0,1,8,0,0,96,135,7,0,10,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,2,0,144,150,7,0,10,0,0,0,1,16,0,0,96,135,7,0,10,0,0,0,1,16,16,0,152,182,7,0,0,0,0,0,254,0,2,0,80,104,7,0,10,0,0,0,1,32,0,0,96,135,7,0,10,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,152,53,7,0,10,0,0,0,1,64,0,0,96,135,7,0,10,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,32,10,7,0,10,0,0,0,1,128,0,0,96,135,7,0,10,0,0,0,1,128,128,0,152,182,7,0,0,0,0,0,102,48,55,95,49,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,16,175,117,217,1,0,16,1,104,48,55,95,50,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,195,20,237,178,1,0,16,1,107,48,55,95,51,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,96,65,95,148,1,0,16,1,109,48,55,95,52,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,197,11,200,221,1,0,16,1,100,48,56,112,95,53,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,81,67,53,98,1,0,16,1,103,103,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,77,63,10,39,1,0,16,1,109,48,56,112,95,55,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,70,83,36,201,1,0,16,1,110,48,56,112,95,56,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,199,69,125,121,1,0,16,1,101,103,103,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,224,65,41,1,4,0,32,0,104,48,49,95,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,175,50,97,194,4,0,32,0,101,103,103,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,253,88,139,252,4,0,32,0,107,48,49,95,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,59,179,194,220,4,0,32,0,117,110,105,119,97,114,115,46,99,108,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,24,149,199,37,7,0,32,0,117,104,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,254,38,150,169,0,0,16,1,117,105,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,132,54,247,90,0,0,16,1,117,97,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,9,187,100,107,0,0,32,0,117,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,218,129,4,228,0,0,64,0,117,106,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,55,75,83,10,0,0,64,0,56,55,99,53,50,46,109,99,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,16,112,114,111,116,100,97,116,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,180,228,211,0,0,0,16,1,49,51,46,117,104,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,155,163,112,159,0,0,16,1,49,50,46,117,105,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,149,100,119,216,0,0,16,1,49,54,46,117,97,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,113,225,145,244,0,0,32,0,49,53,46,117,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,141,139,160,121,0,0,32,0,49,52,46,117,97,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,11,238,250,121,0,0,32,0,117,104,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,8,205,90,61,0,0,64,0,115,114,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,196,82,244,130,0,0,64,0,115,114,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,230,81,158,16,0,0,64,0,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,232,24,7,0,19,0,0,0,1,3,0,0,224,19,7,0,19,0,0,0,1,3,1,0,64,15,7,0,19,0,0,0,1,3,3,0,224,9,7,0,19,0,0,0,1,3,2,0,144,3,7,0,0,0,0,0,254,0,2,0,40,111,8,0,19,0,0,0,1,16,0,0,96,135,7,0,19,0,0,0,1,16,16,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,32,32,0,96,135,7,0,19,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,104,81,2,0,19,0,0,0,1,128,128,0,96,135,7,0,19,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,3,3,0,248,38,7,0,20,0,0,0,1,3,2,0,112,212,3,0,20,0,0,0,1,3,1,0,48,90,7,0,20,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,2,0,128,129,4,0,20,0,0,0,1,4,4,0,8,49,4,0,20,0,0,0,1,4,0,0,72,246,3,0,0,0,0,0,254,0,2,0,80,253,6,0,20,0,0,0,1,8,8,0,96,135,7,0,20,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,2,0,40,249,6,0,20,0,0,0,1,64,64,0,96,135,7,0,20,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,16,227,4,0,20,0,0,0,1,128,128,0,96,135,7,0,20,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,116,117,114,116,95,118,105,100,46,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,251,97,94,236,1,0,16,1,116,117,114,116,95,118,105,100,46,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,30,130,16,253,1,0,16,1,116,117,114,116,95,118,105,100,46,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,250,197,207,221,1,0,16,1,116,117,114,116,95,118,105,100,46,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,108,105,113,158,1,0,16,1,116,117,114,116,95,118,105,100,46,50,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,239,159,212,252,1,0,16,1,116,117,114,116,95,115,110,100,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,154,15,195,240,2,0,16,1,116,117,114,116,95,115,110,100,46,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,60,196,95,175,2,0,16,1,116,117,114,116,95,118,105,100,46,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,82,157,153,229,4,0,32,0,116,117,114,116,95,118,105,100,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,85,214,255,195,4,0,32,0,116,117,114,116,108,101,115,46,99,108,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,221,2,239,243,7,0,32,0,16,0,0,0,255,255,0,0,0,0,0,0,17,0,0,0,255,255,3,0,0,0,0,0,18,0,0,0,255,255,14,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,17,0,0,0,1,3,3,0,8,49,4,0,17,0,0,0,1,3,2,0,152,21,4,0,17,0,0,0,1,3,1,0,72,246,3,0,17,0,0,0,1,3,0,0,144,166,1,0,0,0,0,0,254,0,4,0,32,4,2,0,18,0,0,0,1,6,6,0,136,178,1,0,18,0,0,0,1,6,4,0,144,177,1,0,18,0,0,0,1,6,2,0,176,176,1,0,18,0,0,0,1,6,0,0,248,175,1,0,0,0,0,0,254,0,2,0,200,30,2,0,18,0,0,0,1,8,8,0,120,97,1,0,18,0,0,0,1,8,0,0,96,19,1,0,116,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,204,80,221,137,1,0,16,1,116,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,41,220,98,149,1,0,16,1,116,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,82,22,41,98,1,0,16,1,116,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,232,24,65,128,1,0,16,1,116,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,120,246,36,128,1,0,16,1,56,116,117,114,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,171,216,126,201,2,0,16,1,53,116,117,114,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,60,196,95,175,2,0,16,1,116,117,114,46,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,82,157,153,229,4,0,32,0,116,117,114,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,85,214,255,195,4,0,32,0,116,117,114,116,108,101,115,46,99,108,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,221,2,239,243,7,0,32,0,18,0,0,0,255,255,255,0,0,0,0,0,19,0,0,0,255,255,254,0,0,0,0,0,0,0,0,0,254,0,2,0,24,172,6,0,18,0,0,0,1,1,1,0,96,135,7,0,18,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,18,0,0,0,1,2,2,0,96,135,7,0,18,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,8,0,160,123,6,0,18,0,0,0,1,28,0,0,40,88,7,0,18,0,0,0,1,28,16,0,96,39,7,0,18,0,0,0,1,28,28,0,144,251,6,0,18,0,0,0,1,28,12,0,184,164,6,0,18,0,0,0,1,28,20,0,80,74,6,0,18,0,0,0,1,28,4,0,192,32,6,0,18,0,0,0,1,28,24,0,192,234,2,0,18,0,0,0,1,28,8,0,32,242,5,0,0,0,0,0,254,0,8,0,200,87,7,0,18,0,0,0,1,224,0,0,40,88,7,0,18,0,0,0,1,224,128,0,96,39,7,0,18,0,0,0,1,224,224,0,144,251,6,0,18,0,0,0,1,224,96,0,184,164,6,0,18,0,0,0,1,224,160,0,80,74,6,0,18,0,0,0,1,224,32,0,192,32,6,0,18,0,0,0,1,224,192,0,192,234,2,0,18,0,0,0,1,224,64,0,32,242,5,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,1,1,0,96,135,7,0,19,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,19,0,0,0,1,2,0,0,56,111,3,0,19,0,0,0,1,2,2,0,104,134,3,0,0,0,0,0,254,0,4,0,72,202,5,0,19,0,0,0,1,48,16,0,80,246,3,0,19,0,0,0,1,48,48,0,248,38,7,0,19,0,0,0,1,48,32,0,112,212,3,0,19,0,0,0,1,48,0,0,248,160,5,0,0,0,0,0,254,0,4,0,128,129,4,0,19,0,0,0,1,192,128,0,192,255,2,0,19,0,0,0,1,192,0,0,208,75,4,0,19,0,0,0,1,192,192,0,8,49,4,0,19,0,0,0,1,192,64,0,152,21,4,0,116,104,117,109,98,112,111,112,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,3,71,152,12,0,0,16,1,116,104,117,109,98,112,111,112,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,83,64,76,134,0,0,16,1,116,104,117,109,98,112,111,112,46,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,180,170,149,7,0,0,32,0,116,104,117,109,98,112,111,112,46,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,67,223,88,173,0,0,32,0,109,97,112,45,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,9,250,31,232,0,0,32,0,109,97,112,45,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,254,156,135,140,0,0,32,0,116,104,117,109,98,112,111,112,46,115,110,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,93,241,187,250,0,0,64,0,18,0,0,0,255,255,255,0,0,0,0,0,19,0,0,0,255,255,254,0,0,0,0,0,0,0,0,0,254,0,8,0,200,87,7,0,18,0,0,0,1,224,0,0,16,242,7,0,18,0,0,0,1,224,128,0,104,236,7,0,18,0,0,0,1,224,224,0,128,230,7,0,18,0,0,0,1,224,96,0,184,164,6,0,18,0,0,0,1,224,160,0,80,74,6,0,18,0,0,0,1,224,32,0,192,32,6,0,18,0,0,0,1,224,192,0,192,234,2,0,18,0,0,0,1,224,64,0,32,242,5,0,0,0,0,0,254,0,8,0,160,123,6,0,18,0,0,0,1,28,0,0,16,242,7,0,18,0,0,0,1,28,16,0,104,236,7,0,18,0,0,0,1,28,28,0,128,230,7,0,18,0,0,0,1,28,12,0,184,164,6,0,18,0,0,0,1,28,20,0,80,74,6,0,18,0,0,0,1,28,4,0,192,32,6,0,18,0,0,0,1,28,24,0,192,234,2,0,18,0,0,0,1,28,8,0,32,242,5,0,0,0,0,0,254,0,2,0,144,212,8,0,18,0,0,0,1,2,2,0,96,135,7,0,18,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,24,172,6,0,18,0,0,0,1,1,1,0,96,135,7,0,18,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,19,0,0,0,1,192,128,0,192,255,2,0,19,0,0,0,1,192,0,0,208,75,4,0,19,0,0,0,1,192,192,0,8,49,4,0,19,0,0,0,1,192,64,0,152,21,4,0,0,0,0,0,254,0,4,0,72,202,5,0,19,0,0,0,1,48,16,0,80,246,3,0,19,0,0,0,1,48,48,0,248,38,7,0,19,0,0,0,1,48,32,0,112,212,3,0,19,0,0,0,1,48,0,0,248,160,5,0,0,0,0,0,254,0,2,0,104,159,3,0,19,0,0,0,1,2,0,0,96,135,7,0,19,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,1,1,0,96,135,7,0,19,0,0,0,1,1,0,0,152,182,7,0,116,101,115,116,46,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,127,205,20,6,1,0,16,1,103,97,108,109,105,100,119,46,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,64,154,153,156,1,0,16,1,103,97,108,109,105,100,119,46,119,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,37,73,137,181,1,0,16,1,103,97,108,109,105,100,119,46,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,11,161,60,107,1,0,16,1,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,7,50,147,27,1,0,16,1,49,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,164,67,251,57,4,0,32,0,49,107,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,162,86,63,126,4,0,32,0,54,108,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,103,148,172,195,7,0,32,0,18,0,0,0,255,255,255,0,0,0,0,0,19,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,18,0,0,0,1,15,9,0,72,101,2,0,18,0,0,0,1,15,8,0,192,86,2,0,18,0,0,0,1,15,7,0,24,72,2,0,18,0,0,0,1,15,6,0,112,59,2,0,18,0,0,0,1,15,12,0,40,44,2,0,18,0,0,0,1,15,11,0,200,32,2,0,18,0,0,0,1,15,10,0,144,22,2,0,18,0,0,0,1,15,14,0,80,13,2,0,18,0,0,0,1,15,13,0,96,5,2,0,18,0,0,0,1,15,15,0,128,249,1,0,18,0,0,0,1,15,5,0,24,239,1,0,18,0,0,0,1,15,4,0,96,227,1,0,18,0,0,0,1,15,3,0,112,212,1,0,18,0,0,0,1,15,2,0,32,201,1,0,18,0,0,0,1,15,1,0,184,190,1,0,18,0,0,0,1,15,0,0,16,227,4,0,0,0,0,0,254,0,0,0,232,75,4,0,18,0,0,0,1,128,128,0,96,135,7,0,18,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,0,0,40,153,1,0,19,0,0,0,1,1,1,0,96,135,7,0,19,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,0,0,160,142,1,0,19,0,0,0,1,2,2,0,96,135,7,0,19,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,4,0,0,96,135,7,0,19,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,254,0,2,0,72,202,5,0,19,0,0,0,1,24,16,0,80,246,3,0,19,0,0,0,1,24,24,0,248,38,7,0,19,0,0,0,1,24,8,0,112,212,3,0,19,0,0,0,1,24,0,0,248,160,5,0,0,0,0,0,254,0,2,0,200,71,1,0,19,0,0,0,1,32,32,0,120,76,7,0,19,0,0,0,1,32,0,0,248,63,7,0,0,0,0,0,254,0,2,0,128,129,4,0,19,0,0,0,1,64,64,0,208,75,4,0,19,0,0,0,1,64,0,0,8,49,4,0,0,0,0,0,254,0,2,0,208,24,1,0,19,0,0,0,1,128,128,0,192,15,1,0,19,0,0,0,1,128,0,0,248,10,1,0,0,0,0,0,116,114,105,112,108,101,112,46,50,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,61,169,131,197,1,0,16,1,116,114,105,112,108,101,112,46,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,73,220,61,192,1,0,16,1,116,114,105,112,108,101,112,46,50,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,181,166,60,232,1,0,16,1,116,114,105,112,108,101,112,46,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,185,195,44,152,1,0,16,1,116,114,105,112,108,101,112,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,111,189,28,213,4,0,32,0,116,114,105,112,108,101,112,46,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,89,0,28,242,4,0,32,0,116,114,105,112,112,114,111,109,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,223,117,79,98,7,0,32,0,16,0,0,0,255,255,0,0,0,0,0,0,17,0,0,0,255,255,3,0,0,0,0,0,18,0,0,0,255,255,174,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,17,0,0,0,1,3,3,0,8,49,4,0,17,0,0,0,1,3,2,0,152,21,4,0,17,0,0,0,1,3,1,0,72,246,3,0,17,0,0,0,1,3,0,0,240,64,4,0,0,0,0,0,254,0,4,0,32,4,2,0,18,0,0,0,1,6,4,0,120,219,1,0,18,0,0,0,1,6,2,0,96,217,1,0,18,0,0,0,1,6,6,0,72,215,1,0,18,0,0,0,1,6,0,0,48,213,1,0,0,0,0,0,254,0,2,0,200,30,2,0,18,0,0,0,1,8,8,0,120,97,1,0,18,0,0,0,1,8,0,0,96,19,1,0,0,0,0,0,254,0,2,0,232,75,4,0,18,0,0,0,1,32,32,0,96,135,7,0,18,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,32,150,8,0,18,0,0,0,1,128,128,0,96,135,7,0,18,0,0,0,1,128,0,0,152,182,7,0,101,112,114,45,49,50,53,49,51,46,49,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,165,53,136,174,1,0,16,1,101,112,114,45,49,50,53,49,50,46,49,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,173,114,3,249,1,0,16,1,101,112,114,45,49,50,53,49,53,46,49,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,244,125,4,31,1,0,16,1,101,112,114,45,49,50,53,49,52,46,49,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,195,233,57,85,1,0,16,1,101,112,114,45,49,50,50,57,51,46,49,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,234,30,50,244,1,0,16,1,101,112,114,45,49,50,50,57,50,46,49,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,240,138,217,81,1,0,16,1,111,112,114,45,49,50,50,57,53,46,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,132,58,58,212,9,0,16,1,111,112,114,45,49,50,50,57,52,46,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,211,207,205,39,9,0,16,1,111,112,114,45,49,50,50,57,55,46,55,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,119,86,155,29,9,0,16,1,111,112,114,45,49,50,50,57,54,46,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,113,54,81,10,9,0,16,1,111,112,114,45,49,50,51,50,51,46,49,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,111,58,228,77,2,0,32,0,111,112,114,45,49,50,51,50,52,46,49,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,85,122,96,36,2,0,32,0,111,112,114,45,49,50,51,50,53,46,49,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,122,19,5,20,2,0,32,0,109,112,114,45,49,50,51,51,54,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,199,101,164,221,3,0,32,0,109,112,114,45,49,50,51,51,55,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,209,51,130,130,3,0,32,0,109,112,114,45,49,50,51,51,56,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,244,181,180,70,3,0,32,0,109,112,114,45,49,50,51,51,57,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,171,59,126,13,3,0,32,0,109,112,114,45,49,50,51,54,52,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,101,62,184,164,3,0,32,0,109,112,114,45,49,50,51,54,53,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,169,178,128,74,3,0,32,0,109,112,114,45,49,50,51,54,54,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,171,179,92,56,3,0,32,0,109,112,114,45,49,50,51,54,55,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,74,37,48,73,3,0,32,0,101,112,114,45,49,50,50,57,57,46,52,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,27,196,155,252,10,0,32,0,101,112,114,45,49,50,50,57,56,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,27,196,155,252,10,0,32,0,101,112,114,45,49,50,51,48,48,46,56,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,17,112,255,232,4,0,16,1,111,112,114,45,49,50,51,48,49,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,21,173,120,110,11,0,64,0,111,112,114,45,49,50,51,48,50,46,54,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,175,40,41,231,11,0,64,0,111,112,114,45,49,50,51,48,51,46,54,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,92,32,132,131,11,0,64,0,111,112,114,45,49,50,51,48,52,46,54,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,195,42,118,225,11,0,64,0,111,112,114,45,49,50,51,48,53,46,55,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,119,230,156,186,11,0,64,0,111,112,114,45,49,50,51,48,54,46,55,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,253,73,146,228,11,0,64,0,51,49,55,45,48,49,49,56,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,86,125,61,8,5,0,16,1,11,0,0,0,255,255,255,0,0,0,0,0,12,0,0,0,255,255,217,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,11,0,0,0,1,15,7,0,80,252,6,0,11,0,0,0,1,15,8,0,16,242,7,0,11,0,0,0,1,15,9,0,104,236,7,0,11,0,0,0,1,15,5,0,176,51,4,0,11,0,0,0,1,15,4,0,56,24,4,0,11,0,0,0,1,15,15,0,128,230,7,0,11,0,0,0,1,15,1,0,72,216,3,0,11,0,0,0,1,15,2,0,24,188,3,0,11,0,0,0,1,15,3,0,176,162,3,0,11,0,0,0,1,15,6,0,120,211,6,0,11,0,0,0,1,15,14,0,184,164,6,0,11,0,0,0,1,15,13,0,80,74,6,0,11,0,0,0,1,15,12,0,192,32,6,0,11,0,0,0,1,15,11,0,192,234,2,0,11,0,0,0,1,15,10,0,32,242,5,0,11,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,11,0,0,0,1,240,112,0,80,252,6,0,11,0,0,0,1,240,128,0,16,242,7,0,11,0,0,0,1,240,144,0,104,236,7,0,11,0,0,0,1,240,80,0,176,51,4,0,11,0,0,0,1,240,64,0,56,24,4,0,11,0,0,0,1,240,240,0,128,230,7,0,11,0,0,0,1,240,16,0,72,216,3,0,11,0,0,0,1,240,32,0,24,188,3,0,11,0,0,0,1,240,48,0,176,162,3,0,11,0,0,0,1,240,96,0,120,211,6,0,11,0,0,0,1,240,224,0,184,164,6,0,11,0,0,0,1,240,208,0,80,74,6,0,11,0,0,0,1,240,192,0,192,32,6,0,11,0,0,0,1,240,176,0,192,234,2,0,11,0,0,0,1,240,160,0,32,242,5,0,11,0,0,0,1,240,0,0,208,236,2,0,0,0,0,0,254,0,4,0,200,30,2,0,12,0,0,0,1,3,3,0,120,247,1,0,12,0,0,0,1,3,2,0,120,226,1,0,12,0,0,0,1,3,1,0,104,211,1,0,12,0,0,0,1,3,0,0,80,46,8,0,0,0,0,0,254,0,2,0,168,234,7,0,12,0,0,0,1,4,4,0,96,135,7,0,12,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,208,26,7,0,12,0,0,0,1,8,0,0,96,238,1,0,12,0,0,0,1,8,8,0,152,124,2,0,0,0,0,0,254,0,4,0,56,154,6,0,12,0,0,0,1,48,32,0,200,99,2,0,12,0,0,0,1,48,48,0,32,84,2,0,12,0,0,0,1,48,16,0,16,71,2,0,12,0,0,0,1,48,0,0,168,57,2,0,0,0,0,0,254,0,4,0,72,202,5,0,12,0,0,0,1,192,128,0,80,246,3,0,12,0,0,0,1,192,192,0,248,38,7,0,12,0,0,0,1,192,64,0,112,212,3,0,12,0,0,0,1,192,0,0,248,160,5,0,0,0,0,0,168,86,7,0,1,0,0,0,170,233,148,0,248,191,2,0,24,38,7,0,1,0,0,0,238,232,148,0,184,160,2,0,56,210,6,0,1,0,0,0,235,232,148,0,192,135,2,0,24,163,6,0,1,0,0,0,234,232,148,0,240,108,2,0,152,122,6,0,1,0,0,0,232,232,148,0,96,82,2,0,192,72,6,0,1,0,0,0,233,232,148,0,32,56,2,0,200,110,3,0,1,0,0,0,237,232,148,0,152,30,2,0,120,89,3,0,1,0,0,0,236,232,148,0,232,10,2,0,40,246,1,0,1,0,0,0,171,233,148,0,64,246,1,0,144,236,1,0,1,0,0,0,62,232,148,0,136,224,1,0,176,223,1,0,1,0,0,0,59,232,148,0,72,198,1,0,192,209,1,0,1,0,0,0,58,232,148,0,24,182,1,0,24,198,1,0,1,0,0,0,56,232,148,0,40,167,1,0,120,189,1,0,1,0,0,0,57,232,148,0,200,149,1,0,224,22,1,0,1,0,0,0,61,232,148,0,56,126,1,0,160,14,1,0,1,0,0,0,60,232,148,0,32,101,1,0,88,212,3,0,1,0,0,0,168,216,146,0,40,185,3,0,16,17,8,0,1,0,0,0,169,233,148,0,224,12,8,0,56,58,1,0,1,0,0,0,168,233,148,0,64,50,1,0,72,65,1,0,9,0,0,0,48,94,147,0,32,58,1,0,48,50,1,0,9,0,0,0,49,94,147,0,32,58,1,0,168,86,7,0,1,0,0,0,16,248,146,0,248,191,2,0,24,38,7,0,1,0,0,0,19,248,146,0,184,160,2,0,56,210,6,0,1,0,0,0,168,0,147,0,192,135,2,0,24,163,6,0,1,0,0,0,169,0,147,0,240,108,2,0,152,122,6,0,1,0,0,0,170,0,147,0,96,82,2,0,192,72,6,0,1,0,0,0,171,0,147,0,32,56,2,0,200,110,3,0,1,0,0,0,172,0,147,0,152,30,2,0,120,89,3,0,1,0,0,0,173,0,147,0,232,10,2,0,40,246,1,0,1,0,0,0,17,248,146,0,64,246,1,0,144,236,1,0,1,0,0,0,20,248,146,0,136,224,1,0,176,223,1,0,1,0,0,0,176,0,147,0,72,198,1,0,192,209,1,0,1,0,0,0,177,0,147,0,24,182,1,0,24,198,1,0,1,0,0,0,178,0,147,0,40,167,1,0,120,189,1,0,1,0,0,0,179,0,147,0,200,149,1,0,224,22,1,0,1,0,0,0,180,0,147,0,56,126,1,0,160,14,1,0,1,0,0,0,181,0,147,0,32,101,1,0,88,212,3,0,1,0,0,0,232,219,146,0,40,185,3,0,16,17,8,0,1,0,0,0,18,248,146,0,224,12,8,0,72,65,1,0,9,0,0,0,24,6,147,0,32,58,1,0,48,50,1,0,9,0,0,0,25,6,147,0,32,58,1,0,116,109,110,116,49,50,51,46,106,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,131,81,144,45,0,0,16,1,116,109,110,116,49,50,52,46,107,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,82,83,18,224,0,0,16,1,116,109,110,116,50,49,46,106,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,251,234,222,18,0,0,16,1,116,109,110,116,50,50,46,107,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,195,241,196,174,0,0,16,1,57,54,51,101,50,48,46,103,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,214,166,146,22,0,0,16,1,57,54,51,97,50,56,46,104,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,105,71,219,0,0,32,0,57,54,51,97,50,57,46,107,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,46,205,105,128,0,0,32,0,57,54,51,97,49,55,46,104,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,68,154,35,181,0,0,32,0,57,54,51,97,49,56,46,104,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,239,173,81,221,0,0,32,0,57,54,51,97,49,53,46,107,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,237,78,50,31,0,0,32,0,57,54,51,97,49,54,46,107,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,132,153,189,212,0,0,32,0,57,54,51,97,51,48,46,103,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,128,38,216,171,0,0,32,0,57,54,51,97,51,49,46,103,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,28,74,0,248,0,0,32,0,57,54,51,97,50,54,46,99,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,99,48,172,226,0,0,64,0,57,54,51,97,50,55,46,100,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,75,103,253,45,0,0,64,0,57,54,51,97,50,53,46,100,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,199,120,160,252,0,0,64,0,57,54,51,45,49,50,51,46,106,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,201,39,53,106,0,0,16,1,57,54,51,45,49,50,52,46,107,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,21,250,75,44,0,0,16,1,57,54,51,45,49,50,49,46,106,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,51,183,129,65,0,0,16,1,57,54,51,45,49,50,50,46,107,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,255,181,78,198,0,0,16,1,57,54,51,101,50,48,46,103,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,214,166,146,22,0,0,16,1,57,54,51,97,50,56,46,104,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,105,71,219,0,0,32,0,57,54,51,97,50,57,46,107,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,46,205,105,128,0,0,32,0,57,54,51,97,49,55,46,104,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,68,154,35,181,0,0,32,0,57,54,51,97,49,56,46,104,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,239,173,81,221,0,0,32,0,57,54,51,97,49,53,46,107,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,237,78,50,31,0,0,32,0,57,54,51,97,49,54,46,107,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,132,153,189,212,0,0,32,0,57,54,51,97,51,48,46,103,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,128,38,216,171,0,0,32,0,57,54,51,97,51,49,46,103,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,28,74,0,248,0,0,32,0,57,54,51,97,50,54,46,99,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,99,48,172,226,0,0,64,0,57,54,51,97,50,55,46,100,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,2,0,75,103,253,45,0,0,64,0,57,54,51,97,50,53,46,100,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,199,120,160,252,0,0,64,0,57,54,51,45,95,50,51,46,106,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,26,6,152,134,0,0,16,1,57,54,51,45,95,50,52,46,107,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,117,192,54,64,0,0,16,1,57,54,51,45,95,50,49,46,106,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,156,151,204,221,0,0,16,1,57,54,51,45,95,50,50,46,107,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,39,141,163,113,0,0,16,1,57,54,51,101,50,48,46,103,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,214,166,146,22,0,0,16,1,57,54,51,97,50,56,46,104,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,105,71,219,0,0,32,0,57,54,51,97,50,57,46,107,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,46,205,105,128,0,0,32,0,57,54,51,97,49,55,46,104,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,68,154,35,181,0,0,32,0,57,54,51,97,49,56,46,104,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,239,173,81,221,0,0,32,0,57,54,51,97,49,53,46,107,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,237,78,50,31,0,0,32,0,57,54,51,97,49,54,46,107,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,132,153,189,212,0,0,32,0,57,54,51,97,51,48,46,103,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,128,38,216,171,0,0,32,0,57,54,51,97,51,49,46,103,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,28,74,0,248,0,0,32,0,57,54,51,97,50,54,46,99,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,99,48,172,226,0,0,64,0,57,54,51,97,50,55,46,100,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,75,103,253,45,0,0,64,0,57,54,51,97,50,53,46,100,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,199,120,160,252,0,0,64,0,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,1,0,0,96,135,7,0,19,0,0,0,1,1,1,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,2,2,0,96,135,7,0,19,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,8,0,200,87,7,0,19,0,0,0,1,224,0,0,104,54,4,0,19,0,0,0,1,224,128,0,232,228,5,0,19,0,0,0,1,224,64,0,16,242,7,0,19,0,0,0,1,224,32,0,104,236,7,0,19,0,0,0,1,224,224,0,128,230,7,0,19,0,0,0,1,224,96,0,184,164,6,0,19,0,0,0,1,224,160,0,80,74,6,0,19,0,0,0,1,224,192,0,192,32,6,0,0,0,0,0,254,0,8,0,160,123,6,0,19,0,0,0,1,28,0,0,104,54,4,0,19,0,0,0,1,28,16,0,232,228,5,0,19,0,0,0,1,28,8,0,16,242,7,0,19,0,0,0,1,28,4,0,104,236,7,0,19,0,0,0,1,28,28,0,128,230,7,0,19,0,0,0,1,28,12,0,184,164,6,0,19,0,0,0,1,28,20,0,80,74,6,0,19,0,0,0,1,28,24,0,192,32,6,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,48,48,0,80,246,3,0,20,0,0,0,1,48,16,0,248,38,7,0,20,0,0,0,1,48,32,0,112,212,3,0,20,0,0,0,1,48,0,0,248,160,5,0,0,0,0,0,254,0,3,0,128,129,4,0,20,0,0,0,1,192,128,0,192,255,2,0,20,0,0,0,1,192,192,0,208,75,4,0,20,0,0,0,1,192,64,0,8,49,4,0,0,0,0,0,0,0,0,0,0,0,0,0,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,234,214,120,15,1,0,16,1,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,235,198,172,235,1,0,16,1,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,6,7,253,20,1,0,16,1,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,15,146,62,97,1,0,16,1,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,63,31,121,90,1,0,16,1,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,81,127,179,11,1,0,16,1,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,111,236,253,77,1,0,16,1,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,137,145,154,163,1,0,16,1,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,7,14,185,46,1,0,16,1,49,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,95,230,220,0,4,0,32,0,49,107,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,110,5,192,62,4,0,32,0,54,108,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,135,125,12,106,7,0,32,0,15,0,0,0,255,255,0,0,0,0,0,0,16,0,0,0,255,255,0,0,0,0,0,0,17,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,12,0,0,0,1,4,0,0,96,135,7,0,12,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,254,0,2,0,200,30,2,0,17,0,0,0,1,8,0,0,120,97,1,0,17,0,0,0,1,8,8,0,96,19,1,0,0,0,0,0,105,99,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,20,171,229,144,1,0,16,1,105,99,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,7,10,15,149,1,0,16,1,105,99,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,245,188,134,103,1,0,16,1,105,99,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,23,0,10,56,1,0,16,1,105,99,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,127,123,6,175,1,0,16,1,105,99,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,147,27,65,160,1,0,16,1,105,99,53,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,112,47,44,59,2,0,16,1,105,99,53,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,80,158,66,224,2,0,16,1,105,99,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,132,211,127,82,4,0,32,0,105,99,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,182,9,109,175,4,0,32,0,54,51,51,49,45,49,106,46,56,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,196,43,101,36,7,0,32,0,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,2,2,0,96,135,7,0,19,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,4,4,0,96,135,7,0,19,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,8,0,0,96,135,7,0,19,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,19,0,0,0,1,48,0,0,32,136,7,0,19,0,0,0,1,48,16,0,40,88,7,0,19,0,0,0,1,48,32,0,96,39,7,0,19,0,0,0,1,48,48,0,144,251,6,0,0,0,0,0,254,0,4,0,160,123,6,0,19,0,0,0,1,192,192,0,184,164,6,0,19,0,0,0,1,192,128,0,80,74,6,0,19,0,0,0,1,192,64,0,192,32,6,0,19,0,0,0,1,192,0,0,32,242,5,0,0,0,0,0,101,112,114,45,49,50,50,48,49,97,46,52,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,207,229,80,146,1,0,16,1,101,112,114,45,49,50,50,48,48,97,46,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,255,176,212,133,1,0,16,1,101,112,114,45,49,50,50,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,65,167,125,47,2,0,32,0,101,112,114,45,49,50,50,48,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,197,142,229,166,2,0,32,0,101,112,114,45,49,50,50,48,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,35,142,233,10,2,0,32,0,101,112,114,45,49,50,49,54,57,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,101,97,204,218,3,0,32,0,101,112,114,45,49,50,49,55,48,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,66,78,53,135,3,0,32,0,101,112,114,45,49,50,50,48,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,153,220,149,102,4,0,16,1,51,49,55,45,48,48,57,51,97,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,238,168,164,124,5,0,16,1,101,112,114,45,49,50,49,57,51,46,97,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,212,110,70,68,1,0,16,1,101,112,114,45,49,50,49,57,50,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,175,200,161,1,0,16,1,101,112,114,45,49,50,49,54,53,46,98,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,33,2,100,98,2,0,32,0,101,112,114,45,49,50,49,54,54,46,98,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,59,24,189,154,2,0,32,0,101,112,114,45,49,50,49,54,55,46,98,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,78,253,149,36,2,0,32,0,111,98,106,48,45,111,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,128,136,179,47,3,0,32,0,111,98,106,48,45,101,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,186,44,160,214,3,0,32,0,101,112,114,45,49,50,49,54,56,46,97,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,27,160,155,189,4,0,16,1,51,49,55,45,48,48,57,50,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,217,26,14,209,5,0,16,1,101,112,114,45,49,50,49,54,52,46,97,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,111,205,41,179,1,0,16,1,101,112,114,45,49,50,49,54,51,46,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,243,211,114,211,1,0,16,1,101,112,114,45,49,50,49,54,53,46,98,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,33,2,100,98,2,0,32,0,101,112,114,45,49,50,49,54,54,46,98,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,59,24,189,154,2,0,32,0,101,112,114,45,49,50,49,54,55,46,98,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,78,253,149,36,2,0,32,0,101,112,114,45,49,50,49,54,57,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,101,97,204,218,3,0,32,0,101,112,114,45,49,50,49,55,48,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,66,78,53,135,3,0,32,0,101,112,114,45,49,50,49,54,56,46,97,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,27,160,155,189,4,0,16,1,51,49,55,45,48,48,57,49,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,97,118,147,167,5,0,16,1,101,112,114,45,54,55,54,56,46,49,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,126,129,57,89,0,0,16,1,101,112,114,45,54,55,54,57,46,49,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,221,141,169,20,0,0,16,1,101,112,114,45,54,55,55,48,46,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,194,199,176,103,0,0,16,1,101,112,114,54,55,52,56,120,46,49,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,157,184,161,194,0,0,16,1,101,112,114,45,54,55,52,55,46,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,167,172,229,160,0,0,32,0,101,112,114,45,54,55,52,54,46,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,81,126,183,205,0,0,32,0,101,112,114,45,54,55,52,53,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,195,117,171,12,0,0,32,0,101,112,114,45,54,55,52,52,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,205,210,248,14,0,0,32,0,101,112,114,45,54,55,52,51,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,181,98,48,195,0,0,32,0,101,112,114,45,54,55,52,50,46,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,197,232,87,196,0,0,32,0,101,112,114,45,54,55,51,53,46,49,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,151,90,227,27,0,0,32,0,101,112,114,45,54,55,51,55,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,122,170,83,107,0,0,32,0,101,112,114,45,54,55,51,54,46,49,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,208,37,92,86,0,0,32,0,101,112,114,45,54,55,51,56,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,95,40,22,225,0,0,32,0,112,114,45,53,51,49,55,46,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,184,80,131,100,0,0,0,8,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,254,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,19,0,0,0,1,15,7,0,80,252,6,0,19,0,0,0,1,15,8,0,16,242,7,0,19,0,0,0,1,15,9,0,104,236,7,0,19,0,0,0,1,15,5,0,192,54,8,0,19,0,0,0,1,15,4,0,56,24,4,0,19,0,0,0,1,15,15,0,128,230,7,0,19,0,0,0,1,15,0,0,128,230,7,0,19,0,0,0,1,15,3,0,176,162,3,0,19,0,0,0,1,15,2,0,24,188,3,0,19,0,0,0,1,15,1,0,72,216,3,0,19,0,0,0,1,15,6,0,120,211,6,0,19,0,0,0,1,15,14,0,184,164,6,0,19,0,0,0,1,15,13,0,80,74,6,0,19,0,0,0,1,15,12,0,192,32,6,0,19,0,0,0,1,15,11,0,192,234,2,0,19,0,0,0,1,15,10,0,32,242,5,0,0,0,0,0,254,0,16,0,160,123,6,0])
.concat([19,0,0,0,1,240,112,0,80,252,6,0,19,0,0,0,1,240,128,0,16,242,7,0,19,0,0,0,1,240,144,0,104,236,7,0,19,0,0,0,1,240,80,0,192,54,8,0,19,0,0,0,1,240,64,0,56,24,4,0,19,0,0,0,1,240,240,0,128,230,7,0,19,0,0,0,1,240,0,0,128,230,7,0,19,0,0,0,1,240,48,0,176,162,3,0,19,0,0,0,1,240,32,0,24,188,3,0,19,0,0,0,1,240,16,0,72,216,3,0,19,0,0,0,1,240,96,0,120,211,6,0,19,0,0,0,1,240,224,0,184,164,6,0,19,0,0,0,1,240,208,0,80,74,6,0,19,0,0,0,1,240,192,0,192,32,6,0,19,0,0,0,1,240,176,0,192,234,2,0,19,0,0,0,1,240,160,0,32,242,5,0,0,0,0,0,254,0,2,0,200,30,2,0,20,0,0,0,1,1,0,0,120,97,1,0,20,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,2,0,168,234,7,0,20,0,0,0,1,2,0,0,96,135,7,0,20,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,12,8,0,208,75,4,0,20,0,0,0,1,12,12,0,8,49,4,0,20,0,0,0,1,12,4,0,152,21,4,0,20,0,0,0,1,12,0,0,216,235,5,0,0,0,0,0,254,0,4,0,64,37,5,0,20,0,0,0,1,48,48,0,240,70,8,0,20,0,0,0,1,48,32,0,32,229,5,0,20,0,0,0,1,48,16,0,144,224,5,0,20,0,0,0,1,48,0,0,128,220,5,0,0,0,0,0,254,0,2,0,72,202,5,0,20,0,0,0,1,64,64,0,80,246,3,0,20,0,0,0,1,64,0,0,112,212,3,0,0,0,0,0,18,0,0,0,255,255,255,0,0,0,0,0,19,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,72,202,5,0,18,0,0,0,1,12,4,0,80,246,3,0,18,0,0,0,1,12,12,0,248,38,7,0,18,0,0,0,1,12,8,0,112,212,3,0,18,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,4,0,128,129,4,0,18,0,0,0,1,192,0,0,192,255,2,0,18,0,0,0,1,192,64,0,208,75,4,0,18,0,0,0,1,192,192,0,8,49,4,0,18,0,0,0,1,192,128,0,152,21,4,0,0,0,0,0,254,0,8,0,200,87,7,0,19,0,0,0,1,7,4,0,32,136,7,0,19,0,0,0,1,7,5,0,40,88,7,0,19,0,0,0,1,7,6,0,96,39,7,0,19,0,0,0,1,7,7,0,144,251,6,0,19,0,0,0,1,7,3,0,184,164,6,0,19,0,0,0,1,7,2,0,80,74,6,0,19,0,0,0,1,7,1,0,192,32,6,0,19,0,0,0,1,7,0,0,16,227,4,0,0,0,0,0,254,0,8,0,160,123,6,0,19,0,0,0,1,56,32,0,32,136,7,0,19,0,0,0,1,56,40,0,40,88,7,0,19,0,0,0,1,56,48,0,96,39,7,0,19,0,0,0,1,56,56,0,144,251,6,0,19,0,0,0,1,56,24,0,184,164,6,0,19,0,0,0,1,56,16,0,80,74,6,0,19,0,0,0,1,56,8,0,192,32,6,0,19,0,0,0,1,56,0,0,16,227,4,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,64,0,0,96,135,7,0,19,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,18,0,0,0,255,255,0,0,0,0,0,0,19,0,0,0,255,255,64,0,0,0,0,0,0,0,0,0,254,0,12,0,200,87,7,0,18,0,0,0,1,15,13,0,40,88,7,0,18,0,0,0,1,15,12,0,96,39,7,0,18,0,0,0,1,15,5,0,128,13,7,0,18,0,0,0,1,15,0,0,144,251,6,0,18,0,0,0,1,15,3,0,40,183,6,0,18,0,0,0,1,15,2,0,232,192,7,0,18,0,0,0,1,15,6,0,120,211,6,0,18,0,0,0,1,15,8,0,184,164,6,0,18,0,0,0,1,15,9,0,80,74,6,0,18,0,0,0,1,15,10,0,192,32,6,0,18,0,0,0,1,15,11,0,192,234,2,0,18,0,0,0,1,15,4,0,32,242,5,0,0,0,0,0,254,0,12,0,160,123,6,0,18,0,0,0,1,240,208,0,40,88,7,0,18,0,0,0,1,240,192,0,96,39,7,0,18,0,0,0,1,240,80,0,128,13,7,0,18,0,0,0,1,240,0,0,144,251,6,0,18,0,0,0,1,240,48,0,40,183,6,0,18,0,0,0,1,240,32,0,232,192,7,0,18,0,0,0,1,240,96,0,120,211,6,0,18,0,0,0,1,240,128,0,184,164,6,0,18,0,0,0,1,240,144,0,80,74,6,0,18,0,0,0,1,240,160,0,192,32,6,0,18,0,0,0,1,240,176,0,192,234,2,0,18,0,0,0,1,240,64,0,32,242,5,0,0,0,0,0,254,0,2,0,48,142,4,0,19,0,0,0,1,1,1,0,104,50,5,0,19,0,0,0,1,1,0,0,96,19,5,0,0,0,0,0,254,0,4,0,136,240,4,0,19,0,0,0,1,6,6,0,16,105,8,0,19,0,0,0,1,6,4,0,176,172,4,0,19,0,0,0,1,6,0,0,48,141,4,0,19,0,0,0,1,6,2,0,200,112,4,0,0,0,0,0,254,0,4,0,24,87,4,0,19,0,0,0,1,24,16,0,232,60,4,0,19,0,0,0,1,24,24,0,96,32,4,0,19,0,0,0,1,24,8,0,240,3,4,0,19,0,0,0,1,24,0,0,80,226,3,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,32,0,0,96,135,7,0,19,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,64,0,0,96,135,7,0,19,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,128,0,0,96,135,7,0,19,0,0,0,1,128,128,0,152,182,7,0,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,90,0,0,0,0,0,21,0,0,0,255,255,240,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,19,0,0,0,1,15,2,0,80,252,6,0,19,0,0,0,1,15,5,0,16,242,7,0,19,0,0,0,1,15,8,0,104,236,7,0,19,0,0,0,1,15,4,0,120,113,6,0,19,0,0,0,1,15,1,0,232,228,5,0,19,0,0,0,1,15,15,0,128,230,7,0,19,0,0,0,1,15,3,0,56,141,7,0,19,0,0,0,1,15,7,0,120,211,6,0,19,0,0,0,1,15,14,0,184,164,6,0,19,0,0,0,1,15,6,0,24,1,7,0,19,0,0,0,1,15,13,0,80,74,6,0,19,0,0,0,1,15,12,0,192,32,6,0,19,0,0,0,1,15,11,0,192,234,2,0,19,0,0,0,1,15,10,0,32,242,5,0,19,0,0,0,1,15,9,0,176,192,2,0,19,0,0,0,1,15,0,0,16,227,4,0,0,0,0,0,254,0,15,0,160,123,6,0,19,0,0,0,1,240,32,0,80,252,6,0,19,0,0,0,1,240,80,0,16,242,7,0,19,0,0,0,1,240,128,0,104,236,7,0,19,0,0,0,1,240,64,0,120,113,6,0,19,0,0,0,1,240,16,0,232,228,5,0,19,0,0,0,1,240,240,0,128,230,7,0,19,0,0,0,1,240,48,0,56,141,7,0,19,0,0,0,1,240,112,0,120,211,6,0,19,0,0,0,1,240,224,0,184,164,6,0,19,0,0,0,1,240,96,0,24,1,7,0,19,0,0,0,1,240,208,0,80,74,6,0,19,0,0,0,1,240,192,0,192,32,6,0,19,0,0,0,1,240,176,0,192,234,2,0,19,0,0,0,1,240,160,0,32,242,5,0,19,0,0,0,1,240,144,0,176,192,2,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,3,3,0,208,75,4,0,20,0,0,0,1,3,2,0,8,49,4,0,20,0,0,0,1,3,1,0,72,246,3,0,20,0,0,0,1,3,0,0,64,47,7,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,96,96,0,80,246,3,0,20,0,0,0,1,96,64,0,248,38,7,0,20,0,0,0,1,96,32,0,48,123,8,0,20,0,0,0,1,96,0,0,8,117,8,0,0,0,0,0,254,0,2,0,168,234,7,0,20,0,0,0,1,128,128,0,96,135,7,0,20,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,6,0,21,0,0,0,1,32,32,0,8,208,6,0,21,0,0,0,1,32,0,0,88,204,6,0,0,0,0,0,254,0,2,0,232,75,4,0,21,0,0,0,1,64,64,0,96,135,7,0,21,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,184,40,2,0,1,0,0,0,199,252,146,0,248,191,2,0,184,164,8,0,1,0,0,0,119,244,146,0,64,246,1,0,24,38,7,0,1,0,0,0,198,252,146,0,184,160,2,0,200,110,3,0,1,0,0,0,192,252,146,0,152,30,2,0,120,89,3,0,1,0,0,0,193,252,146,0,232,10,2,0,120,74,3,0,1,0,0,0,194,252,146,0,152,138,8,0,192,61,3,0,1,0,0,0,195,252,146,0,48,119,7,0,144,236,1,0,1,0,0,0,118,244,146,0,136,224,1,0,224,22,1,0,1,0,0,0,112,244,146,0,56,126,1,0,160,14,1,0,1,0,0,0,113,244,146,0,32,101,1,0,176,9,1,0,1,0,0,0,114,244,146,0,96,32,8,0,200,3,1,0,1,0,0,0,115,244,146,0,16,68,7,0,16,17,8,0,1,0,0,0,166,238,146,0,224,12,8,0,88,212,3,0,1,0,0,0,40,217,146,0,40,185,3,0,248,5,8,0,9,0,0,0,80,4,147,0,32,58,1,0,115,116,114,111,110,103,120,46,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,140,38,247,194,1,0,16,1,115,116,114,111,110,103,120,46,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,34,148,5,145,1,0,16,1,50,102,95,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,4,37,158,132,1,0,16,1,50,104,95,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,155,6,100,138,1,0,16,1,50,106,95,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,152,184,185,120,1,0,16,1,50,108,95,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,20,228,186,32,1,0,16,1,115,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,184,93,58,113,2,0,16,1,115,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,17,148,7,70,2,0,16,1,53,102,95,99,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,121,182,33,113,4,0,32,0,53,104,95,99,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,145,173,5,209,4,0,32,0,115,116,114,97,116,101,103,121,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,225,41,166,81,7,0,32,0,115,116,114,97,116,101,103,121,46,49,48,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,24,3,92,217,7,0,32,0,72,23,4,0,1,0,0,0,81,240,146,0,248,191,2,0,200,110,3,0,1,0,0,0,249,0,147,0,152,30,2,0,120,89,3,0,1,0,0,0,250,0,147,0,232,10,2,0,120,74,3,0,1,0,0,0,251,0,147,0,152,138,8,0,192,61,3,0,1,0,0,0,252,0,147,0,48,119,7,0,224,22,1,0,1,0,0,0,89,248,146,0,56,126,1,0,160,14,1,0,1,0,0,0,90,248,146,0,32,101,1,0,176,9,1,0,1,0,0,0,91,248,146,0,96,32,8,0,200,3,1,0,1,0,0,0,92,248,146,0,16,68,7,0,88,212,3,0,1,0,0,0,64,220,146,0,40,185,3,0,248,5,8,0,9,0,0,0,96,6,147,0,32,58,1,0,51,48,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,116,116,153,218,1,0,16,1,51,53,46,49,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,163,170,99,84,1,0,16,1,51,49,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,219,134,7,210,1,0,16,1,51,54,46,49,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,99,40,170,33,1,0,16,1,115,116,45,49,52,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,8,252,60,155,2,0,16,1,115,116,45,50,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,234,154,238,78,4,0,32,0,115,116,45,49,49,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,228,33,127,45,4,0,32,0,115,116,45,53,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,70,170,5,119,4,0,32,0,115,116,45,57,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,34,183,24,91,4,0,32,0,115,116,45,49,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,11,0,95,0,4,0,32,0,115,116,45,49,48,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,25,21,68,185,4,0,32,0,115,116,45,52,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,139,78,208,183,4,0,32,0,115,116,45,56,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,180,19,71,107,4,0,32,0,48,57,46,49,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,188,3,212,46,3,0,16,0,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,128,188,134,67,5,0,64,0,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,215,54,69,68,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,115,116,50,52,109,49,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,126,53,13,168,0,0,0,8,108,119,105,111,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,12,185,82,173,0,0,0,8,20,0,0,0,255,255,0,0,0,0,0,0,21,0,0,0,255,255,0,0,0,0,0,0,22,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,8,0,200,87,7,0,20,0,0,0,1,7,7,0,80,252,6,0,20,0,0,0,1,7,6,0,16,242,7,0,20,0,0,0,1,7,5,0,104,236,7,0,20,0,0,0,1,7,0,0,128,230,7,0,20,0,0,0,1,7,1,0,184,164,6,0,20,0,0,0,1,7,2,0,80,74,6,0,20,0,0,0,1,7,3,0,192,32,6,0,20,0,0,0,1,7,4,0,32,242,5,0,0,0,0,0,254,0,8,0,160,123,6,0,20,0,0,0,1,56,56,0,80,252,6,0,20,0,0,0,1,56,48,0,16,242,7,0,20,0,0,0,1,56,40,0,104,236,7,0,20,0,0,0,1,56,0,0,128,230,7,0,20,0,0,0,1,56,8,0,184,164,6,0,20,0,0,0,1,56,16,0,80,74,6,0,20,0,0,0,1,56,24,0,192,32,6,0,20,0,0,0,1,56,32,0,32,242,5,0,0,0,0,0,254,0,3,0,200,30,2,0,20,0,0,0,1,192,0,0,80,6,2,0,20,0,0,0,1,192,64,0,152,5,2,0,20,0,0,0,1,192,192,0,96,19,1,0,0,0,0,0,254,0,8,0,72,202,5,0,21,0,0,0,1,7,3,0,72,198,6,0,21,0,0,0,1,7,2,0,208,75,4,0,21,0,0,0,1,7,1,0,8,49,4,0,21,0,0,0,1,7,0,0,72,195,6,0,21,0,0,0,1,7,4,0,72,246,3,0,21,0,0,0,1,7,5,0,72,0,3,0,21,0,0,0,1,7,6,0,64,47,7,0,21,0,0,0,1,7,7,0,48,173,6,0,0,0,0,0,254,0,4,0,64,37,5,0,21,0,0,0,1,48,0,0,184,204,1,0,21,0,0,0,1,48,16,0,88,203,1,0,21,0,0,0,1,48,32,0,112,202,1,0,21,0,0,0,1,48,48,0,80,201,1,0,0,0,0,0,254,0,4,0,128,129,4,0,22,0,0,0,1,3,3,0,208,75,4,0,22,0,0,0,1,3,0,0,8,49,4,0,22,0,0,0,1,3,1,0,152,21,4,0,22,0,0,0,1,3,2,0,72,246,3,0,0,0,0,0,254,0,2,0,72,4,1,0,22,0,0,0,1,4,0,0,96,135,7,0,22,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,254,0,2,0,16,227,4,0,22,0,0,0,1,8,0,0,96,135,7,0,22,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,2,0,120,207,1,0,22,0,0,0,1,16,0,0,96,135,7,0,22,0,0,0,1,16,16,0,152,182,7,0,0,0,0,0,254,0,2,0,160,94,8,0,22,0,0,0,1,32,32,0,96,135,7,0,22,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,22,0,0,0,1,64,64,0,96,135,7,0,22,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,79,2,0,22,0,0,0,1,128,0,0,32,182,8,0,22,0,0,0,1,128,128,0,80,251,6,0,115,102,120,111,46,48,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,198,61,163,43,1,0,16,1,115,102,120,111,46,48,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,215,61,102,186,1,0,16,1,115,102,120,111,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,92,98,33,19,1,0,16,1,115,102,120,111,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,237,144,196,12,1,0,16,1,115,102,120,111,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,94,1,185,100,1,0,16,1,115,102,120,111,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,88,75,15,182,1,0,16,1,115,102,120,111,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,63,174,47,100,1,0,16,1,115,115,102,46,54,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,159,63,18,233,8,0,32,0,115,115,102,46,55,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,243,1,130,47,8,0,32,0,115,115,102,46,55,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,180,52,163,15,8,0,32,0,115,115,102,46,55,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,211,64,103,183,8,0,32,0,115,115,102,46,55,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,88,240,20,8,0,32,0,115,115,102,46,55,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,233,58,12,128,8,0,32,0,115,102,120,46,55,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,11,84,207,6,8,0,32,0,115,102,120,46,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,66,78,8,113,8,0,32,0,115,115,102,46,53,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,77,238,179,110,8,0,32,0,115,115,102,46,54,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,218,30,207,43,8,0,32,0,115,115,102,46,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,17,204,48,51,8,0,32,0,115,115,102,46,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,211,234,226,150,8,0,32,0,115,115,102,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,117,162,86,227,8,0,32,0,115,115,102,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,139,105,197,254,8,0,32,0,115,102,120,46,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,81,7,218,105,8,0,32,0,115,102,120,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,21,236,83,204,8,0,32,0,115,115,102,46,55,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,68,13,207,8,0,32,0,115,115,102,46,56,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,164,83,161,86,8,0,32,0,115,115,102,46,56,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,229,132,84,8,0,32,0,115,115,102,46,56,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,245,183,230,252,8,0,32,0,115,115,102,46,56,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,112,121,45,4,8,0,32,0,115,115,102,46,56,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,230,114,196,136,8,0,32,0,115,102,120,46,56,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,72,99,214,167,8,0,32,0,115,102,120,46,56,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,200,25,145,207,8,0,32,0,115,115,102,46,56,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,217,74,55,109,8,0,32,0,115,115,102,46,57,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,207,139,207,52,8,0,32,0,115,115,102,46,57,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,63,234,150,215,8,0,32,0,115,115,102,46,57,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,227,183,95,200,8,0,32,0,115,115,102,46,57,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,194,80,108,8,0,32,0,115,115,102,46,57,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,99,159,84,89,8,0,32,0,115,102,120,46,57,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,105,120,201,134,8,0,32,0,115,102,120,46,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,137,25,14,28,8,0,32,0,115,102,120,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,53,136,123,180,10,0,16,1,115,102,120,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,99,34,0,10,0,16,1,115,115,102,46,53,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,84,105,218,158,12,0,64,0,115,115,102,46,53,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,137,101,95,53,12,0,64,0,115,115,102,46,53,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,5,138,208,213,12,0,64,0,115,115,102,46,53,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,235,37,7,147,12,0,64,0,115,115,102,46,53,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,60,191,122,130,12,0,64,0,115,115,102,46,53,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,229,192,25,57,12,0,64,0,115,115,102,46,53,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,166,191,169,27,12,0,64,0,115,115,102,46,53,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,114,162,137,12,12,0,64,0,115,102,120,106,100,46,48,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,150,233,109,49,1,0,16,1,115,102,120,106,100,46,48,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,46,187,243,155,1,0,16,1,115,102,120,106,100,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,208,88,51,198,1,0,16,1,115,102,120,106,100,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,8,152,178,204,1,0,16,1,115,102,120,106,100,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,130,73,249,97,1,0,16,1,115,102,120,106,100,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,108,195,153,211,1,0,16,1,115,102,120,100,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,150,97,58,11,1,0,16,1,115,102,120,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,117,210,148,207,5,0,32,0,115,102,120,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,175,3,183,94,5,0,32,0,115,102,120,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,15,14,166,255,5,0,32,0,115,102,120,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,197,37,232,52,5,0,32,0,115,102,120,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,231,50,204,183,5,0,32,0,115,102,120,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,24,173,118,131,5,0,32,0,115,102,120,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,54,179,177,245,5,0,32,0,115,102,120,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,107,92,157,69,5,0,32,0,115,102,120,46,50,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,175,84,40,227,5,0,32,0,115,102,120,46,50,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,39,41,15,118,5,0,32,0,115,102,120,46,50,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,8,2,233,30,5,0,32,0,115,102,120,46,50,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,15,64,20,248,5,0,32,0,115,102,120,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,53,136,123,180,10,0,16,1,115,102,120,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,99,34,0,10,0,16,1,115,102,120,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,118,212,219,155,12,0,64,0,115,102,120,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,171,58,94,160,12,0,64,0,115,115,102,106,46,48,51,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,80,68,13,152,1,0,16,1,115,115,102,106,46,48,52,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,6,25,220,180,1,0,16,1,115,115,102,106,46,48,53,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,188,95,227,167,1,0,16,1,115,115,102,106,46,48,54,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,48,43,89,203,1,0,16,1,115,115,102,106,46,48,55,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,21,149,35,31,1,0,16,1,115,115,102,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,117,210,148,207,5,0,32,0,115,115,102,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,175,3,183,94,5,0,32,0,115,115,102,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,15,14,166,255,5,0,32,0,115,115,102,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,197,37,232,52,5,0,32,0,115,115,102,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,231,50,204,183,5,0,32,0,115,115,102,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,24,173,118,131,5,0,32,0,115,115,102,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,54,179,177,245,5,0,32,0,115,115,102,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,107,92,157,69,5,0,32,0,115,115,102,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,140,126,36,235,10,0,16,1,115,115,102,46,113,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,92,218,249,166,12,0,64,0,115,115,102,46,113,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,38,174,102,140,12,0,64,0,115,115,102,46,113,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,202,194,92,105,12,0,64,0,115,115,102,46,113,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,50,190,158,157,12,0,64,0,115,115,102,46,113,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,183,231,112,71,12,0,64,0,115,115,102,46,113,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,81,201,121,78,12,0,64,0,115,115,102,46,113,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,19,67,209,205,12,0,64,0,115,115,102,46,113,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,140,8,90,111,12,0,64,0,115,115,102,104,46,48,51,116,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,139,210,183,109,1,0,16,1,115,115,102,104,46,48,52,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,149,216,231,15,1,0,16,1,115,115,102,104,46,48,53,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,45,79,190,65,1,0,16,1,115,115,102,104,46,48,54,116,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,177,46,82,210,1,0,16,1,115,115,102,104,46,48,55,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,198,163,195,177,1,0,16,1,115,115,102,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,117,210,148,207,5,0,32,0,115,115,102,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,175,3,183,94,5,0,32,0,115,115,102,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,15,14,166,255,5,0,32,0,115,115,102,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,197,37,232,52,5,0,32,0,115,115,102,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,231,50,204,183,5,0,32,0,115,115,102,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,24,173,118,131,5,0,32,0,115,115,102,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,54,179,177,245,5,0,32,0,115,115,102,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,107,92,157,69,5,0,32,0,115,115,102,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,140,126,36,235,10,0,16,1,115,115,102,46,113,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,92,218,249,166,12,0,64,0,115,115,102,46,113,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,38,174,102,140,12,0,64,0,115,115,102,46,113,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,202,194,92,105,12,0,64,0,115,115,102,46,113,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,50,190,158,157,12,0,64,0,115,115,102,46,113,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,183,231,112,71,12,0,64,0,115,115,102,46,113,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,81,201,121,78,12,0,64,0,115,115,102,46,113,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,19,67,209,205,12,0,64,0,115,115,102,46,113,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,140,8,90,111,12,0,64,0,115,115,102,101,100,46,51,116,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,248,202,134,93,1,0,16,1,115,115,102,101,100,46,52,116,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,141,249,225,246,1,0,16,1,115,115,102,101,100,46,53,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,8,0,239,81,198,117,1,0,16,1,115,115,102,101,100,46,54,116,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,215,199,218,154,1,0,16,1,115,115,102,101,100,46,55,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,179,77,245,132,1,0,16,1,115,115,102,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,117,210,148,207,5,0,32,0,115,115,102,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,175,3,183,94,5,0,32,0,115,115,102,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,15,14,166,255,5,0,32,0,115,115,102,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,197,37,232,52,5,0,32,0,115,115,102,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,231,50,204,183,5,0,32,0,115,115,102,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,24,173,118,131,5,0,32,0,115,115,102,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,54,179,177,245,5,0,32,0,115,115,102,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,107,92,157,69,5,0,32,0,115,115,102,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,140,126,36,235,10,0,16,1,115,115,102,46,113,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,92,218,249,166,12,0,64,0,115,115,102,46,113,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,38,174,102,140,12,0,64,0,115,115,102,46,113,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,202,194,92,105,12,0,64,0,115,115,102,46,113,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,50,190,158,157,12,0,64,0,115,115,102,46,113,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,183,231,112,71,12,0,64,0,115,115,102,46,113,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,81,201,121,78,12,0,64,0,115,115,102,46,113,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,19,67,209,205,12,0,64,0,115,115,102,46,113,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,140,8,90,111,12,0,64,0,115,102,120,97,100,46,48,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,206,46,201,227,1,0,16,1,115,102,120,97,100,46,48,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,46,187,243,155,1,0,16,1,115,102,120,97,100,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,208,88,51,198,1,0,16,1,115,102,120,97,100,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,8,152,178,204,1,0,16,1,115,102,120,97,100,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,130,73,249,97,1,0,16,1,115,102,120,97,100,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,108,195,153,211,1,0,16,1,115,102,120,97,100,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,174,132,103,67,1,0,16,1,115,102,120,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,117,210,148,207,5,0,32,0,115,102,120,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,175,3,183,94,5,0,32,0,115,102,120,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,15,14,166,255,5,0,32,0,115,102,120,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,197,37,232,52,5,0,32,0,115,102,120,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,231,50,204,183,5,0,32,0,115,102,120,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,24,173,118,131,5,0,32,0,115,102,120,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,54,179,177,245,5,0,32,0,115,102,120,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,107,92,157,69,5,0,32,0,115,102,120,46,50,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,175,84,40,227,5,0,32,0,115,102,120,46,50,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,39,41,15,118,5,0,32,0,115,102,120,46,50,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,8,2,233,30,5,0,32,0,115,102,120,46,50,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,15,64,20,248,5,0,32,0,115,102,120,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,53,136,123,180,10,0,16,1,115,102,120,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,99,34,0,10,0,16,1,115,102,120,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,118,212,219,155,12,0,64,0,115,102,120,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,171,58,94,160,12,0,64,0,115,115,102,106,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,237,239,176,126,1,0,16,1,115,115,102,106,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,100,33,50,215,1,0,16,1,115,115,102,106,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,154,209,24,9,1,0,16,1,115,115,102,106,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,205,166,8,216,1,0,16,1,115,115,102,106,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,27,155,106,235,1,0,16,1,115,115,102,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,117,210,148,207,5,0,32,0,115,115,102,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,175,3,183,94,5,0,32,0,115,115,102,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,15,14,166,255,5,0,32,0,115,115,102,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,197,37,232,52,5,0,32,0,115,115,102,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,231,50,204,183,5,0,32,0,115,115,102,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,24,173,118,131,5,0,32,0,115,115,102,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,54,179,177,245,5,0,32,0,115,115,102,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,107,92,157,69,5,0,32,0,115,115,102,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,140,126,36,235,10,0,16,1,115,115,102,46,113,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,92,218,249,166,12,0,64,0,115,115,102,46,113,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,38,174,102,140,12,0,64,0,115,115,102,46,113,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,202,194,92,105,12,0,64,0,115,115,102,46,113,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,50,190,158,157,12,0,64,0,115,115,102,46,113,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,183,231,112,71,12,0,64,0,115,115,102,46,113,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,81,201,121,78,12,0,64,0,115,115,102,46,113,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,19,67,209,205,12,0,64,0,115,115,102,46,113,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,140,8,90,111,12,0,64,0,115,115,102,106,46,48,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,4,19,191,11,1,0,16,1,115,115,102,106,46,48,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,92,213,59,1,1,0,16,1,115,115,102,106,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,154,209,24,9,1,0,16,1,115,115,102,106,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,205,166,8,216,1,0,16,1,115,115,102,106,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,27,155,106,235,1,0,16,1,115,115,102,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,117,210,148,207,5,0,32,0,115,115,102,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,175,3,183,94,5,0,32,0,115,115,102,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,15,14,166,255,5,0,32,0,115,115,102,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,197,37,232,52,5,0,32,0,115,115,102,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,231,50,204,183,5,0,32,0,115,115,102,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,24,173,118,131,5,0,32,0,115,115,102,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,54,179,177,245,5,0,32,0,115,115,102,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,107,92,157,69,5,0,32,0,115,115,102,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,140,126,36,235,10,0,16,1,115,115,102,46,113,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,92,218,249,166,12,0,64,0,115,115,102,46,113,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,38,174,102,140,12,0,64,0,115,115,102,46,113,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,202,194,92,105,12,0,64,0,115,115,102,46,113,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,50,190,158,157,12,0,64,0,115,115,102,46,113,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,183,231,112,71,12,0,64,0,115,115,102,46,113,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,81,201,121,78,12,0,64,0,115,115,102,46,113,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,19,67,209,205,12,0,64,0,115,115,102,46,113,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,140,8,90,111,12,0,64,0,115,115,102,97,46,48,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,32,197,163,210,1,0,16,1,115,115,102,97,46,48,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,66,54,135,93,1,0,16,1,115,115,102,97,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,226,77,251,248,1,0,16,1,115,115,102,97,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,231,206,138,170,1,0,16,1,115,115,102,97,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,23,146,226,54,1,0,16,1,115,115,102,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,117,210,148,207,5,0,32,0,115,115,102,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,175,3,183,94,5,0,32,0,115,115,102,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,15,14,166,255,5,0,32,0,115,115,102,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,197,37,232,52,5,0,32,0,115,115,102,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,231,50,204,183,5,0,32,0,115,115,102,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,24,173,118,131,5,0,32,0,115,115,102,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,54,179,177,245,5,0,32,0,115,115,102,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,107,92,157,69,5,0,32,0,115,115,102,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,140,126,36,235,10,0,16,1,115,115,102,46,113,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,92,218,249,166,12,0,64,0,115,115,102,46,113,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,38,174,102,140,12,0,64,0,115,115,102,46,113,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,202,194,92,105,12,0,64,0,115,115,102,46,113,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,50,190,158,157,12,0,64,0,115,115,102,46,113,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,183,231,112,71,12,0,64,0,115,115,102,46,113,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,81,201,121,78,12,0,64,0,115,115,102,46,113,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,19,67,209,205,12,0,64,0,115,115,102,46,113,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,140,8,90,111,12,0,64,0,15,0,0,0,255,255,223,0,0,0,0,0,16,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,72,202,5,0,15,0,0,0,1,3,3,0,80,246,3,0,15,0,0,0,1,3,2,0,80,124,6,0,15,0,0,0,1,3,1,0,112,212,3,0,15,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,2,0,224,172,5,0,15,0,0,0,1,4,0,0,32,137,5,0,15,0,0,0,1,4,4,0,224,109,5,0,0,0,0,0,254,0,2,0,104,159,3,0,15,0,0,0,1,8,8,0,56,111,3,0,15,0,0,0,1,8,0,0,104,134,3,0,0,0,0,0,254,0,2,0,200,30,2,0,15,0,0,0,1,32,0,0,120,97,1,0,15,0,0,0,1,32,32,0,96,19,1,0,0,0,0,0,254,0,4,0,128,129,4,0,15,0,0,0,1,192,0,0,208,75,4,0,15,0,0,0,1,192,192,0,8,49,4,0,15,0,0,0,1,192,128,0,152,21,4,0,15,0,0,0,1,192,64,0,72,246,3,0,0,0,0,0,254,0,11,0,200,87,7,0,16,0,0,0,1,15,6,0,32,136,7,0,16,0,0,0,1,15,8,0,40,88,7,0,16,0,0,0,1,15,10,0,96,39,7,0,16,0,0,0,1,15,7,0,120,113,6,0,16,0,0,0,1,15,9,0,232,216,6,0,16,0,0,0,1,15,15,0,144,251,6,0,16,0,0,0,1,15,14,0,184,164,6,0,16,0,0,0,1,15,13,0,80,74,6,0,16,0,0,0,1,15,12,0,192,32,6,0,16,0,0,0,1,15,11,0,192,234,2,0,16,0,0,0,1,15,0,0,16,227,4,0,0,0,0,0,254,0,11,0,160,123,6,0,16,0,0,0,1,240,96,0,32,136,7,0,16,0,0,0,1,240,128,0,40,88,7,0,16,0,0,0,1,240,160,0,96,39,7,0,16,0,0,0,1,240,112,0,120,113,6,0,16,0,0,0,1,240,144,0,232,216,6,0,16,0,0,0,1,240,240,0,144,251,6,0,16,0,0,0,1,240,224,0,184,164,6,0,16,0,0,0,1,240,208,0,80,74,6,0,16,0,0,0,1,240,192,0,192,32,6,0,16,0,0,0,1,240,176,0,192,234,2,0,16,0,0,0,1,240,0,0,16,227,4,0,0,0,0,0,0,0,0,0,64,0,0,0,128,0,0,0,192,0,0,0,0,1,0,0,64,1,0,0,128,1,0,0,192,1,0,0,0,2,0,0,64,2,0,0,128,2,0,0,192,2,0,0,0,3,0,0,64,3,0,0,128,3,0,0,192,3,0,0,0,0,0,0,64,0,0,0,128,0,0,0,192,0,0,0,0,1,0,0,64,1,0,0,128,1,0,0,192,1,0,0,0,2,0,0,64,2,0,0,128,2,0,0,192,2,0,0,0,3,0,0,64,3,0,0,128,3,0,0,192,3,0,0,0,0,0,0,64,0,0,0,128,0,0,0,192,0,0,0,0,1,0,0,64,1,0,0,128,1,0,0,192,1,0,0,0,0,0,0,64,0,0,0,128,0,0,0,192,0,0,0,0,1,0,0,64,1,0,0,128,1,0,0,192,1,0,0,0,2,0,0,64,2,0,0,128,2,0,0,192,2,0,0,0,3,0,0,64,3,0,0,128,3,0,0,192,3,0,0,0,0,0,0,64,0,0,0,128,0,0,0,192,0,0,0,0,1,0,0,64,1,0,0,128,1,0,0,192,1,0,0,0,2,0,0,64,2,0,0,128,2,0,0,192,2,0,0,0,3,0,0,64,3,0,0,128,3,0,0,192,3,0,0,0,0,0,0,16,0,0,0,32,0,0,0,48,0,0,0,64,0,0,0,80,0,0,0,96,0,0,0,112,0,0,0,0,1,0,0,16,1,0,0,32,1,0,0,48,1,0,0,64,1,0,0,80,1,0,0,96,1,0,0,112,1,0,0,0,0,0,0,32,0,0,0,64,0,0,0,96,0,0,0,128,0,0,0,160,0,0,0,192,0,0,0,224,0,0,0,0,2,0,0,32,2,0,0,64,2,0,0,96,2,0,0,128,2,0,0,160,2,0,0,192,2,0,0,224,2,0,0,4,0,0,0,0,0,0,0,12,0,0,0,8,0,0,0,20,0,0,0,16,0,0,0,28,0,0,0,24,0,0,0,36,0,0,0,32,0,0,0,44,0,0,0,40,0,0,0,52,0,0,0,48,0,0,0,60,0,0,0,56,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,4,0,0,0,0,0,0,0,12,0,0,0,8,0,0,0,20,0,0,0,16,0,0,0,28,0,0,0,24,0,0,0,36,0,0,0,32,0,0,0,44,0,0,0,40,0,0,0,52,0,0,0,48,0,0,0,60,0,0,0,56,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,128,0,0,0,129,0,0,0,130,0,0,0,131,0,0,0,132,0,0,0,133,0,0,0,134,0,0,0,135,0,0,0,3,0,0,0,2,0,0,0,1,0,0,0,0,0,0,0,19,0,0,0,18,0,0,0,17,0,0,0,16,0,0,0,3,1,0,0,2,1,0,0,1,1,0,0,0,1,0,0,19,1,0,0,18,1,0,0,17,1,0,0,16,1,0,0,0,0,0,0,4,0,0,0,8,0,0,0,12,0,0,0,16,0,0,0,20,0,0,0,24,0,0,0,28,0,0,0,32,0,0,0,36,0,0,0,40,0,0,0,44,0,0,0,48,0,0,0,52,0,0,0,56,0,0,0,60,0,0,0,4,0,0,0,0,0,0,0,4,0,4,0,0,0,4,0,12,0,0,0,8,0,0,0,12,0,4,0,8,0,4,0,20,0,0,0,16,0,0,0,20,0,4,0,16,0,4,0,28,0,0,0,24,0,0,0,28,0,4,0,24,0,4,0,0,0,0,0,4,0,0,0,0,0,32,0,4,0,32,0,8,0,0,0,12,0,0,0,8,0,32,0,12,0,32,0,128,0,0,0,132,0,0,0,128,0,32,0,132,0,32,0,136,0,0,0,140,0,0,0,136,0,32,0,140,0,32,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,128,0,0,0,129,0,0,0,130,0,0,0,131,0,0,0,0,1,0,0,1,1,0,0,2,1,0,0,3,1,0,0,128,1,0,0,129,1,0,0,130,1,0,0,131,1,0,0,112,122,102,106,100,46,48,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,8,237,133,94,1,0,16,1,112,122,102,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,226,73,6,184,1,0,16,1,112,122,102,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,203,129,72,45,5,0,32,0,112,122,102,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,190,209,15,75,5,0,32,0,112,122,102,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,51,172,58,228,5,0,32,0,112,122,102,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,241,111,83,127,5,0,32,0,112,122,102,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,163,178,15,96,10,0,16,1,112,122,102,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,224,118,96,73,10,0,16,1,112,122,102,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,67,39,68,120,12,0,64,0,112,122,102,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,123,44,157,57,12,0,64,0,168,86,7,0,1,0,0,0,212,47,216,0,248,191,2,0,24,38,7,0,1,0,0,0,208,47,216,0,184,160,2,0,56,210,6,0,1,0,0,0,35,48,216,0,192,135,2,0,24,163,6,0,1,0,0,0,34,48,216,0,240,108,2,0,152,122,6,0,1,0,0,0,33,48,216,0,96,82,2,0,192,72,6,0,1,0,0,0,32,48,216,0,32,56,2,0,200,48,4,0,1,0,0,0,36,48,216,0,152,30,2,0,56,21,4,0,1,0,0,0,37,48,216,0,232,10,2,0,40,246,1,0,1,0,0,0,213,47,216,0,64,246,1,0,144,236,1,0,1,0,0,0,209,47,216,0,136,224,1,0,176,223,1,0,1,0,0,0,43,48,216,0,72,198,1,0,192,209,1,0,1,0,0,0,42,48,216,0,24,182,1,0,24,198,1,0,1,0,0,0,41,48,216,0,40,167,1,0,120,189,1,0,1,0,0,0,40,48,216,0,200,149,1,0,168,70,1,0,1,0,0,0,44,48,216,0,56,126,1,0,16,65,1,0,1,0,0,0,45,48,216,0,32,101,1,0,88,212,3,0,1,0,0,0,144,46,216,0,40,185,3,0,240,152,1,0,1,0,0,0,201,47,216,0,216,70,1,0,16,17,8,0,1,0,0,0,202,47,216,0,224,12,8,0,136,67,2,0,1,0,0,0,176,48,216,0,152,138,8,0,8,66,2,0,1,0,0,0,184,48,216,0,48,119,7,0,115,112,100,99,111,105,110,46,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,73,30,207,101,1,0,16,1,115,112,100,99,111,105,110,46,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,50,146,229,30,1,0,16,1,115,112,100,99,111,105,110,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,183,100,207,180,2,0,16,1,115,112,100,99,111,105,110,46,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,240,77,48,146,2,0,16,1,115,112,100,99,111,105,110,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,188,29,95,221,4,0,32,0,115,112,100,99,111,105,110,46,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,27,232,31,171,4,0,32,0,115,112,100,99,111,105,110,46,99,108,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,86,204,44,26,7,0,32,0,7,0,0,0,255,255,0,0,0,0,0,0,8,0,0,0,255,255,3,0,0,0,0,0,9,0,0,0,255,255,6,0,0,0,0,0,0,0,0,0,254,0,2,0,72,4,1,0,8,0,0,0,1,1,1,0,96,135,7,0,8,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,16,227,4,0,8,0,0,0,1,2,2,0,96,135,7,0,8,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,72,202,5,0,9,0,0,0,1,4,4,0,80,246,3,0,9,0,0,0,1,4,0,0,112,212,3,0,0,0,0,0,254,0,2,0,128,129,4,0,9,0,0,0,1,8,0,0,8,49,4,0,9,0,0,0,1,8,8,0,72,246,3,0,0,0,0,0,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,57,152,204,56,1,0,16,1,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,214,168,159,65,1,0,16,1,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,239,157,147,161,1,0,16,1,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,197,23,207,203,1,0,16,1,101,109,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,156,193,129,235,1,0,16,1,102,109,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,114,118,123,117,1,0,16,1,103,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,145,59,113,87,1,0,16,1,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,71,216,154,21,1,0,16,1,50,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,39,37,232,162,4,0,32,0,49,55,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,21,42,147,19,4,0,32,0,50,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,116,173,195,128,4,0,32,0,49,55,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,69,209,207,36,4,0,32,0,109,109,105,54,51,51,49,46,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,135,125,12,106,7,0,32,0,101,112,114,45,54,51,57,50,46,49,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,6,69,155,50,0,0,16,1,101,112,114,45,54,51,57,51,46,49,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,95,226,86,59,0,0,16,1,101,112,114,45,54,51,57,52,46,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,1,19,124,100,0,0,16,1,101,112,114,45,54,51,49,54,46,49,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,17,85,249,29,0,0,16,1,101,112,114,45,54,51,50,56,46,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,50,40,191,162,0,0,32,0,101,112,114,45,54,51,57,55,46,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,113,68,13,198,0,0,32,0,101,112,114,45,54,51,50,54,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,76,187,159,38,0,0,32,0,101,112,114,45,54,51,57,54,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,59,207,92,193,0,0,32,0,101,112,114,45,54,51,50,52,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,99,181,179,138,0,0,32,0,101,112,114,45,54,51,57,53,46,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,101,48,8,63,0,0,32,0,101,112,114,45,54,51,48,54,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,50,225,113,232,0,0,32,0,101,112,114,45,54,51,48,56,46,49,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,14,217,194,153,0,0,32,0,101,112,114,45,54,51,48,55,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,67,213,90,10,0,0,32,0,101,112,114,45,54,51,48,57,46,49,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,152,173,35,116,0,0,32,0,112,114,45,53,51,49,55,46,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,184,80,131,100,0,0,0,8,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,252,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,19,0,0,0,1,15,7,0,80,252,6,0,19,0,0,0,1,15,8,0,16,242,7,0,19,0,0,0,1,15,9,0,104,236,7,0,19,0,0,0,1,15,5,0,192,54,8,0,19,0,0,0,1,15,4,0,56,24,4,0,19,0,0,0,1,15,15,0,128,230,7,0,19,0,0,0,1,15,0,0,128,230,7,0,19,0,0,0,1,15,3,0,176,162,3,0,19,0,0,0,1,15,2,0,24,188,3,0,19,0,0,0,1,15,1,0,72,216,3,0,19,0,0,0,1,15,6,0,120,211,6,0,19,0,0,0,1,15,14,0,184,164,6,0,19,0,0,0,1,15,13,0,80,74,6,0,19,0,0,0,1,15,12,0,192,32,6,0,19,0,0,0,1,15,11,0,192,234,2,0,19,0,0,0,1,15,10,0,32,242,5,0,0,0,0,0,254,0,16,0,160,123,6,0,19,0,0,0,1,240,112,0,80,252,6,0,19,0,0,0,1,240,128,0,16,242,7,0,19,0,0,0,1,240,144,0,104,236,7,0,19,0,0,0,1,240,80,0,192,54,8,0,19,0,0,0,1,240,64,0,56,24,4,0,19,0,0,0,1,240,240,0,128,230,7,0,19,0,0,0,1,240,0,0,128,230,7,0,19,0,0,0,1,240,48,0,176,162,3,0,19,0,0,0,1,240,32,0,24,188,3,0,19,0,0,0,1,240,16,0,72,216,3,0,19,0,0,0,1,240,96,0,120,211,6,0,19,0,0,0,1,240,224,0,184,164,6,0,19,0,0,0,1,240,208,0,80,74,6,0,19,0,0,0,1,240,192,0,192,32,6,0,19,0,0,0,1,240,176,0,192,234,2,0,19,0,0,0,1,240,160,0,32,242,5,0,0,0,0,0,254,0,2,0,200,30,2,0,20,0,0,0,1,1,0,0,120,97,1,0,20,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,2,0,168,234,7,0,20,0,0,0,1,2,2,0,96,135,7,0,20,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,12,8,0,208,75,4,0,20,0,0,0,1,12,12,0,8,49,4,0,20,0,0,0,1,12,4,0,152,21,4,0,20,0,0,0,1,12,0,0,112,49,6,0,0,0,0,0,254,0,4,0,64,37,5,0,20,0,0,0,1,48,48,0,104,157,5,0,20,0,0,0,1,48,32,0,64,155,5,0,20,0,0,0,1,48,16,0,240,191,4,0,20,0,0,0,1,48,0,0,120,7,5,0,0,0,0,0,254,0,2,0,184,148,5,0,20,0,0,0,1,64,64,0,56,111,3,0,20,0,0,0,1,64,0,0,104,134,3,0,0,0,0,0,54,46,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,243,176,94,100,0,0,16,1,55,46,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,130,196,245,27,0,0,16,1,56,46,51,106,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,252,222,108,10,0,0,16,1,49,46,51,106,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,46,86,110,250,0,0,16,1,49,50,46,51,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,28,41,113,179,0,0,32,0,49,49,46,51,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,175,210,148,111,0,0,32,0,49,48,46,51,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,161,194,16,131,0,0,32,0,57,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,66,108,126,171,0,0,32,0,50,46,53,108,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,227,43,250,128,0,0,32,0,51,46,54,108,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,180,6,97,35,0,0,32,0,52,46,55,108,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,217,229,143,8,0,0,32,0,53,46,56,108,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,42,35,102,131,0,0,32,0,17,0,0,0,255,255,2,0,0,0,0,0,18,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,168,234,7,0,17,0,0,0,1,1,1,0,96,135,7,0,17,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,200,30,2,0,17,0,0,0,1,2,2,0,120,97,1,0,17,0,0,0,1,2,0,0,96,19,1,0,0,0,0,0,254,0,4,0,128,129,4,0,17,0,0,0,1,12,12,0,208,75,4,0,17,0,0,0,1,12,0,0,8,49,4,0,17,0,0,0,1,12,8,0,152,21,4,0,17,0,0,0,1,12,4,0,72,246,3,0,0,0,0,0,254,0,4,0,200,87,7,0,17,0,0,0,1,192,128,0,224,127,8,0,17,0,0,0,1,192,0,0,32,123,8,0,17,0,0,0,1,192,64,0,48,137,5,0,17,0,0,0,1,192,192,0,240,109,5,0,0,0,0,0,254,0,4,0,160,123,6,0,17,0,0,0,1,48,32,0,224,127,8,0,17,0,0,0,1,48,0,0,32,123,8,0,17,0,0,0,1,48,16,0,48,137,5,0,17,0,0,0,1,48,48,0,240,109,5,0,0,0,0,0,254,0,4,0,72,202,5,0,18,0,0,0,1,3,2,0,80,246,3,0,18,0,0,0,1,3,0,0,248,38,7,0,18,0,0,0,1,3,1,0,48,90,7,0,18,0,0,0,1,3,3,0,48,123,8,0,0,0,0,0,254,0,4,0,72,84,4,0,18,0,0,0,1,12,8,0,248,81,6,0,18,0,0,0,1,12,0,0,248,38,7,0,18,0,0,0,1,12,4,0,120,54,8,0,18,0,0,0,1,12,12,0,128,65,6,0,0,0,0,0,254,0,2,0,80,238,4,0,18,0,0,0,1,16,0,0,248,38,7,0,18,0,0,0,1,16,16,0,48,123,8,0,0,0,0,0,254,0,8,0,64,37,5,0,18,0,0,0,1,224,0,0,72,224,3,0,18,0,0,0,1,224,128,0,184,193,3,0,18,0,0,0,1,224,64,0,24,168,3,0,18,0,0,0,1,224,192,0,24,87,2,0,18,0,0,0,1,224,32,0,192,33,6,0,18,0,0,0,1,224,160,0,0,64,7,0,18,0,0,0,1,224,96,0,120,124,5,0,18,0,0,0,1,224,224,0,120,7,5,0,0,0,0,0,115,110,97,112,50,46,114,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,211,78,158,154,1,0,16,1,115,110,97,112,49,46,114,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,106,141,70,205,1,0,16,1,115,110,97,112,52,46,114,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,30,142,132,15,2,0,32,0,115,110,97,112,51,46,114,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,14,207,248,199,2,0,32,0,115,110,97,112,53,46,114,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,235,8,142,55,2,0,32,0,10,0,0,0,255,255,255,0,0,0,0,0,11,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,8,0,200,87,7,0,10,0,0,0,1,7,7,0,128,230,7,0,10,0,0,0,1,7,6,0,184,164,6,0,10,0,0,0,1,7,5,0,80,74,6,0,10,0,0,0,1,7,4,0,192,32,6,0,10,0,0,0,1,7,3,0,192,234,2,0,10,0,0,0,1,7,2,0,104,236,7,0,10,0,0,0,1,7,1,0,16,242,7,0,10,0,0,0,1,7,0,0,80,252,6,0,0,0,0,0,254,0,4,0,128,129,4,0,10,0,0,0,1,24,16,0,8,49,4,0,10,0,0,0,1,24,24,0,152,21,4,0,10,0,0,0,1,24,8,0,72,246,3,0,10,0,0,0,1,24,0,0,72,0,3,0,0,0,0,0,254,0,2,0,168,234,7,0,11,0,0,0,1,16,0,0,96,135,7,0,11,0,0,0,1,16,16,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,11,0,0,0,1,128,128,0,96,135,7,0,11,0,0,0,1,128,0,0,152,182,7,0,102,97,49,52,45,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,57,30,67,14,0,0,16,1,102,97,49,50,45,50,46,57,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,148,66,83,27,0,0,16,1,102,97,49,53,46,49,57,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,102,146,167,4,0,0,16,1,102,97,49,51,46,49,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,179,196,28,100,0,0,16,1,102,97,49,48,46,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,37,255,210,223,0,0,16,1,102,97,48,53,46,49,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,36,41,128,9,0,0,32,0,102,97,48,52,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,149,184,37,236,0,0,32,0,102,97,48,55,46,49,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,139,38,50,233,0,0,32,0,102,97,48,54,46,49,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,192,56,221,196,0,0,32,0,102,97,48,57,46,50,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,190,233,149,19,0,0,32,0,102,97,48,56,46,50,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,219,100,116,77,0,0,32,0,102,97,48,49,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,146,205,176,153,0,0,32,0,102,97,48,51,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,77,167,126,14,0,0,32,0,102,97,48,48,46,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,215,63,223,247,0,0,32,0,102,97,48,50,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,157,218,232,132,0,0,32,0,102,97,49,49,46,49,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,173,123,84,78,0,0,64,0,109,98,55,49,49,52,104,46,50,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,212,232,38,173,0,0,0,8,112,97,108,49,54,108,56,98,45,116,97,45,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,39,117,168,121,0,0,0,8,112,97,108,49,54,114,52,97,45,116,97,45,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,17,19,163,236,0,0,0,8,112,97,108,49,54,108,56,97,45,116,97,45,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,25,73,50,108,0,0,0,8,112,97,108,49,54,108,56,97,45,116,97,45,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,250,119,97,17,0,0,0,8,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,205,99,186,125,1,0,16,1,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,243,113,102,216,1,0,16,1,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,66,14,77,209,1,0,16,1,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,216,60,6,56,1,0,16,1,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,81,3,20,220,4,0,32,0,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,53,128,232,154,4,0,32,0,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,89,247,33,83,4,0,32,0,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,118,95,235,200,4,0,32,0,49,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,20,34,101,33,4,0,32,0,49,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,176,46,157,212,4,0,32,0,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,214,191,152,13,4,0,32,0,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,241,132,114,128,4,0,32,0,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,197,121,53,41,4,0,32,0,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,231,124,114,195,4,0,32,0,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,59,136,25,41,4,0,32,0,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,32,230,56,245,4,0,32,0,109,98,95,113,97,46,53,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,196,3,26,226,3,0,16,1,112,105,99,49,54,99,53,55,45,120,116,45,112,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,204,92,174,174,7,0,16,0,112,105,99,49,54,99,53,55,45,120,116,45,112,46,104,101,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,30,90,0,0,126,96,248,97,0,0,0,8,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,28,193,160,115,5,0,64,0,48,50,115,95,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,152,23,137,160,0,0,16,1,48,51,115,95,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,70,93,81,95,0,0,16,1,48,55,115,95,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,5,169,128,198,0,0,16,1,48,56,115,95,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,38,191,102,61,0,0,16,1,48,52,97,95,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,170,233,157,33,0,0,32,0,48,57,104,95,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,31,126,229,37,0,0,32,0,49,48,104,95,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,233,229,13,207,0,0,32,0,49,49,104,95,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,72,192,80,64,0,0,32,0,48,54,97,95,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,131,147,128,28,0,0,32,0,48,55,97,95,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,116,215,101,86,0,0,32,0,48,56,97,95,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,42,143,218,109,0,0,32,0,48,57,97,95,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,184,221,33,106,0,0,32,0,49,48,97,95,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,224,72,229,242,0,0,32,0,49,49,97,95,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,18,177,129,134,0,0,32,0,48,49,106,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,163,178,148,106,0,0,32,0,48,49,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,211,35,9,236,0,0,32,0,48,49,102,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,82,112,233,173,0,0,32,0,109,49,46,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,1,146,163,131,0,0,32,0,18,0,0,0,255,255,187,0,0,0,0,0,19,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,18,0,0,0,1,3,3,0,8,49,4,0,18,0,0,0,1,3,2,0,152,21,4,0,18,0,0,0,1,3,1,0,72,246,3,0,18,0,0,0,1,3,0,0,72,0,3,0,0,0,0,0,254,0,2,0,104,159,3,0,18,0,0,0,1,4,4,0,96,135,7,0,18,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,129,2,0,18,0,0,0,1,8,8,0,96,135,7,0,18,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,246,3,0,18,0,0,0,1,16,16,0,96,135,7,0,18,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,2,0,112,104,5,0,18,0,0,0,1,32,32,0,96,135,7,0,18,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,200,30,2,0,18,0,0,0,1,64,0,0,120,97,1,0,18,0,0,0,1,64,64,0,96,19,1,0,0,0,0,0,254,0,2,0,72,4,1,0,18,0,0,0,1,128,128,0,96,135,7,0,18,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,8,0,200,87,7,0,19,0,0,0,1,7,2,0,224,127,8,0,19,0,0,0,1,7,1,0,136,252,1,0,19,0,0,0,1,7,7,0,32,123,8,0,19,0,0,0,1,7,6,0,192,110,8,0,19,0,0,0,1,7,5,0,96,102,7,0,19,0,0,0,1,7,4,0,184,105,6,0,19,0,0,0,1,7,3,0,192,100,6,0,19,0,0,0,1,7,0,0,104,151,6,0,0,0,0,0,254,0,8,0,160,123,6,0,19,0,0,0,1,56,0,0,96,164,8,0,19,0,0,0,1,56,8,0,144,102,8,0,19,0,0,0,1,56,16,0,176,45,8,0,19,0,0,0,1,56,24,0,224,127,8,0,19,0,0,0,1,56,56,0,32,123,8,0,19,0,0,0,1,56,32,0,232,143,1,0,19,0,0,0,1,56,48,0,192,110,8,0,19,0,0,0,1,56,40,0,96,102,7,0,0,0,0,0,18,0,0,0,255,255,255,0,0,0,0,0,19,0,0,0,255,255,242,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,160,123,6,0,18,0,0,0,1,3,0,0,40,88,7,0,18,0,0,0,1,3,1,0,96,39,7,0,18,0,0,0,1,3,3,0,144,251,6,0,18,0,0,0,1,3,2,0,184,164,6,0,0,0,0,0,254,0,2,0,72,4,1,0,18,0,0,0,1,4,4,0,96,135,7,0,18,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,176,110,8,0,18,0,0,0,1,8,0,0,96,135,7,0,18,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,18,0,0,0,1,16,0,0,96,135,7,0,18,0,0,0,1,16,16,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,18,0,0,0,1,96,0,0,40,88,7,0,18,0,0,0,1,96,32,0,96,39,7,0,18,0,0,0,1,96,96,0,144,251,6,0,18,0,0,0,1,96,64,0,184,164,6,0,0,0,0,0,254,0,2,0,232,75,4,0,18,0,0,0,1,128,128,0,96,135,7,0,18,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,1,0,0,96,135,7,0,19,0,0,0,1,1,1,0,152,182,7,0,0,0,0,0,254,0,2,0,56,8,3,0,19,0,0,0,1,2,0,0,56,111,3,0,19,0,0,0,1,2,2,0,104,134,3,0,0,0,0,0,254,0,4,0,64,37,5,0,19,0,0,0,1,48,0,0,120,219,2,0,19,0,0,0,1,48,16,0,96,199,2,0,19,0,0,0,1,48,32,0,72,181,2,0,19,0,0,0,1,48,48,0,64,167,2,0,0,0,0,0,254,0,4,0,128,129,4,0,19,0,0,0,1,192,128,0,192,255,2,0,19,0,0,0,1,192,64,0,208,75,4,0,19,0,0,0,1,192,192,0,8,49,4,0,19,0,0,0,1,192,0,0,72,246,3,0,0,0,0,0,115,107,121,98,97,115,101,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,165,135,91,132,1,0,16,1,115,107,121,98,97,115,101,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,194,133,103,9,1,0,16,1,115,107,121,98,97,115,101,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,91,113,12,213,1,0,16,1,115,107,121,98,97,115,101,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,39,219,126,245,1,0,16,1,115,107,121,98,97,115,101,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,149,93,54,80,1,0,16,1,115,107,121,98,97,115,101,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,127,100,214,203,1,0,16,1,115,107,121,98,97,115,101,46,55,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,134,22,71,155,4,0,32,0,115,107,121,98,97,115,101,46,56,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,218,35,247,28,4,0,32,0,115,107,121,98,97,115,101,46,49,48,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,44,231,2,254,4,0,32,0,115,107,121,98,97,115,101,46,57,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,31,41,113,8,4,0,32,0,56,50,115,49,50,51,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,135,125,12,106,7,0,32,0,12,0,0,0,255,255,0,0,0,0,0,0,13,0,0,0,255,255,0,0,0,0,0,0,14,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,12,0,0,0,1,32,0,0,120,97,1,0,12,0,0,0,1,32,32,0,96,19,1,0,0,0,0,0,254,0,4,0,32,4,2,0,13,0,0,0,1,192,128,0,88,121,1,0,13,0,0,0,1,192,0,0,128,103,7,0,13,0,0,0,1,192,64,0,80,196,7,0,13,0,0,0,1,192,192,0,104,151,6,0,0,0,0,0,254,0,4,0,128,129,4,0,14,0,0,0,1,3,0,0,8,49,4,0,14,0,0,0,1,3,1,0,152,21,4,0,14,0,0,0,1,3,2,0,72,246,3,0,14,0,0,0,1,3,3,0,112,49,6,0,0,0,0,0,254,0,4,0,64,37,5,0,14,0,0,0,1,12,0,0,176,116,6,0,14,0,0,0,1,12,64,0,80,113,6,0,14,0,0,0,1,12,64,0,80,110,6,0,14,0,0,0,1,12,64,0,120,7,5,0,0,0,0,0,101,112,114,45,49,50,50,53,54,46,97,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,27,238,135,89,1,0,16,1,101,112,114,45,49,50,50,53,51,46,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,223,34,168,38,1,0,16,1,101,112,114,45,49,50,50,53,55,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,63,204,42,58,1,0,16,1,101,112,114,45,49,50,50,53,52,46,97,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,23,130,144,126,1,0,16,1,101,112,114,45,49,50,50,50,52,45,57,53,46,98,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,161,123,193,234,2,0,32,0,101,112,114,45,49,50,50,50,53,45,57,52,46,98,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,152,252,16,35,2,0,32,0,101,112,114,45,49,50,50,50,54,45,57,51,46,98,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,153,105,14,33,2,0,32,0,101,112,114,45,49,50,50,51,50,45,49,48,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,43,198,222,10,3,0,32,0,101,112,114,45,49,50,50,51,54,45,49,49,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,248,154,107,40,3,0,32,0,101,112,114,45,49,50,50,51,51,45,49,55,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,156,150,69,62,3,0,32,0,101,112,114,45,49,50,50,51,55,45,49,56,46,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,150,142,5,229,3,0,32,0,101,112,114,45,49,50,50,51,52,45,50,51,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,239,84,141,140,3,0,32,0,101,112,114,45,49,50,50,51,56,45,50,52,46,98,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,4,51,218,122,3,0,32,0,101,112,114,45,49,50,50,51,53,45,50,57,46,98,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,17,213,69,250,3,0,32,0,101,112,114,45,49,50,50,51,57,45,51,48,46,98,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,139,12,247,145,3,0,32,0,101,112,114,45,49,50,50,52,52,46,97,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,229,71,42,203,4,0,16,1,101,112,114,45,49,50,50,52,53,46,97,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,52,65,22,102,8,0,64,0,101,112,114,45,49,50,50,52,54,46,97,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,130,37,36,241,8,0,64,0,101,112,114,45,49,50,50,52,55,46,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,198,100,138,239,8,0,64,0,101,112,114,45,49,50,50,52,56,46,97,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,171,189,234,209,8,0,64,0,51,49,55,45,53,48,50,49,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,55,41,227,195,5,0,16,1,28,0,0,0,255,255,255,0,0,0,0,0,29,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,29,0,0,0,1,15,7,0,80,252,6,0,29,0,0,0,1,15,8,0,16,242,7,0,29,0,0,0,1,15,9,0,104,236,7,0,29,0,0,0,1,15,5,0,176,51,4,0,29,0,0,0,1,15,4,0,56,24,4,0,29,0,0,0,1,15,15,0,128,230,7,0,29,0,0,0,1,15,1,0,72,216,3,0,29,0,0,0,1,15,2,0,24,188,3,0,29,0,0,0,1,15,3,0,176,162,3,0,29,0,0,0,1,15,6,0,120,211,6,0,29,0,0,0,1,15,14,0,184,164,6,0,29,0,0,0,1,15,13,0,80,74,6,0,29,0,0,0,1,15,12,0,192,32,6,0,29,0,0,0,1,15,11,0,192,234,2,0,29,0,0,0,1,15,10,0,32,242,5,0,29,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,29,0,0,0,1,240,112,0,80,252,6,0,29,0,0,0,1,240,128,0,16,242,7,0,29,0,0,0,1,240,144,0,104,236,7,0,29,0,0,0,1,240,80,0,176,51,4,0,29,0,0,0,1,240,64,0,56,24,4,0,29,0,0,0,1,240,240,0,128,230,7,0,29,0,0,0,1,240,16,0,72,216,3,0,29,0,0,0,1,240,32,0,24,188,3,0,29,0,0,0,1,240,48,0,176,162,3,0,29,0,0,0,1,240,96,0,120,211,6,0,29,0,0,0,1,240,224,0,184,164,6,0,29,0,0,0,1,240,208,0,80,74,6,0,29,0,0,0,1,240,192,0,192,32,6,0,29,0,0,0,1,240,176,0,192,234,2,0,29,0,0,0,1,240,160,0,32,242,5,0,29,0,0,0,1,240,0,0,208,236,2,0,115,112,48,52,46,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,30,96,249,51,0,0,16,1,115,112,48,51,46,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,179,67,251,199,0,0,16,1,117,50,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,14,196,248,203,0,0,16,1,117,49,46,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,58,225,119,244,0,0,32,0,118,116,49,49,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,72,27,46,123,0,0,32,0,118,116,49,50,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,211,23,180,129,0,0,32,0,118,116,49,51,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,210,219,18,86,0,0,32,0,118,116,49,52,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,54,238,45,43,0,0,32,0,118,116,49,53,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,191,186,112,222,0,0,32,0,118,116,49,54,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,55,130,23,20,0,0,32,0,117,53,46,101,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,51,201,151,42,0,0,32,0,115,112,48,54,46,101,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,18,114,136,215,0,0,32,0,115,112,48,55,46,101,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,32,122,190,154,0,0,32,0,117,56,46,104,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,46,170,180,214,0,0,32,0,115,112,48,57,46,104,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,24,179,133,57,0,0,32,0,115,112,49,48,46,104,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,15,27,19,60,0,0,32,0,118,116,98,49,46,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,161,21,186,58,0,0,32,0,118,116,98,50,46,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,84,87,134,136,0,0,32,0,118,116,98,51,46,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,246,195,20,76,0,0,32,0,118,116,98,52,46,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,70,194,136,179,0,0,32,0,118,116,98,53,46,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,8,197,42,113,0,0,32,0,118,116,98,54,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,88,81,175,14,0,0,32,0,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,251,0,0,0,0,0,0,0,0,0,254,0,4,0,72,202,5,0,19,0,0,0,1,3,3,0,80,246,3,0,19,0,0,0,1,3,2,0,248,38,7,0,19,0,0,0,1,3,1,0,112,212,3,0,19,0,0,0,1,3,0,0,24,99,5,0,0,0,0,0,254,0,2,0,128,112,3,0,20,0,0,0,1,4,4,0,72,93,8,0,20,0,0,0,1,4,0,0,168,22,4,0,0,0,0,0,254,0,7,0,32,4,2,0,20,0,0,0,1,56,8,0,64,189,7,0,20,0,0,0,1,56,24,0,16,242,7,0,20,0,0,0,1,56,0,0,200,116,6,0,20,0,0,0,1,56,40,0,104,236,7,0,20,0,0,0,1,56,16,0,120,113,6,0,20,0,0,0,1,56,32,0,232,216,6,0,20,0,0,0,1,56,56,0,128,230,7,0,0,0,0,0,254,0,2,0,48,129,6,0,20,0,0,0,1,64,64,0,192,255,2,0,20,0,0,0,1,64,0,0,208,75,4,0,0,0,0,0,254,0,2,0,232,75,4,0,20,0,0,0,1,128,128,0,96,135,7,0,20,0,0,0,1,128,0,0,152,182,7,0,39,0,0,0,255,255,255,0,0,0,0,0,40,0,0,0,255,255,191,0,0,0,0,0,0,0,0,0,254,0,0,0,144,212,8,0,39,0,0,0,1,2,2,0,96,135,7,0,39,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,0,0,232,75,4,0,39,0,0,0,1,4,4,0,96,135,7,0,39,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,39,0,0,0,1,8,0,0,96,135,7,0,39,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,2,0,32,4,2,0,39,0,0,0,1,48,0,0,32,136,7,0,39,0,0,0,1,48,16,0,40,88,7,0,39,0,0,0,1,48,32,0,96,39,7,0,39,0,0,0,1,48,48,0,144,251,6,0,0,0,0,0,254,0,2,0,72,202,5,0,40,0,0,0,1,3,2,0,80,246,3,0,40,0,0,0,1,3,3,0,80,124,6,0,40,0,0,0,1,3,1,0,112,212,3,0,40,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,144,246,3,0,40,0,0,0,1,4,4,0,96,135,7,0,40,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,56,161,6,0,40,0,0,0,1,8,8,0,96,135,7,0,40,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,2,0,16,158,6,0,40,0,0,0,1,16,16,0,96,135,7,0,40,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,2,0,56,154,6,0,40,0,0,0,1,32,32,0,232,150,6,0,40,0,0,0,1,32,0,0,184,147,6,0,0,0,0,0,254,0,2,0,104,143,6,0,40,0,0,0,1,192,192,0,8,140,6,0,40,0,0,0,1,192,128,0,240,242,5,0,40,0,0,0,1,192,64,0,0,130,6,0,40,0,0,0,1,192,0,0,64,125,6,0,20,0,0,0,255,255,191,0,0,0,0,0,21,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,168,212,4,0,20,0,0,0,1,1,0,0,96,135,7,0,20,0,0,0,1,1,1,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,12,0,0,24,99,5,0,20,0,0,0,1,12,4,0,112,212,3,0,20,0,0,0,1,12,12,0,248,38,7,0,20,0,0,0,1,12,8,0,80,246,3,0,0,0,0,0,254,0,4,0,72,84,4,0,20,0,0,0,1,48,0,0,24,99,5,0,20,0,0,0,1,48,16,0,112,212,3,0,20,0,0,0,1,48,48,0,248,38,7,0,20,0,0,0,1,48,32,0,80,246,3,0,0,0,0,0,254,0,2,0,168,234,7,0,20,0,0,0,1,64,64,0,96,135,7,0,20,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,20,0,0,0,1,128,128,0,96,135,7,0,20,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,21,0,0,0,1,1,1,0,96,135,7,0,21,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,96,46,8,0,21,0,0,0,1,8,8,0,192,255,2,0,21,0,0,0,1,8,0,0,208,75,4,0,0,0,0,0,254,0,16,0,32,4,2,0,21,0,0,0,1,240,160,0,144,160,3,0,21,0,0,0,1,240,176,0,96,135,3,0,21,0,0,0,1,240,192,0,32,136,7,0,21,0,0,0,1,240,208,0,40,88,7,0,21,0,0,0,1,240,224,0,96,39,7,0,21,0,0,0,1,240,16,0,32,202,2,0,21,0,0,0,1,240,48,0,120,113,6,0,21,0,0,0,1,240,32,0,232,228,5,0,21,0,0,0,1,240,240,0,144,251,6,0,21,0,0,0,1,240,64,0,120,211,6,0,21,0,0,0,1,240,144,0,184,164,6,0,21,0,0,0,1,240,128,0,80,74,6,0,21,0,0,0,1,240,112,0,192,32,6,0,21,0,0,0,1,240,96,0,192,234,2,0,21,0,0,0,1,240,80,0,32,242,5,0,21,0,0,0,1,240,0,0,16,227,4,0,101,112,114,45,49,50,48,49,48,46,52,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,162,244,247,125,1,0,16,1,101,112,114,45,49,50,48,48,56,46,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,205,100,174,245,1,0,16,1,101,112,114,45,49,50,48,49,49,46,52,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,7,231,70,157,1,0,16,1,101,112,114,45,49,50,48,48,57,46,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,126,208,97,121,1,0,16,1,101,112,114,45,49,49,50,54,52,46,57,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,125,126,98,70,2,0,32,0,101,112,114,45,49,49,50,54,53,46,57,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,33,243,208,135,2,0,32,0,101,112,114,45,49,49,50,54,54,46,57,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,135,175,180,239,2,0,32,0,101,112,114,45,49,49,50,57,48,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,58,65,31,97,3,0,32,0,101,112,114,45,49,49,50,57,52,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,193,15,176,94,3,0,32,0,101,112,114,45,49,49,50,57,49,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,192,151,7,60,3,0,32,0,101,112,114,45,49,49,50,57,53,46,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,248,126,48,37,3,0,32,0,101,112,114,45,49,49,50,57,50,46,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,78,195,154,194,3,0,32,0,101,112,114,45,49,49,50,57,54,46,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,248,55,164,4,3,0,32,0,101,112,114,45,49,49,50,57,51,46,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,99,16,244,65,3,0,32,0,101,112,114,45,49,49,50,57,55,46,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,114,253,225,182,3,0,32,0,101,112,114,45,49,49,50,54,55,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,69,183,80,221,4,0,16,1,55,55,53,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,252,52,149,106,6,0,16,1,101,112,114,45,49,49,50,54,56,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,218,102,121,109,7,0,64,0,21,0,0,0,255,255,252,0,0,0,0,0,22,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,21,0,0,0,1,1,0,0,120,97,1,0,21,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,2,0,168,234,7,0,21,0,0,0,1,2,2,0,96,135,7,0,21,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,21,0,0,0,1,12,8,0,208,75,4,0,21,0,0,0,1,12,12,0,8,49,4,0,21,0,0,0,1,12,4,0,72,246,3,0,21,0,0,0,1,12,0,0,40,130,6,0,0,0,0,0,254,0,4,0,72,202,5,0,21,0,0,0,1,48,32,0,80,246,3,0,21,0,0,0,1,48,48,0,248,38,7,0,21,0,0,0,1,48,16,0,112,212,3,0,21,0,0,0,1,48,0,0,248,160,5,0,0,0,0,0,254,0,2,0,128,235,3,0,21,0,0,0,1,64,64,0,248,81,6,0,21,0,0,0,1,64,0,0,176,64,8,0,0,0,0,0,254,0,2,0,128,112,3,0,21,0,0,0,1,128,128,0,224,247,3,0,21,0,0,0,1,128,0,0,168,22,4,0,0,0,0,0,254,0,16,0,200,87,7,0,22,0,0,0,1,15,7,0,80,252,6,0,22,0,0,0,1,15,8,0,16,242,7,0,22,0,0,0,1,15,9,0,104,236,7,0,22,0,0,0,1,15,5,0,176,51,4,0,22,0,0,0,1,15,4,0,56,24,4,0,22,0,0,0,1,15,15,0,128,230,7,0,22,0,0,0,1,15,1,0,72,216,3,0,22,0,0,0,1,15,2,0,24,188,3,0,22,0,0,0,1,15,3,0,176,162,3,0,22,0,0,0,1,15,6,0,120,211,6,0,22,0,0,0,1,15,14,0,184,164,6,0,22,0,0,0,1,15,13,0,80,74,6,0,22,0,0,0,1,15,12,0,192,32,6,0,22,0,0,0,1,15,11,0,192,234,2,0,22,0,0,0,1,15,10,0,32,242,5,0,22,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,22,0,0,0,1,240,112,0,80,252,6,0,22,0,0,0,1,240,128,0,16,242,7,0,22,0,0,0,1,240,144,0,104,236,7,0,22,0,0,0,1,240,80,0,176,51,4,0,22,0,0,0,1,240,64,0,56,24,4,0,22,0,0,0,1,240,240,0,128,230,7,0,22,0,0,0,1,240,16,0,72,216,3,0,22,0,0,0,1,240,32,0,24,188,3,0])
.concat([22,0,0,0,1,240,48,0,176,162,3,0,22,0,0,0,1,240,96,0,120,211,6,0,22,0,0,0,1,240,224,0,184,164,6,0,22,0,0,0,1,240,208,0,80,74,6,0,22,0,0,0,1,240,192,0,192,32,6,0,22,0,0,0,1,240,176,0,192,234,2,0,22,0,0,0,1,240,160,0,32,242,5,0,22,0,0,0,1,240,0,0,208,236,2,0,21,0,0,0,255,255,255,0,0,0,0,0,22,0,0,0,255,255,252,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,21,0,0,0,1,15,7,0,80,252,6,0,21,0,0,0,1,15,8,0,16,242,7,0,21,0,0,0,1,15,9,0,104,236,7,0,21,0,0,0,1,15,5,0,176,51,4,0,21,0,0,0,1,15,4,0,56,24,4,0,21,0,0,0,1,15,15,0,128,230,7,0,21,0,0,0,1,15,1,0,72,216,3,0,21,0,0,0,1,15,2,0,24,188,3,0,21,0,0,0,1,15,3,0,176,162,3,0,21,0,0,0,1,15,6,0,120,211,6,0,21,0,0,0,1,15,14,0,184,164,6,0,21,0,0,0,1,15,13,0,80,74,6,0,21,0,0,0,1,15,12,0,192,32,6,0,21,0,0,0,1,15,11,0,192,234,2,0,21,0,0,0,1,15,10,0,32,242,5,0,21,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,21,0,0,0,1,240,112,0,80,252,6,0,21,0,0,0,1,240,128,0,16,242,7,0,21,0,0,0,1,240,144,0,104,236,7,0,21,0,0,0,1,240,80,0,176,51,4,0,21,0,0,0,1,240,64,0,56,24,4,0,21,0,0,0,1,240,240,0,128,230,7,0,21,0,0,0,1,240,16,0,72,216,3,0,21,0,0,0,1,240,32,0,24,188,3,0,21,0,0,0,1,240,48,0,176,162,3,0,21,0,0,0,1,240,96,0,120,211,6,0,21,0,0,0,1,240,224,0,184,164,6,0,21,0,0,0,1,240,208,0,80,74,6,0,21,0,0,0,1,240,192,0,192,32,6,0,21,0,0,0,1,240,176,0,192,234,2,0,21,0,0,0,1,240,160,0,32,242,5,0,21,0,0,0,1,240,0,0,208,236,2,0,0,0,0,0,254,0,2,0,200,30,2,0,22,0,0,0,1,1,0,0,120,97,1,0,22,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,2,0,168,234,7,0,22,0,0,0,1,2,2,0,96,135,7,0,22,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,22,0,0,0,1,12,8,0,208,75,4,0,22,0,0,0,1,12,12,0,8,49,4,0,22,0,0,0,1,12,4,0,72,246,3,0,22,0,0,0,1,12,0,0,40,130,6,0,0,0,0,0,254,0,4,0,72,202,5,0,22,0,0,0,1,48,32,0,80,246,3,0,22,0,0,0,1,48,48,0,248,38,7,0,22,0,0,0,1,48,16,0,112,212,3,0,22,0,0,0,1,48,0,0,248,160,5,0,0,0,0,0,254,0,2,0,128,235,3,0,22,0,0,0,1,64,64,0,248,81,6,0,22,0,0,0,1,64,0,0,176,64,8,0,0,0,0,0,254,0,2,0,128,112,3,0,22,0,0,0,1,128,128,0,224,247,3,0,22,0,0,0,1,128,0,0,168,22,4,0,101,112,114,45,49,48,56,56,54,46,49,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,54,205,227,139,1,0,16,1,101,112,114,45,49,48,56,56,52,46,49,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,13,21,6,203,1,0,16,1,101,112,114,45,49,48,56,56,55,46,49,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,176,139,36,141,1,0,16,1,101,112,114,45,49,48,56,56,53,46,49,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,38,95,121,112,1,0,16,1,101,112,114,45,49,48,55,57,50,46,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,37,157,41,22,9,0,16,1,101,112,114,45,49,48,55,57,48,46,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,193,203,70,34,9,0,16,1,101,112,114,45,49,48,55,57,51,46,55,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,39,84,82,217,9,0,16,1,101,112,114,45,49,48,55,57,49,46,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,190,76,175,95,9,0,16,1,101,112,114,45,49,48,54,53,50,46,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,249,134,2,38,2,0,32,0,101,112,114,45,49,48,54,53,49,46,53,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,123,238,9,198,2,0,32,0,101,112,114,45,49,48,54,53,48,46,53,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,3,164,54,178,2,0,32,0,109,112,114,45,49,48,55,57,52,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,99,142,149,124,3,0,32,0,109,112,114,45,49,48,55,57,56,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,7,248,88,125,3,0,32,0,109,112,114,45,49,48,55,57,53,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,140,31,211,217,3,0,32,0,109,112,114,45,49,48,55,57,57,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,61,13,217,150,3,0,32,0,109,112,114,45,49,48,55,57,54,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,124,149,72,251,3,0,32,0,109,112,114,45,49,48,56,48,48,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,142,249,175,254,3,0,32,0,109,112,114,45,49,48,55,57,55,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,13,135,242,39,3,0,32,0,109,112,114,45,49,48,56,48,49,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,149,23,120,18,3,0,32,0,101,112,114,45,49,48,54,52,50,46,52,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,195,188,54,120,10,0,32,0,101,112,114,45,49,48,54,52,57,99,46,56,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,113,206,193,246,4,0,16,1,101,112,114,45,49,48,54,52,51,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,100,83,245,6,11,0,64,0,101,112,114,45,49,48,54,52,52,46,54,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,29,84,29,180,11,0,64,0,101,112,114,45,49,48,54,52,53,46,54,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,255,171,13,166,11,0,64,0,101,112,114,45,49,48,54,52,54,46,54,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,17,196,60,71,11,0,64,0,10,0,0,0,255,255,255,0,0,0,0,0,11,0,0,0,255,255,30,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,10,0,0,0,1,15,7,0,80,252,6,0,10,0,0,0,1,15,8,0,16,242,7,0,10,0,0,0,1,15,9,0,104,236,7,0,10,0,0,0,1,15,5,0,176,51,4,0,10,0,0,0,1,15,4,0,56,24,4,0,10,0,0,0,1,15,15,0,128,230,7,0,10,0,0,0,1,15,1,0,72,216,3,0,10,0,0,0,1,15,2,0,24,188,3,0,10,0,0,0,1,15,3,0,176,162,3,0,10,0,0,0,1,15,6,0,120,211,6,0,10,0,0,0,1,15,14,0,184,164,6,0,10,0,0,0,1,15,13,0,80,74,6,0,10,0,0,0,1,15,12,0,192,32,6,0,10,0,0,0,1,15,11,0,192,234,2,0,10,0,0,0,1,15,10,0,32,242,5,0,10,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,10,0,0,0,1,240,112,0,80,252,6,0,10,0,0,0,1,240,128,0,16,242,7,0,10,0,0,0,1,240,144,0,104,236,7,0,10,0,0,0,1,240,80,0,176,51,4,0,10,0,0,0,1,240,64,0,56,24,4,0,10,0,0,0,1,240,240,0,128,230,7,0,10,0,0,0,1,240,16,0,72,216,3,0,10,0,0,0,1,240,32,0,24,188,3,0,10,0,0,0,1,240,48,0,176,162,3,0,10,0,0,0,1,240,96,0,120,211,6,0,10,0,0,0,1,240,224,0,184,164,6,0,10,0,0,0,1,240,208,0,80,74,6,0,10,0,0,0,1,240,192,0,192,32,6,0,10,0,0,0,1,240,176,0,192,234,2,0,10,0,0,0,1,240,160,0,32,242,5,0,10,0,0,0,1,240,0,0,208,236,2,0,0,0,0,0,254,0,2,0,168,234,7,0,11,0,0,0,1,1,1,0,96,135,7,0,11,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,11,0,0,0,1,6,4,0,80,246,3,0,11,0,0,0,1,6,6,0,248,38,7,0,11,0,0,0,1,6,2,0,112,212,3,0,11,0,0,0,1,6,0,0,248,160,5,0,0,0,0,0,254,0,4,0,40,252,8,0,11,0,0,0,1,24,16,0,80,246,3,0,11,0,0,0,1,24,24,0,248,38,7,0,11,0,0,0,1,24,8,0,112,212,3,0,11,0,0,0,1,24,0,0,248,160,5,0,0,0,0,0,96,181,1,0,1,0,0,0,234,47,216,0,176,123,145,0,24,38,7,0,1,0,0,0,236,47,216,0,184,160,2,0,56,210,6,0,1,0,0,0,35,48,216,0,192,135,2,0,24,163,6,0,1,0,0,0,34,48,216,0,240,108,2,0,152,122,6,0,1,0,0,0,33,48,216,0,96,82,2,0,192,72,6,0,1,0,0,0,32,48,216,0,32,56,2,0,152,226,4,0,1,0,0,0,36,48,216,0,152,30,2,0,168,190,4,0,1,0,0,0,37,48,216,0,232,10,2,0,240,158,4,0,1,0,0,0,38,48,216,0,152,138,8,0,136,128,4,0,1,0,0,0,39,48,216,0,48,119,7,0,176,101,4,0,1,0,0,0,232,47,216,0,112,109,7,0,136,75,4,0,1,0,0,0,238,47,216,0,24,133,7,0,232,173,1,0,1,0,0,0,235,47,216,0,176,123,145,0,144,236,1,0,1,0,0,0,237,47,216,0,136,224,1,0,176,223,1,0,1,0,0,0,43,48,216,0,72,198,1,0,192,209,1,0,1,0,0,0,42,48,216,0,24,182,1,0,24,198,1,0,1,0,0,0,41,48,216,0,40,167,1,0,120,189,1,0,1,0,0,0,40,48,216,0,200,149,1,0,40,126,1,0,1,0,0,0,44,48,216,0,56,126,1,0,0,112,1,0,1,0,0,0,45,48,216,0,32,101,1,0,0,101,1,0,1,0,0,0,46,48,216,0,96,32,8,0,248,91,1,0,1,0,0,0,47,48,216,0,16,68,7,0,128,85,1,0,1,0,0,0,233,47,216,0,240,58,7,0,248,76,1,0,1,0,0,0,239,47,216,0,200,42,1,0,88,212,3,0,1,0,0,0,144,46,216,0,40,185,3,0,115,122,51,106,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,19,75,203,247,1,0,16,1,115,122,51,106,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,157,194,70,8,1,0,16,1,115,122,51,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,138,81,33,155,1,0,16,1,115,122,51,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,167,195,166,231,1,0,16,1,115,122,51,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,253,12,76,236,1,0,16,1,115,122,51,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,64,114,126,92,1,0,16,1,115,122,51,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,83,149,88,197,1,0,16,1,115,122,51,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,114,113,169,1,0,16,1,115,122,51,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,217,96,122,15,5,0,32,0,115,122,51,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,65,55,147,142,5,0,32,0,115,122,51,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,71,129,233,214,5,0,32,0,115,122,51,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,138,114,26,243,5,0,32,0,115,122,51,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,151,130,249,95,5,0,32,0,115,122,51,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,238,189,181,82,5,0,32,0,115,122,51,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,213,30,99,64,5,0,32,0,115,122,51,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,180,9,52,118,5,0,32,0,115,122,51,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,132,0,129,222,10,0,16,1,115,122,51,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,196,93,68,114,10,0,16,1,115,122,51,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,209,238,137,28,12,0,64,0,115,122,51,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,58,177,146,243,12,0,64,0,115,122,51,106,46,48,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,174,190,224,110,1,0,16,1,115,122,51,106,46,48,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,141,151,226,166,1,0,16,1,115,122,51,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,125,75,150,5,1,0,16,1,115,122,51,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,121,33,206,120,1,0,16,1,115,122,51,46,48,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,47,245,139,57,1,0,16,1,115,122,51,46,48,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,136,5,109,134,1,0,16,1,115,122,51,46,48,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,44,137,128,33,1,0,16,1,115,122,51,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,114,113,169,1,0,16,1,115,122,51,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,217,96,122,15,5,0,32,0,115,122,51,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,65,55,147,142,5,0,32,0,115,122,51,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,71,129,233,214,5,0,32,0,115,122,51,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,138,114,26,243,5,0,32,0,115,122,51,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,151,130,249,95,5,0,32,0,115,122,51,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,238,189,181,82,5,0,32,0,115,122,51,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,213,30,99,64,5,0,32,0,115,122,51,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,180,9,52,118,5,0,32,0,115,122,51,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,132,0,129,222,10,0,16,1,115,122,51,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,196,93,68,114,10,0,16,1,115,122,51,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,209,238,137,28,12,0,64,0,115,122,51,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,58,177,146,243,12,0,64,0,115,122,51,97,46,48,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,253,129,198,41,1,0,16,1,115,122,51,97,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,132,20,221,157,1,0,16,1,115,122,51,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,138,81,33,155,1,0,16,1,115,122,51,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,167,195,166,231,1,0,16,1,115,122,51,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,253,12,76,236,1,0,16,1,115,122,51,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,64,114,126,92,1,0,16,1,115,122,51,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,83,149,88,197,1,0,16,1,115,122,51,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,114,113,169,1,0,16,1,115,122,51,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,217,96,122,15,5,0,32,0,115,122,51,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,65,55,147,142,5,0,32,0,115,122,51,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,71,129,233,214,5,0,32,0,115,122,51,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,138,114,26,243,5,0,32,0,115,122,51,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,151,130,249,95,5,0,32,0,115,122,51,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,238,189,181,82,5,0,32,0,115,122,51,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,213,30,99,64,5,0,32,0,115,122,51,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,180,9,52,118,5,0,32,0,115,122,51,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,132,0,129,222,10,0,16,1,115,122,51,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,196,93,68,114,10,0,16,1,115,122,51,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,209,238,137,28,12,0,64,0,115,122,51,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,58,177,146,243,12,0,64,0,115,122,50,106,46,48,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,40,30,70,151,1,0,16,1,115,122,50,106,46,48,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,169,81,72,174,1,0,16,1,115,122,50,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,146,233,232,152,1,0,16,1,115,122,50,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,192,73,29,91,1,0,16,1,115,122,50,106,46,48,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,162,178,16,217,1,0,16,1,115,122,50,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,93,88,232,15,1,0,16,1,115,122,50,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,34,31,31,77,5,0,32,0,115,122,50,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,128,166,206,25,5,0,32,0,115,122,50,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,136,69,27,224,5,0,32,0,115,122,50,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,100,218,238,15,5,0,32,0,115,122,50,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,170,198,96,5,5,0,32,0,115,122,50,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,135,15,148,174,5,0,32,0,115,122,50,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,188,200,195,75,5,0,32,0,115,122,50,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,192,116,230,57,5,0,32,0,115,122,50,46,48,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,207,35,195,27,10,0,16,1,115,122,50,46,48,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,19,80,106,186,10,0,16,1,115,122,50,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,1,166,71,170,12,0,64,0,115,122,50,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,83,188,55,34,12,0,64,0,115,122,50,98,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,11,83,206,230,1,0,16,1,115,122,50,98,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,203,160,5,22,1,0,16,1,115,122,50,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,124,42,68,75,1,0,16,1,115,122,50,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,192,73,29,91,1,0,16,1,115,122,50,98,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,198,138,126,148,1,0,16,1,115,122,50,98,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,110,182,146,1,0,16,1,115,122,50,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,34,31,31,77,5,0,32,0,115,122,50,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,128,166,206,25,5,0,32,0,115,122,50,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,136,69,27,224,5,0,32,0,115,122,50,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,100,218,238,15,5,0,32,0,115,122,50,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,170,198,96,5,5,0,32,0,115,122,50,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,135,15,148,174,5,0,32,0,115,122,50,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,188,200,195,75,5,0,32,0,115,122,50,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,192,116,230,57,5,0,32,0,115,122,50,46,48,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,207,35,195,27,10,0,16,1,115,122,50,46,48,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,19,80,106,186,10,0,16,1,115,122,50,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,1,166,71,170,12,0,64,0,115,122,50,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,83,188,55,34,12,0,64,0,115,122,97,106,46,48,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,227,47,128,163,1,0,16,1,115,122,97,106,46,48,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,199,135,202,231,1,0,16,1,115,122,97,106,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,136,191,142,200,1,0,16,1,115,122,97,106,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,122,91,237,53,1,0,16,1,115,122,97,106,46,48,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,62,203,93,151,1,0,16,1,115,122,97,106,46,48,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,215,242,115,220,1,0,16,1,115,122,97,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,34,31,31,77,5,0,32,0,115,122,97,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,128,166,206,25,5,0,32,0,115,122,97,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,136,69,27,224,5,0,32,0,115,122,97,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,100,218,238,15,5,0,32,0,115,122,97,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,170,198,96,5,5,0,32,0,115,122,97,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,135,15,148,174,5,0,32,0,115,122,97,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,188,200,195,75,5,0,32,0,115,122,97,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,192,116,230,57,5,0,32,0,115,122,97,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,207,35,195,27,10,0,16,1,115,122,97,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,19,80,106,186,10,0,16,1,115,122,97,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,1,166,71,170,12,0,64,0,115,122,97,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,83,188,55,34,12,0,64,0,115,122,97,104,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,29,61,249,6,1,0,16,1,115,122,97,104,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,20,233,46,230,1,0,16,1,115,122,97,104,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,32,75,127,43,1,0,16,1,115,122,97,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,252,162,189,10,1,0,16,1,115,122,97,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,98,7,67,233,1,0,16,1,115,122,97,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,169,17,87,182,1,0,16,1,115,122,97,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,34,31,31,77,5,0,32,0,115,122,97,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,128,166,206,25,5,0,32,0,115,122,97,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,136,69,27,224,5,0,32,0,115,122,97,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,100,218,238,15,5,0,32,0,115,122,97,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,170,198,96,5,5,0,32,0,115,122,97,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,135,15,148,174,5,0,32,0,115,122,97,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,188,200,195,75,5,0,32,0,115,122,97,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,192,116,230,57,5,0,32,0,115,122,97,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,207,35,195,27,10,0,16,1,115,122,97,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,19,80,106,186,10,0,16,1,115,122,97,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,1,166,71,170,12,0,64,0,115,122,97,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,83,188,55,34,12,0,64,0,115,122,97,97,100,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,59,72,249,137,1,0,16,1,115,122,97,97,100,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,229,122,242,174,1,0,16,1,115,122,97,97,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,94,165,83,240,1,0,16,1,115,122,97,97,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,231,192,207,1,0,16,1,115,122,97,97,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,32,139,235,95,1,0,16,1,115,122,97,97,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,18,212,182,110,1,0,16,1,115,122,50,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,34,31,31,77,5,0,32,0,115,122,50,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,128,166,206,25,5,0,32,0,115,122,50,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,136,69,27,224,5,0,32,0,115,122,50,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0])
.concat([100,218,238,15,5,0,32,0,115,122,50,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,170,198,96,5,5,0,32,0,115,122,50,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,135,15,148,174,5,0,32,0,115,122,50,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,188,200,195,75,5,0,32,0,115,122,50,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,192,116,230,57,5,0,32,0,115,122,50,46,48,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,207,35,195,27,10,0,16,1,115,122,50,46,48,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,19,80,106,186,10,0,16,1,115,122,50,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,1,166,71,170,12,0,64,0,115,122,50,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,83,188,55,34,12,0,64,0,115,122,97,98,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,202,110,67,203,1,0,16,1,115,122,97,98,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,234,75,83,20,1,0,16,1,115,122,97,98,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,88,6,177,127,1,0,16,1,115,122,97,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,252,162,189,10,1,0,16,1,115,122,97,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,98,7,67,233,1,0,16,1,115,122,97,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,169,17,87,182,1,0,16,1,115,122,97,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,34,31,31,77,5,0,32,0,115,122,97,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,128,166,206,25,5,0,32,0,115,122,97,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,136,69,27,224,5,0,32,0,115,122,97,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,100,218,238,15,5,0,32,0,115,122,97,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,170,198,96,5,5,0,32,0,115,122,97,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,135,15,148,174,5,0,32,0,115,122,97,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,188,200,195,75,5,0,32,0,115,122,97,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,192,116,230,57,5,0,32,0,115,122,97,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,207,35,195,27,10,0,16,1,115,122,97,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,19,80,106,186,10,0,16,1,115,122,97,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,1,166,71,170,12,0,64,0,115,122,97,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,83,188,55,34,12,0,64,0,115,122,51,117,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,25,74,152,181,1,0,16,1,115,122,51,117,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,186,88,129,126,1,0,16,1,115,122,51,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,138,81,33,155,1,0,16,1,115,122,51,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,167,195,166,231,1,0,16,1,115,122,51,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,253,12,76,236,1,0,16,1,115,122,51,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,64,114,126,92,1,0,16,1,115,122,51,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,83,149,88,197,1,0,16,1,115,122,51,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,114,113,169,1,0,16,1,115,122,51,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,217,96,122,15,5,0,32,0,115,122,51,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,65,55,147,142,5,0,32,0,115,122,51,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,71,129,233,214,5,0,32,0,115,122,51,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,138,114,26,243,5,0,32,0,115,122,51,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,151,130,249,95,5,0,32,0,115,122,51,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,238,189,181,82,5,0,32,0,115,122,51,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,213,30,99,64,5,0,32,0,115,122,51,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,180,9,52,118,5,0,32,0,115,122,51,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,132,0,129,222,10,0,16,1,115,122,51,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,196,93,68,114,10,0,16,1,115,122,51,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,209,238,137,28,12,0,64,0,115,122,51,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,58,177,146,243,12,0,64,0,115,122,51,104,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,62,203,22,75,1,0,16,1,115,122,51,104,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,106,46,173,136,1,0,16,1,115,122,51,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,138,81,33,155,1,0,16,1,115,122,51,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,167,195,166,231,1,0,16,1,115,122,51,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,253,12,76,236,1,0,16,1,115,122,51,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,64,114,126,92,1,0,16,1,115,122,51,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,83,149,88,197,1,0,16,1,115,122,51,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,114,113,169,1,0,16,1,115,122,51,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,217,96,122,15,5,0,32,0,115,122,51,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,65,55,147,142,5,0,32,0,115,122,51,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,71,129,233,214,5,0,32,0,115,122,51,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,138,114,26,243,5,0,32,0,115,122,51,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,151,130,249,95,5,0,32,0,115,122,51,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,238,189,181,82,5,0,32,0,115,122,51,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,213,30,99,64,5,0,32,0,115,122,51,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,180,9,52,118,5,0,32,0,115,122,51,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,132,0,129,222,10,0,16,1,115,122,51,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,196,93,68,114,10,0,16,1,115,122,51,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,209,238,137,28,12,0,64,0,115,122,51,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,58,177,146,243,12,0,64,0,115,122,50,117,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,6,144,160,132,1,0,16,1,115,122,50,117,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,237,229,70,172,1,0,16,1,115,122,50,117,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,211,121,12,108,1,0,16,1,115,122,50,117,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,99,235,200,197,1,0,16,1,115,122,50,117,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,197,28,224,93,1,0,16,1,115,122,50,117,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,86,29,161,190,1,0,16,1,115,122,50,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,34,31,31,77,5,0,32,0,115,122,50,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,128,166,206,25,5,0,32,0,115,122,50,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,136,69,27,224,5,0,32,0,115,122,50,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,100,218,238,15,5,0,32,0,115,122,50,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,170,198,96,5,5,0,32,0,115,122,50,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,135,15,148,174,5,0,32,0,115,122,50,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,188,200,195,75,5,0,32,0,115,122,50,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,192,116,230,57,5,0,32,0,115,122,50,46,48,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,207,35,195,27,10,0,16,1,115,122,50,46,48,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,19,80,106,186,10,0,16,1,115,122,50,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,1,166,71,170,12,0,64,0,115,122,50,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,83,188,55,34,12,0,64,0,115,102,54,45,49,46,48,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,34,72,215,204,1,0,16,1,115,102,54,45,51,46,48,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,87,181,72,42,1,0,16,1,115,102,54,45,50,46,48,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,145,224,230,100,1,0,16,1,115,102,54,45,52,46,48,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,67,68,94,201,1,0,16,1,115,57,50,95,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,216,176,3,4,0,32,0,115,57,50,95,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,137,2,132,4,0,32,0,115,57,50,95,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,240,181,205,4,0,32,0,115,57,50,95,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,114,148,121,226,4,0,32,0,115,57,50,95,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,39,138,186,4,0,32,0,115,57,50,95,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,191,132,229,4,0,32,0,115,57,50,95,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,125,248,227,33,4,0,32,0,115,57,50,95,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,71,252,190,4,0,32,0,115,57,50,95,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,213,135,6,150,4,0,32,0,115,57,50,95,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,205,142,151,4,0,32,0,115,57,50,95,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,10,154,236,214,4,0,32,0,115,57,50,95,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,103,44,237,4,0,32,0,115,57,50,95,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,14,182,246,8,3,0,16,0,115,57,50,95,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,32,22,127,5,0,64,0,115,57,50,95,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,229,173,190,5,0,64,0,54,46,97,109,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,117,162,133,58,8,0,32,0,57,46,97,109,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,47,71,86,145,8,0,32,0,56,46,97,109,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,59,8,219,236,8,0,32,0,49,48,46,97,109,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,132,131,234,143,8,0,32,0,115,102,50,118,48,48,52,46,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,44,159,209,82,2,0,16,1,115,102,50,118,48,48,52,46,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,231,253,38,75,2,0,16,1,115,102,50,114,101,100,46,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,187,134,196,82,2,0,16,1,115,57,50,95,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,216,176,3,4,0,32,0,115,57,50,95,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,137,2,132,4,0,32,0,115,57,50,95,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,240,181,205,4,0,32,0,115,57,50,95,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,114,148,121,226,4,0,32,0,115,57,50,95,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,39,138,186,4,0,32,0,115,57,50,95,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,191,132,229,4,0,32,0,115,57,50,95,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,125,248,227,33,4,0,32,0,115,57,50,95,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,71,252,190,4,0,32,0,115,57,50,95,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,213,135,6,150,4,0,32,0,115,57,50,95,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,205,142,151,4,0,32,0,115,57,50,95,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,10,154,236,214,4,0,32,0,115,57,50,95,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,103,44,237,4,0,32,0,115,57,50,95,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,14,182,246,8,3,0,16,0,115,57,50,95,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,32,22,127,5,0,64,0,115,57,50,95,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,229,173,190,5,0,64,0,168,86,7,0,1,0,0,0,232,47,216,0,248,191,2,0,24,38,7,0,1,0,0,0,236,47,216,0,184,160,2,0,56,210,6,0,1,0,0,0,35,48,216,0,192,135,2,0,24,163,6,0,1,0,0,0,34,48,216,0,240,108,2,0,152,122,6,0,1,0,0,0,33,48,216,0,96,82,2,0,192,72,6,0,1,0,0,0,32,48,216,0,32,56,2,0,152,226,4,0,1,0,0,0,36,48,216,0,152,30,2,0,168,190,4,0,1,0,0,0,37,48,216,0,232,10,2,0,240,158,4,0,1,0,0,0,38,48,216,0,152,138,8,0,136,128,4,0,1,0,0,0,136,47,216,0,48,119,7,0,176,101,4,0,1,0,0,0,137,47,216,0,112,109,7,0,136,75,4,0,1,0,0,0,138,47,216,0,24,133,7,0,40,246,1,0,1,0,0,0,233,47,216,0,64,246,1,0,144,236,1,0,1,0,0,0,237,47,216,0,136,224,1,0,176,223,1,0,1,0,0,0,43,48,216,0,72,198,1,0,192,209,1,0,1,0,0,0,42,48,216,0,24,182,1,0,24,198,1,0,1,0,0,0,41,48,216,0,40,167,1,0,120,189,1,0,1,0,0,0,40,48,216,0,200,149,1,0,40,126,1,0,1,0,0,0,44,48,216,0,56,126,1,0,0,112,1,0,1,0,0,0,45,48,216,0,32,101,1,0,0,101,1,0,1,0,0,0,46,48,216,0,96,32,8,0,248,91,1,0,1,0,0,0,140,47,216,0,16,68,7,0,128,85,1,0,1,0,0,0,141,47,216,0,240,58,7,0,248,76,1,0,1,0,0,0,142,47,216,0,200,42,1,0,88,212,3,0,1,0,0,0,144,46,216,0,40,185,3,0,240,152,1,0,1,0,0,0,238,47,216,0,216,70,1,0,16,17,8,0,1,0,0,0,234,47,216,0,224,12,8,0,72,65,1,0,9,0,0,0,232,48,216,0,32,58,1,0,48,50,1,0,9,0,0,0,224,48,216,0,32,58,1,0,224,41,1,0,9,0,0,0,216,48,216,0,32,58,1,0,115,102,51,100,53,45,49,48,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,58,44,221,188,1,0,16,1,115,102,51,100,53,45,51,48,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,135,89,150,1,1,0,16,1,115,102,51,100,53,45,50,48,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,49,29,46,221,1,0,16,1,115,102,51,100,53,45,52,48,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,67,68,94,201,1,0,16,1,115,57,50,95,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,216,176,3,4,0,32,0,115,57,50,95,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,137,2,132,4,0,32,0,115,57,50,95,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,240,181,205,4,0,32,0,115,57,50,95,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,114,148,121,226,4,0,32,0,115,57,50,95,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,39,138,186,4,0,32,0,115,57,50,95,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,191,132,229,4,0,32,0,115,57,50,95,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,125,248,227,33,4,0,32,0,115,57,50,95,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,71,252,190,4,0,32,0,115,57,50,95,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,213,135,6,150,4,0,32,0,115,57,50,95,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,205,142,151,4,0,32,0,115,57,50,95,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,10,154,236,214,4,0,32,0,115,57,50,95,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,103,44,237,4,0,32,0,115,57,50,95,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,14,182,246,8,3,0,16,0,115,57,50,95,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,32,22,127,5,0,64,0,115,57,50,95,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,229,173,190,5,0,64,0,54,46,97,109,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,117,162,133,58,8,0,32,0,57,46,97,109,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,47,71,86,145,8,0,32,0,56,46,97,109,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,59,8,219,236,8,0,32,0,49,48,46,97,109,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,132,131,234,143,8,0,32,0,99,104,50,50,50,101,115,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,138,5,109,158,1,0,16,1,99,104,49,57,54,101,115,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,55,244,47,237,1,0,16,1,115,57,50,95,50,49,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,119,120,90,146,2,0,16,1,115,57,50,95,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,216,176,3,4,0,32,0,115,57,50,95,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,137,2,132,4,0,32,0,115,57,50,95,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,240,181,205,4,0,32,0,115,57,50,95,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,114,148,121,226,4,0,32,0,115,57,50,95,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,39,138,186,4,0,32,0,115,57,50,95,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,191,132,229,4,0,32,0,115,57,50,95,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,125,248,227,33,4,0,32,0,115,57,50,95,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,71,252,190,4,0,32,0,115,57,50,95,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,213,135,6,150,4,0,32,0,115,57,50,95,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,205,142,151,4,0,32,0,115,57,50,95,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,10,154,236,214,4,0,32,0,115,57,50,95,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,103,44,237,4,0,32,0,115,57,50,95,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,14,182,246,8,3,0,16,0,115,57,50,95,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,32,22,127,5,0,64,0,115,57,50,95,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,229,173,190,5,0,64,0,54,46,97,109,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,117,162,133,58,8,0,32,0,57,46,97,109,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,47,71,86,145,8,0,32,0,56,46,97,109,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,59,8,219,236,8,0,32,0,49,48,46,97,109,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,132,131,234,143,8,0,32,0,27,0,0,0,255,255,0,0,0,0,0,0,28,0,0,0,255,255,19,0,0,0,0,0,29,0,0,0,255,255,96,0,0,0,0,0,0,0,0,0,254,0,8,0,200,87,7,0,27,0,0,0,1,7,7,0,80,252,6,0,27,0,0,0,1,7,6,0,16,242,7,0,27,0,0,0,1,7,5,0,104,236,7,0,27,0,0,0,1,7,0,0,128,230,7,0,27,0,0,0,1,7,1,0,184,164,6,0,27,0,0,0,1,7,2,0,80,74,6,0,27,0,0,0,1,7,3,0,192,32,6,0,27,0,0,0,1,7,4,0,32,242,5,0,0,0,0,0,254,0,8,0,160,123,6,0,27,0,0,0,1,56,56,0,80,252,6,0,27,0,0,0,1,56,48,0,16,242,7,0,27,0,0,0,1,56,40,0,104,236,7,0,27,0,0,0,1,56,0,0,128,230,7,0,27,0,0,0,1,56,8,0,184,164,6,0,27,0,0,0,1,56,16,0,80,74,6,0,27,0,0,0,1,56,24,0,192,32,6,0,27,0,0,0,1,56,32,0,32,242,5,0,0,0,0,0,254,0,2,0,64,232,1,0,27,0,0,0,1,64,0,0,96,135,7,0,27,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,8,0,72,202,5,0,28,0,0,0,1,7,0,0,72,198,6,0,28,0,0,0,1,7,1,0,208,75,4,0,28,0,0,0,1,7,2,0,8,49,4,0,28,0,0,0,1,7,3,0,72,195,6,0,28,0,0,0,1,7,4,0,72,246,3,0,28,0,0,0,1,7,5,0,72,0,3,0,28,0,0,0,1,7,6,0,64,47,7,0,28,0,0,0,1,7,7,0,48,173,6,0,0,0,0,0,254,0,2,0,16,227,4,0,29,0,0,0,1,4,0,0,96,135,7,0,29,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,254,0,2,0,72,4,1,0,29,0,0,0,1,8,0,0,96,135,7,0,29,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,29,0,0,0,1,16,0,0,96,135,7,0,29,0,0,0,1,16,16,0,152,182,7,0,0,0,0,0,254,0,2,0,40,111,8,0,29,0,0,0,1,32,0,0,96,135,7,0,29,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,29,0,0,0,1,64,0,0,96,135,7,0,29,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,168,79,2,0,29,0,0,0,1,128,0,0,32,182,8,0,29,0,0,0,1,128,128,0,80,251,6,0,0,0,0,0,51,46,109,100,116,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,244,78,84,159,1,0,16,1,53,46,109,100,116,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,33,102,109,215,1,0,16,1,50,46,109,100,116,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,146,65,132,116,1,0,16,1])
.concat([52,46,109,100,116,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,21,255,152,189,1,0,16,1,112,102,52,32,115,104,48,53,56,46,105,99,56,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,36,246,253,64,4,0,32,0,112,102,55,32,115,104,48,55,50,46,105,99,57,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,46,2,120,251,4,0,32,0,112,102,53,32,115,104,48,51,54,46,105,99,57,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,139,228,107,10,4,0,32,0,112,102,56,32,115,104,48,55,52,46,105,99,57,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,207,199,88,98,4,0,32,0,112,102,54,32,115,104,48,55,48,46,105,99,56,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,215,9,91,155,4,0,32,0,112,102,57,32,115,104,48,48,49,46,105,99,57,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,14,9,37,159,4,0,32,0,49,46,105,99,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,204,233,190,213,3,0,16,0,50,50,50,45,48,52,48,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,179,92,111,236,1,0,16,1,49,57,54,45,48,52,48,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,43,197,154,14,1,0,16,1,50,50,49,45,48,49,48,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,28,193,38,130,1,0,16,1,49,57,53,45,48,49,48,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,226,108,76,146,1,0,16,1,115,57,50,95,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,216,176,3,4,0,32,0,115,57,50,95,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,137,2,132,4,0,32,0,115,57,50,95,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,240,181,205,4,0,32,0,115,57,50,95,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,114,148,121,226,4,0,32,0,115,57,50,95,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,39,138,186,4,0,32,0,115,57,50,95,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,191,132,229,4,0,32,0,115,57,50,95,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,125,248,227,33,4,0,32,0,115,57,50,95,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,71,252,190,4,0,32,0,115,50,116,95,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,134,38,4,60,4,0,32,0,115,50,116,95,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,131,113,126,139,4,0,32,0,115,50,116,95,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,140,136,60,41,4,0,32,0,115,50,116,95,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,164,53,43,132,4,0,32,0,115,57,50,95,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,14,182,246,8,3,0,16,0,115,57,50,95,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,32,22,127,5,0,64,0,115,57,50,95,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,229,173,190,5,0,64,0,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,213,180,88,162,1,0,16,1,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,116,212,204,89,1,0,16,1,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,99,125,9,130,1,0,16,1,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,77,132,131,12,1,0,16,1,49,98,95,121,102,48,56,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,142,204,201,34,4,0,32,0,49,100,95,121,102,48,50,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,232,59,33,87,4,0,32,0,49,97,95,121,102,48,56,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,79,155,82,186,4,0,32,0,49,99,95,121,102,48,56,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,51,27,75,4,0,32,0,49,102,95,121,102,48,56,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,41,34,126,44,4,0,32,0,49,104,95,121,102,49,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,23,143,84,181,4,0,32,0,49,101,95,121,102,49,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,18,67,184,20,4,0,32,0,49,103,95,121,102,48,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,154,216,156,94,4,0,32,0,49,106,95,121,102,49,49,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,88,250,75,153,4,0,32,0,49,108,95,121,101,48,52,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,157,173,102,62,4,0,32,0,49,105,95,121,102,48,51,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,250,190,193,4,0,32,0,49,107,95,121,101,48,51,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,49,200,39,6,4,0,32,0,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,27,58,130,164,3,0,16,0,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,32,22,127,5,0,64,0,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,229,173,190,5,0,64,0,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,30,98,5,165,8,0,32,0,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,251,113,98,222,8,0,32,0,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,68,83,119,35,8,0,32,0,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,15,85,201,129,8,0,32,0,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,68,28,234,19,0,0,0,8,115,57,50,117,95,50,51,99,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,162,106,139,10,2,0,16,1,115,57,50,95,50,50,99,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,11,99,216,95,2,0,16,1,115,57,50,95,50,49,97,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,119,120,90,146,2,0,16,1,115,57,50,45,49,109,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,216,176,3,4,0,32,0,115,57,50,45,51,109,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,137,2,132,4,0,32,0,115,57,50,45,50,109,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,240,181,205,4,0,32,0,115,57,50,45,52,109,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,114,148,121,226,4,0,32,0,115,57,50,45,53,109,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,39,138,186,4,0,32,0,115,57,50,45,55,109,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,191,132,229,4,0,32,0,115,57,50,45,54,109,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,125,248,227,33,4,0,32,0,115,57,50,45,56,109,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,71,252,190,4,0,32,0,115,57,50,45,49,48,109,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,213,135,6,150,4,0,32,0,115,57,50,45,49,50,109,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,205,142,151,4,0,32,0,115,57,50,45,49,49,109,46,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,10,154,236,214,4,0,32,0,115,57,50,45,49,51,109,46,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,103,44,237,4,0,32,0,115,57,50,95,48,57,46,49,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,14,182,246,8,3,0,16,0,115,57,50,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,32,22,127,5,0,64,0,115,57,50,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,229,173,190,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,115,57,50,54,51,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,224,207,126,10,0,0,0,8,105,111,98,49,46,49,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,98,112,114,103,49,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,167,61,121,49,0,0,0,8,105,111,99,49,46,105,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,129,32,24,13,0,0,0,8,99,54,51,50,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,112,146,189,15,0,0,0,8,115,57,50,117,95,50,51,98,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,21,48,106,153,2,0,16,1,115,57,50,95,50,50,98,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,237,21,190,43,2,0,16,1,115,57,50,95,50,49,97,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,119,120,90,146,2,0,16,1,115,57,50,45,49,109,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,216,176,3,4,0,32,0,115,57,50,45,51,109,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,137,2,132,4,0,32,0,115,57,50,45,50,109,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,240,181,205,4,0,32,0,115,57,50,45,52,109,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,114,148,121,226,4,0,32,0,115,57,50,45,53,109,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,39,138,186,4,0,32,0,115,57,50,45,55,109,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,191,132,229,4,0,32,0,115,57,50,45,54,109,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,125,248,227,33,4,0,32,0,115,57,50,45,56,109,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,71,252,190,4,0,32,0,115,57,50,45,49,48,109,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,213,135,6,150,4,0,32,0,115,57,50,45,49,50,109,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,205,142,151,4,0,32,0,115,57,50,45,49,49,109,46,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,10,154,236,214,4,0,32,0,115,57,50,45,49,51,109,46,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,103,44,237,4,0,32,0,115,57,50,95,48,57,46,49,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,14,182,246,8,3,0,16,0,115,57,50,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,32,22,127,5,0,64,0,115,57,50,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,229,173,190,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,115,57,50,54,51,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,224,207,126,10,0,0,0,8,105,111,98,49,46,49,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,98,112,114,103,49,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,167,61,121,49,0,0,0,8,105,111,99,49,46,105,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,129,32,24,13,0,0,0,8,99,54,51,50,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,112,146,189,15,0,0,0,8,115,57,50,117,95,50,51,97,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,91,65,68,172,2,0,16,1,115,57,50,95,50,50,97,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,164,204,241,153,2,0,16,1,115,57,50,95,50,49,97,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,119,120,90,146,2,0,16,1,115,57,50,45,49,109,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,216,176,3,4,0,32,0,115,57,50,45,51,109,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,137,2,132,4,0,32,0,115,57,50,45,50,109,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,240,181,205,4,0,32,0,115,57,50,45,52,109,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,114,148,121,226,4,0,32,0,115,57,50,45,53,109,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,39,138,186,4,0,32,0,115,57,50,45,55,109,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,191,132,229,4,0,32,0,115,57,50,45,54,109,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,125,248,227,33,4,0,32,0,115,57,50,45,56,109,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,71,252,190,4,0,32,0,115,57,50,45,49,48,109,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,213,135,6,150,4,0,32,0,115,57,50,45,49,50,109,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,205,142,151,4,0,32,0,115,57,50,45,49,49,109,46,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,10,154,236,214,4,0,32,0,115,57,50,45,49,51,109,46,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,103,44,237,4,0,32,0,115,57,50,95,48,57,46,49,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,14,182,246,8,3,0,16,0,115,57,50,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,32,22,127,5,0,64,0,115,57,50,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,229,173,190,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,115,57,50,54,51,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,224,207,126,10,0,0,0,8,105,111,98,49,46,49,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,98,112,114,103,49,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,167,61,121,49,0,0,0,8,105,111,99,49,46,105,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,129,32,24,13,0,0,0,8,99,54,51,50,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,112,146,189,15,0,0,0,8,115,57,50,106,95,50,51,99,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,53,6,18,240,2,0,16,1,115,57,50,106,95,50,50,99,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,214,46,11,140,2,0,16,1,115,57,50,106,95,50,49,97,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,119,120,90,146,2,0,16,1,115,57,50,95,48,49,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,216,176,3,4,0,32,0,115,57,50,95,48,50,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,137,2,132,4,0,32,0,115,57,50,95,48,51,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,240,181,205,4,0,32,0,115,57,50,95,48,52,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,114,148,121,226,4,0,32,0,115,57,50,95,48,53,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,39,138,186,4,0,32,0,115,57,50,95,48,54,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,191,132,229,4,0,32,0,115,57,50,95,48,55,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,125,248,227,33,4,0,32,0,115,57,50,95,48,56,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,71,252,190,4,0,32,0,115,57,50,95,49,48,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,213,135,6,150,4,0,32,0,115,57,50,95,49,49,46,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,205,142,151,4,0,32,0,115,57,50,95,49,50,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,10,154,236,214,4,0,32,0,115,57,50,95,49,51,46,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,103,44,237,4,0,32,0,115,57,50,95,48,57,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,14,182,246,8,3,0,16,0,115,57,50,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,32,22,127,5,0,64,0,115,57,50,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,229,173,190,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,115,57,50,54,51,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,224,207,126,10,0,0,0,8,105,111,98,49,46,49,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,98,112,114,103,49,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,167,61,121,49,0,0,0,8,105,111,99,49,46,105,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,129,32,24,13,0,0,0,8,99,54,51,50,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,112,146,189,15,0,0,0,8,115,57,50,106,95,50,51,98,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,197,118,8,20,2,0,16,1,115,57,50,106,95,50,50,98,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,254,59,187,47,2,0,16,1,115,57,50,95,50,49,97,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,119,120,90,146,2,0,16,1,115,57,50,95,48,49,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,216,176,3,4,0,32,0,115,57,50,95,48,50,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,137,2,132,4,0,32,0,115,57,50,95,48,51,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,240,181,205,4,0,32,0,115,57,50,95,48,52,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,114,148,121,226,4,0,32,0,115,57,50,95,48,53,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,39,138,186,4,0,32,0,115,57,50,95,48,54,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,191,132,229,4,0,32,0,115,57,50,95,48,55,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,125,248,227,33,4,0,32,0,115,57,50,95,48,56,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,71,252,190,4,0,32,0,115,57,50,95,49,48,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,213,135,6,150,4,0,32,0,115,57,50,95,49,49,46,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,205,142,151,4,0,32,0,115,57,50,95,49,50,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,10,154,236,214,4,0,32,0,115,57,50,95,49,51,46,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,103,44,237,4,0,32,0,115,57,50,95,48,57,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,14,182,246,8,3,0,16,0,115,57,50,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,32,22,127,5,0,64,0,115,57,50,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,229,173,190,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,115,57,50,54,51,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,224,207,126,10,0,0,0,8,105,111,98,49,46,49,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,98,112,114,103,49,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,167,61,121,49,0,0,0,8,105,111,99,49,46,105,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,129,32,24,13,0,0,0,8,99,54,51,50,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,112,146,189,15,0,0,0,8,115,57,50,106,95,50,51,97,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,90,187,66,79,2,0,16,1,115,57,50,106,95,50,50,97,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,205,75,246,196,2,0,16,1,115,57,50,95,50,49,97,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,119,120,90,146,2,0,16,1,115,57,50,95,48,49,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,216,176,3,4,0,32,0,115,57,50,95,48,50,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,137,2,132,4,0,32,0,115,57,50,95,48,51,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,240,181,205,4,0,32,0,115,57,50,95,48,52,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,114,148,121,226,4,0,32,0,115,57,50,95,48,53,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,39,138,186,4,0,32,0,115,57,50,95,48,54,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,191,132,229,4,0,32,0,115,57,50,95,48,55,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,125,248,227,33,4,0,32,0,115,57,50,95,48,56,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,71,252,190,4,0,32,0,115,57,50,95,49,48,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,213,135,6,150,4,0,32,0,115,57,50,95,49,49,46,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,205,142,151,4,0,32,0,115,57,50,95,49,50,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,10,154,236,214,4,0,32,0,115,57,50,95,49,51,46,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,103,44,237,4,0,32,0,115,57,50,95,48,57,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,14,182,246,8,3,0,16,0,115,57,50,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,32,22,127,5,0,64,0,115,57,50,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,229,173,190,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,115,57,50,54,51,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,224,207,126,10,0,0,0,8,105,111,98,49,46,49,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,98,112,114,103,49,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,167,61,121,49,0,0,0,8,105,111,99,49,46,105,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,129,32,24,13,0,0,0,8,99,54,51,50,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,112,146,189,15,0,0,0,8,115,57,50,101,95,50,51,97,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,116,107,132,63,2,0,16,1,115,57,50,95,50,50,97,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,164,204,241,153,2,0,16,1,115,57,50,95,50,49,97,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,119,120,90,146,2,0,16,1,115,57,50,45,49,109,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,216,176,3,4,0,32,0,115,57,50,45,51,109,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,137,2,132,4,0,32,0,115,57,50,45,50,109,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,240,181,205,4,0,32,0,115,57,50,45,52,109,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,114,148,121,226,4,0,32,0,115,57,50,45,53,109,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,39,138,186,4,0,32,0,115,57,50,45,55,109,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,191,132,229,4,0,32,0,115,57,50,45,54,109,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,125,248,227,33,4,0,32,0,115,57,50,45,56,109,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,71,252,190,4,0,32,0,115,57,50,45,49,48,109,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,213,135,6,150,4,0,32,0,115,57,50,45,49,50,109,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,205,142,151,4,0,32,0,115,57,50,45,49,49,109,46,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,10,154,236,214,4,0,32,0,115,57,50,45,49,51,109,46,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,103,44,237,4,0,32,0,115,57,50,95,48,57,46,49,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,14,182,246,8,3,0,16,0,115,57,50,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,32,22,127,5,0,64,0,115,57,50,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,229,173,190,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,115,57,50,54,51,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,224,207,126,10,0,0,0,8,105,111,98,49,46,49,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,98,112,114,103,49,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,167,61,121,49,0,0,0,8,105,111,99,49,46,105,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,129,32,24,13,0,0,0,8,99,54,51,50,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,112,146,189,15,0,0,0,8,50,46,117,50,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,248,120,122,58,1,0,16,1,49,46,117,49,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,172,183,60,106,1,0,16,1,52,46,117,50,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,66,98,187,176,1,0,16,1,51,46,117,49,57,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,120,229,22,245,1,0,16,1,121,46,99,46,101,46,99,32,109,46,107,46,114,45,48,48,49,46,117,55,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,19,222,88,162,4,0,32,0,121,46,99,46,101,46,99,46,109,46,107,46,114,45,48,48,51,46,117,54,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,135,191,129,199,4,0,32,0,121,46,99,46,101,46,99,46,109,46,107,46,114,45,48,48,50,46,117,54,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,184,202,38,87,4,0,32,0,121,46,99,46,101,46,99,46,100,46,119,46,99,45,48,49,49,46,117,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,47,193,144,188,4,0,32,0,121,46,99,46,101,46,99,46,100,46,119,46,99,45,48,49,50,46,117,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,204,103,118,24,4,0,32,0,121,46,99,46,101,46,99,46,100,46,119,46,99,45,48,49,51,46,117,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,113,80,88,91,4,0,32,0,115,111,117,110,100,46,117,49,57,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,27,58,130,164,3,0,16,0,118,111,105,99,101,46,117,50,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,17,251,255,108,5,0,64,0,103,114,112,49,46,117,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,113,70,228,109,11,0,32,0,103,114,112,51,46,117,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,98,67,241,232,11,0,32,0,103,114,112,50,46,117,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,25,216,12,191,11,0,32,0,103,114,112,52,46,117,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,31,249,249,118,11,0,32,0,99,111,110,118,46,117,49,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,68,28,234,19,0,0,0,8,116,45,50,46,117,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,139,94,48,13,1,0,16,1,116,45,49,46,117,51,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,101,134,125,19,1,0,16,1,116,45,52,46,117,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,221,229,63,11,1,0,16,1,116,45,51,46,117,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,24,123,238,219,1,0,16,1,119,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,216,176,3,4,0,32,0,119,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,137,2,132,4,0,32,0,119,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,240,181,205,4,0,32,0,119,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,114,148,121,226,4,0,32,0,119,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,39,138,186,4,0,32,0,119,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,191,132,229,4,0,32,0,119,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,125,248,227,33,4,0,32,0,119,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,71,252,190,4,0,32,0,119,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,213,135,6,150,4,0,32,0,119,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,205,142,151,4,0,32,0,119,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,10,154,236,214,4,0,32,0,119,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,103,44,237,4,0,32,0,115,57,50,95,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,14,182,246,8,3,0,16,0,115,57,50,95,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,32,22,127,5,0,64,0,115,57,50,95,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,229,173,190,5,0,64,0,114,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,27,125,66,132,9,0,32,0,114,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,12,121,188,85,9,0,32,0,114,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,221,90,114,248,9,0,32,0,114,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,62,55,165,194,9,0,32,0,103,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,68,28,234,19,0,0,0,8,112,97,108,99,101,49,54,118,56,104,45,55,46,117,51,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,98,100,0,0,74,143,226,76,0,0,0,8,112,108,104,115,49,54,108,56,97,110,45,56,46,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,70,25,0,0,231,44,133,80,0,0,0,8,112,97,108,99,101,49,54,118,56,104,45,57,46,117,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,50,0,0,65,108,178,254,0,0,0,8,112,108,104,115,49,54,108,56,97,110,45,120,46,117,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,70,25,0,0,186,215,215,99,0,0,0,8,115,116,102,50,116,104,45,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,186,31,153,3,1,0,16,1,115,116,102,50,116,104,45,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,30,90,241,57,1,0,16,1,115,116,102,50,116,104,45,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,145,224,230,100,1,0,16,1,115,116,102,50,116,104,45,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,67,68,94,201,1,0,16,1,115,57,50,95,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,216,176,3,4,0,32,0,115,57,50,95,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,137,2,132,4,0,32,0,115,57,50,95,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,240,181,205,4,0,32,0,115,57,50,95,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,114,148,121,226,4,0,32,0,115,57,50,95,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,39,138,186,4,0,32,0,115,57,50,95,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,191,132,229,4,0,32,0,115,57,50,95,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,125,248,227,33,4,0,32,0,115,57,50,95,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,71,252,190,4,0,32,0,115,57,50,95,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,213,135,6,150,4,0,32,0,115,57,50,95,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,205,142,151,4,0,32,0,115,57,50,95,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,10,154,236,214,4,0,32,0,115,57,50,95,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,103,44,237,4,0,32,0,115,57,50,95,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,14,182,246,8,3,0,16,0,115,57,50,95,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,32,22,127,5,0,64,0,115,57,50,95,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,229,173,190,5,0,64,0,115,116,102,50,116,104,45,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,27,125,66,132,9,0,32,0,115,116,102,50,116,104,45,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,12,121,188,85,9,0,32,0,115,116,102,50,116,104,45,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,221,90,114,248,9,0,32,0,115,116,102,50,116,104,45,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,62,55,165,194,9,0,32,0,115,102,50,116,104,45,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,68,28,234,19,0,0,0,8,115,102,117,57,45,49,46,48,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,175,107,48,149,1,0,16,1,115,102,117,57,45,51,46,48,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,95,77,2,33,1,0,16,1,115,102,117,57,45,50,46,48,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,221,229,63,11,1,0,16,1,115,102,117,57,45,52,46,48,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,24,123,238,219,1,0,16,1,115,57,50,95,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,216,176,3,4,0,32,0,115,57,50,95,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,137,2,132,4,0,32,0,115,57,50,95,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,240,181,205,4,0,32,0,115,57,50,95,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,114,148,121,226,4,0,32,0,115,57,50,95,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,39,138,186,4,0,32,0,115,57,50,95,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,191,132,229,4,0,32,0,115,57,50,95,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,125,248,227,33,4,0,32,0,115,57,50,95,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,71,252,190,4,0,32,0,115,57,50,95,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,213,135,6,150,4,0,32,0,115,57,50,95,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,205,142,151,4,0,32,0,115,57,50,95,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,10,154,236,214,4,0,32,0,115,57,50,95,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,103,44,237,4,0,32,0,115,57,50,95,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,14,182,246,8,3,0,16,0,115,57,50,95,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,32,22,127,5,0,64,0,115,57,50,95,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,229,173,190,5,0,64,0,117,50,50,50,45,50,105,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,189,173,167,28,1,0,16,1,117,49,57,54,45,50,105,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,140,64,88,247,1,0,16,1,117,50,50,50,45,50,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,62,234,12,114,1,0,16,1,117,49,57,54,45,50,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,44,131,50,153,1,0,16,1,115,57,50,95,50,49,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,119,120,90,146,2,0,16,1,115,57,50,95,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,216,176,3,4,0,32,0,115,57,50,95,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,137,2,132,4,0,32,0,115,57,50,95,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,240,181,205,4,0,32,0,115,57,50,95,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,114,148,121,226,4,0,32,0,115,57,50,95,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,39,138,186,4,0,32,0,115,57,50,95,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,191,132,229,4,0,32,0,115,57,50,95,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,125,248,227,33,4,0,32,0,115,57,50,95,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,71,252,190,4,0,32,0,115,57,50,95,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,213,135,6,150,4,0,32,0,115,57,50,95,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,205,142,151,4,0,32,0,115,57,50,95,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,10,154,236,214,4,0,32,0,115,57,50,95,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,103,44,237,4,0,32,0,115,57,50,95,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,14,182,246,8,3,0,16,0,115,57,50,95,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,32,22,127,5,0,64,0,115,57,50,95,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,229,173,190,5,0,64,0,54,46,97,109,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,117,162,133,58,8,0,32,0,57,46,97,109,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,47,71,86,145,8,0,32,0,56,46,97,109,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,59,8,219,236,8,0,32,0,49,48,46,97,109,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,132,131,234,143,8,0,32,0,117,50,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,186,31,153,3,1,0,16,1,117,49,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,30,90,241,57,1,0,16,1,115,57,50,95,50,49,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,119,120,90,146,2,0,16,1,115,57,50,95,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,216,176,3,4,0,32,0,115,57,50,95,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,137,2,132,4,0,32,0,115,57,50,95,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,240,181,205,4,0,32,0,115,57,50,95,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,114,148,121,226,4,0,32,0,115,57,50,95,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,39,138,186,4,0,32,0,115,57,50,95,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,191,132,229,4,0,32,0,115,57,50,95,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,125,248,227,33,4,0,32,0,115,57,50,95,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,71,252,190,4,0,32,0,115,57,50,95,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,213,135,6,150,4,0,32,0,115,57,50,95,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,205,142,151,4,0,32,0,115,57,50,95,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,10,154,236,214,4,0,32,0,115,57,50,95,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,103,44,237,4,0,32,0,115,57,50,95,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,14,182,246,8,3,0,16,0,115,57,50,95,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,32,22,127,5,0,64,0,115,57,50,95,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,229,173,190,5,0,64,0,54,46,97,109,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,117,162,133,58,8,0,32,0,57,46,97,109,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,47,71,86,145,8,0,32,0,56,46,97,109,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,59,8,219,236,8,0,32,0,49,48,46,97,109,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,132,131,234,143,8,0,32,0,50,51,45,99,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,123,81,249,53,2,0,16,1,50,50,45,99,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,164,204,241,153,2,0,16,1,50,49,45,99,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,79,3,178,42,2,0,16,1,115,57,50,95,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,216,176,3,4,0,32,0,115,57,50,95,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,137,2,132,4,0,32,0,115,57,50,95,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,240,181,205,4,0,32,0,115,57,50,95,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,114,148,121,226,4,0,32,0,115,57,50,95,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,39,138,186,4,0,32,0,115,57,50,95,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,191,132,229,4,0,32,0,115,57,50,95,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,125,248,227,33,4,0,32,0,115,57,50,95,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,71,252,190,4,0,32,0,115,57,50,95,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,213,135,6,150,4,0,32,0,115,57,50,95,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,205,142,151,4,0,32,0,115,57,50,95,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,10,154,236,214,4,0,32,0,115,57,50,95,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,103,44,237,4,0,32,0,115,57,50,95,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,14,182,246,8,3,0,16,0,115,57,50,95,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,32,22,127,5,0,64,0,115,57,50,95,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,229,173,190,5,0,64,0,117,56,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,77,79,40,159,0,0,16,1,117,56,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,34,91,14,166,0,0,16,1,117,97,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,164,109,211,195,0,0,16,1,112,114,111,116,100,97,116,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,34,184,184,239,0,0,16,1,57,46,117,103,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,205,156,128,191,0,0,32,0,49,48,46,117,103,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,162,191,163,165,0,0,32,0,49,53,46,117,105,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,109,170,200,59,0,0,32,0,49,54,46,117,105,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,141,183,230,113,0,0,32,0,49,49,46,117,107,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,220,250,6,208,0,0,32,0,49,50,46,117,107,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,83,65,47,42,0,0,32,0,53,46,117,106,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,191,108,36,241,0,0,32,0,54,46,117,106,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,140,135,70,211,0,0,32,0,49,51,46,117,107,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,116,7,196,155,0,0,32,0,49,52,46,117,107,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,116,22,230,161,0,0,32,0,55,46,117,106,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,138,206,222,219,0,0,32,0,56,46,117,106,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,209,125,190,96,0,0,32,0,117,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,44,174,92,83,0,0,64,0,56,55,99,53,50,46,109,99,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,16,19,0,0,0,255,255,127,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,1,1,0,96,135,7,0,19,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,8,0,72,202,5,0,19,0,0,0,1,14,4,0,192,255,2,0,19,0,0,0,1,14,8,0,208,75,4,0,19,0,0,0,1,14,0,0,8,49,4,0,19,0,0,0,1,14,14,0,152,21,4,0,19,0,0,0,1,14,6,0,72,246,3,0,19,0,0,0,1,14,10,0,72,0,3,0,19,0,0,0,1,14,2,0,64,47,7,0,19,0,0,0,1,14,12,0,232,99,5,0,0,0,0,0,254,0,8,0,32,4,2,0,19,0,0,0,1,112,0,0,104,54,4,0,19,0,0,0,1,112,64,0,80,252,6,0,19,0,0,0,1,112,32,0,16,242,7,0,19,0,0,0,1,112,96,0,104,236,7,0,19,0,0,0,1,112,112,0,128,230,7,0,19,0,0,0,1,112,80,0,120,211,6,0,19,0,0,0,1,112,48,0,184,164,6,0,19,0,0,0,1,112,16,0,80,74,6,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,128,128,0,96,135,7,0,19,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,16,227,4,0,20,0,0,0,1,1,1,0,96,135,7,0,20,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,172,7,0,20,0,0,0,1,8,8,0,208,75,4,0,20,0,0,0,1,8,0,0,8,49,4,0,0,0,0,0,254,0,4,0,112,59,6,0,20,0,0,0,1,192,64,0,192,160,4,0,20,0,0,0,1,192,128,0,136,66,4,0,20,0,0,0,1,192,192,0,104,142,4,0,20,0,0,0,1,192,0,0,80,150,7,0,0,0,0,0,99,120,56,45,50,55,49,54,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,198,124,185,18,1,0,16,1,99,120,52,45,50,55,49,54,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,112,192,235,102,1,0,16,1,99,120,57,45,50,55,49,54,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,253,72,117,49,1,0,16,1,99,120,53,45,50,55,49,54,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,34,10,56,221,1,0,16,1,99,120,49,48,45,50,55,49,54,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,112,26,79,250,1,0,16,1,99,120,54,45,50,55,49,54,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,116,99,217,159,1,0,16,1,99,120,49,49,45,50,55,49,54,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,160,7,172,136,1,0,16,1,99,120,55,45,50,55,49,54,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,137,196,166,201,1,0,16,1,99,120,51,45,50,55,49,54,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,246,124,3,190,2,0,16,1,99,120,50,45,50,55,49,54,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,218,18,121,222,2,0,16,1,99,120,49,45,50,55,49,54,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,51,169,47,186,2,0,16,1,99,120,49,50,45,50,55,49,54,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,91,132,8,71,4,0,32,0,99,120,49,51,45,50,55,49,54,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,135,40,253,17,4,0,32,0,99,48,49,115,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,171,174,60,78,7,0,32,0,98,49,45,50,55,49,54,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,23,0,66,99,1,0,16,1,98,50,45,50,55,49,54,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,112,192,235,102,1,0,16,1,98,51,45,50,55,49,54,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,253,72,117,49,1,0,16,1,98,52,45,50,55,49,54,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,34,10,56,221,1,0,16,1,98,53,45,50,55,49,54,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,112,26,79,250,1,0,16,1,98,54,45,50,55,49,54,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,116,99,217,159,1,0,16,1,98,55,45,50,55,49,54,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,160,7,172,136,1,0,16,1,98,56,45,50,55,49,54,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,238,136,0,210,1,0,16,1,98,49,49,45,50,55,49,54,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,246,124,3,190,2,0,16,1,98,49,50,45,50,55,49,54,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,218,18,121,222,2,0,16,1,98,49,51,45,50,55,49,54,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,51,169,47,186,2,0,16,1,98,57,45,50,55,49,54,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,91,132,8,71,4,0,32,0,98,49,48,45,50,55,49,54,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,135,40,253,17,4,0,32,0,99,48,49,115,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,171,174,60,78,7,0,32,0,114,49,46,55,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,140,20,67,74,1,0,16,1,114,49,46,55,102,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,134,59,90,33,1,0,16,1,114,50,46,55,104,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,68,148,119,40,1,0,16,1,114,50,46,55,104,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,11,48,75,91,1,0,16,1,114,51,46,55,107,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,83,170,120,180,1,0,16,1,114,51,46,55,107,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,46,7,63,195,1,0,16,1,114,52,46,55,108,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,160,7,172,136,1,0,16,1,114,52,46,55,108,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,3,208,31,50,1,0,16,1,114,54,46,49,106,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,91,132,8,71,4,0,32,0,114,53,46,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,135,40,253,17,4,0,32,0,56,50,115,49,50,51,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,171,174,60,78,7,0,32,0,17,0,0,0,255,255,0,0,0,0,0,0,18,0,0,0,255,255,3,0,0,0,0,0,19,0,0,0,255,255,14,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,18,0,0,0,1,3,3,0,8,49,4,0,18,0,0,0,1,3,2,0,152,21,4,0,18,0,0,0,1,3,1,0,72,246,3,0,18,0,0,0,1,3,0,0,200,28,2,0,0,0,0,0,254,0,4,0,32,4,2,0,19,0,0,0,1,6,6,0,128,103,7,0,19,0,0,0,1,6,4,0,80,196,7,0,19,0,0,0,1,6,2,0,0,90,2,0,19,0,0,0,1,6,0,0,72,74,2,0,0,0,0,0,254,0,2,0,200,30,2,0,19,0,0,0,1,8,8,0,120,97,1,0,19,0,0,0,1,8,0,0,96,19,1,0,18,0,0,0,255,255,255,0,0,0,0,0,19,0,0,0,255,255,90,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,18,0,0,0,1,15,2,0,80,252,6,0,18,0,0,0,1,15,5,0,16,242,7,0,18,0,0,0,1,15,8,0,104,236,7,0,18,0,0,0,1,15,4,0,120,113,6,0,18,0,0,0,1,15,1,0,232,228,5,0,18,0,0,0,1,15,15,0,128,230,7,0,18,0,0,0,1,15,3,0,56,141,7,0,18,0,0,0,1,15,7,0,120,211,6,0,18,0,0,0,1,15,14,0,184,164,6,0,18,0,0,0,1,15,6,0,24,1,7,0,18,0,0,0,1,15,13,0,80,74,6,0,18,0,0,0,1,15,12,0,192,32,6,0,18,0,0,0,1,15,11,0,192,234,2,0,18,0,0,0,1,15,10,0,32,242,5,0,18,0,0,0,1,15,9,0,176,192,2,0,18,0,0,0,1,15,0,0,16,227,4,0,0,0,0,0,254,0,15,0,160,123,6,0,18,0,0,0,1,240,32,0,80,252,6,0,18,0,0,0,1,240,80,0,16,242,7,0,18,0,0,0,1,240,128,0,104,236,7,0,18,0,0,0,1,240,64,0,120,113,6,0,18,0,0,0,1,240,16,0,232,228,5,0,18,0,0,0,1,240,240,0,128,230,7,0,18,0,0,0,1,240,48,0,56,141,7,0,18,0,0,0,1,240,112,0,120,211,6,0,18,0,0,0,1,240,224,0,184,164,6,0,18,0,0,0,1,240,96,0,24,1,7,0,18,0,0,0,1,240,208,0,80,74,6,0,18,0,0,0,1,240,192,0,192,32,6,0,18,0,0,0,1,240,176,0,192,234,2,0,18,0,0,0,1,240,160,0,32,242,5,0,18,0,0,0,1,240,144,0,176,192,2,0,0,0,0,0,254,0,4,0,128,129,4,0,19,0,0,0,1,3,3,0,208,75,4,0,19,0,0,0,1,3,2,0,8,49,4,0,19,0,0,0,1,3,1,0,72,246,3,0,19,0,0,0,1,3,0,0,64,47,7,0,0,0,0,0,254,0,4,0,64,37,5,0,19,0,0,0,1,24,24,0,88,148,3,0,19,0,0,0,1,24,16,0,248,242,2,0,19,0,0,0,1,24,8,0,152,53,6,0,19,0,0,0,1,24,0,0,8,49,6,0,0,0,0,0,254,0,4,0,72,202,5,0,19,0,0,0,1,96,96,0,80,246,3,0,19,0,0,0,1,96,64,0,248,38,7,0,19,0,0,0,1,96,32,0,48,123,8,0,19,0,0,0,1,96,0,0,8,117,8,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,128,128,0,96,135,7,0,19,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,20,0,0,0,1,4,4,0,96,135,7,0,20,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,131,2,0,20,0,0,0,1,8,8,0,8,49,4,0,20,0,0,0,1,8,0,0,72,246,3,0,115,99,111,98,114,97,50,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,56,222,90,225,1,0,16,1,115,99,111,98,114,97,50,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,77,228,112,162,1,0,16,1,115,99,111,98,114,97,50,102,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,70,3,215,189,1,0,16,1,115,99,111,98,114,97,50,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,49,236,165,220,1,0,16,1,115,99,111,98,114,97,50,106,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,110,107,143,13,1,0,16,1,115,99,111,98,114,97,50,108,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,169,243,128,111,1,0,16,1,101,112,114,49,50,55,53,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,211,13,235,222,2,0,16,1,101,112,114,49,50,55,54,46,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,116,26,44,135,2,0,16,1,101,112,114,49,50,55,55,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,16,161,215,204,2,0,16,1,101,112,114,49,50,55,52,46,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,180,19,209,100,4,0,32,0,101,112,114,49,50,55,51,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,211,22,99,169,4,0,32,0,56,50,115,49,50,51,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,13,249,135,155,7,0,32,0,18,0,0,0,255,255,0,0,0,0,0,0,19,0,0,0,255,255,3,0,0,0,0,0,20,0,0,0,255,255,12,0,0,0,0,0,0,0,0,0,254,0,2,0,104,159,3,0,19,0,0,0,1,1,1,0,96,135,7,0,19,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,128,129,4,0,19,0,0,0,1,2,2,0,8,49,4,0,19,0,0,0,1,2,0,0,72,246,3,0,0,0,0,0,254,0,4,0,32,4,2,0,20,0,0,0,1,6,2,0,224,127,8,0,20,0,0,0,1,6,0,0,0,67,1,0,20,0,0,0,1,6,4,0,32,123,8,0,20,0,0,0,1,6,6,0,152,252,1,0,0,0,0,0,254,0,2,0,200,30,2,0,20,0,0,0,1,8,8,0,120,97,1,0,20,0,0,0,1,8,0,0,96,19,1,0,0,0,0,0,118,105,100,95,50,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,145,243,221,174,1,0,16,1,118,105,100,95,50,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,183,126,181,114,1,0,16,1,115,99,111,98,114,97,50,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,77,228,112,162,1,0,16,1,115,99,111,98,114,97,50,102,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,70,3,215,189,1,0,16,1,115,99,111,98,114,97,50,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,49,236,165,220,1,0,16,1,115,99,111,98,114,97,50,106,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,110,107,143,13,1,0,16,1,115,99,111,98,114,97,50,108,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,169,243,128,111,1,0,16,1,101,112,114,49,50,55,53,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,211,13,235,222,2,0,16,1,101,112,114,49,50,55,54,46,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,116,26,44,135,2,0,16,1,101,112,114,49,50,55,55,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,16,161,215,204,2,0,16,1,101,112,114,49,50,55,52,46,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,180,19,209,100,4,0,32,0,101,112,114,49,50,55,51,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,211,22,99,169,4,0,32,0,56,50,115,49,50,51,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,13,249,135,155,7,0,32,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,9,0,0,0,10,0,0,0,11,0,0,0,12,0,0,0,13,0,0,0,14,0,0,0,15,0,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,43,0,0,0,44,0,0,0,45,0,0,0,46,0,0,0,47,0,0,0,48,0,0,0,49,0,0,0,50,0,0,0,51,0,0,0,52,0,0,0,53,0,0,0,54,0,0,0,55,0,0,0,56,0,0,0,57,0,0,0,58,0,0,0,59,0,0,0,60,0,0,0,61,0,0,0,62,0,0,0,63,0,0,0,192,255,255,255,193,255,255,255,194,255,255,255,195,255,255,255,196,255,255,255,197,255,255,255,198,255,255,255,199,255,255,255,200,255,255,255,201,255,255,255,202,255,255,255,203,255,255,255,204,255,255,255,205,255,255,255,206,255,255,255,207,255,255,255,208,255,255,255,209,255,255,255,210,255,255,255,211,255,255,255,212,255,255,255,213,255,255,255,214,255,255,255,215,255,255,255,216,255,255,255,217,255,255,255,218,255,255,255,219,255,255,255,220,255,255,255,221,255,255,255,222,255,255,255,223,255,255,255,224,255,255,255,225,255,255,255,226,255,255,255,227,255,255,255,228,255,255,255,229,255,255,255,230,255,255,255,231,255,255,255,232,255,255,255,233,255,255,255,234,255,255,255,235,255,255,255,236,255,255,255,237,255,255,255,238,255,255,255,239,255,255,255,240,255,255,255,241,255,255,255,242,255,255,255,243,255,255,255,244,255,255,255,245,255,255,255,246,255,255,255,247,255,255,255,248,255,255,255,249,255,255,255,250,255,255,255,251,255,255,255,252,255,255,255,253,255,255,255,254,255,255,255,255,255,255,255,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,9,0,0,0,10,0,0,0,11,0,0,0,12,0,0,0,13,0,0,0,14,0,0,0,15,0,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,43,0,0,0,44,0,0,0,45,0,0,0,46,0,0,0,47,0,0,0,48,0,0,0,49,0,0,0,50,0,0,0,51,0,0,0,52,0,0,0,53,0,0,0,54,0,0,0,55,0,0,0,56,0,0,0,57,0,0,0,58,0,0,0,59,0,0,0,60,0,0,0,61,0,0,0,62,0,0,0,63,0,0,0,192,255,255,255,193,255,255,255,194,255,255,255,195,255,255,255,196,255,255,255,197,255,255,255,198,255,255,255,199,255,255,255,200,255,255,255,201,255,255,255,202,255,255,255,203,255,255,255,204,255,255,255,205,255,255,255,206,255,255,255,207,255,255,255,208,255,255,255,209,255,255,255,210,255,255,255,211,255,255,255,212,255,255,255,213,255,255,255,214,255,255,255,215,255,255,255,216,255,255,255,217,255,255,255,218,255,255,255,219,255,255,255,220,255,255,255,221,255,255,255,222,255,255,255,223,255,255,255,224,255,255,255,225,255,255,255,226,255,255,255,227,255,255,255,228,255,255,255,229,255,255,255,230,255,255,255,231,255,255,255,232,255,255,255,233,255,255,255,234,255,255,255,235,255,255,255,236,255,255,255,237,255,255,255,238,255,255,255,239,255,255,255,240,255,255,255,241,255,255,255,242,255,255,255,243,255,255,255,244,255,255,255,245,255,255,255,246,255,255,255,247,255,255,255,248,255,255,255,249,255,255,255,250,255,255,255,251,255,255,255,252,255,255,255,253,255,255,255,254,255,255,255,255,255,255,255,18,0,0,0,255,255,96,0,0,0,0,0,19,0,0,0,255,255,1,0,0,0,0,0,0,0,0,0,254,0,2,0,232,75,4,0,18,0,0,0,1,32,32,0,96,135,7,0,18,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,192,3,0,18,0,0,0,1,64,64,0,96,135,7,0,18,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,48,45,3,0,19,0,0,0,1,1,0,0,176,20,3,0,19,0,0,0,1,1,1,0,224,32,1,0,0,0,0,0,184,40,2,0,1,0,0,0,139,236,146,0,248,191,2,0,184,164,8,0,1,0,0,0,138,236,146,0,64,246,1,0,24,38,7,0,1,0,0,0,137,236,146,0,184,160,2,0,152,122,6,0,1,0,0,0,120,1,147,0,96,82,2,0,192,72,6,0,1,0,0,0,121,1,147,0,32,56,2,0,24,163,6,0,1,0,0,0,122,1,147,0,240,108,2,0,56,210,6,0,1,0,0,0,123,1,147,0,192,135,2,0,200,110,3,0,1,0,0,0,200,248,146,0,152,30,2,0,120,89,3,0,1,0,0,0,201,248,146,0,232,10,2,0,144,236,1,0,1,0,0,0,136,236,146,0,136,224,1,0,24,198,1,0,1,0,0,0,168,240,146,0,40,167,1,0,120,189,1,0,1,0,0,0,169,240,146,0,200,149,1,0,192,209,1,0,1,0,0,0,170,240,146,0,24,182,1,0,176,223,1,0,1,0,0,0,171,240,146,0,72,198,1,0,224,22,1,0,1,0,0,0,120,237,146,0,56,126,1,0,160,14,1,0,1,0,0,0,121,237,146,0,32,101,1,0,16,17,8,0,1,0,0,0,202,248,146,0,216,70,1,0,88,212,3,0,1,0,0,0,248,220,146,0,40,185,3,0,248,5,8,0,9,0,0,0,206,187,145,0,32,58,1,0,144,250,7,0,9,0,0,0,207,187,145,0,32,58,1,0,248,241,7,0,9,0,0,0,208,187,145,0,32,58,1,0,72,82,8,0,9,0,0,0,209,187,145,0,32,58,1,0,18,0,0,0,255,255,255,0,0,0,0,0,19,0,0,0,255,255,86,0,0,0,0,0,20,0,0,0,255,255,15,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,18,0,0,0,1,15,2,0,80,252,6,0,18,0,0,0,1,15,5,0,16,242,7,0,18,0,0,0,1,15,8,0,104,236,7,0,18,0,0,0,1,15,4,0,120,113,6,0,18,0,0,0,1,15,1,0,232,228,5,0,18,0,0,0,1,15,15,0,128,230,7,0,18,0,0,0,1,15,3,0,56,141,7,0,18,0,0,0,1,15,7,0,120,211,6,0,18,0,0,0,1,15,14,0,184,164,6,0,18,0,0,0,1,15,6,0,24,1,7,0,18,0,0,0,1,15,13,0,80,74,6,0,18,0,0,0,1,15,12,0,192,32,6,0,18,0,0,0,1,15,11,0,192,234,2,0,18,0,0,0,1,15,10,0,32,242,5,0,18,0,0,0,1,15,9,0,176,192,2,0,18,0,0,0,1,15,0,0,16,227,4,0,0,0,0,0,254,0,16,0,160,123,6,0,18,0,0,0,1,240,32,0,80,252,6,0,18,0,0,0,1,240,80,0,16,242,7,0,18,0,0,0,1,240,128,0,104,236,7,0,18,0,0,0,1,240,64,0,120,113,6,0,18,0,0,0,1,240,16,0,232,228,5,0,18,0,0,0,1,240,240,0,128,230,7,0,18,0,0,0,1,240,48,0,56,141,7,0,18,0,0,0,1,240,112,0,120,211,6,0,18,0,0,0,1,240,224,0,184,164,6,0,18,0,0,0,1,240,96,0,24,1,7,0,18,0,0,0,1,240,208,0,80,74,6,0,18,0,0,0,1,240,192,0,192,32,6,0,18,0,0,0,1,240,176,0,192,234,2,0,18,0,0,0,1,240,160,0,32,242,5,0,18,0,0,0,1,240,144,0,176,192,2,0,18,0,0,0,1,240,0,0,168,144,4,0,0,0,0,0,254,0,4,0,128,129,4,0,19,0,0,0,1,3,3,0,192,255,2,0,19,0,0,0,1,3,2,0,208,75,4,0,19,0,0,0,1,3,1,0,8,49,4,0,19,0,0,0,1,3,0,0,72,246,3,0,0,0,0,0,254,0,4,0,240,96,5,0,19,0,0,0,1,24,0,0,224,210,4,0,19,0,0,0,1,24,8,0,40,177,4,0,19,0,0,0,1,24,16,0,8,145,4,0,19,0,0,0,1,24,24,0,120,7,5,0,0,0,0,0,254,0,4,0,72,202,5,0,19,0,0,0,1,96,96,0,80,246,3,0,19,0,0,0,1,96,64,0,248,38,7,0,19,0,0,0,1,96,32,0,112,212,3,0,19,0,0,0,1,96,0,0,248,160,5,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,128,128,0,96,135,7,0,19,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,20,0,0,0,1,4,4,0,96,135,7,0,20,0,0,0,1,4,0,0,152,182,7,0,168,86,7,0,1,0,0,0,152,242,146,0,248,191,2,0,24,38,7,0,1,0,0,0,199,250,146,0,184,160,2,0,56,210,6,0,1,0,0,0,192,250,146,0,192,135,2,0,24,163,6,0,1,0,0,0,193,250,146,0,240,108,2,0,152,122,6,0,1,0,0,0,194,250,146,0,96,82,2,0,192,72,6,0,1,0,0,0,195,250,146,0,32,56,2,0,200,110,3,0,1,0,0,0,196,250,146,0,152,30,2,0,120,89,3,0,1,0,0,0,197,250,146,0,232,10,2,0,120,74,3,0,1,0,0,0,198,250,146,0,152,138,8,0,40,246,1,0,1,0,0,0,153,242,146,0,64,246,1,0,144,236,1,0,1,0,0,0,207,250,146,0,136,224,1,0,176,223,1,0,1,0,0,0,200,250,146,0,72,198,1,0,192,209,1,0,1,0,0,0,201,250,146,0,24,182,1,0,24,198,1,0,1,0,0,0,202,250,146,0,40,167,1,0,120,189,1,0,1,0,0,0,203,250,146,0,200,149,1,0,224,22,1,0,1,0,0,0,204,250,146,0,56,126,1,0,160,14,1,0,1,0,0,0,205,250,146,0,32,101,1,0,176,9,1,0,1,0,0,0,206,250,146,0,96,32,8,0,88,212,3,0,1,0,0,0,136,215,146,0,40,185,3,0,16,17,8,0,1,0,0,0,154,242,146,0,224,12,8,0,72,65,1,0,9,0,0,0,144,3,147,0,32,58,1,0,48,50,1,0,9,0,0,0,145,3,147,0,32,58,1,0,224,41,1,0,9,0,0,0,146,3,147,0,32,58,1,0,101,112,48,53,45,52,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,121,83,195,41,0,0,16,1,101,112,48,49,45,52,46,49,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,105,124,80,119,0,0,16,1,101,112,48,52,45,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,120,23,24,57,0,0,16,1,101,112,48,48,45,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,31,84,40,225,0,0,16,1,101,112,48,51,45,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,36,75,22,91,0,0,16,1,101,110,95,50,52,95,109,98,55,49,50,52,101,46,97,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,152,202,226,184,0,0,16,1,101,112,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,177,74,126,167,0,0,32,0,101,112,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,3,105,189,159,0,0,32,0,101,112,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,184,56,141,29,0,0,32,0,101,112,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,178,41,121,24,0,0,32,0,101,112,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,94,11,88,182,0,0,32,0,101,112,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,199,1,173,155,0,0,32,0,101,112,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,218,206,86,202,0,0,32,0,101,112,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,156,38,69,169,0,0,32,0,101,112,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,88,77,250,231,0,0,32,0,101,112,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,157,232,170,132,0,0,32,0,101,112,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,207,117,93,73,0,0,32,0,101,112,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,226,50,174,162,0,0,32,0,101,112,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,90,66,250,98,0,0,32,0,101,112,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,149,189,227,204,0,0,32,0,101,112,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,86,214,190,17,0,0,32,0,101,112,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,76,123,92,196,0,0,32,0,101,112,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,40,159,202,143,0,0,32,0,101,112,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,195,208,209,60,0,0,32,0,101,112,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,111,228,28,113,0,0,64,0,109,98,55,49,49,54,101,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,86,162,136,194,0,0,0,8,109,98,55,49,50,50,101,46,49,55,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,207,78,118,100,0,0,0,8,24,0,0,0,255,255,127,0,0,0,0,0,25,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,200,87,7,0,24,0,0,0,1,3,0,0,176,45,8,0,24,0,0,0,1,3,1,0,224,127,8,0,24,0,0,0,1,3,3,0,32,123,8,0,24,0,0,0,1,3,2,0,192,110,8,0,0,0,0,0,254,0,4,0,160,123,6,0,24,0,0,0,1,12,0,0,176,45,8,0,24,0,0,0,1,12,4,0,224,127,8,0,24,0,0,0,1,12,12,0,32,123,8,0,24,0,0,0,1,12,8,0,192,110,8,0,0,0,0,0,254,0,2,0,168,234,7,0,24,0,0,0,1,32,0,0,96,135,7,0,24,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,24,0,0,0,1,64,64,0,96,135,7,0,24,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,200,30,2,0,24,0,0,0,1,128,128,0,120,97,1,0,24,0,0,0,1,128,0,0,96,19,1,0,0,0,0,0,254,0,4,0,96,126,1,0,25,0,0,0,1,3,1,0,112,134,3,0,25,0,0,0,1,3,3,0,80,124,6,0,25,0,0,0,1,3,2,0,64,111,3,0,25,0,0,0,1,3,0,0,152,20,8,0,0,0,0,0,254,0,4,0,72,202,5,0,25,0,0,0,1,12,8,0,80,246,3,0,25,0,0,0,1,12,12,0,248,38,7,0,25,0,0,0,1,12,4,0,112,212,3,0,25,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,2,0,192,125,6,0,25,0,0,0,1,16,16,0,56,111,3,0,25,0,0,0])
.concat([1,16,0,0,104,134,3,0,0,0,0,0,254,0,2,0,80,77,1,0,25,0,0,0,1,32,0,0,112,134,3,0,25,0,0,0,1,32,32,0,64,111,3,0,0,0,0,0,254,0,2,0,240,70,1,0,25,0,0,0,1,64,64,0,248,38,7,0,25,0,0,0,1,64,0,0,40,71,8,0,168,86,7,0,1,0,0,0,136,239,146,0,248,191,2,0,24,38,7,0,1,0,0,0,223,254,146,0,184,160,2,0,56,210,6,0,1,0,0,0,218,254,146,0,192,135,2,0,24,163,6,0,1,0,0,0,219,254,146,0,240,108,2,0,152,122,6,0,1,0,0,0,216,254,146,0,96,82,2,0,192,72,6,0,1,0,0,0,217,254,146,0,32,56,2,0,200,110,3,0,1,0,0,0,220,254,146,0,152,30,2,0,120,89,3,0,1,0,0,0,221,254,146,0,232,10,2,0,120,74,3,0,1,0,0,0,222,254,146,0,152,138,8,0,40,246,1,0,1,0,0,0,137,239,146,0,64,246,1,0,144,236,1,0,1,0,0,0,127,246,146,0,136,224,1,0,176,223,1,0,1,0,0,0,122,246,146,0,72,198,1,0,192,209,1,0,1,0,0,0,123,246,146,0,24,182,1,0,24,198,1,0,1,0,0,0,120,246,146,0,40,167,1,0,120,189,1,0,1,0,0,0,121,246,146,0,200,149,1,0,224,22,1,0,1,0,0,0,124,246,146,0,56,126,1,0,160,14,1,0,1,0,0,0,125,246,146,0,32,101,1,0,176,9,1,0,1,0,0,0,126,246,146,0,96,32,8,0,88,212,3,0,1,0,0,0,160,218,146,0,40,185,3,0,16,17,8,0,1,0,0,0,138,239,146,0,224,12,8,0,72,65,1,0,9,0,0,0,48,5,147,0,32,58,1,0,48,50,1,0,9,0,0,0,49,5,147,0,32,58,1,0,224,41,1,0,9,0,0,0,50,5,147,0,32,58,1,0,114,101,112,117,108,115,101,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,157,124,43,251,0,0,16,1,114,101,112,117,108,115,101,46,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,24,153,18,153,0,0,16,1,55,46,106,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,233,168,87,0,0,16,1,49,46,102,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,33,198,133,196,0,0,16,1,50,46,104,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,134,168,198,179,0,0,16,1,51,46,106,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,76,49,126,25,0,0,16,1,114,101,112,117,108,115,101,46,98,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,243,103,178,134,0,0,16,1,114,101,112,117,108,115,101,46,97,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,10,233,29,142,0,0,32,0,49,53,46,57,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,105,52,33,201,0,0,32,0,49,54,46,49,48,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,158,211,229,125,0,0,32,0,49,55,46,49,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,44,247,165,11,0,0,32,0,56,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,126,117,159,14,0,0,32,0,57,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,80,230,210,247,0,0,32,0,49,48,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,244,186,23,231,0,0,32,0,49,49,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,11,37,178,4,0,0,32,0,49,50,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,64,225,16,209,0,0,32,0,49,51,46,49,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,60,113,220,143,0,0,32,0,98,46,49,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,49,84,163,62,0,0,32,0,103,46,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,158,166,215,172,0,0,32,0,114,46,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,65,139,244,183,0,0,32,0,109,49,46,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,1,146,163,131,0,0,32,0,101,112,114,45,53,54,52,48,97,46,49,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,40,21,251,218,0,0,16,1,101,112,114,45,53,54,52,49,97,46,49,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,14,133,204,15,0,0,16,1,101,112,114,45,53,54,52,50,97,46,49,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,23,250,239,79,0,0,16,1,101,112,114,45,53,54,52,51,97,46,49,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,180,126,172,184,0,0,16,1,101,112,114,45,53,54,52,52,46,49,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,125,91,208,255,0,0,16,1,101,112,114,45,53,54,52,53,97,46,49,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,124,247,75,107,0,0,16,1,101,112,114,45,53,54,53,50,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,152,203,237,116,0,0,16,1,101,112,114,45,53,54,53,49,46,56,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,130,62,127,240,0,0,32,0,101,112,114,45,53,54,53,48,46,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,162,186,193,132,0,0,32,0,101,112,114,45,53,54,52,57,46,56,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,149,200,116,103,0,0,32,0,101,112,114,45,53,54,52,56,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,42,233,105,12,0,0,32,0,101,112,114,45,53,54,52,55,46,56,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,181,247,48,147,0,0,32,0,101,112,114,45,53,54,52,54,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,188,203,250,77,0,0,32,0,101,112,114,45,53,54,51,56,46,56,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,221,99,115,97,0,0,32,0,101,112,114,45,53,54,51,57,46,57,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,49,81,236,164,0,0,32,0,112,114,45,53,51,49,55,46,49,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,184,80,131,100,0,0,0,8,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,126,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,19,0,0,0,1,15,7,0,80,252,6,0,19,0,0,0,1,15,8,0,16,242,7,0,19,0,0,0,1,15,9,0,104,236,7,0,19,0,0,0,1,15,5,0,192,54,8,0,19,0,0,0,1,15,4,0,56,24,4,0,19,0,0,0,1,15,15,0,128,230,7,0,19,0,0,0,1,15,0,0,128,230,7,0,19,0,0,0,1,15,3,0,176,162,3,0,19,0,0,0,1,15,2,0,24,188,3,0,19,0,0,0,1,15,1,0,72,216,3,0,19,0,0,0,1,15,6,0,120,211,6,0,19,0,0,0,1,15,14,0,184,164,6,0,19,0,0,0,1,15,13,0,80,74,6,0,19,0,0,0,1,15,12,0,192,32,6,0,19,0,0,0,1,15,11,0,192,234,2,0,19,0,0,0,1,15,10,0,32,242,5,0,0,0,0,0,254,0,16,0,160,123,6,0,19,0,0,0,1,240,112,0,80,252,6,0,19,0,0,0,1,240,128,0,16,242,7,0,19,0,0,0,1,240,144,0,104,236,7,0,19,0,0,0,1,240,80,0,192,54,8,0,19,0,0,0,1,240,64,0,56,24,4,0,19,0,0,0,1,240,240,0,128,230,7,0,19,0,0,0,1,240,0,0,128,230,7,0,19,0,0,0,1,240,48,0,176,162,3,0,19,0,0,0,1,240,32,0,24,188,3,0,19,0,0,0,1,240,16,0,72,216,3,0,19,0,0,0,1,240,96,0,120,211,6,0,19,0,0,0,1,240,224,0,184,164,6,0,19,0,0,0,1,240,208,0,80,74,6,0,19,0,0,0,1,240,192,0,192,32,6,0,19,0,0,0,1,240,176,0,192,234,2,0,19,0,0,0,1,240,160,0,32,242,5,0,0,0,0,0,254,0,2,0,200,30,2,0,20,0,0,0,1,1,0,0,120,97,1,0,20,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,12,12,0,8,49,4,0,20,0,0,0,1,12,8,0,152,21,4,0,20,0,0,0,1,12,4,0,72,246,3,0,20,0,0,0,1,12,0,0,112,49,6,0,0,0,0,0,254,0,2,0,72,202,5,0,20,0,0,0,1,64,64,0,80,246,3,0,20,0,0,0,1,64,0,0,112,212,3,0,0,0,0,0,254,0,2,0,104,159,3,0,20,0,0,0,1,128,128,0,96,135,7,0,20,0,0,0,1,128,0,0,152,182,7,0,114,117,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,55,79,142,90,1,0,16,1,114,117,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,45,245,36,198,1,0,16,1,114,117,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,28,13,3,225,1,0,16,1,114,117,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,158,6,146,118,1,0,16,1,114,117,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,243,143,100,203,1,0,16,1,114,117,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,142,245,169,225,1,0,16,1,114,117,104,106,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,13,43,66,138,4,0,32,0,114,117,107,108,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,177,76,184,30,4,0,32,0,54,108,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,103,148,172,195,7,0,32,0,12,0,0,0,255,255,0,0,0,0,0,0,13,0,0,0,255,255,0,0,0,0,0,0,14,0,0,0,255,255,1,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,12,0,0,0,1,32,0,0,120,97,1,0,12,0,0,0,1,32,32,0,96,19,1,0,0,0,0,0,254,0,2,0,232,75,4,0,12,0,0,0,1,64,0,0,96,135,7,0,12,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,4,0,32,4,2,0,13,0,0,0,1,192,64,0,144,147,2,0,13,0,0,0,1,192,0,0,200,209,1,0,13,0,0,0,1,192,128,0,224,64,1,0,13,0,0,0,1,192,192,0,104,151,6,0,0,0,0,0,254,0,4,0,64,37,5,0,14,0,0,0,1,3,1,0,152,120,3,0,14,0,0,0,1,3,2,0,136,120,6,0,14,0,0,0,1,3,3,0,176,114,3,0,14,0,0,0,1,3,0,0,120,7,5,0,0,0,0,0,254,0,2,0,128,129,4,0,14,0,0,0,1,4,0,0,8,49,4,0,14,0,0,0,1,4,4,0,72,246,3,0,101,112,114,45,49,51,57,56,54,46,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,101,35,139,56,1,0,16,1,101,112,114,45,49,51,57,56,53,46,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,212,165,219,20,1,0,16,1,101,112,114,45,49,51,57,56,56,46,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,164,213,28,220,1,0,16,1,101,112,114,45,49,51,57,56,55,46,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,96,158,190,67,1,0,16,1,101,112,114,45,49,51,57,57,50,97,46,56,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,182,37,213,197,9,0,16,1,101,112,114,45,49,51,57,57,49,97,46,56,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,124,60,158,41,9,0,16,1,101,112,114,45,49,51,57,57,48,46,53,52,46,118,101,114,105,102,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,197,35,235,24,17,0,16,1,101,112,114,45,49,51,57,56,57,46,53,51,46,118,101,114,105,102,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,78,130,79,143,17,0,16,1,109,112,114,45,49,51,57,57,55,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,135,27,223,31,3,0,32,0,109,112,114,45,49,51,57,57,57,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,60,213,29,154,3,0,32,0,109,112,114,45,49,52,48,50,49,46,54,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,129,135,168,159,18,0,32,0,109,112,114,45,49,52,48,50,50,46,55,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,187,36,232,73,18,0,32,0,109,112,114,45,49,52,48,48,57,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,126,24,181,53,18,0,32,0,109,112,114,45,49,52,48,49,48,46,55,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,155,139,83,154,18,0,32,0,109,112,114,45,49,52,48,50,51,46,56,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,103,108,28,225,18,0,32,0,109,112,114,45,49,52,48,50,52,46,49,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,53,69,52,22,18,0,32,0,109,112,114,45,49,52,48,49,49,46,56,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,59,152,233,120,18,0,32,0,109,112,114,45,49,52,48,49,50,46,49,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,164,161,218,233,18,0,32,0,109,112,114,45,49,52,48,49,55,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,89,241,61,184,18,0,32,0,109,112,114,45,49,52,48,49,56,46,55,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,206,233,219,118,18,0,32,0,109,112,114,45,49,52,48,48,53,46,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,9,130,153,158,18,0,32,0,109,112,114,45,49,52,48,48,54,46,55,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,26,223,173,44,18,0,32,0,109,112,114,45,49,52,48,49,57,46,56,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,255,25,94,177,18,0,32,0,109,112,114,45,49,52,48,50,48,46,49,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,143,0,199,132,18,0,32,0,109,112,114,45,49,52,48,48,55,46,56,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,170,95,207,195,18,0,32,0,109,112,114,45,49,52,48,48,56,46,49,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,178,190,145,126,18,0,32,0,109,112,114,45,49,52,48,49,51,46,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,195,178,219,49,18,0,32,0,109,112,114,45,49,52,48,49,52,46,55,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,125,37,104,126,18,0,32,0,109,112,114,45,49,52,48,48,49,46,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,208,26,3,113,18,0,32,0,109,112,114,45,49,52,48,48,50,46,54,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,94,10,231,39,18,0,32,0,109,112,114,45,49,52,48,49,53,46,56,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,133,191,64,117,18,0,32,0,109,112,114,45,49,52,48,49,54,46,49,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,77,185,135,125,18,0,32,0,109,112,114,45,49,52,48,48,51,46,56,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,116,93,114,135,18,0,32,0,109,112,114,45,49,52,48,48,52,46,49,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,145,114,71,115,18,0,32,0,101,112,114,45,49,51,57,57,51,46,49,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,67,181,195,124,4,0,16,1,109,112,114,45,49,51,57,57,54,46,49,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,65,90,95,52,11,0,64,0,109,112,114,45,49,51,57,57,53,46,49,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,112,194,4,246,11,0,64,0,109,112,114,45,49,51,57,57,52,46,49,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,56,85,9,118,11,0,64,0,98,48,52,45,51,56,46,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,177,219,145,28,2,0,16,1,98,48,52,45,51,55,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,221,11,242,236,2,0,16,1,98,48,52,45,52,53,46,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,221,18,40,54,2,0,16,1,98,48,52,45,52,52,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,8,85,204,81,2,0,16,1,98,48,52,45,52,50,46,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,203,167,87,24,2,0,16,1,98,48,52,45,52,49,45,49,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,105,50,64,189,2,0,16,1,98,48,52,45,49,57,46,52,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,216,253,129,238,9,0,16,1,98,48,52,45,48,49,46,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,25,222,48,205,11,0,32,0,98,48,52,45,48,51,46,51,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,100,224,103,171,11,0,32,0,98,48,52,45,48,50,46,54,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,236,15,4,84,11,0,32,0,98,48,52,45,48,52,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,147,126,115,148,11,0,32,0,98,48,52,45,48,53,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,172,148,45,194,15,0,32,0,98,48,52,45,48,55,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,81,42,99,181,15,0,32,0,98,48,52,45,48,54,46,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,57,207,44,0,15,0,32,0,98,48,52,45,48,56,46,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,5,202,175,254,15,0,32,0,98,48,52,45,50,48,46,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,204,52,26,253,26,0,64,0,98,48,52,45,51,56,46,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,177,219,145,28,2,0,16,1,98,48,52,45,51,55,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,221,11,242,236,2,0,16,1,98,48,52,45,52,48,46,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,179,212,48,9,2,0,16,1,98,48,52,45,51,57,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,94,222,90,217,2,0,16,1,98,48,52,45,52,50,46,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,203,167,87,24,2,0,16,1,98,48,52,45,52,51,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,82,145,75,195,2,0,16,1,98,48,52,45,49,57,46,52,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,216,253,129,238,9,0,16,1,98,48,52,45,48,49,46,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,25,222,48,205,11,0,32,0,98,48,52,45,48,51,46,51,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,100,224,103,171,11,0,32,0,98,48,52,45,48,50,46,54,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,236,15,4,84,11,0,32,0,98,48,52,45,48,52,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,147,126,115,148,11,0,32,0,98,48,52,45,48,53,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,172,148,45,194,15,0,32,0,98,48,52,45,48,55,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,81,42,99,181,15,0,32,0,98,48,52,45,48,54,46,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,57,207,44,0,15,0,32,0,98,48,52,45,48,56,46,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,5,202,175,254,15,0,32,0,98,48,52,45,50,48,46,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,204,52,26,253,26,0,64,0,20,0,0,0,255,255,253,0,0,0,0,0,21,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,232,75,4,0,20,0,0,0,1,1,1,0,96,135,7,0,20,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,128,112,3,0,20,0,0,0,1,2,2,0,224,247,3,0,20,0,0,0,1,2,0,0,168,22,4,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,48,16,0,80,246,3,0,20,0,0,0,1,48,48,0,248,38,7,0,20,0,0,0,1,48,32,0,112,212,3,0,20,0,0,0,1,48,0,0,248,160,5,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,192,0,0,192,255,2,0,20,0,0,0,1,192,64,0,208,75,4,0,20,0,0,0,1,192,192,0,8,49,4,0,20,0,0,0,1,192,128,0,152,21,4,0,0,0,0,0,254,0,2,0,168,234,7,0,21,0,0,0,1,2,0,0,96,135,7,0,21,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,8,0,160,123,6,0,21,0,0,0,1,28,16,0,32,136,7,0,21,0,0,0,1,28,8,0,40,88,7,0,21,0,0,0,1,28,24,0,96,39,7,0,21,0,0,0,1,28,28,0,144,251,6,0,21,0,0,0,1,28,12,0,184,164,6,0,21,0,0,0,1,28,20,0,80,74,6,0,21,0,0,0,1,28,4,0,192,32,6,0,21,0,0,0,1,28,0,0,16,227,4,0,0,0,0,0,254,0,8,0,200,87,7,0,21,0,0,0,1,224,128,0,32,136,7,0,21,0,0,0,1,224,64,0,40,88,7,0,21,0,0,0,1,224,192,0,96,39,7,0,21,0,0,0,1,224,224,0,144,251,6,0,21,0,0,0,1,224,96,0,184,164,6,0,21,0,0,0,1,224,160,0,80,74,6,0,21,0,0,0,1,224,32,0,192,32,6,0,21,0,0,0,1,224,0,0,16,227,4,0,0,0,0,0,23,0,0,0,255,255,255,0,0,0,0,0,24,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,0,0,144,212,8,0,23,0,0,0,1,2,2,0,96,135,7,0,23,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,23,0,0,0,1,4,4,0,96,135,7,0,23,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,23,0,0,0,1,8,0,0,96,135,7,0,23,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,2,0,32,4,2,0,23,0,0,0,1,48,16,0,40,88,7,0,23,0,0,0,1,48,32,0,96,39,7,0,23,0,0,0,1,48,0,0,232,228,5,0,23,0,0,0,1,48,48,0,144,251,6,0,0,0,0,0,254,0,4,0,168,248,6,0,23,0,0,0,1,192,64,0,96,39,7,0,23,0,0,0,1,192,128,0,144,251,6,0,23,0,0,0,1,192,192,0,80,75,3,0,23,0,0,0,1,192,0,0,64,224,5,0,0,0,0,0,254,0,4,0,72,202,5,0,24,0,0,0,1,3,2,0,80,246,3,0,24,0,0,0,1,3,3,0,80,124,6,0,24,0,0,0,1,3,1,0,112,212,3,0,24,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,1,0,24,113,4,0,24,0,0,0,1,8,8,0,208,216,5,0,0,0,0,0,254,0,2,0,104,159,3,0,24,0,0,0,1,16,0,0,96,135,7,0,24,0,0,0,1,16,16,0,152,182,7,0,0,0,0,0,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,13,112,130,88,0,0,16,1,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,236,133,101,120,0,0,16,1,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,205,125,13,17,0,0,16,1,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,71,180,58,71,0,0,16,1,56,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,229,29,124,39,0,0,32,0,114,120,49,45,54,46,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,44,246,22,60,0,0,32,0,114,120,49,45,49,46,49,49,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,52,84,134,199,0,0,32,0,114,120,49,45,55,46,56,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,218,79,77,131,0,0,32,0,114,120,49,45,50,46,52,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,21,72,87,143,0,0,32,0,114,120,49,45,51,46,55,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,150,16,134,184,0,0,32,0,114,120,49,45,53,46,51,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,23,112,173,75,0,0,64,0,114,120,49,45,52,46,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,0,114,120,49,95,112,114,103,95,49,46,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,219,56,146,239,0,0,16,1,114,120,49,95,112,114,103,95,50,46,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,86,182,190,124,0,0,16,1,114,120,49,95,112,114,103,95,51,46,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,66,16,75,51,0,0,16,1,114,120,49,95,112,114,103,95,52,46,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,221,138,97,214,0,0,16,1,114,120,49,95,112,114,103,95,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,78,242,105,61,0,0,16,1,114,120,49,95,112,114,103,95,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,22,15,116,233,0,0,16,1,114,120,49,95,112,114,103,95,55,46,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,242,9,49,132,0,0,16,1,114,120,49,95,112,114,103,95,56,46,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,201,110,132,155,0,0,16,1,114,120,49,95,99,104,103,95,49,46,56,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,164,56,255,31,0,0,32,0,114,120,49,95,99,104,103,95,50,46,56,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,82,245,223,104,0,0,32,0,114,120,49,45,54,46,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,44,246,22,60,0,0,32,0,114,120,49,45,49,46,49,49,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,52,84,134,199,0,0,32,0,114,120,49,45,55,46,56,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,218,79,77,131,0,0,32,0,114,120,49,45,50,46,52,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,21,72,87,143,0,0,32,0,114,120,49,45,51,46,55,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,150,16,134,184,0,0,32,0,114,120,49,45,53,46,51,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,23,112,173,75,0,0,64,0,114,120,49,45,52,46,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,0,184,40,2,0,1,0,0,0,222,253,146,0,248,191,2,0,184,164,8,0,1,0,0,0,223,253,146,0,64,246,1,0,24,38,7,0,1,0,0,0,216,253,146,0,184,160,2,0,152,122,6,0,1,0,0,0,136,245,146,0,96,82,2,0,192,72,6,0,1,0,0,0,137,245,146,0,32,56,2,0,24,163,6,0,1,0,0,0,138,245,146,0,240,108,2,0,56,210,6,0,1,0,0,0,139,245,146,0,192,135,2,0,200,110,3,0,1,0,0,0,140,245,146,0,152,30,2,0,120,89,3,0,1,0,0,0,141,245,146,0,232,10,2,0,144,236,1,0,1,0,0,0,217,253,146,0,136,224,1,0,24,198,1,0,1,0,0,0,56,239,146,0,40,167,1,0,120,189,1,0,1,0,0,0,57,239,146,0,200,149,1,0,192,209,1,0,1,0,0,0,58,239,146,0,24,182,1,0,176,223,1,0,1,0,0,0,59,239,146,0,72,198,1,0,224,22,1,0,1,0,0,0,60,239,146,0,56,126,1,0,160,14,1,0,1,0,0,0,61,239,146,0,32,101,1,0,88,212,3,0,1,0,0,0,224,217,146,0,40,185,3,0,248,5,8,0,9,0,0,0,192,4,147,0,32,58,1,0,144,250,7,0,9,0,0,0,193,4,147,0,32,58,1,0,99,56,52,45,49,49,48,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,59,141,154,17,2,0,16,1,99,56,52,45,49,49,49,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,146,86,9,31,2,0,16,1,99,56,52,45,49,48,52,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,198,127,7,55,2,0,16,1,99,56,52,45,49,48,51,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,194,209,161,76,2,0,16,1,99,56,52,45,57,57,46,51,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,64,143,119,36,6,0,16,1,99,56,52,45,49,48,48,46,51,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,138,37,153,43,6,0,16,1,99,56,52,45,49,48,49,46,52,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,110,16,34,147,9,0,16,1,99,56,52,45,57,48,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,141,14,238,131,12,0,32,0,99,56,52,45,56,57,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,135,60,228,170,12,0,32,0,99,56,52,45,57,50,46,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,85,253,232,86,17,0,32,0,99,56,52,45,57,52,46,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,155,193,23,97,17,0,32,0,99,56,52,45,57,49,46,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,108,20,176,177,17,0,32,0,99,56,52,45,57,51,46,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,78,187,55,136,17,0,32,0,99,56,52,45,56,52,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,107,72,220,52,22,0,32,0,99,56,52,45,56,56,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,156,244,209,237,23,0,32,0,99,56,52,45,56,54,46,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,16,0,30,119,217,152,24,0,64,0,99,56,52,45,56,55,46,52,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,12,216,29,156,24,0,64,0,99,56,52,45,56,53,46,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,141,131,205,36,25,0,64,0,99,56,52,45,49,57,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,246,166,69,114,0,0,0,8,99,56,52,45,48,55,46,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,119,92,161,149,0,0,0,8,99,56,52,45,48,57,46,55,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,114,116,33,113,0,0,0,8,99,56,52,45,49,48,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,252,139,62,100,0,0,0,8,99,56,52,45,49,49,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,83,136,114,16,0,0,0,8,11,0,0,0,255,255,255,0,0,0,0,0,12,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,11,0,0,0,1,1,0,0,112,123,7,0,11,0,0,0,1,1,1,0,80,119,7,0,0,0,0,0,254,0,2,0,232,75,4,0,11,0,0,0,1,4,4,0,96,135,7,0,11,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,11,0,0,0,1,8,0,0,96,135,7,0,11,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,11,0,0,0,1,48,0,0,80,252,6,0,11,0,0,0,1,48,16,0,16,242,7,0,11,0,0,0,1,48,32,0,104,236,7,0,11,0,0,0,1,48,48,0,128,230,7,0,0,0,0,0,254,0,4,0,160,123,6,0,11,0,0,0,1,192,192,0,8,201,6,0,11,0,0,0,1,192,128,0,200,197,6,0,11,0,0,0,1,192,64,0,152,194,6,0,11,0,0,0,1,192,0,0,248,189,6,0,0,0,0,0,254,0,2,0,144,114,7,0,12,0,0,0,1,4,4,0,248,38,7,0,12,0,0,0,1,4,0,0,64,111,3,0,0,0,0,0,254,0,2,0,248,102,7,0,12,0,0,0,1,8,0,0,64,96,7,0,12,0,0,0,1,8,8,0,192,89,7,0,0,0,0,0,254,0,2,0,72,83,7,0,12,0,0,0,1,16,16,0,96,135,7,0,12,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,4,0,168,79,7,0,12,0,0,0,1,96,96,0,120,76,7,0,12,0,0,0,1,96,64,0,240,72,7,0,12,0,0,0,1,96,32,0,48,68,7,0,12,0,0,0,1,96,0,0,248,63,7,0,0,0,0,0,101,112,114,45,49,51,49,50,57,46,105,99,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,231,50,159,173,1,0,16,1,101,112,114,45,49,51,49,51,48,46,105,99,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,123,119,34,96,1,0,16,1,101,112,114,45,49,50,56,53,53,46,105,99,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,115,30,207,206,1,0,16,1,101,112,114,45,49,50,56,53,54,46,105,99,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,187,14,144,218,1,0,16,1,101,112,114,45,49,50,56,53,55,46,105,99,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,204,40,35,138,9,0,16,1,101,112,114,45,49,50,56,53,56,46,105,99,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,183,72,162,56,9,0,16,1,101,112,114,45,49,50,56,55,57,46,105,99,49,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,122,222,169,193,2,0,32,0,101,112,114,45,49,50,56,56,48,46,105,99,49,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,165,4,255,39,2,0,32,0,101,112,114,45,49,50,56,56,49,46,105,99,49,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,145,68,241,114,2,0,32,0,101,112,114,45,49,50,56,55,50,46,105,99,57,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,57,97,213,104,3,0,32,0,101,112,114,45,49,50,56,55,51,46,105,99,57,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,80,196,62,61,3,0,32,0,101,112,114,45,49,50,56,55,52,46,105,99,57,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,35,222,107,125,3,0,32,0,101,112,114,45,49,50,56,55,53,46,105,99,49,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,191,146,48,227,3,0,32,0,101,112,114,45,49,50,56,54,56,46,105,99,57,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,131,149,40,150,3,0,32,0,101,112,114,45,49,50,56,54,57,46,105,99,57,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,2,222,240,46,3,0,32,0,101,112,114,45,49,50,56,55,48,46,105,99,57,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,225,48,102,199,3,0,32,0,101,112,114,45,49,50,56,55,49,46,105,99,49,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,26,27,64,35,3,0,32,0,101,112,114,45,49,50,56,54,52,46,105,99,57,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,244,207,214,119,3,0,32,0,101,112,114,45,49,50,56,54,53,46,105,99,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,91,104,126,30,3,0,32,0,101,112,114,45,49,50,56,54,54,46,105,99,49,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,41,19,243,253,3,0,32,0,101,112,114,45,49,50,56,54,55,46,105,99,49,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,253,55,94,178,3,0,32,0,101,112,114,45,49,50,56,54,48,46,105,99,57,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,25,65,182,134,3,0,32,0,101,112,114,45,49,50,56,54,49,46,105,99,57,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,155,241,207,188,3,0,32,0,101,112,114,45,49,50,56,54,50,46,105,99,49,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,5,59,76,125,3,0,32,0,101,112,114,45,49,50,56,54,51,46,105,99,49,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,83,80,9,133,3,0,32,0,101,112,114,45,49,50,56,53,57,46,105,99,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,218,129,120,213,4,0,16,1,101,112,114,45,49,50,56,55,54,46,105,99,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,160,52,42,247,11,0,64,0,101,112,114,45,49,50,56,55,55,46,105,99,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,210,182,193,24,11,0,64,0,101,112,114,45,49,50,56,55,56,46,105,99,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,21,44,33,124,11,0,64,0,51,49,55,45,48,49,52,52,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,255,187,64,135,5,0,16,1,11,0,0,0,255,255,255,0,0,0,0,0,12,0,0,0,255,255,249,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,11,0,0,0,1,15,7,0,80,252,6,0,11,0,0,0,1,15,8,0,16,242,7,0,11,0,0,0,1,15,9,0,104,236,7,0,11,0,0,0,1,15,5,0,176,51,4,0,11,0,0,0,1,15,4,0,56,24,4,0,11,0,0,0,1,15,15,0,128,230,7,0,11,0,0,0,1,15,1,0,72,216,3,0,11,0,0,0,1,15,2,0,24,188,3,0,11,0,0,0,1,15,3,0,176,162,3,0,11,0,0,0,1,15,6,0,120,211,6,0,11,0,0,0,1,15,14,0,184,164,6,0,11,0,0,0,1,15,13,0,80,74,6,0,11,0,0,0,1,15,12,0,192,32,6,0,11,0,0,0,1,15,11,0,192,234,2,0,11,0,0,0,1,15,10,0,32,242,5,0,11,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,11,0,0,0,1,240,112,0,80,252,6,0,11,0,0,0,1,240,128,0,16,242,7,0,11,0,0,0,1,240,144,0,104,236,7,0,11,0,0,0,1,240,80,0,176,51,4,0,11,0,0,0,1,240,64,0,56,24,4,0,11,0,0,0,1,240,240,0,128,230,7,0,11,0,0,0,1,240,16,0,72,216,3,0,11,0,0,0,1,240,32,0,24,188,3,0,11,0,0,0,1,240,48,0,176,162,3,0,11,0,0,0,1,240,96,0,120,211,6,0,11,0,0,0,1,240,224,0,184,164,6,0,11,0,0,0,1,240,208,0,80,74,6,0,11,0,0,0,1,240,192,0,192,32,6,0,11,0,0,0,1,240,176,0,192,234,2,0,11,0,0,0,1,240,160,0,32,242,5,0,11,0,0,0,1,240,0,0,208,236,2,0,0,0,0,0,254,0,2,0,56,154,6,0,12,0,0,0,1,1,1,0,184,30,3,0,12,0,0,0,1,1,0,0,0,28,3,0,0,0,0,0,254,0,2,0,168,234,7,0,12,0,0,0,1,2,2,0,96,135,7,0,12,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,12,0,0,0,1,4,4,0,56,111,3,0,12,0,0,0,1,4,0,0,104,134,3,0,0,0,0,0,254,0,4,0,112,59,6,0,12,0,0,0,1,48,16,0,80,246,3,0,12,0,0,0,1,48,48,0,248,38,7,0,12,0,0,0,1,48,32,0,112,212,3,0,12,0,0,0,1,48,0,0,24,99,5,0,0,0,0,0,254,0,4,0,72,202,5,0,12,0,0,0,1,192,64,0,80,246,3,0,12,0,0,0,1,192,192,0,248,38,7,0,12,0,0,0,1,192,128,0,112,212,3,0,12,0,0,0,1,192,0,0,24,99,5,0,0,0,0,0,99,57,50,45,48,54,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,34,231,75,66,2,0,16,1,99,57,50,45,48,53,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,147,15,71,218,2,0,16,1,99,57,50,45,48,51,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,6,118,105,29,1,0,16,1,99,57,50,45,48,55,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,185,61,49,62,9,0,16,1,99,57,50,45,48,50,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,207,206,172,45,11,0,32,0,99,57,50,45,48,49,46,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,133,162,118,153,15,0,32,0,99,57,50,45,48,52,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,67,187,33,228,24,0,64,0,20,0,0,0,255,255,255,0,0,0,0,0,21,0,0,0,255,255,253,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,21,0,0,0,1,1,1,0,96,135,7,0,21,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,21,0,0,0,1,2,2,0,96,135,7,0,21,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,146,7,0,21,0,0,0,1,32,32,0,192,255,2,0,21,0,0,0,1,32,0,0,208,75,4,0,0,0,0,0,254,0,2,0,232,75,4,0,21,0,0,0,1,128,128,0,96,135,7,0,21,0,0,0,1,128,0,0,152,182,7,0,101,112,114,45,55,52,53,56,97,46,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,62,178,231,66,1,0,16,1,101,112,114,45,55,52,53,53,97,46,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,178,26,99,1,1,0,16,1,101,112,114,45,55,52,53,57,97,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,55,6,84,107,1,0,16,1,101,112,114,45,55,52,53,54,97,46,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,62,88,202,49,1,0,16,1,101,112,114,45,55,52,54,48,46,49,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,19,234,68,164,1,0,16,1,101,112,114,45,55,52,53,55,46,56,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,35,44,40,59,1,0,16,1,101,112,114,45,55,52,54,49,46,57,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,242,7,175,246,2,0,32,0,101,112,114,45,55,52,54,50,46,49,48,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,40,175,20,121,2,0,32,0,101,112,114,45,55,52,54,51,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,3,86,124,130,2,0,32,0,101,112,114,45,55,52,54,53,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,215,183,26,138,3,0,32,0,101,112,114,45,55,52,54,57,46,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,79,174,101,203,3,0,32,0,101,112,114,45,55,52,54,54,46,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,243,244,211,178,3,0,32,0,101,112,114,45,55,52,55,48,46,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,177,103,252,22,3,0,32,0,101,112,114,45,55,52,54,55,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,226,141,246,10,3,0,32,0,101,112,114,45,55,52,55,49,46,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,172,213,250,19,3,0,32,0,101,112,114,45,55,52,54,56,46,56,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,192,64,253,221,3,0,32,0,101,112,114,45,55,52,55,50,46,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,236,98,39,142,3,0,32,0,101,112,114,45,55,52,54,52,46,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,6,19,41,159,4,0,16,1,55,55,53,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,252,52,149,106,6,0,16,1,101,112,114,45,55,52,55,51,46,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,250,117,236,6,7,0,64,0,101,112,114,45,55,52,55,53,46,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,6,18,189,122,7,0,64,0,101,112,114,45,55,52,55,52,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,184,83,248,219,7,0,64,0,101,112,114,45,55,52,55,54,46,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,90,101,186,94,7,0,64,0,51,49,53,45,53,49,57,52,46,109,99,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,16,112,97,108,49,54,114,54,97,46,50,50,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,0,0,0,16,112,97,108,49,54,114,54,97,46,50,51,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,0,0,0,16,112,108,115,49,53,51,46,56,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,235,0,0,0,253,238,225,15,0,0,0,8,33,0,0,0,255,255,255,0,0,0,0,0,34,0,0,0,255,255,254,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,33,0,0,0,1,15,7,0,80,252,6,0,33,0,0,0,1,15,8,0,16,242,7,0,33,0,0,0,1,15,9,0,104,236,7,0,33,0,0,0,1,15,5,0,176,51,4,0,33,0,0,0,1,15,4,0,56,24,4,0,33,0,0,0,1,15,15,0,128,230,7,0,33,0,0,0,1,15,1,0,72,216,3,0,33,0,0,0,1,15,2,0,24,188,3,0,33,0,0,0,1,15,3,0,176,162,3,0,33,0,0,0,1,15,6,0,120,211,6,0,33,0,0,0,1,15,14,0,184,164,6,0,33,0,0,0,1,15,13,0,80,74,6,0,33,0,0,0,1,15,12,0,192,32,6,0,33,0,0,0,1,15,11,0,192,234,2,0,33,0,0,0,1,15,10,0,32,242,5,0,33,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,33,0,0,0,1,240,112,0,80,252,6,0,33,0,0,0,1,240,128,0,16,242,7,0,33,0,0,0,1,240,144,0,104,236,7,0,33,0,0,0,1,240,80,0,176,51,4,0,33,0,0,0,1,240,64,0,56,24,4,0,33,0,0,0,1,240,240,0,128,230,7,0,33,0,0,0,1,240,16,0,72,216,3,0,33,0,0,0,1,240,32,0,24,188,3,0,33,0,0,0,1,240,48,0,176,162,3,0,33,0,0,0,1,240,96,0,120,211,6,0,33,0,0,0,1,240,224,0,184,164,6,0,33,0,0,0,1,240,208,0,80,74,6,0,33,0,0,0,1,240,192,0,192,32,6,0,33,0,0,0,1,240,176,0,192,234,2,0,33,0,0,0,1,240,160,0,32,242,5,0,33,0,0,0,1,240,0,0,208,236,2,0,0,0,0,0,254,0,2,0,168,234,7,0,34,0,0,0,1,1,1,0,96,135,7,0,34,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,4,0,0,217,5,0,34,0,0,0,1,6,4,0,72,242,7,0,34,0,0,0,1,6,6,0,88,207,5,0,34,0,0,0,1,6,2,0,184,230,7,0,34,0,0,0,1,6,0,0,104,109,3,0,0,0,0,0,254,0,4,0,72,202,5,0,34,0,0,0,1,24,16,0,80,246,3,0,34,0,0,0,1,24,24,0,248,38,7,0,34,0,0,0,1,24,8,0,112,212,3,0,34,0,0,0,1,24,0,0,248,160,5,0,0,0,0,0,254,0,2,0,168,195,5,0,34,0,0,0,1,32,32,0,192,192,5,0,34,0,0,0,1,32,0,0,144,189,5,0,0,0,0,0,254,0,2,0,16,227,4,0,34,0,0,0,1,64,64,0,96,135,7,0,34,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,34,0,0,0,1,128,128,0,96,135,7,0,34,0,0,0,1,128,0,0,152,182,7,0,116,110,50,106,95,51,48,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,94,235,38,146,1,0,16,1,116,110,50,106,95,51,55,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,161,13,211,209,1,0,16,1,116,110,50,106,95,51,49,46,49,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,2,0,138,106,94,1,1,0,16,1,116,110,50,106,95,51,56,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,204,155,19,31,1,0,16,1,116,110,50,106,95,50,56,46,57,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,113,127,210,134,1,0,16,1,116,110,50,106,95,51,53,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,125,184,26,122,1,0,16,1,116,110,50,106,95,50,57,46,49,48,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,153,78,56,156,1,0,16,1,116,110,50,106,95,51,54,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,10,42,75,76,1,0,16,1,116,110,50,45,48,50,109,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,52,106,1,242,4,0,32,0,116,110,50,45,48,52,109,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,177,15,78,9,4,0,32,0,116,110,50,45,48,49,109,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,249,12,149,203,4,0,32,0,116,110,50,45,48,51,109,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,89,191,165,24,4,0,32,0,116,110,50,45,49,49,109,46,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,11,211,237,208,4,0,32,0,116,110,50,45,49,51,109,46,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,195,33,102,66,4,0,32,0,116,110,50,45,49,48,109,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,112,206,78,163,4,0,32,0,116,110,50,45,49,50,109,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,244,242,79,224,4,0,32,0,116,110,50,106,95,48,57,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,105,185,100,228,3,0,16,0,116,110,50,106,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,167,249,11,164,5,0,64,0,116,110,50,106,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,30,147,59,91,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,116,110,50,50,57,50,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,57,149,137,61,0,0,0,8,105,111,98,49,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,105,111,99,49,46,105,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,129,32,24,13,0,0,0,8,99,54,51,50,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,112,146,189,15,0,0,0,8,15,0,0,0,255,255,0,0,0,0,0,0,16,0,0,0,255,255,3,0,0,0,0,0,17,0,0,0,255,255,32,0,0,0,0,0,0,0,0,0,254,0,8,0,32,4,2,0,15,0,0,0,1,7,7,0,80,252,6,0,15,0,0,0,1,7,6,0,16,242,7,0,15,0,0,0,1,7,5,0,104,236,7,0,15,0,0,0,1,7,0,0,128,230,7,0,15,0,0,0,1,7,1,0,184,164,6,0,15,0,0,0,1,7,2,0,80,74,6,0,15,0,0,0,1,7,3,0,192,32,6,0,15,0,0,0,1,7,4,0,32,242,5,0,0,0,0,0,254,0,2,0,64,232,1,0,15,0,0,0,1,64,0,0,96,135,7,0,15,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,8,0,72,202,5,0,16,0,0,0,1,7,0,0,72,198,6,0,16,0,0,0,1,7,1,0,208,75,4,0,16,0,0,0,1,7,2,0,8,49,4,0,16,0,0,0,1,7,3,0,72,195,6,0,16,0,0,0,1,7,4,0,72,246,3,0,16,0,0,0,1,7,5,0,72,0,3,0,16,0,0,0,1,7,6,0,64,47,7,0,16,0,0,0,1,7,7,0,48,173,6,0,0,0,0,0,254,0,5,0,128,129,4,0,16,0,0,0,1,224,128,0,192,255,2,0,16,0,0,0,1,224,96,0,208,75,4,0,16,0,0,0,1,224,0,0,8,49,4,0,16,0,0,0,1,224,64,0,152,21,4,0,16,0,0,0,1,224,32,0,72,246,3,0,0,0,0,0,254,0,2,0,144,3,8,0,17,0,0,0,1,2,0,0,96,135,7,0,17,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,2,0,16,227,4,0,17,0,0,0,1,4,0,0,96,135,7,0,17,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,254,0,2,0,72,4,1,0,17,0,0,0,1,8,0,0,96,135,7,0,17,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,2,0,120,207,1,0,17,0,0,0,1,16,0,0,96,135,7,0,17,0,0,0,1,16,16,0,152,182,7,0,0,0,0,0,254,0,2,0,40,111,8,0,17,0,0,0,1,32,0,0,96,135,7,0,17,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,17,0,0,0,1,64,64,0,96,135,7,0,17,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,79,2,0,17,0,0,0,1,128,0,0,32,182,8,0,17,0,0,0,1,128,128,0,80,251,6,0,0,0,0,0,116,113,122,106,46,48,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,48,62,207,122,1,0,16,1,116,113,122,106,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,135,74,4,241,1,0,16,1,116,113,122,106,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,14,186,5,65,1,0,16,1,116,113,122,106,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,165,232,113,195,1,0,16,1,116,113,122,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,162,136,175,152,5,0,32,0,116,113,122,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,145,212,130,223,5,0,32,0,116,113,122,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,255,50,241,66,5,0,32,0,116,113,122,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,163,40,225,178,5,0,32,0,116,113,122,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,10,157,206,233,10,0,16,1,116,113,122,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,79,136,231,120,12,0,64,0,116,113,122,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,19,155,4,46,12,0,64,0,100,52,56,45,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,141,182,115,165,2,0,16,1,100,52,56,45,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,91,58,20,55,2,0,16,1,100,52,56,45,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,220,168,94,251,1,0,16,1,100,52,56,45,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,84,91,108,101,9,0,16,1,100,52,56,45,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,120,176,228,97,11,0,32,0,100,52,56,45,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,99,142,182,167,16,0,32,0,100,52,56,45,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,115,75,169,114,16,0,32,0,100,52,56,45,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,88,208,239,63,24,0,64,0,17,0,0,0,255,255,255,0,0,0,0,0,18,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,17,0,0,0,1,2,2,0,96,135,7,0,17,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,17,0,0,0,1,4,4,0,96,135,7,0,17,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,17,0,0,0,1,48,0,0,16,242,7,0,17,0,0,0,1,48,16,0,104,236,7,0,17,0,0,0,1,48,48,0,128,230,7,0,17,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,17,0,0,0,1,192,0,0,16,242,7,0,17,0,0,0,1,192,64,0,104,236,7,0,17,0,0,0,1,192,192,0,128,230,7,0,17,0,0,0,1,192,128,0,184,164,6,0,0,0,0,0,254,0,4,0,72,202,5,0,18,0,0,0,1,3,2,0,80,246,3,0,18,0,0,0,1,3,3,0,80,124,6,0,18,0,0,0,1,3,1,0,112,212,3,0,18,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,100,53,53,45,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,199,191,175,22,2,0,16,1,100,53,53,45,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,127,5,179,47,2,0,16,1,100,53,53,45,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,118,30,22,77,1,0,16,1,100,53,53,45,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,255,46,120,186,9,0,16,1,100,53,53,45,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,28,47,219,243,11,0,32,0,100,53,53,45,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,2,153,229,240,16,0,32,0,100,53,53,45,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,206,117,41,65,16,0,32,0,100,53,53,45,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,244,154,48,168,24,0,64,0,17,0,0,0,255,255,255,0,0,0,0,0,18,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,17,0,0,0,1,2,2,0,96,135,7,0,17,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,17,0,0,0,1,4,4,0,96,135,7,0,17,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,17,0,0,0,1,48,0,0,16,242,7,0,17,0,0,0,1,48,16,0,104,236,7,0,17,0,0,0,1,48,48,0,128,230,7,0,17,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,17,0,0,0,1,192,0,0,16,242,7,0,17,0,0,0,1,192,64,0,104,236,7,0,17,0,0,0,1,192,192,0,128,230,7,0,17,0,0,0,1,192,128,0,184,164,6,0,0,0,0,0,254,0,4,0,72,202,5,0,18,0,0,0,1,3,2,0,80,246,3,0,18,0,0,0,1,3,3,0,80,124,6,0,18,0,0,0,1,3,1,0,112,212,3,0,18,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,192,19,6,0,18,0,0,0,1,12,0,0,208,16,6,0,18,0,0,0,1,12,4,0,144,12,6,0,18,0,0,0,1,12,8,0,64,6,6,0,18,0,0,0,1,12,12,0,120,53,6,0,112,108,50,101,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,178,133,18,59,1,0,16,1,112,108,50,101,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,71,214,162,64,1,0,16,1,112,108,50,101,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,216,17,15,1,0,16,1,112,108,50,101,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,244,189,251,134,1,0,16,1,112,108,50,45,115,105,109,109,46,48,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,167,19,123,19,6,0,32,0,112,108,50,45,115,105,109,109,46,48,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,7,21,219,162,6,0,32,0,112,108,50,45,115,105,109,109,46,48,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,142,255,128,126,6,0,32,0,112,108,50,45,115,105,109,109,46,48,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,237,230,147,205,6,0,32,0,112,108,50,45,115,105,109,109,46,48,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,202,187,82,15,6,0,32,0,112,108,50,45,115,105,109,109,46,48,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,195,18,39,166,6,0,32,0,112,108,50,45,115,105,109,109,46,48,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,142,159,12,182,6,0,32,0,112,108,50,45,115,105,109,109,46,48,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,132,242,254,131,6,0,32,0,112,108,50,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,105,117,105,53,10,0,16,1,112,108,50,45,115,105,109,109,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,232,251,216,133,13,0,64,0,112,108,50,45,115,105,109,109,46,48,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,132,37,214,30,13,0,64,0,20,0,0,0,255,255,255,0,0,0,0,0,21,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,16,129,1,0,20,0,0,0,1,1,1,0,96,135,7,0,20,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,40,115,1,0,20,0,0,0,1,2,2,0,72,246,3,0,20,0,0,0,1,2,0,0,80,62,6,0,0,0,0,0,254,0,2,0,104,81,2,0,20,0,0,0,1,4,4,0,96,135,7,0,20,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,200,30,2,0,20,0,0,0,1,8,8,0,120,97,1,0,20,0,0,0,1,8,0,0,96,19,1,0,0,0,0,0,254,0,2,0,168,234,7,0,20,0,0,0,1,16,0,0,96,135,7,0,20,0,0,0,1,16,16,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,20,0,0,0,1,32,32,0,96,135,7,0,20,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,8,0,32,4,2,0,21,0,0,0,1,7,0,0,96,135,3,0,21,0,0,0,1,7,1,0,32,136,7,0,21,0,0,0,1,7,2,0,40,88,7,0,21,0,0,0,1,7,3,0,96,39,7,0,21,0,0,0,1,7,7,0,144,251,6,0,21,0,0,0,1,7,6,0,184,164,6,0,21,0,0,0,1,7,5,0,80,74,6,0,21,0,0,0,1,7,4,0,192,32,6,0,0,0,0,0,254,0,2,0,72,202,5,0,21,0,0,0,1,8,8,0,80,246,3,0,21,0,0,0,1,8,0,0,112,212,3,0,99,112,117,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,99,21,21,195,1,0,16,1,99,112,117,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,172,147,37,140,1,0,16,1,99,112,117,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,133,84,90,102,1,0,16,1,99,112,117,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,57,63,177,215,1,0,16,1,103,102,120,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,122,136,154,155,4,0,32,0,103,102,120,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,122,40,148,43,4,0,32,0,103,102,120,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,245,116,189,233,4,0,32,0,103,102,120,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,164,200,225,165,4,0,32,0,103,102,120,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,147,161,117,109,4,0,32,0,103,102,120,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,8,0,193,5,194,163,4,0,32,0,103,102,120,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,146,236,242,34,4,0,32,0,103,102,120,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,201,116,57,118,4,0,32,0,112,105,99,49,54,99,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,7,0,16,16,115,111,117,110,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,198,157,236,174,5,0,64,0,112,103,97,117,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,62,120,58,52,1,0,16,1,112,103,97,117,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,121,141,32,22,1,0,16,1,112,103,97,45,115,105,109,109,46,48,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,176,152,47,69,6,0,32,0,112,103,97,45,115,105,109,109,46,48,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,146,32,103,158,6,0,32,0,112,103,97,45,115,105,109,109,46,48,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,254,218,157,174,6,0,32,0,112,103,97,45,115,105,109,109,46,48,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,148,45,215,148,6,0,32,0,112,103,97,45,115,105,109,109,46,48,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,109,136,161,72,6,0,32,0,112,103,97,45,115,105,109,109,46,48,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,55,126,45,23,6,0,32,0,112,103,97,45,115,105,109,109,46,48,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,152,61,227,158,6,0,32,0,112,103,97,45,115,105,109,109,46,48,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,50,238,141,132,6,0,32,0,112,103,97,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,146,169,191,189,10,0,16,1,112,103,97,45,115,105,109,109,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,12,200,170,192,13,0,64,0,112,103,97,45,115,105,109,109,46,48,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,134,93,166,55,13,0,64,0,112,103,97,45,115,105,109,109,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,52,233,241,211,13,0,64,0,112,103,97,45,115,105,109,109,46,48,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,154,72,57,139,13,0,64,0,168,86,7,0,1,0,0,0,205,255,146,0,248,191,2,0,24,38,7,0,1,0,0,0,69,247,146,0,184,160,2,0,152,122,6,0,1,0,0,0,201,255,146,0,96,82,2,0,192,72,6,0,1,0,0,0,202,255,146,0,32,56,2,0,200,110,3,0,1,0,0,0,200,255,146,0,152,30,2,0,120,89,3,0,1,0,0,0,203,255,146,0,232,10,2,0,40,246,1,0,1,0,0,0,206,255,146,0,64,246,1,0,144,236,1,0,1,0,0,0,70,247,146,0,136,224,1,0,24,198,1,0,1,0,0,0,65,247,146,0,40,167,1,0,120,189,1,0,1,0,0,0,66,247,146,0,200,149,1,0,224,22,1,0,1,0,0,0,64,247,146,0,56,126,1,0,160,14,1,0,1,0,0,0,67,247,146,0,32,101,1,0,88,212,3,0,1,0,0,0,32,219,146,0,40,185,3,0,16,17,8,0,1,0,0,0,207,255,146,0,224,12,8,0,72,65,1,0,9,0,0,0,128,5,147,0,32,58,1,0,112,105,115,99,101,115,46,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,31,142,107,133,1,0,16,1,112,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,98,151,95,5,1,0,16,1,112,105,115,99,101,115,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,228,242,64,85,1,0,16,1,112,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,37,245,170,68,1,0,16,1,112,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,43,81,222,250,1,0,16,1,112,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,47,130,178,90,1,0,16,1,103,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,58,162,3,149,4,0,32,0,103,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,254,195,223,10,4,0,32,0,103,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,73,248,97,62,4,0,32,0,103,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,235,233,48,113,4,0,32,0,99,111,108,111,117,114,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,87,80,164,87,7,0,32,0,11,0,0,0,255,255,0,0,0,0,0,0,12,0,0,0,255,255,0,0,0,0,0,0,13,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,128,129,4,0,12,0,0,0,1,64,0,0,8,49,4,0,12,0,0,0,1,64,64,0,152,21,4,0,0,0,0,0,254,0,2,0,200,30,2,0,12,0,0,0,1,128,0,0,120,97,1,0,12,0,0,0,1,128,128,0,96,19,1,0,0,0,0,0,254,0,2,0,64,37,5,0,13,0,0,0,1,1,0,0,176,116,6,0,13,0,0,0,1,1,1,0,80,110,6,0,0,0,0,0,254,0,4,0,32,4,2,0,13,0,0,0,1,2,2,0,168,68,1,0,13,0,0,0,1,2,0,0,184,146,2,0,0,0,0,0,254,0,2,0,72,202,5,0,13,0,0,0,1,4,0,0,80,246,3,0,13,0,0,0,1,4,4,0,112,212,3,0,19,0,0,0,255,255,12,0,0,0,0,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,12,12,0,96,135,7,0,19,0,0,0,1,12,0,0,152,182,7,0,105,99,52,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,107,8,104,159,0,0,16,1,105,99,52,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,130,74,58,39,0,0,16,1,105,99,52,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,185,132,66,61,0,0,16,1,105,99,52,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,21,153,93,203,0,0,16,1,104,53,45,105,99,52,57,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,231,228,5,161,0,0,16,1,104,54,45,105,99,53,48,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,193,158,94,172,0,0,16,1,104,55,45,105,99,53,49,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,180,53,171,46,0,0,16,1,104,56,45,105,99,53,50,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,197,233,248,175,0,0,16,1,105,99,50,51,46,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,63,98,126,60,0,0,32,0,105,99,50,52,46,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,59,109,145,89,0,0,32,0,98,49,45,105,99,51,57,46,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,143,62,65,83,0,0,32,0,98,50,45,105,99,52,48,46,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,145,186,226,11,0,0,32,0,109,109,105,54,51,48,49,46,105,99,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,37,11,53,121,0,0,32,0,109,109,105,54,51,48,49,46,105,99,52,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,104,183,118,225,0,0,32,0,112,119,103,106,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,75,231,100,242,1,0,16,1,112,119,103,106,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,131,73,168,35,1,0,16,1,112,119,103,106,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,98,140,245,190,1,0,16,1,112,119,103,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,232,12,166,135,1,0,16,1,112,119,103,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,72,177,247,1,0,16,1,112,119,103,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,62,130,98,204,1,0,16,1,112,119,103,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,166,92,200,221,1,0,16,1,112,119,103,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,40,251,196,7,1,0,16,1,112,119,103,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,142,224,143,174,5,0,32,0,112,119,103,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,88,15,86,219,5,0,32,0,112,119,103,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,148,91,71,188,5,0,32,0,112,119,103,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,247,159,67,7,5,0,32,0,112,119,103,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,99,186,249,195,5,0,32,0,112,119,103,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,123,14,91,129,5,0,32,0,112,119,103,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,27,199,9,1,5,0,32,0,112,119,103,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,190,255,117,235,5,0,32,0,112,119,103,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,228,192,165,24,10,0,16,1,112,119,103,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,166,255,223,201,10,0,16,1,112,119,103,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,51,116,143,167,12,0,64,0,112,119,103,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,208,142,67,119,12,0,64,0,168,86,7,0,1,0,0,0,84,0,147,0,248,191,2,0,24,38,7,0,1,0,0,0,189,247,146,0,184,160,2,0,56,210,6,0,1,0,0,0,80,0,147,0,192,135,2,0,24,163,6,0,1,0,0,0,81,0,147,0,240,108,2,0,152,122,6,0,1,0,0,0,82,0,147,0,96,82,2,0,192,72,6,0,1,0,0,0,83,0,147,0,32,56,2,0,200,110,3,0,1,0,0,0,87,0,147,0,152,30,2,0,40,246,1,0,1,0,0,0,85,0,147,0,64,246,1,0,144,236,1,0,1,0,0,0,190,247,146,0,136,224,1,0,176,223,1,0,1,0,0,0,184,247,146,0,72,198,1,0,192,209,1,0,1,0,0,0,185,247,146,0,24,182,1,0,24,198,1,0,1,0,0,0,186,247,146,0,40,167,1,0,120,189,1,0,1,0,0,0,187,247,146,0,200,149,1,0,224,22,1,0,1,0,0,0,191,247,146,0,56,126,1,0,88,212,3,0,1,0,0,0,128,219,146,0,40,185,3,0,72,65,1,0,9,0,0,0,200,5,147,0,32,58,1,0,48,50,1,0,9,0,0,0,201,5,147,0,32,58,1,0,224,41,1,0,9,0,0,0,202,5,147,0,32,58,1,0,168,169,1,0,9,0,0,0,203,5,147,0,32,58,1,0,101,112,114,45,49,49,55,52,54,97,46,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,244,202,241,176,1,0,16,1,101,112,114,45,49,49,55,52,53,97,46,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,205,32,151,168,1,0,16,1,101,112,114,45,49,49,55,52,56,46,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,171,108,167,130,1,0,16,1,101,112,114,45,49,49,55,52,55,46,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,229,236,150,151,1,0,16,1,101,112,114,45,49,49,55,53,50,46,56,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,17,129,187,182,9,0,16,1,101,112,114,45,49,49,55,53,49,46,56,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,17,3,13,127,9,0,16,1,101,112,114,45,49,49,55,53,48,98,46,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,48,206,20,188,17,0,16,1,101,112,114,45,49,49,55,52,57,98,46,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,104,85,56,158,17,0,16,1,101,112,114,45,49,49,55,57,49,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,10,145,178,54,3,0,32,0,101,112,114,45,49,49,55,56,57,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,43,141,111,184,3,0,32,0,101,112,114,45,49,49,55,57,50,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,110,175,92,200,3,0,32,0,101,112,114,45,49,49,55,57,48,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,102,78,86,42,3,0,32,0,101,112,114,45,49,49,55,53,55,46,54,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,120,196,109,228,18,0,32,0,101,112,114,45,49,49,55,53,56,46,55,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,135,92,67,91,18,0,32,0,101,112,114,45,49,49,55,55,51,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,88,87,93,27,18,0,32,0,101,112,114,45,49,49,55,55,52,46,55,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,112,193,160,44,18,0,32,0,101,112,114,45,49,49,55,53,57,46,56,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,246,17,129,172,18,0,32,0,101,112,114,45,49,49,55,54,48,46,49,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,249,42,40,145,18,0,32,0,101,112,114,45,49,49,55,55,53,46,56,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,147,87,34,72,18,0,32,0,101,112,114,45,49,49,55,55,54,46,49,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,152,97,196,120,18,0,32,0,101,112,114,45,49,49,55,54])
.concat([49,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,101,208,165,186,18,0,32,0,101,112,114,45,49,49,55,54,50,46,55,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,165,247,26,29,18,0,32,0,101,112,114,45,49,49,55,55,55,46,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,50,221,98,150,18,0,32,0,101,112,114,45,49,49,55,55,56,46,55,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,148,116,251,45,18,0,32,0,101,112,114,45,49,49,55,54,51,46,56,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,7,52,226,30,18,0,32,0,101,112,114,45,49,49,55,54,52,46,49,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,94,48,89,232,18,0,32,0,101,112,114,45,49,49,55,55,57,46,56,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,147,215,156,164,18,0,32,0,101,112,114,45,49,49,55,56,48,46,49,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,129,237,20,213,18,0,32,0,101,112,114,45,49,49,55,54,53,46,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,255,45,158,100,18,0,32,0,101,112,114,45,49,49,55,54,54,46,55,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,252,183,47,217,18,0,32,0,101,112,114,45,49,49,55,56,49,46,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,205,212,146,150,18,0,32,0,101,112,114,45,49,49,55,56,50,46,54,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,67,187,19,201,18,0,32,0,101,112,114,45,49,49,55,54,55,46,56,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,84,208,138,31,18,0,32,0,101,112,114,45,49,49,55,54,56,46,49,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,83,64,44,219,18,0,32,0,101,112,114,45,49,49,55,56,51,46,56,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,7,144,24,109,18,0,32,0,101,112,114,45,49,49,55,56,52,46,49,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,100,253,245,87,18,0,32,0,101,112,114,45,49,49,55,54,57,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,81,171,240,40,18,0,32,0,101,112,114,45,49,49,55,55,48,46,55,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,169,126,85,215,18,0,32,0,101,112,114,45,49,49,55,56,53,46,54,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,196,50,239,230,18,0,32,0,101,112,114,45,49,49,55,56,54,46,54,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,157,180,102,32,18,0,32,0,101,112,114,45,49,49,55,55,49,46,56,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,24,86,99,103,18,0,32,0,101,112,114,45,49,49,55,55,50,46,49,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,58,141,121,15,18,0,32,0,101,112,114,45,49,49,55,56,55,46,55,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,18,220,49,230,18,0,32,0,101,112,114,45,49,49,55,56,56,46,49,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,110,198,100,132,18,0,32,0,101,112,114,45,49,49,56,57,57,46,49,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,137,168,159,237,4,0,16,1,109,112,114,45,49,49,55,53,52,46,49,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,132,132,235,235,11,0,64,0,101,112,114,45,49,49,55,53,54,46,49,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,138,63,228,18,11,0,64,0,101,112,114,45,49,49,55,53,53,46,49,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,68,18,219,194,11,0,64,0,101,112,114,45,49,49,56,57,53,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,253,166,153,238,16,0,0,8,101,112,114,45,49,49,56,57,54,46,105,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,21,192,235,75,16,0,0,8,101,112,114,45,49,49,56,57,55,46,105,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,149,203,99,68,16,0,0,8,101,112,114,45,49,49,56,57,56,46,105,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,103,215,25,93,16,0,0,8,10,0,0,0,255,255,234,0,0,0,0,0,11,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,3,0,200,30,2,0,10,0,0,0,1,3,3,0,120,247,1,0,10,0,0,0,1,3,2,0,248,133,8,0,10,0,0,0,1,3,1,0,96,128,8,0,0,0,0,0,254,0,2,0,168,234,7,0,10,0,0,0,1,4,4,0,96,135,7,0,10,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,112,123,8,0,10,0,0,0,1,16,0,0,192,255,2,0,10,0,0,0,1,16,16,0,208,75,4,0,0,0,0,0,254,0,2,0,104,159,3,0,10,0,0,0,1,32,0,0,56,111,3,0,10,0,0,0,1,32,32,0,104,134,3,0,0,0,0,0,254,0,4,0,72,202,5,0,10,0,0,0,1,192,128,0,80,246,3,0,10,0,0,0,1,192,192,0,248,38,7,0,10,0,0,0,1,192,64,0,112,212,3,0,10,0,0,0,1,192,0,0,248,160,5,0,0,0,0,0,254,0,16,0,200,87,7,0,11,0,0,0,1,15,7,0,80,252,6,0,11,0,0,0,1,15,8,0,16,242,7,0,11,0,0,0,1,15,9,0,104,236,7,0,11,0,0,0,1,15,5,0,176,51,4,0,11,0,0,0,1,15,4,0,56,24,4,0,11,0,0,0,1,15,15,0,128,230,7,0,11,0,0,0,1,15,1,0,72,216,3,0,11,0,0,0,1,15,2,0,24,188,3,0,11,0,0,0,1,15,3,0,176,162,3,0,11,0,0,0,1,15,6,0,120,211,6,0,11,0,0,0,1,15,14,0,184,164,6,0,11,0,0,0,1,15,13,0,80,74,6,0,11,0,0,0,1,15,12,0,192,32,6,0,11,0,0,0,1,15,11,0,192,234,2,0,11,0,0,0,1,15,10,0,32,242,5,0,11,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,11,0,0,0,1,240,112,0,80,252,6,0,11,0,0,0,1,240,128,0,16,242,7,0,11,0,0,0,1,240,144,0,104,236,7,0,11,0,0,0,1,240,80,0,176,51,4,0,11,0,0,0,1,240,64,0,56,24,4,0,11,0,0,0,1,240,240,0,128,230,7,0,11,0,0,0,1,240,16,0,72,216,3,0,11,0,0,0,1,240,32,0,24,188,3,0,11,0,0,0,1,240,48,0,176,162,3,0,11,0,0,0,1,240,96,0,120,211,6,0,11,0,0,0,1,240,224,0,184,164,6,0,11,0,0,0,1,240,208,0,80,74,6,0,11,0,0,0,1,240,192,0,192,32,6,0,11,0,0,0,1,240,176,0,192,234,2,0,11,0,0,0,1,240,160,0,32,242,5,0,11,0,0,0,1,240,0,0,208,236,2,0,101,112,114,45,49,49,57,48,49,46,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,232,75,116,22,1,0,16,1,101,112,114,45,49,49,57,48,48,46,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,6,13,23,10,1,0,16,1,101,112,114,45,49,49,55,52,56,46,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,171,108,167,130,1,0,16,1,101,112,114,45,49,49,55,52,55,46,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,229,236,150,151,1,0,16,1,101,112,114,45,49,49,57,48,53,46,56,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,129,246,28,9,0,16,1,101,112,114,45,49,49,57,48,52,46,56,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,129,54,153,187,9,0,16,1,101,112,114,45,49,49,57,48,51,46,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,17,244,4,208,17,0,16,1,101,112,114,45,49,49,57,48,50,46,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,8,142,2,232,17,0,16,1,101,112,114,45,49,49,55,57,49,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,10,145,178,54,3,0,32,0,101,112,114,45,49,49,55,56,57,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,43,141,111,184,3,0,32,0,101,112,114,45,49,49,55,57,50,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,110,175,92,200,3,0,32,0,101,112,114,45,49,49,55,57,48,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,102,78,86,42,3,0,32,0,101,112,114,45,49,49,55,53,55,46,54,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,120,196,109,228,18,0,32,0,101,112,114,45,49,49,55,53,56,46,55,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,135,92,67,91,18,0,32,0,101,112,114,45,49,49,55,55,51,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,88,87,93,27,18,0,32,0,101,112,114,45,49,49,55,55,52,46,55,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,112,193,160,44,18,0,32,0,101,112,114,45,49,49,55,53,57,46,56,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,246,17,129,172,18,0,32,0,101,112,114,45,49,49,55,54,48,46,49,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,249,42,40,145,18,0,32,0,101,112,114,45,49,49,55,55,53,46,56,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,147,87,34,72,18,0,32,0,101,112,114,45,49,49,55,55,54,46,49,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,152,97,196,120,18,0,32,0,101,112,114,45,49,49,55,54,49,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,101,208,165,186,18,0,32,0,101,112,114,45,49,49,55,54,50,46,55,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,165,247,26,29,18,0,32,0,101,112,114,45,49,49,55,55,55,46,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,50,221,98,150,18,0,32,0,101,112,114,45,49,49,55,55,56,46,55,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,148,116,251,45,18,0,32,0,101,112,114,45,49,49,55,54,51,46,56,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,7,52,226,30,18,0,32,0,101,112,114,45,49,49,55,54,52,46,49,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,94,48,89,232,18,0,32,0,101,112,114,45,49,49,55,55,57,46,56,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,147,215,156,164,18,0,32,0,101,112,114,45,49,49,55,56,48,46,49,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,129,237,20,213,18,0,32,0,101,112,114,45,49,49,55,54,53,46,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,255,45,158,100,18,0,32,0,101,112,114,45,49,49,55,54,54,46,55,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,252,183,47,217,18,0,32,0,101,112,114,45,49,49,55,56,49,46,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,205,212,146,150,18,0,32,0,101,112,114,45,49,49,55,56,50,46,54,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,67,187,19,201,18,0,32,0,101,112,114,45,49,49,55,54,55,46,56,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,84,208,138,31,18,0,32,0,101,112,114,45,49,49,55,54,56,46,49,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,83,64,44,219,18,0,32,0,101,112,114,45,49,49,55,56,51,46,56,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,7,144,24,109,18,0,32,0,101,112,114,45,49,49,55,56,52,46,49,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,100,253,245,87,18,0,32,0,101,112,114,45,49,49,55,54,57,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,81,171,240,40,18,0,32,0,101,112,114,45,49,49,55,55,48,46,55,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,169,126,85,215,18,0,32,0,101,112,114,45,49,49,55,56,53,46,54,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,196,50,239,230,18,0,32,0,101,112,114,45,49,49,55,56,54,46,54,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,157,180,102,32,18,0,32,0,101,112,114,45,49,49,55,55,49,46,56,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,24,86,99,103,18,0,32,0,101,112,114,45,49,49,55,55,50,46,49,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,58,141,121,15,18,0,32,0,101,112,114,45,49,49,55,56,55,46,55,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,18,220,49,230,18,0,32,0,101,112,114,45,49,49,55,56,56,46,49,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,110,198,100,132,18,0,32,0,101,112,114,45,49,49,56,57,57,46,49,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,137,168,159,237,4,0,16,1,109,112,114,45,49,49,55,53,52,46,49,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,132,132,235,235,11,0,64,0,101,112,114,45,49,49,55,53,54,46,49,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,138,63,228,18,11,0,64,0,101,112,114,45,49,49,55,53,53,46,49,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,68,18,219,194,11,0,64,0,101,112,114,45,49,49,56,57,53,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,253,166,153,238,16,0,0,8,101,112,114,45,49,49,56,57,54,46,105,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,21,192,235,75,16,0,0,8,101,112,114,45,49,49,56,57,55,46,105,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,149,203,99,68,16,0,0,8,101,112,114,45,49,49,56,57,56,46,105,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,103,215,25,93,16,0,0,8,10,0,0,0,255,255,234,0,0,0,0,0,11,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,3,0,200,30,2,0,10,0,0,0,1,3,3,0,120,247,1,0,10,0,0,0,1,3,2,0,120,97,1,0,10,0,0,0,1,3,1,0,96,128,8,0,0,0,0,0,254,0,2,0,168,234,7,0,10,0,0,0,1,4,4,0,96,135,7,0,10,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,112,123,8,0,10,0,0,0,1,16,0,0,192,255,2,0,10,0,0,0,1,16,16,0,208,75,4,0,0,0,0,0,254,0,2,0,104,159,3,0,10,0,0,0,1,32,0,0,56,111,3,0,10,0,0,0,1,32,32,0,104,134,3,0,0,0,0,0,254,0,4,0,72,202,5,0])
.concat([10,0,0,0,1,192,128,0,80,246,3,0,10,0,0,0,1,192,192,0,248,38,7,0,10,0,0,0,1,192,64,0,112,212,3,0,10,0,0,0,1,192,0,0,248,160,5,0,0,0,0,0,254,0,16,0,200,87,7,0,11,0,0,0,1,15,7,0,80,252,6,0,11,0,0,0,1,15,8,0,16,242,7,0,11,0,0,0,1,15,9,0,104,236,7,0,11,0,0,0,1,15,5,0,176,51,4,0,11,0,0,0,1,15,4,0,56,24,4,0,11,0,0,0,1,15,15,0,128,230,7,0,11,0,0,0,1,15,1,0,72,216,3,0,11,0,0,0,1,15,2,0,24,188,3,0,11,0,0,0,1,15,3,0,176,162,3,0,11,0,0,0,1,15,6,0,120,211,6,0,11,0,0,0,1,15,14,0,184,164,6,0,11,0,0,0,1,15,13,0,80,74,6,0,11,0,0,0,1,15,12,0,192,32,6,0,11,0,0,0,1,15,11,0,192,234,2,0,11,0,0,0,1,15,10,0,32,242,5,0,11,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,11,0,0,0,1,240,112,0,80,252,6,0,11,0,0,0,1,240,128,0,16,242,7,0,11,0,0,0,1,240,144,0,104,236,7,0,11,0,0,0,1,240,80,0,176,51,4,0,11,0,0,0,1,240,64,0,56,24,4,0,11,0,0,0,1,240,240,0,128,230,7,0,11,0,0,0,1,240,16,0,72,216,3,0,11,0,0,0,1,240,32,0,24,188,3,0,11,0,0,0,1,240,48,0,176,162,3,0,11,0,0,0,1,240,96,0,120,211,6,0,11,0,0,0,1,240,224,0,184,164,6,0,11,0,0,0,1,240,208,0,80,74,6,0,11,0,0,0,1,240,192,0,192,32,6,0,11,0,0,0,1,240,176,0,192,234,2,0,11,0,0,0,1,240,160,0,32,242,5,0,11,0,0,0,1,240,0,0,208,236,2,0,101,112,114,45,49,50,48,49,55,46,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,34,3,25,49,1,0,16,1,101,112,114,45,49,50,48,49,54,46,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,166,100,159,73,1,0,16,1,101,112,114,45,49,49,55,52,56,46,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,171,108,167,130,1,0,16,1,101,112,114,45,49,49,55,52,55,46,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,229,236,150,151,1,0,16,1,101,112,114,45,49,49,57,48,53,46,56,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,129,246,28,9,0,16,1,101,112,114,45,49,49,57,48,52,46,56,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,129,54,153,187,9,0,16,1,101,112,114,45,49,50,48,49,57,46,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,182,215,20,229,17,0,16,1,101,112,114,45,49,50,48,49,56,46,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,175,127,63,10,17,0,16,1,101,112,114,45,49,49,55,57,49,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,10,145,178,54,3,0,32,0,101,112,114,45,49,49,55,56,57,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,43,141,111,184,3,0,32,0,101,112,114,45,49,49,55,57,50,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,110,175,92,200,3,0,32,0,101,112,114,45,49,49,55,57,48,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,102,78,86,42,3,0,32,0,101,112,114,45,49,49,55,53,55,46,54,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,120,196,109,228,18,0,32,0,101,112,114,45,49,49,55,53,56,46,55,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,135,92,67,91,18,0,32,0,101,112,114,45,49,49,55,55,51,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,88,87,93,27,18,0,32,0,101,112,114,45,49,49,55,55,52,46,55,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,112,193,160,44,18,0,32,0,101,112,114,45,49,49,55,53,57,46,56,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,246,17,129,172,18,0,32,0,101,112,114,45,49,49,55,54,48,46,49,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,249,42,40,145,18,0,32,0,101,112,114,45,49,49,55,55,53,46,56,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,147,87,34,72,18,0,32,0,101,112,114,45,49,49,55,55,54,46,49,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,152,97,196,120,18,0,32,0,101,112,114,45,49,49,55,54,49,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,101,208,165,186,18,0,32,0,101,112,114,45,49,49,55,54,50,46,55,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,165,247,26,29,18,0,32,0,101,112,114,45,49,49,55,55,55,46,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,50,221,98,150,18,0,32,0,101,112,114,45,49,49,55,55,56,46,55,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,148,116,251,45,18,0,32,0,101,112,114,45,49,49,55,54,51,46,56,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,7,52,226,30,18,0,32,0,101,112,114,45,49,49,55,54,52,46,49,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,94,48,89,232,18,0,32,0,101,112,114,45,49,49,55,55,57,46,56,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,147,215,156,164,18,0,32,0,101,112,114,45,49,49,55,56,48,46,49,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,129,237,20,213,18,0,32,0,101,112,114,45,49,49,55,54,53,46,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,255,45,158,100,18,0,32,0,101,112,114,45,49,49,55,54,54,46,55,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,252,183,47,217,18,0,32,0,101,112,114,45,49,49,55,56,49,46,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,205,212,146,150,18,0,32,0,101,112,114,45,49,49,55,56,50,46,54,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,67,187,19,201,18,0,32,0,101,112,114,45,49,49,55,54,55,46,56,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,84,208,138,31,18,0,32,0,101,112,114,45,49,49,55,54,56,46,49,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,83,64,44,219,18,0,32,0,101,112,114,45,49,49,55,56,51,46,56,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,7,144,24,109,18,0,32,0,101,112,114,45,49,49,55,56,52,46,49,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,100,253,245,87,18,0,32,0,101,112,114,45,49,49,55,54,57,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,81,171,240,40,18,0,32,0,101,112,114,45,49,49,55,55,48,46,55,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,169,126,85,215,18,0,32,0,101,112,114,45,49,49,55,56,53,46,54,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,196,50,239,230,18,0,32,0,101,112,114,45,49,49,55,56,54,46,54,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,157,180,102,32,18,0,32,0,101,112,114,45,49,49,55,55,49,46,56,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,24,86,99,103,18,0,32,0,101,112,114,45,49,49,55,55,50,46,49,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,58,141,121,15,18,0,32,0,101,112,114,45,49,49,55,56,55,46,55,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,18,220,49,230,18,0,32,0,101,112,114,45,49,49,55,56,56,46,49,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,110,198,100,132,18,0,32,0,101,112,114,45,49,49,56,57,57,46,49,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,137,168,159,237,4,0,16,1,109,112,114,45,49,49,55,53,52,46,49,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,132,132,235,235,11,0,64,0,101,112,114,45,49,49,55,53,54,46,49,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,138,63,228,18,11,0,64,0,101,112,114,45,49,49,55,53,53,46,49,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,68,18,219,194,11,0,64,0,101,112,114,45,49,49,56,57,53,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,253,166,153,238,16,0,0,8,101,112,114,45,49,49,56,57,54,46,105,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,21,192,235,75,16,0,0,8,101,112,114,45,49,49,56,57,55,46,105,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,149,203,99,68,16,0,0,8,101,112,114,45,49,49,56,57,56,46,105,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,103,215,25,93,16,0,0,8,18,0,0,0,255,255,255,0,0,0,0,0,19,0,0,0,255,255,255,0,0,0,0,0,18,0,0,0,254,0,2,0,152,128,8,0,18,0,0,0,1,1,0,0,8,49,4,0,18,0,0,0,1,1,1,0,152,21,4,0,18,0,0,0,254,0,2,0,168,234,7,0,18,0,0,0,1,2,0,0,96,135,7,0,18,0,0,0,1,2,2,0,152,182,7,0,18,0,0,0,254,0,2,0,152,123,8,0,18,0,0,0,1,4,0,0,144,117,8,0,18,0,0,0,1,4,4,0,232,74,4,0,18,0,0,0,254,0,2,0,208,20,3,0,18,0,0,0,1,8,8,0,72,95,8,0,18,0,0,0,1,8,0,0,0,88,8,0,18,0,0,0,254,0,4,0,72,202,5,0,18,0,0,0,1,48,48,0,80,246,3,0,18,0,0,0,1,48,32,0,248,38,7,0,18,0,0,0,1,48,16,0,112,212,3,0,18,0,0,0,1,48,0,0,248,160,5,0,18,0,0,0,254,0,4,0,32,4,2,0,18,0,0,0,1,192,0,0,240,12,2,0,18,0,0,0,1,192,64,0,160,36,8,0,18,0,0,0,1,192,192,0,208,239,7,0,18,0,0,0,1,192,128,0,120,187,7,0,19,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,1,1,0,96,135,7,0,19,0,0,0,1,1,0,0,152,182,7,0,19,0,0,0,254,0,4,0,232,81,8,0,19,0,0,0,1,48,48,0,16,208,8,0,19,0,0,0,1,48,32,0,248,81,6,0,19,0,0,0,1,48,16,0,176,64,8,0,19,0,0,0,1,48,0,0,128,65,6,0,19,0,0,0,254,0,2,0,128,77,8,0,19,0,0,0,1,64,0,0,8,49,4,0,19,0,0,0,1,64,64,0,152,21,4,0,19,0,0,0,254,0,2,0,136,71,8,0,19,0,0,0,1,128,128,0,248,81,6,0,19,0,0,0,1,128,0,0,176,64,8,0,41,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,232,75,4,0,41,0,0,0,1,128,128,0,96,135,7,0,41,0,0,0,1,128,0,0,152,182,7,0,101,112,114,45,49,49,56,55,49,46,97,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,165,206,156,15,1,0,16,1,101,112,114,45,49,49,56,55,48,46,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,207,235,67,223,1,0,16,1,111,112,114,45,49,49,56,53,52,46,98,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,108,11,28,211,2,0,32,0,111,112,114,45,49,49,56,53,53,46,98,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,180,98,135,183,2,0,32,0,111,112,114,45,49,49,56,53,54,46,98,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,102,246,73,234,2,0,32,0,111,112,114,45,49,49,56,54,50,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,39,71,233,182,3,0,32,0,111,112,114,45,49,49,56,54,53,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,213,213,232,23,3,0,32,0,111,112,114,45,49,49,56,54,51,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,152,0,103,62,3,0,32,0,111,112,114,45,49,49,56,54,54,46,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,204,113,235,80,3,0,32,0,111,112,114,45,49,49,56,54,52,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,168,60,115,5,3,0,32,0,111,112,114,45,49,49,56,54,55,46,98,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,151,150,228,129,3,0,32,0,101,112,114,45,49,49,56,53,55,46,97,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,6,220,158,120,4,0,16,1,101,112,114,45,49,49,56,53,56,46,97,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,24,0,171,8,8,0,64,0,101,112,114,45,49,49,56,53,57,46,97,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,27,224,115,134,8,0,64,0,101,112,114,45,49,49,56,54,48,46,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,70,55,38,16,8,0,64,0,101,112,114,45,49,49,56,54,49,46,97,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,113,74,181,56,8,0,64,0,51,49,55,45,48,48,56,48,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,111,1,45,34,5,0,16,1,23,0,0,0,255,255,240,0,0,0,0,0,24,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,168,234,7,0,23,0,0,0,1,1,1,0,96,135,7,0,23,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,8,0,184,127,3,0,23,0,0,0,1,14,6,0,184,230,7,0,23,0,0,0,1,14,10,0,72,123,3,0,23,0,0,0,1,14,12,0,152,120,3,0,23,0,0,0,1,14,14,0,136,120,6,0,23,0,0,0,1,14,8,0,160,118,3,0,23,0,0,0,1,14,4,0,176,114,3,0,23,0,0,0,1,14,2,0,32,112,3,0,23,0,0,0,1,14,0,0,104,109,3,0,0,0,0,0,254,0,4,0,112,107,3,0,23,0,0,0,1,48,32,0,80,246,3,0,23,0,0,0,1,48,48,0,248,38,7,0,23,0,0,0,1,48,16,0,112,212,3,0,23,0,0,0,1,48,0,0,248,160,5,0,0,0,0,0,254,0,4,0,72,202,5,0,23,0,0,0,1,192,128,0,80,246,3,0,23,0,0,0,1,192,192,0,248,38,7,0,23,0,0,0,1,192,64,0,112,212,3,0,23,0,0,0,1,192,0,0,248,160,5,0,0,0,0,0,254,0,16,0,200,87,7,0,24,0,0,0,1,15,7,0,80,252,6,0,24,0,0,0,1,15,8,0,16,242,7,0,24,0,0,0,1,15,9,0,104,236,7,0,24,0,0,0,1,15,5,0,176,51,4,0,24,0,0,0,1,15,4,0,56,24,4,0,24,0,0,0,1,15,15,0,128,230,7,0,24,0,0,0,1,15,1,0,72,216,3,0,24,0,0,0,1,15,2,0,24,188,3,0,24,0,0,0,1,15,3,0,176,162,3,0,24,0,0,0,1,15,6,0,120,211,6,0,24,0,0,0,1,15,14,0,184,164,6,0,24,0,0,0,1,15,13,0,80,74,6,0,24,0,0,0,1,15,12,0,192,32,6,0,24,0,0,0,1,15,11,0,192,234,2,0,24,0,0,0,1,15,10,0,32,242,5,0,24,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,24,0,0,0,1,240,112,0,80,252,6,0,24,0,0,0,1,240,128,0,16,242,7,0,24,0,0,0,1,240,144,0,104,236,7,0,24,0,0,0,1,240,80,0,176,51,4,0,24,0,0,0,1,240,64,0,56,24,4,0,24,0,0,0,1,240,240,0,128,230,7,0,24,0,0,0,1,240,16,0,72,216,3,0,24,0,0,0,1,240,32,0,24,188,3,0,24,0,0,0,1,240,48,0,176,162,3,0,24,0,0,0,1,240,96,0,120,211,6,0,24,0,0,0,1,240,224,0,184,164,6,0,24,0,0,0,1,240,208,0,80,74,6,0,24,0,0,0,1,240,192,0,192,32,6,0,24,0,0,0,1,240,176,0,192,234,2,0,24,0,0,0,1,240,160,0,32,242,5,0,24,0,0,0,1,240,0,0,208,236,2,0,112,97,51,101,95,49,55,46,49,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,50,29,4,215,2,0,16,1,112,97,51,101,95,49,54,46,49,48,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,131,164,233,27,2,0,16,1,112,97,51,45,48,49,109,46,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,44,21,138,6,4,0,32,0,112,97,51,45,48,55,109,46,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,157,97,74,58,4,0,32,0,112,97,51,95,49,49,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,162,35,20,203,3,0,16,0,112,97,51,95,48,53,46,49,48,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,93,13,161,115,5,0,64,0,112,97,51,95,48,54,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,130,79,250,175,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,99,112,49,98,49,102,46,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,227,184,121,57,0,0,0,8,99,112,49,98,56,107,46,56,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,122,234,82,138,0,0,0,8,99,112,49,98,57,107,46,57,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,195,189,84,167,0,0,0,8,105,111,99,49,46,105,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,129,32,24,13,0,0,0,8,99,54,51,50,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,112,146,189,15,0,0,0,8,49,55,46,49,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,233,37,36,246,2,0,16,1,49,54,46,49,48,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,103,234,105,113,2,0,16,1,49,46,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,44,21,138,6,4,0,32,0,55,46,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,157,97,74,58,4,0,32,0,49,49,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,162,35,20,203,3,0,16,0,53,46,49,48,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,93,13,161,115,5,0,64,0,48,54,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,223,209,102,98,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,99,112,49,98,49,102,46,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,227,184,121,57,0,0,0,8,99,112,49,98,56,107,46,56,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,122,234,82,138,0,0,0,8,99,112,49,98,57,107,46,57,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,195,189,84,167,0,0,0,8,105,111,99,49,46,105,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,129,32,24,13,0,0,0,8,99,54,51,50,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,112,146,189,15,0,0,0,8,112,97,51,95,49,55,98,108,46,49,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,222,153,93,59,2,0,16,1,112,97,51,95,49,54,98,108,46,49,48,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,131,164,233,27,2,0,16,1,112,97,51,45,48,49,109,46,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,44,21,138,6,4,0,32,0,112,97,51,45,48,55,109,46,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,157,97,74,58,4,0,32,0,112,97,51,95,49,49,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,162,35,20,203,3,0,16,0,112,97,51,95,48,53,46,49,48,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,93,13,161,115,5,0,64,0,112,97,51,95,48,54,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,130,79,250,175,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,99,112,49,98,49,102,46,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,227,184,121,57,0,0,0,8,99,112,49,98,56,107,46,56,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,122,234,82,138,0,0,0,8,99,112,49,98,57,107,46,57,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,195,189,84,167,0,0,0,8,105,111,99,49,46,105,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,129,32,24,13,0,0,0,8,99,54,51,50,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,112,146,189,15,0,0,0,8,168,86,7,0,1,0,0,0,232,47,216,0,248,191,2,0,24,38,7,0,1,0,0,0,236,47,216,0,184,160,2,0,56,210,6,0,1,0,0,0,35,48,216,0,192,135,2,0,24,163,6,0,1,0,0,0,34,48,216,0,240,108,2,0,152,122,6,0,1,0,0,0,33,48,216,0,96,82,2,0,192,72,6,0,1,0,0,0,32,48,216,0,32,56,2,0,16,175,2,0,1,0,0,0,36,48,216,0,152,30,2,0,88,160,2,0,1,0,0,0,37,48,216,0,232,10,2,0,40,246,1,0,1,0,0,0,233,47,216,0,64,246,1,0,144,236,1,0,1,0,0,0,237,47,216,0,136,224,1,0,176,223,1,0,1,0,0,0,43,48,216,0,72,198,1,0,192,209,1,0,1,0,0,0,42,48,216,0,24,182,1,0,24,198,1,0,1,0,0,0,41,48,216,0,40,167,1,0,120,189,1,0,1,0,0,0,40,48,216,0,200,149,1,0,24,207,8,0,1,0,0,0,44,48,216,0,56,126,1,0,192,202,8,0,1,0,0,0,45,48,216,0,32,101,1,0,88,212,3,0,1,0,0,0,144,46,216,0,40,185,3,0,240,152,1,0,1,0,0,0,238,47,216,0,216,70,1,0,16,17,8,0,1,0,0,0,234,47,216,0,224,12,8,0,224,41,1,0,9,0,0,0,216,48,216,0,32,58,1,0,14,0,0,0,255,255,200,0,0,0,0,0,15,0,0,0,255,255,255,0,0,0,0,0,16,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,32,4,2,0,14,0,0,0,1,3,3,0,248,83,3,0,14,0,0,0,1,3,1,0,216,81,3,0,14,0,0,0,1,3,2,0,168,80,3,0,14,0,0,0,1,3,0,0,88,78,3,0,0,0,0,0,254,0,4,0,128,129,4,0,14,0,0,0,1,12,0,0,192,255,2,0,14,0,0,0,1,12,4,0,208,75,4,0,14,0,0,0,1,12,8,0,8,49,4,0,14,0,0,0,1,12,12,0,72,246,3,0,0,0,0,0,254,0,4,0,64,37,5,0,14,0,0,0,1,48,0,0,176,116,6,0,14,0,0,0,1,48,16,0,80,113,6,0,14,0,0,0,1,48,32,0,80,110,6,0,14,0,0,0,1,48,48,0,120,7,5,0,0,0,0,0,254,0,2,0,72,202,5,0,14,0,0,0,1,64,64,0,248,38,7,0,14,0,0,0,1,64,0,0,112,212,3,0,0,0,0,0,254,0,2,0,192,75,3,0,14,0,0,0,1,128,128,0,248,38,7,0,14,0,0,0,1,128,0,0,40,87,8,0,0,0,0,0,254,0,2,0,16,27,6,0,15,0,0,0,1,16,16,0,96,135,7,0,15,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,2,0,200,30,2,0,16,0,0,0,1,128,128,0,120,97,1,0,16,0,0,0,1,128,0,0,96,19,1,0,12,0,0,0,255,255,128,0,0,0,0,0,13,0,0,0,255,255,255,0,0,0,0,0,14,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,160,123,6,0,13,0,0,0,1,3,0,0,40,88,7,0,13,0,0,0,1,3,1,0,96,39,7,0,13,0,0,0,1,3,3,0,144,251,6,0,13,0,0,0,1,3,2,0,184,164,6,0,0,0,0,0,254,0,2,0,168,234,7,0,13,0,0,0,1,4,0,0,96,135,7,0,13,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,13,0,0,0,1,24,0,0,40,88,7,0,13,0,0,0,1,24,8,0,96,39,7,0,13,0,0,0,1,24,24,0,144,251,6,0,13,0,0,0,1,24,16,0,184,164,6,0,0,0,0,0,254,0,4,0,128,129,4,0,13,0,0,0,1,96,64,0,208,75,4,0,13,0,0,0,1,96,96,0,8,49,4,0,13,0,0,0,1,96,32,0,152,21,4,0,13,0,0,0,1,96,0,0,72,246,3,0,0,0,0,0,254,0,2,0,232,75,4,0,13,0,0,0,1,128,128,0,96,135,7,0,13,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,184,109,5,0,14,0,0,0,1,1,0,0,96,135,7,0,14,0,0,0,1,1,1,0,152,182,7,0,0,0,0,0,254,0,2,0,72,4,1,0,14,0,0,0,1,2,2,0,96,135,7,0,14,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,176,110,8,0,14,0,0,0,1,4,4,0,96,135,7,0,14,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,14,0,0,0,1,24,16,0,48,238,4,0,14,0,0,0,1,24,24,0,248,202,4,0,14,0,0,0,1,24,8,0,16,170,4,0,14,0,0,0,1,24,0,0,200,138,4,0,0,0,0,0,254,0,8,0,64,37,5,0,14,0,0,0,1,224,224,0,248,84,4,0,14,0,0,0,1,224,128,0,136,57,4,0,14,0,0,0,1,224,64,0,24,30,4,0,14,0,0,0,1,224,192,0,112,1,4,0,14,0,0,0,1,224,160,0,16,224,3,0,14,0,0,0,1,224,32,0,144,193,3,0,14,0,0,0,1,224,0,0,160,102,8,0,14,0,0,0,1,224,96,0,112,142,3,0,0,0,0,0,184,40,2,0,1,0,0,0,47,39,216,0,248,191,2,0,56,250,6,0,1,0,0,0,39,39,216,0,184,160,2,0,184,164,8,0,1,0,0,0,46,39,216,0,64,246,1,0,88,149,7,0,1,0,0,0,38,39,216,0,136,224,1,0,152,122,6,0,1,0,0,0,45,39,216,0,96,82,2,0,192,72,6,0,1,0,0,0,44,39,216,0,32,56,2,0,48,123,2,0,1,0,0,0,43,39,216,0,152,30,2,0,24,198,1,0,1,0,0,0,37,39,216,0,40,167,1,0,120,189,1,0,1,0,0,0,36,39,216,0,200,149,1,0,248,187,8,0,1,0,0,0,35,39,216,0,56,126,1,0,88,212,3,0,1,0,0,0,48,38,216,0,40,185,3,0,248,5,8,0,9,0,0,0,112,39,216,0,32,58,1,0,144,250,7,0,9,0,0,0,113,39,216,0,32,58,1,0,248,241,7,0,9,0,0,0,114,39,216,0,32,58,1,0,101,112,114,45,49,48,51,56,48,46,49,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,122,232,57,227,1,0,16,1,101,112,114,45,49,48,51,56,50,46,49,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,213,141,36,101,1,0,16,1,101,112,114,45,49,48,51,56,49,46,49,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,43,65,140,190,1,0,16,1,101,112,114,45,49,48,51,56,51,46,49,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,231,134,197,220,1,0,16,1,101,112,114,45,49,48,51,50,55,46,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,85,216,153,218,9,0,16,1,101,112,114,45,49,48,51,50,57,46,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,226,165,15,254,9,0,16,1,101,112,114,45,49,48,51,50,56,46,55,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,127,154,14,60,9,0,16,1,101,112,114,45,49,48,51,51,48,46,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,153,110,120,89,9,0,16,1,111,112,114,45,49,48,50,54,56,46,57,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,4,75,52,149,2,0,32,0,111,112,114,45,49,48,50,51,50,46,49,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,235,161,107,119,2,0,32,0,111,112,114,45,49,48,50,54,55,46,49,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,35,184,91,168,2,0,32,0,111,112,114,45,49,48,50,51,49,46,49,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,191,188,8,137,2,0,32,0,111,112,114,45,49,48,50,54,54,46,49,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,116,26,111,159,2,0,32,0,111,112,114,45,49,48,50,51,48,46,49,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,80,94,111,104,2,0,32,0,101,112,114,45,49,48,49,57,52,46,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,189,163,237,240,3,0,32,0,101,112,114,45,49,48,50,48,51,46,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,34,166,69,132,3,0,32,0,101,112,114,45,49,48,50,49,50,46,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,49,231,231,222,3,0,32,0,101,112,114,45,49,48,50,50,49,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,135,19,67,67,3,0,32,0,101,112,114,45,49,48,49,57,53,46,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,221,92,231,13,3,0,32,0,101,112,114,45,49,48,50,48,52,46,51,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,187,90,75,95,3,0,32,0,101,112,114,45,49,48,50,49,51,46,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,240,34,27,29,3,0,32,0,101,112,114,45,49,48,50,50,50,46,54,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,6,199,84,162,3,0,32,0,101,112,114,45,49,48,49,57,54,46,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,89,187,136,134,3,0,32,0,101,112,114,45,49,48,50,48,53,46,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,202,147,189,116,3,0,32,0,101,112,114,45,49,48,50,49,52,46,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,24,126,82,87,3,0,32,0,101,112,114,45,49,48,50,50,51,46,54,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,14,105,80,56,3,0,32,0,101,112,114,45,49,48,49,57,55,46,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,166,101,145,0,3,0,32,0,101,112,114,45,49,48,50,48,54,46,52,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,197,66,69,149,3,0,32,0,101,112,114,45,49,48,50,49,53,46,53,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,108,90,190,105,3,0,32,0,101,112,114,45,49,48,50,50,52,46,54,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,70,195,255,92,3,0,32,0,101,112,114,45,49,48,49,57,56,46,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,46,153,148,216,3,0,32,0,101,112,114,45,49,48,50,48,55,46,52,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,164,206,97,202,3,0,32,0,101,112,114,45,49,48,50,49,54,46,53,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,77,19,148,211,3,0,32,0,101,112,114,45,49,48,50,50,53,46,55,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,43,31,93,10,3,0,32,0,101,112,114,45,49,48,49,57,57,46,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0])
.concat([246,106,55,134,3,0,32,0,101,112,114,45,49,48,50,48,56,46,52,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,250,183,48,104,3,0,32,0,101,112,114,45,49,48,50,49,55,46,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,118,155,44,191,3,0,32,0,101,112,114,45,49,48,50,50,54,46,55,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,116,36,69,90,3,0,32,0,101,112,114,45,49,48,50,48,48,46,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,115,79,93,30,3,0,32,0,101,112,114,45,49,48,50,48,57,46,52,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,158,65,21,92,3,0,32,0,101,112,114,45,49,48,50,49,56,46,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,57,219,75,219,3,0,32,0,101,112,114,45,49,48,50,50,55,46,55,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,146,243,222,199,3,0,32,0,101,112,114,45,49,48,50,48,49,46,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,156,75,157,29,3,0,32,0,101,112,114,45,49,48,50,49,48,46,52,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,49,41,66,57,3,0,32,0,101,112,114,45,49,48,50,49,57,46,53,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,36,146,59,231,3,0,32,0,101,112,114,45,49,48,50,50,56,46,55,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,120,57,128,37,3,0,32,0,111,112,114,45,49,48,49,56,54,46,52,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,38,68,121,34,10,0,32,0,111,112,114,45,49,48,49,56,53,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,38,68,121,34,10,0,32,0,101,112,114,45,49,48,49,56,55,46,56,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,169,186,10,161,4,0,16,1,111,112,114,45,49,48,49,57,51,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,222,13,209,188,11,0,64,0,111,112,114,45,49,48,49,57,50,46,54,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,112,18,15,119,11,0,64,0,111,112,114,45,49,48,49,57,49,46,54,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,171,132,162,32,11,0,64,0,111,112,114,45,49,48,49,57,48,46,54,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,226,112,171,124,11,0,64,0,111,112,114,45,49,48,49,56,57,46,55,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,84,107,54,1,11,0,64,0,111,112,114,45,49,48,49,56,56,46,55,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,217,10,211,186,11,0,64,0,97,45,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,162,238,220,205,1,0,16,1,97,45,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,103,122,233,20,1,0,16,1,97,45,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,87,216,146,48,1,0,16,1,97,45,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,150,196,161,48,1,0,16,1,97,45,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,224,170,245,215,9,0,16,1,97,45,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,143,231,194,136,9,0,16,1,97,45,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,93,94,236,213,9,0,16,1,97,45,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,236,251,197,116,9,0,16,1,97,45,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,51,145,72,76,2,0,32,0,97,45,49,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,29,120,156,137,2,0,32,0,97,45,49,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,21,77,221,152,2,0,32,0,97,45,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,126,55,119,3,0,32,0,97,45,50,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,117,201,236,105,3,0,32,0,97,45,50,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,226,208,168,182,3,0,32,0,97,45,50,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,162,216,50,214,3,0,32,0,97,45,50,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,54,66,120,79,3,0,32,0,97,45,50,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,84,113,79,238,3,0,32,0,97,45,51,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,163,10,136,233,3,0,32,0,97,45,51,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,194,109,40,220,3,0,32,0,97,45,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,119,114,14,44,3,0,32,0,97,45,50,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,87,30,118,84,3,0,32,0,97,45,50,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,118,6,13,160,3,0,32,0,97,45,50,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,104,131,57,218,3,0,32,0,97,45,50,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,86,147,69,141,3,0,32,0,97,45,50,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,39,87,36,168,3,0,32,0,97,45,51,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,254,6,125,239,3,0,32,0,97,45,51,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,159,175,34,18,3,0,32,0,97,45,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,156,218,91,237,10,0,32,0,97,45,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,84,231,111,102,10,0,32,0,97,45,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,58,181,155,32,4,0,16,1,97,45,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,244,152,31,25,11,0,64,0,97,45,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,208,102,68,55,11,0,64,0,97,45,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,176,208,39,42,11,0,64,0,168,86,7,0,1,0,0,0,0,238,146,0,248,191,2,0,24,38,7,0,1,0,0,0,143,250,146,0,184,160,2,0,56,210,6,0,1,0,0,0,136,250,146,0,192,135,2,0,24,163,6,0,1,0,0,0,137,250,146,0,240,108,2,0,152,122,6,0,1,0,0,0,138,250,146,0,96,82,2,0,192,72,6,0,1,0,0,0,139,250,146,0,32,56,2,0,200,110,3,0,1,0,0,0,140,250,146,0,152,30,2,0,120,89,3,0,1,0,0,0,141,250,146,0,232,10,2,0,120,74,3,0,1,0,0,0,142,250,146,0,152,138,8,0,40,246,1,0,1,0,0,0,1,238,146,0,64,246,1,0,144,236,1,0,1,0,0,0,103,242,146,0,136,224,1,0,176,223,1,0,1,0,0,0,96,242,146,0,72,198,1,0,192,209,1,0,1,0,0,0,97,242,146,0,24,182,1,0,24,198,1,0,1,0,0,0,98,242,146,0,40,167,1,0,120,189,1,0,1,0,0,0,99,242,146,0,200,149,1,0,224,22,1,0,1,0,0,0,100,242,146,0,56,126,1,0,160,14,1,0,1,0,0,0,101,242,146,0,32,101,1,0,176,9,1,0,1,0,0,0,102,242,146,0,96,32,8,0,88,212,3,0,1,0,0,0,104,215,146,0,40,185,3,0,72,65,1,0,9,0,0,0,112,3,147,0,32,58,1,0,48,50,1,0,9,0,0,0,113,3,147,0,32,58,1,0,184,40,2,0,1,0,0,0,152,244,146,0,248,191,2,0,24,38,7,0,1,0,0,0,191,238,146,0,184,160,2,0,200,110,3,0,1,0,0,0,186,238,146,0,152,30,2,0,120,89,3,0,1,0,0,0,187,238,146,0,232,10,2,0,120,74,3,0,1,0,0,0,188,238,146,0,152,138,8,0,192,61,3,0,1,0,0,0,185,238,146,0,48,119,7,0,120,194,6,0,1,0,0,0,184,238,146,0,112,109,7,0,96,189,6,0,1,0,0,0,194,238,146,0,24,133,7,0,88,212,3,0,1,0,0,0,64,217,146,0,40,185,3,0,248,5,8,0,9,0,0,0,88,4,147,0,32,58,1,0,144,250,7,0,9,0,0,0,89,4,147,0,32,58,1,0,98,50,48,45,48,53,45,48,50,46,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,58,254,251,63,2,0,16,1,98,50,48,45,48,51,45,48,50,46,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,165,216,171,253,2,0,16,1,98,50,48,45,48,52,46,51,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,56,72,107,33,2,0,16,1,98,50,48,45,49,57,46,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,76,196,27,183,2,0,16,1,98,50,48,45,48,55,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,227,172,199,69,9,0,16,1,98,50,48,45,49,51,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,177,218,172,246,11,0,32,0,98,50,48,45,49,52,46,55,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,229,137,248,137,15,0,32,0,98,50,48,45,48,56,46,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,100,156,225,243,26,0,64,0,10,0,0,0,255,255,255,0,0,0,0,0,11,0,0,0,255,255,127,0,0,0,0,0,0,0,0,0,254,0,2,0,104,159,3,0,10,0,0,0,1,2,2,0,96,135,7,0,10,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,10,0,0,0,1,4,4,0,96,135,7,0,10,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,10,0,0,0,1,8,0,0,96,135,7,0,10,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,10,0,0,0,1,48,16,0,104,236,7,0,10,0,0,0,1,48,48,0,128,230,7,0,10,0,0,0,1,48,0,0,120,211,6,0,10,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,10,0,0,0,1,192,64,0,104,236,7,0,10,0,0,0,1,192,192,0,128,230,7,0,10,0,0,0,1,192,0,0,120,211,6,0,10,0,0,0,1,192,128,0,184,164,6,0,0,0,0,0,254,0,4,0,72,202,5,0,11,0,0,0,1,3,2,0,80,246,3,0,11,0,0,0,1,3,3,0,80,124,6,0,11,0,0,0,1,3,1,0,112,212,3,0,11,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,144,52,7,0,11,0,0,0,1,12,0,0,152,21,4,0,11,0,0,0,1,12,4,0,72,246,3,0,11,0,0,0,1,12,12,0,72,0,3,0,11,0,0,0,1,12,8,0,64,47,7,0,0,0,0,0,254,0,2,0,128,112,3,0,11,0,0,0,1,128,128,0,224,247,3,0,11,0,0,0,1,128,0,0,168,22,4,0,98,50,48,45,48,53,45,48,50,46,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,58,254,251,63,2,0,16,1,98,50,48,45,48,51,45,48,50,46,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,165,216,171,253,2,0,16,1,98,50,48,45,48,52,46,51,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,56,72,107,33,2,0,16,1,98,50,48,45,49,56,46,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,112,36,32,253,2,0,16,1,98,50,48,45,48,55,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,227,172,199,69,9,0,16,1,98,50,48,45,49,51,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,177,218,172,246,11,0,32,0,98,50,48,45,49,52,46,55,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,229,137,248,137,15,0,32,0,98,50,48,45,48,56,46,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,100,156,225,243,26,0,64,0,111,112,119,108,102,98,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,5,68,126,216,2,0,16,1,111,112,119,108,102,98,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,92,247,182,154,2,0,16,1,111,112,119,108,102,98,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,110,12,35,97,2,0,16,1,111,112,119,108,102,98,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,141,49,46,52,2,0,16,1,111,112,119,108,102,98,46,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,76,185,105,6,9,0,16,1,111,112,119,108,102,98,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,221,163,39,171,10,0,16,1,111,112,119,108,102,98,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,78,41,77,19,12,0,32,0,111,112,119,108,102,98,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,141,169,12,222,12,0,32,0,111,112,119,108,102,98,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,102,14,125,49,12,0,32,0,111,112,119,108,102,98,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,208,253,49,98,12,0,32,0,111,112,119,108,102,98,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,94,9,196,225,12,0,32,0,111,112,119,108,102,98,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,128,186,248,204,12,0,32,0,111,112,119,108,102,98,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,200,114,158,253,12,0,32,0,111,112,119,108,102,98,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,86,242,101,10,12,0,32,0,111,112,119,108,102,98,46,49,52,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,235,134,55,102,16,0,32,0,111,112,119,108,102,98,46,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,142,176,154,222,16,0,32,0,111,112,119,108,102,98,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,169,138,91,49,16,0,32,0,111,112,119,108,102,98,46,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,94,248,92,100,16,0,32,0,111,112,119,108,102,98,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,227,153,16,224,16,0,32,0,111,112,119,108,102,98,46,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,198,156,11,216,16,0,32,0,111,112,119,108,102,98,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,29,230,251,86,16,0,32,0,111,112,119,108,102,98,46,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,87,81,210,151,16,0,32,0,111,112,119,108,102,98,46,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,192,234,169,5,27,0,64,0,111,112,119,108,102,98,46,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,88,127,184,133,27,0,64,0,111,112,119,108,102,98,46,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,117,33,27,40,27,0,64,0,111,112,119,108,102,98,46,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,77,93,252,142,27,0,64,0,111,112,119,108,102,98,46,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,166,17,18,68,27,0,64,0,111,112,119,108,102,98,46,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,3,199,116,168,27,0,64,0,111,112,119,108,102,98,46,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,45,212,209,134,27,0,64,0,111,112,119,108,102,98,46,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,31,72,40,146,27,0,64,0,10,0,0,0,255,255,255,0,0,0,0,0,11,0,0,0,255,255,127,0,0,0,0,0,0,0,0,0,254,0,2,0,104,159,3,0,10,0,0,0,1,2,2,0,96,135,7,0,10,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,10,0,0,0,1,4,4,0,96,135,7,0,10,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,10,0,0,0,1,8,0,0,96,135,7,0,10,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,10,0,0,0,1,48,0,0,80,252,6,0,10,0,0,0,1,48,16,0,16,242,7,0,10,0,0,0,1,48,32,0,104,236,7,0,10,0,0,0,1,48,48,0,128,230,7,0,0,0,0,0,254,0,4,0,160,123,6,0,10,0,0,0,1,192,192,0,8,201,6,0,10,0,0,0,1,192,128,0,200,197,6,0,10,0,0,0,1,192,64,0,152,194,6,0,10,0,0,0,1,192,0,0,248,189,6,0,0,0,0,0,254,0,4,0,72,202,5,0,11,0,0,0,1,3,2,0,80,246,3,0,11,0,0,0,1,3,3,0,80,124,6,0,11,0,0,0,1,3,1,0,112,212,3,0,11,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,144,52,7,0,11,0,0,0,1,12,0,0,152,21,4,0,11,0,0,0,1,12,4,0,72,246,3,0,11,0,0,0,1,12,12,0,72,0,3,0,11,0,0,0,1,12,8,0,64,47,7,0,0,0,0,0,98,50,48,45,48,53,45,48,50,46,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,58,254,251,63,2,0,16,1,98,50,48,45,48,51,45,48,50,46,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,165,216,171,253,2,0,16,1,98,50,48,45,48,52,46,51,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,56,72,107,33,2,0,16,1,98,50,48,45,49,55,46,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,142,24,67,96,2,0,16,1,98,50,48,45,48,55,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,227,172,199,69,9,0,16,1,98,50,48,45,49,51,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,177,218,172,246,11,0,32,0,98,50,48,45,49,52,46,55,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,229,137,248,137,15,0,32,0,98,50,48,45,48,56,46,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,100,156,225,243,26,0,64,0,100,55,52,95,49,54,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,241,143,25,2,0,16,1,100,55,52,95,50,49,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,139,85,28,198,2,0,16,1,100,55,52,95,49,56,46,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,219,124,93,189,2,0,16,1,100,55,52,95,49,55,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,114,166,53,172,2,0,16,1,100,55,52,95,50,50,46,55,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,166,116,131,17,9,0,16,1,100,55,52,95,48,53,46,56,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,204,100,234,133,12,0,32,0,100,55,52,95,48,54,46,56,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,141,224,161,47,12,0,32,0,100,55,52,95,48,49,46,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,224,19,83,17,24,0,64,0,100,55,52,95,48,50,46,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,50,99,184,170,0,0,32,0,100,55,52,95,48,51,46,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,22,137,57,63,0,0,32,0,100,55,52,95,48,52,46,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,56,86,56,47,0,0,32,0,17,0,0,0,255,255,16,0,0,0,0,0,0,0,0,0,254,0,2,0,232,75,4,0,17,0,0,0,1,16,16,0,96,135,7,0,17,0,0,0,1,16,0,0,152,182,7,0,184,40,2,0,1,0,0,0,40,39,216,0,248,191,2,0,56,250,6,0,1,0,0,0,32,39,216,0,184,160,2,0,184,164,8,0,1,0,0,0,41,39,216,0,64,246,1,0,88,149,7,0,1,0,0,0,33,39,216,0,136,224,1,0,208,158,7,0,1,0,0,0,42,39,216,0,96,82,2,0,184,154,7,0,1,0,0,0,43,39,216,0,32,56,2,0,176,108,2,0,1,0,0,0,44,39,216,0,152,30,2,0,16,83,7,0,1,0,0,0,34,39,216,0,40,167,1,0,96,79,7,0,1,0,0,0,35,39,216,0,200,149,1,0,48,76,7,0,1,0,0,0,36,39,216,0,56,126,1,0,88,212,3,0,1,0,0,0,48,38,216,0,40,185,3,0,248,5,8,0,9,0,0,0,112,39,216,0,32,58,1,0,144,250,7,0,9,0,0,0,113,39,216,0,32,58,1,0,248,241,7,0,9,0,0,0,114,39,216,0,32,58,1,0,111,109,103,45,112,46,49,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,202,64,250,72,0,0,16,1,111,109,103,45,98,46,49,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,166,31,98,115,0,0,32,0,111,109,103,45,115,46,49,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,54,189,19,100,0,0,32,0,111,109,103,45,103,46,49,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,60,87,5,116,0,0,64,0,17,0,0,0,255,255,255,0,0,0,0,0,18,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,15,0,200,87,7,0,17,0,0,0,1,15,5,0,48,229,8,0,17,0,0,0,1,15,3,0,72,163,8,0,17,0,0,0,1,15,7,0,96,100,8,0,17,0,0,0,1,15,4,0,96,44,8,0,17,0,0,0,1,15,2,0,16,249,7,0,17,0,0,0,1,15,8,0,208,195,7,0,17,0,0,0,1,15,9,0,224,147,7,0,17,0,0,0,1,15,1,0,64,101,7,0,17,0,0,0,1,15,15,0,168,50,7,0,17,0,0,0,1,15,14,0,24,7,7,0,17,0,0,0,1,15,13,0,152,221,6,0,17,0,0,0,1,15,12,0,144,176,6,0,17,0,0,0,1,15,11,0,248,133,6,0,17,0,0,0,1,15,10,0,0,88,6,0,17,0,0,0,1,15,0,0,16,227,4,0,0,0,0,0,254,0,15,0,160,123,6,0,17,0,0,0,1,240,80,0,48,229,8,0,17,0,0,0,1,240,48,0,72,163,8,0,17,0,0,0,1,240,112,0,96,100,8,0,17,0,0,0,1,240,64,0,96,44,8,0,17,0,0,0,1,240,32,0,16,249,7,0,17,0,0,0,1,240,128,0,208,195,7,0,17,0,0,0,1,240,144,0,224,147,7,0,17,0,0,0,1,240,16,0,64,101,7,0,17,0,0,0,1,240,240,0,168,50,7,0,17,0,0,0,1,240,224,0,24,7,7,0,17,0,0,0,1,240,208,0,152,221,6,0,17,0,0,0,1,240,192,0,144,176,6,0,17,0,0,0,1,240,176,0,248,133,6,0,17,0,0,0,1,240,160,0,0,88,6,0,17,0,0,0,1,240,0,0,16,227,4,0,0,0,0,0,254,0,4,0,224,210,5,0,18,0,0,0,1,3,2,0,80,246,3,0,18,0,0,0,1,3,3,0,248,38,7,0,18,0,0,0,1,3,1,0,112,212,3,0,18,0,0,0,1,3,0,0,24,99,5,0,0,0,0,0,254,0,4,0,24,45,5,0,18,0,0,0,1,12,12,0,56,15,5,0,18,0,0,0,1,12,8,0,160,236,4,0,18,0,0,0,1,12,4,0,248,38,7,0,18,0,0,0,1,12,0,0,112,212,3,0,0,0,0,0,254,0,2,0,152,199,4,0,18,0,0,0,1,16,0,0,48,168,4,0,18,0,0,0,1,16,16,0,160,136,4,0,0,0,0,0,254,0,2,0,48,109,4,0,18,0,0,0,1,32,0,0,96,135,7,0,18,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,168,28,4,0,18,0,0,0,1,64,0,0,56,111,3,0,18,0,0,0,1,64,64,0,104,134,3,0,0,0,0,0,254,0,2,0,184,89,6,0,18,0,0,0,1,128,128,0,96,135,7,0,18,0,0,0,1,128,0,0,152,182,7,0,118,112,104,117,100,46,48,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,213,212,32,1,0,16,1,118,112,104,117,100,46,48,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,66,155,190,97,1,0,16,1,118,112,104,117,100,46,48,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,216,6,169,27,1,0,16,1,118,112,104,117,46,48,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,219,76,192,8,1,0,16,1,118,112,104,117,46,48,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,25,171,165,181,1,0,16,1,118,112,104,117,46,48,56,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,251,32,187,81,1,0,16,1,118,112,104,117,46,48,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,5,66,166,65,1,0,16,1,118,112,104,117,100,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,173,173,25,150,1,0,16,1,118,112,104,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,153,175,27,197,5,0,32,0,118,112,104,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,119,60,232,60,5,0,32,0,118,112,104,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,224,8,36,79,5,0,32,0,118,112,104,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,80,2,246,159,5,0,32,0,118,112,104,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,221,26,14,122,5,0,32,0,118,112,104,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,117,202,65,47,5,0,32,0,118,112,104,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,237,142,73,100,5,0,32,0,118,112,104,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,63,67,242,23,5,0,32,0,118,112,104,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,172,220,69,80,10,0,16,1,118,112,104,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,89,14,182,134,10,0,16,1,118,112,104,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,51,125,131,225,12,0,64,0,118,112,104,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,144,205,211,251,12,0,64,0,22,0,0,0,255,255,255,0,0,0,0,0,23,0,0,0,255,255,245,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,22,0,0,0,1,3,2,0,208,75,4,0,22,0,0,0,1,3,3,0,8,49,4,0,22,0,0,0,1,3,1,0,152,21,4,0,22,0,0,0,1,3,0,0,72,246,3,0,0,0,0,0,254,0,4,0,72,202,5,0,22,0,0,0,1,12,8,0,80,246,3,0,22,0,0,0,1,12,12,0,248,38,7,0,22,0,0,0,1,12,4,0,112,212,3,0,22,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,2,0,200,30,2,0,23,0,0,0,1,2,0,0,120,97,1,0,23,0,0,0,1,2,2,0,96,19,1,0,0,0,0,0,254,0,2,0,168,234,7,0,23,0,0,0,1,8,8,0,96,135,7,0,23,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,23,0,0,0,1,16,0,0,56,111,3,0,23,0,0,0,1,16,16,0,104,134,3,0,0,0,0,0,254,0,2,0,144,246,3,0,23,0,0,0,1,64,64,0,96,135,7,0,23,0,0,0,1,64,0,0,152,182,7,0,110,114,120,95,112,114,103,49,46,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,252,233,125,186,0,0,16,1,110,114,120,95,112,114,103,50,46,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,174,204,223,238,0,0,16,1,110,114,120,95,112,114,103,51,46,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,74,211,213,180,0,0,16,1,110,114,120,95,112,114,103,52,46,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,109,73,165,125,0,0,16,1,110,114,120,95,99,104,103,49,46,56,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,164,56,255,31,0,0,32,0,110,114,120,95,99,104,103,50,46,56,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,253,255,217,133,0,0,32,0,114,120,49,45,54,46,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,44,246,22,60,0,0,32,0,110,114,120,49,45,49,46,49,49,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,23,144,164,160,0,0,32,0,110,114,120,49,45,55,46,56,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,133,244,70,78,0,0,32,0,114,120,49,45,50,46,52,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,21,72,87,143,0,0,32,0,114,120,49,45,51,46,55,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,150,16,134,184,0,0,32,0,114,120,49,45,53,46,51,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,23,112,173,75,0,0,64,0,114,120,49,45,52,46,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,0,98,51,49,95,52,57,46,51,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,145,99,139,211,2,0,16,1,98,51,49,95,52,56,46,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,216,179,91,75,2,0,16,1,98,51,49,95,50,57,46,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,55,26,148,242,2,0,16,1,98,51,49,95,50,55,46,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,66,246,63,47,2,0,16,1,98,51,49,95,52,49,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,138,242,174,13,2,0,16,1,98,51,49,95,51,57,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,60,124,25,233,2,0,16,1,98,51,49,95,52,48,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,78,242,224,44,2,0,16,1,98,51,49,95,51,56,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,153,205,104,188,2,0,16,1,98,51,49,95,51,51,46,56,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,68,175,233,108,6,0,16,1,98,51,49,95,51,54,46,57,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,212,176,32,186,6,0,16,1,98,51,49,95,51,50,46,56,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,236,95,2,230,6,0,16,1,98,51,49,95,51,53,46,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,159,168,217,112,6,0,16,1,98,51,49,95,51,49,46,56,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,226,71,127,131,6,0,16,1,98,51,49,95,51,52,46,57,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,42,251,181,214,6,0,16,1,98,51,49,95,51,55,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,157,121,165,12,9,0,16,1,98,51,49,45,48,49,46,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,167,55,130,142,11,0,32,0,98,51,49,45,48,50,46,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,51,78,59,76,11,0,32,0,98,51,49,45,48,55,46,49,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,219,140,86,51,15,0,32,0,98,51,49,45,48,54,46,49,55,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,158,67,89,13,15,0,32,0,98,51,49,45,48,53,46,49,55,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,251,201,31,10,15,0,32,0,98,51,49,45,48,52,46,49,55,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,76,30,46,15,0,32,0,98,51,49,45,48,57,46,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,130,51,167,96,24,0,64,0,98,51,49,45,49,48,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,239,74,67,198,24,0,64,0,98,51,49,45,49,49,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,212,49,165,141,24,0,64,0,98,51,49,45,48,56,46,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,125,248,161,160,25,0,64,0,98,51,49,45,50,53,46,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,72,186,180,160,0,0,0,8,98,51,49,45,50,54,46,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,21,254,229,19,0,0,0,8,98,51,49,95,51,48,46,51,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,159,221,110,5,2,0,16,1,98,51,49,95,50,56,46,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,28,102,167,207,2,0,16,1,98,51,49,95,50,57,46,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,55,26,148,242,2,0,16,1,98,51,49,95,50,55,46,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,66,246,63,47,2,0,16,1,98,51,49,95,52,49,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,138,242,174,13,2,0,16,1,98,51,49,95,51,57,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,60,124,25,233,2,0,16,1,98,51,49,95,52,48,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,78,242,224,44,2,0,16,1,98,51,49,95,51,56,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,153,205,104,188,2,0,16,1,98,51,49,95,51,51,46,56,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,68,175,233,108,6,0,16,1,98,51,49,95,51,54,46,57,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,212,176,32,186,6,0,16,1,98,51,49,95,51,50,46,56,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,236,95,2,230,6,0,16,1,98,51,49,95,51,53,46,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,159,168,217,112,6,0,16,1,98,51,49,95,51,49,46,56,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,226,71,127,131,6,0,16,1,98,51,49,95,51,52,46,57,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,42,251,181,214,6,0,16,1,98,51,49,95,51,55,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,157,121,165,12,9,0,16,1,98,51,49,45,48,49,46,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,167,55,130,142,11,0,32,0,98,51,49,45,48,50,46,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,51,78,59,76,11,0,32,0,98,51,49,45,48,55,46,49,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,219,140,86,51,15,0,32,0,98,51,49,45,48,54,46,49,55,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,158,67,89,13,15,0,32,0,98,51,49,45,48,53,46,49,55,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,251,201,31,10,15,0,32,0,98,51,49,45,48,52,46,49,55,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,76,30,46,15,0,32,0,98,51,49,45,48,57,46,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,130,51,167,96,24,0,64,0,98,51,49,45,49,48,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,239,74,67,198,24,0,64,0,98,51,49,45,49,49,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,212,49,165,141,24,0,64,0,98,51,49,45,48,56,46,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,125,248,161,160,25,0,64,0,98,51,49,45,50,53,46,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,72,186,180,160,0,0,0,8,98,51,49,45,50,54,46,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,21,254,229,19,0,0,0,8,20,0,0,0,255,255,255,0,0,0,0,0,21,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,104,159,3,0,20,0,0,0,1,1,0,0,96,135,7,0,20,0,0,0,1,1,1,0,152,182,7,0,0,0,0,0,254,0,2,0,96,19,7,0,20,0,0,0,1,2,2,0,248,38,7,0,20,0,0,0,1,2,0,0,176,64,8,0,0,0,0,0,254,0,2,0,232,75,4,0,20,0,0,0,1,4,4,0,96,135,7,0,20,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,20,0,0,0,1,8,0,0,96,135,7,0,20,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,20,0,0,0,1,48,0,0,80,252,6,0,20,0,0,0,1,48,16,0,16,242,7,0,20,0,0,0,1,48,32,0,104,236,7,0,20,0,0,0,1,48,48,0,128,230,7,0,0,0,0,0,254,0,4,0,160,123,6,0,20,0,0,0,1,192,192,0,8,201,6,0,20,0,0,0,1,192,128,0,200,197,6,0,20,0,0,0,1,192,64,0,152,194,6,0,20,0,0,0,1,192,0,0,248,189,6,0,0,0,0,0,254,0,4,0,72,202,5,0,21,0,0,0,1,3,2,0,80,246,3,0,21,0,0,0,1,3,3,0,80,124,6,0,21,0,0,0,1,3,1,0,112,212,3,0,21,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,99,56,53,45,49,53,120,46,105,99,53,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,27,72,154,113,2,0,16,1,99,56,53,45,49,50,120,46,105,99,52,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,30,126,63,108,2,0,16,1,99,56,53,45,48,55,46,105,99,52,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,10,253,204,62,2,0,16,1,99,56,53,45,48,54,46,105,99,52,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,209,222,38,209,2,0,16,1,99,56,53,45,49,52,46,105,99,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,81,42,165,242,9,0,16,1,99,56,53,45,48,51,46,105,99,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,185,199,76,11,0,32,0,99,56,53,45,48,49,46,105,99,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,124,151,17,167,15,0,32,0,99,56,53,45,48,50,46,105,99,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,61,15,173,166,15,0,32,0,99,56,53,45,48,52,46,105,99,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,126,116,251,90,24,0,64,0,99,56,53,45,48,53,46,105,99,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,208,14,27,60,25,0,64,0,36,0,0,0,255,255,255,0,0,0,0,0,37,0,0,0,255,255,223,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,36,0,0,0,1,2,2,0,96,135,7,0,36,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,36,0,0,0,1,4,4,0,96,135,7,0,36,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,36,0,0,0,1,8,0,0,96,135,7,0,36,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,32,4,2,0,36,0,0,0,1,48,0,0,80,252,6,0,36,0,0,0,1,48,16,0,16,242,7,0,36,0,0,0,1,48,32,0,104,236,7,0,36,0,0,0,1,48,48,0,128,230,7,0,0,0,0,0,254,0,4,0,168,248,6,0,36,0,0,0,1,192,0,0,16,242,7,0,36,0,0,0,1,192,64,0,104,236,7,0,36,0,0,0,1,192,128,0,80,245,6,0,36,0,0,0,1,192,192,0,240,240,6,0,0,0,0,0,254,0,4,0,72,202,5,0,37,0,0,0,1,3,2,0,80,246,3,0,37,0,0,0,1,3,3,0,80,124,6,0,37,0,0,0,1,3,1,0,112,212,3,0,37,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,64,251,5,0,37,0,0,0,1,12,12,0,240,242,5,0,37,0,0,0,1,12,8,0,56,239,5,0,37,0,0,0,1,12,4,0,64,235,5,0,37,0,0,0,1,12,0,0,40,232,5,0,0,0,0,0,254,0,4,0,128,129,4,0,37,0,0,0,1,48,32,0,208,75,4,0,37,0,0,0,1,48,48,0,8,49,4,0,37,0,0,0,1,48,16,0,152,21,4,0,37,0,0,0,1,48,0,0,72,246,3,0,0,0,0,0,254,0,2,0,104,159,3,0,37,0,0,0,1,64,0,0,96,135,7,0,37,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,224,21,4,0,37,0,0,0,1,128,0,0,48,224,5,0,37,0,0,0,1,128,128,0,0,220,5,0,99,56,53,45,49,48,120,46,105,99,53,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,116,110,126,186,2,0,16,1,99,56,53,45,49,49,120,46,105,99,52,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,142,170,204,228,2,0,16,1,99,56,53,45,48,55,46,105,99,52,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,10,253,204,62,2,0,16,1,99,56,53,45,48,54,46,105,99,52,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,209,222,38,209,2,0,16,1,99,56,53,45,49,52,46,105,99,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,81,42,165,242,9,0,16,1,99,56,53,45,48,51,46,105,99,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,185,199,76,11,0,32,0,99,56,53,45,48,49,46,105,99,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,124,151,17,167,15,0,32,0,99,56,53,45,48,50,46,105,99,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,61,15,173,166,15,0,32,0,99,56,53,45,48,52,46,105,99,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,126,116,251,90,24,0,64,0,99,56,53,45,48,53,46,105,99,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,208,14,27,60,25,0,64,0,36,0,0,0,255,255,255,0,0,0,0,0,37,0,0,0,255,255,223,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,36,0,0,0,1,2,2,0,96,135,7,0,36,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,36,0,0,0,1,4,4,0,96,135,7,0,36,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,36,0,0,0,1,8,0,0,96,135,7,0,36,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,36,0,0,0,1,48,0,0,16,242,7,0,36,0,0,0,1,48,16,0,104,236,7,0,36,0,0,0,1,48,48,0,128,230,7,0,36,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,36,0,0,0,1,192,0,0,16,242,7,0,36,0,0,0,1,192,64,0,104,236,7,0,36,0,0,0,1,192,192,0,128,230,7,0,36,0,0,0,1,192,128,0,184,164,6,0,0,0,0,0,254,0,4,0,72,202,5,0,37,0,0,0,1,3,2,0,80,246,3,0,37,0,0,0,1,3,3,0,80,124,6,0,37,0,0,0,1,3,1,0,112,212,3,0,37,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,64,251,5,0,37,0,0,0,1,12,12,0,240,242,5,0,37,0,0,0,1,12,8,0,56,239,5,0,37,0,0,0,1,12,4,0,64,235,5,0,37,0,0,0,1,12,0,0,40,232,5,0,0,0,0,0,254,0,4,0,128,129,4,0,37,0,0,0,1,48,32,0,208,75,4,0,37,0,0,0,1,48,48,0,8,49,4,0,37,0,0,0,1,48,16,0,152,21,4,0,37,0,0,0,1,48,0,0,72,246,3,0,0,0,0,0,254,0,2,0,104,159,3,0,37,0,0,0,1,64,0,0,96,135,7,0,37,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,224,21,4,0,37,0,0,0,1,128,0,0,48,224,5,0,37,0,0,0,1,128,128,0,0,220,5,0,49,57,120,106,46,48,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,209,189,8,237,1,0,16,1,49,57,120,106,46,48,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,41,63,142,251,1,0,16,1,49,57,120,106,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,196,138,80,170,1,0,16,1,49,57,120,106,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,91,120,45,255,1,0,16,1,49,57,120,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,108,41,192,97,1,0,16,1,49,57,120,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,235,122,66,5,0,32,0,49,57,120,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,84,191,189,99,5,0,32,0,49,57,120,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,24,254,45,5,0,32,0,49,57,120,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,121,149,239,203,5,0,32,0,49,57,120,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,124,150,22,233,5,0,32,0,49,57,120,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,219,243,117,110,5,0,32,0,49,57,120,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,152,231,19,34,5,0,32,0,49,57,120,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,150,91,157,171,5,0,32,0,49,57,120,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,94,25,85,239,10,0,16,1,49,57,120,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,243,238,139,211,12,0,64,0,49,57,120,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,226,150,124,212,12,0,64,0,49,57,120,104,46,48,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,172,226,123,53,1,0,16,1,49,57,120,104,46,48,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,59,234,19,187,1,0,16,1,49,57,120,104,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,102,215,203,1,0,16,1,49,57,120,104,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,139,222,98,179,1,0,16,1,49,57,120,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,108,41,192,97,1,0,16,1,49,57,120,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,235,122,66,5,0,32,0,49,57,120,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,84,191,189,99,5,0,32,0,49,57,120,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,24,254,45,5,0,32,0,49,57,120,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,121,149,239,203,5,0,32,0,49,57,120,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,124,150,22,233,5,0,32,0,49,57,120,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,219,243,117,110,5,0,32,0,49,57,120,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,152,231,19,34,5,0,32,0,49,57,120,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,150,91,157,171,5,0,32,0,49,57,120,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,94,25,85,239,10,0,16,1,49,57,120,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,243,238,139,211,12,0,64,0,49,57,120,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,226,150,124,212,12,0,64,0,49,57,120,117,100,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,229,96,27,248,1,0,16,1,49,57,120,117,100,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,140,99,68,204,1,0,16,1,49,57,120,117,100,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,222,104,161,51,1,0,16,1,49,57,120,117,100,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,130,18,17,224,1,0,16,1,49,57,120,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,108,41,192,97,1,0,16,1,49,57,120,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,235,122,66,5,0,32,0,49,57,120,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,84,191,189,99,5,0,32,0,49,57,120,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,24,254,45,5,0,32,0,49,57,120,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,121,149,239,203,5,0,32,0,49,57,120,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,124,150,22,233,5,0,32,0,49,57,120,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,219,243,117,110,5,0,32,0,49,57,120,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,152,231,19,34,5,0,32,0,49,57,120,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,150,91,157,171,5,0,32,0,49,57,120,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,94,25,85,239,10,0,16,1,49,57,120,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,243,238,139,211,12,0,64,0,49,57,120,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,226,150,124,212,12,0,64,0,49,57,120,98,46,48,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,74,223,27,52,1,0,16,1,49,57,120,98,46,48,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,158,6,248,223,1,0,16,1,49,57,120,98,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,146,122,164,1,0,16,1,49,57,120,98,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,13,241,45,197,1,0,16,1,49,57,120,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,108,41,192,97,1,0,16,1,49,57,120,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,235,122,66,5,0,32,0,49,57,120,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,84,191,189,99,5,0,32,0,49,57,120,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,24,254,45,5,0,32,0,49,57,120,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,121,149,239,203,5,0,32,0,49,57,120,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,124,150,22,233,5,0,32,0,49,57,120,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,219,243,117,110,5,0,32,0,49,57,120,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,152,231,19,34,5,0,32,0,49,57,120,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,150,91,157,171,5,0,32,0,49,57,120,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,94,25,85,239,10,0,16,1,49,57,120,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,243,238,139,211,12,0,64,0,49,57,120,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,226,150,124,212,12,0,64,0,49,57,120,97,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,80,253,32,12,1,0,16,1,49,57,120,97,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,8,117,195,31,1,0,16,1,49,57,120,97,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,237,196,156,108,1,0,16,1,49,57,120,97,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,118,159,91,202,1,0,16,1,49,57,120,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,108,41,192,97,1,0,16,1,49,57,120,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,235,122,66,5,0,32,0,49,57,120,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,84,191,189,99,5,0,32,0,49,57,120,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,24,254,45,5,0,32,0,49,57,120,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,121,149,239,203,5,0,32,0,49,57,120,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,124,150,22,233,5,0,32,0,49,57,120,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,219,243,117,110,5,0,32,0,49,57,120,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,152,231,19,34,5,0,32,0,49,57,120,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,150,91,157,171,5,0,32,0,49,57,120,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,94,25,85,239,10,0,16,1,49,57,120,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,243,238,139,211,12,0,64,0,49,57,120,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,226,150,124,212,12,0,64,0,110,102,102,106,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,239,33,117,36,1,0,16,1,110,102,102,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,110,198,161,219,1,0,16,1,110,102,102,106,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,239,194,32,127,1,0,16,1,110,102,102,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,65,167,252,201,5,0,32,0,110,102,102,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,152,216,9,248,5,0,32,0,110,102,102,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,7,69,186,21,5,0,32,0,110,102,102,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,140,27,212,61,5,0,32,0,110,102,102,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,75,165,227,63,5,0,32,0,110,102,102,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,49,210,92,86,5,0,32,0,110,102,102,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,136,89,202,99,5,0,32,0,110,102,102,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,59,143,235,33,5,0,32,0,110,102,102,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,24,67,228,210,10,0,16,1,110,102,102,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,5,78,62,36,12,0,64,0,110,102,102,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,22,207,79,12,0,64,0,110,102,102,117,100,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,228,170,232,40,1,0,16,1,110,102,102,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,110,198,161,219,1,0,16,1,110,102,102,117,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,183,62,129,234,1,0,16,1,110,102,102,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,65,167,252,201,5,0,32,0,110,102,102,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,152,216,9,248,5,0,32,0,110,102,102,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,7,69,186,21,5,0,32,0,110,102,102,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,140,27,212,61,5,0,32,0,110,102,102,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0])
.concat([75,165,227,63,5,0,32,0,110,102,102,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,49,210,92,86,5,0,32,0,110,102,102,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,136,89,202,99,5,0,32,0,110,102,102,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,59,143,235,33,5,0,32,0,110,102,102,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,24,67,228,210,10,0,16,1,110,102,102,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,5,78,62,36,12,0,64,0,110,102,102,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,22,207,79,12,0,64,0,110,101,119,115,105,110,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,224,63,194,230,1,0,16,1,110,101,119,115,105,110,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,95,123,71,61,1,0,16,1,110,101,119,115,105,110,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,240,154,250,125,1,0,16,1,110,101,119,115,105,110,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,25,186,176,209,1,0,16,1,110,101,119,115,105,110,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,89,93,39,6,1,0,16,1,110,101,119,115,105,110,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,162,137,132,216,2,0,16,1,110,101,119,115,105,110,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,175,167,84,177,2,0,16,1,110,101,119,115,105,110,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,155,112,222,122,2,0,16,1,110,101,119,115,105,110,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,255,173,135,107,4,0,32,0,110,101,119,115,105,110,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,90,137,91,12,4,0,32,0,110,101,119,115,105,110,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,79,214,197,107,4,0,32,0,110,101,119,115,105,110,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,141,205,242,92,7,0,32,0,15,0,0,0,255,255,0,0,0,0,0,0,16,0,0,0,255,255,0,0,0,0,0,0,17,0,0,0,255,255,12,0,0,0,0,0,0,0,0,0,254,0,4,0,32,4,2,0,16,0,0,0,1,3,0,0,152,205,1,0,16,0,0,0,1,3,2,0,224,44,2,0,16,0,0,0,1,3,1,0,0,204,1,0,16,0,0,0,1,3,3,0,224,43,2,0,0,0,0,0,254,0,2,0,200,30,2,0,17,0,0,0,1,2,0,0,120,97,1,0,17,0,0,0,1,2,2,0,96,19,1,0,0,0,0,0,254,0,2,0,128,129,4,0,17,0,0,0,1,8,8,0,8,49,4,0,17,0,0,0,1,8,0,0,72,246,3,0,112,114,111,103,50,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,87,164,67,222,0,0,16,1,112,114,111,103,49,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,190,69,11,55,0,0,16,1,105,115,99,114,50,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,235,162,45,79,0,0,16,1,105,115,99,114,49,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,79,137,198,99,0,0,16,1,105,115,99,114,52,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,65,87,114,0,0,16,1,105,115,99,114,51,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,98,179,214,81,0,0,16,1,105,115,99,114,54,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,243,46,139,23,0,0,16,1,105,115,99,114,53,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,250,197,181,210,0,0,16,1,105,115,99,114,56,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,40,133,20,244,0,0,16,1,105,115,99,114,55,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,49,12,238,45,0,0,16,1,110,102,57,53,111,98,106,49,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,113,188,209,230,0,0,32,0,109,117,115,99,49,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,206,127,52,16,0,0,64,0,109,117,115,99,50,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,140,106,100,185,0,0,64,0,19,0,0,0,255,255,62,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,19,0,0,0,1,1,0,0,120,97,1,0,19,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,2,2,0,96,135,7,0,19,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,4,4,0,96,135,7,0,19,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,8,0,0,96,135,7,0,19,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,32,4,2,0,19,0,0,0,1,48,0,0,32,136,7,0,19,0,0,0,1,48,16,0,40,88,7,0,19,0,0,0,1,48,32,0,96,39,7,0,19,0,0,0,1,48,48,0,144,251,6,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,3,2,0,80,246,3,0,20,0,0,0,1,3,3,0,80,124,6,0,20,0,0,0,1,3,1,0,112,212,3,0,20,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,64,37,5,0,20,0,0,0,1,12,12,0,240,191,4,0,20,0,0,0,1,12,8,0,200,213,4,0,20,0,0,0,1,12,4,0,144,227,4,0,20,0,0,0,1,12,0,0,200,178,5,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,48,32,0,192,255,2,0,20,0,0,0,1,48,16,0,208,75,4,0,20,0,0,0,1,48,48,0,8,49,4,0,20,0,0,0,1,48,0,0,72,246,3,0,0,0,0,0,254,0,2,0,104,159,3,0,20,0,0,0,1,64,0,0,96,135,7,0,20,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,52,49,101,109,95,51,48,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,97,236,73,66,1,0,16,1,52,49,101,109,95,51,53,46,49,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,235,229,190,221,1,0,16,1,52,49,101,109,95,51,49,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,229,136,78,88,1,0,16,1,52,49,101,109,95,51,54,46,49,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,208,49,252,60,1,0,16,1,52,49,45,51,50,109,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,202,72,150,78,2,0,16,1,52,49,45,53,109,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,17,203,209,1,4,0,32,0,52,49,45,55,109,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,9,53,170,174,4,0,32,0,52,49,45,49,109,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,90,152,119,255,4,0,32,0,52,49,45,51,109,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,143,229,59,152,4,0,32,0,52,49,95,57,46,49,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,39,133,157,15,3,0,16,0,52,49,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,235,90,241,209,5,0,64,0,52,49,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,166,195,174,21,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,121,105,50,52,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,223,220,4,48,0,0,0,8,105,111,98,49,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,114,121,45,49,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,229,142,76,111,0,0,16,1,114,121,45,48,57,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,161,2,147,54,0,0,16,1,114,121,45,48,55,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,46,146,233,184,0,0,16,1,101,112,114,45,54,57,51,52,46,49,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,35,114,70,175,0,0,16,1,114,121,45,48,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,67,81,183,223,0,0,32,0,114,121,45,48,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,162,180,104,207,0,0,32,0,114,121,45,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,239,234,0,209,0,0,32,0,101,112,114,45,54,57,50,49,46,49,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,161,5,158,241,0,0,32,0,101,112,114,45,54,57,50,51,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,195,173,136,121,0,0,32,0,101,112,114,45,54,57,50,50,46,49,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,120,122,247,55,0,0,32,0,101,112,114,45,54,57,50,52,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,246,200,189,66,0,0,32,0,112,114,45,53,51,49,55,46,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,184,80,131,100,0,0,0,8,109,119,97,108,107,98,108,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,22,219,156,244,1,0,16,1,109,119,97,108,107,98,108,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,159,242,131,196,1,0,16,1,109,119,97,108,107,98,108,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,150,24,222,11,1,0,16,1,109,119,97,108,107,98,108,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,136,198,159,91,1,0,16,1,109,119,97,108,107,98,108,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,92,225,95,12,1,0,16,1,109,119,97,108,107,98,108,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,4,7,96,158,1,0,16,1,109,119,97,108,107,98,108,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,121,47,105,100,1,0,16,1,109,119,97,108,107,98,108,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,48,165,108,84,1,0,16,1,109,112,114,49,51,50,49,54,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,3,44,45,134,2,0,32,0,109,112,114,49,51,50,49,55,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,236,195,26,125,2,0,32,0,109,112,114,49,51,50,49,56,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,60,57,211,86,2,0,32,0,109,112,114,49,51,50,50,52,46,98,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,123,16,159,197,3,0,32,0,109,112,114,49,51,50,51,49,46,97,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,70,99,233,165,3,0,32,0,109,112,114,49,51,50,50,51,46,98,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,255,96,79,54,3,0,32,0,109,112,114,49,51,50,51,48,46,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,31,9,80,149,3,0,32,0,109,112,114,49,51,50,50,50,46,98,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,237,243,61,82,3,0,32,0,109,112,114,49,51,50,50,57,46,97,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,93,196,13,244,3,0,32,0,101,112,114,49,51,50,50,49,46,98,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,106,84,231,154,3,0,32,0,101,112,114,49,51,50,50,56,46,97,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,190,134,55,222,3,0,32,0,101,112,114,49,51,50,50,53,46,97,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,43,232,194,86,4,0,16,1,109,112,114,49,51,50,49,57,46,98,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,31,6,226,25,19,0,64,0,109,112,114,49,51,50,50,48,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,206,217,212,88,19,0,64,0,109,112,114,49,51,50,52,57,46,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,93,220,62,98,19,0,64,0,184,40,2,0,1,0,0,0,208,155,215,0,248,191,2,0,56,250,6,0,1,0,0,0,212,155,215,0,184,160,2,0,184,164,8,0,1,0,0,0,209,155,215,0,64,246,1,0,88,149,7,0,1,0,0,0,213,155,215,0,136,224,1,0,104,28,8,0,1,0,0,0,215,155,215,0,232,209,1,0,248,23,7,0,1,0,0,0,187,155,215,0,144,189,1,0])
.concat([56,210,6,0,1,0,0,0,205,155,215,0,192,135,2,0,24,163,6,0,1,0,0,0,204,155,215,0,240,108,2,0,152,122,6,0,1,0,0,0,207,155,215,0,96,82,2,0,192,72,6,0,1,0,0,0,206,155,215,0,32,56,2,0,48,123,2,0,1,0,0,0,200,155,215,0,152,30,2,0,96,69,2,0,1,0,0,0,201,155,215,0,232,10,2,0,8,198,7,0,1,0,0,0,203,155,215,0,224,12,8,0,176,223,1,0,1,0,0,0,197,155,215,0,72,198,1,0,192,209,1,0,1,0,0,0,196,155,215,0,24,182,1,0,24,198,1,0,1,0,0,0,199,155,215,0,40,167,1,0,120,189,1,0,1,0,0,0,198,155,215,0,200,149,1,0,248,187,8,0,1,0,0,0,192,155,215,0,56,126,1,0,184,179,8,0,1,0,0,0,193,155,215,0,32,101,1,0,40,180,7,0,1,0,0,0,195,155,215,0,128,176,7,0,192,122,8,0,1,0,0,0,189,155,215,0,208,174,1,0,40,116,8,0,1,0,0,0,188,155,215,0,48,160,1,0,72,110,8,0,1,0,0,0,191,155,215,0,160,140,1,0,184,102,8,0,1,0,0,0,190,155,215,0,56,112,1,0,240,45,8,0,1,0,0,0,184,155,215,0,32,92,1,0,40,38,8,0,1,0,0,0,185,155,215,0,64,77,1,0,208,119,7,0,1,0,0,0,214,155,215,0,248,114,7,0,16,17,8,0,1,0,0,0,211,155,215,0,224,12,8,0,32,77,1,0,1,0,0,0,210,155,215,0,216,70,1,0,88,212,3,0,1,0,0,0,200,154,215,0,40,185,3,0,248,5,8,0,9,0,0,0,0,156,215,0,32,58,1,0,144,250,7,0,9,0,0,0,1,156,215,0,32,58,1,0,109,118,99,117,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,87,190,242,19,1,0,16,1,109,118,99,117,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,13,56,155,94,1,0,16,1,109,118,99,117,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,190,33,243,18,1,0,16,1,109,118,99,117,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,188,36,21,47,1,0,16,1,109,118,99,117,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,219,202,222,95,1,0,16,1,109,118,99,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,205,47,0,188,1,0,16,1,109,118,99,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,38,123,198,1,0,16,1,109,118,99,117,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,99,205,54,79,1,0,16,1,109,118,99,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,188,116,95,250,5,0,32,0,109,118,99,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,143,138,147,113,5,0,32,0,109,118,99,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,7,29,116,146,5,0,32,0,109,118,99,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,198,47,183,188,5,0,32,0,109,118,99,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,228,244,29,127,5,0,32,0,109,118,99,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,3,50,189,144,5,0,32,0,109,118,99,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,39,247,170,103,5,0,32,0,109,118,99,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,232,173,11,139,5,0,32,0,109,118,99,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,149,158,98,65,10,0,16,1,109,118,99,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,107,191,58,150,10,0,16,1,109,118,99,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,99,230,15,133,12,0,64,0,109,118,99,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,150,24,203,124,12,0,64,0,109,118,99,106,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,63,33,100,33,1,0,16,1,109,118,99,106,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,111,200,5,201,1,0,16,1,109,118,99,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,233,28,183,125,1,0,16,1,109,118,99,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,62,109,11,75,1,0,16,1,109,118,99,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,43,163,186,195,1,0,16,1,109,118,99,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,205,47,0,188,1,0,16,1,109,118,99,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,38,123,198,1,0,16,1,109,118,99,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,38,30,221,15,1,0,16,1,109,118,99,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,188,116,95,250,5,0,32,0,109,118,99,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,143,138,147,113,5,0,32,0,109,118,99,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,7,29,116,146,5,0,32,0,109,118,99,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,198,47,183,188,5,0,32,0,109,118,99,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,228,244,29,127,5,0,32,0,109,118,99,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,3,50,189,144,5,0,32,0,109,118,99,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,39,247,170,103,5,0,32,0,109,118,99,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,232,173,11,139,5,0,32,0,109,118,99,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,149,158,98,65,10,0,16,1,109,118,99,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,107,191,58,150,10,0,16,1,109,118,99,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,99,230,15,133,12,0,64,0,109,118,99,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,150,24,203,124,12,0,64,0,109,118,99,97,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,185,167,95,254,1,0,16,1,109,118,99,97,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,28,112,43,8,1,0,16,1,109,118,99,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,233,28,183,125,1,0,16,1,109,118,99,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,62,109,11,75,1,0,16,1,109,118,99,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,43,163,186,195,1,0,16,1,109,118,99,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,205,47,0,188,1,0,16,1,109,118,99,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,38,123,198,1,0,16,1,109,118,99,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,38,30,221,15,1,0,16,1,109,118,99,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,188,116,95,250,5,0,32,0,109,118,99,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,143,138,147,113,5,0,32,0,109,118,99,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,7,29,116,146,5,0,32,0,109,118,99,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,198,47,183,188,5,0,32,0,109,118,99,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,228,244,29,127,5,0,32,0,109,118,99,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,3,50,189,144,5,0,32,0,109,118,99,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,39,247,170,103,5,0,32,0,109,118,99,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,232,173,11,139,5,0,32,0,109,118,99,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,149,158,98,65,10,0,16,1,109,118,99,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,107,191,58,150,10,0,16,1,109,118,99,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,99,230,15,133,12,0,64,0,109,118,99,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,150,24,203,124,12,0,64,0,18,0,0,0,255,255,255,0,0,0,0,0,19,0,0,0,255,255,127,0,0,0,0,0,0,0,0,0,254,0,8,0,200,87,7,0,18,0,0,0,1,7,0,0,40,88,7,0,18,0,0,0,1,7,1,0,96,39,7,0,18,0,0,0,1,7,7,0,144,251,6,0,18,0,0,0,1,7,6,0,184,164,6,0,18,0,0,0,1,7,5,0,80,74,6,0,18,0,0,0,1,7,4,0,192,32,6,0,18,0,0,0,1,7,3,0,192,234,2,0,18,0,0,0,1,7,2,0,32,242,5,0,0,0,0,0,254,0,8,0,160,123,6,0,18,0,0,0,1,56,0,0,40,88,7,0,18,0,0,0,1,56,8,0,96,39,7,0,18,0,0,0,1,56,56,0,144,251,6,0,18,0,0,0,1,56,48,0,184,164,6,0,18,0,0,0,1,56,40,0,80,74,6,0,18,0,0,0,1,56,32,0,192,32,6,0,18,0,0,0,1,56,24,0,192,234,2,0,18,0,0,0,1,56,16,0,32,242,5,0,0,0,0,0,254,0,2,0,144,212,8,0,18,0,0,0,1,64,64,0,96,135,7,0,18,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,152,23,8,0,18,0,0,0,1,128,128,0,192,255,2,0,18,0,0,0,1,128,0,0,208,75,4,0,0,0,0,0,254,0,4,0,112,19,8,0,19,0,0,0,1,3,1,0,248,81,6,0,19,0,0,0,1,3,3,0,248,38,7,0,19,0,0,0,1,3,2,0,176,64,8,0,19,0,0,0,1,3,0,0,128,172,6,0,0,0,0,0,254,0,4,0,72,202,5,0,19,0,0,0,1,12,8,0,80,246,3,0,19,0,0,0,1,12,12,0,248,38,7,0,19,0,0,0,1,12,4,0,112,212,3,0,19,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,4,0,120,12,8,0,19,0,0,0,1,48,0,0,216,244,1,0,19,0,0,0,1,48,16,0,128,5,8,0,19,0,0,0,1,48,32,0,40,71,8,0,19,0,0,0,1,48,48,0,248,38,7,0,0,0,0,0,254,0,2,0,224,117,5,0,19,0,0,0,1,64,0,0,96,135,7,0,19,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,128,128,0,96,135,7,0,19,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,18,0,0,0,255,255,255,0,0,0,0,0,19,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,168,234,7,0,18,0,0,0,1,2,0,0,96,135,7,0,18,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,8,0,160,123,6,0,18,0,0,0,1,28,16,0,32,136,7,0,18,0,0,0,1,28,8,0,40,88,7,0,18,0,0,0,1,28,24,0,96,39,7,0,18,0,0,0,1,28,28,0,144,251,6,0,18,0,0,0,1,28,12,0,184,164,6,0,18,0,0,0,1,28,20,0,80,74,6,0,18,0,0,0,1,28,4,0,192,32,6,0,18,0,0,0,1,28,0,0,16,227,4,0,0,0,0,0,254,0,8,0,200,87,7,0,18,0,0,0,1,224,128,0,32,136,7,0,18,0,0,0,1,224,64,0,40,88,7,0,18,0,0,0,1,224,192,0,96,39,7,0,18,0,0,0,1,224,224,0,144,251,6,0,18,0,0,0,1,224,96,0,184,164,6,0,18,0,0,0,1,224,160,0,80,74,6,0,18,0,0,0,1,224,32,0,192,32,6,0,18,0,0,0,1,224,0,0,16,227,4,0,0,0,0,0,254,0,4,0,72,202,5,0,19,0,0,0,1,12,4,0,80,246,3,0,19,0,0,0,1,12,12,0,248,38,7,0,19,0,0,0,1,12,8,0,112,212,3,0,19,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,4,0,128,129,4,0,19,0,0,0,1,192,64,0,208,75,4,0,19,0,0,0,1,192,192,0,8,49,4,0,19,0,0,0,1,192,128,0,152,21,4,0,19,0,0,0,1,192,0,0,72,246,3,0,0,0,0,0,109,115,117,95,51,48,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,22,200,99,217,1,0,16,1,109,115,117,95,51,53,46,49,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,179,121,241,114,1,0,16,1,109,115,117,95,51,49,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,4,121,205,32,1,0,16,1,109,115,117,95,51,54,46,49,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,128,192,136,191,1,0,16,1,109,115,45,51,50,109,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,252,221,117,36,2,0,16,1,109,115,45,53,109,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,226,231,15,192,4,0,32,0,109,115,45,55,109,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,197,202,202,76,4,0,32,0,109,115,45,49,109,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,190,43,13,4,0,32,0,109,115,45,51,109,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,244,91,26,58,4,0,32,0,109,115,95,48,57,46,49,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,25,149,178,87,3,0,16,0,109,115,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,13,233,100,251,5,0,64,0,109,115,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,185,146,248,116,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,109,115,50,52,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,109,190,109,99,0,0,0,8,105,111,98,49,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,109,115,106,95,51,54,46,49])
.concat([50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,80,239,240,4,1,0,16,1,109,115,106,95,52,50,46,49,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,205,185,203,159,1,0,16,1,109,115,106,95,51,55,46,49,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,112,13,6,108,1,0,16,1,109,115,106,95,52,51,46,49,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,135,119,199,174,1,0,16,1,109,115,95,51,52,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,45,166,89,14,1,0,16,1,109,115,95,52,48,46,49,48,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,58,222,186,186,1,0,16,1,109,115,95,51,53,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,209,153,218,3,1,0,16,1,109,115,95,52,49,46,49,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,234,153,223,250,1,0,16,1,109,115,95,48,57,46,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,246,230,222,74,4,0,32,0,109,115,95,48,49,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,136,27,171,247,4,0,32,0,109,115,95,49,51,46,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,75,220,26,224,4,0,32,0,109,115,95,48,53,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,105,35,44,246,4,0,32,0,109,115,95,50,52,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,161,163,100,190,4,0,32,0,109,115,95,49,55,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,95,102,193,11,4,0,32,0,109,115,95,51,56,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,213,46,74,144,4,0,32,0,109,115,95,51,50,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,48,197,137,61,4,0,32,0,109,115,95,49,48,46,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,24,7,44,240,4,0,32,0,109,115,95,48,50,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,5,164,113,208,4,0,32,0,109,115,95,49,52,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,223,228,178,223,4,0,32,0,109,115,95,48,54,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,145,42,206,211,4,0,32,0,109,115,95,50,53,46,55,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,86,157,25,15,4,0,32,0,109,115,95,49,56,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,242,109,167,27,4,0,32,0,109,115,95,51,57,46,57,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,134,206,239,1,4,0,32,0,109,115,95,51,51,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,252,222,37,206,4,0,32,0,109,115,95,50,51,46,49,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,25,149,178,87,3,0,16,0,109,115,95,51,48,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,13,233,100,251,5,0,64,0,109,115,95,51,49,46,49,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,185,146,248,116,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,109,115,50,50,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,0,0,0,0,0,0,24,105,111,98,49,46,49,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,109,118,115,117,46,48,51,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,21,171,100,6,1,0,16,1,109,118,115,117,46,48,52,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,238,96,224,151,1,0,16,1,109,118,115,46,48,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,66,197,31,146,1,0,16,1,109,118,115,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,48,48,159,149,1,0,16,1,109,118,115,46,48,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,219,91,145,127,1,0,16,1,109,118,115,46,48,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,132,56,129,194,1,0,16,1,109,118,115,46,48,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,136,160,59,1,0,16,1,109,118,115,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,152,186,13,207,1,0,16,1,109,118,115,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,217,95,176,41,5,0,32,0,109,118,115,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,241,204,221,250,5,0,32,0,109,118,115,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,199,244,170,151,5,0,32,0,109,118,115,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,21,233,112,203,5,0,32,0,109,118,115,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,45,151,177,179,5,0,32,0,109,118,115,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,93,219,170,8,5,0,32,0,109,118,115,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,53,139,34,193,5,0,32,0,109,118,115,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,194,198,108,54,5,0,32,0,109,118,115,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,36,35,37,104,10,0,16,1,109,118,115,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,61,119,78,179,10,0,16,1,109,118,115,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,112,151,33,134,12,0,64,0,109,118,115,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,104,127,253,242,12,0,64,0,109,118,115,106,46,48,51,105,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,145,182,203,216,1,0,16,1,109,118,115,106,46,48,52,105,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,206,26,116,50,1,0,16,1,109,118,115,46,48,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,195,13,135,119,1,0,16,1,109,118,115,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,48,48,159,149,1,0,16,1,109,118,115,46,48,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,219,91,145,127,1,0,16,1,109,118,115,46,48,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,132,56,129,194,1,0,16,1,109,118,115,46,48,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,136,160,59,1,0,16,1,109,118,115,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,152,186,13,207,1,0,16,1,109,118,115,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,217,95,176,41,5,0,32,0,109,118,115,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,241,204,221,250,5,0,32,0,109,118,115,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,199,244,170,151,5,0,32,0,109,118,115,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,21,233,112,203,5,0,32,0,109,118,115,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,45,151,177,179,5,0,32,0,109,118,115,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,93,219,170,8,5,0,32,0,109,118,115,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,53,139,34,193,5,0,32,0,109,118,115,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,194,198,108,54,5,0,32,0,109,118,115,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,36,35,37,104,10,0,16,1,109,118,115,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,61,119,78,179,10,0,16,1,109,118,115,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,112,151,33,134,12,0,64,0,109,118,115,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,104,127,253,242,12,0,64,0,109,118,115,104,46,48,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,30,244,96,79,1,0,16,1,109,118,115,104,46,48,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,18,236,8,220,1,0,16,1,109,118,115,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,203,224,93,26,1,0,16,1,109,118,115,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,48,48,159,149,1,0,16,1,109,118,115,46,48,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,219,91,145,127,1,0,16,1,109,118,115,46,48,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,132,56,129,194,1,0,16,1,109,118,115,46,48,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,136,160,59,1,0,16,1,109,118,115,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,152,186,13,207,1,0,16,1,109,118,115,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,217,95,176,41,5,0,32,0,109,118,115,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,241,204,221,250,5,0,32,0,109,118,115,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,199,244,170,151,5,0,32,0,109,118,115,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,21,233,112,203,5,0,32,0,109,118,115,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,45,151,177,179,5,0,32,0,109,118,115,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,93,219,170,8,5,0,32,0,109,118,115,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,53,139,34,193,5,0,32,0,109,118,115,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,194,198,108,54,5,0,32,0,109,118,115,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,36,35,37,104,10,0,16,1,109,118,115,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,61,119,78,179,10,0,16,1,109,118,115,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,112,151,33,134,12,0,64,0,109,118,115,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,104,127,253,242,12,0,64,0,109,118,115,98,46,48,51,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,239,149,56,20,1,0,16,1,109,118,115,98,46,48,52,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,108,136,138,221,1,0,16,1,109,118,115,46,48,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,66,197,31,146,1,0,16,1,109,118,115,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,48,48,159,149,1,0,16,1,109,118,115,46,48,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,219,91,145,127,1,0,16,1,109,118,115,46,48,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,132,56,129,194,1,0,16,1,109,118,115,46,48,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,136,160,59,1,0,16,1,109,118,115,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,152,186,13,207,1,0,16,1,109,118,115,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,217,95,176,41,5,0,32,0,109,118,115,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,241,204,221,250,5,0,32,0,109,118,115,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,199,244,170,151,5,0,32,0,109,118,115,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,21,233,112,203,5,0,32,0,109,118,115,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,45,151,177,179,5,0,32,0,109,118,115,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,93,219,170,8,5,0,32,0,109,118,115,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,53,139,34,193,5,0,32,0,109,118,115,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,194,198,108,54,5,0,32,0,109,118,115,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,36,35,37,104,10,0,16,1,109,118,115,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,61,119,78,179,10,0,16,1,109,118,115,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,112,151,33,134,12,0,64,0,109,118,115,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,104,127,253,242,12,0,64,0,109,118,115,97,46,48,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,22,55,134,91,1,0,16,1,109,118,115,97,46,48,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,95,230,134,72,1,0,16,1,109,118,115,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,203,224,93,26,1,0,16,1,109,118,115,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,48,48,159,149,1,0,16,1,109,118,115,46,48,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,219,91,145,127,1,0,16,1,109,118,115,46,48,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,132,56,129,194,1,0,16,1,109,118,115,46,48,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,136,160,59,1,0,16,1,109,118,115,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,152,186,13,207,1,0,16,1,109,118,115,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,217,95,176,41,5,0,32,0,109,118,115,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,241,204,221,250,5,0,32,0,109,118,115,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,199,244,170,151,5,0,32,0,109,118,115,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,21,233,112,203,5,0,32,0,109,118,115,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,45,151,177,179,5,0,32,0,109,118,115,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,93,219,170,8,5,0,32,0,109,118,115,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,53,139,34,193,5,0,32,0,109,118,115,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,194,198,108,54,5,0,32,0,109,118,115,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,36,35,37,104,10,0,16,1,109,118,115,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,61,119,78,179,10,0,16,1,109,118,115,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,112,151,33,134,12,0,64,0,109,118,115,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,104,127,253,242,12,0,64,0,14,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,32,4,2,0,14,0,0,0,1,3,0,0,40,88,7,0,14,0,0,0,1,3,1,0,96,39,7,0,14,0,0,0,1,3,3,0,144,251,6,0,14,0,0,0,1,3,2,0,184,164,6,0,0,0,0,0,254,0,4,0,248,200,1,0,14,0,0,0,1,12,12,0,24,205,7,0,14,0,0,0,1,12,8,0,192,255,2,0,14,0,0,0,1,12,4,0,208,75,4,0,14,0,0,0,1,12,0,0,8,49,4,0,0,0,0,0,254,0,2,0,144,190,1,0,14,0,0,0,1,16,16,0,248,38,7,0,14,0,0,0,1,16,0,0,80,246,3,0,0,0,0,0,254,0,2,0,56,183,1,0,14,0,0,0,1,32,32,0,248,38,7,0,14,0,0,0,1,32,0,0,64,111,3,0,0,0,0,0,254,0,2,0,152,169,1,0,14,0,0,0,1,64,64,0,248,38,7,0,14,0,0,0,1,64,0,0,112,134,3,0,0,0,0,0,254,0,2,0,232,75,4,0,14,0,0,0,1,128,128,0,96,135,7,0,14,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,112,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,225,205,160,222,1,0,16,1,112,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,81,119,1,200,1,0,16,1,112,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,132,25,146,184,1,0,16,1,112,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,76,117,201,179,1,0,16,1,112,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,188,173,148,141,1,0,16,1,112,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,255,33,201,172,1,0,16,1,97,116,119,45,54,119,45,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,113,163,66,175,2,0,16,1,97,116,119,45,54,121,45,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,2,137,43,134,2,0,16,1,97,116,119,45,54,122,45,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,200,108,57,160,2,0,16,1,103,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,22,209,207,14,4,0,32,0,103,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,198,163,191,0,4,0,32,0,97,116,119,45,112,114,111,109,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,136,177,93,198,7,0,32,0,109,112,110,101,46,48,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,178,249,240,110,1,0,16,1,109,112,110,101,46,48,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,187,104,164,48,1,0,16,1,109,112,110,45,115,105,109,109,46,48,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,107,182,141,56,6,0,32,0,109,112,110,45,115,105,109,109,46,48,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,148,180,241,175,6,0,32,0,109,112,110,45,115,105,109,109,46,48,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,123,133,196,169,6,0,32,0,109,112,110,45,115,105,109,109,46,48,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,34,223,89,247,6,0,32,0,109,112,110,45,115,105,109,109,46,48,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,32,183,198,222,6,0,32,0,109,112,110,45,115,105,109,109,46,48,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,24,76,119,248,6,0,32,0,109,112,110,45,115,105,109,109,46,48,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,236,164,174,194,6,0,32,0,109,112,110,45,115,105,109,109,46,48,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,51,220,214,132,6,0,32,0,109,112,110,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,182,173,199,144,10,0,16,1,109,112,110,45,115,105,109,109,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,33,46,138,49,13,0,64,0,109,112,110,45,115,105,109,109,46,48,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,232,244,98,84,13,0,64,0,168,86,7,0,1,0,0,0,212,47,216,0,248,191,2,0,24,38,7,0,1,0,0,0,208,47,216,0,184,160,2,0,56,210,6,0,1,0,0,0,35,48,216,0,192,135,2,0,24,163,6,0,1,0,0,0,34,48,216,0,240,108,2,0,152,122,6,0,1,0,0,0,33,48,216,0,96,82,2,0,192,72,6,0,1,0,0,0,32,48,216,0,32,56,2,0,8,227,6,0,1,0,0,0,36,48,216,0,152,30,2,0,136,222,6,0,1,0,0,0,37,48,216,0,232,10,2,0,40,246,1,0,1,0,0,0,213,47,216,0,64,246,1,0,144,236,1,0,1,0,0,0,209,47,216,0,136,224,1,0,176,223,1,0,1,0,0,0,43,48,216,0,72,198,1,0,192,209,1,0,1,0,0,0,42,48,216,0,24,182,1,0,24,198,1,0,1,0,0,0,41,48,216,0,40,167,1,0,120,189,1,0,1,0,0,0,40,48,216,0,200,149,1,0,120,217,6,0,1,0,0,0,44,48,216,0,56,126,1,0,48,212,6,0,1,0,0,0,45,48,216,0,32,101,1,0,88,212,3,0,1,0,0,0,144,46,216,0,40,185,3,0,240,152,1,0,1,0,0,0,201,47,216,0,216,70,1,0,16,17,8,0,1,0,0,0,202,47,216,0,224,12,8,0,136,67,2,0,1,0,0,0,176,48,216,0,152,138,8,0,8,66,2,0,1,0,0,0,184,48,216,0,48,119,7,0,109,119,50,46,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,217,180,17,124,1,0,16,1,109,119,50,46,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,190,98,99,27,1,0,16,1,109,119,50,46,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,75,186,216,79,1,0,16,1,109,119,50,46,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,13,159,135,86,1,0,16,1,109,119,50,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,235,49,98,194,2,0,16,1,109,119,50,46,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,70,166,72,187,2,0,16,1,109,119,50,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,160,26,250,197,4,0,32,0,109,119,50,46,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,82,198,204,166,4,0,32,0,109,119,50,46,99,108,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,108,76,97,153,7,0,32,0,13,0,0,0,255,255,0,0,0,0,0,0,14,0,0,0,255,255,3,0,0,0,0,0,15,0,0,0,255,255,12,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,14,0,0,0,1,3,3,0,8,49,4,0,14,0,0,0,1,3,2,0,152,21,4,0,14,0,0,0,1,3,1,0,72,246,3,0,14,0,0,0,1,3,0,0,16,227,4,0,0,0,0,0,254,0,4,0,32,4,2,0,15,0,0,0,1,6,4,0,128,103,7,0,15,0,0,0,1,6,6,0,80,196,7,0,15,0,0,0,1,6,2,0,0,90,2,0,15,0,0,0,1,6,0,0,72,74,2,0,0,0,0,0,254,0,2,0,200,30,2,0,15,0,0,0,1,8,8,0,120,97,1,0,15,0,0,0,1,8,0,0,96,19,1,0,109,113,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,236,19,44,19,1,0,16,1,109,113,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,241,116,235,200,1,0,16,1,109,113,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,137,90,150,51,1,0,16,1,109,113,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,23,29,134,163,1,0,16,1,109,113,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,103,156,207,139,1,0,16,1,109,113,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,169,205,80,87,1,0,16,1,109,113,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,91,254,215,120,1,0,16,1,109,113,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,213,238,25,73,1,0,16,1,109,113,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,6,200,94,181,4,0,32,0,109,113,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,19,14,125,158,4,0,32,0,109,113,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,219,224,238,102,4,0,32,0,109,113,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,13,91,219,166,4,0,32,0,118,105,100,95,101,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,84,139,135,11,7,0,32,0,11,0,0,0,255,255,0,0,0,0,0,0,12,0,0,0,255,255,0,0,0,0,0,0,13,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,11,0,0,0,1,32,0,0,120,97,1,0,11,0,0,0,1,32,32,0,96,19,1,0,0,0,0,0,254,0,4,0,72,202,5,0,12,0,0,0,1,192,0,0,80,246,3,0,12,0,0,0,1,192,64,0,80,124,6,0,12,0,0,0,1,192,128,0,112,212,3,0,12,0,0,0,1,192,192,0,248,160,5,0,0,0,0,0,254,0,4,0,200,87,7,0,13,0,0,0,1,3,3,0,144,102,8,0,13,0,0,0,1,3,2,0,176,45,8,0,13,0,0,0,1,3,1,0,224,127,8,0,13,0,0,0,1,3,0,0,32,123,8,0,0,0,0,0,254,0,4,0,160,123,6,0,13,0,0,0,1,12,0,0,128,103,7,0,13,0,0,0,1,12,4,0,80,196,7,0,13,0,0,0,1,12,8,0,0,90,2,0,13,0,0,0,1,12,12,0,104,151,6,0,0,0,0,0,54,48,46,49,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,230,89,40,50,1,0,16,1,54,49,46,50,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,45,144,73,194,1,0,16,1,54,50,46,51,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,171,176,162,41,1,0,16,1,54,51,46,52,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,109,90,106,76,1,0,16,1,54,52,46,53,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,166,120,211,6,1,0,16,1,54,53,46,54,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,39,169,132,110,1,0,16,1,54,54,46,55,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,206,216,60,242,1,0,16,1,54,55,46,56,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,213,85,218,102,1,0,16,1,54,56,46,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,134,61,102,120,4,0,32,0,54,57,46,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,211,80,44,22,4,0,32,0,112,114,111,109,45,115,110,55,52,115,50,56,56,110,45,55,49,46,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,135,125,12,106,7,0,32,0,103,97,108,120,46,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,125,0,228,121,1,0,16,1,112,114,103,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,48,11,88,89,1,0,16,1,112,114,103,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,18,157,78,182,1,0,16,1,115,117,112,101,114,103,46,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,83,247,99,148,1,0,16,1,112,114,103,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,135,137,183,139,1,0,16,1,99,97,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,221,113,66,7,4,0,32,0,99,97,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,151,3,217,132,4,0,32,0,54,108,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,103,148,172,195,7,0,32,0,97,108,105,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,180,202,206,13,1,0,16,1,97,108,105,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,167,117,238,198,1,0,16,1,97,108,105,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,233,231,27,205,1,0,16,1,97,108,105,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,8,63,176,131,1,0,16,1,97,108,105,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,29,246,60,111,1,0,16,1,97,108,105,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,50,212,105,225,1,0,16,1,97,108,105,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,115,75,246,65,1,0,16,1,97,108,105,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,118,232,46,247,1,0,16,1,97,108,105,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,60,118,251,183,1,0,16,1,97,108,105,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,121,145,5,177,1,0,16,1,97,108,105,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,198,161,121,158,1,0,16,1,97,108,105,49,51,46,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,246,123,40,161,4,0,32,0,97,108,105,49,50,46,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,129,20,143,82,4,0,32,0,54,108,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,103,148,172,195,7,0,32,0,12,0,0,0,255,255,0,0,0,0,0,0,13,0,0,0,255,255,0,0,0,0,0,0,14,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,12,0,0,0,1,32,0,0,120,97,1,0,12,0,0,0,1,32,32,0,96,19,1,0,0,0,0,0,254,0,2,0,232,75,4,0,12,0,0,0,1,64,0,0,96,135,7,0,12,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,4,0,32,4,2,0,13,0,0,0,1,192,64,0,224,127,8,0,13,0,0,0,1,192,0,0,32,123,8,0,13,0,0,0,1,192,128,0,192,110,8,0,13,0,0,0,1,192,192,0,104,151,6,0,0,0,0,0,254,0,4,0,64,37,5,0,14,0,0,0,1,3,1,0,152,120,3,0,14,0,0,0,1,3,2,0,136,120,6,0,14,0,0,0,1,3,3,0,176,114,3,0,14,0,0,0,1,3,0,0,120,7,5,0,0,0,0,0,254,0,2,0,128,129,4,0,14,0,0,0,1,4,0,0,8,49,4,0,14,0,0,0,1,4,4,0,72,246,3,0,109,109,120,117,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,153,181,101,171,1,0,16,1,109,109,120,117,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,108,252,53,1,1,0,16,1,109,109,120,117,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,132,43,253,241,1,0,16,1,109,109,120,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,24,135,116,4,5,0,32,0,109,109,120,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,68,79,7,56,5,0,32,0,109,109,120,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,53,94,99,228,5,0,32,0,109,109,120,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,242,163,0,68,5,0,32,0,109,109,120,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,145,244,43,213,5,0,32,0,109,109,120,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,128,7,247,35,5,0,32,0,109,109,120,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,213,201,98,37,5,0,32,0,109,109,120,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,135,150,58,88,5,0,32,0,109,109,120,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,113,129,126,197,10,0,16,1,109,109,120,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,159,179,128,65,12,0,64,0,109,109,120,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,89,42,226,149,12,0,64,0,109,119,57,54,95,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,177,155,48,177,0,0,16,1,109,119,57,54,95,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,179,43,137,165,0,0,16,1,109,119,57,54,95,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,223,50,112,0,0,16,1,109,119,57,54,95,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,90,222,145,0,0,16,1,109,119,57,54,95,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,111,230,184,0,0,16,1,109,119,57,54,95,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,248,4,122,231,0,0,16,1,109,119,57,54,95,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,211,46,17,38,0,0,16,1,109,119,57,54,95,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,70,74,55,233,0,0,16,1,109,119,57,54,95,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,47,21,131,57,0,0,32,0,109,119,57,54,95,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,158,101,138,231,0,0,64,0,109,119,57,54,95,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,12,250,96,0,0,64,0,18,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,216,128,8,0,18,0,0,0,1,8,0,0,208,233,4,0,18,0,0,0,1,8,8,0,72,197,4,0,0,0,0,0,254,0,4,0,184,40,2,0,18,0,0,0,2,48,0,0,200,201,5,0,18,0,0,0,0,8,0,0,0,0,0,0,18,0,0,0,2,48,16,0,224,67,5,0,18,0,0,0,0,8,0,0,0,0,0,0,18,0,0,0,2,48,32,0,152,160,5,0,18,0,0,0,0,8,0,0,0,0,0,0,18,0,0,0,2,48,48,0,224,189,3,0,18,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,254,0,4,0,184,164,8,0,18,0,0,0,2,192,0,0,200,201,5,0,18,0,0,0,0,8,0,0,0,0,0,0,18,0,0,0,2,192,64,0,224,67,5,0,18,0,0,0,0,8,0,0,0,0,0,0,18,0,0,0,2,192,128,0,152,160,5,0,18,0,0,0,0,8,0,0,0,0,0,0,18,0,0,0,2,192,192,0,224,189,3,0,18,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,254,0,4,0,184,40,2,0,18,0,0,0,2,48,0,0,200,201,5,0,18,0,0,0,0,8,8,0,0,0,0,0,18,0,0,0,2,48,16,0,224,67,5,0,18,0,0,0,0,8,8,0,0,0,0,0,18,0,0,0,2,48,32,0,144,127,5,0,18,0,0,0,0,8,8,0,0,0,0,0,18,0,0,0,2,48,48,0,168,98,5,0,18,0,0,0,0,8,8,0,0,0,0,0,0,0,0,0,254,0,4,0,184,164,8,0,18,0,0,0,2,192,0,0,200,201,5,0,18,0,0,0,0,8,8,0,0,0,0,0,18,0,0,0,2,192,64,0,224,67,5,0,18,0,0,0,0,8,8,0,0,0,0,0,18,0,0,0,2,192,128,0,144,127,5,0,18,0,0,0,0,8,8,0,0,0,0,0,18,0,0,0,2,192,192,0,168,98,5,0,18,0,0,0,0,8,8,0,0,0,0,0,109,97,50,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,53,160,103,19,1,0,16,1,109,97,50,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,33,109,148,104,1,0,16,1,109,97,50,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,229,174,99,118,1,0,16,1,109,97,50,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,93,71,135,151,1,0,16,1,109,97,50,50,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,84,235,236,44,1,0,16,1,109,97,50,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,201,143,19,133,1,0,16,1,109,97,49,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,107,115,239,139,2,0,16,1,109,97,49,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,151,63,123,246,2,0,16,1,109,97,49,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,6,48,112,159,4,0,32,0,109,97,49,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,177,204,13,237,4,0,32,0,109,105,110,101,102,108,100,46,99,108,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,142,54,119,24,7,0,32,0,14,0,0,0,255,255,0,0,0,0,0,0,15,0,0,0,255,255,2,0,0,0,0,0,16,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,112,177,1,0,14,0,0,0,1,2,0,0,192,255,2,0,14,0,0,0,1,2,2,0,8,49,4,0,0,0,0,0,254,0,2,0,128,129,4,0,15,0,0,0,1,1,0,0,8,49,4,0,15,0,0,0,1,1,1,0,72,246,3,0,0,0,0,0,254,0,2,0,168,234,7,0,15,0,0,0,1,2,0,0,96,135,7,0,15,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,2,0,32,4,2,0,16,0,0,0,1,2,0,0,128,103,7,0,16,0,0,0,1,2,2,0,56,52,2,0,0,0,0,0,254,0,4,0,72,202,5,0,16,0,0,0,1,12,0,0,80,246,3,0,16,0,0,0,1,12,4,0,80,124,6,0,16,0,0,0,1,12,8,0,112,212,3,0,16,0,0,0,1,12,12,0,248,160,5,0,102,108,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,162,7,149,47,0,0,16,1,102,108,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,159,173,21,56,0,0,16,1,102,108,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,78,53,40,19,0,0,16,1,102,108,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,94,149,179,227,0,0,16,1,102,108,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,223,11,54,102,0,0,16,1,102,108,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,6,186,90,215,0,0,32,0,102,108,48,52,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,121,187,91,143,0,0,32,0,102,108,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,16,89,125,144,0,0,32,0,102,108,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,60,192,54,169,0,0,32,0,102,108,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,92,196,104,32,0,0,32,0,102,108,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,185,26,36,183,0,0,32,0,102,108,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,180,115,107,184,0,0,32,0,102,108,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,41,91,36,146,0,0,32,0,102,108,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,167,53,139,44,0,0,32,0,102,108,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,60,237,239,30,0,0,32,0,102,108,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,1,184,111,117,0,0,32,0,102,108,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,32,193,210,84,0,0,32,0,102,108,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,93,150,41,144,0,0,64,0,55,49,49,52,46,112,114,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,251,159,83,235,0,0,0,8,112,97,108,49,54,114,52,97,45,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,224,184,143,210,0,0,0,8,112,97,108,49,54,108,56,98,45,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,227,145,181,188,0,0,0,8,112,97,108,49,54,108,56,97,45,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,172,114,41,225,0,0,0,8,112,97,108,49,54,108,56,97,45,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,73,126,67,198,0,0,0,8,112,97,108,49,54,108,56,98,45,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,103,58,238,233,0,0,0,8,112,97,108,49,54,108,56,97,45,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,190,122,177,35,0,0,0,8,24,0,0,0,255,255,255,0,0,0,0,0,25,0,0,0,255,255,191,0,0,0,0,0,0,0,0,0,254,0,4,0,200,87,7,0,24,0,0,0,1,3,0,0,176,45,8,0,24,0,0,0,1,3,1,0,224,127,8,0,24,0,0,0,1,3,3,0,32,123,8,0,24,0,0,0,1,3,2,0,192,110,8,0,0,0,0,0,254,0,4,0,160,123,6,0,24,0,0,0,1,12,0,0,176,45,8,0,24,0,0,0,1,12,4,0,224,127,8,0,24,0,0,0,1,12,12,0,32,123,8,0,24,0,0,0,1,12,8,0,192,110,8,0,0,0,0,0,254,0,2,0,232,75,4,0,24,0,0,0,1,16,16,0,96,135,7,0,24,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,24,0,0,0,1,32,0,0,96,135,7,0,24,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,24,0,0,0,1,64,64,0,96,135,7,0,24,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,25,0,0,0,1,3,1,0,192,255,2,0,25,0,0,0,1,3,3,0,8,49,4,0,25,0,0,0,1,3,2,0,72,246,3,0,25,0,0,0,1,3,0,0,112,49,6,0,0,0,0,0,254,0,4,0,72,202,5,0,25,0,0,0,1,12,8,0,80,246,3,0,25,0,0,0,1,12,12,0,248,38,7,0,25,0,0,0,1,12,4,0,112,212,3,0,25,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,2,0,192,125,6,0,25,0,0,0,1,64,64,0,56,111,3,0,25,0,0,0,1,64,0,0,104,134,3,0,102,104,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,81,42,99,109,0,0,16,1,102,104,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,132,51,20,69,0,0,16,1,102,108,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,78,53,40,19,0,0,16,1,102,108,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,94,149,179,227,0,0,16,1,102,104,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,50,111,115,0,0,0,16,1,102,107,95,48,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,83,116,219,60,0,0,32,0,102,107,95,48,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,12,162,91,50,0,0,32,0,102,108,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,16,89,125,144,0,0,32,0,102,108,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,60,192,54,169,0,0,32,0,102,108,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,92,196,104,32,0,0,32,0,102,108,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,185,26,36,183,0,0,32,0,102,108,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,180,115,107,184,0,0,32,0,102,108,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,41,91,36,146,0,0,32,0,102,108,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,167,53,139,44,0,0,32,0,102,108,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,60,237,239,30,0,0,32,0,102,108,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,1,184,111,117,0,0,32,0,102,108,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,32,193,210,84,0,0,32,0,102,104,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,78,162,176,199,0,0,64,0,55,49,49,52,46,112,114,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,251,159,83,235,0,0,0,8,112,97,108,49,54,114,52,97,45,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,224,184,143,210,0,0,0,8,112,97,108,49,54,108,56,98,45,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,227,145,181,188,0,0,0,8,112,97,108,49,54,108,56,97,45,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,172,114,41,225,0,0,0,8,112,97,108,49,54,108,56,97,45,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,73,126,67,198,0,0,0,8,112,97,108,49,54,108,56,98,45,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,103,58,238,233,0,0,0,8,112,97,108,49,54,108,56,97,45,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,190,122,177,35,0,0,0,8,109,103,45,49,46,49,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,107,234,2,191,0,0,16,1,109,103,45,50,46,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,12,27,20,100,0,0,16,1,109,103,45,49,46,49,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,5,8,106,253,0,0,32,0,109,103,45,50,46,49,52,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,30,135,110,226,0,0,32,0,109,103,45,51,46,49,54,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,154,29,120,221,0,0,32,0,109,103,45,52,46,49,55,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,121,204,175,151,0,0,32,0,109,103,45,54,46,52,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,98,78,89,52,0,0,32,0,109,103,45,55,46,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,6,200,4,243,0,0,32,0,109,103,45,53,46,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,241,50,3,23,0,0,64,0,44,0,0,0,255,255,239,0,0,0,0,0,45,0,0,0,255,255,143,0,0,0,0,0,0,0,0,0,254,0,8,0,200,87,7,0,44,0,0,0,1,7,0,0,144,102,8,0,44,0,0,0,1,7,1,0,176,45,8,0,44,0,0,0,1,7,2,0,224,127,8,0,44,0,0,0,1,7,7,0,32,123,8,0,44,0,0,0,1,7,6,0,192,110,8,0,44,0,0,0,1,7,5,0,96,102,7,0,44,0,0,0,1,7,4,0,184,105,6,0,44,0,0,0,1,7,3,0,192,100,6,0,0,0,0,0,254,0,2,0,48,96,6,0,44,0,0,0,1,8,8,0,144,90,6,0,44,0,0,0,1,8,0,0,232,82,6,0,0,0,0,0,254,0,2,0,152,76,6,0,44,0,0,0,1,16,16,0,200,70,6,0,44,0,0,0,1,16,0,0,24,66,6,0,0,0,0,0,254,0,2,0,144,212,8,0,44,0,0,0,1,32,32,0,96,135,7,0,44,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,72,4,1,0,44,0,0,0,1,64,64,0,96,135,7,0,44,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,44,0,0,0,1,128,128,0,96,135,7,0,44,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,4,0,32,54,6,0,45,0,0,0,1,3,3,0,96,165,7,0,45,0,0,0,1,3,2,0,248,38,7,0,45,0,0,0,1,3,1,0,104,159,7,0,45,0,0,0,1,3,0,0,16,40,6,0,0,0,0,0,254,0,4,0,200,34,6,0,45,0,0,0,1,12,12,0,96,165,7,0,45,0,0,0,1,12,8,0,248,38,7,0,45,0,0,0,1,12,4,0,104,159,7,0,45,0,0,0,1,12,0,0,16,40,6,0,0,0,0,0,254,0,2,0,16,49,4,0,45,0,0,0,1,16,16,0,96,135,7,0,45,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,45,0,0,0,1,32,32,0,96,135,7,0,45,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,0,27,6,0,45,0,0,0,1,64,64,0,96,135,7,0,45,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,100,49,50,45,49,50,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,178,130,111,85,2,0,16,1,100,49,50,45,49,49,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,141,226,158,175,2,0,16,1,100,49,50,45,48,55,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,54,81,127,224,2,0,16,1,100,49,50,45,48,54,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,49,247,29,19,2,0,16,1,100,49,50,45,49,51,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,73,38,202,188,9,0,16,1,100,49,50,45,48,51,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,192,152,180,70,12,0,32,0,100,49,50,45,48,52,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,65,209,102,171,12,0,32,0,100,49,50,45,48,49,46,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,185,35,21,184,15,0,32,0,100,49,50,45,48,50,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,116,62,38,121,24,0,64,0,100,49,50,45,48,53,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,197,54,208,127,25,0,64,0,21,0,0,0,255,255,255,0,0,0,0,0,22,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,21,0,0,0,1,2,2,0,96,135,7,0,21,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,21,0,0,0,1,4,4,0,96,135,7,0,21,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,21,0,0,0,1,8,0,0,96,135,7,0,21,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,21,0,0,0,1,48,0,0,16,242,7,0,21,0,0,0,1,48,16,0,104,236,7,0,21,0,0,0,1,48,48,0,128,230,7,0,21,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,21,0,0,0,1,192,0,0,16,242,7,0,21,0,0,0,1,192,64,0,104,236,7,0,21,0,0,0,1,192,192,0,128,230,7,0,21,0,0,0,1,192,128,0,184,164,6,0,0,0,0,0,254,0,4,0,72,202,5,0,22,0,0,0,1,3,2,0,80,246,3,0,22,0,0,0,1,3,3,0,80,124,6,0,22,0,0,0,1,3,1,0,112,212,3,0,22,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,64,37,5,0,22,0,0,0,1,12,8,0,112,228,4,0,22,0,0,0,1,12,12,0,8,225,4,0,22,0,0,0,1,12,4,0,208,220,4,0,22,0,0,0,1,12,0,0,40,160,4,0,0,0,0,0,254,0,4,0,128,129,4,0,22,0,0,0,1,48,0,0,192,255,2,0,22,0,0,0,1,48,16,0,208,75,4,0,22,0,0,0,1,48,48,0,8,49,4,0,22,0,0,0,1,48,32,0,72,246,3,0,0,0,0,0,254,0,2,0,104,159,3,0,22,0,0,0,1,64,0,0,96,135,7,0,22,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,6,0,22,0,0,0,1,128,0,0,8,208,6,0,22,0,0,0,1,128,128,0,88,204,6,0,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,177,0,0,0,0,0,21,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,240,122,4,0,19,0,0,0,1,1,1,0,8,56,3,0,19,0,0,0,1,1,0,0,16,77,4,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,2,2,0,96,135,7,0,19,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,4,4,0,96,135,7,0,19,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,8,0,0,96,135,7,0,19,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,19,0,0,0,1,48,16,0,96,39,7,0,19,0,0,0,1,48,48,0,144,251,6,0,19,0,0,0,1,48,0,0,120,211,6,0,19,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,19,0,0,0,1,192,64,0,96,39,7,0,19,0,0,0,1,192,192,0,144,251,6,0,19,0,0,0,1,192,0,0,120,211,6,0,19,0,0,0,1,192,128,0,184,164,6,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,3,3,0,248,38,7,0,20,0,0,0,1,3,2,0,80,246,3,0,20,0,0,0,1,3,1,0,112,212,3,0,20,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,64,37,5,0,20,0,0,0,1,12,12,0,120,7,5,0,20,0,0,0,1,12,8,0,224,52,3,0,20,0,0,0,1,12,0,0,64,50,3,0,20,0,0,0,1,12,4,0,168,48,3,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,48,16,0,192,255,2,0,20,0,0,0,1,48,0,0,208,75,4,0,20,0,0,0,1,48,48,0,8,49,4,0,20,0,0,0,1,48,32,0,72,246,3,0,0,0,0,0,254,0,2,0,240,122,4,0,20,0,0,0,1,64,64,0,224,120,4,0,20,0,0,0,1,64,0,0,64,246,3,0,0,0,0,0,254,0,2,0,32,176,1,0,20,0,0,0,1,128,128,0,192,255,2,0,20,0,0,0,1,128,0,0,208,75,4,0,168,86,7,0,1,0,0,0,232,47,216,0,248,191,2,0,24,38,7,0,1,0,0,0,236,47,216,0,184,160,2,0,56,210,6,0,1,0,0,0,35,48,216,0,192,135,2,0,24,163,6,0,1,0,0,0,34,48,216,0,240,108,2,0,152,122,6,0,1,0,0,0,33,48,216,0,96,82,2,0,192,72,6,0,1,0,0,0,32,48,216,0,32,56,2,0,232,158,3,0,1,0,0,0,36,48,216,0,152,30,2,0,104,184,3,0,1,0,0,0,37,48,216,0,232,10,2,0,40,246,1,0,1,0,0,0,233,47,216,0,64,246,1,0,144,236,1,0,1,0,0,0,237,47,216,0,136,224,1,0,176,223,1,0,1,0,0,0,43,48,216,0,72,198,1,0,192,209,1,0,1,0,0,0,42,48,216,0,24,182,1,0,24,198,1,0,1,0,0,0,41,48,216,0,40,167,1,0,120,189,1,0,1,0,0,0,40,48,216,0,200,149,1,0,200,32,1,0,1,0,0,0,44,48,216,0,56,126,1,0,208,41,1,0,1,0,0,0,45,48,216,0,32,101,1,0,168,132,8,0,1,0,0,0,166,47,216,0,232,209,1,0,72,126,8,0,1,0,0,0,167,47,216,0,144,189,1,0,192,122,8,0,1,0,0,0,163,47,216,0,208,174,1,0,40,116,8,0,1,0,0,0,162,47,216,0,48,160,1,0,72,110,8,0,1,0,0,0,161,47,216,0,160,140,1,0,184,102,8,0,1,0,0,0,160,47,216,0,56,112,1,0,176,103,1,0,1,0,0,0,164,47,216,0,32,92,1,0,192,102,1,0,1,0,0,0,165,47,216,0,64,77,1,0,88,212,3,0,1,0,0,0,144,46,216,0,40,185,3,0,240,152,1,0,1,0,0,0,238,47,216,0,216,70,1,0,16,17,8,0,1,0,0,0,234,47,216,0,224,12,8,0,72,65,1,0,9,0,0,0,232,48,216,0,32,58,1,0,48,50,1,0,9,0,0,0,224,48,216,0,32,58,1,0,224,41,1,0,9,0,0,0,216,48,216,0,32,58,1,0,114,99,109,117,95,50,51,98,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,122,60,211,28,2,0,16,1,114,99,109,117,95,50,50,98,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,196,104,130,112,2,0,16,1,114,99,109,117,95,50,49,97,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,149,234,118,67,2,0,16,1,114,99,109,95,48,49,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,63,241,205,110,4,0,32,0,114,99,109,95,48,50,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,15,79,77,148,4,0,32,0,114,99,109,95,48,51,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,60,7,243,54,4,0,32,0,114,99,109,95,48,52,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,255,34,230,84,4,0,32,0,114,99,109,95,48,53,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,253,49,209,93,4,0,32,0,114,99,109,95,48,54,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,19,248,250,240,4,0,32,0,114,99,109,95,48,55,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,19,224,109,130,4,0,32,0,114,99,109,95,48,56,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,207,100,255,251,4,0,32,0,114,99,109,95,49,48,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,169,173,200,77,4,0,32,0,114,99,109,95,49,49,46,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,6,238,185,242,4,0,32,0,114,99,109,95,49,50,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,3,242,213,254,4,0,32,0,114,99,109,95,49,51,46,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,169,212,105,80,4,0,32,0,114,99,109,95,49,52,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,189,227,59,48,4,0,32,0,114,99,109,95,49,53,46,56,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,47,55,45,79,4,0,32,0,114,99,109,95,49,54,46,57,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,222,127,217,147,4,0,32,0,114,99,109,95,49,55,46,49,48,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,66,16,55,146,4,0,32,0,114,99,109,95,48,57,46,49,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,95,143,172,34,3,0,16,0,114,99,109,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,170,248,241,128,5,0,64,0,114,99,109,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,225,219,87,242,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,114,99,109,54,51,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,148,212,172,132,0,0,0,8,105,111,98,49,46,49,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,98,112,114,103,49,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,167,61,121,49,0,0,0,8,105,111,99,49,46,105,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,129,32,24,13,0,0,0,8,99,54,51,50,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,112,146,189,15,0,0,0,8,21,0,0,0,255,255,0,0,0,0,0,0,22,0,0,0,255,255,1,0,0,0,0,0,23,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,19,0,32,4,2,0,21,0,0,0,1,31,0,0,128,230,7,0,21,0,0,0,1,31,1,0,184,164,6,0,21,0,0,0,1,31,2,0,80,74,6,0,21,0,0,0,1,31,3,0,192,32,6,0,21,0,0,0,1,31,4,0,192,234,2,0,21,0,0,0,1,31,5,0,32,242,5,0,21,0,0,0,1,31,6,0,176,192,2,0,21,0,0,0,1,31,7,0,248,175,2,0,21,0,0,0,1,31,8,0,144,68,1,0,21,0,0,0,1,31,9,0,104,236,7,0,21,0,0,0,1,31,10,0,16,242,7,0,21,0,0,0,1,31,11,0,80,252,6,0,21,0,0,0,1,31,12,0,104,54,4,0,21,0,0,0,1,31,13,0,176,73,5,0,21,0,0,0,1,31,14,0,16,95,1,0,21,0,0,0,1,31,15,0,48,94,1,0,21,0,0,0,1,31,16,0,136,93,1,0,21,0,0,0,1,31,17,0,144,92,1,0,21,0,0,0,1,31,18,0,16,227,4,0,0,0,0,0,254,0,4,0,88,160,1,0,21,0,0,0,1,96,64,0,8,92,1,0,21,0,0,0,1,96,0,0,64,91,1,0,21,0,0,0,1,96,32,0,0,91,1,0,0,0,0,0,254,0,4,0,72,202,5,0,22,0,0,0,1,3,0,0,80,246,3,0,22,0,0,0,1,3,1,0,248,38,7,0,22,0,0,0,1,3,2,0,112,212,3,0,22,0,0,0,1,3,3,0,248,160,5,0,0,0,0,0,254,0,4,0,112,59,6,0,22,0,0,0,1,12,0,0,80,167,5,0,22,0,0,0,1,12,4,0,80,150,7,0,22,0,0,0,1,12,8,0,104,142,4,0,22,0,0,0,1,12,12,0,176,63,4,0,0,0,0,0,254,0,2,0,88,178,4,0,22,0,0,0,1,64,64,0,96,135,7,0,22,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,23,0,0,0,1,1,0,0,96,135,7,0,23,0,0,0,1,1,1,0,152,182,7,0,0,0,0,0,254,0,2,0,40,111,8,0,23,0,0,0,1,2,2,0,96,135,7,0,23,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,23,0,0,0,1,4,4,0,96,135,7,0,23,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,79,2,0,23,0,0,0,1,128,0,0,32,182,8,0,23,0,0,0,1,128,128,0,80,251,6,0,7,0,0,0,255,255,40,0,0,0,0,0,8,0,0,0,255,255,254,0,0,0,0,0,0,0,0,0,254,0,2,0,32,4,2,0,7,0,0,0,1,1,0,0,56,37,8,0,7,0,0,0,1,1,1,0,96,240,7,0,0,0,0,0,254,0,2,0,208,104,1,0,7,0,0,0,1,2,0,0,248,81,6,0,7,0,0,0,1,2,2,0,176,64,8,0,0,0,0,0,254,0,2,0,144,80,1,0,7,0,0,0,1,4,4,0,248,81,6,0,7,0,0,0,1,4,0,0,176,64,8,0,0,0,0,0,254,0,2,0,8,73,1,0,7,0,0,0,1,8,8,0,80,246,3,0,7,0,0,0,1,8,0,0,112,212,3,0,0,0,0,0,254,0,2,0,248,51,1,0,7,0,0,0,1,32,32,0,248,81,6,0,7,0,0,0,1,32,0,0,176,64,8,0,0,0,0,0,254,0,4,0,128,129,4,0,7,0,0,0,1,80,0,0,8,49,4,0,7,0,0,0,1,80,16,0,152,21,4,0,7,0,0,0,1,80,64,0,72,246,3,0,7,0,0,0,1,80,80,0,72,0,3,0,0,0,0,0,254,0,2,0,168,79,2,0,7,0,0,0,1,128,0,0,56,36,1,0,7,0,0,0,1,128,128,0,112,26,1,0,0,0,0,0,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,1,0,0,96,135,7,0,19,0,0,0,1,1,1,0,152,182,7,0,0,0,0,0,254,0,2,0,96,46,8,0,19,0,0,0,1,8,8,0,208,233,4,0,19,0,0,0,1,8,0,0,72,197,4,0,0,0,0,0,254,0,7,0,200,87,7,0,19,0,0,0,1,48,0,0,184,220,8,0,19,0,0,0,1,48,16,0,88,154,8,0,19,0,0,0,1,48,16,0,200,92,8,0,19,0,0,0,1,48,48,0,104,172,6,0,19,0,0,0,1,48,0,0,24,46,7,0,19,0,0,0,1,48,32,0,216,129,6,0,19,0,0,0,1,48,32,0,48,39,6,0,0,0,0,0,254,0,7,0,160,123,6,0,19,0,0,0,1,192,0,0,184,220,8,0,19,0,0,0,1,192,64,0,88,154,8,0,19,0,0,0,1,192,64,0,200,92,8,0,19,0,0,0,1,192,192,0,104,172,6,0,19,0,0,0,1,192,0,0,24,46,7,0,19,0,0,0,1,192,128,0,216,129,6,0,19,0,0,0,1,192,128,0,48,39,6,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,3,2,0,80,246,3,0,20,0,0,0,1,3,3,0,248,38,7,0,20,0,0,0,1,3,1,0,112,212,3,0,20,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,12,4,0,208,75,4,0,20,0,0,0,1,12,12,0,8,49,4,0,20,0,0,0,1,12,8,0,152,21,4,0,20,0,0,0,1,12,0,0,72,246,3,0,0,0,0,0,254,0,4,0,104,115,3,0,20,0,0,0,1,48,48,0,8,49,4,0,20,0,0,0,1,48,32,0,152,21,4,0,20,0,0,0,1,48,16,0,72,246,3,0,20,0,0,0,1,48,0,0,232,99,5,0,0,0,0,0,254,0,3,0,200,30,2,0,20,0,0,0,1,192,64,0,72,60,1,0,20,0,0,0,1,192,192,0,88,51,1,0,20,0,0,0,1,192,128,0,96,19,1,0,0,0,0,0,109,98,100,101,95,50,54,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,28,69,183,114,1,0,16,1,109,98,100,101,95,51,48,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,22,220,54,160,1,0,16,1,109,98,100,101,95,50,55,46,49,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,52,245,134,64,1,0,16,1,109,98,100,101,95,51,49,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,240,71,95,8,1,0,16,1,109,98,100,101,95,50,52,46,57,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,165,149,8,194,1,0,16,1,109,98,100,101,95,50,56,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,225,213,24,38,1,0,16,1,109,98,100,101,95,50,53,46,49,48,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,17,107,219,155,1,0,16,1,109,98,100,101,95,50,57,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,229,213,82,63,1,0,16,1,109,98,100,101,95,50,49,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,106,2,12,105,2,0,16,1,109,98,100,101,95,50,48,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,155,19,178,184,2,0,16,1,109,98,45,49,109,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,6,142,70,65,4,0,32,0,109,98,45,51,109,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,158,170,83,244,4,0,32,0,109,98,45,50,109,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,254,251,47,4,0,32,0,109,98,45,52,109,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,29,132,185,30,4,0,32,0,109,98,45,53,109,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,201,157,107,80,4,0,32,0,109,98,45,55,109,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,251,194,248,175,4,0,32,0,109,98,45,54,109,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,233,112,108,183,4,0,32,0,109,98,45,56,109,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,86,149,12,230,4,0,32,0,109,98,45,49,48,109,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,245,111,151,151,4,0,32,0,109,98,45,49,50,109,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,64,168,80,179,4,0,32,0,109,98,45,49,49,109,46,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,67,71,185,143,4,0,32,0,109,98,45,49,51,109,46,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,95,13,129,218,4,0,32,0,109,98,95,113,46,53,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,209,118,250,214,3,0,16,1,109,98,45,113,49,46,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,206,195,48,6,6,0,64,0,109,98,45,113,50,46,50,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,33,156,79,53,6,0,64,0,109,98,45,113,51,46,51,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,124,72,56,120,6,0,64,0,109,98,45,113,52,46,52,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,135,224,102,171,6,0,64,0,109,98,45,113,53,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,242,254,137,199,6,0,64,0,109,98,45,113,54,46,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,27,184,236,6,0,64,0,109,98,45,113,55,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,186,73,30,4,6,0,64,0,109,98,45,113,56,46,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,42,112,254,89,6,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,154,135,134,67,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,109,98,54,51,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,2,47,57,184,0,0,0,8,105,111,98,49,46,49,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,98,112,114,103,49,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,167,61,121,49,0,0,0,8,105,111,99,49,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,129,32,24,13,0,0,0,8,100,55,108,49,46,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,13,65,183,39,0,0,0,8,100,56,108,49,46,56,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,218,199,159,83,0,0,0,8,100,57,107,50,46,57,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,86,161,133,205,0,0,0,8,100,49,48,102,49,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,148,196,25,102,0,0,0,8,19,0,0,0,255,255,254,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,19,0,0,0,1,1,0,0,120,97,1,0,19,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,2,2,0,96,135,7,0,19,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,4,4,0,96,135,7,0,19,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,8,0,0,96,135,7,0,19,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,19,0,0,0,1,48,0,0,32,136,7,0,19,0,0,0,1,48,16,0,40,88,7,0,19,0,0,0,1,48,32,0,96,39,7,0,19,0,0,0,1,48,48,0,144,251,6,0,0,0,0,0,254,0,4,0,160,123,6,0,19,0,0,0,1,192,192,0,184,164,6,0,19,0,0,0,1,192,128,0,80,74,6,0,19,0,0,0,1,192,64,0,192,32,6,0,19,0,0,0,1,192,0,0,32,242,5,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,3,2,0,80,246,3,0,20,0,0,0,1,3,3,0,80,124,6,0,20,0,0,0,1,3,1,0,112,212,3,0,20,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,64,37,5,0,20,0,0,0,1,12,8,0,64,157,5,0,20,0,0,0,1,12,12,0,248,154,5,0,20,0,0,0,1,12,4,0,120,152,5,0,20,0,0,0,1,12,0,0,120,7,5,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,48,48,0,8,49,4,0,20,0,0,0,1,48,32,0,152,21,4,0,20,0,0,0,1,48,16,0,72,246,3,0,20,0,0,0,1,48,0,0,72,0,3,0,0,0,0,0,254,0,2,0,152,148,5,0,20,0,0,0,1,128,128,0,0,147,5,0,20,0,0,0,1,128,0,0,112,143,5,0,109,103,51,45,48,49,46,57,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,115,121,53,4,0,0,16,1,109,103,51,45,48,50,46,49,48,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,160,141,208,80,0,0,16,1,109,103,51,45,97,46,51,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,231,29,15,66,0,0,32,0,109,103,51,45,98,46,52,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,250,19,222,216,0,0,32,0,109,103,51,45,99,46,54,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,232,102,235,251,0,0,32,0,109,103,51,45,100,46,55,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,49,216,107,143,0,0,32,0,109,103,51,45,48,53,46,50,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,45,141,115,122,0,0,32,0,109,103,51,45,48,52,46,49,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,21,5,243,86,0,0,32,0,109,103,51,45,101,46,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,169,47,108,16,0,0,64,0,18,0,0,0,255,255,2,0,0,0,0,0,19,0,0,0,255,255,126,0,0,0,0,0,20,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,128,129,4,0,18,0,0,0,1,1,0,0,8,49,4,0,18,0,0,0,1,1,1,0,72,246,3,0,0,0,0,0,254,0,2,0,200,30,2,0,18,0,0,0,1,2,2,0,120,97,1,0,18,0,0,0,1,2,0,0,96,19,1,0,0,0,0,0,254,0,2,0,144,212,8,0,18,0,0,0,1,4,0,0,96,135,7,0,18,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,254,0,2,0,232,53,6,0,18,0,0,0,1,8,0,0,232,78,1,0,18,0,0,0,1,8,8,0,136,86,1,0,0,0,0,0,254,0,16,0,48,9,7,0,18,0,0,0,1,240,0,0,192,222,6,0,18,0,0,0,1,240,16,0,248,177,6,0,18,0,0,0,1,240,32,0,72,135,6,0,18,0,0,0,1,240,48,0,88,89,6,0,18,0,0,0,1,240,64,0,136,43,6,0,18,0,0,0,1,240,80,0,64,1,6,0,18,0,0,0,1,240,96,0,184,211,5,0,18,0,0,0,1,240,112,0,16,172,5,0,18,0,0,0,1,240,128,0,72,136,5,0,18,0,0,0,1,240,144,0,48,109,5,0,18,0,0,0,1,240,160,0,152,77,5,0,18,0,0,0,1,240,176,0,232,45,5,0,18,0,0,0,1,240,192,0,32,16,5,0,18,0,0,0,1,240,208,0,112,237,4,0,18,0,0,0,1,240,224,0,0,202,4,0,18,0,0,0,1,240,240,0,16,227,4,0,0,0,0,0,254,0,4,0,64,37,5,0,19,0,0,0,1,3,0,0,120,7,5,0,19,0,0,0,1,3,1,0,80,110,6,0,19,0,0,0,1,3,2,0,216,56,4,0,19,0,0,0,1,3,3,0,72,29,4,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,4,0,0,96,135,7,0,19,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,254,0,2,0,72,4,1,0,19,0,0,0,1,128,0,0,96,135,7,0,19,0,0,0,1,128,128,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,20,0,0,0,1,16,0,0,96,135,7,0,20,0,0,0,1,16,16,0,152,182,7,0,116,112,49,46,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,208,223,193,218,1,0,16,1,116,109,50,46,50,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,40,202,231,239,1,0,16,1,116,109,51,46,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,166,129,120,2,1,0,16,1,116,109,52,46,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,220,231,253,160,1,0,16,1,116,109,53,46,50,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,142,203,235,215,1,0,16,1,116,109,56,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,31,97,174,112,4,0,32,0,116,109,57,46,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,158,153,78,142,4,0,32,0,116,52,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,221,182,66,202,7,0,32,0,116,54,46,54,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,204,140,32,173,7,0,32,0,116,53,46,55,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,255,140,216,27,7,0,32,0,109,97,114,105,110,101,98,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,64,101,29,102,0,0,16,1,109,97,114,105,110,101,98,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,127,161,45,146,0,0,16,1,109,97,114,105,110,101,98,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,91,35,10,130,0,0,16,1,109,97,114,105,110,101,98,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,131,162,87,161,0,0,16,1,109,97,114,105,110,101,98,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,192,249,255,159,0,0,16,1,109,97,114,105,110,101,98,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,46,236,83,238,0,0,32,0,109,97,114,105,110,101,98,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,108,196,139,220,0,0,32,0,109,97,114,105,110,101,98,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,171,25,46,157,0,0,32,0,109,97,114,105,110,101,98,46,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,114,148,45,243,0,0,32,0,109,97,114,105,110,101,98,46,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,62,157,198,147,0,0,32,0,14,0,0,0,255,255,64,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,14,0,0,0,1,3,0,0,8,49,4,0,14,0,0,0,1,3,1,0,152,21,4,0,14,0,0,0,1,3,2,0,72,246,3,0,14,0,0,0,1,3,3,0,72,0,3,0,0,0,0,0,254,0,2,0,32,4,2,0,14,0,0,0,1,28,0,0,80,245,6,0,14,0,0,0,1,28,28,0,16,227,4,0,0,0,0,0,254,0,2,0,64,37,5,0,14,0,0,0,1,32,0,0,208,98,2,0,14,0,0,0,1,32,32,0,200,15,5,0,0,0,0,0,254,0,2,0,200,30,2,0,14,0,0,0,1,64,64,0,120,97,1,0,14,0,0,0,1,64,0,0,96,19,1,0,0,0,0,0,18,0,0,0,255,255,255,0,0,0,0,0,19,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,192,195,5,0,18,0,0,0,1,1,1,0,96,135,7,0,18,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,18,0,0,0,1,2,0,0,96,135,7,0,18,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,4,0,200,192,5,0,18,0,0,0,1,24,24,0,208,75,4,0,18,0,0,0,1,24,16,0,8,49,4,0,18,0,0,0,1,24,8,0,152,21,4,0,18,0,0,0,1,24,0,0,72,246,3,0,0,0,0,0,254,0,2,0,16,227,4,0,18,0,0,0,1,64,64,0,96,135,7,0,18,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,19,0,0,0,1,24,8,0,80,246,3,0,19,0,0,0,1,24,24,0,248,38,7,0,19,0,0,0,1,24,16,0,112,212,3,0,19,0,0,0,1,24,0,0,248,160,5,0,0,0,0,0,254,0,8,0,32,4,2,0,19,0,0,0,1,224,0,0,32,136,7,0,19,0,0,0,1,224,32,0,40,88,7,0,19,0,0,0,1,224,64,0,96,39,7,0,19,0,0,0,1,224,96,0,120,113,6,0,19,0,0,0,1,224,224,0,144,251,6,0,19,0,0,0,1,224,128,0,120,211,6,0,19,0,0,0,1,224,192,0,184,164,6,0,19,0,0,0,1,224,160,0,80,74,6,0,33,0,0,0,255,255,255,0,0,0,0,0,34,0,0,0,255,255,87,0,0,0,0,0,35,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,16,0,32,4,2,0,33,0,0,0,1,15,2,0,80,252,6,0,33,0,0,0,1,15,5,0,16,242,7,0,33,0,0,0,1,15,8,0,104,236,7,0,33,0,0,0,1,15,4,0,120,113,6,0,33,0,0,0,1,15,1,0,232,228,5,0,33,0,0,0,1,15,15,0,128,230,7,0,33,0,0,0,1,15,0,0,232,192,7,0,33,0,0,0,1,15,3,0,56,141,7,0,33,0,0,0,1,15,7,0,120,211,6,0,33,0,0,0,1,15,14,0,184,164,6,0,33,0,0,0,1,15,6,0,24,1,7,0,33,0,0,0,1,15,13,0,80,74,6,0,33,0,0,0,1,15,12,0,192,32,6,0,33,0,0,0,1,15,11,0,192,234,2,0,33,0,0,0,1,15,10,0,32,242,5,0,33,0,0,0,1,15,9,0,176,192,2,0,0,0,0,0,254,0,4,0,240,96,5,0,34,0,0,0,1,24,0,0,176,63,4,0,34,0,0,0,1,24,8,0,104,142,4,0,34,0,0,0,1,24,16,0,56,43,1,0,34,0,0,0,1,24,24,0,80,150,7,0,0,0,0,0,254,0,4,0,72,202,5,0,34,0,0,0,1,96,96,0,80,246,3,0,34,0,0,0,1,96,64,0,248,38,7,0,34,0,0,0,1,96,32,0,112,212,3,0,34,0,0,0,1,96,0,0,24,99,5,0,0,0,0,0,254,0,2,0,168,234,7,0,34,0,0,0,1,128,128,0,96,135,7,0,34,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,35,0,0,0,1,1,1,0,96,135,7,0,35,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,35,0,0,0,1,4,4,0,96,135,7,0,35,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,18,0,0,0,255,255,247,0,0,0,0,0,19,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,232,75,4,0,18,0,0,0,1,1,1,0,96,135,7,0,18,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,18,0,0,0,1,2,0,0,96,135,7,0,18,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,2,0,128,112,3,0,18,0,0,0,1,8,0,0,168,22,4,0,18,0,0,0,1,8,8,0,224,247,3,0,0,0,0,0,254,0,4,0,72,202,5,0,18,0,0,0,1,48,16,0,80,246,3,0,18,0,0,0,1,48,48,0,248,38,7,0,18,0,0,0,1,48,32,0,112,212,3,0,18,0,0,0,1,48,0,0,248,160,5,0,0,0,0,0,254,0,4,0,128,129,4,0,18,0,0,0,1,192,0,0,192,255,2,0,18,0,0,0,1,192,64,0,208,75,4,0,18,0,0,0,1,192,192,0,8,49,4,0,18,0,0,0,1,192,128,0,152,21,4,0,0,0,0,0,254,0,16,0,160,123,6,0,19,0,0,0,1,15,4,0,32,136,7,0,19,0,0,0,1,15,10,0,40,88,7,0,19,0,0,0,1,15,1,0,96,39,7,0,19,0,0,0,1,15,0,0,192,24,7,0,19,0,0,0,1,15,2,0,120,113,6,0,19,0,0,0,1,15,8,0,232,228,5,0,19,0,0,0,1,15,15,0,144,251,6,0,19,0,0,0,1,15,12,0,56,141,7,0,19,0,0,0,1,15,14,0,120,211,6,0,19,0,0,0,1,15,7,0,184,164,6,0,19,0,0,0,1,15,6,0,24,1,7,0,19,0,0,0,1,15,11,0,80,74,6,0,19,0,0,0,1,15,3,0,192,32,6,0,19,0,0,0,1,15,13,0,192,234,2,0,19,0,0,0,1,15,5,0,32,242,5,0,19,0,0,0,1,15,9,0,176,192,2,0,0,0,0,0,254,0,16,0,200,87,7,0,19,0,0,0,1,240,64,0,32,136,7,0,19,0,0,0,1,240,160,0,40,88,7,0,19,0,0,0,1,240,16,0,96,39,7,0,19,0,0,0,1,240,32,0,120,113,6,0,19,0,0,0,1,240,128,0,232,228,5,0,19,0,0,0,1,240,240,0,144,251,6,0,19,0,0,0,1,240,192,0,56,141,7,0,19,0,0,0,1,240,224,0,120,211,6,0,19,0,0,0,1,240,112,0,184,164,6,0,19,0,0,0,1,240,96,0,24,1,7,0,19,0,0,0,1,240,176,0,80,74,6,0,19,0,0,0,1,240,48,0,192,32,6,0,19,0,0,0,1,240,208,0,192,234,2,0,19,0,0,0,1,240,80,0,32,242,5,0,19,0,0,0,1,240,144,0,176,192,2,0,19,0,0,0,1,240,0,0,16,227,4,0,0,0,0,0,0,0,36,0,0,0,24,0,0,0,12,0,0,0,0,0,17,0,0,0,255,255,254,0,0,0,0,0,18,0,0,0,255,255,254,0,0,0,0,0,0,0,0,0,254,0,2,0,232,80,3,0,17,0,0,0,1,2,2,0,96,135,7,0,17,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,17,0,0,0,1,12,12,0,208,75,4,0,17,0,0,0,1,12,4,0,8,49,4,0,17,0,0,0,1,12,8,0,152,21,4,0,17,0,0,0,1,12,0,0,72,246,3,0,0,0,0,0,254,0,4,0,192,56,2,0,17,0,0,0,1,48,0,0,176,193,3,0,17,0,0,0,1,48,32,0,208,196,4,0,17,0,0,0,1,48,16,0,56,233,4,0,17,0,0,0,1,48,48,0,16,42,5,0,0,0,0,0,254,0,4,0,0,70,2,0,17,0,0,0,1,192,192,0,16,42,5,0,17,0,0,0,1,192,0,0,24,155,1,0,17,0,0,0,1,192,64,0,152,11,5,0,17,0,0,0,1,192,128,0,24,27,4,0,0,0,0,0,254,0,4,0,72,202,5,0,18,0,0,0,1,6,2,0,80,246,3,0,18,0,0,0,1,6,6,0,80,124,6,0,18,0,0,0,1,6,4,0,112,212,3,0,18,0,0,0,1,6,0,0,248,160,5,0,0,0,0,0,254,0,2,0,40,73,5,0,18,0,0,0,1,8,0,0,96,135,7,0,18,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,2,0,72,217,6,0,18,0,0,0,1,16,0,0,56,111,3,0,18,0,0,0,1,16,16,0,104,134,3,0,0,0,0,0,254,0,8,0,40,148,2,0,18,0,0,0,1,224,224,0,0,117,1,0,18,0,0,0,1,224,96,0,160,104,1,0,18,0,0,0,1,224,160,0,24,94,1,0,18,0,0,0,1,224,32,0,224,87,1,0,18,0,0,0,1,224,192,0,120,80,1,0,18,0,0,0,1,224,64,0,240,72,1,0,18,0,0,0,1,224,128,0,208,66,1,0,18,0,0,0,1,224,0,0,120,7,5,0,0,0,0,0,8,0,0,0,16,0,0,0,24,0,0,0,32,0,0,0,40,0,0,0,48,0,0,0,56,0,0,0,64,0,0,0,72,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,128,0,0,0,129,0,0,0,130,0,0,0,131,0,0,0,132,0,0,0,133,0,0,0,134,0,0,0,135,0,0,0,13,0,0,0,255,255,127,0,0,0,0,0,0,0,0,0,254,0,2,0,128,111,8,0,13,0,0,0,1,1,1,0,96,135,7,0,13,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,160,104,8,0,13,0,0,0,1,2,2,0,72,174,3,0,13,0,0,0,1,2,0,0,168,95,8,0,0,0,0,0,254,0,2,0,120,88,8,0,13,0,0,0,1,4,4,0,56,82,8,0,13,0,0,0,1,4,0,0,176,77,8,0,0,0,0,0,254,0,2,0,88,160,1,0,13,0,0,0,1,8,0,0,192,255,2,0,13,0,0,0,1,8,8,0,208,75,4,0,0,0,0,0,254,0,2,0,232,75,4,0,13,0,0,0,1,64,64,0,96,135,7,0,13,0,0,0,1,64,0,0,152,182,7,0,101,112,114,45,49,50,56,52,57,46,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,254,210,207,97,1,0,16,1,101,112,114,45,49,50,56,53,48,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,42,143,89,20,1,0,16,1,101,112,114,45,49,50,56,48,52,46,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,14,72,83,184,9,0,16,1,101,112,114,45,49,50,56,48,53,46,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,195,0,114,74,9,0,16,1,101,112,114,45,49,50,56,48,50,46,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,57,187,70,215,9,0,16,1,101,112,114,45,49,50,56,48,51,46,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,81,231,217,193,9,0,16,1,111,112,114,45,49,50,55,57,49,46,49,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,186,105,250,172,2,0,32,0,111,112,114,45,49,50,55,57,50,46,49,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,60,114,6,229,2,0,32,0,111,112,114,45,49,50,55,57,51,46,49,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,227,204,232,12,2,0,32,0,101,112,114,45,49,50,55,56,55,46,57,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,166,163,49,100,3,0,32,0,101,112,114,45,49,50,55,56,56,46,57,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,206,160,130,25,3,0,32,0,101,112,114,45,49,50,55,56,57,46,57,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,116,50,208,151,3,0,32,0,101,112,114,45,49,50,55,57,48,46,49,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,230,118,110,129,3,0,32,0,101,112,114,45,49,50,55,56,51,46,57,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,169,238,63,193,3,0,32,0,101,112,114,45,49,50,55,56,52,46,57,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,101,76,185,57,3,0,32,0,101,112,114,45,49,50,55,56,53,46,57,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,89,0,237,5,3,0,32,0,101,112,114,45,49,50,55,56,54,46,49,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,101,49,18,164,3,0,32,0,101,112,114,45,49,50,55,55,57,46,57,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,124,175,88,174,3,0,32,0,101,112,114,45,49,50,55,56,48,46,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,30,12,103,238,3,0,32,0,101,112,114,45,49,50,55,56,49,46,49,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,197,107,143,83,3,0,32,0,101,112,114,45,49,50,55,56,50,46,49,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,247,52,204,90,3,0,32,0,101,112,114,45,49,50,55,55,53,46,57,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,236,86,48,105,3,0,32,0,101,112,114,45,49,50,55,55,54,46,57,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,253,189,239,97,3,0,32,0,101,112,114,45,49,50,55,55,55,46,49,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,83,185,213,41,3,0,32,0,101,112,114,45,49,50,55,55,56,46,49,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,7,142,182,47,3,0,32,0,101,112,114,45,49,50,55,57,56,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,141,115,135,5,4,0,16,1,101,112,114,45,49,50,55,57,57,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,28,24,96,188,11,0,64,0,101,112,114,45,49,50,56,48,48,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,163,193,88,17,11,0,64,0,101,112,114,45,49,50,56,48,49,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,196,103,101,45,11,0,64,0,51,49,55,45,48,49,51,54,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,12,254,75,52,5,0,16,1,14,0,0,0,255,255,255,0,0,0,0,0,15,0,0,0,255,255,156,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,14,0,0,0,1,15,7,0,80,252,6,0,14,0,0,0,1,15,8,0,16,242,7,0,14,0,0,0,1,15,9,0,104,236,7,0,14,0,0,0,1,15,5,0,176,51,4,0,14,0,0,0,1,15,4,0,56,24,4,0,14,0,0,0,1,15,15,0,128,230,7,0,14,0,0,0,1,15,1,0,72,216,3,0,14,0,0,0,1,15,2,0,24,188,3,0,14,0,0,0,1,15,3,0,176,162,3,0,14,0,0,0,1,15,6,0,120,211,6,0,14,0,0,0,1,15,14,0,184,164,6,0,14,0,0,0,1,15,13,0,80,74,6,0,14,0,0,0,1,15,12,0,192,32,6,0,14,0,0,0,1,15,11,0,192,234,2,0,14,0,0,0,1,15,10,0,32,242,5,0,14,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,14,0,0,0,1,240,112,0,80,252,6,0,14,0,0,0,1,240,128,0,16,242,7,0,14,0,0,0,1,240,144,0,104,236,7,0,14,0,0,0,1,240,80,0,176,51,4,0,14,0,0,0,1,240,64,0,56,24,4,0,14,0,0,0,1,240,240,0,128,230,7,0,14,0,0,0,1,240,16,0,72,216,3,0,14,0,0,0,1,240,32,0,24,188,3,0,14,0,0,0,1,240,48,0,176,162,3,0,14,0,0,0,1,240,96,0,120,211,6,0,14,0,0,0,1,240,224,0,184,164,6,0,14,0,0,0,1,240,208,0,80,74,6,0,14,0,0,0,1,240,192,0,192,32,6,0,14,0,0,0,1,240,176,0,192,234,2,0,14,0,0,0,1,240,160,0,32,242,5,0,14,0,0,0,1,240,0,0,208,236,2,0,0,0,0,0,254,0,2,0,128,112,3,0,15,0,0,0,1,1,1,0,224,247,3,0,15,0,0,0,1,1,0,0,168,22,4,0,0,0,0,0,254,0,2,0,200,30,2,0,15,0,0,0,1,2,2,0,80,46,8,0,15,0,0,0,1,2,0,0,120,97,1,0,0,0,0,0,254,0,2,0,0,231,7,0,15,0,0,0,1,4,4,0,96,135,7,0,15,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,15,0,0,0,1,24,16,0,80,246,3,0,15,0,0,0,1,24,24,0,248,38,7,0,15,0,0,0,1,24,8,0,112,212,3,0,15,0,0,0,1,24,0,0,248,160,5,0,0,0,0,0,254,0,2,0,104,159,3,0,15,0,0,0,1,32,32,0,56,111,3,0,15,0,0,0,1,32,0,0,104,134,3,0,0,0,0,0,254,0,2,0,168,234,7,0,15,0,0,0,1,64,64,0,96,135,7,0,15,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,8,93,1,0,15,0,0,0,1,128,128,0,8,208,6,0,15,0,0,0,1,128,0,0,72,5,2,0,0,0,0,0,168,86,7,0,1,0,0,0,180,251,146,0,248,191,2,0,24,38,7,0,1,0,0,0,176,251,146,0,184,160,2,0,56,210,6,0,1,0,0,0,133,243,146,0,192,135,2,0,24,163,6,0,1,0,0,0,132,243,146,0,240,108,2,0,152,122,6,0,1,0,0,0,130,243,146,0,96,82,2,0,192,72,6,0,1,0,0,0,131,243,146,0,32,56,2,0,200,110,3,0,1,0,0,0,128,243,146,0,152,30,2,0,120,89,3,0,1,0,0,0,129,243,146,0,232,10,2,0,40,246,1,0,1,0,0,0,181,251,146,0,64,246,1,0,144,236,1,0,1,0,0,0,177,251,146,0,136,224,1,0,176,223,1,0,1,0,0,0,85,238,146,0,72,198,1,0,192,209,1,0,1,0,0,0,84,238,146,0,24,182,1,0,24,198,1,0,1,0,0,0,82,238,146,0,40,167,1,0,120,189,1,0,1,0,0,0,83,238,146,0,200,149,1,0,224,22,1,0,1,0,0,0,80,238,146,0,56,126,1,0,160,14,1,0,1,0,0,0,81,238,146,0,32,101,1,0,88,212,3,0,1,0,0,0,104,216,146,0,40,185,3,0,16,17,8,0,1,0,0,0,178,251,146,0,224,12,8,0,56,58,1,0,1,0,0,0,179,251,146,0,64,50,1,0,72,65,1,0,9,0,0,0,208,3,147,0,32,58,1,0,48,50,1,0,9,0,0,0,209,3,147,0,32,58,1,0,224,41,1,0,9,0,0,0,210,3,147,0,32,58,1,0,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,102,55,144,128,0,0,16,1,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,203,248,30,122,0,0,16,1,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,11,17,41,169,0,0,16,1,107,121,95,97,45,51,97,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,59,95,54,203,0,0,16,1,100,114,48,49,46,51,99,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,189,151,104,230,0,0,16,1,100,114,48,50,46,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,38,30,227,249,0,0,16,1,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,25,141,94,181,0,0,32,0,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,9,178,187,123,0,0,32,0,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,130,253,112,3,0,0,32,0,49,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,7,165,69,80,0,0,32,0,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,160,22,107,148,0,0,32,0,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,255,105,27,144,0,0,32,0,49,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,147,237,78,80,0,0,32,0,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,11,118,157,66,0,0,32,0,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,100,205,0,23,0,0,32,0,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,99,141,56,79,0,0,32,0,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,193,162,175,218,0,0,32,0,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,25,157,100,96,0,0,32,0,100,114,50,53,46,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,11,67,145,142,0,0,32,0,100,114,51,48,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,99,50,199,40,0,0,32,0,100,114,50,54,46,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,63,185,99,181,0,0,32,0,100,114,51,49,46,49,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,14,33,41,53,0,0,32,0,100,114,50,55,46,51,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,239,104,214,112,0,0,32,0,100,114,50,57,46,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,84,167,115,17,0,0,32,0,100,114,51,50,46,53,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,46,31,205,17,0,0,32,0,100,114,51,51,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,60,141,216,52,0,0,32,0,100,114,50,56,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,189,15,239,108,0,0,0,8,99,52,57,45,48,57,46,105,99,52,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,185,158,224,106,2,0,16,1,99,52,57,45,49,49,46,105,99,52,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,110,190,210,66,2,0,16,1,99,52,57,45,49,48,46,105,99,52,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,224,242,190,80,2,0,16,1,99,52,57,45,49,50,46,105,99,52,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,213,186,22,203,2,0,16,1,99,52,57,45,48,56,46,105,99,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,12,49,60,65,9,0,16,1,99,52,57,45,48,51,46,105,99,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,155,79,54,195,11,0,32,0,99,52,57,45,48,49,46,105,99,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,99,49,204,103,15,0,32,0,99,52,57,45,48,50,46,105,99,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,16,7,64,210,15,0,32,0,99,52,57,45,48,52,46,105,99,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,164,69,77,71,24,0,64,0,19,0,0,0,255,255,254,0,0,0,0,0,20,0,0,0,255,255,127,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,19,0,0,0,1,1,0,0,120,97,1,0,19,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,2,2,0,96,135,7,0,19,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,4,4,0,96,135,7,0,19,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,8,0,0,96,135,7,0,19,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,19,0,0,0,1,48,0,0,80,252,6,0,19,0,0,0,1,48,16,0,16,242,7,0,19,0,0,0,1,48,32,0,104,236,7,0,19,0,0,0,1,48,48,0,128,230,7,0,0,0,0,0,254,0,4,0,160,123,6,0,19,0,0,0,1,192,192,0,8,201,6,0,19,0,0,0,1,192,128,0,200,197,6,0,19,0,0,0,1,192,64,0,152,194,6,0,19,0,0,0,1,192,0,0,248,189,6,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,3,2,0,80,246,3,0,20,0,0,0,1,3,3,0,80,124,6,0,20,0,0,0,1,3,1,0,112,212,3,0,20,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,64,37,5,0,20,0,0,0,1,12,12,0,56,207,4,0,20,0,0,0,1,12,8,0,16,202,4,0,20,0,0,0,1,12,4,0,216,196,4,0,20,0,0,0,1,12,0,0,144,192,4,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,48,32,0,208,75,4,0,20,0,0,0,1,48,48,0,8,49,4,0,20,0,0,0,1,48,0,0,152,21,4,0,20,0,0,0,1,48,16,0,72,246,3,0,0,0,0,0,254,0,2,0,104,159,3,0,20,0,0,0,1,64,0,0,96,135,7,0,20,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,6,0,20,0,0,0,1,128,128,0,8,208,6,0,20,0,0,0,1,128,0,0,88,204,6,0,0,0,0,0,101,112,114,45,49,51,52,50,55,46,97,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,107,251,248,91,1,0,16,1,101,112,114,45,49,51,52,50,56,46,97,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,245,117,103,39,1,0,16,1,101,112,114,45,49,51,52,49,49,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,123,22,96,81,1,0,16,1,101,112,114,45,49,51,52,49,51,46,97,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,216,59,107,101,1,0,16,1,101,112,114,45,49,51,52,49,52,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,25,36,218,218,2,0,32,0,101,112,114,45,49,51,52,49,53,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,72,44,182,187,2,0,32,0,101,112,114,45,49,51,52,49,54,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,174,219,17,29,2,0,32,0,101,112,114,45,49,51,54,48,52,46,99,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,229,200,9,64,3,0,32,0,101,112,114,45,49,51,54,48,51,46,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,78,169,80,83,3,0,32,0,109,112,114,45,49,51,52,50,52,46,99,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,32,217,152,251,3,0,32,0,109,112,114,45,49,51,52,50,49,46,97,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,144,88,199,47,3,0,32,0,109,112,114,45,49,51,52,50,53,46,99,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,137,37,37,248,3,0,32,0,109,112,114,45,49,51,52,50,50,46,97,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,77,117,160,72,3,0,32,0,109,112,114,45,49,51,52,50,54,46,99,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,37,30,251,92,3,0,32,0,109,112,114,45,49,51,52,50,51,46,97,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,157,188,91,51,3,0,32,0,101,112,114,45,49,51,52,49,55,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,73,235,123,205,4,0,16,1,109,112,114,45,49,51,52,50,48,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,228,222,224,61,19,0,64,0,109,112,114,45,49,51,52,49,57,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,10,27,2,231,19,0,64,0,109,112,114,45,49,51,52,49,56,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,77,89,50,7,19,0,64,0,51,49,55,45,48,49,54,53,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,171,103,66,160,5,0,16,1,108,114,51,45,97,45,52,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,142,78,51,91,0,0,16,1,108,114,51,45,97,45,52,100,46,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,49,201,75,168,0,0,16,1,108,114,51,45,97,45,52,98,46,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,29,3,9,190,0,0,16,1,108,114,51,45,97,45,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,205,104,190,40,0,0,16,1,108,114,51,45,97,45,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,183,134,113,203,0,0,16,1,108,114,51,45,110,45,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,238,77,183,249,0,0,32,0,108,114,51,45,110,45,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,186,7,247,254,0,0,32,0,108,114,51,45,110,45,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,185,39,61,175,0,0,32,0,108,114,51,45,98,45,52,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,199,112,240,99,0,0,32,0,108,114,51,45,98,45,51,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,145,173,183,234,0,0,32,0,108,114,51,45,98,45,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,70,10,70,26,0,0,32,0,108,114,51,45,110,45,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,107,184,128,232,0,0,32,0,108,114,51,45,98,45,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,103,113,45,240,0,0,32,0,108,114,51,45,110,45,50,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,81,224,126,4,0,0,32,0,108,114,51,45,98,45,49,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,129,241,55,158,0,0,32,0,108,114,51,45,110,45,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,120,134,173,105,0,0,32,0,108,114,51,45,98,45,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,29,196,17,91,0,0,32,0,108,114,51,45,98,45,53,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,226,105,31,224,0,0,32,0,108,114,51,45,98,45,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,60,141,216,52,0,0,32,0,108,114,51,45,110,45,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,233,75,103,223,0,0,0,8,18,0,0,0,255,255,223,0,0,0,0,0,19,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,72,202,5,0,18,0,0,0,1,3,3,0,80,246,3,0,18,0,0,0,1,3,2,0,80,124,6,0,18,0,0,0,1,3,1,0,112,212,3,0,18,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,2,0,224,172,5,0,18,0,0,0,1,4,0,0,32,137,5,0,18,0,0,0,1,4,4,0,224,109,5,0,0,0,0,0,254,0,2,0,16,27,6,0,18,0,0,0,1,8,8,0,96,135,7,0,18,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,2,0,72,4,1,0,18,0,0,0,1,16,16,0,96,135,7,0,18,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,2,0,200,30,2,0,18,0,0,0,1,32,0,0,120,97,1,0,18,0,0,0,1,32,32,0,96,19,1,0,0,0,0,0,254,0,2,0,16,227,4,0,18,0,0,0,1,64,64,0,56,111,3,0,18,0,0,0,1,64,0,0,104,134,3,0,0,0,0,0,254,0,2,0,128,129,4,0,18,0,0,0,1,128,128,0,8,49,4,0,18,0,0,0,1,128,0,0,72,246,3,0,0,0,0,0,254,0,10,0,160,123,6,0,19,0,0,0,1,15,6,0,32,136,7,0,19,0,0,0,1,15,8,0,40,88,7,0,19,0,0,0,1,15,10,0,96,39,7,0,19,0,0,0,1,15,7,0,120,113,6,0,19,0,0,0,1,15,15,0,144,251,6,0,19,0,0,0,1,15,9,0,120,211,6,0,19,0,0,0,1,15,14,0,184,164,6,0,19,0,0,0,1,15,13,0,80,74,6,0,19,0,0,0,1,15,12,0,192,32,6,0,19,0,0,0,1,15,11,0,192,234,2,0,0,0,0,0,254,0,10,0,200,87,7,0,19,0,0,0,1,240,96,0,32,136,7,0,19,0,0,0,1,240,128,0,40,88,7,0,19,0,0,0,1,240,160,0,96,39,7,0,19,0,0,0,1,240,112,0,120,113,6,0,19,0,0,0,1,240,240,0,144,251,6,0,19,0,0,0,1,240,144,0,120,211,6,0,19,0,0,0,1,240,224,0,184,164,6,0,19,0,0,0,1,240,208,0,80,74,6,0,19,0,0,0,1,240,192,0,192,32,6,0,19,0,0,0,1,240,176,0,192,234,2,0,0,0,0,0,184,40,2,0,1,0,0,0,136,200,148,0,248,191,2,0,56,250,6,0,1,0,0,0,139,200,148,0,184,160,2,0,184,164,8,0,1,0,0,0,137,200,148,0,64,246,1,0,88,149,7,0,1,0,0,0,140,200,148,0,136,224,1,0,240,167,7,0,1,0,0,0,130,200,148,0,192,135,2,0,176,163,7,0,1,0,0,0,131,200,148,0,240,108,2,0,208,158,7,0,1,0,0,0,128,200,148,0,96,82,2,0,184,154,7,0,1,0,0,0,129,200,148,0,32,56,2,0,176,108,2,0,1,0,0,0,132,200,148,0,152,30,2,0,128,98,2,0,1,0,0,0,133,200,148,0,232,10,2,0,8,96,7,0,1,0,0,0,122,200,148,0,72,198,1,0,48,89,7,0,1,0,0,0,123,200,148,0,24,182,1,0,16,83,7,0,1,0,0,0,120,200,148,0,40,167,1,0,96,79,7,0,1,0,0,0,121,200,148,0,200,149,1,0,48,76,7,0,1,0,0,0,124,200,148,0,56,126,1,0,144,72,7,0,1,0,0,0,125,200,148,0,32,101,1,0,88,212,3,0,1,0,0,0,248,100,215,0,40,185,3,0,16,17,8,0,1,0,0,0,138,200,148,0,224,12,8,0,248,5,8,0,9,0,0,0,96,214,146,0,32,58,1,0,144,250,7,0,9,0,0,0,97,214,146,0,32,58,1,0,97,45,52,101,45,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,131,208,226,182,0,0,16,1,97,45,52,100,45,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,142,145,50,117,0,0,16,1,97,45,51,101,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,176,122,232,88,0,0,16,1,97,45,51,102,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,234,49,30,200,0,0,16,1])
.concat([97,45,51,104,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,149,185,159,217,0,0,16,1,103,45,52,99,45,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,200,201,44,107,0,0,32,0,103,45,52,100,45,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,88,245,72,198,0,0,32,0,103,45,52,101,45,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,110,39,233,251,0,0,32,0,98,45,52,107,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,80,81,251,22,0,0,32,0,98,45,52,102,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,51,90,116,103,0,0,32,0,98,45,52,108,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,97,34,28,189,0,0,32,0,98,45,52,104,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,58,237,197,138,0,0,32,0,98,45,51,110,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,170,19,162,40,0,0,32,0,98,45,52,110,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,243,141,34,213,0,0,32,0,98,45,52,109,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,242,228,109,177,0,0,32,0,98,45,51,109,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,107,214,160,235,0,0,32,0,98,45,52,99,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,133,136,41,1,0,0,32,0,98,45,52,101,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,212,135,123,199,0,0,32,0,98,45,52,100,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,95,97,112,106,0,0,32,0,98,45,52,97,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,38,214,137,97,0,0,32,0,103,45,49,106,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,202,107,142,102,0,0,32,0,98,45,49,109,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,156,90,192,118,0,0,32,0,103,45,49,102,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,149,100,75,150,0,0,32,0,98,45,49,110,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,153,107,240,35,0,0,32,0,103,45,49,104,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,225,99,5,85,0,0,32,0,98,45,49,108,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,33,80,228,53,0,0,32,0,98,45,53,102,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,61,28,96,122,0,0,32,0,98,45,54,102,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,18,13,194,130,0,0,32,0,18,0,0,0,255,255,255,0,0,0,0,0,19,0,0,0,255,255,253,0,0,0,0,0,0,0,0,0,254,0,2,0,72,202,5,0,18,0,0,0,1,1,1,0,80,246,3,0,18,0,0,0,1,1,0,0,112,212,3,0,0,0,0,0,254,0,2,0,104,81,3,0,18,0,0,0,1,2,2,0,248,81,6,0,18,0,0,0,1,2,0,0,176,64,8,0,0,0,0,0,254,0,4,0,128,129,4,0,18,0,0,0,1,12,8,0,208,75,4,0,18,0,0,0,1,12,12,0,8,49,4,0,18,0,0,0,1,12,4,0,152,21,4,0,18,0,0,0,1,12,0,0,72,246,3,0,0,0,0,0,254,0,15,0,32,4,2,0,18,0,0,0,2,240,144,0,176,79,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,160,0,8,32,4,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,176,0,96,164,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,192,0,144,102,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,208,0,176,45,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,224,0,224,127,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,240,0,32,123,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,112,0,192,110,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,96,0,96,102,7,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,80,0,184,105,6,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,64,0,152,96,3,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,48,0,192,100,6,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,32,0,64,1,1,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,16,0,184,69,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,0,0,104,151,6,0,19,0,0,0,0,4,4,0,0,0,0,0,0,0,0,0,254,0,4,0,200,87,7,0,18,0,0,0,130,48,16,0,176,45,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,130,48,32,0,224,127,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,130,48,48,0,32,123,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,130,48,0,0,16,227,4,0,19,0,0,0,0,4,4,0,0,0,0,0,0,0,0,0,254,0,4,0,160,123,6,0,18,0,0,0,130,192,192,0,192,110,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,130,192,128,0,96,102,7,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,130,192,64,0,152,96,3,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,130,192,0,0,192,100,6,0,19,0,0,0,0,4,4,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,1,1,0,96,135,7,0,19,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,200,30,2,0,19,0,0,0,1,2,0,0,120,97,1,0,19,0,0,0,1,2,2,0,96,19,1,0,0,0,0,0,254,0,2,0,96,46,8,0,19,0,0,0,1,4,4,0,208,233,4,0,19,0,0,0,1,4,0,0,72,197,4,0,0,0,0,0,254,0,2,0,208,11,8,0,19,0,0,0,1,8,8,0,96,135,7,0,19,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,2,0,72,4,1,0,19,0,0,0,1,16,16,0,96,135,7,0,19,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,2,0,32,228,8,0,19,0,0,0,1,32,32,0,96,135,7,0,19,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,246,3,0,19,0,0,0,1,64,64,0,96,135,7,0,19,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,128,128,0,96,135,7,0,19,0,0,0,1,128,0,0,152,182,7,0,99,53,46,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,29,121,142,93,0,0,16,1,99,52,46,53,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,184,226,0,64,0,0,16,1,97,45,51,101,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,176,122,232,88,0,0,16,1,97,45,51,102,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,234,49,30,200,0,0,16,1,97,45,51,104,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,149,185,159,217,0,0,16,1,103,45,52,99,45,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,200,201,44,107,0,0,32,0,103,45,52,100,45,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,88,245,72,198,0,0,32,0,103,45,52,101,45,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,110,39,233,251,0,0,32,0,98,45,52,107,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,80,81,251,22,0,0,32,0,98,45,52,102,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,51,90,116,103,0,0,32,0,98,45,52,108,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,97,34,28,189,0,0,32,0,98,45,52,104,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,58,237,197,138,0,0,32,0,98,45,51,110,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,170,19,162,40,0,0,32,0,98,45,52,110,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,243,141,34,213,0,0,32,0,98,45,52,109,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,242,228,109,177,0,0,32,0,98,45,51,109,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,107,214,160,235,0,0,32,0,98,45,52,99,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,133,136,41,1,0,0,32,0,98,45,52,101,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,212,135,123,199,0,0,32,0,98,45,52,100,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,95,97,112,106,0,0,32,0,98,45,52,97,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,38,214,137,97,0,0,32,0,116,98,112,50,52,115,49,48,45,109,97,105,110,45,49,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,202,107,142,102,0,0,32,0,116,98,112,50,52,115,49,48,45,103,102,120,45,49,114,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,156,90,192,118,0,0,32,0,116,98,112,50,52,115,49,48,45,109,97,105,110,45,49,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,149,100,75,150,0,0,32,0,116,98,112,50,52,115,49,48,45,103,102,120,45,49,115,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,153,107,240,35,0,0,32,0,116,98,112,50,52,115,49,48,45,109,97,105,110,45,49,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,225,99,5,85,0,0,32,0,116,98,112,50,52,115,49,48,45,103,102,120,45,49,112,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,33,80,228,53,0,0,32,0,49,56,115,48,51,48,45,103,102,120,45,56,116,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,61,28,96,122,0,0,32,0,116,98,112,50,52,115,49,48,45,103,102,120,45,57,107,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,18,13,194,130,0,0,32,0,49,56,115,48,51,48,45,103,102,120,45,49,48,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,208,172,88,56,0,0,0,8,49,56,115,48,51,48,45,103,102,120,45,53,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,205,79,48,81,0,0,0,8,49,56,115,48,51,48,45,103,102,120,45,53,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,205,79,48,81,0,0,0,8,49,56,115,48,51,48,45,103,102,120,45,54,108,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,208,172,88,56,0,0,0,8,116,98,112,50,52,115,49,48,45,103,102,120,45,51,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,244,110,80,230,0,0,0,8,116,98,112,50,52,115,49,48,45,103,102,120,45,52,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,105,136,170,224,0,0,0,8,116,98,112,50,52,115,49,48,45,103,102,120,45,52,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,79,9,61,180,0,0,0,8,116,98,112,50,52,115,49,48,45,103,102,120,45,54,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,201,57,187,72,0,0,0,8,116,98,112,50,52,115,49,48,45,103,102,120,45,54,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,201,57,187,72,0,0,0,8,116,98,112,50,52,115,49,48,45,103,102,120,45,54,109,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,77,26,122,159,0,0,0,8,116,98,112,50,52,115,49,48,45,103,102,120,45,54,110,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,158,179,229,53,0,0,0,8,116,98,112,50,52,115,49,48,45,103,102,120,45,56,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,158,179,229,53,0,0,0,8,116,98,112,50,52,115,49,48,45,103,102,120,45,57,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,77,26,122,159,0,0,0,8,116,98,112,50,52,115,49,48,45,103,102,120,45,57,107,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,18,13,194,130,0,0,0,8,116,98,112,50,52,115,49,48,45,109,97,105,110,45,56,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,87,188,15,24,0,0,0,8,116,98,112,50,52,115,49,48,45,109,97,105,110,45,56,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,90,46,179,59,0,0,0,8,116,98,112,50,52,115,49,48,45,109,97,105,110,45,56,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,159,49,156,89,0,0,0,8,99,56,49,45,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,201,168,78,180,2,0,16,1,99,56,49,45,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,10,196,152,143,2,0,16,1,99,56,49,45,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,96,180,146,21,1,0,16,1,99,56,49,45,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,182,37,134,110,9,0,16,1,99,56,49,45,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,146,244,187,41,11,0,32,0,99,56,49,45,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,42,93,177,100,15,0,32,0,99,56,49,45,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,232,97,36,150,15,0,32,0,99,56,49,45,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,190,113,61,156,24,0,64,0,99,56,49,45,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,180,51,120,146,25,0,64,0,112,97,108,49,54,108,56,98,45,99,56,49,45,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,50,23,52,70,0,0,0,8,112,97,108,49,54,108,56,98,45,99,56,49,45,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,211,210,231,0,0,0,8,112,97,108,49,54,108,56,98,45,99,56,49,45,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,161,18,192,228,0,0,0,8,21,0,0,0,255,255,255,0,0,0,0,0,22,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,21,0,0,0,1,2,2,0,96,135,7,0,21,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,21,0,0,0,1,4,4,0,96,135,7,0,21,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,21,0,0,0,1,8,0,0,96,135,7,0,21,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0])
.concat([254,0,4,0,200,87,7,0,21,0,0,0,1,48,0,0,16,242,7,0,21,0,0,0,1,48,16,0,104,236,7,0,21,0,0,0,1,48,48,0,128,230,7,0,21,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,21,0,0,0,1,192,0,0,16,242,7,0,21,0,0,0,1,192,64,0,104,236,7,0,21,0,0,0,1,192,192,0,128,230,7,0,21,0,0,0,1,192,128,0,184,164,6,0,0,0,0,0,254,0,4,0,72,202,5,0,22,0,0,0,1,3,2,0,80,246,3,0,22,0,0,0,1,3,3,0,80,124,6,0,22,0,0,0,1,3,1,0,112,212,3,0,22,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,2,0,216,238,6,0,22,0,0,0,1,4,0,0,96,135,7,0,22,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,22,0,0,0,1,48,32,0,208,75,4,0,22,0,0,0,1,48,48,0,8,49,4,0,22,0,0,0,1,48,16,0,152,21,4,0,22,0,0,0,1,48,0,0,72,246,3,0,0,0,0,0,254,0,2,0,104,159,3,0,22,0,0,0,1,64,0,0,96,135,7,0,22,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,6,0,22,0,0,0,1,128,0,0,8,208,6,0,22,0,0,0,1,128,128,0,88,204,6,0,107,114,95,50,51,101,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,235,151,57,27,2,0,16,1,107,114,95,50,50,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,169,113,182,208,2,0,16,1,107,114,45,53,109,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,164,193,54,158,4,0,32,0,107,114,45,55,109,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,174,44,131,197,4,0,32,0,107,114,45,49,109,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,45,190,149,240,4,0,32,0,107,114,45,51,109,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,150,253,157,23,4,0,32,0,107,114,45,54,109,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,210,152,66,31,4,0,32,0,107,114,45,56,109,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,81,135,250,55,4,0,32,0,107,114,45,50,109,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,61,188,0,2,4,0,32,0,107,114,45,52,109,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,231,180,178,11,4,0,32,0,107,114,95,48,57,46,49,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,238,217,68,94,3,0,16,0,107,114,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,95,209,105,218,5,0,64,0,107,114,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,233,84,198,191,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,107,114,54,51,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,34,101,91,253,0,0,0,8,105,111,98,49,46,49,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,98,112,114,103,49,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,167,61,121,49,0,0,0,8,105,111,99,49,46,105,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,129,32,24,13,0,0,0,8,99,54,51,50,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,112,146,189,15,0,0,0,8,27,0,0,0,255,255,0,0,0,0,0,0,28,0,0,0,255,255,3,0,0,0,0,0,29,0,0,0,255,255,96,0,0,0,0,0,0,0,0,0,254,0,8,0,32,4,2,0,27,0,0,0,1,7,7,0,80,252,6,0,27,0,0,0,1,7,6,0,16,242,7,0,27,0,0,0,1,7,5,0,104,236,7,0,27,0,0,0,1,7,0,0,128,230,7,0,27,0,0,0,1,7,1,0,184,164,6,0,27,0,0,0,1,7,2,0,80,74,6,0,27,0,0,0,1,7,3,0,192,32,6,0,27,0,0,0,1,7,4,0,32,242,5,0,0,0,0,0,254,0,2,0,64,232,1,0,27,0,0,0,1,64,0,0,96,135,7,0,27,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,8,0,152,79,1,0,28,0,0,0,1,7,0,0,72,198,6,0,28,0,0,0,1,7,1,0,208,75,4,0,28,0,0,0,1,7,2,0,8,49,4,0,28,0,0,0,1,7,3,0,72,195,6,0,28,0,0,0,1,7,4,0,72,246,3,0,28,0,0,0,1,7,5,0,72,0,3,0,28,0,0,0,1,7,6,0,64,47,7,0,28,0,0,0,1,7,7,0,48,173,6,0,0,0,0,0,254,0,8,0,136,77,1,0,28,0,0,0,1,56,56,0,72,198,6,0,28,0,0,0,1,56,48,0,208,75,4,0,28,0,0,0,1,56,40,0,8,49,4,0,28,0,0,0,1,56,0,0,72,195,6,0,28,0,0,0,1,56,8,0,72,246,3,0,28,0,0,0,1,56,16,0,72,0,3,0,28,0,0,0,1,56,24,0,64,47,7,0,28,0,0,0,1,56,32,0,48,173,6,0,0,0,0,0,254,0,2,0,88,160,1,0,28,0,0,0,1,64,64,0,192,255,2,0,28,0,0,0,1,64,0,0,8,49,4,0,0,0,0,0,254,0,2,0,112,242,7,0,28,0,0,0,1,128,128,0,8,77,1,0,28,0,0,0,1,128,0,0,160,76,1,0,0,0,0,0,254,0,4,0,128,129,4,0,29,0,0,0,1,3,3,0,192,255,2,0,29,0,0,0,1,3,0,0,208,75,4,0,29,0,0,0,1,3,1,0,8,49,4,0,29,0,0,0,1,3,2,0,152,21,4,0,0,0,0,0,254,0,2,0,16,227,4,0,29,0,0,0,1,4,0,0,96,135,7,0,29,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,254,0,2,0,72,4,1,0,29,0,0,0,1,8,0,0,96,135,7,0,29,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,2,0,120,207,1,0,29,0,0,0,1,16,0,0,96,135,7,0,29,0,0,0,1,16,16,0,152,182,7,0,0,0,0,0,254,0,2,0,40,111,8,0,29,0,0,0,1,32,0,0,96,135,7,0,29,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,29,0,0,0,1,64,0,0,96,135,7,0,29,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,168,79,2,0,29,0,0,0,1,128,0,0,32,182,8,0,29,0,0,0,1,128,128,0,80,251,6,0,107,121,95,97,45,52,101,45,103,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,215,188,220,46,0,0,16,1,100,114,48,51,46,52,99,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,52,9,162,219,0,0,16,1,107,121,95,116,45,56,107,45,103,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,49,47,196,219,0,0,16,1,100,114,49,50,46,56,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,253,85,178,192,0,0,16,1,100,114,48,48,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,247,9,131,69,0,0,16,1,100,114,48,49,46,51,99,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,189,151,104,230,0,0,16,1,100,114,48,50,46,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,38,30,227,249,0,0,16,1,100,114,48,54,46,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,15,151,154,77,0,0,32,0,100,114,48,55,46,50,100,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,196,164,89,171,0,0,32,0,100,114,48,53,46,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,12,173,109,46,0,0,32,0,100,114,50,49,46,52,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,154,234,108,160,0,0,32,0,100,114,49,57,46,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,173,5,70,179,0,0,32,0,100,114,50,50,46,52,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,232,61,48,65,0,0,32,0,100,114,50,48,46,52,106,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,97,111,190,95,0,0,32,0,100,114,49,52,46,51,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,188,188,207,118,0,0,32,0,100,114,50,52,46,52,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,181,141,28,213,0,0,32,0,100,114,50,51,46,52,110,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,248,157,70,3,0,0,32,0,100,114,49,51,46,51,110,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,224,223,195,213,0,0,32,0,100,114,49,54,46,52,99,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,147,187,209,241,0,0,32,0,100,114,49,56,46,52,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,91,242,183,237,0,0,32,0,100,114,49,55,46,52,100,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,104,120,184,79,0,0,32,0,100,114,49,53,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,229,141,184,224,0,0,32,0,100,114,48,56,46,52,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,67,6,213,50,0,0,32,0,100,114,48,57,46,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,149,111,223,23,0,0,32,0,100,114,49,48,46,52,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,82,226,12,130,0,0,32,0,100,114,50,53,46,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,11,67,145,142,0,0,32,0,100,114,51,48,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,99,50,199,40,0,0,32,0,100,114,50,54,46,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,63,185,99,181,0,0,32,0,100,114,51,49,46,49,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,14,33,41,53,0,0,32,0,100,114,50,55,46,51,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,239,104,214,112,0,0,32,0,100,114,50,57,46,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,84,167,115,17,0,0,32,0,100,114,51,50,46,53,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,46,31,205,17,0,0,32,0,100,114,51,51,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,60,141,216,52,0,0,32,0,100,114,50,56,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,189,15,239,108,0,0,0,8,18,0,0,0,255,255,255,0,0,0,0,0,19,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,18,0,0,0,1,3,2,0,208,75,4,0,18,0,0,0,1,3,3,0,8,49,4,0,18,0,0,0,1,3,1,0,152,21,4,0,18,0,0,0,1,3,0,0,72,246,3,0,0,0,0,0,254,0,2,0,72,202,5,0,18,0,0,0,1,4,4,0,248,38,7,0,18,0,0,0,1,4,0,0,112,212,3,0,0,0,0,0,254,0,2,0,64,37,5,0,18,0,0,0,1,8,8,0,8,49,6,0,18,0,0,0,1,8,0,0,184,43,6,0,0,0,0,0,254,0,16,0,32,4,2,0,18,0,0,0,2,240,160,0,8,32,4,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,176,0,96,164,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,192,0,144,102,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,208,0,176,45,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,16,0,112,169,3,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,224,0,224,127,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,32,0,192,119,3,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,48,0,136,252,1,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,240,0,32,123,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,64,0,248,116,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,144,0,192,110,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,128,0,96,102,7,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,112,0,184,105,6,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,96,0,152,96,3,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,80,0,192,100,6,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,0,0,104,151,6,0,19,0,0,0,0,4,4,0,0,0,0,0,0,0,0,0,254,0,4,0,200,87,7,0,18,0,0,0,130,48,0,0,96,164,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,130,48,16,0,176,45,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,130,48,32,0,224,127,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,130,48,48,0,32,123,8,0,19,0,0,0,0,4,4,0,0,0,0,0,0,0,0,0,254,0,4,0,160,123,6,0,18,0,0,0,130,192,192,0,192,110,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,130,192,128,0,96,102,7,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,130,192,64,0,152,96,3,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,130,192,0,0,192,100,6,0,19,0,0,0,0,4,4,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,1,1,0,96,135,7,0,19,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,200,30,2,0,19,0,0,0,1,2,0,0,120,97,1,0,19,0,0,0,1,2,2,0,96,19,1,0,0,0,0,0,254,0,2,0,96,46,8,0,19,0,0,0,1,4,4,0,208,233,4,0,19,0,0,0,1,4,0,0,72,197,4,0,0,0,0,0,254,0,2,0,136,141,8,0,19,0,0,0,1,8,8,0,96,135,7,0,19,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,19,0,0,0,1,16,0,0,96,135,7,0,19,0,0,0,1,16,16,0,152,182,7,0,0,0,0,0,254,0,2,0,72,4,1,0,19,0,0,0,1,32,32,0,96,135,7,0,19,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,246,3,0,19,0,0,0,1,64,64,0,96,135,7,0,19,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,128,128,0,96,135,7,0,19,0,0,0,1,128,0,0,152,182,7,0,4,0,0,0,255,255,255,0,0,0,0,0,5,0,0,0,255,255,191,0,0,0,0,0,6,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,8,0,72,202,5,0,4,0,0,0,1,7,3,0,192,255,2,0,4,0,0,0,1,7,5,0,208,75,4,0,4,0,0,0,1,7,1,0,8,49,4,0,4,0,0,0,1,7,7,0,152,21,4,0,4,0,0,0,1,7,6,0,72,246,3,0,4,0,0,0,1,7,2,0,72,0,3,0,4,0,0,0,1,7,4,0,64,47,7,0,4,0,0,0,1,7,0,0,232,99,5,0,0,0,0,0,254,0,8,0,88,178,6,0,4,0,0,0,1,56,56,0,48,178,2,0,4,0,0,0,1,56,48,0,72,176,2,0,4,0,0,0,1,56,40,0,184,174,2,0,4,0,0,0,1,56,32,0,248,173,2,0,4,0,0,0,1,56,24,0,64,173,2,0,4,0,0,0,1,56,16,0,88,172,2,0,4,0,0,0,1,56,8,0,32,171,2,0,4,0,0,0,1,56,0,0,48,178,2,0,0,0,0,0,254,0,8,0,200,87,7,0,5,0,0,0,1,7,0,0,96,135,3,0,5,0,0,0,1,7,4,0,32,136,7,0,5,0,0,0,1,7,2,0,40,88,7,0,5,0,0,0,1,7,6,0,96,39,7,0,5,0,0,0,1,7,7,0,144,251,6,0,5,0,0,0,1,7,3,0,184,164,6,0,5,0,0,0,1,7,5,0,80,74,6,0,5,0,0,0,1,7,1,0,192,32,6,0,0,0,0,0,254,0,2,0,16,227,4,0,5,0,0,0,1,32,32,0,96,135,7,0,5,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,5,0,0,0,1,64,64,0,96,135,7,0,5,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,5,0,0,0,1,128,128,0,96,135,7,0,5,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,8,0,32,4,2,0,20,0,0,0,1,7,2,0,88,154,8,0,20,0,0,0,1,7,1,0,200,92,8,0,20,0,0,0,1,7,4,0,152,141,7,0,20,0,0,0,1,7,7,0,104,172,6,0,20,0,0,0,1,7,6,0,24,46,7,0,20,0,0,0,1,7,3,0,216,129,6,0,20,0,0,0,1,7,5,0,184,81,6,0,20,0,0,0,1,7,0,0,16,227,4,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,24,8,0,160,203,8,0,20,0,0,0,1,24,16,0,80,246,3,0,20,0,0,0,1,24,24,0,248,38,7,0,20,0,0,0,1,24,0,0,112,212,3,0,0,0,0,0,254,0,2,0,112,167,5,0,20,0,0,0,1,32,0,0,96,135,7,0,20,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,1,0,232,75,4,0,20,0,0,0,1,128,128,0,96,135,7,0,20,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,0,0,0,0,0,0,0,0,54,56,107,95,112,114,103,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,185,54,53,18,0,0,16,1,122,56,48,95,112,114,103,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,36,68,141,168,0,0,16,1,98,103,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,61,54,161,53,0,0,32,0,98,103,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,67,249,55,91,0,0,32,0,115,112,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,51,6,93,124,0,0,32,0,115,112,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,46,120,174,126,0,0,32,0,115,97,109,112,108,101,115,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,167,48,111,6,0,0,64,0,17,0,0,0,255,255,255,0,0,0,0,0,18,0,0,0,255,255,254,0,0,0,0,0,0,0,0,0,254,0,2,0,232,75,4,0,17,0,0,0,1,1,1,0,96,135,7,0,17,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,16,227,4,0,17,0,0,0,1,2,2,0,96,135,7,0,17,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,8,0,200,87,7,0,17,0,0,0,1,224,0,0,16,242,7,0,17,0,0,0,1,224,128,0,104,236,7,0,17,0,0,0,1,224,224,0,128,230,7,0,17,0,0,0,1,224,96,0,184,164,6,0,17,0,0,0,1,224,160,0,80,74,6,0,17,0,0,0,1,224,32,0,192,32,6,0,17,0,0,0,1,224,192,0,192,234,2,0])
.concat([17,0,0,0,1,224,64,0,32,242,5,0,0,0,0,0,254,0,8,0,160,123,6,0,17,0,0,0,1,28,0,0,16,242,7,0,17,0,0,0,1,28,16,0,104,236,7,0,17,0,0,0,1,28,28,0,128,230,7,0,17,0,0,0,1,28,12,0,184,164,6,0,17,0,0,0,1,28,20,0,80,74,6,0,17,0,0,0,1,28,4,0,192,32,6,0,17,0,0,0,1,28,24,0,192,234,2,0,17,0,0,0,1,28,8,0,32,242,5,0,0,0,0,0,254,0,2,0,168,234,7,0,18,0,0,0,1,1,1,0,96,135,7,0,18,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,18,0,0,0,1,2,0,0,96,135,7,0,18,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,2,0,104,170,1,0,18,0,0,0,1,4,4,0,96,135,7,0,18,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,176,161,1,0,18,0,0,0,1,8,8,0,192,255,2,0,18,0,0,0,1,8,0,0,208,75,4,0,0,0,0,0,254,0,4,0,72,202,5,0,18,0,0,0,1,48,32,0,80,246,3,0,18,0,0,0,1,48,48,0,248,38,7,0,18,0,0,0,1,48,16,0,112,212,3,0,18,0,0,0,1,48,0,0,248,160,5,0,0,0,0,0,254,0,4,0,128,129,4,0,18,0,0,0,1,192,128,0,192,255,2,0,18,0,0,0,1,192,0,0,208,75,4,0,18,0,0,0,1,192,192,0,8,49,4,0,18,0,0,0,1,192,64,0,152,21,4,0,106,98,49,95,104,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,49,107,171,63,2,0,16,1,106,98,49,95,104,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,39,136,135,140,2,0,16,1,106,98,49,95,105,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,207,146,52,68,2,0,16,1,106,98,49,95,105,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,225,186,51,237,2,0,16,1,98,50,50,45,48,51,46,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,184,15,187,62,2,0,16,1,98,50,50,45,48,52,46,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,127,94,98,145,2,0,16,1,106,98,49,95,102,56,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,39,211,16,8,3,0,16,1,106,98,49,95,99,100,54,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,14,192,39,133,9,0,16,1,106,98,50,95,105,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,9,99,183,101,11,0,32,0,106,98,50,95,105,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,131,66,169,67,11,0,32,0,106,98,50,95,105,99,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,251,51,25,230,11,0,32,0,106,98,50,95,105,99,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,178,30,3,237,11,0,32,0,106,98,50,95,105,99,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,202,0,39,49,11,0,32,0,106,98,50,95,105,99,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,136,11,59,222,11,0,32,0,106,98,50,95,105,99,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,142,108,220,159,11,0,32,0,106,98,50,95,105,99,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,146,100,34,6,11,0,32,0,106,98,50,95,105,99,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,108,219,72,133,15,0,32,0,106,98,50,95,105,99,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,59,146,197,55,15,0,32,0,106,98,50,95,105,99,54,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,30,47,42,102,15,0,32,0,106,98,50,95,105,99,55,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,225,101,88,146,15,0,32,0,106,98,50,95,105,99,55,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,209,149,150,176,15,0,32,0,106,98,50,95,105,99,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,67,119,147,65,15,0,32,0,106,98,50,95,105,99,57,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,171,238,68,246,15,0,32,0,106,98,50,95,105,99,57,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,51,205,188,63,15,0,32,0,106,98,50,95,105,99,57,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,20,192,134,216,15,0,32,0,106,98,50,95,105,49,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,77,30,223,147,15,0,32,0,106,98,50,95,105,49,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,59,137,78,124,15,0,32,0,106,98,50,95,105,49,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,216,88,29,126,15,0,32,0,9,0,0,0,255,255,254,0,0,0,0,0,10,0,0,0,255,255,191,0,0,0,0,0,0,0,0,0,254,0,2,0,168,234,7,0,9,0,0,0,1,8,0,0,96,135,7,0,9,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,9,0,0,0,1,48,16,0,104,236,7,0,9,0,0,0,1,48,48,0,128,230,7,0,9,0,0,0,1,48,0,0,120,211,6,0,9,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,9,0,0,0,1,192,64,0,104,236,7,0,9,0,0,0,1,192,192,0,128,230,7,0,9,0,0,0,1,192,0,0,120,211,6,0,9,0,0,0,1,192,128,0,184,164,6,0,0,0,0,0,254,0,4,0,72,202,5,0,10,0,0,0,1,3,2,0,80,246,3,0,10,0,0,0,1,3,3,0,80,124,6,0,10,0,0,0,1,3,1,0,112,212,3,0,10,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,2,0,64,37,5,0,10,0,0,0,1,4,4,0,184,79,7,0,10,0,0,0,1,4,0,0,120,7,5,0,0,0,0,0,254,0,2,0,248,72,7,0,10,0,0,0,1,8,8,0,56,68,7,0,10,0,0,0,1,8,0,0,0,64,7,0,0,0,0,0,254,0,4,0,128,129,4,0,10,0,0,0,1,48,16,0,192,255,2,0,10,0,0,0,1,48,0,0,208,75,4,0,10,0,0,0,1,48,48,0,8,49,4,0,10,0,0,0,1,48,32,0,152,21,4,0,0,0,0,0,106,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,183,161,90,65,1,0,16,1,106,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,16,117,194,177,1,0,16,1,106,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,226,75,194,151,1,0,16,1,106,98,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,18,29,117,102,1,0,16,1,106,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,175,111,214,226,1,0,16,1,106,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,253,189,224,73,1,0,16,1,106,98,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,2,19,215,131,1,0,16,1,106,98,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,10,27,9,154,4,0,32,0,106,98,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,130,192,15,138,4,0,32,0,106,98,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,224,134,81,21,4,0,32,0,106,98,105,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,17,177,73,119,4,0,32,0,106,98,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,223,215,232,6,4,0,32,0,106,98,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,243,221,219,184,4,0,32,0,108,48,54,95,112,114,111,109,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,135,125,12,106,7,0,32,0,15,0,0,0,255,255,0,0,0,0,0,0,16,0,0,0,255,255,0,0,0,0,0,0,17,0,0,0,255,255,1,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,15,0,0,0,1,32,0,0,120,97,1,0,15,0,0,0,1,32,32,0,96,19,1,0,0,0,0,0,254,0,2,0,72,202,5,0,16,0,0,0,1,64,64,0,80,246,3,0,16,0,0,0,1,64,0,0,112,212,3,0,0,0,0,0,254,0,4,0,128,129,4,0,17,0,0,0,1,3,1,0,8,49,4,0,17,0,0,0,1,3,2,0,152,21,4,0,17,0,0,0,1,3,3,0,72,246,3,0,17,0,0,0,1,3,0,0,112,49,6,0,0,0,0,0,254,0,4,0,32,4,2,0,17,0,0,0,1,12,4,0,64,155,1,0,17,0,0,0,1,12,8,0,144,147,2,0,17,0,0,0,1,12,0,0,16,223,1,0,17,0,0,0,1,12,12,0,200,209,1,0,0,0,0,0,0,0,128,0,8,0,128,0,0,0,0,0,8,0,0,0,16,0,128,0,24,0,128,0,16,0,0,0,24,0,0,0,0,1,128,0,8,1,128,0,0,1,0,0,8,1,0,0,16,1,128,0,24,1,128,0,16,1,0,0,24,1,0,0,0,0,128,0,8,0,128,0,0,0,0,0,8,0,0,0,16,0,128,0,24,0,128,0,16,0,0,0,24,0,0,0,168,86,7,0,1,0,0,0,226,238,146,0,248,191,2,0,24,38,7,0,1,0,0,0,224,238,146,0,184,160,2,0,56,210,6,0,1,0,0,0,56,253,146,0,192,135,2,0,24,163,6,0,1,0,0,0,57,253,146,0,240,108,2,0,152,122,6,0,1,0,0,0,58,253,146,0,96,82,2,0,192,72,6,0,1,0,0,0,59,253,146,0,32,56,2,0,200,110,3,0,1,0,0,0,60,253,146,0,152,30,2,0,120,89,3,0,1,0,0,0,61,253,146,0,232,10,2,0,120,74,3,0,1,0,0,0,62,253,146,0,152,138,8,0,192,61,3,0,1,0,0,0,240,236,146,0,48,119,7,0,40,246,1,0,1,0,0,0,227,238,146,0,64,246,1,0,144,236,1,0,1,0,0,0,225,238,146,0,136,224,1,0,176,223,1,0,1,0,0,0,232,244,146,0,72,198,1,0,192,209,1,0,1,0,0,0,233,244,146,0,24,182,1,0,24,198,1,0,1,0,0,0,234,244,146,0,40,167,1,0,120,189,1,0,1,0,0,0,235,244,146,0,200,149,1,0,224,22,1,0,1,0,0,0,236,244,146,0,56,126,1,0,160,14,1,0,1,0,0,0,237,244,146,0,32,101,1,0,176,9,1,0,1,0,0,0,238,244,146,0,96,32,8,0,200,3,1,0,1,0,0,0,242,236,146,0,16,68,7,0,88,212,3,0,1,0,0,0,120,217,146,0,40,185,3,0,16,17,8,0,1,0,0,0,230,238,146,0,224,12,8,0,56,58,1,0,1,0,0,0,229,238,146,0,64,50,1,0,48,50,1,0,9,0,0,0,129,4,147,0,32,58,1,0,72,65,1,0,9,0,0,0,128,4,147,0,32,58,1,0,18,0,0,0,255,255,175,0,0,0,0,0,19,0,0,0,255,255,253,0,0,0,0,0,20,0,0,0,255,255,240,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,18,0,0,0,1,3,2,0,208,75,4,0,18,0,0,0,1,3,3,0,8,49,4,0,18,0,0,0,1,3,1,0,152,21,4,0,18,0,0,0,1,3,0,0,72,246,3,0,0,0,0,0,254,0,4,0,72,202,5,0,18,0,0,0,1,12,0,0,160,203,8,0,18,0,0,0,1,12,8,0,80,246,3,0,18,0,0,0,1,12,12,0,248,38,7,0,18,0,0,0,1,12,4,0,112,212,3,0,0,0,0,0,254,0,2,0,72,8,1,0,18,0,0,0,1,32,32,0,56,111,3,0,18,0,0,0,1,32,0,0,104,134,3,0,0,0,0,0,254,0,2,0,168,234,7,0,18,0,0,0,1,64,64,0,96,135,7,0,18,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,18,0,0,0,1,128,128,0,96,135,7,0,18,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,1,1,0,96,135,7,0,19,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,88,160,1,0,19,0,0,0,1,4,4,0,136,86,1,0,19,0,0,0,1,4,0,0,184,147,6,0,0,0,0,0,254,0,2,0,96,46,8,0,19,0,0,0,1,8,8,0,192,255,2,0,19,0,0,0,1,8,0,0,208,75,4,0,0,0,0,0,254,0,16,0,32,4,2,0,19,0,0,0,1,240,160,0,144,160,3,0,19,0,0,0,1,240,176,0,96,135,3,0,19,0,0,0,1,240,192,0,32,136,7,0,19,0,0,0,1,240,208,0,40,88,7,0,19,0,0,0,1,240,224,0,96,39,7,0,19,0,0,0,1,240,16,0,32,202,2,0,19,0,0,0,1,240,48,0,120,113,6,0,19,0,0,0,1,240,32,0,232,228,5,0,19,0,0,0,1,240,240,0,144,251,6,0,19,0,0,0,1,240,64,0,120,211,6,0,19,0,0,0,1,240,144,0,184,164,6,0,19,0,0,0,1,240,128,0,80,74,6,0,19,0,0,0,1,240,112,0,192,32,6,0,19,0,0,0,1,240,96,0,192,234,2,0,19,0,0,0,1,240,80,0,32,242,5,0,19,0,0,0,1,240,0,0,16,227,4,0,19,0,0,0,255,255,254,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,19,0,0,0,1,1,0,0,120,97,1,0,19,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,2,2,0,96,135,7,0,19,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,4,4,0,96,135,7,0,19,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,8,0,0,96,135,7,0,19,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,19,0,0,0,1,48,0,0,32,136,7,0,19,0,0,0,1,48,16,0,40,88,7,0,19,0,0,0,1,48,32,0,96,39,7,0,19,0,0,0,1,48,48,0,144,251,6,0,0,0,0,0,254,0,4,0,160,123,6,0,19,0,0,0,1,192,192,0,184,164,6,0,19,0,0,0,1,192,128,0,80,74,6,0,19,0,0,0,1,192,64,0,192,32,6,0,19,0,0,0,1,192,0,0,32,242,5,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,3,2,0,80,246,3,0,20,0,0,0,1,3,3,0,80,124,6,0,20,0,0,0,1,3,1,0,112,212,3,0,20,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,64,37,5,0,20,0,0,0,1,12,8,0,152,76,8,0,20,0,0,0,1,12,12,0,240,70,8,0,20,0,0,0,1,12,4,0,80,68,8,0,20,0,0,0,1,12,0,0,208,64,8,0,0,0,0,0,254,0,0,0,128,129,4,0,20,0,0,0,1,48,32,0,208,75,4,0,20,0,0,0,1,48,48,0,8,49,4,0,20,0,0,0,1,48,16,0,152,21,4,0,20,0,0,0,1,48,0,0,72,246,3,0,0,0,0,0,101,112,114,45,54,54,55,54,46,49,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,127,125,8,235,0,0,16,1,101,112,114,45,54,54,55,55,46,49,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,238,75,36,189,0,0,16,1,101,112,114,45,54,54,55,56,46,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,253,185,22,46,0,0,16,1,101,112,114,45,54,54,53,54,46,49,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,133,214,227,37,0,0,16,1,101,112,114,45,54,54,56,52,46,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,119,243,141,44,0,0,32,0,101,112,114,45,54,54,56,51,46,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,72,28,67,137,0,0,32,0,101,112,114,45,54,54,56,50,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,70,146,106,37,0,0,32,0,101,112,114,45,54,54,56,49,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,137,209,116,105,0,0,32,0,101,112,114,45,54,54,56,48,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,214,41,166,16,0,0,32,0,101,112,114,45,54,54,55,52,46,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,60,136,61,20,0,0,32,0,101,112,114,45,54,54,52,53,46,49,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,238,103,161,27,0,0,32,0,101,112,114,45,54,54,52,54,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,214,122,218,237,0,0,32,0,112,114,45,53,51,49,55,46,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,184,80,131,100,0,0,0,8,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,252,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,19,0,0,0,1,15,7,0,80,252,6,0,19,0,0,0,1,15,8,0,16,242,7,0,19,0,0,0,1,15,9,0,104,236,7,0,19,0,0,0,1,15,5,0,192,54,8,0,19,0,0,0,1,15,4,0,56,24,4,0,19,0,0,0,1,15,15,0,128,230,7,0,19,0,0,0,1,15,0,0,128,230,7,0,19,0,0,0,1,15,3,0,176,162,3,0,19,0,0,0,1,15,2,0,24,188,3,0,19,0,0,0,1,15,1,0,72,216,3,0,19,0,0,0,1,15,6,0,120,211,6,0,19,0,0,0,1,15,14,0,184,164,6,0,19,0,0,0,1,15,13,0,80,74,6,0,19,0,0,0,1,15,12,0,192,32,6,0,19,0,0,0,1,15,11,0,192,234,2,0,19,0,0,0,1,15,10,0,32,242,5,0,0,0,0,0,254,0,16,0,160,123,6,0,19,0,0,0,1,240,112,0,80,252,6,0,19,0,0,0,1,240,128,0,16,242,7,0,19,0,0,0,1,240,144,0,104,236,7,0,19,0,0,0,1,240,80,0,192,54,8,0,19,0,0,0,1,240,64,0,56,24,4,0,19,0,0,0,1,240,240,0,128,230,7,0,19,0,0,0,1,240,0,0,128,230,7,0,19,0,0,0,1,240,48,0,176,162,3,0,19,0,0,0,1,240,32,0,24,188,3,0,19,0,0,0,1,240,16,0,72,216,3,0,19,0,0,0,1,240,96,0,120,211,6,0,19,0,0,0,1,240,224,0,184,164,6,0,19,0,0,0,1,240,208,0,80,74,6,0,19,0,0,0,1,240,192,0,192,32,6,0,19,0,0,0,1,240,176,0,192,234,2,0,19,0,0,0,1,240,160,0,32,242,5,0,0,0,0,0,254,0,2,0,200,30,2,0,20,0,0,0,1,1,0,0,120,97,1,0,20,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,2,0,168,234,7,0,20,0,0,0,1,2,2,0,96,135,7,0,20,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,12,12,0,8,49,4,0,20,0,0,0,1,12,8,0,152,21,4,0,20,0,0,0,1,12,4,0,72,246,3,0,20,0,0,0,1,12,0,0,112,49,6,0,0,0,0,0,254,0,4,0,64,37,5,0,20,0,0,0,1,48,48,0,192,33,6,0,20,0,0,0,1,48,32,0,160,30,6,0,20,0,0,0,1,48,16,0,208,26,6,0,20,0,0,0,1,48,0,0,120,7,5,0,184,40,2,0,1,0,0,0,92,240,146,0,248,191,2,0,184,164,8,0,1,0,0,0,93,240,146,0,64,246,1,0,24,38,7,0,1,0,0,0,15,1,147,0,184,160,2,0,56,210,6,0,1,0,0,0,8,1,147,0,192,135,2,0,24,163,6,0,1,0,0,0,9,1,147,0,240,108,2,0,152,122,6,0,1,0,0,0,10,1,147,0,96,82,2,0,192,72,6,0,1,0,0,0,11,1,147,0,32,56,2,0,200,110,3,0,1,0,0,0,12,1,147,0,152,30,2,0,120,89,3,0,1,0,0,0,13,1,147,0,232,10,2,0,120,74,3,0,1,0,0,0,14,1,147,0,152,138,8,0,240,251,8,0,4,0,0,0,32,8,147,0,136,191,7,0,144,236,1,0,1,0,0,0,111,248,146,0,136,224,1,0,176,223,1,0,1,0,0,0,104,248,146,0,72,198,1,0,192,209,1,0,1,0,0,0,105,248,146,0,24,182,1,0,24,198,1,0,1,0,0,0,106,248,146,0,40,167,1,0,120,189,1,0,1,0,0,0,107,248,146,0,200,149,1,0,224,22,1,0,1,0,0,0,108,248,146,0,56,126,1,0,160,14,1,0,1,0,0,0,109,248,146,0,32,101,1,0,176,9,1,0,1,0,0,0,110,248,146,0,96,32,8,0,112,188,8,0,4,0,0,0,34,8,147,0,0,187,4,0,56,122,5,0,1,0,0,0,88,240,146,0,224,12,8,0,88,212,3,0,1,0,0,0,80,220,146,0,40,185,3,0,248,5,8,0,9,0,0,0,112,6,147,0,32,58,1,0,144,250,7,0,9,0,0,0,113,6,147,0,32,58,1,0,101,112,114,45,49,49,50,51,57,46,97,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,215,254,171,229,1,0,16,1,101,112,114,45,49,49,50,51,56,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,36,1,24,37,1,0,16,1,109,112,114,45,49,49,50,52,49,46,97,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,134,106,88,252,2,0,32,0,109,112,114,45,49,49,49,54,54,46,98,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,216,169,170,174,2,0,32,0,109,112,114,45,49,49,50,52,50,46,97,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,66,167,21,119,2,0,32,0,109,112,114,45,49,49,49,54,55,46,98,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,250,42,168,99,2,0,32,0,109,112,114,45,49,49,50,52,51,46,97,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,253,213,12,243,2,0,32,0,109,112,114,45,49,49,49,54,56,46,98,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,168,148,132,91,2,0,32,0,109,112,114,45,49,49,49,53,56,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,19,138,9,252,3,0,32,0,109,112,114,45,49,49,49,54,50,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,168,52,185,93,3,0,32,0,109,112,114,45,49,49,49,53,57,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,116,238,39,31,3,0,32,0,109,112,114,45,49,49,49,54,51,46,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,241,92,106,138,3,0,32,0,109,112,114,45,49,49,49,54,48,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,130,186,178,192,3,0,32,0,109,112,114,45,49,49,49,54,52,46,98,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,123,145,199,214,3,0,32,0,109,112,114,45,49,49,49,54,49,46,98,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,75,228,201,53,3,0,32,0,109,112,114,45,49,49,49,54,53,46,98,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,210,249,232,87,3,0,32,0,101,112,114,45,49,49,50,52,48,46,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,157,45,161,150,4,0,16,1,109,112,114,45,49,49,50,52,52,46,97,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,61,192,145,65,8,0,64,0,109,112,114,45,49,49,50,52,53,46,97,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,123,63,213,164,8,0,64,0,112,108,115,49,53,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,235,0,0,0,18,114,180,57,0,0,0,8,10,0,0,0,255,255,249,0,0,0,0,0,11,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,168,234,7,0,10,0,0,0,1,2,2,0,96,135,7,0,10,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,128,8,3,0,10,0,0,0,1,4,4,0,96,135,7,0,10,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,10,0,0,0,1,8,8,0,96,135,7,0,10,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,10,0,0,0,1,48,32,0,80,246,3,0,10,0,0,0,1,48,48,0,248,38,7,0,10,0,0,0,1,48,16,0,112,212,3,0,10,0,0,0,1,48,0,0,248,160,5,0,0,0,0,0,254,0,4,0,40,252,8,0,10,0,0,0,1,192,128,0,80,246,3,0,10,0,0,0,1,192,192,0,248,38,7,0,10,0,0,0,1,192,64,0,112,212,3,0,10,0,0,0,1,192,0,0,248,160,5,0,0,0,0,0,254,0,16,0,200,87,7,0,11,0,0,0,1,15,7,0,80,252,6,0,11,0,0,0,1,15,8,0,16,242,7,0,11,0,0,0,1,15,9,0,104,236,7,0,11,0,0,0,1,15,5,0,176,51,4,0,11,0,0,0,1,15,4,0,56,24,4,0,11,0,0,0,1,15,15,0,128,230,7,0,11,0,0,0,1,15,1,0,72,216,3,0,11,0,0,0,1,15,2,0,24,188,3,0,11,0,0,0,1,15,3,0,176,162,3,0,11,0,0,0,1,15,6,0,120,211,6,0,11,0,0,0,1,15,14,0,184,164,6,0,11,0,0,0,1,15,13,0,80,74,6,0,11,0,0,0,1,15,12,0,192,32,6,0,11,0,0,0,1,15,11,0,192,234,2,0,11,0,0,0,1,15,10,0,32,242,5,0,11,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,11,0,0,0,1,240,112,0,80,252,6,0,11,0,0,0,1,240,128,0,16,242,7,0,11,0,0,0,1,240,144,0,104,236,7,0,11,0,0,0,1,240,80,0,176,51,4,0,11,0,0,0,1,240,64,0,56,24,4,0,11,0,0,0,1,240,240,0,128,230,7,0,11,0,0,0,1,240,16,0,72,216,3,0,11,0,0,0,1,240,32,0,24,188,3,0,11,0,0,0,1,240,48,0,176,162,3,0,11,0,0,0,1,240,96,0,120,211,6,0,11,0,0,0,1,240,224,0,184,164,6,0,11,0,0,0,1,240,208,0,80,74,6,0,11,0,0,0,1,240,192,0,192,32,6,0,11,0,0,0,1,240,176,0,192,234,2,0,11,0,0,0,1,240,160,0,32,242,5,0,11,0,0,0,1,240,0,0,208,236,2,0,0,0,0,0,104,117,115,116,108,101,114,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,62,154,71,148,1,0,16,1,104,117,115,116,108,101,114,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,204,123,198,60,1,0,16,1,104,117,115,116,108,101,114,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,106,34,34,148,1,0,16,1,104,117,115,116,108,101,114,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,68,101,148,122,2,0,16,1,104,117,115,116,108,101,114,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,81,115,181,61,2,0,16,1,104,117,115,116,108,101,114,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,14,173,223,11,4,0,32,0,104,117,115,116,108,101,114,46,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,119,33,6,142,4,0,32,0,104,117,115,116,108,101,114,46,99,108,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,94,127,31,170,7,0,32,0,16,0,0,0,255,255,0,0,0,0,0,0,17,0,0,0,255,255,2,0,0,0,0,0,18,0,0,0,255,255,14,0,0,0,0,0,0,0,0,0,254,0,2,0,128,129,4,0,17,0,0,0,1,1,1,0,192,255,2,0,17,0,0,0,1,1,0,0,208,75,4,0,0,0,0,0,254,0,2,0,144,3,8,0,17,0,0,0,1,2,2,0,96,135,7,0,17,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,4,0,32,4,2,0,18,0,0,0,1,6,2,0,176,45,8,0,18,0,0,0,1,6,4,0,224,127,8,0,18,0,0,0,1,6,6,0,32,123,8,0,18,0,0,0,1,6,0,0,192,110,8,0,0,0,0,0,254,0,2,0,200,30,2,0,18,0,0,0,1,8,8,0,120,97,1,0,18,0,0,0,1,8,0,0,96,19,1,0,0,0,0,0,50,49,46,117,56,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,127,15,0,233,0,0,16,1,50,50,46,117,54,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,197,142,81,44,0,0,16,1,112,105,99,49,54,99,53,55,45,104,115,46,105,48,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,76,45,0,0,65,105,44,2,0,0,16,1,50,51,46,117,51,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,185,96,207,221,0,0,32,0,50,55,46,117,52,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,244,188,59,65,0,0,32,0,50,52,46,117,51,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,76,91,170,75,0,0,32,0,50,56,46,117,52,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,106,77,243,141,0,0,32,0,50,54,46,117,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,117,59,141,255,0,0,32,0,51,48,46,117,56,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,199,64,166,135,0,0,32,0,50,53,46,117,51,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,69,68,253,196,0,0,32,0,50,57,46,117,56,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,83,251,235,11,0,0,32,0,50,48,46,105,111,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,229,163,243,11,0,0,64,0,11,0,0,0,255,255,239,0,0,0,0,0,12,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,8,0,72,202,5,0,11,0,0,0,1,7,7,0,80,246,3,0,11,0,0,0,1,7,6,0,248,38,7,0,11,0,0,0,1,7,5,0,112,212,3,0,11,0,0,0,1,7,4,0,240,220,6,0,11,0,0,0,1,7,3,0,152,175,6,0,11,0,0,0,1,7,2,0,104,133,6,0,11,0,0,0,1,7,1,0,216,86,6,0,11,0,0,0,1,7,0,0,136,41,6,0,0,0,0,0,254,0,2,0,232,75,4,0,11,0,0,0,1,8,8,0,96,135,7,0,11,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,2,0,40,111,8,0,11,0,0,0,1,16,16,0,96,135,7,0,11,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,2,0,216,107,5,0,11,0,0,0,1,32,32,0,96,135,7,0,11,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,5,0,11,0,0,0,1,64,64,0,96,135,7,0,11,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,72,44,5,0,11,0,0,0,1,128,128,0,96,135,7,0,11,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,96,46,8,0,12,0,0,0,1,1,1,0,208,233,4,0,12,0,0,0,1,1,0,0,72,197,4,0,0,0,0,0,254,0,16,0,152,167,4,0,12,0,0,0,1,30,20,0,176,73,5,0,12,0,0,0,1,30,22,0,104,54,4,0,12,0,0,0,1,30,20,0,80,252,6,0,12,0,0,0,1,30,24,0,16,242,7,0,12,0,0,0,1,30,26,0,40,28,4,0,12,0,0,0,1,30,2,0,104,236,7,0,12,0,0,0,1,30,4,0,96,135,3,0,12,0,0,0,1,30,6,0,120,113,6,0,12,0,0,0,1,30,30,0,128,230,7,0,12,0,0,0,1,30,8,0,120,211,6,0,12,0,0,0,1,30,18,0,184,164,6,0,12,0,0,0,1,30,16,0,80,74,6,0,12,0,0,0,1,30,14,0,192,32,6,0,12,0,0,0,1,30,12,0,192,234,2,0,12,0,0,0,1,30,10,0,32,242,5,0,12,0,0,0,1,30,0,0,16,227,4,0,45,0,0,0,255,255,96,0,0,0,0,0,0,0,0,0,254,0,2,0,232,75,4,0,45,0,0,0,1,32,32,0,96,135,7,0,45,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,192,3,0,45,0,0,0,1,64,64,0,96,135,7,0,45,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,104,114,122,97,45,52,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,162,107,185,152,0,0,16,1,104,114,122,97,45,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,199,106,176,6,0,0,16,1,104,114,122,97,45,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,2,189,192,57,0,0,16,1,104,114,122,97,45,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,159,201,18,116,0,0,16,1,104,114,122,100,45,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,129,213,62,185,0,0,32,0,104,114,122,100,45,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,83,59,247,28,0,0,32,0,104,114,122,100,45,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,83,141,206,234,0,0,32,0,104,114,122,98,45,52,107,46,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,161,243,210,17,0,0,32,0,104,114,122,98,45,52,102,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,234,2,105,53,0,0,32,0,104,114,122,98,45,51,110,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,2,138,7,135,0,0,32,0,104,114,122,98,45,52,110,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,31,203,25,80,0,0,32,0,104,114,122,98,45,52,99,46,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,231,133,179,144,0,0,32,0,104,114,122,98,45,52,101,46,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,162,119,93,208,0,0,32,0,104,114,122,100,45,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,249,8,59,179,0,0,32,0,104,114,122,98,45,49,109,46,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,10,105,113,8,0,0,32,0,104,114,122,100,45,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,58,111,105,110,0,0,32,0,104,114,122,98,45,49,110,46,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,169,208,71,242,0,0,32,0,104,114,122,100,45,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,121,3,166,31,0,0,32,0,104,114,122,98,45,49,108,46,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,200,160,208,154,0,0,32,0,104,114,122,98,45,53,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,233,73,139,32,0,0,32,0,104,114,122,98,45,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,18,13,194,130,0,0,32,0,18,0,0,0,255,255,255,0,0,0,0,0,19,0,0,0,255,255,253,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,18,0,0,0,1,3,0,0,208,75,4,0,18,0,0,0,1,3,3,0,8,49,4,0,18,0,0,0,1,3,1,0,152,21,4,0,18,0,0,0,1,3,2,0,72,246,3,0,0,0,0,0,254,0,4,0,64,37,5,0,18,0,0,0,1,12,0,0,24,93,2,0,18,0,0,0,1,12,12,0,88,12,1,0,18,0,0,0,1,12,8,0,152,100,5,0,18,0,0,0,1,12,4,0,0,48,2,0,0,0,0,0,254,0,16,0,32,4,2,0,18,0,0,0,2,240,0,0,88,27,2,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,160,0,8,32,4,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,176,0,96,164,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,192,0,144,102,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,208,0,176,45,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,224,0,224,127,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,16,0,192,119,3,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,32,0,120,205,1,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,48,0,136,252,1,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,240,0,32,123,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,64,0,248,116,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,144,0,192,110,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,128,0,96,102,7,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,112,0,184,105,6,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,96,0,152,96,3,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,80,0,192,100,6,0,19,0,0,0,0,4,4,0,0,0,0,0,0,0,0,0,254,0,4,0,200,87,7,0,18,0,0,0,130,48,0,0,96,164,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,130,48,16,0,176,45,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,130,48,32,0,224,127,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,130,48,48,0,32,123,8,0,19,0,0,0,0,4,4,0,0,0,0,0,0,0,0,0,254,0,4,0,160,123,6,0,18,0,0,0,130,192,192,0,192,110,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,130,192,128,0,96,102,7,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,130,192,64,0,152,96,3,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,130,192,0,0,192,100,6,0,19,0,0,0,0,4,4,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,1,1,0,96,135,7,0,19,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,200,30,2,0,19,0,0,0,1,2,0,0,120,97,1,0,19,0,0,0,1,2,2,0,96,19,1,0,0,0,0,0,254,0,2,0,96,46,8,0,19,0,0,0,1,4,4,0,208,233,4,0,19,0,0,0,1,4,0,0,72,197,4,0,0,0,0,0,254,0,2,0,72,4,1,0,19,0,0,0,1,8,8,0,96,135,7,0,19,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,2,0,136,18,1,0,19,0,0,0,1,16,16,0,96,135,7,0,19,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,246,3,0,19,0,0,0,1,64,64,0,96,135,7,0,19,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,128,128,0,96,135,7,0,19,0,0,0,1,128,0,0,152,182,7,0,104,111,114,101,107,105,100,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,15,132,236,144,0,0,16,1,104,111,114,101,107,105,100,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,248,250,130,162,0,0,16,1,104,111,114,101,107,105,100,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,80,12,92,55,0,0,16,1,104,111,114,101,107,105,100,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,187,82,125,238,0,0,16,1,104,111,114,101,107,105,100,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,129,59,205,73,0,0,16,1,104,111,114,101,107,105,100,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,56,169,234,193,0,0,16,1,104,111,114,101,107,105,100,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,2,199,43,10,0,0,16,1,104,111,114,101,107,105,100,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,204,119,75,16,0,0,32,0,104,111,114,101,107,105,100,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,16,174,37,218,0,0,32,0,104,111,114,101,107,105,100,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,33,67,110,97,0,0,32,0,104,111,114,101,107,105,100,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,226,43,125,140,0,0,32,0,104,111,114,101,107,105,100,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,2,107,6,160,0,0,32,0,104,111,114,101,107,105,100,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,122,160,202,163,0,0,32,0,104,111,114,101,107,105,100,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,142,255,72,14,0,0,32,0,104,111,114,101,107,105,100,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,122,116,0,227,0,0,32,0,104,111,114,101,107,105,100,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,65,87,16,81,0,0,32,0,107,105,100,95,112,114,111,109,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,35,206,19,202,0,0,32,0,107,105,100,95,112,114,111,109,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,90,40,68,251,0,0,32,0,107,105,100,95,112,114,111,109,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,55,18,212,64,0,0,32,0,107,105,100,95,112,114,111,109,46,50,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,237,224,155,75,0,0,32,0,107,105,100,95,112,114,111,109,46,52,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,238,84,251,228,0,0,32,0,104,111,114,101,107,105,100,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,43,89,141,29,0,0,0,8,18,0,0,0,255,255,32,0,0,0,0,0,19,0,0,0,255,255,239,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,232,75,4,0,18,0,0,0,1,32,32,0,96,135,7,0,18,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,19,0,0,0,1,3,3,0,8,49,4,0,19,0,0,0,1,3,2,0,152,21,4,0,19,0,0,0,1,3,1,0,72,246,3,0,19,0,0,0,1,3,0,0,72,0,3,0,0,0,0,0,254,0,4,0,64,37,5,0,19,0,0,0,1,12,12,0,16,223,3,0,19,0,0,0,1,12,8,0,80,167,3,0,19,0,0,0,1,12,4,0,192,192,3,0,19,0,0,0,1,12,0,0,128,141,3,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,16,16,0,96,135,7,0,19,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,2,0,200,30,2,0,19,0,0,0,1,32,0,0,120,97,1,0,19,0,0,0,1,32,32,0,96,19,1,0,0,0,0,0,254,0,4,0,72,202,5,0,19,0,0,0,1,192,192,0,80,246,3,0,19,0,0,0,1,192,128,0,248,38,7,0,19,0,0,0,1,192,64,0,112,212,3,0,19,0,0,0,1,192,0,0,248,160,5,0,0,0,0,0,254,0,4,0,200,87,7,0,20,0,0,0,1,3,1,0,104,236,7,0,20,0,0,0,1,3,3,0,128,230,7,0,20,0,0,0,1,3,2,0,184,164,6,0,20,0,0,0,1,3,0,0,16,227,4,0,0,0,0,0,254,0,4,0,160,123,6,0,20,0,0,0,1,12,4,0,104,236,7,0,20,0,0,0,1,12,12,0,128,230,7,0,20,0,0,0,1,12,0,0,120,211,6,0,20,0,0,0,1,12,8,0,184,164,6,0,0,0,0,0,254,0,2,0,144,212,8,0,20,0,0,0,1,32,32,0,96,135,7,0,20,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,160,165,8,0,20,0,0,0,1,192,192,0,96,135,7,0,20,0,0,0,1,192,128,0,152,182,7,0,0,0,0,0,118,101,114,116,95,103,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,128,126,37,126,4,0,32,0,118,101,114,116,95,114,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,30,133,240,197,4,0,32,0,56,50,115,49,50,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,191,2,120,115,7,0,32,0,118,101,114,116,95,112,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,252,120,176,189,8,0,16,1,56,50,115,49,52,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,165,127,206,170,0,0,0,8,17,0,0,0,255,255,254,0,0,0,0,0,18,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,32,4,2,0,17,0,0,0,1,3,0,0,16,242,7,0,17,0,0,0,1,3,1,0,104,236,7,0,17,0,0,0,1,3,2,0,80,245,6,0,17,0,0,0,1,3,3,0,8,201,6,0,0,0,0,0,254,0,2,0,232,75,4,0,17,0,0,0,1,128,128,0,96,135,7,0,17,0,0,0,1,128,0,0,152,182,7,0,18,0,0,0,255,255,83,0,0,0,0,0,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,247,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,18,0,0,0,1,4,0,0,120,97,1,0,18,0,0,0,1,4,4,0,96,19,1,0,0,0,0,0,254,0,4,0,72,202,5,0,18,0,0,0,1,24,24,0,80,246,3,0,18,0,0,0,1,24,16,0,248,38,7,0,18,0,0,0,1,24,8,0,112,212,3,0,18,0,0,0,1,24,0,0,248,160,5,0,0,0,0,0,254,0,4,0,120,95,4,0,18,0,0,0,1,96,96,0,56,94,4,0,18,0,0,0,1,96,64,0,248,38,7,0,18,0,0,0,1,96,32,0,176,90,4,0,18,0,0,0,1,96,0,0,192,87,4,0,0,0,0,0,254,0,2,0,168,234,7,0,18,0,0,0,1,128,128,0,96,135,7,0,18,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,16,0,200,87,7,0,19,0,0,0,1,15,2,0,80,252,6,0,19,0,0,0,1,15,5,0,16,242,7,0,19,0,0,0,1,15,8,0,104,236,7,0,19,0,0,0,1,15,4,0,120,113,6,0,19,0,0,0,1,15,1,0,232,228,5,0,19,0,0,0,1,15,15,0,128,230,7,0,19,0,0,0,1,15,3,0,56,141,7,0,19,0,0,0,1,15,7,0,120,211,6,0,19,0,0,0,1,15,14,0,184,164,6,0,19,0,0,0,1,15,6,0,24,1,7,0,19,0,0,0,1,15,13,0,80,74,6,0,19,0,0,0,1,15,12,0,192,32,6,0,19,0,0,0,1,15,11,0,192,234,2,0,19,0,0,0,1,15,10,0,32,242,5,0,19,0,0,0,1,15,9,0,176,192,2,0,19,0,0,0,1,15,0,0,16,227,4,0,0,0,0,0,254,0,15,0,160,123,6,0,19,0,0,0,1,240,32,0,80,252,6,0,19,0,0,0,1,240,80,0,16,242,7,0,19,0,0,0,1,240,128,0,104,236,7,0,19,0,0,0,1,240,64,0,120,113,6,0,19,0,0,0,1,240,16,0,232,228,5,0,19,0,0,0,1,240,240,0,128,230,7,0,19,0,0,0,1,240,48,0,56,141,7,0,19,0,0,0,1,240,112,0,120,211,6,0,19,0,0,0,1,240,224,0,184,164,6,0,19,0,0,0,1,240,96,0,24,1,7,0,19,0,0,0,1,240,208,0,80,74,6,0,19,0,0,0,1,240,192,0,192,32,6,0,19,0,0,0,1,240,176,0,192,234,2,0,19,0,0,0,1,240,160,0,32,242,5,0,19,0,0,0,1,240,144,0,176,192,2,0,0,0,0,0,254,0,2,0,144,212,8,0,20,0,0,0,1,1,1,0,96,135,7,0,20,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,6,0,20,0,0,0,1,2,2,0,8,208,6,0,20,0,0,0,1,2,0,0,88,204,6,0,0,0,0,0,254,0,2,0,232,75,4,0,20,0,0,0,1,4,4,0,96,135,7,0,20,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,20,0,0,0,1,8,8,0,56,111,3,0,20,0,0,0,1,8,0,0,104,134,3,0,104,98,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,158,176,119,72,0,0,16,1,104,98,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,25,194,65,139,0,0,16,1,104,98,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,112,213,135,32,0,0,16,1,104,98,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,174,54,85,129,0,0,16,1,104,98,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,188,63,78,218,0,0,16,1,104,98,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,70,124,237,127,0,0,16,1,104,98,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,247,240,39,161,0,0,16,1,104,98,50,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,44,118,73,134,0,0,32,0,104,98,50,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,189,155,24,248,0,0,32,0,104,98,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,115,67,102,239,0,0,32,0,104,98,49,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,172,134,241,164,0,0,32,0,104,98,50,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,224,59,193,47,0,0,32,0,104,98,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,105,120,180,214,0,0,32,0,104,98,50,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,173,161,214,80,0,0,32,0,104,98,50,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,197,117,29,240,0,0,32,0,104,98,50,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,97,115,55,174,0,0,32,0,104,98,50,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,113,247,218,187,0,0,32,0,104,98,50,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,150,178,20,85,0,0,32,0,104,98,51,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,239,232,85,88,0,0,32,0,104,98,50,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,156,123,219,153,0,0,32,0,104,98,50,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,26,43,206,51,0,0,32,0,104,98,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,7,103,129,33,0,0,32,0,104,98,49,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,116,69,104,165,0,0,32,0,104,98,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,21,131,118,92,0,0,32,0,104,98,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,164,215,100,139,0,0,32,0,104,98,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,101,237,227,86,0,0,32,0,104,98,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,243,231,223,190,0,0,32,0,104,98,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,160,14,36,38,0,0,32,0,104,98,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,71,84,217,71,0,0,32,0,104,98,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,104,91,92,100,0,0,64,0,104,98,51,49,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,111,114,157,35,0,0,16,8,24,0,0,0,255,255,255,0,0,0,0,0,25,0,0,0,255,255,191,0,0,0,0,0,0,0,0,0,254,0,4,0,200,87,7,0,24,0,0,0,1,3,0,0,224,127,8,0,24,0,0,0,1,3,3,0,32,123,8,0,24,0,0,0,1,3,2,0,192,110,8,0,24,0,0,0,1,3,1,0,96,102,7,0,0,0,0,0,254,0,4,0,160,123,6,0,24,0,0,0,1,12,0,0,224,127,8,0,24,0,0,0,1,12,12,0,32,123,8,0,24,0,0,0,1,12,8,0,192,110,8,0,24,0,0,0,1,12,4,0,96,102,7,0,0,0,0,0,254,0,2,0,232,75,4,0,24,0,0,0,1,16,16,0,96,135,7,0,24,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,24,0,0,0,1,32,0,0,96,135,7,0,24,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,24,0,0,0,1,64,64,0,96,135,7,0,24,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,25,0,0,0,1,3,1,0,192,255,2,0,25,0,0,0,1,3,3,0,8,49,4,0,25,0,0,0,1,3,2,0,72,246,3,0,25,0,0,0,1,3,0,0,112,49,6,0,0,0,0,0,254,0,4,0,72,202,5,0,25,0,0,0,1,12,8,0,80,246,3,0,25,0,0,0,1,12,12,0,248,38,7,0,25,0,0,0,1,12,4,0,112,212,3,0,25,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,4,0,64,37,5,0,25,0,0,0,1,48,48,0,40,176,7,0,25,0,0,0,1,48,32,0,248,171,7,0,25,0,0,0,1,48,16,0,40,168,7,0,25,0,0,0,1,48,0,0,232,163,7,0,0,0,0,0,254,0,2,0,192,125,6,0,25,0,0,0,1,64,64,0,56,111,3,0,25,0,0,0,1,64,0,0,104,134,3,0,0,0,0,0,101,112,114,45,54,56,53,49,97,95,95,40,110,101,101,100,115,95,118,101,114,105,102,105,99,97,116,105,111,110,41,46,105,99,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,23,34,77,30,1,0,16,1,101,112,114,45,54,56,52,57,97,95,95,40,110,101,101,100,115,95,118,101,114,105,102,105,99,97,116,105,111,110,41,46,105,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,14,229,147,55,1,0,16,1,101,112,114,45,54,56,53,48,97,95,95,40,110,101,101,100,115,95,118,101,114,105,102,105,99,97,116,105,111,110,41,46,105,99,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,59,94,113,93,1,0,16,1,101,112,114,45,54,56,52,56,97,95,95,40,110,101,101,100,115,95,118,101,114,105,102,105,99,97,116,105,111,110,41,46,105,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,48,154,67,241,1,0,16,1,101,112,114,45,54,56,51,56,46,105,99,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,148,183,71,39,9,0,16,1,101,112,114,45,54,56,51,57,46,105,99,53,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,110,250,233,115,9,0,16,1,101,112,114,45,54,56,52,49,46,105,99,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,220,149,210,84,2,0,32,0,101,112,114,45,54,56,52,50,46,105,99,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,104,181,119,246,2,0,32,0,101,112,114,45,54,56,52,51,46,105,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,218,240,87,162,2,0,32,0,101,112,114,45,54,56,49,57,46,105,99,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,7,173,157,70,3,0,32,0,101,112,114,45,54,56,50,48,46,105,99,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,222,198,203,135,3,0,32,0,101,112,114,45,54,56,50,49,46,105,99,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,105,41,121,21,3,0,32,0,101,112,114,45,54,56,50,50,46,105,99,51,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,229,141,113,233,3,0,32,0,101,112,114,45,54,56,50,51,46,105,99,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,145,38,66,73,3,0,32,0,101,112,114,45,54,56,50,52,46,105,99,51,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,164,234,29,112,3,0,32,0,101,112,114,45,54,56,50,53,46,105,99,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,180,200,35,110,3,0,32,0,101,112,114,45,54,56,50,54,46,105,99,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,44,222,208,119,3,0,32,0,101,112,114,45,54,56,50,55,46,105,99,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,182,191,161,127,3,0,32,0,101,112,114,45,54,56,50,56,46,105,99,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,147,12,136,142,3,0,32,0,101,112,114,45,54,56,50,57,46,105,99,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,45,149,160,124,3,0,32,0,101,112,114,45,54,56,51,48,46,105,99,51,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,239,58,166,177,3,0,32,0,101,112,114,45,54,56,52,53,46,105,99,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,184,201,8,186,3,0,32,0,101,112,114,45,54,56,52,54,46,105,99,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,163,87,30,242,3,0,32,0,101,112,114,45,54,56,52,48,46,105,99,49,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,227,48,18,88,10,0,32,0,101,112,114,45,54,56,51,51,46,105,99,55,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,95,47,148,59,4,0,16,1,101,112,114,45,54,56,51,49,46,105,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,129,84,239,207,11,0,64,0,101,112,114,45,54,56,51,50,46,105,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,165,174,101,65,11,0,64,0,101,112,114,45,54,56,52,52,46,105,99,49,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,214,123,236,227,16,0,32,0,101,112,114,45,54,57,49,56,46,105,99,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,172,242,244,11,1,0,16,1,101,112,114,45,54,57,49,54,46,105,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,138,28,194,6,1,0,16,1,101,112,114,45,54,57,49,55,46,105,99,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,188,108,138,244,1,0,16,1,101,112,114,45,54,57,49,53,46,105,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,238,181,211,117,1,0,16,1,101,112,114,45,54,57,50,48,46,105,99,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,62,1,149,28,9,0,16,1,101,112,114,45,54,57,49,57,46,105,99,53,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,105,13,163,108,9,0,16,1,101,112,114,45,54,56,52,49,46,105,99,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,220,149,210,84,2,0,32,0,101,112,114,45,54,56,52,50,46,105,99,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,104,181,119,246,2,0,32,0,101,112,114,45,54,56,52,51,46,105,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,218,240,87,162,2,0,32,0,101,112,114,45,54,56,49,57,46,105,99,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,7,173,157,70,3,0,32,0,101,112,114,45,54,56,50,48,46,105,99,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,222,198,203,135,3,0,32,0,101,112,114,45,54,56,50,49,46,105,99,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,105,41,121,21,3,0,32,0,101,112,114,45,54,56,50,50,46,105,99,51,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,229,141,113,233,3,0,32,0,101,112,114,45,54,56,50,51,46,105,99,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,145,38,66,73,3,0,32,0,101,112,114,45,54,56,50,52,46,105,99,51,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,164,234,29,112,3,0,32,0,101,112,114,45,54,56,50,53,46,105,99,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,180,200,35,110,3,0,32,0,101,112,114,45,54,56,50,54,46,105,99,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,44,222,208,119,3,0,32,0,101,112,114,45,54,56,50,55,46,105,99,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,182,191,161,127,3,0,32,0,101,112,114,45,54,56,50,56,46,105,99,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,147,12,136,142,3,0,32,0,101,112,114,45,54,56,50,57,46,105,99,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,45,149,160,124,3,0,32,0,101,112,114,45,54,56,51,48,46,105,99,51,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,239,58,166,177,3,0,32,0,101,112,114,45,54,56,52,53,46,105,99,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,184,201,8,186,3,0,32,0,101,112,114,45,54,56,52,54,46,105,99,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,163,87,30,242,3,0,32,0,101,112,114,45,54,56,52,48,46,105,99,49,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,227,48,18,88,10,0,32,0,101,112,114,45,54,56,51,51,46,105,99,55,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,95,47,148,59,4,0,16,1,101,112,114,45,54,56,51,49,46,105,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,129,84,239,207,11,0,64,0,101,112,114,45,54,56,51,50,46,105,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,165,174,101,65,11,0,64,0,101,112,114,45,54,56,52,52,46,105,99,49,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,214,123,236,227,16,0,32,0,18,0,0,0,255,255,255,0,0,0,0,0,19,0,0,0,255,255,253,0,0,0,0,0,0,0,0,0,254,0,8,0,200,87,7,0,18,0,0,0,1,7,1,0,32,136,7,0,18,0,0,0,1,7,2,0,40,88,7,0,18,0,0,0,1,7,3,0,96,39,7,0,18,0,0,0,1,7,7,0,144,251,6,0,18,0,0,0,1,7,6,0,184,164,6,0,18,0,0,0,1,7,5,0,80,74,6,0,18,0,0,0,1,7,4,0,192,32,6,0,18,0,0,0,1,7,0,0,16,227,4,0,0,0,0,0,254,0,8,0,160,123,6,0,18,0,0,0,1,56,8,0,32,136,7,0,18,0,0,0,1,56,16,0,40,88,7,0,18,0,0,0,1,56,24,0,96,39,7,0,18,0,0,0,1,56,56,0,144,251,6,0,18,0,0,0,1,56,48,0,184,164,6,0,18,0,0,0,1,56,40,0,80,74,6,0,18,0,0,0,1,56,32,0,192,32,6,0,18,0,0,0,1,56,0,0,16,227,4,0,0,0,0,0,254,0,2,0,168,234,7,0,18,0,0,0,1,64,0,0,96,135,7,0,18,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,128,112,3,0,19,0,0,0,1,2,0,0,168,22,4,0,19,0,0,0,1,2,2,0,224,247,3,0,0,0,0,0,254,0,4,0,72,202,5,0,19,0,0,0,1,12,4,0,80,246,3,0,19,0,0,0,1,12,12,0,248,38,7,0,19,0,0,0,1,12,8,0,112,212,3,0,19,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,4,0,128,129,4,0,19,0,0,0,1,192,0,0,192,255,2,0,19,0,0,0,1,192,64,0,208,75,4,0,19,0,0,0,1,192,192,0,8,49,4,0,19,0,0,0,1,192,128,0,152,21,4,0,18,0,0,0,255,255,253,0,0,0,0,0,19,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,128,112,3,0,18,0,0,0,1,2,2,0,224,247,3,0,18,0,0,0,1,2,0,0,168,22,4,0,0,0,0,0,254,0,4,0,72,202,5,0,18,0,0,0,1,12,8,0,80,246,3,0,18,0,0,0,1,12,12,0,248,38,7,0,18,0,0,0,1,12,4,0,112,212,3,0,18,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,2,0,0,96,135,7,0,19,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,8,0,160,123,6,0,19,0,0,0,1,28,16,0,32,136,7,0,19,0,0,0,1,28,8,0,40,88,7,0,19,0,0,0,1,28,24,0,96,39,7,0,19,0,0,0,1,28,28,0,144,251,6,0,19,0,0,0,1,28,12,0,184,164,6,0,19,0,0,0,1,28,20,0,80,74,6,0,19,0,0,0,1,28,4,0,192,32,6,0,19,0,0,0,1,28,0,0,16,227,4,0,0,0,0,0,254,0,8,0,200,87,7,0,19,0,0,0,1,224,128,0,32,136,7,0,19,0,0,0,1,224,64,0,40,88,7,0,19,0,0,0,1,224,192,0,96,39,7,0,19,0,0,0,1,224,224,0,144,251,6,0,19,0,0,0,1,224,96,0,184,164,6,0,19,0,0,0,1,224,160,0,80,74,6,0,19,0,0,0,1,224,32,0,192,32,6,0,19,0,0,0,1,224,0,0,16,227,4,0,0,0,0,0,168,86,7,0,1,0,0,0,152,252,146,0,248,191,2,0,56,210,6,0,1,0,0,0,156,252,146,0,192,135,2,0,24,163,6,0,1,0,0,0,157,252,146,0,240,108,2,0,152,122,6,0,1,0,0,0,158,252,146,0,96,82,2,0,192,72,6,0,1,0,0,0,159,252,146,0,32,56,2,0,200,110,3,0,1,0,0,0,154,252,146,0,152,30,2,0,120,89,3,0,1,0,0,0,155,252,146,0,232,10,2,0,176,223,1,0,1,0,0,0,164,252,146,0,72,198,1,0,192,209,1,0,1,0,0,0,165,252,146,0,24,182,1,0,24,198,1,0,1,0,0,0,166,252,146,0,40,167,1,0,120,189,1,0,1,0,0,0,167,252,146,0,200,149,1,0,224,22,1,0,1,0,0,0,162,252,146,0,56,126,1,0,160,14,1,0,1,0,0,0,163,252,146,0,32,101,1,0,88,212,3,0,1,0,0,0,16,217,146,0,40,185,3,0,72,65,1,0,9,0,0,0,56,4,147,0,32,58,1,0,109,109,112,48,120,51,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,196,21,230,91,0,0,16,1,109,109,112,49,120,51,46,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,78,62,133,174,0,0,16,1,109,109,100,48,120,51,46,117,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,255,6,26,46,0,0,16,8,109,109,45,50,48,48,45,52,48,50,45,115,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,252,62,171,192,0,0,32,0,109,109,45,50,48,49,45,52,48,51,45,115,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,220,35,107,207,0,0,32,0,109,109,45,50,48,50,45,52,48,52,45,115,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,211,245,39,143,0,0,32,0,109,109,45,50,48,51,45,52,48,53,45,115,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,140,124,116,233,0,0,32,0,109,109,45,50,48,52,45,53,54,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,51,123,215,87,0,0,32,0,109,109,45,50,48,52,45,52,48,54,45,53,54,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,202,189,184,5,0,0,32,0,109,109,45,51,48,48,45,52,48,54,45,97,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,127,107,95,177,0,0,32,0,109,109,45,49,48,48,45,52,48,49,45,97,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,238,251,203,185,0,0,64,0,109,109,45,49,48,49,45,52,48,50,45,101,50,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,124,220,12,56,0,0,64,0,184,40,2,0,1,0,0,0,170,148,215,0,248,191,2,0,56,250,6,0,1,0,0,0,191,148,215,0,184,160,2,0,184,164,8,0,1,0,0,0,171,148,215,0,64,246,1,0,88,149,7,0,1,0,0,0,183,148,215,0,136,224,1,0,104,28,8,0,1,0,0,0,136,148,215,0,232,209,1,0,248,23,7,0,1,0,0,0,167,148,215,0,144,189,1,0,64,183,7,0,1,0,0,0,137,148,215,0,104,195,5,0,48,19,7,0,1,0,0,0,159,148,215,0,32,245,8,0,56,210,6,0,1,0,0,0,184,148,215,0,192,135,2,0,24,163,6,0,1,0,0,0,185,148,215,0,240,108,2,0,152,122,6,0,1,0,0,0,186,148,215,0,96,82,2,0,192,72,6,0,1,0,0,0,187,148,215,0,32,56,2,0,48,123,2,0,1,0,0,0,188,148,215,0,152,30,2,0,96,69,2,0,1,0,0,0,189,148,215,0,232,10,2,0,144,55,2,0,1,0,0,0,190,148,215,0,152,138,8,0,176,223,1,0,1,0,0,0,176,148,215,0,72,198,1,0,192,209,1,0,1,0,0,0,177,148,215,0,24,182,1,0,24,198,1,0,1,0,0,0,178,148,215,0,40,167,1,0,120,189,1,0,1,0,0,0,179,148,215,0,200,149,1,0,248,187,8,0,1,0,0,0,180,148,215,0,56,126,1,0,184,179,8,0,1,0,0,0,181,148,215,0,32,101,1,0,240,173,8,0,1,0,0,0,182,148,215,0,96,32,8,0,192,122,8,0,1,0,0,0,160,148,215,0,208,174,1,0,40,116,8,0,1,0,0,0,161,148,215,0,48,160,1,0,72,110,8,0,1,0,0,0,162,148,215,0,160,140,1,0,184,102,8,0,1,0,0,0,163,148,215,0,56,112,1,0,240,45,8,0,1,0,0,0,164,148,215,0,32,92,1,0,40,38,8,0,1,0,0,0,165,148,215,0,64,77,1,0,48,32,8,0,1,0,0,0,166,148,215,0,112,157,4,0,248,16,8,0,1,0,0,0,152,148,215,0,32,231,8,0,192,12,8,0,1,0,0,0,153,148,215,0,88,214,8,0,224,5,8,0,1,0,0,0,154,148,215,0,224,202,8,0,144,1,8,0,1,0,0,0,155,148,215,0,72,193,8,0,72,204,7,0,1,0,0,0,156,148,215,0,144,180,8,0,208,196,7,0,1,0,0,0,157,148,215,0,208,164,8,0,248,189,7,0,1,0,0,0,158,148,215,0,160,152,4,0,88,212,3,0,1,0,0,0,200,147,215,0,40,185,3,0,16,17,8,0,1,0,0,0,169,148,215,0,224,12,8,0,0,105,5,0,1,0,0,0,138,148,215,0,192,99,5,0,56,58,1,0,1,0,0,0,168,148,215,0,64,50,1,0,248,5,8,0,9,0,0,0,96,149,215,0,32,58,1,0,144,250,7,0,9,0,0,0,97,149,215,0,32,58,1,0,101,112,114,45,49,51,52,48,57,46,105,99,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,182,129,187,154,1,0,16,1,101,112,114,45,49,51,52,48,56,46,105,99,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,151,14,65,142,1,0,16,1,101,112,114,45,49,51,51,57,53,46,105,99,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,199,250,204,214,9,0,16,1,101,112,114,45,49,51,51,57,52,46,105,99,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,236,85,74,145,9,0,16,1,101,112,114,45,49,51,51,57,51,46,105,99,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,204,35,208,8,9,0,16,1,101,112,114,45,49,51,51,57,50,46,105,99,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,66,205,39,249,9,0,16,1,101,112,114,45,49,51,51,56,51,46,105,99,49,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,167,151,248,36,2,0,32,0,101,112,114,45,49,51,51,56,52,46,105,99,49,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,189,56,130,254,2,0,32,0,101,112,114,45,49,51,51,56,53,46,105,99,49,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,149,185,241,109,2,0,32,0,101,112,114,45,49,51,51,56,50,46,105,99,57,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,194,218,1,3,0,32,0,101,112,114,45,49,51,51,56,49,46,105,99,57,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,49,217,80,58,3,0,32,0,101,112,114,45,49,51,51,56,48,46,105,99,57,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,200,36,16,173,3,0,32,0,101,112,114,45,49,51,51,55,57,46,105,99,49,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,37,118,193,26,3,0,32,0,101,112,114,45,49,51,51,55,56,46,105,99,57,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,103,184,201,80,3,0,32,0,101,112,114,45,49,51,51,55,55,46,105,99,57,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,192,245,18,155,3,0,32,0,101,112,114,45,49,51,51,55,54,46,105,99,57,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,24,197,154,68,3,0,32,0,101,112,114,45,49,51,51,55,53,46,105,99,49,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,255,169,137,84,3,0,32,0,101,112,114,45,49,51,51,55,52,46,105,99,57,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,79,158,49,106,3,0,32,0,101,112,114,45,49,51,51,55,51,46,105,99,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,139,88,165,236,3,0,32,0,101,112,114,45,49,51,51,55,50,46,105,99,49,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,51,164,69,11,3,0,32,0,101,112,114,45,49,51,51,55,49,46,105,99,49,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,255,76,143,182,3,0,32,0,101,112,114,45,49,51,51,55,48,46,105,99,57,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,32,102,39,120,3,0,32,0,101,112,114,45,49,51,51,54,57,46,105,99,57,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,15,191,37,134,3,0,32,0,101,112,114,45,49,51,51,54,56,46,105,99,49,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,108,113,80,15,3,0,32,0,101,112,114,45,49,51,51,54,55,46,105,99,49,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,31,181,27,75,3,0,32,0,101,112,114,45,49,51,51,56,56,46,105,99,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,228,129,101,112,4,0,16,1,101,112,114,45,49,51,51,57,49,46,105,99,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,103,200,48,140,11,0,64,0,101,112,114,45,49,51,51,57,48,46,105,99,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,5,205,147,140,11,0,64,0,101,112,114,45,49,51,51,56,57,46,105,99,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,142,117,76,78,11,0,64,0,51,49,55,45,48,49,54,51,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,7,210,212,193,5,0,16,1,11,0,0,0,255,255,255,0,0,0,0,0,12,0,0,0,255,255,254,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,11,0,0,0,1,15,7,0,80,252,6,0,11,0,0,0,1,15,8,0,16,242,7,0,11,0,0,0,1,15,9,0,104,236,7,0,11,0,0,0,1,15,5,0,176,51,4,0,11,0,0,0,1,15,4,0,56,24,4,0,11,0,0,0,1,15,15,0,128,230,7,0,11,0,0,0,1,15,1,0,72,216,3,0,11,0,0,0,1,15,2,0,24,188,3,0,11,0,0,0,1,15,3,0,176,162,3,0,11,0,0,0,1,15,6,0,120,211,6,0,11,0,0,0,1,15,14,0,184,164,6,0,11,0,0,0,1,15,13,0,80,74,6,0,11,0,0,0,1,15,12,0,192,32,6,0,11,0,0,0,1,15,11,0,192,234,2,0,11,0,0,0,1,15,10,0,32,242,5,0,11,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,11,0,0,0,1,240,112,0,80,252,6,0,11,0,0,0,1,240,128,0,16,242,7,0,11,0,0,0,1,240,144,0,104,236,7,0,11,0,0,0,1,240,80,0,176,51,4,0,11,0,0,0,1,240,64,0,56,24,4,0,11,0,0,0,1,240,240,0,128,230,7,0,11,0,0,0,1,240,16,0,72,216,3,0,11,0,0,0,1,240,32,0,24,188,3,0,11,0,0,0,1,240,48,0,176,162,3,0,11,0,0,0,1,240,96,0,120,211,6,0,11,0,0,0,1,240,224,0,184,164,6,0,11,0,0,0,1,240,208,0,80,74,6,0,11,0,0,0,1,240,192,0,192,32,6,0,11,0,0,0,1,240,176,0,192,234,2,0,11,0,0,0,1,240,160,0,32,242,5,0,11,0,0,0,1,240,0,0,208,236,2,0,0,0,0,0,254,0,2,0,64,251,5,0,12,0,0,0,1,3,3,0,248,248,6,0,12,0,0,0,1,3,2,0,120,97,1,0,0,0,0,0,254,0,2,0,136,245,6,0,12,0,0,0,1,8,8,0,128,241,6,0,12,0,0,0,1,8,0,0,144,129,7,0,0,0,0,0,254,0,2,0,168,234,7,0,12,0,0,0,1,16,0,0,96,135,7,0,12,0,0,0,1,16,16,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,12,0,0,0,1,192,128,0,80,246,3,0,12,0,0,0,1,192,192,0,248,38,7,0,12,0,0,0,1,192,64,0,112,212,3,0,12,0,0,0,1,192,0,0,248,160,5,0,112,99,98,49,95,112,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,112,140,51,25,1,0,16,1,112,99,98,49,95,112,109,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,77,7,219,24,1,0,16,1,112,99,98,49,95,112,109,51])
.concat([46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,29,139,185,171,1,0,16,1,112,99,98,49,95,112,109,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,142,199,3,36,1,0,16,1,112,99,98,49,95,103,120,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,83,159,170,47,1,0,16,1,112,99,98,49,95,103,120,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,22,95,28,18,1,0,16,1,112,99,98,49,95,103,120,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,33,26,216,2,1,0,16,1,112,99,98,50,103,102,120,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,192,187,33,112,4,0,32,0,112,99,98,50,103,102,120,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,43,146,156,8,4,0,32,0,112,99,98,50,103,102,120,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,238,88,191,81,4,0,32,0,112,99,98,50,103,102,120,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,220,208,143,144,4,0,32,0,103,109,103,97,108,97,120,50,46,99,108,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,64,68,159,73,7,0,32,0,108,48,54,95,112,114,111,109,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,135,125,12,106,7,0,32,0,14,0,0,0,255,255,0,0,0,0,0,0,15,0,0,0,255,255,64,0,0,0,0,0,16,0,0,0,255,255,6,0,0,0,0,0,17,0,0,0,255,255,0,0,0,0,0,0,18,0,0,0,255,255,0,0,0,0,0,0,19,0,0,0,255,255,1,0,0,0,0,0,20,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,24,84,1,0,14,0,0,0,1,32,0,0,120,97,1,0,14,0,0,0,1,32,32,0,96,19,1,0,0,0,0,0,254,0,4,0,232,83,1,0,15,0,0,0,1,192,64,0,176,116,6,0,15,0,0,0,1,192,128,0,80,113,6,0,15,0,0,0,1,192,192,0,80,110,6,0,15,0,0,0,1,192,0,0,120,7,5,0,0,0,0,0,254,0,4,0,56,83,1,0,16,0,0,0,1,3,0,0,224,127,8,0,16,0,0,0,1,3,2,0,32,123,8,0,16,0,0,0,1,3,1,0,192,110,8,0,16,0,0,0,1,3,3,0,104,151,6,0,0,0,0,0,254,0,4,0,184,81,1,0,16,0,0,0,1,12,12,0,192,255,2,0,16,0,0,0,1,12,8,0,208,75,4,0,16,0,0,0,1,12,4,0,8,49,4,0,16,0,0,0,1,12,0,0,152,21,4,0,0,0,0,0,254,0,2,0,192,80,1,0,17,0,0,0,1,32,0,0,120,97,1,0,17,0,0,0,1,32,32,0,96,19,1,0,0,0,0,0,254,0,2,0,176,79,1,0,17,0,0,0,1,64,0,0,96,135,7,0,17,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,4,0,216,78,1,0,18,0,0,0,1,192,64,0,224,127,8,0,18,0,0,0,1,192,0,0,32,123,8,0,18,0,0,0,1,192,128,0,192,110,8,0,18,0,0,0,1,192,192,0,104,151,6,0,0,0,0,0,254,0,4,0,16,77,1,0,19,0,0,0,1,3,1,0,152,120,3,0,19,0,0,0,1,3,2,0,136,120,6,0,19,0,0,0,1,3,3,0,176,114,3,0,19,0,0,0,1,3,0,0,120,7,5,0,0,0,0,0,254,0,2,0,168,76,1,0,19,0,0,0,1,4,0,0,8,49,4,0,19,0,0,0,1,4,4,0,72,246,3,0,0,0,0,0,254,0,2,0,88,178,6,0,20,0,0,0,1,1,0,0,48,76,1,0,20,0,0,0,1,1,1,0,72,81,3,0,0,0,0,0,100,109,117,95,50,57,46,49,48,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,178,133,77,51,1,0,16,1,100,109,117,95,51,48,46,49,48,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,181,206,232,206,1,0,16,1,100,109,117,95,50,55,46,57,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,64,65,82,74,1,0,16,1,100,109,117,95,50,56,46,57,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,5,226,170,148,1,0,16,1,100,109,45,49,55,46,55,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,242,176,161,62,2,0,16,1,100,109,45,48,53,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,176,192,169,11,4,0,32,0,100,109,45,48,55,46,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,185,10,118,93,4,0,32,0,100,109,45,48,54,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,89,11,169,75,4,0,32,0,100,109,45,48,56,46,51,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,222,233,222,75,4,0,32,0,48,57,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,25,187,36,174,4,0,32,0,49,56,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,26,39,78,211,4,0,32,0,49,51,46,52,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,55,221,112,63,4,0,32,0,50,50,46,55,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,230,226,105,126,4,0,32,0,49,49,46,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,198,182,201,55,4,0,32,0,50,48,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,180,69,19,47,4,0,32,0,49,53,46,52,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,42,33,42,60,4,0,32,0,50,52,46,55,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,5,172,154,136,4,0,32,0,49,48,46,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,140,242,192,188,4,0,32,0,49,57,46,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,106,22,64,42,4,0,32,0,49,52,46,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,3,92,248,32,4,0,32,0,50,51,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,75,20,38,132,4,0,32,0,49,50,46,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,97,141,8,218,4,0,32,0,50,49,46,55,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,240,29,225,23,4,0,32,0,49,54,46,52,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,28,186,135,241,4,0,32,0,50,53,46,55,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,120,156,247,41,4,0,32,0,50,54,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,229,246,146,54,3,0,16,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,100,109,54,50,48,46,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,39,247,229,246,0,0,0,8,108,119,105,111,46,56,105,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,12,185,82,173,0,0,0,8,18,0,0,0,255,255,0,0,0,0,0,0,19,0,0,0,255,255,0,0,0,0,0,0,20,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,8,0,200,87,7,0,18,0,0,0,1,7,7,0,80,252,6,0,18,0,0,0,1,7,6,0,16,242,7,0,18,0,0,0,1,7,5,0,104,236,7,0,18,0,0,0,1,7,0,0,128,230,7,0,18,0,0,0,1,7,1,0,184,164,6,0,18,0,0,0,1,7,2,0,80,74,6,0,18,0,0,0,1,7,3,0,192,32,6,0,18,0,0,0,1,7,4,0,32,242,5,0,0,0,0,0,254,0,8,0,160,123,6,0,18,0,0,0,1,56,56,0,80,252,6,0,18,0,0,0,1,56,48,0,16,242,7,0,18,0,0,0,1,56,40,0,104,236,7,0,18,0,0,0,1,56,0,0,128,230,7,0,18,0,0,0,1,56,8,0,184,164,6,0,18,0,0,0,1,56,16,0,80,74,6,0,18,0,0,0,1,56,24,0,192,32,6,0,18,0,0,0,1,56,32,0,32,242,5,0,0,0,0,0,254,0,3,0,200,30,2,0,18,0,0,0,1,192,0,0,72,60,1,0,18,0,0,0,1,192,64,0,88,51,1,0,18,0,0,0,1,192,192,0,96,19,1,0,0,0,0,0,254,0,8,0,72,202,5,0,19,0,0,0,1,7,3,0,72,198,6,0,19,0,0,0,1,7,2,0,208,75,4,0,19,0,0,0,1,7,1,0,8,49,4,0,19,0,0,0,1,7,0,0,72,195,6,0,19,0,0,0,1,7,4,0,72,246,3,0,19,0,0,0,1,7,5,0,72,0,3,0,19,0,0,0,1,7,6,0,64,47,7,0,19,0,0,0,1,7,7,0,48,173,6,0,0,0,0,0,254,0,4,0,64,37,5,0,19,0,0,0,1,48,16,0,200,75,1,0,19,0,0,0,1,48,32,0,48,75,1,0,19,0,0,0,1,48,0,0,144,74,1,0,19,0,0,0,1,48,48,0,32,73,1,0,0,0,0,0,254,0,2,0,72,4,1,0,19,0,0,0,1,128,0,0,96,135,7,0,19,0,0,0,1,128,128,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,3,3,0,208,75,4,0,20,0,0,0,1,3,0,0,8,49,4,0,20,0,0,0,1,3,1,0,152,21,4,0,20,0,0,0,1,3,2,0,72,246,3,0,0,0,0,0,254,0,2,0,120,207,1,0,20,0,0,0,1,16,0,0,96,135,7,0,20,0,0,0,1,16,16,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,20,0,0,0,1,64,64,0,96,135,7,0,20,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,79,2,0,20,0,0,0,1,128,0,0,32,182,8,0,20,0,0,0,1,128,128,0,80,251,6,0,25,0,0,0,255,255,240,0,0,0,0,0,26,0,0,0,255,255,191,0,0,0,0,0,0,0,0,0,254,0,2,0,168,234,7,0,25,0,0,0,1,32,0,0,96,135,7,0,25,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,25,0,0,0,1,64,64,0,96,135,7,0,25,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,26,0,0,0,1,3,1,0,192,255,2,0,26,0,0,0,1,3,3,0,8,49,4,0,26,0,0,0,1,3,2,0,72,246,3,0,26,0,0,0,1,3,0,0,48,176,2,0,0,0,0,0,254,0,4,0,72,202,5,0,26,0,0,0,1,12,4,0,80,246,3,0,26,0,0,0,1,12,12,0,248,38,7,0,26,0,0,0,1,12,8,0,112,212,3,0,26,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,4,0,56,58,7,0,26,0,0,0,1,48,0,0,168,51,7,0,26,0,0,0,1,48,16,0,240,46,7,0,26,0,0,0,1,48,48,0,112,40,7,0,26,0,0,0,1,48,32,0,240,35,7,0,0,0,0,0,254,0,2,0,104,159,3,0,26,0,0,0,1,64,64,0,56,111,3,0,26,0,0,0,1,64,0,0,104,134,3,0,0,0,0,0,254,0,2,0,128,33,7,0,26,0,0,0,1,128,0,0,72,29,7,0,26,0,0,0,1,128,128,0,248,38,7,0,0,0,0,0,101,112,114,45,49,49,54,56,56,46,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,223,242,69,200,1,0,16,1,101,112,114,45,49,49,54,56,55,46,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,191,251,190,28,1,0,16,1,101,112,114,45,49,49,56,55,53,46,56,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,198,1,23,200,9,0,16,1,101,112,114,45,49,49,56,55,52,46,56,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,121,253,1,83,9,0,16,1,101,112,114,45,49,49,56,49,54,98,46,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,194,208,125,49,17,0,16,1,101,112,114,45,49,49,56,49,53,98,46,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,241,34,251,241,17,0,16,1,109,112,114,45,49,49,52,54,56,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,165,156,202,116,3,0,32,0,109,112,114,45,49,49,52,54,55,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,54,231,96,110,3,0,32,0,101,112,114,45,49,49,54,57,53,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,190,100,168,56,3,0,32,0,101,112,114,45,49,49,54,57,52,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,132,123,41,126,3,0,32,0,109,112,114,45,49,49,52,54,57,46,54,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,153,34,122,237,18,0,32,0,109,112,114,45,49,49,52,55,48,46,55,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,80,165,222,52,18,0,32,0,109,112,114,45,49,49,52,55,55,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,83,70,120,162,18,0,32,0,109,112,114,45,49,49,52,55,56,46,55,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,147,137,119,139,18,0,32,0,109,112,114,45,49,49,52,55,49,46,56,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,105,64,151,241,18,0,32,0,109,112,114,45,49,49,52,55,50,46,49,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,154,64,36,13,18,0,32,0,109,112,114,45,49,49,52,55,57,46,56,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,138,19,214,236,18,0,32,0,109,112,114,45,49,49,52,56,48,46,49,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,197,102,173,100,18,0,32,0,109,112,114,45,49,49,52,55,51,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,236,198,56,5,18,0,32,0,109,112,114,45,49,49,52,55,52,46,55,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,80,60,146,235,18,0,32,0,109,112,114,45,49,49,52,56,49,46,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,182,82,230,120,18,0,32,0,109,112,114,45,49,49,52,56,50,46,55,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,102,151,135,47,18,0,32,0,109,112,114,45,49,49,52,55,53,46,56,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,137,236,207,105,18,0,32,0,109,112,114,45,49,49,52,55,54,46,49,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,121,155,11,166,18,0,32,0,109,112,114,45,49,49,52,56,51,46,56,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,5,165,211,213,18,0,32,0,109,112,114,45,49,49,52,56,52,46,49,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,80,106,165,184,18,0,32,0,101,112,114,45,49,49,54,57,54,46,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,158,228,232,153,18,0,32,0,101,112,114,45,49,49,54,57,55,46,55,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,46,197,69,117,18,0,32,0,101,112,114,45,49,49,55,48,48,46,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,193,57,56,225,18,0,32,0,101,112,114,45,49,49,55,48,49,46,54,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,101,211,179,159,18,0,32,0,101,112,114,45,49,49,54,57,56,46,56,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,226,163,235,207,18,0,32,0,101,112,114,45,49,49,54,57,57,46,49,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,74,83,0,74,18,0,32,0,101,112,114,45,49,49,55,48,50,46,56,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,39,198,9,42,18,0,32,0,101,112,114,45,49,49,55,48,51,46,49,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,159,125,187,67,18,0,32,0,101,112,114,45,49,49,53,50,52,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,159,132,53,93,18,0,32,0,101,112,114,45,49,49,53,50,53,46,55,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,82,117,228,154,18,0,32,0,101,112,114,45,49,49,53,51,50,46,54,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,219,93,86,179,18,0,32,0,101,112,114,45,49,49,53,51,51,46,54,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,138,110,209,245,18,0,32,0,101,112,114,45,49,49,53,50,54,46,56,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,240,179,76,9,18,0,32,0,101,112,114,45,49,49,53,50,55,46,49,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,68,161,33,232,18,0,32,0,101,112,114,45,49,49,53,51,52,46,55,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,124,173,240,183,18,0,32,0,101,112,114,45,49,49,53,51,53,46,49,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,70,122,218,149,18,0,32,0,101,112,114,45,49,49,54,57,51,46,49,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,92,120,151,4,4,0,16,1,109,112,114,45,49,49,52,54,53,46,49,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,171,109,67,225,11,0,64,0,101,112,114,45,49,49,53,49,54,46,49,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,127,225,208,25,11,0,64,0,101,112,114,45,49,49,56,49,52,46,49,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,118,211,5,11,11,0,64,0,11,0,0,0,255,255,126,0,0,0,0,0,12,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,168,234,7,0,11,0,0,0,1,1,1,0,96,135,7,0,11,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,4,0,160,172,7,0,11,0,0,0,1,6,4,0,80,246,3,0,11,0,0,0,1,6,6,0,248,38,7,0,11,0,0,0,1,6,2,0,112,212,3,0,11,0,0,0,1,6,0,0,248,160,5,0,0,0,0,0,254,0,2,0,192,168,7,0,11,0,0,0,1,8,8,0,96,165,7,0,11,0,0,0,1,8,0,0,104,159,7,0,0,0,0,0,254,0,4,0,72,202,5,0,11,0,0,0,1,48,32,0,80,246,3,0,11,0,0,0,1,48,48,0,248,38,7,0,11,0,0,0,1,48,16,0,112,212,3,0,11,0,0,0,1,48,0,0,248,160,5,0,0,0,0,0,254,0,4,0,200,30,2,0,11,0,0,0,1,192,192,0,152,155,7,0,11,0,0,0,1,192,128,0,240,149,7,0,11,0,0,0,1,192,64,0,120,97,1,0,11,0,0,0,1,192,0,0,136,143,7,0,0,0,0,0,254,0,16,0,200,87,7,0,12,0,0,0,1,15,7,0,80,252,6,0,12,0,0,0,1,15,8,0,16,242,7,0,12,0,0,0,1,15,9,0,104,236,7,0,12,0,0,0,1,15,5,0,176,51,4,0,12,0,0,0,1,15,4,0,56,24,4,0,12,0,0,0,1,15,15,0,128,230,7,0,12,0,0,0,1,15,1,0,72,216,3,0,12,0,0,0,1,15,2,0,24,188,3,0,12,0,0,0,1,15,3,0,176,162,3,0,12,0,0,0,1,15,6,0,120,211,6,0,12,0,0,0,1,15,14,0,184,164,6,0,12,0,0,0,1,15,13,0,80,74,6,0,12,0,0,0,1,15,12,0,192,32,6,0,12,0,0,0,1,15,11,0,192,234,2,0,12,0,0,0,1,15,10,0,32,242,5,0,12,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,12,0,0,0,1,240,112,0,80,252,6,0,12,0,0,0,1,240,128,0,16,242,7,0,12,0,0,0,1,240,144,0,104,236,7,0,12,0,0,0,1,240,80,0,176,51,4,0,12,0,0,0,1,240,64,0,56,24,4,0,12,0,0,0,1,240,240,0,128,230,7,0,12,0,0,0,1,240,16,0,72,216,3,0,12,0,0,0,1,240,32,0,24,188,3,0,12,0,0,0,1,240,48,0,176,162,3,0,12,0,0,0,1,240,96,0,120,211,6,0,12,0,0,0,1,240,224,0,184,164,6,0,12,0,0,0,1,240,208,0,80,74,6,0,12,0,0,0,1,240,192,0,192,32,6,0,12,0,0,0,1,240,176,0,192,234,2,0,12,0,0,0,1,240,160,0,32,242,5,0,12,0,0,0,1,240,0,0,208,236,2,0,0,0,0,0,49,51,54,48,51,55,45,49,48,48,55,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,234,76,34,106,0,0,16,1,49,51,54,48,51,55,45,49,48,48,56,46,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,171,29,57,250,0,0,16,1,49,51,54,48,52,51,45,49,49,48,53,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,71,218,223,69,0,0,16,1,49,51,54,48,52,51,45,49,49,48,54,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,156,2,60,52,0,0,16,1,49,51,54,48,52,51,45,50,50,48,57,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,1,65,127,87,0,0,16,1,49,51,54,48,52,51,45,50,50,49,48,46,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,244,76,37,3,0,0,16,1,49,51,54,48,52,51,45,50,50,50,49,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,26,207,173,200,0,0,16,1,49,51,54,48,52,51,45,50,50,50,50,46,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,132,255,136,119,0,0,16,1,49,51,54,48,52,51,45,49,49,50,48,46,49,54,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,6,16,115,92,0,0,16,1,49,51,54,48,52,51,45,49,49,49,57,46,49,54,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,231,145,53,220,0,0,16,1,49,51,54,48,52,51,45,49,49,48,52,46,54,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,111,207,67,19,0,0,32,0,49,51,54,48,52,51,45,49,49,49,49,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,35,110,223,9,0,0,32,0,49,51,54,48,51,55,45,49,49,50,46,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,190,48,147,134,0,0,32,0,49,51,54,48,52,51,45,49,49,50,51,46,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,1,143,201,228,0,0,32,0,49,51,54,48,52,51,45,49,49,49,51,46,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,110,71,203,51,0,0,32,0,49,51,54,48,51,55,45,49,49,52,46,49,109,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,130,152,239,41,0,0,32,0,49,51,54,48,52,51,45,49,49,50,52,46,49,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,121,120,133,196,0,0,32,0,49,51,54,48,52,51,45,49,49,49,53,46,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,3,37,30,247,0,0,32,0,49,51,54,48,51,55,45,49,49,54,46,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,91,172,224,17,0,0,32,0,49,51,54,48,52,51,45,49,49,50,53,46,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,209,194,194,217,0,0,32,0,49,51,54,48,52,51,45,49,49,49,55,46,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,233,178,48,158,0,0,32,0,49,51,54,48,51,55,45,49,49,56,46,50,109,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,99,178,243,139,0,0,32,0,49,51,54,48,52,51,45,49,49,50,54,46,50,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,42,115,44,163,0,0,32,0,55,52,115,52,55,50,45,49,51,54,48,51,55,45,49,48,49,46,55,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,111,247,100,41,0,0,32,0,55,52,115,52,55,50,45,49,51,54,48,51,55,45,49,48,50,46,53,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,108,236,79,77,0,0,32,0,55,52,115,50,56,55,45,49,51,54,48,51,55,45,49,48,51,46,52,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,8,207,92,108,0,0,32,0,9,0,0,0,255,255,255,0,0,0,0,0,10,0,0,0,255,255,253,0,0,0,0,0,9,0,0,0,254,0,4,0,208,128,1,0,9,0,0,0,1,3,0,0,192,255,2,0,9,0,0,0,1,3,1,0,208,75,4,0,9,0,0,0,1,3,2,0,8,49,4,0,9,0,0,0,1,3,3,0,152,21,4,0,9,0,0,0,254,0,4,0,96,216,8,0,9,0,0,0,1,12,12,0,16,208,8,0,9,0,0,0,1,12,8,0,248,81,6,0,9,0,0,0,1,12,4,0,176,64,8,0,9,0,0,0,1,12,0,0,128,65,6,0,9,0,0,0,254,0,4,0,208,188,8,0,9,0,0,0,1,48,48,0,16,208,8,0,9,0,0,0,1,48,32,0,248,81,6,0,9,0,0,0,1,48,16,0,176,64,8,0,9,0,0,0,1,48,0,0,128,65,6,0,9,0,0,0,254,0,4,0,32,4,2,0,9,0,0,0,1,192,0,0,240,12,2,0,9,0,0,0,1,192,64,0,160,36,8,0,9,0,0,0,1,192,192,0,208,239,7,0,9,0,0,0,1,192,128,0,120,187,7,0,10,0,0,0,254,0,2,0,232,75,4,0,10,0,0,0,1,1,1,0,96,135,7,0,10,0,0,0,1,1,0,0,152,182,7,0,10,0,0,0,254,0,2,0,168,234,7,0,10,0,0,0,1,2,2,0,96,135,7,0,10,0,0,0,1,2,0,0,152,182,7,0,109,114,110,106,95,50,51,100,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,114,190,41,249,2,0,16,1,109,114,110,106,95,48,49,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,32,128,135,63,4,0,32,0,109,114,110,106,95,48,50,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,216,36,86,62,4,0,32,0,109,114,110,106,95,48,51,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,150,31,230,209,4,0,32,0,109,114,110,106,95,48,52,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,27,151,65,210,4,0,32,0,109,114,110,106,95,48,53,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,98,69,161,192,4,0,32,0,109,114,110,106,95,48,54,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,252,29,167,230,4,0,32,0,109,114,110,106,95,48,55,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,199,182,175,153,4,0,32,0,109,114,110,106,95,48,56,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,32,44,136,82,4,0,32,0,109,114,110,106,95,48,57,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,114,13,71,98,3,0,16,0,109,114,110,106,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,64,57,225,8,5,0,64,0,109,114,110,106,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,39,153,165,95,5,0,64,0,109,52,56,116,51,53,121,45,55,48,112,99,49,46,57,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,74,123,16,150,0,0,0,8,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,103,98,112,114,50,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,0,0,0,0,0,0,24,105,111,98,49,46,49,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,98,112,114,103,49,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,167,61,121,49,0,0,0,8,105,111,99,49,46,105,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,129,32,24,13,0,0,0,8,99,54,51,50,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,112,146,189,15,0,0,0,8,10,0,0,0,255,255,0,0,0,0,0,0,11,0,0,0,255,255,0,0,0,0,0,0,12,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,104,72,1,0,10,0,0,0,1,1,0,0,120,71,1,0,10,0,0,0,1,1,1,0,184,70,1,0,0,0,0,0,254,0,2,0,40,70,1,0,10,0,0,0,1,2,0,0,8,70,1,0,10,0,0,0,1,2,2,0,144,69,1,0,0,0,0,0,254,0,8,0,248,68,1,0,10,0,0,0,1,28,24,0,176,2,8,0,10,0,0,0,1,28,28,0,168,148,4,0,10,0,0,0,1,28,0,0,208,7,8,0,10,0,0,0,1,28,4,0,232,99,5,0,10,0,0,0,1,28,8,0,64,47,7,0,10,0,0,0,1,28,12,0,72,0,3,0,10,0,0,0,1,28,16,0,72,246,3,0,10,0,0,0,1,28,20,0,104,66,1,0,0,0,0,0,254,0,4,0,168,65,1,0,10,0,0,0,1,96,0,0,128,230,7,0,10,0,0,0,1,96,32,0,104,236,7,0,10,0,0,0,1,96,64,0,16,242,7,0,10,0,0,0,1,96,96,0,184,70,1,0,0,0,0,0,254,0,2,0,32,65,1,0,10,0,0,0,1,128,0,0,208,64,1,0,10,0,0,0,1,128,128,0,168,64,1,0,0,0,0,0,254,0,8,0,0,64,1,0,11,0,0,0,1,7,6,0,80,227,1,0,11,0,0,0,1,7,7,0,72,212,1,0,11,0,0,0,1,7,0,0,8,201,1,0,11,0,0,0,1,7,1,0,160,190,1,0,11,0,0,0,1,7,2,0,72,183,1,0,11,0,0,0,1,7,3,0,48,176,1,0,11,0,0,0,1,7,4,0,176,169,1,0,11,0,0,0,1,7,5,0,48,161,1,0,0,0,0,0,254,0,4,0,0,57,1,0,12,0,0,0,1,3,0,0,48,24,3,0,12,0,0,0,1,3,1,0,80,55,1,0,12,0,0,0,1,3,2,0,32,55,1,0,12,0,0,0,1,3,3,0,96,135,7,0,0,0,0,0,254,0,2,0,192,52,1,0,12,0,0,0,1,64,0,0,56,111,3,0,12,0,0,0,1,64,64,0,104,134,3,0,0,0,0,0,254,0,2,0,160,50,1,0,12,0,0,0,1,128,0,0,96,135,7,0,12,0,0,0,1,128,128,0,152,182,7,0,112,114,105,110,99,105,112,49,46,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,174,155,93,61,1,0,16,1,112,114,105,110,99,105,112,50,46,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,126,6,51,164,1,0,16,1,112,114,105,110,99,105,112,51,46,119,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,212,56,240,170,1,0,16,1,112,114,105,110,99,105,112,52,46,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,42,221,75,215,1,0,16,1,112,114,105,110,99,105,112,53,46,122,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,99,158,235,126,1,0,16,1,103,114,97,112,104,104,106,46,106,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,164,67,251,57,4,0,32,0,103,114,97,112,104,107,108,46,108,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,162,86,63,126,4,0,32,0,54,108,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,103,148,172,195,7,0,32,0,12,0,0,0,255,255,0,0,0,0,0,0,13,0,0,0,255,255,0,0,0,0,0,0,14,0,0,0,255,255,1,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,12,0,0,0,1,32,0,0,120,97,1,0,12,0,0,0,1,32,32,0,96,19,1,0,0,0,0,0,254,0,2,0,232,75,4,0,12,0,0,0,1,64,0,0,96,135,7,0,12,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,4,0,32,4,2,0,13,0,0,0,1,192,64,0,224,127,8,0,13,0,0,0,1,192,0,0,32,123,8,0,13,0,0,0,1,192,128,0,192,110,8,0,13,0,0,0,1,192,192,0,104,151,6,0,0,0,0,0,254,0,4,0,24,64,1,0,14,0,0,0,1,3,0,0,208,63,1,0,14,0,0,0,1,3,1,0,48,63,1,0,14,0,0,0,1,3,2,0,96,62,1,0,14,0,0,0,1,3,3,0,32,61,1,0,0,0,0,0,254,0,2,0,128,129,4,0,14,0,0,0,1,4,0,0,208,75,4,0,14,0,0,0,1,4,4,0,8,49,4,0,0,0,0,0,254,0,2,0,120,60,1,0,14,0,0,0,1,8,0,0,248,81,6,0,14,0,0,0,1,8,8,0,176,64,8,0,0,0,0,0,103,103,49,45,49,46,51,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,67,247,160,163,0,0,16,1,103,103,49,45,50,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,92,13,187,67,0,0,16,1,103,103,49,45,51,46,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,3,229,60,117,0,0,16,1,103,103,49,45,52,46,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,66,68,135,131,0,0,16,1,103,103,49,45,53,46,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0])
.concat([205,252,2,49,0,0,16,1,103,103,49,45,55,46,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,141,8,149,137,0,0,16,1,103,103,49,45,57,46,52,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,124,244,178,88,0,0,32,0,103,103,49,45,49,49,46,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,128,124,68,173,0,0,32,0,103,103,49,45,49,48,46,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,252,26,111,221,0,0,32,0,112,114,111,109,45,53,46,53,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,107,60,96,84,0,0,32,0,112,114,111,109,45,52,46,50,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,171,237,182,89,0,0,32,0,112,114,111,109,45,51,46,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,107,187,4,74,0,0,32,0,112,114,111,109,45,49,46,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,180,21,40,122,0,0,32,0,112,114,111,109,45,50,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,32,0,0,0,0,0,0,0,0,0,102,114,111,103,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,146,57,86,77,1,0,16,1,102,114,111,103,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,110,192,184,216,1,0,16,1,102,114,111,103,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,181,28,90,181,1,0,16,1,102,114,111,103,103,101,114,46,54,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,86,2,171,232,2,0,16,1,102,114,111,103,103,101,114,46,54,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,143,164,128,115,2,0,16,1,102,114,111,103,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,171,22,124,131,2,0,16,1,102,114,111,103,103,101,114,46,54,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,131,216,247,5,4,0,32,0,102,114,111,103,103,101,114,46,54,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,48,238,36,245,4,0,32,0,112,114,45,57,49,46,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,191,3,55,65,7,0,32,0,102,114,111,103,103,101,114,46,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,214,150,118,89,1,0,16,1,102,114,111,103,103,101,114,46,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,195,252,230,182,1,0,16,1,102,114,115,109,51,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,224,42,162,172,1,0,16,1,102,114,111,103,103,101,114,46,54,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,86,2,171,232,2,0,16,1,102,114,111,103,103,101,114,46,54,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,143,164,128,115,2,0,16,1,102,114,111,103,103,101,114,46,54,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,39,235,215,49,2,0,16,1,102,114,111,103,103,101,114,46,54,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,131,216,247,5,4,0,32,0,102,114,111,103,103,101,114,46,54,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,48,238,36,245,4,0,32,0,112,114,45,57,49,46,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,191,3,55,65,7,0,32,0,14,0,0,0,255,255,0,0,0,0,0,0,15,0,0,0,255,255,3,0,0,0,0,0,16,0,0,0,255,255,14,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,15,0,0,0,1,3,3,0,8,49,4,0,15,0,0,0,1,3,2,0,72,246,3,0,15,0,0,0,1,3,1,0,64,47,7,0,15,0,0,0,1,3,0,0,240,64,4,0,0,0,0,0,254,0,4,0,32,4,2,0,16,0,0,0,1,6,4,0,16,165,1,0,16,0,0,0,1,6,2,0,248,163,1,0,16,0,0,0,1,6,6,0,24,162,1,0,16,0,0,0,1,6,0,0,120,161,1,0,0,0,0,0,254,0,2,0,200,30,2,0,16,0,0,0,1,8,8,0,120,97,1,0,16,0,0,0,1,8,0,0,96,19,1,0,184,40,2,0,1,0,0,0,40,39,216,0,248,191,2,0,56,250,6,0,1,0,0,0,32,39,216,0,184,160,2,0,184,164,8,0,1,0,0,0,41,39,216,0,64,246,1,0,88,149,7,0,1,0,0,0,33,39,216,0,136,224,1,0,240,167,7,0,1,0,0,0,44,39,216,0,192,135,2,0,176,163,7,0,1,0,0,0,47,39,216,0,240,108,2,0,208,158,7,0,1,0,0,0,42,39,216,0,96,82,2,0,184,154,7,0,1,0,0,0,43,39,216,0,32,56,2,0,8,96,7,0,1,0,0,0,36,39,216,0,72,198,1,0,48,89,7,0,1,0,0,0,46,39,216,0,24,182,1,0,16,83,7,0,1,0,0,0,34,39,216,0,40,167,1,0,96,79,7,0,1,0,0,0,35,39,216,0,200,149,1,0,88,212,3,0,1,0,0,0,48,38,216,0,40,185,3,0,16,17,8,0,1,0,0,0,47,39,216,0,224,12,8,0,248,5,8,0,9,0,0,0,112,39,216,0,32,58,1,0,144,250,7,0,9,0,0,0,113,39,216,0,32,58,1,0,248,241,7,0,9,0,0,0,114,39,216,0,32,58,1,0,101,112,114,45,49,50,53,57,49,98,46,97,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,27,62,139,36,1,0,16,1,101,112,114,45,49,50,53,57,48,98,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,61,110,37,117,1,0,16,1,111,112,114,45,49,50,53,57,51,46,97,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,216,130,5,204,2,0,32,0,111,112,114,45,49,50,53,57,52,46,97,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,21,72,252,139,2,0,32,0,111,112,114,45,49,50,53,57,53,46,97,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,11,214,24,91,2,0,32,0,111,112,114,45,49,50,53,57,54,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,243,65,64,74,3,0,32,0,111,112,114,45,49,50,53,57,55,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,118,230,97,105,3,0,32,0,101,112,114,45,49,50,53,57,50,46,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,187,17,140,154,4,0,16,1,51,49,55,45,48,49,50,55,97,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,66,0,219,90,5,0,16,1,114,111,109,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,217,244,26,206,1,0,16,1,114,111,109,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,155,79,72,24,1,0,16,1,114,111,109,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,139,138,36,131,1,0,16,1,114,111,109,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,160,109,63,5,1,0,16,1,114,111,109,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,243,70,197,67,1,0,16,1,114,111,109,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,70,107,8,58,1,0,16,1,114,111,109,49,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,80,32,14,172,1,0,16,1,114,111,109,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,19,165,17,220,1,0,16,1,114,111,109,49,105,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,228,107,251,165,1,0,16,1,114,111,109,49,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,190,207,84,144,1,0,16,1,114,111,109,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,17,142,217,124,1,0,16,1,114,111,109,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,46,243,2,148,1,0,16,1,114,111,109,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,223,129,142,70,1,0,16,1,114,111,109,50,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,118,57,206,177,1,0,16,1,114,111,109,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,112,86,171,126,1,0,16,1,114,111,109,50,105,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,197,90,86,68,1,0,16,1,114,111,109,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,175,149,100,126,4,0,32,0,114,111,109,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,47,247,117,116,4,0,32,0,114,111,109,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,109,212,85,51,4,0,32,0,114,111,109,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,37,90,117,172,4,0,32,0,114,111,109,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,101,219,221,187,4,0,32,0,114,111,109,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,4,2,160,145,4,0,32,0,114,111,109,52,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,151,226,185,12,4,0,32,0,114,111,109,51,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,249,119,254,161,4,0,32,0,54,108,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,135,125,12,106,7,0,32,0,14,0,0,0,255,255,0,0,0,0,0,0,15,0,0,0,255,255,0,0,0,0,0,0,16,0,0,0,255,255,0,0,0,0,0,0,17,0,0,0,255,255,0,0,0,0,0,0,18,0,0,0,255,255,0,0,0,0,0,0,19,0,0,0,255,255,0,0,0,0,0,0,20,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,14,0,0,0,1,32,0,0,120,97,1,0,14,0,0,0,1,32,32,0,96,19,1,0,0,0,0,0,254,0,2,0,128,129,4,0,16,0,0,0,1,4,0,0,8,49,4,0,16,0,0,0,1,4,4,0,72,246,3,0,0,0,0,0,254,0,4,0,40,95,1,0,17,0,0,0,1,3,1,0,176,116,6,0,17,0,0,0,1,3,2,0,80,113,6,0,17,0,0,0,1,3,3,0,80,110,6,0,17,0,0,0,1,3,0,0,120,7,5,0,0,0,0,0,254,0,4,0,72,94,1,0,17,0,0,0,1,192,64,0,104,236,7,0,17,0,0,0,1,192,0,0,128,230,7,0,17,0,0,0,1,192,128,0,184,164,6,0,17,0,0,0,1,192,192,0,16,227,4,0,0,0,0,0,254,0,2,0,232,92,1,0,18,0,0,0,1,8,8,0,56,111,3,0,18,0,0,0,1,8,0,0,104,134,3,0,0,0,0,0,254,0,4,0,16,91,1,0,18,0,0,0,1,192,64,0,104,236,7,0,18,0,0,0,1,192,0,0,128,230,7,0,18,0,0,0,1,192,128,0,184,164,6,0,18,0,0,0,1,192,192,0,16,227,4,0,0,0,0,0,254,0,4,0,104,90,1,0,19,0,0,0,1,3,1,0,152,120,3,0,19,0,0,0,1,3,2,0,136,120,6,0,19,0,0,0,1,3,3,0,176,114,3,0,19,0,0,0,1,3,0,0,120,7,5,0,0,0,0,0,254,0,3,0,16,90,1,0,19,0,0,0,1,192,64,0,104,236,7,0,19,0,0,0,1,192,0,0,128,230,7,0,19,0,0,0,1,192,192,0,16,227,4,0,0,0,0,0,254,0,2,0,144,89,1,0,20,0,0,0,1,1,0,0,8,49,6,0,20,0,0,0,1,1,1,0,184,43,6,0,0,0,0,0,254,0,3,0,240,88,1,0,20,0,0,0,1,192,64,0,104,236,7,0,20,0,0,0,1,192,0,0,128,230,7,0,20,0,0,0,1,192,192,0,16,227,4,0,0,0,0,0,48,49,95,102,119,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,193,120,185,236,0,0,16,1,48,50,95,102,119,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,66,59,35,45,0,0,16,1,48,56,95,102,119,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,233,13,160,164,0,0,32,0,48,55,95,102,119,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,212,209,140,180,0,0,32,0,49,48,95,102,119,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,72,171,27,242,0,0,32,0,48,57,95,102,119,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,15,142,234,106,0,0,32,0,48,53,95,102,119,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,220,236,65,225,0,0,32,0,48,54,95,102,119,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,18,168,88,0,0,0,32,0,48,51,95,102,119,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,20,140,211,106,0,0,32,0,48,52,95,102,119,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,166,121,208,184,0,0,32,0,48,48,95,102,119,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,1,254,149,179,0,0,64,0,20,0,0,0,255,255,247,0,0,0,0,0,21,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,8,0,32,4,2,0,20,0,0,0,1,224,32,0,80,252,6,0,20,0,0,0,1,224,64,0,16,242,7,0,20,0,0,0,1,224,96,0,104,236,7,0,20,0,0,0,1,224,0,0,104,236,7,0,20,0,0,0,1,224,224,0,128,230,7,0,20,0,0,0,1,224,192,0,184,164,6,0,20,0,0,0,1,224,160,0,80,74,6,0,20,0,0,0,1,224,128,0,192,32,6,0,0,0,0,0,254,0,2,0,104,159,3,0,20,0,0,0,1,16,0,0,96,135,7,0,20,0,0,0,1,16,16,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,20,0,0,0,1,8,8,0,96,135,7,0,20,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,2,0,128,112,3,0,20,0,0,0,1,4,4,0,168,22,4,0,20,0,0,0,1,4,0,0,72,93,8,0,0,0,0,0,254,0,2,0,144,212,8,0,20,0,0,0,1,2,2,0,96,135,7,0,20,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,24,172,6,0,20,0,0,0,1,1,1,0,96,135,7,0,20,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,21,0,0,0,1,192,128,0,192,255,2,0,21,0,0,0,1,192,0,0,208,75,4,0,21,0,0,0,1,192,192,0,8,49,4,0,21,0,0,0,1,192,64,0,152,21,4,0,0,0,0,0,254,0,4,0,72,202,5,0,21,0,0,0,1,48,48,0,80,246,3,0,21,0,0,0,1,48,32,0,248,38,7,0,21,0,0,0,1,48,16,0,112,212,3,0,21,0,0,0,1,48,0,0,248,160,5,0,0,0,0,0,254,0,2,0,72,4,1,0,21,0,0,0,1,1,1,0,96,135,7,0,21,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,15,0,0,0,255,255,236,0,0,0,0,0,16,0,0,0,255,255,0,0,0,0,0,0,17,0,0,0,255,255,248,0,0,0,0,0,0,0,0,0,254,0,4,0,64,37,5,0,15,0,0,0,1,3,0,0,40,136,2,0,15,0,0,0,1,3,1,0,184,103,8,0,15,0,0,0,1,3,2,0,168,94,8,0,15,0,0,0,1,3,3,0,104,87,8,0,0,0,0,0,254,0,2,0,16,227,4,0,15,0,0,0,1,4,4,0,96,135,7,0,15,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,15,0,0,0,1,24,8,0,8,49,4,0,15,0,0,0,1,24,16,0,152,21,4,0,15,0,0,0,1,24,24,0,72,246,3,0,15,0,0,0,1,24,0,0,48,176,2,0,0,0,0,0,254,0,2,0,160,165,8,0,15,0,0,0,1,32,32,0,96,135,7,0,15,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,15,0,0,0,1,64,64,0,96,135,7,0,15,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,200,30,2,0,15,0,0,0,1,128,128,0,120,97,1,0,15,0,0,0,1,128,0,0,96,19,1,0,0,0,0,0,254,0,16,0,200,87,7,0,16,0,0,0,1,15,15,0,120,247,3,0,16,0,0,0,1,15,14,0,104,213,3,0,16,0,0,0,1,15,13,0,224,185,3,0,16,0,0,0,1,15,12,0,144,160,3,0,16,0,0,0,1,15,11,0,96,135,3,0,16,0,0,0,1,15,10,0,32,136,7,0,16,0,0,0,1,15,9,0,40,88,7,0,16,0,0,0,1,15,8,0,96,39,7,0,16,0,0,0,1,15,0,0,144,251,6,0,16,0,0,0,1,15,1,0,184,164,6,0,16,0,0,0,1,15,2,0,80,74,6,0,16,0,0,0,1,15,3,0,192,32,6,0,16,0,0,0,1,15,4,0,192,234,2,0,16,0,0,0,1,15,5,0,32,242,5,0,16,0,0,0,1,15,6,0,176,192,2,0,16,0,0,0,1,15,7,0,248,175,2,0,0,0,0,0,254,0,16,0,160,123,6,0,16,0,0,0,1,240,240,0,120,247,3,0,16,0,0,0,1,240,224,0,104,213,3,0,16,0,0,0,1,240,208,0,224,185,3,0,16,0,0,0,1,240,192,0,144,160,3,0,16,0,0,0,1,240,176,0,96,135,3,0,16,0,0,0,1,240,160,0,32,136,7,0,16,0,0,0,1,240,144,0,40,88,7,0,16,0,0,0,1,240,128,0,96,39,7,0,16,0,0,0,1,240,0,0,144,251,6,0,16,0,0,0,1,240,16,0,184,164,6,0,16,0,0,0,1,240,32,0,80,74,6,0,16,0,0,0,1,240,48,0])
.concat([192,32,6,0,16,0,0,0,1,240,64,0,192,234,2,0,16,0,0,0,1,240,80,0,32,242,5,0,16,0,0,0,1,240,96,0,176,192,2,0,16,0,0,0,1,240,112,0,248,175,2,0,0,0,0,0,254,0,2,0,104,159,3,0,17,0,0,0,1,8,0,0,56,111,3,0,17,0,0,0,1,8,8,0,104,134,3,0,0,0,0,0,254,0,2,0,8,47,8,0,17,0,0,0,1,16,0,0,96,135,7,0,17,0,0,0,1,16,16,0,152,182,7,0,0,0,0,0,254,0,2,0,120,39,8,0,17,0,0,0,1,32,32,0,96,135,7,0,17,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,112,109,2,0,17,0,0,0,1,64,64,0,96,135,7,0,17,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,88,160,1,0,17,0,0,0,1,128,0,0,192,255,2,0,17,0,0,0,1,128,128,0,208,75,4,0,101,112,114,45,53,56,53,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,142,200,90,166,0,0,16,1,101,112,114,53,56,53,56,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,244,18,180,24,0,0,16,1,101,112,114,45,53,56,53,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,126,141,85,165,0,0,16,1,101,112,114,45,53,56,54,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,241,254,53,27,0,0,16,1,101,112,114,45,53,56,54,57,46,49,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,78,13,34,109,0,0,16,1,101,112,114,45,53,56,54,56,46,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,107,37,2,116,0,0,32,0,101,112,114,45,53,56,54,55,46,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,48,233,92,47,0,0,32,0,101,112,114,45,53,56,54,54,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,154,29,127,150,0,0,32,0,101,112,114,45,53,56,54,53,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,76,163,217,3,0,0,32,0,101,112,114,45,53,56,54,52,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,88,243,89,230,0,0,32,0,101,112,114,45,53,56,54,51,46,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,21,202,150,164,0,0,32,0,101,112,114,45,53,56,53,53,46,49,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,161,148,248,181,0,0,32,0,101,112,114,45,53,56,53,54,46,49,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,143,247,106,38,0,0,32,0,112,114,45,53,51,49,55,46,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,184,80,131,100,0,0,0,8,101,112,114,53,57,55,56,97,46,49,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,146,20,111,41,0,0,16,1,101,112,114,53,57,55,57,97,46,49,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,249,62,176,100,0,0,16,1,101,112,114,45,53,56,54,57,46,49,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,78,13,34,109,0,0,16,1,54,54,120,120,46,105,99,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,82,167,241,0,0,32,0,54,54,120,48,46,105,99,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,183,239,154,41,0,0,32,0,53,57,57,57,46,105,99,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,87,49,165,28,0,0,32,0,101,112,114,45,53,56,53,53,46,49,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,161,148,248,181,0,0,32,0,101,112,114,45,53,56,53,54,46,49,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,143,247,106,38,0,0,32,0,112,114,45,53,51,49,55,46,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,184,80,131,100,0,0,0,8,98,56,50,45,48,57,45,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,185,156,114,102,2,0,16,1,98,56,50,45,54,45,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,250,135,147,135,2,0,16,1,98,56,50,95,49,48,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,237,170,138,163,9,0,16,1,98,56,50,45,48,54,46,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,37,10,69,252,12,0,32,0,98,56,50,45,48,55,46,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,119,245,61,236,12,0,32,0,98,56,50,45,48,52,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,142,249,70,99,16,0,32,0,98,56,50,45,48,51,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,21,161,218,16,0,32,0,98,56,50,45,48,53,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,58,185,144,170,15,0,32,0,98,56,50,45,48,50,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,221,107,208,93,24,0,64,0,98,56,50,45,48,49,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,70,104,235,240,25,0,64,0,116,105,98,112,97,108,49,54,108,56,46,105,99,52,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,154,161,160,17,0,0,0,8,116,105,98,112,97,108,49,54,108,56,46,105,99,52,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,184,222,83,204,0,0,0,8,116,105,98,112,97,108,49,54,108,56,46,105,99,53,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,55,133,135,242,0,0,0,8,103,97,108,49,54,118,56,46,105,99,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,208,95,247,164,0,0,0,8,103,97,108,49,54,118,56,46,105,99,51,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,225,179,78,202,0,0,0,8,98,56,50,45,48,57,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,205,30,47,99,2,0,16,1,98,56,50,45,48,56,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,229,79,21,7,2,0,16,1,98,56,50,95,49,48,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,237,170,138,163,9,0,16,1,98,56,50,45,48,54,46,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,37,10,69,252,12,0,32,0,98,56,50,45,48,55,46,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,119,245,61,236,12,0,32,0,98,56,50,45,48,52,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,142,249,70,99,16,0,32,0,98,56,50,45,48,51,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,21,161,218,16,0,32,0,98,56,50,45,48,53,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,58,185,144,170,15,0,32,0,98,56,50,45,48,50,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,221,107,208,93,24,0,64,0,98,56,50,45,48,49,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,70,104,235,240,25,0,64,0,116,105,98,112,97,108,49,54,108,56,46,105,99,52,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,154,161,160,17,0,0,0,8,116,105,98,112,97,108,49,54,108,56,46,105,99,52,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,184,222,83,204,0,0,0,8,116,105,98,112,97,108,49,54,108,56,46,105,99,53,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,55,133,135,242,0,0,0,8,103,97,108,49,54,118,56,46,105,99,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,208,95,247,164,0,0,0,8,103,97,108,49,54,118,56,46,105,99,51,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,225,179,78,202,0,0,0,8,25,0,0,0,255,255,255,0,0,0,0,0,26,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,40,115,4,0,25,0,0,0,1,1,1,0,96,135,7,0,25,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,25,0,0,0,1,2,2,0,96,135,7,0,25,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,25,0,0,0,1,4,4,0,96,135,7,0,25,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,25,0,0,0,1,8,0,0,96,135,7,0,25,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,25,0,0,0,1,48,0,0,104,236,7,0,25,0,0,0,1,48,48,0,128,230,7,0,25,0,0,0,1,48,0,0,120,211,6,0,25,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,25,0,0,0,1,192,64,0,104,236,7,0,25,0,0,0,1,192,192,0,128,230,7,0,25,0,0,0,1,192,0,0,120,211,6,0,25,0,0,0,1,192,128,0,184,164,6,0,0,0,0,0,254,0,4,0,72,202,5,0,26,0,0,0,1,3,2,0,80,246,3,0,26,0,0,0,1,3,3,0,80,124,6,0,26,0,0,0,1,3,1,0,112,212,3,0,26,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,102,102,95,51,54,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,131,206,165,249,1,0,16,1,102,102,95,52,50,46,49,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,21,18,241,101,1,0,16,1,102,102,95,51,55,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,132,55,3,225,1,0,16,1,102,102,117,95,52,51,46,49,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,71,89,166,76,1,0,16,1,102,102,45,51,50,109,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,110,105,71,199,2,0,16,1,102,102,45,53,109,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,8,65,40,156,4,0,32,0,102,102,45,55,109,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,251,77,88,167,4,0,32,0,102,102,45,49,109,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,68,94,96,11,4,0,32,0,102,102,45,51,109,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,210,28,41,82,4,0,32,0,102,102,95,48,57,46,49,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,181,126,54,184,3,0,16,0,102,102,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,231,102,92,55,5,0,64,0,102,102,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,249,55,241,30,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,115,50,50,52,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,62,65,196,205,0,0,0,8,105,111,98,49,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,102,102,51,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,131,206,165,249,1,0,16,1,102,102,52,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,21,18,241,101,1,0,16,1,102,102,51,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,132,55,3,225,1,0,16,1,102,102,52,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,195,225,222,182,1,0,16,1,102,102,106,95,51,52,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,252,195,141,12,1,0,16,1,102,102,106,95,52,48,46,49,48,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,185,186,117,128,1,0,16,1,102,102,106,95,51,53,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,33,65,147,74,1,0,16,1,102,102,106,95,52,49,46,49,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,84,129,246,42,1,0,16,1,102,102,106,95,48,57,46,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,13,109,17,91,4,0,32,0,102,102,106,95,48,49,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,151,23,91,129,4,0,32,0,102,102,106,95,49,51,46,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,218,167,33,135,4,0,32,0,102,102,106,95,48,53,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,181,212,252,208,4,0,32,0,102,102,106,95,50,52,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,122,96,171,161,4,0,32,0,102,102,106,95,49,55,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,244,140,193,45,4,0,32,0,102,102,106,95,51,56,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,127,165,53,101,4,0,32,0,102,102,106,95,51,50,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,87,74,188,200,4,0,32,0,102,102,106,95,49,48,46,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,74,146,74,98,4,0,32,0,102,102,106,95,48,50,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,148,246,145,93,4,0,32,0,102,102,106,95,49,52,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,1,145,46,10,4,0,32,0,102,102,106,95,48,54,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,66,240,24,28,4,0,32,0,102,102,106,95,50,53,46,55,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,234,129,129,110,4,0,32,0,102,102,106,95,49,56,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,89,222,158,177,4,0,32,0,102,102,106,95,51,57,46,57,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,119,180,22,148,4,0,32,0,102,102,106,95,51,51,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,7,250,105,115,4,0,32,0,102,102,95,50,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,181,126,54,184,3,0,16,0,102,102,106,95,51,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,231,102,92,55,5,0,64,0,102,102,106,95,51,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,249,55,241,30,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,115,50,50,50,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,0,0,0,0,0,0,24,108,119,105,111,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,12,185,82,173,0,0,0,8,102,102,101,95,51,48,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,81,191,71,35,1,0,16,1,102,102,101,95,51,53,46,49,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,204,78,105,95,1,0,16,1,102,102,101,95,51,49,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,146,183,198,109,1,0,16,1,102,102,101,95,51,54,46,49,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,153,11,106,179,1,0,16,1,102,102,45,51,50,109,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,110,105,71,199,2,0,16,1,102,102,45,53,109,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,8,65,40,156,4,0,32,0,102,102,45,55,109,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,251,77,88,167,4,0,32,0,102,102,45,49,109,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,68,94,96,11,4,0,32,0,102,102,45,51,109,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,210,28,41,82,4,0,32,0,102,102,101,95,50,51,46,49,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,181,126,54,184,3,0,16,0,102,102,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,231,102,92,55,5,0,64,0,102,102,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,249,55,241,30,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,115,50,50,52,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,62,65,196,205,0,0,0,8,108,119,105,111,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,12,185,82,173,0,0,0,8,184,40,2,0,1,0,0,0,8,255,146,0,248,191,2,0,184,164,8,0,1,0,0,0,9,255,146,0,64,246,1,0,136,204,6,0,1,0,0,0,10,255,146,0,184,160,2,0,208,158,7,0,1,0,0,0,2,255,146,0,96,82,2,0,184,154,7,0,1,0,0,0,3,255,146,0,32,56,2,0,136,117,3,0,1,0,0,0,5,255,146,0,152,30,2,0,248,79,3,0,1,0,0,0,4,255,146,0,232,10,2,0,184,49,3,0,1,0,0,0,6,255,146,0,152,138,8,0,88,212,3,0,1,0,0,0,184,218,146,0,40,185,3,0,16,17,8,0,1,0,0,0,14,255,146,0,224,12,8,0,72,65,1,0,9,0,0,0,64,5,147,0,32,58,1,0,48,50,1,0,9,0,0,0,65,5,147,0,32,58,1,0,224,41,1,0,9,0,0,0,66,5,147,0,32,58,1,0,48,45,3,0,9,0,0,0,67,5,147,0,32,58,1,0,17,0,0,0,255,255,255,0,0,0,0,0,18,0,0,0,255,255,187,0,0,0,0,0,0,0,0,0,254,0,8,0,160,123,6,0,17,0,0,0,1,7,0,0,184,220,8,0,17,0,0,0,1,7,1,0,88,154,8,0,17,0,0,0,1,7,2,0,200,92,8,0,17,0,0,0,1,7,7,0,56,37,8,0,17,0,0,0,1,7,6,0,96,240,7,0,17,0,0,0,1,7,5,0,128,188,7,0,17,0,0,0,1,7,4,0,184,46,7,0,17,0,0,0,1,7,3,0,248,140,7,0,0,0,0,0,254,0,8,0,200,87,7,0,17,0,0,0,1,56,0,0,184,220,8,0,17,0,0,0,1,56,8,0,88,154,8,0,17,0,0,0,1,56,16,0,200,92,8,0,17,0,0,0,1,56,56,0,56,37,8,0,17,0,0,0,1,56,48,0,96,240,7,0,17,0,0,0,1,56,40,0,128,188,7,0,17,0,0,0,1,56,32,0,184,46,7,0,17,0,0,0,1,56,24,0,248,140,7,0,0,0,0,0,254,0,2,0,232,75,4,0,17,0,0,0,1,64,0,0,152,182,7,0,17,0,0,0,1,64,64,0,96,135,7,0,0,0,0,0,254,0,2,0,144,212,8,0,17,0,0,0,1,128,128,0,96,135,7,0,17,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,18,0,0,0,1,3,3,0,8,49,4,0,18,0,0,0,1,3,2,0,152,21,4,0,18,0,0,0,1,3,1,0,72,246,3,0,18,0,0,0,1,3,0,0,64,47,7,0,0,0,0,0,254,0,2,0,200,30,2,0,18,0,0,0,1,4,0,0,120,97,1,0,18,0,0,0,1,4,4,0,96,19,1,0,0,0,0,0,254,0,4,0,224,83,4,0,18,0,0,0,1,24,24,0,176,2,8,0,18,0,0,0,1,24,16,0,240,28,4,0,18,0,0,0,1,24,8,0,80,0,4,0,18,0,0,0,1,24,0,0,248,168,7,0,0,0,0,0,254,0,2,0,72,202,5,0,18,0,0,0,1,32,32,0,248,38,7,0,18,0,0,0,1,32,0,0,48,123,8,0,0,0,0,0,254,0,2,0,32,118,3,0,18,0,0,0,1,64,0,0,72,95,3,0,18,0,0,0,1,64,64,0,176,20,3,0,0,0,0,0,254,0,2,0,104,159,3,0,18,0,0,0,1,128,0,0,56,111,3,0,18,0,0,0,1,128,128,0,104,134,3,0,50,50,46,117,51,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,27,28,170,240,0,0,16,1,49,57,46,117,51,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,220,205,138,154,0,0,16,1,50,49,46,117,51,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,100,189,249,253,0,0,16,1,49,56,46,117,51,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,14,126,81,254,0,0,16,1,50,48,46,117,51,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,233,175,146,134,0,0,16,1,49,55,46,117,51,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,107,154,143,151,0,0,16,1,112,105,99,49,54,99,53,55,45,104,115,46,105,48,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,76,45,0,0,65,105,44,2,0,0,16,1,50,54,46,117,51,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,89,192,113,193,0,0,32,0,51,48,46,117,51,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,16,197,164,180,0,0,32,0,50,53,46,117,51,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,27,236,126,102,0,0,32,0,50,57,46,117,51,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,69,7,203,74,0,0,32,0,50,52,46,117,51,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,37,104,244,23,0,0,32,0,50,56,46,117,51,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,189,242,35,168,0,0,32,0,50,51,46,117,51,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,59,69,225,216,0,0,32,0,50,55,46,117,51,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,121,192,162,236,0,0,32,0,49,54,46,105,48,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,93,218,217,126,0,0,64,0,19,0,0,0,255,255,99,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,19,0,0,0,1,3,0,0,192,255,2,0,19,0,0,0,1,3,2,0,208,75,4,0,19,0,0,0,1,3,3,0,8,49,4,0,19,0,0,0,1,3,1,0,152,21,4,0,0,0,0,0,254,0,3,0,144,100,7,0,19,0,0,0,1,12,0,0,56,111,3,0,19,0,0,0,1,12,8,0,88,132,5,0,19,0,0,0,1,12,12,0,168,103,1,0,0,0,0,0,254,0,4,0,72,202,5,0,19,0,0,0,1,48,48,0,80,246,3,0,19,0,0,0,1,48,32,0,248,38,7,0,19,0,0,0,1,48,16,0,80,124,6,0,19,0,0,0,1,48,0,0,112,212,3,0,0,0,0,0,254,0,2,0,104,159,3,0,19,0,0,0,1,64,0,0,56,111,3,0,19,0,0,0,1,64,64,0,104,134,3,0,0,0,0,0,254,0,2,0,40,111,8,0,19,0,0,0,1,128,128,0,96,135,7,0,19,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,96,46,8,0,20,0,0,0,1,1,1,0,208,233,4,0,20,0,0,0,1,1,0,0,72,197,4,0,0,0,0,0,254,0,16,0,152,167,4,0,20,0,0,0,1,30,20,0,176,73,5,0,20,0,0,0,1,30,22,0,104,54,4,0,20,0,0,0,1,30,20,0,80,252,6,0,20,0,0,0,1,30,24,0,16,242,7,0,20,0,0,0,1,30,26,0,40,28,4,0,20,0,0,0,1,30,2,0,104,236,7,0,20,0,0,0,1,30,4,0,96,135,3,0,20,0,0,0,1,30,6,0,120,113,6,0,20,0,0,0,1,30,30,0,128,230,7,0,20,0,0,0,1,30,8,0,120,211,6,0,20,0,0,0,1,30,18,0,184,164,6,0,20,0,0,0,1,30,16,0,80,74,6,0,20,0,0,0,1,30,14,0,192,32,6,0,20,0,0,0,1,30,12,0,192,234,2,0,20,0,0,0,1,30,10,0,32,242,5,0,20,0,0,0,1,30,0,0,16,227,4,0,0,0,0,0,254,0,2,0,72,72,1,0,20,0,0,0,1,32,32,0,192,255,2,0,20,0,0,0,1,32,0,0,208,75,4,0,0,0,0,0,254,0,2,0,80,66,1,0,20,0,0,0,1,64,64,0,8,201,1,0,20,0,0,0,1,64,0,0,80,227,1,0,0,0,0,0,254,0,2,0,232,75,4,0,20,0,0,0,1,128,128,0,96,135,7,0,20,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,101,115,119,97,116,95,99,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,129,204,40,16,1,0,16,1,101,115,119,97,116,95,102,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,136,211,178,247,1,0,16,1,101,115,119,97,116,95,98,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,181,177,198,135,1,0,16,1,101,115,119,97,116,95,101,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,154,223,125,147,1,0,16,1,101,115,119,97,116,95,97,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,98,252,244,42,1,0,16,1,101,115,119,97,116,95,100,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,25,30,117,180,1,0,16,1,109,112,114,49,50,54,50,52,46,98,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,196,94,90,55,2,0,32,0,109,112,114,49,50,54,50,53,46,98,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,126,117,140,59,2,0,32,0,109,112,114,49,50,54,50,54,46,98,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,92,162,252,62,2,0,32,0,105,99,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,191,48,21,13,3,0,32,0,105,99,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,153,7,255,24,3,0,32,0,105,99,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,70,146,6,50,3,0,32,0,105,99,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,54,228,223,163,3,0,32,0,105,99,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,224,150,176,246,3,0,32,0,105,99,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,246,254,115,103,3,0,32,0,101,112,114,49,50,54,49,55,46,97,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,35,207,254,126,4,0,16,1,109,112,114,49,50,54,49,54,46,97,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,194,71,67,37,8,0,64,0,13,0,0,0,255,255,253,0,0,0,0,0,14,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,72,202,5,0,13,0,0,0,1,1,1,0,80,246,3,0,13,0,0,0,1,1,0,0,112,212,3,0,0,0,0,0,254,0,2,0,168,234,7,0,13,0,0,0,1,2,2,0,96,135,7,0,13,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,240,95,3,0,13,0,0,0,1,4,4,0,192,160,4,0,13,0,0,0,1,4,0,0,240,28,4,0,0,0,0,0,254,0,2,0,216,82,6,0,13,0,0,0,1,8,8,0,248,81,6,0,13,0,0,0,1,8,0,0,176,64,8,0,0,0,0,0,254,0,4,0,160,123,6,0,13,0,0,0,1,48,48,0,144,251,6,0,13,0,0,0,1,48,0,0,120,211,6,0,13,0,0,0,1,48,16,0,80,74,6,0,13,0,0,0,1,48,32,0,192,32,6,0,0,0,0,0,254,0,4,0,200,87,7,0,13,0,0,0,1,192,64,0,96,39,7,0,13,0,0,0,1,192,192,0,144,251,6,0,13,0,0,0,1,192,0,0,120,211,6,0,13,0,0,0,1,192,128,0,184,164,6,0,98,53,56,45,51,56,46,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,145,1,170,161,2,0,16,1,98,53,56,45,51,54,46,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,163,61,244,64,2,0,16,1,98,53,56,45,51,55,46,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,92,200,35,232,6,0,16,1,98,53,56,45,51,53,46,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,18,235,60,139,6,0,16,1,98,53,56,45,51,50,46,52,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,202,142,253,243,9,0,16,1,98,53,56,45,48,57,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,49,91,253,159,11,0,32,0,98,53,56,45,48,52,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,141,240,130,148,17,0,32,0,98,53,56,45,48,51,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,64,196,139,21,17,0,32,0,98,53,56,45,48,50,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,124,48,110,106,17,0,32,0,98,53,56,45,48,49,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,240,233,1,17,0,32,0,98,53,56,45,48,54,46,49,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,112,93,73,179,22,0,32,0,98,53,56,45,48,53,46,55,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,27,153,244,209,23,0,32,0,98,53,56,45,48,55,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,8,186,181,238,24,0,64,0,98,53,56,45,48,56,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,207,67,146,4,24,0,64,0,98,53,56,45,49,48,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,193,12,206,237,25,0,64,0,98,53,56,45,50,54,46,49,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,127,12,203,220,0,0,0,8,98,53,56,45,50,55,46,53,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,61,1,107,92,0,0,0,8,98,53,56,45,50,51,46,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,244,143,125,123,0,0,0,8,98,53,56,45,50,52,46,53,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,48,31,248,251,0,0,0,8,98,53,56,45,50,53,46,55,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,66,115,84,222,0,0,0,8,12,0,0,0,255,255,255,0,0,0,0,0,13,0,0,0,255,255,239,0,0,0,0,0,0,0,0,0,254,0,2,0,232,75,4,0,12,0,0,0,1,4,4,0,96,135,7,0,12,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,12,0,0,0,1,8,0,0,96,135,7,0,12,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,12,0,0,0,1,48,16,0,104,236,7,0,12,0,0,0,1,48,48,0,128,230,7,0,12,0,0,0,1,48,0,0,120,211,6,0,12,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,12,0,0,0,1,192,64,0,104,236,7,0,12,0,0,0,1,192,192,0,128,230,7,0,12,0,0,0,1,192,0,0,120,211,6,0,12,0,0,0,1,192,128,0,184,164,6,0,0,0,0,0,254,0,2,0,176,235,6,0,13,0,0,0,1,16,16,0,192,227,6,0,13,0,0,0,1,16,0,0,248,38,7,0,0,0,0,0,101,112,114,45,55,54,52,48,97,46,105,99,57,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,212,197,29,29,1,0,16,1,101,112,114,45,55,54,51,54,97,46,105,99,56,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,57,22,19,132,1,0,16,1,101,112,114,45,55,54,52,49,46,105,99,57,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,124,174,3,37,1,0,16,1,101,112,114,45,55,54,51,55,46,105,99,56,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,140,122,162,130,1,0,16,1,101,112,114,45,55,54,52,50,46,105,99,57,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,234,59,69,28,1,0,16,1,101,112,114,45,55,54,51,56,46,105,99,56,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,121,71,84,112,1,0,16,1,101,112,114,45,55,54,51,52,97,46,105,99,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,49,55,200,174,9,0,16,1,101,112,114,45,55,54,51,53,97,46,105,99,54,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,111,233,252,178,9,0,16,1,101,112,114,45,55,54,52,52,46,105,99,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,144,255,164,231,2,0,32,0,101,112,114,45,55,54,52,53,46,105,99,52,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,149,0,170,76,2,0,32,0,101,112,114,45,55,54,52,54,46,105,99,54,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,131,38,67,126,2,0,32,0,101,112,114,45,55,54,55,56,46,105,99,51,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,86,230,181,159,3,0,32,0,101,112,114,45,55,54,55,48,46,105,99,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,110,47,190,219,3,0,32,0,101,112,114,45,55,54,54,50,46,105,99,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,197,19,12,203,3,0,32,0,101,112,114,45,55,54,53,52,46,49,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,13,82,182,45,3,0,32,0,101,112,114,45,55,54,55,55,46,105,99,51,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,91,118,100,119,3,0,32,0,101,112,114,45,55,54,54,57,46,105,99,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,170,95,82,249,3,0,32,0,101,112,114,45,55,54,54,49,46,105,99,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,155,167,147,254,3,0,32,0,101,112,114,45,55,54,53,51,46,105,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,20,33,165,70,3,0,32,0,101,112,114,45,55,54,55,54,46,105,99,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,212,224,66,46,3,0,32,0,101,112,114,45,55,54,54,56,46,105,99,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,51,206,21,225,3,0,32,0,101,112,114,45,55,54,54,48,46,105,99,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,104,187,223,134,3,0,32,0,101,112,114,45,55,54,53,50,46,105,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,219,207,128,40,3,0,32,0,101,112,114,45,55,54,55,53,46,105,99,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,97,45,205,5,3,0,32,0,101,112,114,45,55,54,54,55,46,105,99,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,157,222,59,146,3,0,32,0,101,112,114,45,55,54,53,57,46,105,99,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,206,200,157,98,3,0,32,0,101,112,114,45,55,54,53,49,46,105,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,173,43,144,215,3,0,32,0,101,112,114,45,55,54,55,52,46,105,99,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,207,154,18,26,3,0,32,0,101,112,114,45,55,54,54,54,46,105,99,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,87,114,105,35,3,0,32,0,101,112,114,45,55,54,53,56,46,105,99,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,79,242,119,22,3,0,32,0,101,112,114,45,55,54,53,48,46,105,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,236,53,38,100,3,0,32,0,101,112,114,45,55,54,55,51,46,105,99,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,148,35,96,130,3,0,32,0,101,112,114,45,55,54,54,53,46,105,99,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,7,118,215,18,3,0,32,0,101,112,114,45,55,54,53,55,46,105,99,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,156,131,88,129,3,0,32,0,101,112,114,45,55,54,52,57,46,105,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,76,161,219,78,3,0,32,0,101,112,114,45,55,54,55,50,46,105,99,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,247,82,20,209,3,0,32,0,101,112,114,45,55,54,54,52,46,105,99,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,173,207,242,13,3,0,32,0,101,112,114,45,55,54,53,54,46,105,99,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,114,18,116,108,3,0,32,0,101,112,114,45,55,54,52,56,46,105,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,48,168,62,152,3,0,32,0,101,112,114,45,55,54,55,49,46,105,99,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,198,253,199,176,3,0,32,0,101,112,114,45,55,54,54,51,46,105,99,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,8,143,11,43,3,0,32,0,101,112,114,45,55,54,53,53,46,105,99,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,123,254,51,52,3,0,32,0,101,112,114,45,55,54,52,55,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,192,190,127,46,3,0,32,0,101,112,114,45,55,54,51,51,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,16,98,20,111,10,0,32,0,101,112,114,45,55,54,56,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,72,191,239,196,4,0,16,1,101,112,114,45,55,54,56,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,18,77,12,188,11,0,64,0,101,112,114,45,55,54,56,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,140,60,123,98,11,0,64,0,101,112,114,45,54,56,52,52,46,105,99,49,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,214,123,236,227,16,0,32,0,51,49,55,45,48,48,49,51,97,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,55,103,94,41,5,0,16,1,10,0,0,0,255,255,255,0,0,0,0,0,11,0,0,0,255,255,126,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,10,0,0,0,1,15,7,0,80,252,6,0,10,0,0,0,1,15,8,0,16,242,7,0,10,0,0,0,1,15,9,0,104,236,7,0,10,0,0,0,1,15,5,0,176,51,4,0,10,0,0,0,1,15,4,0,56,24,4,0,10,0,0,0,1,15,15,0,128,230,7,0,10,0,0,0,1,15,1,0,72,216,3,0,10,0,0,0,1,15,2,0,24,188,3,0,10,0,0,0,1,15,3,0,176,162,3,0,10,0,0,0,1,15,6,0,120,211,6,0,10,0,0,0,1,15,14,0,184,164,6,0,10,0,0,0,1,15,13,0,80,74,6,0,10,0,0,0,1,15,12,0,192,32,6,0,10,0,0,0,1,15,11,0,192,234,2,0,10,0,0,0,1,15,10,0,32,242,5,0,10,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,10,0,0,0,1,240,112,0,80,252,6,0,10,0,0,0,1,240,128,0,16,242,7,0,10,0,0,0,1,240,144,0,104,236,7,0,10,0,0,0,1,240,80,0,176,51,4,0,10,0,0,0,1,240,64,0,56,24,4,0,10,0,0,0,1,240,240,0,128,230,7,0,10,0,0,0,1,240,16,0,72,216,3,0,10,0,0,0,1,240,32,0,24,188,3,0,10,0,0,0,1,240,48,0,176,162,3,0,10,0,0,0,1,240,96,0,120,211,6,0,10,0,0,0,1,240,224,0,184,164,6,0,10,0,0,0,1,240,208,0,80,74,6,0,10,0,0,0,1,240,192,0,192,32,6,0,10,0,0,0,1,240,176,0,192,234,2,0,10,0,0,0,1,240,160,0,32,242,5,0,10,0,0,0,1,240,0,0,208,236,2,0,0,0,0,0,254,0,2,0,200,30,2,0,11,0,0,0,1,1,0,0,120,97,1,0,11,0,0,0,1,1,1,0,224,4,1,0,0,0,0,0,254,0,4,0,72,202,5,0,11,0,0,0,1,6,4,0,80,246,3,0,11,0,0,0,1,6,6,0,80,124,6,0,11,0,0,0,1,6,2,0,112,212,3,0,11,0,0,0,1,6,0,0,248,160,5,0,0,0,0,0,254,0,4,0,40,252,8,0,11,0,0,0,1,24,16,0,80,246,3,0,11,0,0,0,1,24,24,0,80,124,6,0,11,0,0,0,1,24,8,0,112,212,3,0,11,0,0,0,1,24,0,0,248,160,5,0,0,0,0,0,254,0,4,0,16,0,1,0,11,0,0,0,1,96,64,0,80,246,3,0,11,0,0,0,1,96,96,0,80,124,6,0,11,0,0,0,1,96,32,0,112,212,3,0,11,0,0,0,1,96,0,0,248,160,5,0,0,0,0,0,254,0,2,0,168,234,7,0,11,0,0,0,1,128,128,0,96,135,7,0,11,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,16,0,0,0,255,255,97,0,0,0,0,0,17,0,0,0,255,255,127,0,0,0,0,0,0,0,0,0,254,0,2,0,160,165,8,0,16,0,0,0,1,1,1,0,96,135,7,0,16,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,3,0,152,99,8,0,16,0,0,0,1,96,96,0,192,255,2,0,16,0,0,0,1,96,64,0,208,75,4,0,16,0,0,0,1,96,0,0,8,49,4,0,0,0,0,0,254,0,2,0,168,234,7,0,16,0,0,0,1,128,128,0,96,135,7,0,16,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,100,7,0,17,0,0,0,1,128,0,0,56,111,3,0,17,0,0,0,1,128,128,0,104,134,3,0,0,0,0,0,18,0,0,0,255,255,191,0,0,0,0,0,19,0,0,0,255,255,127,0,0,0,0,0,0,0,0,0,254,0,8,0,200,87,7,0,18,0,0,0,1,7,0,0,40,88,7,0,18,0,0,0,1,7,1,0,96,39,7,0,18,0,0,0,1,7,7,0,144,251,6,0,18,0,0,0,1,7,6,0,184,164,6,0,18,0,0,0,1,7,5,0,80,74,6,0,18,0,0,0,1,7,4,0,192,32,6,0,18,0,0,0,1,7,3,0,192,234,2,0,18,0,0,0,1,7,2,0,32,242,5,0,0,0,0,0,254,0,8,0,160,123,6,0,18,0,0,0,1,56,0,0,40,88,7,0,18,0,0,0,1,56,8,0,96,39,7,0,18,0,0,0,1,56,56,0,144,251,6,0,18,0,0,0,1,56,48,0,184,164,6,0,18,0,0,0,1,56,40,0,80,74,6,0,18,0,0,0,1,56,32,0,192,32,6,0,18,0,0,0,1,56,24,0,192,234,2,0,18,0,0,0,1,56,16,0,32,242,5,0,0,0,0,0,254,0,2,0,144,212,8,0,18,0,0,0,1,64,0,0,96,135,7,0,18,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,152,23,8,0,18,0,0,0,1,128,128,0,192,255,2,0,18,0,0,0,1,128,0,0,208,75,4,0,0,0,0,0,254,0,4,0,96,70,8,0,19,0,0,0,1,3,1,0,112,67,8,0,19,0,0,0,1,3,0,0,112,134,3,0,19,0,0,0,1,3,3,0,80,124,6,0,19,0,0,0,1,3,2,0,64,111,3,0,0,0,0,0,254,0,4,0,72,202,5,0,19,0,0,0,1,12,8,0,80,246,3,0,19,0,0,0,1,12,12,0,248,38,7,0,19,0,0,0,1,12,4,0,112,212,3,0,19,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,2,0,224,117,5,0,19,0,0,0,1,64,0,0,96,135,7,0,19,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,128,128,0,96,135,7,0,19,0,0,0,1,128,0,0,152,182,7,0,18,0,0,0,255,255,191,0,0,0,0,0,19,0,0,0,255,255,127,0,0,0,0,0,0,0,0,0,254,0,8,0,200,87,7,0,18,0,0,0,1,7,0,0,40,88,7,0,18,0,0,0,1,7,1,0,96,39,7,0,18,0,0,0,1,7,7,0,144,251,6,0,18,0,0,0,1,7,6,0,184,164,6,0,18,0,0,0,1,7,5,0,80,74,6,0,18,0,0,0,1,7,4,0,192,32,6,0,18,0,0,0,1,7,3,0,192,234,2,0,18,0,0,0,1,7,2,0,32,242,5,0,0,0,0,0,254,0,8,0,160,123,6,0,18,0,0,0,1,56,0,0,40,88,7,0,18,0,0,0,1,56,8,0,96,39,7,0,18,0,0,0,1,56,56,0,144,251,6,0,18,0,0,0,1,56,48,0,184,164,6,0,18,0,0,0,1,56,40,0,80,74,6,0,18,0,0,0,1,56,32,0,192,32,6,0,18,0,0,0,1,56,24,0,192,234,2,0,18,0,0,0,1,56,16,0,32,242,5,0,0,0,0,0,254,0,2,0,144,212,8,0,18,0,0,0,1,64,0,0,96,135,7,0,18,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,128,184,7,0,18,0,0,0,1,128,128,0,96,135,7,0,18,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,4,0,96,70,8,0,19,0,0,0,1,3,1,0,112,67,8,0,19,0,0,0,1,3,0,0,112,134,3,0,19,0,0,0,1,3,3,0,80,124,6,0,19,0,0,0,1,3,2,0,64,111,3,0,0,0,0,0,254,0,4,0,72,202,5,0,19,0,0,0,1,12,8,0,80,246,3,0,19,0,0,0,1,12,12,0,248,38,7,0,19,0,0,0,1,12,4,0,112,212,3,0,19,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,2,0,224,117,5,0,19,0,0,0,1,64,0,0,96,135,7,0,19,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,128,128,0,96,135,7,0,19,0,0,0,1,128,0,0,152,182,7,0,51,54,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,87,102,81,26,1,0,16,1,52,50,46,49,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,160,144,162,18,1,0,16,1,51,55,46,49,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,67,201,47,147,1,0,16,1,52,51,46,49,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,109,215,42,135,1,0,16,1,51,52,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,61,102,143,1,0,16,1,52,48,46,49,48,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,243,219,134,21,1,0,16,1,51,53,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,122,61,185,157,1,0,16,1,52,49,46,49,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,164,105,174,26,1,0,16,1,48,57,46,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,105,60,232,195,4,0,32,0,48,49,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,134,40,123,24,4,0,32,0,49,51,46,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,125,216,115,2,4,0,32,0,48,53,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,184,120,147,51,4,0,32,0,50,52,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,111,155,144,198,4,0,32,0,49,55,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,32,131,47,46,4,0,32,0,51,56,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,237,35,121,205,4,0,32,0,51,50,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,83,164,160,33,4,0,32,0,49,48,46,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,208,248,40,255,4,0,32,0,48,50,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,47,192,131,204,4,0,32,0,49,52,40,95,95,100,121,110,119,97,114,106,41,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,44,35,251,24,4,0,32,0,48,54,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,117,221,158,111,4,0,32,0,50,53,46,55,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,74,167,46,21,4,0,32,0,49,56,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,50,249,51,24,4,0,32,0,51,57,46,57,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,96,179,9,188,4,0,32,0,51,51,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,51,21,222,137,4,0,32,0,49,49,46,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,144,244,234,41,4,0,32,0,48,51,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,55,19,245,123,4,0,32,0,49,53,46,49,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,145,219,108,211,4,0,32,0,48,55,46,49,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,84,240,74,224,4,0,32,0,50,54,46,56,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,75,113,252,7,4,0,32,0,49,57,46,56,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,198,229,20,113,4,0,32,0,50,56,46,49,48,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,7,191,98,175,4,0,32,0,50,49,46,49,48,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,42,70,63,82,4,0,32,0,49,50,46,56,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,57,35,101,56,4,0,32,0,48,52,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,15,188,81,73,4,0,32,0,49,54,46,49,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,174,8,22,56,4,0,32,0,48,56,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,233,212,117,180,4,0,32,0,50,55,46,57,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,250,129,126,162,4,0,32,0,50,48,46,57,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,220,150,39,0,4,0,32,0,50,57,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,45,248,65,107,4,0,32,0,50,50,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,105,83,20,82,4,0,32,0,50,51,46,49,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,79,157,183,179,3,0,16,0,51,48,46,49,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,180,108,95,126,5,0,64,0,51,49,46,49,51,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,55,199,48,74,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,116,107,50,50,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,215,182,26,26,0,0,0,8,108,119,105,111,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,12,185,82,173,0,0,0,8,116,107,101,95,51,54,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,209,145,89,137,1,0,16,1,116,107,101,95,52,50,46,49,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,232,210,152,200,1,0,16,1,116,107,101,95,51,55,46,49,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,140,213,40,178,1,0,16,1,116,107,101,95,52,51,46,49,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,90,55,20,26,1,0,16,1,51,52,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,61,102,143,1,0,16,1,52,48,46,49,48,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,243,219,134,21,1,0,16,1,51,53,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,122,61,185,157,1,0,16,1,52,49,46,49,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,164,105,174,26,1,0,16,1,48,57,46,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,105,60,232,195,4,0,32,0,48,49,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,134,40,123,24,4,0,32,0,49,51,46,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,125,216,115,2,4,0,32,0,48,53,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,184,120,147,51,4,0,32,0,50,52,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,111,155,144,198,4,0,32,0,49,55,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,32,131,47,46,4,0,32,0,51,56,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,237,35,121,205,4,0,32,0,51,50,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,83,164,160,33,4,0,32,0,49,48,46,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,208,248,40,255,4,0,32,0,48,50,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,47,192,131,204,4,0,32,0,49,52,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,47,179,217,88,4,0,32,0,48,54,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,117,221,158,111,4,0,32,0,50,53,46,55,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,74,167,46,21,4,0,32,0,49,56,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,50,249,51,24,4,0,32,0,51,57,46,57,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,96,179,9,188,4,0,32,0,51,51,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,51,21,222,137,4,0,32,0,49,49,46,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,144,244,234,41,4,0,32,0,48,51,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,55,19,245,123,4,0,32,0,49,53,46,49,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,145,219,108,211,4,0,32,0,48,55,46,49,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,84,240,74,224,4,0,32,0,50,54,46,56,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,75,113,252,7,4,0,32,0,49,57,46,56,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,198,229,20,113,4,0,32,0,50,56,46,49,48,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,7,191,98,175,4,0,32,0,50,49,46,49,48,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,42,70,63,82,4,0,32,0,49,50,46,56,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,57,35,101,56,4,0,32,0,48,52,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,15,188,81,73,4,0,32,0,49,54,46,49,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,174,8,22,56,4,0,32,0,48,56,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,233,212,117,180,4,0,32,0,50,55,46,57,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,250,129,126,162,4,0,32,0,50,48,46,57,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,220,150,39,0,4,0,32,0,50,57,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,45,248,65,107,4,0,32,0,50,50,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,105,83,20,82,4,0,32,0,50,51,46,49,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,79,157,183,179,3,0,16,0,116,107,101,95,51,48,46,49,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,125,48,110,172,5,0,64,0,116,107,101,95,51,49,46,49,51,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,219,65,135,6,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,116,107,50,50,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,215,182,26,26,0,0,0,8,108,119,105,111,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,12,185,82,173,0,0,0,8,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,247,0,0,0,0,0,0,0,0,0,254,0,2,0,96,46,8,0,19,0,0,0,1,1,1,0,208,233,4,0,19,0,0,0,1,1,0,0,72,197,4,0,0,0,0,0,254,0,4,0,200,87,7,0,19,0,0,0,1,6,0,0,96,135,3,0,19,0,0,0,1,6,2,0,40,88,7,0,19,0,0,0,1,6,4,0,96,39,7,0,19,0,0,0,1,6,6,0,144,251,6,0,0,0,0,0,254,0,5,0,160,123,6,0,19,0,0,0,1,24,24,0,184,164,6,0,19,0,0,0,1,24,16,0,80,74,6,0,19,0,0,0,1,24,8,0,192,234,2,0,19,0,0,0,1,24,0,0,32,242,5,0,19,0,0,0,1,24,0,0,16,227,4,0,0,0,0,0,254,0,5,0,32,4,2,0,19,0,0,0,1,30,24,0,32,136,7,0,19,0,0,0,1,30,26,0,40,88,7,0,19,0,0,0,1,30,28,0,96,39,7,0,19,0,0,0,1,30,30,0,144,251,6,0,19,0,0,0,1,30,0,0,16,227,4,0,0,0,0,0,254,0,2,0,72,222,3,0,19,0,0,0,1,32,32,0,248,38,7,0,19,0,0,0,1,32,0,0,192,205,4,0,0,0,0,0,254,0,2,0,200,30,2,0,19,0,0,0,1,64,64,0,120,97,1,0,19,0,0,0,1,64,0,0,96,19,1,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,128,128,0,96,135,7,0,19,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,0,0,64,37,5,0,20,0,0,0,1,12,12,0,176,225,3,0,20,0,0,0,1,12,8,0,80,195,3,0,20,0,0,0,1,12,4,0,64,169,3,0,20,0,0,0,1,12,0,0,144,143,3,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,48,48,0,248,38,7,0,20,0,0,0,1,48,32,0,80,246,3,0,20,0,0,0,1,48,16,0,112,212,3,0,20,0,0,0,1,48,0,0,248,160,5,0,0,0,0,0,254,0,4,0,104,159,3,0,20,0,0,0,1,64,0,0,96,135,7,0,20,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,20,0,0,0,1,128,0,0,96,135,7,0,20,0,0,0,1,128,128,0,152,182,7,0,0,0,0,0,103,103,49,48,110,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,144,44,42,93,0,0,16,1,103,103,57,110,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,61,24,235,48,0,0,16,1,103,103,56,110,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,69,33,94,75,0,0,16,1,103,103,49,51,110,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,230,170,100,38,0,0,16,1,103,103,49,50,110,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,232,74,239,199,0,0,16,1,103,103,49,52,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,150,177,207,85,0,0,16,1,49,46,56,52,52,57,48,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,7,207,252,236,0,0,32,0,103,103,51,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,200,34,219,104,0,0,32,0,103,103,49,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,47,221,216,218,0,0,32,0,103,103,51,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,35,131,21,122,0,0,32,0,103,103,49,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,149,208,20,115,0,0,32,0,103,103,51,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,155,109,169,3,0,0,32,0,103,103,49,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,188,153,152,123,0,0,32,0,103,103,52,108,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,180,129,207,73,0,0,32,0,103,103,51,108,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,177,55,20,230,0,0,32,0,103,103,49,108,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,45,224,31,188,0,0,32,0,103,103,52,110,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,167,245,175,213,0,0,32,0,103,103,51,110,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,235,202,137,213,0,0,32,0,103,103,49,110,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,37,169,128,119,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,0,0,0,255,255,29,0,0,0,0,0,0,0,0,0,254,0,2,0,168,234,7,0,14,0,0,0,1,1,0,0,96,135,7,0,14,0,0,0,1,1,1,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,14,0,0,0,1,6,0,0,8,49,4,0,14,0,0,0,1,6,2,0,152,21,4,0,14,0,0,0,1,6,4,0,72,246,3,0,14,0,0,0,1,6,6,0,72,0,3,0,0,0,0,0,254,0,2,0,72,202,5,0,14,0,0,0,1,8,0,0,80,246,3,0,14,0,0,0,1,8,8,0,248,38,7,0,0,0,0,0,254,0,8,0,64,37,5,0,14,0,0,0,1,112,0,0,176,116,6,0,14,0,0,0,1,112,16,0,80,110,6,0,14,0,0,0,1,112,32,0,152,53,6,0,14,0,0,0,1,112,48,0,112,216,4,0,14,0,0,0,1,112,64,0,8,49,6,0,14,0,0,0,1,112,80,0,176,210,4,0,14,0,0,0,1,112,96,0,248,45,5,0,14,0,0,0,1,112,112,0,184,43,6,0,0,0,0,0,254,0,2,0,200,30,2,0,14,0,0,0,1,128,0,0,120,97,1,0,14,0,0,0,1,128,128,0,96,19,1,0,117,98,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,20,171,150,11,0,0,16,1,117,98,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,242,105,248,7,0,0,16,1,117,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,218,129,4,228,0,0,16,1,112,114,111,116,100,97,116,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,224,185,100,96,0,0,16,1,115,114,111,109,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,29,210,205,241,0,0,32,0,115,114,111,109,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,158,147,72,248,0,0,32,0,117,111,114,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,43,145,180,0,0,32,0,117,111,114,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,147,207,17,176,0,0,32,0,117,111,114,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,130,53,108,217,0,0,32,0,117,111,114,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,235,35,255,119,0,0,32,0,117,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,186,196,244,208,0,0,64,0,56,55,99,53,50,46,109,99,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,16,19,0,0,0,255,255,127,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,1,1,0,96,135,7,0,19,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,8,0,72,202,5,0,19,0,0,0,1,14,4,0,192,255,2,0,19,0,0,0,1,14,8,0,208,75,4,0,19,0,0,0,1,14,0,0,8,49,4,0,19,0,0,0,1,14,14,0,152,21,4,0,19,0,0,0,1,14,6,0,72,246,3,0,19,0,0,0,1,14,10,0,72,0,3,0,19,0,0,0,1,14,2,0,64,47,7,0,19,0,0,0,1,14,12,0,232,99,5,0,0,0,0,0,254,0,8,0,32,4,2,0,19,0,0,0,1,112,0,0,16,242,7,0,19,0,0,0,1,112,64,0,16,242,7,0,19,0,0,0,1,112,32,0,16,242,7,0,19,0,0,0,1,112,96,0,104,236,7,0,19,0,0,0,1,112,112,0,128,230,7,0,19,0,0,0,1,112,80,0,120,211,6,0,19,0,0,0,1,112,48,0,184,164,6,0,19,0,0,0,1,112,16,0,80,74,6,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,128,128,0,96,135,7,0,19,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,16,227,4,0,20,0,0,0,1,1,1,0,96,135,7,0,20,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,192,0,0,208,75,4,0,20,0,0,0,1,192,192,0,8,49,4,0,20,0,0,0,1,192,64,0,152,21,4,0,20,0,0,0,1,192,128,0,72,246,3,0,18,0,0,0,255,255,223,0,0,0,0,0,19,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,72,202,5,0,18,0,0,0,1,3,3,0,80,246,3,0,18,0,0,0,1,3,2,0,80,124,6,0,18,0,0,0,1,3,1,0,112,212,3,0,18,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,2,0,64,37,5,0,18,0,0,0,1,4,4,0,80,110,6,0,18,0,0,0,1,4,0,0,152,53,6,0,0,0,0,0,254,0,2,0,16,27,6,0,18,0,0,0,1,8,8,0,96,135,7,0,18,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,2,0,72,4,1,0,18,0,0,0,1,16,16,0,96,135,7,0,18,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,2,0,200,30,2,0,18,0,0,0,1,32,0,0,120,97,1,0,18,0,0,0,1,32,32,0,96,19,1,0,0,0,0,0,254,0,2,0,16,227,4,0,18,0,0,0,1,64,64,0,56,111,3,0,18,0,0,0,1,64,0,0,104,134,3,0,0,0,0,0,254,0,2,0,128,129,4,0,18,0,0,0,1,128,128,0,8,49,4,0,18,0,0,0,1,128,0,0,72,246,3,0,0,0,0,0,254,0,10,0,160,123,6,0,19,0,0,0,1,15,6,0,32,136,7,0,19,0,0,0,1,15,8,0,40,88,7,0,19,0,0,0,1,15,10,0,96,39,7,0,19,0,0,0,1,15,7,0,120,113,6,0,19,0,0,0,1,15,15,0,144,251,6,0,19,0,0,0,1,15,9,0,120,211,6,0,19,0,0,0,1,15,14,0,184,164,6,0,19,0,0,0,1,15,13,0,80,74,6,0,19,0,0,0,1,15,12,0,192,32,6,0,19,0,0,0,1,15,11,0,192,234,2,0,0,0,0,0,254,0,10,0,200,87,7,0,19,0,0,0,1,240,96,0,32,136,7,0,19,0,0,0,1,240,128,0,40,88,7,0,19,0,0,0,1,240,160,0,96,39,7,0,19,0,0,0,1,240,112,0,120,113,6,0,19,0,0,0,1,240,240,0,144,251,6,0,19,0,0,0,1,240,144,0,120,211,6,0,19,0,0,0,1,240,224,0,184,164,6,0,19,0,0,0,1,240,208,0,80,74,6,0,19,0,0,0,1,240,192,0,192,32,6,0,19,0,0,0,1,240,176,0,192,234,2,0,0,0,0,0,100,98,48,54,46,49,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,134,8,62,65,0,0,16,1,100,98,48,55,46,49,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,158,244,220,139,0,0,16,1,100,98,48,56,46,49,52,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,217,189,67,22,0,0,16,1,100,98,48,50,46,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,12,71,168,154,0,0,32,0,100,98,48,51,46,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,61,228,36,51,0,0,32,0,100,98,48,52,46,49,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,194,182,197,192,0,0,32,0,100,98,48,53,46,50,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,242,37,171,210,0,0,32,0,100,98,49,48,46,50,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,174,247,112,158,0,0,32,0,100,98,48,57,46,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,247,99,146,45,0,0,32,0,100,98,48,49,46,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,129,107,250,98,0,0,64,0,112,101,49,46,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,84,236,242,238,0,0,16,1,112,101,50,46,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,107,209,72,188,0,0,16,1,112,101,51,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,87,48,146,28,0,0,16,1,112,101,52,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,186,28,175,35,0,0,16,1,112,101,53,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,41,228,219,57,0,0,16,1,112,101,55,46,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,74,78,9,210,0,0,16,1,112,101,54,46,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,244,71,244,28,0,0,16,1,112,101,56,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,116,41,140,77,0,0,32,0,112,101,57,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,98,161,78,78,0,0,32,0,109,98,55,48,53,49,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,97,220,64,100,0,0,32,0,168,86,7,0,1,0,0,0,31,240,146,0,248,191,2,0,24,38,7,0,1,0,0,0,26,240,146,0,184,160,2,0,56,210,6,0,1,0,0,0,154,0,147,0,192,135,2,0,24,163,6,0,1,0,0,0,155,0,147,0,240,108,2,0,152,122,6,0,1,0,0,0,153,0,147,0,96,82,2,0,192,72,6,0,1,0,0,0,152,0,147,0,32,56,2,0,200,110,3,0,1,0,0,0,156,0,147,0,152,30,2,0,144,236,1,0,1,0,0,0,27,240,146,0,136,224,1,0,176,223,1,0,1,0,0,0,2,248,146,0,72,198,1,0,192,209,1,0,1,0,0,0,3,248,146,0,24,182,1,0,24,198,1,0,1,0,0,0,1,248,146,0,40,167,1,0,120,189,1,0,1,0,0,0,0,248,146,0,200,149,1,0,224,22,1,0,1,0,0,0,4,248,146,0,56,126,1,0,88,212,3,0,1,0,0,0,208,219,146,0,40,185,3,0,72,65,1,0,9,0,0,0,8,6,147,0,32,58,1,0,14,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,8,0,32,4,2,0,14,0,0,0,1,7,2,0,16,242,7,0,14,0,0,0,1,7,4,0,104,236,7,0,14,0,0,0,1,7,0,0,144,251,6,0,14,0,0,0,1,7,6,0,184,164,6,0,14,0,0,0,1,7,1,0,80,74,6,0,14,0,0,0,1,7,3,0,192,32,6,0,14,0,0,0,1,7,5,0,192,234,2,0,14,0,0,0,1,7,7,0,32,242,5,0,0,0,0,0,254,0,2,0,200,30,2,0,14,0,0,0,1,8,0,0,120,97,1,0,14,0,0,0,1,8,8,0,96,19,1,0,0,0,0,0,100,51,57,45,49,52,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,172,253,170,230,2,0,16,1,100,51,57,45,49,54,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,55,133,220,206,2,0,16,1,100,51,57,45,48,52,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,109,80,0,56,1,0,16,1,100,51,57,45,48,53,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,93,59,236,226,1,0,16,1,100,51,57,45,49,50,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,193,199,146,130,9,0,16,1,100,51,57,45,48,54,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,53,40,246,82,11,0,32,0,100,51,57,45,48,49,46,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,125,156,14,209,15,0,32,0,100,51,57,45,48,50,46,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,3,68,48,108,15,0,32,0,100,51,57,45,48,51,46,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,180,218,156,252,15,0,32,0,100,51,57,45,48,55,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,22,40,38,40,24,0,64,0,100,51,57,45,48,56,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,123,139,123,55,25,0,64,0,21,0,0,0,255,255,255,0,0,0,0,0,22,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,21,0,0,0,1,2,2,0,96,135,7,0,21,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,21,0,0,0,1,4,4,0,96,135,7,0,21,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,21,0,0,0,1,8,0,0,96,135,7,0,21,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,21,0,0,0,1,48,0,0,80,252,6,0,21,0,0,0,1,48,16,0,16,242,7,0,21,0,0,0,1,48,32,0,104,236,7,0,21,0,0,0,1,48,48,0,128,230,7,0,0,0,0,0,254,0,4,0,160,123,6,0,21,0,0,0,1,192,192,0,8,201,6,0,21,0,0,0,1,192,128,0,200,197,6,0,21,0,0,0,1,192,64,0,152,194,6,0,21,0,0,0,1,192,0,0,248,189,6,0,0,0,0,0,254,0,4,0,72,202,5,0,22,0,0,0,1,3,2,0,80,246,3,0,22,0,0,0,1,3,3,0,80,124,6,0,22,0,0,0,1,3,1,0,112,212,3,0,22,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,120,95,4,0,22,0,0,0,1,12,8,0,56,94,4,0,22,0,0,0,1,12,12,0,248,38,7,0,22,0,0,0,1,12,4,0,176,90,4,0,22,0,0,0,1,12,0,0,192,87,4,0,0,0,0,0,254,0,2,0,72,84,4,0,22,0,0,0,1,16,16,0,248,38,7,0,22,0,0,0,1,16,0,0,176,64,8,0,0,0,0,0,254,0,2,0,160,76,4,0,22,0,0,0,1,32,32,0,232,74,4,0,22,0,0,0,1,32,0,0,8,208,6,0,0,0,0,0,254,0,2,0,208,81,6,0,22,0,0,0,1,64,64,0,120,97,1,0,22,0,0,0,1,64,0,0,96,19,1,0,0,0,0,0,254,0,2,0,144,212,6,0,22,0,0,0,1,128,0,0,8,208,6,0,22,0,0,0,1,128,128,0,88,204,6,0,0,0,0,0,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,241,203,223,150,1,0,16,1,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,8,235,223,19,1,0,16,1,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,73,243,51,97,1,0,16,1,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0])
.concat([186,88,64,14,1,0,16,1,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,141,201,194,243,4,0,32,0,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,252,190,116,213,4,0,32,0,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,220,10,239,85,4,0,32,0,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,252,5,8,204,4,0,32,0,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,20,247,113,19,4,0,32,0,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,167,196,132,178,4,0,32,0,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,148,51,173,183,4,0,32,0,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,5,119,132,136,4,0,32,0,112,105,99,49,54,99,53,55,45,114,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,76,45,0,0,60,57,109,90,7,0,16,0,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,9,19,146,125,5,0,64,0,168,86,7,0,1,0,0,0,232,47,216,0,248,191,2,0,24,38,7,0,1,0,0,0,236,47,216,0,184,160,2,0,56,210,6,0,1,0,0,0,35,48,216,0,192,135,2,0,24,163,6,0,1,0,0,0,34,48,216,0,240,108,2,0,152,122,6,0,1,0,0,0,33,48,216,0,96,82,2,0,192,72,6,0,1,0,0,0,32,48,216,0,32,56,2,0,152,31,6,0,1,0,0,0,36,48,216,0,152,30,2,0,248,97,5,0,1,0,0,0,37,48,216,0,232,10,2,0,40,147,2,0,1,0,0,0,38,48,216,0,152,138,8,0,40,246,1,0,1,0,0,0,233,47,216,0,64,246,1,0,144,236,1,0,1,0,0,0,237,47,216,0,136,224,1,0,176,223,1,0,1,0,0,0,43,48,216,0,72,198,1,0,192,209,1,0,1,0,0,0,42,48,216,0,24,182,1,0,24,198,1,0,1,0,0,0,41,48,216,0,40,167,1,0,120,189,1,0,1,0,0,0,40,48,216,0,200,149,1,0,8,182,1,0,1,0,0,0,44,48,216,0,56,126,1,0,32,167,1,0,1,0,0,0,45,48,216,0,32,101,1,0,200,197,8,0,1,0,0,0,46,48,216,0,96,32,8,0,168,132,8,0,1,0,0,0,166,47,216,0,232,209,1,0,72,126,8,0,1,0,0,0,167,47,216,0,144,189,1,0,192,122,8,0,1,0,0,0,163,47,216,0,208,174,1,0,40,116,8,0,1,0,0,0,162,47,216,0,48,160,1,0,72,110,8,0,1,0,0,0,161,47,216,0,160,140,1,0,184,102,8,0,1,0,0,0,160,47,216,0,56,112,1,0,248,93,8,0,1,0,0,0,164,47,216,0,32,92,1,0,152,86,8,0,1,0,0,0,165,47,216,0,64,77,1,0,88,212,3,0,1,0,0,0,144,46,216,0,40,185,3,0,240,152,1,0,1,0,0,0,238,47,216,0,216,70,1,0,16,17,8,0,1,0,0,0,234,47,216,0,224,12,8,0,224,41,1,0,9,0,0,0,216,48,216,0,32,58,1,0,184,40,2,0,1,0,0,0,40,39,216,0,248,191,2,0,56,250,6,0,1,0,0,0,32,39,216,0,184,160,2,0,184,164,8,0,1,0,0,0,41,39,216,0,64,246,1,0,88,149,7,0,1,0,0,0,33,39,216,0,136,224,1,0,240,167,7,0,1,0,0,0,44,39,216,0,192,135,2,0,176,163,7,0,1,0,0,0,47,39,216,0,240,108,2,0,208,158,7,0,1,0,0,0,42,39,216,0,96,82,2,0,184,154,7,0,1,0,0,0,43,39,216,0,32,56,2,0,176,108,2,0,1,0,0,0,28,39,216,0,152,30,2,0,8,96,7,0,1,0,0,0,36,39,216,0,72,198,1,0,48,89,7,0,1,0,0,0,46,39,216,0,24,182,1,0,16,83,7,0,1,0,0,0,34,39,216,0,40,167,1,0,96,79,7,0,1,0,0,0,35,39,216,0,200,149,1,0,48,76,7,0,1,0,0,0,45,39,216,0,56,126,1,0,88,212,3,0,1,0,0,0,48,38,216,0,40,185,3,0,248,5,8,0,9,0,0,0,112,39,216,0,32,58,1,0,144,250,7,0,9,0,0,0,113,39,216,0,32,58,1,0,248,241,7,0,9,0,0,0,114,39,216,0,32,58,1,0,103,109,100,101,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,205,206,143,150,1,0,16,1,103,109,100,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,103,85,72,55,1,0,16,1,103,109,100,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,251,159,38,218,1,0,16,1,103,109,100,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,201,131,180,85,1,0,16,1,103,109,100,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,240,25,221,128,5,0,32,0,103,109,100,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,120,58,217,223,5,0,32,0,103,109,100,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,32,101,53,22,5,0,32,0,103,109,100,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,49,48,195,223,5,0,32,0,103,109,100,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,133,201,155,63,10,0,16,1,103,109,100,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,222,157,211,63,10,0,16,1,103,109,100,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,66,85,166,6,12,0,64,0,103,109,100,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,49,122,188,80,12,0,64,0,100,51,111,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,241,249,75,186,0,0,16,1,100,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,250,214,54,244,0,0,16,1,100,53,111,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,58,189,88,174,0,0,16,1,100,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,158,63,63,69,0,0,16,1,100,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,111,91,95,97,0,0,16,1,100,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,4,229,36,58,0,0,32,0,100,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,215,87,67,117,0,0,32,0,100,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,205,237,49,117,0,0,32,0,100,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,8,202,238,34,0,0,32,0,100,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,96,190,97,107,0,0,32,0,100,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,116,82,89,253,0,0,32,0,100,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,210,220,81,127,0,0,32,0,100,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,5,176,100,129,0,0,32,0,100,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,99,33,19,111,0,0,32,0,112,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,88,81,175,14,0,0,32,0,112,114,111,109,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,164,133,18,74,0,0,32,0,10,0,0,0,255,255,129,0,0,0,0,0,11,0,0,0,255,255,7,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,10,0,0,0,1,3,0,0,208,75,4,0,10,0,0,0,1,3,1,0,8,49,4,0,10,0,0,0,1,3,2,0,152,21,4,0,10,0,0,0,1,3,3,0,72,246,3,0,0,0,0,0,254,0,4,0,64,172,4,0,10,0,0,0,1,12,0,0,192,211,1,0,10,0,0,0,1,12,4,0,200,200,1,0,10,0,0,0,1,12,8,0,248,86,4,0,10,0,0,0,1,12,12,0,32,183,1,0,0,0,0,0,254,0,4,0,32,4,2,0,10,0,0,0,1,48,48,0,144,102,8,0,10,0,0,0,1,48,32,0,176,45,8,0,10,0,0,0,1,48,16,0,224,127,8,0,10,0,0,0,1,48,0,0,32,123,8,0,0,0,0,0,254,0,2,0,144,212,8,0,10,0,0,0,1,128,128,0,96,135,7,0,10,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,4,0,104,81,3,0,11,0,0,0,1,15,0,0,16,208,8,0,11,0,0,0,1,15,1,0,120,52,3,0,11,0,0,0,1,15,2,0,88,32,3,0,11,0,0,0,1,15,3,0,72,8,3,0,11,0,0,0,1,15,4,0,216,242,2,0,11,0,0,0,1,15,5,0,136,219,2,0,11,0,0,0,1,15,6,0,112,199,2,0,11,0,0,0,1,15,7,0,248,38,7,0,11,0,0,0,1,15,8,0,80,167,2,0,11,0,0,0,1,15,9,0,32,153,2,0,11,0,0,0,1,15,10,0,16,141,2,0,11,0,0,0,1,15,11,0,248,129,2,0,11,0,0,0,1,15,12,0,240,114,2,0,11,0,0,0,1,15,13,0,16,103,2,0,11,0,0,0,1,15,14,0,32,90,2,0,11,0,0,0,1,15,15,0,128,65,6,0,0,0,0,0,254,0,4,0,136,61,2,0,11,0,0,0,1,48,0,0,192,211,1,0,11,0,0,0,1,48,16,0,200,200,1,0,11,0,0,0,1,48,32,0,248,86,4,0,11,0,0,0,1,48,48,0,32,183,1,0,101,112,114,45,49,48,57,49,55,97,46,97,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,124,196,26,217,1,0,16,1,101,112,114,45,49,48,57,49,53,46,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,16,197,68,115,1,0,16,1,101,112,114,45,49,48,57,49,56,97,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,205,239,27,228,1,0,16,1,101,112,114,45,49,48,57,49,54,97,46,97,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,18,186,88,127,1,0,16,1,101,112,114,45,49,48,56,50,57,46,97,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,8,171,49,164,1,0,16,1,101,112,114,45,49,48,56,50,54,46,97,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,183,228,216,46,1,0,16,1,49,48,57,49,57,46,98,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,130,143,184,35,2,0,32,0,49,48,57,50,48,46,98,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,76,251,177,34,2,0,32,0,49,48,57,50,49,46,98,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,93,245,136,119,2,0,32,0,49,48,55,54,48,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,123,50,222,112,3,0,32,0,49,48,55,54,51,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,181,92,236,153,3,0,32,0,49,48,55,54,49,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,13,248,128,78,3,0,32,0,49,48,55,54,52,46,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,213,165,45,96,3,0,32,0,49,48,55,54,50,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,120,95,75,70,3,0,32,0,49,48,55,54,53,46,98,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,87,160,115,10,3,0,32,0,49,48,55,55,53,46,97,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,168,85,189,76,4,0,16,1,51,49,55,45,48,48,50,56,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,178,7,83,154,5,0,16,1,100,97,100,101,46,48,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,94,3,90,102,1,0,16,1,100,97,100,101,46,48,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,7,50,97,2,1,0,16,1,100,97,100,101,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,150,89,132,54,1,0,16,1,100,97,100,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,86,62,170,19,1,0,16,1,100,97,100,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,221,182,28,67,1,0,16,1,100,97,100,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,214,183,60,218,5,0,32,0,100,97,100,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,114,49,182,146,5,0,32,0,100,97,100,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,245,87,135,185,5,0,32,0,100,97,100,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,70,206,33,129,5,0,32,0,100,97,100,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,63,111,126,131,5,0,32,0,100,97,100,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,219,107,145,240,5,0,32,0,100,97,100,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,239,147,243,206,5,0,32,0,100,97,100,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,158,254,83,137,5,0,32,0,100,97,100,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,36,36,94,63,10,0,16,1,100,97,100,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,103,155,73,12,12,0,64,0,100,97,100,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,78,90,11,47,12,0,64,0,168,86,7,0,1,0,0,0,212,47,216,0,248,191,2,0,24,38,7,0,1,0,0,0,208,47,216,0,184,160,2,0,56,210,6,0,1,0,0,0,35,48,216,0,192,135,2,0,24,163,6,0,1,0,0,0,34,48,216,0,240,108,2,0,152,122,6,0,1,0,0,0,33,48,216,0,96,82,2,0,192,72,6,0,1,0,0,0,32,48,216,0,32,56,2,0,152,31,6,0,1,0,0,0,36,48,216,0,152,30,2,0,248,97,5,0,1,0,0,0,37,48,216,0,232,10,2,0,152,6,5,0,1,0,0,0,38,48,216,0,152,138,8,0,120,36,5,0,1,0,0,0,39,48,216,0,48,119,7,0,40,246,1,0,1,0,0,0,213,47,216,0,64,246,1,0,144,236,1,0,1,0,0,0,209,47,216,0,136,224,1,0,176,223,1,0,1,0,0,0,43,48,216,0,72,198,1,0,192,209,1,0,1,0,0,0,42,48,216,0,24,182,1,0,24,198,1,0,1,0,0,0,41,48,216,0,40,167,1,0,120,189,1,0,1,0,0,0,40,48,216,0,200,149,1,0,8,182,1,0,1,0,0,0,44,48,216,0,56,126,1,0,32,167,1,0,1,0,0,0,45,48,216,0,32,101,1,0,136,140,1,0,1,0,0,0,46,48,216,0,96,32,8,0,128,149,1,0,1,0,0,0,47,48,216,0,16,68,7,0,168,132,8,0,1,0,0,0,214,47,216,0,232,209,1,0,72,126,8,0,1,0,0,0,210,47,216,0,144,189,1,0,192,122,8,0,1,0,0,0,251,47,216,0,208,174,1,0,40,116,8,0,1,0,0,0,250,47,216,0,48,160,1,0,72,110,8,0,1,0,0,0,249,47,216,0,160,140,1,0,184,102,8,0,1,0,0,0,248,47,216,0,56,112,1,0,248,93,8,0,1,0,0,0,252,47,216,0,32,92,1,0,152,86,8,0,1,0,0,0,253,47,216,0,64,77,1,0,168,70,8,0,1,0,0,0,254,47,216,0,112,157,4,0,64,76,8,0,1,0,0,0,255,47,216,0,176,194,6,0,232,23,8,0,1,0,0,0,215,47,216,0,104,195,5,0,160,19,8,0,1,0,0,0,211,47,216,0,32,245,8,0,248,16,8,0,1,0,0,0,3,48,216,0,32,231,8,0,192,12,8,0,1,0,0,0,2,48,216,0,88,214,8,0,224,5,8,0,1,0,0,0,1,48,216,0,224,202,8,0,144,1,8,0,1,0,0,0,0,48,216,0,72,193,8,0,96,250,7,0,1,0,0,0,4,48,216,0,144,180,8,0,120,241,7,0,1,0,0,0,5,48,216,0,208,164,8,0,112,226,7,0,1,0,0,0,6,48,216,0,160,152,4,0,88,230,7,0,1,0,0,0,7,48,216,0,40,184,6,0,88,212,3,0,1,0,0,0,144,46,216,0,40,185,3,0,240,152,1,0,1,0,0,0,201,47,216,0,216,70,1,0,16,17,8,0,1,0,0,0,202,47,216,0,224,12,8,0,136,67,2,0,1,0,0,0,176,48,216,0,112,109,7,0,8,66,2,0,1,0,0,0,184,48,216,0,24,133,7,0,100,100,50,117,100,46,48,51,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,90,105,111,129,1,0,16,1,100,100,50,117,100,46,48,52,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,107,28,200,124,1,0,16,1,100,100,50,46,48,53,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,28,153,177,94,1,0,16,1,100,100,50,46,48,54,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,85,94,107,194,1,0,16,1,100,100,50,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,139,11,154,144,1,0,16,1,100,100,50,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,77,60,229,1,0,16,1,100,100,50,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,159,39,134,95,1,0,16,1,100,100,50,100,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,143,47,23,12,1,0,16,1,100,100,50,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,110,78,107,164,5,0,32,0,100,100,50,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,252,80,252,213,5,0,32,0,100,100,50,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,103,8,124,131,5,0,32,0,100,100,50,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,28,194,14,187,5,0,32,0,100,100,50,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,226,76,130,109,5,0,32,0,100,100,50,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,229,42,104,121,5,0,32,0,100,100,50,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,73,209,221,172,5,0,32,0,100,100,50,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,192,176,127,17,5,0,32,0,100,100,50,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,229,87,214,153,10,0,16,1,100,100,50,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,36,56,122,17,10,0,16,1,100,100,50,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,37,195,208,152,12,0,64,0,100,100,50,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,250,231,162,94,12,0,64,0,100,100,50,101,46,48,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,120,118,230,109,1,0,16,1,100,100,50,101,46,48,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,154,115,69,14,1,0,16,1,100,100,50,101,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,37,128,206,61,1,0,16,1,100,100,50,101,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,239,251,186,81,1,0,16,1,100,100,50,101,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,2,122,119,187,1,0,16,1,100,100,50,101,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,144,8,151,48,1,0,16,1,100,100,50,101,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,77,25,226,153,1,0,16,1,100,100,50,101,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,94,128,152,225,1,0,16,1,100,100,50,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,110,78,107,164,5,0,32,0,100,100,50,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,252,80,252,213,5,0,32,0,100,100,50,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,103,8,124,131,5,0,32,0,100,100,50,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,28,194,14,187,5,0,32,0,100,100,50,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,226,76,130,109,5,0,32,0,100,100,50,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,229,42,104,121,5,0,32,0,100,100,50,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,73,209,221,172,5,0,32,0,100,100,50,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,192,176,127,17,5,0,32,0,100,100,50,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,229,87,214,153,10,0,16,1,100,100,50,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,36,56,122,17,10,0,16,1,100,100,50,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,37,195,208,152,12,0,64,0,100,100,50,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,250,231,162,94,12,0,64,0,100,100,50,101,46,48,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,102,235,45,205,1,0,16,1,100,100,50,101,46,48,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,204,67,238,191,1,0,16,1,100,100,50,101,46,48,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,157,177,154,4,1,0,16,1,100,100,50,101,46,48,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,139,251,148,57,1,0,16,1,100,100,50,101,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,2,122,119,187,1,0,16,1,100,100,50,101,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,144,8,151,48,1,0,16,1,100,100,50,101,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,77,25,226,153,1,0,16,1,100,100,50,101,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,94,128,152,225,1,0,16,1,100,100,50,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,110,78,107,164,5,0,32,0,100,100,50,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,252,80,252,213,5,0,32,0,100,100,50,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,103,8,124,131,5,0,32,0,100,100,50,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,28,194,14,187,5,0,32,0,100,100,50,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,226,76,130,109,5,0,32,0,100,100,50,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,229,42,104,121,5,0,32,0,100,100,50,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,73,209,221,172,5,0,32,0,100,100,50,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,192,176,127,17,5,0,32,0,100,100,50,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,229,87,214,153,10,0,16,1,100,100,50,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,36,56,122,17,10,0,16,1,100,100,50,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,37,195,208,152,12,0,64,0,100,100,50,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,250,231,162,94,12,0,64,0,100,100,50,101,46,48,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,74,8,108,1,0,16,1,100,100,50,101,46,48,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,71,169,148,155,1,0,16,1,100,100,50,101,46,48,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,198,99,106,93,1,0,16,1,100,100,50,101,46,48,54,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,238,232,189,49,1,0,16,1,100,100,50,101,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,2,122,119,187,1,0,16,1,100,100,50,101,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,144,8,151,48,1,0,16,1,100,100,50,101,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,77,25,226,153,1,0,16,1,100,100,50,101,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,94,128,152,225,1,0,16,1,100,100,50,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,110,78,107,164,5,0,32,0,100,100,50,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,252,80,252,213,5,0,32,0,100,100,50,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,103,8,124,131,5,0,32,0,100,100,50,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,28,194,14,187,5,0,32,0,100,100,50,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,226,76,130,109,5,0,32,0,100,100,50,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,229,42,104,121,5,0,32,0,100,100,50,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,73,209,221,172,5,0,32,0,100,100,50,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,192,176,127,17,5,0,32,0,100,100,50,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,229,87,214,153,10,0,16,1,100,100,50,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,36,56,122,17,10,0,16,1,100,100,50,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,37,195,208,152,12,0,64,0,100,100,50,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,250,231,162,94,12,0,64,0,168,86,7,0,1,0,0,0,212,47,216,0,248,191,2,0,24,38,7,0,1,0,0,0,208,47,216,0,184,160,2,0,56,210,6,0,1,0,0,0,35,48,216,0,192,135,2,0,24,163,6,0,1,0,0,0,34,48,216,0,240,108,2,0,152,122,6,0,1,0,0,0,33,48,216,0,96,82,2,0,192,72,6,0,1,0,0,0,32,48,216,0,32,56,2,0,152,31,6,0,1,0,0,0,36,48,216,0,152,30,2,0,248,97,5,0,1,0,0,0,37,48,216,0,232,10,2,0,120,36,5,0,1,0,0,0,38,48,216,0,152,138,8,0,152,6,5,0,1,0,0,0,39,48,216,0,48,119,7,0,40,246,1,0,1,0,0,0,213,47,216,0,64,246,1,0,144,236,1,0,1,0,0,0,209,47,216,0,136,224,1,0,176,223,1,0,1,0,0,0,43,48,216,0,72,198,1,0,192,209,1,0,1,0,0,0,42,48,216,0,24,182,1,0,24,198,1,0,1,0,0,0,41,48,216,0,40,167,1,0,120,189,1,0,1,0,0,0,40,48,216,0,200,149,1,0,8,182,1,0,1,0,0,0,44,48,216,0,56,126,1,0,32,167,1,0,1,0,0,0,45,48,216,0,32,101,1,0,128,149,1,0,1,0,0,0,46,48,216,0,96,32,8,0,136,140,1,0,1,0,0,0,47,48,216,0,16,68,7,0,168,132,8,0,1,0,0,0,214,47,216,0,232,209,1,0,72,126,8,0,1,0,0,0,210,47,216,0,144,189,1,0,192,122,8,0,1,0,0,0,251,47,216,0,208,174,1,0,40,116,8,0,1,0,0,0,250,47,216,0,48,160,1,0,72,110,8,0,1,0,0,0,249,47,216,0,160,140,1,0,184,102,8,0,1,0,0,0,248,47,216,0,56,112,1,0,248,93,8,0,1,0,0,0,252,47,216,0,32,92,1,0,152,86,8,0,1,0,0,0,253,47,216,0,64,77,1,0,64,76,8,0,1,0,0,0,254,47,216,0,112,157,4,0,168,70,8,0,1,0,0,0,255,47,216,0,176,194,6,0,232,23,8,0,1,0,0,0,215,47,216,0,104,195,5,0,160,19,8,0,1,0,0,0,211,47,216,0,32,245,8,0,248,16,8,0,1,0,0,0,3,48,216,0,32,231,8,0,192,12,8,0,1,0,0,0,2,48,216,0,88,214,8,0,224,5,8,0,1,0,0,0,1,48,216,0,224,202,8,0,144,1,8,0,1,0,0,0,0,48,216,0,72,193,8,0,96,250,7,0,1,0,0,0,4,48,216,0,144,180,8,0,120,241,7,0,1,0,0,0,5,48,216,0,208,164,8,0,88,230,7,0,1,0,0,0,6,48,216,0,160,152,4,0,112,226,7,0,1,0,0,0,7,48,216,0,40,184,6,0,88,212,3,0,1,0,0,0,144,46,216,0,40,185,3,0,240,152,1,0,1,0,0,0,201,47,216,0,216,70,1,0,16,17,8,0,1,0,0,0,202,47,216,0,224,12,8,0,136,67,2,0,1,0,0,0,176,48,216,0,112,109,7,0,8,66,2,0,1,0,0,0,184,48,216,0,24,133,7,0,101,112,114,45,49,52,49,53,50,46,97,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,113,181,199,105,1,0,16,1,101,112,114,45,49,52,49,53,51,46,97,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,12,174,31,224,1,0,16,1,109,112,114,45,49,52,49,51,57,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,49,21,195,6,1,0,16,1,109,112,114,45,49,52,49,52,49,46,97,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,75,73,10,8,1,0,16,1,101,112,114,45,49,52,49,50,55,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,136,205,40,34,2,0,32,0,101,112,114,45,49,52,49,50,56,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,16,142,186,237,2,0,32,0,101,112,114,45,49,52,49,50,57,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,5,195,236,232,2,0,32,0,109,112,114,45,49,52,49,51,52,46,99,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,75,106,218,79,3,0,32,0,109,112,114,45,49,52,49,52,50,46,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,42,31,191,60,3,0,32,0,109,112,114,45,49,52,49,51,53,46,99,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,118,72,199,233,3,0,32,0,109,112,114,45,49,52,49,52,51,46,97,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,49,44,2,89,3,0,32,0,109,112,114,45,49,52,49,51,54,46,99,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,88,152,13,114,3,0,32,0,109,112,114,45,49,52,49,52,52,46,97,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,212,253,117,119,3,0,32,0,101,112,114,45,49,52,49,51,55,46,99,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,101,66,108,132,3,0,32,0,101,112,114,45,49,52,49,52,53,46,97,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,151,199,118,14,3,0,32,0,101,112,114,45,49,52,49,51,51,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,101,102,249,207,4,0,16,1,109,112,114,45,49,52,49,51,50,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,32,2,174,31,19,0,64,0,109,112,114,45,49,52,49,51,49,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,11,125,90,190,19,0,64,0,101,112,114,45,49,52,49,51,48,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,161,52,143,148,19,0,64,0,51,49,55,45,48,49,56,54,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,253,241,202,122,5,0,16,1,35,0,0,0,255,255,255,0,0,0,0,0,36,0,0,0,255,255,247,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,35,0,0,0,1,15,7,0,80,252,6,0,35,0,0,0,1,15,8,0,16,242,7,0,35,0,0,0,1,15,9,0,104,236,7,0,35,0,0,0,1,15,5,0,176,51,4,0,35,0,0,0,1,15,4,0,56,24,4,0,35,0,0,0,1,15,15,0,128,230,7,0,35,0,0,0,1,15,1,0,72,216,3,0,35,0,0,0,1,15,2,0,24,188,3,0,35,0,0,0,1,15,3,0,176,162,3,0,35,0,0,0,1,15,6,0,120,211,6,0,35,0,0,0,1,15,14,0,184,164,6,0,35,0,0,0,1,15,13,0,80,74,6,0,35,0,0,0,1,15,12,0,192,32,6,0,35,0,0,0,1,15,11,0,192,234,2,0,35,0,0,0,1,15,10,0,32,242,5,0,35,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,35,0,0,0,1,240,112,0,80,252,6,0,35,0,0,0,1,240,128,0,16,242,7,0,35,0,0,0,1,240,144,0,104,236,7,0,35,0,0,0,1,240,80,0,176,51,4,0,35,0,0,0,1,240,64,0,56,24,4,0,35,0,0,0,1,240,240,0,128,230,7,0,35,0,0,0,1,240,16,0,72,216,3,0,35,0,0,0,1,240,32,0,24,188,3,0,35,0,0,0,1,240,48,0,176,162,3,0,35,0,0,0,1,240,96,0,120,211,6,0,35,0,0,0,1,240,224,0,184,164,6,0,35,0,0,0,1,240,208,0,80,74,6,0,35,0,0,0,1,240,192,0,192,32,6,0,35,0,0,0,1,240,176,0,192,234,2,0,35,0,0,0,1,240,160,0,32,242,5,0,35,0,0,0,1,240,0,0,208,236,2,0,0,0,0,0,254,0,2,0,192,32,3,0,36,0,0,0,1,1,1,0,184,30,3,0,36,0,0,0,1,1,0,0,0,28,3,0,0,0,0,0,254,0,2,0,80,208,6,0,36,0,0,0,1,2,2,0,136,204,6,0,36,0,0,0,1,2,0,0,96,201,6,0,0,0,0,0,254,0,2,0,8,93,1,0,36,0,0,0,1,4,4,0,136,86,1,0,36,0,0,0,1,4,0,0,232,78,1,0,0,0,0,0,254,0,2,0,168,234,7,0,36,0,0,0,1,8,8,0,96,135,7,0,36,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,4,0,8,198,6,0,36,0,0,0,1,48,48,0,32,195,6,0,36,0,0,0,1,48,32,0,88,190,6,0,36,0,0,0,1,48,16,0,224,184,6,0,36,0,0,0,1,48,0,0,160,178,6,0,0,0,0,0,254,0,4,0,72,202,5,0,36,0,0,0,1,192,128,0,80,246,3,0,36,0,0,0,1,192,192,0,248,38,7,0,36,0,0,0,1,192,64,0,112,212,3,0,36,0,0,0,1,192,0,0,248,160,5,0,101,112,114,45,49,52,49,53,48,46,97,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,25,107,134,252,1,0,16,1,101,112,114,45,49,52,49,53,49,46,97,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,228,63,210,70,1,0,16,1,109,112,114,45,49,52,49,51,57,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,49,21,195,6,1,0,16,1,109,112,114,45,49,52,49,52,49,46,97,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,75,73,10,8,1,0,16,1,101,112,114,45,49,52,49,50,55,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,136,205,40,34,2,0,32,0,101,112,114,45,49,52,49,50,56,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,16,142,186,237,2,0,32,0,101,112,114,45,49,52,49,50,57,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,5,195,236,232,2,0,32,0,109,112,114,45,49,52,49,51,52,46,99,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,75,106,218,79,3,0,32,0,109,112,114,45,49,52,49,52,50,46,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,42,31,191,60,3,0,32,0,109,112,114,45,49,52,49,51,53,46,99,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,118,72,199,233,3,0,32,0,109,112,114,45,49,52,49,52,51,46,97,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,49,44,2,89,3,0,32,0,109,112,114,45,49,52,49,51,54,46,99,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,88,152,13,114,3,0,32,0,109,112,114,45,49,52,49,52,52,46,97,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,212,253,117,119,3,0,32,0,101,112,114,45,49,52,49,51,55,46,99,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,101,66,108,132,3,0,32,0,101,112,114,45,49,52,49,52,53,46,97,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,151,199,118,14,3,0,32,0,101,112,114,45,49,52,49,51,51,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,101,102,249,207,4,0,16,1,109,112,114,45,49,52,49,51,50,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,32,2,174,31,19,0,64,0,109,112,114,45,49,52,49,51,49,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,11,125,90,190,19,0,64,0,101,112,114,45,49,52,49,51,48,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,161,52,143,148,19,0,64,0,51,49,55,45,48,49,56,53,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,6,181,80,166,5,0,16,1,101,112,114,45,49,52,49,52,56,46,97,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,207,176,76,223,1,0,16,1,101,112,114,45,49,52,49,52,57,46,97,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,24,248,15,56,1,0,16,1,109,112,114,45,49,52,49,51,57,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,49,21,195,6,1,0,16,1,109,112,114,45,49,52,49,52,49,46,97,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,75,73,10,8,1,0,16,1,101,112,114,45,49,52,49,50,55,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,136,205,40,34,2,0,32,0,101,112,114,45,49,52,49,50,56,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,16,142,186,237,2,0,32,0,101,112,114,45,49,52,49,50,57,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,5,195,236,232,2,0,32,0,109,112,114,45,49,52,49,51,52,46,99,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,75,106,218,79,3,0,32,0,109,112,114,45,49,52,49,52,50,46,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,42,31,191,60,3,0,32,0,109,112,114,45,49,52,49,51,53,46,99,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,118,72,199,233,3,0,32,0,109,112,114,45,49,52,49,52,51,46,97,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,49,44,2,89,3,0,32,0,109,112,114,45,49,52,49,51,54,46,99,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,88,152,13,114,3,0,32,0,109,112,114,45,49,52,49,52,52,46,97,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,212,253,117,119,3,0,32,0,101,112,114,45,49,52,49,51,55,46,99,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,101,66,108,132,3,0,32,0,101,112,114,45,49,52,49,52,53,46,97,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,151,199,118,14,3,0,32,0,101,112,114,45,49,52,49,51,51,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,101,102,249,207,4,0,16,1,109,112,114,45,49,52,49,51,50,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,32,2,174,31,19,0,64,0,109,112,114,45,49,52,49,51,49,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,11,125,90,190,19,0,64,0,101,112,114,45,49,52,49,51,48,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,161,52,143,148,19,0,64,0,51,49,55,45,48,49,56,52,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,84,98,224,206,5,0,16,1,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,247,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,19,0,0,0,1,15,7,0,80,252,6,0,19,0,0,0,1,15,8,0,16,242,7,0,19,0,0,0,1,15,9,0,104,236,7,0,19,0,0,0,1,15,5,0,176,51,4,0,19,0,0,0,1,15,4,0,56,24,4,0,19,0,0,0,1,15,15,0,128,230,7,0,19,0,0,0,1,15,1,0,72,216,3,0,19,0,0,0,1,15,2,0,24,188,3,0,19,0,0,0,1,15,3,0,176,162,3,0,19,0,0,0,1,15,6,0,120,211,6,0,19,0,0,0,1,15,14,0,184,164,6,0,19,0,0,0,1,15,13,0,80,74,6,0,19,0,0,0,1,15,12,0,192,32,6,0,19,0,0,0,1,15,11,0,192,234,2,0,19,0,0,0,1,15,10,0,32,242,5,0,19,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,19,0,0,0,1,240,112,0,80,252,6,0,19,0,0,0,1,240,128,0,16,242,7,0,19,0,0,0,1,240,144,0,104,236,7,0,19,0,0,0,1,240,80,0,176,51,4,0,19,0,0,0,1,240,64,0,56,24,4,0,19,0,0,0,1,240,240,0,128,230,7,0,19,0,0,0,1,240,16,0,72,216,3,0,19,0,0,0,1,240,32,0,24,188,3,0,19,0,0,0,1,240,48,0,176,162,3,0,19,0,0,0,1,240,96,0,120,211,6,0,19,0,0,0,1,240,224,0,184,164,6,0,19,0,0,0,1,240,208,0,80,74,6,0,19,0,0,0,1,240,192,0,192,32,6,0,19,0,0,0,1,240,176,0,192,234,2,0,19,0,0,0,1,240,160,0,32,242,5,0,19,0,0,0,1,240,0,0,208,236,2,0,0,0,0,0,254,0,2,0,192,32,3,0,20,0,0,0,1,1,1,0,184,30,3,0,20,0,0,0,1,1,0,0,0,28,3,0,0,0,0,0,254,0,2,0,80,208,6,0,20,0,0,0,1,2,2,0,136,204,6,0,20,0,0,0,1,2,0,0,96,201,6,0,0,0,0,0,254,0,2,0,8,93,1,0,20,0,0,0,1,4,4,0,136,86,1,0,20,0,0,0,1,4,0,0,232,78,1,0,0,0,0,0,254,0,2,0,168,234,7,0,20,0,0,0,1,8,8,0,96,135,7,0,20,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,4,0,8,198,6,0,20,0,0,0,1,48,48,0,32,195,6,0,20,0,0,0,1,48,32,0,88,190,6,0,20,0,0,0,1,48,16,0,224,184,6,0,20,0,0,0,1,48,0,0,160,178,6,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,192,128,0,80,246,3,0,20,0,0,0,1,192,192,0,248,38,7,0,20,0,0,0,1,192,64,0,112,212,3,0,20,0,0,0,1,192,0,0,248,160,5,0,101,112,114,45,49,52,49,53,52,46,97,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,240,173,13,154,1,0,16,1,101,112,114,45,49,52,49,53,53,46,97,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,244,98,67,231,1,0,16,1,109,112,114,45,49,52,49,51,57,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,49,21,195,6,1,0,16,1,109,112,114,45,49,52,49,52,49,46,97,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,75,73,10,8,1,0,16,1,101,112,114,45,49,52,49,50,55,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,136,205,40,34,2,0,32,0,101,112,114,45,49,52,49,50,56,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,16,142,186,237,2,0,32,0,101,112,114,45,49,52,49,50,57,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,5,195,236,232,2,0,32,0,109,112,114,45,49,52,49,51,52,46,99,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,75,106,218,79,3,0,32,0,109,112,114,45,49,52,49,52,50,46,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,42,31,191,60,3,0,32,0,109,112,114,45,49,52,49,51,53,46,99,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,118,72,199,233,3,0,32,0,109,112,114,45,49,52,49,52,51,46,97,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,49,44,2,89,3,0,32,0,109,112,114,45,49,52,49,51,54,46,99,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,88,152,13,114,3,0,32,0,109,112,114,45,49,52,49,52,52,46,97,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,212,253,117,119,3,0,32,0,101,112,114,45,49,52,49,51,55,46,99,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,101,66,108,132,3,0,32,0,101,112,114,45,49,52,49,52,53,46,97,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,151,199,118,14,3,0,32,0,101,112,114,45,49,52,49,51,51,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,101,102,249,207,4,0,16,1,109,112,114,45,49,52,49,51,50,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,32,2,174,31,19,0,64,0,109,112,114,45,49,52,49,51,49,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,11,125,90,190,19,0,64,0,101,112,114,45,49,52,49,51,48,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,161,52,143,148,19,0,64,0,51,49,55,45,48,49,56,55,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,190,96,251,29,5,0,16,1,99,55,56,95,52,57,45,49,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,49,198,240,166,2,0,16,1,99,55,56,95,53,49,45,49,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,59,232,36,239,2,0,16,1,99,55,56,95,53,48,45,49,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,244,64,4,139,2,0,16,1,99,55,56,95,53,51,45,49,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,99,23,185,43,2,0,16,1,99,55,56,45,51,48,45,49,46,51,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,24,172,106,2,6,0,16,1,99,55,56,45,51,49,45,49,46,51,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,232,35,206,103,6,0,16,1,99,55,56,45,51,52,46,99,52,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,67,105,24,242,9,0,16,1,99,55,56,45,49,48,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,124,137,177,68,12,0,32,0,99,55,56,45,49,49,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,163,212,179,125,12,0,32,0,99,55,56,45,48,56,46,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,17,82,114,108,17,0,32,0,99,55,56,45,48,55,46,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,91,13,160,157,17,0,32,0,99,55,56,45,48,54,46,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,27,233,9,131,17,0,32,0,99,55,56,45,48,53,46,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,104,31,0,144,17,0,32,0,99,55,56,45,48,57,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,245,230,189,13,22,0,32,0,99,55,56,45,48,52,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,124,163,26,204,23,0,32,0,99,55,56,45,49,50,46,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,4,116,38,176,24,0,64,0,99,55,56,45,49,51,46,52,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,162,58,54,27,24,0,64,0,99,55,56,45,49,52,46,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,251,77,173,156,25,0,64,0,99,55,56,45,50,53,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,246,166,69,114,0,0,0,8,99,55,56,45,49,53,46,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,48,31,248,251,0,0,0,8,99,55,56,45,50,49,46,55,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,39,191,38,41,0,0,0,8,99,56,52,45,49,48,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,252,139,62,100,0,0,0,8,99,56,52,45,49,49,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,83,136,114,16,0,0,0,8,13,0,0,0,255,255,255,0,0,0,0,0,14,0,0,0,255,255,251,0,0,0,0,0,0,0,0,0,254,0,2,0,56,178,6,0,13,0,0,0,1,2,2,0,248,38,7,0,13,0,0,0,1,2,0,0,144,172,6,0,0,0,0,0,254,0,2,0,232,75,4,0,13,0,0,0,1,4,4,0,96,135,7,0,13,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,13,0,0,0,1,8,0,0,96,135,7,0,13,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,13,0,0,0,1,48,16,0,104,236,7,0,13,0,0,0,1,48,48,0,128,230,7,0,13,0,0,0,1,48,0,0,120,211,6,0,13,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,13,0,0,0,1,192,64,0,104,236,7,0,13,0,0,0,1,192,192,0,128,230,7,0,13,0,0,0,1,192,0,0,120,211,6,0,13,0,0,0,1,192,128,0,184,164,6,0,0,0,0,0,254,0,4,0,72,202,5,0,14,0,0,0,1,3,2,0,80,246,3,0,14,0,0,0,1,3,3,0,248,38,7,0,14,0,0,0,1,3,1,0,112,212,3,0,14,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,2,0,240,165,6,0,14,0,0,0,1,4,0,0,96,135,7,0,14,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,254,0,2,0,72,161,6,0,14,0,0,0,1,8,8,0,120,76,7,0,14,0,0,0,1,8,0,0,240,72,7,0,0,0,0,0,254,0,2,0,32,158,6,0,14,0,0,0,1,16,16,0,248,38,7,0,14,0,0,0,1,16,0,0,144,172,6,0,0,0,0,0,29,0,0,0,255,255,255,0,0,0,0,0,30,0,0,0,255,255,94,0,0,0,0,0,31,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,16,0,32,4,2,0,29,0,0,0,1,15,2,0,80,252,6,0,29,0,0,0,1,15,5,0,16,242,7,0,29,0,0,0,1,15,8,0,104,236,7,0,29,0,0,0,1,15,4,0,120,113,6,0,29,0,0,0,1,15,1,0,232,228,5,0,29,0,0,0,1,15,15,0,128,230,7,0,29,0,0,0,1,15,3,0,56,141,7,0,29,0,0,0,1,15,7,0,120,211,6,0,29,0,0,0,1,15,14,0,184,164,6,0,29,0,0,0,1,15,6,0,24,1,7,0,29,0,0,0,1,15,13,0,80,74,6,0,29,0,0,0,1,15,12,0,192,32,6,0,29,0,0,0,1,15,11,0,192,234,2,0,29,0,0,0,1,15,10,0,32,242,5,0,29,0,0,0,1,15,9,0,176,192,2,0,29,0,0,0,1,15,0,0,224,170,7,0,0,0,0,0,254,0,4,0,128,129,4,0,30,0,0,0,1,3,3,0,208,75,4,0,30,0,0,0,1,3,2,0,8,49,4,0,30,0,0,0,1,3,1,0,72,246,3,0,30,0,0,0,1,3,0,0,64,47,7,0,0,0,0,0,254,0,4,0,72,202,5,0,30,0,0,0,1,96,96,0,80,246,3,0,30,0,0,0,1,96,64,0,248,38,7,0,30,0,0,0,1,96,32,0,48,123,8,0,30,0,0,0,1,96,0,0,8,117,8,0,0,0,0,0,254,0,2,0,168,234,7,0,30,0,0,0,1,128,128,0,96,135,7,0,30,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,31,0,0,0,1,1,1,0,96,135,7,0,31,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,31,0,0,0,1,4,4,0,96,135,7,0,31,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,97,57,54,45,50,57,46,49,56,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,43,22,117,247,2,0,16,1,97,57,54,45,50,56,46,49,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,103,214,33,71,2,0,16,1,97,57,54,95,51,49,46,49,56,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,137,93,187,233,2,0,16,1,97,57,54,95,51,48,46,49,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,39,225,181,158,2,0,16,1,97,57,54,45,51,51,46,49,57,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,210,64,243,210,6,0,16,1,97,57,54,45,51,50,46,49,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,72,152,76,4,6,0,16,1,97,57,54,45,51,53,46,49,57,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,139,113,237,184,6,0,16,1,97,57,54,45,51,52,46,49,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,96,166,86,117,6,0,16,1,97,57,54,95,53,55,46,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,48,183,206,51,9,0,16,1,97,57,54,95,53,54,46,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,92,245,46,41,10,0,16,1,97,57,54,95,52,56,46,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,170,179,201,57,12,0,32,0,97,57,54,95,53,49,46,52,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,211,240,248,27,12,0,32,0,97,57,54,95,52,57,46,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,138,216,167,55,12,0,32,0,97,57,54,95,53,50,46,52,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,40,33,155,45,12,0,32,0,97,57,54,95,53,48,46,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,228,56,215,117,12,0,32,0,97,57,54,95,53,51,46,52,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,76,72,115,1,12,0,32,0,97,57,54,95,53,52,46,49,52,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,226,42,192,81,14,0,32,0,97,57,54,95,53,53,46,49,52,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,152,77,30,119,14,0,32,0,97,57,54,95,52,52,46,49,55,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,120,136,193,187,17,0,32,0,97,57,54,95,52,53,46,50,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,139,221,108,97,17,0,32,0,97,57,54,95,52,54,46,49,56,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,24,84,195,254,17,0,32,0,97,57,54,95,52,55,46,50,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,106,40,249,141,17,0,32,0,97,57,54,95,52,48,46,49,55,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,30,165,153,182,17,0,32,0,97,57,54,95,52,49,46,49,57,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,58,138,18,151,17,0,32,0,97,57,54,95,52,50,46,49,55,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,15,238,85,127,17,0,32,0,97,57,54,95,52,51,46,49,57,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,105,212,202,199,17,0,32,0,97,57,54,95,51,54,46,49,55,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,65,129,89,175,17,0,32,0,97,57,54,95,51,55,46,49,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,200,55,129,180,17,0,32,0,97,57,54,95,51,56,46,49,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,167,227,243,228,17,0,32,0,97,57,54,95,51,57,46,49,57,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,15,146,48,234,17,0,32,0,97,57,54,45,50,52,46,49,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,127,190,168,15,0,0,0,8,97,57,54,45,50,53,46,49,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,166,8,85,38,0,0,0,8,97,57,54,45,50,54,46,49,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,192,185,145,72,0,0,0,8,97,57,54,95,50,57,45,49,46,49,56,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,98,111,72,117,2,0,16,1,97,57,54,95,50,56,45,49,46,49,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,212,52,251,2,0,16,1,97,57,54,95,51,49,46,49,56,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,137,93,187,233,2,0,16,1,97,57,54,95,51,48,46,49,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,39,225,181,158,2,0,16,1,97,57,54,95,51,51,45,49,46,49,57,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,72,96,24,255,6,0,16,1,97,57,54,95,51,50,45,49,46,49,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,232,157,113,217,6,0,16,1,97,57,54,95,51,53,45,49,46,49,57,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,147,1,40,179,6,0,16,1,97,57,54,95,51,52,45,49,46,49,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,115,37,59,202,6,0,16,1,97,57,54,95,53,55,46,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,48,183,206,51,9,0,16,1,97,57,54,95,53,54,46,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,92,245,46,41,10,0,16,1,97,57,54,95,52,56,46,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,170,179,201,57,12,0,32,0,97,57,54,95,53,49,46,52,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,211,240,248,27,12,0,32,0,97,57,54,95,52,57,46,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,138,216,167,55,12,0,32,0,97,57,54,95,53,50,46,52,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,40,33,155,45,12,0,32,0,97,57,54,95,53,48,46,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,228,56,215,117,12,0,32,0,97,57,54,95,53,51,46,52,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,76,72,115,1,12,0,32,0,97,57,54,95,53,52,46,49,52,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,226,42,192,81,14,0,32,0,97,57,54,95,53,53,46,49,52,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,152,77,30,119,14,0,32,0,97,57,54,95,52,52,46,49,55,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,120,136,193,187,17,0,32,0,97,57,54,95,52,53,46,50,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,139,221,108,97,17,0,32,0,97,57,54,95,52,54,46,49,56,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,24,84,195,254,17,0,32,0,97,57,54,95,52,55,46,50,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,106,40,249,141,17,0,32,0,97,57,54,95,52,48,46,49,55,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,30,165,153,182,17,0,32,0,97,57,54,95,52,49,46,49,57,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,58,138,18,151,17,0,32,0,97,57,54,95,52,50,46,49,55,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,15,238,85,127,17,0,32,0,97,57,54,95,52,51,46,49,57,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,105,212,202,199,17,0,32,0,97,57,54,95,51,54,46,49,55,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,65,129,89,175,17,0,32,0,97,57,54,95,51,55,46,49,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,200,55,129,180,17,0,32,0,97,57,54,95,51,56,46,49,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,167,227,243,228,17,0,32,0,97,57,54,95,51,57,46,49,57,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,15,146,48,234,17,0,32,0,97,57,54,45,50,52,46,49,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,127,190,168,15,0,0,0,8,97,57,54,45,50,53,46,49,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,166,8,85,38,0,0,0,8,97,57,54,45,50,54,46,49,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,192,185,145,72,0,0,0,8,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,96,19,7,0,19,0,0,0,1,2,2,0,248,38,7,0,19,0,0,0,1,2,0,0,176,64,8,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,4,4,0,96,135,7,0,19,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0])
.concat([1,8,0,0,96,135,7,0,19,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,19,0,0,0,1,48,16,0,104,236,7,0,19,0,0,0,1,48,48,0,128,230,7,0,19,0,0,0,1,48,0,0,120,211,6,0,19,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,19,0,0,0,1,192,64,0,104,236,7,0,19,0,0,0,1,192,192,0,128,230,7,0,19,0,0,0,1,192,0,0,120,211,6,0,19,0,0,0,1,192,128,0,184,164,6,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,3,2,0,80,246,3,0,20,0,0,0,1,3,3,0,80,124,6,0,20,0,0,0,1,3,1,0,112,212,3,0,20,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,64,37,5,0,20,0,0,0,1,12,8,0,104,2,7,0,20,0,0,0,1,12,12,0,136,252,6,0,20,0,0,0,1,12,4,0,192,248,6,0,20,0,0,0,1,12,0,0,120,7,5,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,48,48,0,8,49,4,0,20,0,0,0,1,48,32,0,152,21,4,0,20,0,0,0,1,48,16,0,72,246,3,0,20,0,0,0,1,48,0,0,72,0,3,0,100,97,101,45,54,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,39,17,114,237,2,0,16,1,100,97,101,45,54,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,140,234,154,185,2,0,16,1,100,97,101,45,55,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,49,11,89,84,2,0,16,1,97,57,54,95,51,48,46,49,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,39,225,181,158,2,0,16,1,100,97,101,45,55,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,204,162,140,36,6,0,16,1,100,97,101,45,55,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,3,4,221,101,6,0,16,1,100,97,101,45,55,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,96,31,163,14,6,0,16,1,100,97,101,45,55,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,77,106,3,39,6,0,16,1,97,57,54,95,53,55,46,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,48,183,206,51,9,0,16,1,97,57,54,95,53,54,46,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,92,245,46,41,10,0,16,1,97,57,54,95,52,56,46,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,170,179,201,57,12,0,32,0,97,57,54,95,53,49,46,52,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,211,240,248,27,12,0,32,0,97,57,54,95,52,57,46,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,138,216,167,55,12,0,32,0,97,57,54,95,53,50,46,52,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,40,33,155,45,12,0,32,0,97,57,54,95,53,48,46,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,228,56,215,117,12,0,32,0,97,57,54,95,53,51,46,52,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,76,72,115,1,12,0,32,0,97,57,54,95,53,52,46,49,52,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,226,42,192,81,14,0,32,0,97,57,54,95,53,53,46,49,52,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,152,77,30,119,14,0,32,0,97,57,54,95,52,52,46,49,55,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,120,136,193,187,17,0,32,0,97,57,54,95,52,53,46,50,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,139,221,108,97,17,0,32,0,97,57,54,95,52,54,46,49,56,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,24,84,195,254,17,0,32,0,97,57,54,95,52,55,46,50,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,106,40,249,141,17,0,32,0,97,57,54,95,52,48,46,49,55,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,30,165,153,182,17,0,32,0,97,57,54,95,52,49,46,49,57,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,58,138,18,151,17,0,32,0,97,57,54,95,52,50,46,49,55,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,15,238,85,127,17,0,32,0,97,57,54,95,52,51,46,49,57,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,105,212,202,199,17,0,32,0,97,57,54,95,51,54,46,49,55,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,65,129,89,175,17,0,32,0,97,57,54,95,51,55,46,49,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,200,55,129,180,17,0,32,0,97,57,54,95,51,56,46,49,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,167,227,243,228,17,0,32,0,97,57,54,95,51,57,46,49,57,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,15,146,48,234,17,0,32,0,97,57,54,45,50,52,46,49,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,127,190,168,15,0,0,0,8,97,57,54,45,50,53,46,49,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,166,8,85,38,0,0,0,8,97,57,54,45,50,54,46,49,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,192,185,145,72,0,0,0,8,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,96,19,7,0,19,0,0,0,1,2,2,0,248,38,7,0,19,0,0,0,1,2,0,0,176,64,8,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,4,4,0,96,135,7,0,19,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,8,0,0,96,135,7,0,19,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,19,0,0,0,1,48,16,0,104,236,7,0,19,0,0,0,1,48,48,0,128,230,7,0,19,0,0,0,1,48,0,0,120,211,6,0,19,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,19,0,0,0,1,192,64,0,104,236,7,0,19,0,0,0,1,192,192,0,128,230,7,0,19,0,0,0,1,192,0,0,120,211,6,0,19,0,0,0,1,192,128,0,184,164,6,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,3,2,0,80,246,3,0,20,0,0,0,1,3,3,0,80,124,6,0,20,0,0,0,1,3,1,0,112,212,3,0,20,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,64,37,5,0,20,0,0,0,1,12,8,0,104,2,7,0,20,0,0,0,1,12,12,0,136,252,6,0,20,0,0,0,1,12,4,0,192,248,6,0,20,0,0,0,1,12,0,0,120,7,5,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,48,48,0,8,49,4,0,20,0,0,0,1,48,32,0,152,21,4,0,20,0,0,0,1,48,16,0,72,246,3,0,20,0,0,0,1,48,0,0,72,0,3,0,0,0,0,0,254,0,2,0,104,159,3,0,20,0,0,0,1,128,0,0,96,135,7,0,20,0,0,0,1,128,128,0,152,182,7,0,0,0,0,0,99,48,55,45,51,50,45,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,106,143,108,33,2,0,16,1,99,48,55,45,50,57,45,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,127,86,222,72,2,0,16,1,99,48,55,45,51,49,45,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,248,210,121,130,2,0,16,1,99,48,55,45,51,48,45,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,228,34,97,2,0,16,1,99,48,55,45,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,108,123,111,10,2,0,16,1,99,48,55,45,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,206,64,159,5,2,0,16,1,99,48,55,45,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,66,18,65,31,2,0,16,1,99,48,55,45,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,32,156,108,72,2,0,16,1,99,48,55,45,51,53,45,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,35,71,140,221,6,0,16,1,99,48,55,45,51,56,45,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,92,184,175,70,6,0,16,1,99,48,55,45,51,52,45,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,184,132,105,41,6,0,16,1,99,48,55,45,51,55,45,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,31,70,125,139,6,0,16,1,99,48,55,45,51,51,45,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,63,58,160,45,6,0,16,1,99,48,55,45,51,54,45,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,28,43,207,2,6,0,16,1,99,48,55,45,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,197,75,48,218,9,0,16,1,99,48,55,45,48,51,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,206,175,155,24,11,0,32,0,99,48,55,45,48,52,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,129,30,66,80,11,0,32,0,99,48,55,45,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,80,240,240,60,15,0,32,0,99,48,55,45,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,75,109,209,117,15,0,32,0,99,48,55,45,49,48,46,57,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,217,14,190,75,24,0,64,0,99,48,55,45,49,49,46,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,153,86,129,60,24,0,64,0,99,48,55,45,49,50,46,49,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,88,18,183,224,25,0,64,0,20,0,0,0,255,255,254,0,0,0,0,0,21,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,96,19,7,0,20,0,0,0,1,2,2,0,248,38,7,0,20,0,0,0,1,2,0,0,176,64,8,0,0,0,0,0,254,0,2,0,232,75,4,0,20,0,0,0,1,4,4,0,96,135,7,0,20,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,20,0,0,0,1,8,0,0,96,135,7,0,20,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,20,0,0,0,1,48,16,0,104,236,7,0,20,0,0,0,1,48,48,0,128,230,7,0,20,0,0,0,1,48,0,0,120,211,6,0,20,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,20,0,0,0,1,192,64,0,104,236,7,0,20,0,0,0,1,192,192,0,128,230,7,0,20,0,0,0,1,192,0,0,120,211,6,0,20,0,0,0,1,192,128,0,184,164,6,0,0,0,0,0,254,0,4,0,72,202,5,0,21,0,0,0,1,3,2,0,80,246,3,0,21,0,0,0,1,3,3,0,80,124,6,0,21,0,0,0,1,3,1,0,112,212,3,0,21,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,64,37,5,0,21,0,0,0,1,12,12,0,184,174,8,0,21,0,0,0,1,12,8,0,176,165,8,0,21,0,0,0,1,12,4,0,136,156,8,0,21,0,0,0,1,12,0,0,16,150,8,0,0,0,0,0,254,0,4,0,128,129,4,0,21,0,0,0,1,48,48,0,8,49,4,0,21,0,0,0,1,48,32,0,152,21,4,0,21,0,0,0,1,48,16,0,72,246,3,0,21,0,0,0,1,48,0,0,72,0,3,0,0,0,0,0,254,0,2,0,144,246,3,0,21,0,0,0,1,64,64,0,96,135,7,0,21,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,21,0,0,0,1,128,0,0,96,135,7,0,21,0,0,0,1,128,128,0,152,182,7,0,168,86,7,0,1,0,0,0,136,239,146,0,248,191,2,0,24,38,7,0,1,0,0,0,223,254,146,0,184,160,2,0,56,210,6,0,1,0,0,0,218,254,146,0,192,135,2,0,24,163,6,0,1,0,0,0,219,254,146,0,240,108,2,0,152,122,6,0,1,0,0,0,216,254,146,0,96,82,2,0,192,72,6,0,1,0,0,0,217,254,146,0,32,56,2,0,200,110,3,0,1,0,0,0,220,254,146,0,152,30,2,0,120,89,3,0,1,0,0,0,221,254,146,0,232,10,2,0,120,74,3,0,1,0,0,0,222,254,146,0,152,138,8,0,192,61,3,0,1,0,0,0,40,237,146,0,48,119,7,0,120,194,6,0,1,0,0,0,41,237,146,0,112,109,7,0,96,189,6,0,1,0,0,0,42,237,146,0,24,133,7,0,40,246,1,0,1,0,0,0,137,239,146,0,64,246,1,0,144,236,1,0,1,0,0,0,127,246,146,0,136,224,1,0,176,223,1,0,1,0,0,0,122,246,146,0,72,198,1,0,192,209,1,0,1,0,0,0,123,246,146,0,24,182,1,0,24,198,1,0,1,0,0,0,120,246,146,0,40,167,1,0,120,189,1,0,1,0,0,0,121,246,146,0,200,149,1,0,224,22,1,0,1,0,0,0,124,246,146,0,56,126,1,0,160,14,1,0,1,0,0,0,125,246,146,0,32,101,1,0,176,9,1,0,1,0,0,0,126,246,146,0,96,32,8,0,200,3,1,0,1,0,0,0,43,237,146,0,16,68,7,0,208,183,6,0,1,0,0,0,44,237,146,0,240,58,7,0,200,177,6,0,1,0,0,0,45,237,146,0,200,42,1,0,88,212,3,0,1,0,0,0,160,218,146,0,40,185,3,0,16,17,8,0,1,0,0,0,138,239,146,0,224,12,8,0,72,65,1,0,9,0,0,0,48,5,147,0,32,58,1,0,48,50,1,0,9,0,0,0,49,5,147,0,32,58,1,0,224,41,1,0,9,0,0,0,50,5,147,0,32,58,1,0,99,121,98,117,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,244,168,77,219,1,0,16,1,99,121,98,117,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,172,104,236,30,1,0,16,1,99,121,98,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,142,64,64,236,1,0,16,1,99,121,98,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,210,190,208,26,1,0,16,1,99,121,98,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,154,163,69,98,1,0,16,1,99,121,98,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,35,226,72,75,1,0,16,1,99,121,98,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,56,82,225,1,0,16,1,99,121,98,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,59,0,244,117,1,0,16,1,99,121,98,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,146,225,220,240,5,0,32,0,99,121,98,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,156,163,122,24,5,0,32,0,99,121,98,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,18,75,14,138,5,0,32,0,99,121,98,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,18,38,182,52,5,0,32,0,99,121,98,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,87,121,83,193,5,0,32,0,99,121,98,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,134,158,52,21,5,0,32,0,99,121,98,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,125,151,62,216,5,0,32,0,99,121,98,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,92,173,205,119,5,0,32,0,99,121,98,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,121,176,15,156,10,0,16,1,99,121,98,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,78,12,203,81,10,0,16,1,99,121,98,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,178,202,44,54,12,0,64,0,99,121,98,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,204,233,102,112,12,0,64,0,99,121,98,106,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,218,234,150,96,1,0,16,1,99,121,98,106,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,169,250,15,123,1,0,16,1,99,121,98,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,142,64,64,236,1,0,16,1,99,121,98,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,210,190,208,26,1,0,16,1,99,121,98,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,154,163,69,98,1,0,16,1,99,121,98,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,35,226,72,75,1,0,16,1,99,121,98,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,56,82,225,1,0,16,1,99,121,98,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,59,0,244,117,1,0,16,1,99,121,98,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,146,225,220,240,5,0,32,0,99,121,98,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,156,163,122,24,5,0,32,0,99,121,98,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,18,75,14,138,5,0,32,0,99,121,98,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,18,38,182,52,5,0,32,0,99,121,98,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,87,121,83,193,5,0,32,0,99,121,98,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,134,158,52,21,5,0,32,0,99,121,98,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,125,151,62,216,5,0,32,0,99,121,98,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,92,173,205,119,5,0,32,0,99,121,98,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,121,176,15,156,10,0,16,1,99,121,98,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,78,12,203,81,10,0,16,1,99,121,98,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,178,202,44,54,12,0,64,0,99,121,98,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,204,233,102,112,12,0,64,0,50,56,106,49,54,45,48,50,46,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,104,133,139,101,0,0,16,1,50,56,106,49,53,45,49,50,46,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,231,199,170,80,0,0,16,1,50,56,106,49,55,45,48,46,49,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,189,109,44,140,0,0,16,1,50,56,106,49,48,45,48,46,56,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,19,222,70,67,0,0,16,1,50,56,106,55,45,48,46,105,99,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,241,115,183,168,0,0,32,0,50,56,106,54,45,48,46,105,99,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,252,48,117,97,0,0,32,0,50,56,106,53,45,48,46,105,99,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,33,168,240,206,0,0,32,0,50,56,106,52,45,48,46,105,99,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,9,218,79,184,0,0,32,0,50,56,106,51,45,48,46,105,99,55,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,164,194,26,0,0,32,0,50,56,106,49,52,45,48,46,54,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,10,5,105,104,0,0,32,0,50,56,106,50,45,48,46,105,99,55,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,7,103,121,140,0,0,32,0,50,56,106,49,51,45,48,46,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,234,221,138,139,0,0,32,0,50,56,106,49,45,48,46,105,99,57,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,189,173,155,28,0,0,32,0,50,56,106,49,50,45,48,46,56,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,28,4,43,66,0,0,32,0,50,56,106,48,45,48,46,105,99,57,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,158,196,115,186,0,0,32,0,50,56,106,49,49,45,48,46,56,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,91,28,57,74,0,0,32,0,50,56,106,57,45,48,46,105,99,56,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,74,127,42,249,0,0,64,0,50,56,106,56,45,48,46,105,99,56,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,57,11,58,26,0,0,64,0,50,56,46,105,99,52,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,239,41,67,150,0,0,32,0,99,116,95,101,112,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,127,153,250,156,0,0,16,1,99,116,95,101,112,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,129,134,206,46,0,0,16,1,99,116,95,101,112,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,189,109,44,140,0,0,16,1,99,116,95,101,112,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,19,222,70,67,0,0,16,1,99,116,95,109,114,55,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,241,115,183,168,0,0,32,0,99,116,95,109,114,54,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,252,48,117,97,0,0,32,0,99,116,95,109,114,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,33,168,240,206,0,0,32,0,99,116,95,109,114,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,9,218,79,184,0,0,32,0,99,116,95,109,114,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,164,194,26,0,0,32,0,99,116,95,101,112,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,219,173,47,151,0,0,32,0,99,116,95,109,114,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,7,103,121,140,0,0,32,0,99,116,95,101,112,54,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,116,179,58,235,0,0,32,0,99,116,95,109,114,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,189,173,155,28,0,0,32,0,99,116,95,101,112,55,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,151,172,2,198,0,0,32,0,99,116,95,109,114,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,158,196,115,186,0,0,32,0,99,116,95,101,112,56,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,229,216,161,77,0,0,32,0,99,116,95,109,114,56,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,190,166,99,153,0,0,64,0,49,95,50,56,97,49,54,45,50,46,105,99,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,67,132,15,240,0,0,16,1,49,95,50,56,97,49,53,45,50,46,105,99,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,159,7,112,221,0,0,16,1,50,56,106,49,55,45,48,46,49,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,189,109,44,140,0,0,16,1,50,56,97,49,48,45,48,46,105,99,56,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,19,222,70,67,0,0,16,1,50,56,106,55,45,48,46,105,99,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,241,115,183,168,0,0,32,0,50,56,106,54,45,48,46,105,99,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,252,48,117,97,0,0,32,0,50,56,106,53,45,48,46,105,99,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,33,168,240,206,0,0,32,0,50,56,106,52,45,48,46,105,99,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,9,218,79,184,0,0,32,0,50,56,106,51,45,48,46,105,99,55,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,164,194,26,0,0,32,0,50,56,97,49,52,45,48,46,105,99,54,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,219,173,47,151,0,0,32,0,50,56,106,50,45,48,46,105,99,55,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,7,103,121,140,0,0,32,0,50,56,97,49,51,45,48,46,105,99,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,116,179,58,235,0,0,32,0,50,56,106,49,45,48,46,105,99,57,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,189,173,155,28,0,0,32,0,50,56,97,49,50,45,48,46,105,99,56,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,151,172,2,198,0,0,32,0,50,56,106,48,45,48,46,105,99,57,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,158,196,115,186,0,0,32,0,50,56,97,49,49,45,48,46,105,99,56,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,229,216,161,77,0,0,32,0,50,56,106,57,45,48,46,105,99,56,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,74,127,42,249,0,0,64,0,50,56,106,56,45,48,46,105,99,56,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,57,11,58,26,0,0,64,0,50,56,46,105,99,52,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,239,41,67,150,0,0,32,0,17,0,0,0,255,255,127,0,0,0,0,0,18,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,200,87,7,0,17,0,0,0,1,3,0,0,88,154,8,0,17,0,0,0,1,3,1,0,200,92,8,0,17,0,0,0,1,3,3,0,56,37,8,0,17,0,0,0,1,3,2,0,96,240,7,0,0,0,0,0,254,0,4,0,160,123,6,0,17,0,0,0,1,12,0,0,88,154,8,0,17,0,0,0,1,12,4,0,200,92,8,0,17,0,0,0,1,12,12,0,56,37,8,0,17,0,0,0,1,12,8,0,96,240,7,0,0,0,0,0,254,0,2,0,168,234,7,0,17,0,0,0,1,32,0,0,96,135,7,0,17,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,17,0,0,0,1,64,64,0,96,135,7,0,17,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,200,30,2,0,17,0,0,0,1,128,0,0,120,97,1,0,17,0,0,0,1,128,128,0,96,19,1,0,0,0,0,0,254,0,4,0,128,129,4,0,18,0,0,0,1,3,1,0,192,255,2,0,18,0,0,0,1,3,3,0,8,49,4,0,18,0,0,0,1,3,2,0,72,246,3,0,18,0,0,0,1,3,0,0,48,176,2,0,0,0,0,0,254,0,4,0,72,202,5,0,18,0,0,0,1,12,4,0,80,246,3,0,18,0,0,0,1,12,12,0,248,38,7,0,18,0,0,0,1,12,8,0,112,212,3,0,18,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,2,0,104,159,3,0,18,0,0,0,1,16,0,0,56,111,3,0,18,0,0,0,1,16,16,0,104,134,3,0,99,115,99,106,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,162,218,77,236,1,0,16,1,99,115,99,106,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,187,50,198,96,1,0,16,1,99,115,99,106,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,3,32,4,173,1,0,16,1,99,115,99,106,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,64,77,158,22,1,0,16,1,99,115,99,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,170,92,176,1,1,0,16,1,99,115,99,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,250,74,144,232,5,0,32,0,99,115,99,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,121,128,140,201,5,0,32,0,99,115,99,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,90,223,48,192,5,0,32,0,99,115,99,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,99,88,229,180,5,0,32,0,99,115,99,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,17,33,22,238,10,0,16,1,99,115,99,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,39,184,39,160,12,0,64,0,99,115,99,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,85,110,127,203,12,0,64,0,99,115,99,104,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,109,228,215,13,1,0,16,1,99,115,99,104,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,67,129,110,72,1,0,16,1,99,115,99,104,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,251,157,80,158,1,0,16,1,99,115,99,104,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,19,163,123,129,1,0,16,1,99,115,99,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,170,92,176,1,1,0,16,1,99,115,99,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,250,74,144,232,5,0,32,0,99,115,99,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,121,128,140,201,5,0,32,0,99,115,99,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,90,223,48,192,5,0,32,0,99,115,99,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,99,88,229,180,5,0,32,0,99,115,99,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,17,33,22,238,10,0,16,1,99,115,99,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,39,184,39,160,12,0,64,0,99,115,99,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,85,110,127,203,12,0,64,0,99,115,99,97,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,8,215,172,182,1,0,16,1,99,115,99,97,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,95,227,74,212,1,0,16,1,99,115,99,97,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,106,167,141,1,0,16,1,99,115,99,97,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,238,177,183,161,1,0,16,1,99,115,99,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,170,92,176,1,1,0,16,1,99,115,99,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,250,74,144,232,5,0,32,0,99,115,99,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,121,128,140,201,5,0,32,0,99,115,99,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,90,223,48,192,5,0,32,0,99,115,99,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,99,88,229,180,5,0,32,0,99,115,99,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,17,33,22,238,10,0,16,1,99,115,99,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,39,184,39,160,12,0,64,0,99,115,99,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,85,110,127,203,12,0,64,0,99,115,99,101,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,239,82,200,242,1,0,16,1,99,115,99,101,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,15,83,132,17,1,0,16,1,99,115,99,101,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,107,43,78,128,1,0,16,1,99,115,99,101,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,185,124,39,9,1,0,16,1,99,115,99,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,170,92,176,1,1,0,16,1,99,115,99,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,250,74,144,232,5,0,32,0,99,115,99,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,121,128,140,201,5,0,32,0,99,115,99,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,90,223,48,192,5,0,32,0,99,115,99,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,99,88,229,180,5,0,32,0,99,115,99,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,17,33,22,238,10,0,16,1,99,115,99,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,39,184,39,160,12,0,64,0,99,115,99,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,85,110,127,203,12,0,64,0,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,208,19,6,0,19,0,0,0,1,1,1,0,224,16,6,0,19,0,0,0,1,1,0,0,160,12,6,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,2,2,0,96,135,7,0,19,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,4,4,0,96,135,7,0,19,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,8,0,0,96,135,7,0,19,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,32,4,2,0,19,0,0,0,1,48,0,0,32,136,7,0,19,0,0,0,1,48,16,0,40,88,7,0,19,0,0,0,1,48,32,0,96,39,7,0,19,0,0,0,1,48,48,0,144,251,6,0,0,0,0,0,254,0,4,0,168,248,6,0,19,0,0,0,1,192,0,0,40,88,7,0,19,0,0,0,1,192,64,0,96,39,7,0,19,0,0,0,1,192,128,0,144,251,6,0,19,0,0,0,1,192,192,0,80,75,3,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,3,2,0,80,246,3,0,20,0,0,0,1,3,3,0,80,124,6,0,20,0,0,0,1,3,1,0,112,212,3,0,20,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,64,37,5,0,20,0,0,0,1,12,8,0,80,6,6,0,20,0,0,0,1,12,12,0,104,1,6,0,20,0,0,0,1,12,4,0,96,251,5,0,20,0,0,0,1,12,0,0,120,7,5,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,48,16,0,192,255,2,0,20,0,0,0,1,48,32,0,208,75,4,0,20,0,0,0,1,48,48,0,8,49,4,0,20,0,0,0,1,48,0,0,152,21,4,0,0,0,0,0,254,0,4,0,104,159,3,0,20,0,0,0,1,192,0,0,96,135,7,0,20,0,0,0,1,192,64,0,88,239,5,0,20,0,0,0,1,192,128,0,96,235,5,0,20,0,0,0,1,192,192,0,152,182,7,0,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,208,19,6,0,19,0,0,0,1,1,1,0,224,16,6,0,19,0,0,0,1,1,0,0,160,12,6,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,2,2,0,96,135,7,0,19,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,4,4,0,96,135,7,0,19,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,8,0,0,96,135,7,0,19,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,19,0,0,0,1,48,16,0,96,39,7,0,19,0,0,0,1,48,48,0,144,251,6,0,19,0,0,0,1,48,0,0,120,211,6,0,19,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,19,0,0,0,1,192,64,0,96,39,7,0,19,0,0,0,1,192,192,0,144,251,6,0,19,0,0,0,1,192,0,0,120,211,6,0,19,0,0,0,1,192,128,0,184,164,6,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,3,2,0,80,246,3,0,20,0,0,0,1,3,3,0,80,124,6,0,20,0,0,0,1,3,1,0,112,212,3,0,20,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,64,37,5,0,20,0,0,0,1,12,8,0,80,6,6,0,20,0,0,0,1,12,12,0,104,1,6,0,20,0,0,0,1,12,4,0,96,251,5,0,20,0,0,0,1,12,0,0,120,7,5,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,48,16,0,192,255,2,0,20,0,0,0,1,48,32,0,208,75,4,0,20,0,0,0,1,48,48,0,8,49,4,0,20,0,0,0,1,48,0,0,152,21,4,0,0,0,0,0,254,0,4,0,104,159,3,0,20,0,0,0,1,192,0,0,96,135,7,0,20,0,0,0,1,192,64,0,88,239,5,0,20,0,0,0,1,192,128,0,96,235,5,0,20,0,0,0,1,192,192,0,152,182,7,0,99,111,116,116,111,110,46,97,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,16,125,239,231,1,0,16,1,99,111,116,116,111,110,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,62,248,228,171,1,0,16,1,99,111,116,116,111,110,46,97,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,1,68,15,252,1,0,16,1,99,111,116,116,111,110,46,97,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,162,30,15,245,1,0,16,1,111,112,114,45,49,51,56,54,50,46,97,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,182,84,115,164,2,0,32,0,111,112,114,45,49,51,56,55,55,46,98,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,181,36,132,211,2,0,32,0,111,112,114,45,49,51,56,54,51,46,97,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,38,0,153,140,2,0,32,0,111,112,114,45,49,51,56,55,56,46,98,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,138,91,193,33,2,0,32,0,111,112,114,45,49,51,56,54,52,46,97,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,191,117,177,210,2,0,32,0,111,112,114,45,49,51,56,55,57,46,98,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,49,37,214,185,2,0,32,0,111,112,114,45,49,51,56,54,53,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,4,244,36,112,3,0,32,0,111,112,114,45,49,51,56,54,57,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,104,52,75,171,3,0,32,0,111,112,114,45,49,51,56,54,54,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,164,187,105,97,3,0,32,0,111,112,114,45,49,51,56,55,48,46,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,195,26,180,105,3,0,32,0,111,112,114,45,49,51,56,54,55,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,45,240,20,176,3,0,32,0,111,112,114,45,49,51,56,55,49,46,98,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,2,207,1,8,3,0,32,0,111,112,114,45,49,51,56,54,56,46,98,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,214,124,42,230,3,0,32,0,111,112,114,45,49,51,56,55,50,46,98,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,21,243,102,240,3,0,32,0,111,112,114,45,49,51,56,53,50,46,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,139,186,58,148,3,0,32,0,111,112,114,45,49,51,56,55,51,46,98,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,243,69,209,27,3,0,32,0,111,112,114,45,49,51,56,53,51,46,97,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,50,169,126,3,0,32,0,111,112,114,45,49,51,56,55,52,46,98,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,255,155,213,79,3,0,32,0,111,112,114,45,49,51,56,57,49,46,97,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,20,196,179,198,3,0,32,0,111,112,114,45,49,51,56,57,52,46,98,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,226,190,208,227,3,0,32,0,111,112,114,45,49,51,56,53,53,46,97,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,226,62,111,133,3,0,32,0,111,112,114,45,49,51,56,55,54,46,98,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,216,250,95,28,3,0,32,0,101,112,114,45,49,51,56,57,50,46,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,173,230,251,253,4,0,16,1,111,112,114,45,49,51,56,57,51,46,97,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,223,51,66,56,8,0,64,0,51,49,55,45,48,49,56,48,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,21,185,54,162,5,0,16,1,101,112,114,45,49,51,56,53,56,98,46,97,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,172,61,17,45,1,0,16,1,101,112,114,45,49,51,56,53,54,98,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,196,42,171,90,1,0,16,1,101,112,114,45,49,51,56,53,57,98,46,97,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,125,54,103,46,1,0,16,1,101,112,114,45,49,51,56,53,55,98,46,97,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,2,31,54,32,1,0,16,1,111,112,114,45,49,51,56,54,50,46,97,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,182,84,115,164,2,0,32,0,111,112,114,45,49,51,56,55,55,46,98,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,181,36,132,211,2,0,32,0,111,112,114,45,49,51,56,54,51,46,97,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,38,0,153,140,2,0,32,0,111,112,114,45,49,51,56,55,56,46,98,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,138,91,193,33,2,0,32,0,111,112,114,45,49,51,56,54,52,46,97,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,191,117,177,210,2,0,32,0,111,112,114,45,49,51,56,55,57,46,98,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,49,37,214,185,2,0,32,0,111,112,114,45,49,51,56,54,53,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,4,244,36,112,3,0,32,0,111,112,114,45,49,51,56,54,57,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,104,52,75,171,3,0,32,0,111,112,114,45,49,51,56,54,54,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,164,187,105,97,3,0,32,0,111,112,114,45,49,51,56,55,48,46,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,195,26,180,105,3,0,32,0,111,112,114,45,49,51,56,54,55,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,45,240,20,176,3,0,32,0,111,112,114,45,49,51,56,55,49,46,98,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,2,207,1,8,3,0,32,0,111,112,114,45,49,51,56,54,56,46,98,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,214,124,42,230,3,0,32,0,111,112,114,45,49,51,56,55,50,46,98,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,21,243,102,240,3,0,32,0,111,112,114,45,49,51,56,53,50,46,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,139,186,58,148,3,0,32,0,111,112,114,45,49,51,56,55,51,46,98,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,243,69,209,27,3,0,32,0,111,112,114,45,49,51,56,53,51,46,97,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,50,169,126,3,0,32,0,111,112,114,45,49,51,56,55,52,46,98,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,255,155,213,79,3,0,32,0,111,112,114,45,49,51,56,53,52,46,97,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,144,33,148,28,3,0,32,0,111,112,114,45,49,51,56,55,53,46,98,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,141,134,102,106,3,0,32,0,111,112,114,45,49,51,56,53,53,46,97,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,226,62,111,133,3,0,32,0,111,112,114,45,49,51,56,55,54,46,98,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,216,250,95,28,3,0,32,0,101,112,114,45,49,51,56,54,48,46,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,39,176,87,106,4,0,16,1,111,112,114,45,49,51,48,54,49,46,97,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,21,33,77,8,0,64,0,51,49,55,45,48,49,55,57,98,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,211,150,128,72,5,0,16,1,112,114,103,50,46,117,98,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,53,163,100,38,0,0,16,1,112,114,103,49,46,117,98,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,95,51,166,205,0,0,16,1,112,114,103,45,115,46,117,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,163,110,125,84,0,0,16,1,112,114,111,116,100,97,116,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,244,19,125,167,0,0,16,1,115,114,111,109,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,67,110,164,115,0,0,32,0,115,114,111,109,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,236,219,226,173,0,0,32,0,117,111,114,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,35,31,217,167,0,0,32,0,117,111,114,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,194,190,172,154,0,0,32,0,117,111,114,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,60,12,238,63,0,0,32,0,117,111,114,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,45,237,217,190,0,0,32,0,115,111,117,110,100,46,117,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,182,25,94,84,0,0,64,0,56,55,99,53,50,46,109,99,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,16,17,0,0,0,255,255,255,0,0,0,0,0,18,0,0,0,255,255,127,0,0,0,0,0,0,0,0,0,254,0,2,0,232,75,4,0,18,0,0,0,1,1,1,0,96,135,7,0,18,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,18,0,0,0,1,6,0,0,80,246,3,0,18,0,0,0,1,6,6,0,248,38,7,0,18,0,0,0,1,6,2,0,112,212,3,0,18,0,0,0,1,6,4,0,24,99,5,0,0,0,0,0,254,0,8,0,32,4,2,0,18,0,0,0,1,56,0,0,104,54,4,0,18,0,0,0,1,56,32,0,80,252,6,0,18,0,0,0,1,56,16,0,16,242,7,0,18,0,0,0,1,56,48,0,104,236,7,0,18,0,0,0,1,56,56,0,128,230,7,0,18,0,0,0,1,56,40,0,120,211,6,0,18,0,0,0,1,56,24,0,184,164,6,0,18,0,0,0,1,56,8,0,80,74,6,0,0,0,0,0,254,0,2,0,232,19,7,0,18,0,0,0,1,64,0,0,192,255,2,0,18,0,0,0,1,64,64,0,208,75,4,0,0,0,0,0,254,0,2,0,168,234,7,0,18,0,0,0,1,128,128,0,96,135,7,0,18,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,18,0,0,0,255,255,255,0,0,0,0,0,19,0,0,0,255,255,127,0,0,0,0,0,0,0,0,0,254,0,8,0,200,87,7,0,18,0,0,0,1,7,0,0,40,88,7,0,18,0,0,0,1,7,1,0,96,39,7,0,18,0,0,0,1,7,7,0,144,251,6,0,18,0,0,0,1,7,6,0,184,164,6,0,18,0,0,0,1,7,5,0,80,74,6,0,18,0,0,0,1,7,4,0,192,32,6,0,18,0,0,0,1,7,3,0,192,234,2,0,18,0,0,0,1,7,2,0,32,242,5,0,0,0,0,0,254,0,8,0,160,123,6,0,18,0,0,0,1,56,0,0,40,88,7,0,18,0,0,0,1,56,8,0,96,39,7,0,18,0,0,0,1,56,56,0,144,251,6,0,18,0,0,0,1,56,48,0,184,164,6,0,18,0,0,0,1,56,40,0,80,74,6,0,18,0,0,0,1,56,32,0,192,32,6,0,18,0,0,0,1,56,24,0,192,234,2,0,18,0,0,0,1,56,16,0,32,242,5,0,0,0,0,0,254,0,2,0,144,212,8,0,18,0,0,0,1,64,64,0,96,135,7,0,18,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,152,23,8,0,18,0,0,0,1,128,128,0,192,255,2,0,18,0,0,0,1,128,0,0,208,75,4,0,0,0,0,0,254,0,4,0,128,129,4,0,19,0,0,0,1,3,1,0,192,255,2,0,19,0,0,0,1,3,0,0,208,75,4,0,19,0,0,0,1,3,3,0,8,49,4,0,19,0,0,0,1,3,2,0,152,21,4,0,0,0,0,0,254,0,4,0,72,202,5,0,19,0,0,0,1,12,8,0,80,246,3,0,19,0,0,0,1,12,12,0,248,38,7,0,19,0,0,0,1,12,4,0,112,212,3,0,19,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,2,0,24,226,7,0,19,0,0,0,1,16,16,0,96,135,7,0,19,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,128,128,0,96,135,7,0,19,0,0,0,1,128,0,0,152,182,7,0,107,99,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,40,200,127,168,1,0,16,1,107,99,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,236,61,161,148,1,0,16,1,107,99,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,5,103,252,94,1,0,16,1,107,99,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,102,125,145,172,1,0,16,1,107,99,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,237,225,158,90,1,0,16,1,107,99,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,30,67,135,247,1,0,16,1,107,99,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,49,94,24,122,1,0,16,1,107,99,56,99,97,114,97,116,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,203,210,102,120,4,0,32,0,107,99,57,99,97,114,97,116,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,1,161,17,115,4,0,32,0,99,107,95,99,112,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,203,121,11,126,7,0,32,0,12,0,0,0,255,255,0,0,0,0,0,0,13,0,0,0,255,255,0,0,0,0,0,0,14,0,0,0,255,255,10,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,14,0,0,0,1,3,0,0,192,255,2,0,14,0,0,0,1,3,1,0,208,75,4,0,14,0,0,0,1,3,2,0,8,49,4,0,14,0,0,0,1,3,3,0,152,21,4,0,0,0,0,0,254,0,2,0,64,37,5,0,14,0,0,0,1,8,8,0,232,130,1,0,14,0,0,0,1,8,0,0,160,129,1,0,0,0,0,0,168,86,7,0,1,0,0,0,212,47,216,0,248,191,2,0,24,38,7,0,1,0,0,0,208,47,216,0,184,160,2,0,56,210,6,0,1,0,0,0,35,48,216,0,192,135,2,0,24,163,6,0,1,0,0,0,34,48,216,0,240,108,2,0,152,122,6,0,1,0,0,0,33,48,216,0,96,82,2,0,192,72,6,0,1,0,0,0,32,48,216,0,32,56,2,0,8,227,6,0,1,0,0,0,36,48,216,0,152,30,2,0,136,222,6,0,1,0,0,0,37,48,216,0,232,10,2,0,24,180,1,0,1,0,0,0,38,48,216,0,152,138,8,0,40,246,1,0,1,0,0,0,213,47,216,0,64,246,1,0,88,212,3,0,1,0,0,0,144,46,216,0,40,185,3,0,240,152,1,0,1,0,0,0,201,47,216,0,216,70,1,0,16,17,8,0,1,0,0,0,202,47,216,0,224,12,8,0,136,67,2,0,1,0,0,0,176,48,216,0,48,119,7,0,8,66,2,0,1,0,0,0,184,48,216,0,112,109,7,0,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,71,179,112,116,1,0,16,1,55,108,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,54,237,235,120,1,0,16,1,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,243,5,198,136,4,0,32,0,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,106,1,172,119,4,0,32,0,55,52,115,50,56,56,46,99,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,196,43,101,36,7,0,32,0,20,0,0,0,255,255,111,0,0,0,0,0,21,0,0,0,255,255,223,0,0,0,0,0,0,0,0,0,254,0,4,0,200,87,7,0,20,0,0,0,1,3,3,0,8,201,6,0,20,0,0,0,1,3,2,0,200,197,6,0,20,0,0,0,1,3,1,0,152,194,6,0,20,0,0,0,1,3,0,0,248,189,6,0,0,0,0,0,254,0,4,0,160,123,6,0,20,0,0,0,1,12,0,0,32,136,7,0,20,0,0,0,1,12,4,0,40,88,7,0,20,0,0,0,1,12,8,0,96,39,7,0,20,0,0,0,1,12,12,0,144,251,6,0,0,0,0,0,254,0,2,0,168,234,7,0,20,0,0,0,1,32,0,0,96,135,7,0,20,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,20,0,0,0,1,64,64,0,96,135,7,0,20,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,200,30,2,0,20,0,0,0,1,128,0,0,120,97,1,0,20,0,0,0,1,128,128,0,96,19,1,0,0,0,0,0,254,0,4,0,128,129,4,0,21,0,0,0,1,3,1,0,192,255,2,0,21,0,0,0,1,3,3,0,8,49,4,0,21,0,0,0,1,3,2,0,72,246,3,0,21,0,0,0,1,3,0,0,48,176,2,0,0,0,0,0,254,0,4,0,72,202,5,0,21,0,0,0,1,12,4,0,80,246,3,0,21,0,0,0,1,12,12,0,248,38,7,0,21,0,0,0,1,12,8,0,112,212,3,0,21,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,2,0,104,159,3,0,21,0,0,0,1,16,0,0,56,111,3,0,21,0,0,0,1,16,16,0,104,134,3,0,0,0,0,0,254,0,2,0,72,4,1,0,21,0,0,0,1,64,64,0,96,135,7,0,21,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,98,53,50,45,49,51,48,46,51,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,70,235,123,78,2,0,16,1,98,53,50,45,49,51,54,46,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,240,77,65,47,2,0,16,1,98,53,50,45,49,51,49,46,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,131,93,148,170,2,0,16,1,98,53,50,45,49,50,57,46,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,8,188,174,14,2,0,16,1,98,53,50,45,49,51,50,46,51,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,137,71,245,162,6,0,16,1,98,53,50,45,49,51,51,46,53,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,149,47,35,18,6,0,16,1,98,53,50,45,49,51,55,46,53,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,74,183,171,55,9,0,16,1,98,53,50,45,50,57,46,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,124,210,102,131,11,0,32,0,98,53,50,45,51,52,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,54,206,141,125,17,0,32,0,98,53,50,45,51,53,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,13,236,238,120,17,0,32,0,98,53,50,45,51,54,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,145,158,232,97,17,0,32,0,98,53,50,45,51,55,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,185,71,46,240,17,0,32,0,98,53,50,45,51,48,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,71,198,140,27,21,0,32,0,98,53,50,45,51,49,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,32,142,153,241,21,0,32,0,98,53,50,45,51,50,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,12,120,32,134,21,0,32,0,98,53,50,45,51,51,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,196,184,244,230,21,0,32,0,98,53,50,45,50,56,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,43,200,59,150,22,0,32,0,98,53,50,45,51,56,46,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,247,91,91,23,0,32,0,98,53,50,45,49,49,53,46,55,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,147,126,17,78,24,0,64,0,98,53,50,45,49,49,52,46,55,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,177,214,115,58,24,0,64,0,98,53,50,45,49,49,51,46,55,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,5,58,106,44,24,0,64,0,98,53,50,45,49,49,54,46,55,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,60,152,70,173,25,0,64,0,98,53,50,45,48,49,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,23,157,113,137,0,0,0,8,98,53,50,45,48,51,46,49,51,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,13,73,248,163,0,0,0,8,98,53,50,45,48,54,46,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,48,31,248,251,0,0,0,8,98,53,50,45,49,56,46,57,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,26,175,189,96,0,0,0,8,98,53,50,45,49,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,13,190,113,98,0,0,0,8,98,53,50,45,52,57,46,54,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,209,46,221,96,0,0,0,8,98,53,50,45,53,48,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,28,120,137,193,0,0,0,8,98,53,50,45,53,49,46,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,121,31,204,48,0,0,0,8,98,53,50,45,49,50,54,46,49,51,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,14,132,47,250,0,0,0,8,98,53,50,45,49,50,55,46,49,53,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,79,42,104,119,0,0,0,8,112,97,108,50,48,108,56,98,45,98,53,50,45,49,55,46,105,99,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,1,0,0,109,49,81,72,0,0,0,8,112,97,108,50,48,108,56,98,45,98,53,50,45,49,55,46,105,99,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,1,0,0,109,49,81,72,0,0,0,8,112,97,108,50,48,108,56,98,45,98,53,50,45,49,55,46,105,99,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,1,0,0,109,49,81,72,0,0,0,8,112,97,108,50,48,108,56,98,45,98,53,50,45,49,55,46,105,99,53,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,1,0,0,109,49,81,72,0,0,0,8,112,97,108,49,54,108,56,98,45,98,53,50,45,49,57,46,105,99,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,220,146,162,59,0,0,0,8,112,97,108,49,54,108,56,98,45,98,53,50,45,50,48,46,105,99,51,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,115,173,57,189,0,0,0,8,112,97,108,49,54,108,56,98,45,98,53,50,45,50,49,46,105,99,53,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,164,106,231,47,0,0,0,8,112,97,108,50,48,108,56,98,45,98,53,50,45,50,53,46,105,99,49,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,1,0,0,45,99,43,55,0,0,0,8,112,97,108,50,48,108,56,98,45,98,53,50,45,50,54,46,105,99,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,1,0,0,194,43,79,217,0,0,0,8,112,97,108,50,48,108,56,98,45,98,53,50,45,50,54,46,105,99,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,1,0,0,194,43,79,217,0,0,0,8,112,97,108,50,48,108,56,98,45,98,53,50,45,50,54,46,105,99,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,1,0,0,194,43,79,217,0,0,0,8,112,97,108,50,48,108,56,98,45,98,53,50,45,50,54,46,105,99,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,1,0,0,194,43,79,217,0,0,0,8,112,97,108,50,48,108,56,98,45,98,53,50,45,50,55,46,105,99,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,1,0,0,38,171,194,97,0,0,0,8,112,97,108,50,48,108,56,98,45,98,53,50,45,49,49,56,46,105,99,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,1,0,0,175,228,95,156,0,0,0,8,112,97,108,50,48,108,56,98,45,98,53,50,45,49,49,57,46,105,99,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,1,0,0,6,33,142,139,0,0,0,8,112,97,108,49,54,108,56,98,45,98,53,50,45,49,50,48,46,105,99,53,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,160,255,126,62,0,0,0,8,112,97,108,50,48,108,56,98,45,98,53,50,45,49,50,49,46,105,99,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,1,0,0,29,253,86,112,0,0,0,8,112,97,108,49,54,108,56,98,45,98,53,50,45,49,50,50,46,105,99,49,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,4,251,192,4,0,0,0,8,112,97,108,49,54,108,56,98,45,98,53,50,45,49,50,51,46,105,99,49,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,200,209,101,56,0,0,0,8,112,97,108,49,54,108,56,98,45,98,53,50,45,49,50,52,46,105,99,49,56,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,0,0,0,24,112,97,108,49,54,108,56,98,45,98,53,50,45,49,50,53,46,105,99,49,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,87,197,40,118,0,0,0,8,11,0,0,0,255,255,255,0,0,0,0,0,12,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,200,30,2,0,11,0,0,0,1,3,3,0,152,116,6,0,11,0,0,0,1,3,2,0,48,113,6,0,11,0,0,0,1,3,1,0,48,110,6,0,11,0,0,0,1,3,0,0,232,104,6,0,0,0,0,0,254,0,2,0,232,75,4,0,11,0,0,0,1,4,4,0,96,135,7,0,11,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,11,0,0,0,1,8,0,0,96,135,7,0,11,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,11,0,0,0,1,48,0,0,80,252,6,0,11,0,0,0,1,48,16,0,16,242,7,0,11,0,0,0,1,48,32,0,104,236,7,0,11,0,0,0,1,48,48,0,128,230,7,0,0,0,0,0,254,0,4,0,160,123,6,0,11,0,0,0,1,192,192,0,8,201,6,0,11,0,0,0,1,192,128,0,200,197,6,0,11,0,0,0,1,192,64,0,152,194,6,0,11,0,0,0,1,192,0,0,248,189,6,0,0,0,0,0,254,0,4,0,72,202,5,0,12,0,0,0,1,3,2,0,80,246,3,0,12,0,0,0,1,3,3,0,248,38,7,0,12,0,0,0,1,3,1,0,112,212,3,0,12,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,136,20,8,0,12,0,0,0,1,12,8,0,48,17,8,0,12,0,0,0,1,12,4,0,248,12,8,0,12,0,0,0,1,12,12,0,208,6,8,0,12,0,0,0,1,12,0,0,112,2,8,0,0,0,0,0,254,0,2,0,216,250,7,0,12,0,0,0,1,16,16,0,8,49,4,0,12,0,0,0,1,16,0,0,72,246,3,0,0,0,0,0,254,0,2,0,216,99,6,0,12,0,0,0,1,32,32,0,96,135,7,0,12,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,48,219,7,0,12,0,0,0,1,64,0,0,96,135,7,0,12,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,12,0,0,0,1,128,0,0,96,135,7,0,12,0,0,0,1,128,128,0,152,182,7,0,0,0,0,0,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,127,0,0,0,0,0,0,0,0,0,254,0,8,0,200,87,7,0,19,0,0,0,1,7,0,0,40,88,7,0,19,0,0,0,1,7,1,0,96,39,7,0,19,0,0,0,1,7,7,0,144,251,6,0,19,0,0,0,1,7,6,0,184,164,6,0,19,0,0,0,1,7,5,0,80,74,6,0,19,0,0,0,1,7,4,0,192,32,6,0,19,0,0,0,1,7,3,0,192,234,2,0,19,0,0,0,1,7,2,0,32,242,5,0,0,0,0,0,254,0,8,0,160,123,6,0,19,0,0,0,1,56,0,0,40,88,7,0,19,0,0,0,1,56,8,0,96,39,7,0,19,0,0,0,1,56,56,0,144,251,6,0,19,0,0,0,1,56,48,0,184,164,6,0,19,0,0,0,1,56,40,0,80,74,6,0,19,0,0,0,1,56,32,0,192,32,6,0,19,0,0,0,1,56,24,0,192,234,2,0,19,0,0,0,1,56,16,0,32,242,5,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,64,64,0,96,135,7,0,19,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,0,0,128,129,4,0,20,0,0,0,1,3,1,0,192,255,2,0,20,0,0,0,1,3,0,0,208,75,4,0,20,0,0,0,1,3,3,0,8,49,4,0,20,0,0,0,1,3,2,0,152,21,4,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,12,12,0,248,38,7,0,20,0,0,0,1,12,8,0,80,246,3,0,20,0,0,0,1,12,4,0,112,212,3,0,20,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,4,0,104,159,3,0,20,0,0,0,1,64,0,0,56,111,3,0,20,0,0,0,1,64,64,0,104,134,3,0,0,0,0,0,254,0,0,0,168,234,7,0,20,0,0,0,1,128,128,0,96,135,7,0,20,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,99,97,117,95,51,48,97,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,205,234,252,145,1,0,16,1,99,97,117,95,51,53,97,46,49,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,178,217,144,240,1,0,16,1,99,97,117,95,51,49,97,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,175,92,183,229,1,0,16,1,99,97,117,95,51,54,97,46,49,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,19,215,63,199,1,0,16,1,99,97,45,51,50,109,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,212,55,72,12,2,0,16,1,99,97,45,53,109,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,55,204,212,102,4,0,32,0,99,97,45,55,109,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,242,150,248,182,4,0,32,0,99,97,45,49,109,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,253,32,6,77,4,0,32,0,99,97,45,51,109,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,195,65,3,11,4,0,32,0,99,97,117,95,48,57,46,49,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,133,116,254,150,3,0,16,0,99,97,117,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,44,58,97,74,5,0,64,0,99,97,117,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,147,68,88,116,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,99,97,50,52,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,28,11,236,118,0,0,0,8,105,111,98,49,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,99,97,106,95,51,54,97,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,205,234,252,145,1,0,16,1,99,97,106,95,52,50,97,46,49,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,98,131,159,3,1,0,16,1,99,97,106,95,51,55,97,46,49,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,175,92,183,229,1,0,16,1,99,97,106,95,52,51,97,46,49,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,19,215,63,199,1,0,16,1,99,97,106,95,51,52,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,244,87,234,81,1,0,16,1,99,97,106,95,52,48,46,49,48,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,225,26,183,42,1,0,16,1,99,97,106,95,51,53,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,115,25,215,1,1,0,16,1,99,97,106,95,52,49,46,49,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,56,181,67,58,1,0,16,1,99,97,106,95,48,57,46,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,166,249,176,65,4,0,32,0,99,97,106,95,48,49,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,184,208,2,16,4,0,32,0,99,97,106,95,49,51,46,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,178,72,57,111,4,0,32,0,99,97,106,95,48,53,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,215,115,115,32,4,0,32,0,99,97,106,95,50,52,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,215,170,86,227,4,0,32,0,99,97,106,95,49,55,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,216,47,15,84,4,0,32,0,99,97,106,95,51,56,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,171,212,100,36,4,0,32,0,99,97,106,95,51,50,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,179,54,88,155,4,0,32,0,99,97,106,95,49,48,46,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,82,95,138,191,4,0,32,0,99,97,106,95,48,50,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,141,1,91,18,4,0,32,0,99,97,106,95,49,52,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,215,231,88,132,4,0,32,0,99,97,106,95,48,54,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,100,225,128,207,4,0,32,0,99,97,106,95,50,53,46,55,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,77,32,208,205,4,0,32,0,99,97,106,95,49,56,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,177,212,193,41,4,0,32,0,99,97,106,95,51,57,46,57,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,103,59,162,238,4,0,32,0,99,97,106,95,51,51,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,31,137,227,221,4,0,32,0,99,97,106,95,50,51,46,49,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,133,116,254,150,3,0,16,0,99,97,106,95,51,48,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,44,58,97,74,5,0,64,0,99,97,106,95,51,49,46,49,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,147,68,88,116,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,99,97,50,50,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,120,230,82,81,0,0,0,8,105,111,98,49,46,49,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,172,83,179,163,1,0,16,1,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,214,239,98,63,1,0,16,1,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,78,78,215,57,1,0,16,1,49,99,95,115,110,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,85,207,141,245,2,0,16,1,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,111,205,79,212,4,0,32,0,107,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,158,127,188,89,4,0,32,0,99,97,118,101,108,111,110,46,99,108,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,107,53,51,209,7,0,32,0,17,0,0,0,255,255,0,0,0,0,0,0,18,0,0,0,255,255,2,0,0,0,0,0,19,0,0,0,255,255,12,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,18,0,0,0,1,1,0,0,120,97,1,0,18,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,2,0,32,4,2,0,18,0,0,0,1,2,2,0,200,209,1,0,18,0,0,0,1,2,0,0,144,147,2,0,0,0,0,0,254,0,4,0,128,129,4,0,19,0,0,0,1,6,0,0,208,75,4,0,19,0,0,0,1,6,4,0,8,49,4,0,19,0,0,0,1,6,2,0,152,21,4,0,19,0,0,0,1,6,6,0,72,246,3,0,99,97,108,105,112,115,111,46,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,60,112,203,15,1,0,16,1,99,97,108,105,112,115,111,46,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,20,47,98,198,1,0,16,1,99,97,108,105,112,115,111,46,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,186,186,172,123,1,0,16,1,99,97,108,105,112,115,111,46,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,27,17,168,163,1,0,16,1,99,97,108,105,112,115,111,46,50,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,158,123,189,252,1,0,16,1,99,97,108,105,112,115,111,46,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,171,12,99,247,1,0,16,1,99,97,108,105,112,115,111,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,171,101,188,156,2,0,16,1,99,97,108,105,112,115,111,46,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,59,238,37,162,2,0,16,1,99,97,108,105,112,115,111,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,233,82,66,253,4,0,32,0,99,97,108,105,112,115,111,46,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,58,167,99,22,4,0,32,0,99,97,108,105,112,115,111,46,99,108,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,50,88,22,1,7,0,32,0,13,0,0,0,255,255,0,0,0,0,0,0,14,0,0,0,255,255,2,0,0,0,0,0,15,0,0,0,255,255,4,0,0,0,0,0,0,0,0,0,254,0,2,0,128,129,4,0,14,0,0,0,1,1,0,0,8,49,4,0,14,0,0,0,1,1,1,0,72,246,3,0,0,0,0,0,254,0,2,0,168,234,7,0,14,0,0,0,1,2,0,0,96,135,7,0,14,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,4,0,32,4,2,0,15,0,0,0,1,6,4,0,128,103,7,0,15,0,0,0,1,6,6,0,80,196,7,0,15,0,0,0,1,6,2,0,0,90,2,0,15,0,0,0,1,6,0,0,72,74,2,0,19,0,0,0,255,255,254,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,2,2,0,96,135,7,0,19,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,4,4,0,96,135,7,0,19,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,8,0,0,96,135,7,0,19,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,19,0,0,0,1,48,0,0,32,136,7,0,19,0,0,0,1,48,16,0,40,88,7,0,19,0,0,0,1,48,32,0,96,39,7,0,19,0,0,0,1,48,48,0,144,251,6,0,0,0,0,0,254,0,4,0,168,248,6,0,19,0,0,0,1,192,192,0,80,75,3,0,19,0,0,0,1,192,128,0,144,251,6,0,19,0,0,0,1,192,64,0,192,204,7,0,19,0,0,0,1,192,0,0,128,197,7,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,3,2,0,80,246,3,0,20,0,0,0,1,3,3,0,80,124,6,0,20,0,0,0,1,3,1,0,112,212,3,0,20,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,0,191,7,0,20,0,0,0,1,12,0,0,208,183,7,0,20,0,0,0,1,12,4,0,208,179,7,0,20,0,0,0,1,12,12,0,72,176,7,0,20,0,0,0,1,12,8,0,24,172,7,0,0,0,0,0,254,0,4,0,96,168,7,0,20,0,0,0,1,48,0,0,24,164,7,0,20,0,0,0,1,48,16,0,40,159,7,0,20,0,0,0,1,48,48,0,80,155,7,0,20,0,0,0,1,48,32,0,152,149,7,0,0,0,0,0,254,0,3,0,56,143,7,0,20,0,0,0,1,192,192,0,112,137,7,0,20,0,0,0,1,192,128,0,40,133,7,0,20,0,0,0,1,192,0,0,144,129,7,0,19,0,0,0,255,255,254,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,2,2,0,96,135,7,0,19,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,4,4,0,96,135,7,0,19,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,8,0,0,96,135,7,0,19,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,19,0,0,0,1,48,0,0,120,211,6,0,19,0,0,0,1,48,16,0,96,39,7,0,19,0,0,0,1,48,32,0,168,126,7,0,19,0,0,0,1,48,48,0,144,251,6,0,0,0,0,0,254,0,4,0,160,123,6,0,19,0,0,0,1,192,192,0,144,251,6,0,19,0,0,0,1,192,128,0,192,204,7,0,19,0,0,0,1,192,64,0,184,164,6,0,19,0,0,0,1,192,0,0,80,74,6,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,3,2,0,80,246,3,0,20,0,0,0,1,3,3,0,80,124,6,0,20,0,0,0,1,3,1,0,112,212,3,0,20,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,0,191,7,0,20,0,0,0,1,12,0,0,208,183,7,0,20,0,0,0,1,12,4,0,208,179,7,0,20,0,0,0,1,12,12,0,72,176,7,0,20,0,0,0,1,12,8,0,24,172,7,0,0,0,0,0,254,0,4,0,136,123,7,0,20,0,0,0,1,48,0,0,24,164,7,0,20,0,0,0,1,48,16,0,40,159,7,0,20,0,0,0,1,48,48,0,80,155,7,0,20,0,0,0,1,48,32,0,152,149,7,0,0,0,0,0,254,0,3,0,56,143,7,0,20,0,0,0,1,192,192,0,112,137,7,0,20,0,0,0,1,192,128,0,40,133,7,0,20,0,0,0,1,192,0,0,144,129,7,0,19,0,0,0,254,0,2,0,200,30,2,0,19,0,0,0,1,4,0,0,120,97,1,0,19,0,0,0,1,4,4,0,96,19,1,0,20,0,0,0,254,0,2,0,144,212,6,0,20,0,0,0,2,2,2,0,8,208,6,0,19,0,0,0,0,4,0,0,0,0,0,0,20,0,0,0,2,2,0,0,88,204,6,0,19,0,0,0,0,4,0,0,0,0,0,0,114,111,109,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,56,234,221,133,0,0,16,1,97,50,49,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,189,35,147,78,0,0,16,1,97,50,49,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,212,89,230,87,0,0,16,1,97,50,49,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,243,147,114,30,0,0,16,1,97,50,49,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,162,10,206,178,0,0,16,1,98,117,122,108,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,208,40,215,101,0,0,32,0,97,50,49,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,201,241,125,165,0,0,32,0,97,50,49,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,163,59,98,99,0,0,32,0,97,50,49,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,169,105,201,76,0,0,32,0,97,50,49,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,91,77,92,156,0,0,32,0,97,50,49,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,173,90,107,211,0,0,32,0,97,50,49,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,162,174,135,243,0,0,32,0,97,50,49,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,125,125,150,135,0,0,32,0,97,50,49,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,180,10,100,89,0,0,32,0,97,50,49,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,216,136,173,34,0,0,32,0,97,50,49,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,86,251,37,204,0,0,32,0,97,50,49,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,72,68,5,202,0,0,32,0,97,50,49,46,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,73,196,192,35,0,0,32,0,97,50,49,46,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,94,152,196,239,0,0,32,0,109,49,46,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,1,146,163,131,0,0,32,0,101,112,114,45,46,49,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,86,145,241,41,0,0,16,1,101,112,114,45,46,49,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,149,43,125,227,0,0,16,1,101,112,114,45,46,49,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,61,119,245,234,0,0,16,1,101,112,114,45,46,49,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,18,199,195,114,0,0,16,1,101,112,114,45,46,49,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,205,164,159,125,0,0,16,1,101,112,114,45,46,49,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,151,39,31,6,0,0,16,1,101,112,114,45,54,48,55,55,46,49,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,2,118,163,2,0,0,16,1,101,112,114,45,46,56,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,159,52,28,183,0,0,32,0,101,112,114,45,46,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,168,175,222,134,0,0,32,0,101,112,114,45,54,48,56,55,46,56,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,44,116,119,38,0,0,32,0,101,112,114,45,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,190,98,10,111,0,0,32,0,101,112,114,45,54,48,56,53,46,56,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,98,220,61,156,0,0,32,0,101,112,114,45,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,124,229,252,192,0,0,32,0,101,112,114,45,54,48,54,57,46,56,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,65,30,105,254,0,0,32,0,101,112,114,45,54,48,55,48,46,57,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,223,128,240,52,0,0,32,0,112,114,45,53,51,49,55,46,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,184,80,131,100,0,0,0,8,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,252,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,19,0,0,0,1,15,7,0,80,252,6,0,19,0,0,0,1,15,8,0,16,242,7,0,19,0,0,0,1,15,9,0,104,236,7,0,19,0,0,0,1,15,5,0,192,54,8,0,19,0,0,0,1,15,4,0,56,24,4,0,19,0,0,0,1,15,15,0,128,230,7,0,19,0,0,0,1,15,0,0,128,230,7,0,19,0,0,0,1,15,3,0,176,162,3,0,19,0,0,0,1,15,2,0,24,188,3,0,19,0,0,0,1,15,1,0,72,216,3,0,19,0,0,0,1,15,6,0,120,211,6,0,19,0,0,0,1,15,14,0,184,164,6,0,19,0,0,0,1,15,13,0,80,74,6,0,19,0,0,0,1,15,12,0,192,32,6,0,19,0,0,0,1,15,11,0,192,234,2,0,19,0,0,0,1,15,10,0,32,242,5,0,0,0,0,0,254,0,16,0,160,123,6,0,19,0,0,0,1,240,112,0,80,252,6,0,19,0,0,0,1,240,128,0,16,242,7,0,19,0,0,0,1,240,144,0,104,236,7,0,19,0,0,0,1,240,80,0,192,54,8,0,19,0,0,0,1,240,64,0,56,24,4,0,19,0,0,0,1,240,240,0,128,230,7,0,19,0,0,0,1,240,0,0,128,230,7,0,19,0,0,0,1,240,48,0,176,162,3,0,19,0,0,0,1,240,32,0,24,188,3,0,19,0,0,0,1,240,16,0,72,216,3,0,19,0,0,0,1,240,96,0,120,211,6,0,19,0,0,0,1,240,224,0,184,164,6,0,19,0,0,0,1,240,208,0,80,74,6,0,19,0,0,0,1,240,192,0,192,32,6,0,19,0,0,0,1,240,176,0,192,234,2,0,19,0,0,0,1,240,160,0,32,242,5,0,0,0,0,0,254,0,2,0,200,30,2,0,20,0,0,0,1,1,0,0,120,97,1,0,20,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,2,0,168,234,7,0,20,0,0,0,1,2,2,0,96,135,7,0,20,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,12,12,0,8,49,4,0,20,0,0,0,1,12,8,0,152,21,4,0,20,0,0,0,1,12,4,0,72,246,3,0,20,0,0,0,1,12,0,0,112,49,6,0,0,0,0,0,254,0,4,0,64,37,5,0,20,0,0,0,1,48,48,0,192,33,6,0,20,0,0,0,1,48,32,0,208,26,6,0,20,0,0,0,1,48,16,0,48,20,6,0,20,0,0,0,1,48,0,0,120,7,5,0,99,51,52,95,55,49,46,57,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,41,166,31,223,2,0,16,1,99,51,52,95,54,57,46,55,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,122,19,76,165,2,0,16,1,99,51,52,95,55,48,46,57,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,226,129,125,215,2,0,16,1,99,51,52,95,54,55,46,55,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,116,124,48,57,2,0,16,1,99,51,52,95,55,52,46,49,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,153,250,105,104,6,0,16,1,99,51,52,95,55,50,46,49,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,145,15,156,192,6,0,16,1,99,51,52,95,55,53,46,49,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,66,85,166,107,6,0,16,1,99,51,52,95,55,51,46,49,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,181,98,254,242,6,0,16,1,99,51,52,95,48,53,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,218,131,107,89,11,0,32,0,99,51,52,95,48,52,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,218,176,70,36,17,0,32,0,99,51,52,95,48,51,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,120,171,142,161,17,0,32,0,99,51,52,95,48,50,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,16,186,136,132,17,0,32,0,99,51,52,95,48,49,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,99,140,190,62,17,0,32,0,99,51,52,95,48,55,46,52,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,8,120,176,237,22,0,32,0,99,51,52,95,48,54,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,235,182,0,210,23,0,32,0,99,51,52,95,48,56,46,49,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,80,4,163,137,24,0,64,0,99,51,52,95,48,57,46,49,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,80,43,209,57,25,0,64,0,99,51,52,95,49,56,46,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,246,166,69,114,0,0,0,8,99,51,52,95,49,57,46,55,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,4,196,233,46,0,0,0,8,99,51,52,95,50,48,46,56,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,48,31,248,251,0,0,0,8,99,51,52,95,50,49,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,83,136,114,16,0,0,0,8,99,51,52,95,50,50,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,252,139,62,100,0,0,0,8,11,0,0,0,255,255,255,0,0,0,0,0,12,0,0,0,255,255,247,0,0,0,0,0,0,0,0,0,254,0,2,0,144,95,6,0,11,0,0,0,1,1,1,0,96,135,7,0,11,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,11,0,0,0,1,4,4,0,96,135,7,0,11,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,11,0,0,0,1,8,0,0,96,135,7,0,11,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,32,4,2,0,11,0,0,0,1,48,0,0,80,252,6,0,11,0,0,0,1,48,16,0,16,242,7,0,11,0,0,0,1,48,32,0,104,236,7,0,11,0,0,0,1,48,48,0,128,230,7,0,0,0,0,0,254,0,4,0,168,248,6,0,11,0,0,0,1,192,0,0,16,242,7,0,11,0,0,0,1,192,64,0,104,236,7,0,11,0,0,0,1,192,128,0,128,230,7,0,11,0,0,0,1,192,192,0,80,75,3,0,0,0,0,0,254,0,4,0,72,202,5,0,12,0,0,0,1,3,2,0,80,246,3,0,12,0,0,0,1,3,3,0,248,38,7,0,12,0,0,0,1,3,1,0,112,212,3,0,12,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,120,89,6,0,12,0,0,0,1,12,12,0,248,81,6,0,12,0,0,0,1,12,8,0,80,124,6,0,12,0,0,0,1,12,4,0,176,64,8,0,12,0,0,0,1,12,0,0,128,65,6,0,0,0,0,0,99,51,52,95,55,49,46,57,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,41,166,31,223,2,0,16,1,99,51,52,95,54,57,46,55,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,122,19,76,165,2,0,16,1,99,51,52,95,55,48,46,57,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,226,129,125,215,2,0,16,1,99,51,52,95,54,54,46,55,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,206,45,57,160,2,0,16,1,99,51,52,95,55,52,46,49,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,153,250,105,104,6,0,16,1,99,51,52,95,55,50,46,49,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,145,15,156,192,6,0,16,1,99,51,52,95,55,53,46,49,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,66,85,166,107,6,0,16,1,99,51,52,95,55,51,46,49,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,181,98,254,242,6,0,16,1,99,51,52,95,48,53,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,218,131,107,89,11,0,32,0,99,51,52,95,48,52,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,218,176,70,36,17,0,32,0,99,51,52,95,48,51,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,120,171,142,161,17,0,32,0,99,51,52,95,48,50,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,16,186,136,132,17,0,32,0,99,51,52,95,48,49,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,99,140,190,62,17,0,32,0,99,51,52,95,48,55,46,52,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,8,120,176,237,22,0,32,0,99,51,52,95,48,54,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,235,182,0,210,23,0,32,0,99,51,52,95,48,56,46,49,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,80,4,163,137,24,0,64,0,99,51,52,95,48,57,46,49,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,80,43,209,57,25,0,64,0,99,51,52,95,49,56,46,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,246,166,69,114,0,0,0,8,99,51,52,95,49,57,46,55,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,4,196,233,46,0,0,0,8,99,51,52,95,50,48,46,56,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,48,31,248,251,0,0,0,8,99,51,52,95,50,49,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,83,136,114,16,0,0,0,8,99,51,52,95,50,50,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,252,139,62,100,0,0,0,8,11,0,0,0,255,255,255,0,0,0,0,0,12,0,0,0,255,255,247,0,0,0,0,0,0,0,0,0,254,0,2,0,144,95,6,0,11,0,0,0,1,1,1,0,96,135,7,0,11,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,11,0,0,0,1,4,4,0,96,135,7,0,11,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,11,0,0,0,1,8,0,0,96,135,7,0,11,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,11,0,0,0,1,48,16,0,104,236,7,0,11,0,0,0,1,48,48,0,128,230,7,0,11,0,0,0,1,48,0,0,120,211,6,0,11,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,11,0,0,0,1,192,64,0,104,236,7,0,11,0,0,0,1,192,192,0,128,230,7,0,11,0,0,0,1,192,0,0,120,211,6,0,11,0,0,0,1,192,128,0,184,164,6,0,0,0,0,0,254,0,4,0,72,202,5,0,12,0,0,0,1,3,2,0,80,246,3,0,12,0,0,0,1,3,3,0,248,38,7,0,12,0,0,0,1,3,1,0,112,212,3,0,12,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,120,89,6,0,12,0,0,0,1,12,12,0,248,81,6,0,12,0,0,0,1,12,8,0,80,124,6,0,12,0,0,0,1,12,4,0,176,64,8,0,12,0,0,0,1,12,0,0,128,65,6,0,0,0,0,0,18,0,0,0,255,255,255,0,0,0,0,0,19,0,0,0,255,255,76,0,0,0,0,0,20,0,0,0,255,255,240,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,18,0,0,0,1,15,2,0,80,252,6,0,18,0,0,0,1,15,5,0,16,242,7,0,18,0,0,0,1,15,8,0,104,236,7,0,18,0,0,0,1,15,4,0,120,113,6,0,18,0,0,0,1,15,1,0,232,228,5,0,18,0,0,0,1,15,15,0,128,230,7,0,18,0,0,0,1,15,0,0,232,192,7,0,18,0,0,0,1,15,3,0,56,141,7,0,18,0,0,0,1,15,7,0,120,211,6,0,18,0,0,0,1,15,14,0,184,164,6,0,18,0,0,0,1,15,6,0,24,1,7,0,18,0,0,0,1,15,13,0,80,74,6,0,18,0,0,0,1,15,12,0,192,32,6,0,18,0,0,0,1,15,11,0,192,234,2,0,18,0,0,0,1,15,10,0,32,242,5,0,18,0,0,0,1,15,9,0,176,192,2,0,0,0,0,0,254,0,16,0,160,123,6,0,18,0,0,0,1,240,32,0,80,252,6,0,18,0,0,0,1,240,80,0,16,242,7,0,18,0,0,0,1,240,128,0,104,236,7,0,18,0,0,0,1,240,64,0,120,113,6,0,18,0,0,0,1,240,16,0,232,228,5,0,18,0,0,0,1,240,240,0,128,230,7,0,18,0,0,0,1,240,0,0,232,192,7,0,18,0,0,0,1,240,48,0,56,141,7,0,18,0,0,0,1,240,112,0,120,211,6,0,18,0,0,0,1,240,224,0,184,164,6,0,18,0,0,0,1,240,96,0,24,1,7,0,18,0,0,0,1,240,208,0,80,74,6,0,18,0,0,0,1,240,192,0,192,32,6,0,18,0,0,0,1,240,176,0,192,234,2,0,18,0,0,0,1,240,160,0,32,242,5,0,18,0,0,0,1,240,144,0,176,192,2,0,0,0,0,0,254,0,8,0,80,184,7,0,19,0,0,0,1,7,7,0,200,222,2,0,19,0,0,0,1,7,6,0,128,201,2,0,19,0,0,0,1,7,5,0,248,182,2,0,19,0,0,0,1,7,4,0,168,169,2,0,19,0,0,0,1,7,3,0,112,155,2,0,19,0,0,0,1,7,2,0,200,142,2,0,19,0,0,0,1,7,1,0,160,131,2,0,19,0,0,0,1,7,0,0,192,118,2,0,0,0,0,0,254,0,4,0,128,104,2,0,19,0,0,0,1,24,24,0,40,92,2,0,19,0,0,0,1,24,16,0,248,168,7,0,19,0,0,0,1,24,8,0,192,160,4,0,19,0,0,0,1,24,0,0,200,68,4,0,0,0,0,0,254,0,4,0,72,202,5,0,19,0,0,0,1,96,96,0,80,246,3,0,19,0,0,0,1,96,64,0,248,38,7,0,19,0,0,0,1,96,32,0,48,123,8,0,19,0,0,0,1,96,0,0,8,117,8,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,128,128,0,96,135,7,0,19,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,20,0,0,0,1,64,64,0,96,135,7,0,20,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,96,100,3,0,20,0,0,0,1,128,128,0,248,38,7,0,20,0,0,0,1,128,0,0,176,172,3,0,0,0,0,0,112,114,103,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,248,96,46,175,0,0,16,1,112,114,103,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,120,106,204,161,0,0,16,1,109,99,117,46,49,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,36,39,78,157,0,0,16,8,112,99,49,48,48,49,48,49,46,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,16,124,110,201,0,0,32,0,112,99,50,48,48,49,48,50,46,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,106,162,183,194,0,0,32,0,112,99,51,48,48,49,48,51,46,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,44,22,238,81,0,0,32,0,112,99,54,48,48,49,48,54,46,52,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,38,112,135,37,0,0,32,0,112,99,55,48,48,49,48,55,46,52,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,68,28,226,191,0,0,32,0,112,99,52,48,48,49,48,52,46,53,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,132,111,23,59,0,0,32,0,112,99,53,48,48,49,48,53,46,53,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,220,62,187,190,0,0,32,0,112,99,54,48,52,49,48,57,46,49,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,48,85,2,118,0,0,64,0,112,99,54,48,49,49,48,54,46,57,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,28,101,147,168,0,0,64,0,112,99,54,48,50,49,48,55,46,49,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,170,35,187,15,0,0,64,0,112,99,54,48,51,49,48,56,46,49,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,133,137,69,88,0,0,64,0,20,0,0,0,255,255,16,0,0,0,0,0,0,0,0,0,254,0,2,0,40,134,8,0,20,0,0,0,1,1,0,0,136,128,8,0,20,0,0,0,1,1,1,0,32,158,6,0,0,0,0,0,254,0,2,0,16,227,4,0,20,0,0,0,1,2,0,0,96,135,7,0,20,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,2,0,40,111,8,0,20,0,0,0,1,4,4,0,96,135,7,0,20,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,96,104,8,0,20,0,0,0,1,16,0,0,96,135,7,0,20,0,0,0,1,16,16,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,20,0,0,0,1,128,0,0,96,135,7,0,20,0,0,0,1,128,128,0,152,182,7,0,184,40,2,0,1,0,0,0,40,39,216,0,248,191,2,0,56,250,6,0,1,0,0,0,32,39,216,0,184,160,2,0,88,149,7,0,1,0,0,0,33,39,216,0,136,224,1,0,240,167,7,0,1,0,0,0,45,39,216,0,192,135,2,0,208,158,7,0,1,0,0,0,42,39,216,0,96,82,2,0,184,154,7,0,1,0,0,0,43,39,216,0,32,56,2,0,8,96,7,0,1,0,0,0,37,39,216,0,72,198,1,0,16,83,7,0,1,0,0,0,34,39,216,0,40,167,1,0,96,79,7,0,1,0,0,0,35,39,216,0,200,149,1,0,88,212,3,0,1,0,0,0,48,38,216,0,40,185,3,0,248,5,8,0,9,0,0,0,112,39,216,0,32,58,1,0,144,250,7,0,9,0,0,0,113,39,216,0,32,58,1,0,248,241,7,0,9,0,0,0,114,39,216,0,32,58,1,0,72,82,8,0,9,0,0,0,115,39,216,0,32,58,1,0,18,0,0,0,255,255,191,0,0,0,0,0,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,18,0,0,0,1,3,0,0,192,255,2,0,18,0,0,0,1,3,3,0,208,75,4,0,18,0,0,0,1,3,2,0,8,49,4,0,18,0,0,0,1,3,1,0,152,21,4,0,0,0,0,0,254,0,4,0,72,202,5,0,18,0,0,0,1,12,0,0,160,203,8,0,18,0,0,0,1,12,8,0,80,246,3,0,18,0,0,0,1,12,12,0,248,38,7,0,18,0,0,0,1,12,4,0,112,212,3,0,0,0,0,0,254,0,2,0,64,37,5,0,18,0,0,0,1,16,16,0,32,113,6,0,18,0,0,0,1,16,0,0,120,7,5,0,0,0,0,0,254,0,2,0,104,159,3,0,18,0,0,0,1,32,0,0,56,111,3,0,18,0,0,0,1,32,32,0,104,134,3,0,0,0,0,0,254,0,2,0,168,234,7,0,18,0,0,0,1,64,64,0,96,135,7,0,18,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,18,0,0,0,1,128,128,0,96,135,7,0,18,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,1,1,0,96,135,7,0,19,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,88,160,1,0,19,0,0,0,1,4,4,0,136,86,1,0,19,0,0,0,1,4,0,0,184,147,6,0,0,0,0,0,254,0,2,0,96,46,8,0,19,0,0,0,1,8,8,0,192,255,2,0,19,0,0,0,1,8,0,0,208,75,4,0,0,0,0,0,254,0,16,0,32,4,2,0,19,0,0,0,1,240,160,0,144,160,3,0,19,0,0,0,1,240,176,0,96,135,3,0,19,0,0,0,1,240,192,0,32,136,7,0,19,0,0,0,1,240,208,0,40,88,7,0,19,0,0,0,1,240,224,0,96,39,7,0,19,0,0,0,1,240,16,0,32,202,2,0,19,0,0,0,1,240,48,0,120,113,6,0,19,0,0,0,1,240,32,0,232,228,5,0,19,0,0,0,1,240,240,0,144,251,6,0,19,0,0,0,1,240,64,0,120,211,6,0,19,0,0,0,1,240,144,0,184,164,6,0,19,0,0,0,1,240,128,0,80,74,6,0,19,0,0,0,1,240,112,0,192,32,6,0,19,0,0,0,1,240,96,0,192,234,2,0,19,0,0,0,1,240,80,0,32,242,5,0,19,0,0,0,1,240,0,0,16,227,4,0,0,0,0,0,101,112,114,45,49,50,57,49,49,46,97,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,26,88,129,164,1,0,16,1,101,112,114,45,49,50,57,49,48,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,191,195,27,221,1,0,16,1,111,112,114,45,49,50,56,56,52,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,51,170,36,224,2,0,32,0,111,112,114,45,49,50,56,56,53,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,20,184,65,128,2,0,32,0,111,112,114,45,49,50,56,56,54,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,94,40,50,222,2,0,32,0,111,112,114,45,49,50,56,56,55,46,98,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,157,244,192,240,3,0,32,0,111,112,114,45,49,50,56,57,49,46,97,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,140,26,211,144,3,0,32,0,101,112,114,45,49,50,56,56,56,46,97,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,60,198,47,111,4,0,16,1,51,49,55,45,48,49,51,57,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,203,132,174,154,5,0,16,1,98,115,49,54,98,46,112,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,185,120,25,253,1,0,16,1,98,115,49,54,98,46,115,99,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,91,233,228,29,2,0,32,0,98,115,49,54,98,46,111,98,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,32,98,7,5,3,0,32,0,98,115,49,54,98,46,115,110,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,1,0,123,126,12,147,4,0,16,1,21,0,0,0,255,255,254,0,0,0,0,0,22,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,21,0,0,0,255,255,95,0,0,0,0,0,22,0,0,0,255,255,240,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,20,0,0,0,1,15,2,0,80,252,6,0,20,0,0,0,1,15,5,0,16,242,7,0,20,0,0,0,1,15,8,0,104,236,7,0,20,0,0,0,1,15,4,0,120,113,6,0,20,0,0,0,1,15,1,0,232,228,5,0,20,0,0,0,1,15,15,0,128,230,7,0,20,0,0,0,1,15,3,0,56,141,7,0,20,0,0,0,1,15,7,0,120,211,6,0,20,0,0,0,1,15,14,0,184,164,6,0,20,0,0,0,1,15,6,0,24,1,7,0,20,0,0,0,1,15,13,0,80,74,6,0,20,0,0,0,1,15,12,0,192,32,6,0,20,0,0,0,1,15,11,0,192,234,2,0,20,0,0,0,1,15,10,0,32,242,5,0,20,0,0,0,1,15,9,0,176,192,2,0,20,0,0,0,1,15,0,0,16,227,4,0,0,0,0,0,254,0,15,0,160,123,6,0,20,0,0,0,1,240,32,0,80,252,6,0,20,0,0,0,1,240,80,0,16,242,7,0,20,0,0,0,1,240,128,0,104,236,7,0,20,0,0,0,1,240,64,0,120,113,6,0,20,0,0,0,1,240,16,0,232,228,5,0,20,0,0,0,1,240,240,0,128,230,7,0,20,0,0,0,1,240,48,0,56,141,7,0,20,0,0,0,1,240,112,0,120,211,6,0,20,0,0,0,1,240,224,0,184,164,6,0,20,0,0,0,1,240,96,0,24,1,7,0,20,0,0,0,1,240,208,0,80,74,6,0,20,0,0,0,1,240,192,0,192,32,6,0,20,0,0,0,1,240,176,0,192,234,2,0,20,0,0,0,1,240,160,0,32,242,5,0,20,0,0,0,1,240,144,0,176,192,2,0,0,0,0,0,254,0,2,0,128,129,4,0,21,0,0,0,1,1,1,0,192,255,2,0,21,0,0,0,1,1,0,0,208,75,4,0,0,0,0,0,254,0,4,0,72,202,5,0,21,0,0,0,1,96,96,0,80,246,3,0,21,0,0,0,1,96,64,0,248,38,7,0,21,0,0,0,1,96,32,0,48,123,8,0,21,0,0,0,1,96,0,0,8,117,8,0,0,0,0,0,254,0,2,0,168,234,7,0,21,0,0,0,1,128,128,0,96,135,7,0,21,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,22,0,0,0,1,64,64,0,96,135,7,0,22,0,0,0,1,64,0,0,152,182,7,0,109,55,46,108,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,217,111,87,59,0,0,16,1,109,53,46,108,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,183,139,152,124,0,0,16,1,109,54,46,108,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,235,216,104,87,0,0,16,1,109,49,50,46,111,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,217,84,49,150,0,0,32,0,109,49,51,46,111,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,187,128,148,6,0,0,32,0,109,52,46,106,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,79,111,59,158,0,0,32,0,109,51,46,106,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,254,88,157,98,0,0,32,0,109,49,49,46,111,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,165,128,81,37,0,0,32,0,109,49,48,46,111,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,136,192,1,50,0,0,32,0,109,57,46,111,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,228,127,53,41,0,0,32,0,109,56,46,111,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,209,101,214,171,0,0,32,0,98,108,95,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,187,42,236,194,0,0,64,0,184,40,2,0,1,0,0,0,231,233,148,0,248,191,2,0,56,250,6,0,1,0,0,0,227,233,148,0,184,160,2,0,88,149,7,0,1,0,0,0,225,233,148,0,136,224,1,0,152,122,6,0,1,0,0,0,16,218,148,0,96,82,2,0,192,72,6,0,1,0,0,0,17,218,148,0,32,56,2,0,48,123,2,0,1,0,0,0,39,233,148,0,152,30,2,0,24,198,1,0,1,0,0,0,18,218,148,0,40,167,1,0,120,189,1,0,1,0,0,0,19,218,148,0,200,149,1,0,248,187,8,0,1,0,0,0,111,232,148,0,56,126,1,0,88,212,3,0,1,0,0,0,80,219,146,0,40,185,3,0,16,17,8,0,1,0,0,0,230,233,148,0,224,12,8,0,32,77,1,0,1,0,0,0,25,232,148,0,216,70,1,0,98,104,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,25,136,153,100,1,0,16,1,98,104,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,228,108,242,38,1,0,16,1,98,104,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,69,188,24,52,1,0,16,1,98,104,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,129,244,95,115,1,0,16,1,98,104,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,233,123,101,63,1,0,16,1,98,104,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,53,171,87,160,1,0,16,1,98,104,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,33,168,91,151,4,0,32,0,98,104,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,32,16,209,3,4,0,32,0,54,108,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,103,148,172,195,7,0,32,0,10,0,0,0,255,255,0,0,0,0,0,0,11,0,0,0,255,255,0,0,0,0,0,0,12,0,0,0,255,255,2,0,0,0,0,0,0,0,0,0,254,0,4,0,32,4,2,0,11,0,0,0,1,192,192,0,224,127,8,0,11,0,0,0,1,192,0,0,32,123,8,0,11,0,0,0,1,192,64,0,192,110,8,0,11,0,0,0,1,192,128,0,96,102,7,0,0,0,0,0,254,0,4,0,64,37,5,0,12,0,0,0,1,1,0,0,136,120,6,0,12,0,0,0,1,1,1,0,176,116,6,0,0,0,0,0,254,0,2,0,200,30,2,0,12,0,0,0,1,2,2,0,120,97,1,0,12,0,0,0,1,2,0,0,96,19,1,0,98,122,95,112,114,103,49,46,117,56,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,29,227,9,132,0,0,16,1,98,122,95,112,114,103,50,46,117,56,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,139,160,160,184,0,0,16,1,98,122,95,115,112,49,46,117,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,16,0,161,9,88,13,0,0,32,0,98,122,95,115,112,50,46,117,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,189,210,234,86,0,0,32,0,98,122,95,98,103,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,159,241,103,252,0,0,32,0,51,46,117,52,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,148,76,254,82,0,0,16,1,98,122,95,115,112,49,46,117,54,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,161,9,88,13,0,0,0,8,98,122,95,115,112,50,46,117,56,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,189,210,234,86,0,0,0,8,20,0,0,0,255,255,255,0,0,0,0,0,21,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,3,3,0,136,128,8,0,20,0,0,0,1,3,2,0,80,246,3,0,20,0,0,0,1,3,1,0,112,212,3,0,20,0,0,0,1,3,0,0,104,159,7,0,0,0,0,0,254,0,4,0,232,119,7,0,20,0,0,0,1,12,0,0,208,75,4,0,20,0,0,0,1,12,12,0,8,49,4,0,20,0,0,0,1,12,8,0,152,21,4,0,20,0,0,0,1,12,4,0,72,246,3,0,0,0,0,0,254,0,2,0,16,115,7,0,20,0,0,0,1,16,0,0,96,135,7,0,20,0,0,0,1,16,16,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,20,0,0,0,1,128,128,0,96,135,7,0,20,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,16,0,48,110,7,0,21,0,0,0,1,15,0,0,128,103,7,0,21,0,0,0,1,15,1,0,176,96,7,0,21,0,0,0,1,15,2,0,56,90,7,0,21,0,0,0,1,15,3,0,184,83,7,0,21,0,0,0,1,15,4,0,248,79,7,0,21,0,0,0,1,15,5,0,208,76,7,0,21,0,0,0,1,15,6,0,176,96,7,0,21,0,0,0,1,15,7,0,56,73,7,0,21,0,0,0,1,15,8,0,208,68,7,0,21,0,0,0,1,15,9,0,96,64,7,0,21,0,0,0,1,15,10,0,104,59,7,0,21,0,0,0,1,15,11,0,0,53,7,0,21,0,0,0,1,15,12,0,240,47,7,0,21,0,0,0,1,15,13,0,40,41,7,0,21,0,0,0,1,15,14,0,208,36,7,0,21,0,0,0,1,15,15,0,128,103,7,0,0,0,0,0,254,0,16,0,232,33,7,0,21,0,0,0,1,240,0,0,128,103,7,0,21,0,0,0,1,240,16,0,176,96,7,0,21,0,0,0,1,240,32,0,56,90,7,0,21,0,0,0,1,240,48,0,184,83,7,0,21,0,0,0,1,240,64,0,248,79,7,0,21,0,0,0,1,240,80,0,208,76,7,0,21,0,0,0,1,240,96,0,176,96,7,0,21,0,0,0,1,240,112,0,56,73,7,0,21,0,0,0,1,240,128,0,208,68,7,0,21,0,0,0,1,240,144,0,96,64,7,0,21,0,0,0,1,240,160,0,104,59,7,0,21,0,0,0,1,240,176,0,0,53,7,0,21,0,0,0,1,240,192,0,240,47,7,0,21,0,0,0,1,240,208,0,40,41,7,0,21,0,0,0,1,240,224,0,208,36,7,0,21,0,0,0,1,240,240,0,128,103,7,0,21,0,0,0,255,255,255,0,0,0,0,0,22,0,0,0,255,255,255,0,0,0,0,0,23,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,168,234,7,0,21,0,0,0,1,1,0,0,96,135,7,0,21,0,0,0,1,1,1,0,152,182,7,0,0,0,0,0,254,0,2,0,32,176,1,0,21,0,0,0,1,2,2,0,192,255,2,0,21,0,0,0,1,2,0,0,208,75,4,0,0,0,0,0,254,0,8,0,200,87,7,0,21,0,0,0,1,28,16,0,40,88,7,0,21,0,0,0,1,28,12,0,96,39,7,0,21,0,0,0,1,28,28,0,144,251,6,0,21,0,0,0,1,28,4,0,120,211,6,0,21,0,0,0,1,28,24,0,184,164,6,0,21,0,0,0,1,28,8,0,24,1,7,0,21,0,0,0,1,28,20,0,80,74,6,0,21,0,0,0,1,28,0,0,16,227,4,0,0,0,0,0,254,0,8,0,160,123,6,0,21,0,0,0,1,224,224,0,144,251,6,0,21,0,0,0,1,224,96,0,160,157,2,0,21,0,0,0,1,224,192,0,184,164,6,0,21,0,0,0,1,224,128,0,88,156,2,0,21,0,0,0,1,224,32,0,24,1,7,0,21,0,0,0,1,224,64,0,120,155,2,0,21,0,0,0,1,224,160,0,80,74,6,0,21,0,0,0,1,224,0,0,16,227,4,0,0,0,0,0,254,0,4,0,128,129,4,0,22,0,0,0,1,3,2,0,192,255,2,0,22,0,0,0,1,3,3,0,208,75,4,0,22,0,0,0,1,3,1,0,8,49,4,0,22,0,0,0,1,3,0,0,152,21,4,0,0,0,0,0,254,0,4,0,72,202,5,0,22,0,0,0,1,12,8,0,80,246,3,0,22,0,0,0,1,12,12,0,248,38,7,0,22,0,0,0,1,12,4,0,112,212,3,0,22,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,2,0,112,153,2,0,22,0,0,0,1,16,16,0,184,151,2,0,22,0,0,0,1,16,0,0,88,244,4,0,0,0,0,0,254,0,2,0,80,111,3,0,22,0,0,0,1,32,32,0,88,244,4,0,22,0,0,0,1,32,0,0,0,212,5,0,0,0,0,0,254,0,2,0,144,212,8,0,22,0,0,0,1,64,64,0,96,135,7,0,22,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,22,0,0,0,1,128,128,0,96,135,7,0,22,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,18,0,0,0,255,255,255,0,0,0,0,0,19,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,72,202,5,0,18,0,0,0,1,6,0,0,80,246,3,0,18,0,0,0,1,6,6,0,248,38,7,0,18,0,0,0,1,6,2,0,112,212,3,0,18,0,0,0,1,6,4,0,248,160,5,0,0,0,0,0,254,0,2,0,232,75,4,0,18,0,0,0,1,8,8,0,96,135,7,0,18,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,18,0,0,0,1,32,0,0,96,135,7,0,18,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,18,0,0,0,1,192,0,0,208,75,4,0,18,0,0,0,1,192,192,0,8,49,4,0,18,0,0,0,1,192,128,0,152,21,4,0,18,0,0,0,1,192,64,0,72,246,3,0,0,0,0,0,254,0,8,0,160,123,6,0,19,0,0,0,1,28,0,0,96,135,3,0,19,0,0,0,1,28,16,0,32,136,7,0,19,0,0,0,1,28,8,0,40,88,7,0,19,0,0,0,1,28,24,0,96,39,7,0,19,0,0,0,1,28,28,0,144,251,6,0,19,0,0,0,1,28,12,0,184,164,6,0,19,0,0,0,1,28,20,0,80,74,6,0,19,0,0,0,1,28,4,0,192,32,6,0,0,0,0,0,254,0,8,0,200,87,7,0,19,0,0,0,1,224,0,0,96,135,3,0,19,0,0,0,1,224,128,0,32,136,7,0,19,0,0,0,1,224,64,0,40,88,7,0,19,0,0,0,1,224,192,0,96,39,7,0,19,0,0,0,1,224,224,0,144,251,6,0,19,0,0,0,1,224,96,0,184,164,6,0,19,0,0,0,1,224,160,0,80,74,6,0,19,0,0,0,1,224,32,0,192,32,6,0,17,0,0,0,255,255,255,0,0,0,0,0,18,0,0,0,255,255,251,0,0,0,0,0,0,0,0,0,254,0,11,0,200,87,7,0,17,0,0,0,1,15,7,0,32,136,7,0,17,0,0,0,1,15,8,0,40,88,7,0,17,0,0,0,1,15,9,0,96,39,7,0,17,0,0,0,1,15,15,0,144,251,6,0,17,0,0,0,1,15,6,0,120,211,6,0,17,0,0,0,1,15,14,0,184,164,6,0,17,0,0,0,1,15,13,0,80,74,6,0,17,0,0,0,1,15,12,0,192,32,6,0,17,0,0,0,1,15,11,0,192,234,2,0,17,0,0,0,1,15,10,0,32,242,5,0,17,0,0,0,1,15,0,0,8,75,5,0,0,0,0,0,254,0,11,0,160,123,6,0,17,0,0,0,1,240,112,0,32,136,7,0,17,0,0,0,1,240,128,0,40,88,7,0,17,0,0,0,1,240,144,0,96,39,7,0,17,0,0,0,1,240,240,0,144,251,6,0,17,0,0,0,1,240,96,0,120,211,6,0,17,0,0,0,1,240,224,0,184,164,6,0,17,0,0,0,1,240,208,0,80,74,6,0,17,0,0,0,1,240,192,0,192,32,6,0,17,0,0,0,1,240,176,0,192,234,2,0,17,0,0,0,1,240,160,0,32,242,5,0,17,0,0,0,1,240,0,0,144,44,2,0,0,0,0,0,254,0,2,0,232,75,4,0,18,0,0,0,1,1,1,0,96,135,7,0,18,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,18,0,0,0,1,8,0,0,96,135,7,0,18,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,18,0,0,0,1,48,32,0,24,205,7,0,18,0,0,0,1,48,16,0,192,255,2,0,18,0,0,0,1,48,48,0,208,75,4,0,18,0,0,0,1,48,0,0,8,49,4,0,0,0,0,0,254,0,4,0,72,202,5,0,18,0,0,0,1,192,64,0,80,246,3,0,18,0,0,0,1,192,192,0,248,38,7,0,18,0,0,0,1,192,128,0,112,212,3,0,18,0,0,0,1,192,0,0,248,160,5,0,50,46,51,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,96,127,118,230,0,0,16,1,51,46,51,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,144,105,186,90,0,0,16,1,49,54,99,53,55,104,115,46,48,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,76,45,0,0,117,147,126,192,0,0,16,1,52,46,51,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,188,143,98,111,0,0,32,0,53,46,51,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,82,23,155,106,0,0,32,0,54,46,51,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,82,248,28,65,0,0,32,0,55,46,51,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,253,129,92,99,0,0,32,0,56,46,51,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,77,100,73,39,0,0,32,0,57,46,51,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,175,151,24,29,0,0,32,0,49,48,46,51,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,46,67,3,42,0,0,32,0,49,49,46,51,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,76,12,152,44,0,0,32,0,49,46,48,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,220,113,102,255,0,0,64,0,15,0,0,0,255,255,74,0,0,0,0,0,16,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,128,112,3,0,15,0,0,0,1,1,0,0,168,22,4,0,15,0,0,0,1,1,1,0,176,176,7,0,0,0,0,0,254,0,2,0,144,100,7,0,15,0,0,0,1,4,0,0,56,111,3,0,15,0,0,0,1,4,4,0,104,134,3,0,0,0,0,0,254,0,3,0,72,202,5,0,15,0,0,0,1,48,48,0,248,38,7,0,15,0,0,0,1,48,16,0,112,212,3,0,15,0,0,0,1,48,0,0,24,99,5,0,0,0,0,0,254,0,2,0,104,159,3,0,15,0,0,0,1,64,0,0,56,111,3,0,15,0,0,0,1,64,64,0,104,134,3,0,0,0,0,0,254,0,2,0,40,111,8,0,15,0,0,0,1,128,128,0,96,135,7,0,15,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,96,46,8,0,16,0,0,0,1,1,1,0,208,233,4,0,16,0,0,0,1,1,0,0,72,197,4,0,0,0,0,0,254,0,16,0,152,167,4,0,16,0,0,0,1,30,20,0,176,73,5,0,16,0,0,0,1,30,22,0,104,54,4,0,16,0,0,0,1,30,20,0,80,252,6,0,16,0,0,0,1,30,24,0,16,242,7,0,16,0,0,0,1,30,26,0,40,28,4,0,16,0,0,0,1,30,2,0,104,236,7,0,16,0,0,0,1,30,4,0,96,135,3,0,16,0,0,0,1,30,6,0,120,113,6,0,16,0,0,0,1,30,30,0,128,230,7,0,16,0,0,0,1,30,8,0,120,211,6,0,16,0,0,0,1,30,18,0,184,164,6,0,16,0,0,0,1,30,16,0,80,74,6,0,16,0,0,0,1,30,14,0,192,32,6,0,16,0,0,0,1,30,12,0,192,234,2,0,16,0,0,0,1,30,10,0,32,242,5,0,16,0,0,0,1,30,0,0,16,227,4,0,0,0,0,0,254,0,2,0,72,72,1,0,16,0,0,0,1,32,32,0,192,255,2,0,16,0,0,0,1,32,0,0,208,75,4,0,0,0,0,0,112,114,103,50,46,105,99,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,150,10,76,245,0,0,16,1,112,114,103,49,46,105,99,51,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,10,16,85,44,0,0,16,1,98,99,115,116,114,121,95,117,46,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,212,114,160,59,0,0,16,1,112,114,111,116,100,97,116,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,140,50,78,232,0,0,16,1,98,99,115,116,114,121,95,117,46,49,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,122,211,4,235,0,0,32,0,98,99,115,116,114,121,95,117,46,49,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,215,205,110,116,0,0,32,0,98,99,115,116,114,121,95,117,46,49,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,195,101,254,27,0,0,32,0,98,99,115,116,114,121,95,117,46,49,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,60,58,191,200,0,0,32,0,98,99,115,116,114,121,95,117,46,49,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,237,203,17,140,0,0,32,0,98,99,115,116,114,121,95,117,46,49,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,191,188,25,82,0,0,32,0,98,99,115,116,114,121,95,117,46,57,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,135,175,177,205,0,0,32,0,98,99,115,116,114,121,95,117,46,49,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,150,181,102,129,0,0,32,0,98,99,115,116,114,121,95,117,46,49,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,113,12,124,55,0,0,32,0,98,99,115,116,114,121,95,117,46,49,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,237,7,35,68,0,0,32,0,98,99,115,116,114,121,95,117,46,49,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,206,14,180,113,0,0,32,0,98,99,115,116,114,121,95,117,46,49,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,58,146,60,171,0,0,32,0,98,99,115,116,114,121,95,117,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,254,224,240,35,0,0,64,0,56,55,99,53,50,46,109,99,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,16,34,0,0,0,255,255,191,0,0,0,0,0,35,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,34,0,0,0,1,3,2,0,208,75,4,0,34,0,0,0,1,3,3,0,8,49,4,0,34,0,0,0,1,3,1,0,152,21,4,0,34,0,0,0,1,3,0,0,72,246,3,0,0,0,0,0,254,0,4,0,72,202,5,0,34,0,0,0,1,12,8,0,80,246,3,0,34,0,0,0,1,12,12,0,80,124,6,0,34,0,0,0,1,12,4,0,112,212,3,0,34,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,2,0,104,159,3,0,34,0,0,0,1,32,0,0,56,111,3,0,34,0,0,0,1,32,32,0,104,134,3,0,0,0,0,0,254,0,2,0,168,234,7,0,34,0,0,0,1,64,64,0,96,135,7,0,34,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,34,0,0,0,1,128,128,0,96,135,7,0,34,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,35,0,0,0,1,1,1,0,96,135,7,0,35,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,4,0,200,30,2,0,35,0,0,0,1,6,4,0,96,90,6,0,35,0,0,0,1,6,6,0,40,16,8,0,35,0,0,0,1,6,2,0,184,11,8,0,35,0,0,0,1,6,0,0,152,4,8,0,0,0,0,0,254,0,2,0,96,46,8,0,35,0,0,0,1,8,8,0,192,255,2,0,35,0,0,0,1,8,0,0,208,75,4,0,0,0,0,0,254,0,16,0,32,4,2,0,35,0,0,0,1,240,160,0,144,160,3,0,35,0,0,0,1,240,176,0,96,135,3,0,35,0,0,0,1,240,192,0,32,136,7,0,35,0,0,0,1,240,208,0,40,88,7,0,35,0,0,0,1,240,224,0,96,39,7,0,35,0,0,0,1,240,16,0,32,202,2,0,35,0,0,0,1,240,48,0,120,113,6,0,35,0,0,0,1,240,32,0,232,228,5,0,35,0,0,0,1,240,240,0,144,251,6,0,35,0,0,0,1,240,64,0,120,211,6,0,35,0,0,0,1,240,144,0,184,164,6,0,35,0,0,0,1,240,128,0,80,74,6,0,35,0,0,0,1,240,112,0,192,32,6,0,35,0,0,0,1,240,96,0,192,234,2,0,35,0,0,0,1,240,80,0,32,242,5,0,35,0,0,0,1,240,0,0,16,227,4,0,0,0,0,0,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,165,188,15,21,1,0,16,1,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,208,79,98,177,1,0,16,1,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,136,65,119,147,1,0,16,1,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,108,236,148,138,1,0,16,1,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,97,148,102,163,1,0,16,1,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,254,251,30,250,1,0,16,1,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,189,222,119,155,1,0,16,1,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,126,23,102,100,1,0,16,1,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,31,123,101,26,4,0,32,0,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,229,72,43,122,4,0,32,0,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,22,0,87,155,4,0,32,0,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,68,98,149,115,4,0,32,0,108,48,54,95,112,114,111,109,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,135,125,12,106,7,0,32,0,13,0,0,0,255,255,0,0,0,0,0,0,14,0,0,0,255,255,192,0,0,0,0,0,15,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,200,87,7,0,14,0,0,0,1,64,64,0,128,103,7,0,14,0,0,0,1,64,0,0,80,196,7,0,0,0,0,0,254,0,2,0,160,123,6,0,14,0,0,0,1,128,128,0,0,90,2,0,14,0,0,0,1,128,0,0,104,61,2,0,0,0,0,0,254,0,2,0,64,37,5,0,15,0,0,0,1,1,0,0,152,53,6,0,15,0,0,0,1,1,1,0,8,49,6,0,0,0,0,0,254,0,2,0,128,129,4,0,15,0,0,0,1,4,0,0,8,49,4,0,15,0,0,0,1,4,4,0,72,246,3,0,0,0,0,0,254,0,2,0,200,30,2,0,15,0,0,0,1,8,0,0,120,97,1,0,15,0,0,0,1,8,8,0,96,19,1,0,98,116,99,106,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,141,22,126,107,1,0,16,1,98,116,99,106,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,103,52,186,70,1,0,16,1,98,116,99,106,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,89,168,35,14,1,0,16,1,98,116,99,106,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,156,181,83,168,1,0,16,1,98,116,99,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,219,213,34,115,1,0,16,1,98,116,99,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,171,133,172,106,1,0,16,1,98,116,99,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,8,219,3,18,1,0,16,1,98,116,99,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,173,91,112,220,5,0,32,0,98,116,99,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,60,154,119,229,5,0,32,0,98,116,99,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,18,65,63,179,5,0,32,0,98,116,99,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,126,219,252,166,5,0,32,0,98,116,99,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,16,67,25,30,10,0,16,1,98,116,99,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,230,184,174,1,10,0,16,1,98,116,99,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,41,34,127,194,12,0,64,0,98,116,99,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,51,46,138,65,12,0,64,0,98,116,99,101,100,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,109,219,55,7,1,0,16,1,98,116,99,101,100,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,35,136,26,239,1,0,16,1,98,116,99,101,100,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,20,187,189,32,1,0,16,1,98,116,99,101,100,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,188,245,216,180,1,0,16,1,98,116,99,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,219,213,34,115,1,0,16,1,98,116,99,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,171,133,172,106,1,0,16,1,98,116,99,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,8,219,3,18,1,0,16,1,98,116,99,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,173,91,112,220,5,0,32,0,98,116,99,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,60,154,119,229,5,0,32,0,98,116,99,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,18,65,63,179,5,0,32,0,98,116,99,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,126,219,252,166,5,0,32,0,98,116,99,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,16,67,25,30,10,0,16,1,98,116,99,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,230,184,174,1,10,0,16,1,98,116,99,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,41,34,127,194,12,0,64,0,98,116,99,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,51,46,138,65,12,0,64,0,98,116,99,97,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,135,13,210,26,1,0,16,1,98,116,99,97,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,190,77,63,43,1,0,16,1,98,116,99,97,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,217,163,56,130,1,0,16,1,98,116,99,97,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,2,124,108,68,1,0,16,1,98,116,99,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,219,213,34,115,1,0,16,1,98,116,99,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,171,133,172,106,1,0,16,1,98,116,99,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,8,219,3,18,1,0,16,1,98,116,99,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,173,91,112,220,5,0,32,0,98,116,99,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,60,154,119,229,5,0,32,0,98,116,99,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,18,65,63,179,5,0,32,0,98,116,99,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,126,219,252,166,5,0,32,0,98,116,99,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,16,67,25,30,10,0,16,1,98,116,99,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,230,184,174,1,10,0,16,1,98,116,99,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,41,34,127,194,12,0,64,0,98,116,99,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,51,46,138,65,12,0,64,0,50,55,99,48,49,48,46,117,114,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,153,27,181,95,0,0,16,1,50,55,99,48,49,48,46,117,114,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,218,253,193,169,0,0,16,1,50,55,99,48,52,48,46,117,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,133,227,4,6,0,0,32,0,50,55,99,49,54,48,46,117,110,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,76,218,121,74,0,0,32,0,50,55,99,49,54,48,46,117,110,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,68,140,239,191,0,0,32,0,50,55,99,48,52,48,46,117,115,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,239,104,99,124,0,0,64,0,115,111,117,110,100,46,109,99,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,16,16,112,103,109,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,167,252,160,23,1,0,16,1,112,103,109,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,72,152,101,20,1,0,16,1,112,103,109,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,151,251,96,143,1,0,16,1,103,102,120,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,3,184,175,245,4,0,32,0,103,102,120,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,209,229,150,174,4,0,32,0,108,48,54,95,112,114,111,109,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,135,125,12,106,7,0,32,0,14,0,0,0,255,255,0,0,0,0,0,0,15,0,0,0,255,255,0,0,0,0,0,0,16,0,0,0,255,255,0,0,0,0,0,0,17,0,0,0,255,255,1,0,0,0,0,0,0,0,0,0,254,0,2,0,128,129,4,0,15,0,0,0,1,128,0,0,8,49,4,0,15,0,0,0,1,128,128,0,72,246,3,0,0,0,0,0,254,0,2,0,32,4,2,0,16,0,0,0,1,1,1,0,224,127,8,0,16,0,0,0,1,1,0,0,32,123,8,0,0,0,0,0,254,0,2,0,64,37,5,0,16,0,0,0,1,2,0,0,136,120,6,0,16,0,0,0,1,2,2,0,176,114,3,0,0,0,0,0,254,0,2,0,200,30,2,0,16,0,0,0,1,8,0,0,120,97,1,0,16,0,0,0,1,8,8,0,96,19,1,0,0,0,0,0,254,0,4,0,72,202,5,0,17,0,0,0,1,3,3,0,80,246,3,0,17,0,0,0,1,3,1,0,248,38,7,0,17,0,0,0,1,3,2,0,112,212,3,0,17,0,0,0,1,3,0,0,24,99,5,0,0,0,0,0,101,112,114,45,49,51,52,52,54,46,97,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,42,123,245,209,1,0,16,1,101,112,114,45,49,51,52,52,52,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,95,4,43,122,1,0,16,1,101,112,114,45,49,51,52,52,55,46,97,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,103,33,165,112,1,0,16,1,101,112,114,45,49,51,52,52,53,46,97,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,221,195,223,40,1,0,16,1,109,112,114,45,49,51,52,53,48,46,97,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,168,167,196,15,2,0,32,0,109,112,114,45,49,51,52,54,53,46,98,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,224,53,129,224,2,0,32,0,109,112,114,45,49,51,52,53,49,46,97,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,47,133,73,28,2,0,32,0,109,112,114,45,49,51,52,54,54,46,98,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,132,102,76,225,2,0,32,0,109,112,114,45,49,51,52,53,50,46,97,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,94,222,123,4,2,0,32,0,109,112,114,45,49,51,52,54,55,46,98,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,196,254,9,99,2,0,32,0,109,112,114,45,49,51,52,53,51,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,248,169,160,95,3,0,32,0,109,112,114,45,49,51,52,53,55,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,218,84,27,13,3,0,32,0,109,112,114,45,49,51,52,53,52,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,177,51,107,95,3,0,32,0,109,112,114,45,49,51,52,53,56,46,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,195,64,211,186,3,0,32,0,109,112,114,45,49,51,52,53,53,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,11,82,128,78,3,0,32,0,109,112,114,45,49,51,52,53,57,46,98,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,172,101,145,126,3,0,32,0,109,112,114,45,49,51,52,53,54,46,98,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,40,196,51,87,3,0,32,0,109,112,114,45,49,51,52,54,48,46,98,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,179,249,184,102,3,0,32,0,109,112,114,45,49,51,52,52,48,46,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,43,11,55,79,3,0,32,0,109,112,114,45,49,51,52,54,49,46,98,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,191,20,96,247,3,0,32,0,109,112,114,45,49,51,52,52,49,46,97,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,180,156,207,55,3,0,32,0,109,112,114,45,49,51,52,54,50,46,98,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,218,231,97,16,3,0,32,0,109,112,114,45,49,51,52,52,50,46,97,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,239,152,150,4,3,0,32,0,109,112,114,45,49,51,52,54,51,46,98,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,241,251,188,125,3,0,32,0,109,112,114,45,49,51,52,52,51,46,97,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,158,152,168,119,3,0,32,0,109,112,114,45,49,51,52,54,52,46,98,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,34,244,29,85,3,0,32,0,101,112,114,45,49,51,52,52,56,46,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,185,63,24,181,4,0,16,1,109,112,114,45,49,51,52,52,57,46,97,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,249,170,217,211,8,0,64,0,51,49,55,45,48,49,54,55,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,146,23,45,188,5,0,16,1,101,112,114,45,49,51,52,54,57,46,97,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,157,182,40,198,1,0,16,1,101,112,114,45,49,51,52,54,56,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,24,34,9,206,1,0,16,1,101,112,114,45,49,51,52,52,55,46,97,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,103,33,165,112,1,0,16,1,101,112,114,45,49,51,52,52,53,46,97,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,221,195,223,40,1,0,16,1,109,112,114,45,49,51,52,53,48,46,97,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,168,167,196,15,2,0,32,0,109,112,114,45,49,51,52,54,53,46,98,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,224,53,129,224,2,0,32,0,109,112,114,45,49,51,52,53,49,46,97,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,47,133,73,28,2,0,32,0,109,112,114,45,49,51,52,54,54,46,98,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,132,102,76,225,2,0,32,0,109,112,114,45,49,51,52,53,50,46,97,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,94,222,123,4,2,0,32,0,109,112,114,45,49,51,52,54,55,46,98,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,196,254,9,99,2,0,32,0,109,112,114,45,49,51,52,53,51,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,248,169,160,95,3,0,32,0,109,112,114,45,49,51,52,53,55,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,218,84,27,13,3,0,32,0,109,112,114,45,49,51,52,53,52,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,177,51,107,95,3,0,32,0,109,112,114,45,49,51,52,53,56,46,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,195,64,211,186,3,0,32,0,109,112,114,45,49,51,52,53,53,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,11,82,128,78,3,0,32,0,109,112,114,45,49,51,52,53,57,46,98,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,172,101,145,126,3,0,32,0,109,112,114,45,49,51,52,53,54,46,98,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,40,196,51,87,3,0,32,0,109,112,114,45,49,51,52,54,48,46,98,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,179,249,184,102,3,0,32,0,109,112,114,45,49,51,52,52,48,46,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,43,11,55,79,3,0,32,0,109,112,114,45,49,51,52,54,49,46,98,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,191,20,96,247,3,0,32,0,109,112,114,45,49,51,52,52,49,46,97,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,180,156,207,55,3,0,32,0,109,112,114,45,49,51,52,54,50,46,98,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,218,231,97,16,3,0,32,0,109,112,114,45,49,51,52,52,50,46,97,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,239,152,150,4,3,0,32,0,109,112,114,45,49,51,52,54,51,46,98,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,241,251,188,125,3,0,32,0,109,112,114,45,49,51,52,52,51,46,97,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,158,152,168,119,3,0,32,0,109,112,114,45,49,51,52,54,52,46,98,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,34,244,29,85,3,0,32,0,101,112,114,45,49,51,52,52,56,46,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,185,63,24,181,4,0,16,1,109,112,114,45,49,51,52,52,57,46,97,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,249,170,217,211,8,0,64,0,51,49,55,45,48,49,54,56,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,146,23,45,188,5,0,16,1,97,112,45,116,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,71,16,66,151,1,0,16,1,97,112,45,116,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,86,254,101,92,1,0,16,1,97,112,45,116,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,244,88,46,51,2,0,32,0,97,112,45,116,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,44,18,220,221,2,0,32,0,97,112,45,116,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,107,205,94,239,2,0,32,0,17,0,0,0,255,255,255,0,0,0,0,0,18,0,0,0,255,255,47,0,0,0,0,0,0,0,0,0,254,0,8,0,200,87,7,0,17,0,0,0,1,56,0,0,80,252,6,0,17,0,0,0,1,56,32,0,16,242,7,0,17,0,0,0,1,56,24,0,104,236,7,0,17,0,0,0,1,56,56,0,128,230,7,0,17,0,0,0,1,56,16,0,184,164,6,0,17,0,0,0,1,56,40,0,80,74,6,0,17,0,0,0,1,56,8,0,192,32,6,0,17,0,0,0,1,56,48,0,192,234,2,0,0,0,0,0,254,0,8,0,160,123,6,0,17,0,0,0,1,7,0,0,80,252,6,0,17,0,0,0,1,7,4,0,16,242,7,0,17,0,0,0,1,7,3,0,104,236,7,0,17,0,0,0,1,7,7,0,128,230,7,0,17,0,0,0,1,7,2,0,184,164,6,0,17,0,0,0,1,7,5,0,80,74,6,0,17,0,0,0,1,7,1,0,192,32,6,0,17,0,0,0,1,7,6,0,192,234,2,0,0,0,0,0,254,0,4,0,128,129,4,0,17,0,0,0,1,192,192,0,192,255,2,0,17,0,0,0,1,192,128,0,208,75,4,0,17,0,0,0,1,192,64,0,8,49,4,0,17,0,0,0,1,192,0,0,72,246,3,0,0,0,0,0,254,0,4,0,72,202,5,0,18,0,0,0,1,3,1,0,80,246,3,0,18,0,0,0,1,3,3,0,248,38,7,0,18,0,0,0,1,3,2,0,112,212,3,0,18,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,2,0,104,81,2,0,18,0,0,0,1,4,4,0,96,135,7,0,18,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,18,0,0,0,1,8,8,0,96,135,7,0,18,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,18,0,0,0,1,16,16,0,96,135,7,0,18,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,18,0,0,0,1,32,0,0,96,135,7,0,18,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,168,79,2,0,18,0,0,0,1,64,64,0,8,79,2,0,18,0,0,0,1,64,0,0,104,78,2,0,0,0,0,0,254,0,2,0,232,75,4,0,18,0,0,0,1,128,0,0,96,135,7,0,18,0,0,0,1,128,128,0,152,182,7,0,11,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,72,4,1,0,11,0,0,0,1,4,0,0,96,135,7,0,11,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,254,0,2,0,32,181,6,0,11,0,0,0,1,8,0,0,96,135,7,0,11,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,11,0,0,0,1,128,0,0,96,135,7,0,11,0,0,0,1,128,128,0,152,182,7,0,14,0,0,0,255,255,255,0,0,0,0,0,15,0,0,0,255,255,255,0,0,0,0,0,16,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,8,0,200,87,7,0,14,0,0,0,1,7,1,0,32,136,7,0,14,0,0,0,1,7,2,0,40,88,7,0,14,0,0,0,1,7,4,0,96,39,7,0,14,0,0,0,1,7,7,0,144,251,6,0,14,0,0,0,1,7,3,0,120,211,6,0,14,0,0,0,1,7,6,0,184,164,6,0,14,0,0,0,1,7,5,0,80,74,6,0,14,0,0,0,1,7,0,0,16,227,4,0,0,0,0,0,254,0,8,0,160,123,6,0,14,0,0,0,1,56,8,0,32,136,7,0,14,0,0,0,1,56,16,0,40,88,7,0,14,0,0,0,1,56,32,0,96,39,7,0,14,0,0,0,1,56,56,0,144,251,6,0,14,0,0,0,1,56,24,0,120,211,6,0,14,0,0,0,1,56,48,0,184,164,6,0,14,0,0,0,1,56,40,0,80,74,6,0,14,0,0,0,1,56,0,0,16,227,4,0,0,0,0,0,254,0,2,0,168,234,7,0,14,0,0,0,1,64,0,0,96,135,7,0,14,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,0,0,144,212,8,0,15,0,0,0,1,1,1,0,96,135,7,0,15,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,15,0,0,0,1,2,2,0,96,135,7,0,15,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,72,202,5,0,15,0,0,0,1,12,8,0,80,246,3,0,15,0,0,0,1,12,12,0,248,38,7,0,15,0,0,0,1,12,4,0,112,212,3,0,15,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,4,0,128,129,4,0,15,0,0,0,1,48,0,0,208,75,4,0,15,0,0,0,1,48,48,0,8,49,4,0,15,0,0,0,1,48,16,0,152,21,4,0,15,0,0,0,1,48,32,0,72,246,3,0,0,0,0,0,254,0,4,0,64,37,5,0,15,0,0,0,1,192,192,0,120,7,5,0,15,0,0,0,1,192,0,0,216,116,2,0,15,0,0,0,1,192,128,0,64,114,2,0,15,0,0,0,1,192,64,0,8,113,2,0,0,0,0,0,101,112,114,45,49,51,48,57,53,46,97,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,66,7,212,85,1,0,16,1,101,112,114,45,49,51,48,57,52,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,249,5,179,146,1,0,16,1,101,112,114,45,49,51,48,55,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,97,10,93,223,2,0,32,0,101,112,114,45,49,51,48,55,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,184,250,122,120,2,0,32,0,101,112,114,45,49,51,48,55,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,119,180,1,78,2,0,32,0,109,112,114,45,49,51,48,56,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,4,183,130,167,3,0,32,0,109,112,114,45,49,51,48,56,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,240,39,66,42,3,0,32,0,109,112,114,45,49,51,48,56,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,40,2,81,235,3,0,32,0,109,112,114,45,49,51,48,56,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,85,76,107,59,3,0,32,0,109,112,114,45,49,51,48,56,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,251,238,104,230,3,0,32,0,109,112,114,45,49,51,48,56,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,125,66,147,34,3,0,32,0,101,112,114,45,49,51,48,55,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,237,33,146,222,3,0,32,0,101,112,114,45,49,51,48,56,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,196,113,154,140,3,0,32,0,101,112,114,45,49,51,48,56,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,32,175,243,93,4,0,16,1,101,112,114,45,49,51,48,55,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,110,199,230,148,19,0,64,0,101,112,114,45,49,51,48,55,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,141,13,236,226,19,0,64,0,101,112,114,45,49,51,48,55,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,197,77,104,21,19,0,64,0,51,49,55,45,48,49,52,55,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,167,75,213,63,5,0,16,1,101,112,114,45,49,51,48,56,53,46,97,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,45,78,247,21,1,0,16,1,101,112,114,45,49,51,48,56,52,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,143,179,135,150,1,0,16,1,101,112,114,45,49,51,48,55,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,97,10,93,223,2,0,32,0,101,112,114,45,49,51,48,55,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,184,250,122,120,2,0,32,0,101,112,114,45,49,51,48,55,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,119,180,1,78,2,0,32,0,109,112,114,45,49,51,48,56,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,4,183,130,167,3,0,32,0,109,112,114,45,49,51,48,56,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,240,39,66,42,3,0,32,0,109,112,114,45,49,51,48,56,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,40,2,81,235,3,0,32,0,109,112,114,45,49,51,48,56,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,85,76,107,59,3,0,32,0,109,112,114,45,49,51,48,56,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,251,238,104,230,3,0,32,0,109,112,114,45,49,51,48,56,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,125,66,147,34,3,0,32,0,101,112,114,45,49,51,48,55,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,237,33,146,222,3,0,32,0,101,112,114,45,49,51,48,56,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,196,113,154,140,3,0,32,0,101,112,114,45,49,51,48,56,51,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,95,75,155,22,4,0,16,1,101,112,114,45,49,51,48,55,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,110,199,230,148,19,0,64,0,101,112,114,45,49,51,48,55,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,141,13,236,226,19,0,64,0,101,112,114,45,49,51,48,55,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,197,77,104,21,19,0,64,0,51,49,55,45,48,49,52,54,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,197,145,73,233,5,0,16,1,101,112,114,45,49,51,49,54,53,46,97,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,129,211,252,110,1,0,16,1,101,112,114,45,49,51,49,54,52,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,198,147,214,151,1,0,16,1,101,112,114,45,49,51,48,55,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,97,10,93,223,2,0,32,0,101,112,114,45,49,51,48,55,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,184,250,122,120,2,0,32,0,101,112,114,45,49,51,48,55,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,119,180,1,78,2,0,32,0,109,112,114,45,49,51,48,56,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,4,183,130,167,3,0,32,0,109,112,114,45,49,51,48,56,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,240,39,66,42,3,0,32,0,109,112,114,45,49,51,48,56,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,40,2,81,235,3,0,32,0,109,112,114,45,49,51,48,56,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,85,76,107,59,3,0,32,0,109,112,114,45,49,51,48,56,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,251,238,104,230,3,0,32,0,109,112,114,45,49,51,48,56,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,125,66,147,34,3,0,32,0,101,112,114,45,49,51,48,55,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,237,33,146,222,3,0,32,0,101,112,114,45,49,51,48,56,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,196,113,154,140,3,0,32,0,101,112,114,45,49,51,48,56,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,32,175,243,93,4,0,16,1,101,112,114,45,49,51,48,55,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,110,199,230,148,19,0,64,0,101,112,114,45,49,51,48,55,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,141,13,236,226,19,0,64,0,101,112,114,45,49,51,48,55,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,197,77,104,21,19,0,64,0,51,49,55,45,48,49,52,56,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,74,182,228,114,5,0,16,1,19,0,0,0,255,255,254,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,19,0,0,0,1,1,0,0,120,97,1,0,19,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,2,2,0,96,135,7,0,19,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,4,4,0,96,135,7,0,19,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,8,0,0,96,135,7,0,19,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,32,4,2,0,19,0,0,0,1,48,0,0,32,136,7,0,19,0,0,0,1,48,16,0,40,88,7,0,19,0,0,0,1,48,32,0,96,39,7,0,19,0,0,0,1,48,48,0,144,251,6,0,0,0,0,0,254,0,4,0,48,112,3,0,19,0,0,0,1,192,0,0,40,88,7,0,19,0,0,0,1,192,64,0,96,39,7,0,19,0,0,0,1,192,128,0,144,251,6,0,19,0,0,0,1,192,192,0,80,75,3,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,3,2,0,80,246,3,0,20,0,0,0,1,3,3,0,80,124,6,0,20,0,0,0,1,3,1,0,112,212,3,0,20,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,64,37,5,0,20,0,0,0,1,12,8,0,136,53,6,0,20,0,0,0,1,12,12,0,248,48,6,0,20,0,0,0,1,12,4,0,168,43,6,0,20,0,0,0,1,12,0,0,80,39,6,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,48,0,0,192,255,2,0,20,0,0,0,1,48,16,0,208,75,4,0,20,0,0,0,1,48,48,0,8,49,4,0,20,0,0,0,1,48,32,0,152,21,4,0,0,0,0,0,254,0,2,0,104,159,3,0,20,0,0,0,1,64,0,0,96,135,7,0,20,0,0,0,1,64,64,0,152,182,7,0,19,0,0,0,255,255,254,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,19,0,0,0,1,1,0,0,120,97,1,0,19,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,2,2,0,96,135,7,0,19,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,4,4,0,96,135,7,0,19,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,8,0,0,96,135,7,0,19,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,19,0,0,0,1,48,16,0,96,39,7,0,19,0,0,0,1,48,48,0,144,251,6,0,19,0,0,0,1,48,0,0,120,211,6,0,19,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,19,0,0,0,1,192,64,0,96,39,7,0,19,0,0,0,1,192,192,0,144,251,6,0,19,0,0,0,1,192,0,0])
.concat([120,211,6,0,19,0,0,0,1,192,128,0,184,164,6,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,3,2,0,80,246,3,0,20,0,0,0,1,3,3,0,80,124,6,0,20,0,0,0,1,3,1,0,112,212,3,0,20,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,64,37,5,0,20,0,0,0,1,12,8,0,136,53,6,0,20,0,0,0,1,12,12,0,248,48,6,0,20,0,0,0,1,12,4,0,168,43,6,0,20,0,0,0,1,12,0,0,80,39,6,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,48,0,0,192,255,2,0,20,0,0,0,1,48,16,0,208,75,4,0,20,0,0,0,1,48,48,0,8,49,4,0,20,0,0,0,1,48,32,0,152,21,4,0,0,0,0,0,254,0,2,0,104,159,3,0,20,0,0,0,1,64,0,0,96,135,7,0,20,0,0,0,1,64,64,0,152,182,7,0,112,119,103,117,46,48,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,122,73,149,139,1,0,16,1,112,119,103,117,46,48,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,86,235,41,1,0,16,1,112,119,103,117,46,48,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,68,158,78,165,1,0,16,1,112,119,103,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,232,12,166,135,1,0,16,1,112,119,103,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,72,177,247,1,0,16,1,112,119,103,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,62,130,98,204,1,0,16,1,112,119,103,46,48,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,238,186,38,76,1,0,16,1,112,119,103,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,40,251,196,7,1,0,16,1,112,119,103,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,142,224,143,174,5,0,32,0,112,119,103,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,88,15,86,219,5,0,32,0,112,119,103,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,148,91,71,188,5,0,32,0,112,119,103,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,247,159,67,7,5,0,32,0,112,119,103,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,99,186,249,195,5,0,32,0,112,119,103,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,123,14,91,129,5,0,32,0,112,119,103,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,27,199,9,1,5,0,32,0,112,119,103,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,190,255,117,235,5,0,32,0,112,119,103,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,228,192,165,24,10,0,16,1,112,119,103,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,166,255,223,201,10,0,16,1,112,119,103,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,51,116,143,167,12,0,64,0,112,119,103,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,208,142,67,119,12,0,64,0,112,119,103,97,46,48,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,177,74,71,141,1,0,16,1,112,119,103,97,46,48,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,199,174,181,129,1,0,16,1,112,119,103,97,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,25,232,24,38,1,0,16,1,112,119,103,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,232,12,166,135,1,0,16,1,112,119,103,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,72,177,247,1,0,16,1,112,119,103,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,62,130,98,204,1,0,16,1,112,119,103,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,166,92,200,221,1,0,16,1,112,119,103,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,40,251,196,7,1,0,16,1,112,119,103,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,142,224,143,174,5,0,32,0,112,119,103,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,88,15,86,219,5,0,32,0,112,119,103,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,148,91,71,188,5,0,32,0,112,119,103,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,247,159,67,7,5,0,32,0,112,119,103,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,99,186,249,195,5,0,32,0,112,119,103,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,123,14,91,129,5,0,32,0,112,119,103,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,27,199,9,1,5,0,32,0,112,119,103,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,190,255,117,235,5,0,32,0,112,119,103,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,228,192,165,24,10,0,16,1,112,119,103,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,166,255,223,201,10,0,16,1,112,119,103,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,51,116,143,167,12,0,64,0,112,119,103,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,208,142,67,119,12,0,64,0,97,114,97,106,95,50,51,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,203,214,69,112,2,0,16,1,97,114,97,106,95,50,50,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,46,0,19,153,2,0,16,1,97,114,97,95,48,49,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,216,117,69,191,4,0,32,0,97,114,97,95,48,50,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,244,69,41,160,4,0,32,0,97,114,97,95,48,51,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,141,202,101,89,4,0,32,0,97,114,97,95,48,52,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,125,177,109,172,4,0,32,0,97,114,97,95,48,57,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,156,53,136,175,3,0,16,0,97,114,97,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,169,67,75,88,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,97,114,97,54,51,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,0,0,0,0,0,0,24,105,111,98,49,46,49,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,98,112,114,103,49,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,167,61,121,49,0,0,0,8,105,111,99,49,46,105,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,129,32,24,13,0,0,0,8,99,54,51,50,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,112,146,189,15,0,0,0,8,48,48,115,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,185,214,224,199,1,0,16,1,48,49,115,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,220,39,235,3,1,0,16,1,48,50,115,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,79,157,212,243,1,0,16,1,48,51,115,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,132,25,116,14,1,0,16,1,48,53,115,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,228,227,126,242,1,0,16,1,48,54,115,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,130,44,252,253,1,0,16,1,48,56,115,99,46,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,214,169,93,30,4,0,32,0,48,55,115,99,46,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,10,219,122,165,4,0,32,0,109,109,105,54,51,51,49,45,49,46,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,196,43,101,36,7,0,32,0,11,0,0,0,255,255,32,0,0,0,0,0,12,0,0,0,255,255,248,0,0,0,0,0,13,0,0,0,255,255,253,0,0,0,0,0,14,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,32,4,2,0,13,0,0,0,1,3,0,0,224,127,8,0,13,0,0,0,1,3,1,0,32,123,8,0,13,0,0,0,1,3,2,0,192,110,8,0,13,0,0,0,1,3,3,0,96,102,7,0,0,0,0,0,16,0,0,0,255,255,6,0,0,0,0,0,17,0,0,0,255,255,13,0,0,0,0,0,0,0,0,0,254,0,2,0,128,129,4,0,16,0,0,0,1,1,0,0,8,49,4,0,16,0,0,0,1,1,1,0,72,246,3,0,0,0,0,0,254,0,2,0,200,30,2,0,16,0,0,0,1,2,2,0,120,97,1,0,16,0,0,0,1,2,0,0,96,19,1,0,0,0,0,0,254,0,2,0,144,212,8,0,16,0,0,0,1,4,4,0,96,135,7,0,16,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,72,202,5,0,16,0,0,0,1,8,0,0,80,246,3,0,16,0,0,0,1,8,8,0,112,212,3,0,0,0,0,0,254,0,16,0,32,4,2,0,16,0,0,0,1,240,16,0,200,252,3,0,16,0,0,0,1,240,32,0,208,244,3,0,16,0,0,0,1,240,0,0,240,235,3,0,16,0,0,0,1,240,48,0,176,110,4,0,16,0,0,0,1,240,64,0,32,227,3,0,16,0,0,0,1,240,80,0,200,215,5,0,16,0,0,0,1,240,96,0,48,224,3,0,16,0,0,0,1,240,112,0,144,219,3,0,16,0,0,0,1,240,128,0,128,214,3,0,16,0,0,0,1,240,144,0,240,79,5,0,16,0,0,0,1,240,160,0,32,50,5,0,16,0,0,0,1,240,224,0,16,19,5,0,16,0,0,0,1,240,176,0,104,240,4,0,16,0,0,0,1,240,192,0,88,206,4,0,16,0,0,0,1,240,208,0,96,172,4,0,16,0,0,0,1,240,240,0,16,227,4,0,0,0,0,0,254,0,2,0,152,112,4,0,17,0,0,0,1,1,1,0,192,255,2,0,17,0,0,0,1,1,0,0,208,75,4,0,0,0,0,0,254,0,2,0,168,234,7,0,17,0,0,0,1,2,2,0,96,135,7,0,17,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,4,0,64,37,5,0,17,0,0,0,1,12,12,0,96,67,3,0,17,0,0,0,1,12,4,0,152,195,3,0,17,0,0,0,1,12,8,0,160,169,3,0,17,0,0,0,1,12,0,0,120,7,5,0,97,109,105,100,97,114,117,115,46,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,146,7,30,149,1,0,16,1,97,109,105,100,97,114,117,115,46,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,54,161,163,161,1,0,16,1,97,109,105,100,97,114,117,115,46,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,245,27,18,165,1,0,16,1,97,109,105,100,97,114,117,115,46,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,127,28,29,5,1,0,16,1,97,109,105,100,97,114,117,115,46,50,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,213,0,31,53,1,0,16,1,97,109,105,100,97,114,117,115,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,80,183,167,140,2,0,16,1,97,109,105,100,97,114,117,115,46,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,10,220,91,155,2,0,16,1,97,109,105,100,97,114,117,115,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,222,94,254,44,4,0,32,0,97,109,105,100,97,114,117,115,46,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,13,253,196,87,4,0,32,0,97,109,105,100,97,114,46,99,108,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,195,220,64,249,7,0,32,0,16,0,0,0,255,255,0,0,0,0,0,0,17,0,0,0,255,255,0,0,0,0,0,0,18,0,0,0,255,255,6,0,0,0,0,0,19,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,17,0,0,0,1,3,0,0,8,49,4,0,17,0,0,0,1,3,1,0,152,21,4,0,17,0,0,0,1,3,2,0,72,246,3,0,17,0,0,0,1,3,3,0,200,28,2,0,0,0,0,0,254,0,2,0,168,234,7,0,18,0,0,0,1,2,0,0,96,135,7,0,18,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,2,0,64,37,5,0,18,0,0,0,1,4,4,0,176,123,2,0,18,0,0,0,1,4,0,0,96,173,1,0,0,0,0,0,254,0,16,0,200,87,7,0,19,0,0,0,1,15,11,0,144,102,8,0,19,0,0,0,1,15,5,0,176,45,8,0,19,0,0,0,1,15,14,0,224,127,8,0,19,0,0,0,1,15,13,0,136,252,1,0,19,0,0,0,1,15,7,0,0,67,1,0,19,0,0,0,1,15,0,0,32,123,8,0,19,0,0,0,1,15,3,0,232,143,1,0,19,0,0,0,1,15,1,0,248,116,8,0,19,0,0,0,1,15,8,0,192,110,8,0,19,0,0,0,1,15,9,0,168,36,1,0,19,0,0,0,1,15,4,0,96,102,7,0,19,0,0,0,1,15,12,0,184,105,6,0,19,0,0,0,1,15,2,0,152,96,3,0,19,0,0,0,1,15,10,0,192,100,6,0,19,0,0,0,1,15,6,0,64,1,1,0,19,0,0,0,1,15,15,0,16,227,4,0,0,0,0,0,254,0,16,0,160,123,6,0,19,0,0,0,1,240,176,0,144,102,8,0,19,0,0,0,1,240,80,0,176,45,8,0,19,0,0,0,1,240,224,0,224,127,8,0,19,0,0,0,1,240,208,0,136,252,1,0,19,0,0,0,1,240,112,0,0,67,1,0,19,0,0,0,1,240,0,0,32,123,8,0,19,0,0,0,1,240,48,0,232,143,1,0,19,0,0,0,1,240,16,0,248,116,8,0,19,0,0,0,1,240,128,0,192,110,8,0,19,0,0,0,1,240,144,0,168,36,1,0,19,0,0,0,1,240,64,0,96,102,7,0,19,0,0,0,1,240,192,0,184,105,6,0,19,0,0,0,1,240,32,0,152,96,3,0,19,0,0,0,1,240,160,0,192,100,6,0,19,0,0,0,1,240,96,0,64,1,1,0,19,0,0,0,1,240,240,0,48,170,1,0,0,0,0,0,97,109,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,71,149,183,36,1,0,16,1,97,109,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,30,22,100,76,1,0,16,1,97,109,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,114,122,152,179,1,0,16,1,97,109,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,97,52,135,41,1,0,16,1,97,109,50,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,216,84,221,15,1,0,16,1,97,109,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,237,247,130,83,1,0,16,1,97,109,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,233,9,113,29,1,0,16,1,97,109,50,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,198,58,22,201,1,0,16,1,97,109,105,100,97,114,117,115,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,80,183,167,140,2,0,16,1,97,109,105,100,97,114,117,115,46,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,10,220,91,155,2,0,16,1,50,55,49,54,46,97,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,10,173,130,32,4,0,32,0,50,55,49,54,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,79,249,41,48,4,0,32,0,97,109,105,100,97,114,46,99,108,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,195,220,64,249,7,0,32,0,16,0,0,0,255,255,0,0,0,0,0,0,17,0,0,0,255,255,1,0,0,0,0,0,18,0,0,0,255,255,10,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,17,0,0,0,1,3,0,0,208,75,4,0,17,0,0,0,1,3,1,0,8,49,4,0,17,0,0,0,1,3,2,0,152,21,4,0,17,0,0,0,1,3,3,0,240,64,4,0,0,0,0,0,254,0,2,0,32,4,2,0,18,0,0,0,1,2,2,0,200,209,1,0,18,0,0,0,1,2,0,0,144,147,2,0,0,0,0,0,254,0,2,0,200,30,2,0,18,0,0,0,1,8,8,0,120,97,1,0,18,0,0,0,1,8,0,0,96,19,1,0,49,48,55,46,50,99,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,190,54,37,197,1,0,16,1,49,48,56,46,50,102,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,152,139,83,56,1,0,16,1,49,48,57,46,50,102,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,15,127,144,105,1,0,16,1,49,49,48,46,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,147,154,20,186,1,0,16,1,49,49,49,46,50,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,46,28,208,32,1,0,16,1,97,109,105,100,97,114,117,115,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,80,183,167,140,2,0,16,1,97,109,105,100,97,114,117,115,46,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,10,220,91,155,2,0,16,1,97,109,105,100,97,114,117,115,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,222,94,254,44,4,0,32,0,49,49,51,46,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,104,225,220,188,4,0,32,0,97,109,105,100,97,114,46,99,108,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,195,220,64,249,7,0,32,0,16,0,0,0,255,255,0,0,0,0,0,0,17,0,0,0,255,255,2,0,0,0,0,0,18,0,0,0,255,255,6,0,0,0,0,0,19,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,17,0,0,0,1,3,0,0,192,255,2,0,17,0,0,0,1,3,1,0,208,75,4,0,17,0,0,0,1,3,2,0,8,49,4,0,17,0,0,0,1,3,3,0,152,21,4,0,0,0,0,0,254,0,2,0,176,174,1,0,18,0,0,0,1,2,2,0,248,81,6,0,18,0,0,0,1,2,0,0,176,64,8,0,0,0,0,0,254,0,2,0,64,37,5,0,18,0,0,0,1,4,4,0,176,123,2,0,18,0,0,0,1,4,0,0,96,173,1,0,0,0,0,0,254,0,16,0,200,87,7,0,19,0,0,0,1,15,11,0,144,102,8,0,19,0,0,0,1,15,5,0,176,45,8,0,19,0,0,0,1,15,14,0,224,127,8,0,19,0,0,0,1,15,13,0,136,252,1,0,19,0,0,0,1,15,7,0,0,67,1,0,19,0,0,0,1,15,0,0,32,123,8,0,19,0,0,0,1,15,3,0,232,143,1,0,19,0,0,0,1,15,1,0,248,116,8,0,19,0,0,0,1,15,8,0,192,110,8,0,19,0,0,0,1,15,9,0,168,36,1,0,19,0,0,0,1,15,4,0,96,102,7,0,19,0,0,0,1,15,12,0,184,105,6,0,19,0,0,0,1,15,2,0,152,96,3,0,19,0,0,0,1,15,10,0,192,100,6,0,19,0,0,0,1,15,6,0,64,1,1,0,19,0,0,0,1,15,15,0,16,227,4,0,0,0,0,0,254,0,16,0,160,123,6,0,19,0,0,0,1,240,176,0,144,102,8,0,19,0,0,0,1,240,80,0,176,45,8,0,19,0,0,0,1,240,224,0,224,127,8,0,19,0,0,0,1,240,208,0,136,252,1,0,19,0,0,0,1,240,112,0,0,67,1,0,19,0,0,0,1,240,0,0,32,123,8,0,19,0,0,0,1,240,48,0,232,143,1,0,19,0,0,0,1,240,16,0,248,116,8,0,19,0,0,0,1,240,128,0,192,110,8,0,19,0,0,0,1,240,144,0,168,36,1,0,19,0,0,0,1,240,64,0,96,102,7,0,19,0,0,0,1,240,192,0,184,105,6,0,19,0,0,0,1,240,32,0,152,96,3,0,19,0,0,0,1,240,160,0,192,100,6,0,19,0,0,0,1,240,96,0,64,1,1,0,19,0,0,0,1,240,240,0,48,170,1,0,0,0,0,0,97,109,105,50,103,111,114,46,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,210,220,210,154,1,0,16,1,50,46,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,245,47,40,102,1,0,16,1,51,46,50,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,49,14,134,176,1,0,16,1,52,46,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,201,134,64,74,1,0,16,1,56,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,80,183,167,140,2,0,16,1,57,46,57,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,10,220,91,155,2,0,16,1,53,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,10,173,130,32,4,0,32,0,54,46,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,79,249,41,48,4,0,32,0,110,56,50,115,49,50,51,110,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,63,77,0,1,7,0,32,0,97,109,105,100,97,114,46,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,39,191,148,194,1,0,16,1,97,109,105,100,97,114,46,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,38,104,233,230,1,0,16,1,97,109,105,100,97,114,46,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,111,190,86,54,1,0,16,1,97,109,105,100,97,114,46,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,189,112,225,27,1,0,16,1,97,109,105,100,97,114,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,228,106,182,196,2,0,16,1,97,109,105,100,97,114,46,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,175,133,103,128,2,0,16,1,97,109,105,100,97,114,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,77,232,81,94,4,0,32,0,97,109,105,100,97,114,46,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,48,28,127,47,4,0,32,0,97,109,105,100,97,114,46,99,108,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,195,220,64,249,7,0,32,0,0,0,0,80,65,83,69,75,73,83,85,71,69,82,0,0,0,64,75,14,84,65,68,85,78,79,14,14,0,0,0,48,78,65,65,75,69,75,68,85,78,79,0,0,0,32,14,14,73,75,85,84,69,78,14,14,0,0,0,16,75,14,75,65,83,69,66,79,14,65,249,78,0,0,250,98,0,0,249,78,0,0,94,128,0,0,0,200,98,46,50,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,206,60,153,140,0,0,16,1,97,46,55,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,92,175,199,163,0,0,16,1,102,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,233,76,244,77,0,0,32,0,48,57,104,95,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,31,126,229,37,0,0,32,0,49,48,104,95,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,233,229,13,207,0,0,32,0,49,49,104,95,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,72,192,80,64,0,0,32,0,101,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,210,199,251,232,0,0,32,0,100,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,107,21,212,197,0,0,32,0,99,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,177,223,145,222,0,0,32,0,48,49,106,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,163,178,148,106,0,0,32,0,48,49,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,211,35,9,236,0,0,32,0,48,49,102,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,82,112,233,173,0,0,32,0,109,49,46,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,1,146,163,131,0,0,32,0,112,97,108,49,54,108,56,97,46,50,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,0,0,0,24,101,112,108,49,50,112,54,97,46,57,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,52,0,0,0,20,143,128,25,0,0,0,8,101,112,108,49,50,112,54,97,46,57,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,52,0,0,0,133,173,172,245,0,0,0,8,18,0,0,0,255,255,187,0,0,0,0,0,19,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,18,0,0,0,1,3,3,0,152,21,4,0,18,0,0,0,1,3,2,0,72,246,3,0,18,0,0,0,1,3,1,0,72,0,3,0,18,0,0,0,1,3,0,0,64,47,7,0,0,0,0,0,254,0,2,0,104,159,3,0,18,0,0,0,1,4,4,0,96,135,7,0,18,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,129,2,0,18,0,0,0,1,8,8,0,96,135,7,0,18,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,246,3,0,18,0,0,0,1,16,16,0,96,135,7,0,18,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,2,0,112,104,5,0,18,0,0,0,1,32,32,0,96,135,7,0,18,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,200,30,2,0,18,0,0,0,1,64,0,0,120,97,1,0,18,0,0,0,1,64,64,0,96,19,1,0,0,0,0,0,254,0,2,0,72,4,1,0,18,0,0,0,1,128,128,0,96,135,7,0,18,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,8,0,200,87,7,0,19,0,0,0,1,7,2,0,224,127,8,0,19,0,0,0,1,7,1,0,136,252,1,0,19,0,0,0,1,7,7,0,32,123,8,0,19,0,0,0,1,7,6,0,192,110,8,0,19,0,0,0,1,7,5,0,96,102,7,0,19,0,0,0,1,7,4,0,184,105,6,0,19,0,0,0,1,7,3,0,192,100,6,0,19,0,0,0,1,7,0,0,104,151,6,0,0,0,0,0,254,0,8,0,160,123,6,0,19,0,0,0,1,56,0,0,96,164,8,0,19,0,0,0,1,56,8,0,144,102,8,0,19,0,0,0,1,56,16,0,176,45,8,0,19,0,0,0,1,56,24,0,224,127,8,0,19,0,0,0,1,56,56,0,32,123,8,0,19,0,0,0,1,56,32,0,232,143,1,0,19,0,0,0,1,56,48,0,192,110,8,0,19,0,0,0,1,56,40,0,96,102,7,0,0,0,0,0,22,0,0,0,255,255,191,0,0,0,0,0,23,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,22,0,0,0,1,3,2,0,208,75,4,0,22,0,0,0,1,3,3,0,8,49,4,0,22,0,0,0,1,3,1,0,152,21,4,0,22,0,0,0,1,3,0,0,72,246,3,0,0,0,0,0,254,0,4,0,72,202,5,0,22,0,0,0,1,12,0,0,160,203,8,0,22,0,0,0,1,12,8,0,80,246,3,0,22,0,0,0,1,12,12,0,248,38,7,0,22,0,0,0,1,12,4,0,112,212,3,0,0,0,0,0,254,0,2,0,144,212,8,0,23,0,0,0,1,1,1,0,96,135,7,0,23,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,101,112,114,45,49,48,57,52,48,46,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,78,44,19,77,1,0,16,1,101,112,114,45,49,48,57,52,49,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,100,162,110,19,1,0,16,1,101,112,114,45,49,48,57,50,55,46,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,87,103,211,102,9,0,16,1,101,112,114,45,49,48,57,50,56,46,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,11,212,1,124,9,0,16,1,101,112,114,45,49,48,57,50,54,46,49,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,50,214,139,237,2,0,32,0,101,112,114,45,49,48,57,50,53,46,49,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,204,72,240,78,2,0,32,0,101,112,114,45,49,48,57,50,52,46,49,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,109,90,193,80,2,0,32,0,109,112,114,45,49,48,57,51,50,46,57,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,214,33,8,204,3,0,32,0,109,112,114,45,49,48,57,51,52,46,57,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,250,177,81,74,3,0,32,0,109,112,114,45,49,48,57,51,54,46,57,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,100,13,167,173,3,0,32,0,109,112,114,45,49,48,57,51,56,46,49,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,175,91,103,231,3,0,32,0,109,112,114,45,49,48,57,51,51,46,57,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,195,178,239,200,3,0,32,0,109,112,114,45,49,48,57,51,53,46,57,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,33,53,226,193,3,0,32,0,109,112,114,45,49,48,57,51,55,46,57,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,88,150,25,240,3,0,32,0,109,112,114,45,49,48,57,51,57,46,49,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,128,148,212,160,3,0,32,0,101,112,114,45,49,48,57,52,50,46,57,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,140,11,225,92,3,0,32,0,101,112,114,45,49,48,57,52,51,46,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,220,148,130,185,3,0,32,0,101,112,114,45,49,48,57,52,52,46,49,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,103,143,190,23,3,0,32,0,101,112,114,45,49,48,57,52,53,46,49,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,79,76,77,223,3,0,32,0,101,112,114,45,49,48,57,52,54,46,57,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,244,133,212,215,3,0,32,0,101,112,114,45,49,48,57,52,55,46,57,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,146,131,131,8,3,0,32,0,101,112,114,45,49,48,57,52,56,46,49,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,97,71,40,100,3,0,32,0,101,112,114,45,49,48,57,52,57,46,49,48,53,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,146,125,67,216,3,0,32,0,101,112,114,45,49,48,57,50,50,46,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,212,131,145,180,10,0,32,0,101,112,114,45,49,48,57,50,51,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,143,235,136,104,4,0,16,1,109,112,114,45,49,48,57,51,49,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,143,6,9,146,11,0,64,0,109,112,114,45,49,48,57,51,48,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,139,54,147,100,11,0,64,0,101,112,114,45,49,49,49,48,50,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,141,199,7,108,11,0,64,0,11,0,0,0,255,255,255,0,0,0,0,0,12,0,0,0,255,255,193,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,11,0,0,0,1,15,7,0,80,252,6,0,11,0,0,0,1,15,8,0,16,242,7,0,11,0,0,0,1,15,9,0,104,236,7,0,11,0,0,0,1,15,5,0,176,51,4,0,11,0,0,0,1,15,4,0,56,24,4,0,11,0,0,0,1,15,15,0,128,230,7,0,11,0,0,0,1,15,1,0,72,216,3,0,11,0,0,0,1,15,2,0,24,188,3,0,11,0,0,0,1,15,3,0,176,162,3,0,11,0,0,0,1,15,6,0,120,211,6,0,11,0,0,0,1,15,14,0,184,164,6,0,11,0,0,0,1,15,13,0,80,74,6,0,11,0,0,0,1,15,12,0,192,32,6,0,11,0,0,0,1,15,11,0,192,234,2,0,11,0,0,0,1,15,10,0,32,242,5,0,11,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,11,0,0,0,1,240,112,0,80,252,6,0,11,0,0,0,1,240,128,0,16,242,7,0,11,0,0,0,1,240,144,0,104,236,7,0,11,0,0,0,1,240,80,0,176,51,4,0,11,0,0,0,1,240,64,0,56,24,4,0,11,0,0,0,1,240,240,0,128,230,7,0,11,0,0,0,1,240,16,0,72,216,3,0,11,0,0,0,1,240,32,0,24,188,3,0,11,0,0,0,1,240,48,0,176,162,3,0,11,0,0,0,1,240,96,0,120,211,6,0,11,0,0,0,1,240,224,0,184,164,6,0,11,0,0,0,1,240,208,0,80,74,6,0,11,0,0,0,1,240,192,0,192,32,6,0,11,0,0,0,1,240,176,0,192,234,2,0,11,0,0,0,1,240,160,0,32,242,5,0,11,0,0,0,1,240,0,0,208,236,2,0,0,0,0,0,254,0,4,0,64,251,5,0,12,0,0,0,1,3,3,0,32,236,6,0,12,0,0,0,1,3,2,0,16,232,6,0,12,0,0,0,1,3,1,0,80,228,6,0,12,0,0,0,1,3,0,0,16,223,6,0,0,0,0,0,254,0,2,0,168,234,7,0,12,0,0,0,1,4,4,0,96,135,7,0,12,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,128,129,4,0,12,0,0,0,1,16,16,0,8,49,4,0,12,0,0,0,1,16,0,0,200,217,6,0,0,0,0,0,254,0,2,0,104,159,3,0,12,0,0,0,1,32,32,0,56,111,3,0,12,0,0,0,1,32,0,0,104,134,3,0,0,0,0,0,254,0,4,0,72,202,5,0,12,0,0,0,1,192,128,0,80,246,3,0,12,0,0,0,1,192,192,0,248,38,7,0,12,0,0,0,1,192,64,0,112,212,3,0,12,0,0,0,1,192,0,0,248,160,5,0,0,0,0,0,184,40,2,0,1,0,0,0,214,155,215,0,248,191,2,0,56,250,6,0,1,0,0,0,211,155,215,0,184,160,2,0,184,164,8,0,1,0,0,0,215,155,215,0,64,246,1,0,8,3,3,0,4,0,0,0,112,156,215,0,208,13,4,0,208,240,5,0,4,0,0,0,104,156,215,0,152,30,2,0,0,229,5,0,1,0,0,0,213,155,215,0,232,10,2,0,16,17,8,0,1,0,0,0,210,155,215,0,224,12,8,0,32,77,1,0,1,0,0,0,209,155,215,0,216,70,1,0,88,212,3,0,1,0,0,0,200,154,215,0,40,185,3,0,248,5,8,0,9,0,0,0,0,156,215,0,32,58,1,0,144,250,7,0,9,0,0,0,1,156,215,0,32,58,1,0,48,55,48,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,62,32,150,90,1,0,16,1,48,55,48,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,216,2,173,248,3,0,32,0,48,55,48,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,222,109,21,112,3,0,32,0,48,55,48,45,101,112,114,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,145,49,59,90,4,0,16,1,48,55,48,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,255,225,167,211,5,0,64,0,48,54,53,45,97,100,97,48,52,46,49,48,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,36,102,39,184,1,0,16,1,48,54,53,45,97,100,97,48,53,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,173,130,133,198,1,0,16,1,48,54,53,45,97,48,50,46,57,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,76,196,29,179,1,0,16,1,48,54,53,45,97,48,51,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,230,47,132,19,1,0,16,1,48,54,53,45,97,48,49,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,77,58,125,20,2,0,16,1,48,54,53,45,97,48,56,46,49,53,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,202,154,100,107,3,0,32,0,48,54,53,45,97,48,55,46,49,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,196,143,220,197,3,0,32,0,48,54,53,45,97,48,57,46,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,47,213,5,234,4,0,32,0,48,54,53,45,97,49,48,46,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,2,24,185,150,4,0,32,0,48,54,53,45,97,49,50,46,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,122,208,30,50,4,0,32,0,48,54,53,45,97,49,49,46,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,142,148,218,70,4,0,32,0,48,54,53,45,97,48,54,46,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,224,206,219,90,5,0,64,0,120,109,101,110,95,97,100,97,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,145,56,122,167,0,0,0,8,119,105,103,103,105,101,46,101,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,22,143,181,36,1,0,16,1,119,105,103,103,105,101,46,101,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,219,110,186,131,1,0,16,1,119,105,103,103,105,101,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,123,215,120,128,2,0,16,1,119,105,103,103,105,101,46,106,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,138,11,180,79,3,0,32,0,119,105,103,103,105,101,46,106,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,233,24,196,235,3,0,32,0,119,105,103,103,105,101,46,106,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,27,80,115,192,3,0,32,0,119,105,103,103,105,101,46,106,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,57,250,246,34,3,0,32,0,119,105,103,103,105,101,46,100,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,42,225,251,39,6,0,64,0,114,111,109,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,27,175,67,206,0,0,16,1,114,111,109,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,5,167,137,183,0,0,16,1,114,111,109,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,115,219,52,102,1,0,32,0,114,111,109,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,44,156,244,121,1,0,32,0,114,111,109,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,79,253,132,56,1,0,32,0,55,52,115,50,56,56,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,147,226,227,131,2,0,32,0,118,117,108,103,117,115,46,48,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,93,108,157,228,1,0,16,1,118,117,108,103,117,115,46,48,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,118,239,172,81,1,0,16,1,118,117,108,103,117,115,46,48,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,96,127,158,72,1,0,16,1,118,117,108,103,117,115,46,48,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,168,36,58,222,1,0,16,1,49,45,56,110,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,65,202,165,108,1,0,16,1,49,45,49,49,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,244,172,210,59,2,0,16,1,49,45,51,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,165,215,197,139,3,0,32,0,50,45,50,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,161,172,10,225,4,0,32,0,50,45,51,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,218,32,165,141,4,0,32,0,50,45,52,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,241,19,106,32,4,0,32,0,50,45,53,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,132,25,216,182,4,0,32,0,50,45,54,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,143,179,38,90,4,0,32,0,50,45,55,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,115,167,28,30,4,0,32,0,50,45,50,110,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,13,177,177,109,5,0,32,0,50,45,51,110,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,236,52,140,93,5,0,32,0,50,45,52,110,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,227,162,113,0,5,0,32,0,50,45,53,110,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,236,161,35,64,5,0,32,0,101,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,6,54,168,6,6,0,32,0,101,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,60,241,172,190,6,0,32,0,101,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,33,182,31,222,6,0,32,0,100,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,13,8,121,113,6,0,32,0,106,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,41,32,132,208,6,0,32,0,99,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,214,11,31,122,6,0,32,0,56,50,115,49,50,54,46,57,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,33,5,177,50,0,0,0,8,56,50,115,49,50,57,46,56,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,92,99,33,73,0,0,0,8,55,56,53,95,119,48,53,46,54,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,205,153,14,110,1,0,16,1,55,56,53,95,119,48,52,46,52,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,202,116,236,35,1,0,16,1,55,56,53,95,119,48,57,46,54,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,40,79,126,55,1,0,16,1,55,56,53,95,119,48,56,46,52,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,234,65,61,129,1,0,16,1,55,56,53,95,112,48,55,46,49,48,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,157,84,109,104,2,0,16,1,55,56,53,95,112,48,54,46,56,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,238,75,201,112,2,0,16,1,55,56,53,95,112,49,51,46,49,48,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,10,219,143,71,2,0,16,1,55,56,53,95,112,49,50,46,56,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,42,64,234,56,2,0,16,1,55,56,53,95,103,48,51,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,13,181,163,103,3,0,16,1,55,56,53,95,104,49,52,46,100,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,111,177,244,2,4,0,32,0,55,56,53,102,49,55,46,112,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,164,193,190,143,5,0,32,0,55,56,53,102,49,56,46,112,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,56,30,214,80,5,0,32,0,55,56,53,102,49,53,46,112,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,243,174,150,175,5,0,32,0,55,56,53,102,49,54,46,112,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,31,223,88,184,5,0,32,0,55,56,53,95,102,48,49,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,158,214,216,160,7,0,64,0,55,56,53,95,102,48,50,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,164,92,159,195,8,0,64,0,53,98,46,117,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,108,172,51,73,1,0,16,1,54,98,46,117,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,213,57,185,78,1,0,16,1,49,46,117,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,104,193,112,180,2,0,32,0,50,46,117,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,96,141,111,179,2,0,32,0,51,46,117,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,101,167,252,0,2,0,32,0,52,46,117,51,48,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,156,164,37,90,2,0,32,0,56,46,117,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,28,0,76,193,3,0,64,0,55,46,117,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,241,82,140,168,4,0,64,0,22,0,0,0,255,255,255,0,0,0,0,0,23,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,8,0,32,4,2,0,22,0,0,0,1,7,5,0,40,88,7,0,22,0,0,0,1,7,6,0,96,39,7,0,22,0,0,0,1,7,7,0,144,251,6,0,22,0,0,0,1,7,4,0,184,164,6,0,22,0,0,0,1,7,3,0,80,74,6,0,22,0,0,0,1,7,2,0,192,32,6,0,22,0,0,0,1,7,1,0,192,234,2,0,22,0,0,0,1,7,0,0,32,242,5,0,0,0,0,0,254,0,2,0,144,212,8,0,22,0,0,0,1,16,16,0,96,135,7,0,22,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,22,0,0,0,1,32,0,0,96,135,7,0,22,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,23,0,0,0,1,3,2,0,80,246,3,0,23,0,0,0,1,3,3,0,248,38,7,0,23,0,0,0,1,3,1,0,112,212,3,0,23,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,128,129,4,0,23,0,0,0,1,12,8,0,192,255,2,0,23,0,0,0,1,12,4,0,208,75,4,0,23,0,0,0,1,12,12,0,8,49,4,0,23,0,0,0,1,12,0,0,152,21,4,0,0,0,0,0,254,0,2,0,64,37,5,0,23,0,0,0,1,16,16,0,136,167,4,0,23,0,0,0,1,16,0,0,24,136,4,0,0,0,0,0,254,0,2,0,232,75,4,0,23,0,0,0,1,128,128,0,96,135,7,0,23,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,101,112,114,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,67,192,162,114,1,0,16,1,115,45,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,49,140,45,151,2,0,32,0,99,45,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,192,247,24,81,3,0,32,0,99,45,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,62,179,233,239,3,0,32,0,109,45,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,209,183,146,155,4,0,16,1,116,112,48,49,57,45,55,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,62,247,75,90,0,0,16,1,116,112,48,49,57,45,56,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,232,39,186,3,0,0,16,1,118,105,109,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,141,135,134,40,0,0,32,0,118,105,109,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,122,61,166,97,0,0,32,0,118,105,109,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,104,87,81,176,0,0,32,0,118,105,109,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,49,145,83,11,0,0,32,0,118,105,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,205,38,222,205,0,0,32,0,118,105,109,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,193,191,29,0,0,32,0,116,112,48,49,57,45,48,57,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,237,204,136,188,0,0,32,0,116,112,48,49,57,45,49,48,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,146,116,225,161,0,0,32,0,104,100,54,52,55,49,56,48,46,48,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,24,118,97,110,45,49,46,53,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,240,45,27,207,1,0,16,1,118,97,110,45,50,46,53,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,203,225,88,223,1,0,16,1,118,97,110,45,51,46,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,36,30,87,21,1,0,16,1,118,97,110,45,52,46,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,224,203,36,183,1,0,16,1,118,97,110,45,53,46,51,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,76,65,103,219,1,0,16,1,118,97,110,45,50,48,46,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,102,190,239,96,2,0,32,0,118,97,110,45,50,49,46,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,35,55,213,93,2,0,32,0,54,51,51,49,45,49,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,3,149,29,206,3,0,32,0,54,51,48,49,45,49,46,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,159,61,128,75,3,0,32,0,15,0,0,0,255,255,218,0,0,0,0,0,16,0,0,0,255,255,255,0,0,0,0,0,17,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,15,0,0,0,1,1,0,0,120,97,1,0,15,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,2,0,96,228,6,0,15,0,0,0,1,2,2,0,96,135,7,0,15,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,4,0,64,37,5,0,15,0,0,0,1,12,8,0,232,42,4,0,15,0,0,0,1,12,4,0,80,40,4,0,15,0,0,0,1,12,0,0,112,38,4,0,15,0,0,0,1,12,12,0,120,7,5,0,0,0,0,0,254,0,4,0,128,129,4,0,15,0,0,0,1,48,48,0,192,255,2,0,15,0,0,0,1,48,32,0,208,75,4,0,15,0,0,0,1,48,16,0,8,49,4,0,15,0,0,0,1,48,0,0,72,246,3,0,0,0,0,0,254,0,2,0,32,4,2,0,15,0,0,0,1,192,0,0,112,35,4,0,15,0,0,0,1,192,192,0,16,42,5,0,15,0,0,0,1,192,128,0,40,30,4,0,15,0,0,0,1,192,64,0,24,27,4,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,117,50,54,46,105,110,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,172,201,69,180,0,0,16,1,117,50,53,46,105,110,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,130,132,37,161,0,0,16,1,117,51,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,210,42,20,93,0,0,32,0,117,52,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,187,17,251,18,0,0,32,0,117,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,85,215,208,162,0,0,64,0,101,101,112,114,111,109,45,117,111,112,111,107,111,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,149,75,162,244,0,0,16,1,117,99,95,104,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,247,165,10,36,1,0,16,1,117,99,95,108,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,38,72,154,223,1,0,16,1,117,99,95,104,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,214,188,41,141,1,0,16,1,117,99,95,108,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,216,2,164,168,1,0,16,1,117,99,95,115,104,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,152,177,144,223,2,0,16,1,117,99,95,115,108,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,172,26,193,150,2,0,16,1,117,99,95,119,51,56,109,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,229,64,10,19,3,0,32,0,117,99,95,119,51,57,109,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,68,161,44,228,3,0,32,0,117,99,95,119,52,48,109,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,72,22,150,194,3,0,32,0,117,99,95,119,52,49,109,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,128,75,51,245,3,0,32,0,117,99,95,107,49,54,109,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,9,95,34,74,4,0,32,0,117,99,95,107,49,55,109,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,84,154,237,228,4,0,32,0,117,99,95,107,49,56,109,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,18,235,38,166,4,0,32,0,117,99,95,107,49,57,109,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,73,101,244,93,4,0,32,0,117,99,95,119,52,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,214,63,125,209,5,0,64,0,116,52,46,49,48,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,78,235,187,193,1,0,16,1,116,54,46,49,51,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,239,146,149,212,1,0,16,1,116,98,48,53,46,49,50,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,100,178,115,146,1,0,16,1,116,98,48,50,46,49,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,151,71,21,33,2,0,16,1,116,98,48,49,46,54,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,178,145,15,28,3,0,16,1,116,98,48,51,46,56,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,76,43,26,88,4,0,32,0,116,98,49,51,46,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,43,5,90,40,5,0,32,0,116,98,48,57,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,247,147,182,174,5,0,32,0,116,98,49,50,46,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,92,254,176,223,5,0,32,0,116,98,48,56,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,209,201,164,211,5,0,32,0,116,98,49,49,46,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,253,244,240,0,5,0,32,0,116,98,48,55,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,2,238,242,223,5,0,32,0,116,98,49,52,46,56,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,24,172,191,20,5,0,32,0,116,98,49,48,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,109,138,186,113,5,0,32,0,116,98,49,56,46,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,19,71,44,134,6,0,32,0,116,98,49,54,46,51,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,189,140,111,216,6,0,32,0,116,98,49,55,46,53,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,63,59,167,18,6,0,32,0,116,98,49,53,46,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,105,39,26,187,6,0,32,0,116,98,50,50,46,55,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,212,175,218,57,6,0,32,0,116,98,50,48,46,51,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,42,93,97,148,6,0,32,0,116,98,50,49,46,53,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,189,66,198,102,6,0,32,0,116,98,49,57,46,50,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,54,171,213,129,6,0,32,0,116,98,50,53,46,49,53,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,250,198,56,110,7,0,32,0,116,98,50,52,46,49,51,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,242,108,252,20,7,0,32,0,116,98,50,51,46,57,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,14,60,161,237,8,0,32,0,116,98,112,50,52,115,49,48,46,55,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,152,204,107,217,0,0,0,8,109,98,55,49,49,52,101,46,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,157,250,82,80,0,0,0,8,57,51,57,106,48,50,46,101,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,27,29,56,56,0,0,16,1,57,51,57,106,48,51,46,101,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,205,221,190,181,0,0,16,1,57,51,57,101,48,49,46,100,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,72,200,95,74,0,0,16,1,57,51,57,97,48,55,46,107,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,207,223,85,121,0,0,32,0,57,51,57,97,48,56,46,107,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,133,179,149,237,0,0,32,0,57,51,57,97,48,54,46,107,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,6,194,147,227,0,0,32,0,57,51,57,97,48,53,46,107,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,122,212,98,54,0,0,32,0,57,51,57,97,48,52,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,110,43,78,194,0,0,64,0,48,51,56,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,118,165,82,30,1,0,16,1,48,51,56,45,112,50,46,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,47,62,25,165,1,0,16,1,48,51,56,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,227,42,246,255,2,0,32,0,48,51,56,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,212,35,131,197,3,0,32,0,48,51,56,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,158,194,169,187,3,0,32,0,48,51,56,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,214,185,183,59,3,0,32,0,48,51,56,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,207,62,81,164,3,0,32,0,48,51,56,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,126,112,8,9,4,0,16,1,48,51,56,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,213,159,205,92,5,0,64,0,48,51,56,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,230,209,216,221,5,0,64,0,104,100,54,51,48,49,118,49,112,46,104,100,54,51,48,49,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,24,48,48,51,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,186,73,85,247,1,0,16,1,48,48,51,45,112,50,46,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,143,154,128,183,1,0,16,1,48,48,51,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,177,185,62,123,2,0,32,0,48,48,51,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,175,251,21,3,3,0,32,0,48,48,51,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,89,93,193,180,3,0,32,0,48,48,51,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,218,232,227,140,3,0,32,0,48,48,51,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,105,89,114,41,3,0,32,0,48,48,51,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,218,70,113,154,3,0,32,0,48,48,51,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,26,65,99,30,3,0,32,0,48,48,51,45,99,55,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,12,113,134,40,3,0,32,0,48,48,51,45,99,56,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,45,242,42,66,3,0,32,0,48,48,51,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,230,69,197,76,4,0,16,1,48,48,51,45,118,49,49,46,118,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,203,241,151,255,5,0,64,0,48,48,51,45,118,50,49,46,118,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,198,96,73,211,6,0,64,0,48,48,51,45,118,50,50,46,118,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,212,88,95,154,6,0,64,0,48,48,51,45,118,50,51,46,118,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,84,62,245,48,6,0,64,0,48,48,51,45,118,50,52,46,118,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,245,160,91,6,0,64,0,50,46,105,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,239,177,131,245,0,0,16,1,97,55,49,45,48,51,46,105,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,68,207,218,105,0,0,16,1,97,55,49,45,48,52,46,105,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,14,206,164,160,0,0,16,1,97,55,49,45,48,53,46,105,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,69,185,160,109,0,0,16,1,54,46,105,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,91,233,144,20,0,0,16,1,97,55,49,45,48,49,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,7,199,103,8,0,0,16,1,97,55,49,45,48,55,46,105,99,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,123,204,152,242,0,0,16,1,97,55,49,45,48,56,46,105,99,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,19,171,57,4,0,0,32,0,97,55,49,45,48,57,46,105,99,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,255,210,179,237,0,0,32,0,97,55,49,45,49,48,46,105,99,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,140,136,240,105,0,0,32,0,97,55,49,45,49,49,46,105,99,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,49,124,224,74,0,0,32,0,97,55,49,45,49,50,46,105,99,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,6,215,107,63,0,0,32,0,97,55,49,45,49,51,46,105,99,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,170,42,201,242,0,0,32,0,97,55,49,45,49,52,46,105,99,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,178,183,116,197,0,0,32,0,97,55,49,45,49,53,46,105,99,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,127,126,216,18,0,0,32,0,97,55,49,45,49,54,46,105,99,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,182,53,206,11,0,0,32,0,97,55,49,45,49,55,46,105,99,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,135,99,218,222,0,0,32,0,97,55,49,45,49,56,46,105,99,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,215,217,12,51,0,0,32,0,97,55,49,45,49,57,46,105,99,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,224,41,75,252,0,0,32,0,97,55,49,45,50,48,46,105,99,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,101,178,172,101,0,0,32,0,97,55,49,45,50,49,46,105,99,51,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,178,233,205,51,0,0,32,0,97,55,49,45,50,50,46,105,99,51,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,192,234,152,251,0,0,32,0,97,55,49,45,50,51,46,105,99,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,173,70,189,48,0,0,32,0,97,55,49,45,50,53,46,105,99,52,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,69,133,15,45,0,0,32,0,110,115,95,99,45,49,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,123,174,29,60,1,0,16,1,110,115,95,101,45,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,150,46,102,199,2,0,16,1,98,53,51,45,48,57,46,117,52,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,25,206,191,164,3,0,16,8,110,115,95,97,49,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,187,213,11,126,4,0,32,0,110,115,95,97,49,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,38,7,136,149,4,0,32,0,110,115,95,97,49,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,83,192,196,43,4,0,32,0,110,115,95,97,48,56,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,140,216,248,143,4,0,32,0,110,115,95,97,48,55,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,202,202,27,41,4,0,32,0,110,115,95,97,48,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,32,46,118,110,4,0,32,0,110,115,95,97,48,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,157,27,253,225,4,0,32,0,110,115,95,97,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,218,107,176,42,4,0,32,0,98,53,51,45,49,48,46,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,198,69,55,167,1,0,16,1,98,53,51,45,49,49,46,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,67,212,132,151,2,0,16,1,98,53,51,45,48,57,46,117,52,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,25,206,191,164,3,0,16,8,98,53,51,45,48,56,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,42,156,81,195,4,0,32,0,98,53,51,45,48,55,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,232,153,241,43,4,0,32,0,98,53,51,45,48,54,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,217,94,243,146,4,0,32,0,98,53,51,45,48,53,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,129,149,187,237,4,0,32,0,98,53,51,45,48,52,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,246,174,210,89,4,0,32,0,98,53,51,45,48,51,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,155,251,172,116,4,0,32,0,98,53,51,45,48,50,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,192,13,93,9,4,0,32,0,98,53,51,45,48,49,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,77,197,0,152,4,0,32,0,116,109,110,116,45,112,49,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,236,95,79,237,1,0,16,1,116,109,110,116,45,115,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,239,193,197,61,2,0,32,0,116,109,110,116,45,99,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,193,53,23,174,3,0,32,0,116,109,110,116,45,99,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,181,129,66,52,3,0,32,0,116,109,110,116,45,99,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,72,166,88,16,3,0,32,0,116,109,110,116,45,99,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,176,161,107,28,3,0,32,0,116,109,110,116,45,99,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,176,159,168,115,3,0,32,0,116,109,110,116,45,99,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,106,36,57,161,3,0,32,0,116,109,110,116,45,99,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,66,120,149,237,3,0,32,0,116,109,110,116,45,99,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,27,217,21,140,3,0,32,0,116,109,110,116,45,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,239,66,53,149,4,0,16,1,116,109,110,116,45,118,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,73,9,0,195,64,54,39,5,0,64,0,48,54,51,97,100,97,48,50,46,101,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,135,181,17,79,0,0,16,1,48,54,51,97,100,97,48,51,46,103,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,172,185,161,130,0,0,16,1,48,54,51,97,100,97,48,52,46,101,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,122,24,173,5,0,0,16,1,48,54,51,97,100,97,48,53,46,103,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,71,101,130,212,0,0,16,1,48,54,51,98,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,138,84,79,54,0,0,16,1,48,54,51,98,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,25,61,40,211,0,0,32,0,48,54,51,98,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,21,12,188,110,0,0,32,0,48,54,51,98,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,42,157,122,45,0,0,32,0,48,54,51,98,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,110,41,221,242,0,0,32,0,48,54,51,98,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,191,231,190,217,0,0,32,0,48,54,51,98,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,111,227,26,59,0,0,32,0,48,54,51,98,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,165,10,81,30,0,0,64,0,116,109,110,116,50,95,97,100,97,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,160,104,48,6,0,0,0,8,17,0,0,0,32,167,32,0,24,167,32,0,191,250,218,218,48,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,70,50,231,75,0,0,16,1,49,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,103,72,208,170,0,0,16,1,50,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,92,241,67,72,0,0,16,1,97,52,55,95,49,51,46,56,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,126,126,154,115,0,0,32,0,97,52,55,95,49,50,46,54,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,219,236,100,192,0,0,32,0,97,52,55,95,49,49,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,155,174,79,116,0,0,32,0,97,52,55,95,49,48,46,54,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,78,132,207,225,0,0,32,0,97,52,55,95,48,53,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,73,91,50,197,0,0,32,0,97,52,55,95,48,52,46,54,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,142,98,89,205,0,0,32,0,97,52,55,95,48,57,46,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,168,232,250,49,0,0,32,0,97,52,55,95,48,56,46,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,43,175,57,229,0,0,32,0,97,52,55,95,48,55,46,54,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,41,212,253,2,0,0,32,0,97,52,55,95,48,54,46,54,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,140,204,251,17,0,0,32,0,56,50,115,49,50,57,46,49,50,113,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,13,53,105,44,0,0,32,0,56,50,115,49,50,57,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,114,233,66,113,0,0,32,0,56,50,115,49,50,57,46,49,50,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,242,115,242,37,0,0,32,0,97,52,55,95,48,51,46,49,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,15,38,5,209,0,0,16,1,97,52,55,95,49,52,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,159,72,66,64,0,0,16,1,112,97,108,49,54,114,52,97,46,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,0,0,0,16,17,0,0,0,255,255,16,0,0,0,0,0,18,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,192,70,8,0,17,0,0,0,1,128,0,0,248,38,7,0,17,0,0,0,1,128,128,0,176,64,8,0,0,0,0,0,254,0,2,0,0,0,0,0,17,0,0,0,1,64,0,0,136,159,3,0,17,0,0,0,1,64,64,0,208,40,2,0,0,0,0,0,254,0,2,0,0,0,0,0,17,0,0,0,1,32,0,0,200,211,8,0,17,0,0,0,1,32,32,0,216,147,8,0,0,0,0,0,254,0,2,0,200,30,2,0,17,0,0,0,1,16,16,0,120,97,1,0,17,0,0,0,1,16,0,0,0,11,2,0,0,0,0,0,254,0,2,0,240,233,7,0,17,0,0,0,1,8,0,0,152,182,7,0,17,0,0,0,1,8,8,0,96,135,7,0,0,0,0,0,254,0,7,0,32,4,2,0,17,0,0,0,1,7,0,0,200,201,5,0,17,0,0,0,1,7,1,0,152,160,5,0,17,0,0,0,1,7,2,0,144,127,5,0,17,0,0,0,1,7,3,0,224,67,5,0,17,0,0,0,1,7,4,0,88,198,1,0,17,0,0,0,1,7,5,0,216,36,5,0,17,0,0,0,1,7,7,0,40,182,1,0,17,0,0,0,1,7,6,0,216,36,5,0,0,0,0,0,254,0,2,0,56,191,4,0,18,0,0,0,1,16,0,0,200,58,8,0,18,0,0,0,1,16,16,0,16,54,8,0,0,0,0,0,254,0,4,0,136,160,5,0,18,0,0,0,1,12,0,0,24,205,7,0,18,0,0,0,1,12,4,0,192,255,2,0,18,0,0,0,1,12,8,0,208,75,4,0,18,0,0,0,1,12,12,0,8,49,4,0,0,0,0,0,254,0,4,0,224,149,1,0,18,0,0,0,1,3,0,0,8,49,4,0,18,0,0,0,1,3,1,0,72,246,3,0,18,0,0,0,1,3,2,0,192,255,2,0,18,0,0,0,1,3,3,0,208,75,4,0,0,0,0,0,56,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,6,250,88,253,1,0,16,1,51,46,54,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,125,58,130,84,1,0,16,1,55,46,52,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,126,222,232,253,1,0,16,1,50,46,52,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,20,116,152,219,1,0,16,1,54,46,51,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,59,140,187,165,1,0,16,1,49,46,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,40,109,222,210,1,0,16,1,49,49,46,49,55,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,117,212,7,68,2,0,16,1,57,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,188,124,111,188,3,0,32,0,53,46,49,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,253,61,210,37,4,0,32,0,52,46,49,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,39,254,176,185,4,0,32,0,49,53,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,224,216,68,33,5,0,32,0,49,52,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,158,92,79,116,5,0,32,0,49,50,46,55,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,235,44,31,45,6,0,32,0,49,51,46,57,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,214,146,47,29,6,0,32,0,49,48,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,18,88,112,172,7,0,32,8,110,56,50,115,49,50,57,97,110,46,49,49,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,87,71,36,129,8,0,0,8,53,45,117,52,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,149,129,8,144,0,0,16,1,52,45,117,52,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,108,25,83,13,0,0,16,1,117,50,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,115,239,66,237,0,0,32,0,117,50,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,238,202,33,141,0,0,32,0,117,50,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,237,78,227,239,0,0,32,0,117,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,85,125,29,104,0,0,32,0,117,51,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,235,46,46,42,0,0,32,0,49,45,117,54,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,135,227,37,32,0,0,16,1,117,54,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,197,51,54,166,0,0,64,0,117,54,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,87,195,208,58,0,0,64,0,52,45,117,53,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,16,21,0,0,0,255,255,0,0,0,0,0,0,22,0,0,0,255,255,2,0,0,0,0,0,23,0,0,0,255,255,15,0,0,0,0,0,0,0,0,0,254,0,2,0,120,109,4,0,21,0,0,0,130,1,0,0,176,111,1,0,21,0,0,0,0,255,255,0,0,0,0,0,21,0,0,0,130,1,1,0,232,78,1,0,21,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,254,0,9,0,184,40,2,0,21,0,0,0,1,14,0,0,240,255,3,0,21,0,0,0,1,14,2,0,168,222,3,0,21,0,0,0,1,14,4,0,120,192,3,0,21,0,0,0,1,14,8,0,32,167,3,0,21,0,0,0,1,14,6,0,56,141,3,0,21,0,0,0,1,14,10,0,248,117,3,0,21,0,0,0,1,14,12,0,216,94,3,0,21,0,0,0,130,14,14,0,32,80,3,0,21,0,0,0,0,255,255,0,0,0,0,0,21,0,0,0,1,255,255,0,40,182,1,0,0,0,0,0,254,0,9,0,184,164,8,0,21,0,0,0,130,112,0,0,240,255,3,0,21,0,0,0,0,255,255,0,0,0,0,0,21,0,0,0,130,112,16,0,168,222,3,0,21,0,0,0,0,255,255,0,0,0,0,0,21,0,0,0,130,112,32,0,120,192,3,0,21,0,0,0,0,255,255,0,0,0,0,0,21,0,0,0,130,112,64,0,32,167,3,0,21,0,0,0,0,255,255,0,0,0,0,0,21,0,0,0,130,112,48,0,56,141,3,0,21,0,0,0,0,255,255,0,0,0,0,0,21,0,0,0,130,112,80,0,248,117,3,0,21,0,0,0,0,255,255,0,0,0,0,0,21,0,0,0,130,112,96,0,216,94,3,0,21,0,0,0,0,255,255,0,0,0,0,0,21,0,0,0,130,112,112,0,32,80,3,0,21,0,0,0,0,255,255,0,0,0,0,0,21,0,0,0,130,255,255,0,40,182,1,0,21,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,160,176,7,0,21,0,0,0,130,128,0,0,168,84,8,0,21,0,0,0,0,255,255,0,0,0,0,0,21,0,0,0,130,128,128,0,232,239,2,0,21,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,0,0,0,0,22,0,0,0,1,1,0,0,200,211,8,0,22,0,0,0,1,1,1,0,216,147,8,0,0,0,0,0,254,0,2,0,80,105,6,0,22,0,0,0,1,2,0,0,168,165,2,0,22,0,0,0,1,2,2,0,96,151,2,0,0,0,0,0,254,0,4,0,72,202,5,0,22,0,0,0,1,12,0,0,248,38,7,0,22,0,0,0,1,12,4,0,80,246,3,0,22,0,0,0,1,12,8,0,112,212,3,0,22,0,0,0,1,12,12,0,248,160,5,0,0,0,0,0,254,0,4,0,128,129,4,0,22,0,0,0,1,48,0,0,8,49,4,0,22,0,0,0,1,48,16,0,192,255,2,0,22,0,0,0,1,48,32,0,208,75,4,0,22,0,0,0,1,48,48,0,152,21,4,0,0,0,0,0,254,0,2,0,8,14,2,0,22,0,0,0,1,64,0,0,208,17,8,0,22,0,0,0,1,64,64,0,104,250,1,0,15,8,9,12,10,13,11,14,2,7,4,3,1,5,6,0,12,10,11,9,8,15,14,13,6,0,3,5,7,4,2,1,8,12,11,9,13,14,15,10,4,6,5,0,3,1,7,2,8,9,10,13,11,15,14,12,5,4,0,7,2,6,1,3,12,13,14,15,8,9,10,11,1,5,0,3,2,7,6,4,14,15,13,8,12,10,11,9,1,2,7,6,4,3,0,5,13,14,10,11,9,8,12,15,3,1,7,4,5,0,2,6,9,8,14,10,15,11,13,12,6,0,5,2,4,1,3,7,50,54,57,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,252,253,44,67,1,0,16,1,50,54,57,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,156,143,96,27,3,0,32,0,50,54,57,45,99,50,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,148,242,149,90,3,0,32,0,50,54,57,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,157,129,246,4,0,16,1,50,54,57,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,76,179,89,198,5,0,64,0,50,54,57,45,118,50,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,53,56,144,221,5,0,64,0,57,49,49,106,48,49,46,102,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,129,120,100,30,1,0,16,1,57,49,49,107,48,50,46,104,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,182,231,16,239,1,0,16,1,57,49,49,100,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,25,35,141,48,2,0,32,0,57,49,49,100,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,50,155,204,145,2,0,32,0,57,49,49,100,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,130,241,79,227,3,0,32,0,57,49,49,100,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,210,11,112,32,3,0,32,0,72,231,128,128,32,109,28,64,48,47,0,12,16,128,82,136,32,60,0,240,28,64,177,192,102,4,65,237,28,32,43,72,28,64,76,223,1,1,78,117,115,46,116,114,105,118,95,112,49,46,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,110,218,245,220,1,0,16,1,115,46,116,114,105,118,95,112,50,46,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,186,16,22,146,1,0,16,1,115,46,116,114,105,118,95,112,51,46,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,33,14,111,195,1,0,16,1,115,46,116,114,105,118,95,99,112,52,46,102,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,151,138,201,13,1,0,16,1,115,46,116,114,105,118,95,99,51,46,101,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,112,5,75,47,1,0,16,1,115,46,116,114,105,118,95,99,50,46,101,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,171,211,27,226,1,0,16,1,115,46,116,114,105,118,95,99,49,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,130,114,44,44,1,0,16,1,115,46,116,114,105,118,95,115,111,117,110,100,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,79,248,221,183,2,0,16,1,115,46,116,114,105,118,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,155,34,96,143,3,0,32,0,115,46,116,114,105,118,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,156,42,152,143,3,0,32,0,115,46,116,114,105,118,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,156,42,152,143,3,0,32,0,115,46,116,114,105,118,46,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,142,53,212,122,3,0,32,0,115,46,116,114,105,118,95,116,115,48,46,117,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,218,73,104,121,5,0,16,1,115,46,116,114,105,118,95,116,115,49,46,117,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,73,157,5,5,0,16,1,115,46,116,114,105,118,95,116,115,50,46,117,56,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,170,89,65,24,5,0,16,1,115,46,116,114,105,118,95,116,97,48,46,117,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,46,127,235,196,5,0,16,1,115,46,116,114,105,118,95,116,97,49,46,117,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,111,19,154,61,5,0,16,1,115,46,116,114,105,118,95,116,97,50,46,117,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,178,87,165,143,5,0,16,1,115,46,116,114,105,118,95,116,101,48,46,117,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,75,28,93,63,5,0,16,1,115,46,116,114,105,118,95,116,101,49,46,117,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,58,191,226,106,5,0,16,1,115,46,116,114,105,118,95,116,103,48,46,117,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,109,199,201,143,5,0,16,1,115,46,116,114,105,118,95,116,103,49,46,117,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,67,42,26,152,5,0,16,1,115,116,114,97,104,108,45,50,46,56,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,174,8,208,201,1,0,16,1,115,116,114,97,104,108,45,49,46,56,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,214,196,195,175,1,0,16,1,115,116,114,97,104,108,45,52,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,196,153,167,96,2,0,16,1,115,116,114,97,104,108,45,51,46,55,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,62,179,115,34,3,0,32,0,115,116,114,55,98,50,114,48,46,50,55,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,225,227,105,87,4,0,32,0,115,116,114,108,51,45,48,49,46,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,21,127,51,216,5,0,32,0,115,116,114,108,52,45,48,50,46,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,43,85,56,42,5,0,32,0,115,116,114,108,53,45,48,51,46,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,16,210,231,160,5,0,32,0,115,116,114,54,98,49,119,49,46,55,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,85,177,27,187,9,0,64,0,115,116,114,56,112,109,119,49,46,53,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,106,187,214,1,6,0,64,0,115,116,114,57,112,101,119,49,46,54,51,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,159,235,179,107,7,0,64,0,115,113,117,97,115,104,46,100,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,150,174,122,206,1,0,16,1,115,113,117,97,115,104,46,100,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,215,237,250,143,1,0,16,1,115,113,117,97,115,104,46,99,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,69,6,68,92,2,0,32,0,115,113,117,97,115,104,46,99,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,77,105,25,158,2,0,32,0,115,113,117,97,115,104,46,99,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,92,3,42,137,2,0,32,0,115,113,117,97,115,104,46,99,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,105,28,185,11,2,0,32,0,115,113,117,97,115,104,46,100,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,27,101,185,161,3,0,64,0,121,111,110,97,116,101,99,104,53,46,117,49,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,5,92,171,114,1,0,16,1,121,111,110,97,116,101,99,104,54,46,117,49,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,156,189,68,126,1,0,16,1,121,111,110,97,116,101,99,104,49,46,117,49,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,167,205,90,239,2,0,16,1,121,111,110,97,116,101,99,104,52,46,117,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,142,176,38,86,3,0,32,0,117,49,53,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,143,191,11,160,4,0,32,0,117,49,53,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,171,63,66,246,4,0,32,0,117,49,53,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,78,118,123,247,5,0,32,0,121,111,110,97,116,101,99,104,50,46,117,49,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,114,241,96,65,6,0,64,0,121,111,110,97,116,101,99,104,51,46,117,49,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,4,196,68,102,7,0,64,0,115,115,46,48,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,84,204,64,205,1,0,16,1,115,115,46,48,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,39,101,71,195,1,0,16,1,115,115,46,48,51,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,41,231,208,31,1,0,16,1,115,115,95,54,46,99,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,138,196,53,17,2,0,16,1,115,115,95,55,46,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,177,144,8,153,3,0,32,0,115,115,95,56,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,130,255,136,147,3,0,32,0,115,115,95,57,46,109,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,207,202,177,140,4,0,32,0,115,115,95,49,48,46,109,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,94,129,2,248,4,0,32,0,115,115,95,49,49,46,109,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,138,216,186,77,4,0,32,0,115,115,95,49,50,46,109,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,135,230,5,170,4,0,32,0,115,115,95,49,51,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,250,155,17,102,4,0,32,0,115,115,95,49,52,46,109,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,78,245,78,225,4,0,32,0,115,115,98,52,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,52,242,234,200,5,0,32,0,115,115,98,53,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,221,74,67,14,5,0,32,0,115,115,98,50,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,198,33,51,197,5,0,32,0,115,115,98,51,46,104,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,74,50,44,125,5,0,32,0,115,115,98,49,46,107,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,254,12,75,160,0,0,0,8,115,107,50,95,50,46,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,34,88,138,234,1,0,16,1,115,107,49,45,49,99,46,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,108,108,190,122,1,0,16,1,115,107,49,95,51,46,54,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,101,135,75,49,1,0,16,1,115,107,50,95,52,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,224,208,96,164,2,0,16,1,99,117,115,54,51,45,54,51,97,49,46,109,99,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,179,143,240,110,2,0,16,1,115,107,49,95,54,46,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,185,49,183,88,3,0,32,0,115,107,49,95,53,46,55,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,142,73,58,195,4,0,32,0,115,107,49,95,56,46,49,48,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,117,115,187,68,5,0,32,0,115,107,49,95,55,46,49,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,29,103,84,52,5,0,32,0,115,107,49,45,49,46,50,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,38,231,24,2,6,0,32,0,115,107,49,45,50,46,50,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,133,91,13,252,6,0,32,0,115,107,49,45,51,46,50,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,11,98,107,208,6,0,32,0,115,107,49,45,52,46,53,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,114,172,151,198,6,0,32,0,115,107,49,45,53,46,54,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,164,20,21,22,6,0,32,0,115,107,121,102,111,120,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,111,187,212,180,1,0,16,1,115,107,121,102,111,120,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,99,2,94,225,1,0,16,1,115,107,121,102,111,120,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,245,59,40,11,2,0,16,1,115,107,121,102,111,120,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,41,169,23,58,3,0,32,0,115,107,121,102,111,120,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,187,83,128,53,3,0,32,0,115,107,121,102,111,120,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,110,90,33,193,3,0,32,0,115,107,121,102,111,120,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,93,225,55,204,3,0,32,0,115,107,121,102,111,120,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,180,181,42,250,3,0,32,0,115,107,121,102,111,120,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,73,220,62,14,3,0,32,0,115,107,121,102,111,120,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,156,143,245,25,4,0,32,0,115,102,111,120,114,112,114,109,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,127,60,145,121,5,0,32,0,115,102,111,120,103,112,114,109,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,52,212,115,251,5,0,32,0,115,102,111,120,98,112,114,109,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,65,171,210,96,5,0,32,0,115,102,105,105,105,95,97,115,105,97,95,110,111,99,100,46,50,57,102,52,48,48,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,99,36,227,115,0,0,0,3,115,102,105,105,105,45,115,105,109,109,49,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,90,228,201,207,0,0,16,1,115,102,105,105,105,45,115,105,109,109,49,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,70,5,146,87,0,0,16,1,115,102,105,105,105,45,115,105,109,109,49,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,128,38,143,13,0,0,16,1,115,102,105,105,105,45,115,105,109,109,49,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,84,160,76,234,0,0,16,1,115,102,105,105,105,45,115,105,109,109,51,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,211,59,11,8,0,0,32,0,115,102,105,105,105,45,115,105,109,109,51,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,47,111,53,92,0,0,32,0,115,102,105,105,105,45,115,105,109,109,51,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,69,122,201,249,0,0,32,0,115,102,105,105,105,45,115,105,109,109,51,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,173,62,222,9,0,0,32,0,115,102,105,105,105,45,115,105,109,109,51,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,243,225,215,125,0,0,32,0,115,102,105,105,105,45,115,105,109,109,51,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,58,58,160,71,0,0,32,0,115,102,105,105,105,45,115,105,109,109,51,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,38,122,235,233,0,0,32,0,115,102,105,105,105,45,115,105,109,109,51,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,92,57,68,127,0,0,32,0,115,102,105,105,105,45,115,105,109,109,52,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,252,128,192,154,0,0,32,0,115,102,105,105,105,45,115,105,109,109,52,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,148,76,44,110,0,0,32,0,115,102,105,105,105,45,115,105,109,109,52,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,212,34,252,138,0,0,32,0,115,102,105,105,105,45,115,105,109,109,52,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,184,115,56,159,0,0,32,0,115,102,105,105,105,45,115,105,109,109,52,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,151,60,107,22,0,0,32,0,115,102,105,105,105,45,115,105,109,109,52,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,71,37,234,229,0,0,32,0,115,102,105,105,105,45,115,105,109,109,52,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,221,159,91,232,0,0,32,0,115,102,105,105,105,45,115,105,109,109,52,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,183,1,44,54,0,0,32,0,115,102,105,105,105,45,115,105,109,109,53,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,178,8,193,155,0,0,32,0,115,102,105,105,105,45,115,105,109,109,53,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,102,192,241,198,0,0,32,0,115,102,105,105,105,95,106,97,112,97,110,46,50,57,102,52,48,48,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,80,82,32,116,0,0,0,3,115,102,105,105,105,45,115,105,109,109,49,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,90,228,201,207,0,0,16,1,115,102,105,105,105,45,115,105,109,109,49,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,70,5,146,87,0,0,16,1,115,102,105,105,105,45,115,105,109,109,49,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,128,38,143,13,0,0,16,1,115,102,105,105,105,45,115,105,109,109,49,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,84,160,76,234,0,0,16,1,115,102,105,105,105,45,115,105,109,109,51,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,211,59,11,8,0,0,32,0,115,102,105,105,105,45,115,105,109,109,51,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,47,111,53,92,0,0,32,0,115,102,105,105,105,45,115,105,109,109,51,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,69,122,201,249,0,0,32,0,115,102,105,105,105,45,115,105,109,109,51,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,173,62,222,9,0,0,32,0,115,102,105,105,105,45,115,105,109,109,51,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,243,225,215,125,0,0,32,0,115,102,105,105,105,45,115,105,109,109,51,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,58,58,160,71,0,0,32,0,115,102,105,105,105,45,115,105,109,109,51,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,38,122,235,233,0,0,32,0,115,102,105,105,105,45,115,105,109,109,51,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,92,57,68,127,0,0,32,0,115,102,105,105,105,45,115,105,109,109,52,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,252,128,192,154,0,0,32,0,115,102,105,105,105,45,115,105,109,109,52,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,148,76,44,110,0,0,32,0,115,102,105,105,105,45,115,105,109,109,52,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,212,34,252,138,0,0,32,0,115,102,105,105,105,45,115,105,109,109,52,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,184,115,56,159,0,0,32,0,115,102,105,105,105,45,115,105,109,109,52,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,151,60,107,22,0,0,32,0,115,102,105,105,105,45,115,105,109,109,52,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,71,37,234,229,0,0,32,0,115,102,105,105,105,45,115,105,109,109,52,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,221,159,91,232,0,0,32,0,115,102,105,105,105,45,115,105,109,109,52,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,183,1,44,54,0,0,32,0,115,102,105,105,105,45,115,105,109,109,53,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,178,8,193,155,0,0,32,0,115,102,105,105,105,45,115,105,109,109,53,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,102,192,241,198,0,0,32,0,115,102,105,105,105,95,104,105,115,112,97,110,105,99,46,50,57,102,52,48,48,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,72,205,179,210,0,0,0,3,115,102,105,105,105,45,115,105,109,109,49,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,90,228,201,207,0,0,16,1,115,102,105,105,105,45,115,105,109,109,49,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,70,5,146,87,0,0,16,1,115,102,105,105,105,45,115,105,109,109,49,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,128,38,143,13,0,0,16,1,115,102,105,105,105,45,115,105,109,109,49,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,84,160,76,234,0,0,16,1,115,102,105,105,105,45,115,105,109,109,51,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,211,59,11,8,0,0,32,0,115,102,105,105,105,45,115,105,109,109,51,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,47,111,53,92,0,0,32,0,115,102,105,105,105,45,115,105,109,109,51,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,69,122,201,249,0,0,32,0,115,102,105,105,105,45,115,105,109,109,51,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,173,62,222,9,0,0,32,0,115,102,105,105,105,45,115,105,109,109,51,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,243,225,215,125,0,0,32,0,115,102,105,105,105,45,115,105,109,109,51,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,58,58,160,71,0,0,32,0,115,102,105,105,105,45,115,105,109,109,51,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,38,122,235,233,0,0,32,0,115,102,105,105,105,45,115,105,109,109,51,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,92,57,68,127,0,0,32,0,115,102,105,105,105,45,115,105,109,109,52,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,252,128,192,154,0,0,32,0,115,102,105,105,105,45,115,105,109,109,52,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,148,76,44,110,0,0,32,0,115,102,105,105,105,45,115,105,109,109,52,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,212,34,252,138,0,0,32,0,115,102,105,105,105,45,115,105,109,109,52,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,184,115,56,159,0,0,32,0,115,102,105,105,105,45,115,105,109,109,52,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,151,60,107,22,0,0,32,0,115,102,105,105,105,45,115,105,109,109,52,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,71,37,234,229,0,0,32,0,115,102,105,105,105,45,115,105,109,109,52,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,221,159,91,232,0,0,32,0,115,102,105,105,105,45,115,105,109,109,52,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,183,1,44,54,0,0,32,0,115,102,105,105,105,45,115,105,109,109,53,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,178,8,193,155,0,0,32,0,115,102,105,105,105,45,115,105,109,109,53,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,102,192,241,198,0,0,32,0,115,102,105,105,105,51,95,101,117,114,111,46,50,57,102,52,48,48,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,147,242,187,48,0,0,0,3,115,102,105,105,105,51,40,95,95,57,57,48,54,48,56,41,45,115,105,109,109,49,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,205,211,223,17,0,0,16,1,115,102,105,105,105,51,40,95,95,57,57,48,54,48,56,41,45,115,105,109,109,49,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,230,133,5,197,0,0,16,1,115,102,105,105,105,51,40,95,95,57,57,48,54,48,56,41,45,115,105,109,109,49,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,155,29,1,142,0,0,16,1,115,102,105,105,105,51,40,95,95,57,57,48,54,48,56,41,45,115,105,109,109,49,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,47,217,168,220,0,0,16,1,115,102,105,105,105,51,45,115,105,109,109,50,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,158,150,235,6,0,0,16,1,115,102,105,105,105,51,45,115,105,109,109,50,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,130,159,3,231,0,0,16,1,115,102,105,105,105,51,45,115,105,109,109,50,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,247,150,92,100,0,0,16,1,115,102,105,105,105,51,45,115,105,109,109,50,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,177,250,14,97,0,0,16,1,115,102,105,105,105,51,45,115,105,109,109,51,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,121,31,170,123,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,51,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,254,248,75,35,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,51,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,8,195,235,217,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,51,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,119,186,60,41,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,51,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,71,231,85,96,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,51,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,252,166,154,73,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,51,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,158,135,19,108,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,51,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,222,142,79,207,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,52,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,186,213,31,9,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,52,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,23,137,202,11,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,52,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,139,87,253,160,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,52,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,153,198,248,75,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,52,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,133,135,123,19,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,52,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,113,6,183,79,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,52,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,164,116,35,131,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,52,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,109,87,136,28,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,53,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,144,145,125,198,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,53,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,104,152,183,108,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,53,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,14,147,105,223,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,53,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,224,84,55,51,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,53,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,23,212,246,120,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,53,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,177,217,202,140,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,53,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,229,89,222,133,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,53,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,179,41,126,238,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,54,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,66,144,166,141,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,54,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,196,122,140,28,0,0,32,0])
.concat([115,102,105,105,105,51,45,115,105,109,109,54,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,29,52,113,166,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,54,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,73,2,153,26,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,54,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,172,57,203,32,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,54,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,47,75,132,95,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,54,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,40,141,14,69,0,0,32,0,115,102,105,105,105,51,45,115,105,109,109,54,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,135,65,95,204,0,0,32,0,115,102,105,105,105,50,95,117,115,97,46,50,57,102,52,48,48,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,224,114,221,117,0,0,0,3,115,102,105,105,105,50,45,115,105,109,109,49,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,11,111,102,45,0,0,16,1,115,102,105,105,105,50,45,115,105,109,109,49,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,246,142,58,42,0,0,16,1,115,102,105,105,105,50,45,115,105,109,109,49,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,6,34,29,22,0,0,16,1,115,102,105,105,105,50,45,115,105,109,109,49,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,163,216,222,135,0,0,16,1,115,102,105,105,105,50,45,115,105,109,109,50,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,15,206,164,148,0,0,16,1,115,102,105,105,105,50,45,115,105,109,109,50,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,51,80,88,103,0,0,16,1,115,102,105,105,105,50,45,115,105,109,109,50,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,213,252,191,250,0,0,16,1,115,102,105,105,105,50,45,115,105,109,109,50,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,202,9,60,98,0,0,16,1,115,102,105,105,105,50,45,115,105,109,109,51,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,102,215,178,218,0,0,32,0,115,102,105,105,105,50,45,115,105,109,109,51,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,75,163,42,31,0,0,32,0,115,102,105,105,105,50,45,115,105,109,109,51,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,235,4,26,111,0,0,32,0,115,102,105,105,105,50,45,115,105,109,109,51,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,5,242,94,224,0,0,32,0,115,102,105,105,105,50,45,115,105,109,109,51,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,79,7,251,175,0,0,32,0,115,102,105,105,105,50,45,115,105,109,109,51,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,46,135,98,105,0,0,32,0,115,102,105,105,105,50,45,115,105,109,109,51,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,222,135,237,110,0,0,32,0,115,102,105,105,105,50,45,115,105,109,109,51,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,158,71,143,225,0,0,32,0,115,102,105,105,105,50,45,115,105,109,109,52,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,3,37,76,118,0,0,32,0,115,102,105,105,105,50,45,115,105,109,109,52,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,110,175,22,62,0,0,32,0,115,102,105,105,105,50,45,115,105,109,109,52,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,230,5,87,33,0,0,32,0,115,102,105,105,105,50,45,115,105,109,109,52,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,156,189,12,227,0,0,32,0,115,102,105,105,105,50,45,115,105,109,109,52,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,217,222,133,65,0,0,32,0,115,102,105,105,105,50,45,115,105,109,109,52,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,19,176,141,78,0,0,32,0,115,102,105,105,105,50,45,115,105,109,109,52,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,206,72,223,8,0,0,32,0,115,102,105,105,105,50,45,115,105,109,109,52,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,165,128,143,187,0,0,32,0,115,102,105,105,105,50,45,115,105,109,109,53,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,135,71,220,235,0,0,32,0,115,102,105,105,105,50,45,115,105,109,109,53,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,14,85,124,107,0,0,32,0,115,102,105,105,105,50,45,115,105,109,109,53,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,80,140,255,86,0,0,32,0,115,102,105,105,105,50,45,115,105,109,109,53,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,233,195,42,63,0,0,32,0,115,102,105,105,105,50,45,115,105,109,109,53,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,14,165,205,72,0,0,32,0,115,102,105,105,105,50,45,115,105,109,109,53,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,246,10,12,82,0,0,32,0,115,102,105,105,105,50,45,115,105,109,109,53,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,134,89,220,46,0,0,32,0,115,102,105,105,105,50,45,115,105,109,109,53,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,153,161,255,147,0,0,32,0,100,48,48,46,101,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,119,109,34,41,1,0,16,1,100,49,48,46,100,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,128,56,20,235,1,0,16,1,100,50,48,46,99,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,98,242,85,68,1,0,16,1,100,51,48,46,98,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,210,197,74,4,1,0,16,1,100,52,48,46,97,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,74,129,160,181,1,0,16,1,100,53,48,46,106,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,12,193,133,164,2,0,32,0,100,54,48,46,106,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,57,229,212,31,2,0,32,0,100,55,48,46,104,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,178,244,84,132,2,0,32,0,100,56,48,46,104,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,238,137,189,114,2,0,32,0,100,57,48,46,103,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,148,40,60,255,2,0,32,0,100,97,48,46,103,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,74,33,32,156,2,0,32,0,100,99,48,46,99,54,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,214,189,35,255,3,0,32,0,100,98,49,46,98,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,75,130,196,124,0,0,0,8,0,0,0,0,0,0,0,0,48,52,53,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,240,27,229,223,1,0,16,1,48,52,53,45,112,103,50,46,115,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,148,91,116,70,1,0,16,1,48,52,53,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,211,164,66,145,2,0,32,0,48,52,53,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,164,115,88,46,3,0,32,0,48,52,53,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,16,187,254,4,3,0,32,0,48,52,53,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,30,189,218,243,3,0,32,0,48,52,53,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,240,98,92,147,3,0,32,0,48,52,53,45,99,53,49,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,148,40,147,129,3,0,32,0,48,52,53,45,99,54,49,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,46,97,48,190,3,0,32,0,48,52,53,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,64,6,23,149,4,0,16,1,48,52,53,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,155,138,247,55,5,0,64,0,48,52,53,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,207,32,139,86,5,0,64,0,50,53,52,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,255,252,142,255,1,0,16,1,50,53,52,45,112,50,46,115,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,221,212,223,239,1,0,16,1,50,53,52,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,239,200,111,174,3,0,32,0,50,53,52,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,118,161,111,67,3,0,32,0,50,53,52,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,220,242,63,229,3,0,32,0,50,53,52,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,240,114,134,129,3,0,32,0,50,53,52,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,205,234,128,69,3,0,32,0,50,53,52,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,252,112,73,227,3,0,32,0,50,53,52,45,99,55,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,57,50,50,242,3,0,32,0,50,53,52,45,99,56,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,125,140,132,102,3,0,32,0,50,53,52,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,135,68,75,153,4,0,16,1,50,53,52,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,251,88,79,132,5,0,64,0,50,53,52,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,240,72,162,217,5,0,64,0,50,53,52,45,118,51,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,51,45,13,11,5,0,64,0,50,53,52,45,118,52,46,118,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,145,220,19,109,5,0,64,0,49,48,46,117,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,54,175,50,90,0,0,16,1,57,46,117,52,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,125,109,204,41,0,0,16,1,117,50,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,238,127,162,40,0,0,32,0,117,50,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,50,42,21,202,0,0,32,0,117,50,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,169,14,214,197,0,0,32,0,117,50,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,50,3,113,72,0,0,32,0,117,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,84,38,226,222,0,0,32,0,117,51,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,35,62,248,170,0,0,32,0,51,45,117,54,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,225,10,212,66,0,0,16,1,117,54,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,71,207,57,168,0,0,64,0,52,45,117,53,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,16,49,45,117,52,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,18,176,14,192,0,0,16,1,50,45,117,52,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,75,19,90,63,0,0,16,1,117,50,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,238,127,162,40,0,0,32,0,117,50,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,50,42,21,202,0,0,32,0,117,50,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,169,14,214,197,0,0,32,0,117,50,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,50,3,113,72,0,0,32,0,117,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,84,38,226,222,0,0,32,0,117,51,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,35,62,248,170,0,0,32,0,51,45,117,54,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,225,10,212,66,0,0,16,1,117,54,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,71,207,57,168,0,0,64,0,52,45,117,53,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,16,52,45,117,52,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,23,194,255,41,0,0,16,1,53,45,117,52,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,100,251,211,195,0,0,16,1,117,50,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,238,127,162,40,0,0,32,0,117,50,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,50,42,21,202,0,0,32,0,117,50,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,169,14,214,197,0,0,32,0,117,50,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,50,3,113,72,0,0,32,0,117,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,84,38,226,222,0,0,32,0,117,51,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,35,62,248,170,0,0,32,0,51,45,117,54,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,225,10,212,66,0,0,16,1,117,54,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,71,207,57,168,0,0,64,0,52,45,117,53,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,16,114,117,106,48,50,46,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,238,58,34,13,2,0,0,0,114,117,106,48,49,46,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,30,221,188,198,2,0,0,0,114,117,106,48,52,46,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,171,60,21,12,2,0,0,0,114,117,106,48,51,46,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,156,248,149,118,2,0,0,0,114,117,106,48,53,46,51,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,22,11,39,149,9,0,0,0,114,121,117,106,105,110,48,55,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,128,9,245,52,11,0,0,0,114,121,117,106,105,110,48,54,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,52,255,133,27,11,0,0,0,114,121,117,106,105,110,48,56,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,13,4,13,72,24,0,0,0,99,112,117,106,95,53,112,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,186,152,150,179,1,0,16,1,99,112,117,106,95,53,109,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,121,9,24,63,1,0,16,1,99,112,117,106,95,53,106,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,143,78,228,105,1,0,16,1,99,112,117,95,52,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,135,250,162,228,2,0,16,1,99,112,117,106,95,56,107,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,7,119,4,69,3,0,32,0,118,105,100,95,54,107,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,158,219,166,171,4,0,32,0,118,105,100,95,54,106,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,214,46,31,174,4,0,32,0,118,105,100,95,54,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,223,231,217,70,4,0,32,0,118,105,100,95,54,103,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,154,156,131,69,4,0,32,0,118,105,100,95,54,112,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,142,95,174,158,5,0,32,0,118,105,100,95,54,111,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,150,163,16,90,5,0,32,0,118,105,100,95,54,110,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,63,207,18,123,5,0,32,0,118,105,100,95,54,108,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,170,126,234,60,5,0,32,0,118,105,100,95,54,102,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,216,237,64,152,6,0,32,0,118,105,100,95,54,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,116,224,101,255,6,0,32,0,118,105,100,95,54,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,133,140,134,137,6,0,32,0,118,105,100,95,54,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,123,154,56,53,6,0,32,0,99,112,117,95,49,102,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,90,140,201,60,7,0,64,0,53,46,117,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,228,224,19,14,1,0,16,1,52,46,117,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,27,25,197,122,1,0,16,1,51,46,117,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,6,214,118,237,1,0,16,1,50,46,117,55,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,135,250,162,228,2,0,16,1,54,46,117,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,182,47,72,77,3,0,32,0,49,49,46,117,56,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,158,219,166,171,4,0,32,0,49,50,46,117,56,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,214,46,31,174,4,0,32,0,49,51,46,117,56,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,223,231,217,70,4,0,32,0,49,52,46,117,55,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,154,156,131,69,4,0,32,0,55,46,117,56,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,142,95,174,158,5,0,32,0,56,46,117,56,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,150,163,16,90,5,0,32,0,57,46,117,56,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,63,207,18,123,5,0,32,0,49,48,46,117,56,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,170,126,234,60,5,0,32,0,49,53,46,117,55,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,216,237,64,152,6,0,32,0,49,54,46,117,55,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,116,224,101,255,6,0,32,0,49,55,46,117,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,133,140,134,137,6,0,32,0,49,56,46,117,55,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,123,154,56,53,6,0,32,0,49,46,117,49,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,90,140,201,60,7,0,64,0,99,112,117,95,53,112,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,74,5,156,231,1,0,16,1,99,112,117,95,53,109,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,27,25,197,122,1,0,16,1,99,112,117,95,53,106,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,6,214,118,237,1,0,16,1,99,112,117,95,52,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,135,250,162,228,2,0,16,1,99,112,117,95,56,107,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,182,47,72,77,3,0,32,0,118,105,100,95,54,107,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,158,219,166,171,4,0,32,0,118,105,100,95,54,106,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,214,46,31,174,4,0,32,0,118,105,100,95,54,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,223,231,217,70,4,0,32,0,118,105,100,95,54,103,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,154,156,131,69,4,0,32,0,118,105,100,95,54,112,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,142,95,174,158,5,0,32,0,118,105,100,95,54,111,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,150,163,16,90,5,0,32,0,118,105,100,95,54,110,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,63,207,18,123,5,0,32,0,118,105,100,95,54,108,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,170,126,234,60,5,0,32,0,118,105,100,95,54,102,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,216,237,64,152,6,0,32,0,118,105,100,95,54,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,116,224,101,255,6,0,32,0,118,105,100,95,54,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,133,140,134,137,6,0,32,0,118,105,100,95,54,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,123,154,56,53,6,0,32,0,99,112,117,95,49,102,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,90,140,201,60,7,0,64,0,53,112,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,11,252,31,21,1,0,16,1,99,112,117,95,53,109,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,27,25,197,122,1,0,16,1,99,112,117,95,53,106,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,6,214,118,237,1,0,16,1,99,112,117,95,52,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,135,250,162,228,2,0,16,1,99,112,117,95,56,107,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,182,47,72,77,3,0,32,0,118,105,100,95,54,107,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,158,219,166,171,4,0,32,0,118,105,100,95,54,106,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,214,46,31,174,4,0,32,0,118,105,100,95,54,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,223,231,217,70,4,0,32,0,118,105,100,95,54,103,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,154,156,131,69,4,0,32,0,118,105,100,95,54,112,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,142,95,174,158,5,0,32,0,118,105,100,95,54,111,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,150,163,16,90,5,0,32,0,118,105,100,95,54,110,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,63,207,18,123,5,0,32,0,118,105,100,95,54,108,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,170,126,234,60,5,0,32,0,118,105,100,95,54,102,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,216,237,64,152,6,0,32,0,118,105,100,95,54,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,116,224,101,255,6,0,32,0,118,105,100,95,54,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,133,140,134,137,6,0,32,0,118,105,100,95,54,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,123,154,56,53,6,0,32,0,99,112,117,95,49,102,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,90,140,201,60,7,0,64,0,114,116,95,114,45,104,48,45,97,46,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,78,138,0,54,1,0,16,1,114,116,95,114,45,108,48,45,97,46,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,142,102,170,74,1,0,16,1,114,116,95,114,45,104,49,45,97,46,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,83,42,187,126,1,0,16,1,114,116,95,114,45,108,49,45,97,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,59,16,139,194,1,0,16,1,114,116,95,114,45,48,48,46,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,192,59,213,218,2,0,32,0,114,116,95,114,45,48,49,46,49,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,127,30,68,94,2,0,32,0,114,116,95,114,45,49,48,46,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,152,98,166,214,2,0,32,0,114,116,95,114,45,49,49,46,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,248,244,29,121,2,0,32,0,114,116,95,114,45,50,48,46,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,138,124,36,252,2,0,32,0,114,116,95,114,45,50,49,46,51,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,65,56,121,237,2,0,32,0,114,116,95,114,45,51,48,46,51,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,203,161,2,235,2,0,32,0,114,116,95,114,45,51,49,46,51,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,93,53,88,133,2,0,32,0,114,116,95,98,45,97,48,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,176,47,33,78,3,0,32,0,114,116,95,98,45,97,49,46,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,255,189,101,138,3,0,32,0,114,116,95,98,45,97,50,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,185,229,74,90,3,0,32,0,114,116,95,98,45,97,51,46,51,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,6,118,50,115,3,0,32,0,114,116,95,98,45,98,48,46,51,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,145,116,177,167,4,0,32,0,114,116,95,98,45,98,49,46,51,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,134,150,112,185,4,0,32,0,114,116,95,98,45,98,50,46,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,154,34,59,67,4,0,32,0,114,116,95,98,45,98,51,46,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,114,176,137,173,4,0,32,0,109,55,50,95,97,45,56,108,45,46,105,99,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,56,196,96,180,0,0,0,8,109,55,50,95,97,45,57,108,45,46,105,99,55,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,188,196,242,164,0,0,0,8,109,55,50,95,114,45,51,97,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,24,109,55,50,95,97,45,51,100,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,24,109,55,50,95,97,45,52,100,45,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,24,114,116,95,114,45,104,48,45,46,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,242,13,148,194,1,0,16,1,114,116,95,114,45,108,48,45,46,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,246,192,140,133,1,0,16,1,114,116,95,114,45,104,49,45,46,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,218,222,206,91,1,0,16,1,114,116,95,114,45,108,49,45,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,28,20,33,72,1,0,16,1,114,116,95,114,45,48,48,46,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,192,59,213,218,2,0,32,0,114,116,95,114,45,48,49,46,49,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,127,30,68,94,2,0,32,0,114,116,95,114,45,49,48,46,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,152,98,166,214,2,0,32,0,114,116,95,114,45,49,49,46,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,248,244,29,121,2,0,32,0,114,116,95,114,45,50,48,46,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,138,124,36,252,2,0,32,0,114,116,95,114,45,50,49,46,51,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,65,56,121,237,2,0,32,0,114,116,95,114,45,51,48,46,51,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,203,161,2,235,2,0,32,0,114,116,95,114,45,51,49,46,51,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,93,53,88,133,2,0,32,0,114,116,95,98,45,97,48,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,176,47,33,78,3,0,32,0,114,116,95,98,45,97,49,46,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,255,189,101,138,3,0,32,0,114,116,95,98,45,97,50,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,185,229,74,90,3,0,32,0,114,116,95,98,45,97,51,46,51,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,6,118,50,115,3,0,32,0,114,116,95,98,45,98,48,46,51,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,145,116,177,167,4,0,32,0,114,116,95,98,45,98,49,46,51,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,134,150,112,185,4,0,32,0,114,116,95,98,45,98,50,46,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,154,34,59,67,4,0,32,0,114,116,95,98,45,98,51,46,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,114,176,137,173,4,0,32,0,55,46,53,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,36,128,204,234,1,0,16,1,49,46,53,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,123,226,95,46,1,0,16,1,56,46,53,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,80,73,204,34,1,0,16,1,50,46,53,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,14,185,167,173,1,0,16,1,114,116,95,114,45,48,48,46,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,192,59,213,218,2,0,32,0,114,116,95,114,45,48,49,46,49,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,127,30,68,94,2,0,32,0,114,116,95,114,45,49,48,46,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,152,98,166,214,2,0,32,0,114,116,95,114,45,49,49,46,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,248,244,29,121,2,0,32,0,114,116,95,114,45,50,48,46,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,138,124,36,252,2,0,32,0,114,116,95,114,45,50,49,46,51,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,65,56,121,237,2,0,32,0,114,116,95,114,45,51,48,46,51,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,203,161,2,235,2,0,32,0,114,116,95,114,45,51,49,46,51,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,93,53,88,133,2,0,32,0,114,116,95,98,45,97,48,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,176,47,33,78,3,0,32,0,114,116,95,98,45,97,49,46,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,255,189,101,138,3,0,32,0,114,116,95,98,45,97,50,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,185,229,74,90,3,0,32,0,114,116,95,98,45,97,51,46,51,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,6,118,50,115,3,0,32,0,114,116,95,98,45,98,48,46,51,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,145,116,177,167,4,0,32,0,114,116,95,98,45,98,49,46,51,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,134,150,112,185,4,0,32,0,114,116,95,98,45,98,50,46,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,154,34,59,67,4,0,32,0,114,116,95,98,45,98,51,46,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,114,176,137,173,4,0,32,0,114,116,50,45,97,45,104,48,45,100,46,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,244,230,236,216,1,0,16,1,114,116,50,45,97,45,108,48,45,100,46,54,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,228,178,207,50,1,0,16,1,114,116,50,45,97,45,104,49,45,100,46,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,21,155,110,79,1,0,16,1,114,116,50,45,97,45,108,49,45,100,46,53,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,191,35,209,15,1,0,16,1,105,99,49,55,46,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,180,236,255,115,6,0,16,1,105,99,51,49,46,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,19,249,216,44,2,0,32,0,105,99,50,49,46,52,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,109,6,51,80,2,0,32,0,105,99,51,50,46,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,80,4,58,236,2,0,32,0,105,99,50,50,46,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,252,118,97,219,2,0,32,0,105,99,53,48,46,55,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,110,115,248,243,3,0,32,0,105,99,53,49,46,55,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,175,67,197,180,3,0,32,0,105,99,53,54,46,56,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,102,13,184,76,3,0,32,0,105,99,53,55,46,56,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,224,40,225,190,3,0,32,0,105,99,54,53,46,57,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,26,199,201,45,3,0,32,0,105,99,54,54,46,57,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,40,196,51,117,3,0,32,0,105,99,54,51,46,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,242,103,173,166,3,0,32,0,105,99,54,52,46,57,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,85,213,134,54,3,0,32,0,105,99,49,52,46,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,213,114,113,99,5,0,64,0,114,112,117,110,99,104,46,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,89,141,2,162,1,0,16,1,114,112,117,110,99,104,46,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,211,19,219,28,1,0,16,1,114,112,117,110,99,104,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,187,41,151,155,1,0,16,1,114,112,117,110,99,104,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,136,166,4,87,1,0,16,1,114,112,117,110,99,104,46,57,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,227,112,24,94,2,0,16,1,114,108,95,99,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,176,3,132,124,3,0,32,0,114,108,95,99,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,96,178,46,49,3,0,32,0,114,108,95,99,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,25,82,168,190,3,0,32,0,114,108,95,97,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,25,118,167,194,4,0,32,0,114,108,95,97,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,22,44,156,163,4,0,32,0,114,112,117,110,99,104,46,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,71,151,150,226,4,0,32,0,114,108,95,52,103,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,122,75,203,197,5,0,32,0,114,108,95,52,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,153,60,77,138,5,0,32,0,114,108,95,49,103,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,46,27,212,116,5,0,32,0,114,108,95,49,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,187,50,203,125,5,0,32,0,114,112,117,110,99,104,46,56,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,44,138,184,96,5,0,32,0,114,112,117,110,99,104,46,56,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,246,4,210,145,5,0,32,0,114,108,95,102,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,115,6,132,71,6,0,64,0,114,111,117,116,101,120,48,49,46,97,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,231,0,181,153,1,0,16,1,114,116,49,54,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,229,47,197,62,1,0,16,1,114,116,49,54,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,113,40,233,168,1,0,16,1,114,116,49,54,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,197,159,252,160,1,0,16,1,114,111,117,116,101,120,48,53,46,97,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,83,118,239,47,1,0,16,1,114,111,117,116,101,120,48,54,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,72,246,158,163,1,0,16,1,114,111,117,116,101,120,48,55,46,97,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,28,12,248,137,1,0,16,1,114,111,117,116,101,120,49,49,46,98,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,29,221,30,181,2,0,16,1,114,116,49,54,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,137,193,214,208,2,0,16,1,114,116,49,54,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,151,87,252,222,2,0,16,1,114,116,49,54,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,102,74,217,136,2,0,16,1,105,109,53,54,50,51,46,102,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,247,62,121,8,3,0,32,0,105,109,53,54,50,51,46,102,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,247,62,121,8,3,0,32,0,104,97,48,48,46,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,82,48,209,216,1,0,16,1,104,97,48,51,46,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,191,59,104,95,1,0,16,1,109,97,109,48,48,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,166,64,164,15,1,0,16,1,109,97,109,48,55,46,56,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,32,127,188,248,1,0,16,1,104,97,48,52,46,49,56,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,235,8,102,235,2,0,16,1,104,97,48,49,46,49,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,25,133,143,251,3,0,32,0,104,97,48,50,46,49,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,127,193,71,170,3,0,32,0,109,97,109,48,49,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,204,251,244,219,4,0,32,0,109,97,109,48,50,46,49,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,129,196,250,177,4,0,32,0,109,97,109,48,56,46,49,55,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,63,168,151,202,5,0,32,0,109,97,109,48,57,46,49,56,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,111,213,87,63,5,0,32,0,109,97,109,48,53,46,49,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,209,44,122,48,6,0,32,0,109,97,109,48,54,46,50,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,45,154,17,161,6,0,32,0,109,97,109,49,48,46,49,57,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,159,143,244,153,6,0,32,0,109,97,109,49,49,46,50,48,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,89,40,241,195,6,0,32,0,109,97,109,48,51,46,49,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,72,253,77,252,6,0,32,0,109,97,109,48,52,46,49,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,191,56,59,125,6,0,32,0,109,97,109,49,51,46,49,53,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,148,91,82,8,0,64,0,109,97,109,49,50,46,49,52,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,145,183,0,111,7,0,64,0,104,98,45,48,48,46,49,49,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,173,186,167,183,0,0,0,8,106,100,48,48,45,50,46,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,106,100,112,236,1,0,16,1,106,100,48,51,45,50,46,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,162,201,212,17,1,0,16,1,109,97,109,48,48,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,166,64,164,15,1,0,16,1,109,97,109,48,55,46,56,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,32,127,188,248,1,0,16,1,104,97,48,52,46,49,56,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,235,8,102,235,2,0,16,1,104,97,48,49,46,49,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,25,133,143,251,3,0,32,0,104,97,48,50,46,49,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,127,193,71,170,3,0,32,0,109,97,109,48,49,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,204,251,244,219,4,0,32,0,109,97,109,48,50,46,49,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,129,196,250,177,4,0,32,0,109,97,109,48,56,46,49,55,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,63,168,151,202,5,0,32,0,109,97,109,48,57,46,49,56,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,111,213,87,63,5,0,32,0,109,97,109,48,53,46,49,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,209,44,122,48,6,0,32,0,109,97,109,48,54,46,50,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,45,154,17,161,6,0,32,0,109,97,109,49,48,46,49,57,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,159,143,244,153,6,0,32,0,109,97,109,49,49,46,50,48,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,89,40,241,195,6,0,32,0,109,97,109,48,51,46,49,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,72,253,77,252,6,0,32,0,109,97,109,48,52,46,49,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,191,56,59,125,6,0,32,0,109,97,109,49,51,46,49,53,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,148,91,82,8,0,64,0,109,97,109,49,50,46,49,52,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,145,183,0,111,7,0,64,0,104,98,45,48,48,46,49,49,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,173,186,167,183,0,0,0,8,104,116,115,45,48,48,45,51,46,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,236,2,79,21,1,0,16,1,104,116,115,45,48,51,45,51,46,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,216,211,105,94,1,0,16,1,109,97,109,48,48,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,166,64,164,15,1,0,16,1,109,97,109,48,55,46,56,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,32,127,188,248,1,0,16,1,104,97,48,52,46,49,56,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,235,8,102,235,2,0,16,1,104,97,48,49,46,49,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,25,133,143,251,3,0,32,0,104,97,48,50,46,49,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,127,193,71,170,3,0,32,0,109,97,109,48,49,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,204,251,244,219,4,0,32,0,109,97,109,48,50,46,49,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,129,196,250,177,4,0,32,0,109,97,109,48,56,46,49,55,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,63,168,151,202,5,0,32,0,109,97,109,48,57,46,49,56,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,111,213,87,63,5,0,32,0,109,97,109,48,53,46,49,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,209,44,122,48,6,0,32,0,109,97,109,48,54,46,50,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,45,154,17,161,6,0,32,0,109,97,109,49,48,46,49,57,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,159,143,244,153,6,0,32,0,109,97,109,49,49,46,50,48,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,89,40,241,195,6,0,32,0,109,97,109,48,51,46,49,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,72,253,77,252,6,0,32,0,109,97,109,48,52,46,49,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,191,56,59,125,6,0,32,0,109,97,109,49,51,46,49,53,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,148,91,82,8,0,64,0,109,97,109,49,50,46,49,52,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,145,183,0,111,7,0,64,0,104,98,45,48,48,46,49,49,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,173,186,167,183,0,0,0,8,106,100,48,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,122,199,70,224,1,0,16,1,106,100,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,184,32,81,44,1,0,16,1,109,97,109,48,48,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,166,64,164,15,1,0,16,1,109,97,109,48,55,46,56,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,32,127,188,248,1,0,16,1,104,97,48,52,46,49,56,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,235,8,102,235,2,0,16,1,104,97,48,49,46,49,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,25,133,143,251,3,0,32,0,104,97,48,50,46,49,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,127,193,71,170,3,0,32,0,109,97,109,48,49,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,204,251,244,219,4,0,32,0,109,97,109,48,50,46,49,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,129,196,250,177,4,0,32,0,109,97,109,48,56,46,49,55,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,63,168,151,202,5,0,32,0,109,97,109,48,57,46,49,56,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,111,213,87,63,5,0,32,0,109,97,109,48,53,46,49,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,209,44,122,48,6,0,32,0,109,97,109,48,54,46,50,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,45,154,17,161,6,0,32,0,109,97,109,49,48,46,49,57,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,159,143,244,153,6,0,32,0,109,97,109,49,49,46,50,48,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,89,40,241,195,6,0,32,0,109,97,109,48,51,46,49,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,72,253,77,252,6,0,32,0,109,97,109,48,52,46,49,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,191,56,59,125,6,0,32,0,109,97,109,49,51,46,49,53,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,148,91,82,8,0,64,0,109,97,109,49,50,46,49,52,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,145,183,0,111,7,0,64,0,104,98,45,48,48,46,49,49,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,173,186,167,183,0,0,0,8,117,115,48,48,49,48,48,49,46,117,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,82,48,146,171,1,0,16,1,114,101,122,111,110,95,49,95,112,46,117,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,140,47,211,158,1,0,16,1,117,115,48,48,49,48,48,52,46,49,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,124,28,135,84,1,0,16,1,117,115,48,48,49,48,48,51,46,49,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,114,210,195,26,1,0,16,1,117,115,48,48,49,48,48,54,46,117,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,150,110,145,164,3,0,32,0,117,115,48,48,49,48,48,53,46,117,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,188,30,37,230,3,0,32,0,117,115,48,48,49,48,48,55,46,117,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,53,185,96,55,4,0,32,0,117,115,48,48,49,48,48,56,46,117,54,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,16,57,183,10,5,0,32,0,117,115,48,48,49,48,48,57,46,117,55,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,43,46,125,13,6,0,64,0,0,0,0,0,253,0,7,0,48,45,3,0,27,0,0,0,1,255,1,0,176,20,3,0,27,0,0,0,1,255,2,0,160,236,1,0,27,0,0,0,1,255,3,0,136,50,1,0,27,0,0,0,1,255,4,0,160,134,3,0,27,0,0,0,1,255,5,0,128,33,1,0,27,0,0,0,1,255,6,0,232,23,1,0,27,0,0,0,1,255,7,0,88,15,1,0,27,0,0,0,1,255,8,0,160,236,1,0,27,0,0,0,1,255,0,0,80,4,1,0,49,52,48,45,112,49,107,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,225,222,94,150,1,0,16,1,50,52,48,45,112,50,46,115,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,141,168,10,150,1,0,16,1,50,52,48,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,222,64,59,218,2,0,32,0,50,52,48,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,4,197,250,239,3,0,32,0,50,52,48,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,68,45,24,237,3,0,32,0,50,52,48,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,10,51,224,34,3,0,32,0,50,52,48,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,235,7,154,193,3,0,32,0,50,52,48,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,90,255,77,36,3,0,32,0,50,52,48,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,7,229,9,70,3,0,32,0,50,52,48,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,145,39,72,237,4,0,16,1,50,52,48,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,90,38,150,247,5,0,64,0,50,52,48,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,187,243,179,44,5,0,64,0,50,52,48,45,118,51,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,122,54,225,143,5,0,64,0,50,52,48,45,118,52,46,118,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,216,4,103,153,5,0,64,0,50,52,48,45,112,103,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,128,151,150,182,1,0,16,1,50,52,48,45,112,50,46,115,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,141,168,10,150,1,0,16,1,50,52,48,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,222,64,59,218,2,0,32,0,50,52,48,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,4,197,250,239,3,0,32,0,50,52,48,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,68,45,24,237,3,0,32,0,50,52,48,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,10,51,224,34,3,0,32,0,50,52,48,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,235,7,154,193,3,0,32,0,50,52,48,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,90,255,77,36,3,0,32,0,50,52,48,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,7,229,9,70,3,0,32,0,50,52,48,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,145,39,72,237,4,0,16,1,50,52,48,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,90,38,150,247,5,0,64,0,50,52,48,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,187,243,179,44,5,0,64,0,50,52,48,45,118,51,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,122,54,225,143,5,0,64,0,50,52,48,45,118,52,46,118,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,216,4,103,153,5,0,64,0,48,57,53,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,174,216,180,99,1,0,16,1,48,57,53,45,112,50,46,115,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,110,130,21,204,1,0,16,1,48,57,53,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,8,94,191,182,2,0,32,0,48,54,57,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,60,249,2,227,3,0,32,0,48,54,57,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,85,164,83,16,3,0,32,0,48,54,57,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,47,222,15,28,3,0,32,0,48,54,57,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,208,195,95,162,3,0,32,0,48,57,53,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,223,101,155,139,3,0,32,0,48,57,53,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,24,71,22,62,3,0,32,0,48,57,53,45,99,55,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,18,94,96,202,3,0,32,0,48,57,53,45,99,56,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,108,235,107,78,3,0,32,0,48,57,53,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,167,146,52,101,4,0,16,1,48,54,57,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,219,212,219,43,5,0,64,0,48,54,57,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,135,164,152,166,5,0,64,0,48,57,53,45,118,51,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,108,28,157,24,5,0,64,0,48,57,53,45,101,112,114,46,101,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,163,96,0,190,0,0,16,1,114,97,109,98,51,45,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,71,34,196,28,2,0,0,0,114,97,109,98,51,45,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,33,124,145,125,2,0,0,0,114,97,109,98,51,45,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,111,255,115,201,2,0,0,0,114,97,109,98,51,45,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,213,63,61,168,2,0,0,0,114,97,109,98,51,45,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,32,192,139,177,9,0,0,0,114,97,109,98,51,45,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,65,140,128,245,11,0,0,0,114,97,109,98,51,45,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,206,49,120,197,11,0,0,0,114,97,109,98,51,45,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,84,207,95,197,11,0,0,0,114,97,109,98,51,45,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,198,20,208,157,11,0,0,0,114,97,109,98,51,45,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,64,220,121,1,24,0,0,0,49,46,117,48,50,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,133,39,177,164,0,0,16,1,50,46,117,48,50,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,213,11,100,23,0,0,16,1,51,46,117,48,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,208,9,175,246,0,0,16,1,52,106,46,117,48,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,93,76,92,80,0,0,16,1,53,46,117,48,52,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,46,86,3,237,0,0,16,1,54,46,117,48,52,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,93,91,157,161,0,0,16,1,56,46,117,50,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,199,85,224,203,0,0,16,1])
.concat([57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,94,178,34,25,0,0,32,0,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,106,120,144,95,0,0,32,0,115,101,105,52,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,11,31,21,218,0,0,32,0,115,101,105,52,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,172,87,31,172,0,0,32,0,115,101,105,52,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,222,123,109,148,0,0,32,0,55,46,117,50,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,34,120,146,143,0,0,64,0,17,0,0,0,255,255,0,0,0,0,0,0,18,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,96,46,8,0,17,0,0,0,1,1,0,0,120,198,7,0,17,0,0,0,1,1,1,0,16,150,7,0,0,0,0,0,254,0,16,0,32,4,2,0,17,0,0,0,1,30,0,0,200,201,5,0,17,0,0,0,1,30,2,0,224,67,5,0,17,0,0,0,1,30,4,0,216,36,5,0,17,0,0,0,1,30,6,0,64,134,4,0,17,0,0,0,1,30,8,0,128,107,4,0,17,0,0,0,1,30,10,0,192,80,4,0,17,0,0,0,1,30,12,0,152,160,5,0,17,0,0,0,1,30,14,0,144,127,5,0,17,0,0,0,1,30,16,0,168,98,5,0,17,0,0,0,1,30,18,0,88,219,3,0,17,0,0,0,1,30,20,0,224,189,3,0,17,0,0,0,1,30,22,0,88,198,1,0,17,0,0,0,1,30,24,0,144,138,3,0,17,0,0,0,1,30,26,0,224,114,3,0,17,0,0,0,1,30,28,0,216,92,3,0,17,0,0,0,1,30,30,0,16,227,4,0,0,0,0,0,254,0,2,0,0,78,3,0,17,0,0,0,1,32,0,0,192,255,2,0,17,0,0,0,1,32,32,0,208,75,4,0,0,0,0,0,254,0,2,0,144,212,8,0,17,0,0,0,1,128,0,0,96,135,7,0,17,0,0,0,1,128,128,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,18,0,0,0,1,3,0,0,8,49,4,0,18,0,0,0,1,3,1,0,192,255,2,0,18,0,0,0,1,3,2,0,208,75,4,0,18,0,0,0,1,3,3,0,72,246,3,0,0,0,0,0,254,0,4,0,64,37,5,0,18,0,0,0,1,12,0,0,168,138,2,0,18,0,0,0,1,12,4,0,240,127,2,0,18,0,0,0,1,12,8,0,160,112,2,0,18,0,0,0,1,12,12,0,56,101,2,0,0,0,0,0,254,0,4,0,72,202,5,0,18,0,0,0,1,48,0,0,248,38,7,0,18,0,0,0,1,48,16,0,80,246,3,0,18,0,0,0,1,48,32,0,112,212,3,0,18,0,0,0,1,48,48,0,24,99,5,0,0,0,0,0,254,0,2,0,104,159,3,0,18,0,0,0,1,64,0,0,104,134,3,0,18,0,0,0,1,64,64,0,56,111,3,0,0,0,0,0,254,0,2,0,200,135,2,0,18,0,0,0,1,128,0,0,152,182,7,0,18,0,0,0,1,128,128,0,96,135,7,0,0,0,0,0,113,102,49,45,104,48,45,46,55,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,73,48,14,40,1,0,16,1,113,102,49,45,108,48,45,46,55,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,111,138,88,148,1,0,16,1,113,102,49,45,115,112,45,46,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,159,250,100,6,2,0,16,1,113,102,49,45,99,48,45,46,56,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,30,82,107,194,3,0,32,0,113,102,49,45,99,49,45,46,56,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,148,115,157,219,3,0,32,0,113,102,49,45,99,50,45,46,56,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,174,96,20,11,3,0,32,0,113,102,49,45,99,51,45,46,56,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,55,255,50,45,3,0,32,0,113,102,49,45,118,48,45,46,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,124,110,209,184,4,0,64,0,113,102,49,45,104,49,45,46,55,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,43,235,194,198,5,0,16,1,113,102,49,45,108,49,45,46,56,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,68,193,50,49,5,0,16,1,57,55,51,106,48,50,46,101,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,24,1,169,39,1,0,16,1,57,55,51,100,48,49,46,103,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,146,157,238,238,2,0,16,1,57,55,51,101,48,55,46,107,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,248,176,214,11,3,0,32,0,57,55,51,101,48,56,46,107,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,95,13,77,16,3,0,32,0,57,55,51,101,48,57,46,107,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,36,111,58,189,3,0,32,0,57,55,51,101,49,48,46,107,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,134,75,94,207,3,0,32,0,57,55,51,101,48,54,46,107,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,133,175,88,13,4,0,32,0,57,55,51,101,48,53,46,107,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,203,34,216,21,4,0,32,0,57,55,51,101,48,52,46,107,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,44,74,15,215,4,0,32,0,57,55,51,101,48,51,46,107,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,75,75,90,44,4,0,32,0,57,55,51,97,49,49,46,104,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,233,143,210,70,5,0,0,8,49,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,99,156,49,187,1,0,16,1,50,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,152,61,70,161,1,0,16,1,51,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,8,158,26,254,1,0,16,1,52,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,204,155,15,158,1,0,16,1,120,120,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,104,179,226,251,2,0,16,1,120,120,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,61,91,121,225,2,0,16,1,56,46,49,48,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,235,41,27,147,3,0,32,0,55,46,57,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,228,214,230,187,3,0,32,0,54,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,33,193,216,178,4,0,32,0,53,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,182,194,151,16,4,0,32,0,112,111,111,121,97,110,46,112,114,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,14,109,106,160,5,0,32,0,112,111,111,121,97,110,46,112,114,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,96,205,212,140,5,0,32,0,112,111,111,121,97,110,46,112,114,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,11,140,116,130,5,0,32,0,112,111,111,95,105,99,50,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,36,58,178,65,1,0,16,1,112,111,111,95,105,99,50,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,97,70,217,201,1,0,16,1,51,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,8,158,26,254,1,0,16,1,112,111,111,95,105,99,50,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,239,89,228,138,1,0,16,1,120,120,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,104,179,226,251,2,0,16,1,120,120,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,61,91,121,225,2,0,16,1,112,111,111,95,105,99,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,228,2,232,11,3,0,32,0,112,111,111,95,105,99,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,150,144,162,203,3,0,32,0,54,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,33,193,216,178,4,0,32,0,53,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,182,194,151,16,4,0,32,0,112,111,111,121,97,110,46,112,114,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,14,109,106,160,5,0,32,0,112,111,111,121,97,110,46,112,114,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,96,205,212,140,5,0,32,0,112,111,111,121,97,110,46,112,114,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,11,140,116,130,5,0,32,0,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,219,100,64,224,1,0,16,1,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,36,36,117,117,1,0,16,1,48,50,49,95,112,110,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,239,227,36,120,1,0,16,1,48,50,48,95,112,110,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,99,150,123,55,1,0,16,1,48,51,50,95,112,110,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,193,68,222,191,1,0,16,1,48,51,49,95,112,110,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,13,195,232,100,1,0,16,1,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,123,67,50,18,2,0,32,0,101,112,49,54,57,53,46,49,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,233,38,253,91,2,0,32,0,112,114,49,54,51,51,46,55,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,236,68,88,58,3,0,32,0,112,114,49,54,51,52,46,56,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,155,19,107,118,3,0,32,0,112,114,49,54,51,53,46,53,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,39,234,157,194,4,0,64,0,112,114,49,54,51,54,46,55,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,101,112,49,55,51,56,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,234,37,186,104,1,0,16,1,101,112,49,55,51,57,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,179,181,231,65,1,0,16,1,101,112,49,55,52,48,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,89,95,240,39,1,0,16,1,101,112,49,55,52,49,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,193,62,217,39,1,0,16,1,101,112,49,55,52,50,46,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,236,132,32,183,1,0,16,1,101,112,49,55,52,51,46,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,207,112,5,119,1,0,16,1,101,112,49,55,52,52,46,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,196,18,123,175,1,0,16,1,101,112,49,55,52,53,46,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,185,24,126,80,1,0,16,1,101,112,49,54,52,48,46,57,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,205,198,238,215,2,0,32,0,101,112,49,54,57,53,46,49,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,233,38,253,91,2,0,32,0,112,114,49,54,51,51,46,55,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,236,68,88,58,3,0,32,0,112,114,49,54,51,52,46,56,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,155,19,107,118,3,0,32,0,112,114,49,54,51,53,46,53,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,39,234,157,194,4,0,64,0,112,114,49,54,51,54,46,55,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,105,99,56,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,123,75,146,228,1,0,16,1,105,99,55,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,93,119,231,114,1,0,16,1,105,99,49,53,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,30,239,16,116,1,0,16,1,105,99,49,52,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,121,243,179,85,1,0,16,1,101,112,49,54,57,51,98,46,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,236,132,32,183,1,0,16,1,105,99,50,48,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,207,112,5,119,1,0,16,1,101,112,53,49,49,56,98,46,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,196,18,123,175,1,0,16,1,105,99,51,49,46,50,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,193,85,149,102,1,0,16,1,101,112,49,54,52,48,46,57,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,205,198,238,215,2,0,32,0,101,112,49,54,57,53,46,49,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,233,38,253,91,2,0,32,0,112,114,49,54,51,51,46,55,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,236,68,88,58,3,0,32,0,112,114,49,54,51,52,46,56,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,155,19,107,118,3,0,32,0,112,114,49,54,51,53,46,53,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,39,234,157,194,4,0,64,0,112,114,49,54,51,54,46,55,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,112,97,99,109,97,110,104,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,112,194,46,59,1,0,16,1,112,97,99,109,97,110,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,212,178,111,26,1,0,16,1,112,97,99,109,97,110,104,46,54,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,128,23,129,24,1,0,16,1,112,97,99,109,97,110,104,46,54,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,51,167,150,92,1,0,16,1,112,97,99,109,97,110,104,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,122,177,159,41,2,0,32,0,112,97,99,109,97,110,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,249,237,143,149,2,0,32,0,56,50,115,49,50,51,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,189,80,198,47,3,0,32,0,56,50,115,49,50,54,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,228,168,179,62,3,0,32,0,56,50,115,49,50,54,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,134,204,169,4,0,64,0,56,50,115,49,50,54,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,112,97,99,109,97,110,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,16,171,230,193,1,0,16,1,112,97,99,109,97,110,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,212,178,111,26,1,0,16,1,112,97,99,109,97,110,46,54,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,235,27,221,188,1,0,16,1,112,97,99,109,97,110,46,54,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,227,148,125,129,1,0,16,1,112,97,99,109,97,110,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,100,73,148,12,2,0,32,0,112,97,99,109,97,110,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,249,237,143,149,2,0,32,0,56,50,115,49,50,51,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,189,80,198,47,3,0,32,0,56,50,115,49,50,54,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,228,168,179,62,3,0,32,0,56,50,115,49,50,54,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,134,204,169,4,0,64,0,56,50,115,49,50,54,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,98,111,111,116,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,183,49,107,209,1,0,16,1,98,111,111,116,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,94,222,50,13,1,0,16,1,112,97,99,109,97,110,46,55,102,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,92,77,63,81,1,0,16,1,112,97,99,109,97,110,46,55,104,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,142,76,105,112,1,0,16,1,98,111,111,116,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,230,109,62,140,1,0,16,1,98,111,111,116,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,101,177,140,54,1,0,16,1,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,1,29,40,92,2,0,32,0,112,97,99,109,97,110,46,53,101,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,113,238,163,101,2,0,32,0,112,97,99,109,97,110,46,53,104,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,125,71,199,80,2,0,32,0,56,50,115,49,50,51,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,189,80,198,47,3,0,32,0,56,50,115,49,50,57,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,39,185,239,99,3,0,32,0,56,50,115,49,50,54,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,134,204,169,4,0,64,0,56,50,115,49,50,54,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,101,100,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,212,212,176,249,1,0,0,0,101,100,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,169,187,212,226,1,0,0,0,101,100,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,25,217,229,16,2,0,0,0,101,100,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,197,49,32,67,3,0,0,0,101,100,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,100,194,138,48,4,0,0,0,101,100,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,27,121,106,65,5,0,0,0,101,100,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,49,164,219,252,5,0,0,0,101,100,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,188,190,80,125,5,0,0,0,101,100,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,165,15,223,143,5,0,0,0,101,100,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,158,142,165,211,6,0,0,0,101,100,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,15,251,196,79,6,0,0,0,101,100,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,45,31,32,172,6,0,0,0,101,100,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,81,86,220,125,6,0,0,0,105,100,56,55,53,49,104,46,109,99,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,7,0,0,16,100,117,45,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,126,248,161,190,8,0,0,0,0,0,0,0,0,0,0,0,110,97,117,109,111,117,115,101,46,100,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,250,236,71,228,1,0,16,1,110,97,117,109,111,117,115,101,46,100,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,217,19,111,46,1,0,16,1,110,97,117,109,111,117,115,101,46,101,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,151,15,168,68,1,0,16,1,110,97,117,109,111,117,115,101,46,101,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,189,70,122,156,1,0,16,1,110,97,117,109,111,117,115,101,46,104,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,93,76,201,91,1,0,16,1,110,97,117,109,111,117,115,101,46,104,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,34,158,242,26,1,0,16,1,110,97,117,109,111,117,115,101,46,106,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,133,225,59,204,1,0,16,1,110,97,117,109,111,117,115,101,46,106,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,220,229,179,102,1,0,16,1,110,97,117,109,111,117,115,101,46,100,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,63,204,167,46,2,0,32,0,110,97,117,109,111,117,115,101,46,104,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,234,252,17,5,2,0,32,0,110,97,117,109,111,117,115,101,46,101,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,205,39,166,245,2,0,32,0,110,97,117,109,111,117,115,101,46,106,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,14,88,242,101,2,0,32,0,56,50,115,49,50,51,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,189,80,198,47,3,0,32,0,110,97,117,109,111,117,115,101,46,97,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,103,33,119,216,3,0,32,0,56,50,115,49,50,54,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,134,204,169,4,0,64,0,56,50,115,49,50,54,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,14,0,0,0,255,255,201,0,0,0,0,0,15,0,0,0,255,255,255,0,0,0,0,0,16,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,32,4,2,0,14,0,0,0,1,3,3,0,160,36,8,0,14,0,0,0,1,3,1,0,208,239,7,0,14,0,0,0,1,3,2,0,120,187,7,0,14,0,0,0,1,3,0,0,16,227,4,0,0,0,0,0,254,0,4,0,128,129,4,0,14,0,0,0,1,12,0,0,192,255,2,0,14,0,0,0,1,12,4,0,208,75,4,0,14,0,0,0,1,12,8,0,8,49,4,0,14,0,0,0,1,12,12,0,72,246,3,0,0,0,0,0,254,0,4,0,64,37,5,0,14,0,0,0,1,48,0,0,136,120,6,0,14,0,0,0,1,48,16,0,176,116,6,0,14,0,0,0,1,48,32,0,80,113,6,0,14,0,0,0,1,48,48,0,120,7,5,0,0,0,0,0,254,0,2,0,72,202,5,0,14,0,0,0,1,64,64,0,248,38,7,0,14,0,0,0,1,64,0,0,112,212,3,0,0,0,0,0,254,0,2,0,16,27,6,0,15,0,0,0,1,16,16,0,96,135,7,0,15,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,2,0,200,30,2,0,16,0,0,0,1,128,128,0,120,97,1,0,16,0,0,0,1,128,0,0,96,19,1,0,0,0,0,0,110,105,116,100,45,112,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,27,189,5,26,1,0,16,1,110,105,116,100,45,115,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,124,244,59,221,2,0,32,0,110,105,116,100,45,99,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,144,49,53,180,3,0,32,0,110,105,116,100,45,99,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,31,81,39,110,3,0,32,0,110,105,116,100,45,99,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,117,240,44,71,3,0,32,0,110,105,116,100,45,99,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,230,38,57,76,3,0,32,0,50,54,48,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,229,197,7,100,4,0,16,1,110,105,116,100,45,118,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,104,136,0,121,5,0,64,0,110,105,116,100,45,118,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,249,88,133,114,5,0,64,0,102,114,103,45,112,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,218,72,104,194,1,0,16,1,102,114,103,45,115,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,19,205,244,136,2,0,32,0,102,114,103,45,99,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,179,159,47,123,3,0,32,0,102,114,103,45,99,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,111,138,241,167,3,0,32,0,102,114,103,45,99,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,116,172,107,149,3,0,32,0,102,114,103,45,99,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,116,172,107,149,3,0,32,0,102,114,103,45,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,132,180,37,200,4,0,16,1,102,114,103,45,118,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,17,218,57,38,5,0,64,0,102,114,103,45,118,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,139,165,237,229,5,0,64,0,110,103,101,109,45,112,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,227,47,196,242,1,0,16,1,110,103,101,109,45,115,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,210,2,60,251,2,0,32,0,110,103,101,109,45,99,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,71,171,226,168,3,0,32,0,110,103,101,109,45,99,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,28,234,56,167,3,0,32,0,110,103,101,109,45,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,21,74,244,177,4,0,16,1,110,103,101,109,45,118,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,240,153,33,195,5,0,64,0,119,119,50,95,112,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,255,98,55,213,1,0,16,1,119,119,50,95,115,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,26,93,218,63,2,0,32,0,119,119,50,95,99,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,62,253,94,149,3,0,32,0,119,119,50,95,99,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,15,148,19,194,3,0,32,0,119,119,50,95,109,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,78,53,194,153,4,0,16,1,119,119,50,95,118,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,251,184,190,222,5,0,64,0,116,101,116,95,112,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,154,86,101,52,1,0,16,1,116,101,116,95,115,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,147,181,69,165,2,0,32,0,116,101,116,95,99,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,212,209,198,172,3,0,32,0,116,101,116,95,99,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,106,192,126,3,0,32,0,116,101,116,95,109,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,198,3,55,107,4,0,16,1,116,101,116,95,118,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,144,226,232,43,5,0,64,0,97,115,105,97,45,115,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,227,75,182,145,0,0,16,7,115,112,45,115,50,46,115,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,121,216,54,144,0,0,16,15,115,112,45,115,46,115,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,69,250,242,199,0,0,16,15,115,112,45,117,50,46,115,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,222,67,41,231,0,0,16,15,115,112,45,101,46,115,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,181,165,35,39,0,0,16,15,118,115,45,98,105,111,115,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,125,242,232,240,0,0,16,15,115,112,45,106,50,46,115,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,156,229,237,172,0,0,16,15,115,112,49,46,106,105,112,97,110,46,49,48,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,228,171,176,159,0,0,16,15,115,112,45,52,53,46,115,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,106,159,204,3,0,0,16,15,106,97,112,97,110,45,106,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,31,212,246,223,0,0,16,15,110,101,111,45,112,111,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,50,193,208,22,0,0,16,15,110,101,111,45,101,112,111,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,241,113,122,210,0,0,16,15,110,101,111,100,101,98,117,103,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,125,187,142,105,0,0,16,15,115,112,45,49,118,49,95,51,100,98,56,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,190,14,47,22,0,0,16,15,117,110,105,45,98,105,111,115,95,51,95,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,169,137,124,169,0,0,16,15,117,110,105,45,98,105,111,115,95,50,95,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,181,78,102,39,0,0,16,15,117,110,105,45,98,105,111,115,95,50,95,51,111,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,174,32,23,96,0,0,16,15,117,110,105,45,98,105,111,115,95,50,95,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,106,153,80,45,0,0,16,15,117,110,105,45,98,105,111,115,95,50,95,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,107,247,171,141,0,0,16,15,117,110,105,45,98,105,111,115,95,50,95,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,173,194,18,12,0,0,16,15,117,110,105,45,98,105,111,115,95,49,95,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,160,68,75,178,0,0,16,15,117,110,105,45,98,105,111,115,95,49,95,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,233,152,166,79,0,0,16,15,117,110,105,45,98,105,111,115,95,49,95,50,111,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,233,60,157,225,0,0,16,15,117,110,105,45,98,105,111,115,95,49,95,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,132,13,218,93,0,0,16,15,117,110,105,45,98,105,111,115,95,49,95,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,160,83,228,12,0,0,16,15,110,101,111,112,101,110,46,115,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,118,94,145,203,0,0,16,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,115,109,49,46,115,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,103,109,65,148,0,0,16,3,115,102,105,120,46,115,102,105,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,253,12,234,194,0,0,32,2,48,48,48,45,108,111,46,108,111,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,242,207,134,90,0,0,0,3,0,0,0,0,254,0,2,0,232,159,1,0,0,0,0,0,1,1,0,0,96,135,7,0,0,0,0,0,1,1,1,0,152,182,7,0,0,0,0,0,254,0,2,0,48,140,3,0,0,0,0,0,2,2,0,0,192,255,2,0,2,0,0,0,0,63,6,0,0,0,0,0,0,0,0,0,2,2,2,0,208,75,4,0,2,0,0,0,0,63,6,0,0,0,0,0,0,0,0,0,254,0,2,0,48,140,3,0,0,0,0,0,130,2,0,0,208,75,4,0,2,0,0,0,0,63,6,0,0,0,0,0,0,0,0,0,130,2,2,0,152,21,4,0,2,0,0,0,0,63,6,0,0,0,0,0,0,0,0,0,254,0,5,0,192,157,1,0,0,0,0,0,1,56,0,0,168,165,2,0,0,0,0,0,1,56,8,0,216,154,1,0,0,0,0,0,1,56,16,0,144,153,1,0,0,0,0,0,1,56,24,0,248,150,1,0,0,0,0,0,1,56,32,0,72,149,1,0,0,0,0,0,1,56,40,0,192,148,1,0,0,0,0,0,1,56,48,0,72,148,1,0,0,0,0,0,1,56,56,0,224,146,1,0,0,0,0,0,254,0,2,0,40,182,1,0,0,0,0,0,1,64,0,0,96,135,7,0,0,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,248,142,8,0,0,0,0,0,1,128,0,0,96,135,7,0,0,0,0,0,1,128,128,0,152,182,7,0,0,0,0,0,253,0,26,0,184,144,1,0,2,0,0,0,1,31,0,0,176,143,1,0,2,0,0,0,1,31,1,0,208,142,1,0,2,0,0,0,1,31,2,0,104,141,1,0,2,0,0,0,1,31,3,0,96,140,1,0,2,0,0,0,1,31,4,0,192,138,1,0,2,0,0,0,1,31,5,0,184,137,1,0,2,0,0,0,1,31,6,0,152,136,1,0,2,0,0,0,1,31,7,0,64,135,1,0,2,0,0,0,1,31,8,0,40,134,1,0,2,0,0,0,1,31,9,0,144,132,1,0,2,0,0,0,1,31,10,0,160,130,1,0,2,0,0,0,1,31,11,0,40,129,1,0,2,0,0,0,1,31,12,0,32,127,1,0,2,0,0,0,1,31,13,0,208,125,1,0,2,0,0,0,1,31,14,0,24,125,1,0,2,0,0,0,1,31,15,0,200,123,1,0,2,0,0,0,1,31,16,0,120,122,1,0,2,0,0,0,1,31,17,0,216,121,1,0,2,0,0,0,1,31,18,0,200,120,1,0,2,0,0,0,1,31,19,0,32,118,1,0,2,0,0,0,1,31,20,0,208,116,1,0,2,0,0,0,1,31,21,0,56,115,1,0,2,0,0,0,1,31,22,0,232,113,1,0,2,0,0,0,1,31,23,0,200,111,1,0,2,0,0,0,1,31,24,0,160,110,1,0,2,0,0,0,1,31,25,0,232,109,1,0,0,0,0,0,253,0,2,0,40,109,1,0,2,0,0,0,1,128,128,0,64,108,1,0,2,0,0,0,1,128,0,0,120,107,1,0,0,0,0,0,253,0,2,0,176,105,1,0,2,0,0,0,1,64,64,0,80,104,1,0,2,0,0,0,1,64,0,0,248,38,7,0,0,0,0,0,110,101,111,99,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,144,228,157,223,0,0,16,3,48,48,48,45,108,111,46,108,111,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,242,207,134,90,0,0,16,3,97,115,105,97,45,115,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,227,75,182,145,0,0,16,7,115,112,45,115,50,46,115,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,121,216,54,144,0,0,16,15,115,112,45,115,46,115,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,69,250,242,199,0,0,16,15,117,115,97,95,50,115,108,116,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,222,67,41,231,0,0,16,15,115,112,45,101,46,115,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,181,165,35,39,0,0,16,15,118,115,45,98,105,111,115,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,125,242,232,240,0,0,16,15,115,112,45,106,50,46,115,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,156,229,237,172,0,0,16,15,115,112,49,46,106,105,112,97,110,46,49,48,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,228,171,176,159,0,0,16,15,115,112,45,52,53,46,115,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,106,159,204,3,0,0,16,15,106,97,112,97,110,45,106,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,31,212,246,223,0,0,16,15,110,101,111,45,112,111,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,50,193,208,22,0,0,16,15,110,101,111,45,101,112,111,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,241,113,122,210,0,0,16,15,110,101,111,100,101,98,117,103,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,125,187,142,105,0,0,16,15,115,112,45,49,118,49,95,51,100,98,56,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,190,14,47,22,0,0,16,15,117,110,105,45,98,105,111,115,95,51,95,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,169,137,124,169,0,0,16,15,117,110,105,45,98,105,111,115,95,50,95,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,181,78,102,39,0,0,16,15,117,110,105,45,98,105,111,115,95,50,95,51,111,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,174,32,23,96,0,0,16,15,117,110,105,45,98,105,111,115,95,50,95,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,106,153,80,45,0,0,16,15,117,110,105,45,98,105,111,115,95,50,95,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,107,247,171,141,0,0,16,15,117,110,105,45,98,105,111,115,95,50,95,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,173,194,18,12,0,0,16,15,117,110,105,45,98,105,111,115,95,49,95,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,160,68,75,178,0,0,16,15,117,110,105,45,98,105,111,115,95,49,95,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,233,152,166,79,0,0,16,15,117,110,105,45,98,105,111,115,95,49,95,50,111,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,233,60,157,225,0,0,16,15,117,110,105,45,98,105,111,115,95,49,95,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,132,13,218,93,0,0,16,15,117,110,105,45,98,105,111,115,95,49,95,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,160,83,228,12,0,0,16,15,110,101,111,112,101,110,46,115,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,118,94,145,203,0,0,16,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,115,109,49,46,115,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,103,109,65,148,0,0,16,3,115,102,105,120,46,115,102,105,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,253,12,234,194,0,0,32,2,48,48,48,45,108,111,46,108,111,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,242,207,134,90,0,0,0,3,25,0,0,0,240,0,0,0,0,0,0,0,0,0,0,0,255,255,0,0,0,0,0,0,1,0,0,0,255,127,0,0,0,0,0,0,0,0,0,0,254,0,2,0,208,161,1,0,0,0,0,0,1,4,0,0,96,135,7,0,0,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,254,0,2,0,232,159,1,0,0,0,0,0,1,1,0,0,96,135,7,0,0,0,0,0,1,1,1,0,152,182,7,0,0,0,0,0,254,0,2,0,48,140,3,0,0,0,0,0,2,2,0,0,192,255,2,0,2,0,0,0,0,63,6,0,0,0,0,0,0,0,0,0,2,2,2,0,208,75,4,0,2,0,0,0,0,63,6,0,0,0,0,0,0,0,0,0,254,0,2,0,48,140,3,0,0,0,0,0,130,2,0,0,208,75,4,0,2,0,0,0,0,63,6,0,0,0,0,0,0,0,0,0,130,2,2,0,152,21,4,0,2,0,0,0,0,63,6,0,0,0,0,0,0,0,0,0,254,0,5,0,192,157,1,0,0,0,0,0,1,56,0,0,168,165,2,0,0,0,0,0,1,56,8,0,216,154,1,0,0,0,0,0,1,56,16,0])
.concat([144,153,1,0,0,0,0,0,1,56,24,0,248,150,1,0,0,0,0,0,1,56,32,0,72,149,1,0,0,0,0,0,1,56,40,0,192,148,1,0,0,0,0,0,1,56,48,0,72,148,1,0,0,0,0,0,1,56,56,0,224,146,1,0,0,0,0,0,254,0,2,0,40,182,1,0,0,0,0,0,1,64,0,0,96,135,7,0,0,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,248,142,8,0,0,0,0,0,1,128,0,0,96,135,7,0,0,0,0,0,1,128,128,0,152,182,7,0,98,56,49,45,48,56,46,53,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,105,145,218,214,2,0,0,0,98,56,49,45,49,51,46,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,251,118,209,96,2,0,0,0,98,56,49,45,49,48,46,52,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,68,67,243,83,2,0,0,0,98,56,49,45,48,57,46,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,175,52,13,99,2,0,0,0,98,56,49,45,49,49,46,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,9,191,4,55,9,0,0,0,98,56,49,45,48,51,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,230,117,27,85,11,0,0,0,98,56,49,45,48,52,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,18,78,115,207,11,0,0,0,98,56,49,45,48,50,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,134,59,236,32,24,0,0,0,98,56,49,45,48,49,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,107,121,63,179,25,0,0,0,97,109,112,97,108,49,54,108,56,45,98,56,49,45,48,53,46,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,104,211,47,146,0,0,0,8,97,109,112,97,108,49,54,108,56,45,98,56,49,45,48,54,97,46,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,132,236,28,187,0,0,0,8,0,0,0,0,0,0,0,0,48,49,52,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,200,153,22,111,1,0,16,1,48,49,52,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,51,151,65,153,2,0,32,0,48,49,52,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,191,129,67,94,3,0,32,0,48,49,52,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,24,78,186,105,3,0,32,0,48,49,52,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,213,39,3,137,3,0,32,0,48,49,52,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,81,38,0,228,3,0,32,0,48,49,52,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,146,48,104,182,4,0,16,1,48,49,52,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,150,146,65,37,5,0,64,0,48,49,52,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,94,61,229,13,5,0,64,0,50,53,48,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,11,246,241,129,1,0,16,1,50,53,48,45,112,50,46,101,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,18,46,218,31,1,0,16,1,50,53,48,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,29,68,111,251,2,0,32,0,50,53,48,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,111,44,165,9,3,0,32,0,50,53,48,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,33,152,103,49,3,0,32,0,50,53,48,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,25,32,96,253,3,0,32,0,50,53,48,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,19,69,53,49,3,0,32,0,50,53,48,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,36,97,181,164,3,0,32,0,50,53,48,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,157,230,227,131,3,0,32,0,50,53,48,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,66,168,66,253,4,0,16,1,50,53,48,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,115,222,158,199,5,0,64,0,50,53,48,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,225,171,154,234,5,0,64,0,50,53,48,45,118,51,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,2,81,166,44,5,0,64,0,50,54,56,45,112,49,99,114,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,146,103,70,208,1,0,16,1,50,54,56,45,112,50,99,114,46,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,30,182,246,251,1,0,16,1,50,54,56,45,99,49,99,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,154,56,124,171,3,0,32,0,50,54,56,45,99,50,99,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,27,136,96,53,3,0,32,0,50,54,56,45,99,51,99,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,234,85,249,58,3,0,32,0,50,54,56,45,99,52,99,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,115,195,41,195,3,0,32,0,50,54,56,45,99,53,99,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,119,129,156,149,3,0,32,0,50,54,56,45,99,54,99,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,27,131,10,1,3,0,32,0,50,54,56,45,99,55,99,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,105,169,114,109,3,0,32,0,50,54,56,45,99,56,99,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,14,114,29,85,3,0,32,0,50,54,56,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,14,110,90,74,4,0,16,1,50,54,56,45,118,49,99,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,12,214,49,174,5,0,64,0,50,54,56,45,118,50,99,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,237,19,6,196,5,0,64,0,50,54,51,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,243,222,228,39,1,0,16,1,50,54,51,45,112,50,46,115,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,216,174,183,253,1,0,16,1,50,54,51,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,138,95,134,132,3,0,32,0,50,54,51,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,242,151,223,129,3,0,32,0,50,54,51,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,35,51,52,26,3,0,32,0,50,54,51,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,68,251,44,148,3,0,32,0,50,54,51,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,79,133,72,167,3,0,32,0,50,54,51,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,22,161,139,92,3,0,32,0,50,54,51,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,40,130,172,70,4,0,16,1,50,54,51,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,205,185,233,1,5,0,64,0,50,54,51,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,129,191,178,74,5,0,64,0,110,101,111,45,115,109,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,54,87,213,156,9,0,16,1,50,53,54,45,112,103,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,213,223,126,176,1,0,16,1,50,53,54,45,112,103,50,46,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,107,194,151,96,1,0,16,1,50,53,54,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,78,195,121,90,3,0,32,0,50,53,54,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,44,54,76,148,3,0,32,0,50,53,54,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,111,211,105,110,3,0,32,0,50,53,54,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,235,180,85,183,3,0,32,0,50,53,54,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,71,171,172,122,3,0,32,0,50,53,54,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,93,253,152,198,3,0,32,0,50,53,54,45,99,55,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,210,221,206,207,3,0,32,0,50,53,54,45,99,56,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,76,227,155,77,3,0,32,0,50,53,54,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,22,193,238,234,4,0,16,1,50,53,54,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,65,2,105,242,5,0,64,0,50,53,54,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,189,16,42,126,5,0,64,0,50,53,54,45,118,51,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,124,193,174,14,5,0,64,0,50,53,54,45,118,52,46,118,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,212,34,75,155,5,0,64,0,50,52,49,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,218,197,83,42,1,0,16,1,50,52,49,45,112,50,46,115,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,68,63,136,56,1,0,16,1,50,52,49,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,15,47,211,243,2,0,32,0,50,52,49,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,13,94,75,57,3,0,32,0,50,52,49,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,33,98,128,229,3,0,32,0,50,52,49,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,111,250,107,159,3,0,32,0,50,52,49,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,111,48,62,125,3,0,32,0,50,52,49,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,189,14,82,148,4,0,16,1,50,52,49,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,232,32,236,153,5,0,64,0,50,52,49,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,153,103,177,236,5,0,64,0,50,54,56,45,112,49,114,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,146,103,70,208,1,0,16,1,50,54,56,45,112,50,114,46,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,30,182,246,251,1,0,16,1,50,54,56,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,232,66,32,128,3,0,32,0,50,54,56,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,159,251,137,59,3,0,32,0,50,54,56,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,227,89,63,15,3,0,32,0,50,54,56,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,90,67,216,58,3,0,32,0,50,54,56,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,14,110,90,74,4,0,16,1,50,54,56,45,118,49,46,118,49,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,229,175,88,132,5,0,64,0,25,0,0,0,240,0,0,0,0,0,0,0,0,0,0,0,255,255,0,0,0,0,0,0,1,0,0,0,255,127,0,0,0,0,0,0,2,0,0,0,255,255,134,0,0,0,0,0,0,0,0,0,254,0,2,0,208,161,1,0,13,0,0,0,1,4,0,0,96,135,7,0,13,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,254,0,2,0,232,159,1,0,0,0,0,0,1,1,0,0,96,135,7,0,0,0,0,0,1,1,1,0,152,182,7,0,0,0,0,0,254,0,2,0,48,140,3,0,0,0,0,0,2,2,0,0,192,255,2,0,2,0,0,0,0,63,6,0,0,0,0,0,0,0,0,0,2,2,2,0,208,75,4,0,2,0,0,0,0,63,6,0,0,0,0,0,0,0,0,0,254,0,2,0,48,140,3,0,0,0,0,0,130,2,0,0,208,75,4,0,2,0,0,0,0,63,6,0,0,0,0,0,0,0,0,0,130,2,2,0,152,21,4,0,2,0,0,0,0,63,6,0,0,0,0,0,0,0,0,0,254,0,5,0,192,157,1,0,0,0,0,0,1,56,0,0,168,165,2,0,0,0,0,0,1,56,8,0,216,154,1,0,0,0,0,0,1,56,16,0,144,153,1,0,0,0,0,0,1,56,24,0,248,150,1,0,0,0,0,0,1,56,32,0,72,149,1,0,0,0,0,0,1,56,40,0,192,148,1,0,0,0,0,0,1,56,48,0,72,148,1,0,0,0,0,0,1,56,56,0,224,146,1,0,0,0,0,0,254,0,2,0,40,182,1,0,0,0,0,0,1,64,0,0,96,135,7,0,0,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,248,142,8,0,0,0,0,0,1,128,0,0,96,135,7,0,0,0,0,0,1,128,128,0,152,182,7,0,0,0,0,0,253,0,2,0,48,45,3,0,2,0,0,0,2,3,2,0,248,8,1,0,2,0,0,0,0,48,0,0,0,0,0,0,2,0,0,0,2,3,3,0,176,20,3,0,2,0,0,0,0,48,0,0,0,0,0,0,109,104,45,99,45,104,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,70,86,202,226,1,0,16,1,109,104,45,99,45,108,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,205,35,62,100,1,0,16,1,109,104,45,99,45,104,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,77,232,116,137,1,0,16,1,109,104,45,99,45,108,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,105,218,139,95,1,0,16,1,109,104,45,99,45,104,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,110,89,63,20,1,0,16,1,109,104,45,99,45,108,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,54,37,152,192,1,0,16,1,109,104,45,99,45,48,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,33,225,196,222,2,0,32,0,109,104,45,99,45,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,30,21,170,122,2,0,32,0,109,104,45,99,45,50,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,116,222,224,234,2,0,32,0,109,104,45,99,45,51,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,47,5,213,1,2,0,32,0,109,104,45,98,45,97,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,86,178,13,106,3,0,32,0,109,104,45,98,45,97,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,149,151,236,20,3,0,32,0,109,104,45,98,45,97,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,14,81,203,223,3,0,32,0,109,104,45,98,45,97,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,155,50,126,149,3,0,32,0,98,45,98,48,45,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,118,87,185,181,4,0,32,0,98,45,98,49,45,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,238,22,202,116,4,0,32,0,98,45,98,50,45,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,4,202,44,184,4,0,32,0,98,45,98,51,45,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,32,201,175,167,4,0,32,0,99,45,118,48,45,98,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,88,126,194,208,5,0,64,0,109,114,104,101,108,105,95,105,56,55,53,49,46,109,99,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,24,99,112,117,95,100,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,124,33,134,210,1,0,16,1,99,112,117,95,100,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,188,148,207,149,1,0,16,1,99,112,117,95,100,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,126,167,108,70,1,0,16,1,99,112,117,95,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,214,119,20,114,1,0,16,1,99,112,117,95,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,228,1,91,245,1,0,16,1,99,112,117,95,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,170,96,245,121,1,0,16,1,105,111,95,97,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,238,195,32,122,2,0,16,1,105,111,95,99,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,200,224,38,141,2,0,16,1,105,111,95,100,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,192,175,217,171,2,0,16,1,118,100,95,108,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,249,173,178,72,3,0,32,0,118,100,95,108,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,192,104,241,47,3,0,32,0,118,100,95,108,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,202,88,1,16,3,0,32,0,118,100,95,108,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,119,21,80,52,3,0,32,0,118,100,95,106,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,195,184,41,63,3,0,32,0,118,100,95,106,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,234,11,56,57,3,0,32,0,118,100,95,106,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,14,17,75,43,3,0,32,0,118,100,95,106,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,30,139,60,58,3,0,32,0,118,100,95,107,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,167,227,64,117,4,0,32,0,118,100,95,107,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,25,130,104,108,4,0,32,0,118,100,95,107,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,60,111,233,21,4,0,32,0,118,100,95,107,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,223,0,81,254,4,0,32,0,118,100,95,108,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,86,208,227,209,4,0,32,0,118,100,95,108,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,37,185,127,77,4,0,32,0,118,100,95,108,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,138,88,129,109,4,0,32,0,118,100,95,108,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,165,53,55,66,4,0,32,0,109,111,109,111,107,111,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,237,38,110,56,1,0,16,1,109,111,109,111,107,111,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,81,227,85,66,1,0,16,1,109,111,109,111,107,111,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,60,103,166,232,2,0,16,1,109,111,109,111,107,111,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,90,207,69,39,3,0,32,0,109,111,109,111,107,111,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,5,202,204,207,4,0,32,0,109,111,109,111,107,111,49,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,252,118,104,252,5,0,32,0,109,111,109,111,107,111,49,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,71,2,220,69,5,0,32,0,109,111,109,111,107,111,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,199,71,88,159,6,0,32,0,109,111,109,111,107,111,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,67,189,159,156,6,0,32,0,109,111,109,111,107,111,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,75,231,23,174,6,0,32,0,109,111,109,111,107,111,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,196,201,41,30,6,0,32,0,109,111,109,111,107,111,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,195,194,179,58,7,0,32,0,109,111,109,111,107,111,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,43,221,124,117,7,0,32,0,109,111,109,111,107,111,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,139,207,202,32,7,0,32,0,109,111,109,111,107,111,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,219,56,75,185,7,0,32,0,109,111,109,111,107,111,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,2,23,180,105,8,0,32,0,109,111,109,111,107,111,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,6,248,40,128,9,0,32,0,109,111,109,111,107,111,45,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,224,202,92,243,10,0,32,0,109,111,109,111,107,111,45,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,92,14,123,66,10,0,32,0,103,120,49,52,49,46,53,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,13,18,230,152,1,0,16,1,103,120,49,52,49,46,55,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,95,93,28,178,2,0,32,0,121,115,32,105,105,105,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,110,151,39,234,33,0,16,0,120,100,114,32,45,32,120,32,100,97,122,101,100,108,121,32,114,97,121,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,2,208,34,171,33,0,16,0,119,111,114,108,100,32,115,101,114,105,101,115,32,98,97,115,101,98,97,108,108,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,236,213,193,87,33,0,16,0,119,111,114,108,100,32,104,101,114,111,101,115,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,255,206,227,86,33,0,16,0,109,112,114,45,49,50,54,48,55,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,203,43,39,191,33,0,16,0,109,112,114,45,49,57,49,48,55,43,109,112,114,45,49,57,49,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,243,128,115,147,33,0,16,0,109,112,114,45,49,53,50,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,91,192,227,231,33,0,16,0,116,104,117,110,100,101,114,32,102,111,114,99,101,32,105,105,105,32,40,117,115,97,44,32,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,154,57,63,27,33,0,16,0,109,112,114,45,49,50,53,53,57,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,179,97,21,155,33,0,16,0,116,101,115,116,32,100,114,105,118,101,32,105,105,32,45,32,116,104,101,32,100,117,101,108,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,197,248,189,249,33,0,16,0,109,112,114,45,49,52,49,50,53,97,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,69,232,82,64,33,0,16,0,115,117,112,101,114,32,109,97,114,105,111,32,98,114,111,115,46,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,216,43,250,156,33,0,16,0,109,112,114,45,49,53,57,49,48,43,109,112,114,45,49,53,57,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,54,17,212,86,33,0,16,0,112,97,99,105,102,105,99,32,116,104,101,97,116,101,114,32,111,102,32,111,112,101,114,97,116,105,111,110,115,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,226,198,212,217,33,0,16,0,112,103,97,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,225,180,240,193,33,0,16,0,112,114,111,32,97,99,116,105,111,110,32,114,101,112,108,97,121,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,36,82,37,23,33,0,16,0,110,104,108,32,104,111,99,107,101,121,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,63,101,65,38,33,0,16,0,109,97,103,105,99,32,115,99,104,111,111,108,32,98,117,115,44,32,116,104,101,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,18,68,93,26,33,0,16,0,115,50,49,53,95,118,101,114,95,49,46,48,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,7,162,163,26,33,0,16,0,109,107,32,53,32,45,32,109,111,114,116,97,108,32,99,111,109,98,97,116,32,45,32,115,117,98,122,101,114,111,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,161,103,227,17,33,0,16,0,109,111,114,116,97,108,95,107,111,109,98,97,116,95,51,95,112,97,108,46,98,105,110,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,232,227,109,175,33,0,16,0,115,51,55,54,45,117,50,46,49,43,115,51,56,50,45,117,49,46,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,216,19,224,169,33,0,16,0,109,101,116,97,108,32,103,101,97,114,32,115,111,108,105,100,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,235,145,129,179,33,0,16,0,108,104,120,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,141,66,195,112,33,0,16,0,108,101,116,104,97,108,32,101,110,102,111,114,99,101,114,115,32,105,105,32,45,32,103,117,110,32,102,105,103,104,116,101,114,115,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,92,4,254,75,33,0,16,0,103,114,97,110,32,116,117,114,105,115,109,111,32,53,32,40,117,110,108,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,160,18,0,129,33,57,212,33,0,16,0,109,112,114,45,49,54,50,49,49,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,129,193,120,151,33,0,16,0,102,45,50,50,32,105,110,116,101,114,99,101,112,116,111,114,32,40,101,117,114,111,44,32,117,115,97,41,32,40,106,117,110,101,32,49,57,57,50,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,179,178,25,221,33,0,16,0,100,114,97,103,111,110,32,98,97,108,108,32,122,32,45,32,98,117,121,117,117,32,114,101,116,115,117,100,101,110,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,113,51,143,175,33,0,16,0,98,46,111,46,98,46,32,40,101,117,114,111,44,32,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,183,172,162,234,33,0,16,0,98,97,114,101,32,107,110,117,99,107,108,101,32,105,105,105,32,40,106,112,110,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,0,111,35,9,93,33,0,16,0,97,114,116,32,111,102,32,102,105,103,104,116,105,110,103,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,34,196,112,153,33,0,16,0,109,98,114,117,115,104,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,247,191,15,117,1,0,16,1,109,98,114,117,115,104,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,153,66,235,39,1,0,16,1,109,98,114,117,115,104,46,54,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,142,16,151,210,1,0,16,1,109,98,114,117,115,104,46,54,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,208,25,215,111,1,0,16,1,116,112,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,152,113,97,199,2,0,32,0,109,98,114,117,115,104,46,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,103,105,91,193,2,0,32,0,109,98,114,117,115,104,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,184,92,188,213,2,0,32,0,116,112,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,175,28,93,211,2,0,32,0,56,50,115,49,50,51,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,189,80,198,47,3,0,32,0,50,115,49,52,48,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,39,185,239,99,3,0,32,0,56,50,115,49,50,54,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,134,204,169,4,0,64,0,56,50,115,49,50,54,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,14,0,0,0,255,255,57,0,0,0,0,0,15,0,0,0,255,255,239,0,0,0,0,0,16,0,0,0,255,255,111,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,15,0,0,0,1,16,0,0,120,97,1,0,15,0,0,0,1,16,16,0,96,19,1,0,0,0,0,0,254,0,4,0,32,4,2,0,14,0,0,0,1,3,3,0,160,36,8,0,14,0,0,0,1,3,1,0,208,239,7,0,14,0,0,0,1,3,2,0,120,187,7,0,14,0,0,0,1,3,0,0,16,227,4,0,0,0,0,0,254,0,4,0,128,129,4,0,14,0,0,0,1,12,0,0,192,255,2,0,14,0,0,0,1,12,4,0,208,75,4,0,14,0,0,0,1,12,8,0,8,49,4,0,14,0,0,0,1,12,12,0,152,21,4,0,50,54,54,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,199,45,76,93,1,0,16,1,50,54,54,45,112,50,46,115,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,6,25,75,161,1,0,16,1,50,54,54,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,48,78,95,80,3,0,32,0,50,54,54,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,130,116,181,60,3,0,32,0,50,54,54,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,208,106,204,241,3,0,32,0,50,54,54,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,183,6,184,69,3,0,32,0,50,54,54,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,107,221,21,154,3,0,32,0,50,54,54,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,57,185,28,40,3,0,32,0,50,54,54,45,99,55,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,128,247,113,75,3,0,32,0,50,54,54,45,99,56,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,51,61,135,41,3,0,32,0,50,54,54,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,108,62,108,69,4,0,16,1,50,54,54,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,144,54,248,164,5,0,64,0,50,54,54,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,218,158,246,208,5,0,64,0,54,99,95,108,119,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,96,127,90,181,1,0,16,1,55,99,95,108,119,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,27,187,239,165,1,0,16,1,57,99,95,108,119,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,1,194,92,236,1,0,16,1,49,49,101,95,108,119,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,162,55,3,162,2,0,16,1,57,104,95,108,119,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,60,146,29,9,4,0,32,0,51,101,95,108,119,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,44,57,54,84,5,0,32,0,49,101,95,108,119,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,187,187,145,180,5,0,32,0,51,100,95,108,119,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,138,144,209,253,5,0,32,0,49,100,95,108,119,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,6,212,115,92,5,0,32,0,51,98,95,108,119,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,60,123,225,50,5,0,32,0,49,98,95,108,119,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,193,51,229,82,5,0,32,0,51,102,95,108,119,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,186,52,225,153,5,0,32,0,49,102,95,108,119,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,119,135,242,200,5,0,32,0,51,106,95,108,119,49,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,155,188,209,94,6,0,32,0,49,106,95,108,119,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,214,144,7,42,6,0,32,0,51,104,95,108,119,49,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,6,64,131,232,6,0,32,0,49,104,95,108,119,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,165,245,147,182,6,0,32,0,54,51,115,49,52,49,46,49,53,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,152,204,107,217,0,0,0,8,110,110,112,45,112,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,5,107,63,53,1,0,16,1,110,110,112,45,115,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,183,216,36,130,2,0,32,0,110,110,112,45,99,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,152,113,96,139,3,0,32,0,110,110,112,45,99,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,156,181,150,107,3,0,32,0,110,110,112,45,109,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,82,253,71,104,4,0,16,1,110,110,112,45,118,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,231,194,41,3,5,0,64,0,108,111,104,116,45,97,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,84,14,201,204,1,0,16,1,108,111,104,116,45,97,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,48,103,160,58,1,0,16,1,108,111,104,116,45,97,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,222,152,138,255,1,0,16,1,108,111,104,116,45,97,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,188,215,177,234,1,0,16,1,108,111,104,116,45,97,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,236,7,224,121,1,0,16,1,108,111,104,116,45,97,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,110,52,81,185,1,0,16,1,108,111,104,116,45,97,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,213,164,78,37,1,0,16,1,108,111,104,116,45,97,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,13,57,176,207,1,0,16,1,108,111,104,116,45,97,49,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,238,197,90,223,2,0,32,0,108,111,104,116,45,97,49,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,73,248,236,215,2,0,32,0,108,111,104,116,45,97,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,11,34,69,2,0,32,0,108,111,104,116,45,97,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,60,187,249,74,2,0,32,0,108,111,104,116,45,97,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,252,92,184,37,2,0,32,0,108,111,104,116,45,97,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,121,133,77,70,2,0,32,0,108,111,104,116,45,97,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,236,164,63,118,2,0,32,0,108,111,104,116,45,97,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,199,104,53,167,2,0,32,0,108,111,104,116,45,97,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,113,231,163,60,3,0,32,0,108,111,104,116,45,97,50,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,47,238,5,122,3,0,32,0,108,111,104,116,45,97,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,53,35,170,121,3,0,32,0,108,111,104,116,45,97,50,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,36,139,158,120,3,0,32,0,108,111,104,116,45,97,50,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,246,107,98,68,4,0,32,0,108,111,104,116,45,97,50,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,207,82,73,70,4,0,32,0,108,111,104,116,45,97,50,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,199,178,185,61,4,0,32,0,108,111,104,116,45,97,50,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,153,232,31,240,4,0,32,0,108,111,104,116,45,97,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,31,29,213,62,5,0,64,0,108,111,104,116,45,97,50,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,23,30,144,172,0,0,0,8,97,53,52,45,48,49,45,49,46,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,197,169,61,151,1,0,16,1,97,53,52,45,48,50,45,49,46,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,218,9,181,39,1,0,16,1,97,53,52,45,48,52,46,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,154,175,31,84,2,0,16,1])
.concat([97,53,52,45,48,51,46,53,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,216,118,62,73,3,0,16,1,97,53,52,45,48,53,45,49,46,56,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,106,192,51,0,4,0,32,0,97,53,52,45,48,54,45,49,46,56,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,173,217,4,159,4,0,32,0,97,53,52,45,48,55,45,49,46,56,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,164,97,5,178,4,0,32,0,97,53,52,45,48,56,45,49,46,56,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,48,178,243,63,4,0,32,0,97,53,52,45,49,48,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,20,189,223,23,5,0,0,8,97,53,52,45,48,57,46,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,70,136,139,14,6,0,16,8,112,97,108,49,54,108,56,45,97,53,52,45,49,49,46,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,19,33,35,86,7,0,0,8,112,97,108,49,54,108,56,45,97,53,52,45,49,50,46,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,137,60,124,229,7,0,0,8,112,97,108,49,54,108,56,97,45,97,53,52,45,49,51,46,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,142,147,177,201,7,0,0,8,112,97,108,49,54,108,56,97,45,97,53,52,45,49,52,46,51,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,78,100,156,168,7,0,0,8,105,99,51,55,95,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,123,79,105,5,1,0,16,1,105,99,51,56,95,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,158,226,239,34,1,0,16,1,97,53,52,45,48,52,46,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,154,175,31,84,2,0,16,1,97,53,52,45,48,51,46,53,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,216,118,62,73,3,0,16,1,105,99,57,51,95,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,82,62,117,118,4,0,32,0,105,99,57,52,95,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,92,1,60,243,4,0,32,0,105,99,57,53,95,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,232,194,2,14,4,0,32,0,105,99,57,54,95,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,115,240,245,78,4,0,32,0,97,53,52,45,49,48,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,20,189,223,23,5,0,0,8,54,101,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,144,25,188,50,1,0,16,1,54,102,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,20,180,36,239,1,0,16,1,54,104,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,61,216,190,48,1,0,16,1,54,106,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,235,186,9,221,1,0,16,1,119,105,122,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,166,163,222,246,1,0,16,1,119,105,122,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,168,181,127,242,1,0,16,1,53,101,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,115,158,5,69,2,0,32,0,53,102,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,23,151,70,210,2,0,32,0,55,102,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,71,169,73,117,3,0,32,0,52,97,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,54,165,220,95,3,0,32,0,56,50,115,49,50,54,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,134,204,169,4,0,64,0,56,50,115,49,50,54,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,17,0,0,0,255,255,251,0,0,0,0,0,18,0,0,0,255,255,255,0,0,0,0,0,19,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,32,4,2,0,17,0,0,0,1,3,1,0,160,36,8,0,17,0,0,0,1,3,3,0,208,239,7,0,17,0,0,0,1,3,2,0,120,187,7,0,17,0,0,0,1,3,0,0,16,227,4,0,0,0,0,0,254,0,4,0,128,129,4,0,17,0,0,0,1,12,0,0,72,246,3,0,17,0,0,0,1,12,4,0,152,21,4,0,17,0,0,0,1,12,8,0,8,49,4,0,17,0,0,0,1,12,12,0,208,75,4,0,0,0,0,0,254,0,4,0,64,37,5,0,17,0,0,0,1,48,0,0,200,205,3,0,17,0,0,0,1,48,16,0,160,191,4,0,17,0,0,0,1,48,32,0,32,202,3,0,17,0,0,0,1,48,48,0,24,145,2,0,0,0,0,0,254,0,2,0,72,202,5,0,17,0,0,0,1,64,64,0,248,38,7,0,17,0,0,0,1,64,0,0,112,212,3,0,0,0,0,0,0,0,8,16,0,3,1,87,1,0,16,0,0,0,8,16,0,3,1,87,1,0,43,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,9,0,0,3,1,74,4,0,32,0,0,7,8,18,0,3,1,93,4,0,48,0,0,7,9,2,0,3,1,76,4,0,56,0,0,7,9,3,0,3,1,77,4,0,72,0,0,9,8,17,0,3,1,90,5,192,24,0,0,9,9,1,0,3,1,75,5,192,40,0,0,0,11,0,0,0,0,0,24,0,0,0,0,0,11,0,0,0,0,0,24,0,0,0,0,0,11,0,0,0,0,0,24,0,0,0,0,0,11,0,0,0,0,0,24,0,0,0,0,0,11,0,0,0,0,0,24,0,0,0,0,0,11,0,0,0,0,0,24,0,0,0,0,0,11,0,0,0,0,0,24,0,0,0,0,0,11,0,0,0,0,0,24,0,0,0,0,0,11,0,0,0,0,0,24,0,0,0,128,9,76,219,0,0,2,50,6,0,4,0,128,11,9,6,0,3,1,78,6,80,2,128,128,11,9,6,0,3,1,78,6,80,3,128,128,11,9,6,0,3,1,78,6,80,4,128,128,11,9,6,0,3,1,78,6,80,8,0,128,11,9,6,0,3,1,78,6,80,16,0,128,11,9,6,0,3,1,78,6,80,18,0,128,11,9,6,0,3,1,78,6,80,20,0,128,11,9,6,0,3,1,78,6,80,22,0,128,11,9,6,0,3,1,78,6,80,24,0,128,11,9,6,0,3,1,78,6,80,32,0,128,11,9,6,0,3,1,78,6,80,35,0,128,11,9,6,0,3,1,78,6,80,48,0,128,11,9,6,0,3,1,78,6,80,56,0,128,11,9,6,0,3,1,78,6,80,64,0,128,11,9,6,0,3,1,78,6,80,66,0,128,4,8,16,0,3,1,87,1,0,16,0,128,4,8,16,0,3,1,87,1,0,43,0,128,7,9,0,0,3,1,74,4,0,32,0,128,7,8,18,0,3,1,93,4,0,48,0,128,7,9,2,0,3,1,76,4,0,56,0,128,7,9,3,0,3,1,77,4,0,72,0,128,9,8,17,0,3,1,90,5,192,24,0,128,9,9,1,0,3,1,75,5,192,40,0,128,11,10,2,0,0,1,100,6,128,4,0,128,12,11,1,0,0,1,242,6,128,2,128,128,11,10,2,0,0,1,100,6,128,23,0,128,12,11,1,0,0,1,242,6,128,21,128,128,11,10,2,0,0,1,100,7,0,52,0,128,12,11,1,0,0,1,242,7,0,50,128,128,11,10,2,0,0,1,100,6,128,62,128,128,12,11,1,0,0,1,242,6,128,61,128,128,11,10,16,0,0,1,96,7,0,8,0,128,11,10,16,0,0,1,96,7,0,11,0,128,11,10,16,0,0,1,96,7,0,27,0,128,11,10,16,0,0,1,96,7,0,30,0,128,11,10,16,0,0,1,96,7,128,56,0,128,11,10,16,0,0,1,96,7,128,59,0,128,11,10,16,0,0,1,96,7,0,66,128,128,11,10,16,0,0,1,96,7,0,69,128,128,12,11,0,0,0,1,241,11,128,7,128,128,12,11,0,0,0,1,241,11,128,26,128,128,12,11,0,0,0,1,241,12,0,55,128,128,12,11,0,0,0,1,241,11,128,66,0,128,12,75,208,0,0,1,243,6,128,9,128,128,12,75,208,0,0,1,243,6,128,28,128,128,12,75,208,0,0,1,243,6,128,68,0,128,12,11,3,0,0,1,244,8,0,40,0,128,12,11,3,0,0,1,244,8,0,75,128,0,12,11,4,0,0,1,245,8,0,38,128,128,7,9,2,0,3,1,76,4,0,16,0,128,7,9,2,0,3,1,76,4,64,32,0,128,7,9,3,0,3,1,77,3,224,48,0,128,7,9,3,0,3,1,77,3,128,64,0,128,7,9,2,0,3,1,76,4,128,24,0,128,7,9,3,0,3,1,77,3,192,40,0,128,7,11,0,0,3,1,86,4,128,8,0,128,7,11,0,0,3,1,86,4,128,56,0,128,7,11,0,0,3,1,85,4,128,72,0,128,9,9,5,0,15,1,15,5,64,7,64,128,9,9,5,0,15,1,15,5,64,55,64,128,11,10,3,0,0,2,19,6,128,64,0,128,11,10,17,0,0,2,21,8,128,72,128,128,11,10,17,0,0,2,21,8,128,73,128,128,11,11,0,0,0,1,246,7,0,3,128,128,11,11,0,0,0,1,247,7,0,5,0,128,11,11,0,0,0,1,249,7,0,8,128,128,11,11,0,0,0,1,249,7,0,16,0,128,11,11,0,0,0,1,250,7,0,19,128,128,11,11,0,0,0,1,248,11,128,11,128,128,11,11,0,0,0,2,0,11,128,26,128,128,11,11,0,0,0,1,249,7,0,23,128,128,11,11,0,0,0,1,250,7,0,27,0,128,11,11,0,0,0,1,248,11,128,19,0,128,11,11,0,0,0,2,66,11,128,22,0,128,11,11,0,0,0,1,251,7,128,32,128,128,11,11,0,0,0,1,246,7,0,35,128,128,11,11,0,0,0,2,66,11,128,14,128,128,11,11,0,0,0,2,67,11,128,29,128,128,11,11,0,0,0,1,247,7,0,37,0,128,11,11,0,0,0,1,253,6,128,63,0,128,11,11,0,0,0,1,254,7,0,70,0,128,11,11,0,0,0,1,255,7,128,73,128,128,11,11,0,0,0,1,252,9,128,66,0,128,4,11,0,0,3,1,69,1,0,24,0,128,4,11,0,0,3,1,69,1,32,43,0,128,7,12,1,0,3,1,70,4,0,13,0,128,7,12,0,0,5,1,123,11,128,32,0,128,7,12,1,0,3,1,70,4,32,32,0,128,7,12,1,0,3,1,70,3,128,51,0,128,7,12,1,0,3,1,70,4,0,60,0,128,7,12,1,0,3,1,70,3,208,69,0,128,7,12,0,0,5,1,123,11,144,65,0,128,7,12,1,0,3,1,70,4,48,65,0,128,11,12,2,0,3,1,72,7,0,0,0,128,11,10,65,0,0,2,43,6,224,73,64,128,11,12,2,0,3,1,72,7,128,11,0,128,11,11,0,0,0,2,39,10,128,5,128,128,11,11,0,0,0,2,30,8,0,14,128,128,11,11,0,0,0,2,31,7,128,17,0,128,11,11,0,0,0,2,40,11,0,18,0,128,11,11,0,0,0,2,32,7,0,21,128,128,11,11,0,0,0,2,33,7,0,27,128,128,11,11,0,0,0,2,41,10,128,26,0,128,11,11,0,0,0,2,34,7,128,30,0,128,11,11,0,0,0,2,30,8,0,37,0,128,11,11,0,0,0,2,35,7,128,44,128,128,11,11,0,0,0,2,40,11,0,40,128,128,11,12,2,0,3,1,72,7,0,48,0,128,11,10,64,0,0,2,46,7,64,45,0,128,11,11,0,0,0,2,39,10,128,53,128,128,11,12,2,0,3,1,72,7,128,34,0,128,11,11,0,0,0,2,36,7,128,71,0,128,11,11,0,0,0,2,42,10,128,75,0,128,11,11,0,0,0,2,37,7,0,75,128,128,11,11,0,0,0,2,38,7,0,78,0,128,11,12,2,0,3,1,72,7,0,67,128,128,11,12,2,0,3,1,72,7,128,61,128,128,4,11,0,0,3,1,69,1,0,24,0,128,4,11,0,0,3,1,69,1,32,48,0,128,7,8,18,0,3,1,93,4,0,16,0,128,7,8,18,0,3,1,93,4,32,28,0,128,7,8,18,0,3,1,93,3,224,38,0,128,7,8,18,0,3,1,93,3,128,52,0,128,7,8,18,0,3,1,93,4,48,64,0,128,7,12,1,0,3,1,70,4,64,34,0,128,7,12,1,0,3,1,70,4,96,66,0,128,7,12,0,0,5,1,123,11,128,8,0,128,7,12,1,0,3,1,70,4,32,8,0,0,0,0,0,0,0,1,240,0,0,0,0,0,0,0,0,0,0,1,240,0,0,0,0,0,0,0,0,0,0,1,240,0,0,0,0,128,11,11,0,0,0,2,25,11,0,4,0,128,11,11,0,0,0,2,26,9,0,3,128,128,11,11,0,0,0,2,25,11,0,12,0,128,11,11,0,0,0,2,26,9,0,11,128,128,11,11,0,0,0,2,25,11,0,28,0,128,11,11,0,0,0,2,26,9,0,27,128,128,11,11,0,0,0,2,25,11,0,44,0,128,11,11,0,0,0,2,26,9,0,43,128,128,11,11,0,0,0,2,25,11,0,68,0,128,11,11,0,0,0,2,26,9,0,67,128,128,11,11,0,0,0,2,25,11,0,76,0,128,11,11,0,0,0,2,26,9,0,75,128,128,11,12,2,0,3,1,72,9,160,16,0,128,11,12,2,0,3,1,72,9,160,40,0,128,11,12,2,0,3,1,72,9,160,54,0,0,0,0,0,0,0,1,240,0,0,0,0,0,0,0,0,0,0,1,240,0,0,0,0,0,0,0,0,0,0,1,240,0,0,0,0,0,0,0,0,0,0,1,240,0,0,0,0,0,0,0,0,0,0,1,240,0,0,0,0,128,7,9,2,0,3,1,76,4,0,16,0,128,7,9,2,0,3,1,76,4,64,32,0,128,7,9,3,0,3,1,77,3,224,48,0,128,7,9,3,0,3,1,77,3,128,64,0,128,7,9,2,0,3,1,76,4,128,24,0,128,7,9,3,0,3,1,77,3,192,40,0,128,11,11,0,0,0,2,11,9,128,41,0,128,11,9,4,0,0,2,15,8,128,40,128,128,11,10,4,0,0,2,53,10,0,40,128,128,11,10,5,0,0,2,16,6,128,40,128,128,11,10,18,0,0,2,54,8,0,77,0,128,11,10,18,0,0,2,54,8,0,79,0,128,11,10,18,0,0,2,54,8,0,1,0,128,11,10,18,0,0,2,54,8,0,3,0,128,11,10,19,0,0,2,58,7,0,35,0,128,11,10,19,0,0,2,58,7,0,37,128,128,11,10,19,0,0,2,58,9,128,35,0,128,11,10,19,0,0,2,58,9,128,37,128,128,11,10,20,0,0,2,62,7,0,13,0,128,11,10,20,0,0,2,62,7,0,15,128,128,11,11,0,0,0,2,1,7,0,78,128,128,11,75,210,0,0,2,3,7,0,14,0,128,11,11,0,0,0,2,4,6,128,32,0,128,11,75,211,0,0,2,5,6,128,36,0,128,11,11,0,0,0,2,6,9,128,1,0,128,11,75,212,0,0,2,7,11,128,11,128,128,11,75,213,0,0,2,8,11,128,14,0,128,11,11,0,0,0,2,9,11,128,16,0,128,11,11,0,0,0,2,10,9,0,36,0,128,11,75,214,0,0,2,12,12,0,33,128,128,11,11,0,0,0,2,13,12,0,37,0,128,11,11,0,0,0,2,14,9,128,78,0,128,11,9,6,0,3,1,78,6,128,18,128,128,11,9,6,0,3,1,78,7,0,7,128,128,4,8,16,0,3,1,87,1,0,16,0,128,4,8,16,0,3,1,87,1,0,43,0,128,7,9,0,0,3,1,74,4,0,32,0,128,7,8,18,0,3,1,93,4,0,48,0,128,7,9,2,0,3,1,76,4,0,56,0,128,7,9,3,0,3,1,77,4,0,72,0,128,9,8,17,0,3,1,90,5,192,24,0,128,9,9,1,0,3,1,75,5,192,40,0,128,11,10,2,0,0,1,100,6,128,4,0,128,12,11,1,0,0,1,242,6,128,2,128,128,11,10,2,0,0,1,100,6,128,23,0,128,12,11,1,0,0,1,242,6,128,21,128,128,11,10,2,0,0,1,100,7,0,52,0,128,12,11,1,0,0,1,242,7,0,50,128,128,11,10,2,0,0,1,100,6,128,62,128,128,12,11,1,0,0,1,242,6,128,61,128,128,11,10,16,0,0,1,96,7,0,8,0,128,11,10,16,0,0,1,96,7,0,11,0,128,11,10,16,0,0,1,96,7,0,27,0,128,11,10,16,0,0,1,96,7,0,30,0,128,11,10,16,0,0,1,96,7,128,56,0,128,11,10,16,0,0,1,96,7,128,59,0,128,11,10,16,0,0,1,96,7,0,66,128,128,11,10,16,0,0,1,96,7,0,69,128,128,12,11,0,0,0,1,241,11,128,7,128,128,12,11,0,0,0,1,241,11,128,26,128,128,12,11,0,0,0,1,241,12,0,55,128,128,12,11,0,0,0,1,241,11,128,66,0,128,12,75,208,0,0,1,243,6,128,9,128,128,12,75,208,0,0,1,243,6,128,28,128,128,12,75,208,0,0,1,243,6,128,68,0,128,12,11,3,0,0,1,244,8,0,40,0,128,12,11,3,0,0,1,244,8,0,75,128,0,12,11,4,0,0,1,245,8,0,38,128,108,103,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,53,73,126,119,1,0,16,1,108,103,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,36,183,174,196,1,0,16,1,108,101,103,105,111,110,46,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,30,94,228,194,1,0,16,1,108,101,103,105,111,110,46,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,10,102,6,195,1,0,16,1,108,101,103,105,111,110,46,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,240,247,164,44,2,0,16,1,108,103,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,112,101,89,224,3,0,32,0,108,101,103,105,111,110,46,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,175,15,215,169,4,0,32,0,108,101,103,105,111,110,46,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,59,49,24,240,4,0,32,0,108,101,103,105,111,110,46,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,170,173,184,41,5,0,32,0,108,101,103,105,111,110,46,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,185,13,90,255,6,0,32,0,108,101,103,105,111,110,46,49,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,200,32,226,186,6,0,32,0,108,103,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,88,43,62,83,7,0,32,8,108,101,103,105,111,110,46,49,105,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,39,168,244,121,2,0,0,8,0,0,0,0,0,0,0,0,107,111,122,117,114,101,56,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,230,177,191,107,1,0,16,1,107,111,122,117,114,101,51,46,54,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,200,142,23,249,1,0,16,1,107,111,122,117,114,101,55,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,187,9,238,167,1,0,16,1,107,111,122,117,114,101,50,46,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,15,130,109,35,1,0,16,1,107,111,122,117,114,101,54,46,51,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,40,231,32,145,1,0,16,1,107,111,122,117,114,101,49,46,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,165,231,95,52,1,0,16,1,107,111,122,117,114,101,49,49,46,49,55,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,45,30,165,219,2,0,16,1,107,111,122,117,114,101,57,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,110,53,65,224,3,0,32,0,107,111,122,117,114,101,53,46,49,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,88,2,81,11,4,0,32,0,107,111,122,117,114,101,52,46,49,52,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,230,19,142,251,4,0,32,0,107,111,122,117,114,101,49,52,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,208,195,169,148,5,0,32,0,107,111,122,117,114,101,49,50,46,56,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,29,2,244,21,6,0,32,0,107,111,122,117,114,101,49,51,46,57,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,83,199,182,179,6,0,32,0,107,111,122,117,114,101,49,48,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,29,226,139,244,7,0,32,8,110,56,50,115,49,50,57,97,110,46,49,49,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,87,71,36,129,8,0,0,8,112,48,54,48,48,104,95,49,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,25,154,216,225,1,0,16,1,116,48,54,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,214,26,204,74,2,0,32,0,97,48,54,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,52,120,22,216,3,0,32,0,97,48,54,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,115,67,122,255,3,0,32,0,97,48,54,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,89,41,163,231,3,0,32,0,97,48,53,52,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,62,65,211,79,3,0,32,0,98,48,54,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,89,208,60,125,4,0,32,0,98,48,53,52,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,87,151,153,96,4,0,32,0,109,48,54,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,214,79,218,58,5,0,64,0,107,111,118,115,104,95,118,49,48,48,95,99,104,105,110,97,46,97,115,105,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,193,165,9,15,7,0,16,1,117,48,55,48,54,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,52,91,199,87,1,0,16,1,116,48,54,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,214,26,204,74,2,0,32,0,97,48,54,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,52,120,22,216,3,0,32,0,97,48,54,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,115,67,122,255,3,0,32,0,97,48,54,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,89,41,163,231,3,0,32,0,97,48,54,48,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,218,171,49,236,3,0,32,0,97,48,54,48,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,211,159,181,38,3,0,32,0,98,48,54,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,89,208,60,125,4,0,32,0,98,48,54,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,47,28,187,160,4,0,32,0,98,48,54,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,52,121,247,157,4,0,32,0,109,48,54,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,214,79,218,58,5,0,64,0,107,111,118,115,104,95,118,49,48,48,95,99,104,105,110,97,46,97,115,105,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,193,165,9,15,7,0,16,1,112,48,54,48,48,46,49,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,36,41,122,82,1,0,16,1,116,48,54,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,214,26,204,74,2,0,32,0,97,48,54,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,52,120,22,216,3,0,32,0,97,48,54,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,115,67,122,255,3,0,32,0,97,48,54,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,89,41,163,231,3,0,32,0,97,48,54,48,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,218,171,49,236,3,0,32,0,98,48,54,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,89,208,60,125,4,0,32,0,98,48,54,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,47,28,187,160,4,0,32,0,109,48,54,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,214,79,218,58,5,0,64,0,107,111,118,95,105,103,115,48,50,55,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,7,0,16,17,115,97,118,49,49,49,46,117,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,78,27,47,174,1,0,16,1,115,97,118,49,49,49,46,117,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,14,223,238,149,1,0,16,1,115,97,118,49,49,49,46,117,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,74,221,95,1,0,16,1,115,97,118,49,49,49,46,117,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,73,191,60,0,1,0,16,1,115,97,118,49,49,49,46,117,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,7,97,83,213,1,0,16,1,116,48,54,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,214,26,204,74,2,0,32,0,97,48,54,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,52,120,22,216,3,0,32,0,97,48,54,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,115,67,122,255,3,0,32,0,97,48,54,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,89,41,163,231,3,0,32,0,97,48,54,48,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,218,171,49,236,3,0,32,0,98,48,54,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,89,208,60,125,4,0,32,0,98,48,54,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,47,28,187,160,4,0,32,0,109,48,54,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,214,79,218,58,5,0,64,0,107,111,118,95,105,103,115,48,50,55,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,7,0,16,17,112,114,111,116,111,95,48,51,57,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,231,23,29,60,1,0,16,1,112,114,111,116,111,95,48,51,57,45,112,50,46,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,240,145,150,188,1,0,16,1,48,51,57,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,58,5,238,99,2,0,32,0,112,114,111,116,111,95,48,51,57,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,135,167,146,113,3,0,32,0,112,114,111,116,111,95,48,51,57,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,161,236,87,113,3,0,32,0,112,114,111,116,111,95,48,51,57,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,39,87,215,17,3,0,32,0,112,114,111,116,111,95,48,51,57,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,40,139,212,122,3,0,32,0,112,114,111,116,111,95,48,51,57,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,202,249,218,91,3,0,32,0,112,114,111,116,111,95,48,51,57,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,140,190,212,33,3,0,32,0,112,114,111,116,111,95,48,51,57,45,99,55,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,253,85,218,3,0,32,0,112,114,111,116,111,95,48,51,57,45,99,56,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,103,146,46,89,3,0,32,0,48,51,57,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,213,42,91,12,4,0,16,1,112,114,111,116,111,95,48,51,57,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,241,102,53,221,5,0,64,0,112,114,111,116,111,95,48,51,57,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,116,2,246,87,5,0,64,0,112,114,111,116,111,95,48,51,57,45,118,51,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,7,138,0,15,5,0,64,0,112,114,111,116,111,95,48,51,57,45,118,52,46,118,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,254,208,67,25,5,0,64,0,112,114,111,116,111,95,48,51,57,45,118,53,46,118,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,91,4,190,19,5,0,64,0,112,114,111,116,111,95,48,51,57,45,118,54,46,118,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,214,63,221,209,5,0,64,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,222,34,0,0,8,30,0,0,98,0,0,0,98,0,0,0,90,24,0,0,240,1,0,0,98,0,0,0,98,0,0,0,6,4,0,0,26,30,0,0,98,0,0,0,98,0,0,0,38,42,0,0,252,21,0,0,98,0,0,0,98,0,0,0,226,5,0,0,214,11,0,0,98,0,0,0,98,0,0,0,248,22,0,0,218,49,0,0,98,0,0,0,98,0,0,0,152,21,0,0,142,32,0,0,98,0,0,0,98,0,0,0,188,0,0,0,38,21,0,0,98,0,0,0,98,0,0,0,2,19,0,0,82,22,0,0,98,0,0,0,98,0,0,0,40,31,0,0,112,34,0,0,98,0,0,0,144,48,0,0,126,30,0,0,76,11,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,86,8,0,0,98,0,0,0,72,31,0,0,98,0,0,0,160,41,0,0,98,0,0,0,92,13,0,0,98,0,0,0,6,2,0,0,98,0,0,0,80,12,0,0,98,0,0,0,154,5,0,0,98,0,0,0,102,4,0,0,98,0,0,0,44,11,0,0,98,0,0,0,122,41,0,0,98,0,0,0,248,14,0,0,98,0,0,0,78,11,0,0,138,43,0,0,196,48,0,0,248,17,0,0,54,15,0,0,38,2,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,152,27,0,0,98,0,0,0,98,0,0,0,78,47,0,0,98,0,0,0,98,0,0,0,218,48,0,0,98,0,0,0,98,0,0,0,250,1,0,0,98,0,0,0,98,0,0,0,156,38,0,0,98,0,0,0,98,0,0,0,98,0,0,0,178,18,0,0,98,0,0,0,98,0,0,0,218,5,0,0,98,0,0,0,98,0,0,0,168,14,0,0,98,0,0,0,98,0,0,0,164,12,0,0,98,0,0,0,98,0,0,0,52,48,0,0,98,0,0,0,98,0,0,0,98,0,0,0,10,40,0,0,62,38,0,0,110,30,0,0,114,9,0,0,150,28,0,0,64,41,0,0,200,46,0,0,182,8,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,194,13,0,0,98,0,0,0,222,20,0,0,98,0,0,0,156,4,0,0,98,0,0,0,214,10,0,0,98,0,0,0,214,34,0,0,98,0,0,0,174,23,0,0,98,0,0,0,70,48,0,0,98,0,0,0,162,8,0,0,98,0,0,0,146,20,0,0,98,0,0,0,152,5,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,112,114,111,116,111,95,50,53,49,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,196,41,121,243,1,0,16,1,112,114,111,116,111,95,50,53,49,45,112,50,46,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,173,66,151,115,1,0,16,1,112,114,111,116,111,95,50,53,49,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,237,152,20,251,2,0,32,0,112,114,111,116,111,95,50,53,49,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,164,255,216,229,3,0,32,0,112,114,111,116,111,95,50,53,49,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,143,119,34,216,3,0,32,0,112,114,111,116,111,95,50,53,49,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,232,89,9,242,3,0,32,0,112,114,111,116,111,95,50,53,49,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,159,190,255,84,3,0,32,0,112,114,111,116,111,95,50,53,49,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,188,59,122,216,3,0,32,0,112,114,111,116,111,95,50,53,49,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,145,166,64,77,3,0,32,0,112,114,111,116,111,95,50,53,49,45,99,55,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,88,154,71,164,3,0,32,0,112,114,111,116,111,95,50,53,49,45,99,56,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,206,19,213,234,3,0,32,0,50,53,49,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,156,83,116,94,4,0,16,1,50,53,49,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,200,236,46,239,5,0,64,0,50,53,49,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,202,17,226,115,5,0,64,0,50,53,49,45,118,51,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,218,1,25,130,5,0,64,0,50,53,49,45,118,52,46,118,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,120,97,158,180,5,0,64,0,49,53,50,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,250,221,199,242,1,0,16,1,49,53,50,45,112,50,46,115,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,122,244,78,39,1,0,16,1,50,53,49,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,254,147,158,15,3,0,32,0,50,53,49,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,163,46,30,231,3,0,32,0,50,53,49,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,210,85,135,35,3,0,32,0,50,53,49,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,128,0,34,139,140,67,3,0,32,0,50,53,49,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,10,189,10,11,3,0,32,0,50,53,49,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,129,242,187,101,3,0,32,0,50,53,49,45,99,55,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,46,246,101,255,3,0,32,0,50,53,49,45,99,56,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,104,28,146,141,3,0,32,0,50,53,49,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,156,83,116,94,4,0,16,1,50,53,49,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,200,236,46,239,5,0,64,0,50,53,49,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,202,17,226,115,5,0,64,0,50,53,49,45,118,51,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,218,1,25,130,5,0,64,0,50,53,49,45,118,52,46,118,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,120,97,158,180,5,0,64,0,107,99,46,110,101,111,45,115,109,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,71,6,157,108,9,0,16,1,50,53,49,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,50,69,110,0,1,0,16,1,50,53,49,45,112,103,50,46,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,81,127,5,217,1,0,16,1,50,53,49,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,254,147,158,15,3,0,32,0,50,53,49,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,163,46,30,231,3,0,32,0,50,53,49,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,210,85,135,35,3,0,32,0,50,53,49,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,34,139,140,67,3,0,32,0,50,53,49,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,10,189,10,11,3,0,32,0,50,53,49,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,129,242,187,101,3,0,32,0,50,53,49,45,99,55,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,46,246,101,255,3,0,32,0,50,53,49,45,99,56,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,104,28,146,141,3,0,32,0,50,53,49,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,156,83,116,94,4,0,16,1,50,53,49,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,200,236,46,239,5,0,64,0,50,53,49,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,202,17,226,115,5,0,64,0,50,53,49,45,118,51,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,218,1,25,130,5,0,64,0,50,53,49,45,118,52,46,118,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,120,97,158,180,5,0,64,0,107,97,46,110,101,111,45,115,109,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,158,208,102,119,9,0,16,1,50,53,49,45,101,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,45,105,141,30,1,0,16,1,50,53,49,45,101,112,50,46,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,90,110,32,214,1,0,16,1,50,53,49,45,101,112,51,46,112,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,248,62,140,213,1,0,16,1,50,53,49,45,101,112,52,46,112,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,174,2,222,82,1,0,16,1,50,53,49,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,254,147,158,15,3,0,32,0,50,53,49,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,163,46,30,231,3,0,32,0,50,53,49,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,210,85,135,35,3,0,32,0,50,53,49,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,34,139,140,67,3,0,32,0,50,53,49,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,10,189,10,11,3,0,32,0,50,53,49,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,129,242,187,101,3,0,32,0,50,53,49,45,99,55,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,46,246,101,255,3,0,32,0,50,53,49,45,99,56,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,104,28,146,141,3,0,32,0,50,53,49,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,156,83,116,94,4,0,16,1,50,53,49,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,200,236,46,239,5,0,64,0,50,53,49,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,202,17,226,115,5,0,64,0,50,53,49,45,118,51,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,218,1,25,130,5,0,64,0,50,53,49,45,118,52,46,118,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,120,97,158,180,5,0,64,0,50,52,50,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,137,223,147,136,1,0,16,1,50,52,50,45,112,50,46,115,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,76,186,10,152,1,0,16,1,50,52,50,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,5,72,123,127,2,0,32,0,50,52,50,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,214,236,100,229,3,0,32,0,50,52,50,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,96,155,149,189,3,0,32,0,50,52,50,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,79,123,18,34,3,0,32,0,50,52,50,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,68,160,79,11,3,0,32,0,50,52,50,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,211,190,16,157,3,0,32,0,50,52,50,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,162,182,7,218,3,0,32,0,50,52,50,45,99,55,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,138,163,215,246,3,0,32,0,50,52,50,45,99,56,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,69,224,35,200,3,0,32,0,50,52,50,45,109,49,107,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,12,218,18,206,4,0,16,1,50,52,50,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,81,128,234,185,5,0,64,0,50,52,50,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,110,16,17,204,5,0,64,0,50,52,50,45,118,51,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,225,164,78,4,5,0,64,0,50,52,50,45,118,52,46,118,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,48,234,133,121,5,0,64,0,50,52,50,45,112,110,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,138,134,172,97,1,0,16,1,50,52,50,45,112,50,46,115,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,76,186,10,152,1,0,16,1,50,52,50,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,5,72,123,127,2,0,32,0,50,52,50,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,214,236,100,229,3,0,32,0,50,52,50,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,96,155,149,189,3,0,32,0,50,52,50,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,79,123,18,34,3,0,32,0,50,52,50,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,68,160,79,11,3,0,32,0,50,52,50,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,211,190,16,157,3,0,32,0,50,52,50,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,162,182,7,218,3,0,32,0,50,52,50,45,99,55,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,138,163,215,246,3,0,32,0,50,52,50,45,99,56,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,69,224,35,200,3,0,32,0,50,52,50,45,109,103,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,27,107,122,78,4,0,16,1,50,52,50,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,81,128,234,185,5,0,64,0,50,52,50,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,110,16,17,204,5,0,64,0,50,52,50,45,118,51,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,225,164,78,4,5,0,64,0,50,52,50,45,118,52,46,118,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,48,234,133,121,5,0,64,0,50,51,50,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,217,26,184,125,1,0,16,1,50,51,50,45,112,50,46,115,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,246,35,139,21,1,0,16,1,50,51,50,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,245,236,20,133,2,0,32,0,50,51,50,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,161,240,139,95,3,0,32,0,50,51,50,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,129,92,212,228,3,0,32,0,50,51,50,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,24,102,29,88,3,0,32,0,50,51,50,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,104,30,187,73,3,0,32,0,50,51,50,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,81,78,252,52,3,0,32,0,50,51,50,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,123,212,244,79,3,0,32,0,50,51,50,45,109,49,107,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,112,144,234,187,4,0,16,1,50,51,50,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,181,181,162,34,5,0,64,0,50,51,50,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,68,231,4,35,5,0,64,0,50,51,50,45,118,51,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,84,185,158,117,5,0,64,0,50,51,50,45,112,103,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,183,0,36,92,1,0,16,1,50,51,50,45,112,50,46,115,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,246,35,139,21,1,0,16,1,50,51,50,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,245,236,20,133,2,0,32,0,50,51,50,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,161,240,139,95,3,0,32,0,50,51,50,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,129,92,212,228,3,0,32,0,50,51,50,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,24,102,29,88,3,0,32,0,50,51,50,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,104,30,187,73,3,0,32,0,50,51,50,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,81,78,252,52,3,0,32,0,50,51,50,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,123,212,244,79,3,0,32,0,50,51,50,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,71,135,52,69,4,0,16,1,50,51,50,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,181,181,162,34,5,0,64,0,50,51,50,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,68,231,4,35,5,0,64,0,50,51,50,45,118,51,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,84,185,158,117,5,0,64,0,50,49,52,45,112,103,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,201,87,55,189,1,0,16,1,50,49,52,45,112,50,46,115,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,115,203,44,0,1,0,16,1,50,49,52,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,219,203,84,18,2,0,32,0,50,49,52,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,162,74,207,126,3,0,32,0,50,49,52,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,55,79,181,5,3,0,32,0,50,49,52,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,101,154,152,100,3,0,32,0,50,49,52,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,21,165,190,175,3,0,32,0,50,49,52,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,38,189,59,42,3,0,32,0,50,49,52,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,199,13,211,68,3,0,32,0,50,49,52,45,99,55,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,27,51,135,54,3,0,32,0,50,49,52,45,99,56,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,173,97,20,250,3,0,32,0,50,49,52,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,124,66,188,218,4,0,16,1,50,49,52,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,69,176,247,99,5,0,64,0,50,49,52,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,89,144,146,37,5,0,64,0,50,49,52,45,118,51,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,125,37,162,146,5,0,64,0,48,56,52,45,112,103,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,149,207,84,94,1,0,16,1,48,56,52,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,138,111,113,222,2,0,32,0,48,56,52,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,50,126,8,254,3,0,32,0,48,56,52,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,9,78,134,7,3,0,32,0,48,56,52,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,27,93,230,164,3,0,32,0,48,56,52,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,104,228,172,193,3,0,32,0,48,56,52,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,220,30,44,138,3,0,32,0,48,56,52,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,53,172,147,245,3,0,32,0,48,56,52,45,99,55,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,95,2,4,153,3,0,32,0,48,56,52,45,99,56,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,155,15,235,120,3,0,32,0,48,56,52,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,41,116,45,111,4,0,16,1,48,56,52,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,86,27,134,132,5,0,64,0,48,56,52,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,3,40,138,179,5,0,64,0,48,56,52,45,118,51,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,56,163,131,214,5,0,64,0,50,49,54,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,222,179,210,117,1,0,16,1,50,49,54,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,215,114,220,239,2,0,32,0,48,53,57,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,17,166,59,118,3,0,32,0,48,53,57,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,166,140,94,224,3,0,32,0,50,49,54,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,22,159,92,102,3,0,32,0,50,49,54,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,219,3,93,127,3,0,32,0,48,53,57,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,158,63,1,89,3,0,32,0,48,53,57,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,239,93,141,28,3,0,32,0,48,53,57,45,99,55,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,53,112,143,200,3,0,32,0,48,53,57,45,99,56,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,186,227,76,72,3,0,32,0,50,49,54,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,32,104,9,27,4,0,16,1,48,53,57,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,253,80,12,83,5,0,64,0,50,49,54,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,141,122,102,3,5,0,64,0,48,53,57,45,118,51,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,249,194,56,112,5,0,64,0,50,49,54,45,118,52,46,118,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,214,155,185,49,5,0,64,0,107,101,116,97,114,114,95,118,49,48,48,46,117,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,171,168,199,212,1,0,16,1,116,48,52,55,48,49,119,48,54,52,46,117,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,65,176,101,38,2,0,32,0,97,48,52,55,48,49,119,48,54,52,46,117,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,75,185,241,94,3,0,32,0,97,48,52,55,48,50,119,48,54,52,46,117,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,127,218,214,38,3,0,32,0,98,48,52,55,48,49,119,48,54,52,46,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,141,0,236,27,4,0,32,0,109,48,52,55,48,49,98,48,51,50,46,117,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,209,34,110,180,5,0,64,0,107,101,116,95,105,103,115,48,50,55,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,7,0,16,17,107,101,116,95,100,101,102,97,117,108,116,115,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,216,146,168,60,0,0,0,8,109,101,99,97,116,45,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,198,99,34,189,0,0,16,1,109,101,99,97,116,45,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,126,179,231,107,0,0,32,0,109,101,99,97,116,45,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,31,107,228,73,0,0,32,0,109,101,99,97,116,45,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,244,173,183,62,0,0,64,0,101,112,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,185,92,17,49,0,0,64,0,48,53,48,57,49,55,45,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,131,49,33,107,0,0,0,8,100,110,48,56,45,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,127,131,96,76,1,0,16,1,100,110,49,49,45,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,153,187,74,205,1,0,16,1,100,110,48,55,45,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,27,41,20,252,1,0,16,1,100,110,49,48,45,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,55,78,163,164,1,0,16,1,100,110,48,54,45,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,66,78,214,41,1,0,16,1,100,110,48,57,45,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,73,124,45,7,1,0,16,1,100,110,48,53,45,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,168,49,26,250,2,0,16,1,100,110,48,48,45,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,109,124,215,14,3,0,32,0,100,110,48,52,45,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,83,22,18,169,4,0,32,0,100,110,48,49,45,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,158,124,105,24,4,0,32,0,100,110,48,51,45,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,156,221,217,144,4,0,32,0,100,110,48,50,45,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,185,215,4,30,4,0,32,0,100,110,49,50,45,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,44,119,6,152,5,0,32,0,100,110,49,52,45,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,50,103,158,172,5,0,32,0,100,110,49,51,45,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,249,8,51,160,5,0,32,0,100,110,49,53,45,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,184,252,51,137,5,0,32,0,100,110,49,54,45,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,17,58,230,85,5,0,32,0,100,110,49,55,45,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,80,233,10,183,5,0,32,0,100,110,49,56,45,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,19,50,213,42,5,0,32,0,100,110,49,57,45,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,64,250,212,143,5,0,32,0,107,97,114,110,112,114,111,109,46,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,147,187,176,170,6,0,32,0,107,97,114,110,112,114,111,109,46,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,251,143,247,2,6,0,32,0,107,97,114,110,111,118,95,105,56,55,53,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,24,98,51,53,45,49,54,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,88,253,230,164,1,0,16,1,98,51,53,45,49,48,46,57,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,125,69,80,177,1,0,16,1,98,51,53,45,49,55,46,52,51,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,70,194,217,253,2,0,16,1,98,51,53,45,48,49,46,49,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,105,58,216,1,4,0,32,0,98,51,53,45,48,50,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,172,71,175,216,4,0,32,0,98,51,53,45,48,51,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,151,135,182,60,4,0,32,0,98,51,53,45,48,52,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,145,63,192,113,4,0,32,0,98,51,53,45,48,53,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,8,12,226,164,4,0,32,0,98,51,53,45,48,54,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,88,182,138,63,4,0,32,0,98,51,53,45,48,55,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,73,240,74,27,4,0,32,0,98,51,53,45,48,56,46,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,140,38,178,222,4,0,32,0,98,51,53,45,49,53,46,57,56,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,15,42,33,230,6,0,64,0,105,102,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,70,74,0,0,255,255,255,255,255,255,255,255,4,103,0,0,254,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,254,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,254,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,117,78,0,0,255,255,255,255,255,255,255,255,255,255,255,255,254,255,255,255,255,255,255,255,113,78,0,0,252,96,0,0,255,255,255,255,136,114,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,46,49,57,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,138,176,143,32,1,0,0,0,53,46,49,57,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,131,81,46,114,1,0,0,0,57,46,50,48,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,51,204,130,203,1,0,0,0,54,46,50,48,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,157,179,106,130,1,0,0,0,49,48,46,50,49,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,254,63,122,108,1,0,0,0,55,46,50,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,48,130,98,176,1,0,0,0,51,46,57,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,68,94,143,128,2,0,0,0,52,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,196,105,121,166,2,0,0,0,53,46,49,57,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,162,100,169,138,3,0,0,0,54,46,50,48,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,72,126,232,134,3,0,0,0,49,46,49,55,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,142,189,39,160,4,0,0,0,50,55,46,49,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,234,103,167,67,4,0,0,0,50,46,49,56,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,216,201,236,26,4,0,0,0,50,56,46,49,56,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,109,12,92,214,4,0,0,0,51,46,50,48,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,175,204,218,206,4,0,0,0,50,57,46,50,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,155,83,63,1,4,0,0,0,52,46,50,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,34,110,142,106,4,0,0,0,51,48,46,50,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,108,161,217,37,4,0,0,0,49,49,46,49,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,96,85,209,106,5,0,0,0,49,50,46,50,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,68,72,83,104,5,0,0,0,49,51,46,52,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,90,190,113,242,5,0,0,0,49,52,46,53,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,122,24,76,93,5,0,0,0,49,57,46,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,3,223,175,16,5,0,0,0,50,48,46,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,65,79,197,45,5,0,0,0,50,49,46,52,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,163,98,104,148,5,0,0,0,50,50,46,53,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,8,86,95,180,5,0,0,0,49,53,46,49,56,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,49,29,139,203,6,0,0,0,49,54,46,49,57,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,10,78,89,129,6,0,0,0,49,55,46,50,48,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,206,68,205,74,6,0,0,0,49,56,46,50,49,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,195,233,207,37,6,0,0,0,50,51,46,49,56,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,34,214,200,6,6,0,0,0,50,52,46,49,57,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,6,5,42,54,6,0,0,0,50,53,46,50,48,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,75,76,6,190,6,0,0,0,50,54,46,50,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,141,179,181,248,6,0,0,0,49,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,173,83,113,55,7,0,0,0,50,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,93,161,60,9,7,0,0,0,98,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,127,9,126,236,1,0,0,0,99,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,13,143,161,192,1,0,0,0,101,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,12,208,29,168,1,0,0,0,104,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,248,165,93,113,2,0,0,0,110,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,93,113,16,113,3,0,0,0,112,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,22,96,71,70,3,0,0,0,99,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,39,21,83,159,4,0,0,0,100,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,27,212,251,50,4,0,0,0,101,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,142,191,134,34,4,0,0,0,102,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,160,7,112,98,4,0,0,0,99,45,50,101,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,173,199,61,70,5,0,0,0,99,45,50,102,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,66,0,186,71,5,0,0,0,118,45,50,110,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,133,241,219,5,0,0,0,106,111,121,49,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,121,182,68,216,1,0,16,1,106,111,121,53,46,54,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,41,143,156,171,1,0,16,1,106,111,121,50,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,83,120,23,125,1,0,16,1,106,111,121,54,46,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,46,211,200,179,1,0,16,1,106,111,121,51,46,54,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,76,164,69,144,1,0,16,1,106,111,121,55,46,54,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,62,60,143,136,1,0,16,1,106,111,121,52,46,54,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,248,83,181,0,1,0,16,1,106,111,121,56,46,54,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,146,233,92,93,1,0,16,1,106,111,121,57,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,188,87,181,57,2,0,32,0,106,111,121,49,49,46,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,158,40,224,51,2,0,32,0,106,111,121,49,48,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,166,113,135,51,2,0,32,0,106,111,121,49,50,46,53,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,213,173,240,244,2,0,32,0,56,50,115,49,50,51,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,189,80,198,47,3,0,32,0,56,50,115,49,50,54,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,228,168,179,62,3,0,32,0,56,50,115,49,50,54,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,134,204,169,4,0,64,0,56,50,115,49,50,54,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,48,50,49,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,143,71,195,57,1,0,16,1,48,50,49,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,120,215,86,105,2,0,32,0,48,50,49,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,80,146,80,3,0,32,0,48,50,49,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,88,82,237,9,3,0,32,0,48,50,49,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,232,229,75,90,4,0,16,1,48,50,49,45,118,49,49,46,118,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,196,229,193,102,5,0,64,0])
.concat([48,50,49,45,118,50,49,46,118,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,134,10,210,142,6,0,64,0,106,111,106,111,95,117,115,97,46,50,57,102,52,48,48,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,190,247,64,141,0,0,0,3,106,111,106,111,40,95,95,57,56,49,50,48,50,41,45,115,105,109,109,49,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,134,168,107,224,0,0,16,1,106,111,106,111,40,95,95,57,56,49,50,48,50,41,45,115,105,109,109,49,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,200,119,209,109,0,0,16,1,106,111,106,111,40,95,95,57,56,49,50,48,50,41,45,115,105,109,109,49,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,224,21,90,211,0,0,16,1,106,111,106,111,40,95,95,57,56,49,50,48,50,41,45,115,105,109,109,49,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,172,101,216,102,0,0,16,1,106,111,106,111,40,95,95,57,56,49,50,48,50,41,45,115,105,109,109,50,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,193,93,126,65,0,0,16,1,106,111,106,111,40,95,95,57,56,49,50,48,50,41,45,115,105,109,109,50,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,135,200,145,200,0,0,16,1,106,111,106,111,40,95,95,57,56,49,50,48,50,41,45,115,105,109,109,50,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,48,31,16,30,0,0,16,1,106,111,106,111,40,95,95,57,56,49,50,48,50,41,45,115,105,109,109,50,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,228,211,209,31,0,0,16,1,106,111,106,111,45,115,105,109,109,51,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,193,201,127,222,0,0,32,0,106,111,106,111,45,115,105,109,109,51,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,211,83,208,67,0,0,32,0,106,111,106,111,45,115,105,109,109,51,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,165,127,253,47,0,0,32,0,106,111,106,111,45,115,105,109,109,51,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,91,152,164,77,0,0,32,0,106,111,106,111,45,115,105,109,109,51,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,114,141,233,253,0,0,32,0,106,111,106,111,45,115,105,109,109,51,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,102,162,178,237,0,0,32,0,106,111,106,111,45,115,105,109,109,51,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,25,243,124,190,0,0,32,0,106,111,106,111,45,115,105,109,109,51,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,159,26,254,86,0,0,32,0,106,111,106,111,45,115,105,109,109,52,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,104,191,231,196,0,0,32,0,106,111,106,111,45,115,105,109,109,52,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,25,39,43,182,0,0,32,0,106,111,106,111,45,115,105,109,109,52,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,9,88,209,24,0,0,32,0,106,111,106,111,45,115,105,109,109,52,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,121,173,240,154,0,0,32,0,106,111,106,111,45,115,105,109,109,52,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,240,193,36,65,0,0,32,0,106,111,106,111,45,115,105,109,109,52,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,209,31,0,94,0,0,32,0,106,111,106,111,45,115,105,109,109,52,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,59,162,255,154,0,0,32,0,106,111,106,111,45,115,105,109,109,52,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,42,87,17,37,0,0,32,0,106,111,106,111,45,115,105,109,109,53,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,252,21,118,121,0,0,32,0,106,111,106,111,45,115,105,109,109,53,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,98,209,79,115,0,0,32,0,106,111,106,111,95,117,115,97,46,50,57,102,52,48,48,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,190,247,64,141,0,0,0,3,106,111,106,111,40,95,95,57,57,48,49,48,56,41,45,115,105,109,109,49,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,214,56,188,207,0,0,16,1,106,111,106,111,40,95,95,57,57,48,49,48,56,41,45,115,105,109,109,49,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,148,141,87,66,0,0,16,1,106,111,106,111,40,95,95,57,57,48,49,48,56,41,45,115,105,109,109,49,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,102,197,64,27,0,0,16,1,106,111,106,111,40,95,95,57,57,48,49,48,56,41,45,115,105,109,109,49,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,180,9,167,187,0,0,16,1,106,111,106,111,40,95,95,57,57,48,49,48,56,41,45,115,105,109,109,50,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,193,93,126,65,0,0,16,1,106,111,106,111,40,95,95,57,57,48,49,48,56,41,45,115,105,109,109,50,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,125,38,179,211,0,0,16,1,106,111,106,111,40,95,95,57,57,48,49,48,56,41,45,115,105,109,109,50,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,177,150,109,198,0,0,16,1,106,111,106,111,40,95,95,57,57,48,49,48,56,41,45,115,105,109,109,50,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,133,204,52,170,0,0,16,1,106,111,106,111,45,115,105,109,109,51,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,193,201,127,222,0,0,32,0,106,111,106,111,45,115,105,109,109,51,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,211,83,208,67,0,0,32,0,106,111,106,111,45,115,105,109,109,51,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,165,127,253,47,0,0,32,0,106,111,106,111,45,115,105,109,109,51,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,91,152,164,77,0,0,32,0,106,111,106,111,45,115,105,109,109,51,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,114,141,233,253,0,0,32,0,106,111,106,111,45,115,105,109,109,51,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,102,162,178,237,0,0,32,0,106,111,106,111,45,115,105,109,109,51,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,25,243,124,190,0,0,32,0,106,111,106,111,45,115,105,109,109,51,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,159,26,254,86,0,0,32,0,106,111,106,111,45,115,105,109,109,52,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,104,191,231,196,0,0,32,0,106,111,106,111,45,115,105,109,109,52,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,25,39,43,182,0,0,32,0,106,111,106,111,45,115,105,109,109,52,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,9,88,209,24,0,0,32,0,106,111,106,111,45,115,105,109,109,52,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,121,173,240,154,0,0,32,0,106,111,106,111,45,115,105,109,109,52,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,240,193,36,65,0,0,32,0,106,111,106,111,45,115,105,109,109,52,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,209,31,0,94,0,0,32,0,106,111,106,111,45,115,105,109,109,52,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,59,162,255,154,0,0,32,0,106,111,106,111,45,115,105,109,109,52,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,42,87,17,37,0,0,32,0,106,111,106,111,45,115,105,109,109,53,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,252,21,118,121,0,0,32,0,106,111,106,111,45,115,105,109,109,53,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,98,209,79,115,0,0,32,0,106,111,106,111,98,97,95,106,97,112,97,110,46,50,57,102,52,48,48,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,140,71,133,48,0,0,0,3,106,111,106,111,98,97,40,95,95,57,57,48,57,50,55,41,45,115,105,109,109,49,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,119,131,205,173,0,0,16,1,106,111,106,111,98,97,40,95,95,57,57,48,57,50,55,41,45,115,105,109,109,49,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,89,11,89,215,0,0,16,1,106,111,106,111,98,97,40,95,95,57,57,48,57,50,55,41,45,115,105,109,109,49,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,11,36,46,230,0,0,16,1,106,111,106,111,98,97,40,95,95,57,57,48,57,50,55,41,45,115,105,109,109,49,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,195,80,84,201,0,0,16,1,106,111,106,111,98,97,40,95,95,57,57,48,57,50,55,41,45,115,105,109,109,50,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,186,46,95,83,0,0,16,1,106,111,106,111,98,97,40,95,95,57,57,48,57,50,55,41,45,115,105,109,109,50,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,1,58,221,1,0,0,16,1,106,111,106,111,98,97,40,95,95,57,57,48,57,50,55,41,45,115,105,109,109,50,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,114,38,67,97,0,0,16,1,106,111,106,111,98,97,40,95,95,57,57,48,57,50,55,41,45,115,105,109,109,50,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,202,154,220,172,0,0,16,1,106,111,106,111,98,97,45,115,105,109,109,51,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,17,225,22,77,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,51,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,211,6,52,155,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,51,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,151,73,65,242,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,51,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,125,156,75,149,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,51,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,29,220,90,98,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,51,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,180,11,167,32,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,51,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,175,197,14,161,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,51,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,122,222,208,11,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,52,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,220,74,161,110,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,52,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,251,66,76,143,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,52,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,209,134,5,239,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,52,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,112,196,204,147,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,52,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,210,199,158,61,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,52,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,80,104,230,3,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,52,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,195,106,96,1,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,52,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,135,43,57,54,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,53,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,12,198,248,46,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,53,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,166,124,125,207,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,53,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,250,91,129,183,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,53,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,73,192,254,155,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,53,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,107,83,103,209,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,53,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,66,160,231,85,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,53,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,6,41,179,79,0,0,32,0,106,111,106,111,98,97,45,115,105,109,109,53,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,32,229,139,140,0,0,32,0,106,111,105,110,49,46,114,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,204,226,178,181,1,0,16,1,106,111,105,110,50,46,114,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,230,64,241,188,1,0,16,1,106,111,105,110,51,46,114,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,212,228,4,254,1,0,16,1,106,111,105,110,55,46,115,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,20,120,138,187,2,0,16,1,106,111,105,110,52,46,112,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,44,200,100,73,3,0,32,0,106,111,105,110,53,46,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,137,250,120,174,3,0,32,0,106,111,105,110,54,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,97,50,83,43,3,0,32,0,108,56,50,115,49,50,57,46,49,49,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,17,66,114,123,4,0,32,0,104,56,50,115,49,50,57,46,49,50,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,255,197,129,46,4,0,32,0,103,108,45,48,50,45,50,46,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,226,18,218,128,1,0,16,1,103,108,45,48,53,45,50,46,51,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,187,187,77,254,1,0,16,1,103,108,45,48,49,45,50,46,49,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,7,83,36,11,1,0,16,1,103,108,45,48,52,45,50,46,51,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,97,31,51,27,1,0,16,1,103,110,45,48,48,46,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,22,11,17,11,1,0,16,1,103,110,45,48,51,46,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,151,230,40,30,1,0,16,1,103,108,45,48,55,46,49,51,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,150,239,139,202,2,0,16,1,103,108,45,48,56,46,54,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,180,162,51,3,0,32,0,103,108,45,48,57,46,54,122,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,82,71,45,90,3,0,32,0,109,97,103,45,48,50,46,52,122,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,154,198,137,222,4,0,32,0,109,97,103,45,48,48,46,49,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,51,93,240,168,5,0,32,0,109,97,103,45,48,49,46,49,122,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,237,158,57,91,5,0,32,0,109,97,103,45,48,51,46,57,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,159,235,32,34,6,0,32,0,109,97,103,45,48,53,46,49,50,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,84,50,165,86,6,0,32,0,109,97,103,45,48,52,46,57,122,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,204,148,75,20,6,0,32,0,109,97,103,45,48,54,46,49,50,122,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,73,71,212,130,6,0,32,0,103,108,45,48,54,46,49,51,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,157,81,46,217,7,0,64,0,109,97,103,45,48,55,46,49,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,100,82,235,8,8,0,64,0,109,98,55,49,50,50,104,46,55,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,54,115,38,161,0,0,0,8,106,50,112,49,120,49,46,117,54,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,188,196,72,84,1,0,16,1,106,50,112,49,120,50,46,117,54,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,185,74,16,82,1,0,16,1,106,50,112,49,120,51,46,117,54,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,202,235,99,135,1,0,16,1,106,50,112,49,120,52,46,117,55,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,105,94,142,15,1,0,16,1,106,50,112,49,120,53,46,117,56,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,37,119,137,220,2,0,16,1,106,50,112,49,120,54,46,117,56,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,249,36,66,89,2,0,16,1,106,50,100,49,120,49,46,117,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,144,252,183,178,3,0,16,1,106,99,45,50,48,48,46,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,78,194,48,31,4,0,32,0,106,99,45,49,48,48,45,48,48,46,49,55,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,140,146,141,87,5,0,32,0,106,99,45,49,48,49,45,48,48,46,49,56,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,202,26,94,127,5,0,32,0,106,99,45,49,48,50,45,48,48,46,49,56,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,104,170,202,114,5,0,32,0,106,99,45,49,48,51,45,48,48,46,49,56,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,201,159,158,78,5,0,32,0,106,99,45,49,48,52,45,48,48,46,49,56,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,147,46,42,107,5,0,32,0,106,99,45,49,48,53,45,48,48,46,49,56,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,240,209,202,115,5,0,32,0,106,99,45,49,48,56,45,48,48,46,49,56,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,49,17,221,103,5,0,32,0,106,50,103,49,120,49,46,49,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,106,234,167,102,5,0,32,0,106,50,103,49,120,50,46,49,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,12,119,14,102,5,0,32,0,106,99,45,49,48,54,45,48,48,46,49,55,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,27,102,101,188,6,0,32,0,106,99,45,49,48,55,45,48,48,46,49,55,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,139,110,168,146,6,0,32,0,106,99,45,51,48,49,45,48,48,46,56,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,119,48,91,156,7,0,64,0,106,99,45,51,48,48,45,48,48,46,56,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,235,177,213,19,7,0,64,0,106,50,109,49,120,49,46,117,53,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,94,226,246,186,7,0,64,0,104,0,160,31,198,6,56,56,80,198,6,58,56,73,198,6,60,56,67,198,6,62,56,75,198,6,64,56,69,198,6,66,56,84,104,0,176,31,198,6,0,9,182,198,6,0,10,182,198,6,0,11,182,198,6,32,9,182,198,6,33,9,178,198,6,34,9,190,198,6,35,9,184,104,0,208,31,198,6,176,28,87,234,0,0,64,0,0,0,0,0,0,0,0,0,0,105,107,51,45,50,45,118,101,114,49,46,99,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,35,128,174,27,1,0,16,0,105,107,51,45,51,45,118,101,114,49,46,99,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,102,139,227,16,1,0,16,0,105,107,51,45,49,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,86,210,228,71,1,0,16,0,105,107,51,45,52,46,99,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,181,246,58,164,1,0,16,0,105,107,51,45,53,46,49,54,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,252,6,103,206,2,0,16,0,105,107,51,45,55,46,49,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,223,4,72,11,3,0,32,0,105,107,51,45,56,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,80,78,171,16,3,0,32,0,105,107,51,45,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,50,189,86,154,4,0,32,0,105,107,51,45,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,10,161,230,12,4,0,32,0,105,107,51,45,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,67,190,226,228,4,0,32,0,105,107,51,45,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,114,35,34,172,4,0,32,0,105,107,51,45,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,194,113,57,195,4,0,32,0,105,107,51,45,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,119,234,59,69,4,0,32,0,105,107,51,45,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,252,129,26,120,4,0,32,0,105,107,51,45,49,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,11,64,186,128,4,0,32,0,105,107,51,45,49,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,74,206,195,12,4,0,32,0,105,107,51,45,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,69,98,16,186,4,0,32,0,105,107,51,45,50,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,119,92,253,208,4,0,32,0,105,107,51,45,50,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,131,216,120,72,4,0,32,0,105,107,51,45,50,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,240,251,208,80,4,0,32,0,105,107,51,45,50,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,252,30,133,154,4,0,32,0,105,107,51,45,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,137,186,189,78,4,0,32,0,105,107,51,45,50,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,104,109,178,233,4,0,32,0,105,107,51,45,50,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,241,3,59,7,4,0,32,0,105,107,51,45,50,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,97,53,97,156,4,0,32,0,105,107,51,45,50,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,126,34,221,22,4,0,32,0,105,107,51,45,50,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,174,21,23,113,4,0,32,0,105,107,51,45,54,46,49,56,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,164,86,210,89,5,0,64,0,99,53,57,45,49,48,46,52,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,21,173,255,228,2,0,0,0,99,53,57,45,49,50,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,175,215,128,160,2,0,0,0,99,53,57,45,48,57,46,52,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,176,227,67,226,2,0,0,0,99,53,57,45,49,49,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,82,250,77,77,2,0,0,0,99,53,57,45,48,56,46,53,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,11,193,203,211,9,0,0,0,99,53,57,45,48,51,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,72,48,81,158,11,0,0,0,99,53,57,45,48,50,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,7,94,251,175,11,0,0,0,99,53,57,45,48,49,46,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,29,41,174,70,29,0,0,0,112,97,108,50,48,108,56,98,45,99,53,57,45,48,52,46,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,1,0,0,124,240,188,46,0,0,0,8,112,97,108,49,54,108,56,98,45,99,53,57,45,48,53,46,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,92,124,182,55,0,0,0,8,112,97,108,50,48,108,56,98,45,99,53,57,45,48,54,46,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,1,0,0,117,104,23,191,0,0,0,8,112,97,108,49,54,114,52,98,45,99,53,57,45,48,55,46,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,149,189,100,207,0,0,0,8,97,45,104,48,45,118,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,165,2,40,197,1,0,16,1,97,45,108,48,45,118,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,76,7,99,244,1,0,16,1,97,45,104,49,45,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,53,19,226,58,1,0,16,1,97,45,108,49,45,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,249,197,106,188,1,0,16,1])
.concat([97,45,115,112,45,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,231,16,226,128,6,0,16,1,104,104,95,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,239,39,81,236,2,0,32,0,104,104,95,49,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,148,82,246,222,2,0,32,0,104,104,95,50,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,212,106,13,187,2,0,32,0,104,104,95,51,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,78,4,81,67,2,0,32,0,104,104,95,97,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,95,186,119,197,3,0,32,0,104,104,95,97,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,171,18,157,66,3,0,32,0,104,104,95,97,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,176,99,177,181,3,0,32,0,104,104,95,97,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,161,102,245,142,3,0,32,0,97,45,118,48,45,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,255,202,170,250,5,0,64,0,49,50,50,106,97,98,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,209,109,188,234,1,0,16,1,49,50,50,97,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,227,85,174,34,2,0,32,0,49,50,50,97,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,136,67,143,67,2,0,32,0,49,50,50,97,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,191,49,200,188,3,0,64,0,49,50,50,97,48,52,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,198,184,110,80,4,0,32,0,49,50,50,97,48,51,46,49,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,100,79,12,89,4,0,32,0,49,50,50,97,48,50,46,49,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,92,48,52,87,4,0,32,0,114,101,100,45,100,111,116,46,114,103,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,41,242,74,156,1,0,0,0,119,104,116,45,100,111,116,46,108,102,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,53,146,15,193,1,0,0,0,115,105,108,118,101,114,46,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,233,60,134,103,2,0,0,0,112,110,107,46,51,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,122,253,77,87,3,0,0,0,98,108,107,46,51,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,64,192,247,22,3,0,0,0,103,111,108,100,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,237,130,82,95,4,0,0,0,111,114,97,110,103,101,46,55,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,245,153,93,7,4,0,0,0,121,101,108,108,111,119,46,55,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,150,46,39,246,4,0,0,0,118,105,111,108,101,116,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,133,6,2,202,4,0,0,0,56,50,115,49,50,57,46,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,230,71,75,218,5,0,0,0,56,50,115,49,50,57,46,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,164,19,226,150,5,0,0,0,56,50,115,49,50,54,46,50,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,75,206,174,55,5,0,0,0,56,50,115,49,52,55,46,112,114,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,146,188,229,70,6,0,0,0,112,108,115,49,53,51,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,235,0,0,0,0,0,0,0,7,0,0,16,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,254,41,0,0,10,10,0,0,222,24,0,0,142,2,0,0,76,21,0,0,74,39,0,0,90,4,0,0,68,36,0,0,128,41,0,0,18,15,0,0,148,39,0,0,62,34,0,0,160,47,0,0,92,5,0,0,78,46,0,0,244,18,0,0,78,46,0,0,78,46,0,0,78,46,0,0,16,37,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,62,23,0,0,78,46,0,0,246,47,0,0,222,48,0,0,78,46,0,0,134,1,0,0,78,46,0,0,78,46,0,0,78,46,0,0,168,34,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,4,0,0,78,46,0,0,102,29,0,0,166,17,0,0,78,46,0,0,248,20,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,208,37,0,0,162,4,0,0,78,46,0,0,74,13,0,0,78,46,0,0,78,46,0,0,96,41,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,108,40,0,0,48,26,0,0,144,21,0,0,88,23,0,0,126,10,0,0,134,17,0,0,40,3,0,0,78,46,0,0,232,4,0,0,78,46,0,0,78,46,0,0,96,44,0,0,2,17,0,0,78,46,0,0,78,46,0,0,78,46,0,0,192,32,0,0,176,22,0,0,72,40,0,0,42,4,0,0,96,24,0,0,192,35,0,0,124,2,0,0,78,46,0,0,180,3,0,0,78,46,0,0,78,46,0,0,0,45,0,0,170,15,0,0,78,46,0,0,78,46,0,0,78,46,0,0,6,44,0,0,68,22,0,0,142,17,0,0,38,27,0,0,156,19,0,0,142,15,0,0,208,44,0,0,78,46,0,0,58,22,0,0,78,46,0,0,78,46,0,0,92,49,0,0,184,7,0,0,78,46,0,0,78,46,0,0,78,46,0,0,136,48,0,0,66,11,0,0,250,37,0,0,94,6,0,0,56,40,0,0,158,16,0,0,160,22,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,160,13,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,102,37,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,240,36,0,0,196,21,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,182,38,0,0,162,7,0,0,78,46,0,0,78,46,0,0,78,46,0,0,24,36,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,214,25,0,0,154,26,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,176,9,0,0,208,36,0,0,78,46,0,0,78,46,0,0,78,46,0,0,94,35,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,230,45,0,0,90,37,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,0,30,0,0,28,10,0,0,78,46,0,0,78,46,0,0,78,46,0,0,130,27,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,172,20,0,0,78,13,0,0,182,29,0,0,12,13,0,0,94,9,0,0,92,50,0,0,168,41,0,0,170,28,0,0,90,25,0,0,142,36,0,0,90,34,0,0,96,40,0,0,142,44,0,0,232,46,0,0,144,29,0,0,28,3,0,0,162,2,0,0,178,39,0,0,72,8,0,0,26,0,0,0,132,9,0,0,134,48,0,0,60,40,0,0,140,18,0,0,18,18,0,0,86,38,0,0,28,47,0,0,78,46,0,0,78,46,0,0,78,46,0,0,90,50,0,0,174,46,0,0,78,46,0,0,78,46,0,0,138,18,0,0,128,20,0,0,78,46,0,0,138,42,0,0,208,12,0,0,210,25,0,0,252,10,0,0,210,41,0,0,78,46,0,0,166,16,0,0,108,30,0,0,78,46,0,0,62,15,0,0,78,46,0,0,78,46,0,0,78,46,0,0,70,46,0,0,252,4,0,0,78,46,0,0,230,0,0,0,78,46,0,0,78,46,0,0,228,38,0,0,102,32,0,0,78,46,0,0,104,7,0,0,254,39,0,0,78,46,0,0,160,35,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,232,35,0,0,62,37,0,0,124,31,0,0,244,39,0,0,22,48,0,0,190,41,0,0,228,3,0,0,78,46,0,0,78,44,0,0,150,33,0,0,246,26,0,0,166,5,0,0,140,49,0,0,78,46,0,0,144,49,0,0,78,46,0,0,250,31,0,0,116,23,0,0,14,20,0,0,48,10,0,0,132,46,0,0,8,16,0,0,28,50,0,0,98,35,0,0,202,25,0,0,184,3,0,0,104,34,0,0,112,26,0,0,10,34,0,0,78,46,0,0,48,20,0,0,220,15,0,0,188,30,0,0,42,28,0,0,132,33,0,0,174,48,0,0,234,45,0,0,144,30,0,0,144,13,0,0,138,41,0,0,240,4,0,0,162,35,0,0,146,47,0,0,232,7,0,0,182,45,0,0,78,46,0,0,24,1,0,0,112,36,0,0,252,22,0,0,138,7,0,0,38,29,0,0,58,19,0,0,2,38,0,0,108,26,0,0,204,1,0,0,62,33,0,0,154,34,0,0,194,32,0,0,132,36,0,0,86,28,0,0,244,28,0,0,78,46,0,0,196,28,0,0,174,13,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,86,43,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,58,6,0,0,98,11,0,0,6,3,0,0,172,27,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,252,12,0,0,58,7,0,0,110,28,0,0,164,14,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,78,46,0,0,120,8,0,0,58,2,0,0,210,26,0,0,144,22,0,0,104,97,115,99,45,112,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,52,152,223,83,1,0,16,1,104,97,115,99,45,112,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,110,186,240,223,1,0,16,1,104,97,115,99,45,115,112,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,135,22,155,37,2,0,16,1,104,97,115,99,45,99,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,116,33,90,221,3,0,32,0,104,97,115,99,45,99,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,124,33,184,118,3,0,32,0,104,97,115,99,45,99,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,104,154,15,217,3,0,32,0,104,97,115,99,45,99,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,57,13,254,108,3,0,32,0,104,97,110,103,108,121,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,10,97,232,95,1,0,16,1,104,97,110,103,108,121,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,134,101,114,115,1,0,16,1,104,97,110,103,108,121,46,54,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,159,249,126,78,1,0,16,1,104,97,110,103,108,121,46,54,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,230,71,65,127,1,0,16,1,112,97,99,109,97,110,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,100,73,148,12,2,0,32,0,112,97,99,109,97,110,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,249,237,143,149,2,0,32,0,56,50,115,49,50,51,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,189,80,198,47,3,0,32,0,56,50,115,49,50,54,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,228,168,179,62,3,0,32,0,56,50,115,49,50,54,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,134,204,169,4,0,64,0,56,50,115,49,50,54,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,103,121,114,117,115,115,107,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,61,180,115,198,1,0,16,1,103,121,114,117,115,115,107,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,228,3,236,164,1,0,16,1,103,121,114,117,115,115,107,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,152,74,69,39,1,0,16,1,103,121,114,117,115,115,107,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,126,242,43,130,2,0,16,1,103,121,114,117,115,115,107,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,23,28,174,244,3,0,16,1,103,121,114,117,115,115,107,46,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,21,129,73,186,3,0,16,1,103,121,114,117,115,115,107,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,234,93,155,63,4,0,16,1,103,121,114,117,115,115,107,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,16,219,73,201,5,0,32,0,103,121,114,117,115,115,107,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,26,65,34,79,5,0,32,0,103,121,114,117,115,115,107,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,188,31,205,71,5,0,32,0,103,121,114,117,115,115,107,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,140,56,141,142,5,0,32,0,103,121,114,117,115,115,107,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,155,50,216,39,6,0,32,0,103,121,114,117,115,115,107,46,112,114,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,179,45,120,152,7,0,32,0,103,121,114,117,115,115,107,46,112,114,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,222,87,208,126,7,0,32,0,103,121,114,117,115,115,107,46,112,114,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,129,58,130,222,7,0,32,0,108,52,95,97,45,104,48,46,105,99,55,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,97,94,88,157,1,0,16,1,108,52,95,97,45,108,48,46,105,99,55,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,25,197,180,199,1,0,16,1,108,52,95,97,45,115,112,46,105,99,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,78,9,128,187,2,0,16,1,114,99,95,99,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,7,185,208,132,3,0,32,0,114,99,95,99,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,239,132,55,203,3,0,32,0,114,99,95,99,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,215,100,113,104,3,0,32,0,114,99,95,99,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,175,230,107,200,3,0,32,0,114,99,95,118,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,96,195,218,205,4,0,64,0,54,51,51,106,48,51,46,49,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,98,145,145,32,1,0,16,1,54,51,51,106,48,50,46,49,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,154,47,146,181,1,0,16,1,54,51,51,101,48,49,46,49,50,97,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,85,146,84,209,2,0,16,1,54,51,51,101,48,52,46,55,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,66,197,221,20,3,0,32,0,54,51,51,101,48,53,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,68,80,24,66,3,0,32,0,54,51,51,101,48,54,46,49,54,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,174,250,246,156,4,0,32,0,54,51,51,101,48,55,46,49,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,56,102,208,242,4,0,32,0,54,51,51,101,48,56,46,49,48,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,250,73,9,159,5,0,32,0,54,51,51,101,48,57,46,49,50,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,25,94,202,20,5,0,32,0,54,51,51,102,49,48,46,49,56,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,132,77,36,43,5,0,32,0,54,51,51,102,49,49,46,50,48,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,25,94,202,20,5,0,32,0,48,48,55,55,54,54,46,50,48,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,16,103,111,116,99,104,97,46,117,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,224,82,93,94,1,0,16,1,103,111,116,99,104,97,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,255,234,168,58,1,0,16,1,103,111,116,99,104,97,95,117,46,122,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,107,225,246,244,2,0,16,1,103,111,116,99,104,97,45,117,46,52,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,240,34,168,78,3,0,32,0,103,111,116,99,104,97,45,117,46,52,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,172,41,181,107,3,0,32,0,103,111,116,99,104,97,45,117,46,52,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,123,155,41,73,3,0,32,0,103,111,116,99,104,97,45,117,46,52,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,78,240,147,192,3,0,32,0,103,111,116,99,104,97,46,117,53,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,98,160,246,133,4,0,32,0,103,111,116,99,104,97,46,117,53,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,72,78,107,66,4,0,32,0,103,111,116,99,104,97,46,117,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,164,5,62,144,4,0,32,0,103,111,116,99,104,97,46,117,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,30,213,36,60,4,0,32,0,103,111,116,99,104,97,45,117,46,122,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,174,198,17,97,5,0,64,0,50,48,57,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,121,154,1,42,1,0,16,1,50,48,57,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,134,173,234,192,2,0,32,0,50,48,57,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,14,152,157,180,3,0,32,0,50,48,57,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,21,176,73,86,3,0,32,0,50,48,57,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,206,186,145,95,3,0,32,0,50,48,57,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,242,118,159,30,3,0,32,0,50,48,57,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,37,131,117,205,4,0,16,1,50,48,57,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,18,66,33,239,5,0,64,0,100,122,48,49,45,50,50,46,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,242,253,101,252,1,0,0,0,100,122,48,50,46,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,65,117,17,142,1,0,0,0,100,122,48,51,46,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,244,168,6,86,1,0,0,0,100,122,48,52,45,50,49,46,54,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,47,88,70,125,1,0,0,0,100,122,48,53,45,50,49,46,55,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,88,199,225,35,1,0,0,0,100,122,48,54,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,223,86,143,121,2,0,0,0,100,122,48,48,46,49,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,49,79,43,153,3,0,0,0,100,122,49,53,46,49,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,217,95,26,160,4,0,0,0,100,122,49,54,46,49,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,74,52,154,90,4,0,0,0,100,122,49,50,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,153,174,127,129,4,0,0,0,100,122,49,52,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,109,247,187,10,4,0,0,0,100,122,49,49,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,36,156,225,165,4,0,0,0,100,122,49,51,46,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,5,4,124,62,4,0,0,0,100,122,49,55,46,49,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,139,27,54,64,4,0,0,0,100,122,49,56,46,49,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,137,148,33,141,4,0,0,0,100,122,48,55,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,103,81,69,231,5,0,0,0,100,122,48,56,46,49,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,254,221,249,50,5,0,0,0,100,122,48,57,46,49,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,2,252,110,187,5,0,0,0,100,122,49,48,46,49,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,59,150,249,110,5,0,0,0,100,122,49,57,97,46,49,48,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,59,248,225,71,6,0,0,0,100,122,50,48,97,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,153,45,254,216,6,0,0,0,100,122,45,49,46,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,230,225,183,24,7,0,0,0,103,119,48,52,45,53,115,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,85,232,157,255,1,0,16,1,103,119,48,53,45,54,115,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,169,71,105,90,1,0,16,1,103,119,48,51,45,53,104,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,150,149,199,155,2,0,16,1,103,119,48,50,45,51,104,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,53,141,204,122,3,0,32,0,103,119,48,54,45,49,99,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,49,22,165,78,4,0,32,0,103,119,48,55,45,49,100,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,126,99,66,218,4,0,32,0,103,119,48,56,45,49,102,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,112,141,78,11,4,0,32,0,103,119,48,57,45,49,104,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,76,94,92,182,4,0,32,0,103,119,49,48,45,49,110,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,79,205,132,94,5,0,32,0,103,119,49,49,45,50,110,97,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,225,88,180,8,5,0,32,0,103,119,49,50,45,50,110,98,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,20,151,156,34,5,0,32,0,103,119,49,51,45,51,110,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,71,175,223,197,5,0,32,0,103,119,49,52,45,49,114,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,181,229,16,156,6,0,32,0,103,119,49,53,45,50,114,97,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,250,140,209,76,6,0,32,0,103,119,49,54,45,50,114,98,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,190,199,17,249,6,0,32,0,103,119,49,55,45,51,114,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,37,206,169,121,6,0,32,0,103,119,48,49,45,54,97,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,5,250,138,215,7,0,64,0,53,55,55,108,48,51,46,49,48,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,255,228,41,174,1,0,16,1,53,55,55,108,48,50,46,56,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,165,54,8,36,1,0,16,1,53,55,55,108,48,49,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,31,62,250,65,1,0,16,1,53,55,55,108,48,55,46,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,27,189,167,77,2,0,32,0,53,55,55,108,48,54,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,202,176,28,15,3,0,32,0,53,55,55,108,48,53,46,52,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,102,139,58,82,3,0,32,0,53,55,55,108,48,56,46,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,164,51,57,136,3,0,32,0,53,55,55,108,48,52,46,51,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,76,218,236,204,3,0,32,0,53,55,55,104,48,57,46,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,128,124,94,193,4,0,32,0,53,55,55,104,49,49,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,43,153,26,42,4,0,32,0,53,55,55,104,49,48,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,83,30,222,233,4,0,32,0,18,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,18,0,0,0,1,15,2,0,80,252,6,0,18,0,0,0,1,15,5,0,16,242,7,0,18,0,0,0,1,15,8,0,104,236,7,0,18,0,0,0,1,15,4,0,120,113,6,0,18,0,0,0,1,15,1,0,232,228,5,0,18,0,0,0,1,15,15,0,80,245,6,0,18,0,0,0,1,15,3,0,56,141,7,0,18,0,0,0,1,15,7,0,120,211,6,0,18,0,0,0,1,15,14,0,8,201,6,0,18,0,0,0,1,15,6,0,24,1,7,0,18,0,0,0,1,15,13,0,200,197,6,0,18,0,0,0,1,15,12,0,152,194,6,0,18,0,0,0,1,15,11,0,128,95,7,0,18,0,0,0,1,15,10,0,248,189,6,0,18,0,0,0,1,15,9,0,208,114,5,0,18,0,0,0,1,15,0,0,16,227,4,0,0,0,0,0,254,0,15,0,160,123,6,0,18,0,0,0,130,240,32,0,80,252,6,0,18,0,0,0,0,15,0,0,0,0,0,0,18,0,0,0,130,240,80,0,16,242,7,0,18,0,0,0,0,15,0,0,0,0,0,0,18,0,0,0,130,240,128,0,104,236,7,0,18,0,0,0,0,15,0,0,0,0,0,0,18,0,0,0,130,240,64,0,120,113,6,0,18,0,0,0,0,15,0,0,0,0,0,0,18,0,0,0,130,240,16,0,232,228,5,0,18,0,0,0,0,15,0,0,0,0,0,0,18,0,0,0,130,240,240,0,80,245,6,0,18,0,0,0,0,15,0,0,0,0,0,0,18,0,0,0,130,240,48,0,56,141,7,0,18,0,0,0,0,15,0,0,0,0,0,0,18,0,0,0,130,240,112,0,120,211,6,0,18,0,0,0,0,15,0,0,0,0,0,0,18,0,0,0,130,240,224,0,8,201,6,0,18,0,0,0,0,15,0,0,0,0,0,0,18,0,0,0,130,240,96,0,24,1,7,0,18,0,0,0,0,15,0,0,0,0,0,0,18,0,0,0,130,240,208,0,200,197,6,0,18,0,0,0,0,15,0,0,0,0,0,0,18,0,0,0,130,240,192,0,152,194,6,0,18,0,0,0,0,15,0,0,0,0,0,0,18,0,0,0,130,240,176,0,128,95,7,0,18,0,0,0,0,15,0,0,0,0,0,0,18,0,0,0,130,240,160,0,248,189,6,0,18,0,0,0,0,15,0,0,0,0,0,0,18,0,0,0,130,240,144,0,208,114,5,0,18,0,0,0,0,15,0,0,0,0,0,0,19,0,0,0,255,255,74,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,19,0,0,0,1,3,3,0,208,75,4,0,19,0,0,0,1,3,2,0,8,49,4,0,19,0,0,0,1,3,1,0,72,246,3,0,19,0,0,0,1,3,0,0,64,47,7,0,0,0,0,0,254,0,2,0,200,30,2,0,19,0,0,0,1,4,0,0,120,97,1,0,19,0,0,0,1,4,4,0,96,19,1,0,0,0,0,0,254,0,4,0,64,37,5,0,19,0,0,0,1,24,24,0,80,155,2,0,19,0,0,0,1,24,16,0,176,142,2,0,19,0,0,0,1,24,8,0,128,131,2,0,19,0,0,0,1,24,0,0,168,118,2,0,0,0,0,0,254,0,4,0,72,202,5,0,19,0,0,0,1,96,96,0,80,246,3,0,19,0,0,0,1,96,64,0,248,38,7,0,19,0,0,0,1,96,32,0,48,123,8,0,19,0,0,0,1,96,0,0,8,117,8,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,128,128,0,96,135,7,0,19,0,0,0,1,128,0,0,152,182,7,0,20,0,0,0,255,255,15,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,20,0,0,0,1,1,1,0,96,135,7,0,20,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,6,0,20,0,0,0,1,2,2,0,8,208,6,0,20,0,0,0,1,2,0,0,88,204,6,0,56,57,48,119,48,50,46,107,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,56,245,246,178,1,0,16,1,56,57,48,107,48,49,46,102,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,176,62,75,212,2,0,16,1,56,57,48,102,48,54,46,102,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,85,33,89,38,3,0,32,0,56,57,48,102,48,55,46,104,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,46,250,116,108,3,0,32,0,56,57,48,102,48,56,46,106,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,128,46,225,41,3,0,32,0,56,57,48,102,48,57,46,107,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,213,64,202,103,3,0,32,0,56,57,48,102,48,52,46,104,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,250,209,108,241,4,0,32,0,56,57,48,102,48,53,46,107,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,5,219,55,218,4,0,32,0,56,57,48,102,48,51,46,100,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,49,80,6,25,6,0,32,0,54,51,115,49,52,49,110,46,107,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,6,1,98,211,5,0,0,8,112,114,111,116,111,95,50,53,51,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,22,12,47,199,1,0,16,1,112,114,111,116,111,95,50,53,51,45,112,50,46,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,101,229,141,191,1,0,16,1,112,114,111,116,111,95,50,53,51,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,222,137,153,119,2,0,32,0,112,114,111,116,111,95,50,53,51,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,55,209,181,91,3,0,32,0,112,114,111,116,111,95,50,53,51,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,96,41,141,92,3,0,32,0,112,114,111,116,111,95,50,53,51,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,252,22,77,35,3,0,32,0,112,114,111,116,111,95,50,53,51,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,147,185,181,185,3,0,32,0,112,114,111,116,111,95,50,53,51,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,210,21,38,114,3,0,32,0,112,114,111,116,111,95,50,53,51,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,56,171,111,10,3,0,32,0,112,114,111,116,111,95,50,53,51,45,99,55,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,111,128,142,214,3,0,32,0,112,114,111,116,111,95,50,53,51,45,99,56,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,153,254,120,247,3,0,32,0,112,114,111,116,111,95,50,53,51,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,247,100,228,187,4,0,16,1,112,114,111,116,111,95,50,53,51,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,35,57,79,39,5,0,64,0,112,114,111,116,111,95,50,53,51,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,190,218,134,143,5,0,64,0,112,114,111,116,111,95,50,53,51,45,118,51,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,205,6,253,5,5,0,64,0,112,114,111,116,111,95,50,53,51,45,118,52,46,118,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,99,64,152,20,5,0,64,0,107,101,46,110,101,111,45,115,109,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,51,34,199,150,9,0,16,1,50,53,51,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,126,93,174,24,1,0,16,1,50,53,51,45,112,50,46,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,121,167,255,175,1,0,16,1,50,53,51,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,70,224,3,6,3,0,32,0,50,53,51,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,164,210,23,9,3,0,32,0,50,53,51,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,45,201,55,103,3,0,32,0,50,53,51,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,198,46,169,91,3,0,32,0,50,53,51,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,87,85,171,62,3,0,32,0,50,53,51,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,139,9,141,48,3,0,32,0,50,53,51,45,99,55,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,174,149,233,192,3,0,32,0,50,53,51,45,99,56,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,3,19,161,33,3,0,32,0,50,53,51,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,190,6,168,54,4,0,16,1,50,53,51,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,140,56,62,38,5,0,64,0,50,53,51,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,190,199,107,44,5,0,64,0,50,53,51,45,118,51,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,125,178,37,4,5,0,64,0,50,53,51,45,118,52,46,118,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,169,232,75,165,5,0,64,0,50,53,50,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,251,196,138,75,1,0,16,1,50,53,50,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,130,120,238,80,3,0,32,0,50,53,50,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,116,84,88,98,3,0,32,0,50,53,50,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,153,64,204,48,4,0,16,1,50,53,50,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,51,103,148,229,5,0,64,0,99,99,45,99,45,104,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,208,220,23,34,1,0,16,1,99,99,45,99,45,108,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,251,215,57,255,1,0,16,1,99,99,45,99,45,104,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,185,186,43,155,1,0,16,1,99,99,45,99,45,108,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,142,39,211,172,1,0,16,1,99,99,45,99,45,48,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,170,222,153,157,2,0,32,0,99,99,45,99,45,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,237,131,176,126,2,0,32,0,99,99,45,99,45,50,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,158,72,33,148,2,0,32,0,99,99,45,99,45,51,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,53,199,14,146,2,0,32,0,99,99,45,98,45,97,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,189,114,52,163,3,0,32,0,99,99,45,98,45,97,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,45,31,139,17,3,0,32,0,99,99,45,98,45,97,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,72,191,206,131,3,0,32,0,99,99,45,98,45,97,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,252,3,41,87,3,0,32,0,99,99,45,98,45,98,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,57,180,245,13,4,0,32,0,99,99,45,98,45,98,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,143,119,11,1,4,0,32,0,99,99,45,98,45,98,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,251,246,169,189,4,0,32,0,99,99,45,98,45,98,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,63,186,97,211,4,0,32,0,99,99,45,99,45,118,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,222,186,71,98,5,0,64,0,103,97,105,100,101,110,95,49,46,51,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,124,255,55,224,1,0,16,1,103,97,105,100,101,110,95,50,46,52,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,20,115,79,69,1,0,16,1,103,97,105,100,101,110,95,51,46,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,106,62,253,117,2,0,16,1,103,97,105,100,101,110,95,53,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,247,53,64,141,3,0,32,0,49,52,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,170,221,207,30,4,0,32,0,49,53,46,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,150,166,145,18,4,0,32,0,49,54,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,202,71,11,20,4,0,32,0,49,55,46,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,203,204,56,118,4,0,32,0,49,56,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,214,175,173,63,5,0,32,0,49,57,46,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,91,157,174,221,5,0,32,0,50,48,46,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,147,122,207,8,5,0,32,0,50,49,46,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,245,146,200,26,5,0,32,0,54,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,159,223,204,231,6,0,32,0,56,46,51,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,128,248,247,126,6,0,32,0,49,48,46,51,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,236,29,69,166,6,0,32,0,103,97,105,100,101,110,95,49,50,46,51,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,58,225,241,144,6,0,32,0,55,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,149,236,107,1,6,0,32,0,57,46,49,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,211,127,155,110,6,0,32,0,49,49,46,49,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,94,223,191,127,6,0,32,0,103,97,105,100,101,110,95,49,51,46,49,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,94,92,159,125,6,0,32,0,52,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,249,250,224,176,7,0,64,0,168,86,7,0,1,0,0,0,0,245,146,0,248,191,2,0,24,38,7,0,1,0,0,0,4,245,146,0,184,160,2,0,56,210,6,0,1,0,0,0,80,253,146,0,192,135,2,0,24,163,6,0,1,0,0,0,81,253,146,0,240,108,2,0,152,122,6,0,1,0,0,0,82,253,146,0,96,82,2,0,192,72,6,0,1,0,0,0,83,253,146,0,32,56,2,0,200,110,3,0,1,0,0,0,84,253,146,0,152,30,2,0,120,89,3,0,1,0,0,0,85,253,146,0,232,10,2,0,120,74,3,0,1,0,0,0,86,253,146,0,152,138,8,0,192,61,3,0,1,0,0,0,87,253,146,0,48,119,7,0,40,246,1,0,1,0,0,0,1,245,146,0,64,246,1,0,144,236,1,0,1,0,0,0,5,245,146,0,136,224,1,0,176,223,1,0,1,0,0,0,88,253,146,0,72,198,1,0,192,209,1,0,1,0,0,0,89,253,146,0,24,182,1,0,24,198,1,0,1,0,0,0,90,253,146,0,40,167,1,0,120,189,1,0,1,0,0,0,91,253,146,0,200,149,1,0,224,22,1,0,1,0,0,0,92,253,146,0,56,126,1,0,160,14,1,0,1,0,0,0,93,253,146,0,32,101,1,0,176,9,1,0,1,0,0,0,94,253,146,0,96,32,8,0,200,3,1,0,1,0,0,0,95,253,146,0,16,68,7,0,88,212,3,0,1,0,0,0,144,217,146,0,40,185,3,0,32,77,1,0,1,0,0,0,2,245,146,0,216,70,1,0,16,17,8,0,1,0,0,0,3,245,146,0,224,12,8,0,120,166,8,0,9,0,0,0,28,224,146,0,32,58,1,0,232,150,8,0,9,0,0,0,29,224,146,0,32,58,1,0,56,55,48,95,109,50,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,251,191,109,67,1,0,16,1,56,55,48,95,109,50,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,106,157,199,177,1,0,16,1,56,55,48,95,102,48,51,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,39,199,69,166,3,0,16,1,56,55,48,95,102,49,52,46,100,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,21,102,180,201,4,0,16,1,56,55,48,99,49,56,46,112,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,232,127,146,7,5,0,32,0,56,55,48,99,49,55,46,112,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,248,159,201,43,5,0,32,0,56,55,48,99,49,54,46,112])
.concat([49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,27,106,223,65,5,0,32,0,56,55,48,99,49,53,46,112,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,129,146,140,5,0,32,0,56,55,48,95,99,48,49,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,70,101,249,106,7,0,32,0,56,55,48,95,99,48,50,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,109,44,225,84,8,0,32,0,102,114,101,101,122,101,46,102,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,101,22,67,10,1,0,16,1,102,114,101,101,122,101,46,102,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,173,184,137,17,1,0,16,1,102,114,101,101,122,101,46,102,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,234,165,196,16,1,0,16,1,102,114,101,101,122,101,46,102,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,83,76,2,22,1,0,16,1,102,114,101,101,122,101,46,102,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,101,7,11,234,1,0,16,1,102,114,101,101,122,101,46,101,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,11,192,85,17,1,0,16,1,102,114,101,101,122,101,46,101,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,117,141,193,149,1,0,16,1,102,114,101,101,122,101,46,101,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,252,90,143,126,1,0,16,1,102,114,101,101,122,101,46,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,185,245,113,119,2,0,16,1,102,114,101,101,122,101,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,160,152,138,108,3,0,32,0,102,114,101,101,122,101,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,228,37,33,109,3,0,32,0,102,114,101,101,122,101,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,169,47,127,58,3,0,32,0,102,114,101,101,122,101,46,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,214,221,112,221,3,0,32,0,116,118,103,45,49,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,146,211,11,44,1,0,16,1,116,118,103,45,50,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,2,254,110,184,1,0,16,1,116,118,103,45,51,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,244,111,104,253,1,0,16,1,116,118,103,45,52,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,93,53,21,20,1,0,16,1,116,118,103,45,53,46,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,14,180,189,34,2,0,16,1,116,118,103,45,54,46,49,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,105,162,138,220,3,0,32,0,116,118,103,45,55,46,49,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,186,254,158,14,3,0,32,0,116,118,103,45,56,46,49,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,122,8,201,69,3,0,32,0,116,118,103,49,55,95,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,197,243,148,197,4,0,32,0,116,118,103,49,55,95,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,78,11,81,46,4,0,32,0,116,118,103,49,55,95,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,117,39,1,53,4,0,32,0,112,114,111,109,49,55,95,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,236,59,205,219,5,0,32,0,112,114,111,109,49,55,95,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,207,182,183,158,5,0,32,0,112,114,111,109,49,55,95,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,243,167,48,155,5,0,32,0,112,114,111,109,49,55,95,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,157,97,46,150,5,0,32,0,112,114,111,109,49,55,95,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,140,20,245,177,5,0,32,0,112,114,111,109,49,55,95,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,12,243,10,202,6,0,0,8,112,114,111,109,49,55,95,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,116,81,197,243,6,0,0,8,184,40,2,0,1,0,0,0,85,0,147,0,248,191,2,0,184,164,8,0,1,0,0,0,86,0,147,0,64,246,1,0,56,250,6,0,1,0,0,0,189,247,146,0,184,160,2,0,88,149,7,0,1,0,0,0,191,247,146,0,136,224,1,0,56,210,6,0,1,0,0,0,80,0,147,0,192,135,2,0,152,122,6,0,1,0,0,0,81,0,147,0,96,82,2,0,192,72,6,0,1,0,0,0,82,0,147,0,32,56,2,0,24,163,6,0,1,0,0,0,83,0,147,0,240,108,2,0,200,110,3,0,1,0,0,0,188,247,146,0,152,30,2,0,176,223,1,0,1,0,0,0,184,247,146,0,72,198,1,0,24,198,1,0,1,0,0,0,185,247,146,0,40,167,1,0,120,189,1,0,1,0,0,0,186,247,146,0,200,149,1,0,192,209,1,0,1,0,0,0,187,247,146,0,24,182,1,0,224,22,1,0,1,0,0,0,191,247,146,0,56,126,1,0,88,212,3,0,1,0,0,0,128,219,146,0,40,185,3,0,56,58,1,0,1,0,0,0,86,0,147,0,64,50,1,0,64,23,5,0,9,0,0,0,202,5,147,0,32,58,1,0,104,20,5,0,9,0,0,0,200,5,147,0,32,58,1,0,216,16,5,0,9,0,0,0,201,5,147,0,32,58,1,0,101,115,112,103,97,108,117,100,97,95,118,49,48,48,46,117,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,52,236,236,8,1,0,16,1,116,48,52,56,48,49,119,48,54,52,46,117,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,158,199,33,96,2,0,32,0,97,48,52,56,48,49,119,48,54,52,46,117,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,50,73,221,38,3,0,32,0,97,48,52,56,48,50,119,48,54,52,46,117,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,169,247,107,14,3,0,32,0,98,48,52,56,48,49,119,48,54,52,46,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,58,225,220,152,4,0,32,0,119,48,52,56,48,49,98,48,51,50,46,117,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,54,133,41,96,5,0,64,0,101,115,112,103,97,108,95,105,103,115,48,50,55,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,7,0,16,17,50,48,48,49,46,117,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,146,237,171,92,1,0,16,1,50,48,48,49,46,117,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,147,240,124,178,2,0,32,0,50,48,48,49,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,60,115,28,209,3,0,32,0,50,48,48,49,46,117,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,242,174,53,20,3,0,32,0,50,48,48,49,46,117,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,114,165,188,204,4,0,32,0,50,48,48,49,46,117,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,33,47,166,78,5,0,64,0,100,119,50,48,48,49,95,105,103,115,48,50,55,97,95,106,97,112,97,110,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,155,21,121,58,7,0,16,0,50,48,48,49,46,117,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,171,177,61,151,8,0,16,1,49,53,46,117,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,59,118,141,11,1,0,16,1,49,54,46,117,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,101,77,111,32,1,0,16,1,50,48,46,117,56,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,255,134,77,77,2,0,32,0,49,57,46,117,56,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,226,191,236,73,2,0,32,0,49,56,46,117,56,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,33,201,229,142,2,0,32,0,49,55,46,117,56,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,28,75,4,66,2,0,32,0,49,52,46,117,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,20,150,71,3,0,64,0,0,0,0,0,0,0,0,0,100,114,97,103,111,110,118,49,48,48,120,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,29,133,113,94,1,0,16,1,112,103,109,116,48,50,48,48,46,117,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,77,83,246,176,2,0,32,0,112,103,109,97,48,50,48,48,46,117,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,105,80,185,19,3,0,32,0,112,103,109,98,48,50,48,48,46,117,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,19,15,45,147,4,0,32,0,118,45,49,48,48,106,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,62,57,248,248,1,0,16,1,112,103,109,116,48,50,48,48,46,117,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,77,83,246,176,2,0,32,0,112,103,109,97,48,50,48,48,46,117,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,105,80,185,19,3,0,32,0,112,103,109,98,48,50,48,48,46,117,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,19,15,45,147,4,0,32,0,118,45,49,48,48,99,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,129,121,70,103,1,0,16,1,112,103,109,116,48,50,48,48,46,117,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,77,83,246,176,2,0,32,0,112,103,109,97,48,50,48,48,46,117,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,105,80,185,19,3,0,32,0,112,103,109,98,48,50,48,48,46,117,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,19,15,45,147,4,0,32,0,99,95,53,101,116,95,103,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,139,184,112,186,1,0,0,0,99,95,53,99,116,95,103,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,236,97,196,94,1,0,0,0,99,95,53,98,116,95,103,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,36,211,151,28,1,0,0,0,99,95,53,97,116,95,103,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,192,90,0,185,1,0,0,0,100,50,107,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,13,202,149,110,2,0,0,0,115,95,51,105,95,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,6,237,164,69,3,0,0,0,115,95,51,106,95,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,146,254,67,71,3,0,0,0,118,95,53,104,95,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,93,201,200,18,4,0,0,0,118,95,51,112,116,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,233,197,233,21,4,0,0,0,108,95,52,109,95,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,77,5,248,89,5,0,0,0,108,95,52,110,95,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,20,71,46,103,5,0,0,0,108,95,52,114,95,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,238,89,170,254,5,0,0,0,108,95,52,115,95,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,126,239,242,32,5,0,0,0,99,45,50,107,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,229,237,115,226,6,0,0,0,99,45,50,106,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,88,35,65,214,6,0,0,0,118,45,53,101,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,245,184,105,184,6,0,0,0,99,95,53,102,95,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,17,43,79,66,1,0,0,0,99,95,53,99,116,95,103,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,236,97,196,94,1,0,0,0,99,95,53,104,95,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,93,137,40,29,1,0,0,0,116,107,103,51,99,46,53,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,187,137,59,85,1,0,0,0,115,95,51,105,95,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,6,237,164,69,2,0,0,0,115,95,51,106,95,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,146,254,67,71,2,0,0,0,118,95,53,104,95,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,93,201,200,18,3,0,0,0,118,95,51,112,116,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,233,197,233,21,3,0,0,0,108,95,52,109,95,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,77,5,248,89,4,0,0,0,108,95,52,110,95,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,20,71,46,103,4,0,0,0,108,95,52,114,95,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,238,89,170,254,4,0,0,0,108,95,52,115,95,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,126,239,242,32,4,0,0,0,99,45,50,107,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,229,237,115,226,5,0,0,0,99,45,50,106,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,88,35,65,214,5,0,0,0,118,45,53,101,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,245,184,105,184,5,0,0,0,99,95,53,102,95,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,17,43,79,66,1,0,0,0,53,103,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,155,89,38,211,1,0,0,0,53,104,46,99,112,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,137,172,49,255,1,0,0,0,99,95,53,107,95,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,7,96,77,57,1,0,0,0,115,95,51,105,95,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,6,237,164,69,2,0,0,0,115,95,51,106,95,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,146,254,67,71,2,0,0,0,118,95,53,104,95,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,93,201,200,18,3,0,0,0,118,95,53,107,95,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,20,249,132,54,3,0,0,0,108,95,52,109,95,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,77,5,248,89,4,0,0,0,108,95,52,110,95,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,20,71,46,103,4,0,0,0,108,95,52,114,95,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,238,89,170,254,4,0,0,0,108,95,52,115,95,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,126,239,242,32,4,0,0,0,99,45,50,107,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,229,237,115,226,5,0,0,0,99,45,50,106,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,88,35,65,214,5,0,0,0,118,45,53,101,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,245,184,105,184,5,0,0,0,100,107,95,102,46,53,101,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,175,239,183,0,1,0,0,0,100,107,95,102,46,53,99,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,105,155,175,136,1,0,0,0,100,107,95,102,46,53,98,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,145,173,116,222,1,0,0,0,100,107,95,102,46,53,97,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,32,212,107,106,1,0,0,0,115,95,51,105,95,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,6,237,164,69,2,0,0,0,115,95,51,106,95,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,146,254,67,71,2,0,0,0,118,95,53,104,95,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,93,201,200,18,3,0,0,0,118,95,51,112,116,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,233,197,233,21,3,0,0,0,108,95,52,109,95,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,77,5,248,89,4,0,0,0,108,95,52,110,95,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,20,71,46,103,4,0,0,0,108,95,52,114,95,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,238,89,170,254,4,0,0,0,108,95,52,115,95,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,126,239,242,32,4,0,0,0,99,45,50,107,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,229,237,115,226,5,0,0,0,99,45,50,106,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,88,35,65,214,5,0,0,0,118,45,53,101,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,245,184,105,184,5,0,0,0,100,107,51,99,46,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,142,243,213,56,1,0,0,0,100,107,51,99,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,121,67,19,201,1,0,0,0,100,107,51,99,46,55,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,33,41,46,210,1,0,0,0,100,107,51,99,46,55,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,183,20,95,97,1,0,0,0,100,107,51,99,46,53,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,133,136,248,127,2,0,0,0,100,107,51,99,46,54,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,12,32,215,54,3,0,0,0,100,107,51,118,46,51,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,199,153,90,65,4,0,0,0,100,107,51,118,46,51,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,160,78,116,37,4,0,0,0,100,107,51,118,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,55,23,250,143,5,0,0,0,100,107,51,118,46,55,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,134,70,200,154,5,0,0,0,100,107,51,118,46,55,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,251,243,10,12,5,0,0,0,100,107,51,118,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,98,134,197,85,5,0,0,0,100,107,99,49,45,99,46,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,252,190,84,223,6,0,0,0,100,107,99,49,45,99,46,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,64,127,167,102,6,0,0,0,100,107,99,49,45,118,46,50,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,52,52,227,80,6,0,0,0,100,107,99,49,45,118,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,248,234,226,211,7,0,0,0,234,61,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,106,121,95,48,48,45,50,46,104,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,98,207,77,1,1,0,16,1,106,121,95,48,49,45,50,46,104,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,131,189,62,121,1,0,16,1,106,121,95,48,50,46,109,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,165,146,52,78,2,0,16,1,109,97,121,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,141,31,77,35,3,0,32,0,109,97,121,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,4,125,165,45,4,0,32,0,109,97,121,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,19,167,102,58,4,0,32,0,109,97,121,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,174,43,228,182,5,0,64,0,112,97,108,49,54,108,56,98,95,118,100,45,48,48,46,54,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,6,0,0,16,112,97,108,49,54,108,56,98,95,118,100,45,48,49,46,55,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,6,0,0,16,112,97,108,49,54,114,54,97,95,118,100,45,48,50,46,49,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,6,0,0,16,54,56,55,95,116,48,53,46,54,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,97,220,183,138,1,0,16,1,54,56,55,95,116,48,52,46,52,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,218,36,153,198,1,0,16,1,54,56,55,95,116,48,57,46,54,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,224,125,233,250,1,0,16,1,54,56,55,95,116,48,56,46,52,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,103,141,137,140,1,0,16,1,54,56,55,95,113,48,55,46,49,48,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,11,12,17,83,2,0,16,1,54,56,55,95,113,48,54,46,56,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,197,160,83,156,2,0,16,1,54,56,55,95,113,49,51,46,49,48,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,20,96,174,54,2,0,16,1,54,56,55,95,113,49,50,46,56,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,103,33,1,109,2,0,16,1,54,56,55,95,108,48,51,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,60,152,1,114,3,0,16,1,54,56,55,95,109,49,52,46,100,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,87,133,51,215,4,0,32,0,54,56,55,105,49,55,46,112,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,35,57,203,102,5,0,32,0,54,56,55,105,49,56,46,112,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,219,208,199,161,5,0,32,0,54,56,55,105,49,53,46,112,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,178,197,200,238,5,0,32,0,54,56,55,105,49,54,46,112,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,139,244,108,116,5,0,32,0,54,56,55,95,108,49,49,46,49,48,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,232,238,157,57,6,0,32,0,54,56,55,95,108,49,48,46,56,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,238,145,124,17,6,0,32,0,54,56,55,95,105,48,49,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,251,45,153,212,7,0,64,0,54,56,55,95,105,48,50,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,1,117,148,229,8,0,64,0,2,78,117,0,0,0,0,0,76,85,78,65,0,0,0,0,116,48,48,49,46,117,112,97,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,44,185,20,1,0,16,1,116,48,48,50,46,117,112,97,108,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,104,92,176,15,1,0,16,1,116,48,48,51,46,117,122,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,160,175,223,139,2,0,16,1,116,49,48,49,46,117,97,104,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,69,248,186,116,3,0,32,0,116,49,48,50,46,117,97,108,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,163,196,2,26,3,0,32,0,116,49,48,51,46,117,98,108,49,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,136,218,231,132,3,0,32,0,116,49,48,52,46,117,99,108,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,26,97,235,102,3,0,32,0,116,51,48,49,46,117,98,100,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,119,97,2,139,4,0,32,0,116,50,48,49,46,117,98,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,172,135,160,213,6,0,32,0,116,50,48,50,46,117,98,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,225,218,81,240,7,0,32,0,116,52,48,49,46,117,121,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,146,25,17,146,8,0,64,0,116,53,48,49,46,117,97,100,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,254,188,47,9,0,64,0,100,101,114,111,111,110,95,54,56,104,99,49,49,97,56,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,16,100,101,114,111,111,110,95,54,56,104,99,49,49,97,56,46,101,101,112,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,16,117,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,99,53,111,224,0,0,16,1,117,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,214,187,107,114,0,0,16,1,117,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,85,20,114,171,0,0,16,1,117,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,228,3,185,221,0,0,16,1,56,50,115,49,50,51,46,117,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,32,16,118,49,48,50,46,117,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,64,160,158,90,1,0,16,1,100,100,112,50,95,105,103,115,48,50,55,97,95,104,111,110,103,95,107,111,110,103,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,206,202,209,167,7,0,16,1,116,49,51,48,48,46,117,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,203,240,72,231,2,0,32,0,97,49,51,48,48,46,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,5,164,135,252,3,0,32,0,97,49,51,48,49,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,218,32,133,12,3,0,32,0,98,49,51,48,48,46,117,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,4,102,100,239,4,0,32,0,109,49,51,48,48,46,117,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,93,1,212,130,5,0,64,0,118,49,48,48,46,117,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,41,221,195,6,8,0,16,1,46,0,0,0,255,255,4,0,0,0,0,0,0,0,0,0,164,150,95,192,171,73,159,25,132,230,214,202,0,0,0,0,0,0,0,0,0,0,0,0,100,98,45,97,45,104,48,45,46,53,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,103,114,23,225,1,0,16,1,100,98,45,97,45,108,48,45,46,54,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,126,22,43,216,1,0,16,1,100,98,45,97,45,115,112,45,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,96,21,166,84,6,0,16,1,100,98,95,107,56,48,48,109,46,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,207,168,39,192,2,0,32,0,100,98,95,107,56,48,49,109,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,51,175,63,9,2,0,32,0,100,98,95,107,56,48,50,109,46,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,89,76,91,5,2,0,32,0,100,98,95,107,56,48,51,109,46,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,34,57,214,142,2,0,32,0,100,98,95,107,56,48,52,109,46,97,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,46,233,131,76,3,0,32,0,100,98,95,107,56,48,53,109,46,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,104,242,94,131,3,0,32,0,100,98,95,107,56,48,54,109,46,97,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,20,241,23,81,3,0,32,0,100,98,95,107,56,48,55,109,46,97,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,120,201,176,142,3,0,32,0,100,98,95,97,45,118,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,130,114,47,49,5,0,64,0,3,2,0,72,0,0,0,0,0,0,0,0,0,0,0,0,52,95,112,114,111,103,95,108,46,117,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,9,70,11,102,1,0,16,1,51,95,112,114,111,103,95,104,46,117,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,246,156,122,1,0,16,1,112,114,111,103,46,117,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,144,233,66,55,1,0,16,1,48,108,46,117,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,39,132,93,86,2,0,32,0,48,104,46,117,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,48,38,96,154,2,0,32,0,49,108,46,117,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,225,232,92,172,2,0,32,0,49,104,46,117,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,123,159,165,176,2,0,32,0,50,108,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,178,3,170,45,2,0,32,0,50,104,46,117,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,90,24,142,233,2,0,32,0,51,108,46,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,161,42,55,29,2,0,32,0,51,104,46,117,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,21,63,127,89,2,0,32,0,52,108,46,117,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,216,140,213,227,2,0,32,0,52,104,46,117,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,208,156,188,174,2,0,32,0,53,108,46,117,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,11,165,181,234,2,0,32,0,53,104,46,117,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,79,71,87,241,2,0,32,0,54,108,46,117,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,27,141,0,159,2,0,32,0,54,104,46,117,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,227,208,210,172,2,0,32,0,115,111,117,110,100,46,117,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,29,120,44,239,3,0,64,0,101,101,112,114,111,109,45,100,97,114,97,107,117,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,151,82,113,169,0,0,0,8,102,103,49,45,48,48,49,46,117,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,74,231,74,16,1,0,16,1,102,103,49,45,48,48,50,46,117,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,103,78,154,227,1,0,16,1,102,103,49,45,48,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,62,83,176,154,3,0,32,0,102,103,49,45,48,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,226,81,157,28,3,0,32,0,102,103,49,45,48,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,185,89,81,194,4,0,32,0,102,103,49,45,48,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,154,195,82,32,5,0,32,0,102,103,49,45,48,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,224,233,47,74,6,0,64,0,49,49,49,48,53,45,48,46,48,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,41,84,66,221,1,0,16,1,49,49,49,48,53,45,49,46,49,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,239,158,216,249,1,0,16,1,49,49,49,48,53,45,50,46,50,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,39,58,194,64,1,0,16,1,49,49,49,48,53,45,51,46,51,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,79,100,2,88,1,0,16,1,49,49,49,48,53,45,52,46,52,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,218,210,186,145,2,0,32,0,49,49,49,48,53,45,53,46,53,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,118,67,193,181,2,0,32,0,55,52,115,50,56,56,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,70,68,52,255,3,0,32,0,50,52,115,49,48,46,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,39,185,239,99,3,0,32,0,14,0,0,0,255,255,255,0,0,0,0,0,15,0,0,0,255,255,255,0,0,0,0,0,16,0,0,0,255,255,255,0,0,0,0,0,17,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,184,109,3,0,15,0,0,0,1,16,16,0,96,135,7,0,15,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,16,0,200,87,7,0,17,0,0,0,1,15,8,0,160,36,8,0,17,0,0,0,1,15,9,0,184,107,3,0,17,0,0,0,1,15,0,0,208,239,7,0,17,0,0,0,1,15,10,0,16,79,1,0,17,0,0,0,1,15,11,0,64,104,3,0,17,0,0,0,1,15,1,0,184,107,3,0,17,0,0,0,1,15,12,0,32,15,1,0,17,0,0,0,1,15,13,0,152,100,3,0,17,0,0,0,1,15,2,0,136,23,1,0,17,0,0,0,1,15,14,0,144,97,3,0,17,0,0,0,1,15,15,0,232,95,3,0,17,0,0,0,1,15,3,0,88,217,6,0,17,0,0,0,1,15,4,0,32,15,1,0,17,0,0,0,1,15,5,0,80,177,6,0,17,0,0,0,1,15,6,0,144,88,3,0,17,0,0,0,1,15,7,0,128,87,3,0,0,0,0,0,254,0,16,0,160,123,6,0,17,0,0,0,1,240,128,0,160,36,8,0,17,0,0,0,1,240,144,0,184,107,3,0,17,0,0,0,1,240,0,0,208,239,7,0,17,0,0,0,1,240,160,0,16,79,1,0,17,0,0,0,1,240,176,0,64,104,3,0,17,0,0,0,1,240,16,0,184,107,3,0,17,0,0,0,1,240,192,0,32,15,1,0,17,0,0,0,1,240,208,0,152,100,3,0,17,0,0,0,1,240,32,0,136,23,1,0,17,0,0,0,1,240,224,0,144,97,3,0,17,0,0,0,1,240,240,0,232,95,3,0,17,0,0,0,1,240,48,0,88,217,6,0,17,0,0,0,1,240,64,0,32,15,1,0,17,0,0,0,1,240,80,0,80,177,6,0,17,0,0,0,1,240,96,0,144,88,3,0,17,0,0,0,1,240,112,0,128,87,3,0,0,0,0,0,99,114,116,119,116,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,247,33,189,173,1,0,16,1,99,114,116,119,116,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,234,169,80,66,2,0,32,0,56,50,115,49,50,51,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,189,80,198,47,3,0,32,0,56,50,115,49,50,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,57,211,197,43,3,0,32,0,56,50,115,49,50,54,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,134,204,169,4,0,64,0,56,50,115,49,50,54,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,117,110,107,109,111,108,46,52,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,223,13,21,73,1,0,16,1,117,110,107,109,111,108,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,23,126,244,33,1,0,16,1,117,110,107,109,111,108,46,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,146,213,109,155,1,0,16,1,117,110,107,109,111,108,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,82,20,92,117,1,0,16,1,117,110,107,109,111,108,46,52,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,18,163,48,237,1,0,16,1,117,110,107,109,111,108,46,54,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,235,176,75,254,1,0,16,1,117,110,107,109,111,108,46,52,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,201,145,43,7,1,0,16,1,117,110,107,109,111,108,46,54,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,125,160,251,102,1,0,16,1,117,110,107,109,111,108,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,160,128,136,51,2,0,32,0,117,110,107,109,111,108,46,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,31,200,233,76,2,0,32,0,117,110,107,109,111,108,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,128,55,46,117,2,0,32,0,117,110,107,109,111,108,46,53,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,172,210,0,110,2,0,32,0,56,50,115,49,50,51,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,189,80,198,47,3,0,32,0,50,115,49,52,48,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,39,185,239,99,3,0,32,0,56,50,115,49,50,54,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,134,204,169,4,0,64,0,56,50,115,49,50,54,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,116,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,46,89,118,242,1,0,16,1,116,112,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,190,42,48,61,1,0,16,1,116,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,112,46,244,37,1,0,16,1,116,112,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,190,156,39,152,1,0,16,1,116,112,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,203,180,119,131,1,0,16,1,116,112,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,140,108,231,216,1,0,16,1,116,112,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,163,143,178,144,1,0,16,1,116,112,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,27,78,133,16,1,0,16,1,116,112,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,152,113,97,199,2,0,32,0,116,112,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,106,215,41,225,2,0,32,0,116,112,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,5,159,137,209,2,0,32,0,116,112,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,175,28,93,211,2,0,32,0,56,50,115,49,50,51,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,189,80,198,47,3,0,32,0,50,115,49,52,48,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,39,185,239,99,3,0,32,0,56,50,115,49,50,54,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,134,204,169,4,0,64,0,56,50,115,49,50,54,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,98,57,57,45,48,55,46,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,230,134,232,38,2,0,0,0,98,57,57,45,48,53,46,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,157,154,127,255,2,0,0,0,98,57,57,45,48,54,46,51,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,146,170,38,31,2,0,0,0,98,57,57,45,49,52,46,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,215,180,200,113,2,0,0,0,98,57,57,45,48,56,46,52,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,81,84,19,38,9,0,0,0,98,57,57,45,48,50,46,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,38,74,93,42,11,0,0,0,98,57,57,45,48,49,46,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,58,55,158,161,11,0,0,0,98,57,57,45,48,51,46,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,247,13,161,221,24,0,0,0,168,86,7,0,1,0,0,0,152,48,216,0,248,191,2,0,24,38,7,0,1,0,0,0,156,48,216,0,184,160,2,0,56,210,6,0,1,0,0,0,160,48,216,0,192,135,2,0,24,163,6,0,1,0,0,0,161,48,216,0,240,108,2,0,152,122,6,0,1,0,0,0,162,48,216,0,96,82,2,0,192,72,6,0,1,0,0,0,163,48,216,0,32,56,2,0,152,226,4,0,1,0,0,0,164,48,216,0,152,30,2,0,168,190,4,0,1,0,0,0,165,48,216,0,232,10,2,0,240,158,4,0,1,0,0,0,166,48,216,0,152,138,8,0,136,128,4,0,1,0,0,0,131,48,216,0,48,119,7,0,176,101,4,0,1,0,0,0,130,48,216,0,112,109,7,0,136,75,4,0,1,0,0,0,129,48,216,0,24,133,7,0,40,246,1,0,1,0,0,0,153,48,216,0,64,246,1,0,144,236,1,0,1,0,0,0,157,48,216,0,136,224,1,0,176,223,1,0,1,0,0,0,168,48,216,0,72,198,1,0,192,209,1,0,1,0,0,0,169,48,216,0,24,182,1,0,24,198,1,0,1,0,0,0,170,48,216,0,40,167,1,0,120,189,1,0,1,0,0,0,171,48,216,0,200,149,1,0,40,126,1,0,1,0,0,0,172,48,216,0,56,126,1,0,0,112,1,0,1,0,0,0,173,48,216,0,32,101,1,0,0,101,1,0,1,0,0,0,174,48,216,0,96,32,8,0,248,91,1,0,1,0,0,0,132,48,216,0,16,68,7,0,128,85,1,0,1,0,0,0,133,48,216,0,240,58,7,0,248,76,1,0,1,0,0,0,154,48,216,0,200,42,1,0,88,212,3,0,1,0,0,0,224,121,145,0,40,185,3,0,240,152,1,0,1,0,0,0,145,48,216,0,216,70,1,0,16,17,8,0,1,0,0,0,144,48,216,0,224,12,8,0,48,45,3,0,9,0,0,0,16,122,145,0,32,58,1,0,54,51,51,109,48,51,46,49,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,218,225,69,208,1,0,16,1,54,51,51,105,48,50,46,49,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,154,189,247,178,1,0,16,1,54,51,51,101,48,49,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,85,146,84,209,2,0,16,1,54,51,51,101,48,52,46,55,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,66,197,221,20,3,0,32,0,54,51,51,101,48,53,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,68,80,24,66,3,0,32,0,54,51,51,101,48,54,46,49,54,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,174,250,246,156,4,0,32,0,54,51,51,101,48,55,46,49,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,56,102,208,242,4,0,32,0,54,51,51,101,48,56,46,49,48,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,250,73,9,159,5,0,32,0,54,51,51,101,48,57,46,49,50,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,25,94,202,20,5,0,32,0,54,51,51,102,49,48,46,49,56,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,132,77,36,43,5,0,32,0,54,51,51,102,49,49,46,50,48,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,25,94,202,20,5,0,32,0,48,48,55,55,54,54,46,50,48,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,16,103,110,45,48,50,45,51,46,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,42,161,174,57,1,0,16,1,103,110,45,48,53,45,50,46,51,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,239,96,67,15,1,0,16,1,103,110,45,48,49,45,50,46,49,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,126,239,64,247,1,0,16,1,103,110,45,48,52,45,50,46,51,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,98,203,143,201,1,0,16,1,103,110,45,48,48,46,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,22,11,17,11,1,0,16,1,103,110,45,48,51,46,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,151,230,40,30,1,0,16,1,103,108,45,48,55,46,49,51,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,150,239,139,202,2,0,16,1,103,108,45,48,56,46,54,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,180,162,51,3,0,32,0,103,108,45,48,57,46,54,122,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,82,71,45,90,3,0,32,0,109,97,103,45,48,50,46,52,122,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,154,198,137,222,4,0,32,0,109,97,103,45,48,48,46,49,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,51,93,240,168,5,0,32,0,109,97,103,45,48,49,46,49,122,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,237,158,57,91,5,0,32,0,109,97,103,45,48,51,46,57,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,159,235,32,34,6,0,32,0,109,97,103,45,48,53,46,49,50,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,84,50,165,86,6,0,32,0,109,97,103,45,48,52,46,57,122,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,204,148,75,20,6,0,32,0,109,97,103,45,48,54,46,49,50,122,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,73,71,212,130,6,0,32,0,103,108,45,48,54,46,49,51,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,157,81,46,217,7,0,64,0,109,97,103,45,48,55,46,49,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,100,82,235,8,8,0,64,0,109,98,55,49,50,50,104,46,55,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,54,115,38,161,0,0,0,8,99,50,49,45,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,251,19,175,93,2,0,16,1,99,50,49,45,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,117,46,170,203,2,0,16,1,99,50,49,45,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,233,14,158,107,2,0,16,1,99,50,49,45,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,138,87,154,191,2,0,16,1,99,50,49,45,48,56,46,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,160,149,164,220,9,0,16,1,99,50,49,45,48,50,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,185,131,88,32,11,0,32,0,99,50,49,45,48,49,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,156,243,246,31,15,0,32,0,99,50,49,45,48,55,46,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,189,146,34,240,0,0,16,8,112,97,108,49,54,108,56,98,45,99,50,49,45,48,57,46,105,99,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,103,41,75,0,0,0,8,112,97,108,49,54,108,56,98,45,99,50,49,45,49,48,46,105,99,52,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,47,100,53,0,0,0,8,112,97,108,49,54,108,56,98,45,99,50,49,45,49,49,45,49,46,105,99,52,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,36,30,121,244,0,0,0,8,112,97,108,50,48,108,56,98,45,99,50,49,45,49,50,46,105,99,52,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,1,0,0,151,204,194,187,0,0,0,8,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,47,255,178,21,1,0,16,1,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,106,164,139,91,1,0,16,1,105,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,157,201,123,235,3,0,32,0,115,45,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,185,98,233,252,4,0,32,0,115,45,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,188,143,118,22,4,0,32,0,115,45,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,184,129,23,188,5,0,32,0,115,45,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,94,136,35,248,5,0,32,0,115,45,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,175,7,132,40,6,0,64,0,115,45,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,126,58,227,67,7,0,64,0,97,53,51,95,48,53,46,105,99,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,139,240,163,99,1,0,16,1,97,53,51,95,48,54,46,105,99,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,8,203,13,203,1,0,16,1,97,53,51,95,48,55,46,105,99,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,119,154,246,114,2,0,16,1,97,53,51,95,48,56,46,105,99,53,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,249,57,81,248,3,0,16,1,97,53,51,95,48,49,46,105,99,56,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,178,127,207,56,4,0,32,0,97,53,51,95,48,50,46,105,99,56,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,254,173,167,220,4,0,32,0,97,53,51,95,48,51,46,105,99,56,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,151,185,62,175,4,0,32,0,97,53,51,95,48,52,46,105,99,56,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,211,114,175,101,4,0,32,0,97,53,52,45,49,48,46,105])
.concat([99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,217,34,151,54,5,0,0,8,97,53,49,95,48,57,46,105,99,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,70,136,139,14,6,0,16,8,48,48,50,45,112,103,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,245,181,0,193,1,0,16,1,48,48,50,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,198,208,127,26,2,0,32,0,48,48,50,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,69,42,255,170,3,0,32,0,48,48,50,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,228,247,160,59,3,0,32,0,48,48,50,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,250,253,240,150,3,0,32,0,48,48,50,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,47,127,216,95,3,0,32,0,48,48,50,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,59,216,126,128,3,0,32,0,48,48,50,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,65,173,60,90,3,0,32,0,48,48,50,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,238,164,202,78,4,0,16,1,48,48,50,45,118,49,49,46,118,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,189,37,185,183,5,0,64,0,48,48,50,45,118,49,50,46,118,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,252,38,159,50,5,0,64,0,48,48,50,45,118,49,51,46,118,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,200,243,57,12,5,0,64,0,48,48,50,45,118,49,52,46,118,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,56,28,225,199,5,0,64,0,48,48,50,45,118,50,49,46,118,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,209,51,167,4,6,0,64,0,57,51,48,56,55,45,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,45,78,200,147,1,0,16,1,57,51,48,56,55,45,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,138,103,255,48,1,0,16,1,57,51,48,56,55,45,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,124,223,19,170,3,0,32,0,57,51,48,56,55,45,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,208,38,79,138,4,0,32,0,57,51,48,56,55,45,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,93,36,6,187,5,0,32,0,57,51,48,56,55,45,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,221,70,45,55,6,0,64,0,57,51,48,56,55,45,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,8,120,166,141,7,0,64,0,56,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,201,177,58,99,0,0,0,8,57,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,162,83,86,67,0,0,0,8,97,54,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,173,248,88,58,1,0,16,1,99,54,46,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,162,30,198,254,1,0,16,1,97,52,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,59,120,146,51,1,0,16,1,99,52,46,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,61,216,145,35,1,0,16,1,99,49,46,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,79,245,107,143,2,0,32,0,99,51,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,64,84,181,16,2,0,32,0,110,56,50,115,49,50,51,110,46,49,48,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,70,68,52,255,3,0,32,0,110,56,50,115,49,50,57,110,46,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,39,185,239,99,3,0,32,0,110,56,50,115,49,50,57,110,46,52,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,134,204,169,4,0,64,0,110,56,50,115,49,50,57,110,46,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,117,97,48,50,46,105,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,61,2,148,158,1,0,16,1,117,97,48,51,46,105,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,216,168,207,8,1,0,16,1,117,115,48,50,46,112,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,250,5,204,199,2,0,16,1,117,115,48,56,46,113,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,222,243,216,133,3,0,64,0,117,99,48,55,32,112,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,84,153,41,61,4,0,32,0,117,99,48,56,46,109,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,14,195,192,47,4,0,32,0,117,99,50,57,46,107,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,33,195,96,2,4,0,32,0,117,99,50,56,46,110,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,190,56,153,4,0,32,0,117,100,49,52,46,106,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,110,105,28,20,5,0,32,0,117,100,49,53,46,104,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,192,173,4,124,5,0,32,0,117,100,49,54,46,103,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,118,234,130,50,5,0,32,0,117,100,49,55,46,101,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,26,63,58,58,5,0,32,0,98,102,45,117,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,123,81,252,58,1,0,16,1,98,102,45,117,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,208,118,189,141,1,0,16,1,98,101,97,115,116,102,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,52,220,84,86,2,0,32,0,98,101,97,115,116,102,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,97,202,48,27,2,0,32,0,103,108,111,98,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,39,117,97,31,3,0,32,0,103,108,111,98,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,105,167,250,40,3,0,32,0,56,50,115,49,50,54,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,134,204,169,4,0,64,0,56,50,115,49,50,54,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,104,0,160,31,198,6,56,56,83,198,6,58,56,65,198,6,60,56,77,198,6,62,56,79,198,6,64,56,84,198,6,66,56,79,104,0,176,31,198,6,0,9,182,198,6,0,10,182,198,6,0,11,182,198,6,0,0,52,104,0,208,31,198,6,112,22,119,234,104,1,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,98,98,109,50,45,104,48,45,98,46,55,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,9,55,125,86,1,0,16,1,98,98,109,50,45,108,48,45,98,46,55,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,43,194,98,231,1,0,16,1,98,98,109,50,45,115,112,46,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,158,104,193,107,2,0,16,1,98,98,109,50,45,99,48,46,56,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,138,5,206,231,3,0,32,0,98,98,109,50,45,99,49,46,56,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,169,120,106,99,3,0,32,0,98,98,109,50,45,99,50,46,56,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,47,20,194,154,3,0,32,0,98,98,109,50,45,99,51,46,56,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,80,23,175,71,3,0,32,0,98,98,109,50,45,118,48,46,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,237,137,216,74,4,0,64,0,98,98,49,50,46,109,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,69,194,1,69,1,0,16,1,98,98,49,49,46,108,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,96,91,228,85,1,0,16,1,98,98,49,51,46,110,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,117,129,247,30,2,0,16,1,54,56,55,48,53,46,117,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,3,0,16,16,98,98,49,46,103,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,184,188,45,182,4,0,32,0,98,98,52,46,100,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,248,229,125,183,5,0,32,0,98,98,53,46,100,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,191,204,255,255,5,0,32,0,98,98,50,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,54,50,177,165,5,0,32,0,98,98,51,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,61,56,91,227,5,0,32,0,98,98,54,46,104,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,206,169,173,12,6,0,32,0,98,98,56,46,106,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,193,231,95,213,6,0,32,0,98,98,55,46,104,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,59,213,82,163,6,0,32,0,98,98,57,46,106,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,172,133,209,120,6,0,32,0,98,98,49,48,46,108,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,249,152,100,208,7,0,32,0,98,98,95,112,114,111,109,46,101,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,54,174,128,236,8,0,0,8,48,51,48,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,203,201,150,211,1,0,16,1,48,51,48,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,252,184,21,112,2,0,32,0,48,51,48,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,189,25,94,79,3,0,32,0,48,51,48,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,240,75,49,214,3,0,32,0,48,51,48,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,238,223,253,71,3,0,32,0,48,51,48,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,78,28,13,120,3,0,32,0,48,51,48,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,236,102,244,76,4,0,16,1,48,51,48,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,78,54,202,212,5,0,64,0,48,51,48,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,85,68,153,84,5,0,64,0,112,114,103,48,95,101,117,114,111,112,101,46,117,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,117,233,211,145,0,0,16,1,112,114,103,50,46,117,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,191,95,170,189,0,0,16,1,112,114,103,49,98,46,117,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,146,180,112,142,0,0,16,1,112,114,103,51,46,117,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,65,249,169,122,0,0,16,1,114,111,109,45,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,162,156,246,13,0,0,32,0,114,111,109,45,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,56,125,22,96,0,0,32,0,114,111,109,45,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,147,165,254,27,0,0,32,0,114,111,109,45,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,148,60,224,190,0,0,32,0,115,110,100,46,117,55,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,150,38,104,86,0,0,16,1,114,111,109,45,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,246,218,116,66,0,0,64,0,114,111,109,45,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,38,36,28,42,0,0,64,0,98,54,56,45,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,187,27,170,30,2,0,16,1,98,54,56,45,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,96,110,201,140,2,0,16,1,98,54,56,45,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,16,155,165,211,1,0,16,1,98,54,56,45,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,8,181,120,195,9,0,16,1,98,54,56,45,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,148,44,243,137,11,0,32,0,98,54,56,45,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,211,140,1,245,15,0,32,0,98,54,56,45,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,200,172,19,193,16,0,32,0,98,54,56,45,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,77,230,23,245,16,0,32,0,98,54,56,45,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,64,175,122,56,26,0,64,0,99,52,51,45,49,53,46,53,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,198,214,5,93,2,0,0,0,99,52,51,45,49,51,46,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,119,216,183,117,2,0,0,0,99,52,51,45,49,52,46,52,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,125,243,231,237,2,0,0,0,99,52,51,45,49,50,46,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,160,75,138,176,2,0,0,0,99,52,51,45,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,225,252,38,203,9,0,0,0,99,52,51,45,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,174,34,87,16,11,0,0,0,99,52,51,45,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,186,6,102,66,11,0,0,0,99,52,51,45,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,55,63,149,219,24,0,0,0,48,54,46,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,226,21,144,15,1,0,16,1,48,49,46,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,197,247,111,129,1,0,16,1,48,55,46,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,165,68,49,91,1,0,16,1,48,50,46,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,157,194,16,250,1,0,16,1,97,102,95,48,56,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,54,212,209,1,0,16,1,97,102,95,48,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,45,254,225,187,1,0,16,1,97,102,95,49,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,135,203,234,197,2,0,16,1,48,57,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,213,147,105,92,3,0,32,0,97,102,95,48,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,79,175,211,68,4,0,32,0,97,102,95,48,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,171,108,7,146,4,0,32,0,97,102,95,49,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,167,197,93,140,5,0,32,0,97,102,95,49,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,163,88,106,19,5,0,32,0,97,102,95,49,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,60,71,108,180,6,0,32,0,97,102,95,49,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,254,107,203,35,6,0,32,0,97,49,46,105,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,157,93,184,49,0,0,16,1,97,50,46,103,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,138,216,40,131,0,0,16,1,97,51,46,102,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,181,122,181,141,0,0,16,1,97,52,46,101,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,164,210,52,74,0,0,16,1,102,97,50,46,110,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,186,52,241,231,0,0,32,0,102,97,49,46,109,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,158,150,16,173,0,0,32,0,97,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,17,245,39,95,0,0,32,0,98,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,59,253,3,27,0,0,0,8,49,51,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,15,151,126,84,0,0,0,8,49,52,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,231,140,42,98,0,0,0,8,56,55,53,95,106,48,50,46,101,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,113,9,194,86,1,0,16,1,56,55,53,95,106,48,49,46,99,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,214,156,82,106,1,0,16,1,56,55,53,95,98,48,51,46,103,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,131,210,196,26,2,0,16,1,56,55,53,98,49,49,46,107,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,133,200,197,137,3,0,32,0,56,55,53,98,48,55,46,106,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,102,109,197,233,3,0,32,0,56,55,53,98,49,50,46,107,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,23,220,107,234,3,0,32,0,56,55,53,98,48,56,46,106,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,102,121,56,249,3,0,32,0,56,55,53,98,49,48,46,107,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,177,53,16,11,4,0,32,0,56,55,53,98,48,54,46,106,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,102,5,26,8,4,0,32,0,56,55,53,98,48,57,46,107,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,25,60,107,231,4,0,32,0,56,55,53,98,48,53,46,106,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,242,97,162,25,4,0,32,0,56,55,53,98,48,52,46,101,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,200,154,32,78,5,0,64,0,56,50,49,97,48,56,46,104,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,88,165,125,6,0,0,8,112,97,108,99,111,49,46,56,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,122,145,204,58,1,0,16,1,112,97,108,99,111,50,46,57,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,204,91,253,171,1,0,16,1,112,97,108,99,111,51,46,55,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,125,201,33,42,2,0,16,1,112,97,108,99,111,52,46,55,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,254,156,253,157,3,0,64,0,56,50,115,49,50,57,112,114,46,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,167,189,91,178,0,0,0,8,97,99,97,95,117,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,220,47,28,38,1,0,16,1,97,99,97,95,117,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,202,180,250,5,1,0,16,1,97,99,97,95,53,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,201,210,45,127,2,0,32,0,97,99,97,95,55,102,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,68,183,59,19,3,0,32,0,97,99,97,95,52,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,143,32,41,142,3,0,32,0,56,50,115,49,50,54,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,134,204,169,4,0,64,0,56,50,115,49,50,54,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,10,0,0,0,255,255,255,0,0,0,0,0,11,0,0,0,255,255,255,0,0,0,0,0,12,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,16,0,24,153,4,0,11,0,0,0,1,30,30,0,8,49,4,0,11,0,0,0,1,30,28,0,152,21,4,0,11,0,0,0,1,30,26,0,72,246,3,0,11,0,0,0,1,30,24,0,72,0,3,0,11,0,0,0,1,30,22,0,64,47,7,0,11,0,0,0,1,30,20,0,232,99,5,0,11,0,0,0,1,30,18,0,80,62,6,0,11,0,0,0,1,30,16,0,208,7,8,0,11,0,0,0,1,30,14,0,168,148,4,0,11,0,0,0,1,30,12,0,176,2,8,0,11,0,0,0,1,30,10,0,160,142,4,0,11,0,0,0,1,30,7,0,216,138,4,0,11,0,0,0,1,30,6,0,216,202,4,0,11,0,0,0,1,30,4,0,240,28,4,0,11,0,0,0,1,30,2,0,216,127,4,0,11,0,0,0,1,30,0,0,80,0,4,0,0,0,0,0,254,0,2,0,168,234,7,0,11,0,0,0,1,32,32,0,96,135,7,0,11,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,97,115,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,2,35,16,11,1,0,16,1,97,115,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,236,168,22,49,1,0,16,1,97,115,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,224,129,2,188,1,0,16,1,97,115,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,232,226,142,66,1,0,16,1,97,115,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,173,70,93,224,1,0,16,1,97,115,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,203,168,233,58,1,0,16,1,97,115,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,64,185,158,179,1,0,16,1,97,115,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,103,28,207,22,1,0,16,1,97,115,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,229,171,218,97,2,0,32,0,97,115,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,152,12,213,129,2,0,32,0,97,115,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,19,22,189,163,2,0,32,0,97,115,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,104,43,128,157,2,0,32,0,56,50,115,49,50,51,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,189,80,198,47,3,0,32,0,97,115,52,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,36,179,5,22,3,0,32,0,56,50,115,49,50,54,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,134,204,169,4,0,64,0,56,50,115,49,50,54,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,117,101,49,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,200,63,108,218,0,0,16,1,117,100,49,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,225,250,1,41,0,0,16,1,57,51,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,63,101,221,97,0,0,16,1,57,52,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,237,33,3,50,0,0,16,1,57,51,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,204,67,101,89,0,0,16,1,57,52,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,83,251,157,12,0,0,16,1,57,51,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,138,152,101,30,0,0,16,1,57,51,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,163,166,144,135,0,0,16,1,57,51,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,96,107,192,97,0,0,16,1,57,52,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,184,19,36,40,0,0,16,1,117,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,216,116,194,0,0,32,0,115,110,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,62,66,32,188,0,0,64,0,19,0,0,0,255,255,0,0,0,0,0,0,20,0,0,0,255,255,16,0,0,0,0,0,0,0,0,0,254,0,2,0,248,219,3,0,19,0,0,0,1,2,0,0,96,135,7,0,19,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,19,0,0,0,1,12,12,0,192,255,2,0,19,0,0,0,1,12,4,0,208,75,4,0,19,0,0,0,1,12,0,0,8,49,4,0,19,0,0,0,1,12,8,0,152,21,4,0,0,0,0,0,254,0,4,0,32,4,2,0,20,0,0,0,1,3,0,0,200,201,5,0,20,0,0,0,1,3,1,0,152,160,5,0,20,0,0,0,1,3,2,0,224,67,5,0,20,0,0,0,1,3,3,0,216,36,5,0,0,0,0,0,254,0,2,0,160,195,2,0,20,0,0,0,1,4,4,0,96,135,7,0,20,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,80,105,6,0,20,0,0,0,1,8,8,0,96,135,7,0,20,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,122,122,95,100,49,46,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,129,141,192,140,1,0,16,1,122,122,95,100,50,46,55,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,69,141,109,50,1,0,16,1,122,122,95,100,52,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,42,217,78,169,1,0,16,1,122,122,95,100,51,46,55,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,122,94,206,1,0,16,1,122,122,95,54,46,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,42,22,12,120,4,0,32,0,122,122,95,53,46,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,197,254,205,243,4,0,32,0,122,122,98,112,114,95,101,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,208,109,72,170,7,0,32,0,14,0,0,0,255,255,0,0,0,0,0,0,15,0,0,0,255,255,0,0,0,0,0,0,16,0,0,0,255,255,2,0,0,0,0,0,0,0,0,0,254,0,4,0,32,4,2,0,15,0,0,0,1,192,64,0,224,127,8,0,15,0,0,0,1,192,0,0,32,123,8,0,15,0,0,0,1,192,128,0,192,110,8,0,15,0,0,0,1,192,192,0,104,151,6,0,0,0,0,0,254,0,2,0,128,129,4,0,16,0,0,0,1,1,0,0,8,49,4,0,16,0,0,0,1,1,1,0,152,21,4,0,0,0,0,0,254,0,2,0,200,30,2,0,16,0,0,0,1,2,2,0,120,97,1,0,16,0,0,0,1,2,0,0,96,19,1,0,0,0,0,0,254,0,4,0,64,37,5,0,16,0,0,0,1,12,0,0,24,225,3,0,16,0,0,0,1,12,4,0,208,168,3,0,16,0,0,0,1,12,8,0,88,229,1,0,16,0,0,0,1,12,12,0,200,70,1,0,0,0,0,0,100,50,48,45,48,53,45,50,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,41,185,173,104,2,0,16,1,100,50,48,45,48,52,45,50,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,248,98,71,168,2,0,16,1,100,50,48,45,48,54,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,220,55,181,62,9,0,16,1,100,50,48,45,48,49,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,87,77,138,157,11,0,32,0,100,50,48,45,48,50,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,64,142,26,231,16,0,32,0,100,50,48,45,48,51,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,180,161,81,106,16,0,32,0,9,0,0,0,255,255,255,0,0,0,0,0,10,0,0,0,255,255,254,0,0,0,0,0,0,0,0,0,254,0,2,0,72,14,7,0,10,0,0,0,1,1,0,0,96,135,7,0,10,0,0,0,1,1,1,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,10,0,0,0,1,2,0,0,96,135,7,0,10,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,4,0,32,4,2,0,10,0,0,0,1,48,0,0,80,252,6,0,10,0,0,0,1,48,16,0,16,242,7,0,10,0,0,0,1,48,32,0,104,236,7,0,10,0,0,0,1,48,48,0,128,230,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,118,115,117,46,48,51,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,239,57,135,1,0,16,1,120,118,115,117,46,48,52,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,193,53,29,225,1,0,16,1,120,118,115,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,93,2,182,125,1,0,16,1,120,118,115,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,92,199,226,232,1,0,16,1,120,118,115,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,237,171,240,8,1,0,16,1,120,118,115,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,117,150,146,129,1,0,16,1,120,118,115,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,107,243,65,150,1,0,16,1,120,118,115,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,253,78,104,246,5,0,32,0,120,118,115,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,33,146,16,41,5,0,32,0,120,118,115,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,116,52,219,146,5,0,32,0,120,118,115,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,60,71,51,55,5,0,32,0,120,118,115,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,65,46,172,188,5,0,32,0,120,118,115,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,114,162,4,234,5,0,32,0,120,118,115,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,106,248,222,176,5,0,32,0,120,118,115,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,159,255,64,75,5,0,32,0,120,118,115,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,58,233,153,57,10,0,16,1,120,118,115,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,233,222,27,16,10,0,16,1,120,118,115,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,188,205,173,156,12,0,64,0,120,118,115,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,96,228,17,123,12,0,64,0,120,118,115,106,46,48,51,105,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,150,218,36,239,1,0,16,1,120,118,115,106,46,48,52,105,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,53,155,165,112,1,0,16,1,120,118,115,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,93,2,182,125,1,0,16,1,120,118,115,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,92,199,226,232,1,0,16,1,120,118,115,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,237,171,240,8,1,0,16,1,120,118,115,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,117,150,146,129,1,0,16,1,120,118,115,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,107,243,65,150,1,0,16,1,120,118,115,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,253,78,104,246,5,0,32,0,120,118,115,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,33,146,16,41,5,0,32,0,120,118,115,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,116,52,219,146,5,0,32,0,120,118,115,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,60,71,51,55,5,0,32,0,120,118,115,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,65,46,172,188,5,0,32,0,120,118,115,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,114,162,4,234,5,0,32,0,120,118,115,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,106,248,222,176,5,0,32,0,120,118,115,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,159,255,64,75,5,0,32,0,120,118,115,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,58,233,153,57,10,0,16,1,120,118,115,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,233,222,27,16,10,0,16,1,120,118,115,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,188,205,173,156,12,0,64,0,120,118,115,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,96,228,17,123,12,0,64,0,120,118,115,104,46,48,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,4,251,255,212,1,0,16,1,120,118,115,104,46,48,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,56,166,78,27,1,0,16,1,120,118,115,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,93,2,182,125,1,0,16,1,120,118,115,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,92,199,226,232,1,0,16,1,120,118,115,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,237,171,240,8,1,0,16,1,120,118,115,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,117,150,146,129,1,0,16,1,120,118,115,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,107,243,65,150,1,0,16,1,120,118,115,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,253,78,104,246,5,0,32,0,120,118,115,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,33,146,16,41,5,0,32,0,120,118,115,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,116,52,219,146,5,0,32,0,120,118,115,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,60,71,51,55,5,0,32,0,120,118,115,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,65,46,172,188,5,0,32,0,120,118,115,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,114,162,4,234,5,0,32,0,120,118,115,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,106,248,222,176,5,0,32,0,120,118,115,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,159,255,64,75,5,0,32,0,120,118,115,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,58,233,153,57,10,0,16,1,120,118,115,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,233,222,27,16,10,0,16,1,120,118,115,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,188,205,173,156,12,0,64,0,120,118,115,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,96,228,17,123,12,0,64,0,120,118,115,98,46,48,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,202,204,186,5,1,0,16,1,120,118,115,98,46,48,52,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,85,199,80,227,1,0,16,1,120,118,115,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,93,2,182,125,1,0,16,1,120,118,115,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,92,199,226,232,1,0,16,1,120,118,115,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,237,171,240,8,1,0,16,1,120,118,115,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,117,150,146,129,1,0,16,1,120,118,115,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,107,243,65,150,1,0,16,1,120,118,115,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,253,78,104,246,5,0,32,0,120,118,115,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,33,146,16,41,5,0,32,0,120,118,115,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,116,52,219,146,5,0,32,0,120,118,115,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,60,71,51,55,5,0,32,0,120,118,115,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,65,46,172,188,5,0,32,0,120,118,115,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,114,162,4,234,5,0,32,0,120,118,115,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,106,248,222,176,5,0,32,0,120,118,115,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,159,255,64,75,5,0,32,0,120,118,115,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,58,233,153,57,10,0,16,1,120,118,115,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,233,222,27,16,10,0,16,1,120,118,115,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,188,205,173,156,12,0,64,0,120,118,115,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,96,228,17,123,12,0,64,0,120,118,115,97,46,48,51,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,167,204,208,1,0,16,1,120,118,115,97,46,48,52,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,253,118,142,140,1,0,16,1,120,118,115,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,93,2,182,125,1,0,16,1,120,118,115,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,92,199,226,232,1,0,16,1,120,118,115,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,237,171,240,8,1,0,16,1,120,118,115,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,117,150,146,129,1,0,16,1,120,118,115,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,107,243,65,150,1,0,16,1,120,118,115,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,253,78,104,246,5,0,32,0,120,118,115,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,33,146,16,41,5,0,32,0,120,118,115,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,116,52,219,146,5,0,32,0,120,118,115,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,60,71,51,55,5,0,32,0,120,118,115,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,65,46,172,188,5,0,32,0,120,118,115,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,114,162,4,234,5,0,32,0,120,118,115,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,106,248,222,176,5,0,32,0,120,118,115,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,159,255,64,75,5,0,32,0,120,118,115,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,58,233,153,57,10,0,16,1,120,118,115,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,233,222,27,16,10,0,16,1,120,118,115,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,188,205,173,156,12,0,64,0,120,118,115,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,96,228,17,123,12,0,64,0,168,86,7,0,1,0,0,0,103,249,146,0,248,191,2,0,24,38,7,0,1,0,0,0,72,241,146,0,184,160,2,0,56,210,6,0,1,0,0,0,96,249,146,0,192,135,2,0,24,163,6,0,1,0,0,0,97,249,146,0,240,108,2,0,152,122,6,0,1,0,0,0,98,249,146,0,96,82,2,0,192,72,6,0,1,0,0,0,99,249,146,0,32,56,2,0,200,110,3,0,1,0,0,0,100,249,146,0,152,30,2,0,120,89,3,0,1,0,0,0,101,249,146,0,232,10,2,0,120,74,3,0,1,0,0,0,102,249,146,0,152,138,8,0,40,246,1,0,1,0,0,0,39,2,147,0,64,246,1,0,144,236,1,0,1,0,0,0,73,241,146,0,136,224,1,0,176,223,1,0,1,0,0,0,32,2,147,0,72,198,1,0,192,209,1,0,1,0,0,0,33,2,147,0,24,182,1,0,24,198,1,0,1,0,0,0,34,2,147,0,40,167,1,0,120,189,1,0,1,0,0,0,35,2,147,0,200,149,1,0,224,22,1,0,1,0,0,0,36,2,147,0,56,126,1,0,160,14,1,0,1,0,0,0,37,2,147,0,32,101,1,0,176,9,1,0,1,0,0,0,38,2,147,0,96,32,8,0,168,132,8,0,1,0,0,0,111,249,146,0,232,209,1,0,72,126,8,0,1,0,0,0,74,241,146,0,144,189,1,0,192,122,8,0,1,0,0,0,104,249,146,0,208,174,1,0,40,116,8,0,1,0,0,0,105,249,146,0,48,160,1,0,72,110,8,0,1,0,0,0,106,249,146,0,160,140,1,0,184,102,8,0,1,0,0,0,107,249,146,0,56,112,1,0,248,67,8,0,1,0,0,0,108,249,146,0,32,92,1,0,136,64,8,0,1,0,0,0,109,249,146,0,64,77,1,0,128,58,8,0,1,0,0,0,110,249,146,0,112,157,4,0,232,23,8,0,1,0,0,0,47,2,147,0,104,195,5,0,160,19,8,0,1,0,0,0,75,241,146,0,32,245,8,0,248,16,8,0,1,0,0,0,40,2,147,0,32,231,8,0,192,12,8,0,1,0,0,0,41,2,147,0,88,214,8,0,224,5,8,0,1,0,0,0,42,2,147,0,224,202,8,0,144,1,8,0,1,0,0,0,43,2,147,0,72,193,8,0,176,222,7,0,1,0,0,0,44,2,147,0,144,180,8,0,176,218,7,0,1,0,0,0,45,2,147,0,208,164,8,0,248,214,7,0,1,0,0,0,46,2,147,0,160,152,4,0,88,212,3,0,1,0,0,0,152,221,146,0,40,185,3,0,32,77,1,0,1,0,0,0,78,241,146,0,216,70,1,0,120,109,110,101,46,48,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,19,109,114,90,1,0,16,1,120,109,110,101,46,48,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,58,63,168,6,1,0,16,1,120,109,110,101,46,48,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,15,237,176,135,1,0,16,1,120,109,110,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,40,163,134,27,1,0,16,1,120,109,110,46,48,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,68,42,20,44,1,0,16,1,120,109,110,46,48,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,79,212,18,247,1,0,16,1,120,109,110,46,48,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,232,202,65,146,1,0,16,1,120,109,110,101,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,164,176,54,203,1,0,16,1,120,109,110,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,115,240,77,191,5,0,32,0,120,109,110,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,239,76,126,77,5,0,32,0,120,109,110,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,23,234,62,81,5,0,32,0,120,109,110,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,252,151,56,210,5,0,32,0,120,109,110,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,183,55,130,119,5,0,32,0,120,109,110,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,72,105,179,103,5,0,32,0,120,109,110,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,76,124,90,1,5,0,32,0,120,109,110,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,88,39,222,157,5,0,32,0,120,109,110,46,48,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,234,121,244,64,10,0,16,1,120,109,110,46,48,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,173,181,217,57,10,0,16,1,120,109,110,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,188,166,72,200,12,0,64,0,120,109,110,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,143,24,156,114,12,0,64,0,17,0,0,0,255,255,255,0,0,0,0,0,18,0,0,0,255,255,253,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,17,0,0,0,1,15,7,0,80,252,6,0,17,0,0,0,1,15,8,0,16,242,7,0,17,0,0,0,1,15,9,0,104,236,7,0,17,0,0,0,1,15,5,0,176,51,4,0,17,0,0,0,1,15,4,0,56,24,4,0,17,0,0,0,1,15,15,0,128,230,7,0,17,0,0,0,1,15,1,0,72,216,3,0,17,0,0,0,1,15,2,0,24,188,3,0,17,0,0,0,1,15,3,0,176,162,3,0,17,0,0,0,1,15,6,0,120,211,6,0,17,0,0,0,1,15,14,0,184,164,6,0,17,0,0,0,1,15,13,0,80,74,6,0,17,0,0,0,1,15,12,0,192,32,6,0,17,0,0,0,1,15,11,0,192,234,2,0,17,0,0,0,1,15,10,0,32,242,5,0,17,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,17,0,0,0,1,240,112,0,80,252,6,0,17,0,0,0,1,240,128,0,16,242,7,0,17,0,0,0,1,240,144,0,104,236,7,0,17,0,0,0,1,240,80,0,176,51,4,0,17,0,0,0,1,240,64,0,56,24,4,0,17,0,0,0,1,240,240,0,128,230,7,0,17,0,0,0,1,240,16,0,72,216,3,0,17,0,0,0,1,240,32,0,24,188,3,0,17,0,0,0,1,240,48,0,176,162,3,0,17,0,0,0,1,240,96,0,120,211,6,0,17,0,0,0,1,240,224,0,184,164,6,0,17,0,0,0,1,240,208,0,80,74,6,0,17,0,0,0,1,240,192,0,192,32,6,0,17,0,0,0,1,240,176,0,192,234,2,0,17,0,0,0,1,240,160,0,32,242,5,0,17,0,0,0,1,240,0,0,208,236,2,0,0,0,0,0,254,0,2,0,88,131,3,0,18,0,0,0,1,1,1,0,96,135,7,0,18,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,18,0,0,0,1,2,2,0,96,135,7,0,18,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,8,93,1,0,18,0,0,0,1,4,4,0,136,86,1,0,18,0,0,0,1,4,0,0,232,78,1,0,0,0,0,0,254,0,4,0,72,202,5,0,18,0,0,0,1,96,64,0,80,246,3,0,18,0,0,0,1,96,96,0,248,38,7,0,18,0,0,0,1,96,32,0,112,212,3,0,18,0,0,0,1,96,0,0,248,160,5,0,99,45,100,49,52,48,46,48,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,166,51,217,230,1,0,16,1,97,45,48,48,53,48,46,48,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,173,174,62,64,1,0,16,1,116,107,50,95,103,102,120,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,191,185,156,13,4,0,32,0,116,107,50,95,103,102,120,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,112,34,69,4,0,32,0,116,107,50,95,103,102,120,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,96,36,202,197,4,0,32,0,116,107,50,95,103,102,120,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,28,85,73,227,4,0,32,0,116,107,50,95,103,102,120,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,11,15,31,41,4,0,32,0,116,107,50,95,103,102,120,55,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,73,185,222,62,4,0,32,0,116,107,50,95,103,102,120,54,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,214,20,189,26,4,0,32,0,116,107,50,95,103,102,120,56,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,227,72,121,178,4,0,32,0,111,110,101,46,56,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,77,88,7,5,2,0,16,1,116,107,50,95,103,102,120,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,191,185,156,13,4,0,32,0,116,107,50,95,103,102,120,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,112,34,69,4,0,32,0,116,107,50,95,103,102,120,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,96,36,202,197,4,0,32,0,116,107,50,95,103,102,120,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,28,85,73,227,4,0,32,0,116,107,50,95,103,102,120,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,11,15,31,41,4,0,32,0,116,107,50,95,103,102,120,55,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,73,185,222,62,4,0,32,0,116,107,50,95,103,102,120,54,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,214,20,189,26,4,0,32,0,116,107,50,95,103,102,120,56,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,227,72,121,178,4,0,32,0,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,151,138,254,134,3,0,16,0,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,32,231,75,192,5,0,64,0,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,193,216,184,251,5,0,64,0,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,18,179,228,106,2,0,16,1,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,26,208,232,148,2,0,16,1,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,191,185,156,13,4,0,32,0,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,112,34,69,4,0,32,0,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,96,36,202,197,4,0,32,0,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,28,85,73,227,4,0,32,0,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,123,157,148,52,4,0,32,0,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,113,9,167,223,4,0,32,0,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,166,134,54,7,4,0,32,0,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,219,248,0,83,4,0,32,0,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,151,138,254,134,3,0,16,0,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,32,231,75,192,5,0,64,0,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,193,216,184,251,5,0,64,0,27,0,0,0,255,255,0,0,0,0,0,0,28,0,0,0,255,255,19,0,0,0,0,0,29,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,4,0,200,87,7,0,27,0,0,0,1,3,0,0,80,245,6,0,27,0,0,0,1,3,1,0,8,201,6,0,27,0,0,0,1,3,2,0,200,197,6,0,27,0,0,0,1,3,3,0,152,194,6,0,0,0,0,0,254,0,8,0,72,202,5,0,28,0,0,0,1,7,0,0,160,64,2,0,28,0,0,0,1,7,1,0,160,203,8,0,28,0,0,0,1,7,2,0,80,246,3,0,28,0,0,0,1,7,3,0,248,38,7,0,28,0,0,0,1,7,4,0,112,212,3,0,28,0,0,0,1,7,5,0,24,99,5,0,28,0,0,0,1,7,6,0,40,53,2,0,28,0,0,0,1,7,7,0,248,160,5,0,0,0,0,0,254,0,8,0,128,129,4,0,28,0,0,0,1,112,112,0,104,48,2,0,28,0,0,0,1,112,96,0,120,47,2,0,28,0,0,0,1,112,80,0,152,46,2,0,28,0,0,0,1,112,64,0,64,45,2,0,28,0,0,0,1,112,48,0,72,44,2,0,28,0,0,0,1,112,32,0,240,41,2,0,28,0,0,0,1,112,16,0,88,40,2,0,28,0,0,0,1,112,0,0,168,39,2,0,0,0,0,0,254,0,3,0,88,160,1,0,29,0,0,0,1,3,2,0,128,38,2,0,29,0,0,0,1,3,1,0,200,37,2,0,29,0,0,0,1,3,0,0,208,36,2,0,168,86,7,0,1,0,0,0,232,47,216,0,248,191,2,0,24,38,7,0,1,0,0,0,236,47,216,0,184,160,2,0,56,210,6,0,1,0,0,0,35,48,216,0,192,135,2,0,24,163,6,0,1,0,0,0,34,48,216,0,240,108,2,0,152,122,6,0,1,0,0,0,33,48,216,0,96,82,2,0,192,72,6,0,1,0,0,0,32,48,216,0,32,56,2,0,152,31,6,0,1,0,0,0,36,48,216,0,152,30,2,0,248,97,5,0,1,0,0,0,37,48,216,0,232,10,2,0,40,246,1,0,1,0,0,0,233,47,216,0,64,246,1,0,144,236,1,0,1,0,0,0,237,47,216,0,136,224,1,0,176,223,1,0,1,0,0,0,43,48,216,0,72,198,1,0,192,209,1,0,1,0,0,0,42,48,216,0,24,182,1,0,24,198,1,0,1,0,0,0,41,48,216,0,40,167,1,0,120,189,1,0,1,0,0,0,40,48,216,0,200,149,1,0,8,182,1,0,1,0,0,0,44,48,216,0,56,126,1,0,32,167,1,0,1,0,0,0,45,48,216,0,32,101,1,0,168,132,8,0,1,0,0,0,166,47,216,0,232,209,1,0,72,126,8,0,1,0,0,0,167,47,216,0,144,189,1,0,192,122,8,0,1,0,0,0,163,47,216,0,208,174,1,0,40,116,8,0,1,0,0,0,162,47,216,0,48,160,1,0,72,110,8,0,1,0,0,0,161,47,216,0,160,140,1,0,184,102,8,0,1,0,0,0,160,47,216,0,56,112,1,0,248,93,8,0,1,0,0,0,164,47,216,0,32,92,1,0,152,86,8,0,1,0,0,0,165,47,216,0,64,77,1,0,88,212,3,0,1,0,0,0,144,46,216,0,40,185,3,0,16,17,8,0,1,0,0,0,234,47,216,0,224,12,8,0,72,65,1,0,9,0,0,0,232,48,216,0,32,58,1,0,48,50,1,0,9,0,0,0,224,48,216,0,32,58,1,0,224,41,1,0,9,0,0,0,216,48,216,0,32,58,1,0,116,107,50,97,104,95,50,51,98,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,198,131,253,72,2,0,16,1,116,107,50,97,95,50,50,98,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,205,212,10,144,2,0,16,1,116,107,50,95,103,102,120,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,191,185,156,13,4,0,32,0,116,107,50,95,103,102,120,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,112,34,69,4,0,32,0,116,107,50,95,103,102,120,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,96,36,202,197,4,0,32,0,116,107,50,95,103,102,120,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,28,85,73,227,4,0,32,0,116,107,50,95,103,102,120,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,11,15,31,41,4,0,32,0,116,107,50,95,103,102,120,55,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,73,185,222,62,4,0,32,0,116,107,50,95,103,102,120,54,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,214,20,189,26,4,0,32,0,116,107,50,95,103,102,120,56,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,227,72,121,178,4,0,32,0,116,107,50,95,113,97,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,13,58,24,201,3,0,16,0,116,107,50,95,113,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,207,104,18,97,6,0,64,0,116,107,50,95,113,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,169,92,245,32,6,0,64,0,116,107,50,95,113,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,111,207,191,6,0,64,0,116,107,50,95,113,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,136,46,100,54,6,0,64,0,104,116,107,50,97,104,95,50,51,98,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,130,243,63,110,2,0,16,1,116,107,50,97,95,50,50,98,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,205,212,10,144,2,0,16,1,116,107,50,95,103,102,120,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,191,185,156,13,4,0,32,0,116,107,50,95,103,102,120,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,112,34,69,4,0,32,0,116,107,50,95,103,102,120,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,96,36,202,197,4,0,32,0,116,107,50,95,103,102,120,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,28,85,73,227,4,0,32,0,116,107,50,95,103,102,120,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,11,15,31,41,4,0,32,0,116,107,50,95,103,102,120,55,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,73,185,222,62,4,0,32,0,116,107,50,95,103,102,120,54,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,214,20,189,26,4,0,32,0,116,107,50,95,103,102,120,56,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,227,72,121,178,4,0,32,0,116,107,50,95,113,97,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,13,58,24,201,3,0,16,0,116,107,50,95,113,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,207,104,18,97,6,0,64,0,116,107,50,95,113,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,169,92,245,32,6,0,64,0,116,107,50,95,113,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,111,207,191,6,0,64,0,116,107,50,95,113,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,136,46,100,54,6,0,64,0,107,54,98,46,48,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,8,81,54,123,1,0,16,1,107,54,97,46,48,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,81,138,72,16,1,0,16,1,107,54,97,46,49,54,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,13,24,33,161,4,0,32,0,107,54,98,46,49,54,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,196,150,219,164,4,0,32,0,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,151,138,254,134,3,0,16,0,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,32,231,75,192,5,0,64,0,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,193,216,184,251,5,0,64,0,26,0,0,0,255,255,0,0,0,0,0,0,27,0,0,0,255,255,19,0,0,0,0,0,28,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,4,0,32,4,2,0,26,0,0,0,1,3,0,0,80,245,6,0,26,0,0,0,1,3,1,0,8,201,6,0,26,0,0,0,1,3,2,0,200,197,6,0,26,0,0,0,1,3,3,0,152,194,6,0,0,0,0,0,254,0,8,0,72,202,5,0,27,0,0,0,1,7,0,0,160,64,2,0,27,0,0,0,1,7,1,0,160,203,8,0,27,0,0,0,1,7,2,0,80,246,3,0,27,0,0,0,1,7,3,0,248,38,7,0,27,0,0,0,1,7,4,0,112,212,3,0,27,0,0,0,1,7,5,0,24,99,5,0,27,0,0,0,1,7,6,0,40,53,2,0,27,0,0,0,1,7,7,0,248,160,5,0,0,0,0,0,254,0,8,0,128,129,4,0,27,0,0,0,1,112,112,0,104,48,2,0,27,0,0,0,1,112,96,0,120,47,2,0,27,0,0,0,1,112,80,0,152,46,2,0,27,0,0,0,1,112,64,0,64,45,2,0,27,0,0,0,1,112,48,0,72,44,2,0,27,0,0,0,1,112,32,0,240,41,2,0,27,0,0,0,1,112,16,0,88,40,2,0,27,0,0,0,1,112,0,0,168,39,2,0,0,0,0,0,254,0,3,0,88,160,1,0,28,0,0,0,1,3,2,0,128,38,2,0,28,0,0,0,1,3,1,0,200,37,2,0,28,0,0,0,1,3,0,0,208,36,2,0,51,106,115,95,50,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,218,118,187,30,2,0,16,1,51,106,115,95,50,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,83,97,29,244,2,0,16,1,51,106,115,95,50,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,212,234,6,1,0,16,1,51,106,115,95,50,56,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,230,52,169,139,1,0,16,1,116,107,50,95,103,102,120,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,191,185,156,13,4,0,32,0,116,107,50,95,103,102,120,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,112,34,69,4,0,32,0,116,107,50,95,103,102,120,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,96,36,202,197,4,0,32,0,116,107,50,95,103,102,120,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,28,85,73,227,4,0,32,0,51,106,115,95,103,102,120,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,130,143,181,148,4,0,32,0,51,106,115,95,103,102,120,55,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,134,179,79,223,4,0,32,0,51,106,115,95,103,102,120,54,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,216,91,44,194,4,0,32,0,51,106,115,95,103,102,120,56,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,139,208,207,249,4,0,32,0,51,106,115,95,48,57,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,76,4,206,33,3,0,16,0,51,106,115,95,49,56,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,125,48,110,172,5,0,64,0,51,106,115,95,49,57,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,219,65,135,6,5,0,64,0,28,0,0,0,255,255,0,0,0,0,0,0,29,0,0,0,255,255,0,0,0,0,0,0,30,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,4,0,32,4,2,0,28,0,0,0,1,3,1,0,104,236,7,0,28,0,0,0,1,3,0,0,128,230,7,0,28,0,0,0,1,3,2,0,184,164,6,0,28,0,0,0,1,3,3,0,80,74,6,0,0,0,0,0,254,0,2,0,88,160,1,0,29,0,0,0,1,1,1,0,200,37,2,0,29,0,0,0,1,1,0,0,208,36,2,0,0,0,0,0,254,0,8,0,72,202,5,0,30,0,0,0,1,7,0,0,32,30,2,0,30,0,0,0,1,7,1,0,168,29,2,0,30,0,0,0,1,7,2,0,248,28,2,0,30,0,0,0,1,7,3,0,112,28,2,0,30,0,0,0,1,7,4,0,200,27,2,0,30,0,0,0,1,7,5,0,200,26,2,0,30,0,0,0,1,7,6,0,136,24,2,0,30,0,0,0,1,7,7,0,176,23,2,0,0,0,0,0,254,0,5,0,128,129,4,0,30,0,0,0,1,112,64,0,168,39,2,0,30,0,0,0,1,112,48,0,176,22,2,0,30,0,0,0,1,112,32,0,72,44,2,0,30,0,0,0,1,112,16,0,240,41,2,0,30,0,0,0,1,112,0,0,88,40,2,0,119,109,46,49,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,66,68,219,182,0,0,16,1,119,109,46,49,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,160,167,160,89,0,0,16,1,119,109,46,49,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,106,133,179,76,0,0,16,1,119,109,46,49,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,41,75,228,226,0,0,16,1,119,109,46,49,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,69,100,163,67,0,0,16,1,119,109,46,49,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,76,121,36,86,0,0,16,1,119,109,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,183,175,210,80,0,0,16,1,119,109,46,56,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,243,11,15,84,0,0,32,0,119,109,46,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,158,227,193,146,0,0,32,0,119,109,46,56,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,42,255,1,106,0,0,32,0,119,109,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,155,68,230,170,0,0,32,0,119,109,46,56,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,212,11,63,252,0,0,32,0,119,109,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,147,155,206,194,0,0,32,0,119,109,46,56,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,229,224,138,35,0,0,32,0,119,109,46,57,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,112,145,241,162,0,0,32,0,112,114,45,53,51,49,55,46,49,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,184,80,131,100,0,0,0,8,25,0,0,0,255,255,255,0,0,0,0,0,26,0,0,0,255,255,252,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,25,0,0,0,1,15,7,0,80,252,6,0,25,0,0,0,1,15,8,0,16,242,7,0,25,0,0,0,1,15,9,0,104,236,7,0,25,0,0,0,1,15,5,0,192,54,8,0,25,0,0,0,1,15,4,0,56,24,4,0,25,0,0,0,1,15,15,0,128,230,7,0,25,0,0,0,1,15,0,0,128,230,7,0,25,0,0,0,1,15,3,0,176,162,3,0,25,0,0,0,1,15,2,0,24,188,3,0,25,0,0,0,1,15,1,0,72,216,3,0,25,0,0,0,1,15,6,0,120,211,6,0,25,0,0,0,1,15,14,0,184,164,6,0,25,0,0,0,1,15,13,0,80,74,6,0,25,0,0,0,1,15,12,0,192,32,6,0,25,0,0,0,1,15,11,0,192,234,2,0,25,0,0,0,1,15,10,0,32,242,5,0,0,0,0,0,254,0,16,0,160,123,6,0,25,0,0,0,1,240,112,0,80,252,6,0,25,0,0,0,1,240,128,0,16,242,7,0,25,0,0,0,1,240,144,0,104,236,7,0,25,0,0,0,1,240,80,0,192,54,8,0,25,0,0,0,1,240,64,0,56,24,4,0,25,0,0,0,1,240,240,0,128,230,7,0,25,0,0,0,1,240,0,0,128,230,7,0,25,0,0,0,1,240,48,0,176,162,3,0,25,0,0,0,1,240,32,0,24,188,3,0,25,0,0,0,1,240,16,0,72,216,3,0,25,0,0,0,1,240,96,0,120,211,6,0,25,0,0,0,1,240,224,0,184,164,6,0,25,0,0,0,1,240,208,0,80,74,6,0,25,0,0,0,1,240,192,0,192,32,6,0,25,0,0,0,1,240,176,0,192,234,2,0,25,0,0,0,1,240,160,0,32,242,5,0,0,0,0,0,254,0,2,0,200,30,2,0,26,0,0,0,1,1,0,0,120,97,1,0,26,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,2,0,168,234,7,0,26,0,0,0,1,2,2,0,96,135,7,0,26,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,4,0,112,59,6,0,26,0,0,0,1,12,12,0,248,38,7,0,26,0,0,0,1,12,8,0,176,64,8,0,26,0,0,0,1,12,4,0,120,54,8,0,26,0,0,0,1,12,0,0,128,65,6,0,0,0,0,0,254,0,2,0,64,37,5,0,26,0,0,0,1,16,16,0,120,176,7,0,26,0,0,0,1,16,0,0,152,172,7,0,0,0,0,0,254,0,2,0,72,202,5,0,26,0,0,0,1,64,64,0,80,246,3,0,26,0,0,0,1,64,0,0,112,212,3,0,0,0,0,0,110,45,52,46,117,56,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,155,130,62,252,0,0,16,1,110,45,51,46,117,56,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,35,198,27,240,0,0,16,1,117,97,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,95,250,202,144,0,0,16,1,112,114,111,116,100,97,116,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,91,222,255,183,0,0,16,1,53,46,115,114,111,109,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,89,200,248,247,0,0,32,0,54,46,115,114,111,109,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,226,172,52,0,0,32,0,55,46,117,100,114,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,29,195,71,110,0,0,32,0,56,46,117,100,114,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,124,213,197,9,0,0,32,0,57,46,117,100,114,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,240,100,192,62,0,0,32,0,49,48,46,117,100,114,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,221,60,105,180,0,0,32,0,117,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,48,125,33,222,0,0,64,0,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,127,0,0,0,0,0,0,0,0,0,254,0,2,0,88,41,7,0,19,0,0,0,1,16,0,0,88,244,4,0,19,0,0,0,1,16,16,0,184,151,2,0,0,0,0,0,254,0,4,0,72,202,5,0,19,0,0,0,1,192,0,0,80,246,3,0,19,0,0,0,1,192,192,0,248,38,7,0,19,0,0,0,1,192,64,0,112,212,3,0,19,0,0,0,1,192,128,0,248,160,5,0,0,0,0,0,254,0,2,0,96,30,7,0,20,0,0,0,1,1,0,0,80,62,6,0,20,0,0,0,1,1,1,0,176,2,8,0,0,0,0,0,254,0,2,0,0,91,7,0,20,0,0,0,1,2,2,0,72,25,8,0,20,0,0,0,1,2,0,0,56,21,8,0,0,0,0,0,254,0,2,0,64,84,7,0,20,0,0,0,1,4,0,0,48,14,8,0,20,0,0,0,1,4,4,0,200,8,8,0,0,0,0,0,254,0,2,0,56,3,8,0,20,0,0,0,1,8,0,0,248,251,7,0,20,0,0,0,1,8,8,0,72,244,7,0,0,0,0,0,254,0,8,0,32,4,2,0,20,0,0,0,1,112,0,0,104,54,4,0,20,0,0,0,1,112,64,0,80,252,6,0,20,0,0,0,1,112,32,0,16,242,7,0,20,0,0,0,1,112,96,0,104,236,7,0,20,0,0,0,1,112,112,0,128,230,7,0,20,0,0,0,1,112,80,0,120,211,6,0,20,0,0,0,1,112,48,0,184,164,6,0,20,0,0,0,1,112,16,0,80,74,6,0,0,0,0,0,254,0,2,0,168,234,7,0,20,0,0,0,1,128,128,0,96,135,7,0,20,0,0,0,1,128,0,0,152,182,7,0,168,86,7,0,1,0,0,0,136,239,146,0,248,191,2,0,24,38,7,0,1,0,0,0,223,254,146,0,184,160,2,0,56,210,6,0,1,0,0,0,218,254,146,0,192,135,2,0,24,163,6,0,1,0,0,0,219,254,146,0,240,108,2,0,152,122,6,0,1,0,0,0,216,254,146,0,96,82,2,0,192,72,6,0,1,0,0,0,217,254,146,0,32,56,2,0,200,110,3,0,1,0,0,0,220,254,146,0,152,30,2,0,120,89,3,0,1,0,0,0,221,254,146,0,232,10,2,0,40,246,1,0,1,0,0,0,137,239,146,0,64,246,1,0,144,236,1,0,1,0,0,0,127,246,146,0,136,224,1,0,176,223,1,0,1,0,0,0,122,246,146,0,72,198,1,0,192,209,1,0,1,0,0,0,123,246,146,0,24,182,1,0,24,198,1,0,1,0,0,0,120,246,146,0,40,167,1,0,120,189,1,0,1,0,0,0,121,246,146,0,200,149,1,0,224,22,1,0,1,0,0,0,124,246,146,0,56,126,1,0,160,14,1,0,1,0,0,0,125,246,146,0,32,101,1,0,72,126,8,0,1,0,0,0,47,237,146,0,144,189,1,0,192,122,8,0,1,0,0,0,42,237,146,0,208,174,1,0,40,116,8,0,1,0,0,0,43,237,146,0,48,160,1,0,72,110,8,0,1,0,0,0,40,237,146,0,160,140,1,0,184,102,8,0,1,0,0,0,41,237,146,0,56,112,1,0,248,67,8,0,1,0,0,0,44,237,146,0,32,92,1,0,136,64,8,0,1,0,0,0,45,237,146,0,64,77,1,0,160,19,8,0,1,0,0,0,71,236,146,0,32,245,8,0,248,16,8,0,1,0,0,0,66,236,146,0,32,231,8,0,192,12,8,0,1,0,0,0,67,236,146,0,88,214,8,0,224,5,8,0,1,0,0,0,64,236,146,0,224,202,8,0,144,1,8,0,1,0,0,0,65,236,146,0,72,193,8,0,176,222,7,0,1,0,0,0,68,236,146,0,144,180,8,0,176,218,7,0,1,0,0,0,69,236,146,0,208,164,8,0,88,212,3,0,1,0,0,0,160,218,146,0,40,185,3,0,16,17,8,0,1,0,0,0,138,239,146,0,224,12,8,0,56,58,1,0,1,0,0,0,139,239,146,0,64,50,1,0,72,65,1,0,9,0,0,0,48,5,147,0,32,58,1,0,48,50,1,0,9,0,0,0,49,5,147,0,32,58,1,0,224,41,1,0,9,0,0,0,50,5,147,0,32,58,1,0,119,108,117,95,51,48,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,177,219,4,214,1,0,16,1,51,53,46,49,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,119,30,121,122,1,0,16,1,119,108,117,95,51,49,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,131,138,180,14,1,0,16,1,119,108,117,95,51,54,46,49,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,2,16,54,1,0,16,1,119,108,109,45,51,50,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,67,246,217,223,2,0,16,1,119,108,109,45,55,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,115,75,167,175,4,0,32,0,119,108,109,45,53,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,11,220,160,18,4,0,32,0,119,108,109,45,51,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,206,171,242,198,4,0,32,0,119,108,109,45,49,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,211,198,164,74,4,0,32,0,119,108,95,50,52,46,55,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,229,222,10,111,4,0,32,0,119,108,95,49,52,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,125,2,243,156,4,0,32,0,119,108,95,50,54,46,57,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,207,142,156,240,4,0,32,0,119,108,95,49,54,46,57,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,170,7,84,227,4,0,32,0,119,108,95,50,48,46,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,80,35,153,132,4,0,32,0,119,108,95,49,48,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,54,90,123,184,4,0,32,0,119,108,95,50,50,46,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,240,137,63,253,4,0,32,0,119,108,95,49,50,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,105,157,164,125,4,0,32,0,119,108,95,48,57,46,49,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,96,208,179,246,3,0,16,0,119,108,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,77,61,226,189,5,0,64,0,119,108,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,245,152,56,104,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,119,108,50,52,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,241,205,1,113,0,0,0,8,108,119,105,111,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,12,185,82,173,0,0,0,8,21,0,0,0,255,255,0,0,0,0,0,0,22,0,0,0,255,255,0,0,0,0,0,0,23,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,8,0,200,87,7,0,21,0,0,0,1,7,6,0,80,252,6,0,21,0,0,0,1,7,5,0,16,242,7,0,21,0,0,0,1,7,4,0,104,236,7,0,21,0,0,0,1,7,7,0,104,9,2,0,21,0,0,0,1,7,0,0,128,230,7,0,21,0,0,0,1,7,1,0,184,164,6,0,21,0,0,0,1,7,2,0,80,74,6,0,21,0,0,0,1,7,3,0,192,32,6,0,0,0,0,0,254,0,8,0,160,123,6,0,21,0,0,0,1,56,48,0,80,252,6,0,21,0,0,0,1,56,40,0,16,242,7,0,21,0,0,0,1,56,32,0,104,236,7,0,21,0,0,0,1,56,56,0,104,9,2,0,21,0,0,0,1,56,0,0,128,230,7,0,21,0,0,0,1,56,8,0,184,164,6,0,21,0,0,0,1,56,16,0,80,74,6,0,21,0,0,0,1,56,24,0,192,32,6,0,0,0,0,0,254,0,3,0,200,30,2,0,21,0,0,0,1,192,0,0,80,6,2,0,21,0,0,0,1,192,64,0,152,5,2,0,21,0,0,0,1,192,192,0,96,19,1,0,0,0,0,0,254,0,8,0,72,202,5,0,22,0,0,0,1,7,3,0,72,198,6,0,22,0,0,0,1,7,2,0,208,75,4,0,22,0,0,0,1,7,1,0,8,49,4,0,22,0,0,0,1,7,0,0,72,195,6,0,22,0,0,0,1,7,4,0,72,246,3,0,22,0,0,0,1,7,5,0,72,0,3,0,22,0,0,0,1,7,6,0,64,47,7,0,22,0,0,0,1,7,7,0,48,173,6,0,0,0,0,0,254,0,4,0,160,249,1,0,22,0,0,0,1,24,8,0,248,81,6,0,22,0,0,0,1,24,0,0,248,38,7,0,22,0,0,0,1,24,16,0,176,64,8,0,22,0,0,0,1,24,24,0,128,172,6,0,0,0,0,0,254,0,2,0,168,244,1,0,22,0,0,0,1,128,0,0,96,135,7,0,22,0,0,0,1,128,128,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,23,0,0,0,1,3,1,0,192,255,2,0,23,0,0,0,1,3,0,0,208,75,4,0,23,0,0,0,1,3,2,0,8,49,4,0,23,0,0,0,1,3,3,0,152,21,4,0,0,0,0,0,254,0,4,0,200,242,1,0,23,0,0,0,1,12,12,0,208,75,4,0,23,0,0,0,1,12,0,0,8,49,4,0,23,0,0,0,1,12,4,0,152,21,4,0,23,0,0,0,1,12,8,0,72,246,3,0,0,0,0,0,254,0,2,0,40,214,8,0,23,0,0,0,1,16,0,0,96,135,7,0,23,0,0,0,1,16,16,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,23,0,0,0,1,32,32,0,96,135,7,0,23,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,23,0,0,0,1,64,64,0,96,135,7,0,23,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,79,2,0,23,0,0,0,1,128,0,0,32,182,8,0,23,0,0,0,1,128,128,0,80,251,6,0,97,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,201,148,110,30,0,0,16,1,97,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,122,241,79,245,0,0,16,1,97,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,47,94,83,61,0,0,16,1,97,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,75,28,66,158,0,0,16,1,97,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,34,118,49,61,0,0,16,1,97,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,129,68,5,12,0,0,32,0,97,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,72,235,179,235,0,0,32,0,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,248,42,35,192,0,0,32,0,97,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,251,23,110,163,0,0,32,0,97,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,23,24,195,56,0,0,32,0,97,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,41,158,227,50,0,0,32,0,97,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,150,199,206,92,0,0,32,0,97,50,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,145,160,84,12,0,0,32,0,49,52,54,95,97,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,150,0,166,213,0,0,32,0,49,52,55,95,97,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,72,253,22,91,0,0,32,0,49,52,56,95,97,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,24,28,55,38,0,0,32,0,49,52,57,95,97,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,98,57,66,178,0,0,32,0,49,53,48,95,97,49,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,249,37,168,13,0,0,32,0,49,53,49,95,97,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,142,119,152,175,0,0,32,0,49,53,50,95,97,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,9,108,107,81,0,0,32,0,49,53,51,95,97,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,69,39,170,140,0,0,32,0,101,108,95,105,99,51,57,95,103,97,108,49,54,118,56,95,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,0,0,0,0,0,0,24,101,108,95,105,99,52,52,95,103,97,108,49,54,118,56,95,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,0,0,0,0,0,0,24,101,108,95,105,99,53,52,95,103,97,108,49,54,118,56,95,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,0,0,0,0,0,0,24,101,108,95,105,99,49,48,48,95,103,97,108,49,54,118,56,95,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,0,0,0,0,0,0,24,101,108,95,105,99,49,52,51,95,103,97,108,49,54,118,56,95,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,0,0,0,0,0,0,24,97,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,221,3,42,25,0,0,16,1,97,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,122,241,79,245,0,0,16,1,97,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,47,94,83,61,0,0,16,1,97,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,75,28,66,158,0,0,16,1,97,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,34,118,49,61,0,0,16,1,97,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,183,135,83,59,0,0,32,0,97,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,163,165,34,198,0,0,32,0,97,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,246,217,35,9,0,0,32,0,97,50,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,62,200,222,184,0,0,32,0,97,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,23,24,195,56,0,0,32,0,97,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,41,158,227,50,0,0,32,0,97,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,150,199,206,92,0,0,32,0,97,50,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,145,160,84,12,0,0,32,0,49,52,54,95,97,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,150,0,166,213,0,0,32,0,49,52,55,95,97,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,103,244,187,54,0,0,32,0,49,52,56,95,97,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,24,28,55,38,0,0,32,0,49,52,57,95,97,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,134,155,170,117,0,0,32,0,49,53,48,95,97,49,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,249,37,168,13,0,0,32,0,49,53,49,95,97,49,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,216,41,132,34,0,0,32,0,49,53,50,95,97,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,9,108,107,81,0,0,32,0,49,53,51,95,97,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,169,144,99,243,0,0,32,0,101,108,95,105,99,51,57,95,103,97,108,49,54,118,56,95,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,0,0,0,0,0,0,24,101,108,95,105,99,52,52,95,103,97,108,49,54,118,56,95,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,0,0,0,0,0,0,24,101,108,95,105,99,53,52,95,103,97,108,49,54,118,56,95,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,0,0,0,0,0,0,24,101,108,95,105,99,49,48,48,95,103,97,108,49,54,118,56,95,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,0,0,0,0,0,0,24,101,108,95,105,99,49,52,51,95,103,97,108,49,54,118,56,95,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,0,0,0,0,0,0,24,17,0,0,0,255,255,255,0,0,0,0,0,18,0,0,0,255,255,127,0,0,0,0,0,0,0,0,0,254,0,16,0,32,4,2,0,17,0,0,0,1,15,0,0,224,12,7,0,17,0,0,0,1,15,8,0,248,225,6,0,17,0,0,0,1,15,4,0,40,182,6,0,17,0,0,0,1,15,12,0,160,138,6,0,17,0,0,0,1,15,2,0,112,94,6,0,17,0,0,0,1,15,10,0,128,47,6,0,17,0,0,0,1,15,6,0,16,5,6,0,17,0,0,0,1,15,14,0,144,215,5,0,17,0,0,0,1,15,1,0,104,177,5,0,17,0,0,0,1,15,9,0,168,139,5,0,17,0,0,0,1,15,15,0,248,111,5,0,17,0,0,0,1,15,7,0,216,79,5,0,17,0,0,0,1,15,11,0,8,50,5,0,17,0,0,0,1,15,3,0,248,18,5,0,17,0,0,0,1,15,13,0,72,240,4,0,17,0,0,0,1,15,5,0,64,206,4,0,0,0,0,0,254,0,4,0,72,202,5,0,17,0,0,0,1,48,48,0,80,246,3,0,17,0,0,0,1,48,16,0,248,38,7,0,17,0,0,0,1,48,32,0,112,212,3,0,17,0,0,0,1,48,0,0,248,160,5,0,0,0,0,0,254,0,2,0,56,32,4,0,17,0,0,0,1,64,64,0,248,38,7,0,17,0,0,0,1,64,0,0,176,64,8,0,0,0,0,0,254,0,2,0,168,234,7,0,17,0,0,0,1,128,0,0,96,135,7,0,17,0,0,0,1,128,128,0,152,182,7,0,0,0,0,0,254,0,4,0,232,143,3,0,18,0,0,0,1,3,1,0,248,119,3,0,18,0,0,0,1,3,2,0,64,106,4,0,18,0,0,0,1,3,3,0,160,196,4,0,18,0,0,0,1,3,0,0,88,67,3,0,0,0,0,0,254,0,8,0,96,52,3,0,18,0,0,0,1,28,12,0,248,119,3,0,18,0,0,0,1,28,20,0,64,106,4,0,18,0,0,0,1,28,4,0,160,196,4,0,18,0,0,0,1,28,24,0,88,67,3,0,18,0,0,0,1,28,28,0,176,17,8,0,18,0,0,0,1,28,8,0,208,13,8,0,18,0,0,0,1,28,16,0,208,242,2,0,18,0,0,0,1,28,0,0,208,183,7,0,0,0,0,0,254,0,2,0,128,112,3,0,18,0,0,0,1,128,0,0,168,22,4,0,18,0,0,0,1,128,128,0,224,247,3,0,0,0,0,0,184,40,2,0,1,0,0,0,208,211,148,0,248,191,2,0,56,250,6,0,1,0,0,0,210,211,148,0,184,160,2,0,184,164,8,0,1,0,0,0,209,211,148,0,64,246,1,0,88,149,7,0,1,0,0,0,211,211,148,0,136,224,1,0,56,210,6,0,1,0,0,0,224,211,148,0,192,135,2,0,24,163,6,0,1,0,0,0,225,211,148,0,240,108,2,0,152,122,6,0,1,0,0,0,226,211,148,0,96,82,2,0,192,72,6,0,1,0,0,0,227,211,148,0,32,56,2,0,48,123,2,0,1,0,0,0,228,211,148,0,152,30,2,0,96,69,2,0,1,0,0,0,229,211,148,0,232,10,2,0,176,223,1,0,1,0,0,0,216,211,148,0,72,198,1,0,192,209,1,0,1,0,0,0,217,211,148,0,24,182,1,0,24,198,1,0,1,0,0,0,218,211,148,0,40,167,1,0,120,189,1,0,1,0,0,0,219,211,148,0,200,149,1,0,248,187,8,0,1,0,0,0,220,211,148,0,56,126,1,0,184,179,8,0,1,0,0,0,221,211,148,0,32,101,1,0,88,212,3,0,1,0,0,0,24,157,145,0,40,185,3,0,248,5,8,0,9,0,0,0,88,230,146,0,32,58,1,0,144,250,7,0,9,0,0,0,89,230,146,0,32,58,1,0,184,40,2,0,1,0,0,0,128,93,148,0,248,191,2,0,56,250,6,0,1,0,0,0,132,93,148,0,184,160,2,0,184,164,8,0,1,0,0,0,129,93,148,0,64,246,1,0,88,149,7,0,1,0,0,0,133,93,148,0,136,224,1,0,152,122,6,0,1,0,0,0,151,93,148,0,96,82,2,0,192,72,6,0,1,0,0,0,150,93,148,0,32,56,2,0,48,123,2,0,1,0,0,0,145,93,148,0,152,30,2,0,96,69,2,0,1,0,0,0,146,93,148,0,232,10,2,0,24,198,1,0,1,0,0,0,143,93,148,0,40,167,1,0,120,189,1,0,1,0,0,0,142,93,148,0,200,149,1,0,248,187,8,0,1,0,0,0,137,93,148,0,56,126,1,0,184,179,8,0,1,0,0,0,138,93,148,0,32,101,1,0,88,212,3,0,1,0,0,0,248,26,149,0,40,185,3,0,16,17,8,0,1,0,0,0,131,93,148,0,224,12,8,0,80,251,6,0,1,0,0,0,130,93,148,0,216,70,1,0,248,5,8,0,9,0,0,0,112,99,215,0,32,58,1,0,144,250,7,0,9,0,0,0,113,99,215,0,32,58,1,0,105,99,49,50,57,95,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,9,183,196,50,0,0,16,1,105,99,49,51,48,95,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,222,62,70,86,0,0,16,1,105,99,49,51,49,95,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,146,211,94,119,0,0,16,1,105,99,49,51,50,95,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,8,39,146,123,0,0,16,1,101,112,114,45,55,53,57,49,46,49,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,35,170,121,131,0,0,16,1,101,112,114,45,55,53,57,50,46,49,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,215,165,103,199,0,0,16,1,101,112,114,55,52,57,56,97,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,92,32,152,193,0,0,16,1,101,112,114,45,55,52,57,55,46,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,202,9,214,8,0,0,32,0,101,112,114,45,55,52,57,54,46,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,241,253,97,111,0,0,32,0,101,112,114,45,55,52,57,53,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,45,44,13,106,0,0,32,0,101,112,114,45,55,52,57,52,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,199,129,226,168,0,0,32,0,101,112,114,45,55,52,57,51,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,244,93,48,137,0,0,32,0,101,112,114,45,55,52,57,50,46,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,177,6,248,96,0,0,32,0,101,112,114,45,55,52,56,53,46,49,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,34,23,137,194,0,0,32,0,101,112,114,45,55,52,56,55,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,27,66,58,45,0,0,32,0,101,112,114,45,55,52,56,54,46,49,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,80,44,98,141,0,0,32,0,101,112,114,45,55,52,56,56,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,27,47,124,0,0,0,32,0,112,114,45,53,51,49,55,46,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,184,80,131,100,0,0,0,8,20,0,0,0,255,255,255,0,0,0,0,0,21,0,0,0,255,255,90,0,0,0,0,0,22,0,0,0,255,255,253,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,20,0,0,0,1,15,2,0,248,223,6,0,20,0,0,0,1,15,5,0,88,179,6,0,20,0,0,0,1,15,8,0,32,136,6,0,20,0,0,0,1,15,4,0,120,113,6,0,20,0,0,0,1,15,1,0,232,228,5,0,20,0,0,0,1,15,15,0,120,90,6,0,20,0,0,0,1,15,3,0,56,141,7,0,20,0,0,0,1,15,7,0,120,211,6,0,20,0,0,0,1,15,14,0,184,164,6,0,20,0,0,0,1,15,6,0,24,1,7,0,20,0,0,0,1,15,13,0,80,74,6,0,20,0,0,0,1,15,12,0,192,32,6,0,20,0,0,0,1,15,11,0,192,234,2,0,20,0,0,0,1,15,10,0,32,242,5,0,20,0,0,0,1,15,9,0,176,192,2,0,20,0,0,0,1,15,0,0,16,227,4,0,0,0,0,0,254,0,16,0,160,123,6,0,20,0,0,0,1,240,32,0,248,223,6,0,20,0,0,0,1,240,80,0,88,179,6,0,20,0,0,0,1,240,128,0,32,136,6,0,20,0,0,0,1,240,64,0,120,113,6,0,20,0,0,0,1,240,16,0,232,228,5,0,20,0,0,0,1,240,240,0,120,90,6,0,20,0,0,0,1,240,48,0,56,141,7,0,20,0,0,0,1,240,112,0,120,211,6,0,20,0,0,0,1,240,224,0,184,164,6,0,20,0,0,0,1,240,96,0,24,1,7,0,20,0,0,0,1,240,208,0,80,74,6,0,20,0,0,0,1,240,192,0,192,32,6,0,20,0,0,0,1,240,176,0,192,234,2,0,20,0,0,0,1,240,160,0,32,242,5,0,20,0,0,0,1,240,144,0,176,192,2,0,20,0,0,0,1,240,0,0,168,165,2,0,0,0,0,0,254,0,4,0,128,129,4,0,21,0,0,0,1,3,3,0,208,75,4,0,21,0,0,0,1,3,2,0,8,49,4,0,21,0,0,0,1,3,1,0,152,21,4,0,21,0,0,0,1,3,0,0,64,47,7,0,0,0,0,0,254,0,2,0,200,30,2,0,21,0,0,0,1,4,0,0,120,97,1,0,21,0,0,0,1,4,4,0,96,19,1,0,0,0,0,0,254,0,4,0,64,37,5,0,21,0,0,0,1,24,24,0,160,196,8,0,21,0,0,0,1,24,16,0,48,46,1,0,21,0,0,0,1,24,8,0,224,64,8,0,21,0,0,0,1,24,0,0,56,201,8,0,0,0,0,0,254,0,4,0,72,202,5,0,21,0,0,0,1,96,96,0,80,246,3,0,21,0,0,0,1,96,64,0,248,38,7,0,21,0,0,0,1,96,32,0,48,123,8,0,21,0,0,0,1,96,0,0,8,117,8,0,0,0,0,0,254,0,2,0,168,234,7,0,21,0,0,0,1,128,128,0,96,135,7,0,21,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,22,0,0,0,1,1,1,0,96,135,7,0,22,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,6,0,22,0,0,0,1,2,2,0,8,208,6,0,22,0,0,0,1,2,0,0,88,204,6,0,0,0,0,0,254,0,2,0,232,75,4,0,22,0,0,0,1,4,4,0,96,135,7,0,22,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,118,115,50,106,95,100,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,123,95,134,80,1,0,16,1,118,115,50,106,95,100,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,227,240,191,195,1,0,16,1,118,115,50,106,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,56,150,151,97,1,0,16,1,118,115,50,106,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,194,91,124,243,1,0,16,1,118,115,50,106,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,9,88,136,143,1,0,16,1,118,115,50,106,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,32,193,24,32,1,0,16,1,118,115,50,106,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,23,194,195,250,1,0,16,1,118,115,50,106,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,19,2,73,235,1,0,16,1,118,115,50,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,82,47,133,92,5,0,32,0,118,115,50,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,175,88,15,162,5,0,32,0,118,115,50,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,173,89,219,57,5,0,32,0,118,115,50,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,167,99,199,0,5,0,32,0,118,115,50,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,99,189,9,205,5,0,32,0,118,115,50,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,21,44,24,224,5,0,32,0,118,115,50,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,246,196,141,119,5,0,32,0,118,115,50,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,29,157,93,96,5,0,32,0,118,115,50,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,57,1,25,53,10,0,16,1,118,115,50,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,186,45,195,10,0,16,1,118,115,50,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,183,71,126,214,12,0,64,0,118,115,50,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,20,10,2,109,12,0,64,0,21,0,0,0,255,255,0,0,0,0,0,0,22,0,0,0,255,255,0,0,0,0,0,0,23,0,0,0,255,255,2,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,21,0,0,0,1,2,0,0,96,135,7,0,21,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,21,0,0,0,1,8,8,0,96,135,7,0,21,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,21,0,0,0,1,48,48,0,32,136,7,0,21,0,0,0,1,48,32,0,40,88,7,0,21,0,0,0,1,48,16,0,96,39,7,0,21,0,0,0,1,48,0,0,144,251,6,0,0,0,0,0,254,0,4,0,160,123,6,0,21,0,0,0,1,192,0,0,184,164,6,0,21,0,0,0,1,192,64,0,80,74,6,0,21,0,0,0,1,192,128,0,192,32,6,0,21,0,0,0,1,192,192,0,32,242,5,0,0,0,0,0,254,0,4,0,72,202,5,0,22,0,0,0,1,3,1,0,80,246,3,0,22,0,0,0,1,3,0,0,80,124,6,0,22,0,0,0,1,3,2,0,112,212,3,0,22,0,0,0,1,3,3,0,248,160,5,0,0,0,0,0,254,0,4,0,64,37,5,0,22,0,0,0,1,12,0,0,240,211,6,0,22,0,0,0,1,12,4,0,64,165,6,0,22,0,0,0,1,12,8,0,208,227,4,0,22,0,0,0,1,12,12,0,248,74,6,0,0,0,0,0,254,0,4,0,128,129,4,0,22,0,0,0,1,48,48,0,208,75,4,0,22,0,0,0,1,48,0,0,8,49,4,0,22,0,0,0,1,48,32,0,152,21,4,0,22,0,0,0,1,48,16,0,72,246,3,0,0,0,0,0,254,0,2,0,144,246,3,0,22,0,0,0,1,64,0,0,96,135,7,0,22,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,22,0,0,0,1,128,128,0,56,111,3,0,22,0,0,0,1,128,0,0,104,134,3,0,0,0,0,0,254,0,10,0,216,227,4,0,23,0,0,0,1,15,0,0,24,192,4,0,23,0,0,0,1,15,1,0,184,255,2,0,23,0,0,0,1,15,2,0,8,234,2,0,23,0,0,0,1,15,3,0,192,20,3,0,23,0,0,0,1,15,4,0,56,50,1,0,23,0,0,0,1,15,5,0,80,65,1,0,23,0,0,0,1,15,6,0,32,22,4,0,23,0,0,0,1,15,7,0,200,246,3,0,23,0,0,0,1,15,8,0,248,212,3,0,23,0,0,0,1,15,15,0,24,192,4,0,0,0,0,0,118,112,104,106,46,48,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,51,227,226,61,1,0,16,1,118,112,104,106,46,48,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,4,243,92,201,1,0,16,1,118,112,104,106,46,48,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,221,93,222,80,1,0,16,1,118,112,104,106,46,48,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,213,211,59,172,1,0,16,1,118,112,104,106,46,48,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,159,48,97,7,1,0,16,1,118,112,104,106,46,48,56,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,245,43,92,90,1,0,16,1,118,112,104,106,46,48,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,153,109,61,130,1,0,16,1,118,112,104,106,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,240,216,199,50,1,0,16,1,118,112,104,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,153,175,27,197,5,0,32,0,118,112,104,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,119,60,232,60,5,0,32,0,118,112,104,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,224,8,36,79,5,0,32,0,118,112,104,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,80,2,246,159,5,0,32,0,118,112,104,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,221,26,14,122,5,0,32,0,118,112,104,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,117,202,65,47,5,0,32,0,118,112,104,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,237,142,73,100,5,0,32,0,118,112,104,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,63,67,242,23,5,0,32,0,118,112,104,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,172,220,69,80,10,0,16,1,118,112,104,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,89,14,182,134,10,0,16,1,118,112,104,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,51,125,131,225,12,0,64,0,118,112,104,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,144,205,211,251,12,0,64,0,118,104,50,106,46,48,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,134,241,232,154,1,0,16,1,118,104,50,106,46,48,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,83,191,250,226,1,0,16,1,118,104,50,106,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,36,246,52,222,1,0,16,1,118,104,50,106,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,151,152,59,106,1,0,16,1,118,104,50,106,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,41,192,33,176,1,0,16,1,118,104,50,106,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,255,61,135,172,1,0,16,1,118,104,50,106,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,156,206,239,234,1,0,16,1,118,104,50,106,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,9,115,17,1,0,16,1,118,104,50,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,170,221,2,59,5,0,32,0,118,104,50,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,102,222,64,78,5,0,32,0,118,104,50,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,201,0,29,179,5,0,32,0,118,104,50,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,171,227,155,20,5,0,32,0,118,104,50,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,99,189,9,205,5,0,32,0,118,104,50,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,21,44,24,224,5,0,32,0,118,104,50,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,246,196,141,119,5,0,32,0,118,104,50,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,29,157,93,96,5,0,32,0,118,104,50,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,121,247,185,103,10,0,16,1,118,104,50,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,203,95,241,170,10,0,16,1,118,104,50,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,253,46,146,56,12,0,64,0,118,104,50,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,175,48,36,110,12,0,64,0,118,97,117,95,50,51,97,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,38,135,230,251,2,0,16,1,118,97,117,95,50,50,97,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,189,27,215,14,2,0,16,1,118,97,45,53,109,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,110,114,251,177,4,0,32,0,118,97,45,55,109,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,205,136,101,76,4,0,32,0,118,97,45,49,109,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,55,206,26,11,4,0,32,0,118,97,45,51,109,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,6,231,223,68,4,0,32,0,118,97,95,48,57,46,49,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,110,68,153,122,3,0,16,0,118,97,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,14,81,48,222,5,0,64,0,118,97,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,172,164,16,6,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,118,97,54,51,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,0,0,0,0,0,0,24,105,111,98,49,46,49,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,98,112,114,103,49,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,167,61,121,49,0,0,0,8,118,97,106,95,51,54,98,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,106,141,121,29,1,0,16,1,118,97,106,95,52,50,98,46,49,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,51,2,114,15,1,0,16,1,118,97,106,95,51,55,98,46,49,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,23,75,65,36,1,0,16,1,118,97,106,95,52,51,98,46,49,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,108,176,180,52,1,0,16,1,118,97,106,95,51,52,98,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,237,154,199,135,1,0,16,1,118,97,106,95,52,48,98,46,49,48,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,208,75,11,33,1,0,16,1,118,97,106,95,51,53,98,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,159,166,13,107,1,0,16,1,118,97,106,95,52,49,98,46,49,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,164,200,66,101,1,0,16,1,118,97,95,48,57,46,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,168,250,61,24,4,0,32,0,118,97,95,48,49,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,181,18,19,196,4,0,32,0,118,97,95,49,51,46,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,105,126,83,69,4,0,32,0,118,97,95,48,53,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,233,212,101,112,4,0,32,0,118,97,95,50,52,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,207,28,25,87,4,0,32,0,118,97,95,49,55,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,91,90,79,5,4,0,32,0,118,97,95,51,56,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,126,161,23,225,4,0,32,0,118,97,95,51,50,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,178,64,79,59,4,0,32,0,118,97,95,49,48,46,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,205,80,39,214,4,0,32,0,118,97,95,48,50,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,37,3,89,17,4,0,32,0,118,97,95,49,52,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,131,71,47,220,4,0,32,0,118,97,95,48,54,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,172,51,232,6,4,0,32,0,118,97,95,50,53,46,55,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,144,6,217,81,4,0,32,0,118,97,95,49,56,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,192,23,120,161,4,0,32,0,118,97,95,51,57,46,57,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,81,47,177,176,4,0,32,0,118,97,95,51,51,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,247,58,0,75,4,0,32,0,118,97,95,50,51,46,49,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,110,68,153,122,3,0,16,0,118,97,95,51,48,46,49,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,14,81,48,222,5,0,64,0,118,97,95,51,49,46,49,51,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,172,164,16,6,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,118,97,50,50,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,116,213,124,189,0,0,0,8,108,119,105,111,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,12,185,82,173,0,0,0,8,105,111,99,49,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,129,32,24,13,0,0,0,8,118,97,109,106,46,48,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,34,55,93,245,1,0,16,1,118,97,109,106,46,48,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,227,218,203,253,1,0,16,1,118,97,109,106,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,146,126,73,108,1,0,16,1,118,97,109,106,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,182,236,187,241,1,0,16,1,118,97,109,106,46,48,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,132,173,103,16,1,0,16,1,118,97,109,106,46,48,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,31,244,137,75,1,0,16,1,118,97,109,106,46,48,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,172,74,10,252,1,0,16,1,118,97,109,106,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,107,194,112,146,1,0,16,1,118,97,109,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,153,175,27,197,5,0,32,0,118,97,109,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,119,60,232,60,5,0,32,0,118,97,109,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,224,8,36,79,5,0,32,0,118,97,109,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,80,2,246,159,5,0,32,0,118,97,109,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,60,36,135,189,5,0,32,0,118,97,109,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,95,133,236,175,5,0,32,0,118,97,109,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,37,54,3,58,5,0,32,0,118,97,109,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,137,106,255,43,5,0,32,0,118,97,109,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,213,133,182,100,10,0,16,1,118,97,109,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,199,151,124,207,10,0,16,1,118,97,109,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,178,222,57,74,12,0,64,0,118,97,109,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,3,92,62,26,12,0,64,0,26,0,0,0,255,255,174,0,0,0,0,0,27,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,26,0,0,0,1,3,0,0,192,255,2,0,26,0,0,0,1,3,3,0,208,75,4,0,26,0,0,0,1,3,2,0,8,49,4,0,26,0,0,0,1,3,1,0,152,21,4,0,0,0,0,0,254,0,4,0,72,202,5,0,26,0,0,0,1,12,0,0,160,203,8,0,26,0,0,0,1,12,8,0,80,246,3,0,26,0,0,0,1,12,12,0,248,38,7,0,26,0,0,0,1,12,4,0,112,212,3,0,0,0,0,0,254,0,2,0,72,8,1,0,26,0,0,0,1,32,0,0,56,111,3,0,26,0,0,0,1,32,32,0,104,134,3,0,0,0,0,0,254,0,2,0,168,234,7,0,26,0,0,0,1,64,64,0,96,135,7,0,26,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,26,0,0,0,1,128,128,0,96,135,7,0,26,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,27,0,0,0,1,1,1,0,96,135,7,0,27,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,200,30,2,0,27,0,0,0,1,2,2,0,240,242,5,0,27,0,0,0,1,2,0,0,216,104,6,0,0,0,0,0,254,0,2,0,88,160,1,0,27,0,0,0,1,4,4,0,136,86,1,0,27,0,0,0,1,4,0,0,184,147,6,0,0,0,0,0,254,0,2,0,96,46,8,0,27,0,0,0,1,8,8,0,192,255,2,0,27,0,0,0,1,8,0,0,208,75,4,0,0,0,0,0,254,0,16,0,32,4,2,0,27,0,0,0,1,240,160,0,144,160,3,0,27,0,0,0,1,240,176,0,96,135,3,0,27,0,0,0,1,240,192,0,32,136,7,0,27,0,0,0,1,240,208,0,40,88,7,0,27,0,0,0,1,240,224,0,96,39,7,0,27,0,0,0,1,240,16,0,32,202,2,0,27,0,0,0,1,240,48,0,120,113,6,0,27,0,0,0,1,240,32,0,232,228,5,0,27,0,0,0,1,240,240,0,144,251,6,0,27,0,0,0,1,240,64,0,120,211,6,0,27,0,0,0,1,240,144,0,184,164,6,0,27,0,0,0,1,240,128,0,80,74,6,0,27,0,0,0,1,240,112,0,192,32,6,0,27,0,0,0,1,240,96,0,192,234,2,0,27,0,0,0,1,240,80,0,32,242,5,0,27,0,0,0,1,240,0,0,16,227,4,0,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,115,116,23,137,1,0,16,1,109,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,198,165,108,76,1,0,16,1,109,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,82,22,41,98,1,0,16,1,116,117,114,116,95,118,105,100,46,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,108,105,113,158,1,0,16,1,109,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,242,0,38,125,1,0,16,1,116,117,114,116,95,115,110,100,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,154,15,195,240,2,0,16,1,116,117,114,116,95,115,110,100,46,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,60,196,95,175,2,0,16,1,116,117,114,116,95,118,105,100,46,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,82,157,153,229,4,0,32,0,116,117,114,116,95,118,105,100,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,85,214,255,195,4,0,32,0,116,117,114,116,108,101,115,46,99,108,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,221,2,239,243,7,0,32,0,16,0,0,0,255,255,0,0,0,0,0,0,17,0,0,0,255,255,3,0,0,0,0,0,18,0,0,0,255,255,14,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,17,0,0,0,1,3,3,0,8,49,4,0,17,0,0,0,1,3,2,0,72,246,3,0,17,0,0,0,1,3,1,0,64,47,7,0,17,0,0,0,1,3,0,0,144,166,1,0,0,0,0,0,254,0,4,0,32,4,2,0,18,0,0,0,1,6,0,0,144,102,8,0,18,0,0,0,1,6,4,0,224,127,8,0,18,0,0,0,1,6,6,0,32,123,8,0,18,0,0,0,1,6,2,0,192,110,8,0,0,0,0,0,254,0,2,0,200,30,2,0,18,0,0,0,1,8,8,0,120,97,1,0,18,0,0,0,1,8,0,0,96,19,1,0,101,112,114,45,49,50,50,54,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,248,222,73,245,1,0,16,1,101,112,114,45,49,50,50,54,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,137,178,205,247,1,0,16,1,101,112,114,45,49,50,50,54,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,145,225,60,60,1,0,16,1,101,112,114,45,49,50,50,54,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,154,221,218,140,1,0,16,1,49,50,50,54,56,46,97,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,127,192,218,224,2,0,32,0,49,50,50,54,57,46,97,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,144,135,122,69,2,0,32,0,49,50,50,55,48,46,97,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,91,2,252,105,2,0,32,0,49,50,50,55,54,46,98,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,31,215,139,131,3,0,32,0,49,50,50,56,48,46,98,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,203,87,154,99,3,0,32,0,49,50,50,55,55,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,162,107,107,241,3,0,32,0,49,50,50,56,49,46,98,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,127,7,241,30,3,0,32,0,49,50,50,55,56,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,183,6,29,150,3,0,32,0,49,50,50,56,50,46,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,225,30,103,232,3,0,32,0,49,50,50,55,57,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,177,159,22,122,3,0,32,0,49,50,50,56,51,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,133,160,15,174,3,0,32,0,101,112,114,45,49,50,50,55,49,46,97,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,82,30,103,153,4,0,16,1,101,112,114,45,49,50,50,55,50,46,97,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,159,230,247,124,8,0,64,0,101,112,114,45,49,50,50,55,51,46,97,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,139,187,240,40,8,0,64,0,101,112,114,45,49,50,50,55,52,46,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,196,240,7,130,8,0,64,0,101,112,114,45,49,50,50,55,53,46,97,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,61,60,47,24,8,0,64,0,51,49,55,45,48,48,57,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,228,227,118,246,0,0,0,8,17,0,0,0,255,255,252,0,0,0,0,0,18,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,3,0,200,30,2,0,17,0,0,0,1,3,0,0,72,60,1,0,17,0,0,0,1,3,2,0,88,51,1,0,17,0,0,0,1,3,3,0,96,19,1,0,0,0,0,0,254,0,8,0,40,148,2,0,17,0,0,0,1,28,16,0,208,168,3,0,17,0,0,0,1,28,12,0,176,109,2,0,17,0,0,0,1,28,8,0,64,119,3,0,17,0,0,0,1,28,28,0,88,229,1,0,17,0,0,0,1,28,24,0,176,123,2,0,17,0,0,0,1,28,20,0,184,202,1,0,17,0,0,0,1,28,4,0,8,192,1,0,17,0,0,0,1,28,0,0,120,7,5,0,0,0,0,0,254,0,6,0,112,177,1,0,17,0,0,0,1,224,224,0,192,255,2,0,17,0,0,0,1,224,192,0,208,75,4,0,17,0,0,0,1,224,160,0,8,49,4,0,17,0,0,0,1,224,128,0,152,21,4,0,17,0,0,0,1,224,96,0,72,246,3,0,17,0,0,0,1,224,64,0,72,0,3,0,0,0,0,0,254,0,4,0,0,70,2,0,18,0,0,0,1,3,0,0,56,233,4,0,18,0,0,0,1,3,3,0,16,42,5,0,18,0,0,0,1,3,2,0,152,11,5,0,18,0,0,0,1,3,1,0,24,27,4,0,0,0,0,0,254,0,4,0,192,56,2,0,18,0,0,0,1,12,0,0,176,193,3,0,18,0,0,0,1,12,4,0,208,196,4,0,18,0,0,0,1,12,8,0,56,233,4,0,18,0,0,0,1,12,12,0,16,42,5,0,0,0,0,0,254,0,4,0,128,129,4,0,18,0,0,0,1,48,32,0,208,75,4,0,18,0,0,0,1,48,48,0,8,49,4,0,18,0,0,0,1,48,16,0,152,21,4,0,18,0,0,0,1,48,0,0,72,246,3,0,0,0,0,0,254,0,2,0,232,80,3,0,18,0,0,0,1,64,64,0,96,135,7,0,18,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,72,217,6,0,18,0,0,0,1,128,0,0,56,111,3,0,18,0,0,0,1,128,128,0,104,134,3,0,0,0,0,0,168,86,7,0,1,0,0,0,40,240,146,0,248,191,2,0,24,38,7,0,1,0,0,0,19,248,146,0,184,160,2,0,56,210,6,0,1,0,0,0,168,0,147,0,192,135,2,0,24,163,6,0,1,0,0,0,169,0,147,0,240,108,2,0,152,122,6,0,1,0,0,0,170,0,147,0,96,82,2,0,192,72,6,0,1,0,0,0,171,0,147,0,32,56,2,0,200,110,3,0,1,0,0,0,172,0,147,0,152,30,2,0,120,89,3,0,1,0,0,0,173,0,147,0,232,10,2,0,40,246,1,0,1,0,0,0,41,240,146,0,64,246,1,0,144,236,1,0,1,0,0,0,20,248,146,0,136,224,1,0,176,223,1,0,1,0,0,0,176,0,147,0,72,198,1,0,192,209,1,0,1,0,0,0,177,0,147,0,24,182,1,0,24,198,1,0,1,0,0,0,178,0,147,0,40,167,1,0,120,189,1,0,1,0,0,0,179,0,147,0,200,149,1,0,224,22,1,0,1,0,0,0,180,0,147,0,56,126,1,0,160,14,1,0,1,0,0,0,181,0,147,0,32,101,1,0,88,212,3,0,1,0,0,0,232,219,146,0,40,185,3,0,16,17,8,0,1,0,0,0,18,248,146,0,224,12,8,0,72,65,1,0,9,0,0,0,24,6,147,0,32,58,1,0,48,50,1,0,9,0,0,0,25,6,147,0,32,58,1,0,19,0,0,0,255,255,254,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,19,0,0,0,1,1,0,0,120,97,1,0,19,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,2,2,0,96,135,7,0,19,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,4,4,0,96,135,7,0,19,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,19,0,0,0,1,48,0,0,32,136,7,0,19,0,0,0,1,48,16,0,40,88,7,0,19,0,0,0,1,48,32,0,96,39,7,0,19,0,0,0,1,48,48,0,144,251,6,0,0,0,0,0,254,0,4,0,160,123,6,0,19,0,0,0,1,192,192,0,184,164,6,0,19,0,0,0,1,192,128,0,80,74,6,0,19,0,0,0,1,192,64,0,192,32,6,0,19,0,0,0,1,192,0,0,32,242,5,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,3,2,0,80,246,3,0,20,0,0,0,1,3,3,0,80,124,6,0,20,0,0,0,1,3,1,0,112,212,3,0,20,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,64,37,5,0,20,0,0,0,1,12,0,0,176,204,7,0,20,0,0,0,1,12,12,0,104,197,7,0,20,0,0,0,1,12,4,0,224,190,7,0,20,0,0,0,1,12,8,0,152,183,7,0,0,0,0,0,254,0,0,0,128,129,4,0,20,0,0,0,1,48,32,0,208,75,4,0,20,0,0,0,1,48,48,0,8,49,4,0,20,0,0,0,1,48,16,0,152,21,4,0,20,0,0,0,1,48,0,0,72,246,3,0,0,0,0,0,254,0,2,0,104,159,3,0,20,0,0,0,1,64,0,0,56,111,3,0,20,0,0,0,1,64,64,0,104,134,3,0,0,0,0,0,19,0,0,0,255,255,254,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,19,0,0,0,1,1,0,0,120,97,1,0,19,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,2,2,0,96,135,7,0,19,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,4,4,0,96,135,7,0,19,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,4,0,184,179,7,0,20,0,0,0,1,8,8,0,96,135,7,0,20,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,19,0,0,0,1,48,16,0,96,39,7,0,19,0,0,0,1,48,48,0,144,251,6,0,19,0,0,0,1,48,0,0,120,211,6,0,19,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,19,0,0,0,1,192,64,0,96,39,7,0,19,0,0,0,1,192,192,0,144,251,6,0,19,0,0,0,1,192,0,0,120,211,6,0,19,0,0,0,1,192,128,0,184,164,6,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,3,2,0,80,246,3,0,20,0,0,0,1,3,3,0,80,124,6,0,20,0,0,0,1,3,1,0,112,212,3,0,20,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,64,37,5,0,20,0,0,0,1,12,0,0,56,176,7,0,20,0,0,0,1,12,12,0,8,172,7,0,20,0,0,0,1,12,4,0,56,168,7,0,20,0,0,0,1,12,8,0,248,163,7,0,0,0,0,0,254,0,0,0,128,129,4,0,20,0,0,0,1,48,32,0,208,75,4,0,20,0,0,0,1,48,48,0,8,49,4,0,20,0,0,0,1,48,16,0,152,21,4,0,20,0,0,0,1,48,0,0,72,246,3,0,0,0,0,0,254,0,2,0,104,159,3,0,20,0,0,0,1,64,0,0,56,111,3,0,20,0,0,0,1,64,64,0,104,134,3,0,57,54,51,45,106,50,51,46,106,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,226,20,115,247,0,0,16,1,57,54,51,45,106,50,52,46,107,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,211,98,246,71,0,0,16,1,57,54,51,45,106,50,49,46,106,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,232,159,238,123,0,0,16,1,57,54,51,45,106,50,50,46,107,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,159,208,254,46,0,0,16,1,57,54,51,101,50,48,46,103,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,214,166,146,22,0,0,16,1,57,54,51,97,50,56,46,104,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,105,71,219,0,0,32,0,57,54,51,97,50,57,46,107,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,46,205,105,128,0,0,32,0,57,54,51,97,49,55,46,104,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,68,154,35,181,0,0,32,0,57,54,51,97,49,56,46,104,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,239,173,81,221,0,0,32,0,57,54,51,97,49,53,46,107,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,237,78,50,31,0,0,32,0,57,54,51,97,49,54,46,107,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,132,153,189,212,0,0,32,0,57,54,51,97,51,48,46,103,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,128,38,216,171,0,0,32,0,57,54,51,97,51,49,46,103,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,28,74,0,248,0,0,32,0,57,54,51,97,50,54,46,99,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,99,48,172,226,0,0,64,0,57,54,51,97,50,55,46,100,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,75,103,253,45,0,0,64,0,57,54,51,97,50,53,46,100,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,199,120,160,252,0,0,64,0,184,40,2,0,1,0,0,0,72,234,148,0,248,191,2,0,184,164,8,0,1,0,0,0,73,234,148,0,64,246,1,0,104,28,8,0,1,0,0,0,74,234,148,0,232,209,1,0,64,183,7,0,1,0,0,0,75,234,148,0,104,195,5,0,56,210,6,0,1,0,0,0,138,233,148,0,192,135,2,0,24,163,6,0,1,0,0,0,139,233,148,0,240,108,2,0,152,122,6,0,1,0,0,0,136,233,148,0,96,82,2,0,192,72,6,0,1,0,0,0,137,233,148,0,32,56,2,0,48,123,2,0,1,0,0,0,140,233,148,0,152,30,2,0,96,69,2,0,1,0,0,0,141,233,148,0,232,10,2,0,176,223,1,0,1,0,0,0,202,232,148,0,72,198,1,0,192,209,1,0,1,0,0,0,203,232,148,0,24,182,1,0,24,198,1,0,1,0,0,0,200,232,148,0,40,167,1,0,120,189,1,0,1,0,0,0,201,232,148,0,200,149,1,0,248,187,8,0,1,0,0,0,204,232,148,0,56,126,1,0,184,179,8,0,1,0,0,0,205,232,148,0,32,101,1,0,192,122,8,0,1,0,0,0,42,232,148,0,208,174,1,0,40,116,8,0,1,0,0,0,43,232,148,0,48,160,1,0,72,110,8,0,1,0,0,0,40,232,148,0,160,140,1,0,184,102,8,0,1,0,0,0,41,232,148,0,56,112,1,0,240,45,8,0,1,0,0,0,44,232,148,0,32,92,1,0,40,38,8,0,1,0,0,0,45,232,148,0,64,77,1,0,248,16,8,0,1,0,0,0,2,232,148,0,32,231,8,0,192,12,8,0,1,0,0,0,3,232,148,0,88,214,8,0,224,5,8,0,1,0,0,0,0,232,148,0,224,202,8,0,144,1,8,0,1,0,0,0,1,232,148,0,72,193,8,0,72,204,7,0,1,0,0,0,4,232,148,0,144,180,8,0,208,196,7,0,1,0,0,0,5,232,148,0,208,164,8,0,88,212,3,0,1,0,0,0,248,221,146,0,40,185,3,0,56,122,5,0,1,0,0,0,76,234,148,0,224,12,8,0,0,105,5,0,1,0,0,0,77,234,148,0,128,176,7,0,152,120,4,0,1,0,0,0,78,234,148,0,248,114,7,0,112,109,5,0,1,0,0,0,79,234,148,0,32,105,5,0,248,5,8,0,9,0,0,0,240,94,147,0,32,58,1,0,144,250,7,0,9,0,0,0,241,94,147,0,32,58,1,0,248,241,7,0,9,0,0,0,242,94,147,0,32,58,1,0,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,94,0,0,0,0,0,21,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,19,0,0,0,1,15,2,0,80,252,6,0,19,0,0,0,1,15,5,0,16,242,7,0,19,0,0,0,1,15,8,0,104,236,7,0,19,0,0,0,1,15,4,0,120,113,6,0,19,0,0,0,1,15,1,0,232,228,5,0,19,0,0,0,1,15,15,0,128,230,7,0,19,0,0,0,1,15,3,0,56,141,7,0,19,0,0,0,1,15,7,0,120,211,6,0,19,0,0,0,1,15,14,0,184,164,6,0,19,0,0,0,1,15,6,0,24,1,7,0,19,0,0,0,1,15,13,0,80,74,6,0,19,0,0,0,1,15,12,0,192,32,6,0,19,0,0,0,1,15,11,0,192,234,2,0,19,0,0,0,1,15,10,0,32,242,5,0,19,0,0,0,1,15,9,0,176,192,2,0,19,0,0,0,1,15,0,0,16,227,4,0,0,0,0,0,254,0,15,0,160,123,6,0,19,0,0,0,1,240,32,0,80,252,6,0,19,0,0,0,1,240,80,0,16,242,7,0,19,0,0,0,1,240,128,0,104,236,7,0,19,0,0,0,1,240,64,0,120,113,6,0,19,0,0,0,1,240,16,0,232,228,5,0,19,0,0,0,1,240,240,0,128,230,7,0,19,0,0,0,1,240,48,0,56,141,7,0,19,0,0,0,1,240,112,0,120,211,6,0,19,0,0,0,1,240,224,0,184,164,6,0,19,0,0,0,1,240,96,0,24,1,7,0,19,0,0,0,1,240,208,0,80,74,6,0,19,0,0,0,1,240,192,0,192,32,6,0,19,0,0,0,1,240,176,0,192,234,2,0,19,0,0,0,1,240,160,0,32,242,5,0,19,0,0,0,1,240,144,0,176,192,2,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,3,3,0,192,255,2,0,20,0,0,0,1,3,2,0,208,75,4,0,20,0,0,0,1,3,1,0,8,49,4,0,20,0,0,0,1,3,0,0,72,246,3,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,96,96,0,80,246,3,0,20,0,0,0,1,96,64,0,248,38,7,0,20,0,0,0,1,96,32,0,48,123,8,0,20,0,0,0,1,96,0,0,8,117,8,0,0,0,0,0,254,0,2,0,168,234,7,0,20,0,0,0,1,128,128,0,96,135,7,0,20,0,0,0,1,128,0,0])
.concat([152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,21,0,0,0,1,1,1,0,96,135,7,0,21,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,184,89,6,0,21,0,0,0,1,4,4,0,96,135,7,0,21,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,57,54,51,45,117,50,51,46,106,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,72,199,190,88,0,0,16,1,57,54,51,45,117,50,52,46,107,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,141,124,232,220,0,0,16,1,57,54,51,45,117,50,49,46,106,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,173,94,206,171,0,0,16,1,57,54,51,45,117,50,50,46,107,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,107,141,204,78,0,0,16,1,57,54,51,101,50,48,46,103,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,214,166,146,22,0,0,16,1,57,54,51,97,50,56,46,104,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,105,71,219,0,0,32,0,57,54,51,97,50,57,46,107,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,46,205,105,128,0,0,32,0,57,54,51,97,49,55,46,104,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,68,154,35,181,0,0,32,0,57,54,51,97,49,56,46,104,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,239,173,81,221,0,0,32,0,57,54,51,97,49,53,46,107,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,237,78,50,31,0,0,32,0,57,54,51,97,49,54,46,107,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,132,153,189,212,0,0,32,0,57,54,51,97,51,48,46,103,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,128,38,216,171,0,0,32,0,57,54,51,97,51,49,46,103,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,28,74,0,248,0,0,32,0,57,54,51,97,50,54,46,99,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,99,48,172,226,0,0,64,0,57,54,51,97,50,55,46,100,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,75,103,253,45,0,0,64,0,57,54,51,97,50,53,46,100,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,199,120,160,252,0,0,64,0,112,105,116,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,204,254,175,113,0,0,16,1,112,105,116,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,205,99,64,137,0,0,16,1,112,105,116,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,67,133,72,27,0,0,16,1,112,105,116,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,72,232,65,233,0,0,16,1,112,105,116,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,149,60,100,224,0,0,16,1,112,105,116,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,182,223,121,27,0,0,16,1,112,105,116,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,252,42,80,105,0,0,32,0,112,105,116,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,83,179,1,217,0,0,32,0,56,50,115,49,50,51,46,105,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,103,181,88,167,0,0,32,0,105,99,49,51,95,49,116,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,186,85,229,147,1,0,16,1,105,99,49,52,95,50,116,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,39,173,231,45,1,0,16,1,105,99,49,53,95,51,116,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,11,117,95,3,1,0,16,1,105,99,49,54,95,52,116,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,92,107,40,97,1,0,16,1,105,99,49,55,95,53,116,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,104,143,74,67,1,0,16,1,105,99,49,56,95,54,116,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,134,199,76,220,1,0,16,1,105,99,53,54,95,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,41,31,20,122,2,0,16,1,105,99,53,53,95,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,193,151,132,33,2,0,16,1,105,99,51,48,95,50,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,191,247,204,104,4,0,32,0,105,99,51,49,95,49,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,153,201,72,74,4,0,32,0,54,51,51,49,45,49,106,46,56,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,196,43,101,36,7,0,32,0,14,0,0,0,255,255,0,0,0,0,0,0,15,0,0,0,255,255,3,0,0,0,0,0,16,0,0,0,255,255,14,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,15,0,0,0,1,3,3,0,8,49,4,0,15,0,0,0,1,3,2,0,152,21,4,0,15,0,0,0,1,3,1,0,72,246,3,0,15,0,0,0,1,3,0,0,240,64,4,0,0,0,0,0,254,0,4,0,32,4,2,0,16,0,0,0,1,6,2,0,176,45,8,0,16,0,0,0,1,6,4,0,224,127,8,0,16,0,0,0,1,6,6,0,32,123,8,0,16,0,0,0,1,6,0,0,192,110,8,0,0,0,0,0,254,0,2,0,200,30,2,0,16,0,0,0,1,8,8,0,120,97,1,0,16,0,0,0,1,8,0,0,96,19,1,0,101,112,114,45,49,50,50,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,81,155,142,51,1,0,16,1,101,112,114,45,49,50,50,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,121,135,5,251,1,0,16,1,101,112,114,45,49,50,50,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,65,167,125,47,2,0,32,0,101,112,114,45,49,50,50,48,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,197,142,229,166,2,0,32,0,101,112,114,45,49,50,50,48,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,35,142,233,10,2,0,32,0,101,112,114,45,49,50,49,54,57,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,101,97,204,218,3,0,32,0,101,112,114,45,49,50,49,55,48,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,66,78,53,135,3,0,32,0,101,112,114,45,49,50,50,48,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,153,220,149,102,4,0,16,1,51,49,55,45,48,48,57,51,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,66,68,6,224,5,0,16,1,17,0,0,0,255,255,253,0,0,0,0,0,18,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,168,234,7,0,17,0,0,0,1,2,2,0,96,135,7,0,17,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,17,0,0,0,1,48,32,0,80,246,3,0,17,0,0,0,1,48,48,0,248,38,7,0,17,0,0,0,1,48,16,0,112,212,3,0,17,0,0,0,1,48,0,0,248,160,5,0,0,0,0,0,254,0,16,0,200,87,7,0,18,0,0,0,1,15,7,0,80,252,6,0,18,0,0,0,1,15,8,0,16,242,7,0,18,0,0,0,1,15,9,0,104,236,7,0,18,0,0,0,1,15,5,0,176,51,4,0,18,0,0,0,1,15,4,0,56,24,4,0,18,0,0,0,1,15,15,0,128,230,7,0,18,0,0,0,1,15,1,0,72,216,3,0,18,0,0,0,1,15,2,0,24,188,3,0,18,0,0,0,1,15,3,0,176,162,3,0,18,0,0,0,1,15,6,0,120,211,6,0,18,0,0,0,1,15,14,0,184,164,6,0,18,0,0,0,1,15,13,0,80,74,6,0,18,0,0,0,1,15,12,0,192,32,6,0,18,0,0,0,1,15,11,0,192,234,2,0,18,0,0,0,1,15,10,0,32,242,5,0,18,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,18,0,0,0,1,240,112,0,80,252,6,0,18,0,0,0,1,240,128,0,16,242,7,0,18,0,0,0,1,240,144,0,104,236,7,0,18,0,0,0,1,240,80,0,176,51,4,0,18,0,0,0,1,240,64,0,56,24,4,0,18,0,0,0,1,240,240,0,128,230,7,0,18,0,0,0,1,240,16,0,72,216,3,0,18,0,0,0,1,240,32,0,24,188,3,0,18,0,0,0,1,240,48,0,176,162,3,0,18,0,0,0,1,240,96,0,120,211,6,0,18,0,0,0,1,240,224,0,184,164,6,0,18,0,0,0,1,240,208,0,80,74,6,0,18,0,0,0,1,240,192,0,192,32,6,0,18,0,0,0,1,240,176,0,192,234,2,0,18,0,0,0,1,240,160,0,32,242,5,0,18,0,0,0,1,240,0,0,208,236,2,0,17,0,0,0,255,255,255,0,0,0,0,0,18,0,0,0,255,255,253,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,17,0,0,0,1,15,7,0,80,252,6,0,17,0,0,0,1,15,8,0,16,242,7,0,17,0,0,0,1,15,9,0,104,236,7,0,17,0,0,0,1,15,5,0,176,51,4,0,17,0,0,0,1,15,4,0,56,24,4,0,17,0,0,0,1,15,15,0,128,230,7,0,17,0,0,0,1,15,1,0,72,216,3,0,17,0,0,0,1,15,2,0,24,188,3,0,17,0,0,0,1,15,3,0,176,162,3,0,17,0,0,0,1,15,6,0,120,211,6,0,17,0,0,0,1,15,14,0,184,164,6,0,17,0,0,0,1,15,13,0,80,74,6,0,17,0,0,0,1,15,12,0,192,32,6,0,17,0,0,0,1,15,11,0,192,234,2,0,17,0,0,0,1,15,10,0,32,242,5,0,17,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,17,0,0,0,1,240,112,0,80,252,6,0,17,0,0,0,1,240,128,0,16,242,7,0,17,0,0,0,1,240,144,0,104,236,7,0,17,0,0,0,1,240,80,0,176,51,4,0,17,0,0,0,1,240,64,0,56,24,4,0,17,0,0,0,1,240,240,0,128,230,7,0,17,0,0,0,1,240,16,0,72,216,3,0,17,0,0,0,1,240,32,0,24,188,3,0,17,0,0,0,1,240,48,0,176,162,3,0,17,0,0,0,1,240,96,0,120,211,6,0,17,0,0,0,1,240,224,0,184,164,6,0,17,0,0,0,1,240,208,0,80,74,6,0,17,0,0,0,1,240,192,0,192,32,6,0,17,0,0,0,1,240,176,0,192,234,2,0,17,0,0,0,1,240,160,0,32,242,5,0,17,0,0,0,1,240,0,0,208,236,2,0,0,0,0,0,254,0,2,0,168,234,7,0,18,0,0,0,1,2,2,0,96,135,7,0,18,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,18,0,0,0,1,48,32,0,80,246,3,0,18,0,0,0,1,48,48,0,248,38,7,0,18,0,0,0,1,48,16,0,112,212,3,0,18,0,0,0,1,48,0,0,248,160,5,0,116,101,116,114,48,54,46,117,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,147,214,77,136,0,0,16,1,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,21,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,3,0,88,178,6,0,21,0,0,0,1,3,0,0,192,172,6,0,21,0,0,0,1,3,1,0,32,166,6,0,21,0,0,0,1,3,2,0,88,161,6,0,0,0,0,0,21,0,0,0,255,255,15,0,0,0,0,0,22,0,0,0,255,255,63,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,21,0,0,0,1,3,3,0,8,49,4,0,21,0,0,0,1,3,2,0,152,21,4,0,21,0,0,0,1,3,1,0,72,246,3,0,21,0,0,0,1,3,0,0,72,0,3,0,0,0,0,0,254,0,2,0,232,168,4,0,21,0,0,0,1,4,4,0,160,39,6,0,21,0,0,0,1,4,0,0,208,26,6,0,0,0,0,0,254,0,2,0,240,83,4,0,21,0,0,0,1,8,8,0,232,23,6,0,21,0,0,0,1,8,0,0,248,211,5,0,0,0,0,0,254,0,4,0,64,37,5,0,21,0,0,0,1,12,12,0,16,223,3,0,21,0,0,0,1,12,4,0,192,192,3,0,21,0,0,0,1,12,8,0,80,167,3,0,21,0,0,0,1,12,0,0,128,141,3,0,0,0,0,0,254,0,2,0,168,234,7,0,21,0,0,0,1,16,16,0,96,135,7,0,21,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,22,0,0,0,1,3,1,0,96,39,7,0,22,0,0,0,1,3,3,0,144,251,6,0,22,0,0,0,1,3,2,0,184,164,6,0,22,0,0,0,1,3,0,0,16,227,4,0,0,0,0,0,254,0,4,0,160,123,6,0,22,0,0,0,1,12,4,0,96,39,7,0,22,0,0,0,1,12,12,0,144,251,6,0,22,0,0,0,1,12,0,0,120,211,6,0,22,0,0,0,1,12,8,0,184,164,6,0,0,0,0,0,254,0,0,0,144,212,8,0,22,0,0,0,1,32,32,0,96,135,7,0,22,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,22,0,0,0,1,192,192,0,56,111,3,0,22,0,0,0,1,192,128,0,240,139,2,0,22,0,0,0,1,192,64,0,24,129,2,0,22,0,0,0,1,192,0,0,104,134,3,0,0,0,0,0,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,254,25,232,123,1,0,16,1,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,94,58,200,112,1,0,16,1,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,160,181,94,71,1,0,16,1,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,67,25,167,32,1,0,16,1,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,220,242,196,114,1,0,16,1,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,228,43,78,250,1,0,16,1,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,212,177,1,215,4,0,32,0,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,253,188,19,49,4,0,32,0,98,112,114,111,109,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,63,245,76,43,7,0,32,0,55,102,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,222,177,53,67,1,0,16,1,115,117,112,101,114,103,46,119,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,174,189,234,221,1,0,16,1,115,117,112,101,114,103,46,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,83,247,99,148,1,0,16,1,115,117,112,101,114,103,46,122,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,53,46,49,230,1,0,16,1,103,97,108,109,105,100,119,46,49,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,152,207,222,132,4,0,32,0,103,97,108,109,105,100,119,46,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,158,218,26,195,4,0,32,0,54,108,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,103,148,172,195,7,0,32,0,12,0,0,0,255,255,0,0,0,0,0,0,13,0,0,0,255,255,0,0,0,0,0,0,14,0,0,0,255,255,1,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,12,0,0,0,1,32,0,0,120,97,1,0,12,0,0,0,1,32,32,0,96,19,1,0,0,0,0,0,254,0,2,0,232,75,4,0,12,0,0,0,1,64,0,0,96,135,7,0,12,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,4,0,32,4,2,0,13,0,0,0,1,192,64,0,224,127,8,0,13,0,0,0,1,192,0,0,32,123,8,0,13,0,0,0,1,192,128,0,192,110,8,0,13,0,0,0,1,192,192,0,104,151,6,0,0,0,0,0,254,0,4,0,64,37,5,0,14,0,0,0,1,3,1,0,152,120,3,0,14,0,0,0,1,3,2,0,136,120,6,0,14,0,0,0,1,3,3,0,176,114,3,0,14,0,0,0,1,3,0,0,120,7,5,0,0,0,0,0,254,0,2,0,128,129,4,0,14,0,0,0,1,4,0,0,8,49,4,0,14,0,0,0,1,4,4,0,72,246,3,0,18,0,0,0,255,255,127,0,0,0,0,0,19,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,8,0,200,87,7,0,18,0,0,0,1,7,0,0,96,135,3,0,18,0,0,0,1,7,1,0,32,136,7,0,18,0,0,0,1,7,2,0,40,88,7,0,18,0,0,0,1,7,3,0,96,39,7,0,18,0,0,0,1,7,7,0,144,251,6,0,18,0,0,0,1,7,6,0,184,164,6,0,18,0,0,0,1,7,5,0,80,74,6,0,18,0,0,0,1,7,4,0,192,32,6,0,0,0,0,0,254,0,8,0,160,123,6,0,18,0,0,0,1,56,0,0,96,135,3,0,18,0,0,0,1,56,8,0,32,136,7,0,18,0,0,0,1,56,16,0,40,88,7,0,18,0,0,0,1,56,24,0,96,39,7,0,18,0,0,0,1,56,56,0,144,251,6,0,18,0,0,0,1,56,48,0,184,164,6,0,18,0,0,0,1,56,40,0,80,74,6,0,18,0,0,0,1,56,32,0,192,32,6,0,0,0,0,0,254,0,2,0,168,234,7,0,18,0,0,0,1,128,128,0,96,135,7,0,18,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,19,0,0,0,1,3,2,0,208,75,4,0,19,0,0,0,1,3,3,0,8,49,4,0,19,0,0,0,1,3,1,0,152,21,4,0,19,0,0,0,1,3,0,0,72,246,3,0,0,0,0,0,254,0,4,0,72,202,5,0,19,0,0,0,1,12,8,0,80,246,3,0,19,0,0,0,1,12,12,0,248,38,7,0,19,0,0,0,1,12,4,0,112,212,3,0,19,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,4,0,64,37,5,0,19,0,0,0,1,96,64,0,40,160,4,0,19,0,0,0,1,96,96,0,0,34,7,0,19,0,0,0,1,96,32,0,40,30,7,0,19,0,0,0,1,96,0,0,120,7,5,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,128,128,0,96,135,7,0,19,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,115,102,120,106,46,48,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,121,123,65,167,1,0,16,1,115,102,120,106,46,48,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,180,103,119,175,1,0,16,1,115,102,120,106,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,245,24,255,244,1,0,16,1,115,102,120,106,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,112,3,13,38,1,0,16,1,115,102,120,106,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,42,208,36,19,1,0,16,1,115,102,120,106,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,16,111,231,45,1,0,16,1,115,102,120,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,63,174,47,100,1,0,16,1,115,102,120,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,117,210,148,207,5,0,32,0,115,102,120,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,175,3,183,94,5,0,32,0,115,102,120,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,15,14,166,255,5,0,32,0,115,102,120,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,197,37,232,52,5,0,32,0,115,102,120,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,231,50,204,183,5,0,32,0,115,102,120,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,24,173,118,131,5,0,32,0,115,102,120,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,54,179,177,245,5,0,32,0,115,102,120,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,107,92,157,69,5,0,32,0,115,102,120,46,50,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,175,84,40,227,5,0,32,0,115,102,120,46,50,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,39,41,15,118,5,0,32,0,115,102,120,46,50,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,8,2,233,30,5,0,32,0,115,102,120,46,50,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,15,64,20,248,5,0,32,0,115,102,120,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,53,136,123,180,10,0,16,1,115,102,120,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,99,34,0,10,0,16,1,115,102,120,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,118,212,219,155,12,0,64,0,115,102,120,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,171,58,94,160,12,0,64,0,115,115,102,117,100,46,48,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,248,218,213,250,1,0,16,1,115,115,102,117,100,46,48,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,101,175,49,13,1,0,16,1,115,115,102,117,100,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,239,81,198,117,1,0,16,1,115,115,102,117,100,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,236,195,133,1,0,16,1,115,115,102,117,100,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,4,37,126,36,1,0,16,1,115,115,102,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,117,210,148,207,5,0,32,0,115,115,102,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,175,3,183,94,5,0,32,0,115,115,102,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,15,14,166,255,5,0,32,0,115,115,102,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,197,37,232,52,5,0,32,0,115,115,102,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,231,50,204,183,5,0,32,0,115,115,102,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,24,173,118,131,5,0,32,0,115,115,102,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,54,179,177,245,5,0,32,0,115,115,102,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,107,92,157,69,5,0,32,0,115,115,102,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,140,126,36,235,10,0,16,1,115,115,102,46,113,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,92,218,249,166,12,0,64,0,115,115,102,46,113,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,38,174,102,140,12,0,64,0,115,115,102,46,113,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,202,194,92,105,12,0,64,0,115,115,102,46,113,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,50,190,158,157,12,0,64,0,115,115,102,46,113,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,183,231,112,71,12,0,64,0,115,115,102,46,113,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,81,201,121,78,12,0,64,0,115,115,102,46,113,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,19,67,209,205,12,0,64,0,115,115,102,46,113,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,140,8,90,111,12,0,64,0,115,102,120,117,46,48,51,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,158,104,255,214,1,0,16,1,115,102,120,117,46,48,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,253,95,43,83,1,0,16,1,115,102,120,117,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,222,198,163,255,1,0,16,1,115,102,120,117,46,48,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,43,56,249,131,1,0,16,1,115,102,120,117,46,48,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,232,115,182,106,1,0,16,1,115,102,120,117,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,16,24,199,179,1,0,16,1,115,102,120,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,63,174,47,100,1,0,16,1,115,102,120,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,117,210,148,207,5,0,32,0,115,102,120,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,175,3,183,94,5,0,32,0,115,102,120,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,15,14,166,255,5,0,32,0,115,102,120,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,197,37,232,52,5,0,32,0,115,102,120,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,231,50,204,183,5,0,32,0,115,102,120,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,24,173,118,131,5,0,32,0,115,102,120,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,54,179,177,245,5,0,32,0,115,102,120,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,107,92,157,69,5,0,32,0,115,102,120,46,50,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,175,84,40,227,5,0,32,0,115,102,120,46,50,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,39,41,15,118,5,0,32,0,115,102,120,46,50,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,8,2,233,30,5,0,32,0,115,102,120,46,50,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,15,64,20,248,5,0,32,0,115,102,120,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,53,136,123,180,10,0,16,1,115,102,120,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,99,34,0,10,0,16,1,115,102,120,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,118,212,219,155,12,0,64,0,115,102,120,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,171,58,94,160,12,0,64,0,115,102,120,101,100,46,48,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,80,216,153,237,1,0,16,1,115,102,120,101,100,46,48,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,100,179,217,56,1,0,16,1,115,102,120,101,100,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,208,88,51,198,1,0,16,1,115,102,120,101,100,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,8,152,178,204,1,0,16,1,115,102,120,101,100,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,130,73,249,97,1,0,16,1,115,102,120,101,100,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,108,195,153,211,1,0,16,1,115,102,120,101,100,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,188,93,123,49,1,0,16,1,115,102,120,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,117,210,148,207,5,0,32,0,115,102,120,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,175,3,183,94,5,0,32,0,115,102,120,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,15,14,166,255,5,0,32,0,115,102,120,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,197,37,232,52,5,0,32,0,115,102,120,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,231,50,204,183,5,0,32,0,115,102,120,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,24,173,118,131,5,0,32,0,115,102,120,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,54,179,177,245,5,0,32,0,115,102,120,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,107,92,157,69,5,0,32,0,115,102,120,46,50,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,175,84,40,227,5,0,32,0,115,102,120,46,50,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,39,41,15,118,5,0,32,0,115,102,120,46,50,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,8,2,233,30,5,0,32,0,115,102,120,46,50,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,15,64,20,248,5,0,32,0,115,102,120,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,53,136,123,180,10,0,16,1,115,102,120,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,99,34,0,10,0,16,1,115,102,120,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,118,212,219,155,12,0,64,0,115,102,120,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,171,58,94,160,12,0,64,0,115,115,102,101,46,48,51,116,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,9,132,106,73,1,0,16,1,115,115,102,101,46,48,52,116,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,139,193,69,75,1,0,16,1,115,115,102,101,46,48,53,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,68,100,156,106,1,0,16,1,115,115,102,101,46,48,54,116,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,195,79,148,228,1,0,16,1,115,115,102,101,46,48,55,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,130,71,159,44,1,0,16,1,115,115,102,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,117,210,148,207,5,0,32,0,115,115,102,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,175,3,183,94,5,0,32,0,115,115,102,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,15,14,166,255,5,0,32,0,115,115,102,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,197,37,232,52,5,0,32,0,115,115,102,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,231,50,204,183,5,0,32,0,115,115,102,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,24,173,118,131,5,0,32,0,115,115,102,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,54,179,177,245,5,0,32,0,115,115,102,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,107,92,157,69,5,0,32,0,115,115,102,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,140,126,36,235,10,0,16,1,115,115,102,46,113,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,92,218,249,166,12,0,64,0,115,115,102,46,113,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,38,174,102,140,12,0,64,0,115,115,102,46,113,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,202,194,92,105,12,0,64,0,115,115,102,46,113,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,50,190,158,157,12,0,64,0,115,115,102,46,113,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,183,231,112,71,12,0,64,0,115,115,102,46,113,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,81,201,121,78,12,0,64,0,115,115,102,46,113,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,19,67,209,205,12,0,64,0,115,115,102,46,113,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,140,8,90,111,12,0,64,0,115,102,120,97,46,48,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,52,255,185,4,1,0,16,1,115,102,120,97,46,48,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,122,95,234,22,1,0,16,1,115,102,120,97,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,12,31,214,83,1,0,16,1,115,102,120,97,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,9,109,6,1,0,16,1,115,102,120,97,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,123,37,40,164,1,0,16,1,115,102,120,97,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,108,89,190,57,1,0,16,1,115,102,120,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,63,174,47,100,1,0,16,1,115,102,120,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,117,210,148,207,5,0,32,0,115,102,120,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,175,3,183,94,5,0,32,0,115,102,120,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,15,14,166,255,5,0,32,0,115,102,120,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,197,37,232,52,5,0,32,0,115,102,120,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,231,50,204,183,5,0,32,0,115,102,120,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,24,173,118,131,5,0,32,0,115,102,120,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,54,179,177,245,5,0,32,0,115,102,120,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,107,92,157,69,5,0,32,0,115,102,120,46,50,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,175,84,40,227,5,0,32,0,115,102,120,46,50,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,39,41,15,118,5,0,32,0,115,102,120,46,50,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,8,2,233,30,5,0,32,0,115,102,120,46,50,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,15,64,20,248,5,0,32,0,115,102,120,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,53,136,123,180,10,0,16,1,115,102,120,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,99,34,0,10,0,16,1,115,102,120,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,118,212,219,155,12,0,64,0,115,102,120,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,171,58,94,160,12,0,64,0,17,0,0,0,255,255,255,0,0,0,0,0,18,0,0,0,255,255,223,0,0,0,0,0,0,0,0,0,254,0,8,0,200,87,7,0,17,0,0,0,1,7,2,0,144,160,3,0,17,0,0,0,1,7,3,0,96,135,3,0,17,0,0,0,1,7,4,0,32,136,7,0,17,0,0,0,1,7,5,0,40,88,7,0,17,0,0,0,1,7,6,0,96,39,7,0,17,0,0,0,1,7,1,0,120,113,6,0,17,0,0,0,1,7,0,0,232,228,5,0,17,0,0,0,1,7,7,0,144,251,6,0,0,0,0,0,254,0,8,0,160,123,6,0,17,0,0,0,1,56,56,0,144,251,6,0,17,0,0,0,1,56,0,0,56,141,7,0,17,0,0,0,1,56,8,0,120,211,6,0,17,0,0,0,1,56,48,0,184,164,6,0,17,0,0,0,1,56,40,0,80,74,6,0,17,0,0,0,1,56,32,0,192,32,6,0,17,0,0,0,1,56,24,0,192,234,2,0,17,0,0,0,1,56,16,0,32,242,5,0,0,0,0,0,254,0,2,0,136,150,2,0,17,0,0,0,1,64,64,0,8,139,2,0,17,0,0,0,1,64,0,0,40,128,2,0,0,0,0,0,254,0,2,0,16,227,4,0,17,0,0,0,1,128,128,0,96,135,7,0,17,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,18,0,0,0,1,3,2,0,80,246,3,0,18,0,0,0,1,3,3,0,248,38,7,0,18,0,0,0,1,3,1,0,112,212,3,0,18,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,176,101,2,0,18,0,0,0,1,12,8,0,152,21,4,0,18,0,0,0,1,12,12,0,72,246,3,0,18,0,0,0,1,12,4,0,72,0,3,0,18,0,0,0,1,12,0,0,64,47,7,0,0,0,0,0,254,0,2,0,168,234,7,0,18,0,0,0,1,32,32,0,96,135,7,0,18,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,18,0,0,0,1,128,128,0,96,135,7,0,18,0,0,0,1,128,0,0,152,182,7,0,112,122,102,106,46,48,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,74,85,112,32,1,0,16,1,112,122,102,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,226,73,6,184,1,0,16,1,112,122,102,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,203,129,72,45,5,0,32,0,112,122,102,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,190,209,15,75,5,0,32,0,112,122,102,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,51,172,58,228,5,0,32,0,112,122,102,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,241,111,83,127,5,0,32,0,112,122,102,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,163,178,15,96,10,0,16,1,112,122,102,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,224,118,96,73,10,0,16,1,112,122,102,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,67,39,68,120,12,0,64,0,112,122,102,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,123,44,157,57,12,0,64,0,112,122,102,104,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,45,15,81,32,1,0,16,1,112,122,102,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,226,73,6,184,1,0,16,1,112,122,102,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,203,129,72,45,5,0,32,0,112,122,102,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,190,209,15,75,5,0,32,0,112,122,102,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,51,172,58,228,5,0,32,0,112,122,102,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,241,111,83,127,5,0,32,0,112,122,102,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,163,178,15,96,10,0,16,1,112,122,102,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,224,118,96,73,10,0,16,1,112,122,102,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,67,39,68,120,12,0,64,0,112,122,102,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,123,44,157,57,12,0,64,0,112,122,102,117,95,100,46,48,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,3,185,54,120,1,0,16,1,112,122,102,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,226,73,6,184,1,0,16,1,112,122,102,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,203,129,72,45,5,0,32,0,112,122,102,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,190,209,15,75,5,0,32,0,112,122,102,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,51,172,58,228,5,0,32,0,112,122,102,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,241,111,83,127,5,0,32,0,112,122,102,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,163,178,15,96,10,0,16,1,112,122,102,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,224,118,96,73,10,0,16,1,112,122,102,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,67,39,68,120,12,0,64,0,112,122,102,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,123,44,157,57,12,0,64,0,112,122,102,97,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,120,250,236,60,1,0,16,1,112,122,102,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,226,73,6,184,1,0,16,1,112,122,102,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,203,129,72,45,5,0,32,0,112,122,102,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,190,209,15,75,5,0,32,0,112,122,102,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,51,172,58,228,5,0,32,0,112,122,102,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,241,111,83,127,5,0,32,0,112,122,102,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,163,178,15,96,10,0,16,1,112,122,102,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,224,118,96,73,10,0,16,1,112,122,102,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,67,39,68,120,12,0,64,0,112,122,102,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,123,44,157,57,12,0,64,0,18,0,0,0,255,255,255,0,0,0,0,0,19,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,232,75,4,0,18,0,0,0,1,1,1,0,96,135,7,0,18,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,18,0,0,0,1,2,0,0,96,135,7,0,18,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,2,0,16,227,4,0,18,0,0,0,1,4,4,0,96,135,7,0,18,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,240,235,5,0,18,0,0,0,1,8,8,0,208,75,4,0,18,0,0,0,1,8,0,0,8,49,4,0,0,0,0,0,254,0,2,0,168,232,5,0,18,0,0,0,1,16,0,0,96,135,7,0,18,0,0,0,1,16,16,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,18,0,0,0,1,192,0,0,192,255,2,0,18,0,0,0,1,192,128,0,208,75,4,0,18,0,0,0,1,192,192,0,8,49,4,0,18,0,0,0,1,192,64,0,72,246,3,0,0,0,0,0,254,0,4,0,72,202,5,0,19,0,0,0,1,24,8,0,80,246,3,0,19,0,0,0,1,24,24,0,248,38,7,0,19,0,0,0,1,24,16,0,112,212,3,0,19,0,0,0,1,24,0,0,248,160,5,0,0,0,0,0,254,0,8,0,32,4,2,0,19,0,0,0,1,224,0,0,32,136,7,0,19,0,0,0,1,224,128,0,40,88,7,0,19,0,0,0,1,224,64,0,96,39,7,0,19,0,0,0,1,224,192,0,120,113,6,0,19,0,0,0,1,224,224,0,144,251,6,0,19,0,0,0,1,224,32,0,120,211,6,0,19,0,0,0,1,224,96,0,184,164,6,0,19,0,0,0,1,224,160,0,80,74,6,0,115,112,106,95,49,49,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,11,139,84,26,0,0,16,1,115,112,106,55,95,49,51,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,101,183,194,20,0,0,16,1,115,112,106,56,95,49,52,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,183,229,228,75,0,0,16,1,115,112,106,48,50,95,49,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,215,105,159,65,0,0,32,0,48,51,46,102,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,193,139,226,58,0,0,32,0,115,112,106,48,52,95,49,103,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,111,80,112,104,0,0,32,0,48,53,46,103,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,132,8,6,74,0,0,32,0,115,112,106,49,48,95,50,107,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,222,10,221,238,0,0,32,0,115,112,106,48,57,95,49,107,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,117,27,180,4,0,0,32,0,48,49,46,100,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,38,161,110,185,0,0,64,0,101,101,112,114,111,109,45,115,112,97,110,103,106,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,235,0,124,35,0,0,16,0,15,0,0,0,255,255,223,0,0,0,0,0,16,0,0,0,255,255,235,0,0,0,0,0,0,0,0,0,254,0,16,0,32,4,2,0,15,0,0,0,1,15,2,0,176,193,3,0,15,0,0,0,1,15,5,0,208,196,4,0,15,0,0,0,1,15,8,0,56,233,4,0,15,0,0,0,1,15,4,0,240,118,3,0,15,0,0,0,1,15,1,0,64,154,7,0,15,0,0,0,1,15,15,0,16,42,5,0,15,0,0,0,1,15,3,0,16,58,7,0,15,0,0,0,1,15,7,0,184,80,3,0,15,0,0,0,1,15,14,0,152,11,5,0,15,0,0,0,1,15,6,0,32,183,6,0,15,0,0,0,1,15,13,0,24,27,4,0,15,0,0,0,1,15,12,0,48,31,3,0,15,0,0,0,1,15,11,0,24,7,3,0,15,0,0,0,1,15,10,0,32,143,3,0,15,0,0,0,1,15,9,0,32,216,5,0,15,0,0,0,1,15,0,0,200,82,2,0,0,0,0,0,254,0,2,0,144,248,8,0,15,0,0,0,1,16,16,0,200,87,7,0,15,0,0,0,1,16,0,0,160,123,6,0,0,0,0,0,254,0,2,0,168,234,7,0,15,0,0,0,1,32,32,0,96,135,7,0,15,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,15,0,0,0,1,64,64,0,96,135,7,0,15,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,16,0,0,0,1,3,3,0,8,49,4,0,16,0,0,0,1,3,2,0,152,21,4,0,16,0,0,0,1,3,1,0,72,246,3,0,16,0,0,0,1,3,0,0,64,47,7,0,0,0,0,0,254,0,2,0,88,41,7,0,16,0,0,0,1,4,4,0,88,244,4,0,16,0,0,0,1,4,0,0,184,151,2,0,0,0,0,0,254,0,4,0,40,148,2,0,16,0,0,0,1,24,8,0,192,169,3,0,16,0,0,0,1,24,0,0,56,144,3,0,16,0,0,0,1,24,24,0,80,110,6,0,16,0,0,0,1,24,16,0,152,53,6,0,0,0,0,0,254,0,4,0,72,202,5,0,16,0,0,0,1,96,96,0,80,246,3,0,16,0,0,0,1,96,64,0,80,124,6,0,16,0,0,0,1,96,32,0,112,212,3,0,16,0,0,0,1,96,0,0,248,160,5,0,0,0,0,0,254,0,2,0,72,4,1,0,16,0,0,0,1,128,128,0,96,135,7,0,16,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,101,112,114,45,49,50,53,54,49,97,46,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,137,235,5,229,1,0,16,1,101,112,114,45,49,50,53,54,50,97,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,21,66,175,195,1,0,16,1,101,112,114,45,49,50,53,55,52,97,46,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,139,195,181,248,9,0,16,1,101,112,114,45,49,50,53,55,53,97,46,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,23,29,139,36,9,0,16,1,101,112,114,45,49,50,52,50,57,46,49,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,20,230,81,88,2,0,32,0,101,112,114,45,49,50,52,51,48,46,49,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,52,1,224,5,2,0,32,0,101,112,114,45,49,50,52,51,49,46,49,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,74,47,87,53,2,0,32,0,109,112,114,45,49,50,52,50,53,46,57,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,21,42,191,20,3,0,32,0,109,112,114,45,49,50,52,50,54,46,57,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,192,13,182,40,3,0,32,0,109,112,114,45,49,50,52,50,55,46,57,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,40,121,54,10,3,0,32,0,109,112,114,45,49,50,52,50,56,46,49,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,213,10,168,239,3,0,32,0,109,112,114,45,49,50,52,50,49,46,57,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,64,97,244,37,3,0,32,0,109,112,114,45,49,50,52,50,50,46,57,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,246,200,81,203,3,0,32,0,109,112,114,45,49,50,52,50,51,46,57,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,142,129,233,11,3,0,32,0,109,112,114,45,49,50,52,50,52,46,49,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,252,13,224,12,3,0,32,0,109,112,114,45,49,50,52,49,55,46,57,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,191,234,6,168,3,0,32,0,109,112,114,45,49,50,52,49,56,46,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,43,15,26,237,3,0,32,0,109,112,114,45,49,50,52,49,57,46,49,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,203,104,69,206,3,0,32,0,109,112,114,45,49,50,52,50,48,46,49,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,235,66,148,103,3,0,32,0,101,112,114,45,49,50,54,48,57,46,57,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,47,129,103,168,3,0,32,0,101,112,114,45,49,50,54,49,48,46,57,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,23,148,185,83,3,0,32,0,101,112,114,45,49,50,54,49,49,46,49,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,176,106,92,189,3,0,32,0,101,112,114,45,49,50,54,49,50,46,49,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,144,232,134,172,3,0,32,0,101,112,114,45,49,50,52,51,54,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,10,95,236,22,4,0,16,1,101,112,114,45,49,50,53,51,53,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,151,53,69,128,12,0,16,1,101,112,114,45,49,50,53,56,55,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,139,100,254,42,13,0,16,1,101,112,114,45,49,50,53,48,53,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,138,120,32,80,14,0,16,1,109,112,114,45,49,50,52,51,55,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,18,231,199,161,11,0,64,0,109,112,114,45,49,50,52,51,56,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,107,212,115,101,11,0,64,0,109,112,114,45,49,50,52,51,57,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,229,109,191,19,11,0,64,0,109,112,114,45,49,50,52,51,55,46,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,18,231,199,161,15,0,64,0,109,112,114,45,49,50,52,51,56,46,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,107,212,115,101,15,0,64,0,109,112,114,45,49,50,52,51,57,46,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,229,109,191,19,15,0,64,0,51,49,55,45,48,49,50,53,97,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,32,177,205,62,5,0,16,1,101,112,114,45,49,50,53,54,49,98,46,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,85,38,163,128,1,0,16,1,101,112,114,45,49,50,53,54,50,98,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,168,242,37,213,1,0,16,1,101,112,114,45,49,50,53,55,52,97,46,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,139,195,181,248,9,0,16,1,101,112,114,45,49,50,53,55,53,97,46,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,23,29,139,36,9,0,16,1,101,112,114,45,49,50,52,50,57,46,49,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,20,230,81,88,2,0,32,0,101,112,114,45,49,50,52,51,48,46,49,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,52,1,224,5,2,0,32,0,101,112,114,45,49,50,52,51,49,46,49,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,74,47,87,53,2,0,32,0,109,112,114,45,49,50,52,50,53,46,57,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,21,42,191,20,3,0,32,0,109,112,114,45,49,50,52,50,54,46,57,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,192,13,182,40,3,0,32,0,109,112,114,45,49,50,52,50,55,46,57,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,40,121,54,10,3,0,32,0,109,112,114,45,49,50,52,50,56,46,49,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,213,10,168,239,3,0,32,0,109,112,114,45,49,50,52,50,49,46,57,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,64,97,244,37,3,0,32,0,109,112,114,45,49,50,52,50,50,46,57,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,246,200,81,203,3,0,32,0,109,112,114,45,49,50,52,50,51,46,57,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,142,129,233,11,3,0,32,0,109,112,114,45,49,50,52,50,52,46,49,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,252,13,224,12,3,0,32,0,109,112,114,45,49,50,52,49,55,46,57,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,191,234,6,168,3,0,32,0,109,112,114,45,49,50,52,49,56,46,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,43,15,26,237,3,0,32,0,109,112,114,45,49,50,52,49,57,46,49,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,203,104,69,206,3,0,32,0,109,112,114,45,49,50,52,50,48,46,49,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,235,66,148,103,3,0,32,0,101,112,114,45,49,50,54,48,57,46,57,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,47,129,103,168,3,0,32,0,101,112,114,45,49,50,54,49,48,46,57,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,23,148,185,83,3,0,32,0,101,112,114,45,49,50,54,49,49,46,49,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,176,106,92,189,3,0,32,0,101,112,114,45,49,50,54,49,50,46,49,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,144,232,134,172,3,0,32,0,101,112,114,45,49,50,52,51,54,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,10,95,236,22,4,0,16,1,101,112,114,45,49,50,53,51,53,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,151,53,69,128,12,0,16,1,101,112,114,45,49,50,53,56,55,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,139,100,254,42,13,0,16,1,101,112,114,45,49,50,53,48,53,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,138,120,32,80,14,0,16,1,109,112,114,45,49,50,52,51,55,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,18,231,199,161,11,0,64,0,109,112,114,45,49,50,52,51,56,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,107,212,115,101,11,0,64,0,109,112,114,45,49,50,52,51,57,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,229,109,191,19,11,0,64,0,109,112,114,45,49,50,52,51,55,46,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,18,231,199,161,15,0,64,0,109,112,114,45,49,50,52,51,56,46,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,107,212,115,101,15,0,64,0,109,112,114,45,49,50,52,51,57,46,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,229,109,191,19,15,0,64,0,51,49,55,45,48,49,50,53,97,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,32,177,205,62,5,0,16,1,101,112,114,45,49,50,52,51,50,97,46,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,114,118,81,34,1,0,16,1,101,112,114,45,49,50,52,51,51,97,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,19,93,107,164,1,0,16,1,101,112,114,45,49,50,52,52,49,97,46,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,193,153,149,44,9,0,16,1,101,112,114,45,49,50,52,52,50,97,46,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,22,236,165,119,9,0,16,1,101,112,114,45,49,50,52,50,57,46,49,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,20,230,81,88,2,0,32,0,101,112,114,45,49,50,52,51,48,46,49,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,52,1,224,5,2,0,32,0,101,112,114,45,49,50,52,51,49,46,49,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,74,47,87,53,2,0,32,0,109,112,114,45,49,50,52,50,53,46,57,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,21,42,191,20,3,0,32,0,109,112,114,45,49,50,52,50,54,46,57,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,192,13,182,40,3,0,32,0,109,112,114,45,49,50,52,50,55,46,57,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,40,121,54,10,3,0,32,0,109,112,114,45,49,50,52,50,56,46,49,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,213,10,168,239,3,0,32,0,109,112,114,45,49,50,52,50,49,46,57,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,64,97,244,37,3,0,32,0,109,112,114,45,49,50,52,50,50,46,57,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,246,200,81,203,3,0,32,0,109,112,114,45,49,50,52,50,51,46,57,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,142,129,233,11,3,0,32,0,109,112,114,45,49,50,52,50,52,46,49,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,252,13,224,12,3,0,32,0,109,112,114,45,49,50,52,49,55,46,57,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,191,234,6,168,3,0,32,0,109,112,114,45,49,50,52,49,56,46,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,43,15,26,237,3,0,32,0,109,112,114,45,49,50,52,49,57,46,49,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,203,104,69,206,3,0,32,0,109,112,114,45,49,50,52,50,48,46,49,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,235,66,148,103,3,0,32,0,101,112,114,45,49,50,52,49,51,46,57,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,223,147,22,47,3,0,32,0,101,112,114,45,49,50,52,49,52,46,57,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,69,61,143,199,3,0,32,0,101,112,114,45,49,50,52,49,53,46,49,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,237,233,128,96,3,0,32,0,101,112,114,45,49,50,52,49,54,46,49,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,105,39,31,111,3,0,32,0,101,112,114,45,49,50,52,51,54,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,10,95,236,22,4,0,16,1,101,112,114,45,49,50,53,51,53,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,151,53,69,128,12,0,16,1,101,112,114,45,49,50,53,56,55,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,139,100,254,42,13,0,16,1,101,112,114,45,49,50,53,48,53,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,138,120,32,80,14,0,16,1,109,112,114,45,49,50,52,51,55,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,18,231,199,161,11,0,64,0,109,112,114,45,49,50,52,51,56,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,107,212,115,101,11,0,64,0,109,112,114,45,49,50,52,51,57,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,229,109,191,19,11,0,64,0,109,112,114,45,49,50,52,51,55,46,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,18,231,199,161,15,0,64,0,109,112,114,45,49,50,52,51,56,46,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,107,212,115,101,15,0,64,0,109,112,114,45,49,50,52,51,57,46,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,229,109,191,19,15,0,64,0,51,49,55,45,48,49,50,52,97,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,22,138,42,2,5,0,16,1,115,109,98,106,46,48,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,222,19,86,28,1,0,16,1,115,109,98,106,46,48,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,215,30,7,41,1,0,16,1,115,109,98,106,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,228,188,32,235,1,0,16,1,115,109,98,106,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,205,32,180,148,1,0,16,1,115,109,98,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,119,21,161,185,1,0,16,1,115,109,98,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,107,183,49,249,1,0,16,1,115,109,98,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,222,209,178,217,5,0,32,0,115,109,98,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,146,109,118,154,5,0,32,0,115,109,98,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,15,15,128,81,5,0,32,0,115,109,98,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,150,126,117,53,5,0,32,0,115,109,98,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,231,208,191,229,5,0,32,0,115,109,98,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,102,8,108,197,5,0,32,0,115,109,98,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,16,57,237,77,5,0,32,0,115,109,98,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,197,30,234,38,5,0,32,0,115,109,98,46,50,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,252,197,8,10,5,0,32,0,115,109,98,46,50,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,196,182,17,9,5,0,32,0,115,109,98,46,50,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,196,214,130,5,0,32,0,115,109,98,46,50,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,139,103,72,155,5,0,32,0,115,109,98,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,154,34,188,10,10,0,16,1,115,109,98,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,154,103,81,208,10,0,16,1,115,109,98,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,249,53,105,197,12,0,64,0,115,109,98,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,130,7,91,149,12,0,64,0,102,97,49,52,45,51,46,49,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,132,58,53,84,0,0,16,1,102,97,49,50,45,50,46,57,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,148,66,83,27,0,0,16,1,102,97,49,53,46,49,57,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,102,146,167,4,0,0,16,1,102,97,49,51,46,49,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,179,196,28,100,0,0,16,1,102,97,49,48,46,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,37,255,210,223,0,0,16,1,102,97,48,53,46,49,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,36,41,128,9,0,0,32,0,102,97,48,52,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,149,184,37,236,0,0,32,0,102,97,48,55,46,49,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,139,38,50,233,0,0,32,0,102,97,48,54,46,49,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,192,56,221,196,0,0,32,0,102,97,48,57,46,50,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,190,233,149,19,0,0,32,0,102,97,48,56,46,50,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,219,100,116,77,0,0,32,0,102,97,48,49,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,146,205,176,153,0,0,32,0,102,97,48,51,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,77,167,126,14,0,0,32,0,102,97,48,48,46,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,215,63,223,247,0,0,32,0,102,97,48,50,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,157,218,232,132,0,0,32,0,102,97,49,49,46,49,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,173,123,84,78,0,0,64,0,109,98,55,49,49,52,104,46,50,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,212,232,38,173,0,0,0,8,112,97,108,49,54,108,56,98,45,116,97,45,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,39,117,168,121,0,0,0,8,112,97,108,49,54,114,52,97,45,116,97,45,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,17,19,163,236,0,0,0,8,112,97,108,49,54,108,56,97,45,116,97,45,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,25,73,50,108,0,0,0,8,112,97,108,49,54,108,56,97,45,116,97,45,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,250,119,97,17,0,0,0,8,20,0,0,0,255,255,127,0,0,0,0,0,21,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,200,87,7,0,20,0,0,0,1,3,0,0,176,45,8,0,20,0,0,0,1,3,1,0,224,127,8,0,20,0,0,0,1,3,3,0,32,123,8,0,20,0,0,0,1,3,2,0,192,110,8,0,0,0,0,0,254,0,4,0,160,123,6,0,20,0,0,0,1,12,0,0,176,45,8,0,20,0,0,0,1,12,4,0,224,127,8,0,20,0,0,0,1,12,12,0,32,123,8,0,20,0,0,0,1,12,8,0,192,110,8,0,0,0,0,0,254,0,2,0,232,75,4,0,20,0,0,0,1,16,16,0,96,135,7,0,20,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,20,0,0,0,1,32,0,0,96,135,7,0,20,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,20,0,0,0,1,64,64,0,96,135,7,0,20,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,200,30,2,0,20,0,0,0,1,128,0,0,120,97,1,0,20,0,0,0,1,128,128,0,96,19,1,0,0,0,0,0,254,0,4,0,104,115,3,0,21,0,0,0,1,3,2,0,120,246,1,0,21,0,0,0,1,3,3,0,168,236,1,0,21,0,0,0,1,3,1,0,200,224,1,0,21,0,0,0,1,3,0,0,120,210,1,0,0,0,0,0,254,0,4,0,72,202,5,0,21,0,0,0,1,12,8,0,80,246,3,0,21,0,0,0,1,12,12,0,248,38,7,0,21,0,0,0,1,12,4,0,112,212,3,0,21,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,2,0,192,125,6,0,21,0,0,0,1,16,0,0,56,111,3,0,21,0,0,0,1,16,16,0,104,134,3,0,0,0,0,0,18,0,0,0,255,255,255,0,0,0,0,0,19,0,0,0,255,255,242,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,160,123,6,0,18,0,0,0,1,3,0,0,40,88,7,0,18,0,0,0,1,3,1,0,96,39,7,0,18,0,0,0,1,3,3,0,144,251,6,0,18,0,0,0,1,3,2,0,184,164,6,0,0,0,0,0,254,0,2,0,72,4,1,0,18,0,0,0,1,4,4,0,96,135,7,0,18,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,112,47,6,0,18,0,0,0,1,8,8,0,96,135,7,0,18,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,18,0,0,0,1,16,0,0,96,135,7,0,18,0,0,0,1,16,16,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,18,0,0,0,1,96,0,0,40,88,7,0,18,0,0,0,1,96,32,0,96,39,7,0,18,0,0,0,1,96,96,0,144,251,6,0,18,0,0,0,1,96,64,0,184,164,6,0,0,0,0,0,254,0,2,0,232,75,4,0,18,0,0,0,1,128,128,0,96,135,7,0,18,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,1,0,0,96,135,7,0,19,0,0,0,1,1,1,0,152,182,7,0,0,0,0,0,254,0,2,0,56,8,3,0,19,0,0,0,1,2,0,0,56,111,3,0,19,0,0,0,1,2,2,0,104,134,3,0,0,0,0,0,254,0,4,0,64,37,5,0,19,0,0,0,1,48,0,0,16,90,2,0,19,0,0,0,1,48,16,0,88,74,2,0,19,0,0,0,1,48,32,0,120,61,2,0,19,0,0,0,1,48,48,0,32,46,2,0,0,0,0,0,254,0,4,0,128,129,4,0,19,0,0,0,1,192,128,0,192,255,2,0,19,0,0,0,1,192,64,0,208,75,4,0,19,0,0,0,1,192,192,0,8,49,4,0,19,0,0,0,1,192,0,0,72,246,3,0,0,0,0,0,9,0,0,0,255,255,111,0,0,0,0,0,10,0,0,0,255,255,240,0,0,0,0,0,11,0,0,0,255,255,250,0,0,0,0,0,0,0,0,0,254,0,4,0,64,37,5,0,9,0,0,0,1,24,0,0,224,64,8,0,9,0,0,0,1,24,8,0,144,164,8,0,9,0,0,0,1,24,16,0,160,102,8,0,9,0,0,0,1,24,24,0,208,45,8,0,0,0,0,0,254,0,2,0,72,202,5,0,9,0,0,0,1,32,32,0,80,124,6,0,9,0,0,0,1,32,0,0,112,212,3,0,0,0,0,0,254,0,2,0,144,212,8,0,9,0,0,0,1,64,64,0,96,135,7,0,9,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,200,30,2,0,9,0,0,0,1,128,0,0,120,97,1,0,9,0,0,0,1,128,128,0,96,19,1,0,0,0,0,0,254,0,8,0,32,4,2,0,10,0,0,0,1,14,14,0,96,135,3,0,10,0,0,0,1,14,10,0,32,136,7,0,10,0,0,0,1,14,6,0,40,88,7,0,10,0,0,0,1,14,2,0,96,39,7,0,10,0,0,0,1,14,0,0,144,251,6,0,10,0,0,0,1,14,4,0,184,164,6,0,10,0,0,0,1,14,8,0,80,74,6,0,10,0,0,0,1,14,12,0,192,32,6,0,0,0,0,0,254,0,6,0,128,129,4,0,11,0,0,0,1,7,0,0,192,255,2,0,11,0,0,0,1,7,1,0,208,75,4,0,11,0,0,0,1,7,2,0,8,49,4,0,11,0,0,0,1,7,3,0,152,21,4,0,11,0,0,0,1,7,4,0,72,246,3,0,11,0,0,0,1,7,7,0,48,176,2,0,0,0,0,0,115,104,105,110,48,54,46,117,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,233,115,215,57,0,0,16,1,19,0,0,0,255,255,252,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,21,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,19,0,0,0,1,1,0,0,120,97,1,0,19,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,4,0,128,129,4,0,19,0,0,0,1,12,8,0,208,75,4,0,19,0,0,0,1,12,12,0,8,49,4,0,19,0,0,0,1,12,4,0,152,21,4,0,19,0,0,0,1,12,0,0,40,130,6,0,0,0,0,0,254,0,4,0,104,125,6,0,19,0,0,0,1,48,48,0,136,120,6,0,19,0,0,0,1,48,32,0,176,116,6,0,19,0,0,0,1,48,16,0,80,113,6,0,19,0,0,0,1,48,0,0,80,110,6,0,0,0,0,0,254,0,2,0,72,202,5,0,19,0,0,0,1,192,128,0,80,246,3,0,19,0,0,0,1,192,192,0,248,38,7,0,19,0,0,0,1,192,64,0,112,212,3,0,19,0,0,0,1,192,0,0,248,160,5,0,0,0,0,0,254,0,3,0,88,178,6,0,21,0,0,0,1,3,0,0,184,75,6,0,21,0,0,0,1,3,1,0,56,70,6,0,21,0,0,0,1,3,2,0,136,65,6,0,0,0,0,0,112,99,102,104,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,71,51,16,233,1,0,16,1,112,99,102,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,150,76,49,244,1,0,16,1,112,99,102,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,85,86,33,1,0,16,1,112,99,102,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,234,19,111,234,1,0,16,1,112,99,102,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,234,213,198,90,1,0,16,1,112,99,102,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,185,42,215,34,5,0,32,0,112,99,102,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,60,129,164,22,5,0,32,0,112,99,102,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,53,224,151,16,5,0,32,0,112,99,102,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,116,216,98,211,5,0,32,0,112,99,102,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,124,137,131,3,5,0,32,0,112,99,102,46,49,54,109,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,132,16,249,118,5,0,32,0,112,99,102,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,84,55,108,117,5,0,32,0,112,99,102,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,125,39,201,158,5,0,32,0,112,99,102,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,51,95,78,37,10,0,16,1,112,99,102,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,249,244,2,105,10,0,16,1,112,99,102,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,5,160,222,165,12,0,64,0,112,99,102,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,254,53,226,76,12,0,64,0,112,99,102,117,100,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,74,103,131,139,1,0,16,1,112,99,102,100,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,3,29,143,181,1,0,16,1,112,99,102,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,85,86,33,1,0,16,1,112,99,102,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,234,19,111,234,1,0,16,1,112,99,102,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,234,213,198,90,1,0,16,1,112,99,102,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,185,42,215,34,5,0,32,0,112,99,102,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,60,129,164,22,5,0,32,0,112,99,102,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,53,224,151,16,5,0,32,0,112,99,102,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,116,216,98,211,5,0,32,0,112,99,102,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,124,137,131,3,5,0,32,0,112,99,102,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,132,16,249,118,5,0,32,0,112,99,102,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,84,55,108,117,5,0,32,0,112,99,102,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,125,39,201,158,5,0,32,0,112,99,102,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,51,95,78,37,10,0,16,1,112,99,102,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,249,244,2,105,10,0,16,1,112,99,102,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,5,160,222,165,12,0,64,0,112,99,102,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,254,53,226,76,12,0,64,0,112,99,102,97,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,154,8,124,225,1,0,16,1,112,99,102,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,150,76,49,244,1,0,16,1,112,99,102,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,85,86,33,1,0,16,1,112,99,102,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,234,19,111,234,1,0,16,1,112,99,102,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,234,213,198,90,1,0,16,1,112,99,102,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,185,42,215,34,5,0,32,0,112,99,102,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,60,129,164,22,5,0,32,0,112,99,102,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,53,224,151,16,5,0,32,0,112,99,102,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,116,216,98,211,5,0,32,0,112,99,102,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,124,137,131,3,5,0,32,0,112,99,102,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,132,16,249,118,5,0,32,0,112,99,102,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,84,55,108,117,5,0,32,0,112,99,102,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,125,39,201,158,5,0,32,0,112,99,102,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,51,95,78,37,10,0,16,1,112,99,102,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,249,244,2,105,10,0,16,1,112,99,102,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,5,160,222,165,12,0,64,0,112,99,102,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,254,53,226,76,12,0,64,0,115,102,122,106,46,48,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,60,233,252,60,1,0,16,1,115,102,122,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,48,109,67,12,1,0,16,1,115,102,122,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,18,54,54,31,1,0,16,1,115,102,122,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,56,143,110,128,1,0,16,1,115,102,122,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,179,253,254,144,5,0,32,0,115,102,122,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,72,201,84,83,5,0,32,0,115,102,122,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,144,231,161,65,5,0,32,0,115,102,122,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,152,223,73,165,5,0,32,0,115,102,122,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,125,236,255,255,10,0,16,1,115,102,122,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,8,106,244,69,10,0,16,1,115,102,122,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,205,147,176,196,12,0,64,0,115,102,122,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,180,196,219,139,12,0,64,0,115,102,122,106,46,48,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,194,32,66,132,1,0,16,1,115,102,122,46,48,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,165,233,153,95,1,0,16,1,115,102,122,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,77,84,16,8,1,0,16,1,115,102,122,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,56,143,110,128,1,0,16,1,115,102,122,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,179,253,254,144,5,0,32,0,115,102,122,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,72,201,84,83,5,0,32,0,115,102,122,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,144,231,161,65,5,0,32,0,115,102,122,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,152,223,73,165,5,0,32,0,115,102,122,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,125,236,255,255,10,0,16,1,115,102,122,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,8,106,244,69,10,0,16,1,115,102,122,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,205,147,176,196,12,0,64,0,115,102,122,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,180,196,219,139,12,0,64,0,115,102,122,104,46,48,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,170,53,230,188,1,0,16,1,115,102,122,46,48,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,165,233,153,95,1,0,16,1,115,102,122,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,77,84,16,8,1,0,16,1,115,102,122,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,56,143,110,128,1,0,16,1,115,102,122,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,179,253,254,144,5,0,32,0,115,102,122,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,72,201,84,83,5,0,32,0,115,102,122,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,144,231,161,65,5,0,32,0,115,102,122,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,152,223,73,165,5,0,32,0,115,102,122,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,125,236,255,255,10,0,16,1,115,102,122,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,8,106,244,69,10,0,16,1,115,102,122,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,205,147,176,196,12,0,64,0,115,102,122,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,180,196,219,139,12,0,64,0,115,102,122,98,46,48,51,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,163,137,186,236,1,0,16,1,115,102,122,46,48,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,229,176,115,139,1,0,16,1,115,102,122,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,77,84,16,8,1,0,16,1,115,102,122,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,56,143,110,128,1,0,16,1,115,102,122,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,179,253,254,144,5,0,32,0,115,102,122,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,72,201,84,83,5,0,32,0,115,102,122,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,144,231,161,65,5,0,32,0,115,102,122,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,152,223,73,165,5,0,32,0,115,102,122,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,125,236,255,255,10,0,16,1,115,102,122,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,8,106,244,69,10,0,16,1,115,102,122,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,205,147,176,196,12,0,64,0,115,102,122,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,180,196,219,139,12,0,64,0,115,102,122,97,46,48,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,141,140,141,243,1,0,16,1,115,102,122,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,48,109,67,12,1,0,16,1,115,102,122,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,18,54,54,31,1,0,16,1,115,102,122,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,56,143,110,128,1,0,16,1,115,102,122,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,179,253,254,144,5,0,32,0,115,102,122,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,72,201,84,83,5,0,32,0,115,102,122,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,144,231,161,65,5,0,32,0,115,102,122,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,152,223,73,165,5,0,32,0,115,102,122,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,125,236,255,255,10,0,16,1,115,102,122,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,8,106,244,69,10,0,16,1,115,102,122,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,205,147,176,196,12,0,64,0,115,102,122,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,180,196,219,139,12,0,64,0,115,122,50,106,95,100,46,48,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,248,93,50,183,1,0,16,1,115,122,50,106,95,100,46,48,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,62,42,2,161,1,0,16,1,115,122,50,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,146,233,232,152,1,0,16,1,115,122,50,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,192,73,29,91,1,0,16,1,115,122,50,106,46,48,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,162,178,16,217,1,0,16,1,115,122,50,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,93,88,232,15,1,0,16,1,115,122,50,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,34,31,31,77,5,0,32,0,115,122,50,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,128,166,206,25,5,0,32,0,115,122,50,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,136,69,27,224,5,0,32,0,115,122,50,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,100,218,238,15,5,0,32,0,115,122,50,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,170,198,96,5,5,0,32,0,115,122,50,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,135,15,148,174,5,0,32,0,115,122,50,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,188,200,195,75,5,0,32,0,115,122,50,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,192,116,230,57,5,0,32,0,115,122,50,46,48,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,207,35,195,27,10,0,16,1,115,122,50,46,48,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,19,80,106,186,10,0,16,1,115,122,50,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,1,166,71,170,12,0,64,0,115,122,50,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,83,188,55,34,12,0,64,0,115,122,97,97,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,62,2,231,136,1,0,16,1,115,122,97,97,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,110,195,142,174,1,0,16,1,115,122,97,97,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,94,165,83,240,1,0,16,1,115,122,97,97,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,231,192,207,1,0,16,1,115,122,97,97,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,32,139,235,95,1,0,16,1,115,122,97,97,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,18,212,182,110,1,0,16,1,115,122,97,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,34,31,31,77,5,0,32,0,115,122,97,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,128,166,206,25,5,0,32,0,115,122,97,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,136,69,27,224,5,0,32,0,115,122,97,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,100,218,238,15,5,0,32,0,115,122,97,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,170,198,96,5,5,0,32,0,115,122,97,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,135,15,148,174,5,0,32,0,115,122,97,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,188,200,195,75,5,0,32,0,115,122,97,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,192,116,230,57,5,0,32,0,115,122,97,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,207,35,195,27,10,0,16,1,115,122,97,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,19,80,106,186,10,0,16,1,115,122,97,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,1,166,71,170,12,0,64,0,115,122,97,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,83,188,55,34,12,0,64,0,115,122,50,97,100,46,48,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,171,143,127,1,1,0,16,1,115,122,50,97,100,46,48,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,162,94,14,245,1,0,16,1,115,122,50,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,146,233,232,152,1,0,16,1,115,122,50,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,192,73,29,91,1,0,16,1,115,122,50,97,46,48,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,148,36,237,10,1,0,16,1,115,122,50,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,93,88,232,15,1,0,16,1,115,122,50,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,34,31,31,77,5,0,32,0,115,122,50,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,128,166,206,25,5,0,32,0,115,122,50,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,136,69,27,224,5,0,32,0,115,122,50,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,100,218,238,15,5,0,32,0,115,122,50,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,170,198,96,5,5,0,32,0,115,122,50,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,135,15,148,174,5,0,32,0,115,122,50,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,188,200,195,75,5,0,32,0,115,122,50,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,192,116,230,57,5,0,32,0,115,122,50,46,48,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,207,35,195,27,10,0,16,1,115,122,50,46,48,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,19,80,106,186,10,0,16,1,115,122,50,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,1,166,71,170,12,0,64,0,115,122,50,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,83,188,55,34,12,0,64,0,184,40,2,0,1,0,0,0,128,248,146,0,248,191,2,0,184,164,8,0,1,0,0,0,129,248,146,0,64,246,1,0,24,38,7,0,1,0,0,0,40,1,147,0,184,160,2,0,56,210,6,0,1,0,0,0,107,240,146,0,192,135,2,0,24,163,6,0,1,0,0,0,106,240,146,0,240,108,2,0,152,122,6,0,1,0,0,0,105,240,146,0,96,82,2,0,192,72,6,0,1,0,0,0,104,240,146,0,32,56,2,0,200,110,3,0,1,0,0,0,108,240,146,0,152,30,2,0,120,89,3,0,1,0,0,0,109,240,146,0,232,10,2,0,120,74,3,0,1,0,0,0,137,248,146,0,152,138,8,0,192,61,3,0,1,0,0,0,110,240,146,0,48,119,7,0,120,194,6,0,1,0,0,0,111,240,146,0,112,109,7,0,96,189,6,0,1,0,0,0,130,248,146,0,24,133,7,0,144,236,1,0,1,0,0,0,41,1,147,0,136,224,1,0,176,223,1,0,1,0,0,0,115,240,146,0,192,135,2,0,192,209,1,0,1,0,0,0,114,240,146,0,24,182,1,0,24,198,1,0,1,0,0,0,113,240,146,0,40,167,1,0,120,189,1,0,1,0,0,0,112,240,146,0,200,149,1,0,224,22,1,0,1,0,0,0,116,240,146,0,56,126,1,0,160,14,1,0,1,0,0,0,117,240,146,0,32,101,1,0,176,9,1,0,1,0,0,0,138,248,146,0,96,32,8,0,200,3,1,0,1,0,0,0,118,240,146,0,16,68,7,0,208,183,6,0,1,0,0,0,119,240,146,0,240,58,7,0,200,177,6,0,1,0,0,0,136,248,146,0,200,42,1,0,16,17,8,0,1,0,0,0,42,1,147,0,224,12,8,0,88,212,3,0,1,0,0,0,152,220,146,0,40,185,3,0,248,5,8,0,9,0,0,0,136,6,147,0,32,58,1,0,144,250,7,0,9,0,0,0,137,6,147,0,32,58,1,0,248,241,7,0,9,0,0,0,138,6,147,0,32,58,1,0,72,82,8,0,9,0,0,0,139,6,147,0,32,58,1,0,184,40,2,0,1,0,0,0,128,248,146,0,248,191,2,0,184,164,8,0,1,0,0,0,129,248,146,0,64,246,1,0,24,38,7,0,1,0,0,0,40,1,147,0,184,160,2,0,56,210,6,0,1,0,0,0,107,240,146,0,192,135,2,0,24,163,6,0,1,0,0,0,106,240,146,0,240,108,2,0,152,122,6,0,1,0,0,0,105,240,146,0,96,82,2,0,192,72,6,0,1,0,0,0,104,240,146,0,32,56,2,0,200,110,3,0,1,0,0,0,112,240,146,0,152,30,2,0,120,89,3,0,1,0,0,0,113,240,146,0,232,10,2,0,120,74,3,0,1,0,0,0,114,240,146,0,152,138,8,0,192,61,3,0,1,0,0,0,116,240,146,0,48,119,7,0,120,194,6,0,1,0,0,0,117,240,146,0,112,109,7,0,96,189,6,0,1,0,0,0,118,240,146,0,24,133,7,0,144,236,1,0,1,0,0,0,41,1,147,0,136,224,1,0,176,223,1,0,1,0,0,0,91,237,146,0,192,135,2,0,192,209,1,0,1,0,0,0,90,237,146,0,24,182,1,0,24,198,1,0,1,0,0,0,89,237,146,0,40,167,1,0,120,189,1,0,1,0,0,0,88,237,146,0,200,149,1,0,224,22,1,0,1,0,0,0,96,237,146,0,56,126,1,0,160,14,1,0,1,0,0,0,97,237,146,0,32,101,1,0,176,9,1,0,1,0,0,0,98,237,146,0,96,32,8,0,200,3,1,0,1,0,0,0,100,237,146,0,16,68,7,0,208,183,6,0,1,0,0,0,101,237,146,0,240,58,7,0,200,177,6,0,1,0,0,0,102,237,146,0,200,42,1,0,16,17,8,0,1,0,0,0,42,1,147,0,224,12,8,0,88,212,3,0,1,0,0,0,152,220,146,0,40,185,3,0,248,5,8,0,9,0,0,0,136,6,147,0,32,58,1,0,144,250,7,0,9,0,0,0,137,6,147,0,32,58,1,0,248,241,7,0,9,0,0,0,138,6,147,0,32,58,1,0,72,82,8,0,9,0,0,0,139,6,147,0,32,58,1,0,115,122,51,117,100,46,48,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,215,173,184,109,1,0,16,1,115,122,51,117,100,46,48,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,38,90,198,217,1,0,16,1,115,122,51,46,48,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,64,10,253,87,1,0,16,1,115,122,51,46,48,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,139,95,48,246,1,0,16,1,115,122,51,46,48,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,111,15,171,110,1,0,16,1,115,122,51,46,48,56,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,59,74,12,145,1,0,16,1,115,122,51,46,48,57,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,153,81,158,178,1,0,16,1,115,122,51,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,255,178,222,1,0,16,1,115,122,51,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,217,96,122,15,5,0,32,0,115,122,51,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,65,55,147,142,5,0,32,0,115,122,51,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,71,129,233,214,5,0,32,0,115,122,51,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,138,114,26,243,5,0,32,0,115,122,51,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,151,130,249,95,5,0,32,0,115,122,51,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,238,189,181,82,5,0,32,0,115,122,51,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,213,30,99,64,5,0,32,0,115,122,51,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,180,9,52,118,5,0,32,0,115,122,51,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,132,0,129,222,10,0,16,1,115,122,51,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,196,93,68,114,10,0,16,1,115,122,51,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,209,238,137,28,12,0,64,0,115,122,51,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,58,177,146,243,12,0,64,0,98,49,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,213,47,116,143,1,0,16,1,98,49,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,127,236,49,136,1,0,16,1,98,49,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,37,101,164,148,1,0,16,1,98,49,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,71,221,179,143,1,0,16,1,115,57,50,95,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,216,176,3,4,0,32,0,115,57,50,95,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,137,2,132,4,0,32,0,115,57,50,95,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,240,181,205,4,0,32,0,115,57,50,95,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,114,148,121,226,4,0,32,0,115,57,50,95,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,39,138,186,4,0,32,0,115,57,50,95,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,191,132,229,4,0,32,0,115,57,50,95,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,125,248,227,33,4,0,32,0,115,57,50,95,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,71,252,190,4,0,32,0,115,57,50,95,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,213,135,6,150,4,0,32,0,115,57,50,95,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,205,142,151,4,0,32,0,115,57,50,95,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,10,154,236,214,4,0,32,0,115,57,50,95,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,103,44,237,4,0,32,0,115,57,50,95,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,14,182,246,8,3,0,16,0,115,57,50,95,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,32,22,127,5,0,64,0,115,57,50,95,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,229,173,190,5,0,64,0,54,46,97,109,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,117,162,133,58,8,0,32,0,57,46,97,109,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,47,71,86,145,8,0,32,0,56,46,97,109,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,59,8,219,236,8,0,32,0,49,48,46,97,109,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,132,131,234,143,8,0,32,0,112,114,103,32,112,97,114,116,32,49,46,115,116,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,213,180,88,162,1,0,16,1,112,114,103,32,112,97,114,116,32,50,46,115,116,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,116,212,204,89,1,0,16,1,99,101,57,49,101,45,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,110,56,98,8,1,0,16,1,99,101,57,49,101,45,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,77,132,131,12,1,0,16,1,115,116,116,45,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,109,3,167,16,4,0,32,0,115,116,116,45,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,36,177,128,53,4,0,32,0,115,116,116,45,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,78,34,9,122,4,0,32,0,115,116,116,45,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,44,97,42,56,4,0,32,0,115,116,116,45,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,143,27,112,17,4,0,32,0,115,116,116,45,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,114,11,26,16,4,0,32,0,51,46,115,116,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,27,58,130,164,3,0,16,0,50,46,115,116,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,32,22,127,5,0,64,0,49,46,115,116,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,229,173,190,5,0,64,0,53,46,115,116,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,30,98,5,165,8,0,32,0,55,46,115,116,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,251,113,98,222,8,0,32,0,54,46,115,116,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,68,83,119,35,8,0,32,0,56,46,115,116,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,15,85,201,129,8,0,32,0,52,46,115,116,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,68,28,234,19,0,0,0,8,115,102,50,114,101,100,46,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,187,106,39,64,2,0,16,1,115,102,50,114,101,100,46,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,135,243,218,24,2,0,16,1,115,102,50,114,101,100,46,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,187,134,196,82,2,0,16,1,115,57,50,95,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,216,176,3,4,0,32,0,115,57,50,95,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,137,2,132,4,0,32,0,115,57,50,95,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,240,181,205,4,0,32,0,115,57,50,95,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,114,148,121,226,4,0,32,0,115,57,50,95,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,39,138,186,4,0,32,0,115,57,50,95,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,191,132,229,4,0,32,0,115,57,50,95,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,125,248,227,33,4,0,32,0,115,57,50,95,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,71,252,190,4,0,32,0,115,57,50,95,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,213,135,6,150,4,0,32,0,115,57,50,95,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,205,142,151,4,0,32,0,115,57,50,95,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,10,154,236,214,4,0,32,0,115,57,50,95,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,103,44,237,4,0,32,0,115,57,50,95,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,14,182,246,8,3,0,16,0,115,57,50,95,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,32,22,127,5,0,64,0,115,57,50,95,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,229,173,190,5,0,64,0,99,101,98,108,95,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,173,252,57,20,2,0,16,1,99,101,98,108,95,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,177,12,232,39,2,0,16,1,99,101,98,108,95,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,70,48,30,242,2,0,16,1,115,57,50,45,49,109,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,216,176,3,4,0,32,0,115,57,50,45,51,109,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,137,2,132,4,0,32,0,115,57,50,45,50,109,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,240,181,205,4,0,32,0,115,57,50,45,52,109,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,114,148,121,226,4,0,32,0,115,57,50,45,53,109,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,39,138,186,4,0,32,0,115,57,50,45,55,109,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,191,132,229,4,0,32,0,115,57,50,45,54,109,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,125,248,227,33,4,0,32,0,115,57,50,45,56,109,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,71,252,190,4,0,32,0,115,57,50,45,49,48,109,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,213,135,6,150,4,0,32,0,115,57,50,45,49,50,109,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,205,142,151,4,0,32,0,115,57,50,45,49,49,109,46,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,10,154,236,214,4,0,32,0,115,57,50,45,49,51,109,46,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,103,44,237,4,0,32,0,115,57,50,95,48,57,46,49,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,14,182,246,8,3,0,16,0,115,57,50,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,32,22,127,5,0,64,0,115,57,50,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,229,173,190,5,0,64,0,115,102,117,56,45,49,46,48,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,254,103,236,16,1,0,16,1,115,102,117,56,45,51,46,48,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,28,58,235,146,1,0,16,1,115,102,117,56,45,50,46,48,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,182,183,115,16,1,0,16,1,115,102,117,56,45,52,46,48,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,226,108,76,146,1,0,16,1,115,57,50,95,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,216,176,3,4,0,32,0,115,57,50,95,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,137,2,132,4,0,32,0,115,57,50,95,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,240,181,205,4,0,32,0,115,57,50,95,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,114,148,121,226,4,0,32,0,115,57,50,95,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,39,138,186,4,0,32,0,115,57,50,95,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,191,132,229,4,0,32,0,115,57,50,95,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,125,248,227,33,4,0,32,0,115,57,50,95,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,71,252,190,4,0,32,0,115,57,50,95,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,213,135,6,150,4,0,32,0,115,57,50,95,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,8,0,24,205,142,151,4,0,32,0,115,57,50,95,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,10,154,236,214,4,0,32,0,115,57,50,95,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,103,44,237,4,0,32,0,115,57,50,95,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,14,182,246,8,3,0,16,0,115,57,50,95,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,32,22,127,5,0,64,0,115,57,50,95,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,229,173,190,5,0,64,0,117,50,50,50,110,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,158,72,51,113,1,0,16,1,117,49,57,54,110,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,144,79,122,176,1,0,16,1,115,57,50,95,50,49,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,119,120,90,146,2,0,16,1,115,57,50,95,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,216,176,3,4,0,32,0,115,57,50,95,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,137,2,132,4,0,32,0,115,57,50,95,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,240,181,205,4,0,32,0,115,57,50,95,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,114,148,121,226,4,0,32,0,115,57,50,95,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,39,138,186,4,0,32,0,115,57,50,95,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,191,132,229,4,0,32,0,115,57,50,95,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,125,248,227,33,4,0,32,0,115,57,50,95,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,71,252,190,4,0,32,0,115,57,50,95,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,213,135,6,150,4,0,32,0,115,57,50,95,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,205,142,151,4,0,32,0,115,57,50,95,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,10,154,236,214,4,0,32,0,115,57,50,95,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,103,44,237,4,0,32,0,115,57,50,95,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,14,182,246,8,3,0,16,0,115,57,50,95,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,32,22,127,5,0,64,0,115,57,50,95,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,229,173,190,5,0,64,0,115,102,50,95,99,101,95,114,98,46,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,80,158,47,32,2,0,16,1,115,102,50,95,99,101,95,114,98,46,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,25,82,94,20,2,0,16,1,115,57,50,95,50,49,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,119,120,90,146,2,0,16,1,115,57,50,95,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,216,176,3,4,0,32,0,115,57,50,95,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,137,2,132,4,0,32,0,115,57,50,95,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,240,181,205,4,0,32,0,115,57,50,95,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,114,148,121,226,4,0,32,0,115,57,50,95,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,39,138,186,4,0,32,0,115,57,50,95,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,191,132,229,4,0,32,0,115,57,50,95,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,125,248,227,33,4,0,32,0,115,57,50,95,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,71,252,190,4,0,32,0,115,57,50,95,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,213,135,6,150,4,0,32,0,115,57,50,95,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,205,142,151,4,0,32,0,115,57,50,95,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,10,154,236,214,4,0,32,0,115,57,50,95,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,103,44,237,4,0,32,0,115,57,50,95,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,14,182,246,8,3,0,16,0,115,57,50,95,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,32,22,127,5,0,64,0,115,57,50,95,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,229,173,190,5,0,64,0,50,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,205,110,41,64,1,0,16,1,51,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,65,74,149,135,1,0,16,1,50,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,149,65,151,166,1,0,16,1,51,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,50,254,65,129,1,0,16,1,50,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,114,247,248,158,1,0,16,1,50,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,156,71,156,125,1,0,16,1,50,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,132,150,87,147,1,0,16,1,50,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,101,136,114,255,1,0,16,1,115,57,50,95,50,49,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,119,120,90,146,2,0,16,1,115,57,50,95,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,216,176,3,4,0,32,0,115,57,50,95,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,137,2,132,4,0,32,0,115,57,50,95,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,240,181,205,4,0,32,0,115,57,50,95,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,114,148,121,226,4,0,32,0,115,57,50,95,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,39,138,186,4,0,32,0,115,57,50,95,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,191,132,229,4,0,32,0,115,57,50,95,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,125,248,227,33,4,0,32,0,115,57,50,95,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,71,252,190,4,0,32,0,115,57,50,95,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,213,135,6,150,4,0,32,0,115,57,50,95,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,205,142,151,4,0,32,0,115,57,50,95,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,10,154,236,214,4,0,32,0,115,57,50,95,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,103,44,237,4,0,32,0,115,57,50,95,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,14,182,246,8,3,0,16,0,115,57,50,95,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,32,22,127,5,0,64,0,115,57,50,95,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,229,173,190,5,0,64,0,115,116,102,105,105,45,113,107,110,45,99,112,115,45,49,55,46,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,238,88,148,58,2,0,16,1,115,116,102,105,105,45,113,107,110,45,99,112,115,45,49,55,46,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,216,21,210,78,2,0,16,1,115,102,50,95,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,142,204,201,34,4,0,32,0,115,102,50,95,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,232,59,33,87,4,0,32,0,115,102,50,95,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,79,155,82,186,4,0,32,0,115,102,50,95,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,51,27,75,4,0,32,0,115,102,50,95,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,41,34,126,44,4,0,32,0,115,102,50,95,49,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,23,143,84,181,4,0,32,0,115,102,50,95,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,18,67,184,20,4,0,32,0,115,102,50,95,49,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,154,216,156,94,4,0,32,0,115,102,50,95,50,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,88,250,75,153,4,0,32,0,115,102,50,95,50,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,157,173,102,62,4,0,32,0,115,102,50,95,50,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,250,190,193,4,0,32,0,115,102,50,95,50,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,49,200,39,6,4,0,32,0,115,102,50,95,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,27,58,130,164,3,0,16,0,115,102,50,95,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,32,22,127,5,0,64,0,115,102,50,95,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,229,173,190,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,51,46,105,99,49,55,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,31,180,1,83,1,0,16,1,49,46,105,99,49,55,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,3,200,193,1,0,16,1,52,46,105,99,49,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,182,183,115,16,1,0,16,1,50,46,105,99,49,55,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,226,108,76,146,1,0,16,1,55,46,105,99,57,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,72,175,110,137,4,0,32,0,49,51,46,105,99,56,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,42,215,93,48,4,0,32,0,49,48,46,105,99,56,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,232,91,63,239,4,0,32,0,49,54,46,105,99,56,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,185,109,127,229,4,0,32,0,54,46,105,99,57,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,196,213,76,5,4,0,32,0,49,50,46,105,99,57,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,232,105,224,135,4,0,32,0,57,46,105,99,57,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,61,163,140,129,4,0,32,0,49,53,46,105,99,57,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,209,68,251,93,4,0,32,0,56,46,105,99,56,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,250,179,187,52,4,0,32,0,49,52,46,105,99,56,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,103,26,159,125,4,0,32,0,49,49,46,105,99,56,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,214,209,166,206,4,0,32,0,49,55,46,105,99,56,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,93,160,169,145,4,0,32,0,53,46,105,99,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,138,186,213,23,3,0,16,0,115,50,116,117,95,50,51,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,56,252,161,137,2,0,16,1,115,50,116,117,95,50,50,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,53,224,166,174,2,0,16,1,115,50,116,117,95,50,49,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,136,2,32,253,2,0,16,1,115,57,50,45,49,109,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,216,176,3,4,0,32,0,115,57,50,45,51,109,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,137,2,132,4,0,32,0,115,57,50,45,50,109,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,240,181,205,4,0,32,0,115,57,50,45,52,109,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,114,148,121,226,4,0,32,0,115,57,50,45,53,109,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,39,138,186,4,0,32,0,115,57,50,45,55,109,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,191,132,229,4,0,32,0,115,57,50,45,54,109,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,125,248,227,33,4,0,32,0,115,57,50,45,56,109,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,71,252,190,4,0,32,0,115,57,50,45,49,48,109,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,213,135,6,150,4,0,32,0,115,57,50,45,49,50,109,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,205,142,151,4,0,32,0,115,57,50,45,49,49,109,46,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,10,154,236,214,4,0,32,0,115,57,50,45,49,51,109,46,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,103,44,237,4,0,32,0,115,57,50,95,48,57,46,49,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,14,182,246,8,3,0,16,0,115,57,50,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,32,22,127,5,0,64,0,115,57,50,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,229,173,190,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,115,57,50,54,51,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,224,207,126,10,0,0,0,8,105,111,98,49,46,49,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,98,112,114,103,49,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,167,61,121,49,0,0,0,8,105,111,99,49,46,105,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,129,32,24,13,0,0,0,8,99,54,51,50,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,112,146,189,15,0,0,0,8,115,50,116,106,95,50,51,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,220,180,115,234,2,0,16,1,115,50,116,106,95,50,50,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,53,224,166,174,2,0,16,1,115,50,116,106,95,50,49,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,136,2,32,253,2,0,16,1,115,57,50,95,48,49,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,216,176,3,4,0,32,0,115,57,50,95,48,50,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,137,2,132,4,0,32,0,115,57,50,95,48,51,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,240,181,205,4,0,32,0,115,57,50,95,48,52,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,114,148,121,226,4,0,32,0,115,57,50,95,48,53,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,39,138,186,4,0,32,0,115,57,50,95,48,54,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,191,132,229,4,0,32,0,115,57,50,95,48,55,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,125,248,227,33,4,0,32,0,115,57,50,95,48,56,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,71,252,190,4,0,32,0,115,50,116,95,49,48,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,134,38,4,60,4,0,32,0,115,50,116,95,49,49,46,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,131,113,126,139,4,0,32,0,115,50,116,95,49,50,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,140,136,60,41,4,0,32,0,115,50,116,95,49,51,46,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,164,53,43,132,4,0,32,0,115,57,50,95,48,57,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,14,182,246,8,3,0,16,0,115,57,50,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,32,22,127,5,0,64,0,115,57,50,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,229,173,190,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,115,57,50,54,51,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,224,207,126,10,0,0,0,8,105,111,98,49,46,49,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,98,112,114,103,49,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,167,61,121,49,0,0,0,8,105,111,99,49,46,105,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,129,32,24,13,0,0,0,8,99,54,51,50,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,112,146,189,15,0,0,0,8,50,51,40,95,95,115,102,50,98,104,104,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,158,58,246,92,2,0,16,1,50,50,40,95,95,115,102,50,98,104,104,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,202,43,215,62,2,0,16,1,115,57,50,95,50,49,97,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,119,120,90,146,2,0,16,1,115,57,50,45,49,109,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,216,176,3,4,0,32,0,115,57,50,45,51,109,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,137,2,132,4,0,32,0,115,57,50,45,50,109,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,240,181,205,4,0,32,0,115,57,50,45,52,109,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,114,148,121,226,4,0,32,0,115,57,50,45,53,109,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,39,138,186,4,0,32,0,115,57,50,45,55,109,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,191,132,229,4,0,32,0,115,57,50,45,54,109,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,125,248,227,33,4,0,32,0,115,57,50,45,56,109,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,71,252,190,4,0,32,0,115,57,50,45,49,48,109,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,213,135,6,150,4,0,32,0,115,57,50,45,49,50,109,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,205,142,151,4,0,32,0,115,57,50,45,49,49,109,46,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,10,154,236,214,4,0,32,0,115,57,50,45,49,51,109,46,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,103,44,237,4,0,32,0,115,57,50,95,48,57,46,49,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,14,182,246,8,3,0,16,0,115,57,50,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,32,22,127,5,0,64,0,115,57,50,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,229,173,190,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,115,57,50,54,51,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,224,207,126,10,0,0,0,8,105,111,98,49,46,49,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,98,112,114,103,49,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,167,61,121,49,0,0,0,8,105,111,99,49,46,105,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,129,32,24,13,0,0,0,8,99,54,51,50,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,112,146,189,15,0,0,0,8,27,0,0,0,255,255,0,0,0,0,0,0,28,0,0,0,255,255,3,0,0,0,0,0,29,0,0,0,255,255,96,0,0,0,0,0,0,0,0,0,254,0,8,0,200,87,7,0,27,0,0,0,1,7,7,0,80,252,6,0,27,0,0,0,1,7,6,0,16,242,7,0,27,0,0,0,1,7,5,0,104,236,7,0,27,0,0,0,1,7,0,0,128,230,7,0,27,0,0,0,1,7,1,0,184,164,6,0,27,0,0,0,1,7,2,0,80,74,6,0,27,0,0,0,1,7,3,0,192,32,6,0,27,0,0,0,1,7,4,0,32,242,5,0,0,0,0,0,254,0,8,0,160,123,6,0,27,0,0,0,1,56,56,0,80,252,6,0,27,0,0,0,1,56,48,0,16,242,7,0,27,0,0,0,1,56,40,0,104,236,7,0,27,0,0,0,1,56,0,0,128,230,7,0,27,0,0,0,1,56,8,0,184,164,6,0,27,0,0,0,1,56,16,0,80,74,6,0,27,0,0,0,1,56,24,0,192,32,6,0,27,0,0,0,1,56,32,0,32,242,5,0,0,0,0,0,254,0,2,0,64,232,1,0,27,0,0,0,1,64,0,0,96,135,7,0,27,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,8,0,72,202,5,0,28,0,0,0,1,7,0,0,72,198,6,0,28,0,0,0,1,7,1,0,208,75,4,0,28,0,0,0,1,7,2,0,8,49,4,0,28,0,0,0,1,7,3,0,72,195,6,0,28,0,0,0,1,7,4,0,72,246,3,0,28,0,0,0,1,7,5,0,72,0,3,0,28,0,0,0,1,7,6,0,64,47,7,0,28,0,0,0,1,7,7,0,48,173,6,0,0,0,0,0,254,0,2,0,216,82,6,0,29,0,0,0,1,1,0,0,248,38,7,0,29,0,0,0,1,1,1,0,176,64,8,0,0,0,0,0,254,0,2,0,16,227,4,0,29,0,0,0,1,4,0,0,96,135,7,0,29,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,254,0,2,0,72,4,1,0,29,0,0,0,1,8,0,0,96,135,7,0,29,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,29,0,0,0,1,16,0,0,96,135,7,0,29,0,0,0,1,16,16,0,152,182,7,0,0,0,0,0,254,0,2,0,40,111,8,0,29,0,0,0,1,32,0,0,96,135,7,0,29,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,29,0,0,0,1,64,0,0,96,135,7,0,29,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,168,79,2,0,29,0,0,0,1,128,0,0,32,182,8,0,29,0,0,0,1,128,128,0,80,251,6,0,53,46,97,109,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,186,31,153,3,1,0,16,1,52,46,97,109,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,30,90,241,57,1,0,16,1,52,46,117,50,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,66,98,187,176,1,0,16,1,51,46,117,49,57,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,120,229,22,245,1,0,16,1,121,46,99,46,101,46,99,32,109,46,107,46,114,45,48,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,19,222,88,162,4,0,32,0,121,46,99,46,101,46,99,32,109,46,107,46,114,45,48,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,135,191,129,199,4,0,32,0,121,46,99,46,101,46,99,32,109,46,107,46,114,45,48,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,184,202,38,87,4,0,32,0,121,46,99,46,101,46,99,32,100,46,119,46,99,45,48,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,47,193,144,188,4,0,32,0,121,46,99,46,101,46,99,32,100,46,119,46,99,45,48,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,204,103,118,24,4,0,32,0,121,46,99,46,101,46,99,32,100,46,119,46,99,45,48,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,113,80,88,91,4,0,32,0,51,46,97,109,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,27,58,130,164,3,0,16,0,50,46,97,109,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,32,22,127,5,0,64,0,49,46,97,109,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,229,173,190,5,0,64,0,54,46,97,109,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,117,162,133,58,8,0,32,0,57,46,97,109,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,47,71,86,145,8,0,32,0,56,46,97,109,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,59,8,219,236,8,0,32,0,49,48,46,97,109,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,132,131,234,143,8,0,32,0,55,46,97,109,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,68,28,234,19,0,0,0,8,27,0,0,0,255,255,0,0,0,0,0,0,28,0,0,0,255,255,3,0,0,0,0,0,29,0,0,0,255,255,96,0,0,0,0,0,0,0,0,0,254,0,8,0,200,87,7,0,27,0,0,0,1,7,7,0,80,252,6,0,27,0,0,0,1,7,6,0,16,242,7,0,27,0,0,0,1,7,5,0,104,236,7,0,27,0,0,0,1,7,0,0,128,230,7,0,27,0,0,0,1,7,1,0,184,164,6,0,27,0,0,0,1,7,2,0,80,74,6,0,27,0,0,0,1,7,3,0,192,32,6,0,27,0,0,0,1,7,4,0,32,242,5,0,0,0,0,0,254,0,8,0,160,123,6,0,27,0,0,0,1,56,56,0,80,252,6,0,27,0,0,0,1,56,48,0,16,242,7,0,27,0,0,0,1,56,40,0,104,236,7,0,27,0,0,0,1,56,0,0,128,230,7,0,27,0,0,0,1,56,8,0,184,164,6,0,27,0,0,0,1,56,16,0,80,74,6,0,27,0,0,0,1,56,24,0,192,32,6,0,27,0,0,0,1,56,32,0,32,242,5,0,0,0,0,0,254,0,2,0,64,232,1,0,27,0,0,0,1,64,0,0,96,135,7,0,27,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,8,0,72,202,5,0,28,0,0,0,1,7,0,0,72,198,6,0,28,0,0,0,1,7,1,0,208,75,4,0,28,0,0,0,1,7,2,0,8,49,4,0,28,0,0,0,1,7,3,0,72,195,6,0,28,0,0,0,1,7,4,0,72,246,3,0,28,0,0,0,1,7,5,0,72,0,3,0,28,0,0,0,1,7,6,0,64,47,7,0,28,0,0,0,1,7,7,0,48,173,6,0,0,0,0,0,254,0,2,0,128,166,1,0,28,0,0,0,1,56,0,0,96,135,7,0,28,0,0,0,1,56,56,0,152,182,7,0,0,0,0,0,254,0,2,0,16,227,4,0,29,0,0,0,1,4,0,0,96,135,7,0,29,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,254,0,2,0,72,4,1,0,29,0,0,0,1,8,0,0,96,135,7,0,29,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,29,0,0,0,1,16,0,0,96,135,7,0,29,0,0,0,1,16,16,0,152,182,7,0,0,0,0,0,254,0,2,0,40,111,8,0,29,0,0,0,1,32,0,0,96,135,7,0,29,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,29,0,0,0,1,64,0,0,96,135,7,0,29,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,168,79,2,0,29,0,0,0,1,128,0,0,32,182,8,0,29,0,0,0,1,128,128,0,80,251,6,0,115,102,50,99,97,95,50,51,45,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,166,197,200,231,2,0,16,1,115,102,50,99,97,95,50,50,45,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,164,204,241,153,2,0,16,1,115,102,50,99,97,95,50,49,45,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,140,204,127,207,2,0,16,1,115,57,50,95,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,216,176,3,4,0,32,0,115,57,50,95,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,137,2,132,4,0,32,0,115,57,50,95,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,240,181,205,4,0,32,0,115,57,50,95,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,114,148,121,226,4,0,32,0,115,57,50,95,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,39,138,186,4,0,32,0,115,57,50,95,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,191,132,229,4,0,32,0,115,57,50,95,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,125,248,227,33,4,0,32,0,115,57,50,95,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,71,252,190,4,0,32,0,115,57,50,95,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,213,135,6,150,4,0,32,0,115,57,50,95,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,205,142,151,4,0,32,0,115,57,50,95,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,10,154,236,214,4,0,32,0,115,57,50,95,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,103,44,237,4,0,32,0,115,57,50,95,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,14,182,246,8,3,0,16,0,115,57,50,95,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,32,22,127,5,0,64,0,115,57,50,95,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,229,173,190,5,0,64,0,101,112,114,49,50,54,53,46,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,63,75,116,160,1,0,16,1,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,205,69,114,142,1,0,16,1,101,112,114,49,50,54,55,46,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,251,230,164,71,1,0,16,1,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,28,242,68,114,1,0,16,1,101,112,114,49,50,54,57,46,50,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,1,168,248,225,1,0,16,1,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,222,255,42,213,1,0,16,1,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,89,105,52,212,2,0,16,1,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,149,93,2,204,2,0,16,1,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,63,197,40,22,2,0,16,1,101,112,114,49,50,55,52,46,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,180,19,209,100,4,0,32,0,101,112,114,49,50,55,51,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,211,22,99,169,4,0,32,0,56,50,115,49,50,51,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,13,249,135,155,7,0,32,0,18,0,0,0,255,255,0,0,0,0,0,0,19,0,0,0,255,255,3,0,0,0,0,0,20,0,0,0,255,255,12,0,0,0,0,0,0,0,0,0,254,0,2,0,104,159,3,0,19,0,0,0,1,1,1,0,96,135,7,0,19,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,128,129,4,0,19,0,0,0,1,2,2,0,8,49,4,0,19,0,0,0,1,2,0,0,152,21,4,0,0,0,0,0,254,0,4,0,32,4,2,0,20,0,0,0,1,6,2,0,224,127,8,0,20,0,0,0,1,6,0,0,0,67,1,0,20,0,0,0,1,6,4,0,32,123,8,0,20,0,0,0,1,6,6,0,152,252,1,0,0,0,0,0,254,0,2,0,200,30,2,0,20,0,0,0,1,8,8,0,120,97,1,0,20,0,0,0,1,8,0,0,96,19,1,0,0,0,0,0,48,54,46,106,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,106,238,46,41,0,0,16,1,48,55,46,106,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,141,105,107,244,0,0,16,1,48,56,46,106,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,190,127,94,167,0,0,16,1,48,50,46,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,198,255,34,12,0,0,32,0,48,51,46,102,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,193,139,226,58,0,0,32,0,48,52,46,103,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,91,238,61,187,0,0,32,0,48,53,46,103,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,132,8,6,74,0,0,32,0,49,48,46,108,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,143,93,103,214,0,0,32,0,48,57,46,108,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,200,139,103,143,0,0,32,0,48,49,46,100,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,38,161,110,185,0,0,64,0,101,101,112,114,111,109,45,115,98,98,114,111,115,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,205,211,105,237,0,0,16,0,17,0,0,0,255,255,0,0,0,0,0,0,18,0,0,0,255,255,4,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,17,0,0,0,1,2,0,0,120,97,1,0,17,0,0,0,1,2,2,0,96,19,1,0,0,0,0,0,254,0,4,0,128,129,4,0,17,0,0,0,1,192,0,0,8,49,4,0,17,0,0,0,1,192,64,0,152,21,4,0,17,0,0,0,1,192,128,0,72,246,3,0,17,0,0,0,1,192,192,0,72,0,3,0,0,0,0,0,254,0,2,0,32,4,2,0,18,0,0,0,1,2,2,0,208,244,3,0,18,0,0,0,1,2,0,0,144,219,3,0,0,0,0,0,254,0,2,0,168,234,7,0,18,0,0,0,1,4,0,0,96,135,7,0,18,0,0,0,1,4,4,0,152,182,7,0,101,112,114,45,49,51,51,52,56,46,97,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,134,12,14,95,1,0,16,1,101,112,114,45,49,51,51,52,55,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,250,49,128,57,1,0,16,1,111,112,114,45,49,51,51,53,49,46,97,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,109,78,138,166,2,0,32,0,111,112,114,45,49,51,51,53,50,46,97,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,228,49,85,94,2,0,32,0,111,112,114,45,49,51,51,53,51,46,97,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,216,223,35,109,2,0,32,0,111,112,114,45,49,51,51,53,52,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,153,173,122,240,3,0,32,0,111,112,114,45,49,51,51,53,54,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,11,41,152,84,3,0,32,0,111,112,114,45,49,51,51,53,53,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,25,0,137,103,3,0,32,0,111,112,114,45,49,51,51,53,55,46,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,3,207,231,249,3,0,32,0,101,112,114,45,49,51,51,52,57,46,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,248,131,49,184,4,0,16,1,111,112,114,45,49,51,51,53,48,46,97,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,88,166,89,60,8,0,64,0,51,49,55,45,53,48,50,51,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,49,67,112,67,5,0,16,1])
.concat([13,0,0,0,255,255,248,0,0,0,0,0,14,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,168,234,7,0,13,0,0,0,1,1,1,0,96,135,7,0,13,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,48,148,3,0,13,0,0,0,1,2,0,0,208,75,4,0,13,0,0,0,1,2,2,0,8,49,4,0,0,0,0,0,254,0,2,0,72,84,4,0,13,0,0,0,1,4,4,0,152,43,6,0,13,0,0,0,1,4,0,0,80,138,3,0,0,0,0,0,254,0,2,0,128,135,3,0,13,0,0,0,1,8,0,0,96,135,7,0,13,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,192,132,3,0,13,0,0,0,1,48,32,0,80,246,3,0,13,0,0,0,1,48,48,0,248,38,7,0,13,0,0,0,1,48,16,0,112,212,3,0,13,0,0,0,1,48,0,0,248,160,5,0,0,0,0,0,254,0,4,0,72,202,5,0,13,0,0,0,1,192,128,0,80,246,3,0,13,0,0,0,1,192,192,0,248,38,7,0,13,0,0,0,1,192,64,0,112,212,3,0,13,0,0,0,1,192,0,0,248,160,5,0,0,0,0,0,254,0,16,0,200,87,7,0,14,0,0,0,1,15,7,0,80,252,6,0,14,0,0,0,1,15,8,0,16,242,7,0,14,0,0,0,1,15,9,0,104,236,7,0,14,0,0,0,1,15,5,0,176,51,4,0,14,0,0,0,1,15,4,0,56,24,4,0,14,0,0,0,1,15,15,0,128,230,7,0,14,0,0,0,1,15,1,0,72,216,3,0,14,0,0,0,1,15,2,0,24,188,3,0,14,0,0,0,1,15,3,0,176,162,3,0,14,0,0,0,1,15,6,0,120,211,6,0,14,0,0,0,1,15,14,0,184,164,6,0,14,0,0,0,1,15,13,0,80,74,6,0,14,0,0,0,1,15,12,0,192,32,6,0,14,0,0,0,1,15,11,0,192,234,2,0,14,0,0,0,1,15,10,0,32,242,5,0,14,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,14,0,0,0,1,240,112,0,80,252,6,0,14,0,0,0,1,240,128,0,16,242,7,0,14,0,0,0,1,240,144,0,104,236,7,0,14,0,0,0,1,240,80,0,176,51,4,0,14,0,0,0,1,240,64,0,56,24,4,0,14,0,0,0,1,240,240,0,128,230,7,0,14,0,0,0,1,240,16,0,72,216,3,0,14,0,0,0,1,240,32,0,24,188,3,0,14,0,0,0,1,240,48,0,176,162,3,0,14,0,0,0,1,240,96,0,120,211,6,0,14,0,0,0,1,240,224,0,184,164,6,0,14,0,0,0,1,240,208,0,80,74,6,0,14,0,0,0,1,240,192,0,192,32,6,0,14,0,0,0,1,240,176,0,192,234,2,0,14,0,0,0,1,240,160,0,32,242,5,0,14,0,0,0,1,240,0,0,208,236,2,0,21,0,0,0,255,255,255,0,0,0,0,0,22,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,21,0,0,0,1,2,2,0,96,135,7,0,21,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,21,0,0,0,1,4,4,0,96,135,7,0,21,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,21,0,0,0,1,8,0,0,96,135,7,0,21,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,2,0,200,87,7,0,21,0,0,0,1,48,0,0,40,88,7,0,21,0,0,0,1,48,16,0,96,39,7,0,21,0,0,0,1,48,48,0,144,251,6,0,21,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,21,0,0,0,1,192,0,0,40,88,7,0,21,0,0,0,1,192,64,0,96,39,7,0,21,0,0,0,1,192,192,0,144,251,6,0,21,0,0,0,1,192,128,0,184,164,6,0,0,0,0,0,254,0,4,0,72,202,5,0,22,0,0,0,1,3,2,0,80,246,3,0,22,0,0,0,1,3,3,0,80,124,6,0,22,0,0,0,1,3,1,0,112,212,3,0,22,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,128,129,4,0,22,0,0,0,1,12,0,0,192,255,2,0,22,0,0,0,1,12,4,0,208,75,4,0,22,0,0,0,1,12,12,0,8,49,4,0,22,0,0,0,1,12,8,0,152,21,4,0,0,0,0,0,99,55,52,45,49,48,46,105,99,53,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,11,162,129,202,2,0,16,1,99,55,52,45,48,56,46,105,99,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,158,221,53,170,2,0,16,1,99,55,52,45,49,49,46,105,99,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,213,214,59,238,2,0,16,1,99,55,52,45,48,57,46,105,99,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,235,47,204,88,2,0,16,1,99,55,52,45,49,50,46,105,99,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,104,214,110,187,9,0,16,1,99,55,52,45,48,49,46,105,99,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,128,206,52,52,11,0,32,0,99,55,52,45,48,51,46,105,99,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,81,137,13,26,15,0,32,0,99,55,52,45,48,50,46,105,99,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,6,21,162,21,15,0,32,0,99,55,52,45,48,52,46,105,99,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,242,237,151,45,24,0,64,0,99,55,52,45,48,53,46,105,99,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,40,8,156,226,25,0,64,0,40,0,0,0,255,255,255,0,0,0,0,0,41,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,40,0,0,0,1,2,2,0,96,135,7,0,40,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,40,0,0,0,1,4,4,0,96,135,7,0,40,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,40,0,0,0,1,8,0,0,96,135,7,0,40,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,40,0,0,0,1,48,0,0,16,242,7,0,40,0,0,0,1,48,16,0,104,236,7,0,40,0,0,0,1,48,48,0,128,230,7,0,40,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,40,0,0,0,1,192,0,0,16,242,7,0,40,0,0,0,1,192,64,0,104,236,7,0,40,0,0,0,1,192,192,0,128,230,7,0,40,0,0,0,1,192,128,0,184,164,6,0,0,0,0,0,254,0,4,0,72,202,5,0,41,0,0,0,1,3,2,0,80,246,3,0,41,0,0,0,1,3,3,0,248,38,7,0,41,0,0,0,1,3,1,0,112,212,3,0,41,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,64,251,5,0,41,0,0,0,1,48,48,0,240,242,5,0,41,0,0,0,1,48,32,0,136,176,4,0,41,0,0,0,1,48,16,0,72,173,4,0,41,0,0,0,1,48,0,0,80,169,4,0,0,0,0,0,254,0,2,0,160,164,4,0,41,0,0,0,1,64,0,0,96,135,7,0,41,0,0,0,1,64,64,0,152,182,7,0,22,0,0,0,255,255,251,0,0,0,0,0,0,0,0,0,254,0,2,0,168,234,7,0,22,0,0,0,1,4,4,0,152,182,7,0,22,0,0,0,1,4,0,0,96,135,7,0,22,0,0,0,255,255,255,0,0,0,0,0,23,0,0,0,255,255,247,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,22,0,0,0,1,3,2,0,208,75,4,0,22,0,0,0,1,3,3,0,8,49,4,0,22,0,0,0,1,3,1,0,152,21,4,0,22,0,0,0,1,3,0,0,72,246,3,0,0,0,0,0,254,0,4,0,72,202,5,0,22,0,0,0,1,12,8,0,80,246,3,0,22,0,0,0,1,12,12,0,248,38,7,0,22,0,0,0,1,12,4,0,112,212,3,0,22,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,2,0,168,234,7,0,23,0,0,0,1,2,0,0,96,135,7,0,23,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,3,0,200,30,2,0,23,0,0,0,1,24,16,0,120,97,1,0,23,0,0,0,1,24,0,0,64,201,8,0,23,0,0,0,1,24,24,0,96,19,1,0,0,0,0,0,18,0,0,0,255,255,0,0,0,0,0,0,19,0,0,0,255,255,32,0,0,0,0,0,0,0,0,0,254,0,12,0,200,87,7,0,18,0,0,0,1,15,13,0,40,88,7,0,18,0,0,0,1,15,12,0,96,39,7,0,18,0,0,0,1,15,5,0,128,13,7,0,18,0,0,0,1,15,0,0,144,251,6,0,18,0,0,0,1,15,3,0,40,183,6,0,18,0,0,0,1,15,2,0,232,192,7,0,18,0,0,0,1,15,6,0,120,211,6,0,18,0,0,0,1,15,8,0,184,164,6,0,18,0,0,0,1,15,9,0,80,74,6,0,18,0,0,0,1,15,10,0,192,32,6,0,18,0,0,0,1,15,11,0,192,234,2,0,18,0,0,0,1,15,4,0,32,242,5,0,0,0,0,0,254,0,12,0,160,123,6,0,18,0,0,0,1,240,208,0,40,88,7,0,18,0,0,0,1,240,192,0,96,39,7,0,18,0,0,0,1,240,80,0,128,13,7,0,18,0,0,0,1,240,0,0,144,251,6,0,18,0,0,0,1,240,48,0,40,183,6,0,18,0,0,0,1,240,32,0,232,192,7,0,18,0,0,0,1,240,96,0,120,211,6,0,18,0,0,0,1,240,128,0,184,164,6,0,18,0,0,0,1,240,144,0,80,74,6,0,18,0,0,0,1,240,160,0,192,32,6,0,18,0,0,0,1,240,176,0,192,234,2,0,18,0,0,0,1,240,64,0,32,242,5,0,0,0,0,0,254,0,4,0,72,202,5,0,19,0,0,0,1,3,2,0,80,246,3,0,19,0,0,0,1,3,0,0,248,38,7,0,19,0,0,0,1,3,1,0,112,212,3,0,19,0,0,0,1,3,3,0,248,160,5,0,0,0,0,0,254,0,2,0,128,129,4,0,19,0,0,0,1,4,0,0,208,75,4,0,19,0,0,0,1,4,4,0,8,49,4,0,0,0,0,0,254,0,2,0,16,190,6,0,19,0,0,0,1,8,0,0,200,105,5,0,19,0,0,0,1,8,8,0,48,153,2,0,0,0,0,0,254,0,2,0,32,141,2,0,19,0,0,0,1,16,0,0,72,130,2,0,19,0,0,0,1,16,16,0,120,7,5,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,32,0,0,96,135,7,0,19,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,224,117,5,0,19,0,0,0,1,64,64,0,96,135,7,0,19,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,128,0,0,96,135,7,0,19,0,0,0,1,128,128,0,152,182,7,0,0,0,0,0,0,0,0,0,0,0,0,0,184,40,2,0,1,0,0,0,30,84,148,0,248,191,2,0,56,250,6,0,1,0,0,0,22,84,148,0,184,160,2,0,184,164,8,0,1,0,0,0,31,84,148,0,64,246,1,0,88,149,7,0,1,0,0,0,23,84,148,0,136,224,1,0,56,210,6,0,1,0,0,0,19,84,148,0,192,135,2,0,24,163,6,0,1,0,0,0,18,84,148,0,240,108,2,0,152,122,6,0,1,0,0,0,17,84,148,0,96,82,2,0,192,72,6,0,1,0,0,0,16,84,148,0,32,56,2,0,48,123,2,0,1,0,0,0,9,84,148,0,152,30,2,0,96,69,2,0,1,0,0,0,20,84,148,0,232,10,2,0,144,55,2,0,1,0,0,0,21,84,148,0,152,138,8,0,176,223,1,0,1,0,0,0,27,84,148,0,72,198,1,0,192,209,1,0,1,0,0,0,26,84,148,0,24,182,1,0,24,198,1,0,1,0,0,0,25,84,148,0,40,167,1,0,120,189,1,0,1,0,0,0,24,84,148,0,200,149,1,0,248,187,8,0,1,0,0,0,13,84,148,0,56,126,1,0,184,179,8,0,1,0,0,0,28,84,148,0,32,101,1,0,240,173,8,0,1,0,0,0,29,84,148,0,96,32,8,0,88,212,3,0,1,0,0,0,40,229,148,0,40,185,3,0,248,5,8,0,9,0,0,0,160,72,215,0,32,58,1,0,144,250,7,0,9,0,0,0,161,72,215,0,32,58,1,0,114,98,49,53,97,99,112,117,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,186,84,230,215,1,0,16,1,114,98,49,53,98,99,112,117,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,88,161,62,169,1,0,16,1,114,98,49,53,99,99,112,117,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,208,211,140,5,1,0,16,1,114,98,49,53,100,99,112,117,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,66,87,80,214,1,0,16,1,114,98,49,53,101,99,112,117,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,164,243,77,96,1,0,16,1,114,98,49,53,99,115,110,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,23,191,36,139,2,0,16,1,114,98,49,53,100,115,110,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,179,79,110,217,2,0,16,1,114,98,49,53,102,99,112,117,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,12,210,137,68,4,0,32,0,114,98,49,53,104,99,112,117,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,71,197,18,85,4,0,32,0,114,101,115,99,117,101,46,99,108,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,189,188,198,64,7,0,32,0,14,0,0,0,255,255,0,0,0,0,0,0,15,0,0,0,255,255,2,0,0,0,0,0,16,0,0,0,255,255,12,0,0,0,0,0,0,0,0,0,254,0,2,0,112,177,1,0,14,0,0,0,1,2,0,0,192,255,2,0,14,0,0,0,1,2,2,0,8,49,4,0,0,0,0,0,254,0,2,0,128,129,4,0,15,0,0,0,1,1,0,0,8,49,4,0,15,0,0,0,1,1,1,0,72,246,3,0,0,0,0,0,254,0,2,0,168,234,7,0,15,0,0,0,1,2,0,0,96,135,7,0,15,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,4,0,32,4,2,0,16,0,0,0,1,6,4,0,128,103,7,0,16,0,0,0,1,6,6,0,56,52,2,0,16,0,0,0,1,6,2,0,224,44,2,0,16,0,0,0,1,6,0,0,224,43,2,0,0,0,0,0,254,0,2,0,72,202,5,0,16,0,0,0,1,8,8,0,80,246,3,0,16,0,0,0,1,8,0,0,112,212,3,0,114,101,100,117,102,111,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,60,135,59,106,1,0,16,1,114,101,100,117,102,111,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,59,218,46,32,1,0,16,1,114,101,100,117,102,111,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,232,48,112,191,1,0,16,1,114,101,100,117,102,111,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,249,46,28,140,1,0,16,1,114,101,100,117,102,111,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,36,91,150,239,1,0,16,1,114,101,100,117,102,111,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,155,227,179,88,1,0,16,1,114,101,100,117,102,111,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,17,216,7,253,1,0,16,1,114,101,100,117,102,111,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,180,124,76,179,4,0,32,0,114,101,100,117,102,111,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,71,212,162,80,4,0,32,0,116,98,112,49,56,115,48,51,48,110,46,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,135,125,12,106,7,0,32,0,12,0,0,0,255,255,0,0,0,0,0,0,13,0,0,0,255,255,192,0,0,0,0,0,14,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,232,75,4,0,12,0,0,0,1,64,0,0,96,135,7,0,12,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,200,87,7,0,13,0,0,0,1,64,0,0,224,127,8,0,13,0,0,0,1,64,64,0,32,123,8,0,0,0,0,0,254,0,2,0,160,123,6,0,13,0,0,0,1,128,128,0,96,102,7,0,13,0,0,0,1,128,0,0,152,96,3,0,0,0,0,0,254,0,2,0,64,37,5,0,14,0,0,0,1,1,0,0,176,114,3,0,14,0,0,0,1,1,1,0,120,7,5,0,0,0,0,0,254,0,2,0,128,129,4,0,14,0,0,0,1,4,0,0,8,49,4,0,14,0,0,0,1,4,4,0,72,246,3,0,0,0,0,0,254,0,2,0,200,30,2,0,14,0,0,0,1,8,0,0,120,97,1,0,14,0,0,0,1,8,8,0,96,19,1,0,0,0,0,0,101,112,114,45,49,51,57,56,54,46,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,101,35,139,56,1,0,16,1,101,112,114,45,49,51,57,56,53,46,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,212,165,219,20,1,0,16,1,101,112,114,45,49,51,57,56,56,46,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,164,213,28,220,1,0,16,1,101,112,114,45,49,51,57,56,55,46,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,96,158,190,67,1,0,16,1,101,112,114,45,49,51,57,57,50,97,46,56,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,182,37,213,197,9,0,16,1,101,112,114,45,49,51,57,57,49,97,46,56,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,124,60,158,41,9,0,16,1,101,112,114,45,49,52,48,57,50,46,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,197,35,235,24,17,0,16,1,101,112,114,45,49,52,48,57,49,46,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,113,111,165,114,17,0,16,1,109,112,114,45,49,51,57,57,55,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,135,27,223,31,3,0,32,0,109,112,114,45,49,51,57,57,57,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,60,213,29,154,3,0,32,0,109,112,114,45,49,52,48,50,49,46,54,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,129,135,168,159,18,0,32,0,109,112,114,45,49,52,48,50,50,46,55,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,187,36,232,73,18,0,32,0,109,112,114,45,49,52,48,48,57,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,126,24,181,53,18,0,32,0,109,112,114,45,49,52,48,49,48,46,55,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,155,139,83,154,18,0,32,0,109,112,114,45,49,52,48,50,51,46,56,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,103,108,28,225,18,0,32,0,109,112,114,45,49,52,48,50,52,46,49,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,53,69,52,22,18,0,32,0,109,112,114,45,49,52,48,49,49,46,56,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,59,152,233,120,18,0,32,0,109,112,114,45,49,52,48,49,50,46,49,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,164,161,218,233,18,0,32,0,109,112,114,45,49,52,48,49,55,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,89,241,61,184,18,0,32,0,109,112,114,45,49,52,48,49,56,46,55,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,206,233,219,118,18,0,32,0,109,112,114,45,49,52,48,48,53,46,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,9,130,153,158,18,0,32,0,109,112,114,45,49,52,48,48,54,46,55,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,26,223,173,44,18,0,32,0,109,112,114,45,49,52,48,49,57,46,56,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,255,25,94,177,18,0,32,0,109,112,114,45,49,52,48,50,48,46,49,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,143,0,199,132,18,0,32,0,109,112,114,45,49,52,48,48,55,46,56,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,170,95,207,195,18,0,32,0,109,112,114,45,49,52,48,48,56,46,49,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,178,190,145,126,18,0,32,0,109,112,114,45,49,52,48,49,51,46,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,195,178,219,49,18,0,32,0,109,112,114,45,49,52,48,49,52,46,55,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,125,37,104,126,18,0,32,0,109,112,114,45,49,52,48,48,49,46,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,208,26,3,113,18,0,32,0,109,112,114,45,49,52,48,48,50,46,54,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,94,10,231,39,18,0,32,0,109,112,114,45,49,52,48,49,53,46,56,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,133,191,64,117,18,0,32,0,109,112,114,45,49,52,48,49,54,46,49,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,77,185,135,125,18,0,32,0,109,112,114,45,49,52,48,48,51,46,56,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,116,93,114,135,18,0,32,0,109,112,114,45,49,52,48,48,52,46,49,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,145,114,71,115,18,0,32,0,101,112,114,45,49,51,57,57,51,46,49,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,67,181,195,124,4,0,16,1,109,112,114,45,49,51,57,57,54,46,49,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,65,90,95,52,11,0,64,0,109,112,114,45,49,51,57,57,53,46,49,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,112,194,4,246,11,0,64,0,109,112,114,45,49,51,57,57,52,46,49,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,56,85,9,118,11,0,64,0,13,0,0,0,255,255,99,0,0,0,0,0,14,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,56,154,6,0,13,0,0,0,1,3,3,0,184,30,3,0,13,0,0,0,1,3,2,0,0,28,3,0,13,0,0,0,1,3,1,0,144,188,3,0,13,0,0,0,1,3,0,0,176,163,3,0,0,0,0,0,254,0,2,0,8,93,1,0,13,0,0,0,1,4,4,0,8,208,6,0,13,0,0,0,1,4,0,0,72,5,2,0,0,0,0,0,254,0,2,0,200,30,2,0,13,0,0,0,1,8,8,0,120,247,1,0,13,0,0,0,1,8,0,0,120,97,1,0,0,0,0,0,254,0,4,0,72,202,5,0,13,0,0,0,1,96,64,0,80,246,3,0,13,0,0,0,1,96,96,0,248,38,7,0,13,0,0,0,1,96,32,0,112,212,3,0,13,0,0,0,1,96,0,0,248,160,5,0,0,0,0,0,254,0,2,0,168,234,7,0,13,0,0,0,1,128,128,0,96,135,7,0,13,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,4,0,8,248,1,0,14,0,0,0,1,3,0,0,80,252,6,0,14,0,0,0,1,3,1,0,16,242,7,0,14,0,0,0,1,3,2,0,104,236,7,0,14,0,0,0,1,3,3,0,208,238,1,0,0,0,0,0,254,0,2,0,32,227,1,0,14,0,0,0,1,4,4,0,192,211,1,0,14,0,0,0,1,4,0,0,200,200,1,0,0,0,0,0,254,0,4,0,104,190,1,0,14,0,0,0,1,24,24,0,192,211,1,0,14,0,0,0,1,24,16,0,32,183,1,0,14,0,0,0,1,24,8,0,24,176,1,0,14,0,0,0,1,24,0,0,144,169,1,0,0,0,0,0,254,0,8,0,24,161,1,0,14,0,0,0,1,224,224,0,120,7,5,0,14,0,0,0,1,224,192,0,120,142,1,0,14,0,0,0,1,224,160,0,192,128,1,0,14,0,0,0,1,224,128,0,192,114,1,0,14,0,0,0,1,224,96,0,248,102,1,0,14,0,0,0,1,224,64,0,24,93,1,0,14,0,0,0,1,224,32,0,144,86,1,0,14,0,0,0,1,224,0,0,248,78,1,0,0,0,0,0,98,48,52,45,51,56,46,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,177,219,145,28,2,0,16,1,98,48,52,45,51,55,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,221,11,242,236,2,0,16,1,98,48,52,45,52,48,46,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,179,212,48,9,2,0,16,1,98,48,52,45,51,57,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,94,222,90,217,2,0,16,1,98,48,52,45,52,50,46,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,203,167,87,24,2,0,16,1,98,48,52,45,52,51,45,49,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,255,2,71,202,2,0,16,1,98,48,52,45,49,57,46,52,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,216,253,129,238,9,0,16,1,98,48,52,45,48,49,46,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,25,222,48,205,11,0,32,0,98,48,52,45,48,51,46,51,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,100,224,103,171,11,0,32,0,98,48,52,45,48,50,46,54,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,236,15,4,84,11,0,32,0,98,48,52,45,48,52,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,147,126,115,148,11,0,32,0,98,48,52,45,48,53,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,172,148,45,194,15,0,32,0,98,48,52,45,48,55,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,81,42,99,181,15,0,32,0,98,48,52,45,48,54,46,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,57,207,44,0,15,0,32,0,98,48,52,45,48,56,46,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,5,202,175,254,15,0,32,0,98,48,52,45,50,48,46,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,204,52,26,253,26,0,64,0,19,0,0,0,255,255,254,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,19,0,0,0,1,1,0,0,120,97,1,0,19,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,2,2,0,96,135,7,0,19,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,4,4,0,96,135,7,0,19,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,8,0,0,96,135,7,0,19,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,19,0,0,0,1,48,0,0,80,252,6,0,19,0,0,0,1,48,16,0,16,242,7,0,19,0,0,0,1,48,32,0,104,236,7,0,19,0,0,0,1,48,48,0,128,230,7,0,0,0,0,0,254,0,4,0,160,123,6,0,19,0,0,0,1,192,192,0,8,201,6,0,19,0,0,0,1,192,128,0,200,197,6,0,19,0,0,0,1,192,64,0,152,194,6,0,19,0,0,0,1,192,0,0,248,189,6,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,3,2,0,80,246,3,0,20,0,0,0,1,3,3,0,80,124,6,0,20,0,0,0,1,3,1,0,112,212,3,0,20,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,64,37,5,0,20,0,0,0,1,12,12,0,168,114,7,0,20,0,0,0,1,12,8,0,152,109,7,0,20,0,0,0,1,12,4,0,16,103,7,0,20,0,0,0,1,12,0,0,72,96,7,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,48,48,0,8,49,4,0,20,0,0,0,1,48,32,0,152,21,4,0,20,0,0,0,1,48,16,0,72,246,3,0,20,0,0,0,1,48,0,0,72,0,3,0,0,0,0,0,254,0,2,0,104,159,3,0,20,0,0,0,1,64,0,0,96,135,7,0,20,0,0,0,1,64,64,0,152,182,7,0,19,0,0,0,255,255,254,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,2,2,0,96,135,7,0,19,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,4,4,0,96,135,7,0,19,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,8,0,0,96,135,7,0,19,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,19,0,0,0,1,48,0,0,32,136,7,0,19,0,0,0,1,48,16,0,40,88,7,0,19,0,0,0,1,48,32,0,96,39,7,0,19,0,0,0,1,48,48,0,144,251,6,0,0,0,0,0,254,0,4,0,160,123,6,0,19,0,0,0,1,192,192,0,184,164,6,0,19,0,0,0,1,192,128,0,80,74,6,0,19,0,0,0,1,192,64,0,192,32,6,0,19,0,0,0,1,192,0,0,32,242,5,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,3,2,0,80,246,3,0,20,0,0,0,1,3,3,0,80,124,6,0,20,0,0,0,1,3,1,0,112,212,3,0,20,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,2,0,104,159,3,0,20,0,0,0,1,16,0,0,96,135,7,0,20,0,0,0,1,16,16,0,152,182,7,0,0,0,0,0,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,13,112,130,88,0,0,16,1,114,97,108,108,121,120,110,46,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,43,186,30,237,0,0,16,1,114,97,108,108,121,120,110,46,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,28,221,152,79,0,0,16,1,114,97,108,108,121,120,110,46,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,240,204,172,154,0,0,16,1,56,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,229,29,124,39,0,0,32,0,114,120,49,45,54,46,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,44,246,22,60,0,0,32,0,114,120,49,45,49,46,49,49,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,52,84,134,199,0,0,32,0,114,120,49,45,55,46,56,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,218,79,77,131,0,0,32,0,114,120,49,45,50,46,52,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,21,72,87,143,0,0,32,0,114,120,49,45,51,46,55,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,150,16,134,184,0,0,32,0,114,120,49,45,53,46,51,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,23,112,173,75,0,0,64,0,114,120,49,45,52,46,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,0,99,53,51,45,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,32,252,152,199,2,0,16,1,99,53,51,45,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,62,201,68,191,2,0,16,1,99,53,51,45,53,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,202,74,225,18,2,0,16,1,99,53,51,45,53,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,243,102,239,179,2,0,16,1,99,53,51,45,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,129,126,24,37,9,0,16,1,99,53,51,45,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,112,110,89,71,16,0,32,0,99,53,51,45,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,47,168,159,79,16,0,32,0,99,53,51,45,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,244,198,4,215,16,0,32,0,99,53,51,45,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,252,99,127,247,16,0,32,0,99,53,51,45,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,212,10,137,153,24,0,64,0,17,0,0,0,255,255,255,0,0,0,0,0,18,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,17,0,0,0,1,2,2,0,96,135,7,0,17,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,17,0,0,0,1,4,4,0,96,135,7,0,17,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,17,0,0,0,1,48,0,0,16,242,7,0,17,0,0,0,1,48,16,0,104,236,7,0,17,0,0,0,1,48,48,0,128,230,7,0,17,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,17,0,0,0,1,192,0,0,16,242,7,0,17,0,0,0,1,192,64,0,104,236,7,0,17,0,0,0,1,192,192,0,128,230,7,0,17,0,0,0,1,192,128,0,184,164,6,0,0,0,0,0,254,0,4,0,72,202,5,0,18,0,0,0,1,3,2,0,80,246,3,0,18,0,0,0,1,3,3,0,80,124,6,0,18,0,0,0,1,3,1,0,112,212,3,0,18,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,112,59,6,0,18,0,0,0,1,12,12,0,184,56,6,0,18,0,0,0,1,12,8,0,120,53,6,0,18,0,0,0,1,12,4,0,200,48,6,0,18,0,0,0,1,12,0,0,152,43,6,0,0,0,0,0,254,0,4,0,128,129,4,0,18,0,0,0,1,48,32,0,192,255,2,0,18,0,0,0,1,48,48,0,208,75,4,0,18,0,0,0,1,48,16,0,8,49,4,0,18,0,0,0,1,48,0,0,152,21,4,0,0,0,0,0,254,0,2,0,104,159,3,0,18,0,0,0,1,64,0,0,96,135,7,0,18,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,6,0,18,0,0,0,1,128,0,0,8,208,6,0,18,0,0,0,1,128,128,0,88,204,6,0,0,0,0,0,22,0,0,0,255,255,159,0,0,0,0,0,23,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,22,0,0,0,1,3,2,0,208,75,4,0,22,0,0,0,1,3,3,0,8,49,4,0,22,0,0,0,1,3,1,0,152,21,4,0,22,0,0,0,1,3,0,0,72,246,3,0,0,0,0,0,254,0,2,0,136,74,8,0,22,0,0,0,1,32,32,0,120,26,6,0,22,0,0,0,1,32,0,0,88,140,3,0,0,0,0,0,254,0,2,0,168,234,7,0,22,0,0,0,1,64,64,0,96,135,7,0,22,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,22,0,0,0,1,128,128,0,96,135,7,0,22,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,23,0,0,0,1,1,1,0,96,135,7,0,23,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,96,46,8,0,23,0,0,0,1,8,8,0,192,255,2,0,23,0,0,0,1,8,0,0,208,75,4,0,0,0,0,0,254,0,16,0,32,4,2,0,23,0,0,0,1,240,160,0,144,160,3,0,23,0,0,0,1,240,176,0,96,135,3,0,23,0,0,0,1,240,192,0,32,136,7,0,23,0,0,0,1,240,208,0,40,88,7,0,23,0,0,0,1,240,224,0,96,39,7,0,23,0,0,0,1,240,16,0,32,202,2,0,23,0,0,0,1,240,48,0,120,113,6,0,23,0,0,0,1,240,32,0,232,228,5,0,23,0,0,0,1,240,240,0,144,251,6,0,23,0,0,0,1,240,64,0,120,211,6,0,23,0,0,0,1,240,144,0,184,164,6,0,23,0,0,0,1,240,128,0,80,74,6,0,23,0,0,0,1,240,112,0,192,32,6,0,23,0,0,0,1,240,96,0,192,234,2,0,23,0,0,0,1,240,80,0,32,242,5,0,23,0,0,0,1,240,0,0,16,227,4,0,0,0,0,0,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,254,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,19,0,0,0,1,15,7,0,80,252,6,0,19,0,0,0,1,15,8,0,16,242,7,0,19,0,0,0,1,15,9,0,104,236,7,0,19,0,0,0,1,15,5,0,176,51,4,0,19,0,0,0,1,15,4,0,56,24,4,0,19,0,0,0,1,15,15,0,128,230,7,0,19,0,0,0,1,15,1,0,72,216,3,0,19,0,0,0,1,15,2,0,24,188,3,0,19,0,0,0,1,15,3,0,176,162,3,0,19,0,0,0,1,15,6,0,120,211,6,0,19,0,0,0,1,15,14,0,184,164,6,0,19,0,0,0,1,15,13,0,80,74,6,0,19,0,0,0,1,15,12,0,192,32,6,0,19,0,0,0,1,15,11,0,192,234,2,0,19,0,0,0,1,15,10,0,32,242,5,0,19,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,19,0,0,0,1,240,112,0,80,252,6,0,19,0,0,0,1,240,128,0,16,242,7,0,19,0,0,0,1,240,144,0,104,236,7,0,19,0,0,0,1,240,80,0,176,51,4,0,19,0,0,0,1,240,64,0,56,24,4,0,19,0,0,0,1,240,240,0,128,230,7,0,19,0,0,0,1,240,16,0,72,216,3,0,19,0,0,0,1,240,32,0,24,188,3,0,19,0,0,0,1,240,48,0,176,162,3,0,19,0,0,0,1,240,96,0,120,211,6,0,19,0,0,0,1,240,224,0,184,164,6,0,19,0,0,0,1,240,208,0,80,74,6,0,19,0,0,0,1,240,192,0,192,32,6,0,19,0,0,0,1,240,176,0,192,234,2,0,19,0,0,0,1,240,160,0,32,242,5,0,19,0,0,0,1,240,0,0,208,236,2,0,0,0,0,0,254,0,2,0,168,234,7,0,20,0,0,0,1,1,1,0,96,135,7,0,20,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,4,0,0,217,5,0,20,0,0,0,1,6,4,0,72,242,7,0,20,0,0,0,1,6,6,0,88,207,5,0,20,0,0,0,1,6,2,0,184,230,7,0,20,0,0,0,1,6,0,0,104,109,3,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,24,16,0,80,246,3,0,20,0,0,0,1,24,24,0,248,38,7,0,20,0,0,0,1,24,8,0,112,212,3,0,20,0,0,0,1,24,0,0,248,160,5,0,0,0,0,0,113,51,45,48,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,68,163,208,29,0,0,16,1,113,51,45,48,54,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,16,33,106,189,0,0,16,1,113,51,45,48,55,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,79,60,229,97,0,0,16,1,113,51,45,48,56,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,120,185,51,21,0,0,32,0,113,51,45,48,57,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,242,178,45,163,0,0,32,0,113,51,45,49,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,168,26,104,237,0,0,32,0,113,51,45,49,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,16,253,178,56,0,0,32,0,113,51,45,49,56,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,172,146,66,158,0,0,32,0,113,51,45,49,57,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,15,212,246,183,0,0,32,0,113,51,45,50,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,141,243,215,108,0,0,32,0,113,51,45,50,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,75,107,170,180,0,0,32,0,113,51,45,49,54,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,54,104,61,134,0,0,32,0,113,51,45,49,55,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,156,245,155,69,0,0,32,0,113,51,45,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,145,229,27,108,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,111,114,116,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,254,247,186,186,1,0,16,1,112,111,114,116,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,227,176,126,143,1,0,16,1,112,111,114,116,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,181,57,57,104,1,0,16,1,112,111,114,116,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,141,213,101,106,1,0,16,1,112,111,114,116,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,170,169,120,41,1,0,16,1,112,111,114,116,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,181,255,205,126,1,0,16,1,112,111,114,116,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,249,148,50,96,4,0,32,0,112,111,114,116,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,61,118,106,182,4,0,32,0])
.concat([109,109,105,54,51,51,49,46,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,135,125,12,106,7,0,32,0,13,0,0,0,255,255,0,0,0,0,0,0,14,0,0,0,255,255,0,0,0,0,0,0,15,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,112,110,105,106,95,51,54,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,43,251,79,45,1,0,16,1,112,110,105,106,95,52,50,46,49,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,175,223,133,192,1,0,16,1,112,110,105,106,95,48,57,46,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,10,123,23,72,4,0,32,0,112,110,105,106,95,48,49,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,17,243,160,1,4,0,32,0,112,110,105,106,95,49,51,46,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,176,81,100,64,4,0,32,0,112,110,105,106,95,48,53,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,192,93,81,140,4,0,32,0,112,110,105,106,95,50,54,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,30,152,175,226,4,0,32,0,112,110,105,106,95,49,56,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,86,14,122,241,4,0,32,0,112,110,105,106,95,51,56,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,140,189,117,235,4,0,32,0,112,110,105,106,95,51,50,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,239,11,86,132,4,0,32,0,112,110,105,106,95,49,48,46,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,113,193,172,194,4,0,32,0,112,110,105,106,95,48,50,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,51,252,33,14,4,0,32,0,112,110,105,106,95,49,52,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,25,155,229,127,4,0,32,0,112,110,105,106,95,48,54,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,227,191,244,121,4,0,32,0,112,110,105,106,95,50,55,46,55,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,14,203,213,131,4,0,32,0,112,110,105,106,95,49,57,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,48,178,8,175,4,0,32,0,112,110,105,106,95,51,57,46,57,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,121,229,251,112,4,0,32,0,112,110,105,106,95,51,51,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,128,198,210,62,4,0,32,0,112,110,105,106,95,49,55,46,49,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,122,120,111,232,3,0,16,0,112,110,105,106,95,50,52,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,125,37,146,80,5,0,64,0,112,110,105,106,95,50,53,46,49,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,170,154,16,34,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,112,107,98,49,48,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,0,0,0,0,0,0,24,105,111,98,49,46,49,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,105,111,99,49,46,105,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,129,32,24,13,0,0,0,8,99,54,51,50,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,112,146,189,15,0,0,0,8,19,0,0,0,255,255,0,0,0,0,0,0,20,0,0,0,255,255,3,0,0,0,0,0,21,0,0,0,255,255,32,0,0,0,0,0,0,0,0,0,254,0,8,0,32,4,2,0,19,0,0,0,1,7,7,0,80,252,6,0,19,0,0,0,1,7,6,0,16,242,7,0,19,0,0,0,1,7,5,0,104,236,7,0,19,0,0,0,1,7,0,0,128,230,7,0,19,0,0,0,1,7,1,0,184,164,6,0,19,0,0,0,1,7,2,0,80,74,6,0,19,0,0,0,1,7,3,0,192,32,6,0,19,0,0,0,1,7,4,0,32,242,5,0,0,0,0,0,254,0,2,0,88,160,1,0,19,0,0,0,1,8,0,0,192,255,2,0,19,0,0,0,1,8,8,0,208,75,4,0,0,0,0,0,254,0,8,0,72,202,5,0,20,0,0,0,1,7,0,0,72,198,6,0,20,0,0,0,1,7,1,0,208,75,4,0,20,0,0,0,1,7,2,0,8,49,4,0,20,0,0,0,1,7,3,0,72,195,6,0,20,0,0,0,1,7,4,0,72,246,3,0,20,0,0,0,1,7,5,0,72,0,3,0,20,0,0,0,1,7,6,0,64,47,7,0,20,0,0,0,1,7,7,0,48,173,6,0,0,0,0,0,254,0,4,0,16,138,1,0,20,0,0,0,1,192,0,0,104,136,1,0,20,0,0,0,1,192,64,0,168,135,1,0,20,0,0,0,1,192,128,0,0,135,1,0,20,0,0,0,1,192,192,0,248,132,1,0,0,0,0,0,254,0,2,0,72,4,1,0,21,0,0,0,1,8,0,0,96,135,7,0,21,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,2,0,120,207,1,0,21,0,0,0,1,16,0,0,96,135,7,0,21,0,0,0,1,16,16,0,152,182,7,0,0,0,0,0,254,0,2,0,40,111,8,0,21,0,0,0,1,32,0,0,96,135,7,0,21,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,168,79,2,0,21,0,0,0,1,128,0,0,32,182,8,0,21,0,0,0,1,128,128,0,80,251,6,0,0,0,0,0,0,0,0,0,32,0,0,0,64,0,0,0,96,0,0,0,128,0,0,0,160,0,0,0,192,0,0,0,224,0,0,0,0,0,0,0,4,0,0,0,8,0,0,0,12,0,0,0,16,0,0,0,20,0,0,0,24,0,0,0,28,0,0,0,112,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,228,176,197,64,1,0,16,1,112,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,98,151,95,5,1,0,16,1,112,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,4,221,115,48,1,0,16,1,112,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,37,245,170,68,1,0,16,1,112,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,43,81,222,250,1,0,16,1,112,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,47,130,178,90,1,0,16,1,103,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,58,162,3,149,4,0,32,0,103,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,254,195,223,10,4,0,32,0,103,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,73,248,97,62,4,0,32,0,103,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,235,233,48,113,4,0,32,0,99,111,108,111,117,114,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,87,80,164,87,7,0,32,0,11,0,0,0,255,255,0,0,0,0,0,0,12,0,0,0,255,255,0,0,0,0,0,0,13,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,128,129,4,0,12,0,0,0,1,64,0,0,8,49,4,0,12,0,0,0,1,64,64,0,152,21,4,0,0,0,0,0,254,0,2,0,200,30,2,0,12,0,0,0,1,128,0,0,120,97,1,0,12,0,0,0,1,128,128,0,96,19,1,0,0,0,0,0,254,0,2,0,64,37,5,0,13,0,0,0,1,1,0,0,176,116,6,0,13,0,0,0,1,1,1,0,80,110,6,0,0,0,0,0,254,0,4,0,32,4,2,0,13,0,0,0,1,2,2,0,144,147,2,0,13,0,0,0,1,2,0,0,200,209,1,0,0,0,0,0,254,0,2,0,72,202,5,0,13,0,0,0,1,4,0,0,80,246,3,0,13,0,0,0,1,4,4,0,112,212,3,0,112,99,102,106,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,62,164,29,104,1,0,16,1,112,99,102,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,150,76,49,244,1,0,16,1,112,99,102,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,85,86,33,1,0,16,1,112,99,102,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,234,19,111,234,1,0,16,1,112,99,102,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,234,213,198,90,1,0,16,1,112,99,102,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,185,42,215,34,5,0,32,0,112,99,102,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,60,129,164,22,5,0,32,0,112,99,102,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,53,224,151,16,5,0,32,0,112,99,102,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,116,216,98,211,5,0,32,0,112,99,102,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,124,137,131,3,5,0,32,0,112,99,102,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,132,16,249,118,5,0,32,0,112,99,102,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,84,55,108,117,5,0,32,0,112,99,102,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,125,39,201,158,5,0,32,0,112,99,102,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,51,95,78,37,10,0,16,1,112,99,102,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,249,244,2,105,10,0,16,1,112,99,102,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,5,160,222,165,12,0,64,0,112,99,102,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,254,53,226,76,12,0,64,0,101,112,114,45,49,50,48,49,55,46,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,34,3,25,49,1,0,16,1,101,112,114,45,49,50,48,49,54,46,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,166,100,159,73,1,0,16,1,101,112,114,45,49,49,55,52,56,46,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,171,108,167,130,1,0,16,1,101,112,114,45,49,49,55,52,55,46,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,229,236,150,151,1,0,16,1,101,112,114,45,49,49,57,48,53,46,56,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,129,246,28,9,0,16,1,101,112,114,45,49,49,57,48,52,46,56,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,129,54,153,187,9,0,16,1,101,112,114,45,49,50,48,49,57,97,46,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,48,138,24,17,17,0,16,1,101,112,114,45,49,50,48,49,56,97,46,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,31,46,88,28,17,0,16,1,101,112,114,45,49,49,55,57,49,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,10,145,178,54,3,0,32,0,101,112,114,45,49,49,55,56,57,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,43,141,111,184,3,0,32,0,101,112,114,45,49,49,55,57,50,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,110,175,92,200,3,0,32,0,101,112,114,45,49,49,55,57,48,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,102,78,86,42,3,0,32,0,101,112,114,45,49,49,55,53,55,46,54,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,120,196,109,228,18,0,32,0,101,112,114,45,49,49,55,53,56,46,55,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,135,92,67,91,18,0,32,0,101,112,114,45,49,49,55,55,51,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,88,87,93,27,18,0,32,0,101,112,114,45,49,49,55,55,52,46,55,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,112,193,160,44,18,0,32,0,101,112,114,45,49,49,55,53,57,46,56,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,246,17,129,172,18,0,32,0,101,112,114,45,49,49,55,54,48,46,49,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,249,42,40,145,18,0,32,0,101,112,114,45,49,49,55,55,53,46,56,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,147,87,34,72,18,0,32,0,101,112,114,45,49,49,55,55,54,46,49,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,152,97,196,120,18,0,32,0,101,112,114,45,49,49,55,54,49,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,101,208,165,186,18,0,32,0,101,112,114,45,49,49,55,54,50,46,55,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,165,247,26,29,18,0,32,0,101,112,114,45,49,49,55,55,55,46,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,50,221,98,150,18,0,32,0,101,112,114,45,49,49,55,55,56,46,55,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,148,116,251,45,18,0,32,0,101,112,114,45,49,49,55,54,51,46,56,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,7,52,226,30,18,0,32,0,101,112,114,45,49,49,55,54,52,46,49,49,51,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,94,48,89,232,18,0,32,0,101,112,114,45,49,49,55,55,57,46,56,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,147,215,156,164,18,0,32,0,101,112,114,45,49,49,55,56,48,46,49,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,129,237,20,213,18,0,32,0,101,112,114,45,49,49,55,54,53,46,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,255,45,158,100,18,0,32,0,101,112,114,45,49,49,55,54,54,46,55,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,252,183,47,217,18,0,32,0,101,112,114,45,49,49,55,56,49,46,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,205,212,146,150,18,0,32,0,101,112,114,45,49,49,55,56,50,46,54,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,67,187,19,201,18,0,32,0,101,112,114,45,49,49,55,54,55,46,56,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,84,208,138,31,18,0,32,0,101,112,114,45,49,49,55,54,56,46,49,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,83,64,44,219,18,0,32,0,101,112,114,45,49,49,55,56,51,46,56,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,7,144,24,109,18,0,32,0,101,112,114,45,49,49,55,56,52,46,49,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,100,253,245,87,18,0,32,0,101,112,114,45,49,49,55,54,57,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,81,171,240,40,18,0,32,0,101,112,114,45,49,49,55,55,48,46,55,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,169,126,85,215,18,0,32,0,101,112,114,45,49,49,55,56,53,46,54,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,196,50,239,230,18,0,32,0,101,112,114,45,49,49,55,56,54,46,54,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,157,180,102,32,18,0,32,0,101,112,114,45,49,49,55,55,49,46,56,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,24,86,99,103,18,0,32,0,101,112,114,45,49,49,55,55,50,46,49,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,58,141,121,15,18,0,32,0,101,112,114,45,49,49,55,56,55,46,55,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,18,220,49,230,18,0,32,0,101,112,114,45,49,49,55,56,56,46,49,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,110,198,100,132,18,0,32,0,101,112,114,45,49,49,56,57,57,46,49,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,137,168,159,237,4,0,16,1,109,112,114,45,49,49,55,53,52,46,49,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,132,132,235,235,11,0,64,0,101,112,114,45,49,49,55,53,54,46,49,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,138,63,228,18,11,0,64,0,101,112,114,45,49,49,55,53,53,46,49,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,68,18,219,194,11,0,64,0,101,112,114,45,49,49,56,57,53,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,253,166,153,238,16,0,0,8,101,112,114,45,49,49,56,57,54,46,105,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,21,192,235,75,16,0,0,8,101,112,114,45,49,49,56,57,55,46,105,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,149,203,99,68,16,0,0,8,101,112,114,45,49,49,56,57,56,46,105,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,103,215,25,93,16,0,0,8,10,0,0,0,255,255,234,0,0,0,0,0,11,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,3,0,200,30,2,0,10,0,0,0,1,3,3,0,120,247,1,0,10,0,0,0,1,3,2,0,248,133,8,0,10,0,0,0,1,3,1,0,96,128,8,0,0,0,0,0,254,0,2,0,168,234,7,0,10,0,0,0,1,4,4,0,96,135,7,0,10,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,4,0,56,154,6,0,10,0,0,0,1,8,8,0,184,30,3,0,10,0,0,0,1,8,24,0,0,28,3,0,10,0,0,0,1,8,0,0,64,104,8,0,10,0,0,0,1,8,16,0,144,188,3,0,0,0,0,0,254,0,2,0,104,159,3,0,10,0,0,0,1,32,0,0,56,111,3,0,10,0,0,0,1,32,32,0,104,134,3,0,0,0,0,0,254,0,4,0,72,202,5,0,10,0,0,0,1,192,128,0,80,246,3,0,10,0,0,0,1,192,192,0,248,38,7,0,10,0,0,0,1,192,64,0,112,212,3,0,10,0,0,0,1,192,0,0,248,160,5,0,0,0,0,0,254,0,16,0,200,87,7,0,11,0,0,0,1,15,7,0,80,252,6,0,11,0,0,0,1,15,8,0,16,242,7,0,11,0,0,0,1,15,9,0,104,236,7,0,11,0,0,0,1,15,5,0,176,51,4,0,11,0,0,0,1,15,4,0,56,24,4,0,11,0,0,0,1,15,15,0,128,230,7,0,11,0,0,0,1,15,1,0,72,216,3,0,11,0,0,0,1,15,2,0,24,188,3,0,11,0,0,0,1,15,3,0,176,162,3,0,11,0,0,0,1,15,6,0,120,211,6,0,11,0,0,0,1,15,14,0,184,164,6,0,11,0,0,0,1,15,13,0,80,74,6,0,11,0,0,0,1,15,12,0,192,32,6,0,11,0,0,0,1,15,11,0,192,234,2,0,11,0,0,0,1,15,10,0,32,242,5,0,11,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,11,0,0,0,1,240,112,0,80,252,6,0,11,0,0,0,1,240,128,0,16,242,7,0,11,0,0,0,1,240,144,0,104,236,7,0,11,0,0,0,1,240,80,0,176,51,4,0,11,0,0,0,1,240,64,0,56,24,4,0,11,0,0,0,1,240,240,0,128,230,7,0,11,0,0,0,1,240,16,0,72,216,3,0,11,0,0,0,1,240,32,0,24,188,3,0,11,0,0,0,1,240,48,0,176,162,3,0,11,0,0,0,1,240,96,0,120,211,6,0,11,0,0,0,1,240,224,0,184,164,6,0,11,0,0,0,1,240,208,0,80,74,6,0,11,0,0,0,1,240,192,0,192,32,6,0,11,0,0,0,1,240,176,0,192,234,2,0,11,0,0,0,1,240,160,0,32,242,5,0,11,0,0,0,1,240,0,0,208,236,2,0,168,86,7,0,1,0,0,0,232,252,146,0,248,191,2,0,24,38,7,0,1,0,0,0,233,252,146,0,184,160,2,0,56,210,6,0,1,0,0,0,236,252,146,0,192,135,2,0,24,163,6,0,1,0,0,0,237,252,146,0,240,108,2,0,152,122,6,0,1,0,0,0,238,252,146,0,96,82,2,0,192,72,6,0,1,0,0,0,239,252,146,0,32,56,2,0,200,110,3,0,1,0,0,0,234,252,146,0,152,30,2,0,120,89,3,0,1,0,0,0,235,252,146,0,232,10,2,0,40,246,1,0,1,0,0,0,240,252,146,0,64,246,1,0,144,236,1,0,1,0,0,0,241,252,146,0,136,224,1,0,176,223,1,0,1,0,0,0,244,252,146,0,72,198,1,0,192,209,1,0,1,0,0,0,245,252,146,0,24,182,1,0,24,198,1,0,1,0,0,0,246,252,146,0,40,167,1,0,120,189,1,0,1,0,0,0,247,252,146,0,200,149,1,0,224,22,1,0,1,0,0,0,242,252,146,0,56,126,1,0,160,14,1,0,1,0,0,0,243,252,146,0,32,101,1,0,88,212,3,0,1,0,0,0,72,217,146,0,40,185,3,0,72,65,1,0,9,0,0,0,96,4,147,0,32,58,1,0,48,50,1,0,9,0,0,0,97,4,147,0,32,58,1,0,50,55,99,53,49,50,46,49,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,62,69,154,54,0,0,16,1,50,55,99,48,50,48,46,49,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,177,36,127,94,0,0,16,1,112,97,110,103,95,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,245,131,88,58,0,0,32,0,98,98,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,8,237,168,121,0,0,32,0,112,97,110,103,95,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,174,22,106,22,0,0,32,0,98,98,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,108,219,179,47,0,0,32,0,98,98,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,110,79,186,253,0,0,32,0,98,98,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,99,122,244,57,0,0,32,0,98,98,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,142,91,46,197,0,0,64,0,184,40,2,0,1,0,0,0,231,233,148,0,248,191,2,0,56,250,6,0,1,0,0,0,227,233,148,0,184,160,2,0,88,149,7,0,1,0,0,0,225,233,148,0,136,224,1,0,56,210,6,0,1,0,0,0,39,233,148,0,192,135,2,0,24,163,6,0,1,0,0,0,38,233,148,0,240,108,2,0,152,122,6,0,1,0,0,0,37,233,148,0,96,82,2,0,192,72,6,0,1,0,0,0,36,233,148,0,32,56,2,0,48,123,2,0,1,0,0,0,35,233,148,0,152,30,2,0,96,69,2,0,1,0,0,0,34,233,148,0,232,10,2,0,176,223,1,0,1,0,0,0,111,232,148,0,72,198,1,0,192,209,1,0,1,0,0,0,110,232,148,0,24,182,1,0,24,198,1,0,1,0,0,0,109,232,148,0,40,167,1,0,120,189,1,0,1,0,0,0,108,232,148,0,200,149,1,0,248,187,8,0,1,0,0,0,107,232,148,0,56,126,1,0,184,179,8,0,1,0,0,0,106,232,148,0,32,101,1,0,88,212,3,0,1,0,0,0,80,219,146,0,40,185,3,0,16,17,8,0,1,0,0,0,230,233,148,0,224,12,8,0,32,77,1,0,1,0,0,0,25,232,148,0,216,70,1,0,112,97,51,106,95,49,55,46,49,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,31,229,246,33,2,0,16,1,112,97,51,106,95,49,54,46,49,48,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,151,120,29,202,2,0,16,1,112,97,51,45,48,49,109,46,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,44,21,138,6,4,0,32,0,112,97,51,45,48,55,109,46,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,157,97,74,58,4,0,32,0,112,97,51,95,49,49,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,162,35,20,203,3,0,16,0,112,97,51,95,48,53,46,49,48,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,93,13,161,115,5,0,64,0,112,97,51,95,48,54,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,130,79,250,175,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,99,112,49,98,49,102,46,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,227,184,121,57,0,0,0,8,99,112,49,98,56,107,46,56,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,122,234,82,138,0,0,0,8,99,112,49,98,57,107,46,57,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,195,189,84,167,0,0,0,8,105,111,99,49,46,105,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,129,32,24,13,0,0,0,8,99,54,51,50,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,112,146,189,15,0,0,0,8,112,97,51,119,95,49,55,46,49,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,52,130,19,18,2,0,16,1,112,97,51,119,95,49,54,46,49,48,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,92,88,186,209,2,0,16,1,112,97,51,45,48,49,109,46,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,44,21,138,6,4,0,32,0,112,97,51,45,48,55,109,46,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,157,97,74,58,4,0,32,0,112,97,51,95,49,49,40,95,95,112,97,110,103,51,98,41,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,70,140,160,144,3,0,16,0,112,97,51,95,48,53,46,49,48,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,93,13,161,115,5,0,64,0,112,97,51,95,48,54,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,130,79,250,175,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,99,112,49,98,49,102,46,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,227,184,121,57,0,0,0,8,99,112,49,98,56,107,46,56,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,122,234,82,138,0,0,0,8,99,112,49,98,57,107,46,57,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,195,189,84,167,0,0,0,8,105,111,99,49,46,105,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,129,32,24,13,0,0,0,8,99,54,51,50,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,112,146,189,15,0,0,0,8,101,112,114,45,49,48,51,56,48,98,46,49,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,173,173,108,31,1,0,16,1,101,112,114,45,49,48,51,56,50,98,46,49,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,26,250,195,196,1,0,16,1,101,112,114,45,49,48,51,56,49,98,46,49,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,43,65,140,190,1,0,16,1,101,112,114,45,49,48,51,56,51,98,46,49,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,74,1,162,16,1,0,16,1,101,112,114,45,49,48,51,50,55,97,46,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,175,91,138,226,9,0,16,1,101,112,114,45,49,48,51,50,57,97,46,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,129,28,19,218,9,0,16,1,101,112,114,45,49,48,51,50,56,97,46,55,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,93,94,236,213,9,0,16,1,101,112,114,45,49,48,51,51,48,97,46,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,42,200,158,186,9,0,16,1,111,112,114,45,49,48,50,54,56,46,57,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,4,75,52,149,2,0,32,0,111,112,114,45,49,48,50,51,50,46,49,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,235,161,107,119,2,0,32,0,111,112,114,45,49,48,50,54,55,46,49,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,35,184,91,168,2,0,32,0,111,112,114,45,49,48,50,51,49,46,49,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,191,188,8,137,2,0,32,0,111,112,114,45,49,48,50,54,54,46,49,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,116,26,111,159,2,0,32,0,111,112,114,45,49,48,50,51,48,46,49,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,80,94,111,104,2,0,32,0,109,112,114,45,49,48,51,55,49,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,8,98,200,124,3,0,32,0,109,112,114,45,49,48,51,55,51,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,201,106,210,176,3,0,32,0,109,112,114,45,49,48,51,55,53,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,215,11,182,89,3,0,32,0,109,112,114,45,49,48,51,55,55,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,74,176,161,23,3,0,32,0,109,112,114,45,49,48,51,55,50,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,140,7,87,181,3,0,32,0,109,112,114,45,49,48,51,55,52,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,23,229,81,128,3,0,32,0,109,112,114,45,49,48,51,55,54,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,24,243,184,243,3,0,32,0,109,112,114,45,49,48,51,55,56,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,132,41,6,161,3,0,32,0,111,112,114,45,49,48,49,56,54,46,52,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,38,68,121,34,10,0,32,0,111,112,114,45,49,48,49,56,53,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,38,68,121,34,10,0,32,0,101,112,114,45,49,48,49,56,55,46,56,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,169,186,10,161,4,0,16,1,111,112,114,45,49,48,49,57,51,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,222,13,209,188,11,0,64,0,111,112,114,45,49,48,49,57,50,46,54,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,112,18,15,119,11,0,64,0,111,112,114,45,49,48,49,57,49,46,54,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,171,132,162,32,11,0,64,0,111,112,114,45,49,48,49,57,48,46,54,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,226,112,171,124,11,0,64,0,111,112,114,45,49,48,49,56,57,46,55,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,84,107,54,1,11,0,64,0,111,112,114,45,49,48,49,56,56,46,55,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,217,10,211,186,11,0,64,0,10,0,0,0,255,255,255,0,0,0,0,0,11,0,0,0,255,255,249,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,10,0,0,0,1,15,7,0,80,252,6,0,10,0,0,0,1,15,8,0,16,242,7,0,10,0,0,0,1,15,9,0,104,236,7,0,10,0,0,0,1,15,5,0,176,51,4,0,10,0,0,0,1,15,4,0,56,24,4,0,10,0,0,0,1,15,15,0,128,230,7,0,10,0,0,0,1,15,1,0,72,216,3,0,10,0,0,0,1,15,2,0,24,188,3,0,10,0,0,0,1,15,3,0,176,162,3,0,10,0,0,0,1,15,6,0,120,211,6,0,10,0,0,0,1,15,14,0,184,164,6,0,10,0,0,0,1,15,13,0,80,74,6,0,10,0,0,0,1,15,12,0,192,32,6,0,10,0,0,0,1,15,11,0,192,234,2,0,10,0,0,0,1,15,10,0,32,242,5,0,10,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,10,0,0,0,1,240,112,0,80,252,6,0,10,0,0,0,1,240,128,0,16,242,7,0,10,0,0,0,1,240,144,0,104,236,7,0,10,0,0,0,1,240,80,0,176,51,4,0,10,0,0,0,1,240,64,0,56,24,4,0,10,0,0,0,1,240,240,0,128,230,7,0,10,0,0,0,1,240,16,0,72,216,3,0,10,0,0,0,1,240,32,0,24,188,3,0,10,0,0,0,1,240,48,0,176,162,3,0,10,0,0,0,1,240,96,0,120,211,6,0,10,0,0,0,1,240,224,0,184,164,6,0,10,0,0,0,1,240,208,0,80,74,6,0,10,0,0,0,1,240,192,0,192,32,6,0,10,0,0,0,1,240,176,0,192,234,2,0,10,0,0,0,1,240,160,0,32,242,5,0,10,0,0,0,1,240,0,0,208,236,2,0,0,0,0,0,254,0,3,0,200,30,2,0,11,0,0,0,1,3,3,0,120,247,1,0,11,0,0,0,1,3,2,0,192,231,8,0,11,0,0,0,1,3,1,0,104,211,1,0,0,0,0,0,254,0,2,0,168,234,7,0,11,0,0,0,1,4,4,0,96,135,7,0,11,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,4,0,40,252,8,0,11,0,0,0,1,48,32,0,80,246,3,0,11,0,0,0,1,48,48,0,248,38,7,0,11,0,0,0,1,48,16,0,112,212,3,0,11,0,0,0,1,48,0,0,248,160,5,0,0,0,0,0,254,0,4,0,72,202,5,0,11,0,0,0,1,192,128,0,80,246,3,0,11,0,0,0,1,192,192,0,248,38,7,0,11,0,0,0,1,192,64,0,112,212,3,0,11,0,0,0,1,192,0,0,248,160,5,0,0,0,0,0,19,0,0,0,255,255,127,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,200,87,7,0,19,0,0,0,1,3,3,0,96,240,7,0,19,0,0,0,1,3,2,0,128,188,7,0,19,0,0,0,1,3,1,0,184,46,7,0,19,0,0,0,1,3,0,0,248,140,7,0,0,0,0,0,254,0,4,0,160,123,6,0,19,0,0,0,1,12,0,0,184,220,8,0,19,0,0,0,1,12,4,0,88,154,8,0,19,0,0,0,1,12,8,0,200,92,8,0,19,0,0,0,1,12,12,0,56,37,8,0,0,0,0,0,254,0,2,0,136,132,7,0,19,0,0,0,1,16,16,0,96,135,7,0,19,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,32,0,0,96,135,7,0,19,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,64,64,0,96,135,7,0,19,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,200,30,2,0,19,0,0,0,1,128,0,0,120,97,1,0,19,0,0,0,1,128,128,0,96,19,1,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,3,1,0,192,255,2,0,20,0,0,0,1,3,3,0,8,49,4,0,20,0,0,0,1,3,2,0,72,246,3,0,20,0,0,0,1,3,0,0,48,176,2,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,12,4,0,80,246,3,0,20,0,0,0,1,12,12,0,248,38,7,0,20,0,0,0,1,12,8,0,112,212,3,0,20,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,4,0,64,37,5,0,20,0,0,0,1,48,48,0,240,128,7,0,20,0,0,0,1,48,32,0,24,136,4,0,20,0,0,0,1,48,16,0,216,122,7,0,20,0,0,0,1,48,0,0,176,147,2,0,0,0,0,0,254,0,2,0,88,226,7,0,20,0,0,0,1,64,64,0,96,135,7,0,20,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,20,0,0,0,1,128,0,0,56,111,3,0,20,0,0,0,1,128,128,0,104,134,3,0,0,0,0,0,168,86,7,0,1,0,0,0,136,239,146,0,248,191,2,0,24,38,7,0,1,0,0,0,223,254,146,0,184,160,2,0,56,210,6,0,1,0,0,0,218,254,146,0,192,135,2,0,24,163,6,0,1,0,0,0,219,254,146,0,240,108,2,0,152,122,6,0,1,0,0,0,216,254,146,0,96,82,2,0,192,72,6,0,1,0,0,0,217,254,146,0,32,56,2,0,200,110,3,0,1,0,0,0,220,254,146,0,152,30,2,0,40,246,1,0,1,0,0,0,137,239,146,0,64,246,1,0,144,236,1,0,1,0,0,0,127,246,146,0,136,224,1,0,176,223,1,0,1,0,0,0,122,246,146,0,72,198,1,0,192,209,1,0,1,0,0,0,123,246,146,0,24,182,1,0,24,198,1,0,1,0,0,0,120,246,146,0,40,167,1,0,120,189,1,0,1,0,0,0,121,246,146,0,200,149,1,0,224,22,1,0,1,0,0,0,124,246,146,0,56,126,1,0,88,212,3,0,1,0,0,0,160,218,146,0,40,185,3,0,16,17,8,0,1,0,0,0,138,239,146,0,224,12,8,0,72,65,1,0,9,0,0,0,48,5,147,0,32,58,1,0,48,50,1,0,9,0,0,0,49,5,147,0,32,58,1,0,224,41,1,0,9,0,0,0,50,5,147,0,32,58,1,0,98,50,48,45,48,53,45,48,50,46,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,58,254,251,63,2,0,16,1,98,50,48,45,48,51,45,48,50,46,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,165,216,171,253,2,0,16,1,98,50,48,45,48,52,46,51,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,56,72,107,33,2,0,16,1,98,50,48,45,50,48,46,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,26,67,68,210,2,0,16,1,98,50,48,45,48,55,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,227,172,199,69,9,0,16,1,98,50,48,45,49,51,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,177,218,172,246,11,0,32,0,98,50,48,45,49,52,46,55,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,229,137,248,137,15,0,32,0,98,50,48,45,48,56,46,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,100,156,225,243,26,0,64,0,10,0,0,0,255,255,255,0,0,0,0,0,11,0,0,0,255,255,127,0,0,0,0,0,0,0,0,0,254,0,2,0,104,159,3,0,10,0,0,0,1,2,2,0,96,135,7,0,10,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,10,0,0,0,1,4,4,0,96,135,7,0,10,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,10,0,0,0,1,8,0,0,96,135,7,0,10,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,10,0,0,0,1,48,0,0,80,252,6,0,10,0,0,0,1,48,16,0,16,242,7,0,10,0,0,0,1,48,32,0,104,236,7,0,10,0,0,0,1,48,48,0,128,230,7,0,0,0,0,0,254,0,4,0,160,123,6,0,10,0,0,0,1,192,192,0,8,201,6,0,10,0,0,0,1,192,128,0,200,197,6,0,10,0,0,0,1,192,64,0,152,194,6,0,10,0,0,0,1,192,0,0,248,189,6,0,0,0,0,0,254,0,4,0,72,202,5,0,11,0,0,0,1,3,2,0,80,246,3,0,11,0,0,0,1,3,3,0,80,124,6,0,11,0,0,0,1,3,1,0,112,212,3,0,11,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,144,52,7,0,11,0,0,0,1,12,0,0,152,21,4,0,11,0,0,0,1,12,4,0,72,246,3,0,11,0,0,0,1,12,12,0,72,0,3,0,11,0,0,0,1,12,8,0,64,47,7,0,0,0,0,0,254,0,2,0,128,112,3,0,11,0,0,0,1,128,128,0,224,247,3,0,11,0,0,0,1,128,0,0,168,22,4,0,118,112,104,117,46,48,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,89,163,214,133,1,0,16,1,118,112,104,117,46,48,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,119,206,127,203,1,0,16,1,118,112,104,117,46,48,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,186,43,143,224,1,0,16,1,118,112,104,117,46,48,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,219,76,192,8,1,0,16,1,118,112,104,117,46,48,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,25,171,165,181,1,0,16,1,118,112,104,117,46,48,56,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,251,32,187,81,1,0,16,1,118,112,104,117,46,48,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,5,66,166,65,1,0,16,1,118,112,104,117,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,174,67,29,43,1,0,16,1,118,112,104,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,153,175,27,197,5,0,32,0,118,112,104,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,119,60,232,60,5,0,32,0,118,112,104,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,224,8,36,79,5,0,32,0,118,112,104,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,80,2,246,159,5,0,32,0,118,112,104,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,221,26,14,122,5,0,32,0,118,112,104,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,117,202,65,47,5,0,32,0,118,112,104,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,237,142,73,100,5,0,32,0,118,112,104,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,63,67,242,23,5,0,32,0,118,112,104,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,172,220,69,80,10,0,16,1,118,112,104,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,89,14,182,134,10,0,16,1,118,112,104,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,51,125,131,225,12,0,64,0,118,112,104,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,144,205,211,251,12,0,64,0,118,112,104,104,46,48,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,190,199,41,96,1,0,16,1,118,112,104,104,46,48,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,238,37,102,210,1,0,16,1,118,112,104,104,46,48,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,138,11,238,115,1,0,16,1,118,112,104,104,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,10,165,179,165,1,0,16,1,118,112,104,104,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,193,189,194,95,1,0,16,1,118,112,104,104,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,217,136,85,230,1,0,16,1,118,112,104,104,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,99,109,206,162,1,0,16,1,118,112,104,104,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,185,244,244,226,1,0,16,1,118,112,104,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,153,175,27,197,5,0,32,0,118,112,104,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,119,60,232,60,5,0,32,0,118,112,104,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,224,8,36,79,5,0,32,0,118,112,104,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,80,2,246,159,5,0,32,0,118,112,104,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,221,26,14,122,5,0,32,0,118,112,104,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,117,202,65,47,5,0,32,0,118,112,104,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,237,142,73,100,5,0,32,0,118,112,104,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,63,67,242,23,5,0,32,0,118,112,104,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,172,220,69,80,10,0,16,1,118,112,104,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,89,14,182,134,10,0,16,1,118,112,104,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,51,125,131,225,12,0,64,0,118,112,104,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,144,205,211,251,12,0,64,0,118,112,104,98,46,48,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,63,109,66,58,1,0,16,1,118,112,104,98,46,48,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,47,187,196,81,1,0,16,1,118,112,104,98,46,48,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,151,217,68,172,1,0,16,1,118,112,104,98,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,254,165,114,80,1,0,16,1,118,112,104,98,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,146,81,53,155,1,0,16,1,118,112,104,98,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,132,15,34,66,1,0,16,1,118,112,104,98,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,93,1,158,2,1,0,16,1,118,112,104,98,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,55,206,179,55,1,0,16,1,118,112,104,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,153,175,27,197,5,0,32,0,118,112,104,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,119,60,232,60,5,0,32,0,118,112,104,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,224,8,36,79,5,0,32,0,118,112,104,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,80,2,246,159,5,0,32,0,118,112,104,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,221,26,14,122,5,0,32,0,118,112,104,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,117,202,65,47,5,0,32,0,118,112,104,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,237,142,73,100,5,0,32,0,118,112,104,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,63,67,242,23,5,0,32,0,118,112,104,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,172,220,69,80,10,0,16,1,118,112,104,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,89,14,182,134,10,0,16,1,118,112,104,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,51,125,131,225,12,0,64,0,118,112,104,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,144,205,211,251,12,0,64,0,118,112,104,97,46,48,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,214,205,112,10,1,0,16,1,118,112,104,97,46,48,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,228,98,206,112,1,0,16,1,118,112,104,97,46,48,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,63,160,146,86,1,0,16,1,118,112,104,97,46,48,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,102,254,16,184,1,0,16,1,118,112,104,97,46,48,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,243,100,226,27,1,0,16,1,118,112,104,97,46,48,56,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,237,241,134,1,0,16,1,118,112,104,97,46,48,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,10,189,150,126,1,0,16,1,118,112,104,97,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,253,226,188,88,1,0,16,1,118,112,104,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,153,175,27,197,5,0,32,0,118,112,104,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,119,60,232,60,5,0,32,0,118,112,104,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,224,8,36,79,5,0,32,0,118,112,104,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,80,2,246,159,5,0,32,0,118,112,104,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,221,26,14,122,5,0,32,0,118,112,104,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,117,202,65,47,5,0,32,0,118,112,104,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,237,142,73,100,5,0,32,0,118,112,104,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,63,67,242,23,5,0,32,0,118,112,104,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,172,220,69,80,10,0,16,1,118,112,104,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,89,14,182,134,10,0,16,1,118,112,104,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,51,125,131,225,12,0,64,0,118,112,104,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,144,205,211,251,12,0,64,0,168,86,7,0,1,0,0,0,96,254,146,0,248,191,2,0,24,38,7,0,1,0,0,0,95,254,146,0,184,160,2,0,56,210,6,0,1,0,0,0,88,254,146,0,192,135,2,0,24,163,6,0,1,0,0,0,89,254,146,0,240,108,2,0,152,122,6,0,1,0,0,0,90,254,146,0,96,82,2,0,192,72,6,0,1,0,0,0,91,254,146,0,32,56,2,0,200,110,3,0,1,0,0,0,92,254,146,0,152,30,2,0,40,246,1,0,1,0,0,0,16,246,146,0,64,246,1,0,144,236,1,0,1,0,0,0,15,246,146,0,136,224,1,0,176,223,1,0,1,0,0,0,8,246,146,0,72,198,1,0,192,209,1,0,1,0,0,0,9,246,146,0,24,182,1,0,24,198,1,0,1,0,0,0,10,246,146,0,40,167,1,0,120,189,1,0,1,0,0,0,11,246,146,0,200,149,1,0,224,22,1,0,1,0,0,0,12,246,146,0,56,126,1,0,88,212,3,0,1,0,0,0,64,218,146,0,40,185,3,0,16,17,8,0,1,0,0,0,17,246,146,0,224,12,8,0,72,65,1,0,9,0,0,0,248,4,147,0,32,58,1,0,48,50,1,0,9,0,0,0,249,4,147,0,32,58,1,0,184,40,2,0,1,0,0,0,152,244,146,0,248,191,2,0,184,164,8,0,1,0,0,0,153,244,146,0,64,246,1,0,24,38,7,0,1,0,0,0,191,238,146,0,184,160,2,0,56,210,6,0,1,0,0,0,184,238,146,0,192,135,2,0,24,163,6,0,1,0,0,0,185,238,146,0,240,108,2,0,152,122,6,0,1,0,0,0,186,238,146,0,96,82,2,0,192,72,6,0,1,0,0,0,187,238,146,0,32,56,2,0,200,110,3,0,1,0,0,0,188,238,146,0,152,30,2,0,120,89,3,0,1,0,0,0,189,238,146,0,232,10,2,0,120,74,3,0,1,0,0,0,190,238,146,0,152,138,8,0,144,236,1,0,1,0,0,0,199,238,146,0,136,224,1,0,176,223,1,0,1,0,0,0,192,238,146,0,72,198,1,0,192,209,1,0,1,0,0,0,193,238,146,0,24,182,1,0,24,198,1,0,1,0,0,0,194,238,146,0,40,167,1,0,120,189,1,0,1,0,0,0,195,238,146,0,200,149,1,0,224,22,1,0,1,0,0,0,196,238,146,0,56,126,1,0,160,14,1,0,1,0,0,0,197,238,146,0,32,101,1,0,176,9,1,0,1,0,0,0,198,238,146,0,96,32,8,0,88,212,3,0,1,0,0,0,64,217,146,0,40,185,3,0,248,5,8,0,9,0,0,0,88,4,147,0,32,58,1,0,144,250,7,0,9,0,0,0,89,4,147,0,32,58,1,0,98,51,49,95,52,53,46,51,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,195,2,121,16,2,0,16,1,98,51,49,95,52,55,46,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,30,107,83,189,2,0,16,1,98,51,49,95,50,57,46,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,55,26,148,242,2,0,16,1,98,51,49,95,50,55,46,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,66,246,63,47,2,0,16,1,98,51,49,95,52,49,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,138,242,174,13,2,0,16,1,98,51,49,95,51,57,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,60,124,25,233,2,0,16,1,98,51,49,95,52,48,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,78,242,224,44,2,0,16,1,98,51,49,95,51,56,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,153,205,104,188,2,0,16,1,98,51,49,95,51,51,46,56,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,68,175,233,108,6,0,16,1,98,51,49,95,51,54,46,57,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,212,176,32,186,6,0,16,1,98,51,49,95,51,50,46,56,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,236,95,2,230,6,0,16,1,98,51,49,95,51,53,46,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,159,168,217,112,6,0,16,1,98,51,49,95,51,49,46,56,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,226,71,127,131,6,0,16,1,98,51,49,95,51,52,46,57,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,42,251,181,214,6,0,16,1,98,51,49,95,51,55,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,157,121,165,12,9,0,16,1,98,51,49,45,48,49,46,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,167,55,130,142,11,0,32,0,98,51,49,45,48,50,46,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,51,78,59,76,11,0,32,0,98,51,49,45,48,55,46,49,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,219,140,86,51,15,0,32,0,98,51,49,45,48,54,46,49,55,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,158,67,89,13,15,0,32,0,98,51,49,45,48,53,46,49,55,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,251,201,31,10,15,0,32,0,98,51,49,45,48,52,46,49,55,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,76,30,46,15,0,32,0,98,51,49,45,48,57,46,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,130,51,167,96,24,0,64,0,98,51,49,45,49,48,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,239,74,67,198,24,0,64,0,98,51,49,45,49,49,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,212,49,165,141,24,0,64,0,98,51,49,45,48,56,46,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,125,248,161,160,25,0,64,0,98,51,49,45,50,53,46,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,72,186,180,160,0,0,0,8,98,51,49,45,50,54,46,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,21,254,229,19,0,0,0,8,20,0,0,0,255,255,255,0,0,0,0,0,21,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,104,159,3,0,20,0,0,0,1,1,0,0,96,135,7,0,20,0,0,0,1,1,1,0,152,182,7,0,0,0,0,0,254,0,2,0,96,19,7,0,20,0,0,0,1,2,2,0,248,38,7,0,20,0,0,0,1,2,0,0,176,64,8,0,0,0,0,0,254,0,2,0,232,75,4,0,20,0,0,0,1,4,4,0,96,135,7,0,20,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,20,0,0,0,1,8,0,0,96,135,7,0,20,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,20,0,0,0,1,48,16,0,104,236,7,0,20,0,0,0,1,48,48,0,128,230,7,0,20,0,0,0,1,48,0,0,120,211,6,0,20,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,20,0,0,0,1,192,64,0,104,236,7,0,20,0,0,0,1,192,192,0,128,230,7,0,20,0,0,0,1,192,0,0,120,211,6,0,20,0,0,0,1,192,128,0,184,164,6,0,0,0,0,0,254,0,4,0,72,202,5,0,21,0,0,0,1,3,2,0,80,246,3,0,21,0,0,0,1,3,3,0,80,124,6,0,21,0,0,0,1,3,1,0,112,212,3,0,21,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,99,56,53,45,49,48,120,46,105,99,53,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,116,110,126,186,2,0,16,1,99,56,53,45,49,51,120,46,105,99,52,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,162,203,194,10,2,0,16,1,99,56,53,45,48,55,46,105,99,52,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,10,253,204,62,2,0,16,1,99,56,53,45,48,54,46,105,99,52,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,209,222,38,209,2,0,16,1,99,56,53,45,49,52,46,105,99,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,81,42,165,242,9,0,16,1,99,56,53,45,48,51,46,105,99,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,185,199,76,11,0,32,0,99,56,53,45,48,49,46,105,99,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,124,151,17,167,15,0,32,0,99,56,53,45,48,50,46,105,99,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,61,15,173,166,15,0,32,0,99,56,53,45,48,52,46,105,99,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,126,116,251,90,24,0,64,0,99,56,53,45,48,53,46,105,99,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,208,14,27,60,25,0,64,0,36,0,0,0,255,255,255,0,0,0,0,0,37,0,0,0,255,255,223,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,36,0,0,0,1,2,2,0,96,135,7,0,36,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,36,0,0,0,1,4,4,0,96,135,7,0,36,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,36,0,0,0,1,8,0,0,96,135,7,0,36,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,36,0,0,0,1,48,0,0,80,252,6,0,36,0,0,0,1,48,16,0,16,242,7,0,36,0,0,0,1,48,32,0,104,236,7,0,36,0,0,0,1,48,48,0,128,230,7,0,0,0,0,0,254,0,4,0,160,123,6,0,36,0,0,0,1,192,192,0,8,201,6,0,36,0,0,0,1,192,128,0,200,197,6,0,36,0,0,0,1,192,64,0,152,194,6,0,36,0,0,0,1,192,0,0,248,189,6,0,0,0,0,0,254,0,4,0,72,202,5,0,37,0,0,0,1,3,2,0,80,246,3,0,37,0,0,0,1,3,3,0,80,124,6,0,37,0,0,0,1,3,1,0,112,212,3,0,37,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,64,251,5,0,37,0,0,0,1,12,12,0,240,242,5,0,37,0,0,0,1,12,8,0,56,239,5,0,37,0,0,0,1,12,4,0,64,235,5,0,37,0,0,0,1,12,0,0,40,232,5,0,0,0,0,0,254,0,4,0,128,129,4,0,37,0,0,0,1,48,32,0,208,75,4,0,37,0,0,0,1,48,48,0,8,49,4,0,37,0,0,0,1,48,16,0,152,21,4,0,37,0,0,0,1,48,0,0,72,246,3,0,0,0,0,0,254,0,2,0,104,159,3,0,37,0,0,0,1,64,0,0,96,135,7,0,37,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,224,21,4,0,37,0,0,0,1,128,0,0,48,224,5,0,37,0,0,0,1,128,128,0,0,220,5,0,49,57,120,117,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,104,82,149,5,1,0,16,1,49,57,120,117,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,127,171,17,49,1,0,16,1,49,57,120,117,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,99,74,223,56,1,0,16,1,49,57,120,117,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,211,96,126,92,1,0,16,1,49,57,120,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,108,41,192,97,1,0,16,1,49,57,120,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,235,122,66,5,0,32,0,49,57,120,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,84,191,189,99,5,0,32,0])
.concat([49,57,120,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,24,254,45,5,0,32,0,49,57,120,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,121,149,239,203,5,0,32,0,49,57,120,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,124,150,22,233,5,0,32,0,49,57,120,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,219,243,117,110,5,0,32,0,49,57,120,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,152,231,19,34,5,0,32,0,49,57,120,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,150,91,157,171,5,0,32,0,49,57,120,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,94,25,85,239,10,0,16,1,49,57,120,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,243,238,139,211,12,0,64,0,49,57,120,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,226,150,124,212,12,0,64,0,110,102,102,117,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,143,207,147,150,1,0,16,1,110,102,102,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,110,198,161,219,1,0,16,1,110,102,102,117,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,183,62,129,234,1,0,16,1,110,102,102,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,65,167,252,201,5,0,32,0,110,102,102,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,152,216,9,248,5,0,32,0,110,102,102,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,7,69,186,21,5,0,32,0,110,102,102,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,140,27,212,61,5,0,32,0,110,102,102,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,75,165,227,63,5,0,32,0,110,102,102,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,49,210,92,86,5,0,32,0,110,102,102,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,136,89,202,99,5,0,32,0,110,102,102,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,59,143,235,33,5,0,32,0,110,102,102,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,24,67,228,210,10,0,16,1,110,102,102,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,5,78,62,36,12,0,64,0,110,102,102,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,22,207,79,12,0,64,0,184,40,2,0,1,0,0,0,208,215,148,0,248,191,2,0,56,250,6,0,1,0,0,0,209,215,148,0,184,160,2,0,240,167,7,0,1,0,0,0,210,215,148,0,192,135,2,0,176,163,7,0,1,0,0,0,211,215,148,0,240,108,2,0,208,158,7,0,1,0,0,0,212,215,148,0,96,82,2,0,184,154,7,0,1,0,0,0,213,215,148,0,32,56,2,0,176,108,2,0,1,0,0,0,214,215,148,0,152,30,2,0,128,98,2,0,1,0,0,0,215,215,148,0,232,10,2,0,88,212,3,0,1,0,0,0,224,157,145,0,40,185,3,0,248,5,8,0,9,0,0,0,208,233,146,0,32,58,1,0,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,0,0,144,212,8,0,19,0,0,0,1,2,2,0,96,135,7,0,19,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,4,4,0,96,135,7,0,19,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,8,0,0,96,135,7,0,19,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,2,0,200,87,7,0,19,0,0,0,1,48,0,0,32,136,7,0,19,0,0,0,1,48,16,0,40,88,7,0,19,0,0,0,1,48,32,0,96,39,7,0,19,0,0,0,1,48,48,0,144,251,6,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,3,2,0,80,246,3,0,20,0,0,0,1,3,3,0,80,124,6,0,20,0,0,0,1,3,1,0,112,212,3,0,20,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,64,37,5,0,20,0,0,0,1,12,12,0,240,191,4,0,20,0,0,0,1,12,8,0,200,213,4,0,20,0,0,0,1,12,4,0,144,227,4,0,20,0,0,0,1,12,0,0,200,178,5,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,48,32,0,192,255,2,0,20,0,0,0,1,48,16,0,208,75,4,0,20,0,0,0,1,48,48,0,8,49,4,0,20,0,0,0,1,48,0,0,72,246,3,0,0,0,0,0,254,0,4,0,104,159,3,0,20,0,0,0,1,64,0,0,96,135,7,0,20,0,0,0,1,64,64,0,152,182,7,0,48,51,54,45,112,114,103,46,49,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,247,98,115,59,0,0,16,1,48,51,54,45,98,103,46,49,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,165,141,62,245,0,0,32,0,48,51,54,45,115,112,114,46,49,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,49,135,109,227,0,0,32,0,48,51,54,45,115,110,100,46,49,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,244,202,224,163,0,0,64,0,17,0,0,0,255,255,255,0,0,0,0,0,18,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,15,0,200,87,7,0,17,0,0,0,1,15,5,0,48,229,8,0,17,0,0,0,1,15,3,0,72,163,8,0,17,0,0,0,1,15,7,0,96,100,8,0,17,0,0,0,1,15,4,0,96,44,8,0,17,0,0,0,1,15,2,0,16,249,7,0,17,0,0,0,1,15,8,0,208,195,7,0,17,0,0,0,1,15,9,0,224,147,7,0,17,0,0,0,1,15,1,0,64,101,7,0,17,0,0,0,1,15,15,0,168,50,7,0,17,0,0,0,1,15,14,0,24,7,7,0,17,0,0,0,1,15,13,0,152,221,6,0,17,0,0,0,1,15,12,0,144,176,6,0,17,0,0,0,1,15,11,0,248,133,6,0,17,0,0,0,1,15,10,0,0,88,6,0,17,0,0,0,1,15,0,0,16,227,4,0,0,0,0,0,254,0,15,0,160,123,6,0,17,0,0,0,1,240,80,0,48,229,8,0,17,0,0,0,1,240,48,0,72,163,8,0,17,0,0,0,1,240,112,0,96,100,8,0,17,0,0,0,1,240,64,0,96,44,8,0,17,0,0,0,1,240,32,0,16,249,7,0,17,0,0,0,1,240,128,0,208,195,7,0,17,0,0,0,1,240,144,0,224,147,7,0,17,0,0,0,1,240,16,0,64,101,7,0,17,0,0,0,1,240,240,0,168,50,7,0,17,0,0,0,1,240,224,0,24,7,7,0,17,0,0,0,1,240,208,0,152,221,6,0,17,0,0,0,1,240,192,0,144,176,6,0,17,0,0,0,1,240,176,0,248,133,6,0,17,0,0,0,1,240,160,0,0,88,6,0,17,0,0,0,1,240,0,0,16,227,4,0,0,0,0,0,254,0,4,0,224,210,5,0,18,0,0,0,1,3,2,0,80,246,3,0,18,0,0,0,1,3,3,0,248,38,7,0,18,0,0,0,1,3,1,0,112,212,3,0,18,0,0,0,1,3,0,0,24,99,5,0,0,0,0,0,254,0,4,0,24,45,5,0,18,0,0,0,1,12,12,0,56,15,5,0,18,0,0,0,1,12,8,0,160,236,4,0,18,0,0,0,1,12,4,0,248,38,7,0,18,0,0,0,1,12,0,0,112,212,3,0,0,0,0,0,254,0,2,0,152,199,4,0,18,0,0,0,1,16,0,0,48,168,4,0,18,0,0,0,1,16,16,0,160,136,4,0,0,0,0,0,254,0,2,0,48,109,4,0,18,0,0,0,1,32,0,0,96,135,7,0,18,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,168,28,4,0,18,0,0,0,1,64,0,0,56,111,3,0,18,0,0,0,1,64,64,0,104,134,3,0,0,0,0,0,254,0,2,0,72,4,1,0,18,0,0,0,1,128,128,0,96,135,7,0,18,0,0,0,1,128,0,0,152,182,7,0,168,86,7,0,1,0,0,0,232,47,216,0,248,191,2,0,24,38,7,0,1,0,0,0,236,47,216,0,184,160,2,0,56,210,6,0,1,0,0,0,35,48,216,0,192,135,2,0,24,163,6,0,1,0,0,0,34,48,216,0,240,108,2,0,152,122,6,0,1,0,0,0,33,48,216,0,96,82,2,0,192,72,6,0,1,0,0,0,32,48,216,0,32,56,2,0,232,158,3,0,1,0,0,0,36,48,216,0,152,30,2,0,104,184,3,0,1,0,0,0,37,48,216,0,232,10,2,0,40,246,1,0,1,0,0,0,233,47,216,0,64,246,1,0,144,236,1,0,1,0,0,0,237,47,216,0,136,224,1,0,176,223,1,0,1,0,0,0,43,48,216,0,72,198,1,0,192,209,1,0,1,0,0,0,42,48,216,0,24,182,1,0,24,198,1,0,1,0,0,0,41,48,216,0,40,167,1,0,120,189,1,0,1,0,0,0,40,48,216,0,200,149,1,0,200,32,1,0,1,0,0,0,44,48,216,0,56,126,1,0,208,41,1,0,1,0,0,0,45,48,216,0,32,101,1,0,88,212,3,0,1,0,0,0,144,46,216,0,40,185,3,0,16,17,8,0,1,0,0,0,234,47,216,0,224,12,8,0,72,65,1,0,9,0,0,0,232,48,216,0,32,58,1,0,48,50,1,0,9,0,0,0,224,48,216,0,32,58,1,0,224,41,1,0,9,0,0,0,216,48,216,0,32,58,1,0,101,112,114,54,57,54,51,98,46,49,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,212,137,175,77,0,0,16,1,101,112,114,54,57,54,52,97,46,49,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,229,136,97,194,0,0,16,1,101,112,114,45,54,57,50,55,46,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,100,175,187,60,0,0,16,1,101,112,114,45,54,57,120,120,46,49,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,233,225,57,0,0,0,16,1,101,112,114,45,54,57,54,54,46,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,1,4,127,21,0,0,32,0,101,112,114,45,54,57,54,49,46,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,71,206,83,190,0,0,32,0,101,112,114,45,54,57,54,48,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,170,27,56,189,0,0,32,0,101,112,114,45,54,57,53,57,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,154,231,4,188,0,0,32,0,101,112,114,45,54,57,53,56,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,38,44,79,113,0,0,32,0,101,112,114,45,54,57,53,55,46,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,18,1,146,128,0,0,32,0,101,112,114,45,54,57,50,49,46,49,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,161,5,158,241,0,0,32,0,101,112,114,45,54,57,50,51,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,195,173,136,121,0,0,32,0,101,112,114,45,54,57,50,50,46,49,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,120,122,247,55,0,0,32,0,101,112,114,45,54,57,50,52,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,246,200,189,66,0,0,32,0,112,114,45,53,51,49,55,46,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,184,80,131,100,0,0,0,8,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,252,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,19,0,0,0,1,15,7,0,80,252,6,0,19,0,0,0,1,15,8,0,16,242,7,0,19,0,0,0,1,15,9,0,104,236,7,0,19,0,0,0,1,15,5,0,192,54,8,0,19,0,0,0,1,15,4,0,56,24,4,0,19,0,0,0,1,15,15,0,128,230,7,0,19,0,0,0,1,15,0,0,128,230,7,0,19,0,0,0,1,15,3,0,176,162,3,0,19,0,0,0,1,15,2,0,24,188,3,0,19,0,0,0,1,15,1,0,72,216,3,0,19,0,0,0,1,15,6,0,120,211,6,0,19,0,0,0,1,15,14,0,184,164,6,0,19,0,0,0,1,15,13,0,80,74,6,0,19,0,0,0,1,15,12,0,192,32,6,0,19,0,0,0,1,15,11,0,192,234,2,0,19,0,0,0,1,15,10,0,32,242,5,0,0,0,0,0,254,0,16,0,160,123,6,0,19,0,0,0,1,240,112,0,80,252,6,0,19,0,0,0,1,240,128,0,16,242,7,0,19,0,0,0,1,240,144,0,104,236,7,0,19,0,0,0,1,240,80,0,192,54,8,0,19,0,0,0,1,240,64,0,56,24,4,0,19,0,0,0,1,240,240,0,128,230,7,0,19,0,0,0,1,240,0,0,128,230,7,0,19,0,0,0,1,240,48,0,176,162,3,0,19,0,0,0,1,240,32,0,24,188,3,0,19,0,0,0,1,240,16,0,72,216,3,0,19,0,0,0,1,240,96,0,120,211,6,0,19,0,0,0,1,240,224,0,184,164,6,0,19,0,0,0,1,240,208,0,80,74,6,0,19,0,0,0,1,240,192,0,192,32,6,0,19,0,0,0,1,240,176,0,192,234,2,0,19,0,0,0,1,240,160,0,32,242,5,0,0,0,0,0,254,0,2,0,200,30,2,0,20,0,0,0,1,1,0,0,120,97,1,0,20,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,2,0,168,234,7,0,20,0,0,0,1,2,2,0,96,135,7,0,20,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,12,12,0,8,49,4,0,20,0,0,0,1,12,8,0,152,21,4,0,20,0,0,0,1,12,4,0,72,246,3,0,20,0,0,0,1,12,0,0,112,49,6,0,0,0,0,0,254,0,4,0,64,37,5,0,20,0,0,0,1,48,48,0,192,33,6,0,20,0,0,0,1,48,32,0,208,26,6,0,20,0,0,0,1,48,16,0,48,20,6,0,20,0,0,0,1,48,0,0,248,211,5,0,0,0,0,0,254,0,2,0,72,202,5,0,20,0,0,0,1,64,64,0,80,246,3,0,20,0,0,0,1,64,0,0,112,212,3,0,0,0,0,0,109,118,99,117,100,46,48,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,229,227,205,117,1,0,16,1,109,118,99,117,100,46,48,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,132,164,46,179,1,0,16,1,109,118,99,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,134,142,140,45,1,0,16,1,109,118,99,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,245,225,40,133,1,0,16,1,109,118,99,100,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,233,147,82,32,1,0,16,1,109,118,99,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,205,47,0,188,1,0,16,1,109,118,99,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,38,123,198,1,0,16,1,109,118,99,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,38,30,221,15,1,0,16,1,109,118,99,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,188,116,95,250,5,0,32,0,109,118,99,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,143,138,147,113,5,0,32,0,109,118,99,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,7,29,116,146,5,0,32,0,109,118,99,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,198,47,183,188,5,0,32,0,109,118,99,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,228,244,29,127,5,0,32,0,109,118,99,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,3,50,189,144,5,0,32,0,109,118,99,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,39,247,170,103,5,0,32,0,109,118,99,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,232,173,11,139,5,0,32,0,109,118,99,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,149,158,98,65,10,0,16,1,109,118,99,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,107,191,58,150,10,0,16,1,109,118,99,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,99,230,15,133,12,0,64,0,109,118,99,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,150,24,203,124,12,0,64,0,109,118,99,101,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,192,63,99,224,1,0,16,1,109,118,99,101,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,81,162,80,164,1,0,16,1,109,118,99,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,233,28,183,125,1,0,16,1,109,118,99,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,62,109,11,75,1,0,16,1,109,118,99,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,43,163,186,195,1,0,16,1,109,118,99,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,205,47,0,188,1,0,16,1,109,118,99,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,38,123,198,1,0,16,1,109,118,99,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,38,30,221,15,1,0,16,1,109,118,99,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,188,116,95,250,5,0,32,0,109,118,99,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,143,138,147,113,5,0,32,0,109,118,99,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,7,29,116,146,5,0,32,0,109,118,99,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,198,47,183,188,5,0,32,0,109,118,99,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,228,244,29,127,5,0,32,0,109,118,99,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,3,50,189,144,5,0,32,0,109,118,99,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,39,247,170,103,5,0,32,0,109,118,99,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,232,173,11,139,5,0,32,0,109,118,99,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,149,158,98,65,10,0,16,1,109,118,99,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,107,191,58,150,10,0,16,1,109,118,99,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,99,230,15,133,12,0,64,0,109,118,99,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,150,24,203,124,12,0,64,0,99,104,101,95,51,48,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,177,45,42,154,1,0,16,1,99,104,101,95,51,53,46,49,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,2,107,249,167,1,0,16,1,99,104,101,95,51,49,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,153,138,255,187,1,0,16,1,99,104,101,95,51,54,46,49,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,57,12,160,15,1,0,16,1,99,107,45,51,50,109,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,65,189,112,155,2,0,16,1,99,107,45,53,109,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,21,95,199,78,4,0,32,0,99,107,45,55,109,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,214,0,93,216,4,0,32,0,99,107,45,49,109,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,212,169,60,243,4,0,32,0,99,107,45,51,109,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,127,4,162,11,4,0,32,0,99,104,95,48,57,46,49,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,183,85,66,77,3,0,16,0,99,104,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,222,232,9,249,5,0,64,0,99,104,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,247,140,21,252,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,99,107,50,52,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,0,0,0,0,0,0,24,105,111,98,49,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,21,0,0,0,255,255,0,0,0,0,0,0,22,0,0,0,255,255,3,0,0,0,0,0,23,0,0,0,255,255,96,0,0,0,0,0,0,0,0,0,254,0,8,0,200,87,7,0,21,0,0,0,1,7,7,0,80,252,6,0,21,0,0,0,1,7,6,0,16,242,7,0,21,0,0,0,1,7,5,0,104,236,7,0,21,0,0,0,1,7,0,0,128,230,7,0,21,0,0,0,1,7,1,0,184,164,6,0,21,0,0,0,1,7,2,0,80,74,6,0,21,0,0,0,1,7,3,0,192,32,6,0,21,0,0,0,1,7,4,0,32,242,5,0,0,0,0,0,254,0,8,0,160,123,6,0,21,0,0,0,1,56,56,0,80,252,6,0,21,0,0,0,1,56,48,0,16,242,7,0,21,0,0,0,1,56,40,0,104,236,7,0,21,0,0,0,1,56,0,0,128,230,7,0,21,0,0,0,1,56,8,0,184,164,6,0,21,0,0,0,1,56,16,0,80,74,6,0,21,0,0,0,1,56,24,0,192,32,6,0,21,0,0,0,1,56,32,0,32,242,5,0,0,0,0,0,254,0,8,0,72,202,5,0,22,0,0,0,1,7,0,0,72,198,6,0,22,0,0,0,1,7,1,0,208,75,4,0,22,0,0,0,1,7,2,0,8,49,4,0,22,0,0,0,1,7,3,0,72,195,6,0,22,0,0,0,1,7,4,0,72,246,3,0,22,0,0,0,1,7,5,0,72,0,3,0,22,0,0,0,1,7,6,0,64,47,7,0,22,0,0,0,1,7,7,0,48,173,6,0,0,0,0,0,254,0,4,0,128,129,4,0,22,0,0,0,1,56,40,0,192,255,2,0,22,0,0,0,1,56,32,0,208,75,4,0,22,0,0,0,1,56,48,0,8,49,4,0,22,0,0,0,1,56,56,0,152,21,4,0,0,0,0,0,254,0,2,0,16,227,4,0,23,0,0,0,1,4,0,0,96,135,7,0,23,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,254,0,2,0,72,4,1,0,23,0,0,0,1,8,0,0,96,135,7,0,23,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,2,0,120,207,1,0,23,0,0,0,1,16,0,0,96,135,7,0,23,0,0,0,1,16,16,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,23,0,0,0,1,32,0,0,96,135,7,0,23,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,23,0,0,0,1,64,0,0,96,135,7,0,23,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,168,79,2,0,23,0,0,0,1,128,0,0,32,182,8,0,23,0,0,0,1,128,128,0,80,251,6,0,0,0,0,0,109,115,101,95,51,48,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,188,141,252,3,1,0,16,1,109,115,101,95,51,53,46,49,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,205,102,191,213,1,0,16,1,109,115,101,95,51,49,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,207,43,51,48,1,0,16,1,109,115,101,95,51,54,46,49,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,233,108,125,143,1,0,16,1,109,115,45,51,50,109,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,252,221,117,36,2,0,16,1,109,115,45,53,109,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,226,231,15,192,4,0,32,0,109,115,45,55,109,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,197,202,202,76,4,0,32,0,109,115,45,49,109,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,190,43,13,4,0,32,0,109,115,45,51,109,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,244,91,26,58,4,0,32,0,109,115,95,48,57,46,49,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,25,149,178,87,3,0,16,0,109,115,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,13,233,100,251,5,0,64,0,109,115,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,185,146,248,116,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,109,115,50,52,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,109,190,109,99,0,0,0,8,105,111,98,49,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,21,0,0,0,255,255,0,0,0,0,0,0,22,0,0,0,255,255,3,0,0,0,0,0,23,0,0,0,255,255,96,0,0,0,0,0,0,0,0,0,254,0,8,0,200,87,7,0,21,0,0,0,1,7,7,0,80,252,6,0,21,0,0,0,1,7,6,0,16,242,7,0,21,0,0,0,1,7,5,0,104,236,7,0,21,0,0,0,1,7,0,0,128,230,7,0,21,0,0,0,1,7,1,0,184,164,6,0,21,0,0,0,1,7,2,0,80,74,6,0,21,0,0,0,1,7,3,0,192,32,6,0,21,0,0,0,1,7,4,0,32,242,5,0,0,0,0,0,254,0,8,0,160,123,6,0,21,0,0,0,1,56,56,0,80,252,6,0,21,0,0,0,1,56,48,0,16,242,7,0,21,0,0,0,1,56,40,0,104,236,7,0,21,0,0,0,1,56,0,0,128,230,7,0,21,0,0,0,1,56,8,0,184,164,6,0,21,0,0,0,1,56,16,0,80,74,6,0,21,0,0,0,1,56,24,0,192,32,6,0,21,0,0,0,1,56,32,0,32,242,5,0,0,0,0,0,254,0,2,0,64,232,1,0,21,0,0,0,1,64,0,0,96,135,7,0,21,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,8,0,80,114,1,0,22,0,0,0,1,7,0,0,72,198,6,0,22,0,0,0,1,7,1,0,208,75,4,0,22,0,0,0,1,7,2,0,8,49,4,0,22,0,0,0,1,7,3,0,72,195,6,0,22,0,0,0,1,7,4,0,72,246,3,0,22,0,0,0,1,7,5,0,72,0,3,0,22,0,0,0,1,7,6,0,64,47,7,0,22,0,0,0,1,7,7,0,48,173,6,0,0,0,0,0,254,0,8,0,176,110,6,0,22,0,0,0,1,56,24,0,72,198,6,0,22,0,0,0,1,56,16,0,208,75,4,0,22,0,0,0,1,56,8,0,8,49,4,0,22,0,0,0,1,56,0,0,72,195,6,0,22,0,0,0,1,56,32,0,72,246,3,0,22,0,0,0,1,56,40,0,72,0,3,0,22,0,0,0,1,56,48,0,64,47,7,0,22,0,0,0,1,56,56,0,48,173,6,0,0,0,0,0,254,0,2,0,128,111,8,0,22,0,0,0,1,64,0,0,96,135,7,0,22,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,4,0,200,242,1,0,23,0,0,0,1,3,3,0,192,255,2,0,23,0,0,0,1,3,0,0,208,75,4,0,23,0,0,0,1,3,1,0,32,110,1,0,23,0,0,0,1,3,2,0,128,109,1,0,0,0,0,0,254,0,2,0,16,227,4,0,23,0,0,0,1,4,0,0,96,135,7,0,23,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,254,0,2,0,72,4,1,0,23,0,0,0,1,8,0,0,96,135,7,0,23,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,2,0,120,207,1,0,23,0,0,0,1,16,0,0,96,135,7,0,23,0,0,0,1,16,16,0,152,182,7,0,0,0,0,0,254,0,2,0,40,111,8,0,23,0,0,0,1,32,0,0,96,135,7,0,23,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,23,0,0,0,1,64,0,0,96,135,7,0,23,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,168,79,2,0,23,0,0,0,1,128,0,0,32,182,8,0,23,0,0,0,1,128,128,0,80,251,6,0,109,118,115,101,46,48,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,153,193,45,183,1,0,16,1,109,118,115,101,46,48,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,249,153,247,110,1,0,16,1,109,118,115,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,203,224,93,26,1,0,16,1,109,118,115,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,48,48,159,149,1,0,16,1,109,118,115,46,48,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,219,91,145,127,1,0,16,1,109,118,115,46,48,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,132,56,129,194,1,0,16,1,109,118,115,46,48,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,136,160,59,1,0,16,1,109,118,115,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,152,186,13,207,1,0,16,1,109,118,115,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,217,95,176,41,5,0,32,0,109,118,115,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,241,204,221,250,5,0,32,0,109,118,115,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,199,244,170,151,5,0,32,0,109,118,115,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,21,233,112,203,5,0,32,0,109,118,115,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,45,151,177,179,5,0,32,0,109,118,115,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,93,219,170,8,5,0,32,0,109,118,115,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,53,139,34,193,5,0,32,0,109,118,115,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,194,198,108,54,5,0,32,0,109,118,115,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,36,35,37,104,10,0,16,1,109,118,115,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,61,119,78,179,10,0,16,1,109,118,115,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,112,151,33,134,12,0,64,0,109,118,115,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,104,127,253,242,12,0,64,0,109,115,104,106,46,48,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,210,47,23,255,1,0,16,1,109,115,104,106,46,48,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,90,32,187,235,1,0,16,1,109,115,104,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,158,27,9,106,1,0,16,1,109,115,104,46,48,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,164,63,62,128,1,0,16,1,109,115,104,46,48,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,142,95,196,1,0,16,1,109,115,104,46,48,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,44,241,166,156,1,0,16,1,109,115,104,46,48,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,175,39,236,130,1,0,16,1,109,115,104,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,150,17,147,141,1,0,16,1,109,115,104,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,102,69,209,9,5,0,32,0,109,115,104,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,64,0,87,32,150,238,5,0,32,0,109,115,104,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,20,206,78,96,5,0,32,0,109,115,104,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,232,49,167,148,5,0,32,0,109,115,104,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,62,151,151,65,5,0,32,0,109,115,104,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,160,164,141,67,5,0,32,0,109,115,104,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,148,45,185,77,5,0,32,0,109,115,104,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,192,198,176,162,5,0,32,0,109,115,104,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,249,230,118,201,10,0,16,1,109,115,104,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,217,208,103,206,10,0,16,1,109,115,104,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,48,109,172,55,12,0,64,0,109,115,104,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,112,37,9,222,12,0,64,0,109,112,110,117,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,60,208,126,110,1,0,16,1,109,112,110,117,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,49,145,7,222,1,0,16,1,109,112,110,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,220,35,241,197,5,0,32,0,109,112,110,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,101,50,3,142,5,0,32,0,109,112,110,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,210,115,205,207,5,0,32,0,109,112,110,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,188,255,177,45,5,0,32,0,109,112,110,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,182,173,199,144,10,0,16,1,109,112,110,46,113,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,90,31,28,210,12,0,64,0,109,112,110,46,113,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,177,144,32,210,12,0,64,0,109,112,110,46,113,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,242,94,170,96,12,0,64,0,109,112,110,46,113,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,3,210,103,58,12,0,64,0,109,112,110,106,46,48,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,28,123,89,191,1,0,16,1,109,112,110,106,46,48,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,15,171,163,244,1,0,16,1,109,112,110,45,115,105,109,109,46,48,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,107,182,141,56,6,0,32,0,109,112,110,45,115,105,109,109,46,48,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,148,180,241,175,6,0,32,0,109,112,110,45,115,105,109,109,46,48,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,123,133,196,169,6,0,32,0,109,112,110,45,115,105,109,109,46,48,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,34,223,89,247,6,0,32,0,109,112,110,45,115,105,109,109,46,48,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,32,183,198,222,6,0,32,0,109,112,110,45,115,105,109,109,46,48,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,24,76,119,248,6,0,32,0,109,112,110,45,115,105,109,109,46,48,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,236,164,174,194,6,0,32,0,109,112,110,45,115,105,109,109,46,48,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,51,220,214,132,6,0,32,0,109,112,110,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,182,173,199,144,10,0,16,1,109,112,110,45,115,105,109,109,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,33,46,138,49,13,0,64,0,109,112,110,45,115,105,109,109,46,48,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,232,244,98,84,13,0,64,0,16,0,0,0,255,255,127,0,0,0,0,0,17,0,0,0,255,255,239,0,0,0,0,0,18,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,16,0,0,0,1,3,3,0,8,49,4,0,16,0,0,0,1,3,2,0,152,21,4,0,16,0,0,0,1,3,1,0,72,246,3,0,16,0,0,0,1,3,0,0,216,128,5,0,0,0,0,0,254,0,8,0,32,4,2,0,16,0,0,0,1,28,16,0,96,135,3,0,16,0,0,0,1,28,20,0,40,88,7,0,16,0,0,0,1,28,24,0,96,39,7,0,16,0,0,0,1,28,28,0,144,251,6,0,16,0,0,0,1,28,12,0,184,164,6,0,16,0,0,0,1,28,4,0,24,1,7,0,16,0,0,0,1,28,8,0,192,234,2,0,16,0,0,0,1,28,0,0,16,227,4,0,0,0,0,0,254,0,4,0,72,202,5,0,16,0,0,0,1,96,64,0,80,246,3,0,16,0,0,0,1,96,96,0,248,38,7,0,16,0,0,0,1,96,32,0,112,212,3,0,16,0,0,0,1,96,0,0,248,160,5,0,0,0,0,0,254,0,4,0,64,37,5,0,17,0,0,0,1,3,1,0,160,39,6,0,17,0,0,0,1,3,3,0,192,33,6,0,17,0,0,0,1,3,2,0,208,26,6,0,17,0,0,0,1,3,0,0,0,64,7,0,0,0,0,0,254,0,2,0,168,234,7,0,17,0,0,0,1,32,0,0,96,135,7,0,17,0,0,0,1,32,32,0,152,182,7,0,102,107,95,49,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,223,34,117,222,0,0,16,1,102,107,95,49,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,201,184,148,52,0,0,16,1,102,108,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,78,53,40,19,0,0,16,1,102,108,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,94,149,179,227,0,0,16,1,102,108,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,223,11,54,102,0,0,16,1,102,107,95,48,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,83,116,219,60,0,0,32,0,102,107,95,48,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,12,162,91,50,0,0,32,0,102,108,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,16,89,125,144,0,0,32,0,102,108,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,60,192,54,169,0,0,32,0,102,108,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,92,196,104,32,0,0,32,0,102,108,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,185,26,36,183,0,0,32,0,102,108,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,180,115,107,184,0,0,32,0,102,108,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,41,91,36,146,0,0,32,0,102,108,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,167,53,139,44,0,0,32,0,102,108,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,60,237,239,30,0,0,32,0,102,108,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,1,184,111,117,0,0,32,0,102,108,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,32,193,210,84,0,0,32,0,102,108,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,93,150,41,144,0,0,64,0,55,49,49,52,46,112,114,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,251,159,83,235,0,0,0,8,112,97,108,49,54,114,52,97,45,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,224,184,143,210,0,0,0,8,112,97,108,49,54,108,56,98,45,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,227,145,181,188,0,0,0,8,112,97,108,49,54,108,56,97,45,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,172,114,41,225,0,0,0,8,112,97,108,49,54,108,56,97,45,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,73,126,67,198,0,0,0,8,112,97,108,49,54,108,56,98,45,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,103,58,238,233,0,0,0,8,112,97,108,49,54,108,56,97,45,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,190,122,177,35,0,0,0,8,24,0,0,0,255,255,255,0,0,0,0,0,25,0,0,0,255,255,191,0,0,0,0,0,0,0,0,0,254,0,4,0,200,87,7,0,24,0,0,0,1,3,0,0,176,45,8,0,24,0,0,0,1,3,1,0,224,127,8,0,24,0,0,0,1,3,3,0,32,123,8,0,24,0,0,0,1,3,2,0,192,110,8,0,0,0,0,0,254,0,4,0,160,123,6,0,24,0,0,0,1,12,0,0,176,45,8,0,24,0,0,0,1,12,4,0,224,127,8,0,24,0,0,0,1,12,12,0,32,123,8,0,24,0,0,0,1,12,8,0,192,110,8,0,0,0,0,0,254,0,2,0,232,75,4,0,24,0,0,0,1,16,16,0,96,135,7,0,24,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,24,0,0,0,1,32,0,0,96,135,7,0,24,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,24,0,0,0,1,64,64,0,96,135,7,0,24,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,25,0,0,0,1,3,3,0,8,49,4,0,25,0,0,0,1,3,2,0,152,21,4,0,25,0,0,0,1,3,1,0,72,246,3,0,25,0,0,0,1,3,0,0,112,49,6,0,0,0,0,0,254,0,4,0,72,202,5,0,25,0,0,0,1,12,8,0,80,246,3,0,25,0,0,0,1,12,12,0,248,38,7,0,25,0,0,0,1,12,4,0,112,212,3,0,25,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,2,0,192,125,6,0,25,0,0,0,1,64,64,0,56,111,3,0,25,0,0,0,1,64,0,0,104,134,3,0,100,49,54,45,49,54,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,97,190,80,49,2,0,16,1,100,49,54,45,49,56,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,146,208,22,82,2,0,16,1,100,49,50,45,48,55,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,54,81,127,224,2,0,16,1,100,49,50,45,48,54,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,49,247,29,19,2,0,16,1,100,49,50,45,49,51,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,73,38,202,188,9,0,16,1,100,49,50,45,48,51,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,192,152,180,70,12,0,32,0,100,49,50,45,48,52,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,65,209,102,171,12,0,32,0,100,49,50,45,48,49,46,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,185,35,21,184,15,0,32,0,100,49,50,45,48,50,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,116,62,38,121,24,0,64,0,100,49,50,45,48,53,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,197,54,208,127,25,0,64,0,21,0,0,0,255,255,255,0,0,0,0,0,22,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,21,0,0,0,1,2,2,0,96,135,7,0,21,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,21,0,0,0,1,4,4,0,96,135,7,0,21,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,21,0,0,0,1,8,0,0,96,135,7,0,21,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,21,0,0,0,1,48,0,0,80,252,6,0,21,0,0,0,1,48,16,0,16,242,7,0,21,0,0,0,1,48,32,0,104,236,7,0,21,0,0,0,1,48,48,0,128,230,7,0,0,0,0,0,254,0,4,0,160,123,6,0,21,0,0,0,1,192,192,0,8,201,6,0,21,0,0,0,1,192,128,0,200,197,6,0,21,0,0,0,1,192,64,0,152,194,6,0,21,0,0,0,1,192,0,0,248,189,6,0,0,0,0,0,254,0,4,0,72,202,5,0,22,0,0,0,1,3,2,0,80,246,3,0,22,0,0,0,1,3,3,0,80,124,6,0,22,0,0,0,1,3,1,0,112,212,3,0,22,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,64,37,5,0,22,0,0,0,1,12,8,0,112,228,4,0,22,0,0,0,1,12,12,0,8,225,4,0,22,0,0,0,1,12,4,0,208,220,4,0,22,0,0,0,1,12,0,0,40,160,4,0,0,0,0,0,254,0,4,0,128,129,4,0,22,0,0,0,1,48,0,0,192,255,2,0,22,0,0,0,1,48,16,0,208,75,4,0,22,0,0,0,1,48,48,0,8,49,4,0,22,0,0,0,1,48,32,0,72,246,3,0,0,0,0,0,254,0,2,0,104,159,3,0,22,0,0,0,1,64,0,0,96,135,7,0,22,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,6,0,22,0,0,0,1,128,0,0,8,208,6,0,22,0,0,0,1,128,128,0,88,204,6,0,115,111,50,95,51,48,97,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,215,37,231,228,1,0,16,1,115,111,50,95,51,53,97,46,49,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,69,52,132,231,1,0,16,1,115,111,50,95,51,49,97,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,234,29,185,192,1,0,16,1,115,111,50,95,51,54,97,46,49,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,108,223,30,89,1,0,16,1,115,111,50,45,51,50,109,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,12,207,181,46,2,0,16,1,115,111,50,45,54,109,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,175,2,97,170,4,0,32,0,115,111,50,45,56,109,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,105,104,158,131,4,0,32,0,115,111,50,45,50,109,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,117,40,124,89,4,0,32,0,115,111,50,45,52,109,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,160,156,42,145,4,0,32,0,115,111,50,95,50,52,46,55,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,254,78,37,63,4,0,32,0,115,111,50,95,49,52,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0])
.concat([94,144,168,245,4,0,32,0,115,111,50,95,50,54,46,57,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,74,90,170,243,4,0,32,0,115,111,50,95,49,54,46,57,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,168,209,60,180,4,0,32,0,115,111,50,95,50,48,46,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,163,81,167,140,4,0,32,0,115,111,50,95,49,48,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,253,105,245,233,4,0,32,0,115,111,50,95,50,50,46,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,119,163,233,252,4,0,32,0,115,111,50,95,49,50,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,6,138,223,183,4,0,32,0,115,111,50,95,48,57,46,49,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,122,124,157,208,3,0,16,0,115,111,50,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,67,22,234,187,5,0,64,0,115,111,50,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,113,170,88,172,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,111,50,50,52,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,205,200,17,194,0,0,0,8,105,111,98,49,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,99,54,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,0,0,0,0,0,0,24,115,111,50,95,51,54,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,247,155,127,225,1,0,16,1,115,111,50,95,52,50,46,49,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,198,132,56,44,1,0,16,1,115,111,50,95,51,55,46,49,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,54,77,32,81,1,0,16,1,115,111,50,95,52,51,46,49,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,180,168,251,156,1,0,16,1,115,111,50,95,51,52,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,95,233,218,184,1,0,16,1,115,111,50,95,52,48,46,49,48,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,28,119,55,222,1,0,16,1,115,111,50,95,51,53,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,77,57,36,125,1,0,16,1,115,111,50,95,52,49,46,49,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,224,133,79,145,1,0,16,1,115,111,50,95,48,57,46,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,29,38,12,105,4,0,32,0,115,111,50,95,48,49,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,21,39,253,49,4,0,32,0,115,111,50,95,49,51,46,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,130,130,228,181,4,0,32,0,115,111,50,95,48,53,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,44,216,190,84,4,0,32,0,115,111,50,95,50,52,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,203,240,182,120,4,0,32,0,115,111,50,95,49,55,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,8,179,139,231,4,0,32,0,115,111,50,95,51,56,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,162,169,16,0,4,0,32,0,115,111,50,95,51,50,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,154,252,223,117,4,0,32,0,115,111,50,95,49,48,46,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,20,23,135,47,4,0,32,0,115,111,50,95,48,50,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,183,160,178,180,4,0,32,0,115,111,50,95,49,52,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,75,116,122,115,4,0,32,0,115,111,50,95,48,54,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,81,111,117,157,4,0,32,0,115,111,50,95,50,53,46,55,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,214,5,14,109,4,0,32,0,115,111,50,95,49,56,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,78,31,246,150,4,0,32,0,115,111,50,95,51,57,46,57,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,54,163,43,213,4,0,32,0,115,111,50,95,51,51,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,37,13,185,57,4,0,32,0,115,111,50,95,49,49,46,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,254,78,37,63,4,0,32,0,115,111,50,95,48,51,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,94,144,168,245,4,0,32,0,115,111,50,95,49,53,46,49,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,74,90,170,243,4,0,32,0,115,111,50,95,48,55,46,49,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,168,209,60,180,4,0,32,0,115,111,50,95,50,54,46,56,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,163,81,167,140,4,0,32,0,115,111,50,95,49,57,46,56,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,253,105,245,233,4,0,32,0,115,111,50,95,50,56,46,49,48,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,119,163,233,252,4,0,32,0,115,111,50,95,50,49,46,49,48,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,6,138,223,183,4,0,32,0,115,111,50,95,50,51,46,49,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,122,124,157,208,3,0,16,0,115,111,50,95,51,48,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,67,22,234,187,5,0,64,0,115,111,50,95,51,49,46,49,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,113,170,88,172,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,111,50,50,50,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,0,0,0,0,0,0,24,108,119,105,111,46,49,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,12,185,82,173,0,0,0,8,99,54,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,0,0,0,0,0,0,24,184,40,2,0,1,0,0,0,47,39,216,0,248,191,2,0,56,250,6,0,1,0,0,0,39,39,216,0,184,160,2,0,184,164,8,0,1,0,0,0,46,39,216,0,64,246,1,0,88,149,7,0,1,0,0,0,38,39,216,0,136,224,1,0,168,188,8,0,1,0,0,0,28,39,216,0,192,135,2,0,24,175,8,0,1,0,0,0,30,39,216,0,240,108,2,0,240,156,8,0,1,0,0,0,45,39,216,0,96,82,2,0,80,144,8,0,1,0,0,0,44,39,216,0,32,56,2,0,64,38,2,0,1,0,0,0,31,39,216,0,208,174,1,0,136,37,2,0,1,0,0,0,29,39,216,0,48,160,1,0,56,36,2,0,1,0,0,0,43,39,216,0,160,140,1,0,96,34,2,0,1,0,0,0,42,39,216,0,56,112,1,0,16,111,8,0,1,0,0,0,40,39,216,0,72,198,1,0,32,95,8,0,1,0,0,0,24,39,216,0,24,182,1,0,192,81,8,0,1,0,0,0,37,39,216,0,40,167,1,0,112,71,8,0,1,0,0,0,36,39,216,0,200,149,1,0,24,192,1,0,1,0,0,0,23,39,216,0,32,231,8,0,80,190,1,0,1,0,0,0,21,39,216,0,88,214,8,0,208,188,1,0,1,0,0,0,35,39,216,0,224,202,8,0,232,187,1,0,1,0,0,0,34,39,216,0,72,193,8,0,88,212,3,0,1,0,0,0,48,38,216,0,40,185,3,0,16,17,8,0,1,0,0,0,41,39,216,0,224,12,8,0,248,5,8,0,9,0,0,0,112,39,216,0,32,58,1,0,144,250,7,0,9,0,0,0,113,39,216,0,32,58,1,0,248,241,7,0,9,0,0,0,114,39,216,0,32,58,1,0,72,82,8,0,9,0,0,0,80,39,216,0,32,58,1,0,0,0,0,0,0,0,0,0,17,0,0,0,255,255,254,0,0,0,0,0,18,0,0,0,255,255,254,0,0,0,0,0,0,0,0,0,254,0,2,0,232,80,3,0,17,0,0,0,1,2,2,0,96,135,7,0,17,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,17,0,0,0,1,12,12,0,8,49,4,0,17,0,0,0,1,12,4,0,152,21,4,0,17,0,0,0,1,12,8,0,72,246,3,0,17,0,0,0,1,12,0,0,72,0,3,0,0,0,0,0,254,0,4,0,192,56,2,0,17,0,0,0,1,48,0,0,176,193,3,0,17,0,0,0,1,48,32,0,208,196,4,0,17,0,0,0,1,48,16,0,56,233,4,0,17,0,0,0,1,48,48,0,16,42,5,0,0,0,0,0,254,0,4,0,0,70,2,0,17,0,0,0,1,192,192,0,16,42,5,0,17,0,0,0,1,192,0,0,24,155,1,0,17,0,0,0,1,192,64,0,152,11,5,0,17,0,0,0,1,192,128,0,24,27,4,0,0,0,0,0,254,0,4,0,72,202,5,0,18,0,0,0,1,6,2,0,80,246,3,0,18,0,0,0,1,6,6,0,80,124,6,0,18,0,0,0,1,6,4,0,112,212,3,0,18,0,0,0,1,6,0,0,248,160,5,0,0,0,0,0,254,0,2,0,40,73,5,0,18,0,0,0,1,8,0,0,96,135,7,0,18,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,2,0,72,217,6,0,18,0,0,0,1,16,0,0,56,111,3,0,18,0,0,0,1,16,16,0,104,134,3,0,0,0,0,0,254,0,8,0,40,148,2,0,18,0,0,0,1,224,224,0,0,117,1,0,18,0,0,0,1,224,96,0,160,104,1,0,18,0,0,0,1,224,160,0,24,94,1,0,18,0,0,0,1,224,32,0,224,87,1,0,18,0,0,0,1,224,192,0,120,80,1,0,18,0,0,0,1,224,64,0,240,72,1,0,18,0,0,0,1,224,128,0,208,66,1,0,18,0,0,0,1,224,0,0,120,7,5,0,108,111,116,45,97,45,52,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,143,208,19,41,0,0,16,1,108,111,116,45,97,45,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,95,9,67,4,0,0,16,1,108,111,116,45,97,45,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,231,206,129,7,0,0,16,1,108,111,116,45,107,45,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,244,149,54,27,0,0,32,0,108,111,116,45,107,45,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,48,7,43,189,0,0,32,0,108,111,116,45,107,45,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,85,221,13,147,0,0,32,0,108,111,116,45,98,45,52,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,144,203,39,253,0,0,32,0,108,111,116,45,98,45,51,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,255,111,72,189,0,0,32,0,108,111,116,45,98,45,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,108,238,38,48,0,0,32,0,108,111,116,45,107,45,52,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,186,149,125,59,0,0,32,0,108,111,116,45,107,45,52,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,31,202,141,249,0,0,32,0,108,111,116,45,107,45,52,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,165,118,205,240,0,0,32,0,108,111,116,45,107,45,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,94,160,32,184,0,0,32,0,108,111,116,45,98,45,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,29,70,70,193,0,0,32,0,108,111,116,45,107,45,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,13,35,62,172,0,0,32,0,108,111,116,45,107,45,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,5,160,31,155,0,0,32,0,108,111,116,45,98,45,49,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,182,125,224,1,0,0,32,0,108,111,116,45,107,45,50,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,43,173,17,24,0,0,32,0,108,111,116,45,107,45,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,168,217,94,49,0,0,32,0,108,111,116,45,98,45,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,227,205,111,139,0,0,32,0,108,111,116,45,107,45,50,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,42,239,145,231,0,0,32,0,108,111,116,45,98,45,53,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,253,33,11,17,0,0,32,0,108,111,116,45,98,45,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,60,141,216,52,0,0,32,0,108,111,116,45,107,45,55,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,189,15,239,108,0,0,32,0,108,111,116,45,107,45,55,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,238,43,68,4,0,0,32,0,18,0,0,0,255,255,255,0,0,0,0,0,19,0,0,0,255,255,245,0,0,0,0,0,0,0,0,0,254,0,4,0,216,82,6,0,18,0,0,0,1,3,3,0,96,131,8,0,18,0,0,0,1,3,2,0,248,81,6,0,18,0,0,0,1,3,1,0,176,64,8,0,18,0,0,0,1,3,0,0,128,172,6,0,0,0,0,0,254,0,4,0,128,129,4,0,18,0,0,0,1,12,8,0,192,255,2,0,18,0,0,0,1,12,12,0,208,75,4,0,18,0,0,0,1,12,4,0,8,49,4,0,18,0,0,0,1,12,0,0,152,21,4,0,0,0,0,0,254,0,16,0,32,4,2,0,18,0,0,0,2,240,160,0,8,32,4,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,176,0,96,164,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,192,0,144,102,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,208,0,176,45,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,16,0,112,169,3,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,224,0,224,127,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,32,0,192,119,3,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,48,0,136,252,1,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,240,0,32,123,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,64,0,248,116,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,144,0,192,110,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,128,0,96,102,7,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,112,0,184,105,6,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,96,0,152,96,3,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,80,0,192,100,6,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,0,0,104,151,6,0,19,0,0,0,0,4,4,0,0,0,0,0,0,0,0,0,254,0,4,0,200,87,7,0,18,0,0,0,130,48,0,0,96,164,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,130,48,16,0,176,45,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,130,48,32,0,224,127,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,130,48,48,0,32,123,8,0,19,0,0,0,0,4,4,0,0,0,0,0,0,0,0,0,254,0,4,0,160,123,6,0,18,0,0,0,130,192,192,0,192,110,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,130,192,128,0,96,102,7,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,130,192,64,0,152,96,3,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,130,192,0,0,192,100,6,0,19,0,0,0,0,4,4,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,1,1,0,96,135,7,0,19,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,200,30,2,0,19,0,0,0,1,2,0,0,120,97,1,0,19,0,0,0,1,2,2,0,96,19,1,0,0,0,0,0,254,0,2,0,96,46,8,0,19,0,0,0,1,4,4,0,208,233,4,0,19,0,0,0,1,4,0,0,72,197,4,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,8,8,0,96,135,7,0,19,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,2,0,72,4,1,0,19,0,0,0,1,16,16,0,96,135,7,0,19,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,246,3,0,19,0,0,0,1,64,64,0,96,135,7,0,19,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,128,128,0,96,135,7,0,19,0,0,0,1,128,0,0,152,182,7,0,101,112,114,45,49,51,52,50,57,46,97,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,192,101,189,9,1,0,16,1,101,112,114,45,49,51,52,51,48,46,97,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,224,159,0,81,1,0,16,1,101,112,114,45,49,51,52,49,49,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,123,22,96,81,1,0,16,1,101,112,114,45,49,51,52,49,51,46,97,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,216,59,107,101,1,0,16,1,101,112,114,45,49,51,52,49,52,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,25,36,218,218,2,0,32,0,101,112,114,45,49,51,52,49,53,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,72,44,182,187,2,0,32,0,101,112,114,45,49,51,52,49,54,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,174,219,17,29,2,0,32,0,101,112,114,45,49,51,54,48,52,46,99,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,229,200,9,64,3,0,32,0,101,112,114,45,49,51,54,48,51,46,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,78,169,80,83,3,0,32,0,109,112,114,45,49,51,52,50,52,46,99,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,32,217,152,251,3,0,32,0,109,112,114,45,49,51,52,50,49,46,97,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,144,88,199,47,3,0,32,0,109,112,114,45,49,51,52,50,53,46,99,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,137,37,37,248,3,0,32,0,109,112,114,45,49,51,52,50,50,46,97,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,77,117,160,72,3,0,32,0,109,112,114,45,49,51,52,50,54,46,99,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,37,30,251,92,3,0,32,0,109,112,114,45,49,51,52,50,51,46,97,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,157,188,91,51,3,0,32,0,101,112,114,45,49,51,52,49,55,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,73,235,123,205,4,0,16,1,109,112,114,45,49,51,52,50,48,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,228,222,224,61,19,0,64,0,109,112,114,45,49,51,52,49,57,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,10,27,2,231,19,0,64,0,109,112,114,45,49,51,52,49,56,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,77,89,50,7,19,0,64,0,51,49,55,45,48,49,54,54,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,31,150,121,131,5,0,16,1,20,0,0,0,255,255,255,0,0,0,0,0,21,0,0,0,255,255,253,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,20,0,0,0,1,15,7,0,80,252,6,0,20,0,0,0,1,15,8,0,16,242,7,0,20,0,0,0,1,15,9,0,104,236,7,0,20,0,0,0,1,15,5,0,176,51,4,0,20,0,0,0,1,15,4,0,56,24,4,0,20,0,0,0,1,15,15,0,128,230,7,0,20,0,0,0,1,15,1,0,72,216,3,0,20,0,0,0,1,15,2,0,24,188,3,0,20,0,0,0,1,15,3,0,176,162,3,0,20,0,0,0,1,15,6,0,120,211,6,0,20,0,0,0,1,15,14,0,184,164,6,0,20,0,0,0,1,15,13,0,80,74,6,0,20,0,0,0,1,15,12,0,192,32,6,0,20,0,0,0,1,15,11,0,192,234,2,0,20,0,0,0,1,15,10,0,32,242,5,0,20,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,20,0,0,0,1,240,112,0,80,252,6,0,20,0,0,0,1,240,128,0,16,242,7,0,20,0,0,0,1,240,144,0,104,236,7,0,20,0,0,0,1,240,80,0,176,51,4,0,20,0,0,0,1,240,64,0,56,24,4,0,20,0,0,0,1,240,240,0,128,230,7,0,20,0,0,0,1,240,16,0,72,216,3,0,20,0,0,0,1,240,32,0,24,188,3,0,20,0,0,0,1,240,48,0,176,162,3,0,20,0,0,0,1,240,96,0,120,211,6,0,20,0,0,0,1,240,224,0,184,164,6,0,20,0,0,0,1,240,208,0,80,74,6,0,20,0,0,0,1,240,192,0,192,32,6,0,20,0,0,0,1,240,176,0,192,234,2,0,20,0,0,0,1,240,160,0,32,242,5,0,20,0,0,0,1,240,0,0,208,236,2,0,0,0,0,0,254,0,2,0,88,131,3,0,21,0,0,0,1,1,1,0,96,135,7,0,21,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,21,0,0,0,1,2,2,0,96,135,7,0,21,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,8,0,72,202,5,0,21,0,0,0,1,28,24,0,80,246,3,0,21,0,0,0,1,28,20,0,120,103,7,0,21,0,0,0,1,28,12,0,160,246,1,0,21,0,0,0,1,28,28,0,248,38,7,0,21,0,0,0,1,28,16,0,112,212,3,0,21,0,0,0,1,28,4,0,48,90,7,0,21,0,0,0,1,28,8,0,248,160,5,0,21,0,0,0,1,28,0,0,168,83,7,0,0,0,0,0,254,0,2,0,240,98,1,0,21,0,0,0,1,32,0,0,96,135,7,0,21,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,8,93,1,0,21,0,0,0,1,64,0,0,136,86,1,0,21,0,0,0,1,64,64,0,232,78,1,0,0,0,0,0,103,57,54,48,53,57,46,97,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,122,98,80,149,1,0,16,1,103,57,54,48,54,48,46,100,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,70,70,198,90,1,0,16,1,103,57,54,48,54,49,46,101,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,32,229,184,157,1,0,16,1,103,57,54,48,54,50,46,104,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,58,139,142,124,1,0,16,1,103,57,54,48,54,51,46,106,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,147,231,97,250,1,0,16,1,103,57,54,48,54,52,46,108,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,137,243,151,247,1,0,16,1,103,57,53,57,52,56,46,110,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,146,198,160,216,4,0,32,0,103,57,53,57,52,57,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,82,165,96,54,4,0,32,0,103,57,53,57,52,54,46,106,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,45,27,182,115,4,0,32,0,103,57,53,57,52,55,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,226,103,255,114,4,0,32,0,103,57,54,48,108,101,118,46,99,108,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,190,187,254,1,7,0,32,0,13,0,0,0,255,255,0,0,0,0,0,0,14,0,0,0,255,255,0,0,0,0,0,0,15,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,16,227,4,0,15,0,0,0,1,8,0,0,96,135,7,0,15,0,0,0,1,8,8,0,152,182,7,0,21,0,0,0,255,255,247,0,0,0,0,0,22,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,21,0,0,0,1,3,3,0,8,49,4,0,21,0,0,0,1,3,2,0,152,21,4,0,21,0,0,0,1,3,1,0,72,246,3,0,21,0,0,0,1,3,0,0,72,0,3,0,0,0,0,0,254,0,2,0,64,37,5,0,21,0,0,0,1,4,4,0,72,102,2,0,21,0,0,0,1,4,0,0,64,119,7,0,0,0,0,0,254,0,2,0,168,234,7,0,21,0,0,0,1,8,8,0,96,135,7,0,21,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,21,0,0,0,1,16,16,0,96,135,7,0,21,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,0,0,24,73,2,0,21,0,0,0,1,128,128,0,56,111,3,0,21,0,0,0,1,128,0,0,104,134,3,0,0,0,0,0,254,0,0,0,200,87,7,0,22,0,0,0,1,3,1,0,96,39,7,0,22,0,0,0,1,3,3,0,144,251,6,0,22,0,0,0,1,3,2,0,184,164,6,0,22,0,0,0,1,3,0,0,16,227,4,0,0,0,0,0,254,0,2,0,160,123,6,0,22,0,0,0,1,12,4,0,96,39,7,0,22,0,0,0,1,12,12,0,144,251,6,0,22,0,0,0,1,12,0,0,120,211,6,0,22,0,0,0,1,12,8,0,184,164,6,0,0,0,0,0,254,0,4,0,88,160,1,0,22,0,0,0,1,16,16,0,136,86,1,0,22,0,0,0,1,16,0,0,232,78,1,0,0,0,0,0,254,0,4,0,72,202,5,0,22,0,0,0,1,32,32,0,80,246,3,0,22,0,0,0,1,32,0,0,112,212,3,0,0,0,0,0,254,0,2,0,128,250,1,0,22,0,0,0,1,64,64,0,96,135,7,0,22,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,128,240,1,0,22,0,0,0,1,128,128,0,96,135,7,0,22,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,97,95,114,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,244,196,193,12,0,0,16,1,97,95,114,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,107,12,39,75,0,0,16,1,97,95,114,55,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,180,94,254,171,0,0,16,1,97,95,114,56,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,169,155,123,126,0,0,16,1,97,95,114,57,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,30,127,115,102,0,0,16,1,97,95,110,55,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,83,90,145,19,0,0,16,1,98,95,97,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,247,60,221,199,0,0,32,0,98,95,104,57,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,74,100,232,31,0,0,32,0,98,95,104,49,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,46,200,125,95,0,0,32,0,98,95,104,49,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,67,22,116,70,0,0,32,0,98,95,97,54,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,28,242,137,22,0,0,32,0,98,95,97,55,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,9,201,39,245,0,0,32,0,98,95,97,56,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,41,134,97,141,0,0,32,0,98,95,97,57,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,85,45,126,125,0,0,32,0,98,95,97,49,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,254,50,34,241,0,0,32,0,98,95,97,49,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,61,36,9,140,0,0,32,0,56,50,115,49,50,57,46,49,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,192,10,89,64,0,0,32,0,56,50,115,49,50,57,46,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,99,179,66,229,0,0,32,0,56,50,115,49,50,57,46,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,200,111,83,117,0,0,32,0,56,50,115,49,50,51,46,53,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,81,6,143,201,0,0,32,0,109,49,46,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,1,146,163,131,0,0,32,0,101,112,108,49,48,112,56,46,50,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,44,0,0,0,191,3,188,138,0,0,0,8,101,112,108,49,50,112,54,46,57,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,52,0,0,0,248,214,11,155,0,0,0,8,101,112,108,49,50,112,54,46,57,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,52,0,0,0,13,135,174,220,0,0,0,8,18,0,0,0,255,255,191,0,0,0,0,0,19,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,18,0,0,0,1,3,3,0,8,49,4,0,18,0,0,0,1,3,2,0,152,21,4,0,18,0,0,0,1,3,1,0,72,246,3,0,18,0,0,0,1,3,0,0,72,0,3,0,0,0,0,0,254,0,2,0,24,167,2,0,18,0,0,0,1,4,4,0,8,153,2,0,18,0,0,0,1,4,0,0,248,140,2,0,0,0,0,0,254,0,2,0,232,129,2,0,18,0,0,0,1,8,8,0,96,135,7,0,18,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,2,0,112,104,5,0,18,0,0,0,1,32,32,0,96,135,7,0,18,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,200,30,2,0,18,0,0,0,1,64,0,0,120,97,1,0,18,0,0,0,1,64,64,0,96,19,1,0,0,0,0,0,254,0,2,0,72,4,1,0,18,0,0,0,1,128,128,0,96,135,7,0,18,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,8,0,200,87,7,0,19,0,0,0,1,7,2,0,224,127,8,0,19,0,0,0,1,7,1,0,136,252,1,0,19,0,0,0,1,7,7,0,32,123,8,0,19,0,0,0,1,7,6,0,192,110,8,0,19,0,0,0,1,7,5,0,96,102,7,0,19,0,0,0,1,7,4,0,184,105,6,0,19,0,0,0,1,7,3,0,192,100,6,0,19,0,0,0,1,7,0,0,104,151,6,0,0,0,0,0,254,0,8,0,160,123,6,0,19,0,0,0,1,56,0,0,96,164,8,0,19,0,0,0,1,56,8,0,144,102,8,0,19,0,0,0,1,56,16,0,176,45,8,0,19,0,0,0,1,56,24,0,224,127,8,0,19,0,0,0,1,56,56,0,32,123,8,0,19,0,0,0,1,56,32,0,232,143,1,0,19,0,0,0,1,56,48,0,192,110,8,0,19,0,0,0,1,56,40,0,96,102,7,0,114,111,109,97,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,225,33,148,39,0,0,16,1,108,114,45,97,45,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,115,4,242,150,0,0,16,1,114,111,109,97,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,173,75,70,60,0,0,16,1,114,111,109,97,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,224,248,157,137,0,0,16,1,108,114,45,97,45,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,205,172,150,122,0,0,16,1,108,114,45,97,45,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,57,57,127,63,0,0,16,1,108,114,45,101,45,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,141,181,249,36,0,0,32,0,108,114,45,101,45,50,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,8,94,23,67,0,0,32,0,108,114,45,101,45,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,36,113,49,224,0,0,32,0,108,114,45,98,45,52,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,62,64,65,129,0,0,32,0,108,114,45,98,45,51,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,84,65,21,85,0,0,32,0,108,114,45,98,45,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,208,52,78,146,0,0,32,0,108,114,45,101,45,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,22,4,4,83,0,0,32,0,108,114,45,98,45,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,37,28,174,75,0,0,32,0,108,114,45,101,45,51,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,55,96,120,103,0,0,32,0,108,114,45,98,45,49,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,148,219,211,156,0,0,32,0,108,114,45,101,45,51,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,55,104,113,91,0,0,32,0,108,114,45,98,45,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,154,207,216,8,0,0,32,0,108,114,45,98,45,53,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,226,105,31,224,0,0,32,0,108,114,45,98,45,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,60,141,216,52,0,0,32,0,108,114,52,45,97,45,52,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,191,233,131,83,0,0,16,1,108,114,52,45,97,45,52,100,46,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,54,250,138,41,0,0,16,1,108,114,52,45,118,45,52,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,189,138,36,139,0,0,16,1,108,114,52,45,97,45,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,69,212,198,134,0,0,16,1,108,114,52,45,97,45,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,10,108,124,9,0,0,16,1,108,114,52,45,118,45,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,10,230,24,65,0,0,32,0,108,114,52,45,118,45,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,181,181,43,84,0,0,32,0,108,114,52,45,118,45,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,108,38,101,199,0,0,32,0,108,114,52,45,98,45,52,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,12,98,254,231,0,0,32,0,108,114,52,45,98,45,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,219,3,4,111,0,0,32,0,108,114,52,45,98,45,51,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,27,186,31,173,0,0,32,0,108,114,52,45,98,45,52,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,171,143,86,14,0,0,32,0,108,114,52,45,98,45,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,105,54,197,130,0,0,32,0,108,114,52,45,98,45,52,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,82,19,122,118,0,0,32,0,108,114,52,45,118,45,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,29,191,81,254,0,0,32,0,108,114,52,45,98,45,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,208,23,141,93,0,0,32,0,108,114,52,45,118,45,49,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,229,88,6,218,0,0,32,0,108,114,52,45,98,45,49,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,210,41,17,218,0,0,32,0,108,114,52,45,118,45,49,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,190,62,242,13,0,0,32,0,108,114,52,45,98,45,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,146,182,137,13,0,0,32,0,108,114,52,45,98,45,53,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,226,105,31,224,0,0,32,0,108,114,52,45,98,45,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,60,141,216,52,0,0,32,0,108,114,52,45,118,45,52,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,233,75,103,223,0,0,0,8,18,0,0,0,255,255,255,0,0,0,0,0,19,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,216,238,6,0,18,0,0,0,1,1,1,0,248,81,6,0,18,0,0,0,1,1,0,0,176,64,8,0,0,0,0,0,254,0,2,0,88,41,7,0,18,0,0,0,1,2,0,0,88,244,4,0,18,0,0,0,1,2,2,0,184,151,2,0,0,0,0,0,254,0,4,0,224,83,8,0,18,0,0,0,1,12,8,0,208,75,4,0,18,0,0,0,1,12,12,0,8,49,4,0,18,0,0,0,1,12,4,0,152,21,4,0,18,0,0,0,1,12,0,0,72,246,3,0,0,0,0,0,254,0,15,0,32,4,2,0,18,0,0,0,2,240,144,0,176,79,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,160,0,8,32,4,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,176,0,96,164,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,192,0,144,102,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,208,0,176,45,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,224,0,224,127,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,240,0,32,123,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,112,0,192,110,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,96,0,96,102,7,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,80,0,184,105,6,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,64,0,152,96,3,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,48,0,192,100,6,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,32,0,64,1,1,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,16,0,184,69,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,0,0,104,151,6,0,19,0,0,0,0,4,4,0,0,0,0,0,0,0,0,0,254,0,4,0,200,87,7,0,18,0,0,0,130,48,16,0,176,45,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,130,48,32,0,224,127,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,130,48,48,0,32,123,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,130,48,0,0,16,227,4,0,19,0,0,0,0,4,4,0,0,0,0,0,0,0,0,0,254,0,4,0,160,123,6,0,18,0,0,0,130,192,192,0,192,110,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,130,192,128,0,96,102,7,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,130,192,64,0,152,96,3,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,130,192,0,0,192,100,6,0,19,0,0,0,0,4,4,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,1,1,0,96,135,7,0,19,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,56,63,8,0,19,0,0,0,1,2,2,0,72,246,3,0,19,0,0,0,1,2,0,0,72,0,3,0,0,0,0,0,254,0,2,0,96,46,8,0,19,0,0,0,1,4,4,0,208,233,4,0,19,0,0,0,1,4,0,0,72,197,4,0,0,0,0,0,254,0,2,0,144,50,8,0,19,0,0,0,1,16,0,0,96,135,7,0,19,0,0,0,1,16,16,0,152,182,7,0,0,0,0,0,254,0,2,0,32,228,8,0,19,0,0,0,1,32,32,0,96,135,7,0,19,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,246,3,0,19,0,0,0,1,64,64,0,96,135,7,0,19,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,128,128,0,96,135,7,0,19,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,108,114,51,97,52,101,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,71,252,175,9,0,0,16,1,108,114,51,97,52,100,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,120,33,160,35,0,0,16,1,108,114,51,97,52,98,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,26,26,80,61,0,0,16,1,108,114,51,45,97,45,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,205,104,190,40,0,0,16,1,108,114,51,45,97,45,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,183,134,113,203,0,0,16,1,108,114,51,45,110,45,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,238,77,183,249,0,0,32,0,108,114,51,45,110,45,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,186,7,247,254,0,0,32,0,108,114,51,45,110,45,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,185,39,61,175,0,0,32,0,108,114,51,98,52,107,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,197,216,236,33,0,0,32,0,115,110,120,98,52,102,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,123,157,113,237,0,0,32,0,108,114,51,98,51,110,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,171,255,140,218,0,0,32,0,115,110,120,98,52,110,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,3,80,103,220,0,0,32,0,115,110,120,98,52,99,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,68,162,90,88,0,0,32,0,115,110,120,98,52,101,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,221,105,59,45,0,0,32,0,108,114,51,45,110,45,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,107,184,128,232,0,0,32,0,108,114,51,45,98,45,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,103,113,45,240,0,0,32,0,108,114,51,45,110,45,50,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,81,224,126,4,0,0,32,0,108,114,51,45,98,45,49,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,129,241,55,158,0,0,32,0,108,114,51,45,110,45,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,120,134,173,105,0,0,32,0,108,114,51,45,98,45,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,29,196,17,91,0,0,32,0,108,114,51,45,98,45,53,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,226,105,31,224,0,0,32,0,108,114,51,45,98,45,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,60,141,216,52,0,0,32,0,108,114,51,45,110,45,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,233,75,103,223,0,0,0,8,108,114,50,45,97,45,52,101,46,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,39,51,49,34,0,0,16,1,108,114,50,45,97,45,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,121,81,100,239,0,0,16,1,108,114,50,45,97,45,52,97,46,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,89,223,29,177,0,0,16,1,108,114,50,45,97,45,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,161,200,12,71,0,0,16,1,108,114,50,45,104,45,49,99,46,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,188,173,188,126,0,0,16,1,108,114,50,45,104,45,49,100,46,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,249,183,203,100,0,0,16,1,108,114,50,45,97,45,51,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,152,56,63,133,0,0,16,1,108,114,50,45,97,45,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,205,172,150,122,0,0,16,1,108,114,50,45,97,45,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,202,131,14,42,0,0,16,1,108,114,50,45,104,45,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,255,168,99,157,0,0,32,0,108,114,50,45,104,45,49,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,189,43,51,64,0,0,32,0,108,114,50,45,104,45,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,125,114,4,148,0,0,32,0,108,114,50,45,98,45,52,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,113,152,144,121,0,0,32,0,108,114,50,45,98,45,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,244,30,186,6,0,0,32,0,108,114,50,45,98,45,51,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,63,137,197,60,0,0,32,0,108,114,50,45,98,45,52,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,66,47,193,73,0,0,32,0,108,114,50,45,98,45,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,76,210,230,251,0,0,32,0,108,114,50,45,98,45,52,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,31,45,23,117,0,0,32,0,108,114,50,45,104,45,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,75,131,93,44,0,0,32,0,108,114,50,45,98,45,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,61,187,201,78,0,0,32,0,108,114,50,45,104,45,51,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,202,154,230,58,0,0,32,0,108,114,50,45,98,45,49,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,164,31,175,29,0,0,32,0,108,114,50,45,104,45,51,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,197,174,40,43,0,0,32,0,108,114,50,45,98,45,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,138,112,251,200,0,0,32,0,108,114,50,45,98,45,53,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,226,105,31,224,0,0,32,0,108,114,50,45,98,45,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,60,141,216,52,0,0,32,0,18,0,0,0,255,255,255,0,0,0,0,0,19,0,0,0,255,255,253,0,0,0,0,0,0,0,0,0,254,0,2,0,216,238,6,0,18,0,0,0,1,1,1,0,248,81,6,0,18,0,0,0,1,1,0,0,176,64,8,0,0,0,0,0,254,0,2,0,80,43,8,0,18,0,0,0,1,2,0,0])
.concat([112,134,3,0,18,0,0,0,1,2,2,0,64,111,3,0,0,0,0,0,254,0,4,0,128,129,4,0,18,0,0,0,1,12,8,0,208,75,4,0,18,0,0,0,1,12,12,0,8,49,4,0,18,0,0,0,1,12,4,0,152,21,4,0,18,0,0,0,1,12,0,0,72,246,3,0,0,0,0,0,254,0,15,0,32,4,2,0,18,0,0,0,2,240,144,0,176,79,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,160,0,8,32,4,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,176,0,96,164,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,192,0,144,102,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,208,0,176,45,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,224,0,224,127,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,240,0,32,123,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,112,0,192,110,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,96,0,96,102,7,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,80,0,184,105,6,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,64,0,152,96,3,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,48,0,192,100,6,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,32,0,64,1,1,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,16,0,184,69,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,0,0,104,151,6,0,19,0,0,0,0,4,4,0,0,0,0,0,0,0,0,0,254,0,4,0,200,87,7,0,18,0,0,0,130,48,16,0,176,45,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,130,48,32,0,224,127,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,130,48,48,0,32,123,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,130,48,0,0,16,227,4,0,19,0,0,0,0,4,4,0,0,0,0,0,0,0,0,0,254,0,4,0,160,123,6,0,18,0,0,0,130,192,192,0,192,110,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,130,192,128,0,96,102,7,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,130,192,64,0,152,96,3,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,130,192,0,0,192,100,6,0,19,0,0,0,0,4,4,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,1,1,0,96,135,7,0,19,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,200,30,2,0,19,0,0,0,1,2,0,0,120,97,1,0,19,0,0,0,1,2,2,0,96,19,1,0,0,0,0,0,254,0,2,0,96,46,8,0,19,0,0,0,1,4,4,0,208,233,4,0,19,0,0,0,1,4,0,0,72,197,4,0,0,0,0,0,254,0,2,0,72,4,1,0,19,0,0,0,1,16,16,0,96,135,7,0,19,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,2,0,32,228,8,0,19,0,0,0,1,32,32,0,96,135,7,0,19,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,246,3,0,19,0,0,0,1,64,64,0,96,135,7,0,19,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,128,128,0,96,135,7,0,19,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,21,0,0,0,255,255,207,0,0,0,0,0,22,0,0,0,255,255,207,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,21,0,0,0,1,3,3,0,8,49,4,0,21,0,0,0,1,3,2,0,152,21,4,0,21,0,0,0,1,3,1,0,72,246,3,0,21,0,0,0,1,3,0,0,72,0,3,0,0,0,0,0,254,0,2,0,232,168,4,0,21,0,0,0,1,4,4,0,120,7,5,0,21,0,0,0,1,4,0,0,208,26,6,0,0,0,0,0,254,0,2,0,240,83,4,0,21,0,0,0,1,8,8,0,232,23,6,0,21,0,0,0,1,8,0,0,248,211,5,0,0,0,0,0,254,0,4,0,64,37,5,0,21,0,0,0,1,12,8,0,80,167,3,0,21,0,0,0,1,12,0,0,128,141,3,0,21,0,0,0,1,12,12,0,208,213,1,0,21,0,0,0,1,12,4,0,80,202,1,0,0,0,0,0,254,0,2,0,72,202,5,0,21,0,0,0,1,64,64,0,80,246,3,0,21,0,0,0,1,64,0,0,112,212,3,0,0,0,0,0,254,0,0,0,200,87,7,0,22,0,0,0,1,3,1,0,96,39,7,0,22,0,0,0,1,3,3,0,144,251,6,0,22,0,0,0,1,3,2,0,184,164,6,0,22,0,0,0,1,3,0,0,16,227,4,0,0,0,0,0,254,0,4,0,160,123,6,0,22,0,0,0,1,12,0,0,40,88,7,0,22,0,0,0,1,12,4,0,120,211,6,0,22,0,0,0,1,12,12,0,80,74,6,0,22,0,0,0,1,12,8,0,32,242,5,0,0,0,0,0,254,0,4,0,104,159,3,0,22,0,0,0,1,48,48,0,56,111,3,0,22,0,0,0,1,48,32,0,120,170,1,0,22,0,0,0,1,48,16,0,88,239,5,0,22,0,0,0,1,48,0,0,104,134,3,0,0,0,0,0,254,0,4,0,104,159,3,0,22,0,0,0,1,64,0,0,56,111,3,0,22,0,0,0,1,64,64,0,104,134,3,0,0,0,0,0,184,40,2,0,1,0,0,0,41,39,216,0,248,191,2,0,240,167,7,0,1,0,0,0,47,39,216,0,192,135,2,0,176,163,7,0,1,0,0,0,37,39,216,0,240,108,2,0,208,158,7,0,1,0,0,0,42,39,216,0,96,82,2,0,184,154,7,0,1,0,0,0,43,39,216,0,32,56,2,0,176,108,2,0,1,0,0,0,32,39,216,0,152,30,2,0,128,98,2,0,1,0,0,0,33,39,216,0,56,126,1,0,88,212,3,0,1,0,0,0,48,38,216,0,40,185,3,0,248,5,8,0,9,0,0,0,112,39,216,0,32,58,1,0,144,250,7,0,9,0,0,0,113,39,216,0,32,58,1,0,248,241,7,0,9,0,0,0,114,39,216,0,32,58,1,0,168,86,7,0,1,0,0,0,232,47,216,0,248,191,2,0,24,38,7,0,1,0,0,0,236,47,216,0,184,160,2,0,56,210,6,0,1,0,0,0,35,48,216,0,192,135,2,0,24,163,6,0,1,0,0,0,34,48,216,0,240,108,2,0,152,122,6,0,1,0,0,0,33,48,216,0,96,82,2,0,192,72,6,0,1,0,0,0,32,48,216,0,32,56,2,0,152,31,6,0,1,0,0,0,36,48,216,0,152,30,2,0,248,97,5,0,1,0,0,0,37,48,216,0,232,10,2,0,40,246,1,0,1,0,0,0,233,47,216,0,64,246,1,0,144,236,1,0,1,0,0,0,237,47,216,0,136,224,1,0,176,223,1,0,1,0,0,0,43,48,216,0,72,198,1,0,192,209,1,0,1,0,0,0,42,48,216,0,24,182,1,0,24,198,1,0,1,0,0,0,41,48,216,0,40,167,1,0,120,189,1,0,1,0,0,0,40,48,216,0,200,149,1,0,8,182,1,0,1,0,0,0,44,48,216,0,56,126,1,0,32,167,1,0,1,0,0,0,45,48,216,0,32,101,1,0,168,132,8,0,1,0,0,0,118,47,216,0,232,209,1,0,72,126,8,0,1,0,0,0,119,47,216,0,144,189,1,0,192,122,8,0,1,0,0,0,115,47,216,0,208,174,1,0,40,116,8,0,1,0,0,0,114,47,216,0,48,160,1,0,72,110,8,0,1,0,0,0,113,47,216,0,160,140,1,0,184,102,8,0,1,0,0,0,112,47,216,0,56,112,1,0,248,93,8,0,1,0,0,0,116,47,216,0,32,92,1,0,152,86,8,0,1,0,0,0,117,47,216,0,64,77,1,0,88,212,3,0,1,0,0,0,144,46,216,0,40,185,3,0,240,152,1,0,1,0,0,0,238,47,216,0,216,70,1,0,16,17,8,0,1,0,0,0,234,47,216,0,224,12,8,0,72,65,1,0,9,0,0,0,232,48,216,0,32,58,1,0,48,50,1,0,9,0,0,0,224,48,216,0,32,58,1,0,224,41,1,0,9,0,0,0,216,48,216,0,32,58,1,0,21,0,0,0,255,255,0,0,0,0,0,0,22,0,0,0,255,255,0,0,0,0,0,0,23,0,0,0,255,255,6,0,0,0,0,0,0,0,0,0,254,0,2,0,240,98,1,0,21,0,0,0,1,1,0,0,248,38,7,0,21,0,0,0,1,1,1,0,208,212,8,0,0,0,0,0,254,0,2,0,144,212,8,0,21,0,0,0,1,2,0,0,96,135,7,0,21,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,21,0,0,0,1,4,0,0,96,135,7,0,21,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,21,0,0,0,1,8,8,0,96,135,7,0,21,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,7,0,200,87,7,0,21,0,0,0,1,48,48,0,32,136,7,0,21,0,0,0,1,48,32,0,40,88,7,0,21,0,0,0,1,48,16,0,96,39,7,0,21,0,0,0,1,48,32,0,96,39,7,0,21,0,0,0,1,48,0,0,144,251,6,0,21,0,0,0,1,48,48,0,120,211,6,0,21,0,0,0,1,48,16,0,184,164,6,0,0,0,0,0,254,0,8,0,160,123,6,0,21,0,0,0,1,192,128,0,96,39,7,0,21,0,0,0,1,192,0,0,144,251,6,0,21,0,0,0,1,192,192,0,120,211,6,0,21,0,0,0,1,192,64,0,184,164,6,0,21,0,0,0,1,192,0,0,184,164,6,0,21,0,0,0,1,192,64,0,80,74,6,0,21,0,0,0,1,192,128,0,192,32,6,0,21,0,0,0,1,192,192,0,32,242,5,0,0,0,0,0,254,0,4,0,72,202,5,0,22,0,0,0,1,3,3,0,248,160,5,0,22,0,0,0,1,3,2,0,112,212,3,0,22,0,0,0,1,3,0,0,80,124,6,0,22,0,0,0,1,3,1,0,80,246,3,0,0,0,0,0,254,0,4,0,64,37,5,0,22,0,0,0,1,12,12,0,120,7,5,0,22,0,0,0,1,12,8,0,144,227,4,0,22,0,0,0,1,12,4,0,240,191,4,0,22,0,0,0,1,12,0,0,24,160,4,0,0,0,0,0,254,0,4,0,128,129,4,0,22,0,0,0,1,48,48,0,192,255,2,0,22,0,0,0,1,48,0,0,208,75,4,0,22,0,0,0,1,48,32,0,8,49,4,0,22,0,0,0,1,48,16,0,152,21,4,0,0,0,0,0,254,0,2,0,144,246,3,0,22,0,0,0,1,64,0,0,96,135,7,0,22,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,22,0,0,0,1,128,128,0,56,111,3,0,22,0,0,0,1,128,0,0,104,134,3,0,0,0,0,0,254,0,7,0,120,185,3,0,23,0,0,0,1,15,0,0,128,242,5,0,23,0,0,0,1,15,14,0,32,192,2,0,23,0,0,0,1,15,6,0,200,211,6,0,23,0,0,0,1,15,11,0,56,50,1,0,23,0,0,0,1,15,3,0,144,45,3,0,23,0,0,0,1,15,4,0,192,20,3,0,23,0,0,0,1,15,5,0,80,65,1,0,0,0,0,0,20,0,0,0,255,255,175,0,0,0,0,0,21,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,160,123,6,0,20,0,0,0,1,3,0,0,96,39,7,0,20,0,0,0,1,3,3,0,144,251,6,0,20,0,0,0,1,3,2,0,184,164,6,0,20,0,0,0,1,3,1,0,80,74,6,0,0,0,0,0,254,0,4,0,200,87,7,0,20,0,0,0,1,12,0,0,96,39,7,0,20,0,0,0,1,12,12,0,144,251,6,0,20,0,0,0,1,12,8,0,184,164,6,0,20,0,0,0,1,12,4,0,80,74,6,0,0,0,0,0,254,0,2,0,144,212,8,0,20,0,0,0,1,32,32,0,96,135,7,0,20,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,200,30,2,0,20,0,0,0,1,64,0,0,120,97,1,0,20,0,0,0,1,64,64,0,96,19,1,0,0,0,0,0,254,0,4,0,128,129,4,0,21,0,0,0,1,3,1,0,192,255,2,0,21,0,0,0,1,3,3,0,8,49,4,0,21,0,0,0,1,3,2,0,72,246,3,0,21,0,0,0,1,3,0,0,48,176,2,0,0,0,0,0,254,0,4,0,64,37,5,0,21,0,0,0,1,12,12,0,184,237,8,0,21,0,0,0,1,12,8,0,136,230,8,0,21,0,0,0,1,12,4,0,8,222,8,0,21,0,0,0,1,12,0,0,144,213,8,0,0,0,0,0,254,0,4,0,72,202,5,0,21,0,0,0,1,48,48,0,80,246,3,0,21,0,0,0,1,48,16,0,248,38,7,0,21,0,0,0,1,48,32,0,112,212,3,0,21,0,0,0,1,48,0,0,24,99,5,0,0,0,0,0,254,0,2,0,168,234,7,0,21,0,0,0,1,64,0,0,96,135,7,0,21,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,72,84,4,0,21,0,0,0,1,128,128,0,248,38,7,0,21,0,0,0,1,128,0,0,176,64,8,0,0,0,0,0,19,0,0,0,255,255,254,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,19,0,0,0,1,1,0,0,120,97,1,0,19,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,2,2,0,96,135,7,0,19,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,4,4,0,96,135,7,0,19,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,8,0,0,96,135,7,0,19,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,19,0,0,0,1,48,16,0,96,39,7,0,19,0,0,0,1,48,48,0,144,251,6,0,19,0,0,0,1,48,0,0,120,211,6,0,19,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,19,0,0,0,1,192,64,0,96,39,7,0,19,0,0,0,1,192,192,0,144,251,6,0,19,0,0,0,1,192,0,0,120,211,6,0,19,0,0,0,1,192,128,0,184,164,6,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,3,2,0,80,246,3,0,20,0,0,0,1,3,3,0,80,124,6,0,20,0,0,0,1,3,1,0,112,212,3,0,20,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,2,0,104,159,3,0,20,0,0,0,1,128,0,0,56,111,3,0,20,0,0,0,1,128,128,0,104,134,3,0,13,0,0,0,255,255,0,0,0,0,0,0,14,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,4,0,200,87,7,0,13,0,0,0,1,3,1,0,224,67,5,0,13,0,0,0,1,3,3,0,192,135,6,0,13,0,0,0,1,3,0,0,200,201,5,0,13,0,0,0,1,3,2,0,144,127,5,0,0,0,0,0,254,0,4,0,160,123,6,0,13,0,0,0,1,12,8,0,216,36,5,0,13,0,0,0,1,12,4,0,224,67,5,0,13,0,0,0,1,12,12,0,192,135,6,0,13,0,0,0,1,12,0,0,200,201,5,0,0,0,0,0,254,0,2,0,128,129,4,0,13,0,0,0,1,16,0,0,208,75,4,0,13,0,0,0,1,16,16,0,72,246,3,0,0,0,0,0,254,0,2,0,200,30,2,0,14,0,0,0,1,1,1,0,120,97,1,0,14,0,0,0,1,1,0,0,96,19,1,0,0,0,0,0,254,0,2,0,48,18,8,0,14,0,0,0,1,32,0,0,96,135,7,0,14,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,144,3,8,0,14,0,0,0,1,128,0,0,208,75,4,0,14,0,0,0,1,128,128,0,8,49,4,0,0,0,0,0,254,0,2,0,232,21,1,0,23,0,0,0,1,4,4,0,96,135,7,0,23,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,168,86,7,0,1,0,0,0,254,0,147,0,248,191,2,0,120,248,6,0,1,0,0,0,248,0,147,0,184,160,2,0,200,245,6,0,1,0,0,0,88,248,146,0,192,135,2,0,24,163,6,0,1,0,0,0,89,248,146,0,240,108,2,0,192,72,6,0,1,0,0,0,90,248,146,0,32,56,2,0,152,122,6,0,1,0,0,0,91,248,146,0,96,82,2,0,200,110,3,0,1,0,0,0,80,240,146,0,152,30,2,0,120,89,3,0,1,0,0,0,81,240,146,0,232,10,2,0,40,246,1,0,1,0,0,0,253,0,147,0,64,246,1,0,48,245,6,0,1,0,0,0,249,0,147,0,136,224,1,0,64,98,7,0,1,0,0,0,92,248,146,0,72,198,1,0,192,209,1,0,1,0,0,0,93,248,146,0,24,182,1,0,120,189,1,0,1,0,0,0,94,248,146,0,200,149,1,0,24,198,1,0,1,0,0,0,95,248,146,0,40,167,1,0,224,22,1,0,1,0,0,0,80,237,146,0,56,126,1,0,160,14,1,0,1,0,0,0,81,237,146,0,32,101,1,0,88,212,3,0,1,0,0,0,64,220,146,0,40,185,3,0,248,5,8,0,9,0,0,0,96,6,147,0,32,58,1,0,144,250,7,0,9,0,0,0,97,6,147,0,32,58,1,0,168,86,7,0,1,0,0,0,144,240,146,0,248,191,2,0,24,38,7,0,1,0,0,0,146,240,146,0,184,160,2,0,56,210,6,0,1,0,0,0,90,1,147,0,192,135,2,0,24,163,6,0,1,0,0,0,91,1,147,0,240,108,2,0,152,122,6,0,1,0,0,0,89,1,147,0,96,82,2,0,192,72,6,0,1,0,0,0,88,1,147,0,32,56,2,0,200,110,3,0,1,0,0,0,92,1,147,0,152,30,2,0,40,246,1,0,1,0,0,0,145,240,146,0,64,246,1,0,144,236,1,0,1,0,0,0,147,240,146,0,136,224,1,0,176,223,1,0,1,0,0,0,170,248,146,0,72,198,1,0,192,209,1,0,1,0,0,0,171,248,146,0,24,182,1,0,24,198,1,0,1,0,0,0,169,248,146,0,40,167,1,0,120,189,1,0,1,0,0,0,168,248,146,0,200,149,1,0,224,22,1,0,1,0,0,0,172,248,146,0,56,126,1,0,88,212,3,0,1,0,0,0,200,220,146,0,40,185,3,0,16,17,8,0,1,0,0,0,151,240,146,0,224,12,8,0,72,65,1,0,9,0,0,0,176,6,147,0,32,58,1,0,48,50,1,0,9,0,0,0,177,6,147,0,32,58,1,0,99,56,48,45,49,54,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,82,91,121,78,2,0,16,1,99,56,48,45,49,55,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,56,168,192,66,2,0,16,1,99,56,48,45,49,50,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,239,111,212,128,2,0,16,1,99,56,48,45,49,56,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,4,41,162,174,2,0,16,1,99,56,48,45,49,53,46,55,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,215,127,170,5,9,0,16,1,99,56,48,45,48,52,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,140,254,23,154,12,0,32,0,99,56,48,45,48,53,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,113,112,222,172,12,0,32,0,99,56,48,45,48,49,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,230,130,55,244,15,0,32,0,99,56,48,45,48,50,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,97,139,10,6,15,0,32,0,99,56,48,45,48,51,46,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,213,56,153,96,24,0,64,0,37,0,0,0,255,255,127,0,0,0,0,0,38,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,128,150,4,0,37,0,0,0,1,128,128,0,56,148,4,0,37,0,0,0,1,128,0,0,136,144,4,0,0,0,0,0,254,0,2,0,144,212,8,0,37,0,0,0,1,64,64,0,96,135,7,0,37,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,37,0,0,0,1,32,32,0,96,135,7,0,37,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,37,0,0,0,1,16,0,0,96,135,7,0,37,0,0,0,1,16,16,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,37,0,0,0,1,12,0,0,16,242,7,0,37,0,0,0,1,12,8,0,104,236,7,0,37,0,0,0,1,12,12,0,128,230,7,0,37,0,0,0,1,12,4,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,37,0,0,0,1,3,0,0,16,242,7,0,37,0,0,0,1,3,2,0,104,236,7,0,37,0,0,0,1,3,3,0,128,230,7,0,37,0,0,0,1,3,1,0,184,164,6,0,0,0,0,0,254,0,4,0,72,202,5,0,38,0,0,0,1,192,64,0,80,246,3,0,38,0,0,0,1,192,192,0,248,38,7,0,38,0,0,0,1,192,128,0,112,212,3,0,38,0,0,0,1,192,0,0,248,160,5,0,0,0,0,0,254,0,4,0,48,142,4,0,38,0,0,0,1,48,0,0,56,138,4,0,38,0,0,0,1,48,48,0,8,134,4,0,38,0,0,0,1,48,32,0,24,130,4,0,38,0,0,0,1,48,16,0,136,127,4,0,0,0,0,0,254,0,4,0,200,30,2,0,38,0,0,0,1,12,12,0,240,242,5,0,38,0,0,0,1,12,4,0,136,176,4,0,38,0,0,0,1,12,8,0,72,173,4,0,38,0,0,0,1,12,0,0,80,169,4,0,0,0,0,0,254,0,2,0,104,159,3,0,38,0,0,0,1,2,0,0,96,135,7,0,38,0,0,0,1,2,2,0,152,182,7,0,104,115,50,97,100,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,113,211,83,1,1,0,16,1,104,115,50,97,100,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,138,183,118,2,1,0,16,1,104,115,50,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,53,74,227,221,1,0,16,1,104,115,50,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,218,109,229,244,1,0,16,1,104,115,50,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,252,32,68,238,1,0,16,1,104,115,50,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,51,21,68,201,1,0,16,1,104,115,50,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,56,198,63,1,0,16,1,104,115,50,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,228,249,208,32,1,0,16,1,104,115,50,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,241,245,247,111,5,0,32,0,104,115,50,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,93,47,218,38,5,0,32,0,104,115,50,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,142,238,105,231,5,0,32,0,104,115,50,46,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,7,253,71,127,5,0,32,0,104,115,50,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,51,227,73,197,5,0,32,0,104,115,50,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,249,65,133,10,5,0,32,0,104,115,50,46,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,39,43,201,244,5,0,32,0,104,115,50,46,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,117,90,53,186,5,0,32,0,104,115,50,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,134,55,161,193,10,0,16,1,104,115,50,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,170,148,135,45,10,0,16,1,104,115,50,40,95,95,104,115,102,50,100,97,41,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,150,4,176,92,12,0,64,0,104,115,50,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,7,128,41,143,12,0,64,0,37,0,0,0,255,255,255,0,0,0,0,0,38,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,104,143,6,0,37,0,0,0,1,1,1,0,216,104,6,0,37,0,0,0,1,1,0,0,240,242,5,0,0,0,0,0,254,0,2,0,232,75,4,0,37,0,0,0,1,4,4,0,96,135,7,0,37,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,37,0,0,0,1,8,0,0,96,135,7,0,37,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,37,0,0,0,1,48,16,0,96,39,7,0,37,0,0,0,1,48,48,0,144,251,6,0,37,0,0,0,1,48,0,0,120,211,6,0,37,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,37,0,0,0,1,192,64,0,96,39,7,0,37,0,0,0,1,192,192,0,144,251,6,0,37,0,0,0,1,192,0,0,120,211,6,0,37,0,0,0,1,192,128,0,184,164,6,0,0,0,0,0,254,0,4,0,72,202,5,0,38,0,0,0,1,3,2,0,80,246,3,0,38,0,0,0,1,3,3,0,80,124,6,0,38,0,0,0,1,3,1,0,112,212,3,0,38,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,200,99,6,0,38,0,0,0,1,12,12,0,128,95,6,0,38,0,0,0,1,12,4,0,104,89,6,0,38,0,0,0,1,12,8,0,232,81,6,0,38,0,0,0,1,12,0,0,144,75,6,0,0,0,0,0,254,0,2,0,40,70,6,0,38,0,0,0,1,128,0,0,120,65,6,0,38,0,0,0,1,128,128,0,80,62,6,0,22,0,0,0,255,255,191,0,0,0,0,0,23,0,0,0,255,255,253,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,22,0,0,0,1,3,2,0,208,75,4,0,22,0,0,0,1,3,3,0,8,49,4,0,22,0,0,0,1,3,1,0,152,21,4,0,22,0,0,0,1,3,0,0,72,246,3,0,0,0,0,0,254,0,4,0,72,202,5,0,22,0,0,0,1,12,0,0,160,203,8,0,22,0,0,0,1,12,8,0,80,246,3,0,22,0,0,0,1,12,12,0,248,38,7,0,22,0,0,0,1,12,4,0,112,212,3,0,0,0,0,0,254,0,2,0,168,131,2,0,22,0,0,0,1,16,0,0,56,111,3,0,22,0,0,0,1,16,16,0,104,134,3,0,0,0,0,0,254,0,2,0,104,159,3,0,22,0,0,0,1,32,0,0,56,111,3,0,22,0,0,0,1,32,32,0,104,134,3,0,0,0,0,0,254,0,3,0,200,30,2,0,23,0,0,0,1,6,4,0,120,97,1,0,23,0,0,0,1,6,0,0,64,201,8,0,23,0,0,0,1,6,6,0,96,19,1,0,18,0,0,0,255,255,255,0,0,0,0,0,19,0,0,0,255,255,79,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,18,0,0,0,1,15,2,0,80,252,6,0,18,0,0,0,1,15,5,0,16,242,7,0,18,0,0,0,1,15,8,0,104,236,7,0,18,0,0,0,1,15,4,0,120,113,6,0,18,0,0,0,1,15,1,0,232,228,5,0,18,0,0,0,1,15,15,0,128,230,7,0,18,0,0,0,1,15,3,0,56,141,7,0,18,0,0,0,1,15,7,0,120,211,6,0,18,0,0,0,1,15,14,0,184,164,6,0,18,0,0,0,1,15,6,0,24,1,7,0,18,0,0,0,1,15,13,0,80,74,6,0,18,0,0,0,1,15,12,0,192,32,6,0,18,0,0,0,1,15,11,0,192,234,2,0,18,0,0,0,1,15,10,0,32,242,5,0,18,0,0,0,1,15,9,0,176,192,2,0,18,0,0,0,1,15,0,0,16,227,4,0,0,0,0,0,254,0,16,0,160,123,6,0,18,0,0,0,1,240,32,0,80,252,6,0,18,0,0,0,1,240,80,0,16,242,7,0,18,0,0,0,1,240,128,0,104,236,7,0,18,0,0,0,1,240,64,0,120,113,6,0,18,0,0,0,1,240,16,0,232,228,5,0,18,0,0,0,1,240,240,0,128,230,7,0,18,0,0,0,1,240,48,0,56,141,7,0,18,0,0,0,1,240,112,0,120,211,6,0,18,0,0,0,1,240,224,0,184,164,6,0,18,0,0,0,1,240,96,0,24,1,7,0,18,0,0,0,1,240,208,0,80,74,6,0,18,0,0,0,1,240,192,0,192,32,6,0,18,0,0,0,1,240,176,0,192,234,2,0,18,0,0,0,1,240,160,0,32,242,5,0,18,0,0,0,1,240,144,0,176,192,2,0,18,0,0,0,1,240,0,0,16,227,4,0,0,0,0,0,254,0,8,0,72,202,5,0,19,0,0,0,1,112,112,0,160,246,1,0,19,0,0,0,1,112,96,0,160,203,8,0,19,0,0,0,1,112,80,0,80,246,3,0,19,0,0,0,1,112,64,0,80,124,6,0,19,0,0,0,1,112,48,0,248,176,4,0,19,0,0,0,1,112,32,0,112,212,3,0,19,0,0,0,1,112,16,0,24,99,5,0,19,0,0,0,1,112,0,0,248,160,5,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,128,128,0,96,135,7,0,19,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,20,0,0,0,1,1,1,0,96,135,7,0,20,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,20,0,0,0,1,4,4,0,96,135,7,0,20,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,168,86,7,0,1,0,0,0,206,251,146,0,248,191,2,0,24,38,7,0,1,0,0,0,205,251,146,0,184,160,2,0,56,210,6,0,1,0,0,0,200,251,146,0,192,135,2,0,24,163,6,0,1,0,0,0,201,251,146,0,240,108,2,0,152,122,6,0,1,0,0,0,202,251,146,0,96,82,2,0,192,72,6,0,1,0,0,0,203,251,146,0,32,56,2,0,200,110,3,0,1,0,0,0,204,251,146,0,152,30,2,0,120,89,3,0,1,0,0,0,207,251,146,0,232,10,2,0,88,212,3,0,1,0,0,0,128,216,146,0,40,185,3,0,72,65,1,0,9,0,0,0,224,3,147,0,32,58,1,0,16,0,0,0,255,255,129,0,0,0,0,0,0,0,0,0,254,0,0,0,128,129,4,0,16,0,0,0,1,2,0,0,8,49,4,0,16,0,0,0,1,2,2,0,72,246,3,0,0,0,0,0,254,0,2,0,8,99,2,0,16,0,0,0,1,12,0,0,24,205,7,0,16,0,0,0,1,12,4,0,192,255,2,0,16,0,0,0,1,12,8,0,208,75,4,0,16,0,0,0,1,12,12,0,8,49,4,0,0,0,0,0,254,0,4,0,32,4,2,0,16,0,0,0,1,112,112,0,96,135,3,0,16,0,0,0,1,112,80,0,32,136,7,0,16,0,0,0,1,112,48,0,40,88,7,0,16,0,0,0,1,112,16,0,96,39,7,0,16,0,0,0,1,112,0,0,144,251,6,0,16,0,0,0,1,112,32,0,184,164,6,0,16,0,0,0,1,112,64,0,80,74,6,0,16,0,0,0,1,112,96,0,192,32,6,0,0,0,0,0,254,0,8,0,200,30,2,0,16,0,0,0,1,128,128,0,120,97,1,0,16,0,0,0,1,128,0,0,96,19,1,0,0,0,0,0,113,50,45,48,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,218,225,201,102,0,0,16,1,113,50,45,48,54,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,22,153,195,95,0,0,16,1,113,50,45,48,55,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,94,94,109,236,0,0,16,1,113,50,45,48,56,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,60,218,128,108,0,0,32,0,113,50,45,48,57,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,92,225,227,171,0,0,32,0,113,50,45,49,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,13,69,99,105,0,0,32,0,113,50,45,49,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,162,159,49,30,0,0,32,0,113,50,45,49,56,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,201,224,110,190,0,0,32,0,113,50,45,49,57,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,69,4,48,112,0,0,32,0,113,50,45,50,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,66,255,166,33,0,0,32,0,113,50,45,50,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,201,128,98,7,0,0,32,0,113,50,45,49,54,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,240,178,25,236,0,0,32,0,113,50,45,49,55,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,146,157,214,236,0,0,32,0,113,50,45,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,137,122,158,20,0,0,64,0,18,0,0,0,255,255,191,0,0,0,0,0,19,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,104,159,3,0,18,0,0,0,1,32,0,0,56,111,3,0,18,0,0,0,1,32,32,0,104,134,3,0,0,0,0,0,254,0,2,0,168,234,7,0,18,0,0,0,1,64,64,0,96,135,7,0,18,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,18,0,0,0,1,128,128,0,96,135,7,0,18,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,1,1,0,96,135,7,0,19,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,128,184,7,0,19,0,0,0,1,2,2,0,96,135,7,0,19,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,96,46,8,0,19,0,0,0,1,8,8,0,192,255,2,0,19,0,0,0,1,8,0,0,208,75,4,0,0,0,0,0,254,0,16,0,32,4,2,0,19,0,0,0,1,240,160,0,144,160,3,0,19,0,0,0,1,240,176,0,96,135,3,0,19,0,0,0,1,240,192,0,32,136,7,0,19,0,0,0,1,240,208,0,40,88,7,0,19,0,0,0,1,240,224,0,96,39,7,0,19,0,0,0,1,240,16,0,32,202,2,0,19,0,0,0,1,240,48,0,120,113,6,0,19,0,0,0,1,240,32,0,232,228,5,0,19,0,0,0,1,240,240,0,144,251,6,0,19,0,0,0,1,240,64,0,120,211,6,0,19,0,0,0,1,240,144,0,184,164,6,0,19,0,0,0,1,240,128,0,80,74,6,0,19,0,0,0,1,240,112,0,192,32,6,0,19,0,0,0,1,240,96,0,192,234,2,0,19,0,0,0,1,240,80,0,32,242,5,0,19,0,0,0,1,240,0,0,16,227,4,0,0,0,0,0,101,112,114,45,54,57,49,56,97,46,105,99,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,176,194,177,32,1,0,16,1,101,112,114,45,54,57,49,54,97,46,105,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,191,177,157,125,1,0,16,1,101,112,114,45,54,57,49,55,97,46,105,99,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,103,35,161,254,1,0,16,1,101,112,114,45,54,57,49,53,97,46,105,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,64,50,136,172,1,0,16,1,101,112,114,45,54,57,50,48,46,105,99,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,62,1,149,28,9,0,16,1,101,112,114,45,54,57,49,57,46,105,99,53,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,105,13,163,108,9,0,16,1,101,112,114,45,54,56,52,49,46,105,99,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,220,149,210,84,2,0,32,0,101,112,114,45,54,56,52,50,46,105,99,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,104,181,119,246,2,0,32,0,101,112,114,45,54,56,52,51,46,105,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,218,240,87,162,2,0,32,0,101,112,114,45,54,56,49,57,46,105,99,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,7,173,157,70,3,0,32,0,101,112,114,45,54,56,50,48,46,105,99,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,222,198,203,135,3,0,32,0,101,112,114,45,54,56,50,49,46,105,99,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,105,41,121,21,3,0,32,0,101,112,114,45,54,56,50,50,46,105,99,51,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,229,141,113,233,3,0,32,0,101,112,114,45,54,56,50,51,46,105,99,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,145,38,66,73,3,0,32,0,101,112,114,45,54,56,50,52,46,105,99,51,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,164,234,29,112,3,0,32,0,101,112,114,45,54,56,50,53,46,105,99,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,180,200,35,110,3,0,32,0,101,112,114,45,54,56,50,54,46,105,99,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,44,222,208,119,3,0,32,0,101,112,114,45,54,56,50,55,46,105,99,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,182,191,161,127,3,0,32,0,101,112,114,45,54,56,50,56,46,105,99,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,147,12,136,142,3,0,32,0,101,112,114,45,54,56,50,57,46,105,99,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,45,149,160,124,3,0,32,0,101,112,114,45,54,56,51,48,46,105,99,51,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,239,58,166,177,3,0,32,0,101,112,114,45,54,56,52,53,46,105,99,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,184,201,8,186,3,0,32,0,101,112,114,45,54,56,52,54,46,105,99,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,163,87,30,242,3,0,32,0,101,112,114,45,54,56,52,48,46,105,99,49,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,227,48,18,88,10,0,32,0,101,112,114,45,54,56,51,51,46,105,99,55,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,95,47,148,59,4,0,16,1,101,112,114,45,54,56,51,49,46,105,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,129,84,239,207,11,0,64,0,101,112,114,45,54,56,51,50,46,105,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,165,174,101,65,11,0,64,0,101,112,114,45,54,56,52,52,46,105,99,49,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,214,123,236,227,16,0,32,0,9,0,0,0,255,255,255,0,0,0,0,0,10,0,0,0,255,255,254,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,9,0,0,0,1,15,7,0,80,252,6,0,9,0,0,0,1,15,8,0,16,242,7,0,9,0,0,0,1,15,9,0,104,236,7,0,9,0,0,0,1,15,5,0,176,51,4,0,9,0,0,0,1,15,4,0,56,24,4,0,9,0,0,0,1,15,15,0,128,230,7,0,9,0,0,0,1,15,1,0,72,216,3,0,9,0,0,0,1,15,2,0,24,188,3,0,9,0,0,0,1,15,3,0,176,162,3,0,9,0,0,0,1,15,6,0,120,211,6,0,9,0,0,0,1,15,14,0,184,164,6,0,9,0,0,0,1,15,13,0,80,74,6,0,9,0,0,0,1,15,12,0,192,32,6,0,9,0,0,0,1,15,11,0,192,234,2,0,9,0,0,0,1,15,10,0,32,242,5,0,9,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,9,0,0,0,1,240,112,0,80,252,6,0,9,0,0,0,1,240,128,0,16,242,7,0,9,0,0,0,1,240,144,0,104,236,7,0,9,0,0,0,1,240,80,0,176,51,4,0,9,0,0,0,1,240,64,0,56,24,4,0,9,0,0,0,1,240,240,0,128,230,7,0,9,0,0,0,1,240,16,0,72,216,3,0,9,0,0,0,1,240,32,0,24,188,3,0,9,0,0,0,1,240,48,0,176,162,3,0,9,0,0,0,1,240,96,0,120,211,6,0,9,0,0,0,1,240,224,0,184,164,6,0,9,0,0,0,1,240,208,0,80,74,6,0,9,0,0,0,1,240,192,0,192,32,6,0,9,0,0,0,1,240,176,0,192,234,2,0,9,0,0,0,1,240,160,0,32,242,5,0,9,0,0,0,1,240,0,0,208,236,2,0,0,0,0,0,254,0,2,0,168,234,7,0,10,0,0,0,1,1,1,0,96,135,7,0,10,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,10,0,0,0,1,6,4,0,80,246,3,0,10,0,0,0,1,6,6,0,80,124,6,0,10,0,0,0,1,6,2,0,112,212,3,0,10,0,0,0,1,6,0,0,248,160,5,0,0,0,0,0,254,0,4,0,40,252,8,0,10,0,0,0,1,24,24,0,248,38,7,0,10,0,0,0,1,24,16,0,80,124,6,0,10,0,0,0,1,24,8,0,112,212,3,0,10,0,0,0,1,24,0,0,248,160,5,0,0,0,0,0,254,0,2,0,184,10,1,0,10,0,0,0,1,32,0,0,96,135,7,0,10,0,0,0,1,32,32,0,152,182,7,0,16,0,0,0,255,255,255,0,0,0,0,0,17,0,0,0,255,255,59,0,0,0,0,0,18,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,16,0,0,0,1,15,2,0,184,220,8,0,16,0,0,0,1,15,5,0,88,154,8,0,16,0,0,0,1,15,8,0,200,92,8,0,16,0,0,0,1,15,4,0,152,141,7,0,16,0,0,0,1,15,1,0,80,65,7,0,16,0,0,0,1,15,15,0,104,172,6,0,16,0,0,0,1,15,3,0,192,233,6,0,16,0,0,0,1,15,7,0,24,46,7,0,16,0,0,0,1,15,14,0,216,129,6,0,16,0,0,0,1,15,6,0,208,168,7,0,16,0,0,0,1,15,13,0,184,81,6,0,16,0,0,0,1,15,12,0,48,39,6,0,16,0,0,0,1,15,11,0,160,221,5,0,16,0,0,0,1,15,10,0,96,183,5,0,16,0,0,0,1,15,9,0,96,144,5,0,16,0,0,0,1,15,0,0,16,227,4,0,0,0,0,0,254,0,16,0,160,123,6,0,16,0,0,0,1,240,32,0,184,220,8,0,16,0,0,0,1,240,80,0,88,154,8,0,16,0,0,0,1,240,128,0,200,92,8,0,16,0,0,0,1,240,64,0,152,141,7,0,16,0,0,0,1,240,16,0,80,65,7,0,16,0,0,0,1,240,240,0,104,172,6,0,16,0,0,0,1,240,48,0,192,233,6,0,16,0,0,0,1,240,112,0,24,46,7,0,16,0,0,0,1,240,224,0,216,129,6,0,16,0,0,0,1,240,96,0,208,168,7,0,16,0,0,0,1,240,208,0,184,81,6,0,16,0,0,0,1,240,192,0,48,39,6,0,16,0,0,0,1,240,176,0,160,221,5,0,16,0,0,0,1,240,160,0,96,183,5,0,16,0,0,0,1,240,144,0,96,144,5,0,16,0,0,0,1,240,0,0,16,227,4,0,0,0,0,0,254,0,4,0,128,129,4,0,17,0,0,0,1,3,3,0,8,49,4,0,17,0,0,0,1,3,2,0,152,21,4,0,17,0,0,0,1,3,1,0,72,246,3,0,17,0,0,0,1,3,0,0,216,128,5,0,0,0,0,0,254,0,2,0,200,30,2,0,17,0,0,0,1,4,0,0,120,97,1,0,17,0,0,0,1,4,4,0,96,19,1,0,0,0,0,0,254,0,2,0,64,37,5,0,17,0,0,0,1,8,8,0,48,223,2,0,17,0,0,0,1,8,0,0,184,201,2,0,0,0,0,0,254,0,8,0,72,202,5,0,17,0,0,0,1,112,112,0,72,198,6,0,17,0,0,0,1,112,96,0,208,75,4,0,17,0,0,0,1,112,80,0,8,49,4,0,17,0,0,0,1,112,64,0,152,21,4,0,17,0,0,0,1,112,48,0,200,148,3,0,17,0,0,0,1,112,32,0,72,0,3,0,17,0,0,0,1,112,16,0,64,47,7,0,17,0,0,0,1,112,0,0,48,173,6,0,0,0,0,0,254,0,2,0,168,234,7,0,17,0,0,0,1,128,128,0,96,135,7,0,17,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,112,167,5,0,18,0,0,0,1,1,1,0,96,135,7,0,18,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,184,40,2,0,1,0,0,0,122,83,148,0,248,191,2,0,56,250,6,0,1,0,0,0,120,83,148,0,184,160,2,0,184,164,8,0,1,0,0,0,123,83,148,0,64,246,1,0,88,149,7,0,1,0,0,0,121,83,148,0,136,224,1,0,56,210,6,0,1,0,0,0,136,83,148,0,192,135,2,0,24,163,6,0,1,0,0,0,137,83,148,0,240,108,2,0,152,122,6,0,1,0,0,0,138,83,148,0,96,82,2,0,192,72,6,0,1,0,0,0,139,83,148,0,32,56,2,0,48,123,2,0,1,0,0,0,141,83,148,0,152,30,2,0,96,69,2,0,1,0,0,0,140,83,148,0,232,10,2,0,176,223,1,0,1,0,0,0,128,83,148,0,72,198,1,0,192,209,1,0,1,0,0,0,129,83,148,0,24,182,1,0,24,198,1,0,1,0,0,0,130,83,148,0,40,167,1,0,120,189,1,0,1,0,0,0,131,83,148,0,200,149,1,0,248,187,8,0,1,0,0,0,133,83,148,0,56,126,1,0,184,179,8,0,1,0,0,0,132,83,148,0,32,101,1,0,88,212,3,0,1,0,0,0,192,228,148,0,40,185,3,0,16,17,8,0,1,0,0,0,126,83,148,0,224,12,8,0,80,251,6,0,1,0,0,0,124,83,148,0,216,70,1,0,56,58,1,0,1,0,0,0,125,83,148,0,64,50,1,0,248,5,8,0,9,0,0,0,16,71,215,0,32,58,1,0,109,50,112,48,97,49,46,117,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,94,29,62,129,0,0,16,1,109,50,112,49,97,49,46,117,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,102,54,230,190,0,0,16,1,109,50,100,48,120,48,46,117,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,255,6,26,46,0,0,16,8,109,50,45,50,48,48,45,48,46,117,52,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,83,252,170,147,0,0,32,0,109,50,45,50,48,49,45,48,46,117,53,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,131,10,182,57,0,0,32,0,109,50,45,50,48,50,45,48,46,117,53,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,57,179,6,253,0,0,32,0,109,50,115,48,97,49,46,117,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,113,113,151,152,0,0,32,0,109,50,115,49,97,49,46,117,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,46,115,154,198,0,0,32,0,109,50,45,51,48,48,45,48,46,117,56,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,187,47,196,77,0,0,32,0,109,50,45,51,48,49,45,48,46,117,57,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,242,148,232,244,0,0,32,0,109,50,98,48,120,48,46,117,57,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,27,213,35,224,0,0,32,0,109,50,98,49,120,48,46,117,57,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,219,139,196,3,0,0,32,0,109,50,45,49,48,48,45,48,46,117,52,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,69,250,80,82,0,0,64,0,109,50,119,49,97,49,46,117,52,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,66,83,242,21,0,0,64,0,109,50,112,48,120,49,46,117,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,102,95,82,0,0,16,1,109,50,112,49,120,49,46,117,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,229,131,70,145,0,0,16,1,109,50,100,48,120,48,46,117,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,255,6,26,46,0,0,16,8,109,50,45,50,48,48,45,48,46,117,52,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,83,252,170,147,0,0,32,0,109,50,45,50,48,49,45,48,46,117,53,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,131,10,182,57,0,0,32,0,109,50,45,50,48,50,45,48,46,117,53,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,57,179,6,253,0,0,32,0,109,50,115,48,120,49,46,117,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,199,214,105,64,0,0,32,0,109,50,115,49,120,49,46,117,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,105,226,63,197,0,0,32,0,109,50,45,51,48,48,45,48,46,117,56,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,187,47,196,77,0,0,32,0,109,50,45,51,48,49,45,48,46,117,57,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,242,148,232,244,0,0,32,0,109,50,98,48,120,48,46,117,57,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,27,213,35,224,0,0,32,0,109,50,98,49,120,48,46,117,57,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,219,139,196,3,0,0,32,0,109,50,45,49,48,48,45,48,46,117,52,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,69,250,80,82,0,0,64,0,109,50,119,49,120,48,46,117,52,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,197,19,5,27,0,0,64,0,99,55,52,45,49,48,46,105,99,53,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,11,162,129,202,2,0,16,1,99,55,52,45,48,56,46,105,99,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,158,221,53,170,2,0,16,1,99,55,52,45,49,49,46,105,99,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,213,214,59,238,2,0,16,1,99,55,52,45,49,51,46,105,99,54,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,81,126,197,193,2,0,16,1,99,55,52,45,49,50,46,105,99,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,104,214,110,187,9,0,16,1,99,55,52,45,48,49,46,105,99,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,128,206,52,52,11,0,32,0,99,55,52,45,48,51,46,105,99,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,81,137,13,26,15,0,32,0,99,55,52,45,48,50,46,105,99,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,6,21,162,21,15,0,32,0,99,55,52,45,48,52,46,105,99,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,242,237,151,45,24,0,64,0,99,55,52,45,48,53,46,105,99,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,40,8,156,226,25,0,64,0,40,0,0,0,255,255,255,0,0,0,0,0,41,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,40,0,0,0,1,2,2,0,96,135,7,0,40,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,40,0,0,0,1,4,4,0,96,135,7,0,40,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,40,0,0,0,1,8,0,0,96,135,7,0,40,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,32,4,2,0,40,0,0,0,1,48,0,0,80,252,6,0,40,0,0,0,1,48,16,0,16,242,7,0,40,0,0,0,1,48,32,0,104,236,7,0,40,0,0,0,1,48,48,0,128,230,7,0,0,0,0,0,254,0,4,0,168,248,6,0,40,0,0,0,1,192,0,0,16,242,7,0,40,0,0,0,1,192,64,0,104,236,7,0,40,0,0,0,1,192,128,0,80,245,6,0,40,0,0,0,1,192,192,0,240,240,6,0,0,0,0,0,254,0,4,0,72,202,5,0,41,0,0,0,1,3,2,0,80,246,3,0,41,0,0,0,1,3,3,0,248,38,7,0,41,0,0,0,1,3,1,0,112,212,3,0,41,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,64,251,5,0,41,0,0,0,1,48,48,0,240,242,5,0,41,0,0,0,1,48,32,0,136,176,4,0,41,0,0,0,1,48,16,0,72,173,4,0,41,0,0,0,1,48,0,0,80,169,4,0,0,0,0,0,254,0,2,0,160,164,4,0,41,0,0,0,1,64,0,0,96,135,7,0,41,0,0,0,1,64,64,0,152,182,7,0,15,0,0,0,255,255,151,0,0,0,0,0,16,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,8,0,72,202,5,0,15,0,0,0,1,7,7,0,192,255,2,0,15,0,0,0,1,7,6,0,208,75,4,0,15,0,0,0,1,7,5,0,8,49,4,0,15,0,0,0,1,7,4,0,152,21,4,0,15,0,0,0,1,7,3,0,72,246,3,0,15,0,0,0,1,7,2,0,72,0,3,0,15,0,0,0,1,7,1,0,64,47,7,0,15,0,0,0,1,7,0,0,232,99,5,0,0,0,0,0,254,0,2,0,168,234,7,0,15,0,0,0,1,8,8,0,96,135,7,0,15,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,15,0,0,0,1,48,48,0,192,255,2,0,15,0,0,0,1,48,32,0,208,75,4,0,15,0,0,0,1,48,16,0,8,49,4,0,15,0,0,0,1,48,0,0,152,21,4,0,0,0,0,0,254,0,4,0,32,4,2,0,15,0,0,0,1,192,0,0,40,88,7,0,15,0,0,0,1,192,64,0,96,39,7,0,15,0,0,0,1,192,128,0,144,251,6,0,15,0,0,0,1,192,192,0,144,253,5,0,0,0,0,0,254,0,2,0,176,208,5,0,16,0,0,0,1,1,1,0,96,135,7,0,16,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,192,169,5,0,16,0,0,0,1,2,2,0,96,135,7,0,16,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,192,133,5,0,16,0,0,0,1,4,0,0,96,135,7,0,16,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,16,0,0,0,1,128,128,0,96,135,7,0,16,0,0,0,1,128,0,0,152,182,7,0,184,40,2,0,1,0,0,0,214,155,215,0,248,191,2,0,56,250,6,0,1,0,0,0,211,155,215,0,184,160,2,0,184,164,8,0,1,0,0,0,215,155,215,0,64,246,1,0,8,3,3,0,4,0,0,0,112,156,215,0,208,13,4,0,248,230,7,0,4,0,0,0,104,156,215,0,184,198,5,0,184,171,7,0,4,0,0,0,96,156,215,0,136,191,7,0,176,108,2,0,1,0,0,0,212,155,215,0,152,30,2,0,128,98,2,0,1,0,0,0,213,155,215,0,232,10,2,0,48,82,2,0,1,0,0,0,208,155,215,0,152,138,8,0,16,17,8,0,1,0,0,0,210,155,215,0,224,12,8,0,32,77,1,0,1,0,0,0,209,155,215,0,216,70,1,0,88,212,3,0,1,0,0,0,200,154,215,0,40,185,3,0,248,5,8,0,9,0,0,0,0,156,215,0,32,58,1,0,144,250,7,0,9,0,0,0,1,156,215,0,32,58,1,0,103,105,110,107,117,110,48,49,46,105,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,213,111,148,152,0,0,16,1,103,105,110,107,117,110,48,50,46,105,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,246,87,135,233,0,0,16,1,103,105,110,107,117,110,48,51,46,105,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,223,224,86,68,0,0,32,0,103,105,110,107,117,110,48,53,46,105,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,66,189,99,18,0,0,32,0,103,105,110,107,117,110,48,52,46,105,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,17,246,76,158,0,0,32,0,103,105,110,107,117,110,48,57,46,105,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,185,132,51,35,0,0,32,0,103,105,110,107,117,110,48,54,46,105,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,132,145,88,248,0,0,32,0,103,105,110,107,117,110,48,55,46,105,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,170,177,54,136,0,0,80,0,103,105,110,107,117,110,48,56,46,105,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,199,131,117,139,0,0,64,0,17,0,0,0,255,255,255,0,0,0,0,0,18,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,120,183,1,0,17,0,0,0,1,3,3,0,80,245,6,0,17,0,0,0,1,3,2,0,8,201,6,0,17,0,0,0,1,3,1,0,200,197,6,0,17,0,0,0,1,3,0,0,152,194,6,0,0,0,0,0,254,0,4,0,96,176,1,0,17,0,0,0,1,12,0,0,80,252,6,0,17,0,0,0,1,12,4,0,16,242,7,0,17,0,0,0,1,12,8,0,104,236,7,0,17,0,0,0,1,12,12,0,80,245,6,0,0,0,0,0,254,0,2,0,240,169,1,0,17,0,0,0,1,16,16,0,96,135,7,0,17,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,18,0,0,0,1,3,0,0,208,75,4,0,18,0,0,0,1,3,3,0,8,49,4,0,18,0,0,0,1,3,2,0,152,21,4,0,18,0,0,0,1,3,1,0,72,246,3,0,0,0,0,0,254,0,4,0,72,202,5,0,18,0,0,0,1,12,8,0,80,246,3,0,18,0,0,0,1,12,12,0,248,38,7,0,18,0,0,0,1,12,4,0,112,212,3,0,18,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,2,0,144,212,8,0,18,0,0,0,1,16,16,0,96,135,7,0,18,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,18,0,0,0,1,32,0,0,96,135,7,0,18,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,168,86,7,0,1,0,0,0,83,191,145,0,248,191,2,0,24,38,7,0,1,0,0,0,85,191,145,0,184,160,2,0,56,210,6,0,1,0,0,0,88,251,146,0,192,135,2,0,24,163,6,0,1,0,0,0,89,251,146,0,240,108,2,0,152,122,6,0,1,0,0,0,90,251,146,0,96,82,2,0,192,72,6,0,1,0,0,0,91,251,146,0,32,56,2,0,200,110,3,0,1,0,0,0,92,251,146,0,152,30,2,0,120,89,3,0,1,0,0,0,93,251,146,0,232,10,2,0,40,246,1,0,1,0,0,0,84,191,145,0,64,246,1,0,144,236,1,0,1,0,0,0,86,191,145,0,136,224,1,0,176,223,1,0,1,0,0,0,40,243,146,0,72,198,1,0,192,209,1,0,1,0,0,0,41,243,146,0,24,182,1,0,24,198,1,0,1,0,0,0,42,243,146,0,40,167,1,0,120,189,1,0,1,0,0,0,43,243,146,0,200,149,1,0,224,22,1,0,1,0,0,0,44,243,146,0,56,126,1,0,160,14,1,0,1,0,0,0,45,243,146,0,32,101,1,0,88,212,3,0,1,0,0,0,8,216,146,0,40,185,3,0,16,17,8,0,1,0,0,0,80,191,145,0,224,12,8,0,56,58,1,0,1,0,0,0,81,191,145,0,64,50,1,0,72,65,1,0,9,0,0,0,131,223,146,0,32,58,1,0,48,50,1,0,9,0,0,0,132,223,146,0,32,58,1,0,224,41,1,0,9,0,0,0,133,223,146,0,32,58,1,0,100,109,101,95,50,57,46,49,48,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,162,88,106,22,1,0,16,1,100,109,101,95,51,48,46,49,48,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,122,64,200,122,1,0,16,1,100,109,101,95,50,55,46,57,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,190,178,52,247,1,0,16,1,100,109,101,95,50,56,46,57,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,20,231,211,3,1,0,16,1,100,109,45,49,55,46,55,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,242,176,161,62,2,0,16,1,100,109,45,48,53,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,176,192,169,11,4,0,32,0,100,109,45,48,55,46,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,185,10,118,93,4,0,32,0,100,109,45,48,54,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,89,11,169,75,4,0,32,0,100,109,45,48,56,46,51,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,222,233,222,75,4,0,32,0,48,57,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,25,187,36,174,4,0,32,0,49,56,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,26,39,78,211,4,0,32,0,49,51,46,52,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,55,221,112,63,4,0,32,0,50,50,46,55,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,230,226,105,126,4,0,32,0,49,49,46,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,198,182,201,55,4,0,32,0,50,48,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,180,69,19,47,4,0,32,0,49,53,46,52,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,42,33,42,60,4,0,32,0,50,52,46,55,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,5,172,154,136,4,0,32,0,49,48,46,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,140,242,192,188,4,0,32,0,49,57,46,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,106,22,64,42,4,0,32,0,49,52,46,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,3,92,248,32,4,0,32,0,50,51,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,75,20,38,132,4,0,32,0,49,50,46,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,97,141,8,218,4,0,32,0,50,49,46,55,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,240,29,225,23,4,0,32,0,49,54,46,52,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,28,186,135,241,4,0,32,0,50,53,46,55,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,120,156,247,41,4,0,32,0,50,54,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,229,246,146,54,3,0,16,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,100,109,54,50,48,46,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,39,247,229,246,0,0,0,8,108,119,105,111,46,56,105,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,12,185,82,173,0,0,0,8,18,0,0,0,255,255,0,0,0,0,0,0,19,0,0,0,255,255,0,0,0,0,0,0,20,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,8,0,200,87,7,0,18,0,0,0,1,7,7,0,80,252,6,0,18,0,0,0,1,7,6,0,16,242,7,0,18,0,0,0,1,7,5,0,104,236,7,0,18,0,0,0,1,7,0,0,128,230,7,0,18,0,0,0,1,7,1,0,184,164,6,0,18,0,0,0,1,7,2,0,80,74,6,0,18,0,0,0,1,7,3,0,192,32,6,0,18,0,0,0,1,7,4,0,32,242,5,0,0,0,0,0,254,0,8,0,160,123,6,0,18,0,0,0,1,56,56,0,80,252,6,0,18,0,0,0,1,56,48,0,16,242,7,0,18,0,0,0,1,56,40,0,104,236,7,0,18,0,0,0,1,56,0,0,128,230,7,0,18,0,0,0,1,56,8,0,184,164,6,0,18,0,0,0,1,56,16,0,80,74,6,0,18,0,0,0,1,56,24,0,192,32,6,0,18,0,0,0,1,56,32,0,32,242,5,0,0,0,0,0,254,0,3,0,200,30,2,0,18,0,0,0,1,192,0,0,72,60,1,0,18,0,0,0,1,192,64,0,88,51,1,0,18,0,0,0,1,192,192,0,96,19,1,0,0,0,0,0,254,0,8,0,72,202,5,0,19,0,0,0,1,7,3,0,72,198,6,0,19,0,0,0,1,7,2,0,208,75,4,0,19,0,0,0,1,7,1,0,8,49,4,0,19,0,0,0,1,7,0,0,72,195,6,0,19,0,0,0,1,7,4,0,72,246,3,0,19,0,0,0,1,7,5,0,72,0,3,0,19,0,0,0,1,7,6,0,64,47,7,0,19,0,0,0,1,7,7,0,48,173,6,0,0,0,0,0,254,0,4,0,64,37,5,0,19,0,0,0,1,48,16,0,200,75,1,0,19,0,0,0,1,48,32,0,48,75,1,0,19,0,0,0,1,48,0,0,144,74,1,0,19,0,0,0,1,48,48,0,32,73,1,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,3,0,0,8,49,4,0,20,0,0,0,1,3,1,0,152,21,4,0,20,0,0,0,1,3,2,0,72,246,3,0,20,0,0,0,1,3,3,0,72,0,3,0,0,0,0,0,254,0,2,0,120,207,1,0,20,0,0,0,1,16,0,0,96,135,7,0,20,0,0,0,1,16,16,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,20,0,0,0,1,64,64,0,96,135,7,0,20,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,79,2,0,20,0,0,0,1,128,0,0,32,182,8,0,20,0,0,0,1,128,128,0,80,251,6,0,0,0,0,0,17,0,0,0,255,255,240,0,0,0,0,0,18,0,0,0,255,255,191,0,0,0,0,0,0,0,0,0,254,0,2,0,168,234,7,0,17,0,0,0,1,32,0,0,96,135,7,0,17,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,17,0,0,0,1,64,64,0,96,135,7,0,17,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,18,0,0,0,1,3,1,0,192,255,2,0,18,0,0,0,1,3,3,0,8,49,4,0,18,0,0,0,1,3,2,0,72,246,3,0,18,0,0,0,1,3,0,0,48,176,2,0,0,0,0,0,254,0,4,0,72,202,5,0,18,0,0,0,1,12,4,0,80,246,3,0,18,0,0,0,1,12,12,0,248,38,7,0,18,0,0,0,1,12,8,0,112,212,3,0,18,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,4,0,56,58,7,0,18,0,0,0,1,48,0,0,168,51,7,0,18,0,0,0,1,48,16,0,240,46,7,0,18,0,0,0,1,48,48,0,112,40,7,0,18,0,0,0,1,48,32,0,240,35,7,0,0,0,0,0,254,0,2,0,104,159,3,0,18,0,0,0,1,64,64,0,56,111,3,0,18,0,0,0,1,64,0,0,104,134,3,0,0,0,0,0,254,0,2,0,128,33,7,0,18,0,0,0,1,128,0,0,72,29,7,0,18,0,0,0,1,128,128,0,248,38,7,0,0,0,0,0,17,0,0,0,255,255,0,0,0,0,0,0,18,0,0,0,255,255,0,0,0,0,0,0,19,0,0,0,255,255,0,0,0,0,0,0,20,0,0,0,255,255,0,0,0,0,0,0,17,0,0,0,254,0,8,0,200,87,7,0,17,0,0,0,1,7,6,0,160,36,8,0,17,0,0,0,1,7,0,0,208,239,7,0,17,0,0,0,1,7,7,0,16,79,1,0,17,0,0,0,1,7,1,0,120,187,7,0,17,0,0,0,1,7,2,0,136,23,1,0,17,0,0,0,1,7,3,0,88,217,6,0,17,0,0,0,1,7,4,0,32,15,1,0,17,0,0,0,1,7,5,0,80,177,6,0,17,0,0,0,254,0,2,0,176,206,4,0,17,0,0,0,1,8,0,0,184,172,4,0,17,0,0,0,1,8,8,0,56,141,4,0,18,0,0,0,254,0,8,0,160,123,6,0,18,0,0,0,1,7,6,0,160,36,8,0,18,0,0,0,1,7,0,0,208,239,7,0,18,0,0,0,1,7,7,0,16,79,1,0,18,0,0,0,1,7,1,0,120,187,7,0,18,0,0,0,1,7,2,0,136,23,1,0,18,0,0,0,1,7,3,0,88,217,6,0,18,0,0,0,1,7,4,0,32,15,1,0,18,0,0,0,1,7,5,0,80,177,6,0,18,0,0,0,254,0,2,0,48,87,4,0,18,0,0,0,1,8,0,0,56,111,3,0,18,0,0,0,1,8,8,0,104,134,3,0,19,0,0,0,254,0,4,0,128,129,4,0,19,0,0,0,1,3,3,0,208,75,4,0,19,0,0,0,1,3,0,0,8,49,4,0,19,0,0,0,1,3,1,0,152,21,4,0,19,0,0,0,1,3,2,0,72,246,3,0,19,0,0,0,254,0,4,0,72,202,5,0,19,0,0,0,1,12,0,0,80,246,3,0,19,0,0,0,1,12,4,0,248,38,7,0,19,0,0,0,1,12,8,0,112,212,3,0,19,0,0,0,1,12,12,0,248,160,5,0,20,0,0,0,254,0,8,0,64,37,5,0,20,0,0,0,1,7,0,0,88,8,3,0,20,0,0,0,1,7,1,0,248,242,2,0,20,0,0,0,1,7,2,0,168,219,2,0,20,0,0,0,1,7,3,0,8,49,6,0,20,0,0,0,1,7,4,0,160,191,4,0,20,0,0,0,1,7,5,0,240,159,4,0,20,0,0,0,1,7,6,0,200,143,2,0,20,0,0,0,1,7,7,0,120,7,5,0,20,0,0,0,254,0,2,0,168,234,7,0,20,0,0,0,1,8,8,0,96,135,7,0,20,0,0,0,1,8,0,0,152,182,7,0,49,51,54,48,51,55,45,49,51,48,55,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,67,135,254,70,0,0,16,1,49,51,54,48,51,55,45,49,51,48,56,46,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,196,21,110,39,0,0,16,1,49,51,54,48,52,51,45,49,49,48,53,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,71,218,223,69,0,0,16,1,49,51,54,48,52,51,45,49,49,48,54,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,156,2,60,52,0,0,16,1,49,51,54,48,52,51,45,49,49,48,57,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,163,169,160,88,0,0,16,1,49,51,54,48,52,51,45,49,49,49,48,46,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,168,13,143,101,0,0,16,1,49,51,54,48,52,51,45,49,49,50,49,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,186,27,48,174,0,0,16,1,49,51,54,48,52,51,45,49,49,50,50,46,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,138,170,74,233,0,0,16,1,49,51,54,48,52,51,45,49,49,50,48,46,49,54,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,6,16,115,92,0,0,16,1,49,51,54,48,52,51,45,49,49,49,57,46,49,54,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,231,145,53,220,0,0,16,1,49,51,54,48,52,51,45,49,49,48,52,46,54,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,111,207,67,19,0,0,32,0,49,51,54,48,52,51,45,49,49,49,49,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,128,0,0,35,110,223,9,0,0,32,0,49,51,54,48,51,55,45,49,49,50,46,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,190,48,147,134,0,0,32,0,49,51,54,48,52,51,45,49,49,50,51,46,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,1,143,201,228,0,0,32,0,49,51,54,48,52,51,45,49,49,49,51,46,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,110,71,203,51,0,0,32,0,49,51,54,48,51,55,45,49,49,52,46,49,109,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,130,152,239,41,0,0,32,0,49,51,54,48,52,51,45,49,49,50,52,46,49,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,121,120,133,196,0,0,32,0,49,51,54,48,52,51,45,49,49,49,53,46,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,3,37,30,247,0,0,32,0,49,51,54,48,51,55,45,49,49,54,46,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,91,172,224,17,0,0,32,0,49,51,54,48,52,51,45,49,49,50,53,46,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,209,194,194,217,0,0,32,0,49,51,54,48,52,51,45,49,49,49,55,46,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,233,178,48,158,0,0,32,0,49,51,54,48,51,55,45,49,49,56,46,50,109,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,99,178,243,139,0,0,32,0,49,51,54,48,52,51,45,49,49,50,54,46,50,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,42,115,44,163,0,0,32,0,55,52,115,52,55,50,45,49,51,54,48,51,55,45,49,48,49,46,55,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,111,247,100,41,0,0,32,0,55,52,115,52,55,50,45,49,51,54,48,51,55,45,49,48,50,46,53,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,108,236,79,77,0,0,32,0,55,52,115,50,56,55,45,49,51,54,48,51,55,45,49,48,51,46,52,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,8,207,92,108,0,0,32,0,101,112,114,49,48,50,53,53,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,107,42,40,137,0,0,16,1,101,112,114,49,48,50,53,52,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,216,182,38,40,0,0,16,1,101,112,114,49,48,50,53,51,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,15,38,17,121,0,0,16,1,101,112,114,49,48,50,52,51,46,49,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,96,6,34,135,0,0,16,1,101,112,114,49,48,50,52,57,46,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,242,208,10,78,0,0,32,0,101,112,114,49,48,50,52,56,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,36,209,21,53,0,0,32,0,101,112,114,49,48,50,52,55,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,85,21,30,84,0,0,32,0,101,112,114,49,48,50,51,52,46,49,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,51,237,106,138,0,0,32,0,101,112,114,49,48,50,51,51,46,49,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,211,132,39,197,0,0,32,0,101,112,114,49,48,50,51,54,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,39,178,90,179,0,0,32,0,101,112,114,49,48,50,51,53,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,81,49,106,0,0,0,32,0,98,112,114,111,109,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,114,15,238,142,0,0,32,0,98,112,114,111,109,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,215,171,123,62,0,0,32,0,98,112,114,111,109,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,166,68,28,55,0,0,32,0,112,114,53,51,49,55,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,184,80,131,100,0,0,0,8,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,124,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,19,0,0,0,1,15,7,0,80,252,6,0,19,0,0,0,1,15,8,0,16,242,7,0,19,0,0,0,1,15,9,0,104,236,7,0,19,0,0,0,1,15,5,0,192,54,8,0,19,0,0,0,1,15,4,0,56,24,4,0,19,0,0,0,1,15,15,0,128,230,7,0,19,0,0,0,1,15,0,0,128,230,7,0,19,0,0,0,1,15,3,0,176,162,3,0,19,0,0,0,1,15,2,0,24,188,3,0,19,0,0,0,1,15,1,0,72,216,3,0,19,0,0,0,1,15,6,0,120,211,6,0,19,0,0,0,1,15,14,0,184,164,6,0,19,0,0,0,1,15,13,0,80,74,6,0,19,0,0,0,1,15,12,0,192,32,6,0,19,0,0,0,1,15,11,0,192,234,2,0,19,0,0,0,1,15,10,0,32,242,5,0,0,0,0,0,254,0,16,0,160,123,6,0,19,0,0,0,1,240,112,0,80,252,6,0,19,0,0,0,1,240,128,0,16,242,7,0,19,0,0,0,1,240,144,0,104,236,7,0,19,0,0,0,1,240,80,0,192,54,8,0,19,0,0,0,1,240,64,0,56,24,4,0,19,0,0,0,1,240,240,0,128,230,7,0,19,0,0,0,1,240,0,0,128,230,7,0,19,0,0,0,1,240,48,0,176,162,3,0,19,0,0,0,1,240,32,0,24,188,3,0,19,0,0,0,1,240,16,0,72,216,3,0,19,0,0,0,1,240,96,0,120,211,6,0,19,0,0,0,1,240,224,0,184,164,6,0,19,0,0,0,1,240,208,0,80,74,6,0,19,0,0,0,1,240,192,0,192,32,6,0,19,0,0,0,1,240,176,0,192,234,2,0,19,0,0,0,1,240,160,0,32,242,5,0,0,0,0,0,254,0,2,0,200,30,2,0,20,0,0,0,1,1,0,0,120,97,1,0,20,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,2,0,168,234,7,0,20,0,0,0,1,2,2,0,96,135,7,0,20,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,12,12,0,8,49,4,0,20,0,0,0,1,12,8,0,152,21,4,0,20,0,0,0,1,12,4,0,72,246,3,0,20,0,0,0,1,12,0,0,112,49,6,0,0,0,0,0,254,0,4,0,64,37,5,0,20,0,0,0,1,48,48,0,104,61,5,0,20,0,0,0,1,48,32,0,72,59,5,0,20,0,0,0,1,48,16,0,184,56,5,0,20,0,0,0,1,48,0,0,120,7,5,0,0,0,0,0,254,0,2,0,72,202,5,0,20,0,0,0,1,64,64,0,80,246,3,0,20,0,0,0,1,64,0,0,112,212,3,0,0,0,0,0,22,0,0,0,255,255,191,0,0,0,0,0,23,0,0,0,255,255,249,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,22,0,0,0,1,3,2,0,208,75,4,0,22,0,0,0,1,3,3,0,8,49,4,0,22,0,0,0,1,3,1,0,152,21,4,0,22,0,0,0,1,3,0,0,72,246,3,0,0,0,0,0,254,0,4,0,72,202,5,0,22,0,0,0,1,12,0,0,160,203,8,0,22,0,0,0,1,12,8,0,80,246,3,0,22,0,0,0,1,12,12,0,248,38,7,0,22,0,0,0,1,12,4,0,112,212,3,0,0,0,0,0,254,0,0,0,104,159,3,0,22,0,0,0,1,32,0,0,56,111,3,0,22,0,0,0,1,32,32,0,104,134,3,0,0,0,0,0,254,0,2,0,144,212,8,0,23,0,0,0,1,1,1,0,96,135,7,0,23,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,200,30,2,0,23,0,0,0,1,6,0,0,120,97,1,0,23,0,0,0,1,6,2,0,64,201,8,0,23,0,0,0,1,6,6,0,96,19,1,0,103,97,108,108,97,103,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,67,247,160,163,0,0,16,1,103,97,108,108,97,103,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,167,96,218,94,0,0,16,1,103,97,108,108,97,103,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,3,229,60,117,0,0,16,1,103,97,108,108,97,103,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,66,68,135,131,0,0,16,1,103,97,108,108,97,103,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,205,252,2,49,0,0,16,1,103,97,108,108,97,103,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,141,8,149,137,0,0,16,1,103,97,108,108,97,103,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,188,112,27,0,0,0,16,1,103,97,108,108,97,103,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,164,152,154,22,0,0,32,0,103,97,108,108,97,103,46,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,128,124,68,173,0,0,32,0,103,97,108,108,97,103,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,252,26,111,221,0,0,32,0,112,114,111,109,45,53,46,53,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,107,60,96,84,0,0,32,0,112,114,111,109,45,52,46,50,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,171,237,182,89,0,0,32,0,112,114,111,109,45,51,46,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,107,187,4,74,0,0,32,0,112,114,111,109,45,49,46,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,180,21,40,122,0,0,32,0,112,114,111,109,45,50,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,32,0,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,16,175,117,217,1,0,16,1,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,195,20,237,178,1,0,16,1,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,96,65,95,148,1,0,16,1,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,234,19,122,223,1,0,16,1,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,162,40,97,255,1,0,16,1,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,137,163,21,217,1,0,16,1,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,70,83,36,201,1,0,16,1,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,199,69,125,121,1,0,16,1,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,147,123,23,48,4,0,32,0,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,175,50,97,194,4,0,32,0,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,19,204,141,126,4,0,32,0,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,59,179,194,220,4,0,32,0,108,48,54,95,112,114,111,109,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,135,125,12,106,7,0,32,0,103,97,108,120,46,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,125,0,228,121,1,0,16,1,103,97,108,120,46,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,78,6,22,188,1,0,16,1,103,97,108,120,46,119,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,238,211,210,114,1,0,16,1,103,97,108,120,46,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,243,151,227,175,1,0,16,1,103,97,108,120,46,122,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,60,13,140,119,1,0,16,1,103,97,108,120,46,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,84,6,129,232,4,0,32,0,103,97,108,120,46,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,118,74,232,203,4,0,32,0,54,108,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,103,148,172,195,7,0,32,0,103,97,108,110,97,109,99,111,46,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,1,229,253,172,1,0,16,1,103,97,108,110,97,109,99,111,46,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,119,60,207,101,1,0,16,1,103,97,108,110,97,109,99,111,46,119,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,230,154,239,158,1,0,16,1,103,97,108,110,97,109,99,111,46,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,209,221,165,86,1,0,16,1,103,97,108,110,97,109,99,111,46,122,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,98,114,188,244,1,0,16,1,103,97,108,120,95,52,99,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,180,138,232,213,4,0,32,0,103,97,108,120,95,52,99,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,228,131,123,165,4,0,32,0,54,108,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,103,148,172,195,7,0,32,0,55,102,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,222,177,53,67,1,0,16,1,103,97,108,97,120,105,97,110,46,119,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,192,49,112,76,1,0,16,1,103,97,108,120,95,49,95,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,158,29,30,231,1,0,16,1,103,97,108,120,95,49,95,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,178,163,101,110,1,0,16,1,103,97,108,109,105,100,119,46,49,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,152,207,222,132,4,0,32,0,103,97,108,109,105,100,119,46,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,158,218,26,195,4,0,32,0,54,108,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,103,148,172,195,7,0,32,0,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,1,0,0,96,135,7,0,19,0,0,0,1,1,1,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,2,2,0,96,135,7,0,19,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,8,0,200,87,7,0,19,0,0,0,1,224,0,0,104,54,4,0,19,0,0,0,1,224,128,0,232,228,5,0,19,0,0,0,1,224,64,0,16,242,7,0,19,0,0,0,1,224,32,0,104,236,7,0,19,0,0,0,1,224,224,0,128,230,7,0,19,0,0,0,1,224,96,0,184,164,6,0,19,0,0,0,1,224,160,0,80,74,6,0,19,0,0,0,1,224,192,0,192,32,6,0,0,0,0,0,254,0,8,0,160,123,6,0,19,0,0,0,1,28,0,0,104,54,4,0,19,0,0,0,1,28,16,0,232,228,5,0,19,0,0,0,1,28,8,0,16,242,7,0,19,0,0,0,1,28,4,0,104,236,7,0,19,0,0,0,1,28,28,0,128,230,7,0,19,0,0,0,1,28,12,0,184,164,6,0,19,0,0,0,1,28,20,0,80,74,6,0,19,0,0,0,1,28,24,0,192,32,6,0,0,0,0,0,254,0,4,0,104,115,3,0,20,0,0,0,1,48,0,0,208,75,4,0])
.concat([20,0,0,0,1,48,48,0,8,49,4,0,20,0,0,0,1,48,16,0,152,21,4,0,20,0,0,0,1,48,32,0,72,246,3,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,192,0,0,192,255,2,0,20,0,0,0,1,192,192,0,208,75,4,0,20,0,0,0,1,192,64,0,8,49,4,0,20,0,0,0,1,192,128,0,152,21,4,0,20,0,0,0,255,255,255,0,0,0,0,0,21,0,0,0,255,255,66,0,0,0,0,0,22,0,0,0,255,255,253,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,20,0,0,0,1,15,2,0,248,223,6,0,20,0,0,0,1,15,5,0,88,179,6,0,20,0,0,0,1,15,8,0,32,136,6,0,20,0,0,0,1,15,4,0,120,113,6,0,20,0,0,0,1,15,1,0,232,228,5,0,20,0,0,0,1,15,15,0,120,90,6,0,20,0,0,0,1,15,3,0,56,141,7,0,20,0,0,0,1,15,7,0,120,211,6,0,20,0,0,0,1,15,14,0,184,164,6,0,20,0,0,0,1,15,6,0,24,1,7,0,20,0,0,0,1,15,13,0,80,74,6,0,20,0,0,0,1,15,12,0,192,32,6,0,20,0,0,0,1,15,11,0,192,234,2,0,20,0,0,0,1,15,10,0,32,242,5,0,20,0,0,0,1,15,9,0,176,192,2,0,20,0,0,0,1,15,0,0,16,227,4,0,0,0,0,0,254,0,16,0,160,123,6,0,20,0,0,0,1,240,32,0,248,223,6,0,20,0,0,0,1,240,80,0,88,179,6,0,20,0,0,0,1,240,128,0,32,136,6,0,20,0,0,0,1,240,64,0,120,113,6,0,20,0,0,0,1,240,16,0,232,228,5,0,20,0,0,0,1,240,240,0,120,90,6,0,20,0,0,0,1,240,48,0,56,141,7,0,20,0,0,0,1,240,112,0,120,211,6,0,20,0,0,0,1,240,224,0,184,164,6,0,20,0,0,0,1,240,96,0,24,1,7,0,20,0,0,0,1,240,208,0,80,74,6,0,20,0,0,0,1,240,192,0,192,32,6,0,20,0,0,0,1,240,176,0,192,234,2,0,20,0,0,0,1,240,160,0,32,242,5,0,20,0,0,0,1,240,144,0,176,192,2,0,20,0,0,0,1,240,0,0,168,165,2,0,0,0,0,0,254,0,4,0,104,115,3,0,21,0,0,0,1,3,3,0,80,0,4,0,21,0,0,0,1,3,2,0,248,168,7,0,21,0,0,0,1,3,1,0,32,235,8,0,21,0,0,0,1,3,0,0,152,195,2,0,0,0,0,0,254,0,4,0,72,202,5,0,21,0,0,0,1,96,96,0,80,246,3,0,21,0,0,0,1,96,64,0,248,38,7,0,21,0,0,0,1,96,32,0,48,123,8,0,21,0,0,0,1,96,0,0,8,117,8,0,0,0,0,0,254,0,2,0,168,234,7,0,21,0,0,0,1,128,128,0,96,135,7,0,21,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,22,0,0,0,1,1,1,0,96,135,7,0,22,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,22,0,0,0,1,4,4,0,96,135,7,0,22,0,0,0,1,4,0,0,152,182,7,0,8,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,8,0,0,0,1,1,0,0,96,135,7,0,8,0,0,0,1,1,1,0,152,182,7,0,0,0,0,0,254,0,2,0,72,202,5,0,8,0,0,0,1,4,0,0,80,246,3,0,8,0,0,0,1,4,4,0,112,212,3,0,0,0,0,0,254,0,2,0,128,129,4,0,8,0,0,0,1,8,0,0,8,49,4,0,8,0,0,0,1,8,8,0,72,246,3,0,0,0,0,0,254,0,4,0,64,37,5,0,8,0,0,0,1,48,0,0,176,116,6,0,8,0,0,0,1,48,16,0,176,180,7,0,8,0,0,0,1,48,32,0,24,225,3,0,8,0,0,0,1,48,48,0,48,173,7,0,0,0,0,0,254,0,4,0,32,4,2,0,8,0,0,0,1,192,128,0,104,236,7,0,8,0,0,0,1,192,0,0,80,245,6,0,8,0,0,0,1,192,64,0,8,201,6,0,8,0,0,0,1,192,192,0,16,227,4,0,101,112,114,45,49,50,53,57,57,98,46,97,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,84,243,227,38,1,0,16,1,101,112,114,45,49,50,53,57,56,98,46,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,125,201,242,192,1,0,16,1,111,112,114,45,49,50,53,57,51,46,97,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,216,130,5,204,2,0,32,0,111,112,114,45,49,50,53,57,52,46,97,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,21,72,252,139,2,0,32,0,111,112,114,45,49,50,53,57,53,46,97,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,11,214,24,91,2,0,32,0,111,112,114,45,49,50,53,57,54,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,243,65,64,74,3,0,32,0,111,112,114,45,49,50,53,57,55,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,118,230,97,105,3,0,32,0,101,112,114,45,49,50,53,57,50,46,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,187,17,140,154,4,0,16,1,51,49,55,45,48,49,50,55,97,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,66,0,219,90,5,0,16,1,17,0,0,0,255,255,253,0,0,0,0,0,18,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,168,234,7,0,17,0,0,0,1,2,2,0,96,135,7,0,17,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,17,0,0,0,1,48,32,0,80,246,3,0,17,0,0,0,1,48,48,0,248,38,7,0,17,0,0,0,1,48,16,0,112,212,3,0,17,0,0,0,1,48,0,0,248,160,5,0,0,0,0,0,254,0,2,0,192,247,2,0,17,0,0,0,1,64,0,0,192,255,2,0,17,0,0,0,1,64,64,0,208,75,4,0,0,0,0,0,254,0,2,0,120,246,2,0,17,0,0,0,1,128,0,0,96,135,7,0,17,0,0,0,1,128,128,0,152,182,7,0,0,0,0,0,254,0,16,0,200,87,7,0,18,0,0,0,1,15,7,0,80,252,6,0,18,0,0,0,1,15,8,0,16,242,7,0,18,0,0,0,1,15,9,0,104,236,7,0,18,0,0,0,1,15,5,0,176,51,4,0,18,0,0,0,1,15,4,0,56,24,4,0,18,0,0,0,1,15,15,0,128,230,7,0,18,0,0,0,1,15,1,0,72,216,3,0,18,0,0,0,1,15,2,0,24,188,3,0,18,0,0,0,1,15,3,0,176,162,3,0,18,0,0,0,1,15,6,0,120,211,6,0,18,0,0,0,1,15,14,0,184,164,6,0,18,0,0,0,1,15,13,0,80,74,6,0,18,0,0,0,1,15,12,0,192,32,6,0,18,0,0,0,1,15,11,0,192,234,2,0,18,0,0,0,1,15,10,0,32,242,5,0,18,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,18,0,0,0,1,240,112,0,80,252,6,0,18,0,0,0,1,240,128,0,16,242,7,0,18,0,0,0,1,240,144,0,104,236,7,0,18,0,0,0,1,240,80,0,176,51,4,0,18,0,0,0,1,240,64,0,56,24,4,0,18,0,0,0,1,240,240,0,128,230,7,0,18,0,0,0,1,240,16,0,72,216,3,0,18,0,0,0,1,240,32,0,24,188,3,0,18,0,0,0,1,240,48,0,176,162,3,0,18,0,0,0,1,240,96,0,120,211,6,0,18,0,0,0,1,240,224,0,184,164,6,0,18,0,0,0,1,240,208,0,80,74,6,0,18,0,0,0,1,240,192,0,192,32,6,0,18,0,0,0,1,240,176,0,192,234,2,0,18,0,0,0,1,240,160,0,32,242,5,0,18,0,0,0,1,240,0,0,208,236,2,0,101,112,114,53,57,55,56,97,46,49,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,146,20,111,41,0,0,16,1,101,112,114,53,57,55,57,97,46,49,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,249,62,176,100,0,0,16,1,101,112,114,45,53,56,54,57,46,49,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,78,13,34,109,0,0,16,1,101,112,114,45,53,56,54,56,46,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,107,37,2,116,0,0,32,0,101,112,114,45,53,56,54,55,46,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,48,233,92,47,0,0,32,0,101,112,114,45,53,56,54,54,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,154,29,127,150,0,0,32,0,101,112,114,45,53,56,54,53,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,76,163,217,3,0,0,32,0,101,112,114,45,53,56,54,52,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,88,243,89,230,0,0,32,0,101,112,114,45,53,56,54,51,46,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,21,202,150,164,0,0,32,0,101,112,114,45,53,56,53,53,46,49,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,161,148,248,181,0,0,32,0,101,112,114,45,53,56,53,54,46,49,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,143,247,106,38,0,0,32,0,112,114,45,53,51,49,55,46,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,184,80,131,100,0,0,0,8,13,0,0,0,255,255,255,0,0,0,0,0,14,0,0,0,255,255,254,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,13,0,0,0,1,15,7,0,80,252,6,0,13,0,0,0,1,15,8,0,16,242,7,0,13,0,0,0,1,15,9,0,104,236,7,0,13,0,0,0,1,15,5,0,192,54,8,0,13,0,0,0,1,15,4,0,56,24,4,0,13,0,0,0,1,15,15,0,128,230,7,0,13,0,0,0,1,15,0,0,128,230,7,0,13,0,0,0,1,15,3,0,176,162,3,0,13,0,0,0,1,15,2,0,24,188,3,0,13,0,0,0,1,15,1,0,72,216,3,0,13,0,0,0,1,15,6,0,120,211,6,0,13,0,0,0,1,15,14,0,184,164,6,0,13,0,0,0,1,15,13,0,80,74,6,0,13,0,0,0,1,15,12,0,192,32,6,0,13,0,0,0,1,15,11,0,192,234,2,0,13,0,0,0,1,15,10,0,32,242,5,0,0,0,0,0,254,0,16,0,160,123,6,0,13,0,0,0,1,240,112,0,80,252,6,0,13,0,0,0,1,240,128,0,16,242,7,0,13,0,0,0,1,240,144,0,104,236,7,0,13,0,0,0,1,240,80,0,192,54,8,0,13,0,0,0,1,240,64,0,56,24,4,0,13,0,0,0,1,240,240,0,128,230,7,0,13,0,0,0,1,240,0,0,128,230,7,0,13,0,0,0,1,240,48,0,176,162,3,0,13,0,0,0,1,240,32,0,24,188,3,0,13,0,0,0,1,240,16,0,72,216,3,0,13,0,0,0,1,240,96,0,120,211,6,0,13,0,0,0,1,240,224,0,184,164,6,0,13,0,0,0,1,240,208,0,80,74,6,0,13,0,0,0,1,240,192,0,192,32,6,0,13,0,0,0,1,240,176,0,192,234,2,0,13,0,0,0,1,240,160,0,32,242,5,0,0,0,0,0,254,0,2,0,200,30,2,0,14,0,0,0,1,1,0,0,120,97,1,0,14,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,4,0,128,129,4,0,14,0,0,0,1,12,12,0,208,75,4,0,14,0,0,0,1,12,8,0,8,49,4,0,14,0,0,0,1,12,4,0,152,21,4,0,14,0,0,0,1,12,0,0,112,49,6,0,0,0,0,0,254,0,4,0,64,37,5,0,14,0,0,0,1,48,48,0,32,54,5,0,14,0,0,0,1,48,32,0,16,51,5,0,14,0,0,0,1,48,16,0,64,46,5,0,14,0,0,0,1,48,0,0,64,42,5,0,0,0,0,0,254,0,2,0,72,202,5,0,14,0,0,0,1,64,64,0,80,246,3,0,14,0,0,0,1,64,0,0,112,212,3,0,98,56,50,45,48,57,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,205,30,47,99,2,0,16,1,98,56,50,45,49,55,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,201,46,27,233,2,0,16,1,98,56,50,95,49,48,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,237,170,138,163,9,0,16,1,98,56,50,45,48,54,46,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,37,10,69,252,12,0,32,0,98,56,50,45,48,55,46,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,119,245,61,236,12,0,32,0,98,56,50,45,48,52,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,142,249,70,99,16,0,32,0,98,56,50,45,48,51,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,21,161,218,16,0,32,0,98,56,50,45,48,53,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,58,185,144,170,15,0,32,0,98,56,50,45,48,50,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,221,107,208,93,24,0,64,0,98,56,50,45,48,49,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,70,104,235,240,25,0,64,0,116,105,98,112,97,108,49,54,108,56,46,105,99,52,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,154,161,160,17,0,0,0,8,116,105,98,112,97,108,49,54,108,56,46,105,99,52,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,184,222,83,204,0,0,0,8,116,105,98,112,97,108,49,54,108,56,46,105,99,53,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,55,133,135,242,0,0,0,8,103,97,108,49,54,118,56,46,105,99,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,208,95,247,164,0,0,0,8,103,97,108,49,54,118,56,46,105,99,51,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,225,179,78,202,0,0,0,8,25,0,0,0,255,255,255,0,0,0,0,0,26,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,40,115,4,0,25,0,0,0,1,1,1,0,96,135,7,0,25,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,25,0,0,0,1,2,2,0,96,135,7,0,25,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,25,0,0,0,1,4,4,0,96,135,7,0,25,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,25,0,0,0,1,8,0,0,96,135,7,0,25,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,25,0,0,0,1,48,0,0,80,252,6,0,25,0,0,0,1,48,16,0,16,242,7,0,25,0,0,0,1,48,32,0,104,236,7,0,25,0,0,0,1,48,48,0,128,230,7,0,0,0,0,0,254,0,4,0,160,123,6,0,25,0,0,0,1,192,192,0,8,201,6,0,25,0,0,0,1,192,128,0,200,197,6,0,25,0,0,0,1,192,64,0,152,194,6,0,25,0,0,0,1,192,0,0,248,189,6,0,0,0,0,0,254,0,4,0,72,202,5,0,26,0,0,0,1,3,2,0,80,246,3,0,26,0,0,0,1,3,3,0,80,124,6,0,26,0,0,0,1,3,1,0,112,212,3,0,26,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,102,102,95,51,54,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,131,206,165,249,1,0,16,1,102,102,95,52,50,46,49,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,21,18,241,101,1,0,16,1,102,102,95,51,55,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,132,55,3,225,1,0,16,1,102,102,101,95,52,51,46,49,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,138,150,94,153,1,0,16,1,102,102,45,51,50,109,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,110,105,71,199,2,0,16,1,102,102,45,53,109,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,8,65,40,156,4,0,32,0,102,102,45,55,109,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,251,77,88,167,4,0,32,0,102,102,45,49,109,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,68,94,96,11,4,0,32,0,102,102,45,51,109,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,210,28,41,82,4,0,32,0,102,102,95,48,57,46,49,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,181,126,54,184,3,0,16,0,102,102,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,231,102,92,55,5,0,64,0,102,102,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,249,55,241,30,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,115,50,50,52,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,62,65,196,205,0,0,0,8,105,111,98,49,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,20,0,0,0,255,255,0,0,0,0,0,0,21,0,0,0,255,255,11,0,0,0,0,0,22,0,0,0,255,255,96,0,0,0,0,0,0,0,0,0,254,0,8,0,200,87,7,0,20,0,0,0,1,7,7,0,80,252,6,0,20,0,0,0,1,7,6,0,16,242,7,0,20,0,0,0,1,7,5,0,104,236,7,0,20,0,0,0,1,7,0,0,128,230,7,0,20,0,0,0,1,7,1,0,184,164,6,0,20,0,0,0,1,7,2,0,80,74,6,0,20,0,0,0,1,7,3,0,192,32,6,0,20,0,0,0,1,7,4,0,32,242,5,0,0,0,0,0,254,0,8,0,160,123,6,0,20,0,0,0,1,56,56,0,80,252,6,0,20,0,0,0,1,56,48,0,16,242,7,0,20,0,0,0,1,56,40,0,104,236,7,0,20,0,0,0,1,56,0,0,128,230,7,0,20,0,0,0,1,56,8,0,184,164,6,0,20,0,0,0,1,56,16,0,80,74,6,0,20,0,0,0,1,56,24,0,192,32,6,0,20,0,0,0,1,56,32,0,32,242,5,0,0,0,0,0,254,0,2,0,64,232,1,0,20,0,0,0,1,64,0,0,96,135,7,0,20,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,8,0,72,202,5,0,21,0,0,0,1,7,0,0,72,198,6,0,21,0,0,0,1,7,1,0,208,75,4,0,21,0,0,0,1,7,2,0,8,49,4,0,21,0,0,0,1,7,3,0,72,195,6,0,21,0,0,0,1,7,4,0,72,246,3,0,21,0,0,0,1,7,5,0,72,0,3,0,21,0,0,0,1,7,6,0,64,47,7,0,21,0,0,0,1,7,7,0,48,173,6,0,0,0,0,0,254,0,4,0,176,33,1,0,21,0,0,0,1,24,0,0,80,246,3,0,21,0,0,0,1,24,8,0,248,38,7,0,21,0,0,0,1,24,16,0,112,212,3,0,21,0,0,0,1,24,24,0,248,160,5,0,0,0,0,0,254,0,4,0,64,37,5,0,21,0,0,0,1,96,0,0,0,64,7,0,21,0,0,0,1,96,32,0,120,124,5,0,21,0,0,0,1,96,64,0,40,160,4,0,21,0,0,0,1,96,96,0,120,7,5,0,0,0,0,0,254,0,4,0,128,129,4,0,22,0,0,0,1,3,3,0,192,255,2,0,22,0,0,0,1,3,0,0,208,75,4,0,22,0,0,0,1,3,1,0,8,49,4,0,22,0,0,0,1,3,2,0,152,21,4,0,0,0,0,0,254,0,2,0,16,227,4,0,22,0,0,0,1,4,0,0,96,135,7,0,22,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,254,0,2,0,72,4,1,0,22,0,0,0,1,8,0,0,96,135,7,0,22,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,2,0,120,207,1,0,22,0,0,0,1,16,0,0,96,135,7,0,22,0,0,0,1,16,16,0,152,182,7,0,0,0,0,0,254,0,2,0,40,111,8,0,22,0,0,0,1,32,0,0,96,135,7,0,22,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,22,0,0,0,1,64,0,0,96,135,7,0,22,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,168,79,2,0,22,0,0,0,1,128,0,0,32,182,8,0,22,0,0,0,1,128,128,0,80,251,6,0,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,145,76,133,198,1,0,16,1,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,179,194,247,119,1,0,16,1,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,223,179,149,24,1,0,16,1,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,238,17,212,187,1,0,16,1,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,242,235,35,91,1,0,16,1,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,190,174,162,171,1,0,16,1,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,246,55,191,212,1,0,16,1,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,67,143,172,7,1,0,16,1,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,217,230,238,241,4,0,32,0,50,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,55,69,95,103,4,0,32,0,50,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,172,50,138,219,4,0,32,0,50,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,87,62,17,244,4,0,32,0,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,62,133,120,212,4,0,32,0,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,66,86,5,37,4,0,32,0,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,40,3,125,183,4,0,32,0,49,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,121,26,17,234,4,0,32,0,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,72,31,170,179,4,0,32,0,50,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,201,117,209,4,4,0,32,0,50,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,79,186,146,229,4,0,32,0,50,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,15,116,154,184,4,0,32,0,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,96,122,69,212,4,0,32,0,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,125,163,38,59,4,0,32,0,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,126,131,109,4,0,32,0,49,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,108,77,154,197,4,0,32,0,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,20,108,39,91,3,0,16,0,184,40,2,0,1,0,0,0,8,255,146,0,248,191,2,0,184,164,8,0,1,0,0,0,9,255,146,0,64,246,1,0,136,204,6,0,1,0,0,0,10,255,146,0,184,160,2,0,208,158,7,0,1,0,0,0,2,255,146,0,96,82,2,0,184,154,7,0,1,0,0,0,3,255,146,0,32,56,2,0,136,117,3,0,1,0,0,0,5,255,146,0,152,30,2,0,248,79,3,0,1,0,0,0,4,255,146,0,232,10,2,0,88,212,3,0,1,0,0,0,184,218,146,0,40,185,3,0,16,17,8,0,1,0,0,0,14,255,146,0,224,12,8,0,72,65,1,0,9,0,0,0,64,5,147,0,32,58,1,0,48,50,1,0,9,0,0,0,65,5,147,0,32,58,1,0,224,41,1,0,9,0,0,0,66,5,147,0,32,58,1,0,48,45,3,0,9,0,0,0,67,5,147,0,32,58,1,0,101,120,111,100,117,115,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,225,101,254,93,1,0,16,1,101,120,111,100,117,115,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,47,34,89,101,1,0,16,1,101,120,111,100,117,115,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,232,48,112,191,1,0,16,1,101,120,111,100,117,115,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,158,144,7,54,1,0,16,1,101,120,111,100,117,115,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,196,144,74,153,1,0,16,1,101,120,111,100,117,115,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,135,17,209,251,1,0,16,1,101,120,111,100,117,115,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,17,216,7,253,1,0,16,1,101,120,111,100,117,115,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,180,124,76,179,4,0,32,0,101,120,111,100,117,115,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,71,212,162,80,4,0,32,0,108,48,54,95,112,114,111,109,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,135,125,12,106,7,0,32,0,11,0,0,0,255,255,0,0,0,0,0,0,12,0,0,0,255,255,192,0,0,0,0,0,13,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,232,75,4,0,11,0,0,0,1,64,0,0,96,135,7,0,11,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,160,123,6,0,12,0,0,0,1,64,0,0,224,127,8,0,12,0,0,0,1,64,64,0,32,123,8,0,0,0,0,0,254,0,2,0,200,87,7,0,12,0,0,0,1,128,128,0,0,90,2,0,12,0,0,0,1,128,0,0,104,61,2,0,0,0,0,0,254,0,4,0,64,37,5,0,13,0,0,0,1,1,0,0,176,114,3,0,13,0,0,0,1,1,1,0,120,7,5,0,0,0,0,0,254,0,2,0,128,129,4,0,13,0,0,0,1,4,0,0,8,49,4,0,13,0,0,0,1,4,4,0,72,246,3,0,0,0,0,0,254,0,2,0,200,30,2,0,13,0,0,0,1,8,0,0,120,97,1,0,13,0,0,0,1,8,8,0,96,19,1,0,0,0,0,0,101,112,114,45,49,50,54,53,55,46,97,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,170,114,202,67,1,0,16,1,101,112,114,45,49,50,54,53,54,46,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,103,137,1,95,1,0,16,1,109,112,114,45,49,50,54,50,52,46,98,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,196,94,90,55,2,0,32,0,109,112,114,45,49,50,54,50,53,46,98,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,126,117,140,59,2,0,32,0,109,112,114,45,49,50,54,50,54,46,98,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,92,162,252,62,2,0,32,0,109,112,114,45,49,50,54,49,56,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,191,48,21,13,3,0,32,0,109,112,114,45,49,50,54,50,49,46,98,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,153,7,255,24,3,0,32,0,109,112,114,45,49,50,54,49,57,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,70,146,6,50,3,0,32,0,109,112,114,45,49,50,54,50,50,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,54,228,223,163,3,0,32,0,109,112,114,45,49,50,54,50,48,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,224,150,176,246,3,0,32,0,109,112,114,45,49,50,54,50,51,46,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,246,254,115,103,3,0,32,0,101,112,114,45,49,50,54,49,55,46,97,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,35,207,254,126,4,0,16,1,109,112,114,45,49,50,54,49,54,46,97,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,194,71,67,37,8,0,64,0,51,49,55,45,48,49,50,57,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,199,2,131,18,5,0,16,1,101,112,114,45,49,50,54,49,53,46,97,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,167,46,140,56,1,0,16,1,101,112,114,45,49,50,54,49,52,46,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,71,251,240,213,1,0,16,1,109,112,114,45,49,50,54,50,52,46,98,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,196,94,90,55,2,0,32,0,109,112,114,45,49,50,54,50,53,46,98,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,126,117,140,59,2,0,32,0,109,112,114,45,49,50,54,50,54,46,98,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,92,162,252,62,2,0,32,0,109,112,114,45,49,50,54,49,56,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,191,48,21,13,3,0,32,0,109,112,114,45,49,50,54,50,49,46,98,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,153,7,255,24,3,0,32,0,109,112,114,45,49,50,54,49,57,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,70,146,6,50,3,0,32,0,109,112,114,45,49,50,54,50,50,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,54,228,223,163,3,0,32,0,109,112,114,45,49,50,54,50,48,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,224,150,176,246,3,0,32,0,109,112,114,45,49,50,54,50,51,46,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,246,254,115,103,3,0,32,0,101,112,114,45,49,50,54,49,55,46,97,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,35,207,254,126,4,0,16,1,109,112,114,45,49,50,54,49,54,46,97,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,194,71,67,37,8,0,64,0,51,49,55,45,48,49,50,56,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,119,98,249,149,5,0,16,1,101,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,38,149,76,34,1,0,16,1,101,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,189,142,83,204,1,0,16,1,102,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,171,176,162,41,1,0,16,1,102,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,109,90,106,76,1,0,16,1,101,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,166,120,211,6,1,0,16,1,101,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,213,32,234,13,1,0,16,1,101,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,232,241,90,180,1,0,16,1,101,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,118,168,55,196,1,0,16,1,101,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,76,61,198,227,4,0,32,0,101,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,237,222,143,98,4,0,32,0,101,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,71,158,66,89,4,0,32,0,101,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,253,197,78,238,4,0,32,0,108,48,54,95,112,114,111,109,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,135,125,12,106,7,0,32,0,101,49,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,163,183,170,69,1,0,16,1,101,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,189,142,83,204,1,0,16,1,102,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,171,176,162,41,1,0,16,1,102,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,109,90,106,76,1,0,16,1,101,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,166,120,211,6,1,0,16,1,101,54,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,198,248,9,159,1,0,16,1,101,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,232,241,90,180,1,0,16,1,101,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,118,168,55,196,1,0,16,1,101,49,48,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,189,142,179,37,4,0,32,0,101,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,237,222,143,98,4,0,32,0,101,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,153,64,102,186,4,0,32,0,101,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,253,197,78,238,4,0,32,0,108,48,54,95,112,114,111,109,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,135,125,12,106,7,0,32,0,11,0,0,0,255,255,0,0,0,0,0,0,12,0,0,0,255,255,128,0,0,0,0,0,13,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,11,0,0,0,1,32,0,0,120,97,1,0,11,0,0,0,1,32,32,0,96,19,1,0,0,0,0,0,254,0,2,0,64,37,5,0,12,0,0,0,1,64,0,0,152,53,6,0,12,0,0,0,1,64,64,0,8,49,6,0,0,0,0,0,254,0,2,0,128,112,3,0,12,0,0,0,1,128,128,0,168,22,4,0,12,0,0,0,1,128,0,0,224,247,3,0,0,0,0,0,254,0,4,0,32,4,2,0,13,0,0,0,1,3,3,0,144,102,8,0,13,0,0,0,1,3,2,0,176,45,8,0,13,0,0,0,1,3,1,0,224,127,8,0,13,0,0,0,1,3,0,0,32,123,8,0,0,0,0,0,254,0,2,0,16,227,4,0,13,0,0,0,1,12,0,0,96,135,7,0,13,0,0,0,1,12,12,0,152,182,7,0,51,48,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,104,109,236,249,1,0,16,1,51,53,46,49,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,47,255,31,228,1,0,16,1,51,49,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,255,118,222,227,1,0,16,1,51,54,46,49,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,191,207,19,122,1,0,16,1,116,107,109,45,57,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,207,75,101,147,2,0,16,1,116,107,109,45,53,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,160,182,75,246,4,0,32,0,116,107,109,45,56,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,116,98,254,33,4,0,32,0,116,107,109,45,54,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,203,40,242,11,4,0,32,0,116,107,109,45,55,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,177,223,85,18,4,0,32,0,116,107,109,45,49,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,30,102,247,68,4,0,32,0,116,107,109,45,52,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,93,81,76,165,4,0,32,0,116,107,109,45,50,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,124,104,92,202,4,0,32,0,116,107,109,45,51,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,145,101,254,249,4,0,32,0,116,107,101,95,49,55,46,49,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,79,157,183,179,3,0,16,0,116,107,101,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,125,48,110,172,5,0,64,0,116,107,101,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,219,65,135,6,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,116,107,50,52,98,49,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,69,118,74,174,0,0,0,8,108,119,105,111,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,12,185,82,173,0,0,0,8,20,0,0,0,255,255,0,0,0,0,0,0,21,0,0,0,255,255,0,0,0,0,0,0,22,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,8,0,200,87,7,0,20,0,0,0,1,7,6,0,80,252,6,0,20,0,0,0,1,7,5,0,16,242,7,0,20,0,0,0,1,7,4,0,104,236,7,0,20,0,0,0,1,7,7,0,104,9,2,0,20,0,0,0,1,7,0,0,128,230,7,0,20,0,0,0,1,7,1,0,184,164,6,0,20,0,0,0,1,7,2,0,80,74,6,0,20,0,0,0,1,7,3,0,192,32,6,0,0,0,0,0,254,0,8,0,160,123,6,0,20,0,0,0,1,56,48,0,80,252,6,0,20,0,0,0,1,56,40,0,16,242,7,0,20,0,0,0,1,56,32,0,104,236,7,0,20,0,0,0,1,56,56,0,104,9,2,0,20,0,0,0,1,56,0,0,128,230,7,0,20,0,0,0,1,56,8,0,184,164,6,0,20,0,0,0,1,56,16,0,80,74,6,0,20,0,0,0,1,56,24,0,192,32,6,0,0,0,0,0,254,0,2,0,16,227,4,0,20,0,0,0,1,128,0,0,96,135,7,0,20,0,0,0,1,128,128,0,152,182,7,0,0,0,0,0,254,0,8,0,72,202,5,0,21,0,0,0,1,7,3,0,72,198,6,0,21,0,0,0,1,7,2,0,208,75,4,0,21,0,0,0,1,7,1,0,8,49,4,0,21,0,0,0,1,7,0,0,72,195,6,0,21,0,0,0,1,7,4,0,72,246,3,0,21,0,0,0,1,7,5,0,72,0,3,0,21,0,0,0,1,7,6,0,64,47,7,0,21,0,0,0,1,7,7,0,48,173,6,0,0,0,0,0,254,0,2,0,72,4,1,0,22,0,0,0,1,1,0,0,96,135,7,0,22,0,0,0,1,1,1,0,152,182,7,0,0,0,0,0,254,0,2,0,128,166,1,0,22,0,0,0,1,2,0,0,96,135,7,0,22,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,2,0,120,207,1,0,22,0,0,0,1,16,0,0,96,135,7,0,22,0,0,0,1,16,16,0,152,182,7,0,0,0,0,0,254,0,2,0,40,111,8,0,22,0,0,0,1,32,32,0,96,135,7,0,22,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,22,0,0,0,1,64,64,0,96,135,7,0,22,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,79,2,0,22,0,0,0,1,128,0,0,32,182,8,0,22,0,0,0,1,128,128,0,80,251,6,0,0,0,0,0,118,97,109,117,46,48,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,63,52,166,104,1,0,16,1,118,97,109,117,46,48,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,83,20,22,88,1,0,16,1,118,97,109,117,46,48,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,184,56,192,223,1,0,16,1,118,97,109,117,46,48,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,137,44,132,195,1,0,16,1,118,97,109,117,46,48,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,110,11,182,37,1,0,16,1,118,97,109,117,46,48,56,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,150,197,19,33,1,0,16,1,118,97,109,117,46,48,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,229,154,30,45,1,0,16,1,118,97,109,117,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,34,86,20,129,1,0,16,1,118,97,109,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,153,175,27,197,5,0,32,0,118,97,109,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,119,60,232,60,5,0,32,0,118,97,109,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,224,8,36,79,5,0,32,0,118,97,109,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,80,2,246,159,5,0,32,0,118,97,109,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,60,36,135,189,5,0,32,0,118,97,109,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,95,133,236,175,5,0,32,0,118,97,109,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,37,54,3,58,5,0,32,0,118,97,109,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,137,106,255,43,5,0,32,0,118,97,109,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,213,133,182,100,10,0,16,1,118,97,109,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,199,151,124,207,10,0,16,1,118,97,109,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,178,222,57,74,12,0,64,0,118,97,109,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,3,92,62,26,12,0,64,0,118,97,109,104,46,48,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,143,158,123,77,1,0,16,1,118,97,109,104,46,48,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,160,233,23,34,1,0,16,1,118,97,109,104,46,48,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,60,177,5,58,1,0,16,1,118,97,109,104,46,48,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,28,10,215,17,1,0,16,1,118,97,109,104,46,48,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,103,135,90,219,1,0,16,1,118,97,109,104,46,48,56,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,155,215,79,42,1,0,16,1,118,97,109,104,46,48,57,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,50,118,24,21,1,0,16,1,118,97,109,104,46,49,48,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,129,45,45,25,1,0,16,1,118,97,109,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,153,175,27,197,5,0,32,0,118,97,109,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,119,60,232,60,5,0,32,0,118,97,109,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,224,8,36,79,5,0,32,0,118,97,109,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,80,2,246,159,5,0,32,0,118,97,109,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,60,36,135,189,5,0,32,0,118,97,109,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,95,133,236,175,5,0,32,0,118,97,109,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,37,54,3,58,5,0,32,0,118,97,109,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,137,106,255,43,5,0,32,0,118,97,109,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,213,133,182,100,10,0,16,1,118,97,109,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,199,151,124,207,10,0,16,1,118,97,109,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,178,222,57,74,12,0,64,0,118,97,109,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,3,92,62,26,12,0,64,0,118,97,109,97,46,48,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,11,78,41,1,0,16,1,118,97,109,97,46,48,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,40,225,24,188,1,0,16,1,118,97,109,97,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,89,250,9,231,1,0,16,1,118,97,109,97,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,135,211,228,85,1,0,16,1,118,97,109,97,46,48,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,129,249,232,36,1,0,16,1,118,97,109,97,46,48,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,142,58,63,116,1,0,16,1,118,97,109,97,46,48,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,115,85,250,103,1,0,16,1,118,97,109,97,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,71,215,3,94,1,0,16,1,118,97,109,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,153,175,27,197,5,0,32,0,118,97,109,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,119,60,232,60,5,0,32,0,118,97,109,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,224,8,36,79,5,0,32,0,118,97,109,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,80,2,246,159,5,0,32,0,118,97,109,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,60,36,135,189,5,0,32,0,118,97,109,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,95,133,236,175,5,0,32,0,118,97,109,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,37,54,3,58,5,0,32,0,118,97,109,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,137,106,255,43,5,0,32,0,118,97,109,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,213,133,182,100,10,0,16,1,118,97,109,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,199,151,124,207,10,0,16,1,118,97,109,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,178,222,57,74,12,0,64,0,118,97,109,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,3,92,62,26,12,0,64,0,98,109,107,48,49,46,49,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,219,17,34,125,0,0,16,1,98,109,107,48,50,46,49,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,197,200,187,46,0,0,16,1,98,109,107,48,51,46,49,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,197,106,90,71,0,0,16,1,98,109,107,48,52,46,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,87,121,243,37,0,0,16,1,98,109,107,48,53,46,52,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,146,134,74,136,0,0,32,0,98,109,49,53,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,67,4,26,107,0,0,32,0,98,109,107,49,54,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,13,254,22,148,0,0,32,0,98,109,107,49,55,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,185,202,90,61,0,0,32,0,98,109,107,49,56,46,49,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,29,218,98,123,0,0,32,0,98,109,49,57,46,49,48,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,188,186,138,134,0,0,32,0,98,109,107,50,48,46,49,49,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,193,100,3,185,0,0,32,0,98,109,107,50,49,46,49,50,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,74,231,127,140,0,0,32,0,98,109,107,50,50,46,49,52,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,14,138,239,213,0,0,32,0,98,109,107,50,52,46,49,52,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,242,110,24,191,0,0,32,0,98,109,107,50,53,46,49,52,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,241,250,85,167,0,0,32,0,98,109,107,48,54,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,179,56,126,95,0,0,32,0,98,109,107,48,55,46,49,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,253,81,55,255,0,0,32,0,98,109,107,48,56,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,189,81,157,21,0,0,32,0,98,109,107,48,57,46,49,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,210,227,131,134,0,0,32,0,98,109,107,49,48,46,49,48,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,113,149,13,30,0,0,32,0,98,109,107,49,49,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,225,94,252,241,0,0,32,0,98,109,107,49,50,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,1,192,80,15,0,0,32,0,98,109,107,49,51,46,49,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,142,207,26,253,0,0,32,0,98,109,107,49,52,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,83,90,15,207,0,0,32,0,98,109,107,50,51,46,56,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,249,126,247,23,0,0,32,0,98,109,107,49,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,51,234,1,224,0,0,32,0,98,109,107,50,46,49,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,26,217,52,175,0,0,32,0,98,109,107,51,46,49,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,239,246,233,67,0,0,32,0,98,109,107,53,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,52,137,135,65,0,0,32,0,98,109,107,49,48,46,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,72,183,68,222,0,0,32,0,98,109,107,57,46,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,192,87,234,89,0,0,32,0,98,109,107,49,50,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,176,248,101,135,0,0,32,0,98,109,107,49,49,46,49,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,78,133,168,135,0,0,32,0,98,109,107,56,46,56,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,45,126,209,218,0,0,32,0,98,109,107,55,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,141,127,48,118,0,0,32,0,98,109,52,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,225,162,168,145,0,0,32,0,98,109,54,46,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,88,81,175,14,0,0,32,0,98,109,46,55,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,16,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,104,208,89,72,0,0,16,1,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,239,43,50,8,0,0,16,1,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,100,119,141,136,0,0,16,1,103,110,103,46,110,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,218,141,154,253,0,0,16,1,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,85,46,44,243,0,0,16,1,103,103,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,111,91,95,97,0,0,16,1,103,103,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,7,207,252,236,0,0,32,0,103,103,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,169,111,213,221,0,0,32,0,103,103,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,157,82,2,115,0,0,32,0,103,103,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,218,91,3,32,0,0,32,0,103,103,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,113,162,43,241,0,0,32,0,103,103,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,125,32,37,229,0,0,32,0,103,103,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,178,233,119,45,0,0,32,0,49,57,46,56,52,52,55,50,46,52,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,220,175,19,70,0,0,32,0,49,56,46,56,52,52,55,50,46,51,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,202,229,215,6,0,0,32,0,49,55,46,56,52,52,55,50,46,49,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,45,224,31,188,0,0,32,0,49,54,46,56,52,52,55,50,46,52,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,213,104,141,96,0,0,32,0,49,53,46,56,52,52,57,48,46,51,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,202,63,12,232,0,0,32,0,49,52,46,56,52,52,57,48,46,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,37,169,128,119,0,0,32,0,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,90,79,24,243,0,0,16,1,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,36,123,95,131,0,0,16,1,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,110,108,69,47,0,0,16,1,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,107,240,135,189,0,0,16,1,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,145,161,188,110,0,0,32,0,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,164,159,50,96,0,0,32,0,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,22,193,186,102,0,0,32,0,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,193,206,63,98,0,0,32,0,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,239,69,35,223,0,0,32,0,49,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,237,177,6,193,0,0,32,0,115,98,45,53,46,101,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,83,129,171,147,0,0,32,0,115,98,45,54,46,101,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,125,79,180,138,0,0,32,0,115,98,45,55,46,101,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,164,233,173,244,0,0,32,0,115,98,45,48,46,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,27,217,71,96,0,0,32,0,115,98,45,52,46,100,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,141,150,88,72,0,0,32,0,115,98,45,56,46,107,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,67,217,250,246,0,0,32,0,115,98,45,50,46,100,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,223,179,184,139,0,0,32,0,115,98,45,51,46,100,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,175,153,12,59,0,0,32,0,115,98,45,49,46,107,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,8,197,42,113,0,0,32,0,115,98,45,57,46,109,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,92,99,33,73,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,0,0,0,255,255,128,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,14,0,0,0,1,3,0,0,8,49,4,0,14,0,0,0,1,3,1,0,152,21,4,0,14,0,0,0,1,3,2,0,72,246,3,0,14,0,0,0,1,3,3,0,72,0,3,0,0,0,0,0,254,0,4,0,64,37,5,0,14,0,0,0,1,12,0,0,176,114,3,0,14,0,0,0,1,12,4,0,176,116,6,0,14,0,0,0,1,12,8,0,80,113,6,0,14,0,0,0,1,12,12,0,80,110,6,0,0,0,0,0,254,0,8,0,32,4,2,0,14,0,0,0,1,112,112,0,16,227,4,0,14,0,0,0,1,112,80,0,32,136,7,0,14,0,0,0,1,112,48,0,40,88,7,0,14,0,0,0,1,112,16,0,96,39,7,0,14,0,0,0,1,112,0,0,144,251,6,0,14,0,0,0,1,112,32,0,184,164,6,0,14,0,0,0,1,112,64,0,80,74,6,0,14,0,0,0,1,112,96,0,192,32,6,0,0,0,0,0,254,0,2,0,200,30,2,0,14,0,0,0,1,128,128,0,120,97,1,0,14,0,0,0,1,128,0,0,96,19,1,0,0,0,0,0,15,0,0,0,255,255,0,0,0,0,0,0,16,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,8,0,32,4,2,0,15,0,0,0,1,7,2,0,40,88,7,0,15,0,0,0,1,7,4,0,96,39,7,0,15,0,0,0,1,7,0,0,144,251,6,0,15,0,0,0,1,7,6,0,184,164,6,0,15,0,0,0,1,7,1,0,80,74,6,0,15,0,0,0,1,7,3,0,192,32,6,0,15,0,0,0,1,7,5,0,192,234,2,0,15,0,0,0,1,7,7,0,32,242,5,0,0,0,0,0,254,0,2,0,232,75,4,0,15,0,0,0,1,64,0,0,96,135,7,0,15,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,200,30,2,0,15,0,0,0,1,128,0,0,120,97,1,0,15,0,0,0,1,128,128,0,96,19,1,0,0,0,0,0,254,0,4,0,128,129,4,0,16,0,0,0,1,3,0,0,8,49,4,0,16,0,0,0,1,3,1,0,152,21,4,0,16,0,0,0,1,3,2,0,72,246,3,0,16,0,0,0,1,3,3,0,72,0,3,0,0,0,0,0,254,0,4,0,64,37,5,0,16,0,0,0,1,12,0,0,152,53,6,0,16,0,0,0,1,12,4,0,112,216,4,0,16,0,0,0,1,12,8,0,8,49,6,0,16,0,0,0,1,12,12,0,120,7,5,0,0,0,0,0,254,0,4,0,240,184,7,0,16,0,0,0,1,48,0,0,152,53,6,0,16,0,0,0,1,48,16,0,112,216,4,0,16,0,0,0,1,48,32,0,8,49,6,0,16,0,0,0,1,48,48,0,120,7,5,0,0,0,0,0,254,0,4,0,72,202,5,0,16,0,0,0,1,192,0,0,80,246,3,0,16,0,0,0,1,192,64,0,80,124,6,0,16,0,0,0,1,192,128,0,112,212,3,0,16,0,0,0,1,192,192,0,248,160,5,0,0,0,0,0,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,18,75,207,206,2,0,16,1,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,56,178,238,7,2,0,16,1,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,122,213,195,59,2,0,16,1,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,23,249,164,141,4,0,32,0,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,3,246,64,108,4,0,32,0,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,45,252,200,9,4,0,32,0,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,143,243,127,99,4,0,32,0,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,238,239,11,71,4,0,32,0,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,163,183,191,34,4,0,32,0,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,196,154,89,231,4,0,32,0,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,21,75,27,33,4,0,32,0,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,88,139,142,105,3,0,16,0,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0])
.concat([219,194,226,109,5,0,64,0,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,174,145,144,185,5,0,64,0,100,105,110,111,101,104,46,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,100,131,184,166,2,0,16,1,99,100,101,95,50,50,97,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,18,170,120,146,2,0,16,1,100,105,110,111,101,104,46,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,72,5,154,184,2,0,16,1,99,100,95,103,102,120,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,23,249,164,141,4,0,32,0,99,100,95,103,102,120,48,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,3,246,64,108,4,0,32,0,99,100,95,103,102,120,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,45,252,200,9,4,0,32,0,99,100,95,103,102,120,48,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,143,243,127,99,4,0,32,0,99,100,95,103,102,120,48,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,238,239,11,71,4,0,32,0,99,100,95,103,102,120,48,55,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,163,183,191,34,4,0,32,0,99,100,95,103,102,120,48,54,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,196,154,89,231,4,0,32,0,99,100,95,103,102,120,48,56,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,21,75,27,33,4,0,32,0,99,100,95,113,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,11,219,95,96,3,0,16,0,99,100,95,113,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,117,119,146,96,6,0,64,0,99,100,95,113,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,71,76,15,119,6,0,64,0,99,100,95,113,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,252,63,39,47,6,0,64,0,99,100,95,113,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,29,130,103,44,6,0,64,0,168,86,7,0,1,0,0,0,232,47,216,0,248,191,2,0,24,38,7,0,1,0,0,0,236,47,216,0,184,160,2,0,56,210,6,0,1,0,0,0,35,48,216,0,192,135,2,0,24,163,6,0,1,0,0,0,34,48,216,0,240,108,2,0,152,122,6,0,1,0,0,0,33,48,216,0,96,82,2,0,192,72,6,0,1,0,0,0,32,48,216,0,32,56,2,0,152,31,6,0,1,0,0,0,36,48,216,0,152,30,2,0,248,97,5,0,1,0,0,0,37,48,216,0,232,10,2,0,40,246,1,0,1,0,0,0,233,47,216,0,64,246,1,0,144,236,1,0,1,0,0,0,237,47,216,0,136,224,1,0,176,223,1,0,1,0,0,0,43,48,216,0,72,198,1,0,192,209,1,0,1,0,0,0,42,48,216,0,24,182,1,0,24,198,1,0,1,0,0,0,41,48,216,0,40,167,1,0,120,189,1,0,1,0,0,0,40,48,216,0,200,149,1,0,8,182,1,0,1,0,0,0,44,48,216,0,56,126,1,0,32,167,1,0,1,0,0,0,45,48,216,0,32,101,1,0,168,132,8,0,1,0,0,0,110,47,216,0,232,209,1,0,72,126,8,0,1,0,0,0,111,47,216,0,144,189,1,0,192,122,8,0,1,0,0,0,107,47,216,0,208,174,1,0,40,116,8,0,1,0,0,0,106,47,216,0,48,160,1,0,72,110,8,0,1,0,0,0,105,47,216,0,160,140,1,0,184,102,8,0,1,0,0,0,104,47,216,0,56,112,1,0,248,93,8,0,1,0,0,0,108,47,216,0,32,92,1,0,152,86,8,0,1,0,0,0,109,47,216,0,64,77,1,0,88,212,3,0,1,0,0,0,144,46,216,0,40,185,3,0,240,152,1,0,1,0,0,0,238,47,216,0,216,70,1,0,16,17,8,0,1,0,0,0,234,47,216,0,224,12,8,0,224,41,1,0,9,0,0,0,216,48,216,0,32,58,1,0,20,0,0,0,255,255,255,0,0,0,0,0,21,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,8,0,200,87,7,0,20,0,0,0,1,7,0,0,40,88,7,0,20,0,0,0,1,7,1,0,96,39,7,0,20,0,0,0,1,7,7,0,144,251,6,0,20,0,0,0,1,7,6,0,184,164,6,0,20,0,0,0,1,7,5,0,80,74,6,0,20,0,0,0,1,7,4,0,192,32,6,0,20,0,0,0,1,7,3,0,192,234,2,0,20,0,0,0,1,7,2,0,32,242,5,0,0,0,0,0,254,0,8,0,160,123,6,0,20,0,0,0,1,56,0,0,40,88,7,0,20,0,0,0,1,56,8,0,96,39,7,0,20,0,0,0,1,56,56,0,144,251,6,0,20,0,0,0,1,56,48,0,184,164,6,0,20,0,0,0,1,56,40,0,80,74,6,0,20,0,0,0,1,56,32,0,192,32,6,0,20,0,0,0,1,56,24,0,192,234,2,0,20,0,0,0,1,56,16,0,32,242,5,0,0,0,0,0,254,0,2,0,144,212,8,0,20,0,0,0,1,64,64,0,96,135,7,0,20,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,56,180,7,0,20,0,0,0,1,128,128,0,112,202,5,0,20,0,0,0,1,128,0,0,144,126,5,0,0,0,0,0,254,0,4,0,128,129,4,0,21,0,0,0,1,3,1,0,192,255,2,0,21,0,0,0,1,3,0,0,208,75,4,0,21,0,0,0,1,3,3,0,8,49,4,0,21,0,0,0,1,3,2,0,152,21,4,0,0,0,0,0,254,0,4,0,72,202,5,0,21,0,0,0,1,12,8,0,80,246,3,0,21,0,0,0,1,12,12,0,248,38,7,0,21,0,0,0,1,12,4,0,112,212,3,0,21,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,2,0,16,227,4,0,21,0,0,0,1,16,16,0,96,135,7,0,21,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,94,0,0,0,0,0,21,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,19,0,0,0,1,15,2,0,248,223,6,0,19,0,0,0,1,15,5,0,88,179,6,0,19,0,0,0,1,15,8,0,32,136,6,0,19,0,0,0,1,15,4,0,120,113,6,0,19,0,0,0,1,15,1,0,232,228,5,0,19,0,0,0,1,15,15,0,120,90,6,0,19,0,0,0,1,15,3,0,56,141,7,0,19,0,0,0,1,15,7,0,120,211,6,0,19,0,0,0,1,15,14,0,184,164,6,0,19,0,0,0,1,15,6,0,24,1,7,0,19,0,0,0,1,15,13,0,80,74,6,0,19,0,0,0,1,15,12,0,192,32,6,0,19,0,0,0,1,15,11,0,192,234,2,0,19,0,0,0,1,15,10,0,32,242,5,0,19,0,0,0,1,15,9,0,176,192,2,0,19,0,0,0,1,15,0,0,16,227,4,0,0,0,0,0,254,0,16,0,160,123,6,0,19,0,0,0,1,240,32,0,248,223,6,0,19,0,0,0,1,240,80,0,88,179,6,0,19,0,0,0,1,240,128,0,32,136,6,0,19,0,0,0,1,240,64,0,120,113,6,0,19,0,0,0,1,240,16,0,232,228,5,0,19,0,0,0,1,240,240,0,120,90,6,0,19,0,0,0,1,240,48,0,56,141,7,0,19,0,0,0,1,240,112,0,120,211,6,0,19,0,0,0,1,240,224,0,184,164,6,0,19,0,0,0,1,240,96,0,24,1,7,0,19,0,0,0,1,240,208,0,80,74,6,0,19,0,0,0,1,240,192,0,192,32,6,0,19,0,0,0,1,240,176,0,192,234,2,0,19,0,0,0,1,240,160,0,32,242,5,0,19,0,0,0,1,240,144,0,176,192,2,0,19,0,0,0,1,240,0,0,168,165,2,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,3,3,0,208,75,4,0,20,0,0,0,1,3,2,0,8,49,4,0,20,0,0,0,1,3,1,0,72,246,3,0,20,0,0,0,1,3,0,0,64,47,7,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,96,96,0,80,246,3,0,20,0,0,0,1,96,64,0,248,38,7,0,20,0,0,0,1,96,32,0,48,123,8,0,20,0,0,0,1,96,0,0,8,117,8,0,0,0,0,0,254,0,2,0,168,234,7,0,20,0,0,0,1,128,128,0,96,135,7,0,20,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,21,0,0,0,1,1,1,0,96,135,7,0,21,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,21,0,0,0,1,4,4,0,96,135,7,0,21,0,0,0,1,4,0,0,152,182,7,0,184,40,2,0,1,0,0,0,216,232,148,0,248,191,2,0,56,250,6,0,1,0,0,0,95,234,148,0,184,160,2,0,184,164,8,0,1,0,0,0,217,232,148,0,64,246,1,0,88,149,7,0,1,0,0,0,159,233,148,0,136,224,1,0,240,167,7,0,1,0,0,0,88,234,148,0,192,135,2,0,176,163,7,0,1,0,0,0,89,234,148,0,240,108,2,0,208,158,7,0,1,0,0,0,90,234,148,0,96,82,2,0,184,154,7,0,1,0,0,0,91,234,148,0,32,56,2,0,176,108,2,0,1,0,0,0,92,234,148,0,152,30,2,0,128,98,2,0,1,0,0,0,93,234,148,0,232,10,2,0,48,82,2,0,1,0,0,0,94,234,148,0,152,138,8,0,8,96,7,0,1,0,0,0,152,233,148,0,72,198,1,0,48,89,7,0,1,0,0,0,153,233,148,0,24,182,1,0,16,83,7,0,1,0,0,0,154,233,148,0,40,167,1,0,96,79,7,0,1,0,0,0,155,233,148,0,200,149,1,0,48,76,7,0,1,0,0,0,156,233,148,0,56,126,1,0,144,72,7,0,1,0,0,0,157,233,148,0,32,101,1,0,224,67,7,0,1,0,0,0,158,233,148,0,96,32,8,0,88,212,3,0,1,0,0,0,16,216,146,0,40,185,3,0,16,17,8,0,1,0,0,0,218,232,148,0,224,12,8,0,248,5,8,0,9,0,0,0,32,94,147,0,32,58,1,0,144,250,7,0,9,0,0,0,33,94,147,0,32,58,1,0,184,40,2,0,1,0,0,0,220,232,148,0,248,191,2,0,56,250,6,0,1,0,0,0,218,232,148,0,184,160,2,0,184,164,8,0,1,0,0,0,221,232,148,0,64,246,1,0,88,149,7,0,1,0,0,0,219,232,148,0,136,224,1,0,240,167,7,0,1,0,0,0,88,234,148,0,192,135,2,0,176,163,7,0,1,0,0,0,89,234,148,0,240,108,2,0,208,158,7,0,1,0,0,0,90,234,148,0,96,82,2,0,184,154,7,0,1,0,0,0,91,234,148,0,32,56,2,0,176,108,2,0,1,0,0,0,92,234,148,0,152,30,2,0,128,98,2,0,1,0,0,0,93,234,148,0,232,10,2,0,48,82,2,0,1,0,0,0,94,234,148,0,152,138,8,0,136,108,7,0,1,0,0,0,95,234,148,0,48,119,7,0,152,102,7,0,1,0,0,0,216,232,148,0,112,109,7,0,8,96,7,0,1,0,0,0,152,233,148,0,72,198,1,0,48,89,7,0,1,0,0,0,153,233,148,0,24,182,1,0,16,83,7,0,1,0,0,0,154,233,148,0,40,167,1,0,96,79,7,0,1,0,0,0,155,233,148,0,200,149,1,0,48,76,7,0,1,0,0,0,156,233,148,0,56,126,1,0,144,72,7,0,1,0,0,0,157,233,148,0,32,101,1,0,224,67,7,0,1,0,0,0,158,233,148,0,96,32,8,0,152,63,7,0,1,0,0,0,159,233,148,0,16,68,7,0,184,58,7,0,1,0,0,0,217,232,148,0,240,58,7,0,88,212,3,0,1,0,0,0,16,216,146,0,40,185,3,0,16,17,8,0,1,0,0,0,222,232,148,0,224,12,8,0,248,5,8,0,9,0,0,0,32,94,147,0,32,58,1,0,144,250,7,0,9,0,0,0,33,94,147,0,32,58,1,0,8,0,0,0,255,255,254,0,0,0,0,0,9,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,168,234,7,0,8,0,0,0,1,1,1,0,96,135,7,0,8,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,16,227,4,0,8,0,0,0,1,2,2,0,96,135,7,0,8,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,200,30,2,0,8,0,0,0,1,64,64,0,120,97,1,0,8,0,0,0,1,64,0,0,96,19,1,0,0,0,0,0,254,0,2,0,144,212,8,0,8,0,0,0,1,128,128,0,96,135,7,0,8,0,0,0,1,128,0,0,152,182,7,0,100,100,117,120,98,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,18,96,82,231,1,0,16,1,100,100,117,120,98,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,55,18,157,69,1,0,16,1,100,100,117,120,98,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,50,49,237,216,1,0,16,1,100,100,117,120,98,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,146,203,198,48,1,0,16,1,100,100,117,120,98,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,53,209,75,102,2,0,32,0,100,100,117,120,98,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,48,43,13,206,2,0,32,0,100,100,117,120,98,49,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,52,84,233,109,2,0,32,0,100,100,117,120,98,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,229,174,227,11,3,0,32,0,100,100,117,120,98,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,153,158,7,176,3,0,32,0,100,100,117,120,98,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,24,175,178,207,3,0,32,0,100,100,117,120,98,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,156,54,23,2,3,0,32,0,100,100,117,120,98,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,21,155,206,40,3,0,32,0,100,100,117,120,98,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,54,243,68,136,3,0,32,0,100,100,117,120,98,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,89,119,229,239,3,0,32,0,100,100,117,120,98,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,101,246,100,107,3,0,32,0,100,100,117,120,98,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,215,240,190,13,4,0,16,1,100,97,100,117,46,48,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,95,144,25,165,1,0,16,1,100,97,100,117,46,48,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,56,45,86,82,1,0,16,1,100,97,100,117,46,48,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,254,251,28,238,1,0,16,1,100,97,100,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,86,62,170,19,1,0,16,1,100,97,100,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,221,182,28,67,1,0,16,1,100,97,100,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,214,183,60,218,5,0,32,0,100,97,100,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,114,49,182,146,5,0,32,0,100,97,100,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,245,87,135,185,5,0,32,0,100,97,100,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,70,206,33,129,5,0,32,0,100,97,100,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,63,111,126,131,5,0,32,0,100,97,100,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,219,107,145,240,5,0,32,0,100,97,100,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,239,147,243,206,5,0,32,0,100,97,100,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,158,254,83,137,5,0,32,0,100,97,100,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,36,36,94,63,10,0,16,1,100,97,100,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,103,155,73,12,12,0,64,0,100,97,100,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,78,90,11,47,12,0,64,0,100,97,100,106,46,48,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,152,87,27,11,1,0,16,1,100,97,100,106,46,48,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,200,251,162,198,1,0,16,1,100,97,100,106,46,48,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,254,21,155,24,1,0,16,1,100,97,100,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,90,73,37,98,1,0,16,1,100,97,100,46,48,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,195,14,72,179,1,0,16,1,100,97,100,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,214,183,60,218,5,0,32,0,100,97,100,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,114,49,182,146,5,0,32,0,100,97,100,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,245,87,135,185,5,0,32,0,100,97,100,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,70,206,33,129,5,0,32,0,100,97,100,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,63,111,126,131,5,0,32,0,100,97,100,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,219,107,145,240,5,0,32,0,100,97,100,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,239,147,243,206,5,0,32,0,100,97,100,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,158,254,83,137,5,0,32,0,100,97,100,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,36,36,94,63,10,0,16,1,100,97,100,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,103,155,73,12,12,0,64,0,100,97,100,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,78,90,11,47,12,0,64,0,100,97,100,104,46,48,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,168,80,87,1,0,16,1,100,97,100,104,46,48,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,86,27,191,207,1,0,16,1,100,97,100,104,46,48,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,186,98,229,166,1,0,16,1,100,97,100,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,90,73,37,98,1,0,16,1,100,97,100,46,48,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,195,14,72,179,1,0,16,1,100,97,100,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,214,183,60,218,5,0,32,0,100,97,100,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,114,49,182,146,5,0,32,0,100,97,100,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,245,87,135,185,5,0,32,0,100,97,100,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,70,206,33,129,5,0,32,0,100,97,100,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,63,111,126,131,5,0,32,0,100,97,100,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,219,107,145,240,5,0,32,0,100,97,100,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,239,147,243,206,5,0,32,0,100,97,100,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,158,254,83,137,5,0,32,0,100,97,100,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,36,36,94,63,10,0,16,1,100,97,100,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,103,155,73,12,12,0,64,0,100,97,100,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,78,90,11,47,12,0,64,0,100,97,100,101,100,46,48,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,244,48,51,132,1,0,16,1,100,97,100,101,100,46,48,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,252,20,111,48,1,0,16,1,100,97,100,101,100,46,48,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,40,131,107,140,1,0,16,1,100,97,100,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,90,73,37,98,1,0,16,1,100,97,100,100,46,48,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,204,246,13,15,1,0,16,1,100,97,100,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,214,183,60,218,5,0,32,0,100,97,100,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,114,49,182,146,5,0,32,0,100,97,100,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,245,87,135,185,5,0,32,0,100,97,100,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,70,206,33,129,5,0,32,0,100,97,100,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,63,111,126,131,5,0,32,0,100,97,100,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,219,107,145,240,5,0,32,0,100,97,100,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,239,147,243,206,5,0,32,0,100,97,100,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,158,254,83,137,5,0,32,0,100,97,100,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,36,36,94,63,10,0,16,1,100,97,100,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,103,155,73,12,12,0,64,0,100,97,100,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,78,90,11,47,12,0,64,0,100,97,100,97,46,48,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,21,62,36,191,1,0,16,1,100,97,100,97,46,48,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,30,85,118,1,0,16,1,100,97,100,97,46,48,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,216,10,10,1,0,16,1,100,97,100,97,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,90,73,37,98,1,0,16,1,100,97,100,97,46,48,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,195,14,72,179,1,0,16,1,100,97,100,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,214,183,60,218,5,0,32,0,100,97,100,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,114,49,182,146,5,0,32,0,100,97,100,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,245,87,135,185,5,0,32,0,100,97,100,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,70,206,33,129,5,0,32,0,100,97,100,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,63,111,126,131,5,0,32,0,100,97,100,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,219,107,145,240,5,0,32,0,100,97,100,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,239,147,243,206,5,0,32,0,100,97,100,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,158,254,83,137,5,0,32,0,100,97,100,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,36,36,94,63,10,0,16,1,100,97,100,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,103,155,73,12,12,0,64,0,100,97,100,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,78,90,11,47,12,0,64,0,100,100,50,117,46,48,51,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,57,155,8,251,1,0,16,1,100,100,50,117,46,48,52,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,115,43,67,205,1,0,16,1,100,100,50,46,48,53,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,28,153,177,94,1,0,16,1,100,100,50,46,48,54,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,85,94,107,194,1,0,16,1,100,100,50,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,139,11,154,144,1,0,16,1,100,100,50,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,77,60,229,1,0,16,1,100,100,50,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,159,39,134,95,1,0,16,1,100,100,50,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,38,76,149,173,1,0,16,1,100,100,50,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,110,78,107,164,5,0,32,0,100,100,50,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,252,80,252,213,5,0,32,0,100,100,50,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,103,8,124,131,5,0,32,0,100,100,50,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,28,194,14,187,5,0,32,0,100,100,50,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,226,76,130,109,5,0,32,0,100,100,50,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,229,42,104,121,5,0,32,0,100,100,50,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,73,209,221,172,5,0,32,0,100,100,50,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,192,176,127,17,5,0,32,0,100,100,50,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,229,87,214,153,10,0,16,1,100,100,50,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,36,56,122,17,10,0,16,1,100,100,50,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,37,195,208,152,12,0,64,0,100,100,50,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,250,231,162,94,12,0,64,0,100,100,50,106,46,48,51,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,133,201,200,230,1,0,16,1,100,100,50,106,46,48,52,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,189,192,134,131,1,0,16,1,100,100,50,46,48,53,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,28,153,177,94,1,0,16,1,100,100,50,46,48,54,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,85,94,107,194,1,0,16,1,100,100,50,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,139,11,154,144,1,0,16,1,100,100,50,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,77,60,229,1,0,16,1,100,100,50,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,159,39,134,95,1,0,16,1,100,100,50,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,38,76,149,173,1,0,16,1,100,100,50,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,110,78,107,164,5,0,32,0,100,100,50,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,252,80,252,213,5,0,32,0,100,100,50,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,103,8,124,131,5,0,32,0,100,100,50,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,28,194,14,187,5,0,32,0,100,100,50,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,226,76,130,109,5,0,32,0,100,100,50,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,229,42,104,121,5,0,32,0,100,100,50,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,73,209,221,172,5,0,32,0,100,100,50,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,192,176,127,17,5,0,32,0,100,100,50,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,229,87,214,153,10,0,16,1,100,100,50,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,36,56,122,17,10,0,16,1,100,100,50,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,37,195,208,152,12,0,64,0,100,100,50,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,250,231,162,94,12,0,64,0,100,100,50,104,46,48,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,243,201,114,228,1,0,16,1,100,100,50,104,46,48,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,6,119,90,49,1,0,16,1,100,100,50,104,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,235,52,37,155,1,0,16,1,100,100,50,104,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,89,186,33,59,1,0,16,1,100,100,50,104,46,48,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,141,85,226,252,1,0,16,1,100,100,50,101,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,144,8,151,48,1,0,16,1,100,100,50,101,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,77,25,226,153,1,0,16,1,100,100,50,101,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,94,128,152,225,1,0,16,1,100,100,50,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,110,78,107,164,5,0,32,0,100,100,50,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,252,80,252,213,5,0,32,0,100,100,50,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,103,8,124,131,5,0,32,0,100,100,50,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,28,194,14,187,5,0,32,0,100,100,50,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,226,76,130,109,5,0,32,0,100,100,50,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,229,42,104,121,5,0,32,0,100,100,50,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,73,209,221,172,5,0,32,0,100,100,50,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,192,176,127,17,5,0,32,0,100,100,50,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,229,87,214,153,10,0,16,1,100,100,50,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,36,56,122,17,10,0,16,1,100,100,50,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,37,195,208,152,12,0,64,0,100,100,50,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,250,231,162,94,12,0,64,0,100,100,50,98,46,48,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,187,127,206,232,1,0,16,1,100,100,50,98,46,48,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,100,150,103,107,1,0,16,1,100,100,50,98,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,235,52,37,155,1,0,16,1,100,100,50,98,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,89,186,33,59,1,0,16,1,100,100,50,98,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,141,85,226,252,1,0,16,1,100,100,50,101,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,144,8,151,48,1,0,16,1,100,100,50,101,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,77,25,226,153,1,0,16,1,100,100,50,101,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,94,128,152,225,1,0,16,1,100,100,50,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,110,78,107,164,5,0,32,0,100,100,50,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,252,80,252,213,5,0,32,0,100,100,50,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,103,8,124,131,5,0,32,0,100,100,50,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,28,194,14,187,5,0,32,0,100,100,50,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,226,76,130,109,5,0,32,0,100,100,50,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,229,42,104,121,5,0,32,0,100,100,50,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,73,209,221,172,5,0,32,0,100,100,50,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,192,176,127,17,5,0,32,0,100,100,50,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,229,87,214,153,10,0,16,1,100,100,50,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,36,56,122,17,10,0,16,1,100,100,50,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,37,195,208,152,12,0,64,0,100,100,50,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,250,231,162,94,12,0,64,0,100,100,50,97,46,48,51,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,34,236,79,11,1,0,16,1,100,100,50,97,46,48,52,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,25,112,91,5,1,0,16,1,100,100,50,46,48,53,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,28,153,177,94,1,0,16,1,100,100,50,46,48,54,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,85,94,107,194,1,0,16,1,100,100,50,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,139,11,154,144,1,0,16,1,100,100,50,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,77,60,229,1,0,16,1,100,100,50,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,159,39,134,95,1,0,16,1,100,100,50,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,38,76,149,173,1,0,16,1,100,100,50,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,110,78,107,164,5,0,32,0,100,100,50,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,252,80,252,213,5,0,32,0,100,100,50,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,103,8,124,131,5,0,32,0,100,100,50,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,28,194,14,187,5,0,32,0,100,100,50,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,226,76,130,109,5,0,32,0,100,100,50,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,229,42,104,121,5,0,32,0,100,100,50,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,73,209,221,172,5,0,32,0,100,100,50,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,192,176,127,17,5,0,32,0,100,100,50,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,229,87,214,153,10,0,16,1,100,100,50,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,36,56,122,17,10,0,16,1,100,100,50,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,37,195,208,152,12,0,64,0,100,100,50,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,250,231,162,94,12,0,64,0,101,112,114,45,49,52,49,54,48,46,97,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,183,151,248,185,1,0,16,1,101,112,114,45,49,52,49,54,49,46,97,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,240,193,3,187,1,0,16,1,109,112,114,45,49,52,49,51,57,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,49,21,195,6,1,0,16,1,109,112,114,45,49,52,49,52,49,46,97,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,75,73,10,8,1,0,16,1,101,112,114,45,49,52,49,50,55,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,136,205,40,34,2,0,32,0,101,112,114,45,49,52,49,50,56,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,16,142,186,237,2,0,32,0,101,112,114,45,49,52,49,50,57,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,5,195,236,232,2,0,32,0,109,112,114,45,49,52,49,51,52,46,99,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,75,106,218,79,3,0,32,0,109,112,114,45,49,52,49,52,50,46,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,42,31,191,60,3,0,32,0,109,112,114,45,49,52,49,51,53,46,99,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,118,72,199,233,3,0,32,0,109,112,114,45,49,52,49,52,51,46,97,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,49,44,2,89,3,0,32,0,109,112,114,45,49,52,49,51,54,46,99,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,88,152,13,114,3,0,32,0,109,112,114,45,49,52,49,52,52,46,97,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,212,253,117,119,3,0,32,0,101,112,114,45,49,52,49,51,55,46,99,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,101,66,108,132,3,0,32,0,101,112,114,45,49,52,49,52,53,46,97,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,151,199,118,14,3,0,32,0,101,112,114,45,49,52,49,51,51,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,101,102,249,207,4,0,16,1,109,112,114,45,49,52,49,51,50,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,32,2,174,31,19,0,64,0,109,112,114,45,49,52,49,51,49,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,11,125,90,190,19,0,64,0,101,112,114,45,49,52,49,51,48,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,161,52,143,148,19,0,64,0,51,49,55,45,48,49,57,48,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,17,43,80,45,5,0,16,1,27,0,0,0,255,255,255,0,0,0,0,0,28,0,0,0,255,255,247,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,27,0,0,0,1,15,7,0,80,252,6,0,27,0,0,0,1,15,8,0,16,242,7,0,27,0,0,0,1,15,9,0,104,236,7,0,27,0,0,0,1,15,5,0,176,51,4,0,27,0,0,0,1,15,4,0,56,24,4,0,27,0,0,0,1,15,15,0,128,230,7,0,27,0,0,0,1,15,1,0,72,216,3,0,27,0,0,0,1,15,2,0,24,188,3,0,27,0,0,0,1,15,3,0,176,162,3,0,27,0,0,0,1,15,6,0,120,211,6,0,27,0,0,0,1,15,14,0,184,164,6,0,27,0,0,0,1,15,13,0,80,74,6,0,27,0,0,0,1,15,12,0,192,32,6,0,27,0,0,0,1,15,11,0,192,234,2,0,27,0,0,0,1,15,10,0,32,242,5,0,27,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,27,0,0,0,1,240,112,0,80,252,6,0,27,0,0,0,1,240,128,0,16,242,7,0,27,0,0,0,1,240,144,0,104,236,7,0,27,0,0,0,1,240,80,0,176,51,4,0,27,0,0,0,1,240,64,0,56,24,4,0,27,0,0,0,1,240,240,0,128,230,7,0,27,0,0,0,1,240,16,0,72,216,3,0,27,0,0,0,1,240,32,0,24,188,3,0,27,0,0,0,1,240,48,0,176,162,3,0,27,0,0,0,1,240,96,0,120,211,6,0,27,0,0,0,1,240,224,0,184,164,6,0,27,0,0,0,1,240,208,0,80,74,6,0,27,0,0,0,1,240,192,0,192,32,6,0,27,0,0,0,1,240,176,0,192,234,2,0,27,0,0,0,1,240,160,0,32,242,5,0,27,0,0,0,1,240,0,0,208,236,2,0,0,0,0,0,254,0,2,0,192,32,3,0,28,0,0,0,1,1,1,0,184,30,3,0,28,0,0,0,1,1,0,0,0,28,3,0,0,0,0,0,254,0,2,0,80,208,6,0,28,0,0,0,1,2,2,0,136,204,6,0,28,0,0,0,1,2,0,0,96,201,6,0,0,0,0,0,254,0,2,0,8,93,1,0,28,0,0,0,1,4,4,0,136,86,1,0,28,0,0,0,1,4,0,0,232,78,1,0,0,0,0,0,254,0,2,0,168,234,7,0,28,0,0,0,1,8,8,0,96,135,7,0,28,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,4,0,8,198,6,0,28,0,0,0,1,48,48,0,32,195,6,0,28,0,0,0,1,48,32,0,88,190,6,0,28,0,0,0,1,48,16,0,224,184,6,0,28,0,0,0,1,48,0,0,160,178,6,0,0,0,0,0,254,0,4,0,72,202,5,0,28,0,0,0,1,192,128,0,80,246,3,0,28,0,0,0,1,192,192,0,248,38,7,0,28,0,0,0,1,192,64,0,112,212,3,0,28,0,0,0,1,192,0,0,248,160,5,0,168,86,7,0,1,0,0,0,152,253,146,0,248,191,2,0,24,38,7,0,1,0,0,0,24,239,146,0,184,160,2,0,56,210,6,0,1,0,0,0,72,245,146,0,192,135,2,0,24,163,6,0,1,0,0,0,73,245,146,0,240,108,2,0,152,122,6,0,1,0,0,0,74,245,146,0,96,82,2,0,192,72,6,0,1,0,0,0,75,245,146,0,32,56,2,0,200,110,3,0,1,0,0,0,76,245,146,0,152,30,2,0,120,89,3,0,1,0,0,0,77,245,146,0,232,10,2,0,40,246,1,0,1,0,0,0,153,253,146,0,64,246,1,0,144,236,1,0,1,0,0,0,28,239,146,0,136,224,1,0,176,223,1,0,1,0,0,0,80,245,146,0,72,198,1,0,192,209,1,0,1,0,0,0,81,245,146,0,24,182,1,0,24,198,1,0,1,0,0,0,82,245,146,0,40,167,1,0,120,189,1,0,1,0,0,0,83,245,146,0,200,149,1,0,224,22,1,0,1,0,0,0,84,245,146,0,56,126,1,0,160,14,1,0,1,0,0,0,85,245,146,0,32,101,1,0,88,212,3,0,1,0,0,0,192,217,146,0,40,185,3,0,16,17,8,0,1,0,0,0,36,239,146,0,224,12,8,0,72,65,1,0,9,0,0,0,168,4,147,0,32,58,1,0,48,50,1,0,9,0,0,0,169,4,147,0,32,58,1,0,22,0,0,0,255,255,255,0,0,0,0,0,23,0,0,0,255,255,245,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,22,0,0,0,1,3,2,0,208,75,4,0,22,0,0,0,1,3,3,0,8,49,4,0,22,0,0,0,1,3,1,0,152,21,4,0,22,0,0,0,1,3,0,0,72,246,3,0,0,0,0,0,254,0,4,0,72,202,5,0,22,0,0,0,1,12,0,0,160,203,8,0,22,0,0,0,1,12,8,0,80,246,3,0,22,0,0,0,1,12,12,0,248,38,7,0,22,0,0,0,1,12,4,0,112,212,3,0,0,0,0,0,254,0,2,0,200,30,2,0,23,0,0,0,1,2,0,0,120,97,1,0,23,0,0,0,1,2,2,0,96,19,1,0,0,0,0,0,254,0,2,0,168,234,7,0,23,0,0,0,1,8,8,0,96,135,7,0,23,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,23,0,0,0,1,16,0,0,56,111,3,0,23,0,0,0,1,16,16,0,104,134,3,0,0,0,0,0,100,97,45,53,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,235,180,170,17,2,0,16,1,100,97,45,53,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,151,230,113,95,2,0,16,1,100,97,45,54,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,155,170,54,71,2,0,16,1,100,97,45,54,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,86,95,222,78,2,0,16,1,97,57,54,95,51,49,46,49,56,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,137,93,187,233,2,0,16,1,97,57,54,95,51,48,46,49,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,39,225,181,158,2,0,16,1,97,57,54,95,51,51,45,49,46,49,57,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,72,96,24,255,6,0,16,1,97,57,54,95,51,50,45,49,46,49,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,232,157,113,217,6,0,16,1,97,57,54,95,51,53,45,49,46,49,57,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,147,1,40,179,6,0,16,1,97,57,54,95,51,52,45,49,46,49,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,115,37,59,202,6,0,16,1,97,57,54,95,53,55,46,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,48,183,206,51,9,0,16,1,97,57,54,95,53,54,46,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,92,245,46,41,10,0,16,1,97,57,54,95,52,56,46,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,170,179,201,57,12,0,32,0,97,57,54,95,53,49,46,52,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,211,240,248,27,12,0,32,0,97,57,54,95,52,57,46,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,138,216,167,55,12,0,32,0,97,57,54,95,53,50,46,52,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,40,33,155,45,12,0,32,0,97,57,54,95,53,48,46,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,228,56,215,117,12,0,32,0,97,57,54,95,53,51,46,52,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,76,72,115,1,12,0,32,0,97,57,54,95,53,52,46,49,52,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,226,42,192,81,14,0,32,0,97,57,54,95,53,53,46,49,52,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,152,77,30,119,14,0,32,0,97,57,54,95,52,52,46,49,55,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,120,136,193,187,17,0,32,0,97,57,54,95,52,53,46,50,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,139,221,108,97,17,0,32,0,97,57,54,95,52,54,46,49,56,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,24,84,195,254,17,0,32,0,97,57,54,95,52,55,46,50,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,106,40,249,141,17,0,32,0,97,57,54,95,52,48,46,49,55,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,30,165,153,182,17,0,32,0,97,57,54,95,52,49,46,49,57,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,58,138,18,151,17,0,32,0,97,57,54,95,52,50,46,49,55,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,15,238,85,127,17,0,32,0,97,57,54,95,52,51,46,49,57,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,105,212,202,199,17,0,32,0,100,97,45,54,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,44,134,121,145,17,0,32,0,100,97,45,54,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,255,207,25,250,17,0,32,0,100,97,45,54,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,111,103,76,129,17,0,32,0,100,97,45,54,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,38,227,238,20,17,0,32,0,97,57,54,45,50,52,46,49,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,127,190,168,15,0,0,0,8,97,57,54,45,50,53,46,49,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,166,8,85,38,0,0,0,8,97,57,54,45,50,54,46,49,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,192,185,145,72,0,0,0,8,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,96,19,7,0,19,0,0,0,1,2,2,0,248,38,7,0,19,0,0,0,1,2,0,0,176,64,8,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,4,4,0,96,135,7,0,19,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,8,0,0,96,135,7,0,19,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,19,0,0,0,1,48,0,0,80,252,6,0,19,0,0,0,1,48,16,0,16,242,7,0,19,0,0,0,1,48,32,0,104,236,7,0,19,0,0,0,1,48,48,0,128,230,7,0,0,0,0,0,254,0,4,0,160,123,6,0,19,0,0,0,1,192,192,0,8,201,6,0,19,0,0,0,1,192,128,0,200,197,6,0,19,0,0,0,1,192,64,0,152,194,6,0,19,0,0,0,1,192,0,0,248,189,6,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,3,2,0,80,246,3,0,20,0,0,0,1,3,3,0,80,124,6,0,20,0,0,0,1,3,1,0,112,212,3,0,20,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,64,37,5,0,20,0,0,0,1,12,8,0,104,2,7,0,20,0,0,0,1,12,12,0,136,252,6,0,20,0,0,0,1,12,4,0,192,248,6,0,20,0,0,0,1,12,0,0,120,7,5,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,48,48,0,8,49,4,0,20,0,0,0,1,48,32,0,152,21,4,0,20,0,0,0,1,48,16,0,72,246,3,0,20,0,0,0,1,48,0,0,72,0,3,0,0,0,0,0,254,0,2,0,104,159,3,0,20,0,0,0,1,128,0,0,96,135,7,0,20,0,0,0,1,128,128,0,152,182,7,0,0,0,0,0,22,0,0,0,255,255,96,0,0,0,0,0,23,0,0,0,255,255,1,0,0,0,0,0,0,0,0,0,254,0,2,0,232,75,4,0,22,0,0,0,1,32,32,0,96,135,7,0,22,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,192,3,0,22,0,0,0,1,64,64,0,96,135,7,0,22,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,48,45,3,0,23,0,0,0,1,1,0,0,176,20,3,0,23,0,0,0,1,1,1,0,224,32,1,0,0,0,0,0,99,121,98,101,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,205,129,67,35,1,0,16,1,99,121,98,101,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,16,105,128,1,0,16,1,99,121,98,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,142,64,64,236,1,0,16,1,99,121,98,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,210,190,208,26,1,0,16,1,99,121,98,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,154,163,69,98,1,0,16,1,99,121,98,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,35,226,72,75,1,0,16,1,99,121,98,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,56,82,225,1,0,16,1,99,121,98,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,59,0,244,117,1,0,16,1,99,121,98,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,146,225,220,240,5,0,32,0,99,121,98,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,156,163,122,24,5,0,32,0,99,121,98,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,18,75,14,138,5,0,32,0,99,121,98,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,18,38,182,52,5,0,32,0,99,121,98,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,87,121,83,193,5,0,32,0,99,121,98,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,134,158,52,21,5,0,32,0,99,121,98,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,125,151,62,216,5,0,32,0,99,121,98,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,92,173,205,119,5,0,32,0,99,121,98,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,121,176,15,156,10,0,16,1,99,121,98,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,78,12,203,81,10,0,16,1,99,121,98,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,178,202,44,54,12,0,64,0,99,121,98,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,204,233,102,112,12,0,64,0,99,119,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,61,114,193,211,0,0,16,1,99,119,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,163,212,30,215,0,0,16,1,99,119,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,8,206,25,212,0,0,16,1,99,119,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,60,218,128,108,0,0,32,0,99,119,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,113,218,7,118,0,0,32,0,99,119,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,159,99,14,111,0,0,32,0,99,119,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,192,215,11,19,0,0,32,0,99,119,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,201,224,110,190,0,0,32,0,99,119,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,50,85,252,81,0,0,32,0,99,119,50,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,88,29,56,88,0,0,32,0,99,119,50,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,83,199,12,145,0,0,32,0,99,119,49,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,209,23,2,249,0,0,32,0,99,119,49,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,2,199,83,201,0,0,32,0,99,119,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,91,143,54,244,0,0,64,0,50,56,97,49,54,45,50,46,105,99,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,99,46,107,196,0,0,16,1,50,56,97,49,53,45,50,46,105,99,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,85,199,33,50,0,0,16,1,50,56,106,49,55,45,48,46,49,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,189,109,44,140,0,0,16,1,50,56,97,49,48,45,48,46,105,99,56,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,19,222,70,67,0,0,16,1,50,56,106,55,45,48,46,105,99,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,241,115,183,168,0,0,32,0,50,56,106,54,45,48,46,105,99,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,252,48,117,97,0,0,32,0,50,56,106,53,45,48,46,105,99,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,33,168,240,206,0,0,32,0,50,56,106,52,45,48,46,105,99,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,9,218,79,184,0,0,32,0,50,56,106,51,45,48,46,105,99,55,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,164,194,26,0,0,32,0,50,56,97,49,52,45,48,46,105,99,54,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,219,173,47,151,0,0,32,0,50,56,106,50,45,48,46,105,99,55,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,7,103,121,140,0,0,32,0,50,56,97,49,51,45,48,46,105,99,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,116,179,58,235,0,0,32,0,50,56,106,49,45,48,46,105,99,57,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,189,173,155,28,0,0,32,0,50,56,97,49,50,45,48,46,105,99,56,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,151,172,2,198,0,0,32,0,50,56,106,48,45,48,46,105,99,57,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,158,196,115,186,0,0,32,0,50,56,97,49,49,45,48,46,105,99,56,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,229,216,161,77,0,0,32,0,50,56,106,57,45,48,46,105,99,56,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,74,127,42,249,0,0,64,0,50,56,106,56,45,48,46,105,99,56,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,57,11,58,26,0,0,64,0,50,56,46,105,99,52,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,239,41,67,150,0,0,32,0,28,0,0,0,255,255,16,0,0,0,0,0,29,0,0,0,255,255,255,0,0,0,0,0,30,0,0,0,255,255,255,0,0,0,0,0,31,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,28,0,0,0,1,16,16,0,96,135,7,0,28,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,4,0,32,4,2,0,29,0,0,0,1,3,0,0,16,242,7,0,29,0,0,0,1,3,1,0,104,236,7,0,29,0,0,0,1,3,3,0,128,230,7,0,29,0,0,0,1,3,2,0,184,164,6,0,0,0,0,0,254,0,2,0,0,76,5,0,29,0,0,0,1,16,16,0,96,135,7,0,29,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,29,0,0,0,1,32,0,0,96,135,7,0,29,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,30,0,0,0,1,3,2,0,80,246,3,0,30,0,0,0,1,3,3,0,248,38,7,0,30,0,0,0,1,3,1,0,112,212,3,0,30,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,2,0,72,84,4,0,30,0,0,0,1,4,4,0,248,38,7,0,30,0,0,0,1,4,0,0,176,64,8,0,0,0,0,0,254,0,2,0,232,219,3,0,30,0,0,0,1,8,0,0,96,135,7,0,30,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,2,0,184,89,6,0,30,0,0,0,1,16,16,0,96,135,7,0,30,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,2,0,24,254,3,0,30,0,0,0,1,32,32,0,24,205,7,0,30,0,0,0,1,32,0,0,136,66,4,0,0,0,0,0,254,0,2,0,184,165,3,0,31,0,0,0,1,1,1,0,96,135,7,0,31,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,119,7,0,31,0,0,0,1,2,2,0,208,75,4,0,31,0,0,0,1,2,0,0,8,49,4,0,0,0,0,0,99,115,99,101,46,48,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,8,0,190,130,64,130,1,0,16,1,99,115,99,101,46,48,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,254,164,230,116,1,0,16,1,99,115,99,101,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,25,223,224,138,1,0,16,1,99,115,99,101,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,211,240,242,81,1,0,16,1,99,115,99,101,46,48,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,253,104,57,0,1,0,16,1,99,115,99,46,55,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,195,7,95,51,7,0,32,0,99,115,99,46,55,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,87,83,33,171,7,0,32,0,99,115,99,46,55,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,129,115,54,162,7,0,32,0,99,115,99,46,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,31,172,138,114,7,0,32,0,99,115,99,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,202,184,17,55,7,0,32,0,99,115,99,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,216,6,138,130,7,0,32,0,99,115,99,46,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,105,69,238,134,7,0,32,0,99,115,99,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,127,87,79,194,7,0,32,0,99,115,99,46,56,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,42,209,80,7,7,0,32,0,99,115,99,46,56,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,57,47,169,144,7,0,32,0,99,115,99,46,56,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,18,176,138,208,7,0,32,0,99,115,99,46,56,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,131,37,101,65,7,0,32,0,99,115,99,46,57,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,247,199,86,167,7,0,32,0,99,115,99,46,57,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,115,204,124,251,7,0,32,0,99,115,99,46,57,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,151,66,1,77,7,0,32,0,99,115,99,46,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,239,177,84,103,7,0,32,0,99,115,99,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,17,33,22,238,10,0,16,1,99,115,99,46,53,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,213,175,82,90,12,0,64,0,99,115,99,46,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,17,168,8,20,12,0,64,0,99,115,99,46,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,124,245,185,79,12,0,64,0,99,115,99,46,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,64,143,154,12,0,64,0,99,115,99,46,53,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,145,154,82,145,12,0,64,0,99,115,99,46,53,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,52,83,52,154,12,0,64,0,99,115,99,46,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,242,39,220,174,12,0,64,0,99,115,99,46,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,179,183,0,35,12,0,64,0,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,208,19,6,0,19,0,0,0,1,1,1,0,224,16,6,0,19,0,0,0,1,1,0,0,160,12,6,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,2,2,0,96,135,7,0,19,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,4,4,0,96,135,7,0,19,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,8,0,0,96,135,7,0,19,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,19,0,0,0,1,48,0,0,32,136,7,0,19,0,0,0,1,48,16,0,40,88,7,0,19,0,0,0,1,48,32,0,96,39,7,0,19,0,0,0,1,48,48,0,144,251,6,0,0,0,0,0,254,0,4,0,160,123,6,0,19,0,0,0,1,192,192,0,184,164,6,0,19,0,0,0,1,192,128,0,80,74,6,0,19,0,0,0,1,192,64,0,192,32,6,0,19,0,0,0,1,192,0,0,32,242,5,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,3,2,0,80,246,3,0,20,0,0,0,1,3,3,0,80,124,6,0,20,0,0,0,1,3,1,0,112,212,3,0,20,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,64,37,5,0,20,0,0,0,1,12,8,0,80,6,6,0,20,0,0,0,1,12,12,0,104,1,6,0,20,0,0,0,1,12,4,0,96,251,5,0,20,0,0,0,1,12,0,0,120,7,5,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,48,16,0,192,255,2,0,20,0,0,0,1,48,32,0,208,75,4,0,20,0,0,0,1,48,48,0,8,49,4,0,20,0,0,0,1,48,0,0,152,21,4,0,0,0,0,0,254,0,4,0,104,159,3,0,20,0,0,0,1,192,0,0,96,135,7,0,20,0,0,0,1,192,64,0,88,239,5,0,20,0,0,0,1,192,128,0,96,235,5,0,20,0,0,0,1,192,192,0,152,182,7,0,101,112,114,45,49,51,57,50,49,97,46,97,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,55,160,71,240,1,0,16,1,101,112,114,45,49,51,57,49,57,97,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,177,8,17,101,1,0,16,1,101,112,114,45,49,51,57,50,50,97,46,97,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,197,72,162,28,1,0,16,1,101,112,114,45,49,51,57,50,48,97,46,97,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,249,16,54,250,1,0,16,1,111,112,114,45,49,51,56,54,50,46,97,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,182,84,115,164,2,0,32,0,111,112,114,45,49,51,56,55,55,46,98,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,181,36,132,211,2,0,32,0,111,112,114,45,49,51,56,54,51,46,97,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,38,0,153,140,2,0,32,0,111,112,114,45,49,51,56,55,56,46,98,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,138,91,193,33,2,0,32,0,111,112,114,45,49,51,56,54,52,46,97,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,191,117,177,210,2,0,32,0,111,112,114,45,49,51,56,55,57,46,98,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,49,37,214,185,2,0,32,0,111,112,114,45,49,51,56,54,53,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,4,244,36,112,3,0,32,0,111,112,114,45,49,51,56,54,57,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,104,52,75,171,3,0,32,0,111,112,114,45,49,51,56,54,54,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,164,187,105,97,3,0,32,0,111,112,114,45,49,51,56,55,48,46,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,195,26,180,105,3,0,32,0,111,112,114,45,49,51,56,54,55,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,45,240,20,176,3,0,32,0,111,112,114,45,49,51,56,55,49,46,98,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,2,207,1,8,3,0,32,0,111,112,114,45,49,51,56,54,56,46,98,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,214,124,42,230,3,0,32,0,111,112,114,45,49,51,56,55,50,46,98,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,21,243,102,240,3,0,32,0,111,112,114,45,49,51,56,53,50,46,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,139,186,58,148,3,0,32,0,111,112,114,45,49,51,56,55,51,46,98,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,243,69,209,27,3,0,32,0,111,112,114,45,49,51,56,53,51,46,97,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,50,169,126,3,0,32,0,111,112,114,45,49,51,56,55,52,46,98,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,255,155,213,79,3,0,32,0,111,112,114,45,49,51,56,57,49,46,97,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,20,196,179,198,3,0,32,0,111,112,114,45,49,51,56,57,52,46,98,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,226,190,208,227,3,0,32,0,111,112,114,45,49,51,56,53,53,46,97,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,226,62,111,133,3,0,32,0,111,112,114,45,49,51,56,55,54,46,98,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,216,250,95,28,3,0,32,0,101,112,114,45,49,51,56,57,50,46,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,173,230,251,253,4,0,16,1,111,112,114,45,49,51,56,57,51,46,97,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,223,51,66,56,8,0,64,0,51,49,55,45,48,49,56,49,97,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,54,155,65,92,5,0,16,1,19,0,0,0,255,255,254,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,1,1,0,96,135,7,0,19,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,19,0,0,0,1,6,4,0,208,75,4,0,19,0,0,0,1,6,6,0,8,49,4,0,19,0,0,0,1,6,2,0,152,21,4,0,19,0,0,0,1,6,0,0,72,246,3,0,0,0,0,0,254,0,4,0,72,202,5,0,19,0,0,0,1,24,16,0,80,246,3,0,19,0,0,0,1,24,24,0,248,38,7,0,19,0,0,0,1,24,8,0,112,212,3,0,19,0,0,0,1,24,0,0,248,160,5,0,0,0,0,0,254,0,16,0,200,87,7,0,20,0,0,0,1,15,7,0,80,252,6,0,20,0,0,0,1,15,8,0,16,242,7,0,20,0,0,0,1,15,9,0,104,236,7,0,20,0,0,0,1,15,5,0,176,51,4,0,20,0,0,0,1,15,4,0,56,24,4,0,20,0,0,0,1,15,15,0,128,230,7,0,20,0,0,0,1,15,1,0,72,216,3,0,20,0,0,0,1,15,2,0,24,188,3,0,20,0,0,0,1,15,3,0,176,162,3,0,20,0,0,0,1,15,6,0,120,211,6,0,20,0,0,0,1,15,14,0,184,164,6,0,20,0,0,0,1,15,13,0,80,74,6,0,20,0,0,0,1,15,12,0,192,32,6,0,20,0,0,0,1,15,11,0,192,234,2,0,20,0,0,0,1,15,10,0,32,242,5,0,20,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,20,0,0,0,1,240,112,0,80,252,6,0,20,0,0,0,1,240,128,0,16,242,7,0,20,0,0,0,1,240,144,0,104,236,7,0,20,0,0,0,1,240,80,0,176,51,4,0,20,0,0,0,1,240,64,0,56,24,4,0,20,0,0,0,1,240,240,0,128,230,7,0,20,0,0,0,1,240,16,0,72,216,3,0,20,0,0,0,1,240,32,0,24,188,3,0,20,0,0,0,1,240,48,0,176,162,3,0,20,0,0,0,1,240,96,0,120,211,6,0,20,0,0,0,1,240,224,0,184,164,6,0,20,0,0,0,1,240,208,0,80,74,6,0,20,0,0,0,1,240,192,0,192,32,6,0,20,0,0,0,1,240,176,0,192,234,2,0,20,0,0,0,1,240,160,0,32,242,5,0,20,0,0,0,1,240,0,0,208,236,2,0,0,0,0,0,18,0,0,0,255,255,255,0,0,0,0,0,19,0,0,0,255,255,127,0,0,0,0,0,0,0,0,0,254,0,8,0,200,87,7,0,18,0,0,0,1,7,0,0,40,88,7,0,18,0,0,0,1,7,1,0,96,39,7,0,18,0,0,0,1,7,7,0,144,251,6,0,18,0,0,0,1,7,6,0,184,164,6,0,18,0,0,0,1,7,5,0,80,74,6,0,18,0,0,0,1,7,4,0,192,32,6,0,18,0,0,0,1,7,3,0,192,234,2,0,18,0,0,0,1,7,2,0,32,242,5,0,0,0,0,0,254,0,8,0,160,123,6,0,18,0,0,0,1,56,0,0,40,88,7,0,18,0,0,0,1,56,8,0,96,39,7,0,18,0,0,0,1,56,56,0,144,251,6,0,18,0,0,0,1,56,48,0,184,164,6,0,18,0,0,0,1,56,40,0,80,74,6,0,18,0,0,0,1,56,32,0,192,32,6,0,18,0,0,0,1,56,24,0,192,234,2,0,18,0,0,0,1,56,16,0,32,242,5,0,0,0,0,0,254,0,2,0,144,212,8,0,18,0,0,0,1,64,64,0,96,135,7,0,18,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,19,0,0,0,1,3,1,0,192,255,2,0,19,0,0,0,1,3,0,0,208,75,4,0,19,0,0,0,1,3,3,0,8,49,4,0,19,0,0,0,1,3,2,0,152,21,4,0,0,0,0,0,254,0,4,0,72,202,5,0,19,0,0,0,1,12,8,0,80,246,3,0,19,0,0,0,1,12,12,0,248,38,7,0,19,0,0,0,1,12,4,0,112,212,3,0,19,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,2,0,24,226,7,0,19,0,0,0,1,16,16,0,96,135,7,0,19,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,128,128,0,96,135,7,0,19,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,118,105,100,95,50,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,52,194,168,73,1,0,16,1,118,105,100,95,50,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,241,103,182,241,1,0,16,1,118,105,100,95,50,102,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,93,183,148,177,1,0,16,1,118,105,100,95,50,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,138,186,82,32,1,0,16,1,118,105,100,95,50,106,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,208,175,119,179,1,0,16,1,118,105,100,95,50,108,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,145,230,101,254,1,0,16,1,116,117,114,116,95,115,110,100,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,154,15,195,240,2,0,16,1,115,110,100,95,53,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,71,149,44,137,2,0,16,1,118,105,100,95,53,102,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,203,210,102,120,4,0,32,0,118,105,100,95,53,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,1,161,17,115,4,0,32,0,118,105,100,95,54,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,151,175,57,80,7,0,32,0,15,0,0,0,255,255,0,0,0,0,0,0,16,0,0,0,255,255,0,0,0,0,0,0,17,0,0,0,255,255,2,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,17,0,0,0,1,2,2,0,120,97,1,0,17,0,0,0,1,2,0,0,96,19,1,0,0,0,0,0,254,0,2,0,128,129,4,0,17,0,0,0,1,4,0,0,8,49,4,0,17,0,0,0,1,4,4,0,152,21,4,0,0,0,0,0,103,95,99,107,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,148,59,50,164,1,0,16,1,99,107,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,150,41,83,30,1,0,16,1,103,95,99,107,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,222,124,21,101,1,0,16,1,103,95,99,107,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,198,123,130,67,1,0,16,1,103,95,99,107,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,110,217,78,167,1,0,16,1,103,95,99,107,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,41,129,77,44,1,0,16,1,99,107,118,105,100,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,203,210,102,120,4,0,32,0,99,107,118,105,100,55,46,98])
.concat([105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,1,161,17,115,4,0,32,0,99,107,95,99,112,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,203,121,11,126,7,0,32,0,15,0,0,0,255,255,0,0,0,0,0,0,16,0,0,0,255,255,128,0,0,0,0,0,17,0,0,0,255,255,10,0,0,0,0,0,0,0,0,0,254,0,2,0,32,4,2,0,16,0,0,0,1,64,0,0,80,196,7,0,16,0,0,0,1,64,64,0,72,74,2,0,0,0,0,0,254,0,4,0,128,129,4,0,17,0,0,0,1,3,0,0,192,255,2,0,17,0,0,0,1,3,1,0,208,75,4,0,17,0,0,0,1,3,2,0,8,49,4,0,17,0,0,0,1,3,3,0,152,21,4,0,0,0,0,0,254,0,2,0,64,37,5,0,17,0,0,0,1,8,8,0,232,130,1,0,17,0,0,0,1,8,0,0,160,129,1,0,99,104,106,95,51,54,97,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,216,40,19,236,1,0,16,1,99,104,106,95,52,50,97,46,49,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,3,53,225,74,1,0,16,1,99,104,106,95,51,55,97,46,49,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,123,207,210,70,1,0,16,1,99,104,106,95,52,51,97,46,49,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,232,127,56,141,1,0,16,1,99,104,95,51,52,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,249,210,158,96,1,0,16,1,99,104,95,52,48,46,49,48,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,1,131,13,190,1,0,16,1,99,104,95,51,53,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,127,134,16,184,1,0,16,1,99,104,95,52,49,46,49,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,85,97,217,138,1,0,16,1,99,104,95,48,57,46,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,202,179,122,86,4,0,32,0,99,104,95,48,49,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,86,123,59,127,4,0,32,0,99,104,95,49,51,46,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,186,168,167,18,4,0,32,0,99,104,95,48,53,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,154,251,26,108,4,0,32,0,99,104,95,50,52,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,188,230,182,156,4,0,32,0,99,104,95,49,55,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,70,8,73,254,4,0,32,0,99,104,95,51,56,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,182,140,92,110,4,0,32,0,99,104,95,51,50,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,176,39,125,49,4,0,32,0,99,104,95,49,48,46,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,155,26,37,232,4,0,32,0,99,104,95,48,50,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,251,136,140,124,4,0,32,0,99,104,95,49,52,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,75,236,18,64,4,0,32,0,99,104,95,48,54,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,43,75,136,129,4,0,32,0,99,104,95,50,53,46,55,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,197,186,252,29,4,0,32,0,99,104,95,49,56,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,209,52,106,81,4,0,32,0,99,104,95,51,57,46,57,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,164,178,47,135,4,0,32,0,99,104,95,51,51,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,237,93,220,48,4,0,32,0,99,104,95,50,51,46,49,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,183,85,66,77,3,0,16,0,99,104,95,51,48,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,222,232,9,249,5,0,64,0,99,104,95,51,49,46,49,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,247,140,21,252,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,99,107,50,50,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,0,0,0,0,0,0,24,105,111,98,49,46,49,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,99,97,101,95,51,48,97,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,205,234,252,145,1,0,16,1,99,97,101,95,51,53,97,46,49,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,131,48,240,62,1,0,16,1,99,97,101,95,51,49,97,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,175,92,183,229,1,0,16,1,99,97,101,95,51,54,97,46,49,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,19,215,63,199,1,0,16,1,99,97,45,51,50,109,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,212,55,72,12,2,0,16,1,99,97,45,53,109,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,55,204,212,102,4,0,32,0,99,97,45,55,109,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,242,150,248,182,4,0,32,0,99,97,45,49,109,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,253,32,6,77,4,0,32,0,99,97,45,51,109,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,195,65,3,11,4,0,32,0,99,97,95,57,46,49,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,133,116,254,150,3,0,16,0,99,97,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,44,58,97,74,5,0,64,0,99,97,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,147,68,88,116,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,99,97,50,52,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,28,11,236,118,0,0,0,8,105,111,98,49,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,21,0,0,0,255,255,0,0,0,0,0,0,22,0,0,0,255,255,3,0,0,0,0,0,23,0,0,0,255,255,96,0,0,0,0,0,0,0,0,0,254,0,8,0,200,87,7,0,21,0,0,0,1,7,7,0,80,252,6,0,21,0,0,0,1,7,6,0,16,242,7,0,21,0,0,0,1,7,5,0,104,236,7,0,21,0,0,0,1,7,0,0,128,230,7,0,21,0,0,0,1,7,1,0,184,164,6,0,21,0,0,0,1,7,2,0,80,74,6,0,21,0,0,0,1,7,3,0,192,32,6,0,21,0,0,0,1,7,4,0,32,242,5,0,0,0,0,0,254,0,8,0,160,123,6,0,21,0,0,0,1,56,56,0,80,252,6,0,21,0,0,0,1,56,48,0,16,242,7,0,21,0,0,0,1,56,40,0,104,236,7,0,21,0,0,0,1,56,0,0,128,230,7,0,21,0,0,0,1,56,8,0,184,164,6,0,21,0,0,0,1,56,16,0,80,74,6,0,21,0,0,0,1,56,24,0,192,32,6,0,21,0,0,0,1,56,32,0,32,242,5,0,0,0,0,0,254,0,2,0,64,232,1,0,21,0,0,0,1,64,0,0,96,135,7,0,21,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,8,0,56,31,1,0,22,0,0,0,1,7,0,0,72,198,6,0,22,0,0,0,1,7,1,0,208,75,4,0,22,0,0,0,1,7,2,0,8,49,4,0,22,0,0,0,1,7,3,0,72,195,6,0,22,0,0,0,1,7,4,0,72,246,3,0,22,0,0,0,1,7,5,0,72,0,3,0,22,0,0,0,1,7,6,0,64,47,7,0,22,0,0,0,1,7,7,0,48,173,6,0,0,0,0,0,254,0,4,0,208,30,1,0,22,0,0,0,1,24,8,0,80,246,3,0,22,0,0,0,1,24,0,0,248,38,7,0,22,0,0,0,1,24,16,0,48,123,8,0,22,0,0,0,1,24,24,0,8,117,8,0,0,0,0,0,254,0,2,0,16,227,4,0,23,0,0,0,1,4,0,0,96,135,7,0,23,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,254,0,2,0,72,4,1,0,23,0,0,0,1,8,0,0,96,135,7,0,23,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,2,0,120,207,1,0,23,0,0,0,1,16,0,0,96,135,7,0,23,0,0,0,1,16,16,0,152,182,7,0,0,0,0,0,254,0,2,0,160,94,8,0,23,0,0,0,1,32,0,0,96,135,7,0,23,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,23,0,0,0,1,64,0,0,96,135,7,0,23,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,168,79,2,0,23,0,0,0,1,128,0,0,32,182,8,0,23,0,0,0,1,128,128,0,80,251,6,0,19,0,0,0,255,255,254,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,2,2,0,96,135,7,0,19,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,4,4,0,96,135,7,0,19,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,8,0,0,96,135,7,0,19,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,19,0,0,0,1,48,0,0,32,136,7,0,19,0,0,0,1,48,16,0,40,88,7,0,19,0,0,0,1,48,32,0,96,39,7,0,19,0,0,0,1,48,48,0,144,251,6,0,0,0,0,0,254,0,4,0,160,123,6,0,19,0,0,0,1,192,192,0,184,164,6,0,19,0,0,0,1,192,128,0,80,74,6,0,19,0,0,0,1,192,64,0,192,32,6,0,19,0,0,0,1,192,0,0,32,242,5,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,3,2,0,80,246,3,0,20,0,0,0,1,3,3,0,80,124,6,0,20,0,0,0,1,3,1,0,112,212,3,0,20,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,0,191,7,0,20,0,0,0,1,12,0,0,208,183,7,0,20,0,0,0,1,12,4,0,208,179,7,0,20,0,0,0,1,12,12,0,72,176,7,0,20,0,0,0,1,12,8,0,24,172,7,0,0,0,0,0,254,0,4,0,136,123,7,0,20,0,0,0,1,48,0,0,24,164,7,0,20,0,0,0,1,48,16,0,40,159,7,0,20,0,0,0,1,48,48,0,80,155,7,0,20,0,0,0,1,48,32,0,152,149,7,0,0,0,0,0,254,0,3,0,56,143,7,0,20,0,0,0,1,192,192,0,112,137,7,0,20,0,0,0,1,192,128,0,40,133,7,0,20,0,0,0,1,192,0,0,144,129,7,0,19,0,0,0,255,255,60,0,0,0,0,0,20,0,0,0,255,255,0,0,0,0,0,0,21,0,0,0,255,255,64,0,0,0,0,0,0,0,0,0,254,0,2,0,16,227,4,0,19,0,0,0,1,4,4,0,96,135,7,0,19,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,19,0,0,0,1,24,24,0,8,49,4,0,19,0,0,0,1,24,16,0,152,21,4,0,19,0,0,0,1,24,8,0,72,246,3,0,19,0,0,0,1,24,0,0,216,128,5,0,0,0,0,0,254,0,0,0,144,212,8,0,19,0,0,0,1,64,0,0,96,135,7,0,19,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,200,30,2,0,19,0,0,0,1,128,0,0,120,97,1,0,19,0,0,0,1,128,128,0,96,19,1,0,0,0,0,0,254,0,2,0,200,87,7,0,20,0,0,0,1,15,15,0,120,247,3,0,20,0,0,0,1,15,14,0,104,213,3,0,20,0,0,0,1,15,13,0,224,185,3,0,20,0,0,0,1,15,12,0,144,160,3,0,20,0,0,0,1,15,11,0,96,135,3,0,20,0,0,0,1,15,10,0,32,136,7,0,20,0,0,0,1,15,9,0,40,88,7,0,20,0,0,0,1,15,8,0,96,39,7,0,20,0,0,0,1,15,0,0,144,251,6,0,20,0,0,0,1,15,1,0,184,164,6,0,20,0,0,0,1,15,2,0,80,74,6,0,20,0,0,0,1,15,3,0,192,32,6,0,20,0,0,0,1,15,4,0,192,234,2,0,20,0,0,0,1,15,5,0,32,242,5,0,20,0,0,0,1,15,6,0,176,192,2,0,20,0,0,0,1,15,7,0,248,175,2,0,0,0,0,0,254,0,16,0,160,123,6,0,20,0,0,0,1,240,240,0,120,247,3,0,20,0,0,0,1,240,224,0,104,213,3,0,20,0,0,0,1,240,208,0,224,185,3,0,20,0,0,0,1,240,192,0,144,160,3,0,20,0,0,0,1,240,176,0,96,135,3,0,20,0,0,0,1,240,160,0,32,136,7,0,20,0,0,0,1,240,144,0,40,88,7,0,20,0,0,0,1,240,128,0,96,39,7,0,20,0,0,0,1,240,0,0,144,251,6,0,20,0,0,0,1,240,16,0,184,164,6,0,20,0,0,0,1,240,32,0,80,74,6,0,20,0,0,0,1,240,48,0,192,32,6,0,20,0,0,0,1,240,64,0,192,234,2,0,20,0,0,0,1,240,80,0,32,242,5,0,20,0,0,0,1,240,96,0,176,192,2,0,20,0,0,0,1,240,112,0,248,175,2,0,0,0,0,0,254,0,2,0,112,109,2,0,21,0,0,0,1,64,64,0,96,135,7,0,21,0,0,0,1,64,0,0,152,182,7,0,101,112,114,45,49,49,48,49,48,46,97,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,222,1,144,221,1,0,16,1,101,112,114,45,49,49,48,48,55,46,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,16,129,224,217,1,0,16,1,101,112,114,45,49,49,48,49,49,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,159,107,68,127,1,0,16,1,101,112,114,45,49,49,48,48,56,46,97,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,59,77,130,52,1,0,16,1,101,112,114,45,49,49,48,49,50,46,97,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,89,241,146,57,1,0,16,1,101,112,114,45,49,49,48,48,57,46,97,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,153,153,25,223,1,0,16,1,101,112,114,45,49,48,57,57,52,46,98,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,138,70,53,48,2,0,32,0,101,112,114,45,49,48,57,57,53,46,98,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,241,175,151,107,2,0,32,0,101,112,114,45,49,48,57,57,54,46,98,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,214,221,27,80,2,0,32,0,101,112,114,45,49,48,57,57,57,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,8,0,159,17,3,0,32,0,101,112,114,45,49,49,48,48,51,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,137,144,66,47,3,0,32,0,101,112,114,45,49,49,48,48,48,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,190,43,72,245,3,0,32,0,101,112,114,45,49,49,48,48,52,46,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,240,109,136,140,3,0,32,0,101,112,114,45,49,49,48,48,49,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,224,113,234,101,3,0,32,0,101,112,114,45,49,49,48,48,53,46,98,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,80,157,47,234,3,0,32,0,101,112,114,45,49,49,48,48,50,46,98,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,43,4,37,158,3,0,32,0,101,112,114,45,49,49,48,48,54,46,98,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,242,132,115,107,3,0,32,0,101,112,114,45,49,48,57,57,55,46,97,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,181,202,217,93,4,0,16,1,101,112,114,45,49,48,57,57,56,46,97,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0])
.concat([23,168,113,249,8,0,64,0,51,49,55,45,48,48,52,49,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,26,134,212,76,5,0,16,1,33,0,0,0,255,255,255,0,0,0,0,0,34,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,34,0,0,0,1,15,7,0,80,252,6,0,34,0,0,0,1,15,8,0,16,242,7,0,34,0,0,0,1,15,9,0,104,236,7,0,34,0,0,0,1,15,5,0,176,51,4,0,34,0,0,0,1,15,4,0,56,24,4,0,34,0,0,0,1,15,15,0,128,230,7,0,34,0,0,0,1,15,1,0,72,216,3,0,34,0,0,0,1,15,2,0,24,188,3,0,34,0,0,0,1,15,3,0,176,162,3,0,34,0,0,0,1,15,6,0,120,211,6,0,34,0,0,0,1,15,14,0,184,164,6,0,34,0,0,0,1,15,13,0,80,74,6,0,34,0,0,0,1,15,12,0,192,32,6,0,34,0,0,0,1,15,11,0,192,234,2,0,34,0,0,0,1,15,10,0,32,242,5,0,34,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,34,0,0,0,1,240,112,0,80,252,6,0,34,0,0,0,1,240,128,0,16,242,7,0,34,0,0,0,1,240,144,0,104,236,7,0,34,0,0,0,1,240,80,0,176,51,4,0,34,0,0,0,1,240,64,0,56,24,4,0,34,0,0,0,1,240,240,0,128,230,7,0,34,0,0,0,1,240,16,0,72,216,3,0,34,0,0,0,1,240,32,0,24,188,3,0,34,0,0,0,1,240,48,0,176,162,3,0,34,0,0,0,1,240,96,0,120,211,6,0,34,0,0,0,1,240,224,0,184,164,6,0,34,0,0,0,1,240,208,0,80,74,6,0,34,0,0,0,1,240,192,0,192,32,6,0,34,0,0,0,1,240,176,0,192,234,2,0,34,0,0,0,1,240,160,0,32,242,5,0,34,0,0,0,1,240,0,0,208,236,2,0,99,51,52,95,55,49,46,57,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,41,166,31,223,2,0,16,1,99,51,52,95,54,57,46,55,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,122,19,76,165,2,0,16,1,99,51,52,95,55,48,46,57,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,226,129,125,215,2,0,16,1,99,51,52,95,54,56,46,55,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,226,76,55,78,2,0,16,1,99,51,52,95,55,52,46,49,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,153,250,105,104,6,0,16,1,99,51,52,95,55,50,46,49,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,145,15,156,192,6,0,16,1,99,51,52,95,55,53,46,49,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,66,85,166,107,6,0,16,1,99,51,52,95,55,51,46,49,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,181,98,254,242,6,0,16,1,99,51,52,95,48,53,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,218,131,107,89,11,0,32,0,99,51,52,95,48,52,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,218,176,70,36,17,0,32,0,99,51,52,95,48,51,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,120,171,142,161,17,0,32,0,99,51,52,95,48,50,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,16,186,136,132,17,0,32,0,99,51,52,95,48,49,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,99,140,190,62,17,0,32,0,99,51,52,95,48,55,46,52,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,8,120,176,237,22,0,32,0,99,51,52,95,48,54,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,235,182,0,210,23,0,32,0,99,51,52,95,48,56,46,49,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,80,4,163,137,24,0,64,0,99,51,52,95,48,57,46,49,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,80,43,209,57,25,0,64,0,99,51,52,95,49,56,46,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,246,166,69,114,0,0,0,8,99,51,52,95,49,57,46,55,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,4,196,233,46,0,0,0,8,99,51,52,95,50,48,46,56,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,48,31,248,251,0,0,0,8,99,51,52,95,50,49,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,83,136,114,16,0,0,0,8,99,51,52,95,50,50,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,252,139,62,100,0,0,0,8,11,0,0,0,255,255,255,0,0,0,0,0,12,0,0,0,255,255,247,0,0,0,0,0,0,0,0,0,254,0,2,0,144,95,6,0,11,0,0,0,1,1,1,0,96,135,7,0,11,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,11,0,0,0,1,4,4,0,96,135,7,0,11,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,11,0,0,0,1,8,0,0,96,135,7,0,11,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,11,0,0,0,1,48,0,0,80,252,6,0,11,0,0,0,1,48,16,0,16,242,7,0,11,0,0,0,1,48,32,0,104,236,7,0,11,0,0,0,1,48,48,0,128,230,7,0,0,0,0,0,254,0,4,0,160,123,6,0,11,0,0,0,1,192,192,0,8,201,6,0,11,0,0,0,1,192,128,0,200,197,6,0,11,0,0,0,1,192,64,0,152,194,6,0,11,0,0,0,1,192,0,0,248,189,6,0,0,0,0,0,254,0,4,0,72,202,5,0,12,0,0,0,1,3,2,0,80,246,3,0,12,0,0,0,1,3,3,0,248,38,7,0,12,0,0,0,1,3,1,0,112,212,3,0,12,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,120,89,6,0,12,0,0,0,1,12,12,0,248,81,6,0,12,0,0,0,1,12,8,0,80,124,6,0,12,0,0,0,1,12,4,0,176,64,8,0,12,0,0,0,1,12,0,0,128,65,6,0,0,0,0,0,49,46,51,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,195,199,48,140,1,0,16,1,50,46,51,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,12,55,202,31,1,0,16,1,51,46,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,103,65,113,138,1,0,16,1,52,46,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,34,10,56,221,1,0,16,1,53,46,51,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,114,14,152,146,1,0,16,1,54,46,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,116,99,217,159,1,0,16,1,55,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,160,7,172,136,1,0,16,1,56,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,9,46,35,117,1,0,16,1,49,49,46,56,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,232,21,186,151,2,0,16,1,49,50,46,56,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,29,118,16,101,2,0,16,1,99,50,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,91,132,8,71,4,0,32,0,99,49,46,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,135,40,253,17,4,0,32,0,99,48,49,115,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,171,174,60,78,7,0,32,0,98,108,106,95,48,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,154,150,85,59,0,0,16,1,98,108,101,95,48,54,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,85,61,177,205,0,0,16,1,98,108,106,95,48,55,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,60,136,35,23,0,0,16,1,98,108,95,48,56,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,241,79,15,170,0,0,32,0,98,108,95,48,57,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,134,193,168,111,0,0,32,0,98,108,95,49,56,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,175,175,172,192,0,0,32,0,98,108,95,49,57,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,245,66,233,26,0,0,32,0,98,108,95,49,54,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,247,175,220,250,0,0,32,0,98,108,95,49,55,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,66,171,140,95,0,0,32,0,98,108,95,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,187,42,236,194,0,0,64,0,18,0,0,0,255,255,255,0,0,0,0,0,19,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,8,0,0,24,6,0,18,0,0,0,1,14,8,0,120,201,6,0,18,0,0,0,1,14,4,0,104,17,6,0,18,0,0,0,1,14,12,0,232,12,6,0,18,0,0,0,1,14,14,0,176,20,3,0,18,0,0,0,1,14,6,0,56,50,1,0,18,0,0,0,1,14,10,0,216,251,5,0,18,0,0,0,1,14,2,0,192,20,3,0,18,0,0,0,1,14,0,0,232,41,1,0,0,0,0,0,254,0,4,0,72,202,5,0,18,0,0,0,1,48,32,0,80,246,3,0,18,0,0,0,1,48,48,0,248,38,7,0,18,0,0,0,1,48,16,0,112,212,3,0,18,0,0,0,1,48,0,0,248,160,5,0,0,0,0,0,254,0,4,0,128,129,4,0,18,0,0,0,1,192,0,0,192,255,2,0,18,0,0,0,1,192,64,0,208,75,4,0,18,0,0,0,1,192,192,0,8,49,4,0,18,0,0,0,1,192,128,0,152,21,4,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,2,0,0,96,135,7,0,19,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,8,0,160,123,6,0,19,0,0,0,1,28,16,0,32,136,7,0,19,0,0,0,1,28,8,0,40,88,7,0,19,0,0,0,1,28,24,0,96,39,7,0,19,0,0,0,1,28,28,0,144,251,6,0,19,0,0,0,1,28,12,0,184,164,6,0,19,0,0,0,1,28,20,0,80,74,6,0,19,0,0,0,1,28,4,0,192,32,6,0,19,0,0,0,1,28,0,0,16,227,4,0,0,0,0,0,254,0,8,0,200,87,7,0,19,0,0,0,1,224,128,0,32,136,7,0,19,0,0,0,1,224,64,0,40,88,7,0,19,0,0,0,1,224,192,0,96,39,7,0,19,0,0,0,1,224,224,0,144,251,6,0,19,0,0,0,1,224,96,0,184,164,6,0,19,0,0,0,1,224,160,0,80,74,6,0,19,0,0,0,1,224,32,0,192,32,6,0,19,0,0,0,1,224,0,0,16,227,4,0,0,0,0,0,0,0,0,0,17,0,0,0,255,255,251,0,0,0,0,0,18,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,232,75,4,0,17,0,0,0,1,1,1,0,96,135,7,0,17,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,4,0,32,4,2,0,17,0,0,0,1,6,0,0,16,242,7,0,17,0,0,0,1,6,4,0,104,236,7,0,17,0,0,0,1,6,2,0,80,245,6,0,17,0,0,0,1,6,6,0,8,201,6,0,98,99,115,116,114,121,95,117,46,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,68,162,122,127,0,0,16,1,98,99,115,116,114,121,95,117,46,51,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,164,128,91,210,0,0,16,1,98,99,115,116,114,121,95,117,46,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,212,114,160,59,0,0,16,1,112,114,111,116,100,97,116,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,140,50,78,232,0,0,16,1,98,99,115,116,114,121,95,117,46,49,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,122,211,4,235,0,0,32,0,98,99,115,116,114,121,95,117,46,49,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,215,205,110,116,0,0,32,0,98,99,115,116,114,121,95,117,46,49,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,195,101,254,27,0,0,32,0,98,99,115,116,114,121,95,117,46,49,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,60,58,191,200,0,0,32,0,98,99,115,116,114,121,95,117,46,49,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,237,203,17,140,0,0,32,0,98,99,115,116,114,121,95,117,46,49,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,191,188,25,82,0,0,32,0,98,99,115,116,114,121,95,117,46,57,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,135,175,177,205,0,0,32,0,98,99,115,116,114,121,95,117,46,49,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,150,181,102,129,0,0,32,0,98,99,115,116,114,121,95,117,46,49,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,113,12,124,55,0,0,32,0,98,99,115,116,114,121,95,117,46,49,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,237,7,35,68,0,0,32,0,98,99,115,116,114,121,95,117,46,49,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,206,14,180,113,0,0,32,0,98,99,115,116,114,121,95,117,46,49,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,58,146,60,171,0,0,32,0,98,99,115,116,114,121,95,117,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,254,224,240,35,0,0,64,0,56,55,99,53,50,46,109,99,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,16,19,0,0,0,255,255,127,0,0,0,0,0,20,0,0,0,255,255,223,0,0,0,0,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,1,1,0,96,135,7,0,19,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,8,0,72,202,5,0,19,0,0,0,1,14,4,0,192,255,2,0,19,0,0,0,1,14,8,0,208,75,4,0,19,0,0,0,1,14,0,0,8,49,4,0,19,0,0,0,1,14,14,0,152,21,4,0,19,0,0,0,1,14,6,0,72,246,3,0,19,0,0,0,1,14,10,0,72,0,3,0,19,0,0,0,1,14,2,0,64,47,7,0,19,0,0,0,1,14,12,0,232,99,5,0,0,0,0,0,254,0,8,0,32,4,2,0,19,0,0,0,1,112,0,0,104,54,4,0,19,0,0,0,1,112,64,0,80,252,6,0,19,0,0,0,1,112,32,0,16,242,7,0,19,0,0,0,1,112,96,0,104,236,7,0,19,0,0,0,1,112,112,0,128,230,7,0,19,0,0,0,1,112,80,0,120,211,6,0,19,0,0,0,1,112,48,0,184,164,6,0,19,0,0,0,1,112,16,0,80,74,6,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,128,128,0,96,135,7,0,19,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,16,227,4,0,20,0,0,0,1,1,1,0,96,135,7,0,20,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,184,198,7,0,20,0,0,0,1,32,32,0,96,135,7,0,20,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,64,192,7,0,20,0,0,0,1,64,64,0,152,184,7,0,20,0,0,0,1,64,0,0,88,140,3,0,0,0,0,0,254,0,2,0,160,165,8,0,20,0,0,0,1,128,128,0,96,135,7,0,20,0,0,0,1,128,0,0,152,182,7,0,34,0,0,0,255,255,191,0,0,0,0,0,35,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,34,0,0,0,1,3,2,0,208,75,4,0,34,0,0,0,1,3,3,0,8,49,4,0,34,0,0,0,1,3,1,0,152,21,4,0,34,0,0,0,1,3,0,0,72,246,3,0,0,0,0,0,254,0,4,0,72,202,5,0,34,0,0,0,1,12,8,0,80,246,3,0,34,0,0,0,1,12,12,0,80,124,6,0,34,0,0,0,1,12,4,0,112,212,3,0,34,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,2,0,184,123,7,0,34,0,0,0,1,16,16,0,152,247,7,0,34,0,0,0,1,16,0,0,48,239,7,0,0,0,0,0,254,0,2,0,104,159,3,0,34,0,0,0,1,32,0,0,56,111,3,0,34,0,0,0,1,32,32,0,104,134,3,0,0,0,0,0,254,0,2,0,168,234,7,0,34,0,0,0,1,64,64,0,96,135,7,0,34,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,34,0,0,0,1,128,128,0,96,135,7,0,34,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,35,0,0,0,1,1,1,0,96,135,7,0,35,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,4,0,200,30,2,0,35,0,0,0,1,6,4,0,96,90,6,0,35,0,0,0,1,6,6,0,40,16,8,0,35,0,0,0,1,6,2,0,184,11,8,0,35,0,0,0,1,6,0,0,152,4,8,0,0,0,0,0,254,0,2,0,96,46,8,0,35,0,0,0,1,8,8,0,192,255,2,0,35,0,0,0,1,8,0,0,208,75,4,0,0,0,0,0,254,0,16,0,32,4,2,0,35,0,0,0,1,240,160,0,144,160,3,0,35,0,0,0,1,240,176,0,96,135,3,0,35,0,0,0,1,240,192,0,32,136,7,0,35,0,0,0,1,240,208,0,40,88,7,0,35,0,0,0,1,240,224,0,96,39,7,0,35,0,0,0,1,240,16,0,32,202,2,0,35,0,0,0,1,240,48,0,120,113,6,0,35,0,0,0,1,240,32,0,232,228,5,0,35,0,0,0,1,240,240,0,144,251,6,0,35,0,0,0,1,240,64,0,120,211,6,0,35,0,0,0,1,240,144,0,184,164,6,0,35,0,0,0,1,240,128,0,80,74,6,0,35,0,0,0,1,240,112,0,192,32,6,0,35,0,0,0,1,240,96,0,192,234,2,0,35,0,0,0,1,240,80,0,32,242,5,0,35,0,0,0,1,240,0,0,16,227,4,0,18,0,0,0,255,255,207,0,0,0,0,0,19,0,0,0,255,255,253,0,0,0,0,0,0,0,0,0,254,0,8,0,32,4,2,0,18,0,0,0,1,7,0,0,96,135,3,0,18,0,0,0,1,7,1,0,32,136,7,0,18,0,0,0,1,7,2,0,40,88,7,0,18,0,0,0,1,7,3,0,96,39,7,0,18,0,0,0,1,7,7,0,144,251,6,0,18,0,0,0,1,7,6,0,184,164,6,0,18,0,0,0,1,7,5,0,80,74,6,0,18,0,0,0,1,7,4,0,192,32,6,0,0,0,0,0,254,0,2,0,72,202,5,0,18,0,0,0,1,8,8,0,80,246,3,0,18,0,0,0,1,8,0,0,112,212,3,0,0,0,0,0,254,0,2,0,88,253,5,0,18,0,0,0,1,16,16,0,96,135,7,0,18,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,2,0,152,133,5,0,18,0,0,0,1,32,32,0,96,135,7,0,18,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,18,0,0,0,1,192,192,0,192,255,2,0,18,0,0,0,1,192,128,0,208,75,4,0,18,0,0,0,1,192,64,0,8,49,4,0,18,0,0,0,1,192,0,0,152,21,4,0,0,0,0,0,254,0,2,0,176,197,4,0,19,0,0,0,1,1,1,0,192,255,2,0,19,0,0,0,1,1,0,0,208,75,4,0,0,0,0,0,254,0,2,0,176,165,4,0,19,0,0,0,1,2,2,0,56,111,3,0,19,0,0,0,1,2,0,0,104,134,3,0,0,0,0,0,254,0,3,0,232,75,4,0,19,0,0,0,1,192,192,0,96,135,7,0,19,0,0,0,1,192,64,0,80,55,4,0,19,0,0,0,1,192,0,0,112,27,4,0,0,0,0,0,98,116,99,101,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,75,72,96,188,1,0,16,1,98,116,99,101,46,48,52,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,85,125,69,1,0,16,1,98,116,99,101,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,215,96,101,232,1,0,16,1,98,116,99,101,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,27,230,120,247,1,0,16,1,98,116,99,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,219,213,34,115,1,0,16,1,98,116,99,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,171,133,172,106,1,0,16,1,98,116,99,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,8,219,3,18,1,0,16,1,98,116,99,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,173,91,112,220,5,0,32,0,98,116,99,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,60,154,119,229,5,0,32,0,98,116,99,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,18,65,63,179,5,0,32,0,98,116,99,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,126,219,252,166,5,0,32,0,98,116,99,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,16,67,25,30,10,0,16,1,98,116,99,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,230,184,174,1,10,0,16,1,98,116,99,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,41,34,127,194,12,0,64,0,98,116,99,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,51,46,138,65,12,0,64,0,101,57,95,98,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,145,97,21,224,0,0,16,1,102,57,95,98,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,130,137,117,123,0,0,16,1,102,57,95,98,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,123,7,42,48,0,0,16,1,107,57,95,98,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,203,147,66,240,0,0,16,1,109,57,95,98,48,57,115,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,79,62,232,104,0,0,16,1,110,57,95,98,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,247,121,101,29,0,0,16,1,101,49,95,98,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,85,107,10,74,0,0,16,1,106,49,95,98,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,4,239,128,198,0,0,16,1,99,49,95,98,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,178,147,81,112,0,0,16,1,102,49,95,98,48,51,115,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,167,237,161,219,0,0,16,1,112,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,35,85,133,42,0,0,32,0,114,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,25,16,111,174,0,0,32,0,114,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,106,79,138,197,0,0,32,0,114,57,95,98,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,255,87,0,46,0,0,64,0,116,57,95,98,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,221,14,18,178,0,0,64,0,168,86,7,0,1,0,0,0,212,47,216,0,248,191,2,0,24,38,7,0,1,0,0,0,208,47,216,0,184,160,2,0,56,210,6,0,1,0,0,0,35,48,216,0,192,135,2,0,24,163,6,0,1,0,0,0,34,48,216,0,240,108,2,0,152,122,6,0,1,0,0,0,33,48,216,0,96,82,2,0,192,72,6,0,1,0,0,0,32,48,216,0,32,56,2,0,232,158,3,0,1,0,0,0,36,48,216,0,152,30,2,0,152,31,6,0,1,0,0,0,37,48,216,0,232,10,2,0,248,97,5,0,1,0,0,0,38,48,216,0,152,138,8,0,40,246,1,0,1,0,0,0,213,47,216,0,64,246,1,0,144,236,1,0,1,0,0,0,209,47,216,0,136,224,1,0,176,223,1,0,1,0,0,0,43,48,216,0,72,198,1,0,192,209,1,0,1,0,0,0,42,48,216,0,24,182,1,0,24,198,1,0,1,0,0,0,41,48,216,0,40,167,1,0,120,189,1,0,1,0,0,0,40,48,216,0,200,149,1,0,200,32,1,0,1,0,0,0,44,48,216,0,56,126,1,0,8,182,1,0,1,0,0,0,45,48,216,0,32,101,1,0,32,167,1,0,1,0,0,0,46,48,216,0,96,32,8,0,168,132,8,0,1,0,0,0,214,47,216,0,232,209,1,0,72,126,8,0,1,0,0,0,210,47,216,0,144,189,1,0,192,122,8,0,1,0,0,0,251,47,216,0,208,174,1,0,40,116,8,0,1,0,0,0,250,47,216,0,48,160,1,0,72,110,8,0,1,0,0,0,249,47,216,0,160,140,1,0,184,102,8,0,1,0,0,0,248,47,216,0,56,112,1,0,176,103,1,0,1,0,0,0,252,47,216,0,32,92,1,0,248,93,8,0,1,0,0,0,253,47,216,0,64,77,1,0,152,86,8,0,1,0,0,0,254,47,216,0,112,157,4,0,88,212,3,0,1,0,0,0,144,46,216,0,40,185,3,0,240,152,1,0,1,0,0,0,201,47,216,0,216,70,1,0,16,17,8,0,1,0,0,0,202,47,216,0,224,12,8,0,136,67,2,0,1,0,0,0,176,48,216,0,48,119,7,0,8,66,2,0,1,0,0,0,184,48,216,0,112,109,7,0,101,112,114,45,49,51,53,55,55,46,97,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,134,182,1,103,1,0,16,1,101,112,114,45,49,51,53,55,54,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,148,141,66,30,1,0,16,1,101,112,114,45,49,51,52,52,55,46,97,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,103,33,165,112,1,0,16,1,101,112,114,45,49,51,52,52,53,46,97,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,221,195,223,40,1,0,16,1,109,112,114,45,49,51,52,53,48,46,97,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,168,167,196,15,2,0,32,0,109,112,114,45,49,51,52,54,53,46,98,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,224,53,129,224,2,0,32,0,109,112,114,45,49,51,52,53,49,46,97,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,47,133,73,28,2,0,32,0,109,112,114,45,49,51,52,54,54,46,98,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,132,102,76,225,2,0,32,0,109,112,114,45,49,51,52,53,50,46,97,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,94,222,123,4,2,0,32,0,109,112,114,45,49,51,52,54,55,46,98,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,196,254,9,99,2,0,32,0,109,112,114,45,49,51,52,53,51,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,248,169,160,95,3,0,32,0,109,112,114,45,49,51,52,53,55,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,218,84,27,13,3,0,32,0,109,112,114,45,49,51,52,53,52,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,177,51,107,95,3,0,32,0,109,112,114,45,49,51,52,53,56,46,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,195,64,211,186,3,0,32,0,109,112,114,45,49,51,52,53,53,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,11,82,128,78,3,0,32,0,109,112,114,45,49,51,52,53,57,46,98,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,172,101,145,126,3,0,32,0,109,112,114,45,49,51,52,53,54,46,98,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,40,196,51,87,3,0,32,0,109,112,114,45,49,51,52,54,48,46,98,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,179,249,184,102,3,0,32,0,109,112,114,45,49,51,52,52,48,46,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,43,11,55,79,3,0,32,0,109,112,114,45,49,51,52,54,49,46,98,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,191,20,96,247,3,0,32,0,109,112,114,45,49,51,52,52,49,46,97,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,180,156,207,55,3,0,32,0,109,112,114,45,49,51,52,54,50,46,98,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,218,231,97,16,3,0,32,0,109,112,114,45,49,51,52,52,50,46,97,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,239,152,150,4,3,0,32,0,109,112,114,45,49,51,52,54,51,46,98,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,241,251,188,125,3,0,32,0,109,112,114,45,49,51,52,52,51,46,97,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,158,152,168,119,3,0,32,0,109,112,114,45,49,51,52,54,52,46,98,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,34,244,29,85,3,0,32,0,101,112,114,45,49,51,52,52,56,46,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,185,63,24,181,4,0,16,1,109,112,114,45,49,51,52,52,57,46,97,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,249,170,217,211,8,0,64,0,21,0,0,0,255,255,253,0,0,0,0,0,22,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,21,0,0,0,1,1,1,0,120,97,1,0,21,0,0,0,1,1,0,0,96,19,1,0,0,0,0,0,254,0,2,0,168,234,7,0,21,0,0,0,1,2,2,0,96,135,7,0,21,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,21,0,0,0,1,12,0,0,208,75,4,0,21,0,0,0,1,12,12,0,8,49,4,0,21,0,0,0,1,12,8,0,152,21,4,0,21,0,0,0,1,12,4,0,72,246,3,0,0,0,0,0,254,0,2,0,64,37,5,0,21,0,0,0,1,16,16,0,160,93,2,0,21,0,0,0,1,16,0,0,16,92,2,0,0,0,0,0,254,0,2,0,72,202,5,0,21,0,0,0,1,32,32,0,248,38,7,0,21,0,0,0,1,32,0,0,112,212,3,0,0,0,0,0,254,0,2,0,160,90,2,0,21,0,0,0,1,64,64,0,232,88,2,0,21,0,0,0,1,64,0,0,248,85,2,0,0,0,0,0,254,0,2,0,216,82,2,0,21,0,0,0,1,128,128,0,96,135,7,0,21,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,16,0,200,87,7,0,22,0,0,0,1,15,7,0,80,252,6,0,22,0,0,0,1,15,8,0,16,242,7,0,22,0,0,0,1,15,9,0,104,236,7,0,22,0,0,0,1,15,5,0,176,51,4,0,22,0,0,0,1,15,4,0,56,24,4,0,22,0,0,0,1,15,15,0,128,230,7,0,22,0,0,0,1,15,1,0,72,216,3,0,22,0,0,0,1,15,2,0,24,188,3,0,22,0,0,0,1,15,3,0,176,162,3,0,22,0,0,0,1,15,6,0,120,211,6,0,22,0,0,0,1,15,14,0,184,164,6,0,22,0,0,0,1,15,13,0,80,74,6,0,22,0,0,0,1,15,12,0,192,32,6,0,22,0,0,0,1,15,11,0,192,234,2,0,22,0,0,0,1,15,10,0,32,242,5,0,22,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,22,0,0,0,1,240,112,0,80,252,6,0,22,0,0,0,1,240,128,0,16,242,7,0,22,0,0,0,1,240,144,0,104,236,7,0,22,0,0,0,1,240,80,0,176,51,4,0,22,0,0,0,1,240,64,0,56,24,4,0,22,0,0,0,1,240,240,0,128,230,7,0,22,0,0,0,1,240,16,0,72,216,3,0,22,0,0,0,1,240,32,0,24,188,3,0,22,0,0,0,1,240,48,0,176,162,3,0,22,0,0,0,1,240,96,0,120,211,6,0,22,0,0,0,1,240,224,0,184,164,6,0,22,0,0,0,1,240,208,0,80,74,6,0,22,0,0,0,1,240,192,0,192,32,6,0,22,0,0,0,1,240,176,0,192,234,2,0,22,0,0,0,1,240,160,0,32,242,5,0,22,0,0,0,1,240,0,0,208,236,2,0,0,0,0,0,101,112,114,45,49,51,49,56,50,46,97,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,28,42,31,227,1,0,16,1,101,112,114,45,49,51,49,56,49,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,38,59,205,120,1,0,16,1,101,112,114,45,49,51,48,55,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,97,10,93,223,2,0,32,0,101,112,114,45,49,51,48,55,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,184,250,122,120,2,0,32,0,101,112,114,45,49,51,48,55,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,119,180,1,78,2,0,32,0,109,112,114,45,49,51,48,56,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,4,183,130,167,3,0,32,0,109,112,114,45,49,51,48,56,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,240,39,66,42,3,0,32,0,109,112,114,45,49,51,48,56,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,40,2,81,235,3,0,32,0,109,112,114,45,49,51,48,56,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,85,76,107,59,3,0,32,0,109,112,114,45,49,51,48,56,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,251,238,104,230,3,0,32,0,109,112,114,45,49,51,48,56,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,125,66,147,34,3,0,32,0,101,112,114,45,49,51,48,55,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,237,33,146,222,3,0,32,0,101,112,114,45,49,51,48,56,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,196,113,154,140,3,0,32,0,101,112,114,45,49,51,48,56,51,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,6,142,82,231,4,0,16,1,101,112,114,45,49,51,48,55,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,110,199,230,148,19,0,64,0,101,112,114,45,49,51,48,55,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,141,13,236,226,19,0,64,0,101,112,114,45,49,51,48,55,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,197,77,104,21,19,0,64,0,51,49,55,45,48,49,53,52,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,143,107,107,184,5,0,16,1,33,0,0,0,255,255,255,0,0,0,0,0,34,0,0,0,255,255,253,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,33,0,0,0,1,15,7,0,80,252,6,0,33,0,0,0,1,15,8,0,16,242,7,0,33,0,0,0,1,15,9,0,104,236,7,0,33,0,0,0,1,15,5,0,176,51,4,0,33,0,0,0,1,15,4,0,56,24,4,0,33,0,0,0,1,15,15,0,128,230,7,0,33,0,0,0,1,15,1,0,72,216,3,0,33,0,0,0,1,15,2,0,24,188,3,0,33,0,0,0,1,15,3,0,176,162,3,0,33,0,0,0,1,15,6,0,120,211,6,0,33,0,0,0,1,15,14,0,184,164,6,0,33,0,0,0,1,15,13,0,80,74,6,0,33,0,0,0,1,15,12,0,192,32,6,0,33,0,0,0,1,15,11,0,192,234,2,0,33,0,0,0,1,15,10,0,32,242,5,0,33,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,33,0,0,0,1,240,112,0,80,252,6,0,33,0,0,0,1,240,128,0,16,242,7,0,33,0,0,0,1,240,144,0,104,236,7,0,33,0,0,0,1,240,80,0,176,51,4,0,33,0,0,0,1,240,64,0,56,24,4,0,33,0,0,0,1,240,240,0,128,230,7,0,33,0,0,0,1,240,16,0,72,216,3,0,33,0,0,0,1,240,32,0,24,188,3,0,33,0,0,0,1,240,48,0,176,162,3,0,33,0,0,0,1,240,96,0,120,211,6,0,33,0,0,0,1,240,224,0,184,164,6,0,33,0,0,0,1,240,208,0,80,74,6,0,33,0,0,0,1,240,192,0,192,32,6,0,33,0,0,0,1,240,176,0,192,234,2,0,33,0,0,0,1,240,160,0,32,242,5,0,33,0,0,0,1,240,0,0,208,236,2,0,0,0,0,0,254,0,2,0,88,131,3,0,34,0,0,0,1,1,1,0,96,135,7,0,34,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,34,0,0,0,1,2,2,0,96,135,7,0,34,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,8,0,72,202,5,0,34,0,0,0,1,28,4,0,160,246,1,0,34,0,0,0,1,28,8,0,120,103,7,0,34,0,0,0,1,28,12,0,80,246,3,0,34,0,0,0,1,28,28,0,248,38,7,0,34,0,0,0,1,28,16,0,112,212,3,0,34,0,0,0,1,28,20,0,48,90,7,0,34,0,0,0,1,28,24,0,248,160,5,0,34,0,0,0,1,28,0,0,88,32,6,0,0,0,0,0,254,0,2,0,232,53,6,0])
.concat([34,0,0,0,1,32,0,0,192,255,2,0,34,0,0,0,1,32,32,0,8,49,4,0,19,0,0,0,255,255,254,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,19,0,0,0,1,1,0,0,120,97,1,0,19,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,2,2,0,96,135,7,0,19,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,4,4,0,96,135,7,0,19,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,8,0,0,96,135,7,0,19,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,19,0,0,0,1,48,0,0,32,136,7,0,19,0,0,0,1,48,16,0,40,88,7,0,19,0,0,0,1,48,32,0,96,39,7,0,19,0,0,0,1,48,48,0,144,251,6,0,0,0,0,0,254,0,4,0,160,123,6,0,19,0,0,0,1,192,192,0,184,164,6,0,19,0,0,0,1,192,128,0,80,74,6,0,19,0,0,0,1,192,64,0,192,32,6,0,19,0,0,0,1,192,0,0,32,242,5,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,3,2,0,80,246,3,0,20,0,0,0,1,3,3,0,80,124,6,0,20,0,0,0,1,3,1,0,112,212,3,0,20,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,64,37,5,0,20,0,0,0,1,12,8,0,136,53,6,0,20,0,0,0,1,12,12,0,248,48,6,0,20,0,0,0,1,12,4,0,168,43,6,0,20,0,0,0,1,12,0,0,80,39,6,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,48,0,0,192,255,2,0,20,0,0,0,1,48,16,0,208,75,4,0,20,0,0,0,1,48,48,0,8,49,4,0,20,0,0,0,1,48,32,0,152,21,4,0,0,0,0,0,254,0,2,0,104,159,3,0,20,0,0,0,1,64,0,0,96,135,7,0,20,0,0,0,1,64,64,0,152,182,7,0,112,119,103,101,46,48,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,49,73,247,49,1,0,16,1,112,119,103,101,46,48,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,95,79,243,22,1,0,16,1,112,119,103,101,46,48,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,8,237,3,68,1,0,16,1,112,119,103,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,232,12,166,135,1,0,16,1,112,119,103,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,72,177,247,1,0,16,1,112,119,103,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,62,130,98,204,1,0,16,1,112,119,103,46,48,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,238,186,38,76,1,0,16,1,112,119,103,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,40,251,196,7,1,0,16,1,112,119,103,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,142,224,143,174,5,0,32,0,112,119,103,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,88,15,86,219,5,0,32,0,112,119,103,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,148,91,71,188,5,0,32,0,112,119,103,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,247,159,67,7,5,0,32,0,112,119,103,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,99,186,249,195,5,0,32,0,112,119,103,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,123,14,91,129,5,0,32,0,112,119,103,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,27,199,9,1,5,0,32,0,112,119,103,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,190,255,117,235,5,0,32,0,112,119,103,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,228,192,165,24,10,0,16,1,112,119,103,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,166,255,223,201,10,0,16,1,112,119,103,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,51,116,143,167,12,0,64,0,112,119,103,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,208,142,67,119,12,0,64,0,21,0,0,0,255,255,223,0,0,0,0,0,22,0,0,0,255,255,207,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,21,0,0,0,1,3,3,0,8,49,4,0,21,0,0,0,1,3,2,0,152,21,4,0,21,0,0,0,1,3,1,0,72,246,3,0,21,0,0,0,1,3,0,0,72,0,3,0,0,0,0,0,254,0,2,0,232,168,4,0,21,0,0,0,1,4,4,0,160,39,6,0,21,0,0,0,1,4,0,0,160,30,6,0,0,0,0,0,254,0,2,0,240,83,4,0,21,0,0,0,1,8,8,0,232,23,6,0,21,0,0,0,1,8,0,0,248,216,5,0,0,0,0,0,254,0,4,0,64,37,5,0,21,0,0,0,1,12,12,0,16,223,3,0,21,0,0,0,1,12,4,0,16,9,8,0,21,0,0,0,1,12,8,0,96,3,8,0,21,0,0,0,1,12,0,0,16,252,7,0,0,0,0,0,254,0,2,0,168,234,7,0,21,0,0,0,1,16,0,0,96,135,7,0,21,0,0,0,1,16,16,0,152,182,7,0,0,0,0,0,254,0,2,0,200,30,2,0,21,0,0,0,1,32,0,0,120,97,1,0,21,0,0,0,1,32,32,0,96,19,1,0,0,0,0,0,254,0,4,0,72,202,5,0,21,0,0,0,1,192,192,0,80,246,3,0,21,0,0,0,1,192,128,0,248,38,7,0,21,0,0,0,1,192,64,0,112,212,3,0,21,0,0,0,1,192,0,0,248,160,5,0,0,0,0,0,254,0,4,0,200,87,7,0,22,0,0,0,1,3,1,0,96,39,7,0,22,0,0,0,1,3,3,0,144,251,6,0,22,0,0,0,1,3,2,0,184,164,6,0,22,0,0,0,1,3,0,0,16,227,4,0,0,0,0,0,254,0,4,0,160,123,6,0,22,0,0,0,1,12,4,0,96,39,7,0,22,0,0,0,1,12,12,0,144,251,6,0,22,0,0,0,1,12,0,0,120,211,6,0,22,0,0,0,1,12,8,0,184,164,6,0,0,0,0,0,254,0,4,0,104,159,3,0,22,0,0,0,1,48,48,0,56,111,3,0,22,0,0,0,1,48,32,0,120,170,1,0,22,0,0,0,1,48,16,0,88,239,5,0,22,0,0,0,1,48,0,0,104,134,3,0,0,0,0,0,254,0,2,0,144,212,8,0,22,0,0,0,1,64,64,0,96,135,7,0,22,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,97,114,95,51,54,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,146,3,3,101,1,0,16,1,97,114,95,52,50,46,49,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,222,112,129,196,1,0,16,1,97,114,95,51,55,46,49,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,75,105,233,51,1,0,16,1,97,114,95,52,51,46,49,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,158,251,200,124,1,0,16,1,97,114,95,51,52,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,134,3,232,246,1,0,16,1,97,114,95,52,48,46,49,48,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,69,193,54,190,1,0,16,1,97,114,95,51,53,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,243,143,217,134,1,0,16,1,97,114,95,52,49,46,49,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,211,147,136,117,1,0,16,1,97,114,95,48,57,46,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,248,118,147,219,4,0,32,0,97,114,95,48,49,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,180,81,33,57,4,0,32,0,97,114,95,49,51,46,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,129,100,67,129,4,0,32,0,97,114,95,48,53,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,159,237,70,226,4,0,32,0,97,114,95,50,52,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,163,226,214,156,4,0,32,0,97,114,95,49,55,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,244,13,142,11,4,0,32,0,97,114,95,51,56,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,185,117,158,139,4,0,32,0,97,114,95,51,50,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,207,205,106,219,4,0,32,0,97,114,95,49,48,46,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,34,182,25,66,4,0,32,0,97,114,95,48,50,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,197,222,197,186,4,0,32,0,97,114,95,49,52,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,121,225,186,230,4,0,32,0,97,114,95,48,54,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,35,66,240,200,4,0,32,0,97,114,95,50,53,46,55,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,129,249,204,21,4,0,32,0,97,114,95,49,56,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,106,219,54,147,4,0,32,0,97,114,95,51,57,46,57,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,99,19,142,155,4,0,32,0,97,114,95,51,51,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,181,244,104,57,4,0,32,0,97,114,95,50,51,46,49,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,103,19,221,243,3,0,16,0,97,114,95,51,48,46,49,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,169,67,75,88,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,97,114,50,50,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,48,144,219,241,0,0,0,8,108,119,105,111,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,12,185,82,173,0,0,0,8,97,112,111,110,111,119,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,121,21,1,51,1,0,16,1,97,112,111,110,111,119,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,62,87,119,212,1,0,16,1,97,112,111,110,111,119,48,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,152,24,196,70,1,0,16,1,114,98,49,53,100,99,112,117,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,66,87,80,214,1,0,16,1,114,98,49,53,101,99,112,117,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,164,243,77,96,1,0,16,1,114,98,49,53,99,115,110,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,23,191,36,139,2,0,16,1,114,98,49,53,100,115,110,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,179,79,110,217,2,0,16,1,114,98,49,53,102,99,112,117,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,12,210,137,68,4,0,32,0,114,98,49,53,104,99,112,117,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,71,197,18,85,4,0,32,0,114,101,115,99,117,101,46,99,108,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,189,188,198,64,7,0,32,0,49,46,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,222,116,27,98,1,0,16,1,50,46,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,152,139,83,56,1,0,16,1,51,46,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,36,203,158,9,1,0,16,1,52,46,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,147,154,20,186,1,0,16,1,53,46,50,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,191,26,204,238,1,0,16,1,115,49,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,80,183,167,140,2,0,16,1,115,50,46,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,10,220,91,155,2,0,16,1,99,50,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,222,94,254,44,4,0,32,0,99,50,46,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,13,253,196,87,4,0,32,0,97,109,105,100,97,114,46,99,108,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,195,220,64,249,7,0,32,0,16,0,0,0,255,255,0,0,0,0,0,0,17,0,0,0,255,255,0,0,0,0,0,0,18,0,0,0,255,255,6,0,0,0,0,0,19,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,17,0,0,0,1,3,0,0,8,49,4,0,17,0,0,0,1,3,1,0,152,21,4,0,17,0,0,0,1,3,2,0,72,246,3,0,17,0,0,0,1,3,3,0,200,28,2,0,0,0,0,0,254,0,2,0,168,234,7,0,18,0,0,0,1,2,0,0,96,135,7,0,18,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,2,0,64,37,5,0,18,0,0,0,1,4,4,0,128,169,1,0,18,0,0,0,1,4,0,0,48,167,1,0,0,0,0,0,254,0,16,0,200,87,7,0,19,0,0,0,1,15,11,0,144,102,8,0,19,0,0,0,1,15,5,0,176,45,8,0,19,0,0,0,1,15,14,0,224,127,8,0,19,0,0,0,1,15,13,0,136,252,1,0,19,0,0,0,1,15,7,0,0,67,1,0,19,0,0,0,1,15,0,0,32,123,8,0,19,0,0,0,1,15,3,0,232,143,1,0,19,0,0,0,1,15,1,0,248,116,8,0,19,0,0,0,1,15,8,0,192,110,8,0,19,0,0,0,1,15,9,0,168,36,1,0,19,0,0,0,1,15,4,0,96,102,7,0,19,0,0,0,1,15,12,0,184,105,6,0,19,0,0,0,1,15,2,0,152,96,3,0,19,0,0,0,1,15,10,0,192,100,6,0,19,0,0,0,1,15,6,0,64,1,1,0,19,0,0,0,1,15,15,0,16,227,4,0,0,0,0,0,254,0,16,0,160,123,6,0,19,0,0,0,1,240,176,0,144,102,8,0,19,0,0,0,1,240,80,0,176,45,8,0,19,0,0,0,1,240,224,0,224,127,8,0,19,0,0,0,1,240,208,0,136,252,1,0,19,0,0,0,1,240,112,0,0,67,1,0,19,0,0,0,1,240,0,0,32,123,8,0,19,0,0,0,1,240,48,0,232,143,1,0,19,0,0,0,1,240,16,0,248,116,8,0,19,0,0,0,1,240,128,0,192,110,8,0,19,0,0,0,1,240,144,0,168,36,1,0,19,0,0,0,1,240,64,0,96,102,7,0,19,0,0,0,1,240,192,0,184,105,6,0,19,0,0,0,1,240,32,0,152,96,3,0,19,0,0,0,1,240,160,0,192,100,6,0,19,0,0,0,1,240,96,0,64,1,1,0,19,0,0,0,1,240,240,0,48,170,1,0,0,0,0,0,17,0,0,0,255,255,192,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,17,0,0,0,1,3,0,0,8,49,4,0,17,0,0,0,1,3,1,0,152,21,4,0,17,0,0,0,1,3,2,0,72,246,3,0,17,0,0,0,1,3,3,0,72,0,3,0,0,0,0,0,254,0,8,0,32,4,2,0,17,0,0,0,1,28,20,0,16,242,7,0,17,0,0,0,1,28,16,0,104,236,7,0,17,0,0,0,1,28,0,0,208,238,1,0,17,0,0,0,1,28,4,0,8,201,6,0,17,0,0,0,1,28,24,0,24,1,7,0,17,0,0,0,1,28,8,0,200,197,6,0,17,0,0,0,1,28,12,0,152,194,6,0,17,0,0,0,1,28,28,0,216,177,5,0,0,0,0,0,254,0,2,0,72,202,5,0,17,0,0,0,1,32,0,0,80,246,3,0,17,0,0,0,1,32,32,0,112,212,3,0,0,0,0,0,254,0,2,0,64,37,5,0,17,0,0,0,1,64,64,0,184,43,6,0,17,0,0,0,1,64,0,0,160,240,4,0,0,0,0,0,254,0,2,0,200,30,2,0,17,0,0,0,1,128,128,0,120,97,1,0,17,0,0,0,1,128,0,0,96,19,1,0,49,49,46,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,197,133,127,108,0,0,16,1,57,46,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,137,169,183,225,0,0,16,1,49,50,46,54,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,238,163,232,77,0,0,16,1,49,48,46,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,129,173,107,216,0,0,16,1,49,46,49,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,231,181,168,85,0,0,16,1,50,46,49,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,202,124,122,66,0,0,16,1,51,46,49,56,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,247,234,204,184,0,0,16,1,56,46,49,54,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,68,134,236,12,0,0,32,0,49,51,46,49,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,217,244,95,65,0,0,32,0,49,52,46,49,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,72,92,43,73,0,0,32,0,49,53,46,49,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,157,11,172,177,0,0,32,0,52,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,122,237,124,247,0,0,32,0,53,46,55,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,101,20,239,22,0,0,32,0,54,46,54,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,65,201,110,147,0,0,32,0,55,46,55,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,142,113,221,102,0,0,32,0,99,108,114,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,65,179,64,100,0,0,32,0,99,108,114,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,127,148,30,39,0,0,32,0,99,108,114,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,27,98,56,125,0,0,32,0,50,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,185,22,202,68,0,0,32,0,52,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,123,44,95,3,0,0,32,0,49,54,46,49,56,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,43,89,141,29,0,0,0,8,18,0,0,0,255,255,32,0,0,0,0,0,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,232,75,4,0,18,0,0,0,1,32,32,0,96,135,7,0,18,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,19,0,0,0,1,3,3,0,8,49,4,0,19,0,0,0,1,3,2,0,152,21,4,0,19,0,0,0,1,3,1,0,72,246,3,0,19,0,0,0,1,3,0,0,72,0,3,0,0,0,0,0,254,0,4,0,64,37,5,0,19,0,0,0,1,12,12,0,248,25,1,0,19,0,0,0,1,12,8,0,112,16,1,0,19,0,0,0,1,12,4,0,176,11,1,0,19,0,0,0,1,12,0,0,160,5,1,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,16,0,0,96,135,7,0,19,0,0,0,1,16,16,0,152,182,7,0,0,0,0,0,254,0,2,0,200,30,2,0,19,0,0,0,1,32,0,0,120,97,1,0,19,0,0,0,1,32,32,0,96,19,1,0,0,0,0,0,254,0,4,0,200,87,7,0,20,0,0,0,1,3,1,0,104,236,7,0,20,0,0,0,1,3,3,0,128,230,7,0,20,0,0,0,1,3,2,0,184,164,6,0,20,0,0,0,1,3,0,0,16,227,4,0,0,0,0,0,254,0,4,0,160,123,6,0,20,0,0,0,1,12,0,0,16,242,7,0,20,0,0,0,1,12,8,0,128,230,7,0,20,0,0,0,1,12,4,0,120,211,6,0,20,0,0,0,1,12,12,0,80,74,6,0,0,0,0,0,254,0,2,0,72,202,5,0,20,0,0,0,1,16,16,0,80,246,3,0,20,0,0,0,1,16,0,0,112,212,3,0,0,0,0,0,254,0,2,0,144,212,8,0,20,0,0,0,1,32,32,0,96,135,7,0,20,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,16,57,4,0,20,0,0,0,1,64,64,0,112,134,3,0,20,0,0,0,1,64,0,0,64,111,3,0,0,0,0,0,254,0,2,0,160,225,8,0,20,0,0,0,1,128,128,0,96,135,7,0,20,0,0,0,1,128,0,0,152,182,7,0,18,0,0,0,255,255,255,0,0,0,0,0,19,0,0,0,255,255,94,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,18,0,0,0,1,15,2,0,80,252,6,0,18,0,0,0,1,15,5,0,16,242,7,0,18,0,0,0,1,15,8,0,104,236,7,0,18,0,0,0,1,15,4,0,120,113,6,0,18,0,0,0,1,15,1,0,232,228,5,0,18,0,0,0,1,15,15,0,128,230,7,0,18,0,0,0,1,15,3,0,56,141,7,0,18,0,0,0,1,15,7,0,120,211,6,0,18,0,0,0,1,15,14,0,184,164,6,0,18,0,0,0,1,15,6,0,24,1,7,0,18,0,0,0,1,15,13,0,80,74,6,0,18,0,0,0,1,15,12,0,192,32,6,0,18,0,0,0,1,15,11,0,192,234,2,0,18,0,0,0,1,15,10,0,32,242,5,0,18,0,0,0,1,15,9,0,176,192,2,0,18,0,0,0,1,15,0,0,16,227,4,0,0,0,0,0,254,0,16,0,160,123,6,0,18,0,0,0,1,240,32,0,80,252,6,0,18,0,0,0,1,240,80,0,16,242,7,0,18,0,0,0,1,240,128,0,104,236,7,0,18,0,0,0,1,240,64,0,120,113,6,0,18,0,0,0,1,240,16,0,232,228,5,0,18,0,0,0,1,240,240,0,128,230,7,0,18,0,0,0,1,240,48,0,56,141,7,0,18,0,0,0,1,240,112,0,120,211,6,0,18,0,0,0,1,240,224,0,184,164,6,0,18,0,0,0,1,240,96,0,24,1,7,0,18,0,0,0,1,240,208,0,80,74,6,0,18,0,0,0,1,240,192,0,192,32,6,0,18,0,0,0,1,240,176,0,192,234,2,0,18,0,0,0,1,240,160,0,32,242,5,0,18,0,0,0,1,240,144,0,176,192,2,0,18,0,0,0,1,240,0,0,168,144,4,0,0,0,0,0,254,0,4,0,128,129,4,0,19,0,0,0,1,3,3,0,192,255,2,0,19,0,0,0,1,3,2,0,208,75,4,0,19,0,0,0,1,3,1,0,8,49,4,0,19,0,0,0,1,3,0,0,72,246,3,0,0,0,0,0,254,0,4,0,72,202,5,0,19,0,0,0,1,96,96,0,80,246,3,0,19,0,0,0,1,96,64,0,248,38,7,0,19,0,0,0,1,96,32,0,112,212,3,0,19,0,0,0,1,96,0,0,24,99,5,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,128,128,0,96,135,7,0,19,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,20,0,0,0,1,4,4,0,96,135,7,0,20,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,168,86,7,0,1,0,0,0,8,2,147,0,248,191,2,0,24,38,7,0,1,0,0,0,11,2,147,0,184,160,2,0,56,210,6,0,1,0,0,0,74,249,146,0,192,135,2,0,24,163,6,0,1,0,0,0,75,249,146,0,240,108,2,0,152,122,6,0,1,0,0,0,72,249,146,0,96,82,2,0,192,72,6,0,1,0,0,0,73,249,146,0,32,56,2,0,200,110,3,0,1,0,0,0,76,249,146,0,152,30,2,0,120,89,3,0,1,0,0,0,77,249,146,0,232,10,2,0,120,74,3,0,1,0,0,0,78,249,146,0,152,138,8,0,40,246,1,0,1,0,0,0,9,2,147,0,64,246,1,0,144,236,1,0,1,0,0,0,12,2,147,0,136,224,1,0,176,223,1,0,1,0,0,0,42,241,146,0,72,198,1,0,192,209,1,0,1,0,0,0,43,241,146,0,24,182,1,0,24,198,1,0,1,0,0,0,40,241,146,0,40,167,1,0,120,189,1,0,1,0,0,0,41,241,146,0,200,149,1,0,224,22,1,0,1,0,0,0,44,241,146,0,56,126,1,0,160,14,1,0,1,0,0,0,45,241,146,0,32,101,1,0,176,9,1,0,1,0,0,0,46,241,146,0,96,32,8,0,88,212,3,0,1,0,0,0,128,221,146,0,40,185,3,0,16,17,8,0,1,0,0,0,10,2,147,0,224,12,8,0,72,65,1,0,9,0,0,0,64,7,147,0,32,58,1,0,48,50,1,0,9,0,0,0,65,7,147,0,32,58,1,0,224,41,1,0,9,0,0,0,66,7,147,0,32,58,1,0,22,0,0,0,255,255,255,0,0,0,0,0,23,0,0,0,255,255,63,0,0,0,0,0,0,0,0,0,254,0,4,0,32,4,2,0,22,0,0,0,1,3,0,0,88,154,8,0,22,0,0,0,1,3,1,0,200,92,8,0,22,0,0,0,1,3,3,0,56,37,8,0,22,0,0,0,1,3,2,0,96,240,7,0,0,0,0,0,254,0,2,0,104,178,6,0,22,0,0,0,1,4,0,0,96,135,7,0,22,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,22,0,0,0,1,32,0,0,96,135,7,0,22,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,72,202,5,0,23,0,0,0,1,3,2,0,80,246,3,0,23,0,0,0,1,3,3,0,248,38,7,0,23,0,0,0,1,3,1,0,112,212,3,0,23,0,0,0,1,3,0,0,24,99,5,0,0,0,0,0,254,0,2,0,216,77,5,0,23,0,0,0,1,4,4,0,192,255,2,0,23,0,0,0,1,4,0,0,208,75,4,0,0,0,0,0,97,100,48,46,49,48,111,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,90,50,52,77,1,0,16,1,97,100,49,46,57,111,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,75,19,55,15,1,0,16,1,97,100,50,46,56,111,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,95,101,250,188,1,0,16,1,97,100,51,46,55,111,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,37,82,101,96,1,0,16,1,97,100,49,115,46,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,15,155,243,128,2,0,16,1,97,100,50,115,46,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,43,254,119,81,2,0,16,1,97,100,52,46,53,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,33,221,140,56,4,0,32,0,97,100,53,46,51,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,73,52,63,245,4,0,32,0,112,114,111,109,45,97,109,50,55,115,49,57,100,99,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,189,174,89,39,7,0,32,0,97,100,49,118,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,255,63,185,76,0,0,64,8,97,100,50,118,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,167,14,83,75,0,0,64,8,112,114,111,109,45,115,110,55,52,115,49,56,56,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,106,79,138,197,0,0,64,8,11,0,0,0,255,255,0,0,0,0,0,0,12,0,0,0,255,255,0,0,0,0,0,0,13,0,0,0,255,255,0,0,0,0,0,0,14,0,0,0,255,255,16,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,13,0,0,0,1,15,8,0,224,127,8,0,13,0,0,0,1,15,9,0,240,169,3,0,13,0,0,0,1,15,0,0,32,123,8,0,13,0,0,0,1,15,10,0,248,116,8,0,13,0,0,0,1,15,11,0,152,81,3,0,13,0,0,0,1,15,1,0,192,110,8,0,13,0,0,0,1,15,12,0,168,36,1,0,13,0,0,0,1,15,13,0,40,242,1,0,13,0,0,0,1,15,2,0,96,102,7,0,13,0,0,0,1,15,14,0,0,240,1,0,13,0,0,0,1,15,15,0,192,238,1,0,13,0,0,0,1,15,3,0,184,105,6,0,13,0,0,0,1,15,4,0,152,96,3,0,13,0,0,0,1,15,5,0,192,100,6,0,13,0,0,0,1,15,6,0,64,1,1,0,13,0,0,0,1,15,7,0,184,69,8,0,0,0,0,0,254,0,16,0,160,123,6,0,13,0,0,0,1,240,128,0,224,127,8,0,13,0,0,0,1,240,144,0,240,169,3,0,13,0,0,0,1,240,0,0,32,123,8,0,13,0,0,0,1,240,160,0,248,116,8,0,13,0,0,0,1,240,176,0,152,81,3,0,13,0,0,0,1,240,16,0,192,110,8,0,13,0,0,0,1,240,192,0,168,36,1,0,13,0,0,0,1,240,208,0,40,242,1,0,13,0,0,0,1,240,32,0,96,102,7,0,13,0,0,0,1,240,224,0,0,240,1,0,13,0,0,0,1,240,240,0,192,238,1,0,13,0,0,0,1,240,48,0,184,105,6,0,13,0,0,0,1,240,64,0,152,96,3,0,13,0,0,0,1,240,80,0,192,100,6,0,13,0,0,0,1,240,96,0,64,1,1,0,13,0,0,0,1,240,112,0,184,69,8,0,0,0,0,0,254,0,4,0,128,129,4,0,14,0,0,0,1,3,3,0,208,75,4,0,14,0,0,0,1,3,2,0,8,49,4,0,14,0,0,0,1,3,1,0,152,21,4,0,14,0,0,0,1,3,0,0,72,246,3,0,0,0,0,0,254,0,4,0,64,37,5,0,14,0,0,0,1,12,12,0,120,7,5,0,14,0,0,0,1,12,8,0,160,191,4,0,14,0,0,0,1,12,4,0,24,145,2,0,14,0,0,0,1,12,0,0,240,159,4,0,0,0,0,0,254,0,2,0,200,30,2,0,14,0,0,0,1,16,16,0,120,97,1,0,14,0,0,0,1,16,0,0,96,19,1,0,0,0,0,0,254,0,2,0,104,159,3,0,14,0,0,0,1,32,32,0,96,135,7,0,14,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,14,0,0,0,1,128,128,0,96,135,7,0,14,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,101,112,114,45,49,51,53,53,55,98,46,105,99,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,106,16,78,85,1,0,16,1,101,112,114,45,49,51,53,53,54,98,46,105,99,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,46,243,123,51,1,0,16,1,101,112,114,45,49,51,53,53,57,46,105,99,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,25,191,136,69,1,0,16,1,101,112,114,45,49,51,53,53,56,46,105,99,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,212,158,37,17,1,0,16,1,101,112,114,45,49,51,53,54,54,46,105,99,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,50,47,229,34,9,0,16,1,101,112,114,45,49,51,53,54,53,46,105,99,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,189,132,23,162,9,0,16,1,111,112,114,45,49,51,53,53,51,46,105,99,49,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,55,136,65,140,2,0,32,0,111,112,114,45,49,51,53,53,52,46,105,99,49,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,240,249,61,78,2,0,32,0,111,112,114,45,49,51,53,53,53,46,105,99,49,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,66,29,74,108,2,0,32,0,111,112,114,45,49,51,53,53,50,46,105,99,57,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,6,247,44,204,3,0,32,0,111,112,114,45,49,51,53,53,49,46,105,99,57,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,193,118,242,214,3,0,32,0,111,112,114,45,49,51,53,53,48,46,105,99,57,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,221,24,101,241,3,0,32,0,111,112,114,45,49,51,53,52,57,46,105,99,49,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,167,7,164,203,3,0,32,0,111,112,114,45,49,51,53,52,56,46,105,99,57,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,5,216,15,8,3,0,32,0,111,112,114,45,49,51,53,52,55,46,105,99,57,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,104,221,212,66,3,0,32,0,111,112,114,45,49,51,53,52,54,46,105,99,57,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,61,191,111,202,3,0,32,0,111,112,114,45,49,51,53,52,53,46,105,99,49,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,210,141,229,201,3,0,32,0,111,112,114,45,49,51,53,52,52,46,105,99,57,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,217,54,20,156,3,0,32,0,111,112,114,45,49,51,53,52,51,46,105,99,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,14,143,28,44,3,0,32,0,111,112,114,45,49,51,53,52,50,46,105,99,49,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,184,82,253,1,3,0,32,0,111,112,114,45,49,51,53,52,49,46,105,99,49,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,123,84,92,164,3,0,32,0,111,112,114,45,49,51,53,52,48,46,105,99,57,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,176,42,180,132,3,0,32,0,111,112,114,45,49,51,53,51,57,46,105,99,57,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,79,82,110,205,3,0,32,0,111,112,114,45,49,51,53,51,56,46,105,99,49,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,134,69,154,191,3,0,32,0,111,112,114,45,49,51,53,51,55,46,105,99,49,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,62,237,20,250,3,0,32,0,111,112,114,45,49,51,53,54,52,46,105,99,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,56,161,11,231,10,0,32,0,101,112,114,45,49,51,53,54,48,46,105,99,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,37,9,5,131,4,0,16,1,111,112,114,45,49,51,53,54,51,46,105,99,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,79,231,131,64,11,0,64,0,111,112,114,45,49,51,53,54,50,46,105,99,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,143,150,195,60,11,0,64,0,111,112,114,45,49,51,53,54,49,46,105,99,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,42,192,167,128,11,0,64,0,51,49,55,45,48,49,54,57,98,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,110,163,141,5,5,0,16,1,48,54,53,45,106,98,97,48,52,46,49,48,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,235,245,108,216,1,0,16,1,48,54,53,45,106,98,97,48,53,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,38,129,188,171,1,0,16,1,48,54,53,45,97,48,50,46,57,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,76,196,29,179,1,0,16,1,48,54,53,45,97,48,51,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,230,47,132,19,1,0,16,1,48,54,53,45,97,48,49,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,77,58,125,20,2,0,16,1,48,54,53,45,97,48,56,46,49,53,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,202,154,100,107,3,0,32,0,48,54,53,45,97,48,55,46])
.concat([49,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,196,143,220,197,3,0,32,0,48,54,53,45,97,48,57,46,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,47,213,5,234,4,0,32,0,48,54,53,45,97,49,48,46,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,2,24,185,150,4,0,32,0,48,54,53,45,97,49,50,46,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,122,208,30,50,4,0,32,0,48,54,53,45,97,49,49,46,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,142,148,218,70,4,0,32,0,48,54,53,45,97,48,54,46,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,224,206,219,90,5,0,64,0,120,109,101,110,95,106,98,97,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,167,206,57,116,0,0,0,8,48,54,53,45,101,98,97,48,52,46,49,48,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,236,197,136,53,1,0,16,1,48,54,53,45,101,98,97,48,53,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,248,50,206,121,1,0,16,1,48,54,53,45,97,48,50,46,57,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,76,196,29,179,1,0,16,1,48,54,53,45,97,48,51,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,230,47,132,19,1,0,16,1,48,54,53,45,97,48,49,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,77,58,125,20,2,0,16,1,48,54,53,45,97,48,56,46,49,53,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,202,154,100,107,3,0,32,0,48,54,53,45,97,48,55,46,49,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,196,143,220,197,3,0,32,0,48,54,53,45,97,48,57,46,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,47,213,5,234,4,0,32,0,48,54,53,45,97,49,48,46,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,2,24,185,150,4,0,32,0,48,54,53,45,97,49,50,46,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,122,208,30,50,4,0,32,0,48,54,53,45,97,49,49,46,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,142,148,218,70,4,0,32,0,48,54,53,45,97,48,54,46,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,224,206,219,90,5,0,64,0,120,109,101,110,95,101,98,97,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,122,231,248,55,0,0,0,8,48,54,53,45,97,101,97,48,52,46,49,48,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,152,46,141,14,1,0,16,1,48,54,53,45,97,101,97,48,53,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,78,42,116,11,1,0,16,1,48,54,53,45,97,48,50,46,57,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,76,196,29,179,1,0,16,1,48,54,53,45,97,48,51,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,230,47,132,19,1,0,16,1,48,54,53,45,97,48,49,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,77,58,125,20,2,0,16,1,48,54,53,45,97,48,56,46,49,53,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,202,154,100,107,3,0,32,0,48,54,53,45,97,48,55,46,49,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,196,143,220,197,3,0,32,0,48,54,53,45,97,48,57,46,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,47,213,5,234,4,0,32,0,48,54,53,45,97,49,48,46,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,2,24,185,150,4,0,32,0,48,54,53,45,97,49,50,46,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,122,208,30,50,4,0,32,0,48,54,53,45,97,49,49,46,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,142,148,218,70,4,0,32,0,48,54,53,45,97,48,54,46,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,224,206,219,90,5,0,64,0,120,109,101,110,95,97,101,97,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,32,79,61,215,0,0,0,8,48,53,51,45,112,49,95,97,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,226,253,41,237,1,0,16,1,48,53,51,45,112,50,95,97,46,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,88,177,242,152,1,0,16,1,48,53,51,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,107,45,44,140,2,0,32,0,48,53,51,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,206,91,235,133,3,0,32,0,48,53,51,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,72,176,147,236,3,0,32,0,48,53,51,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,101,73,214,13,3,0,32,0,48,53,51,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,84,217,112,146,3,0,32,0,48,53,51,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,75,208,217,27,4,0,16,1,48,53,51,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,133,244,141,166,5,0,64,0,48,53,51,45,118,52,46,118,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,102,143,234,123,5,0,64,0,119,97,99,48,53,46,104,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,46,71,110,171,0,0,16,1,119,97,99,49,45,53,50,46,104,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,109,170,142,152,0,0,16,1,119,99,49,46,101,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,83,75,92,202,1,0,32,0,119,99,50,46,101,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,89,42,245,183,1,0,32,0,119,99,51,46,101,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,58,75,133,246,1,0,32,0,55,52,115,50,56,56,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,147,226,227,131,2,0,32,0,116,112,48,50,55,95,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,244,80,29,115,0,0,16,1,116,112,48,50,55,95,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,232,69,123,135,0,0,32,0,116,112,48,50,55,95,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,98,99,252,177,0,0,32,0,20,0,0,0,255,255,0,0,0,0,0,0,21,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,0,0,0,0,20,0,0,0,1,1,0,0,120,97,1,0,20,0,0,0,1,1,1,0,8,148,8,0,0,0,0,0,254,0,2,0,0,0,0,0,20,0,0,0,1,2,0,0,200,211,8,0,20,0,0,0,1,2,2,0,216,147,8,0,0,0,0,0,254,0,2,0,0,0,0,0,20,0,0,0,1,4,0,0,168,84,8,0,20,0,0,0,1,4,4,0,208,87,7,0,0,0,0,0,254,0,2,0,240,233,7,0,20,0,0,0,1,8,0,0,152,182,7,0,20,0,0,0,1,8,8,0,96,135,7,0,0,0,0,0,254,0,4,0,200,87,7,0,20,0,0,0,130,48,0,0,232,38,7,0,22,0,0,0,0,14,8,0,0,0,0,0,20,0,0,0,130,48,16,0,120,164,6,0,22,0,0,0,0,14,8,0,0,0,0,0,20,0,0,0,130,48,32,0,224,123,6,0,22,0,0,0,0,14,8,0,0,0,0,0,20,0,0,0,130,48,48,0,16,74,6,0,22,0,0,0,0,14,8,0,0,0,0,0,0,0,0,0,254,0,4,0,160,123,6,0,20,0,0,0,130,192,0,0,232,38,7,0,22,0,0,0,0,14,8,0,0,0,0,0,20,0,0,0,130,192,64,0,120,164,6,0,22,0,0,0,0,14,8,0,0,0,0,0,20,0,0,0,130,192,128,0,224,123,6,0,22,0,0,0,0,14,8,0,0,0,0,0,20,0,0,0,130,192,192,0,16,74,6,0,22,0,0,0,0,14,8,0,0,0,0,0,0,0,0,0,254,0,4,0,200,87,7,0,20,0,0,0,2,48,0,0,232,38,7,0,22,0,0,0,0,14,8,0,0,0,0,0,20,0,0,0,2,48,16,0,224,123,6,0,22,0,0,0,0,14,8,0,0,0,0,0,20,0,0,0,2,48,32,0,200,241,5,0,22,0,0,0,0,14,8,0,0,0,0,0,20,0,0,0,2,48,48,0,200,241,5,0,22,0,0,0,0,14,8,0,0,0,0,0,0,0,0,0,254,0,4,0,160,123,6,0,20,0,0,0,2,192,0,0,120,164,6,0,22,0,0,0,0,14,8,0,0,0,0,0,20,0,0,0,2,192,64,0,232,201,5,0,22,0,0,0,0,14,8,0,0,0,0,0,20,0,0,0,2,192,128,0,168,241,5,0,22,0,0,0,0,14,8,0,0,0,0,0,20,0,0,0,2,192,192,0,208,127,5,0,22,0,0,0,0,14,8,0,0,0,0,0,0,0,0,0,254,0,4,0,136,160,5,0,21,0,0,0,1,3,0,0,16,68,5,0,21,0,0,0,1,3,1,0,248,36,5,0,21,0,0,0,1,3,2,0,40,7,5,0,21,0,0,0,1,3,3,0,56,227,4,0,0,0,0,0,254,0,4,0,56,191,4,0,21,0,0,0,1,12,0,0,152,159,4,0,21,0,0,0,1,12,4,0,64,129,4,0,21,0,0,0,1,12,8,0,56,102,4,0,21,0,0,0,1,12,12,0,248,75,4,0,0,0,0,0,254,0,4,0,248,101,4,0,21,0,0,0,1,48,0,0,8,49,4,0,21,0,0,0,1,48,1,0,72,246,3,0,21,0,0,0,1,48,2,0,208,75,4,0,21,0,0,0,1,48,3,0,192,255,2,0,0,0,0,0,254,0,2,0,0,0,0,0,21,0,0,0,1,64,0,0,136,159,3,0,21,0,0,0,1,64,64,0,120,134,3,0,0,0,0,0,254,0,2,0,80,111,3,0,21,0,0,0,1,128,0,0,152,182,7,0,21,0,0,0,1,128,128,0,96,135,7,0,0,0,0,0,114,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,177,171,48,208,1,0,16,1,114,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,77,93,246,219,1,0,16,1,114,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,205,111,36,219,1,0,16,1,103,121,114,117,115,115,107,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,126,242,43,130,2,0,16,1,103,121,114,117,115,115,107,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,23,28,174,244,3,0,16,1,103,121,114,117,115,115,107,46,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,21,129,73,186,3,0,16,1,103,121,114,117,115,115,107,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,234,93,155,63,4,0,16,1,103,121,114,117,115,115,107,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,16,219,73,201,5,0,32,0,103,121,114,117,115,115,107,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,26,65,34,79,5,0,32,0,103,121,114,117,115,115,107,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,188,31,205,71,5,0,32,0,103,121,114,117,115,115,107,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,140,56,141,142,5,0,32,0,103,121,114,117,115,115,107,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,155,50,216,39,6,0,32,0,103,121,114,117,115,115,107,46,112,114,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,179,45,120,152,7,0,32,0,103,121,114,117,115,115,107,46,112,114,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,222,87,208,126,7,0,32,0,103,121,114,117,115,115,107,46,112,114,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,129,58,130,222,7,0,32,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,5,0,0,0,7,0,0,0,10,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,254,255,255,255,253,255,255,255,251,255,255,255,249,255,255,255,246,255,255,255,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,6,0,0,0,8,0,0,0,13,0,0,0,0,0,0,0,255,255,255,255,254,255,255,255,253,255,255,255,252,255,255,255,250,255,255,255,248,255,255,255,243,255,255,255,0,0,0,0,1,0,0,0,2,0,0,0,4,0,0,0,5,0,0,0,7,0,0,0,10,0,0,0,15,0,0,0,0,0,0,0,255,255,255,255,254,255,255,255,252,255,255,255,251,255,255,255,249,255,255,255,246,255,255,255,241,255,255,255,0,0,0,0,1,0,0,0,3,0,0,0,4,0,0,0,6,0,0,0,9,0,0,0,13,0,0,0,19,0,0,0,0,0,0,0,255,255,255,255,253,255,255,255,252,255,255,255,250,255,255,255,247,255,255,255,243,255,255,255,237,255,255,255,0,0,0,0,2,0,0,0,3,0,0,0,5,0,0,0,8,0,0,0,11,0,0,0,15,0,0,0,23,0,0,0,0,0,0,0,254,255,255,255,253,255,255,255,251,255,255,255,248,255,255,255,245,255,255,255,241,255,255,255,233,255,255,255,0,0,0,0,2,0,0,0,4,0,0,0,7,0,0,0,10,0,0,0,14,0,0,0,19,0,0,0,29,0,0,0,0,0,0,0,254,255,255,255,252,255,255,255,249,255,255,255,246,255,255,255,242,255,255,255,237,255,255,255,227,255,255,255,0,0,0,0,3,0,0,0,5,0,0,0,8,0,0,0,12,0,0,0,16,0,0,0,22,0,0,0,33,0,0,0,0,0,0,0,253,255,255,255,251,255,255,255,248,255,255,255,244,255,255,255,240,255,255,255,234,255,255,255,223,255,255,255,1,0,0,0,4,0,0,0,7,0,0,0,10,0,0,0,15,0,0,0,20,0,0,0,29,0,0,0,43,0,0,0,255,255,255,255,252,255,255,255,249,255,255,255,246,255,255,255,241,255,255,255,236,255,255,255,227,255,255,255,213,255,255,255,1,0,0,0,4,0,0,0,8,0,0,0,13,0,0,0,18,0,0,0,25,0,0,0,35,0,0,0,53,0,0,0,255,255,255,255,252,255,255,255,248,255,255,255,243,255,255,255,238,255,255,255,231,255,255,255,221,255,255,255,203,255,255,255,1,0,0,0,6,0,0,0,10,0,0,0,16,0,0,0,22,0,0,0,31,0,0,0,43,0,0,0,64,0,0,0,255,255,255,255,250,255,255,255,246,255,255,255,240,255,255,255,234,255,255,255,225,255,255,255,213,255,255,255,192,255,255,255,2,0,0,0,7,0,0,0,12,0,0,0,19,0,0,0,27,0,0,0,37,0,0,0,51,0,0,0,76,0,0,0,254,255,255,255,249,255,255,255,244,255,255,255,237,255,255,255,229,255,255,255,219,255,255,255,205,255,255,255,180,255,255,255,2,0,0,0,9,0,0,0,16,0,0,0,24,0,0,0,34,0,0,0,46,0,0,0,64,0,0,0,96,0,0,0,254,255,255,255,247,255,255,255,240,255,255,255,232,255,255,255,222,255,255,255,210,255,255,255,192,255,255,255,160,255,255,255,3,0,0,0,11,0,0,0,19,0,0,0,29,0,0,0,41,0,0,0,57,0,0,0,79,0,0,0,117,0,0,0,253,255,255,255,245,255,255,255,237,255,255,255,227,255,255,255,215,255,255,255,199,255,255,255,177,255,255,255,139,255,255,255,4,0,0,0,13,0,0,0,24,0,0,0,36,0,0,0,50,0,0,0,69,0,0,0,96,0,0,0,143,0,0,0,252,255,255,255,243,255,255,255,232,255,255,255,220,255,255,255,206,255,255,255,187,255,255,255,160,255,255,255,113,255,255,255,4,0,0,0,16,0,0,0,29,0,0,0,44,0,0,0,62,0,0,0,85,0,0,0,118,0,0,0,175,0,0,0,252,255,255,255,240,255,255,255,227,255,255,255,212,255,255,255,194,255,255,255,171,255,255,255,138,255,255,255,81,255,255,255,6,0,0,0,20,0,0,0,36,0,0,0,54,0,0,0,76,0,0,0,104,0,0,0,144,0,0,0,214,0,0,0,250,255,255,255,236,255,255,255,220,255,255,255,202,255,255,255,180,255,255,255,152,255,255,255,112,255,255,255,42,255,255,255,48,56,54,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,182,10,226,3,1,0,16,1,48,56,54,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,58,43,94,111,2,0,32,0,48,56,54,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,42,188,17,38,3,0,32,0,48,56,54,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,39,104,13,107,3,0,32,0,48,56,54,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,12,220,13,117,3,0,32,0,48,56,54,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,130,125,110,122,3,0,32,0,48,56,54,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,93,188,130,203,4,0,16,1,48,56,54,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,134,25,191,151,5,0,64,0,48,56,54,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,223,5,235,183,5,0,64,0,54,98,46,49,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,254,217,116,54,1,0,0,0,49,52,46,49,48,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,175,72,221,191,1,0,0,0,116,111,107,105,106,112,46,48,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,8,40,168,214,1,0,0,0,116,111,107,105,106,112,46,48,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,16,91,26,160,1,0,0,0,116,111,107,105,106,112,46,48,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,197,196,135,108,2,0,0,0,116,111,107,105,106,112,46,48,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,196,105,121,166,2,0,0,0,116,111,107,105,106,112,46,48,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,162,100,169,138,3,0,0,0,116,111,107,105,106,112,46,48,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,72,126,232,134,3,0,0,0,116,111,107,105,46,111,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,186,128,122,162,4,0,0,0,116,111,107,105,46,111,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,119,104,250,4,0,0,0,116,111,107,105,46,98,107,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,75,95,170,253,5,0,0,0,116,111,107,105,46,98,107,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,100,198,106,216,6,0,0,0,116,111,107,105,106,112,46,48,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,139,107,122,174,7,0,0,0,97,55,49,45,48,50,45,49,46,105,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,215,171,141,187,0,0,16,1,97,55,49,45,48,51,45,49,46,105,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,131,179,73,238,0,0,16,1,97,55,49,45,48,52,46,105,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,14,206,164,160,0,0,16,1,97,55,49,45,48,53,46,105,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,69,185,160,109,0,0,16,1,97,55,49,45,48,54,45,49,46,105,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,63,123,146,86,0,0,16,1,97,55,49,45,48,49,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,7,199,103,8,0,0,16,1,97,55,49,45,48,55,46,105,99,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,123,204,152,242,0,0,16,1,97,55,49,45,48,56,46,105,99,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,19,171,57,4,0,0,32,0,97,55,49,45,48,57,46,105,99,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,255,210,179,237,0,0,32,0,97,55,49,45,49,48,46,105,99,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,140,136,240,105,0,0,32,0,97,55,49,45,49,49,46,105,99,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,49,124,224,74,0,0,32,0,97,55,49,45,49,50,46,105,99,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,6,215,107,63,0,0,32,0,97,55,49,45,49,51,46,105,99,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,170,42,201,242,0,0,32,0,97,55,49,45,49,52,46,105,99,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,178,183,116,197,0,0,32,0,97,55,49,45,49,53,46,105,99,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,127,126,216,18,0,0,32,0,97,55,49,45,49,54,46,105,99,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,182,53,206,11,0,0,32,0,97,55,49,45,49,55,46,105,99,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,135,99,218,222,0,0,32,0,97,55,49,45,49,56,46,105,99,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,215,217,12,51,0,0,32,0,97,55,49,45,49,57,46,105,99,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,224,41,75,252,0,0,32,0,97,55,49,45,50,48,46,105,99,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,101,178,172,101,0,0,32,0,97,55,49,45,50,49,46,105,99,51,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,178,233,205,51,0,0,32,0,97,55,49,45,50,50,46,105,99,51,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,192,234,152,251,0,0,32,0,97,55,49,45,50,51,46,105,99,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,173,70,189,48,0,0,32,0,97,55,49,45,50,53,46,105,99,52,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,69,133,15,45,0,0,32,0,97,55,49,45,50,52,46,105,99,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,6,0,0,16,97,55,49,45,50,54,46,105,99,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,156,17,31,78,7,0,0,8,116,111,107,105,46,101,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,164,61,155,174,1,0,0,0,116,111,107,105,46,101,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,214,161,165,102,1,0,0,0,116,111,107,105,106,112,46,48,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,8,40,168,214,1,0,0,0,116,111,107,105,106,112,46,48,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,16,91,26,160,1,0,0,0,116,111,107,105,46,101,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,117,239,50,40,2,0,0,0,116,111,107,105,46,101,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,189,172,140,187,3,0,0,0,116,111,107,105,46,101,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,117,210,42,5,3,0,0,0,116,111,107,105,46,101,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,33,220,220,4,3,0,0,0,116,111,107,105,46,101,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,6,145,114,112,3,0,0,0,116,111,107,105,46,101,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,252,113,186,168,4,0,0,0,116,111,107,105,46,101,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,72,73,120,41,4,0,0,0,116,111,107,105,46,101,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,155,225,246,229,4,0,0,0,116,111,107,105,46,101,51,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,139,219,232,150,4,0,0,0,116,111,107,105,46,101,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,27,43,13,119,4,0,0,0,116,111,107,105,46,101,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,70,210,137,194,4,0,0,0,116,111,107,105,46,101,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,251,231,244,135,4,0,0,0,116,111,107,105,46,101,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,80,115,232,150,4,0,0,0,116,111,107,105,46,101,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,53,61,177,254,5,0,0,0,116,111,107,105,46,101,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,55,86,54,91,5,0,0,0,116,111,107,105,46,101,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,230,50,124,97,5,0,0,0,116,111,107,105,46,101,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,240,192,17,42,5,0,0,0,116,111,107,105,46,101,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,86,212,195,251,5,0,0,0,116,111,107,105,46,101,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,225,114,42,76,5,0,0,0,116,111,107,105,46,101,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,33,184,161,70,5,0,0,0,116,111,107,105,46,101,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,246,39,206,130,5,0,0,0,116,111,107,105,46,101,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,173,108,2,99,6,0,0,0,116,111,107,105,46,101,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,38,206,242,167,6,0,0,0,116,111,107,105,46,101,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,160,154,152,72,6,0,0,0,116,111,107,105,46,101,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,66,147,173,194,6,0,0,0,116,111,107,105,46,101,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,24,43,210,108,6,0,0,0,116,111,107,105,46,101,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,58,49,158,133,6,0,0,0,116,111,107,105,46,101,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,15,29,92,225,6,0,0,0,116,111,107,105,46,101,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,138,135,75,111,6,0,0,0,116,111,107,105,106,112,46,48,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,177,38,215,3,1,0,0,0,52,99,46,49,48,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,197,69,195,178,1,0,0,0,116,111,107,105,106,112,46,48,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,8,40,168,214,1,0,0,0,116,111,107,105,106,112,46,48,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,16,91,26,160,1,0,0,0,116,111,107,105,106,112,46,48,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,197,196,135,108,2,0,0,0,116,111,107,105,106,112,46,48,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,196,105,121,166,2,0,0,0,116,111,107,105,106,112,46,48,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,162,100,169,138,3,0,0,0,116,111,107,105,106,112,46,48,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,72,126,232,134,3,0,0,0,116,111,107,105,46,111,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,186,128,122,162,4,0,0,0,116,111,107,105,46,111,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,119,104,250,4,0,0,0,116,111,107,105,46,98,107,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,75,95,170,253,5,0,0,0,116,111,107,105,46,98,107,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,100,198,106,216,6,0,0,0,116,111,107,105,106,112,46,48,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,139,107,122,174,7,0,0,0,117,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,158,179,243,237,1,0,16,1,117,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,99,13,52,96,2,0,16,1,98,53,51,45,48,54,46,117,52,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,25,206,191,164,3,0,16,8,98,53,51,45,48,56,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,42,156,81,195,4,0,32,0,98,53,51,45,48,55,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,232,153,241,43,4,0,32,0,98,53,51,45,48,54,46,54,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,217,94,243,146,4,0,32,0,98,53,51,45,48,53,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,129,149,187,237,4,0,32,0,98,53,51,45,48,52,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,246,174,210,89,4,0,32,0,98,53,51,45,48,51,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,155,251,172,116,4,0,32,0,98,53,51,45,48,50,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,192,13,93,9,4,0,32,0,98,53,51,45,48,49,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,77,197,0,152,4,0,32,0,98,53,51,45,50,52,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,198,36,104,214,1,0,16,1,98,53,51,45,50,55,46,117,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,195,95,65,179,2,0,16,1,98,53,51,45,50,54,46,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,156,100,213,207,3,0,16,1,98,53,51,45,49,54,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,42,156,81,195,4,0,32,0,98,53,51,45,49,55,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,232,153,241,43,4,0,32,0,98,53,51,45,49,56,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,217,94,243,146,4,0,32,0,98,53,51,45,49,57,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,129,149,187,237,4,0,32,0,98,53,51,45,50,50,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,246,174,210,89,4,0,32,0,98,53,51,45,50,51,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,155,251,172,116,4,0,32,0,98,53,51,45,50,48,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,192,13,93,9,4,0,32,0,98,53,51,45,50,49,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,77,197,0,152,4,0,32,0,116,109,110,116,45,112,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,255,102,80,45,1,0,16,1,116,109,110,116,45,115,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,239,193,197,61,2,0,32,0,116,109,110,116,45,99,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,193,53,23,174,3,0,32,0,116,109,110,116,45,99,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,181,129,66,52,3,0,32,0,116,109,110,116,45,99,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,72,166,88,16,3,0,32,0,116,109,110,116,45,99,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,176,161,107,28,3,0,32,0,116,109,110,116,45,99,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,176,159,168,115,3,0,32,0,116,109,110,116,45,99,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,106,36,57,161,3,0,32,0,116,109,110,116,45,99,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,66,120,149,237,3,0,32,0,116,109,110,116,45,99,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,27,217,21,140,3,0,32,0,116,109,110,116,45,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,239,66,53,149,4,0,16,1,116,109,110,116,45,118,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,73,9,0,195,64,54,39,5,0,64,0,48,54,51,117,97,97,48,50,46,101,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,61,201,213,88,0,0,16,1,48,54,51,117,97,97,48,51,46,103,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,201,254,65,5,0,0,16,1,48,54,51,117,97,97,48,52,46,101,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,125,26,68,29,0,0,16,1,48,54,51,117,97,97,48,53,46,103,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,115,130,66,156,0,0,16,1,48,54,51,98,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,138,84,79,54,0,0,16,1,48,54,51,98,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,25,61,40,211,0,0,32,0,48,54,51,98,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,21,12,188,110,0,0,32,0,48,54,51,98,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,42,157,122,45,0,0,32,0,48,54,51,98,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,110,41,221,242,0,0,32,0,48,54,51,98,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,191,231,190,217,0,0,32,0,48,54,51,98,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,111,227,26,59,0,0,32,0,48,54,51,98,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,165,10,81,30,0,0,64,0,116,109,110,116,50,95,117,97,97,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,189,87,67,40,0,0,0,8,116,104,49,56,100,101,97,49,46,48,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,37,214,186,89,1,0,16,1,116,104,49,54,49,101,98,52,46,48,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,237,97,221,106,1,0,16,1,99,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,191,237,240,6,2,0,32,0,99,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,133,112,34,45,2,0,32,0,99,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,126,239,3,116,2,0,32,0,99,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,54,202,165,41,2,0,32,0,115,111,117,110,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,97,9,248,153,3,0,64,0,49,98,46,117,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,25,251,153,117,1,0,16,1,50,98,46,117,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,108,98,188,56,1,0,16,1,56,49,116,115,95,51,108,46,117,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,156,255,124,215,2,0,32,0,56,50,116,115,95,51,104,46,117,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,131,181,18,240,2,0,32,0,56,51,116,115,95,52,108,46,117,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,195,175,140,7,2,0,32,0,56,52,116,115,95,52,104,46,117,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,107,68,145,31,2,0,32,0,56,53,116,115,95,53,108,46,117,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,89,210,251,64,2,0,32,0,56,54,116,115,95,53,104,46,117,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,95,147,108,24,2,0,32,0,56,55,116,115,95,54,108,46,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,138,196,125,193,2,0,32,0,56,56,116,115,95,54,104,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,218,165,219,228,2,0,32,0,56,57,116,115,95,55,108,46,117,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,197,178,177,218,2,0,32,0,57,48,116,115,95,55,104,46,117,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,179,150,230,170,2,0,32,0,57,49,116,115,95,56,108,46,117,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,225,172,83,233,2,0,32,0,57,50,116,115,95,56,104,46,117,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,118,185,163,157,2,0,32,0,57,51,116,115,95,57,108,46,117,52,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,254,135,48,35,2,0,32,0,57,52,116,115,95,57,104,46,117,52,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,199,49,168,157,2,0,32,0,57,53,116,115,95,49,48,108,46,117,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,64,82,58,48,2,0,32,0,57,54,116,115,95,49,48,104,46,117,53,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,246,235,64,34,2,0,32,0,57,55,116,115,95,115,110,100,46,117,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,166,236,85,145,3,0,64,0,116,103,109,50,112,46,100,101,102,97,117,108,116,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,64,139,50,178,4,0,16,1,112,114,111,103,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,69,206,43,169,1,0,16,1,112,114,111,103,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,126,14,105,255,1,0,16,1,97,117,100,105,111,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,130,47,244,61,2,0,16,1,97,117,100,105,111,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,169,91,200,202,3,0,16,1,103,102,120,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,207,90,222,11,5,0,32,0,103,102,120,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,38,72,183,36,5,0,32,0,14,0,0,0,255,255,207,0,0,0,0,0,14,0,0,0,254,0,8,0,32,4,2,0,14,0,0,0,1,7,0,0,56,111,8,0,14,0,0,0,1,7,1,0,88,241,7,0,14,0,0,0,1,7,2,0,240,12,2,0,14,0,0,0,1,7,3,0,160,36,8,0,14,0,0,0,1,7,7,0,208,239,7,0,14,0,0,0,1,7,6,0,120,187,7,0,14,0,0,0,1,7,5,0,136,23,1,0,14,0,0,0,1,7,4,0,88,217,6,0,14,0,0,0,254,0,4,0,72,202,5,0,14,0,0,0,1,24,0,0,80,246,3,0,14,0,0,0,1,24,8,0,248,38,7,0,14,0,0,0,1,24,16,0,112,212,3,0,14,0,0,0,1,24,24,0,248,160,5,0,14,0,0,0,254,0,2,0,168,234,7,0,14,0,0,0,1,32,32,0,96,135,7,0,14,0,0,0,1,32,0,0,152,182,7,0,14,0,0,0,254,0,2,0,144,212,8,0,14,0,0,0,1,64,64,0,96,135,7,0,14,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,112,114,49,46,102,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,110,218,245,220,1,0,16,1,112,114,50,46,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,186,16,22,146,1,0,16,1,112,114,51,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,33,14,111,195,1,0,16,1,112,114,52,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,151,138,201,13,1,0,16,1,98,99,51,46,55,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,133,56,240,131,1,0,16,1,98,99,50,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,97,131,241,117,1,0,16,1,98,99,49,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,133,3,21,13,1,0,16,1,115,110,100,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,79,248,221,183,2,0,16,1,99,104,114,48,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,155,34,96,143,3,0,32,0,99,104,114,50,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,156,42,152,143,3,0,32,0,99,104,114,51,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,156,42,152,143,3,0,32,0,99,104,114,49,46,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,142,53,212,122,3,0,32,0,114,111,109,46,117,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,40,122,45,163,5,0,16,1,114,111,109,46,117,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,24,174,68,188,5,0,16,1,116,98,102,100,50,46,117,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,74,152,114,149,5,0,16,1,116,98,102,100,51,46,117,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,241,162,4,217,5,0,16,1,116,98,102,108,48,46,117,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,162,100,2,104,5,0,16,1,116,98,102,108,49,46,117,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,157,233,51,5,0,16,1,116,98,102,108,50,46,117,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,31,148,122,46,5,0,16,1,116,98,102,116,48,46,117,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,137,94,46,125,5,0,16,1,116,98,102,116,49,46,117,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,207,70,98,211,5,0,16,1,116,98,102,100,49,46,117,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,152,179,93,116,5,0,16,1,116,98,102,100,48,46,117,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,153,48,184,21,0,0,0,8,0,0,0,0,0,0,0,0,115,102,105,105,105,95,117,115,97,46,50,57,102,52,48,48,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,142,42,23,251,0,0,0,3,115,102,105,105,105,45,115,105,109,109,49,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,90,228,201,207,0,0,16,1,115,102,105,105,105,45,115,105,109,109,49,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,70,5,146,87,0,0,16,1,115,102,105,105,105,45,115,105,109,109,49,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,128,38,143,13,0,0,16,1,115,102,105,105,105,45,115,105,109,109,49,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,84,160,76,234,0,0,16,1,115,102,105,105,105,45,115,105,109,109,51,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,211,59,11,8,0,0,32,0,115,102,105,105,105,45,115,105,109,109,51,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,47,111,53,92,0,0,32,0,115,102,105,105,105,45,115,105,109,109,51,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,69,122,201,249,0,0,32,0,115,102,105,105,105,45,115,105,109,109,51,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,173,62,222,9,0,0,32,0,115,102,105,105,105,45,115,105,109,109,51,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,243,225,215,125,0,0,32,0,115,102,105,105,105,45,115,105,109,109,51,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,58,58,160,71,0,0,32,0,115,102,105,105,105,45,115,105,109,109,51,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,38,122,235,233,0,0,32,0,115,102,105,105,105,45,115,105,109,109,51,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,92,57,68,127,0,0,32,0,115,102,105,105,105,45,115,105,109,109,52,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,252,128,192,154,0,0,32,0,115,102,105,105,105,45,115,105,109,109,52,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,148,76,44,110,0,0,32,0,115,102,105,105,105,45,115,105,109,109,52,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,212,34,252,138,0,0,32,0,115,102,105,105,105,45,115,105,109,109,52,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,184,115,56,159,0,0,32,0,115,102,105,105,105,45,115,105,109,109,52,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,151,60,107,22,0,0,32,0,115,102,105,105,105,45,115,105,109,109,52,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,71,37,234,229,0,0,32,0,115,102,105,105,105,45,115,105,109,109,52,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,221,159,91,232,0,0,32,0,115,102,105,105,105,45,115,105,109,109,52,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,183,1,44,54,0,0,32,0,115,102,105,105,105,45,115,105,109,109,53,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,178,8,193,155,0,0,32,0,115,102,105,105,105,45,115,105,109,109,53,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,102,192,241,198,0,0,32,0,0,0,0,0,253,0,7,0,48,45,3,0,27,0,0,0,1,15,1,0,176,20,3,0,27,0,0,0,1,15,2,0,160,236,1,0,27,0,0,0,1,15,3,0,136,50,1,0,27,0,0,0,1,15,4,0,160,134,3,0,27,0,0,0,1,15,5,0,128,33,1,0,27,0,0,0,1,15,6,0,232,23,1,0,27,0,0,0,1,15,7,0,88,15,1,0,27,0,0,0,1,15,8,0,160,236,1,0,27,0,0,0,1,15,0,0,80,4,1,0,0,0,0,0,253,0,2,0,72,255,0,0,27,0,0,0,1,128,128,0,24,252,8,0,27,0,0,0,1,128,0,0,248,38,7,0,0,0,0,0,0,0,100,182,0,0,38,44,0,0,44,218,0,0,44,188,0,0,44,158,0,0,47,14,0,0,49,16,0,0,197,146,0,0,50,144,0,0,172,100,0,0,43,192,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,100,190,0,0,38,44,0,0,44,218,0,0,44,188,0,0,44,158,0,0,47,14,0,0,49,16,0,0,199,42,0,0,50,144,0,0,173,76,0,0,43,192,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,115,46,117,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,42,6,16,155,0,0,16,1,51,115,46,117,52,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,26,135,126,248,0,0,16,1,117,50,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,238,127,162,40,0,0,32,0,117,50,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,50,42,21,202,0,0,32,0,117,50,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,169,14,214,197,0,0,32,0,117,50,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,50,3,113,72,0,0,32,0,117,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,84,38,226,222,0,0,32,0,117,51,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,35,62,248,170,0,0,32,0,51,45,117,54,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,225,10,212,66,0,0,16,1,117,54,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,71,207,57,168,0,0,64,0,52,45,117,53,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,16,21,0,0,0,255,255,0,0,0,0,0,0,22,0,0,0,255,255,2,0,0,0,0,0,0,0,0,0,254,0,2,0,120,109,4,0,21,0,0,0,1,1,0,0,176,111,1,0,21,0,0,0,1,1,1,0,232,78,1,0,0,0,0,0,254,0,8,0,184,40,2,0,21,0,0,0,1,14,0,0,240,255,3,0,21,0,0,0,1,14,2,0,168,222,3,0,21,0,0,0,1,14,4,0,120,192,3,0,21,0,0,0,1,14,8,0,32,167,3,0,21,0,0,0,1,14,6,0,56,141,3,0,21,0,0,0,1,14,10,0,248,117,3,0,21,0,0,0,1,14,12,0,216,94,3,0,21,0,0,0,130,14,14,0,32,80,3,0,0,0,0,0,254,0,8,0,184,164,8,0,21,0,0,0,1,112,0,0,240,255,3,0,21,0,0,0,1,112,16,0,168,222,3,0,21,0,0,0,1,112,32,0,120,192,3,0,21,0,0,0,1,112,64,0,32,167,3,0,21,0,0,0,1,112,48,0,56,141,3,0,21,0,0,0,1,112,80,0,248,117,3,0,21,0,0,0,1,112,96,0,216,94,3,0,21,0,0,0,1,112,112,0,32,80,3,0,0,0,0,0,254,0,2,0,160,176,7,0,21,0,0,0,1,128,0,0,168,84,8,0,21,0,0,0,1,128,128,0,232,239,2,0,0,0,0,0,254,0,2,0,40,214,8,0,22,0,0,0,1,1,0,0,248,38,7,0,22,0,0,0,1,1,1,0,32,158,6,0,0,0,0,0,254,0,2,0,200,135,2,0,22,0,0,0,1,2,0,0,96,135,7,0,22,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,22,0,0,0,1,12,0,0,248,38,7,0,22,0,0,0,1,12,4,0,80,246,3,0,22,0,0,0,1,12,8,0,48,123,8,0,22,0,0,0,1,12,12,0,0,104,1,0,0,0,0,0,254,0,4,0,200,93,1,0,22,0,0,0,1,48,0,0,8,49,4,0,22,0,0,0,1,48,16,0,192,255,2,0,22,0,0,0,1,48,32,0,208,75,4,0,22,0,0,0,1,48,48,0,152,21,4,0,0,0,0,0,254,0,2,0,168,87,1,0,22,0,0,0,1,64,0,0,216,79,1,0,22,0,0,0,1,64,64,0,144,72,1,0,0,0,0,0,254,0,2,0,208,87,7,0,22,0,0,0,1,128,0,0,96,135,7,0,22,0,0,0,1,128,128,0,152,182,7,0,53,46,53,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,93,213,44,6,1,0,16,1,99,112,117,95,53,109,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,27,25,197,122,1,0,16,1,99,112,117,95,53,106,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,6,214,118,237,1,0,16,1,99,112,117,95,52,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,135,250,162,228,2,0,16,1,99,112,117,95,56,107,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,182,47,72,77,3,0,32,0,118,105,100,95,54,107,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,158,219,166,171,4,0,32,0,118,105,100,95,54,106,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,214,46,31,174,4,0,32,0,118,105,100,95,54,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,223,231,217,70,4,0,32,0,118,105,100,95,54,103,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,154,156,131,69,4,0,32,0,118,105,100,95,54,112,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,142,95,174,158,5,0,32,0,118,105,100,95,54,111,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,150,163,16,90,5,0,32,0,118,105,100,95,54,110,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,63,207,18,123,5,0,32,0,118,105,100,95,54,108,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,170,126,234,60,5,0,32,0,118,105,100,95,54,102,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,216,237,64,152,6,0,32,0,118,105,100,95,54,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,116,224,101,255,6,0,32,0,118,105,100,95,54,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,133,140,134,137,6,0,32,0,118,105,100,95,54,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,123,154,56,53,6,0,32,0,99,112,117,95,49,102,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,90,140,201,60,7,0,64,0,114,116,95,114,45,104,48,45,98,46,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,84,119,28,89,1,0,16,1,114,116,95,114,45,108,48,45,98,46,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,240,141,146,161,1,0,16,1,114,116,95,114,45,104,49,45,98,46,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,202,30,215,169,1,0,16,1,114,116,95,114,45,108,49,45,98,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,61,87,243,13,1,0,16,1,114,116,95,114,45,48,48,46,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,192,59,213,218,2,0,32,0,114,116,95,114,45,48,49,46,49,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,127,30,68,94,2,0,32,0,114,116,95,114,45,49,48,46,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,152,98,166,214,2,0,32,0,114,116,95,114,45,49,49,46,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,248,244,29,121,2,0,32,0,114,116,95,114,45,50,48,46,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,138,124,36,252,2,0,32,0,114,116,95,114,45,50,49,46,51,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,65,56,121,237,2,0,32,0,114,116,95,114,45,51,48,46,51,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,203,161,2,235,2,0,32,0,114,116,95,114,45,51,49,46,51,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,93,53,88,133,2,0,32,0,114,116,95,98,45,97,48,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,176,47,33,78,3,0,32,0,114,116,95,98,45,97,49,46,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,255,189,101,138,3,0,32,0,114,116,95,98,45,97,50,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,185,229,74,90,3,0,32,0,114,116,95,98,45,97,51,46,51,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,6,118,50,115,3,0,32,0,114,116,95,98,45,98,48,46,51,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,145,116,177,167,4,0,32,0,114,116,95,98,45,98,49,46,51,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,134,150,112,185,4,0,32,0,114,116,95,98,45,98,50,46,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,154,34,59,67,4,0,32,0,114,116,95,98,45,98,51,46,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,114,176,137,173,4,0,32,0,104,116,45,48,48,45,49,46,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,103,74,216,30,1,0,16,1,104,116,45,48,51,45,49,46,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,246,235,231,132,1,0,16,1,109,97,109,48,48,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,166,64,164,15,1,0,16,1,109,97,109,48,55,46,56,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,32,127,188,248,1,0,16,1,104,97,48,52,46,49,56,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,235,8,102,235,2,0,16,1,104,97,48,49,46,49,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,25,133,143,251,3,0,32,0,104,97,48,50,46,49,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,127,193,71,170,3,0,32,0,109,97,109,48,49,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,204,251,244,219,4,0,32,0,109,97,109,48,50,46,49,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,129,196,250,177,4,0,32,0,109,97,109,48,56,46,49,55,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,63,168,151,202,5,0,32,0,109,97,109,48,57,46,49,56,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,111,213,87,63,5,0,32,0,109,97,109,48,53,46,49,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,209,44,122,48,6,0,32,0,109,97,109,48,54,46,50,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,45,154,17,161,6,0,32,0,109,97,109,49,48,46,49,57,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,159,143,244,153,6,0,32,0,109,97,109,49,49,46,50,48,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,89,40,241,195,6,0,32,0,109,97,109,48,51,46,49,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,72,253,77,252,6,0,32,0,109,97,109,48,52,46,49,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,191,56,59,125,6,0,32,0,109,97,109,49,51,46,49,53,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,148,91,82,8,0,64,0,109,97,109,49,50,46,49,52,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,145,183,0,111,7,0,64,0,104,98,45,48,48,46,49,49,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,173,186,167,183,0,0,0,8,117,115,48,48,49,48,48,49,46,117,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,82,48,146,171,1,0,16,1,117,115,48,48,49,48,48,50,46,117,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,213,160,175,61,1,0,16,1,117,115,48,48,49,48,48,52,46,49,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,124,28,135,84,1,0,16,1,117,115,48,48,49,48,48,51,46,49,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,114,210,195,26,1,0,16,1,117,115,48,48,49,48,48,54,46,117,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,150,110,145,164,3,0,32,0,117,115,48,48,49,48,48,53,46,117,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,188,30,37,230,3,0,32,0,117,115,48,48,49,48,48,55,46,117,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,53,185,96,55,4,0,32,0,117,115,48,48,49,48,48,56,46,117,54,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,16,57,183,10,5,0,32,0,117,115,48,48,49,48,48,57,46,117,55,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,43,46,125,13,6,0,64,0,112,23,0,0,0,0,0,0,50,52,48,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,5,18,228,128,1,0,16,1,50,52,48,45,112,50,46,115,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,141,168,10,150,1,0,16,1,50,52,48,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,222,64,59,218,2,0,32,0,50,52,48,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,4,197,250,239,3,0,32,0,50,52,48,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,68,45,24,237,3,0,32,0,50,52,48,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,10,51,224,34,3,0,32,0,50,52,48,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,235,7,154,193,3,0,32,0,50,52,48,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,90,255,77,36,3,0,32,0,50,52,48,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,7,229,9,70,3,0,32,0,50,52,48,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,145,39,72,237,4,0,16,1,50,52,48,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,90,38,150,247,5,0,64,0,50,52,48,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,187,243,179,44,5,0,64,0,50,52,48,45,118,51,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,122,54,225,143,5,0,64,0,50,52,48,45,118,52,46,118,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,216,4,103,153,5,0,64,0,48,57,53,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,174,216,180,99,1,0,16,1,48,57,53,45,112,50,46,115,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,110,130,21,204,1,0,16,1,48,57,53,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,8,94,191,182,2,0,32,0,48,54,57,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,60,249,2,227,3,0,32,0,48,54,57,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,85,164,83,16,3,0,32,0,48,54,57,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,47,222,15,28,3,0,32,0,48,54,57,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,208,195,95,162,3,0,32,0,48,57,53,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,223,101,155,139,3,0,32,0,48,57,53,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,24,71,22,62,3,0,32,0,48,57,53,45,99,55,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,18,94,96,202,3,0,32,0,48,57,53,45,99,56,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,108,235,107,78,3,0,32,0,48,57,53,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,167,146,52,101,4,0,16,1,48,54,57,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,219,212,219,43,5,0,64,0,48,54,57,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,135,164,152,166,5,0,64,0,48,57,53,45,118,51,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,108,28,157,24,5,0,64,0,97,45,51,115,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,108,42,60,48,1,0,16,1,97,45,52,115,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,203,254,49,95,1,0,16,1,97,45,52,98,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,149,92,101,24,2,0,16,1,98,45,55,97,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,241,75,46,109,3,0,32,0,98,45,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,210,27,29,120,4,0,32,0,98,45,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,132,139,70,137,5,0,32,0,98,45,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,50,236,148,87,6,0,32,0,98,45,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,237,13,222,176,6,0,32,0,97,45,52,97,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,207,205,154,239,7,0,64,0,97,45,54,118,46,109,99,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,16,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,95,115,49,103,0,0,16,1,114,111,109,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,48,235,0,167,0,0,16,1,114,111,109,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,126,249,68,211,0,0,16,1,114,111,109,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,116,177,30,171,0,0,16,1,56,50,115,49,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,20,89,241,195,0,0,32,0,98,89,23,227,225,17,2,151,103,77,74,28,31,118,100,193,250,4,210,159,34,245,253,254,137,235,171,65,192,172,43,100,254,30,155,104,7,253,117,37,36,160,65,93,121,181,103,147,225,163,58,36,160,191,100,98,56,101,117,120,138,249,124,0,113,56,197,228,220,248,197,197,141,29,107,184,132,78,33,109,85,149,49,134,17,230,177,119,119,59,1,130,171,136,239,119,8,216,128,186,65,251,179,48,95,242,91,230,90,99,176,164,55,55,109,31,39,14,128,142,26,69,151,219,97,16,36,138,98,68,242,145,116,37,62,197,230,142,85,68,90,138,144,37,161,13,67,53,70,128,254,179,78,76,33,204,153,194,61,206,25,197,44,174,232,148,173,237,54,181,142,241,129,254,98,58,140,224,144,136,241,49,197,217,60,244,112,125,125,28,202,226,81,206,160,51,66,30,247,228,19,207,160,149,51,89,91,236,247,109,86,172,106,174,85,155,146,20,109,1,35,75,128,174,101,21,201,132,102,215,189,22,210,231,21,149,22,156,211,210,98,81,246,227,166,234,50,134,103,204,74,70,77,55,69,213,112,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,36,38,89,0,1,0,16,1,112,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,97,152,251,46,1,0,16,1,112,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,57,61,14,162,2,0,32,0,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,204,231,188,152,3,0,32,0,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,2,254,48,3,0,32,0,50,54,55,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,192,226,47,17,1,0,16,1,50,54,55,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,101,238,235,94,3,0,32,0,50,54,55,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,123,24,103,43,3,0,32,0,50,54,55,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,205,60,133,199,4,0,16,1,50,54,55,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,23,233,232,226,5,0,64,0,217,146,178,188,165,136,227,72,125,235,197,77,49,228,130,188,130,207,231,243,21,222,143,145,239,198,184,129,151,227,223,77,136,191,228,5,37,115,30,208,207,30,235,77,24,78,111,159,0,114,195,116,190,2,9,10,176,177,142,155,8,237,104,109,37,232,40,148,166,68,166,250,149,105,114,211,109,182,255,243,69,78,163,96,242,88,231,89,228,79,112,210,221,192,110,243,215,178,220,30,168,65,7,93,96,21,234,207,219,193,29,77,183,66,236,196,202,169,64,48,15,60,226,129,224,92,81,7,176,30,74,179,100,62,28,98,23,205,242,228,20,157,166,212,100,54,165,232,126,132,14,179,93,121,87,234,215,173,188,158,45,144,3,158,14,198,152,219,227,182,159,155,246,33,230,152,148,119,183,43,170,201,255,239,122,242,113,78,82,6,133,55,129,142,134,100,57,146,42,202,243,62,135,181,12,123,66,94,4,167,251,215,19,127,131,106,119,15,167,52,81,136,156,172,35,144,77,77,114,78,163,38,26,69,97,14,16,36,138,39,146,20,35,174,75,128,174,106,86,1,172,85,247,109,155,109,50,49,57,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,116,229,240,106,1,0,16,1,50,49,57,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,136,60,47,0,2,0,32,0,50,49,57,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,220,196,254,103,3,0,32,0,50,49,57,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,242,1,237,134,3,0,32,0,50,49,57,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,165,208,218,95,3,0,32,0,50,49,57,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,28,74,123,245,3,0,32,0,50,49,57,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,200,253,142,149,4,0,16,1,50,49,57,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,217,51,174,208,5,0,64,0,168,86,7,0,1,0,0,0,56,30,216,0,248,191,2,0,24,38,7,0,1,0,0,0,24,30,216,0,184,160,2,0,56,210,6,0,1,0,0,0,25,30,216,0,192,135,2,0,24,163,6,0,1,0,0,0,26,30,216,0,240,108,2,0,152,122,6,0,1,0,0,0,27,30,216,0,96,82,2,0,192,72,6,0,1,0,0,0,28,30,216,0,32,56,2,0,200,110,3,0,1,0,0,0,29,30,216,0,152,30,2,0,120,89,3,0,1,0,0,0,30,30,216,0,232,10,2,0,120,74,3,0,1,0,0,0,31,30,216,0,152,138,8,0,192,61,3,0,1,0,0,0,48,30,216,0,48,119,7,0,40,246,1,0,1,0,0,0,57,30,216,0,64,246,1,0,144,236,1,0,1,0,0,0,16,30,216,0,136,224,1,0,176,223,1,0,1,0,0,0,17,30,216,0,72,198,1,0,192,209,1,0,1,0,0,0,18,30,216,0,24,182,1,0,24,198,1,0,1,0,0,0,19,30,216,0,40,167,1,0,120,189,1,0,1,0,0,0,20,30,216,0,200,149,1,0,224,22,1,0,1,0,0,0,21,30,216,0,56,126,1,0,160,14,1,0,1,0,0,0,22,30,216,0,32,101,1,0,176,9,1,0,1,0,0,0,23,30,216,0,96,32,8,0,200,3,1,0,1,0,0,0,49,30,216,0,16,68,7,0,168,132,8,0,1,0,0,0,58,30,216,0,232,209,1,0,72,126,8,0,1,0,0,0,8,30,216,0,144,189,1,0,192,122,8,0,1,0,0,0,9,30,216,0,208,174,1,0,40,116,8,0,1,0,0,0,10,30,216,0,48,160,1,0,72,110,8,0,1,0,0,0,11,30,216,0,160,140,1,0,184,102,8,0,1,0,0,0,12,30,216,0,56,112,1,0,248,67,8,0,1,0,0,0,13,30,216,0,32,92,1,0,136,64,8,0,1,0,0,0,14,30,216,0,64,77,1,0,128,58,8,0,1,0,0,0,15,30,216,0,112,157,4,0,200,53,8,0,1,0,0,0,50,30,216,0,176,194,6,0,232,23,8,0,1,0,0,0,59,30,216,0,104,195,5,0,160,19,8,0,1,0,0,0,0,30,216,0,32,245,8,0,248,16,8,0,1,0,0,0,1,30,216,0,32,231,8,0,192,12,8,0,1,0,0,0,2,30,216,0,88,214,8,0,224,5,8,0,1,0,0,0,3,30,216,0,224,202,8,0,144,1,8,0,1,0,0,0,4,30,216,0,72,193,8,0,176,222,7,0,1,0,0,0,5,30,216,0,144,180,8,0,176,218,7,0,1,0,0,0,6,30,216,0,208,164,8,0,248,214,7,0,1,0,0,0,7,30,216,0,160,152,4,0,64,209,7,0,1,0,0,0,51,30,216,0,40,184,6,0,88,212,3,0,1,0,0,0,248,29,216,0,40,185,3,0,216,148,3,0,1,0,0,0,60,30,216,0,216,70,1,0,184,142,3,0,1,0,0,0,62,30,216,0,176,123,145,0,56,122,5,0,1,0,0,0,61,30,216,0,224,12,8,0,0,105,5,0,1,0,0,0,63,30,216,0,128,176,7,0,72,65,1,0,9,0,0,0,38,30,216,0,32,58,1,0,48,50,1,0,9,0,0,0,39,30,216,0,32,58,1,0,224,41,1,0,9,0,0,0,40,30,216,0,32,58,1,0,48,48,56,95,112,110,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,223,40,243,34,1,0,16,1,48,48,55,95,112,110,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,211,199,187,21,1,0,16,1,48,49,53,95,112,110,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,74,183,130,222,1,0,16,1,48,49,52,95,112,110,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,54,56,15,22,1,0,16,1,48,50,49,95,112,110,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,239,227,36,120,1,0,16,1,48,50,48,95,112,110,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,99,150,123,55,1,0,16,1,48,51,50,95,112,110,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,193,68,222,191,1,0,16,1,48,51,49,95,112,110,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,13,195,232,100,1,0,16,1,48,57,50,95,112,110,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,157,186,254,106,2,0,32,0,101,112,49,54,57,53,46,49,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,233,38,253,91,2,0,32,0,112,114,49,54,51,51,46,55,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,236,68,88,58,3,0,32,0,112,114,49,54,51,52,46,56,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,155,19,107,118,3,0,32,0,112,114,49,54,51,53,46,53,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,39,234,157,194,4,0,64,0,112,114,49,54,51,54,46,55,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,101,112,49,54,56,57,99,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,168,102,112,243,1,0,16,1,101,112,49,54,57,48,98,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,67,129,244,186,1,0,16,1,101,112,49,54,57,49,98,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,160,235,240,173,1,0,16,1,101,112,49,54,57,50,98,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,15,214,134,160,1,0,16,1,101,112,49,54,57,51,98,46,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,236,132,32,183,1,0,16,1,101,112,49,54,57,52,98,46,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,137,74,25,148,1,0,16,1,101,112,53,49,49,56,98,46,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,196,18,123,175,1,0,16,1,101,112,53,49,49,57,99,46,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,254,80,57,147,1,0,16,1,101,112,49,54,52,48,46,57,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,205,198,238,215,2,0,32,0,101,112,49,54,57,53,46,49,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,233,38,253,91,2,0,32,0,112,114,49,54,51,51,46,55,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,236,68,88,58,3,0,32,0,112,114,49,54,51,52,46,56,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,155,19,107,118,3,0,32,0,112,114,49,54,51,53,46,53,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,39,234,157,194,4,0,64,0,112,114,49,54,51,54,46,55,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,24,38,7,0,1,0,0,0,163,31,216,0,184,160,2,0,120,36,5,0,1,0,0,0,162,31,216,0,96,78,4,0,56,210,6,0,1,0,0,0,164,31,216,0,192,135,2,0,24,163,6,0,1,0,0,0,166,31,216,0,240,108,2,0,152,122,6,0,1,0,0,0,167,31,216,0,96,82,2,0,192,72,6,0,1,0,0,0,165,31,216,0,32,56,2,0,200,110,3,0,1,0,0,0,161,31,216,0,152,30,2,0,120,89,3,0,1,0,0,0,160,31,216,0,232,10,2,0,120,74,3,0,1,0,0,0,168,31,216,0,152,138,8,0,192,61,3,0,1,0,0,0,169,31,216,0,48,119,7,0,120,194,6,0,1,0,0,0,170,31,216,0,112,109,7,0,96,189,6,0,1,0,0,0,171,31,216,0,24,133,7,0,144,236,1,0,1,0,0,0,147,31,216,0,136,224,1,0,128,149,1,0,1,0,0,0,146,31,216,0,24,60,1,0,176,223,1,0,1,0,0,0,148,31,216,0,72,198,1,0,192,209,1,0,1,0,0,0,150,31,216,0,24,182,1,0,24,198,1,0,1,0,0,0,151,31,216,0,40,167,1,0,120,189,1,0,1,0,0,0,149,31,216,0,200,149,1,0,224,22,1,0,1,0,0,0,145,31,216,0,56,126,1,0,160,14,1,0,1,0,0,0,144,31,216,0,32,101,1,0,176,9,1,0,1,0,0,0,152,31,216,0,96,32,8,0,200,3,1,0,1,0,0,0,153,31,216,0,16,68,7,0,208,183,6,0,1,0,0,0,154,31,216,0,240,58,7,0,200,177,6,0,1,0,0,0,155,31,216,0,200,42,1,0,72,126,8,0,1,0,0,0,131,31,216,0,144,189,1,0,64,76,8,0,1,0,0,0,130,31,216,0,32,40,1,0,192,122,8,0,1,0,0,0,132,31,216,0,208,174,1,0,40,116,8,0,1,0,0,0,134,31,216,0,48,160,1,0,72,110,8,0,1,0,0,0,135,31,216,0,160,140,1,0,184,102,8,0,1,0,0,0,133,31,216,0,56,112,1,0,248,67,8,0,1,0,0,0,129,31,216,0,32,92,1,0,136,64,8,0,1,0,0,0,128,31,216,0,64,77,1,0,128,58,8,0,1,0,0,0,136,31,216,0,112,157,4,0,200,53,8,0,1,0,0,0,137,31,216,0,176,194,6,0,192,23,1,0,1,0,0,0,138,31,216,0,168,22,1,0,240,21,1,0,1,0,0,0,139,31,216,0,104,20,1,0,160,19,8,0,1,0,0,0,115,31,216,0,32,245,8,0,88,230,7,0,1,0,0,0,114,31,216,0,40,17,1,0,248,16,8,0,1,0,0,0,116,31,216,0,32,231,8,0,192,12,8,0,1,0,0,0,118,31,216,0,88,214,8,0,224,5,8,0,1,0,0,0,119,31,216,0,224,202,8,0,144,1,8,0,1,0,0,0,117,31,216,0,72,193,8,0,176,222,7,0,1,0,0,0,113,31,216,0,144,180,8,0,176,218,7,0,1,0,0,0,112,31,216,0,208,164,8,0,248,214,7,0,1,0,0,0,120,31,216,0,160,152,4,0,64,209,7,0,1,0,0,0,121,31,216,0,40,184,6,0,232,8,1,0,1,0,0,0,122,31,216,0,128,8,1,0,32,8,1,0,1,0,0,0,123,31,216,0,48,7,1,0,184,5,1,0,1,0,0,0,99,31,216,0,16,5,1,0,40,4,1,0,1,0,0,0,98,31,216,0,168,3,1,0,96,3,1,0,1,0,0,0,100,31,216,0,48,3,1,0,232,2,1,0,1,0,0,0,102,31,216,0,144,2,1,0,72,2,1,0,1,0,0,0,103,31,216,0,232,1,1,0,152,0,1,0,1,0,0,0,101,31,216,0,40,0,1,0,40,255,0,0,1,0,0,0,97,31,216,0,192,254,0,0,80,254,0,0,1,0,0,0,96,31,216,0,248,253,0,0,168,253,0,0,1,0,0,0,104,31,216,0,136,255,8,0,32,255,8,0,1,0,0,0,105,31,216,0,80,254,8,0,128,253,8,0,1,0,0,0,106,31,216,0,248,252,8,0,0,252,8,0,1,0,0,0,107,31,216,0,168,251,8,0,88,212,3,0,1,0,0,0,80,31,216,0,40,185,3,0,72,65,1,0,9,0,0,0,176,31,216,0,32,58,1,0,48,50,1,0,9,0,0,0,177,31,216,0,32,58,1,0,224,41,1,0,9,0,0,0,178,31,216,0,32,58,1,0,115,97,48,48,45,48,46,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,87,50,107,236,1,0,16,1,109,99,102,45,48,48,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,220,18,119,36,2,0,32,0,109,99,102,45,48,50,46,49,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,51,27,37,33,3,0,32,0,109,99,102,45,48,52,46,49,52,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,119,85,165,79,3,0,32,0,109,99,102,45,48,49,46,49,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,37,30,136,131,3,0,32,0,109,99,102,45,48,51,46,49,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,29,213,241,250,3,0,32,0,115,97,48,49,45,48,46,49,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,142,54,168,206,4,0,64,0,109,99,102,45,48,53,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,118,211,7,240,5,0,64,0,101,101,112,114,111,109,45,111,115,109,97,110,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,178,82,149,80,6,0,16,1,100,117,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,216,64,0,18,1,0,0,0,101,100,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,169,187,212,226,1,0,0,0,100,117,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,64,196,69,255,2,0,0,0,101,100,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,197,49,32,67,3,0,0,0,101,100,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,100,194,138,48,4,0,0,0,101,100,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,27,121,106,65,5,0,0,0,101,100,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,49,164,219,252,5,0,0,0,101,100,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,188,190,80,125,5,0,0,0,101,100,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,165,15,223,143,5,0,0,0,101,100,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,158,142,165,211,6,0,0,0,101,100,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,15,251,196,79,6,0,0,0,101,100,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,45,31,32,172,6,0,0,0,101,100,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,81,86,220,125,6,0,0,0,105,100,56,55,53,49,104,46,109,99,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,7,0,0,16,112,49,46,117,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,98,24,242,235,1,0,16,1,112,50,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,106,58,148,247,1,0,16,1,52,46,117,49,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,101,181,115,237,2,0,16,1,56,46,117,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,93,254,141,237,3,0,32,0,49,49,46,117,54,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,167,100,39,116,3,0,32,0,57,46,117,55,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,208,239,118,43,3,0,32,0,49,51,46,117,55,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,86,179,146,56,3,0,32,0,54,46,117,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,56,8,11,92,3,0,32,0,49,48,46,117,54,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,164,177,93,193,3,0,32,0,55,46,117,55,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,84,247,16,105,3,0,32,0,49,50,46,117,56,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,239,217,93,76,3,0,32,0,52,46,117,56,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,244,156,86,162,4,0,32,0,53,46,117,56,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,142,84,94,4,4,0,32,0,51,46,117,49,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,249,219,193,4,4,0,32,0,50,46,117,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,232,125,250,17,4,0,32,0,49,46,117,57,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,136,254,31,205,4,0,32,0,51,46,117,49,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,16,211,158,102,5,0,64,0,73,71,83,48,48,49,51,82,68,49,48,52,48,55,50,55,245,121,109,171,4,34,81,150,242,114,232,58,150,210,154,204,63,71,60,9,242,217,114,65,230,68,67,167,62,226,253,216,6,216,76,169,112,128,149,53,80,23,153,39,213,168,71,69,137,56,225,61,140,51,83,180,13,23,209,141,9,95,175,118,72,178,133,185,149,76,131,66,61,173,17,236,202,130,172,16,1,208,253,80,25,103,59,160,62,134,194,151,70,203,244,245,179,95,80,116,233,95,210,212,176,141,138,33,237,55,128,71,157,104,199,217,18,78,223,30,114,235,80,94,109,0,133,107,62,55,230,114,229,143,58,3,163,13,59,95,182,161,123,2,86,86,119,113,239,190,249,70,161,157,179,121,246,213,25,240,226,145,126,74,1,182,115,232,12,134,93,62,156,151,85,88,35,244,69,176,40,145,64,47,194,244,33,129,88,34,104,157,151,199,81,149,180,170,54,155,228,81,39,85,24,240,199,98,254,152,106,45,53,157,108,241,207,72,212,13,12,190,42,138,85,49,150,234,120,69,58,51,35,197,209,60,163,134,136,56,38,163,165,233,200,51,167,45,242,163,249,225,188,108,1,149,0,0,0,0,0,0,0,0,104,0,160,31,198,6,56,56,78,198,6,58,56,73,198,6,60,56,78,198,6,62,56,68])
.concat([198,6,64,56,79,198,6,66,56,85,104,0,176,31,198,6,0,9,182,198,6,0,10,182,198,6,0,11,182,104,0,208,31,198,6,112,22,87,198,6,113,22,0,234,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,110,111,115,45,112,101,45,116,46,117,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,200,251,229,190,1,0,16,1,110,111,115,45,112,111,45,116,46,117,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,49,99,115,244,1,0,16,1,110,111,115,45,112,115,46,117,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,233,81,37,131,2,0,16,1,110,111,115,45,115,101,45,48,46,117,56,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,141,16,153,157,3,0,32,0,110,111,115,45,115,111,45,48,46,117,56,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,126,252,240,125,3,0,32,0,110,111,115,45,115,101,45,49,46,117,56,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,7,118,208,170,3,0,32,0,110,111,115,45,115,111,45,49,46,117,56,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,44,1,208,131,3,0,32,0,110,111,115,45,115,101,45,50,46,117,56,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,5,96,158,217,3,0,32,0,110,111,115,45,115,111,45,50,46,117,56,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,243,142,14,246,3,0,32,0,110,111,115,45,98,48,45,48,46,117,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,242,176,20,2,4,0,32,0,110,111,115,45,98,48,45,49,46,117,53,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,52,107,139,63,4,0,32,0,110,111,115,45,98,49,45,48,46,117,54,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,199,208,111,186,5,0,32,0,110,111,115,45,98,49,45,49,46,117,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,9,128,189,218,5,0,32,0,110,111,115,115,110,45,48,48,46,117,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,188,188,209,59,6,0,64,0,110,111,115,45,112,101,45,106,46,117,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,73,1,8,75,1,0,16,1,110,111,115,45,112,111,45,106,46,117,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,222,65,226,127,1,0,16,1,110,111,115,45,112,115,46,117,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,233,81,37,131,2,0,16,1,110,111,115,45,115,101,45,48,46,117,56,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,141,16,153,157,3,0,32,0,110,111,115,45,115,111,45,48,46,117,56,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,126,252,240,125,3,0,32,0,110,111,115,45,115,101,45,49,46,117,56,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,7,118,208,170,3,0,32,0,110,111,115,45,115,111,45,49,46,117,56,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,44,1,208,131,3,0,32,0,110,111,115,45,115,101,45,50,46,117,56,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,5,96,158,217,3,0,32,0,110,111,115,45,115,111,45,50,46,117,56,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,243,142,14,246,3,0,32,0,110,111,115,45,98,48,45,48,46,117,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,242,176,20,2,4,0,32,0,110,111,115,45,98,48,45,49,46,117,53,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,52,107,139,63,4,0,32,0,110,111,115,45,98,49,45,48,46,117,54,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,199,208,111,186,5,0,32,0,110,111,115,45,98,49,45,49,46,117,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,9,128,189,218,5,0,32,0,110,111,115,115,110,45,48,48,46,117,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,188,188,209,59,6,0,64,0,117,98,49,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,226,22,133,87,1,0,16,1,117,98,49,54,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,131,180,250,18,1,0,16,1,120,104,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,196,71,208,18,2,0,16,1,115,114,111,109,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,194,224,243,109,3,0,32,0,115,114,111,109,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,249,101,175,60,3,0,32,0,115,114,111,109,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,135,63,47,129,3,0,32,0,115,114,111,109,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,157,41,184,237,3,0,32,0,115,114,111,109,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,31,130,121,3,0,32,0,115,114,111,109,54,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,175,171,55,126,3,0,32,0,115,114,111,109,55,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,96,198,169,183,3,0,32,0,115,114,111,109,56,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,88,96,186,215,3,0,32,0,117,102,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,101,189,45,80,4,0,32,0,117,102,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,160,204,68,103,4,0,32,0,117,102,97,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,127,103,16,113,4,0,32,0,117,104,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,77,239,163,246,4,0,32,0,117,106,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,239,216,149,5,4,0,32,0,120,114,97,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,62,79,74,199,5,0,64,0,22,0,0,0,240,0,0,0,0,0,0,0,0,0,0,0,255,255,2,0,0,0,0,0,0,0,0,0,254,0,4,0,48,45,3,0,0,0,0,0,1,3,0,0,176,20,3,0,0,0,0,0,1,3,1,0,160,134,3,0,0,0,0,0,1,3,2,0,8,234,2,0,0,0,0,0,1,3,3,0,64,233,8,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,48,49,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,165,218,216,8,1,0,16,1,50,48,49,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,141,149,85,47,2,0,32,0,50,48,49,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,118,54,129,114,3,0,32,0,50,48,49,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,116,37,246,150,3,0,32,0,50,48,49,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,106,69,33,81,3,0,32,0,50,48,49,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,163,89,173,244,3,0,32,0,50,48,49,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,83,50,139,194,4,0,16,1,50,48,49,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,209,46,210,35,5,0,64,0,50,48,49,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,219,249,44,71,5,0,64,0,116,110,116,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,134,101,131,14,1,0,16,1,116,110,116,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,91,76,156,119,1,0,16,1,116,110,116,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,136,198,111,173,1,0,16,1,116,110,116,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,179,87,117,215,1,0,16,1,116,110,116,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,14,204,56,48,2,0,32,0,116,110,116,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,139,77,99,151,2,0,32,0,56,50,115,49,50,51,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,189,80,198,47,3,0,32,0,56,50,115,49,50,54,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,228,168,179,62,3,0,32,0,56,50,115,49,50,54,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,134,204,169,4,0,64,0,56,50,115,49,50,54,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,16,0,0,0,255,255,251,0,0,0,0,0,17,0,0,0,255,255,255,0,0,0,0,0,18,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,32,4,2,0,16,0,0,0,1,3,1,0,160,36,8,0,16,0,0,0,1,3,3,0,208,239,7,0,16,0,0,0,1,3,2,0,120,187,7,0,16,0,0,0,1,3,0,0,16,227,4,0,0,0,0,0,254,0,4,0,128,129,4,0,16,0,0,0,1,12,12,0,208,75,4,0,16,0,0,0,1,12,8,0,8,49,4,0,16,0,0,0,1,12,4,0,152,21,4,0,16,0,0,0,1,12,0,0,72,246,3,0,0,0,0,0,254,0,4,0,64,37,5,0,16,0,0,0,1,48,48,0,200,205,3,0,16,0,0,0,1,48,32,0,160,191,4,0,16,0,0,0,1,48,16,0,32,202,3,0,16,0,0,0,1,48,0,0,24,145,2,0,0,0,0,0,254,0,2,0,200,30,2,0,16,0,0,0,1,64,64,0,120,97,1,0,16,0,0,0,1,64,0,0,96,19,1,0,0,0,0,0,100,111,115,110,111,119,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,44,78,69,211,1,0,16,1,100,111,115,110,111,119,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,178,166,32,81,1,0,16,1,100,111,115,110,111,119,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,190,109,65,150,1,0,16,1,100,111,115,110,111,119,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,182,81,80,192,1,0,16,1,100,111,115,110,111,119,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,23,98,209,133,2,0,32,0,100,111,115,110,111,119,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,75,245,167,97,2,0,32,0,100,111,115,110,111,119,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,154,35,209,43,3,0,32,0,100,111,115,110,111,119,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,223,253,143,172,3,0,32,0,100,111,115,110,111,119,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,40,216,98,118,4,0,32,0,100,111,115,110,111,119,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,209,136,63,65,4,0,32,0,117,48,50,45,45,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,215,101,138,35,5,0,32,0,116,48,50,45,45,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,192,61,38,174,5,0,32,0,102,49,48,45,45,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,162,76,238,22,5,0,32,0,106,49,48,45,45,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,132,226,127,255,5,0,32,0,100,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,89,147,205,61,1,0,16,1,100,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,216,88,0,113,1,0,16,1,100,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,216,18,125,70,1,0,16,1,100,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,235,175,233,252,1,0,16,1,100,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,102,254,76,222,2,0,32,0])
.concat([100,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,139,243,194,166,2,0,32,0,114,56,45,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,250,159,220,219,3,0,32,0,110,56,45,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,219,115,153,75,3,0,32,0,104,53,45,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,197,140,33,225,4,0,32,0,107,53,45,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,4,139,246,177,4,0,32,0,117,48,50,45,45,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,215,101,138,35,5,0,32,0,116,48,50,45,45,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,192,61,38,174,5,0,32,0,102,49,48,45,45,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,162,76,238,22,5,0,32,0,106,49,48,45,45,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,132,226,127,255,5,0,32,0,119,111,114,108,100,32,104,101,114,111,101,115,32,40,117,115,97,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,236,34,77,15,33,0,16,0,109,112,114,45,49,54,57,49,48,45,117,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,145,246,88,6,33,0,16,0,109,112,114,45,49,54,57,49,49,45,115,46,105,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,92,213,207,77,40,0,16,0,109,111,114,116,97,108,32,107,111,109,98,97,116,32,40,119,111,114,108,100,41,32,40,118,49,46,49,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,182,154,241,51,33,0,16,0,109,112,114,45,49,53,56,51,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,32,69,221,251,33,0,16,0,97,99,116,105,111,110,32,114,101,112,108,97,121,32,40,101,117,114,111,41,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,62,124,255,149,33,0,16,0,54,56,55,95,115,48,53,46,54,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,52,180,153,189,1,0,16,1,54,56,55,95,115,48,52,46,52,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,226,50,247,61,1,0,16,1,54,56,55,95,115,48,57,46,54,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,195,254,110,31,1,0,16,1,54,56,55,95,115,48,56,46,52,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,198,200,22,138,1,0,16,1,54,56,55,95,113,48,55,46,49,48,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,11,12,17,83,2,0,16,1,54,56,55,95,113,48,54,46,56,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,197,160,83,156,2,0,16,1,54,56,55,95,113,49,51,46,49,48,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,20,96,174,54,2,0,16,1,54,56,55,95,113,49,50,46,56,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,103,33,1,109,2,0,16,1,54,56,55,95,108,48,51,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,60,152,1,114,3,0,16,1,54,56,55,95,108,49,52,46,100,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,214,204,236,32,4,0,32,0,54,56,55,105,49,55,46,112,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,35,57,203,102,5,0,32,0,54,56,55,105,49,56,46,112,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,219,208,199,161,5,0,32,0,54,56,55,105,49,53,46,112,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,178,197,200,238,5,0,32,0,54,56,55,105,49,54,46,112,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,139,244,108,116,5,0,32,0,54,56,55,95,108,49,49,46,49,48,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,232,238,157,57,6,0,32,0,54,56,55,95,108,49,48,46,56,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,238,145,124,17,6,0,32,0,54,56,55,95,105,48,49,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,251,45,153,212,7,0,64,0,54,56,55,95,105,48,50,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,1,117,148,229,8,0,64,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,80,195,0,0,0,0,0,0,116,111,109,95,99,45,104,48,45,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,152,41,117,42,1,0,16,1,116,111,109,95,99,45,108,48,45,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,40,217,36,162,1,0,16,1,116,111,109,95,99,45,104,51,45,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,181,120,71,113,1,0,16,1,116,111,109,95,99,45,108,51,45,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,3,155,4,47,1,0,16,1,114,50,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,95,38,131,11,2,0,32,0,114,50,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,243,246,197,142,2,0,32,0,114,50,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,253,59,29,164,2,0,32,0,114,50,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,91,162,129,157,2,0,32,0,114,50,97,48,46,97,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,113,231,163,60,3,0,32,0,114,50,97,49,46,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,47,238,5,122,3,0,32,0,114,50,97,50,46,97,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,53,35,170,121,3,0,32,0,114,50,97,51,46,97,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,36,139,158,120,3,0,32,0,48,55,56,46,98,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,246,107,98,68,4,0,32,0,48,55,57,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,207,82,73,70,4,0,32,0,48,56,48,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,199,178,185,61,4,0,32,0,48,56,49,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,153,232,31,240,4,0,32,0,48,56,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,31,29,213,62,5,0,64,0,116,111,109,95,99,45,112,114,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,150,180,169,159,0,0,0,8,108,111,104,116,98,48,51,46,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,112,90,132,139,1,0,16,1,108,111,104,116,98,48,53,46,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,35,118,15,233,1,0,16,1,108,111,104,116,98,48,50,46,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,181,120,71,113,1,0,16,1,108,111,104,116,98,48,52,46,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,3,155,4,47,1,0,16,1,108,111,104,116,98,48,49,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,3,143,189,228,6,0,16,1,108,111,104,116,98,49,52,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,238,197,90,223,2,0,32,0,108,111,104,116,98,49,56,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,73,248,236,215,2,0,32,0,108,111,104,116,98,49,53,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,11,34,69,2,0,32,0,108,111,104,116,98,49,57,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,8,168,209,53,2,0,32,0,108,111,104,116,98,49,54,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,252,92,184,37,2,0,32,0,108,111,104,116,98,50,48,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,121,133,77,70,2,0,32,0,108,111,104,116,98,49,55,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,236,164,63,118,2,0,32,0,108,111,104,116,98,50,49,46,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,199,104,53,167,2,0,32,0,108,111,104,116,98,49,51,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,212,23,159,53,3,0,32,0,108,111,104,116,98,49,49,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,138,30,57,115,3,0,32,0,108,111,104,116,98,48,57,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,144,211,150,112,3,0,32,0,108,111,104,116,98,48,55,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,129,123,162,113,3,0,32,0,108,111,104,116,98,49,50,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,83,155,94,77,4,0,32,0,108,111,104,116,98,49,48,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,106,162,117,79,4,0,32,0,108,111,104,116,98,48,56,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,98,66,133,52,4,0,32,0,108,111,104,116,98,48,54,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,60,24,35,249,4,0,32,0,97,53,52,45,48,49,45,50,46,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,52,151,253,96,1,0,16,1,97,53,52,45,48,50,45,50,46,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,206,37,138,135,1,0,16,1,97,53,52,45,48,52,46,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,154,175,31,84,2,0,16,1,97,53,52,45,48,51,46,53,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,216,118,62,73,3,0,16,1,97,53,52,45,48,53,45,49,46,56,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,106,192,51,0,4,0,32,0,97,53,52,45,48,54,45,49,46,56,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,173,217,4,159,4,0,32,0,97,53,52,45,48,55,45,49,46,56,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,164,97,5,178,4,0,32,0,97,53,52,45,48,56,45,49,46,56,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,48,178,243,63,4,0,32,0,97,53,52,45,49,48,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,20,189,223,23,5,0,0,8,97,53,52,45,48,57,46,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,70,136,139,14,6,0,16,8,112,97,108,49,54,108,56,45,97,53,52,45,49,49,46,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,19,33,35,86,7,0,0,8,112,97,108,49,54,108,56,45,97,53,52,45,49,50,46,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,137,60,124,229,7,0,0,8,112,97,108,49,54,108,56,97,45,97,53,52,45,49,51,46,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,142,147,177,201,7,0,0,8,112,97,108,49,54,108,56,97,45,97,53,52,45,49,52,46,51,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,78,100,156,168,7,0,0,8,51,48,48,45,112,49,99,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,215,5,116,15,1,0,16,1,51,48,48,45,115,49,99,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,214,149,132,41,2,0,32,0,51,48,48,45,99,49,99,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,115,107,78,85,3,0,32,0,51,48,48,45,99,50,99,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,252,176,132,124,3,0,32,0,51,48,48,45,99,51,99,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,85,117,236,40,3,0,32,0,51,48,48,45,99,52,99,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,107,35,124,139,3,0,32,0,51,48,48,45,109,49,99,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,83,193,246,217,4,0,16,1,51,48,48,45,118,49,99,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,195,62,86,222,5,0,64,0,51,48,48,45,118,50,99,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,51,128,71,147,5,0,64,0,51,48,48,45,118,51,99,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,202,153,252,224,5,0,64,0,102,112,48,50,45,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,244,94,112,208,1,0,16,1,102,112,48,48,45,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,72,46,169,29,1,0,16,1,102,112,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,241,160,13,234,1,0,16,1,102,112,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,134,190,236,227,1,0,16,1,102,106,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,155,223,174,233,2,0,16,1,118,116,109,97,97,48,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,59,225,48,3,3,0,32,0,118,116,109,97,97,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,27,163,23,194,4,0,32,0,118,116,109,97,97,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,142,249,31,9,4,0,32,0,118,116,109,97,97,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,204,233,19,183,5,0,32,0,118,116,109,97,97,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,129,191,48,26,5,0,32,0,102,106,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,53,162,152,110,6,0,64,0,102,106,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,181,162,205,57,7,0,64,0,102,106,45,50,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,66,87,4,101,8,0,0,8,112,48,54,48,48,46,51,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,243,229,120,124,1,0,16,1,116,48,54,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,214,26,204,74,2,0,32,0,97,48,54,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,52,120,22,216,3,0,32,0,97,48,54,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,115,67,122,255,3,0,32,0,97,48,54,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,89,41,163,231,3,0,32,0,97,48,54,48,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,218,171,49,236,3,0,32,0,97,48,54,48,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,211,159,181,38,3,0,32,0,98,48,54,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,89,208,60,125,4,0,32,0,98,48,54,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,47,28,187,160,4,0,32,0,98,48,54,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,52,121,247,157,4,0,32,0,109,48,54,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,214,79,218,58,5,0,64,0,107,111,118,115,104,95,118,49,48,48,95,99,104,105,110,97,46,97,115,105,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,193,165,9,15,7,0,16,1,117,56,45,50,55,51,50,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,222,192,44,58,1,0,16,1,116,49,50,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,9,102,226,215,2,0,32,0,97,49,50,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,216,129,235,206,3,0,32,0,97,49,50,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,167,60,6,33,3,0,32,0,97,49,50,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,174,47,185,75,3,0,32,0,97,49,50,48,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,39,182,60,231,3,0,32,0,97,49,50,48,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,187,181,180,20,3,0,32,0,98,49,50,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,148,217,215,190,4,0,32,0,98,49,50,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,87,235,81,242,4,0,32,0,109,49,50,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,32,135,216,176,5,0,64,0,107,111,118,50,112,95,105,103,115,48,50,55,97,95,99,104,105,110,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,149,189,160,25,7,0,16,1,118,50,48,48,45,49,54,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,31,193,160,22,8,0,16,1,48,49,54,45,104,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,30,98,116,183,1,0,16,1,48,49,54,45,112,50,46,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,43,220,175,18,1,0,16,1,48,49,54,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,179,238,46,26,2,0,32,0,48,49,54,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,37,28,71,113,3,0,32,0,48,49,54,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,72,176,13,50,3,0,32,0,48,49,54,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,149,121,222,152,3,0,32,0,48,49,54,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,226,6,5,7,3,0,32,0,48,49,54,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,16,202,169,157,4,0,16,1,48,49,54,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,2,165,192,134,5,0,64,0,48,49,54,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,197,62,194,91,5,0,64,0,48,51,57,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,76,213,114,179,1,0,16,1,48,51,57,45,112,50,46,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,254,26,102,40,1,0,16,1,48,51,57,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,58,5,238,99,2,0,32,0,48,51,57,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,169,74,28,109,3,0,32,0,48,51,57,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,55,83,183,247,3,0,32,0,48,51,57,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,178,240,196,191,3,0,32,0,48,51,57,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,80,194,201,129,3,0,32,0,48,51,57,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,213,42,91,12,4,0,16,1,48,51,57,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,37,75,211,134,5,0,64,0,48,51,57,45,118,52,46,118,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,11,42,166,143,5,0,64,0,107,97,46,110,101,111,45,115,109,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,158,208,102,119,9,0,16,1,50,53,49,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,50,69,110,0,1,0,16,1,50,53,49,45,112,50,46,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,21,95,23,144,1,0,16,1,50,53,49,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,254,147,158,15,3,0,32,0,50,53,49,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,163,46,30,231,3,0,32,0,50,53,49,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,210,85,135,35,3,0,32,0,50,53,49,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,34,139,140,67,3,0,32,0,50,53,49,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,10,189,10,11,3,0,32,0,50,53,49,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,129,242,187,101,3,0,32,0,50,53,49,45,99,55,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,46,246,101,255,3,0,32,0,50,53,49,45,99,56,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,104,28,146,141,3,0,32,0,50,53,49,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,156,83,116,94,4,0,16,1,50,53,49,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,200,236,46,239,5,0,64,0,50,53,49,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,202,17,226,115,5,0,64,0,50,53,49,45,118,51,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,218,1,25,130,5,0,64,0,50,53,49,45,118,52,46,118,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,120,97,158,180,5,0,64,0,50,52,50,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,137,223,147,136,1,0,16,1,50,52,50,45,112,50,46,115,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,76,186,10,152,1,0,16,1,50,52,50,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,5,72,123,127,2,0,32,0,50,52,50,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,214,236,100,229,3,0,32,0,50,52,50,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,96,155,149,189,3,0,32,0,50,52,50,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,79,123,18,34,3,0,32,0,50,52,50,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,68,160,79,11,3,0,32,0,50,52,50,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,211,190,16,157,3,0,32,0,50,52,50,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,162,182,7,218,3,0,32,0,50,52,50,45,99,55,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,138,163,215,246,3,0,32,0,50,52,50,45,99,56,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,69,224,35,200,3,0,32,0,50,52,50,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,107,1,247,78,4,0,16,1,50,52,50,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,81,128,234,185,5,0,64,0,50,52,50,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,110,16,17,204,5,0,64,0,50,52,50,45,118,51,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,225,164,78,4,5,0,64,0,50,52,50,45,118,52,46,118,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,48,234,133,121,5,0,64,0,50,51,50,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,217,26,184,125,1,0,16,1,50,51,50,45,112,50,46,115,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,246,35,139,21,1,0,16,1,50,51,50,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,245,236,20,133,2,0,32,0,50,51,50,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,161,240,139,95,3,0,32,0,50,51,50,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,129,92,212,228,3,0,32,0,50,51,50,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,24,102,29,88,3,0,32,0,50,51,50,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,104,30,187,73,3,0,32,0,50,51,50,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,81,78,252,52,3,0,32,0,50,51,50,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,123,212,244,79,3,0,32,0,50,51,50,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,71,135,52,69,4,0,16,1,50,51,50,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,181,181,162,34,5,0,64,0,50,51,50,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,68,231,4,35,5,0,64,0,50,51,50,45,118,51,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,84,185,158,117,5,0,64,0,50,49,52,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,116,93,117,82,1,0,16,1,50,49,52,45,112,50,46,115,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,115,203,44,0,1,0,16,1,50,49,52,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,219,203,84,18,2,0,32,0,50,49,52,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,162,74,207,126,3,0,32,0,50,49,52,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,55,79,181,5,3,0,32,0,50,49,52,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,101,154,152,100,3,0,32,0,50,49,52,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,21,165,190,175,3,0,32,0,50,49,52,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,38,189,59,42,3,0,32,0,50,49,52,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,199,13,211,68,3,0,32,0,50,49,52,45,99,55,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,27,51,135,54,3,0,32,0,50,49,52,45,99,56,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,173,97,20,250,3,0,32,0,50,49,52,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,124,66,188,218,4,0,16,1,50,49,52,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,69,176,247,99,5,0,64,0,50,49,52,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,89,144,146,37,5,0,64,0,50,49,52,45,118,51,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,125,37,162,146,5,0,64,0,48,56,52,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,22,39,186,44,1,0,16,1,48,56,52,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,138,111,113,222,2,0,32,0,48,56,52,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,50,126,8,254,3,0,32,0,48,56,52,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,9,78,134,7,3,0,32,0,48,56,52,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,27,93,230,164,3,0,32,0,48,56,52,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,104,228,172,193,3,0,32,0,48,56,52,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,220,30,44,138,3,0,32,0,48,56,52,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,53,172,147,245,3,0,32,0,48,56,52,45,99,55,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,95,2,4,153,3,0,32,0,48,56,52,45,99,56,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,155,15,235,120,3,0,32,0,48,56,52,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,41,116,45,111,4,0,16,1,48,56,52,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,86,27,134,132,5,0,64,0,48,56,52,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,3,40,138,179,5,0,64,0,48,56,52,45,118,51,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,56,163,131,214,5,0,64,0,48,53,53,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,66,32,10,241,1,0,16,1,48,53,53,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,193,118,89,130,2,0,32,0,48,53,53,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,96,244,110,185,3,0,32,0,48,53,53,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,167,150,224,21,3,0,32,0,48,53,53,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,84,98,246,84,3,0,32,0,48,53,53,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,95,118,1,11,3,0,32,0,48,53,53,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,99,147,117,238,3,0,32,0,48,53,53,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,44,165,141,73,3,0,32,0,48,53,53,45,99,55,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,136,104,246,98,3,0,32,0,48,53,53,45,99,56,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,93,35,10,254,3,0,32,0,48,53,53,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,245,124,231,246,4,0,16,1,48,53,53,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,109,89,137,136,5,0,64,0,48,53,53,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,39,43,2,37,5,0,64,0,48,53,53,45,118,51,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,192,50,207,131,5,0,64,0,20,0,0,0,255,255,0,0,0,0,0,0,21,0,0,0,255,255,0,0,0,0,0,0,22,0,0,0,255,15,0,0,0,0,0,0,0,0,0,0,254,0,2,0,0,0,0,0,20,0,0,0,1,1,0,0,216,196,1,0,20,0,0,0,1,1,1,0,232,99,1,0,0,0,0,0,254,0,2,0,0,0,0,0,20,0,0,0,1,2,0,0,200,211,8,0,20,0,0,0,1,2,2,0,216,147,8,0,0,0,0,0,254,0,2,0,0,0,0,0,20,0,0,0,1,4,0,0,168,84,8,0,20,0,0,0,1,4,4,0,208,87,7,0,0,0,0,0,254,0,2,0,240,233,7,0,20,0,0,0,1,8,0,0,152,182,7,0,20,0,0,0,1,8,8,0,96,135,7,0,0,0,0,0,254,0,4,0,200,87,7,0,20,0,0,0,1,48,0,0,232,38,7,0,20,0,0,0,1,48,16,0,120,164,6,0,20,0,0,0,1,48,32,0,224,123,6,0,20,0,0,0,1,48,48,0,16,74,6,0,0,0,0,0,254,0,4,0,160,123,6,0,20,0,0,0,1,192,0,0,232,38,7,0,20,0,0,0,1,192,64,0,120,164,6,0,20,0,0,0,1,192,128,0,224,123,6,0,20,0,0,0,1,192,192,0,16,74,6,0,0,0,0,0,254,0,4,0,136,160,5,0,21,0,0,0,1,3,0,0,16,150,7,0,21,0,0,0,1,3,1,0,120,198,7,0,21,0,0,0,1,3,2,0,160,103,7,0,21,0,0,0,1,3,3,0,16,53,7,0,0,0,0,0,254,0,4,0,56,191,4,0,21,0,0,0,1,12,0,0,64,128,5,0,21,0,0,0,1,12,4,0,216,135,2,0,21,0,0,0,1,12,8,0,176,227,4,0,21,0,0,0,1,12,12,0,248,75,4,0,0,0,0,0,254,0,4,0,248,101,4,0,21,0,0,0,1,48,0,0,208,75,4,0,21,0,0,0,1,48,1,0,72,246,3,0,21,0,0,0,1,48,2,0,152,21,4,0,21,0,0,0,1,48,3,0,208,75,4,0,0,0,0,0,254,0,2,0,0,0,0,0,21,0,0,0,1,64,0,0,136,159,3,0,21,0,0,0,1,64,64,0,168,102,4,0,0,0,0,0,254,0,2,0,104,82,2,0,21,0,0,0,1,128,0,0,152,182,7,0,21,0,0,0,1,128,128,0,96,135,7,0,0,0,0,0,254,0,7,0,224,159,3,0,22,0,0,0,1,15,0,0,176,20,3,0,22,0,0,0,1,15,1,0,160,134,3,0,22,0,0,0,1,15,2,0,8,234,2,0,22,0,0,0,1,15,3,0,56,50,1,0,22,0,0,0,1,15,4,0,192,20,3,0,22,0,0,0,1,15,5,0,80,65,1,0,22,0,0,0,1,15,6,0,160,236,1,0,22,0,0,0,1,15,7,0,24,4,2,0,22,0,0,0,1,15,8,0,176,20,3,0,22,0,0,0,1,15,9,0,24,4,2,0,22,0,0,0,1,15,10,0,8,234,2,0,22,0,0,0,1,15,11,0,56,50,1,0,22,0,0,0,1,15,12,0,192,20,3,0,22,0,0,0,1,15,13,0,80,65,1,0,22,0,0,0,1,15,14,0,160,236,1,0,22,0,0,0,1,15,15,0,176,123,145,0,0,0,0,0,106,117,106,117,98,95,112,108,97,121,109,97,114,107,46,101,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,236,115,12,181,1,0,0,0,106,117,106,117,98,95,112,108,97,121,109,97,114,107,46,101,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,66,41,129,178,1,0,0,0,116,111,107,105,106,112,46,48,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,8,40,168,214,1,0,0,0,116,111,107,105,106,112,46,48,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,16,91,26,160,1,0,0,0,116,111,107,105,46,101,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,117,239,50,40,2,0,0,0,116,111,107,105,46,101,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,189,172,140,187,3,0,0,0,116,111,107,105,46,101,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,117,210,42,5,3,0,0,0,116,111,107,105,46,101,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,33,220,220,4,3,0,0,0,116,111,107,105,46,101,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,6,145,114,112,3,0,0,0,116,111,107,105,46,101,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,252,113,186,168,4,0,0,0,116,111,107,105,46,101,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,72,73,120,41,4,0,0,0,116,111,107,105,46,101,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,155,225,246,229,4,0,0,0,116,111,107,105,46,101,51,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,139,219,232,150,4,0,0,0,116,111,107,105,46,101,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,27,43,13,119,4,0,0,0,116,111,107,105,46,101,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,70,210,137,194,4,0,0,0,116,111,107,105,46,101,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,251,231,244,135,4,0,0,0,116,111,107,105,46,101,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,80,115,232,150,4,0,0,0,116,111,107,105,46,101,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,53,61,177,254,5,0,0,0,116,111,107,105,46,101,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,55,86,54,91,5,0,0,0,116,111,107,105,46,101,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,230,50,124,97,5,0,0,0,116,111,107,105,46,101,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,240,192,17,42,5,0,0,0,116,111,107,105,46,101,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,86,212,195,251,5,0,0,0,116,111,107,105,46,101,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,225,114,42,76,5,0,0,0,116,111,107,105,46,101,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,33,184,161,70,5,0,0,0,116,111,107,105,46,101,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,246,39,206,130,5,0,0,0,116,111,107,105,46,101,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,173,108,2,99,6,0,0,0,116,111,107,105,46,101,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,38,206,242,167,6,0,0,0,116,111,107,105,46,101,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,160,154,152,72,6,0,0,0,116,111,107,105,46,101,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,66,147,173,194,6,0,0,0,116,111,107,105,46,101,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,24,43,210,108,6,0,0,0,116,111,107,105,46,101,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,58,49,158,133,6,0,0,0,116,111,107,105,46,101,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,15,29,92,225,6,0,0,0,116,111,107,105,46,101,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,138,135,75,111,6,0,0,0,106,111,106,111,95,97,115,105,97,95,110,111,99,100,46,50,57,102,52,48,48,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,83,249,180,5,0,0,0,3,106,111,106,111,40,95,95,57,57,48,49,50,56,41,45,115,105,109,109,49,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,139,148,22,149,0,0,16,1,106,111,106,111,40,95,95,57,57,48,49,50,56,41,45,115,105,109,109,49,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,141,132,71,168,0,0,16,1,106,111,106,111,40,95,95,57,57,48,49,50,56,41,45,115,105,109,109,49,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,70,136,62,133,0,0,16,1,106,111,106,111,40,95,95,57,57,48,49,50,56,41,45,115,105,109,109,49,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,14,224,79,192,0,0,16,1,106,111,106,111,40,95,95,57,57,48,49,50,56,41,45,115,105,109,109,50,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,200,179,164,225,0,0,16,1,106,111,106,111,40,95,95,57,57,48,49,50,56,41,45,115,105,109,109,50,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,149,239,156,24,0,0,16,1,106,111,106,111,40,95,95,57,57,48,49,50,56,41,45,115,105,109,109,50,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,198,94,219,71,0,0,16,1,106,111,106,111,40,95,95,57,57,48,49,50,56,41,45,115,105,109,109,50,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,85,161,211,227,0,0,16,1,106,111,106,111,45,115,105,109,109,51,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,193,201,127,222,0,0,32,0,106,111,106,111,45,115,105,109,109,51,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,211,83,208,67,0,0,32,0,106,111,106,111,45,115,105,109,109,51,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,165,127,253,47,0,0,32,0,106,111,106,111,45,115,105,109,109,51,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,91,152,164,77,0,0,32,0,106,111,106,111,45,115,105,109,109,51,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,114,141,233,253,0,0,32,0,106,111,106,111,45,115,105,109,109,51,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,102,162,178,237,0,0,32,0,106,111,106,111,45,115,105,109,109,51,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,25,243,124,190,0,0,32,0,106,111,106,111,45,115,105,109,109,51,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,159,26,254,86,0,0,32,0,106,111,106,111,45,115,105,109,109,52,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,104,191,231,196,0,0,32,0,106,111,106,111,45,115,105,109,109,52,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,25,39,43,182,0,0,32,0,106,111,106,111,45,115,105,109,109,52,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,9,88,209,24,0,0,32,0,106,111,106,111,45,115,105,109,109,52,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,121,173,240,154,0,0,32,0,106,111,106,111,45,115,105,109,109,52,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,240,193,36,65,0,0,32,0,106,111,106,111,45,115,105,109,109,52,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,209,31,0,94,0,0,32,0,106,111,106,111,45,115,105,109,109,52,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,59,162,255,154,0,0,32,0,106,111,106,111,45,115,105,109,109,52,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,42,87,17,37,0,0,32,0,106,111,106,111,45,115,105,109,109,53,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,252,21,118,121,0,0,32,0,106,111,106,111,45,115,105,109,109,53,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,98,209,79,115,0,0,32,0,106,111,106,111,95,106,97,112,97,110,46,50,57,102,52,48,48,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,96,143,119,2,0,0,0,3,106,111,106,111,40,95,95,57,57,48,49,50,56,41,45,115,105,109,109,49,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,139,148,22,149,0,0,16,1,106,111,106,111,40,95,95,57,57,48,49,50,56,41,45,115,105,109,109,49,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,141,132,71,168,0,0,16,1,106,111,106,111,40,95,95,57,57,48,49,50,56,41,45,115,105,109,109,49,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,70,136,62,133,0,0,16,1,106,111,106,111,40,95,95,57,57,48,49,50,56,41,45,115,105,109,109,49,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,14,224,79,192,0,0,16,1,106,111,106,111,40,95,95,57,57,48,49,50,56,41,45,115,105,109,109,50,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,200,179,164,225,0,0,16,1,106,111,106,111,40,95,95,57,57,48,49,50,56,41,45,115,105,109,109,50,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,149,239,156,24,0,0,16,1,106,111,106,111,40,95,95,57,57,48,49,50,56,41,45,115,105,109,109,50,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,198,94,219,71,0,0,16,1,106,111,106,111,40,95,95,57,57,48,49,50,56,41,45,115,105,109,109,50,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,85,161,211,227,0,0,16,1,106,111,106,111,45,115,105,109,109,51,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,193,201,127,222,0,0,32,0,106,111,106,111,45,115,105,109,109,51,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,211,83,208,67,0,0,32,0,106,111,106,111,45,115,105,109,109,51,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,165,127,253,47,0,0,32,0,106,111,106,111,45,115,105,109,109,51,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,91,152,164,77,0,0,32,0,106,111,106,111,45,115,105,109,109,51,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,114,141,233,253,0,0,32,0,106,111,106,111,45,115,105,109,109,51,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,102,162,178,237,0,0,32,0,106,111,106,111,45,115,105,109,109,51,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,25,243,124,190,0,0,32,0,106,111,106,111,45,115,105,109,109,51,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,159,26,254,86,0,0,32,0,106,111,106,111,45,115,105,109,109,52,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,104,191,231,196,0,0,32,0,106,111,106,111,45,115,105,109,109,52,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,25,39,43,182,0,0,32,0,106,111,106,111,45,115,105,109,109,52,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,9,88,209,24,0,0,32,0,106,111,106,111,45,115,105,109,109,52,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,121,173,240,154,0,0,32,0,106,111,106,111,45,115,105,109,109,52,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,240,193,36,65,0,0,32,0,106,111,106,111,45,115,105,109,109,52,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,209,31,0,94,0,0,32,0,106,111,106,111,45,115,105,109,109,52,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,59,162,255,154,0,0,32,0,106,111,106,111,45,115,105,109,109,52,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,42,87,17,37,0,0,32,0,106,111,106,111,45,115,105,109,109,53,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,252,21,118,121,0,0,32,0,106,111,106,111,45,115,105,109,109,53,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,98,209,79,115,0,0,32,0,106,109,48,49,120,51,46,117,54,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,65,177,173,192,1,0,16,1,106,109,48,48,120,51,46,117,54,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,90,220,170,177,1,0,16,1,106,109,49,49,120,51,46,117,54,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,19,249,227,210,1,0,16,1,106,109,49,48,120,51,46,117,55,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,225,254,8,238,1,0,16,1,106,115,112,49,120,51,46,117,56,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,142,43,93,209,2,0,16,1,106,115,112,48,120,51,46,117,56,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,177,80,236,235,2,0,16,1,106,99,100,48,120,49,46,117,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,156,218,65,42,3,0,16,1,106,99,45,50,48,48,46,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,78,194,48,31,4,0,32,0,106,99,45,49,48,48,45,48,48,46,49,55,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,140,146,141,87,5,0,32,0,106,99,45,49,48,49,45,48,48,46,49,56,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,202,26,94,127,5,0,32,0,106,99,45,49,48,50,45,48,48,46,49,56,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,104,170,202,114,5,0,32,0,106,99,45,49,48,51,45,48,48,46,49,56,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,201,159,158,78,5,0,32,0,106,99,45,49,48,52,45,48,48,46,49,56,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,147,46,42,107,5,0,32,0,106,99,45,49,48,53,45,48,48,46,49,56,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,240,209,202,115,5,0,32,0,106,99,45,49,48,56,45,48,48,46,49,56,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,49,17,221,103,5,0,32,0,106,99,115,48,120,51,46,49,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,188,44,1,154,5,0,32,0,106,99,115,49,120,51,46,49,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,141,124,174,87,5,0,32,0,106,99,45,49,48,54,45,48,48,46,49,55,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,27,102,101,188,6,0,32,0,106,99,45,49,48,55,45,48,48,46,49,55,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,139,110,168,146,6,0,32,0,106,99,45,51,48,49,45,48,48,46,56,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,119,48,91,156,7,0,64,0,106,99,45,51,48,48,45,48,48,46,56,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,235,177,213,19,7,0,64,0,106,99,119,48,120,48,46,117,53,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,42,92,242,188,7,0,64,0,45,0,0,0,255,255,0,0,0,0,0,0,47,0,0,0,255,1,0,0,0,0,0,0,0,0,0,0,254,0,2,0,208,87,7,0,45,0,0,0,1,1,0,0,96,135,7,0,45,0,0,0,1,1,1,0,152,182,7,0,0,0,0,0,254,0,2,0,16,49,4,0,45,0,0,0,1,2,2,0,96,135,7,0,45,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,88,178,4,0,45,0,0,0,1,4,4,0,96,135,7,0,45,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,40,182,1,0,45,0,0,0,1,8,0,0,96,135,7,0,45,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,2,0,248,142,8,0,45,0,0,0,1,16,0,0,96,135,7,0,45,0,0,0,1,16,16,0,152,182,7,0,0,0,0,0,106,97,99,107,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,210,81,33,99,1,0,16,1,106,97,99,107,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,217,128,79,249,1,0,16,1,106,97,99,107,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,30,255,48,200,1,0,16,1,106,97,99,107,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,231,23,234,141,1,0,16,1,106,103,107,46,106,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,168,20,85,96,1,0,16,1,106,103,107,46,106,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,183,137,228,188,1,0,16,1,106,103,107,46,106,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,16,0,0,85,189,33,219,1,0,16,1,106,97,99,107,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,61,234,117,126,1,0,16,1,106,103,107,46,106,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,30,220,194,2,0,16,1,106,97,99,107,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,71,6,50,128,3,0,32,0,106,103,107,46,106,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,141,44,236,106,3,0,32,0,106,103,107,46,106,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,37,197,20,253,3,0,32,0,106,103,107,46,106,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,178,144,184,234,3,0,32,0,106,103,107,46,106,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,32,158,34,254,1,0,16,1,106,103,107,46,106,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,14,129,215,54,1,0,16,1,106,103,107,46,106,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,238,243,95,177,1,0,16,1,106,103,107,46,106,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,66,210,99,74,1,0,16,1,106,103,107,46,106,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,168,20,85,96,1,0,16,1,106,103,107,46,106,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,183,137,228,188,1,0,16,1,106,103,107,46,106,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,85,189,33,219,1,0,16,1,106,103,107,46,106,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,49,254,255,73,1,0,16,1,106,103,107,46,106,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,30,220,194,2,0,16,1,106,103,107,46,106,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,240,109,114,206,3,0,32,0,106,103,107,46,106,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,141,44,236,106,3,0,32,0,106,103,107,46,106,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,37,197,20,253,3,0,32,0,106,103,107,46,106,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,178,144,184,234,3,0,32,0,126,204,236,3,4,51,182,197,191,55,146,148,0,0,0,0,0,0,0,0,0,0,0,0,104,45,104,48,45,99,46,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,158,35,204,132,1,0,16,1,104,45,108,48,45,99,46,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,254,148,225,69,1,0,16,1,104,45,104,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,240,161,75,38,1,0,16,1,104,45,108,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,49,55,145,249,1,0,16,1,104,45,115,104,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,110,229,164,134,2,0,16,1,104,45,115,108,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,118,150,253,16,2,0,16,1,104,111,111,107,45,99,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,207,61,198,222,3,0,32,0,104,111,111,107,45,99,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,146,11,235,228,3,0,32,0,104,111,111,107,45,99,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,11,50,43,165,3,0,32,0,104,111,111,107,45,99,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,49,119,246,126,3,0,32,0,104,111,111,107,45,48,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,48,172,206,204,4,0,32,0,104,111,111,107,45,48,49,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,103,218,200,138,4,0,32,0,104,111,111,107,45,48,50,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,154,175,71,136,4,0,32,0,104,111,111,107,45,48,51,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,126,135,158,35,4,0,32,0,104,111,111,107,45,100,97,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,18,2,205,136,5,0,64,0,104,45,104,48,45,103,46,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,134,200,100,89,1,0,16,1,104,45,108,48,45,103,46,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,242,51,116,127,1,0,16,1,104,45,104,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,240,161,75,38,1,0,16,1,104,45,108,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,49,55,145,249,1,0,16,1,104,45,115,104,48,45,97,46,51,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,97,31,61,189,2,0,16,1,104,45,115,108,48,45,97,46,51,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,239,29,55,118,2,0,16,1,104,111,111,107,45,99,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,207,61,198,222,3,0,32,0,104,111,111,107,45,99,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,146,11,235,228,3,0,32,0,104,111,111,107,45,99,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,11,50,43,165,3,0,32,0,104,111,111,107,45,99,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,49,119,246,126,3,0,32,0,104,111,111,107,45,48,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,48,172,206,204,4,0,32,0,104,111,111,107,45,48,49,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,103,218,200,138,4,0,32,0,104,111,111,107,45,48,50,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,154,175,71,136,4,0,32,0,104,111,111,107,45,48,51,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,126,135,158,35,4,0,32,0,104,111,111,107,45,100,97,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,18,2,205,136,5,0,64,0,50,4,0,0,146,4,0,0,50,4,0,0,50,4,0,0,140,29,0,0,114,49,0,0,148,38,0,0,208,22,0,0,8,12,0,0,114,32,0,0,176,7,0,0,176,39,0,0,124,24,0,0,116,44,0,0,44,42,0,0,74,10,0,0,62,40,0,0,36,47,0,0,162,25,0,0,228,19,0,0,50,4,0,0,50,4,0,0,56,22,0,0,254,9,0,0,212,49,0,0,10,41,0,0,42,47,0,0,36,31,0,0,50,4,0,0,50,4,0,0,50,4,0,0,50,4,0,0,134,11,0,0,112,35,0,0,132,18,0,0,194,14,0,0,168,37,0,0,38,41,0,0,90,3,0,0,56,2,0,0,254,38,0,0,16,23,0,0,100,42,0,0,84,3,0,0,118,9,0,0,248,19,0,0,170,3,0,0,218,42,0,0,248,2,0,0,178,28,0,0,172,13,0,0,206,7,0,0,86,2,0,0,86,16,0,0,84,20,0,0,232,38,0,0,38,43,0,0,80,17,0,0,152,35,0,0,120,50,0,0,66,46,0,0,234,19,0,0,46,49,0,0,120,31,0,0,78,40,0,0,50,4,0,0,50,4,0,0,100,23,0,0,26,43,0,0,50,4,0,0,238,45,0,0,190,0,0,0,232,9,0,0,54,9,0,0,230,26,0,0,50,4,0,0,152,26,0,0,70,9,0,0,50,4,0,0,232,26,0,0,62,29,0,0,50,4,0,0,50,4,0,0,122,47,0,0,248,35,0,0,50,4,0,0,224,33,0,0,254,2,0,0,242,37,0,0,198,34,0,0,122,18,0,0,50,4,0,0,72,37,0,0,250,25,0,0,50,4,0,0,14,16,0,0,92,37,0,0,244,35,0,0,68,28,0,0,166,40,0,0,174,34,0,0,28,16,0,0,162,3,0,0,148,4,0,0,202,38,0,0,214,14,0,0,106,42,0,0,196,9,0,0,94,12,0,0,236,27,0,0,156,27,0,0,238,40,0,0,186,7,0,0,154,44,0,0,40,48,0,0,140,5,0,0,70,13,0,0,40,8,0,0,156,47,0,0,4,40,0,0,14,30,0,0,150,29,0,0,128,27,0,0,64,19,0,0,156,48,0,0,138,22,0,0,30,39,0,0,26,4,0,0,104,50,0,0,186,34,0,0,88,42,0,0,198,9,0,0,188,42,0,0,24,30,0,0,232,36,0,0,46,47,0,0,236,21,0,0,66,43,0,0,138,24,0,0,188,45,0,0,16,25,0,0,8,50,0,0,106,50,0,0,152,25,0,0,26,17,0,0,184,37,0,0,214,23,0,0,38,22,0,0,188,22,0,0,12,1,0,0,2,4,0,0,182,26,0,0,26,48,0,0,94,39,0,0,220,48,0,0,162,32,0,0,18,38,0,0,50,34,0,0,232,32,0,0,60,10,0,0,90,33,0,0,156,8,0,0,8,5,0,0,28,31,0,0,158,14,0,0,208,38,0,0,202,49,0,0,208,48,0,0,46,0,0,0,254,0,0,0,44,49,0,0,32,2,0,0,180,35,0,0,26,16,0,0,118,4,0,0,30,10,0,0,158,9,0,0,208,32,0,0,158,46,0,0,114,46,0,0,38,35,0,0,58,23,0,0,116,50,0,0,254,21,0,0,202,29,0,0,242,14,0,0,44,22,0,0,76,7,0,0,86,40,0,0,230,8,0,0,148,49,0,0,120,11,0,0,18,34,0,0,90,6,0,0,132,47,0,0,172,49,0,0,248,11,0,0,200,42,0,0,144,28,0,0,154,14,0,0,86,22,0,0,206,27,0,0,74,45,0,0,136,19,0,0,48,9,0,0,56,45,0,0,178,14,0,0,126,40,0,0,70,40,0,0,242,24,0,0,30,3,0,0,66,33,0,0,34,9,0,0,102,50,0,0,240,44,0,0,84,11,0,0,12,26,0,0,156,31,0,0,44,25,0,0,48,11,0,0,18,45,0,0,104,8,0,0,88,46,0,0,226,11,0,0,158,15,0,0,124,30,0,0,84,22,0,0,190,8,0,0,114,28,0,0,44,36,0,0,146,16,0,0,76,17,0,0,182,47,0,0,132,6,0,0,244,32,0,0,16,46,0,0,24,40,0,0,102,27,0,0,96,13,0,0,18,11,0,0,216,2,0,0,32,43,0,0,126,3,0,0,164,42,0,0,74,7,0,0,44,30,0,0,84,50,0,0,216,44,0,0,172,11,0,0,154,46,0,0,130,4,0,0,120,47,0,0,172,33,0,0,86,4,0,0,120,35,0,0,152,39,0,0,117,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,228,153,152,224,1,0,16,1,117,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,203,154,229,96,1,0,16,1,117,50,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,107,224,251,22,2,0,64,0,117,53,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,152,23,116,151,3,0,32,0,117,53,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,27,69,17,20,3,0,32,0,117,52,50,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,50,81,68,66,4,0,32,0,117,52,50,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,47,14,31,222,4,0,32,0,116,112,48,50,49,45,48,49,97,46,117,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,200,19,27,193,0,0,16,1,116,112,48,50,49,45,48,50,97,46,117,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,103,103,66,141,0,0,16,1,116,112,48,50,49,45,48,51,46,117,51,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,157,142,93,161,0,0,32,0,116,112,48,50,49,45,48,52,46,117,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,154,28,237,38,0,0,32,0,104,100,54,52,55,49,56,48,46,48,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,16,49,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,176,191,106,210,1,0,16,1,50,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,180,37,74,161,1,0,16,1,55,46,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,172,138,218,88,2,0,32,0,57,46,51,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,168,217,186,150,2,0,32,0,56,46,52,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,182,88,220,13,2,0,32,0,49,48,46,52,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,197,8,227,43,2,0,32,0,54,46,54,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,247,42,66,184,3,0,32,0,53,46,55,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,197,37,97,228,3,0,32,0,52,46,55,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,27,210,142,122,3,0,32,0,51,46,55,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,202,214,139,247,3,0,32,0,48,46,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,188,135,208,128,4,0,64,0,107,102,46,110,101,111,45,115,109,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,220,147,188,152,9,0,16,1,50,53,51,45,101,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,164,113,49,234,1,0,16,1,50,53,51,45,101,112,50,46,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,75,112,47,56,1,0,16,1,50,53,51,45,101,112,51,46,112,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,221,191,149,227,1,0,16,1,50,53,51,45,101,112,52,46,112,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,142,192,146,218,1,0,16,1,50,53,51,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,70,224,3,6,3,0,32,0,50,53,51,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,164,210,23,9,3,0,32,0,50,53,51,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,45,201,55,103,3,0,32,0,50,53,51,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,198,46,169,91,3,0,32,0,50,53,51,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0])
.concat([87,85,171,62,3,0,32,0,50,53,51,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,139,9,141,48,3,0,32,0,50,53,51,45,99,55,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,174,149,233,192,3,0,32,0,50,53,51,45,99,56,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,3,19,161,33,3,0,32,0,50,53,51,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,190,6,168,54,4,0,16,1,50,53,51,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,140,56,62,38,5,0,64,0,50,53,51,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,190,199,107,44,5,0,64,0,50,53,51,45,118,51,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,125,178,37,4,5,0,64,0,50,53,51,45,118,52,46,118,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,169,232,75,165,5,0,64,0,48,57,56,45,112,49,99,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,65,85,103,9,1,0,16,1,48,57,56,45,115,49,99,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,115,124,106,14,2,0,32,0,48,57,56,45,99,49,99,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,247,139,20,41,3,0,32,0,48,57,56,45,99,50,99,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,99,18,107,34,3,0,32,0,48,57,56,45,109,49,99,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,207,120,72,218,4,0,16,1,48,57,56,45,118,49,99,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,220,205,140,111,5,0,64,0,2,0,1,1,2,1,3,3,1,1,1,2,0,1,0,2,0,1,2,0,2,3,0,2,3,3,2,2,3,2,0,1,3,0,2,0,2,3,1,3,2,0,0,1,1,2,3,1,1,1,0,1,2,0,3,3,1,1,1,3,3,1,1,0,0,0,0,0,1,0,0,0,3,0,0,0,6,0,0,0,7,0,0,0,255,255,255,255,0,0,0,0,3,0,0,0,1,2,2,1,0,3,3,1,0,2,2,2,1,0,1,0,1,1,0,1,0,2,1,0,2,1,0,2,3,2,3,3,2,2,1,2,2,3,1,3,3,3,0,1,0,1,3,0,0,0,1,2,0,3,3,2,3,2,1,3,2,1,0,2,0,0,0,0,1,0,0,0,2,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,4,0,0,0,7,0,0,0,2,3,2,1,3,2,3,0,0,2,1,1,0,0,3,2,3,1,0,1,2,2,2,1,3,2,2,1,0,2,1,2,0,3,1,0,0,3,1,1,3,3,2,0,1,0,1,3,0,0,1,2,1,2,3,2,1,0,0,3,2,1,1,3,0,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,7,0,0,0,1,0,0,0,2,0,0,0,2,0,0,3,2,2,2,1,3,3,1,1,2,0,0,3,1,0,3,2,1,0,2,0,3,2,2,3,2,0,3,0,1,3,0,2,2,1,3,3,0,1,0,3,1,1,3,2,0,3,0,2,3,2,1,3,2,3,0,0,1,3,2,1,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,5,0,0,0,6,0,0,0,2,1,2,1,2,3,1,3,2,2,1,3,3,0,0,1,0,2,0,3,3,1,0,0,1,1,0,2,3,2,1,2,1,1,2,1,1,3,2,2,0,2,2,3,3,3,2,0,0,0,0,0,3,3,3,0,1,2,1,0,2,3,3,1,2,0,0,0,3,0,0,0,4,0,0,0,6,0,0,0,255,255,255,255,255,255,255,255,3,0,0,0,5,0,0,0,3,2,3,3,1,0,3,0,2,0,1,1,1,0,3,0,3,1,3,1,0,1,2,3,2,2,3,2,0,1,1,2,3,0,0,2,1,0,0,2,2,0,1,0,0,2,0,0,1,3,1,3,2,0,3,3,1,0,2,2,2,3,0,0,0,0,0,0,1,0,0,0,3,0,0,0,5,0,0,0,7,0,0,0,255,255,255,255,0,0,0,0,2,0,0,0,2,2,1,0,2,3,3,0,0,0,1,3,1,2,3,2,2,3,1,3,0,3,0,3,3,2,2,1,0,0,0,2,1,2,2,2,0,0,1,2,0,1,3,0,2,3,2,1,3,2,2,2,3,1,3,0,2,0,2,1,0,3,3,1,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,5,0,0,0,7,0,0,0,1,0,0,0,6,0,0,0,1,2,3,2,0,2,1,3,3,1,0,1,1,2,2,0,0,1,1,1,2,1,1,2,0,1,3,3,1,1,1,2,3,3,1,0,2,1,1,1,2,1,0,0,2,2,3,2,3,2,2,0,2,2,3,3,0,2,3,0,2,2,1,1,0,0,0,0,2,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,4,0,0,0,7,0,0,0,3,1,3,0,3,0,3,1,3,0,0,1,1,3,0,3,1,1,0,1,2,3,2,3,3,1,2,2,2,0,2,3,2,2,2,1,1,3,3,0,3,1,2,1,1,1,0,2,0,3,3,0,0,2,0,0,1,1,2,1,2,1,1,0,0,0,0,0,2,0,0,0,4,0,0,0,6,0,0,0,255,255,255,255,255,255,255,255,4,0,0,0,6,0,0,0,0,3,0,3,3,2,1,2,3,1,1,1,2,0,2,3,0,3,1,2,2,1,3,3,3,2,1,2,2,0,1,0,2,3,0,1,2,0,1,1,2,0,2,1,2,0,2,3,3,1,0,2,3,3,0,3,1,1,3,0,0,1,2,0,1,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,0,0,0,0,3,0,0,0,0,0,2,1,3,2,1,0,1,2,2,2,1,1,0,3,1,2,2,3,2,1,1,0,3,0,0,1,1,2,3,1,3,3,2,2,1,0,1,1,1,2,0,1,2,3,0,3,3,0,3,2,2,0,2,2,1,2,3,2,1,0,2,1,0,0,0,0,1,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,7,0,0,0,1,0,0,0,7,0,0,0,0,2,1,2,0,2,2,0,1,3,2,0,3,2,3,0,3,3,2,3,1,2,3,1,2,2,0,0,2,2,1,2,2,3,3,3,1,1,0,0,0,3,2,0,3,2,3,1,1,1,1,0,1,0,1,3,0,0,1,2,2,3,2,0,1,0,0,0,2,0,0,0,3,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,2,0,0,0,5,0,0,0,2,0,2,0,3,0,0,3,1,1,0,1,3,2,0,1,2,0,1,2,0,2,0,2,2,2,3,0,2,1,3,0,0,1,0,1,2,2,3,3,0,3,0,2,3,0,1,2,1,1,0,2,0,3,1,1,2,2,1,3,1,1,3,1,0,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,7,0,0,0,255,255,255,255,6,0,0,0,7,0,0,0,1,1,0,3,0,2,0,1,3,0,2,0,1,1,0,0,1,3,2,2,0,2,2,2,2,0,1,3,3,3,1,1,1,3,1,3,2,2,2,2,2,2,0,1,0,1,1,2,3,1,1,2,0,3,3,3,2,2,3,1,1,1,3,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,6,0,0,0,255,255,255,255,3,0,0,0,5,0,0,0,1,0,2,2,3,3,3,3,1,2,2,1,0,1,2,1,1,2,3,1,2,0,0,1,2,3,1,2,0,0,0,2,2,0,1,1,0,0,2,0,0,0,2,3,2,3,0,1,3,0,0,0,2,3,2,0,1,3,2,1,3,1,1,3,1,0,0,0,2,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,1,0,0,0,4,0,0,0,1,3,3,0,3,2,3,1,3,2,1,1,3,3,2,1,2,3,0,3,1,0,0,2,3,0,0,0,3,3,0,1,2,3,0,0,0,1,2,1,3,0,0,1,0,2,2,2,3,3,1,2,1,3,0,0,0,3,0,1,3,2,2,0,0,0,0,0,2,0,0,0,3,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,0,0,0,0,2,0,0,0,1,1,1,1,1,0,1,3,3,2,3,0,1,2,0,2,3,3,0,1,2,1,2,3,0,3,2,3,2,0,1,2,0,1,0,3,2,1,3,2,3,1,2,3,2,0,1,2,2,0,0,0,2,1,3,0,3,1,3,0,1,3,3,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,7,0,0,0,0,0,0,0,4,0,0,0,3,0,0,0,0,1,0,2,3,3,1,3,0,3,1,2,2,2,3,1,0,0,2,0,1,0,2,2,3,3,0,0,1,1,3,0,2,3,0,3,0,3,0,2,0,2,0,1,0,3,0,1,3,1,1,0,0,1,3,3,2,2,1,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,5,0,0,0,6,0,0,0,1,0,0,0,3,0,0,0,0,1,1,2,0,1,3,1,2,0,3,2,0,0,3,0,3,0,1,2,2,3,3,2,3,2,0,1,0,0,1,0,3,0,2,3,0,2,2,2,1,1,0,2,2,0,0,1,2,1,1,1,2,3,0,3,1,2,3,3,1,1,3,0,0,0,0,0,2,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,2,0,0,0,6,0,0,0,0,1,2,2,0,1,0,3,2,2,1,1,3,2,0,2,0,1,3,3,0,2,2,3,3,2,0,0,2,1,3,3,1,1,1,3,1,2,1,1,0,3,3,2,3,2,3,0,3,1,0,0,3,0,0,0,2,2,2,1,2,3,0,0,0,0,0,0,1,0,0,0,3,0,0,0,4,0,0,0,6,0,0,0,7,0,0,0,5,0,0,0,7,0,0,0,0,0,0,3,3,1,1,0,2,0,2,0,0,0,3,2,0,1,2,3,2,2,1,0,3,0,0,0,0,0,2,3,3,0,0,1,1,2,3,3,0,1,3,2,0,1,3,3,2,0,0,1,0,2,0,0,0,3,1,3,3,3,3,3,0,0,0,0,1,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,255,255,255,255,0,0,0,0,5,0,0,0,2,3,2,3,0,2,3,0,2,2,3,0,3,2,0,2,1,0,2,3,1,1,1,0,0,1,0,2,1,2,2,1,3,0,2,1,2,3,3,0,3,2,3,1,0,2,1,0,1,2,2,3,0,2,1,3,1,3,0,2,1,1,1,3,2,0,0,0,3,0,0,0,4,0,0,0,6,0,0,0,7,0,0,0,255,255,255,255,6,0,0,0,7,0,0,0,3,0,2,1,1,3,1,2,2,1,2,2,2,0,0,1,2,3,1,0,2,0,0,2,3,1,2,0,0,0,3,0,2,1,1,2,0,0,1,2,3,1,1,2,0,1,3,0,3,1,1,0,0,2,3,0,0,0,0,3,2,0,0,0,0,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,1,0,0,0,4,0,0,0,0,1,0,0,2,1,3,2,3,3,2,1,0,1,1,1,1,1,0,3,3,1,1,0,0,2,2,1,0,3,3,2,1,3,3,0,3,0,2,1,1,2,3,2,2,2,1,0,0,3,3,3,2,2,3,1,0,2,3,0,3,1,1,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,5,0,0,0,7,0,0,0,2,0,0,0,3,0,0,0,3,3,2,0,3,0,3,1,0,3,0,1,0,2,1,3,1,3,0,3,3,1,3,3,3,2,3,2,2,3,1,2,0,2,2,1,0,1,2,0,3,3,0,1,3,2,1,2,3,0,1,3,0,1,2,2,1,2,1,2,0,1,3,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,6,0,0,0,255,255,255,255,1,0,0,0,6,0,0,0,1,2,3,2,1,3,0,1,1,0,2,0,0,2,3,2,3,3,0,1,2,2,1,0,1,0,1,2,3,2,1,3,2,2,2,0,1,0,2,3,2,1,2,1,2,1,0,3,0,1,2,3,1,2,1,3,2,0,3,2,3,0,2,0,2,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,255,255,255,255,5,0,0,0,7,0,0,0,0,1,0,2,1,1,0,1,0,2,2,2,1,3,0,0,1,1,3,1,2,2,2,3,1,0,3,3,3,2,2,2,1,1,3,0,3,1,3,0,1,3,3,2,1,1,0,0,1,2,2,2,1,1,1,2,2,0,0,3,2,3,1,3,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,7,0,0,0,0,0,0,0,3,0,0,0,2,1,0,3,3,3,2,0,1,2,1,1,1,0,3,1,1,3,3,0,1,2,1,0,0,0,3,0,3,0,3,0,1,3,3,3,0,3,2,0,2,1,2,2,2,1,1,3,0,1,0,1,0,1,1,1,1,3,1,0,1,2,3,3,0,0,0,0,1,0,0,0,3,0,0,0,4,0,0,0,6,0,0,0,7,0,0,0,2,0,0,0,4,0,0,0,0,2,2,0,1,0,1,1,3,2,0,3,0,3,1,2,1,1,1,2,1,3,2,2,2,3,3,2,1,1,1,2,2,2,0,0,3,1,3,1,1,1,3,0,0,1,0,0,1,2,2,1,2,3,2,2,2,3,1,3,2,0,1,3,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,255,255,255,255,255,255,255,255,3,0,0,0,6,0,0,0,3,0,2,2,2,1,1,1,1,2,1,0,0,0,2,3,2,3,1,3,0,0,0,2,1,2,2,3,0,3,3,3,0,1,3,2,3,3,3,1,1,1,1,2,0,1,2,1,3,2,3,1,1,3,2,2,2,3,1,3,2,3,0,0,0,0,0,0,1,0,0,0,2,0,0,0,4,0,0,0,7,0,0,0,255,255,255,255,2,0,0,0,7,0,0,0,3,0,3,1,1,0,2,2,3,1,2,0,3,3,2,3,0,1,0,1,2,3,0,2,0,2,0,1,0,0,1,0,2,3,1,2,1,0,2,0,2,1,0,1,0,2,1,0,3,1,2,3,1,3,1,1,1,2,0,2,2,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,6,0,0,0,7,0,0,0,0,0,0,0,1,0,0,0,3,2,0,3,0,2,2,1,1,2,3,2,1,3,2,1,2,2,1,3,3,2,1,0,1,0,1,3,0,0,0,2,2,1,0,1,0,1,0,1,3,1,1,2,2,3,2,0,3,3,2,0,2,1,3,3,0,0,3,0,1,1,3,3,0,0,0,0,1,0,0,0,3,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,4,0,0,0,5,0,0,0,114,111,109,49,50,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,153,241,197,197,1,0,16,1,114,111,109,49,52,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,226,136,83,221,1,0,16,1,114,111,109,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,130,250,12,59,1,0,16,1,114,111,109,49,51,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,3,163,122,195,2,0,16,1,114,111,109,53,46,118,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,161,152,147,106,3,0,16,1,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,215,90,213,242,4,0,32,0,114,111,109,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,46,62,192,26,5,0,32,0,114,111,109,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,31,44,42,178,6,0,32,0,114,111,109,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,35,190,252,67,6,0,32,0,114,111,109,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,161,232,237,27,6,0,32,0,114,111,109,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,161,242,186,152,6,0,32,0,114,111,109,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,173,215,211,194,7,0,64,0,114,111,109,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,111,6,143,127,7,0,64,0,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,154,39,157,51,1,0,16,1,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,29,166,104,27,1,0,16,1,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,248,170,249,212,1,0,16,1,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,128,187,65,107,1,0,16,1,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,72,14,142,116,1,0,16,1,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,116,74,127,123,1,0,16,1,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,132,56,122,54,1,0,16,1,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,174,173,170,43,1,0,16,1,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,83,6,44,52,2,0,32,0,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,55,165,167,170,2,0,32,0,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,44,184,71,178,2,0,32,0,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,48,75,175,153,2,0,32,0,55,48,53,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,203,44,173,13,3,0,32,0,55,48,53,49,45,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,41,136,215,216,3,0,32,0,56,50,115,49,50,54,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,134,204,169,4,0,64,0,55,48,53,49,45,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,4,0,0,8,103,51,56,50,48,49,46,55,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,133,113,218,44,1,0,16,1,103,51,56,50,48,50,46,55,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,89,79,254,185,1,0,16,1,103,51,56,50,48,51,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,102,186,24,214,1,0,16,1,103,51,56,50,48,52,46,55,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,118,130,3,207,1,0,16,1,103,51,56,50,48,53,46,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,199,180,177,3,2,0,32,0,103,51,56,50,48,54,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,1,82,43,164,2,0,32,0,56,50,115,49,50,51,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,189,80,198,47,3,0,32,0,56,50,115,49,50,57,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,41,136,215,216,3,0,32,0,56,50,115,49,50,54,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,134,204,169,4,0,64,0,56,50,115,49,50,54,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,84,209,142,129,1,0,16,1,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,147,29,178,164,1,0,16,1,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,237,35,122,93,1,0,16,1,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,141,202,219,233,1,0,16,1,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,133,171,24,67,1,0,16,1,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,127,77,33,3,1,0,16,1,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,228,91,128,220,1,0,16,1,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,75,32,174,249,1,0,16,1,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,38,134,173,150,2,0,32,0,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,23,64,50,204,2,0,32,0,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0])
.concat([19,245,151,124,2,0,32,0,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,2,6,147,46,2,0,32,0,56,50,115,49,50,51,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,189,80,198,47,3,0,32,0,56,50,115,49,50,54,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,228,168,179,62,3,0,32,0,56,50,115,49,50,54,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,134,204,169,4,0,64,0,56,50,115,49,50,54,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,100,117,99,107,45,112,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,28,113,117,249,1,0,16,1,100,117,99,107,45,115,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,94,178,184,99,2,0,32,0,100,117,99,107,45,99,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,186,171,173,2,3,0,32,0,100,117,99,107,45,99,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,172,135,189,0,3,0,32,0,100,117,99,107,45,99,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,200,7,51,38,3,0,32,0,100,117,99,107,45,99,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,30,12,51,184,3,0,32,0,100,117,99,107,45,99,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,184,252,153,206,3,0,32,0,100,117,99,107,45,99,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,129,7,211,166,3,0,32,0,100,117,99,107,45,99,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,35,83,161,237,3,0,32,0,100,117,99,107,45,99,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,205,212,15,64,3,0,32,0,100,117,99,107,45,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,147,217,97,119,4,0,16,1,100,117,99,107,45,118,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,9,0,238,22,183,36,5,0,64,0,118,45,49,49,48,120,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,107,16,120,25,1,0,16,1,112,103,109,116,48,50,48,48,46,117,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,77,83,246,176,2,0,32,0,112,103,109,97,48,50,48,48,46,117,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,105,80,185,19,3,0,32,0,112,103,109,98,48,50,48,48,46,117,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,19,15,45,147,4,0,32,0,100,111,109,109,121,46,101,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,237,100,224,154,1,0,16,1,100,111,109,109,121,46,101,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,92,173,79,124,1,0,16,1,100,111,109,109,121,46,101,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,85,77,26,205,1,0,16,1,100,111,109,109,121,46,101,53,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,164,176,157,94,2,0,32,0,100,111,109,109,121,46,101,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,251,54,28,77,2,0,32,0,100,111,109,109,121,46,101,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,18,187,104,78,2,0,32,0,100,111,109,109,121,46,101,55,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,110,216,193,80,3,0,32,0,100,111,109,109,121,46,101,54,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,99,43,218,36,4,0,0,8,99,95,53,101,116,95,103,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,139,184,112,186,1,0,0,0,99,95,53,99,116,95,103,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,236,97,196,94,1,0,0,0,99,95,53,98,116,95,103,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,36,211,151,28,1,0,0,0,99,95,53,97,116,95,103,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,192,90,0,185,1,0,0,0,115,95,51,105,95,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,6,237,164,69,2,0,0,0,115,95,51,106,95,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,146,254,67,71,2,0,0,0,118,95,53,104,95,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,93,201,200,18,3,0,0,0,118,95,51,112,116,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,233,197,233,21,3,0,0,0,108,95,52,109,95,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,77,5,248,89,4,0,0,0,108,95,52,110,95,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,20,71,46,103,4,0,0,0,108,95,52,114,95,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,238,89,170,254,4,0,0,0,108,95,52,115,95,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,126,239,242,32,4,0,0,0,99,45,50,107,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,229,237,115,226,5,0,0,0,99,45,50,106,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,88,35,65,214,5,0,0,0,118,45,53,101,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,245,184,105,184,5,0,0,0,200,180,220,248,211,186,72,237,121,8,28,179,0,0,0,0,0,0,0,0,0,0,0,0,238,23,0,0,190,26,0,0,242,44,0,0,22,18,0,0,100,100,32,118,49,48,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,228,193,160,125,1,0,16,1,116,48,52,52,48,49,119,48,54,52,46,117,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,156,241,149,58,2,0,32,0,97,48,52,52,48,49,119,48,54,52,46,117,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,148,151,34,237,3,0,32,0,97,48,52,52,48,50,119,48,54,52,46,117,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,176,103,33,117,3,0,32,0,98,48,52,52,48,49,119,48,54,52,46,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,102,240,191,140,4,0,32,0,109,48,52,52,48,49,98,48,51,50,46,117,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,118,189,13,90,5,0,64,0,100,100,112,51,95,105,103,115,48,50,55,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,7,0,16,17,100,100,112,51,95,100,101,102,97,117,108,116,115,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,192,150,30,87,0,0,0,8,100,100,112,51,95,100,95,100,95,49,95,48,46,117,51,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,186,133,63,93,1,0,16,1,116,48,52,52,48,49,119,48,54,52,46,117,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,156,241,149,58,2,0,32,0,97,48,52,52,48,49,119,48,54,52,46,117,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,148,151,34,237,3,0,32,0,97,48,52,52,48,50,119,48,54,52,46,117,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,176,103,33,117,3,0,32,0,98,48,52,52,48,49,119,48,54,52,46,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,102,240,191,140,4,0,32,0,109,48,52,52,48,49,98,48,51,50,46,117,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,118,189,13,90,5,0,64,0,100,100,112,51,95,105,103,115,48,50,55,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,7,0,16,17,100,100,112,51,95,100,101,102,97,117,108,116,115,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,192,150,30,87,0,0,0,8,118,49,48,50,46,117,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,64,160,158,90,1,0,16,1,100,100,112,50,95,105,103,115,48,50,55,97,95,116,97,105,119,97,110,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,220,75,211,29,7,0,16,1,116,49,51,48,48,46,117,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,203,240,72,231,2,0,32,0,97,49,51,48,48,46,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,5,164,135,252,3,0,32,0,97,49,51,48,49,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,218,32,133,12,3,0,32,0,98,49,51,48,48,46,117,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,4,102,100,239,4,0,32,0,109,49,51,48,48,46,117,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,93,1,212,130,5,0,64,0,118,49,48,48,46,117,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,41,221,195,6,8,0,16,1,46,0,0,0,255,255,1,0,0,0,0,0,0,0,0,0,118,49,48,50,46,117,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,64,160,158,90,1,0,16,1,100,100,112,50,95,105,103,115,48,50,55,97,95,107,111,114,101,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,23,28,168,229,7,0,16,1,116,49,51,48,48,46,117,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,203,240,72,231,2,0,32,0,97,49,51,48,48,46,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,5,164,135,252,3,0,32,0,97,49,51,48,49,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,218,32,133,12,3,0,32,0,98,49,51,48,48,46,117,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,4,102,100,239,4,0,32,0,109,49,51,48,48,46,117,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,93,1,212,130,5,0,64,0,118,49,48,48,46,117,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,41,221,195,6,8,0,16,1,46,0,0,0,255,255,3,0,0,0,0,0,0,0,0,0,118,49,48,50,46,117,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,64,160,158,90,1,0,16,1,100,100,112,50,95,105,103,115,48,50,55,97,95,106,97,112,97,110,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,210,52,45,116,7,0,16,1,116,49,51,48,48,46,117,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,203,240,72,231,2,0,32,0,97,49,51,48,48,46,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,5,164,135,252,3,0,32,0,97,49,51,48,49,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,218,32,133,12,3,0,32,0,98,49,51,48,48,46,117,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,4,102,100,239,4,0,32,0,109,49,51,48,48,46,117,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,93,1,212,130,5,0,64,0,118,49,48,48,46,117,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,41,221,195,6,8,0,16,1,118,49,48,50,46,117,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,64,160,158,90,1,0,16,1,100,100,112,50,95,105,103,115,48,50,55,97,95,99,104,105,110,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,25,99,86,140,7,0,16,1,116,49,51,48,48,46,117,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,203,240,72,231,2,0,32,0,97,49,51,48,48,46,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,5,164,135,252,3,0,32,0,97,49,51,48,49,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,218,32,133,12,3,0,32,0,98,49,51,48,48,46,117,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,4,102,100,239,4,0,32,0,109,49,51,48,48,46,117,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,93,1,212,130,5,0,64,0,118,49,48,48,46,117,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,41,221,195,6,8,0,16,1,46,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,102,103,48,48,49,48,48,49,46,117,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,7,48,239,225,1,0,16,1,102,103,48,48,49,48,48,50,46,117,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,249,129,52,94,1,0,16,1,102,103,49,45,48,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,62,83,176,154,3,0,32,0,102,103,49,45,48,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,226,81,157,28,3,0,32,0,102,103,49,45,48,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,185,89,81,194,4,0,32,0,102,103,49,45,48,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,154,195,82,32,5,0,32,0,102,103,49,45,48,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,224,233,47,74,6,0,64,0,99,1,99,99,1,1,1,1,1,1,1,1,1,1,1,1,1,1,99,99,99,99,1,1,2,2,4,1,99,99,99,99,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,1,1,3,3,1,1,4,4,4,5,1,10,5,7,9,12,1,99,99,1,1,99,1,1,1,1,1,99,1,1,99,1,1,99,99,1,1,99,1,1,1,1,1,99,1,1,99,1,6,7,7,6,6,7,6,6,6,6,6,5,6,4,3,5,6,6,6,6,6,6,6,6,6,6,6,4,6,4,3,5,2,2,2,3,2,2,2,99,2,2,2,2,3,5,3,99,3,3,3,4,3,3,3,3,3,3,3,3,4,5,4,4,4,4,4,5,4,4,4,4,4,4,4,4,5,5,5,5,4,4,4,5,4,4,4,4,4,4,4,4,5,6,5,5,2,2,2,3,2,2,2,99,2,2,2,2,3,99,3,99,3,3,3,4,3,3,3,3,3,3,3,3,4,4,4,4,4,4,4,5,4,4,4,4,4,4,4,4,5,5,5,5,4,4,4,5,4,4,4,4,4,4,4,4,5,5,5,5,99,114,117,115,104,107,114,108,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,84,143,221,168,1,0,16,1,99,114,117,115,104,107,114,108,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,153,114,56,145,1,0,16,1,99,114,117,115,104,107,114,108,46,54,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,39,95,69,212,1,0,16,1,99,114,117,115,104,107,114,108,46,54,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,81,194,159,213,1,0,16,1,109,97,107,101,116,114,97,120,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,218,210,186,145,2,0,32,0,109,97,107,101,116,114,97,120,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,85,159,167,174,2,0,32,0,56,50,115,49,50,51,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,189,80,198,47,3,0,32,0,50,115,49,52,48,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,39,185,239,99,3,0,32,0,56,50,115,49,50,54,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,134,204,169,4,0,64,0,56,50,115,49,50,54,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,101,112,114,45,49,48,57,48,52,46,55,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,53,99,16,75,1,0,16,1,101,112,114,45,49,48,57,48,53,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,144,195,111,167,1,0,16,1,101,112,114,45,49,48,57,48,54,46,55,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,133,72,213,22,1,0,16,1,101,112,114,45,49,48,57,48,51,46,55,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,171,156,165,183,1,0,16,1,101,112,114,45,49,48,57,49,52,46,53,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,64,35,122,125,2,0,32,0,101,112,114,45,49,48,57,49,51,46,53,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,174,168,193,213,2,0,32,0,101,112,114,45,49,48,57,48,55,46,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,163,238,229,8,3,0,32,0,101,112,114,45,49,48,57,48,56,46,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,245,19,228,217,3,0,32,0,101,112,114,45,49,48,57,48,57,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,44,150,199,254,3,0,32,0,101,112,114,45,49,48,57,49,48,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,167,15,219,51,3,0,32,0,101,112,114,45,49,48,57,49,49,46,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,109,158,93,86,3,0,32,0,101,112,114,45,49,48,57,49,50,46,53,105,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,56,39,226,203,3,0,32,0,112,114,45,49,48,57,48,48,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,102,205,95,249,4,0,32,0,112,114,45,49,48,57,48,49,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,200,129,217,111,4,0,32,0,112,114,45,49,48,57,48,50,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,237,189,214,132,4,0,32,0,51,49,53,45,53,48,55,52,46,50,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,91,2,0,0,186,187,87,46,0,0,0,8,51,49,53,45,53,48,55,51,46,112,97,108,49,54,108,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,24,16,0,0,0,255,255,16,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,16,0,0,0,1,1,0,0,96,135,7,0,16,0,0,0,1,1,1,0,152,182,7,0,0,0,0,0,254,0,4,0,32,4,2,0,16,0,0,0,1,6,6,0,160,36,8,0,16,0,0,0,1,6,0,0,208,239,7,0,16,0,0,0,1,6,2,0,120,187,7,0,16,0,0,0,1,6,4,0,136,23,1,0,0,0,0,0,254,0,2,0,128,129,4,0,16,0,0,0,1,8,0,0,8,49,4,0,16,0,0,0,1,8,8,0,152,21,4,0,0,0,0,0,254,0,2,0,200,30,2,0,16,0,0,0,1,16,16,0,120,97,1,0,16,0,0,0,1,16,0,0,96,19,1,0,0,0,0,0,254,0,2,0,72,202,5,0,16,0,0,0,1,64,0,0,80,246,3,0,16,0,0,0,1,64,64,0,112,212,3,0,0,0,0,0,254,0,2,0,152,205,5,0,16,0,0,0,1,128,0,0,56,165,5,0,16,0,0,0,1,128,128,0,0,131,5,0,0,0,0,0,0,0,40,40,80,80,0,0,0,0,80,80,0,16,32,48,0,16,0,16,32,48,64,80,0,24,48,0,24,48,0,24,48,48,24,0,0,40,80,0,40,80,0,48,32,80,16,32,0,80,0,80,0,80,48,24,0,48,24,0,48,24,0,0,24,48,48,0,16,64,80,32,48,32,16,0,16,0,80,64,48,32,16,0,80,80,80,80,0,0,0,0,0,0,0,0,50,48,48,50,45,112,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,164,98,158,31,1,0,16,1,50,48,48,50,45,115,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,245,23,164,5,2,0,32,0,50,48,48,50,45,99,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,65,71,151,225,3,0,32,0,50,48,48,50,45,99,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,156,91,159,3,0,32,0,110,110,112,45,109,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,100,222,105,118,4,0,16,1,110,110,112,45,118,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,73,248,75,80,5,0,64,0,26,18,92,8,132,182,115,209,84,145,148,235,0,0,0,0,0,0,0,0,0,0,0,0,101,112,114,45,54,49,55,53,46,55,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,184,82,69,4,1,0,16,1,101,112,114,45,54,49,55,52,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,152,21,155,210,1,0,16,1,101,112,114,45,54,49,55,51,46,55,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,56,93,64,184,1,0,16,1,101,112,114,45,54,49,55,54,46,55,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,194,138,201,1,0,16,1,101,112,114,45,54,49,54,53,46,53,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,147,74,243,174,2,0,32,0,101,112,114,45,54,49,54,54,46,53,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,17,203,19,202,2,0,32,0,101,112,114,45,54,49,55,50,46,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,139,135,196,196,3,0,32,0,101,112,114,45,54,49,55,49,46,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,161,101,129,161,3,0,32,0,101,112,114,45,54,49,55,48,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,250,168,138,181,3,0,32,0,101,112,114,45,54,49,54,57,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,206,127,163,26,3,0,32,0,101,112,114,45,54,49,54,56,46,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,103,168,243,5,3,0,32,0,101,112,114,45,54,49,54,55,46,53,105,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,225,55,163,63,3,0,32,0,112,114,45,54,49,55,55,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,174,197,112,235,4,0,32,0,112,114,45,54,49,55,56,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,1,160,204,10,4,0,32,0,112,114,45,54,49,55,57,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,219,175,59,229,4,0,32,0,51,49,53,45,53,48,55,52,46,50,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,91,2,0,0,186,187,87,46,0,0,0,8,51,49,53,45,53,48,55,51,46,112,97,108,49,54,108,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,24,16,0,0,0,255,255,192,0,0,0,0,0,0,0,0,0,254,0,4,0,72,21,2,0,16,0,0,0,1,3,3,0,240,12,2,0,16,0,0,0,1,3,2,0,160,36,8,0,16,0,0,0,1,3,0,0,208,239,7,0,16,0,0,0,1,3,1,0,120,187,7,0,0,0,0,0,254,0,2,0,16,5,2,0,16,0,0,0,1,4,4,0,160,36,8,0,16,0,0,0,1,4,0,0,208,239,7,0,0,0,0,0,254,0,2,0,128,129,4,0,16,0,0,0,1,8,0,0,8,49,4,0,16,0,0,0,1,8,8,0,152,21,4,0,0,0,0,0,254,0,2,0,64,37,5,0,16,0,0,0,1,16,0,0,128,238,1,0,16,0,0,0,1,16,16,0,200,226,1,0,0,0,0,0,254,0,2,0,72,202,5,0,16,0,0,0,1,32,0,0,80,246,3,0,16,0,0,0,1,32,32,0,112,212,3,0,0,0,0,0,254,0,2,0,168,234,7,0,16,0,0,0,1,64,0,0,96,135,7,0,16,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,200,30,2,0,16,0,0,0,1,128,128,0,120,97,1,0,16,0,0,0,1,128,0,0,96,19,1,0,98,54,56,45,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,62,251,94,133,2,0,16,1,98,54,56,45,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,233,238,30,39,2,0,16,1,98,54,56,45,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,16,155,165,211,1,0,16,1,98,54,56,45,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,8,181,120,195,9,0,16,1,98,54,56,45,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,148,44,243,137,11,0,32,0,98,54,56,45,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,211,140,1,245,15,0,32,0,98,54,56,45,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,200,172,19,193,16,0,32,0,98,54,56,45,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,77,230,23,245,16,0,32,0,98,54,56,45,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,64,175,122,56,26,0,64,0,49,57,54,45,112,49,107,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,137,7,120,160,1,0,16,1,48,57,54,45,112,50,46,115,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,2,38,90,77,1,0,16,1,48,57,54,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,68,211,127,204,2,0,32,0,48,57,54,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,137,141,123,241,3,0,32,0,48,57,54,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,8,197,64,56,3,0,32,0,48,57,54,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,30,238,249,85,3,0,32,0,48,57,54,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,71,126,91,88,3,0,32,0,48,57,54,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,60,117,90,199,3,0,32,0,48,57,54,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,122,47,157,154,3,0,32,0,48,57,54,45,99,55,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,178,138,189,81,3,0,32,0,48,57,54,45,99,56,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,156,249,52,154,3,0,32,0,48,57,54,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,89,182,7,203,4,0,16,1,48,57,54,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,116,32,195,226,5,0,64,0,48,57,54,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,231,238,144,162,5,0,64,0,48,57,54,45,118,51,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,234,18,157,25,5,0,64,0,48,53,54,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,33,208,177,163,1,0,16,1,48,53,54,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,142,99,2,139,2,0,32,0,48,53,54,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,210,203,185,23,3,0,32,0,48,53,54,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,103,107,215,95,3,0,32,0,48,53,54,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,104,135,200,210,3,0,32,0,48,53,54,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,131,184,57,219,3,0,32,0,48,53,54,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,55,65,7,195,3,0,32,0,48,53,54,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,211,104,222,49,3,0,32,0,48,53,54,45,99,55,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,87,223,54,63,3,0,32,0,48,53,54,45,99,56,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,168,215,70,229,3,0,32,0,48,53,54,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,82,157,126,242,4,0,16,1,48,53,54,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,224,253,40,70,5,0,64,0,48,53,54,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,242,226,16,183,5,0,64,0,48,53,54,45,118,51,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,195,104,209,5,0,64,0,48,53,54,45,101,112,114,46,101,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,28,48,214,117,0,0,16,1,97,55,55,95,48,48,45,49,46,56,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,96,45,168,43,0,0,16,1,97,55,55,95,48,49,45,49,46,56,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,18,47,187,24,0,0,16,1,97,55,55,95,49,50,46,56,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,151,211,69,133,0,0,32,0,97,55,55,95,49,49,46,55,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,37,185,183,177,0,0,32,0,97,55,55,95,49,48,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,107,148,45,66,0,0,32,0,97,55,55,95,48,57,46,55,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,174,19,113,88,0,0,32,0,97,55,55,95,48,52,45,49,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,131,52,0,49,0,0,32,0,97,55,55,95,48,51,45,49,46,54,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,192,82,65,64,0,0,32,0,97,55,55,95,48,56,46,54,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,5,131,53,182,0,0,32,0,97,55,55,95,48,55,46,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,96,157,45,233,0,0,32,0,97,55,55,95,48,54,46,54,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,163,238,174,95,0,0,32,0,97,55,55,95,48,53,46,54,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,169,46,78,151,0,0,32,0,50,49,95,56,50,115,49,50,57,46,49,50,113,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,153,175,239,160,0,0,32,0,50,48,95,56,50,115,49,50,57,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,229,87,109,165,0,0,32,0,49,57,95,56,50,115,49,50,57,46,49,50,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,159,191,92,0,0,32,0,97,55,55,95,48,50,46,49,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,90,112,244,135,0,0,16,1,97,55,55,95,49,51,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,217,129,12,167,0,0,16,1,55,55,48,95,108,48,49,46,110,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,116,82,234,124,1,0,16,1,55,55,48,95,108,48,50,46,110,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,43,89,125,173,1,0,16,1,55,55,48,95,108,48,53,46,105,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,178,251,100,237,2,0,16,1,55,55,48,95,102,48,52,46,103,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,156,236,228,224,2,0,16,1,55,55,48,95,102,48,51,46,102,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,253,20,233,63,3,0,16,1,55,55,48,99,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,78,202,89,184,4,0,32,0,55,55,48,99,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,114,75,209,80,4,0,32,0,55,55,48,99,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,255,167,180,26,5,0,32,0,55,55,48,99,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,134,5,232,168,5,0,32,0,55,55,48,99,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,238,146,197,208,6,0,32,0,55,55,48,99,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,177,159,57,11,6,0,32,0,55,55,48,99,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,95,130,172,127,7,0,64,0,55,55,48,99,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,90,97,154,41,8,0,64,0,54,51,115,50,52,49,46,106,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,159,113,221,155,9,0,0,8,104,0,208,31,198,6,192,28,87,234,105,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,98,112,109,112,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,167,235,247,180,1,0,16,1,56,98,112,109,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,109,74,137,28,2,0,32,0,56,98,112,109,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,65,66,245,76,3,0,32,0,56,98,112,109,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,160,5,133,97,3,0,32,0,15,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,15,0,0,0,1,1,0,0,120,97,1,0,15,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,118,115,101,46,48,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,63,65,6,219,1,0,16,1,120,118,115,101,46,48,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,239,90,1,239,1,0,16,1,120,118,115,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,93,2,182,125,1,0,16,1,120,118,115,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,92,199,226,232,1,0,16,1,120,118,115,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,237,171,240,8,1,0,16,1,120,118,115,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,117,150,146,129,1,0,16,1,120,118,115,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,107,243,65,150,1,0,16,1,120,118,115,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,253,78,104,246,5,0,32,0,120,118,115,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,33,146,16,41,5,0,32,0,120,118,115,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,116,52,219,146,5,0,32,0,120,118,115,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,60,71,51,55,5,0,32,0,120,118,115,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,65,46,172,188,5,0,32,0,120,118,115,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,114,162,4,234,5,0,32,0,120,118,115,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,106,248,222,176,5,0,32,0,120,118,115,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,159,255,64,75,5,0,32,0,120,118,115,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,58,233,153,57,10,0,16,1,120,118,115,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,233,222,27,16,10,0,16,1,120,118,115,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,188,205,173,156,12,0,64,0,120,118,115,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,96,228,17,123,12,0,64,0,99,45,99,52,55,98,46,48,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,151,128,177,1,0,16,1,97,45,50,52,48,50,46,48,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,50,66,171,79,1,0,16,1,116,107,50,95,103,102,120,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,191,185,156,13,4,0,32,0,116,107,50,95,103,102,120,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,112,34,69,4,0,32,0,116,107,50,95,103,102,120,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,96,36,202,197,4,0,32,0,116,107,50,95,103,102,120,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,28,85,73,227,4,0,32,0,116,107,50,95,103,102,120,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,11,15,31,41,4,0,32,0,116,107,50,95,103,102,120,55,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,73,185,222,62,4,0,32,0,116,107,50,95,103,102,120,54,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,214,20,189,26,4,0,32,0,116,107,50,95,103,102,120,56,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,227,72,121,178,4,0,32,0,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,151,138,254,134,3,0,16,0,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,32,231,75,192,5,0,64,0,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,193,216,184,251,5,0,64,0,116,107,50,101,95,50,51,98,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,209,46,251,17,2,0,16,1,116,107,50,101,95,50,50,98,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,36,63,155,71,2,0,16,1,116,107,50,45,49,109,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,191,185,156,13,4,0,32,0,116,107,50,45,51,109,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,112,34,69,4,0,32,0,116,107,50,45,50,109,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,96,36,202,197,4,0,32,0,116,107,50,45,52,109,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,28,85,73,227,4,0,32,0,116,107,50,45,53,109,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,11,15,31,41,4,0,32,0,116,107,50,45,55,109,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,73,185,222,62,4,0,32,0,116,107,50,45,54,109,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,214,20,189,26,4,0,32,0,116,107,50,45,56,109,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,227,72,121,178,4,0,32,0,116,107,50,95,113,97,46,53,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,13,58,24,201,3,0,16,0,116,107,50,45,113,49,46,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,207,104,18,97,6,0,64,0,116,107,50,45,113,50,46,50,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,169,92,245,32,6,0,64,0,116,107,50,45,113,51,46,51,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,111,207,191,6,0,64,0,116,107,50,45,113,52,46,52,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,136,46,100,54,6,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,154,135,134,67,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,116,107,50,54,51,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,155,52,176,196,0,0,0,8,105,111,98,49,46,49,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,98,112,114,103,49,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,167,61,121,49,0,0,0,8,105,111,99,49,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,129,32,24,13,0,0,0,8,100,55,108,49,46,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,13,65,183,39,0,0,0,8,100,56,108,49,46,56,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,218,199,159,83,0,0,0,8,100,57,107,49,46,57,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,0,0,0,0,0,0,24,100,49,48,102,49,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,148,196,25,102,0,0,0,8,116,107,50,106,50,51,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,117,133,211,132,2,0,16,1,116,107,50,106,50,50,99,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,172,9,75,183,2,0,16,1,116,107,50,95,103,102,120,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,191,185,156,13,4,0,32,0,116,107,50,95,103,102,120,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,112,34,69,4,0,32,0,116,107,50,95,103,102,120,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,96,36,202,197,4,0,32,0,116,107,50,95,103,102,120,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,28,85,73,227,4,0,32,0,116,107,50,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,83,77,164,228,4,0,32,0,116,107,50,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,107,6,88,4,0,32,0,116,107,50,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,142,86,6,215,4,0,32,0,116,107,50,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,2,154,161,212,4,0,32,0,116,107,50,95,113,97,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,13,58,24,201,3,0,16,0,116,107,50,95,113,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,207,104,18,97,6,0,64,0,116,107,50,95,113,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,169,92,245,32,6,0,64,0,116,107,50,95,113,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,111,207,191,6,0,64,0,116,107,50,95,113,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,136,46,100,54,6,0,64,0,102,103,45,99,46,48,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,134,252,70,208,1,0,16,1,102,103,45,97,46,48,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,143,238,118,241,1,0,16,1,115,103,121,120,45,49,46,49,54,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,246,233,11,166,4,0,32,0,115,103,121,120,45,50,46,49,54,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,72,208,217,106,4,0,32,0,115,103,121,120,122,95,115,110,100,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,111,55,12,33,3,0,16,0,115,103,121,120,122,95,115,110,100,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,242,192,90,193,5,0,64,0,116,107,50,40,99,104,41,95,50,51,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,238,141,11,78,2,0,16,1,116,107,50,40,99,104,41,95,50,50,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,141,122,147,208,2,0,16,1,116,107,50,45,49,109,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,191,185,156,13,4,0,32,0,116,107,50,45,51,109,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,112,34,69,4,0,32,0,116,107,50,45,50,109,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,96,36,202,197,4,0,32,0,116,107,50,45,52,109,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,28,85,73,227,4,0,32,0,116,107,50,40,99,104,41,95,48,53,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,83,77,164,228,4,0,32,0,116,107,50,40,99,104,41,95,48,54,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,107,6,88,4,0,32,0,116,107,50,40,99,104,41,95,48,55,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,201,6,144,204,4,0,32,0,116,107,50,40,99,104,41,95,48,56,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,2,154,161,212,4,0,32,0,116,107,50,95,113,97,46,53,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,13,58,24,201,3,0,16,0,116,107,50,45,113,49,46,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,207,104,18,97,6,0,64,0,116,107,50,45,113,50,46,50,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,169,92,245,32,6,0,64,0,116,107,50,45,113,51,46,51,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,111,207,191,6,0,64,0,116,107,50,45,113,52,46,52,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,136,46,100,54,6,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,154,135,134,67,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,116,107,50,54,51,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,155,52,176,196,0,0,0,8,105,111,98,49,46,49,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,98,112,114,103,49,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,167,61,121,49,0,0,0,8,105,111,99,49,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,129,32,24,13,0,0,0,8,99,54,51,50,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,112,146,189,15,0,0,0,8,100,55,108,49,46,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,13,65,183,39,0,0,0,8,100,56,108,49,46,56,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,218,199,159,83,0,0,0,8,100,57,107,49,46,57,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,0,0,0,0,0,0,24,100,49,48,102,49,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,148,196,25,102,0,0,0,8,104,116,107,50,97,95,50,51,98,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,133,252,23,27,2,0,16,1,116,107,50,97,95,50,50,98,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,205,212,10,144,2,0,16,1,116,107,50,95,103,102,120,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,191,185,156,13,4,0,32,0,116,107,50,95,103,102,120,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,112,34,69,4,0,32,0,116,107,50,95,103,102,120,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,96,36,202,197,4,0,32,0,116,107,50,95,103,102,120,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,28,85,73,227,4,0,32,0,116,107,50,95,103,102,120,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,11,15,31,41,4,0,32,0,116,107,50,95,103,102,120,55,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,73,185,222,62,4,0,32,0,116,107,50,95,103,102,120,54,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,214,20,189,26,4,0,32,0,116,107,50,95,103,102,120,56,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,227,72,121,178,4,0,32,0,116,107,50,95,113,97,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,13,58,24,201,3,0,16,0,116,107,50,95,113,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,207,104,18,97,6,0,64,0,116,107,50,95,113,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,169,92,245,32,6,0,64,0,116,107,50,95,113,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,111,207,191,6,0,64,0,116,107,50,95,113,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,136,46,100,54,6,0,64,0,119,99,57,48,97,45,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,104,26,245,182,0,0,16,1,119,99,57,48,97,45,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,152,42,15,197,0,0,16,1,105,99,54,55,95,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,175,110,220,0,0,16,1,119,99,57,48,97,45,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,66,149,122,140,0,0,16,1,105,99,53,52,95,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,179,72,195,39,0,0,16,1,105,99,56,53,95,48,55,118,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,38,148,33,197,0,0,32,0,105,99,56,54,95,48,56,118,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,255,161,161,143,0,0,32,0,105,99,57,48,95,48,57,118,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,28,132,248,153,0,0,32,0,105,99,56,55,95,49,48,118,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,61,9,50,130,0,0,32,0,105,99,57,49,95,49,49,118,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,137,55,141,24,0,0,32,0,105,99,53,48,95,49,50,118,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,34,233,31,218,0,0,32,0,105,99,53,52,95,49,51,118,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,44,60,208,154,0,0,32,0,105,99,54,48,95,49,52,118,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,27,251,157,73,0,0,32,0,105,99,54,53,95,49,53,118,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,129,92,234,216,0,0,32,0,105,99,56,50,95,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,237,146,214,47,0,0,64,0,105,99,56,55,45,49,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,113,169,36,208,0,0,16,1,105,99,57,53,95,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,156,67,125,132,0,0,16,1,105,99,54,55,95,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,175,110,220,0,0,16,1,105,99,53,54,95,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,59,43,192,26,0,0,16,1,105,99,53,52,95,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,179,72,195,39,0,0,16,1,105,99,56,53,95,48,55,118,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,38,148,33,197,0,0,32,0,105,99,56,54,95,48,56,118,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,255,161,161,143,0,0,32,0,105,99,57,48,95,48,57,118,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,28,132,248,153,0,0,32,0,105,99,56,55,95,49,48,118,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,61,9,50,130,0,0,32,0,105,99,57,49,95,49,49,118,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,137,55,141,24,0,0,32,0,105,99,53,48,95,49,50,118,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,34,233,31,218,0,0,32,0,105,99,53,52,95,49,51,118,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,44,60,208,154,0,0,32,0,105,99,54,48,95,49,52,118,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,27,251,157,73,0,0,32,0,105,99,54,53,95,49,53,118,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,129,92,234,216,0,0,32,0,105,99,56,50,95,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,237,146,214,47,0,0,64,0,119,99,57,48,45,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,26,78,128,209,0,0,16,1,105,99,57,53,95,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,156,67,125,132,0,0,16,1,105,99,54,55,95,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,175,110,220,0,0,16,1,105,99,53,54,95,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,59,43,192,26,0,0,16,1,105,99,53,52,95,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,179,72,195,39,0,0,16,1,105,99,56,53,95,48,55,118,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,38,148,33,197,0,0,32,0,105,99,56,54,95,48,56,118,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,255,161,161,143,0,0,32,0,105,99,57,48,95,48,57,118,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,28,132,248,153,0,0,32,0,105,99,56,55,95,49,48,118,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,61,9,50,130,0,0,32,0,105,99,57,49,95,49,49,118,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,137,55,141,24,0,0,32,0,105,99,53,48,95,49,50,118,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,34,233,31,218,0,0,32,0,105,99,53,52,95,49,51,118,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,44,60,208,154,0,0,32,0,105,99,54,48,95,49,52,118,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,27,251,157,73,0,0,32,0,105,99,54,53,95,49,53,118,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,129,92,234,216,0,0,32,0,105,99,56,50,95,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,237,146,214,47,0,0,64,0,105,99,49,49,54,95,56,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,240,206,216,115,0,0,16,1,105,99,49,48,57,95,57,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,40,104,84,41,0,0,16,1,105,99,48,57,54,95,57,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,42,92,20,199,0,0,16,1,101,112,114,45,55,52,57,56,46,49,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,123,30,174,120,0,0,16,1,101,112,114,45,55,52,57,55,46,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,202,9,214,8,0,0,32,0,101,112,114,45,55,52,57,54,46,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,241,253,97,111,0,0,32,0,101,112,114,45,55,52,57,53,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,45,44,13,106,0,0,32,0,101,112,114,45,55,52,57,52,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,199,129,226,168,0,0,32,0,101,112,114,45,55,52,57,51,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,244,93,48,137,0,0,32,0,101,112,114,45,55,52,57,50,46,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,177,6,248,96,0,0,32,0,105,99,49,49,55,95,56,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,232,106,233,30,0,0,32,0,105,99,48,48,52,95,56,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,187,53,151,17,0,0,32,0,105,99,49,49,48,95,56,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,196,250,208,38,0,0,32,0,105,99,48,48,53,95,56,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,25,229,2,38,0,0,32,0,112,114,45,53,51,49,55,46,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,184,80,131,100,0,0,0,8,15,0,0,0,255,255,190,0,0,0,0,0,16,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,15,0,0,0,1,1,0,0,120,97,1,0,15,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,4,0,128,129,4,0,15,0,0,0,1,6,0,0,208,75,4,0,15,0,0,0,1,6,6,0,8,49,4,0,15,0,0,0,1,6,4,0,152,21,4,0,15,0,0,0,1,6,2,0,72,246,3,0,0,0,0,0,254,0,2,0,168,234,7,0,15,0,0,0,1,64,64,0,96,135,7,0,15,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,8,0,32,4,2,0,16,0,0,0,1,7,4,0,80,252,6,0,16,0,0,0,1,7,5,0,16,242,7,0,16,0,0,0,1,7,0,0,200,116,6,0,16,0,0,0,1,7,6,0,104,236,7,0,16,0,0,0,1,7,1,0,120,113,6,0,16,0,0,0,1,7,2,0,96,39,7,0,16,0,0,0,1,7,7,0,128,230,7,0,16,0,0,0,1,7,3,0,184,164,6,0,0,0,0,0,254,0,2,0,104,159,3,0,16,0,0,0,1,16,0,0,96,135,7,0,16,0,0,0,1,16,16,0,152,182,7,0,0,0,0,0,254,0,4,0,128,156,8,0,16,0,0,0,1,192,192,0,96,212,3,0,16,0,0,0,1,192,128,0,16,227,4,0,16,0,0,0,1,192,64,0,184,89,6,0,16,0,0,0,1,192,0,0,24,82,6,0,101,112,114,45,46,49,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,52,117,210,81,0,0,16,1,101,112,114,45,46,49,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,209,28,157,226,0,0,16,1,101,112,114,45,55,52,57,49,46,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,254,14,125,31,0,0,16,1,101,112,114,45,55,52,57,56,46,49,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,123,30,174,120,0,0,16,1,101,112,114,45,55,52,57,55,46,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,202,9,214,8,0,0,32,0,101,112,114,45,55,52,57,54,46,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,241,253,97,111,0,0,32,0,101,112,114,45,55,52,57,53,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,45,44,13,106,0,0,32,0,101,112,114,45,55,52,57,52,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,199,129,226,168,0,0,32,0,101,112,114,45,55,52,57,51,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,244,93,48,137,0,0,32,0,101,112,114,45,55,52,57,50,46,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,177,6,248,96,0,0,32,0,101,112,114,45,55,52,56,53,46,49,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,34,23,137,194,0,0,32,0,101,112,114,45,55,52,56,55,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,27,66,58,45,0,0,32,0,101,112,114,45,55,52,56,54,46,49,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,80,44,98,141,0,0,32,0,101,112,114,45,55,52,56,56,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,27,47,124,0,0,0,32,0,112,114,45,53,51,49,55,46,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,184,80,131,100,0,0,0,8,119,98,49,46,105,99,49,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,124,64,103,108,0,0,16,1,119,98,95,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,36,182,129,64,0,0,16,1,119,98,95,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,54,14,138,196,0,0,16,1,101,112,114,45,55,52,57,56,46,49,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,123,30,174,120,0,0,16,1,101,112,114,45,55,52,57,55,46,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,202,9,214,8,0,0,32,0,101,112,114,45,55,52,57,54,46,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,241,253,97,111,0,0,32,0,101,112,114,45,55,52,57,53,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,45,44,13,106,0,0,32,0,101,112,114,45,55,52,57,52,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,199,129,226,168,0,0,32,0,101,112,114,45,55,52,57,51,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,244,93,48,137,0,0,32,0,101,112,114,45,55,52,57,50,46,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,177,6,248,96,0,0,32,0,101,112,114,45,55,52,56,53,46,49,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,34,23,137,194,0,0,32,0,101,112,114,45,55,52,56,55,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,27,66,58,45,0,0,32,0,101,112,114,45,55,52,56,54,46,49,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,80,44,98,141,0,0,32,0,101,112,114,45,55,52,56,56,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,27,47,124,0,0,0,32,0,112,114,45,53,51,49,55,46,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,184,80,131,100,0,0,0,8,105,99,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,6,192,178,72,0,0,16,1,105,99,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,49,174,108,70,0,0,16,1,55,53,56,51,46,49,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,60,75,51,153,0,0,16,1,101,112,114,55,54,49,48,46,105,99,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,106,210,133,22,0,0,32,0,101,112,114,55,54,48,57,46,105,99,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,83,186,236,135,0,0,32,0,101,112,114,55,54,48,56,46,105,99,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,236,179,18,232,0,0,32,0,55,53,55,56,46,56,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,127,99,241,111,0,0,32,0,55,53,55,55,46,56,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,94,112,179,88,0,0,32,0,112,114,45,53,51,49,55,46,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,184,80,131,100,0,0,0,8,119,98,95,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,73,239,111,189,0,0,16,1,119,98,95,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,36,182,129,64,0,0,16,1,119,98,95,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,54,14,138,196,0,0,16,1,101,112,114,45,55,52,57,56,46,49,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,123,30,174,120,0,0,16,1,101,112,114,45,55,52,57,55,46,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,202,9,214,8,0,0,32,0,101,112,114,45,55,52,57,54,46,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,241,253,97,111,0,0,32,0,101,112,114,45,55,52,57,53,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,45,44,13,106,0,0,32,0,101,112,114,45,55,52,57,52,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,199,129,226,168,0,0,32,0,101,112,114,45,55,52,57,51,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,244,93,48,137,0,0,32,0,101,112,114,45,55,52,57,50,46,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,177,6,248,96,0,0,32,0,101,112,114,45,55,52,56,53,46,49,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,34,23,137,194,0,0,32,0,101,112,114,45,55,52,56,55,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,27,66,58,45,0,0,32,0,101,112,114,45,55,52,56,54,46,49,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,80,44,98,141,0,0,32,0,101,112,114,45,55,52,56,56,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,27,47,124,0,0,0,32,0,112,114,45,53,51,49,55,46,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,184,80,131,100,0,0,0,8,15,0,0,0,255,255,255,0,0,0,0,0,16,0,0,0,255,255,236,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,15,0,0,0,1,15,7,0,80,252,6,0,15,0,0,0,1,15,8,0,16,242,7,0,15,0,0,0,1,15,9,0,104,236,7,0,15,0,0,0,1,15,5,0,192,54,8,0,15,0,0,0,1,15,4,0,56,24,4,0,15,0,0,0,1,15,15,0,128,230,7,0,15,0,0,0,1,15,0,0,128,230,7,0,15,0,0,0,1,15,3,0,176,162,3,0,15,0,0,0,1,15,2,0,24,188,3,0,15,0,0,0,1,15,1,0,72,216,3,0,15,0,0,0,1,15,6,0,120,211,6,0,15,0,0,0,1,15,14,0,184,164,6,0,15,0,0,0,1,15,13,0,80,74,6,0,15,0,0,0,1,15,12,0,192,32,6,0,15,0,0,0,1,15,11,0,192,234,2,0,15,0,0,0,1,15,10,0,32,242,5,0,0,0,0,0,254,0,16,0,160,123,6,0,15,0,0,0,1,240,112,0,80,252,6,0,15,0,0,0,1,240,128,0,16,242,7,0,15,0,0,0,1,240,144,0,104,236,7,0,15,0,0,0,1,240,80,0,192,54,8,0,15,0,0,0,1,240,64,0,56,24,4,0,15,0,0,0,1,240,240,0,128,230,7,0,15,0,0,0,1,240,0,0,128,230,7,0,15,0,0,0,1,240,48,0,176,162,3,0,15,0,0,0,1,240,32,0,24,188,3,0,15,0,0,0,1,240,16,0,72,216,3,0,15,0,0,0,1,240,96,0,120,211,6,0,15,0,0,0,1,240,224,0,184,164,6,0,15,0,0,0,1,240,208,0,80,74,6,0,15,0,0,0,1,240,192,0,192,32,6,0,15,0,0,0,1,240,176,0,192,234,2,0,15,0,0,0,1,240,160,0,32,242,5,0,0,0,0,0,254,0,2,0,200,30,2,0,16,0,0,0,1,1,0,0,120,97,1,0,16,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,2,0,168,234,7,0,16,0,0,0,1,2,2,0,96,135,7,0,16,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,16,0,0,0,1,12,12,0,192,255,2,0,16,0,0,0,1,12,8,0,208,75,4,0,16,0,0,0,1,12,4,0,8,49,4,0,16,0,0,0,1,12,0,0,104,151,6,0,0,0,0,0,254,0,2,0,64,37,5,0,16,0,0,0,1,16,16,0,32,148,6,0,16,0,0,0,1,16,0,0,208,143,6,0,0,0,0,0,254,0,2,0,104,159,3,0,16,0,0,0,1,32,0,0,96,135,7,0,16,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,72,202,5,0,16,0,0,0,1,64,64,0,80,246,3,0,16,0,0,0,1,64,0,0,112,212,3,0,101,112,114,45,55,53,56,55,46,49,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,84,115,187,27,0,0,16,1,101,112,114,45,55,53,56,56,46,49,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,19,116,0,33,0,0,16,1,101,112,114,45,55,53,56,57,46,49,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,51,4,179,68,0,0,16,1,101,112,114,45,55,53,57,48,46,49,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,11,90,82,187,0,0,16,1,101,112,114,45,55,53,57,49,46,49,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,35,170,121,131,0,0,16,1,101,112,114,45,55,53,57,50,46,49,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,215,165,103,199,0,0,16,1,101,112,114,45,55,52,57,56,46,49,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,123,30,174,120,0,0,16,1,101,112,114,45,55,52,57,55,46,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,202,9,214,8,0,0,32,0,101,112,114,45,55,52,57,54,46,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,241,253,97,111,0,0,32,0,101,112,114,45,55,52,57,53,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,45,44,13,106,0,0,32,0,101,112,114,45,55,52,57,52,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,199,129,226,168,0,0,32,0,101,112,114,45,55,52,57,51,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,244,93,48,137,0,0,32,0,101,112,114,45,55,52,57,50,46,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,177,6,248,96,0,0,32,0,101,112,114,45,55,52,56,53,46,49,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,34,23,137,194,0,0,32,0,101,112,114,45,55,52,56,55,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,27,66,58,45,0,0,32,0,101,112,114,45,55,52,56,54,46,49,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,80,44,98,141,0,0,32,0,101,112,114,45,55,52,56,56,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,27,47,124,0,0,0,32,0,112,114,45,53,51,49,55,46,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,184,80,131,100,0,0,0,8,9,0,0,0,255,255,97,0,0,0,0,0,10,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,9,0,0,0,1,3,3,0,72,246,3,0,9,0,0,0,1,3,2,0,152,21,4,0,9,0,0,0,1,3,1,0,8,49,4,0,9,0,0,0,1,3,0,0,208,75,4,0,0,0,0,0,254,0,4,0,64,37,5,0,9,0,0,0,1,12,12,0,64,201,7,0,9,0,0,0,1,12,8,0,16,152,7,0,9,0,0,0,1,12,4,0,16,106,7,0,9,0,0,0,1,12,0,0,96,135,7,0,0,0,0,0,254,0,2,0,120,11,7,0,9,0,0,0,1,16,16,0,248,38,7,0,9,0,0,0,1,16,0,0,144,68,8,0,0,0,0,0,254,0,4,0,72,84,4,0,9,0,0,0,1,96,96,0,248,81,6,0,9,0,0,0,1,96,64,0,248,38,7,0,9,0,0,0,1,96,32,0,176,64,8,0,9,0,0,0,1,96,0,0,88,3,6,0,0,0,0,0,254,0,2,0,16,17,8,0,9,0,0,0,1,128,128,0,200,175,5,0,9,0,0,0,1,128,0,0,248,38,7,0,0,0,0,0,254,0,4,0,200,87,7,0,10,0,0,0,1,3,3,0,160,36,8,0,10,0,0,0,1,3,0,0,208,239,7,0,10,0,0,0,1,3,1,0,120,187,7,0,10,0,0,0,1,3,2,0,32,15,1,0,0,0,0,0,254,0,4,0,160,123,6,0,10,0,0,0,1,12,12,0,160,36,8,0,10,0,0,0,1,12,0,0,208,239,7,0,10,0,0,0,1,12,4,0,120,187,7,0,10,0,0,0,1,12,8,0,32,15,1,0,0,0,0,0,254,0,4,0,16,5,2,0,10,0,0,0,1,48,48,0,160,36,8,0,10,0,0,0,1,48,0,0,208,239,7,0,10,0,0,0,1,48,16,0,120,187,7,0,10,0,0,0,1,48,32,0,32,15,1,0,118,109,51,117,46,48,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,116,82,41,31,1,0,16,1,118,109,51,117,46,48,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,129,223,106,196,1,0,16,1,118,109,51,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,15,224,24,65,1,0,16,1,118,109,51,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,169,211,79,47,1,0,16,1,118,109,51,46,48,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,184,145,218,203,1,0,16,1,118,109,51,46,48,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,89,114,164,108,1,0,16,1,118,109,51,46,48,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,227,57,163,244,1,0,16,1,118,109,51,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,184,181,251,255,1,0,16,1,118,109,51,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,235,17,138,253,5,0,32,0,118,109,51,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,78,125,30,221,5,0,32,0,118,109,51,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,94,68,137,107,5,0,32,0,118,109,51,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,199,253,48,56,5,0,32,0,118,109,51,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,108,142,162,193,5,0,32,0,118,109,51,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,4,115,74,25,5,0,32,0,118,109,51,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,71,159,154,223,5,0,32,0,118,109,51,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,217,195,47,194,5,0,32,0,118,109,51,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,155,118,120,247,10,0,16,1,118,109,51,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,161,250,9,204,10,0,16,1,118,109,51,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,110,149,14,232,12,0,64,0,118,109,51,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,87,21,215,156,12,0,64,0,118,109,51,106,46,48,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,164,116,46,42,1,0,16,1,118,109,51,106,46,48,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,188,39,36,28,1,0,16,1,118,109,51,106,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,213,136,206,149,1,0,16,1,118,109,51,106,46,48,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,224,151,66,44,1,0,16,1,118,109,51,106,46,48,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,231,170,138,163,1,0,16,1,118,109,51,106,46,48,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,201,229,115,87,1,0,16,1,118,109,51,106,46,48,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,185,248,100,208,1,0,16,1,118,109,51,106,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,233,24,69,67,1,0,16,1,118,109,51,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,235,17,138,253,5,0,32,0,118,109,51,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,78,125,30,221,5,0,32,0,118,109,51,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,94,68,137,107,5,0,32,0,118,109,51,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,199,253,48,56,5,0,32,0,118,109,51,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,108,142,162,193,5,0,32,0,118,109,51,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,4,115,74,25,5,0,32,0,118,109,51,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,71,159,154,223,5,0,32,0,118,109,51,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,217,195,47,194,5,0,32,0,118,109,51,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,155,118,120,247,10,0,16,1,118,109,51,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,161,250,9,204,10,0,16,1,118,109,51,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,110,149,14,232,12,0,64,0,118,109,51,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,87,21,215,156,12,0,64,0,118,109,51,104,46,48,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,248,45,198,124,1,0,16,1,118,109,51,104,46,48,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,243,22,215,1,0,16,1,118,109,51,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,15,224,24,65,1,0,16,1,118,109,51,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,169,211,79,47,1,0,16,1,118,109,51,46,48,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,184,145,218,203,1,0,16,1,118,109,51,46,48,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,89,114,164,108,1,0,16,1,118,109,51,46,48,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,227,57,163,244,1,0,16,1,118,109,51,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,184,181,251,255,1,0,16,1,118,109,51,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,235,17,138,253,5,0,32,0,118,109,51,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,78,125,30,221,5,0,32,0,118,109,51,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,94,68,137,107,5,0,32,0,118,109,51,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,199,253,48,56,5,0,32,0,118,109,51,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,108,142,162,193,5,0,32,0,118,109,51,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,4,115,74,25,5,0,32,0,118,109,51,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,71,159,154,223,5,0,32,0,118,109,51,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,217,195,47,194,5,0,32,0,118,109,51,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,155,118,120,247,10,0,16,1,118,109,51,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,161,250,9,204,10,0,16,1,118,109,51,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,110,149,14,232,12,0,64,0,118,109,51,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,87,21,215,156,12,0,64,0,118,109,51,101,100,46,48,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,227,5,216,151,1,0,16,1,118,109,51,101,100,46,48,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,206,253,7,94,1,0,16,1,118,109,51,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,15,224,24,65,1,0,16,1,118,109,51,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,169,211,79,47,1,0,16,1,118,109,51,46,48,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,184,145,218,203,1,0,16,1,118,109,51,46,48,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,89,114,164,108,1,0,16,1,118,109,51,46,48,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,227,57,163,244,1,0,16,1,118,109,51,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,184,181,251,255,1,0,16,1,118,109,51,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,235,17,138,253,5,0,32,0,118,109,51,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,78,125,30,221,5,0,32,0,118,109,51,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,94,68,137,107,5,0,32,0,118,109,51,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,199,253,48,56,5,0,32,0,118,109,51,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,108,142,162,193,5,0,32,0,118,109,51,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,4,115,74,25,5,0,32,0,118,109,51,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,71,159,154,223,5,0,32,0,118,109,51,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,217,195,47,194,5,0,32,0,118,109,51,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,155,118,120,247,10,0,16,1,118,109,51,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,161,250,9,204,10,0,16,1,118,109,51,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,110,149,14,232,12,0,64,0,118,109,51,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,87,21,215,156,12,0,64,0,118,109,51,97,46,48,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,143,25,193,68,1,0,16,1,118,109,51,97,46,48,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,129,183,24,34,1,0,16,1,118,109,51,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,15,224,24,65,1,0,16,1,118,109,51,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,169,211,79,47,1,0,16,1,118,109,51,46,48,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,184,145,218,203,1,0,16,1,118,109,51,46,48,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,89,114,164,108,1,0,16,1,118,109,51,46,48,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,227,57,163,244,1,0,16,1,118,109,51,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,184,181,251,255,1,0,16,1,118,109,51,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,235,17,138,253,5,0,32,0,118,109,51,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,78,125,30,221,5,0,32,0,118,109,51,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,94,68,137,107,5,0,32,0,118,109,51,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,199,253,48,56,5,0,32,0,118,109,51,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,108,142,162,193,5,0,32,0,118,109,51,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,4,115,74,25,5,0,32,0,118,109,51,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,71,159,154,223,5,0,32,0,118,109,51,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,217,195,47,194,5,0,32,0,118,109,51,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,155,118,120,247,10,0,16,1,118,109,51,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,161,250,9,204,10,0,16,1,118,109,51,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,110,149,14,232,12,0,64,0,118,109,51,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,87,21,215,156,12,0,64,0,118,115,50,106,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,180,134,253,137,1,0,16,1,118,115,50,106,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,27,9,124,16,1,0,16,1,118,115,50,106,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,56,150,151,97,1,0,16,1,118,115,50,106,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,194,91,124,243,1,0,16,1,118,115,50,106,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,9,88,136,143,1,0,16,1,118,115,50,106,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,32,193,24,32,1,0,16,1,118,115,50,106,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,23,194,195,250,1,0,16,1,118,115,50,106,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,19,2,73,235,1,0,16,1,118,115,50,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,82,47,133,92,5,0,32,0,118,115,50,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,175,88,15,162,5,0,32,0,118,115,50,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,173,89,219,57,5,0,32,0,118,115,50,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,167,99,199,0,5,0,32,0,118,115,50,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,99,189,9,205,5,0,32,0,118,115,50,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,21,44,24,224,5,0,32,0,118,115,50,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,246,196,141,119,5,0,32,0,118,115,50,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,29,157,93,96,5,0,32,0,118,115,50,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,57,1,25,53,10,0,16,1,118,115,50,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,186,45,195,10,0,16,1,118,115,50,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,183,71,126,214,12,0,64,0,118,115,50,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,20,10,2,109,12,0,64,0,118,105,100,112,111,111,108,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,50,71,63,51,1,0,16,1,118,105,100,112,111,111,108,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,241,192,166,238,1,0,16,1,118,105,100,112,111,111,108,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,166,114,153,48,1,0,16,1,118,105,100,112,111,111,108,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,29,28,247,196,1,0,16,1,104,117,115,116,108,101,114,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,14,173,223,11,4,0,32,0,104,117,115,116,108,101,114,46,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,119,33,6,142,4,0,32,0,104,117,115,116,108,101,114,46,99,108,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,94,127,31,170,7,0,32,0,12,0,0,0,255,255,32,0,0,0,0,0,13,0,0,0,255,255,224,0,0,0,0,0,14,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,232,75,4,0,12,0,0,0,1,64,0,0,96,135,7,0,12,0,0,0,1,64,64,0,152,182,7,0,118,97,101,95,51,48,98,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,145,211,184,173,1,0,16,1,118,97,101,95,51,53,98,46,49,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,143,84,229,68,1,0,16,1,118,97,101,95,51,49,98,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,28,167,73,23,1,0,16,1,118,97,101,95,51,54,98,46,49,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,80,36,46,95,1,0,16,1,118,97,101,95,50,56,98,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,80,202,36,229,1,0,16,1,118,97,101,95,51,51,98,46,57,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,201,248,187,192,1,0,16,1,118,97,101,95,50,57,98,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,106,153,64,102,1,0,16,1,118,97,101,95,51,52,98,46,49,48,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,138,190,89,250,1,0,16,1,118,97,45,53,109,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,110,114,251,177,4,0,32,0,118,97,45,55,109,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,205,136,101,76,4,0,32,0,118,97,45,49,109,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,55,206,26,11,4,0,32,0,118,97,45,51,109,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,6,231,223,68,4,0,32,0,118,97,95,48,57,46,49,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,110,68,153,122,3,0,16,0,118,97,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,14,81,48,222,5,0,64,0,118,97,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,172,164,16,6,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,118,97,50,52,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,80,102,71,204,0,0,0,8,105,111,98,49,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,21,0,0,0,255,255,0,0,0,0,0,0,22,0,0,0,255,255,11,0,0,0,0,0,23,0,0,0,255,255,96,0,0,0,0,0,0,0,0,0,254,0,8,0,200,87,7,0,21,0,0,0,1,7,7,0,80,252,6,0,21,0,0,0,1,7,6,0,16,242,7,0,21,0,0,0,1,7,5,0,104,236,7,0,21,0,0,0,1,7,0,0,128,230,7,0,21,0,0,0,1,7,1,0,184,164,6,0,21,0,0,0,1,7,2,0,80,74,6,0,21,0,0,0,1,7,3,0,192,32,6,0,21,0,0,0,1,7,4,0,32,242,5,0,0,0,0,0,254,0,8,0,160,123,6,0,21,0,0,0,1,56,56,0,80,252,6,0,21,0,0,0,1,56,48,0,16,242,7,0,21,0,0,0,1,56,40,0,104,236,7,0,21,0,0,0,1,56,0,0,128,230,7,0,21,0,0,0,1,56,8,0,184,164,6,0,21,0,0,0,1,56,16,0,80,74,6,0,21,0,0,0,1,56,24,0,192,32,6,0,21,0,0,0,1,56,32,0,32,242,5,0,0,0,0,0,254,0,2,0,64,232,1,0,21,0,0,0,1,64,0,0,96,135,7,0,21,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,8,0,72,202,5,0,22,0,0,0,1,7,0,0,72,198,6,0,22,0,0,0,1,7,1,0,208,75,4,0,22,0,0,0,1,7,2,0,8,49,4,0,22,0,0,0,1,7,3,0,72,195,6,0,22,0,0,0,1,7,4,0,72,246,3,0,22,0,0,0,1,7,5,0,72,0,3,0,22,0,0,0,1,7,6,0,64,47,7,0,22,0,0,0,1,7,7,0,48,173,6,0,0,0,0,0,254,0,4,0,64,37,5,0,22,0,0,0,1,24,0,0,208,228,1,0,22,0,0,0,1,24,8,0,144,227,1,0,22,0,0,0,1,24,16,0,192,225,1,0,22,0,0,0,1,24,24,0,64,223,1,0,0,0,0,0,254,0,4,0,128,129,4,0,23,0,0,0,1,3,1,0,192,255,2,0,23,0,0,0,1,3,2,0,208,75,4,0,23,0,0,0,1,3,0,0,8,49,4,0,23,0,0,0,1,3,3,0,152,21,4,0,0,0,0,0,254,0,2,0,16,227,4,0,23,0,0,0,1,4,0,0,96,135,7,0,23,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,254,0,2,0,72,4,1,0,23,0,0,0,1,8,0,0,96,135,7,0,23,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,23,0,0,0,1,16,0,0,96,135,7,0,23,0,0,0,1,16,16,0,152,182,7,0,0,0,0,0,254,0,2,0,40,111,8,0,23,0,0,0,1,32,0,0,96,135,7,0,23,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,23,0,0,0,1,64,0,0,96,135,7,0,23,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,168,79,2,0,23,0,0,0,1,128,0,0,32,182,8,0,23,0,0,0,1,128,128,0,80,251,6,0,0,0,0,0,118,97,109,106,46,48,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,34,55,93,245,1,0,16,1,118,97,109,106,46,48,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,196,67,156,77,1,0,16,1,118,97,109,106,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,146,126,73,108,1,0,16,1,118,97,109,106,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,182,236,187,241,1,0,16,1,118,97,109,106,46,48,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,132,173,103,16,1,0,16,1,118,97,109,106,46,48,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,31,244,137,75,1,0,16,1,118,97,109,106,46,48,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,172,74,10,252,1,0,16,1,118,97,109,106,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,107,194,112,146,1,0,16,1,118,97,109,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,153,175,27,197,5,0,32,0,118,97,109,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,119,60,232,60,5,0,32,0,118,97,109,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,224,8,36,79,5,0,32,0,118,97,109,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,80,2,246,159,5,0,32,0,118,97,109,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,60,36,135,189,5,0,32,0,118,97,109,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,95,133,236,175,5,0,32,0,118,97,109,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,37,54,3,58,5,0,32,0,118,97,109,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,137,106,255,43,5,0,32,0,118,97,109,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,213,133,182,100,10,0,16,1,118,97,109,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,199,151,124,207,10,0,16,1,118,97,109,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,178,222,57,74,12,0,64,0,118,97,109,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,3,92,62,26,12,0,64,0,49,50,51,50,55,46,97,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,147,197,118,3,1,0,16,1,49,50,51,50,54,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,43,134,152,249,1,0,16,1,49,50,50,54,56,46,97,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,127,192,218,224,2,0,32,0,49,50,50,54,57,46,97,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,144,135,122,69,2,0,32,0,49,50,50,55,48,46,97,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,91,2,252,105,2,0,32,0,49,50,50,55,57,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,177,159,22,122,3,0,32,0,49,50,50,56,51,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,133,160,15,174,3,0,32,0,49,50,50,55,56,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,183,6,29,150,3,0,32,0,49,50,50,56,50,46,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,225,30,103,232,3,0,32,0,49,50,50,55,55,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,162,107,107,241,3,0,32,0,49,50,50,56,49,46,98,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,127,7,241,30,3,0,32,0,49,50,50,55,54,46,98,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,31,215,139,131,3,0,32,0,49,50,50,56,48,46,98,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,203,87,154,99,3,0,32,0,49,50,51,50,56,46,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,4,0,16,16,49,50,51,50,57,46,97,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,109,104,154,237,8,0,64,0,49,50,51,51,48,46,97,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,202,43,118,251,8,0,64,0,51,49,55,45,48,49,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,16,21,0,0,0,255,255,44,0,0,0,0,0,22,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,224,117,5,0,21,0,0,0,1,3,0,0,120,7,5,0,21,0,0,0,1,3,1,0,8,49,4,0,21,0,0,0,1,3,2,0,184,112,5,0,21,0,0,0,1,3,3,0,184,112,5,0,0,0,0,0,254,0,4,0,72,202,5,0,21,0,0,0,1,12,8,0,80,246,3,0,21,0,0,0,1,12,12,0,248,38,7,0,21,0,0,0,1,12,4,0,112,212,3,0,21,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,4,0,80,109,5,0,21,0,0,0,1,48,0,0,8,49,4,0,21,0,0,0,1,48,16,0,152,21,4,0,21,0,0,0,1,48,32,0,72,0,3,0,21,0,0,0,1,48,48,0,232,99,5,0,0,0,0,0,254,0,2,0,168,234,7,0,21,0,0,0,1,64,64,0,96,135,7,0,21,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,240,96,5,0,21,0,0,0,1,128,128,0,192,255,2,0,21,0,0,0,1,128,0,0,208,75,4,0,0,0,0,0,254,0,16,0,200,87,7,0,22,0,0,0,1,15,7,0,80,252,6,0,22,0,0,0,1,15,8,0,16,242,7,0,22,0,0,0,1,15,9,0,104,236,7,0,22,0,0,0,1,15,5,0,176,51,4,0,22,0,0,0,1,15,4,0,56,24,4,0,22,0,0,0,1,15,15,0,128,230,7,0,22,0,0,0,1,15,1,0,72,216,3,0,22,0,0,0,1,15,2,0,24,188,3,0,22,0,0,0,1,15,3,0,176,162,3,0,22,0,0,0,1,15,6,0,120,211,6,0,22,0,0,0,1,15,14,0,184,164,6,0,22,0,0,0,1,15,13,0,80,74,6,0,22,0,0,0,1,15,12,0,192,32,6,0,22,0,0,0,1,15,11,0,192,234,2,0,22,0,0,0,1,15,10,0,32,242,5,0,22,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,22,0,0,0,1,240,112,0,80,252,6,0,22,0,0,0,1,240,128,0,16,242,7,0,22,0,0,0,1,240,144,0,104,236,7,0,22,0,0,0,1,240,80,0,176,51,4,0,22,0,0,0,1,240,64,0,56,24,4,0,22,0,0,0,1,240,240,0,128,230,7,0,22,0,0,0,1,240,16,0,72,216,3,0,22,0,0,0,1,240,32,0,24,188,3,0,22,0,0,0,1,240,48,0,176,162,3,0,22,0,0,0,1,240,96,0,120,211,6,0,22,0,0,0,1,240,224,0,184,164,6,0,22,0,0,0,1,240,208,0,80,74,6,0,22,0,0,0,1,240,192,0,192,32,6,0,22,0,0,0,1,240,176,0,192,234,2,0,22,0,0,0,1,240,160,0,32,242,5,0,22,0,0,0,1,240,0,0,208,236,2,0,0,0,0,0,19,0,0,0,255,255,254,0,0,0,0,0,20,0,0,0,255,255,126,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,19,0,0,0,1,1,0,0,120,97,1,0,19,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,2,2,0,96,135,7,0,19,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,4,4,0,96,135,7,0,19,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,8,0,0,96,135,7,0,19,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,19,0,0,0,1,48,16,0,96,39,7,0,19,0,0,0,1,48,48,0,144,251,6,0,19,0,0,0,1,48,0,0,120,211,6,0,19,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,19,0,0,0,1,192,64,0,96,39,7,0,19,0,0,0,1,192,192,0,144,251,6,0,19,0,0,0,1,192,0,0,120,211,6,0,19,0,0,0,1,192,128,0,184,164,6,0,0,0,0,0,254,0,2,0,232,235,2,0,20,0,0,0,1,1,1,0,224,211,2,0,20,0,0,0,1,1,0,0,184,193,2,0,0,0,0,0,254,0,2,0,160,176,2,0,20,0,0,0,1,2,2,0,224,211,2,0,20,0,0,0,1,2,0,0,184,193,2,0,0,0,0,0,254,0,4,0,64,37,5,0,20,0,0,0,1,12,12,0,240,148,2,0,20,0,0,0,1,12,8,0,200,136,2,0,20,0,0,0,1,12,4,0,88,124,2,0,20,0,0,0,1,12,0,0,96,110,2,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,48,48,0,8,49,4,0,20,0,0,0,1,48,32,0,152,21,4,0,20,0,0,0,1,48,16,0,72,246,3,0,20,0,0,0,1,48,0,0,80,42,2,0,0,0,0,0,254,0,0,0,128,112,3,0,20,0,0,0,1,128,0,0,168,22,4,0,20,0,0,0,1,128,128,0,224,247,3,0,0,0,0,0,19,0,0,0,255,255,254,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,19,0,0,0,1,1,0,0,120,97,1,0,19,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,2,2,0,96,135,7,0,19,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,4,4,0,96,135,7,0,19,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,19,0,0,0,1,48,16,0,96,39,7,0,19,0,0,0,1,48,48,0,144,251,6,0,19,0,0,0,1,48,0,0,120,211,6,0,19,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,19,0,0,0,1,192,64,0,96,39,7,0,19,0,0,0,1,192,192,0,144,251,6,0,19,0,0,0,1,192,0,0,120,211,6,0,19,0,0,0,1,192,128,0,184,164,6,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,3,2,0,80,246,3,0,20,0,0,0,1,3,3,0,80,124,6,0,20,0,0,0,1,3,1,0,112,212,3,0,20,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,64,37,5,0,20,0,0,0,1,12,0,0,56,176,7,0,20,0,0,0,1,12,12,0,8,172,7,0,20,0,0,0,1,12,4,0,56,168,7,0,20,0,0,0,1,12,8,0,248,163,7,0,0,0,0,0,254,0,0,0,128,129,4,0,20,0,0,0,1,48,32,0,208,75,4,0,20,0,0,0,1,48,48,0,8,49,4,0,20,0,0,0,1,48,16,0,152,21,4,0,20,0,0,0,1,48,0,0,72,246,3,0,0,0,0,0,254,0,2,0,104,159,3,0,20,0,0,0,1,64,0,0,56,111,3,0,20,0,0,0,1,64,64,0,104,134,3,0,0,0,0,0,57,54,51,45,114,50,51,46,106,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,149,17,246,167,0,0,16,1,57,54,51,45,114,50,52,46,107,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,106,5,30,102,0,0,16,1,57,54,51,45,114,50,49,46,106,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,182,123,4,222,0,0,16,1,57,54,51,45,114,50,50,46,107,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,136,8,106,216,0,0,16,1,57,54,51,101,50,48,46,103,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,214,166,146,22,0,0,16,1,57,54,51,97,50,56,46,104,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,105,71,219,0,0,32,0,57,54,51,97,50,57,46,107,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,46,205,105,128,0,0,32,0,57,54,51,97,49,55,46,104,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,68,154,35,181,0,0,32,0,57,54,51,97,49,56,46,104,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,239,173,81,221,0,0,32,0,57,54,51,97,49,53,46,107,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,237,78,50,31,0,0,32,0,57,54,51,97,49,54,46,107,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,132,153,189,212,0,0,32,0,57,54,51,97,51,48,46,103,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,128,38,216,171,0,0,32,0,57,54,51,97,51,49,46,103,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,28,74,0,248,0,0,32,0,57,54,51,97,50,54,46,99,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,99,48,172,226,0,0,64,0,57,54,51,97,50,55,46,100,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,75,103,253,45,0,0,64,0,57,54,51,97,50,53,46,100,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,199,120,160,252,0,0,64,0,57,54,51,95,50,50,51,46,106,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,255,165,52,13,0,0,16,1,57,54,51,95,50,50,52,46,107,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,242,83,212,47,0,0,16,1,57,54,51,95,50,50,49,46,106,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,253,37,142,250,0,0,16,1,57,54,51,95,50,50,50,46,107,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,79,122,67,202,0,0,16,1,57,54,51,101,50,48,46,103,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,214,166,146,22,0,0,16,1,57,54,51,97,50,56,46,104,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,105,71,219,0,0,32,0,57,54,51,97,50,57,46,107,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,46,205,105,128,0,0,32,0,57,54,51,97,49,55,46,104,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,68,154,35,181,0,0,32,0,57,54,51,97,49,56,46,104,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,239,173,81,221,0,0,32,0,57,54,51,97,49,53,46,107,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,237,78,50,31,0,0,32,0,57,54,51,97,49,54,46,107,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,132,153,189,212,0,0,32,0,57,54,51,97,51,48,46,103,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,128,38,216,171,0,0,32,0,57,54,51,97,51,49,46,103,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,28,74,0,248,0,0,32,0,57,54,51,97,50,54,46,99,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,99,48,172,226,0,0,64,0,57,54,51,97,50,55,46,100,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,75,103,253,45,0,0,64,0,57,54,51,97,50,53,46,100,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,199,120,160,252,0,0,64,0,57,54,51,45,115,50,51,46,106,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,238,126,175,181,0,0,16,1,57,54,51,45,115,50,52,46,107,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,139,206,184,188,0,0,16,1,57,54,51,45,115,50,49,46,106,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,166,191,136,11,0,0,16,1,57,54,51,45,115,50,50,46,107,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,75,109,206,68,0,0,16,1,57,54,51,101,50,48,46,103,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,214,166,146,22,0,0,16,1,57,54,51,97,50,56,46,104,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,105,71,219,0,0,32,0,57,54,51,97,50,57,46,107,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,46,205,105,128,0,0,32,0,57,54,51,97,49,55,46,104,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,68,154,35,181,0,0,32,0,57,54,51,97,49,56,46,104,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,239,173,81,221,0,0,32,0,57,54,51,97,49,53,46,107,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,237,78,50,31,0,0,32,0,57,54,51,97,49,54,46,107,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,132,153,189,212,0,0,32,0,57,54,51,97,51,48,46,103,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,128,38,216,171,0,0,32,0,57,54,51,97,51,49,46,103,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,28,74,0,248,0,0,32,0,57,54,51,97,50,54,46,99,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,99,48,172,226,0,0,64,0,57,54,51,97,50,55,46,100,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,75,103,253,45,0,0,64,0,57,54,51,97,50,53,46,100,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,199,120,160,252,0,0,64,0,0,0,0,0,16,0,0,0,32,0,0,0,48,0,0,0,64,0,0,0,80,0,0,0,96,0,0,0,112,0,0,0,0,0,0,0,8,0,0,0,16,0,0,0,24,0,0,0,32,0,0,0,40,0,0,0,48,0,0,0,56,0,0,0,0,64,0,0,8,64,0,0,16,64,0,0,24,64,0,0,32,64,0,0,40,64,0,0,48,64,0,0,56,64,0,0,3,0,0,0,2,0,0,0,1,0,0,0,0,0,0,0,11,0,0,0,10,0,0,0,9,0,0,0,8,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,16,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,0,1,0,0,1,1,0,0,2,1,0,0,3,1,0,0,4,1,0,0,5,1,0,0,6,1,0,0,7,1,0,0,0,0,0,0,0,0,0,0,17,0,0,0,255,255,255,0,0,0,0,0,18,0,0,0,255,255,207,0,0,0,0,0,0,0,0,0,254,0,11,0,200,87,7,0,17,0,0,0,1,15,7,0,32,136,7,0,17,0,0,0,1,15,8,0,40,88,7,0,17,0,0,0,1,15,9,0,96,39,7,0,17,0,0,0,1,15,15,0,144,251,6,0,17,0,0,0,1,15,6,0,120,211,6,0,17,0,0,0,1,15,14,0,184,164,6,0,17,0,0,0,1,15,13,0,80,74,6,0,17,0,0,0,1,15,12,0,192,32,6,0,17,0,0,0,1,15,11,0,192,234,2,0,17,0,0,0,1,15,10,0,32,242,5,0,17,0,0,0,1,15,0,0,8,75,5,0,0,0,0,0,254,0,2,0,120,43,5,0,17,0,0,0,1,64,64,0,96,135,7,0,17,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,18,0,0,0,1,3,3,0,80,246,3,0,18,0,0,0,1,3,2,0,248,38,7,0,18,0,0,0,1,3,1,0,112,212,3,0,18,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,2,0,128,55,4,0,18,0,0,0,1,4,4,0,128,183,8,0,18,0,0,0,1,4,0,0,192,188,8,0,0,0,0,0,254,0,4,0,128,129,4,0,18,0,0,0,1,24,0,0,152,21,4,0,18,0,0,0,1,24,8,0,8,49,4,0,18,0,0,0,1,24,16,0,208,75,4,0,18,0,0,0,1,24,24,0,192,255,2,0,0,0,0,0,254,0,2,0,168,234,7,0,18,0,0,0,1,32,32,0,96,135,7,0,18,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,200,30,2,0,18,0,0,0,1,64,64,0,120,97,1,0,18,0,0,0,1,64,0,0,96,19,1,0,0,0,0,0,254,0,2,0,232,75,4,0,18,0,0,0,1,128,128,0,96,135,7,0,18,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,115,119,97,114,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,208,163,235,33,1,0,16,1,115,119,97,114,109,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,205,54,164,243,1,0,16,1,115,119,97,114,109,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,139,227,21,41,1,0,16,1,115,119,97,114,109,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,134,244,187,139,1,0,16,1,115,119,97,114,109,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,126,152,177,241,1,0,16,1,115,119,97,114,109,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,187,87,134,239,4,0,32,0,115,119,97,114,109,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,49,189,196,96,4,0,32,0,54,108,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,103,148,172,195,7,0,32,0,12,0,0,0,255,255,0,0,0,0,0,0,13,0,0,0,255,255,0,0,0,0,0,0,14,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,12,0,0,0,1,32,0,0,120,97,1,0,12,0,0,0,1,32,32,0,96,19,1,0,0,0,0,0,254,0,2,0,232,75,4,0,12,0,0,0,1,64,0,0,96,135,7,0,12,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,4,0,32,4,2,0,13,0,0,0,1,192,64,0,224,127,8,0,13,0,0,0,1,192,0,0,32,123,8,0,13,0,0,0,1,192,128,0,192,110,8,0,13,0,0,0,1,192,192,0,104,151,6,0,0,0,0,0,254,0,4,0,64,37,5,0,14,0,0,0,1,3,1,0,176,116,6,0,14,0,0,0,1,3,2,0,80,110,6,0,14,0,0,0,1,3,3,0,112,216,4,0,14,0,0,0,1,3,0,0,120,7,5,0,0,0,0,0,254,0,2,0,128,129,4,0,14,0,0,0,1,4,0,0,8,49,4,0,14,0,0,0,1,4,4,0,152,21,4,0,0,0,0,0,254,0,2,0,72,202,5,0,14,0,0,0,1,8,0,0,80,246,3,0,14,0,0,0,1,8,8,0,112,212,3,0,0,0,0,0,10,0,0,0,255,255,253,0,0,0,0,0,0,0,0,0,254,0,2,0,128,119,3,0,10,0,0,0,1,2,2,0,248,96,3,0,10,0,0,0,1,2,0,0,16,81,3,0,0,0,0,0,254,0,8,0,0,67,3,0,10,0,0,0,1,5,1,0,208,75,4,0,10,0,0,0,1,5,5,0,8,49,4,0,10,0,0,0,1,5,0,0,152,21,4,0,10,0,0,0,1,5,4,0,72,246,3,0,10,0,0,0,1,5,1,0,152,21,4,0,10,0,0,0,1,5,5,0,72,246,3,0,10,0,0,0,1,5,0,0,72,0,3,0,10,0,0,0,1,5,4,0,64,47,7,0,0,0,0,0,254,0,2,0,200,30,2,0,10,0,0,0,1,8,8,0,120,97,1,0,10,0,0,0,1,8,0,0,96,19,1,0,0,0,0,0,254,0,2,0,32,4,2,0,10,0,0,0,1,16,0,0,104,236,7,0,10,0,0,0,1,16,16,0,80,245,6,0,0,0,0,0,254,0,2,0,240,102,2,0,10,0,0,0,1,32,32,0,184,89,2,0,10,0,0,0,1,32,0,0,16,74,2,0,0,0,0,0,254,0,2,0,216,33,6,0,10,0,0,0,1,64,0,0,56,111,3,0,10,0,0,0,1,64,64,0,104,134,3,0,0,0,0,0,168,86,7,0,1,0,0,0,136,239,146,0,248,191,2,0,24,38,7,0,1,0,0,0,223,254,146,0,184,160,2,0,56,210,6,0,1,0,0,0,218,254,146,0,192,135,2,0,24,163,6,0,1,0,0,0,219,254,146,0,240,108,2,0,152,122,6,0,1,0,0,0,216,254,146,0,96,82,2,0,192,72,6,0,1,0,0,0,217,254,146,0,32,56,2,0,200,110,3,0,1,0,0,0,220,254,146,0,152,30,2,0,120,89,3,0,1,0,0,0,221,254,146,0,232,10,2,0,120,74,3,0,1,0,0,0,222,254,146,0,152,138,8,0,144,236,1,0,1,0,0,0,127,246,146,0,136,224,1,0,176,223,1,0,1,0,0,0,122,246,146,0,72,198,1,0,192,209,1,0,1,0,0,0,123,246,146,0,24,182,1,0,24,198,1,0,1,0,0,0,120,246,146,0,40,167,1,0,120,189,1,0,1,0,0,0,121,246,146,0,200,149,1,0,224,22,1,0,1,0,0,0,124,246,146,0,56,126,1,0,160,14,1,0,1,0,0,0,125,246,146,0,32,101,1,0,176,9,1,0,1,0,0,0,126,246,146,0,96,32,8,0,88,212,3,0,1,0,0,0,160,218,146,0,40,185,3,0,16,17,8,0,1,0,0,0,138,239,146,0,224,12,8,0,72,65,1,0,9,0,0,0,48,5,147,0,32,58,1,0,48,50,1,0,9,0,0,0,49,5,147,0,32,58,1,0,224,41,1,0,9,0,0,0,50,5,147,0,32,58,1,0,115,116,101,114,97,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,168,254,4,205,1,0,16,1,115,116,101,114,97,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,142,135,209,204,1,0,16,1,115,116,101,114,97,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,171,176,162,41,1,0,16,1,115,116,101,114,97,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,109,90,106,76,1,0,16,1,115,116,101,114,97,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,166,120,211,6,1,0,16,1,115,116,101,114,97,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,39,169,132,110,1,0,16,1,115,116,101,114,97,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,232,241,90,180,1,0,16,1,115,116,101,114,97,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,86,153,241,55,1,0,16,1,115,116,101,114,97,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,5,167,141,82,4,0,32,0,115,116,101,114,97,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,21,42,147,19,4,0,32,0,115,116,101,114,97,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,107,255,121,78,4,0,32,0,115,116,101,114,97,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,69,209,207,36,4,0,32,0,115,116,101,114,97,46,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,135,125,12,106,7,0,32,0,115,115,102,117,46,48,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,51,156,242,114,1,0,16,1,115,115,102,117,46,48,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,68,234,92,147,1,0,16,1,115,115,102,117,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,138,178,172,160,1,0,16,1,115,115,102,117,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,207,61,65,71,1,0,16,1,115,115,102,117,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,119,96,6,230,1,0,16,1,115,115,102,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,117,210,148,207,5,0,32,0,115,115,102,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,175,3,183,94,5,0,32,0,115,115,102,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,15,14,166,255,5,0,32,0,115,115,102,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,197,37,232,52,5,0,32,0,115,115,102,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,231,50,204,183,5,0,32,0,115,115,102,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,24,173,118,131,5,0,32,0,115,115,102,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,54,179,177,245,5,0,32,0,115,115,102,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,107,92,157,69,5,0,32,0,115,115,102,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,140,126,36,235,10,0,16,1,115,115,102,46,113,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,92,218,249,166,12,0,64,0,115,115,102,46,113,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,38,174,102,140,12,0,64,0,115,115,102,46,113,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,202,194,92,105,12,0,64,0,115,115,102,46,113,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,50,190,158,157,12,0,64,0,115,115,102,46,113,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,183,231,112,71,12,0,64,0,115,115,102,46,113,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,81,201,121,78,12,0,64,0,115,115,102,46,113,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,19,67,209,205,12,0,64,0,115,115,102,46,113,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,140,8,90,111,12,0,64,0,115,102,120,101,46,48,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,150,243,161,47,1,0,16,1,115,102,120,101,46,48,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,198,41,188,208,1,0,16,1,115,102,120,101,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,100,41,34,101,1,0,16,1,115,102,120,101,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,49,245,233,143,1,0,16,1,115,102,120,101,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,182,12,125,138,1,0,16,1,115,102,120,101,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,98,64,194,116,1,0,16,1,115,102,120,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,63,174,47,100,1,0,16,1,115,102,120,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,117,210,148,207,5,0,32,0,115,102,120,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,175,3,183,94,5,0,32,0,115,102,120,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,15,14,166,255,5,0,32,0,115,102,120,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,197,37,232,52,5,0,32,0,115,102,120,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,231,50,204,183,5,0,32,0,115,102,120,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,24,173,118,131,5,0,32,0,115,102,120,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,54,179,177,245,5,0,32,0,115,102,120,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,107,92,157,69,5,0,32,0,115,102,120,46,50,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,175,84,40,227,5,0,32,0,115,102,120,46,50,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,39,41,15,118,5,0,32,0,115,102,120,46,50,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,8,2,233,30,5,0,32,0,115,102,120,46,50,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,15,64,20,248,5,0,32,0,115,102,120,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,53,136,123,180,10,0,16,1,115,102,120,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,99,34,0,10,0,16,1,115,102,120,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,118,212,219,155,12,0,64,0,115,102,120,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,171,58,94,160,12,0,64,0,115,115,102,106,46,48,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,109,53,46,92,1,0,16,1,115,115,102,106,46,48,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,92,213,59,1,1,0,16,1,115,115,102,106,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,154,209,24,9,1,0,16,1,115,115,102,106,46,48,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,109,12,78,1,1,0,16,1,115,115,102,106,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,27,155,106,235,1,0,16,1,115,115,102,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,117,210,148,207,5,0,32,0,115,115,102,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,175,3,183,94,5,0,32,0,115,115,102,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,15,14,166,255,5,0,32,0,115,115,102,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,197,37,232,52,5,0,32,0,115,115,102,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,231,50,204,183,5,0,32,0,115,115,102,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,24,173,118,131,5,0,32,0,115,115,102,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,54,179,177,245,5,0,32,0,115,115,102,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,107,92,157,69,5,0,32,0,115,115,102,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,140,126,36,235,10,0,16,1,115,115,102,46,113,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,92,218,249,166,12,0,64,0,115,115,102,46,113,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,38,174,102,140,12,0,64,0,115,115,102,46,113,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,202,194,92,105,12,0,64,0,115,115,102,46,113,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,50,190,158,157,12,0,64,0,115,115,102,46,113,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,183,231,112,71,12,0,64,0,115,115,102,46,113,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,81,201,121,78,12,0,64,0,115,115,102,46,113,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,19,67,209,205,12,0,64,0,115,115,102,46,113,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,140,8,90,111,12,0,64,0,115,115,102,104,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,85,179,134,176,1,0,16,1,115,115,102,104,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,41,155,98,30,1,0,16,1,115,115,102,104,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,16,126,153,181,1,0,16,1,115,115,102,104,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,173,143,59,121,1,0,16,1,115,115,102,104,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,195,42,185,203,1,0,16,1,115,115,102,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,117,210,148,207,5,0,32,0,115,115,102,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,175,3,183,94,5,0,32,0,115,115,102,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,15,14,166,255,5,0,32,0,115,115,102,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,197,37,232,52,5,0,32,0,115,115,102,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,231,50,204,183,5,0,32,0,115,115,102,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,24,173,118,131,5,0,32,0,115,115,102,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,54,179,177,245,5,0,32,0,115,115,102,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,107,92,157,69,5,0,32,0,115,115,102,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,140,126,36,235,10,0,16,1,115,115,102,46,113,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,92,218,249,166,12,0,64,0,115,115,102,46,113,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,38,174,102,140,12,0,64,0,115,115,102,46,113,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,202,194,92,105,12,0,64,0,115,115,102,46,113,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,50,190,158,157,12,0,64,0,115,115,102,46,113,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,183,231,112,71,12,0,64,0,115,115,102,46,113,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,81,201,121,78,12,0,64,0,115,115,102,46,113,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,19,67,209,205,12,0,64,0,115,115,102,46,113,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,140,8,90,111,12,0,64,0,115,115,102,101,100,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,248,218,213,250,1,0,16,1,115,115,102,101,100,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,101,175,49,13,1,0,16,1,115,115,102,101,100,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,239,81,198,117,1,0,16,1,115,115,102,101,100,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,236,195,133,1,0,16,1,115,115,102,101,100,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,80,227,32,147,1,0,16,1,115,115,102,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,117,210,148,207,5,0,32,0,115,115,102,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,175,3,183,94,5,0,32,0,115,115,102,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,15,14,166,255,5,0,32,0,115,115,102,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,197,37,232,52,5,0,32,0,115,115,102,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,231,50,204,183,5,0,32,0,115,115,102,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,24,173,118,131,5,0,32,0,115,115,102,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,54,179,177,245,5,0,32,0,115,115,102,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,107,92,157,69,5,0,32,0,115,115,102,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,140,126,36,235,10,0,16,1,115,115,102,46,113,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,92,218,249,166,12,0,64,0,115,115,102,46,113,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,38,174,102,140,12,0,64,0,115,115,102,46,113,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,202,194,92,105,12,0,64,0,115,115,102,46,113,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,50,190,158,157,12,0,64,0,115,115,102,46,113,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,183,231,112,71,12,0,64,0,115,115,102,46,113,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,81,201,121,78,12,0,64,0,115,115,102,46,113,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,19,67,209,205,12,0,64,0,115,115,102,46,113,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,140,8,90,111,12,0,64,0,115,115,102,97,46,48,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,191,89,160,131,1,0,16,1,115,115,102,97,46,48,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,66,54,135,93,1,0,16,1,115,115,102,97,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,226,77,251,248,1,0,16,1,115,115,102,97,46,48,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,157,209,133,49,1,0,16,1,115,115,102,97,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,23,146,226,54,1,0,16,1,115,115,102,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,117,210,148,207,5,0,32,0,115,115,102,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,175,3,183,94,5,0,32,0,115,115,102,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,15,14,166,255,5,0,32,0,115,115,102,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,197,37,232,52,5,0,32,0,115,115,102,46,49,52,109,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,231,50,204,183,5,0,32,0,115,115,102,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,24,173,118,131,5,0,32,0,115,115,102,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,54,179,177,245,5,0,32,0,115,115,102,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,107,92,157,69,5,0,32,0,115,115,102,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,140,126,36,235,10,0,16,1,115,115,102,46,113,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,92,218,249,166,12,0,64,0,115,115,102,46,113,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,38,174,102,140,12,0,64,0,115,115,102,46,113,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,202,194,92,105,12,0,64,0,115,115,102,46,113,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,50,190,158,157,12,0,64,0,115,115,102,46,113,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,183,231,112,71,12,0,64,0,115,115,102,46,113,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,81,201,121,78,12,0,64,0,115,115,102,46,113,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,19,67,209,205,12,0,64,0,115,115,102,46,113,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,140,8,90,111,12,0,64,0,168,86,7,0,1,0,0,0,120,241,146,0,248,191,2,0,24,38,7,0,1,0,0,0,88,2,147,0,184,160,2,0,56,210,6,0,1,0,0,0,89,2,147,0,192,135,2,0,24,163,6,0,1,0,0,0,90,2,147,0,240,108,2,0,152,122,6,0,1,0,0,0,91,2,147,0,96,82,2,0,192,72,6,0,1,0,0,0,92,2,147,0,32,56,2,0,200,110,3,0,1,0,0,0,94,2,147,0,152,30,2,0,120,89,3,0,1,0,0,0,93,2,147,0,232,10,2,0,40,246,1,0,1,0,0,0,121,241,146,0,64,246,1,0,144,236,1,0,1,0,0,0,152,249,146,0,136,224,1,0,176,223,1,0,1,0,0,0,153,249,146,0,72,198,1,0,192,209,1,0,1,0,0,0,154,249,146,0,24,182,1,0,24,198,1,0,1,0,0,0,155,249,146,0,40,167,1,0,120,189,1,0,1,0,0,0,156,249,146,0,200,149,1,0,224,22,1,0,1,0,0,0,158,249,146,0,56,126,1,0,160,14,1,0,1,0,0,0,157,249,146,0,32,101,1,0,88,212,3,0,1,0,0,0,192,221,146,0,40,185,3,0,16,17,8,0,1,0,0,0,122,241,146,0,224,12,8,0,72,65,1,0,9,0,0,0,112,7,147,0,32,58,1,0,48,50,1,0,9,0,0,0,113,7,147,0,32,58,1,0,224,41,1,0,9,0,0,0,114,7,147,0,32,58,1,0,112,122,102,117,46,48,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,239,98,110,52,1,0,16,1,112,122,102,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,226,73,6,184,1,0,16,1,112,122,102,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,203,129,72,45,5,0,32,0,112,122,102,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,190,209,15,75,5,0,32,0,112,122,102,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,51,172,58,228,5,0,32,0,112,122,102,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,241,111,83,127,5,0,32,0,112,122,102,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,163,178,15,96,10,0,16,1,112,122,102,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,224,118,96,73,10,0,16,1,112,122,102,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,67,39,68,120,12,0,64,0,112,122,102,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,123,44,157,57,12,0,64,0,115,112,101,95,48,54,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,251,6,241,26,0,0,16,1,115,112,101,95,48,55,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,84,95,139,32,0,0,16,1,115,112,101,95,48,56,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,222,58,192,43,0,0,16,1,115,112,101,95,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,210,223,201,99,0,0,32,0,48,51,46,102,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,193,139,226,58,0,0,32,0,115,112,101,95,48,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,91,34,123,157,0,0,32,0,48,53,46,103,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,132,8,6,74,0,0,32,0,115,112,106,49,48,95,50,107,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,222,10,221,238,0,0,32,0,115,112,106,48,57,95,49,107,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,117,27,180,4,0,0,32,0,115,112,101,95,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,51,193,25,45,0,0,64,0,101,101,112,114,111,109,45,115,112,97,110,103,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,145,18,174,222,0,0,16,0,101,112,114,45,49,50,53,54,49,99,46,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,254,243,176,165,1,0,16,1,101,112,114,45,49,50,53,54,50,99,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,244,85,158,121,1,0,16,1,101,112,114,45,49,50,53,55,52,97,46,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,139,195,181,248,9,0,16,1,101,112,114,45,49,50,53,55,53,97,46,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,23,29,139,36,9,0,16,1,101,112,114,45,49,50,52,50,57,46,49,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,20,230,81,88,2,0,32,0,101,112,114,45,49,50,52,51,48,46,49,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,52,1,224,5,2,0,32,0,101,112,114,45,49,50,52,51,49,46,49,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,74,47,87,53,2,0,32,0,109,112,114,45,49,50,52,50,53,46,57,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,21,42,191,20,3,0,32,0,109,112,114,45,49,50,52,50,54,46,57,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,192,13,182,40,3,0,32,0,109,112,114,45,49,50,52,50,55,46,57,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,40,121,54,10,3,0,32,0,109,112,114,45,49,50,52,50,56,46,49,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,213,10,168,239,3,0,32,0,109,112,114,45,49,50,52,50,49,46,57,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,64,97,244,37,3,0,32,0,109,112,114,45,49,50,52,50,50,46,57,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,246,200,81,203,3,0,32,0,109,112,114,45,49,50,52,50,51,46,57,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,142,129,233,11,3,0,32,0,109,112,114,45,49,50,52,50,52,46,49,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,252,13,224,12,3,0,32,0,109,112,114,45,49,50,52,49,55,46,57,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,191,234,6,168,3,0,32,0,109,112,114,45,49,50,52,49,56,46,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,43,15,26,237,3,0,32,0,109,112,114,45,49,50,52,49,57,46,49,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,203,104,69,206,3,0,32,0,109,112,114,45,49,50,52,50,48,46,49,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,235,66,148,103,3,0,32,0,101,112,114,45,49,50,54,48,57,46,57,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,47,129,103,168,3,0,32,0,101,112,114,45,49,50,54,49,48,46,57,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,23,148,185,83,3,0,32,0,101,112,114,45,49,50,54,49,49,46,49,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,176,106,92,189,3,0,32,0,101,112,114,45,49,50,54,49,50,46,49,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,144,232,134,172,3,0,32,0,101,112,114,45,49,50,52,51,54,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,10,95,236,22,4,0,16,1,101,112,114,45,49,50,53,51,53,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,151,53,69,128,12,0,16,1,101,112,114,45,49,50,53,56,55,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,139,100,254,42,13,0,16,1,101,112,114,45,49,50,53,48,53,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,138,120,32,80,14,0,16,1,109,112,114,45,49,50,52,51,55,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,18,231,199,161,11,0,64,0,109,112,114,45,49,50,52,51,56,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,107,212,115,101,11,0,64,0,109,112,114,45,49,50,52,51,57,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,229,109,191,19,11,0,64,0,109,112,114,45,49,50,52,51,55,46,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,18,231,199,161,15,0,64,0,109,112,114,45,49,50,52,51,56,46,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,107,212,115,101,15,0,64,0,109,112,114,45,49,50,52,51,57,46,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,229,109,191,19,15,0,64,0,51,49,55,45,48,49,50,53,97,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,32,177,205,62,5,0,16,1,101,112,114,45,49,50,52,51,50,98,46,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,177,157,162,193,1,0,16,1,101,112,114,45,49,50,52,51,51,98,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,177,158,25,151,1,0,16,1,101,112,114,45,49,50,52,52,49,97,46,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,193,153,149,44,9,0,16,1,101,112,114,45,49,50,52,52,50,97,46,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,22,236,165,119,9,0,16,1,101,112,114,45,49,50,52,50,57,46,49,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,20,230,81,88,2,0,32,0,101,112,114,45,49,50,52,51,48,46,49,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,52,1,224,5,2,0,32,0,101,112,114,45,49,50,52,51,49,46,49,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,74,47,87,53,2,0,32,0,109,112,114,45,49,50,52,50,53,46,57,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,21,42,191,20,3,0,32,0,109,112,114,45,49,50,52,50,54,46,57,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,192,13,182,40,3,0,32,0,109,112,114,45,49,50,52,50,55,46,57,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,40,121,54,10,3,0,32,0,109,112,114,45,49,50,52,50,56,46,49,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,213,10,168,239,3,0,32,0,109,112,114,45,49,50,52,50,49,46,57,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,64,97,244,37,3,0,32,0,109,112,114,45,49,50,52,50,50,46,57,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,246,200,81,203,3,0,32,0,109,112,114,45,49,50,52,50,51,46,57,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,142,129,233,11,3,0,32,0,109,112,114,45,49,50,52,50,52,46,49,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,252,13,224,12,3,0,32,0,109,112,114,45,49,50,52,49,55,46,57,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,191,234,6,168,3,0,32,0,109,112,114,45,49,50,52,49,56,46,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,43,15,26,237,3,0,32,0,109,112,114,45,49,50,52,49,57,46,49,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,203,104,69,206,3,0,32,0,109,112,114,45,49,50,52,50,48,46,49,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,235,66,148,103,3,0,32,0,101,112,114,45,49,50,52,49,51,46,57,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,223,147,22,47,3,0,32,0,101,112,114,45,49,50,52,49,52,46,57,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,69,61,143,199,3,0,32,0,101,112,114,45,49,50,52,49,53,46,49,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,237,233,128,96,3,0,32,0,101,112,114,45,49,50,52,49,54,46,49,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,105,39,31,111,3,0,32,0,101,112,114,45,49,50,52,51,54,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,10,95,236,22,4,0,16,1,101,112,114,45,49,50,53,51,53,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,151,53,69,128,12,0,16,1,101,112,114,45,49,50,53,56,55,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,139,100,254,42,13,0,16,1,101,112,114,45,49,50,53,48,53,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,138,120,32,80,14,0,16,1,109,112,114,45,49,50,52,51,55,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,18,231,199,161,11,0,64,0,109,112,114,45,49,50,52,51,56,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,107,212,115,101,11,0,64,0,109,112,114,45,49,50,52,51,57,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,229,109,191,19,11,0,64,0,109,112,114,45,49,50,52,51,55,46,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,18,231,199,161,15,0,64,0,109,112,114,45,49,50,52,51,56,46,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,107,212,115,101,15,0,64,0,109,112,114,45,49,50,52,51,57,46,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,229,109,191,19,15,0,64,0,51,49,55,45,48,49,50,52,97,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,22,138,42,2,5,0,16,1,101,112,114,45,49,50,53,54,51,97,46,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,14,177,100,46,1,0,16,1,101,112,114,45,49,50,53,54,52,97,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,231,163,171,91,1,0,16,1,101,112,114,45,49,50,53,55,54,97,46,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,193,153,149,44,9,0,16,1,101,112,114,45,49,50,53,55,55,97,46,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,11,165,249,171,9,0,16,1,101,112,114,45,49,50,52,50,57,46,49,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,20,230,81,88,2,0,32,0,101,112,114,45,49,50,52,51,48,46,49,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,52,1,224,5,2,0,32,0,101,112,114,45,49,50,52,51,49,46,49,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,74,47,87,53,2,0,32,0,109,112,114,45,49,50,52,50,53,46,57,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,21,42,191,20,3,0,32,0,109,112,114,45,49,50,52,50,54,46,57,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,192,13,182,40,3,0,32,0,109,112,114,45,49,50,52,50,55,46,57,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,40,121,54,10,3,0,32,0,109,112,114,45,49,50,52,50,56,46,49,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,213,10,168,239,3,0,32,0,109,112,114,45,49,50,52,50,49,46,57,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,64,97,244,37,3,0,32,0,109,112,114,45,49,50,52,50,50,46,57,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,246,200,81,203,3,0,32,0,109,112,114,45,49,50,52,50,51,46,57,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,142,129,233,11,3,0,32,0,109,112,114,45,49,50,52,50,52,46,49,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,252,13,224,12,3,0,32,0,109,112,114,45,49,50,52,49,55,46,57,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,191,234,6,168,3,0,32,0,109,112,114,45,49,50,52,49,56,46,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,43,15,26,237,3,0,32,0,109,112,114,45,49,50,52,49,57,46,49,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,203,104,69,206,3,0,32,0,109,112,114,45,49,50,52,50,48,46,49,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,235,66,148,103,3,0,32,0,101,112,114,45,49,50,54,48,57,46,57,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,47,129,103,168,3,0,32,0,101,112,114,45,49,50,54,49,48,46,57,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,23,148,185,83,3,0,32,0,101,112,114,45,49,50,54,49,49,46,49,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,176,106,92,189,3,0,32,0,101,112,114,45,49,50,54,49,50,46,49,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,144,232,134,172,3,0,32,0,101,112,114,45,49,50,52,51,54,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,10,95,236,22,4,0,16,1,101,112,114,45,49,50,53,51,53,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,151,53,69,128,12,0,16,1,101,112,114,45,49,50,53,56,55,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,139,100,254,42,13,0,16,1,101,112,114,45,49,50,53,48,53,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,138,120,32,80,14,0,16,1,109,112,114,45,49,50,52,51,55,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,18,231,199,161,11,0,64,0,109,112,114,45,49,50,52,51,56,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,107,212,115,101,11,0,64,0,109,112,114,45,49,50,52,51,57,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,229,109,191,19,11,0,64,0,109,112,114,45,49,50,52,51,55,46,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,18,231,199,161,15,0,64,0,109,112,114,45,49,50,52,51,56,46,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,107,212,115,101,15,0,64,0,109,112,114,45,49,50,52,51,57,46,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,229,109,191,19,15,0,64,0,51,49,55,45,48,49,50,54,97,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,130,25,188,42,5,0,16,1,101,112,114,45,49,50,53,54,51,46,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,174,37,115,109,1,0,16,1,101,112,114,45,49,50,53,54,52,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,33,249,251,173,1,0,16,1,101,112,114,45,49,50,53,55,54,46,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,38,107,38,35,9,0,16,1,101,112,114,45,49,50,53,55,55,46,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,17,50,181,213,9,0,16,1,101,112,114,45,49,50,52,50,57,46,49,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,20,230,81,88,2,0,32,0,101,112,114,45,49,50,52,51,48,46,49,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,52,1,224,5,2,0,32,0,101,112,114,45,49,50,52,51,49,46,49,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,74,47,87,53,2,0,32,0,109,112,114,45,49,50,52,50,53,46,57,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,21,42,191,20,3,0,32,0,109,112,114,45,49,50,52,50,54,46,57,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,192,13,182,40,3,0,32,0,109,112,114,45,49,50,52,50,55,46,57,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,40,121,54,10,3,0,32,0,109,112,114,45,49,50,52,50,56,46,49,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,213,10,168,239,3,0,32,0,109,112,114,45,49,50,52,50,49,46,57,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,64,97,244,37,3,0,32,0,109,112,114,45,49,50,52,50,50,46,57,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,246,200,81,203,3,0,32,0,109,112,114,45,49,50,52,50,51,46,57,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,142,129,233,11,3,0,32,0,109,112,114,45,49,50,52,50,52,46,49,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,252,13,224,12,3,0,32,0,109,112,114,45,49,50,52,49,55,46,57,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,191,234,6,168,3,0,32,0,109,112,114,45,49,50,52,49,56,46,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,43,15,26,237,3,0,32,0,109,112,114,45,49,50,52,49,57,46,49,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,203,104,69,206,3,0,32,0,109,112,114,45,49,50,52,50,48,46,49,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,235,66,148,103,3,0,32,0,101,112,114,45,49,50,52,49,51,46,57,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,223,147,22,47,3,0,32,0,101,112,114,45,49,50,52,49,52,46,57,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,69,61,143,199,3,0,32,0,101,112,114,45,49,50,52,49,53,46,49,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,237,233,128,96,3,0,32,0,101,112,114,45,49,50,52,49,54,46,49,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,105,39,31,111,3,0,32,0,101,112,114,45,49,50,52,51,54,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,10,95,236,22,4,0,16,1,101,112,114,45,49,50,53,51,53,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,151,53,69,128,12,0,16,1,101,112,114,45,49,50,53,56,55,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,139,100,254,42,13,0,16,1,101,112,114,45,49,50,53,48,53,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,138,120,32,80,14,0,16,1,109,112,114,45,49,50,52,51,55,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,18,231,199,161,11,0,64,0,109,112,114,45,49,50,52,51,56,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,107,212,115,101,11,0,64,0,109,112,114,45,49,50,52,51,57,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,229,109,191,19,11,0,64,0,109,112,114,45,49,50,52,51,55,46,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,18,231,199,161,15,0,64,0,109,112,114,45,49,50,52,51,56,46,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,107,212,115,101,15,0,64,0,109,112,114,45,49,50,52,51,57,46,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,229,109,191,19,15,0,64,0,51,49,55,45,48,49,50,54,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,150,121,145,77,5,0,16,1,115,103,121,120,122,95,112,114,103,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,131,156,66,149,1,0,16,1,115,103,121,120,122,95,112,114,103,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,41,25,81,216,1,0,16,1,115,103,121,120,122,95,103,102,120,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,246,233,11,166,4,0,32,0,115,103,121,120,122,95,103,102,120,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,72,208,217,106,4,0,32,0,115,103,121,120,122,95,115,110,100,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,111,55,12,33,3,0,16,0,115,103,121,120,122,95,115,110,100,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,242,192,90,193,5,0,64,0,112,99,102,117,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,102,133,46,172,1,0,16,1,112,99,102,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,150,76,49,244,1,0,16,1,112,99,102,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,85,86,33,1,0,16,1,112,99,102,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,234,19,111,234,1,0,16,1])
.concat([112,99,102,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,234,213,198,90,1,0,16,1,112,99,102,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,185,42,215,34,5,0,32,0,112,99,102,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,60,129,164,22,5,0,32,0,112,99,102,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,53,224,151,16,5,0,32,0,112,99,102,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,116,216,98,211,5,0,32,0,112,99,102,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,124,137,131,3,5,0,32,0,112,99,102,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,132,16,249,118,5,0,32,0,112,99,102,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,84,55,108,117,5,0,32,0,112,99,102,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,125,39,201,158,5,0,32,0,112,99,102,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,51,95,78,37,10,0,16,1,112,99,102,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,249,244,2,105,10,0,16,1,112,99,102,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,5,160,222,165,12,0,64,0,112,99,102,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,254,53,226,76,12,0,64,0,115,102,122,99,104,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,63,116,64,17,2,0,16,1,115,102,122,97,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,128,36,155,141,2,0,16,1,115,102,122,99,104,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,93,34,53,84,2,0,16,1,115,102,122,97,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,56,143,110,128,2,0,16,1,115,102,122,95,48,49,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,98,62,213,13,4,0,32,0,115,102,122,95,48,50,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,63,30,195,148,4,0,32,0,115,102,122,95,48,51,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,133,172,132,149,4,0,32,0,115,102,122,95,48,52,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,76,98,131,185,4,0,32,0,115,102,122,95,48,53,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,69,182,71,43,4,0,32,0,115,102,122,95,48,54,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,177,159,253,116,4,0,32,0,115,102,122,95,48,55,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,77,115,44,187,4,0,32,0,115,102,122,95,48,56,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,104,120,79,69,4,0,32,0,115,102,122,95,49,48,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,94,103,125,42,4,0,32,0,115,102,122,95,49,49,46,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,200,70,85,227,4,0,32,0,115,102,122,95,49,50,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,58,105,34,241,4,0,32,0,115,102,122,95,49,51,46,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,200,66,249,124,4,0,32,0,115,102,122,95,49,52,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,129,140,3,9,4,0,32,0,115,102,122,95,49,53,46,56,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,145,115,161,26,4,0,32,0,115,102,122,95,49,54,46,57,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,214,171,165,25,4,0,32,0,115,102,122,95,49,55,46,49,48,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,115,59,139,36,4,0,32,0,115,102,122,95,48,57,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,139,98,114,199,3,0,16,0,115,102,122,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,45,43,2,97,5,0,64,0,115,102,122,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,213,134,88,59,5,0,64,0,115,122,51,106,46,48,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,81,74,223,202,1,0,16,1,115,122,51,106,46,48,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,40,18,179,252,1,0,16,1,115,122,51,46,48,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,64,10,253,87,1,0,16,1,115,122,51,46,48,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,139,95,48,246,1,0,16,1,115,122,51,46,48,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,111,15,171,110,1,0,16,1,115,122,51,46,48,56,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,59,74,12,145,1,0,16,1,115,122,51,46,48,57,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,153,81,158,178,1,0,16,1,115,122,51,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,255,178,222,1,0,16,1,115,122,51,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,217,96,122,15,5,0,32,0,115,122,51,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,65,55,147,142,5,0,32,0,115,122,51,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,71,129,233,214,5,0,32,0,115,122,51,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,138,114,26,243,5,0,32,0,115,122,51,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,151,130,249,95,5,0,32,0,115,122,51,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,238,189,181,82,5,0,32,0,115,122,51,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,213,30,99,64,5,0,32,0,115,122,51,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,180,9,52,118,5,0,32,0,115,122,51,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,132,0,129,222,10,0,16,1,115,122,51,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,196,93,68,114,10,0,16,1,115,122,51,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,209,238,137,28,12,0,64,0,115,122,51,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,58,177,146,243,12,0,64,0,115,122,51,97,46,48,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,214,64,225,215,1,0,16,1,115,122,51,97,46,48,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,162,105,104,224,1,0,16,1,115,122,51,46,48,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,64,10,253,87,1,0,16,1,115,122,51,46,48,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,139,95,48,246,1,0,16,1,115,122,51,46,48,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,111,15,171,110,1,0,16,1,115,122,51,46,48,56,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,59,74,12,145,1,0,16,1,115,122,51,46,48,57,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,153,81,158,178,1,0,16,1,115,122,51,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,255,178,222,1,0,16,1,115,122,51,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,217,96,122,15,5,0,32,0,115,122,51,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,65,55,147,142,5,0,32,0,115,122,51,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,71,129,233,214,5,0,32,0,115,122,51,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,138,114,26,243,5,0,32,0,115,122,51,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,151,130,249,95,5,0,32,0,115,122,51,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,238,189,181,82,5,0,32,0,115,122,51,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,213,30,99,64,5,0,32,0,115,122,51,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,180,9,52,118,5,0,32,0,115,122,51,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,132,0,129,222,10,0,16,1,115,122,51,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,196,93,68,114,10,0,16,1,115,122,51,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,209,238,137,28,12,0,64,0,115,122,51,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,58,177,146,243,12,0,64,0,115,122,50,110,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,65,71,146,88,1,0,16,1,115,122,50,110,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,197,23,42,89,1,0,16,1,115,122,50,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,124,42,68,75,1,0,16,1,115,122,50,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,192,73,29,91,1,0,16,1,115,122,50,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,70,66,24,142,1,0,16,1,115,122,50,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,93,88,232,15,1,0,16,1,115,122,50,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,34,31,31,77,5,0,32,0,115,122,50,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,128,166,206,25,5,0,32,0,115,122,50,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,136,69,27,224,5,0,32,0,115,122,50,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,100,218,238,15,5,0,32,0,115,122,50,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,170,198,96,5,5,0,32,0,115,122,50,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,135,15,148,174,5,0,32,0,115,122,50,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,188,200,195,75,5,0,32,0,115,122,50,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,192,116,230,57,5,0,32,0,115,122,50,46,48,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,207,35,195,27,10,0,16,1,115,122,50,46,48,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,19,80,106,186,10,0,16,1,115,122,50,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,1,166,71,170,12,0,64,0,115,122,50,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,83,188,55,34,12,0,64,0,115,122,50,106,46,48,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,133,46,30,62,1,0,16,1,115,122,50,106,46,48,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,69,108,61,245,1,0,16,1,115,122,50,106,46,48,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,86,65,34,221,1,0,16,1,115,122,50,106,46,48,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,166,117,90,164,1,0,16,1,115,122,50,106,46,48,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,56,240,82,99,1,0,16,1,115,122,50,106,46,48,56,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,110,182,146,1,0,16,1,115,122,50,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,34,31,31,77,5,0,32,0,115,122,50,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,128,166,206,25,5,0,32,0,115,122,50,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,136,69,27,224,5,0,32,0,115,122,50,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,100,218,238,15,5,0,32,0,115,122,50,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,170,198,96,5,5,0,32,0,115,122,50,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,135,15,148,174,5,0,32,0,115,122,50,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,188,200,195,75,5,0,32,0,115,122,50,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,192,116,230,57,5,0,32,0,115,122,50,46,48,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,207,35,195,27,10,0,16,1,115,122,50,46,48,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,19,80,106,186,10,0,16,1,115,122,50,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,1,166,71,170,12,0,64,0,115,122,50,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,83,188,55,34,12,0,64,0,115,122,50,104,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,91,223,237,191,1,0,16,1,115,122,50,104,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,251,9,80,234,1,0,16,1,115,122,50,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,124,42,68,75,1,0,16,1,115,122,50,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,192,73,29,91,1,0,16,1,115,122,50,104,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,198,138,126,148,1,0,16,1,115,122,50,104,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,110,182,146,1,0,16,1,115,122,50,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,34,31,31,77,5,0,32,0,115,122,50,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,128,166,206,25,5,0,32,0,115,122,50,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,136,69,27,224,5,0,32,0,115,122,50,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,100,218,238,15,5,0,32,0,115,122,50,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,170,198,96,5,5,0,32,0,115,122,50,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,135,15,148,174,5,0,32,0,115,122,50,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,188,200,195,75,5,0,32,0,115,122,50,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,192,116,230,57,5,0,32,0,115,122,50,46,48,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,207,35,195,27,10,0,16,1,115,122,50,46,48,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,19,80,106,186,10,0,16,1,115,122,50,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,1,166,71,170,12,0,64,0,115,122,50,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,83,188,55,34,12,0,64,0,115,122,50,98,46,48,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,18,40,193,26,1,0,16,1,115,122,50,98,46,48,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,104,175,255,228,1,0,16,1,115,122,50,98,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,86,65,34,221,1,0,16,1,115,122,50,98,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,166,117,90,164,1,0,16,1,115,122,50,98,46,48,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,213,25,125,1,0,16,1,115,122,50,98,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,110,182,146,1,0,16,1,115,122,50,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,34,31,31,77,5,0,32,0,115,122,50,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,128,166,206,25,5,0,32,0,115,122,50,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,136,69,27,224,5,0,32,0,115,122,50,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,100,218,238,15,5,0,32,0,115,122,50,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,170,198,96,5,5,0,32,0,115,122,50,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,135,15,148,174,5,0,32,0,115,122,50,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,188,200,195,75,5,0,32,0,115,122,50,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,192,116,230,57,5,0,32,0,115,122,50,46,48,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,207,35,195,27,10,0,16,1,115,122,50,46,48,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,19,80,106,186,10,0,16,1,115,122,50,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,1,166,71,170,12,0,64,0,115,122,50,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,83,188,55,34,12,0,64,0,115,122,50,97,46,48,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,159,9,210,48,1,0,16,1,115,122,50,97,46,48,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,177,77,201,28,1,0,16,1,115,122,50,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,146,233,232,152,1,0,16,1,115,122,50,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,192,73,29,91,1,0,16,1,115,122,50,97,46,48,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,148,36,237,10,1,0,16,1,115,122,50,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,93,88,232,15,1,0,16,1,115,122,50,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,34,31,31,77,5,0,32,0,115,122,50,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,128,166,206,25,5,0,32,0,115,122,50,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,136,69,27,224,5,0,32,0,115,122,50,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,100,218,238,15,5,0,32,0,115,122,50,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,170,198,96,5,5,0,32,0,115,122,50,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,135,15,148,174,5,0,32,0,115,122,50,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,188,200,195,75,5,0,32,0,115,122,50,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,192,116,230,57,5,0,32,0,115,122,50,46,48,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,207,35,195,27,10,0,16,1,115,122,50,46,48,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,19,80,106,186,10,0,16,1,115,122,50,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,1,166,71,170,12,0,64,0,115,122,50,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,83,188,55,34,12,0,64,0,184,40,2,0,1,0,0,0,47,39,216,0,248,191,2,0,56,250,6,0,1,0,0,0,39,39,216,0,184,160,2,0,184,164,8,0,1,0,0,0,46,39,216,0,64,246,1,0,88,149,7,0,1,0,0,0,38,39,216,0,136,224,1,0,56,210,6,0,1,0,0,0,28,39,216,0,192,135,2,0,24,163,6,0,1,0,0,0,30,39,216,0,240,108,2,0,152,122,6,0,1,0,0,0,45,39,216,0,96,82,2,0,192,72,6,0,1,0,0,0,44,39,216,0,32,56,2,0,48,123,2,0,1,0,0,0,43,39,216,0,152,30,2,0,96,69,2,0,1,0,0,0,41,39,216,0,232,10,2,0,176,223,1,0,1,0,0,0,40,39,216,0,72,198,1,0,192,209,1,0,1,0,0,0,24,39,216,0,24,182,1,0,24,198,1,0,1,0,0,0,37,39,216,0,40,167,1,0,120,189,1,0,1,0,0,0,36,39,216,0,200,149,1,0,248,187,8,0,1,0,0,0,35,39,216,0,56,126,1,0,184,179,8,0,1,0,0,0,34,39,216,0,32,101,1,0,88,212,3,0,1,0,0,0,48,38,216,0,40,185,3,0,16,17,8,0,1,0,0,0,42,39,216,0,224,12,8,0,248,5,8,0,9,0,0,0,112,39,216,0,32,58,1,0,144,250,7,0,9,0,0,0,113,39,216,0,32,58,1,0,248,241,7,0,9,0,0,0,114,39,216,0,32,58,1,0,115,102,122,117,100,46,48,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,119,245,47,159,1,0,16,1,115,102,122,46,48,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,229,176,115,139,1,0,16,1,115,102,122,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,77,84,16,8,1,0,16,1,115,102,122,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,56,143,110,128,1,0,16,1,115,102,122,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,179,253,254,144,5,0,32,0,115,102,122,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,72,201,84,83,5,0,32,0,115,102,122,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,144,231,161,65,5,0,32,0,115,102,122,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,152,223,73,165,5,0,32,0,115,102,122,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,125,236,255,255,10,0,16,1,115,102,122,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,8,106,244,69,10,0,16,1,115,102,122,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,205,147,176,196,12,0,64,0,115,102,122,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,180,196,219,139,12,0,64,0,115,102,122,101,46,48,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,52,212,188,253,1,0,16,1,115,102,122,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,8,0,48,109,67,12,1,0,16,1,115,102,122,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,18,54,54,31,1,0,16,1,115,102,122,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,56,143,110,128,1,0,16,1,115,102,122,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,179,253,254,144,5,0,32,0,115,102,122,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,72,201,84,83,5,0,32,0,115,102,122,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,144,231,161,65,5,0,32,0,115,102,122,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,152,223,73,165,5,0,32,0,115,102,122,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,125,236,255,255,10,0,16,1,115,102,122,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,8,106,244,69,10,0,16,1,115,102,122,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,205,147,176,196,12,0,64,0,115,102,122,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,180,196,219,139,12,0,64,0,115,102,122,101,46,48,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,142,112,245,43,1,0,16,1,115,102,122,46,48,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,165,233,153,95,1,0,16,1,115,102,122,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,77,84,16,8,1,0,16,1,115,102,122,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,56,143,110,128,1,0,16,1,115,102,122,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,179,253,254,144,5,0,32,0,115,102,122,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,72,201,84,83,5,0,32,0,115,102,122,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,144,231,161,65,5,0,32,0,115,102,122,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,152,223,73,165,5,0,32,0,115,102,122,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,125,236,255,255,10,0,16,1,115,102,122,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,8,106,244,69,10,0,16,1,115,102,122,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,205,147,176,196,12,0,64,0,115,102,122,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,180,196,219,139,12,0,64,0,115,102,122,101,46,48,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,215,157,182,161,1,0,16,1,115,102,122,101,46,48,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,213,172,144,187,1,0,16,1,115,102,122,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,77,84,16,8,1,0,16,1,115,102,122,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,56,143,110,128,1,0,16,1,115,102,122,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,179,253,254,144,5,0,32,0,115,102,122,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,72,201,84,83,5,0,32,0,115,102,122,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,144,231,161,65,5,0,32,0,115,102,122,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,152,223,73,165,5,0,32,0,115,102,122,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,125,236,255,255,10,0,16,1,115,102,122,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,8,106,244,69,10,0,16,1,115,102,122,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,205,147,176,196,12,0,64,0,115,102,122,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,180,196,219,139,12,0,64,0,115,122,51,117,46,48,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,46,218,7,224,1,0,16,1,115,122,51,117,46,48,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,231,240,120,95,1,0,16,1,115,122,51,46,48,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,64,10,253,87,1,0,16,1,115,122,51,46,48,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,139,95,48,246,1,0,16,1,115,122,51,46,48,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,111,15,171,110,1,0,16,1,115,122,51,46,48,56,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,59,74,12,145,1,0,16,1,115,122,51,46,48,57,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,153,81,158,178,1,0,16,1,115,122,51,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,255,178,222,1,0,16,1,115,122,51,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,217,96,122,15,5,0,32,0,115,122,51,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,65,55,147,142,5,0,32,0,115,122,51,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,71,129,233,214,5,0,32,0,115,122,51,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,138,114,26,243,5,0,32,0,115,122,51,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,151,130,249,95,5,0,32,0,115,122,51,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,238,189,181,82,5,0,32,0,115,122,51,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,213,30,99,64,5,0,32,0,115,122,51,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,180,9,52,118,5,0,32,0,115,122,51,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,132,0,129,222,10,0,16,1,115,122,51,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,196,93,68,114,10,0,16,1,115,122,51,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,209,238,137,28,12,0,64,0,115,122,51,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,58,177,146,243,12,0,64,0,115,122,51,104,46,48,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,163,99,181,179,1,0,16,1,115,122,51,104,46,48,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,31,137,71,1,0,16,1,115,122,51,46,48,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,64,10,253,87,1,0,16,1,115,122,51,46,48,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,139,95,48,246,1,0,16,1,115,122,51,46,48,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,111,15,171,110,1,0,16,1,115,122,51,46,48,56,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,59,74,12,145,1,0,16,1,115,122,51,46,48,57,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,153,81,158,178,1,0,16,1,115,122,51,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,255,178,222,1,0,16,1,115,122,51,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,217,96,122,15,5,0,32,0,115,122,51,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,65,55,147,142,5,0,32,0,115,122,51,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,71,129,233,214,5,0,32,0,115,122,51,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,138,114,26,243,5,0,32,0,115,122,51,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,151,130,249,95,5,0,32,0,115,122,51,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,238,189,181,82,5,0,32,0,115,122,51,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,213,30,99,64,5,0,32,0,115,122,51,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,180,9,52,118,5,0,32,0,115,122,51,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,132,0,129,222,10,0,16,1,115,122,51,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,196,93,68,114,10,0,16,1,115,122,51,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,209,238,137,28,12,0,64,0,115,122,51,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,58,177,146,243,12,0,64,0,115,122,51,98,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,77,155,108,4,1,0,16,1,115,122,51,98,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,25,25,33,218,1,0,16,1,115,122,51,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,138,81,33,155,1,0,16,1,115,122,51,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,167,195,166,231,1,0,16,1,115,122,51,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,253,12,76,236,1,0,16,1,115,122,51,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,64,114,126,92,1,0,16,1,115,122,51,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,83,149,88,197,1,0,16,1,115,122,51,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,114,113,169,1,0,16,1,115,122,51,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,217,96,122,15,5,0,32,0,115,122,51,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,65,55,147,142,5,0,32,0,115,122,51,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,71,129,233,214,5,0,32,0,115,122,51,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,138,114,26,243,5,0,32,0,115,122,51,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,151,130,249,95,5,0,32,0,115,122,51,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,238,189,181,82,5,0,32,0,115,122,51,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,213,30,99,64,5,0,32,0,115,122,51,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,180,9,52,118,5,0,32,0,115,122,51,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,132,0,129,222,10,0,16,1,115,122,51,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,196,93,68,114,10,0,16,1,115,122,51,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,209,238,137,28,12,0,64,0,115,122,51,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,58,177,146,243,12,0,64,0,115,122,50,117,46,48,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,79,80,62,208,1,0,16,1,115,122,50,117,46,48,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,195,233,224,250,1,0,16,1,115,122,50,117,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,88,215,45,208,1,0,16,1,115,122,50,117,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,99,235,200,197,1,0,16,1,115,122,50,117,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,197,28,224,93,1,0,16,1,115,122,50,117,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,86,29,161,190,1,0,16,1,115,122,50,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,34,31,31,77,5,0,32,0,115,122,50,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,128,166,206,25,5,0,32,0,115,122,50,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,136,69,27,224,5,0,32,0,115,122,50,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,100,218,238,15,5,0,32,0,115,122,50,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,170,198,96,5,5,0,32,0,115,122,50,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,135,15,148,174,5,0,32,0,115,122,50,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,188,200,195,75,5,0,32,0,115,122,50,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,192,116,230,57,5,0,32,0,115,122,50,46,48,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,207,35,195,27,10,0,16,1,115,122,50,46,48,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,19,80,106,186,10,0,16,1,115,122,50,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,1,166,71,170,12,0,64,0,115,122,50,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,83,188,55,34,12,0,64,0,115,102,50,117,95,51,48,107,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,108,7,102,143,1,0,16,1,115,102,50,117,95,51,55,107,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,131,106,31,78,1,0,16,1,115,102,50,117,95,51,49,107,46,49,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,96,159,248,249,1,0,16,1,115,102,50,117,95,51,56,107,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,90,168,224,108,1,0,16,1,115,102,50,117,95,50,56,107,46,57,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,49,143,149,142,1,0,16,1,115,102,50,117,95,51,53,107,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,173,111,231,252,1,0,16,1,115,102,50,117,95,50,57,97,46,49,48,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,21,243,74,187,1,0,16,1,115,102,50,117,95,51,54,97,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,235,19,42,192,1,0,16,1,115,102,50,45,53,109,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,142,204,201,34,4,0,32,0,115,102,50,45,55,109,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,232,59,33,87,4,0,32,0,115,102,50,45,49,109,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,79,155,82,186,4,0,32,0,115,102,50,45,51,109,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,51,27,75,4,0,32,0,115,102,50,45,54,109,46,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,41,34,126,44,4,0,32,0,115,102,50,45,56,109,46,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,23,143,84,181,4,0,32,0,115,102,50,45,50,109,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,18,67,184,20,4,0,32,0,115,102,50,45,52,109,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,154,216,156,94,4,0,32,0,115,102,50,45,49,51,109,46,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,88,250,75,153,4,0,32,0,115,102,50,45,49,53,109,46,54,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,157,173,102,62,4,0,32,0,115,102,50,45,57,109,46,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,250,190,193,4,0,32,0,115,102,50,45,49,49,109,46,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,49,200,39,6,4,0,32,0,115,102,50,95,48,57,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,27,58,130,164,3,0,16,0,115,102,50,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,32,22,127,5,0,64,0,115,102,50,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,229,173,190,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,115,116,102,50,57,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,197,9,51,4,0,0,0,8,105,111,98,49,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,99,54,51,50,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,112,146,189,15,0,0,0,8,115,102,50,117,95,51,48,105,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,51,238,57,254,1,0,16,1,115,102,50,117,95,51,55,105,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,221,7,247,157,1,0,16,1,115,102,50,117,95,51,49,105,46,49,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,1,163,160,105,1,0,16,1,115,102,50,117,95,51,56,105,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,175,109,180,76,1,0,16,1,115,102,50,117,95,50,56,105,46,57,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,76,190,128,21,1,0,16,1,115,102,50,117,95,51,53,105,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,133,209,104,20,1,0,16,1,115,102,50,95,50,57,98,46,49,48,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,21,243,74,187,1,0,16,1,115,102,50,95,51,54,98,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,235,19,42,192,1,0,16,1,115,102,50,45,53,109,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,142,204,201,34,4,0,32,0,115,102,50,45,55,109,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,232,59,33,87,4,0,32,0,115,102,50,45,49,109,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,79,155,82,186,4,0,32,0,115,102,50,45,51,109,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,51,27,75,4,0,32,0,115,102,50,45,54,109,46,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,41,34,126,44,4,0,32,0,115,102,50,45,56,109,46,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,23,143,84,181,4,0,32,0,115,102,50,45,50,109,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,18,67,184,20,4,0,32,0,115,102,50,45,52,109,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,154,216,156,94,4,0,32,0,115,102,50,45,49,51,109,46,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,88,250,75,153,4,0,32,0,115,102,50,45,49,53,109,46,54,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,157,173,102,62,4,0,32,0,115,102,50,45,57,109,46,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,250,190,193,4,0,32,0,115,102,50,45,49,49,109,46,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,49,200,39,6,4,0,32,0,115,102,50,95,57,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,27,58,130,164,3,0,16,0,115,102,50,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,32,22,127,5,0,64,0,115,102,50,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,229,173,190,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,115,116,102,50,57,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,197,9,51,4,0,0,0,8,105,111,98,49,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,99,54,51,50,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,112,146,189,15,0,0,0,8,115,102,50,117,95,51,48,103,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,51,238,57,254,1,0,16,1,115,102,50,117,95,51,55,103,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,231,202,134,88,1,0,16,1,115,102,50,117,95,51,49,103,46,49,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,1,163,160,105,1,0,16,1,115,102,50,117,95,51,56,103,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,112,219,34,94,1,0,16,1,115,102,50,117,95,50,56,103,46,57,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,229,241,249,139,1,0,16,1,115,102,50,117,95,51,53,103,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,52,249,110,98,1,0,16,1,115,102,50,95,50,57,98,46,49,48,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,21,243,74,187,1,0,16,1,115,102,50,95,51,54,98,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,235,19,42,192,1,0,16,1,115,102,50,45,53,109,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,142,204,201,34,4,0,32,0,115,102,50,45,55,109,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,232,59,33,87,4,0,32,0,115,102,50,45,49,109,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,79,155,82,186,4,0,32,0,115,102,50,45,51,109,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,51,27,75,4,0,32,0,115,102,50,45,54,109,46,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,41,34,126,44,4,0,32,0,115,102,50,45,56,109,46,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,23,143,84,181,4,0,32,0,115,102,50,45,50,109,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,18,67,184,20,4,0,32,0,115,102,50,45,52,109,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,154,216,156,94,4,0,32,0,115,102,50,45,49,51,109,46,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,88,250,75,153,4,0,32,0,115,102,50,45,49,53,109,46,54,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,157,173,102,62,4,0,32,0,115,102,50,45,57,109,46,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,250,190,193,4,0,32,0,115,102,50,45,49,49,109,46,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,49,200,39,6,4,0,32,0,115,102,50,95,57,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,27,58,130,164,3,0,16,0,115,102,50,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,32,22,127,5,0,64,0,115,102,50,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,229,173,190,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,115,116,102,50,57,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,197,9,51,4,0,0,0,8,105,111,98,49,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,99,54,51,50,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,112,146,189,15,0,0,0,8,115,102,50,117,95,51,48,102,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,51,238,57,254,1,0,16,1,115,102,50,117,95,51,55,102,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,136,115,158,22,1,0,16,1,115,102,50,117,95,51,49,102,46,49,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,1,163,160,105,1,0,16,1,115,102,50,117,95,51,56,102,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,226,228,16,21,1,0,16,1,115,102,50,117,95,50,56,102,46,57,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,91,23,216,172,1,0,16,1,115,102,50,117,95,51,53,102,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,209,11,168,192,1,0,16,1,115,102,50,95,50,57,98,46,49,48,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,21,243,74,187,1,0,16,1,115,102,50,95,51,54,98,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,235,19,42,192,1,0,16,1,115,102,50,45,53,109,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,142,204,201,34,4,0,32,0,115,102,50,45,55,109,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,232,59,33,87,4,0,32,0,115,102,50,45,49,109,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,79,155,82,186,4,0,32,0,115,102,50,45,51,109,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,51,27,75,4,0,32,0,115,102,50,45,54,109,46,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,41,34,126,44,4,0,32,0,115,102,50,45,56,109,46,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,23,143,84,181,4,0,32,0,115,102,50,45,50,109,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,18,67,184,20,4,0,32,0,115,102,50,45,52,109,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,154,216,156,94,4,0,32,0,115,102,50,45,49,51,109,46,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,88,250,75,153,4,0,32,0,115,102,50,45,49,53,109,46,54,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,157,173,102,62,4,0,32,0,115,102,50,45,57,109,46,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,250,190,193,4,0,32,0,115,102,50,45,49,49,109,46,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,49,200,39,6,4,0,32,0,115,102,50,95,57,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,27,58,130,164,3,0,16,0,115,102,50,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,32,22,127,5,0,64,0,115,102,50,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,229,173,190,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,115,116,102,50,57,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,197,9,51,4,0,0,0,8,105,111,98,49,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,99,54,51,50,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,112,146,189,15,0,0,0,8,115,102,50,117,95,51,48,101,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,136,208,124,243,1,0,16,1,115,102,50,117,95,51,55,101,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,19,165,97,108,1,0,16,1,115,102,50,117,95,51,49,101,46,49,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,180,113,71,124,1,0,16,1,115,102,50,117,95,51,56,101,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,217,12,189,164,1,0,16,1,115,102,50,117,95,50,56,101,46,57,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,37,86,185,227,1,0,16,1,115,102,50,117,95,51,53,101,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,154,118,72,54,1,0,16,1,115,102,50,95,50,57,98,46,49,48,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,21,243,74,187,1,0,16,1,115,102,50,95,51,54,98,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,235,19,42,192,1,0,16,1,115,102,50,45,53,109,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,142,204,201,34,4,0,32,0,115,102,50,45,55,109,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,232,59,33,87,4,0,32,0,115,102,50,45,49,109,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,79,155,82,186,4,0,32,0,115,102,50,45,51,109,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,51,27,75,4,0,32,0,115,102,50,45,54,109,46,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,41,34,126,44,4,0,32,0,115,102,50,45,56,109,46,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,23,143,84,181,4,0,32,0,115,102,50,45,50,109,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,18,67,184,20,4,0,32,0,115,102,50,45,52,109,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,154,216,156,94,4,0,32,0,115,102,50,45,49,51,109,46,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,88,250,75,153,4,0,32,0,115,102,50,45,49,53,109,46,54,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,157,173,102,62,4,0,32,0,115,102,50,45,57,109,46,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,250,190,193,4,0,32,0,115,102,50,45,49,49,109,46,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,49,200,39,6,4,0,32,0,115,102,50,95,57,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,27,58,130,164,3,0,16,0,115,102,50,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,32,22,127,5,0,64,0,115,102,50,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,229,173,190,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,115,116,102,50,57,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,197,9,51,4,0,0,0,8,105,111,98,50,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,0,0,0,0,0,0,24,99,54,51,50,98,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,112,146,189,15,0,0,0,8,115,102,50,117,95,51,48,100,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,124,101,178,75,1,0,16,1,115,102,50,117,95,51,55,100,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,242,66,59,179,1,0,16,1,115,102,50,117,95,51,49,100,46,49,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,215,103,123,213,1,0,16,1,115,102,50,117,95,51,56,100,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,239,22,137,156,1,0,16,1,115,102,50,117,95,50,56,100,46,57,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,209,25,88,23,1,0,16,1,115,102,50,117,95,51,53,100,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,164,13,6,130,1,0,16,1,115,102,50,95,50,57,98,46,49,48,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,21,243,74,187,1,0,16,1,115,102,50,95,51,54,98,46,49,48,102,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,235,19,42,192,1,0,16,1,115,102,50,45,53,109,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,142,204,201,34,4,0,32,0,115,102,50,45,55,109,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,232,59,33,87,4,0,32,0,115,102,50,45,49,109,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,79,155,82,186,4,0,32,0,115,102,50,45,51,109,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,51,27,75,4,0,32,0,115,102,50,45,54,109,46,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,41,34,126,44,4,0,32,0,115,102,50,45,56,109,46,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,23,143,84,181,4,0,32,0,115,102,50,45,50,109,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,18,67,184,20,4,0,32,0,115,102,50,45,52,109,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,154,216,156,94,4,0,32,0,115,102,50,45,49,51,109,46,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,88,250,75,153,4,0,32,0,115,102,50,45,49,53,109,46,54,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,157,173,102,62,4,0,32,0,115,102,50,45,57,109,46,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,250,190,193,4,0,32,0,115,102,50,45,49,49,109,46,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,49,200,39,6,4,0,32,0,115,102,50,95,57,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,27,58,130,164,3,0,16,0,115,102,50,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,32,22,127,5,0,64,0,115,102,50,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,229,173,190,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,115,116,102,50,57,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,197,9,51,4,0,0,0,8,105,111,98,49,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,99,54,51,50,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,112,146,189,15,0,0,0,8,115,102,50,117,95,51,48,99,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,133,147,181,108,1,0,16,1,115,102,50,117,95,51,55,99,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,120,194,226,50,1,0,16,1,115,102,50,117,95,51,49,99,46,49,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,169,244,255,196,1,0,16,1,115,102,50,117,95,51,56,99,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,14,252,16,130,1,0,16,1,115,102,50,117,95,50,56,99,46,57,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,232,213,221,110,1,0,16,1,115,102,50,117,95,51,53,99,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,76,64,203,107,1,0,16,1,115,102,50,95,50,57,98,46,49,48,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,21,243,74,187,1,0,16,1,115,102,50,95,51,54,98,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,235,19,42,192,1,0,16,1,115,102,50,45,53,109,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,142,204,201,34,4,0,32,0,115,102,50,45,55,109,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,232,59,33,87,4,0,32,0,115,102,50,45,49,109,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,79,155,82,186,4,0,32,0,115,102,50,45,51,109,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,51,27,75,4,0,32,0,115,102,50,45,54,109,46,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,41,34,126,44,4,0,32,0,115,102,50,45,56,109,46,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,23,143,84,181,4,0,32,0,115,102,50,45,50,109,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,18,67,184,20,4,0,32,0,115,102,50,45,52,109,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,154,216,156,94,4,0,32,0,115,102,50,45,49,51,109,46,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,88,250,75,153,4,0,32,0,115,102,50,45,49,53,109,46,54,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,157,173,102,62,4,0,32,0,115,102,50,45,57,109,46,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,250,190,193,4,0,32,0,115,102,50,45,49,49,109,46,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,49,200,39,6,4,0,32,0,115,102,50,95,57,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,27,58,130,164,3,0,16,0,115,102,50,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,32,22,127,5,0,64,0,115,102,50,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,229,173,190,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,115,116,102,50,57,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,197,9,51,4,0,0,0,8,105,111,98,49,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,99,54,51,50,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,112,146,189,15,0,0,0,8,115,102,50,117,95,51,48,98,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,81,112,189,87,1,0,16,1,115,102,50,117,95,51,55,98,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,121,212,84,74,1,0,16,1,115,102,50,117,95,51,49,98,46,49,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,61,20,115,166,1,0,16,1,115,102,50,117,95,51,56,98,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,247,206,44,76,1,0,16,1,115,102,50,117,95,50,56,98,46,57,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,94,149,9,64,1,0,16,1,115,102,50,117,95,51,53,98,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,148,57,31,140,1,0,16,1,115,102,50,95,50,57,98,46,49,48,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,21,243,74,187,1,0,16,1,115,102,50,95,51,54,98,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,235,19,42,192,1,0,16,1,115,102,50,45,53,109,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,142,204,201,34,4,0,32,0,115,102,50,45,55,109,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,232,59,33,87,4,0,32,0,115,102,50,45,49,109,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,79,155,82,186,4,0,32,0,115,102,50,45,51,109,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,51,27,75,4,0,32,0,115,102,50,45,54,109,46,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,41,34,126,44,4,0,32,0,115,102,50,45,56,109,46,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,23,143,84,181,4,0,32,0,115,102,50,45,50,109,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,18,67,184,20,4,0,32,0,115,102,50,45,52,109,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,154,216,156,94,4,0,32,0,115,102,50,45,49,51,109,46,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,88,250,75,153,4,0,32,0,115,102,50,45,49,53,109,46,54,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,157,173,102,62,4,0,32,0,115,102,50,45,57,109,46,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,250,190,193,4,0,32,0,115,102,50,45,49,49,109,46,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,49,200,39,6,4,0,32,0,115,102,50,95,57,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,27,58,130,164,3,0,16,0,115,102,50,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,32,22,127,5,0,64,0,115,102,50,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,229,173,190,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,115,116,102,50,57,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,197,9,51,4,0,0,0,8,105,111,98,49,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,99,54,51,50,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,112,146,189,15,0,0,0,8,115,102,50,117,95,51,48,97,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,97,184,190,8,1,0,16,1,115,102,50,117,95,51,55,97,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,105,141,99,183,1,0,16,1,115,102,50,117,95,51,49,97,46,49,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,224,148,83,13,1,0,16,1,115,102,50,117,95,51,56,97,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,158,167,214,66,1,0,16,1,115,102,50,117,95,50,56,97,46,57,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,92,23,122,56,1,0,16,1,115,102,50,117,95,51,53,97,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,204,173,165,161,1,0,16,1,115,102,50,95,50,57,98,46,49,48,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,21,243,74,187,1,0,16,1,115,102,50,95,51,54,98,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,235,19,42,192,1,0,16,1,115,102,50,45,53,109,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,142,204,201,34,4,0,32,0,115,102,50,45,55,109,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,232,59,33,87,4,0,32,0,115,102,50,45,49,109,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,79,155,82,186,4,0,32,0,115,102,50,45,51,109,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,51,27,75,4,0,32,0,115,102,50,45,54,109,46,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,41,34,126,44,4,0,32,0,115,102,50,45,56,109,46,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,23,143,84,181,4,0,32,0,115,102,50,45,50,109,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,18,67,184,20,4,0,32,0,115,102,50,45,52,109,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,154,216,156,94,4,0,32,0,115,102,50,45,49,51,109,46,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,88,250,75,153,4,0,32,0,115,102,50,45,49,53,109,46,54,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,157,173,102,62,4,0,32,0,115,102,50,45,57,109,46,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,250,190,193,4,0,32,0,115,102,50,45,49,49,109,46,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,49,200,39,6,4,0,32,0,115,102,50,95,57,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,27,58,130,164,3,0,16,0,115,102,50,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,32,22,127,5,0,64,0,115,102,50,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,229,173,190,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,115,116,102,50,57,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,197,9,51,4,0,0,0,8,105,111,98,49,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,99,54,51,50,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,112,146,189,15,0,0,0,8,115,102,50,100,95,95,50,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,176,50,5,69,2,0,16,1,115,102,50,100,95,95,50,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,245,156,157,254,2,0,16,1,115,57,50,95,50,49,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,119,120,90,146,2,0,16,1,115,57,50,95,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,216,176,3,4,0,32,0,115,57,50,95,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,137,2,132,4,0,32,0,115,57,50,95,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,240,181,205,4,0,32,0,115,57,50,95,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,114,148,121,226,4,0,32,0,115,57,50,95,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,39,138,186,4,0,32,0,115,57,50,95,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,191,132,229,4,0,32,0,115,57,50,95,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,125,248,227,33,4,0,32,0,115,57,50,95,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,71,252,190,4,0,32,0,115,57,50,95,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,213,135,6,150,4,0,32,0,115,57,50,95,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,205,142,151,4,0,32,0,115,57,50,95,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,10,154,236,214,4,0,32,0,115,57,50,95,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,103,44,237,4,0,32,0,115,57,50,95,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,14,182,246,8,3,0,16,0,115,57,50,95,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,32,22,127,5,0,64,0,115,57,50,95,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,229,173,190,5,0,64,0,115,102,45,50,95,51,48,108,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,2,206,161,52,1,0,16,1,115,102,45,50,95,51,55,108,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,210,14,99,91,1,0,16,1,115,102,45,50,95,51,49,108,46,49,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,210,200,235,100,1,0,16,1,115,102,45,50,95,51,56,108,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,67,116,132,115,1,0,16,1,115,102,45,50,95,50,56,108,46,57,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,38,180,226,238,1,0,16,1,115,102,45,50,95,51,53,108,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,82,180,168,236,1,0,16,1,115,102,50,106,95,50,57,97,46,49,48,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,21,243,74,187,1,0,16,1,115,102,50,106,95,51,54,97,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,235,19,42,192,1,0,16,1,115,102,50,95,48,54,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,142,204,201,34,4,0,32,0,115,102,50,95,48,56,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,232,59,33,87,4,0,32,0,115,102,50,95,48,53,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,79,155,82,186,4,0,32,0,115,102,50,95,48,55,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,51,27,75,4,0,32,0,115,102,50,95,49,53,46,56,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,41,34,126,44,4,0,32,0,115,102,50,95,49,55,46,49,48,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,23,143,84,181,4,0,32,0,115,102,50,95,49,52,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,18,67,184,20,4,0,32,0,115,102,50,95,49,54,46,57,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,154,216,156,94,4,0,32,0,115,102,50,95,50,53,46,56,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,88,250,75,153,4,0,32,0,115,102,50,95,50,55,46,49,48,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,157,173,102,62,4,0,32,0,115,102,50,95,50,52,46,55,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,250,190,193,4,0,32,0,115,102,50,95,50,54,46,57,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,49,200,39,6,4,0,32,0,115,102,50,106,95,48,57,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,27,58,130,164,3,0,16,0,115,102,50,106,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,32,22,127,5,0,64,0,115,102,50,106,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,229,173,190,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,115,116,102,50,57,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,197,9,51,4,0,0,0,8,105,111,98,49,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,99,54,51,50,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,112,146,189,15,0,0,0,8,115,102,50,106,95,51,48,104,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,51,238,57,254,1,0,16,1,115,102,50,106,95,51,55,104,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,176,4,3,51,1,0,16,1,115,102,50,106,95,51,49,104,46,49,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,1,163,160,105,1,0,16,1,115,102,50,106,95,51,56,104,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,120,246,89,166,1,0,16,1,115,102,50,106,95,50,56,104,46,57,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,224,142,92,138,1,0,16,1,115,102,50,106,95,51,53,104,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,77,252,40,200,1,0,16,1,115,102,50,106,95,50,57,97,46,49,48,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,21,243,74,187,1,0,16,1,115,102,50,106,95,51,54,97,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,235,19,42,192,1,0,16,1,115,102,50,95,48,54,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,142,204,201,34,4,0,32,0,115,102,50,95,48,56,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,232,59,33,87,4,0,32,0,115,102,50,95,48,53,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,79,155,82,186,4,0,32,0,115,102,50,95,48,55,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,51,27,75,4,0,32,0,115,102,50,95,49,53,46,56,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,41,34,126,44,4,0,32,0,115,102,50,95,49,55,46,49,48,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,23,143,84,181,4,0,32,0,115,102,50,95,49,52,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,18,67,184,20,4,0,32,0,115,102,50,95,49,54,46,57,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,154,216,156,94,4,0,32,0,115,102,50,95,50,53,46,56,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,88,250,75,153,4,0,32,0])
.concat([115,102,50,95,50,55,46,49,48,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,157,173,102,62,4,0,32,0,115,102,50,95,50,52,46,55,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,250,190,193,4,0,32,0,115,102,50,95,50,54,46,57,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,49,200,39,6,4,0,32,0,115,102,50,95,48,57,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,27,58,130,164,3,0,16,0,115,102,50,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,32,22,127,5,0,64,0,115,102,50,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,229,173,190,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,115,116,102,50,57,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,197,9,51,4,0,0,0,8,105,111,98,49,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,99,54,51,50,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,112,146,189,15,0,0,0,8,115,102,50,106,95,51,48,102,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,51,238,57,254,1,0,16,1,115,102,50,106,95,51,55,102,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,198,140,66,193,1,0,16,1,115,102,50,106,95,51,49,102,46,49,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,1,163,160,105,1,0,16,1,115,102,50,106,95,51,56,102,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,226,228,16,21,1,0,16,1,115,102,50,106,95,50,56,102,46,57,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,91,23,216,172,1,0,16,1,115,102,50,106,95,51,53,102,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,209,11,168,192,1,0,16,1,115,102,50,106,95,50,57,97,46,49,48,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,21,243,74,187,1,0,16,1,115,102,50,106,95,51,54,97,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,235,19,42,192,1,0,16,1,115,102,50,95,48,54,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,142,204,201,34,4,0,32,0,115,102,50,95,48,56,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,232,59,33,87,4,0,32,0,115,102,50,95,48,53,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,79,155,82,186,4,0,32,0,115,102,50,95,48,55,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,51,27,75,4,0,32,0,115,102,50,95,49,53,46,56,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,41,34,126,44,4,0,32,0,115,102,50,95,49,55,46,49,48,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,23,143,84,181,4,0,32,0,115,102,50,95,49,52,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,18,67,184,20,4,0,32,0,115,102,50,95,49,54,46,57,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,154,216,156,94,4,0,32,0,115,102,50,95,50,53,46,56,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,88,250,75,153,4,0,32,0,115,102,50,95,50,55,46,49,48,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,157,173,102,62,4,0,32,0,115,102,50,95,50,52,46,55,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,250,190,193,4,0,32,0,115,102,50,95,50,54,46,57,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,49,200,39,6,4,0,32,0,115,102,50,95,48,57,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,27,58,130,164,3,0,16,0,115,102,50,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,32,22,127,5,0,64,0,115,102,50,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,229,173,190,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,115,116,102,50,57,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,197,9,51,4,0,0,0,8,105,111,98,49,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,99,54,51,50,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,112,146,189,15,0,0,0,8,115,102,50,106,95,51,48,99,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,236,53,221,138,1,0,16,1,115,102,50,106,95,51,55,99,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,86,162,116,13,1,0,16,1,115,102,50,106,95,51,49,99,46,49,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,169,244,255,196,1,0,16,1,115,102,50,106,95,51,56,99,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,14,252,16,130,1,0,16,1,115,102,50,106,95,50,56,99,46,57,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,232,213,221,110,1,0,16,1,115,102,50,106,95,51,53,99,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,76,64,203,107,1,0,16,1,115,102,50,106,95,50,57,97,46,49,48,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,21,243,74,187,1,0,16,1,115,102,50,106,95,51,54,97,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,235,19,42,192,1,0,16,1,115,102,50,95,48,54,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,142,204,201,34,4,0,32,0,115,102,50,95,48,56,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,232,59,33,87,4,0,32,0,115,102,50,95,48,53,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,79,155,82,186,4,0,32,0,115,102,50,95,48,55,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,51,27,75,4,0,32,0,115,102,50,95,49,53,46,56,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,41,34,126,44,4,0,32,0,115,102,50,95,49,55,46,49,48,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,23,143,84,181,4,0,32,0,115,102,50,95,49,52,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,18,67,184,20,4,0,32,0,115,102,50,95,49,54,46,57,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,154,216,156,94,4,0,32,0,115,102,50,95,50,53,46,56,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,88,250,75,153,4,0,32,0,115,102,50,95,50,55,46,49,48,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,157,173,102,62,4,0,32,0,115,102,50,95,50,52,46,55,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,250,190,193,4,0,32,0,115,102,50,95,50,54,46,57,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,49,200,39,6,4,0,32,0,115,102,50,95,48,57,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,27,58,130,164,3,0,16,0,115,102,50,106,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,32,22,127,5,0,64,0,115,102,50,106,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,229,173,190,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,115,116,102,50,57,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,197,9,51,4,0,0,0,8,105,111,98,49,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,99,54,51,50,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,112,146,189,15,0,0,0,8,115,102,50,106,95,51,48,97,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,81,112,189,87,1,0,16,1,115,102,50,106,95,51,55,97,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,68,104,31,30,1,0,16,1,115,102,50,106,95,51,49,97,46,49,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,61,20,115,166,1,0,16,1,115,102,50,106,95,51,56,97,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,247,206,44,76,1,0,16,1,115,102,50,106,95,50,56,97,46,57,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,94,149,9,64,1,0,16,1,115,102,50,106,95,51,53,97,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,148,57,31,140,1,0,16,1,115,102,50,106,95,50,57,97,46,49,48,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,21,243,74,187,1,0,16,1,115,102,50,106,95,51,54,97,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,235,19,42,192,1,0,16,1,115,102,50,95,48,54,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,142,204,201,34,4,0,32,0,115,102,50,95,48,56,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,232,59,33,87,4,0,32,0,115,102,50,95,48,53,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,79,155,82,186,4,0,32,0,115,102,50,95,48,55,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,51,27,75,4,0,32,0,115,102,50,95,49,53,46,56,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,41,34,126,44,4,0,32,0,115,102,50,95,49,55,46,49,48,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,23,143,84,181,4,0,32,0,115,102,50,95,49,52,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,18,67,184,20,4,0,32,0,115,102,50,95,49,54,46,57,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,154,216,156,94,4,0,32,0,115,102,50,95,50,53,46,56,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,88,250,75,153,4,0,32,0,115,102,50,95,50,55,46,49,48,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,157,173,102,62,4,0,32,0,115,102,50,95,50,52,46,55,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,250,190,193,4,0,32,0,115,102,50,95,50,54,46,57,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,49,200,39,6,4,0,32,0,115,102,50,106,95,48,57,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,27,58,130,164,3,0,16,0,115,102,50,106,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,32,22,127,5,0,64,0,115,102,50,106,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,229,173,190,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,115,116,102,50,57,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,197,9,51,4,0,0,0,8,105,111,98,49,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,99,54,51,50,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,112,146,189,15,0,0,0,8,115,50,116,101,95,50,51,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,20,37,215,45,2,0,16,1,115,50,116,101,95,50,50,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,53,224,166,174,2,0,16,1,115,50,116,101,95,50,49,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,136,2,32,253,2,0,16,1,115,57,50,45,49,109,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,216,176,3,4,0,32,0,115,57,50,45,51,109,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,137,2,132,4,0,32,0,115,57,50,45,50,109,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,240,181,205,4,0,32,0,115,57,50,45,52,109,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,114,148,121,226,4,0,32,0,115,57,50,45,53,109,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,39,138,186,4,0,32,0,115,57,50,45,55,109,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,191,132,229,4,0,32,0,115,57,50,45,54,109,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,125,248,227,33,4,0,32,0,115,57,50,45,56,109,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,71,252,190,4,0,32,0,115,57,50,45,49,48,109,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,213,135,6,150,4,0,32,0,115,57,50,45,49,50,109,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,205,142,151,4,0,32,0,115,57,50,45,49,49,109,46,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,10,154,236,214,4,0,32,0,115,57,50,45,49,51,109,46,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,103,44,237,4,0,32,0,115,57,50,95,48,57,46,49,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,14,182,246,8,3,0,16,0,115,57,50,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,32,22,127,5,0,64,0,115,57,50,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,229,173,190,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,115,57,50,54,51,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,224,207,126,10,0,0,0,8,105,111,98,49,46,49,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,98,112,114,103,49,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,167,61,121,49,0,0,0,8,105,111,99,49,46,105,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,129,32,24,13,0,0,0,8,99,54,51,50,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,112,146,189,15,0,0,0,8,115,102,50,101,95,51,48,101,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,136,208,124,243,1,0,16,1,115,102,50,101,95,51,55,101,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,230,104,148,195,1,0,16,1,115,102,50,101,95,51,49,101,46,49,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,180,113,71,124,1,0,16,1,115,102,50,101,95,51,56,101,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,217,12,189,164,1,0,16,1,115,102,50,101,95,50,56,101,46,57,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,37,86,185,227,1,0,16,1,115,102,50,101,95,51,53,101,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,154,118,72,54,1,0,16,1,115,102,50,95,50,57,98,46,49,48,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,21,243,74,187,1,0,16,1,115,102,50,95,51,54,98,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,235,19,42,192,1,0,16,1,115,102,50,45,53,109,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,142,204,201,34,4,0,32,0,115,102,50,45,55,109,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,232,59,33,87,4,0,32,0,115,102,50,45,49,109,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,79,155,82,186,4,0,32,0,115,102,50,45,51,109,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,51,27,75,4,0,32,0,115,102,50,45,54,109,46,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,41,34,126,44,4,0,32,0,115,102,50,45,56,109,46,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,23,143,84,181,4,0,32,0,115,102,50,45,50,109,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,18,67,184,20,4,0,32,0,115,102,50,45,52,109,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,154,216,156,94,4,0,32,0,115,102,50,45,49,51,109,46,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,88,250,75,153,4,0,32,0,115,102,50,45,49,53,109,46,54,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,157,173,102,62,4,0,32,0,115,102,50,45,57,109,46,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,250,190,193,4,0,32,0,115,102,50,45,49,49,109,46,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,49,200,39,6,4,0,32,0,115,102,50,95,57,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,27,58,130,164,3,0,16,0,115,102,50,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,32,22,127,5,0,64,0,115,102,50,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,229,173,190,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,115,116,102,50,57,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,197,9,51,4,0,0,0,8,105,111,98,50,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,0,0,0,0,0,0,24,99,54,51,50,98,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,112,146,189,15,0,0,0,8,115,102,50,101,95,51,48,98,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,81,112,189,87,1,0,16,1,115,102,50,101,95,51,55,98,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,221,28,105,98,1,0,16,1,115,102,50,101,95,51,49,98,46,49,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,61,20,115,166,1,0,16,1,115,102,50,101,95,51,56,98,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,247,206,44,76,1,0,16,1,115,102,50,95,50,56,98,46,57,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,94,149,9,64,1,0,16,1,115,102,50,95,51,53,98,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,148,57,31,140,1,0,16,1,115,102,50,95,50,57,98,46,49,48,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,21,243,74,187,1,0,16,1,115,102,50,95,51,54,98,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,235,19,42,192,1,0,16,1,115,102,50,45,53,109,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,142,204,201,34,4,0,32,0,115,102,50,45,55,109,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,232,59,33,87,4,0,32,0,115,102,50,45,49,109,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,79,155,82,186,4,0,32,0,115,102,50,45,51,109,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,51,27,75,4,0,32,0,115,102,50,45,54,109,46,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,41,34,126,44,4,0,32,0,115,102,50,45,56,109,46,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,23,143,84,181,4,0,32,0,115,102,50,45,50,109,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,18,67,184,20,4,0,32,0,115,102,50,45,52,109,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,154,216,156,94,4,0,32,0,115,102,50,45,49,51,109,46,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,8,0,88,250,75,153,4,0,32,0,115,102,50,45,49,53,109,46,54,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,157,173,102,62,4,0,32,0,115,102,50,45,57,109,46,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,250,190,193,4,0,32,0,115,102,50,45,49,49,109,46,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,49,200,39,6,4,0,32,0,115,102,50,95,57,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,27,58,130,164,3,0,16,0,115,102,50,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,32,22,127,5,0,64,0,115,102,50,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,229,173,190,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,115,116,102,50,57,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,197,9,51,4,0,0,0,8,105,111,98,49,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,99,54,51,50,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,112,146,189,15,0,0,0,8,115,57,50,101,95,50,51,98,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,58,26,170,10,2,0,16,1,115,57,50,95,50,50,98,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,237,21,190,43,2,0,16,1,115,57,50,95,50,49,97,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,119,120,90,146,2,0,16,1,115,57,50,45,49,109,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,216,176,3,4,0,32,0,115,57,50,45,51,109,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,236,137,2,132,4,0,32,0,115,57,50,45,50,109,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,240,181,205,4,0,32,0,115,57,50,45,52,109,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,114,148,121,226,4,0,32,0,115,57,50,45,53,109,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,39,138,186,4,0,32,0,115,57,50,45,55,109,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,191,132,229,4,0,32,0,115,57,50,45,54,109,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,125,248,227,33,4,0,32,0,115,57,50,45,56,109,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,71,252,190,4,0,32,0,115,57,50,45,49,48,109,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,213,135,6,150,4,0,32,0,115,57,50,45,49,50,109,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,205,142,151,4,0,32,0,115,57,50,45,49,49,109,46,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,10,154,236,214,4,0,32,0,115,57,50,45,49,51,109,46,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,246,103,44,237,4,0,32,0,115,57,50,95,48,57,46,49,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,14,182,246,8,3,0,16,0,115,57,50,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,32,22,127,5,0,64,0,115,57,50,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,229,173,190,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,115,57,50,54,51,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,224,207,126,10,0,0,0,8,105,111,98,49,46,49,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,98,112,114,103,49,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,167,61,121,49,0,0,0,8,105,111,99,49,46,105,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,129,32,24,13,0,0,0,8,99,54,51,50,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,112,146,189,15,0,0,0,8,115,102,50,101,95,51,48,98,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,81,112,189,87,1,0,16,1,115,102,50,101,95,51,55,98,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,221,28,105,98,1,0,16,1,115,102,50,101,95,51,49,98,46,49,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,61,20,115,166,1,0,16,1,115,102,50,101,95,51,56,98,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,247,206,44,76,1,0,16,1,112,114,104,50,46,117,50,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,184,119,15,109,1,0,16,1,112,114,108,49,46,117,49,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,100,238,150,155,1,0,16,1,98,100,115,116,45,49,46,117,55,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,25,139,74,169,4,0,32,0,98,100,115,116,45,52,46,117,54,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,31,242,5,4,4,0,32,0,98,100,115,116,45,50,46,117,54,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,67,32,220,5,4,0,32,0,98,100,115,116,45,53,46,117,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,241,100,91,5,4,0,32,0,98,100,115,116,45,51,46,117,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,9,134,81,26,4,0,32,0,98,100,115,116,45,54,46,117,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,79,53,249,132,4,0,32,0,115,111,117,110,100,46,117,49,57,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,27,58,130,164,3,0,16,0,118,111,105,99,101,46,117,50,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,17,251,255,108,5,0,64,0,103,114,112,49,46,117,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,113,70,228,109,11,0,32,0,103,114,112,51,46,117,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,98,67,241,232,11,0,32,0,103,114,112,50,46,117,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,25,216,12,191,11,0,32,0,103,114,112,52,46,117,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,31,249,249,118,11,0,32,0,117,49,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,68,28,234,19,0,0,0,8,168,86,7,0,1,0,0,0,232,47,216,0,248,191,2,0,24,38,7,0,1,0,0,0,236,47,216,0,184,160,2,0,56,210,6,0,1,0,0,0,35,48,216,0,192,135,2,0,24,163,6,0,1,0,0,0,34,48,216,0,240,108,2,0,152,122,6,0,1,0,0,0,33,48,216,0,96,82,2,0,192,72,6,0,1,0,0,0,32,48,216,0,32,56,2,0,152,226,4,0,1,0,0,0,36,48,216,0,152,30,2,0,168,190,4,0,1,0,0,0,37,48,216,0,232,10,2,0,240,158,4,0,1,0,0,0,38,48,216,0,152,138,8,0,136,128,4,0,1,0,0,0,160,47,216,0,48,119,7,0,176,101,4,0,1,0,0,0,161,47,216,0,112,109,7,0,136,75,4,0,1,0,0,0,162,47,216,0,24,133,7,0,40,246,1,0,1,0,0,0,233,47,216,0,64,246,1,0,144,236,1,0,1,0,0,0,237,47,216,0,136,224,1,0,176,223,1,0,1,0,0,0,43,48,216,0,72,198,1,0,192,209,1,0,1,0,0,0,42,48,216,0,24,182,1,0,24,198,1,0,1,0,0,0,41,48,216,0,40,167,1,0,120,189,1,0,1,0,0,0,40,48,216,0,200,149,1,0,40,126,1,0,1,0,0,0,44,48,216,0,56,126,1,0,0,112,1,0,1,0,0,0,45,48,216,0,32,101,1,0,0,101,1,0,1,0,0,0,46,48,216,0,96,32,8,0,248,91,1,0,1,0,0,0,164,47,216,0,16,68,7,0,128,85,1,0,1,0,0,0,165,47,216,0,240,58,7,0,248,76,1,0,1,0,0,0,166,47,216,0,200,42,1,0,88,212,3,0,1,0,0,0,144,46,216,0,40,185,3,0,240,152,1,0,1,0,0,0,238,47,216,0,216,70,1,0,16,17,8,0,1,0,0,0,234,47,216,0,224,12,8,0,72,65,1,0,9,0,0,0,232,48,216,0,32,58,1,0,48,50,1,0,9,0,0,0,224,48,216,0,32,58,1,0,224,41,1,0,9,0,0,0,216,48,216,0,32,58,1,0,97,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,214,29,196,242,1,0,16,1,97,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,239,22,248,169,1,0,16,1,97,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,126,226,82,121,1,0,16,1,97,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,38,243,154,54,1,0,16,1,97,54,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,135,194,226,142,1,0,16,1,97,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,49,66,62,25,1,0,16,1,101,112,114,45,49,48,55,55,50,46,98,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,99,43,24,2,0,32,0,101,112,114,45,49,48,55,55,51,46,98,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,162,41,113,143,2,0,32,0,101,112,114,45,49,48,55,55,52,46,98,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,31,65,9,68,2,0,32,0,98,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,10,197,226,48,3,0,32,0,98,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,139,62,78,121,3,0,32,0,98,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,208,63,139,106,3,0,32,0,49,48,55,54,52,46,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,213,165,45,96,3,0,32,0,98,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,235,58,222,185,3,0,32,0,49,48,55,54,53,46,98,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,87,160,115,10,3,0,32,0,97,55,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,127,159,63,121,4,0,16,1,184,40,2,0,1,0,0,0,208,155,215,0,248,191,2,0,56,250,6,0,1,0,0,0,212,155,215,0,184,160,2,0,184,164,8,0,1,0,0,0,209,155,215,0,64,246,1,0,88,149,7,0,1,0,0,0,213,155,215,0,136,224,1,0,56,210,6,0,1,0,0,0,201,155,215,0,192,135,2,0,24,163,6,0,1,0,0,0,200,155,215,0,240,108,2,0,152,122,6,0,1,0,0,0,203,155,215,0,96,82,2,0,192,72,6,0,1,0,0,0,202,155,215,0,32,56,2,0,136,189,3,0,4,0,0,0,112,156,215,0,152,210,1,0,96,183,3,0,4,0,0,0,104,156,215,0,208,189,1,0,48,123,2,0,1,0,0,0,214,155,215,0,248,174,1,0,176,223,1,0,1,0,0,0,205,155,215,0,72,198,1,0,192,209,1,0,1,0,0,0,204,155,215,0,24,182,1,0,24,198,1,0,1,0,0,0,207,155,215,0,40,167,1,0,120,189,1,0,1,0,0,0,206,155,215,0,200,149,1,0,136,189,3,0,4,0,0,0,96,156,215,0,136,7,4,0,96,183,3,0,4,0,0,0,88,156,215,0,136,113,1,0,248,187,8,0,1,0,0,0,215,155,215,0,56,126,1,0,16,17,8,0,1,0,0,0,211,155,215,0,224,12,8,0,32,77,1,0,1,0,0,0,210,155,215,0,216,70,1,0,88,212,3,0,1,0,0,0,200,154,215,0,40,185,3,0,248,5,8,0,9,0,0,0,0,156,215,0,32,58,1,0,144,250,7,0,9,0,0,0,1,156,215,0,32,58,1,0,184,40,2,0,1,0,0,0,138,151,215,0,248,191,2,0,56,250,6,0,1,0,0,0,131,151,215,0,184,160,2,0,184,164,8,0,1,0,0,0,139,151,215,0,64,246,1,0,240,190,7,0,4,0,0,0,104,150,215,0,208,13,4,0,32,201,5,0,1,0,0,0,141,151,215,0,152,30,2,0,208,240,5,0,1,0,0,0,133,151,215,0,232,10,2,0,88,168,7,0,1,0,0,0,137,151,215,0,152,138,8,0,208,26,7,0,1,0,0,0,128,151,215,0,48,119,7,0,32,160,5,0,1,0,0,0,132,151,215,0,112,109,7,0,72,137,7,0,1,0,0,0,130,151,215,0,24,133,7,0,88,212,3,0,1,0,0,0,200,147,215,0,40,185,3,0,16,17,8,0,1,0,0,0,140,151,215,0,224,12,8,0,56,58,1,0,1,0,0,0,129,151,215,0,64,50,1,0,248,5,8,0,9,0,0,0,152,151,215,0,32,58,1,0,144,250,7,0,9,0,0,0,153,151,215,0,32,58,1,0,168,86,7,0,1,0,0,0,122,151,215,0,248,191,2,0,24,38,7,0,1,0,0,0,128,151,215,0,184,160,2,0,56,210,6,0,1,0,0,0,136,151,215,0,192,135,2,0,24,163,6,0,1,0,0,0,137,151,215,0,240,108,2,0,152,122,6,0,1,0,0,0,138,151,215,0,96,82,2,0,192,72,6,0,1,0,0,0,139,151,215,0,32,56,2,0,200,110,3,0,1,0,0,0,124,151,215,0,152,30,2,0,120,89,3,0,1,0,0,0,125,151,215,0,232,10,2,0,120,74,3,0,1,0,0,0,126,151,215,0,152,138,8,0,192,61,3,0,1,0,0,0,127,151,215,0,48,119,7,0,40,246,1,0,1,0,0,0,123,151,215,0,64,246,1,0,144,236,1,0,1,0,0,0,129,151,215,0,136,224,1,0,176,223,1,0,1,0,0,0,140,151,215,0,72,198,1,0,192,209,1,0,1,0,0,0,141,151,215,0,24,182,1,0,24,198,1,0,1,0,0,0,142,151,215,0,40,167,1,0,120,189,1,0,1,0,0,0,143,151,215,0,200,149,1,0,88,212,3,0,1,0,0,0,200,147,215,0,40,185,3,0,16,17,8,0,1,0,0,0,121,151,215,0,224,12,8,0,56,58,1,0,1,0,0,0,120,151,215,0,64,50,1,0,72,65,1,0,9,0,0,0,152,151,215,0,32,58,1,0,48,50,1,0,9,0,0,0,153,151,215,0,32,58,1,0,18,0,0,0,255,255,0,0,0,0,0,0,19,0,0,0,255,255,0,0,0,0,0,0,20,0,0,0,255,255,0,0,0,0,0,0,21,0,0,0,255,255,0,0,0,0,0,0,18,0,0,0,254,0,4,0,200,87,7,0,18,0,0,0,1,3,1,0,160,36,8,0,18,0,0,0,1,3,0,0,208,239,7,0,18,0,0,0,1,3,2,0,120,187,7,0,18,0,0,0,1,3,3,0,136,23,1,0,18,0,0,0,254,0,4,0,160,123,6,0,18,0,0,0,1,12,4,0,160,36,8,0,18,0,0,0,1,12,0,0,208,239,7,0,18,0,0,0,1,12,8,0,120,187,7,0,18,0,0,0,1,12,12,0,136,23,1,0,19,0,0,0,254,0,4,0])
.concat([128,129,4,0,19,0,0,0,1,3,3,0,208,75,4,0,19,0,0,0,1,3,0,0,8,49,4,0,19,0,0,0,1,3,1,0,152,21,4,0,19,0,0,0,1,3,2,0,72,246,3,0,19,0,0,0,254,0,2,0,200,30,2,0,19,0,0,0,1,4,4,0,120,97,1,0,19,0,0,0,1,4,0,0,96,19,1,0,20,0,0,0,254,0,4,0,64,37,5,0,20,0,0,0,1,3,0,0,200,140,8,0,20,0,0,0,1,3,1,0,88,89,8,0,20,0,0,0,1,3,2,0,232,82,8,0,20,0,0,0,1,3,3,0,160,191,4,0,21,0,0,0,254,0,4,0,72,202,5,0,21,0,0,0,1,3,0,0,80,246,3,0,21,0,0,0,1,3,1,0,248,38,7,0,21,0,0,0,1,3,2,0,112,212,3,0,21,0,0,0,1,3,3,0,248,160,5,0,21,0,0,0,254,0,2,0,8,78,8,0,21,0,0,0,1,4,0,0,56,111,3,0,21,0,0,0,1,4,4,0,104,134,3,0,21,0,0,0,254,0,2,0,104,159,3,0,21,0,0,0,1,8,0,0,56,111,3,0,21,0,0,0,1,8,8,0,104,134,3,0,22,0,0,0,255,255,251,0,0,0,0,0,23,0,0,0,255,255,253,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,22,0,0,0,1,3,2,0,208,75,4,0,22,0,0,0,1,3,3,0,8,49,4,0,22,0,0,0,1,3,1,0,152,21,4,0,22,0,0,0,1,3,0,0,72,246,3,0,0,0,0,0,254,0,2,0,168,234,7,0,22,0,0,0,1,4,4,0,96,135,7,0,22,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,64,37,5,0,22,0,0,0,1,8,0,0,240,49,7,0,22,0,0,0,1,8,8,0,32,44,7,0,0,0,0,0,254,0,2,0,200,30,2,0,23,0,0,0,1,2,0,0,120,97,1,0,23,0,0,0,1,2,2,0,96,19,1,0,0,0,0,0,254,0,2,0,72,202,5,0,23,0,0,0,1,8,8,0,248,38,7,0,23,0,0,0,1,8,0,0,112,212,3,0,0,0,0,0,254,0,2,0,104,159,3,0,23,0,0,0,1,16,0,0,56,111,3,0,23,0,0,0,1,16,16,0,104,134,3,0,0,0,0,0,254,0,2,0,144,246,3,0,23,0,0,0,1,64,64,0,96,135,7,0,23,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,21,0,0,0,255,255,127,0,0,0,0,0,22,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,8,0,200,87,7,0,20,0,0,0,1,7,0,0,40,88,7,0,20,0,0,0,1,7,1,0,96,39,7,0,20,0,0,0,1,7,7,0,144,251,6,0,20,0,0,0,1,7,6,0,184,164,6,0,20,0,0,0,1,7,5,0,80,74,6,0,20,0,0,0,1,7,4,0,192,32,6,0,20,0,0,0,1,7,3,0,192,234,2,0,20,0,0,0,1,7,2,0,32,242,5,0,0,0,0,0,254,0,8,0,160,123,6,0,20,0,0,0,1,56,0,0,40,88,7,0,20,0,0,0,1,56,8,0,96,39,7,0,20,0,0,0,1,56,56,0,144,251,6,0,20,0,0,0,1,56,48,0,184,164,6,0,20,0,0,0,1,56,40,0,80,74,6,0,20,0,0,0,1,56,32,0,192,32,6,0,20,0,0,0,1,56,24,0,192,234,2,0,20,0,0,0,1,56,16,0,32,242,5,0,0,0,0,0,254,0,2,0,144,212,8,0,20,0,0,0,1,64,64,0,96,135,7,0,20,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,152,184,3,0,20,0,0,0,1,128,128,0,96,135,7,0,20,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,4,0,16,116,8,0,21,0,0,0,1,48,48,0,248,38,7,0,21,0,0,0,1,48,32,0,112,134,3,0,21,0,0,0,1,48,16,0,184,164,4,0,21,0,0,0,1,48,0,0,64,111,3,0,0,0,0,0,254,0,2,0,104,159,3,0,21,0,0,0,1,64,64,0,96,135,7,0,21,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,21,0,0,0,1,128,128,0,96,135,7,0,21,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,192,80,8,0,22,0,0,0,1,1,1,0,96,135,7,0,22,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,4,0,24,76,8,0,22,0,0,0,1,12,8,0,112,134,3,0,22,0,0,0,1,12,12,0,248,38,7,0,22,0,0,0,1,12,4,0,64,111,3,0,22,0,0,0,1,12,0,0,208,89,3,0,0,0,0,0,254,0,4,0,208,67,8,0,22,0,0,0,1,48,32,0,112,134,3,0,22,0,0,0,1,48,48,0,248,38,7,0,22,0,0,0,1,48,16,0,64,111,3,0,22,0,0,0,1,48,0,0,208,89,3,0,0,0,0,0,254,0,4,0,112,64,8,0,22,0,0,0,1,192,128,0,248,81,6,0,22,0,0,0,1,192,192,0,248,38,7,0,22,0,0,0,1,192,64,0,176,64,8,0,22,0,0,0,1,192,0,0,128,65,6,0,20,0,0,0,255,255,255,0,0,0,0,0,21,0,0,0,255,255,255,0,0,0,0,0,22,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,20,0,0,0,1,1,1,0,96,135,7,0,20,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,20,0,0,0,1,2,0,0,96,135,7,0,20,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,3,0,200,30,2,0,20,0,0,0,1,24,0,0,192,33,2,0,20,0,0,0,1,24,24,0,232,32,2,0,20,0,0,0,1,24,8,0,96,19,1,0,0,0,0,0,254,0,2,0,232,75,4,0,20,0,0,0,1,128,128,0,96,135,7,0,20,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,21,0,0,0,1,3,2,0,208,75,4,0,21,0,0,0,1,3,3,0,8,49,4,0,21,0,0,0,1,3,1,0,152,21,4,0,21,0,0,0,1,3,0,0,72,246,3,0,0,0,0,0,254,0,4,0,72,202,5,0,21,0,0,0,1,12,8,0,80,246,3,0,21,0,0,0,1,12,12,0,248,38,7,0,21,0,0,0,1,12,4,0,112,212,3,0,21,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,16,0,32,4,2,0,21,0,0,0,1,240,160,0,144,160,3,0,21,0,0,0,1,240,176,0,96,135,3,0,21,0,0,0,1,240,192,0,32,136,7,0,21,0,0,0,1,240,208,0,40,88,7,0,21,0,0,0,1,240,16,0,40,28,4,0,21,0,0,0,1,240,224,0,96,39,7,0,21,0,0,0,1,240,32,0,192,24,7,0,21,0,0,0,1,240,48,0,120,113,6,0,21,0,0,0,1,240,240,0,144,251,6,0,21,0,0,0,1,240,64,0,120,211,6,0,21,0,0,0,1,240,144,0,184,164,6,0,21,0,0,0,1,240,128,0,80,74,6,0,21,0,0,0,1,240,112,0,192,32,6,0,21,0,0,0,1,240,96,0,192,234,2,0,21,0,0,0,1,240,80,0,32,242,5,0,21,0,0,0,1,240,0,0,16,227,4,0,0,0,0,0,254,0,2,0,232,75,4,0,22,0,0,0,1,8,8,0,96,135,7,0,22,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,2,0,48,31,2,0,22,0,0,0,1,16,0,0,96,135,7,0,22,0,0,0,1,16,16,0,152,182,7,0,0,0,0,0,108,21,0,0,242,13,0,0,40,14,0,0,158,17,0,0,108,24,0,0,120,3,0,0,56,38,0,0,208,8,0,0,116,46,0,0,42,18,0,0,190,13,0,0,202,24,0,0,40,33,0,0,216,49,0,0,102,40,0,0,254,33,0,0,66,5,0,0,156,21,0,0,86,45,0,0,196,47,0,0,56,25,0,0,178,41,0,0,90,29,0,0,230,2,0,0,144,2,0,0,14,7,0,0,54,2,0,0,128,22,0,0,248,41,0,0,70,25,0,0,136,10,0,0,38,30,0,0,108,47,0,0,2,32,0,0,250,35,0,0,52,8,0,0,116,4,0,0,2,23,0,0,76,5,0,0,104,18,0,0,150,14,0,0,4,31,0,0,90,15,0,0,192,44,0,0,68,6,0,0,128,9,0,0,208,35,0,0,108,8,0,0,150,20,0,0,78,3,0,0,32,47,0,0,72,49,0,0,18,39,0,0,156,22,0,0,10,35,0,0,220,18,0,0,42,9,0,0,72,30,0,0,112,29,0,0,122,37,0,0,240,41,0,0,54,46,0,0,166,31,0,0,120,7,0,0,236,19,0,0,132,11,0,0,236,15,0,0,50,9,0,0,98,32,0,0,198,38,0,0,20,25,0,0,108,15,0,0,44,6,0,0,168,11,0,0,170,41,0,0,8,29,0,0,32,23,0,0,176,5,0,0,44,15,0,0,170,22,0,0,28,0,0,0,204,23,0,0,22,26,0,0,6,35,0,0,64,12,0,0,30,15,0,0,82,26,0,0,138,50,0,0,190,40,0,0,58,31,0,0,22,42,0,0,216,29,0,0,142,38,0,0,184,10,0,0,218,27,0,0,234,28,0,0,178,23,0,0,144,1,0,0,228,2,0,0,92,43,0,0,112,40,0,0,122,1,0,0,40,38,0,0,16,50,0,0,12,31,0,0,88,47,0,0,92,44,0,0,158,34,0,0,118,22,0,0,76,4,0,0,100,27,0,0,204,29,0,0,106,5,0,0,166,38,0,0,92,41,0,0,196,29,0,0,70,5,0,0,164,16,0,0,244,27,0,0,2,35,0,0,152,44,0,0,18,31,0,0,160,26,0,0,90,47,0,0,150,39,0,0,68,4,0,0,108,35,0,0,150,38,0,0,17,0,0,0,255,255,255,0,0,0,0,0,18,0,0,0,255,255,95,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,17,0,0,0,1,240,0,0,104,54,4,0,17,0,0,0,1,240,64,0,80,252,6,0,17,0,0,0,1,240,160,0,16,242,7,0,17,0,0,0,1,240,16,0,104,236,7,0,17,0,0,0,1,240,32,0,120,113,6,0,17,0,0,0,1,240,128,0,232,228,5,0,17,0,0,0,1,240,240,0,128,230,7,0,17,0,0,0,1,240,192,0,56,141,7,0,17,0,0,0,1,240,224,0,120,211,6,0,17,0,0,0,1,240,112,0,184,164,6,0,17,0,0,0,1,240,96,0,24,1,7,0,17,0,0,0,1,240,176,0,80,74,6,0,17,0,0,0,1,240,48,0,192,32,6,0,17,0,0,0,1,240,208,0,192,234,2,0,17,0,0,0,1,240,80,0,32,242,5,0,17,0,0,0,1,240,144,0,176,192,2,0,0,0,0,0,254,0,16,0,160,123,6,0,17,0,0,0,1,15,0,0,104,54,4,0,17,0,0,0,1,15,4,0,80,252,6,0,17,0,0,0,1,15,10,0,16,242,7,0,17,0,0,0,1,15,1,0,104,236,7,0,17,0,0,0,1,15,2,0,120,113,6,0,17,0,0,0,1,15,8,0,232,228,5,0,17,0,0,0,1,15,15,0,128,230,7,0,17,0,0,0,1,15,12,0,56,141,7,0,17,0,0,0,1,15,14,0,120,211,6,0,17,0,0,0,1,15,7,0,184,164,6,0,17,0,0,0,1,15,6,0,24,1,7,0,17,0,0,0,1,15,11,0,80,74,6,0,17,0,0,0,1,15,3,0,192,32,6,0,17,0,0,0,1,15,13,0,192,234,2,0,17,0,0,0,1,15,5,0,32,242,5,0,17,0,0,0,1,15,9,0,176,192,2,0,0,0,0,0,254,0,4,0,64,37,5,0,18,0,0,0,1,3,3,0,120,101,2,0,18,0,0,0,1,3,1,0,24,87,2,0,18,0,0,0,1,3,2,0,152,99,2,0,18,0,0,0,1,3,0,0,120,7,5,0,0,0,0,0,254,0,4,0,128,129,4,0,18,0,0,0,1,12,0,0,208,75,4,0,18,0,0,0,1,12,12,0,8,49,4,0,18,0,0,0,1,12,4,0,152,21,4,0,18,0,0,0,1,12,8,0,72,246,3,0,0,0,0,0,254,0,4,0,72,202,5,0,18,0,0,0,1,48,48,0,80,246,3,0,18,0,0,0,1,48,16,0,248,38,7,0,18,0,0,0,1,48,32,0,112,212,3,0,18,0,0,0,1,48,0,0,248,160,5,0,0,0,0,0,254,0,2,0,168,234,7,0,18,0,0,0,1,128,128,0,96,135,7,0,18,0,0,0,1,128,0,0,152,182,7,0,113,97,100,95,50,51,97,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,222,83,53,77,2,0,16,1,113,97,100,95,50,50,97,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,208,221,145,49,2,0,16,1,113,97,100,95,48,49,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,87,59,133,157,4,0,32,0,113,97,100,95,48,50,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,196,118,89,179,4,0,32,0,113,97,100,95,48,51,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,140,202,164,206,4,0,32,0,113,97,100,95,48,52,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,27,77,183,65,4,0,32,0,113,97,100,95,48,57,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,204,97,49,115,3,0,16,0,113,97,100,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,106,111,254,43,5,0,64,0,113,97,100,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,107,35,211,19,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,113,97,100,54,51,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,19,43,49,179,0,0,0,8,105,111,98,49,46,49,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,98,112,114,103,49,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,167,61,121,49,0,0,0,8,105,111,99,49,46,105,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,129,32,24,13,0,0,0,8,99,54,51,50,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,112,146,189,15,0,0,0,8,15,0,0,0,255,255,0,0,0,0,0,0,16,0,0,0,255,255,0,0,0,0,0,0,17,0,0,0,255,255,32,0,0,0,0,0,0,0,0,0,254,0,8,0,32,4,2,0,15,0,0,0,1,7,7,0,80,252,6,0,15,0,0,0,1,7,6,0,16,242,7,0,15,0,0,0,1,7,5,0,104,236,7,0,15,0,0,0,1,7,0,0,128,230,7,0,15,0,0,0,1,7,1,0,184,164,6,0,15,0,0,0,1,7,2,0,80,74,6,0,15,0,0,0,1,7,3,0,192,32,6,0,15,0,0,0,1,7,4,0,32,242,5,0,0,0,0,0,254,0,2,0,64,232,1,0,15,0,0,0,1,64,0,0,96,135,7,0,15,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,5,0,72,202,5,0,16,0,0,0,1,7,0,0,24,205,7,0,16,0,0,0,1,7,1,0,192,255,2,0,16,0,0,0,1,7,2,0,208,75,4,0,16,0,0,0,1,7,3,0,8,49,4,0,16,0,0,0,1,7,4,0,152,21,4,0,0,0,0,0,254,0,3,0,128,129,4,0,16,0,0,0,1,224,64,0,192,255,2,0,16,0,0,0,1,224,32,0,208,75,4,0,16,0,0,0,1,224,0,0,8,49,4,0,0,0,0,0,254,0,2,0,16,227,4,0,17,0,0,0,1,4,0,0,96,135,7,0,17,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,254,0,2,0,72,4,1,0,17,0,0,0,1,8,0,0,96,135,7,0,17,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,2,0,120,207,1,0,17,0,0,0,1,16,0,0,96,135,7,0,17,0,0,0,1,16,16,0,152,182,7,0,0,0,0,0,254,0,2,0,40,111,8,0,17,0,0,0,1,32,0,0,96,135,7,0,17,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,17,0,0,0,1,64,64,0,96,135,7,0,17,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,79,2,0,17,0,0,0,1,128,0,0,32,182,8,0,17,0,0,0,1,128,128,0,80,251,6,0,0,0,0,0,14,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,14,0,0,0,1,1,0,0,120,97,1,0,14,0,0,0,1,1,1,0,96,19,1,0,112,119,103,106,46,48,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,2,12,156,199,1,0,16,1,112,119,103,106,46,48,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,216,110,124,22,1,0,16,1,112,119,103,106,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,180,63,166,1,0,16,1,112,119,103,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,232,12,166,135,1,0,16,1,112,119,103,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,72,177,247,1,0,16,1,112,119,103,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,62,130,98,204,1,0,16,1,112,119,103,46,48,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,238,186,38,76,1,0,16,1,112,119,103,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,40,251,196,7,1,0,16,1,112,119,103,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,142,224,143,174,5,0,32,0,112,119,103,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,88,15,86,219,5,0,32,0,112,119,103,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,148,91,71,188,5,0,32,0,112,119,103,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,247,159,67,7,5,0,32,0,112,119,103,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,99,186,249,195,5,0,32,0,112,119,103,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,123,14,91,129,5,0,32,0,112,119,103,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,27,199,9,1,5,0,32,0,112,119,103,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,190,255,117,235,5,0,32,0,112,119,103,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,228,192,165,24,10,0,16,1,112,119,103,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,166,255,223,201,10,0,16,1,112,119,103,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,51,116,143,167,12,0,64,0,112,119,103,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,208,142,67,119,12,0,64,0,15,0,0,0,255,255,255,0,0,0,0,0,16,0,0,0,255,255,255,0,0,0,0,0,17,0,0,0,255,255,176,0,0,0,0,0,18,0,0,0,255,255,204,0,0,0,0,0,0,0,0,0,254,0,1,0,232,75,4,0,16,0,0,0,1,16,16,0,96,135,7,0,0,0,0,0,254,0,2,0,64,37,5,0,17,0,0,0,1,1,0,0,152,53,6,0,17,0,0,0,1,1,1,0,8,49,6,0,0,0,0,0,254,0,2,0,168,234,7,0,17,0,0,0,1,2,2,0,96,135,7,0,17,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,200,30,2,0,17,0,0,0,1,4,0,0,120,97,1,0,17,0,0,0,1,4,4,0,96,19,1,0,0,0,0,0,254,0,4,0,128,129,4,0,17,0,0,0,1,24,24,0,208,75,4,0,17,0,0,0,1,24,16,0,8,49,4,0,17,0,0,0,1,24,8,0,152,21,4,0,17,0,0,0,1,24,0,0,72,246,3,0,0,0,0,0,254,0,2,0,16,27,6,0,17,0,0,0,1,32,32,0,96,135,7,0,17,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,17,0,0,0,1,192,192,0,80,246,3,0,17,0,0,0,1,192,128,0,80,124,6,0,17,0,0,0,1,192,64,0,112,212,3,0,17,0,0,0,1,192,0,0,248,160,5,0,0,0,0,0,254,0,16,0,200,87,7,0,18,0,0,0,1,15,0,0,32,136,7,0,18,0,0,0,1,15,8,0,40,88,7,0,18,0,0,0,1,15,4,0,96,39,7,0,18,0,0,0,1,15,9,0,32,236,5,0,18,0,0,0,1,15,5,0,216,232,5,0,18,0,0,0,1,15,12,0,144,251,6,0,18,0,0,0,1,15,13,0,248,13,5,0,18,0,0,0,1,15,3,0,160,220,5,0,18,0,0,0,1,15,11,0,216,43,5,0,18,0,0,0,1,15,2,0,184,164,6,0,18,0,0,0,1,15,7,0,248,207,5,0,18,0,0,0,1,15,15,0,184,203,5,0,18,0,0,0,1,15,10,0,80,74,6,0,18,0,0,0,1,15,6,0,192,32,6,0,18,0,0,0,1,15,14,0,192,234,2,0,18,0,0,0,1,15,1,0,32,242,5,0,0,0,0,0,254,0,16,0,160,123,6,0,18,0,0,0,1,240,0,0,32,136,7,0,18,0,0,0,1,240,128,0,40,88,7,0,18,0,0,0,1,240,64,0,96,39,7,0,18,0,0,0,1,240,144,0,32,236,5,0,18,0,0,0,1,240,80,0,216,232,5,0,18,0,0,0,1,240,192,0,144,251,6,0,18,0,0,0,1,240,208,0,248,13,5,0,18,0,0,0,1,240,48,0,160,220,5,0,18,0,0,0,1,240,176,0,216,43,5,0,18,0,0,0,1,240,32,0,184,164,6,0,18,0,0,0,1,240,112,0,248,207,5,0,18,0,0,0,1,240,240,0,184,203,5,0,18,0,0,0,1,240,160,0,80,74,6,0,18,0,0,0,1,240,96,0,192,32,6,0,18,0,0,0,1,240,224,0,192,234,2,0,18,0,0,0,1,240,16,0,32,242,5,0,112,97,110,103,95,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,165,136,143,246,0,0,16,1,112,97,110,103,95,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,97,187,21,63,0,0,16,1,112,97,110,103,95,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,174,119,132,12,0,0,16,1,112,97,110,103,95,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,245,131,88,58,0,0,32,0,98,98,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,8,237,168,121,0,0,32,0,112,97,110,103,95,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,174,22,106,22,0,0,32,0,98,98,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,108,219,179,47,0,0,32,0,98,98,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,110,79,186,253,0,0,32,0,98,98,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,99,122,244,57,0,0,32,0,98,98,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,142,91,46,197,0,0,64,0,112,97,51,101,95,49,55,97,46,49,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,128,250,19,162,2,0,16,1,112,97,51,101,95,49,54,97,46,49,48,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,103,234,105,113,2,0,16,1,112,97,51,45,48,49,109,46,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,44,21,138,6,4,0,32,0,112,97,51,45,48,55,109,46,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,32,0,157,97,74,58,4,0,32,0,112,97,51,95,49,49,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,162,35,20,203,3,0,16,0,112,97,51,95,48,53,46,49,48,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,93,13,161,115,5,0,64,0,112,97,51,95,48,54,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,130,79,250,175,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,99,112,49,98,49,102,46,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,227,184,121,57,0,0,0,8,99,112,49,98,56,107,46,56,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,122,234,82,138,0,0,0,8,99,112,49,98,57,107,97,46,57,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,0,0,0,0,0,0,24,105,111,99,49,46,105,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,129,32,24,13,0,0,0,8,99,54,51,50,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,112,146,189,15,0,0,0,8,19,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,72,4,1,0,19,0,0,0,1,8,0,0,96,135,7,0,19,0,0,0,1,8,8,0,152,182,7,0,114,111,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,139,158,137,84,1,0,16,1,114,111,109,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,252,251,144,60,1,0,16,1,114,111,109,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,59,49,254,121,1,0,16,1,114,111,109,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,232,133,66,70,4,0,32,0,114,111,109,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,204,109,5,146,4,0,32,0,111,122,111,110,49,46,99,108,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,233,166,94,96,7,0,32,0,11,0,0,0,255,255,0,0,0,0,0,0,12,0,0,0,255,255,2,0,0,0,0,0,13,0,0,0,255,255,6,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,12,0,0,0,1,3,3,0,8,49,4,0,12,0,0,0,1,3,2,0,152,21,4,0,12,0,0,0,1,3,1,0,72,246,3,0,12,0,0,0,1,3,0,0,72,0,3,0,0,0,0,0,254,0,4,0,32,4,2,0,13,0,0,0,1,6,6,0,152,205,1,0,13,0,0,0,1,6,4,0,0,204,1,0,13,0,0,0,1,6,2,0,224,44,2,0,13,0,0,0,1,6,0,0,224,43,2,0,0,0,0,0,19,0,0,0,255,255,127,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,200,87,7,0,19,0,0,0,1,3,0,0,200,92,8,0,19,0,0,0,1,3,3,0,56,37,8,0,19,0,0,0,1,3,2,0,96,240,7,0,19,0,0,0,1,3,1,0,128,188,7,0,0,0,0,0,254,0,4,0,160,123,6,0,19,0,0,0,1,12,0,0,200,92,8,0,19,0,0,0,1,12,12,0,56,37,8,0,19,0,0,0,1,12,8,0,96,240,7,0,19,0,0,0,1,12,4,0,128,188,7,0,0,0,0,0,254,0,2,0,136,132,7,0,19,0,0,0,1,16,16,0,96,135,7,0,19,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,32,0,0,96,135,7,0,19,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,64,64,0,96,135,7,0,19,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,200,30,2,0,19,0,0,0,1,128,0,0,120,97,1,0,19,0,0,0,1,128,128,0,96,19,1,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,3,1,0,192,255,2,0,20,0,0,0,1,3,3,0,8,49,4,0,20,0,0,0,1,3,2,0,72,246,3,0,20,0,0,0,1,3,0,0,48,176,2,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,12,4,0,80,246,3,0,20,0,0,0,1,12,12,0,248,38,7,0,20,0,0,0,1,12,8,0,112,212,3,0,20,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,4,0,64,37,5,0,20,0,0,0,1,48,48,0,240,128,7,0,20,0,0,0,1,48,32,0,24,136,4,0,20,0,0,0,1,48,16,0,216,122,7,0,20,0,0,0,1,48,0,0,176,147,2,0,0,0,0,0,254,0,2,0,112,109,2,0,20,0,0,0,1,64,64,0,96,135,7,0,20,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,20,0,0,0,1,128,0,0,56,111,3,0,20,0,0,0,1,128,128,0,104,134,3,0,0,0,0,0,9,0,0,0,255,255,255,0,0,0,0,0,10,0,0,0,255,255,255,0,0,0,0,0,9,0,0,0,254,0,2,0,48,164,3,0,9,0,0,0,1,1,1,0,40,138,3,0,9,0,0,0,1,1,0,0,136,114,3,0,9,0,0,0,254,0,2,0,128,92,3,0,9,0,0,0,1,2,2,0,248,77,3,0,9,0,0,0,1,2,0,0,72,242,7,0,9,0,0,0,254,0,4,0,64,48,3,0,9,0,0,0,1,12,12,0,176,116,6,0,9,0,0,0,1,12,8,0,152,53,6,0,9,0,0,0,1,12,4,0,8,49,6,0,9,0,0,0,1,12,0,0,160,191,4,0,9,0,0,0,254,0,4,0,232,194,2,0,9,0,0,0,1,48,48,0,0,178,2,0,9,0,0,0,1,48,32,0,176,163,2,0,9,0,0,0,1,48,16,0,40,150,2,0,9,0,0,0,1,48,0,0,104,138,2,0,9,0,0,0,254,0,4,0,32,4,2,0,9,0,0,0,1,192,192,0,8,127,2,0,9,0,0,0,1,192,128,0,80,112,2,0,9,0,0,0,1,192,64,0,232,100,2,0,9,0,0,0,1,192,0,0,224,85,2,0,10,0,0,0,254,0,2,0,232,75,4,0,10,0,0,0,1,1,1,0,96,135,7,0,10,0,0,0,1,1,0,0,152,182,7,0,10,0,0,0,254,0,2,0,216,71,2,0,10,0,0,0,1,4,4,0,64,59,2,0,10,0,0,0,1,4,0,0,8,44,2,0,10,0,0,0,254,0,4,0,104,32,2,0,10,0,0,0,1,24,24,0,120,22,2,0,10,0,0,0,1,24,16,0,64,13,2,0,10,0,0,0,1,24,8,0,80,5,2,0,10,0,0,0,1,24,0,0,224,248,1,0,10,0,0,0,254,0,8,0,0,239,1,0,10,0,0,0,1,224,224,0,80,227,1,0,10,0,0,0,1,224,192,0,72,212,1,0,10,0,0,0,1,224,160,0,8,201,1,0,10,0,0,0,1,224,128,0,160,190,1,0,10,0,0,0,1,224,96,0,72,183,1,0,10,0,0,0,1,224,64,0,48,176,1,0,10,0,0,0,1,224,32,0,176,169,1,0,10,0,0,0,1,224,0,0,48,161,1,0,0,0,0,0,111,109,101,103,97,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,107,9,42,252,1,0,16,1,111,109,101,103,97,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,87,3,16,173,1,0,16,1,111,109,101,103,97,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,121,190,227,215,1,0,16,1,111,109,101,103,97,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,113,129,6,66,1,0,16,1,111,109,101,103,97,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,131,51,169,216,1,0,16,1,111,109,101,103,97,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,68,47,164,50,1,0,16,1,111,109,101,103,97,49,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,132,211,127,82,4,0,32,0,111,109,101,103,97,49,107,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,198,66,222,54,4,0,32,0,109,109,105,54,51,51,49,45,49,106,46,56,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,135,125,12,106,7,0,32,8,11,0,0,0,255,255,0,0,0,0,0,0,12,0,0,0,255,255,192,0,0,0,0,0,13,0,0,0,255,255,1,0,0,0,0,0,0,0,0,0,254,0,2,0,200,87,7,0,12,0,0,0,1,64,0,0,224,127,8,0,12,0,0,0,1,64,64,0,32,123,8,0,0,0,0,0,254,0,2,0,160,123,6,0,12,0,0,0,1,128,128,0,0,90,2,0,12,0,0,0,1,128,0,0,104,61,2,0,0,0,0,0,254,0,2,0,64,37,5,0,13,0,0,0,1,1,0,0,176,116,6,0,13,0,0,0,1,1,1,0,80,110,6,0,0,0,0,0,254,0,2,0,128,129,4,0,13,0,0,0,1,4,0,0,8,49,4,0,13,0,0,0,1,4,4,0,72,246,3,0,0,0,0,0,254,0,2,0,200,30,2,0,13,0,0,0,1,8,0,0,120,97,1,0,13,0,0,0,1,8,8,0,96,19,1,0,118,112,104,101,46,48,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,79,196,34,169,1,0,16,1,118,112,104,101,46,48,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,144,216,18,115,1,0,16,1,118,112,104,101,46,48,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,6,181,232,205,1,0,16,1,118,112,104,101,46,48,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,208,231,153,190,1,0,16,1,118,112,104,101,46,48,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,12,230,224,105,1,0,16,1,118,112,104,101,46,48,56,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,73,56,90,217,1,0,16,1,118,112,104,101,46,48,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,28,86,130,152,1,0,16,1,118,112,104,101,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,47,166,111,151,1,0,16,1,118,112,104,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,153,175,27,197,5,0,32,0,118,112,104,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,119,60,232,60,5,0,32,0,118,112,104,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,224,8,36,79,5,0,32,0,118,112,104,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,80,2,246,159,5,0,32,0,118,112,104,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,221,26,14,122,5,0,32,0,118,112,104,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,117,202,65,47,5,0,32,0,118,112,104,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,237,142,73,100,5,0,32,0,118,112,104,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,63,67,242,23,5,0,32,0,118,112,104,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,172,220,69,80,10,0,16,1,118,112,104,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,89,14,182,134,10,0,16,1,118,112,104,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,51,125,131,225,12,0,64,0,118,112,104,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,144,205,211,251,12,0,64,0,101,112,114,54,53,57,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,252,229,240,62,0,0,16,1,101,112,114,54,53,57,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,205,19,111,177,0,0,16,1,101,112,114,45,54,53,53,50,46,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,216,176,238,242,0,0,16,1,101,112,114,45,54,53,53,57,46,49,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,238,112,21,90,0,0,16,1,101,112,114,45,54,53,53,56,46,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,235,234,249,42,0,0,32,0,101,112,114,54,53,57,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,161,199,208,136,0,0,32,0,101,112,114,45,54,53,53,54,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,247,38,253,121,0,0,32,0,101,112,114,54,53,57,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,97,59,110,149,0,0,32,0,101,112,114,45,54,53,53,52,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,5,210,201,90,0,0,32,0,101,112,114,54,53,56,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,163,20,58,2,0,0,32,0,101,112,114,45,54,53,52,54,46,49,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,146,86,120,164,0,0,32,0,101,112,114,45,54,53,52,56,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,193,120,242,189,0,0,32,0,101,112,114,45,54,53,52,55,46,49,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,8,27,69,52,0,0,32,0,101,112,114,45,54,53,52,57,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,104,118,5,210,0,0,32,0,112,114,45,53,51,49,55,46,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,184,80,131,100,0,0,0,8,110,101,119,115,97,95,118,105,114,117,115,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,218,87,162,116,0,0,16,1,118,105,114,117,115,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,216,88,175,181,0,0,32,0,118,105,114,117,115,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,117,193,177,164,0,0,32,0,118,105,114,117,115,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,90,147,245,65,0,0,64,0,9,0,0,0,255,255,223,0,0,0,0,0,0,0,0,0,254,0,4,0,32,4,2,0,9,0,0,0,1,3,0,0,16,242,7,0,9,0,0,0,1,3,1,0,104,236,7,0,9,0,0,0,1,3,3,0,128,230,7,0,9,0,0,0,1,3,2,0,184,164,6,0,0,0,0,0,254,0,4,0,72,202,5,0,9,0,0,0,1,12,12,0,80,246,3,0,9,0,0,0,1,12,8,0,80,124,6,0,9,0,0,0,1,12,4,0,112,212,3,0,9,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,2,0,208,128,1,0,9,0,0,0,1,16,16,0,192,255,2,0,9,0,0,0,1,16,0,0,208,75,4,0,110,109,106,95,51,54,97,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,187,234,236,218,1,0,16,1,110,109,106,95,52,50,97,46,49,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,64,71,2,85,1,0,16,1,110,109,106,95,51,55,97,46,49,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,182,104,144,97,1,0,16,1,110,109,106,95,52,51,97,46,49,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,59,165,72,169,1,0,16,1,110,109,95,51,52,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,237,254,55,87,1,0,16,1,110,109,95,52,48,46,49,48,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,243,153,64,138,1,0,16,1,110,109,95,51,53,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,248,167,17,189,1,0,16,1,110,109,95,52,49,46,49,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,61,96,9,99,1,0,16,1,110,109,95,48,57,46,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,134,210,96,157,4,0,32,0,110,109,95,48,49,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,196,247,131,138,4,0,32,0,110,109,95,49,51,46,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,224,159,144,164,4,0,32,0,110,109,95,48,53,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,97,30,219,22,4,0,32,0,110,109,95,50,52,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,72,198,18,51,4,0,32,0,110,109,95,49,55,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,226,80,252,204,4,0,32,0,110,109,95,51,56,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,151,169,152,174,4,0,32,0,110,109,95,51,50,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,222,77,112,179,4,0,32,0,110,109,95,49,48,46,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,140,56,193,51,4,0,32,0,110,109,95,48,50,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,105,148,198,132,4,0,32,0,110,109,95,49,52,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,112,34,97,102,4,0,32,0,110,109,95,48,54,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,149,207,155,139,4,0,32,0,110,109,95,50,53,46,55,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,210,132,252,172,4,0,32,0,110,109,95,49,56,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,237,222,71,67,4,0,32,0,110,109,95,51,57,46,57,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,205,78,39,106,4,0,32,0,110,109,95,51,51,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,116,220,105,196,4,0,32,0,110,109,95,50,51,46,49,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,66,90,60,141,3,0,16,0,110,109,95,51,48,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,212,51,179,186,5,0,64,0,110,109,95,51,49,46,49,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,168,160,80,38,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,110,109,50,50,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,0,0,0,0,0,0,24,105,111,98,49,46,49,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,101,112,114,45,49,51,50,51,53,46,97,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,41,225,131,105,1,0,16,1,101,112,114,45,49,51,50,51,52,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,242,32,253,201,1,0,16,1,109,112,114,45,49,51,50,49,54,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,3,44,45,134,2,0,32,0,109,112,114,45,49,51,50,49,55,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,236,195,26,125,2,0,32,0,109,112,114,45,49,51,50,49,56,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,60,57,211,86,2,0,32,0,109,112,114,45,49,51,50,50,52,46,98,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,123,16,159,197,3,0,32,0,109,112,114,45,49,51,50,51,49,46,97,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,70,99,233,165,3,0,32,0,109,112,114,45,49,51,50,50,51,46,98,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,255,96,79,54,3,0,32,0,109,112,114,45,49,51,50,51,48,46,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,31,9,80,149,3,0,32,0,109,112,114,45,49,51,50,50,50,46,98,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,237,243,61,82,3,0,32,0,109,112,114,45,49,51,50,50,57,46,97,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,93,196,13,244,3,0,32,0,101,112,114,45,49,51,50,50,49,46,98,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,106,84,231,154,3,0,32,0,101,112,114,45,49,51,50,50,56,46,97,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,190,134,55,222,3,0,32,0,101,112,114,45,49,51,50,50,53,46,97,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,43,232,194,86,4,0,16,1,109,112,114,45,49,51,50,49,57,46,98,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,31,6,226,25,19,0,64,0,109,112,114,45,49,51,50,50,48,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,206,217,212,88,19,0,64,0,109,112,114,45,49,51,50,52,57,46,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,93,220,62,98,19,0,64,0,51,49,55,45,48,49,53,57,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,240,56,120,80,5,0,16,1,51,49,53,45,53,52,51,55,46,105,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,193,59,246,75,16,0,16,0,30,0,0,0,255,255,255,0,0,0,0,0,31,0,0,0,255,255,253,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,30,0,0,0,1,15,7,0,80,252,6,0,30,0,0,0,1,15,8,0,16,242,7,0,30,0,0,0,1,15,9,0,104,236,7,0,30,0,0,0,1,15,5,0,176,51,4,0,30,0,0,0,1,15,4,0,56,24,4,0,30,0,0,0,1,15,15,0,128,230,7,0,30,0,0,0,1,15,1,0,72,216,3,0,30,0,0,0,1,15,2,0,24,188,3,0,30,0,0,0,1,15,3,0,176,162,3,0,30,0,0,0,1,15,6,0,120,211,6,0,30,0,0,0,1,15,14,0,184,164,6,0,30,0,0,0,1,15,13,0,80,74,6,0,30,0,0,0,1,15,12,0,192,32,6,0,30,0,0,0,1,15,11,0,192,234,2,0,30,0,0,0,1,15,10,0,32,242,5,0,30,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,30,0,0,0,1,240,112,0,80,252,6,0,30,0,0,0,1,240,128,0,16,242,7,0,30,0,0,0,1,240,144,0,104,236,7,0,30,0,0,0,1,240,80,0,176,51,4,0,30,0,0,0,1,240,64,0,56,24,4,0,30,0,0,0,1,240,240,0,128,230,7,0,30,0,0,0,1,240,16,0,72,216,3,0,30,0,0,0,1,240,32,0,24,188,3,0,30,0,0,0,1,240,48,0,176,162,3,0,30,0,0,0,1,240,96,0,120,211,6,0,30,0,0,0,1,240,224,0,184,164,6,0,30,0,0,0,1,240,208,0,80,74,6,0,30,0,0,0,1,240,192,0,192,32,6,0,30,0,0,0,1,240,176,0,192,234,2,0,30,0,0,0,1,240,160,0,32,242,5,0,30,0,0,0,1,240,0,0,208,236,2,0,0,0,0,0,254,0,2,0,88,131,3,0,31,0,0,0,1,1,1,0,96,135,7,0,31,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,31,0,0,0,1,2,2,0,96,135,7,0,31,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,128,129,4,0,31,0,0,0,1,4,4,0,208,75,4,0,31,0,0,0,1,4,0,0,8,49,4,0,0,0,0,0,254,0,2,0,192,7,8,0,31,0,0,0,1,8,8,0,112,134,3,0,31,0,0,0,1,8,0,0,64,111,3,0,0,0,0,0,254,0,2,0,112,242,7,0,31,0,0,0,1,16,16,0,240,242,5,0,31,0,0,0,1,16,0,0,8,140,6,0,0,0,0,0,254,0,2,0,8,93,1,0,31,0,0,0,1,32,32,0,136,86,1,0,31,0,0,0,1,32,0,0,232,78,1,0,0,0,0,0,254,0,4,0,72,202,5,0,31,0,0,0,1,192,128,0,80,246,3,0,31,0,0,0,1,192,192,0,248,38,7,0,31,0,0,0,1,192,64,0,112,212,3,0,31,0,0,0,1,192,0,0,248,160,5,0,0,0,0,0,109,118,99,117,46,48,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,87,117,0,198,1,0,16,1,109,118,99,117,46,48,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,32,43,75,114,1,0,16,1,109,118,99,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,134,142,140,45,1,0,16,1,109,118,99,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,245,225,40,133,1,0,16,1,109,118,99,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,43,163,186,195,1,0,16,1,109,118,99,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,205,47,0,188,1,0,16,1,109,118,99,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,38,123,198,1,0,16,1,109,118,99,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,38,30,221,15,1,0,16,1,109,118,99,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,188,116,95,250,5,0,32,0,109,118,99,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,143,138,147,113,5,0,32,0,109,118,99,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,7,29,116,146,5,0,32,0,109,118,99,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,198,47,183,188,5,0,32,0,109,118,99,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,228,244,29,127,5,0,32,0,109,118,99,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,3,50,189,144,5,0,32,0,109,118,99,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,39,247,170,103,5,0,32,0,109,118,99,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,232,173,11,139,5,0,32,0,109,118,99,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,149,158,98,65,10,0,16,1,109,118,99,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,107,191,58,150,10,0,16,1,109,118,99,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,99,230,15,133,12,0,64,0,109,118,99,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,150,24,203,124,12,0,64,0,109,118,99,106,46,48,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,121,136,241,61,1,0,16,1,109,118,99,106,46,48,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,232,18,210,7,1,0,16,1,109,118,99,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,134,142,140,45,1,0,16,1,109,118,99,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,245,225,40,133,1,0,16,1,109,118,99,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,43,163,186,195,1,0,16,1,109,118,99,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,205,47,0,188,1,0,16,1,109,118,99,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,38,123,198,1,0,16,1,109,118,99,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,38,30,221,15,1,0,16,1,109,118,99,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,188,116,95,250,5,0,32,0,109,118,99,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,143,138,147,113,5,0,32,0,109,118,99,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,7,29,116,146,5,0,32,0,109,118,99,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,198,47,183,188,5,0,32,0,109,118,99,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,228,244,29,127,5,0,32,0,109,118,99,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,3,50,189,144,5,0,32,0,109,118,99,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,39,247,170,103,5,0,32,0,109,118,99,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,232,173,11,139,5,0,32,0,109,118,99,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,149,158,98,65,10,0,16,1,109,118,99,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,107,191,58,150,10,0,16,1,109,118,99,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,99,230,15,133,12,0,64,0,109,118,99,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,150,24,203,124,12,0,64,0,109,118,99,104,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,247,201,14,106,1,0,16,1,109,118,99,104,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,164,63,240,0,1,0,16,1,109,118,99,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,134,142,140,45,1,0,16,1,109,118,99,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,245,225,40,133,1,0,16,1,109,118,99,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,43,163,186,195,1,0,16,1,109,118,99,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,205,47,0,188,1,0,16,1,109,118,99,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,38,123,198,1,0,16,1,109,118,99,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,38,30,221,15,1,0,16,1,109,118,99,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,188,116,95,250,5,0,32,0,109,118,99,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,143,138,147,113,5,0,32,0,109,118,99,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,7,29,116,146,5,0,32,0,109,118,99,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,198,47,183,188,5,0,32,0,109,118,99,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,228,244,29,127,5,0,32,0,109,118,99,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,3,50,189,144,5,0,32,0,109,118,99,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,39,247,170,103,5,0,32,0,109,118,99,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,232,173,11,139,5,0,32,0,109,118,99,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,149,158,98,65,10,0,16,1,109,118,99,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,107,191,58,150,10,0,16,1,109,118,99,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,99,230,15,133,12,0,64,0,109,118,99,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,150,24,203,124,12,0,64,0,109,118,99,98,46,48,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,59,149,85,113,1,0,16,1,109,118,99,98,46,48,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,14,125,17,251,1,0,16,1,109,118,99,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,134,142,140,45,1,0,16,1,109,118,99,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,245,225,40,133,1,0,16,1,109,118,99,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,43,163,186,195,1,0,16,1,109,118,99,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,205,47,0,188,1,0,16,1,109,118,99,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,38,123,198,1,0,16,1,109,118,99,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,38,30,221,15,1,0,16,1,109,118,99,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,188,116,95,250,5,0,32,0,109,118,99,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,143,138,147,113,5,0,32,0,109,118,99,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,7,29,116,146,5,0,32,0,109,118,99,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,198,47,183,188,5,0,32,0,109,118,99,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,228,244,29,127,5,0,32,0,109,118,99,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,3,50,189,144,5,0,32,0,109,118,99,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,39,247,170,103,5,0,32,0,109,118,99,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,232,173,11,139,5,0,32,0,109,118,99,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,149,158,98,65,10,0,16,1,109,118,99,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,107,191,58,150,10,0,16,1,109,118,99,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,99,230,15,133,12,0,64,0,109,118,99,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,150,24,203,124,12,0,64,0,109,118,99,97,46,48,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,37,174,244,47,1,0,16,1,109,118,99,97,46,48,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,239,39,132,242,1,0,16,1,109,118,99,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,134,142,140,45,1,0,16,1,109,118,99,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,245,225,40,133,1,0,16,1,109,118,99,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,43,163,186,195,1,0,16,1,109,118,99,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,205,47,0,188,1,0,16,1,109,118,99,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,38,123,198,1,0,16,1,109,118,99,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,38,30,221,15,1,0,16,1,109,118,99,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,188,116,95,250,5,0,32,0,109,118,99,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,143,138,147,113,5,0,32,0,109,118,99,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,7,29,116,146,5,0,32,0,109,118,99,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,198,47,183,188,5,0,32,0,109,118,99,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,228,244,29,127,5,0,32,0,109,118,99,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,3,50,189,144,5,0,32,0,109,118,99,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,39,247,170,103,5,0,32,0,109,118,99,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,232,173,11,139,5,0,32,0,109,118,99,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,149,158,98,65,10,0,16,1,109,118,99,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,107,191,58,150,10,0,16,1,109,118,99,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,99,230,15,133,12,0,64,0,109,118,99,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,150,24,203,124,12,0,64,0,109,115,104,117,100,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,198,196,216,193,1,0,16,1,109,115,104,117,100,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,22,218,61,231,1,0,16,1,109,115,104,117,100,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,132,62,73,59,1,0,16,1,109,115,104,46,48,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,164,63,62,128,1,0,16,1,109,115,104,46,48,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,142,95,196,1,0,16,1,109,115,104,46,48,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,44,241,166,156,1,0,16,1,109,115,104,46,48,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,175,39,236,130,1,0,16,1,109,115,104,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,150,17,147,141,1,0,16,1,109,115,104,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,102,69,209,9,5,0,32,0,109,115,104,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,87,32,150,238,5,0,32,0,109,115,104,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,20,206,78,96,5,0,32,0,109,115,104,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,232,49,167,148,5,0,32,0,109,115,104,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,62,151,151,65,5,0,32,0,109,115,104,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,160,164,141,67,5,0,32,0,109,115,104,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,148,45,185,77,5,0,32,0,109,115,104,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,192,198,176,162,5,0,32,0,109,115,104,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,249,230,118,201,10,0,16,1,109,115,104,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,217,208,103,206,10,0,16,1,109,115,104,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,48,109,172,55,12,0,64,0,109,115,104,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,112,37,9,222,12,0,64,0,109,112,110,101,46,48,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,159,252,22,254,1,0,16,1,109,112,110,101,46,48,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,34,236,197,44,1,0,16,1,109,112,110,45,115,105,109,109,46,48,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,107,182,141,56,6,0,32,0,109,112,110,45,115,105,109,109,46,48,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,148,180,241,175,6,0,32,0,109,112,110,45,115,105,109,109,46,48,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,123,133,196,169,6,0,32,0,109,112,110,45,115,105,109,109,46,48,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,34,223,89,247,6,0,32,0,109,112,110,45,115,105,109,109,46,48,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,32,183,198,222,6,0,32,0,109,112,110,45,115,105,109,109,46,48,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,24,76,119,248,6,0,32,0,109,112,110,45,115,105,109,109,46,48,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,236,164,174,194,6,0,32,0,109,112,110,45,115,105,109,109,46,48,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,51,220,214,132,6,0,32,0,109,112,110,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,182,173,199,144,10,0,16,1,109,112,110,45,115,105,109,109,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,33,46,138,49,13,0,64,0,109,112,110,45,115,105,109,109,46,48,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,232,244,98,84,13,0,64,0])
.concat([184,40,2,0,1,0,0,0,72,234,148,0,248,191,2,0,56,250,6,0,1,0,0,0,75,234,148,0,184,160,2,0,184,164,8,0,1,0,0,0,73,234,148,0,64,246,1,0,88,149,7,0,1,0,0,0,76,234,148,0,136,224,1,0,56,210,6,0,1,0,0,0,138,233,148,0,192,135,2,0,24,163,6,0,1,0,0,0,139,233,148,0,240,108,2,0,152,122,6,0,1,0,0,0,136,233,148,0,96,82,2,0,192,72,6,0,1,0,0,0,137,233,148,0,32,56,2,0,48,123,2,0,1,0,0,0,140,233,148,0,152,30,2,0,96,69,2,0,1,0,0,0,141,233,148,0,232,10,2,0,144,55,2,0,1,0,0,0,142,233,148,0,152,138,8,0,176,223,1,0,1,0,0,0,202,232,148,0,72,198,1,0,192,209,1,0,1,0,0,0,203,232,148,0,24,182,1,0,24,198,1,0,1,0,0,0,200,232,148,0,40,167,1,0,120,189,1,0,1,0,0,0,201,232,148,0,200,149,1,0,248,187,8,0,1,0,0,0,204,232,148,0,56,126,1,0,184,179,8,0,1,0,0,0,205,232,148,0,32,101,1,0,240,173,8,0,1,0,0,0,206,232,148,0,96,32,8,0,88,212,3,0,1,0,0,0,248,221,146,0,40,185,3,0,16,17,8,0,1,0,0,0,78,234,148,0,224,12,8,0,248,5,8,0,9,0,0,0,240,94,147,0,32,58,1,0,144,250,7,0,9,0,0,0,241,94,147,0,32,58,1,0,248,241,7,0,9,0,0,0,242,94,147,0,32,58,1,0,115,111,50,95,51,48,101,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,247,155,127,225,1,0,16,1,115,111,50,95,51,53,101,46,49,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,117,53,230,120,1,0,16,1,115,111,50,95,51,49,101,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,54,77,32,81,1,0,16,1,115,111,50,95,51,54,101,46,49,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,180,168,251,156,1,0,16,1,115,111,50,45,51,50,109,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,12,207,181,46,2,0,16,1,115,111,50,45,54,109,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,175,2,97,170,4,0,32,0,115,111,50,45,56,109,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,105,104,158,131,4,0,32,0,115,111,50,45,50,109,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,117,40,124,89,4,0,32,0,115,111,50,45,52,109,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,160,156,42,145,4,0,32,0,115,111,50,95,50,52,46,55,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,254,78,37,63,4,0,32,0,115,111,50,95,49,52,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,94,144,168,245,4,0,32,0,115,111,50,95,50,54,46,57,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,74,90,170,243,4,0,32,0,115,111,50,95,49,54,46,57,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,168,209,60,180,4,0,32,0,115,111,50,95,50,48,46,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,163,81,167,140,4,0,32,0,115,111,50,95,49,48,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,253,105,245,233,4,0,32,0,115,111,50,95,50,50,46,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,119,163,233,252,4,0,32,0,115,111,50,95,49,50,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,6,138,223,183,4,0,32,0,115,111,50,95,48,57,46,49,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,122,124,157,208,3,0,16,0,115,111,50,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,67,22,234,187,5,0,64,0,115,111,50,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,113,170,88,172,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,111,50,50,52,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,205,200,17,194,0,0,0,8,105,111,98,49,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,99,54,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,0,0,0,0,0,0,24,27,0,0,0,255,255,0,0,0,0,0,0,28,0,0,0,255,255,3,0,0,0,0,0,29,0,0,0,255,255,96,0,0,0,0,0,0,0,0,0,254,0,8,0,32,4,2,0,27,0,0,0,1,7,7,0,80,252,6,0,27,0,0,0,1,7,6,0,16,242,7,0,27,0,0,0,1,7,5,0,104,236,7,0,27,0,0,0,1,7,0,0,128,230,7,0,27,0,0,0,1,7,1,0,184,164,6,0,27,0,0,0,1,7,2,0,80,74,6,0,27,0,0,0,1,7,3,0,192,32,6,0,27,0,0,0,1,7,4,0,32,242,5,0,0,0,0,0,254,0,2,0,64,232,1,0,27,0,0,0,1,64,0,0,96,135,7,0,27,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,8,0,72,202,5,0,28,0,0,0,1,7,0,0,72,198,6,0,28,0,0,0,1,7,1,0,208,75,4,0,28,0,0,0,1,7,2,0,8,49,4,0,28,0,0,0,1,7,3,0,72,195,6,0,28,0,0,0,1,7,4,0,72,246,3,0,28,0,0,0,1,7,5,0,72,0,3,0,28,0,0,0,1,7,6,0,64,47,7,0,28,0,0,0,1,7,7,0,48,173,6,0,0,0,0,0,254,0,2,0,88,160,1,0,28,0,0,0,1,8,8,0,192,255,2,0,28,0,0,0,1,8,0,0,8,49,4,0,0,0,0,0,254,0,2,0,112,242,7,0,28,0,0,0,1,16,16,0,96,90,6,0,28,0,0,0,1,16,0,0,24,106,1,0,0,0,0,0,254,0,2,0,72,4,1,0,29,0,0,0,1,8,0,0,96,135,7,0,29,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,29,0,0,0,1,16,0,0,96,135,7,0,29,0,0,0,1,16,16,0,152,182,7,0,0,0,0,0,254,0,2,0,40,111,8,0,29,0,0,0,1,32,0,0,96,135,7,0,29,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,29,0,0,0,1,64,0,0,96,135,7,0,29,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,29,0,0,0,1,128,0,0,96,135,7,0,29,0,0,0,1,128,128,0,152,182,7,0,0,0,0,0,116,109,97,49,45,99,45,55,102,95,102,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,20,224,198,192,0,0,16,1,116,109,97,49,45,99,45,55,101,95,102,46,55,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,214,96,251,148,0,0,16,1,116,109,97,49,45,99,45,55,100,95,102,46,55,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,193,182,206,220,0,0,16,1,116,109,97,49,45,99,45,55,99,95,102,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,107,217,99,74,0,0,16,1,116,109,97,49,45,99,45,54,107,95,101,46,54,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,133,255,185,6,0,0,16,1,116,109,97,49,45,118,45,51,102,46,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,44,196,176,40,0,0,32,0,116,109,97,49,45,118,45,51,106,46,51,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,77,192,140,12,0,0,32,0,116,109,97,49,45,118,45,55,109,46,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,46,55,183,34,0,0,32,0,116,109,97,49,45,118,45,55,110,46,55,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,71,31,58,79,0,0,32,0,116,109,97,49,45,118,45,55,112,46,55,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,205,108,190,86,0,0,32,0,116,109,97,49,45,118,45,55,115,46,55,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,19,214,241,86,0,0,32,0,116,109,97,49,45,118,45,55,116,46,55,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,8,0,31,100,0,0,32,0,116,109,97,49,45,118,45,55,117,46,55,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,9,83,175,123,0,0,32,0,116,109,97,49,45,99,45,52,112,95,49,46,52,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,134,210,135,129,0,0,32,0,116,109,97,49,45,99,45,53,112,46,53,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,152,96,216,88,0,0,32,0,0,0,0,0,0,0,0,0,184,40,2,0,1,0,0,0,139,228,148,0,248,191,2,0,56,250,6,0,1,0,0,0,136,228,148,0,184,160,2,0,184,164,8,0,1,0,0,0,124,228,148,0,64,246,1,0,88,149,7,0,1,0,0,0,137,228,148,0,136,224,1,0,240,167,7,0,1,0,0,0,131,228,148,0,192,135,2,0,176,163,7,0,1,0,0,0,130,228,148,0,240,108,2,0,208,158,7,0,1,0,0,0,129,228,148,0,96,82,2,0,184,154,7,0,1,0,0,0,128,228,148,0,32,56,2,0,176,108,2,0,1,0,0,0,135,228,148,0,152,30,2,0,128,98,2,0,1,0,0,0,133,228,148,0,232,10,2,0,8,96,7,0,1,0,0,0,123,228,148,0,72,198,1,0,48,89,7,0,1,0,0,0,122,228,148,0,24,182,1,0,16,83,7,0,1,0,0,0,121,228,148,0,40,167,1,0,96,79,7,0,1,0,0,0,120,228,148,0,200,149,1,0,48,76,7,0,1,0,0,0,127,228,148,0,56,126,1,0,144,72,7,0,1,0,0,0,125,228,148,0,32,101,1,0,88,212,3,0,1,0,0,0,24,214,146,0,40,185,3,0,16,17,8,0,1,0,0,0,138,228,148,0,224,12,8,0,248,5,8,0,9,0,0,0,200,93,147,0,32,58,1,0,144,250,7,0,9,0,0,0,201,93,147,0,32,58,1,0,19,0,0,0,255,255,127,0,0,0,0,0,20,0,0,0,255,255,0,0,0,0,0,0,21,0,0,0,255,255,254,0,0,0,0,0,0,0,0,0,254,0,4,0,40,148,2,0,19,0,0,0,1,3,3,0,40,136,2,0,19,0,0,0,1,3,2,0,176,123,2,0,19,0,0,0,1,3,1,0,176,109,2,0,19,0,0,0,1,3,0,0,208,98,2,0,0,0,0,0,254,0,2,0,200,82,2,0,19,0,0,0,1,4,4,0,96,135,7,0,19,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,19,0,0,0,1,24,24,0,8,49,4,0,19,0,0,0,1,24,16,0,152,21,4,0,19,0,0,0,1,24,8,0,72,246,3,0,19,0,0,0,1,24,0,0,216,128,5,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,64,64,0,96,135,7,0,19,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,200,30,2,0,19,0,0,0,1,128,0,0,120,97,1,0,19,0,0,0,1,128,128,0,96,19,1,0,0,0,0,0,254,0,16,0,0,70,2,0,20,0,0,0,1,15,15,0,120,247,3,0,20,0,0,0,1,15,14,0,104,213,3,0,20,0,0,0,1,15,13,0,224,185,3,0,20,0,0,0,1,15,12,0,144,160,3,0,20,0,0,0,1,15,11,0,96,135,3,0,20,0,0,0,1,15,10,0,32,136,7,0,20,0,0,0,1,15,9,0,40,88,7,0,20,0,0,0,1,15,8,0,96,39,7,0,20,0,0,0,1,15,0,0,144,251,6,0,20,0,0,0,1,15,1,0,184,164,6,0,20,0,0,0,1,15,2,0,80,74,6,0,20,0,0,0,1,15,3,0,192,32,6,0,20,0,0,0,1,15,4,0,192,234,2,0,20,0,0,0,1,15,5,0,32,242,5,0,20,0,0,0,1,15,6,0,176,192,2,0,20,0,0,0,1,15,7,0,248,175,2,0,0,0,0,0,254,0,16,0,192,56,2,0,20,0,0,0,1,240,240,0,120,247,3,0,20,0,0,0,1,240,224,0,104,213,3,0,20,0,0,0,1,240,208,0,224,185,3,0,20,0,0,0,1,240,192,0,144,160,3,0,20,0,0,0,1,240,176,0,96,135,3,0,20,0,0,0,1,240,160,0,32,136,7,0,20,0,0,0,1,240,144,0,40,88,7,0,20,0,0,0,1,240,128,0,96,39,7,0,20,0,0,0,1,240,0,0,144,251,6,0,20,0,0,0,1,240,16,0,184,164,6,0,20,0,0,0,1,240,32,0,80,74,6,0,20,0,0,0,1,240,48,0,192,32,6,0,20,0,0,0,1,240,64,0,192,234,2,0,20,0,0,0,1,240,80,0,32,242,5,0,20,0,0,0,1,240,96,0,176,192,2,0,20,0,0,0,1,240,112,0,248,175,2,0,0,0,0,0,254,0,2,0,168,234,7,0,21,0,0,0,1,1,1,0,96,135,7,0,21,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,24,31,2,0,21,0,0,0,1,2,2,0,56,20,2,0,21,0,0,0,1,2,0,0,56,11,2,0,0,0,0,0,254,0,4,0,72,202,5,0,21,0,0,0,1,12,12,0,160,246,1,0,21,0,0,0,1,12,8,0,80,246,3,0,21,0,0,0,1,12,4,0,248,38,7,0,21,0,0,0,1,12,0,0,112,212,3,0,0,0,0,0,254,0,2,0,136,198,1,0,21,0,0,0,1,16,16,0,192,189,1,0,21,0,0,0,1,16,0,0,96,182,1,0,0,0,0,0,254,0,2,0,144,123,2,0,21,0,0,0,1,32,0,0,64,171,7,0,21,0,0,0,1,32,32,0,152,167,1,0,0,0,0,0,254,0,2,0,112,109,2,0,21,0,0,0,1,64,64,0,96,135,7,0,21,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,88,160,1,0,21,0,0,0,1,128,128,0,168,82,2,0,21,0,0,0,1,128,0,0,240,69,2,0,0,0,0,0,108,114,45,97,45,52,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,77,42,126,93,0,0,16,1,108,114,45,97,45,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,115,4,242,150,0,0,16,1,108,114,45,97,45,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,169,196,65,176,0,0,16,1,108,114,45,97,45,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,170,66,94,100,0,0,16,1,108,114,45,97,45,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,205,172,150,122,0,0,16,1,108,114,45,97,45,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,57,57,127,63,0,0,16,1,108,114,45,101,45,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,141,181,249,36,0,0,32,0,108,114,45,101,45,50,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,8,94,23,67,0,0,32,0,108,114,45,101,45,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,36,113,49,224,0,0,32,0,108,114,45,98,45,52,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,62,64,65,129,0,0,32,0,108,114,45,98,45,51,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,84,65,21,85,0,0,32,0,108,114,45,98,45,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,208,52,78,146,0,0,32,0,108,114,45,101,45,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,22,4,4,83,0,0,32,0,108,114,45,98,45,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,37,28,174,75,0,0,32,0,108,114,45,101,45,51,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,55,96,120,103,0,0,32,0,108,114,45,98,45,49,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,148,219,211,156,0,0,32,0,108,114,45,101,45,51,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,55,104,113,91,0,0,32,0,108,114,45,98,45,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,154,207,216,8,0,0,32,0,108,114,45,98,45,53,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,226,105,31,224,0,0,32,0,108,114,45,98,45,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,60,141,216,52,0,0,32,0,18,0,0,0,255,255,255,0,0,0,0,0,19,0,0,0,255,255,253,0,0,0,0,0,0,0,0,0,254,0,4,0,216,238,6,0,18,0,0,0,1,3,3,0,248,81,6,0,18,0,0,0,1,3,2,0,80,124,6,0,18,0,0,0,1,3,1,0,176,64,8,0,18,0,0,0,1,3,0,0,128,65,6,0,0,0,0,0,254,0,4,0,128,129,4,0,18,0,0,0,1,12,8,0,208,75,4,0,18,0,0,0,1,12,12,0,8,49,4,0,18,0,0,0,1,12,4,0,152,21,4,0,18,0,0,0,1,12,0,0,72,246,3,0,0,0,0,0,254,0,15,0,32,4,2,0,18,0,0,0,2,240,144,0,176,79,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,160,0,8,32,4,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,176,0,96,164,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,192,0,144,102,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,208,0,176,45,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,224,0,224,127,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,240,0,32,123,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,112,0,192,110,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,96,0,96,102,7,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,80,0,184,105,6,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,64,0,152,96,3,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,48,0,192,100,6,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,32,0,64,1,1,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,16,0,184,69,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,2,240,0,0,104,151,6,0,19,0,0,0,0,4,4,0,0,0,0,0,0,0,0,0,254,0,4,0,200,87,7,0,18,0,0,0,130,48,16,0,176,45,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,130,48,32,0,224,127,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,130,48,48,0,32,123,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,130,48,0,0,16,227,4,0,19,0,0,0,0,4,4,0,0,0,0,0,0,0,0,0,254,0,4,0,160,123,6,0,18,0,0,0,130,192,192,0,192,110,8,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,130,192,128,0,96,102,7,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,130,192,64,0,152,96,3,0,19,0,0,0,0,4,4,0,0,0,0,0,18,0,0,0,130,192,0,0,192,100,6,0,19,0,0,0,0,4,4,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,1,1,0,96,135,7,0,19,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,200,30,2,0,19,0,0,0,1,2,0,0,120,97,1,0,19,0,0,0,1,2,2,0,96,19,1,0,0,0,0,0,254,0,2,0,96,46,8,0,19,0,0,0,1,4,4,0,208,233,4,0,19,0,0,0,1,4,0,0,72,197,4,0,0,0,0,0,254,0,2,0,72,4,1,0,19,0,0,0,1,16,16,0,96,135,7,0,19,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,2,0,32,228,8,0,19,0,0,0,1,32,32,0,96,135,7,0,19,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,246,3,0,19,0,0,0,1,64,64,0,96,135,7,0,19,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,128,128,0,96,135,7,0,19,0,0,0,1,128,0,0,152,182,7,0,107,100,101,95,51,48,46,49])
.concat([49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,212,79,65,199,1,0,16,1,107,100,101,95,51,55,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,210,64,191,165,1,0,16,1,107,100,101,95,51,49,46,49,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,189,199,255,31,1,0,16,1,107,100,101,95,51,56,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,130,122,229,137,1,0,16,1,107,100,101,95,50,56,46,57,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,217,188,103,147,1,0,16,1,107,100,101,95,51,53,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,138,164,166,76,1,0,16,1,107,100,101,95,50,57,46,49,48,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,120,168,11,106,1,0,16,1,107,100,101,95,51,54,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,157,179,9,181,1,0,16,1,107,100,45,53,109,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,135,91,228,4,0,32,0,107,100,45,55,109,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,34,3,117,167,4,0,32,0,107,100,45,49,109,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,120,191,116,95,4,0,32,0,107,100,45,51,109,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,191,3,83,94,4,0,32,0,107,100,45,54,109,46,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,243,88,51,17,4,0,32,0,107,100,45,56,109,46,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,68,60,133,56,4,0,32,0,107,100,45,50,109,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,4,102,243,158,4,0,32,0,107,100,45,52,109,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,79,155,43,64,4,0,32,0,107,100,95,57,40,95,95,107,111,100,114,49,41,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,16,69,81,245,3,0,16,0,107,100,95,49,56,40,95,95,107,111,100,114,49,41,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,200,178,236,105,5,0,64,0,107,100,95,49,57,40,95,95,107,111,100,114,49,41,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,193,81,216,2,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,107,100,50,57,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,0,0,0,0,0,0,24,105,111,98,49,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,105,111,99,49,46,105,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,129,32,24,13,0,0,0,8,99,54,51,50,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,112,146,189,15,0,0,0,8,27,0,0,0,255,255,0,0,0,0,0,0,28,0,0,0,255,255,3,0,0,0,0,0,29,0,0,0,255,255,96,0,0,0,0,0,0,0,0,0,254,0,8,0,32,4,2,0,27,0,0,0,1,7,7,0,80,252,6,0,27,0,0,0,1,7,6,0,16,242,7,0,27,0,0,0,1,7,5,0,104,236,7,0,27,0,0,0,1,7,0,0,128,230,7,0,27,0,0,0,1,7,1,0,184,164,6,0,27,0,0,0,1,7,2,0,80,74,6,0,27,0,0,0,1,7,3,0,192,32,6,0,27,0,0,0,1,7,4,0,32,242,5,0,0,0,0,0,254,0,2,0,88,160,1,0,27,0,0,0,1,8,8,0,192,255,2,0,27,0,0,0,1,8,0,0,8,49,4,0,0,0,0,0,254,0,2,0,112,242,7,0,27,0,0,0,1,16,16,0,240,242,5,0,27,0,0,0,1,16,0,0,8,140,6,0,0,0,0,0,254,0,2,0,64,232,1,0,27,0,0,0,1,64,0,0,96,135,7,0,27,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,8,0,72,202,5,0,28,0,0,0,1,7,0,0,72,198,6,0,28,0,0,0,1,7,1,0,208,75,4,0,28,0,0,0,1,7,2,0,8,49,4,0,28,0,0,0,1,7,3,0,72,195,6,0,28,0,0,0,1,7,4,0,72,246,3,0,28,0,0,0,1,7,5,0,72,0,3,0,28,0,0,0,1,7,6,0,64,47,7,0,28,0,0,0,1,7,7,0,48,173,6,0,0,0,0,0,254,0,8,0,128,129,4,0,28,0,0,0,1,56,8,0,192,255,2,0,28,0,0,0,1,56,0,0,208,75,4,0,28,0,0,0,1,56,16,0,8,49,4,0,28,0,0,0,1,56,24,0,152,21,4,0,28,0,0,0,1,56,32,0,72,246,3,0,28,0,0,0,1,56,40,0,72,0,3,0,28,0,0,0,1,56,48,0,64,47,7,0,28,0,0,0,1,56,56,0,232,99,5,0,0,0,0,0,254,0,4,0,64,37,5,0,28,0,0,0,1,192,64,0,192,83,1,0,28,0,0,0,1,192,0,0,32,83,1,0,28,0,0,0,1,192,128,0,160,81,1,0,28,0,0,0,1,192,192,0,120,7,5,0,0,0,0,0,254,0,2,0,16,227,4,0,29,0,0,0,1,4,0,0,96,135,7,0,29,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,254,0,2,0,72,4,1,0,29,0,0,0,1,8,0,0,96,135,7,0,29,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,29,0,0,0,1,16,0,0,96,135,7,0,29,0,0,0,1,16,16,0,152,182,7,0,0,0,0,0,254,0,2,0,40,111,8,0,29,0,0,0,1,32,0,0,96,135,7,0,29,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,29,0,0,0,1,64,0,0,96,135,7,0,29,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,168,79,2,0,29,0,0,0,1,128,0,0,32,182,8,0,29,0,0,0,1,128,128,0,80,251,6,0,107,100,106,95,51,54,97,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,173,136,199,235,1,0,16,1,107,100,106,95,52,50,97,46,49,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,41,53,92,229,1,0,16,1,107,100,106,95,51,55,97,46,49,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,34,215,16,199,1,0,16,1,107,100,106,95,52,51,97,46,49,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,58,237,214,87,1,0,16,1,107,100,95,51,52,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,217,188,103,147,1,0,16,1,107,100,95,52,48,46,49,48,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,138,164,166,76,1,0,16,1,107,100,95,51,53,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,114,250,96,3,1,0,16,1,107,100,95,52,49,97,46,49,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,248,206,163,149,1,0,16,1,107,100,95,57,46,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,227,152,26,64,4,0,32,0,107,100,95,49,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,154,57,148,88,4,0,32,0,107,100,95,49,51,46,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,49,81,104,182,4,0,32,0,107,100,95,53,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,179,154,155,194,4,0,32,0,107,100,95,50,52,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,219,143,0,151,4,0,32,0,107,100,95,49,55,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,211,131,154,220,4,0,32,0,107,100,95,51,56,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,209,210,61,156,4,0,32,0,107,100,95,51,50,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,42,128,42,27,4,0,32,0,107,100,95,49,48,46,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,150,174,136,231,4,0,32,0,107,100,95,50,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,227,227,34,176,4,0,32,0,107,100,95,49,52,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,239,197,64,72,4,0,32,0,107,100,95,54,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,228,174,159,81,4,0,32,0,107,100,95,50,53,46,55,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,83,168,15,93,4,0,32,0,107,100,95,49,56,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,187,178,211,106,4,0,32,0,107,100,95,51,57,46,57,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,19,2,146,215,4,0,32,0,107,100,95,51,51,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,214,190,194,101,4,0,32,0,107,100,95,49,49,46,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,16,51,126,20,4,0,32,0,107,100,95,51,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,131,188,24,93,4,0,32,0,107,100,95,49,53,46,49,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,70,151,53,87,4,0,32,0,107,100,95,55,46,49,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,121,48,224,127,4,0,32,0,107,100,95,50,54,46,56,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,181,250,229,87,4,0,32,0,107,100,95,49,57,46,56,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,124,15,243,177,4,0,32,0,107,100,95,50,56,46,49,48,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,53,65,66,58,4,0,32,0,107,100,95,50,49,46,49,48,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,195,210,16,206,4,0,32,0,107,100,95,49,50,46,56,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,162,42,4,166,4,0,32,0,107,100,95,52,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,48,186,224,12,4,0,32,0,107,100,95,49,54,46,49,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,224,183,220,99,4,0,32,0,107,100,95,56,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,174,119,155,198,4,0,32,0,107,100,95,50,55,46,57,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,237,191,215,64,4,0,32,0,107,100,95,50,48,46,57,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,153,243,193,1,4,0,32,0,107,100,95,50,57,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,3,172,238,161,4,0,32,0,107,100,95,50,50,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,235,152,222,90,4,0,32,0,107,100,95,50,51,46,49,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,38,236,198,186,3,0,16,0,107,100,95,51,48,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,29,24,99,76,5,0,64,0,107,100,95,51,49,46,49,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,128,27,148,146,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,107,100,50,50,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,0,0,0,0,0,0,24,105,111,98,49,46,49,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,105,111,99,49,46,105,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,129,32,24,13,0,0,0,8,99,54,51,50,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,112,146,189,15,0,0,0,8,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,38,184,106,10,2,0,16,1,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,75,173,215,155,2,0,16,1,107,100,45,53,109,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,135,91,228,4,0,32,0,107,100,45,55,109,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,34,3,117,167,4,0,32,0,107,100,45,49,109,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,8,0,120,191,116,95,4,0,32,0,107,100,100,97,45,55,109,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,111,183,44,14,4,0,32,0,107,100,45,54,109,46,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,243,88,51,17,4,0,32,0,107,100,45,56,109,46,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,68,60,133,56,4,0,32,0,107,100,45,50,109,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,4,102,243,158,4,0,32,0,107,100,45,52,109,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,79,155,43,64,4,0,32,0,107,100,95,57,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,38,236,198,186,3,0,16,0,107,100,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,29,24,99,76,5,0,64,0,107,100,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,128,27,148,146,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,107,100,50,57,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,0,0,0,0,0,0,24,105,111,98,49,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,105,111,99,49,46,105,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,129,32,24,13,0,0,0,8,99,54,51,50,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,112,146,189,15,0,0,0,8,0,0,0,0,0,0,0,0,23,0,0,0,255,255,219,0,0,0,0,0,24,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,232,75,4,0,23,0,0,0,1,1,1,0,96,135,7,0,23,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,23,0,0,0,1,2,2,0,96,135,7,0,23,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,23,0,0,0,1,4,4,0,96,135,7,0,23,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,160,94,8,0,23,0,0,0,1,8,0,0,96,39,8,0,23,0,0,0,1,8,8,0,80,242,7,0,0,0,0,0,254,0,2,0,16,227,4,0,23,0,0,0,1,16,16,0,96,135,7,0,23,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,2,0,80,143,7,0,23,0,0,0,1,32,32,0,248,38,7,0,23,0,0,0,1,32,0,0,64,111,3,0,0,0,0,0,254,0,2,0,120,2,7,0,23,0,0,0,1,64,64,0,56,111,3,0,23,0,0,0,1,64,0,0,104,134,3,0,0,0,0,0,254,0,2,0,24,130,6,0,23,0,0,0,1,128,128,0,0,82,6,0,23,0,0,0,1,128,0,0,96,39,6,0,17,0,0,0,255,255,0,0,0,0,0,0,18,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,4,0,160,123,6,0,17,0,0,0,1,3,0,0,200,201,5,0,17,0,0,0,1,3,1,0,152,160,5,0,17,0,0,0,1,3,2,0,144,127,5,0,17,0,0,0,1,3,3,0,88,219,3,0,0,0,0,0,254,0,4,0,200,87,7,0,17,0,0,0,1,12,12,0,8,7,5,0,17,0,0,0,1,12,8,0,216,36,5,0,17,0,0,0,1,12,4,0,224,67,5,0,17,0,0,0,1,12,0,0,200,201,5,0,0,0,0,0,254,0,2,0,128,129,4,0,17,0,0,0,1,16,0,0,8,49,4,0,17,0,0,0,1,16,16,0,72,246,3,0,0,0,0,0,254,0,2,0,64,37,5,0,17,0,0,0,1,32,0,0,104,91,7,0,17,0,0,0,1,32,32,0,144,84,7,0,0,0,0,0,254,0,2,0,72,202,5,0,17,0,0,0,1,64,0,0,104,80,7,0,17,0,0,0,1,64,64,0,32,37,7,0,0,0,0,0,254,0,2,0,136,73,7,0,17,0,0,0,1,128,0,0,192,255,2,0,17,0,0,0,1,128,128,0,208,75,4,0,0,0,0,0,254,0,2,0,200,30,2,0,18,0,0,0,1,1,1,0,120,97,1,0,18,0,0,0,1,1,0,0,96,19,1,0,0,0,0,0,254,0,2,0,112,109,2,0,18,0,0,0,1,64,0,0,96,135,7,0,18,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,4,0,200,59,7,0,18,0,0,0,1,128,0,0,96,135,7,0,18,0,0,0,1,128,128,0,152,182,7,0,0,0,0,0,17,0,0,0,255,255,0,0,0,0,0,0,18,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,4,0,160,123,6,0,17,0,0,0,1,3,3,0,192,135,6,0,17,0,0,0,1,3,0,0,200,201,5,0,17,0,0,0,1,3,1,0,152,160,5,0,17,0,0,0,1,3,2,0,144,127,5,0,0,0,0,0,254,0,4,0,200,87,7,0,17,0,0,0,1,12,8,0,216,36,5,0,17,0,0,0,1,12,4,0,224,67,5,0,17,0,0,0,1,12,12,0,192,135,6,0,17,0,0,0,1,12,0,0,184,108,4,0,0,0,0,0,254,0,2,0,128,129,4,0,17,0,0,0,1,16,0,0,8,49,4,0,17,0,0,0,1,16,16,0,72,246,3,0,0,0,0,0,254,0,2,0,64,37,5,0,17,0,0,0,1,32,0,0,104,91,7,0,17,0,0,0,1,32,32,0,144,84,7,0,0,0,0,0,254,0,2,0,72,202,5,0,17,0,0,0,1,64,0,0,104,80,7,0,17,0,0,0,1,64,64,0,32,37,7,0,0,0,0,0,254,0,2,0,136,73,7,0,17,0,0,0,1,128,0,0,192,255,2,0,17,0,0,0,1,128,128,0,208,75,4,0,0,0,0,0,254,0,2,0,200,30,2,0,18,0,0,0,1,1,1,0,120,97,1,0,18,0,0,0,1,1,0,0,96,19,1,0,0,0,0,0,254,0,2,0,112,109,2,0,18,0,0,0,1,64,0,0,96,135,7,0,18,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,4,0,200,59,7,0,18,0,0,0,1,128,0,0,96,135,7,0,18,0,0,0,1,128,128,0,152,182,7,0,0,0,0,0,105,115,109,50,48,48,54,118,48,48,46,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,92,88,146,34,0,0,16,3,22,0,0,0,255,255,0,0,0,0,0,0,23,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,22,0,0,0,1,3,2,0,208,75,4,0,22,0,0,0,1,3,0,0,8,49,4,0,22,0,0,0,1,3,1,0,152,21,4,0,22,0,0,0,1,3,3,0,72,246,3,0,0,0,0,0,254,0,4,0,112,171,4,0,22,0,0,0,1,12,8,0,16,140,4,0,22,0,0,0,1,12,0,0,80,245,6,0,22,0,0,0,1,12,4,0,64,86,4,0,22,0,0,0,1,12,12,0,16,227,4,0,0,0,0,0,254,0,2,0,112,31,4,0,22,0,0,0,1,22,0,0,232,2,4,0,22,0,0,0,1,22,22,0,136,225,3,0,0,0,0,0,254,0,2,0,16,195,3,0,22,0,0,0,1,64,64,0,96,135,7,0,22,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,22,0,0,0,1,128,0,0,96,135,7,0,22,0,0,0,1,128,128,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,23,0,0,0,1,1,0,0,96,135,7,0,23,0,0,0,1,1,1,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,23,0,0,0,1,2,2,0,56,111,3,0,23,0,0,0,1,2,0,0,104,134,3,0,0,0,0,0,254,0,4,0,64,37,5,0,23,0,0,0,1,12,0,0,120,176,7,0,23,0,0,0,1,12,8,0,136,136,2,0,23,0,0,0,1,12,4,0,24,219,2,0,23,0,0,0,1,12,12,0,120,7,5,0,0,0,0,0,254,0,4,0,168,79,2,0,23,0,0,0,1,48,22,0,8,167,2,0,23,0,0,0,1,48,0,0,208,152,2,0,23,0,0,0,1,48,48,0,72,4,1,0,23,0,0,0,1,48,16,0,224,195,4,0,0,0,0,0,254,0,4,0,72,202,5,0,23,0,0,0,1,192,0,0,80,246,3,0,23,0,0,0,1,192,128,0,248,38,7,0,23,0,0,0,1,192,64,0,112,212,3,0,23,0,0,0,1,192,192,0,248,160,5,0,104,115,50,106,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,115,143,115,0,1,0,16,1,104,115,50,106,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,74,44,7,64,1,0,16,1,104,115,50,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,53,74,227,221,1,0,16,1,104,115,50,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,218,109,229,244,1,0,16,1,104,115,50,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,252,32,68,238,1,0,16,1,104,115,50,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,51,21,68,201,1,0,16,1,104,115,50,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,56,198,63,1,0,16,1,104,115,50,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,228,249,208,32,1,0,16,1,104,115,50,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,23,171,236,166,5,0,32,0,104,115,50,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,77,174,160,16,5,0,32,0,104,115,50,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,38,119,250,173,5,0,32,0,104,115,50,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,34,227,58,187,5,0,32,0,104,115,50,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,134,55,161,193,10,0,16,1,104,115,50,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,170,148,135,45,10,0,16,1,104,115,50,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,89,195,21,14,12,0,64,0,104,115,50,97,100,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,113,211,83,1,1,0,16,1,104,115,50,97,100,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,138,183,118,2,1,0,16,1,104,115,50,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,53,74,227,221,1,0,16,1,104,115,50,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,218,109,229,244,1,0,16,1,104,115,50,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,252,32,68,238,1,0,16,1,104,115,50,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,51,21,68,201,1,0,16,1,104,115,50,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,56,198,63,1,0,16,1,104,115,50,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,228,249,208,32,1,0,16,1,104,115,50,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,23,171,236,166,5,0,32,0,104,115,50,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,77,174,160,16,5,0,32,0,104,115,50,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,38,119,250,173,5,0,32,0,104,115,50,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,34,227,58,187,5,0,32,0,104,115,50,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,134,55,161,193,10,0,16,1,104,115,50,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,170,148,135,45,10,0,16,1,104,115,50,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,89,195,21,14,12,0,64,0,104,115,50,97,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,224,23,10,213,1,0,16,1,104,115,50,97,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,222,66,127,162,1,0,16,1,104,115,50,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,53,74,227,221,1,0,16,1,104,115,50,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,218,109,229,244,1,0,16,1,104,115,50,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,252,32,68,238,1,0,16,1,104,115,50,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,51,21,68,201,1,0,16,1,104,115,50,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,56,198,63,1,0,16,1,104,115,50,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,228,249,208,32,1,0,16,1,104,115,50,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,23,171,236,166,5,0,32,0,104,115,50,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,77,174,160,16,5,0,32,0,104,115,50,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,38,119,250,173,5,0,32,0,104,115,50,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,34,227,58,187,5,0,32,0,104,115,50,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,134,55,161,193,10,0,16,1,104,115,50,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,170,148,135,45,10,0,16,1,104,115,50,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,89,195,21,14,12,0,64,0,14,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,32,4,2,0,14,0,0,0,1,3,0,0,40,88,7,0,14,0,0,0,1,3,1,0,96,39,7,0,14,0,0,0,1,3,3,0,144,251,6,0,14,0,0,0,1,3,2,0,184,164,6,0,0,0,0,0,254,0,2,0,208,128,1,0,14,0,0,0,1,4,0,0,24,205,7,0,14,0,0,0,1,4,4,0,192,255,2,0,0,0,0,0,254,0,2,0,208,114,1,0,14,0,0,0,1,8,8,0,248,38,7,0,14,0,0,0,1,8,0,0,64,111,3,0,0,0,0,0,254,0,4,0,72,202,5,0,14,0,0,0,1,48,32,0,80,246,3,0,14,0,0,0,1,48,48,0,248,38,7,0,14,0,0,0,1,48,16,0,112,212,3,0,14,0,0,0,1,48,0,0,248,160,5,0,0,0,0,0,254,0,2,0,80,11,5,0,14,0,0,0,1,64,64,0,96,135,7,0,14,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,14,0,0,0,1,128,128,0,96,135,7,0,14,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,103,109,109,117,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,169,74,220,54,0,0,16,1,103,109,109,117,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,68,193,83,134,0,0,16,1,103,116,109,114,117,115,97,46,117,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,255,6,26,46,0,0,16,8,103,109,109,117,50,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,252,62,171,192,0,0,32,0,103,109,109,117,50,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,220,35,107,207,0,0,32,0,103,109,109,117,50,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,211,245,39,143,0,0,32,0,103,109,109,117,51,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,140,124,116,233,0,0,32,0,103,109,109,117,54,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,51,123,215,87,0,0,32,0,103,109,109,117,54,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,202,189,184,5,0,0,32,0,103,109,109,117,53,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,127,107,95,177,0,0,32,0,103,109,109,117,50,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,238,251,203,185,0,0,64,0,103,109,109,117,50,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,124,220,12,56,0,0,64,0,109,109,112,48,120,50,46,117,53,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,200,119,74,186,0,0,16,1,109,109,112,49,120,50,46,117,53,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,78,3,185,162,0,0,16,1,109,109,100,48,120,50,46,117,49,50,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,41,179,124,61,0,0,16,8,109,109,45,50,48,48,45,52,48,50,45,115,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,252,62,171,192,0,0,32,0,109,109,45,50,48,49,45,52,48,51,45,115,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,220,35,107,207,0,0,32,0,109,109,45,50,48,50,45,52,48,52,45,115,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,211,245,39,143,0,0,32,0,109,109,45,50,48,51,45,52,48,53,45,115,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,140,124,116,233,0,0,32,0,109,109,115,49,120,50,46,117,51,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,111,66,43,180,0,0,32,0,109,109,115,48,120,50,46,117,50,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,210,183,34,189,0,0,32,0,109,109,45,51,48,48,45,52,48,54,45,97,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,127,107,95,177,0,0,32,0,109,109,45,49,48,48,45,52,48,49,45,101,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,238,251,203,185,0,0,64,0,109,50,112,48,120,49,97,46,117,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,251,57,144,194,0,0,16,1,109,50,112,49,120,49,97,46,117,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,196,146,243,142,0,0,16,1,109,50,100,48,120,48,46,117,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,255,6,26,46,0,0,16,8,109,50,45,50,48,48,45,48,46,117,52,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,83,252,170,147,0,0,32,0,109,50,45,50,48,49,45,48,46,117,53,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,131,10,182,57,0,0,32,0,109,50,45,50,48,50,45,48,46,117,53,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,57,179,6,253,0,0,32,0,109,50,115,48,120,49,97,46,117,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,198,238,133,164,0,0,32,0,109,50,115,49,120,49,97,46,117,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,178,27,183,197,0,0,32,0,109,50,45,51,48,48,45,48,46,117,56,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,187,47,196,77,0,0,32,0,109,50,45,51,48,49,45,48,46,117,57,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,242,148,232,244,0,0,32,0,109,50,98,48,120,48,46,117,57,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,27,213,35,224,0,0,32,0,109,50,98,49,120,48,46,117,57,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,219,139,196,3,0,0,32,0,109,50,45,49,48,48,45,48,46,117,52,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,69,250,80,82,0,0,64,0,109,50,119,49,120,48,46,117,52,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,197,19,5,27,0,0,64,0,20,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,5,0,32,43,1,0,20,0,0,0,1,7,0,0,120,7,5,0,20,0,0,0,1,7,1,0,160,24,1,0,20,0,0,0,1,7,2,0,152,15,1,0,20,0,0,0,1,7,3,0,200,10,1,0,20,0,0,0,1,7,4,0,232,4,1,0,0,0,0,0,254,0,4,0,0,150,8,0,20,0,0,0,1,24,0,0,120,26,6,0,20,0,0,0,1,24,16,0,88,246,8,0,20,0,0,0,1,24,8,0,176,239,8,0,20,0,0,0,1,24,24,0,48,232,8,0,0,0,0,0,254,0,2,0,88,223,8,0,20,0,0,0,1,32,0,0,80,216,8,0,20,0,0,0,1,32,32,0,0,208,8,0,0,0,0,0,254,0,2,0,144,212,8,0,20,0,0,0,1,64,0,0,96,135,7,0,20,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,20,0,0,0,1,128,0,0,96,135,7,0,20,0,0,0,1,128,128,0,152,182,7,0,0,0,0,0,99,55,52,45,49,48,46,105,99,53,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,11,162,129,202,2,0,16,1,99,55,52,45,48,56,46,105,99,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,158,221,53,170,2,0,16,1,99,55,52,45,49,49,46,105,99,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,213,214,59,238,2,0,16,1,99,55,52,45,49,52,46,105,99,54,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,199,78,194,182,2,0,16,1,99,55,52,45,49,50,46,105,99,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,104,214,110,187,9,0,16,1,99,55,52,45,48,49,46,105,99,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,128,206,52,52,11,0,32,0,99,55,52,45,48,51,46,105,99,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,81,137,13,26,15,0,32,0,99,55,52,45,48,50,46,105,99,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,6,21,162,21,15,0,32,0,99,55,52,45,48,52,46,105,99,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,242,237,151,45,24,0,64,0,99,55,52,45,48,53,46,105,99,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,40,8,156,226,25,0,64,0,40,0,0,0,255,255,255,0,0,0,0,0,41,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,40,0,0,0,1,2,2,0,96,135,7,0,40,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,40,0,0,0,1,4,4,0,96,135,7,0,40,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,40,0,0,0,1,8,0,0,96,135,7,0,40,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,40,0,0,0,1,48,0,0,80,252,6,0,40,0,0,0,1,48,16,0,16,242,7,0,40,0,0,0,1,48,32,0,104,236,7,0,40,0,0,0,1,48,48,0,128,230,7,0,0,0,0,0,254,0,4,0,160,123,6,0,40,0,0,0,1,192,192,0,8,201,6,0,40,0,0,0,1,192,128,0,200,197,6,0,40,0,0,0,1,192,64,0,152,194,6,0,40,0,0,0,1,192,0,0,248,189,6,0,0,0,0,0,254,0,4,0,72,202,5,0,41,0,0,0,1,3,2,0,80,246,3,0,41,0,0,0,1,3,3,0,248,38,7,0,41,0,0,0,1,3,1,0,112,212,3,0,41,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,64,251,5,0,41,0,0,0,1,48,48,0,240,242,5,0,41,0,0,0,1,48,32,0,136,176,4,0,41,0,0,0,1,48,16,0,72,173,4,0,41,0,0,0,1,48,0,0,80,169,4,0,0,0,0,0,254,0,2,0,160,164,4,0,41,0,0,0,1,64,0,0,96,135,7,0,41,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,102,178,98,23,1,0,16,1,112,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,22,57,47,50,1,0,16,1,112,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,81,97,189,40,1,0,16,1,112,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,24,171,105,90,1,0,16,1,112,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,69,119,241,180,1,0,16,1,112,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,181,113,190,52,1,0,16,1,112,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,140,220,62,222,1,0,16,1,107,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,131,216,247,5,4,0,32,0,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,248,69,135,101,4,0,32,0,112,114,45,57,49,46,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,191,3,55,65,7,0,32,0,14,0,0,0,255,255,0,0,0,0,0,0,15,0,0,0,255,255,192,0,0,0,0,0,16,0,0,0,255,255,5,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,15,0,0,0,1,192,192,0,8,49,4,0,15,0,0,0,1,192,128,0,72,246,3,0,15,0,0,0,1,192,64,0,64,47,7,0,15,0,0,0,1,192,0,0,240,64,4,0,0,0,0,0,254,0,2,0,200,30,2,0,16,0,0,0,1,1,1,0,120,97,1,0,16,0,0,0,1,1,0,0,96,19,1,0,0,0,0,0,254,0,2,0,32,4,2,0,16,0,0,0,1,4,0,0,104,236,7,0,16,0,0,0,1,4,4,0,128,230,7,0,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,115,169,240,143,1,0,16,1,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,75,187,135,48,1,0,16,1,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,18,157,134,195,1,0,16,1,102,114,111,103,103,101,114,46,54,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,86,2,171,232,2,0,16,1,102,114,111,103,103,101,114,46,54,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,143,164,128,115,2,0,16,1,102,114,111,103,103,101,114,46,54,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,39,235,215,49,2,0,16,1,102,114,111,103,103,101,114,46,54,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,131,216,247,5,4,0,32,0,101,112,114,45,49,48,51,54,46,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,248,69,135,101,4,0,32,0,112,114,45,57,49,46,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,191,3,55,65,7,0,32,0,10,0,0,0,255,255,255,0,0,0,0,0,11,0,0,0,255,255,255,0,0,0,0,0,12,0,0,0,255,255,251,0,0,0,0,0,13,0,0,0,255,255,1,0,0,0,0,0,0,0,0,0,254,0,2,0,16,227,4,0,11,0,0,0,1,1,1,0,96,135,7,0,11,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,8,0,200,87,7,0,11,0,0,0,1,14,10,0,16,242,7,0,11,0,0,0,1,14,12,0,104,236,7,0,11,0,0,0,1,14,14,0,128,230,7,0,11,0,0,0,1,14,8,0,184,164,6,0,11,0,0,0,1,14,6,0,80,74,6,0,11,0,0,0,1,14,4,0,192,32,6,0,11,0,0,0,1,14,2,0,192,234,2,0,11,0,0,0,1,14,0,0,32,242,5,0,0,0,0,0,254,0,8,0,160,123,6,0,11,0,0,0,1,112,80,0,16,242,7,0,11,0,0,0,1,112,96,0,104,236,7,0,11,0,0,0,1,112,112,0,128,230,7,0,11,0,0,0,1,112,64,0,184,164,6,0,11,0,0,0,1,112,48,0,80,74,6,0,11,0,0,0,1,112,32,0,192,32,6,0,11,0,0,0,1,112,16,0,192,234,2,0,11,0,0,0,1,112,0,0,32,242,5,0,0,0,0,0,254,0,2,0,24,172,6,0,11,0,0,0,1,128,128,0,96,135,7,0,11,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,10,0,0,0,1,3,2,0,80,246,3,0,10,0,0,0,1,3,3,0,248,38,7,0,10,0,0,0,1,3,1,0,112,212,3,0,10,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,2,0,192,76,5,0,10,0,0,0,1,8,0,0,96,135,7,0,10,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,12,0,0,0,1,1,1,0,96,135,7,0,12,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,12,0,0,0,1,4,4,0,96,135,7,0,12,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,224,133,4,0,13,0,0,0,1,1,1,0,224,32,1,0,13,0,0,0,1,1,0,0,176,20,3,0,0,0,0,0,101,112,114,45,49,50,54,53,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,185,45,171,197,1,0,16,1,101,112,114,45,49,50,54,53,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,113,189,64,175,1,0,16,1,109,112,114,45,49,50,54,50,52,46,98,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,196,94,90,55,2,0,32,0,109,112,114,45,49,50,54,50,53,46,98,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,126,117,140,59,2,0,32,0,109,112,114,45,49,50,54,50,54,46,98,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,92,162,252,62,2,0,32,0,109,112,114,45,49,50,54,49,56,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,191,48,21,13,3,0,32,0,109,112,114,45,49,50,54,50,49,46,98,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,153,7,255,24,3,0,32,0,109,112,114,45,49,50,54,49,57,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,70,146,6,50,3,0,32,0,109,112,114,45,49,50,54,50,50,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,54,228,223,163,3,0,32,0,109,112,114,45,49,50,54,50,48,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,224,150,176,246,3,0,32,0,109,112,114,45,49,50,54,50,51,46,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,246,254,115,103,3,0,32,0,101,112,114,45,49,50,54,49,55,46,97,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,35,207,254,126,4,0,16,1,109,112,114,45,49,50,54,49,54,46,97,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,194,71,67,37,8,0,64,0,51,49,55,45,48,49,51,48,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,123,113,123,186,5,0,16,1,21,0,0,0,255,255,253,0,0,0,0,0,22,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,88,131,3,0,21,0,0,0,1,1,1,0,96,135,7,0,21,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,21,0,0,0,1,2,2,0,96,135,7,0,21,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,21,0,0,0,1,4,4,0,96,135,7,0,21,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,112,59,6,0,21,0,0,0,1,8,8,0,248,38,7,0,21,0,0,0,1,8,0,0,112,212,3,0,0,0,0,0,254,0,4,0,72,202,5,0,21,0,0,0,1,48,32,0,80,246,3,0,21,0,0,0,1,48,48,0,248,38,7,0,21,0,0,0,1,48,16,0,112,212,3,0,21,0,0,0,1,48,0,0,248,160,5,0,0,0,0,0,254,0,4,0,128,129,4,0,21,0,0,0,1,192,0,0,192,255,2,0,21,0,0,0,1,192,64,0,208,75,4,0,21,0,0,0,1,192,192,0,8,49,4,0,21,0,0,0,1,192,128,0,152,21,4,0,0,0,0,0,254,0,16,0,200,87,7,0,22,0,0,0,1,15,7,0,80,252,6,0,22,0,0,0,1,15,8,0,16,242,7,0,22,0,0,0,1,15,9,0,104,236,7,0,22,0,0,0,1,15,5,0,176,51,4,0,22,0,0,0,1,15,4,0,56,24,4,0,22,0,0,0,1,15,15,0,128,230,7,0,22,0,0,0,1,15,1,0,72,216,3,0,22,0,0,0,1,15,2,0,24,188,3,0,22,0,0,0,1,15,3,0,176,162,3,0,22,0,0,0,1,15,6,0,120,211,6,0,22,0,0,0,1,15,14,0,184,164,6,0,22,0,0,0,1,15,13,0,80,74,6,0,22,0,0,0,1,15,12,0,192,32,6,0,22,0,0,0,1,15,11,0,192,234,2,0,22,0,0,0,1,15,10,0,32,242,5,0,22,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,22,0,0,0,1,240,112,0,80,252,6,0,22,0,0,0,1,240,128,0,16,242,7,0,22,0,0,0,1,240,144,0,104,236,7,0,22,0,0,0,1,240,80,0,176,51,4,0,22,0,0,0,1,240,64,0,56,24,4,0,22,0,0,0,1,240,240,0,128,230,7,0,22,0,0,0,1,240,16,0,72,216,3,0,22,0,0,0,1,240,32,0,24,188,3,0,22,0,0,0,1,240,48,0,176,162,3,0,22,0,0,0,1,240,96,0,120,211,6,0,22,0,0,0,1,240,224,0,184,164,6,0,22,0,0,0,1,240,208,0,80,74,6,0,22,0,0,0,1,240,192,0,192,32,6,0,22,0,0,0,1,240,176,0,192,234,2,0,22,0,0,0,1,240,160,0,32,242,5,0,22,0,0,0,1,240,0,0,208,236,2,0,101,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,38,149,76,34,1,0,16,1,101,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,189,142,83,204,1,0,16,1,102,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,171,176,162,41,1,0,16,1,102,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,109,90,106,76,1,0,16,1,101,53,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,166,120,211,6,1,0,16,1,101,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,213,32,234,13,1,0,16,1,101,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,232,241,90,180,1,0,16,1,101,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,118,168,55,196,1,0,16,1,101,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,191,88,206,64,4,0,32,0,101,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,237,222,143,98,4,0,32,0,101,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,153,64,102,186,4,0,32,0,101,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,253,197,78,238,4,0,32,0,108,48,54,95,112,114,111,109,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,135,125,12,106,7,0,32,0,118,97,109,101,46,48,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,255,156,76,0,1,0,16,1,118,97,109,101,46,48,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,242,63,65,174,1,0,16,1,118,97,109,101,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,86,135,103,96,1,0,16,1,118,97,109,101,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,179,112,40,145,1,0,16,1,118,97,109,101,46,48,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,232,227,186,218,1,0,16,1,118,97,109,101,46,48,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,119,48,110,44,1,0,16,1,118,97,109,101,46,48,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,75,183,109,241,1,0,16,1,118,97,109,101,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,71,33,30,112,1,0,16,1,118,97,109,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,153,175,27,197,5,0,32,0,118,97,109,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,119,60,232,60,5,0,32,0,118,97,109,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,224,8,36,79,5,0,32,0,118,97,109,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,80,2,246,159,5,0,32,0,118,97,109,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,60,36,135,189,5,0,32,0,118,97,109,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,95,133,236,175,5,0,32,0,118,97,109,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,37,54,3,58,5,0,32,0,118,97,109,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,137,106,255,43,5,0,32,0,118,97,109,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,213,133,182,100,10,0,16,1,118,97,109,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,199,151,124,207,10,0,16,1,118,97,109,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,178,222,57,74,12,0,64,0,118,97,109,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,3,92,62,26,12,0,64,0,101,49,45,49,46,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,67,22,149,75,0,0,16,1,50,49,97,45,50,45,52,46,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,87,118,214,92,0,0,16,1,50,49,97,45,51,46,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,151,72,242,219,0,0,16,1,101,52,45,49,46,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,53,105,226,177,0,0,16,1,50,49,106,109,45,48,46,105,99,53,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,3,45,35,245,0,0,16,1,50,49,106,45,48,45,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,187,149,250,158,0,0,16,1,50,49,106,45,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,180,141,139,122,0,0,32,0,50,49,106,45,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,227,172,79,87,0,0,32,0,50,49,106,45,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,118,122,80,64,0,0,32,0,50,49,106,45,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,111,199,11,187,0,0,32,0,50,49,106,45,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,27,35,79,203,0,0,32,0,50,49,106,45,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,97,194,160,160,0,0,32,0,50,49,106,45,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,246,82,161,107,0,0,32,0,50,49,106,45,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,182,160,32,50,0,0,32,0,50,49,106,45,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,125,81,199,101,0,0,32,0,50,49,106,45,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,135,88,67,124,0,0,32,0,50,49,106,45,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,237,10,100,198,0,0,32,0,50,49,106,45,105,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,160,176,255,94,0,0,32,0,50,49,106,45,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,124,46,180,95,0,0,32,0,50,49,106,45,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,227,93,117,52,0,0,32,0,50,49,106,45,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,248,230,77,144,0,0,32,0,50,49,106,45,107,45,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,169,48,177,253,0,0,32,0,50,49,106,45,108,45,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,41,149,51,70,0,0,32,0,50,49,97,45,49,95,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,225,176,84,243,0,0,16,1,50,49,97,45,50,95,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,87,118,214,92,0,0,16,1,50,49,97,45,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,151,72,242,219,0,0,16,1,50,49,97,45,52,95,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,152,149,1,155,0,0,16,1,50,49,106,109,45,48,46,105,99,53,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,3,45,35,245,0,0,16,1,50,49,106,45,48,45,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,187,149,250,158,0,0,16,1,50,49,106,45,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,180,141,139,122,0,0,32,0,50,49,106,45,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,227,172,79,87,0,0,32,0,50,49,106,45,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,118,122,80,64,0,0,32,0,50,49,106,45,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,111,199,11,187,0,0,32,0,50,49,106,45,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,27,35,79,203,0,0,32,0,50,49,106,45,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,97,194,160,160,0,0,32,0,50,49,106,45,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,246,82,161,107,0,0,32,0,50,49,106,45,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,182,160,32,50,0,0,32,0,50,49,106,45,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,125,81,199,101,0,0,32,0,50,49,106,45,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,135,88,67,124,0,0,32,0,50,49,106,45,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,237,10,100,198,0,0,32,0,50,49,106,45,105,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,160,176,255,94,0,0,32,0,50,49,106,45,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,124,46,180,95,0,0,32,0,50,49,106,45,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,227,93,117,52,0,0,32,0,50,49,106,45,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,248,230,77,144,0,0,32,0,50,49,106,45,107,45,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,169,48,177,253,0,0,32,0,50,49,106,45,108,45,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,41,149,51,70,0,0,32,0,50,49,97,45,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,8,80,98,29,0,0,16,1,50,49,97,45,50,95,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,87,118,214,92,0,0,16,1,50,49,97,45,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,151,72,242,219,0,0,16,1,50,49,97,45,52,95,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,152,149,1,155,0,0,16,1,50,49,106,109,45,48,46,105,99,53,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,3,45,35,245,0,0,16,1,50,49,106,45,48,45,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,187,149,250,158,0,0,16,1,50,49,106,45,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,180,141,139,122,0,0,32,0,50,49,106,45,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,227,172,79,87,0,0,32,0,50,49,106,45,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,118,122,80,64,0,0,32,0,50,49,106,45,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,111,199,11,187,0,0,32,0,50,49,106,45,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,27,35,79,203,0,0,32,0,50,49,106,45,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,97,194,160,160,0,0,32,0,50,49,106,45,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,246,82,161,107,0,0,32,0,50,49,106,45,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,182,160,32,50,0,0,32,0,50,49,106,45,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,125,81,199,101,0,0,32,0,50,49,106,45,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,135,88,67,124,0,0,32,0,50,49,106,45,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,237,10,100,198,0,0,32,0,50,49,106,45,105,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,160,176,255,94,0,0,32,0,50,49,106,45,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,124,46,180,95,0,0,32,0,50,49,106,45,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,227,93,117,52,0,0,32,0,50,49,106,45,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,248,230,77,144,0,0,32,0,50,49,106,45,107,45,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,169,48,177,253,0,0,32,0,50,49,106,45,108,45,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,41,149,51,70,0,0,32,0,118,103,45,97,45,56,104,45,103,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,78,192,68,148,0,0,16,1,97,45,56,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,155,121,149,127,0,0,16,1,103,48,53,95,99,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,45,43,88,16,0,0,16,1,102,48,53,95,99,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,32,157,87,1,0,0,32,0,104,48,53,95,99,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,240,114,88,79,0,0,32,0,110,48,55,95,99,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,178,142,175,16,0,0,32,0,107,48,55,95,99,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,4,243,118,149,0,0,32,0,111,48,55,95,99,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,220,212,217,177,0,0,32,0,108,48,55,95,99,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,74,190,152,69,0,0,32,0,116,48,55,95,99,49,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,66,94,66,245,0,0,32,0,112,48,55,95,99,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,124,161,80,203,0,0,32,0,118,48,55,95,99,49,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,199,163,155,149,0,0,32,0,115,48,55,95,99,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,197,145,46,127,0,0,32,0,100,48,49,95,99,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,92,238,177,129,0,0,32,0,101,48,49,95,99,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,115,54,211,208,0,0,32,0,102,48,49,95,99,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,149,22,232,170,0,0,32,0,100,48,52,95,99,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,29,16,133,155,0,0,64,0,118,103,95,98,45,56,114,46,105,99,57,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,122,138,54,223,0,0,32,0,118,103,95,98,45,52,109,46,105,99,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,4,66,202,219,0,0,32,0,118,103,95,98,45,49,98,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,103,81,46,146,0,0,32,0,98,109,48,49,46,49,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,55,89,147,246,0,0,16,1,98,109,48,50,46,49,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,117,21,151,175,0,0,16,1,98,109,48,51,46,49,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,19,199,14,48,0,0,16,1,98,109,48,52,46,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,215,210,43,238,0,0,16,1,98,109,48,53,46,52,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,61,157,203,70,0,0,32,0,98,109,49,53,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,67,4,26,107,0,0,32,0,98,109,49,54,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,194,8,201,35,0,0,32,0,98,109,49,55,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,7,221,188,70,0,0,32,0,98,109,49,56,46,49,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,160,123,174,230,0,0,32,0,98,109,49,57,46,49,48,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,188,186,138,134,0,0,32,0,98,109,50,48,46,49,49,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,212,229,23,9,0,0,32,0,98,109,50,49,46,49,50,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,137,13,251,155,0,0,32,0,98,109,50,50,46,49,52,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,116,194,243,4,0,0,32,0,98,109,50,52,46,49,52,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,54,64,19,17,0,0,32,0,98,109,50,53,46,49,52,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,193,249,44,9,0,0,32,0,98,109,48,54,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,175,200,172,151,0,0,32,0,98,109,48,55,46,49,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,151,113,143,215,0,0,32,0,98,109,48,56,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,8,102,98,26,0,0,32,0,98,109,48,57,46,49,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,132,64,146,0,0,32,0,98,109,49,48,46,49,48,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,74,164,56,132,0,0,32,0,98,109,49,49,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,29,53,105,108,0,0,32,0,98,109,49,50,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,183,253,126,94,0,0,32,0,98,109,49,51,46,49,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,154,130,67,17,0,0,32,0,98,109,49,52,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,1,100,60,77,0,0,32,0,98,109,50,51,46,56,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,189,236,42,165,0,0,32,0,98,109,49,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,24,31,66,116,0,0,32,0,98,109,50,46,49,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,31,84,39,172,0,0,32,0,98,109,51,46,49,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,255,182,31,37,0,0,32,0,98,109,53,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,208,19,103,32,0,0,32,0,98,109,49,48,46,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,28,73,194,51,0,0,32,0,98,109,57,46,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,247,74,234,174,0,0,32,0,98,109,49,50,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,54,161,138,193,0,0,32,0,98,109,49,49,46,49,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,55,174,90,64,0,0,32,0,98,109,56,46,56,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,158,10,1,194,0,0,32,0,98,109,55,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,195,48,111,181,0,0,32,0,98,109,52,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,225,162,168,145,0,0,32,0,98,109,54,46,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,88,81,175,14,0,0,32,0,98,109,46,55,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,16,53,46,56,52,52,57,48,46,49,48,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,235,107,96,102,0,0,16,1,52,46,56,52,52,57,48,46,57,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,57,92,127,82,0,0,16,1,51,46,56,52,52,57,48,46,56,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,213,117,81,28,0,0,16,1,55,46,56,52,52,57,48,46,49,51,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,218,141,154,253,0,0,16,1,54,46,56,52,52,57,48,46,49,50,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,16,189,61,200,0,0,16,1,50,46,56,53,50,57,46,49,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,150,177,207,85,0,0,16,1,49,46,56,52,52,57,48,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,7,207,252,236,0,0,32,0,49,51,46,56,52,52,57,48,46,51,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,169,111,213,221,0,0,32,0,49,50,46,56,52,52,57,48,46,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,157,82,2,115,0,0,32,0,49,49,46,56,52,52,57,48,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,218,91,3,32,0,0,32,0,49,48,46,56,52,52,57,48,46,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,113,162,43,241,0,0,32,0,57,46,56,52,52,57,48,46,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,125,32,37,229,0,0,32,0,56,46,56,52,52,57,48,46,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,178,233,119,45,0,0,32,0,49,57,46,56,52,52,55,50,46,52,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,220,175,19,70,0,0,32,0,49,56,46,56,52,52,55,50,46,51,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,202,229,215,6,0,0,32,0,49,55,46,56,52,52,55,50,46,49,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,45,224,31,188,0,0,32,0,49,54,46,56,52,52,55,50,46,52,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,213,104,141,96,0,0,32,0,49,53,46,56,52,52,57,48,46,51,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,202,63,12,232,0,0,32,0,49,52,46,56,52,52,57,48,46,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,37,169,128,119,0,0,32,0,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,100,73,113,174,0,0,16,1,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,98,87,4,72,0,0,16,1,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,151,72,242,219,0,0,16,1,50,95,51,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,115,84,135,103,0,0,16,1,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,187,149,250,158,0,0,16,1,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,180,141,139,122,0,0,32,0,50,49,106,45,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,227,172,79,87,0,0,32,0,50,49,106,45,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0])
.concat([118,122,80,64,0,0,32,0,50,49,106,45,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,111,199,11,187,0,0,32,0,50,49,106,45,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,27,35,79,203,0,0,32,0,50,49,106,45,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,97,194,160,160,0,0,32,0,50,49,106,45,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,246,82,161,107,0,0,32,0,50,49,106,45,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,182,160,32,50,0,0,32,0,50,49,106,45,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,125,81,199,101,0,0,32,0,50,49,106,45,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,135,88,67,124,0,0,32,0,50,49,106,45,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,237,10,100,198,0,0,32,0,50,49,106,45,105,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,160,176,255,94,0,0,32,0,50,49,106,45,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,124,46,180,95,0,0,32,0,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,227,93,117,52,0,0,32,0,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,114,31,49,249,0,0,32,0,50,49,106,45,107,45,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,169,48,177,253,0,0,32,0,50,49,106,45,108,45,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,41,149,51,70,0,0,32,0,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,105,20,93,171,0,0,16,1,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,161,59,164,209,0,0,16,1,56,40,115,111,48,50,46,57,102,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,165,172,32,202,0,0,16,1,55,40,118,116,48,49,46,53,100,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,224,38,87,80,0,0,32,0,49,55,40,118,116,49,49,46,53,97,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,72,27,46,123,0,0,32,0,49,54,40,118,116,49,50,46,54,97,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,211,23,180,129,0,0,32,0,49,53,40,118,116,49,51,46,55,97,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,210,219,18,86,0,0,32,0,49,52,40,118,116,49,52,46,56,97,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,54,238,45,43,0,0,32,0,49,51,40,118,116,49,53,46,57,97,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,191,186,112,222,0,0,32,0,49,50,40,118,116,49,54,46,49,48,97,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,55,130,23,20,0,0,32,0,51,40,118,116,48,53,46,55,101,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,61,110,241,121,0,0,32,0,50,40,118,116,48,54,46,56,101,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,33,229,254,38,0,0,32,0,49,40,118,116,48,55,46,57,101,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,253,189,136,202,0,0,32,0,54,40,118,116,48,56,46,55,104,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,131,200,25,32,0,0,32,0,53,40,118,116,48,57,46,56,104,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,130,57,112,152,0,0,32,0,52,40,118,116,49,48,46,57,104,41,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,248,210,105,240,0,0,32,0,118,116,98,49,46,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,161,21,186,58,0,0,32,0,118,116,98,50,46,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,84,87,134,136,0,0,32,0,118,116,98,51,46,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,246,195,20,76,0,0,32,0,118,116,98,52,46,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,70,194,136,179,0,0,32,0,118,116,98,53,46,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,8,197,42,113,0,0,32,0,118,116,98,54,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,88,81,175,14,0,0,32,0,99,111,109,109,97,110,100,111,98,50,95,112,97,108,49,54,108,56,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,0,0,0,24,117,50,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,205,199,183,179,0,0,16,1,117,50,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,117,21,151,175,0,0,16,1,117,50,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,19,199,14,48,0,0,16,1,117,56,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,215,210,43,238,0,0,16,1,117,54,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,150,32,186,10,0,0,32,0,117,54,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,127,154,94,7,0,0,32,0,117,54,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,154,160,172,5,0,0,32,0,117,55,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,14,126,75,15,0,0,32,0,117,55,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,10,12,169,97,0,0,32,0,117,49,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,54,64,19,17,0,0,32,0,117,49,49,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,193,249,44,9,0,0,32,0,117,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,175,200,172,151,0,0,32,0,117,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,151,113,143,215,0,0,32,0,117,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,138,120,92,237,0,0,32,0,117,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,74,164,56,132,0,0,32,0,117,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,29,53,105,108,0,0,32,0,117,49,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,94,68,66,75,0,0,32,0,117,53,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,1,100,60,77,0,0,32,0,117,57,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,29,136,76,37,0,0,32,0,98,109,49,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,24,31,66,116,0,0,32,0,98,109,50,46,49,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,31,84,39,172,0,0,32,0,98,109,51,46,49,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,255,182,31,37,0,0,32,0,98,109,53,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,208,19,103,32,0,0,32,0,98,109,49,48,46,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,28,73,194,51,0,0,32,0,98,109,57,46,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,247,74,234,174,0,0,32,0,98,109,49,50,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,54,161,138,193,0,0,32,0,98,109,49,49,46,49,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,55,174,90,64,0,0,32,0,98,109,56,46,56,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,158,10,1,194,0,0,32,0,98,109,55,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,195,48,111,181,0,0,32,0,98,109,52,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,225,162,168,145,0,0,32,0,98,109,54,46,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,88,81,175,14,0,0,32,0,98,50,95,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,25,250,141,102,0,0,16,1,98,50,95,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,94,112,121,87,0,0,16,1,98,50,95,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,19,166,222,59,0,0,16,1,98,50,95,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,185,135,143,114,0,0,16,1,54,51,55,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,3,45,35,245,0,0,16,1,98,50,95,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,187,149,250,158,0,0,16,1,98,50,95,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,180,141,139,122,0,0,32,0,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,227,172,79,87,0,0,32,0,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,118,122,80,64,0,0,32,0,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,23,30,185,200,0,0,32,0,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,27,35,79,203,0,0,32,0,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,97,194,160,160,0,0,32,0,49,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,246,82,161,107,0,0,32,0,49,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,182,160,32,50,0,0,32,0,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,125,81,199,101,0,0,32,0,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,135,88,67,124,0,0,32,0,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,237,10,100,198,0,0,32,0,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,242,93,214,34,0,0,32,0,50,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,124,46,180,95,0,0,32,0,98,50,95,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,227,93,117,52,0,0,32,0,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,248,230,77,144,0,0,32,0,50,49,106,45,107,45,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,169,48,177,253,0,0,32,0,50,49,106,45,108,45,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,41,149,51,70,0,0,32,0,98,45,57,46,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,133,13,253,64,0,0,16,1,98,45,56,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,106,17,224,38,0,0,16,1,98,45,52,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,46,230,118,208,0,0,16,1,98,45,55,46,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,105,121,111,157,0,0,32,0,98,45,54,46,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,67,78,14,88,0,0,32,0,98,45,53,46,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,210,113,171,5,0,0,32,0,98,45,49,46,49,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,234,251,205,162,0,0,32,0,98,45,50,46,49,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,231,195,181,238,0,0,32,0,98,45,51,46,49,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,29,210,24,142,0,0,32,0,100,104,45,48,57,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,79,155,4,206,0,0,32,0,100,104,45,48,56,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,15,24,242,205,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,168,86,7,0,1,0,0,0,216,241,146,0,248,191,2,0,24,38,7,0,1,0,0,0,7,250,146,0,184,160,2,0,56,210,6,0,1,0,0,0,0,250,146,0,192,135,2,0,24,163,6,0,1,0,0,0,1,250,146,0,240,108,2,0,152,122,6,0,1,0,0,0,2,250,146,0,96,82,2,0,192,72,6,0,1,0,0,0,3,250,146,0,32,56,2,0,200,110,3,0,1,0,0,0,4,250,146,0,152,30,2,0,120,89,3,0,1,0,0,0,5,250,146,0,232,10,2,0,40,246,1,0,1,0,0,0,217,241,146,0,64,246,1,0,144,236,1,0,1,0,0,0,15,250,146,0,136,224,1,0,176,223,1,0,1,0,0,0,8,250,146,0,72,198,1,0,192,209,1,0,1,0,0,0,9,250,146,0,24,182,1,0,24,198,1,0,1,0,0,0,10,250,146,0,40,167,1,0,120,189,1,0,1,0,0,0,11,250,146,0,200,149,1,0,224,22,1,0,1,0,0,0,12,250,146,0,56,126,1,0,160,14,1,0,1,0,0,0,13,250,146,0,32,101,1,0,88,212,3,0,1,0,0,0,24,215,146,0,40,185,3,0,16,17,8,0,1,0,0,0,218,241,146,0,224,12,8,0,72,65,1,0,9,0,0,0,48,3,147,0,32,58,1,0,48,50,1,0,9,0,0,0,49,3,147,0,32,58,1,0,168,86,7,0,1,0,0,0,187,251,146,0,248,191,2,0,152,122,6,0,1,0,0,0,184,251,146,0,96,82,2,0,192,72,6,0,1,0,0,0,185,251,146,0,32,56,2,0,200,110,3,0,1,0,0,0,186,251,146,0,152,30,2,0,88,212,3,0,1,0,0,0,112,216,146,0,40,185,3,0,168,86,7,0,1,0,0,0,204,251,146,0,248,191,2,0,120,248,6,0,1,0,0,0,200,251,146,0,184,160,2,0,200,110,3,0,1,0,0,0,144,243,146,0,152,30,2,0,240,251,8,0,4,0,0,0,224,7,147,0,208,13,4,0,40,246,1,0,1,0,0,0,205,251,146,0,64,246,1,0,48,245,6,0,1,0,0,0,201,251,146,0,136,224,1,0,224,22,1,0,1,0,0,0,146,243,146,0,56,126,1,0,112,188,8,0,4,0,0,0,226,7,147,0,208,13,4,0,56,58,1,0,1,0,0,0,203,251,146,0,64,50,1,0,16,17,8,0,1,0,0,0,202,251,146,0,216,70,1,0,88,212,3,0,1,0,0,0,128,216,146,0,40,185,3,0,248,5,8,0,9,0,0,0,224,3,147,0,32,58,1,0,56,210,6,0,1,0,0,0,40,252,146,0,192,135,2,0,24,163,6,0,1,0,0,0,41,252,146,0,240,108,2,0,152,122,6,0,1,0,0,0,42,252,146,0,96,82,2,0,192,72,6,0,1,0,0,0,43,252,146,0,32,56,2,0,200,110,3,0,1,0,0,0,44,252,146,0,152,30,2,0,120,89,3,0,1,0,0,0,45,252,146,0,232,10,2,0,120,248,6,0,1,0,0,0,46,252,146,0,184,160,2,0,168,86,7,0,1,0,0,0,47,252,146,0,248,191,2,0,88,212,3,0,1,0,0,0,192,216,146,0,40,185,3,0,168,86,7,0,1,0,0,0,16,253,146,0,248,191,2,0,24,38,7,0,1,0,0,0,20,253,146,0,184,160,2,0,56,210,6,0,1,0,0,0,197,244,146,0,192,135,2,0,24,163,6,0,1,0,0,0,196,244,146,0,240,108,2,0,152,122,6,0,1,0,0,0,199,244,146,0,96,82,2,0,192,72,6,0,1,0,0,0,198,244,146,0,32,56,2,0,200,110,3,0,1,0,0,0,192,244,146,0,152,30,2,0,120,89,3,0,1,0,0,0,193,244,146,0,232,10,2,0,120,74,3,0,1,0,0,0,194,244,146,0,152,138,8,0,40,246,1,0,1,0,0,0,17,253,146,0,64,246,1,0,144,236,1,0,1,0,0,0,21,253,146,0,136,224,1,0,176,223,1,0,1,0,0,0,205,238,146,0,72,198,1,0,192,209,1,0,1,0,0,0,204,238,146,0,24,182,1,0,24,198,1,0,1,0,0,0,207,238,146,0,40,167,1,0,120,189,1,0,1,0,0,0,206,238,146,0,200,149,1,0,224,22,1,0,1,0,0,0,200,238,146,0,56,126,1,0,160,14,1,0,1,0,0,0,201,238,146,0,32,101,1,0,176,9,1,0,1,0,0,0,202,238,146,0,96,32,8,0,88,212,3,0,1,0,0,0,104,217,146,0,40,185,3,0,16,17,8,0,1,0,0,0,19,253,146,0,224,12,8,0,72,65,1,0,9,0,0,0,112,4,147,0,32,58,1,0,184,40,2,0,1,0,0,0,190,233,148,0,248,191,2,0,56,250,6,0,1,0,0,0,254,232,148,0,184,160,2,0,184,164,8,0,1,0,0,0,191,233,148,0,64,246,1,0,88,149,7,0,1,0,0,0,255,232,148,0,136,224,1,0,56,210,6,0,1,0,0,0,184,233,148,0,192,135,2,0,24,163,6,0,1,0,0,0,185,233,148,0,240,108,2,0,152,122,6,0,1,0,0,0,187,233,148,0,96,82,2,0,192,72,6,0,1,0,0,0,186,233,148,0,32,56,2,0,48,123,2,0,1,0,0,0,189,233,148,0,152,30,2,0,96,69,2,0,1,0,0,0,188,233,148,0,232,10,2,0,176,223,1,0,1,0,0,0,248,232,148,0,72,198,1,0,192,209,1,0,1,0,0,0,249,232,148,0,24,182,1,0,24,198,1,0,1,0,0,0,251,232,148,0,40,167,1,0,120,189,1,0,1,0,0,0,250,232,148,0,200,149,1,0,248,187,8,0,1,0,0,0,253,232,148,0,56,126,1,0,184,179,8,0,1,0,0,0,252,232,148,0,32,101,1,0,88,212,3,0,1,0,0,0,128,217,146,0,40,185,3,0,248,5,8,0,9,0,0,0,72,94,147,0,32,58,1,0,144,250,7,0,9,0,0,0,73,94,147,0,32,58,1,0,168,86,7,0,1,0,0,0,240,244,146,0,248,191,2,0,24,38,7,0,1,0,0,0,244,244,146,0,184,160,2,0,56,210,6,0,1,0,0,0,67,253,146,0,192,135,2,0,24,163,6,0,1,0,0,0,66,253,146,0,240,108,2,0,152,122,6,0,1,0,0,0,65,253,146,0,96,82,2,0,192,72,6,0,1,0,0,0,64,253,146,0,32,56,2,0,200,110,3,0,1,0,0,0,68,253,146,0,152,30,2,0,120,89,3,0,1,0,0,0,69,253,146,0,232,10,2,0,120,74,3,0,1,0,0,0,70,253,146,0,152,138,8,0,192,61,3,0,1,0,0,0,71,253,146,0,48,119,7,0,120,194,6,0,1,0,0,0,240,238,146,0,112,109,7,0,96,189,6,0,1,0,0,0,241,238,146,0,24,133,7,0,96,249,1,0,1,0,0,0,242,238,146,0,72,120,6,0,40,246,1,0,1,0,0,0,241,244,146,0,64,246,1,0,144,236,1,0,1,0,0,0,245,244,146,0,136,224,1,0,176,223,1,0,1,0,0,0,75,253,146,0,72,198,1,0,192,209,1,0,1,0,0,0,74,253,146,0,24,182,1,0,24,198,1,0,1,0,0,0,73,253,146,0,40,167,1,0,120,189,1,0,1,0,0,0,72,253,146,0,200,149,1,0,224,22,1,0,1,0,0,0,76,253,146,0,56,126,1,0,160,14,1,0,1,0,0,0,77,253,146,0,32,101,1,0,176,9,1,0,1,0,0,0,78,253,146,0,96,32,8,0,200,3,1,0,1,0,0,0,79,253,146,0,16,68,7,0,208,183,6,0,1,0,0,0,244,238,146,0,240,58,7,0,200,177,6,0,1,0,0,0,245,238,146,0,200,42,1,0,216,10,1,0,1,0,0,0,246,238,146,0,16,178,2,0,88,212,3,0,1,0,0,0,136,217,146,0,40,185,3,0,72,65,1,0,9,0,0,0,136,4,147,0,32,58,1,0,48,50,1,0,9,0,0,0,137,4,147,0,32,58,1,0,184,40,2,0,1,0,0,0,128,253,146,0,248,191,2,0,184,164,8,0,1,0,0,0,129,253,146,0,64,246,1,0,24,38,7,0,1,0,0,0,131,253,146,0,184,160,2,0,56,210,6,0,1,0,0,0,51,245,146,0,192,135,2,0,24,163,6,0,1,0,0,0,50,245,146,0,240,108,2,0,152,122,6,0,1,0,0,0,49,245,146,0,96,82,2,0,192,72,6,0,1,0,0,0,48,245,146,0,32,56,2,0,200,110,3,0,1,0,0,0,52,245,146,0,152,30,2,0,120,89,3,0,1,0,0,0,53,245,146,0,232,10,2,0,64,178,2,0,1,0,0,0,54,245,146,0,152,138,8,0,144,236,1,0,1,0,0,0,132,253,146,0,136,224,1,0,176,223,1,0,1,0,0,0,59,245,146,0,72,198,1,0,192,209,1,0,1,0,0,0,58,245,146,0,24,182,1,0,24,198,1,0,1,0,0,0,57,245,146,0,40,167,1,0,120,189,1,0,1,0,0,0,56,245,146,0,200,149,1,0,224,22,1,0,1,0,0,0,60,245,146,0,56,126,1,0,160,14,1,0,1,0,0,0,61,245,146,0,32,101,1,0,72,239,1,0,1,0,0,0,62,245,146,0,96,32,8,0,16,17,8,0,1,0,0,0,7,237,146,0,224,12,8,0,88,212,3,0,1,0,0,0,176,217,146,0,40,185,3,0,248,5,8,0,9,0,0,0,152,4,147,0,32,58,1,0,144,250,7,0,9,0,0,0,153,4,147,0,32,58,1,0,184,40,2,0,1,0,0,0,222,253,146,0,248,191,2,0,184,164,8,0,1,0,0,0,223,253,146,0,64,246,1,0,24,38,7,0,1,0,0,0,216,253,146,0,184,160,2,0,152,122,6,0,1,0,0,0,136,245,146,0,96,82,2,0,192,72,6,0,1,0,0,0,137,245,146,0,32,56,2,0,24,163,6,0,1,0,0,0,138,245,146,0,240,108,2,0,56,210,6,0,1,0,0,0,139,245,146,0,192,135,2,0,200,110,3,0,1,0,0,0,141,245,146,0,152,30,2,0,120,89,3,0,1,0,0,0,142,245,146,0,232,10,2,0,120,74,3,0,1,0,0,0,140,245,146,0,152,138,8,0,144,236,1,0,1,0,0,0,217,253,146,0,136,224,1,0,24,198,1,0,1,0,0,0,56,239,146,0,40,167,1,0,120,189,1,0,1,0,0,0,57,239,146,0,200,149,1,0,192,209,1,0,1,0,0,0,58,239,146,0,24,182,1,0,176,223,1,0,1,0,0,0,59,239,146,0,72,198,1,0,224,22,1,0,1,0,0,0,61,239,146,0,56,126,1,0,160,14,1,0,1,0,0,0,62,239,146,0,32,101,1,0,176,9,1,0,1,0,0,0,60,239,146,0,96,32,8,0,88,212,3,0,1,0,0,0,224,217,146,0,40,185,3,0,248,5,8,0,9,0,0,0,192,4,147,0,32,58,1,0,144,250,7,0,9,0,0,0,193,4,147,0,32,58,1,0,184,40,2,0,1,0,0,0,232,231,148,0,248,191,2,0,56,250,6,0,1,0,0,0,199,233,148,0,184,160,2,0,88,149,7,0,1,0,0,0,7,233,148,0,136,224,1,0,248,23,7,0,1,0,0,0,79,232,148,0,144,189,1,0,48,19,7,0,1,0,0,0,15,232,148,0,32,245,8,0,56,210,6,0,1,0,0,0,194,233,148,0,192,135,2,0,24,163,6,0,1,0,0,0,195,233,148,0,240,108,2,0,152,122,6,0,1,0,0,0,193,233,148,0,96,82,2,0,192,72,6,0,1,0,0,0,192,233,148,0,32,56,2,0,48,123,2,0,1,0,0,0,196,233,148,0,152,30,2,0,96,69,2,0,1,0,0,0,197,233,148,0,232,10,2,0,176,223,1,0,1,0,0,0,2,233,148,0,72,198,1,0,192,209,1,0,1,0,0,0,3,233,148,0,24,182,1,0,24,198,1,0,1,0,0,0,1,233,148,0,40,167,1,0,120,189,1,0,1,0,0,0,0,233,148,0,200,149,1,0,248,187,8,0,1,0,0,0,4,233,148,0,56,126,1,0,184,179,8,0,1,0,0,0,5,233,148,0,32,101,1,0,192,122,8,0,1,0,0,0,74,232,148,0,208,174,1,0,40,116,8,0,1,0,0,0,75,232,148,0,48,160,1,0,72,110,8,0,1,0,0,0,73,232,148,0,160,140,1,0,184,102,8,0,1,0,0,0,72,232,148,0,56,112,1,0,240,45,8,0,1,0,0,0,76,232,148,0,32,92,1,0,40,38,8,0,1,0,0,0,77,232,148,0,64,77,1,0,248,16,8,0,1,0,0,0,10,232,148,0,32,231,8,0,192,12,8,0,1,0,0,0,11,232,148,0,88,214,8,0,224,5,8,0,1,0,0,0,9,232,148,0,224,202,8,0,144,1,8,0,1,0,0,0,8,232,148,0,72,193,8,0,72,204,7,0,1,0,0,0,12,232,148,0,144,180,8,0,208,196,7,0,1,0,0,0,13,232,148,0,208,164,8,0,88,212,3,0,1,0,0,0,240,217,146,0,40,185,3,0,16,17,8,0,1,0,0,0,233,231,148,0,224,12,8,0,248,5,8,0,9,0,0,0,80,94,147,0,32,58,1,0,144,250,7,0,9,0,0,0,81,94,147,0,32,58,1,0,168,86,7,0,1,0,0,0,38,254,146,0,248,191,2,0,24,38,7,0,1,0,0,0,214,245,146,0,184,160,2,0,56,210,6,0,1,0,0,0,32,254,146,0,192,135,2,0,24,163,6,0,1,0,0,0,33,254,146,0,240,108,2,0,152,122,6,0,1,0,0,0,35,254,146,0,96,82,2,0,192,72,6,0,1,0,0,0,34,254,146,0,32,56,2,0,200,110,3,0,1,0,0,0,37,254,146,0,152,30,2,0,120,89,3,0,1,0,0,0,36,254,146,0,232,10,2,0,40,246,1,0,1,0,0,0,39,254,146,0,64,246,1,0,144,236,1,0,1,0,0,0,215,245,146,0,136,224,1,0,176,223,1,0,1,0,0,0,208,245,146,0,72,198,1,0,192,209,1,0,1,0,0,0,209,245,146,0,24,182,1,0,24,198,1,0,1,0,0,0,211,245,146,0,40,167,1,0,120,189,1,0,1,0,0,0,210,245,146,0,200,149,1,0,224,22,1,0,1,0,0,0,213,245,146,0,56,126,1,0,160,14,1,0,1,0,0,0,212,245,146,0,32,101,1,0,88,212,3,0,1,0,0,0,24,218,146,0,40,185,3,0,72,65,1,0,9,0,0,0,224,4,147,0,32,58,1,0,48,50,1,0,9,0,0,0,225,4,147,0,32,58,1,0,168,86,7,0,1,0,0,0,64,254,146,0,248,191,2,0,24,38,7,0,1,0,0,0,63,254,146,0,184,160,2,0,56,210,6,0,1,0,0,0,56,254,146,0,192,135,2,0,24,163,6,0,1,0,0,0,57,254,146,0,240,108,2,0,152,122,6,0,1,0,0,0,58,254,146,0,96,82,2,0,192,72,6,0,1,0,0,0,59,254,146,0,32,56,2,0,200,110,3,0,1,0,0,0,60,254,146,0,152,30,2,0,120,89,3,0,1,0,0,0,61,254,146,0,232,10,2,0,120,74,3,0,1,0,0,0,62,254,146,0,152,138,8,0,192,61,3,0,1,0,0,0,66,254,146,0,48,119,7,0,144,236,1,0,1,0,0,0,239,245,146,0,136,224,1,0,176,223,1,0,1,0,0,0,232,245,146,0,72,198,1,0,192,209,1,0,1,0,0,0,233,245,146,0,24,182,1,0,24,198,1,0,1,0,0,0,234,245,146,0,40,167,1,0,120,189,1,0,1,0,0,0,235,245,146,0,200,149,1,0,224,22,1,0,1,0,0,0,236,245,146,0,56,126,1,0,160,14,1,0,1,0,0,0,237,245,146,0,32,101,1,0,176,9,1,0,1,0,0,0,238,245,146,0,96,32,8,0,200,3,1,0,1,0,0,0,242,245,146,0,16,68,7,0,88,212,3,0,1,0,0,0,40,218,146,0,40,185,3,0,56,122,5,0,1,0,0,0,65,254,146,0,224,12,8,0,0,105,5,0,1,0,0,0,241,245,146,0,224,12,8,0,184,40,2,0,1,0,0,0,166,254,146,0,248,191,2,0,184,164,8,0,1,0,0,0,167,254,146,0,64,246,1,0,24,38,7,0,1,0,0,0,70,246,146,0,184,160,2,0,56,210,6,0,1,0,0,0,160,254,146,0,192,135,2,0,24,163,6,0,1,0,0,0,161,254,146,0,240,108,2,0,152,122,6,0,1,0,0,0,163,254,146,0,96,82,2,0,192,72,6,0,1,0,0,0,162,254,146,0,32,56,2,0,200,110,3,0,1,0,0,0,165,254,146,0,152,30,2,0,120,89,3,0,1,0,0,0,164,254,146,0,232,10,2,0,144,236,1,0,1,0,0,0,71,246,146,0,136,224,1,0,176,223,1,0,1,0,0,0,64,246,146,0,72,198,1,0,192,209,1,0,1,0,0,0,65,246,146,0,24,182,1,0,24,198,1,0,1,0,0,0,67,246,146,0,40,167,1,0,120,189,1,0,1,0,0,0,66,246,146,0,200,149,1,0,224,22,1,0,1,0,0,0,69,246,146,0,56,126,1,0,160,14,1,0,1,0,0,0,68,246,146,0,32,101,1,0,88,212,3,0,1,0,0,0,112,218,146,0,40,185,3,0,248,5,8,0,9,0,0,0,16,5,147,0,32,58,1,0,144,250,7,0,9,0,0,0,17,5,147,0,32,58,1,0,184,40,2,0,1,0,0,0,16,233,148,0,248,191,2,0,56,250,6,0,1,0,0,0,215,233,148,0,184,160,2,0,184,164,8,0,1,0,0,0,17,233,148,0,64,246,1,0,88,149,7,0,1,0,0,0,95,232,148,0,136,224,1,0,248,23,7,0,1,0,0,0,23,232,148,0,144,189,1,0,56,210,6,0,1,0,0,0,210,233,148,0,192,135,2,0,24,163,6,0,1,0,0,0,211,233,148,0,240,108,2,0,152,122,6,0,1,0,0,0,209,233,148,0,96,82,2,0,192,72,6,0,1,0,0,0,208,233,148,0,32,56,2,0,48,123,2,0,1,0,0,0,212,233,148,0,152,30,2,0,96,69,2,0,1,0,0,0,213,233,148,0,232,10,2,0,144,55,2,0,1,0,0,0,214,233,148,0,152,138,8,0,176,223,1,0,1,0,0,0,90,232,148,0,72,198,1,0,192,209,1,0,1,0,0,0,91,232,148,0,24,182,1,0,24,198,1,0,1,0,0,0,89,232,148,0,40,167,1,0,120,189,1,0,1,0,0,0,88,232,148,0,200,149,1,0,248,187,8,0,1,0,0,0,92,232,148,0,56,126,1,0,184,179,8,0,1,0,0,0,93,232,148,0,32,101,1,0,240,173,8,0,1,0,0,0,94,232,148,0,96,32,8,0,192,122,8,0,1,0,0,0,18,232,148,0,208,174,1,0,40,116,8,0,1,0,0,0,19,232,148,0,48,160,1,0,72,110,8,0,1,0,0,0,17,232,148,0,160,140,1,0,184,102,8,0,1,0,0,0,16,232,148,0,56,112,1,0,240,45,8,0,1,0,0,0,20,232,148,0,32,92,1,0,40,38,8,0,1,0,0,0,21,232,148,0,64,77,1,0,48,32,8,0,1,0,0,0,22,232,148,0,112,157,4,0,88,212,3,0,1,0,0,0,144,218,146,0,40,185,3,0,16,17,8,0,1,0,0,0,18,233,148,0,224,12,8,0,248,5,8,0,9,0,0,0,104,94,147,0,32,58,1,0,144,250,7,0,9,0,0,0,105,94,147,0,32,58,1,0,248,241,7,0,9,0,0,0,106,94,147,0,32,58,1,0,72,82,8,0,9,0,0,0,107,94,147,0,32,58,1,0,184,40,2,0,1,0,0,0,104,246,146,0,248,191,2,0,184,164,8,0,1,0,0,0,105,246,146,0,64,246,1,0,24,38,7,0,1,0,0,0,106,246,146,0,184,160,2,0,56,210,6,0,1,0,0,0,215,254,146,0,192,135,2,0,24,163,6,0,1,0,0,0,214,254,146,0,240,108,2,0,152,122,6,0,1,0,0,0,212,254,146,0,96,82,2,0,192,72,6,0,1,0,0,0,213,254,146,0,32,56,2,0,200,110,3,0,1,0,0,0,211,254,146,0,152,30,2,0,120,89,3,0,1,0,0,0,210,254,146,0,232,10,2,0,120,74,3,0,1,0,0,0,209,254,146,0,152,138,8,0,144,236,1,0,1,0,0,0,107,246,146,0,136,224,1,0,176,223,1,0,1,0,0,0,207,254,146,0,72,198,1,0,192,209,1,0,1,0,0,0,206,254,146,0,24,182,1,0,24,198,1,0,1,0,0,0,204,254,146,0,40,167,1,0,120,189,1,0,1,0,0,0,205,254,146,0,200,149,1,0,224,22,1,0,1,0,0,0,203,254,146,0,56,126,1,0,160,14,1,0,1,0,0,0,202,254,146,0,32,101,1,0,176,9,1,0,1,0,0,0,201,254,146,0,96,32,8,0,80,251,6,0,1,0,0,0,109,246,146,0,216,70,1,0,16,17,8,0,1,0,0,0,108,246,146,0,224,12,8,0,88,212,3,0,1,0,0,0,152,218,146,0,40,185,3,0,248,5,8,0,9,0,0,0,40,5,147,0,32,58,1,0,144,250,7,0,9,0,0,0,41,5,147,0,32,58,1,0,168,86,7,0,1,0,0,0,136,255,146,0,248,191,2,0,120,248,6,0,1,0,0,0,139,255,146,0,184,160,2,0,152,122,6,0,1,0,0,0,0,247,146,0,96,82,2,0,192,72,6,0,1,0,0,0,1,247,146,0,32,56,2,0,56,210,6,0,1,0,0,0,2,247,146,0,192,135,2,0,24,163,6,0,1,0,0,0,3,247,146,0,240,108,2,0,200,110,3,0,1,0,0,0,4,247,146,0,152,30,2,0,40,246,1,0,1,0,0,0,137,255,146,0,64,246,1,0,48,245,6,0,1,0,0,0,140,255,146,0,136,224,1,0,24,198,1,0,1,0,0,0,184,239,146,0,40,167,1,0,120,189,1,0,1,0,0,0,185,239,146,0,200,149,1,0,176,223,1,0,1,0,0,0,186,239,146,0,72,198,1,0,192,209,1,0,1,0,0,0,187,239,146,0,24,182,1,0,224,22,1,0,1,0,0,0,188,239,146,0,56,126,1,0,88,212,3,0,1,0,0,0,248,218,146,0,40,185,3,0,248,5,8,0,9,0,0,0,104,5,147,0,32,58,1,0,144,250,7,0,9,0,0,0,105,5,147,0,32,58,1,0,184,40,2,0,1,0,0,0,169,255,146,0,248,191,2,0,56,250,6,0,1,0,0,0,170,255,146,0,184,160,2,0,88,149,7,0,1,0,0,0,34,247,146,0,136,224,1,0,144,0,6,0,1,0,0,0,160,255,146,0,152,30,2,0,160,171,5,0,1,0,0,0,161,255,146,0,232,10,2,0,184,108,5,0,1,0,0,0,162,255,146,0,152,138,8,0,144,45,5,0,1,0,0,0,163,255,146,0,48,119,7,0,0,237,4,0,1,0,0,0,164,255,146,0,112,109,7,0,184,168,4,0,1,0,0,0,165,255,146,0,24,133,7,0,144,109,4,0,1,0,0,0,166,255,146,0,72,120,6,0,144,56,4,0,1,0,0,0,167,255,146,0,88,119,7,0,8,0,4,0,1,0,0,0,168,255,146,0,240,202,2,0,160,192,3,0,1,0,0,0,24,247,146,0,56,126,1,0,80,141,3,0,1,0,0,0,25,247,146,0,32,101,1,0,8,95,3,0,1,0,0,0,26,247,146,0,96,32,8,0,160,65,3,0,1,0,0,0,27,247,146,0,16,68,7,0,136,30,3,0,1,0,0,0,28,247,146,0,240,58,7,0,248,239,2,0,1,0,0,0,29,247,146,0,200,42,1,0,184,196,2,0,1,0,0,0,30,247,146,0,16,178,2,0,184,165,2,0,1,0,0,0,31,247,146,0,136,174,2,0,200,139,2,0,1,0,0,0,32,247,146,0,48,173,2,0,88,212,3,0,1,0,0,0,8,219,146,0,40,185,3,0,248,5,8,0,9,0,0,0,112,5,147,0,32,58,1,0,184,40,2,0,1,0,0,0,199,239,146,0,248,191,2,0,184,164,8,0,1,0,0,0,198,239,146,0,64,246,1,0,24,38,7,0,1,0,0,0,197,239,146,0,184,160,2,0,144,236,1,0,1,0,0,0,196,239,146,0,136,224,1,0,192,72,6,0,1,0,0,0,176,255,146,0,32,56,2,0,152,122,6,0,1,0,0,0,177,255,146,0,96,82,2,0,24,163,6,0,1,0,0,0,178,255,146,0,240,108,2,0,56,210,6,0,1,0,0,0,179,255,146,0,192,135,2,0,200,110,3,0,1,0,0,0,195,239,146,0,152,30,2,0,120,189,1,0,1,0,0,0,40,247,146,0,200,149,1,0,24,198,1,0,1,0,0,0,41,247,146,0,40,167,1,0,192,209,1,0,1,0,0,0,42,247,146,0,24,182,1,0,176,223,1,0,1,0,0,0,43,247,146,0,72,198,1,0,224,22,1,0,1,0,0,0,193,239,146,0,56,126,1,0,88,212,3,0,1,0,0,0,16,219,146,0,40,185,3,0,248,5,8,0,9,0,0,0,120,5,147,0,112,250,1,0,144,250,7,0,9,0,0,0,121,5,147,0,112,228,1,0,248,241,7,0,9,0,0,0,122,5,147,0,48,202,1,0,168,86,7,0,1,0,0,0,216,255,146,0,248,191,2,0,24,38,7,0,1,0,0,0,217,255,146,0,184,160,2,0,192,72,6,0,1,0,0,0,218,255,146,0,32,56,2,0,152,122,6,0,1,0,0,0,219,255,146,0,96,82,2,0,56,210,6,0,1,0,0,0,220,255,146,0,192,135,2,0,24,163,6,0,1,0,0,0,221,255,146,0,240,108,2,0,200,110,3,0,1,0,0,0,222,255,146,0,152,30,2,0,144,236,1,0,1,0,0,0,80,247,146,0,136,224,1,0,120,189,1,0,1,0,0,0,81,247,146,0,200,149,1,0,24,198,1,0,1,0,0,0,82,247,146,0,40,167,1,0,176,223,1,0,1,0,0,0,83,247,146,0,72,198,1,0,192,209,1,0,1,0,0,0,84,247,146,0,24,182,1,0,224,22,1,0,1,0,0,0,85,247,146,0,56,126,1,0,232,75,4,0,1,0,0,0,223,255,146,0,216,70,1,0,88,212,3,0,1,0,0,0,48,219,146,0,40,185,3,0,248,5,8,0,9,0,0,0,152,0,148,0,32,58,1,0,168,86,7,0,1,0,0,0,127,247,146,0,248,191,2,0,120,248,6,0,1,0,0,0,21,0,147,0,184,160,2,0,152,122,6,0,1,0,0,0,16,0,147,0,96,82,2,0,192,72,6,0,1,0,0,0,17,0,147,0,32,56,2,0,200,110,3,0,1,0,0,0,18,0,147,0,152,30,2,0,48,245,6,0,1,0,0,0,125,247,146,0,136,224,1,0,24,198,1,0,1,0,0,0,120,247,146,0,40,167,1,0,120,189,1,0,1,0,0,0,121,247,146,0,200,149,1,0,224,22,1,0,1,0,0,0,122,247,146,0,56,126,1,0,232,75,4,0,1,0,0,0,126,247,146,0,216,70,1,0,88,212,3,0,1,0,0,0,72,219,146,0,40,185,3,0,248,5,8,0,9,0,0,0,152,5,147,0,32,58,1,0,168,86,7,0,1,0,0,0,38,0,147,0,248,191,2,0,120,248,6,0,1,0,0,0,142,247,146,0,184,160,2,0,192,72,6,0,1,0,0,0,32,0,147,0,32,56,2,0,152,122,6,0,1,0,0,0,33,0,147,0,96,82,2,0,56,210,6,0,1,0,0,0,34,0,147,0,192,135,2,0,24,163,6,0,1,0,0,0,35,0,147,0,240,108,2,0,200,110,3,0,1,0,0,0,36,0,147,0,152,30,2,0,40,246,1,0,1,0,0,0,39,0,147,0,64,246,1,0,48,245,6,0,1,0,0,0,143,247,146,0,136,224,1,0,120,189,1,0,1,0,0,0,136,247,146,0,200,149,1,0,24,198,1,0,1,0,0,0,137,247,146,0,40,167,1,0,176,223,1,0,1,0,0,0,138,247,146,0,72,198,1,0,192,209,1,0,1,0,0,0,139,247,146,0,24,182,1,0,224,22,1,0,1,0,0,0,140,247,146,0,56,126,1,0,88,212,3,0,1,0,0,0,96,219,146,0,40,185,3,0,248,5,8,0,9,0,0,0,168,5,147,0,112,250,1,0,144,250,7,0,9,0,0,0,169,5,147,0,112,228,1,0,168,86,7,0,1,0,0,0,56,0,147,0,248,191,2,0,24,38,7,0,1,0,0,0,57,0,147,0,184,160,2,0,192,72,6,0,1,0,0,0,58,0,147,0,32,56,2,0,152,122,6,0,1,0,0,0,59,0,147,0,96,82,2,0,56,210,6,0,1,0,0,0,60,0,147,0,192,135,2,0,24,163,6,0,1,0,0,0,61,0,147,0,240,108,2,0,200,110,3,0,1,0,0,0,62,0,147,0,152,30,2,0,40,246,1,0,1,0,0,0,160,247,146,0,64,246,1,0,144,236,1,0,1,0,0,0,161,247,146,0,136,224,1,0,120,189,1,0,1,0,0,0,162,247,146,0,200,149,1,0,24,198,1,0,1,0,0,0,163,247,146,0,40,167,1,0,176,223,1,0,1,0,0,0,164,247,146,0,72,198,1,0,192,209,1,0,1,0,0,0,165,247,146,0,24,182,1,0,224,22,1,0,1,0,0,0,166,247,146,0,56,126,1,0,232,75,4,0,1,0,0,0,63,0,147,0,216,70,1,0,88,212,3,0,1,0,0,0,112,219,146,0,40,185,3,0,248,5,8,0,9,0,0,0,184,5,147,0,32,58,1,0,144,250,7,0,9,0,0,0,185,5,147,0,32,58,1,0,184,40,2,0,1,0,0,0,85,0,147,0,248,191,2,0,184,164,8,0,1,0,0,0,86,0,147,0,64,246,1,0,56,250,6,0,1,0,0,0,189,247,146,0,184,160,2,0,88,149,7,0,1,0,0,0,190,247,146,0,136,224,1,0,56,210,6,0,1,0,0,0,80,0,147,0,192,135,2,0,152,122,6,0,1,0,0,0,81,0,147,0,96,82,2,0,192,72,6,0,1,0,0,0,82,0,147,0,32,56,2,0,24,163,6,0,1,0,0,0,83,0,147,0,240,108,2,0,176,223,1,0,1,0,0,0,184,247,146,0,72,198,1,0,24,198,1,0,1,0,0,0,185,247,146,0,40,167,1,0,120,189,1,0,1,0,0,0,186,247,146,0,200,149,1,0,192,209,1,0,1,0,0,0,187,247,146,0,24,182,1,0,88,212,3,0,1,0,0,0,128,219,146,0,40,185,3,0,232,75,4,0,1,0,0,0,87,0,147,0,216,70,1,0,160,193,3,0,9,0,0,0,202,5,147,0,32,58,1,0,104,20,5,0,9,0,0,0,200,5,147,0,32,58,1,0,216,16,5,0,9,0,0,0,201,5,147,0,32,58,1,0,88,12,5,0,9,0,0,0,203,5,147,0,32,58,1,0,184,40,2,0,1,0,0,0,94,0,147,0,248,191,2,0,184,164,8,0,1,0,0,0,95,0,147,0,64,246,1,0,24,38,7,0,1,0,0,0,88,0,147,0,184,160,2,0,56,210,6,0,1,0,0,0,195,247,146,0,192,135,2,0,24,163,6,0,1,0,0,0,194,247,146,0,240,108,2,0,152,122,6,0,1,0,0,0,193,247,146,0,96,82,2,0,192,72,6,0,1,0,0,0,192,247,146,0,32,56,2,0,200,110,3,0,1,0,0,0,196,247,146,0,152,30,2,0,120,89,3,0,1,0,0,0,197,247,146,0,232,10,2,0,144,236,1,0,1,0,0,0,89,0,147,0,136,224,1,0,176,223,1,0,1,0,0,0,243,239,146,0,72,198,1,0,192,209,1,0,1,0,0,0,242,239,146,0,24,182,1,0,24,198,1,0,1,0,0,0,241,239,146,0,40,167,1,0,120,189,1,0,1,0,0,0,240,239,146,0,200,149,1,0,224,22,1,0,1,0,0,0,244,239,146,0,56,126,1,0,160,14,1,0,1,0,0,0,245,239,146,0,32,101,1,0,88,212,3,0,1,0,0,0,136,219,146,0,40,185,3,0,16,17,8,0,1,0,0,0,93,0,147,0,224,12,8,0,248,5,8,0,9,0,0,0,208,5,147,0,32,58,1,0,144,250,7,0,9,0,0,0,209,5,147,0,32,58,1,0,248,241,7,0,9,0,0,0,210,5,147,0,32,58,1,0,184,40,2,0,1,0,0,0,248,239,146,0,248,191,2,0,184,164,8,0,1,0,0,0,249,239,146,0,64,246,1,0,56,250,6,0,1,0,0,0,104,0,147,0,184,160,2,0,56,210,6,0,1,0,0,0,96,0,147,0,192,135,2,0,24,163,6,0,1,0,0,0,97,0,147,0,240,108,2,0,192,72,6,0,1,0,0,0,98,0,147,0,32,56,2,0,152,122,6,0,1,0,0,0,99,0,147,0,96,82,2,0,200,110,3,0,1,0,0,0,100,0,147,0,152,30,2,0,120,89,3,0,1,0,0,0,101,0,147,0,232,10,2,0,88,149,7,0,1,0,0,0,105,0,147,0,136,224,1,0,176,223,1,0,1,0,0,0,200,247,146,0,72,198,1,0,192,209,1,0,1,0,0,0,201,247,146,0,24,182,1,0,120,189,1,0,1,0,0,0,202,247,146,0,200,149,1,0,24,198,1,0,1,0,0,0,203,247,146,0,40,167,1,0,224,22,1,0,1,0,0,0,204,247,146,0,56,126,1,0,160,14,1,0,1,0,0,0,205,247,146,0,32,101,1,0,232,75,4,0,1,0,0,0,111,0,147,0,16,17,8,0,88,212,3,0,1,0,0,0,152,219,146,0,40,185,3,0,16,89,2,0,9,0,0,0,216,5,147,0,32,58,1,0,168,86,7,0,1,0,0,0,144,40,216,0,248,191,2,0,24,38,7,0,1,0,0,0,145,40,216,0,184,160,2,0,56,210,6,0,1,0,0,0,146,40,216,0,192,135,2,0,24,163,6,0,1,0,0,0,147,40,216,0,240,108,2,0,152,122,6,0,1,0,0,0,148,40,216,0,96,82,2,0,192,72,6,0,1,0,0,0,149,40,216,0,32,56,2,0,200,110,3,0,1,0,0,0,150,40,216,0,152,30,2,0,40,246,1,0,1,0,0,0,136,40,216,0,64,246,1,0,144,236,1,0,1,0,0,0,137,40,216,0,136,224,1,0,176,223,1,0,1,0,0,0,138,40,216,0,72,198,1,0,192,209,1,0,1,0,0,0,139,40,216,0,24,182,1,0,24,198,1,0,1,0,0,0,140,40,216,0,40,167,1,0,120,189,1,0,1,0,0,0,141,40,216,0,200,149,1,0,224,22,1,0,1,0,0,0,142,40,216,0,56,126,1,0,88,212,3,0,1,0,0,0,160,219,146,0,40,185,3,0,200,191,1,0,9,0,0,0,248,50,216,0,32,58,1,0,32,177,1,0,9,0,0,0,249,50,216,0,32,58,1,0,184,40,2,0,1,0,0,0,118,0,147,0,248,191,2,0,184,164,8,0,1,0,0,0,119,0,147,0,64,246,1,0,24,38,7,0,1,0,0,0,117,0,147,0,184,160,2,0,152,122,6,0,1,0,0,0,219,247,146,0,96,82,2,0,192,72,6,0,1,0,0,0,218,247,146,0,32,56,2,0,24,163,6,0,1,0,0,0,220,247,146,0,240,108,2,0,56,210,6,0,1,0,0,0,221,247,146,0,192,135,2,0,200,110,3,0,1,0,0,0,217,247,146,0,152,30,2,0,120,89,3,0,1,0,0,0,216,247,146,0,232,10,2,0,144,236,1,0,1,0,0,0,116,0,147,0,136,224,1,0,24,198,1,0,1,0,0,0,11,240,146,0,40,167,1,0,120,189,1,0,1,0,0,0,10,240,146,0,200,149,1,0,192,209,1,0,1,0,0,0,12,240,146,0,24,182,1,0,176,223,1,0,1,0,0,0,13,240,146,0,72,198,1,0,224,22,1,0,1,0,0,0,9,240,146,0,56,126,1,0,160,14,1,0,1,0,0,0,8,240,146,0,32,101,1,0,88,212,3,0,1,0,0,0,168,219,146,0,40,185,3,0,248,5,8,0,9,0,0,0,224,5,147,0,32,58,1,0,144,250,7,0,9,0,0,0,225,5,147,0,32,58,1,0,168,86,7,0,1,0,0,0,246,247,146,0,248,191,2,0,24,38,7,0,1,0,0,0,141,0,147,0,184,160,2,0,56,210,6,0,1,0,0,0,139,0,147,0,192,135,2,0,24,163,6,0,1,0,0,0,137,0,147,0,240,108,2,0,152,122,6,0,1,0,0,0,136,0,147,0,96,82,2,0,192,72,6,0,1,0,0,0,138,0,147,0,32,56,2,0,200,110,3,0,1,0,0,0,140,0,147,0,152,30,2,0,40,246,1,0,1,0,0,0,247,247,146,0,64,246,1,0,144,236,1,0,1,0,0,0,142,0,147,0,136,224,1,0,176,223,1,0,1,0,0,0,243,247,146,0,72,198,1,0,192,209,1,0,1,0,0,0,241,247,146,0,24,182,1,0,24,198,1,0,1,0,0,0,240,247,146,0,40,167,1,0,120,189,1,0,1,0,0,0,242,247,146,0,200,149,1,0,224,22,1,0,1,0,0,0,244,247,146,0,56,126,1,0,56,58,1,0,1,0,0,0,143,0,147,0,64,50,1,0,88,212,3,0,1,0,0,0,192,219,146,0,40,185,3,0,248,5,8,0,9,0,0,0,248,5,147,0,112,250,1,0,144,250,7,0,9,0,0,0,249,5,147,0,112,228,1,0,168,86,7,0,1,0,0,0,166,0,147,0,248,191,2,0,120,248,6,0,1,0,0,0,160,0,147,0,184,160,2,0,192,72,6,0,1,0,0,0,8,248,146,0,32,56,2,0,152,122,6,0,1,0,0,0,9,248,146,0,96,82,2,0,24,163,6,0,1,0,0,0,10,248,146,0,240,108,2,0,56,210,6,0,1,0,0,0,11,248,146,0,192,135,2,0,200,110,3,0,1,0,0,0,12,248,146,0,152,30,2,0,120,89,3,0,1,0,0,0,13,248,146,0,232,10,2,0,120,74,3,0,1,0,0,0,14,248,146,0,152,138,8,0,40,246,1,0,1,0,0,0,167,0,147,0,64,246,1,0,48,245,6,0,1,0,0,0,161,0,147,0,136,224,1,0,120,189,1,0,1,0,0,0,32,240,146,0,200,149,1,0,24,198,1,0,1,0,0,0,33,240,146,0,40,167,1,0,192,209,1,0,1,0,0,0,34,240,146,0,24,182,1,0,176,223,1,0,1,0,0,0,35,240,146,0,72,198,1,0,224,22,1,0,1,0,0,0,36,240,146,0,56,126,1,0,160,14,1,0,1,0,0,0,37,240,146,0,32,101,1,0,176,9,1,0,1,0,0,0,38,240,146,0,96,32,8,0,16,17,8,0,1,0,0,0,164,0,147,0,224,12,8,0,88,212,3,0,1,0,0,0,216,219,146,0,40,185,3,0,248,5,8,0,9,0,0,0,16,6,147,0,32,58,1,0,144,250,7,0,9,0,0,0,17,6,147,0,32,58,1,0,184,40,2,0,1,0,0,0,122,232,148,0,248,191,2,0,56,250,6,0,1,0,0,0,120,232,148,0,184,160,2,0,184,164,8,0,1,0,0,0])
.concat([123,232,148,0,64,246,1,0,88,149,7,0,1,0,0,0,121,232,148,0,136,224,1,0,56,210,6,0,1,0,0,0,240,233,148,0,192,135,2,0,24,163,6,0,1,0,0,0,241,233,148,0,240,108,2,0,152,122,6,0,1,0,0,0,242,233,148,0,96,82,2,0,192,72,6,0,1,0,0,0,243,233,148,0,32,56,2,0,48,123,2,0,1,0,0,0,244,233,148,0,152,30,2,0,96,69,2,0,1,0,0,0,245,233,148,0,232,10,2,0,176,223,1,0,1,0,0,0,48,233,148,0,72,198,1,0,192,209,1,0,1,0,0,0,49,233,148,0,24,182,1,0,24,198,1,0,1,0,0,0,50,233,148,0,40,167,1,0,120,189,1,0,1,0,0,0,51,233,148,0,200,149,1,0,248,187,8,0,1,0,0,0,52,233,148,0,56,126,1,0,184,179,8,0,1,0,0,0,53,233,148,0,32,101,1,0,88,212,3,0,1,0,0,0,224,219,146,0,40,185,3,0,16,17,8,0,1,0,0,0,124,232,148,0,224,12,8,0,248,5,8,0,9,0,0,0,136,94,147,0,32,58,1,0,144,250,7,0,9,0,0,0,137,94,147,0,32,58,1,0,248,241,7,0,9,0,0,0,138,94,147,0,32,58,1,0,184,40,2,0,1,0,0,0,0,94,147,0,248,191,2,0,184,164,8,0,1,0,0,0,1,94,147,0,120,180,6,0,56,250,6,0,1,0,0,0,2,94,147,0,184,160,2,0,200,110,3,0,1,0,0,0,3,94,147,0,152,30,2,0,120,89,3,0,1,0,0,0,4,94,147,0,232,10,2,0,120,74,3,0,1,0,0,0,5,94,147,0,152,138,8,0,88,212,3,0,1,0,0,0,240,219,146,0,40,185,3,0,56,58,1,0,1,0,0,0,6,94,147,0,64,50,1,0,16,89,2,0,9,0,0,0,32,6,147,0,32,58,1,0,184,40,2,0,1,0,0,0,190,0,147,0,248,191,2,0,184,164,8,0,1,0,0,0,191,0,147,0,64,246,1,0,24,38,7,0,1,0,0,0,184,0,147,0,184,160,2,0,144,236,1,0,1,0,0,0,185,0,147,0,136,224,1,0,192,72,6,0,1,0,0,0,32,248,146,0,32,56,2,0,152,122,6,0,1,0,0,0,33,248,146,0,96,82,2,0,24,163,6,0,1,0,0,0,34,248,146,0,240,108,2,0,56,210,6,0,1,0,0,0,35,248,146,0,192,135,2,0,200,110,3,0,1,0,0,0,36,248,146,0,152,30,2,0,120,89,3,0,1,0,0,0,37,248,146,0,232,10,2,0,120,189,1,0,1,0,0,0,48,240,146,0,200,149,1,0,24,198,1,0,1,0,0,0,49,240,146,0,40,167,1,0,192,209,1,0,1,0,0,0,50,240,146,0,24,182,1,0,176,223,1,0,1,0,0,0,51,240,146,0,72,198,1,0,224,22,1,0,1,0,0,0,52,240,146,0,56,126,1,0,160,14,1,0,1,0,0,0,53,240,146,0,32,101,1,0,16,17,8,0,1,0,0,0,189,0,147,0,224,12,8,0,88,212,3,0,1,0,0,0,248,219,146,0,40,185,3,0,248,5,8,0,9,0,0,0,40,6,147,0,112,250,1,0,144,250,7,0,9,0,0,0,41,6,147,0,112,228,1,0,184,40,2,0,1,0,0,0,199,0,147,0,248,191,2,0,184,164,8,0,1,0,0,0,198,0,147,0,64,246,1,0,24,38,7,0,1,0,0,0,192,0,147,0,184,160,2,0,144,236,1,0,1,0,0,0,193,0,147,0,136,224,1,0,192,72,6,0,1,0,0,0,40,248,146,0,32,56,2,0,152,122,6,0,1,0,0,0,41,248,146,0,96,82,2,0,24,163,6,0,1,0,0,0,42,248,146,0,240,108,2,0,56,210,6,0,1,0,0,0,43,248,146,0,192,135,2,0,200,110,3,0,1,0,0,0,44,248,146,0,152,30,2,0,120,89,3,0,1,0,0,0,45,248,146,0,232,10,2,0,120,189,1,0,1,0,0,0,56,240,146,0,200,149,1,0,24,198,1,0,1,0,0,0,57,240,146,0,40,167,1,0,192,209,1,0,1,0,0,0,58,240,146,0,24,182,1,0,176,223,1,0,1,0,0,0,59,240,146,0,72,198,1,0,224,22,1,0,1,0,0,0,60,240,146,0,56,126,1,0,160,14,1,0,1,0,0,0,61,240,146,0,32,101,1,0,88,212,3,0,1,0,0,0,0,220,146,0,40,185,3,0,248,5,8,0,9,0,0,0,48,6,147,0,112,250,1,0,144,250,7,0,9,0,0,0,49,6,147,0,112,228,1,0,184,40,2,0,1,0,0,0,255,233,148,0,248,191,2,0,56,250,6,0,1,0,0,0,248,233,148,0,184,160,2,0,184,164,8,0,1,0,0,0,254,233,148,0,64,246,1,0,88,149,7,0,1,0,0,0,249,233,148,0,136,224,1,0,240,167,7,0,1,0,0,0,59,233,148,0,192,135,2,0,176,163,7,0,1,0,0,0,58,233,148,0,240,108,2,0,208,158,7,0,1,0,0,0,57,233,148,0,96,82,2,0,184,154,7,0,1,0,0,0,56,233,148,0,32,56,2,0,176,108,2,0,1,0,0,0,60,233,148,0,152,30,2,0,128,98,2,0,1,0,0,0,61,233,148,0,232,10,2,0,8,96,7,0,1,0,0,0,131,232,148,0,72,198,1,0,48,89,7,0,1,0,0,0,130,232,148,0,24,182,1,0,16,83,7,0,1,0,0,0,129,232,148,0,40,167,1,0,96,79,7,0,1,0,0,0,128,232,148,0,200,149,1,0,48,76,7,0,1,0,0,0,132,232,148,0,56,126,1,0,144,72,7,0,1,0,0,0,133,232,148,0,32,101,1,0,88,212,3,0,1,0,0,0,8,220,146,0,40,185,3,0,16,17,8,0,1,0,0,0,252,233,148,0,224,12,8,0,248,5,8,0,9,0,0,0,144,94,147,0,32,58,1,0,144,250,7,0,9,0,0,0,145,94,147,0,32,58,1,0,168,86,7,0,1,0,0,0,230,0,147,0,248,191,2,0,24,38,7,0,1,0,0,0,224,0,147,0,184,160,2,0,56,210,6,0,1,0,0,0,67,248,146,0,192,135,2,0,24,163,6,0,1,0,0,0,66,248,146,0,240,108,2,0,152,122,6,0,1,0,0,0,65,248,146,0,96,82,2,0,192,72,6,0,1,0,0,0,64,248,146,0,32,56,2,0,200,110,3,0,1,0,0,0,68,248,146,0,152,30,2,0,120,89,3,0,1,0,0,0,69,248,146,0,232,10,2,0,40,246,1,0,1,0,0,0,231,0,147,0,64,246,1,0,144,236,1,0,1,0,0,0,225,0,147,0,136,224,1,0,176,223,1,0,1,0,0,0,75,240,146,0,72,198,1,0,192,209,1,0,1,0,0,0,74,240,146,0,24,182,1,0,24,198,1,0,1,0,0,0,73,240,146,0,40,167,1,0,120,189,1,0,1,0,0,0,72,240,146,0,200,149,1,0,224,22,1,0,1,0,0,0,76,240,146,0,56,126,1,0,160,14,1,0,1,0,0,0,77,240,146,0,32,101,1,0,88,212,3,0,1,0,0,0,40,220,146,0,40,185,3,0,72,65,1,0,9,0,0,0,152,94,147,0,32,58,1,0,48,50,1,0,9,0,0,0,153,94,147,0,32,58,1,0,168,86,7,0,1,0,0,0,238,0,147,0,248,191,2,0,120,248,6,0,1,0,0,0,78,248,146,0,184,160,2,0,192,72,6,0,1,0,0,0,232,0,147,0,32,56,2,0,152,122,6,0,1,0,0,0,233,0,147,0,96,82,2,0,56,210,6,0,1,0,0,0,234,0,147,0,192,135,2,0,24,163,6,0,1,0,0,0,235,0,147,0,240,108,2,0,200,110,3,0,1,0,0,0,236,0,147,0,152,30,2,0,120,89,3,0,1,0,0,0,237,0,147,0,232,10,2,0,40,246,1,0,1,0,0,0,239,0,147,0,64,246,1,0,48,245,6,0,1,0,0,0,79,248,146,0,136,224,1,0,120,189,1,0,1,0,0,0,72,248,146,0,200,149,1,0,24,198,1,0,1,0,0,0,73,248,146,0,40,167,1,0,176,223,1,0,1,0,0,0,74,248,146,0,72,198,1,0,192,209,1,0,1,0,0,0,75,248,146,0,24,182,1,0,224,22,1,0,1,0,0,0,76,248,146,0,56,126,1,0,160,14,1,0,1,0,0,0,77,248,146,0,32,101,1,0,88,212,3,0,1,0,0,0,48,220,146,0,40,185,3,0,248,5,8,0,9,0,0,0,80,6,147,0,112,250,1,0,144,250,7,0,9,0,0,0,81,6,147,0,112,228,1,0,184,40,2,0,1,0,0,0,92,240,146,0,248,191,2,0,184,164,8,0,1,0,0,0,93,240,146,0,64,246,1,0,24,38,7,0,1,0,0,0,15,1,147,0,184,160,2,0,56,210,6,0,1,0,0,0,8,1,147,0,192,135,2,0,24,163,6,0,1,0,0,0,9,1,147,0,240,108,2,0,152,122,6,0,1,0,0,0,10,1,147,0,96,82,2,0,192,72,6,0,1,0,0,0,11,1,147,0,32,56,2,0,200,110,3,0,1,0,0,0,12,1,147,0,152,30,2,0,120,89,3,0,1,0,0,0,13,1,147,0,232,10,2,0,120,74,3,0,1,0,0,0,14,1,147,0,152,138,8,0,144,236,1,0,1,0,0,0,111,248,146,0,136,224,1,0,176,223,1,0,1,0,0,0,104,248,146,0,72,198,1,0,192,209,1,0,1,0,0,0,105,248,146,0,24,182,1,0,24,198,1,0,1,0,0,0,106,248,146,0,40,167,1,0,120,189,1,0,1,0,0,0,107,248,146,0,200,149,1,0,224,22,1,0,1,0,0,0,108,248,146,0,56,126,1,0,160,14,1,0,1,0,0,0,109,248,146,0,32,101,1,0,176,9,1,0,1,0,0,0,110,248,146,0,96,32,8,0,56,122,5,0,1,0,0,0,88,240,146,0,224,12,8,0,88,212,3,0,1,0,0,0,80,220,146,0,40,185,3,0,248,5,8,0,9,0,0,0,112,6,147,0,32,58,1,0,144,250,7,0,9,0,0,0,113,6,147,0,32,58,1,0,184,40,2,0,1,0,0,0,6,234,148,0,248,191,2,0,56,250,6,0,1,0,0,0,0,234,148,0,184,160,2,0,184,164,8,0,1,0,0,0,7,234,148,0,64,246,1,0,88,149,7,0,1,0,0,0,1,234,148,0,136,224,1,0,240,167,7,0,1,0,0,0,67,233,148,0,192,135,2,0,176,163,7,0,1,0,0,0,66,233,148,0,240,108,2,0,208,158,7,0,1,0,0,0,65,233,148,0,96,82,2,0,184,154,7,0,1,0,0,0,64,233,148,0,32,56,2,0,176,108,2,0,1,0,0,0,68,233,148,0,152,30,2,0,128,98,2,0,1,0,0,0,69,233,148,0,232,10,2,0,8,96,7,0,1,0,0,0,139,232,148,0,72,198,1,0,48,89,7,0,1,0,0,0,138,232,148,0,24,182,1,0,16,83,7,0,1,0,0,0,137,232,148,0,40,167,1,0,96,79,7,0,1,0,0,0,136,232,148,0,200,149,1,0,48,76,7,0,1,0,0,0,140,232,148,0,56,126,1,0,144,72,7,0,1,0,0,0,141,232,148,0,32,101,1,0,88,212,3,0,1,0,0,0,96,220,146,0,40,185,3,0,248,5,8,0,9,0,0,0,160,94,147,0,32,58,1,0,144,250,7,0,9,0,0,0,161,94,147,0,32,58,1,0,184,40,2,0,1,0,0,0,14,234,148,0,248,191,2,0,56,250,6,0,1,0,0,0,8,234,148,0,184,160,2,0,184,164,8,0,1,0,0,0,15,234,148,0,64,246,1,0,88,149,7,0,1,0,0,0,9,234,148,0,136,224,1,0,56,210,6,0,1,0,0,0,75,233,148,0,192,135,2,0,24,163,6,0,1,0,0,0,74,233,148,0,240,108,2,0,152,122,6,0,1,0,0,0,73,233,148,0,96,82,2,0,192,72,6,0,1,0,0,0,72,233,148,0,32,56,2,0,48,123,2,0,1,0,0,0,76,233,148,0,152,30,2,0,96,69,2,0,1,0,0,0,77,233,148,0,232,10,2,0,176,223,1,0,1,0,0,0,147,232,148,0,72,198,1,0,192,209,1,0,1,0,0,0,146,232,148,0,24,182,1,0,24,198,1,0,1,0,0,0,145,232,148,0,40,167,1,0,120,189,1,0,1,0,0,0,144,232,148,0,200,149,1,0,176,108,2,0,1,0,0,0,148,232,148,0,56,126,1,0,128,98,2,0,1,0,0,0,149,232,148,0,32,101,1,0,88,212,3,0,1,0,0,0,104,220,146,0,40,185,3,0,248,5,8,0,9,0,0,0,168,94,147,0,32,58,1,0,144,250,7,0,9,0,0,0,169,94,147,0,32,58,1,0,184,40,2,0,1,0,0,0,86,233,148,0,248,191,2,0,56,250,6,0,1,0,0,0,22,234,148,0,184,160,2,0,184,164,8,0,1,0,0,0,87,233,148,0,64,246,1,0,88,149,7,0,1,0,0,0,23,234,148,0,136,224,1,0,56,210,6,0,1,0,0,0,18,234,148,0,192,135,2,0,24,163,6,0,1,0,0,0,19,234,148,0,240,108,2,0,152,122,6,0,1,0,0,0,17,234,148,0,96,82,2,0,192,72,6,0,1,0,0,0,16,234,148,0,32,56,2,0,48,123,2,0,1,0,0,0,20,234,148,0,152,30,2,0,96,69,2,0,1,0,0,0,21,234,148,0,232,10,2,0,144,55,2,0,1,0,0,0,154,232,148,0,152,138,8,0,176,223,1,0,1,0,0,0,82,233,148,0,72,198,1,0,192,209,1,0,1,0,0,0,83,233,148,0,24,182,1,0,24,198,1,0,1,0,0,0,81,233,148,0,40,167,1,0,120,189,1,0,1,0,0,0,80,233,148,0,200,149,1,0,248,187,8,0,1,0,0,0,84,233,148,0,56,126,1,0,184,179,8,0,1,0,0,0,85,233,148,0,32,101,1,0,240,173,8,0,1,0,0,0,155,232,148,0,96,32,8,0,88,212,3,0,1,0,0,0,120,220,146,0,40,185,3,0,16,17,8,0,1,0,0,0,159,232,148,0,224,12,8,0,248,5,8,0,9,0,0,0,176,94,147,0,32,58,1,0,144,250,7,0,9,0,0,0,177,94,147,0,32,58,1,0,184,40,2,0,1,0,0,0,172,232,148,0,248,191,2,0,56,250,6,0,1,0,0,0,170,232,148,0,184,160,2,0,184,164,8,0,1,0,0,0,171,232,148,0,64,246,1,0,88,149,7,0,1,0,0,0,169,232,148,0,136,224,1,0,240,167,7,0,1,0,0,0,39,234,148,0,192,135,2,0,176,163,7,0,1,0,0,0,38,234,148,0,240,108,2,0,208,158,7,0,1,0,0,0,37,234,148,0,96,82,2,0,184,154,7,0,1,0,0,0,36,234,148,0,32,56,2,0,176,108,2,0,1,0,0,0,35,234,148,0,152,30,2,0,8,96,7,0,1,0,0,0,103,233,148,0,72,198,1,0,48,89,7,0,1,0,0,0,102,233,148,0,24,182,1,0,16,83,7,0,1,0,0,0,101,233,148,0,40,167,1,0,96,79,7,0,1,0,0,0,100,233,148,0,200,149,1,0,48,76,7,0,1,0,0,0,99,233,148,0,56,126,1,0,88,212,3,0,1,0,0,0,144,220,146,0,40,185,3,0,16,17,8,0,1,0,0,0,175,232,148,0,224,12,8,0,248,5,8,0,9,0,0,0,192,94,147,0,32,58,1,0,144,250,7,0,9,0,0,0,193,94,147,0,32,58,1,0,248,241,7,0,9,0,0,0,194,94,147,0,32,58,1,0,184,40,2,0,1,0,0,0,46,234,148,0,248,191,2,0,56,250,6,0,1,0,0,0,40,234,148,0,184,160,2,0,184,164,8,0,1,0,0,0,47,234,148,0,64,246,1,0,88,149,7,0,1,0,0,0,41,234,148,0,136,224,1,0,240,167,7,0,1,0,0,0,107,233,148,0,192,135,2,0,176,163,7,0,1,0,0,0,106,233,148,0,240,108,2,0,208,158,7,0,1,0,0,0,105,233,148,0,96,82,2,0,184,154,7,0,1,0,0,0,104,233,148,0,32,56,2,0,176,108,2,0,1,0,0,0,108,233,148,0,152,30,2,0,128,98,2,0,1,0,0,0,109,233,148,0,232,10,2,0,8,96,7,0,1,0,0,0,179,232,148,0,72,198,1,0,48,89,7,0,1,0,0,0,178,232,148,0,24,182,1,0,16,83,7,0,1,0,0,0,177,232,148,0,40,167,1,0,96,79,7,0,1,0,0,0,176,232,148,0,200,149,1,0,48,76,7,0,1,0,0,0,180,232,148,0,56,126,1,0,144,72,7,0,1,0,0,0,181,232,148,0,32,101,1,0,88,212,3,0,1,0,0,0,176,220,146,0,40,185,3,0,16,17,8,0,1,0,0,0,45,234,148,0,224,12,8,0,248,5,8,0,9,0,0,0,200,94,147,0,32,58,1,0,144,250,7,0,9,0,0,0,201,94,147,0,32,58,1,0,56,250,6,0,1,0,0,0,75,1,147,0,184,160,2,0,88,149,7,0,1,0,0,0,74,1,147,0,136,224,1,0,168,86,7,0,1,0,0,0,162,248,146,0,248,191,2,0,192,72,6,0,1,0,0,0,76,1,147,0,32,56,2,0,152,122,6,0,1,0,0,0,77,1,147,0,96,82,2,0,56,210,6,0,1,0,0,0,78,1,147,0,192,135,2,0,24,163,6,0,1,0,0,0,79,1,147,0,240,108,2,0,200,110,3,0,1,0,0,0,73,1,147,0,152,30,2,0,88,212,3,0,1,0,0,0,184,220,146,0,40,185,3,0,248,5,8,0,9,0,0,0,160,6,147,0,32,58,1,0,144,250,7,0,9,0,0,0,161,6,147,0,32,58,1,0,184,40,2,0,1,0,0,0,52,234,148,0,248,191,2,0,56,250,6,0,1,0,0,0,50,234,148,0,184,160,2,0,184,164,8,0,1,0,0,0,53,234,148,0,64,246,1,0,88,149,7,0,1,0,0,0,51,234,148,0,136,224,1,0,208,158,7,0,1,0,0,0,115,233,148,0,96,82,2,0,184,154,7,0,1,0,0,0,113,233,148,0,32,56,2,0,176,108,2,0,1,0,0,0,116,233,148,0,152,30,2,0,16,83,7,0,1,0,0,0,187,232,148,0,40,167,1,0,96,79,7,0,1,0,0,0,185,232,148,0,200,149,1,0,48,76,7,0,1,0,0,0,188,232,148,0,56,126,1,0,88,212,3,0,1,0,0,0,208,220,146,0,40,185,3,0,16,17,8,0,1,0,0,0,54,234,148,0,224,12,8,0,248,5,8,0,9,0,0,0,208,94,147,0,32,58,1,0,144,250,7,0,9,0,0,0,209,94,147,0,32,58,1,0,248,241,7,0,9,0,0,0,210,94,147,0,32,58,1,0,184,40,2,0,1,0,0,0,63,234,148,0,248,191,2,0,56,250,6,0,1,0,0,0,62,234,148,0,184,160,2,0,184,164,8,0,1,0,0,0,127,233,148,0,64,246,1,0,88,149,7,0,1,0,0,0,126,233,148,0,136,224,1,0,240,167,7,0,1,0,0,0,61,234,148,0,192,135,2,0,176,163,7,0,1,0,0,0,60,234,148,0,240,108,2,0,208,158,7,0,1,0,0,0,58,234,148,0,96,82,2,0,184,154,7,0,1,0,0,0,59,234,148,0,32,56,2,0,176,108,2,0,1,0,0,0,57,234,148,0,152,30,2,0,8,96,7,0,1,0,0,0,125,233,148,0,72,198,1,0,48,89,7,0,1,0,0,0,124,233,148,0,24,182,1,0,16,83,7,0,1,0,0,0,122,233,148,0,40,167,1,0,96,79,7,0,1,0,0,0,123,233,148,0,200,149,1,0,48,76,7,0,1,0,0,0,121,233,148,0,56,126,1,0,88,212,3,0,1,0,0,0,224,220,146,0,40,185,3,0,16,17,8,0,1,0,0,0,56,234,148,0,224,12,8,0,248,5,8,0,9,0,0,0,216,94,147,0,32,58,1,0,144,250,7,0,9,0,0,0,217,94,147,0,32,58,1,0,184,40,2,0,1,0,0,0,134,233,148,0,248,191,2,0,56,250,6,0,1,0,0,0,70,234,148,0,184,160,2,0,184,164,8,0,1,0,0,0,135,233,148,0,64,246,1,0,88,149,7,0,1,0,0,0,71,234,148,0,136,224,1,0,56,210,6,0,1,0,0,0,66,234,148,0,192,135,2,0,24,163,6,0,1,0,0,0,67,234,148,0,240,108,2,0,152,122,6,0,1,0,0,0,65,234,148,0,96,82,2,0,192,72,6,0,1,0,0,0,64,234,148,0,32,56,2,0,48,123,2,0,1,0,0,0,68,234,148,0,152,30,2,0,96,69,2,0,1,0,0,0,69,234,148,0,232,10,2,0,144,55,2,0,1,0,0,0,193,232,148,0,152,138,8,0,176,223,1,0,1,0,0,0,130,233,148,0,72,198,1,0,192,209,1,0,1,0,0,0,131,233,148,0,24,182,1,0,24,198,1,0,1,0,0,0,129,233,148,0,40,167,1,0,120,189,1,0,1,0,0,0,128,233,148,0,200,149,1,0,248,187,8,0,1,0,0,0,132,233,148,0,56,126,1,0,184,179,8,0,1,0,0,0,133,233,148,0,32,101,1,0,240,173,8,0,1,0,0,0,194,232,148,0,96,32,8,0,88,212,3,0,1,0,0,0,8,221,146,0,40,185,3,0,16,17,8,0,1,0,0,0,192,232,148,0,224,12,8,0,248,5,8,0,9,0,0,0,224,94,147,0,32,58,1,0,144,250,7,0,9,0,0,0,225,94,147,0,32,58,1,0,168,86,7,0,1,0,0,0,212,240,146,0,248,191,2,0,24,38,7,0,1,0,0,0,211,240,146,0,184,160,2,0,56,210,6,0,1,0,0,0,176,1,147,0,192,135,2,0,24,163,6,0,1,0,0,0,177,1,147,0,240,108,2,0,152,122,6,0,1,0,0,0,178,1,147,0,96,82,2,0,192,72,6,0,1,0,0,0,179,1,147,0,32,56,2,0,200,110,3,0,1,0,0,0,208,240,146,0,152,30,2,0,120,89,3,0,1,0,0,0,209,240,146,0,232,10,2,0,120,74,3,0,1,0,0,0,210,240,146,0,152,138,8,0,144,236,1,0,1,0,0,0,147,237,146,0,136,224,1,0,176,223,1,0,1,0,0,0,240,248,146,0,72,198,1,0,192,209,1,0,1,0,0,0,241,248,146,0,24,182,1,0,24,198,1,0,1,0,0,0,242,248,146,0,40,167,1,0,120,189,1,0,1,0,0,0,243,248,146,0,200,149,1,0,224,22,1,0,1,0,0,0,144,237,146,0,56,126,1,0,160,14,1,0,1,0,0,0,145,237,146,0,32,101,1,0,176,9,1,0,1,0,0,0,146,237,146,0,96,32,8,0,88,212,3,0,1,0,0,0,48,221,146,0,40,185,3,0,56,122,5,0,1,0,0,0,214,240,146,0,224,12,8,0,0,105,5,0,1,0,0,0,215,240,146,0,224,12,8,0,72,65,1,0,9,0,0,0,248,6,147,0,32,58,1,0,184,40,2,0,1,0,0,0,224,240,146,0,248,191,2,0,184,164,8,0,1,0,0,0,225,240,146,0,64,246,1,0,24,38,7,0,1,0,0,0,227,240,146,0,184,160,2,0,144,236,1,0,1,0,0,0,228,240,146,0,136,224,1,0,152,122,6,0,1,0,0,0,192,1,147,0,96,82,2,0,192,72,6,0,1,0,0,0,193,1,147,0,32,56,2,0,56,210,6,0,1,0,0,0,194,1,147,0,192,135,2,0,24,163,6,0,1,0,0,0,195,1,147,0,240,108,2,0,200,110,3,0,1,0,0,0,196,1,147,0,152,30,2,0,120,89,3,0,1,0,0,0,197,1,147,0,232,10,2,0,24,198,1,0,1,0,0,0,0,249,146,0,40,167,1,0,120,189,1,0,1,0,0,0,1,249,146,0,200,149,1,0,176,223,1,0,1,0,0,0,2,249,146,0,72,198,1,0,192,209,1,0,1,0,0,0,3,249,146,0,24,182,1,0,224,22,1,0,1,0,0,0,4,249,146,0,56,126,1,0,160,14,1,0,1,0,0,0,5,249,146,0,32,101,1,0,16,17,8,0,1,0,0,0,226,240,146,0,224,12,8,0,88,212,3,0,1,0,0,0,64,221,146,0,40,185,3,0,248,5,8,0,9,0,0,0,8,7,147,0,32,58,1,0,144,250,7,0,9,0,0,0,9,7,147,0,32,58,1,0,248,241,7,0,9,0,0,0,10,7,147,0,32,58,1,0,184,40,2,0,1,0,0,0,24,2,147,0,248,191,2,0,184,164,8,0,1,0,0,0,25,2,147,0,64,246,1,0,56,250,6,0,1,0,0,0,27,2,147,0,184,160,2,0,88,149,7,0,1,0,0,0,28,2,147,0,136,224,1,0,152,122,6,0,1,0,0,0,88,249,146,0,96,82,2,0,192,72,6,0,1,0,0,0,89,249,146,0,32,56,2,0,56,210,6,0,1,0,0,0,90,249,146,0,192,135,2,0,24,163,6,0,1,0,0,0,91,249,146,0,240,108,2,0,48,123,2,0,1,0,0,0,92,249,146,0,152,30,2,0,96,69,2,0,1,0,0,0,93,249,146,0,232,10,2,0,24,198,1,0,1,0,0,0,56,241,146,0,40,167,1,0,120,189,1,0,1,0,0,0,57,241,146,0,200,149,1,0,176,223,1,0,1,0,0,0,58,241,146,0,72,198,1,0,192,209,1,0,1,0,0,0,59,241,146,0,24,182,1,0,248,187,8,0,1,0,0,0,60,241,146,0,56,126,1,0,184,179,8,0,1,0,0,0,61,241,146,0,32,101,1,0,88,212,3,0,1,0,0,0,144,221,146,0,40,185,3,0,16,17,8,0,1,0,0,0,26,2,147,0,224,12,8,0,248,5,8,0,9,0,0,0,232,94,147,0,32,58,1,0,144,250,7,0,9,0,0,0,233,94,147,0,32,58,1,0,248,241,7,0,9,0,0,0,234,94,147,0,32,58,1,0,168,86,7,0,1,0,0,0,56,2,147,0,248,191,2,0,24,38,7,0,1,0,0,0,59,2,147,0,184,160,2,0,56,210,6,0,1,0,0,0,122,249,146,0,192,135,2,0,24,163,6,0,1,0,0,0,123,249,146,0,240,108,2,0,152,122,6,0,1,0,0,0,120,249,146,0,96,82,2,0,192,72,6,0,1,0,0,0,121,249,146,0,32,56,2,0,200,110,3,0,1,0,0,0,124,249,146,0,152,30,2,0,120,89,3,0,1,0,0,0,125,249,146,0,232,10,2,0,120,74,3,0,1,0,0,0,126,249,146,0,152,138,8,0,40,246,1,0,1,0,0,0,57,2,147,0,64,246,1,0,144,236,1,0,1,0,0,0,60,2,147,0,136,224,1,0,176,223,1,0,1,0,0,0,90,241,146,0,72,198,1,0,192,209,1,0,1,0,0,0,91,241,146,0,24,182,1,0,24,198,1,0,1,0,0,0,88,241,146,0,40,167,1,0,120,189,1,0,1,0,0,0,89,241,146,0,200,149,1,0,224,22,1,0,1,0,0,0,92,241,146,0,56,126,1,0,160,14,1,0,1,0,0,0,93,241,146,0,32,101,1,0,176,9,1,0,1,0,0,0,94,241,146,0,96,32,8,0,88,212,3,0,1,0,0,0,168,221,146,0,40,185,3,0,16,17,8,0,1,0,0,0,62,2,147,0,224,12,8,0,72,65,1,0,9,0,0,0,88,7,147,0,32,58,1,0,48,50,1,0,9,0,0,0,89,7,147,0,32,58,1,0,224,41,1,0,9,0,0,0,90,7,147,0,32,58,1,0,168,86,7,0,1,0,0,0,136,2,147,0,248,191,2,0,24,38,7,0,1,0,0,0,139,2,147,0,184,160,2,0,56,210,6,0,1,0,0,0,202,249,146,0,192,135,2,0,24,163,6,0,1,0,0,0,203,249,146,0,240,108,2,0,200,110,3,0,1,0,0,0,204,249,146,0,152,30,2,0,40,246,1,0,1,0,0,0,137,2,147,0,64,246,1,0,144,236,1,0,1,0,0,0,140,2,147,0,136,224,1,0,176,223,1,0,1,0,0,0,170,241,146,0,72,198,1,0,192,209,1,0,1,0,0,0,171,241,146,0,24,182,1,0,224,22,1,0,1,0,0,0,172,241,146,0,56,126,1,0,16,17,8,0,1,0,0,0,138,2,147,0,224,12,8,0,88,212,3,0,1,0,0,0,240,221,146,0,40,185,3,0,248,5,8,0,9,0,0,0,144,7,147,0,32,58,1,0,144,250,7,0,9,0,0,0,145,7,147,0,32,58,1,0,184,40,2,0,1,0,0,0,83,234,148,0,248,191,2,0,56,250,6,0,1,0,0,0,80,234,148,0,184,160,2,0,184,164,8,0,1,0,0,0,212,232,148,0,64,246,1,0,88,149,7,0,1,0,0,0,81,234,148,0,136,224,1,0,240,167,7,0,1,0,0,0,147,233,148,0,192,135,2,0,176,163,7,0,1,0,0,0,146,233,148,0,240,108,2,0,208,158,7,0,1,0,0,0,145,233,148,0,96,82,2,0,184,154,7,0,1,0,0,0,144,233,148,0,32,56,2,0,176,108,2,0,1,0,0,0,149,233,148,0,152,30,2,0,128,98,2,0,1,0,0,0,151,233,148,0,232,10,2,0,8,96,7,0,1,0,0,0,211,232,148,0,72,198,1,0,48,89,7,0,1,0,0,0,210,232,148,0,24,182,1,0,16,83,7,0,1,0,0,0,209,232,148,0,40,167,1,0,96,79,7,0,1,0,0,0,208,232,148,0,200,149,1,0,48,76,7,0,1,0,0,0,213,232,148,0,56,126,1,0,144,72,7,0,1,0,0,0,215,232,148,0,32,101,1,0,88,212,3,0,1,0,0,0,8,222,146,0,40,185,3,0,16,17,8,0,1,0,0,0,82,234,148,0,224,12,8,0,248,5,8,0,9,0,0,0,248,94,147,0,32,58,1,0,144,250,7,0,9,0,0,0,249,94,147,0,32,58,1,0,184,40,2,0,1,0,0,0,231,232,148,0,248,191,2,0,56,250,6,0,1,0,0,0,166,233,148,0,184,160,2,0,184,164,8,0,1,0,0,0,230,232,148,0,64,246,1,0,88,149,7,0,1,0,0,0,167,233,148,0,136,224,1,0,240,167,7,0,1,0,0,0,162,233,148,0,192,135,2,0,176,163,7,0,1,0,0,0,163,233,148,0,240,108,2,0,208,158,7,0,1,0,0,0,161,233,148,0,96,82,2,0,184,154,7,0,1,0,0,0,160,233,148,0,32,56,2,0,176,108,2,0,1,0,0,0,164,233,148,0,152,30,2,0,128,98,2,0,1,0,0,0,165,233,148,0,232,10,2,0,8,96,7,0,1,0,0,0,226,232,148,0,72,198,1,0,48,89,7,0,1,0,0,0,227,232,148,0,24,182,1,0,16,83,7,0,1,0,0,0,225,232,148,0,40,167,1,0,96,79,7,0,1,0,0,0,224,232,148,0,200,149,1,0,48,76,7,0,1,0,0,0,228,232,148,0,56,126,1,0,144,72,7,0,1,0,0,0,229,232,148,0,32,101,1,0,88,212,3,0,1,0,0,0,48,215,146,0,40,185,3,0,16,17,8,0,1,0,0,0,54,232,148,0,224,12,8,0,248,5,8,0,9,0,0,0,16,94,147,0,32,58,1,0,144,250,7,0,9,0,0,0,17,94,147,0,32,58,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,54,97,57,45,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,73,198,207,242,0,0,16,1,50,54,97,97,45,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,75,93,221,68,0,0,16,1,50,54,97,98,45,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,205,221,221,73,0,0,16,1,50,54,97,99,45,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,38,175,126,9,0,0,16,1,50,54,97,101,45,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,103,120,67,234,0,0,16,1,50,54,97,100,45,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,214,108,227,117,0,0,16,1,50,54,97,56,45,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,156,4,209,58,0,0,32,0,50,54,106,48,45,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,132,156,48,219,0,0,32,0,50,54,106,49,45,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,12,30,8,195,0,0,32,0,50,54,97,102,45,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,173,90,97,58,0,0,32,0,50,54,106,50,45,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,174,100,149,88,0,0,32,0,50,54,106,51,45,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,214,64,240,218,0,0,32,0,50,54,97,49,48,45,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,137,216,22,109,0,0,32,0,50,54,106,52,45,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,118,62,201,168,0,0,32,0,50,54,106,53,45,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,55,82,85,238,0,0,32,0,50,54,106,54,45,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,41,42,75,168,0,0,32,0,50,54,106,55,45,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,213,72,106,188,0,0,32,0,112,114,111,109,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,41,149,51,70,0,0,32,0,100,108,95,51,46,117,54,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,79,62,235,1,0,0,16,1,100,108,95,53,46,117,54,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,97,11,116,117,0,0,16,1,100,108,95,52,46,117,54,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,111,119,163,198,0,0,16,1,100,108,95,49,46,117,52,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,123,160,17,174,0,0,16,1,100,108,95,50,46,117,55,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,232,38,154,79,0,0,16,1,100,108,95,54,46,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,250,211,82,99,0,0,32,0,100,108,95,55,46,53,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,105,139,163,55,0,0,32,0,100,108,95,56,46,54,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,177,229,158,80,0,0,32,0,100,108,95,57,46,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,215,20,133,174,0,0,32,0,100,108,95,49,48,46,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,183,111,64,109,0,0,32,0,100,108,95,49,49,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,171,192,249,189,0,0,32,0,97,55,49,45,50,53,46,52,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,69,133,15,45,0,0,32,0,15,0,0,0,255,255,255,0,0,0,0,0,16,0,0,0,255,255,63,0,0,0,0,0,0,0,0,0,254,0,2,0,32,182,8,0,15,0,0,0,1,1,1,0,168,174,8,0,15,0,0,0,1,1,0,0,136,165,8,0,0,0,0,0,254,0,4,0,128,156,8,0,15,0,0,0,1,5,4,0,240,149,8,0,15,0,0,0,1,5,5,0,0,144,8,0,15,0,0,0,1,5,1,0,232,138,8,0,15,0,0,0,1,5,0,0,120,133,8,0,0,0,0,0,254,0,2,0,144,212,8,0,15,0,0,0,1,2,2,0,96,135,7,0,15,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,15,0,0,0,1,4,0,0,96,135,7,0,15,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,15,0,0,0,1,8,0,0,96,135,7,0,15,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,15,0,0,0,1,48,16,0,224,127,8,0,15,0,0,0,1,48,48,0,32,123,8,0,15,0,0,0,1,48,0,0,248,116,8,0,15,0,0,0,1,48,32,0,192,110,8,0,0,0,0,0,254,0,4,0,160,123,6,0,15,0,0,0,1,192,64,0,224,127,8,0,15,0,0,0,1,192,192,0,32,123,8,0,15,0,0,0,1,192,0,0,248,116,8,0,15,0,0,0,1,192,128,0,192,110,8,0,0,0,0,0,254,0,4,0,72,202,5,0,16,0,0,0,1,3,2,0,80,246,3,0,16,0,0,0,1,3,3,0,248,38,7,0,16,0,0,0,1,3,1,0,112,212,3,0,16,0,0,0,1,3,0,0,24,99,5,0,0,0,0,0,254,0,4,0,64,37,5,0,16,0,0,0,1,12,8,0,24,71,8,0,16,0,0,0,1,12,12,0,128,68,8,0,16,0,0,0,1,12,4,0,0,65,8,0,16,0,0,0,1,12,0,0,184,59,8,0,0,0,0,0,254,0,4,0,128,129,4,0,16,0,0,0,1,48,16,0,192,255,2,0,16,0,0,0,1,48,0,0,208,75,4,0,16,0,0,0,1,48,48,0,8,49,4,0,16,0,0,0,1,48,32,0,104,39,8,0,0,0,0,0,254,0,4,0,96,33,8,0,16,0,0,0,1,192,0,0,248,38,7,0,16,0,0,0,1,192,64,0,80,124,6,0,16,0,0,0,1,192,128,0,64,111,3,0,16,0,0,0,1,192,192,0,152,20,8,0,0,0,0,0,14,0,0,0,255,255,128,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,14,0,0,0,1,3,0,0,8,49,4,0,14,0,0,0,1,3,1,0,152,21,4,0,14,0,0,0,1,3,2,0,72,246,3,0,14,0,0,0,1,3,3,0,72,0,3,0,0,0,0,0,254,0,4,0,64,37,5,0,14,0,0,0,1,12,0,0,176,114,3,0,14,0,0,0,1,12,4,0,176,116,6,0,14,0,0,0,1,12,8,0,80,113,6,0,14,0,0,0,1,12,12,0,80,110,6,0,0,0,0,0,254,0,8,0,32,4,2,0,14,0,0,0,1,112,112,0,96,135,3,0,14,0,0,0,1,112,80,0,32,136,7,0,14,0,0,0,1,112,48,0,40,88,7,0,14,0,0,0,1,112,16,0,96,39,7,0,14,0,0,0,1,112,0,0,144,251,6,0,14,0,0,0,1,112,32,0,184,164,6,0,14,0,0,0,1,112,64,0,80,74,6,0,14,0,0,0,1,112,96,0,192,32,6,0,0,0,0,0,254,0,2,0,200,30,2,0,14,0,0,0,1,128,128,0,120,97,1,0,14,0,0,0,1,128,0,0,96,19,1,0,0,0,0,0,99,100,117,95,50,51,97,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,205,67,37,124,2,0,16,1,99,100,117,95,50,50,97,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,169,64,183,250,2,0,16,1,99,100,117,95,50,49,97,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,226,61,210,102,2,0,16,1,99,100,45,49,109,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,23,249,164,141,4,0,32,0,99,100,45,51,109,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,3,246,64,108,4,0,32,0,99,100,45,50,109,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,45,252,200,9,4,0,32,0,99,100,45,52,109,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,143,243,127,99,4,0,32,0,99,100,45,53,109,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,238,239,11,71,4,0,32,0,99,100,45,55,109,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,163,183,191,34,4,0,32,0,99,100,45,54,109,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,196,154,89,231,4,0,32,0,99,100,45,56,109,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,21,75,27,33,4,0,32,0,99,100,95,113,46,53,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,11,219,95,96,3,0,16,0,99,100,45,113,49,46,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,117,119,146,96,6,0,64,0,99,100,45,113,50,46,50,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,71,76,15,119,6,0,64,0,99,100,45,113,51,46,51,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,252,63,39,47,6,0,64,0,99,100,45,113,52,46,52,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,29,130,103,44,6,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,154,135,134,67,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,99,100,54,51,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,2,233,114,239,0,0,0,8,105,111,98,49,46,49,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,98,112,114,103,49,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,167,61,121,49,0,0,0,8,105,111,99,49,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,129,32,24,13,0,0,0,8,100,55,108,49,46,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,13,65,183,39,0,0,0,8,100,56,108,49,46,56,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,218,199,159,83,0,0,0,8,100,57,107,50,46,57,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,86,161,133,205,0,0,0,8,100,49,48,102,49,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,148,196,25,102,0,0,0,8,107,108,50,45,114,49,46,56,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,167,220,112,76,2,0,16,1,107,108,50,45,108,50,46,56,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,56,115,174,198,2,0,16,1,99,100,45,97,46,49,54,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,179,159,79,126,4,0,32,0,99,100,45,98,46,49,54,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,133,45,83,137,4,0,32,0,99,100,95,113,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,11,219,95,96,3,0,16,0,99,100,95,113,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,117,119,146,96,6,0,64,0,99,100,95,113,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,71,76,15,119,6,0,64,0,99,100,95,113,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,252,63,39,47,6,0,64,0,99,100,95,113,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,29,130,103,44,6,0,64,0,99,100,106,95,50,51,97,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,150,206,62,95,2,0,16,1,99,100,106,95,50,50,97,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,41,222,216,160,2,0,16,1,99,100,106,95,50,49,97,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,226,61,210,102,2,0,16,1,99,100,95,48,49,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,23,249,164,141,4,0,32,0,99,100,95,48,50,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,3,246,64,108,4,0,32,0,99,100,95,48,51,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,45,252,200,9,4,0,32,0,99,100,95,48,52,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,143,243,127,99,4,0,32,0,99,100,95,48,53,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,238,239,11,71,4,0,32,0,99,100,95,48,54,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,163,183,191,34,4,0,32,0,99,100,95,48,55,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,196,154,89,231,4,0,32,0,99,100,95,48,56,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,21,75,27,33,4,0,32,0,99,100,95,113,46,53,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,11,219,95,96,3,0,16,0,99,100,45,113,49,46,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,117,119,146,96,6,0,64,0,99,100,45,113,50,46,50,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,71,76,15,119,6,0,64,0,99,100,45,113,51,46,51,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,252,63,39,47,6,0,64,0,99,100,45,113,52,46,52,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,29,130,103,44,6,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,154,135,134,67,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,99,100,54,51,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,2,233,114,239,0,0,0,8,105,111,98,49,46,49,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,98,112,114,103,49,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,167,61,121,49,0,0,0,8,105,111,99,49,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,129,32,24,13,0,0,0,8,100,55,108,49,46,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,13,65,183,39,0,0,0,8,100,56,108,49,46,56,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,218,199,159,83,0,0,0,8,100,57,107,50,46,57,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,86,161,133,205,0,0,0,8,100,49,48,102,49,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,148,196,25,102,0,0,0,8,99,100,97,95,50,51,104,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,240,156,42,142,2,0,16,1,99,100,97,95,50,50,104,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,25,210,44,247,2,0,16,1,99,100,97,95,50,49,104,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,118,91,39,188,2,0,16,1,99,100,97,95,50,48,104,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,117,201,135,137,2,0,16,1,99,100,95,103,102,120,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,23,249,164,141,4,0,32,0,99,100,95,103,102,120,48,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,3,246,64,108,4,0,32,0,99,100,95,103,102,120,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,45,252,200,9,4,0,32,0,99,100,95,103,102,120,48,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,143,243,127,99,4,0,32,0,99,100,95,103,102,120,48,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,238,239,11,71,4,0,32,0,99,100,95,103,102,120,48,55,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,163,183,191,34,4,0,32,0,99,100,95,103,102,120,48,54,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,196,154,89,231,4,0,32,0,99,100,95,103,102,120,48,56,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,21,75,27,33,4,0,32,0,99,100,95,113,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,11,219,95,96,3,0,16,0,99,100,95,113,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,117,119,146,96,6,0,64,0,99,100,95,113,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,71,76,15,119,6,0,64,0,99,100,95,113,51,46,114,111,109,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,252,63,39,47,6,0,64,0,99,100,95,113,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,29,130,103,44,6,0,64,0,29,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,72,4,1,0,29,0,0,0,1,8,0,0,96,135,7,0,29,0,0,0,1,8,8,0,152,182,7,0,48,48,51,46,101,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,15,85,136,208,1,0,16,1,48,48,52,46,104,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,106,68,40,162,1,0,16,1,48,48,53,46,106,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,187,128,214,20,1,0,16,1,54,46,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,224,146,112,4,2,0,16,1,48,48,49,46,104,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,77,221,177,26,4,0,32,0,48,48,50,46,107,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,238,117,227,75,4,0,32,0,49,56,115,48,51,48,46,108,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,249,208,97,48,7,0,32,0,15,0,0,0,255,255,0,0,0,0,0,0,16,0,0,0,255,255,128,0,0,0,0,0,17,0,0,0,255,255,1,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,16,0,0,0,1,64,0,0,120,97,1,0,16,0,0,0,1,64,64,0,96,19,1,0,0,0,0,0,254,0,2,0,32,4,2,0,16,0,0,0,1,128,64,0,144,147,2,0,16,0,0,0,1,128,128,0,184,146,2,0,0,0,0,0,254,0,4,0,72,202,5,0,17,0,0,0,1,3,0,0,80,246,3,0,17,0,0,0,1,3,1,0,80,124,6,0,17,0,0,0,1,3,2,0,112,212,3,0,17,0,0,0,1,3,3,0,248,160,5,0,0,0,0,0,254,0,2,0,128,129,4,0,17,0,0,0,1,4,0,0,8,49,4,0,17,0,0,0,1,4,4,0,152,21,4,0,0,0,0,0,254,0,2,0,64,37,5,0,17,0,0,0,1,8,0,0,80,110,6,0,17,0,0,0,1,8,8,0,112,216,4,0,101,112,114,45,49,50,49,56,57,46,97,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,93,155,142,85,1,0,16,1,101,112,114,45,49,50,49,56,56,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,15,36,42,128,1,0,16,1,101,112,114,45,49,49,57,49,53,46,97,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,50,49,237,216,1,0,16,1,101,112,114,45,49,49,57,49,51,46,97,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,146,203,198,48,1,0,16,1,109,112,114,45,49,49,57,49,55,46,97,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,144,33,119,111,2,0,32,0,109,112,114,45,49,49,57,49,56,46,97,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,149,219,49,199,2,0,32,0,109,112,114,45,49,49,57,49,57,46,97,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,145,164,213,100,2,0,32,0,109,112,114,45,49,49,57,50,48,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,205,227,209,229,3,0,32,0,109,112,114,45,49,49,57,50,50,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,221,196,176,112,3,0,32,0,109,112,114,45,49,49,57,50,49,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,140,53,210,97,3,0,32,0,109,112,114,45,49,49,57,50,51,46,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,125,228,255,201,3,0,32,0,101,112,114,45,49,49,57,49,54,46,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,207,65,181,122,4,0,16,1,51,49,55,45,48,48,57,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,16,100,97,100,101,46,48,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,61,83,115,142,1,0,16,1,100,97,100,101,46,48,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,46,232,194,0,1,0,16,1,100,97,100,101,46,48,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,8,96,153,234,1,0,16,1,100,97,100,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,90,73,37,98,1,0,16,1,100,97,100,46,48,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,195,14,72,179,1,0,16,1,100,97,100,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,214,183,60,218,5,0,32,0,100,97,100,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,114,49,182,146,5,0,32,0,100,97,100,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,245,87,135,185,5,0,32,0,100,97,100,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,70,206,33,129,5,0,32,0,100,97,100,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,63,111,126,131,5,0,32,0,100,97,100,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,219,107,145,240,5,0,32,0,100,97,100,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,239,147,243,206,5,0,32,0,100,97,100,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,158,254,83,137,5,0,32,0,100,97,100,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,36,36,94,63,10,0,16,1,100,97,100,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,103,155,73,12,12,0,64,0,100,97,100,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,78,90,11,47,12,0,64,0,100,100,50,101,46,48,51,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,175,97,147,68,1,0,16,1,100,100,50,101,46,48,52,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,182,82,112,91,1,0,16,1,100,100,50,101,46,48,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,96,95,141,120,1,0,16,1,100,100,50,101,46,48,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,30,126,128,224,1,0,16,1,100,100,50,101,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,2,122,119,187,1,0,16,1,100,100,50,101,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,144,8,151,48,1,0,16,1,100,100,50,101,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,77,25,226,153,1,0,16,1,100,100,50,101,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,94,128,152,225,1,0,16,1,100,100,50,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,110,78,107,164,5,0,32,0,100,100,50,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,252,80,252,213,5,0,32,0,100,100,50,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,103,8,124,131,5,0,32,0,100,100,50,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,28,194,14,187,5,0,32,0,100,100,50,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,226,76,130,109,5,0,32,0,100,100,50,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,229,42,104,121,5,0,32,0,100,100,50,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,73,209,221,172,5,0,32,0,100,100,50,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,192,176,127,17,5,0,32,0,100,100,50,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,229,87,214,153,10,0,16,1,100,100,50,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,36,56,122,17,10,0,16,1,100,100,50,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,37,195,208,152,12,0,64,0,100,100,50,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,250,231,162,94,12,0,64,0,26,0,0,0,255,255,127,0,0,0,0,0,27,0,0,0,255,255,255,0,0,0,0,0,28,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,8,0,200,87,7,0,26,0,0,0,1,7,1,0,32,136,7,0,26,0,0,0,1,7,2,0,40,88,7,0,26,0,0,0,1,7,4,0,96,39,7,0,26,0,0,0,1,7,7,0,144,251,6,0,26,0,0,0,1,7,3,0,120,211,6,0,26,0,0,0,1,7,6,0,184,164,6,0,26,0,0,0,1,7,5,0,80,74,6,0,26,0,0,0,1,7,0,0,16,227,4,0,0,0,0,0,254,0,8,0,160,123,6,0,26,0,0,0,1,56,8,0,32,136,7,0,26,0,0,0,1,56,16,0,40,88,7,0,26,0,0,0,1,56,32,0,96,39,7,0,26,0,0,0,1,56,56,0,144,251,6,0,26,0,0,0,1,56,24,0,120,211,6,0,26,0,0,0,1,56,48,0,184,164,6,0,26,0,0,0,1,56,40,0,80,74,6,0,26,0,0,0,1,56,0,0,16,227,4,0,0,0,0,0,254,0,2,0,168,234,7,0,26,0,0,0,1,64,0,0,96,135,7,0,26,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,16,30,2,0,26,0,0,0,1,128,128,0,96,135,7,0,26,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,27,0,0,0,1,1,1,0,96,135,7,0,27,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,27,0,0,0,1,2,2,0,96,135,7,0,27,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,27,0,0,0,1,12,8,0,80,246,3,0,27,0,0,0,1,12,12,0,248,38,7,0,27,0,0,0,1,12,4,0,112,212,3,0,27,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,4,0,128,129,4,0,27,0,0,0,1,48,0,0,192,255,2,0,27,0,0,0,1,48,16,0,208,75,4,0,27,0,0,0,1,48,48,0,8,49,4,0,27,0,0,0,1,48,32,0,72,246,3,0,0,0,0,0,254,0,4,0,64,37,5,0,27,0,0,0,1,192,128,0,144,29,2,0,27,0,0,0,1,192,192,0,224,28,2,0,27,0,0,0,1,192,64,0,88,28,2,0,27,0,0,0,1,192,0,0,184,27,2,0,0,0,0,0,254,0,2,0,224,133,4,0,28,0,0,0,1,128,128,0,144,26,2,0,28,0,0,0,1,128,0,0,104,24,2,0,0,0,0,0,17,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,4,0,72,202,5,0,17,0,0,0,1,3,1,0,80,246,3,0,17,0,0,0,1,3,0,0,248,38,7,0,17,0,0,0,1,3,2,0,112,212,3,0,17,0,0,0,1,3,3,0,248,160,5,0,0,0,0,0,254,0,4,0,128,129,4,0,17,0,0,0,1,48,32,0,208,75,4,0,17,0,0,0,1,48,0,0,8,49,4,0,17,0,0,0,1,48,16,0,152,21,4,0,17,0,0,0,1,48,48,0,72,246,3,0,0,0,0,0,254,0,2,0,80,105,6,0,17,0,0,0,1,64,64,0,96,135,7,0,17,0,0,0,1,64,0,0,152,182,7,0,102,97,108,99,111,110,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,195,202,113,33,0,0,16,1,102,97,108,99,111,110,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,247,63,184,136,0,0,16,1,102,97,108,99,111,110,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,71,175,242,207,0,0,16,1,102,97,108,99,111,110,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,35,207,46,107,0,0,16,1,102,97,108,99,111,110,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,223,202,125,50,0,0,16,1,102,97,108,99,111,110,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,200,109,145,168,0,0,32,0,102,97,108,99,111,110,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,222,93,59,205,0,0,32,0,102,97,108,99,111,110,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,103,3,42,182,0,0,32,0,102,97,108,99,111,110,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,94,44,18,97,0,0,32,0,102,97,108,99,111,110,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,241,128,124,246,0,0,32,0,102,97,108,99,111,110,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,125,81,235,128,0,0,32,0,99,107,54,118,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,37,51,28,117,0,0,32,0,99,107,54,117,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,250,64,25,171,0,0,32,0,99,107,54,116,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,165,39,232,180,0,0,32,0,102,97,108,99,111,110,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,251,205,11,95,0,0,64,0,102,97,108,99,111,110,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,189,255,3,144,0,0,64,0,116,107,111,106,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,47,69,245,17,1,0,16,1,116,107,111,106,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,120,83,101,104,1,0,16,1,116,107,111,106,49,95,100,46,115,105,109,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,125,55,51,105,6,0,32,0,116,107,111,106,49,95,99,46,115,105,109,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,80,137,102,127,6,0,32,0,116,107,111,106,49,95,98,46,115,105,109,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,169,140,182,207,6,0,32,0,116,107,111,106,49,95,97,46,115,105,109,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,197,33,126,67,6,0,32,0,116,107,111,106,51,95,100,46,115,105,109,109,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,87,43,227,169,6,0,32,0,116,107,111,106,51,95,99,46,115,105,109,109,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,56,147,171,183,6,0,32,0])
.concat([116,107,111,106,51,95,98,46,115,105,109,109,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,154,145,63,77,6,0,32,0,116,107,111,106,51,95,97,46,115,105,109,109,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,171,23,239,207,6,0,32,0,116,107,111,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,194,80,218,110,10,0,16,1,116,107,111,106,53,95,97,46,115,105,109,109,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,9,213,69,171,14,0,64,0,116,107,111,106,53,95,98,46,115,105,109,109,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,61,92,144,250,14,0,64,0,0,0,0,0,32,0,0,0,64,0,0,0,96,0,0,0,128,0,0,0,160,0,0,0,192,0,0,0,224,0,0,0,0,0,0,0,64,0,0,0,128,0,0,0,192,0,0,0,0,1,0,0,64,1,0,0,128,1,0,0,192,1,0,0,0,2,0,0,64,2,0,0,128,2,0,0,192,2,0,0,0,3,0,0,64,3,0,0,128,3,0,0,192,3,0,0,0,0,0,0,32,0,0,0,64,0,0,0,96,0,0,0,128,0,0,0,160,0,0,0,192,0,0,0,224,0,0,0,0,0,0,0,64,0,0,0,128,0,0,0,192,0,0,0,0,1,0,0,64,1,0,0,128,1,0,0,192,1,0,0,0,2,0,0,64,2,0,0,128,2,0,0,192,2,0,0,0,3,0,0,64,3,0,0,128,3,0,0,192,3,0,0,0,0,0,0,32,0,0,0,64,0,0,0,96,0,0,0,128,0,0,0,160,0,0,0,192,0,0,0,224,0,0,0,0,0,0,0,32,0,0,0,64,0,0,0,96,0,0,0,128,0,0,0,160,0,0,0,192,0,0,0,224,0,0,0,8,0,0,0,12,0,0,0,0,0,0,0,4,0,0,0,24,0,0,0,28,0,0,0,16,0,0,0,20,0,0,0,4,0,0,0,0,0,0,0,20,0,0,0,16,0,0,0,12,0,0,0,8,0,0,0,28,0,0,0,24,0,0,0,36,0,0,0,32,0,0,0,52,0,0,0,48,0,0,0,44,0,0,0,40,0,0,0,60,0,0,0,56,0,0,0,8,0,0,0,12,0,0,0,0,0,0,0,4,0,0,0,24,0,0,0,28,0,0,0,16,0,0,0,20,0,0,0,4,0,0,0,0,0,0,0,20,0,0,0,16,0,0,0,12,0,0,0,8,0,0,0,28,0,0,0,24,0,0,0,36,0,0,0,32,0,0,0,52,0,0,0,48,0,0,0,44,0,0,0,40,0,0,0,60,0,0,0,56,0,0,0,8,0,0,0,12,0,0,0,0,0,0,0,4,0,0,0,24,0,0,0,28,0,0,0,16,0,0,0,20,0,0,0,8,0,0,0,12,0,0,0,0,0,0,0,4,0,0,0,24,0,0,0,28,0,0,0,16,0,0,0,20,0,0,0,1,0,0,0,0,0,0,0,65,0,0,0,64,0,0,0,129,0,0,0,128,0,0,0,193,0,0,0,192,0,0,0,98,114,97,105,110,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,49,236,42,45,0,0,16,1,98,114,97,105,110,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,181,138,10,129,0,0,16,1,98,114,97,105,110,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,52,86,34,154,0,0,16,1,98,114,97,105,110,46,49,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,120,2,229,199,0,0,16,1,98,114,97,105,110,46,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,2,35,206,125,0,0,32,0,98,114,97,105,110,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,211,63,224,124,0,0,32,0,98,114,97,105,110,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,63,50,84,234,0,0,32,0,98,114,97,105,110,46,49,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,164,113,255,146,0,0,32,0,98,114,97,105,110,46,49,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,236,71,184,161,0,0,32,0,98,114,97,105,110,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,59,165,46,253,0,0,32,0,98,112,114,111,109,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,114,15,238,142,0,0,32,0,98,112,114,111,109,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,215,171,123,62,0,0,32,0,98,112,114,111,109,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,166,68,28,55,0,0,32,0,112,114,53,51,49,55,46,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,184,80,131,100,0,0,0,8,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,252,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,19,0,0,0,1,15,7,0,80,252,6,0,19,0,0,0,1,15,8,0,16,242,7,0,19,0,0,0,1,15,9,0,104,236,7,0,19,0,0,0,1,15,5,0,192,54,8,0,19,0,0,0,1,15,4,0,56,24,4,0,19,0,0,0,1,15,15,0,128,230,7,0,19,0,0,0,1,15,0,0,128,230,7,0,19,0,0,0,1,15,3,0,176,162,3,0,19,0,0,0,1,15,2,0,24,188,3,0,19,0,0,0,1,15,1,0,72,216,3,0,19,0,0,0,1,15,6,0,120,211,6,0,19,0,0,0,1,15,14,0,184,164,6,0,19,0,0,0,1,15,13,0,80,74,6,0,19,0,0,0,1,15,12,0,192,32,6,0,19,0,0,0,1,15,11,0,192,234,2,0,19,0,0,0,1,15,10,0,32,242,5,0,0,0,0,0,254,0,16,0,160,123,6,0,19,0,0,0,1,240,112,0,80,252,6,0,19,0,0,0,1,240,128,0,16,242,7,0,19,0,0,0,1,240,144,0,104,236,7,0,19,0,0,0,1,240,80,0,192,54,8,0,19,0,0,0,1,240,64,0,56,24,4,0,19,0,0,0,1,240,240,0,128,230,7,0,19,0,0,0,1,240,0,0,128,230,7,0,19,0,0,0,1,240,48,0,176,162,3,0,19,0,0,0,1,240,32,0,24,188,3,0,19,0,0,0,1,240,16,0,72,216,3,0,19,0,0,0,1,240,96,0,120,211,6,0,19,0,0,0,1,240,224,0,184,164,6,0,19,0,0,0,1,240,208,0,80,74,6,0,19,0,0,0,1,240,192,0,192,32,6,0,19,0,0,0,1,240,176,0,192,234,2,0,19,0,0,0,1,240,160,0,32,242,5,0,0,0,0,0,254,0,2,0,200,30,2,0,20,0,0,0,1,1,0,0,120,97,1,0,20,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,2,0,168,234,7,0,20,0,0,0,1,2,2,0,96,135,7,0,20,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,12,12,0,8,49,4,0,20,0,0,0,1,12,8,0,152,21,4,0,20,0,0,0,1,12,4,0,72,246,3,0,20,0,0,0,1,12,0,0,112,49,6,0,0,0,0,0,98,103,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,198,142,154,222,1,0,16,1,98,103,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,98,166,157,161,1,0,16,1,98,103,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,80,33,111,159,1,0,16,1,98,103,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,210,114,3,248,1,0,16,1,98,103,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,222,234,146,252,1,0,16,1,98,103,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,93,158,29,86,1,0,16,1,98,45,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,3,209,121,252,4,0,32,0,98,45,107,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,243,123,209,148,4,0,32,0,98,45,99,108,114,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,218,26,118,196,7,0,32,0,10,0,0,0,255,255,0,0,0,0,0,0,11,0,0,0,255,255,0,0,0,0,0,0,12,0,0,0,255,255,0,0,0,0,0,0,13,0,0,0,255,255,64,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,13,0,0,0,1,6,0,0,208,75,4,0,13,0,0,0,1,6,2,0,8,49,4,0,13,0,0,0,1,6,4,0,152,21,4,0,13,0,0,0,1,6,6,0,72,246,3,0,0,0,0,0,254,0,2,0,144,3,8,0,13,0,0,0,1,8,0,0,96,135,7,0,13,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,2,0,32,4,2,0,13,0,0,0,1,64,0,0,224,127,8,0,13,0,0,0,1,64,64,0,32,123,8,0,0,0,0,0,254,0,2,0,200,30,2,0,13,0,0,0,1,128,0,0,120,97,1,0,13,0,0,0,1,128,128,0,96,19,1,0,98,108,101,95,48,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,76,127,46,193,0,0,16,1,98,108,101,95,48,54,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,85,61,177,205,0,0,16,1,98,108,101,95,48,55,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,19,79,17,29,0,0,16,1,98,108,95,48,56,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,241,79,15,170,0,0,32,0,98,108,95,48,57,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,134,193,168,111,0,0,32,0,98,108,95,49,56,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,175,175,172,192,0,0,32,0,98,108,95,49,57,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,245,66,233,26,0,0,32,0,98,108,95,49,54,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,247,175,220,250,0,0,32,0,98,108,95,49,55,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,66,171,140,95,0,0,32,0,98,108,95,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,187,42,236,194,0,0,64,0,98,98,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,164,28,4,163,0,0,16,1,98,98,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,104,28,35,9,0,0,16,1,98,98,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,146,153,242,98,0,0,32,0,98,98,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,8,237,168,121,0,0,32,0,98,98,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,137,170,5,247,0,0,32,0,98,98,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,108,219,179,47,0,0,32,0,98,98,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,110,79,186,253,0,0,32,0,98,98,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,99,122,244,57,0,0,32,0,98,98,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,142,91,46,197,0,0,64,0,97,118,112,117,46,48,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,80,121,117,66,1,0,16,1,97,118,112,117,46,48,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,230,222,188,90,1,0,16,1,97,118,112,46,48,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,122,93,251,251,1,0,16,1,97,118,112,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,127,129,11,25,1,0,16,1,97,118,112,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,228,90,139,143,5,0,32,0,97,118,112,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,223,128,2,176,5,0,32,0,97,118,112,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,149,49,64,148,5,0,32,0,97,118,112,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,69,18,152,225,5,0,32,0,97,118,112,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,62,9,186,235,5,0,32,0,97,118,112,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,151,130,34,251,5,0,32,0,97,118,112,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,50,114,251,52,5,0,32,0,97,118,112,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,33,170,11,249,5,0,32,0,97,118,112,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,32,66,59,45,10,0,16,1,97,118,112,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,23,152,73,131,12,0,64,0,97,118,112,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,73,13,17,244,12,0,64,0,97,118,112,106,46,48,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,25,145,121,73,1,0,16,1,97,118,112,106,46,48,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,187,210,140,1,0,16,1,97,118,112,46,48,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,122,93,251,251,1,0,16,1,97,118,112,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,127,129,11,25,1,0,16,1,97,118,112,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,228,90,139,143,5,0,32,0,97,118,112,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,223,128,2,176,5,0,32,0,97,118,112,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,149,49,64,148,5,0,32,0,97,118,112,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,69,18,152,225,5,0,32,0,97,118,112,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,62,9,186,235,5,0,32,0,97,118,112,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,151,130,34,251,5,0,32,0,97,118,112,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,50,114,251,52,5,0,32,0,97,118,112,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,33,170,11,249,5,0,32,0,97,118,112,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,32,66,59,45,10,0,16,1,97,118,112,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,23,152,73,131,12,0,64,0,97,118,112,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,73,13,17,244,12,0,64,0,97,118,112,104,46,48,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,71,4,68,62,1,0,16,1,97,118,112,104,46,48,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,47,200,111,175,1,0,16,1,97,118,112,46,48,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,122,93,251,251,1,0,16,1,97,118,112,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,127,129,11,25,1,0,16,1,97,118,112,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,228,90,139,143,5,0,32,0,97,118,112,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,223,128,2,176,5,0,32,0,97,118,112,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,149,49,64,148,5,0,32,0,97,118,112,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,69,18,152,225,5,0,32,0,97,118,112,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,62,9,186,235,5,0,32,0,97,118,112,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,151,130,34,251,5,0,32,0,97,118,112,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,50,114,251,52,5,0,32,0,97,118,112,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,33,170,11,249,5,0,32,0,97,118,112,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,32,66,59,45,10,0,16,1,97,118,112,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,23,152,73,131,12,0,64,0,97,118,112,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,73,13,17,244,12,0,64,0,97,118,112,101,100,46,48,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,173,138,170,102,1,0,16,1,97,118,112,101,100,46,48,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,194,6,147,87,1,0,16,1,97,118,112,46,48,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,122,93,251,251,1,0,16,1,97,118,112,100,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,57,69,9,99,1,0,16,1,97,118,112,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,228,90,139,143,5,0,32,0,97,118,112,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,223,128,2,176,5,0,32,0,97,118,112,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,149,49,64,148,5,0,32,0,97,118,112,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,69,18,152,225,5,0,32,0,97,118,112,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,62,9,186,235,5,0,32,0,97,118,112,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,151,130,34,251,5,0,32,0,97,118,112,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,50,114,251,52,5,0,32,0,97,118,112,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,33,170,11,249,5,0,32,0,97,118,112,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,32,66,59,45,10,0,16,1,97,118,112,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,23,152,73,131,12,0,64,0,97,118,112,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,73,13,17,244,12,0,64,0,97,118,112,97,46,48,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,88,24,28,108,1,0,16,1,97,118,112,97,46,48,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,12,11,245,148,1,0,16,1,97,118,112,46,48,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,122,93,251,251,1,0,16,1,97,118,112,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,127,129,11,25,1,0,16,1,97,118,112,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,228,90,139,143,5,0,32,0,97,118,112,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,223,128,2,176,5,0,32,0,97,118,112,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,149,49,64,148,5,0,32,0,97,118,112,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,69,18,152,225,5,0,32,0,97,118,112,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,62,9,186,235,5,0,32,0,97,118,112,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,151,130,34,251,5,0,32,0,97,118,112,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,50,114,251,52,5,0,32,0,97,118,112,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,33,170,11,249,5,0,32,0,97,118,112,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,32,66,59,45,10,0,16,1,97,118,112,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,23,152,73,131,12,0,64,0,97,118,112,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,73,13,17,244,12,0,64,0,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,191,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,2,2,0,96,135,7,0,19,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,4,4,0,96,135,7,0,19,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,8,0,0,96,135,7,0,19,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,19,0,0,0,1,48,16,0,96,39,7,0,19,0,0,0,1,48,48,0,144,251,6,0,19,0,0,0,1,48,0,0,120,211,6,0,19,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,19,0,0,0,1,192,64,0,96,39,7,0,19,0,0,0,1,192,192,0,144,251,6,0,19,0,0,0,1,192,0,0,120,211,6,0,19,0,0,0,1,192,128,0,184,164,6,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,3,2,0,80,246,3,0,20,0,0,0,1,3,3,0,80,124,6,0,20,0,0,0,1,3,1,0,112,212,3,0,20,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,8,251,7,0,20,0,0,0,1,12,12,0,72,242,7,0,20,0,0,0,1,12,8,0,176,236,7,0,20,0,0,0,1,12,4,0,184,230,7,0,20,0,0,0,1,12,0,0,192,226,7,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,48,16,0,192,255,2,0,20,0,0,0,1,48,32,0,208,75,4,0,20,0,0,0,1,48,48,0,8,49,4,0,20,0,0,0,1,48,0,0,152,21,4,0,0,0,0,0,254,0,4,0,104,159,3,0,20,0,0,0,1,192,0,0,56,111,3,0,20,0,0,0,1,192,192,0,56,223,7,0,20,0,0,0,1,192,128,0,88,219,7,0,20,0,0,0,1,192,64,0,104,134,3,0,0,0,0,0,255,255,255,255,0,0,0,0,50,55,51,50,46,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,86,200,13,147,1,0,16,1,50,55,51,50,46,97,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,245,47,40,102,1,0,16,1,50,55,51,50,46,97,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,118,220,211,233,1,0,16,1,50,55,51,50,46,97,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,201,134,64,74,1,0,16,1,97,109,105,100,97,114,117,115,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,80,183,167,140,2,0,16,1,97,109,105,100,97,114,117,115,46,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,10,220,91,155,2,0,16,1,50,55,49,54,46,97,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,10,173,130,32,4,0,32,0,50,55,49,54,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,79,249,41,48,4,0,32,0,97,109,105,100,97,114,46,99,108,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,195,220,64,249,7,0,32,0,101,112,114,45,49,51,53,54,56,98,46,105,99,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,91,179,141,248,1,0,16,1,101,112,114,45,49,51,53,53,54,98,46,105,99,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,46,243,123,51,1,0,16,1,101,112,114,45,49,51,53,53,57,46,105,99,53,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,25,191,136,69,1,0,16,1,101,112,114,45,49,51,53,53,56,46,105,99,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,212,158,37,17,1,0,16,1,101,112,114,45,49,51,53,54,54,46,105,99,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,50,47,229,34,9,0,16,1,101,112,114,45,49,51,53,54,53,46,105,99,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,189,132,23,162,9,0,16,1,111,112,114,45,49,51,53,53,51,46,105,99,49,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,55,136,65,140,2,0,32,0,111,112,114,45,49,51,53,53,52,46,105,99,49,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,240,249,61,78,2,0,32,0,111,112,114,45,49,51,53,53,53,46,105,99,49,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,66,29,74,108,2,0,32,0,111,112,114,45,49,51,53,53,50,46,105,99,57,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,6,247,44,204,3,0,32,0,111,112,114,45,49,51,53,53,49,46,105,99,57,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,193,118,242,214,3,0,32,0,111,112,114,45,49,51,53,53,48,46,105,99,57,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,221,24,101,241,3,0,32,0,111,112,114,45,49,51,53,52,57,46,105,99,49,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,167,7,164,203,3,0,32,0,111,112,114,45,49,51,53,52,56,46,105,99,57,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,5,216,15,8,3,0,32,0,111,112,114,45,49,51,53,52,55,46,105,99,57,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,104,221,212,66,3,0,32,0,111,112,114,45,49,51,53,52,54,46,105,99,57,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,61,191,111,202,3,0,32,0,111,112,114,45,49,51,53,52,53,46,105,99,49,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,210,141,229,201,3,0,32,0,111,112,114,45,49,51,53,52,52,46,105,99,57,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,217,54,20,156,3,0,32,0,111,112,114,45,49,51,53,52,51,46,105,99,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,14,143,28,44,3,0,32,0,111,112,114,45,49,51,53,52,50,46,105,99,49,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,184,82,253,1,3,0,32,0,111,112,114,45,49,51,53,52,49,46,105,99,49,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,123,84,92,164,3,0,32,0,111,112,114,45,49,51,53,52,48,46,105,99,57,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,176,42,180,132,3,0,32,0,111,112,114,45,49,51,53,51,57,46,105,99,57,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,79,82,110,205,3,0,32,0,111,112,114,45,49,51,53,51,56,46,105,99,49,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,134,69,154,191,3,0,32,0,111,112,114,45,49,51,53,51,55,46,105,99,49,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,62,237,20,250,3,0,32,0,111,112,114,45,49,51,53,54,52,46,105,99,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,56,161,11,231,10,0,32,0,101,112,114,45,49,51,53,54,48,46,105,99,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,37,9,5,131,4,0,16,1,111,112,114,45,49,51,53,54,51,46,105,99,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,79,231,131,64,11,0,64,0,111,112,114,45,49,51,53,54,50,46,105,99,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,143,150,195,60,11,0,64,0,111,112,114,45,49,51,53,54,49,46,105,99,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,42,192,167,128,11,0,64,0,51,49,55,45,48,49,54,57,98,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,110,163,141,5,5,0,16,1,9,0,0,0,255,255,255,0,0,0,0,0,10,0,0,0,255,255,249,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,9,0,0,0,1,15,7,0,80,252,6,0,9,0,0,0,1,15,8,0,16,242,7,0,9,0,0,0,1,15,9,0,104,236,7,0,9,0,0,0,1,15,5,0,176,51,4,0,9,0,0,0,1,15,4,0,56,24,4,0,9,0,0,0,1,15,15,0,128,230,7,0,9,0,0,0,1,15,1,0,72,216,3,0,9,0,0,0,1,15,2,0,24,188,3,0,9,0,0,0,1,15,3,0,176,162,3,0,9,0,0,0,1,15,6,0,120,211,6,0,9,0,0,0,1,15,14,0,184,164,6,0,9,0,0,0,1,15,13,0,80,74,6,0,9,0,0,0,1,15,12,0,192,32,6,0,9,0,0,0,1,15,11,0,192,234,2,0,9,0,0,0,1,15,10,0,32,242,5,0,9,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,9,0,0,0,1,240,112,0,80,252,6,0,9,0,0,0,1,240,128,0,16,242,7,0,9,0,0,0,1,240,144,0,104,236,7,0,9,0,0,0,1,240,80,0,176,51,4,0,9,0,0,0,1,240,64,0,56,24,4,0,9,0,0,0,1,240,240,0,128,230,7,0,9,0,0,0,1,240,16,0,72,216,3,0,9,0,0,0,1,240,32,0,24,188,3,0,9,0,0,0,1,240,48,0,176,162,3,0,9,0,0,0,1,240,96,0,120,211,6,0,9,0,0,0,1,240,224,0,184,164,6,0,9,0,0,0,1,240,208,0,80,74,6,0,9,0,0,0,1,240,192,0,192,32,6,0,9,0,0,0,1,240,176,0,192,234,2,0,9,0,0,0,1,240,160,0,32,242,5,0,9,0,0,0,1,240,0,0,208,236,2,0,0,0,0,0,254,0,2,0,56,154,6,0,10,0,0,0,1,1,1,0,184,30,3,0,10,0,0,0,1,1,0,0,0,28,3,0,0,0,0,0,254,0,2,0,168,234,7,0,10,0,0,0,1,2,2,0,96,135,7,0,10,0,0,0,1,2,0,0,152,182,7,0])
.concat([0,0,0,0,254,0,2,0,104,159,3,0,10,0,0,0,1,4,4,0,56,111,3,0,10,0,0,0,1,4,0,0,104,134,3,0,0,0,0,0,254,0,4,0,112,59,6,0,10,0,0,0,1,48,16,0,80,246,3,0,10,0,0,0,1,48,48,0,248,38,7,0,10,0,0,0,1,48,32,0,112,212,3,0,10,0,0,0,1,48,0,0,248,160,5,0,0,0,0,0,254,0,4,0,72,202,5,0,10,0,0,0,1,192,64,0,80,246,3,0,10,0,0,0,1,192,192,0,248,38,7,0,10,0,0,0,1,192,128,0,112,212,3,0,10,0,0,0,1,192,0,0,248,160,5,0,0,0,0,0,48,54,53,45,117,98,98,48,52,46,49,48,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,59,201,150,248,1,0,16,1,48,54,53,45,117,98,98,48,53,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,100,93,46,224,1,0,16,1,48,54,53,45,97,48,50,46,57,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,76,196,29,179,1,0,16,1,48,54,53,45,97,48,51,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,230,47,132,19,1,0,16,1,48,54,53,45,97,48,49,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,77,58,125,20,2,0,16,1,48,54,53,45,97,48,56,46,49,53,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,202,154,100,107,3,0,32,0,48,54,53,45,97,48,55,46,49,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,196,143,220,197,3,0,32,0,48,54,53,45,97,48,57,46,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,47,213,5,234,4,0,32,0,48,54,53,45,97,49,48,46,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,2,24,185,150,4,0,32,0,48,54,53,45,97,49,50,46,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,122,208,30,50,4,0,32,0,48,54,53,45,97,49,49,46,49,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,142,148,218,70,4,0,32,0,48,54,53,45,97,48,54,46,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,224,206,219,90,5,0,64,0,120,109,101,110,95,117,98,98,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,186,52,243,82,0,0,0,8,117,110,48,48,49,48,48,49,46,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,126,86,108,65,1,0,16,1,117,110,48,48,49,48,48,50,46,117,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,166,63,122,73,1,0,16,1,117,110,48,48,49,48,48,56,46,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,43,11,93,29,11,0,32,0,117,110,48,48,49,48,48,55,46,53,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,81,109,30,158,11,0,32,0,117,110,48,48,49,48,48,54,46,52,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,212,128,169,152,11,0,32,0,117,110,48,48,49,48,48,53,46,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,192,227,44,111,11,0,32,0,117,110,48,48,49,48,48,52,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,56,249,95,161,6,0,64,0,117,110,48,48,49,48,48,51,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,85,158,75,63,6,0,64,0,48,54,52,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,134,46,90,56,1,0,16,1,48,54,52,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,138,153,3,42,2,0,32,0,48,54,52,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,234,124,200,46,3,0,32,0,48,54,52,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,171,129,107,82,3,0,32,0,48,54,52,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,49,27,109,67,3,0,32,0,48,54,52,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,38,221,200,249,3,0,32,0,48,54,52,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,244,169,52,142,3,0,32,0,48,54,52,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,102,71,62,164,3,0,32,0,48,54,52,45,99,55,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,21,114,217,89,3,0,32,0,48,54,52,45,99,56,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,103,35,9,252,3,0,32,0,48,54,52,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,211,201,238,210,4,0,16,1,48,54,52,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,9,113,39,170,5,0,64,0,48,54,52,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,221,126,82,182,5,0,64,0,48,53,51,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,203,116,181,149,1,0,16,1,48,53,51,45,112,50,46,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,69,237,152,241,1,0,16,1,48,53,51,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,107,45,44,140,2,0,32,0,48,53,51,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,206,91,235,133,3,0,32,0,48,53,51,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,72,176,147,236,3,0,32,0,48,53,51,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,101,73,214,13,3,0,32,0,48,53,51,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,84,217,112,146,3,0,32,0,48,53,51,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,75,208,217,27,4,0,16,1,48,53,51,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,133,244,141,166,5,0,64,0,48,53,51,45,118,52,46,118,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,102,143,234,123,5,0,64,0,108,49,48,95,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,145,93,1,148,1,0,0,0,107,49,48,95,52,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,239,211,27,83,1,0,0,0,116,111,107,105,106,112,46,48,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,8,40,168,214,1,0,0,0,116,111,107,105,106,112,46,48,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,16,91,26,160,1,0,0,0,116,111,107,105,106,112,46,48,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,197,196,135,108,2,0,0,0,116,111,107,105,106,112,46,48,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,196,105,121,166,2,0,0,0,116,111,107,105,106,112,46,48,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,162,100,169,138,3,0,0,0,116,111,107,105,106,112,46,48,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,72,126,232,134,3,0,0,0,116,111,107,105,46,111,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,186,128,122,162,4,0,0,0,116,111,107,105,46,111,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,119,104,250,4,0,0,0,116,111,107,105,46,98,107,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,75,95,170,253,5,0,0,0,116,111,107,105,46,98,107,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,100,198,106,216,6,0,0,0,116,111,107,105,106,112,46,48,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,139,107,122,174,7,0,0,0,98,53,51,45,50,52,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,198,36,104,214,1,0,16,1,98,53,51,45,50,53,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,113,78,172,214,2,0,16,1,98,53,51,45,50,54,46,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,156,100,213,207,3,0,16,1,98,53,51,45,49,54,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,42,156,81,195,4,0,32,0,98,53,51,45,49,55,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,232,153,241,43,4,0,32,0,98,53,51,45,49,56,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,217,94,243,146,4,0,32,0,98,53,51,45,49,57,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,129,149,187,237,4,0,32,0,98,53,51,45,50,50,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,246,174,210,89,4,0,32,0,98,53,51,45,50,51,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,155,251,172,116,4,0,32,0,98,53,51,45,50,48,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,192,13,93,9,4,0,32,0,98,53,51,45,50,49,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,77,197,0,152,4,0,32,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,4,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,49,46,117,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,36,191,33,197,1,0,16,1,50,46,117,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,49,108,159,177,1,0,16,1,56,49,116,115,95,51,108,46,117,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,156,255,124,215,2,0,32,0,56,50,116,115,95,51,104,46,117,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,131,181,18,240,2,0,32,0,56,51,116,115,95,52,108,46,117,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,195,175,140,7,2,0,32,0,56,52,116,115,95,52,104,46,117,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,107,68,145,31,2,0,32,0,56,53,116,115,95,53,108,46,117,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,89,210,251,64,2,0,32,0,56,54,116,115,95,53,104,46,117,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,95,147,108,24,2,0,32,0,56,55,116,115,95,54,108,46,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,138,196,125,193,2,0,32,0,56,56,116,115,95,54,104,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,218,165,219,228,2,0,32,0,56,57,116,115,95,55,108,46,117,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,197,178,177,218,2,0,32,0,57,48,116,115,95,55,104,46,117,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,179,150,230,170,2,0,32,0,57,49,116,115,95,56,108,46,117,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,32,0,225,172,83,233,2,0,32,0,57,50,116,115,95,56,104,46,117,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,118,185,163,157,2,0,32,0,57,51,116,115,95,57,108,46,117,52,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,254,135,48,35,2,0,32,0,57,52,116,115,95,57,104,46,117,52,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,199,49,168,157,2,0,32,0,57,53,116,115,95,49,48,108,46,117,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,64,82,58,48,2,0,32,0,57,54,116,115,95,49,48,104,46,117,53,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,246,235,64,34,2,0,32,0,57,55,116,115,95,115,110,100,46,117,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,166,236,85,145,3,0,64,0,116,103,109,50,46,100,101,102,97,117,108,116,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,140,52,226,80,4,0,16,1,56,53,55,109,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,164,127,216,59,1,0,16,1,56,53,55,109,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,89,198,108,48,1,0,16,1,56,53,55,100,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,15,33,212,170,2,0,16,1,56,53,55,98,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,102,9,120,184,3,0,32,0,56,53,55,98,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,80,141,77,62,3,0,32,0,56,53,55,98,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,177,95,81,123,4,0,32,0,56,53,55,98,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,59,247,176,39,4,0,32,0,56,53,55,98,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,212,18,53,206,5,0,64,0,56,53,55,98,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,19,60,184,32,6,0,64,0,56,53,55,97,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,7,133,117,50,7,0,0,8,0,0,0,0,0,0,0,0,3,0,0,0,24,0,0,0,26,0,0,0,28,0,0,0,30,0,0,0,127,0,0,0,107,0,0,0,255,63,0,0,82,61,0,0,252,63,0,0,100,61,0,0,249,63,0,0,24,0,0,0,0,0,0,0,240,63,0,0,160,0,0,0,243,63,0,0,160,0,0,0,243,63,0,0,161,0,0,0,243,63,0,0,162,0,0,0,243,63,0,0,163,0,0,0,248,63,0,0,176,0,0,0,255,255,0,0,255,255,0,0,255,255,0,0,255,255,0,0,255,255,0,0,255,255,0,0,255,255,0,0,255,255,0,0,255,255,0,0,255,255,0,0,3,0,0,0,8,0,0,0,10,0,0,0,12,0,0,0,14,0,0,0,127,0,0,0,43,0,0,0,255,63,0,0,82,0,0,0,252,63,0,0,100,0,0,0,249,63,0,0,8,0,0,0,0,0,0,0,240,63,0,0,160,61,0,0,243,63,0,0,160,61,0,0,243,63,0,0,161,61,0,0,243,63,0,0,162,61,0,0,243,63,0,0,163,61,0,0,248,63,0,0,176,61,0,0,255,255,0,0,255,255,0,0,255,255,0,0,255,255,0,0,255,255,0,0,255,255,0,0,255,255,0,0,255,255,0,0,255,255,0,0,255,255,0,0,3,0,0,0,32,0,0,0,40,0,0,0,48,0,0,0,56,0,0,0,127,0,0,0,105,0,0,0,255,63,0,0,53,55,0,0,252,63,0,0,100,55,0,0,231,63,0,0,32,0,0,0,0,0,0,0,240,63,0,0,144,61,0,0,243,63,0,0,144,61,0,0,243,63,0,0,145,61,0,0,243,63,0,0,146,61,0,0,243,63,0,0,147,61,0,0,248,63,0,0,160,61,0,0,255,255,0,0,255,255,0,0,255,255,0,0,255,255,0,0,255,255,0,0,255,255,0,0,255,255,0,0,255,255,0,0,255,255,0,0,255,255,0,0,3,0,0,0,128,0,0,0,144,0,0,0,160,0,0,0,176,0,0,0,127,0,0,0,255,255,0,0,255,31,0,0,255,29,0,0,252,31,0,0,92,27,0,0,207,31,0,0,128,0,0,0,0,0,0,0,240,31,0,0,64,21,0,0,243,31,0,0,64,21,0,0,243,31,0,0,65,21,0,0,243,31,0,0,66,21,0,0,243,31,0,0,67,21,0,0,248,31,0,0,80,21,0,0,255,255,0,0,255,255,0,0,255,255,0,0,255,255,0,0,255,255,0,0,255,255,0,0,255,255,0,0,255,255,0,0,255,255,0,0,255,255,0,0,115,102,115,49,57,117,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,73,28,228,200,1,0,16,1,115,102,115,50,50,117,46,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,9,147,126,102,1,0,16,1,115,102,115,50,48,117,46,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,191,101,48,48,1,0,16,1,115,102,115,50,51,117,46,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,163,39,105,222,1,0,16,1,115,102,115,50,49,117,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,139,65,74,0,1,0,16,1,115,102,115,50,52,117,46,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,255,69,69,43,1,0,16,1,115,102,45,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,52,197,154,74,2,0,16,1,115,102,117,45,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,3,233,204,167,3,0,16,1,115,102,45,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,213,240,224,134,3,0,16,1,115,102,45,51,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,146,210,227,206,4,0,32,0,115,102,45,51,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,118,150,169,46,4,0,32,0,115,102,45,52,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,149,4,40,224,4,0,32,0,115,102,45,52,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,222,48,11,199,4,0,32,0,115,102,45,50,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,46,4,35,127,5,0,32,0,115,102,45,50,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,28,185,248,146,5,0,32,0,115,102,45,51,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,86,152,57,177,5,0,32,0,115,102,45,51,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,46,174,182,150,5,0,32,0,115,102,45,50,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,245,233,237,84,5,0,32,0,115,102,45,50,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,103,154,100,240,5,0,32,0,115,102,45,51,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,26,215,77,143,5,0,32,0,115,102,45,51,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,180,15,192,112,5,0,32,0,115,102,45,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,219,19,1,252,6,0,32,0,115,102,45,49,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,211,166,228,130,6,0,32,0,115,102,45,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,27,223,18,225,6,0,32,0,115,102,45,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,153,34,213,66,6,0,32,0,115,102,45,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,217,64,243,73,6,0,32,0,115,102,45,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,177,233,236,149,6,0,32,0,115,102,45,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,129,87,160,92,6,0,32,0,115,102,45,49,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,142,196,250,105,6,0,32,0,115,102,45,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,141,209,207,113,6,0,32,0,115,102,45,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,75,178,46,250,6,0,32,0,115,102,45,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,149,92,149,173,6,0,32,0,115,102,45,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,49,58,183,65,6,0,32,0,115,102,45,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,80,28,196,145,6,0,32,0,115,102,45,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,190,124,140,83,6,0,32,0,115,102,45,50,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,109,179,9,43,7,0,32,0,115,102,45,51,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,61,157,208,35,8,0,32,0,115,102,45,51,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,108,223,22,234,8,0,32,0,115,102,45,51,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,217,43,223,114,8,0,32,0,115,102,45,51,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,213,211,153,62,8,0,32,0,115,102,98,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,173,153,65,134,0,0,0,8,115,102,98,48,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,93,140,63,189,0,0,0,8,109,98,55,49,49,52,104,46,49,50,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,100,75,115,76,0,0,0,8,109,109,105,45,55,54,48,51,46,49,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,83,218,188,6,0,0,0,8,105,56,55,53,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,16,115,102,45,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,215,39,96,17,1,0,16,1,115,102,45,50,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,158,208,203,211,1,0,16,1,115,102,45,50,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,63,232,7,254,1,0,16,1,115,102,45,50,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,51,93,67,30,1,0,16,1,115,102,45,50,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,76,188,134,224,1,0,16,1,115,102,45,50,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,107,105,166,19,1,0,16,1,115,102,45,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,52,197,154,74,2,0,16,1,115,102,45,48,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,69,56,115,75,3,0,16,1,115,102,45,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,213,240,224,134,3,0,16,1,115,102,45,51,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,146,210,227,206,4,0,32,0,115,102,45,51,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,118,150,169,46,4,0,32,0,115,102,45,52,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,149,4,40,224,4,0,32,0,115,102,45,52,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,222,48,11,199,4,0,32,0,115,102,45,50,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,46,4,35,127,5,0,32,0,115,102,45,50,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,28,185,248,146,5,0,32,0,115,102,45,51,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,86,152,57,177,5,0,32,0,115,102,45,51,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,46,174,182,150,5,0,32,0,115,102,45,50,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,245,233,237,84,5,0,32,0,115,102,45,50,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,103,154,100,240,5,0,32,0,115,102,45,51,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,26,215,77,143,5,0,32,0,115,102,45,51,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,180,15,192,112,5,0,32,0,115,102,45,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,219,19,1,252,6,0,32,0,115,102,45,49,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,211,166,228,130,6,0,32,0,115,102,45,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,27,223,18,225,6,0,32,0,115,102,45,49,50,46,98,105])
.concat([110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,153,34,213,66,6,0,32,0,115,102,45,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,217,64,243,73,6,0,32,0,115,102,45,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,177,233,236,149,6,0,32,0,115,102,45,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,129,87,160,92,6,0,32,0,115,102,45,49,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,142,196,250,105,6,0,32,0,115,102,45,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,141,209,207,113,6,0,32,0,115,102,45,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,75,178,46,250,6,0,32,0,115,102,45,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,149,92,149,173,6,0,32,0,115,102,45,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,49,58,183,65,6,0,32,0,115,102,45,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,80,28,196,145,6,0,32,0,115,102,45,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,190,124,140,83,6,0,32,0,115,102,45,50,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,109,179,9,43,7,0,32,0,115,102,45,51,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,61,157,208,35,8,0,32,0,115,102,45,51,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,108,223,22,234,8,0,32,0,115,102,45,51,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,217,43,223,114,8,0,32,0,115,102,45,51,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,213,211,153,62,8,0,32,0,115,102,98,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,173,153,65,134,0,0,0,8,115,102,98,48,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,93,140,63,189,0,0,0,8,109,98,55,49,49,52,104,46,49,50,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,100,75,115,76,0,0,0,8,109,109,105,45,55,54,48,51,46,49,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,83,218,188,6,0,0,0,8,54,56,55,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,100,174,0,0,38,44,0,0,44,218,0,0,44,188,0,0,44,158,0,0,47,14,0,0,49,16,0,0,197,30,0,0,50,144,0,0,172,92,0,0,43,192,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,54,52,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,157,150,204,184,1,0,16,1,50,54,52,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,238,143,20,79,3,0,32,0,50,54,52,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,114,255,245,124,3,0,32,0,50,54,52,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,152,76,216,100,3,0,32,0,50,54,52,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,149,74,57,47,3,0,32,0,50,54,52,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,120,185,153,107,3,0,32,0,50,54,52,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,125,92,125,132,3,0,32,0,50,54,52,45,99,55,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,30,104,29,35,3,0,32,0,50,54,52,45,99,56,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,196,181,237,197,3,0,32,0,50,54,52,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,67,123,189,77,4,0,16,1,50,54,52,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,18,88,0,250,5,0,64,0,50,54,52,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,240,139,220,195,5,0,64,0,183,102,163,192,81,85,109,99,134,96,100,108,103,24,11,5,98,255,224,30,48,33,46,64,65,185,96,56,209,36,126,54,122,11,28,105,79,9,225,158,207,205,124,0,115,8,119,55,95,80,50,62,211,84,119,107,96,96,116,124,85,79,68,94,102,92,88,38,53,41,63,53,63,28,11,13,8,91,89,92,160,165,135,133,36,117,95,66,27,243,26,88,23,88,113,107,105,137,125,58,243,196,93,160,79,39,88,196,168,221,168,251,190,164,226,238,7,16,144,114,153,8,104,109,92,92,109,88,47,220,21,213,214,214,59,59,249,50,204,221,212,241,234,237,228,246,242,145,202,193,237,242,246,251,192,232,227,231,250,241,245,8,38,43,47,52,57,19,40,7,136,91,143,148,155,46,245,171,114,118,122,64,185,9,216,59,205,49,61,66,171,177,181,185,59,227,11,101,24,251,31,18,228,232,236,242,247,252,192,232,224,230,250,241,244,11,38,43,48,53,57,19,41,33,12,17,22,27,31,100,14,96,5,121,124,55,0,15,79,56,29,24,162,182,178,169,172,171,174,145,152,141,145,187,177,192,49,46,117,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,110,221,53,177,1,0,16,1,50,46,117,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,156,40,133,119,1,0,16,1,55,46,117,49,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,207,61,198,222,2,0,16,1,54,46,117,49,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,146,11,235,228,2,0,16,1,53,46,117,49,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,11,50,43,165,2,0,16,1,52,46,117,49,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,49,119,246,126,2,0,16,1,49,53,46,117,49,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,120,47,252,205,3,0,32,0,49,52,46,117,49,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,240,103,231,135,3,0,32,0,49,51,46,117,49,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,190,42,127,224,3,0,32,0,49,50,46,117,49,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,14,21,70,244,3,0,32,0,49,49,46,117,49,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,170,77,17,92,3,0,32,0,49,48,46,117,49,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,64,250,17,250,3,0,32,0,57,46,117,49,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,26,107,70,157,3,0,32,0,56,46,117,49,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,107,95,138,208,3,0,32,0,51,46,117,49,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,40,112,211,208,4,0,32,0,49,45,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,176,191,23,47,1,0,16,0,50,45,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,84,35,163,186,1,0,16,0,100,103,56,46,101,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,163,29,214,209,2,0,16,0,100,103,57,46,108,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,8,74,134,223,3,0,32,0,100,103,49,48,46,109,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,83,13,71,158,3,0,32,0,115,110,107,56,56,48,46,49,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,6,217,15,231,4,0,32,0,115,110,107,56,56,48,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,237,26,139,98,4,0,32,0,115,110,107,56,56,48,46,49,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,104,136,220,25,4,0,32,0,115,110,107,56,56,48,46,49,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,139,73,205,71,4,0,32,0,115,110,107,56,56,48,46,49,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,87,233,144,122,4,0,32,0,115,110,107,56,56,48,46,49,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,19,108,10,228,4,0,32,0,115,110,107,56,56,48,46,49,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,194,28,147,199,4,0,32,0,115,110,107,56,56,48,46,49,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,50,34,215,238,4,0,32,0,115,110,107,56,56,48,46,49,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,221,184,117,23,4,0,32,0,115,110,107,56,56,48,46,50,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,236,82,231,248,4,0,32,0,115,110,107,56,56,48,46,50,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,254,255,233,39,4,0,32,0,115,110,107,56,56,48,46,50,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,216,0,156,170,4,0,32,0,115,110,107,56,56,48,46,50,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,104,173,182,173,4,0,32,0,115,110,107,56,56,48,46,50,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,90,134,65,221,4,0,32,0,115,110,107,56,56,48,46,50,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,173,89,87,5,4,0,32,0,115,110,107,56,56,48,46,50,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,197,97,194,155,4,0,32,0,100,103,55,46,100,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,211,169,169,171,5,0,64,0,112,97,108,50,48,108,49,48,46,97,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,204,0,0,0,41,231,217,195,0,0,0,8,0,0,0,0,0,0,0,0,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,246,24,95,12,1,0,16,1,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,61,87,84,123,1,0,16,1,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,222,204,160,185,2,0,16,1,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,189,91,49,199,3,0,64,0,51,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,7,63,179,42,4,0,32,0,51,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,157,112,119,102,4,0,32,0,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,26,184,17,127,5,0,32,0,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,29,167,224,128,5,0,32,0,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,231,153,100,41,5,0,32,0,51,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,92,173,192,53,5,0,32,0,111,114,98,115,46,117,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,200,121,240,16,1,0,16,1,111,114,98,115,46,117,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,111,209,105,242,1,0,16,1,111,114,98,115,46,117,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,65,101,199,28,3,0,32,0,111,114,98,115,46,117,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,26,220,75,120,3,0,32,0,111,114,98,115,46,117,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,194,82,195,184,3,0,32,0,111,114,98,115,46,117,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,186,56,203,88,3,0,32,0,111,114,98,115,46,117,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,227,159,14,188,6,0,64,0,111,114,98,115,46,117,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,115,131,205,174,6,0,64,0,52,24,0,0,198,14,0,0,120,16,0,0,120,16,0,0,218,45,0,0,198,14,0,0,114,21,0,0,114,21,0,0,18,42,0,0,18,42,0,0,18,42,0,0,18,42,0,0,148,10,0,0,148,10,0,0,148,10,0,0,148,10,0,0,230,30,0,0,230,30,0,0,230,30,0,0,230,30,0,0,224,13,0,0,224,13,0,0,224,13,0,0,224,13,0,0,56,26,0,0,56,26,0,0,56,26,0,0,56,26,0,0,224,11,0,0,224,11,0,0,224,11,0,0,224,11,0,0,94,3,0,0,94,3,0,0,94,3,0,0,94,3,0,0,62,7,0,0,62,7,0,0,62,7,0,0,62,7,0,0,60,24,0,0,60,24,0,0,60,24,0,0,60,24,0,0,196,18,0,0,196,18,0,0,196,18,0,0,196,18,0,0,60,46,0,0,60,46,0,0,60,46,0,0,60,46,0,0,136,8,0,0,136,8,0,0,136,8,0,0,136,8,0,0,74,1,0,0,74,1,0,0,74,1,0,0,74,1,0,0,122,44,0,0,122,44,0,0,122,44,0,0,122,44,0,0,158,6,0,0,158,6,0,0,158,6,0,0,158,6,0,0,158,6,0,0,158,6,0,0,158,6,0,0,158,6,0,0,158,6,0,0,158,6,0,0,158,6,0,0,158,6,0,0,158,6,0,0,158,6,0,0,158,6,0,0,158,6,0,0,238,38,0,0,238,38,0,0,238,38,0,0,238,38,0,0,238,38,0,0,238,38,0,0,238,38,0,0,238,38,0,0,238,38,0,0,238,38,0,0,238,38,0,0,238,38,0,0,238,38,0,0,238,38,0,0,238,38,0,0,238,38,0,0,124,26,0,0,124,26,0,0,124,26,0,0,124,26,0,0,124,26,0,0,124,26,0,0,124,26,0,0,124,26,0,0,124,26,0,0,124,26,0,0,124,26,0,0,124,26,0,0,124,26,0,0,124,26,0,0,124,26,0,0,124,26,0,0,212,22,0,0,212,22,0,0,212,22,0,0,212,22,0,0,212,22,0,0,212,22,0,0,212,22,0,0,212,22,0,0,212,22,0,0,212,22,0,0,212,22,0,0,212,22,0,0,212,22,0,0,212,22,0,0,212,22,0,0,212,22,0,0,56,11,0,0,56,11,0,0,56,11,0,0,56,11,0,0,56,11,0,0,56,11,0,0,56,11,0,0,56,11,0,0,56,11,0,0,56,11,0,0,56,11,0,0,56,11,0,0,56,11,0,0,56,11,0,0,56,11,0,0,56,11,0,0,186,27,0,0,186,27,0,0,186,27,0,0,186,27,0,0,186,27,0,0,186,27,0,0,186,27,0,0,186,27,0,0,186,27,0,0,186,27,0,0,186,27,0,0,186,27,0,0,186,27,0,0,186,27,0,0,186,27,0,0,186,27,0,0,162,50,0,0,162,50,0,0,162,50,0,0,162,50,0,0,162,50,0,0,162,50,0,0,162,50,0,0,162,50,0,0,162,50,0,0,162,50,0,0,162,50,0,0,162,50,0,0,162,50,0,0,162,50,0,0,162,50,0,0,162,50,0,0,162,50,0,0,162,50,0,0,162,50,0,0,162,50,0,0,162,50,0,0,162,50,0,0,162,50,0,0,162,50,0,0,162,50,0,0,162,50,0,0,162,50,0,0,162,50,0,0,162,50,0,0,162,50,0,0,162,50,0,0,162,50,0,0,240,34,0,0,240,34,0,0,240,34,0,0,240,34,0,0,240,34,0,0,240,34,0,0,240,34,0,0,240,34,0,0,240,34,0,0,240,34,0,0,240,34,0,0,240,34,0,0,240,34,0,0,240,34,0,0,240,34,0,0,240,34,0,0,226,47,0,0,226,47,0,0,226,47,0,0,226,47,0,0,226,47,0,0,226,47,0,0,226,47,0,0,226,47,0,0,226,47,0,0,226,47,0,0,226,47,0,0,226,47,0,0,226,47,0,0,226,47,0,0,226,47,0,0,226,47,0,0,114,15,0,0,114,15,0,0,114,15,0,0,114,15,0,0,114,15,0,0,114,15,0,0,114,15,0,0,114,15,0,0,114,15,0,0,114,15,0,0,114,15,0,0,114,15,0,0,114,15,0,0,114,15,0,0,114,15,0,0,114,15,0,0,32,9,0,0,32,9,0,0,32,9,0,0,32,9,0,0,32,9,0,0,32,9,0,0,32,9,0,0,32,9,0,0,32,9,0,0,32,9,0,0,32,9,0,0,32,9,0,0,32,9,0,0,32,9,0,0,32,9,0,0,32,9,0,0,1,0,0,0,196,26,0,0,0,0,0,0,230,31,0,0,2,0,0,0,194,2,0,0,2,0,0,0,20,22,0,0,2,0,0,0,50,28,0,0,1,0,0,0,22,21,0,0,0,0,0,0,230,31,0,0,1,0,0,0,34,21,0,0,2,0,0,0,248,40,0,0,2,0,0,0,72,21,0,0,2,0,0,0,144,15,0,0,0,0,0,0,230,31,0,0,2,0,0,0,32,36,0,0,2,0,0,0,152,17,0,0,2,0,0,0,80,23,0,0,2,0,0,0,70,4,0,0,1,0,0,0,144,20,0,0,1,0,0,0,86,1,0,0,2,0,0,0,26,24,0,0,2,0,0,0,202,31,0,0,2,0,0,0,236,14,0,0,1,0,0,0,108,45,0,0,2,0,0,0,78,6,0,0,1,0,0,0,62,24,0,0,1,0,0,0,20,31,0,0,1,0,0,0,154,49,0,0,1,0,0,0,100,18,0,0,1,0,0,0,198,36,0,0,1,0,0,0,18,5,0,0,1,0,0,0,28,39,0,0,1,0,0,0,118,42,0,0,1,0,0,0,246,10,0,0,1,0,0,0,12,24,0,0,1,0,0,0,128,42,0,0,0,0,0,0,230,31,0,0,2,0,0,0,48,34,0,0,2,0,0,0,34,23,0,0,1,0,0,0,154,39,0,0,2,0,0,0,178,44,0,0,1,0,0,0,64,4,0,0,1,0,0,0,10,47,0,0,1,0,0,0,190,28,0,0,1,0,0,0,170,0,0,0,1,0,0,0,254,15,0,0,1,0,0,0,124,21,0,0,1,0,0,0,82,2,0,0,1,0,0,0,92,8,0,0,1,0,0,0,16,40,0,0,1,0,0,0,136,28,0,0,1,0,0,0,116,28,0,0,2,0,0,0,148,42,0,0,0,0,0,0,230,31,0,0,2,0,0,0,176,16,0,0,1,0,0,0,240,21,0,0,2,0,0,0,222,17,0,0,1,0,0,0,10,44,0,0,0,0,0,0,230,31,0,0,2,0,0,0,222,37,0,0,2,0,0,0,174,40,0,0,0,0,0,0,230,31,0,0,2,0,0,0,4,22,0,0,2,0,0,0,66,12,0,0,2,0,0,0,144,8,0,0,2,0,0,0,162,48,0,0,1,0,0,0,134,38,0,0,1,0,0,0,6,7,0,0,1,0,0,0,210,1,0,0,2,0,0,0,106,1,0,0,2,0,0,0,172,41,0,0,1,0,0,0,8,2,0,0,2,0,0,0,106,26,0,0,1,0,0,0,12,3,0,0,1,0,0,0,176,17,0,0,1,0,0,0,10,49,0,0,1,0,0,0,48,24,0,0,1,0,0,0,60,13,0,0,1,0,0,0,230,41,0,0,1,0,0,0,106,23,0,0,1,0,0,0,218,28,0,0,1,0,0,0,98,10,0,0,1,0,0,0,142,35,0,0,1,0,0,0,206,3,0,0,2,0,0,0,234,36,0,0,2,0,0,0,56,12,0,0,2,0,0,0,228,34,0,0,1,0,0,0,108,13,0,0,2,0,0,0,78,36,0,0,1,0,0,0,182,2,0,0,1,0,0,0,172,43,0,0,1,0,0,0,112,25,0,0,1,0,0,0,126,6,0,0,1,0,0,0,26,38,0,0,1,0,0,0,204,19,0,0,1,0,0,0,92,0,0,0,1,0,0,0,124,32,0,0,1,0,0,0,56,14,0,0,1,0,0,0,58,28,0,0,1,0,0,0,164,46,0,0,1,0,0,0,54,8,0,0,0,0,0,0,230,31,0,0,2,0,0,0,20,10,0,0,1,0,0,0,212,8,0,0,0,0,0,0,230,31,0,0,1,0,0,0,174,22,0,0,1,0,0,0,162,23,0,0,1,0,0,0,168,4,0,0,1,0,0,0,166,10,0,0,1,0,0,0,54,42,0,0,1,0,0,0,138,47,0,0,1,0,0,0,220,20,0,0,1,0,0,0,142,34,0,0,1,0,0,0,94,16,0,0,1,0,0,0,116,1,0,0,1,0,0,0,136,33,0,0,2,0,0,0,34,5,0,0,0,0,0,0,230,31,0,0,2,0,0,0,66,3,0,0,1,0,0,0,88,4,0,0,2,0,0,0,112,8,0,0,1,0,0,0,88,15,0,0,1,0,0,0,246,25,0,0,1,0,0,0,74,44,0,0,1,0,0,0,238,12,0,0,1,0,0,0,80,31,0,0,1,0,0,0,192,49,0,0,1,0,0,0,128,18,0,0,1,0,0,0,248,36,0,0,1,0,0,0,82,29,0,0,2,0,0,0,16,20,0,0,2,0,0,0,178,0,0,0,0,0,0,0,230,31,0,0,2,0,0,0,160,46,0,0,2,0,0,0,160,28,0,0,1,0,0,0,30,22,0,0,2,0,0,0,98,40,0,0,0,0,0,0,230,31,0,0,2,0,0,0,152,18,0,0,2,0,0,0,12,40,0,0,2,0,0,0,166,39,0,0,0,0,0,0,230,31,0,0,2,0,0,0,28,25,0,0,2,0,0,0,144,34,0,0,2,0,0,0,44,38,0,0,2,0,0,0,158,27,0,0,2,0,0,0,170,24,0,0,2,0,0,0,188,2,0,0,2,0,0,0,12,48,0,0,2,0,0,0,208,16,0,0,2,0,0,0,250,23,0,0,1,0,0,0,240,48,0,0,2,0,0,0,38,33,0,0,1,0,0,0,154,45,0,0,2,0,0,0,142,22,0,0,2,0,0,0,160,27,0,0,2,0,0,0,146,27,0,0,0,0,0,0,230,31,0,0,2,0,0,0,126,41,0,0,2,0,0,0,234,12,0,0,2,0,0,0,96,48,0,0,2,0,0,0,150,5,0,0,1,0,0,0,252,2,0,0,1,0,0,0,224,31,0,0,0,0,0,0,230,31,0,0,2,0,0,0,82,34,0,0,2,0,0,0,250,46,0,0,1,0,0,0,64,3,0,0,0,0,0,0,230,31,0,0,1,0,0,0,240,6,0,0,1,0,0,0,234,42,0,0,1,0,0,0,244,47,0,0,1,0,0,0,54,45,0,0,1,0,0,0,190,4,0,0,1,0,0,0,66,38,0,0,1,0,0,0,6,48,0,0,1,0,0,0,62,45,0,0,1,0,0,0,220,4,0,0,2,0,0,0,176,28,0,0,2,0,0,0,146,11,0,0,2,0,0,0,178,16,0,0,2,0,0,0,128,11,0,0,2,0,0,0,142,42,0,0,1,0,0,0,100,40,0,0,2,0,0,0,30,40,0,0,0,0,0,0,230,31,0,0,2,0,0,0,228,23,0,0,2,0,0,0,126,42,0,0,2,0,0,0,18,4,0,0,2,0,0,0,208,23,0,0,2,0,0,0,160,21,0,0,2,0,0,0,220,40,0,0,2,0,0,0,158,12,0,0,2,0,0,0,0,22,0,0,0,0,0,0,230,31,0,0,0,0,0,0,230,31,0,0,0,0,0,0,230,31,0,0,0,0,0,0,230,31,0,0,2,0,0,0,238,15,0,0,1,0,0,0,226,31,0,0,2,0,0,0,226,10,0,0,1,0,0,0,64,36,0,0,1,0,0,0,182,41,0,0,1,0,0,0,56,10,0,0,1,0,0,0,174,28,0,0,1,0,0,0,38,47,0,0,1,0,0,0,246,15,0,0,1,0,0,0,70,34,0,0,1,0,0,0,72,2,0,0,1,0,0,0,142,21,0,0,1,0,0,0,194,6,0,0,1,0,0,0,76,38,0,0,2,0,0,0,16,11,0,0,2,0,0,0,136,30,0,0,2,0,0,0,242,10,0,0,1,0,0,0,152,13,0,0,0,0,0,0,230,31,0,0,1,0,0,0,162,6,0,0,1,0,0,0,70,39,0,0,1,0,0,0,174,7,0,0,1,0,0,0,86,26,0,0,1,0,0,0,46,2,0,0,1,0,0,0,60,15,0,0,1,0,0,0,114,33,0,0,1,0,0,0,102,1,0,0,1,0,0,0,216,20,0,0,0,0,0,0,230,31,0,0,0,0,0,0,230,31,0,0,0,0,0,0,230,31,0,0,2,0,0,0,246,41,0,0,2,0,0,0,36,34,0,0,1,0,0,0,60,32,0,0,2,0,0,0,188,4,0,0,1,0,0,0,226,26,0,0,2,0,0,0,16,13,0,0,2,0,0,0,2,13,0,0,2,0,0,0,230,49,0,0,2,0,0,0,126,31,0,0,2,0,0,0,144,18,0,0,2,0,0,0,166,18,0,0,2,0,0,0,72,24,0,0,2,0,0,0,124,5,0,0,1,0,0,0,98,2,0,0,1,0,0,0,84,34,0,0,2,0,0,0,236,22,0,0,0,0,0,0,230,31,0,0,2,0,0,0,120,29,0,0,1,0,0,0,14,0,0,0,2,0,0,0,222,38,0,0,1,0,0,0,50,10,0,0,1,0,0,0,168,9,0,0,1,0,0,0,34,28,0,0,1,0,0,0,128,46,0,0,1,0,0,0,182,36,0,0,1,0,0,0,164,33,0,0,1,0,0,0,156,1,0,0,1,0,0,0,8,21,0,0,1,0,0,0,122,39,0,0,0,0,10,58,78,46,3,64,51,67,38,44,0,0,0,0,0,0,68,77,11,39,61,15,55,43,2,47,21,69,14,48,56,49,40,35,32,28,24,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,0,0,0,0,0,0,0,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,0,0,0,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,31,31,31,31,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,80,30,31,32,33,34,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,31,32,33,34,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,32,33,34,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,33,34,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,80,0,160,0,200,0,240,0,144,1,244,1,88,2,0,0,50,0,50,0,100,0,150,0,150,0,250,0,44,1,94,1,50,0,100,0,150,0,200,0,200,0,44,1,94,1,144,1,100,0,150,0,200,0,250,0,250,0,94,1,144,1,194,1,150,0,200,0,250,0,44,1,44,1,144,1,194,1,244,1,4,4,4,4,4,3,3,3,2,2,2,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,115,112,95,118,49,48,49,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,97,150,235,8,1,0,16,1,115,112,95,118,49,48,49,46,117,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,30,140,53,10,1,0,16,1,115,112,95,118,49,48,49,46,117,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,224,112,101,118,1,0,16,1,115,112,95,118,49,48,49,46,117,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,18,46,102,88,1,0,16,1,115,112,95,118,49,48,49,46,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,30,79,47,43,1,0,16,1,116,48,53,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,108,114,129,216,2,0,32,0,116,48,53,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,100,104,16,210,2,0,32,0,97,48,53,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,151,145,165,128,3,0,32,0,97,48,53,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,177,49,201,152,3,0,32,0,97,48,53,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,29,223,252,195,3,0,32,0,97,48,53,48,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,236,255,109,6,3,0,32,0,97,48,53,48,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,131,117,51,69,3,0,32,0,97,48,53,48,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,165,243,140,91,3,0,32,0,97,48,53,48,54,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,12,198,122,8,3,0,32,0,98,48,53,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,116,127,224,205,4,0,32,0,98,48,53,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,233,194,70,21,4,0,32,0,98,48,53,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,195,49,123,233,4,0,32,0,98,48,53,48,51,46,117,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,228,152,29,228,4,0,32,0,109,48,53,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,221,140,146,55,5,0,64,0,115,112,95,118,49,48,49,46,117,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,188,70,112,9,0,0,16,1,46,0,0,0,255,255,4,0,0,0,0,0,0,0,0,0,254,0,6,0,144,165,4,0,46,0,0,0,1,15,1,0,80,65,1,0,46,0,0,0,1,15,2,0,232,41,1,0,46,0,0,0,1,15,3,0,176,20,3,0,46,0,0,0,1,15,4,0,56,50,1,0,46,0,0,0,1,15,5,0,192,20,3,0,46,0,0,0,1,15,6,0,224,32,1,0,254,148,110,78,200,51,167,45,242,163,249,225,169,108,2,149,0,0,0,0,0,0,0,0,110,111,115,45,112,101,45,117,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,73,1,8,75,1,0,16,1,110,111,115,45,112,111,45,117,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,217,214,60,158,1,0,16,1,110,111,115,45,112,115,46,117,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,233,81,37,131,3,0,16,1,110,111,115,45,115,101,45,48,46,117,56,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,141,16,153,157,3,0,32,0,110,111,115,45,115,111,45,48,46,117,56,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,126,252,240,125,3,0,32,0,110,111,115,45,115,101,45,49,46,117,56,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,7,118,208,170,3,0,32,0,110,111,115,45,115,111,45,49,46,117,56,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,44,1,208,131,3,0,32,0,110,111,115,45,115,101,45,50,46,117,56,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,5,96,158,217,3,0,32,0,110,111,115,45,115,111,45,50,46,117,56,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,243,142,14,246,3,0,32,0,110,111,115,45,98,48,45,48,46,117,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,242,176,20,2,4,0,32,0,110,111,115,45,98,48,45,49,46,117,53,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,52,107,139,63,4,0,32,0,110,111,115,45,98,49,45,48,46,117,54,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,199,208,111,186,5,0,32,0,110,111,115,45,98,49,45,49,46,117,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,9,128,189,218,5,0,32,0,110,111,115,115,110,45,48,48,46,117,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,188,188,209,59,6,0,64,0,117,98,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,47,62,175,54,1,0,16,1,117,98,49,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,212,35,153,45,1,0,16,1,120,104,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,196,71,208,18,2,0,16,1,115,114,111,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,148,182,113,103,3,0,32,0,115,114,111,109,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,175,51,45,54,3,0,32,0,115,114,111,109,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,209,105,173,139,3,0,32,0,115,114,111,109,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,203,127,58,231,3,0,32,0,115,114,111,109,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,78,73,0,115,3,0,32,0,115,114,111,109,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,249,253,181,116,3,0,32,0,115,114,111,109,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,54,144,43,189,3,0,32,0,115,114,111,109,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,14,54,56,221,3,0,32,0,117,102,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,244,182,159,154,4,0,32,0,117,102,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,99,77,149,102,4,0,32,0,117,102,97,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,45,237,115,186,4,0,32,0,117,104,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,142,110,114,247,4,0,32,0,117,106,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,110,72,247,84,4,0,32,0,120,114,97,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,62,79,74,199,5,0,64,0,50,54,48,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,130,16,54,97,1,0,16,1,50,54,48,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,127,12,123,20,3,0,32,0,50,54,48,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,13,75,176,210,3,0,32,0,50,54,48,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,229,197,7,100,4,0,16,1,50,54,48,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,12,72,176,36,5,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,0,0,0,0,109,114,108,111,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,125,94,69,111,1,0,16,1,100,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,216,88,0,113,1,0,16,1,100,111,102,105,120,46,100,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,155,3,125,58,1,0,16,1,109,114,108,111,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,116,2,193,73,1,0,16,1,109,114,108,111,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,13,13,182,253,2,0,32,0,109,114,108,111,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,14,193,146,4,2,0,32,0,114,56,45,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,250,159,220,219,3,0,32,0,110,56,45,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,219,115,153,75,3,0,32,0,104,53,45,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,197,140,33,225,4,0,32,0,107,53,45,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,4,139,246,177,4,0,32,0,117,48,50,45,45,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,215,101,138,35,5,0,32,0,116,48,50,45,45,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,192,61,38,174,5,0,32,0,102,49,48,45,45,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,162,76,238,22,5,0,32,0,106,49,48,45,45,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,132,226,127,255,5,0,32,0,100,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,89,147,205,61,1,0,16,1,100,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,216,88,0,113,1,0,16,1,100,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,216,18,125,70,1,0,16,1,100,117,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,24,194,59,137,1,0,16,1,100,117,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,220,220,144,64,2,0,32,0,100,117,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,105,171,99,30,2,0,32,0,114,56,45,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,250,159,220,219,3,0,32,0,110,56,45,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,219,115,153,75,3,0,32,0,104,53,45,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,197,140,33,225,4,0,32,0,107,53,45,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,4,139,246,177,4,0,32,0,117,48,50,45,45,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,215,101,138,35,5,0,32,0,116,48,50,45,45,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,192,61,38,174,5,0,32,0,102,49,48,45,45,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,162,76,238,22,5,0,32,0,106,49,48,45,45,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,132,226,127,255,5,0,32,0,97,52,45,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,162,251,220,3,1,0,16,1,99,52,45,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,156,211,205,14,1,0,16,1,101,52,45,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,194,93,143,53,1,0,16,1,102,52,45,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,252,12,25,244,1,0,16,1,115,56,45,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,182,197,128,170,2,0,32,0,117,56,45,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,91,200,14,210,2,0,32,0,114,56,45,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,250,159,220,219,3,0,32,0,110,56,45,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,219,115,153,75,3,0,32,0,104,53,45,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,197,140,33,225,4,0,32,0,107,53,45,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,4,139,246,177,4,0,32,0,117,48,50,45,45,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,215,101,138,35,5,0,32,0,116,48,50,45,45,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,192,61,38,174,5,0,32,0,102,49,48,45,45,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,162,76,238,22,5,0,32,0,106,49,48,45,45,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,132,226,127,255,5,0,32,0,109,51,97,46,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,239,223,187,95,1,0,16,1,109,50,97,46,55,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,66,6,169,242,1,0,16,1,109,49,97,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,154,17,240,207,1,0,16,1,109,101,97,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,22,145,216,73,2,0,32,0,109,99,97,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,3,233,4,2,0,32,0,109,97,97,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,43,68,233,108,2,0,32,0,109,102,97,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,19,125,12,13,2,0,32,0,109,100,97,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,66,24,174,65,2,0,32,0,109,98,97,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,201,63,196,80,2,0,32,0,56,48,56,95,114,48,53,46,54,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,244,131,253,145,1,0,16,1,56,48,56,95,114,48,52,46,52,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,151,197,200,241,1,0,16,1,56,48,56,95,114,48,57,46,54,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,103,68,77,247,1,0,16,1,56,48,56,95,114,48,56,46,52,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,4,23,242,38,1,0,16,1,56,48,56,95,101,48,55,46,49,48,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,234,220,123,41,2,0,16,1,56,48,56,95,101,48,54,46,56,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,51,107,87,143,2,0,16,1,56,48,56,95,101,49,51,46,49,48,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,244,8,167,31,2,0,16,1,56,48,56,95,101,49,50,46,56,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,222,31,47,214,2,0,16,1,56,48,56,95,101,48,51,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,205,167,147,61,3,0,16,1,56,48,56,95,101,49,52,46,100,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,37,101,211,185,4,0,32,0,56,48,56,100,49,55,46,112,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,130,144,41,209,5,0,32,0,56,48,56,100,49,53,46,112,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,182,166,34,43,5,0,32,0,56,48,56,95,100,48,49,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,192,55,77,253,7,0,32,0,116,111,109,95,99,45,104,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,182,4,50,166,1,0,16,1,116,111,109,95,99,45,108,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,47,0,136,231,1,0,16,1,116,111,109,95,99,45,104,51,45,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,181,120,71,113,1,0,16,1,116,111,109,95,99,45,108,51,45,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,3,155,4,47,1,0,16,1,116,111,109,95,109,53,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,95,38,131,11,2,0,32,0,116,111,109,95,109,53,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,243,246,197,142,2,0,32,0,116,111,109,95,109,52,57,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,253,59,29,164,2,0,32,0,116,111,109,95,109,52,55,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,91,162,129,157,2,0,32,0,116,111,109,95,109,50,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,113,231,163,60,3,0,32,0,116,111,109,95,109,50,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,47,238,5,122,3,0,32,0,116,111,109,95,109,50,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,53,35,170,121,3,0,32,0,116,111,109,95,109,50,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,36,139,158,120,3,0,32,0,116,111,109,95,109,50,54,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,246,107,98,68,4,0,32,0,116,111,109,95,109,50,55,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,207,82,73,70,4,0,32,0,116,111,109,95,109,50,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,199,178,185,61,4,0,32,0,116,111,109,95,109,50,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,153,232,31,240,4,0,32,0,116,111,109,95,109,52,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,31,29,213,62,5,0,64,0,108,111,104,116,95,105,56,55,53,49,46,109,99,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,24,117,49,56,46,49,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,44,91,26,102,1,0,16,1,116,49,50,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,9,102,226,215,2,0,32,0,97,49,50,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,216,129,235,206,3,0,32,0,97,49,50,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,167,60,6,33,3,0,32,0,97,49,50,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,174,47,185,75,3,0,32,0,97,49,50,48,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,39,182,60,231,3,0,32,0,97,49,50,48,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,187,181,180,20,3,0,32,0,98,49,50,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,148,217,215,190,4,0,32,0,98,49,50,48,49,46,114,111])
.concat([109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,87,235,81,242,4,0,32,0,109,49,50,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,32,135,216,176,5,0,64,0,107,111,118,50,95,118,49,48,48,95,104,111,110,103,107,111,110,103,46,97,115,105,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,159,103,215,224,7,0,16,1,117,49,57,46,49,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,128,41,46,70,8,0,16,1,48,49,54,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,49,135,129,27,1,0,16,1,48,49,54,45,112,50,46,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,43,220,175,18,1,0,16,1,48,49,54,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,179,238,46,26,2,0,32,0,48,49,54,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,37,28,71,113,3,0,32,0,48,49,54,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,72,176,13,50,3,0,32,0,48,49,54,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,149,121,222,152,3,0,32,0,48,49,54,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,226,6,5,7,3,0,32,0,48,49,54,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,16,202,169,157,4,0,16,1,48,49,54,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,2,165,192,134,5,0,64,0,48,49,54,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,197,62,194,91,5,0,64,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,118,37,0,0,118,37,0,0,118,37,0,0,118,37,0,0,194,30,0,0,196,19,0,0,182,22,0,0,126,35,0,0,170,6,0,0,50,29,0,0,118,37,0,0,118,37,0,0,106,49,0,0,238,28,0,0,118,37,0,0,118,37,0,0,130,35,0,0,136,20,0,0,118,37,0,0,118,37,0,0,128,12,0,0,24,8,0,0,118,37,0,0,118,37,0,0,160,30,0,0,72,47,0,0,118,37,0,0,118,37,0,0,36,41,0,0,70,37,0,0,118,37,0,0,118,37,0,0,172,25,0,0,126,4,0,0,118,37,0,0,118,37,0,0,222,21,0,0,68,50,0,0,118,37,0,0,118,37,0,0,10,27,0,0,66,23,0,0,118,37,0,0,118,37,0,0,78,39,0,0,82,35,0,0,118,37,0,0,118,37,0,0,70,11,0,0,118,37,0,0,118,37,0,0,118,37,0,0,30,28,0,0,86,36,0,0,72,41,0,0,68,45,0,0,124,16,0,0,118,37,0,0,246,46,0,0,118,37,0,0,176,31,0,0,118,37,0,0,212,42,0,0,118,37,0,0,204,38,0,0,118,37,0,0,230,33,0,0,118,37,0,0,98,22,0,0,118,37,0,0,0,31,0,0,118,37,0,0,166,0,0,0,118,37,0,0,200,11,0,0,118,37,0,0,242,45,0,0,118,37,0,0,70,47,0,0,118,37,0,0,118,37,0,0,118,37,0,0,118,37,0,0,118,37,0,0,118,37,0,0,98,0,0,0,98,0,0,0,98,0,0,0,126,2,0,0,28,15,0,0,116,41,0,0,64,8,0,0,116,18,0,0,46,36,0,0,246,16,0,0,14,39,0,0,242,28,0,0,32,5,0,0,208,28,0,0,44,12,0,0,0,3,0,0,204,3,0,0,112,27,0,0,236,4,0,0,72,23,0,0,38,49,0,0,186,37,0,0,172,15,0,0,252,14,0,0,30,33,0,0,186,19,0,0,206,41,0,0,6,38,0,0,182,1,0,0,84,25,0,0,130,23,0,0,222,6,0,0,66,41,0,0,162,9,0,0,130,44,0,0,198,45,0,0,144,14,0,0,118,37,0,0,84,28,0,0,214,22,0,0,118,37,0,0,244,40,0,0,90,46,0,0,118,37,0,0,34,48,0,0,32,24,0,0,118,37,0,0,202,10,0,0,66,42,0,0,118,37,0,0,4,8,0,0,248,9,0,0,140,28,0,0,118,37,0,0,188,28,0,0,46,23,0,0,118,37,0,0,186,45,0,0,132,14,0,0,118,37,0,0,110,19,0,0,30,25,0,0,118,37,0,0,40,41,0,0,158,22,0,0,118,37,0,0,42,19,0,0,2,47,0,0,186,41,0,0,118,37,0,0,118,37,0,0,118,37,0,0,118,37,0,0,118,37,0,0,118,37,0,0,118,37,0,0,118,37,0,0,180,37,0,0,160,31,0,0,138,19,0,0,94,25,0,0,46,37,0,0,98,0,0,0,2,46,0,0,134,49,0,0,178,30,0,0,174,42,0,0,2,48,0,0,230,3,0,0,202,0,0,0,204,44,0,0,52,34,0,0,118,37,0,0,198,2,0,0,118,37,0,0,28,12,0,0,118,37,0,0,106,48,0,0,118,37,0,0,76,2,0,0,118,37,0,0,206,0,0,0,118,37,0,0,130,33,0,0,118,37,0,0,222,40,0,0,118,37,0,0,206,4,0,0,118,37,0,0,106,17,0,0,118,37,0,0,162,40,0,0,40,28,0,0,216,34,0,0,238,46,0,0,52,45,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,107,101,116,115,117,105,95,112,114,103,95,111,114,105,103,105,110,97,108,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,83,225,165,204,1,0,16,1,116,48,52,55,48,49,119,48,54,52,46,117,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,65,176,101,38,2,0,32,0,97,48,52,55,48,49,119,48,54,52,46,117,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,75,185,241,94,3,0,32,0,97,48,52,55,48,50,119,48,54,52,46,117,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,127,218,214,38,3,0,32,0,98,48,52,55,48,49,119,48,54,52,46,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,141,0,236,27,4,0,32,0,109,48,52,55,48,49,98,48,51,50,46,117,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,209,34,110,180,5,0,64,0,107,101,116,95,105,103,115,48,50,55,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,7,0,16,17,107,101,116,95,100,101,102,97,117,108,116,115,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,216,146,168,60,0,0,0,8,107,101,116,115,117,105,95,112,114,103,95,114,101,118,105,115,101,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,235,245,252,105,1,0,16,1,116,48,52,55,48,49,119,48,54,52,46,117,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,65,176,101,38,2,0,32,0,97,48,52,55,48,49,119,48,54,52,46,117,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,75,185,241,94,3,0,32,0,97,48,52,55,48,50,119,48,54,52,46,117,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,127,218,214,38,3,0,32,0,98,48,52,55,48,49,119,48,54,52,46,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,141,0,236,27,4,0,32,0,109,48,52,55,48,49,98,48,51,50,46,117,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,209,34,110,180,5,0,64,0,107,101,116,95,105,103,115,48,50,55,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,7,0,16,17,107,101,116,95,100,101,102,97,117,108,116,115,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,216,146,168,60,0,0,0,8,116,111,107,105,106,112,46,48,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,177,38,215,3,1,0,0,0,116,111,107,105,106,112,46,48,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,18,94,164,84,1,0,0,0,116,111,107,105,106,112,46,48,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,8,40,168,214,1,0,0,0,116,111,107,105,106,112,46,48,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,16,91,26,160,1,0,0,0,116,111,107,105,106,112,46,48,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,197,196,135,108,2,0,0,0,116,111,107,105,106,112,46,48,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,196,105,121,166,2,0,0,0,116,111,107,105,106,112,46,48,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,162,100,169,138,3,0,0,0,116,111,107,105,106,112,46,48,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,72,126,232,134,3,0,0,0,116,111,107,105,46,111,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,186,128,122,162,4,0,0,0,116,111,107,105,46,111,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,24,119,104,250,4,0,0,0,116,111,107,105,46,98,107,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,75,95,170,253,5,0,0,0,116,111,107,105,46,98,107,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,100,198,106,216,6,0,0,0,116,111,107,105,106,112,46,48,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,139,107,122,174,7,0,0,0,106,111,106,111,95,117,115,97,46,50,57,102,52,48,48,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,190,247,64,141,0,0,0,3,106,111,106,111,40,95,95,57,57,48,49,50,56,41,45,115,105,109,109,49,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,139,148,22,149,0,0,16,1,106,111,106,111,40,95,95,57,57,48,49,50,56,41,45,115,105,109,109,49,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,141,132,71,168,0,0,16,1,106,111,106,111,40,95,95,57,57,48,49,50,56,41,45,115,105,109,109,49,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,70,136,62,133,0,0,16,1,106,111,106,111,40,95,95,57,57,48,49,50,56,41,45,115,105,109,109,49,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,14,224,79,192,0,0,16,1,106,111,106,111,40,95,95,57,57,48,49,50,56,41,45,115,105,109,109,50,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,200,179,164,225,0,0,16,1,106,111,106,111,40,95,95,57,57,48,49,50,56,41,45,115,105,109,109,50,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,149,239,156,24,0,0,16,1,106,111,106,111,40,95,95,57,57,48,49,50,56,41,45,115,105,109,109,50,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,198,94,219,71,0,0,16,1,106,111,106,111,40,95,95,57,57,48,49,50,56,41,45,115,105,109,109,50,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,85,161,211,227,0,0,16,1,106,111,106,111,45,115,105,109,109,51,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,193,201,127,222,0,0,32,0,106,111,106,111,45,115,105,109,109,51,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,211,83,208,67,0,0,32,0,106,111,106,111,45,115,105,109,109,51,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,165,127,253,47,0,0,32,0,106,111,106,111,45,115,105,109,109,51,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,91,152,164,77,0,0,32,0,106,111,106,111,45,115,105,109,109,51,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,114,141,233,253,0,0,32,0,106,111,106,111,45,115,105,109,109,51,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,102,162,178,237,0,0,32,0,106,111,106,111,45,115,105,109,109,51,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,25,243,124,190,0,0,32,0,106,111,106,111,45,115,105,109,109,51,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,159,26,254,86,0,0,32,0,106,111,106,111,45,115,105,109,109,52,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,104,191,231,196,0,0,32,0,106,111,106,111,45,115,105,109,109,52,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,25,39,43,182,0,0,32,0,106,111,106,111,45,115,105,109,109,52,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,9,88,209,24,0,0,32,0,106,111,106,111,45,115,105,109,109,52,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,121,173,240,154,0,0,32,0,106,111,106,111,45,115,105,109,109,52,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,240,193,36,65,0,0,32,0,106,111,106,111,45,115,105,109,109,52,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,209,31,0,94,0,0,32,0,106,111,106,111,45,115,105,109,109,52,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,59,162,255,154,0,0,32,0,106,111,106,111,45,115,105,109,109,52,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,42,87,17,37,0,0,32,0,106,111,106,111,45,115,105,109,109,53,46,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,252,21,118,121,0,0,32,0,106,111,106,111,45,115,105,109,109,53,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,98,209,79,115,0,0,32,0,106,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,152,57,231,200,1,0,16,1,106,103,107,46,106,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,14,129,215,54,1,0,16,1,106,103,107,46,106,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,238,243,95,177,1,0,16,1,106,103,107,46,106,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,66,210,99,74,1,0,16,1,106,103,107,46,106,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,168,20,85,96,1,0,16,1,106,103,107,46,106,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,183,137,228,188,1,0,16,1,106,103,107,46,106,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,85,189,33,219,1,0,16,1,106,103,107,46,106,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,49,254,255,73,1,0,16,1,106,103,107,46,106,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,30,220,194,2,0,16,1,106,103,107,46,106,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,240,109,114,206,3,0,32,0,106,103,107,46,106,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,141,44,236,106,3,0,32,0,106,103,107,46,106,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,37,197,20,253,3,0,32,0,106,103,107,46,106,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,178,144,184,234,3,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,2,0,0,0,4,0,0,0,6,0,0,0,8,0,0,0,116,118,103,49,55,95,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,124,22,40,203,1,0,16,1,116,118,103,49,55,95,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,80,116,108,117,1,0,16,1,116,118,103,49,55,95,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,182,168,240,145,1,0,16,1,116,118,103,49,55,95,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,125,207,111,105,1,0,16,1,116,118,103,49,55,95,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,14,180,189,34,2,0,16,1,116,118,103,49,55,95,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,105,162,138,220,3,0,32,0,116,118,103,49,55,95,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,186,254,158,14,3,0,32,0,116,118,103,49,55,95,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,122,8,201,69,3,0,32,0,116,118,103,49,55,95,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,197,243,148,197,4,0,32,0,116,118,103,49,55,95,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,78,11,81,46,4,0,32,0,116,118,103,49,55,95,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,117,39,1,53,4,0,32,0,112,114,111,109,49,55,95,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,236,59,205,219,5,0,32,0,112,114,111,109,49,55,95,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,207,182,183,158,5,0,32,0,112,114,111,109,49,55,95,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,243,167,48,155,5,0,32,0,112,114,111,109,49,55,95,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,157,97,46,150,5,0,32,0,112,114,111,109,49,55,95,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,140,20,245,177,5,0,32,0,112,114,111,109,49,55,95,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,12,243,10,202,6,0,0,8,112,114,111,109,49,55,95,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,116,81,197,243,6,0,0,8,105,103,109,111,45,117,49,48,46,55,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,164,145,246,169,0,0,16,1,105,103,109,111,45,117,57,46,55,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,151,60,19,60,0,0,16,1,105,103,109,111,45,117,56,46,55,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,216,248,146,86,0,0,16,1,105,103,109,111,45,117,55,46,55,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,237,226,10,99,0,0,16,1,105,103,109,111,45,117,54,46,55,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,29,14,242,211,0,0,16,1,105,103,109,111,45,117,53,46,55,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,145,179,107,226,0,0,16,1,105,103,109,111,45,117,52,46,55,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,23,68,42,118,0,0,16,1,105,103,109,111,45,117,49,49,46,55,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,55,88,103,140,0,0,16,1,56,50,115,49,50,51,46,117,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,32,16,104,45,104,48,45,100,46,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,246,159,24,64,1,0,16,1,104,45,108,48,45,100,46,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,144,118,86,20,1,0,16,1,104,45,104,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,240,161,75,38,1,0,16,1,104,45,108,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,49,55,145,249,1,0,16,1,104,45,115,104,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,110,229,164,134,2,0,16,1,104,45,115,108,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,118,150,253,16,2,0,16,1,104,111,111,107,45,99,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,207,61,198,222,3,0,32,0,104,111,111,107,45,99,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,146,11,235,228,3,0,32,0,104,111,111,107,45,99,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,11,50,43,165,3,0,32,0,104,111,111,107,45,99,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,49,119,246,126,3,0,32,0,104,111,111,107,45,48,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,48,172,206,204,4,0,32,0,104,111,111,107,45,48,49,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,103,218,200,138,4,0,32,0,104,111,111,107,45,48,50,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,154,175,71,136,4,0,32,0,104,111,111,107,45,48,51,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,126,135,158,35,4,0,32,0,104,111,111,107,45,100,97,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,18,2,205,136,5,0,64,0,104,101,120,97,46,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,134,5,176,152,1,0,16,1,104,101,120,97,46,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,108,0,93,61,1,0,16,1,104,101,120,97,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,214,29,145,246,3,0,32,0,104,101,120,97,46,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,210,149,61,110,3,0,32,0,104,101,120,97,46,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,49,122,233,255,3,0,32,0,104,101,120,97,46,48,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,180,85,160,136,4,0,32,0,104,101,120,97,46,48,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,50,73,157,62,4,0,32,0,104,101,120,97,46,48,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,108,54,21,255,4,0,32,0,100,44,0,0,110,36,0,0,204,13,0,0,4,1,0,0,90,35,0,0,112,4,0,0,60,11,0,0,174,11,0,0,6,29,0,0,76,31,0,0,234,16,0,0,204,17,0,0,172,24,0,0,180,47,0,0,90,20,0,0,54,43,0,0,120,21,0,0,78,2,0,0,4,4,0,0,118,17,0,0,236,32,0,0,78,46,0,0,66,13,0,0,42,16,0,0,78,46,0,0,124,38,0,0,120,25,0,0,78,46,0,0,180,28,0,0,190,16,0,0,98,37,0,0,162,27,0,0,146,43,0,0,100,41,0,0,104,13,0,0,118,6,0,0,158,32,0,0,130,50,0,0,204,21,0,0,48,0,0,0,50,22,0,0,40,6,0,0,44,4,0,0,152,48,0,0,152,14,0,0,72,25,0,0,52,23,0,0,8,47,0,0,178,20,0,0,112,1,0,0,76,37,0,0,100,26,0,0,124,3,0,0,224,22,0,0,242,40,0,0,244,33,0,0,78,46,0,0,180,6,0,0,252,47,0,0,246,33,0,0,240,39,0,0,48,13,0,0,78,46,0,0,240,42,0,0,206,1,0,0,78,46,0,0,78,46,0,0,46,11,0,0,20,13,0,0,78,46,0,0,224,36,0,0,106,18,0,0,28,33,0,0,32,17,0,0,206,48,0,0,78,46,0,0,210,28,0,0,18,25,0,0,78,46,0,0,126,26,0,0,236,7,0,0,78,46,0,0,78,46,0,0,82,5,0,0,112,7,0,0,78,46,0,0,246,27,0,0,4,24,0,0,192,12,0,0,230,47,0,0,100,30,0,0,78,46,0,0,48,3,0,0,168,6,0,0,78,46,0,0,190,44,0,0,20,33,0,0,42,12,0,0,234,26,0,0,86,24,0,0,172,14,0,0,108,34,0,0,2,5,0,0,40,39,0,0,254,12,0,0,34,29,0,0,82,3,0,0,16,38,0,0,244,42,0,0,86,30,0,0,4,28,0,0,84,44,0,0,198,28,0,0,244,34,0,0,244,15,0,0,112,3,0,0,0,44,0,0,158,29,0,0,138,16,0,0,156,9,0,0,246,19,0,0,98,33,0,0,180,11,0,0,138,8,0,0,122,19,0,0,8,10,0,0,66,32,0,0,172,48,0,0,42,24,0,0,10,37,0,0,150,45,0,0,60,49,0,0,52,4,0,0,16,14,0,0,104,37,0,0,78,46,0,0,208,7,0,0,222,9,0,0,124,40,0,0,50,1,0,0,10,26,0,0,128,13,0,0,28,19,0,0,78,46,0,0,150,49,0,0,168,30,0,0,156,2,0,0,116,48,0,0,132,39,0,0,62,27,0,0,30,26,0,0,94,4,0,0,16,33,0,0,184,6,0,0,72,4,0,0,66,22,0,0,28,29,0,0,246,44,0,0,226,17,0,0,54,22,0,0,124,1,0,0,2,2,0,0,136,39,0,0,202,2,0,0,130,15,0,0,174,31,0,0,222,39,0,0,134,43,0,0,174,3,0,0,134,25,0,0,106,36,0,0,128,3,0,0,196,36,0,0,140,33,0,0,32,10,0,0,144,42,0,0,140,47,0,0,20,34,0,0,200,43,0,0,108,14,0,0,202,44,0,0,228,42,0,0,238,34,0,0,26,39,0,0,220,30,0,0,108,4,0,0,148,19,0,0,200,30,0,0,110,41,0,0,206,10,0,0,96,8,0,0,218,37,0,0,206,47,0,0,12,29,0,0,50,12,0,0,224,4,0,0,98,29,0,0,112,10,0,0,224,6,0,0,78,46,0,0,38,46,0,0,52,44,0,0,62,32,0,0,154,37,0,0,224,27,0,0,108,10,0,0,242,2,0,0,78,46,0,0,66,26,0,0,76,49,0,0,244,43,0,0,130,41,0,0,82,16,0,0,248,8,0,0,66,25,0,0,90,1,0,0,224,5,0,0,220,14,0,0,102,28,0,0,76,33,0,0,126,5,0,0,176,8,0,0,28,13,0,0,196,40,0,0,200,8,0,0,52,32,0,0,86,14,0,0,204,2,0,0,124,18,0,0,74,8,0,0,160,4,0,0,92,18,0,0,246,49,0,0,14,3,0,0,164,41,0,0,192,6,0,0,16,17,0,0,38,6,0,0,64,10,0,0,28,9,0,0,58,38,0,0,218,0,0,0,200,9,0,0,160,32,0,0,38,14,0,0,150,0,0,0,30,2,0,0,102,41,0,0,80,4,0,0,6,24,0,0,98,30,0,0,194,34,0,0,220,49,0,0,216,10,0,0,150,18,0,0,132,38,0,0,116,112,48,50,49,45,48,49,46,117,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,103,172,86,158,0,0,16,1,116,112,48,50,49,45,48,50,46,117,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,15,198,202,21,0,0,16,1,116,112,48,50,49,45,48,51,46,117,51,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,157,142,93,161,0,0,32,0,116,112,48,50,49,45,48,52,46,117,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,154,28,237,38,0,0,32,0,104,100,54,52,55,49,56,48,46,48,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,16,112,114,103,49,46,49,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,178,4,185,71,0,0,16,1,112,114,103,50,46,49,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,148,119,155,70,0,0,16,1,111,98,106,49,46,55,51,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,93,78,248,244,0,0,32,0,111,98,106,50,46,55,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,206,169,194,21,0,0,32,0,98,103,49,46,57,56,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,61,105,58,1,0,0,32,0,98,103,50,46,57,57,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,47,198,60,120,0,0,32,0,98,103,51,46,57,57,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,28,29,214,188,0,0,32,0,115,110,100,49,46,52,52,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,82,10,119,146,0,0,64,0,115,110,100,50,46,52,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,207,225,154,50,0,0,64,0,115,110,100,51,46,52,53,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,78,214,72,64,0,0,64,0,23,0,0,0,255,255,4,0,0,0,0,0,24,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,80,157,8,0,23,0,0,0,1,1,0,0,96,135,7,0,23,0,0,0,1,1,1,0,152,182,7,0,0,0,0,0,254,0,2,0,200,135,2,0,23,0,0,0,1,2,2,0,96,135,7,0,23,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,128,112,3,0,23,0,0,0,1,4,0,0,224,247,3,0,23,0,0,0,1,4,4,0,168,22,4,0,0,0,0,0,254,0,9,0,72,23,4,0,23,0,0,0,1,120,0,0,200,201,5,0,23,0,0,0,1,120,8,0,152,160,5,0,23,0,0,0,1,120,16,0,144,127,5,0,23,0,0,0,1,120,24,0,224,67,5,0,23,0,0,0,1,120,32,0,88,198,1,0,23,0,0,0,1,120,40,0,216,36,5,0,23,0,0,0,1,120,48,0,8,7,5,0,23,0,0,0,1,120,56,0,136,207,5,0,23,0,0,0,1,120,64,0,40,182,1,0,23,0,0,0,1,120,72,0,40,182,1,0,23,0,0,0,1,120,80,0,40,182,1,0,23,0,0,0,1,120,88,0,40,182,1,0,23,0,0,0,1,120,96,0,40,182,1,0,23,0,0,0,1,120,104,0,40,182,1,0,23,0,0,0,1,120,112,0,40,182,1,0,23,0,0,0,1,120,120,0,40,182,1,0,0,0,0,0,254,0,2,0,80,111,3,0,23,0,0,0,1,128,128,0,96,135,7,0,23,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,8,0,16,57,4,0,24,0,0,0,1,224,32,0,248,73,5,0,24,0,0,0,1,224,64,0,80,246,3,0,24,0,0,0,1,224,0,0,80,124,6,0,24,0,0,0,1,224,128,0,0,12,5,0,24,0,0,0,1,224,96,0,168,237,4,0,24,0,0,0,1,224,192,0,80,233,4,0,24,0,0,0,1,224,160,0,72,185,3,0,24,0,0,0,1,224,224,0,248,160,5,0,0,0,0,0,254,0,2,0,56,191,4,0,24,0,0,0,2,4,4,0,208,164,4,0,24,0,0,0,0,224,0,0,0,0,0,0,24,0,0,0,2,4,0,0,40,134,4,0,24,0,0,0,0,224,0,0,0,0,0,0,0,0,0,0,254,0,2,0,56,191,4,0,24,0,0,0,2,4,4,0,208,164,4,0,24,0,0,0,0,224,32,0,0,0,0,0,24,0,0,0,2,4,0,0,112,107,4,0,24,0,0,0,0,224,32,0,0,0,0,0,0,0,0,0,254,0,2,0,56,191,4,0,24,0,0,0,2,4,4,0,208,164,4,0,24,0,0,0,0,224,64,0,0,0,0,0,24,0,0,0,2,4,0,0,40,134,4,0,24,0,0,0,0,224,64,0,0,0,0,0,0,0,0,0,254,0,2,0,56,191,4,0,24,0,0,0,2,4,4,0,208,164,4,0,24,0,0,0,0,224,96,0,0,0,0,0,24,0,0,0,2,4,0,0,160,80,4,0,24,0,0,0,0,224,96,0,0,0,0,0,0,0,0,0,254,0,2,0,56,191,4,0,24,0,0,0,2,4,4,0,208,164,4,0,24,0,0,0,0,224,128,0,0,0,0,0,24,0,0,0,2,4,0,0,160,80,4,0,24,0,0,0,0,224,128,0,0,0,0,0,0,0,0,0,254,0,2,0,56,191,4,0,24,0,0,0,2,4,4,0,208,164,4,0,24,0,0,0,0,224,160,0,0,0,0,0,24,0,0,0,2,4,0,0,176,54,4,0,24,0,0,0,0,224,160,0,0,0,0,0,0,0,0,0,254,0,2,0,56,191,4,0,24,0,0,0,2,4,4,0,208,164,4,0,24,0,0,0,0,224,192,0,0,0,0,0,24,0,0,0,2,4,0,0,160,80,4,0,24,0,0,0,0,224,192,0,0,0,0,0,0,0,0,0,254,0,2,0,56,191,4,0,24,0,0,0,2,4,4,0,208,164,4,0,24,0,0,0,0,224,224,0,0,0,0,0,24,0,0,0,2,4,0,0,176,54,4,0,24,0,0,0,0,224,224,0,0,0,0,0,0,0,0,0,254,0,4,0,200,26,4,0,24,0,0,0,1,3,2,0,112,252,3,0,24,0,0,0,1,3,3,0,40,219,3,0,24,0,0,0,1,3,0,0,192,189,3,0,24,0,0,0,1,3,1,0,112,164,3,0,0,0,0,0,254,0,4,0,120,95,4,0,24,0,0,0,1,24,0,0,200,114,3,0,24,0,0,0,1,24,8,0,176,92,3,0,24,0,0,0,1,24,16,0,40,78,3,0,24,0,0,0,1,24,24,0,160,64,3,0,0,0,0,0,0,0,0,0,114,111,109,49,45,97,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,91,120,143,45,1,0,16,1,114,111,109,49,49,45,97,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,161,142,223,83,1,0,16,1,114,111,109,49,48,45,97,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,251,137,162,70,1,0,16,1,114,111,109,49,51,45,97,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,250,225,146,125,1,0,16,1,114,111,109,49,50,45,97,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,244,188,193,216,1,0,16,1,114,111,109,54,45,97,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,63,122,148,109,1,0,16,1,114,111,109,55,45,97,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,166,75,1,122,1,0,16,1,114,111,109,57,45,97,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,114,101,40,73,1,0,16,1,114,111,109,56,45,97,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,199,131,215,14,1,0,16,1,114,111,109,50,45,97,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,18,209,125,116,1,0,16,1,114,111,109,51,45,97,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,19,237,74,38,1,0,16,1,114,111,109,52,45,97,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,54,29,129,142,2,0,16,1,114,111,109,53,45,97,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,53,110,163,158,3,0,16,1,114,111,109,51,45,98,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,137,212,177,255,4,0,32,0,114,111,109,50,45,98,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,31,71,179,209,4,0,32,0,114,111,109,53,45,98,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,54,43,87,23,5,0,32,0,114,111,109,52,45,98,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,41,33,209,114,5,0,32,0,114,111,109,55,45,98,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,3,144,237,42,6,0,32,0,114,111,109,54,45,98,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,18,239,137,103,6,0,32,0,114,111,109,49,52,45,97,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,49,172,193,180,7,0,64,0,114,111,109,49,55,45,97,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,61,48,112,234,7,0,64,0,100,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,137,172,9,59,1,0,16,1,101,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,85,104,9,151,1,0,16,1,102,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,78,41,30,115,1,0,16,1,104,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,25,167,247,34,1,0,16,1,100,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,48,0,175,214,2,0,32,0,101,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,1,82,43,164,2,0,32,0,56,50,115,49,50,51,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,189,80,198,47,3,0,32,0,56,50,115,49,50,57,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,41,136,215,216,3,0,32,0,56,50,115,49,50,54,46,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,191,134,204,169,4,0,64,0,56,50,115,49,50,54,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,64,8,16,0,0,0,255,255,251,0,0,0,0,0,17,0,0,0,255,255,255,0,0,0,0,0,18,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,32,4,2,0,16,0,0,0,1,3,1,0,160,36,8,0,16,0,0,0,1,3,3,0,208,239,7,0,16,0,0,0,1,3,2,0,120,187,7,0,16,0,0,0,1,3,0,0,16,227,4,0,0,0,0,0,254,0,4,0,128,129,4,0,16,0,0,0,1,12,12,0,208,75,4,0,16,0,0,0,1,12,8,0,8,49,4,0,16,0,0,0,1,12,4,0,152,21,4,0,16,0,0,0,1,12,0,0,72,246,3,0,0,0,0,0,254,0,4,0,64,37,5,0,16,0,0,0,1,48,48,0,8,49,6,0,16,0,0,0,1,48,32,0,200,205,3,0,16,0,0,0,1,48,16,0,160,191,4,0,16,0,0,0,1,48,0,0,32,202,3,0,0,0,0,0,254,0,2,0,200,30,2,0,16,0,0,0,1,64,64,0,120,97,1,0,16,0,0,0,1,64,0,0,96,19,1,0,0,0,0,0,101,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,157,111,33,78,1,0,16,1,100,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,127,38,219,78,1,0,16,1,99,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,140,196,165,21,1,0,16,1,98,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,14,192,17,92,1,0,16,1,97,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,7,175,63,149,1,0,16,1,106,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,70,46,74,206,2,0,32,0,106,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,252,175,188,161,2,0,32,0,104,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,109,131,98,149,2,0,32,0,104,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,142,58,251,60,2,0,32,0,103,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,247,138,159,103,2,0,32,0,103,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,181,211,88,91,2,0,32,0,101,103,103,115,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,129,140,64,232,3,0,32,0,100,98,49,46,98,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,75,130,196,124,0,0,0,8,100,119,112,99,95,118,49,48,49,106,112,46,117,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,192,39,48,185,1,0,16,1,100,119,112,99,95,118,49,48,48,106,112,46,117,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,135,167,165,58,2,0,32,0,100,119,112,99,95,118,49,48,48,106,112,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,99,87,17,231,3,0,32,0,100,119,112,99,95,118,49,48,48,106,112,46,117,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,164,132,193,73,3,0,32,0,100,119,112,99,95,118,49,48,48,106,112,46,117,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,19,153,43,65,4,0,32,0,100,119,112,99,95,118,49,48,48,106,112,46,117,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,218,186,249,92,5,0,64,0,100,119,50,48,48,49,95,105,103,115,48,50,55,97,95,106,97,112,97,110,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,155,21,121,58,7,0,16,0,100,119,112,99,95,118,49,48,48,106,112,46,117,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,38,33,17,13,8,0,16,1,100,119,105,45,112,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,168,46,63,142,1,0,16,1,100,119,105,45,115,49,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,94,178,184,99,2,0,32,0,100,119,105,45,99,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,148,218,139,43,3,0,32,0,100,119,105,45,99,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,222,228,69,83,3,0,32,0,100,119,105,45,99,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,20,95,24,198,3,0,32,0,100,119,105,45,99,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,1,151,229,201,3,0,32,0,100,119,105,45,99,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,144,28,221,66,3,0,32,0,100,119,105,45,99,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,81,214,166,159,3,0,32,0,100,119,105,45,99,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,134,104,250,92,3,0,32,0,100,119,105,45,99,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,113,120,195,89,3,0,32,0,100,119,105,45,109,49,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,150,223,248,185,4,0,16,1,100,119,105,45,118,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,9,0,228,76,187,19,5,0,64,0,5,0,0,0,192,77,90,0,184,77,90,0,166,41,75,63,255,255,0,0,0,0,0,0,100,100,112,51,95,118,49,48,49,46,117,51,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,30,92,91,25,1,0,16,1,116,48,52,52,48,49,119,48,54,52,46,117,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,156,241,149,58,2,0,32,0,97,48,52,52,48,49,119,48,54,52,46,117,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,148,151,34,237,3,0,32,0,97,48,52,52,48,50,119,48,54,52,46,117,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,176,103,33,117,3,0,32,0,98,48,52,52,48,49,119,48,54,52,46,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,102,240,191,140,4,0,32,0,109,48,52,52,48,49,98,48,51,50,46,117,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,118,189,13,90,5,0,64,0,100,100,112,51,95,105,103,115,48,50,55,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,7,0,16,17,100,100,112,51,95,100,101,102,97,117,108,116,115,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,192,150,30,87,0,0,0,8,118,49,48,50,46,117,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,64,160,158,90,1,0,16,1,100,100,112,50,95,105,103,115,48,50,55,97,95,119,111,114,108,100,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,11,226,84,54,7,0,16,1,116,49,51,48,48,46,117,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,203,240,72,231,2,0,32,0,97,49,51,48,48,46,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,5,164,135,252,3,0,32,0,97,49,51,48,49,46,117,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,218,32,133,12,3,0,32,0,98,49,51,48,48,46,117,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,4,102,100,239,4,0,32,0,109,49,51,48,48,46,117,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,93,1,212,130,5,0,64,0,118,49,48,48,46,117,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,41,221,195,6,8,0,16,1,46,0,0,0,255,255,5,0,0,0,0,0,0,0,0,0,112,48,45,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,21,236,103,167,1,0,16,1,112,48,45,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,145,160,239,167,1,0,16,1,112,49,45,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,125,239,193,62,1,0,16,1,112,49,45,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,32,227,141,75,1,0,16,1,102,109,115,110,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,170,15,69,80,2,0,16,1,102,105,120,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,31,6,48,171,3,0,32,0,102,105,120,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,21,33,88,160,3,0,32,0,98,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,131,50,196,234,4,0,32,0,98,103,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,224,161,8,20,5,0,32,0,98,103,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,182,78,134,1,6,0,32,0,111,98,106,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,219,55,175,195,7,0,32,0,111,98,106,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,186,83,31,190,7,0,32,0,111,98,106,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,28,181,224,36,7,0,32,0,111,98,106,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,45,240,116,82,7,0,32,0,112,99,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,133,59,19,210,8,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0])
.concat([1,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,99,2,99,99,3,3,2,2,3,3,2,2,2,2,2,2,2,2,99,99,99,99,2,2,99,2,99,2,99,99,99,99,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,4,4,3,3,3,3,5,5,3,10,4,10,9,12,2,99,99,2,2,99,2,2,2,2,2,99,2,2,99,2,2,99,99,2,2,99,2,2,2,2,2,99,2,2,99,2,6,99,99,6,6,99,6,6,6,6,6,99,6,6,3,6,6,99,99,6,6,99,6,6,6,6,6,99,6,6,3,6,2,2,2,4,2,2,2,99,2,2,2,2,4,6,3,99,3,3,3,5,3,3,3,3,3,3,3,3,5,5,4,4,4,4,4,6,4,4,4,4,4,4,4,4,6,6,5,5,4,4,4,6,4,4,4,4,4,4,4,4,6,6,5,5,2,2,2,4,2,2,2,99,2,2,2,2,3,99,3,99,3,3,3,5,3,3,3,3,3,3,3,3,4,4,4,4,4,4,4,6,4,4,4,4,4,4,4,4,5,5,5,5,4,4,4,6,4,4,4,4,4,4,4,4,5,5,5,5,99,2,99,99,99,99,2,2,4,4,2,2,2,2,2,2,2,2,99,99,99,99,2,2,99,2,99,2,99,99,99,99,4,99,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,99,5,99,10,99,99,9,12,2,99,99,2,2,99,2,2,2,2,2,99,2,2,99,2,2,99,99,2,2,99,2,2,2,2,2,99,2,2,99,2,7,99,99,7,7,99,7,7,7,7,7,99,7,7,4,7,6,99,99,6,6,99,6,6,6,6,6,99,6,6,3,6,2,2,2,99,2,2,2,99,2,2,2,2,3,8,3,99,3,3,3,99,3,3,3,4,3,3,3,3,4,99,4,5,5,5,5,99,5,5,5,6,5,5,5,5,6,8,6,7,4,4,4,99,4,4,4,5,4,4,4,4,5,9,5,6,2,2,2,99,2,2,2,99,2,2,2,2,99,99,3,99,3,3,3,99,3,3,3,4,3,3,3,3,99,99,4,5,5,5,5,99,5,5,5,6,5,5,5,5,99,99,6,7,4,4,4,99,4,4,4,5,4,4,4,4,99,99,5,6,99,110,100,45,112,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,29,164,249,45,1,0,16,1,99,110,100,45,115,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,94,178,184,99,2,0,32,0,99,110,100,45,99,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,252,50,189,85,3,0,32,0,99,110,100,45,99,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,51,55,180,187,3,0,32,0,99,110,100,45,99,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,24,3,94,113,3,0,32,0,99,110,100,45,99,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,126,60,111,1,3,0,32,0,99,110,100,45,99,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,140,203,198,40,3,0,32,0,99,110,100,45,99,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,63,80,137,156,3,0,32,0,99,110,100,45,99,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,7,212,77,7,3,0,32,0,99,110,100,45,99,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,181,125,219,93,3,0,32,0,99,110,100,45,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,89,10,18,174,4,0,16,1,99,110,100,45,118,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,9,0,55,85,212,145,5,0,64,0,99,110,98,101,45,112,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,134,65,206,126,1,0,16,1,99,110,98,101,45,115,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,143,105,164,64,2,0,32,0,99,110,98,101,45,99,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,111,234,79,15,3,0,32,0,99,110,98,101,45,99,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,111,195,95,61,3,0,32,0,99,110,98,101,45,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,156,28,130,165,4,0,16,1,99,110,98,101,45,118,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,100,23,25,112,5,0,64,0,99,97,116,116,45,117,51,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,30,30,146,140,1,0,16,1,99,97,116,116,45,117,50,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,109,175,37,231,1,0,16,1,117,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,113,81,160,253,2,0,16,1,109,99,97,45,117,56,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,70,215,1,95,3,0,32,0,109,99,97,45,117,56,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,166,229,27,78,3,0,32,0,117,56,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,36,214,63,132,3,0,32,0,117,56,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,40,182,231,94,3,0,32,0,109,99,97,45,117,56,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,218,241,123,1,3,0,32,0,109,99,97,45,117,56,55,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,185,201,157,188,3,0,32,0,117,53,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,58,52,201,115,4,0,32,0,109,99,97,45,117,54,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,20,38,148,200,5,0,32,0,109,99,97,45,117,54,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,201,102,175,81,5,0,32,0,109,99,97,45,117,49,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,176,241,115,178,5,0,32,0,117,53,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,36,166,242,153,6,0,64,0,112,101,101,108,49,56,99,118,56,46,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,85,1,0,0,0,0,0,0,7,0,0,24,103,97,108,49,54,118,56,97,46,117,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,0,0,0,7,0,0,24,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,112,13,14,5,1,0,16,1,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,174,24,129,102,1,0,16,1,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,207,214,94,255,1,0,16,1,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,169,69,174,195,1,0,16,1,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,169,159,249,222,1,0,16,1,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,237,23,231,221,1,0,16,1,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,216,2,202,173,1,0,16,1,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,140,135,59,188,1,0,16,1,105,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,96,36,116,199,2,0,16,1,106,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,205,108,22,114,2,0,16,1,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,14,145,100,128,3,0,32,0,109,46,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,2,20,123,33,3,0,32,0,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,160,226,215,199,3,0,32,0,108,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,131,26,66,171,3,0,32,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,57,54,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,13,66,219,158,1,0,16,1,48,57,54,45,112,50,46,115,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,2,38,90,77,1,0,16,1,48,57,54,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,68,211,127,204,2,0,32,0,48,57,54,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,137,141,123,241,3,0,32,0,48,57,54,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,8,197,64,56,3,0,32,0,48,57,54,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,30,238,249,85,3,0,32,0,48,57,54,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,71,126,91,88,3,0,32,0,48,57,54,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,60,117,90,199,3,0,32,0,48,57,54,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,122,47,157,154,3,0,32,0,48,57,54,45,99,55,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,178,138,189,81,3,0,32,0,48,57,54,45,99,56,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,156,249,52,154,3,0,32,0,48,57,54,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,89,182,7,203,4,0,16,1,48,57,54,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,116,32,195,226,5,0,64,0,48,57,54,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,231,238,144,162,5,0,64,0,48,57,54,45,118,51,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,234,18,157,25,5,0,64,0,48,53,54,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,33,208,177,163,1,0,16,1,48,53,54,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,142,99,2,139,2,0,32,0,48,53,54,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,210,203,185,23,3,0,32,0,48,53,54,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,103,107,215,95,3,0,32,0,48,53,54,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,104,135,200,210,3,0,32,0,48,53,54,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,131,184,57,219,3,0,32,0,48,53,54,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,55,65,7,195,3,0,32,0,48,53,54,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,211,104,222,49,3,0,32,0,48,53,54,45,99,55,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,87,223,54,63,3,0,32,0,48,53,54,45,99,56,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,168,215,70,229,3,0,32,0,48,53,54,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,82,157,126,242,4,0,16,1,48,53,54,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,224,253,40,70,5,0,64,0])
.concat([48,53,54,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,242,226,16,183,5,0,64,0,48,53,54,45,118,51,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,1,195,104,209,5,0,64,0,48,55,52,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,83,149,54,98,1,0,16,1,48,55,52,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,43,141,20,150,2,0,32,0,48,55,52,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,68,147,179,160,3,0,32,0,48,55,52,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,116,96,63,32,3,0,32,0,48,55,52,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,65,77,255,127,3,0,32,0,48,55,52,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,10,62,219,72,3,0,32,0,48,55,52,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,81,94,76,199,3,0,32,0,48,55,52,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,224,231,232,115,3,0,32,0,48,55,52,45,99,55,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,1,170,125,172,3,0,32,0,48,55,52,45,99,56,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,113,173,231,20,3,0,32,0,48,55,52,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,209,169,82,90,4,0,16,1,48,55,52,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,250,184,117,118,5,0,64,0,48,55,52,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,233,134,218,169,5,0,64,0,55,55,48,95,109,48,49,46,110,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,58,229,100,74,1,0,16,1,55,55,48,95,108,48,50,46,110,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,43,89,125,173,1,0,16,1,55,55,48,95,108,48,53,46,105,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,178,251,100,237,2,0,16,1,55,55,48,95,102,48,52,46,103,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,156,236,228,224,2,0,16,1,55,55,48,95,104,48,51,46,102,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,252,42,253,47,3,0,16,1,55,55,48,99,49,51,45,97,46,102,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,242,255,246,78,4,0,32,0,55,55,48,99,49,51,45,99,46,102,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,182,186,255,151,4,0,32,0,55,55,48,99,49,51,45,98,46,101,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,6,215,253,134,4,0,32,0,55,55,48,99,49,51,45,100,46,101,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,45,203,122,125,4,0,32,0,55,55,48,99,49,50,45,97,46,102,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,104,222,10,108,4,0,32,0,55,55,48,99,49,50,45,99,46,102,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,204,57,252,97,4,0,32,0,55,55,48,99,49,50,45,98,46,101,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,198,28,34,95,4,0,32,0,55,55,48,99,49,50,45,100,46,101,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,244,178,237,241,4,0,32,0,55,55,48,99,48,57,45,97,46,102,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,184,15,105,118,5,0,32,0,55,55,48,99,48,57,45,101,46,102,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,201,130,180,23,5,0,32,0,55,55,48,99,48,57,45,98,46,101,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,209,9,23,205,5,0,32,0,55,55,48,99,48,57,45,102,46,101,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,126,180,164,203,5,0,32,0,55,55,48,99,48,57,45,99,46,100,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,184,128,208,191,5,0,32,0,55,55,48,99,48,57,45,103,46,100,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,160,142,213,119,5,0,32,0,55,55,48,99,48,57,45,100,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,86,149,111,5,0,32,0,55,55,48,99,48,57,45,104,46,99,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,144,144,74,73,5,0,32,0,55,55,48,99,48,56,45,97,46,102,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,86,154,210,239,5,0,32,0,55,55,48,99,48,56,45,101,46,102,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,222,175,67,109,5,0,32,0,55,55,48,99,48,56,45,98,46,101,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,20,64,55,243,5,0,32,0,55,55,48,99,48,56,45,102,46,101,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,170,89,186,245,5,0,32,0,55,55,48,99,48,56,45,99,46,100,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,143,8,231,40,5,0,32,0,55,55,48,99,48,56,45,103,46,100,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,109,143,218,23,5,0,32,0,55,55,48,99,48,56,45,100,46,99,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,119,23,89,145,5,0,32,0,55,55,48,99,48,56,45,104,46,99,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,21,75,125,217,5,0,32,0,55,55,48,99,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,238,146,197,208,6,0,32,0,55,55,48,99,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,177,159,57,11,6,0,32,0,55,55,48,99,49,48,45,97,46,97,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,148,192,94,228,7,0,64,0,55,55,48,99,49,48,45,98,46,97,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,211,183,157,52,7,0,64,0,55,55,48,99,49,48,45,99,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,5,31,203,113,7,0,64,0,55,55,48,99,49,48,45,100,46,97,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,68,24,171,232,7,0,64,0,55,55,48,99,49,49,45,97,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,224,217,204,140,8,0,64,0,55,55,48,99,49,49,45,98,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,221,254,242,10,8,0,64,0,55,55,48,99,49,49,45,99,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,74,242,113,116,8,0,64,0,55,55,48,99,49,49,45,100,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,35,227,139,165,8,0,64,0,55,55,48,99,49,49,45,101,46,98,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,65,53,85,221,8,0,64,0,55,55,48,99,49,49,45,102,46,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,15,189,120,63,8,0,64,0,55,55,48,99,49,49,45,103,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,178,81,140,7,8,0,64,0,55,55,48,99,49,49,45,104,46,98,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,225,194,0,115,8,0,64,0,54,51,115,50,52,49,46,106,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,159,113,221,155,9,0,0,8,114,156,202,133,201,18,204,234,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,35,0,0,0,6,0,0,0,4,0,0,0,5,0,0,0,7,0,0,0,3,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,146,0,0,0,2,0,0,0,5,0,0,0,3,0,0,0,6,0,0,0,7,0,0,0,1,0,0,0,0,0,0,0,4,0,0,0,184,0,0,0,6,0,0,0,7,0,0,0,4,0,0,0,2,0,0,0,0,0,0,0,5,0,0,0,1,0,0,0,3,0,0,0,116,0,0,0,5,0,0,0,3,0,0,0,7,0,0,0,1,0,0,0,4,0,0,0,6,0,0,0,0,0,0,0,2,0,0,0,207,0,0,0,7,0,0,0,4,0,0,0,1,0,0,0,0,0,0,0,6,0,0,0,2,0,0,0,3,0,0,0,5,0,0,0,196,0,0,0,3,0,0,0,1,0,0,0,6,0,0,0,4,0,0,0,5,0,0,0,0,0,0,0,2,0,0,0,7,0,0,0,81,0,0,0,5,0,0,0,7,0,0,0,2,0,0,0,4,0,0,0,3,0,0,0,1,0,0,0,6,0,0,0,0,0,0,0,20,0,0,0,7,0,0,0,2,0,0,0,0,0,0,0,6,0,0,0,1,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,127,0,0,0,3,0,0,0,5,0,0,0,6,0,0,0,0,0,0,0,2,0,0,0,1,0,0,0,7,0,0,0,4,0,0,0,3,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,0,0,0,0,6,0,0,0,7,0,0,0,5,0,0,0,1,0,0,0,150,0,0,0,3,0,0,0,1,0,0,0,7,0,0,0,5,0,0,0,2,0,0,0,4,0,0,0,6,0,0,0,0,0,0,0,48,0,0,0,7,0,0,0,6,0,0,0,2,0,0,0,3,0,0,0,0,0,0,0,4,0,0,0,5,0,0,0,1,0,0,0,226,0,0,0,1,0,0,0,0,0,0,0,3,0,0,0,7,0,0,0,4,0,0,0,5,0,0,0,2,0,0,0,6,0,0,0,114,0,0,0,1,0,0,0,6,0,0,0,0,0,0,0,5,0,0,0,7,0,0,0,2,0,0,0,4,0,0,0,3,0,0,0,245,0,0,0,0,0,0,0,4,0,0,0,1,0,0,0,2,0,0,0,6,0,0,0,5,0,0,0,7,0,0,0,3,0,0,0,91,0,0,0,0,0,0,0,7,0,0,0,5,0,0,0,3,0,0,0,1,0,0,0,4,0,0,0,2,0,0,0,6,0,0,0,116,107,50,117,95,50,51,99,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,18,156,184,41,2,0,16,1,116,107,50,117,95,50,50,99,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,116,71,175,245,2,0,16,1,116,107,50,45,49,109,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,191,185,156,13,4,0,32,0,116,107,50,45,51,109,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,112,34,69,4,0,32,0,116,107,50,45,50,109,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,96,36,202,197,4,0,32,0,116,107,50,45,52,109,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,28,85,73,227,4,0,32,0,116,107,50,45,53,109,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,11,15,31,41,4,0,32,0,116,107,50,45,55,109,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,73,185,222,62,4,0,32,0,116,107,50,45,54,109,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,214,20,189,26,4,0,32,0,116,107,50,45,56,109,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,227,72,121,178,4,0,32,0,116,107,50,95,113,97,46,53,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,13,58,24,201,3,0,16,0,116,107,50,45,113,49,46,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,207,104,18,97,6,0,64,0,116,107,50,45,113,50,46,50,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,169,92,245,32,6,0,64,0,116,107,50,45,113,51,46,51,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,111,207,191,6,0,64,0,116,107,50,45,113,52,46,52,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,136,46,100,54,6,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,154,135,134,67,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,116,107,50,54,51,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,155,52,176,196,0,0,0,8,105,111,98,49,46,49,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,98,112,114,103,49,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,167,61,121,49,0,0,0,8,105,111,99,49,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,129,32,24,13,0,0,0,8,100,55,108,49,46,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,13,65,183,39,0,0,0,8,100,56,108,49,46,56,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,218,199,159,83,0,0,0,8,100,57,107,49,46,57,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,0,0,0,0,0,0,24,100,49,48,102,49,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,148,196,25,102,0,0,0,8,116,107,50,106,95,50,51,99])
.concat([46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,104,90,33,155,2,0,16,1,116,107,50,106,95,50,50,99,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,172,9,75,183,2,0,16,1,116,107,50,95,48,49,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,191,185,156,13,4,0,32,0,116,107,50,95,48,50,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,112,34,69,4,0,32,0,116,107,50,95,48,51,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,96,36,202,197,4,0,32,0,116,107,50,95,48,52,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,28,85,73,227,4,0,32,0,116,107,50,95,48,53,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,83,77,164,228,4,0,32,0,116,107,50,95,48,54,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,107,6,88,4,0,32,0,116,107,50,95,48,55,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,142,86,6,215,4,0,32,0,116,107,50,95,48,56,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,2,154,161,212,4,0,32,0,116,107,50,95,113,97,46,53,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,13,58,24,201,3,0,16,0,116,107,50,45,113,49,46,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,207,104,18,97,6,0,64,0,116,107,50,45,113,50,46,50,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,169,92,245,32,6,0,64,0,116,107,50,45,113,51,46,51,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,111,207,191,6,0,64,0,116,107,50,45,113,52,46,52,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,136,46,100,54,6,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,154,135,134,67,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,116,107,50,54,51,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,155,52,176,196,0,0,0,8,105,111,98,49,46,49,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,98,112,114,103,49,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,167,61,121,49,0,0,0,8,105,111,99,49,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,129,32,24,13,0,0,0,8,100,55,108,49,46,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,13,65,183,39,0,0,0,8,100,56,108,49,46,56,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,218,199,159,83,0,0,0,8,100,57,107,49,46,57,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,0,0,0,0,0,0,24,100,49,48,102,49,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,148,196,25,102,0,0,0,8,115,103,121,120,46,56,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,80,166,3,55,2,0,16,1,115,103,121,120,45,49,46,49,54,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,246,233,11,166,4,0,32,0,115,103,121,120,45,50,46,49,54,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,72,208,217,106,4,0,32,0,115,103,121,120,122,95,115,110,100,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,111,55,12,33,3,0,16,0,115,103,121,120,122,95,115,110,100,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,242,192,90,193,5,0,64,0,26,0,0,0,255,255,0,0,0,0,0,0,27,0,0,0,255,255,0,0,0,0,0,0,28,0,0,0,255,255,19,0,0,0,0,0,0,0,0,0,254,0,3,0,88,160,1,0,26,0,0,0,1,3,2,0,128,38,2,0,26,0,0,0,1,3,1,0,200,37,2,0,26,0,0,0,1,3,0,0,208,36,2,0,0,0,0,0,254,0,4,0,32,4,2,0,27,0,0,0,1,3,0,0,80,245,6,0,27,0,0,0,1,3,1,0,8,201,6,0,27,0,0,0,1,3,2,0,200,197,6,0,27,0,0,0,1,3,3,0,152,194,6,0,0,0,0,0,254,0,8,0,72,202,5,0,28,0,0,0,1,7,0,0,160,64,2,0,28,0,0,0,1,7,1,0,160,203,8,0,28,0,0,0,1,7,2,0,80,246,3,0,28,0,0,0,1,7,3,0,248,38,7,0,28,0,0,0,1,7,4,0,112,212,3,0,28,0,0,0,1,7,5,0,24,99,5,0,28,0,0,0,1,7,6,0,40,53,2,0,28,0,0,0,1,7,7,0,248,160,5,0,0,0,0,0,254,0,8,0,128,129,4,0,28,0,0,0,1,112,112,0,104,48,2,0,28,0,0,0,1,112,96,0,120,47,2,0,28,0,0,0,1,112,80,0,152,46,2,0,28,0,0,0,1,112,64,0,64,45,2,0,28,0,0,0,1,112,48,0,72,44,2,0,28,0,0,0,1,112,32,0,240,41,2,0,28,0,0,0,1,112,16,0,88,40,2,0,28,0,0,0,1,112,0,0,168,39,2,0,51,45,102,50,97,98,46,48,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,10,253,97,1,0,16,1,49,45,57,50,48,55,46,48,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,76,226,89,127,1,0,16,1,52,45,100,52,100,50,46,48,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,135,238,94,254,1,0,16,1,50,45,54,99,52,49,46,48,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,190,121,147,115,1,0,16,1,53,45,99,97,102,51,46,48,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,149,170,220,200,4,0,32,0,54,45,48,51,52,102,46,48,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,12,0,176,26,4,0,32,0,55,45,98,48,102,97,46,48,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,107,255,37,132,4,0,32,0,56,45,97,54,98,55,46,48,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,123,25,206,36,4,0,32,0,57,45,56,97,50,99,46,48,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,155,239,32,157,4,0,32,0,49,48,45,55,100,50,52,46,48,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,210,61,201,144,4,0,32,0,49,49,45,52,49,55,49,46,48,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,226,215,159,33,4,0,32,0,49,50,45,102,53,54,98,46,48,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,154,124,193,239,4,0,32,0,51,106,115,95,48,57,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,76,4,206,33,3,0,16,0,51,106,115,95,49,56,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,125,48,110,172,5,0,64,0,51,106,115,95,49,57,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,219,65,135,6,5,0,64,0,116,107,50,97,95,50,51,99,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,40,70,2,46,2,0,16,1,116,107,50,97,95,50,50,99,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,205,212,10,144,2,0,16,1,116,107,50,45,49,109,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,191,185,156,13,4,0,32,0,116,107,50,45,51,109,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,112,34,69,4,0,32,0,116,107,50,45,50,109,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,96,36,202,197,4,0,32,0,116,107,50,45,52,109,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,28,85,73,227,4,0,32,0,116,107,50,45,53,109,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,11,15,31,41,4,0,32,0,116,107,50,45,55,109,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,73,185,222,62,4,0,32,0,116,107,50,45,54,109,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,214,20,189,26,4,0,32,0,116,107,50,45,56,109,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,227,72,121,178,4,0,32,0,116,107,50,95,113,97,46,53,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,13,58,24,201,3,0,16,0,116,107,50,45,113,49,46,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,207,104,18,97,6,0,64,0,116,107,50,45,113,50,46,50,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,169,92,245,32,6,0,64,0,116,107,50,45,113,51,46,51,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,111,207,191,6,0,64,0,116,107,50,45,113,52,46,52,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,136,46,100,54,6,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,154,135,134,67,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,116,107,50,54,51,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,155,52,176,196,0,0,0,8,105,111,98,49,46,49,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,98,112,114,103,49,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,167,61,121,49,0,0,0,8,105,111,99,49,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,129,32,24,13,0,0,0,8,100,55,108,49,46,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,13,65,183,39,0,0,0,8,100,56,108,49,46,56,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,218,199,159,83,0,0,0,8,100,57,107,49,46,57,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,0,0,0,0,0,0,24,100,49,48,102,49,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,148,196,25,102,0,0,0,8,33,0,0,0,255,255,255,0,0,0,0,0,34,0,0,0,255,255,255,0,0,0,0,0,35,0,0,0,255,255,127,0,0,0,0,0,0,0,0,0,254,0,4,0,72,202,5,0,33,0,0,0,1,3,2,0,80,246,3,0,33,0,0,0,1,3,3,0,248,38,7,0,33,0,0,0,1,3,1,0,112,212,3,0,33,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,64,37,5,0,33,0,0,0,1,12,8,0,64,103,2,0,33,0,0,0,1,12,12,0,176,102,2,0,33,0,0,0,1,12,4,0,104,101,2,0,33,0,0,0,1,12,0,0,24,99,2,0,0,0,0,0,254,0,4,0,128,129,4,0,33,0,0,0,1,48,0,0,192,255,2,0,33,0,0,0,1,48,16,0,208,75,4,0,33,0,0,0,1,48,48,0,8,49,4,0,33,0,0,0,1,48,32,0,72,246,3,0,0,0,0,0,254,0,2,0,112,242,7,0,33,0,0,0,1,64,64,0,240,242,5,0,33,0,0,0,1,64,0,0,216,104,6,0,0,0,0,0,254,0,2,0,8,95,2,0,33,0,0,0,1,128,0,0,56,111,3,0,33,0,0,0,1,128,128,0,104,134,3,0,0,0,0,0,254,0,2,0,200,30,2,0,34,0,0,0,1,1,1,0,120,97,1,0,34,0,0,0,1,1,0,0,96,19,1,0,0,0,0,0,254,0,2,0,144,212,8,0,34,0,0,0,1,2,2,0,96,135,7,0,34,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,34,0,0,0,1,4,4,0,224,93,2,0,34,0,0,0,1,4,0,0,64,92,2,0,0,0,0,0,254,0,2,0,232,75,4,0,34,0,0,0,1,8,8,0,96,135,7,0,34,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,34,0,0,0,1,48,0,0,32,136,7,0,34,0,0,0,1,48,16,0,40,88,7,0,34,0,0,0,1,48,32,0,96,39,7,0,34,0,0,0,1,48,48,0,144,251,6,0,0,0,0,0,254,0,4,0,160,123,6,0,34,0,0,0,1,192,192,0,184,164,6,0,34,0,0,0,1,192,128,0,80,74,6,0,34,0,0,0,1,192,64,0,192,32,6,0,34,0,0,0,1,192,0,0,32,242,5,0,0,0,0,0,254,0,4,0,8,80,7,0,35,0,0,0,1,192,192,0,224,120,4,0,35,0,0,0,1,192,128,0,0,89,2,0,35,0,0,0,1,192,64,0,224,86,2,0,35,0,0,0,1,192,0,0,40,83,2,0,0,0,0,0,105,99,56,55,95,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,188,255,26,74,0,0,16,1,105,99,57,53,95,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,156,67,125,132,0,0,16,1,105,99,54,55,95,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,175,110,220,0,0,16,1,105,99,53,54,95,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,59,43,192,26,0,0,16,1,105,99,53,52,95,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,179,72,195,39,0,0,16,1,105,99,56,53,95,48,55,118,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,38,148,33,197,0,0,32,0,105,99,56,54,95,48,56,118,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,255,161,161,143,0,0,32,0,105,99,57,48,95,48,57,118,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,28,132,248,153,0,0,32,0,105,99,56,55,95,49,48,118,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,61,9,50,130,0,0,32,0,105,99,57,49,95,49,49,118,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,137,55,141,24,0,0,32,0,105,99,53,48,95,49,50,118,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,34,233,31,218,0,0,32,0,105,99,53,52,95,49,51,118,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,44,60,208,154,0,0,32,0,105,99,54,48,95,49,52,118,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,27,251,157,73,0,0,32,0,105,99,54,53,95,49,53,118,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,129,92,234,216,0,0,32,0,105,99,56,50,95,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,237,146,214,47,0,0,64,0,101,112,114,45,55,52,56,57,46,49,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,112,75,15,19,0,0,16,1,101,112,114,45,55,52,57,48,46,49,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,51,103,101,158,0,0,16,1,101,112,114,45,55,52,57,49,46,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,254,14,125,31,0,0,16,1,101,112,114,45,55,52,57,56,46,49,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,123,30,174,120,0,0,16,1,101,112,114,45,55,52,57,55,46,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,202,9,214,8,0,0,32,0,101,112,114,45,55,52,57,54,46,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,241,253,97,111,0,0,32,0,101,112,114,45,55,52,57,53,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,45,44,13,106,0,0,32,0,101,112,114,45,55,52,57,52,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,199,129,226,168,0,0,32,0,101,112,114,45,55,52,57,51,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,244,93,48,137,0,0,32,0,101,112,114,45,55,52,57,50,46,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,177,6,248,96,0,0,32,0,101,112,114,45,55,52,56,53,46,49,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,34,23,137,194,0,0,32,0,101,112,114,45,55,52,56,55,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,27,66,58,45,0,0,32,0,101,112,114,45,55,52,56,54,46,49,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,80,44,98,141,0,0,32,0,101,112,114,45,55,52,56,56,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,27,47,124,0,0,0,32,0,112,114,45,53,51,49,55,46,55,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,184,80,131,100,0,0,0,8,15,0,0,0,255,255,255,0,0,0,0,0,16,0,0,0,255,255,236,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,15,0,0,0,1,15,7,0,80,252,6,0,15,0,0,0,1,15,8,0,16,242,7,0,15,0,0,0,1,15,9,0,104,236,7,0,15,0,0,0,1,15,5,0,192,54,8,0,15,0,0,0,1,15,4,0,56,24,4,0,15,0,0,0,1,15,15,0,128,230,7,0,15,0,0,0,1,15,0,0,128,230,7,0,15,0,0,0,1,15,3,0,176,162,3,0,15,0,0,0,1,15,2,0,24,188,3,0,15,0,0,0,1,15,1,0,72,216,3,0,15,0,0,0,1,15,6,0,120,211,6,0,15,0,0,0,1,15,14,0,184,164,6,0,15,0,0,0,1,15,13,0,80,74,6,0,15,0,0,0,1,15,12,0,192,32,6,0,15,0,0,0,1,15,11,0,192,234,2,0,15,0,0,0,1,15,10,0,32,242,5,0,0,0,0,0,254,0,16,0,160,123,6,0,15,0,0,0,1,240,112,0,80,252,6,0,15,0,0,0,1,240,128,0,16,242,7,0,15,0,0,0,1,240,144,0,104,236,7,0,15,0,0,0,1,240,80,0,192,54,8,0,15,0,0,0,1,240,64,0,56,24,4,0,15,0,0,0,1,240,240,0,128,230,7,0,15,0,0,0,1,240,0,0,128,230,7,0,15,0,0,0,1,240,48,0,176,162,3,0,15,0,0,0,1,240,32,0,24,188,3,0,15,0,0,0,1,240,16,0,72,216,3,0,15,0,0,0,1,240,96,0,120,211,6,0,15,0,0,0,1,240,224,0,184,164,6,0,15,0,0,0,1,240,208,0,80,74,6,0,15,0,0,0,1,240,192,0,192,32,6,0,15,0,0,0,1,240,176,0,192,234,2,0,15,0,0,0,1,240,160,0,32,242,5,0,0,0,0,0,254,0,2,0,200,30,2,0,16,0,0,0,1,1,0,0,120,97,1,0,16,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,2,0,168,234,7,0,16,0,0,0,1,2,2,0,96,135,7,0,16,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,16,0,0,0,1,12,12,0,8,49,4,0,16,0,0,0,1,12,8,0,152,21,4,0,16,0,0,0,1,12,4,0,72,246,3,0,16,0,0,0,1,12,0,0,104,151,6,0,0,0,0,0,254,0,2,0,64,37,5,0,16,0,0,0,1,16,16,0,32,148,6,0,16,0,0,0,1,16,0,0,208,143,6,0,0,0,0,0,254,0,2,0,104,159,3,0,16,0,0,0,1,32,0,0,96,135,7,0,16,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,72,202,5,0,16,0,0,0,1,64,64,0,80,246,3,0,16,0,0,0,1,64,0,0,112,212,3,0,101,112,114,45,49,50,49,50,48,46,52,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,155,201,216,203,1,0,16,1,101,112,114,45,49,50,49,49,56,46,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,12,40,163,233,1,0,16,1,101,112,114,45,49,50,49,50,49,46,52,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,169,192,68,94,1,0,16,1,101,112,114,45,49,50,49,49,57,46,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,249,62,237,1,1,0,16,1,101,112,114,45,49,50,48,56,54,46,57,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,223,73,185,69,2,0,32,0,101,112,114,45,49,50,48,56,55,46,57,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,183,150,3,111,2,0,32,0,101,112,114,45,49,50,48,56,56,46,56,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,73,7,140,186,2,0,32,0,101,112,114,45,49,50,48,57,48,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,202,207,238,174,3,0,32,0,101,112,114,45,49,50,48,57,52,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,39,73,94,97,3,0,32,0,101,112,114,45,49,50,48,57,49,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,67,162,9,132,3,0,32,0,101,112,114,45,49,50,48,57,53,46,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,44,236,116,231,3,0,32,0,101,112,114,45,49,50,48,57,50,46,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,144,13,47,92,3,0,32,0,101,112,114,45,49,50,48,57,54,46,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,110,157,213,12,3,0,32,0,101,112,114,45,49,50,48,57,51,46,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,187,231,145,72,3,0,32,0,101,112,114,45,49,50,48,57,55,46,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,44,144,69,230,3,0,32,0,101,112,114,45,49,50,48,56,57,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,11,235,33,131,4,0,16,1,51,49,55,45,48,48,56,54,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,128,11,72,236,5,0,16,1,101,112,114,45,49,50,49,51,49,46,97,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,136,207,94,185,1,0,16,1,101,112,114,45,49,50,49,50,56,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,43,55,17,183,1,0,16,1,101,112,114,45,49,50,49,50,52,46,97,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,111,251,206,218,2,0,32,0,101,112,114,45,49,50,49,50,53,46,97,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,247,109,195,159,2,0,32,0,101,112,114,45,49,50,49,50,54,46,97,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,148,253,147,166,2,0,32,0,101,112,114,45,49,50,48,57,48,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,202,207,238,174,3,0,32,0,101,112,114,45,49,50,48,57,52,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,39,73,94,97,3,0,32,0,101,112,114,45,49,50,48,57,49,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,67,162,9,132,3,0,32,0,101,112,114,45,49,50,48,57,53,46,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,44,236,116,231,3,0,32,0,101,112,114,45,49,50,48,57,50,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,144,13,47,92,3,0,32,0,101,112,114,45,49,50,48,57,54,46,98,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,110,157,213,12,3,0,32,0,101,112,114,45,49,50,48,57,51,46,98,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,187,231,145,72,3,0,32,0,101,112,114,45,49,50,48,57,55,46,98,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,44,144,69,230,3,0,32,0,101,112,114,45,49,50,49,50,55,46,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,187,1,185,11,4,0,16,1,51,49,55,45,48,48,56,55,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,49,181,44,22,5,0,16,1,101,112,114,45,49,50,49,51,55,46,97,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,142,35,129,111,1,0,16,1,101,112,114,45,49,50,49,51,54,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,3,80,240,76,1,0,16,1,101,112,114,45,49,50,49,50,52,46,97,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,111,251,206,218,2,0,32,0,101,112,114,45,49,50,49,50,53,46,97,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,247,109,195,159,2,0,32,0,101,112,114,45,49,50,49,50,54,46,97,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,148,253,147,166,2,0,32,0,101,112,114,45,49,50,48,57,48,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,202,207,238,174,3,0,32,0,101,112,114,45,49,50,48,57,52,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,39,73,94,97,3,0,32,0,101,112,114,45,49,50,48,57,49,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,67,162,9,132,3,0,32,0,101,112,114,45,49,50,48,57,53,46,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,44,236,116,231,3,0,32,0,101,112,114,45,49,50,48,57,50,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,144,13,47,92,3,0,32,0,101,112,114,45,49,50,48,57,54,46,98,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,110,157,213,12,3,0,32,0,101,112,114,45,49,50,48,57,51,46,98,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,187,231,145,72,3,0,32,0,101,112,114,45,49,50,48,57,55,46,98,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,44,144,69,230,3,0,32,0,101,112,114,45,49,50,49,50,55,46,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,187,1,185,11,4,0,16,1,51,49,55,45,48,48,56,57,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,211,48,125,89,5,0,16,1,101,112,114,45,49,50,49,48,48,46,97,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,188,74,202,245,1,0,16,1,101,112,114,45,49,50,48,57,56,46,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,229,229,152,217,1,0,16,1,101,112,114,45,49,50,49,48,49,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,43,73,70,97,1,0,16,1,101,112,114,45,49,50,48,57,57,46,97,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,69,59,36,62,1,0,16,1,101,112,114,45,49,50,49,50,52,46,98,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,111,251,206,218,2,0,32,0,101,112,114,45,49,50,49,50,53,46,98,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,247,109,195,159,2,0,32,0,101,112,114,45,49,50,49,50,54,46,98,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,148,253,147,166,2,0,32,0,101,112,114,45,49,50,48,57,48,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,202,207,238,174,3,0,32,0,101,112,114,45,49,50,48,57,52,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,39,73,94,97,3,0,32,0,101,112,114,45,49,50,48,57,49,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,67,162,9,132,3,0,32,0,101,112,114,45,49,50,48,57,53,46,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,44,236,116,231,3,0,32,0,101,112,114,45,49,50,48,57,50,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,144,13,47,92,3,0,32,0,101,112,114,45,49,50,48,57,54,46,98,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,110,157,213,12,3,0,32,0,101,112,114,45,49,50,48,57,51,46,98,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,187,231,145,72,3,0,32,0,101,112,114,45,49,50,48,57,55,46,98,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,44,144,69,230,3,0,32,0,101,112,114,45,49,50,49,50,55,46,97,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,187,1,185,11,4,0,16,1,51,49,55,45,48,48,56,53,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,141,243,80,129,5,0,16,1,101,112,114,45,49,50,48,56,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,84,182,222,182,1,0,16,1,101,112,114,45,49,50,48,56,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,21,91,220,56,1,0,16,1,101,112,114,45,49,50,48,56,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,139,9,98,9,1,0,16,1,101,112,114,45,49,50,48,56,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,142,26,99,61,1,0,16,1,101,112,114,45,49,50,48,56,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,223,73,185,69,2,0,32,0,101,112,114,45,49,50,48,56,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,183,150,3,111,2,0,32,0,101,112,114,45,49,50,48,56,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,73,7,140,186,2,0,32,0,101,112,114,45,49,50,48,57,48,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,202,207,238,174,3,0,32,0,101,112,114,45,49,50,48,57,52,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,39,73,94,97,3,0,32,0,101,112,114,45,49,50,48,57,49,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,67,162,9,132,3,0,32,0,101,112,114,45,49,50,48,57,53,46,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,44,236,116,231,3,0,32,0,101,112,114,45,49,50,48,57,50,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,144,13,47,92,3,0,32,0,101,112,114,45,49,50,48,57,54,46,98,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,110,157,213,12,3,0,32,0,101,112,114,45,49,50,48,57,51,46,98,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,187,231,145,72,3,0,32,0,101,112,114,45,49,50,48,57,55,46,98,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,44,144,69,230,3,0,32,0,101,112,114,45,49,50,48,56,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,11,235,33,131,4,0,16,1,51,49,55,45,48,48,56,52,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,250,218,88,44,5,0,16,1,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,252,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,19,0,0,0,1,15,7,0,80,252,6,0,19,0,0,0,1,15,8,0,16,242,7,0,19,0,0,0,1,15,9,0,104,236,7,0,19,0,0,0,1,15,5,0,176,51,4,0,19,0,0,0,1,15,4,0,56,24,4,0,19,0,0,0,1,15,15,0,128,230,7,0,19,0,0,0,1,15,1,0,72,216,3,0,19,0,0,0,1,15,2,0,24,188,3,0,19,0,0,0,1,15,3,0,176,162,3,0,19,0,0,0,1,15,6,0,120,211,6,0,19,0,0,0,1,15,14,0,184,164,6,0,19,0,0,0,1,15,13,0,80,74,6,0,19,0,0,0,1,15,12,0,192,32,6,0,19,0,0,0,1,15,11,0,192,234,2,0,19,0,0,0,1,15,10,0,32,242,5,0,19,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,19,0,0,0,1,240,112,0,80,252,6,0,19,0,0,0,1,240,128,0,16,242,7,0,19,0,0,0,1,240,144,0,104,236,7,0,19,0,0,0,1,240,80,0,176,51,4,0,19,0,0,0,1,240,64,0,56,24,4,0,19,0,0,0,1,240,240,0,128,230,7,0,19,0,0,0,1,240,16,0,72,216,3,0,19,0,0,0,1,240,32,0,24,188,3,0,19,0,0,0,1,240,48,0,176,162,3,0,19,0,0,0,1,240,96,0,120,211,6,0,19,0,0,0,1,240,224,0,184,164,6,0,19,0,0,0,1,240,208,0,80,74,6,0,19,0,0,0,1,240,192,0,192,32,6,0,19,0,0,0,1,240,176,0,192,234,2,0,19,0,0,0,1,240,160,0,32,242,5,0,19,0,0,0,1,240,0,0,208,236,2,0,0,0,0,0,254,0,2,0,168,234,7,0,20,0,0,0,1,2,2,0,96,135,7,0,20,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,12,0,0,208,75,4,0,20,0,0,0,1,12,12,0,8,49,4,0,20,0,0,0,1,12,8,0,152,21,4,0,20,0,0,0,1,12,4,0,72,246,3,0,0,0,0,0,254,0,2,0,64,37,5,0,20,0,0,0,1,16,16,0,40,124,5,0,20,0,0,0,1,16,0,0,232,121,5,0,0,0,0,0,254,0,2,0,72,202,5,0,20,0,0,0,1,32,32,0,248,38,7,0,20,0,0,0,1,32,0,0,112,212,3,0,0,0,0,0,254,0,2,0,160,119,5,0,20,0,0,0,1,64,64,0,56,111,3,0,20,0,0,0,1,64,0,0,104,134,3,0,0,0,0,0,118,109,51,101,46,48,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,140,42,150,245,1,0,16,1,118,109,51,101,46,48,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,162,14,180,33,1,0,16,1,118,109,51,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,15,224,24,65,1,0,16,1,118,109,51,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,169,211,79,47,1,0,16,1,118,109,51,46,48,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,184,145,218,203,1,0,16,1,118,109,51,46,48,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,89,114,164,108,1,0,16,1,118,109,51,46,48,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,227,57,163,244,1,0,16,1,118,109,51,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,184,181,251,255,1,0,16,1,118,109,51,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,235,17,138,253,5,0,32,0,118,109,51,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,78,125,30,221,5,0,32,0,118,109,51,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,94,68,137,107,5,0,32,0,118,109,51,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,199,253,48,56,5,0,32,0,118,109,51,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,108,142,162,193,5,0,32,0,118,109,51,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,4,115,74,25,5,0,32,0,118,109,51,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,71,159,154,223,5,0,32,0,118,109,51,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,217,195,47,194,5,0,32,0,118,109,51,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,155,118,120,247,10,0,16,1,118,109,51,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,161,250,9,204,10,0,16,1,118,109,51,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,110,149,14,232,12,0,64,0,118,109,51,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,87,21,215,156,12,0,64,0,18,0,0,0,255,255,223,0,0,0,0,0,19,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,20,0,32,4,2,0,18,0,0,0,1,31,21,0,160,218,3,0,18,0,0,0,1,31,23,0,112,31,1,0,18,0,0,0,1,31,25,0,184,220,8,0,18,0,0,0,1,31,27,0,88,154,8,0,18,0,0,0,1,31,3,0,184,213,5,0,18,0,0,0,1,31,29,0,200,92,8,0,18,0,0,0,1,31,5,0,248,137,5,0,18,0,0,0,1,31,7,0,152,141,7,0,18,0,0,0,1,31,31,0,56,37,8,0,18,0,0,0,1,31,9,0,24,46,7,0,18,0,0,0,1,31,19,0,96,240,7,0,18,0,0,0,1,31,17,0,128,188,7,0,18,0,0,0,1,31,15,0,184,46,7,0,18,0,0,0,1,31,13,0,120,251,7,0,18,0,0,0,1,31,11,0,248,140,7,0,18,0,0,0,1,31,30,0,176,110,4,0,18,0,0,0,1,31,20,0,208,244,3,0,18,0,0,0,1,31,10,0,64,58,4,0,18,0,0,0,1,31,0,0,216,30,4,0,18,0,0,0,1,31,1,0,200,82,2,0,0,0,0,0,254,0,2,0,120,189,3,0,18,0,0,0,1,32,32,0,192,255,2,0,18,0,0,0,1,32,0,0,208,75,4,0,0,0,0,0,254,0,2,0,200,30,2,0,18,0,0,0,1,64,64,0,120,97,1,0,18,0,0,0,1,64,0,0,96,19,1,0,0,0,0,0,254,0,2,0,232,80,3,0,18,0,0,0,1,128,128,0,96,135,7,0,18,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,19,0,0,0,1,3,2,0,208,75,4,0,19,0,0,0,1,3,3,0,8,49,4,0,19,0,0,0,1,3,1,0,72,246,3,0,19,0,0,0,1,3,0,0,48,176,2,0,0,0,0,0,254,0,4,0,40,148,2,0,19,0,0,0,1,12,8,0,168,94,8,0,19,0,0,0,1,12,0,0,16,166,2,0,19,0,0,0,1,12,12,0,248,45,5,0,19,0,0,0,1,12,4,0,48,203,8,0,0,0,0,0,254,0,4,0,72,202,5,0,19,0,0,0,1,48,32,0,80,246,3,0,19,0,0,0,1,48,48,0,80,124,6,0,19,0,0,0,1,48,16,0,112,212,3,0,19,0,0,0,1,48,0,0,248,160,5,0,0,0,0,0,254,0,2,0,72,217,6,0,19,0,0,0,1,64,0,0,56,111,3,0,19,0,0,0,1,64,64,0,104,134,3,0,0,0,0,0,254,0,2,0,40,73,5,0,19,0,0,0,1,128,0,0,96,135,7,0,19,0,0,0,1,128,128,0,152,182,7,0,0,0,0,0,19,0,0,0,255,255,254,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,19,0,0,0,1,1,0,0,120,97,1,0,19,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,2,2,0,96,135,7,0,19,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,4,4,0,96,135,7,0,19,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,19,0,0,0,1,48,0,0,32,136,7,0,19,0,0,0,1,48,16,0,40,88,7,0,19,0,0,0,1,48,32,0,96,39,7,0,19,0,0,0,1,48,48,0,144,251,6,0,0,0,0,0,254,0,4,0,160,123,6,0,19,0,0,0,1,192,192,0,184,164,6,0,19,0,0,0,1,192,128,0,80,74,6,0,19,0,0,0,1,192,64,0,192,32,6,0,19,0,0,0,1,192,0,0,32,242,5,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,3,2,0,80,246,3,0,20,0,0,0,1,3,3,0,80,124,6,0,20,0,0,0,1,3,1,0,112,212,3,0,20,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,64,37,5,0,20,0,0,0,1,12,0,0,56,176,7,0,20,0,0,0,1,12,12,0,8,172,7,0,20,0,0,0,1,12,4,0,56,168,7,0,20,0,0,0,1,12,8,0,248,163,7,0,0,0,0,0,254,0,0,0,128,129,4,0,20,0,0,0,1,48,32,0,208,75,4,0,20,0,0,0,1,48,48,0,8,49,4,0,20,0,0,0,1,48,16,0,152,21,4,0,20,0,0,0,1,48,0,0,72,246,3,0,0,0,0,0,254,0,2,0,104,159,3,0,20,0,0,0,1,64,0,0,56,111,3,0,20,0,0,0,1,64,64,0,104,134,3,0,0,0,0,0,57,54,51,45,120,50,51,46,106,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,4,144,84,169,0,0,16,1,57,54,51,45,120,50,52,46,107,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,103,144,204,229,0,0,16,1,57,54,51,45,120,50,49,46,106,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,146,207,137,87,0,0,16,1,57,54,51,45,120,50,50,46,107,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,119,226,116,10,0,0,16,1,57,54,51,101,50,48,46,103,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,214,166,146,22,0,0,16,1,57,54,51,97,50,56,46,104,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,105,71,219,0,0,32,0,57,54,51,97,50,57,46,107,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,46,205,105,128,0,0,32,0,57,54,51,97,49,55,46,104,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,68,154,35,181,0,0,32,0,57,54,51,97,49,56,46,104,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,239,173,81,221,0,0,32,0,57,54,51,97,49,53,46,107,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,237,78,50,31,0,0,32,0,57,54,51,97,49,54,46,107,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,132,153,189,212,0,0,32,0,57,54,51,97,51,48,46,103,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,128,38,216,171,0,0,32,0,57,54,51,97,51,49,46,103,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,28,74,0,248,0,0,32,0,57,54,51,97,50,54,46,99,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,99,48,172,226,0,0,64,0,57,54,51,97,50,55,46,100,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,75,103,253,45,0,0,64,0,57,54,51,97,50,53,46,100,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,199,120,160,252,0,0,64,0,33,0,0,0,255,255,255,0,0,0,0,0,34,0,0,0,255,255,94,0,0,0,0,0,35,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,16,0,32,4,2,0,33,0,0,0,1,15,0,0,104,54,4,0,33,0,0,0,1,15,2,0,80,252,6,0,33,0,0,0,1,15,5,0,16,242,7,0,33,0,0,0,1,15,8,0,104,236,7,0,33,0,0,0,1,15,4,0,120,113,6,0,33,0,0,0,1,15,1,0,232,228,5,0,33,0,0,0,1,15,15,0,128,230,7,0,33,0,0,0,1,15,3,0,56,141,7,0,33,0,0,0,1,15,7,0,120,211,6,0,33,0,0,0,1,15,14,0,184,164,6,0,33,0,0,0,1,15,6,0,24,1,7,0,33,0,0,0,1,15,13,0,80,74,6,0,33,0,0,0,1,15,12,0,192,32,6,0,33,0,0,0,1,15,11,0,192,234,2,0,33,0,0,0,1,15,10,0,32,242,5,0,33,0,0,0,1,15,9,0,176,192,2,0,0,0,0,0,254,0,4,0,128,129,4,0,34,0,0,0,1,3,3,0,192,255,2,0,34,0,0,0,1,3,2,0,208,75,4,0,34,0,0,0,1,3,1,0,8,49,4,0,34,0,0,0,1,3,0,0,72,246,3,0,0,0,0,0,254,0,4,0,72,202,5,0,34,0,0,0,1,96,96,0,80,246,3,0,34,0,0,0,1,96,64,0,248,38,7,0,34,0,0,0,1,96,32,0,48,123,8,0,34,0,0,0,1,96,0,0,8,117,8,0,0,0,0,0,254,0,2,0,168,234,7,0,34,0,0,0,1,128,128,0,96,135,7,0,34,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,35,0,0,0,1,1,1,0,96,135,7,0,35,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,184,89,6,0,35,0,0,0,1,4,4,0,96,135,7,0,35,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,57,54,51,45,102,50,51,46,106,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,97,228,181,156,0,0,16,1,57,54,51,45,102,50,52,46,107,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,171,47,144,45,0,0,16,1,57,54,51,45,102,50,49,46,106,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,120,83,162,159,0,0,16,1,57,54,51,45,102,50,50,46,107,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,83,238,39,33,0,0,16,1,57,54,51,101,50,48,46,103,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,214,166,146,22,0,0,16,1,57,54,51,97,50,56,46,104,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,105,71,219,0,0,32,0,57,54,51,97,50,57,46,107,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,46,205,105,128,0,0,32,0,57,54,51,97,49,55,46,104,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,68,154,35,181,0,0,32,0,57,54,51,97,49,56,46,104,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,239,173,81,221,0,0,32,0,57,54,51,97,49,53,46,107,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,237,78,50,31,0,0,32,0,57,54,51,97,49,54,46,107,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,132,153,189,212,0,0,32,0,57,54,51,97,51,48,46,103,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,128,38,216,171,0,0,32,0,57,54,51,97,51,49,46,103,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,28,74,0,248,0,0,32,0,57,54,51,97,50,54,46,99,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,99,48,172,226,0,0,64,0,57,54,51,97,50,55,46,100,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,75,103,253,45,0,0,64,0,57,54,51,97,50,53,46,100,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,199,120,160,252,0,0,64,0,20,0,0,0,255,255,96,0,0,0,0,0,21,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,232,75,4,0,20,0,0,0,1,32,32,0,96,135,7,0,20,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,192,3,0,20,0,0,0,1,64,64,0,96,135,7,0,20,0,0,0,1,64,0,0,152,182,7,0,101,112,114,53,56,48,55,98,46,49,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,159,156,219,147,0,0,16,1,101,112,114,45,53,56,48,56,46,49,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0])
.concat([101,102,17,103,0,0,16,1,101,112,114,45,53,56,48,57,46,49,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,201,47,121,253,0,0,16,1,101,112,114,45,53,56,49,48,46,49,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,157,39,43,220,0,0,16,1,101,112,114,45,53,56,49,49,46,49,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,177,58,62,9,0,0,16,1,101,112,114,45,53,56,49,50,46,49,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,47,105,253,91,0,0,16,1,101,112,114,45,53,56,49,57,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,253,208,175,246,0,0,16,1,101,112,114,45,53,56,49,56,46,56,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,217,51,32,178,0,0,32,0,101,112,114,45,53,56,49,55,46,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,151,39,148,253,0,0,32,0,101,112,114,45,53,56,49,54,46,56,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,109,55,132,67,0,0,32,0,101,112,114,45,53,56,49,53,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,108,4,173,22,0,0,32,0,101,112,114,45,53,56,49,52,46,56,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,153,28,114,190,0,0,32,0,101,112,114,45,53,56,49,51,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,126,194,66,13,0,0,32,0,101,112,114,45,53,56,48,53,46,56,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,101,40,115,90,0,0,32,0,101,112,114,45,53,56,48,54,46,57,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,140,37,172,38,0,0,32,0,112,114,45,53,51,49,55,46,49,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,184,80,131,100,0,0,0,8,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,254,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,19,0,0,0,1,15,7,0,80,252,6,0,19,0,0,0,1,15,8,0,16,242,7,0,19,0,0,0,1,15,9,0,104,236,7,0,19,0,0,0,1,15,5,0,192,54,8,0,19,0,0,0,1,15,4,0,56,24,4,0,19,0,0,0,1,15,15,0,128,230,7,0,19,0,0,0,1,15,0,0,128,230,7,0,19,0,0,0,1,15,3,0,176,162,3,0,19,0,0,0,1,15,2,0,24,188,3,0,19,0,0,0,1,15,1,0,72,216,3,0,19,0,0,0,1,15,6,0,120,211,6,0,19,0,0,0,1,15,14,0,184,164,6,0,19,0,0,0,1,15,13,0,80,74,6,0,19,0,0,0,1,15,12,0,192,32,6,0,19,0,0,0,1,15,11,0,192,234,2,0,19,0,0,0,1,15,10,0,32,242,5,0,0,0,0,0,254,0,16,0,160,123,6,0,19,0,0,0,1,240,112,0,80,252,6,0,19,0,0,0,1,240,128,0,16,242,7,0,19,0,0,0,1,240,144,0,104,236,7,0,19,0,0,0,1,240,80,0,192,54,8,0,19,0,0,0,1,240,64,0,56,24,4,0,19,0,0,0,1,240,240,0,128,230,7,0,19,0,0,0,1,240,0,0,128,230,7,0,19,0,0,0,1,240,48,0,176,162,3,0,19,0,0,0,1,240,32,0,24,188,3,0,19,0,0,0,1,240,16,0,72,216,3,0,19,0,0,0,1,240,96,0,120,211,6,0,19,0,0,0,1,240,224,0,184,164,6,0,19,0,0,0,1,240,208,0,80,74,6,0,19,0,0,0,1,240,192,0,192,32,6,0,19,0,0,0,1,240,176,0,192,234,2,0,19,0,0,0,1,240,160,0,32,242,5,0,0,0,0,0,254,0,2,0,200,30,2,0,20,0,0,0,1,1,0,0,120,97,1,0,20,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,6,6,0,8,49,4,0,20,0,0,0,1,6,4,0,152,21,4,0,20,0,0,0,1,6,2,0,72,246,3,0,20,0,0,0,1,6,0,0,112,49,6,0,0,0,0,0,254,0,8,0,64,37,5,0,20,0,0,0,1,56,56,0,192,33,6,0,20,0,0,0,1,56,48,0,160,30,6,0,20,0,0,0,1,56,40,0,208,26,6,0,20,0,0,0,1,56,32,0,232,23,6,0,20,0,0,0,1,56,24,0,48,20,6,0,20,0,0,0,1,56,16,0,248,216,5,0,20,0,0,0,1,56,8,0,248,211,5,0,20,0,0,0,1,56,0,0,120,7,5,0,0,0,0,0,133,0,6,0,53,0,143,0,8,0,48,0,229,0,27,0,7,0,34,0,28,0,49,0,229,0,37,0,29,0,21,0,38,0,41,0,128,0,45,0,59,0,151,0,46,0,28,0,186,0,59,0,5,0,54,0,61,0,54,0,87,0,68,0,9,0,207,0,68,0,61,0,97,0,78,0,39,0,135,0,100,0,26,0,214,0,100,0,23,0,11,0,108,0,60,0,6,0,109,0,36,0,24,0,110,0,58,0,169,0,121,0,35,0,138,0,123,0,17,0,214,0,128,0,12,0,103,0,130,0,63,0,57,0,131,0,56,0,114,0,131,0,20,0,236,0,132,0,22,0,142,0,133,0,16,0,32,0,136,0,37,0,149,0,138,0,15,0,14,0,141,0,0,0,6,0,145,0,46,0,7,0,148,0,13,0,174,0,151,0,11,0,0,0,152,0,45,0,134,0,155,0,1,0,88,0,161,0,52,0,254,0,161,0,62,0,162,0,168,0,31,0,65,0,170,0,10,0,63,0,172,0,50,0,222,0,172,0,3,0,212,0,185,0,38,0,109,0,187,0,27,0,98,0,189,0,57,0,201,0,190,0,24,0,108,0,193,0,4,0,89,0,195,0,33,0,96,0,204,0,14,0,145,0,204,0,18,0,63,0,207,0,6,0,247,0,207,0,34,0,68,0,208,0,51,0,52,0,210,0,8,0,211,0,217,0,32,0,113,0,221,0,55,0,115,0,225,0,44,0,185,0,227,0,47,0,169,0,228,0,19,0,211,0,231,0,25,0,55,0,237,0,2,0,189,0,244,0,21,0,15,0,246,0,40,0,79,0,247,0,43,0,251,0,255,0,42,0,254,0,4,0,61,1,196,0,6,0,16,1,30,0,7,0,45,1,131,0,11,0,31,1,46,0,13,0,60,1,31,0,14,0,0,1,216,0,14,0,44,1,3,0,15,0,23,1,149,0,17,0,63,1,106,0,23,0,53,1,204,0,23,0,2,1,0,0,24,0,50,1,146,0,29,0,54,1,227,0,33,0,4,1,47,0,45,0,55,1,240,0,47,0,12,1,155,0,62,0,6,1,164,0,76,0,7,1,234,0,77,0,19,1,132,0,78,0,33,1,51,0,82,0,15,1,112,0,83,0,14,1,6,0,89,0,8,1,129,0,96,0,40,1,55,0,97,0,41,1,143,0,103,0,47,1,27,0,106,0,29,1,191,0,124,0,18,1,81,0,127,0,49,1,97,0,134,0,37,1,106,0,143,0,13,1,106,0,145,0,25,1,144,0,146,0,5,1,59,0,150,0,36,1,140,0,151,0,10,1,6,0,153,0,3,1,56,0,153,0,56,1,168,0,153,0,24,1,118,0,166,0,32,1,173,0,166,0,28,1,236,0,166,0,30,1,134,0,172,0,21,1,120,0,175,0,62,1,123,0,179,0,9,1,39,0,184,0,57,1,136,0,194,0,35,1,68,0,195,0,58,1,207,0,197,0,52,1,53,0,201,0,48,1,110,0,209,0,59,1,214,0,215,0,22,1,58,0,217,0,43,1,171,0,224,0,17,1,224,0,226,0,27,1,111,0,230,0,11,1,184,0,232,0,20,1,217,0,232,0,26,1,249,0,232,0,34,1,4,0,241,0,46,1,73,0,248,0,38,1,16,0,249,0,1,1,57,0,251,0,51,1,40,0,252,0,39,1,250,0,6,0,25,2,228,0,7,0,45,2,114,0,10,0,3,2,132,0,27,0,0,2,186,0,29,0,41,2,227,0,34,0,4,2,209,0,38,0,42,2,137,0,50,0,48,2,91,0,54,0,39,2,132,0,58,0,54,2,83,0,63,0,13,2,8,0,64,0,29,2,85,0,64,0,26,2,170,0,65,0,49,2,251,0,65,0,43,2,188,0,70,0,22,2,147,0,82,0,57,2,185,0,87,0,16,2,84,0,89,0,40,2,230,0,90,0,1,2,167,0,93,0,27,2,45,0,94,0,53,2,20,0,98,0,33,2,105,0,109,0,31,2,206,0,111,0,11,2,223,0,117,0,47,2,203,0,119,0,18,2,78,0,124,0,35,2,74,0,132,0,15,2,18,0,134,0,37,2,104,0,140,0,50,2,3,0,149,0,32,2,10,0,156,0,23,2,91,0,163,0,8,2,95,0,164,0,62,2,114,0,164,0,46,2,204,0,166,0,6,2,138,0,171,0,12,2,224,0,173,0,38,2,243,0,175,0,10,2,117,0,180,0,19,2,104,0,183,0,17,2,109,0,194,0,44,2,118,0,195,0,20,2,207,0,196,0,30,2,4,0,197,0,28,2,19,0,198,0,63,2,185,0,199,0,60,2,5,0,215,0,52,2,149,0,215,0,58,2,252,0,216,0,2,2,231,0,220,0,9,2,29,0,225,0,5,2,5,0,230,0,51,2,28,0,233,0,59,2,162,0,237,0,55,2,40,0,238,0,7,2,221,0,239,0,24,2,109,0,240,0,56,2,161,0,242,0,14,2,116,0,247,0,61,2,105,0,249,0,34,2,63,0,255,0,36,2,113,0,16,0,52,3,175,0,17,0,35,3,160,0,20,0,38,3,2,0,23,0,2,3,75,0,25,0,49,3,147,0,28,0,14,3,27,0,30,0,37,3,50,0,32,0,46,3,238,0,32,0,58,3,121,0,34,0,47,3,108,0,35,0,23,3,188,0,37,0,17,3,65,0,41,0,48,3,28,0,46,0,50,3,185,0,49,0,1,3,131,0,50,0,5,3,149,0,58,0,18,3,13,0,63,0,7,3,32,0,65,0,51,3,146,0,69,0,44,3,212,0,71,0,8,3,161,0,75,0,45,3,210,0,75,0,59,3,214,0,82,0,36,3,154,0,95,0,28,3,22,0,96,0,61,3,26,0,99,0,31,3,205,0,102,0,40,3,255,0,103,0,16,3,53,0,105,0,32,3,143,0,108,0,4,3,202,0,108,0,42,3,90,0,116,0,9,3,96,0,120,0,56,3,114,0,121,0,30,3,55,0,127,0,41,3,18,0,128,0,20,3,41,0,130,0,43,3,132,0,152,0,54,3,50,0,153,0,55,3,187,0,160,0,25,3,62,0,163,0,62,3,74,0,166,0,26,3,41,0,167,0,33,3,157,0,183,0,34,3,108,0,185,0,21,3,12,0,192,0,10,3,194,0,195,0,15,3,47,0,201,0,13,3,210,0,206,0,22,3,243,0,206,0,11,3,117,0,207,0,39,3,26,0,213,0,53,3,38,0,214,0,57,3,128,0,218,0,60,3,169,0,221,0,0,3,188,0,235,0,3,3,50,0,239,0,27,3,103,0,240,0,63,3,239,0,241,0,24,3,168,0,243,0,12,3,222,0,249,0,29,3,44,0,250,0,19,3,115,115,102,101,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,93,116,151,165,1,0,16,1,115,115,102,101,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,103,170,130,176,1,0,16,1,115,115,102,101,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,55,193,185,2,1,0,16,1,115,115,102,101,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,197,112,212,112,1,0,16,1,115,115,102,101,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,29,0,9,36,1,0,16,1,115,115,102,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,117,210,148,207,5,0,32,0,115,115,102,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,175,3,183,94,5,0,32,0,115,115,102,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,15,14,166,255,5,0,32,0,115,115,102,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,197,37,232,52,5,0,32,0,115,115,102,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,231,50,204,183,5,0,32,0,115,115,102,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,24,173,118,131,5,0,32,0,115,115,102,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,54,179,177,245,5,0,32,0,115,115,102,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,107,92,157,69,5,0,32,0,115,115,102,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,140,126,36,235,10,0,16,1,115,115,102,46,113,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,92,218,249,166,12,0,64,0,115,115,102,46,113,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,38,174,102,140,12,0,64,0,115,115,102,46,113,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,202,194,92,105,12,0,64,0,115,115,102,46,113,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,50,190,158,157,12,0,64,0,115,115,102,46,113,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,183,231,112,71,12,0,64,0,115,115,102,46,113,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,81,201,121,78,12,0,64,0,115,115,102,46,113,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,19,67,209,205,12,0,64,0,115,115,102,46,113,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,140,8,90,111,12,0,64,0,101,112,114,45,49,50,53,54,51,98,46,53,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,51,243,241,186,1,0,16,1,101,112,114,45,49,50,53,54,52,98,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,240,26,25,181,1,0,16,1,101,112,114,45,49,50,53,55,54,97,46,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,193,153,149,44,9,0,16,1,101,112,114,45,49,50,53,55,55,97,46,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,11,165,249,171,9,0,16,1,101,112,114,45,49,50,52,50,57,46,49,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,20,230,81,88,2,0,32,0,101,112,114,45,49,50,52,51,48,46,49,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,52,1,224,5,2,0,32,0,101,112,114,45,49,50,52,51,49,46,49,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,74,47,87,53,2,0,32,0,109,112,114,45,49,50,52,50,53,46,57,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,21,42,191,20,3,0,32,0,109,112,114,45,49,50,52,50,54,46,57,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,192,13,182,40,3,0,32,0,109,112,114,45,49,50,52,50,55,46,57,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,40,121,54,10,3,0,32,0,109,112,114,45,49,50,52,50,56,46,49,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,213,10,168,239,3,0,32,0,109,112,114,45,49,50,52,50,49,46,57,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,64,97,244,37,3,0,32,0,109,112,114,45,49,50,52,50,50,46,57,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,246,200,81,203,3,0,32,0,109,112,114,45,49,50,52,50,51,46,57,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,142,129,233,11,3,0,32,0,109,112,114,45,49,50,52,50,52,46,49,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,252,13,224,12,3,0,32,0,109,112,114,45,49,50,52,49,55,46,57,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,191,234,6,168,3,0,32,0,109,112,114,45,49,50,52,49,56,46,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,43,15,26,237,3,0,32,0,109,112,114,45,49,50,52,49,57,46,49,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,203,104,69,206,3,0,32,0,109,112,114,45,49,50,52,50,48,46,49,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,235,66,148,103,3,0,32,0,101,112,114,45,49,50,54,48,57,46,57,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,47,129,103,168,3,0,32,0,101,112,114,45,49,50,54,49,48,46,57,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,23,148,185,83,3,0,32,0,101,112,114,45,49,50,54,49,49,46,49,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,176,106,92,189,3,0,32,0,101,112,114,45,49,50,54,49,50,46,49,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,144,232,134,172,3,0,32,0,101,112,114,45,49,50,52,51,54,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,10,95,236,22,4,0,16,1,101,112,114,45,49,50,53,51,53,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,151,53,69,128,12,0,16,1,101,112,114,45,49,50,53,56,55,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,139,100,254,42,13,0,16,1,101,112,114,45,49,50,53,48,53,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,138,120,32,80,14,0,16,1,109,112,114,45,49,50,52,51,55,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,18,231,199,161,11,0,64,0,109,112,114,45,49,50,52,51,56,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,107,212,115,101,11,0,64,0,109,112,114,45,49,50,52,51,57,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,229,109,191,19,11,0,64,0,109,112,114,45,49,50,52,51,55,46,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,18,231,199,161,15,0,64,0,109,112,114,45,49,50,52,51,56,46,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,107,212,115,101,15,0,64,0,109,112,114,45,49,50,52,51,57,46,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,229,109,191,19,15,0,64,0,51,49,55,45,48,49,50,54,97,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,130,25,188,42,5,0,16,1,11,0,0,0,255,255,255,0,0,0,0,0,12,0,0,0,255,255,127,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,11,0,0,0,1,15,7,0,80,252,6,0,11,0,0,0,1,15,8,0,16,242,7,0,11,0,0,0,1,15,9,0,104,236,7,0,11,0,0,0,1,15,5,0,176,51,4,0,11,0,0,0,1,15,4,0,56,24,4,0,11,0,0,0,1,15,15,0,128,230,7,0,11,0,0,0,1,15,1,0,72,216,3,0,11,0,0,0,1,15,2,0,24,188,3,0,11,0,0,0,1,15,3,0,176,162,3,0,11,0,0,0,1,15,6,0,120,211,6,0,11,0,0,0,1,15,14,0,184,164,6,0,11,0,0,0,1,15,13,0,80,74,6,0,11,0,0,0,1,15,12,0,192,32,6,0,11,0,0,0,1,15,11,0,192,234,2,0,11,0,0,0,1,15,10,0,32,242,5,0,11,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0])
.concat([11,0,0,0,1,240,112,0,80,252,6,0,11,0,0,0,1,240,128,0,16,242,7,0,11,0,0,0,1,240,144,0,104,236,7,0,11,0,0,0,1,240,80,0,176,51,4,0,11,0,0,0,1,240,64,0,56,24,4,0,11,0,0,0,1,240,240,0,128,230,7,0,11,0,0,0,1,240,16,0,72,216,3,0,11,0,0,0,1,240,32,0,24,188,3,0,11,0,0,0,1,240,48,0,176,162,3,0,11,0,0,0,1,240,96,0,120,211,6,0,11,0,0,0,1,240,224,0,184,164,6,0,11,0,0,0,1,240,208,0,80,74,6,0,11,0,0,0,1,240,192,0,192,32,6,0,11,0,0,0,1,240,176,0,192,234,2,0,11,0,0,0,1,240,160,0,32,242,5,0,11,0,0,0,1,240,0,0,208,236,2,0,0,0,0,0,254,0,8,0,0,111,8,0,12,0,0,0,1,7,7,0,192,255,2,0,12,0,0,0,1,7,6,0,208,75,4,0,12,0,0,0,1,7,5,0,8,49,4,0,12,0,0,0,1,7,4,0,152,21,4,0,12,0,0,0,1,7,3,0,72,246,3,0,12,0,0,0,1,7,2,0,72,0,3,0,12,0,0,0,1,7,1,0,64,47,7,0,12,0,0,0,1,7,0,0,232,99,5,0,0,0,0,0,254,0,8,0,96,77,8,0,12,0,0,0,1,56,56,0,192,255,2,0,12,0,0,0,1,56,48,0,208,75,4,0,12,0,0,0,1,56,40,0,8,49,4,0,12,0,0,0,1,56,32,0,152,21,4,0,12,0,0,0,1,56,24,0,72,246,3,0,12,0,0,0,1,56,16,0,72,0,3,0,12,0,0,0,1,56,8,0,64,47,7,0,12,0,0,0,1,56,0,0,232,99,5,0,0,0,0,0,254,0,3,0,200,30,2,0,12,0,0,0,1,192,192,0,240,149,7,0,12,0,0,0,1,192,128,0,80,46,8,0,12,0,0,0,1,192,64,0,120,97,1,0,115,102,122,106,46,48,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,32,65,68,245,1,0,16,1,115,102,122,46,48,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,229,176,115,139,1,0,16,1,115,102,122,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,77,84,16,8,1,0,16,1,115,102,122,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,56,143,110,128,1,0,16,1,115,102,122,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,179,253,254,144,5,0,32,0,115,102,122,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,72,201,84,83,5,0,32,0,115,102,122,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,144,231,161,65,5,0,32,0,115,102,122,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,152,223,73,165,5,0,32,0,115,102,122,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,125,236,255,255,10,0,16,1,115,102,122,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,8,106,244,69,10,0,16,1,115,102,122,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,205,147,176,196,12,0,64,0,115,102,122,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,180,196,219,139,12,0,64,0,115,102,122,104,46,48,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,224,203,8,110,1,0,16,1,115,102,122,46,48,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,213,172,144,187,1,0,16,1,115,102,122,46,48,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,77,84,16,8,1,0,16,1,115,102,122,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,56,143,110,128,1,0,16,1,115,102,122,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,179,253,254,144,5,0,32,0,115,102,122,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,72,201,84,83,5,0,32,0,115,102,122,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,144,231,161,65,5,0,32,0,115,102,122,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,152,223,73,165,5,0,32,0,115,102,122,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,125,236,255,255,10,0,16,1,115,102,122,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,8,106,244,69,10,0,16,1,115,102,122,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,205,147,176,196,12,0,64,0,115,102,122,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,180,196,219,139,12,0,64,0,115,102,122,98,46,48,51,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,212,98,136,52,1,0,16,1,115,102,122,98,46,48,52,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,128,36,155,141,1,0,16,1,115,102,122,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,77,84,16,8,1,0,16,1,115,102,122,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,56,143,110,128,1,0,16,1,115,102,122,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,179,253,254,144,5,0,32,0,115,102,122,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,72,201,84,83,5,0,32,0,115,102,122,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,144,231,161,65,5,0,32,0,115,102,122,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,152,223,73,165,5,0,32,0,115,102,122,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,125,236,255,255,10,0,16,1,115,102,122,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,8,106,244,69,10,0,16,1,115,102,122,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,205,147,176,196,12,0,64,0,115,102,122,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,180,196,219,139,12,0,64,0,115,102,122,97,46,48,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,217,190,145,202,1,0,16,1,115,102,122,46,48,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,165,233,153,95,1,0,16,1,115,102,122,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,77,84,16,8,1,0,16,1,115,102,122,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,56,143,110,128,1,0,16,1,115,102,122,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,179,253,254,144,5,0,32,0,115,102,122,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,72,201,84,83,5,0,32,0,115,102,122,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,144,231,161,65,5,0,32,0,115,102,122,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,152,223,73,165,5,0,32,0,115,102,122,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,125,236,255,255,10,0,16,1,115,102,122,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,8,106,244,69,10,0,16,1,115,102,122,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,205,147,176,196,12,0,64,0,115,102,122,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,180,196,219,139,12,0,64,0,26,0,0,0,255,255,255,0,0,0,0,0,27,0,0,0,255,255,255,0,0,0,0,0,28,0,0,0,255,255,248,0,0,0,0,0,29,0,0,0,255,255,127,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,26,0,0,0,1,1,1,0,96,135,7,0,26,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,40,241,1,0,26,0,0,0,1,2,0,0,96,135,7,0,26,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,2,0,216,82,6,0,26,0,0,0,1,16,0,0,248,81,6,0,26,0,0,0,1,16,16,0,248,38,7,0,0,0,0,0,254,0,2,0,168,234,7,0,26,0,0,0,1,32,32,0,96,135,7,0,26,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,72,4,1,0,26,0,0,0,1,64,64,0,96,135,7,0,26,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,8,0,200,87,7,0,27,0,0,0,1,7,0,0,80,252,6,0,27,0,0,0,1,7,1,0,16,242,7,0,27,0,0,0,1,7,2,0,104,236,7,0,27,0,0,0,1,7,7,0,128,230,7,0,27,0,0,0,1,7,6,0,184,164,6,0,27,0,0,0,1,7,5,0,80,74,6,0,27,0,0,0,1,7,4,0,192,32,6,0,27,0,0,0,1,7,3,0,32,242,5,0,0,0,0,0,254,0,8,0,160,123,6,0,27,0,0,0,1,56,0,0,80,252,6,0,27,0,0,0,1,56,8,0,16,242,7,0,27,0,0,0,1,56,16,0,104,236,7,0,27,0,0,0,1,56,56,0,128,230,7,0,27,0,0,0,1,56,48,0,184,164,6,0,27,0,0,0,1,56,40,0,80,74,6,0,27,0,0,0,1,56,32,0,192,32,6,0,27,0,0,0,1,56,24,0,32,242,5,0,0,0,0,0,254,0,6,0,208,80,1,0,28,0,0,0,1,56,56,0,208,138,2,0,28,0,0,0,1,56,48,0,112,150,2,0,28,0,0,0,1,56,40,0,48,61,1,0,28,0,0,0,1,56,32,0,40,172,5,0,28,0,0,0,1,56,24,0,184,44,1,0,28,0,0,0,1,56,8,0,152,36,1,0,0,0,0,0,254,0,2,0,120,26,1,0,28,0,0,0,1,64,0,0,152,21,4,0,28,0,0,0,1,64,64,0,208,75,4,0,0,0,0,0,254,0,6,0,72,6,1,0,29,0,0,0,1,7,7,0,208,138,2,0,29,0,0,0,1,7,6,0,112,150,2,0,29,0,0,0,1,7,5,0,48,61,1,0,29,0,0,0,1,7,4,0,40,172,5,0,29,0,0,0,1,7,3,0,184,44,1,0,29,0,0,0,1,7,2,0,48,1,1,0,0,0,0,0,254,0,4,0,16,254,8,0,29,0,0,0,1,24,24,0,80,167,5,0,29,0,0,0,1,24,16,0,120,148,5,0,29,0,0,0,1,24,8,0,56,132,5,0,29,0,0,0,1,24,0,0,40,226,8,0,0,0,0,0,254,0,4,0,72,202,5,0,29,0,0,0,1,96,96,0,248,38,7,0,29,0,0,0,1,96,64,0,80,246,3,0,29,0,0,0,1,96,32,0,48,123,8,0,29,0,0,0,1,96,0,0,232,199,8,0,115,102,122,117,46,48,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,185,125,252,73,1,0,16,1,115,102,122,46,48,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,165,233,153,95,1,0,16,1,115,102,122,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,77,84,16,8,1,0,16,1,115,102,122,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,56,143,110,128,1,0,16,1,115,102,122,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,179,253,254,144,5,0,32,0,115,102,122,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,72,201,84,83,5,0,32,0,115,102,122,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,144,231,161,65,5,0,32,0,115,102,122,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,152,223,73,165,5,0,32,0,115,102,122,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,125,236,255,255,10,0,16,1,115,102,122,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,8,106,244,69,10,0,16,1,115,102,122,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,205,147,176,196,12,0,64,0,115,102,122,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,180,196,219,139,12,0,64,0,115,102,122,101,100,46,48,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,72,165,161,1,0,16,1,115,102,122,46,48,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,229,176,115,139,1,0,16,1,115,102,122,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,77,84,16,8,1,0,16,1,115,102,122,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,56,143,110,128,1,0,16,1,115,102,122,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,179,253,254,144,5,0,32,0,115,102,122,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,72,201,84,83,5,0,32,0,115,102,122,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,144,231,161,65,5,0,32,0,115,102,122,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,152,223,73,165,5,0,32,0,115,102,122,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,125,236,255,255,10,0,16,1,115,102,122,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,8,106,244,69,10,0,16,1,115,102,122,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,205,147,176,196,12,0,64,0,115,102,122,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,180,196,219,139,12,0,64,0,115,122,51,101,46,48,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,6,178,98,151,1,0,16,1,115,122,51,101,46,48,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,33,247,211,90,1,0,16,1,115,122,51,46,48,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,64,10,253,87,1,0,16,1,115,122,51,46,48,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,139,95,48,246,1,0,16,1,115,122,51,46,48,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,111,15,171,110,1,0,16,1,115,122,51,46,48,56,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,59,74,12,145,1,0,16,1,115,122,51,46,48,57,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,153,81,158,178,1,0,16,1,115,122,51,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,255,178,222,1,0,16,1,115,122,51,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,217,96,122,15,5,0,32,0,115,122,51,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,65,55,147,142,5,0,32,0,115,122,51,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,71,129,233,214,5,0,32,0,115,122,51,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,138,114,26,243,5,0,32,0,115,122,51,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,151,130,249,95,5,0,32,0,115,122,51,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,238,189,181,82,5,0,32,0,115,122,51,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,213,30,99,64,5,0,32,0,115,122,51,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,180,9,52,118,5,0,32,0,115,122,51,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,132,0,129,222,10,0,16,1,115,122,51,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,196,93,68,114,10,0,16,1,115,122,51,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,209,238,137,28,12,0,64,0,115,122,51,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,58,177,146,243,12,0,64,0,115,122,50,101,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,187,230,97,16,1,0,16,1,115,122,50,101,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,38,123,209,34,1,0,16,1,115,122,50,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,124,42,68,75,1,0,16,1,115,122,50,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,192,73,29,91,1,0,16,1,115,122,50,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,70,66,24,142,1,0,16,1,115,122,50,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,93,88,232,15,1,0,16,1,115,122,50,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,34,31,31,77,5,0,32,0,115,122,50,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,128,166,206,25,5,0,32,0,115,122,50,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,136,69,27,224,5,0,32,0,115,122,50,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,100,218,238,15,5,0,32,0,115,122,50,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,170,198,96,5,5,0,32,0,115,122,50,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,135,15,148,174,5,0,32,0,115,122,50,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,188,200,195,75,5,0,32,0,115,122,50,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,192,116,230,57,5,0,32,0,115,122,50,46,48,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,207,35,195,27,10,0,16,1,115,122,50,46,48,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,19,80,106,186,10,0,16,1,115,122,50,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,1,166,71,170,12,0,64,0,115,122,50,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,83,188,55,34,12,0,64,0,184,40,2,0,1,0,0,0,128,248,146,0,248,191,2,0,184,164,8,0,1,0,0,0,129,248,146,0,64,246,1,0,24,38,7,0,1,0,0,0,40,1,147,0,184,160,2,0,56,210,6,0,1,0,0,0,107,240,146,0,192,135,2,0,24,163,6,0,1,0,0,0,106,240,146,0,240,108,2,0,152,122,6,0,1,0,0,0,105,240,146,0,96,82,2,0,192,72,6,0,1,0,0,0,104,240,146,0,32,56,2,0,200,110,3,0,1,0,0,0,88,237,146,0,152,30,2,0,120,89,3,0,1,0,0,0,89,237,146,0,232,10,2,0,120,74,3,0,1,0,0,0,90,237,146,0,152,138,8,0,192,61,3,0,1,0,0,0,96,237,146,0,48,119,7,0,120,194,6,0,1,0,0,0,97,237,146,0,112,109,7,0,96,189,6,0,1,0,0,0,98,237,146,0,24,133,7,0,144,236,1,0,1,0,0,0,41,1,147,0,136,224,1,0,176,223,1,0,1,0,0,0,115,240,146,0,72,198,1,0,192,209,1,0,1,0,0,0,114,240,146,0,24,182,1,0,24,198,1,0,1,0,0,0,113,240,146,0,40,167,1,0,120,189,1,0,1,0,0,0,112,240,146,0,200,149,1,0,224,22,1,0,1,0,0,0,112,236,146,0,56,126,1,0,160,14,1,0,1,0,0,0,113,236,146,0,32,101,1,0,176,9,1,0,1,0,0,0,114,236,146,0,96,32,8,0,200,3,1,0,1,0,0,0,120,236,146,0,16,68,7,0,208,183,6,0,1,0,0,0,121,236,146,0,240,58,7,0,200,177,6,0,1,0,0,0,122,236,146,0,200,42,1,0,16,17,8,0,1,0,0,0,42,1,147,0,224,12,8,0,88,212,3,0,1,0,0,0,152,220,146,0,40,185,3,0,248,5,8,0,9,0,0,0,136,6,147,0,32,58,1,0,144,250,7,0,9,0,0,0,137,6,147,0,32,58,1,0,248,241,7,0,9,0,0,0,138,6,147,0,32,58,1,0,72,82,8,0,9,0,0,0,139,6,147,0,32,58,1,0,115,102,50,106,51,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,49,43,2,121,1,0,16,1,115,102,50,106,51,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,236,118,103,81,1,0,16,1,115,102,50,106,51,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,57,203,21,254,1,0,16,1,115,102,50,106,51,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,112,77,97,56,1,0,16,1,115,102,50,106,50,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,122,24,131,210,1,0,16,1,115,102,50,106,51,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,228,88,129,210,1,0,16,1,115,102,50,106,95,50,57,97,46,49,48,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,21,243,74,187,1,0,16,1,115,102,50,106,95,51,54,97,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,235,19,42,192,1,0,16,1,115,102,50,95,48,54,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,142,204,201,34,4,0,32,0,115,102,50,95,48,56,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,232,59,33,87,4,0,32,0,115,102,50,95,48,53,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,79,155,82,186,4,0,32,0,115,102,50,95,48,55,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,51,27,75,4,0,32,0,115,102,50,95,49,53,46,56,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,41,34,126,44,4,0,32,0,115,102,50,95,49,55,46,49,48,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,23,143,84,181,4,0,32,0,115,102,50,95,49,52,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,18,67,184,20,4,0,32,0,115,102,50,95,49,54,46,57,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,154,216,156,94,4,0,32,0,115,102,50,95,50,53,46,56,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,88,250,75,153,4,0,32,0,115,102,50,95,50,55,46,49,48,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,157,173,102,62,4,0,32,0,115,102,50,95,50,52,46,55,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,250,190,193,4,0,32,0,115,102,50,95,50,54,46,57,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,49,200,39,6,4,0,32,0,115,102,50,95,48,57,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,27,58,130,164,3,0,16,0,115,102,50,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,32,22,127,5,0,64,0,115,102,50,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,229,173,190,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,115,116,102,50,57,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,197,9,51,4,0,0,0,8,105,111,98,49,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,99,54,51,50,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,112,146,189,15,0,0,0,8,27,0,0,0,255,255,0,0,0,0,0,0,28,0,0,0,255,255,3,0,0,0,0,0,29,0,0,0,255,255,96,0,0,0,0,0,0,0,0,0,254,0,8,0,200,87,7,0,27,0,0,0,1,7,7,0,80,252,6,0,27,0,0,0,1,7,6,0,16,242,7,0,27,0,0,0,1,7,5,0,104,236,7,0,27,0,0,0,1,7,0,0,128,230,7,0,27,0,0,0,1,7,1,0,184,164,6,0,27,0,0,0,1,7,2,0,80,74,6,0,27,0,0,0,1,7,3,0,192,32,6,0,27,0,0,0,1,7,4,0,32,242,5,0,0,0,0,0,254,0,8,0,160,123,6,0,27,0,0,0,1,56,56,0,80,252,6,0,27,0,0,0,1,56,48,0,16,242,7,0,27,0,0,0,1,56,40,0,104,236,7,0,27,0,0,0,1,56,0,0,128,230,7,0,27,0,0,0,1,56,8,0,184,164,6,0,27,0,0,0,1,56,16,0,80,74,6,0,27,0,0,0,1,56,24,0,192,32,6,0,27,0,0,0,1,56,32,0,32,242,5,0,0,0,0,0,254,0,2,0,64,232,1,0,27,0,0,0,1,64,0,0,96,135,7,0,27,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,8,0,72,202,5,0,28,0,0,0,1,7,0,0,72,198,6,0,28,0,0,0,1,7,1,0,208,75,4,0,28,0,0,0,1,7,2,0,8,49,4,0,28,0,0,0,1,7,3,0,72,195,6,0,28,0,0,0,1,7,4,0,72,246,3,0,28,0,0,0,1,7,5,0,72,0,3,0,28,0,0,0,1,7,6,0,64,47,7,0,28,0,0,0,1,7,7,0,48,173,6,0,0,0,0,0,254,0,2,0,88,41,7,0,28,0,0,0,1,8,0,0,248,164,1,0,28,0,0,0,1,8,8,0,56,163,1,0,0,0,0,0,254,0,2,0,16,227,4,0,29,0,0,0,1,4,0,0,96,135,7,0,29,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,254,0,2,0,72,4,1,0,29,0,0,0,1,8,0,0,96,135,7,0,29,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,29,0,0,0,1,16,0,0,96,135,7,0,29,0,0,0,1,16,16,0,152,182,7,0,0,0,0,0,254,0,2,0,40,111,8,0,29,0,0,0,1,32,0,0,96,135,7,0,29,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,29,0,0,0,1,64,0,0,96,135,7,0,29,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,168,79,2,0,29,0,0,0,1,128,0,0,32,182,8,0,29,0,0,0,1,128,128,0,80,251,6,0,115,102,50,101,95,51,48,98,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,81,112,189,87,1,0,16,1,115,102,50,101,95,51,55,98,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,221,28,105,98,1,0,16,1,115,102,50,101,95,51,49,98,46,49,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,61,20,115,166,1,0,16,1,115,102,50,101,95,51,56,98,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,247,206,44,76,1,0,16,1,117,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,57,63,252,92,1,0,16,1,117,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,182,36,221,71,1,0,16,1,115,102,50,95,50,57,98,46,49,48,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,21,243,74,187,1,0,16,1,115,102,50,95,51,54,98,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,235,19,42,192,1,0,16,1,115,102,50,95,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,142,204,201,34,4,0,32,0,115,102,50,95,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,232,59,33,87,4,0,32,0,115,102,50,95,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,79,155,82,186,4,0,32,0,115,102,50,95,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,51,27,75,4,0,32,0,115,102,50,95,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,41,34,126,44,4,0,32,0,115,102,50,95,49,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,23,143,84,181,4,0,32,0,115,102,50,95,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,18,67,184,20,4,0,32,0,115,102,50,95,49,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,154,216,156,94,4,0,32,0,115,102,50,95,50,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,88,250,75,153,4,0,32,0,115,102,50,95,50,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,157,173,102,62,4,0,32,0,115,102,50,95,50,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,250,190,193,4,0,32,0,115,102,50,95,50,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,49,200,39,6,4,0,32,0,117,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,1,0,27,58,130,164,3,0,16,0,117,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,17,251,255,108,5,0,64,0,115,102,50,45,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,113,70,228,109,11,0,32,0,115,102,50,45,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,98,67,241,232,11,0,32,0,115,102,50,45,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,25,216,12,191,11,0,32,0,115,102,50,45,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,31,249,249,118,11,0,32,0,115,102,50,45,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,68,28,234,19,0,0,0,8,117,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,124,206,158,44,0,0,0,8,117,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,122,76,251,78,0,0,0,8,101,112,114,45,49,48,57,56,54,97,46,97,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,21,98,19,62,1,0,16,1,101,112,114,45,49,48,57,56,52,97,46,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,245,60,191,68,1,0,16,1,101,112,114,45,49,48,57,56,55,97,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,4,148,215,207,1,0,16,1,101,112,114,45,49,48,57,56,53,97,46,97,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,63,160,33,28,1,0,16,1,101,112,114,45,49,48,56,50,57,46,97,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,8,171,49,164,1,0,16,1,101,112,114,45,49,48,56,50,54,46,97,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,183,228,216,46,1,0,16,1,101,112,114,45,49,48,55,55,50,46,98,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,99,43,24,2,0,32,0,101,112,114,45,49,48,55,55,51,46,98,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,162,41,113,143,2,0,32,0,101,112,114,45,49,48,55,55,52,46,98,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,31,65,9,68,2,0,32,0,49,48,55,54,48,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,123,50,222,112,3,0,32,0,49,48,55,54,51,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,181,92,236,153,3,0,32,0,49,48,55,54,49,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,13,248,128,78,3,0,32,0,49,48,55,54,52,46,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,213,165,45,96,3,0,32,0,49,48,55,54,50,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,120,95,75,70,3,0,32,0,49,48,55,54,53,46,98,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,87,160,115,10,3,0,32,0,49,48,55,55,53,46,97,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,168,85,189,76,4,0,16,1,51,49,55,45,48,48,50,56,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,178,7,83,154,5,0,16,1,21,0,0,0,255,255,253,0,0,0,0,0,22,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,104,159,3,0,21,0,0,0,1,1,1,0,56,111,3,0,21,0,0,0,1,1,0,0,104,134,3,0,0,0,0,0,254,0,2,0,168,234,7,0,21,0,0,0,1,2,2,0,96,135,7,0,21,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,21,0,0,0,1,12,8,0,208,75,4,0,21,0,0,0,1,12,12,0,8,49,4,0,21,0,0,0,1,12,4,0,152,21,4,0,21,0,0,0,1,12,0,0,64,96,7,0,0,0,0,0,254,0,4,0,72,202,5,0,21,0,0,0,1,48,32,0,80,246,3,0,21,0,0,0,1,48,48,0,248,38,7,0,21,0,0,0,1,48,16,0,112,212,3,0,21,0,0,0,1,48,0,0,248,160,5,0,0,0,0,0,254,0,4,0,64,37,5,0,21,0,0,0,1,192,128,0,200,201,3,0,21,0,0,0,1,192,192,0,8,49,6,0,21,0,0,0,1,192,64,0,160,191,4,0,21,0,0,0,1,192,0,0,120,7,5,0,0,0,0,0,254,0,16,0,200,87,7,0,22,0,0,0,1,15,7,0,80,252,6,0,22,0,0,0,1,15,8,0,16,242,7,0,22,0,0,0,1,15,9,0,104,236,7,0,22,0,0,0,1,15,5,0,176,51,4,0,22,0,0,0,1,15,4,0,56,24,4,0,22,0,0,0,1,15,15,0,128,230,7,0,22,0,0,0,1,15,1,0,72,216,3,0,22,0,0,0,1,15,2,0,24,188,3,0,22,0,0,0,1,15,3,0,176,162,3,0,22,0,0,0,1,15,6,0,120,211,6,0,22,0,0,0,1,15,14,0,184,164,6,0,22,0,0,0,1,15,13,0,80,74,6,0,22,0,0,0,1,15,12,0,192,32,6,0,22,0,0,0,1,15,11,0,192,234,2,0,22,0,0,0,1,15,10,0,32,242,5,0,22,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,22,0,0,0,1,240,112,0,80,252,6,0,22,0,0,0,1,240,128,0,16,242,7,0,22,0,0,0,1,240,144,0,104,236,7,0,22,0,0,0,1,240,80,0,176,51,4,0,22,0,0,0,1,240,64,0,56,24,4,0,22,0,0,0,1,240,240,0,128,230,7,0,22,0,0,0,1,240,16,0,72,216,3,0,22,0,0,0,1,240,32,0,24,188,3,0,22,0,0,0,1,240,48,0,176,162,3,0,22,0,0,0,1,240,96,0,120,211,6,0,22,0,0,0,1,240,224,0,184,164,6,0,22,0,0,0,1,240,208,0,80,74,6,0,22,0,0,0,1,240,192,0,192,32,6,0,22,0,0,0,1,240,176,0,192,234,2,0,22,0,0,0,1,240,160,0,32,242,5,0,22,0,0,0,1,240,0,0,208,236,2,0,0,0,0,0,99,48,57,45,52,51,46,52,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,62,52,169,32,2,0,16,1,99,48,57,45,52,52,46,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,138,51,36,117,2,0,16,1,99,48,57,45,52,49,46,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,17,127,71,131,2,0,16,1,99,48,57,45,51,57,46,52,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,185,188,135,222,2,0,16,1,99,48,57,45,51,51,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,91,108,78,207,6,0,16,1,99,48,57,45,51,50,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,25,55,113,164,6,0,16,1,99,48,57,45,51,52,46,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,81,49,27,162,9,0,16,1,99,48,57,45,48,53,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,240,56,11,137,11,0,32,0,99,48,57,45,48,52,46,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,155,60,187,44,17,0,32,0,99,48,57,45,48,50,46,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,137,3,58,168,17,0,32,0,99,48,57,45,48,51,46,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,128,14,29,163,17,0,32,0,99,48,57,45,48,49,46,53,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,16,234,191,100,17,0,32,0,99,48,57,45,48,55,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,43,200,59,150,22,0,32,0,99,48,57,45,48,54,46,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,123,109,223,18,23,0,32,0,99,48,57,45,49,52,46,52,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,70,191,120,173,24,0,64,0,99,48,57,45,49,51,46,52,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,211,65,124,213,24,0,64,0,99,48,57,45,49,50,46,52,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,165,159,201,86,24,0,64,0,99,48,57,45,49,53,46,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,149,144,59,230,25,0,64,0,99,48,57,45,49,54,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,246,166,69,114,0,0,0,8,99,48,57,45,50,48,46,55,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,128,253,143,205,0,0,0,8,99,48,57,45,50,51,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,48,31,248,251,0,0,0,8,13,0,0,0,255,255,254,0,0,0,0,0,14,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,13,0,0,0,1,1,1,0,80,46,8,0,13,0,0,0,1,1,0,0,120,97,1,0,0,0,0,0,254,0,2,0,232,75,4,0,13,0,0,0,1,4,4,0,96,135,7,0,13,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,13,0,0,0,1,8,0,0,96,135,7,0,13,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,32,4,2,0,13,0,0,0,1,48,0,0,80,252,6,0,13,0,0,0,1,48,16,0,16,242,7,0,13,0,0,0,1,48,32,0,104,236,7,0,13,0,0,0,1,48,48,0,128,230,7,0,0,0,0,0,254,0,4,0,168,248,6,0,13,0,0,0,1,192,0,0,16,242,7,0,13,0,0,0,1,192,64,0,104,236,7,0,13,0,0,0,1,192,128,0,128,230,7,0,13,0,0,0,1,192,192,0,80,75,3,0,0,0,0,0,254,0,4,0,72,202,5,0,14,0,0,0,1,3,2,0,80,246,3,0,14,0,0,0,1,3,3,0,248,38,7,0,14,0,0,0,1,3,1,0,112,212,3,0,14,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,136,20,8,0,14,0,0,0,1,12,8,0,48,17,8,0,14,0,0,0,1,12,4,0,248,12,8,0,14,0,0,0,1,12,12,0,208,6,8,0,14,0,0,0,1,12,0,0,112,2,8,0,0,0,0,0,254,0,2,0,216,250,7,0,14,0,0,0,1,16,16,0,8,49,4,0,14,0,0,0,1,16,0,0,72,246,3,0,0,0,0,0,254,0,2,0,152,230,7,0,14,0,0,0,1,32,0,0,160,226,7,0,14,0,0,0,1,32,32,0,24,223,7,0,0,0,0,0,254,0,2,0,48,219,7,0,14,0,0,0,1,64,0,0,96,135,7,0,14,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,104,215,7,0,14,0,0,0,1,128,128,0,248,38,7,0,14,0,0,0,1,128,0,0,112,134,3,0,0,0,0,0,99,48,57,45,51,55,46,52,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,23,234,236,15,2,0,16,1,99,48,57,45,51,56,46,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,155,189,110,228,2,0,16,1,99,48,57,45,52,48,46,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,171,46,78,26,2,0,16,1,99,48,57,45,51,57,46,52,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,185,188,135,222,2,0,16,1,99,48,57,45,51,51,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,91,108,78,207,6,0,16,1,99,48,57,45,51,50,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,25,55,113,164,6,0,16,1,99,48,57,45,50,55,46,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,202,29,22,205,9,0,16,1,99,48,57,45,48,53,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,240,56,11,137,11,0,32,0,99,48,57,45,48,52,46,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,155,60,187,44,17,0,32,0,99,48,57,45,48,50,46,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,137,3,58,168,17,0,32,0,99,48,57,45,48,51,46,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,128,14,29,163,17,0,32,0,99,48,57,45,48,49,46,53,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,16,234,191,100,17,0,32,0,99,48,57,45,48,55,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,43,200,59,150,22,0,32,0,99,48,57,45,48,54,46,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,123,109,223,18,23,0,32,0,99,48,57,45,49,48,46,52,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,70,191,120,173,24,0,64,0,99,48,57,45,48,57,46,52,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,92,101,106,24,0,64,0,99,48,57,45,48,56,46,52,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,22,195,223,125,24,0,64,0,99,48,57,45,49,49,46,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,225,17,26,107,25,0,64,0,99,48,57,45,49,54,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,246,166,69,114,0,0,0,8,99,48,57,45,50,48,46,55,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,128,253,143,205,0,0,0,8,99,48,57,45,50,51,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,48,31,248,251,0,0,0,8,13,0,0,0,255,255,254,0,0,0,0,0,14,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,13,0,0,0,1,1,1,0,80,46,8,0,13,0,0,0,1,1,0,0,120,97,1,0,0,0,0,0,254,0,2,0,232,75,4,0,13,0,0,0,1,4,4,0,96,135,7,0,13,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,13,0,0,0,1,8,0,0,96,135,7,0,13,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,13,0,0,0,1,48,16,0,104,236,7,0,13,0,0,0,1,48,48,0,128,230,7,0,13,0,0,0,1,48,0,0,120,211,6,0,13,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,13,0,0,0,1,192,64,0,104,236,7,0,13,0,0,0,1,192,192,0,128,230,7,0,13,0,0,0,1,192,0,0,120,211,6,0,13,0,0,0,1,192,128,0,184,164,6,0,0,0,0,0,254,0,4,0,72,202,5,0,14,0,0,0,1,3,2,0,80,246,3,0,14,0,0,0,1,3,3,0,248,38,7,0,14,0,0,0,1,3,1,0,112,212,3,0,14,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,136,20,8,0,14,0,0,0,1,12,8,0,48,17,8,0,14,0,0,0,1,12,4,0,248,12,8,0,14,0,0,0,1,12,12,0,208,6,8,0,14,0,0,0,1,12,0,0,112,2,8,0,0,0,0,0,254,0,2,0,216,250,7,0,14,0,0,0,1,16,16,0,8,49,4,0,14,0,0,0,1,16,0,0,72,246,3,0,0,0,0,0,254,0,2,0,152,230,7,0,14,0,0,0,1,32,0,0,160,226,7,0,14,0,0,0,1,32,32,0,24,223,7,0,0,0,0,0,254,0,2,0,48,219,7,0,14,0,0,0,1,64,0,0,96,135,7,0,14,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,104,215,7,0,14,0,0,0,1,128,128,0,248,38,7,0,14,0,0,0,1,128,0,0,112,134,3,0,0,0,0,0,99,48,57,45,50,56,46,52,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,173,186,13,99,2,0,16,1,99,48,57,45,51,48,46,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,125,169,177,104,2,0,16,1,99,48,57,45,51,54,46,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,186,124,228,89,2,0,16,1,99,48,57,45,51,49,46,52,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,191,31,43,150,2,0,16,1,99,48,57,45,51,51,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,91,108,78,207,6,0,16,1,99,48,57,45,51,50,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,25,55,113,164,6,0,16,1,99,48,57,45,51,52,46,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,81,49,27,162,9,0,16,1,99,48,57,45,48,53,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,240,56,11,137,11,0,32,0,99,48,57,45,48,52,46,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,8,0,155,60,187,44,17,0,32,0,99,48,57,45,48,50,46,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,137,3,58,168,17,0,32,0,99,48,57,45,48,51,46,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,128,14,29,163,17,0,32,0,99,48,57,45,48,49,46,53,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,16,234,191,100,17,0,32,0,99,48,57,45,48,55,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,43,200,59,150,22,0,32,0,99,48,57,45,48,54,46,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,123,109,223,18,23,0,32,0,99,48,57,45,49,52,46,52,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,70,191,120,173,24,0,64,0,99,48,57,45,49,51,46,52,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,211,65,124,213,24,0,64,0,99,48,57,45,49,50,46,52,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,165,159,201,86,24,0,64,0,99,48,57,45,49,53,46,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,149,144,59,230,25,0,64,0,99,48,57,45,49,54,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,246,166,69,114,0,0,0,8,99,48,57,45,50,48,46,55,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,128,253,143,205,0,0,0,8,99,48,57,45,50,51,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,48,31,248,251,0,0,0,8,49,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,46,35,244,158,0,0,16,1,50,46,105,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,191,251,198,242,0,0,16,1,51,46,105,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,150,92,15,246,0,0,32,0,53,46,105,99,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,120,206,111,5,0,0,32,0,52,46,105,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,180,231,148,8,0,0,32,0,57,46,105,99,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,243,84,173,14,0,0,32,0,54,46,105,99,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,218,97,239,150,0,0,32,0,55,46,105,99,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,243,184,149,10,0,0,80,0,56,46,105,99,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,102,226,112,75,0,0,64,0,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,252,0,0,0,0,0,0,0,0,0,254,0,8,0,200,87,7,0,19,0,0,0,1,7,0,0,104,54,4,0,19,0,0,0,1,7,1,0,80,252,6,0,19,0,0,0,1,7,2,0,16,242,7,0,19,0,0,0,1,7,4,0,104,236,7,0,19,0,0,0,1,7,7,0,80,245,6,0,19,0,0,0,1,7,6,0,8,201,6,0,19,0,0,0,1,7,5,0,200,197,6,0,19,0,0,0,1,7,3,0,152,194,6,0,0,0,0,0,254,0,8,0,160,123,6,0,19,0,0,0,1,56,0,0,104,54,4,0,19,0,0,0,1,56,8,0,80,252,6,0,19,0,0,0,1,56,16,0,16,242,7,0,19,0,0,0,1,56,32,0,104,236,7,0,19,0,0,0,1,56,56,0,80,245,6,0,19,0,0,0,1,56,48,0,104,236,7,0,19,0,0,0,1,56,40,0,16,242,7,0,19,0,0,0,1,56,24,0,80,252,6,0,0,0,0,0,254,0,2,0,192,208,5,0,19,0,0,0,1,64,64,0,192,255,2,0,19,0,0,0,1,64,0,0,208,75,4,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,3,3,0,192,255,2,0,20,0,0,0,1,3,2,0,208,75,4,0,20,0,0,0,1,3,1,0,8,49,4,0,20,0,0,0,1,3,0,0,152,21,4,0,0,0,0,0,254,0,2,0,144,212,8,0,20,0,0,0,1,16,16,0,96,135,7,0,20,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,20,0,0,0,1,32,0,0,96,135,7,0,20,0,0,0,1,32,32,0,152,182,7,0,20,0,0,0,255,255,0,0,0,0,0,0,21,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,4,0,200,87,7,0,20,0,0,0,1,3,0,0,128,230,7,0,20,0,0,0,1,3,2,0,184,164,6,0,20,0,0,0,1,3,1,0,80,74,6,0,20,0,0,0,1,3,3,0,192,32,6,0,0,0,0,0,254,0,4,0,160,123,6,0,20,0,0,0,1,12,12,0,80,252,6,0,20,0,0,0,1,12,4,0,16,242,7,0,20,0,0,0,1,12,8,0,104,236,7,0,20,0,0,0,1,12,0,0,128,230,7,0,0,0,0,0,254,0,2,0,128,129,4,0,20,0,0,0,1,16,0,0,208,75,4,0,20,0,0,0,1,16,16,0,8,49,4,0,0,0,0,0,254,0,2,0,112,31,4,0,20,0,0,0,1,20,0,0,232,2,4,0,20,0,0,0,1,20,20,0,136,225,3,0,0,0,0,0,254,0,2,0,144,212,8,0,20,0,0,0,1,128,0,0,96,135,7,0,20,0,0,0,1,128,128,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,21,0,0,0,1,1,0,0,96,135,7,0,21,0,0,0,1,1,1,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,21,0,0,0,1,2,2,0,56,111,3,0,21,0,0,0,1,2,0,0,104,134,3,0,0,0,0,0,254,0,4,0,64,37,5,0,21,0,0,0,1,12,0,0,120,176,7,0,21,0,0,0,1,12,8,0,136,136,2,0,21,0,0,0,1,12,4,0,24,219,2,0,21,0,0,0,1,12,12,0,120,7,5,0,0,0,0,0,254,0,4,0,168,79,2,0,21,0,0,0,1,48,0,0,208,152,2,0,21,0,0,0,1,48,20,0,8,167,2,0,21,0,0,0,1,48,48,0,72,4,1,0,21,0,0,0,1,48,16,0,224,195,4,0,0,0,0,0,254,0,4,0,72,202,5,0,21,0,0,0,1,192,128,0,80,246,3,0,21,0,0,0,1,192,0,0,248,38,7,0,21,0,0,0,1,192,64,0,112,212,3,0,21,0,0,0,1,192,192,0,248,160,5,0,17,0,0,0,255,255,255,0,0,0,0,0,18,0,0,0,255,255,231,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,18,0,0,0,1,3,0,0,208,75,4,0,18,0,0,0,1,3,3,0,8,49,4,0,18,0,0,0,1,3,1,0,152,21,4,0,18,0,0,0,1,3,2,0,72,246,3,0,0,0,0,0,254,0,4,0,72,202,5,0,18,0,0,0,1,24,0,0,80,246,3,0,18,0,0,0,1,24,24,0,248,38,7,0,18,0,0,0,1,24,8,0,112,212,3,0,18,0,0,0,1,24,16,0,248,160,5,0,0,0,0,0,254,0,7,0,32,4,2,0,18,0,0,0,1,224,128,0,184,220,8,0,18,0,0,0,1,224,64,0,88,154,8,0,18,0,0,0,1,224,192,0,200,92,8,0,18,0,0,0,1,224,224,0,144,251,6,0,18,0,0,0,1,224,96,0,184,164,6,0,18,0,0,0,1,224,160,0,80,74,6,0,18,0,0,0,1,224,32,0,192,32,6,0,112,97,110,103,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,205,82,190,104,0,0,16,1,112,97,110,103,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,246,112,46,74,0,0,16,1,112,97,110,103,95,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,245,131,88,58,0,0,32,0,98,98,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,8,237,168,121,0,0,32,0,112,97,110,103,95,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,174,22,106,22,0,0,32,0,98,98,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,108,219,179,47,0,0,32,0,98,98,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,110,79,186,253,0,0,32,0,98,98,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,99,122,244,57,0,0,32,0,98,98,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,142,91,46,197,0,0,64,0,16,0,0,0,255,255,255,0,0,0,0,0,17,0,0,0,255,255,255,0,0,0,0,0,18,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,16,0,0,0,1,1,1,0,96,135,7,0,16,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,16,0,0,0,1,2,0,0,96,135,7,0,16,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,16,0,0,0,1,12,8,0,80,246,3,0,16,0,0,0,1,12,12,0,248,38,7,0,16,0,0,0,1,12,4,0,112,212,3,0,16,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,2,0,72,168,2,0,16,0,0,0,1,16,16,0,192,255,2,0,16,0,0,0,1,16,0,0,208,75,4,0,0,0,0,0,254,0,2,0,104,81,2,0,16,0,0,0,1,32,32,0,96,135,7,0,16,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,0,164,2,0,16,0,0,0,1,64,64,0,248,38,7,0,16,0,0,0,1,64,0,0,176,64,8,0,0,0,0,0,254,0,2,0,232,75,4,0,16,0,0,0,1,128,128,0,96,135,7,0,16,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,8,0,200,87,7,0,17,0,0,0,1,7,5,0,40,88,7,0,17,0,0,0,1,7,6,0,96,39,7,0,17,0,0,0,1,7,7,0,144,251,6,0,17,0,0,0,1,7,4,0,184,164,6,0,17,0,0,0,1,7,3,0,80,74,6,0,17,0,0,0,1,7,2,0,192,32,6,0,17,0,0,0,1,7,1,0,192,234,2,0,17,0,0,0,1,7,0,0,32,242,5,0,0,0,0,0,254,0,8,0,160,123,6,0,17,0,0,0,1,56,40,0,40,88,7,0,17,0,0,0,1,56,48,0,96,39,7,0,17,0,0,0,1,56,56,0,144,251,6,0,17,0,0,0,1,56,32,0,184,164,6,0,17,0,0,0,1,56,24,0,80,74,6,0,17,0,0,0,1,56,16,0,192,32,6,0,17,0,0,0,1,56,8,0,192,234,2,0,17,0,0,0,1,56,0,0,32,242,5,0,0,0,0,0,254,0,2,0,240,159,2,0,17,0,0,0,1,64,64,0,56,111,3,0,17,0,0,0,1,64,0,0,96,39,7,0,0,0,0,0,111,109,110,105,49,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,198,172,183,169,1,0,16,1,111,109,110,105,50,46,55,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,183,41,222,106,1,0,16,1,111,109,110,105,51,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,36,187,55,158,1,0,16,1,111,109,110,105,53,98,46,108,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,58,162,3,149,4,0,32,0,111,109,110,105,54,99,46,106,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,254,195,223,10,4,0,32,0,111,109,110,105,52,97,46,106,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,73,248,97,62,4,0,32,0,111,109,110,105,55,100,46,108,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,235,233,48,113,4,0,32,0,99,111,108,111,117,114,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,87,80,164,87,7,0,32,0,16,0,0,0,255,255,255,0,0,0,0,0,17,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,16,0,0,0,1,3,2,0,208,75,4,0,16,0,0,0,1,3,3,0,8,49,4,0,16,0,0,0,1,3,1,0,152,21,4,0,16,0,0,0,1,3,0,0,72,246,3,0,0,0,0,0,254,0,4,0,72,202,5,0,16,0,0,0,1,12,8,0,80,246,3,0,16,0,0,0,1,12,12,0,248,38,7,0,16,0,0,0,1,12,4,0,112,212,3,0,16,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,2,0,168,234,7,0,16,0,0,0,1,32,0,0,96,135,7,0,16,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,4,0,64,37,5,0,16,0,0,0,1,192,128,0,152,75,5,0,16,0,0,0,1,192,192,0,8,44,5,0,16,0,0,0,1,192,64,0,72,14,5,0,16,0,0,0,1,192,0,0,120,7,5,0,0,0,0,0,254,0,8,0,200,87,7,0,17,0,0,0,1,7,2,0,88,154,8,0,17,0,0,0,1,7,4,0,200,92,8,0,17,0,0,0,1,7,1,0,152,141,7,0,17,0,0,0,1,7,7,0,104,172,6,0,17,0,0,0,1,7,3,0,24,46,7,0,17,0,0,0,1,7,6,0,216,129,6,0,17,0,0,0,1,7,5,0,184,81,6,0,17,0,0,0,1,7,0,0,16,227,4,0,0,0,0,0,254,0,8,0,192,56,2,0,17,0,0,0,1,56,0,0,184,220,8,0,17,0,0,0,1,56,16,0,88,154,8,0,17,0,0,0,1,56,32,0,200,92,8,0,17,0,0,0,1,56,8,0,152,141,7,0,17,0,0,0,1,56,56,0,104,172,6,0,17,0,0,0,1,56,24,0,24,46,7,0,17,0,0,0,1,56,48,0,216,129,6,0,17,0,0,0,1,56,40,0,184,81,6,0,110,111,98,111,45,116,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,104,209,111,23,0,0,16,1,110,111,98,111,45,114,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,201,243,28,214,0,0,16,1,110,111,98,111,45,115,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,127,105,231,176,0,0,16,1,110,111,98,111,45,109,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,118,223,90,65,0,0,16,1,110,111,98,111,45,107,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,221,188,111,68,0,0,32,0,110,111,98,111,45,106,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,57,240,45,241,0,0,32,0,110,111,98,111,45,108,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,223,150,243,53,0,0,32,0,110,111,98,111,45,113,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,109,184,66,36,0,0,32,0,110,111,98,111,45,111,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,166,67,55,227,0,0,32,0,110,111,98,111,45,112,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,29,160,187,127,0,0,32,0,110,111,98,111,45,110,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,159,162,231,133,0,0,32,0,110,111,98,111,95,112,114,46,49,54,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,194,10,1,149,0,0,32,0,110,111,98,111,95,112,114,46,49,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,12,172,90,197,0,0,32,0,110,111,98,111,95,112,114,46,49,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,238,76,57,222,0,0,32,0,110,111,98,111,95,112,114,46,49,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,184,80,131,100,0,0,0,8,19,0,0,0,255,255,47,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,200,87,7,0,19,0,0,0,1,3,0,0,104,236,7,0,19,0,0,0,1,3,3,0,128,230,7,0,19,0,0,0,1,3,2,0,184,164,6,0,19,0,0,0,1,3,1,0,80,74,6,0,0,0,0,0,254,0,4,0,160,123,6,0,19,0,0,0,1,12,0,0,104,236,7,0,19,0,0,0,1,12,12,0,128,230,7,0,19,0,0,0,1,12,8,0,184,164,6,0,19,0,0,0,1,12,4,0,80,74,6,0,0,0,0,0,254,0,2,0,72,202,5,0,19,0,0,0,1,48,32,0,80,246,3,0,19,0,0,0,1,48,48,0,80,124,6,0,19,0,0,0,1,48,16,0,112,212,3,0,19,0,0,0,1,48,0,0,248,160,5,0,0,0,0,0,254,0,2,0,200,30,2,0,19,0,0,0,1,64,0,0,120,97,1,0,19,0,0,0,1,64,64,0,96,19,1,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,128,0,0,96,135,7,0,19,0,0,0,1,128,128,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,3,2,0,208,75,4,0,20,0,0,0,1,3,3,0,8,49,4,0,20,0,0,0,1,3,1,0,72,246,3,0,20,0,0,0,1,3,0,0,120,65,6,0,0,0,0,0,254,0,4,0,64,37,5,0,20,0,0,0,1,12,8,0,240,99,5,0,20,0,0,0,1,12,12,0,0,97,5,0,20,0,0,0,1,12,4,0,96,94,5,0,20,0,0,0,1,12,0,0,120,7,5,0,0,0,0,0,254,0,2,0,104,159,3,0,20,0,0,0,1,16,0,0,96,135,7,0,20,0,0,0,1,16,16,0,152,182,7,0,0,0,0,0,254,0,2,0,16,227,4,0,20,0,0,0,1,32,32,0,96,135,7,0,20,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,223,0,0,0,0,0,19,0,0,0,254,0,2,0,184,123,7,0,19,0,0,0,1,1,1,0,0,120,7,0,19,0,0,0,1,1,0,0,40,115,7,0,19,0,0,0,254,0,4,0,72,110,7,0,19,0,0,0,1,6,6,0,144,103,7,0,19,0,0,0,1,6,2,0,192,96,7,0,19,0,0,0,1,6,4,0,72,90,7,0,19,0,0,0,1,6,0,0,200,83,7,0,19,0,0,0,254,0,4,0,8,80,7,0,19,0,0,0,1,24,0,0,224,76,7,0,19,0,0,0,1,24,8,0,72,73,7,0,19,0,0,0,1,24,16,0,224,68,7,0,19,0,0,0,1,24,24,0,120,7,5,0,19,0,0,0,254,0,2,0,120,59,7,0,19,0,0,0,1,32,32,0,144,117,8,0,19,0,0,0,1,32,0,0,232,74,4,0,19,0,0,0,254,0,4,0,72,202,5,0,19,0,0,0,1,192,64,0,80,246,3,0,19,0,0,0,1,192,192,0,248,38,7,0,19,0,0,0,1,192,128,0,112,212,3,0,19,0,0,0,1,192,0,0,248,160,5,0,20,0,0,0,254,0,4,0,160,123,6,0,20,0,0,0,1,3,2,0,160,36,8,0,20,0,0,0,1,3,3,0,208,239,7,0,20,0,0,0,1,3,0,0,16,79,1,0,20,0,0,0,1,3,1,0,120,187,7,0,20,0,0,0,254,0,4,0,200,87,7,0,20,0,0,0,1,12,8,0,160,36,8,0,20,0,0,0,1,12,12,0,208,239,7,0,20,0,0,0,1,12,0,0,16,79,1,0,20,0,0,0,1,12,4,0,120,187,7,0,20,0,0,0,254,0,2,0,168,234,7,0,20,0,0,0,1,32,32,0,96,135,7,0,20,0,0,0,1,32,0,0,152,182,7,0,20,0,0,0,254,0,2,0,224,36,7,0,20,0,0,0,1,64,64,0,192,255,2,0,20,0,0,0,1,64,0,0,208,75,4,0,20,0,0,0,254,0,2,0,232,75,4,0,20,0,0,0,1,128,0,0,96,135,7,0,20,0,0,0,1,128,128,0,152,182,7,0,118,105,114,117,115,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,251,93,0,170,0,0,16,1,118,105,114,117,115,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,216,88,175,181,0,0,32,0,118,105,114,117,115,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,117,193,177,164,0,0,32,0,118,105,114,117,115,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,90,147,245,65,0,0,64,0,9,0,0,0,255,255,223,0,0,0,0,0,0,0,0,0,254,0,4,0,32,4,2,0,9,0,0,0,1,3,0,0,16,242,7,0,9,0,0,0,1,3,1,0,104,236,7,0,9,0,0,0,1,3,3,0,128,230,7,0,9,0,0,0,1,3,2,0,184,164,6,0,0,0,0,0,254,0,4,0,72,202,5,0,9,0,0,0,1,12,12,0,80,246,3,0,9,0,0,0,1,12,8,0,80,124,6,0,9,0,0,0,1,12,4,0,112,212,3,0,9,0,0,0,1,12,0,0,248,160,5,0,0,0,0,0,254,0,2,0,208,128,1,0,9,0,0,0,1,16,16,0,192,255,2,0,9,0,0,0,1,16,0,0,208,75,4,0,0,0,0,0,254,0,2,0,192,76,8,0,9,0,0,0,1,32,0,0,248,168,5,0,9,0,0,0,1,32,32,0,248,132,5,0,0,0,0,0,110,109,101,95,51,48,97,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,86,62,192,210,1,0,16,1,110,109,101,95,51,53,97,46,49,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,97,22,211,95,1,0,16,1,110,109,101,95,51,49,97,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,111,79,189,178,1,0,16,1,110,109,101,95,51,54,97,46,49,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,227,80,148,238,1,0,16,1,110,109,45,51,50,109,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,211,173,209,214,2,0,16,1,110,109,45,53,109,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,71,135,123,72,4,0,32,0,110,109,45,55,109,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,198,200,61,32,4,0,32,0,110,109,45,49,109,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,36,128,135,158,4,0,32,0,110,109,45,51,109,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,182,230,1,187,4,0,32,0,110,109,101,95,48,57,46,49,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,129,5,75,15,3,0,16,0,110,109,101,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,212,51,179,186,5,0,64,0,110,109,101,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,168,160,80,38,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,110,109,50,52,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,198,186,37,123,0,0,0,8,105,111,98,49,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,21,0,0,0,255,255,0,0,0,0,0,0,22,0,0,0,255,255,3,0,0,0,0,0,23,0,0,0,255,255,96,0,0,0,0,0,0,0,0,0,254,0,8,0,200,87,7,0,21,0,0,0,1,7,7,0,80,252,6,0,21,0,0,0,1,7,6,0,16,242,7,0,21,0,0,0,1,7,5,0,104,236,7,0,21,0,0,0,1,7,0,0,128,230,7,0,21,0,0,0,1,7,1,0,184,164,6,0,21,0,0,0,1,7,2,0,80,74,6,0,21,0,0,0,1,7,3,0,192,32,6,0,21,0,0,0,1,7,4,0,32,242,5,0,0,0,0,0,254,0,8,0,160,123,6,0,21,0,0,0,1,56,56,0,80,252,6,0,21,0,0,0,1,56,48,0,16,242,7,0,21,0,0,0,1,56,40,0,104,236,7,0,21,0,0,0,1,56,0,0,128,230,7,0,21,0,0,0,1,56,8,0,184,164,6,0,21,0,0,0,1,56,16,0,80,74,6,0,21,0,0,0,1,56,24,0,192,32,6,0,21,0,0,0,1,56,32,0,32,242,5,0,0,0,0,0,254,0,2,0,64,232,1,0,21,0,0,0,1,64,0,0,96,135,7,0,21,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,8,0,72,202,5,0,22,0,0,0,1,7,0,0,72,198,6,0,22,0,0,0,1,7,1,0,208,75,4,0,22,0,0,0,1,7,2,0,8,49,4,0,22,0,0,0,1,7,3,0,72,195,6,0,22,0,0,0,1,7,4,0,72,246,3,0,22,0,0,0,1,7,5,0,72,0,3,0,22,0,0,0,1,7,6,0,64,47,7,0,22,0,0,0,1,7,7,0,48,173,6,0,0,0,0,0,254,0,3,0,72,121,1,0,22,0,0,0,1,24,24,0,0,118,1,0,22,0,0,0,1,24,0,0,80,124,6,0,22,0,0,0,1,24,16,0,32,186,3,0,0,0,0,0,254,0,4,0,128,129,4,0,23,0,0,0,1,3,1,0,192,255,2,0,23,0,0,0,1,3,0,0,208,75,4,0,23,0,0,0,1,3,2,0,8,49,4,0,23,0,0,0,1,3,3,0,152,21,4,0,0,0,0,0,254,0,2,0,16,227,4,0,23,0,0,0,1,4,0,0,96,135,7,0,23,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,254,0,2,0,72,4,1,0,23,0,0,0,1,8,0,0,96,135,7,0,23,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,2,0,120,207,1,0,23,0,0,0,1,16,0,0,96,135,7,0,23,0,0,0,1,16,16,0,152,182,7,0,0,0,0,0,254,0,2,0,40,111,8,0,23,0,0,0,1,32,0,0,96,135,7,0,23,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,23,0,0,0,1,64,0,0,96,135,7,0,23,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,168,79,2,0,23,0,0,0,1,128,0,0,32,182,8,0,23,0,0,0,1,128,128,0,80,251,6,0,18,0,0,0,255,255,0,0,0,0,0,0,19,0,0,0,255,255,0,0,0,0,0,0,20,0,0,0,255,255,96,0,0,0,0,0,0,0,0,0,254,0,8,0,200,87,7,0,18,0,0,0,1,7,7,0,80,252,6,0,18,0,0,0,1,7,6,0,16,242,7,0,18,0,0,0,1,7,5,0,104,236,7,0,18,0,0,0,1,7,0,0,128,230,7,0,18,0,0,0,1,7,1,0,184,164,6,0,18,0,0,0,1,7,2,0,80,74,6,0,18,0,0,0,1,7,3,0,192,32,6,0,18,0,0,0,1,7,4,0,32,242,5,0,0,0,0,0,254,0,8,0,160,123,6,0,18,0,0,0,1,56,56,0,80,252,6,0,18,0,0,0,1,56,48,0,16,242,7,0,18,0,0,0,1,56,40,0,104,236,7,0,18,0,0,0,1,56,0,0,128,230,7,0,18,0,0,0,1,56,8,0,184,164,6,0,18,0,0,0,1,56,16,0,80,74,6,0,18,0,0,0,1,56,24,0,192,32,6,0,18,0,0,0,1,56,32,0,32,242,5,0,0,0,0,0,254,0,2,0,64,232,1,0,18,0,0,0,1,64,0,0,96,135,7,0,18,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,8,0,72,202,5,0,19,0,0,0,1,7,0,0,72,198,6,0,19,0,0,0,1,7,1,0,208,75,4,0,19,0,0,0,1,7,2,0,8,49,4,0,19,0,0,0,1,7,3,0,72,195,6,0,19,0,0,0,1,7,4,0,72,246,3,0,19,0,0,0,1,7,5,0,72,0,3,0,19,0,0,0,1,7,6,0,64,47,7,0,19,0,0,0,1,7,7,0,48,173,6,0,0,0,0,0,254,0,4,0,176,14,1,0,19,0,0,0,1,24,0,0,104,14,1,0,19,0,0,0,1,24,8,0,48,14,1,0,19,0,0,0,1,24,16,0,208,13,1,0,19,0,0,0,1,24,24,0,120,13,1,0,0,0,0,0,254,0,4,0,72,13,1,0,19,0,0,0,1,96,0,0,96,131,8,0,19,0,0,0,1,96,32,0,248,81,6,0,19,0,0,0,1,96,64,0,176,64,8,0,19,0,0,0,1,96,96,0,128,172,6,0,0,0,0,0,254,0,2,0,48,12,1,0,19,0,0,0,1,128,0,0,56,11,1,0,19,0,0,0,1,128,128,0,32,10,1,0,0,0,0,0,254,0,2,0,192,9,1,0,20,0,0,0,1,1,1,0,96,135,7,0,20,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,16,227,4,0,20,0,0,0,1,4,0,0,96,135,7,0,20,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,254,0,2,0,72,4,1,0,20,0,0,0,1,8,0,0,96,135,7,0,20,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,2,0,120,207,1,0,20,0,0,0,1,16,0,0,96,135,7,0,20,0,0,0,1,16,16,0,152,182,7,0,0,0,0,0,254,0,2,0,40,111,8,0,20,0,0,0,1,32,0,0,96,135,7,0,20,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,20,0,0,0,1,64,0,0,96,135,7,0,20,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,168,79,2,0,20,0,0,0,1,128,0,0,32,182,8,0,20,0,0,0,1,128,128,0,80,251,6,0,0,0,0,0,109,118,99,101,46,48,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,144,74,78,130,1,0,16,1,109,118,99,101,46,48,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,78,90,108,67,1,0,16,1,109,118,99,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,134,142,140,45,1,0,16,1,109,118,99,46,48,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,245,225,40,133,1,0,16,1,109,118,99,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,43,163,186,195,1,0,16,1,109,118,99,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,205,47,0,188,1,0,16,1,109,118,99,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,223,38,123,198,1,0,16,1,109,118,99,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,38,30,221,15,1,0,16,1,109,118,99,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,188,116,95,250,5,0,32,0,109,118,99,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,143,138,147,113,5,0,32,0,109,118,99,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,7,29,116,146,5,0,32,0,109,118,99,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,198,47,183,188,5,0,32,0,109,118,99,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,228,244,29,127,5,0,32,0,109,118,99,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,3,50,189,144,5,0,32,0,109,118,99,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,39,247,170,103,5,0,32,0,109,118,99,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,232,173,11,139,5,0,32,0,109,118,99,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,149,158,98,65,10,0,16,1,109,118,99,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,107,191,58,150,10,0,16,1,109,118,99,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,99,230,15,133,12,0,64,0,109,118,99,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,150,24,203,124,12,0,64,0,101,112,114,45,49,50,57,54,55,46,97,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,55,193,58,229,1,0,16,1,101,112,114,45,49,50,57,54,53,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,158,203,102,66,1,0,16,1,101,112,114,45,49,50,57,54,56,46,97,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,172,114,199,145,1,0,16,1,101,112,114,45,49,50,57,54,54,46,97,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,121,90,54,57,1,0,16,1,101,112,114,45,49,50,57,55,49,46,97,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,31,205,93,36,2,0,32,0,101,112,114,45,49,50,57,56,51,46,98,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,201,15,87,243,2,0,32,0,101,112,114,45,49,50,57,55,50,46,97,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,120,66,124,255,2,0,32,0,101,112,114,45,49,50,57,56,52,46,98,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,118,24,125,211,2,0,32,0,101,112,114,45,49,50,57,55,51,46,97,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,234,185,201,141,2,0,32,0,101,112,114,45,49,50,57,56,53,46,98,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,138,58,243,227,2,0,32,0,101,112,114,45,49,50,57,55,52,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,151,85,218,225,3,0,32,0,101,112,114,45,49,50,57,55,55,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,98,151,235,185,3,0,32,0,101,112,114,45,49,50,57,55,53,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,209,81,77,54,3,0,32,0,101,112,114,45,49,50,57,55,56,46,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,66,84,75,1,3,0,32,0,101,112,114,45,49,50,57,55,54,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,192,73,181,67,3,0,32,0,101,112,114,45,49,50,57,55,57,46,98,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,248,3,246,32,3,0,32,0,101,112,114,45,49,50,57,54,50,46,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,163,141,103,155,3,0,32,0,101,112,114,45,49,50,57,56,48,46,98,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,42,121,59,136,3,0,32,0,101,112,114,45,49,50,57,54,51,46,97,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,90,249,112,136,3,0,32,0,101,112,114,45,49,50,57,56,49,46,98,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,176,108,99,72,3,0,32,0,101,112,114,45,49,50,57,54,52,46,97,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,93,140,20,249,3,0,32,0,101,112,114,45,49,50,57,56,50,46,98,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,146,50,69,196,3,0,32,0,101,112,114,45,49,50,57,54,57,46,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,147,24,98,236,4,0,16,1,101,112,114,45,49,50,57,55,48,46,97,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,87,118,125,143,8,0,64,0,51,49,55,45,48,49,52,50,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,69,128,70,144,5,0,16,1,109,115,104,117,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,221,91,128,210,1,0,16,1,109,115,104,117,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,255,150,63,116,1,0,16,1,109,115,104,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,158,27,9,106,1,0,16,1,109,115,104,46,48,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,164,63,62,128,1,0,16,1,109,115,104,46,48,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,142,95,196,1,0,16,1,109,115,104,46,48,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,44,241,166,156,1,0,16,1,109,115,104,46,48,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,175,39,236,130,1,0,16,1,109,115,104,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,150,17,147,141,1,0,16,1,109,115,104,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,102,69,209,9,5,0,32,0,109,115,104,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,87,32,150,238,5,0,32,0,109,115,104,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,20,206,78,96,5,0,32,0,109,115,104,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,232,49,167,148,5,0,32,0,109,115,104,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,62,151,151,65,5,0,32,0,109,115,104,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,160,164,141,67,5,0,32,0,109,115,104,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,148,45,185,77,5,0,32,0,109,115,104,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,192,198,176,162,5,0,32,0,109,115,104,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,249,230,118,201,10,0,16,1,109,115,104,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,217,208,103,206,10,0,16,1,109,115,104,46,49,49,109,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,48,109,172,55,12,0,64,0,109,115,104,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,112,37,9,222,12,0,64,0,109,115,104,106,46,48,51,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,145,64,31,38,1,0,16,1,109,115,104,106,46,48,52,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,198,145,215,97,1,0,16,1,109,115,104,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,230,57,117,243,1,0,16,1,109,115,104,46,48,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,164,63,62,128,1,0,16,1,109,115,104,46,48,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,142,95,196,1,0,16,1,109,115,104,46,48,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,44,241,166,156,1,0,16,1,109,115,104,46,48,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,175,39,236,130,1,0,16,1,109,115,104,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,150,17,147,141,1,0,16,1,109,115,104,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,102,69,209,9,5,0,32,0,109,115,104,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,87,32,150,238,5,0,32,0,109,115,104,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,20,206,78,96,5,0,32,0,109,115,104,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,232,49,167,148,5,0,32,0,109,115,104,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,62,151,151,65,5,0,32,0,109,115,104,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,160,164,141,67,5,0,32,0,109,115,104,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,148,45,185,77,5,0,32,0,109,115,104,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,192,198,176,162,5,0,32,0,109,115,104,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,249,230,118,201,10,0,16,1,109,115,104,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,217,208,103,206,10,0,16,1,109,115,104,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,48,109,172,55,12,0,64,0,109,115,104,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,112,37,9,222,12,0,64,0,109,115,104,104,46,48,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,250,176,132,141,1,0,16,1,109,115,104,104,46,48,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,246,56,214,1,0,16,1,109,115,104,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,230,57,117,243,1,0,16,1,109,115,104,46,48,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,164,63,62,128,1,0,16,1,109,115,104,46,48,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,142,95,196,1,0,16,1,109,115,104,46,48,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,44,241,166,156,1,0,16,1,109,115,104,46,48,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,175,39,236,130,1,0,16,1,109,115,104,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,150,17,147,141,1,0,16,1,109,115,104,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,102,69,209,9,5,0,32,0,109,115,104,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,87,32,150,238,5,0,32,0,109,115,104,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,20,206,78,96,5,0,32,0,109,115,104,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,232,49,167,148,5,0,32,0,109,115,104,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,62,151,151,65,5,0,32,0,109,115,104,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,160,164,141,67,5,0,32,0,109,115,104,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,148,45,185,77,5,0,32,0,109,115,104,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,192,198,176,162,5,0,32,0,109,115,104,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,249,230,118,201,10,0,16,1,109,115,104,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,217,208,103,206,10,0,16,1,109,115,104,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,48,109,172,55,12,0,64,0,109,115,104,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,112,37,9,222,12,0,64,0,109,115,104,98,46,48,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,116,127,105,25,1,0,16,1,109,115,104,98,46,48,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,111,122,49,149,1,0,16,1,109,115,104,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,230,57,117,243,1,0,16,1,109,115,104,46,48,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,164,63,62,128,1,0,16,1,109,115,104,46,48,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,142,95,196,1,0,16,1,109,115,104,46,48,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,44,241,166,156,1,0,16,1,109,115,104,46,48,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,175,39,236,130,1,0,16,1,109,115,104,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,150,17,147,141,1,0,16,1,109,115,104,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,102,69,209,9,5,0,32,0,109,115,104,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,87,32,150,238,5,0,32,0,109,115,104,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,20,206,78,96,5,0,32,0,109,115,104,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,232,49,167,148,5,0,32,0,109,115,104,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,62,151,151,65,5,0,32,0,109,115,104,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,160,164,141,67,5,0,32,0,109,115,104,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,148,45,185,77,5,0,32,0,109,115,104,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,192,198,176,162,5,0,32,0,109,115,104,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,249,230,118,201,10,0,16,1,109,115,104,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,217,208,103,206,10,0,16,1,109,115,104,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,48,109,172,55,12,0,64,0,109,115,104,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,112,37,9,222,12,0,64,0,109,115,104,97,46,48,51,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,68,236,132,236,1,0,16,1,109,115,104,97,46,48,52,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,3,133,139,9,1,0,16,1,109,115,104,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,158,27,9,106,1,0,16,1,109,115,104,46,48,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,164,63,62,128,1,0,16,1,109,115,104,46,48,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,142,95,196,1,0,16,1,109,115,104,46,48,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,44,241,166,156,1,0,16,1,109,115,104,46,48,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,175,39,236,130,1,0,16,1,109,115,104,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,150,17,147,141,1,0,16,1,109,115,104,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,102,69,209,9,5,0,32,0,109,115,104,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,87,32,150,238,5,0,32,0,109,115,104,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,20,206,78,96,5,0,32,0,109,115,104,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,232,49,167,148,5,0,32,0,109,115,104,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,62,151,151,65,5,0,32,0,109,115,104,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,160,164,141,67,5,0,32,0,109,115,104,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,148,45,185,77,5,0,32,0,109,115,104,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,192,198,176,162,5,0,32,0,109,115,104,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,249,230,118,201,10,0,16,1,109,115,104,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,217,208,103,206,10,0,16,1,109,115,104,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,48,109,172,55,12,0,64,0,109,115,104,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,112,37,9,222,12,0,64,0,20,0,0,0,255,255,255,0,0,0,0,0,21,0,0,0,255,255,82,0,0,0,0,0,22,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,20,0,0,0,1,15,2,0,248,223,6,0,20,0,0,0,1,15,5,0,88,179,6,0,20,0,0,0,1,15,8,0,32,136,6,0,20,0,0,0,1,15,4,0,120,113,6,0,20,0,0,0,1,15,1,0,232,228,5,0,20,0,0,0,1,15,15,0,120,90,6,0,20,0,0,0,1,15,3,0,56,141,7,0,20,0,0,0,1,15,7,0,120,211,6,0,20,0,0,0,1,15,14,0,184,164,6,0,20,0,0,0,1,15,6,0,24,1,7,0,20,0,0,0,1,15,13,0,80,74,6,0,20,0,0,0,1,15,12,0,192,32,6,0,20,0,0,0,1,15,11,0,192,234,2,0,20,0,0,0,1,15,10,0,32,242,5,0,20,0,0,0,1,15,9,0,176,192,2,0,20,0,0,0,1,15,0,0,16,227,4,0,0,0,0,0,254,0,16,0,160,123,6,0,20,0,0,0,1,240,32,0,248,223,6,0,20,0,0,0,1,240,80,0,88,179,6,0,20,0,0,0,1,240,128,0,32,136,6,0,20,0,0,0,1,240,64,0,120,113,6,0,20,0,0,0,1,240,16,0,232,228,5,0,20,0,0,0,1,240,240,0,120,90,6,0,20,0,0,0,1,240,48,0,56,141,7,0,20,0,0,0,1,240,112,0,120,211,6,0,20,0,0,0,1,240,224,0,184,164,6,0,20,0,0,0,1,240,96,0,24,1,7,0,20,0,0,0,1,240,208,0,80,74,6,0,20,0,0,0,1,240,192,0,192,32,6,0,20,0,0,0,1,240,176,0,192,234,2,0,20,0,0,0,1,240,160,0,32,242,5,0,20,0,0,0,1,240,144,0,176,192,2,0,20,0,0,0,1,240,0,0,168,165,2,0,0,0,0,0,254,0,4,0,128,129,4,0,21,0,0,0,1,3,3,0,208,75,4,0,21,0,0,0,1,3,2,0,8,49,4,0,21,0,0,0,1,3,1,0,72,246,3,0,21,0,0,0,1,3,0,0,64,47,7,0,0,0,0,0,254,0,4,0,64,37,5,0,21,0,0,0,1,24,24,0,48,46,1,0,21,0,0,0,1,24,16,0,168,38,1,0,21,0,0,0,1,24,8,0,208,45,8,0,21,0,0,0,1,24,0,0,208,227,4,0,0,0,0,0,254,0,4,0,72,202,5,0,21,0,0,0,1,96,96,0,80,246,3,0,21,0,0,0,1,96,64,0,248,38,7,0,21,0,0,0,1,96,32,0,48,123,8,0,21,0,0,0,1,96,0,0,8,117,8,0,0,0,0,0,254,0,2,0,168,234,7,0,21,0,0,0,1,128,128,0,96,135,7,0,21,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,22,0,0,0,1,1,1,0,96,135,7,0,22,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,48,2,1,0,22,0,0,0,1,2,2,0,96,135,7,0,22,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,22,0,0,0,1,4,4,0,96,135,7,0,22,0,0,0,1,4,0,0,152,182,7,0,56,48,56,115,50,48,46,104,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,127,137,162,202,0,0,16,1,56,48,56,115,50,49,46,106,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,251,47,137,61,0,0,16,1,56,48,56,101,48,51,46,102,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,205,167,147,61,0,0,16,1,56,48,56,101,49,50,46,102,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,222,31,47,214,0,0,32,0,56,48,56,101,49,51,46,104,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,244,8,167,31,0,0,32,0,56,48,56,101,50,50,46,105,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,246,88,215,115,0,0,32,0,56,48,56,101,50,51,46,107,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,33,139,240,143,0,0,32,0,56,48,56,100,49,55,46,106,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,130,144,41,209,0,0,32,0,56,48,56,100,49,53,46,104,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,182,166,34,43,0,0,32,0,56,48,56,97,49,56,46,102,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,222,174,149,235,0,0,32,0,56,48,56,100,48,49,46,100,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,192,55,77,253,0,0,64,0,117,50,54,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,44,137,136,47,1,0,16,1,117,53,54,46,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,247,203,107,158,1,0,16,1,117,54,57,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,110,110,73,223,1,0,16,1,117,57,56,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,187,116,242,117,1,0,16,1,117,49,49,52,46,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,208,216,127,73,1,0,16,1,117,49,51,51,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,159,213,76,61,1,0,16,1,117,51,57,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,185,104,89,187,2,0,16,1,117,53,49,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,32,119,253,117,2,0,16,1,117,55,56,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,218,146,164,114,2,0,16,1,117,55,50,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,208,137,151,39,4,0,32,0,117,49,48,49,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,127,98,220,197,4,0,32,0,99,48,49,115,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,171,174,60,78,7,0,32,0,22,0,0,0,255,255,0,0,0,0,0,0,23,0,0,0,255,255,3,0,0,0,0,0,24,0,0,0,255,255,14,0,0,0,0,0,25,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,200,87,7,0,23,0,0,0,1,2,0,0,224,127,8,0,23,0,0,0,1,2,2,0,128,103,7,0,0,0,0,0,254,0,2,0,160,123,6,0,23,0,0,0,1,1,1,0,0,90,2,0,23,0,0,0,1,1,0,0,104,61,2,0,0,0,0,0,254,0,2,0,200,30,2,0,24,0,0,0,1,2,2,0,120,97,1,0,24,0,0,0,1,2,0,0,96,19,1,0,0,0,0,0,254,0,2,0,128,129,4,0,24,0,0,0,1,8,8,0,8,49,4,0,24,0,0,0,1,8,0,0,200,28,2,0,0,0,0,0,0,0,0,0,22,0,0,0,255,255,251,0,0,0,0,0,23,0,0,0,255,255,253,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,22,0,0,0,1,3,0,0,208,75,4,0,22,0,0,0,1,3,3,0,8,49,4,0,22,0,0,0,1,3,2,0,152,21,4,0,22,0,0,0,1,3,1,0,72,246,3,0,0,0,0,0,254,0,2,0,168,234,7,0,22,0,0,0,1,4,4,0,96,135,7,0,22,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,200,30,2,0,23,0,0,0,1,2,0,0,120,97,1,0,23,0,0,0,1,2,2,0,96,19,1,0,0,0,0,0,254,0,4,0,72,202,5,0,23,0,0,0,1,24,0,0,80,246,3,0,23,0,0,0,1,24,24,0,248,38,7,0,23,0,0,0,1,24,16,0,112,212,3,0,23,0,0,0,1,24,8,0,248,160,5,0,0,0,0,0,254,0,2,0,144,246,3,0,23,0,0,0,1,64,64,0,96,135,7,0,23,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,181,190,6,162,1,0,16,1,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,182,151,85,215,1,0,16,1,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,123,184,224,84,1,0,16,1,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,162,76,108,53,1,0,16,1,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,118,89,41,45,1,0,16,1,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,202,28,19,119,1,0,16,1,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,241,195,94,61,1,0,16,1,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,229,229,95,1,1,0,16,1,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,82,160,66,254,4,0,32,0,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,221,44,43,173,4,0,32,0,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,126,24,250,145,4,0,32,0,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,223,36,71,183,4,0,32,0,112,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,24,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,10,202,51,125,0,0,0,8,8,0,0,0,255,255,0,0,0,0,0,0,9,0,0,0,255,255,0,0,0,0,0,0,10,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,232,75,4,0,8,0,0,0,1,32,0,0,96,135,7,0,8,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,240,135,1,0,8,0,0,0,1,64,0,0,96,135,7,0,8,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,128,129,4,0,9,0,0,0,1,64,0,0,8,49,4,0,9,0,0,0,1,64,64,0,72,246,3,0,0,0,0,0,254,0,2,0,32,4,2,0,9,0,0,0,1,128,0,0,128,230,7,0,9,0,0,0,1,128,128,0,104,236,7,0,0,0,0,0,254,0,4,0,64,37,5,0,10,0,0,0,1,3,0,0,176,116,6,0,10,0,0,0,1,3,1,0,80,110,6,0,10,0,0,0,1,3,2,0,152,53,6,0,10,0,0,0,1,3,3,0,120,7,5,0,0,0,0,0,254,0,2,0,128,156,8,0,10,0,0,0,1,4,4,0,32,133,1,0,10,0,0,0,1,4,0,0,248,38,7,0,0,0,0,0,107,100,117,95,51,48,98,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,249,23,88,130,1,0,16,1,107,100,117,95,51,55,98,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,251,45,66,210,1,0,16,1,107,100,117,95,51,49,98,46,49,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,57,96,243,154,1,0,16,1,107,100,117,95,51,56,98,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,161,5,132,190,1,0,16,1,107,100,117,95,50,56,46,57,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,217,188,103,147,1,0,16,1,107,100,117,95,51,53,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,138,164,166,76,1,0,16,1,107,100,117,95,50,57,46,49,48,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,114,250,96,3,1,0,16,1,107,100,117,95,51,54,97,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,248,206,163,149,1,0,16,1,107,100,45,53,109,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,135,91,228,4,0,32,0,107,100,45,55,109,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,34,3,117,167,4,0,32,0,107,100,45,49,109,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,120,191,116,95,4,0,32,0,107,100,45,51,109,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,191,3,83,94,4,0,32,0,107,100,45,54,109,46,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,243,88,51,17,4,0,32,0,107,100,45,56,109,46,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,68,60,133,56,4,0,32,0,107,100,45,50,109,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,4,102,243,158,4,0,32,0,107,100,45,52,109,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,79,155,43,64,4,0,32,0,107,100,95,48,57,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,38,236,198,186,3,0,16,0,107,100,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,29,24,99,76,5,0,64,0,107,100,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,128,27,148,146,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,107,100,50,57,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,0,0,0,0,0,0,24,105,111,98,49,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,105,111,99,49,46,105,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,129,32,24,13,0,0,0,8,99,54,51,50,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,112,146,189,15,0,0,0,8,107,100,106,95,51,48,97,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,173,136,199,235,1,0,16,1,107,100,106,95,51,55,97,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,41,53,92,229,1,0,16,1,107,100,106,95,51,49,97,46,49,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,34,215,16,199,1,0,16,1,107,100,106,95,51,56,97,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,58,237,214,87,1,0,16,1,107,100,95,51,51,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,75,173,215,155,2,0,16,1,107,100,95,48,54,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,135,91,228,4,0,32,0,107,100,95,48,56,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,34,3,117,167,4,0,32,0,107,100,95,48,53,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,120,191,116,95,4,0,32,0,107,100,95,48,55,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,191,3,83,94,4,0,32,0,107,100,95,49,53,46,56,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,243,88,51,17,4,0,32,0,107,100,95,49,55,46,49,48,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,68,60,133,56,4,0,32,0,107,100,95,49,52,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,4,102,243,158,4,0,32,0,107,100,95,49,54,46,57,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,79,155,43,64,4,0,32,0,107,100,95,48,57,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,38,236,198,186,3,0,16,0,107,100,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,29,24,99,76,5,0,64,0,107,100,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,128,27,148,146,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,107,100,50,57,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,0,0,0,0,0,0,24,105,111,98,49,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,105,111,99,49,46,105,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,129,32,24,13,0,0,0,8,99,54,51,50,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,112,146,189,15,0,0,0,8,50,51,46,48,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,251,156,248,218,2,0,16,1,50,50,46,48,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,216,25,62,200,2,0,16,1,49,46,48,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,129,24,38,9,4,0,32,0,50,46,48,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,242,31,18,188,4,0,32,0,51,46,48,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,34,174,99,244,4,0,32,0,52,46,48,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,51,135,48,1,4,0,32,0,107,111,100,49,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,243,88,51,17,4,0,32,0,107,111,100,49,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,68,60,133,56,4,0,32,0,55,46,48,57,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,4,71,171,199,4,0,32,0,107,111,100,49,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,79,155,43,64,4,0,32,0,107,100,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,38,236,198,186,3,0,16,0,107,100,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,29,24,99,76,5,0,64,0,107,100,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,128,27,148,146,5,0,64,0,51,46,105,99,49,55,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,76,215,109,3,1,0,16,1,52,46,105,99,49,55,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,149,114,75,62,1,0,16,1,99,112,46,105,99,57,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,158,88,184,227,4,0,32,0,100,112,46,105,99,56,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,128,149,236,62,4,0,32,0,97,112,46,105,99,56,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,99,241,245,253,4,0,32,0,98,112,46,105,99,56,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,183,82,28,78,4,0,32,0,99,105,46,105,99,57,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,197,139,34,34,4,0,32,0,100,105,46,105,99,57,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,99,23,3,171,4,0,32,0,97,105,46,105,99,57,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,190,244,251,207,4,0,32,0,98,105,46,105,99,57,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,254,67,27,74,4,0,32,0,49,46,105,99,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,12,230,202,1,3,0,16,0,50,46,105,99,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,117,21,219,162,5,0,64,0,0,0,0,0,0,0,0,0,17,0,0,0,255,255,0,0,0,0,0,0,18,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,4,0,160,123,6,0,17,0,0,0,1,3,1,0,224,67,5,0,17,0,0,0,1,3,3,0,192,135,6,0,17,0,0,0,1,3,0,0,200,201,5,0,17,0,0,0,1,3,2,0,144,127,5,0,0,0,0,0,254,0,4,0,200,87,7,0,17,0,0,0,1,12,0,0,216,36,5,0,17,0,0,0,1,12,4,0,224,67,5,0,17,0,0,0,1,12,8,0,192,135,6,0,17,0,0,0,1,12,12,0,184,108,4,0,0,0,0,0,254,0,2,0,128,129,4,0,17,0,0,0,1,16,0,0,8,49,4,0,17,0,0,0,1,16,16,0,72,246,3,0,0,0,0,0,254,0,2,0,64,37,5,0,17,0,0,0,1,32,0,0,104,91,7,0,17,0,0,0,1,32,32,0,144,84,7,0,0,0,0,0,254,0,2,0,72,202,5,0,17,0,0,0,1,64,0,0,104,80,7,0,17,0,0,0,1,64,64,0,32,37,7,0,0,0,0,0,254,0,2,0,136,73,7,0,17,0,0,0,1,128,0,0,192,255,2,0,17,0,0,0,1,128,128,0,208,75,4,0,0,0,0,0,254,0,2,0,200,30,2,0,18,0,0,0,1,1,1,0,120,97,1,0,18,0,0,0,1,1,0,0,96,19,1,0,0,0,0,0,254,0,2,0,112,109,2,0,18,0,0,0,1,64,0,0,96,135,7,0,18,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,4,0,200,59,7,0,18,0,0,0,1,128,0,0,96,135,7,0,18,0,0,0,1,128,128,0,152,182,7,0,0,0,0,0,16,0,0,0,255,255,0,0,0,0,0,0,17,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,128,129,4,0,16,0,0,0,1,1,0,0,8,49,4,0,16,0,0,0,1,1,1,0,72,246,3,0,0,0,0,0,254,0,2,0,112,153,2,0,16,0,0,0,1,2,0,0,184,151,2,0,16,0,0,0,1,2,2,0,88,244,4,0,0,0,0,0,254,0,2,0,144,212,8,0,16,0,0,0,1,4,0,0,96,135,7,0,16,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,254,0,16,0,48,9,7,0,16,0,0,0,1,240,0,0,176,57,7,0,16,0,0,0,1,240,16,0,72,13,7,0,16,0,0,0,1,240,32,0,104,226,6,0,16,0,0,0,1,240,48,0,168,182,6,0,16,0,0,0,1,240,64,0,32,139,6,0,16,0,0,0,1,240,80,0,152,94,6,0,16,0,0,0,1,240,96,0,184,47,6,0,16,0,0,0,1,240,112,0,72,5,6,0,16,0,0,0,1,240,128,0,216,215,5,0,16,0,0,0,1,240,144,0,136,177,5,0,16,0,0,0,1,240,160,0,208,139,5,0,16,0,0,0,1,240,176,0,32,112,5,0,16,0,0,0,1,240,192,0,0,80,5,0,16,0,0,0,1,240,208,0,48,50,5,0,16,0,0,0,1,240,224,0,32,19,5,0,16,0,0,0,1,240,240,0,200,82,2,0,0,0,0,0,254,0,2,0,168,234,7,0,17,0,0,0,1,1,1,0,96,135,7,0,17,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,17,0,0,0,1,6,0,0,16,141,4,0,17,0,0,0,1,6,2,0,208,75,4,0,17,0,0,0,1,6,4,0,8,49,4,0,17,0,0,0,1,6,6,0,32,193,3,0,0,0,0,0,254,0,2,0,72,4,1,0,17,0,0,0,1,128,0,0,96,135,7,0,17,0,0,0,1,128,128,0,152,182,7,0,0,0,0,0,9,0,0,0,255,255,0,0,0,0,0,0,10,0,0,0,255,255,254,0,0,0,0,0,0,0,0,0,254,0,2,0,32,4,2,0,9,0,0,0,1,1,0,0,56,37,8,0,9,0,0,0,1,1,1,0,96,240,7,0,0,0,0,0,254,0,4,0,64,37,5,0,9,0,0,0,1,34,0,0,80,110,6,0,9,0,0,0,1,34,2,0,112,216,4,0,9,0,0,0,1,34,32,0,176,210,4,0,9,0,0,0,1,34,34,0,184,43,6,0,0,0,0,0,254,0,4,0,128,129,4,0,9,0,0,0,1,80,0,0,8,49,4,0,9,0,0,0,1,80,16,0,152,21,4,0,9,0,0,0,1,80,64,0,72,246,3,0,9,0,0,0,1,80,80,0,72,0,3,0,0,0,0,0,254,0,8,0,72,202,5,0,9,0,0,0,1,140,0,0,192,255,2,0,9,0,0,0,1,140,4,0,208,75,4,0,9,0,0,0,1,140,8,0,8,49,4,0,9,0,0,0,1,140,12,0,152,21,4,0,9,0,0,0,1,140,128,0,72,246,3,0,9,0,0,0,1,140,132,0,72,0,3,0,9,0,0,0,1,140,136,0,64,47,7,0,9,0,0,0,1,140,140,0,232,99,5,0,104,115,50,117,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,30,21,8,179,1,0,16,1,104,115,50,117,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,156,164,122,50,1,0,16,1,104,115,50,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,53,74,227,221,1,0,16,1,104,115,50,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,218,109,229,244,1,0,16,1,104,115,50,46,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,252,32,68,238,1,0,16,1,104,115,50,46,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,51,21,68,201,1,0,16,1,104,115,50,46,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,56,198,63,1,0,16,1,104,115,50,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,228,249,208,32,1,0,16,1,104,115,50,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,23,171,236,166,5,0,32,0,104,115,50,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,77,174,160,16,5,0,32,0,104,115,50,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,38,119,250,173,5,0,32,0,104,115,50,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,34,227,58,187,5,0,32,0,104,115,50,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,134,55,161,193,10,0,16,1,104,115,50,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,170,148,135,45,10,0,16,1,104,115,50,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,89,195,21,14,12,0,64,0,34,0,0,0,255,255,191,0,0,0,0,0,35,0,0,0,255,255,255,0,0,0,0,0,36,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,34,0,0,0,1,3,0,0,192,255,2,0,34,0,0,0,1,3,3,0,208,75,4,0,34,0,0,0,1,3,2,0,8,49,4,0,34,0,0,0,1,3,1,0,152,21,4,0,0,0,0,0,254,0,4,0,72,202,5,0,34,0,0,0,1,12,0,0,160,203,8,0,34,0,0,0,1,12,8,0,80,246,3,0,34,0,0,0,1,12,12,0,248,38,7,0,34,0,0,0,1,12,4,0,112,212,3,0,0,0,0,0,254,0,2,0,72,8,1,0,34,0,0,0,1,32,0,0,56,111,3,0,34,0,0,0,1,32,32,0,104,134,3,0,0,0,0,0,254,0,2,0,168,234,7,0,34,0,0,0,1,64,64,0,96,135,7,0,34,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,34,0,0,0,1,128,128,0,96,135,7,0,34,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,35,0,0,0,1,1,1,0,96,135,7,0,35,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,200,30,2,0,35,0,0,0,1,2,2,0,240,242,5,0,35,0,0,0,1,2,0,0,216,104,6,0,0,0,0,0,254,0,2,0,88,160,1,0,35,0,0,0,1,4,4,0,136,86,1,0,35,0,0,0,1,4,0,0,184,147,6,0,0,0,0,0,254,0,2,0,96,46,8,0,35,0,0,0,1,8,8,0,192,255,2,0,35,0,0,0,1,8,0,0,208,75,4,0,0,0,0,0,254,0,16,0,32,4,2,0,35,0,0,0,1,240,160,0,144,160,3,0,35,0,0,0,1,240,176,0,96,135,3,0,35,0,0,0,1,240,192,0,32,136,7,0,35,0,0,0,1,240,208,0,40,88,7,0,35,0,0,0,1,240,224,0,96,39,7,0,35,0,0,0,1,240,16,0,32,202,2,0,35,0,0,0,1,240,48,0,120,113,6,0,35,0,0,0,1,240,32,0,232,228,5,0,35,0,0,0,1,240,240,0,144,251,6,0,35,0,0,0,1,240,64,0,120,211,6,0,35,0,0,0,1,240,144,0,184,164,6,0,35,0,0,0,1,240,128,0,80,74,6,0,35,0,0,0,1,240,112,0,192,32,6,0,35,0,0,0,1,240,96,0,192,234,2,0,35,0,0,0,1,240,80,0,32,242,5,0,35,0,0,0,1,240,0,0,16,227,4,0,0,0,0,0,9,0,0,0,255,255,251,0,0,0,0,0,0,0,0,0,254,0,4,0,32,4,2,0,9,0,0,0,1,3,0,0,40,88,7,0,9,0,0,0,1,3,1,0,96,39,7,0,9,0,0,0,1,3,3,0,144,251,6,0,9,0,0,0,1,3,2,0,184,164,6,0,0,0,0,0,254,0,2,0,104,148,2,0,9,0,0,0,1,4,4,0,96,135,7,0,9,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,9,0,0,0,1,8,8,0,96,135,7,0,9,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,4,0,8,99,2,0,9,0,0,0,1,48,48,0,0,83,2,0,9,0,0,0,1,48,32,0,88,70,2,0,9,0,0,0,1,48,16,0,208,56,2,0,9,0,0,0,1,48,0,0,160,41,2,0,0,0,0,0,254,0,2,0,40,31,2,0,9,0,0,0,1,64,64,0,208,75,4,0,9,0,0,0,1,64,0,0,152,21,4,0,0,0,0,0,254,0,2,0,168,234,7,0,9,0,0,0,1,128,0,0,96,135,7,0,9,0,0,0,1,128,128,0,152,182,7,0,0,0,0,0,104,114,45,103,112,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,136,151,243,130,0,0,16,1,104,114,45,103,112,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,18,120,96,121,0,0,16,1,104,114,45,103,112,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,92,113,2,41,0,0,16,1,104,114,45,103,112,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,142,47,109,105,0,0,16,1,104,114,45,103,112,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,166,75,106,147,0,0,16,1,104,114,45,115,100,112,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,121,207,78,195,0,0,16,1,104,114,45,115,112,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,177,60,195,165,0,0,64,0,104,114,45,99,112,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,150,20,32,45,0,0,32,0,104,114,45,99,112,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,227,31,182,33,0,0,32,0,104,114,45,99,112,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,158,63,142,156,0,0,32,0,53,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,36,166,85,240,0,0,64,0,56,50,115,49,56,53,46,49,48,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,166,188,5,194,0,0,32,0,56,50,115,49,50,51,46,49,48,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,236,28,34,181,0,0,32,0,117,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,247,153,23,3,0,0,16,1,117,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,10,121,56,98,0,0,16,1,109,109,100,48,120,50,46,117,49,50,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,41,179,124,61,0,0,16,8,109,109,45,50,48,48,45,52,48,50,45,115,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,252,62,171,192,0,0,32,0,109,109,45,50,48,49,45,52,48,51,45,115,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,220,35,107,207,0,0,32,0,109,109,45,50,48,50,45,52,48,52,45,115,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,211,245,39,143,0,0,32,0,109,109,45,50,48,51,45,52,48,53,45,115,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,140,124,116,233,0,0,32,0,109,109,115,49,120,50,46,117,51,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,111,66,43,180,0,0,32,0,109,109,115,48,120,50,46,117,50,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,210,183,34,189,0,0,32,0,109,109,45,51,48,48,45,52,48,54,45,97,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,127,107,95,177,0,0,32,0,109,109,45,49,48,48,45,52,48,49,45,101,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,238,251,203,185,0,0,64,0,20,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,232,75,4,0,20,0,0,0,1,1,0,0,96,135,7,0,20,0,0,0,1,1,1,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,20,0,0,0,1,2,0,0,96,135,7,0,20,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,2,0,200,30,2,0,20,0,0,0,1,4,0,0,120,97,1,0,20,0,0,0,1,4,4,0,96,19,1,0,0,0,0,0,254,0,4,0,0,150,8,0,20,0,0,0,1,24,0,0,192,188,8,0,20,0,0,0,1,24,16,0,128,183,8,0,20,0,0,0,1,24,8,0,88,246,8,0,20,0,0,0,1,24,24,0,48,175,8,0,0,0,0,0,254,0,2,0,104,166,8,0,20,0,0,0,1,32,32,0,96,135,7,0,20,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,4,0,8,157,8,0,20,0,0,0,1,192,0,0,200,150,8,0,20,0,0,0,1,192,64,0,104,144,8,0,20,0,0,0,1,192,128,0,96,139,8,0,20,0,0,0,1,192,192,0,120,7,5,0,0,0,0,0,103,109,100,106,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,227,121,105,205,1,0,16,1,103,109,100,46,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,103,85,72,55,1,0,16,1,103,109,100,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,251,159,38,218,1,0,16,1,103,109,100,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,201,131,180,85,1,0,16,1])
.concat([103,109,100,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,240,25,221,128,5,0,32,0,103,109,100,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,120,58,217,223,5,0,32,0,103,109,100,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,32,101,53,22,5,0,32,0,103,109,100,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,49,48,195,223,5,0,32,0,103,109,100,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,133,201,155,63,10,0,16,1,103,109,100,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,222,157,211,63,10,0,16,1,103,109,100,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,66,85,166,6,12,0,64,0,103,109,100,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,49,122,188,80,12,0,64,0,101,112,114,45,49,51,49,55,48,46,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,41,146,24,69,1,0,16,1,101,112,114,45,49,51,49,54,57,46,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,110,205,71,27,1,0,16,1,101,112,114,45,49,51,48,50,56,46,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,223,46,170,182,1,0,16,1,101,112,114,45,49,51,48,50,55,46,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,122,200,99,100,1,0,16,1,101,112,114,45,49,51,48,51,50,46,56,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,78,156,160,125,9,0,16,1,101,112,114,45,49,51,48,51,49,46,56,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,244,227,199,243,9,0,16,1,101,112,114,45,49,51,48,51,48,46,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,191,202,171,129,17,0,16,1,101,112,114,45,49,51,48,50,57,46,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,251,142,99,243,17,0,16,1,101,112,114,45,49,51,48,51,55,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,80,162,1,184,3,0,32,0,101,112,114,45,49,51,48,51,57,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,109,38,225,215,3,0,32,0,101,112,114,45,49,51,48,51,56,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,109,219,46,11,3,0,32,0,101,112,114,45,49,51,48,52,48,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,133,58,235,74,3,0,32,0,101,112,114,45,49,51,48,52,56,46,54,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,221,176,30,254,18,0,32,0,101,112,114,45,49,51,48,53,54,46,55,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,230,248,4,89,18,0,32,0,101,112,114,45,49,51,48,52,52,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,137,31,147,77,18,0,32,0,101,112,114,45,49,51,48,53,50,46,55,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,64,240,145,2,18,0,32,0,101,112,114,45,49,51,48,54,52,46,56,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,27,101,142,95,18,0,32,0,101,112,114,45,49,51,48,55,50,46,49,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,26,100,133,107,18,0,32,0,101,112,114,45,49,51,48,54,48,46,56,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,151,173,22,238,18,0,32,0,101,112,114,45,49,51,48,54,56,46,49,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,187,43,213,100,18,0,32,0,101,112,114,45,49,51,48,52,55,46,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,50,8,52,83,18,0,32,0,101,112,114,45,49,51,48,53,53,46,55,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,101,182,182,57,18,0,32,0,101,112,114,45,49,51,48,52,51,46,54,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,253,22,143,32,18,0,32,0,101,112,114,45,49,51,48,53,49,46,55,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,212,203,98,173,18,0,32,0,101,112,114,45,49,51,48,54,51,46,56,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,109,191,128,197,18,0,32,0,101,112,114,45,49,51,48,55,49,46,49,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,153,239,153,223,18,0,32,0,101,112,114,45,49,51,48,53,57,46,56,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,88,37,152,76,18,0,32,0,101,112,114,45,49,51,48,54,55,46,49,48,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,25,97,127,249,18,0,32,0,101,112,114,45,49,51,48,52,54,46,54,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,233,134,90,199,18,0,32,0,101,112,114,45,49,51,48,53,52,46,55,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,154,84,52,41,18,0,32,0,101,112,114,45,49,51,48,52,50,46,54,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,175,151,237,83,18,0,32,0,101,112,114,45,49,51,48,53,48,46,54,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,104,144,66,4,18,0,32,0,101,112,114,45,49,51,48,54,50,46,56,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,227,78,219,79,18,0,32,0,101,112,114,45,49,51,48,55,48,46,49,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,14,19,234,82,18,0,32,0,101,112,114,45,49,51,48,53,56,46,56,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,38,22,255,25,18,0,32,0,101,112,114,45,49,51,48,54,54,46,49,48,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,80,162,112,188,18,0,32,0,101,112,114,45,49,51,48,52,53,46,54,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,109,188,213,84,18,0,32,0,101,112,114,45,49,51,48,53,51,46,55,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,19,175,2,149,18,0,32,0,101,112,114,45,49,51,48,52,49,46,54,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,44,64,167,208,18,0,32,0,101,112,114,45,49,51,48,52,57,46,54,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,108,11,156,91,18,0,32,0,101,112,114,45,49,51,48,54,49,46,56,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,59,236,149,123,18,0,32,0,101,112,114,45,49,51,48,54,57,46,49,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,240,56,245,225,18,0,32,0,101,112,114,45,49,51,48,53,55,46,55,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,238,239,186,115,18,0,32,0,101,112,114,45,49,51,48,54,53,46,49,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,85,166,55,137,18,0,32,0,101,112,114,45,49,51,48,51,51,46,49,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,39,232,245,109,4,0,16,1,101,112,114,45,49,51,48,51,54,46,49,48,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,108,194,144,120,11,0,64,0,101,112,114,45,49,51,48,51,53,46,49,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,62,161,159,0,11,0,64,0,101,112,114,45,49,51,48,51,52,46,49,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,93,217,34,205,11,0,64,0,12,0,0,0,255,255,107,0,0,0,0,0,13,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,72,202,5,0,12,0,0,0,1,3,2,0,80,246,3,0,12,0,0,0,1,3,3,0,248,38,7,0,12,0,0,0,1,3,1,0,112,212,3,0,12,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,2,0,168,234,7,0,12,0,0,0,1,4,4,0,96,135,7,0,12,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,3,0,200,30,2,0,12,0,0,0,1,24,24,0,120,247,1,0,12,0,0,0,1,24,16,0,80,46,8,0,12,0,0,0,1,24,8,0,120,97,1,0,0,0,0,0,254,0,2,0,104,159,3,0,12,0,0,0,1,32,0,0,56,111,3,0,12,0,0,0,1,32,32,0,104,134,3,0,0,0,0,0,254,0,4,0,56,154,6,0,12,0,0,0,1,192,64,0,184,30,3,0,12,0,0,0,1,192,192,0,0,28,3,0,12,0,0,0,1,192,128,0,144,188,3,0,12,0,0,0,1,192,0,0,176,163,3,0,0,0,0,0,254,0,16,0,200,87,7,0,13,0,0,0,1,15,7,0,80,252,6,0,13,0,0,0,1,15,8,0,16,242,7,0,13,0,0,0,1,15,9,0,104,236,7,0,13,0,0,0,1,15,5,0,176,51,4,0,13,0,0,0,1,15,4,0,56,24,4,0,13,0,0,0,1,15,15,0,128,230,7,0,13,0,0,0,1,15,1,0,72,216,3,0,13,0,0,0,1,15,2,0,24,188,3,0,13,0,0,0,1,15,3,0,176,162,3,0,13,0,0,0,1,15,6,0,120,211,6,0,13,0,0,0,1,15,14,0,184,164,6,0,13,0,0,0,1,15,13,0,80,74,6,0,13,0,0,0,1,15,12,0,192,32,6,0,13,0,0,0,1,15,11,0,192,234,2,0,13,0,0,0,1,15,10,0,32,242,5,0,13,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,13,0,0,0,1,240,112,0,80,252,6,0,13,0,0,0,1,240,128,0,16,242,7,0,13,0,0,0,1,240,144,0,104,236,7,0,13,0,0,0,1,240,80,0,176,51,4,0,13,0,0,0,1,240,64,0,56,24,4,0,13,0,0,0,1,240,240,0,128,230,7,0,13,0,0,0,1,240,16,0,72,216,3,0,13,0,0,0,1,240,32,0,24,188,3,0,13,0,0,0,1,240,48,0,176,162,3,0,13,0,0,0,1,240,96,0,120,211,6,0,13,0,0,0,1,240,224,0,184,164,6,0,13,0,0,0,1,240,208,0,80,74,6,0,13,0,0,0,1,240,192,0,192,32,6,0,13,0,0,0,1,240,176,0,192,234,2,0,13,0,0,0,1,240,160,0,32,242,5,0,13,0,0,0,1,240,0,0,208,236,2,0,19,0,0,0,255,255,0,0,0,0,0,0,20,0,0,0,255,255,0,0,0,0,0,0,21,0,0,0,255,255,242,0,0,0,0,0,0,0,0,0,254,0,2,0,232,21,1,0,19,0,0,0,1,1,0,0,96,135,7,0,19,0,0,0,1,1,1,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,2,0,0,96,135,7,0,19,0,0,0,1,2,2,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,4,0,0,96,135,7,0,19,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,8,8,0,96,135,7,0,19,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,7,0,200,87,7,0,19,0,0,0,1,48,48,0,32,136,7,0,19,0,0,0,1,48,32,0,40,88,7,0,19,0,0,0,1,48,16,0,96,39,7,0,19,0,0,0,1,48,32,0,96,39,7,0,19,0,0,0,1,48,0,0,144,251,6,0,19,0,0,0,1,48,48,0,120,211,6,0,19,0,0,0,1,48,16,0,184,164,6,0,0,0,0,0,254,0,8,0,160,123,6,0,19,0,0,0,1,192,128,0,96,39,7,0,19,0,0,0,1,192,0,0,144,251,6,0,19,0,0,0,1,192,192,0,120,211,6,0,19,0,0,0,1,192,64,0,184,164,6,0,19,0,0,0,1,192,0,0,184,164,6,0,19,0,0,0,1,192,64,0,80,74,6,0,19,0,0,0,1,192,128,0,192,32,6,0,19,0,0,0,1,192,192,0,32,242,5,0,0,0,0,0,254,0,0,0,72,202,5,0,20,0,0,0,1,3,3,0,248,160,5,0,20,0,0,0,1,3,2,0,112,212,3,0,20,0,0,0,1,3,0,0,248,38,7,0,20,0,0,0,1,3,1,0,80,246,3,0,0,0,0,0,254,0,4,0,64,37,5,0,20,0,0,0,1,12,12,0,120,7,5,0,20,0,0,0,1,12,8,0,240,191,4,0,20,0,0,0,1,12,4,0,8,192,4,0,20,0,0,0,1,12,0,0,40,160,4,0,0,0,0,0,254,0,4,0,128,129,4,0,20,0,0,0,1,48,48,0,192,255,2,0,20,0,0,0,1,48,32,0,208,75,4,0,20,0,0,0,1,48,0,0,8,49,4,0,20,0,0,0,1,48,16,0,72,246,3,0,0,0,0,0,254,0,4,0,144,246,3,0,20,0,0,0,1,64,0,0,96,135,7,0,20,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,232,21,1,0,20,0,0,0,1,128,0,0,96,135,7,0,20,0,0,0,1,128,128,0,152,182,7,0,0,0,0,0,254,0,2,0,48,45,3,0,21,0,0,0,1,15,2,0,8,234,2,0,21,0,0,0,1,15,10,0,184,159,3,0,21,0,0,0,1,15,13,0,184,134,3,0,21,0,0,0,1,15,1,0,160,134,3,0,21,0,0,0,1,15,9,0,112,111,3,0,21,0,0,0,1,15,11,0,16,75,3,0,21,0,0,0,1,15,12,0,80,62,3,0,21,0,0,0,1,15,0,0,176,20,3,0,21,0,0,0,1,15,4,0,56,50,1,0,21,0,0,0,1,15,3,0,48,62,3,0,21,0,0,0,1,15,5,0,80,65,1,0,21,0,0,0,1,15,6,0,184,210,2,0,21,0,0,0,1,15,7,0,64,192,2,0,21,0,0,0,1,15,8,0,200,175,2,0,0,0,0,0,0,0,0,0,9,0,0,0,255,255,255,0,0,0,0,0,10,0,0,0,255,255,255,0,0,0,0,0,11,0,0,0,255,255,251,0,0,0,0,0,12,0,0,0,255,255,16,0,0,0,0,0,0,0,0,0,254,0,2,0,16,227,4,0,10,0,0,0,1,1,1,0,96,135,7,0,10,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,8,0,200,87,7,0,10,0,0,0,1,14,10,0,16,242,7,0,10,0,0,0,1,14,12,0,104,236,7,0,10,0,0,0,1,14,14,0,128,230,7,0,10,0,0,0,1,14,8,0,184,164,6,0,10,0,0,0,1,14,6,0,80,74,6,0,10,0,0,0,1,14,4,0,192,32,6,0,10,0,0,0,1,14,2,0,192,234,2,0,10,0,0,0,1,14,0,0,32,242,5,0,0,0,0,0,254,0,8,0,160,123,6,0,10,0,0,0,1,112,80,0,16,242,7,0,10,0,0,0,1,112,96,0,104,236,7,0,10,0,0,0,1,112,112,0,128,230,7,0,10,0,0,0,1,112,64,0,184,164,6,0,10,0,0,0,1,112,48,0,80,74,6,0,10,0,0,0,1,112,32,0,192,32,6,0,10,0,0,0,1,112,16,0,192,234,2,0,10,0,0,0,1,112,0,0,32,242,5,0,0,0,0,0,254,0,2,0,24,172,6,0,10,0,0,0,1,128,128,0,96,135,7,0,10,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,9,0,0,0,1,3,2,0,80,246,3,0,9,0,0,0,1,3,3,0,248,38,7,0,9,0,0,0,1,3,1,0,112,212,3,0,9,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,2,0,192,76,5,0,9,0,0,0,1,8,0,0,96,135,7,0,9,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,11,0,0,0,1,1,1,0,96,135,7,0,11,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,11,0,0,0,1,4,4,0,96,135,7,0,11,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,6,0,224,133,4,0,12,0,0,0,1,31,16,0,224,32,1,0,12,0,0,0,1,31,1,0,32,27,4,0,12,0,0,0,1,31,0,0,176,20,3,0,12,0,0,0,1,31,2,0,56,50,1,0,12,0,0,0,1,31,4,0,192,20,3,0,12,0,0,0,1,31,8,0,80,65,1,0,0,0,0,0,115,119,45,48,51,46,109,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,112,151,215,175,0,0,16,1,115,119,45,48,52,46,109,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,16,153,61,147,0,0,16,1,115,119,45,48,53,46,109,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,182,27,167,233,0,0,16,1,115,119,45,48,54,46,109,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,72,130,111,70,0,0,16,1,115,119,45,48,55,46,109,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,94,101,65,236,0,0,16,1,115,114,45,48,49,46,99,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,107,240,135,189,0,0,16,1,115,119,45,48,50,46,102,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,162,173,233,248,0,0,32,0,115,114,45,48,56,46,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,235,217,132,56,0,0,32,0,115,114,45,48,57,46,97,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,224,246,156,153,0,0,32,0,115,114,45,49,48,46,97,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,58,39,219,142,0,0,32,0,115,114,45,49,49,46,97,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,195,38,39,58,0,0,32,0,115,114,45,49,50,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,187,216,211,27,0,0,32,0,115,114,45,49,51,46,97,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,196,2,143,101,0,0,32,0,115,114,45,49,52,46,108,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,198,190,40,37,0,0,32,0,115,114,45,49,53,46,108,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,170,135,146,248,0,0,32,0,115,114,45,49,54,46,110,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,248,24,68,2,0,0,32,0,115,114,45,49,55,46,110,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,137,228,199,226,0,0,32,0,115,98,45,53,46,101,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,83,129,171,147,0,0,32,0,115,98,45,54,46,101,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,125,79,180,138,0,0,32,0,115,98,45,55,46,101,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,164,233,173,244,0,0,32,0,115,98,45,48,46,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,27,217,71,96,0,0,32,0,115,98,45,52,46,100,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,141,150,88,72,0,0,32,0,115,98,45,56,46,107,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,67,217,250,246,0,0,32,0,115,98,45,50,46,100,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,223,179,184,139,0,0,32,0,115,98,45,51,46,100,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,175,153,12,59,0,0,32,0,115,98,45,49,46,107,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,8,197,42,113,0,0,32,0,115,98,45,57,46,109,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,92,99,33,73,0,0,32,0,50,49,106,45,49,46,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,100,73,113,174,0,0,16,1,50,49,106,45,50,45,51,46,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,94,112,121,87,0,0,16,1,50,49,97,45,51,46,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,151,72,242,219,0,0,16,1,50,49,106,45,52,46,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,250,70,159,108,0,0,16,1,50,49,106,109,45,48,46,105,99,53,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,3,45,35,245,0,0,16,1,50,49,106,45,48,45,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,187,149,250,158,0,0,16,1,50,49,106,45,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,180,141,139,122,0,0,32,0,50,49,106,45,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,227,172,79,87,0,0,32,0,50,49,106,45,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,118,122,80,64,0,0,32,0,50,49,106,45,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,111,199,11,187,0,0,32,0,50,49,106,45,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,27,35,79,203,0,0,32,0,50,49,106,45,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,97,194,160,160,0,0,32,0,50,49,106,45,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,246,82,161,107,0,0,32,0,50,49,106,45,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,182,160,32,50,0,0,32,0,50,49,106,45,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,125,81,199,101,0,0,32,0,50,49,106,45,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,135,88,67,124,0,0,32,0,50,49,106,45,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,237,10,100,198,0,0,32,0,50,49,106,45,105,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,160,176,255,94,0,0,32,0,50,49,106,45,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,124,46,180,95,0,0,32,0,50,49,106,45,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,227,93,117,52,0,0,32,0,50,49,106,45,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,248,230,77,144,0,0,32,0,50,49,106,45,107,45,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,169,48,177,253,0,0,32,0,50,49,106,45,108,45,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,41,149,51,70,0,0,32,0,98,99,95,114,111,109,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,162,84,240,118,0,0,16,1,98,99,95,114,111,109,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,197,180,112,37,0,0,16,1,98,99,95,114,111,109,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,155,167,92,229,0,0,32,0,98,99,95,114,111,109,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,150,140,243,205,0,0,32,0,98,99,95,114,111,109,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,61,171,55,3,0,0,32,0,98,99,95,114,111,109,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,126,145,88,84,0,0,32,0,98,99,95,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,161,139,111,172,0,0,64,0,98,99,95,114,111,109,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,191,49,188,164,0,0,64,0,117,52,45,102,46,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,53,137,17,166,0,0,16,1,117,51,45,102,46,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,132,150,244,36,0,0,16,1,99,109,48,50,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,116,74,204,249,0,0,16,1,118,116,48,49,46,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,224,38,87,80,0,0,32,0,118,116,49,49,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,72,27,46,123,0,0,32,0,118,116,49,50,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,211,23,180,129,0,0,32,0,118,116,49,51,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,210,219,18,86,0,0,32,0,118,116,49,52,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,54,238,45,43,0,0,32,0,118,116,49,53,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,191,186,112,222,0,0,32,0,118,116,49,54,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,55,130,23,20,0,0,32,0,118,116,48,53,46,55,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,61,110,241,121,0,0,32,0,118,116,48,54,46,56,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,33,229,254,38,0,0,32,0,118,116,48,55,46,57,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,253,189,136,202,0,0,32,0,118,116,48,56,46,55,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,131,200,25,32,0,0,32,0,118,116,48,57,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,130,57,112,152,0,0,32,0,118,116,49,48,46,57,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,248,210,105,240,0,0,32,0,118,116,98,49,46,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,161,21,186,58,0,0,32,0,118,116,98,50,46,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,84,87,134,136,0,0,32,0,118,116,98,51,46,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,246,195,20,76,0,0,32,0,118,116,98,52,46,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,70,194,136,179,0,0,32,0,118,116,98,53,46,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,8,197,42,113,0,0,32,0,118,116,98,54,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,88,81,175,14,0,0,32,0,98,109,117,48,49,99,46,49,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,92,204,134,198,0,0,16,1,98,109,117,48,50,99,46,49,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,65,10,136,216,0,0,16,1,98,109,117,48,51,99,46,49,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,108,226,14,63,0,0,16,1,98,109,48,52,46,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,215,210,43,238,0,0,16,1,98,109,48,53,46,52,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,61,157,203,70,0,0,32,0,98,109,49,53,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,67,4,26,107,0,0,32,0,98,109,49,54,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,194,8,201,35,0,0,32,0,98,109,49,55,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,7,221,188,70,0,0,32,0,98,109,49,56,46,49,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,160,123,174,230,0,0,32,0,98,109,49,57,46,49,48,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,188,186,138,134,0,0,32,0,98,109,50,48,46,49,49,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,212,229,23,9,0,0,32,0,98,109,50,49,46,49,50,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,137,13,251,155,0,0,32,0,98,109,50,50,46,49,52,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,116,194,243,4,0,0,32,0,98,109,50,52,46,49,52,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,54,64,19,17,0,0,32,0,98,109,50,53,46,49,52,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,193,249,44,9,0,0,32,0,98,109,48,54,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,175,200,172,151,0,0,32,0,98,109,48,55,46,49,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,151,113,143,215,0,0,32,0,98,109,48,56,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,8,102,98,26,0,0,32,0,98,109,48,57,46,49,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,132,64,146,0,0,32,0,98,109,49,48,46,49,48,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,74,164,56,132,0,0,32,0,98,109,49,49,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,29,53,105,108,0,0,32,0,98,109,49,50,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,183,253,126,94,0,0,32,0,98,109,49,51,46,49,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,154,130,67,17,0,0,32,0,98,109,49,52,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,1,100,60,77,0,0,32,0,98,109,50,51,46,56,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,189,236,42,165,0,0,32,0,98,109,49,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,24,31,66,116,0,0,32,0,98,109,50,46,49,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,31,84,39,172,0,0,32,0,98,109,51,46,49,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,255,182,31,37,0,0,32,0,98,109,53,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,208,19,103,32,0,0,32,0,98,109,49,48,46,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,28,73,194,51,0,0,32,0,98,109,57,46,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,247,74,234,174,0,0,32,0,98,109,49,50,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,54,161,138,193,0,0,32,0,98,109,49,49,46,49,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,55,174,90,64,0,0,32,0,98,109,56,46,56,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,158,10,1,194,0,0,32,0,98,109,55,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,195,48,111,181,0,0,32,0,98,109,52,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,225,162,168,145,0,0,32,0,98,109,54,46,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,88,81,175,14,0,0,32,0,98,109,46,55,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,16,109,100,117,95,48,52,46,56,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,41,131,127,127,0,0,16,1,109,100,117,95,48,51,46,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,47,84,250,17,0,0,16,1,109,100,101,95,48,50,46,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,22,190,94,159,0,0,16,1,109,100,101,95,48,49,46,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,240,42,234,28,0,0,16,1,109,100,101,95,48,53,46,49,52,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,69,201,191,47,0,0,16,1,109,100,117,95,48,54,46,49,48,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,2,220,191,84,0,0,32,0,108,115,45,49,50,46,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,108,44,27,108,0,0,32,0,108,115,45,49,49,46,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,100,28,248,107,0,0,32,0,49,49,46,114,111,109,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,100,154,49,238,0,0,32,0,48,55,117,46,114,111,109,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,18,178,82,113,0,0,32,0,49,50,46,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,32,241,126,136,0,0,32,0,48,56,117,46,114,111,109,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,37,213,229,114,0,0,32,0,49,51,46,114,111,109,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,180,125,224,234,0,0,32,0,48,57,117,46,114,111,109,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,203,117,81,123,0,0,32,0,49,52,46,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,76,66,229,33,0,0,32,0,49,48,117,46,114,111,109,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,100,202,183,109,0,0,32,0,108,115,45,48,54,46,49,48,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,91,154,211,136,0,0,64,0,108,115,45,48,53,46,49,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,181,3,110,176,0,0,64,0,50,57,46,49,52,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,30,46,134,127,0,0,32,0,50,49,97,45,49,45,53,46,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,17,110,74,226,0,0,16,1,50,49,106,45,50,45,51,46,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,94,112,121,87,0,0,16,1,50,49,97,45,51,46,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,151,72,242,219,0,0,16,1,50,49,97,45,52,46,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,114,96,161,110,0,0,16,1,50,49,106,109,45,48,46,105,99,53,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,3,45,35,245,0,0,16,1,50,49,106,45,48,45,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,187,149,250,158,0,0,16,1,50,49,106,45,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,180,141,139,122,0,0,32,0,50,49,106,45,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,227,172,79,87,0,0,32,0,50,49,106,45,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,118,122,80,64,0,0,32,0,50,49,106,45,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,111,199,11,187,0,0,32,0,50,49,106,45,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,27,35,79,203,0,0,32,0,50,49,106,45,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,97,194,160,160,0,0,32,0,50,49,106,45,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,246,82,161,107,0,0,32,0,50,49,106,45,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,182,160,32,50,0,0,32,0,50,49,106,45,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,125,81,199,101,0,0,32,0,50,49,106,45,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,135,88,67,124,0,0,32,0,50,49,106,45,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,237,10,100,198,0,0,32,0,50,49,106,45,105,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,160,176,255,94,0,0,32,0,50,49,106,45,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,124,46,180,95,0,0,32,0,50,49,106,45,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,227,93,117,52,0,0,32,0,50,49,106,45,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,248,230,77,144,0,0,32,0,50,49,106,45,107,45,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,169,48,177,253,0,0,32,0,50,49,106,45,108,45,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,41,149,51,70,0,0,32,0,97,45,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,158,16,21,141,0,0,16,1,97,45,56,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,155,121,149,127,0,0,16,1,103,48,53,95,99,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,45,43,88,16,0,0,16,1,102,48,53,95,99,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,32,157,87,1,0,0,32,0,104,48,53,95,99,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,240,114,88,79,0,0,32,0,110,48,55,95,99,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,178,142,175,16,0,0,32,0,107,48,55,95,99,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,4,243,118,149,0,0,32,0,111,48,55,95,99,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,220,212,217,177,0,0,32,0,108,48,55,95,99,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,74,190,152,69,0,0,32,0,116,48,55,95,99,49,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,66,94,66,245,0,0,32,0,112,48,55,95,99,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,124,161,80,203,0,0,32,0,118,48,55,95,99,49,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,199,163,155,149,0,0,32,0,115,48,55,95,99,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,197,145,46,127,0,0,32,0,100,48,49,95,99,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,92,238,177,129,0,0,32,0,101,48,49,95,99,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,115,54,211,208,0,0,32,0,102,48,49,95,99,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,149,22,232,170,0,0,32,0,100,48,52,95,99,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,29,16,133,155,0,0,64,0,118,103,95,98,45,56,114,46,105,99,57,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,122,138,54,223,0,0,32,0,118,103,95,98,45,52,109,46,105,99,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,4,66,202,219,0,0,32,0,118,103,95,98,45,49,98,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,103,81,46,146,0,0,32,0,109,109,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,246,6,36,101,0,0,16,1,109,109,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,66,11,4,251,0,0,16,1,109,109,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,97,255,124,143,0,0,16,1,103,103,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,111,91,95,97,0,0,16,1,103,103,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,7,207,252,236,0,0,32,0,103,103,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,169,111,213,221,0,0,32,0,103,103,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,157,82,2,115,0,0,32,0,103,103,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,218,91,3,32,0,0,32,0,103,103,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,113,162,43,241,0,0,32,0,103,103,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,125,32,37,229,0,0,32,0,103,103,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,178,233,119,45,0,0,32,0,103,103,49,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,143,10,229,147,0,0,32,0,103,103,49,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,202,229,215,6,0,0,32,0,103,103,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,45,224,31,188,0,0,32,0,103,103,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,249,18,175,106,0,0,32,0,103,103,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,202,63,12,232,0,0,32,0,103,103,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,37,169,128,119,0,0,32,0,116,98,112,50,52,115,49,48,46,49,52,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,88,81,175,14,0,0,32,0,54,51,115,49,52,49,46,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,164,133,18,74,0,0,32,0,51,48,97,49,52,45,48,46,105,99,56,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,22,224,47,244,0,0,16,1,51,48,97,49,53,45,48,46,105,99,55,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,44,233,80,173,0,0,16,1,51,48,97,49,51,45,48,46,105,99,52,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,155,77,151,30,0,0,16,1,49,52,46,105,99,52,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,123,162,54,176,0,0,32,0,49,53,46,105,99,52,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,65,191,208,36,0,0,32,0,51,48,46,105,99,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,22,43,254,114,0,0,32,0,51,49,46,105,99,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,200,160,72,171,0,0,32,0,50,51,46,105,99,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,221,254,104,7,0,0,32,0,50,52,46,105,99,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,138,177,157,236,0,0,32,0,50,49,46,105,99,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,185,68,39,144,0,0,32,0,50,50,46,105,99,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,77,45,20,91,0,0,32,0,57,46,105,99,51,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,183,73,108,114,0,0,32,0,49,48,46,105,99,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,53,195,161,55,0,0,32,0,49,49,46,105,99,52,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,60,230,207,43,0,0,32,0,49,50,46,105,99,52,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,23,207,100,184,0,0,32,0,52,46,105,99,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,6,235,113,140,0,0,32,0,53,46,105,99,51,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,233,75,19,62,0,0,32,0,54,46,105,99,51,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,240,94,17,180,0,0,32,0,55,46,105,99,51,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,61,51,57,70,0,0,32,0,49,54,46,105,99,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,200,12,66,4,0,0,32,0,49,55,46,105,99,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,47,123,249,51,0,0,32,0,49,56,46,105,99,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,42,143,154,15,0,0,32,0,49,57,46,105,99,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,114,23,201,21,0,0,32,0,50,53,46,105,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,179,52,71,137,0,0,32,0,50,54,46,105,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,132,69,80,205,0,0,32,0,50,55,46,105,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,173,169,232,56,0,0,32,0,50,56,46,105,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,116,203,193,128,0,0,32,0,51,48,97,49,50,45,48,46,105,99,52,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,76,0,218,145,0,0,32,0,51,48,97,49,49,45,48,46,105,99,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,50,146,65,95,0,0,32,0,51,48,97,49,48,45,48,46,105,99,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,186,65,246,18,0,0,32,0,51,48,97,57,45,48,46,105,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,123,167,153,145,0,0,32,0,50,46,105,99,55,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,190,29,242,58,0,0,64,0,51,46,105,99,55,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,205,83,139,194,0,0,64,0,51,48,46,105,99,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,67,116,60,17,0,0,32,0,49,97,95,52,98,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,121,116,241,118,0,0,16,1,49,97,95,52,100,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,110,240,25,129,0,0,16,1,49,97,95,54,98,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,34,88,75,186,0,0,16,1,49,97,95,54,100,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,246,82,72,202,0,0,16,1,49,97,95,55,98,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,186,27,119,208,0,0,16,1,49,97,95,55,100,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,217,89,157,2,0,0,16,1,49,97,95,57,98,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,86,123,34,105,0,0,16,1,49,97,95,57,100,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,66,41,103,90,0,0,16,1,50,97,95,49,53,98,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,17,59,76,96,0,0,16,1,50,97,95,49,55,98,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,141,137,252,175,0,0,16,1,50,97,95,49,56,98,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,171,192,45,48,0,0,16,1,50,97,95,49,54,98,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,4,56,26,89,0,0,32,0,49,97,95,49,53,102,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,127,89,74,152,0,0,32,0,49,97,95,49,55,102,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,255,151,226,48,0,0,32,0,50,97,95,54,101,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,11,116,247,188,0,0,32,0,50,97,95,55,101,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,92,86,11,167,0,0,32,0,50,97,95,54,103,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,230,195,158,74,0,0,32,0,50,97,95,55,103,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,252,73,7,69,0,0,32,0,116,99,49,97,95,49,48,102,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,68,197,7,206,0,0,32,0,116,99,49,97,95,49,49,102,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,58,50,109,86,0,0,32,0,116,99,49,97,95,49,50,102,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,70,57,166,126,0,0,32,0,116,99,50,97,95,50,103,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,173,155,96,8,0,0,32,0,116,99,50,97,95,52,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,31,153,67,44,0,0,32,0,49,97,95,52,98,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,121,116,241,118,0,0,16,1,49,97,95,52,100,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,110,240,25,129,0,0,16,1,49,97,95,54,98,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,34,88,75,186,0,0,16,1,49,97,95,54,100,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,246,82,72,202,0,0,16,1,49,97,95,55,98,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,186,27,119,208,0,0,16,1,49,97,95,55,100,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,217,89,157,2,0,0,16,1,49,97,95,57,98,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,86,123,34,105,0,0,16,1,49,97,95,57,100,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,66,41,103,90,0,0,16,1,116,99,50,97,95,49,53,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,169,223,13,121,0,0,16,1,116,99,50,97,95,49,55,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,19,17,83,212,0,0,16,1,50,97,95,49,54,98,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,4,56,26,89,0,0,32,0,49,97,95,49,53,102,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,127,89,74,152,0,0,32,0,49,97,95,49,55,102,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,255,151,226,48,0,0,32,0,50,97,95,54,101,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,11,116,247,188,0,0,32,0,50,97,95,55,101,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,92,86,11,167,0,0,32,0,50,97,95,54,103,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,230,195,158,74,0,0,32,0,50,97,95,55,103,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,252,73,7,69,0,0,32,0,116,99,49,97,95,49,48,102,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,68,197,7,206,0,0,32,0,116,99,49,97,95,49,49,102,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,58,50,109,86,0,0,32,0,116,99,49,97,95,49,50,102,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,70,57,166,126,0,0,32,0,116,99,50,97,95,50,103,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,173,155,96,8,0,0,32,0,116,99,50,97,95,52,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,31,153,67,44,0,0,32,0,51,49,101,49,51,45,48,46,105,99,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,167,38,74,119,0,0,16,1,51,49,101,49,52,45,48,46,105,99,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,7,184,187,5,0,0,16,1,51,49,97,49,49,45,50,46,105,99,52,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,234,191,222,93,0,0,16,1,51,49,101,49,50,45,48,46,105,99,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,21,38,242,6,0,0,32,0,51,49,106,48,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,80,180,18,138,0,0,32,0,51,49,106,49,46,105,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,85,113,237,130,0,0,32,0,51,49,106,51,46,105,99,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,29,207,149,227,0,0,32,0,51,49,106,50,46,105,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,101,116,169,181,0,0,32,0,51,49,106,53,46,105,99,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,232,69,229,44,0,0,32,0,51,49,106,52,46,105,99,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,106,182,237,0,0,0,32,0,51,49,106,54,46,105,99,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,248,108,149,121,0,0,32,0,51,49,106,55,46,105,99,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,195,116,215,116,0,0,32,0,51,49,106,57,46,105,99,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,137,114,56,221,0,0,32,0,51,49,106,56,46,105,99,49])
.concat([52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,39,225,171,68,0,0,32,0,51,49,106,49,48,46,105,99,55,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,219,46,82,108,0,0,64,0,51,49,106,49,51,45,48,46,105,99,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,13,120,71,33,0,0,16,1,51,49,106,49,52,45,48,46,105,99,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,71,199,111,215,0,0,16,1,51,49,97,49,49,45,50,46,105,99,52,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,234,191,222,93,0,0,16,1,51,49,106,49,50,45,48,46,105,99,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,224,31,130,244,0,0,32,0,51,49,106,48,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,80,180,18,138,0,0,32,0,51,49,106,49,46,105,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,85,113,237,130,0,0,32,0,51,49,106,51,46,105,99,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,29,207,149,227,0,0,32,0,51,49,106,50,46,105,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,101,116,169,181,0,0,32,0,51,49,106,53,46,105,99,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,232,69,229,44,0,0,32,0,51,49,106,52,46,105,99,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,106,182,237,0,0,0,32,0,51,49,106,54,46,105,99,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,248,108,149,121,0,0,32,0,51,49,106,55,46,105,99,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,195,116,215,116,0,0,32,0,51,49,106,57,46,105,99,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,137,114,56,221,0,0,32,0,51,49,106,56,46,105,99,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,39,225,171,68,0,0,32,0,51,49,106,49,48,46,105,99,55,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,219,46,82,108,0,0,64,0,51,48,106,49,53,46,105,99,55,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,188,140,97,64,0,0,16,1,51,48,106,49,52,46,105,99,55,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,128,126,130,150,0,0,16,1,51,48,106,49,51,46,105,99,52,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,155,77,151,30,0,0,16,1,51,48,106,45,55,46,105,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,50,141,213,137,0,0,32,0,51,48,106,45,54,46,105,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,142,83,241,155,0,0,32,0,51,48,106,45,53,46,105,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,98,26,103,143,0,0,32,0,51,48,106,45,52,46,105,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,28,234,116,15,0,0,32,0,51,48,106,45,51,46,105,99,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,113,24,21,179,0,0,32,0,51,48,106,49,50,45,48,46,105,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,215,144,146,30,0,0,32,0,51,48,106,45,50,46,105,99,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,8,251,198,65,0,0,32,0,51,48,106,49,49,45,48,46,105,99,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,42,91,25,153,0,0,32,0,51,48,106,45,49,46,105,99,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,20,241,166,103,0,0,32,0,51,48,106,49,48,45,48,46,105,99,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,93,155,135,227,0,0,32,0,51,48,106,45,48,46,105,99,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,190,175,93,241,0,0,32,0,51,48,106,57,45,48,46,105,99,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,132,174,89,39,0,0,32,0,51,48,106,45,56,46,105,99,55,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,243,64,173,195,0,0,64,0,109,98,55,49,49,52,104,46,105,99,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,67,116,60,17,0,0,32,0,115,111,48,52,46,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,179,191,242,211,0,0,16,1,115,111,48,51,46,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,114,244,1,237,0,0,16,1,115,111,48,50,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,165,172,32,202,0,0,16,1,118,116,48,49,46,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,224,38,87,80,0,0,32,0,118,116,49,49,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,72,27,46,123,0,0,32,0,118,116,49,50,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,211,23,180,129,0,0,32,0,118,116,49,51,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,210,219,18,86,0,0,32,0,118,116,49,52,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,54,238,45,43,0,0,32,0,118,116,49,53,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,191,186,112,222,0,0,32,0,118,116,49,54,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,55,130,23,20,0,0,32,0,118,116,48,53,46,55,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,61,110,241,121,0,0,32,0,118,116,48,54,46,56,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,33,229,254,38,0,0,32,0,118,116,48,55,46,57,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,253,189,136,202,0,0,32,0,118,116,48,56,46,55,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,131,200,25,32,0,0,32,0,118,116,48,57,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,130,57,112,152,0,0,32,0,118,116,49,48,46,57,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,248,210,105,240,0,0,32,0,118,116,98,49,46,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,161,21,186,58,0,0,32,0,118,116,98,50,46,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,84,87,134,136,0,0,32,0,118,116,98,51,46,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,246,195,20,76,0,0,32,0,118,116,98,52,46,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,70,194,136,179,0,0,32,0,118,116,98,53,46,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,8,197,42,113,0,0,32,0,118,116,98,54,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,88,81,175,14,0,0,32,0,98,109,48,49,98,46,49,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,61,159,63,54,0,0,16,1,98,109,48,50,98,46,49,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,220,126,13,127,0,0,16,1,98,109,48,51,98,46,49,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,42,218,147,112,0,0,16,1,98,109,48,52,46,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,215,210,43,238,0,0,16,1,98,109,48,53,46,52,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,61,157,203,70,0,0,32,0,98,109,49,53,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,67,4,26,107,0,0,32,0,98,109,49,54,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,194,8,201,35,0,0,32,0,98,109,49,55,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,7,221,188,70,0,0,32,0,98,109,49,56,46,49,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,160,123,174,230,0,0,32,0,98,109,49,57,46,49,48,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,188,186,138,134,0,0,32,0,98,109,50,48,46,49,49,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,212,229,23,9,0,0,32,0,98,109,50,49,46,49,50,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,137,13,251,155,0,0,32,0,98,109,50,50,46,49,52,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,116,194,243,4,0,0,32,0,98,109,50,52,46,49,52,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,54,64,19,17,0,0,32,0,98,109,50,53,46,49,52,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,193,249,44,9,0,0,32,0,98,109,48,54,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,175,200,172,151,0,0,32,0,98,109,48,55,46,49,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,151,113,143,215,0,0,32,0,98,109,48,56,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,8,102,98,26,0,0,32,0,98,109,48,57,46,49,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,132,64,146,0,0,32,0,98,109,49,48,46,49,48,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,74,164,56,132,0,0,32,0,98,109,49,49,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,29,53,105,108,0,0,32,0,98,109,49,50,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,183,253,126,94,0,0,32,0,98,109,49,51,46,49,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,154,130,67,17,0,0,32,0,98,109,49,52,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,1,100,60,77,0,0,32,0,98,109,50,51,46,56,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,189,236,42,165,0,0,32,0,98,109,49,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,24,31,66,116,0,0,32,0,98,109,50,46,49,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,31,84,39,172,0,0,32,0,98,109,51,46,49,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,255,182,31,37,0,0,32,0,98,109,53,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,208,19,103,32,0,0,32,0,98,109,49,48,46,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,28,73,194,51,0,0,32,0,98,109,57,46,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,247,74,234,174,0,0,32,0,98,109,49,50,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,54,161,138,193,0,0,32,0,98,109,49,49,46,49,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,55,174,90,64,0,0,32,0,98,109,56,46,56,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,158,10,1,194,0,0,32,0,98,109,55,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,195,48,111,181,0,0,32,0,98,109,52,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,225,162,168,145,0,0,32,0,98,109,54,46,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,88,81,175,14,0,0,32,0,98,109,46,55,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,16,110,98,45,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,245,253,252,147,0,0,16,1,116,97,49,56,45,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,205,245,64,242,0,0,16,1,110,48,45,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,59,222,135,53,0,0,16,1,116,97,49,56,45,50,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,163,190,210,155,0,0,32,0,116,97,49,56,45,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,36,80,241,218,0,0,32,0,116,97,49,56,45,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,72,162,89,31,0,0,32,0,110,55,45,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,50,165,165,124,0,0,32,0,116,97,49,56,45,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,33,0,76,153,0,0,32,0,116,97,49,56,45,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,170,232,185,85,0,0,32,0,116,97,49,56,45,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,154,201,117,4,0,0,32,0,116,97,49,56,45,50,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,57,65,213,199,0,0,32,0,116,97,49,56,45,50,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,69,125,103,132,0,0,32,0,116,97,49,56,45,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,83,8,119,28,0,0,32,0,116,97,49,56,45,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,23,96,101,175,0,0,32,0,116,97,49,56,45,50,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,247,156,209,63,0,0,32,0,116,97,49,56,45,49,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,110,76,198,116,0,0,32,0,116,97,49,56,45,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,215,95,121,200,0,0,32,0,116,97,49,56,45,50,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,245,47,58,223,0,0,32,0,116,97,49,56,45,49,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,208,186,68,114,0,0,32,0,116,97,49,56,45,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,70,77,177,182,0,0,32,0,116,97,49,56,45,50,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,155,0,94,201,0,0,32,0,116,97,49,56,45,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,1,29,214,165,0,0,32,0,116,97,49,56,45,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,237,243,227,2,0,0,32,0,116,97,49,56,45,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,19,38,49,201,0,0,32,0,116,97,49,56,45,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,5,71,237,7,0,0,32,0,109,99,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,16,16,109,100,106,95,48,52,46,56,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,177,235,187,158,0,0,16,1,109,100,106,95,48,51,46,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,45,156,87,165,0,0,16,1,109,103,95,48,50,46,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,22,190,94,159,0,0,16,1,109,103,95,48,49,46,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,240,42,234,28,0,0,16,1,109,103,95,48,53,46,49,52,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,69,201,191,47,0,0,16,1,109,103,95,48,54,46,49,48,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,155,229,46,56,0,0,32,0,108,115,45,49,50,46,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,108,44,27,108,0,0,32,0,108,115,45,49,49,46,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,100,28,248,107,0,0,32,0,109,103,95,109,49,49,46,114,111,109,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,100,154,49,238,0,0,32,0,109,103,95,109,48,55,46,114,111,109,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,17,178,192,229,0,0,32,0,109,103,95,109,49,50,46,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,32,241,126,136,0,0,32,0,109,103,95,109,48,56,46,114,111,109,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,163,154,112,89,0,0,32,0,109,103,95,109,49,51,46,114,111,109,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,180,125,224,234,0,0,32,0,109,103,95,109,48,57,46,114,111,109,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,235,131,238,64,0,0,32,0,109,103,95,109,49,52,46,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,76,66,229,33,0,0,32,0,109,103,95,109,49,48,46,114,111,109,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,84,251,74,182,0,0,32,0,108,115,45,48,54,46,49,48,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,91,154,211,136,0,0,64,0,108,115,45,48,53,46,49,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,181,3,110,176,0,0,64,0,50,57,46,49,52,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,30,46,134,127,0,0,32,0,118,103,95,97,45,56,104,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,19,135,132,186,0,0,16,1,118,103,95,97,45,56,108,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,216,177,18,59,0,0,16,1,103,48,53,95,99,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,45,43,88,16,0,0,16,1,102,48,53,95,99,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,32,157,87,1,0,0,32,0,104,48,53,95,99,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,240,114,88,79,0,0,32,0,110,48,55,95,99,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,178,142,175,16,0,0,32,0,107,48,55,95,99,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,4,243,118,149,0,0,32,0,111,48,55,95,99,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,220,212,217,177,0,0,32,0,108,48,55,95,99,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,74,190,152,69,0,0,32,0,116,48,55,95,99,49,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,66,94,66,245,0,0,32,0,112,48,55,95,99,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,124,161,80,203,0,0,32,0,118,48,55,95,99,49,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,199,163,155,149,0,0,32,0,115,48,55,95,99,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,197,145,46,127,0,0,32,0,100,48,49,95,99,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,92,238,177,129,0,0,32,0,101,48,49,95,99,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,115,54,211,208,0,0,32,0,102,48,49,95,99,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,149,22,232,170,0,0,32,0,100,48,52,95,99,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,29,16,133,155,0,0,64,0,118,103,95,98,45,56,114,46,105,99,57,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,122,138,54,223,0,0,32,0,118,103,95,98,45,52,109,46,105,99,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,4,66,202,219,0,0,32,0,118,103,95,98,45,49,98,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,103,81,46,146,0,0,32,0,100,104,48,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,141,194,107,166,0,0,16,1,100,104,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,46,230,118,208,0,0,16,1,105,56,55,53,49,46,109,99,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,24,100,104,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,88,232,12,125,0,0,32,0,100,104,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,114,223,109,184,0,0,32,0,100,104,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,242,148,111,223,0,0,32,0,100,104,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,234,251,205,162,0,0,32,0,100,104,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,231,195,181,238,0,0,32,0,100,104,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,29,210,24,142,0,0,32,0,100,104,45,48,57,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,79,155,4,206,0,0,32,0,100,104,45,48,56,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,15,24,242,205,0,0,32,0,18,0,0,0,255,255,223,0,0,0,0,0,19,0,0,0,255,255,251,0,0,0,0,0,0,0,0,0,254,0,16,0,32,4,2,0,18,0,0,0,1,15,2,0,144,102,8,0,18,0,0,0,1,15,5,0,176,45,8,0,18,0,0,0,1,15,8,0,224,127,8,0,18,0,0,0,1,15,4,0,136,252,1,0,18,0,0,0,1,15,1,0,0,67,1,0,18,0,0,0,1,15,15,0,32,123,8,0,18,0,0,0,1,15,3,0,232,143,1,0,18,0,0,0,1,15,7,0,248,116,8,0,18,0,0,0,1,15,14,0,192,110,8,0,18,0,0,0,1,15,6,0,168,36,1,0,18,0,0,0,1,15,13,0,96,102,7,0,18,0,0,0,1,15,12,0,184,105,6,0,18,0,0,0,1,15,11,0,152,96,3,0,18,0,0,0,1,15,10,0,192,100,6,0,18,0,0,0,1,15,9,0,64,1,1,0,18,0,0,0,1,15,0,0,104,151,6,0,0,0,0,0,254,0,2,0,144,248,8,0,18,0,0,0,1,16,16,0,200,87,7,0,18,0,0,0,1,16,0,0,160,123,6,0,0,0,0,0,254,0,2,0,168,234,7,0,18,0,0,0,1,32,32,0,96,135,7,0,18,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,18,0,0,0,1,64,64,0,96,135,7,0,18,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,18,0,0,0,1,128,128,0,96,135,7,0,18,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,19,0,0,0,1,3,3,0,8,49,4,0,19,0,0,0,1,3,2,0,152,21,4,0,19,0,0,0,1,3,1,0,72,246,3,0,19,0,0,0,1,3,0,0,64,47,7,0,0,0,0,0,254,0,2,0,200,30,2,0,19,0,0,0,1,4,0,0,120,97,1,0,19,0,0,0,1,4,4,0,96,19,1,0,0,0,0,0,254,0,4,0,64,37,5,0,19,0,0,0,1,24,24,0,64,185,8,0,19,0,0,0,1,24,16,0,8,176,8,0,19,0,0,0,1,24,8,0,232,140,2,0,19,0,0,0,1,24,0,0,208,129,2,0,0,0,0,0,254,0,4,0,72,202,5,0,19,0,0,0,1,96,64,0,80,246,3,0,19,0,0,0,1,96,96,0,248,38,7,0,19,0,0,0,1,96,32,0,48,123,8,0,19,0,0,0,1,96,0,0,8,117,8,0,0,0,0,0,254,0,2,0,144,246,3,0,19,0,0,0,1,128,128,0,96,135,7,0,19,0,0,0,1,128,0,0,152,182,7,0,18,0,0,0,255,255,255,0,0,0,0,0,19,0,0,0,255,255,251,0,0,0,0,0,0,0,0,0,254,0,4,0,200,87,7,0,18,0,0,0,1,12,0,0,104,236,7,0,18,0,0,0,1,12,12,0,128,230,7,0,18,0,0,0,1,12,8,0,184,164,6,0,18,0,0,0,1,12,4,0,80,74,6,0,0,0,0,0,254,0,4,0,160,123,6,0,18,0,0,0,1,3,0,0,104,236,7,0,18,0,0,0,1,3,3,0,128,230,7,0,18,0,0,0,1,3,2,0,184,164,6,0,18,0,0,0,1,3,1,0,80,74,6,0,0,0,0,0,254,0,2,0,168,234,7,0,18,0,0,0,1,64,0,0,96,135,7,0,18,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,4,0,72,84,4,0,19,0,0,0,1,3,0,0,248,194,5,0,19,0,0,0,1,3,3,0,248,81,6,0,19,0,0,0,1,3,2,0,80,124,6,0,19,0,0,0,1,3,1,0,176,64,8,0,0,0,0,0,254,0,4,0,128,129,4,0,19,0,0,0,1,12,4,0,208,75,4,0,19,0,0,0,1,12,8,0,8,49,4,0,19,0,0,0,1,12,12,0,72,0,3,0,19,0,0,0,1,12,0,0,112,49,6,0,0,0,0,0,254,0,4,0,64,37,5,0,19,0,0,0,1,48,48,0,248,98,4,0,19,0,0,0,1,48,32,0,80,72,4,0,19,0,0,0,1,48,16,0,248,43,4,0,19,0,0,0,1,48,0,0,80,72,4,0,109,109,95,99,95,48,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,15,19,148,79,0,0,16,1,109,109,95,99,95,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,138,19,239,29,0,0,16,1,109,109,95,99,95,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,110,232,40,237,0,0,16,1,103,103,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,111,91,95,97,0,0,16,1,103,103,49,46,98,105,110,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,7,207,252,236,0,0,32,0,103,103,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,169,111,213,221,0,0,32,0,103,103,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,157,82,2,115,0,0,32,0,103,103,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,218,91,3,32,0,0,32,0,103,103,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,113,162,43,241,0,0,32,0,103,103,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,125,32,37,229,0,0,32,0,103,103,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,178,233,119,45,0,0,32,0,103,103,49,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,143,10,229,147,0,0,32,0,103,103,49,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,202,229,215,6,0,0,32,0,103,103,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,45,224,31,188,0,0,32,0,103,103,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,249,18,175,106,0,0,32,0,103,103,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,202,63,12,232,0,0,32,0,103,103,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,37,169,128,119,0,0,32,0,116,98,112,50,52,115,49,48,46,49,52,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,88,81,175,14,0,0,32,0,54,51,115,49,52,49,46,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,164,133,18,74,0,0,32,0,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,164,179,43,99,0,0,16,1,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,156,54,115,234,0,0,16,1,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,162,205,232,217,0,0,16,1,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,117,245,14,82,0,0,32,0,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,235,214,228,53,0,0,32,0,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,178,165,84,160,0,0,32,0,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,54,1,31,16,0,0,32,0,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,167,203,46,123,0,0,32,0,119,102,95,48,57,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,29,207,149,227,0,0,32,0,119,102,95,48,56,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,101,116,169,181,0,0,32,0,119,102,95,49,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,232,69,229,44,0,0,32,0,119,102,95,49,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,106,182,237,0,0,0,32,0,119,102,95,49,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,248,108,149,121,0,0,32,0,119,102,95,49,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,195,116,215,116,0,0,32,0,119,102,95,49,53,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,137,114,56,221,0,0,32,0,119,102,95,49,52,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,39,225,171,68,0,0,32,0,119,102,95,55,51,97,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,219,46,82,108,0,0,64,0,100,100,51,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,139,29,50,104,0,0,16,1,100,100,51,46,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,59,118,5,188,0,0,16,1,100,100,51,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,117,174,217,56,0,0,16,1,100,100,51,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,155,77,151,30,0,0,16,1,100,100,51,46,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,50,141,213,137,0,0,32,0,100,100,51,46,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,142,83,241,155,0,0,32,0,100,100,51,46,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,98,26,103,143,0,0,32,0,100,100,51,46,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,28,234,116,15,0,0,32,0,100,100,51,46,51,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,183,73,108,114,0,0,32,0,100,100,51,46,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,53,195,161,55,0,0,32,0,100,100,51,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,60,230,207,43,0,0,32,0,100,100,51,46,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,23,207,100,184,0,0,32,0,100,100,51,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,234,75,214,32,0,0,32,0,100,100,51,46,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,6,235,113,140,0,0,32,0,100,100,51,46,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,233,75,19,62,0,0,32,0,100,100,51,46,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,240,94,17,180,0,0,32,0,100,100,51,46,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,61,51,57,70,0,0,32,0,100,100,51,46,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,176,113,93,120,0,0,32,0,100,100,51,46,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,200,12,66,4,0,0,32,0,100,100,51,46,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,47,123,249,51,0,0,32,0,100,100,51,46,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,42,143,154,15,0,0,32,0,100,100,51,46,49,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,114,23,201,21,0,0,32,0,100,100,51,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,18,61,228,21,0,0,32,0,100,100,51,46,48,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,179,52,71,137,0,0,32,0,100,100,51,46,48,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,132,69,80,205,0,0,32,0,100,100,51,46,48,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,173,169,232,56,0,0,32,0,100,100,51,46,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,116,203,193,128,0,0,32,0,100,100,51,46,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,164,231,71,90,0,0,32,0,100,100,51,46,106,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,190,29,242,58,0,0,64,0,100,100,51,46,106,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,205,83,139,194,0,0,64,0,109,98,55,49,49,52,104,46,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,67,116,60,17,0,0,32,0,115,114,45,48,51,46,109,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,242,117,41,97,0,0,16,1,115,114,45,48,52,46,109,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,68,198,10,166,0,0,16,1,115,114,45,48,53,46,109,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,36,123,95,131,0,0,16,1,115,114,45,48,54,46,109,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,129,100,28,130,0,0,16,1,115,114,45,48,55,46,109,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,225,37,245,93,0,0,16,1,115,114,45,48,49,46,99,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,107,240,135,189,0,0,16,1,115,114,45,48,50,46,102,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,145,161,188,110,0,0,32,0,115,114,45,48,56,46,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,235,217,132,56,0,0,32,0,115,114,45,48,57,46,97,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,224,246,156,153,0,0,32,0,115,114,45,49,48,46,97,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,58,39,219,142,0,0,32,0,115,114,45,49,49,46,97,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,195,38,39,58,0,0,32,0,115,114,45,49,50,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,187,216,211,27,0,0,32,0,115,114,45,49,51,46,97,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,196,2,143,101,0,0,32,0,115,114,45,49,52,46,108,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,198,190,40,37,0,0,32,0,115,114,45,49,53,46,108,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,170,135,146,248,0,0,32,0,115,114,45,49,54,46,110,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,248,24,68,2,0,0,32,0,115,114,45,49,55,46,110,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,137,228,199,226,0,0,32,0,115,98,45,53,46,101,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,83,129,171,147,0,0,32,0,115,98,45,54,46,101,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,125,79,180,138,0,0,32,0,115,98,45,55,46,101,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,164,233,173,244,0,0,32,0,115,98,45,48,46,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,27,217,71,96,0,0,32,0,115,98,45,52,46,100,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,141,150,88,72,0,0,32,0,115,98,45,56,46,107,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,67,217,250,246,0,0,32,0,115,98,45,50,46,100,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,223,179,184,139,0,0,32,0,115,98,45,51,46,100,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,175,153,12,59,0,0,32,0,115,98,45,49,46,107,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,8,197,42,113,0,0,32,0,115,98,45,57,46,109,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,92,99,33,73,0,0,32,0,99,111,109,109,97,110,100,111,98,95,48,52,95,57,109,95,50,55,50,53,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,84,118,138,52,0,0,16,1,99,109,48,51,46,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,66,101,72,53,0,0,16,1,99,109,48,50,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,116,74,204,249,0,0,16,1,118,116,48,49,46,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,224,38,87,80,0,0,32,0,118,116,49,49,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,72,27,46,123,0,0,32,0,118,116,49,50,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,211,23,180,129,0,0,32,0,118,116,49,51,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,210,219,18,86,0,0,32,0,118,116,49,52,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,54,238,45,43,0,0,32,0,118,116,49,53,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,191,186,112,222,0,0,32,0,118,116,49,54,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,55,130,23,20,0,0,32,0,118,116,48,53,46,55,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,61,110,241,121,0,0,32,0,118,116,48,54,46,56,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,33,229,254,38,0,0,32,0,118,116,48,55,46,57,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,253,189,136,202,0,0,32,0,118,116,48,56,46,55,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,131,200,25,32,0,0,32,0,118,116,48,57,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,130,57,112,152,0,0,32,0,118,116,49,48,46,57,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,248,210,105,240,0,0,32,0,118,116,98,49,46,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,161,21,186,58,0,0,32,0,118,116,98,50,46,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,84,87,134,136,0,0,32,0,118,116,98,51,46,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,246,195,20,76,0,0,32,0,118,116,98,52,46,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,70,194,136,179,0,0,32,0,118,116,98,53,46,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,8,197,42,113,0,0,32,0,118,116,98,54,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,88,81,175,14,0,0,32,0,99,111,109,109,97,110,100,111,98,95,112,97,108,49,54,108,56,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,0,0,0,24,49,46,49,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,171,112,45,154,0,0,16,1,98,109,48,50,46,49,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,117,21,151,175,0,0,16,1,98,109,48,51,46,49,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,19,199,14,48,0,0,16,1,98,109,48,52,46,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,215,210,43,238,0,0,16,1,52,46,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,150,32,186,10,0,0,32,0,49,53,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,186,79,43,98,0,0,32,0,49,54,46,49,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,141,26,71,37,0,0,32,0,49,55,46,49,50,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,83,150,167,157,0,0,32,0,49,56,46,49,52,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,216,206,58,31,0,0,32,0,98,109,50,52,46,49,52,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,54,64,19,17,0,0,32,0,98,109,50,53,46,49,52,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,193,249,44,9,0,0,32,0,98,109,48,54,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,175,200,172,151,0,0,32,0,98,109,48,55,46,49,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,151,113,143,215,0,0,32,0,98,109,48,56,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,8,102,98,26,0,0,32,0,98,109,48,57,46,49,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,132,64,146,0,0,32,0,98,109,49,48,46,49,48,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,74,164,56,132,0,0,32,0,98,109,49,49,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,29,53,105,108,0,0,32,0,98,109,49,50,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,183,253,126,94,0,0,32,0,98,109,49,51,46,49,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,154,130,67,17,0,0,32,0,98,109,49,52,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,1,100,60,77,0,0,32,0,98,109,50,51,46,56,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,189,236,42,165,0,0,32,0,98,109,49,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,24,31,66,116,0,0,32,0,98,109,50,46,49,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,31,84,39,172,0,0,32,0,98,109,51,46,49,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,255,182,31,37,0,0,32,0,98,109,53,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,208,19,103,32,0,0,32,0,98,109,49,48,46,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,28,73,194,51,0,0,32,0,98,109,57,46,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,247,74,234,174,0,0,32,0,98,109,49,50,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,54,161,138,193,0,0,32,0,98,109,49,49,46,49,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,55,174,90,64,0,0,32,0,98,109,56,46,56,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,158,10,1,194,0,0,32,0,98,109,55,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,195,48,111,181,0,0,32,0,98,109,52,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,225,162,168,145,0,0,32,0,98,109,54,46,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,88,81,175,14,0,0,32,0,116,97,49,56,45,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,74,244,12,169,0,0,16,1,116,97,49,56,45,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,205,245,64,242,0,0,16,1,110,48,45,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,59,222,135,53,0,0,16,1,116,97,49,56,45,50,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,163,190,210,155,0,0,32,0,116,97,49,56,45,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,36,80,241,218,0,0,32,0,116,97,49,56,45,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,72,162,89,31,0,0,32,0,110,55,45,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,50,165,165,124,0,0,32,0,116,97,49,56,45,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,33,0,76,153,0,0,32,0,116,97,49,56,45,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,170,232,185,85,0,0,32,0,116,97,49,56,45,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,154,201,117,4,0,0,32,0,116,97,49,56,45,50,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,57,65,213,199,0,0,32,0,116,97,49,56,45,50,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,69,125,103,132,0,0,32,0,116,97,49,56,45,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,83,8,119,28,0,0,32,0,116,97,49,56,45,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,23,96,101,175,0,0,32,0,116,97,49,56,45,50,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,247,156,209,63,0,0,32,0,116,97,49,56,45,49,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,110,76,198,116,0,0,32,0,116,97,49,56,45,49,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,215,95,121,200,0,0,32,0,116,97,49,56,45,50,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,245,47,58,223,0,0,32,0,116,97,49,56,45,49,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,208,186,68,114,0,0,32,0,116,97,49,56,45,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,70,77,177,182,0,0,32,0,116,97,49,56,45,50,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,155,0,94,201,0,0,32,0,116,97,49,56,45,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,1,29,214,165,0,0,32,0,116,97,49,56,45,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,237,243,227,2,0,0,32,0,116,97,49,56,45,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,19,38,49,201,0,0,32,0,116,97,49,56,45,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,5,71,237,7,0,0,32,0,50,49,106,45,49,46,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,100,73,113,174,0,0,16,1,50,49,106,45,50,45,51,46,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,94,112,121,87,0,0,16,1,50,49,97,45,51,46,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,151,72,242,219,0,0,16,1,50,49,106,45,52,46,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,250,70,159,108,0,0,16,1,105,99,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,37,3,106,106,0,0,16,1,50,49,106,45,48,45,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,187,149,250,158,0,0,16,1,50,49,106,45,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,180,141,139,122,0,0,32,0,50,49,106,45,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,227,172,79,87,0,0,32,0,50,49,106,45,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,118,122,80,64,0,0,32,0,50,49,106,45,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,111,199,11,187,0,0,32,0,50,49,106,45,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,27,35,79,203,0,0,32,0,50,49,106,45,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,97,194,160,160,0,0,32,0])
.concat([50,49,106,45,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,246,82,161,107,0,0,32,0,50,49,106,45,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,182,160,32,50,0,0,32,0,50,49,106,45,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,125,81,199,101,0,0,32,0,50,49,106,45,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,135,88,67,124,0,0,32,0,50,49,106,45,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,237,10,100,198,0,0,32,0,50,49,106,45,105,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,160,176,255,94,0,0,32,0,50,49,106,45,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,124,46,180,95,0,0,32,0,50,49,106,45,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,227,93,117,52,0,0,32,0,50,49,106,45,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,248,230,77,144,0,0,32,0,50,49,106,45,107,45,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,169,48,177,253,0,0,32,0,50,49,106,45,108,45,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,41,149,51,70,0,0,32,0,115,112,95,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,75,229,111,60,0,0,16,1,115,112,95,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,205,129,127,52,0,0,16,1,100,104,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,46,230,118,208,0,0,16,1,115,112,95,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,105,121,111,157,0,0,32,0,115,112,95,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,67,78,14,88,0,0,32,0,115,112,95,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,210,113,171,5,0,0,32,0,100,104,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,234,251,205,162,0,0,32,0,100,104,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,231,195,181,238,0,0,32,0,100,104,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,29,210,24,142,0,0,32,0,100,104,45,48,57,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,79,155,4,206,0,0,32,0,100,104,45,48,56,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,15,24,242,205,0,0,32,0,28,0,0,0,255,255,16,0,0,0,0,0,29,0,0,0,255,255,255,0,0,0,0,0,30,0,0,0,255,255,255,0,0,0,0,0,31,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,28,0,0,0,1,16,16,0,96,135,7,0,28,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,4,0,32,4,2,0,29,0,0,0,1,3,0,0,16,242,7,0,29,0,0,0,1,3,1,0,104,236,7,0,29,0,0,0,1,3,3,0,128,230,7,0,29,0,0,0,1,3,2,0,184,164,6,0,0,0,0,0,254,0,2,0,0,76,5,0,29,0,0,0,1,16,16,0,96,135,7,0,29,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,29,0,0,0,1,32,0,0,96,135,7,0,29,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,30,0,0,0,1,3,2,0,80,246,3,0,30,0,0,0,1,3,3,0,248,38,7,0,30,0,0,0,1,3,1,0,112,212,3,0,30,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,2,0,136,79,3,0,30,0,0,0,1,4,4,0,96,135,7,0,30,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,184,89,6,0,30,0,0,0,1,16,16,0,96,135,7,0,30,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,2,0,24,254,3,0,30,0,0,0,1,32,0,0,96,135,7,0,30,0,0,0,1,32,32,0,136,66,4,0,0,0,0,0,254,0,2,0,80,109,5,0,31,0,0,0,1,1,0,0,56,132,5,0,31,0,0,0,1,1,1,0,152,29,3,0,0,0,0,0,254,0,2,0,232,119,7,0,31,0,0,0,1,2,2,0,208,75,4,0,31,0,0,0,1,2,0,0,8,49,4,0,18,0,0,0,255,255,255,0,0,0,0,0,19,0,0,0,255,255,251,0,0,0,0,0,0,0,0,0,254,0,4,0,200,87,7,0,18,0,0,0,1,12,0,0,80,252,6,0,18,0,0,0,1,12,4,0,16,242,7,0,18,0,0,0,1,12,8,0,104,236,7,0,18,0,0,0,1,12,12,0,128,230,7,0,0,0,0,0,254,0,4,0,160,123,6,0,18,0,0,0,1,3,3,0,184,164,6,0,18,0,0,0,1,3,2,0,80,74,6,0,18,0,0,0,1,3,1,0,192,32,6,0,18,0,0,0,1,3,0,0,32,242,5,0,0,0,0,0,254,0,2,0,168,234,7,0,18,0,0,0,1,64,0,0,96,135,7,0,18,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,4,0,72,84,4,0,19,0,0,0,1,3,0,0,248,194,5,0,19,0,0,0,1,3,3,0,80,124,6,0,19,0,0,0,1,3,2,0,176,64,8,0,19,0,0,0,1,3,1,0,128,65,6,0,0,0,0,0,254,0,4,0,128,129,4,0,19,0,0,0,1,12,4,0,208,75,4,0,19,0,0,0,1,12,8,0,8,49,4,0,19,0,0,0,1,12,12,0,72,0,3,0,19,0,0,0,1,12,0,0,112,49,6,0,0,0,0,0,119,102,95,49,57,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,196,227,2,189,0,0,16,1,119,102,95,49,56,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,160,161,62,147,0,0,16,1,51,49,97,49,49,45,50,46,105,99,52,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,234,191,222,93,0,0,16,1,51,49,101,49,50,45,48,46,105,99,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,21,38,242,6,0,0,32,0,51,49,106,48,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,80,180,18,138,0,0,32,0,51,49,106,49,46,105,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,85,113,237,130,0,0,32,0,51,49,106,51,46,105,99,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,29,207,149,227,0,0,32,0,51,49,106,50,46,105,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,101,116,169,181,0,0,32,0,51,49,106,53,46,105,99,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,232,69,229,44,0,0,32,0,51,49,106,52,46,105,99,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,106,182,237,0,0,0,32,0,51,49,106,54,46,105,99,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,248,108,149,121,0,0,32,0,51,49,106,55,46,105,99,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,195,116,215,116,0,0,32,0,51,49,106,57,46,105,99,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,137,114,56,221,0,0,32,0,51,49,106,56,46,105,99,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,39,225,171,68,0,0,32,0,51,49,106,49,48,46,105,99,55,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,219,46,82,108,0,0,64,0,49,97,95,52,98,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,121,116,241,118,0,0,16,1,49,97,95,52,100,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,110,240,25,129,0,0,16,1,49,97,95,54,98,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,34,88,75,186,0,0,16,1,49,97,95,54,100,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,246,82,72,202,0,0,16,1,49,97,95,55,98,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,186,27,119,208,0,0,16,1,49,97,95,55,100,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,217,89,157,2,0,0,16,1,49,97,95,57,98,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,86,123,34,105,0,0,16,1,49,97,95,57,100,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,66,41,103,90,0,0,16,1,50,97,95,49,53,98,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,17,59,76,96,0,0,16,1,100,103,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,8,56,155,158,0,0,16,1,50,97,95,49,56,98,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,171,192,45,48,0,0,16,1,50,97,95,49,54,98,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,4,56,26,89,0,0,32,0,49,97,95,49,53,102,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,127,89,74,152,0,0,32,0,49,97,95,49,55,102,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,255,151,226,48,0,0,32,0,50,97,95,54,101,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,11,116,247,188,0,0,32,0,50,97,95,55,101,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,92,86,11,167,0,0,32,0,50,97,95,54,103,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,230,195,158,74,0,0,32,0,50,97,95,55,103,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,252,73,7,69,0,0,32,0,116,99,49,97,95,49,48,102,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,68,197,7,206,0,0,32,0,116,99,49,97,95,49,49,102,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,58,50,109,86,0,0,32,0,116,99,49,97,95,49,50,102,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,70,57,166,126,0,0,32,0,116,99,50,97,95,50,103,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,173,155,96,8,0,0,32,0,116,99,50,97,95,52,101,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,31,153,67,44,0,0,32,0,115,114,97,45,48,51,46,109,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,171,27,32,64,0,0,16,1,115,114,45,48,52,46,109,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,68,198,10,166,0,0,16,1,115,114,45,48,53,46,109,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,36,123,95,131,0,0,16,1,115,114,45,48,54,46,109,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,129,100,28,130,0,0,16,1,115,114,45,48,55,46,109,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,225,37,245,93,0,0,16,1,115,114,45,48,49,46,99,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,107,240,135,189,0,0,16,1,115,114,45,48,50,46,102,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,145,161,188,110,0,0,32,0,115,114,45,48,56,46,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,235,217,132,56,0,0,32,0,115,114,45,48,57,46,97,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,224,246,156,153,0,0,32,0,115,114,45,49,48,46,97,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,58,39,219,142,0,0,32,0,115,114,45,49,49,46,97,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,195,38,39,58,0,0,32,0,115,114,45,49,50,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,187,216,211,27,0,0,32,0,115,114,45,49,51,46,97,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,196,2,143,101,0,0,32,0,115,114,45,49,52,46,108,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,198,190,40,37,0,0,32,0,115,114,45,49,53,46,108,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,170,135,146,248,0,0,32,0,115,114,45,49,54,46,110,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,248,24,68,2,0,0,32,0,115,114,45,49,55,46,110,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,137,228,199,226,0,0,32,0,115,98,45,53,46,101,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,83,129,171,147,0,0,32,0,115,98,45,54,46,101,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,125,79,180,138,0,0,32,0,115,98,45,55,46,101,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,164,233,173,244,0,0,32,0,115,98,45,48,46,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,27,217,71,96,0,0,32,0,115,98,45,52,46,100,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,141,150,88,72,0,0,32,0,115,98,45,56,46,107,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,67,217,250,246,0,0,32,0,115,98,45,50,46,100,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,223,179,184,139,0,0,32,0,115,98,45,51,46,100,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,175,153,12,59,0,0,32,0,115,98,45,49,46,107,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,8,197,42,113,0,0,32,0,115,98,45,57,46,109,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,92,99,33,73,0,0,32,0,103,110,103,46,110,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,136,49,52,96,0,0,16,1,103,110,103,46,110,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,251,28,185,182,0,0,16,1,103,110,103,46,110,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,40,169,207,165,0,0,16,1,103,110,103,46,110,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,218,141,154,253,0,0,16,1,103,110,103,46,110,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,56,98,207,19,0,0,16,1,103,103,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,111,91,95,97,0,0,16,1,103,103,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,7,207,252,236,0,0,32,0,103,103,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,169,111,213,221,0,0,32,0,103,103,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,157,82,2,115,0,0,32,0,103,103,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,218,91,3,32,0,0,32,0,103,103,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,113,162,43,241,0,0,32,0,103,103,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,125,32,37,229,0,0,32,0,103,103,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,178,233,119,45,0,0,32,0,103,103,49,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,143,10,229,147,0,0,32,0,103,103,49,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,202,229,215,6,0,0,32,0,103,103,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,45,224,31,188,0,0,32,0,103,103,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,249,18,175,106,0,0,32,0,103,103,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,202,63,12,232,0,0,32,0,103,103,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,37,169,128,119,0,0,32,0,116,98,112,50,52,115,49,48,46,49,52,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,88,81,175,14,0,0,32,0,54,51,115,49,52,49,46,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,164,133,18,74,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,54,97,57,45,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,73,198,207,242,0,0,16,1,50,54,97,97,45,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,75,93,221,68,0,0,16,1,50,54,97,98,45,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,205,221,221,73,0,0,16,1,50,54,97,99,45,48,101,46,54,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,44,173,172,87,0,0,16,1,50,54,97,101,45,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,103,120,67,234,0,0,16,1,50,54,97,100,45,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,214,108,227,117,0,0,16,1,50,54,97,56,45,48,101,46,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,54,205,128,78,0,0,32,0,50,54,106,48,45,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,132,156,48,219,0,0,32,0,50,54,106,49,45,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,12,30,8,195,0,0,32,0,50,54,97,102,45,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,173,90,97,58,0,0,32,0,50,54,106,50,45,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,174,100,149,88,0,0,32,0,50,54,106,51,45,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,214,64,240,218,0,0,32,0,50,54,97,49,48,45,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,137,216,22,109,0,0,32,0,50,54,106,52,45,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,118,62,201,168,0,0,32,0,50,54,106,53,45,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,55,82,85,238,0,0,32,0,50,54,106,54,45,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,41,42,75,168,0,0,32,0,50,54,106,55,45,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,213,72,106,188,0,0,32,0,112,114,111,109,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,41,149,51,70,0,0,32,0,20,0,0,0,255,255,255,0,0,0,0,0,21,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,8,0,200,87,7,0,20,0,0,0,1,7,0,0,144,102,8,0,20,0,0,0,1,7,1,0,176,45,8,0,20,0,0,0,1,7,2,0,224,127,8,0,20,0,0,0,1,7,7,0,32,123,8,0,20,0,0,0,1,7,6,0,192,110,8,0,20,0,0,0,1,7,5,0,96,102,7,0,20,0,0,0,1,7,4,0,184,105,6,0,20,0,0,0,1,7,3,0,152,96,3,0,0,0,0,0,254,0,8,0,160,123,6,0,20,0,0,0,1,56,0,0,144,102,8,0,20,0,0,0,1,56,8,0,176,45,8,0,20,0,0,0,1,56,16,0,224,127,8,0,20,0,0,0,1,56,56,0,32,123,8,0,20,0,0,0,1,56,48,0,192,110,8,0,20,0,0,0,1,56,40,0,96,102,7,0,20,0,0,0,1,56,32,0,184,105,6,0,20,0,0,0,1,56,24,0,152,96,3,0,0,0,0,0,254,0,2,0,200,30,2,0,20,0,0,0,1,64,64,0,120,97,1,0,20,0,0,0,1,64,0,0,96,19,1,0,0,0,0,0,254,0,2,0,144,212,8,0,20,0,0,0,1,128,128,0,96,135,7,0,20,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,192,6,2,0,21,0,0,0,1,8,0,0,80,246,3,0,21,0,0,0,1,8,8,0,248,38,7,0,0,0,0,0,254,0,4,0,216,238,6,0,21,0,0,0,1,48,0,0,176,63,4,0,21,0,0,0,1,48,16,0,152,215,1,0,21,0,0,0,1,48,48,0,104,142,4,0,21,0,0,0,1,48,32,0,56,43,1,0,0,0,0,0,254,0,4,0,128,129,4,0,21,0,0,0,1,192,192,0,192,255,2,0,21,0,0,0,1,192,128,0,208,75,4,0,21,0,0,0,1,192,64,0,8,49,4,0,21,0,0,0,1,192,0,0,152,21,4,0,0,0,0,0,118,103,95,97,45,56,104,45,99,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,232,130,38,215,0,0,16,1,118,103,95,97,45,56,108,45,97,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,47,129,13,105,0,0,16,1,103,48,53,95,99,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,45,43,88,16,0,0,16,1,102,48,53,95,99,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,32,157,87,1,0,0,32,0,104,48,53,95,99,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,240,114,88,79,0,0,32,0,110,48,55,95,99,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,178,142,175,16,0,0,32,0,107,48,55,95,99,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,4,243,118,149,0,0,32,0,111,48,55,95,99,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,220,212,217,177,0,0,32,0,108,48,55,95,99,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,74,190,152,69,0,0,32,0,116,48,55,95,99,49,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,66,94,66,245,0,0,32,0,112,48,55,95,99,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,124,161,80,203,0,0,32,0,118,48,55,95,99,49,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,199,163,155,149,0,0,32,0,115,48,55,95,99,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,197,145,46,127,0,0,32,0,100,48,49,95,99,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,92,238,177,129,0,0,32,0,101,48,49,95,99,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,115,54,211,208,0,0,32,0,102,48,49,95,99,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,149,22,232,170,0,0,32,0,100,48,52,95,99,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,29,16,133,155,0,0,64,0,118,103,95,98,45,56,114,46,105,99,57,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,122,138,54,223,0,0,32,0,118,103,95,98,45,52,109,46,105,99,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,4,66,202,219,0,0,32,0,118,103,95,98,45,49,98,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,103,81,46,146,0,0,32,0,0,0,0,0,32,0,0,0,64,0,0,0,96,0,0,0,99,100,101,95,50,51,97,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,94,88,78,143,2,0,16,1,99,100,101,95,50,50,97,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,18,170,120,146,2,0,16,1,99,100,101,95,50,49,97,46,54,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,226,61,210,102,2,0,16,1,99,100,45,49,109,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,23,249,164,141,4,0,32,0,99,100,45,51,109,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,3,246,64,108,4,0,32,0,99,100,45,50,109,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,45,252,200,9,4,0,32,0,99,100,45,52,109,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,143,243,127,99,4,0,32,0,99,100,45,53,109,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,238,239,11,71,4,0,32,0,99,100,45,55,109,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,163,183,191,34,4,0,32,0,99,100,45,54,109,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,196,154,89,231,4,0,32,0,99,100,45,56,109,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,21,75,27,33,4,0,32,0,99,100,95,113,46,53,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,11,219,95,96,3,0,16,0,99,100,45,113,49,46,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,117,119,146,96,6,0,64,0,99,100,45,113,50,46,50,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,71,76,15,119,6,0,64,0,99,100,45,113,51,46,51,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,252,63,39,47,6,0,64,0,99,100,45,113,52,46,52,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,29,130,103,44,6,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,154,135,134,67,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,99,100,54,51,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,2,233,114,239,0,0,0,8,105,111,98,49,46,49,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,98,112,114,103,49,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,167,61,121,49,0,0,0,8,105,111,99,49,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,129,32,24,13,0,0,0,8,100,55,108,49,46,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,13,65,183,39,0,0,0,8,100,56,108,49,46,56,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,218,199,159,83,0,0,0,8,100,57,107,50,46,57,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,86,161,133,205,0,0,0,8,100,49,48,102,49,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,148,196,25,102,0,0,0,8,27,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,72,4,1,0,27,0,0,0,1,8,0,0,96,135,7,0,27,0,0,0,1,8,8,0,152,182,7,0,101,112,114,45,49,49,49,57,49,46,97,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,10,64,14,80,1,0,16,1,101,112,114,45,49,49,49,57,48,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,8,131,105,42,1,0,16,1,101,112,114,45,49,49,57,49,53,46,97,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,50,49,237,216,1,0,16,1,101,112,114,45,49,49,57,49,51,46,97,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,146,203,198,48,1,0,16,1,109,112,114,45,49,49,57,49,55,46,97,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,144,33,119,111,2,0,32,0,109,112,114,45,49,49,57,49,56,46,97,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,149,219,49,199,2,0,32,0,109,112,114,45,49,49,57,49,57,46,97,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,145,164,213,100,2,0,32,0,109,112,114,45,49,49,57,50,48,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,205,227,209,229,3,0,32,0,109,112,114,45,49,49,57,50,50,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,221,196,176,112,3,0,32,0,109,112,114,45,49,49,57,50,49,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,140,53,210,97,3,0,32,0,109,112,114,45,49,49,57,50,51,46,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,125,228,255,201,3,0,32,0,101,112,114,45,49,49,57,49,54,46,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,207,65,181,122,4,0,16,1,51,49,55,45,48,48,57,54,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,110,210,215,111,5,0,16,1,19,0,0,0,255,255,254,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,1,1,0,96,135,7,0,19,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,19,0,0,0,1,6,4,0,80,246,3,0,19,0,0,0,1,6,6,0,248,38,7,0,19,0,0,0,1,6,2,0,112,212,3,0,19,0,0,0,1,6,0,0,248,160,5,0,0,0,0,0,254,0,4,0,128,129,4,0,19,0,0,0,1,24,16,0,208,75,4,0,19,0,0,0,1,24,24,0,8,49,4,0,19,0,0,0,1,24,8,0,152,21,4,0,19,0,0,0,1,24,0,0,72,246,3,0,0,0,0,0,254,0,4,0,64,37,5,0,19,0,0,0,1,96,64,0,24,145,2,0,19,0,0,0,1,96,96,0,240,159,4,0,19,0,0,0,1,96,32,0,200,143,2,0,19,0,0,0,1,96,0,0,192,142,2,0,0,0,0,0,254,0,16,0,200,87,7,0,20,0,0,0,1,15,7,0,80,252,6,0,20,0,0,0,1,15,8,0,16,242,7,0,20,0,0,0,1,15,9,0,104,236,7,0,20,0,0,0,1,15,5,0,176,51,4,0,20,0,0,0,1,15,4,0,56,24,4,0,20,0,0,0,1,15,15,0,128,230,7,0,20,0,0,0,1,15,1,0,72,216,3,0,20,0,0,0,1,15,2,0,24,188,3,0,20,0,0,0,1,15,3,0,176,162,3,0,20,0,0,0,1,15,6,0,120,211,6,0,20,0,0,0,1,15,14,0,184,164,6,0,20,0,0,0,1,15,13,0,80,74,6,0,20,0,0,0,1,15,12,0,192,32,6,0,20,0,0,0,1,15,11,0,192,234,2,0,20,0,0,0,1,15,10,0,32,242,5,0,20,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,20,0,0,0,1,240,112,0,80,252,6,0,20,0,0,0,1,240,128,0,16,242,7,0,20,0,0,0,1,240,144,0,104,236,7,0,20,0,0,0,1,240,80,0,176,51,4,0,20,0,0,0,1,240,64,0,56,24,4,0,20,0,0,0,1,240,240,0,128,230,7,0,20,0,0,0,1,240,16,0,72,216,3,0,20,0,0,0,1,240,32,0,24,188,3,0,20,0,0,0,1,240,48,0,176,162,3,0,20,0,0,0,1,240,96,0,120,211,6,0,20,0,0,0,1,240,224,0,184,164,6,0,20,0,0,0,1,240,208,0,80,74,6,0,20,0,0,0,1,240,192,0,192,32,6,0,20,0,0,0,1,240,176,0,192,234,2,0,20,0,0,0,1,240,160,0,32,242,5,0,20,0,0,0,1,240,0,0,208,236,2,0,18,0,0,0,255,255,255,0,0,0,0,0,19,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,8,0,200,87,7,0,18,0,0,0,1,7,0,0,96,135,3,0,18,0,0,0,1,7,1,0,32,136,7,0,18,0,0,0,1,7,2,0,40,88,7,0,18,0,0,0,1,7,3,0,96,39,7,0,18,0,0,0,1,7,7,0,144,251,6,0,18,0,0,0,1,7,6,0,184,164,6,0,18,0,0,0,1,7,5,0,80,74,6,0,18,0,0,0,1,7,4,0,192,32,6,0,0,0,0,0,254,0,8,0,160,123,6,0,18,0,0,0,1,56,0,0,96,135,3,0,18,0,0,0,1,56,8,0,32,136,7,0,18,0,0,0,1,56,16,0,40,88,7,0,18,0,0,0,1,56,24,0,96,39,7,0,18,0,0,0,1,56,56,0,144,251,6,0,18,0,0,0,1,56,48,0,184,164,6,0,18,0,0,0,1,56,40,0,80,74,6,0,18,0,0,0,1,56,32,0,192,32,6,0,184,157,6,0,4,0,0,0,10,0,0,0,0,0,0,0,0,0,0,0,240,10,3,0,4,0,0,0,10,0,0,0,0,0,0,0,0,0,0,0,56,242,1,0,4,0,0,0,10,0,0,0,0,0,0,0,0,0,0,0,48,54,1,0,4,0,0,0,10,0,0,0,0,0,0,0,0,0,0,0,192,176,8,0,14,0,0,0,20,0,0,0,0,0,0,0,0,0,0,0,24,4,8,0,14,0,0,0,20,0,0,0,0,0,0,0,0,0,0,0,24,157,7,0,14,0,0,0,20,0,0,0,0,0,0,0,0,0,0,0,152,61,7,0,14,0,0,0,21,0,0,0,0,0,0,0,0,0,0,0,112,229,6,0,1,0,0,0,20,0,0,0,0,0,0,0,0,0,0,0,32,141,6,0,14,0,0,0,20,0,0,0,0,0,0,0,0,0,0,0,40,50,6,0,16,0,0,0,23,0,0,0,0,0,0,0,0,0,0,0,224,217,5,0,16,0,0,0,23,0,0,0,0,0,0,0,0,0,0,0,176,141,5,0,16,0,0,0,23,0,0,0,0,0,0,0,0,0,0,0,184,81,5,0,16,0,0,0,23,0,0,0,0,0,0,0,0,0,0,0,160,20,5,0,16,0,0,0,23,0,0,0,0,0,0,0,0,0,0,0,128,208,4,0,16,0,0,0,23,0,0,0,0,0,0,0,0,0,0,0,136,113,4,0,16,0,0,0,23,0,0,0,0,0,0,0,0,0,0,0,72,62,4,0,10,0,0,0,17,0,0,0,0,0,0,0,0,0,0,0,24,5,4,0,10,0,0,0,17,0,0,0,0,0,0,0,0,0,0,0,192,196,3,0,10,0,0,0,17,0,0,0,0,0,0,0,0,0,0,0,56,145,3,0,10,0,0,0,18,0,0,0,0,0,0,0,0,0,0,0,216,97,3,0,10,0,0,0,17,0,0,0,0,0,0,0,0,0,0,0,208,67,3,0,10,0,0,0,17,0,0,0,0,0,0,0,0,0,0,0,104,200,2,0,19,0,0,0,28,0,0,0,0,0,0,0,0,0,0,0,80,141,2,0,22,0,0,0,30,0,0,0,0,0,0,0,138,27,0,0,176,46,2,0,22,0,0,0,30,0,0,0,0,0,0,0,138,27,0,0,216,90,2,0,22,0,0,0,30,0,0,0,0,0,0,0,138,27,0,0,144,24,2,0,22,0,0,0,30,0,0,0,0,0,0,0,0,0,0,0,176,253,1,0,22,0,0,0,30,0,0,0,0,0,0,0,0,0,0,0,184,230,1,0,22,0,0,0,30,0,0,0,0,0,0,0,0,0,0,0,8,118,1,0,22,0,0,0,30,0,0,0,0,0,0,0,138,27,0,0,112,203,1,0,13,0,0,0,30,0,0,0,0,0,0,0,138,27,0,0,200,94,1,0,13,0,0,0,30,0,0,0,0,0,0,0,138,27,0,0,152,185,1,0,13,0,0,0,30,0,0,0,0,0,0,0,138,27,0,0,72,171,1,0,22,0,0,0,30,0,0,0,0,0,0,0,138,27,0,0,16,156,1,0,13,0,0,0,30,0,0,0,0,0,0,0,0,0,0,0,48,81,1,0,1,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,192,61,1,0,1,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,24,45,1,0,1,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,24,17,1,0,13,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,224,1,1,0,3,0,0,0,9,0,0,0,0,0,0,0,0,0,0,0,56,249,8,0,3,0,0,0,9,0,0,0,0,0,0,0,0,0,0,0,64,234,8,0,3,0,0,0,9,0,0,0,0,0,0,0,0,0,0,0,120,218,8,0,3,0,0,0,9,0,0,0,0,0,0,0,0,0,0,0,128,205,8,0,0,0,0,0,9,0,0,0,0,0,0,0,0,0,0,0,24,195,8,0,4,0,0,0,9,0,0,0,0,0,0,0,0,0,0,0,144,185,8,0,3,0,0,0,9,0,0,0,0,0,0,0,0,0,0,0,88,169,8,0,0,0,0,0,9,0,0,0,0,0,0,0,0,0,0,0,96,152,8,0,1,0,0,0,9,0,0,0,0,0,0,0,0,0,0,0,240,140,8,0,0,0,0,0,9,0,0,0,0,0,0,0,0,0,0,0,192,130,8,0,30,0,0,0,9,0,0,0,0,0,0,0,0,0,0,0,160,119,8,0,30,0,0,0,9,0,0,0,0,0,0,0,0,0,0,0,216,96,8,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,88,78,8,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,64,69,8,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,128,62,8,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,104,49,8,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,216,34,8,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,112,26,8,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,176,18,8,0,13,0,0,0,39,0,0,0,0,0,0,0,0,0,0,0,24,10,8,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,104,253,7,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,160,238,7,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,120,224,7,0,13,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,56,211,7,0,13,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,64,193,7,0,17,0,0,0,24,0,0,0,0,0,0,0,0,0,0,0,224,180,7,0,17,0,0,0,24,0,0,0,0,0,0,0,0,0,0,0,72,174,7,0,17,0,0,0,24,0,0,0,0,0,0,0,0,0,0,0,72,166,7,0,17,0,0,0,24,0,0,0,0,0,0,0,0,0,0,0,24,156,7,0,17,0,0,0,24,0,0,0,0,0,0,0,0,0,0,0,200,145,7,0,17,0,0,0,24,0,0,0,0,0,0,0,0,0,0,0,16,134,7,0,13,0,0,0,24,0,0,0,0,0,0,0,0,0,0,0,112,127,7,0,17,0,0,0,24,0,0,0,0,0,0,0,0,0,0,0,80,121,7,0,13,0,0,0,24,0,0,0,0,0,0,0,0,0,0,0,120,105,7,0,13,0,0,0,24,0,0,0,0,0,0,0,0,0,0,0,216,91,7,0,15,0,0,0,22,0,0,0,0,0,0,0,0,0,0,0,160,80,7,0,15,0,0,0,22,0,0,0,0,0,0,0,0,0,0,0,128,74,7,0,15,0,0,0,22,0,0,0,0,0,0,0,0,0,0,0,192,65,7,0,15,0,0,0,22,0,0,0,0,0,0,0,0,0,0,0,32,54,7,0,15,0,0,0,22,0,0,0,0,0,0,0,0,0,0,0,208,42,7,0,15,0,0,0,22,0,0,0,0,0,0,0,0,0,0,0,128,34,7,0,13,0,0,0,22,0,0,0,0,0,0,0,0,0,0,0,72,25,7,0,13,0,0,0,22,0,0,0,0,0,0,0,0,0,0,0,176,15,7,0,13,0,0,0,36,0,0,0,0,0,0,0,0,0,0,0,8,254,6,0,13,0,0,0,36,0,0,0,0,0,0,0,0,0,0,0,184,246,6,0,13,0,0,0,36,0,0,0,0,0,0,0,0,0,0,0,208,239,6,0,6,0,0,0,13,0,0,0,0,0,0,0,0,0,0,0,224,233,6,0,6,0,0,0,13,0,0,0,0,0,0,0,0,0,0,0,88,224,6,0,6,0,0,0,13,0,0,0,0,0,0,0,0,0,0,0,136,214,6,0,6,0,0,0,13,0,0,0,0,0,0,0,0,0,0,0,32,202,6,0,7,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,216,195,6,0,7,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,24,168,6,0,7,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,112,186,6,0,7,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,136,158,6,0,8,0,0,0,15,0,0,0,0,0,0,0,0,0,0,0,112,152,6,0,8,0,0,0,15,0,0,0,0,0,0,0,0,0,0,0,144,144,6,0,9,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,160,136,6,0,9,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,152,126,6,0,13,0,0,0,38,0,0,0,0,0,0,0,0,0,0,0,48,114,6,0,13,0,0,0,38,0,0,0,0,0,0,0,0,0,0,0,248,105,6,0,13,0,0,0,38,0,0,0,0,0,0,0,0,0,0,0,96,96,6,0,13,0,0,0,38,0,0,0,0,0,0,0,0,0,0,0,56,83,6,0,3,0,0,0,38,0,0,0,0,0,0,0,0,0,0,0,224,70,6,0,3,0,0,0,38,0,0,0,0,0,0,0,0,0,0,0,8,63,6,0,13,0,0,0,38,0,0,0,0,0,0,0,0,0,0,0,96,57,6,0,13,0,0,0,37,0,0,0,0,0,0,0,0,0,0,0,120,40,6,0,23,0,0,0,31,0,0,0,0,0,0,0,188,39,0,0,8,31,6,0,23,0,0,0,31,0,0,0,0,0,0,0,188,39,0,0,104,24,6,0,23,0,0,0,31,0,0,0,0,0,0,0,188,39,0,0,184,17,6,0,23,0,0,0,31,0,0,0,0,0,0,0,188,39,0,0,16,7,6,0,23,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,240,252,5,0,23,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,32,240,5,0,23,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,56,233,5,0,13,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,184,221,5,0,20,0,0,0,33,0,0,0,0,0,0,0,0,0,0,0,160,212,5,0,13,0,0,0,34,0,0,0,0,0,0,0,0,0,0,0,32,204,5,0,13,0,0,0,35,0,0,0,0,0,0,0,0,0,0,0,80,193,5,0,5,0,0,0,19,0,0,0,0,0,0,0,0,0,0,0,248,185,5,0,11,0,0,0,19,0,0,0,0,0,0,0,0,0,0,0,136,179,5,0,12,0,0,0,19,0,0,0,0,0,0,0,0,0,0,0,112,169,5,0,11,0,0,0,19,0,0,0,0,0,0,0,0,0,0,0,168,157,5,0,11,0,0,0,19,0,0,0,0,0,0,0,0,0,0,0,0,153,5,0,11,0,0,0,19,0,0,0,0,0,0,0,0,0,0,0,80,147,5,0,11,0,0,0,19,0,0,0,0,0,0,0,0,0,0,0,16,141,5,0,6,0,0,0,19,0,0,0,0,0,0,0,0,0,0,0,144,133,5,0,4,0,0,0,19,0,0,0,0,0,0,0,0,0,0,0,120,126,5,0,12,0,0,0,19,0,0,0,0,0,0,0,0,0,0,0,168,122,5,0,9,0,0,0,19,0,0,0,0,0,0,0,0,0,0,0,72,118,5,0,5,0,0,0,19,0,0,0,0,0,0,0,0,0,0,0,40,113,5,0,8,0,0,0,19,0,0,0,0,0,0,0,0,0,0,0,208,105,5,0,11,0,0,0,19,0,0,0,0,0,0,0,0,0,0,0,128,97,5,0,7,0,0,0,19,0,0,0,0,0,0,0,0,0,0,0,168,92,5,0,11,0,0,0,19,0,0,0,0,0,0,0,0,0,0,0,56,88,5,0,6,0,0,0,19,0,0,0,0,0,0,0,0,0,0,0,136,81,5,0,9,0,0,0,19,0,0,0,0,0,0,0,0,0,0,0,112,74,5,0,7,0,0,0,19,0,0,0,0,0,0,0,0,0,0,0,192,66,5,0,11,0,0,0,19,0,0,0,0,0,0,0,0,0,0,0,184,61,5,0,11,0,0,0,19,0,0,0,0,0,0,0,0,0,0,0,32,57,5,0,11,0,0,0,19,0,0,0,0,0,0,0,0,0,0,0,112,51,5,0,11,0,0,0,19,0,0,0,0,0,0,0,0,0,0,0,48,43,5,0,11,0,0,0,19,0,0,0,0,0,0,0,0,0,0,0,168,134,4,0,13,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,120,35,5,0,13,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,216,30,5,0,13,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,16,6,5,0,13,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,112,255,4,0,13,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,168,249,4,0,13,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,120,26,5,0,13,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,136,20,5,0,13,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,176,12,5,0,13,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,32,214,4,0,13,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,240,207,4,0,13,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,144,197,4,0,13,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,24,190,4,0,26,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,176,184,4,0,26,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,80,180,4,0,13,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,232,173,4,0,13,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,120,165,4,0,13,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,40,158,4,0,13,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,56,153,4,0,13,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,192,148,4,0,13,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,200,142,4,0,13,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,160,241,4,0,13,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,32,234,4,0,13,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,176,225,4,0,13,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,32,219,4,0,13,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,80,18,4,0,13,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,104,14,4,0,13,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,8,5,4,0,13,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,232,183,3,0,13,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,128,178,3,0,13,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,200,174,3,0,13,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,248,97,4,0,13,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,128,94,4,0,13,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,16,88,4,0,13,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,64,81,4,0,13,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,48,75,4,0,13,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,112,71,4,0,13,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,224,66,4,0,13,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,64,62,4,0,13,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,56,55,4,0,13,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,56,47,4,0,13,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,43,4,0,13,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,144,38,4,0,13,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,24,33,4,0,13,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,128,23,4,0,13,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,16,253,3,0,13,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,248,244,3,0,13,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,176,239,3,0,26,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,16,234,3,0,26,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,104,227,3,0,27,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,216,219,3,0,27,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,152,211,3,0,27,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,224,205,3,0,27,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,48,202,3,0,27,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,160,196,3,0,13,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,104,190,3,0,13,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,16,128,4,0,13,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,64,123,4,0,13,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,232,118,4,0,13,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,128,113,4,0,13,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,224,107,4,0,29,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,96,101,4,0,29,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,104,161,3,0,24,0,0,0,32,0,0,0,0,0,0,0,238,35,0,0,216,156,3,0,24,0,0,0,32,0,0,0,0,0,0,0,238,35,0,0,224,152,3,0,24,0,0,0,32,0,0,0,0,0,0,0,238,35,0,0,168,148,3,0,25,0,0,0,32,0,0,0,0,0,0,0,238,35,0,0,136,142,3,0,25,0,0,0,32,0,0,0,0,0,0,0,238,35,0,0,224,135,3,0,24,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,16,130,3,0,0,0,0,0,3,0,0,0,1,0,0,0,0,0,0,0,144,125,3,0,0,0,0,0,3,0,0,0,1,0,0,0,0,0,0,0,240,120,3,0,13,0,0,0,3,0,0,0,1,0,0,0,0,0,0,0,224,112,3,0,0,0,0,0,6,0,0,0,1,0,0,0,0,0,0,0,224,105,3,0,5,0,0,0,11,0,0,0,0,0,0,0,0,0,0,0,160,100,3,0,5,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,8,93,3,0,13,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,136,87,3,0,3,0,0,0,26,0,0,0,0,0,0,0,0,0,0,0,40,86,3,0,3,0,0,0,26,0,0,0,0,0,0,0,0,0,0,0,192,80,3,0,3,0,0,0,26,0,0,0,0,0,0,0,0,0,0,0,40,84,3,0,18,0,0,0,27,0,0,0,0,0,0,0,0,0,0,0,248,73,3,0,2,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,88,70,3,0,2,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,112,72,3,0,2,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,200,67,3,0,21,0,0,0,29,0,0,0,0,0,0,0,12,9,0,0,216,64,3,0,13,0,0,0,29,0,0,0,0,0,0,0,12,9,0,0,152,61,3,0,21,0,0,0,29,0,0,0,0,0,0,0,12,9,0,0,120,59,3,0,21,0,0,0,29,0,0,0,0,0,0,0,12,9,0,0,56,56,3,0,13,0,0,0,29,0,0,0,0,0,0,0,12,9,0,0,192,41,3,0,13,0,0,0,29,0,0,0,0,0,0,0,0,0,0,0,192,38,3,0,31,0,0,0,29,0,0,0,0,0,0,0,0,0,0,0,56,31,3,0,31,0,0,0,29,0,0,0,0,0,0,0,0,0,0,0,8,20,3,0,31,0,0,0,29,0,0,0,0,0,0,0,0,0,0,0,136,15,3,0,13,0,0,0,29,0,0,0,0,0,0,0,0,0,0,0,152,8,3,0,31,0,0,0,29,0,0,0,0,0,0,0,0,0,0,0,8,1,3,0,31,0,0,0,29,0,0,0,0,0,0,0,0,0,0,0,120,251,2,0,31,0,0,0,29,0,0,0,0,0,0,0,0,0,0,0,184,246,2,0,31,0,0,0,29,0,0,0,0,0,0,0,0,0,0,0,136,238,2,0,31,0,0,0,29,0,0,0,0,0,0,0,0,0,0,0,160,230,2,0,13,0,0,0,29,0,0,0,0,0,0,0,0,0,0,0,176,224,2,0,13,0,0,0,29,0,0,0,0,0,0,0,0,0,0,0,160,220,2,0,21,0,0,0,29,0,0,0,0,0,0,0,12,9,0,0,176,211,2,0,13,0,0,0,29,0,0,0,0,0,0,0,12,9,0,0,88,206,2,0,13,0,0,0,29,0,0,0,0,0,0,0,12,9,0,0,168,201,2,0,13,0,0,0,29,0,0,0,0,0,0,0,12,9,0,0,64,170,3,0,13,0,0,0,39,0,0,0,0,0,0,0,0,0,0,0,184,48,3,0,13,0,0,0,39,0,0,0,0,0,0,0,12,9,0,0,96,34,3,0,3,0,0,0,39,0,0,0,0,0,0,0,0,0,0,0,136,195,2,0,3,0,0,0,41,0,0,0,0,0,0,0,0,0,0,0,152,187,2,0,13,0,0,0,37,0,0,0,0,0,0,0,0,0,0,0,96,168,2,0,13,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,16,164,2,0,13,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,128,184,2,0,24,0,0,0,32,0,0,0,0,0,0,0,238,35,0,0,216,181,2,0,24,0,0,0,32,0,0,0,0,0,0,0,238,35,0,0,88,178,2,0,25,0,0,0,32,0,0,0,0,0,0,0,238,35,0,0,192,174,2,0,25,0,0,0,32,0,0,0,0,0,0,0,238,35,0,0,96,173,2,0,25,0,0,0,32,0,0,0,0,0,0,0,238,35,0,0,40,171,2,0,25,0,0,0,32,0,0,0,0,0,0,0,238,35,0,0,8,160,2,0,13,0,0,0,29,0,0,0,0,0,0,0,12,9,0,0,96,158,2,0,13,0,0,0,39,0,0,0,0,0,0,0,0,0,0,0,112,15,1,0,13,0,0,0,39,0,0,0,0,0,0,0,0,0,0,0,128,153,2,0,13,0,0,0,39,0,0,0,0,0,0,0,0,0,0,0,104,150,2,0,13,0,0,0,39,0,0,0,0,0,0,0,0,0,0,0,0,147,2,0,13,0,0,0,39,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,97,118,112,101,46,48,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,169,52,67,119,1,0,16,1,97,118,112,101,46,48,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,105,55,168,127,1,0,16,1,97,118,112,46,48,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,122,93,251,251,1,0,16,1,97,118,112,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,127,129,11,25,1,0,16,1,97,118,112,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,228,90,139,143,5,0,32,0,97,118,112,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,223,128,2,176,5,0,32,0,97,118,112,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,149,49,64,148,5,0,32,0,97,118,112,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,69,18,152,225,5,0,32,0,97,118,112,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,62,9,186,235,5,0,32,0,97,118,112,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,151,130,34,251,5,0,32,0,97,118,112,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,50,114,251,52,5,0,32,0,97,118,112,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,33,170,11,249,5,0,32,0,97,118,112,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,32,66,59,45,10,0,16,1,97,118,112,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,23,152,73,131,12,0,64,0,97,118,112,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,73,13,17,244,12,0,64,0,20,0,0,0,255,255,255,0,0,0,0,0,21,0,0,0,255,255,82,0,0,0,0,0,22,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,20,0,0,0,1,15,2,0,80,252,6,0,20,0,0,0,1,15,5,0,16,242,7,0,20,0,0,0,1,15,8,0,104,236,7,0,20,0,0,0,1,15,4,0,120,113,6,0,20,0,0,0,1,15,1,0,232,228,5,0,20,0,0,0,1,15,15,0,128,230,7,0,20,0,0,0,1,15,3,0,56,141,7,0,20,0,0,0,1,15,7,0,120,211,6,0,20,0,0,0,1,15,14,0,184,164,6,0,20,0,0,0,1,15,6,0,24,1,7,0,20,0,0,0,1,15,13,0,80,74,6,0,20,0,0,0,1,15,12,0,192,32,6,0,20,0,0,0,1,15,11,0,192,234,2,0,20,0,0,0,1,15,10,0,32,242,5,0,20,0,0,0,1,15,9,0,176,192,2,0,20,0,0,0,1,15,0,0,16,227,4,0,0,0,0,0,254,0,15,0,160,123,6,0,20,0,0,0,1,240,32,0,80,252,6,0,20,0,0,0,1,240,80,0,16,242,7,0,20,0,0,0,1,240,128,0,104,236,7,0,20,0,0,0,1,240,64,0,120,113,6,0,20,0,0,0,1,240,16,0,232,228,5,0,20,0,0,0,1,240,240,0,128,230,7,0,20,0,0,0,1,240,48,0,56,141,7,0,20,0,0,0,1,240,112,0,120,211,6,0,20,0,0,0,1,240,224,0,184,164,6,0,20,0,0,0,1,240,96,0,24,1,7,0,20,0,0,0,1,240,208,0,80,74,6,0,20,0,0,0,1,240,192,0,192,32,6,0,20,0,0,0,1,240,176,0,192,234,2,0,20,0,0,0,1,240,160,0,32,242,5,0,20,0,0,0,1,240,144,0,176,192,2,0,0,0,0,0,254,0,4,0,128,129,4,0,21,0,0,0,1,3,3,0,208,75,4,0,21,0,0,0,1,3,2,0,8,49,4,0,21,0,0,0,1,3,1,0,72,246,3,0,21,0,0,0,1,3,0,0,64,47,7,0,0,0,0,0,254,0,4,0,64,37,5,0,21,0,0,0,1,24,24,0,184,103,8,0,21,0,0,0,1,24,16,0,88,8,3,0,21,0,0,0,1,24,8,0,152,53,6,0,21,0,0,0,1,24,0,0,8,49,6,0,0,0,0,0,254,0,4,0,72,202,5,0,21,0,0,0,1,96,96,0,80,246,3,0,21,0,0,0,1,96,64,0,248,38,7,0,21,0,0,0,1,96,32,0,48,123,8,0])
.concat([21,0,0,0,1,96,0,0,8,117,8,0,0,0,0,0,254,0,2,0,168,234,7,0,21,0,0,0,1,128,128,0,96,135,7,0,21,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,6,0,22,0,0,0,1,2,2,0,8,208,6,0,22,0,0,0,1,2,0,0,88,204,6,0,0,0,0,0,254,0,2,0,232,75,4,0,22,0,0,0,1,4,4,0,96,135,7,0,22,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,216,11,3,0,22,0,0,0,1,8,8,0,248,38,7,0,22,0,0,0,1,8,0,0,144,172,6,0,0,0,0,0,48,57,48,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,2,71,170,175,1,0,16,1,48,57,48,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,15,136,74,23,2,0,32,0,48,57,48,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,155,237,48,205,3,0,32,0,48,57,48,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,238,213,238,16,3,0,32,0,48,54,52,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,49,27,109,67,3,0,32,0,48,54,52,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,38,221,200,249,3,0,32,0,48,54,52,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,244,169,52,142,3,0,32,0,48,54,52,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,102,71,62,164,3,0,32,0,48,54,52,45,99,55,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,21,114,217,89,3,0,32,0,48,54,52,45,99,56,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,103,35,9,252,3,0,32,0,48,57,48,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,104,86,6,40,4,0,16,1,48,57,48,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,9,39,207,48,5,0,64,0,48,54,52,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,221,126,82,182,5,0,64,0,48,57,48,45,118,51,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,206,167,8,25,5,0,64,0,48,53,55,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,217,145,168,101,1,0,16,1,48,53,55,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,164,179,174,252,2,0,32,0,48,53,55,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,145,187,198,33,3,0,32,0,48,53,55,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,37,153,153,163,3,0,32,0,48,53,55,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,25,162,37,183,3,0,32,0,48,53,55,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,94,66,150,141,3,0,32,0,48,53,55,45,99,53,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,175,84,3,178,3,0,32,0,48,53,55,45,99,54,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,227,29,61,177,3,0,32,0,48,53,55,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,119,188,163,143,4,0,16,1,48,53,55,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,1,227,119,136,5,0,64,0,48,53,55,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,244,127,49,193,5,0,64,0,48,53,51,45,101,112,114,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,154,30,46,212,1,0,16,1,48,53,51,45,101,112,114,46,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,163,232,51,14,1,0,16,1,48,53,51,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,107,45,44,140,2,0,32,0,48,53,51,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,206,91,235,133,3,0,32,0,48,53,51,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,72,176,147,236,3,0,32,0,48,53,51,45,99,51,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,101,73,214,13,3,0,32,0,48,53,51,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,84,217,112,146,3,0,32,0,48,53,51,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,75,208,217,27,4,0,16,1,48,53,51,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,133,244,141,166,5,0,64,0,48,53,51,45,118,52,46,118,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,102,143,234,123,5,0,64,0,0,0,0,0,0,0,0,0,50,54,57,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,94,0,226,56,1,0,16,1,50,54,57,45,112,50,46,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,124,121,19,109,1,0,16,1,50,54,57,45,99,49,114,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,104,64,123,136,3,0,32,0,50,54,57,45,99,50,114,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,228,3,137,78,3,0,32,0,50,54,57,45,99,51,114,46,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,176,85,156,125,3,0,32,0,50,54,57,45,99,52,114,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,182,91,203,138,3,0,32,0,50,54,57,45,99,53,114,46,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,87,65,122,9,3,0,32,0,50,54,57,45,99,54,114,46,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,68,243,157,225,3,0,32,0,50,54,57,45,99,55,114,46,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,11,52,240,216,3,0,32,0,50,54,57,45,99,56,114,46,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,27,183,112,37,3,0,32,0,50,54,57,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,157,129,246,4,0,16,1,50,54,57,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,76,179,89,198,5,0,64,0,50,54,57,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,53,56,144,221,5,0,64,0,97,116,116,48,49,48,48,51,46,117,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,147,10,100,122,1,0,16,1,97,116,116,48,49,48,48,49,46,117,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,211,138,168,79,1,0,16,1,97,116,116,48,49,48,48,52,46,117,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,161,92,212,187,1,0,16,1,97,116,116,48,49,48,48,50,46,117,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,12,216,143,47,1,0,16,1,97,116,116,48,49,48,48,54,46,117,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,162,142,215,106,3,0,32,0,97,116,116,48,49,48,48,53,46,117,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,255,71,163,3,0,32,0,97,116,116,48,49,48,48,56,46,117,51,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,87,116,196,32,4,0,32,0,97,116,116,48,49,48,48,55,46,117,52,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,68,85,151,172,4,0,32,0,97,116,116,48,49,48,48,57,46,117,52,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,141,181,118,66,6,0,64,0,97,116,116,48,49,48,49,48,46,117,53,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,83,47,251,255,6,0,64,0,56,53,55,110,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,56,59,153,151,1,0,16,1,56,53,55,110,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,254,126,169,49,1,0,16,1,56,53,55,100,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,15,33,212,170,2,0,16,1,56,53,55,98,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,102,9,120,184,3,0,32,0,56,53,55,98,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,80,141,77,62,3,0,32,0,56,53,55,98,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,177,95,81,123,4,0,32,0,56,53,55,98,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,59,247,176,39,4,0,32,0,56,53,55,98,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,212,18,53,206,5,0,64,0,56,53,55,98,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,19,60,184,32,6,0,64,0,56,53,55,97,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,7,133,117,50,7,0,0,8,115,102,100,45,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,85,98,175,250,1,0,16,1,115,102,100,45,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,25,53,254,225,1,0,16,1,115,102,100,45,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,189,21,185,68,1,0,16,1,115,102,100,45,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,248,63,196,121,1,0,16,1,115,102,100,45,50,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,155,121,219,232,1,0,16,1,115,102,100,45,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,64,52,106,70,1,0,16,1,115,102,45,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,52,197,154,74,2,0,16,1,115,102,117,45,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,3,233,204,167,3,0,16,1,115,102,45,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,213,240,224,134,3,0,16,1,115,102,45,51,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,146,210,227,206,4,0,32,0,115,102,45,51,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,118,150,169,46,4,0,32,0,115,102,45,52,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,149,4,40,224,4,0,32,0,115,102,45,52,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,222,48,11,199,4,0,32,0,115,102,45,50,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,46,4,35,127,5,0,32,0,115,102,45,50,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,28,185,248,146,5,0,32,0,115,102,45,51,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,86,152,57,177,5,0,32,0,115,102,45,51,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,46,174,182,150,5,0,32,0,115,102,45,50,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,245,233,237,84,5,0,32,0,115,102,45,50,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,103,154,100,240,5,0,32,0,115,102,45,51,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,26,215,77,143,5,0,32,0,115,102,45,51,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,180,15,192,112,5,0,32,0,115,102,45,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0])
.concat([219,19,1,252,6,0,32,0,115,102,45,49,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,211,166,228,130,6,0,32,0,115,102,45,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,27,223,18,225,6,0,32,0,115,102,45,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,153,34,213,66,6,0,32,0,115,102,45,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,217,64,243,73,6,0,32,0,115,102,45,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,177,233,236,149,6,0,32,0,115,102,45,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,129,87,160,92,6,0,32,0,115,102,45,49,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,142,196,250,105,6,0,32,0,115,102,45,49,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,141,209,207,113,6,0,32,0,115,102,45,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,75,178,46,250,6,0,32,0,115,102,45,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,149,92,149,173,6,0,32,0,115,102,45,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,49,58,183,65,6,0,32,0,115,102,45,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,80,28,196,145,6,0,32,0,115,102,45,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,190,124,140,83,6,0,32,0,115,102,45,50,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,109,179,9,43,7,0,32,0,115,102,45,51,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,61,157,208,35,8,0,32,0,115,102,45,51,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,108,223,22,234,8,0,32,0,115,102,45,51,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,217,43,223,114,8,0,32,0,115,102,45,51,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,213,211,153,62,8,0,32,0,109,98,55,49,49,52,104,46,49,50,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,83,53,175,117,0,0,0,8,109,98,55,49,49,52,104,46,49,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,134,101,229,192,0,0,0,8,109,98,55,49,49,52,104,46,49,50,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,100,75,115,76,0,0,0,8,109,109,105,45,55,54,48,51,46,49,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,83,218,188,6,0,0,0,8,112,114,103,56,46,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,163,6,141,212,1,0,16,1,112,114,103,48,46,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,26,108,96,232,1,0,16,1,115,111,117,110,100,46,57,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,174,50,205,67,2,0,16,1,118,111,105,99,101,46,49,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,128,193,35,63,3,0,16,1,98,107,99,104,114,46,50,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,202,122,212,228,4,0,32,0,98,107,99,104,114,46,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,27,188,28,90,4,0,32,0,98,107,99,104,114,46,52,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,72,189,81,195,4,0,32,0,98,107,99,104,114,46,51,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,80,176,178,107,4,0,32,0,109,99,104,114,46,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,11,166,6,171,5,0,32,0,109,99,104,114,46,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,125,56,33,210,5,0,32,0,109,99,104,114,46,49,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,18,23,76,30,5,0,32,0,109,99,104,114,46,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,41,245,129,163,5,0,32,0,109,99,104,114,46,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,196,3,35,229,5,0,32,0,109,99,104,114,46,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,161,166,185,35,5,0,32,0,109,99,104,114,46,50,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,172,131,18,5,0,32,0,109,99,104,114,46,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,92,240,107,204,5,0,32,0,98,49,109,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,50,130,117,100,6,0,32,0,98,50,109,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,173,245,88,217,6,0,32,0,98,49,107,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,254,245,102,231,6,0,32,0,98,50,107,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,211,114,21,231,6,0,32,0,98,49,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,140,243,148,132,6,0,32,0,98,50,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,73,240,197,31,6,0,32,0,98,51,109,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,46,128,54,209,6,0,32,0,98,52,109,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,211,133,250,180,6,0,32,0,98,51,107,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,200,28,225,64,6,0,32,0,98,52,107,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,110,113,169,92,6,0,32,0,98,51,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,115,145,61,140,6,0,32,0,98,52,104,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,248,102,223,162,6,0,32,0,118,114,97,109,46,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,50,251,173,191,7,0,32,0,98,107,115,49,106,49,48,46,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,205,170,52,73,8,0,32,0,98,107,115,49,106,49,56,46,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,136,252,31,85,8,0,32,0,109,115,49,106,49,48,46,51,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,184,88,41,249,8,0,32,0,109,115,49,106,49,56,46,53,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,193,93,227,137,8,0,32,0,115,102,98,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,173,153,65,134,0,0,0,8,115,102,98,48,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,93,140,63,189,0,0,0,8,109,98,55,49,49,52,104,46,49,50,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,100,75,115,76,0,0,0,8,109,109,105,45,55,54,48,51,46,49,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,83,218,188,6,0,0,0,8,99,54,57,45,50,48,45,49,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,16,73,14,180,2,0,0,0,99,54,57,45,50,50,45,49,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,48,248,188,236,2,0,0,0,99,54,57,45,49,57,45,49,46,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,88,193,25,87,2,0,0,0,99,54,57,45,50,49,45,49,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,148,35,86,115,2,0,0,0,99,54,57,45,50,51,46,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,62,225,252,178,9,0,0,0,99,54,57,45,48,49,46,105,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,227,171,31,82,11,0,0,0,99,54,57,45,49,51,46,105,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,132,8,85,209,12,0,0,0,99,54,57,45,49,50,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,44,88,86,235,12,0,0,0,99,54,57,45,49,51,46,105,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,132,8,85,209,12,0,0,0,99,54,57,45,49,50,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,44,88,86,235,12,0,0,0,99,54,57,45,49,51,46,105,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,132,8,85,209,12,0,0,0,99,54,57,45,49,50,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,44,88,86,235,12,0,0,0,99,54,57,45,49,51,46,105,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,132,8,85,209,12,0,0,0,99,54,57,45,49,50,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,44,88,86,235,12,0,0,0,99,54,57,45,48,50,46,105,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,53,13,226,240,11,0,0,0,99,54,57,45,49,53,46,105,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,22,211,97,151,12,0,0,0,99,54,57,45,49,52,46,105,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,42,39,208,14,12,0,0,0,99,54,57,45,49,53,46,105,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,22,211,97,151,12,0,0,0,99,54,57,45,49,52,46,105,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,42,39,208,14,12,0,0,0,99,54,57,45,49,53,46,105,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,22,211,97,151,12,0,0,0,99,54,57,45,49,52,46,105,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,42,39,208,14,12,0,0,0,99,54,57,45,49,53,46,105,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,22,211,97,151,12,0,0,0,99,54,57,45,49,52,46,105,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,42,39,208,14,12,0,0,0,99,54,57,45,48,51,46,51,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,231,182,230,99,24,0,0,0,255,255,255,255,0,0,0,0,100,103,49,118,101,114,49,46,106,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,175,168,113,142,1,0,16,0,100,103,50,118,101,114,49,46,108,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,252,175,135,66,1,0,16,0,100,103,56,46,101,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,163,29,214,209,2,0,16,0,100,103,57,46,108,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,8,74,134,223,3,0,32,0,100,103,49,48,46,109,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,83,13,71,158,3,0,32,0,115,110,107,56,56,48,46,49,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,6,217,15,231,4,0,32,0,115,110,107,56,56,48,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,237,26,139,98,4,0,32,0,115,110,107,56,56,48,46,49,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,104,136,220,25,4,0,32,0,115,110,107,56,56,48,46,49,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,139,73,205,71,4,0,32,0,115,110,107,56,56,48,46,49,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,87,233,144,122,4,0,32,0,115,110,107,56,56,48,46,49,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,19,108,10,228,4,0,32,0,115,110,107,56,56,48,46,49,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,194,28,147,199,4,0,32,0,115,110,107,56,56,48,46,49,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,50,34,215,238,4,0,32,0,115,110,107,56,56,48,46,49,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,221,184,117,23,4,0,32,0,115,110,107,56,56,48,46,50,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,236,82,231,248,4,0,32,0,115,110,107,56,56,48,46,50,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,254,255,233,39,4,0,32,0,115,110,107,56,56,48,46,50,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,216,0,156,170,4,0,32,0,115,110,107,56,56,48,46,50,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,104,173,182,173,4,0,32,0,115,110,107,56,56,48,46,50,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,90,134,65,221,4,0,32,0,115,110,107,56,56,48,46,50,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,173,89,87,5,4,0,32,0,115,110,107,56,56,48,46,50,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,197,97,194,155,4,0,32,0,100,103,55,46,100,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,211,169,169,171,5,0,64,0,112,97,108,50,48,108,49,48,46,97,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,204,0,0,0,41,231,217,195,0,0,0,8,112,103,109,95,116,48,49,115,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,160,35,113,26,0,0,32,2,112,103,109,95,109,48,49,115,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,89,113,174,69,0,0,64,2,112,103,109,95,112,48,49,115,46,117,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,110,22,43,228,0,0,16,2,112,103,109,95,112,48,50,115,46,117,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,162,95,193,120,0,0,16,2,100,100,112,51,95,98,105,111,115,46,117,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,143,92,204,179,0,0,16,2,98,105,111,115,46,117,52,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,162,247,124,81,0,0,16,2,45,0,0,0,255,255,0,0,0,0,0,0,47,0,0,0,255,1,1,0,0,0,0,0,0,0,0,0,254,0,2,0,208,87,7,0,45,0,0,0,1,1,0,0,96,135,7,0,45,0,0,0,1,1,1,0,152,182,7,0,0,0,0,0,254,0,2,0,16,49,4,0,45,0,0,0,1,2,2,0,96,135,7,0,45,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,88,178,4,0,45,0,0,0,1,4,4,0,96,135,7,0,45,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,40,182,1,0,45,0,0,0,1,8,0,0,96,135,7,0,45,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,2,0,248,142,8,0,45,0,0,0,1,16,0,0,96,135,7,0,45,0,0,0,1,16,16,0,152,182,7,0,0,0,0,0,254,0,4,0,248,145,4,0,47,0,0,0,1,15,0,0,216,142,4,0,47,0,0,0,1,15,1,0,128,139,4,0,47,0,0,0,1,15,2,0,200,134,4,0,47,0,0,0,1,15,3,0,48,131,4,0,61,0,0,0,255,255,0,0,0,0,0,0,62,0,0,0,255,255,0,0,0,0,0,0,63,0,0,0,255,255,1,0,0,0,0,0,0,0,0,0,254,0,2,0,192,84,1,0,61,0,0,0,1,3,0,0,40,84,1,0,61,0,0,0,1,3,2,0,248,83,1,0,0,0,0,0,254,0,2,0,104,83,1,0,61,0,0,0,1,12,0,0,40,84,1,0,61,0,0,0,1,12,8,0,248,83,1,0,0,0,0,0,254,0,2,0,144,82,1,0,221,0,0,0,1,48,0,0,40,84,1,0,61,0,0,0,1,48,32,0,248,83,1,0,0,0,0,0,254,0,2,0,56,81,1,0,61,0,0,0,1,192,0,0,40,84,1,0,61,0,0,0,1,192,128,0,248,83,1,0,0,0,0,0,254,0,2,0,80,80,1,0,62,0,0,0,1,3,0,0,40,84,1,0,62,0,0,0,1,3,2,0,248,83,1,0,0,0,0,0,254,0,2,0,40,79,1,0,63,0,0,0,1,1,0,0,96,135,7,0,63,0,0,0,1,1,1,0,152,182,7,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,0,0,0,0,36,33,31,20,249,40,251,71,76,119,158,194,0,0,0,0,0,0,0,0,0,0,0,0,54,3,0,0,146,4,0,0,54,3,0,0,54,3,0,0,140,29,0,0,114,49,0,0,148,38,0,0,208,22,0,0,8,12,0,0,114,32,0,0,176,7,0,0,176,39,0,0,124,24,0,0,116,44,0,0,44,42,0,0,74,10,0,0,62,40,0,0,36,47,0,0,54,3,0,0,54,3,0,0,54,3,0,0,54,3,0,0,56,22,0,0,254,9,0,0,54,3,0,0,10,41,0,0,54,3,0,0,36,31,0,0,54,3,0,0,54,3,0,0,54,3,0,0,54,3,0,0,134,11,0,0,112,35,0,0,132,18,0,0,194,14,0,0,168,37,0,0,38,41,0,0,90,3,0,0,56,2,0,0,254,38,0,0,16,23,0,0,100,42,0,0,84,3,0,0,118,9,0,0,248,19,0,0,170,3,0,0,218,42,0,0,248,2,0,0,178,28,0,0,172,13,0,0,206,7,0,0,86,2,0,0,86,16,0,0,84,20,0,0,232,38,0,0,38,43,0,0,80,17,0,0,152,35,0,0,120,50,0,0,66,46,0,0,234,19,0,0,46,49,0,0,120,31,0,0,78,40,0,0,54,3,0,0,54,3,0,0,100,23,0,0,26,43,0,0,54,3,0,0,238,45,0,0,190,0,0,0,232,9,0,0,54,9,0,0,230,26,0,0,54,3,0,0,152,26,0,0,70,9,0,0,54,3,0,0,232,26,0,0,62,29,0,0,54,3,0,0,54,3,0,0,122,47,0,0,248,35,0,0,54,3,0,0,224,33,0,0,254,2,0,0,242,37,0,0,198,34,0,0,122,18,0,0,54,3,0,0,72,37,0,0,250,25,0,0,54,3,0,0,14,16,0,0,92,37,0,0,54,3,0,0,54,3,0,0,166,40,0,0,174,34,0,0,54,3,0,0,162,3,0,0,148,4,0,0,202,38,0,0,214,14,0,0,106,42,0,0,54,3,0,0,94,12,0,0,236,27,0,0,156,27,0,0,238,40,0,0,186,7,0,0,54,3,0,0,54,3,0,0,140,5,0,0,70,13,0,0,54,3,0,0,156,47,0,0,4,40,0,0,14,30,0,0,150,29,0,0,128,27,0,0,54,3,0,0,156,48,0,0,138,22,0,0,30,39,0,0,26,4,0,0,104,50,0,0,186,34,0,0,88,42,0,0,198,9,0,0,188,42,0,0,24,30,0,0,232,36,0,0,46,47,0,0,236,21,0,0,66,43,0,0,138,24,0,0,188,45,0,0,16,25,0,0,8,50,0,0,106,50,0,0,152,25,0,0,26,17,0,0,184,37,0,0,214,23,0,0,38,22,0,0,188,22,0,0,12,1,0,0,2,4,0,0,182,26,0,0,26,48,0,0,94,39,0,0,220,48,0,0,162,32,0,0,18,38,0,0,50,34,0,0,232,32,0,0,60,10,0,0,90,33,0,0,156,8,0,0,8,5,0,0,28,31,0,0,158,14,0,0,208,38,0,0,202,49,0,0,208,48,0,0,46,0,0,0,254,0,0,0,44,49,0,0,32,2,0,0,180,35,0,0,26,16,0,0,118,4,0,0,30,10,0,0,158,9,0,0,208,32,0,0,158,46,0,0,114,46,0,0,38,35,0,0,58,23,0,0,116,50,0,0,254,21,0,0,202,29,0,0,242,14,0,0,44,22,0,0,76,7,0,0,86,40,0,0,230,8,0,0,148,49,0,0,120,11,0,0,18,34,0,0,90,6,0,0,132,47,0,0,172,49,0,0,248,11,0,0,200,42,0,0,144,28,0,0,154,14,0,0,86,22,0,0,206,27,0,0,74,45,0,0,136,19,0,0,48,9,0,0,56,45,0,0,178,14,0,0,126,40,0,0,70,40,0,0,242,24,0,0,30,3,0,0,66,33,0,0,34,9,0,0,102,50,0,0,240,44,0,0,84,11,0,0,12,26,0,0,156,31,0,0,44,25,0,0,48,11,0,0,18,45,0,0,104,8,0,0,88,46,0,0,226,11,0,0,158,15,0,0,124,30,0,0,84,22,0,0,190,8,0,0,114,28,0,0,44,36,0,0,146,16,0,0,76,17,0,0,182,47,0,0,132,6,0,0,244,32,0,0,16,46,0,0,24,40,0,0,102,27,0,0,96,13,0,0,18,11,0,0,216,2,0,0,32,43,0,0,126,3,0,0,164,42,0,0,74,7,0,0,44,30,0,0,84,50,0,0,216,44,0,0,172,11,0,0,154,46,0,0,130,4,0,0,120,47,0,0,172,33,0,0,86,4,0,0,120,35,0,0,152,39,0,0,54,3,0,0,146,4,0,0,54,3,0,0,54,3,0,0,54,3,0,0,54,3,0,0,148,38,0,0,208,22,0,0,8,12,0,0,114,32,0,0,176,7,0,0,176,39,0,0,124,24,0,0,116,44,0,0,44,42,0,0,74,10,0,0,62,40,0,0,36,47,0,0,54,3,0,0,54,3,0,0,54,3,0,0,54,3,0,0,56,22,0,0,254,9,0,0,54,3,0,0,10,41,0,0,54,3,0,0,36,31,0,0,54,3,0,0,54,3,0,0,54,3,0,0,54,3,0,0,134,11,0,0,112,35,0,0,132,18,0,0,194,14,0,0,168,37,0,0,38,41,0,0,90,3,0,0,56,2,0,0,254,38,0,0,16,23,0,0,100,42,0,0,84,3,0,0,118,9,0,0,248,19,0,0,170,3,0,0,218,42,0,0,248,2,0,0,178,28,0,0,172,13,0,0,206,7,0,0,86,2,0,0,86,16,0,0,84,20,0,0,232,38,0,0,54,3,0,0,80,17,0,0,54,3,0,0,120,50,0,0,54,3,0,0,54,3,0,0,46,49,0,0,120,31,0,0,78,40,0,0,54,3,0,0,54,3,0,0,100,23,0,0,26,43,0,0,54,3,0,0,238,45,0,0,190,0,0,0,232,9,0,0,54,9,0,0,230,26,0,0,54,3,0,0,152,26,0,0,70,9,0,0,54,3,0,0,232,26,0,0,62,29,0,0,54,3,0,0,54,3,0,0,122,47,0,0,248,35,0,0,54,3,0,0,224,33,0,0,254,2,0,0,242,37,0,0,198,34,0,0,122,18,0,0,54,3,0,0,72,37,0,0,250,25,0,0,54,3,0,0,14,16,0,0,92,37,0,0,54,3,0,0,54,3,0,0,166,40,0,0,174,34,0,0,54,3,0,0,162,3,0,0,148,4,0,0,202,38,0,0,214,14,0,0,106,42,0,0,54,3,0,0,94,12,0,0,236,27,0,0,156,27,0,0,238,40,0,0,186,7,0,0,54,3,0,0,54,3,0,0,140,5,0,0,70,13,0,0,54,3,0,0,156,47,0,0,4,40,0,0,14,30,0,0,150,29,0,0,128,27,0,0,54,3,0,0,156,48,0,0,138,22,0,0,30,39,0,0,26,4,0,0,104,50,0,0,186,34,0,0,88,42,0,0,54,3,0,0,188,42,0,0,24,30,0,0,232,36,0,0,46,47,0,0,236,21,0,0,66,43,0,0,138,24,0,0,188,45,0,0,2,3,0,0,8,50,0,0,106,50,0,0,152,25,0,0,26,17,0,0,184,37,0,0,214,23,0,0,54,3,0,0,188,22,0,0,12,1,0,0,2,4,0,0,182,26,0,0,26,48,0,0,94,39,0,0,220,48,0,0,162,32,0,0,166,30,0,0,50,34,0,0,232,32,0,0,60,10,0,0,90,33,0,0,156,8,0,0,8,5,0,0,54,3,0,0,158,14,0,0,208,38,0,0,202,49,0,0,208,48,0,0,46,0,0,0,254,0,0,0,44,49,0,0,32,2,0,0,122,22,0,0,26,16,0,0,118,4,0,0,30,10,0,0,158,9,0,0,208,32,0,0,158,46,0,0,54,3,0,0,38,35,0,0,58,23,0,0,116,50,0,0,254,21,0,0,202,29,0,0,242,14,0,0,44,22,0,0,76,7,0,0,32,31,0,0,230,8,0,0,148,49,0,0,120,11,0,0,18,34,0,0,90,6,0,0,132,47,0,0,54,3,0,0,248,11,0,0,200,42,0,0,144,28,0,0,154,14,0,0,86,22,0,0,206,27,0,0,74,45,0,0,136,19,0,0,54,3,0,0,54,3,0,0,178,14,0,0,126,40,0,0,70,40,0,0,242,24,0,0,30,3,0,0,54,3,0,0,34,9,0,0,102,50,0,0,240,44,0,0,84,11,0,0,12,26,0,0,156,31,0,0,44,25,0,0,48,11,0,0,54,3,0,0,54,3,0,0,88,46,0,0,226,11,0,0,158,15,0,0,124,30,0,0,84,22,0,0,54,3,0,0,114,28,0,0,44,36,0,0,146,16,0,0,76,17,0,0,182,47,0,0,132,6,0,0,244,32,0,0,16,46,0,0,54,3,0,0,54,3,0,0,96,13,0,0,18,11,0,0,216,2,0,0,32,43,0,0,126,3,0,0,54,3,0,0,74,7,0,0,44,30,0,0,84,50,0,0,216,44,0,0,172,11,0,0,154,46,0,0,130,4,0,0,120,47,0,0,54,3,0,0,54,3,0,0,120,35,0,0,152,39,0,0,73,71,83,48,48,48,57,114,100,49,48,52,48,50,49,57,249,140,189,135,22,7,57,235,41,158,23,239,79,100,124,224,95,115,91,161,94,149,13,241,64,54,47,0,226,138,188,50,68,250,108,51,11,213,76,59,54,52,158,163,32,46,243,169,183,62,135,128,251,241,221,156,186,211,155,59,138,156,168,55,7,151,132,12,78,84,231,37,186,142,157,107,222,95,161,16,195,162,121,153,99,169,209,42,101,32,91,22,27,65,230,167,186,58,189,42,216,219,67,63,43,133,204,95,128,79,190,174,250,121,232,3,141,22,34,53,187,246,38,169,141,210,175,25,212,187,208,166,161,196,150,33,2,239,225,150,0,86,128,27,214,154,140,215,115,145,7,85,50,43,181,11,216,165,57,38,206,242,116,152,161,102,26,100,184,165,150,41,84,203,33,237,205,221,30,44,11,112,184,34,67,152,190,84,243,20,190,101,33,183,97,23,207,25,7,160,194,127,163,48,117,8,216,191,88,26,85,27,78,13,109,50,101,21,251,158,216,117,118,111,66,226,79,60,37,53,147,108,155,86,190,193,91,101,222,39,112,48,54,48,48,46,49,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,230,159,209,196,1,0,16,1,116,48,54,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,214,26,204,74,2,0,32,0,97,48,54,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,52,120,22,216,3,0,32,0,97,48,54,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,115,67,122,255,3,0,32,0,97,48,54,48,50,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,89,41,163,231,3,0,32,0,97,48,54,48,51,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,218,171,49,236,3,0,32,0,98,48,54,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,89,208,60,125,4,0,32,0,98,48,54,48,49,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,47,28,187,160,4,0,32,0,109,48,54,48,48,46,114,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,214,79,218,58,5,0,64,0,107,111,118,95,105,103,115,48,50,55,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,7,0,16,17,46,0,0,0,255,255,5,0,0,0,0,0,0,0,0,0,254,0,6,0,144,165,4,0,46,0,0,0,1,15,0,0,232,41,1,0,46,0,0,0,1,15,1,0,80,65,1,0,46,0,0,0,1,15,2,0,176,20,3,0,46,0,0,0,1,15,3,0,56,50,1,0,46,0,0,0,1,15,4,0,192,20,3,0,46,0,0,0,1,15,5,0,224,32,1,0,53,50,51,50,45,112,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,198,62,65,210,1,0,16,1,50,51,50,45,112,50,46,115,112,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,246,35,139,21,1,0,16,1,53,50,51,50,45,115,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,218,105,239,11,2,0,32,0,53,50,51,50,45,99,49,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,10,155,171,78,3,0,32,0,53,50,51,50,45,99,50,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,208,143,127,105,3,0,32,0,53,50,51,50,45,99,49,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,243,253,67,17,3,0,32,0,53,50,51,50,45,99,50,98,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,143,207,130,234,3,0,32,0,53,50,51,50,45,99,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,7,190,209,171,3,0,32,0,53,50,51,50,45,99,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,123,150,189,210,3,0,32,0,50,51,50,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,71,135,52,69,4,0,16,1,50,51,50,45,118,49,46,118,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,181,181,162,34,5,0,64,0,50,51,50,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,68,231,4,35,5,0,64,0,50,51,50,45,118,51,46,118,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,84,185,158,117,5,0,64,0,176,196,6,0,255,255,255,255,255,255,255,255,0,0,0,0,120,28,4,0,137,103,69,35,1,239,205,171,0,0,64,0,80,240,3,0,120,86,52,18,240,222,188,154,0,0,64,0,128,21,4,0,154,120,86,52,18,240,222,188,0,0,64,0,88,17,4,0,154,120,86,52,18,240,222,188,0,0,64,0,192,5,4,0,103,69,35,1,239,205,171,137,0,0,64,0,112,253,3,0,103,69,35,1,239,205,171,137,0,0,64,0,56,246,3,0,103,69,35,1,239,205,171,137,0,0,64,0,0,13,4,0,188,154,120,86,52,18,240,222,0,0,64,0,168,234,3,0,239,205,171,137,103,69,35,1,0,0,64,0,8,225,3,0,239,205,171,137,103,69,35,1,0,0,64,0,128,217,3,0,205,171,137,103,69,35,1,239,0,0,64,0,176,209,3,0,18,240,222,188,154,120,86,52,0,0,64,0,40,2,1,0,8,254,103,71,217,53,202,20,0,0,24,0,24,250,8,0,8,254,103,71,217,53,202,20,0,0,24,0,32,131,8,0,61,156,161,236,240,107,115,36,0,0,24,0,72,121,8,0,61,156,161,236,240,107,115,36,0,0,24,0,56,170,8,0,156,231,16,69,45,138,107,243,0,0,24,0,32,153,8,0,156,231,16,69,45,138,107,243,0,0,24,0,80,141,8,0,156,231,16,69,45,138,107,243,0,0,24,0,8,235,8,0,5,193,202,222,17,4,113,25,0,0,24,0,48,219,8,0,5,193,202,222,17,4,113,25,0,0,24,0,232,205,8,0,25,16,105,25,224,221,37,232,0,0,24,0,104,196,8,0,25,16,105,25,224,221,37,232,0,0,24,0,88,186,8,0,25,16,105,25,224,221,37,232,0,0,24,0,208,228,7,0,220,49,16,147,84,118,152,186,0,0,32,0,224,194,7,0,237,49,16,147,101,135,169,203,0,0,32,0,152,181,7,0,237,49,16,147,101,135,169,203,0,0,32,0,32,175,7,0,254,49,16,147,118,152,186,220,0,0,32,0,96,217,7,0,186,49,16,147,50,84,118,152,0,0,32,0,72,207,7,0,203,49,16,147,67,101,135,169,0,0,32,0,240,204,3,0,2,131,78,148,60,20,211,86,0,0,64,0,32,201,3,0,2,208,196,148,113,20,74,102,0,0,64,0,72,195,3,0,2,137,250,148,63,20,119,76,0,0,64,0,96,188,3,0,2,137,250,148,63,20,119,76,0,0,64,0,192,182,3,0,2,87,42,148,14,20,172,5,0,0,64,0,120,177,3,0,2,43,60,148,34,20,205,122,0,0,64,0,56,132,3,0,164,237,198,59,81,2,248,151,0,0,16,0,248,128,3,0,164,237,198,59,81,2,248,151,0,0,16,0,112,86,3,0,205,126,165,50,75,111,1,152,0,0,16,0,168,113,3,0,52,220,232,245,23,178,150,160,0,0,16,0,248,108,3,0,52,220,232,245,23,178,150,160,0,0,16,0,40,105,3,0,21,115,2,70,158,205,139,175,0,0,16,0,16,102,3,0,21,115,2,70,158,205,139,175,0,0,16,0,32,97,3,0,21,115,2,70,158,205,139,175,0,0,16,0,168,91,3,0,21,115,2,70,158,205,139,175,0,0,16,0,80,88,3,0,21,115,2,70,158,205,139,175,0,0,16,0,168,124,3,0,226,164,149,7,28,134,63,219,0,0,16,0,160,119,3,0,226,164,149,7,28,134,63,219,0,0,16,0,88,191,6,0,11,76,157,158,31,8,57,138,0,0,16,0,112,54,6,0,11,76,157,158,31,8,57,138,0,0,16,0,88,144,5,0,163,184,192,212,233,249,129,144,0,0,16,0,80,84,5,0,163,184,192,212,233,249,129,144,0,0,16,0,120,23,5,0,138,11,76,157,158,31,8,57,0,0,16,0,160,211,4,0,138,11,76,157,158,31,8,57,0,0,16,0,152,221,5,0,76,157,158,31,8,57,138,11,0,0,16,0,136,165,6,0,121,143,32,21,179,108,222,74,0,0,16,0,184,172,3,0,137,16,246,180,35,90,247,204,0,0,16,0,248,230,3,0,250,184,220,233,100,32,55,81,0,0,16,0,72,91,4,0,189,243,104,193,112,89,74,46,0,0,16,0,136,35,4,0,10,105,43,113,95,142,205,67,0,0,16,0,24,63,8,0,168,167,216,19,144,176,8,0,0,0,16,0,48,27,8,0,240,235,128,30,25,113,34,16,0,0,16,0,224,18,8,0,240,235,128,30,25,113,34,16,0,0,16,0,88,50,8,0,152,131,93,32,113,25,34,6,0,0,16,0,0,36,8,0,254,62,70,34,170,105,17,1,0,0,16,0,176,11,8,0,4,8,203,239,174,25,104,2,0,0,16,0,184,254,7,0,4,8,203,239,174,25,104,2,0,0,16,0,32,239,7,0,4,8,203,239,174,25,104,2,0,0,16,0,152,82,5,0,39,7,148,25,3,73,68,23,0,0,24,0,56,76,5,0,9,2,148,25,3,20,3,23,0,0,24,0,168,67,5,0,9,2,148,25,3,20,3,23,0,0,24,0,128,63,5,0,39,7,148,25,3,33,69,23,0,0,24,0,232,7,2,0,67,89,66,69,1,9,9,5,0,0,16,0,72,218,1,0,9,9,5,67,89,66,85,1,0,0,16,0,192,242,1,0,1,9,9,5,67,89,66,74,0,0,16,0,144,206,6,0,38,238,17,26,23,93,149,231,0,0,16,0,168,152,6,0,78,162,5,135,155,49,23,74,0,0,16,0,176,168,6,0,25,130,232,5,66,33,173,49,0,0,16,0,232,158,6,0,25,130,232,5,66,33,173,49,0,0,16,0,224,199,6,0,1,235,122,69,61,197,151,56,0,0,16,0,0,181,6,0,80,90,76,252,144,193,156,181,0,0,16,0,160,192,6,0,22,36,21,122,230,248,39,173,0,0,16,0,136,201,5,0,69,209,25,16,5,90,240,3,0,0,24,0,160,170,5,0,12,125,74,16,30,122,27,63,0,0,24,0,56,181,5,0,1,27,150,196,32,96,148,42,0,0,24,0,136,188,5,0,9,113,198,23,32,42,54,183,0,0,24,0,248,193,5,0,12,13,148,78,164,97,184,57,0,0,24,0,96,160,5,0,195,178,53,17,242,215,233,164,0,0,24,0,112,154,5,0,195,178,53,17,242,215,233,164,0,0,24,0,240,147,5,0,195,178,53,17,242,215,233,164,0,0,24,0,136,142,5,0,195,178,53,17,242,215,233,164,0,0,24,0,136,58,5,0,110,93,137,15,27,58,39,196,0,0,8,0,160,52,5,0,110,93,137,15,27,58,39,196,0,0,8,0,104,44,5,0,110,93,137,15,27,58,39,196,0,0,8,0,176,36,5,0,110,93,137,15,27,58,39,196,0,0,8,0,152,31,5,0,54,173,190,37,24,64,207,151,0,0,8,0,24,27,5,0,8,197,61,228,127,154,27,98,0,0,8,0,128,21,5,0,8,197,61,228,127,154,27,98,0,0,8,0,160,242,4,0,122,22,179,141,69,15,158,194,0,0,8,0,56,236,4,0,122,22,179,141,69,15,158,194,0,0,8,0,216,226,4,0,122,22,179,141,69,15,158,194,0,0,8,0,200,0,5,0,57,14,107,135,209,79,162,92,0,0,8,0,216,250,4,0,57,14,107,135,209,79,162,92,0,0,8,0,24,15,5,0,211,91,65,239,128,198,146,122,0,0,8,0,120,6,5,0,211,91,65,239,128,198,146,122,0,0,8,0,72,28,7,0,250,147,72,5,37,37,100,148,0,0,16,0,72,17,7,0,1,85,33,7,208,50,250,55,0,0,16,0,248,99,8,0,31,24,7,14,128,240,208,95,0,0,32,0,208,32,3,0,245,76,231,204,17,55,218,183,0,0,32,0,88,185,8,0,248,93,17,0,126,248,15,0,0,0,32,0,136,61,8,0,248,93,17,0,126,248,15,0,0,0,32,0,136,61,1,0,250,186,73,93,159,108,33,247,0,0,32,0,152,253,1,0,106,71,249,229,63,98,251,45,0,0,32,0,104,193,1,0,188,154,136,135,99,95,31,216,0,0,16,0,152,172,1,0,188,154,136,135,99,95,31,216,0,0,16,0,120,157,1,0,188,154,136,135,99,95,31,216,0,0,16,0,0,134,1,0,188,154,136,135,99,95,31,216,0,0,16,0,32,29,1,0,38,5,159,72,122,62,205,27,0,0,16,0,248,12,1,0,38,5,159,72,122,62,205,27,0,0,16,0,192,62,1,0,148,250,146,174,69,144,90,49,0,0,16,0,32,46,1,0,148,250,146,174,69,144,90,49,0,0,16,0,48,107,1,0,205,171,25,135,69,131,2,239,0,0,16,0,40,75,1,0,69,66,19,66,7,230,13,18,0,0,16,0,64,89,1,0,130,167,73,113,206,191,165,243,0,0,16,0,176,66,7,0,172,28,80,80,80,101,52,237,0,0,16,0,240,55,7,0,43,138,20,63,21,10,121,214,0,0,16,0,216,34,7,0,115,202,158,49,112,18,85,16,0,0,16,0,160,43,7,0,202,115,85,118,208,16,2,37,0,0,16,0,152,91,5,0,115,234,4,88,152,7,107,246,0,0,8,0,40,220,4,0,156,207,74,252,249,225,251,59,0,0,16,0,128,215,4,0,150,61,191,27,74,97,244,138,0,0,16,0,40,209,4,0,150,61,191,27,74,97,244,138,0,0,16,0,88,175,4,0,153,126,244,131,17,33,119,218,0,0,16,0,16,168,4,0,153,126,244,131,17,33,119,218,0,0,16,0,96,199,4,0,244,232,194,175,135,148,120,67,0,0,16,0,232,190,4,0,153,69,19,172,46,187,248,97,0,0,16,0,224,185,4,0,153,69,19,172,46,187,248,97,0,0,16,0,56,181,4,0,66,45,138,249,159,8,123,89,0,0,16,0,88,159,4,0,156,248,43,227,220,70,123,165,0,0,16,0,112,154,4,0,208,192,114,241,166,33,6,4,0,0,16,0,88,136,4,0,136,12,69,153,77,44,10,160,0,0,16,0,136,143,4,0,124,91,241,149,198,8,12,32,0,0,16,0,184,149,4,0,40,74,205,115,28,175,131,255,0,0,16,0,0,49,4,0,80,135,106,112,133,193,15,125,0,0,4,0,200,43,4,0,90,131,44,177,255,118,9,233,0,0,4,0,16,39,4,0,171,225,72,156,251,52,15,214,0,0,4,0,240,33,4,0,171,140,237,81,182,133,143,34,0,0,4,0])
.concat([144,84,3,0,25,133,207,189,234,172,178,63,0,0,16,0,64,81,3,0,25,133,207,189,234,172,178,63,0,0,16,0,216,56,3,0,210,3,203,79,193,59,101,248,0,0,16,0,48,52,3,0,210,3,203,79,193,59,101,248,0,0,16,0,216,63,3,0,188,147,223,56,172,115,3,33,0,0,16,0,64,61,3,0,188,147,223,56,172,115,3,33,0,0,16,0,64,59,3,0,188,147,223,56,172,115,3,33,0,0,16,0,32,77,3,0,62,252,56,116,144,237,171,25,0,0,16,0,184,73,3,0,62,252,56,116,144,237,171,25,0,0,16,0,40,72,3,0,62,252,56,116,144,237,171,25,0,0,16,0,40,67,3,0,208,178,95,131,55,145,250,66,0,0,16,0,112,69,3,0,74,158,173,142,240,132,33,176,0,0,16,0,168,123,3,0,151,229,149,209,181,226,188,60,0,0,32,0,40,69,3,0,203,128,93,30,199,46,136,152,0,0,32,0,248,36,3,0,216,77,255,0,232,8,0,0,0,0,32,0,144,155,2,0,160,159,46,102,193,231,16,66,0,0,32,0,200,131,2,0,160,159,46,102,193,231,16,66,0,0,32,0,176,104,2,0,42,222,102,19,55,41,180,154,0,0,32,0,112,47,2,0,229,11,45,74,192,19,192,86,0,0,32,0,184,26,2,0,229,11,45,74,192,19,192,86,0,0,32,0,160,76,2,0,167,168,20,240,208,148,119,46,0,0,32,0,120,145,6,0,96,174,132,19,191,37,215,156,0,0,16,0,168,60,6,0,113,73,109,163,40,27,245,206,0,0,16,0,32,55,6,0,113,73,109,163,40,27,245,206,0,0,16,0,240,92,6,0,248,145,195,93,180,224,39,166,0,0,16,0,168,77,6,0,248,145,195,93,180,224,39,166,0,0,16,0,200,67,6,0,248,145,195,93,180,224,39,166,0,0,16,0,152,102,6,0,196,111,145,126,45,133,171,3,0,0,16,0,64,137,6,0,97,250,227,82,216,123,73,12,0,0,16,0,40,127,6,0,97,250,227,82,216,123,73,12,0,0,16,0,120,118,6,0,73,199,104,218,1,226,243,91,0,0,16,0,160,111,6,0,73,199,104,218,1,226,243,91,0,0,16,0,8,72,4,0,118,73,35,132,126,187,15,94,0,0,8,0,56,68,4,0,192,235,210,151,215,148,143,48,0,0,8,0,24,63,4,0,42,65,11,9,147,233,126,196,0,0,8,0,40,56,4,0,27,167,99,129,36,210,143,124,0,0,8,0,64,174,3,0,163,235,193,54,24,15,177,38,0,0,16,0,48,169,3,0,163,235,193,54,24,15,177,38,0,0,16,0,104,163,3,0,129,88,205,224,112,187,186,113,0,0,16,0,136,143,3,0,238,160,46,166,230,3,62,87,0,0,16,0,176,149,3,0,51,78,143,250,185,129,184,164,0,0,16,0,24,157,3,0,48,153,238,71,172,18,180,144,0,0,16,0,168,153,3,0,141,124,211,178,221,170,183,211,0,0,16,0,80,137,3,0,244,228,129,214,223,30,55,96,0,0,16,0,128,45,6,0,222,90,2,72,39,123,105,28,0,0,16,0,56,31,6,0,222,90,2,72,39,123,105,28,0,0,16,0,16,227,5,0,27,196,45,105,5,200,241,126,0,0,16,0,240,217,5,0,27,196,45,105,5,200,241,126,0,0,16,0,112,240,5,0,56,97,193,175,176,62,18,151,0,0,16,0,136,233,5,0,56,97,193,175,176,62,18,151,0,0,16,0,168,210,5,0,56,97,193,175,176,62,18,151,0,0,16,0,168,24,6,0,198,174,72,242,23,205,5,121,0,0,16,0,232,17,6,0,198,174,72,242,23,205,5,121,0,0,16,0,216,253,5,0,35,122,92,157,239,24,107,229,0,0,16,0,184,9,6,0,235,214,116,8,152,183,194,81,0,0,16,0,96,128,4,0,224,200,191,106,193,221,128,39,0,0,16,0,248,108,4,0,229,240,187,231,72,50,148,103,0,0,16,0,232,101,4,0,229,240,187,231,72,50,148,103,0,0,16,0,8,120,4,0,140,223,34,132,97,163,23,123,0,0,16,0,80,114,4,0,140,223,34,132,97,163,23,123,0,0,16,0,0,124,4,0,178,192,33,212,150,210,22,129,0,0,16,0,56,89,4,0,3,248,73,125,121,45,190,12,0,0,16,0,88,83,4,0,3,248,73,125,121,45,190,12,0,0,16,0,192,75,4,0,3,248,73,125,121,45,190,12,0,0,16,0,160,98,4,0,1,147,11,153,126,44,228,164,0,0,16,0,24,95,4,0,1,147,11,153,126,44,228,164,0,0,16,0,96,78,7,0,230,42,164,108,89,63,246,146,0,0,0,0,248,117,7,0,221,157,54,90,156,24,163,254,0,0,16,0,136,100,7,0,48,54,237,184,61,10,227,170,0,0,16,0,128,86,7,0,224,47,216,101,71,62,184,219,0,0,16,0,200,166,7,0,144,226,45,229,128,215,96,27,0,0,16,0,176,125,7,0,106,25,38,17,149,8,245,190,0,0,16,0,40,152,7,0,90,168,6,53,104,183,177,102,0,0,16,0,176,131,7,0,17,66,167,206,133,163,13,64,0,0,16,0,192,139,7,0,176,69,231,15,157,127,239,150,0,0,16,0,56,6,7,0,121,189,158,172,223,103,4,65,0,0,24,0,128,247,6,0,149,30,248,77,35,152,237,114,0,0,24,0,32,240,6,0,198,65,247,149,27,162,71,229,0,0,16,0,136,234,6,0,198,65,247,149,27,162,71,229,0,0,16,0,248,224,6,0,198,65,247,149,27,162,71,229,0,0,16,0,112,215,6,0,198,65,247,149,27,162,71,229,0,0,16,0,208,113,5,0,18,248,84,160,180,54,13,196,0,0,64,0,64,103,5,0,18,248,84,160,180,54,13,196,0,0,64,0,32,96,5,0,18,248,84,160,180,54,13,196,0,0,64,0,176,246,2,0,198,18,251,211,181,23,142,127,0,0,64,0,80,106,8,0,64,142,219,13,43,253,23,40,0,0,8,0,160,69,8,0,89,175,117,101,145,166,254,176,0,0,8,0,200,83,8,0,88,190,247,151,98,235,33,97,0,0,8,0,248,210,7,0,76,114,62,29,122,252,89,139,0,0,8,0,152,20,7,0,58,156,215,35,70,39,139,225,0,0,8,0,232,134,5,0,198,216,154,99,243,13,19,239,0,0,64,0,32,121,5,0,86,220,126,159,190,71,251,57,0,0,64,0,96,125,5,0,40,177,138,101,94,155,220,253,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,73,71,83,48,48,48,52,82,68,49,48,50,49,48,49,53,124,73,39,165,255,246,152,45,15,61,18,35,226,48,80,207,241,130,240,206,72,68,91,243,13,223,248,93,80,83,145,217,18,175,5,122,152,208,47,118,241,93,23,68,197,3,88,244,97,238,209,206,0,136,144,46,92,118,251,159,117,207,64,55,161,159,0,50,213,156,55,210,50,39,111,118,211,134,37,249,214,96,123,78,169,122,32,89,150,177,125,16,146,55,34,210,66,18,111,7,79,210,135,250,235,146,113,243,164,49,145,152,104,210,71,134,218,146,229,43,212,137,215,231,61,3,13,99,12,0,172,49,157,233,246,165,52,149,119,242,207,124,114,137,49,58,139,174,43,71,182,93,45,245,95,92,14,171,219,161,24,96,14,230,88,91,94,139,36,41,216,172,237,223,162,131,70,145,161,255,53,19,106,165,186,239,110,168,158,166,98,68,126,44,237,96,23,158,150,100,211,70,236,88,149,209,247,62,194,207,223,176,144,108,219,190,147,109,93,2,133,110,124,5,85,90,161,215,115,43,118,233,91,228,12,46,96,203,75,114,107,101,116,115,117,105,95,118,49,48,48,46,117,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,59,47,230,223,1,0,16,1,116,48,52,55,48,49,119,48,54,52,46,117,49,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,65,176,101,38,2,0,32,0,97,48,52,55,48,49,119,48,54,52,46,117,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,75,185,241,94,3,0,32,0,97,48,52,55,48,50,119,48,54,52,46,117,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,127,218,214,38,3,0,32,0,98,48,52,55,48,49,119,48,54,52,46,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,141,0,236,27,4,0,32,0,109,48,52,55,48,49,98,48,51,50,46,117,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,209,34,110,180,5,0,64,0,107,101,116,95,105,103,115,48,50,55,97,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,7,0,16,17,107,101,116,95,100,101,102,97,117,108,116,115,46,110,118,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,216,146,168,60,0,0,0,8,0,0,0,0,0,0,0,0,140,15,0,0,112,20,0,0,226,1,0,0,192,33,0,0,190,39,0,0,106,44,0,0,4,13,0,0,252,7,0,0,60,3,0,0,28,22,0,0,198,30,0,0,52,20,0,0,110,17,0,0,128,36,0,0,174,4,0,0,36,44,0,0,96,36,0,0,0,18,0,0,254,14,0,0,82,33,0,0,214,27,0,0,40,42,0,0,156,23,0,0,72,9,0,0,102,25,0,0,194,19,0,0,42,30,0,0,170,25,0,0,96,17,0,0,238,42,0,0,110,24,0,0,154,0,0,0,120,32,0,0,88,0,0,0,112,47,0,0,254,28,0,0,154,6,0,0,110,25,0,0,200,19,0,0,134,4,0,0,156,30,0,0,54,49,0,0,178,11,0,0,106,15,0,0,188,24,0,0,84,17,0,0,182,35,0,0,58,41,0,0,70,17,0,0,154,48,0,0,18,37,0,0,52,5,0,0,6,26,0,0,156,24,0,0,22,30,0,0,68,31,0,0,146,15,0,0,208,46,0,0,196,13,0,0,174,26,0,0,184,26,0,0,160,25,0,0,186,6,0,0,196,1,0,0,62,47,0,0,20,16,0,0,0,35,0,0,196,16,0,0,18,24,0,0,238,41,0,0,88,10,0,0,166,42,0,0,118,45,0,0,68,14,0,0,94,33,0,0,128,17,0,0,176,20,0,0,240,40,0,0,92,9,0,0,108,43,0,0,234,31,0,0,140,13,0,0,148,26,0,0,230,44,0,0,106,21,0,0,158,39,0,0,4,21,0,0,10,19,0,0,30,30,0,0,166,11,0,0,184,32,0,0,20,37,0,0,54,5,0,0,30,47,0,0,168,28,0,0,52,11,0,0,62,21,0,0,228,39,0,0,34,30,0,0,208,11,0,0,140,41,0,0,166,15,0,0,236,9,0,0,206,35,0,0,244,22,0,0,118,41,0,0,4,50,0,0,166,12,0,0,112,13,0,0,126,7,0,0,54,26,0,0,158,36,0,0,212,12,0,0,38,44,0,0,216,19,0,0,60,38,0,0,172,6,0,0,210,5,0,0,10,24,0,0,138,12,0,0,6,11,0,0,132,42,0,0,114,1,0,0,60,30,0,0,38,15,0,0,116,26,0,0,158,7,0,0,34,4,0,0,50,49,0,0,102,11,0,0,100,36,0,0,234,17,0,0,12,17,0,0,110,35,0,0,168,3,0,0,16,42,0,0,44,41,0,0,82,36,0,0,8,22,0,0,228,46,0,0,18,9,0,0,166,27,0,0,252,45,0,0,88,21,0,0,160,10,0,0,250,8,0,0,174,27,0,0,26,46,0,0,232,0,0,0,242,32,0,0,166,14,0,0,124,28,0,0,234,25,0,0,30,7,0,0,104,41,0,0,0,10,0,0,120,40,0,0,202,33,0,0,56,29,0,0,196,35,0,0,186,4,0,0,108,36,0,0,30,18,0,0,226,23,0,0,64,29,0,0,176,10,0,0,64,42,0,0,124,49,0,0,178,6,0,0,70,38,0,0,134,0,0,0,128,44,0,0,218,38,0,0,146,18,0,0,214,49,0,0,48,19,0,0,132,0,0,0,160,14,0,0,76,16,0,0,150,47,0,0,142,25,0,0,198,43,0,0,46,38,0,0,176,23,0,0,80,49,0,0,136,34,0,0,68,37,0,0,216,26,0,0,14,49,0,0,2,43,0,0,126,11,0,0,10,2,0,0,190,35,0,0,180,49,0,0,94,5,0,0,80,24,0,0,182,11,0,0,58,43,0,0,82,38,0,0,240,49,0,0,12,34,0,0,174,15,0,0,128,6,0,0,238,37,0,0,174,43,0,0,94,0,0,0,94,32,0,0,252,13,0,0,32,16,0,0,106,34,0,0,198,25,0,0,218,6,0,0,128,14,0,0,110,10,0,0,226,28,0,0,174,32,0,0,88,14,0,0,164,32,0,0,42,31,0,0,56,43,0,0,194,24,0,0,244,1,0,0,52,21,0,0,14,19,0,0,94,50,0,0,254,31,0,0,224,16,0,0,36,35,0,0,162,26,0,0,244,7,0,0,160,39,0,0,98,9,0,0,176,48,0,0,56,30,0,0,136,14,0,0,12,6,0,0,108,27,0,0,216,8,0,0,92,40,0,0,58,30,0,0,250,39,0,0,44,8,0,0,224,20,0,0,62,8,0,0,198,31,0,0,4,34,0,0,126,28,0,0,92,26,0,0,146,41,0,0,240,9,0,0,108,50,0,0,68,38,0,0,220,19,0,0,22,33,0,0,14,1,0,0,118,12,0,0,42,3,0,0,10,22,0,0,162,16,0,0,234,34,0,0,178,27,0,0,254,45,0,0,176,40,0,0,26,9,0,0,244,4,0,0,0,24,0,0,30,4,0,0,178,48,0,0,110,17,0,0,4,10,0,0,146,28,0,0,6,23,0,0,30,38,0,0,174,19,0,0,114,25,0,0,130,6,0,0,58,14,0,0,110,45,0,0,96,0,0,0,96,32,0,0,36,40,0,0,148,21,0,0,42,30,0,0,186,35,0,0,96,17,0,0,190,24,0,0,254,5,0,0,184,11,0,0,208,29,0,0,72,48,0,0,8,17,0,0,86,35,0,0,0,20,0,0,134,22,0,0,4,41,0,0,140,9,0,0,16,28,0,0,196,25,0,0,162,37,0,0,36,6,0,0,186,44,0,0,90,43,0,0,246,11,0,0,70,30,0,0,162,14,0,0,196,45,0,0,126,27,0,0,220,8,0,0,114,38,0,0,44,20,0,0,204,0,0,0,226,32,0,0,194,12,0,0,234,10,0,0,196,13,0,0,250,44,0,0,184,26,0,0,18,6,0,0,64,22,0,0,32,19,0,0,214,48,0,0,30,17,0,0,36,12,0,0,106,30,0,0,40,25,0,0,132,43,0,0,234,37,0,0,72,6,0,0,44,47,0,0,24,16,0,0,228,6,0,0,172,0,0,0,20,20,0,0,124,14,0,0,196,32,0,0,78,9,0,0,142,33,0,0,84,15,0,0,238,20,0,0,160,1,0,0,194,7,0,0,128,31,0,0,184,44,0,0,142,26,0,0,104,35,0,0,4,17,0,0,184,32,0,0,88,38,0,0,8,20,0,0,174,25,0,0,220,6,0,0,154,12,0,0,30,5,0,0,222,36,0,0,0,5,0,0,14,24,0,0,22,44,0,0,214,12,0,0,8,31,0,0,166,49,0,0,56,20,0,0,140,38,0,0,120,26,0,0,160,44,0,0,112,13,0,0,108,33,0,0,134,27,0,0,60,20,0,0,116,2,0,0,96,34,0,0,22,16,0,0,68,47,0,0,118,18,0,0,94,10,0,0,214,41,0,0,94,23,0,0,82,4,0,0,42,36,0,0,114,1,0,0,96,33,0,0,38,15,0,0,64,46,0,0,252,27,0,0,96,9,0,0,158,19,0,0,254,37,0,0,88,32,0,0,50,0,0,0,170,43,0,0,72,12,0,0,116,6,0,0,74,25,0,0,228,17,0,0,82,36,0,0,174,10,0,0,250,21,0,0,134,40,0,0,0,33,0,0,238,0,0,0,226,45,0,0,208,3,0,0,122,35,0,0,90,41,0,0,178,22,0,0,248,29,0,0,52,47,0,0,42,17,0,0,126,48,0,0,228,1,0,0,196,33,0,0,234,2,0,0,240,8,0,0,120,40,0,0,172,47,0,0,56,29,0,0,180,34,0,0,172,19,0,0,56,0,0,0,124,6,0,0,4,38,0,0,78,45,0,0,2,27,0,0,92,32,0,0,32,14,0,0,128,21,0,0,50,2,0,0,182,18,0,0,84,24,0,0,136,5,0,0,56,13,0,0,126,44,0,0,242,49,0,0,54,11,0,0,186,29,0,0,122,17,0,0,240,16,0,0,54,35,0,0,150,3,0,0,12,30,0,0,0,41,0,0,112,9,0,0,14,28,0,0,110,18,0,0,118,30,0,0,14,49,0,0,178,17,0,0,58,36,0,0,98,4,0,0,166,45,0,0,114,27,0,0,198,8,0,0,94,40,0,0,178,15,0,0,200,0,0,0,190,32,0,0,138,14,0,0,254,43,0,0,188,25,0,0,228,37,0,0,80,19,0,0,10,0,0,0,104,30,0,0,34,12,0,0,126,43,0,0,84,30,0,0,212,48,0,0,94,43,0,0,14,12,0,0,50,6,0,0,14,25,0,0,62,19,0,0,194,37,0,0,182,28,0,0,4,47,0,0,42,31,0,0,232,25,0,0,130,11,0,0,154,38,0,0,28,7,0,0,234,0,0,0,50,15,0,0,94,46,0,0,120,1,0,0,104,33,0,0,86,39,0,0,198,20,0,0,114,26,0,0,160,7,0,0,232,16,0,0,20,49,0,0,10,7,0,0,40,22,0,0,40,44,0,0,120,44,0,0,34,31,0,0,216,36,0,0,142,49,0,0,68,18,0,0,180,36,0,0,222,4,0,0,206,25,0,0,18,44,0,0,184,12,0,0,234,30,0,0,192,0,0,0,38,20,0,0,108,50,0,0,8,19,0,0,126,37,0,0,222,7,0,0,62,4,0,0,224,44,0,0,7,7,8,8,8,9,9,10,10,11,11,11,12,12,13,13,14,14,14,15,15,16,16,16,17,17,18,18,19,19,19,20,20,21,21,21,22,22,23,23,24,24,24,25,25,26,26,27,27,27,28,28,29,29,29,30,30,31,31,32,32,32,33,33,34,34,35,35,35,36,36,37,37,37,38,38,39,39,40,40,40,41,41,42,42,42,43,43,44,44,45,45,45,46,46,47,47,48,48,48,49,49,50,50,50,51,51,52,52,53,53,53,54,54,55,55,56,56,56,57,57,58,58,58,59,59,60,60,61,61,61,62,62,63,63,63,64,64,65,65,66,66,66,67,67,68,68,69,69,69,70,70,71,71,71,72,72,73,73,74,74,74,75,75,76,76,77,77,77,78,78,79,79,79,80,80,81,81,82,82,82,83,83,84,84,85,85,85,86,86,87,87,87,88,88,89,89,90,90,90,91,91,92,92,92,93,93,94,94,95,95,95,96,96,97,97,98,98,98,99,99,100,100,100,101,101,102,102,103,103,103,104,104,105,105,106,106,106,107,107,108,108,108,109,109,110,110,111,111,111,112,112,113,113,113,114,114,115,115,116,116,116,117,117,118,118,119,119,119,120,120,121,121,121,122,122,123,123,124,124,124,125,125,126,126,127,127,127,128,128,129,129,129,130,130,131,131,132,132,132,133,133,134,134,134,135,135,136,136,137,137,137,138,138,139,139,140,140,140,141,141,142,142,142,143,143,144,144,145,145,145,146,146,147,147,148,148,148,149,149,150,150,150,151,151,152,152,153,153,153,154,154,155,155,155,156,156,157,157,158,158,158,159,159,160,160,161,161,161,162,162,163,163,163,164,164,165,165,166,166,166,167,167,168,168,169,169,169,170,170,171,171,171,172,172,173,173,174,174,174,175,175,176,176,228,228,228,229,229,230,230,230,231,231,232,232,233,233,233,234,234,235,235,235,236,236,237,237,238,238,238,239,239,240,240,241,241,241,242,242,243,243,243,244,244,245,245,246,246,246,247,247,248,248,249,249,249,250,250,251,251,251,252,252,253,253,254,254,254,255,255,0,0,0,1,1,2,2,3,3,3,4,4,5,5,6,6,6,7,7,8,8,8,9,9,10,10,11,11,11,12,12,13,13,14,14,14,15,15,16,16,16,5,5,5,6,6,7,7,7,8,8,8,9,9,9,10,10,10,11,11,11,12,12,12,13,13,13,14,14,15,15,15,16,16,16,17,17,17,18,18,18,19,19,19,20,20,20,21,21,21,22,22,23,23,23,24,24,24,25,25,25,26,26,26,27,27,27,28,28,28,29,29,29,30,30,31,31,31,32,32,32,33,33,33,34,34,34,35,35,35,36,36,36,37,37,38,38,38,39,39,39,40,40,40,41,41,41,42,42,42,43,43,43,44,44,44,45,45,46,46,46,47,47,47,48,48,48,49,49,49,50,50,50,51,51,51,52,52,52,53,53,54,54,54,55,55,55,56,56,56,57,57,57,58,58,58,59,59,59,60,60,61,61,61,62,62,62,63,63,63,64,64,64,65,65,65,66,66,66,67,67,67,68,68,69,69,69,70,70,70,71,71,71,72,72,72,73,73,73,74,74,74,75,75,75,76,76,77,77,77,78,78,78,79,79,79,80,80,80,81,81,81,82,82,82,83,83,83,84,84,85,85,85,86,86,86,87,87,87,88,88,88,89,89,89,90,90,90,91,91,92,92,92,93,93,93,94,94,94,95,95,95,96,96,96,97,97,97,98,98,98,99,99,100,100,100,101,101,101,102,102,102,103,103,103,104,104,104,105,105,105,106,106,106,107,107,108,108,108,109,109,109,110,110,110,111,111,111,112,112,112,113,113,113,114,114,114,115,115,116,116,116,117,117,117,118,118,118,119,119,119,120,120,120,121,121,121,122,122,123,123,123,124,124,124,125,125,125,126,126,126,127,127,127,128,128,128,129,129,129,130,130,131,131,131,132,132,132,133,133,133,134,134,134,135,135,135,136,136,136,137,137,137,138,138,139,139,139,140,140,140,141,141,141,142,142,142,143,143,143,144,144,144,145,145,232,232,232,233,233,233,234,234,234,235,235,235,236,236,236,237,237,237,238,238,238,239,239,240,240,240,241,241,241,242,242,242,243,243,243,244,244,244,245,245,245,246,246,246,247,247,248,248,248,249,249,249,250,250,250,251,251,251,252,252,252,253,253,253,254,254,254,255,255,0,0,0,1,1,1,2,2,2,3,3,3,4,4,4,5,5,5,6,6,7,7,7,8,8,8,9,9,9,10,10,10,11,11,11,12,12,12,13,0,0,0,0,0,0,0,0,3,0,0,0,5,0,0,0,9,0,0,0,10,0,0,0,8,0,0,0,15,0,0,0,12,0,0,0,11,0,0,0,6,0,0,0,0,0,0,0,2,0,0,0,13,0,0,0,1,0,0,0,4,0,0,0,14,0,0,0,7,0,0,0,0,0,0,0,1,0,0,0,3,0,0,0,5,0,0,0,8,0,0,0,9,0,0,0,11,0,0,0,12,0,0,0,10,0,0,0,4,0,0,0,6,0,0,0,7,0,0,0,2,0,0,0,13,0,0,0,15,0,0,0,14,0,0,0,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,101,116,111,45,49,46,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,151,101,40,68,2,0,16,1,101,116,111,45,48,46,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,112,147,183,87,2,0,16,1,101,116,111,45,50,46,51,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,181,111,244,18,1,0,16,1,101,116,111,45,53,46,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,160,157,104,179,9,0,16,1,101,116,111,45,52,46,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,57,137,118,168,11,0,32,0,101,116,111,45,51,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,151,115,36,221,15,0,32,0,73,71,83,48,48,48,55,82,68,49,48,51,48,57,48,57,167,241,10,202,105,178,206,134,236,61,162,90,3,233,191,186,247,213,236,104,3,144,21,204,13,8,45,118,165,181,65,241,67,6,221,203,189,12,164,226,8,101,42,240,48,107,21,89,153,158,117,53,119,79,96,153,140,143,210,43,33,87,195,229,72,249,138,41,80,198,113,6,137,1,154,201,57,4,18,200,223,177,51,107,167,28,63,123,45,118,58,175,118,61,8,116,44,162,200,253,26,58,111,139,232,233,169,254,23,12,237,157,64,230,223,34,137,77,234,9,104,150,30,26,156,189,71,53,104,217,79,94,18,191,214,9,157,246,15,167,194,219,222,112,53,21,47,115,22,60,154,220,181,197,53,134,138,49,184,193,116,118,215,101,50,173,220,23,31,254,133,218,50,201,29,218,54,22,222,118,69,63,133,140,139,220,55,8,57,239,148,175,200,81,25,41,112,93,187,78,232,219,194,178,95,46,227,115,186,194,161,66,16,176,229,176,100,180,220,187,161,81,18,152,220,67,204,195,197,37,171,69,110,99,126,69,64,99,103,210,100,119,105,45,112,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,168,46,63,142,1,0,16,1,100,119,105,45,115,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,239,193,197,61,2,0,32,0,100,119,105,45,99,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,148,218,139,43,3,0,32,0,100,119,105,45,99,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,222,228,69,83,3,0,32,0,100,119,105,45,99,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,20,95,24,198,3,0,32,0,100,119,105,45,99,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,1,151,229,201,3,0,32,0,100,119,105,45,99,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,144,28,221,66,3,0,32,0,100,119,105,45,99,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,81,214,166,159,3,0,32,0,100,119,105,45,99,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,134,104,250,92,3,0,32,0,100,119,105,45,99,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,113,120,195,89,3,0,32,0,100,119,105,45,109,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,101,224,73,34,4,0,16,1,100,119,105,45,118,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,9,0,228,76,187,19,5,0,64,0,116,112,48,50,48,45,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,213,11,66,216,0,0,16,1,116,112,48,50,48,45,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,142,222,34,114,0,0,16,1,116,112,48,50,48,45,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,30,228,187,62,0,0,32,0,116,112,48,50,48,45,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,34,94,45,0,0,32,0,104,100,54,52,55,49,56,48,46,48,50,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,16,0,0,16,116,112,48,50,51,95,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,29,248,101,41,0,0,16,1,116,112,48,50,51,95,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,139,80,173,50,0,0,32,0,116,112,48,50,51,95,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,235,144,76,184,0,0,32,0,116,112,48,50,51,95,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,119,192,147,228,0,0,32,0,116,112,48,50,51,95,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,10,181,132,144,0,0,32,0,116,112,48,50,51,95,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,161,130,216,76,0,0,16,1,116,112,48,50,51,95,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,143,49,50,55,0,0,64,0,81,196,227,16,28,173,138,57,140,224,165,4,15,228,53,195,45,107,50,226,96,84,99,6,163,241,11,95,108,92,179,236,119,97,105,231,60,183,66,114,26,112,176,150,164,40,192,251,10,0,203,21,73,72,211,148,88,207,65,134,23,113,177,189,33,1,55,30,186,235,243,89,246,167,41,79,181,202,76,52,32,162,98,75,147,158,71,159,141,14,27,182,77,130,213,244,133,121,83,146,155,247,234,68,118,31,34,69,237,190,17,85,175,245,248,80,7,230,199,94,215,222,229,38,43,242,106,139,184,152,137,219,20,91,197,120,220,208,135,93,193,13,149,151,126,168,36,61,225,209,25,166,153,216,131,29,255,48,157,5,212,2,39,123,19,178,127,64,18,160,104,103,78,58,70,185,238,223,102,214,143,169,12,145,101,24,82,86,217,116,9,110,198,115,201,252,3,67,239,170,124,187,44,144,204,206,232,174,42,249,87,136,200,233,90,221,46,125,100,194,109,62,250,128,22,205,111,132,142,156,240,172,180,154,47,188,49,35,254,56,8,117,161,51,171,210,218,129,191,122,59,63,74,253,37,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,52,52,45,112,49,46,112,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,109,122,159,202,1,0,16,1,48,52,52,45,115,49,46,115,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,57,63,144,137,2,0,32,0,48,52,52,45,99,49,46,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,167,152,171,221,3,0,32,0,48,52,52,45,99,50,46,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,117,213,204,216,3,0,32,0,48,52,52,45,99,51,46,99,51,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,138,137,62,64,3,0,32,0,48,52,52,45,99,52,46,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,170,251,53,98,3,0,32,0,48,52,52,45,109,49,46,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,187,228,135,9,4,0,16,1,48,52,52,45,118,50,46,118,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,234,50,198,62,5,0,64,0,48,52,52,45,118,52,46,118,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,35,142,15,75,5,0,64,0,116,107,50,101,95,50,51,99,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,5,133,112,13,2,0,16,1,116,107,50,101,95,50,50,99,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,227,23,140,96,2,0,16,1,116,107,50,45,49,109,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,191,185,156,13,4,0,32,0,116,107,50,45,51,109,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,112,34,69,4,0,32,0,116,107,50,45,50,109,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,96,36,202,197,4,0,32,0,116,107,50,45,52,109,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,28,85,73,227,4,0,32,0,116,107,50,45,53,109,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,11,15,31,41,4,0,32,0,116,107,50,45,55,109,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,73,185,222,62,4,0,32,0,116,107,50,45,54,109,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,214,20,189,26,4,0,32,0,116,107,50,45,56,109,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,227,72,121,178,4,0,32,0,116,107,50,95,113,97,46,53,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,13,58,24,201,3,0,16,0,116,107,50,45,113,49,46,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,207,104,18,97,6,0,64,0,116,107,50,45,113,50,46,50,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,169,92,245,32,6,0,64,0,116,107,50,45,113,51,46,51,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,82,111,207,191,6,0,64,0,116,107,50,45,113,52,46,52,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,136,46,100,54,6,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,154,135,134,67,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,116,107,50,54,51,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,155,52,176,196,0,0,0,8,105,111,98,49,46,49,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,98,112,114,103,49,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,167,61,121,49,0,0,0,8,105,111,99,49,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,129,32,24,13,0,0,0,8,100,55,108,49,46,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,13,65,183,39,0,0,0,8,100,56,108,49,46,56,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,218,199,159,83,0,0,0,8,100,57,107,49,46,57,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,0,0,0,0,0,0,24,100,49,48,102,49,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,148,196,25,102,0,0,0,8,27,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,72,4,1,0,27,0,0,0,1,8,8,0,96,135,7,0,27,0,0,0,1,8,0,0,152,182,7,0,101,112,114,45,49,50,50,53,57,46,97,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,126,124,146,84,1,0,16,1,101,112,114,45,49,50,50,53,56,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,140,137,245,1,1,0,16,1,101,112,114,45,49,50,49,50,52,46,97,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,111,251,206,218,2,0,32,0,101,112,114,45,49,50,49,50,53,46,97,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,247,109,195,159,2,0,32,0,101,112,114,45,49,50,49,50,54,46,97,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,148,253,147,166,2,0,32,0,101,112,114,45,49,50,48,57,48,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,202,207,238,174,3,0,32,0,101,112,114,45,49,50,48,57,52,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,39,73,94,97,3,0,32,0,101,112,114,45,49,50,48,57,49,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,67,162,9,132,3,0,32,0,101,112,114,45,49,50,48,57,53,46,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,44,236,116,231,3,0,32,0,101,112,114,45,49,50,48,57,50,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,144,13,47,92,3,0,32,0,101,112,114,45,49,50,48,57,54,46,98,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,110,157,213,12,3,0,32,0,101,112,114,45,49,50,48,57,51,46,98,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,187,231,145,72,3,0,32,0,101,112,114,45,49,50,48,57,55,46,98,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,44,144,69,230,3,0,32,0,101,112,114,45,49,50,49,50,55,46,97,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,187,1,185,11,4,0,16,1,51,49,55,45,48,48,57,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,16,19,0,0,0,255,255,253,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,2,2,0,96,135,7,0,19,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,19,0,0,0,1,12,0,0,208,75,4,0,19,0,0,0,1,12,12,0,8,49,4,0,19,0,0,0,1,12,8,0,152,21,4,0,19,0,0,0,1,12,4,0,72,246,3,0,0,0,0,0,254,0,2,0,64,37,5,0,19,0,0,0,1,16,16,0,40,124,5,0,19,0,0,0,1,16,0,0,232,121,5,0,0,0,0,0,254,0,2,0,72,202,5,0,19,0,0,0,1,32,32,0,248,38,7,0,19,0,0,0,1,32,0,0,112,212,3,0,0,0,0,0,254,0,2,0,160,119,5,0,19,0,0,0,1,64,64,0,56,111,3,0,19,0,0,0,1,64,0,0,104,134,3,0,0,0,0,0,254,0,16,0,200,87,7,0,20,0,0,0,1,15,7,0,80,252,6,0,20,0,0,0,1,15,8,0,16,242,7,0,20,0,0,0,1,15,9,0,104,236,7,0,20,0,0,0,1,15,5,0,176,51,4,0,20,0,0,0,1,15,4,0,56,24,4,0,20,0,0,0,1,15,15,0,128,230,7,0,20,0,0,0,1,15,1,0,72,216,3,0,20,0,0,0,1,15,2,0,24,188,3,0,20,0,0,0,1,15,3,0,176,162,3,0,20,0,0,0,1,15,6,0,120,211,6,0,20,0,0,0,1,15,14,0,184,164,6,0,20,0,0,0,1,15,13,0,80,74,6,0,20,0,0,0,1,15,12,0,192,32,6,0,20,0,0,0,1,15,11,0,192,234,2,0,20,0,0,0,1,15,10,0,32,242,5,0,20,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,20,0,0,0,1,240,112,0,80,252,6,0,20,0,0,0,1,240,128,0,16,242,7,0,20,0,0,0,1,240,144,0,104,236,7,0,20,0,0,0,1,240,80,0,176,51,4,0,20,0,0,0,1,240,64,0,56,24,4,0,20,0,0,0,1,240,240,0,128,230,7,0,20,0,0,0,1,240,16,0,72,216,3,0,20,0,0,0,1,240,32,0,24,188,3,0,20,0,0,0,1,240,48,0,176,162,3,0,20,0,0,0,1,240,96,0,120,211,6,0,20,0,0,0,1,240,224,0,184,164,6,0,20,0,0,0,1,240,208,0,80,74,6,0,20,0,0,0,1,240,192,0,192,32,6,0,20,0,0,0,1,240,176,0,192,234,2,0,20,0,0,0,1,240,160,0,32,242,5,0,20,0,0,0,1,240,0,0,208,236,2,0,0,0,0,0,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,21,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,72,202,5,0,19,0,0,0,1,3,2,0,80,246,3,0,19,0,0,0,1,3,3,0,248,38,7,0,19,0,0,0,1,3,1,0,112,212,3,0,19,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,128,129,4,0,19,0,0,0,1,48,16,0,192,255,2,0,19,0,0,0,1,48,0,0,208,75,4,0,19,0,0,0,1,48,48,0,8,49,4,0,19,0,0,0,1,48,32,0,72,246,3,0,0,0,0,0,254,0,4,0,144,212,8,0,20,0,0,0,1,2,2,0,96,135,7,0,20,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,20,0,0,0,1,4,4,0,96,135,7,0,20,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,20,0,0,0,1,48,16,0,96,39,7,0,20,0,0,0,1,48,48,0,144,251,6,0,20,0,0,0,1,48,0,0,120,211,6,0,20,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,2,0,168,234,7,0,20,0,0,0,1,64,0,0,96,135,7,0,20,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,99,54,52,95,49,53,45,49,46,105,99,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,166,8,147,206,2,0,16,1,99,54,52,95,49,54,45,49,46,105,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,58,72,10,71,2,0,16,1,99,54,52,45,48,57,46,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,92,246,215,136,9,0,16,1,99,54,52,45,48,49,46,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,134,244,180,161,15,0,32,0,99,54,52,45,48,50,46,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,7,185,176,60,24,0,64,0,19,0,0,0,255,255,254,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,19,0,0,0,1,1,0,0,120,97,1,0,19,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,2,2,0,96,135,7,0,19,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,4,4,0,96,135,7,0,19,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,8,0,0,96,135,7,0,19,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,19,0,0,0,1,48,0,0,80,252,6,0,19,0,0,0,1,48,16,0,16,242,7,0,19,0,0,0,1,48,32,0,104,236,7,0,19,0,0,0,1,48,48,0,128,230,7,0,0,0,0,0,254,0,4,0,160,123,6,0,19,0,0,0,1,192,192,0,8,201,6,0,19,0,0,0,1,192,128,0,200,197,6,0,19,0,0,0,1,192,64,0,152,194,6,0,19,0,0,0,1,192,0,0,248,189,6,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,3,2,0,80,246,3,0,20,0,0,0,1,3,3,0,80,124,6,0,20,0,0,0,1,3,1,0,112,212,3,0,20,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,192,99,6,0,20,0,0,0,1,12,0,0,120,7,5,0,20,0,0,0,1,12,12,0,192,255,2,0,20,0,0,0,1,12,4,0,208,75,4,0,20,0,0,0,1,12,8,0,8,49,4,0,0,0,0,0,254,0,2,0,128,129,4,0,20,0,0,0,1,16,0,0,208,75,4,0,20,0,0,0,1,16,16,0,8,49,4,0,0,0,0,0,254,0,4,0,208,81,6,0,20,0,0,0,1,160,160,0,128,75,6,0,20,0,0,0,1,160,128,0,16,70,6,0,20,0,0,0,1,160,0,0,104,65,6,0,20,0,0,0,1,160,32,0,64,62,6,0,0,0,0,0,254,0,2,0,104,159,3,0,20,0,0,0,1,64,0,0,96,135,7,0,20,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,18,0,0,0,255,255,255,0,0,0,0,0,19,0,0,0,255,255,94,0,0,0,0,0,20,0,0,0,255,255,240,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,18,0,0,0,1,15,2,0,80,252,6,0,18,0,0,0,1,15,5,0,16,242,7,0,18,0,0,0,1,15,8,0,104,236,7,0,18,0,0,0,1,15,4,0,120,113,6,0,18,0,0,0,1,15,1,0,232,228,5,0,18,0,0,0,1,15,15,0,128,230,7,0,18,0,0,0,1,15,3,0,56,141,7,0,18,0,0,0,1,15,7,0,120,211,6,0,18,0,0,0,1,15,14,0,184,164,6,0,18,0,0,0,1,15,6,0,24,1,7,0,18,0,0,0,1,15,13,0,80,74,6,0,18,0,0,0,1,15,12,0,192,32,6,0,18,0,0,0,1,15,11,0,192,234,2,0,18,0,0,0,1,15,10,0,32,242,5,0,18,0,0,0,1,15,9,0,176,192,2,0,18,0,0,0,1,15,0,0,16,227,4,0,0,0,0,0,254,0,15,0,160,123,6,0,18,0,0,0,1,240,32,0,80,252,6,0,18,0,0,0,1,240,80,0,16,242,7,0,18,0,0,0,1,240,128,0,104,236,7,0,18,0,0,0,1,240,64,0,120,113,6,0,18,0,0,0,1,240,16,0,232,228,5,0,18,0,0,0,1,240,240,0,128,230,7,0,18,0,0,0,1,240,48,0,56,141,7,0,18,0,0,0,1,240,112,0,120,211,6,0,18,0,0,0,1,240,224,0,184,164,6,0,18,0,0,0,1,240,96,0,24,1,7,0,18,0,0,0,1,240,208,0,80,74,6,0,18,0,0,0,1,240,192,0,192,32,6,0,18,0,0,0,1,240,176,0,192,234,2,0,18,0,0,0,1,240,160,0,32,242,5,0,18,0,0,0,1,240,144,0,176,192,2,0,0,0,0,0,254,0,4,0,128,129,4,0,19,0,0,0,1,3,3,0,208,75,4,0,19,0,0,0,1,3,2,0,8,49,4,0,19,0,0,0,1,3,1,0,72,246,3,0,19,0,0,0,1,3,0,0,64,47,7,0,0,0,0,0,254,0,4,0,64,37,5,0,19,0,0,0,1,24,24,0,240,177,4,0,19,0,0,0,1,24,16,0,152,145,4,0,19,0,0,0,1,24,8,0,152,195,3,0,19,0,0,0,1,24,0,0,112,129,7,0,0,0,0,0,254,0,4,0,72,202,5,0,19,0,0,0,1,96,96,0,80,246,3,0,19,0,0,0,1,96,64,0,248,38,7,0,19,0,0,0,1,96,32,0,48,123,8,0,19,0,0,0,1,96,0,0,8,117,8,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,128,128,0,96,135,7,0,19,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,192,192,5,0,20,0,0,0,1,32,32,0,248,38,7,0,20,0,0,0,1,32,0,0,104,159,7,0,0,0,0,0,254,0,2,0,232,75,4,0,20,0,0,0,1,64,64,0,96,135,7,0,20,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,224,117,5,0,20,0,0,0,1,128,128,0,184,112,5,0,20,0,0,0,1,128,0,0,88,239,5,0,0,0,0,0,115,102,120,95,98,45,48,46,49,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,82,105,188,229,1,0,16,1,49,46,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,231,72,60,27,1,0,16,1,50,50,46,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,13,149,68,237,1,0,16,1,50,51,46,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,160,60,74,244,1,0,16,1,50,55,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,159,131,134,237,1,0,16,1,50,52,46,49,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,116,220,215,230,1,0,16,1,53,46,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,144,211,232,209,1,0,16,1,53,46,53,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,182,143,2,89,2,0,16,1,54,46,54,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,15,103,39,84,2,0,16,1,49,46,49,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,88,44,23,47,3,0,16,1,50,46,50,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,107,47,173,166,3,0,16,1,51,46,51,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,250,116,18,250,3,0,16,1,52,46,52,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,58,63,211,28,3,0,16,1,49,48,46,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,91,161,51,184,3,0,16,1,49,49,46,52,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,194,110,215,203,3,0,16,1,50,56,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,82,130,58,215,4,0,32,0,50,57,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,242,204,1,20,4,0,32,0,54,51,51,49,46,57,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,205,156,29,202,7,0,32,0,18,0,0,0,255,255,0,0,0,0,0,0,19,0,0,0,255,255,1,0,0,0,0,0,20,0,0,0,255,255,8,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,19,0,0,0,1,3,1,0,8,49,4,0,19,0,0,0,1,3,2,0,152,21,4,0,19,0,0,0,1,3,3,0,72,246,3,0,19,0,0,0,1,3,0,0,48,250,1,0])
.concat([0,0,0,0,254,0,4,0,32,4,2,0,20,0,0,0,1,6,6,0,176,45,8,0,20,0,0,0,1,6,4,0,224,127,8,0,20,0,0,0,1,6,0,0,32,123,8,0,20,0,0,0,1,6,2,0,192,110,8,0,0,0,0,0,254,0,2,0,200,30,2,0,20,0,0,0,1,8,8,0,120,97,1,0,20,0,0,0,1,8,0,0,96,19,1,0,115,102,122,101,46,48,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,77,5,242,235,1,0,16,1,115,102,122,46,48,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,229,176,115,139,1,0,16,1,115,102,122,46,48,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,77,84,16,8,1,0,16,1,115,102,122,46,48,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,56,143,110,128,1,0,16,1,115,102,122,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,179,253,254,144,5,0,32,0,115,102,122,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,72,201,84,83,5,0,32,0,115,102,122,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,144,231,161,65,5,0,32,0,115,102,122,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,152,223,73,165,5,0,32,0,115,102,122,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,125,236,255,255,10,0,16,1,115,102,122,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,8,106,244,69,10,0,16,1,115,102,122,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,205,147,176,196,12,0,64,0,115,102,122,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,180,196,219,139,12,0,64,0,115,102,50,101,95,51,48,103,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,51,238,57,254,1,0,16,1,115,102,50,101,95,51,55,103,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,116,205,146,251,1,0,16,1,115,102,50,101,95,51,49,103,46,49,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,1,163,160,105,1,0,16,1,115,102,50,101,95,51,56,103,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,112,219,34,94,1,0,16,1,115,102,50,101,95,50,56,103,46,57,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,229,241,249,139,1,0,16,1,115,102,50,101,95,51,53,103,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,52,249,110,98,1,0,16,1,115,102,50,95,50,57,98,46,49,48,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,21,243,74,187,1,0,16,1,115,102,50,95,51,54,98,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,235,19,42,192,1,0,16,1,115,102,50,45,53,109,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,142,204,201,34,4,0,32,0,115,102,50,45,55,109,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,232,59,33,87,4,0,32,0,115,102,50,45,49,109,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,79,155,82,186,4,0,32,0,115,102,50,45,51,109,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,51,27,75,4,0,32,0,115,102,50,45,54,109,46,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,41,34,126,44,4,0,32,0,115,102,50,45,56,109,46,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,23,143,84,181,4,0,32,0,115,102,50,45,50,109,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,18,67,184,20,4,0,32,0,115,102,50,45,52,109,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,154,216,156,94,4,0,32,0,115,102,50,45,49,51,109,46,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,88,250,75,153,4,0,32,0,115,102,50,45,49,53,109,46,54,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,157,173,102,62,4,0,32,0,115,102,50,45,57,109,46,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,168,250,190,193,4,0,32,0,115,102,50,45,49,49,109,46,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,49,200,39,6,4,0,32,0,115,102,50,95,57,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,27,58,130,164,3,0,16,0,115,102,50,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,9,32,22,127,5,0,64,0,115,102,50,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,63,229,173,190,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,115,116,102,50,57,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,197,9,51,4,0,0,0,8,105,111,98,49,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,99,54,51,50,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,112,146,189,15,0,0,0,8,27,0,0,0,255,255,0,0,0,0,0,0,28,0,0,0,255,255,3,0,0,0,0,0,29,0,0,0,255,255,96,0,0,0,0,0,0,0,0,0,254,0,8,0,200,87,7,0,27,0,0,0,1,7,7,0,80,252,6,0,27,0,0,0,1,7,6,0,16,242,7,0,27,0,0,0,1,7,5,0,104,236,7,0,27,0,0,0,1,7,0,0,128,230,7,0,27,0,0,0,1,7,1,0,184,164,6,0,27,0,0,0,1,7,2,0,80,74,6,0,27,0,0,0,1,7,3,0,192,32,6,0,27,0,0,0,1,7,4,0,32,242,5,0,0,0,0,0,254,0,8,0,160,123,6,0,27,0,0,0,1,56,56,0,80,252,6,0,27,0,0,0,1,56,48,0,16,242,7,0,27,0,0,0,1,56,40,0,104,236,7,0,27,0,0,0,1,56,0,0,128,230,7,0,27,0,0,0,1,56,8,0,184,164,6,0,27,0,0,0,1,56,16,0,80,74,6,0,27,0,0,0,1,56,24,0,192,32,6,0,27,0,0,0,1,56,32,0,32,242,5,0,0,0,0,0,254,0,2,0,64,232,1,0,27,0,0,0,1,64,0,0,96,135,7,0,27,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,8,0,72,202,5,0,28,0,0,0,1,7,0,0,72,198,6,0,28,0,0,0,1,7,1,0,208,75,4,0,28,0,0,0,1,7,2,0,8,49,4,0,28,0,0,0,1,7,3,0,72,195,6,0,28,0,0,0,1,7,4,0,72,246,3,0,28,0,0,0,1,7,5,0,72,0,3,0,28,0,0,0,1,7,6,0,64,47,7,0,28,0,0,0,1,7,7,0,48,173,6,0,0,0,0,0,254,0,2,0,16,227,4,0,29,0,0,0,1,4,0,0,96,135,7,0,29,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,254,0,2,0,72,4,1,0,29,0,0,0,1,8,0,0,96,135,7,0,29,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,29,0,0,0,1,16,0,0,96,135,7,0,29,0,0,0,1,16,16,0,152,182,7,0,0,0,0,0,254,0,2,0,40,111,8,0,29,0,0,0,1,32,0,0,96,135,7,0,29,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,29,0,0,0,1,64,0,0,96,135,7,0,29,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,168,79,2,0,29,0,0,0,1,128,0,0,32,182,8,0,29,0,0,0,1,128,128,0,80,251,6,0,0,0,0,0,101,112,114,45,49,48,57,55,48,46,52,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,44,74,250,184,1,0,16,1,101,112,114,45,49,48,57,54,56,46,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,147,119,249,163,1,0,16,1,101,112,114,45,49,48,57,55,49,46,52,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,40,3,74,196,1,0,16,1,101,112,114,45,49,48,57,54,57,46,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,189,21,93,69,1,0,16,1,101,112,114,45,49,48,55,53,53,46,52,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,105,57,94,64,1,0,16,1,101,112,114,45,49,48,55,53,50,46,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,64,55,69,119,1,0,16,1,101,112,114,45,49,48,55,53,54,46,57,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,6,165,216,68,2,0,32,0,101,112,114,45,49,48,55,53,55,46,57,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,64,23,126,73,2,0,32,0,101,112,114,45,49,48,55,53,56,46,57,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,134,20,214,97,2,0,32,0,101,112,114,45,49,48,55,54,48,46,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,10,197,226,48,3,0,32,0,101,112,114,45,49,48,55,54,51,46,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,139,62,78,121,3,0,32,0,101,112,114,45,49,48,55,54,49,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,208,63,139,106,3,0,32,0,101,112,114,45,49,48,55,54,52,46,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,213,165,45,96,3,0,32,0,101,112,114,45,49,48,55,54,50,46,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,235,58,222,185,3,0,32,0,101,112,114,45,49,48,55,54,53,46,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,87,160,115,10,3,0,32,0,101,112,114,45,49,48,55,53,57,46,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,159,100,249,215,4,0,16,1,51,49,55,45,48,48,50,55,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,178,7,83,154,5,0,16,1,21,0,0,0,255,255,255,0,0,0,0,0,22,0,0,0,255,255,253,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,21,0,0,0,1,15,7,0,80,252,6,0,21,0,0,0,1,15,8,0,16,242,7,0,21,0,0,0,1,15,9,0,104,236,7,0,21,0,0,0,1,15,5,0,176,51,4,0,21,0,0,0,1,15,4,0,56,24,4,0,21,0,0,0,1,15,15,0,128,230,7,0,21,0,0,0,1,15,1,0,72,216,3,0,21,0,0,0,1,15,2,0,24,188,3,0,21,0,0,0,1,15,3,0,176,162,3,0,21,0,0,0,1,15,6,0,120,211,6,0,21,0,0,0,1,15,14,0,184,164,6,0,21,0,0,0,1,15,13,0,80,74,6,0,21,0,0,0,1,15,12,0,192,32,6,0,21,0,0,0,1,15,11,0,192,234,2,0,21,0,0,0,1,15,10,0,32,242,5,0,21,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,21,0,0,0,1,240,112,0,80,252,6,0,21,0,0,0,1,240,128,0,16,242,7,0,21,0,0,0,1,240,144,0,104,236,7,0,21,0,0,0,1,240,80,0,176,51,4,0,21,0,0,0,1,240,64,0,56,24,4,0,21,0,0,0,1,240,240,0,128,230,7,0,21,0,0,0,1,240,16,0,72,216,3,0,21,0,0,0,1,240,32,0,24,188,3,0,21,0,0,0,1,240,48,0,176,162,3,0,21,0,0,0,1,240,96,0,120,211,6,0,21,0,0,0,1,240,224,0,184,164,6,0,21,0,0,0,1,240,208,0,80,74,6,0,21,0,0,0,1,240,192,0,192,32,6,0,21,0,0,0,1,240,176,0,192,234,2,0,21,0,0,0,1,240,160,0,32,242,5,0,21,0,0,0,1,240,0,0,208,236,2,0,0,0,0,0,254,0,2,0,104,159,3,0,22,0,0,0,1,1,1,0,56,111,3,0,22,0,0,0,1,1,0,0,104,134,3,0,0,0,0,0,254,0,2,0,168,234,7,0,22,0,0,0,1,2,2,0,96,135,7,0,22,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,22,0,0,0,1,12,8,0,208,75,4,0,22,0,0,0,1,12,12,0,8,49,4,0,22,0,0,0,1,12,4,0,152,21,4,0,22,0,0,0,1,12,0,0,64,96,7,0,0,0,0,0,254,0,4,0,72,202,5,0,22,0,0,0,1,48,32,0,80,246,3,0,22,0,0,0,1,48,48,0,248,38,7,0,22,0,0,0,1,48,16,0,112,212,3,0,22,0,0,0,1,48,0,0,248,160,5,0,0,0,0,0,254,0,4,0,64,37,5,0,22,0,0,0,1,192,128,0,200,201,3,0,22,0,0,0,1,192,192,0,8,49,6,0,22,0,0,0,1,192,64,0,160,191,4,0,22,0,0,0,1,192,0,0,120,7,5,0,0,0,0,0,99,48,57,45,51,55,46,52,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,23,234,236,15,2,0,16,1,99,48,57,45,51,56,46,52,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,155,189,110,228,2,0,16,1,99,48,57,45,52,50,46,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,135,79,64,244,2,0,16,1,99,48,57,45,51,57,46,52,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,185,188,135,222,2,0,16,1,99,48,57,45,51,51,46,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,91,108,78,207,6,0,16,1,99,48,57,45,51,50,46,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,25,55,113,164,6,0,16,1,99,48,57,45,51,52,46,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,81,49,27,162,9,0,16,1,99,48,57,45,48,53,46,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,240,56,11,137,11,0,32,0,99,48,57,45,48,52,46,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,155,60,187,44,17,0,32,0,99,48,57,45,48,50,46,53,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,137,3,58,168,17,0,32,0,99,48,57,45,48,51,46,53,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,128,14,29,163,17,0,32,0,99,48,57,45,48,49,46,53,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,16,234,191,100,17,0,32,0,99,48,57,45,48,55,46,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,43,200,59,150,22,0,32,0,99,48,57,45,48,54,46,51,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,123,109,223,18,23,0,32,0,99,48,57,45,49,52,46,52,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,70,191,120,173,24,0,64,0,99,48,57,45,49,51,46,52,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,211,65,124,213,24,0,64,0,99,48,57,45,49,50,46,52,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,165,159,201,86,24,0,64,0,99,48,57,45,49,53,46,50,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,149,144,59,230,25,0,64,0,99,48,57,45,49,54,46,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0])
.concat([246,166,69,114,0,0,0,8,99,48,57,45,50,48,46,55,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,128,253,143,205,0,0,0,8,99,48,57,45,50,51,46,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,48,31,248,251,0,0,0,8,13,0,0,0,255,255,254,0,0,0,0,0,14,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,13,0,0,0,1,1,1,0,80,46,8,0,13,0,0,0,1,1,0,0,120,97,1,0,0,0,0,0,254,0,2,0,232,75,4,0,13,0,0,0,1,4,4,0,96,135,7,0,13,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,13,0,0,0,1,8,0,0,96,135,7,0,13,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,13,0,0,0,1,48,0,0,80,252,6,0,13,0,0,0,1,48,16,0,16,242,7,0,13,0,0,0,1,48,32,0,104,236,7,0,13,0,0,0,1,48,48,0,128,230,7,0,0,0,0,0,254,0,4,0,160,123,6,0,13,0,0,0,1,192,192,0,8,201,6,0,13,0,0,0,1,192,128,0,200,197,6,0,13,0,0,0,1,192,64,0,152,194,6,0,13,0,0,0,1,192,0,0,248,189,6,0,0,0,0,0,254,0,4,0,72,202,5,0,14,0,0,0,1,3,2,0,80,246,3,0,14,0,0,0,1,3,3,0,248,38,7,0,14,0,0,0,1,3,1,0,112,212,3,0,14,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,136,20,8,0,14,0,0,0,1,12,8,0,48,17,8,0,14,0,0,0,1,12,4,0,248,12,8,0,14,0,0,0,1,12,12,0,208,6,8,0,14,0,0,0,1,12,0,0,112,2,8,0,0,0,0,0,254,0,2,0,216,250,7,0,14,0,0,0,1,16,16,0,8,49,4,0,14,0,0,0,1,16,0,0,72,246,3,0,0,0,0,0,254,0,2,0,152,230,7,0,14,0,0,0,1,32,0,0,160,226,7,0,14,0,0,0,1,32,32,0,24,223,7,0,0,0,0,0,254,0,2,0,48,219,7,0,14,0,0,0,1,64,0,0,96,135,7,0,14,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,104,215,7,0,14,0,0,0,1,128,128,0,248,38,7,0,14,0,0,0,1,128,0,0,112,134,3,0,0,0,0,0,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,252,0,0,0,0,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,4,4,0,96,135,7,0,19,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,8,0,0,96,135,7,0,19,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,32,4,2,0,19,0,0,0,1,48,0,0,32,136,7,0,19,0,0,0,1,48,16,0,40,88,7,0,19,0,0,0,1,48,32,0,96,39,7,0,19,0,0,0,1,48,48,0,144,251,6,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,3,2,0,80,246,3,0,20,0,0,0,1,3,3,0,80,124,6,0,20,0,0,0,1,3,1,0,112,212,3,0,20,0,0,0,1,3,0,0,248,160,5,0,22,0,0,0,255,255,0,0,0,0,0,0,23,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,120,26,6,0,22,0,0,0,1,1,0,0,96,184,1,0,22,0,0,0,1,1,1,0,136,128,8,0,0,0,0,0,254,0,4,0,128,129,4,0,22,0,0,0,1,12,8,0,208,75,4,0,22,0,0,0,1,12,0,0,8,49,4,0,22,0,0,0,1,12,4,0,152,21,4,0,22,0,0,0,1,12,12,0,72,246,3,0,0,0,0,0,254,0,4,0,112,171,4,0,22,0,0,0,1,48,22,0,104,236,7,0,22,0,0,0,1,48,0,0,128,230,7,0,22,0,0,0,1,48,16,0,184,164,6,0,22,0,0,0,1,48,48,0,16,227,4,0,0,0,0,0,254,0,2,0,112,31,4,0,22,0,0,0,1,64,0,0,232,2,4,0,22,0,0,0,1,64,64,0,136,225,3,0,0,0,0,0,254,0,2,0,144,212,8,0,22,0,0,0,1,128,0,0,96,135,7,0,22,0,0,0,1,128,128,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,23,0,0,0,1,1,0,0,96,135,7,0,23,0,0,0,1,1,1,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,23,0,0,0,1,2,2,0,56,111,3,0,23,0,0,0,1,2,0,0,104,134,3,0,0,0,0,0,254,0,4,0,64,37,5,0,23,0,0,0,1,12,0,0,120,101,2,0,23,0,0,0,1,12,8,0,8,162,1,0,23,0,0,0,1,12,4,0,32,155,1,0,23,0,0,0,1,12,12,0,120,7,5,0,0,0,0,0,254,0,4,0,168,79,2,0,23,0,0,0,1,48,22,0,8,167,2,0,23,0,0,0,1,48,0,0,208,152,2,0,23,0,0,0,1,48,48,0,72,4,1,0,23,0,0,0,1,48,16,0,224,195,4,0,0,0,0,0,254,0,4,0,72,202,5,0,23,0,0,0,1,192,128,0,80,246,3,0,23,0,0,0,1,192,0,0,248,38,7,0,23,0,0,0,1,192,64,0,112,212,3,0,23,0,0,0,1,192,192,0,248,160,5,0,22,13,0,0,96,26,0,0,226,6,0,0,206,13,0,0,132,17,0,0,188,36,0,0,144,27,0,0,244,3,0,0,80,6,0,0,166,8,0,0,60,37,0,0,100,48,0,0,113,100,117,95,51,54,97,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,160,36,156,222,1,0,16,1,113,100,117,95,52,50,97,46,49,50,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,12,111,227,207,1,0,16,1,113,100,117,95,51,55,97,46,49,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,32,35,210,16,1,0,16,1,113,100,117,95,52,51,97,46,49,51,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,185,190,230,21,1,0,16,1,113,100,95,48,57,46,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,68,159,63,140,4,0,32,0,113,100,95,48,49,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,143,207,136,246,4,0,32,0,113,100,95,49,51,46,57,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,27,85,189,175,4,0,32,0,113,100,95,48,53,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,16,9,219,195,4,0,32,0,113,100,95,50,52,46,53,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,236,208,27,47,4,0,32,0,113,100,95,49,55,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,226,249,18,168,4,0,32,0,113,100,95,51,56,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,31,221,221,204,4,0,32,0,113,100,95,51,50,46,56,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,211,149,210,168,4,0,32,0,113,100,95,50,51,46,49,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,75,38,181,207,3,0,16,0,113,100,117,95,51,48,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,132,218,144,241,5,0,64,0,113,100,117,95,51,49,46,49,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,115,63,88,183,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,113,100,50,50,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,171,83,60,120,0,0,0,8,105,111,98,49,46,49,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,105,111,99,49,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,129,32,24,13,0,0,0,8,15,0,0,0,255,255,0,0,0,0,0,0,16,0,0,0,255,255,11,0,0,0,0,0,17,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,8,0,32,4,2,0,15,0,0,0,1,7,7,0,80,252,6,0,15,0,0,0,1,7,6,0,16,242,7,0,15,0,0,0,1,7,5,0,104,236,7,0,15,0,0,0,1,7,0,0,128,230,7,0,15,0,0,0,1,7,1,0,184,164,6,0,15,0,0,0,1,7,2,0,80,74,6,0,15,0,0,0,1,7,3,0,192,32,6,0,15,0,0,0,1,7,4,0,32,242,5,0,0,0,0,0,254,0,2,0,64,232,1,0,15,0,0,0,1,64,0,0,96,135,7,0,15,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,5,0,72,202,5,0,16,0,0,0,1,7,1,0,160,246,1,0,16,0,0,0,1,7,2,0,80,246,3,0,16,0,0,0,1,7,3,0,248,38,7,0,16,0,0,0,1,7,4,0,112,212,3,0,16,0,0,0,1,7,5,0,248,160,5,0,0,0,0,0,254,0,4,0,64,153,1,0,16,0,0,0,1,24,0,0,80,246,3,0,16,0,0,0,1,24,8,0,248,38,7,0,16,0,0,0,1,24,16,0,112,212,3,0,16,0,0,0,1,24,24,0,248,160,5,0,0,0,0,0,254,0,5,0,128,129,4,0,16,0,0,0,1,224,128,0,192,255,2,0,16,0,0,0,1,224,96,0,208,75,4,0,16,0,0,0,1,224,64,0,8,49,4,0,16,0,0,0,1,224,32,0,152,21,4,0,16,0,0,0,1,224,0,0,72,246,3,0,0,0,0,0,254,0,2,0,16,227,4,0,17,0,0,0,1,4,0,0,96,135,7,0,17,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,254,0,2,0,72,4,1,0,17,0,0,0,1,8,0,0,96,135,7,0,17,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,2,0,120,207,1,0,17,0,0,0,1,16,0,0,96,135,7,0,17,0,0,0,1,16,16,0,152,182,7,0,0,0,0,0,254,0,2,0,40,111,8,0,17,0,0,0,1,32,32,0,96,135,7,0,17,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,17,0,0,0,1,64,64,0,96,135,7,0,17,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,79,2,0,17,0,0,0,1,128,0,0,32,182,8,0,17,0,0,0,1,128,128,0,80,251,6,0,20,0,0,0,255,255,0,0,0,0,0,0,21,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,4,0,200,87,7,0,20,0,0,0,1,3,0,0,128,230,7,0,20,0,0,0,1,3,2,0,184,164,6,0,20,0,0,0,1,3,1,0,80,74,6,0,20,0,0,0,1,3,3,0,192,32,6,0,0,0,0,0,254,0,4,0,160,123,6,0,20,0,0,0,1,12,12,0,80,252,6,0,20,0,0,0,1,12,4,0,16,242,7,0,20,0,0,0,1,12,8,0,104,236,7,0,20,0,0,0,1,12,0,0,128,230,7,0,0,0,0,0,254,0,2,0,128,129,4,0,20,0,0,0,1,16,0,0,208,75,4,0,20,0,0,0,1,16,16,0,8,49,4,0,0,0,0,0,254,0,2,0,112,31,4,0,20,0,0,0,1,20,0,0,232,2,4,0,20,0,0,0,1,20,20,0,136,225,3,0,0,0,0,0,254,0,2,0,128,112,3,0,20,0,0,0,1,64,0,0,168,22,4,0,20,0,0,0,1,64,64,0,224,247,3,0,0,0,0,0,254,0,2,0,144,212,8,0,20,0,0,0,1,128,0,0,96,135,7,0,20,0,0,0,1,128,128,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,21,0,0,0,1,1,0,0,96,135,7,0,21,0,0,0,1,1,1,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,21,0,0,0,1,2,2,0,56,111,3,0,21,0,0,0,1,2,0,0,104,134,3,0,0,0,0,0,254,0,4,0,64,37,5,0,21,0,0,0,1,12,0,0,120,176,7,0,21,0,0,0,1,12,8,0,136,136,2,0,21,0,0,0,1,12,4,0,24,219,2,0,21,0,0,0,1,12,12,0,120,7,5,0,0,0,0,0,254,0,4,0,168,79,2,0,21,0,0,0,1,48,0,0,208,152,2,0,21,0,0,0,1,48,20,0,8,167,2,0,21,0,0,0,1,48,48,0,72,4,1,0,21,0,0,0,1,48,16,0,224,195,4,0,0,0,0,0,254,0,4,0,72,202,5,0,21,0,0,0,1,192,128,0,80,246,3,0,21,0,0,0,1,192,0,0,248,38,7,0,21,0,0,0,1,192,64,0,112,212,3,0,21,0,0,0,1,192,192,0,248,160,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,100,109,48,56,46,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,214,2,214,152,0,0,16,1,100,109,49,48,46,49,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,99,102,192,231,0,0,16,1,100,109,48,57,46,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,47,135,76,220,0,0,16,1,100,109,48,51,46,57,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,118,223,90,65,0,0,16,1,100,109,48,49,46,49,50,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,221,188,111,68,0,0,32,0,100,109,48,50,46,49,51,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,57,240,45,241,0,0,32,0,100,109,48,48,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,223,150,243,53,0,0,32,0,100,109,48,52,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,109,184,66,36,0,0,32,0,100,109,48,54,46,53,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,166,67,55,227,0,0,32,0,100,109,48,53,46,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,29,160,187,127,0,0,32,0,100,109,48,55,46,53,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,159,162,231,133,0,0,32,0,110,111,98,111,95,112,114,46,49,54,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,194,10,1,149,0,0,32,0,110,111,98,111,95,112,114,46,49,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,12,172,90,197,0,0,32,0,100,109,45,49,50,46,105,99,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,238,76,57,222,0,0,32,0,100,99,45,49,49,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,184,80,131,100,0,0,0,8,100,109,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,203,157,222,111,0,0,16,8,101,112,114,45,49,51,48,48,48,46,97,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,236,33,14,46,1,0,16,1,101,112,114,45,49,50,57,57,57,46,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,40,61,33,253,1,0,16,1,101,112,114,45,49,51,48,49,49,46,98,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,252,113,184,28,2,0,32,0,101,112,114,45,49,51,48,49,50,46,98,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,33,104,94,183,2,0,32,0,101,112,114,45,49,51,48,49,51,46,98,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,60,74,148,241,2,0,32,0,101,112,114,45,49,51,48,48,51,46,98,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,81,65,66,33,3,0,32,0,101,112,114,45,49,51,48,48,54,46,98,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,47,253,154,46,3,0,32,0,101,112,114,45,49,51,48,48,52,46,98,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,211,157,160,10,3,0,32,0,101,112,114,45,49,51,48,48,55,46,98,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,91,96,200,85,3,0,32,0,101,112,114,45,49,51,48,48,53,46,98,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,16,200,153,200,3,0,32,0,101,112,114,45,49,51,48,48,56,46,98,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,252,109,212,179,3,0,32,0,101,112,114,45,49,51,48,48,57,46,98,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,55,46,109,18,3,0,32,0,101,112,114,45,49,51,48,49,48,46,98,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,103,197,55,223,3,0,32,0,101,112,114,45,49,51,48,48,50,46,97,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,21,21,110,27,4,0,16,1,101,112,114,45,49,51,48,48,49,46,97,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,140,206,202,232,8,0,64,0,51,49,55,45,48,49,52,51,46,107,101,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,218,232,162,251,5,0,16,1,21,0,0,0,255,255,253,0,0,0,0,0,22,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,192,32,3,0,21,0,0,0,1,1,1,0,184,30,3,0,21,0,0,0,1,1,0,0,0,28,3,0,0,0,0,0,254,0,2,0,168,234,7,0,21,0,0,0,1,2,2,0,96,135,7,0,21,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,88,21,3,0,21,0,0,0,1,4,4,0,232,19,3,0,21,0,0,0,1,4,12,0,128,18,3,0,0,0,0,0,254,0,8,0,112,16,3,0,21,0,0,0,1,56,24,0,80,246,3,0,21,0,0,0,1,56,40,0,56,15,3,0,21,0,0,0,1,56,8,0,72,14,3,0,21,0,0,0,1,56,56,0,248,38,7,0,21,0,0,0,1,56,48,0,112,212,3,0,21,0,0,0,1,56,16,0,80,233,4,0,21,0,0,0,1,56,32,0,152,228,4,0,21,0,0,0,1,56,0,0,248,160,5,0,0,0,0,0,254,0,4,0,72,202,5,0,21,0,0,0,1,192,128,0,80,246,3,0,21,0,0,0,1,192,64,0,56,15,3,0,21,0,0,0,1,192,192,0,248,38,7,0,21,0,0,0,1,192,48,0,112,212,3,0,0,0,0,0,254,0,16,0,200,87,7,0,22,0,0,0,1,15,7,0,80,252,6,0,22,0,0,0,1,15,8,0,16,242,7,0,22,0,0,0,1,15,9,0,104,236,7,0,22,0,0,0,1,15,5,0,176,51,4,0,22,0,0,0,1,15,4,0,56,24,4,0,22,0,0,0,1,15,15,0,128,230,7,0,22,0,0,0,1,15,1,0,72,216,3,0,22,0,0,0,1,15,2,0,24,188,3,0,22,0,0,0,1,15,3,0,176,162,3,0,22,0,0,0,1,15,6,0,120,211,6,0,22,0,0,0,1,15,14,0,184,164,6,0,22,0,0,0,1,15,13,0,80,74,6,0,22,0,0,0,1,15,12,0,192,32,6,0,22,0,0,0,1,15,11,0,192,234,2,0,22,0,0,0,1,15,10,0,32,242,5,0,22,0,0,0,1,15,0,0,72,24,3,0,0,0,0,0,254,0,16,0,160,123,6,0,22,0,0,0,1,240,112,0,80,252,6,0,22,0,0,0,1,240,128,0,16,242,7,0,22,0,0,0,1,240,144,0,104,236,7,0,22,0,0,0,1,240,80,0,176,51,4,0,22,0,0,0,1,240,64,0,56,24,4,0,22,0,0,0,1,240,240,0,128,230,7,0,22,0,0,0,1,240,16,0,72,216,3,0,22,0,0,0,1,240,32,0,24,188,3,0,22,0,0,0,1,240,48,0,176,162,3,0,22,0,0,0,1,240,96,0,120,211,6,0,22,0,0,0,1,240,224,0,184,164,6,0,22,0,0,0,1,240,208,0,80,74,6,0,22,0,0,0,1,240,192,0,192,32,6,0,22,0,0,0,1,240,176,0,192,234,2,0,22,0,0,0,1,240,160,0,32,242,5,0,22,0,0,0,1,240,0,0,208,236,2,0,0,0,0,0,109,115,104,101,46,48,51,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,20,20,149,189,1,0,16,1,109,115,104,101,46,48,52,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,242,66,221,25,1,0,16,1,109,115,104,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,158,27,9,106,1,0,16,1,109,115,104,46,48,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,164,63,62,128,1,0,16,1,109,115,104,46,48,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,39,142,95,196,1,0,16,1,109,115,104,46,48,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,44,241,166,156,1,0,16,1,109,115,104,46,48,57,97,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,175,39,236,130,1,0,16,1,109,115,104,46,49,48,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,150,17,147,141,1,0,16,1,109,115,104,46,49,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,102,69,209,9,5,0,32,0,109,115,104,46,49,53,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,87,32,150,238,5,0,32,0,109,115,104,46,49,55,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,20,206,78,96,5,0,32,0,109,115,104,46,49,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,232,49,167,148,5,0,32,0,109,115,104,46,49,52,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,62,151,151,65,5,0,32,0,109,115,104,46,49,54,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,160,164,141,67,5,0,32,0,109,115,104,46,49,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,148,45,185,77,5,0,32,0,109,115,104,46,50,48,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,192,198,176,162,5,0,32,0,109,115,104,46,48,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,249,230,118,201,10,0,16,1,109,115,104,46,48,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,217,208,103,206,10,0,16,1,109,115,104,46,49,49,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,48,109,172,55,12,0,64,0,109,115,104,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,112,37,9,222,12,0,64,0,56,48,56,116,50,48,46,104,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,29,203,10,111,0,0,16,1,56,48,56,116,50,49,46,106,49,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,22,4,163,66,0,0,16,1,56,48,56,101,48,51,46,102,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,205,167,147,61,0,0,16,1,56,48,56,101,49,50,46,102,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,222,31,47,214,0,0,32,0,56,48,56,101,49,51,46,104,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,244,8,167,31,0,0,32,0,56,48,56,101,50,50,46,105,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,246,88,215,115,0,0,32,0,56,48,56,101,50,51,46,107,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,33,139,240,143,0,0,32,0,56,48,56,100,49,55,46,106,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,130,144,41,209,0,0,32,0,56,48,56,100,49,53,46,104,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,182,166,34,43,0,0,32,0,56,48,56,97,49,56,46,102,49,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,222,174,149,235,0,0,32,0,56,48,56,100,48,49,46,100,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,192,55,77,253,0,0,64,0,20,0,0,0,255,255,255,0,0,0,0,0,21,0,0,0,255,255,86,0,0,0,0,0,22,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,20,0,0,0,1,15,2,0,80,252,6,0,20,0,0,0,1,15,5,0,16,242,7,0,20,0,0,0,1,15,8,0,104,236,7,0,20,0,0,0,1,15,4,0,120,113,6,0,20,0,0,0,1,15,1,0,232,228,5,0,20,0,0,0,1,15,15,0,128,230,7,0,20,0,0,0,1,15,3,0,56,141,7,0,20,0,0,0,1,15,7,0,120,211,6,0,20,0,0,0,1,15,14,0,184,164,6,0,20,0,0,0,1,15,6,0,24,1,7,0,20,0,0,0,1,15,13,0,80,74,6,0,20,0,0,0,1,15,12,0,192,32,6,0,20,0,0,0,1,15,11,0,192,234,2,0,20,0,0,0,1,15,10,0,32,242,5,0,20,0,0,0,1,15,9,0,176,192,2,0,20,0,0,0,1,15,0,0,16,227,4,0,0,0,0,0,254,0,15,0,160,123,6,0,20,0,0,0,1,240,32,0,80,252,6,0,20,0,0,0,1,240,80,0,16,242,7,0,20,0,0,0,1,240,128,0,104,236,7,0,20,0,0,0,1,240,64,0,120,113,6,0,20,0,0,0,1,240,16,0,232,228,5,0,20,0,0,0,1,240,240,0,128,230,7,0,20,0,0,0,1,240,48,0,56,141,7,0,20,0,0,0,1,240,112,0,120,211,6,0,20,0,0,0,1,240,224,0,184,164,6,0,20,0,0,0,1,240,96,0,24,1,7,0,20,0,0,0,1,240,208,0,80,74,6,0,20,0,0,0,1,240,192,0,192,32,6,0,20,0,0,0,1,240,176,0,192,234,2,0,20,0,0,0,1,240,160,0,32,242,5,0,20,0,0,0,1,240,144,0,176,192,2,0,0,0,0,0,254,0,4,0,128,129,4,0,21,0,0,0,1,3,3,0,208,75,4,0,21,0,0,0,1,3,2,0,8,49,4,0,21,0,0,0,1,3,1,0,72,246,3,0,21,0,0,0,1,3,0,0,64,47,7,0,0,0,0,0,254,0,4,0,64,37,5,0,21,0,0,0,1,24,24,0,136,81,3,0,21,0,0,0,1,24,16,0,224,110,5,0,21,0,0,0,1,24,8,0,208,26,6,0,21,0,0,0,1,24,0,0,0,64,7,0,0,0,0,0,254,0,4,0,72,202,5,0,21,0,0,0,1,96,96,0,80,246,3,0,21,0,0,0,1,96,64,0,248,38,7,0,21,0,0,0,1,96,32,0,48,123,8,0,21,0,0,0,1,96,0,0,8,117,8,0,0,0,0,0,254,0,2,0,168,234,7,0,21,0,0,0,1,128,128,0,96,135,7,0,21,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,22,0,0,0,1,1,1,0,96,135,7,0,22,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,48,2,1,0,22,0,0,0,1,2,2,0,96,135,7,0,22,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,184,89,6,0,22,0,0,0,1,4,4,0,96,135,7,0,22,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,0,0,0,0,0,0,0,0,107,100,101,95,51,48,97,46,49,49,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,226,239,181,252,1,0,16,1,107,100,101,95,51,55,97,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,102,82,46,242,1,0,16,1,107,100,101,95,51,49,97,46,49,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,34,215,16,199,1,0,16,1,107,100,101,95,51,56,97,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,58,237,214,87,1,0,16,1,107,100,95,50,56,46,57,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,217,188,103,147,1,0,16,1,107,100,95,51,53,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,138,164,166,76,1,0,16,1,107,100,95,50,57,46,49,48,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,114,250,96,3,1,0,16,1,107,100,95,51,54,97,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,248,206,163,149,1,0,16,1,107,100,45,53,109,46,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,1,135,91,228,4,0,32,0,107,100,45,55,109,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,34,3,117,167,4,0,32,0,107,100,45,49,109,46,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,120,191,116,95,4,0,32,0,107,100,45,51,109,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,191,3,83,94,4,0,32,0,107,100,45,54,109,46,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,243,88,51,17,4,0,32,0,107,100,45,56,109,46,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,68,60,133,56,4,0,32,0,107,100,45,50,109,46,51,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,4,102,243,158,4,0,32,0,107,100,45,52,109,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,79,155,43,64,4,0,32,0,107,100,95,57,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,38,236,198,186,3,0,16,0,107,100,95,49,56,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,29,24,99,76,5,0,64,0,107,100,95,49,57,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,128,27,148,146,5,0,64,0,98,117,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,231,45,18,235,0,0,0,8,105,111,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,59,238,199,89,0,0,0,8,112,114,103,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,68,151,18,241,0,0,0,8,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,185,115,220,65,0,0,0,8,115,111,117,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,254,178,244,132,0,0,0,8,107,100,50,57,98,46,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,0,0,0,0,0,0,24,105,111,98,49,46,49,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,7,188,58,0,0,0,8,105,111,99,49,46,105,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,129,32,24,13,0,0,0,8,99,54,51,50,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,112,146,189,15,0,0,0,8,27,0,0,0,255,255,0,0,0,0,0,0,28,0,0,0,255,255,3,0,0,0,0,0,29,0,0,0,255,255,96,0,0,0,0,0,0,0,0,0,254,0,8,0,32,4,2,0,27,0,0,0,1,7,7,0,80,252,6,0,27,0,0,0,1,7,6,0,16,242,7,0,27,0,0,0,1,7,5,0,104,236,7,0,27,0,0,0,1,7,0,0,128,230,7,0,27,0,0,0,1,7,1,0,184,164,6,0,27,0,0,0,1,7,2,0,80,74,6,0,27,0,0,0,1,7,3,0,192,32,6,0,27,0,0,0,1,7,4,0,32,242,5,0,0,0,0,0,254,0,2,0,88,160,1,0,27,0,0,0,1,8,8,0,192,255,2,0,27,0,0,0,1,8,0,0,8,49,4,0,0,0,0,0,254,0,2,0,112,242,7,0,27,0,0,0,1,16,16,0,240,242,5,0,27,0,0,0,1,16,0,0,8,140,6,0,0,0,0,0,254,0,2,0,64,232,1,0,27,0,0,0,1,64,0,0,96,135,7,0,27,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,8,0,72,202,5,0,28,0,0,0,1,7,0,0,72,198,6,0,28,0,0,0,1,7,1,0,208,75,4,0,28,0,0,0,1,7,2,0,8,49,4,0,28,0,0,0,1,7,3,0,72,195,6,0,28,0,0,0,1,7,4,0,72,246,3,0,28,0,0,0,1,7,5,0,72,0,3,0,28,0,0,0,1,7,6,0,64,47,7,0,28,0,0,0,1,7,7,0,48,173,6,0,0,0,0,0,254,0,8,0,128,129,4,0,28,0,0,0,1,56,8,0,192,255,2,0,28,0,0,0,1,56,0,0,208,75,4,0,28,0,0,0,1,56,16,0,8,49,4,0,28,0,0,0,1,56,24,0,152,21,4,0,28,0,0,0,1,56,32,0,72,246,3,0,28,0,0,0,1,56,40,0,72,0,3,0,28,0,0,0,1,56,48,0,64,47,7,0,28,0,0,0,1,56,56,0,232,99,5,0,0,0,0,0,254,0,4,0,64,37,5,0,28,0,0,0,1,192,64,0,192,83,1,0,28,0,0,0,1,192,128,0,32,83,1,0,28,0,0,0,1,192,0,0,160,81,1,0,28,0,0,0,1,192,192,0,120,7,5,0,0,0,0,0,254,0,2,0,16,227,4,0,29,0,0,0,1,4,0,0,96,135,7,0,29,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,254,0,2,0,72,4,1,0,29,0,0,0,1,8,0,0,96,135,7,0,29,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,29,0,0,0,1,16,0,0,96,135,7,0,29,0,0,0,1,16,16,0,152,182,7,0,0,0,0,0,254,0,2,0,40,111,8,0,29,0,0,0,1,32,0,0,96,135,7,0,29,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,29,0,0,0,1,64,0,0,96,135,7,0,29,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,168,79,2,0,29,0,0,0,1,128,0,0,32,182,8,0,29,0,0,0,1,128,128,0,80,251,6,0,0,0,0,0,0,0,0,0,102,120,97,49,46,116,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,170,50,19,167,0,0,16,1,102,120,97,50,46,116,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,129,147,41,235,0,0,16,1,102,120,46,48,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,134,66,80,74,0,0,32,0,49,55,46,57,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,88,20,33,65,0,0,32,0,49,56,46,49,48,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,212,204,14,116,0,0,32,0,49,54,46,49,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,219,165,244,193,0,0,32,0,102,120,97,53,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,220,137,34,62,0,0,32,0,102,120,97,52,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,127,61,150,38,0,0,32,0,102,120,97,51,46,49,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,160,241,135,134,0,0,32,0,109,114,46,49,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,110,67,10,17,0,0,32,0,109,103,46,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,240,217,191,15,0,0,32,0,109,98,46,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,12,137,66,163,0,0,32,0,109,50,46,53,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,173,85,10,25,0,0,32,0,109,49,46,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,1,146,163,131,0,0,32,0,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,3,0,0,0,0,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,2,2,0,96,135,7,0,19,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,4,4,0,96,135,7,0,19,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,8,0,0,96,135,7,0,19,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,19,0,0,0,1,48,16,0,96,39,7,0,19,0,0,0,1,48,48,0,144,251,6,0,19,0,0,0,1,48,0,0,120,211,6,0,19,0,0,0,1,48,32,0,184,164,6,0,0,0,0,0,254,0,4,0,160,123,6,0,19,0,0,0,1,192,64,0,96,39,7,0,19,0,0,0,1,192,192,0,144,251,6,0,19,0,0,0,1,192,0,0,120,211,6,0,19,0,0,0,1,192,128,0,184,164,6,0,0,0,0,0,254,0,4,0,72,202,5,0,20,0,0,0,1,3,2,0,80,246,3,0,20,0,0,0,1,3,3,0,80,124,6,0,20,0,0,0,1,3,1,0,112,212,3,0,20,0,0,0,1,3,0,0,248,160,5,0,98,99,114,111,109,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,186,144,212,6,0,0,16,1,98,99,114,111,109,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,100,166,172,51,0,0,16,1,98,99,95,114,111,109,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,155,167,92,229,0,0,32,0,98,99,95,114,111,109,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,150,140,243,205,0,0,32,0,98,99,95,114,111,109,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,61,171,55,3,0,0,32,0,98,99,95,114,111,109,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,126,145,88,84,0,0,32,0,98,99,95,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,161,139,111,172,0,0,64,0,98,99,95,114,111,109,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,191,49,188,164,0,0,64,0,51,49,97,49,51,45,50,46,105,99,49,57,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,167,188,117,113,0,0,16,1,51,49,97,49,52,45,50,46,105,99,49,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,209,191,6,93,0,0,16,1,51,49,97,49,49,45,50,46,105,99,52,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,234,191,222,93,0,0,16,1,51,49,97,49,50,45,48,46,105,99,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,32,62,128,208,0,0,32,0,51,49,106,48,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,80,180,18,138,0,0,32,0,51,49,106,49,46,105,99,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,85,113,237,130,0,0,32,0,51,49,106,51,46,105,99,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,29,207,149,227,0,0,32,0,51,49,106,50,46,105,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,101,116,169,181,0,0,32,0,51,49,106,53,46,105,99,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,232,69,229,44,0,0,32,0,51,49,106,52,46,105,99,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,106,182,237,0,0,0,32,0,51,49,106,54,46,105,99,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,248,108,149,121,0,0,32,0,51,49,106,55,46,105,99,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,195,116,215,116,0,0,32,0,51,49,106,57,46,105,99,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,137,114,56,221,0,0,32,0,51,49,106,56,46,105,99,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,39,225,171,68,0,0,32,0,51,49,106,49,48,46,105,99,55,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,219,46,82,108,0,0,64,0,51,48,97,49,52,45,48,46,105,99,55,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,22,224,47,244,0,0,16,1,51,48,97,49,53,45,48,46,105,99,55,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,44,233,80,173,0,0,16,1,51,48,97,49,51,45,48,46,105,99,52,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,155,77,151,30,0,0,16,1,51,48,106,45,55,46,105,99,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,50,141,213,137,0,0,32,0,51,48,106,45,54,46,105,99,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,142,83,241,155,0,0,32,0,51,48,106,45,53,46,105,99,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,98,26,103,143,0,0,32,0,51,48,106,45,52,46,105,99,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,28,234,116,15,0,0,32,0,51,48,106,45,51,46,105,99,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,113,24,21,179,0,0,32,0,51,48,97,49,50,45,48,46,105,99,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,234,75,214,32,0,0,32,0,51,48,106,45,50,46,105,99,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,8,251,198,65,0,0,32,0,51,48,97,49,49,45,48,46,105,99,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,176,113,93,120,0,0,32,0,51,48,106,45,49,46,105,99,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,20,241,166,103,0,0,32,0,51,48,97,49,48,45,48,46,105,99,49,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,18,61,228,21,0,0,32,0,51,48,106,45,48,46,105,99,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,190,175,93,241,0,0,32,0,51,48,97,57,45,48,46,105,99,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,164,231,71,90,0,0,32,0,51,48,106,45,56,46,105,99,55,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,243,64,173,195,0,0,64,0,109,98,55,49,49,52,104,46,105,99,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,67,116,60,17,0,0,32,0,98,107,49,95,49,46,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,112,39,147,96,0,0,16,1,98,107,49,95,51,46,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,14,36,54,203,0,0,16,1,98,107,49,95,50,46,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,242,82,147,83,0,0,16,1,98,107,49,95,52,46,54,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,134,117,56,25,0,0,16,1,98,107,50,95,49,49,46,49,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,17,59,76,96,0,0,16,1,98,107,50,95,49,50,46,49,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,141,137,252,175,0,0,16,1,98,107,50,95,49,51,46,49,56,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,171,192,45,48,0,0,16,1,98,107,50,95,49,52,46,49,54,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,4,56,26,89,0,0,32,0,98,107,49,95,53,46,49,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,127,89,74,152,0,0,32,0,98,107,49,95,54,46,49,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,255,151,226,48,0,0,32,0,98,107,50,95,55,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,11,116,247,188,0,0,32,0,98,107,50,95,56,46,55,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,92,86,11,167,0,0,32,0,98,107,50,95,57,46,54,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,230,195,158,74,0,0,32,0,98,107,50,95,49,48,46,55,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,252,73,7,69,0,0,32,0,98,107,49,95,51,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,68,197,7,206,0,0,32,0,98,107,49,95,50,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,58,50,109,86,0,0,32,0,98,107,49,95,49,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,70,57,166,126,0,0,32,0,98,107,50,95,52,46,50,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,173,155,96,8,0,0,32,0,98,107,50,95,53,46,52,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,31,153,67,44,0,0,32,0,115,114,98,45,48,51,46,109,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,195,252,218,217,0,0,16,1,115,114,98,45,48,52,46,109,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,36,249,12,218,0,0,16,1,115,114,98,45,48,53,46,109,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,28,145,2,209,0,0,16,1,115,114,98,45,48,54,46,109,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,72,130,111,70,0,0,16,1,115,114,98,45,48,55,46,109,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,140,3,49,13,0,0,16,1,115,114,45,48,49,46,99,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,107,240,135,189,0,0,16,1,115,114,45,48,50,46,102,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,145,161,188,110,0,0,32,0,115,114,45,48,56,46,97,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,235,217,132,56,0,0,32,0,115,114,45,48,57,46,97,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,224,246,156,153,0,0,32,0,115,114,45,49,48,46,97,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,58,39,219,142,0,0,32,0,115,114,45,49,49,46,97,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,195,38,39,58,0,0,32,0,115,114,45,49,50,46,97,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,187,216,211,27,0,0,32,0,115,114,45,49,51,46,97,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,196,2,143,101,0,0,32,0,115,114,45,49,52,46,108,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,198,190,40,37,0,0,32,0,115,114,45,49,53,46,108,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,170,135,146,248,0,0,32,0,115,114,45,49,54,46,110,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,248,24,68,2,0,0,32,0,115,114,45,49,55,46,110,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,137,228,199,226,0,0,32,0,115,98,45,53,46,101,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,83,129,171,147,0,0,32,0,115,98,45,54,46,101,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,125,79,180,138,0,0,32,0,115,98,45,55,46,101,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,164,233,173,244,0,0,32,0,115,98,45,48,46,102,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,27,217,71,96,0,0,32,0,115,98,45,52,46,100,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,141,150,88,72,0,0,32,0,115,98,45,56,46,107,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,67,217,250,246,0,0,32,0,115,98,45,50,46,100,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,223,179,184,139,0,0,32,0,115,98,45,51,46,100,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,175,153,12,59,0,0,32,0,115,98,45,49,46,107,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,8,197,42,113,0,0,32,0,115,98,45,57,46,109,49,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,92,99,33,73,0,0,32,0,99,109,48,52,46,57,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,148,182,56,132,0,0,16,1,99,109,48,51,46,56,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,66,101,72,53,0,0,16,1,99,109,48,50,46,57,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,116,74,204,249,0,0,16,1,118,116,48,49,46,53,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,224,38,87,80,0,0,32,0,118,116,49,49,46,53,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,72,27,46,123,0,0,32,0,118,116,49,50,46,54,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,211,23,180,129,0,0,32,0,118,116,49,51,46,55,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,210,219,18,86,0,0,32,0,118,116,49,52,46,56,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,54,238,45,43,0,0,32,0,118,116,49,53,46,57,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,191,186,112,222,0,0,32,0,118,116,49,54,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,55,130,23,20,0,0,32,0,118,116,48,53,46,55,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,61,110,241,121,0,0,32,0,118,116,48,54,46,56,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,33,229,254,38,0,0,32,0,118,116,48,55,46,57,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,253,189,136,202,0,0,32,0,118,116,48,56,46,55,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,131,200,25,32,0,0,32,0,118,116,48,57,46,56,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,130,57,112,152,0,0,32,0,118,116,49,48,46,57,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,248,210,105,240,0,0,32,0,118,116,98,49,46,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,161,21,186,58,0,0,32,0,118,116,98,50,46,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,84,87,134,136,0,0,32,0,118,116,98,51,46,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,246,195,20,76,0,0,32,0,118,116,98,52,46,49,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,70,194,136,179,0,0,32,0,118,116,98,53,46,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,8,197,42,113,0,0,32,0,118,116,98,54,46,54,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,88,81,175,14,0,0,32,0,98,109,101,48,49,46,49,50,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,126,68,253,85,0,0,16,1,98,109,101,48,50,46,49,51,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,124,197,63,7,0,0,16,1,98,109,101,48,51,46,49,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,194,34,88,131,0,0,16,1,98,109,48,52,46,53,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,215,210,43,238,0,0,16,1,98,109,48,53,46,52,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,61,157,203,70,0,0,32,0,98,109,49,53,46,49,48,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,67,4,26,107,0,0,32,0,98,109,49,54,46,49,49,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,194,8,201,35,0,0,32,0,98,109,49,55,46,49,50,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,7,221,188,70,0,0,32,0,98,109,49,56,46,49,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,160,123,174,230,0,0,32,0,98,109,49,57,46,49,48,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,188,186,138,134,0,0,32,0,98,109,50,48,46,49,49,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,212,229,23,9,0,0,32,0,98,109,50,49,46,49,50,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,137,13,251,155,0,0,32,0,98,109,50,50,46,49,52,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,116,194,243,4,0,0,32,0,98,109,50,52,46,49,52,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,54,64,19,17,0,0,32,0,98,109,50,53,46,49,52,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,193,249,44,9,0,0,32,0,98,109,48,54,46,49,48,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,175,200,172,151,0,0,32,0,98,109,48,55,46,49,49,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,151,113,143,215,0,0,32,0,98,109,48,56,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,8,102,98,26,0,0,32,0,98,109,48,57,46,49,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,132,64,146,0,0,32,0,98,109,49,48,46,49,48,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,74,164,56,132,0,0,32,0,98,109,49,49,46,49,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,29,53,105,108,0,0,32,0,98,109,49,50,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,183,253,126,94,0,0,32,0,98,109,49,51,46,49,52,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,154,130,67,17,0,0,32,0,98,109,49,52,46,53,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,1,100,60,77,0,0,32,0,98,109,50,51,46,56,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,189,236,42,165,0,0,32,0,98,109,49,46,49,50,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,24,31,66,116,0,0,32,0,98,109,50,46,49,51,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,31,84,39,172,0,0,32,0,98,109,51,46,49,52,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,255,182,31,37,0,0,32,0,98,109,53,46,55,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,208,19,103,32,0,0,32,0,98,109,49,48,46,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,28,73,194,51,0,0,32,0,98,109,57,46,54,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,247,74,234,174,0,0,32,0,98,109,49,50,46,49,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,54,161,138,193,0,0,32,0,98,109,49,49,46,49,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,55,174,90,64,0,0,32,0,98,109,56,46,56,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,158,10,1,194,0,0,32,0,98,109,55,46,55,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,195,48,111,181,0,0,32,0,98,109,52,46,49,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,225,162,168,145,0,0,32,0,98,109,54,46,52,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,88,81,175,14,0,0,32,0,98,109,46,55,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,16,110,98,45,53,46,105,99,53,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,223,61,104,186,0,0,16,1,110,97,45,53,46,105,99,53,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,244,125,126,222,0,0,16,1,110,48,45,53,46,105,99,49,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,59,222,135,53,0,0,16,1,110,99,45,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,93,170,223,154,0,0,32,0,110,49,45,53,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,243,71,159,74,0,0,32,0,110,54,45,53,46,105,99,50,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,168,10,42,214,0,0,32,0,110,55,45,53,46,105,99,50,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,50,165,165,124,0,0,32,0,110,50,45,53,46,105,99,49,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,130,121,46,141,0,0,32,0,110,56,45,53,46,105,99,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,211,49,186,13,0,0,32,0,110,57,45,53,46,105,99,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,106,27,98,91,0,0,32,0,110,104,45,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,124,133,215,220,0,0,32,0,110,100,45,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,124,113,225,45,0,0,32,0,110,106,45,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,142,161,150,15,0,0,32,0,110,110,45,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,135,87,241,27,0,0,32,0,110,101,45,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,136,115,76,146,0,0,32,0,110,107,45,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,148,154,73,105,0,0,32,0,110,105,45,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,210,126,89,111,0,0,32,0,110,102,45,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,69,141,252,14,0,0,32,0,110,108,45,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,54,131,119,20,0,0,32,0,110,111,45,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,59,210,125,20,0,0,32,0,110,103,45,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,32,55,238,168,0,0,32,0,110,109,45,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,142,37,0,193,0,0,32,0,110,53,45,53,46,105,99,51,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,60,58,228,126,0,0,32,0,110,52,45,53,46,105,99,51,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,76,86,87,101,0,0,32,0,110,51,45,53,46,105,99,51,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,144,97,253,120,0,0,32,0,110,122,45,53,46,105,99,57,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,96,117,228,50,0,0,16,1,109,103,95,48,52,46,56,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,125,37,18,177,0,0,16,1,109,103,95,48,51,46,55,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,101,36,103,178,0,0,16,1,109,103,95,48,50,46,54,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,22,190,94,159,0,0,16,1,109,103,95,48,49,46,53,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,240,42,234,28,0,0,16,1,109,103,95,48,53,46,49,52,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,69,201,191,47,0,0,16,1,109,103,95,48,54,46,49,48,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,155,229,46,56,0,0,32,0,108,115,45,49,50,46,55,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,108,44,27,108,0,0,32,0,108,115,45,49,49,46,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,100,28,248,107,0,0,32,0,109,103,95,109,49,49,46,114,111,109,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,100,154,49,238,0,0,32,0,109,103,95,109,48,55,46,114,111,109,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,17,178,192,229,0,0,32,0,109,103,95,109,49,50,46,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,32,241,126,136,0,0,32,0,109,103,95,109,48,56,46,114,111,109,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,163,154,112,89,0,0,32,0,109,103,95,109,49,51,46,114,111,109,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,180,125,224,234,0,0,32,0,109,103,95,109,48,57,46,114,111,109,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,235,131,238,64,0,0,32,0,109,103,95,109,49,52,46,114,111,109,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,76,66,229,33,0,0,32,0,109,103,95,109,49,48,46,114,111,109,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,84,251,74,182,0,0,32,0,108,115,45,48,54,46,49,48,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,91,154,211,136,0,0,64,0,108,115,45,48,53,46,49,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,181,3,110,176,0,0,64,0,50,57,46,49,52,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,30,46,134,127,0,0,32,0,103,103,52,46,98,105,110,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,235,107,96,102,0,0,16,1,103,103,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,94,198,1,158,0,0,16,1,103,103,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,43,123,57,214,0,0,16,1,103,103,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,111,91,95,97,0,0,16,1,103,103,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,7,207,252,236,0,0,32,0,103,103,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,169,111,213,221,0,0,32,0,103,103,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,157,82,2,115,0,0,32,0,103,103,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,218,91,3,32,0,0,32,0,103,103,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,113,162,43,241,0,0,32,0,103,103,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,125,32,37,229,0,0,32,0,103,103,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,178,233,119,45,0,0,32,0,103,103,49,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,143,10,229,147,0,0,32,0,103,103,49,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,202,229,215,6,0,0,32,0,103,103,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,45,224,31,188,0,0,32,0,103,103,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,249,18,175,106,0,0,32,0,103,103,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,202,63,12,232,0,0,32,0,103,103,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,37,169,128,119,0,0,32,0,116,98,112,50,52,115,49,48,46,49,52,107,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,88,81,175,14,0,0,32,0,54,51,115,49,52,49,46,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,164,133,18,74,0,0,32,0,103,103,45,112,97,108,49,48,108,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,44,0,0,0,224,183,241,135,0,0,32,0,103,103,49,95,49,98,46,51,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,159,108,3,171,0,0,16,1,103,103,49,95,50,98,46,51,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,64,34,35,217,0,0,16,1,103,103,49,95,51,46,50,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,3,229,60,117,0,0,16,1,103,103,49,95,52,98,46,50,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,118,204,159,73,0,0,16,1,103,103,49,95,53,98,46,51,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,227,170,92,187,0,0,16,1,103,103,49,95,55,98,46,50,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,107,104,22,208,0,0,16,1,103,103,49,95,57,46,52,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,124,244,178,88,0,0,32,0,103,103,49,95,49,49,46,52,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,128,124,68,173,0,0,32,0,103,103,49,95,49,48,46,52,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,252,26,111,221,0,0,32,0,112,114,111,109,45,53,46,53,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,107,60,96,84,0,0,32,0,112,114,111,109,45,52,46,50,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,171,237,182,89,0,0,32,0,112,114,111,109,45,51,46,49,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,107,187,4,74,0,0,32,0,112,114,111,109,45,49,46,49,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,180,21,40,122,0,0,32,0,112,114,111,109,45,50,46,53,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,102,91,36,119,0,0,32,0,50,49,106,45,49,45,53,46,50,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,253,93,4,66,0,0,16,1,50,49,106,45,50,45,51,46,50,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,94,112,121,87,0,0,16,1,50,49,106,45,51,46,50,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,19,166,222,59,0,0,16,1,50,49,106,45,52,45,49,46,50,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,185,135,143,114,0,0,16,1,50,49,106,109,45,48,46,105,99,53,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,3,45,35,245,0,0,16,1,50,49,106,45,48,45,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,187,149,250,158,0,0,16,1,50,49,106,45,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,180,141,139,122,0,0,32,0,50,49,106,45,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,227,172,79,87,0,0,32,0,50,49,106,45,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,118,122,80,64,0,0,32,0,50,49,106,45,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,111,199,11,187,0,0,32,0,50,49,106,45,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,27,35,79,203,0,0,32,0,50,49,106,45,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,97,194,160,160,0,0,32,0,50,49,106,45,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,246,82,161,107,0,0,32,0,50,49,106,45,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,182,160,32,50,0,0,32,0,50,49,106,45,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,125,81,199,101,0,0,32,0,50,49,106,45,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,135,88,67,124,0,0,32,0,50,49,106,45,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,237,10,100,198,0,0,32,0,50,49,106,45,105,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,160,176,255,94,0,0,32,0,50,49,106,45,106,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,124,46,180,95,0,0,32,0,50,49,106,45,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,227,93,117,52,0,0,32,0,50,49,106,45,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,248,230,77,144,0,0,32,0,50,49,106,45,107,45,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,169,48,177,253,0,0,32,0,50,49,106,45,108,45,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,41,149,51,70,0,0,32,0,103,48,55,95,99,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,129,160,204,157,0,0,16,1,106,48,55,95,99,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,5,145,21,224,0,0,16,1,103,48,53,95,99,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,45,43,88,16,0,0,16,1,102,48,53,95,99,48,56,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,32,157,87,1,0,0,32,0,104,48,53,95,99,48,57,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,240,114,88,79,0,0,32,0,110,48,55,95,99,49,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,178,142,175,16,0,0,32,0,107,48,55,95,99,49,48,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,4,243,118,149,0,0,32,0,111,48,55,95,99,49,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,220,212,217,177,0,0,32,0,108,48,55,95,99,49,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,74,190,152,69,0,0,32,0,116,48,55,95,99,49,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,66,94,66,245,0,0,32,0,112,48,55,95,99,49,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,124,161,80,203,0,0,32,0,118,48,55,95,99,49,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,199,163,155,149,0,0,32,0,115,48,55,95,99,49,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,197,145,46,127,0,0,32,0,100,48,49,95,99,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,92,238,177,129,0,0,32,0,101,48,49,95,99,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,115,54,211,208,0,0,32,0,102,48,49,95,99,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,149,22,232,170,0,0,32,0,100,48,52,95,99,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,29,16,133,155,0,0,64,0,118,103,95,98,45,56,114,46,105,99,57,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,122,138,54,223,0,0,32,0,118,103,95,98,45,52,109,46,105,99,51,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,4,66,202,219,0,0,32,0,118,103,95,98,45,49,98,46,105,99,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,103,81,46,146,0,0,32,0,100,104,48,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,110,49,27,37,0,0,16,1,100,104,48,52,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,46,230,118,208,0,0,16,1,105,56,55,53,49,46,109,99,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,24,115,112,95,48,55,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,105,121,111,157,0,0,32,0,115,112,95,48,54,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,67,78,14,88,0,0,32,0,115,112,95,48,53,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,210,113,171,5,0,0,32,0,100,104,48,49,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,234,251,205,162,0,0,32,0,100,104,48,50,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,231,195,181,238,0,0,32,0,100,104,48,51,46,98,105,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,29,210,24,142,0,0,32,0,100,104,45,48,57,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,79,155,4,206,0,0,32,0,100,104,45,48,56,46,98,112,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,15,24,242,205,0,0,32,0,17,0,0,0,255,255,223,0,0,0,0,0,18,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,72,202,5,0,17,0,0,0,1,3,2,0,80,246,3,0,17,0,0,0,1,3,3,0,248,38,7,0,17,0,0,0,1,3,1,0,112,212,3,0,17,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,2,0,120,189,3,0,17,0,0,0,1,4,0,0,192,255,2,0,17,0,0,0,1,4,4,0,208,75,4,0,0,0,0,0,254,0,1,0,0,150,8,0,17,0,0,0,1,24,24,0,120,26,6,0,0,0,0,0,254,0,2,0,168,234,7,0,17,0,0,0,1,32,32,0,96,135,7,0,17,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,17,0,0,0,1,128,128,0,96,135,7,0,17,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,8,0,200,87,7,0,18,0,0,0,1,7,7,0,128,230,7,0,18,0,0,0,1,7,0,0,56,141,7,0,18,0,0,0,1,7,1,0,120,211,6,0,18,0,0,0,1,7,6,0,184,164,6,0,18,0,0,0,1,7,5,0,80,74,6,0,18,0,0,0,1,7,4,0,192,32,6,0,18,0,0,0,1,7,3,0,192,234,2,0,18,0,0,0,1,7,2,0,32,242,5,0,0,0,0,0,254,0,8,0,160,123,6,0,18,0,0,0,1,56,16,0,176,73,5,0,18,0,0,0,1,56,24,0,104,54,4,0,18,0,0,0,1,56,32,0,80,252,6,0,18,0,0,0,1,56,40,0,16,242,7,0,18,0,0,0,1,56,48,0])
.concat([104,236,7,0,18,0,0,0,1,56,8,0,120,113,6,0,18,0,0,0,1,56,0,0,232,228,5,0,18,0,0,0,1,56,56,0,128,230,7,0,0,0,0,0,254,0,2,0,0,78,3,0,18,0,0,0,1,64,64,0,192,255,2,0,18,0,0,0,1,64,0,0,208,75,4,0,0,0,0,0,254,0,2,0,16,227,4,0,18,0,0,0,1,128,128,0,96,135,7,0,18,0,0,0,1,128,0,0,152,182,7,0,27,0,0,0,255,255,167,0,0,0,0,0,28,0,0,0,255,255,252,0,0,0,0,0,0,0,0,0,254,0,7,0,32,4,2,0,27,0,0,0,1,7,0,0,184,220,8,0,27,0,0,0,1,7,1,0,88,154,8,0,27,0,0,0,1,7,2,0,200,92,8,0,27,0,0,0,1,7,7,0,56,37,8,0,27,0,0,0,1,7,6,0,96,240,7,0,27,0,0,0,1,7,5,0,128,188,7,0,27,0,0,0,1,7,4,0,184,46,7,0,0,0,0,0,254,0,2,0,80,111,3,0,27,0,0,0,1,8,8,0,96,135,7,0,27,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,2,0,40,73,5,0,27,0,0,0,1,16,16,0,96,135,7,0,27,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,2,0,128,251,5,0,27,0,0,0,1,32,32,0,96,135,7,0,27,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,16,227,4,0,27,0,0,0,1,64,64,0,96,135,7,0,27,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,192,167,5,0,27,0,0,0,1,128,128,0,96,135,7,0,27,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,8,0,72,202,5,0,28,0,0,0,1,7,7,0,160,246,1,0,28,0,0,0,1,7,6,0,120,103,7,0,28,0,0,0,1,7,5,0,80,246,3,0,28,0,0,0,1,7,4,0,248,38,7,0,28,0,0,0,1,7,3,0,80,124,6,0,28,0,0,0,1,7,2,0,112,212,3,0,28,0,0,0,1,7,1,0,48,90,7,0,28,0,0,0,1,7,0,0,248,160,5,0,0,0,0,0,254,0,2,0,128,112,3,0,28,0,0,0,1,8,8,0,168,22,4,0,28,0,0,0,1,8,0,0,72,93,8,0,0,0,0,0,254,0,2,0,48,142,4,0,28,0,0,0,1,16,16,0,248,38,7,0,28,0,0,0,1,16,0,0,56,252,3,0,0,0,0,0,254,0,2,0,200,218,3,0,28,0,0,0,1,32,32,0,96,135,7,0,28,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,160,189,3,0,28,0,0,0,1,64,64,0,88,164,3,0,28,0,0,0,1,64,0,0,120,76,7,0,0,0,0,0,254,0,2,0,232,75,4,0,28,0,0,0,1,128,128,0,96,135,7,0,28,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,20,0,0,0,255,255,223,0,0,0,0,0,21,0,0,0,255,255,247,0,0,0,0,0,20,0,0,0,254,0,8,0,32,4,2,0,20,0,0,0,1,7,0,0,56,111,8,0,20,0,0,0,1,7,1,0,88,241,7,0,20,0,0,0,1,7,2,0,240,12,2,0,20,0,0,0,1,7,3,0,160,36,8,0,20,0,0,0,1,7,7,0,208,239,7,0,20,0,0,0,1,7,6,0,120,187,7,0,20,0,0,0,1,7,5,0,136,23,1,0,20,0,0,0,1,7,4,0,88,217,6,0,20,0,0,0,254,0,2,0,72,202,5,0,20,0,0,0,1,8,8,0,136,173,6,0,20,0,0,0,1,8,0,0,0,131,6,0,20,0,0,0,254,0,2,0,216,82,6,0,20,0,0,0,1,16,16,0,248,38,7,0,20,0,0,0,1,16,0,0,176,64,8,0,20,0,0,0,254,0,2,0,168,234,7,0,20,0,0,0,1,32,0,0,96,135,7,0,20,0,0,0,1,32,32,0,152,182,7,0,21,0,0,0,254,0,2,0,208,128,1,0,21,0,0,0,1,4,4,0,192,255,2,0,21,0,0,0,1,4,0,0,208,75,4,0,21,0,0,0,254,0,2,0,56,12,5,0,21,0,0,0,1,8,0,0,152,53,6,0,21,0,0,0,1,8,8,0,120,7,5,0,21,0,0,0,254,0,2,0,24,165,4,0,21,0,0,0,1,16,16,0,56,111,3,0,21,0,0,0,1,16,0,0,104,134,3,0,0,0,0,0,31,0,0,0,255,255,239,0,0,0,0,0,32,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,32,4,2,0,31,0,0,0,1,3,0,0,16,242,7,0,31,0,0,0,1,3,1,0,104,236,7,0,31,0,0,0,1,3,3,0,128,230,7,0,31,0,0,0,1,3,2,0,184,164,6,0,0,0,0,0,254,0,2,0,16,234,4,0,31,0,0,0,1,4,4,0,0,212,5,0,31,0,0,0,1,4,0,0,128,165,4,0,0,0,0,0,254,0,2,0,176,134,4,0,31,0,0,0,1,8,8,0,0,212,5,0,31,0,0,0,1,8,0,0,128,165,4,0,0,0,0,0,254,0,2,0,48,112,3,0,31,0,0,0,1,16,16,0,0,212,5,0,31,0,0,0,1,16,0,0,128,165,4,0,0,0,0,0,254,0,2,0,168,234,7,0,31,0,0,0,1,32,0,0,96,135,7,0,31,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,31,0,0,0,1,64,64,0,96,135,7,0,31,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,219,3,0,31,0,0,0,1,128,0,0,96,135,7,0,31,0,0,0,1,128,128,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,32,0,0,0,1,3,2,0,80,246,3,0,32,0,0,0,1,3,3,0,248,38,7,0,32,0,0,0,1,3,1,0,112,212,3,0,32,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,3,0,232,119,7,0,32,0,0,0,1,12,4,0,208,75,4,0,32,0,0,0,1,12,8,0,8,49,4,0,32,0,0,0,1,12,12,0,152,21,4,0,0,0,0,0,254,0,4,0,160,4,3,0,32,0,0,0,1,96,0,0,24,205,7,0,32,0,0,0,1,96,32,0,176,2,8,0,32,0,0,0,1,96,96,0,152,195,2,0,32,0,0,0,1,96,64,0,104,178,2,0,0,0,0,0,254,0,2,0,24,164,2,0,32,0,0,0,1,128,0,0,112,150,2,0,32,0,0,0,1,128,128,0,208,138,2,0,17,0,0,0,255,255,255,0,0,0,0,0,18,0,0,0,255,255,175,0,0,0,0,0,0,0,0,0,254,0,11,0,200,87,7,0,17,0,0,0,1,15,10,0,104,236,7,0,17,0,0,0,1,15,7,0,120,113,6,0,17,0,0,0,1,15,0,0,120,228,8,0,17,0,0,0,1,15,15,0,80,245,6,0,17,0,0,0,1,15,6,0,56,141,7,0,17,0,0,0,1,15,9,0,120,211,6,0,17,0,0,0,1,15,14,0,8,201,6,0,17,0,0,0,1,15,8,0,24,1,7,0,17,0,0,0,1,15,13,0,200,197,6,0,17,0,0,0,1,15,12,0,152,194,6,0,17,0,0,0,1,15,11,0,128,95,7,0,0,0,0,0,254,0,11,0,160,123,6,0,17,0,0,0,1,240,160,0,104,236,7,0,17,0,0,0,1,240,112,0,120,113,6,0,17,0,0,0,1,240,0,0,120,228,8,0,17,0,0,0,1,240,240,0,80,245,6,0,17,0,0,0,1,240,96,0,56,141,7,0,17,0,0,0,1,240,144,0,120,211,6,0,17,0,0,0,1,240,224,0,8,201,6,0,17,0,0,0,1,240,128,0,24,1,7,0,17,0,0,0,1,240,208,0,200,197,6,0,17,0,0,0,1,240,192,0,152,194,6,0,17,0,0,0,1,240,176,0,128,95,7,0,0,0,0,0,254,0,2,0,112,59,6,0,18,0,0,0,1,1,0,0,40,71,8,0,18,0,0,0,1,1,1,0,144,68,8,0,0,0,0,0,254,0,2,0,200,86,6,0,18,0,0,0,1,2,2,0,40,71,8,0,18,0,0,0,1,2,0,0,144,68,8,0,0,0,0,0,254,0,2,0,184,89,6,0,18,0,0,0,1,8,8,0,96,135,7,0,18,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,18,0,0,0,1,16,16,0,96,135,7,0,18,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,2,0,128,112,3,0,18,0,0,0,1,32,32,0,168,22,4,0,18,0,0,0,1,32,0,0,176,176,7,0,0,0,0,0,254,0,2,0,104,159,3,0,18,0,0,0,1,64,64,0,56,111,3,0,18,0,0,0,1,64,0,0,104,134,3,0,28,0,0,0,255,255,255,0,0,0,0,0,29,0,0,0,255,255,255,0,0,0,0,0,30,0,0,0,255,255,255,0,0,0,0,0,31,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,32,4,2,0,28,0,0,0,1,3,0,0,16,242,7,0,28,0,0,0,1,3,1,0,104,236,7,0,28,0,0,0,1,3,3,0,128,230,7,0,28,0,0,0,1,3,2,0,184,164,6,0,0,0,0,0,254,0,2,0,0,76,5,0,28,0,0,0,1,16,16,0,96,135,7,0,28,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,28,0,0,0,1,32,0,0,96,135,7,0,28,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,28,0,0,0,1,64,64,0,96,135,7,0,28,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,29,0,0,0,1,3,2,0,80,246,3,0,29,0,0,0,1,3,3,0,248,38,7,0,29,0,0,0,1,3,1,0,112,212,3,0,29,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,2,0,136,79,3,0,29,0,0,0,1,4,4,0,96,135,7,0,29,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,184,89,6,0,29,0,0,0,1,16,16,0,96,135,7,0,29,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,2,0,24,254,3,0,29,0,0,0,1,32,0,0,96,135,7,0,29,0,0,0,1,32,32,0,136,66,4,0,0,0,0,0,254,0,2,0,80,109,5,0,29,0,0,0,1,64,0,0,56,132,5,0,29,0,0,0,1,64,64,0,152,29,3,0,0,0,0,0,254,0,2,0,232,119,7,0,29,0,0,0,1,128,128,0,208,75,4,0,29,0,0,0,1,128,0,0,8,49,4,0,21,0,0,0,255,255,28,0,0,0,0,0,22,0,0,0,255,255,247,0,0,0,0,0,0,0,0,0,254,0,2,0,128,129,4,0,21,0,0,0,1,1,1,0,192,255,2,0,21,0,0,0,1,1,0,0,208,75,4,0,0,0,0,0,254,0,2,0,0,44,8,0,21,0,0,0,1,2,2,0,96,135,7,0,21,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,8,0,72,202,5,0,21,0,0,0,1,224,96,0,160,246,1,0,21,0,0,0,1,224,64,0,120,103,7,0,21,0,0,0,1,224,32,0,80,246,3,0,21,0,0,0,1,224,0,0,248,38,7,0,21,0,0,0,1,224,224,0,80,124,6,0,21,0,0,0,1,224,192,0,112,212,3,0,21,0,0,0,1,224,160,0,48,90,7,0,21,0,0,0,1,224,128,0,248,160,5,0,0,0,0,0,254,0,2,0,16,227,4,0,22,0,0,0,1,2,2,0,96,135,7,0,22,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,22,0,0,0,1,8,8,0,96,135,7,0,22,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,2,0,168,170,5,0,22,0,0,0,1,16,16,0,8,208,6,0,22,0,0,0,1,16,0,0,0,199,5,0,0,0,0,0,254,0,8,0,32,4,2,0,22,0,0,0,1,224,0,0,104,54,4,0,22,0,0,0,1,224,32,0,80,252,6,0,22,0,0,0,1,224,64,0,16,242,7,0,22,0,0,0,1,224,96,0,104,236,7,0,22,0,0,0,1,224,224,0,128,230,7,0,22,0,0,0,1,224,192,0,184,164,6,0,22,0,0,0,1,224,160,0,80,74,6,0,22,0,0,0,1,224,128,0,192,32,6,0,0,0,0,0,22,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,120,230,8,0,22,0,0,0,1,1,0,0,248,77,3,0,22,0,0,0,1,1,1,0,104,102,8,0,0,0,0,0,254,0,2,0,32,4,2,0,22,0,0,0,1,2,0,0,128,103,7,0,22,0,0,0,1,2,2,0,80,196,7,0,0,0,0,0,254,0,2,0,200,30,2,0,22,0,0,0,1,16,0,0,120,97,1,0,22,0,0,0,1,16,16,0,96,19,1,0,15,0,0,0,255,255,255,0,0,0,0,0,16,0,0,0,255,255,255,0,0,0,0,0,17,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,72,4,1,0,15,0,0,0,1,4,4,0,96,135,7,0,15,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,8,0,200,87,7,0,16,0,0,0,1,7,1,0,96,164,8,0,16,0,0,0,1,7,2,0,144,102,8,0,16,0,0,0,1,7,3,0,176,45,8,0,16,0,0,0,1,7,4,0,16,250,7,0,16,0,0,0,1,7,7,0,32,123,8,0,16,0,0,0,1,7,6,0,192,110,8,0,16,0,0,0,1,7,5,0,96,102,7,0,16,0,0,0,1,7,0,0,104,151,6,0,0,0,0,0,254,0,8,0,160,123,6,0,16,0,0,0,1,56,8,0,96,164,8,0,16,0,0,0,1,56,16,0,144,102,8,0,16,0,0,0,1,56,24,0,176,45,8,0,16,0,0,0,1,56,32,0,16,250,7,0,16,0,0,0,1,56,56,0,32,123,8,0,16,0,0,0,1,56,48,0,192,110,8,0,16,0,0,0,1,56,40,0,96,102,7,0,16,0,0,0,1,56,0,0,104,151,6,0,0,0,0,0,254,0,4,0,128,129,4,0,16,0,0,0,1,192,128,0,192,255,2,0,16,0,0,0,1,192,64,0,208,75,4,0,16,0,0,0,1,192,192,0,8,49,4,0,16,0,0,0,1,192,0,0,72,246,3,0,0,0,0,0,254,0,2,0,200,30,2,0,17,0,0,0,1,1,0,0,120,97,1,0,17,0,0,0,1,1,1,0,96,19,1,0,0,0,0,0,254,0,8,0,64,37,5,0,17,0,0,0,1,14,14,0,216,108,5,0,17,0,0,0,1,14,12,0,72,77,5,0,17,0,0,0,1,14,10,0,184,45,5,0,17,0,0,0,1,14,8,0,232,15,5,0,17,0,0,0,1,14,6,0,32,237,4,0,17,0,0,0,1,14,4,0,144,201,4,0,17,0,0,0,1,14,2,0,216,168,4,0,17,0,0,0,1,14,0,0,120,7,5,0,0,0,0,0,254,0,2,0,168,234,7,0,17,0,0,0,1,16,0,0,96,135,7,0,17,0,0,0,1,16,16,0,152,182,7,0,0,0,0,0,254,0,2,0,112,167,5,0,17,0,0,0,1,32,0,0,96,135,7,0,17,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,17,0,0,0,1,64,64,0,96,135,7,0,17,0,0,0,1,64,0,0,152,182,7,0,15,0,0,0,255,255,32,0,0,0,0,0,0,0,0,0,254,0,2,0,128,129,4,0,15,0,0,0,1,1,0,0,8,49,4,0,15,0,0,0,1,1,1,0,72,246,3,0,0,0,0,0,254,0,3,0,32,4,2,0,15,0,0,0,1,24,8,0,56,233,4,0,15,0,0,0,1,24,0,0,16,42,5,0,15,0,0,0,1,24,24,0,152,11,5,0,0,0,0,0,254,0,2,0,200,30,2,0,15,0,0,0,1,32,32,0,120,97,1,0,15,0,0,0,1,32,0,0,96,19,1,0,0,0,0,0,254,0,2,0,144,212,8,0,15,0,0,0,1,64,0,0,96,135,7,0,15,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,15,0,0,0,1,128,0,0,96,135,7,0,15,0,0,0,1,128,128,0,152,182,7,0,0,0,0,0,11,0,0,0,255,255,251,0,0,0,0,0,0,0,0,0,254,0,4,0,32,4,2,0,11,0,0,0,1,3,0,0,240,12,2,0,11,0,0,0,1,3,2,0,160,36,8,0,11,0,0,0,1,3,3,0,208,239,7,0,11,0,0,0,1,3,1,0,120,187,7,0,0,0,0,0,254,0,2,0,200,30,2,0,11,0,0,0,1,4,0,0,120,97,1,0,11,0,0,0,1,4,4,0,96,19,1,0,0,0,0,0,254,0,2,0,168,234,7,0,11,0,0,0,1,8,0,0,96,135,7,0,11,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,11,0,0,0,1,48,16,0,80,246,3,0,11,0,0,0,1,48,48,0,80,124,6,0,11,0,0,0,1,48,32,0,112,212,3,0,11,0,0,0,1,48,0,0,248,160,5,0,0,0,0,0,254,0,2,0,96,228,6,0,11,0,0,0,1,64,64,0,96,135,7,0,11,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,16,227,4,0,11,0,0,0,1,128,128,0,96,135,7,0,11,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,15,0,0,0,255,255,127,0,0,0,0,0,0,0,0,0,254,0,4,0,200,87,7,0,15,0,0,0,1,3,0,0,160,36,8,0,15,0,0,0,1,3,3,0,208,239,7,0,15,0,0,0,1,3,1,0,120,187,7,0,15,0,0,0,1,3,2,0,136,23,1,0,0,0,0,0,254,0,4,0,160,123,6,0,15,0,0,0,1,12,0,0,160,36,8,0,15,0,0,0,1,12,12,0,136,23,1,0,15,0,0,0,1,12,4,0,120,187,7,0,15,0,0,0,1,12,8,0,136,23,1,0,0,0,0,0,254,0,2,0,200,30,2,0,15,0,0,0,1,64,64,0,96,19,1,0,15,0,0,0,1,64,0,0,120,97,1,0,16,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,128,129,4,0,16,0,0,0,1,1,1,0,8,49,4,0,16,0,0,0,1,1,0,0,72,246,3,0,0,0,0,0,254,0,4,0,64,37,5,0,16,0,0,0,1,6,4,0,152,53,6,0,16,0,0,0,1,6,2,0,8,49,6,0,16,0,0,0,1,6,6,0,248,45,5,0,16,0,0,0,1,6,0,0,48,129,4,0,0,0,0,0,254,0,2,0,72,202,5,0,16,0,0,0,1,128,128,0,80,246,3,0,16,0,0,0,1,128,0,0,112,212,3,0,16,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,16,49,4,0,16,0,0,0,1,32,32,0,96,135,7,0,16,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,200,30,2,0,16,0,0,0,1,64,0,0,120,97,1,0,16,0,0,0,1,64,64,0,96,19,1,0,0,0,0,0,254,0,2,0,144,212,8,0,16,0,0,0,1,128,0,0,96,135,7,0,16,0,0,0,1,128,128,0,152,182,7,0,17,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,254,0,2,0,128,129,4,0,17,0,0,0,1,1,0,0,8,49,4,0,17,0,0,0,1,1,1,0,72,246,3,0,0,0,0,0,254,0,2,0,72,202,5,0,17,0,0,0,1,2,0,0,80,246,3,0,17,0,0,0,1,2,2,0,112,212,3,0,0,0,0,0,254,0,4,0,64,37,5,0,17,0,0,0,1,12,8,0,64,109,5,0,17,0,0,0,1,12,12,0,176,77,5,0,17,0,0,0,1,12,4,0,176,116,6,0,17,0,0,0,1,12,0,0,120,7,5,0,0,0,0,0,254,0,16,0,32,4,2,0,17,0,0,0,1,240,16,0,56,233,4,0,17,0,0,0,1,240,32,0,152,169,4,0,17,0,0,0,1,240,0,0,16,42,5,0,17,0,0,0,1,240,48,0,232,109,4,0,17,0,0,0,1,240,64,0,88,84,4,0,17,0,0,0,1,240,80,0,0,57,4,0,17,0,0,0,1,240,96,0,128,29,4,0,17,0,0,0,1,240,112,0,168,0,4,0,17,0,0,0,1,240,128,0,152,11,5,0,17,0,0,0,1,240,144,0,16,193,3,0,17,0,0,0,1,240,160,0,144,167,3,0,17,0,0,0,1,240,224,0,232,141,3,0,17,0,0,0,1,240,176,0,120,118,3,0,17,0,0,0,1,240,192,0,120,95,3,0,17,0,0,0,1,240,208,0,96,80,3,0,17,0,0,0,1,240,240,0,200,82,2,0,0,0,0,0,14,0,0,0,255,255,201,0,0,0,0,0,15,0,0,0,255,255,255,0,0,0,0,0,16,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,32,4,2,0,14,0,0,0,1,3,3,0,160,36,8,0,14,0,0,0,1,3,1,0,208,239,7,0,14,0,0,0,1,3,2,0,120,187,7,0,14,0,0,0,1,3,0,0,16,227,4,0,0,0,0,0,254,0,4,0,128,129,4,0,14,0,0,0,1,12,0,0,192,255,2,0,14,0,0,0,1,12,4,0,208,75,4,0,14,0,0,0,1,12,8,0,8,49,4,0,14,0,0,0,1,12,12,0,72,246,3,0,0,0,0,0,254,0,4,0,64,37,5,0,14,0,0,0,1,48,0,0,176,116,6,0,14,0,0,0,1,48,16,0,80,113,6,0,14,0,0,0,1,48,32,0,80,110,6,0,14,0,0,0,1,48,48,0,120,7,5,0,0,0,0,0,254,0,2,0,72,202,5,0,14,0,0,0,1,64,64,0,248,38,7,0,14,0,0,0,1,64,0,0,112,212,3,0,0,0,0,0,254,0,2,0,192,75,3,0,14,0,0,0,1,128,128,0,248,38,7,0,14,0,0,0,1,128,0,0,40,87,8,0,0,0,0,0,254,0,2,0,16,27,6,0,15,0,0,0,1,16,16,0,96,135,7,0,15,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,2,0,200,30,2,0,16,0,0,0,1,128,128,0,120,97,1,0,16,0,0,0,1,128,0,0,96,19,1,0,18,0,0,0,255,255,255,0,0,0,0,0,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,1,1,0,0,0,0,0,18,0,0,0,254,0,8,0,200,87,7,0,18,0,0,0,1,7,0,0,48,53,7,0,18,0,0,0,1,7,1,0,168,9,7,0,18,0,0,0,1,7,2,0,48,223,6,0,18,0,0,0,1,7,7,0,216,178,6,0,18,0,0,0,1,7,6,0,8,201,6,0,18,0,0,0,1,7,5,0,200,197,6,0,18,0,0,0,1,7,4,0,152,194,6,0,18,0,0,0,1,7,3,0,128,95,7,0,18,0,0,0,254,0,8,0,160,123,6,0,18,0,0,0,1,56,0,0,48,53,7,0,18,0,0,0,1,56,8,0,168,9,7,0,18,0,0,0,1,56,16,0,48,223,6,0,18,0,0,0,1,56,56,0,216,178,6,0,18,0,0,0,1,56,48,0,8,201,6,0,18,0,0,0,1,56,40,0,200,197,6,0,18,0,0,0,1,56,32,0,152,194,6,0,18,0,0,0,1,56,24,0,128,95,7,0,18,0,0,0,254,0,2,0,144,212,8,0,18,0,0,0,1,64,64,0,96,135,7,0,18,0,0,0,1,64,0,0,152,182,7,0,18,0,0,0,254,0,2,0,80,251,6,0,18,0,0,0,1,128,128,0,96,135,7,0,18,0,0,0,1,128,0,0,152,182,7,0,19,0,0,0,254,0,4,0,128,129,4,0,19,0,0,0,1,3,2,0,208,75,4,0,19,0,0,0,1,3,3,0,8,49,4,0,19,0,0,0,1,3,1,0,72,246,3,0,19,0,0,0,1,3,0,0,64,47,7,0,19,0,0,0,254,0,8,0,72,202,5,0,19,0,0,0,1,28,28,0,72,198,6,0,19,0,0,0,1,28,24,0,208,75,4,0,19,0,0,0,1,28,20,0,8,49,4,0,19,0,0,0,1,28,16,0,152,21,4,0,19,0,0,0,1,28,12,0,72,57,4,0,19,0,0,0,1,28,8,0,72,0,3,0,19,0,0,0,1,28,4,0,64,47,7,0,19,0,0,0,1,28,0,0,48,173,6,0,19,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,32,0,0,96,135,7,0,19,0,0,0,1,32,32,0,152,182,7,0,19,0,0,0,254,0,2,0,104,159,3,0,19,0,0,0,1,64,0,0,56,111,3,0,19,0,0,0,1,64,64,0,104,134,3,0,19,0,0,0,254,0,2,0,200,30,2,0,19,0,0,0,1,128,0,0,120,97,1,0,19,0,0,0,1,128,128,0,96,19,1,0,20,0,0,0,254,0,2,0,224,65,3,0,20,0,0,0,1,1,1,0,104,134,3,0,20,0,0,0,1,1,0,0,56,111,3,0,0,0,0,0,18,0,0,0,255,255,8,0,0,0,0,0,0,0,0,0,254,0,8,0,88,167,8,0,18,0,0,0,1,7,7,0,216,104,8,0,18,0,0,0,1,7,6,0,88,48,8,0,18,0,0,0,1,7,5,0,240,251,7,0,18,0,0,0,1,7,4,0,176,198,7,0,18,0,0,0,1,7,3,0,72,150,7,0,18,0,0,0,1,7,2,0,240,103,7,0,18,0,0,0,1,7,1,0,112,53,7,0,18,0,0,0,1,7,0,0,216,9,7,0,0,0,0,0,254,0,2,0,32,4,2,0,18,0,0,0,1,8,8,0,128,29,4,0,18,0,0,0,1,8,0,0,16,136,6,0,0,0,0,0,254,0,2,0,96,90,6,0,18,0,0,0,1,16,0,0,88,44,6,0,18,0,0,0,1,16,16,0,16,2,6,0,0,0,0,0,254,0,2,0,64,212,5,0,18,0,0,0,1,32,32,0,216,104,8,0,18,0,0,0,1,32,0,0,88,48,8,0,0,0,0,0,17,0,0,0,255,255,255,0,0,0,0,0,18,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,8,0,0,70,2,0,17,0,0,0,1,7,0,0,248,223,6,0,17,0,0,0,1,7,1,0,88,179,6,0,17,0,0,0,1,7,2,0,32,136,6,0,17,0,0,0,1,7,7,0,120,90,6,0,17,0,0,0,1,7,6,0,184,164,6,0,17,0,0,0,1,7,5,0,80,74,6,0,17,0,0,0,1,7,4,0,192,32,6,0,17,0,0,0,1,7,3,0,32,242,5,0,0,0,0,0,254,0,8,0,192,56,2,0,17,0,0,0,1,56,0,0,248,223,6,0,17,0,0,0,1,56,8,0,88,179,6,0,17,0,0,0,1,56,16,0,32,136,6,0,17,0,0,0,1,56,56,0,120,90,6,0,17,0,0,0,1,56,48,0,184,164,6,0,17,0,0,0,1,56,40,0,80,74,6,0,17,0,0,0,1,56,32,0,192,32,6,0,17,0,0,0,1,56,24,0,32,242,5,0,0,0,0,0,254,0,2,0,232,75,4,0,17,0,0,0,1,64,64,0,96,135,7,0,17,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,17,0,0,0,1,128,128,0,96,135,7,0,17,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,18,0,0,0,1,3,3,0,8,49,4,0,18,0,0,0,1,3,2,0,152,21,4,0,18,0,0,0,1,3,1,0,72,246,3,0,18,0,0,0,1,3,0,0,64,47,7,0,0,0,0,0,254,0,2,0,200,30,2,0,18,0,0,0,1,4,4,0,120,97,1,0,18,0,0,0,1,4,0,0,96,19,1,0,0,0,0,0,254,0,4,0,40,148,2,0,18,0,0,0,1,24,24,0,248,223,3,0,18,0,0,0,1,24,16,0,120,193,3,0,18,0,0,0,1,24,8,0,0,168,3,0,18,0,0,0,1,24,0,0,88,142,3,0,0,0,0,0,254,0,4,0,72,202,5,0,18,0,0,0,1,96,64,0,80,246,3,0,18,0,0,0,1,96,96,0,80,124,6,0,18,0,0,0,1,96,32,0,112,212,3,0,18,0,0,0,1,96,0,0,248,160,5,0,0,0,0,0,254,0,2,0,72,4,1,0,18,0,0,0,1,128,128,0,96,135,7,0,18,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,16,0,0,0,255,255,223,0,0,0,0,0,0,0,0,0,254,0,4,0,72,202,5,0,16,0,0,0,1,3,3,0,80,246,3,0,16,0,0,0,1,3,2,0,80,124,6,0,16,0,0,0,1,3,1,0,112,212,3,0,16,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,2,0,200,109,5,0,16,0,0,0,1,4,4,0,96,135,7,0,16,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,2,0,88,32,6,0,16,0,0,0,1,8,8,0,80,246,3,0,16,0,0,0,1,8,0,0,112,212,3,0,0,0,0,0,254,0,2,0,80,238,4,0,16,0,0,0,1,16,16,0,80,246,3,0,16,0,0,0,1,16,0,0,112,212,3,0,0,0,0,0,254,0,2,0,200,30,2,0,16,0,0,0,1,32,0,0,120,97,1,0,16,0,0,0,1,32,32,0,96,19,1,0,0,0,0,0,254,0,4,0,128,129,4,0,16,0,0,0,1,192,0,0,208,75,4,0,16,0,0,0,1,192,192,0,8,49,4,0,16,0,0,0,1,192,128,0,152,21,4,0,16,0,0,0,1,192,64,0,72,246,3,0,17,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,11,0,160,123,6,0,17,0,0,0,1,15,6,0,176,193,3,0,17,0,0,0,1,15,8,0,208,196,4,0,17,0,0,0,1,15,10,0,56,233,4,0,17,0,0,0,1,15,7,0,240,118,3,0,17,0,0,0,1,15,15,0,16,42,5,0,17,0,0,0,1,15,9,0,184,80,3,0,17,0,0,0,1,15,14,0,152,11,5,0,17,0,0,0,1,15,13,0,24,27,4,0,17,0,0,0,1,15,12,0,48,31,3,0,17,0,0,0,1,15,11,0,24,7,3,0,17,0,0,0,1,15,0,0,200,82,2,0,0,0,0,0,254,0,11,0,200,87,7,0,17,0,0,0,1,240,96,0,176,193,3,0,17,0,0,0,1,240,128,0,208,196,4,0,17,0,0,0,1,240,160,0,56,233,4,0,17,0,0,0,1,240,112,0,240,118,3,0,17,0,0,0,1,240,240,0,16,42,5,0,17,0,0,0,1,240,144,0,184,80,3,0,17,0,0,0,1,240,224,0,152,11,5,0,17,0,0,0,1,240,208,0,24,27,4,0,17,0,0,0,1,240,192,0,48,31,3,0,17,0,0,0,1,240,176,0,24,7,3,0,17,0,0,0,1,240,0,0,200,82,2,0,20,0,0,0,255,255,247,0,0,0,0,0,0,0,0,0,254,0,4,0,64,37,5,0,20,0,0,0,1,3,1,0,128,252,7,0,20,0,0,0,1,3,3,0,136,199,7,0,20,0,0,0,1,3,0,0,248,150,7,0,20,0,0,0,1,3,2,0,8,133,7,0,0,0,0,0,254,0,2,0,0,152,2,0,20,0,0,0,1,4,0,0,96,135,7,0,20,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,18,0,0,0,255,255,32,0,0,0,0,0,19,0,0,0,255,255,255,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,232,75,4,0,18,0,0,0,1,32,32,0,96,135,7,0,18,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,19,0,0,0,1,3,3,0,8,49,4,0,19,0,0,0,1,3,2,0,152,21,4,0,19,0,0,0,1,3,1,0,72,246,3,0,19,0,0,0,1,3,0,0,72,0,3,0,0,0,0,0,254,0,4,0,64,37,5,0,19,0,0,0,1,12,12,0,16,223,3,0,19,0,0,0,1,12,8,0,32,168,8,0,19,0,0,0,1,12,4,0,16,252,7,0,19,0,0,0,1,12,0,0,128,141,3,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,16,0,0,96,135,7,0,19,0,0,0,1,16,16,0,152,182,7,0,0,0,0,0,254,0,2,0,200,30,2,0,19,0,0,0,1,32,0,0,120,97,1,0,19,0,0,0,1,32,32,0,96,19,1,0,0,0,0,0,254,0,4,0,200,87,7,0,20,0,0,0,1,3,1,0,104,236,7,0,20,0,0,0,1,3,3,0,128,230,7,0,20,0,0,0,1,3,2,0,184,164,6,0,20,0,0,0,1,3,0,0,16,227,4,0,0,0,0,0,254,0,4,0,160,123,6,0,20,0,0,0,1,12,0,0,16,242,7,0,20,0,0,0,1,12,4,0,120,211,6,0,20,0,0,0,1,12,12,0,80,74,6,0,20,0,0,0,1,12,8,0,32,242,5,0,0,0,0,0,254,0,2,0,72,202,5,0,20,0,0,0,1,16,16,0,80,246,3,0,20,0,0,0,1,16,0,0,112,212,3,0,0,0,0,0,254,0,2,0,144,212,8,0,20,0,0,0,1,32,32,0,96,135,7,0,20,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,64,145,8,0,20,0,0,0,1,64,64,0,96,135,7,0,20,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,152,140,8,0,20,0,0,0,1,128,128,0,96,135,7,0,20,0,0,0,1,128,0,0,152,182,7,0,8,0,0,0,255,255,64,0,0,0,0,0,0,0,0,0,254,0,2,0,208,87,7,0,8,0,0,0,1,8,0,0,96,135,7,0,8,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,2,0,224,253,7,0,8,0,0,0,1,16,0,0,96,135,7,0,8,0,0,0,1,16,16,0,152,182,7,0,0,0,0,0,254,0,2,0,200,87,7,0,8,0,0,0,1,64,0,0,224,67,5,0,8,0,0,0,1,64,64,0,200,201,5,0,18,0,0,0,255,255,223,0,0,0,0,0,19,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,72,202,5,0,18,0,0,0,1,3,2,0,80,246,3,0,18,0,0,0,1,3,3,0,248,38,7,0,18,0,0,0,1,3,1,0,112,212,3,0,18,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,4,0,128,129,4,0,18,0,0,0,1,12,8,0,192,255,2,0,18,0,0,0,1,12,4,0,208,75,4,0,18,0,0,0,1,12,12,0,8,49,4,0,18,0,0,0,1,12,0,0,72,246,3,0,0,0,0,0,254,0,2,0,88,41,7,0,18,0,0,0,1,16,0,0,88,244,4,0,18,0,0,0,1,16,16,0,184,151,2,0,0,0,0,0,254,0,2,0,128,112,3,0,18,0,0,0,1,32,0,0,168,22,4,0,18,0,0,0,1,32,32,0,224,247,3,0,0,0,0,0,254,0,2,0,72,4,1,0,18,0,0,0,1,64,64,0,96,135,7,0,18,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,18,0,0,0,1,128,128,0,96,135,7,0,18,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,8,0,200,87,7,0,19,0,0,0,1,7,0,0,144,102,8,0,19,0,0,0,1,7,1,0,176,45,8,0,19,0,0,0,1,7,2,0,224,127,8,0,19,0,0,0,1,7,7,0,32,123,8,0,19,0,0,0,1,7,6,0,192,110,8,0,19,0,0,0,1,7,5,0,96,102,7,0,19,0,0,0,1,7,4,0,184,105,6,0,19,0,0,0,1,7,3,0,152,96,3,0,0,0,0,0,254,0,8,0,160,123,6,0,19,0,0,0,1,56,0,0,144,102,8,0,19,0,0,0,1,56,8,0,176,45,8,0,19,0,0,0,1,56,16,0,224,127,8,0,19,0,0,0,1,56,56,0,32,123,8,0,19,0,0,0,1,56,48,0,192,110,8,0,19,0,0,0,1,56,40,0,96,102,7,0,19,0,0,0,1,56,32,0,184,105,6,0,19,0,0,0,1,56,24,0,152,96,3,0,0,0,0,0,254,0,2,0,104,159,3,0,19,0,0,0,1,64,0,0,56,111,3,0,19,0,0,0,1,64,64,0,104,134,3,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,128,0,0,96,135,7,0,19,0,0,0,1,128,128,0,152,182,7,0,17,0,0,0,255,255,255,0,0,0,0,0,18,0,0,0,255,255,127,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,17,0,0,0,1,3,1,0,192,255,2,0,17,0,0,0,1,3,2,0,208,75,4,0,17,0,0,0,1,3,3,0,8,49,4,0,17,0,0,0,1,3,0,0,72,246,3,0,0,0,0,0,254,0,7,0,160,123,6,0,17,0,0,0,1,28,16,0,96,164,8,0,17,0,0,0,1,28,8,0,144,102,8,0,17,0,0,0,1,28,24,0,176,45,8,0,17,0,0,0,1,28,4,0,224,127,8,0,17,0,0,0,1,28,28,0,32,123,8,0,17,0,0,0,1,28,12,0,192,110,8,0,17,0,0,0,1,28,20,0,96,102,7,0,0,0,0,0,254,0,8,0,200,87,7,0,17,0,0,0,1,224,128,0,96,164,8,0,17,0,0,0,1,224,64,0,144,102,8,0,17,0,0,0,1,224,192,0,176,45,8,0,17,0,0,0,1,224,32,0,224,127,8,0,17,0,0,0,1,224,224,0,32,123,8,0,17,0,0,0,1,224,96,0,192,110,8,0,17,0,0,0,1,224,160,0,96,102,7,0,17,0,0,0,1,224,0,0,104,151,6,0,0,0,0,0,254,0,4,0,8,99,2,0,18,0,0,0,1,3,2,0,0,83,2,0,18,0,0,0,1,3,3,0,104,239,4,0,18,0,0,0,1,3,1,0,208,56,2,0,18,0,0,0,1,3,0,0,160,41,2,0,0,0,0,0,254,0,2,0,112,167,5,0,18,0,0,0,1,4,0,0,96,135,7,0,18,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,254,0,2,0,168,234,7,0,18,0,0,0,1,8,0,0,96,135,7,0,18,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,8,0,64,37,5,0,18,0,0,0,1,112,48,0,80,2,4,0,18,0,0,0,1,112,80,0,24,225,3,0,18,0,0,0,1,112,16,0,144,194,3,0,18,0,0,0,1,112,112,0,208,168,3,0,18,0,0,0,1,112,96,0,176,109,2,0,18,0,0,0,1,112,32,0,64,119,3,0,18,0,0,0,1,112,64,0,176,123,2,0,18,0,0,0,1,112,0,0,120,7,5,0,0,0,0,0,254,0,2,0,200,30,2,0,18,0,0,0,1,128,0,0,120,97,1,0,18,0,0,0,1,128,128,0,96,19,1,0,0,0,0,0,18,0,0,0,255,255,247,0,0,0,0,0,19,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,8,0,200,87,7,0,18,0,0,0,1,7,1,0,144,102,8,0,18,0,0,0,1,7,2,0,176,45,8,0,18,0,0,0,1,7,4,0,224,127,8,0,18,0,0,0,1,7,7,0,32,123,8,0,18,0,0,0,1,7,3,0,248,116,8,0,18,0,0,0,1,7,6,0,192,110,8,0,18,0,0,0,1,7,5,0,184,105,6,0,18,0,0,0,1,7,0,0,104,151,6,0,0,0,0,0,254,0,2,0,200,30,2,0,18,0,0,0,1,8,0,0,120,97,1,0,18,0,0,0,1,8,8,0,96,19,1,0,0,0,0,0,254,0,4,0,64,37,5,0,18,0,0,0,1,48,48,0,208,85,4,0,18,0,0,0,1,48,32,0,184,59,4,0,18,0,0,0,1,48,16,0,32,31,4,0,18,0,0,0,1,48,0,0,136,199,7,0,0,0,0,0,254,0,4,0,128,129,4,0,18,0,0,0,1,192,128,0,192,255,2,0,18,0,0,0,1,192,64,0,208,75,4,0,18,0,0,0,1,192,192,0,8,49,4,0,18,0,0,0,1,192,0,0,72,246,3,0,0,0,0,0,254,0,8,0,160,123,6,0,19,0,0,0,1,7,1,0,144,102,8,0,19,0,0,0,1,7,2,0,176,45,8,0,19,0,0,0,1,7,4,0,224,127,8,0,19,0,0,0,1,7,7,0,32,123,8,0,19,0,0,0,1,7,3,0,248,116,8,0,19,0,0,0,1,7,6,0,192,110,8,0,19,0,0,0,1,7,5,0,184,105,6,0,19,0,0,0,1,7,0,0,104,151,6,0,0,0,0,0,254,0,2,0,232,75,4,0,19,0,0,0,1,8,8,0,96,135,7,0,19,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,16,16,0,96,135,7,0,19,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,19,0,0,0,1,96,64,0,80,246,3,0,19,0,0,0,1,96,96,0,248,38,7,0,19,0,0,0,1,96,32,0,48,123,8,0,19,0,0,0,1,96,0,0,8,117,8,0,0,0,0,0,254,0,2,0,176,166,2,0,19,0,0,0,1,128,128,0,96,135,7,0,19,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,17,0,0,0,255,255,251,0,0,0,0,0,18,0,0,0,255,255,31,0,0,0,0,0,0,0,0,0,254,0,2,0,128,129,4,0,17,0,0,0,1,1,1,0,8,49,4,0,17,0,0,0,1,1,0,0,72,246,3,0,0,0,0,0,254,0,2,0,72,202,5,0,17,0,0,0,1,2,2,0,80,246,3,0,17,0,0,0,1,2,0,0,112,212,3,0,0,0,0,0,254,0,2,0,168,234,7,0,17,0,0,0,1,4,4,0,96,135,7,0,17,0,0,0,1,4,0,0,152,182,7,0,0,0,0,0,254,0,4,0,200,87,7,0,18,0,0,0,1,3,0,0,160,36,8,0,18,0,0,0,1,3,3,0,208,239,7,0,18,0,0,0,1,3,2,0,120,187,7,0,18,0,0,0,1,3,1,0,136,23,1,0,0,0,0,0,254,0,4,0,160,123,6,0,18,0,0,0,1,12,0,0,160,36,8,0,18,0,0,0,1,12,12,0,208,239,7,0,18,0,0,0,1,12,8,0,120,187,7,0,18,0,0,0,1,12,4,0,136,23,1,0,0,0,0,0,254,0,2,0,144,212,8,0,18,0,0,0,1,32,0,0,96,135,7,0,18,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,2,0,200,30,2,0,18,0,0,0,1,64,0,0,120,97,1,0,18,0,0,0,1,64,64,0,96,19,1,0,0,0,0,0,17,0,0,0,255,255,255,0,0,0,0,0,18,0,0,0,255,255,31,0,0,0,0,0,0,0,0,0,254,0,4,0,160,138,5,0,17,0,0,0,1,3,3,0,80,111,5,0,17,0,0,0,1,3,1,0,24,79,5,0,17,0,0,0,1,3,2,0,80,49,5,0,17,0,0,0,1,3,0,0,32,18,5,0,0,0,0,0,254,0,4,0,128,129,4,0,17,0,0,0,1,12,4,0])
.concat([208,75,4,0,17,0,0,0,1,12,12,0,8,49,4,0,17,0,0,0,1,12,8,0,152,21,4,0,17,0,0,0,1,12,0,0,72,246,3,0,0,0,0,0,254,0,4,0,200,87,7,0,17,0,0,0,1,192,0,0,224,127,8,0,17,0,0,0,1,192,192,0,32,123,8,0,17,0,0,0,1,192,64,0,192,110,8,0,17,0,0,0,1,192,128,0,96,102,7,0,0,0,0,0,254,0,4,0,160,123,6,0,17,0,0,0,1,48,0,0,144,102,8,0,17,0,0,0,1,48,32,0,176,45,8,0,17,0,0,0,1,48,16,0,224,127,8,0,17,0,0,0,1,48,48,0,32,123,8,0,0,0,0,0,254,0,8,0,64,37,5,0,18,0,0,0,1,7,7,0,8,97,3,0,18,0,0,0,1,7,3,0,32,81,3,0,18,0,0,0,1,7,5,0,24,67,3,0,18,0,0,0,1,7,1,0,8,52,3,0,18,0,0,0,1,7,6,0,176,31,3,0,18,0,0,0,1,7,2,0,8,8,3,0,18,0,0,0,1,7,4,0,112,242,2,0,18,0,0,0,1,7,0,0,120,7,5,0,0,0,0,0,254,0,2,0,168,234,7,0,18,0,0,0,1,8,0,0,96,135,7,0,18,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,2,0,72,202,5,0,18,0,0,0,1,16,16,0,248,38,7,0,18,0,0,0,1,16,0,0,48,123,8,0,0,0,0,0,254,0,2,0,144,212,8,0,18,0,0,0,1,32,0,0,96,135,7,0,18,0,0,0,1,32,32,0,152,182,7,0,0,0,0,0,254,0,3,0,200,30,2,0,18,0,0,0,1,192,0,0,120,97,1,0,18,0,0,0,1,192,64,0,88,51,1,0,18,0,0,0,1,192,192,0,96,19,1,0,17,0,0,0,255,255,248,0,0,0,0,0,18,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,16,0,72,202,5,0,17,0,0,0,1,15,15,0,144,29,4,0,17,0,0,0,1,15,14,0,208,75,4,0,17,0,0,0,1,15,13,0,8,49,4,0,17,0,0,0,1,15,12,0,152,21,4,0,17,0,0,0,1,15,11,0,72,246,3,0,17,0,0,0,1,15,10,0,72,0,3,0,17,0,0,0,1,15,9,0,64,47,7,0,17,0,0,0,1,15,8,0,136,31,4,0,17,0,0,0,1,15,7,0,80,62,6,0,17,0,0,0,1,15,6,0,208,7,8,0,17,0,0,0,1,15,5,0,168,148,4,0,17,0,0,0,1,15,4,0,176,2,8,0,17,0,0,0,1,15,3,0,160,142,4,0,17,0,0,0,1,15,2,0,216,138,4,0,17,0,0,0,1,15,1,0,216,202,4,0,17,0,0,0,1,15,0,0,48,81,3,0,0,0,0,0,254,0,2,0,112,153,2,0,17,0,0,0,1,16,0,0,24,52,3,0,17,0,0,0,1,16,16,0,192,31,3,0,0,0,0,0,254,0,2,0,144,212,8,0,17,0,0,0,1,32,32,0,96,135,7,0,17,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,72,4,1,0,17,0,0,0,1,64,64,0,96,135,7,0,17,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,17,0,0,0,1,128,128,0,96,135,7,0,17,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,8,0,200,87,7,0,18,0,0,0,1,7,0,0,144,102,8,0,18,0,0,0,1,7,1,0,176,45,8,0,18,0,0,0,1,7,2,0,224,127,8,0,18,0,0,0,1,7,7,0,128,103,7,0,18,0,0,0,1,7,6,0,80,196,7,0,18,0,0,0,1,7,5,0,0,90,2,0,18,0,0,0,1,7,4,0,72,74,2,0,18,0,0,0,1,7,3,0,104,61,2,0,0,0,0,0,254,0,8,0,160,123,6,0,18,0,0,0,1,56,0,0,144,102,8,0,18,0,0,0,1,56,8,0,176,45,8,0,18,0,0,0,1,56,16,0,224,127,8,0,18,0,0,0,1,56,56,0,128,103,7,0,18,0,0,0,1,56,48,0,80,196,7,0,18,0,0,0,1,56,40,0,0,90,2,0,18,0,0,0,1,56,32,0,72,74,2,0,18,0,0,0,1,56,24,0,104,61,2,0,0,0,0,0,254,0,2,0,104,159,3,0,18,0,0,0,1,64,0,0,56,111,3,0,18,0,0,0,1,64,64,0,104,134,3,0,0,0,0,0,254,0,2,0,168,234,7,0,18,0,0,0,1,128,0,0,96,135,7,0,18,0,0,0,1,128,128,0,152,182,7,0,0,0,0,0,20,0,0,0,255,255,191,0,0,0,0,0,21,0,0,0,255,255,3,0,0,0,0,0,0,0,0,0,254,0,4,0,200,87,7,0,20,0,0,0,1,3,0,0,224,127,8,0,20,0,0,0,1,3,3,0,32,123,8,0,20,0,0,0,1,3,2,0,192,110,8,0,20,0,0,0,1,3,1,0,96,102,7,0,0,0,0,0,254,0,4,0,160,123,6,0,20,0,0,0,1,12,0,0,224,127,8,0,20,0,0,0,1,12,12,0,32,123,8,0,20,0,0,0,1,12,8,0,192,110,8,0,20,0,0,0,1,12,4,0,96,102,7,0,0,0,0,0,254,0,2,0,128,129,4,0,20,0,0,0,1,16,16,0,192,255,2,0,20,0,0,0,1,16,0,0,208,75,4,0,0,0,0,0,254,0,4,0,200,73,5,0,20,0,0,0,1,32,32,0,192,33,6,0,20,0,0,0,1,32,0,0,120,7,5,0,0,0,0,0,254,0,2,0,200,30,2,0,20,0,0,0,1,64,0,0,120,97,1,0,20,0,0,0,1,64,64,0,96,19,1,0,0,0,0,0,254,0,2,0,144,212,8,0,20,0,0,0,1,128,128,0,96,135,7,0,20,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,21,0,0,0,1,3,2,0,80,246,3,0,21,0,0,0,1,3,3,0,248,38,7,0,21,0,0,0,1,3,1,0,112,212,3,0,21,0,0,0,1,3,0,0,24,99,5,0,0,0,0,0,16,0,0,0,255,255,255,0,0,0,0,0,17,0,0,0,255,255,255,0,0,0,0,0,18,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,2,0,232,75,4,0,16,0,0,0,1,128,128,0,96,135,7,0,16,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,2,0,192,125,6,0,17,0,0,0,1,1,0,0,56,111,3,0,17,0,0,0,1,1,1,0,104,134,3,0,0,0,0,0,254,0,2,0,144,212,8,0,17,0,0,0,1,2,2,0,96,135,7,0,17,0,0,0,1,2,0,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,17,0,0,0,1,12,8,0,80,246,3,0,17,0,0,0,1,12,12,0,248,38,7,0,17,0,0,0,1,12,4,0,48,123,8,0,17,0,0,0,1,12,0,0,8,117,8,0,0,0,0,0,254,0,3,0,200,30,2,0,17,0,0,0,1,48,48,0,240,205,4,0,17,0,0,0,1,48,0,0,0,172,4,0,17,0,0,0,1,48,16,0,96,19,1,0,0,0,0,0,254,0,2,0,168,234,7,0,17,0,0,0,1,64,0,0,96,135,7,0,17,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,2,0,192,86,4,0,17,0,0,0,1,128,0,0,96,135,7,0,17,0,0,0,1,128,128,0,152,182,7,0,0,0,0,0,254,0,16,0,200,87,7,0,18,0,0,0,1,240,32,0,8,32,4,0,18,0,0,0,1,240,64,0,96,164,8,0,18,0,0,0,1,240,80,0,144,102,8,0,18,0,0,0,1,240,112,0,176,45,8,0,18,0,0,0,1,240,16,0,112,169,3,0,18,0,0,0,1,240,144,0,224,127,8,0,18,0,0,0,1,240,48,0,192,119,3,0,18,0,0,0,1,240,96,0,136,252,1,0,18,0,0,0,1,240,240,0,32,123,8,0,18,0,0,0,1,240,128,0,248,116,8,0,18,0,0,0,1,240,224,0,192,110,8,0,18,0,0,0,1,240,208,0,96,102,7,0,18,0,0,0,1,240,192,0,184,105,6,0,18,0,0,0,1,240,176,0,152,96,3,0,18,0,0,0,1,240,160,0,192,100,6,0,18,0,0,0,1,240,0,0,104,151,6,0,0,0,0,0,254,0,15,0,160,123,6,0,18,0,0,0,1,15,2,0,8,32,4,0,18,0,0,0,1,15,4,0,96,164,8,0,18,0,0,0,1,15,5,0,144,102,8,0,18,0,0,0,1,15,7,0,176,45,8,0,18,0,0,0,1,15,1,0,112,169,3,0,18,0,0,0,1,15,9,0,224,127,8,0,18,0,0,0,1,15,3,0,192,119,3,0,18,0,0,0,1,15,6,0,136,252,1,0,18,0,0,0,1,15,15,0,32,123,8,0,18,0,0,0,1,15,8,0,248,116,8,0,18,0,0,0,1,15,14,0,192,110,8,0,18,0,0,0,1,15,13,0,96,102,7,0,18,0,0,0,1,15,12,0,184,105,6,0,18,0,0,0,1,15,11,0,152,96,3,0,18,0,0,0,1,15,10,0,192,100,6,0,18,0,0,0,255,255,223,0,0,0,0,0,19,0,0,0,255,255,251,0,0,0,0,0,0,0,0,0,254,0,16,0,32,4,2,0,18,0,0,0,1,15,2,0,144,102,8,0,18,0,0,0,1,15,5,0,176,45,8,0,18,0,0,0,1,15,8,0,224,127,8,0,18,0,0,0,1,15,4,0,136,252,1,0,18,0,0,0,1,15,1,0,0,67,1,0,18,0,0,0,1,15,15,0,32,123,8,0,18,0,0,0,1,15,3,0,232,143,1,0,18,0,0,0,1,15,7,0,248,116,8,0,18,0,0,0,1,15,14,0,192,110,8,0,18,0,0,0,1,15,6,0,168,36,1,0,18,0,0,0,1,15,13,0,96,102,7,0,18,0,0,0,1,15,12,0,184,105,6,0,18,0,0,0,1,15,11,0,152,96,3,0,18,0,0,0,1,15,10,0,192,100,6,0,18,0,0,0,1,15,9,0,64,1,1,0,18,0,0,0,1,15,0,0,104,151,6,0,0,0,0,0,254,0,2,0,144,248,8,0,18,0,0,0,1,16,16,0,200,87,7,0,18,0,0,0,1,16,0,0,160,123,6,0,0,0,0,0,254,0,2,0,168,234,7,0,18,0,0,0,1,32,32,0,96,135,7,0,18,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,232,75,4,0,18,0,0,0,1,64,64,0,96,135,7,0,18,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,212,8,0,18,0,0,0,1,128,128,0,96,135,7,0,18,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,4,0,128,129,4,0,19,0,0,0,1,3,3,0,8,49,4,0,19,0,0,0,1,3,2,0,152,21,4,0,19,0,0,0,1,3,1,0,72,246,3,0,19,0,0,0,1,3,0,0,64,47,7,0,0,0,0,0,254,0,2,0,200,30,2,0,19,0,0,0,1,4,0,0,120,97,1,0,19,0,0,0,1,4,4,0,96,19,1,0,0,0,0,0,254,0,4,0,64,37,5,0,19,0,0,0,1,24,24,0,64,185,8,0,19,0,0,0,1,24,16,0,8,176,8,0,19,0,0,0,1,24,8,0,232,140,2,0,19,0,0,0,1,24,0,0,208,129,2,0,0,0,0,0,254,0,4,0,72,202,5,0,19,0,0,0,1,96,64,0,80,246,3,0,19,0,0,0,1,96,96,0,248,38,7,0,19,0,0,0,1,96,32,0,48,123,8,0,19,0,0,0,1,96,0,0,8,117,8,0,0,0,0,0,9,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,200,73,5,0,9,0,0,0,1,3,3,0,120,198,7,0,9,0,0,0,1,3,2,0,16,150,7,0,9,0,0,0,1,3,1,0,160,103,7,0,9,0,0,0,1,3,0,0,16,53,7,0,10,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,4,0,32,4,2,0,10,0,0,0,1,3,2,0,160,36,8,0,10,0,0,0,1,3,3,0,208,239,7,0,10,0,0,0,1,3,0,0,16,79,1,0,10,0,0,0,1,3,1,0,120,187,7,0,0,0,0,0,254,0,4,0,128,129,4,0,10,0,0,0,1,12,12,0,8,49,4,0,10,0,0,0,1,12,8,0,152,21,4,0,10,0,0,0,1,12,4,0,72,246,3,0,10,0,0,0,1,12,0,0,64,47,7,0,0,0,0,0,254,0,4,0,72,202,5,0,10,0,0,0,1,48,48,0,80,246,3,0,10,0,0,0,1,48,32,0,80,124,6,0,10,0,0,0,1,48,16,0,112,212,3,0,10,0,0,0,1,48,0,0,248,160,5,0,12,0,0,0,255,255,128,0,0,0,0,0,13,0,0,0,255,255,247,0,0,0,0,0,14,0,0,0,255,255,151,0,0,0,0,0,0,0,0,0,254,0,2,0,232,75,4,0,12,0,0,0,1,128,128,0,96,135,7,0,12,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,13,0,0,0,1,3,3,0,80,246,3,0,13,0,0,0,1,3,0,0,80,124,6,0,13,0,0,0,1,3,1,0,112,212,3,0,13,0,0,0,1,3,2,0,248,160,5,0,0,0,0,0,254,0,2,0,168,234,7,0,13,0,0,0,1,8,8,0,96,135,7,0,13,0,0,0,1,8,0,0,152,182,7,0,0,0,0,0,254,0,2,0,72,4,1,0,13,0,0,0,1,16,16,0,96,135,7,0,13,0,0,0,1,16,0,0,152,182,7,0,0,0,0,0,254,0,2,0,32,150,8,0,13,0,0,0,1,32,32,0,96,135,7,0,13,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,200,30,2,0,13,0,0,0,1,128,128,0,120,97,1,0,13,0,0,0,1,128,0,0,96,19,1,0,0,0,0,0,254,0,8,0,32,4,2,0,14,0,0,0,1,7,4,0,144,102,8,0,14,0,0,0,1,7,2,0,176,45,8,0,14,0,0,0,1,7,6,0,224,127,8,0,14,0,0,0,1,7,7,0,32,123,8,0,14,0,0,0,1,7,1,0,248,116,8,0,14,0,0,0,1,7,3,0,192,110,8,0,14,0,0,0,1,7,5,0,96,102,7,0,14,0,0,0,1,7,0,0,104,151,6,0,0,0,0,0,254,0,8,0,64,37,5,0,14,0,0,0,1,56,32,0,184,45,5,0,14,0,0,0,1,56,24,0,24,144,3,0,14,0,0,0,1,56,16,0,232,15,5,0,14,0,0,0,1,56,48,0,88,97,3,0,14,0,0,0,1,56,56,0,136,81,3,0,14,0,0,0,1,56,8,0,112,67,3,0,14,0,0,0,1,56,40,0,152,52,3,0,14,0,0,0,1,56,0,0,120,7,5,0,0,0,0,0,254,0,4,0,128,129,4,0,14,0,0,0,1,192,0,0,208,75,4,0,14,0,0,0,1,192,128,0,8,49,4,0,14,0,0,0,1,192,64,0,152,21,4,0,14,0,0,0,1,192,192,0,72,246,3,0,16,0,0,0,255,255,1,0,0,0,0,0,17,0,0,0,255,255,203,0,0,0,0,0,0,0,0,0,254,0,2,0,200,30,2,0,16,0,0,0,1,1,0,0,96,19,1,0,16,0,0,0,1,1,1,0,120,97,1,0,0,0,0,0,254,0,2,0,232,75,4,0,17,0,0,0,1,1,1,0,96,135,7,0,17,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,4,0,64,37,5,0,17,0,0,0,1,6,2,0,80,113,6,0,17,0,0,0,1,6,4,0,152,53,6,0,17,0,0,0,1,6,6,0,112,216,4,0,17,0,0,0,1,6,0,0,120,7,5,0,0,0,0,0,254,0,8,0,72,202,5,0,17,0,0,0,1,56,16,0,152,184,1,0,17,0,0,0,1,56,40,0,176,177,1,0,17,0,0,0,1,56,0,0,216,170,1,0,17,0,0,0,1,56,24,0,56,162,1,0,17,0,0,0,1,56,48,0,112,155,1,0,17,0,0,0,1,56,8,0,248,143,1,0,17,0,0,0,1,56,32,0,248,130,1,0,17,0,0,0,1,56,56,0,48,117,1,0,0,0,0,0,254,0,4,0,32,4,2,0,17,0,0,0,1,192,64,0,224,127,8,0,17,0,0,0,1,192,192,0,32,123,8,0,17,0,0,0,1,192,128,0,192,110,8,0,17,0,0,0,1,192,0,0,104,151,6,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,21,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,8,0,200,87,7,0,20,0,0,0,1,7,0,0,144,102,8,0,20,0,0,0,1,7,1,0,176,45,8,0,20,0,0,0,1,7,2,0,224,127,8,0,20,0,0,0,1,7,7,0,32,123,8,0,20,0,0,0,1,7,6,0,192,110,8,0,20,0,0,0,1,7,5,0,96,102,7,0,20,0,0,0,1,7,4,0,184,105,6,0,20,0,0,0,1,7,3,0,152,96,3,0,0,0,0,0,254,0,8,0,160,123,6,0,20,0,0,0,1,56,0,0,144,102,8,0,20,0,0,0,1,56,8,0,176,45,8,0,20,0,0,0,1,56,16,0,224,127,8,0,20,0,0,0,1,56,56,0,32,123,8,0,20,0,0,0,1,56,48,0,192,110,8,0,20,0,0,0,1,56,40,0,96,102,7,0,20,0,0,0,1,56,32,0,184,105,6,0,20,0,0,0,1,56,24,0,152,96,3,0,0,0,0,0,254,0,2,0,200,30,2,0,20,0,0,0,1,64,64,0,120,97,1,0,20,0,0,0,1,64,0,0,96,19,1,0,0,0,0,0,254,0,2,0,144,212,8,0,20,0,0,0,1,128,128,0,96,135,7,0,20,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,254,0,4,0,72,202,5,0,21,0,0,0,1,3,1,0,80,246,3,0,21,0,0,0,1,3,3,0,80,124,6,0,21,0,0,0,1,3,2,0,112,212,3,0,21,0,0,0,1,3,0,0,248,160,5,0,0,0,0,0,254,0,2,0,168,234,7,0,21,0,0,0,1,4,0,0,96,135,7,0,21,0,0,0,1,4,4,0,152,182,7,0,0,0,0,0,254,0,4,0,64,37,5,0,21,0,0,0,1,48,16,0,160,39,6,0,21,0,0,0,1,48,0,0,160,30,6,0,21,0,0,0,1,48,48,0,208,16,1,0,21,0,0,0,1,48,32,0,88,12,1,0,0,0,0,0,254,0,4,0,128,129,4,0,21,0,0,0,1,192,192,0,208,75,4,0,21,0,0,0,1,192,128,0,8,49,4,0,21,0,0,0,1,192,64,0,152,21,4,0,21,0,0,0,1,192,0,0,112,49,6,0,20,0,0,0,255,255,128,0,0,0,0,0,0,0,0,0,254,0,2,0,136,109,2,0,20,0,0,0,1,128,128,0,248,96,3,0,20,0,0,0,1,128,0,0,16,81,3,0,18,0,0,0,255,255,255,0,0,0,0,0,19,0,0,0,255,255,90,0,0,0,0,0,20,0,0,0,255,255,255,0,0,0,0,0,18,0,0,0,254,0,16,0,200,87,7,0,18,0,0,0,1,15,2,0,80,252,6,0,18,0,0,0,1,15,5,0,16,242,7,0,18,0,0,0,1,15,8,0,104,236,7,0,18,0,0,0,1,15,4,0,120,113,6,0,18,0,0,0,1,15,1,0,232,228,5,0,18,0,0,0,1,15,15,0,128,230,7,0,18,0,0,0,1,15,3,0,56,141,7,0,18,0,0,0,1,15,7,0,120,211,6,0,18,0,0,0,1,15,14,0,184,164,6,0,18,0,0,0,1,15,6,0,24,1,7,0,18,0,0,0,1,15,13,0,80,74,6,0,18,0,0,0,1,15,12,0,192,32,6,0,18,0,0,0,1,15,11,0,192,234,2,0,18,0,0,0,1,15,10,0,32,242,5,0,18,0,0,0,1,15,9,0,176,192,2,0,18,0,0,0,1,15,0,0,16,227,4,0,18,0,0,0,254,0,15,0,160,123,6,0,18,0,0,0,1,240,32,0,80,252,6,0,18,0,0,0,1,240,80,0,16,242,7,0,18,0,0,0,1,240,128,0,104,236,7,0,18,0,0,0,1,240,64,0,120,113,6,0,18,0,0,0,1,240,16,0,232,228,5,0,18,0,0,0,1,240,240,0,128,230,7,0,18,0,0,0,1,240,48,0,56,141,7,0,18,0,0,0,1,240,112,0,120,211,6,0,18,0,0,0,1,240,224,0,184,164,6,0,18,0,0,0,1,240,96,0,24,1,7,0,18,0,0,0,1,240,208,0,80,74,6,0,18,0,0,0,1,240,192,0,192,32,6,0,18,0,0,0,1,240,176,0,192,234,2,0,18,0,0,0,1,240,160,0,32,242,5,0,18,0,0,0,1,240,144,0,176,192,2,0,19,0,0,0,254,0,4,0,128,129,4,0,19,0,0,0,1,3,3,0,208,75,4,0,19,0,0,0,1,3,2,0,8,49,4,0,19,0,0,0,1,3,1,0,72,246,3,0,19,0,0,0,1,3,0,0,64,47,7,0,19,0,0,0,254,0,4,0,64,37,5,0,19,0,0,0,1,24,24,0,176,123,2,0,19,0,0,0,1,24,16,0,8,192,1,0,19,0,0,0,1,24,8,0,112,216,4,0,19,0,0,0,1,24,0,0,8,49,6,0,19,0,0,0,254,0,4,0,72,202,5,0,19,0,0,0,1,96,96,0,80,246,3,0,19,0,0,0,1,96,64,0,248,38,7,0,19,0,0,0,1,96,32,0,112,212,3,0,19,0,0,0,1,96,0,0,248,160,5,0,19,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,128,128,0,96,135,7,0,19,0,0,0,1,128,0,0,152,182,7,0,20,0,0,0,254,0,2,0,144,212,8,0,20,0,0,0,1,1,1,0,96,135,7,0,20,0,0,0,1,1,0,0,152,182,7,0,20,0,0,0,254,0,2,0,232,75,4,0,20,0,0,0,1,4,4,0,96,135,7,0,20,0,0,0,1,4,0,0,152,182,7,0,20,0,0,0,254,0,2,0,160,94,8,0,20,0,0,0,1,8,0,0,96,39,8,0,20,0,0,0,1,8,8,0,80,242,7,0,0,0,0,0,12,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,254,0,16,0,200,87,7,0,12,0,0,0,1,15,2,0,80,252,6,0,12,0,0,0,1,15,5,0,16,242,7,0,12,0,0,0,1,15,8,0,104,236,7,0,12,0,0,0,1,15,4,0,120,113,6,0,12,0,0,0,1,15,1,0,232,228,5,0,12,0,0,0,1,15,15,0,80,245,6,0,12,0,0,0,1,15,3,0,56,141,7,0,12,0,0,0,1,15,7,0,120,211,6,0,12,0,0,0,1,15,14,0,8,201,6,0,12,0,0,0,1,15,6,0,24,1,7,0,12,0,0,0,1,15,13,0,200,197,6,0,12,0,0,0,1,15,12,0,152,194,6,0,12,0,0,0,1,15,11,0,128,95,7,0,12,0,0,0,1,15,10,0,248,189,6,0,12,0,0,0,1,15,9,0,208,114,5,0,12,0,0,0,1,15,0,0,16,227,4,0,0,0,0,0,254,0,15,0,160,123,6,0,12,0,0,0,130,240,32,0,80,252,6,0,12,0,0,0,0,15,0,0,0,0,0,0,12,0,0,0,130,240,80,0,16,242,7,0,12,0,0,0,0,15,0,0,0,0,0,0,12,0,0,0,130,240,128,0,104,236,7,0,12,0,0,0,0,15,0,0,0,0,0,0,12,0,0,0,130,240,64,0,120,113,6,0,12,0,0,0,0,15,0,0,0,0,0,0,12,0,0,0,130,240,16,0,232,228,5,0,12,0,0,0,0,15,0,0,0,0,0,0,12,0,0,0,130,240,240,0,80,245,6,0,12,0,0,0,0,15,0,0,0,0,0,0,12,0,0,0,130,240,48,0,56,141,7,0,12,0,0,0,0,15,0,0,0,0,0,0,12,0,0,0,130,240,112,0,120,211,6,0,12,0,0,0,0,15,0,0,0,0,0,0,12,0,0,0,130,240,224,0,8,201,6,0,12,0,0,0,0,15,0,0,0,0,0,0,12,0,0,0,130,240,96,0,24,1,7,0,12,0,0,0,0,15,0,0,0,0,0,0,12,0,0,0,130,240,208,0,200,197,6,0,12,0,0,0,0,15,0,0,0,0,0,0,12,0,0,0,130,240,192,0,152,194,6,0,12,0,0,0,0,15,0,0,0,0,0,0,12,0,0,0,130,240,176,0,128,95,7,0,12,0,0,0,0,15,0,0,0,0,0,0,12,0,0,0,130,240,160,0,248,189,6,0,12,0,0,0,0,15,0,0,0,0,0,0,12,0,0,0,130,240,144,0,208,114,5,0,12,0,0,0,0,15,0,0,0,0,0,0,13,0,0,0,255,255,123,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,13,0,0,0,1,3,3,0,8,49,4,0,13,0,0,0,1,3,2,0,152,21,4,0,13,0,0,0,1,3,1,0,72,246,3,0,13,0,0,0,1,3,0,0,240,64,4,0,0,0,0,0,254,0,2,0,200,30,2,0,13,0,0,0,1,4,0,0,120,97,1,0,13,0,0,0,1,4,4,0,96,19,1,0,0,0,0,0,254,0,2,0,64,37,5,0,13,0,0,0,1,8,8,0,192,173,3,0,13,0,0,0,1,8,0,0,80,230,3,0,0,0,0,0,254,0,8,0,72,202,5,0,13,0,0,0,1,112,112,0,144,29,4,0,13,0,0,0,1,112,96,0,208,75,4,0,13,0,0,0,1,112,80,0,8,49,4,0,13,0,0,0,1,112,64,0,152,21,4,0,13,0,0,0,1,112,48,0,72,246,3,0,13,0,0,0,1,112,32,0,72,0,3,0,13,0,0,0,1,112,16,0,64,47,7,0,13,0,0,0,1,112,0,0,128,37,3,0,0,0,0,0,254,0,2,0,168,234,7,0,13,0,0,0,1,128,128,0,96,135,7,0,13,0,0,0,1,128,0,0,152,182,7,0,0,0,0,0,18,0,0,0,255,255,255,0,0,0,0,0,19,0,0,0,255,255,253,0,0,0,0,0,0,0,0,0,254,0,4,0,128,129,4,0,18,0,0,0,1,3,2,0,208,75,4,0,18,0,0,0,1,3,3,0,8,49,4,0,18,0,0,0,1,3,1,0,152,21,4,0,18,0,0,0,1,3,0,0,72,246,3,0,0,0,0,0,254,0,2,0,72,202,5,0,18,0,0,0,1,4,4,0,248,38,7,0,18,0,0,0,1,4,0,0,112,212,3,0,0,0,0,0,254,0,2,0,168,91,8,0,18,0,0,0,1,8,8,0,248,81,6,0,18,0,0,0,1,8,0,0,176,64,8,0,0,0,0,0,254,0,16,0,32,4,2,0,18,0,0,0,1,240,160,0,8,32,4,0,18,0,0,0,1,240,176,0,96,164,8,0,18,0,0,0,1,240,192,0,144,102,8,0,18,0,0,0,1,240,208,0,176,45,8,0,18,0,0,0,1,240,16,0,112,169,3,0,18,0,0,0,1,240,224,0,224,127,8,0,18,0,0,0,1,240,32,0,192,119,3,0,18,0,0,0,1,240,48,0,136,252,1,0,18,0,0,0,1,240,240,0,32,123,8,0,18,0,0,0,1,240,64,0,248,116,8,0,18,0,0,0,1,240,144,0,192,110,8,0,18,0,0,0,1,240,128,0,96,102,7,0,18,0,0,0,1,240,112,0,184,105,6,0,18,0,0,0,1,240,96,0,152,96,3,0,18,0,0,0,1,240,80,0,192,100,6,0,18,0,0,0,1,240,0,0,104,151,6,0,0,0,0,0,254,0,2,0,144,212,8,0,19,0,0,0,1,1,1,0,96,135,7,0,19,0,0,0,1,1,0,0,152,182,7,0,0,0,0,0,254,0,2,0,200,30,2,0,19,0,0,0,1,2,0,0,120,97,1,0,19,0,0,0,1,2,2,0,96,19,1,0,0,0,0,0,254,0,2,0,96,46,8,0,19,0,0,0,1,4,4,0,208,233,4,0,19,0,0,0,1,4,0,0,72,197,4,0,0,0,0,0,254,0,2,0,168,234,7,0,19,0,0,0,1,8,0,0,96,135,7,0,19,0,0,0,1,8,8,0,152,182,7,0,0,0,0,0,254,0,2,0,104,159,3,0,19,0,0,0,1,16,0,0,96,135,7,0,19,0,0,0,1,16,16,0,152,182,7,0,0,0,0,0,254,0,2,0,88,63,8,0,19,0,0,0,1,32,32,0,96,135,7,0,19,0,0,0,1,32,0,0,152,182,7,0,0,0,0,0,254,0,2,0,144,246,3,0,19,0,0,0,1,64,64,0,96,135,7,0,19,0,0,0,1,64,0,0,152,182,7,0,0,0,0,0,18,0,0,0,255,255,255,0,0,0,0,0,19,0,0,0,255,255,251,0,0,0,0,0,0,0,0,0,254,0,4,0,200,87,7,0,18,0,0,0,1,12,0,0,80,252,6,0,18,0,0,0,1,12,4,0,16,242,7,0,18,0,0,0,1,12,8,0,104,236,7,0,18,0,0,0,1,12,12,0,128,230,7,0,0,0,0,0,254,0,4,0,160,123,6,0,18,0,0,0,1,3,3,0,184,164,6,0,18,0,0,0,1,3,2,0,80,74,6,0,18,0,0,0,1,3,1,0,192,32,6,0,18,0,0,0,1,3,0,0,32,242,5,0,0,0,0,0,254,0,2,0,168,234,7,0,18,0,0,0,1,64,0,0,96,135,7,0,18,0,0,0,1,64,64,0,152,182,7,0,0,0,0,0,254,0,4,0,72,84,4,0,19,0,0,0,1,3,0,0,248,194,5,0,19,0,0,0,1,3,3,0,248,81,6,0,19,0,0,0,1,3,2,0,80,124,6,0,19,0,0,0,1,3,1,0,176,64,8,0,0,0,0,0,254,0,4,0,128,129,4,0,19,0,0,0,1,12,4,0,208,75,4,0,19,0,0,0,1,12,8,0,8,49,4,0,19,0,0,0,1,12,12,0,72,0,3,0,19,0,0,0,1,12,0,0,112,49,6,0,0,0,0,0,254,0,4,0,64,37,5,0,19,0,0,0,1,48,48,0,248,98,4,0,19,0,0,0,1,48,32,0,80,72,4,0,19,0,0,0,1,48,16,0,248,43,4,0,19,0,0,0,1,48,0,0,80,72,4,0,112,216,19,0,14,0,0,0,104,216,19,0,6,0,0,0,96,216,19,0,7,0,0,0,88,216,19,0,8,0,0,0,80,216,19,0,6,0,0,0,72,216,19,0,6,0,0,0,64,216,19,0,7,0,0,0,56,216,19,0,7,0,0,0,48,216,19,0,8,0,0,0,40,216,19,0,8,0,0,0,5,1,0,0,0,0,0,0,17,0,0,4,130,0,0,0,0,0,0,33,48,5,0,0,0,0,66,0,0,51,4,0,84,64,0,0,0,0,0,0,80,64,3,0,0,0,0,0,0,4,36,0,0,0,0,0,34,34,34,0,0,0,0,0,3,51,3,0,0,0,0,0,51,32,35,0,0,0,0,0,48,0,51,1,0,0,0,0,34,34,34,2,0,0,0,0,0,52,0,64,0,0,0,0,35,2,3,64,0,0,0,0,34,0,18,4,0,0,0,0,2,34,2,4,0,0,0,0,68,3,0,0,0,0,0,0,48,68,0,0,0,0,0,0,0,48,83,0,0,0,0,0,2,34,50,0,0,0,0,0,4,64,32,0,0,0,0,0,34,2,2,0,0,0,0,0,32,48,48,0,0,0,0,0,18,33,34,0,0,0,0,0,34,32,2,0,0,0,0,0,34,2,2,2,0,0,0,0,2,34,32,3,0,0,0,0,18,18,17,2,0,0,0,0,3,33,0,3,0,0,0,0,18,48,3,0,0,0,0,0,32,1,34,3,0,0,0,0,18,33,34,3,0,0,0,0,2,2,32,0,0,0,0,0,16,34,34,0,0,0,0,0,2,16,0,49,0,0,0,0,33,1,1,17,0,0,0,0,32,3,2,2,0,0,0,0,51,32,0,16,0,0,0,0,2,32,18,0,0,0,0,0,48,0,2,17,0,0,0,0,104,222,19,0,204,0,0,0,216,221,19,0,144,0,0,0,48,221,19,0,168,0,0,0,112,220,19,0,192,0,0,0,224,219,19,0,144,0,0,0,80,219,19,0,144,0,0,0,168,218,19,0,168,0,0,0,0,218,19,0,168,0,0,0,64,217,19,0,192,0,0,0,128,216,19,0,192,0,0,0,232,228,19,0,136,0,0,0,128,228,19,0,104,0,0,0,240,227,19,0,142,0,0,0,48,227,19,0,192,0,0,0,120,226,19,0,182,0,0,0,224,225,19,0,148,0,0,0,72,225,19,0,152,0,0,0,184,224,19,0,138,0,0,0,24,224,19,0,158,0,0,0,56,223,19,0,224,0,0,0,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57,58,59,60,61,62,63,64,65,66,67,68,69,70,71,0,0,0,0,2,2,2,2,4,4,4,4,6,6,6,6,16,16,18,18,20,20,22,32,34,22,32,34,22,22,32,32,34,34,0,0,0,0,0,0,1,0,0,0,0,1,1,1,1,1,1,1,1,1,1,2,10,1,1,1,1,1,1,1,1,1,1,2,10,12,1,1,1,1,1,1,1,1,1,2,10,11,1,1,1,1,1,1,1,1,1,2,7,8,9,1,1,1,1,1,1,1,1,2,7,8,8,1,1,1,1,1,1,1,1,2,7,8,8,9,1,1,1,1,1,1,1,2,7,8,8,8,1,1,1,1,1,1,1,2,3,4,4,4,5,1,1,1,1,1,1,2,3,4,4,4,4,1,1,1,1,1,1,2,3,4,4,4,4,5,1,1,1,1,1,2,3,4,4,4,4,4,1,1,1,1,1,2,3,4,4,4,4,4,5,1,1,1,1,2,3,4,4,4,4,4,4,1,1,1,1,2,3,4,4,4,4,4,4,5,1,1,1,2,3,4,4,4,4,4,4,4,1,1,1,2,3,4,4,4,4,4,4,4,5,1,1,2,3,4,4,4,4,4,4,4,4,1,1,2,3,4,4,4,4,4,4,4,4,5,1,2,3,4,4,4,4,4,4,4,4,4,4,2,3,4,4,4,4,4,4,4,4,4,4,6,0,0,0,0,0,0,2,6,8,8,10,12,12,14,14,16,18,20,22,24,26,28,30,32,34,36,38,40,42,44,46,48,50,88,90,92,94,96,98,100,102,104,106,108,110,112,114,116,118,120,122,124,126,126,126,128,130,134,134,138,138,138,138,138,138,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,89,77,50,54,49,50,0,0,89,77,50,54,49,48,0,0,0,0,0,0,0,0,0,0,89,77,50,54,48,56,0,0,0,0,0,0,191,1,0,0,192,1,0,0,63,4,0,0,64,4,0,0,127,27,0,0,128,27,0,0,255,28,0,0,0,29,0,0,127,31,0,0,128,31,0,0,255,31,0,0,136,8,8,8,0,136,22,118,153,184,34,58,132,60,177,84,16,169,152,50,128,51,154,167,74,180,88,188,21,41,138,151,155,68,172,128,18,222,19,27,192,88,200,17,10,162,26,160,0,152,11,147,158,146,10,136,190,20,27,152,8,161,74,193,48,217,51,152,16,137,23,26,130,41,55,12,131,80,154,36,26,131,16,35,25,179,114,138,22,16,10,147,112,153,35,153,2,32,145,24,2,65,171,36,24,129,153,74,232,40,154,153,161,47,168,157,144,8,204,163,29,202,130,11,216,8,185,9,188,184,0,190,144,27,202,0,155,138,168,145,15,179,61,184,49,11,165,10,17,161,72,146,16,80,145,48,35,9,55,57,162,114,137,146,48,131,28,150,40,185,36,140,161,49,173,169,19,156,186,168,11,191,184,155,202,136,219,184,25,252,146,10,186,137,171,184,171,216,8,173,186,51,157,170,131,58,192,64,185,21,57,162,82,137,2,99,136,19,35,3,82,2,84,0,17,35,35,53,32,1,68,65,128,36,64,169,69,25,129,18,129,2,17,33,25,2,97,138,19,58,16,18,35,139,55,24,145,36,16,129,52,32,5,50,130,83,32,20,51,49,52,82,0,67,50,19,82,34,19,82,17,67,17,50,50,50,34,2,19,18,137,34,25,129,129,8,168,8,139,144,27,186,138,155,185,137,202,185,171,202,155,202,185,171,218,153,172,187,155,172,170,186,172,171,154,170,170,186,184,169,186,153,169,154,160,138,169,8,138,169,0,153,137,136,152,8,153,0,137,128,8,152,0,136,136,128,144,128,144,128,129,153,8,136,153,9,0,26,168,16,154,136,8,10,138,137,153,168,152,169,153,153,169,153,170,138,170,155,138,154,169,154,186,153,154,170,153,137,169,153,152,154,152,136,9,137,9,8,8,9,24,24,0,18,0,17,17,17,18,18,33,33,34,34,34,34,34,34,50,49,50,49,50,50,33,49,33,50,33,18,0,128,128,128,128,128,128,128,10,220,20,11,186,188,1,15,245,47,135,25,201,36,27,161,49,153,144,50,50,254,131,72,168,169,35,25,188,145,2,65,222,129,40,168,10,177,114,218,35,188,4,25,184,33,138,3,41,186,20,33,11,192,67,8,145,80,147,15,134,26,145,24,33,203,39,10,161,66,140,169,33,16,8,171,148,42,218,2,139,145,9,152,174,128,169,2,10,233,33,187,21,32,190,146,66,9,169,17,52,8,18,10,39,41,161,82,18,142,146,40,146,43,209,35,191,129,16,153,168,10,196,59,185,176,0,98,207,146,41,146,43,177,28,178,114,170,136,17,24,128,19,158,3,24,176,96,161,40,136,8,4,16,143,150,25,144,1,9,200,80,145,138,1,171,3,80,186,157,147,104,186,128,34,203,65,188,146,96,185,26,149,74,200,32,136,51,172,146,56,131,9,128,22,9,41,208,84,140,162,40,145,137,147,96,205,133,27,161,73,144,138,128,52,12,201,20,25,152,160,64,169,33,217,52,10,169,16,35,203,37,170,37,155,19,205,22,9,160,128,1,25,144,136,33,172,51,139,216,39,59,184,129,49,128,175,151,10,130,10,160,33,137,138,162,50,141,187,135,25,33,201,188,69,9,144,9,161,36,26,208,16,8,17,169,33,232,96,169,20,12,209,50,171,4,12,129,144,41,131,155,1,143,151,11,130,24,136,186,6,57,200,35,188,4,9,146,8,26,187,116,140,129,24,129,157,131,65,205,129,64,154,144,16,18,156,161,104,216,51,156,145,1,18,190,2,9,18,153,154,54,10,176,48,136,163,45,18,188,3,58,17,189,8,200,98,128,139,216,35,56,249,18,8,153,145,33,153,133,47,178,48,144,136,217,83,172,130,25,145,32,204,150,41,201,36,137,128,153,18,8,24,136,153,35,171,115,203,51,159,4,43,177,8,3,27,201,33,50,250,51,219,2,51,174,185,84,139,161,32,137,144,17,136,9,152,35,190,55,141,129,32,170,52,187,19,24,185,64,177,24,131,142,178,114,188,130,48,169,154,36,139,39,14,145,32,144,8,176,50,185,33,176,172,69,154,161,80,169,128,10,38,155,17,187,35,113,203,18,16,184,64,169,165,57,192,48,178,32,170,186,118,28,193,72,152,128,24,129,170,35,156,162,50,172,154,67,156,18,173,130,114,188,0,130,57,209,58,184,53,155,16,64,249,34,10,192,81,185,130,24,152,163,121,208,32,136,9,1,153,130,17,56,252,51,9,200,64,169,17,41,170,148,58,194,74,192,137,82,188,17,8,9,184,113,169,8,168,98,141,146,16,0,158,148,56,186,19,136,144,74,226,48,186,2,0,25,217,98,187,4,11,163,104,185,33,136,157,4,16,140,200,98,153,170,36,26,128,154,20,155,38,140,146,48,185,9,163,113,187,16,25,130,57,219,2,68,159,16,7,255,124,60,49,198,196,187,127,127,123,130,138,77,95,124,62,68,210,179,160,25,27,108,129,40,196,161,28,75,24,0,42,162,10,124,42,0,1,137,152,72,138,60,40,42,91,62,58,26,59,61,75,59,74,8,42,26,44,74,59,130,153,60,93,41,43,57,11,35,171,26,76,121,163,1,193,42,10,56,167,185,18,31,41,8,130,161,8,169,66,170,149,179,144,129,9,212,26,128,27,7,184,18,142,73,129,146,211,144,161,42,2,225,163,153,2,179,148,179,176,244,152,147,144,19,225,129,153,56,145,166,211,153,148,193,131,177,146,152,73,196,178,164,163,208,26,48,186,89,2,212,160,164,162,138,1,0,183,168,24,42,43,30,35,200,26,0,57,160,24,146,79,45,90,16,137,129,42,139,106,2,9,179,141,72,27,128,25,52,248,41,10,123,42,40,129,12,2,30,41,9,18,194,148,225,24,152,2,196,137,145,26,32,169,2,27,72,142,32,136,45,8,89,27,2,163,177,138,30,88,128,194,182,136,145,136,17,161,163,226,1,176,25,17,9,244,136,9,136,25,137,18,241,42,40,140,37,153,164,152,57,161,0,208,88,170,89,1,12,0,43,0,8,137,107,105,144,1,144,152,18,179,243,160,137,2,59,12,80,169,78,107,25,40,9,162,8,47,32,136,146,138,17,196,147,241,24,136,17,242,128,146,168,2,168,183,179,163,160,136,26,64,226,145,25,136,24,145,131,193,181,146,169,198,144,1,194,129,152,3,240,0,44,42,146,44,131,31,58,41,0,184,112,171,105,24,137,16,13,18,11,136,74,58,155,112,168,40,47,42,58,27,133,136,139,106,41,0,145,145,27,124,41,1,136,144,25,43,43,0,57,168,94,33,137,145,9,58,111,42,24,24,139,80,137,43,25,73,136,41,245,137,8,9,18,170,21,176,130,172,56,0,63,129,16,176,73,162,129,58,200,135,144,196,163,153,25,131,225,132,226,162,144,128,147,181,196,179,161,10,24,146,196,160,147,12,58,24,1,30,32,177,130,140,3,181,46,130,25,178,27,27,107,76,25,18,139,90,17,12,58,44,24,61,8,42,92,24,0,136,61,41,128,42,9,0,122,10,16,11,105,152,16,129,63,0,24,25,145,183,154,40,138,72,146,243,162,136,152,135,161,136,128,129,149,209,163,27,28,57,16,161,42,11,122,75,128,19,193,209,43,42,133,178,162,147,178,211,128,209,24,8,8,183,152,129,63,1,136,1,226,0,154,89,8,16,195,153,132,169,165,145,145,145,128,181,148,192,1,152,9,132,176,128,122,8,24,144,168,106,28,57,42,183,152,25,16,42,161,16,189,57,24,45,57,63,16,63,1,9,25,10,56,140,64,179,180,147,173,32,43,212,129,195,176,57,160,35,216,4,177,155,167,26,146,8,165,136,129,226,1,184,1,129,193,199,144,146,128,161,151,160,162,130,184,24,0,156,120,152,131,11,11,50,125,25,16,161,25,9,10,120,168,16,27,41,41,26,20,47,136,74,27,16,16,171,121,13,73,24,160,2,31,25,58,43,17,138,136,121,138,32,73,155,88,11,40,24,169,58,125,0,41,136,130,61,26,56,186,21,9,170,81,139,131,60,138,88,27,181,1,187,80,25,153,36,202,33,27,162,135,168,177,104,161,166,162,168,41,139,36,180,226,146,138,0,25,147,181,180,177,129,177,3,154,130,167,144,214,160,128,27,41,1,164,225,24,10,42,41,146,199,168,129,25,137,48,16,224,48,184,16,12,26,121,27,167,128,160,0,11,40,24,177,133,30,0,32,169,24,24,28,19,188,21,153,46,18,0,225,0,11,59,33,144,6,201,42,73,10,24,32,209,60,8,0,131,201,65,142,24,8,2,160,9,164,123,144,25,42,16,42,168,113,186,16,74,14,34,178,178,27,140,120,26,181,147,169,27,73,25,41,163,198,136,170,50,13,27,34,8,194,24,185,121,63,1,16,169,132,28,9,33,176,167,10,153,80,12,129,40,139,72,46,0,8,153,56,91,136,20,169,8,17,170,114,193,179,9,138,5,145,242,129,161,9,2,242,146,153,26,73,128,197,144,144,24,9,18,161,242,129,152,198,145,160,17,160,148,180,242,129,139,3,128,210,147,168,136])
.concat([105,160,3,184,136,50,188,151,128,177,59,26,166,0,209,1,11,59,48,155,49,62,146,25,138,211,92,27,65,160,147,162,175,57,76,1,146,168,129,60,13,120,152,0,25,10,32,45,41,60,27,72,136,153,122,45,41,42,130,128,168,73,62,25,17,152,130,154,59,40,47,32,76,144,41,25,154,122,41,40,152,136,51,205,17,58,193,164,160,196,130,200,80,152,178,33,192,182,152,130,128,156,35,0,248,48,168,26,104,168,134,154,1,42,10,151,145,193,24,137,2,131,224,1,139,41,48,226,145,11,24,59,28,17,40,172,120,128,147,145,169,73,139,135,144,153,61,90,129,8,161,17,47,26,33,155,21,162,176,17,192,145,91,152,36,162,242,146,139,106,24,129,181,177,136,76,0,0,164,193,43,26,89,10,2,128,30,2,8,179,128,154,35,184,242,132,171,1,72,144,167,144,10,41,9,149,153,160,89,43,0,151,176,41,137,42,3,208,183,27,129,0,166,177,144,9,72,192,17,0,138,0,91,131,154,24,47,60,24,17,169,4,26,79,1,152,129,9,9,74,24,180,162,11,89,144,59,73,188,64,106,136,58,8,62,58,128,147,176,225,90,0,164,179,227,144,13,56,9,130,196,161,177,76,24,16,145,178,19,234,52,153,136,166,137,146,145,193,32,178,194,134,210,179,128,178,8,9,135,145,192,17,137,144,40,185,121,25,164,130,208,3,12,163,165,178,178,27,41,19,241,180,129,157,56,0,196,161,137,89,26,129,164,169,28,106,25,2,177,26,74,11,120,137,129,28,42,41,74,163,62,28,73,26,8,33,174,40,75,25,32,140,16,58,171,38,139,24,89,153,19,162,171,121,47,24,16,178,128,27,77,90,128,130,152,129,128,9,165,144,145,3,194,226,129,168,130,9,198,163,177,8,91,8,5,209,162,137,42,40,145,166,136,176,73,128,9,8,136,7,184,5,153,129,136,24,226,0,195,24,13,16,48,208,147,138,9,16,47,17,144,161,32,155,177,115,200,148,152,59,1,12,48,25,248,18,144,186,120,10,17,152,160,121,138,48,43,194,17,13,9,122,0,130,185,1,122,137,33,9,161,10,124,16,136,181,136,10,43,105,26,16,160,91,25,26,16,25,26,108,32,144,165,152,27,10,105,130,209,24,9,25,42,147,212,154,1,73,162,162,130,216,34,170,151,169,45,56,42,182,128,144,10,60,130,148,184,33,14,42,34,184,0,79,43,58,129,161,41,44,106,19,209,162,152,40,12,1,213,8,169,49,179,176,167,176,41,27,135,162,161,178,74,137,17,195,243,152,8,3,160,163,197,144,179,181,180,184,2,145,145,211,164,193,27,130,40,164,209,148,138,40,8,3,224,128,212,144,145,161,59,61,2,228,161,146,137,26,75,149,179,144,153,106,10,48,161,147,166,169,133,139,130,16,177,163,148,248,56,154,48,26,139,167,137,1,91,25,24,17,240,24,28,57,25,12,18,28,42,123,58,136,43,24,43,92,32,146,141,56,138,58,91,46,58,43,16,18,187,106,77,24,16,177,129,42,139,121,128,1,10,9,91,45,132,138,8,2,162,145,130,232,80,155,133,163,176,163,27,2,24,243,162,136,171,83,209,180,163,9,9,24,212,8,176,9,88,209,130,137,129,26,24,5,185,195,48,192,149,128,195,137,137,19,136,242,147,14,24,1,146,165,184,42,57,170,51,154,177,17,245,161,161,10,80,184,3,196,160,78,41,16,136,194,26,57,29,40,152,148,14,16,42,60,2,45,27,75,59,73,25,169,72,47,41,16,137,2,12,16,9,185,112,27,138,80,168,43,73,137,105,136,149,137,144,146,76,25,130,193,1,128,160,43,122,129,16,194,183,152,136,25,44,3,177,164,161,12,59,120,136,133,177,160,27,58,74,8,148,129,241,128,0,12,89,9,24,144,166,146,140,26,121,146,168,0,129,46,42,19,162,176,165,136,136,137,17,25,160,243,130,176,131,95,42,1,161,148,176,9,120,152,163,166,160,145,128,147,152,193,18,24,201,23,160,160,26,33,128,153,212,48,157,0,16,47,8,28,33,8,180,195,43,169,82,210,163,209,9,16,139,36,146,209,128,25,160,44,18,73,170,182,149,184,8,58,43,1,243,179,11,9,121,24,162,164,160,24,12,32,8,169,22,12,0,27,8,43,123,1,1,185,89,25,139,69,168,128,12,26,65,30,0,40,168,90,0,193,73,153,33,29,8,133,153,149,137,144,17,144,209,40,178,167,153,129,2,172,19,129,178,166,169,40,28,177,51,209,193,88,168,20,176,183,145,160,130,137,194,40,161,178,73,210,148,200,18,128,153,133,8,211,9,162,179,30,8,33,185,35,180,171,65,172,135,9,162,197,11,42,90,145,32,154,137,120,155,49,137,128,41,10,183,60,152,72,29,0,1,176,32,47,41,74,137,148,28,136,40,43,16,136,154,113,154,8,74,47,24,43,24,2,168,75,122,153,72,128,168,32,29,64,168,16,8,168,197,136,194,24,136,42,18,243,130,216,32,10,9,166,152,4,185,17,24,195,225,41,161,17,193,3,226,154,51,169,181,152,146,161,2,248,33,168,16,2,193,183,27,144,91,60,131,147,224,25,26,17,17,241,146,137,25,44,44,65,153,146,144,63,24,75,0,8,210,1,178,170,120,9,1,145,162,152,47,58,44,1,0,147,224,40,44,43,1,18,225,128,179,61,58,10,80,152,194,160,17,170,48,135,144,194,41,136,56,200,181,144,186,112,26,2,148,208,128,26,130,166,176,145,24,179,0,19,241,162,193,130,176,0,21,11,211,2,168,145,43,31,73,136,166,128,136,8,27,165,128,185,6,11,144,33,157,72,24,160,21,201,130,43,26,66,154,196,57,188,105,0,160,41,140,57,89,8,9,73,169,107,129,0,152,176,104,61,129,136,24,25,29,18,128,178,58,63,133,146,208,0,10,25,18,241,2,155,25,64,185,17,2,242,26,8,148,10,194,131,11,180,164,192,50,216,134,152,144,149,137,163,131,194,146,225,146,130,217,3,8,169,133,146,162,128,224,48,139,179,135,137,144,131,160,8,146,147,62,171,67,137,227,128,131,47,0,163,128,201,34,63,8,129,11,51,154,163,123,12,41,74,27,33,170,112,27,13,72,26,129,136,177,57,63,8,88,160,129,26,26,43,109,17,10,145,1,26,152,90,12,3,177,132,163,173,88,42,161,132,177,160,92,43,19,168,149,131,232,16,129,176,0,194,150,160,145,0,44,144,48,242,128,168,57,33,193,3,172,57,124,41,145,26,0,25,44,58,147,176,41,143,40,2,147,243,169,1,3,224,8,9,29,88,161,131,169,107,42,60,33,137,194,44,75,138,80,129,152,168,50,12,142,36,11,26,129,146,161,79,24,58,10,180,24,46,57,130,25,211,208,40,27,17,152,7,170,40,0,136,180,137,27,31,34,0,179,201,51,171,43,181,72,152,152,167,16,210,193,35,202,147,198,128,161,136,2,137,226,9,56,186,64,137,33,216,73,16,141,2,144,195,154,36,137,8,132,165,156,16,17,156,136,48,60,161,148,88,140,11,105,41,154,129,18,43,139,121,148,176,193,132,194,153,37,153,17,162,147,228,153,128,10,0,16,183,176,49,186,60,33,179,241,24,160,42,32,163,6,232,40,161,180,8,11,17,75,183,144,165,152,61,25,2,161,196,178,25,40,192,165,146,177,163,10,10,8,43,112,196,179,0,188,75,57,18,227,160,0,63,24,41,148,209,25,9,0,161,131,153,155,53,128,196,177,106,26,28,41,56,14,25,90,26,130,138,89,42,46,32,136,168,58,56,61,0,179,41,173,73,16,12,1,1,163,143,133,9,27,136,16,163,210,144,60,92,57,3,209,160,0,42,11,4,167,144,160,17,144,153,131,180,177,241,132,136,144,24,24,211,210,179,160,26,33,167,178,179,146,154,34,185,40,56,189,135,42,177,19,13,10,56,201,36,192,25,35,15,1,136,192,42,130,24,40,240,24,42,41,75,53,184,163,157,24,27,64,0,154,92,58,9,47,56,138,59,59,17,92,25,43,74,8,10,61,32,79,58,25,42,24,77,27,58,17,13,58,60,75,147,129,170,107,74,24,0,195,195,154,89,42,27,167,161,129,136,136,88,178,177,43,131,212,129,8,15,0,32,194,226,128,8,28,41,4,177,162,1,28,145,0,12,73,176,67,242,153,57,63,0,129,148,193,9,26,105,144,128,148,170,32,42,145,177,57,122,56,209,16,138,140,90,1,181,152,128,42,11,50,146,241,129,154,35,138,163,183,9,3,8,208,148,154,9,1,147,183,194,140,58,131,153,5,160,11,41,147,229,128,137,56,144,138,215,161,25,27,72,152,146,195,161,9,63,2,12,34,195,178,161,1,159,74,1,163,211,176,40,63,41,32,162,194,177,8,90,152,19,210,193,1,178,128,61,3,193,137,150,144,144,58,26,154,50,182,162,142,74,40,138,132,162,138,45,73,9,136,24,48,157,44,35,177,12,146,45,57,130,196,46,16,26,16,185,72,25,57,186,52,218,45,72,26,166,152,131,154,29,56,4,208,24,144,44,17,147,211,154,17,8,130,241,1,160,42,147,211,180,184,130,47,17,163,179,168,59,9,35,150,200,59,63,147,130,161,144,63,40,129,209,147,8,45,24,145,179,181,152,42,43,132,177,91,138,49,24,128,139,126,57,43,2,193,139,108,73,9,16,161,8,1,12,32,161,9,79,24,0,1,160,92,27,91,16,146,144,43,90,61,24,145,25,152,45,57,137,45,58,72,44,17,181,154,25,91,40,144,149,152,137,43,64,8,144,243,10,8,166,128,145,178,160,2,242,161,183,137,129,130,145,177,33,171,50,233,4,162,141,18,145,163,163,210,139,57,209,132,226,144,0,43,41,163,212,161,145,29,90,8,25,17,153,8,24,73,15,24,16,130,241,0,137,47,58,1,179,194,129,63,41,8,16,161,161,59,93,25,40,11,56,130,145,25,189,59,122,128,18,179,224,11,106,1,136,164,8,11,8,89,128,128,29,73,137,0,132,153,26,43,50,227,180,169,58,153,49,227,170,88,59,136,149,192,24,74,9,48,242,163,28,27,73,0,211,178,160,24,17,146,211,178,145,128,231,161,145,152,25,34,194,210,24,141,59,16,165,145,152,2,62,128,1,144,170,19,241,2,209,8,25,73,180,145,180,153,42,12,50,192,5,136,11,128,44,129,16,11,81,169,25,5,191,40,32,225,144,128,40,25,8,38,177,161,24,136,42,240,18,138,179,20,27,212,216,16,8,138,23,160,152,43,58,41,72,164,153,14,74,18,139,49,139,78,26,17,181,137,145,41,137,194,151,144,10,25,17,145,193,213,8,137,32,145,177,26,45,24,41,210,59,62,58,42,144,130,28,73,59,147,182,200,76,2,145,147,242,136,45,40,129,130,193,137,45,107,25,130,128,24,139,57,57,200,58,106,10,34,210,9,44,26,104,146,226,137,42,42,48,194,163,180,29,42,9,147,24,242,137,40,179,1,143,24,17,161,147,144,209,122,32,195,162,168,136,29,40,165,162,162,11,41,43,135,193,128,10,25,1,18,241,16,128,10,24,8,47,74,2,137,27,41,93,76,8,130,161,10,58,75,41,198,195,9,9,136,57,152,130,165,26,48,17,189,63,18,139,40,195,136,63,43,59,72,161,128,138,77,57,1,147,162,241,25,25,10,2,178,139,36,210,75,18,200,46,16,181,137,1,9,28,42,3,212,145,152,153,17,43,228,0,0,1,224,165,137,153,49,24,208,183,152,24,10,16,148,194,144,24,0,153,135,160,144,42,60,2,184,193,121,26,32,8,161,210,28,41,3,209,41,153,44,80,179,209,8,9,60,16,4,178,13,43,89,128,144,1,15,58,24,1,162,155,91,61,129,3,210,152,89,144,129,146,180,139,27,64,178,181,8,75,1,9,209,145,139,122,16,179,195,153,73,26,41,181,162,171,64,129,25,183,176,32,43,212,136,161,145,60,130,55,211,177,138,27,48,179,244,161,145,9,16,3,208,131,169,143,16,1,144,24,128,32,43,241,40,153,42,65,240,18,170,131,130,209,193,8,137,89,9,131,135,176,42,77,24,9,25,179,75,63,57,25,9,1,137,3,31,0,26,11,16,104,160,24,140,106,9,8,151,161,129,27,43,76,3,180,168,146,75,60,161,129,149,168,129,18,187,146,69,185,147,244,136,10,45,40,0,163,163,138,63,72,177,146,180,168,48,128,211,128,209,25,59,196,129,193,41,13,32,19,200,180,76,9,0,130,194,59,13,48,11,18,240,27,32,10,166,128,10,74,74,128,148,177,46,59,26,16,147,16,76,61,8,130,201,25,106,43,56,209,8,25,42,90,130,177,141,41,120,9,130,10,44,27,25,65,184,140,121,43,17,136,130,145,220,40,17,176,17,24,201,98,161,145,152,59,58,176,244,1,192,41,57,248,149,145,136,136,145,3,161,226,24,130,209,162,209,128,25,32,131,177,227,128,145,77,26,3,178,9,24,209,25,9,146,166,160,182,178,139,56,16,66,211,208,168,32,44,16,1,177,180,171,91,121,128,16,26,168,61,24,32,179,143,24,1,0,9,243,137,105,136,129,145,8,225,26,8,17,129,30,41,160,1,0,144,62,123,24,130,195,161,42,44,91,129,165,144,129,0,11,26,28,44,50,192,243,128,45,42,16,2,228,193,137,74,9,1,3,210,152,42,57,138,137,38,177,178,18,192,10,90,24,152,243,146,153,153,121,1,181,161,128,128,144,131,160,226,129,41,147,138,10,106,31,24,2,200,1,25,59,74,152,23,168,13,56,161,145,16,162,43,76,166,129,186,33,76,128,33,209,146,44,8,48,159,147,42,137,3,139,135,10,13,18,152,164,147,187,89,24,161,50,233,132,8,138,2,161,145,75,180,32,136,240,58,26,136,135,177,146,10,8,107,131,195,145,192,43,121,8,138,132,160,137,64,27,161,57,152,23,194,162,18,205,32,137,146,37,176,45,58,139,88,42,160,76,8,48,174,130,89,137,26,16,194,24,44,64,30,1,163,138,129,44,41,41,169,19,81,173,18,137,143,24,44,57,0,193,16,60,42,65,200,162,145,10,108,16,18,136,232,48,145,129,216,1,27,13,7,0,168,146,10,40,210,195,2,170,148,129,180,179,26,11,19,249,22,161,138,89,25,2,193,145,139,61,24,59,164,148,128,153,136,28,121,10,2,3,248,144,57,91,25,2,195,144,187,88,106,9,2,137,145,136,26,105,138,25,21,160,162,0,154,107,73,136,163,146,187,107,61,56,1,152,145,63,9,24,32,144,128,172,112,145,155,81,9,136,153,20,139,152,131,121,160,153,19,1,25,224,131,11,176,12,49,149,181,194,138,57,32,128,57,243,177,16,136,94,24,148,161,136,161,152,21,170,57,212,132,192,162,162,12,129,134,181,161,177,20,27,177,2,146,195,224,136,17,170,105,24,129,163,176,1,191,42,49,147,241,0,137,24,25,17,211,224,16,24,177,24,36,154,43,164,192,176,49,108,25,180,18,168,234,88,16,139,147,130,136,154,65,16,195,234,65,169,156,52,161,42,121,162,1,168,179,40,204,65,154,179,75,179,39,139,131,43,47,8,40,178,128,44,48,94,9,18,155,9,34,91,25,138,17,89,153,164,50,205,24,8,16,133,179,180,30,136,40,138,17,9,192,121,128,145,59,128,16,15,1,128,145,25,61,146,40,168,55,154,10,58,138,69,169,164,0,170,9,61,89,32,225,8,152,144,89,16,9,163,195,147,153,43,105,17,209,177,164,145,60,137,131,240,16,145,161,137,89,5,153,147,148,200,8,10,9,23,177,131,193,145,64,162,194,152,195,186,40,35,15,128,80,184,25,16,150,152,140,5,152,25,41,43,59,10,226,1,15,60,56,8,9,129,74,108,8,0,136,152,56,44,90,27,32,26,57,176,9,203,91,73,9,113,0,193,14,8,56,12,2,16,14,16,138,72,25,144,146,13,163,152,59,121,25,1,16,225,128,25,43,16,242,2,171,132,154,41,180,128,146,3,136,149,208,3,144,160,199,161,176,162,2,24,181,212,1,192,8,162,147,168,160,195,32,243,144,0,213,8,137,165,128,160,129,130,194,9,209,19,203,3,132,145,225,27,18,8,171,135,24,171,88,137,40,129,201,51,169,128,46,32,131,185,32,59,158,122,8,129,24,11,136,121,128,139,0,18,14,137,81,27,129,160,58,1,175,17,40,186,53,152,136,82,192,131,47,169,17,10,25,37,208,48,156,8,33,152,129,42,243,42,128,182,43,8,147,233,2,129,140,33,0,166,169,148,1,143,128,148,152,147,180,0,8,192,20,152,179,180,193,9,24,167,0,163,200,10,60,25,150,131,193,153,25,74,133,128,193,145,153,144,42,23,149,153,136,18,174,57,8,146,132,176,168,121,9,25,1,178,163,143,40,43,162,64,130,160,76,169,57,141,129,112,136,160,26,73,45,26,38,168,152,8,41,11,18,150,177,178,58,19,155,96,160,136,178,52,234,26,42,121,152,16,4,140,28,129,4,140,131,25,47,129,147,152,16,8,48,42,250,5,8,42,137,145,163,250,17,17,0,140,4,138,42,181,16,169,194,61,27,50,4,10,26,9,64,31,146,29,42,145,16,48,47,11,104,153,162,146,136,120,169,32,40,226,146,26,153,75,25,34,161,226,33,47,152,41,24,145,8,176,121,26,130,59,177,167,138,179,152,91,35,202,66,131,240,144,24,152,8,180,32,163,192,67,216,128,129,163,153,217,167,25,144,16,5,177,139,2,164,189,35,147,138,153,75,3,193,248,56,9,43,20,208,3,138,42,57,185,151,144,170,80,1,153,81,209,9,26,181,0,139,147,8,152,17,249,133,43,8,150,137,144,42,18,74,216,133,43,14,16,0,1,177,155,105,26,144,64,184,1,8,10,44,9,20,75,226,130,136,177,120,10,1,194,147,25,206,32,60,130,180,27,32,140,59,41,171,134,35,216,129,154,90,73,176,22,160,176,40,27,19,147,228,162,169,8,90,179,18,193,225,16,136,1,12,146,8,137,183,136,129,16,154,23,160,176,19,153,224,57,49,210,178,128,11,45,73,128,1,176,6,9,12,58,105,160,8,178,161,105,43,90,129,146,186,33,177,125,16,128,8,136,130,50,13,176,26,28,33,148,169,88,185,90,74,160,19,169,128,124,0,32,138,4,12,0,130,42,178,172,75,105,160,166,129,155,25,56,139,23,178,129,42,187,148,41,162,21,186,151,163,185,121,1,178,2,241,144,10,41,17,136,229,160,129,25,145,144,40,179,20,208,181,145,154,41,11,7,162,179,1,157,40,65,208,145,144,130,26,168,68,154,169,33,227,169,75,25,120,137,131,163,185,90,61,128,130,162,160,108,16,32,139,147,139,14,51,169,177,104,138,49,172,148,180,139,50,11,180,129,145,29,51,217,49,225,139,59,48,18,73,210,142,41,24,138,146,2,170,89,28,50,136,1,35,251,131,41,218,89,1,129,146,225,24,138,29,48,147,241,0,1,11,57,146,137,160,17,91,224,130,9,19,170,180,22,216,145,42,41,132,27,197,152,152,49,152,153,23,169,32,146,195,24,157,32,61,137,148,162,28,92,41,57,160,179,0,12,76,72,146,10,145,133,154,1,130,31,16,153,21,193,160,57,26,29,133,180,144,26,42,75,1,178,147,190,18,131,201,24,9,32,120,241,8,25,136,58,131,179,169,147,122,10,150,152,0,168,58,48,146,242,155,61,56,146,146,195,184,107,41,1,1,178,47,9,25,24,1,59,123,16,161,144,57,15,56,10,181,164,137,139,106,43,18,200,144,64,42,158,34,136,24,9,58,195,232,9,89,8,18,148,208,26,44,56,0,161,131,232,8,58,8,16,158,131,29,146,25,44,57,59,89,4,225,128,8,141,33,129,178,178,2,153,145,164,214,152,153,3,128,152,167,145,9,161,178,179,225,18,146,177,129,6,153,10,35,196,177,242,137,25,58,148,130,224,137,56,11,164,165,128,128,140,52,185,169,35,19,185,193,199,27,137,16,32,17,227,168,75,11,64,145,144,27,95,42,24,130,145,11,74,40,202,64,128,91,44,19,176,138,169,90,88,137,130,136,46,59,49,161,155,1,122,44,1,145,147,63,136,57,16,241,145,139,72,10,18,227,168,24,40,146,151,152,153,25,161,17,182,136,59,16,211,195,161,42,138,73,4,241,145,2,138,137,4,241,152,128,24,18,227,129,152,128,1,179,242,153,18,42,181,179,146,170,25,80,178,195,146,208,43,104,147,153,192,44,62,128,32,8,147,13,42,49,141,2,43,145,8,10,3,44,60,82,185,160,18,191,58,41,1,136,192,106,60,10,73,24,11,57,43,105,10,132,42,42,28,42,195,140,25,80,9,145,167,141,24,26,40,0,160,148,16,31,32,144,138,18,208,26,90,129,4,188,35,16,224,144,144,24,26,166,18,177,208,74,8,130,146,182,154,10,18,136,195,197,138,137,32,181,147,11,24,0,9,242,136,42,74,8,5,178,169,59,93,40,164,177,0,25,25,122,163,179,10,144,161,196,128,186,80,19,193,194,154,42,123,40,132,193,9,59,78,32,145,161,24,171,121,16,180,8,154,17,43,240,147,170,1,106,1,147,128,184,42,91,16,128,137,74,91,146,21,178,160,47,25,147,184,149,128,28,33,169,2,11,160,90,24,152,57,27,104,0,145,145,156,57,62,24,132,179,155,122,8,24,10,181,145,11,40,57,25,144,10,80,172,17,1,171,136,82,27,131,196,162,154,171,3,144,25,147,129,8,146,154,104,152,25,57,193,146,138,56,78,2,177,144,195,24,43,4,195,210,145,144,129,137,19,241,136,147,162,0,145,192,91,33,153,147,6,154,27,72,153,183,144,137,24,27,17,164,178,129,154,8,151,152,145,16,184,6,162,160,41,43,33,194,209,16,26,74,41,241,152,41,27,49,16,160,161,29,90,41,178,130,168,15,40,33,9,145,130,77,16,163,176,137,76,57,160,164,161,137,30,40,41,163,195,45,25,1,73,1,155,12,33,194,162,147,124,42,16,144,117,242,171,125,126,92,59,75,60,77,74,2,179,197,231,227,146,179,196,179,195,138,59,93,92,58,132,194,145,164,231,247,247,244,161,27,73,165,177,30,127,90,0,137,57,183,168,61,74,132,231,247,226,45,76,58,78,125,4,176,45,75,16,128,163,153,16,14,89,147,196,177,129,196,162,178,136,8,63,59,40,166,195,162,162,197,193,63,126,57,129,147,194,163,229,210,128,147,184,109,73,130,212,161,144,1,160,9,4,227,178,145,183,179,168,42,3,243,161,146,197,195,178,11,48,179,142,109,74,1,180,180,196,195,153,59,18,227,161,136,130,180,154,92,58,24,147,195,179,180,168,25,4,243,168,59,16,162,136,165,178,11,109,75,16,145,137,60,24,24,166,196,195,152,25,43,32,145,160,78,40,147,179,194,146,169,90,150,196,194,9,1,196,161,146,196,161,137,16,163,161,144,28,90,1,197,161,146,212,179,196,196,195,161,136,26,40,137,60,58,61,41,0,147,176,61,40,128,145,130,227,153,42,17,214,195,153,41,130,196,195,161,10,59,61,58,2,195,162,153,59,44,124,40,129,163,178,163,177,8,26,60,24,46,76,57,165,179,180,194,136,8,25,10,73,183,179,162,161,146,161,147,177,12,125,57,147,179,177,26,25,93,40,166,196,178,144,9,42,24,27,91,40,136,44,41,130,160,24,145,45,41,43,92,76,59,76,40,128,146,144,9,43,40,29,107,17,197,178,11,57,9,77,40,136,0,27,40,148,227,160,26,40,181,180,179,178,147,226,145,146,212,160,27,74,1,161,136,45,92,59,40,8,147,212,178,145,180,160,62,59,75,59,41,8,147,155,123,58,25,0,128,128,160,119,39,135,1,45,79,195,193,146,145,137,89,131,26,50,194,149,177,129,136,129,74,61,17,158,11,136,12,24,59,17,17,145,0,160,226,10,72,19,36,129,72,27,57,28,131,132,161,209,142,138,11,192,152,146,184,57,144,16,146,240,181,136,50,73,81,33,3,130,16,138,122,9,0,162,202,27,204,28,185,142,137,137,161,137,146,41,17,96,64,20,34,50,120,64,1,2,144,129,171,11,0,175,153,204,171,218,169,153,27,48,20,146,34,25,104,50,20,38,19,35,35,32,18,154,168,185,250,170,202,204,12,168,174,136,185,136,160,2,33,80,67,3,129,42,17,52,99,36,51,34,56,139,234,174,153,160,144,130,0,137,191,138,232,169,144,1,18,19,18,8,169,170,201,34,99,99,18,68,0,16,136,156,152,161,133,3,50,54,128,137,219,219,187,185,186,1,129,40,25,203,250,188,9,19,55,52,52,35,49,32,16,0,0,40,56,16,136,236,141,203,188,204,187,187,201,153,0,0,51,17,34,129,7,65,84,52,52,34,49,0,136,154,155,152,171,142,155,189,156,188,187,218,170,169,153,24,56,96,32,49,19,19,81,20,49,83,51,53,34,1,138,156,169,202,201,168,0,16,129,156,158,171,204,171,186,152,48,82,3,129,8,156,172,172,24,17,3,81,97,65,49,49,2,1,32,36,67,68,64,48,16,188,190,203,219,171,186,153,152,153,170,189,170,200,144,17,83,55,35,67,52,51,51,51,17,40,0,25,169,154,203,206,187,235,188,187,202,186,168,136,17,18,33,32,34,38,38,35,35,67,36,34,50,32,49,129,154,188,188,203,189,154,169,144,152,186,204,203,188,139,136,34,53,35,18,153,139,170,170,137,130,147,49,66,35,35,33,50,17,32,19,19,36,36,36,34,17,138,158,172,172,170,186,170,171,189,188,203,203,169,168,145,18,68,67,68,52,52,66,51,66,33,17,17,136,128,170,11,172,203,236,172,186,202,171,154,153,128,145,9,8,16,34,68,67,68,51,67,34,19,33,34,32,9,136,185,200,187,171,171,169,169,155,155,153,144,144,0,129,0,8,9,138,154,170,169,169,153,144,128,1,128,0,9,49,50,68,51,67,52,51,36,34,35,18,16,9,155,171,202,204,187,203,218,202,171,202,171,169,168,146,18,67,83,53,35,51,67,67,82,34,34,33,1,9,137,169,187,189,188,203,218,171,171,171,170,169,153,168,9,1,17,52,37,35,51,81,34,49,18,32,33,18,16,128,153,154,153,153,136,8,0,136,169,153,153,128,128,16,1,0,154,170,187,186,186,169,153,153,137,153,153,0,1,51,53,36,35,52,35,51,52,51,67,50,33,136,171,189,187,219,171,186,187,218,187,203,187,188,168,144,1,18,35,67,83,52,52,57,128,8,8,8,8,8,8,8,8,0,15,255,115,142,113,205,0,73,16,144,33,73,160,219,2,58,227,10,80,152,192,89,162,153,9,34,162,128,16,168,91,210,136,33,9,150,168,16,10,224,8,72,25,171,82,168,146,12,3,25,226,10,18,194,129,30,1,208,72,136,152,1,73,145,170,44,37,137,136,181,129,162,154,18,158,56,59,129,155,89,1,147,202,74,33,160,61,10,57,61,18,168,63,24,1,146,28,0,178,72,185,148,163,25,79,25,178,50,144,186,1,230,145,128,193,164,42,8,161,177,37,210,136,153,33,128,136,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,89,77,50,50,48,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,47,138,66,145,68,55,113,207,251,192,181,165,219,181,233,91,194,86,57,241,17,241,89,164,130,63,146,213,94,28,171,152,170,7,216,1,91,131,18,190,133,49,36,195,125,12,85,116,93,190,114,254,177,222,128,167,6,220,155,116,241,155,193,193,105,155,228,134,71,190,239,198,157,193,15,204,161,12,36,111,44,233,45,170,132,116,74,220,169,176,92,218,136,249,118,82,81,62,152,109,198,49,168,200,39,3,176,199,127,89,191,243,11,224,198,71,145,167,213,81,99,202,6,103,41,41,20,133,10,183,39,56,33,27,46,252,109,44,77,19,13,56,83,84,115,10,101,187,10,106,118,46,201,194,129,133,44,114,146,161,232,191,162,75,102,26,168,112,139,75,194,163,81,108,199,25,232,146,209,36,6,153,214,133,53,14,244,112,160,106,16,22,193,164,25,8,108,55,30,76,119,72,39,181,188,176,52,179,12,28,57,74,170,216,78,79,202,156,91,243,111,46,104,238,130,143,116,111,99,165,120,20,120,200,132,8,2,199,140,250,255,190,144,235,108,80,164,247,163,249,190,242,120,113,198,103,230,9,106,133,174,103,187,114,243,110,60,58,245,79,165,127,82,14,81,140,104,5,155,171,217,131,31,25,205,224,91,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,4,0,0,0,2,0,0,0,24,0,0,0,24,0,0,0,72,0,0,0,36,0,0,0,64,33,216,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,17,0,0,192,16,0,0,6,17,0,0,240,4,0,0,112,19,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,240,8,240,4,240,2,240,1,240,16,232,8,232,4,232,2,232,1,232,16,228,8,228,4,228,2,228,1,228,16,226,8,226,4,226,2,226,1,226,16,225,8,225,4,225,2,225,1,225,144,224,136,224,132,224,130,224,129,224,80,224,72,224,68,224,66,224,65,224,48,224,40,224,36,224,34,224,33,224,39,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,1,0,0,1,1,0,0,0,0,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,0,0,1,0,0,0,0,0,1,0,0,0,0,0,1,0,0,0,0,0,1,0,0,0,0,1,1,1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1,1,1,1,1,0,0,0,0,1,0,0,0,1,0,0,0,1,1,0,0,0,0,1,0,0,0,1,0,0,1,1,1,1,1,1,1,0,0,0,1,1,1,1,1,1,1,0,0,1,0,0,0,1,1,0,0,0,0,1,1,0,0,1,0,0,0,1,0,0,0,0,1,0,1,0,1,1,0,0,0,1,0,0,0,0,1,0,0,0,0,1,1,1,1,0,0,0,1,0,0,0,0,0,1,0,0,0,0,0,1,1,0,0,0,0,1,0,0,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,0,0,0,0,1,1,0,0,1,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,107,8,0,0,0,0,0,0,0,0,0,0,0,0,0,232,167,7,0,232,50,8,0,0,0,0,0,224,254,7,0,120,201,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,132,31,0,0,24,31,0,0,0,0,0,0,0,0,0,0,250,46,0,0,170,3,0,0,84,12,0,0,72,16,0,0,22,17,0,0,242,18,0,0,76,53,0,0,224,132,215,0,0,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,232,201,7,0,136,107,8,0,0,0,0,0,0,0,0,0,232,167,7,0,144,152,7,0,0,0,0,0,224,254,7,0,120,201,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,116,4,0,0,38,30,0,0,0,0,0,0,0,0,0,0,250,46,0,0,170,3,0,0,84,12,0,0,72,16,0,0,22,17,0,0,242,18,0,0,76,53,0,0,224,132,215,0,0,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,104,3,2,0,160,170,3,0,72,172,6,0,0,0,0,0,168,163,7,0,240,2,2,0,0,0,0,0,144,88,7,0,208,9,3,0,8,2,2,0,0,0,0,0,0,0,0,0,0,0,0,0,17,1,0,0,2,0,0,0,0,0,1,133,0,16,0,0,0,0,0,0,0,0,0,0,174,10,0,0,192,25,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,170,3,0,0,0,0,0,72,172,6,0,0,0,0,0,168,163,7,0,160,168,3,0,0,0,0,0,240,164,3,0,208,9,3,0,184,161,3,0,0,0,0,0,0,0,0,0,0,0,0,0,33,0,0,0,2,0,0,0,0,0,1,133,0,16,0,0,0,0,0,0,0,0,0,0,254,11,0,0,104,34,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,34,3,0,0,0,0,0,72,172,6,0,0,0,0,0,0,38,7,0,112,31,3,0,0,0,0,0,232,167,5,0,208,9,3,0,56,23,3,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,1,0,0,0,0,0,0,0,0,0,0,0,88,55,0,0,70,17,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,104,7,0,96,240,4,0,0,0,0,0,0,0,0,0,232,167,7,0,160,53,7,0,0,0,0,0,144,88,7,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,182,59,0,0,40,2,0,0,0,0,0,0,0,0,0,0,136,21,0,0,234,1,0,0,38,5,0,0,84,2,0,0,72,6,0,0,178,17,0,0,24,42,0,0,0,0,0,0,64,1,0,0,192,0,0,0,240,0,0,0,3,0,0,0,4,0,0,0,176,165,7,0,24,177,7,0,0,0,0,0,0,0,0,0,216,194,1,0,64,160,7,0,0,0,0,0,8,169,7,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,15,0,8,0,0,0,0,0,0,0,0,0,0,26,57,0,0,50,16,0,0,0,0,0,0,0,0,0,0,100,0,0,0,28,37,0,0,80,12,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,24,177,7,0,0,0,0,0,0,0,0,0,0,0,0,0,216,194,1,0,16,173,7,0,0,0,0,0,8,169,7,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,2,0,0,0,0,0,0,15,0,8,0,0,0,0,0,0,0,0,0,0,186,37,0,0,166,11,0,0,0,0,0,0,0,0,0,0,100,0,0,0,28,37,0,0,80,12,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,176,202,8,0,0,0,0,0,72,172,6,0,0,0,0,0,0,38,7,0,96,116,3,0,0,0,0,0,176,237,2,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,0,64,0,0,0,0,0,0,0,0,0,0,0,11,0,0,118,17,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,218,7,0,0,0,0,0,72,172,6,0,0,0,0,0,32,127,5,0,80,202,3,0,0,0,0,0,80,215,3,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,1,0,1,133,8,0,0,0,0,0,0,0,0,0,0,0,40,36,0,0,168,31,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,214,8,0,0,0,0,0,72,172,6,0,0,0,0,0,0,38,7,0,16,220,3,0,0,0,0,0,80,215,3,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,1,0,1,133,8,0,0,0,0,0,0,0,0,0,0,0,126,40,0,0,128,37,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,22,1,0,0,0,0,0,72,172,6,0,0,0,0,0,240,3,2,0,160,231,3,0,0,0,0,0,112,30,8,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,1,0,1,133,8,0,0,0,0,0,0,0,0,0,0,0,198,13,0,0,92,17,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,239,3,0,248,100,1,0,72,172,6,0,0,0,0,0,96,135,2,0,168,236,3,0,0,0,0,0,208,40,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,4,0,1,133,8,0,0,0,0,0,0,0,0,0,0,0,52,38,0,0,26,35,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,245,3,0,248,100,1,0,72,172,6,0,0,0,0,0,96,135,2,0,80,242,3,0,0,0,0,0,208,40,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,4,0,1,133,8,0,0,0,0,0,0,0,0,0,0,0,136,61,0,0,234,23,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,100,1,0,0,0,0,0,72,172,6,0,0,0,0,0,96,135,2,0,88,249,3,0,0,0,0,0,208,40,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,4,0,1,133,8,0,0,0,0,0,0,0,0,0,0,0,58,38,0,0,240,11,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,209,2,0,0,0,0,0,72,172,6,0,0,0,0,0,168,163,7,0,56,208,2,0,0,0,0,0,8,116,8,0,208,9,3,0,128,206,2,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,8,0,0,0,0,0,0,0,0,0,0,0,156,46,0,0,54,47,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,231,1,0,200,27,5,0,0,0,0,0,0,0,0,0,232,233,7,0,8,133,1,0,0,0,0,0,192,223,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,0,20,2,0,0,0,0,0,0,0,0,0,0,0,200,40,0,0,162,7,0,0,0,0,0,0,0,0,0,0,172,35,0,0,20,16,0,0,154,10,0,0,10,14,0,0,202,5,0,0,14,14,0,0,56,22,0,0,152,175,145,0,0,8,0,0,224,0,0,0,0,1,0,0])
.concat([3,0,0,0,4,0,0,0,88,245,2,0,200,27,5,0,0,0,0,0,0,0,0,0,232,233,7,0,152,91,2,0,0,0,0,0,192,223,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,20,2,0,0,0,0,0,0,0,0,0,0,0,202,7,0,0,48,25,0,0,0,0,0,0,0,0,0,0,172,35,0,0,20,16,0,0,154,10,0,0,10,14,0,0,202,5,0,0,14,14,0,0,56,22,0,0,152,175,145,0,0,8,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,200,27,5,0,0,0,0,0,0,0,0,0,0,0,0,0,232,233,7,0,56,98,6,0,0,0,0,0,192,223,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,0,20,2,0,0,0,0,0,0,0,0,0,0,0,78,38,0,0,138,29,0,0,0,0,0,0,0,0,0,0,172,35,0,0,20,16,0,0,154,10,0,0,10,14,0,0,202,5,0,0,14,14,0,0,56,22,0,0,152,175,145,0,0,8,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,56,69,2,0,240,73,2,0,72,172,6,0,0,0,0,0,104,129,6,0,64,68,2,0,0,0,0,0,216,70,2,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,80,1,5,64,0,0,0,0,0,0,0,0,0,0,0,10,2,0,0,228,30,0,0,0,0,0,0,0,0,0,0,80,4,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,73,2,0,0,0,0,0,72,172,6,0,0,0,0,0,104,129,6,0,112,72,2,0,0,0,0,0,216,70,2,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,80,1,5,64,0,0,0,0,0,0,0,0,0,0,0,128,46,0,0,170,22,0,0,0,0,0,0,0,0,0,0,80,4,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,160,1,0,0,0,0,0,72,172,6,0,0,0,0,0,96,135,2,0,8,157,3,0,0,0,0,0,88,155,3,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,4,0,1,133,0,0,8,0,0,0,0,0,0,0,0,0,20,26,0,0,152,22,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,41,7,0,192,59,7,0,0,0,0,0,0,0,0,0,64,164,6,0,8,37,7,0,0,0,0,0,40,34,7,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,0,15,0,1,0,0,0,0,0,0,0,0,0,0,138,58,0,0,56,43,0,0,0,0,0,0,0,0,0,0,56,54,0,0,170,58,0,0,98,5,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,120,30,7,0,192,59,7,0,0,0,0,0,0,0,0,0,64,164,6,0,120,27,7,0,0,0,0,0,40,34,7,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,0,15,0,1,0,0,0,0,0,0,0,0,0,0,198,39,0,0,28,22,0,0,0,0,0,0,0,0,0,0,56,54,0,0,170,58,0,0,98,5,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,192,59,7,0,0,0,0,0,0,0,0,0,0,0,0,0,64,164,6,0,136,53,7,0,0,0,0,0,72,48,7,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,0,15,0,1,0,0,0,0,0,0,0,0,0,0,82,35,0,0,228,26,0,0,0,0,0,0,0,0,0,0,58,56,0,0,170,58,0,0,98,5,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,200,164,2,0,0,0,0,0,72,172,6,0,0,0,0,0,168,163,7,0,216,161,2,0,0,0,0,0,32,0,1,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,0,128,0,0,0,0,0,0,0,0,0,0,48,27,0,0,32,36,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,231,6,0,0,0,0,0,72,172,6,0,0,0,0,0,168,163,7,0,240,174,3,0,0,0,0,0,112,30,8,0,208,9,3,0,48,173,3,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,1,0,1,133,2,0,0,0,0,0,0,0,0,0,0,0,38,5,0,0,62,44,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,132,7,0,0,0,0,0,72,172,6,0,0,0,0,0,168,163,7,0,72,41,3,0,0,0,0,0,80,126,7,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,1,0,1,133,0,64,0,0,0,0,0,0,0,0,0,0,246,25,0,0,68,43,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,88,6,0,0,0,0,0,0,0,0,0,0,0,0,0,96,159,4,0,40,43,6,0,0,0,0,0,64,246,3,0,160,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,2,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,230,35,0,0,116,27,0,0,0,0,0,0,0,0,0,0,64,34,0,0,0,0,0,0,200,6,0,0,128,2,0,0,38,9,0,0,62,9,0,0,130,37,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,4,0,0,0,3,0,0,0,0,111,5,0,240,3,6,0,0,0,0,0,0,0,0,0,216,194,1,0,248,78,5,0,0,0,0,0,48,49,5,0,120,201,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,20,3,0,0,192,11,0,0,0,0,0,0,0,0,0,0,30,20,0,0,0,0,0,0,154,9,0,0,72,16,0,0,22,17,0,0,242,18,0,0,76,53,0,0,224,132,215,0,0,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,240,3,6,0,0,0,0,0,0,0,0,0,0,0,0,0,216,194,1,0,32,176,5,0,0,0,0,0,120,138,5,0,120,201,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,172,30,0,0,154,15,0,0,0,0,0,0,0,0,0,0,30,20,0,0,0,0,0,0,154,9,0,0,72,16,0,0,22,17,0,0,242,18,0,0,76,53,0,0,224,132,215,0,0,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,216,46,1,0,0,64,5,0,0,0,0,0,0,0,0,0,232,167,7,0,88,235,8,0,0,0,0,0,176,170,8,0,120,201,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,104,2,0,0,178,45,0,0,0,0,0,0,0,0,0,0,42,19,0,0,194,5,0,0,30,5,0,0,72,16,0,0,22,17,0,0,242,18,0,0,76,53,0,0,224,132,215,0,0,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,144,12,4,0,0,0,0,0,72,172,6,0,0,0,0,0,144,47,2,0,144,9,4,0,0,0,0,0,208,40,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,0,0,4,0,0,0,0,0,0,0,0,0,156,57,0,0,82,39,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,39,2,0,0,0,0,0,72,172,6,0,0,0,0,0,0,38,7,0,168,38,2,0,0,0,0,0,248,37,2,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,65,0,0,0,2,0,0,0,0,0,1,133,0,8,0,0,0,0,0,0,0,0,0,0,74,37,0,0,86,34,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,44,1,0,120,225,4,0,0,0,0,0,0,0,0,0,200,190,7,0,248,232,8,0,0,0,0,0,192,223,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,20,0,8,0,0,0,0,0,0,0,0,0,0,66,33,0,0,64,28,0,0,0,0,0,0,0,0,0,0,222,57,0,0,102,37,0,0,130,11,0,0,152,17,0,0,62,14,0,0,138,14,0,0,42,35,0,0,104,175,145,0,0,4,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,113,8,0,24,246,1,0,72,172,6,0,0,0,0,0,0,38,7,0,184,105,8,0,0,0,0,0,128,145,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,133,4,0,0,0,0,0,0,0,0,0,0,0,198,7,0,0,90,13,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,246,1,0,0,0,0,0,72,172,6,0,0,0,0,0,0,38,7,0,184,119,8,0,0,0,0,0,128,145,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,4,0,0,0,0,0,0,0,0,0,0,0,86,50,0,0,26,13,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,90,3,0,152,135,3,0,0,0,0,0,0,0,0,0,104,174,7,0,96,75,3,0,0,0,0,0,144,84,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,11,0,8,0,0,0,0,0,0,0,0,0,0,10,52,0,0,32,37,0,0,0,0,0,0,0,0,0,0,68,17,0,0,204,3,0,0,62,11,0,0,82,3,0,0,246,2,0,0,152,1,0,0,92,6,0,0,144,173,145,0,0,2,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,135,3,0,0,0,0,0,0,0,0,0,0,0,0,0,104,174,7,0,64,112,3,0,0,0,0,0,168,183,7,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,3,11,0,8,0,0,0,0,0,0,0,0,0,0,136,44,0,0,218,5,0,0,0,0,0,0,0,0,0,0,68,17,0,0,48,6,0,0,62,11,0,0,82,3,0,0,246,2,0,0,152,1,0,0,92,6,0,0,144,173,145,0,0,2,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,188,1,0,16,190,1,0,72,172,6,0,0,0,0,0,48,57,5,0,32,188,1,0,32,205,1,0,136,203,1,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,4,0,0,2,0,0,0,0,0,1,5,0,0,1,0,0,0,0,0,0,0,0,0,88,24,0,0,246,14,0,0,0,0,0,0,0,0,0,0,208,59,0,0,168,4,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,190,1,0,0,0,0,0,72,172,6,0,0,0,0,0,48,57,5,0,24,189,1,0,32,205,1,0,136,203,1,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,4,0,0,2,0,0,0,0,0,1,5,0,0,1,0,0,0,0,0,0,0,0,0,12,11,0,0,70,21,0,0,0,0,0,0,0,0,0,0,208,59,0,0,168,4,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,173,1,0,0,0,0,0,72,172,6,0,0,0,0,0,56,187,1,0,144,173,1,0,0,0,0,0,56,173,1,0,112,183,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,0,0,2,0,0,0,0,0,1,5,0,0,1,0,0,0,0,0,0,0,0,0,148,1,0,0,150,24,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,116,7,0,184,110,7,0,0,0,0,0,0,0,0,0,64,164,6,0,48,104,7,0,0,0,0,0,40,98,7,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,15,0,8,0,0,0,0,0,0,0,0,0,0,44,52,0,0,186,46,0,0,0,0,0,0,0,0,0,0,248,26,0,0,28,50,0,0,180,3,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,160,96,1,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,248,95,1,0,0,0,0,0,80,25,7,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,4,55,0,0,90,11,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,192,98,1,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,184,97,1,0,0,0,0,0,176,241,1,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,86,25,0,0,16,24,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,200,100,1,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,192,99,1,0,0,0,0,0,80,25,7,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,144,62,0,0,120,20,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,72,103,1,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,184,101,1,0,0,0,0,0,80,25,7,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,28,24,0,0,0,12,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,80,140,1,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,136,138,1,0,0,0,0,0,80,25,7,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,114,25,0,0,20,43,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,64,104,1,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,176,48,2,0,0,0,0,0,80,25,7,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,238,35,0,0,6,34,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,160,105,1,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,56,51,2,0,0,0,0,0,80,25,7,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,164,58,0,0,98,5,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,104,107,1,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,56,54,2,0,0,0,0,0,80,25,7,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,128,54,0,0,26,16,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,48,108,1,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,56,63,2,0,0,0,0,0,80,25,7,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,186,3,0,0,74,29,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,24,109,1,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,184,65,2,0,0,0,0,0,80,25,7,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,44,15,0,0,72,7,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,216,109,1,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,56,67,2,0,0,0,0,0,80,25,7,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,58,0,0,0,150,13,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,216,113,1,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,184,111,1,0,0,0,0,0,144,110,1,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,206,36,0,0,148,24,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,192,116,1,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,24,115,1,0,0,0,0,0,80,25,7,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,34,4,0,0,136,4,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,184,120,1,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,16,118,1,0,0,0,0,0,80,25,7,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,176,7,0,0,164,10,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,104,122,1,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,200,121,1,0,0,0,0,0,176,241,1,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,112,6,0,0,120,44,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,8,125,1,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,184,123,1,0,0,0,0,0,80,25,7,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,170,56,0,0,36,19,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,16,127,1,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,192,125,1,0,0,0,0,0,80,25,7,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,10,44,0,0,198,26,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,144,130,1,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,248,128,1,0,0,0,0,0,80,25,7,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,92,47,0,0,222,37,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,24,134,1,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,128,132,2,0,0,0,0,0,80,25,7,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,152,5,0,0,0,21,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,48,135,1,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,200,133,2,0,0,0,0,0,80,25,7,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,178,50,0,0,82,20,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,136,136,1,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,120,150,2,0,0,0,0,0,80,25,7,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,56,39,0,0,88,18,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,184,142,1,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,88,141,1,0,0,0,0,0,64,32,1,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,214,51,0,0,148,32,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,160,143,1,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,144,176,2,0,0,0,0,0,176,241,1,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,162,33,0,0,216,42,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,200,145,1,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,168,144,1,0,0,0,0,0,80,25,7,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,244,0,0,0,184,40,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,80,146,1,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,64,186,2,0,0,0,0,0,248,1,2,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,174,37,0,0,194,1,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,56,148,1,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,0,190,2,0,0,0,0,0,200,146,1,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,186,42,0,0,98,6,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,16,149,1,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,176,148,1,0,0,0,0,0,80,25,7,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,38,35,0,0,190,13,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,168,137,1,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,48,164,2,0,0,0,0,0,80,25,7,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,60,34,0,0,252,47,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,112,153,1,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,232,150,1,0,0,0,0,0,176,241,1,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,174,47,0,0,10,46,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,176,157,1,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,56,156,1,0,0,0,0,0,80,25,7,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,54,10,0,0,50,1,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,200,154,1,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,136,251,2,0,0,0,0,0,80,25,7,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,180,4,0,0,90,42,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,8,159,1,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,128,158,1,0,0,0,0,0,80,25,7,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,112,48,0,0,156,34,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,120,159,1,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,16,76,3,0,0,0,0,0,80,25,7,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,112,47,0,0,152,29,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,160,159,1,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,64,145,3,0,0,0,0,0,208,230,1,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,226,57,0,0,240,10,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,192,160,1,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,208,159,1,0,0,0,0,0,80,25,7,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,140,46,0,0,148,10,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,192,161,1,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,64,161,1,0,0,0,0,0,80,25,7,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,212,35,0,0,12,38,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,168,163,1,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,160,187,3,0,0,0,0,0,80,25,7,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,46,60,0,0,214,27,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,24,166,1,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,216,165,1,0,0,0,0,0,80,25,7,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,232,33,0,0,246,3,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,232,166,1,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,168,166,1,0,0,0,0,0,80,25,7,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,42,9,0,0,74,8,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,96,183,1,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,168,182,1,0,0,0,0,0,192,181,1,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,72,30,0,0,6,19,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,88,171,1,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,72,249,3,0,0,0,0,0,80,25,7,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,6,41,0,0,110,19,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,136,170,1,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,64,242,3,0,0,0,0,0,80,25,7,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,248,59,0,0,150,20,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,176,172,1,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,32,73,4,0,0,0,0,0,80,25,7,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,102,14,0,0,204,37,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,128,173,1,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,32,173,1,0,0,0,0,0,80,25,7,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,80,26,0,0,62,36,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,176,173,1,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,168,217,4,0,0,0,0,0,80,25,7,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,222,14,0,0,94,9,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,64,177,1,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,144,47,2,0,64,239,4,0,0,0,0,0,176,241,1,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,38,62,0,0,182,12,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,72,176,1,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,72,175,1,0,0,0,0,0,80,25,7,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,124,55,0,0,194,17,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,64,174,1,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,248,173,1,0,0,0,0,0,80,25,7,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,136,39,0,0,2,21,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,24,178,1,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,120,51,5,0,0,0,0,0,160,200,5,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,144,37,0,0,182,46,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,24,179,1,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,56,57,5,0,0,0,0,0,80,25,7,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,144,6,0,0,10,5,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,104,180,1,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,176,179,1,0,0,0,0,0,80,25,7,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,214,53,0,0,198,30,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,160,185,1,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,48,184,1,0,0,0,0,0,80,25,7,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,96,17,0,0,152,44,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,112,181,1,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,200,180,1,0,0,0,0,0,248,1,2,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,250,24,0,0,124,15,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,40,187,1,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,120,186,1,0,0,0,0,0,80,25,7,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,174,13,0,0,106,36,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,176,187,1,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,216,179,5,0,0,0,0,0,176,241,1,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,198,57,0,0,196,37,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,168,188,1,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,16,188,1,0,0,0,0,0,80,25,7,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,98,21,0,0,54,27,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,48,165,1,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,144,164,1,0,0,0,0,0,176,241,1,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,160,1,0,0,172,7,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,0,190,1,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,8,189,1,0,0,0,0,0,176,241,1,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,58,22,0,0,238,47,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,216,191,1,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,16,191,1,0,0,0,0,0,80,25,7,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,182,22,0,0,90,34,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,16,229,1,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,184,227,1,0,240,117,1,0,80,25,7,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,98,25,0,0,182,14,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,200,192,1,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,120,186,6,0,0,0,0,0,80,25,7,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,126,46,0,0,134,35,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,136,193,1,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,168,209,6,0,0,0,0,0,80,25,7,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,230,44,0,0,118,11,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,32,195,1,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,56,194,1,0,0,0,0,0,176,241,1,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,22,33,0,0,218,25,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,176,195,1,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,216,42,7,0,0,0,0,0,80,25,7,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,158,27,0,0,68,23,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,128,202,1,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,16,78,7,0,0,0,0,0,80,25,7,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,180,2,0,0,62,37,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,136,197,1,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,176,196,1,0,0,0,0,0,80,25,7,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,142,4,0,0,124,21,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,104,201,1,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,16,199,1,0,0,0,0,0,80,25,7,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,164,6,0,0,66,45,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,8,206,1,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,0,205,1,0,0,0,0,0,80,25,7,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,38,32,0,0,60,3,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,128,207,1,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,224,206,1,0,0,0,0,0,80,25,7,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,176,21,0,0,166,43,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,88,209,1,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,168,208,1,0,0,0,0,0,176,241,1,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,0,31,0,0,52,4,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,120,203,1,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,216,145,7,0,0,0,0,0,80,25,7,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,170,29,0,0,92,19,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,176,212,1,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,168,210,1,0,0,0,0,0,80,25,7,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,28,10,0,0,164,0,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,8,217,1,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,8,215,1,0,0,0,0,0,176,241,1,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,240,24,0,0,24,21,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,240,218,1,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,0,83,8,0,0,0,0,0,80,25,7,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,162,8,0,0,70,5,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,112,220,1,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,232,219,1,0,0,0,0,0,80,25,7,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,112,40,0,0,144,14,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,80,222,1,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,240,220,1,0,0,0,0,0,80,25,7,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,58,45,0,0,64,32,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,224,225,1,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,80,223,1,0,0,0,0,0,80,25,7,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,130,53,0,0,48,19,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,128,132,1,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,16,128,2,0,0,0,0,0,176,241,1,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,106,11,0,0,98,46,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,120,232,1,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,216,1,1,0,32,254,8,0,208,230,1,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,38,33,0,0,14,19,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,24,234,1,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,40,233,1,0,0,0,0,0,80,25,7,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,228,52,0,0,230,25,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,72,235,1,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,160,234,1,0,0,0,0,0,80,25,7,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,80,24,0,0,16,22,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,112,243,1,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,240,242,1,0,0,0,0,0,176,241,1,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,30,58,0,0,198,38,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,40,237,1,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,32,236,1,0,0,0,0,0,80,25,7,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,230,48,0,0,222,46,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,200,240,1,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,112,239,1,0,0,0,0,0,80,25,7,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,32,58,0,0,252,22,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,192,244,1,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,88,241,1,0,0,0,0,0,248,1,2,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,192,44,0,0,86,1,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,16,244,1,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,200,177,1,0,0,0,0,0,80,25,7,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,220,61,0,0,98,9,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,168,245,1,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,104,245,1,0,0,0,0,0,80,25,7,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,246,4,0,0,220,10,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,192,249,1,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,200,246,1,0,0,0,0,0,80,25,7,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,92,25,0,0,56,23,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,208,253,1,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,72,251,1,0,0,0,0,0,80,25,7,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,242,48,0,0,26,30,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,168,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,176,4,4,0,0,0,0,0,80,25,7,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,84,53,0,0,244,45,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,152,4,2,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,80,3,8,0,0,0,0,0,80,25,7,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,10,0,0,0,0,30,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,192,169,1,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,64,168,1,0,0,0,0,0,176,241,1,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,204,53,0,0,14,30,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,160,1,2,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,128,228,6,0,0,0,0,0,80,25,7,0,184,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,2,23,0,0,1,0,0,0,0,0,226,52,0,0,224,26,0,0,10,8,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,184,6,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,16,161,3,0,0,0,0,0,0,0,0,0,0,0,0,0,160,135,3,0,104,112,3,0,64,90,3,0,152,75,3,0,208,138,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,3,11,32,0,0,0,0,0,0,0,0,0,0,0,100,16,0,0,198,27,0,0,0,0,0,0,0,0,0,0,70,14,0,0,14,1,0,0,230,4,0,0,20,7,0,0,122,3,0,0,24,18,0,0,236,62,0,0,152,173,145,0,0,2,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,209,1,0,0,0,0,0,72,172,6,0,0,0,0,0,136,232,4,0,184,208,1,0,0,0,0,0,144,81,5,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,4,0,0,2,0,0,0,0,0,1,5,0,0,1,0,0,0,0,0,0,0,0,0,160,60,0,0,6,8,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,151,4,0,112,178,4,0,72,172,6,0,0,0,0,0,144,33,2,0,24,149,4,0,0,0,0,0,192,154,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,133,8,0,0,0,6,0,0,0,0,0,0,0,244,53,0,0,102,0,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,102,16,0,0,16,11,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,156,4,0,112,178,4,0,72,172,6,0,0,0,0,0,144,33,2,0,120,153,4,0,0,0,0,0,192,154,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,133,8,0,0,0,6,0,0,0,0,0,0,0,0,59,0,0,140,41,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,178,10,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,162,4,0,112,178,4,0,72,172,6,0,0,0,0,0,144,33,2,0,64,158,4,0,0,0,0,0,192,154,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,133,8,0,0,0,6,0,0,0,0,0,0,0,18,8,0,0,78,43,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,126,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,182,4,0,192,187,4,0,0,0,0,0,0,0,0,0,144,33,2,0,128,180,4,0,0,0,0,0,32,215,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,48,3,4,5,8,0,0,0,6,0,0,0,0,0,0,0,104,49,0,0,98,17,0,0,0,0,0,0,0,0,0,0,208,59,0,0,20,43,0,0,126,19,0,0,16,11,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,187,4,0,0,0,0,0,0,0,0,0,0,0,0,0,144,33,2,0,208,184,4,0,0,0,0,0,32,215,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,48,1,4,5,8,0,0,0,6,0,0,0,0,0,0,0,94,38,0,0,236,14,0,0,0,0,0,0,0,0,0,0,208,59,0,0,20,43,0,0,126,19,0,0,16,11,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,170,4,0,112,178,4,0,72,172,6,0,0,0,0,0,144,33,2,0,240,165,4,0,0,0,0,0,192,154,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,133,8,0,0,0,6,0,0,0,0,0,0,0,28,55,0,0,144,28,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,216,2,0,0,16,11,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,178,4,0,0,0,0,0,72,172,6,0,0,0,0,0,144,33,2,0,88,174,4,0,0,0,0,0,32,215,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,48,3,1,133,8,0,0,0,6,0,0,0,0,0,0,0,30,23,0,0,46,36,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,126,19,0,0,16,11,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,137,6,0,0,0,0,0,0,0,0,0,0,0,0,0,232,233,7,0,88,93,6,0,0,0,0,0,40,46,6,0,120,201,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,20,38,0,0,32,4,0,0,0,0,0,0,0,0,0,0,164,30,0,0,60,33,0,0,36,9,0,0,72,16,0,0,22,17,0,0,242,18,0,0,76,53,0,0,224,132,215,0,0,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,24,169,3,0,224,2,4,0,0,0,0,0,0,0,0,0,64,171,7,0,88,143,3,0,120,155,4,0,176,170,8,0,120,201,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,152,26,0,0,2,39,0,0,0,0,0,0,0,0,0,0,254,40,0,0,236,40,0,0,230,9,0,0,72,16,0,0,22,17,0,0,242,18,0,0,76,53,0,0,224,132,215,0,0,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,224,2,4,0,0,0,0,0,0,0,0,0,0,0,0,0,64,171,7,0,0,195,3,0,120,155,4,0,176,170,8,0,120,201,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,90,2,0,0,220,34,0,0,0,0,0,0,0,0,0,0,254,40,0,0,236,40,0,0,230,9,0,0,72,16,0,0,22,17,0,0,242,18,0,0,76,53,0,0,224,132,215,0,0,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,64,110,8,0,0,0,0,0,72,172,6,0,0,0,0,0,0,38,7,0,48,106,3,0,0,0,0,0,176,237,2,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,0,64,0,0,0,0,0,0,0,0,0,0,138,16,0,0,6,24,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,56,7,0,32,255,7,0,0,0,0,0,0,0,0,0,184,168,7,0,184,11,7,0,0,0,0,0,128,145,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,110,46,0,0,218,4,0,0,0,0,0,0,0,0,0,0,238,44,0,0,156,4,0,0,10,15,0,0,62,7,0,0,96,4,0,0,26,8,0,0,134,11,0,0,216,175,145,0,0,8,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,255,7,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,16,202,7,0,0,0,0,0,128,145,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,250,15,0,0,186,24,0,0,0,0,0,0,0,0,0,0,238,44,0,0,184,62,0,0,228,4,0,0,62,7,0,0,96,4,0,0,26,8,0,0,134,11,0,0,216,175,145,0,0,8,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,225,6,0,32,255,7,0,0,0,0,0,0,0,0,0,184,168,7,0,112,181,6,0,0,0,0,0,128,145,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,104,5,0,0,214,7,0,0,0,0,0,0,0,0,0,0,238,44,0,0,156,4,0,0,10,15,0,0,62,7,0,0,96,4,0,0,26,8,0,0,134,11,0,0,216,175,145,0,0,8,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,152,7,0,32,255,7,0,0,0,0,0,0,0,0,0,184,168,7,0,208,106,7,0,0,0,0,0,128,145,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,26,61,0,0,164,29,0,0,0,0,0,0,0,0,0,0,238,44,0,0,184,62,0,0,10,15,0,0,62,7,0,0,96,4,0,0,26,8,0,0,134,11,0,0,216,175,145,0,0,8,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,149,7,0,168,102,8,0,0,0,0,0,0,0,0,0,96,159,4,0,112,102,7,0,0,0,0,0,176,51,7,0,160,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,4,33,0,0,180,7,0,0,0,0,0,0,0,0,0,0,82,31,0,0,92,15,0,0,56,14,0,0,128,2,0,0,38,9,0,0,62,9,0,0,130,37,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,3,0,0,0,4,0,0,0,224,8,7,0,168,102,8,0,0,0,0,0,0,0,0,0,96,159,4,0,96,222,6,0,0,0,0,0,192,154,4,0,160,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,214,10,0,0,238,12,0,0,0,0,0,0,0,0,0,0,82,31,0,0,92,15,0,0,56,14,0,0,128,2,0,0,38,9,0,0,62,9,0,0,130,37,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,3,0,0,0,4,0,0,0,48,242,2,0,0,0,0,0,72,172,6,0,0,0,0,0,168,163,7,0,184,238,2,0,0,0,0,0,48,236,7,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,1,0,1,133,0,0,1,0,0,0,0,0,0,0,0,0,46,13,0,0,248,45,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,250,7,0,0,0,0,0,72,172,6,0,0,0,0,0,32,127,5,0,120,253,2,0,0,0,0,0,48,236,7,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,1,0,1,133,0,0,1,0,0,0,0,0,0,0,0,0,148,9,0,0,80,18,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,91,7,0,184,110,7,0,0,0,0,0,0,0,0,0,64,164,6,0,112,84,7,0,0,0,0,0,40,98,7,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,15,0,8,0,0,0,0,0,0,0,0,0,0,236,32,0,0,252,34,0,0,0,0,0,0,0,0,0,0,248,26,0,0,28,50,0,0,180,3,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,88,80,7,0,184,110,7,0,0,0,0,0,0,0,0,0,64,164,6,0,64,77,7,0,0,0,0,0,192,154,4,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,15,0,8,0,0,0,0,0,0,0,0,0,0,108,16,0,0,16,3,0,0,0,0,0,0,0,0,0,0,248,26,0,0,28,50,0,0,86,12,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,32,126,3,0,0,0,0,0,72,172,6,0,0,0,0,0,240,3,2,0,240,123,3,0])
.concat([0,0,0,0,176,237,2,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,0,8,0,0,0,0,0,0,0,0,0,0,40,28,0,0,166,26,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,191,1,0,0,0,0,0,72,172,6,0,0,0,0,0,48,57,5,0,32,191,1,0,32,205,1,0,136,203,1,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,4,0,0,2,0,0,0,0,0,1,5,0,0,1,0,0,0,0,0,0,0,0,0,40,8,0,0,146,33,0,0,0,0,0,0,0,0,0,0,208,59,0,0,168,4,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,102,8,0,0,0,0,0,0,0,0,0,0,0,0,0,96,159,4,0,48,250,7,0,0,0,0,0,152,196,7,0,160,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,184,37,0,0,144,43,0,0,0,0,0,0,0,0,0,0,82,31,0,0,114,26,0,0,56,14,0,0,128,2,0,0,38,9,0,0,62,9,0,0,130,37,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,3,0,0,0,4,0,0,0,152,177,6,0,168,102,8,0,0,0,0,0,0,0,0,0,96,159,4,0,232,134,6,0,0,0,0,0,192,154,4,0,160,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,20,15,0,0,2,40,0,0,0,0,0,0,0,0,0,0,82,31,0,0,92,15,0,0,96,19,0,0,128,2,0,0,38,9,0,0,62,9,0,0,130,37,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,3,0,0,0,4,0,0,0,192,158,7,0,0,0,0,0,72,172,6,0,0,0,0,0,32,127,5,0,240,143,2,0,0,0,0,0,224,189,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,1,0,1,133,2,0,0,0,128,0,0,0,0,0,0,0,46,10,0,0,232,20,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,138,8,0,0,0,0,0,72,172,6,0,0,0,0,0,0,38,7,0,152,145,2,0,0,0,0,0,224,189,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,1,0,1,133,2,0,0,0,128,0,0,0,0,0,0,0,234,27,0,0,214,22,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,125,1,0,0,0,0,0,0,0,0,0,0,0,0,0,64,164,6,0,104,230,8,0,0,0,0,0,0,223,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,2,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,26,29,0,0,228,39,0,0,0,0,0,0,0,0,0,0,88,16,0,0,94,33,0,0,182,12,0,0,156,11,0,0,20,11,0,0,210,6,0,0,84,15,0,0,0,175,145,0,32,0,0,0,224,0,0,0,236,0,0,0,3,0,0,0,4,0,0,0,24,164,8,0,96,125,1,0,0,0,0,0,0,0,0,0,64,164,6,0,64,102,8,0,0,0,0,0,128,45,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,214,2,0,0,186,0,0,0,0,0,0,0,0,0,0,0,88,16,0,0,0,36,0,0,182,12,0,0,156,11,0,0,20,11,0,0,210,6,0,0,84,15,0,0,0,175,145,0,32,0,0,0,224,0,0,0,236,0,0,0,3,0,0,0,4,0,0,0,200,230,2,0,216,235,2,0,72,172,6,0,0,0,0,0,184,12,8,0,72,229,2,0,0,0,0,0,48,236,7,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,133,2,0,0,0,0,0,0,0,0,0,0,0,216,8,0,0,96,1,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,235,2,0,0,0,0,0,72,172,6,0,0,0,0,0,184,12,8,0,136,233,2,0,0,0,0,0,48,236,7,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,2,0,0,0,0,0,0,0,0,0,0,0,56,5,0,0,254,21,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,226,2,0,0,0,0,0,72,172,6,0,0,0,0,0,192,177,6,0,208,224,2,0,0,0,0,0,48,236,7,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,2,0,0,0,0,0,0,0,0,0,0,0,206,60,0,0,36,0,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,85,1,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,40,85,1,0,0,0,0,0,200,196,7,0,176,90,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,3,23,0,0,1,0,0,0,0,0,198,10,0,0,100,32,0,0,148,15,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,146,2,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,192,87,1,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,0,87,1,0,0,0,0,0,144,110,7,0,176,90,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,3,23,0,0,1,0,0,0,0,0,198,10,0,0,214,48,0,0,136,46,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,146,2,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,96,89,1,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,104,88,1,0,0,0,0,0,200,196,7,0,176,90,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,3,23,0,0,1,0,0,0,0,0,198,10,0,0,64,23,0,0,48,26,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,146,2,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,56,90,1,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,176,89,1,0,0,0,0,0,200,196,7,0,176,90,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,3,23,0,0,1,0,0,0,0,0,198,10,0,0,64,7,0,0,116,10,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,146,2,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,168,91,1,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,40,91,1,0,0,0,0,0,200,196,7,0,176,90,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,3,23,0,0,1,0,0,0,0,0,198,10,0,0,152,38,0,0,36,29,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,146,2,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,80,234,1,0,56,120,5,0,0,0,0,0,0,0,0,0,200,190,7,0,24,137,1,0,0,0,0,0,192,223,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,20,8,0,0,0,2,0,0,0,0,0,0,0,30,19,0,0,166,14,0,0,0,0,0,0,0,0,0,0,210,24,0,0,138,46,0,0,10,13,0,0,250,5,0,0,166,17,0,0,40,4,0,0,80,32,0,0,248,175,145,0,1,4,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,251,2,0,56,120,5,0,0,0,0,0,0,0,0,0,200,190,7,0,216,95,2,0,0,0,0,0,192,223,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,20,8,0,0,0,2,0,0,0,0,0,0,0,166,1,0,0,180,32,0,0,0,0,0,0,0,0,0,0,120,40,0,0,138,46,0,0,250,2,0,0,250,5,0,0,166,17,0,0,40,4,0,0,80,32,0,0,248,175,145,0,1,4,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,172,8,0,56,120,5,0,0,0,0,0,0,0,0,0,200,190,7,0,224,108,8,0,0,0,0,0,192,223,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,81,0,0,0,2,0,0,0,0,0,0,20,8,0,0,0,2,0,0,0,0,0,0,0,124,39,0,0,140,21,0,0,0,0,0,0,0,0,0,0,212,34,0,0,132,16,0,0,240,10,0,0,250,5,0,0,166,17,0,0,40,4,0,0,80,32,0,0,248,175,145,0,1,4,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,48,1,0,56,120,5,0,0,0,0,0,0,0,0,0,200,190,7,0,88,236,8,0,0,0,0,0,192,223,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,20,8,0,0,0,2,0,0,0,0,0,0,0,116,38,0,0,188,29,0,0,0,0,0,0,0,0,0,0,210,24,0,0,138,46,0,0,236,17,0,0,250,5,0,0,166,17,0,0,40,4,0,0,80,32,0,0,248,175,145,0,1,4,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,120,5,0,0,0,0,0,0,0,0,0,0,0,0,0,200,190,7,0,88,112,6,0,0,0,0,0,192,223,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,20,8,0,0,0,2,0,0,0,0,0,0,0,102,12,0,0,46,33,0,0,0,0,0,0,0,0,0,0,212,34,0,0,132,16,0,0,8,8,0,0,250,5,0,0,166,17,0,0,40,4,0,0,80,32,0,0,248,175,145,0,1,4,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,235,8,0,24,233,1,0,0,0,0,0,0,0,0,0,184,168,7,0,208,170,8,0,0,0,0,0,128,145,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,92,35,0,0,242,35,0,0,0,0,0,0,0,0,0,0,42,50,0,0,186,8,0,0,10,15,0,0,62,7,0,0,96,4,0,0,26,8,0,0,134,11,0,0,216,175,145,0,0,8,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,160,107,8,0,24,233,1,0,0,0,0,0,0,0,0,0,184,168,7,0,16,51,8,0,0,0,0,0,128,145,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,18,24,0,0,138,46,0,0,0,0,0,0,0,0,0,0,42,50,0,0,186,8,0,0,10,15,0,0,62,7,0,0,96,4,0,0,26,8,0,0,134,11,0,0,216,175,145,0,0,8,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,24,233,1,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,232,46,1,0,0,0,0,0,128,145,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,2,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,228,55,0,0,24,17,0,0,0,0,0,0,0,0,0,0,42,50,0,0,186,8,0,0,10,15,0,0,62,7,0,0,96,4,0,0,26,8,0,0,134,11,0,0,216,175,145,0,0,8,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,72,170,2,0,0,0,0,0,72,172,6,0,0,0,0,0,168,163,7,0,160,168,2,0,0,0,0,0,120,58,8,0,208,9,3,0,40,166,2,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,1,0,1,133,0,64,0,0,0,0,0,0,0,0,0,0,88,23,0,0,166,47,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,234,2,0,0,0,0,0,0,0,0,0,0,0,0,0,64,164,6,0,136,225,1,0,0,0,0,0,120,58,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,0,22,0,1,0,0,0,0,0,0,0,0,0,0,38,24,0,0,114,24,0,0,0,0,0,0,0,0,0,0,154,11,0,0,4,16,0,0,0,6,0,0,156,0,0,0,98,18,0,0,232,14,0,0,224,37,0,0,56,175,145,0,8,0,0,0,240,0,0,0,240,0,0,0,3,0,0,0,4,0,0,0,112,131,4,0,48,146,4,0,72,172,6,0,0,0,0,0,144,33,2,0,40,128,4,0,0,0,0,0,160,139,4,0,208,9,3,0,136,125,4,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,16,1,1,133,8,0,0,0,32,0,0,0,0,0,0,0,204,39,0,0,62,1,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,154,16,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,123,4,0,48,146,4,0,72,172,6,0,0,0,0,0,144,33,2,0,96,121,4,0,0,0,0,0,192,154,4,0,208,9,3,0,0,119,4,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,133,8,0,0,0,32,0,0,0,0,0,0,0,18,18,0,0,16,37,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,198,19,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,146,4,0,0,0,0,0,72,172,6,0,0,0,0,0,144,33,2,0,240,142,4,0,0,0,0,0,160,139,4,0,208,9,3,0,8,135,4,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,16,1,1,133,8,0,0,0,32,0,0,0,0,0,0,0,128,20,0,0,84,6,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,154,16,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,186,7,0,216,230,8,0,72,172,6,0,0,0,0,0,0,38,7,0,0,181,7,0,0,0,0,0,128,145,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,1,0,1,133,8,0,0,0,32,0,0,0,0,0,0,0,26,17,0,0,230,15,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,94,6,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,55,4,0,136,71,4,0,72,172,6,0,0,0,0,0,0,180,6,0,48,51,4,0,0,0,0,0,160,139,4,0,208,9,3,0,80,47,4,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,16,1,1,133,8,0,0,0,32,0,0,0,0,0,0,0,208,34,0,0,194,38,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,198,5,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,64,4,0,136,71,4,0,72,172,6,0,0,0,0,0,0,180,6,0,96,62,4,0,0,0,0,0,160,139,4,0,208,9,3,0,80,58,4,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,16,1,1,133,8,0,0,0,32,0,0,0,0,0,0,0,50,54,0,0,194,7,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,198,5,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,71,4,0,0,0,0,0,72,172,6,0,0,0,0,0,0,180,6,0,136,69,4,0,0,0,0,0,160,139,4,0,208,9,3,0,248,66,4,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,16,1,1,133,8,0,0,0,32,0,0,0,0,0,0,0,156,59,0,0,92,8,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,198,5,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,20,3,0,0,0,0,0,72,172,6,0,0,0,0,0,144,139,6,0,48,19,3,0,0,0,0,0,232,163,8,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,8,0,1,133,2,0,0,0,0,0,0,0,0,0,0,0,138,28,0,0,234,22,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,146,6,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,230,8,0,176,135,4,0,0,0,0,0,0,0,0,0,216,194,1,0,152,164,8,0,0,0,0,0,192,154,4,0,160,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,72,52,0,0,206,43,0,0,0,0,0,0,0,0,0,0,82,31,0,0,118,47,0,0,204,3,0,0,128,2,0,0,38,9,0,0,62,9,0,0,130,37,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,3,0,0,0,4,0,0,0,48,223,1,0,176,135,4,0,0,0,0,0,0,0,0,0,216,194,1,0,168,125,1,0,0,0,0,0,192,154,4,0,160,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,76,44,0,0,112,41,0,0,0,0,0,0,0,0,0,0,82,31,0,0,118,47,0,0,10,9,0,0,128,2,0,0,38,9,0,0,62,9,0,0,130,37,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,3,0,0,0,4,0,0,0,232,231,2,0,176,135,4,0,0,0,0,0,0,0,0,0,216,194,1,0,120,81,2,0,0,0,0,0,88,225,4,0,160,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,98,60,0,0,86,41,0,0,0,0,0,0,0,0,0,0,82,31,0,0,118,47,0,0,70,13,0,0,128,2,0,0,38,9,0,0,62,9,0,0,130,37,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,3,0,0,0,4,0,0,0,176,135,4,0,0,0,0,0,0,0,0,0,0,0,0,0,216,194,1,0,120,70,6,0,0,0,0,0,88,225,4,0,160,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,238,8,0,0,108,46,0,0,0,0,0,0,0,0,0,0,82,31,0,0,118,47,0,0,10,9,0,0,128,2,0,0,38,9,0,0,62,9,0,0,130,37,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,3,0,0,0,4,0,0,0,136,96,2,0,0,0,0,0,72,172,6,0,0,0,0,0,56,172,6,0,112,95,2,0,0,0,0,0,0,94,2,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,16,1,1,133,8,0,0,0,0,0,0,0,0,0,0,0,98,50,0,0,152,2,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,20,6,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,208,6,0,0,0,0,0,0,0,0,0,0,0,0,0,160,234,7,0,224,204,6,0,0,0,0,0,224,201,6,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,2,0,0,0,0,0,0,15,0,32,0,0,0,0,0,0,0,0,0,0,220,37,0,0,60,28,0,0,0,0,0,0,0,0,0,0,22,9,0,0,2,40,0,0,64,10,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,88,165,8,0,0,0,0,0,0,0,0,0,0,0,0,0,64,164,6,0,56,103,8,0,56,46,8,0,200,250,7,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,0,22,0,1,0,0,0,0,0,0,0,0,0,0,62,57,0,0,44,9,0,0,0,0,0,0,0,0,0,0,154,11,0,0,4,16,0,0,254,9,0,0,156,0,0,0,98,18,0,0,232,14,0,0,224,37,0,0,56,175,145,0,8,0,0,0,240,0,0,0,240,0,0,0,3,0,0,0,4,0,0,0,152,193,1,0,0,0,0,0,72,172,6,0,0,0,0,0,48,57,5,0,216,192,1,0,32,205,1,0,136,203,1,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,4,0,0,2,0,0,0,0,0,1,5,0,0,1,0,0,0,0,0,0,0,0,0,176,33,0,0,84,38,0,0,0,0,0,0,0,0,0,0,208,59,0,0,168,4,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,224,6,0,184,238,6,0,72,172,6,0,0,0,0,0,168,163,7,0,200,218,6,0,0,0,0,0,128,145,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,133,8,0,0,0,16,0,0,0,0,0,0,0,172,15,0,0,2,15,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,238,6,0,0,0,0,0,72,172,6,0,0,0,0,0,168,163,7,0,24,229,6,0,0,0,0,0,128,145,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,8,0,0,0,16,0,0,0,0,0,0,0,254,29,0,0,176,28,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,63,6,0,40,189,6,0,72,172,6,0,0,0,0,0,192,177,6,0,64,60,6,0,0,0,0,0,128,145,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,133,8,0,0,0,16,0,0,0,0,0,0,0,30,51,0,0,140,36,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,77,6,0,40,189,6,0,72,172,6,0,0,0,0,0,192,177,6,0,160,71,6,0,0,0,0,0,128,145,4,0,208,9,3,0,144,66,6,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,133,8,0,0,0,16,0,0,0,0,0,0,0,188,39,0,0,122,7,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,189,6,0,0,0,0,0,72,172,6,0,0,0,0,0,192,177,6,0,136,92,6,0,0,0,0,0,128,145,4,0,208,9,3,0,128,83,6,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,8,0,0,0,16,0,0,0,0,0,0,0,44,57,0,0,146,17,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,78,7,0,104,179,7,0,72,172,6,0,0,0,0,0,32,127,5,0,152,74,7,0,0,0,0,0,128,145,4,0,208,9,3,0,144,69,7,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,133,8,0,0,0,16,0,0,0,0,0,0,0,56,9,0,0,212,35,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,212,17,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,179,7,0,0,0,0,0,72,172,6,0,0,0,0,0,32,127,5,0,216,85,7,0,0,0,0,0,128,145,4,0,208,9,3,0,184,80,7,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,8,0,0,0,16,0,0,0,0,0,0,0,70,52,0,0,164,44,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,26,7,0,0,0,0,0,72,172,6,0,0,0,0,0,168,163,7,0,192,250,2,0,0,0,0,0,48,236,7,0,208,9,3,0,48,249,2,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,1,0,1,133,8,0,0,0,0,0,0,0,0,0,0,0,80,1,0,0,20,10,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,7,3,0,240,93,8,0,72,172,6,0,0,0,0,0,32,127,5,0,200,4,3,0,0,0,0,0,48,236,7,0,208,9,3,0,56,1,3,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,133,0,32,0,0,0,0,0,0,0,0,0,0,90,25,0,0,178,41,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,93,8,0,0,0,0,0,72,172,6,0,0,0,0,0,32,127,5,0,176,14,3,0,0,0,0,0,48,236,7,0,208,9,3,0,176,8,3,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,0,32,0,0,0,0,0,0,0,0,0,0,78,15,0,0,18,30,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,134,2,0,0,0,0,0,72,172,6,0,0,0,0,0,32,127,5,0,224,133,2,0,0,0,0,0,64,133,2,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,0,16,0,0,0,0,0,0,0,0,0,0,226,41,0,0,244,13,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,121,2,0,184,134,2,0,72,172,6,0,0,0,0,0,184,12,8,0,16,121,2,0,0,0,0,0,64,133,2,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,133,0,16,0,0,0,0,0,0,0,0,0,0,222,6,0,0,132,41,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,230,7,0,0,0,0,0,72,172,6,0,0,0,0,0,32,127,5,0,112,139,3,0,0,0,0,0,168,222,7,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,1,0,0,0,0,0,0,0,0,0,0,0,244,60,0,0,20,3,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,198,7,0,160,203,4,0,0,0,0,0,0,0,0,0,216,194,1,0,248,149,7,0,0,0,0,0,248,39,8,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,15,0,1,0,0,0,0,0,0,0,0,0,0,8,33,0,0,76,17,0,0,0,0,0,0,0,0,0,0,76,35,0,0,154,39,0,0,86,12,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,192,166,8,0,160,203,4,0,0,0,0,0,0,0,0,0,216,194,1,0,232,47,8,0,0,0,0,0,144,251,7,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,15,0,1,0,0,0,0,0,0,0,0,0,0,180,60,0,0,164,47,0,0,0,0,0,0,0,0,0,0,76,35,0,0,154,39,0,0,86,12,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,232,128,1,0,160,203,4,0,0,0,0,0,0,0,0,0,96,159,4,0,64,43,1,0,0,0,0,0,144,88,7,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,15,0,1,0,0,0,0,0,0,0,0,0,0,224,40,0,0,52,13,0,0,0,0,0,0,0,0,0,0,76,35,0,0,154,39,0,0,86,12,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,120,238,2,0,160,203,4,0,0,0,0,0,0,0,0,0,96,159,4,0,248,86,2,0,0,0,0,0,192,154,4,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,15,0,1,0,0,0,0,0,0,0,0,0,0,78,55,0,0,66,10,0,0,0,0,0,0,0,0,0,0,76,35,0,0,154,39,0,0,86,12,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,160,203,4,0,0,0,0,0,0,0,0,0,0,0,0,0,96,159,4,0,240,82,6,0,0,0,0,0,248,39,8,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,2,0,0,0,0,0,0,15,0,1,0,0,0,0,0,0,0,0,0,0,120,50,0,0,96,44,0,0,0,0,0,0,0,0,0,0,76,35,0,0,154,39,0,0,86,12,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,208,173,8,0,0,0,0,0,72,172,6,0,0,0,0,0,0,38,7,0,208,148,2,0,0,0,0,0,224,189,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,0,64,0,0,0,0,0,0,0,0,0,0,166,42,0,0,184,31,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,130,3,0,0,0,0,0,72,172,6,0,0,0,0,0,144,139,6,0,120,128,3,0,0,0,0,0,176,131,3,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,8,0,1,133,1,0,0,0,0,0,0,0,0,0,0,0,230,12,0,0,98,18,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,112,8,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,247,2,0,40,75,5,0,0,0,0,0,0,0,0,0,104,174,7,0,184,93,2,0,0,0,0,0,128,145,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,206,32,0,0,144,39,0,0,0,0,0,0,0,0,0,0,238,44,0,0,184,31,0,0,92,4,0,0,62,7,0,0,96,4,0,0,26,8,0,0,134,11,0,0,216,175,145,0,0,8,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,75,5,0,0,0,0,0,0,0,0,0,0,0,0,0,104,174,7,0,96,105,6,0,0,0,0,0,128,145,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,148,36,0,0,194,12,0,0,0,0,0,0,0,0,0,0,238,44,0,0,134,56,0,0,92,4,0,0,62,7,0,0,96,4,0,0,26,8,0,0,134,11,0,0,216,175,145,0,0,8,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,136,5,0,160,203,4,0,0,0,0,0,0,0,0,0,216,194,1,0,128,109,5,0,0,0,0,0,144,88,7,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,2,0,0,0,0,0,0,15,0,1,0,0,0,0,0,0,0,0,0,0,160,31,0,0,100,46,0,0,0,0,0,0,0,0,0,0,76,35,0,0,154,39,0,0,86,12,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,72,143,2,0,0,0,0,0,72,172,6,0,0,0,0,0,184,12,8,0,112,141,2,0,0,0,0,0,224,189,4,0,208,9,3,0,64,140,2,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,16,1,133,0,16,0,0,0,0,0,0,0,0,0,0,28,51,0,0,218,20,0,0,0,0,0,0,0,0,0,0,200,48,0,0,126,27,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,127,7,0,136,138,7,0,0,0,0,0,0,0,0,0,232,167,7,0,240,123,7,0,0,0,0,0,32,120,7,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,15,0,8,0,0,0,0,0,0,0,0,0,0,48,55,0,0,40,14,0,0,0,0,0,0,0,0,0,0,194,38,0,0,120,55,0,0,68,14,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,138,7,0,0,0,0,0,0,0,0,0,0,0,0,0,232,167,7,0,168,133,7,0,0,0,0,0,48,130,7,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,15,0,8,0,0,0,0,0,0,0,0,0,0,76,21,0,0,112,1,0,0,0,0,0,0,0,0,0,0,194,38,0,0,120,55,0,0,68,14,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,212,1,0,0,0,0,0,72,172,6,0,0,0,0,0,136,232,4,0,208,210,1,0,0,0,0,0,120,245,1,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,0,0,2,0,0,0,0,0,1,5,64,0,0,0,0,0,0,0,0,0,0,0,106,60,0,0,2,4,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,190,2,0,0,0,0,0,72,172,6,0,0,0,0,0,144,33,2,0,176,187,2,0,0,0,0,0,88,186,2,0,208,9,3,0,208,184,2,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,16,1,1,133,0,16,0,0,0,0,0,0,0,0,0,0,56,29,0,0,0,7,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,164,13,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,233,2,0,40,147,4,0,0,0,0,0,0,0,0,0,64,171,7,0,16,82,2,0,0,0,0,0,232,196,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,42,12,0,0,120,13,0,0,0,0,0,0,0,0,0,0,112,39,0,0,172,43,0,0,78,9,0,0,234,2,0,0,58,14,0,0,34,2,0,0,64,43,0,0,0,0,0,0,0,2,0,0,0,1,0,0,192,0,0,0,4,0,0,0,3,0,0,0,40,147,4,0,0,0,0,0,0,0,0,0,0,0,0,0,64,171,7,0,168,72,6,0,0,0,0,0,232,196,4,0,240,185,2,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,62,21,0,0,250,47,0,0,0,0,0,0,0,0,0,0,112,39,0,0,172,43,0,0,78,9,0,0,234,2,0,0,58,14,0,0,34,2,0,0,64,43,0,0,0,0,0,0,0,2,0,0,0,1,0,0,192,0,0,0,4,0,0,0,3,0,0,0,64,21,8,0,160,203,4,0,0,0,0,0,0,0,0,0,216,194,1,0,24,18,8,0,0,0,0,0,96,25,8,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,15,0,1,0,0,0,0,0,0,0,0,0,0,142,22,0,0,246,11,0,0,0,0,0,0,0,0,0,0,76,35,0,0,76,47,0,0,192,8,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,72,14,8,0,160,203,4,0,0,0,0,0,0,0,0,0,216,194,1,0,40,9,8,0,0,0,0,0,144,88,7,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,15,0,1,0,0,0,0,0,0,0,0,0,0,168,60,0,0,76,46,0,0,0,0,0,0,0,0,0,0,76,35,0,0,76,47,0,0,86,12,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,120,34,8,0,160,203,4,0,0,0,0,0,0,0,0,0,216,194,1,0,104,29,8,0,0,0,0,0,96,25,8,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,15,0,1,0,0,0,0,0,0,0,0,0,0,196,13,0,0,206,4,0,0,0,0,0,0,0,0,0,0,76,35,0,0,76,47,0,0,192,8,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,232,44,1,0,8,88,1,0,200,240,5,0,0,0,0,0,144,139,6,0,216,36,1,0,0,0,0,0,72,174,3,0,88,0,3,0,240,26,1,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,1,0,0,8,0,16,0,0,0,0,0,0,0,0,0,0,120,10,0,0,48,33,0,0,0,0,0,0,0,0,0,0,104,35,0,0,222,12,0,0,236,2,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,192,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,19,7,0,0,0,0,0,72,172,6,0,0,0,0,0,168,163,7,0,16,244,2,0,0,0,0,0,48,236,7,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,1,0,1,133,0,128,0,0,0,0,0,0,0,0,0,0,24,7,0,0,16,8,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,105,6,0,112,158,6,0,0,0,0,0,0,0,0,0,232,167,7,0,8,101,6,0,0,0,0,0,88,46,8,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,0,0,0,2,0,0,0,0,0,0,15,0,1,0,0,0,0,0,0,0,0,0,0,158,17,0,0,44,15,0,0,0,0,0,0,0,0,0,0,244,35,0,0,156,26,0,0,134,19,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,24,117,6,0,112,158,6,0,0,0,0,0,0,0,0,0,232,167,7,0,168,113,6,0,0,0,0,0,88,46,8,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,0,0,0,2,0,0,0,0,0,0,15,0,1,0,0,0,0,0,0,0,0,0,0,22,57,0,0,46,14,0,0,0,0,0,0,0,0,0,0,244,35,0,0,156,26,0,0,134,19,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,8,126,6,0,112,158,6,0,0,0,0,0,0,0,0,0,232,167,7,0,232,120,6,0,0,0,0,0,40,161,4,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,15,0,1,0,0,0,0,0,0,0,0,0,0,200,43,0,0,32,0,0,0,0,0,0,0,0,0,0,0,244,35,0,0,156,26,0,0,22,12,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,56,136,6,0,112,158,6,0,0,0,0,0,0,0,0,0,232,167,7,0,16,131,6,0,0,0,0,0,40,161,4,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,15,0,1,0,0,0,0,0,0,0,0,0,0,108,59,0,0,30,32,0,0,0,0,0,0,0,0,0,0,244,35,0,0,156,26,0,0,82,12,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,56,144,6,0,112,158,6,0,0,0,0,0,0,0,0,0,232,167,7,0,144,140,6,0,0,0,0,0,40,161,4,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,15,0,1,0,0,0,0,0,0,0,0,0,0,46,62,0,0,162,5,0,0,0,0,0,0,0,0,0,0,244,35,0,0,156,26,0,0,82,12,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,24,152,6,0,112,158,6,0,0,0,0,0,0,0,0,0,232,167,7,0,112,148,6,0,0,0,0,0,40,161,4,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,15,0,1,0,0,0,0,0,0,0,0,0,0,10,50,0,0,172,16,0,0,0,0,0,0,0,0,0,0,244,35,0,0,156,26,0,0,22,12,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,112,158,6,0,0,0,0,0,0,0,0,0,0,0,0,0,232,167,7,0,8,155,6,0,0,0,0,0,40,161,4,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,2,0,0,0,0,0,0,15,0,1,0,0,0,0,0,0,0,0,0,0,166,21,0,0,116,30,0,0,0,0,0,0,0,0,0,0,244,35,0,0,156,26,0,0,22,12,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,120,14,2,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,128,13,2,0,0,0,0,0,104,81,5,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,200,22,0,0,184,15,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,96,18,2,0,152,17,2,0,0,0,0,0,0,0,0,0,144,47,2,0,216,16,2,0,0,0,0,0,136,168,2,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,224,41,0,0,200,8,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,152,17,2,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,168,15,2,0,0,0,0,0,136,168,2,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,144,48,0,0,34,23,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,72,19,2,0,0,0,0,0,0,0,0,0,0,0,0,0,104,174,7,0,184,18,2,0,0,0,0,0,200,196,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,8,7,0,0,152,37,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,88,20,2,0,0,0,0,0,0,0,0,0,0,0,0,0,104,174,7,0,160,19,2,0,0,0,0,0,176,67,3,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,14,21,0,0,214,10,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,160,105,8,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,232,96,8,0,0,0,0,0,160,161,8,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,196,62,0,0,88,0,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,192,23,2,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,224,22,2,0,0,0,0,0,176,67,3,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,166,10,0,0,148,22,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,8,42,2,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,112,40,2,0,0,0,0,0,160,15,5,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,236,23,0,0,174,21,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,96,31,2,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,40,30,2,0,0,0,0,0,176,67,3,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,200,49,0,0,160,3,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,224,26,2,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,152,24,2,0,0,0,0,0,176,67,3,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,228,60,0,0,148,47,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,248,33,2,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,24,33,2,0,0,0,0,0,0,193,8,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,138,48,0,0,168,13,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,120,28,2,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,208,27,2,0,0,0,0,0,176,67,3,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,102,56,0,0,160,45,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,176,29,2,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,0,29,2,0,0,0,0,0,72,174,3,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,90,33,0,0,66,1,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,48,158,4,0,0,0,0,0,0,0,0,0,0,0,0,0,104,174,7,0,16,156,4,0,0,0,0,0,200,196,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,200,8,0,0,98,35,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,0,37,2,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,80,35,2,0,0,0,0,0,32,111,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,152,32,0,0,6,12,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,192,39,2,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,32,39,2,0,0,0,0,0,168,155,8,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,18,36,0,0,148,28,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,136,45,2,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,112,44,2,0,0,0,0,0,64,246,3,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,248,22,0,0,128,10,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,176,47,2,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,184,46,2,0,0,0,0,0,72,174,3,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,128,13,0,0,30,29,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,8,50,2,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,176,48,2,0,0,0,0,0,152,54,6,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,118,4,0,0,160,30,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,64,53,2,0,0,0,0,0,0,0,0,0,0,0,0,0,200,190,7,0,56,51,2,0,0,0,0,0,200,196,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,110,20,0,0,220,38,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,64,57,2,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,56,54,2,0,0,0,0,0,64,89,2,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,248,18,0,0,72,21,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,152,38,2,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,224,37,2,0,0,0,0,0,176,67,3,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,22,37,0,0,52,45,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,192,60,2,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,184,59,2,0,0,0,0,0,168,222,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,50,1,0,0,214,19,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,136,224,7,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,24,221,7,0,0,0,0,0,168,95,8,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,88,41,0,0,144,27,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,224,64,2,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,56,63,2,0,0,0,0,0,16,96,6,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,54,62,0,0,160,23,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,104,66,2,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,184,65,2,0,0,0,0,0,16,96,6,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,196,60,0,0,152,19,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,48,68,2,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,56,67,2,0,0,0,0,0,16,96,6,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,108,4,0,0,250,19,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,224,73,2,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,80,72,2,0,0,0,0,0,160,15,5,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,100,25,0,0,194,11,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,232,76,2,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,200,75,2,0,0,0,0,0,72,174,3,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,24,22,0,0,212,29,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,56,79,2,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,120,78,2,0,0,0,0,0,192,77,2,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,24,53,0,0,74,30,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,152,92,2,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,248,90,2,0,0,0,0,0,64,89,2,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,44,9,0,0,4,41,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,96,95,2,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,240,93,2,0,0,0,0,0,136,168,2,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,112,27,0,0,194,5,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,192,239,3,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,144,236,3,0,0,0,0,0,64,246,3,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,138,3,0,0,118,16,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,96,97,2,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,128,96,2,0,0,0,0,0,160,15,5,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,22,29,0,0,10,21,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,104,99,2,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,80,98,2,0,0,0,0,0,160,161,8,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,156,20,0,0,58,8,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,184,104,2,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,112,103,2,0,0,0,0,0,24,254,6,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,92,44,0,0,126,20,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,192,102,2,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,152,101,2,0,0,0,0,0,144,110,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,164,45,0,0,154,29,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,56,110,2,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,64,108,2,0,0,0,0,0,8,66,8,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,202,1,0,0,246,23,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,112,114,2,0,56,119,2,0,0,0,0,0,0,0,0,0,96,135,2,0,40,113,2,0,0,0,0,0,64,246,3,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,246,45,0,0,184,39,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,56,119,2,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,40,117,2,0,0,0,0,0,64,246,3,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,100,57,0,0,144,22,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,40,124,2,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,232,122,2,0,0,0,0,0,200,196,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,148,17,0,0,146,0,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,48,133,2,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,128,132,2,0,0,0,0,0,168,155,8,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,146,30,0,0,234,26,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,208,131,2,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,216,130,2,0,0,0,0,0,200,196,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,42,31,0,0,226,1,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,184,144,2,0,0,0,0,0,0,0,0,0,0,0,0,0,40,41,5,0,216,143,2,0,0,0,0,0,240,155,5,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,4,17,0,0,48,41,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,192,148,2,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,8,147,2,0,0,0,0,0,16,96,6,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,204,51,0,0,52,6,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,168,134,2,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,200,133,2,0,0,0,0,0,200,196,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,48,14,0,0,242,41,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,8,152,2,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,120,150,2,0,0,0,0,0,176,67,3,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,106,40,0,0,170,26,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,152,155,2,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,128,154,2,0,0,0,0,0,136,168,2,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,68,40,0,0,38,9,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,232,157,2,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,112,156,2,0,0,0,0,0,136,168,2,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,44,43,0,0,128,16,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,200,161,2,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,16,160,2,0,0,0,0,0,64,246,3,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,158,4,0,0,174,1,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,112,173,2,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,120,172,2,0,0,0,0,0,80,25,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,66,61,0,0,142,8,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,208,174,2,0,0,0,0,0,0,0,0,0,0,0,0,0,40,41,5,0,0,174,2,0,0,0,0,0,200,196,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,70,1,0,0,112,4,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,112,178,2,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,144,176,2,0,0,0,0,0,200,196,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,166,12,0,0,36,48,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,56,171,2,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,48,170,2,0,0,0,0,0,136,168,2,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,108,21,0,0,192,18,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,152,136,2,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,48,135,2,0,0,0,0,0,200,196,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,148,26,0,0,78,27,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,48,140,2,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,216,138,2,0,0,0,0,0,200,196,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,30,52,0,0,174,31,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,40,143,2,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,88,141,2,0,0,0,0,0,104,81,5,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,118,56,0,0,136,23,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,232,181,2,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,224,180,2,0,0,0,0,0,16,96,6,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,122,48,0,0,66,20,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,192,184,2,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,24,183,2,0,0,0,0,0,72,174,3,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0])
.concat([5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,220,5,0,0,240,35,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,160,187,2,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,64,186,2,0,0,0,0,0,0,193,8,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,164,26,0,0,248,30,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,160,191,2,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,0,190,2,0,0,0,0,0,80,25,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,206,34,0,0,184,21,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,248,90,5,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,72,88,5,0,0,0,0,0,32,111,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,202,56,0,0,42,39,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,8,95,5,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,200,92,5,0,0,0,0,0,112,139,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,18,58,0,0,28,46,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,184,195,2,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,104,193,2,0,0,0,0,0,88,198,2,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,48,59,0,0,178,47,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,200,201,2,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,120,200,2,0,0,0,0,0,88,198,2,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,130,28,0,0,134,45,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,128,205,2,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,32,204,2,0,0,0,0,0,16,96,6,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,184,19,0,0,36,17,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,40,208,2,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,112,206,2,0,0,0,0,0,144,87,3,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,52,11,0,0,136,8,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,0,121,2,0,96,122,2,0,0,0,0,0,0,0,0,0,184,168,7,0,64,120,2,0,0,0,0,0,168,222,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,120,62,0,0,218,13,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,96,122,2,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,160,121,2,0,0,0,0,0,168,222,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,62,41,0,0,62,17,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,0,166,2,0,0,0,0,0,0,0,0,0,0,0,0,0,104,174,7,0,48,164,2,0,0,0,0,0,80,25,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,216,26,0,0,70,1,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,208,211,2,0,0,0,0,0,0,0,0,0,0,0,0,0,200,190,7,0,224,209,2,0,0,0,0,0,200,196,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,0,19,0,0,124,44,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,80,146,2,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,112,145,2,0,0,0,0,0,72,143,1,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,216,44,0,0,10,14,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,224,218,2,0,0,0,0,0,0,0,0,0,0,0,0,0,104,174,7,0,176,215,2,0,0,0,0,0,200,196,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,240,37,0,0,202,31,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,64,223,2,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,176,220,2,0,0,0,0,0,8,66,8,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,230,39,0,0,188,18,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,96,106,2,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,64,105,2,0,0,0,0,0,152,54,6,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,128,2,0,0,8,47,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,64,159,2,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,104,158,2,0,0,0,0,0,64,246,3,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,58,39,0,0,106,17,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,208,226,2,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,192,224,2,0,0,0,0,0,168,95,8,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,48,36,0,0,14,31,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,184,230,2,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,40,229,2,0,0,0,0,0,152,54,6,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,100,9,0,0,208,14,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,200,235,2,0,0,0,0,0,0,0,0,0,0,0,0,0,104,174,7,0,88,233,2,0,0,0,0,0,200,196,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,164,24,0,0,222,8,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,32,242,2,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,144,238,2,0,0,0,0,0,160,161,8,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,222,34,0,0,206,20,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,160,14,3,0,0,0,0,0,0,0,0,0,0,0,0,0,104,174,7,0,136,13,3,0,0,0,0,0,200,196,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,14,3,0,0,24,32,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,32,18,3,0,0,0,0,0,0,0,0,0,0,0,0,0,104,174,7,0,144,15,3,0,0,0,0,0,200,196,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,212,27,0,0,110,40,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,192,246,2,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,0,244,2,0,0,0,0,0,80,118,5,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,106,25,0,0,232,6,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,176,250,2,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,32,249,2,0,0,0,0,0,64,246,3,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,204,47,0,0,36,42,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,104,253,2,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,136,251,2,0,0,0,0,0,200,196,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,166,43,0,0,138,32,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,40,1,3,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,104,255,2,0,0,0,0,0,152,54,6,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,108,56,0,0,168,18,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,160,8,3,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,136,7,3,0,0,0,0,0,168,155,8,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,28,12,0,0,34,43,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,16,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,40,41,5,0,24,19,3,0,0,0,0,0,240,155,5,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,138,55,0,0,32,42,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,184,28,3,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,40,23,3,0,0,0,0,0,64,246,3,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,50,30,0,0,236,9,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,112,34,3,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,96,31,3,0,0,0,0,0,192,135,8,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,196,39,0,0,56,18,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,192,48,3,0,0,0,0,0,0,0,0,0,0,0,0,0,104,174,7,0,168,46,3,0,0,0,0,0,176,67,3,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,230,38,0,0,182,26,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,200,38,3,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,80,37,3,0,0,0,0,0,160,15,5,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,138,23,0,0,54,48,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,80,58,3,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,64,56,3,0,0,0,0,0,200,196,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,244,23,0,0,230,39,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,192,43,3,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,240,41,3,0,0,0,0,0,176,67,3,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,76,24,0,0,182,3,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,224,30,5,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,128,28,5,0,0,0,0,0,48,33,5,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,140,12,0,0,12,15,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,152,39,5,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,128,35,5,0,0,0,0,0,48,33,5,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,226,56,0,0,4,11,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,56,41,3,0,0,0,0,0,0,0,0,0,0,0,0,0,104,174,7,0,104,40,3,0,0,0,0,0,176,67,3,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,78,4,0,0,224,6,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,128,82,3,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,216,80,3,0,0,0,0,0,104,81,5,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,240,9,0,0,244,26,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,0,85,3,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,48,84,3,0,0,0,0,0,200,196,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,50,19,0,0,190,20,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,112,96,3,0,192,100,3,0,0,0,0,0,0,0,0,0,144,47,2,0,32,93,3,0,0,0,0,0,200,196,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,76,0,0,0,82,27,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,116,0,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,192,100,3,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,232,97,3,0,0,0,0,0,200,196,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,50,6,0,0,140,34,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,116,0,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,112,70,3,0,0,0,0,0,0,0,0,0,0,0,0,0,104,174,7,0,80,69,3,0,0,0,0,0,200,196,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,22,7,0,0,192,42,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,120,72,3,0,0,0,0,0,0,0,0,0,0,0,0,0,40,41,5,0,72,71,3,0,0,0,0,0,200,196,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,24,37,0,0,94,37,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,0,74,3,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,72,73,3,0,0,0,0,0,200,196,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,82,44,0,0,190,17,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,128,59,3,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,0,59,3,0,0,0,0,0,200,196,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,120,34,0,0,156,38,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,160,61,3,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,48,60,3,0,0,0,0,0,200,196,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,34,54,0,0,180,17,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,224,64,3,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,16,63,3,0,0,0,0,0,200,196,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,158,32,0,0,28,37,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,224,67,3,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,80,66,3,0,0,0,0,0,200,196,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,144,27,0,0,194,27,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,168,78,3,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,16,76,3,0,0,0,0,0,200,196,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,198,17,0,0,246,5,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,224,86,3,0,176,90,3,0,0,0,0,0,0,0,0,0,104,221,5,0,48,86,3,0,0,0,0,0,144,87,3,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,78,13,0,0,8,40,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,176,90,3,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,40,89,3,0,0,0,0,0,144,87,3,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,168,48,0,0,242,24,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,104,104,3,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,8,103,3,0,0,0,0,0,240,155,5,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,70,20,0,0,230,23,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,224,123,3,0,104,128,3,0,0,0,0,0,0,0,0,0,184,168,7,0,40,121,3,0,0,0,0,0,200,196,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,198,38,0,0,66,2,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,80,108,3,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,248,105,3,0,0,0,0,0,200,196,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,118,13,0,0,44,46,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,48,113,3,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,240,109,3,0,0,0,0,0,200,196,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,62,12,0,0,50,25,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,48,119,3,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,48,116,3,0,0,0,0,0,200,196,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,42,41,0,0,124,35,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,104,128,3,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,240,125,3,0,0,0,0,0,200,196,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,228,15,0,0,144,47,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,200,142,3,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,40,139,3,0,0,0,0,0,168,95,8,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,208,52,0,0,60,45,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,232,148,3,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,64,145,3,0,0,0,0,0,64,246,3,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,68,27,0,0,170,25,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,24,153,3,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,240,150,3,0,0,0,0,0,160,15,5,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,24,9,0,0,66,48,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,168,161,3,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,112,158,3,0,0,0,0,0,176,67,3,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,138,39,0,0,222,33,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,248,156,3,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,56,155,3,0,0,0,0,0,16,227,3,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,232,61,0,0,66,23,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,152,170,3,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,128,168,3,0,0,0,0,0,168,222,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,60,14,0,0,210,7,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,224,174,3,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,32,173,3,0,0,0,0,0,0,193,8,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,212,19,0,0,254,18,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,160,178,3,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,32,177,3,0,0,0,0,0,144,110,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,64,54,0,0,70,27,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,16,184,3,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,200,181,3,0,0,0,0,0,8,116,8,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,166,58,0,0,64,5,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,136,190,3,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,160,187,3,0,0,0,0,0,176,67,3,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,242,49,0,0,170,40,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,200,196,3,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,32,194,3,0,0,0,0,0,144,110,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,174,45,0,0,126,36,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,64,202,3,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,248,199,3,0,0,0,0,0,176,67,3,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,30,39,0,0,24,1,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,168,211,3,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,56,209,3,0,0,0,0,0,200,196,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0])
.concat([76,60,0,0,230,41,0,0,66,29,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,240,205,3,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,120,204,3,0,0,0,0,0,64,246,3,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,178,40,0,0,150,36,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,160,141,5,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,184,137,5,0,0,0,0,0,16,96,6,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,90,30,0,0,174,29,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,32,234,3,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,128,231,3,0,0,0,0,0,168,227,3,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,88,36,0,0,230,12,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,56,253,3,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,72,249,3,0,0,0,0,0,200,196,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,74,2,0,0,104,24,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,8,245,3,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,64,242,3,0,0,0,0,0,200,196,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,222,25,0,0,120,21,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,40,5,4,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,16,2,4,0,0,0,0,0,160,15,5,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,114,53,0,0,148,11,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,128,12,4,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,96,9,4,0,0,0,0,0,160,15,5,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,228,61,0,0,170,27,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,0,17,4,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,112,14,4,0,0,0,0,0,200,196,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,128,56,0,0,126,31,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,8,21,4,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,88,18,4,0,0,0,0,0,104,85,4,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,60,47,0,0,30,7,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,128,27,4,0,0,0,0,0,0,0,0,0,0,0,0,0,104,174,7,0,192,23,4,0,0,0,0,0,200,196,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,166,15,0,0,136,41,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,80,33,4,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,192,30,4,0,0,0,0,0,32,111,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,194,8,0,0,80,25,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,152,38,4,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,0,36,4,0,0,0,0,0,160,15,5,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,92,11,0,0,90,21,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,8,43,4,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,192,40,4,0,0,0,0,0,160,15,5,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,10,9,0,0,236,6,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,96,55,4,0,80,62,4,0,0,0,0,0,0,0,0,0,184,168,7,0,16,51,4,0,0,0,0,0,152,54,6,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,254,39,0,0,38,12,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,80,62,4,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,40,58,4,0,0,0,0,0,152,54,6,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,64,62,0,0,64,3,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,232,66,4,0,120,71,4,0,0,0,0,0,0,0,0,0,144,47,2,0,168,64,4,0,0,0,0,0,32,111,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,80,8,0,0,110,43,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,120,71,4,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,120,69,4,0,0,0,0,0,32,111,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,192,0,0,0,238,33,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,64,75,4,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,32,73,4,0,0,0,0,0,112,139,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,48,23,0,0,176,18,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,88,81,4,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,200,77,4,0,0,0,0,0,144,110,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,116,37,0,0,26,19,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,200,99,4,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,0,98,4,0,0,0,0,0,200,196,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,138,53,0,0,34,33,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,88,96,4,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,152,94,4,0,0,0,0,0,200,196,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,36,11,0,0,132,39,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,160,110,4,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,0,108,4,0,0,0,0,0,200,196,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,28,11,0,0,68,4,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,168,104,4,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,112,101,4,0,0,0,0,0,200,196,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,132,15,0,0,98,40,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,168,91,4,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,120,88,4,0,0,0,0,0,104,85,4,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,90,34,0,0,76,43,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,96,178,4,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,240,173,4,0,0,0,0,0,24,254,6,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,248,25,0,0,174,27,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,192,182,4,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,88,180,4,0,0,0,0,0,232,196,4,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,80,47,0,0,4,34,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,176,187,4,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,184,184,4,0,0,0,0,0,8,116,8,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,230,15,0,0,182,36,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,16,212,4,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,80,208,4,0,0,0,0,0,160,161,8,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,54,27,0,0,116,41,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,248,193,4,0,184,204,4,0,0,0,0,0,0,0,0,0,104,221,5,0,32,190,4,0,0,0,0,0,160,161,8,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,212,58,0,0,26,15,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,184,204,4,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,184,197,4,0,0,0,0,0,160,161,8,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,174,54,0,0,78,25,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,80,116,4,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,152,113,4,0,0,0,0,0,176,67,3,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,80,9,0,0,120,25,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,184,170,4,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,200,165,4,0,0,0,0,0,16,162,4,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,14,36,0,0,44,35,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,80,121,4,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,240,118,4,0,0,0,0,0,160,161,8,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,44,55,0,0,86,7,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,24,128,4,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,120,125,4,0,0,0,0,0,64,32,1,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,128,58,0,0,244,32,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,24,226,4,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,152,222,4,0,0,0,0,0,176,67,3,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,74,13,0,0,226,3,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,248,134,4,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,72,131,4,0,0,0,0,0,200,196,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,228,20,0,0,108,35,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,224,142,4,0,0,0,0,0,0,0,0,0,0,0,0,0,104,174,7,0,136,139,4,0,0,0,0,0,16,96,6,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,212,54,0,0,36,32,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,8,149,4,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,16,146,4,0,0,0,0,0,160,15,5,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,56,25,0,0,44,31,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,72,153,4,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,48,151,4,0,0,0,0,0,0,193,8,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,254,22,0,0,122,15,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,64,219,4,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,168,217,4,0,0,0,0,0,24,215,4,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,240,40,0,0,174,2,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,96,144,1,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,96,131,1,0,240,117,1,0,104,105,1,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,42,1,0,0,20,4,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,184,241,4,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,64,239,4,0,0,0,0,0,152,54,6,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,36,8,0,0,192,22,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,24,235,4,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,0,230,4,0,0,0,0,0,104,81,5,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,148,3,0,0,20,20,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,8,250,4,0,96,0,5,0,0,0,0,0,0,0,0,0,40,41,5,0,192,246,4,0,0,0,0,0,240,155,5,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,18,57,0,0,74,16,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,96,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,40,41,5,0,248,252,4,0,0,0,0,0,240,155,5,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,126,23,0,0,220,47,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,144,20,5,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,80,17,5,0,0,0,0,0,240,155,5,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,152,23,0,0,196,43,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,200,12,5,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,88,9,5,0,0,0,0,0,240,155,5,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,146,43,0,0,122,26,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,128,26,5,0,0,0,0,0,0,0,0,0,0,0,0,0,200,190,7,0,200,23,5,0,0,0,0,0,200,196,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,156,19,0,0,138,44,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,40,6,5,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,56,3,5,0,0,0,0,0,64,246,3,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,144,21,0,0,180,8,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,64,47,5,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,88,43,5,0,0,0,0,0,104,81,5,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,140,49,0,0,34,11,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,40,55,5,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,120,51,5,0,0,0,0,0,160,200,5,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,250,41,0,0,230,26,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,0,60,5,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,56,57,5,0,0,0,0,0,16,96,6,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,40,62,0,0,226,46,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,32,65,5,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,248,62,5,0,0,0,0,0,64,246,3,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,32,35,0,0,18,37,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,40,71,5,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,200,66,5,0,0,0,0,0,32,111,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,42,22,0,0,112,34,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,120,78,5,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,240,74,5,0,0,0,0,0,8,66,8,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,52,23,0,0,180,41,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,176,84,5,0,0,0,0,0,0,0,0,0,0,0,0,0,200,190,7,0,160,81,5,0,0,0,0,0,200,196,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,234,10,0,0,32,16,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,136,101,5,0,112,110,5,0,0,0,0,0,0,0,0,0,184,168,7,0,144,97,5,0,0,0,0,0,80,25,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,72,29,0,0,80,2,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,112,110,5,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,0,106,5,0,0,0,0,0,80,25,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,42,62,0,0,216,40,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,96,147,5,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,208,144,5,0,0,0,0,0,24,254,6,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,138,6,0,0,130,28,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,248,115,5,0,176,122,5,0,0,0,0,0,0,0,0,0,184,168,7,0,56,113,5,0,0,0,0,0,80,118,5,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,62,4,0,0,40,5,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,176,122,5,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,136,120,5,0,0,0,0,0,80,118,5,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,6,22,0,0,36,39,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,128,126,5,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,240,124,5,0,0,0,0,0,64,246,3,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,102,33,0,0,114,7,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,176,133,5,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,0,130,5,0,0,0,0,0,200,196,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,94,23,0,0,24,33,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,72,153,5,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,184,150,5,0,0,0,0,0,152,54,6,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,206,1,0,0,46,4,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,200,163,5,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,248,158,5,0,0,0,0,0,240,155,5,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,220,18,0,0,74,31,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,88,197,5,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,160,193,5,0,0,0,0,0,64,246,3,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,192,35,0,0,24,40,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,192,183,5,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,216,179,5,0,0,0,0,0,64,246,3,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,234,20,0,0,170,35,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,160,208,5,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,112,204,5,0,0,0,0,0,160,200,5,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,254,38,0,0,36,41,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,248,226,5,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,200,221,5,0,0,0,0,0,160,161,8,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,12,31,0,0,176,8,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,200,217,5,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,160,213,5,0,0,0,0,0,160,161,8,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,232,1,0,0,216,22,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,88,233,5,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,240,229,5,0,0,0,0,0,64,246,3,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,160,49,0,0,116,1,0,0,0,0,0,0])
.concat([0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,96,240,5,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,216,236,5,0,0,0,0,0,200,196,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,80,46,0,0,130,43,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,104,253,5,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,16,246,5,0,0,0,0,0,200,196,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,98,10,0,0,190,8,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,144,8,6,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,152,2,6,0,0,0,0,0,168,95,8,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,0,7,0,0,120,36,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,216,17,6,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,56,14,6,0,0,0,0,0,232,196,4,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,78,39,0,0,254,41,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,32,31,6,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,184,27,6,0,0,0,0,0,176,67,3,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,252,24,0,0,94,7,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,176,40,6,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,120,35,6,0,0,0,0,0,176,67,3,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,28,20,0,0,184,41,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,24,50,6,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,0,45,6,0,0,0,0,0,72,143,1,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,32,25,0,0,14,22,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,48,60,6,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,104,57,6,0,0,0,0,0,152,54,6,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,214,49,0,0,198,22,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,128,66,6,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,24,63,6,0,0,0,0,0,112,139,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,146,25,0,0,62,12,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,96,77,6,0,0,0,0,0,0,0,0,0,0,0,0,0,104,174,7,0,144,71,6,0,0,0,0,0,176,67,3,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,192,62,0,0,114,28,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,48,102,6,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,200,96,6,0,0,0,0,0,112,139,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,124,44,0,0,236,8,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,120,92,6,0,0,0,0,0,0,0,0,0,0,0,0,0,104,174,7,0,104,83,6,0,0,0,0,0,112,139,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,190,29,0,0,128,11,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,168,126,6,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,160,121,6,0,0,0,0,0,192,218,6,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,174,59,0,0,82,30,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,48,118,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,64,114,6,0,0,0,0,0,192,218,6,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,154,46,0,0,60,16,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,184,136,6,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,144,131,6,0,0,0,0,0,192,218,6,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,182,6,0,0,232,15,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,152,144,6,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,216,140,6,0,0,0,0,0,192,218,6,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,136,12,0,0,120,27,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,120,152,6,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,192,148,6,0,0,0,0,0,192,218,6,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,192,14,0,0,92,39,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,104,199,6,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,232,195,6,0,0,0,0,0,176,67,3,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,106,50,0,0,22,6,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,144,158,6,0,32,168,6,0,0,0,0,0,0,0,0,0,40,41,5,0,168,155,6,0,0,0,0,0,200,196,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,136,42,0,0,208,25,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,32,168,6,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,56,162,6,0,0,0,0,0,200,196,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,150,16,0,0,150,21,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,56,180,6,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,192,174,6,0,0,0,0,0,192,218,6,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,12,30,0,0,204,12,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,192,191,6,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,120,186,6,0,0,0,0,0,176,67,3,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,12,39,0,0,74,36,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,248,205,6,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,40,202,6,0,0,0,0,0,24,254,6,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,178,25,0,0,90,45,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,144,214,6,0,0,0,0,0,0,0,0,0,0,0,0,0,104,174,7,0,168,209,6,0,0,0,0,0,80,25,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,62,30,0,0,146,41,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,8,229,6,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,144,224,6,0,0,0,0,0,192,218,6,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,172,44,0,0,240,40,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,192,21,7,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,184,15,7,0,0,0,0,0,104,81,5,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,226,46,0,0,38,19,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,144,31,7,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,192,45,8,0,0,0,0,0,80,25,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,154,51,0,0,168,40,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,184,236,6,0,88,242,6,0,0,0,0,0,0,0,0,0,104,221,5,0,232,233,6,0,0,0,0,0,24,254,6,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,76,50,0,0,184,16,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,88,242,6,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,216,239,6,0,0,0,0,0,24,254,6,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,144,42,0,0,126,38,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,232,249,6,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,200,246,6,0,0,0,0,0,24,254,6,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,254,43,0,0,46,32,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,216,10,7,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,96,5,7,0,0,0,0,0,24,254,6,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,80,37,0,0,176,0,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,40,87,2,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,128,83,2,0,0,0,0,0,160,15,5,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,98,12,0,0,190,5,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,152,37,7,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,136,34,7,0,0,0,0,0,112,139,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,78,1,0,0,228,41,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,32,49,7,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,216,42,7,0,0,0,0,0,200,196,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,140,13,0,0,28,30,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,168,80,7,0,0,0,0,0,0,0,0,0,0,0,0,0,104,174,7,0,16,78,7,0,0,0,0,0,176,67,3,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,16,42,0,0,192,4,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,224,91,7,0,136,105,7,0,0,0,0,0,0,0,0,0,144,47,2,0,160,85,7,0,0,0,0,0,176,67,3,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,84,21,0,0,164,28,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,136,105,7,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,192,98,7,0,0,0,0,0,176,67,3,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,212,37,0,0,146,8,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,144,81,2,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,208,79,2,0,0,0,0,0,176,67,3,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,42,44,0,0,172,37,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,24,61,7,0,136,74,7,0,0,0,0,0,0,0,0,0,104,221,5,0,72,54,7,0,0,0,0,0,0,193,8,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,224,39,0,0,124,23,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,136,74,7,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,120,69,7,0,0,0,0,0,0,193,8,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,220,0,0,0,54,24,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,96,121,7,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,224,116,7,0,0,0,0,0,32,111,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,240,10,0,0,212,11,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,128,127,7,0,32,134,7,0,0,0,0,0,0,0,0,0,104,221,5,0,168,124,7,0,0,0,0,0,144,110,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,138,13,0,0,48,34,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,32,134,7,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,112,131,7,0,0,0,0,0,144,110,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,116,16,0,0,220,31,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,176,161,7,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,40,156,7,0,0,0,0,0,200,196,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,180,21,0,0,158,12,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,128,169,7,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,88,166,7,0,0,0,0,0,200,196,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,66,7,0,0,124,22,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,144,177,7,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,88,174,7,0,0,0,0,0,64,246,3,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,240,14,0,0,192,26,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,232,34,8,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,240,29,8,0,0,0,0,0,128,26,8,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,158,35,0,0,26,18,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,88,186,7,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,240,180,7,0,0,0,0,0,160,15,5,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,132,61,0,0,190,3,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,80,200,7,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,72,193,7,0,0,0,0,0,104,81,5,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,6,45,0,0,164,3,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,72,211,7,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,176,206,7,0,0,0,0,0,160,15,5,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,142,44,0,0,192,29,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,200,232,7,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,0,228,7,0,0,0,0,0,104,81,5,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,88,22,0,0,4,36,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,112,253,7,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,16,245,7,0,0,0,0,0,176,238,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,134,45,0,0,62,5,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,144,151,7,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,216,145,7,0,0,0,0,0,112,139,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,92,36,0,0,40,35,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,192,174,5,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,152,169,5,0,0,0,0,0,200,196,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,120,60,0,0,168,25,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,32,10,8,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,248,3,8,0,0,0,0,0,144,110,7,0,112,15,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,44,11,0,0,92,43,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,146,2,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,208,21,8,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,184,18,8,0,0,0,0,0,144,110,7,0,112,15,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,34,6,0,0,168,32,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,146,2,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,120,49,8,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,32,42,8,0,0,0,0,0,144,110,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,16,21,0,0,164,26,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,144,62,8,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,200,55,8,0,0,0,0,0,8,66,8,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,46,58,0,0,34,6,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,96,90,8,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,0,83,8,0,0,0,0,0,72,174,3,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,136,6,0,0,232,46,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,192,27,1,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,248,16,1,0,0,0,0,0,160,161,8,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,148,50,0,0,138,45,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,16,73,8,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,80,69,8,0,0,0,0,0,8,66,8,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,154,12,0,0,112,47,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,168,119,8,0,176,130,8,0,0,0,0,0,0,0,0,0,144,47,2,0,48,113,8,0,0,0,0,0,160,15,5,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,232,44,0,0,90,14,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,176,130,8,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,64,124,8,0,0,0,0,0,160,15,5,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,242,50,0,0,190,32,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,120,145,8,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,224,140,8,0,0,0,0,0,192,135,8,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,216,39,0,0,240,6,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,32,158,8,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,80,152,8,0,0,0,0,0,8,116,8,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,50,48,0,0,82,2,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,128,185,8,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,96,176,8,0,0,0,0,0,72,169,8,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,184,52,0,0,108,16,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,128,24,6,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,40,21,6,0,0,0,0,0,64,246,3,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,156,60,0,0,112,45,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,112,205,8,0,104,218,8,0,0,0,0,0,0,0,0,0,104,221,5,0,16,200,8,0,0,0,0,0,160,15,5,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,106,63,0,0,96,30,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,104,218,8,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,112,209,8,0,0,0,0,0,160,15,5,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,130,61,0,0,116,26,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,48,234,8,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,104,226,8,0,0,0,0,0,176,67,3,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,150,42,0,0,156,47,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,104,129,2,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,16,128,2,0,0,0,0,0,64,246,3,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,178,49,0,0,98,1,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0])
.concat([2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,40,249,8,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,16,241,8,0,0,0,0,0,64,246,3,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,42,10,0,0,122,2,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,112,6,1,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,216,1,1,0,32,254,8,0,64,246,3,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,14,17,0,0,142,13,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,8,45,1,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,48,37,1,0,0,0,0,0,160,15,5,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,78,10,0,0,26,0,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,32,67,1,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,160,61,1,0,0,0,0,0,184,52,1,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,148,33,0,0,122,22,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,32,81,1,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,8,74,1,0,0,0,0,0,160,15,5,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,214,8,0,0,48,20,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,184,94,1,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,24,88,1,0,0,0,0,0,160,15,5,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,196,7,0,0,22,4,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,8,195,8,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,168,190,8,0,0,0,0,0,176,67,3,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,140,52,0,0,236,5,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,56,171,1,0,0,0,0,0,0,0,0,0,0,0,0,0,40,41,5,0,240,155,1,0,0,0,0,0,200,196,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,70,38,0,0,160,15,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,72,203,1,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,120,192,1,0,0,0,0,0,200,196,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,108,47,0,0,86,40,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,168,230,1,0,160,253,1,0,0,0,0,0,0,0,0,0,96,135,2,0,152,216,1,0,0,0,0,0,200,196,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,112,51,0,0,158,47,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,160,253,1,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,88,241,1,0,0,0,0,0,200,196,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,112,19,0,0,86,33,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,136,185,1,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,200,177,1,0,0,0,0,0,200,196,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,48,48,0,0,66,12,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,80,15,2,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,240,6,2,0,0,0,0,0,24,62,4,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,118,42,0,0,20,17,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,64,47,4,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,200,44,4,0,0,0,0,0,0,193,8,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,32,55,0,0,14,23,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,24,35,2,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,128,24,2,0,0,0,0,0,200,196,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,222,18,0,0,86,37,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,8,62,2,0,80,103,2,0,0,0,0,0,0,0,0,0,200,190,7,0,128,46,2,0,0,0,0,0,200,196,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,110,8,0,0,138,2,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,80,103,2,0,0,0,0,0,0,0,0,0,0,0,0,0,200,190,7,0,80,75,2,0,0,0,0,0,200,196,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,58,60,0,0,112,17,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,200,181,2,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,80,168,2,0,0,0,0,0,200,196,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,62,62,0,0,228,42,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,240,52,3,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,232,32,3,0,0,0,0,0,8,116,8,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,112,50,0,0,162,39,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,136,243,2,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,32,200,2,0,0,0,0,0,200,196,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,232,8,0,0,10,25,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,128,97,3,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,200,81,3,0,0,0,0,0,176,67,3,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,26,20,0,0,150,23,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,144,196,3,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,200,144,3,0,0,0,0,0,64,246,3,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,86,49,0,0,158,30,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,248,32,4,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,176,4,4,0,0,0,0,0,16,227,3,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,68,36,0,0,144,4,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,200,70,2,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,0,69,2,0,0,0,0,0,48,33,5,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,26,8,0,0,30,4,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,144,142,4,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,240,87,4,0,0,0,0,0,24,62,4,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,220,45,0,0,162,22,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,104,241,4,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,168,207,4,0,0,0,0,0,232,196,4,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,156,16,0,0,158,39,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,72,51,5,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,88,20,5,0,0,0,0,0,72,143,1,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,196,23,0,0,144,34,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,240,140,5,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,0,113,5,0,0,0,0,0,104,81,5,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,34,35,0,0,128,47,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,48,217,5,0,0,0,0,0,0,0,0,0,0,0,0,0,104,174,7,0,56,179,5,0,0,0,0,0,200,196,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,30,35,0,0,42,40,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,184,49,6,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,208,6,6,0,0,0,0,0,200,196,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,182,15,0,0,202,23,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,120,185,6,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,96,140,6,0,0,0,0,0,16,96,6,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,222,31,0,0,70,2,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,88,111,6,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,240,106,6,0,0,0,0,0,160,161,8,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,86,48,0,0,184,38,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,240,111,8,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,80,3,8,0,0,0,0,0,200,196,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,50,12,0,0,30,17,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,144,51,1,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,88,240,8,0,0,0,0,0,200,196,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,78,17,0,0,20,26,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,168,59,7,0,0,0,0,0,0,0,0,0,0,0,0,0,104,174,7,0,128,228,6,0,0,0,0,0,160,15,5,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,186,30,0,0,158,24,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,136,205,7,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,88,31,1,0,0,0,0,0,144,110,7,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,68,45,0,0,128,1,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,136,6,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,72,240,1,0,0,0,0,0,72,143,1,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,126,55,0,0,22,32,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,200,64,6,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,80,134,6,0,0,0,0,0,160,15,5,0,128,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,0,0,1,23,0,0,1,0,0,0,0,0,76,60,0,0,8,63,0,0,2,34,0,0,0,0,0,0,0,0,0,0,226,10,0,0,212,14,0,0,50,18,0,0,2,6,0,0,224,19,0,0,180,16,0,0,132,48,0,0,88,31,216,0,0,4,0,0,0,2,0,0,240,0,0,0,4,0,0,0,3,0,0,0,152,200,2,0,184,53,8,0,72,172,6,0,0,0,0,0,0,38,7,0,104,198,2,0,0,0,0,0,64,246,3,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,133,0,16,0,0,0,0,0,0,0,0,0,0,42,45,0,0,108,22,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,53,8,0,0,0,0,0,72,172,6,0,0,0,0,0,0,38,7,0,48,204,2,0,0,0,0,0,64,246,3,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,0,16,0,0,0,0,0,0,0,0,0,0,160,22,0,0,10,28,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,195,2,0,0,0,0,0,72,172,6,0,0,0,0,0,144,139,6,0,136,193,2,0,0,0,0,0,176,191,2,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,0,16,0,0,0,0,0,0,0,0,0,0,42,29,0,0,40,15,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,70,3,0,0,0,0,0,72,172,6,0,0,0,0,0,0,38,7,0,96,69,3,0,0,0,0,0,240,67,3,0,208,9,3,0,104,66,3,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,0,16,0,0,0,0,0,0,0,0,0,0,248,51,0,0,192,9,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,240,8,0,24,116,1,0,0,0,0,0,0,0,0,0,216,194,1,0,40,233,8,0,0,0,0,0,192,154,4,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,15,0,1,0,0,0,0,0,0,0,0,0,0,98,1,0,0,16,4,0,0,0,0,0,0,0,0,0,0,76,35,0,0,72,35,0,0,86,12,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,240,76,4,0,208,217,2,0,0,0,0,0,0,0,0,0,160,234,7,0,32,50,4,0,0,0,0,0,192,154,4,0,208,138,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,0,0,0,2,0,0,0,0,0,3,11,32,0,0,0,0,0,0,0,0,0,0,0,252,55,0,0,240,7,0,0,0,0,0,0,0,0,0,0,4,31,0,0,218,25,0,0,210,4,0,0,20,7,0,0,122,3,0,0,24,18,0,0,236,62,0,0,152,173,145,0,0,2,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,240,77,5,0,160,203,4,0,0,0,0,0,0,0,0,0,96,159,4,0,104,46,5,0,0,0,0,0,120,16,5,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,0,0,0,2,0,0,0,0,0,0,15,0,1,0,0,0,0,0,0,0,0,0,0,24,8,0,0,182,47,0,0,0,0,0,0,0,0,0,0,76,35,0,0,2,53,0,0,86,12,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,136,240,2,0,0,0,0,0,0,0,0,0,0,0,0,0,232,167,7,0,192,217,2,0,0,0,0,0,136,9,7,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,2,0,0,0,0,0,0,15,0,1,0,0,0,0,0,0,0,0,0,0,124,43,0,0,64,13,0,0,0,0,0,0,0,0,0,0,76,35,0,0,154,39,0,0,246,13,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,136,138,4,0,160,203,4,0,0,0,0,0,0,0,0,0,216,194,1,0,32,110,4,0,0,0,0,0,136,9,7,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,15,0,1,0,0,0,0,0,0,0,0,0,0,88,44,0,0,110,10,0,0,0,0,0,0,0,0,0,0,76,35,0,0,154,39,0,0,86,12,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,32,50,3,0,160,203,4,0,0,0,0,0,0,0,0,0,160,135,3,0,200,6,3,0,0,0,0,0,144,88,7,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,15,0,1,0,0,0,0,0,0,0,0,0,0,60,45,0,0,180,26,0,0,0,0,0,0,0,0,0,0,76,35,0,0,154,39,0,0,246,19,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,40,223,6,0,160,203,4,0,0,0,0,0,0,0,0,0,96,159,4,0,176,178,6,0,0,0,0,0,136,9,7,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,15,0,1,0,0,0,0,0,0,0,0,0,0,142,57,0,0,36,20,0,0,0,0,0,0,0,0,0,0,76,35,0,0,154,39,0,0,86,12,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,168,103,7,0,160,203,4,0,0,0,0,0,0,0,0,0,96,159,4,0,24,53,7,0,0,0,0,0,136,9,7,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,15,0,1,0,0,0,0,0,0,0,0,0,0,62,27,0,0,100,29,0,0,0,0,0,0,0,0,0,0,76,35,0,0,154,39,0,0,86,12,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,192,29,4,0,160,203,4,0,0,0,0,0,0,0,0,0,216,194,1,0,56,1,4,0,0,0,0,0,144,88,7,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,15,0,1,0,0,0,0,0,0,0,0,0,0,36,3,0,0,156,21,0,0,0,0,0,0,0,0,0,0,76,35,0,0,154,39,0,0,86,12,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,168,228,1,0,8,140,2,0,0,0,0,0,0,0,0,0,216,194,1,0,240,213,1,0,0,0,0,0,144,88,7,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,15,0,1,0,0,0,0,0,0,0,0,0,0,252,46,0,0,148,20,0,0,0,0,0,0,0,0,0,0,76,35,0,0,76,47,0,0,108,5,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,136,72,7,0,0,0,0,0,72,172,6,0,0,0,0,0,168,163,7,0,168,187,3,0,0,0,0,0,112,30,8,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,1,0,1,133,0,0,4,0,0,0,0,0,0,0,0,0,112,44,0,0,220,40,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,83,6,0,0,0,0,0,200,240,5,0,0,0,0,0,0,180,6,0,16,77,6,0,8,168,6,0,72,174,3,0,88,0,3,0,232,70,6,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,4,0,0,0,0,0,0,8,4,0,0,0,0,0,0,0,0,0,0,0,200,31,0,0,104,41,0,0,0,0,0,0,0,0,0,0,104,35,0,0,36,46,0,0,82,19,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,192,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,15,7,0,0,25,7,0,0,0,0,0,0,0,0,0,216,194,1,0,8,10,7,0,0,0,0,0,176,3,7,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,15,0,8,0,0,0,0,0,0,0,0,0,0,164,34,0,0,146,2,0,0,0,0,0,0,0,0,0,0,76,35,0,0,172,36,0,0,102,4,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,0,25,7,0,0,0,0,0,0,0,0,0,0,0,0,0,216,194,1,0,24,20,7,0,0,0,0,0,8,169,7,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,2,0,0,0,0,0,0,15,0,8,0,0,0,0,0,0,0,0,0,0,120,3,0,0,214,43,0,0,0,0,0,0,0,0,0,0,76,35,0,0,172,36,0,0,102,4,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,128,231,2,0,144,122,4,0,0,0,0,0,0,0,0,0,32,127,5,0,0,81,2,0,0,0,0,0,48,224,4,0,136,153,3,0,144,222,1,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,1,0,0,6,8,0,0,0,0,0,0,0,0,0,0,0,216,49,0,0,164,22,0,0,0,0,0,0,0,0,0,0,34,58,0,0,0,0,0,0,214,5,0,0,182,2,0,0,228,18,0,0,140,15,0,0,10,61,0,0,96,49,216,0,0,128,0,0,128,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,64,84,3,0,240,86,3,0,72,172,6,0,0,0,0,0,104,129,6,0,144,82,3,0,0,0,0,0,192,154,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,133,0,8,0,0,0,0,0,0,0,0,0,0,40,1,0,0,244,25,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,86,3,0,0,0,0,0,72,172,6,0,0,0,0,0,184,230,7,0,72,86,3,0,0,0,0,0,16,85,3,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,8,0,1,133,0,8,0,0,0,0,0,0,0,0,0,0,224,24,0,0,204,10,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,20,3,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,36,7,0,0,0,0,0,72,172,6,0,0,0,0,0,168,163,7,0,216,181,3,0,0,0,0,0,80,215,3,0,208,9,3,0,176,178,3,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,8,0,0,0,0,0,0,0,0,0,0,0,146,28,0,0,76,4,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,182,1,0,0,0,0,0,72,172,6,0,0,0,0,0,56,187,1,0,208,181,1,0,128,181,1,0,248,180,1,0,112,183,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,0,0,2,0,0,0,0,0,1,5,0,0,1,0,0,0,0,0,0,0,0,0,110,30,0,0,58,4,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,219,1,0,0,0,0,0,72,172,6,0,0,0,0,0,160,217,6,0,24,217,1,0,0,0,0,0,24,215,1,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,0,0,2,0,0,0,0,0,1,5,0,0,1,0,0,0,0,0,0,0,0,0,140,16,0,0,230,33,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,220,1,0,0,0,0,0,72,172,6,0,0,0,0,0,160,217,6,0,248,219,1,0,0,0,0,0,136,239,1,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,0,0,2,0,0,0,0,0,1,5,0,16,0,0,0,0,0,0,0,0,0,0,164,52,0,0,148,31,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,84,4,0,160,203,4,0,0,0,0,0,0,0,0,0,96,159,4,0,56,57,4,0,0,0,0,0,144,88,7,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,15,0,1,0,0,0,0,0,0,0,0,0,0,80,7,0,0,36,33,0,0,0,0,0,0,0,0,0,0,76,35,0,0,154,39,0,0,86,12,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,216,165,2,0,160,203,4,0,0,0,0,0,0,0,0,0,96,159,4,0,168,151,2,0,0,0,0,0,144,88,7,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,15,0,1,0,0,0,0,0,0,0,0,0,0,206,44,0,0,22,9,0,0,0,0,0,0,0,0,0,0,76,35,0,0,154,39,0,0,86,12,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,40,197,2,0,160,203,4,0,0,0,0,0,0,0,0,0,96,159,4,0,168,180,2,0,0,0,0,0,144,88,7,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,15,0,1,0,0,0,0,0,0,0,0,0,0,52,33,0,0,58,36,0,0,0,0,0,0,0,0,0,0,76,35,0,0,154,39,0,0,86,12,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,96,175,1,0,0,0,0,0,72,172,6,0,0,0,0,0,56,187,1,0,80,174,1,0,0,0,0,0,16,174,1,0,112,183,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,0,0,2,0,0,0,0,0,1,5,0,0,1,0,0,0,0,0,0,0,0,0,242,35,0,0,204,25,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,187,1,0,0,0,0,0,72,172,6,0,0,0,0,0,56,187,1,0,136,186,1,0,176,185,1,0,64,184,1,0,112,183,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,0,0,2,0,0,0,0,0,1,5,1,0,0,0,0,0,0,0,0,0,0,0,246,18,0,0,192,40,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,166,1,0,0,0,0,0,72,172,6,0,0,0,0,0,104,171,1,0,40,166,1,0,0,0,0,0,232,165,1,0,112,183,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,0,0,2,0,0,0,0,0,1,5,0,0,1,0,0,0,0,0,0,0,0,0,230,26,0,0,106,28,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,165,1,0,0,0,0,0,72,172,6,0,0,0,0,0,104,171,1,0,168,164,1,0,0,0,0,0,184,163,1,0,112,183,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,0,0,2,0,0,0,0,0,1,5,0,0,1,0,0,0,0,0,0,0,0,0,220,59,0,0,238,11,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,222,1,0,216,227,1,0,72,172,6,0,0,0,0,0,56,172,6,0,0,221,1,0,0,0,0,0,96,223,1,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,2,0,0,2,0,0,0,0,0,1,5,128,0,0,0,0,0,0,0,0,0,0,0,72,58,0,0,164,2,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,98,19,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0])
.concat([208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,227,1,0,0,0,0,0,72,172,6,0,0,0,0,0,56,172,6,0,8,226,1,0,0,0,0,0,96,223,1,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,0,0,2,0,0,0,0,0,1,5,128,0,0,0,0,0,0,0,0,0,0,0,34,43,0,0,26,9,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,230,1,0,0,0,0,0,72,172,6,0,0,0,0,0,136,232,4,0,32,229,1,0,0,0,0,0,144,81,5,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,0,0,2,0,0,0,0,0,1,5,0,16,0,0,0,0,0,0,0,0,0,0,142,25,0,0,164,12,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,132,2,0,0,0,0,0,72,172,6,0,0,0,0,0,168,163,7,0,240,131,2,0,0,0,0,0,40,52,7,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,0,1,0,0,0,0,0,0,0,0,0,0,154,27,0,0,240,1,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,168,1,0,192,172,1,0,72,172,6,0,0,0,0,0,104,171,1,0,248,166,1,0,0,0,0,0,208,169,1,0,112,183,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,2,0,0,2,0,0,0,0,0,1,5,0,0,1,0,0,0,0,0,0,0,0,0,126,26,0,0,124,40,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,172,1,0,0,0,0,0,72,172,6,0,0,0,0,0,104,171,1,0,152,170,1,0,0,0,0,0,208,169,1,0,112,183,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,0,0,2,0,0,0,0,0,1,5,0,0,1,0,0,0,0,0,0,0,0,0,84,2,0,0,6,16,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,63,7,0,0,0,0,0,72,172,6,0,0,0,0,0,168,163,7,0,56,124,2,0,0,0,0,0,40,52,7,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,1,0,1,133,0,0,4,0,0,0,0,0,0,0,0,0,238,30,0,0,94,31,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,234,1,0,0,0,0,0,72,172,6,0,0,0,0,0,56,172,6,0,56,233,1,0,0,0,0,0,136,232,1,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,4,0,0,2,0,0,0,0,0,1,5,0,0,1,0,0,0,0,0,0,0,0,0,128,45,0,0,238,35,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,180,1,0,0,0,0,0,72,172,6,0,0,0,0,0,0,180,6,0,208,179,1,0,0,0,0,0,40,179,1,0,112,183,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,0,0,2,0,0,0,0,0,1,5,0,0,1,0,0,0,0,0,0,0,0,0,248,3,0,0,212,27,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,144,1,0,0,0,0,0,72,172,6,0,0,0,0,0,168,163,7,0,72,241,8,0,136,176,8,0,128,145,4,0,104,113,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,3,5,0,0,0,0,0,0,0,0,0,0,0,0,178,32,0,0,4,27,0,0,0,0,0,0,0,0,0,0,60,26,0,0,84,1,0,0,212,13,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,59,3,0,0,0,0,0,72,172,6,0,0,0,0,0,184,12,8,0,16,59,3,0,0,0,0,0,200,196,7,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,0,1,0,0,0,0,0,0,0,0,0,0,82,57,0,0,106,30,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,178,1,0,0,0,0,0,72,172,6,0,0,0,0,0,56,187,1,0,72,177,1,0,0,0,0,0,88,176,1,0,112,183,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,0,0,2,0,0,0,0,0,1,5,0,0,1,0,0,0,0,0,0,0,0,0,180,7,0,0,244,28,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,235,1,0,0,0,0,0,72,172,6,0,0,0,0,0,0,180,6,0,176,234,1,0,0,0,0,0,144,81,5,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,4,0,0,2,0,0,0,0,0,1,5,0,0,1,0,0,0,0,0,0,0,0,0,140,59,0,0,236,38,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,174,1,0,0,0,0,0,72,172,6,0,0,0,0,0,96,135,2,0,64,2,4,0,0,0,0,0,208,40,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,2,0,0,0,0,0,0,0,0,0,0,0,170,18,0,0,70,11,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,27,4,0,32,250,6,0,72,172,6,0,0,0,0,0,104,221,5,0,208,23,4,0,0,0,0,0,208,40,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,133,4,0,0,0,0,0,0,0,0,0,0,0,32,14,0,0,90,47,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,250,6,0,0,0,0,0,72,172,6,0,0,0,0,0,104,221,5,0,232,30,4,0,0,0,0,0,208,40,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,4,0,0,0,0,0,0,0,0,0,0,0,110,18,0,0,102,16,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,55,5,0,0,0,0,0,0,0,0,0,0,0,0,0,232,233,7,0,8,103,6,0,0,0,0,0,120,58,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,2,0,0,0,0,0,0,22,0,1,0,0,0,0,0,0,0,0,0,0,38,41,0,0,88,10,0,0,0,0,0,0,0,0,0,0,152,60,0,0,240,39,0,0,176,8,0,0,208,3,0,0,52,2,0,0,60,11,0,0,4,23,0,0,192,175,145,0,64,0,0,0,240,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,48,247,2,0,184,55,5,0,0,0,0,0,0,0,0,0,232,233,7,0,40,93,2,0,0,0,0,0,120,58,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,22,0,1,0,0,0,0,0,0,0,0,0,0,62,61,0,0,118,37,0,0,0,0,0,0,0,0,0,0,152,60,0,0,240,39,0,0,176,8,0,0,208,3,0,0,52,2,0,0,60,11,0,0,4,23,0,0,192,175,145,0,64,0,0,0,240,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,184,232,1,0,184,55,5,0,0,0,0,0,0,0,0,0,232,233,7,0,152,134,1,0,0,0,0,0,120,58,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,22,0,1,0,0,0,0,0,0,0,0,0,0,122,34,0,0,12,12,0,0,0,0,0,0,0,0,0,0,152,60,0,0,240,39,0,0,176,8,0,0,208,3,0,0,52,2,0,0,60,11,0,0,4,23,0,0,192,175,145,0,64,0,0,0,240,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,96,202,1,0,8,140,2,0,0,0,0,0,0,0,0,0,216,194,1,0,176,191,1,0,0,0,0,0,144,88,7,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,15,0,1,0,0,0,0,0,0,0,0,0,0,192,31,0,0,102,32,0,0,0,0,0,0,0,0,0,0,76,35,0,0,76,47,0,0,108,5,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,48,114,2,0,8,140,2,0,0,0,0,0,0,0,0,0,96,159,4,0,136,102,2,0,0,0,0,0,248,88,2,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,15,0,1,0,0,0,0,0,0,0,0,0,0,174,53,0,0,136,38,0,0,0,0,0,0,0,0,0,0,76,35,0,0,76,47,0,0,162,11,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,168,250,1,0,8,140,2,0,0,0,0,0,0,0,0,0,216,194,1,0,160,240,1,0,0,0,0,0,192,154,4,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,15,0,1,0,0,0,0,0,0,0,0,0,0,108,5,0,0,8,48,0,0,0,0,0,0,0,0,0,0,76,35,0,0,76,47,0,0,170,4,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,128,73,2,0,8,140,2,0,0,0,0,0,0,0,0,0,96,159,4,0,176,60,2,0,0,0,0,0,144,88,7,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,15,0,1,0,0,0,0,0,0,0,0,0,0,96,41,0,0,24,25,0,0,0,0,0,0,0,0,0,0,76,35,0,0,76,47,0,0,162,11,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,16,184,1,0,8,140,2,0,0,0,0,0,0,0,0,0,216,194,1,0,248,176,1,0,0,0,0,0,192,154,4,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,0,0,0,2,0,0,0,0,0,0,15,0,1,0,0,0,0,0,0,0,0,0,0,0,21,0,0,122,19,0,0,0,0,0,0,0,0,0,0,76,35,0,0,76,47,0,0,226,14,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,8,140,2,0,0,0,0,0,0,0,0,0,0,0,0,0,96,159,4,0,88,129,2,0,0,0,0,0,248,39,8,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,2,0,0,0,0,0,0,15,0,1,0,0,0,0,0,0,0,0,0,0,48,42,0,0,160,26,0,0,0,0,0,0,0,0,0,0,76,35,0,0,76,47,0,0,162,11,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,24,14,2,0,8,140,2,0,0,0,0,0,0,0,0,0,216,194,1,0,56,6,2,0,0,0,0,0,248,39,8,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,15,0,1,0,0,0,0,0,0,0,0,0,0,116,10,0,0,36,15,0,0,0,0,0,0,0,0,0,0,76,35,0,0,76,47,0,0,108,5,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,32,212,4,0,80,219,4,0,72,172,6,0,0,0,0,0,144,33,2,0,144,208,4,0,0,0,0,0,32,215,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,48,3,1,133,0,8,0,0,1,0,0,0,0,0,0,0,206,19,0,0,10,40,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,70,16,0,0,16,11,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,4,2,0,80,219,4,0,72,172,6,0,0,0,0,0,144,33,2,0,200,3,2,0,0,0,0,0,192,154,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,48,1,1,133,0,8,0,0,1,0,0,0,0,0,0,0,254,14,0,0,124,14,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,220,6,0,0,16,11,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,219,4,0,0,0,0,0,72,172,6,0,0,0,0,0,144,33,2,0,184,217,4,0,0,0,0,0,32,215,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,48,3,1,133,0,8,0,0,1,0,0,0,0,0,0,0,108,1,0,0,192,44,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,70,16,0,0,16,11,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,101,2,0,216,104,2,0,72,172,6,0,0,0,0,0,56,172,6,0,120,99,2,0,0,0,0,0,208,102,2,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,16,1,1,133,0,8,0,0,1,0,0,0,0,0,0,0,160,45,0,0,226,0,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,146,15,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,104,2,0,0,0,0,0,72,172,6,0,0,0,0,0,56,172,6,0,160,103,2,0,0,0,0,0,208,102,2,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,16,1,1,133,0,8,0,0,1,0,0,0,0,0,0,0,146,31,0,0,156,31,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,146,15,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,138,5,0,112,147,5,0,72,172,6,0,0,0,0,0,184,230,7,0,208,133,5,0,0,0,0,0,128,145,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,8,0,1,133,0,8,0,0,1,0,0,0,0,0,0,0,120,18,0,0,112,21,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,12,0,0,0,84,19,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,130,5,0,112,147,5,0,72,172,6,0,0,0,0,0,184,230,7,0,168,126,5,0,0,0,0,0,192,154,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,8,0,1,133,0,8,0,0,1,0,0,0,0,0,0,0,150,23,0,0,254,0,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,0,18,0,0,84,19,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,147,5,0,0,0,0,0,72,172,6,0,0,0,0,0,184,230,7,0,192,141,5,0,0,0,0,0,128,145,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,72,0,1,133,0,8,0,0,1,0,0,0,0,0,0,0,34,16,0,0,226,20,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,182,5,0,0,84,19,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,123,7,0,0,0,0,0,72,172,6,0,0,0,0,0,168,163,7,0,96,37,3,0,0,0,0,0,80,126,7,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,1,0,1,133,0,8,0,0,1,0,0,0,0,0,0,0,14,44,0,0,162,25,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,45,2,0,8,140,2,0,0,0,0,0,0,0,0,0,96,159,4,0,168,33,2,0,0,0,0,0,152,23,2,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,15,0,1,0,0,0,0,0,0,0,0,0,0,88,33,0,0,24,9,0,0,0,0,0,0,0,0,0,0,76,35,0,0,76,47,0,0,162,11,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,144,143,1,0,8,140,2,0,0,0,0,0,0,0,0,0,32,127,5,0,72,130,1,0,0,0,0,0,144,88,7,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,15,0,1,0,0,0,0,0,0,0,0,0,0,142,37,0,0,144,31,0,0,0,0,0,0,0,0,0,0,214,60,0,0,8,46,0,0,128,10,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,128,170,1,0,8,140,2,0,0,0,0,0,0,0,0,0,32,127,5,0,136,154,1,0,0,0,0,0,144,88,7,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,15,0,1,0,0,0,0,0,0,0,0,0,0,182,5,0,0,226,8,0,0,0,0,0,0,0,0,0,0,214,60,0,0,8,46,0,0,128,10,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,8,194,4,0,80,219,4,0,72,172,6,0,0,0,0,0,144,33,2,0,88,190,4,0,0,0,0,0,192,154,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,48,1,1,133,0,8,0,0,1,0,0,0,0,0,0,0,186,43,0,0,154,2,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,72,19,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,204,4,0,0,0,0,0,0,0,0,0,0,0,0,0,144,33,2,0,248,197,4,0,0,0,0,0,32,215,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,48,3,4,5,0,8,0,0,1,0,0,0,0,0,0,0,22,12,0,0,26,40,0,0,0,0,0,0,0,0,0,0,208,59,0,0,160,6,0,0,70,16,0,0,16,11,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,98,2,0,216,104,2,0,72,172,6,0,0,0,0,0,56,172,6,0,112,97,2,0,0,0,0,0,192,154,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,16,1,1,133,0,8,0,0,1,0,0,0,0,0,0,0,154,36,0,0,110,16,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,146,15,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,82,8,0,0,0,0,0,0,0,0,0,0,0,0,0,232,167,7,0,200,77,8,0,0,0,0,0,200,71,8,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,2,0,0,0,0,0,0,15,0,1,0,0,0,0,0,0,0,0,0,0,150,38,0,0,254,30,0,0,0,0,0,0,0,0,0,0,158,1,0,0,222,15,0,0,86,14,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,56,233,8,0,96,240,4,0,0,0,0,0,0,0,0,0,232,167,7,0,16,168,8,0,0,0,0,0,88,46,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,53,0,0,0,2,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,78,2,0,0,214,40,0,0,0,0,0,0,0,0,0,0,136,21,0,0,234,1,0,0,38,5,0,0,84,2,0,0,72,6,0,0,178,17,0,0,24,42,0,0,0,0,0,0,64,1,0,0,192,0,0,0,240,0,0,0,3,0,0,0,4,0,0,0,48,142,5,0,0,0,0,0,0,0,0,0,0,0,0,0,232,167,7,0,152,114,6,0,0,0,0,0,120,0,5,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,1,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,88,26,0,0,196,13,0,0,0,0,0,0,0,0,0,0,150,52,0,0,78,32,0,0,162,5,0,0,158,17,0,0,16,0,0,0,216,5,0,0,156,23,0,0,0,0,0,0,128,0,0,0,248,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,168,48,8,0,96,240,4,0,0,0,0,0,0,0,0,0,232,167,7,0,56,252,7,0,0,0,0,0,88,46,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,53,0,0,0,2,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,32,6,0,0,22,47,0,0,0,0,0,0,0,0,0,0,136,21,0,0,234,1,0,0,38,5,0,0,84,2,0,0,72,6,0,0,178,17,0,0,24,42,0,0,0,0,0,0,64,1,0,0,192,0,0,0,240,0,0,0,3,0,0,0,4,0,0,0,8,199,7,0,96,240,4,0,0,0,0,0,0,0,0,0,232,167,7,0,152,150,7,0,0,0,0,0,104,238,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,85,0,0,0,2,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,12,54,0,0,60,5,0,0,0,0,0,0,0,0,0,0,136,21,0,0,234,1,0,0,38,5,0,0,84,2,0,0,72,6,0,0,178,17,0,0,24,42,0,0,0,0,0,0,64,1,0,0,192,0,0,0,240,0,0,0,3,0,0,0,4,0,0,0,8,242,2,0,96,240,4,0,0,0,0,0,0,0,0,0,232,167,7,0,32,89,2,0,0,0,0,0,232,228,1,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,8,9,0,0,56,29,0,0,0,0,0,0,0,0,0,0,136,21,0,0,234,1,0,0,38,5,0,0,84,2,0,0,72,6,0,0,178,17,0,0,24,42,0,0,0,0,0,0,64,1,0,0,192,0,0,0,240,0,0,0,3,0,0,0,4,0,0,0,136,130,1,0,96,240,4,0,0,0,0,0,0,0,0,0,232,167,7,0,72,44,1,0,0,0,0,0,232,228,1,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,72,2,0,0,244,4,0,0,0,0,0,0,0,0,0,0,136,21,0,0,234,1,0,0,38,5,0,0,84,2,0,0,72,6,0,0,178,17,0,0,24,42,0,0,0,0,0,0,64,1,0,0,192,0,0,0,240,0,0,0,3,0,0,0,4,0,0,0,96,240,4,0,0,0,0,0,0,0,0,0,0,0,0,0,232,167,7,0,200,90,6,0,0,0,0,0,104,238,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,248,8,0,0,102,6,0,0,0,0,0,0,0,0,0,0,136,21,0,0,234,1,0,0,38,5,0,0,84,2,0,0,72,6,0,0,178,17,0,0,24,42,0,0,0,0,0,0,64,1,0,0,192,0,0,0,240,0,0,0,3,0,0,0,4,0,0,0,40,114,7,0,0,0,0,0,72,172,6,0,0,0,0,0,32,127,5,0,216,196,3,0,0,0,0,0,80,215,3,0,208,9,3,0,48,194,3,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,0,16,0,0,0,0,0,0,0,0,0,0,174,52,0,0,244,24,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,204,2,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,128,248,5,0,0,0,0,0,144,84,8,0,120,137,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,3,11,0,0,8,0,0,0,0,0,0,0,0,0,234,34,0,0,222,6,0,0,0,0,0,0,0,0,0,0,234,49,0,0,0,0,0,0,168,1,0,0,212,14,0,0,4,16,0,0,60,15,0,0,220,58,0,0,0,0,0,0,0,0,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,58,3,0,0,0,0,0,72,172,6,0,0,0,0,0,104,221,5,0,80,56,3,0,0,0,0,0,120,53,3,0,208,9,3,0,8,51,3,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,64,1,133,0,0,2,0,0,0,0,0,0,0,0,0,202,34,0,0,186,30,0,0,0,0,0,0,0,0,0,0,200,29,0,0,126,48,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,73,3,0,0,0,0,0,72,172,6,0,0,0,0,0,184,12,8,0,136,72,3,0,0,0,0,0,160,161,8,0,208,9,3,0,112,71,3,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,0,16,0,0,0,0,0,0,0,0,0,0,96,44,0,0,226,43,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,122,4,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,152,68,6,0,0,0,0,0,48,224,4,0,136,153,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,1,0,0,6,8,0,0,0,0,0,0,0,0,0,0,0,244,21,0,0,148,12,0,0,0,0,0,0,0,0,0,0,34,58,0,0,0,0,0,0,214,5,0,0,182,2,0,0,228,18,0,0,140,15,0,0,10,61,0,0,96,49,216,0,0,128,0,0,128,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,64,69,5,0,192,69,5,0,0,0,0,0,0,0,0,0,240,3,2,0,200,68,5,0,0,0,0,0,80,89,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,58,57,0,0,148,37,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,174,3,0,136,174,3,0,0,0,0,0,0,0,0,0,32,127,5,0,48,174,3,0,0,0,0,0,48,55,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,212,2,0,0,212,12,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,174,3,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,120,174,3,0,0,0,0,0,48,55,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,240,18,0,0,232,38,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,170,7,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,184,166,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,170,1,0,0,164,38,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,174,3,0,216,174,3,0,0,0,0,0,0,0,0,0,240,3,2,0,144,174,3,0,0,0,0,0,216,121,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,246,51,0,0,224,36,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,174,3,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,176,174,3,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,96,39,0,0,78,19,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,175,3,0,40,176,3,0,0,0,0,0,0,0,0,0,0,38,7,0,8,175,3,0,0,0,0,0,168,95,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,52,27,0,0,110,25,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,176,3,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,112,175,3,0,0,0,0,0,168,95,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,228,57,0,0,172,13,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,176,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,56,176,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,18,63,0,0,80,26,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,176,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,128,176,3,0,0,0,0,0,104,176,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,244,34,0,0,72,5,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,177,3,0,104,177,3,0,0,0,0,0,0,0,0,0,144,47,2,0,8,177,3,0,0,0,0,0,160,150,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,46,27,0,0,240,14,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,177,3,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,80,177,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,48,25,0,0,232,5,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,177,3,0,40,178,3,0,0,0,0,0,0,0,0,0,0,38,7,0,176,177,3,0,0,0,0,0,248,177,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,132,12,0,0,220,29,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,244,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,40,210,4,0,0,0,0,0,192,181,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,210,48,0,0,204,8,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,178,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,0,178,3,0,0,0,0,0,248,177,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,40,63,0,0,52,10,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,178,3,0,88,162,7,0,0,0,0,0,0,0,0,0,104,221,5,0,72,178,3,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,180,20,0,0,94,45,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,162,7,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,72,157,7,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,66,35,0,0,176,10,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,179,3,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,128,179,3,0,0,0,0,0,160,51,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,24,50,0,0,132,2,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0])
.concat([4,0,0,0,3,0,0,0,232,180,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,136,180,3,0,0,0,0,0,168,66,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,144,44,0,0,54,8,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,181,3,0,232,180,3,0,0,0,0,0,0,0,0,0,0,38,7,0,192,180,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,202,0,0,0,150,14,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,180,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,232,179,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,60,50,0,0,228,0,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,181,3,0,40,182,3,0,0,0,0,0,0,0,0,0,144,47,2,0,48,181,3,0,0,0,0,0,120,67,7,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,106,58,0,0,68,13,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,182,3,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,0,182,3,0,0,0,0,0,232,62,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,158,3,0,0,158,21,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,182,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,48,182,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,50,43,0,0,92,7,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,32,183,3,0,0,0,0,0,232,182,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,100,56,0,0,72,20,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,184,3,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,248,183,3,0,0,0,0,0,232,248,7,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,134,17,0,0,152,4,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,112,183,3,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,146,47,0,0,180,16,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,188,3,0,40,189,3,0,0,0,0,0,0,0,0,0,168,163,7,0,72,188,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,66,59,0,0,236,24,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,189,3,0,0,0,0,0,0,0,0,0,0,0,0,0,168,163,7,0,24,189,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,18,37,0,0,254,10,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,201,3,0,40,202,3,0,0,0,0,0,0,0,0,0,240,3,2,0,176,201,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,174,32,0,0,10,38,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,194,3,0,144,201,3,0,0,0,0,0,0,0,0,0,0,38,7,0,72,193,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,170,27,0,0,196,2,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,193,3,0,144,201,3,0,0,0,0,0,0,0,0,0,0,38,7,0,216,192,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,226,2,0,0,20,22,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,189,3,0,144,201,3,0,0,0,0,0,0,0,0,0,0,38,7,0,72,189,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,6,5,0,0,30,48,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,192,3,0,144,201,3,0,0,0,0,0,0,0,0,0,0,38,7,0,56,192,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,62,23,0,0,64,24,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,192,3,0,144,201,3,0,0,0,0,0,0,0,0,0,0,38,7,0,104,191,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,224,8,0,0,170,34,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,191,3,0,144,201,3,0,0,0,0,0,0,0,0,0,0,38,7,0,168,190,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,36,7,0,0,210,25,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,190,3,0,144,201,3,0,0,0,0,0,0,0,0,0,0,38,7,0,16,190,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,130,6,0,0,174,43,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,201,3,0,144,201,3,0,0,0,0,0,0,0,0,0,0,38,7,0,240,200,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,138,18,0,0,150,0,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,200,3,0,144,201,3,0,0,0,0,0,0,0,0,0,0,38,7,0,8,200,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,40,9,0,0,254,42,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,199,3,0,144,201,3,0,0,0,0,0,0,0,0,0,0,38,7,0,64,199,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,176,34,0,0,254,32,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,199,3,0,144,201,3,0,0,0,0,0,0,0,0,0,0,38,7,0,224,198,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,28,9,0,0,194,26,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,198,3,0,144,201,3,0,0,0,0,0,0,0,0,0,0,38,7,0,144,198,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,10,17,0,0,34,12,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,197,3,0,144,201,3,0,0,0,0,0,0,0,0,0,0,38,7,0,112,197,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,136,53,0,0,178,15,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,197,3,0,144,201,3,0,0,0,0,0,0,0,0,0,0,38,7,0,24,197,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,138,4,0,0,74,26,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,196,3,0,144,201,3,0,0,0,0,0,0,0,0,0,0,38,7,0,96,196,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,80,62,0,0,118,36,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,196,3,0,144,201,3,0,0,0,0,0,0,0,0,0,0,38,7,0,8,196,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,254,52,0,0,0,45,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,195,3,0,144,201,3,0,0,0,0,0,0,0,0,0,0,38,7,0,168,195,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,88,37,0,0,220,25,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,195,3,0,144,201,3,0,0,0,0,0,0,0,0,0,0,38,7,0,24,195,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,60,32,0,0,176,23,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,194,3,0,144,201,3,0,0,0,0,0,0,0,0,0,0,38,7,0,160,194,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,122,57,0,0,106,9,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,201,3,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,80,201,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,178,8,0,0,26,48,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,202,3,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,232,201,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,96,15,0,0,220,12,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,185,3,0,104,185,3,0,0,0,0,0,0,0,0,0,168,163,7,0,192,184,3,0,0,0,0,0,88,78,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,9,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,42,28,0,0,226,45,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,185,3,0,0,0,0,0,0,0,0,0,0,0,0,0,168,163,7,0,120,184,3,0,0,0,0,0,88,78,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,9,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,28,1,0,0,232,45,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,185,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,152,185,3,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,134,24,0,0,130,39,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,10,1,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,136,9,1,0,0,0,0,0,104,9,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,48,45,0,0,38,14,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,186,3,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,0,186,3,0,0,0,0,0,72,246,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,244,28,0,0,2,29,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,188,3,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,184,187,3,0,0,0,0,0,0,187,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,108,2,0,0,228,37,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,37,4,0,216,37,4,0,0,0,0,0,0,0,0,0,0,38,7,0,48,37,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,14,62,0,0,158,44,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,36,4,0,216,37,4,0,0,0,0,0,0,0,0,0,0,38,7,0,80,36,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,110,6,0,0,202,32,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,35,4,0,216,37,4,0,0,0,0,0,0,0,0,0,0,38,7,0,64,35,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,0,27,0,0,136,5,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,37,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,192,37,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,110,44,0,0,6,21,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,203,3,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,128,203,3,0,0,0,0,0,40,47,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,164,46,0,0,134,43,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,203,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,184,203,3,0,0,0,0,0,40,47,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,234,6,0,0,212,0,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,204,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,232,203,3,0,0,0,0,0,48,143,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,14,39,0,0,250,35,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,202,3,0,112,203,3,0,0,0,0,0,0,0,0,0,32,127,5,0,104,202,3,0,0,0,0,0,48,143,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,198,26,0,0,162,18,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,203,3,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,200,202,3,0,0,0,0,0,48,143,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,154,45,0,0,42,27,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,204,3,0,0,0,0,0,0,0,0,0,0,0,0,0,168,163,7,0,192,204,3,0,0,0,0,0,168,204,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,210,31,0,0,82,25,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,207,3,0,80,212,3,0,0,0,0,0,0,0,0,0,240,3,2,0,72,207,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,172,42,0,0,44,16,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,211,3,0,80,212,3,0,0,0,0,0,0,0,0,0,240,3,2,0,96,211,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,158,59,0,0,196,17,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,211,3,0,80,212,3,0,0,0,0,0,0,0,0,0,240,3,2,0,0,211,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,220,49,0,0,114,14,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,210,3,0,80,212,3,0,0,0,0,0,0,0,0,0,240,3,2,0,120,210,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,182,56,0,0,242,5,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,210,3,0,80,212,3,0,0,0,0,0,0,0,0,0,0,38,7,0,216,209,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,152,48,0,0,68,11,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,209,3,0,80,212,3,0,0,0,0,0,0,0,0,0,0,38,7,0,184,208,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,246,55,0,0,22,34,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,208,3,0,80,212,3,0,0,0,0,0,0,0,0,0,0,38,7,0,96,208,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,196,49,0,0,224,22,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,210,3,0,80,212,3,0,0,0,0,0,0,0,0,0,0,38,7,0,48,210,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,52,44,0,0,98,44,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,208,3,0,80,212,3,0,0,0,0,0,0,0,0,0,0,38,7,0,8,208,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,50,11,0,0,138,37,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,207,3,0,80,212,3,0,0,0,0,0,0,0,0,0,0,38,7,0,176,207,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,154,50,0,0,4,42,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,212,3,0,0,0,0,0,0,0,0,0,0,0,0,0,184,12,8,0,152,212,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,62,34,0,0,178,11,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,213,3,0,0,0,0,0,0,0,0,0,0,0,0,0,168,163,7,0,32,213,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,52,34,0,0,196,45,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,232,3,0,24,233,3,0,0,0,0,0,0,0,0,0,0,38,7,0,40,232,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,174,25,0,0,176,34,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,231,3,0,24,233,3,0,0,0,0,0,0,0,0,0,0,38,7,0,0,231,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,120,33,0,0,76,20,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,230,3,0,24,233,3,0,0,0,0,0,0,0,0,0,0,38,7,0,96,230,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,148,7,0,0,112,13,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,223,3,0,24,233,3,0,0,0,0,0,0,0,0,0,32,127,5,0,104,223,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,56,52,0,0,112,29,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,223,3,0,24,233,3,0,0,0,0,0,0,0,0,0,32,127,5,0,192,222,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,178,45,0,0,172,8,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,222,3,0,24,233,3,0,0,0,0,0,0,0,0,0,32,127,5,0,16,222,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,74,11,0,0,120,15,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,221,3,0,24,233,3,0,0,0,0,0,0,0,0,0,32,127,5,0,40,221,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,60,8,0,0,222,42,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,220,3,0,24,233,3,0,0,0,0,0,0,0,0,0,32,127,5,0,160,219,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,180,32,0,0,244,29,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,219,3,0,24,233,3,0,0,0,0,0,0,0,0,0,32,127,5,0,216,218,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,88,30,0,0,108,43,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,218,3,0,24,233,3,0,0,0,0,0,0,0,0,0,32,127,5,0,88,218,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,24,40,0,0,234,20,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,218,3,0,24,233,3,0])
.concat([0,0,0,0,0,0,0,0,32,127,5,0,240,217,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,246,36,0,0,218,18,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,217,3,0,24,233,3,0,0,0,0,0,0,0,0,0,32,127,5,0,96,216,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,228,13,0,0,136,39,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,215,3,0,24,233,3,0,0,0,0,0,0,0,0,0,32,127,5,0,168,214,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,110,14,0,0,24,19,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,214,3,0,24,233,3,0,0,0,0,0,0,0,0,0,32,127,5,0,200,213,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,206,46,0,0,162,13,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,230,3,0,24,233,3,0,0,0,0,0,0,0,0,0,32,127,5,0,232,229,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,2,0,0,0,216,44,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,229,3,0,24,233,3,0,0,0,0,0,0,0,0,0,32,127,5,0,48,229,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,158,43,0,0,168,41,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,228,3,0,24,233,3,0,0,0,0,0,0,0,0,0,32,127,5,0,192,228,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,250,60,0,0,40,33,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,227,3,0,24,233,3,0,0,0,0,0,0,0,0,0,32,127,5,0,48,227,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,152,52,0,0,106,38,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,227,3,0,24,233,3,0,0,0,0,0,0,0,0,0,32,127,5,0,200,226,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,70,60,0,0,214,12,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,226,3,0,24,233,3,0,0,0,0,0,0,0,0,0,32,127,5,0,88,226,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,10,54,0,0,182,1,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,226,3,0,24,233,3,0,0,0,0,0,0,0,0,0,32,127,5,0,232,225,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,24,48,0,0,94,23,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,225,3,0,24,233,3,0,0,0,0,0,0,0,0,0,32,127,5,0,72,225,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,62,15,0,0,34,2,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,225,3,0,24,233,3,0,0,0,0,0,0,0,0,0,32,127,5,0,88,224,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,218,54,0,0,4,21,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,233,3,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,240,232,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,116,29,0,0,250,24,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,212,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,48,212,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,178,46,0,0,56,15,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,143,5,0,72,144,5,0,0,0,0,0,0,0,0,0,144,47,2,0,72,143,5,0,0,0,0,0,176,67,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,212,23,0,0,160,35,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,205,3,0,104,205,3,0,0,0,0,0,0,0,0,0,144,47,2,0,24,205,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,224,60,0,0,152,25,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,205,3,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,72,205,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,64,30,0,0,54,17,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,205,3,0,232,206,3,0,0,0,0,0,0,0,0,0,32,127,5,0,136,205,3,0,0,0,0,0,32,230,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,16,11,0,0,188,31,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,206,3,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,208,205,3,0,0,0,0,0,32,230,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,66,40,0,0,230,10,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,32,8,0,160,33,8,0,0,0,0,0,0,0,0,0,96,135,2,0,168,31,8,0,0,0,0,0,72,246,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,56,8,0,0,68,3,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,233,3,0,152,234,3,0,0,0,0,0,0,0,0,0,96,135,2,0,40,233,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,230,2,0,0,248,41,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,233,3,0,152,234,3,0,0,0,0,0,0,0,0,0,96,135,2,0,128,233,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,158,34,0,0,82,12,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,234,3,0,152,234,3,0,0,0,0,0,0,0,0,0,96,135,2,0,224,233,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,168,34,0,0,230,3,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,234,3,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,80,234,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,236,9,0,0,156,0,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,12,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,152,12,4,0,0,0,0,0,192,77,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,94,46,0,0,82,45,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,15,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,168,14,4,0,0,0,0,0,48,143,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,144,12,0,0,134,22,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,15,4,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,184,15,4,0,0,0,0,0,40,15,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,184,0,0,0,252,43,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,15,4,0,96,16,4,0,0,0,0,0,0,0,0,0,240,3,2,0,224,15,4,0,0,0,0,0,56,127,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,0,6,0,0,20,21,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,16,4,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,32,16,4,0,0,0,0,0,56,127,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,218,40,0,0,164,11,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,102,3,0,248,54,4,0,0,0,0,0,0,0,0,0,0,46,3,0,160,101,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,252,60,0,0,148,6,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,102,3,0,24,56,4,0,0,0,0,0,0,0,0,0,0,46,3,0,32,102,3,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,116,14,0,0,250,41,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,17,4,0,136,17,4,0,0,0,0,0,0,0,0,0,240,3,2,0,128,16,4,0,0,0,0,0,88,239,7,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,116,0,0,0,106,21,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,17,4,0,136,17,4,0,0,0,0,0,0,0,0,0,0,38,7,0,48,17,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,150,4,0,0,122,14,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,17,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,112,17,4,0,0,0,0,0,88,239,7,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,4,48,0,0,2,42,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,17,4,0,168,18,4,0,0,0,0,0,0,0,0,0,96,135,2,0,152,17,4,0,0,0,0,0,144,110,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,176,22,0,0,214,47,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,18,4,0,168,18,4,0,0,0,0,0,0,0,0,0,96,135,2,0,232,17,4,0,0,0,0,0,144,110,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,200,9,0,0,254,14,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,18,4,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,40,18,4,0,0,0,0,0,144,110,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,2,2,0,0,170,1,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,134,7,0,72,136,7,0,0,0,0,0,0,0,0,0,144,47,2,0,200,133,7,0,0,0,0,0,40,225,7,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,16,52,0,0,154,17,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,19,4,0,128,20,4,0,0,0,0,0,0,0,0,0,240,3,2,0,248,18,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,164,27,0,0,74,3,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,19,4,0,128,20,4,0,0,0,0,0,0,0,0,0,240,3,2,0,144,19,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,164,56,0,0,78,41,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,20,4,0,128,20,4,0,0,0,0,0,0,0,0,0,0,38,7,0,248,19,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,20,31,0,0,214,21,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,20,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,72,20,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,160,33,0,0,16,26,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,21,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,96,21,4,0,0,0,0,0,72,21,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,0,53,0,0,40,13,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,240,3,0,48,246,3,0,0,0,0,0,0,0,0,0,0,38,7,0,112,240,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,44,20,0,0,130,27,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,240,3,0,48,246,3,0,0,0,0,0,0,0,0,0,0,38,7,0,16,240,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,246,37,0,0,46,43,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,239,3,0,48,246,3,0,0,0,0,0,0,0,0,0,0,38,7,0,128,239,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,68,53,0,0,168,5,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,239,3,0,48,246,3,0,0,0,0,0,0,0,0,0,0,38,7,0,200,238,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,190,41,0,0,66,18,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,238,3,0,48,246,3,0,0,0,0,0,0,0,0,0,0,38,7,0,136,238,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,186,44,0,0,236,36,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,238,3,0,48,246,3,0,0,0,0,0,0,0,0,0,0,38,7,0,40,238,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,52,3,0,0,230,20,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,238,3,0,48,246,3,0,0,0,0,0,0,0,0,0,0,38,7,0,200,237,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,14,16,0,0,56,25,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,236,3,0,48,246,3,0,0,0,0,0,0,0,0,0,0,38,7,0,8,236,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,82,15,0,0,92,0,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,235,3,0,48,246,3,0,0,0,0,0,0,0,0,0,0,38,7,0,152,235,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,64,52,0,0,240,20,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,235,3,0,48,246,3,0,0,0,0,0,0,0,0,0,0,38,7,0,48,235,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,112,49,0,0,176,32,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,235,3,0,48,246,3,0,0,0,0,0,0,0,0,0,0,38,7,0,240,234,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,222,48,0,0,54,23,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,244,3,0,48,246,3,0,0,0,0,0,0,0,0,0,0,38,7,0,32,244,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,250,40,0,0,54,28,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,244,3,0,48,246,3,0,0,0,0,0,0,0,0,0,0,38,7,0,208,243,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,116,2,0,0,82,32,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,241,3,0,48,246,3,0,0,0,0,0,0,0,0,0,0,38,7,0,192,240,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,104,27,0,0,92,38,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,243,3,0,48,246,3,0,0,0,0,0,0,0,0,0,0,38,7,0,128,243,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,184,39,0,0,28,27,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,243,3,0,48,246,3,0,0,0,0,0,0,0,0,0,0,38,7,0,16,243,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,74,42,0,0,156,13,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,242,3,0,48,246,3,0,0,0,0,0,0,0,0,0,0,38,7,0,200,241,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,124,38,0,0,204,27,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,241,3,0,48,246,3,0,0,0,0,0,0,0,0,0,0,38,7,0,88,241,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,106,30,0,0,104,11,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,245,3,0,48,246,3,0,0,0,0,0,0,0,0,0,0,46,3,0,224,244,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,236,24,0,0,50,26,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,22,4,0,152,22,4,0,0,0,0,0,0,0,0,0,104,221,5,0,240,21,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,254,3,0,0,102,41,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,22,4,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,88,22,4,0,0,0,0,0,232,62,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,44,49,0,0,132,12,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,26,4,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,88,26,4,0,0,0,0,0,216,121,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,218,29,0,0,192,36,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,153,3,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,240,152,3,0,0,0,0,0,104,167,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,35,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,2,29,0,0,206,28,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,246,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,24,246,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,32,7,0,0,96,19,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,27,4,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,224,26,4,0,0,0,0,0,248,39,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,154,56,0,0,50,21,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,246,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,88,246,3,0,0,0,0,0,88,239,7,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,98,56,0,0,208,47,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,250,3,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,184,249,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,32,38,0,0,144,44,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,247,3,0,24,250,3,0,0,0,0,0,0,0,0,0,184,168,7,0,224,246,3,0])
.concat([0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,30,21,0,0,142,47,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,248,3,0,24,250,3,0,0,0,0,0,0,0,0,0,184,168,7,0,152,247,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,60,1,0,0,164,39,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,252,3,0,24,12,4,0,0,0,0,0,0,0,0,0,0,38,7,0,64,252,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,18,46,0,0,100,33,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,11,4,0,24,12,4,0,0,0,0,0,0,0,0,0,0,38,7,0,144,11,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,14,19,0,0,62,19,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,3,4,0,24,12,4,0,0,0,0,0,0,0,0,0,0,38,7,0,136,3,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,124,36,0,0,42,8,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,11,4,0,24,12,4,0,0,0,0,0,0,0,0,0,0,38,7,0,64,11,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,6,10,0,0,26,46,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,3,4,0,24,12,4,0,0,0,0,0,0,0,0,0,0,38,7,0,168,2,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,242,61,0,0,222,23,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,2,4,0,24,12,4,0,0,0,0,0,0,0,0,0,0,38,7,0,200,1,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,208,22,0,0,32,20,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,1,4,0,24,12,4,0,0,0,0,0,0,0,0,0,0,38,7,0,240,0,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,146,17,0,0,86,44,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,0,4,0,24,12,4,0,0,0,0,0,0,0,0,0,0,38,7,0,24,0,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,172,58,0,0,162,35,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,10,4,0,24,12,4,0,0,0,0,0,0,0,0,0,0,38,7,0,8,10,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,182,40,0,0,130,20,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,255,3,0,24,12,4,0,0,0,0,0,0,0,0,0,0,38,7,0,120,254,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,94,15,0,0,12,3,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,254,3,0,24,12,4,0,0,0,0,0,0,0,0,0,0,38,7,0,160,253,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,70,44,0,0,8,37,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,253,3,0,24,12,4,0,0,0,0,0,0,0,0,0,0,38,7,0,216,252,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,216,54,0,0,174,9,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,9,4,0,24,12,4,0,0,0,0,0,0,0,0,0,0,38,7,0,0,9,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,134,55,0,0,182,0,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,8,4,0,24,12,4,0,0,0,0,0,0,0,0,0,0,38,7,0,24,8,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,214,57,0,0,8,32,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,7,4,0,24,12,4,0,0,0,0,0,0,0,0,0,0,38,7,0,16,7,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,98,40,0,0,204,42,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,7,4,0,24,12,4,0,0,0,0,0,0,0,0,0,0,38,7,0,32,6,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,190,32,0,0,210,21,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,5,4,0,24,12,4,0,0,0,0,0,0,0,0,0,0,38,7,0,120,5,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,232,5,0,0,186,12,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,5,4,0,24,12,4,0,0,0,0,0,0,0,0,0,0,38,7,0,208,4,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,74,5,0,0,32,21,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,4,4,0,24,12,4,0,0,0,0,0,0,0,0,0,0,38,7,0,96,4,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,142,42,0,0,206,46,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,4,4,0,24,12,4,0,0,0,0,0,0,0,0,0,0,38,7,0,248,3,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,194,35,0,0,82,3,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,12,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,224,11,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,10,4,0,0,230,9,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,249,3,0,24,250,3,0,0,0,0,0,0,0,0,0,184,168,7,0,144,248,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,48,41,0,0,74,9,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,251,3,0,0,252,3,0,0,0,0,0,0,0,0,0,96,135,2,0,208,250,3,0,0,0,0,0,88,239,7,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,74,1,0,0,170,41,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,252,3,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,192,251,3,0,0,0,0,0,88,239,7,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,4,49,0,0,50,40,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,13,4,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,160,13,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,1,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,238,29,0,0,162,8,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,13,4,0,248,13,4,0,0,0,0,0,0,0,0,0,144,47,2,0,96,13,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,1,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,192,52,0,0,160,13,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,14,4,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,24,14,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,50,5,0,0,120,38,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,27,4,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,160,27,4,0,0,0,0,0,48,18,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,234,61,0,0,4,16,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,28,4,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,64,28,4,0,0,0,0,0,120,175,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,132,11,0,0,62,23,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,28,4,0,0,0,0,0,0,0,0,0,0,0,0,0,232,28,4,0,200,28,4,0,0,0,0,0,32,230,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,102,18,0,0,124,18,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,251,6,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,160,29,4,0,0,0,0,0,64,207,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,44,42,0,0,96,35,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,31,4,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,0,31,4,0,0,0,0,0,112,242,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,44,14,0,0,106,39,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,32,4,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,72,32,4,0,0,0,0,0,112,242,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,44,17,0,0,104,19,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,32,4,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,136,32,4,0,0,0,0,0,192,181,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,116,8,0,0,46,20,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,33,4,0,192,33,4,0,0,0,0,0,0,0,0,0,0,38,7,0,216,32,4,0,0,0,0,0,48,143,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,138,15,0,0,214,1,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,33,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,152,33,4,0,0,0,0,0,48,143,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,80,57,0,0,230,21,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,102,3,0,16,131,5,0,0,0,0,0,0,0,0,0,0,46,3,0,80,102,3,0,0,0,0,0,40,132,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,156,9,0,0,50,27,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,34,4,0,184,34,4,0,0,0,0,0,0,0,0,0,144,47,2,0,208,33,4,0,0,0,0,0,40,52,7,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,32,5,0,0,242,10,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,34,4,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,168,34,4,0,0,0,0,0,56,206,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,70,21,0,0,80,17,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,35,4,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,216,34,4,0,0,0,0,0,72,187,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,32,21,0,0,204,1,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,151,7,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,208,150,7,0,0,0,0,0,48,18,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,170,40,0,0,54,3,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,38,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,248,37,4,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,70,10,0,0,214,15,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,38,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,80,38,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,40,27,0,0,50,18,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,39,4,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,240,38,4,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,126,1,0,0,60,2,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,63,4,0,224,63,4,0,0,0,0,0,0,0,0,0,144,47,2,0,144,63,4,0,0,0,0,0,64,246,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,230,59,0,0,20,16,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,38,4,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,184,38,4,0,0,0,0,0,112,139,7,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,134,19,0,0,182,35,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,139,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,168,138,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,24,59,0,0,68,36,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,43,4,0,32,44,4,0,0,0,0,0,0,0,0,0,0,38,7,0,168,43,4,0,0,0,0,0,224,183,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,188,61,0,0,216,39,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,44,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,8,44,4,0,0,0,0,0,224,183,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,132,18,0,0,90,28,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,146,7,0,96,147,7,0,0,0,0,0,0,0,0,0,0,38,7,0,64,144,7,0,0,0,0,0,160,200,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,220,23,0,0,136,40,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,39,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,184,39,4,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,8,0,0,0,246,9,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,42,4,0,160,43,4,0,0,0,0,0,0,0,0,0,168,163,7,0,72,42,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,124,48,0,0,186,3,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,42,4,0,160,43,4,0,0,0,0,0,0,0,0,0,168,163,7,0,0,42,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,50,59,0,0,180,31,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,41,4,0,160,43,4,0,0,0,0,0,0,0,0,0,168,163,7,0,96,41,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,184,3,0,0,226,35,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,41,4,0,160,43,4,0,0,0,0,0,0,0,0,0,168,163,7,0,232,40,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,160,14,0,0,198,24,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,40,4,0,160,43,4,0,0,0,0,0,0,0,0,0,168,163,7,0,8,40,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,90,20,0,0,30,38,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,42,4,0,160,43,4,0,0,0,0,0,0,0,0,0,184,12,8,0,176,42,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,198,58,0,0,52,41,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,43,4,0,0,0,0,0,0,0,0,0,0,0,0,0,184,12,8,0,56,43,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,226,58,0,0,170,5,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,44,4,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,48,44,4,0,0,0,0,0,24,21,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,36,15,0,0,216,20,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,126,4,0,80,127,4,0,0,0,0,0,0,0,0,0,184,168,7,0,168,126,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,152,47,0,0,30,26,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,127,4,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,48,127,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,72,6,0,0,180,40,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,216,4,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,168,215,4,0,0,0,0,0,48,143,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,200,15,0,0,232,44,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,49,4,0,144,51,4,0,0,0,0,0,0,0,0,0,32,127,5,0,24,49,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,160,27,0,0,88,4,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,49,4,0,144,51,4,0,0,0,0,0,0,0,0,0,32,127,5,0,152,49,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,68,29,0,0,52,16,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,50,4,0,144,51,4,0,0,0,0,0,0,0,0,0,32,127,5,0,240,49,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,84,57,0,0,38,32,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,47,4,0,240,48,4,0,0,0,0,0,0,0,0,0,168,163,7,0,208,46,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,30,55,0,0,128,9,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,46,4,0,240,48,4,0,0,0,0,0,0,0,0,0,168,163,7,0,128,46,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,40,24,0,0,110,45,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,46,4,0,240,48,4,0,0,0,0,0,0,0,0,0,168,163,7,0,48,46,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,66,56,0,0,20,7,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,45,4,0,240,48,4,0,0,0,0,0,0,0,0,0,168,163,7,0,168,45,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,34,62,0,0,108,20,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,44,4,0,240,48,4,0,0,0,0,0,0,0,0,0,168,163,7,0,80,44,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,230,1,0,0,206,33,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,48,4,0,240,48,4,0,0,0,0,0,0,0,0,0,168,163,7,0,24,47,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,82,3,0,0,22,37,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,48,4,0,0,0,0,0,0,0,0,0,0,0,0,0,168,163,7,0,216,48,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,32,57,0,0,102,40,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,51,4,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,144,50,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,44,29,0,0,174,18,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,39,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,144,39,4,0,0,0,0,0,48,143,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,94,47,0,0,44,38,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,53,4,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,96,53,4,0,0,0,0,0,232,62,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,250,21,0,0,192,6,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,55,4,0,24,56,4,0,0,0,0,0,0,0,0,0,144,47,2,0,24,55,4,0,0,0,0,0,240,201,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,210,20,0,0,186,44,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,54,4,0,248,54,4,0,0,0,0,0,0,0,0,0,144,47,2,0,8,54,4,0,0,0,0,0,120,67,7,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,62,45,0,0,218,26,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,54,4,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,136,54,4,0,0,0,0,0,232,62,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,122,46,0,0,116,24,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,56,4,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,192,55,4,0,0,0,0,0,232,62,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,216,5,0,0,74,39,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,56,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,48,56,4,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,184,48,0,0,40,36,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,56,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,160,56,4,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,202,32,0,0,28,47,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,57,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,24,57,4,0,0,0,0,0,192,181,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,32,24,0,0,28,8,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,147,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,160,147,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,106,7,0,0,32,7,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,59,4,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,176,57,4,0,0,0,0,0,144,110,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,10,24,0,0,54,34,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,60,4,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,216,59,4,0,0,0,0,0,24,215,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,190,51,0,0,92,11,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,62,4,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,40,62,4,0,0,0,0,0,160,88,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,80,17,0,0,182,7,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,64,4,0,176,65,4,0,0,0,0,0,0,0,0,0,168,163,7,0,56,64,4,0,0,0,0,0,80,235,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,126,18,0,0,58,39,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,65,4,0,0,0,0,0,0,0,0,0,0,0,0,0,168,163,7,0,64,65,4,0,0,0,0,0,48,143,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,144,61,0,0,10,31,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,147,3,0,128,63,4,0,0,0,0,0,0,0,0,0,0,46,3,0,152,146,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,228,24,0,0,118,7,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,63,4,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,56,63,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,184,6,0,0,154,11,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,63,4,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,248,62,4,0,0,0,0,0,32,11,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,120,52,0,0,26,20,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,63,4,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,200,63,4,0,0,0,0,0,64,246,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,12,60,0,0,106,29,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,160,6,0,32,163,6,0,0,0,0,0,0,0,0,0,96,135,2,0,40,159,6,0,0,0,0,0,72,246,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,90,48,0,0,142,45,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,66,4,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,224,65,4,0,0,0,0,0,72,246,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,74,34,0,0,132,47,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,66,4,0,224,67,4,0,0,0,0,0,0,0,0,0,96,135,2,0,144,66,4,0,0,0,0,0,0,193,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,58,4,0,0,216,24,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,67,4,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,200,66,4,0,0,0,0,0,0,193,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,172,29,0,0,0,47,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,5,1,0,144,8,1,0,0,0,0,0,0,0,0,0,0,46,3,0,104,4,1,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,144,58,0,0,142,29,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,68,4,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,136,68,4,0,0,0,0,0,72,68,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,242,25,0,0,176,38,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,68,4,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,0,68,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,166,27,0,0,214,36,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,69,4,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,224,68,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,176,19,0,0,234,39,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,70,4,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,208,69,4,0,0,0,0,0,144,110,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,46,9,0,0,170,33,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,13,4,0,248,13,4,0,0,0,0,0,0,0,0,0,168,163,7,0,208,12,4,0,0,0,0,0,168,66,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,1,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,232,45,0,0,4,26,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,70,4,0,8,71,4,0,0,0,0,0,0,0,0,0,0,46,3,0,160,70,4,0,0,0,0,0,136,60,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,52,35,0,0,194,16,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,71,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,208,70,4,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,110,16,0,0,184,0,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,90,4,0,48,93,4,0,0,0,0,0,0,0,0,0,240,3,2,0,120,90,4,0,0,0,0,0,168,95,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,112,33,0,0,226,24,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,91,4,0,48,93,4,0,0,0,0,0,0,0,0,0,240,3,2,0,240,90,4,0,0,0,0,0,168,95,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,20,63,0,0,254,46,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,93,4,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,32,92,4,0,0,0,0,0,168,95,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,204,25,0,0,54,7,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,103,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,128,103,3,0,0,0,0,0,120,103,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,100,6,0,0,152,24,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,93,4,0,16,94,4,0,0,0,0,0,0,0,0,0,0,38,7,0,104,93,4,0,0,0,0,0,168,95,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,210,22,0,0,150,32,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,94,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,224,93,4,0,0,0,0,0,168,95,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,236,7,0,0,28,16,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,119,4,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,160,119,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,174,46,0,0,84,47,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,71,4,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,56,71,4,0,0,0,0,0,48,143,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,182,44,0,0,188,25,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,148,3,0,0,0,0,0,0,0,0,0,0,0,0,0,168,163,7,0,176,148,3,0,0,0,0,0,104,148,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,82,49,0,0,196,35,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,71,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,160,71,4,0,0,0,0,0,128,223,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,46,2,0,0,248,13,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,72,4,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,56,72,4,0,0,0,0,0,232,246,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,132,51,0,0,98,15,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,120,4,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,200,120,4,0,0,0,0,0,40,225,7,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,252,23,0,0,238,28,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,74,4,0,184,74,4,0,0,0,0,0,0,0,0,0,96,135,2,0,24,74,4,0,0,0,0,0,240,201,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,206,11,0,0,188,33,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,74,4,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,128,74,4,0,0,0,0,0,232,62,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,66,18,0,0,242,0,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,102,3,0,72,191,6,0,0,0,0,0,0,0,0,0,0,46,3,0,120,102,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,234,3,0,0,98,33,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,74,4,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,200,74,4,0,0,0,0,0,160,95,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,242,40,0,0,92,23,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,95,4,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,128,95,4,0,0,0,0,0,192,218,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,32,39,0,0,92,42,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,72,4,0,208,72,4,0,0,0,0,0,0,0,0,0,32,127,5,0,112,72,4,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,32,44,0,0,24,3,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,72,4,0,0,0,0,0,0,0,0,0,0,0,0,0,168,163,7,0,184,72,4,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,252,36,0,0,246,19,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,74,4,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,96,73,4,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,46,15,0,0,200,44,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,75,4,0,8,76,4,0,0,0,0,0,0,0,0,0,168,163,7,0,96,75,4,0,0,0,0,0,32,189,7,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,250,2,0,0,48,21,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,76,4,0,0,0,0,0,0,0,0,0,0,0,0,0,168,163,7,0,168,75,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,12,34,0,0,252,1,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,75,4,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,24,75,4,0,0,0,0,0,24,125,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,104,52,0,0,224,42,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,76,4,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,64,76,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,118,26,0,0,192,7,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,70,4,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,48,70,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,112,21,0,0,16,16,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,76,4,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,120,76,4,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,24,18,0,0,184,4,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,77,4,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,248,76,4,0,0,0,0,0,232,115,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,252,10,0,0,4,38,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,78,4,0,160,153,1,0,0,0,0,0,0,0,0,0,240,3,2,0,64,78,4,0,0,0,0,0,160,202,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,36,52,0,0,172,39,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,79,4,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,200,78,4,0,0,0,0,0,152,67,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,102,51,0,0,156,16,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,79,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,168,79,4,0,0,0,0,0,232,246,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,80,61,0,0,84,25,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,153,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,192,153,3,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,39,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,62,51,0,0,146,1,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,153,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,112,153,3,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,50,17,0,0,58,22,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,81,4,0,232,82,4,0,0,0,0,0,0,0,0,0,0,38,7,0,232,80,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,94,3,0,0,144,17,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,82,4,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,136,82,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,230,8,0,0,242,8,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,83,4,0,216,83,4,0,0,0,0,0,0,0,0,0,144,47,2,0,40,83,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,38,30,0,0,10,16,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,83,4,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,160,83,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,136,23,0,0,146,47,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,87,4,0,200,87,4,0,0,0,0,0,0,0,0,0,96,135,2,0,0,87,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0])
.concat([2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,230,24,0,0,164,36,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,84,4,0,216,86,4,0,0,0,0,0,0,0,0,0,240,3,2,0,0,84,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,178,55,0,0,26,45,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,85,4,0,216,86,4,0,0,0,0,0,0,0,0,0,240,3,2,0,184,84,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,214,20,0,0,48,16,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,86,4,0,216,86,4,0,0,0,0,0,0,0,0,0,240,3,2,0,160,85,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,38,55,0,0,176,2,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,86,4,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,88,86,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,136,11,0,0,176,24,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,87,4,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,128,87,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,16,14,0,0,178,1,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,99,4,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,8,99,4,0,0,0,0,0,64,246,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,236,27,0,0,168,11,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,89,4,0,0,0,0,0,0,0,0,0,0,0,0,0,168,163,7,0,16,89,4,0,0,0,0,0,96,19,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,76,3,0,0,210,40,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,90,4,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,176,89,4,0,0,0,0,0,96,19,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,192,4,0,0,66,26,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,103,4,0,56,105,4,0,0,0,0,0,0,0,0,0,240,3,2,0,0,103,4,0,0,0,0,0,168,95,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,30,50,0,0,230,44,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,104,4,0,56,105,4,0,0,0,0,0,0,0,0,0,240,3,2,0,200,103,4,0,0,0,0,0,168,95,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,42,36,0,0,64,33,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,106,4,0,72,107,4,0,0,0,0,0,0,0,0,0,96,135,2,0,136,106,4,0,0,0,0,0,168,95,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,160,55,0,0,250,26,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,103,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,192,102,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,230,10,0,0,104,21,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,105,4,0,72,107,4,0,0,0,0,0,0,0,0,0,96,135,2,0,88,105,4,0,0,0,0,0,168,95,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,90,61,0,0,84,3,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,105,4,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,216,104,4,0,0,0,0,0,168,95,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,218,60,0,0,250,42,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,107,4,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,248,106,4,0,0,0,0,0,168,95,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,182,57,0,0,16,9,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,94,4,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,32,94,4,0,0,0,0,0,224,218,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,48,52,0,0,208,18,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,94,4,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,96,94,4,0,0,0,0,0,144,110,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,24,29,0,0,224,39,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,94,4,0,56,95,4,0,0,0,0,0,0,0,0,0,168,163,7,0,184,94,4,0,0,0,0,0,56,24,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,118,28,0,0,96,12,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,95,4,0,0,0,0,0,0,0,0,0,0,0,0,0,168,163,7,0,0,95,4,0,0,0,0,0,56,24,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,106,3,0,0,166,16,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,11,5,0,136,11,5,0,0,0,0,0,0,0,0,0,0,38,7,0,208,10,5,0,0,0,0,0,232,246,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,222,35,0,0,22,13,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,95,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,96,95,4,0,0,0,0,0,96,198,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,32,30,0,0,26,27,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,185,4,0,40,91,8,0,0,0,0,0,0,0,0,0,32,127,5,0,192,185,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,16,20,0,0,96,8,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,187,4,0,40,91,8,0,0,0,0,0,0,0,0,0,0,38,7,0,16,187,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,224,55,0,0,24,2,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,186,4,0,40,91,8,0,0,0,0,0,0,0,0,0,0,38,7,0,160,186,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,4,34,0,0,66,41,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,188,4,0,40,91,8,0,0,0,0,0,0,0,0,0,32,127,5,0,200,187,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,238,24,0,0,204,0,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,188,4,0,40,91,8,0,0,0,0,0,0,0,0,0,0,38,7,0,88,188,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,160,39,0,0,144,30,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,189,4,0,40,91,8,0,0,0,0,0,0,0,0,0,32,127,5,0,248,188,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,228,54,0,0,128,12,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,189,4,0,40,91,8,0,0,0,0,0,0,0,0,0,32,127,5,0,96,189,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,224,51,0,0,36,38,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,97,8,0,40,91,8,0,0,0,0,0,0,0,0,0,32,127,5,0,112,83,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,0,44,0,0,126,43,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,91,8,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,192,189,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,186,31,0,0,12,11,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,98,4,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,168,98,4,0,0,0,0,0,48,18,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,166,5,0,0,136,10,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,99,4,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,64,99,4,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,136,40,0,0,232,0,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,96,4,0,192,96,4,0,0,0,0,0,0,0,0,0,144,47,2,0,232,95,4,0,0,0,0,0,64,246,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,68,31,0,0,82,21,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,96,4,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,168,96,4,0,0,0,0,0,64,246,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,134,9,0,0,222,38,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,97,4,0,160,97,4,0,0,0,0,0,0,0,0,0,96,135,2,0,64,97,4,0,0,0,0,0,72,122,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,94,22,0,0,236,13,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,97,4,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,112,97,4,0,0,0,0,0,72,122,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,48,3,0,0,18,15,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,98,4,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,216,97,4,0,0,0,0,0,72,122,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,92,45,0,0,78,29,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,98,4,0,136,112,7,0,0,0,0,0,0,0,0,0,184,168,7,0,104,98,4,0,0,0,0,0,72,122,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,108,37,0,0,138,30,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,112,7,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,240,105,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,188,15,0,0,248,4,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,140,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,240,139,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,72,39,0,0,232,37,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,100,4,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,0,100,4,0,0,0,0,0,192,172,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,150,34,0,0,16,45,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,100,4,0,16,101,4,0,0,0,0,0,0,0,0,0,144,47,2,0,184,100,4,0,0,0,0,0,72,246,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,236,37,0,0,68,12,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,101,4,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,232,100,4,0,0,0,0,0,72,246,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,238,4,0,0,198,23,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,124,4,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,40,124,4,0,0,0,0,0,40,47,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,204,16,0,0,206,12,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,101,4,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,144,101,4,0,0,0,0,0,8,116,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,26,38,0,0,48,2,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,102,4,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,208,101,4,0,0,0,0,0,8,116,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,216,45,0,0,194,9,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,101,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,48,101,4,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,28,26,0,0,242,27,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,102,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,144,102,4,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,146,39,0,0,100,39,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,201,5,0,136,202,5,0,0,0,0,0,0,0,0,0,96,135,2,0,40,201,5,0,0,0,0,0,160,88,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,154,60,0,0,4,5,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,107,4,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,176,107,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,226,22,0,0,80,45,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,117,4,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,208,116,4,0,0,0,0,0,168,200,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,98,26,0,0,116,31,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,108,4,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,120,108,4,0,0,0,0,0,32,0,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,2,33,0,0,82,41,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,109,4,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,216,108,4,0,0,0,0,0,176,211,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,178,35,0,0,72,43,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,113,4,0,64,114,4,0,0,0,0,0,0,0,0,0,240,3,2,0,240,112,4,0,0,0,0,0,32,0,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,12,59,0,0,250,5,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,113,4,0,64,114,4,0,0,0,0,0,0,0,0,0,240,3,2,0,80,113,4,0,0,0,0,0,32,0,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,230,60,0,0,166,8,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,114,4,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,16,114,4,0,0,0,0,0,32,0,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,66,23,0,0,46,26,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,111,4,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,232,110,4,0,0,0,0,0,32,0,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,238,60,0,0,216,0,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,112,4,0,208,112,4,0,0,0,0,0,0,0,0,0,0,38,7,0,232,111,4,0,0,0,0,0,32,0,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,78,27,0,0,234,45,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,112,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,168,112,4,0,0,0,0,0,32,0,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,56,60,0,0,98,10,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,109,4,0,248,109,4,0,0,0,0,0,0,0,0,0,0,38,7,0,80,109,4,0,0,0,0,0,32,0,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,160,7,0,0,34,38,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,109,4,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,176,109,4,0,0,0,0,0,32,0,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,218,0,0,0,136,26,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,110,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,80,110,4,0,0,0,0,0,32,0,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,186,51,0,0,42,0,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,115,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,248,114,4,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,230,47,0,0,106,7,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,114,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,112,114,4,0,0,0,0,0,32,0,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,0,49,0,0,138,21,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,117,4,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,136,117,4,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,4,18,0,0,98,41,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,118,4,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,48,118,4,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,238,19,0,0,98,14,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,100,4,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,88,100,4,0,0,0,0,0,144,110,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,178,21,0,0,196,26,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,148,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,16,148,3,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,244,39,0,0,134,5,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,48,8,0,40,64,8,0,0,0,0,0,0,0,0,0,0,38,7,0,32,48,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,80,2,0,0,10,10,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,54,8,0,40,64,8,0,0,0,0,0,0,0,0,0,0,38,7,0,216,53,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,184,2,0,0,122,44,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,63,8,0,40,64,8,0,0,0,0,0,0,0,0,0,0,38,7,0,200,62,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0])
.concat([196,53,0,0,126,54,0,0,240,31,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,53,8,0,40,64,8,0,0,0,0,0,0,0,0,0,0,38,7,0,96,52,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,212,31,0,0,152,13,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,51,8,0,40,64,8,0,0,0,0,0,0,0,0,0,0,38,7,0,96,51,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,38,52,0,0,0,46,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,50,8,0,40,64,8,0,0,0,0,0,0,0,0,0,0,38,7,0,176,49,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,60,51,0,0,216,23,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,61,8,0,40,64,8,0,0,0,0,0,0,0,0,0,0,38,7,0,152,60,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,194,60,0,0,236,28,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,60,8,0,40,64,8,0,0,0,0,0,0,0,0,0,0,38,7,0,144,58,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,200,2,0,0,144,18,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,58,8,0,40,64,8,0,0,0,0,0,0,0,0,0,0,38,7,0,232,57,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,112,43,0,0,18,8,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,57,8,0,40,64,8,0,0,0,0,0,0,0,0,0,0,38,7,0,24,57,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,194,21,0,0,16,40,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,57,8,0,40,64,8,0,0,0,0,0,0,0,0,0,0,38,7,0,32,56,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,182,55,0,0,236,1,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,55,8,0,40,64,8,0,0,0,0,0,0,0,0,0,0,38,7,0,56,55,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,158,30,0,0,192,15,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,64,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,232,63,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,110,43,0,0,144,45,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,118,4,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,152,118,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,160,5,0,0,44,0,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,120,4,0,104,120,4,0,0,0,0,0,0,0,0,0,144,47,2,0,232,119,4,0,0,0,0,0,64,207,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,188,31,0,0,216,13,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,120,4,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,72,120,4,0,0,0,0,0,64,207,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,60,31,0,0,100,24,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,124,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,64,124,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,188,55,0,0,14,11,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,104,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,232,103,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,168,19,0,0,202,3,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,118,1,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,152,106,1,0,0,0,0,0,248,39,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,184,29,0,0,92,37,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,122,4,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,8,122,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,98,35,0,0,16,7,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,122,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,80,122,4,0,0,0,0,0,88,78,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,150,49,0,0,202,17,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,122,4,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,120,122,4,0,0,0,0,0,160,88,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,150,15,0,0,44,5,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,105,3,0,8,124,4,0,0,0,0,0,0,0,0,0,0,46,3,0,160,104,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,28,49,0,0,202,4,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,123,4,0,8,124,4,0,0,0,0,0,0,0,0,0,96,135,2,0,112,123,4,0,0,0,0,0,48,143,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,162,13,0,0,94,38,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,123,4,0,8,124,4,0,0,0,0,0,0,0,0,0,0,38,7,0,208,122,4,0,0,0,0,0,56,56,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,120,54,0,0,30,19,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,124,4,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,216,123,4,0,0,0,0,0,48,143,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,38,16,0,0,44,13,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,124,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,144,124,4,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,214,52,0,0,168,9,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,125,4,0,152,126,4,0,0,0,0,0,0,0,0,0,240,3,2,0,216,124,4,0,0,0,0,0,120,175,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,84,5,0,0,58,9,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,126,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,48,126,4,0,0,0,0,0,120,175,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,40,50,0,0,112,12,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,128,4,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,224,127,4,0,0,0,0,0,232,62,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,152,44,0,0,216,2,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,128,4,0,136,129,4,0,0,0,0,0,0,0,0,0,104,221,5,0,152,128,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,190,28,0,0,20,46,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,129,4,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,88,129,4,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,68,6,0,0,212,10,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,130,4,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,240,129,4,0,0,0,0,0,200,129,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,166,49,0,0,210,4,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,134,4,0,72,136,4,0,0,0,0,0,0,0,0,0,144,47,2,0,232,133,4,0,0,0,0,0,168,155,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,114,58,0,0,134,2,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,134,4,0,72,136,4,0,0,0,0,0,0,0,0,0,144,47,2,0,88,134,4,0,0,0,0,0,168,155,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,140,26,0,0,154,39,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,136,4,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,248,135,4,0,0,0,0,0,168,155,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,136,24,0,0,84,17,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,130,4,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,96,130,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,60,49,0,0,88,2,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,29,5,0,144,121,7,0,0,0,0,0,0,0,0,0,240,3,2,0,112,29,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,62,0,0,0,80,31,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,30,5,0,144,121,7,0,0,0,0,0,0,0,0,0,240,3,2,0,240,29,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,110,5,0,0,228,27,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,31,5,0,144,121,7,0,0,0,0,0,0,0,0,0,240,3,2,0,176,30,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,40,26,0,0,56,37,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,99,5,0,136,102,5,0,0,0,0,0,0,0,0,0,184,168,7,0,40,99,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,62,29,0,0,194,21,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,148,4,0,176,148,4,0,0,0,0,0,0,0,0,0,184,168,7,0,32,148,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,232,55,0,0,100,30,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,148,4,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,128,148,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,58,35,0,0,16,39,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,156,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,128,156,3,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,34,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,138,36,0,0,116,45,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,162,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,96,162,3,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,32,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,44,37,0,0,226,40,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,149,4,0,144,150,4,0,0,0,0,0,0,0,0,0,184,168,7,0,160,149,4,0,0,0,0,0,216,28,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,248,15,0,0,182,25,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,150,4,0,144,150,4,0,0,0,0,0,0,0,0,0,184,168,7,0,16,150,4,0,0,0,0,0,24,21,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,110,7,0,0,46,31,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,150,4,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,104,150,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,144,8,0,0,106,45,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,143,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,88,143,4,0,0,0,0,0,144,110,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,96,54,0,0,250,20,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,131,4,0,192,133,4,0,0,0,0,0,0,0,0,0,96,135,2,0,128,131,4,0,0,0,0,0,8,116,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,178,17,0,0,82,42,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,133,4,0,192,133,4,0,0,0,0,0,0,0,0,0,96,135,2,0,152,132,4,0,0,0,0,0,8,116,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,36,4,0,0,92,6,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,133,4,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,112,133,4,0,0,0,0,0,72,246,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,140,36,0,0,248,35,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,159,1,0,80,161,1,0,0,0,0,0,0,0,0,0,96,135,2,0,176,159,1,0,0,0,0,0,64,246,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,144,2,0,0,154,42,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,9,1,0,40,10,1,0,0,0,0,0,0,0,0,0,144,47,2,0,8,9,1,0,0,0,0,0,104,9,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,154,1,0,0,28,6,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,153,4,0,8,154,4,0,0,0,0,0,0,0,0,0,184,168,7,0,216,152,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,114,15,0,0,184,26,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,154,4,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,176,153,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,58,6,0,0,200,11,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,157,4,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,32,157,4,0,0,0,0,0,192,181,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,76,28,0,0,240,22,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,157,4,0,160,160,4,0,0,0,0,0,0,0,0,0,240,3,2,0,88,157,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,122,61,0,0,152,20,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,158,4,0,160,160,4,0,0,0,0,0,0,0,0,0,0,38,7,0,168,157,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,162,39,0,0,148,30,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,159,4,0,160,160,4,0,0,0,0,0,0,0,0,0,0,38,7,0,48,159,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,156,24,0,0,252,37,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,160,4,0,160,160,4,0,0,0,0,0,0,0,0,0,0,38,7,0,248,159,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,18,44,0,0,4,6,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,158,4,0,160,160,4,0,0,0,0,0,0,0,0,0,192,227,4,0,120,158,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,150,53,0,0,138,16,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,160,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,80,160,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,60,23,0,0,168,22,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,205,4,0,208,206,4,0,0,0,0,0,0,0,0,0,0,38,7,0,208,204,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,148,57,0,0,192,5,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,203,4,0,208,206,4,0,0,0,0,0,0,0,0,0,0,38,7,0,136,202,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,154,17,0,0,40,10,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,202,4,0,208,206,4,0,0,0,0,0,0,0,0,0,0,38,7,0,168,201,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,16,9,0,0,42,11,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,201,4,0,208,206,4,0,0,0,0,0,0,0,0,0,0,38,7,0,224,200,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,216,22,0,0,146,22,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,199,4,0,208,206,4,0,0,0,0,0,0,0,0,0,0,38,7,0,16,199,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,156,15,0,0,2,28,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,198,4,0,208,206,4,0,0,0,0,0,0,0,0,0,0,38,7,0,80,198,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,48,22,0,0,84,2,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,206,4,0,208,206,4,0,0,0,0,0,0,0,0,0,0,38,7,0,88,205,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,172,47,0,0,74,4,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,206,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,104,206,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,24,1,0,0,234,0,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,190,4,0,64,191,4,0,0,0,0,0,0,0,0,0,104,221,5,0,0,190,4,0,0,0,0,0,112,119,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,128,53,0,0,86,16,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,191,4,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,208,190,4,0,0,0,0,0,184,190,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,174,57,0,0,46,41,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,161,4,0,88,162,4,0,0,0,0,0,0,0,0,0,0,38,7,0,8,161,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,240,4,0,0,226,19,0,0,0,0,0,0])
.concat([0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,162,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,40,162,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,100,21,0,0,24,22,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,164,4,0,104,165,4,0,0,0,0,0,0,0,0,0,104,221,5,0,128,164,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,34,11,0,0,62,35,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,163,4,0,88,164,4,0,0,0,0,0,0,0,0,0,104,221,5,0,192,162,4,0,0,0,0,0,88,239,7,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,144,49,0,0,226,11,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,164,4,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,48,164,4,0,0,0,0,0,88,239,7,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,230,20,0,0,164,4,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,165,4,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,248,164,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,180,23,0,0,18,36,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,192,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,168,191,4,0,0,0,0,0,232,246,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,70,55,0,0,22,25,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,192,4,0,232,194,4,0,0,0,0,0,0,0,0,0,96,135,2,0,104,192,4,0,0,0,0,0,160,200,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,72,53,0,0,62,33,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,193,4,0,232,194,4,0,0,0,0,0,0,0,0,0,240,3,2,0,248,192,4,0,0,0,0,0,160,200,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,218,50,0,0,136,3,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,194,4,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,16,194,4,0,0,0,0,0,160,200,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,158,22,0,0,14,33,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,65,8,0,144,65,8,0,0,0,0,0,0,0,0,0,96,135,2,0,152,64,8,0,0,0,0,0,40,47,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,242,9,0,0,56,31,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,207,4,0,224,207,4,0,0,0,0,0,0,0,0,0,32,127,5,0,0,207,4,0,0,0,0,0,48,144,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,120,53,0,0,124,5,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,207,4,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,104,207,4,0,0,0,0,0,224,212,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,200,56,0,0,246,29,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,137,4,0,56,28,7,0,0,0,0,0,0,0,0,0,104,174,7,0,112,136,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,238,26,0,0,38,0,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,28,7,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,120,25,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,254,36,0,0,156,35,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,105,3,0,8,68,8,0,0,0,0,0,0,0,0,0,0,46,3,0,168,105,3,0,0,0,0,0,40,132,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,54,53,0,0,110,30,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,105,3,0,208,15,4,0,0,0,0,0,0,0,0,0,0,46,3,0,128,105,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,96,55,0,0,182,27,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,195,4,0,128,196,4,0,0,0,0,0,0,0,0,0,0,38,7,0,24,195,4,0,0,0,0,0,48,143,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,36,36,0,0,144,21,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,196,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,48,196,4,0,0,0,0,0,48,143,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,76,6,0,0,202,27,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,196,4,0,104,197,4,0,0,0,0,0,0,0,0,0,144,47,2,0,168,196,4,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,206,41,0,0,228,28,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,197,4,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,40,197,4,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,212,3,0,0,116,38,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,209,4,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,16,209,4,0,0,0,0,0,144,110,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,172,4,0,0,90,43,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,208,4,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,192,208,4,0,0,0,0,0,112,139,7,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,152,17,0,0,182,37,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,64,5,0,104,64,5,0,0,0,0,0,0,0,0,0,144,47,2,0,8,64,5,0,0,0,0,0,64,246,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,48,9,0,0,116,8,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,64,5,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,80,64,5,0,0,0,0,0,64,246,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,30,33,0,0,138,0,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,156,4,0,224,156,4,0,0,0,0,0,0,0,0,0,96,135,2,0,56,156,4,0,0,0,0,0,168,95,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,36,12,0,0,202,14,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,156,4,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,160,156,4,0,0,0,0,0,168,95,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,114,19,0,0,118,26,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,240,4,0,168,124,8,0,0,0,0,0,0,0,0,0,240,3,2,0,168,240,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,70,53,0,0,32,43,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,241,4,0,168,124,8,0,0,0,0,0,0,0,0,0,240,3,2,0,48,241,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,72,23,0,0,232,16,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,242,4,0,168,124,8,0,0,0,0,0,0,0,0,0,240,3,2,0,184,242,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,124,13,0,0,58,35,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,242,4,0,168,124,8,0,0,0,0,0,0,0,0,0,240,3,2,0,136,241,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,236,26,0,0,90,29,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,124,8,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,136,120,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,4,25,0,0,156,33,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,69,8,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,136,66,8,0,0,0,0,0,40,47,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,98,6,0,0,184,36,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,182,4,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,240,181,4,0,0,0,0,0,64,207,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,210,45,0,0,248,17,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,140,4,0,32,141,4,0,0,0,0,0,0,0,0,0,32,127,5,0,216,139,4,0,0,0,0,0,168,178,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,208,12,0,0,122,5,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,141,4,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,200,140,4,0,0,0,0,0,168,178,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,62,58,0,0,24,12,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,138,4,0,192,139,4,0,0,0,0,0,0,0,0,0,0,38,7,0,232,137,4,0,0,0,0,0,192,223,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,7,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,50,3,0,0,132,37,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,138,4,0,192,139,4,0,0,0,0,0,0,0,0,0,0,38,7,0,80,138,4,0,0,0,0,0,192,223,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,7,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,254,9,0,0,192,27,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,139,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,224,138,4,0,0,0,0,0,192,223,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,7,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,176,5,0,0,56,20,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,105,3,0,248,120,4,0,0,0,0,0,0,0,0,0,0,46,3,0,8,105,3,0,0,0,0,0,40,132,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,176,41,0,0,178,29,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,142,4,0,56,143,4,0,0,0,0,0,0,0,0,0,104,221,5,0,64,142,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,160,48,0,0,110,15,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,143,4,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,168,142,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,162,7,0,0,110,3,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,182,4,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,88,182,4,0,0,0,0,0,72,182,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,168,6,0,0,204,20,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,157,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,136,157,3,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,24,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,200,61,0,0,56,34,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,106,3,0,144,170,8,0,0,0,0,0,0,0,0,0,0,46,3,0,112,106,3,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,164,54,0,0,78,30,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,210,4,0,184,210,4,0,0,0,0,0,0,0,0,0,32,127,5,0,160,209,4,0,0,0,0,0,48,143,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,4,24,0,0,214,24,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,210,4,0,0,0,0,0,0,0,0,0,0,0,0,0,168,163,7,0,72,210,4,0,0,0,0,0,224,212,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,110,42,0,0,178,25,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,211,4,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,248,210,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,1,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,0,1,0,0,220,3,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,212,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,48,212,4,0,0,0,0,0,168,66,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,242,32,0,0,134,23,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,107,3,0,80,29,1,0,0,0,0,0,0,0,0,0,0,46,3,0,192,106,3,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,4,26,0,0,200,27,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,213,4,0,144,213,4,0,0,0,0,0,0,0,0,0,240,3,2,0,248,212,4,0,0,0,0,0,176,67,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,2,27,0,0,80,44,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,213,4,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,120,213,4,0,0,0,0,0,248,39,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,224,19,0,0,166,17,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,213,4,0,88,83,5,0,0,0,0,0,0,0,0,0,96,135,2,0,176,213,4,0,0,0,0,0,248,39,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,150,59,0,0,204,45,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,114,5,0,88,83,5,0,0,0,0,0,0,0,0,0,96,135,2,0,200,53,5,0,0,0,0,0,176,67,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,154,8,0,0,24,11,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,83,5,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,248,213,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,208,0,0,0,76,14,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,215,4,0,0,0,0,0,0,0,0,0,0,0,0,0,168,163,7,0,16,214,4,0,0,0,0,0,224,218,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,170,41,0,0,20,39,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,215,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,80,215,4,0,0,0,0,0,136,108,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,90,6,0,0,204,9,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,177,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,232,174,7,0,0,0,0,0,40,47,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,144,33,0,0,80,23,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,216,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,48,216,4,0,0,0,0,0,48,143,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,150,33,0,0,242,21,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,216,4,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,120,216,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,62,54,0,0,232,11,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,217,4,0,112,218,4,0,0,0,0,0,0,0,0,0,32,127,5,0,208,216,4,0,0,0,0,0,48,143,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,98,17,0,0,32,15,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,218,4,0,112,218,4,0,0,0,0,0,0,0,0,0,32,127,5,0,240,217,4,0,0,0,0,0,48,143,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,76,23,0,0,112,11,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,218,4,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,80,218,4,0,0,0,0,0,48,143,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,30,38,0,0,130,47,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,218,4,0,88,219,4,0,0,0,0,0,0,0,0,0,144,47,2,0,144,218,4,0,0,0,0,0,104,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,80,45,0,0,78,23,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,218,4,0,88,219,4,0,0,0,0,0,0,0,0,0,96,135,2,0,200,218,4,0,0,0,0,0,224,109,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,228,8,0,0,2,45,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,219,4,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,8,219,4,0,0,0,0,0,72,246,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,182,61,0,0,164,27,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,220,4,0,168,220,4,0,0,0,0,0,0,0,0,0,0,38,7,0,64,220,4,0,0,0,0,0,168,95,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,182,47,0,0,232,27,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,220,4,0,168,220,4,0,0,0,0,0,0,0,0,0,0,38,7,0,224,219,4,0,0,0,0,0,168,95,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,82,6,0,0,4,40,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,220,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,144,220,4,0,0,0,0,0,168,95,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,20,53,0,0,60,9,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,93,3,0,112,103,3,0,0,0,0,0,0,0,0,0,240,3,2,0,0,91,3,0,0,0,0,0,80,89,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,94,9,0,0,144,36,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,141,3,0,8,142,3,0,0,0,0,0,0,0,0,0,0,46,3,0,8,141,3,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,96,2,0,0,124,31,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,142,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,168,141,3,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,122,27,0,0,90,24,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0])
.concat([226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,157,3,0,8,158,3,0,0,0,0,0,0,0,0,0,0,46,3,0,192,157,3,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,142,16,0,0,142,9,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,158,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,248,157,3,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,22,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,250,37,0,0,192,34,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,224,4,0,56,226,4,0,0,0,0,0,0,0,0,0,96,135,2,0,136,224,4,0,0,0,0,0,112,139,7,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,22,13,0,0,2,25,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,225,4,0,56,226,4,0,0,0,0,0,0,0,0,0,96,135,2,0,40,225,4,0,0,0,0,0,64,207,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,186,62,0,0,58,19,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,226,4,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,144,225,4,0,0,0,0,0,64,207,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,62,17,0,0,122,39,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,224,4,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,200,223,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,214,30,0,0,130,13,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,131,2,0,48,155,2,0,0,0,0,0,0,0,0,0,144,47,2,0,0,118,2,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,134,23,0,0,156,7,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,172,4,0,72,180,4,0,0,0,0,0,0,0,0,0,0,38,7,0,128,171,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,46,42,0,0,84,32,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,171,4,0,72,180,4,0,0,0,0,0,0,0,0,0,0,38,7,0,232,170,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,74,58,0,0,144,23,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,170,4,0,72,180,4,0,0,0,0,0,0,0,0,0,0,38,7,0,224,169,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,138,54,0,0,192,30,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,169,4,0,72,180,4,0,0,0,0,0,0,0,0,0,0,38,7,0,8,169,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,188,51,0,0,200,21,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,176,4,0,72,180,4,0,0,0,0,0,0,0,0,0,0,38,7,0,216,175,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,6,24,0,0,206,30,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,175,4,0,72,180,4,0,0,0,0,0,0,0,0,0,0,38,7,0,40,175,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,12,13,0,0,230,1,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,175,4,0,72,180,4,0,0,0,0,0,0,0,0,0,0,38,7,0,144,174,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,232,14,0,0,154,12,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,173,4,0,72,180,4,0,0,0,0,0,0,0,0,0,0,38,7,0,128,173,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,130,12,0,0,136,21,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,173,4,0,72,180,4,0,0,0,0,0,0,0,0,0,0,38,7,0,224,172,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,150,17,0,0,128,19,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,172,4,0,72,180,4,0,0,0,0,0,0,0,0,0,0,38,7,0,112,172,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,204,50,0,0,228,38,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,168,4,0,72,180,4,0,0,0,0,0,0,0,0,0,0,38,7,0,96,168,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,148,13,0,0,116,22,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,179,4,0,72,180,4,0,0,0,0,0,0,0,0,0,0,38,7,0,168,179,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,98,48,0,0,94,21,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,179,4,0,72,180,4,0,0,0,0,0,0,0,0,0,0,38,7,0,48,179,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,124,10,0,0,158,40,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,178,4,0,72,180,4,0,0,0,0,0,0,0,0,0,0,38,7,0,128,178,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,188,22,0,0,174,8,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,177,4,0,72,180,4,0,0,0,0,0,0,0,0,0,0,38,7,0,64,177,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,108,23,0,0,134,33,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,176,4,0,72,180,4,0,0,0,0,0,0,0,0,0,0,38,7,0,88,176,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,220,57,0,0,232,40,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,180,4,0,72,180,4,0,0,0,0,0,0,0,0,0,0,38,7,0,232,179,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,128,30,0,0,82,22,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,180,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,24,180,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,130,50,0,0,26,33,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,181,4,0,232,181,4,0,0,0,0,0,0,0,0,0,96,135,2,0,24,181,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,190,8,0,0,222,40,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,181,4,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,152,181,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,156,32,0,0,16,12,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,155,2,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,72,142,2,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,12,61,0,0,188,22,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,239,4,0,200,61,7,0,0,0,0,0,0,0,0,0,192,239,4,0,112,239,4,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,30,63,0,0,34,48,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,142,3,0,32,244,4,0,0,0,0,0,0,0,0,0,0,46,3,0,48,142,3,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,54,33,0,0,110,0,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,243,4,0,32,244,4,0,0,0,0,0,0,0,0,0,0,46,3,0,48,243,4,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,4,60,0,0,88,28,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,244,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,224,243,4,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,172,21,0,0,148,39,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,240,4,0,200,61,7,0,0,0,0,0,0,0,0,0,144,47,2,0,16,240,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,44,7,0,0,92,3,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,244,4,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,128,244,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,48,29,0,0,180,14,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,141,8,0,64,136,8,0,0,0,0,0,0,0,0,0,32,127,5,0,216,130,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,222,59,0,0,230,13,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,136,8,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,104,247,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,14,27,0,0,96,38,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,226,4,0,32,170,8,0,0,0,0,0,0,0,0,0,0,38,7,0,168,226,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,3,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,172,54,0,0,116,44,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,227,4,0,32,170,8,0,0,0,0,0,0,0,0,0,192,227,4,0,72,227,4,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,3,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,176,16,0,0,248,1,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,152,8,0,32,170,8,0,0,0,0,0,0,0,0,0,0,38,7,0,48,146,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,3,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,230,50,0,0,34,32,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,252,4,0,144,252,4,0,0,0,0,0,0,0,0,0,168,163,7,0,176,251,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,144,16,0,0,30,25,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,251,4,0,144,252,4,0,0,0,0,0,0,0,0,0,168,163,7,0,56,251,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,122,17,0,0,72,33,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,250,4,0,144,252,4,0,0,0,0,0,0,0,0,0,168,163,7,0,160,250,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,48,37,0,0,102,7,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,250,4,0,144,252,4,0,0,0,0,0,0,0,0,0,168,163,7,0,40,250,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,36,53,0,0,210,30,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,249,4,0,144,252,4,0,0,0,0,0,0,0,0,0,168,163,7,0,64,249,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,164,29,0,0,124,17,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,249,4,0,144,252,4,0,0,0,0,0,0,0,0,0,168,163,7,0,200,248,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,132,24,0,0,40,0,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,248,4,0,144,252,4,0,0,0,0,0,0,0,0,0,168,163,7,0,72,248,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,0,17,0,0,14,24,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,248,4,0,144,252,4,0,0,0,0,0,0,0,0,0,168,163,7,0,216,247,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,176,51,0,0,84,0,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,252,4,0,0,0,0,0,0,0,0,0,0,0,0,0,168,163,7,0,72,252,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,128,42,0,0,234,4,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,253,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,64,253,4,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,3,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,18,55,0,0,96,28,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,254,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,168,253,4,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,3,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,202,61,0,0,166,15,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,170,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,32,161,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,3,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,240,55,0,0,24,39,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,237,4,0,88,238,4,0,0,0,0,0,0,0,0,0,96,135,2,0,184,236,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,140,30,0,0,76,11,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,236,4,0,88,238,4,0,0,0,0,0,0,0,0,0,96,135,2,0,8,236,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,34,39,0,0,166,31,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,235,4,0,88,238,4,0,0,0,0,0,0,0,0,0,96,135,2,0,56,235,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,76,25,0,0,186,2,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,233,4,0,88,238,4,0,0,0,0,0,0,0,0,0,96,135,2,0,160,233,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,36,20,0,0,128,6,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,233,4,0,88,238,4,0,0,0,0,0,0,0,0,0,96,135,2,0,8,233,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,128,31,0,0,254,28,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,232,4,0,88,238,4,0,0,0,0,0,0,0,0,0,96,135,2,0,176,232,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,4,3,0,0,228,19,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,232,4,0,88,238,4,0,0,0,0,0,0,0,0,0,96,135,2,0,224,231,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,216,36,0,0,152,47,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,228,4,0,88,238,4,0,0,0,0,0,0,0,0,0,96,135,2,0,16,228,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,36,63,0,0,22,3,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,229,4,0,88,238,4,0,0,0,0,0,0,0,0,0,96,135,2,0,24,229,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,108,15,0,0,6,44,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,230,4,0,88,238,4,0,0,0,0,0,0,0,0,0,96,135,2,0,96,230,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,92,48,0,0,172,2,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,237,4,0,88,238,4,0,0,0,0,0,0,0,0,0,96,135,2,0,56,237,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,144,46,0,0,118,1,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,238,4,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,0,238,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,104,30,0,0,54,22,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,61,7,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,208,55,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,230,57,0,0,82,31,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,210,8,0,200,205,8,0,0,0,0,0,0,0,0,0,0,38,7,0,184,200,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,218,35,0,0,62,40,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,186,8,0,200,205,8,0,0,0,0,0,0,0,0,0,0,38,7,0,208,176,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,124,6,0,0,164,18,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,196,8,0,200,205,8,0,0,0,0,0,0,0,0,0,0,38,7,0,24,191,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,34,23,0,0,206,23,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,205,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,200,9,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,48,44,0,0,28,4,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,165,1,0,200,166,1,0,0,0,0,0,0,0,0,0,240,3,2,0,184,164,1,0,0,0,0,0,0,210,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,248,57,0,0,52,25,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,10,5,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,232,9,5,0,0,0,0,0,232,62,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,126,35,0,0,86,27,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,27,5,0,40,28,5,0,0,0,0,0,0,0,0,0,104,221,5,0,152,27,5,0,0,0,0,0,112,139,7,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,42,30,0,0,138,5,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0])
.concat([104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,11,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,96,11,5,0,0,0,0,0,232,246,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,128,48,0,0,10,32,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,12,5,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,208,11,5,0,0,0,0,0,160,200,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,144,47,0,0,186,33,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,107,3,0,216,174,7,0,0,0,0,0,0,0,0,0,0,46,3,0,40,107,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,84,27,0,0,166,45,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,96,3,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,88,96,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,214,12,0,0,114,6,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,13,5,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,104,12,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,106,16,0,0,188,40,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,15,5,0,0,0,0,0,0,0,0,0,0,0,0,0,168,163,7,0,104,14,5,0,0,0,0,0,224,218,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,30,48,0,0,22,1,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,234,8,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,80,227,8,0,0,0,0,0,224,218,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,40,31,0,0,116,20,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,143,4,0,80,79,8,0,0,0,0,0,0,0,0,0,104,221,5,0,168,143,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,10,63,0,0,102,20,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,144,4,0,80,79,8,0,0,0,0,0,0,0,0,0,104,221,5,0,80,144,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,184,36,0,0,72,2,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,145,4,0,80,79,8,0,0,0,0,0,0,0,0,0,104,221,5,0,208,144,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,174,34,0,0,254,36,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,106,3,0,184,110,3,0,0,0,0,0,0,0,0,0,96,135,2,0,192,104,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,192,53,0,0,110,11,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,110,3,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,168,108,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,94,0,0,0,234,27,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,79,8,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,56,73,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,36,14,0,0,208,40,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,105,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,72,105,3,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,124,19,0,0,54,44,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,146,4,0,96,147,4,0,0,0,0,0,0,0,0,0,0,46,3,0,72,145,4,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,218,6,0,0,148,7,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,147,4,0,96,147,4,0,0,0,0,0,0,0,0,0,0,46,3,0,240,146,4,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,24,21,0,0,88,30,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,147,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,8,155,3,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,26,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,2,20,0,0,62,22,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,38,4,0,96,43,4,0,0,0,0,0,0,0,0,0,184,168,7,0,120,36,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,78,33,0,0,174,17,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,117,3,0,16,118,3,0,0,0,0,0,0,0,0,0,0,46,3,0,0,117,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,174,44,0,0,118,8,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,118,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,208,117,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,84,40,0,0,214,13,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,140,3,0,184,155,3,0,0,0,0,0,0,0,0,0,0,46,3,0,112,140,3,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,86,35,0,0,6,4,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,155,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,104,155,3,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,27,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,24,39,0,0,178,14,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,88,4,0,0,89,4,0,0,0,0,0,0,0,0,0,96,135,2,0,216,87,4,0,0,0,0,0,112,119,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,124,0,0,0,136,14,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,89,4,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,184,88,4,0,0,0,0,0,232,62,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,38,59,0,0,48,32,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,16,5,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,248,15,5,0,0,0,0,0,168,200,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,250,27,0,0,206,6,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,16,5,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,192,16,5,0,0,0,0,0,160,200,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,50,62,0,0,102,1,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,18,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,168,17,5,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,108,20,0,0,38,43,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,58,5,0,88,59,5,0,0,0,0,0,0,0,0,0,0,38,7,0,192,58,5,0,0,0,0,0,192,223,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,50,4,0,0,10,4,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,59,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,248,58,5,0,0,0,0,0,192,223,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,72,54,0,0,172,31,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,18,5,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,48,18,5,0,0,0,0,0,64,129,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,218,4,0,0,102,36,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,94,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,232,93,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,114,9,0,0,200,47,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,94,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,104,94,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,206,0,0,0,188,11,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,95,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,24,95,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,246,31,0,0,18,38,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,254,4,0,160,6,5,0,0,0,0,0,0,0,0,0,0,38,7,0,32,254,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,24,63,0,0,114,35,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,2,5,0,160,6,5,0,0,0,0,0,0,0,0,0,0,38,7,0,224,1,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,126,36,0,0,60,44,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,6,5,0,160,6,5,0,0,0,0,0,0,0,0,0,0,38,7,0,192,5,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,52,9,0,0,68,5,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,1,5,0,160,6,5,0,0,0,0,0,0,0,0,0,0,38,7,0,128,1,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,48,7,0,0,86,12,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,5,5,0,160,6,5,0,0,0,0,0,0,0,0,0,0,38,7,0,8,5,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,196,20,0,0,8,7,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,1,5,0,160,6,5,0,0,0,0,0,0,0,0,0,0,38,7,0,8,1,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,116,12,0,0,36,21,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,4,5,0,160,6,5,0,0,0,0,0,0,0,0,0,0,38,7,0,168,4,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,22,46,0,0,72,27,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,0,5,0,160,6,5,0,0,0,0,0,0,0,0,0,0,38,7,0,136,0,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,240,3,0,0,208,20,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,4,5,0,160,6,5,0,0,0,0,0,0,0,0,0,0,38,7,0,64,4,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,212,39,0,0,160,0,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,255,4,0,160,6,5,0,0,0,0,0,0,0,0,0,0,38,7,0,16,255,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,166,57,0,0,252,20,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,4,5,0,160,6,5,0,0,0,0,0,0,0,0,0,0,38,7,0,136,3,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,192,26,0,0,188,6,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,2,5,0,160,6,5,0,0,0,0,0,0,0,0,0,0,38,7,0,88,2,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,146,5,0,0,4,46,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,156,3,0,104,156,3,0,0,0,0,0,0,0,0,0,0,46,3,0,200,155,3,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,17,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,104,12,0,0,4,22,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,17,7,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,48,11,7,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,254,7,0,0,38,22,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,149,4,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,80,149,4,0,0,0,0,0,88,239,7,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,238,6,0,0,130,44,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,19,5,0,8,20,5,0,0,0,0,0,0,0,0,0,32,127,5,0,72,19,5,0,0,0,0,0,40,3,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,220,29,0,0,62,7,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,20,5,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,168,19,5,0,0,0,0,0,40,3,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,126,2,0,0,44,47,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,6,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,72,6,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,116,23,0,0,68,18,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,222,4,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,48,221,4,0,0,0,0,0,64,246,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,188,46,0,0,10,1,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,221,4,0,224,222,4,0,0,0,0,0,0,0,0,0,104,221,5,0,240,220,4,0,0,0,0,0,64,246,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,106,47,0,0,202,26,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,240,6,0,56,237,6,0,0,0,0,0,0,0,0,0,96,135,2,0,104,234,6,0,0,0,0,0,0,193,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,100,7,0,0,158,4,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,22,5,0,56,237,6,0,0,0,0,0,0,0,0,0,96,135,2,0,40,22,5,0,0,0,0,0,0,193,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,24,10,0,0,162,33,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,237,6,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,168,22,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,234,5,0,0,112,14,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,23,5,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,248,22,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,20,48,0,0,144,35,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,24,5,0,0,0,0,0,0,0,0,0,0,0,0,0,168,163,7,0,96,23,5,0,0,0,0,0,232,248,7,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,178,9,0,0,236,25,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,24,5,0,0,0,0,0,0,0,0,0,0,0,0,0,144,139,6,0,136,24,5,0,0,0,0,0,80,24,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,60,36,0,0,114,27,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,108,3,0,136,218,5,0,0,0,0,0,0,0,0,0,0,46,3,0,152,108,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,232,50,0,0,68,46,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,109,3,0,80,183,3,0,0,0,0,0,0,0,0,0,0,46,3,0,232,108,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,100,40,0,0,46,5,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,28,5,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,0,28,5,0,0,0,0,0,160,95,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,34,29,0,0,52,19,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,28,5,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,192,28,5,0,0,0,0,0,88,198,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,216,48,0,0,128,0,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,51,5,0,40,52,5,0,0,0,0,0,0,0,0,0,104,221,5,0,32,51,5,0,0,0,0,0,120,131,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,12,2,0,0,114,17,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,29,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,80,29,5,0,0,0,0,0,8,29,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,78,12,0,0,246,32,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,31,5,0,144,121,7,0,0,0,0,0,0,0,0,0,240,3,2,0,88,31,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,196,31,0,0,48,7,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,121,7,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,120,117,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,244,62,0,0,200,17,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,35,5,0,160,36,5,0,0,0,0,0,0,0,0,0,96,135,2,0,88,35,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,224,54,0,0,40,20,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,35,5,0,160,36,5,0,0,0,0,0,0,0,0,0,96,135,2,0,224,34,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,244,61,0,0,130,4,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,36,5,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,136,36,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,170,22,0,0,128,13,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,33,5,0,136,249,8,0,0,0,0,0,0,0,0,0,0,38,7,0,208,32,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,240,57,0,0,68,16,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0])
.concat([4,0,0,0,3,0,0,0,72,34,5,0,136,249,8,0,0,0,0,0,0,0,0,0,0,38,7,0,8,34,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,60,27,0,0,234,36,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,33,5,0,136,249,8,0,0,0,0,0,0,0,0,0,0,38,7,0,168,33,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,92,27,0,0,236,4,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,34,5,0,136,249,8,0,0,0,0,0,0,0,0,0,240,3,2,0,88,34,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,148,43,0,0,118,4,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,249,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,168,241,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,182,43,0,0,18,5,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,31,5,0,192,32,5,0,0,0,0,0,0,0,0,0,144,47,2,0,160,31,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,188,23,0,0,164,13,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,32,5,0,192,32,5,0,0,0,0,0,0,0,0,0,0,38,7,0,0,32,5,0,0,0,0,0,168,66,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,196,48,0,0,34,17,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,32,5,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,152,32,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,180,37,0,0,174,32,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,150,4,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,168,150,4,0,0,0,0,0,104,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,226,54,0,0,102,43,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,37,5,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,8,37,5,0,0,0,0,0,8,116,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,210,40,0,0,178,26,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,37,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,128,37,5,0,0,0,0,0,88,78,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,240,56,0,0,206,21,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,50,5,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,120,50,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,132,56,0,0,234,37,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,223,4,0,176,113,8,0,0,0,0,0,0,0,0,0,104,174,7,0,8,223,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,254,51,0,0,56,32,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,113,8,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,48,106,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,172,40,0,0,160,17,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,38,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,48,38,5,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,46,54,0,0,178,5,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,151,4,0,0,152,4,0,0,0,0,0,0,0,0,0,184,168,7,0,88,151,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,66,5,0,0,106,19,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,152,4,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,168,151,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,60,16,0,0,238,4,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,125,8,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,128,124,8,0,0,0,0,0,88,198,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,96,1,0,0,94,30,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,39,5,0,120,41,5,0,0,0,0,0,0,0,0,0,0,38,7,0,224,38,5,0,0,0,0,0,104,152,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,52,8,0,0,126,13,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,40,5,0,120,41,5,0,0,0,0,0,0,0,0,0,0,38,7,0,224,39,5,0,0,0,0,0,104,152,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,236,53,0,0,144,5,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,41,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,248,40,5,0,0,0,0,0,104,152,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,146,56,0,0,40,42,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,41,5,0,0,0,0,0,0,0,0,0,0,0,0,0,184,12,8,0,192,41,5,0,0,0,0,0,168,178,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,100,47,0,0,252,38,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,45,5,0,160,46,5,0,0,0,0,0,0,0,0,0,240,3,2,0,224,44,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,232,19,0,0,8,26,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,44,5,0,160,46,5,0,0,0,0,0,0,0,0,0,240,3,2,0,24,44,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,4,32,0,0,88,29,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,43,5,0,160,46,5,0,0,0,0,0,0,0,0,0,0,38,7,0,240,42,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,88,7,0,0,44,10,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,42,5,0,160,46,5,0,0,0,0,0,0,0,0,0,0,38,7,0,80,42,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,122,22,0,0,30,10,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,45,5,0,160,46,5,0,0,0,0,0,0,0,0,0,0,46,3,0,160,45,5,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,146,44,0,0,10,22,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,46,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,80,46,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,150,9,0,0,204,40,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,52,5,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,88,51,5,0,0,0,0,0,8,13,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,130,39,0,0,44,23,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,152,4,0,176,152,4,0,0,0,0,0,0,0,0,0,96,135,2,0,24,152,4,0,0,0,0,0,8,116,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,30,29,0,0,238,38,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,152,4,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,128,152,4,0,0,0,0,0,8,116,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,52,28,0,0,18,13,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,183,4,0,168,184,4,0,0,0,0,0,0,0,0,0,240,3,2,0,16,183,4,0,0,0,0,0,192,223,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,180,53,0,0,200,0,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,183,4,0,168,184,4,0,0,0,0,0,0,0,0,0,192,183,4,0,152,183,4,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,22,63,0,0,132,14,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,184,4,0,168,184,4,0,0,0,0,0,0,0,0,0,240,3,2,0,216,183,4,0,0,0,0,0,192,223,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,52,59,0,0,106,24,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,184,4,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,72,184,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,38,8,0,0,198,34,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,52,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,104,52,5,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,140,51,0,0,46,9,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,53,5,0,160,54,5,0,0,0,0,0,0,0,0,0,240,3,2,0,160,53,5,0,0,0,0,0,48,54,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,132,21,0,0,82,7,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,54,5,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,80,54,5,0,0,0,0,0,48,54,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,24,38,0,0,240,12,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,53,5,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,240,52,5,0,0,0,0,0,152,22,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,126,8,0,0,248,7,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,55,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,64,55,5,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,136,8,0,0,160,2,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,56,5,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,200,55,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,158,9,0,0,66,35,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,171,3,0,64,172,3,0,0,0,0,0,0,0,0,0,0,46,3,0,40,171,3,0,0,0,0,0,216,171,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,224,3,0,0,242,40,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,172,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,16,172,3,0,0,0,0,0,216,171,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,104,6,0,0,244,2,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,170,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,72,170,3,0,0,0,0,0,216,171,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,192,29,0,0,134,27,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,56,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,80,56,5,0,0,0,0,0,56,127,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,156,36,0,0,240,41,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,56,5,0,16,57,5,0,0,0,0,0,0,0,0,0,0,38,7,0,128,56,5,0,0,0,0,0,56,24,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,164,41,0,0,252,29,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,57,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,216,56,5,0,0,0,0,0,48,18,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,70,32,0,0,22,48,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,127,4,0,104,128,4,0,0,0,0,0,0,0,0,0,96,135,2,0,168,127,4,0,0,0,0,0,120,127,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,134,28,0,0,188,9,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,27,5,0,0,0,0,0,0,0,0,0,0,0,0,0,104,129,6,0,64,27,5,0,0,0,0,0,168,66,2,0,32,20,3,0,192,26,5,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,242,23,0,0,24,0,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,25,5,0,176,26,5,0,0,0,0,0,0,0,0,0,56,172,6,0,136,25,5,0,0,0,0,0,168,66,2,0,32,20,3,0,248,24,5,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,136,49,0,0,116,34,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,26,5,0,0,0,0,0,0,0,0,0,0,0,0,0,56,172,6,0,88,26,5,0,0,0,0,0,168,66,2,0,32,20,3,0,216,25,5,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,52,60,0,0,222,20,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,149,3,0,104,156,3,0,0,0,0,0,0,0,0,0,0,46,3,0,208,149,3,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,170,2,0,0,90,16,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,156,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,56,156,3,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,16,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,134,12,0,0,58,38,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,247,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,96,245,4,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,16,60,0,0,128,39,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,58,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,24,58,5,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,24,35,0,0,196,16,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,58,5,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,104,58,5,0,0,0,0,0,48,143,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,184,58,0,0,104,15,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,154,4,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,48,154,4,0,0,0,0,0,24,125,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,86,20,0,0,2,36,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,154,4,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,168,154,4,0,0,0,0,0,216,208,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,140,23,0,0,46,3,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,60,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,64,60,5,0,0,0,0,0,160,59,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,174,9,0,0,230,24,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,60,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,200,60,5,0,0,0,0,0,136,60,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,242,10,0,0,194,3,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,61,5,0,48,61,5,0,0,0,0,0,0,0,0,0,0,46,3,0,248,60,5,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,62,22,0,0,250,28,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,61,5,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,104,59,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,44,3,0,0,86,6,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,66,5,0,128,67,5,0,0,0,0,0,0,0,0,0,96,135,2,0,152,66,5,0,0,0,0,0,160,88,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,210,25,0,0,174,35,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,68,5,0,160,68,5,0,0,0,0,0,0,0,0,0,144,47,2,0,144,67,5,0,0,0,0,0,160,88,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,108,11,0,0,236,42,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,61,5,0,144,63,5,0,0,0,0,0,0,0,0,0,0,38,7,0,136,61,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,234,62,0,0,48,37,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,63,5,0,144,63,5,0,0,0,0,0,0,0,0,0,0,38,7,0,16,63,5,0,0,0,0,0,232,180,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,12,46,0,0,6,47,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,63,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,104,63,5,0,0,0,0,0,232,180,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,0,22,0,0,112,43,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,189,5,0,208,12,1,0,0,0,0,0,0,0,0,0,0,38,7,0,208,188,5,0,0,0,0,0,168,178,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,210,4,0,0,180,20,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,189,5,0,208,12,1,0,0,0,0,0,0,0,0,0,0,38,7,0,40,189,5,0,0,0,0,0,168,178,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,216,23,0,0,250,4,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,12,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,160,7,1,0,0,0,0,0,168,178,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,4,0,0,0,4,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,174,23,0,0,102,2,0,0,0,0,0,0,0,0,0,0,120,28,0,0,136,19,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,63,5,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,200,63,5,0,0,0,0,0,168,178,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,182,33,0,0,246,7,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,223,7,0,72,226,7,0,0,0,0,0,0,0,0,0,104,221,5,0,88,223,7,0,0,0,0,0,160,150,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,76,8,0,0,180,38,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,65,5,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,38,7,0,64,65,5,0,0,0,0,0,32,11,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,232,24,0,0,18,1,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,66,5,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,8,66,5,0,0,0,0,0,64,246,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,6,39,0,0,4,39,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,156,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,176,156,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,36,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,112,10,0,0,48,10,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,157,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,32,157,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,37,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,156,14,0,0,98,31,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,5,4,0,48,21,4,0,0,0,0,0,0,0,0,0,0,38,7,0,112,2,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,212,40,0,0,14,1,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,142,7,0,224,143,7,0,0,0,0,0,0,0,0,0,144,47,2,0,240,141,7,0,0,0,0,0,64,246,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,244,1,0,0,170,37,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,66,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,40,66,5,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,212,10,0,0,130,25,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,71,5,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,136,71,5,0,0,0,0,0,248,39,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,140,54,0,0,130,3,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,72,5,0,224,73,5,0,0,0,0,0,0,0,0,0,144,47,2,0,48,72,5,0,0,0,0,0,248,39,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,148,12,0,0,104,32,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,73,5,0,224,73,5,0,0,0,0,0,0,0,0,0,144,47,2,0,200,72,5,0,0,0,0,0,176,67,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,44,10,0,0,236,12,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,73,5,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,128,73,5,0,0,0,0,0,248,39,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,204,19,0,0,64,14,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,94,5,0,0,98,5,0,0,0,0,0,0,0,0,0,0,38,7,0,32,94,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,28,46,0,0,206,37,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,97,5,0,0,98,5,0,0,0,0,0,0,0,0,0,0,38,7,0,56,97,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,34,0,0,0,156,5,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,97,5,0,0,98,5,0,0,0,0,0,0,0,0,0,0,38,7,0,152,96,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,228,22,0,0,176,31,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,96,5,0,0,98,5,0,0,0,0,0,0,0,0,0,0,38,7,0,80,96,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,170,14,0,0,114,11,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,96,5,0,0,98,5,0,0,0,0,0,0,0,0,0,0,38,7,0,232,95,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,16,19,0,0,136,15,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,95,5,0,0,98,5,0,0,0,0,0,0,0,0,0,0,38,7,0,104,95,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,124,29,0,0,78,4,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,94,5,0,0,98,5,0,0,0,0,0,0,0,0,0,0,38,7,0,136,94,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,174,35,0,0,226,17,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,98,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,184,97,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,54,46,0,0,44,26,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,85,5,0,96,87,5,0,0,0,0,0,0,0,0,0,32,127,5,0,224,84,5,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,106,8,0,0,52,29,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,87,5,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,152,85,5,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,160,35,0,0,68,19,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,87,5,0,40,88,5,0,0,0,0,0,0,0,0,0,240,3,2,0,128,87,5,0,0,0,0,0,80,89,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,36,54,0,0,148,25,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,87,5,0,40,88,5,0,0,0,0,0,0,0,0,0,96,135,2,0,168,87,5,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,108,45,0,0,22,2,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,88,5,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,8,88,5,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,176,6,0,0,242,46,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,183,7,0,40,184,7,0,0,0,0,0,0,0,0,0,96,135,2,0,240,182,7,0,0,0,0,0,160,88,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,60,10,0,0,172,19,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,67,5,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,8,67,5,0,0,0,0,0,160,88,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,230,42,0,0,194,2,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,68,5,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,120,68,5,0,0,0,0,0,160,88,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,98,8,0,0,158,9,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,69,5,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,136,69,5,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,124,34,0,0,60,37,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,130,5,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,224,126,5,0,0,0,0,0,24,125,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,18,61,0,0,240,13,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,158,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,24,158,3,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,33,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,4,10,0,0,86,32,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,168,6,0,8,172,6,0,0,0,0,0,0,0,0,0,0,38,7,0,104,168,6,0,0,0,0,0,192,223,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,212,52,0,0,180,28,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,170,6,0,8,172,6,0,0,0,0,0,0,0,0,0,0,38,7,0,112,169,6,0,0,0,0,0,192,223,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,178,48,0,0,18,17,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,75,5,0,56,77,5,0,0,0,0,0,0,0,0,0,240,3,2,0,48,75,5,0,0,0,0,0,168,95,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,234,19,0,0,76,32,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,76,5,0,56,77,5,0,0,0,0,0,0,0,0,0,240,3,2,0,24,76,5,0,0,0,0,0,168,95,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,248,54,0,0,82,19,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,77,5,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,248,76,5,0,0,0,0,0,168,95,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,180,19,0,0,202,18,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,78,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,152,78,5,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,176,15,0,0,146,10,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,80,5,0,184,82,5,0,0,0,0,0,0,0,0,0,0,38,7,0,40,80,5,0,0,0,0,0,72,246,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,224,44,0,0,174,0,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,81,5,0,184,82,5,0,0,0,0,0,0,0,0,0,0,38,7,0,112,80,5,0,0,0,0,0,224,212,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,74,12,0,0,194,35,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,81,5,0,184,82,5,0,0,0,0,0,0,0,0,0,0,38,7,0,56,81,5,0,0,0,0,0,224,212,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,214,61,0,0,82,0,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,82,5,0,184,82,5,0,0,0,0,0,0,0,0,0,0,38,7,0,240,81,5,0,0,0,0,0,224,212,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,56,32,0,0,234,41,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,82,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,112,82,5,0,0,0,0,0,224,212,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,10,8,0,0,22,44,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,79,5,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,56,79,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,216,4,0,0,68,20,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,83,5,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,224,82,5,0,0,0,0,0,40,47,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,20,14,0,0,66,36,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,71,7,0,160,158,7,0,0,0,0,0,0,0,0,0,240,3,2,0,168,71,7,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,118,15,0,0,114,23,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,158,7,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,200,113,7,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,240,51,0,0,116,2,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,88,5,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,136,88,5,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,190,36,0,0,222,3,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,83,5,0,64,84,5,0,0,0,0,0,0,0,0,0,96,135,2,0,104,83,5,0,0,0,0,0,160,200,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,16,16,0,0,176,41,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,84,5,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,16,84,5,0,0,0,0,0,160,200,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,112,52,0,0,202,10,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,77,5,0,48,78,5,0,0,0,0,0,0,0,0,0,0,38,7,0,96,77,5,0,0,0,0,0,232,27,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,6,62,0,0,52,32,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,78,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,16,78,5,0,0,0,0,0,232,27,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,164,59,0,0,106,42,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,89,5,0,224,91,5,0,0,0,0,0,0,0,0,0,0,38,7,0,216,89,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,182,30,0,0,206,42,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,89,5,0,224,91,5,0,0,0,0,0,0,0,0,0,0,38,7,0,184,88,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,92,49,0,0,90,46,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,90,5,0,224,91,5,0,0,0,0,0,0,0,0,0,0,38,7,0,128,90,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,132,19,0,0,34,5,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,90,5,0,224,91,5,0,0,0,0,0,0,0,0,0,0,38,7,0,8,90,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,160,17,0,0,172,3,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,91,5,0,224,91,5,0,0,0,0,0,0,0,0,0,32,127,5,0,48,91,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,64,37,0,0,96,25,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,91,5,0,224,91,5,0,0,0,0,0,0,0,0,0,0,38,7,0,120,91,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,200,54,0,0,44,37,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,91,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,192,91,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,120,38,0,0,52,33,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,92,5,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,112,92,5,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,186,6,0,0,192,13,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,93,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,240,92,5,0,0,0,0,0,224,105,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,192,56,0,0,180,25,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,12,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,80,182,5,0,0,0,0,0,48,143,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,24,0,0,0,244,38,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,93,5,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,88,93,5,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,14,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,234,54,0,0,106,47,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,94,5,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,240,93,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,156,21,0,0,224,25,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,124,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,40,109,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,8,21,0,0,238,9,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,109,3,0,176,246,5,0,0,0,0,0,0,0,0,0,0,46,3,0,88,109,3,0,0,0,0,0,80,109,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,120,47,0,0,252,31,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,98,5,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,32,98,5,0,0,0,0,0,48,143,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,72,43,0,0,208,33,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,100,5,0,136,102,5,0,0,0,0,0,0,0,0,0,184,168,7,0,128,99,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,106,62,0,0,14,7,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,101,5,0,136,102,5,0,0,0,0,0,0,0,0,0,184,168,7,0,176,100,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,2,55,0,0,178,32,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,102,5,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,40,102,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,54,7,0,0,158,32,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,103,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,40,103,5,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,210,52,0,0,164,9,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,104,5,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,72,104,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,188,6,0,0,194,42,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,105,5,0,184,107,5,0,0,0,0,0,0,0,0,0,240,3,2,0,144,104,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,52,55,0,0,136,22,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,105,5,0,184,107,5,0,0,0,0,0,0,0,0,0,240,3,2,0,104,105,5,0])
.concat([0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,122,31,0,0,50,47,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,107,5,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,32,106,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,134,40,0,0,136,28,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,108,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,240,107,5,0,0,0,0,0,120,175,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,208,33,0,0,36,28,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,154,3,0,176,154,3,0,0,0,0,0,0,0,0,0,0,46,3,0,248,153,3,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,194,10,0,0,222,22,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,154,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,96,154,3,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,18,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,68,48,0,0,186,22,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,114,5,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,176,114,5,0,0,0,0,0,64,246,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,182,10,0,0,230,36,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,119,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,72,119,5,0,0,0,0,0,160,200,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,32,47,0,0,174,11,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,119,5,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,128,119,5,0,0,0,0,0,160,200,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,192,19,0,0,46,24,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,118,5,0,184,118,5,0,0,0,0,0,0,0,0,0,96,135,2,0,24,118,5,0,0,0,0,0,160,200,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,142,13,0,0,222,30,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,117,5,0,184,118,5,0,0,0,0,0,0,0,0,0,96,135,2,0,192,117,5,0,0,0,0,0,160,200,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,116,20,0,0,140,42,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,118,5,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,144,118,5,0,0,0,0,0,160,200,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,208,37,0,0,158,3,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,119,5,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,200,118,5,0,0,0,0,0,160,200,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,178,34,0,0,190,1,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,108,5,0,96,109,5,0,0,0,0,0,0,0,0,0,104,221,5,0,120,108,5,0,0,0,0,0,64,246,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,112,15,0,0,56,4,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,109,5,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,16,109,5,0,0,0,0,0,64,246,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,34,21,0,0,86,46,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,110,5,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,160,109,5,0,0,0,0,0,24,21,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,156,58,0,0,94,4,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,112,5,0,200,112,5,0,0,0,0,0,0,0,0,0,240,3,2,0,72,112,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,62,50,0,0,50,20,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,112,5,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,128,112,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,140,35,0,0,58,1,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,113,5,0,168,113,5,0,0,0,0,0,0,0,0,0,96,135,2,0,216,112,5,0,0,0,0,0,160,200,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,198,3,0,0,60,48,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,113,5,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,112,113,5,0,0,0,0,0,160,200,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,190,31,0,0,98,32,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,113,5,0,120,114,5,0,0,0,0,0,0,0,0,0,184,168,7,0,184,113,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,200,55,0,0,84,5,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,114,5,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,40,114,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,84,12,0,0,190,9,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,115,5,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,24,115,5,0,0,0,0,0,112,242,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,94,20,0,0,198,43,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,7,5,0,200,205,8,0,0,0,0,0,0,0,0,0,0,38,7,0,144,7,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,254,1,0,0,118,39,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,7,5,0,200,205,8,0,0,0,0,0,0,0,0,0,0,38,7,0,168,6,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,80,53,0,0,242,30,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,8,5,0,200,205,8,0,0,0,0,0,0,0,0,0,0,38,7,0,240,7,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,142,56,0,0,78,9,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,116,5,0,120,117,5,0,0,0,0,0,0,0,0,0,0,38,7,0,32,116,5,0,0,0,0,0,104,152,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,236,52,0,0,6,6,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,117,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,184,116,5,0,0,0,0,0,104,152,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,184,8,0,0,244,34,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,152,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,180,6,0,168,152,3,0,0,0,0,0,136,152,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,19,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,106,61,0,0,136,20,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,152,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,180,6,0,80,152,3,0,0,0,0,0,200,151,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,19,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,234,56,0,0,50,24,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,117,5,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,152,117,5,0,0,0,0,0,160,200,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,140,11,0,0,208,21,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,121,5,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,48,121,5,0,0,0,0,0,248,39,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,196,22,0,0,114,1,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,121,5,0,120,100,7,0,0,0,0,0,0,0,0,0,144,47,2,0,136,121,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,248,9,0,0,38,13,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,100,7,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,144,92,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,168,56,0,0,56,6,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,120,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,24,120,5,0,0,0,0,0,0,120,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,166,13,0,0,162,30,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,122,5,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,248,121,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,10,43,0,0,94,29,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,123,5,0,24,124,5,0,0,0,0,0,0,0,0,0,144,47,2,0,152,123,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,144,32,0,0,108,12,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,122,5,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,128,122,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,32,63,0,0,138,39,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,123,5,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,56,123,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,224,28,0,0,180,29,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,124,5,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,248,123,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,242,14,0,0,38,27,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,125,5,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,208,125,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,104,36,0,0,114,34,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,125,5,0,192,125,5,0,0,0,0,0,0,0,0,0,0,38,7,0,48,125,5,0,0,0,0,0,136,217,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,170,23,0,0,58,26,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,125,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,112,125,5,0,0,0,0,0,136,217,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,234,12,0,0,156,4,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,126,5,0,208,126,5,0,0,0,0,0,0,0,0,0,144,47,2,0,248,125,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,200,7,0,0,16,41,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,126,5,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,88,126,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,56,27,0,0,104,22,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,127,5,0,48,128,5,0,0,0,0,0,0,0,0,0,0,38,7,0,48,127,5,0,0,0,0,0,192,223,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,240,46,0,0,200,38,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,128,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,224,127,5,0,0,0,0,0,192,223,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,190,19,0,0,200,37,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,128,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,80,128,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,118,33,0,0,52,20,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,129,5,0,16,131,5,0,0,0,0,0,0,0,0,0,240,3,2,0,248,128,5,0,0,0,0,0,56,127,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,248,58,0,0,176,25,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,130,5,0,16,131,5,0,0,0,0,0,0,0,0,0,240,3,2,0,120,129,5,0,0,0,0,0,56,127,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,2,61,0,0,48,4,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,131,5,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,184,130,5,0,0,0,0,0,56,127,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,148,29,0,0,220,32,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,202,5,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,248,201,5,0,0,0,0,0,160,88,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,82,18,0,0,58,15,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,131,5,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,176,131,5,0,0,0,0,0,120,131,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,250,26,0,0,82,23,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,215,6,0,232,224,6,0,0,0,0,0,0,0,0,0,0,38,7,0,248,209,6,0,0,0,0,0,168,178,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,208,7,0,0,130,32,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,224,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,120,220,6,0,0,0,0,0,168,178,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,196,3,0,0,194,14,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,170,5,0,112,170,5,0,0,0,0,0,0,0,0,0,0,38,7,0,216,169,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,242,11,0,0,28,32,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,165,5,0,112,170,5,0,0,0,0,0,0,0,0,0,0,38,7,0,96,164,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,200,24,0,0,108,47,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,166,5,0,112,170,5,0,0,0,0,0,0,0,0,0,0,38,7,0,24,166,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,0,30,0,0,152,33,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,167,5,0,112,170,5,0,0,0,0,0,0,0,0,0,0,38,7,0,8,167,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,34,51,0,0,238,13,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,162,5,0,112,170,5,0,0,0,0,0,0,0,0,0,0,38,7,0,208,161,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,172,31,0,0,206,10,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,164,5,0,112,170,5,0,0,0,0,0,0,0,0,0,0,38,7,0,200,162,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,170,21,0,0,254,12,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,168,5,0,112,170,5,0,0,0,0,0,0,0,0,0,240,3,2,0,144,167,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,48,11,0,0,74,20,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,170,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,32,169,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,170,11,0,0,86,28,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,171,5,0,176,172,5,0,0,0,0,0,0,0,0,0,104,221,5,0,64,171,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,0,9,0,0,8,35,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,171,5,0,176,172,5,0,0,0,0,0,0,0,0,0,192,177,6,0,176,171,5,0,0,0,0,0,168,66,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,154,2,0,0,32,32,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,172,5,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,48,172,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,52,7,0,0,96,10,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,182,5,0,8,2,1,0,0,0,0,0,0,0,0,0,184,168,7,0,24,182,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,138,44,0,0,192,0,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,182,5,0,8,2,1,0,0,0,0,0,0,0,0,0,0,46,3,0,168,182,5,0,0,0,0,0,168,66,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,10,46,0,0,70,26,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,184,5,0,8,2,1,0,0,0,0,0,0,0,0,0,184,168,7,0,32,183,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,230,27,0,0,224,37,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,168,254,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,226,8,0,0,152,21,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,175,5,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,248,172,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,172,0,0,0,162,11,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,176,5,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,232,175,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,98,16,0,0,196,33,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,177,5,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,32,177,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,154,48,0,0,138,28,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,178,5,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,240,177,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,4,39,0,0,130,33,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,179,5,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,216,178,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,190,25,0,0,16,6,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,180,5,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,80,179,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,68,32,0,0,0,10,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,181,5,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,240,180,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,152,4,0,0,164,35,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,181,5,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,96,181,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,226,23,0,0,138,9,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,135,5,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,192,134,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,134,49,0,0,106,12,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,76,7,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,72,76,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,106,35,0,0,56,17,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,135,5,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,128,135,5,0,0,0,0,0,128,223,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,74,22,0,0,34,44,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,134,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,240,133,5,0,0,0,0,0,168,95,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,184,26,0,0,148,0,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,140,5,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,136,140,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,142,54,0,0,134,32,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,141,5,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,208,140,5,0,0,0,0,0,120,175,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,238,43,0,0,118,6,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,142,5,0,0,0,0,0,0,0,0,0,0,0,0,0,168,163,7,0,248,141,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,94,59,0,0,94,47,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,142,5,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,112,142,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,28,57,0,0,122,41,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,143,5,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,200,142,5,0,0,0,0,0,104,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,2,12,0,0,192,45,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,137,5,0,48,140,5,0,0,0,0,0,0,0,0,0,240,3,2,0,8,137,5,0,0,0,0,0,160,200,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,252,4,0,0,158,46,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,138,5,0,48,140,5,0,0,0,0,0,0,0,0,0,240,3,2,0,24,138,5,0,0,0,0,0,160,200,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,36,41,0,0,246,17,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,139,5,0,48,140,5,0,0,0,0,0,0,0,0,0,240,3,2,0,200,138,5,0,0,0,0,0,160,200,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,214,0,0,0,158,27,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,136,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,232,135,5,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,234,15,0,0,188,44,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,140,5,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,248,139,5,0,0,0,0,0,232,115,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,80,34,0,0,92,45,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,189,5,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,168,189,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,172,5,0,0,48,5,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,144,5,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,184,143,5,0,0,0,0,0,248,39,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,34,48,0,0,202,41,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,202,8,0,232,203,8,0,0,0,0,0,0,0,0,0,96,135,2,0,80,202,8,0,0,0,0,0,72,187,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,246,46,0,0,178,4,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,147,5,0,200,147,5,0,0,0,0,0,0,0,0,0,144,47,2,0,240,146,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,72,7,0,0,16,13,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,147,5,0,200,147,5,0,0,0,0,0,0,0,0,0,144,47,2,0,48,147,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,82,25,0,0,86,35,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,147,5,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,120,147,5,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,178,0,0,0,248,6,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,158,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,152,158,3,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,28,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,36,18,0,0,30,14,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,148,5,0,64,149,5,0,0,0,0,0,0,0,0,0,0,46,3,0,128,148,5,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,208,56,0,0,102,29,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,148,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,80,148,5,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,41,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,228,25,0,0,108,31,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,149,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,40,149,5,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,40,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,46,3,0,0,112,28,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,109,3,0,40,148,5,0,0,0,0,0,0,0,0,0,0,46,3,0,128,109,3,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,244,13,0,0,78,21,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,148,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,216,147,5,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,134,54,0,0,146,5,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,151,5,0,8,152,5,0,0,0,0,0,0,0,0,0,168,163,7,0,112,151,5,0,0,0,0,0,32,189,7,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,192,18,0,0,182,32,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,152,5,0,0,0,0,0,0,0,0,0,0,0,0,0,168,163,7,0,168,151,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,204,38,0,0,60,22,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,145,5,0,104,146,5,0,0,0,0,0,0,0,0,0,240,3,2,0,72,145,5,0,0,0,0,0,80,89,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,58,41,0,0,20,41,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,146,5,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,16,146,5,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,12,18,0,0,10,3,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,153,5,0,80,154,5,0,0,0,0,0,0,0,0,0,144,47,2,0,224,152,5,0,0,0,0,0,160,200,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,238,5,0,0,210,44,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,154,5,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,48,154,5,0,0,0,0,0,160,200,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,172,41,0,0,242,6,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,152,5,0,200,152,5,0,0,0,0,0,0,0,0,0,0,38,7,0,40,152,5,0,0,0,0,0,104,152,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,108,10,0,0,200,30,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,152,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,136,152,5,0,0,0,0,0,104,152,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,220,34,0,0,0,13,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,154,5,0,232,154,5,0,0,0,0,0,0,0,0,0,240,3,2,0,128,154,5,0,0,0,0,0,248,165,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,86,38,0,0,154,23,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,154,5,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,200,154,5,0,0,0,0,0,248,165,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,146,27,0,0,180,30,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,155,5,0,8,156,5,0,0,0,0,0,0,0,0,0,0,38,7,0,8,155,5,0,0,0,0,0,8,116,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,238,48,0,0,64,31,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,156,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,96,155,5,0,0,0,0,0,8,116,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,62,49,0,0,80,21,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,156,5,0,232,156,5,0,0,0,0,0,0,0,0,0,168,163,7,0,40,156,5,0,0,0,0,0,48,18,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,202,25,0,0,34,25,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,156,5,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,136,156,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,92,7,0,0,52,40,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,157,5,0,192,186,7,0,0,0,0,0,0,0,0,0,240,3,2,0,248,156,5,0,0,0,0,0,184,55,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,78,43,0,0,248,37,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,186,7,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,112,181,7,0,0,0,0,0,184,55,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,162,55,0,0,128,44,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,62,7,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,168,62,7,0,0,0,0,0,168,200,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,248,28,0,0,146,35,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,157,5,0,80,160,5,0,0,0,0,0,0,0,0,0,104,221,5,0,88,157,5,0,0,0,0,0,248,39,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,28,43,0,0,222,16,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,159,5,0,80,160,5,0,0,0,0,0,0,0,0,0,104,221,5,0,152,157,5,0,0,0,0,0,176,67,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,242,37,0,0,138,41,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,160,5,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,40,160,5,0,0,0,0,0,248,39,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,110,36,0,0,8,19,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,161,5,0,136,161,5,0,0,0,0,0,0,0,0,0,32,127,5,0,192,160,5,0,0,0,0,0,48,55,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,26,28,0,0,248,12,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,161,5,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,64,161,5,0,0,0,0,0,48,55,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,66,12,0,0,60,29,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,188,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,104,188,5,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,128,57,0,0,198,8,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,185,5,0,240,185,5,0,0,0,0,0,0,0,0,0,144,47,2,0,112,185,5,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,200,52,0,0,216,45,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,188,5,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,240,187,5,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,68,3,0,0,132,11,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,184,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,72,184,5,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,192,39,0,0,126,44,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,184,5,0,120,99,6,0,0,0,0,0,0,0,0,0,240,3,2,0,184,184,5,0,0,0,0,0,80,89,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,24,32,0,0,192,24,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,143,6,0,120,99,6,0,0,0,0,0,0,0,0,0,96,135,2,0,0,53,6,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,158,39,0,0,216,21,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,99,6,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,16,185,5,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,178,7,0,0,10,19,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,185,5,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,200,185,5,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,12,57,0,0,202,29,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,192,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,0,192,5,0,0,0,0,0,192,181,1,0,32,20,3,0,64,191,5,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,128,39,0,0,94,17,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,191,5,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,8,191,5,0,0,0,0,0,192,181,1,0,32,20,3,0,64,190,5,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,12,6,0,0,192,28,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,193,5,0,72,194,5,0,0,0,0,0,0,0,0,0,240,3,2,0,224,192,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,102,26,0,0,214,26,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,194,5,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,184,193,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,68,28,0,0,180,3,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,146,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,192,146,5,0,0,0,0,0,88,239,7,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,74,0,0,0,2,38,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,195,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,200,195,5,0,0,0,0,0,8,116,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,20,59,0,0,34,9,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,110,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,80,110,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,124,57,0,0,164,46,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,111,3,0,216,62,4,0,0,0,0,0,0,0,0,0,0,46,3,0,232,110,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,86,45,0,0,70,38,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,141,4,0,56,143,4,0,0,0,0,0,0,0,0,0,104,221,5,0,64,141,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,150,45,0,0,176,13,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,22,7,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,96,20,7,0,0,0,0,0,32,11,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0])
.concat([2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,248,36,0,0,84,30,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,194,5,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,88,194,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,132,39,0,0,62,10,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,98,3,0,32,99,3,0,0,0,0,0,0,0,0,0,0,46,3,0,176,97,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,172,25,0,0,212,13,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,99,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,240,98,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,52,5,0,0,192,35,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,99,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,88,99,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,72,37,0,0,140,12,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,195,5,0,128,195,5,0,0,0,0,0,0,0,0,0,96,135,2,0,232,194,5,0,0,0,0,0,160,200,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,30,32,0,0,202,12,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,195,5,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,80,195,5,0,0,0,0,0,160,200,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,6,51,0,0,138,25,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,6,7,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,88,255,6,0,0,0,0,0,160,200,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,152,54,0,0,36,22,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,197,5,0,168,198,5,0,0,0,0,0,0,0,0,0,0,38,7,0,168,197,5,0,0,0,0,0,96,198,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,48,61,0,0,120,28,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,198,5,0,168,198,5,0,0,0,0,0,0,0,0,0,0,38,7,0,0,198,5,0,0,0,0,0,96,198,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,218,17,0,0,238,32,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,198,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,112,198,5,0,0,0,0,0,96,198,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,208,26,0,0,52,36,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,199,5,0,176,200,5,0,0,0,0,0,0,0,0,0,144,47,2,0,200,198,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,152,29,0,0,156,29,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,200,5,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,88,199,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,228,11,0,0,80,20,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,206,5,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,136,203,5,0,0,0,0,0,248,39,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,12,52,0,0,18,45,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,204,5,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,232,203,5,0,0,0,0,0,160,200,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,78,5,0,0,180,11,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,205,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,56,205,5,0,0,0,0,0,248,39,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,22,40,0,0,96,46,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,203,5,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,216,202,5,0,0,0,0,0,160,202,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,192,43,0,0,70,29,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,206,5,0,168,206,5,0,0,0,0,0,0,0,0,0,240,3,2,0,48,206,5,0,0,0,0,0,248,39,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,92,41,0,0,176,4,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,214,5,0,0,216,5,0,0,0,0,0,0,0,0,0,144,47,2,0,128,214,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,86,26,0,0,222,39,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,216,5,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,48,215,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,10,35,0,0,120,29,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,210,5,0,64,214,5,0,0,0,0,0,0,0,0,0,240,3,2,0,136,210,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,226,47,0,0,98,43,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,211,5,0,64,214,5,0,0,0,0,0,0,0,0,0,240,3,2,0,16,211,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,2,17,0,0,110,42,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,212,5,0,64,214,5,0,0,0,0,0,0,0,0,0,240,3,2,0,224,211,5,0,0,0,0,0,176,211,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,186,16,0,0,30,6,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,214,5,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,88,212,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,204,21,0,0,88,15,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,216,5,0,32,217,5,0,0,0,0,0,0,0,0,0,96,135,2,0,40,216,5,0,0,0,0,0,216,208,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,12,28,0,0,226,38,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,217,5,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,224,216,5,0,0,0,0,0,216,208,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,206,43,0,0,90,30,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,218,5,0,136,218,5,0,0,0,0,0,0,0,0,0,240,3,2,0,64,217,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,72,12,0,0,116,23,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,218,5,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,112,218,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,80,30,0,0,222,25,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,219,5,0,0,0,0,0,0,0,0,0,0,0,0,0,104,174,7,0,24,219,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,186,54,0,0,124,42,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,207,5,0,16,208,5,0,0,0,0,0,0,0,0,0,0,38,7,0,32,207,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,222,54,0,0,0,18,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,208,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,200,207,5,0,0,0,0,0,0,193,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,148,48,0,0,184,27,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,220,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,72,220,5,0,0,0,0,0,160,88,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,178,47,0,0,14,2,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,107,3,0,192,69,5,0,0,0,0,0,0,0,0,0,0,46,3,0,88,107,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,22,61,0,0,142,36,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,108,3,0,192,69,5,0,0,0,0,0,0,0,0,0,0,46,3,0,144,107,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,230,6,0,0,42,24,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,227,5,0,176,228,5,0,0,0,0,0,0,0,0,0,32,127,5,0,200,224,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,8,51,0,0,234,6,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,224,5,0,176,228,5,0,0,0,0,0,0,0,0,0,32,127,5,0,112,224,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,52,22,0,0,22,0,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,223,5,0,176,228,5,0,0,0,0,0,0,0,0,0,32,127,5,0,232,222,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,182,62,0,0,146,7,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,222,5,0,176,228,5,0,0,0,0,0,0,0,0,0,32,127,5,0,112,221,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,188,20,0,0,254,45,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,224,5,0,176,228,5,0,0,0,0,0,0,0,0,0,32,127,5,0,224,223,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,150,61,0,0,14,13,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,223,5,0,176,228,5,0,0,0,0,0,0,0,0,0,32,127,5,0,136,223,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,64,58,0,0,244,20,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,227,5,0,176,228,5,0,0,0,0,0,0,0,0,0,32,127,5,0,128,227,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,62,38,0,0,128,36,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,228,5,0,176,228,5,0,0,0,0,0,0,0,0,0,32,127,5,0,8,228,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,154,0,0,0,44,19,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,228,5,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,152,228,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,112,46,0,0,200,28,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,92,4,0,64,36,3,0,0,0,0,0,0,0,0,0,240,3,2,0,224,88,4,0,0,0,0,0,72,246,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,40,39,0,0,208,6,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,96,4,0,64,36,3,0,0,0,0,0,0,0,0,0,240,3,2,0,208,94,4,0,0,0,0,0,72,246,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,52,61,0,0,242,44,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,229,5,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,8,229,5,0,0,0,0,0,144,110,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,110,21,0,0,126,5,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,97,6,0,168,100,6,0,0,0,0,0,0,0,0,0,176,229,7,0,96,97,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,170,52,0,0,52,7,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,230,5,0,0,0,0,0,0,0,0,0,0,0,0,0,168,163,7,0,136,229,5,0,0,0,0,0,56,24,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,58,8,0,0,222,17,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,230,5,0,200,232,5,0,0,0,0,0,0,0,0,0,96,135,2,0,192,230,5,0,0,0,0,0,88,239,7,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,154,19,0,0,126,11,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,231,5,0,200,232,5,0,0,0,0,0,0,0,0,0,96,135,2,0,40,231,5,0,0,0,0,0,88,239,7,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,54,22,0,0,58,7,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,232,5,0,200,232,5,0,0,0,0,0,0,0,0,0,96,135,2,0,168,231,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,232,57,0,0,112,23,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,232,5,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,88,232,5,0,0,0,0,0,88,239,7,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,128,29,0,0,140,15,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,233,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,16,233,5,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,146,1,0,0,168,10,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,237,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,56,236,5,0,0,0,0,0,56,127,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,8,54,0,0,78,22,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,234,5,0,176,234,5,0,0,0,0,0,0,0,0,0,240,3,2,0,224,233,5,0,0,0,0,0,160,88,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,170,61,0,0,202,20,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,235,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,224,234,5,0,0,0,0,0,160,88,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,82,47,0,0,80,46,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,236,5,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,152,235,5,0,0,0,0,0,160,88,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,194,56,0,0,164,8,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,234,5,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,128,234,5,0,0,0,0,0,160,88,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,224,4,0,0,56,36,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,238,5,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,32,238,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,98,52,0,0,24,27,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,239,5,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,160,238,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,150,7,0,0,84,24,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,75,7,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,136,75,7,0,0,0,0,0,192,181,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,242,31,0,0,184,25,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,243,5,0,176,246,5,0,0,0,0,0,0,0,0,0,96,135,2,0,40,243,5,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,14,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,46,45,0,0,16,0,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,246,5,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,248,243,5,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,14,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,242,36,0,0,84,43,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,111,3,0,104,12,6,0,0,0,0,0,0,0,0,0,0,46,3,0,128,111,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,14,11,0,0,222,44,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,250,5,0,168,11,6,0,0,0,0,0,0,0,0,0,0,38,7,0,208,248,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,64,40,0,0,232,10,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,247,5,0,168,11,6,0,0,0,0,0,0,0,0,0,0,38,7,0,240,246,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,220,14,0,0,36,7,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,252,5,0,168,11,6,0,0,0,0,0,0,0,0,0,0,38,7,0,152,251,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,190,43,0,0,220,27,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,250,5,0,168,11,6,0,0,0,0,0,0,0,0,0,0,38,7,0,160,250,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,130,9,0,0,200,36,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,6,6,0,168,11,6,0,0,0,0,0,0,0,0,0,0,38,7,0,144,5,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,120,61,0,0,106,11,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,5,6,0,168,11,6,0,0,0,0,0,0,0,0,0,0,38,7,0,200,4,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,70,3,0,0,130,10,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,4,6,0,168,11,6,0,0,0,0,0,0,0,0,0,0,38,7,0,176,3,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,8,17,0,0,66,44,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,3,6,0,168,11,6,0,0,0,0,0,0,0,0,0,0,38,7,0,24,2,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0])
.concat([196,53,0,0,92,32,0,0,88,42,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,2,6,0,168,11,6,0,0,0,0,0,0,0,0,0,0,38,7,0,168,1,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,82,5,0,0,76,3,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,1,6,0,168,11,6,0,0,0,0,0,0,0,0,0,0,38,7,0,160,0,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,172,38,0,0,64,44,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,0,6,0,168,11,6,0,0,0,0,0,0,0,0,0,0,38,7,0,192,255,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,12,35,0,0,222,9,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,255,5,0,168,11,6,0,0,0,0,0,0,0,0,0,0,38,7,0,152,254,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,80,54,0,0,64,0,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,253,5,0,168,11,6,0,0,0,0,0,0,0,0,0,0,38,7,0,72,252,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,20,55,0,0,134,39,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,10,6,0,168,11,6,0,0,0,0,0,0,0,0,0,0,38,7,0,88,10,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,112,3,0,0,38,38,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,9,6,0,168,11,6,0,0,0,0,0,0,0,0,0,0,38,7,0,224,6,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,100,11,0,0,26,14,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,6,6,0,168,11,6,0,0,0,0,0,0,0,0,0,0,38,7,0,128,6,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,170,19,0,0,192,20,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,11,6,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,80,11,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,246,33,0,0,246,38,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,12,6,0,0,0,0,0,0,0,0,0,0,0,0,0,184,12,8,0,248,11,6,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,108,51,0,0,74,35,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,12,6,0,0,0,0,0,0,0,0,0,0,0,0,0,168,163,7,0,208,12,6,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,54,63,0,0,50,5,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,15,6,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,136,13,6,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,106,38,0,0,24,15,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,16,6,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,216,15,6,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,0,61,0,0,8,29,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,231,6,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,16,189,6,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,38,28,0,0,44,21,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,90,8,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,24,89,8,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,136,60,0,0,110,18,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,16,6,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,40,16,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,42,39,0,0,144,20,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,237,5,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,160,237,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,26,23,0,0,194,18,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,112,3,0,128,70,4,0,0,0,0,0,0,0,0,0,0,46,3,0,224,111,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,216,11,0,0,76,18,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,16,6,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,112,16,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,16,39,0,0,44,44,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,17,6,0,0,0,0,0,0,0,0,0,0,0,0,0,168,163,7,0,32,17,6,0,0,0,0,0,48,143,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,12,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,150,19,0,0,214,0,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,18,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,136,17,6,0,0,0,0,0,48,143,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,11,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,164,3,0,0,14,36,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,19,6,0,0,0,0,0,0,0,0,0,0,0,0,0,184,12,8,0,112,19,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,12,47,0,0,54,20,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,34,6,0,64,36,6,0,0,0,0,0,0,0,0,0,0,38,7,0,40,34,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,28,27,0,0,22,46,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,33,6,0,64,36,6,0,0,0,0,0,0,0,0,0,0,38,7,0,88,33,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,6,2,0,0,2,24,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,32,6,0,64,36,6,0,0,0,0,0,0,0,0,0,0,38,7,0,152,32,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,180,47,0,0,56,11,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,32,6,0,64,36,6,0,0,0,0,0,0,0,0,0,0,38,7,0,168,31,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,216,13,0,0,192,31,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,31,6,0,64,36,6,0,0,0,0,0,0,0,0,0,0,38,7,0,224,30,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,252,22,0,0,60,23,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,30,6,0,64,36,6,0,0,0,0,0,0,0,0,0,0,38,7,0,120,30,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,72,56,0,0,254,8,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,30,6,0,64,36,6,0,0,0,0,0,0,0,0,0,0,38,7,0,248,29,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,110,34,0,0,50,0,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,29,6,0,64,36,6,0,0,0,0,0,0,0,0,0,0,38,7,0,168,29,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,132,20,0,0,52,39,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,28,6,0,64,36,6,0,0,0,0,0,0,0,0,0,0,38,7,0,184,28,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,146,41,0,0,106,23,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,28,6,0,64,36,6,0,0,0,0,0,0,0,0,0,0,38,7,0,64,27,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,44,12,0,0,146,29,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,26,6,0,64,36,6,0,0,0,0,0,0,0,0,0,0,38,7,0,176,26,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,34,40,0,0,38,23,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,26,6,0,64,36,6,0,0,0,0,0,0,0,0,0,0,38,7,0,24,26,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,10,10,0,0,222,2,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,25,6,0,64,36,6,0,0,0,0,0,0,0,0,0,0,38,7,0,56,25,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,12,44,0,0,160,14,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,25,6,0,64,36,6,0,0,0,0,0,0,0,0,0,0,38,7,0,240,24,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,196,55,0,0,50,2,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,24,6,0,64,36,6,0,0,0,0,0,0,0,0,0,0,38,7,0,72,24,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,204,56,0,0,82,10,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,24,6,0,64,36,6,0,0,0,0,0,0,0,0,0,0,38,7,0,200,23,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,12,56,0,0,10,33,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,23,6,0,64,36,6,0,0,0,0,0,0,0,0,0,0,38,7,0,32,23,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,10,29,0,0,234,7,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,22,6,0,64,36,6,0,0,0,0,0,0,0,0,0,0,38,7,0,184,22,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,16,6,0,0,186,42,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,22,6,0,64,36,6,0,0,0,0,0,0,0,0,0,0,38,7,0,24,22,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,148,6,0,0,186,25,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,21,6,0,64,36,6,0,0,0,0,0,0,0,0,0,0,38,7,0,72,20,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,82,56,0,0,120,37,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,20,6,0,64,36,6,0,0,0,0,0,0,0,0,0,0,38,7,0,16,20,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,150,27,0,0,226,25,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,36,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,240,34,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,138,2,0,0,4,48,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,18,6,0,96,19,6,0,0,0,0,0,0,0,0,0,0,38,7,0,104,18,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,2,30,0,0,84,8,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,19,6,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,232,18,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,142,33,0,0,250,8,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,201,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,128,201,6,0,0,0,0,0,48,143,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,48,24,0,0,220,24,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,61,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,240,60,4,0,0,0,0,0,160,88,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,126,10,0,0,228,31,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,129,3,0,80,58,8,0,0,0,0,0,0,0,0,0,0,46,3,0,8,129,3,0,0,0,0,0,40,132,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,50,15,0,0,176,15,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,40,6,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,200,39,6,0,0,0,0,0,24,215,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,144,26,0,0,8,8,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,239,5,0,48,241,5,0,0,0,0,0,0,0,0,0,0,46,3,0,184,239,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,54,21,0,0,182,34,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,240,5,0,48,241,5,0,0,0,0,0,0,0,0,0,32,127,5,0,0,240,5,0,0,0,0,0,168,66,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,166,16,0,0,202,22,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,241,5,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,224,240,5,0,0,0,0,0,168,66,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,194,54,0,0,16,15,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,41,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,216,40,6,0,0,0,0,0,216,208,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,26,25,0,0,44,30,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,42,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,152,41,6,0,0,0,0,0,216,208,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,40,3,0,0,76,42,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,43,6,0,216,43,6,0,0,0,0,0,0,0,0,0,0,38,7,0,160,42,6,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,190,13,0,0,58,43,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,43,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,96,43,6,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,52,63,0,0,138,3,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,44,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,56,44,6,0,0,0,0,0,80,89,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,184,21,0,0,116,15,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,49,6,0,0,0,0,0,0,0,0,0,0,0,0,0,184,12,8,0,144,48,6,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,130,45,0,0,172,40,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,49,6,0,0,0,0,0,0,0,0,0,0,0,0,0,168,163,7,0,128,49,6,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,36,34,0,0,174,22,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,51,6,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,248,50,6,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,166,46,0,0,208,27,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,52,6,0,176,52,6,0,0,0,0,0,0,0,0,0,0,38,7,0,160,51,6,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,190,60,0,0,154,28,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,52,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,88,52,6,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,216,18,0,0,16,10,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,54,6,0,0,55,6,0,0,0,0,0,0,0,0,0,224,53,6,0,48,53,6,0,0,0,0,0,48,143,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,11,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,222,5,0,0,20,45,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,55,6,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,72,54,6,0,0,0,0,0,48,143,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,11,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,232,30,0,0,156,27,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,55,6,0,64,57,6,0,0,0,0,0,0,0,0,0,0,38,7,0,88,55,6,0,0,0,0,0,56,56,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,10,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,138,20,0,0,158,34,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,56,6,0,64,57,6,0,0,0,0,0,0,0,0,0,0,38,7,0,80,56,6,0,0,0,0,0,56,56,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,10,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,62,46,0,0,70,44,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,56,6,0,64,57,6,0,0,0,0,0,0,0,0,0,240,3,2,0,160,56,6,0,0,0,0,0,104,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,10,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,180,31,0,0,210,1,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,57,6,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,32,57,6,0,0,0,0,0,104,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,10,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,186,29,0,0,226,16,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,57,6,0,184,58,6,0,0,0,0,0,0,0,0,0,168,163,7,0,120,57,6,0,0,0,0,0,248,88,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,170,60,0,0,8,46,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,58,6,0,0,0,0,0,0,0,0,0,0,0,0,0,168,163,7,0,40,58,6,0,0,0,0,0,248,88,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,112,60,0,0,190,28,0,0,0,0,0,0])
.concat([0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,59,6,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,8,59,6,0,0,0,0,0,40,47,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,174,22,0,0,198,28,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,87,6,0,176,88,6,0,0,0,0,0,0,0,0,0,0,38,7,0,232,86,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,12,5,0,0,74,28,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,86,6,0,176,88,6,0,0,0,0,0,0,0,0,0,0,38,7,0,168,84,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,90,38,0,0,88,16,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,83,6,0,176,88,6,0,0,0,0,0,0,0,0,0,0,38,7,0,160,82,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,134,48,0,0,4,14,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,59,6,0,8,82,6,0,0,0,0,0,0,0,0,0,0,38,7,0,192,59,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,54,1,0,0,92,13,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,59,6,0,8,82,6,0,0,0,0,0,0,0,0,0,0,38,7,0,72,59,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,250,53,0,0,136,29,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,81,6,0,8,82,6,0,0,0,0,0,0,0,0,0,0,38,7,0,192,80,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,118,9,0,0,148,40,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,80,6,0,8,82,6,0,0,0,0,0,0,0,0,0,0,38,7,0,120,79,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,54,12,0,0,58,27,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,78,6,0,8,82,6,0,0,0,0,0,0,0,0,0,0,38,7,0,128,77,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,2,38,0,0,172,6,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,76,6,0,8,82,6,0,0,0,0,0,0,0,0,0,0,38,7,0,88,76,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,182,38,0,0,88,31,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,75,6,0,8,82,6,0,0,0,0,0,0,0,0,0,0,38,7,0,48,75,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,108,40,0,0,52,23,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,75,6,0,8,82,6,0,0,0,0,0,0,0,0,0,0,38,7,0,152,74,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,88,48,0,0,160,8,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,74,6,0,8,82,6,0,0,0,0,0,0,0,0,0,0,38,7,0,8,73,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,66,19,0,0,46,12,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,72,6,0,8,82,6,0,0,0,0,0,0,0,0,0,0,38,7,0,0,72,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,176,35,0,0,206,22,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,68,6,0,8,82,6,0,0,0,0,0,0,0,0,0,32,127,5,0,24,68,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,204,29,0,0,30,33,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,67,6,0,8,82,6,0,0,0,0,0,0,0,0,0,32,127,5,0,160,67,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,18,21,0,0,212,3,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,66,6,0,8,82,6,0,0,0,0,0,0,0,0,0,32,127,5,0,240,65,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,204,5,0,0,90,22,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,65,6,0,8,82,6,0,0,0,0,0,0,0,0,0,32,127,5,0,40,65,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,240,0,0,0,30,20,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,65,6,0,8,82,6,0,0,0,0,0,0,0,0,0,32,127,5,0,216,64,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,66,27,0,0,238,5,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,64,6,0,8,82,6,0,0,0,0,0,0,0,0,0,32,127,5,0,224,63,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,2,16,0,0,56,44,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,63,6,0,8,82,6,0,0,0,0,0,0,0,0,0,32,127,5,0,56,63,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,202,59,0,0,20,37,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,62,6,0,8,82,6,0,0,0,0,0,0,0,0,0,32,127,5,0,200,62,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,248,33,0,0,106,18,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,62,6,0,8,82,6,0,0,0,0,0,0,0,0,0,32,127,5,0,24,62,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,62,36,0,0,150,44,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,61,6,0,8,82,6,0,0,0,0,0,0,0,0,0,32,127,5,0,192,61,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,58,55,0,0,150,16,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,61,6,0,8,82,6,0,0,0,0,0,0,0,0,0,32,127,5,0,208,60,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,36,40,0,0,16,31,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,60,6,0,8,82,6,0,0,0,0,0,0,0,0,0,32,127,5,0,128,60,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,50,53,0,0,84,22,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,70,6,0,8,82,6,0,0,0,0,0,0,0,0,0,32,127,5,0,136,70,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,176,37,0,0,30,40,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,70,6,0,8,82,6,0,0,0,0,0,0,0,0,0,32,127,5,0,216,69,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,192,49,0,0,220,30,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,69,6,0,8,82,6,0,0,0,0,0,0,0,0,0,32,127,5,0,208,68,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,234,21,0,0,250,27,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,82,6,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,152,81,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,52,57,0,0,164,14,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,88,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,64,88,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,70,9,0,0,198,16,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,112,3,0,8,82,6,0,0,0,0,0,0,0,0,0,0,46,3,0,144,112,3,0,0,0,0,0,40,132,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,234,38,0,0,56,12,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,113,3,0,176,88,6,0,0,0,0,0,0,0,0,0,0,46,3,0,64,113,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,242,41,0,0,32,3,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,114,3,0,72,137,6,0,0,0,0,0,0,0,0,0,0,46,3,0,152,113,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,168,11,0,0,24,8,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,114,3,0,168,245,6,0,0,0,0,0,0,0,0,0,0,46,3,0,88,114,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,186,34,0,0,134,47,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,89,6,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,24,89,6,0,0,0,0,0,232,92,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,228,21,0,0,12,22,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,93,6,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,40,93,6,0,0,0,0,0,232,92,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,58,1,0,0,240,34,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,94,6,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,40,94,6,0,0,0,0,0,176,67,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,64,46,0,0,184,43,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,36,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,136,36,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,82,16,0,0,70,8,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,192,5,0,72,194,5,0,0,0,0,0,0,0,0,0,240,3,2,0,96,192,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,124,35,0,0,102,42,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,39,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,0,39,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,2,10,0,0,192,47,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,38,6,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,112,38,6,0,0,0,0,0,40,37,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,146,34,0,0,22,41,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,96,6,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,240,95,6,0,0,0,0,0,160,95,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,196,32,0,0,198,9,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,99,6,0,168,100,6,0,0,0,0,0,0,0,0,0,184,168,7,0,56,99,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,54,47,0,0,38,15,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,100,6,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,48,100,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,8,28,0,0,80,14,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,116,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,16,116,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,250,48,0,0,154,45,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,194,6,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,80,194,6,0,0,0,0,0,64,246,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,102,8,0,0,10,17,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,153,6,0,208,154,6,0,0,0,0,0,0,0,0,0,104,221,5,0,160,153,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,26,62,0,0,180,45,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,154,6,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,72,154,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,84,23,0,0,234,24,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,74,5,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,40,74,5,0,0,0,0,0,40,47,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,30,57,0,0,244,16,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,104,6,0,200,104,6,0,0,0,0,0,0,0,0,0,104,221,5,0,240,103,6,0,0,0,0,0,160,150,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,44,8,0,0,160,32,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,104,6,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,104,104,6,0,0,0,0,0,216,28,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,144,51,0,0,10,13,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,105,6,0,104,108,6,0,0,0,0,0,0,0,0,0,96,135,2,0,8,105,6,0,0,0,0,0,72,246,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,244,11,0,0,4,12,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,107,6,0,104,108,6,0,0,0,0,0,0,0,0,0,96,135,2,0,208,105,6,0,0,0,0,0,72,246,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,238,56,0,0,212,40,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,108,6,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,64,108,6,0,0,0,0,0,72,246,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,184,38,0,0,52,46,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,204,6,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,56,204,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,216,7,0,0,190,34,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,109,6,0,88,110,6,0,0,0,0,0,0,0,0,0,0,46,3,0,8,109,6,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,140,43,0,0,120,6,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,110,6,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,232,109,6,0,0,0,0,0,168,109,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,242,47,0,0,90,23,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,210,6,0,64,217,6,0,0,0,0,0,0,0,0,0,32,127,5,0,200,209,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,242,6,0,0,246,1,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,212,6,0,64,217,6,0,0,0,0,0,0,0,0,0,32,127,5,0,152,211,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,248,60,0,0,214,6,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,211,6,0,64,217,6,0,0,0,0,0,0,0,0,0,32,127,5,0,176,210,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,58,15,0,0,178,2,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,208,6,0,64,217,6,0,0,0,0,0,0,0,0,0,32,127,5,0,152,208,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,178,60,0,0,184,42,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,208,6,0,64,217,6,0,0,0,0,0,0,0,0,0,32,127,5,0,216,207,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,66,2,0,0,44,4,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,207,6,0,64,217,6,0,0,0,0,0,0,0,0,0,32,127,5,0,96,207,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,28,15,0,0,238,8,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,207,6,0,64,217,6,0,0,0,0,0,0,0,0,0,32,127,5,0,168,206,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,128,6,0,0,6,10,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,216,6,0,64,217,6,0,0,0,0,0,0,0,0,0,32,127,5,0,16,216,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,108,8,0,0,78,11,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,215,6,0,64,217,6,0,0,0,0,0,0,0,0,0,32,127,5,0,208,214,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,60,38,0,0,120,4,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,214,6,0,64,217,6,0,0,0,0,0,0,0,0,0,32,127,5,0,112,213,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,246,19,0,0,8,1,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,213,6,0,64,217,6,0,0,0,0,0,0,0,0,0,32,127,5,0,64,212,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,92,14,0,0,226,37,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,206,6,0,64,217,6,0,0,0,0,0,0,0,0,0,32,127,5,0,64,206,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,148,20,0,0,68,21,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,217,6,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,184,216,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,122,56,0,0,102,28,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0])
.concat([226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,110,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,136,110,6,0,0,0,0,0,32,230,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,70,58,0,0,220,46,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,111,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,136,111,6,0,0,0,0,0,32,230,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,18,43,0,0,206,35,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,114,3,0,192,199,8,0,0,0,0,0,0,0,0,0,0,46,3,0,152,114,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,224,48,0,0,176,21,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,116,6,0,32,117,6,0,0,0,0,0,0,0,0,0,96,135,2,0,104,116,6,0,0,0,0,0,224,105,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,64,1,0,0,28,31,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,117,6,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,248,116,6,0,0,0,0,0,224,105,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,44,16,0,0,166,41,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,137,6,0,72,139,6,0,0,0,0,0,0,0,0,0,0,38,7,0,136,137,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,240,2,0,0,178,46,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,129,6,0,240,130,6,0,0,0,0,0,0,0,0,0,32,127,5,0,112,129,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,178,15,0,0,126,8,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,129,6,0,240,130,6,0,0,0,0,0,0,0,0,0,32,127,5,0,128,128,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,152,22,0,0,138,40,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,128,6,0,240,130,6,0,0,0,0,0,0,0,0,0,32,127,5,0,104,127,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,226,60,0,0,148,29,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,127,6,0,240,130,6,0,0,0,0,0,0,0,0,0,32,127,5,0,64,126,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,72,17,0,0,126,28,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,125,6,0,240,130,6,0,0,0,0,0,0,0,0,0,32,127,5,0,120,125,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,148,40,0,0,22,24,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,130,6,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,48,130,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,252,11,0,0,252,12,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,133,6,0,72,139,6,0,0,0,0,0,0,0,0,0,0,38,7,0,16,133,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,60,29,0,0,226,29,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,132,6,0,72,139,6,0,0,0,0,0,0,0,0,0,0,38,7,0,64,131,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,132,36,0,0,50,4,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,137,6,0,72,139,6,0,0,0,0,0,0,0,0,0,0,38,7,0,64,136,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,118,30,0,0,18,41,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,136,6,0,72,139,6,0,0,0,0,0,0,0,0,0,0,38,7,0,96,135,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,168,24,0,0,128,14,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,135,6,0,72,139,6,0,0,0,0,0,0,0,0,0,0,38,7,0,176,134,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,128,14,0,0,92,46,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,134,6,0,72,139,6,0,0,0,0,0,0,0,0,0,0,38,7,0,192,133,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,44,31,0,0,36,12,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,116,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,24,115,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,94,25,0,0,0,4,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,139,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,104,138,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,48,33,0,0,76,10,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,151,6,0,144,153,6,0,0,0,0,0,0,0,0,0,0,38,7,0,24,151,6,0,0,0,0,0,152,22,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,42,51,0,0,114,16,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,152,6,0,144,153,6,0,0,0,0,0,0,0,0,0,0,38,7,0,48,152,6,0,0,0,0,0,152,22,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,120,14,0,0,88,5,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,153,6,0,144,153,6,0,0,0,0,0,0,0,0,0,32,127,5,0,176,152,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,186,39,0,0,178,9,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,153,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,72,153,6,0,0,0,0,0,152,22,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,172,8,0,0,60,17,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,102,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,184,101,6,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,4,14,0,0,44,18,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,103,6,0,48,201,7,0,0,0,0,0,0,0,0,0,240,3,2,0,56,103,6,0,0,0,0,0,80,89,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,128,4,0,0,172,33,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,201,7,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,184,194,7,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,220,25,0,0,28,25,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,118,6,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,88,118,6,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,176,52,0,0,128,27,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,114,6,0,232,115,6,0,0,0,0,0,0,0,0,0,240,3,2,0,24,114,6,0,0,0,0,0,104,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,238,32,0,0,0,19,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,119,6,0,200,119,6,0,0,0,0,0,0,0,0,0,0,46,3,0,224,118,6,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,190,16,0,0,82,18,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,119,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,168,119,6,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,96,53,0,0,116,43,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,112,6,0,24,113,6,0,0,0,0,0,0,0,0,0,32,127,5,0,112,112,6,0,0,0,0,0,80,235,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,90,7,0,0,56,40,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,113,6,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,208,112,6,0,0,0,0,0,48,143,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,54,15,0,0,132,29,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,113,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,88,113,6,0,0,0,0,0,48,143,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,74,26,0,0,0,42,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,115,6,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,112,115,6,0,0,0,0,0,104,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,192,21,0,0,100,11,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,120,6,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,88,120,6,0,0,0,0,0,16,120,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,74,44,0,0,4,15,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,122,6,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,8,121,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,232,48,0,0,48,17,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,140,6,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,176,139,6,0,0,0,0,0,104,139,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,38,7,0,0,4,1,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,138,5,0,200,34,4,0,0,0,0,0,0,0,0,0,0,38,7,0,88,134,5,0,0,0,0,0,32,230,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,148,37,0,0,142,31,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,34,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,72,7,4,0,0,0,0,0,32,230,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,248,49,0,0,196,27,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,140,6,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,40,140,6,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,8,19,0,0,144,26,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,141,6,0,40,143,6,0,0,0,0,0,0,0,0,0,240,3,2,0,48,141,6,0,0,0,0,0,232,115,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,60,21,0,0,174,42,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,142,6,0,40,143,6,0,0,0,0,0,0,0,0,0,240,3,2,0,224,141,6,0,0,0,0,0,160,200,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,172,39,0,0,176,16,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,143,6,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,144,142,6,0,0,0,0,0,232,115,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,250,5,0,0,206,17,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,145,6,0,192,146,6,0,0,0,0,0,0,0,0,0,144,47,2,0,112,144,6,0,0,0,0,0,0,193,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,140,7,0,0,28,15,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,146,6,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,224,145,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,172,9,0,0,88,11,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,147,6,0,0,0,0,0,0,0,0,0,0,0,0,0,168,163,7,0,16,147,6,0,0,0,0,0,168,178,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,4,0,0,0,5,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,242,43,0,0,18,34,0,0,0,0,0,0,0,0,0,0,120,28,0,0,136,19,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,147,6,0,168,45,1,0,0,0,0,0,0,0,0,0,0,38,7,0,72,147,6,0,0,0,0,0,168,178,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,4,0,0,0,5,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,122,21,0,0,40,1,0,0,0,0,0,0,0,0,0,0,120,28,0,0,136,19,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,45,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,208,37,1,0,0,0,0,0,168,178,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,4,0,0,0,5,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,98,9,0,0,66,39,0,0,0,0,0,0,0,0,0,0,120,28,0,0,136,19,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,149,6,0,128,206,6,0,0,0,0,0,0,0,0,0,240,3,2,0,128,148,6,0,0,0,0,0,168,178,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,242,54,0,0,170,14,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,149,6,0,128,206,6,0,0,0,0,0,0,0,0,0,240,3,2,0,128,149,6,0,0,0,0,0,168,178,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,38,22,0,0,218,6,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,150,6,0,128,206,6,0,0,0,0,0,0,0,0,0,240,3,2,0,40,150,6,0,0,0,0,0,168,178,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,16,57,0,0,22,39,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,206,6,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,120,202,6,0,0,0,0,0,168,178,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,210,12,0,0,28,14,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,148,6,0,176,28,1,0,0,0,0,0,0,0,0,0,32,127,5,0,232,147,6,0,0,0,0,0,168,178,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,4,0,0,0,5,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,138,8,0,0,128,26,0,0,0,0,0,0,0,0,0,0,120,28,0,0,136,19,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,28,1,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,176,17,1,0,0,0,0,0,168,178,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,4,0,0,0,5,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,64,44,0,0,218,29,0,0,0,0,0,0,0,0,0,0,120,28,0,0,136,19,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,171,7,0,216,174,7,0,0,0,0,0,0,0,0,0,96,135,2,0,104,171,7,0,0,0,0,0,72,246,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,8,60,0,0,148,16,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,172,7,0,216,174,7,0,0,0,0,0,0,0,0,0,96,135,2,0,104,172,7,0,0,0,0,0,72,246,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,60,7,0,0,82,17,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,174,7,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,64,173,7,0,0,0,0,0,72,246,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,30,24,0,0,196,28,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,150,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,128,150,6,0,0,0,0,0,104,58,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,212,55,0,0,4,29,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,153,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,80,152,7,0,0,0,0,0,192,223,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,88,40,0,0,248,24,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,116,3,0,72,15,1,0,0,0,0,0,0,0,0,0,0,46,3,0,152,116,3,0,0,0,0,0,40,132,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,252,7,0,0,60,21,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,123,6,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,160,122,6,0,0,0,0,0,0,193,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,8,14,0,0,186,7,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,156,6,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,32,156,6,0,0,0,0,0,16,96,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,154,33,0,0,8,39,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,157,6,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,176,156,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,84,36,0,0,180,1,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,157,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,120,157,6,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,104,17,0,0,4,30,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,158,6,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,232,157,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,10,37,0,0,146,45,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,164,6,0,48,165,6,0,0,0,0,0,0,0,0,0,0,38,7,0,128,163,6,0,0,0,0,0,0,193,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,100,44,0,0,38,2,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,165,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,0,165,6,0,0,0,0,0,152,22,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,90,1,0,0,40,24,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,121,5,0,120,121,5,0,0,0,0,0,0,0,0,0,144,47,2,0,232,120,5,0,0,0,0,0,176,67,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,238,31,0,0,126,26,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,166,6,0,48,167,6,0,0,0,0,0,0,0,0,0,0,38,7,0,144,165,6,0,0,0,0,0,120,175,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,244,29,0,0,208,32,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,167,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,200,166,6,0,0,0,0,0,120,175,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,130,8,0,0,158,2,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0])
.concat([104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,158,6,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,72,158,6,0,0,0,0,0,176,67,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,168,35,0,0,14,41,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,173,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,152,172,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,178,44,0,0,94,25,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,172,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,80,172,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,18,35,0,0,28,34,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,159,6,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,184,158,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,200,6,0,0,54,41,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,172,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,64,171,6,0,0,0,0,0,192,223,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,1,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,96,50,0,0,46,48,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,160,6,0,32,163,6,0,0,0,0,0,0,0,0,0,240,3,2,0,200,160,6,0,0,0,0,0,224,109,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,130,14,0,0,128,2,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,161,6,0,32,163,6,0,0,0,0,0,0,0,0,0,96,135,2,0,32,161,6,0,0,0,0,0,72,246,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,122,62,0,0,142,7,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,161,6,0,32,163,6,0,0,0,0,0,0,0,0,0,96,135,2,0,176,161,6,0,0,0,0,0,72,246,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,230,43,0,0,102,25,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,163,6,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,144,162,6,0,0,0,0,0,72,246,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,74,47,0,0,180,15,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,62,1,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,56,54,1,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,116,26,0,0,66,11,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,173,6,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,104,173,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,200,14,0,0,78,6,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,175,6,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,232,174,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,4,43,0,0,136,43,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,176,6,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,232,175,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,148,41,0,0,244,47,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,177,6,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,32,177,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,0,62,0,0,42,32,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,172,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,80,172,6,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,250,25,0,0,106,5,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,178,6,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,216,177,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,66,24,0,0,186,38,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,181,6,0,184,74,1,0,0,0,0,0,0,0,0,0,0,38,7,0,152,180,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,88,35,0,0,146,4,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,74,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,144,67,1,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,72,55,0,0,86,19,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,179,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,0,179,6,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,136,46,0,0,240,32,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,182,6,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,144,181,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,200,57,0,0,242,11,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,183,6,0,160,187,6,0,0,0,0,0,0,0,0,0,240,3,2,0,208,182,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,84,31,0,0,200,41,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,184,6,0,160,187,6,0,0,0,0,0,0,0,0,0,240,3,2,0,224,183,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,198,40,0,0,200,15,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,185,6,0,160,187,6,0,0,0,0,0,0,0,0,0,240,3,2,0,64,185,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,170,49,0,0,200,22,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,187,6,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,248,186,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,12,7,0,0,28,33,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,143,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,112,143,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,160,38,0,0,140,45,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,191,6,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,152,190,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,22,17,0,0,10,2,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,188,6,0,72,191,6,0,0,0,0,0,0,0,0,0,240,3,2,0,184,187,6,0,0,0,0,0,232,246,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,32,53,0,0,36,40,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,189,6,0,72,191,6,0,0,0,0,0,0,0,0,0,240,3,2,0,168,188,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,112,13,0,0,94,18,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,190,6,0,72,191,6,0,0,0,0,0,0,0,0,0,240,3,2,0,112,189,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,156,5,0,0,58,25,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,147,8,0,24,148,8,0,0,0,0,0,0,0,0,0,32,127,5,0,248,145,8,0,0,0,0,0,168,66,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,176,43,0,0,176,7,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,148,8,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,128,147,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,106,53,0,0,56,8,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,193,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,208,192,6,0,0,0,0,0,72,192,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,238,52,0,0,14,39,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,194,6,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,0,194,6,0,0,0,0,0,136,72,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,134,36,0,0,174,19,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,195,6,0,144,196,6,0,0,0,0,0,0,0,0,0,144,47,2,0,88,195,6,0,0,0,0,0,16,195,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,118,58,0,0,86,38,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,196,6,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,16,196,6,0,0,0,0,0,232,62,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,238,34,0,0,150,29,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,89,1,0,240,118,1,0,0,0,0,0,0,0,0,0,144,47,2,0,200,81,1,0,0,0,0,0,176,67,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,168,59,0,0,106,3,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,121,4,0,240,118,1,0,0,0,0,0,0,0,0,0,144,47,2,0,152,121,4,0,0,0,0,0,176,67,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,190,3,0,0,156,11,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,197,6,0,112,197,6,0,0,0,0,0,0,0,0,0,32,127,5,0,184,196,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,190,0,0,0,108,13,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,197,6,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,88,197,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,16,2,0,0,196,14,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,197,6,0,232,199,6,0,0,0,0,0,0,0,0,0,0,38,7,0,184,197,6,0,0,0,0,0,232,115,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,218,18,0,0,222,15,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,198,6,0,232,199,6,0,0,0,0,0,0,0,0,0,0,38,7,0,88,198,6,0,0,0,0,0,232,115,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,14,31,0,0,226,30,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,199,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,176,199,6,0,0,0,0,0,232,115,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,172,49,0,0,156,23,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,200,6,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,248,199,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,62,24,0,0,124,2,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,118,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,40,118,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,208,48,0,0,178,31,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,119,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,192,118,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,148,60,0,0,156,24,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,201,6,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,208,200,6,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,186,18,0,0,188,36,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,224,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,32,224,6,0,0,0,0,0,88,78,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,168,2,0,0,72,34,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,95,6,0,56,96,6,0,0,0,0,0,0,0,0,0,144,47,2,0,240,94,6,0,0,0,0,0,64,246,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,24,36,0,0,42,44,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,242,5,0,224,242,5,0,0,0,0,0,0,0,0,0,240,3,2,0,216,241,5,0,0,0,0,0,216,121,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,96,21,0,0,70,3,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,242,5,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,160,242,5,0,0,0,0,0,168,95,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,154,24,0,0,164,5,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,202,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,80,202,6,0,0,0,0,0,168,178,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,44,54,0,0,50,15,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,203,6,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,8,203,6,0,0,0,0,0,112,139,7,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,16,31,0,0,82,36,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,159,3,0,56,160,3,0,0,0,0,0,0,0,0,0,0,46,3,0,0,159,3,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,23,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,144,5,0,0,196,3,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,160,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,232,159,3,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,23,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,62,33,0,0,226,10,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,204,6,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,224,203,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,20,39,0,0,64,18,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,143,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,248,142,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,122,43,0,0,148,13,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,205,6,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,144,204,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,170,33,0,0,64,10,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,119,3,0,96,177,8,0,0,0,0,0,0,0,0,0,0,46,3,0,80,119,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,172,2,0,0,220,37,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,218,6,0,0,0,0,0,0,0,0,0,0,0,0,0,168,163,7,0,168,217,6,0,0,0,0,0,136,217,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,138,26,0,0,48,29,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,49,7,0,88,50,7,0,0,0,0,0,0,0,0,0,96,135,2,0,120,48,7,0,0,0,0,0,80,89,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,118,45,0,0,112,26,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,219,6,0,0,0,0,0,0,0,0,0,0,0,0,0,184,12,8,0,104,218,6,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,76,15,0,0,126,39,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,221,6,0,0,0,0,0,0,0,0,0,0,0,0,0,184,12,8,0,184,220,6,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,24,23,0,0,68,37,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,221,6,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,56,221,6,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,4,54,0,0,22,19,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,222,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,40,222,6,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,126,33,0,0,60,19,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,223,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,240,222,6,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,24,2,0,0,118,28,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,52,7,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,112,51,7,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,162,42,0,0,104,9,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,53,7,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,216,52,7,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,244,8,0,0,6,20,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,50,7,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,8,50,7,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,170,10,0,0,112,36,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,51,7,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,112,50,7,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,212,18,0,0,156,45,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,119,3,0,144,170,8,0,0,0,0,0,0,0,0,0,0,46,3,0,136,119,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,158,16,0,0,8,27,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,120,3,0,8,205,6,0,0,0,0,0,0,0,0,0,0,46,3,0,0,120,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,44,30,0,0,104,37,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0])
.concat([4,0,0,0,3,0,0,0,104,225,6,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,40,225,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,106,36,0,0,150,45,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,63,7,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,232,18,7,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,86,47,0,0,152,16,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,226,6,0,24,227,6,0,0,0,0,0,0,0,0,0,240,3,2,0,176,225,6,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,66,10,0,0,250,15,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,227,6,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,208,226,6,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,22,18,0,0,220,20,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,120,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,96,120,3,0,0,0,0,0,40,132,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,206,42,0,0,216,38,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,121,3,0,64,191,4,0,0,0,0,0,0,0,0,0,0,46,3,0,176,120,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,204,60,0,0,234,44,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,228,6,0,0,0,0,0,0,0,0,0,0,0,0,0,184,12,8,0,16,228,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,140,32,0,0,20,11,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,229,6,0,152,230,6,0,0,0,0,0,0,0,0,0,96,135,2,0,168,228,6,0,0,0,0,0,232,27,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,136,9,0,0,110,38,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,229,6,0,152,230,6,0,0,0,0,0,0,0,0,0,240,3,2,0,208,229,6,0,0,0,0,0,232,27,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,218,46,0,0,186,36,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,230,6,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,88,230,6,0,0,0,0,0,232,27,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,56,3,0,0,118,22,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,231,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,240,230,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,34,10,0,0,6,2,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,232,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,0,232,6,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,172,20,0,0,198,37,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,234,6,0,0,0,0,0,0,0,0,0,0,0,0,0,168,163,7,0,128,233,6,0,0,0,0,0,32,230,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,0,43,0,0,4,3,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,235,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,200,234,6,0,0,0,0,0,224,212,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,32,8,0,0,82,24,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,144,3,0,192,160,3,0,0,0,0,0,0,0,0,0,0,46,3,0,0,144,3,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,166,24,0,0,66,7,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,144,3,0,192,160,3,0,0,0,0,0,0,0,0,0,0,46,3,0,112,144,3,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,15,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,224,43,0,0,206,45,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,160,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,128,160,3,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,15,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,42,54,0,0,152,8,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,150,3,0,120,161,3,0,0,0,0,0,0,0,0,0,0,46,3,0,8,150,3,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,136,43,0,0,244,15,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,161,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,32,161,3,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,30,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,164,44,0,0,120,3,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,97,4,0,160,97,4,0,0,0,0,0,0,0,0,0,96,135,2,0,240,96,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,80,20,0,0,240,28,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,235,6,0,72,50,8,0,0,0,0,0,0,0,0,0,32,127,5,0,48,235,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,110,57,0,0,40,7,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,235,6,0,72,50,8,0,0,0,0,0,0,0,0,0,32,127,5,0,88,235,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,162,18,0,0,16,34,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,236,6,0,72,50,8,0,0,0,0,0,0,0,0,0,32,127,5,0,248,235,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,190,45,0,0,166,38,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,237,6,0,72,50,8,0,0,0,0,0,0,0,0,0,32,127,5,0,120,236,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,98,33,0,0,178,33,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,50,8,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,232,42,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,252,39,0,0,100,8,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,237,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,120,237,6,0,0,0,0,0,160,88,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,210,58,0,0,158,8,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,238,6,0,208,238,6,0,0,0,0,0,0,0,0,0,240,3,2,0,16,238,6,0,0,0,0,0,80,89,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,186,47,0,0,188,45,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,238,6,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,136,238,6,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,118,21,0,0,182,28,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,120,4,0,248,120,4,0,0,0,0,0,0,0,0,0,104,221,5,0,120,120,4,0,0,0,0,0,112,139,7,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,28,48,0,0,40,6,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,240,6,0,224,240,6,0,0,0,0,0,0,0,0,0,240,3,2,0,56,240,6,0,0,0,0,0,168,95,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,100,52,0,0,38,24,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,240,6,0,224,240,6,0,0,0,0,0,0,0,0,0,240,3,2,0,104,240,6,0,0,0,0,0,168,95,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,234,44,0,0,4,35,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,240,6,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,160,240,6,0,0,0,0,0,168,95,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,80,13,0,0,116,39,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,244,6,0,64,245,6,0,0,0,0,0,0,0,0,0,96,135,2,0,32,244,6,0,0,0,0,0,8,116,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,146,36,0,0,170,16,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,244,6,0,64,245,6,0,0,0,0,0,0,0,0,0,96,135,2,0,152,244,6,0,0,0,0,0,8,116,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,164,51,0,0,116,37,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,245,6,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,248,244,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,20,11,0,0,138,43,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,241,6,0,168,243,6,0,0,0,0,0,0,0,0,0,0,38,7,0,16,241,6,0,0,0,0,0,56,127,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,186,2,0,0,132,27,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,243,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,0,242,6,0,0,0,0,0,56,127,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,234,50,0,0,54,21,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,239,6,0,8,240,6,0,0,0,0,0,0,0,0,0,0,38,7,0,0,239,6,0,0,0,0,0,168,95,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,4,9,0,0,180,19,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,240,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,120,239,6,0,0,0,0,0,168,95,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,82,32,0,0,178,40,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,247,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,208,245,6,0,0,0,0,0,120,175,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,182,0,0,0,212,19,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,248,6,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,248,247,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,10,48,0,0,84,9,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,248,6,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,56,248,6,0,0,0,0,0,152,22,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,214,54,0,0,166,20,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,148,4,0,176,148,4,0,0,0,0,0,0,0,0,0,184,168,7,0,240,147,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,222,60,0,0,30,36,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,80,4,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,72,80,4,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,170,0,0,0,206,25,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,3,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,144,2,7,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,218,30,0,0,224,40,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,251,6,0,184,251,6,0,0,0,0,0,0,0,0,0,144,47,2,0,104,251,6,0,0,0,0,0,112,139,7,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,96,36,0,0,100,35,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,249,6,0,208,250,6,0,0,0,0,0,0,0,0,0,0,38,7,0,208,248,6,0,0,0,0,0,112,139,7,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,84,18,0,0,144,1,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,250,6,0,208,250,6,0,0,0,0,0,0,0,0,0,0,38,7,0,104,249,6,0,0,0,0,0,112,139,7,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,142,30,0,0,250,33,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,250,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,64,250,6,0,0,0,0,0,112,139,7,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,164,21,0,0,48,28,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,252,6,0,24,75,7,0,0,0,0,0,0,0,0,0,96,135,2,0,8,252,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,194,57,0,0,88,13,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,253,6,0,24,75,7,0,0,0,0,0,0,0,0,0,96,135,2,0,32,253,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,8,2,0,0,78,5,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,255,6,0,24,75,7,0,0,0,0,0,0,0,0,0,96,135,2,0,16,255,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,98,34,0,0,14,18,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,0,7,0,24,75,7,0,0,0,0,0,0,0,0,0,240,3,2,0,48,0,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,206,39,0,0,70,16,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,78,7,0,24,75,7,0,0,0,0,0,0,0,0,0,240,3,2,0,160,70,7,0,0,0,0,0,40,161,4,0,32,20,3,0,248,65,7,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,2,21,0,0,72,44,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,75,7,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,120,1,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,250,7,0,0,70,18,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,2,7,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,232,1,7,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,50,47,0,0,28,28,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,0,8,0,160,2,8,0,0,0,0,0,0,0,0,0,144,47,2,0,152,255,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,194,16,0,0,152,11,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,1,8,0,160,2,8,0,0,0,0,0,0,0,0,0,144,47,2,0,160,0,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,34,27,0,0,106,44,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,5,7,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,56,4,7,0,0,0,0,0,176,67,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,212,4,0,0,34,29,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,122,3,0,0,138,1,0,0,0,0,0,0,0,0,0,0,46,3,0,232,121,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,162,57,0,0,254,20,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,121,3,0,0,138,1,0,0,0,0,0,0,0,0,0,0,46,3,0,136,121,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,76,40,0,0,64,34,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,52,4,0,232,53,4,0,0,0,0,0,0,0,0,0,144,47,2,0,208,51,4,0,0,0,0,0,240,201,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,154,7,0,0,206,39,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,98,6,0,168,100,6,0,0,0,0,0,0,0,0,0,184,168,7,0,72,98,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,214,33,0,0,30,12,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,68,4,0,8,69,4,0,0,0,0,0,0,0,0,0,144,47,2,0,176,68,4,0,0,0,0,0,64,207,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,122,10,0,0,130,31,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,6,7,0,200,7,7,0,0,0,0,0,0,0,0,0,96,135,2,0,80,6,7,0,0,0,0,0,40,47,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,108,33,0,0,196,31,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,7,7,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,232,6,7,0,0,0,0,0,40,47,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,218,11,0,0,194,29,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,18,7,0,56,19,7,0,0,0,0,0,0,0,0,0,240,3,2,0,0,18,7,0,0,0,0,0,232,180,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,206,16,0,0,146,31,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,17,7,0,56,19,7,0,0,0,0,0,0,0,0,0,240,3,2,0,144,17,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,72,10,0,0,126,12,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,17,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,88,15,7,0,0,0,0,0,232,180,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,22,21,0,0,156,32,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,19,7,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,160,18,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,20,44,0,0,170,4,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,64,8,0,144,65,8,0,0,0,0,0,0,0,0,0,96,135,2,0,72,64,8,0,0,0,0,0,96,179,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,40,35,0,0,236,23,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,123,3,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,46,3,0,24,123,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,66,49,0,0,224,10,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,163,3,0,32,164,3,0,0,0,0,0,0,0,0,0,0,46,3,0,72,163,3,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,21,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,140,34,0,0,236,29,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,164,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,0,164,3,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,21,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,112,18,0,0,216,1,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,150,3,0,96,164,3,0,0,0,0,0,0,0,0,0,0,46,3,0,96,150,3,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,128,37,0,0,78,3,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,164,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,64,164,3,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,20,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,160,10,0,0,22,7,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,144,3,0,96,164,3,0,0,0,0,0,0,0,0,0,0,46,3,0,184,144,3,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,112,1,0,0,96,26,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,255,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,104,254,4,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,132,42,0,0,8,34,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,9,7,0,208,9,7,0,0,0,0,0,0,0,0,0,104,221,5,0,184,8,7,0,0,0,0,0,176,67,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,64,63,0,0,48,6,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,9,7,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,80,9,7,0,0,0,0,0,160,200,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,52,2,0,0,60,42,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,11,7,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,88,10,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,244,55,0,0,156,15,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,12,7,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,160,11,7,0,0,0,0,0,136,72,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,254,33,0,0,236,17,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,13,7,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,136,12,7,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,40,40,0,0,150,34,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,14,7,0,48,15,7,0,0,0,0,0,0,0,0,0,96,135,2,0,176,13,7,0,0,0,0,0,96,179,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,202,48,0,0,102,34,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,15,7,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,192,14,7,0,0,0,0,0,232,246,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,8,57,0,0,102,26,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,19,7,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,144,19,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,230,7,0,0,160,24,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,252,7,0,208,254,7,0,0,0,0,0,0,0,0,0,240,3,2,0,184,251,7,0,0,0,0,0,80,89,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,192,13,0,0,70,0,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,23,7,0,176,139,7,0,0,0,0,0,0,0,0,0,96,135,2,0,16,23,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,144,56,0,0,34,41,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,139,7,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,104,134,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,196,52,0,0,78,20,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,23,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,120,23,7,0,0,0,0,0,232,246,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,122,55,0,0,236,20,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,121,2,0,64,128,2,0,0,0,0,0,0,0,0,0,240,3,2,0,104,120,2,0,0,0,0,0,112,119,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,58,52,0,0,182,41,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,122,3,0,112,7,2,0,0,0,0,0,0,0,0,0,0,46,3,0,224,122,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,14,57,0,0,20,35,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,24,7,0,216,24,7,0,0,0,0,0,0,0,0,0,0,38,7,0,200,23,7,0,0,0,0,0,120,175,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,42,34,0,0,170,36,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,24,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,112,24,7,0,0,0,0,0,120,175,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,140,9,0,0,196,42,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,25,7,0,192,25,7,0,0,0,0,0,0,0,0,0,144,47,2,0,8,25,7,0,0,0,0,0,96,179,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,44,56,0,0,58,28,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,25,7,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,152,25,7,0,0,0,0,0,8,13,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,210,23,0,0,238,41,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,131,4,0,128,149,4,0,0,0,0,0,0,0,0,0,104,174,7,0,120,128,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,122,63,0,0,160,22,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,143,4,0,128,149,4,0,0,0,0,0,0,0,0,0,104,174,7,0,200,135,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,206,45,0,0,88,45,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,210,5,0,64,214,5,0,0,0,0,0,0,0,0,0,0,46,3,0,208,208,5,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,128,32,0,0,66,8,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,37,7,0,184,38,7,0,0,0,0,0,0,0,0,0,0,38,7,0,56,37,7,0,0,0,0,0,224,212,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,206,13,0,0,32,31,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,38,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,40,38,7,0,0,0,0,0,224,212,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,176,14,0,0,116,42,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,39,7,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,48,39,7,0,0,0,0,0,112,242,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,202,52,0,0,220,39,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,36,7,0,240,36,7,0,0,0,0,0,0,0,0,0,240,3,2,0,208,35,7,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,182,36,0,0,132,24,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,35,7,0,240,36,7,0,0,0,0,0,0,0,0,0,240,3,2,0,104,35,7,0,0,0,0,0,80,89,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,84,60,0,0,84,34,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,36,7,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,160,36,7,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,178,61,0,0,130,23,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,71,7,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,112,70,7,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,202,58,0,0,134,31,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,58,8,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,232,208,7,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,114,50,0,0,170,46,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,33,7,0,24,35,7,0,0,0,0,0,0,0,0,0,240,3,2,0,96,33,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,206,48,0,0,8,43,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,34,7,0,24,35,7,0,0,0,0,0,0,0,0,0,240,3,2,0,208,33,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,108,50,0,0,18,22,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,28,7,0,80,33,7,0,0,0,0,0,0,0,0,0,0,38,7,0,144,27,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,162,21,0,0,58,33,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,27,7,0,80,33,7,0,0,0,0,0,0,0,0,0,0,38,7,0,0,27,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,36,55,0,0,74,47,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,26,7,0,80,33,7,0,0,0,0,0,0,0,0,0,0,38,7,0,96,26,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,56,45,0,0,160,7,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,32,7,0,80,33,7,0,0,0,0,0,0,0,0,0,0,38,7,0,64,32,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,76,16,0,0,126,35,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,31,7,0,80,33,7,0,0,0,0,0,0,0,0,0,0,38,7,0,136,30,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,198,41,0,0,40,39,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,30,7,0,80,33,7,0,0,0,0,0,0,0,0,0,0,38,7,0,208,29,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,210,59,0,0,62,6,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,29,7,0,80,33,7,0,0,0,0,0,0,0,0,0,0,38,7,0,16,29,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,118,18,0,0,138,19,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,29,7,0,80,33,7,0,0,0,0,0,0,0,0,0,0,38,7,0,200,28,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,202,4,0,0,192,38,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,28,7,0,80,33,7,0,0,0,0,0,0,0,0,0,0,38,7,0,104,28,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,252,62,0,0,108,42,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,33,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,248,32,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,226,37,0,0,158,20,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,34,7,0,24,35,7,0,0,0,0,0,0,0,0,0,240,3,2,0,56,34,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,120,19,0,0,124,10,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,35,7,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,0,35,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,68,62,0,0,162,47,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,45,7,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,232,43,7,0,0,0,0,0,136,108,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,72,31,0,0,100,3,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,45,7,0,48,48,7,0,0,0,0,0,0,0,0,0,240,3,2,0,136,45,7,0,0,0,0,0,80,89,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,192,27,0,0,228,13,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,47,7,0,48,48,7,0,0,0,0,0,0,0,0,0,96,135,2,0,136,46,7,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,246,23,0,0,200,2,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,48,7,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,72,47,7,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,116,59,0,0,150,2,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,156,1,0,24,145,1,0,0,0,0,0,0,0,0,0,144,47,2,0,104,133,1,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,248,41,0,0,154,46,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,145,1,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,192,53,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,102,19,0,0,94,14,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,56,7,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,160,55,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,250,28,0,0,78,18,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,57,7,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,104,56,7,0,0,0,0,0,232,180,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,236,17,0,0,248,27,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,76,7,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,224,75,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,200,13,0,0,46,22,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,78,7,0,208,78,7,0,0,0,0,0,0,0,0,0,240,3,2,0,40,78,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,188,33,0,0,18,35,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,77,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,0,77,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,156,17,0,0,100,37,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,78,7,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,144,78,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,220,54,0,0,152,14,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,26,7,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,8,26,7,0,0,0,0,0,48,143,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,44,32,0,0,98,8,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,31,8,0,160,33,8,0,0,0,0,0,0,0,0,0,240,3,2,0,216,30,8,0,0,0,0,0,80,156,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,28,53,0,0,220,11,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,58,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,216,57,7,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,124,30,0,0,126,6,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,61,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,224,59,7,0,0,0,0,0,152,59,7,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,132,14,0,0,70,39,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,59,7,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,144,58,7,0,0,0,0,0,72,246,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,246,3,0,0,168,1,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,62,7,0,112,247,6,0,0,0,0,0,0,0,0,0,144,47,2,0,48,62,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,232,16,0,0,142,18,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,247,6,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,184,243,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,88,49,0,0,184,29,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,65,7,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,56,65,7,0,0,0,0,0,216,121,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,154,23,0,0,68,38,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,63,7,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,16,63,7,0,0,0,0,0,216,121,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,44,63,0,0,54,11,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,64,7,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,32,64,7,0])
.concat([0,0,0,0,216,121,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,226,11,0,0,124,1,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,155,7,0,184,157,7,0,0,0,0,0,0,0,0,0,96,135,2,0,192,154,7,0,0,0,0,0,232,62,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,210,51,0,0,118,3,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,67,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,32,67,7,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,6,25,0,0,148,2,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,41,7,0,80,43,7,0,0,0,0,0,0,0,0,0,32,127,5,0,0,41,7,0,0,0,0,0,48,143,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,76,56,0,0,212,1,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,40,7,0,80,43,7,0,0,0,0,0,0,0,0,0,32,127,5,0,80,40,7,0,0,0,0,0,48,143,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,70,18,0,0,74,34,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,43,7,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,192,41,7,0,0,0,0,0,48,143,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,70,45,0,0,106,6,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,75,7,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,224,74,7,0,0,0,0,0,64,246,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,40,42,0,0,238,14,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,73,7,0,184,57,1,0,0,0,0,0,0,0,0,0,96,135,2,0,168,72,7,0,0,0,0,0,232,115,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,4,4,0,0,198,12,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,72,7,0,184,57,1,0,0,0,0,0,0,0,0,0,240,3,2,0,56,72,7,0,0,0,0,0,160,200,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,56,21,0,0,136,9,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,57,1,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,112,179,8,0,0,0,0,0,232,115,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,42,59,0,0,22,36,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,67,7,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,136,67,7,0,0,0,0,0,120,67,7,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,166,48,0,0,124,41,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,68,7,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,248,67,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,144,10,0,0,80,4,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,69,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,240,68,7,0,0,0,0,0,224,212,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,216,34,0,0,230,38,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,79,7,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,248,78,7,0,0,0,0,0,88,239,7,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,86,60,0,0,160,29,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,79,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,120,79,7,0,0,0,0,0,48,143,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,142,0,0,0,234,25,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,80,7,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,16,80,7,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,0,3,0,0,202,6,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,82,7,0,0,0,0,0,0,0,0,0,0,0,0,0,168,163,7,0,176,82,7,0,0,0,0,0,168,95,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,56,15,0,0,92,10,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,82,7,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,152,81,7,0,0,0,0,0,192,181,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,6,12,0,0,242,28,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,123,3,0,88,124,3,0,0,0,0,0,0,0,0,0,0,46,3,0,96,123,3,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,128,11,0,0,132,38,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,124,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,24,124,3,0,0,0,0,0,80,131,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,202,54,0,0,252,4,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,83,7,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,32,83,7,0,0,0,0,0,232,115,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,36,57,0,0,178,28,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,84,7,0,144,96,7,0,0,0,0,0,0,0,0,0,0,38,7,0,216,83,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,178,1,0,0,228,29,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,91,7,0,144,96,7,0,0,0,0,0,0,0,0,0,0,38,7,0,176,90,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,78,25,0,0,204,19,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,90,7,0,144,96,7,0,0,0,0,0,0,0,0,0,0,38,7,0,64,89,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,144,14,0,0,166,1,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,89,7,0,144,96,7,0,0,0,0,0,0,0,0,0,0,38,7,0,64,88,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,44,26,0,0,160,6,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,88,7,0,144,96,7,0,0,0,0,0,0,0,0,0,0,38,7,0,8,87,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,94,62,0,0,82,37,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,86,7,0,144,96,7,0,0,0,0,0,0,0,0,0,0,38,7,0,32,86,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,208,42,0,0,218,38,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,93,7,0,144,96,7,0,0,0,0,0,0,0,0,0,0,38,7,0,0,92,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,216,12,0,0,224,5,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,94,7,0,144,96,7,0,0,0,0,0,0,0,0,0,0,38,7,0,144,93,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,70,31,0,0,60,26,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,95,7,0,144,96,7,0,0,0,0,0,0,0,0,0,0,38,7,0,192,94,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,202,16,0,0,144,40,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,96,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,168,95,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,42,13,0,0,196,1,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,98,7,0,160,100,7,0,0,0,0,0,0,0,0,0,104,221,5,0,216,97,7,0,0,0,0,0,96,179,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,106,41,0,0,32,24,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,100,7,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,56,99,7,0,0,0,0,0,8,13,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,188,40,0,0,140,22,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,124,3,0,216,124,3,0,0,0,0,0,0,0,0,0,0,46,3,0,128,124,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,44,44,0,0,228,21,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,101,7,0,80,102,7,0,0,0,0,0,0,0,0,0,96,135,2,0,224,100,7,0,0,0,0,0,88,239,7,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,124,54,0,0,132,13,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,102,7,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,240,101,7,0,0,0,0,0,88,239,7,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,24,16,0,0,62,2,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,125,3,0,112,95,4,0,0,0,0,0,0,0,0,0,0,46,3,0,8,125,3,0,0,0,0,0,40,132,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,162,10,0,0,84,19,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,106,7,0,64,107,7,0,0,0,0,0,0,0,0,0,240,3,2,0,184,105,7,0,0,0,0,0,80,89,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,120,37,0,0,248,20,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,107,7,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,8,107,7,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,92,33,0,0,0,29,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,108,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,184,107,7,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,190,50,0,0,120,43,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,125,5,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,144,124,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,128,21,0,0,208,5,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,125,3,0,240,142,1,0,0,0,0,0,0,0,0,0,0,46,3,0,48,125,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,170,32,0,0,82,5,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,126,3,0,240,142,1,0,0,0,0,0,0,0,0,0,0,46,3,0,160,125,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,126,61,0,0,94,12,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,126,3,0,8,132,3,0,0,0,0,0,0,0,0,0,0,46,3,0,128,126,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,174,29,0,0,76,16,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,110,7,0,224,110,7,0,0,0,0,0,0,0,0,0,144,47,2,0,144,108,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,18,32,0,0,6,17,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,110,7,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,96,110,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,106,22,0,0,88,9,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,113,7,0,232,114,7,0,0,0,0,0,0,0,0,0,0,38,7,0,200,112,7,0,0,0,0,0,168,95,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,124,62,0,0,136,31,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,113,7,0,232,114,7,0,0,0,0,0,0,0,0,0,0,38,7,0,112,113,7,0,0,0,0,0,168,95,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,104,42,0,0,146,42,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,114,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,72,114,7,0,0,0,0,0,168,95,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,124,12,0,0,12,47,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,116,7,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,192,115,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,102,3,0,0,76,37,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,118,7,0,168,118,7,0,0,0,0,0,0,0,0,0,0,38,7,0,80,117,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,134,13,0,0,186,20,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,118,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,136,118,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,186,25,0,0,60,40,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,128,7,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,32,128,7,0,0,0,0,0,216,127,7,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,54,58,0,0,172,14,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,118,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,200,118,7,0,0,0,0,0,88,239,7,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,88,38,0,0,164,21,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,119,7,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,24,119,7,0,0,0,0,0,216,121,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,64,13,0,0,120,47,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,103,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,160,102,7,0,0,0,0,0,88,239,7,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,10,31,0,0,8,21,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,164,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,168,164,3,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,25,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,130,49,0,0,106,25,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,165,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,24,165,3,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,42,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,72,42,0,0,124,37,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,127,3,0,216,174,7,0,0,0,0,0,0,0,0,0,0,46,3,0,96,127,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,44,36,0,0,66,33,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,128,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,200,127,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,28,16,0,0,252,5,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,120,7,0,192,121,7,0,0,0,0,0,0,0,0,0,96,135,2,0,8,120,7,0,0,0,0,0,152,22,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,164,62,0,0,36,23,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,121,7,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,128,121,7,0,0,0,0,0,152,22,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,98,62,0,0,232,29,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,123,7,0,104,172,1,0,0,0,0,0,0,0,0,0,96,135,2,0,24,123,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,28,35,0,0,84,31,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,122,7,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,160,122,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,140,2,0,0,186,39,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,172,1,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,24,164,1,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,168,55,0,0,188,1,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,247,6,0,40,248,6,0,0,0,0,0,0,0,0,0,184,168,7,0,160,247,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,100,31,0,0,140,3,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,124,7,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,200,123,7,0,0,0,0,0,64,246,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,42,63,0,0,166,24,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,125,7,0,112,86,7,0,0,0,0,0,0,0,0,0,184,168,7,0,128,125,7,0,0,0,0,0,72,122,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,214,58,0,0,210,36,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,86,7,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,192,81,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,56,59,0,0,128,4,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,127,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,40,127,3,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,122,39,0,0,46,11,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,227,8,0,144,230,8,0,0,0,0,0,0,0,0,0,0,46,3,0,232,225,8,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,176,53,0,0,196,29,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,125,7,0,216,126,7,0,0,0,0,0,0,0,0,0,144,47,2,0,208,125,7,0,0,0,0,0,216,28,5,0,32,20,3,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,110,28,0,0,200,34,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,126,7,0,216,126,7,0,0,0,0,0,0,0,0,0,104,221,5,0,24,126,7,0,0,0,0,0,112,139,7,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,10,47,0,0,138,8,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,126,7,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,104,126,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,200,27,0,0,178,6,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,127,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,0,127,7,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,236,51,0,0,232,30,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,128,7,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,152,128,7,0,0,0,0,0,112,242,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,60,13,0,0,116,46,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,238,7,0,64,240,7,0,0,0,0,0,0,0,0,0,32,127,5,0,8,238,7,0,0,0,0,0,88,239,7,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,184,5,0,0,228,8,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,129,7,0,48,193,1,0,0,0,0,0,0,0,0,0,240,3,2,0,216,128,7,0,0,0,0,0,0,193,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,248,23,0,0,68,40,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,193,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,48,186,1,0,0,0,0,0,168,178,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,226,48,0,0,154,44,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,130,7,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,192,129,7,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,58,46,0,0,34,45,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,133,7,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,72,133,7,0,0,0,0,0,160,200,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,30,2,0,0,106,4,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,132,7,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,48,132,7,0,0,0,0,0,192,181,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,44,5,0,0,146,27,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,132,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,104,132,7,0,0,0,0,0,192,181,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,114,49,0,0,38,7,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,131,7,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,88,130,7,0,0,0,0,0,144,110,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,210,0,0,0,252,0,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,131,7,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,208,131,7,0,0,0,0,0,192,181,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,238,28,0,0,156,43,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,135,7,0,72,136,7,0,0,0,0,0,0,0,0,0,144,47,2,0,184,134,7,0,0,0,0,0,112,139,7,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,118,48,0,0,230,14,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,136,7,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,192,135,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,174,7,0,0,54,32,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,136,7,0,136,140,7,0,0,0,0,0,0,0,0,0,240,3,2,0,152,136,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,180,3,0,0,120,10,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,138,7,0,136,140,7,0,0,0,0,0,0,0,0,0,240,3,2,0,200,137,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,240,25,0,0,166,30,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,139,7,0,136,140,7,0,0,0,0,0,0,0,0,0,240,3,2,0,200,138,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,58,51,0,0,202,33,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,140,7,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,8,140,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,4,37,0,0,86,23,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,141,7,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,216,140,7,0,0,0,0,0,88,239,7,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,104,57,0,0,30,42,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,128,3,0,104,205,7,0,0,0,0,0,0,0,0,0,0,46,3,0,64,128,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,250,29,0,0,172,20,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,143,7,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,120,143,7,0,0,0,0,0,64,246,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,218,61,0,0,126,1,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,147,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,32,147,7,0,0,0,0,0,160,200,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,238,54,0,0,48,48,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,148,7,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,168,147,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,120,35,0,0,14,16,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,154,7,0,240,153,7,0,0,0,0,0,0,0,0,0,0,38,7,0,96,153,7,0,0,0,0,0,192,223,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,54,38,0,0,174,46,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,157,7,0,184,157,7,0,0,0,0,0,0,0,0,0,96,135,2,0,224,155,7,0,0,0,0,0,192,135,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,154,4,0,0,104,7,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,157,7,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,136,157,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,198,53,0,0,240,23,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,158,7,0,88,159,7,0,0,0,0,0,0,0,0,0,104,221,5,0,16,158,7,0,0,0,0,0,120,158,7,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,196,19,0,0,74,13,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,159,7,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,216,158,7,0,0,0,0,0,120,158,7,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,50,42,0,0,196,9,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,162,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,96,160,7,0,0,0,0,0,64,32,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,228,4,0,0,88,6,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,162,7,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,128,162,7,0,0,0,0,0,24,125,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,70,41,0,0,218,7,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,163,7,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,96,163,7,0,0,0,0,0,232,196,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,16,58,0,0,110,20,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,167,7,0,216,167,7,0,0,0,0,0,0,0,0,0,184,168,7,0,240,166,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,202,31,0,0,202,35,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,167,7,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,168,167,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,168,41,0,0,146,40,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,165,7,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,208,163,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,66,38,0,0,232,36,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,165,7,0,224,166,7,0,0,0,0,0,0,0,0,0,144,47,2,0,112,165,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,182,29,0,0,38,11,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,166,7,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,120,166,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,6,58,0,0,12,40,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,166,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,224,165,3,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,38,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,58,2,0,0,214,38,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,168,7,0,96,171,7,0,0,0,0,0,0,0,0,0,96,135,2,0,16,168,7,0,0,0,0,0,216,208,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,46,7,0,0,196,41,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,169,7,0,96,171,7,0,0,0,0,0,0,0,0,0,96,135,2,0,232,168,7,0,0,0,0,0,216,208,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,50,55,0,0,212,26,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,171,7,0,96,171,7,0,0,0,0,0,0,0,0,0,240,3,2,0,240,170,7,0,0,0,0,0,160,170,7,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,32,11,0,0,234,42,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,171,7,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,48,171,7,0,0,0,0,0,192,181,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,68,52,0,0,130,11,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,203,7,0,128,204,7,0,0,0,0,0,0,0,0,0,240,3,2,0,144,202,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,230,23,0,0,100,4,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,204,7,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,184,203,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,114,23,0,0,48,45,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,175,7,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,104,175,7,0,0,0,0,0,112,139,7,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,62,18,0,0,94,32,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,149,7,0,152,217,1,0,0,0,0,0,0,0,0,0,0,38,7,0,0,149,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,1,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,64,25,0,0,146,6,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,150,7,0,152,217,1,0,0,0,0,0,0,0,0,0,0,38,7,0,208,149,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,1,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,210,17,0,0,148,36,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,217,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,56,204,1,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,1,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,252,14,0,0,108,21,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,242,1,0,40,16,2,0,0,0,0,0,0,0,0,0,184,168,7,0,128,231,1,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,162,22,0,0,230,19,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,16,2,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,184,255,1,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,20,13,0,0,6,45,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,176,7,0,40,177,7,0,0,0,0,0,0,0,0,0,104,221,5,0,16,176,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,126,6,0,0,246,36,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,177,7,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,184,176,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,206,18,0,0,86,47,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,197,7,0,144,198,7,0,0,0,0,0,0,0,0,0,144,47,2,0,96,196,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,212,38,0,0,238,36,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,198,7,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,240,197,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,120,26,0,0,94,34,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,100,3,0,112,100,3,0,0,0,0,0,0,0,0,0,0,46,3,0,216,99,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,188,25,0,0,62,15,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,100,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,64,100,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,70,19,0,0,4,9,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,196,7,0,80,217,7,0,0,0,0,0,0,0,0,0,144,47,2,0,160,195,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,26,42,0,0,108,44,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,217,7,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,48,213,7,0,0,0,0,0,56,207,7,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,246,57,0,0,120,34,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,178,7,0,192,178,7,0,0,0,0,0,0,0,0,0,96,135,2,0,160,177,7,0,0,0,0,0,40,47,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,168,7,0,0,174,34,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,178,7,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,16,178,7,0,0,0,0,0,40,47,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,0,38,0,0,16,44,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,180,7,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,136,179,7,0,0,0,0,0,160,88,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,206,50,0,0,154,3,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,180,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,104,180,7,0,0,0,0,0,120,175,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,202,44,0,0,116,28,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,179,7,0,24,180,7,0,0,0,0,0,0,0,0,0,240,3,2,0,248,178,7,0,0,0,0,0,160,88,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,68,37,0,0,48,8,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,181,7,0,192,182,7,0,0,0,0,0,0,0,0,0,0,38,7,0,80,181,7,0,0,0,0,0,80,89,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,206,37,0,0,216,18,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,182,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,16,182,7,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,82,13,0,0,162,38,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,97,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,232,96,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,32,33,0,0,186,8,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,184,7,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,72,183,7,0,0,0,0,0,160,88,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,144,4,0,0,248,47,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,185,7,0,32,188,7,0,0,0,0,0,0,0,0,0,240,3,2,0,136,184,7,0,0,0,0,0,160,200,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,38,31,0,0,146,24,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,186,7,0,32,188,7,0,0,0,0,0,0,0,0,0,240,3,2,0,120,186,7,0,0,0,0,0,160,200,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,188,35,0,0,2,6,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,188,7,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,128,187,7,0,0,0,0,0,160,200,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,82,37,0,0,20,40,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,3,8,0,192,4,8,0,0,0,0,0,0,0,0,0,0,38,7,0,248,2,8,0,0,0,0,0,232,180,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0])
.concat([2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,226,0,0,0,44,1,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,5,8,0,48,8,8,0,0,0,0,0,0,0,0,0,240,3,2,0,208,4,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,212,56,0,0,90,31,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,190,7,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,136,189,7,0,0,0,0,0,32,189,7,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,232,40,0,0,20,14,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,192,7,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,88,191,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,172,37,0,0,236,0,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,36,2,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,80,26,2,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,1,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,208,51,0,0,226,6,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,194,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,200,192,7,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,8,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,66,20,0,0,198,20,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,195,7,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,16,195,7,0,0,0,0,0,80,156,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,84,52,0,0,250,7,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,245,6,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,112,245,6,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,64,36,0,0,70,22,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,200,7,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,72,199,7,0,0,0,0,0,232,62,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,152,55,0,0,146,9,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,202,7,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,192,201,7,0,0,0,0,0,216,121,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,10,3,0,0,80,38,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,227,7,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,56,227,7,0,0,0,0,0,160,51,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,204,43,0,0,54,46,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,234,7,0,240,127,7,0,0,0,0,0,0,0,0,0,0,46,3,0,104,234,7,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,22,24,0,0,196,34,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,167,3,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,248,166,3,0,0,0,0,0,104,167,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,35,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,240,20,0,0,242,29,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,207,7,0,136,207,7,0,0,0,0,0,0,0,0,0,240,3,2,0,168,205,7,0,0,0,0,0,128,223,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,128,49,0,0,8,13,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,207,7,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,112,207,7,0,0,0,0,0,152,22,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,228,43,0,0,238,15,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,205,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,32,205,7,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,208,45,0,0,118,18,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,208,7,0,0,0,0,0,0,0,0,0,0,0,0,0,192,177,6,0,80,208,7,0,0,0,0,0,32,208,7,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,134,3,0,0,132,19,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,210,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,104,210,7,0,0,0,0,0,152,22,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,230,56,0,0,130,19,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,19,8,0,128,19,8,0,0,0,0,0,0,0,0,0,240,3,2,0,248,18,8,0,0,0,0,0,160,200,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,122,60,0,0,88,32,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,214,7,0,160,214,7,0,0,0,0,0,0,0,0,0,184,168,7,0,0,213,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,138,29,0,0,108,40,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,214,7,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,112,214,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,176,29,0,0,0,32,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,214,7,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,176,214,7,0,0,0,0,0,48,143,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,158,11,0,0,234,40,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,174,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,208,173,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,204,40,0,0,6,26,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,215,7,0,136,217,7,0,0,0,0,0,0,0,0,0,240,3,2,0,80,215,7,0,0,0,0,0,64,246,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,34,42,0,0,178,8,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,215,7,0,136,217,7,0,0,0,0,0,0,0,0,0,240,3,2,0,208,215,7,0,0,0,0,0,64,246,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,168,33,0,0,164,33,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,217,7,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,48,217,7,0,0,0,0,0,64,246,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,16,13,0,0,90,8,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,218,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,184,217,7,0,0,0,0,0,152,22,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,234,37,0,0,66,28,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,218,7,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,112,218,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,96,58,0,0,186,1,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,219,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,248,218,7,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,36,30,0,0,222,35,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,220,7,0,128,222,7,0,0,0,0,0,0,0,0,0,240,3,2,0,176,219,7,0,0,0,0,0,88,239,7,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,210,19,0,0,252,18,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,221,7,0,128,222,7,0,0,0,0,0,0,0,0,0,240,3,2,0,48,221,7,0,0,0,0,0,88,239,7,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,166,33,0,0,34,16,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,222,7,0,128,222,7,0,0,0,0,0,0,0,0,0,240,3,2,0,216,221,7,0,0,0,0,0,8,116,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,94,18,0,0,50,6,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,222,7,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,96,222,7,0,0,0,0,0,88,239,7,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,224,14,0,0,0,17,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,225,7,0,72,226,7,0,0,0,0,0,0,0,0,0,104,221,5,0,48,224,7,0,0,0,0,0,40,225,7,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,22,27,0,0,194,33,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,225,7,0,72,226,7,0,0,0,0,0,0,0,0,0,104,221,5,0,136,225,7,0,0,0,0,0,40,225,7,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,238,61,0,0,32,5,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,226,7,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,48,226,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,104,23,0,0,28,39,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,226,7,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,120,226,7,0,0,0,0,0,64,246,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,18,14,0,0,24,24,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,73,7,0,120,75,7,0,0,0,0,0,0,0,0,0,104,221,5,0,88,73,7,0,0,0,0,0,64,246,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,50,38,0,0,208,22,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,229,7,0,160,229,7,0,0,0,0,0,0,0,0,0,144,47,2,0,120,228,7,0,0,0,0,0,64,207,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,16,50,0,0,126,7,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,229,7,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,32,229,7,0,0,0,0,0,64,207,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,230,55,0,0,134,29,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,232,7,0,152,233,7,0,0,0,0,0,0,0,0,0,0,46,3,0,120,231,7,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,48,35,0,0,32,12,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,230,7,0,0,0,0,0,0,0,0,0,0,0,0,0,184,12,8,0,0,230,7,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,210,38,0,0,132,46,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,108,2,0,0,0,0,0,0,0,0,0,0,0,0,0,168,163,7,0,32,149,1,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,116,5,0,0,196,5,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,233,7,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,72,233,7,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,122,32,0,0,190,44,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,131,7,0,240,127,7,0,0,0,0,0,0,0,0,0,0,38,7,0,152,125,7,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,18,51,0,0,178,18,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,127,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,72,22,7,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,90,59,0,0,216,35,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,129,3,0,240,127,7,0,0,0,0,0,0,0,0,0,0,46,3,0,184,129,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,32,13,0,0,110,34,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,130,3,0,24,12,4,0,0,0,0,0,0,0,0,0,0,46,3,0,24,130,3,0,0,0,0,0,40,132,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,122,9,0,0,56,48,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,129,3,0,64,236,7,0,0,0,0,0,0,0,0,0,0,46,3,0,96,129,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,46,25,0,0,158,35,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,231,7,0,88,108,2,0,0,0,0,0,0,0,0,0,0,46,3,0,192,230,7,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,70,37,0,0,202,15,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,236,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,8,236,7,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,114,28,0,0,208,41,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,237,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,248,236,7,0,0,0,0,0,72,187,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,26,4,0,0,30,11,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,240,7,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,216,239,7,0,0,0,0,0,88,239,7,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,174,41,0,0,222,14,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,241,7,0,72,76,2,0,0,0,0,0,0,0,0,0,96,135,2,0,200,240,7,0,0,0,0,0,40,47,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,142,39,0,0,172,12,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,242,7,0,72,76,2,0,0,0,0,0,0,0,0,0,96,135,2,0,128,241,7,0,0,0,0,0,40,47,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,74,15,0,0,236,46,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,76,2,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,0,64,2,0,0,0,0,0,40,47,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,220,44,0,0,218,1,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,246,7,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,168,244,7,0,0,0,0,0,168,66,2,0,32,20,3,0,136,243,7,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,200,21,0,0,108,26,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,248,7,0,0,250,7,0,0,0,0,0,0,0,0,0,168,163,7,0,184,247,7,0,0,0,0,0,232,248,7,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,122,28,0,0,20,31,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,250,7,0,0,0,0,0,0,0,0,0,0,0,0,0,168,163,7,0,112,249,7,0,0,0,0,0,232,248,7,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,190,9,0,0,56,1,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,251,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,112,250,7,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,76,48,0,0,52,48,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,15,5,0,104,16,5,0,0,0,0,0,0,0,0,0,104,221,5,0,144,15,5,0,0,0,0,0,40,15,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,26,43,0,0,162,15,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,5,8,0,48,8,8,0,0,0,0,0,0,0,0,0,240,3,2,0,168,5,8,0,0,0,0,0,232,180,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,224,0,0,0,42,1,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,4,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,40,4,8,0,0,0,0,0,232,180,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,146,9,0,0,216,31,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,8,8,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,168,7,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,144,59,0,0,20,12,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,254,7,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,240,253,7,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,28,0,0,0,196,24,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,2,8,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,160,1,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,242,59,0,0,102,30,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,128,3,0,248,60,1,0,0,0,0,0,0,0,0,0,0,46,3,0,168,128,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,118,1,0,0,16,20,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,12,8,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,104,11,8,0,0,0,0,0,128,9,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,42,14,0,0,64,48,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,12,8,0,168,12,8,0,0,0,0,0,0,0,0,0,144,47,2,0,48,12,8,0,0,0,0,0,168,178,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,144,43,0,0,202,13,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,12,8,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,136,12,8,0,0,0,0,0,168,178,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,96,4,0,0,218,27,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,13,8,0,104,14,8,0,0,0,0,0,0,0,0,0,144,47,2,0,200,12,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,12,14,0,0,74,46,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,14,8,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,16,14,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0])
.concat([196,53,0,0,210,21,0,0,240,5,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,16,8,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,208,15,8,0,0,0,0,0,216,121,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,148,11,0,0,178,0,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,16,8,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,96,16,8,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,122,35,0,0,150,30,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,21,8,0,168,145,8,0,0,0,0,0,0,0,0,0,144,47,2,0,184,20,8,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,180,0,0,0,232,7,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,19,8,0,168,145,8,0,0,0,0,0,0,0,0,0,240,3,2,0,136,19,8,0,0,0,0,0,80,89,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,236,1,0,0,120,33,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,155,7,0,168,145,8,0,0,0,0,0,0,0,0,0,144,47,2,0,152,35,5,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,52,39,0,0,166,23,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,145,8,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,120,21,8,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,204,6,0,0,38,46,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,17,8,0,200,18,8,0,0,0,0,0,0,0,0,0,240,3,2,0,120,17,8,0,0,0,0,0,232,115,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,218,27,0,0,10,26,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,18,8,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,80,18,8,0,0,0,0,0,232,115,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,52,36,0,0,152,36,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,90,6,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,16,90,6,0,0,0,0,0,232,92,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,152,13,0,0,232,13,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,17,8,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,200,16,8,0,0,0,0,0,72,226,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,190,7,0,0,110,46,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,22,8,0,208,23,8,0,0,0,0,0,0,0,0,0,240,3,2,0,112,22,8,0,0,0,0,0,248,165,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,220,32,0,0,166,22,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,23,8,0,208,23,8,0,0,0,0,0,0,0,0,0,240,3,2,0,248,22,8,0,0,0,0,0,248,165,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,50,27,0,0,82,29,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,23,8,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,176,23,8,0,0,0,0,0,248,165,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,200,35,0,0,190,35,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,24,8,0,128,25,8,0,0,0,0,0,0,0,0,0,0,38,7,0,240,23,8,0,0,0,0,0,80,89,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,46,21,0,0,62,30,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,25,8,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,16,25,8,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,144,41,0,0,130,14,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,19,8,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,80,19,8,0,0,0,0,0,160,200,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,48,46,0,0,172,29,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,110,5,0,200,112,5,0,0,0,0,0,0,0,0,0,240,3,2,0,144,110,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,158,23,0,0,144,46,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,111,5,0,200,112,5,0,0,0,0,0,0,0,0,0,240,3,2,0,112,111,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,108,49,0,0,216,33,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,27,8,0,192,28,8,0,0,0,0,0,0,0,0,0,32,127,5,0,96,27,8,0,0,0,0,0,48,144,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,170,9,0,0,218,0,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,27,8,0,192,28,8,0,0,0,0,0,0,0,0,0,32,127,5,0,224,27,8,0,0,0,0,0,48,144,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,4,56,0,0,216,5,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,28,8,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,112,28,8,0,0,0,0,0,224,212,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,60,56,0,0,74,38,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,27,8,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,216,26,8,0,0,0,0,0,136,108,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,142,52,0,0,110,17,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,225,7,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,96,221,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,96,16,0,0,56,46,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,29,8,0,152,30,8,0,0,0,0,0,0,0,0,0,144,47,2,0,32,29,8,0,0,0,0,0,240,201,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,194,53,0,0,24,16,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,30,8,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,24,30,8,0,0,0,0,0,232,62,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,150,29,0,0,42,42,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,126,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,48,125,1,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,76,42,0,0,132,8,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,232,7,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,160,228,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,1,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,144,60,0,0,142,4,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,219,5,0,136,220,5,0,0,0,0,0,0,0,0,0,240,3,2,0,152,219,5,0,0,0,0,0,160,88,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,54,16,0,0,66,21,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,33,8,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,64,32,8,0,0,0,0,0,72,246,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,38,57,0,0,148,9,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,34,8,0,144,39,8,0,0,0,0,0,0,0,0,0,0,38,7,0,48,34,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,108,28,0,0,104,28,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,37,8,0,144,39,8,0,0,0,0,0,0,0,0,0,0,38,7,0,112,37,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,2,62,0,0,38,28,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,36,8,0,144,39,8,0,0,0,0,0,0,0,0,0,0,38,7,0,160,35,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,228,7,0,0,134,10,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,37,8,0,144,39,8,0,0,0,0,0,0,0,0,0,0,38,7,0,168,36,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,108,32,0,0,128,21,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,39,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,56,38,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,64,18,0,0,50,38,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,40,8,0,72,247,7,0,0,0,0,0,0,0,0,0,104,221,5,0,0,40,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,204,57,0,0,218,10,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,247,7,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,240,238,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,22,36,0,0,116,33,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,35,8,0,40,30,8,0,0,0,0,0,0,0,0,0,0,38,7,0,8,27,8,0,0,0,0,0,152,22,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,138,5,0,0,252,9,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,30,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,128,43,8,0,0,0,0,0,152,22,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,56,19,0,0,130,35,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,18,8,0,232,15,8,0,0,0,0,0,0,0,0,0,0,38,7,0,128,11,8,0,0,0,0,0,152,22,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,54,3,0,0,112,0,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,15,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,144,42,8,0,0,0,0,0,152,22,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,216,28,0,0,102,24,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,44,8,0,160,45,8,0,0,0,0,0,0,0,0,0,0,38,7,0,200,43,8,0,0,0,0,0,152,22,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,104,54,0,0,110,8,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,45,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,8,45,8,0,0,0,0,0,152,22,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,166,6,0,0,142,6,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,47,8,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,0,46,8,0,0,0,0,0,152,22,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,68,49,0,0,88,12,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,65,8,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,120,65,8,0,0,0,0,0,40,47,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,182,19,0,0,128,28,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,70,8,0,112,70,8,0,0,0,0,0,0,0,0,0,144,47,2,0,240,69,8,0,0,0,0,0,160,51,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,44,33,0,0,170,15,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,70,8,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,56,70,8,0,0,0,0,0,232,62,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,160,36,0,0,16,48,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,66,8,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,112,66,8,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,4,28,0,0,114,19,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,67,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,0,67,8,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,76,62,0,0,16,27,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,68,8,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,168,67,8,0,0,0,0,0,152,67,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,14,53,0,0,250,32,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,69,8,0,128,69,8,0,0,0,0,0,0,0,0,0,104,221,5,0,216,68,8,0,0,0,0,0,72,122,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,86,40,0,0,94,19,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,69,8,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,32,69,8,0,0,0,0,0,232,62,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,128,60,0,0,26,43,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,84,8,0,80,85,8,0,0,0,0,0,0,0,0,0,0,38,7,0,0,84,8,0,0,0,0,0,48,144,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,208,17,0,0,108,3,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,82,8,0,96,83,8,0,0,0,0,0,0,0,0,0,168,163,7,0,160,81,8,0,0,0,0,0,48,144,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,152,1,0,0,6,28,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,83,8,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,208,82,8,0,0,0,0,0,224,212,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,156,47,0,0,126,30,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,85,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,8,85,8,0,0,0,0,0,224,212,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,76,22,0,0,42,30,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,70,8,0,184,71,8,0,0,0,0,0,0,0,0,0,32,127,5,0,128,70,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,70,48,0,0,66,32,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,71,8,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,72,71,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,228,45,0,0,62,13,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,80,8,0,224,80,8,0,0,0,0,0,0,0,0,0,240,3,2,0,24,80,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,228,40,0,0,40,17,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,73,8,0,240,79,8,0,0,0,0,0,0,0,0,0,0,38,7,0,224,71,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,148,46,0,0,110,12,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,75,8,0,240,79,8,0,0,0,0,0,0,0,0,0,0,38,7,0,224,74,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,184,56,0,0,26,29,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,76,8,0,240,79,8,0,0,0,0,0,0,0,0,0,0,38,7,0,224,75,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,62,60,0,0,42,29,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,77,8,0,240,79,8,0,0,0,0,0,0,0,0,0,0,38,7,0,24,77,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,18,38,0,0,94,20,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,79,8,0,240,79,8,0,0,0,0,0,0,0,0,0,0,38,7,0,216,77,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,106,55,0,0,32,44,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,75,8,0,240,79,8,0,0,0,0,0,0,0,0,0,0,38,7,0,80,75,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,142,62,0,0,194,22,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,79,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,200,79,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,176,27,0,0,76,29,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,80,8,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,136,80,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,20,22,0,0,82,16,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,88,8,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,184,87,8,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,26,36,0,0,12,34,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,167,3,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,160,167,3,0,0,0,0,0,104,167,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,35,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,188,50,0,0,140,8,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,86,8,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,96,86,8,0,0,0,0,0,232,62,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,56,48,0,0,220,7,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,92,8,0,16,93,8,0,0,0,0,0,0,0,0,0,96,135,2,0,200,91,8,0,0,0,0,0,80,89,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,232,28,0,0,66,27,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,93,8,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,152,92,8,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,24,34,0,0,106,43,0,0,0,0,0,0])
.concat([0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,138,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,48,138,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,160,46,0,0,200,16,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,104,8,0,248,105,8,0,0,0,0,0,0,0,0,0,104,221,5,0,8,104,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,168,31,0,0,232,26,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,105,8,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,56,105,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,92,46,0,0,106,8,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,107,8,0,80,109,8,0,0,0,0,0,0,0,0,0,144,47,2,0,72,107,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,80,25,0,0,250,45,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,109,8,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,168,108,8,0,0,0,0,0,224,109,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,170,24,0,0,126,14,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,110,8,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,80,110,8,0,0,0,0,0,224,109,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,84,26,0,0,138,1,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,114,8,0,176,115,8,0,0,0,0,0,0,0,0,0,240,3,2,0,120,113,8,0,0,0,0,0,224,212,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,234,46,0,0,176,36,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,115,8,0,176,115,8,0,0,0,0,0,0,0,0,0,240,3,2,0,144,114,8,0,0,0,0,0,224,212,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,6,46,0,0,220,22,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,115,8,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,80,115,8,0,0,0,0,0,224,212,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,62,32,0,0,28,44,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,146,3,0,72,117,8,0,0,0,0,0,0,0,0,0,0,46,3,0,56,146,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,62,52,0,0,238,20,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,117,8,0,0,0,0,0,0,0,0,0,0,0,0,0,192,177,6,0,48,116,8,0,0,0,0,0,168,66,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,28,41,0,0,174,10,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,186,8,0,144,187,8,0,0,0,0,0,0,0,0,0,240,3,2,0,248,185,8,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,98,55,0,0,218,30,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,187,8,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,72,187,8,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,206,54,0,0,210,43,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,125,8,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,96,125,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,6,9,0,0,138,31,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,126,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,240,125,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,36,49,0,0,242,20,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,211,8,0,224,212,8,0,0,0,0,0,0,0,0,0,96,135,2,0,216,210,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,180,59,0,0,140,6,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,212,8,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,64,212,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,228,1,0,0,146,28,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,136,8,0,24,137,8,0,0,0,0,0,0,0,0,0,240,3,2,0,24,135,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,192,7,0,0,170,12,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,134,8,0,24,137,8,0,0,0,0,0,0,0,0,0,240,3,2,0,144,133,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,224,18,0,0,198,47,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,137,8,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,232,136,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,80,16,0,0,200,39,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,118,4,0,112,118,4,0,0,0,0,0,0,0,0,0,96,135,2,0,248,117,4,0,0,0,0,0,80,89,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,76,52,0,0,4,28,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,92,5,0,152,92,5,0,0,0,0,0,0,0,0,0,240,3,2,0,240,91,5,0,0,0,0,0,80,89,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,76,5,0,0,154,43,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,131,8,0,40,132,8,0,0,0,0,0,0,0,0,0,0,38,7,0,128,131,8,0,0,0,0,0,48,143,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,118,22,0,0,30,16,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,132,8,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,248,131,8,0,0,0,0,0,224,212,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,228,47,0,0,208,24,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,118,8,0,232,121,8,0,0,0,0,0,0,0,0,0,240,3,2,0,16,118,8,0,0,0,0,0,160,200,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,130,48,0,0,218,31,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,121,8,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,224,119,8,0,0,0,0,0,160,200,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,136,38,0,0,134,12,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,17,2,0,24,19,2,0,0,0,0,0,0,0,0,0,240,3,2,0,248,16,2,0,0,0,0,0,152,22,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,158,48,0,0,254,19,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,19,2,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,120,18,2,0,0,0,0,0,152,22,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,136,5,0,0,186,13,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,142,8,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,8,142,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,6,7,0,0,122,12,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,142,8,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,120,142,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,14,28,0,0,66,25,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,145,8,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,232,144,8,0,0,0,0,0,48,144,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,190,58,0,0,14,42,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,132,8,0,24,137,8,0,0,0,0,0,0,0,0,0,0,46,3,0,56,132,8,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,190,17,0,0,136,27,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,148,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,96,148,8,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,116,27,0,0,116,11,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,130,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,112,130,3,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,12,8,0,0,244,10,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,150,8,0,248,151,8,0,0,0,0,0,0,0,0,0,144,47,2,0,24,149,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,218,14,0,0,240,0,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,151,8,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,72,151,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,240,41,0,0,114,18,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,122,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,160,122,8,0,0,0,0,0,64,246,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,146,52,0,0,238,24,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,153,8,0,32,155,8,0,0,0,0,0,0,0,0,0,104,221,5,0,136,152,8,0,0,0,0,0,72,187,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,240,60,0,0,24,43,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,154,8,0,32,155,8,0,0,0,0,0,0,0,0,0,104,221,5,0,208,153,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,128,22,0,0,160,47,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,155,8,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,176,154,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,130,55,0,0,124,12,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,157,8,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,184,156,8,0,0,0,0,0,200,155,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,78,21,0,0,100,9,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,124,6,0,8,125,6,0,0,0,0,0,0,0,0,0,144,47,2,0,240,123,6,0,0,0,0,0,144,110,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,16,18,0,0,190,37,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,125,6,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,160,124,6,0,0,0,0,0,144,110,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,6,20,0,0,20,2,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,159,8,0,0,0,0,0,0,0,0,0,0,0,0,0,168,163,7,0,168,157,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,68,44,0,0,16,19,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,170,8,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,208,169,8,0,0,0,0,0,80,168,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,96,61,0,0,140,19,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,172,8,0,112,173,8,0,0,0,0,0,0,0,0,0,144,47,2,0,240,170,8,0,0,0,0,0,160,51,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,28,38,0,0,236,41,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,173,8,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,200,172,8,0,0,0,0,0,232,62,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,106,42,0,0,86,14,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,164,8,0,48,167,8,0,0,0,0,0,0,0,0,0,240,3,2,0,40,164,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,158,60,0,0,114,45,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,163,8,0,48,167,8,0,0,0,0,0,0,0,0,0,240,3,2,0,16,163,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,140,42,0,0,112,30,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,162,8,0,48,167,8,0,0,0,0,0,0,0,0,0,240,3,2,0,208,161,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,252,16,0,0,186,26,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,167,8,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,32,166,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,26,7,0,0,72,0,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,174,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,0,174,8,0,0,0,0,0,224,212,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,144,29,0,0,204,31,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,82,7,0,224,82,7,0,0,0,0,0,0,0,0,0,0,46,3,0,48,82,7,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,74,32,0,0,70,35,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,176,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,208,175,8,0,0,0,0,0,120,175,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,140,48,0,0,224,26,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,177,8,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,72,177,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,192,9,0,0,156,12,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,179,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,224,177,8,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,64,31,0,0,80,40,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,130,3,0,160,2,8,0,0,0,0,0,0,0,0,0,0,46,3,0,216,130,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,194,40,0,0,150,22,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,97,8,0,200,102,8,0,0,0,0,0,0,0,0,0,0,38,7,0,32,96,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,94,6,0,0,42,13,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,95,8,0,200,102,8,0,0,0,0,0,0,0,0,0,0,38,7,0,208,94,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,190,52,0,0,208,2,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,94,8,0,200,102,8,0,0,0,0,0,0,0,0,0,0,38,7,0,136,93,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,6,55,0,0,180,42,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,100,8,0,200,102,8,0,0,0,0,0,0,0,0,0,0,38,7,0,176,99,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,22,48,0,0,226,41,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,101,8,0,200,102,8,0,0,0,0,0,0,0,0,0,0,38,7,0,72,100,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,184,46,0,0,134,9,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,102,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,112,102,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,74,36,0,0,108,30,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,123,8,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,72,123,8,0,0,0,0,0,160,200,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,198,48,0,0,58,13,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,122,8,0,248,123,8,0,0,0,0,0,0,0,0,0,240,3,2,0,96,122,8,0,0,0,0,0,72,122,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,32,29,0,0,180,12,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,185,8,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,48,184,8,0,0,0,0,0,8,13,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,30,56,0,0,158,38,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,196,8,0,72,197,8,0,0,0,0,0,0,0,0,0,0,38,7,0,24,196,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,196,56,0,0,12,5,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,194,8,0,72,197,8,0,0,0,0,0,0,0,0,0,0,38,7,0,0,194,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,62,11,0,0,232,25,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,193,8,0,72,197,8,0,0,0,0,0,0,0,0,0,0,38,7,0,24,193,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,86,37,0,0,168,15,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,192,8,0,72,197,8,0,0,0,0,0,0,0,0,0,0,38,7,0,176,192,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,150,40,0,0,214,30,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,192,8,0,72,197,8,0,0,0,0,0,0,0,0,0,0,38,7,0,160,191,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,58,42,0,0,66,22,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0])
.concat([226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,191,8,0,72,197,8,0,0,0,0,0,0,0,0,0,0,38,7,0,232,190,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,10,18,0,0,96,31,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,189,8,0,72,197,8,0,0,0,0,0,0,0,0,0,0,38,7,0,88,189,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,38,2,0,0,30,43,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,188,8,0,72,197,8,0,0,0,0,0,0,0,0,0,0,38,7,0,8,188,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,112,30,0,0,242,1,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,187,8,0,72,197,8,0,0,0,0,0,0,0,0,0,0,38,7,0,176,187,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,140,0,0,0,236,40,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,197,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,232,196,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,102,32,0,0,212,24,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,197,8,0,192,198,8,0,0,0,0,0,0,0,0,0,32,127,5,0,136,197,8,0,0,0,0,0,48,143,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,72,36,0,0,250,29,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,198,8,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,208,197,8,0,0,0,0,0,48,143,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,28,39,0,0,192,32,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,131,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,8,131,3,0,0,0,0,0,80,131,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,86,46,0,0,96,37,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,199,8,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,48,199,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,192,59,0,0,182,9,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,202,8,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,216,201,8,0,0,0,0,0,8,116,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,58,27,0,0,140,14,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,201,8,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,80,201,8,0,0,0,0,0,168,200,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,98,61,0,0,84,28,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,131,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,128,131,3,0,0,0,0,0,80,131,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,224,12,0,0,144,2,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,203,8,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,96,203,8,0,0,0,0,0,72,187,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,116,31,0,0,166,4,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,112,8,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,144,111,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,244,7,0,0,154,4,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,112,7,0,232,114,7,0,0,0,0,0,0,0,0,0,0,38,7,0,64,112,7,0,0,0,0,0,168,95,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,76,45,0,0,206,8,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,137,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,96,137,8,0,0,0,0,0,128,223,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,14,43,0,0,110,28,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,138,8,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,184,137,8,0,0,0,0,0,40,47,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,170,53,0,0,240,43,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,140,8,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,224,139,8,0,0,0,0,0,24,215,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,2,6,0,0,228,24,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,141,8,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,168,141,8,0,0,0,0,0,144,110,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,126,50,0,0,124,4,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,122,7,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,248,121,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,130,24,0,0,136,19,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,128,8,0,208,130,8,0,0,0,0,0,0,0,0,0,0,38,7,0,88,126,8,0,0,0,0,0,64,129,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,136,57,0,0,238,21,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,130,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,120,129,8,0,0,0,0,0,64,129,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,244,2,0,0,194,8,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,205,8,0,32,206,8,0,0,0,0,0,0,0,0,0,0,38,7,0,96,204,8,0,0,0,0,0,8,116,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,180,42,0,0,198,21,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,206,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,248,205,8,0,0,0,0,0,8,116,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,234,36,0,0,114,5,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,208,8,0,240,209,8,0,0,0,0,0,0,0,0,0,240,3,2,0,144,207,8,0,0,0,0,0,160,200,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,26,59,0,0,142,14,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,209,8,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,216,208,8,0,0,0,0,0,160,200,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,150,47,0,0,212,39,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,206,8,0,40,207,8,0,0,0,0,0,0,0,0,0,0,46,3,0,120,206,8,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,238,47,0,0,178,22,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,207,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,216,206,8,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,128,40,0,0,34,27,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,216,8,0,24,220,8,0,0,0,0,0,0,0,0,0,240,3,2,0,200,215,8,0,0,0,0,0,0,193,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,26,47,0,0,12,14,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,218,8,0,24,220,8,0,0,0,0,0,0,0,0,0,240,3,2,0,192,217,8,0,0,0,0,0,0,193,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,218,32,0,0,26,36,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,220,8,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,152,219,8,0,0,0,0,0,0,193,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,200,0,0,0,238,0,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,221,8,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,152,220,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,246,53,0,0,10,29,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,222,8,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,32,222,8,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,26,16,0,0,14,25,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,65,5,0,24,66,5,0,0,0,0,0,0,0,0,0,104,221,5,0,144,65,5,0,0,0,0,0,64,246,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,74,57,0,0,244,6,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,225,8,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,8,223,8,0,0,0,0,0,176,67,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,34,2,0,0,96,6,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,175,7,0,40,16,2,0,0,0,0,0,0,0,0,0,184,168,7,0,176,175,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,148,28,0,0,228,9,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,62,4,0,216,62,4,0,0,0,0,0,0,0,0,0,96,135,2,0,208,61,4,0,0,0,0,0,160,88,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,132,57,0,0,218,9,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,60,4,0,24,61,4,0,0,0,0,0,0,0,0,0,0,38,7,0,104,60,4,0,0,0,0,0,160,88,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,194,39,0,0,84,39,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,228,8,0,144,230,8,0,0,0,0,0,0,0,0,0,0,46,3,0,88,228,8,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,96,19,0,0,170,21,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,230,8,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,104,229,8,0,0,0,0,0,72,174,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,14,45,0,0,14,15,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,232,8,0,144,233,8,0,0,0,0,0,0,0,0,0,0,38,7,0,240,230,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,44,18,0,0,218,43,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,233,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,120,232,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,140,19,0,0,52,5,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,235,8,0,72,236,8,0,0,0,0,0,0,0,0,0,240,3,2,0,136,234,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,178,58,0,0,134,13,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,236,8,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,160,235,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,196,41,0,0,166,42,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,18,1,0,160,19,1,0,0,0,0,0,0,0,0,0,96,135,2,0,112,17,1,0,0,0,0,0,72,246,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,48,54,0,0,182,20,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,237,8,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,232,236,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,152,58,0,0,128,34,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,182,1,0,152,186,1,0,0,0,0,0,0,0,0,0,0,38,7,0,232,181,1,0,0,0,0,0,168,95,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,32,2,0,0,88,26,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,184,1,0,152,186,1,0,0,0,0,0,0,0,0,0,0,38,7,0,136,183,1,0,0,0,0,0,168,95,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,166,52,0,0,58,11,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,186,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,216,185,1,0,0,0,0,0,168,95,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,226,20,0,0,164,6,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,239,8,0,216,240,8,0,0,0,0,0,0,0,0,0,32,127,5,0,64,238,8,0,0,0,0,0,48,143,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,66,36,0,0,0,1,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,240,8,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,16,240,8,0,0,0,0,0,48,143,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,172,53,0,0,74,40,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,242,8,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,96,241,8,0,0,0,0,0,24,21,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,84,63,0,0,140,30,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,244,8,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,8,243,8,0,0,0,0,0,112,242,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,112,45,0,0,206,41,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,132,3,0,224,240,6,0,0,0,0,0,0,0,0,0,0,46,3,0,80,132,3,0,0,0,0,0,40,132,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,76,34,0,0,48,38,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,249,8,0,216,3,1,0,0,0,0,0,0,0,0,0,0,38,7,0,224,247,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,232,39,0,0,188,27,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,246,8,0,216,3,1,0,0,0,0,0,0,0,0,0,0,38,7,0,16,246,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,192,41,0,0,88,36,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,244,8,0,216,3,1,0,0,0,0,0,0,0,0,0,0,38,7,0,128,244,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,100,51,0,0,106,2,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,255,8,0,216,3,1,0,0,0,0,0,0,0,0,0,0,38,7,0,88,255,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,66,39,0,0,254,31,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,254,8,0,216,3,1,0,0,0,0,0,0,0,0,0,0,38,7,0,200,253,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,196,4,0,0,214,34,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,253,8,0,216,3,1,0,0,0,0,0,0,0,0,0,0,38,7,0,64,252,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,102,23,0,0,44,33,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,251,8,0,216,3,1,0,0,0,0,0,0,0,0,0,0,38,7,0,120,251,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,138,7,0,0,170,3,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,251,8,0,216,3,1,0,0,0,0,0,0,0,0,0,0,38,7,0,32,251,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,42,25,0,0,210,12,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,250,8,0,216,3,1,0,0,0,0,0,0,0,0,0,0,38,7,0,96,250,8,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,186,27,0,0,134,7,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,3,1,0,216,3,1,0,0,0,0,0,0,0,0,0,0,38,7,0,240,2,1,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,126,32,0,0,206,9,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,2,1,0,216,3,1,0,0,0,0,0,0,0,0,0,0,38,7,0,96,2,1,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,54,19,0,0,244,30,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,1,1,0,216,3,1,0,0,0,0,0,0,0,0,0,0,38,7,0,240,0,1,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,160,52,0,0,174,41,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,0,1,0,216,3,1,0,0,0,0,0,0,0,0,0,0,38,7,0,152,255,0,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,6,0,0,0,32,10,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,254,0,0,216,3,1,0,0,0,0,0,0,0,0,0,0,38,7,0,128,254,0,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,78,46,0,0,12,48,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,254,0,0,216,3,1,0,0,0,0,0,0,0,0,0,0,38,7,0,192,253,0,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,84,48,0,0,180,39,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,3,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,128,3,1,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,196,29,0,0,26,41,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,96,2,0,200,101,2,0,0,0,0,0,0,0,0,0,96,135,2,0,144,95,2,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,60,62,0,0,230,37,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0])
.concat([104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,8,5,0,200,205,8,0,0,0,0,0,0,0,0,0,0,38,7,0,152,8,5,0,0,0,0,0,64,32,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,172,60,0,0,86,29,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,7,1,0,144,8,1,0,0,0,0,0,0,0,0,0,240,3,2,0,32,6,1,0,0,0,0,0,80,89,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,112,14,0,0,216,32,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,8,1,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,96,8,1,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,76,10,0,0,238,27,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,66,4,0,224,67,4,0,0,0,0,0,0,0,0,0,96,135,2,0,96,66,4,0,0,0,0,0,0,193,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,96,48,0,0,158,14,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,13,1,0,72,15,1,0,0,0,0,0,0,0,0,0,144,47,2,0,96,13,1,0,0,0,0,0,8,13,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,92,1,0,0,166,39,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,14,1,0,72,15,1,0,0,0,0,0,0,0,0,0,104,221,5,0,24,14,1,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,240,61,0,0,220,23,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,15,1,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,128,14,1,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,48,30,0,0,52,8,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,12,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,200,11,1,0,0,0,0,0,32,11,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,246,26,0,0,72,14,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,104,7,0,88,4,8,0,0,0,0,0,0,0,0,0,240,3,2,0,192,103,7,0,0,0,0,0,40,47,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,148,51,0,0,224,31,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,4,8,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,136,254,7,0,0,0,0,0,40,47,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,166,51,0,0,180,36,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,132,3,0,40,178,3,0,0,0,0,0,0,0,0,0,0,46,3,0,240,131,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,200,26,0,0,210,37,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,172,1,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,176,170,1,0,0,0,0,0,128,223,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,62,48,0,0,166,29,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,16,1,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,248,15,1,0,0,0,0,0,168,178,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,78,7,0,0,218,14,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,19,1,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,0,19,1,0,0,0,0,0,72,246,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,48,8,0,0,72,8,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,22,1,0,80,29,1,0,0,0,0,0,0,0,0,0,0,38,7,0,136,20,1,0,0,0,0,0,72,246,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,194,3,0,0,244,27,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,23,1,0,80,29,1,0,0,0,0,0,0,0,0,0,0,38,7,0,192,22,1,0,0,0,0,0,72,246,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,56,41,0,0,226,22,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,26,1,0,80,29,1,0,0,0,0,0,0,0,0,0,0,38,7,0,24,25,1,0,0,0,0,0,72,246,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,80,33,0,0,240,26,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,29,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,80,28,1,0,0,0,0,0,72,246,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,50,37,0,0,84,37,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,132,5,0,128,134,5,0,0,0,0,0,0,0,0,0,0,38,7,0,8,132,5,0,0,0,0,0,168,95,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,106,20,0,0,228,34,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,133,5,0,128,134,5,0,0,0,0,0,0,0,0,0,0,38,7,0,216,132,5,0,0,0,0,0,168,95,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,150,20,0,0,158,33,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,31,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,184,30,1,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,116,24,0,0,236,26,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,132,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,216,132,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,20,9,0,0,46,6,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,132,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,152,132,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,208,57,0,0,254,16,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,41,1,0,168,58,1,0,0,0,0,0,0,0,0,0,32,127,5,0,48,40,1,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,22,53,0,0,40,31,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,39,1,0,168,58,1,0,0,0,0,0,0,0,0,0,32,127,5,0,120,39,1,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,118,23,0,0,140,28,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,51,1,0,168,58,1,0,0,0,0,0,0,0,0,0,32,127,5,0,40,51,1,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,30,62,0,0,44,6,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,50,1,0,168,58,1,0,0,0,0,0,0,0,0,0,32,127,5,0,248,49,1,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,92,16,0,0,164,37,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,49,1,0,168,58,1,0,0,0,0,0,0,0,0,0,32,127,5,0,16,49,1,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,62,28,0,0,94,26,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,48,1,0,168,58,1,0,0,0,0,0,0,0,0,0,32,127,5,0,56,47,1,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,30,59,0,0,230,6,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,46,1,0,168,58,1,0,0,0,0,0,0,0,0,0,32,127,5,0,64,45,1,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,20,25,0,0,34,31,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,44,1,0,168,58,1,0,0,0,0,0,0,0,0,0,32,127,5,0,104,43,1,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,46,46,0,0,52,17,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,42,1,0,168,58,1,0,0,0,0,0,0,0,0,0,32,127,5,0,160,41,1,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,18,47,0,0,38,8,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,54,1,0,168,58,1,0,0,0,0,0,0,0,0,0,32,127,5,0,240,53,1,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,168,30,0,0,224,12,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,32,1,0,168,58,1,0,0,0,0,0,0,0,0,0,32,127,5,0,200,31,1,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,214,22,0,0,90,1,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,33,1,0,168,58,1,0,0,0,0,0,0,0,0,0,32,127,5,0,176,32,1,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,162,25,0,0,126,19,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,36,1,0,168,58,1,0,0,0,0,0,0,0,0,0,32,127,5,0,128,34,1,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,8,4,0,0,154,41,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,57,1,0,168,58,1,0,0,0,0,0,0,0,0,0,32,127,5,0,216,56,1,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,162,28,0,0,184,3,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,39,1,0,168,58,1,0,0,0,0,0,0,0,0,0,32,127,5,0,112,37,1,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,206,15,0,0,14,14,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,56,1,0,168,58,1,0,0,0,0,0,0,0,0,0,32,127,5,0,56,55,1,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,6,33,0,0,174,23,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,58,1,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,200,57,1,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,174,56,0,0,188,47,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,60,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,40,60,1,0,0,0,0,0,192,181,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,66,9,0,0,4,0,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,62,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,40,62,1,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,2,31,0,0,196,4,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,63,1,0,192,64,1,0,0,0,0,0,0,0,0,0,240,3,2,0,120,63,1,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,224,31,0,0,206,27,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,64,1,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,128,64,1,0,0,0,0,0,232,246,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,234,35,0,0,24,47,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,65,1,0,192,66,1,0,0,0,0,0,0,0,0,0,104,221,5,0,248,64,1,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,248,5,0,0,160,11,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,66,1,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,48,66,1,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,78,57,0,0,2,8,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,68,1,0,0,0,0,0,0,0,0,0,0,0,0,0,168,163,7,0,96,67,1,0,0,0,0,0,48,143,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,13,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,140,8,0,0,244,46,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,96,1,0,240,97,1,0,0,0,0,0,0,0,0,0,0,38,7,0,208,94,1,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,72,38,0,0,246,12,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,94,1,0,240,97,1,0,0,0,0,0,0,0,0,0,0,38,7,0,72,93,1,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,134,46,0,0,52,1,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,92,1,0,240,97,1,0,0,0,0,0,0,0,0,0,0,38,7,0,184,91,1,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,220,16,0,0,18,6,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,91,1,0,240,97,1,0,0,0,0,0,0,0,0,0,0,38,7,0,192,90,1,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,0,60,0,0,190,46,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,78,1,0,240,97,1,0,0,0,0,0,0,0,0,0,0,38,7,0,184,76,1,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,104,48,0,0,114,41,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,76,1,0,240,97,1,0,0,0,0,0,0,0,0,0,0,38,7,0,80,76,1,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,230,0,0,0,34,37,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,76,1,0,240,97,1,0,0,0,0,0,0,0,0,0,0,38,7,0,128,75,1,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,194,37,0,0,22,26,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,75,1,0,240,97,1,0,0,0,0,0,0,0,0,0,0,38,7,0,72,74,1,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,34,26,0,0,112,38,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,72,1,0,240,97,1,0,0,0,0,0,0,0,0,0,0,38,7,0,232,71,1,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,254,4,0,0,170,47,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,71,1,0,240,97,1,0,0,0,0,0,0,0,0,0,0,38,7,0,96,70,1,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,240,11,0,0,70,15,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,70,1,0,240,97,1,0,0,0,0,0,0,0,0,0,0,38,7,0,184,69,1,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,64,15,0,0,226,28,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,90,1,0,240,97,1,0,0,0,0,0,0,0,0,0,0,38,7,0,192,89,1,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,164,61,0,0,184,12,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,89,1,0,240,97,1,0,0,0,0,0,0,0,0,0,0,38,7,0,144,88,1,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,4,50,0,0,92,4,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,87,1,0,240,97,1,0,0,0,0,0,0,0,0,0,0,38,7,0,40,87,1,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,184,24,0,0,70,33,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,86,1,0,240,97,1,0,0,0,0,0,0,0,0,0,0,38,7,0,64,85,1,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,68,33,0,0,80,43,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,84,1,0,240,97,1,0,0,0,0,0,0,0,0,0,0,38,7,0,112,84,1,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,118,25,0,0,34,0,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,84,1,0,240,97,1,0,0,0,0,0,0,0,0,0,0,38,7,0,128,83,1,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,202,36,0,0,10,41,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,82,1,0,240,97,1,0,0,0,0,0,0,0,0,0,0,38,7,0,96,81,1,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,220,33,0,0,194,4,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,80,1,0,240,97,1,0,0,0,0,0,0,0,0,0,0,38,7,0,72,79,1,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,166,0,0,0,86,45,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,69,1,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,192,68,1,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,8,39,0,0,118,46,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,97,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,192,96,1,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,66,26,0,0,148,34,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,99,1,0,0,0,0,0,0,0,0,0,0,0,0,0,168,163,7,0,208,98,1,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,18,31,0,0,162,45,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,101,1,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,216,100,1,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,218,19,0,0,26,10,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,104,1,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,112,103,1,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,194,45,0,0,76,45,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0])
.concat([4,0,0,0,3,0,0,0,80,108,1,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,136,107,1,0,0,0,0,0,224,105,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,162,36,0,0,118,9,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,110,1,0,80,115,1,0,0,0,0,0,0,0,0,0,240,3,2,0,56,109,1,0,0,0,0,0,152,22,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,156,39,0,0,248,33,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,111,1,0,80,115,1,0,0,0,0,0,0,0,0,0,240,3,2,0,184,110,1,0,0,0,0,0,152,22,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,86,28,0,0,46,28,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,115,1,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,8,114,1,0,0,0,0,0,152,22,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,184,59,0,0,14,0,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,118,1,0,240,121,1,0,0,0,0,0,0,0,0,0,0,38,7,0,232,116,1,0,0,0,0,0,232,27,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,250,16,0,0,220,28,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,121,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,240,120,1,0,0,0,0,0,232,27,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,114,52,0,0,78,14,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,123,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,152,122,1,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,82,55,0,0,124,9,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,170,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,104,168,1,0,0,0,0,0,16,167,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,166,3,0,0,246,16,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,129,1,0,0,138,1,0,0,0,0,0,0,0,0,0,240,3,2,0,224,127,1,0,0,0,0,0,72,246,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,104,24,0,0,212,7,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,132,1,0,0,138,1,0,0,0,0,0,0,0,0,0,240,3,2,0,176,130,1,0,0,0,0,0,72,246,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,138,40,0,0,244,5,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,135,1,0,0,138,1,0,0,0,0,0,0,0,0,0,0,38,7,0,56,134,1,0,0,0,0,0,72,246,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,112,26,0,0,84,42,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,138,1,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,184,136,1,0,0,0,0,0,40,3,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,194,9,0,0,66,34,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,140,1,0,240,142,1,0,0,0,0,0,0,0,0,0,96,135,2,0,224,138,1,0,0,0,0,0,72,246,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,176,9,0,0,118,24,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,142,1,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,136,141,1,0,0,0,0,0,72,246,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,144,24,0,0,30,21,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,151,3,0,224,168,3,0,0,0,0,0,0,0,0,0,0,46,3,0,56,151,3,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,166,26,0,0,198,42,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,168,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,96,168,3,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,29,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,78,49,0,0,192,3,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,144,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,208,143,1,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,148,58,0,0,160,36,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,146,1,0,112,148,1,0,0,0,0,0,0,0,0,0,96,135,2,0,216,145,1,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,192,10,0,0,194,45,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,148,1,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,24,147,1,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,146,3,0,0,22,35,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,153,1,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,8,151,1,0,0,0,0,0,224,212,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,158,58,0,0,252,40,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,149,1,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,208,148,1,0,0,0,0,0,176,67,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,30,26,0,0,120,23,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,156,1,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,232,154,1,0,0,0,0,0,72,187,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,202,60,0,0,108,7,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,158,1,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,208,157,1,0,0,0,0,0,72,187,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,202,19,0,0,230,28,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,133,3,0,240,134,3,0,0,0,0,0,0,0,0,0,0,46,3,0,104,133,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,238,0,0,0,236,35,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,134,3,0,240,134,3,0,0,0,0,0,0,0,0,0,192,177,6,0,40,134,3,0,0,0,0,0,152,134,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,168,37,0,0,212,44,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,134,3,0,0,0,0,0,0,0,0,0,0,0,0,0,192,177,6,0,168,134,3,0,0,0,0,0,152,134,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,114,0,0,0,42,45,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,187,3,0,56,200,3,0,0,0,0,0,0,0,0,0,96,135,2,0,80,184,3,0,0,0,0,0,0,193,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,118,7,0,0,172,45,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,159,1,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,24,159,1,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,216,6,0,0,94,27,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,20,2,0,16,24,2,0,0,0,0,0,0,0,0,0,240,3,2,0,192,19,2,0,0,0,0,0,96,19,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,10,42,0,0,142,43,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,161,1,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,208,160,1,0,0,0,0,0,64,246,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,122,59,0,0,152,34,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,166,1,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,80,166,1,0,0,0,0,0,248,165,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,84,20,0,0,242,25,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,163,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,224,161,1,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,38,50,0,0,64,22,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,177,1,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,112,176,1,0,0,0,0,0,40,47,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,212,29,0,0,102,21,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,173,1,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,208,172,1,0,0,0,0,0,216,208,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,82,21,0,0,96,5,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,175,1,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,120,174,1,0,0,0,0,0,56,206,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,208,3,0,0,160,4,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,179,1,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,112,178,1,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,0,34,0,0,232,4,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,202,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,192,201,1,0,0,0,0,0,224,212,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,28,40,0,0,62,4,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,180,1,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,232,179,1,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,84,10,0,0,32,39,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,187,1,0,192,188,1,0,0,0,0,0,0,0,0,0,104,221,5,0,64,187,1,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,246,34,0,0,138,20,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,188,1,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,112,188,1,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,26,35,0,0,118,14,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,104,3,0,88,172,1,0,0,0,0,0,0,0,0,0,0,46,3,0,16,104,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,94,63,0,0,214,3,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,104,3,0,32,141,4,0,0,0,0,0,0,0,0,0,0,46,3,0,48,104,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,54,56,0,0,212,22,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,25,4,0,48,26,4,0,0,0,0,0,0,0,0,0,0,46,3,0,120,24,4,0,0,0,0,0,168,66,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,72,40,0,0,182,5,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,26,4,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,208,25,4,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,190,20,0,0,136,45,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,23,4,0,80,24,4,0,0,0,0,0,0,0,0,0,0,46,3,0,8,23,4,0,0,0,0,0,168,66,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,128,1,0,0,188,3,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,24,4,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,232,23,4,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,140,31,0,0,130,2,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,190,1,0,248,191,1,0,0,0,0,0,0,0,0,0,240,3,2,0,72,189,1,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,202,53,0,0,160,28,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,191,1,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,56,191,1,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,32,54,0,0,216,7,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,193,1,0,48,193,1,0,0,0,0,0,0,0,0,0,0,38,7,0,0,193,1,0,0,0,0,0,0,193,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,120,46,0,0,88,44,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,195,1,0,40,199,1,0,0,0,0,0,0,0,0,0,96,135,2,0,96,194,1,0,0,0,0,0,0,193,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,168,8,0,0,66,4,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,196,1,0,40,199,1,0,0,0,0,0,0,0,0,0,96,135,2,0,240,195,1,0,0,0,0,0,0,193,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,250,30,0,0,88,24,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,199,1,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,192,197,1,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,122,16,0,0,124,27,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,210,1,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,120,209,1,0,0,0,0,0,216,208,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,144,13,0,0,42,6,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,205,1,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,176,203,1,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,38,27,0,0,104,40,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,207,1,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,240,206,1,0,0,0,0,0,56,206,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,158,54,0,0,60,35,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,217,1,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,40,215,1,0,0,0,0,0,224,212,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,94,61,0,0,38,34,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,30,4,0,72,31,4,0,0,0,0,0,0,0,0,0,96,135,2,0,248,29,4,0,0,0,0,0,112,242,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,186,13,0,0,66,15,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,32,4,0,112,32,4,0,0,0,0,0,0,0,0,0,144,47,2,0,152,31,4,0,0,0,0,0,112,242,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,26,14,0,0,42,18,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,220,1,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,24,220,1,0,0,0,0,0,64,246,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,252,3,0,0,198,2,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,222,1,0,56,229,1,0,0,0,0,0,0,0,0,0,104,221,5,0,24,221,1,0,0,0,0,0,248,39,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,26,1,0,0,148,19,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,226,1,0,56,229,1,0,0,0,0,0,0,0,0,0,104,221,5,0,136,223,1,0,0,0,0,0,176,67,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,236,57,0,0,124,0,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,229,1,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,8,228,1,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,250,17,0,0,136,30,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,46,6,0,152,232,1,0,0,0,0,0,0,0,0,0,240,3,2,0,136,45,6,0,0,0,0,0,80,89,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,210,27,0,0,238,26,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,232,1,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,16,231,1,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,48,31,0,0,84,11,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,47,6,0,48,234,1,0,0,0,0,0,0,0,0,0,240,3,2,0,136,46,6,0,0,0,0,0,80,89,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,104,0,0,0,136,33,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,48,6,0,48,234,1,0,0,0,0,0,0,0,0,0,240,3,2,0,224,47,6,0,0,0,0,0,80,89,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,124,2,0,0,208,23,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,234,1,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,112,233,1,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,90,43,0,0,136,25,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,169,3,0,176,169,3,0,0,0,0,0,0,0,0,0,0,46,3,0,0,169,3,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,136,27,0,0,228,45,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,169,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,144,169,3,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,31,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,196,51,0,0,122,42,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,235,1,0,0,152,7,0,0,0,0,0,0,0,0,0,168,163,7,0,208,234,1,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,176,31,0,0,192,12,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,152,7,0,0,0,0,0,0,0,0,0,0,0,0,0,168,163,7,0,160,146,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,166,11,0,0,210,42,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,237,1,0,232,240,1,0])
.concat([0,0,0,0,0,0,0,0,104,221,5,0,104,236,1,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,68,7,0,0,82,47,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,240,1,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,176,239,1,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,102,22,0,0,112,16,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,243,1,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,200,241,1,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,122,18,0,0,12,17,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,244,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,168,243,1,0,0,0,0,0,192,181,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,88,3,0,0,48,0,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,245,1,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,224,244,1,0,0,0,0,0,192,181,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,116,15,0,0,144,12,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,246,1,0,120,251,1,0,0,0,0,0,0,0,0,0,0,38,7,0,224,245,1,0,0,0,0,0,8,116,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,226,5,0,0,16,35,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,251,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,216,249,1,0,0,0,0,0,8,116,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,134,51,0,0,238,44,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,0,2,0,224,3,2,0,0,0,0,0,0,0,0,0,240,3,2,0,88,255,1,0,0,0,0,0,40,3,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,102,20,0,0,178,20,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,2,2,0,224,3,2,0,0,0,0,0,0,0,0,0,0,38,7,0,184,1,2,0,0,0,0,0,40,3,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,106,32,0,0,106,35,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,120,3,2,0,0,0,0,0,40,3,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,4,36,0,0,76,5,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,226,2,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,240,224,2,0,0,0,0,0,128,223,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,108,29,0,0,148,14,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,221,2,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,240,218,2,0,0,0,0,0,128,223,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,66,54,0,0,104,42,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,250,2,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,168,249,2,0,0,0,0,0,232,246,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,180,62,0,0,16,46,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,72,4,0,96,72,4,0,0,0,0,0,0,0,0,0,96,135,2,0,240,71,4,0,0,0,0,0,232,246,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,16,8,0,0,136,18,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,233,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,216,230,2,0,0,0,0,0,96,229,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,58,26,0,0,6,27,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,115,4,0,152,115,4,0,0,0,0,0,0,0,0,0,0,46,3,0,80,115,4,0,0,0,0,0,24,115,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,78,14,0,0,194,32,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,5,2,0,112,7,2,0,0,0,0,0,0,0,0,0,0,38,7,0,216,4,2,0,0,0,0,0,216,121,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,190,14,0,0,238,19,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,7,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,104,6,2,0,0,0,0,0,216,121,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,100,17,0,0,204,18,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,10,2,0,216,13,2,0,0,0,0,0,0,0,0,0,32,127,5,0,72,10,2,0,0,0,0,0,168,178,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,178,28,0,0,154,1,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,13,2,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,152,11,2,0,0,0,0,0,168,178,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,130,41,0,0,212,33,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,8,2,0,8,10,2,0,0,0,0,0,0,0,0,0,168,163,7,0,16,8,2,0,0,0,0,0,168,178,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,6,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,166,25,0,0,182,2,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,10,2,0,0,0,0,0,0,0,0,0,0,0,0,0,168,163,7,0,144,9,2,0,0,0,0,0,168,178,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,6,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,130,18,0,0,134,46,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,16,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,152,14,2,0,0,0,0,0,192,181,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,94,54,0,0,94,40,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,24,2,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,24,23,2,0,0,0,0,0,16,123,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,174,27,0,0,28,38,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,174,1,0,104,175,1,0,0,0,0,0,0,0,0,0,240,3,2,0,200,173,1,0,0,0,0,0,40,52,7,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,90,18,0,0,130,0,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,27,2,0,128,29,2,0,0,0,0,0,0,0,0,0,0,38,7,0,32,26,2,0,0,0,0,0,232,27,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,188,62,0,0,154,18,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,29,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,152,28,2,0,0,0,0,0,232,27,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,196,43,0,0,148,8,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,39,2,0,160,40,2,0,0,0,0,0,0,0,0,0,0,38,7,0,232,38,2,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,208,19,0,0,58,3,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,38,2,0,160,40,2,0,0,0,0,0,0,0,0,0,0,38,7,0,24,37,2,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,242,51,0,0,32,11,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,35,2,0,160,40,2,0,0,0,0,0,0,0,0,0,0,38,7,0,24,34,2,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,100,1,0,0,134,37,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,33,2,0,160,40,2,0,0,0,0,0,0,0,0,0,0,38,7,0,144,31,2,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,64,39,0,0,182,43,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,30,2,0,160,40,2,0,0,0,0,0,0,0,0,0,0,38,7,0,208,29,2,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,22,55,0,0,152,43,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,40,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,240,39,2,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,38,53,0,0,36,30,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,149,3,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,160,149,3,0,0,0,0,0,96,149,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,182,9,0,0,76,28,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,135,3,0,0,0,0,0,0,0,0,0,0,0,0,0,16,63,6,0,144,135,3,0,0,0,0,0,40,135,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,164,37,0,0,40,21,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,59,2,0,240,70,2,0,0,0,0,0,0,0,0,0,0,38,7,0,104,57,2,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,142,17,0,0,126,3,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,63,2,0,240,70,2,0,0,0,0,0,0,0,0,0,0,38,7,0,248,60,2,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,166,8,0,0,18,28,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,54,2,0,240,70,2,0,0,0,0,0,0,0,0,0,0,38,7,0,128,53,2,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,90,56,0,0,2,46,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,52,2,0,240,70,2,0,0,0,0,0,0,0,0,0,0,38,7,0,72,50,2,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,34,56,0,0,216,43,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,65,2,0,240,70,2,0,0,0,0,0,0,0,0,0,0,38,7,0,248,64,2,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,42,20,0,0,210,24,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,68,2,0,240,70,2,0,0,0,0,0,0,0,0,0,0,38,7,0,96,67,2,0,0,0,0,0,168,66,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,110,2,0,0,8,11,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,70,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,64,69,2,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,10,49,0,0,170,7,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,98,3,0,112,103,3,0,0,0,0,0,0,0,0,0,240,3,2,0,184,96,3,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,224,25,0,0,158,37,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,103,3,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,80,101,3,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,224,15,0,0,248,14,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,44,2,0,0,49,2,0,0,0,0,0,0,0,0,0,144,47,2,0,120,42,2,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,176,11,0,0,178,43,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,46,2,0,0,49,2,0,0,0,0,0,0,0,0,0,144,47,2,0,200,45,2,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,16,40,0,0,76,31,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,49,2,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,192,47,2,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,54,5,0,0,102,5,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,88,2,0,120,91,2,0,0,0,0,0,0,0,0,0,240,3,2,0,200,83,2,0,0,0,0,0,8,116,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,98,49,0,0,208,15,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,91,2,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,112,89,2,0,0,0,0,0,8,116,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,194,19,0,0,210,29,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,75,2,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,248,73,2,0,0,0,0,0,136,72,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,50,60,0,0,122,17,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,77,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,8,77,2,0,0,0,0,0,48,143,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,190,48,0,0,200,32,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,79,2,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,168,78,2,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,114,32,0,0,44,7,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,82,2,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,152,80,2,0,0,0,0,0,48,143,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,54,50,0,0,188,30,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,94,2,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,200,92,2,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,250,36,0,0,56,45,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,167,4,0,72,180,4,0,0,0,0,0,0,0,0,0,0,38,7,0,32,167,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,56,50,0,0,208,37,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,168,4,0,72,180,4,0,0,0,0,0,0,0,0,0,0,38,7,0,248,167,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,20,27,0,0,10,39,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,181,4,0,232,181,4,0,0,0,0,0,0,0,0,0,96,135,2,0,176,180,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,238,12,0,0,92,22,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,98,2,0,200,101,2,0,0,0,0,0,0,0,0,0,96,135,2,0,160,97,2,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,112,56,0,0,146,30,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,101,2,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,168,99,2,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,54,26,0,0,104,45,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,104,2,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,208,103,2,0,0,0,0,0,216,102,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,112,29,0,0,196,25,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,107,2,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,72,107,2,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,242,55,0,0,62,11,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,106,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,112,105,2,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,40,30,0,0,152,27,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,210,7,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,120,209,7,0,0,0,0,0,48,143,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,13,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,158,33,0,0,42,10,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,113,2,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,112,110,2,0,0,0,0,0,136,108,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,122,26,0,0,56,14,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,117,2,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,152,114,2,0,0,0,0,0,192,181,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,88,45,0,0,142,12,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,186,4,0,40,91,8,0,0,0,0,0,0,0,0,0,0,38,7,0,40,186,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,96,31,0,0,6,35,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,185,4,0,40,91,8,0,0,0,0,0,0,0,0,0,32,127,5,0,0,185,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,254,17,0,0,250,43,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,122,2,0,64,128,2,0,0,0,0,0,0,0,0,0,240,3,2,0,208,121,2,0,0,0,0,0,16,123,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,164,7,0,0,70,32,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,128,2,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,104,124,2,0,0,0,0,0,16,123,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,22,11,0,0,250,9,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,145,2,0,56,182,2,0,0,0,0,0,0,0,0,0,0,38,7,0,200,144,2,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,4,42,0,0,172,4,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,179,2,0,56,182,2,0,0,0,0,0,0,0,0,0,0,38,7,0,176,176,2,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,170,7,0,0,170,2,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,175,2,0,56,182,2,0,0,0,0,0,0,0,0,0,0,38,7,0,40,174,2,0])
.concat([0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,90,41,0,0,196,8,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,144,2,0,56,182,2,0,0,0,0,0,0,0,0,0,0,38,7,0,88,143,2,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,86,15,0,0,66,42,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,141,2,0,56,182,2,0,0,0,0,0,0,0,0,0,0,38,7,0,168,140,2,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,74,16,0,0,198,41,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,139,2,0,56,182,2,0,0,0,0,0,0,0,0,0,0,38,7,0,216,136,2,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,170,8,0,0,146,25,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,135,2,0,56,182,2,0,0,0,0,0,0,0,0,0,0,38,7,0,200,134,2,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,184,60,0,0,224,45,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,134,2,0,56,182,2,0,0,0,0,0,0,0,0,0,0,38,7,0,88,133,2,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,234,13,0,0,206,38,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,132,2,0,56,182,2,0,0,0,0,0,0,0,0,0,0,38,7,0,0,132,2,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,240,42,0,0,220,18,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,130,2,0,56,182,2,0,0,0,0,0,0,0,0,0,0,38,7,0,144,129,2,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,24,57,0,0,166,9,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,150,2,0,56,182,2,0,0,0,0,0,0,0,0,0,0,38,7,0,8,149,2,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,86,39,0,0,150,42,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,147,2,0,56,182,2,0,0,0,0,0,0,0,0,0,0,38,7,0,96,146,2,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,202,21,0,0,26,6,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,158,2,0,56,182,2,0,0,0,0,0,0,0,0,0,0,38,7,0,0,158,2,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,58,58,0,0,16,17,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,156,2,0,56,182,2,0,0,0,0,0,0,0,0,0,0,38,7,0,208,155,2,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,66,53,0,0,14,32,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,154,2,0,56,182,2,0,0,0,0,0,0,0,0,0,0,38,7,0,136,152,2,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,52,54,0,0,42,23,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,173,2,0,56,182,2,0,0,0,0,0,0,0,0,0,0,38,7,0,200,172,2,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,202,37,0,0,252,27,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,171,2,0,56,182,2,0,0,0,0,0,0,0,0,0,0,38,7,0,96,170,2,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,162,17,0,0,130,41,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,169,2,0,56,182,2,0,0,0,0,0,0,0,0,0,0,38,7,0,192,166,2,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,230,22,0,0,40,4,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,164,2,0,56,182,2,0,0,0,0,0,0,0,0,0,0,38,7,0,0,162,2,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,74,35,0,0,244,40,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,160,2,0,56,182,2,0,0,0,0,0,0,0,0,0,0,38,7,0,88,159,2,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,150,2,0,0,226,21,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,182,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,240,180,2,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,104,56,0,0,48,44,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,136,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,32,136,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,176,8,0,0,6,9,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,185,2,0,200,191,2,0,0,0,0,0,0,0,0,0,0,38,7,0,80,183,2,0,0,0,0,0,48,55,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,240,31,0,0,188,38,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,188,2,0,200,191,2,0,0,0,0,0,0,0,0,0,0,38,7,0,120,186,2,0,0,0,0,0,48,55,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,140,14,0,0,102,13,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,191,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,32,190,2,0,0,0,0,0,48,55,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,170,54,0,0,194,24,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,195,2,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,216,193,2,0,0,0,0,0,8,116,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,92,53,0,0,216,15,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,200,2,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,176,198,2,0,0,0,0,0,8,116,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,42,5,0,0,22,11,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,205,2,0,72,208,2,0,0,0,0,0,0,0,0,0,144,47,2,0,104,204,2,0,0,0,0,0,240,201,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,64,6,0,0,110,14,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,208,2,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,224,206,2,0,0,0,0,0,232,62,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,202,5,0,0,202,24,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,49,5,0,88,50,5,0,0,0,0,0,0,0,0,0,96,135,2,0,0,49,5,0,0,0,0,0,16,96,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,184,27,0,0,248,21,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,216,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,16,212,2,0,0,0,0,0,0,210,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,2,18,0,0,204,5,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,48,5,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,176,46,5,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,60,55,0,0,214,16,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,50,5,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,200,49,5,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,56,37,0,0,246,42,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,253,2,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,144,251,2,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,84,7,0,0,86,21,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,244,2,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,64,242,2,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,140,33,0,0,38,42,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,238,2,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,168,236,2,0,0,0,0,0,184,198,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,234,40,0,0,208,13,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,13,3,0,80,104,2,0,0,0,0,0,0,0,0,0,104,221,5,0,192,9,3,0,0,0,0,0,8,116,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,194,30,0,0,96,17,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,34,7,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,184,31,7,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,96,38,0,0,146,44,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,7,3,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,240,4,3,0,0,0,0,0,8,116,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,80,5,0,0,40,43,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,15,3,0,80,104,2,0,0,0,0,0,0,0,0,0,104,221,5,0,224,14,3,0,0,0,0,0,8,116,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,84,61,0,0,176,6,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,2,3,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,128,255,2,0,0,0,0,0,48,143,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,168,5,0,0,102,11,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,104,2,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,216,91,2,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,34,17,0,0,54,31,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,168,163,7,0,72,19,3,0,0,0,0,0,48,18,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,240,22,0,0,198,40,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,31,3,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,64,29,3,0,0,0,0,0,56,24,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,68,13,0,0,48,27,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,37,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,168,34,3,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,204,17,0,0,136,47,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,21,5,0,160,21,5,0,0,0,0,0,0,0,0,0,96,135,2,0,192,20,5,0,0,0,0,0,40,47,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,166,40,0,0,118,40,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,21,5,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,64,21,5,0,0,0,0,0,40,47,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,86,1,0,0,80,3,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,20,5,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,24,20,5,0,0,0,0,0,40,47,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,242,0,0,0,128,40,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,40,3,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,216,38,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,224,16,0,0,174,37,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,42,3,0,40,47,3,0,0,0,0,0,0,0,0,0,32,127,5,0,120,41,3,0,0,0,0,0,192,181,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,106,27,0,0,92,26,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,47,3,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,192,44,3,0,0,0,0,0,192,181,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,214,25,0,0,200,24,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,51,3,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,16,49,3,0,0,0,0,0,192,181,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,174,19,0,0,28,0,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,56,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,72,54,3,0,0,0,0,0,104,58,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,88,32,0,0,72,22,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,59,3,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,32,59,3,0,0,0,0,0,104,58,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,226,62,0,0,104,4,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,61,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,40,61,3,0,0,0,0,0,192,181,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,124,11,0,0,22,17,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,65,3,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,128,63,3,0,0,0,0,0,248,39,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,160,59,0,0,252,17,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,68,3,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,224,66,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,164,28,0,0,178,17,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,183,8,0,32,185,8,0,0,0,0,0,0,0,0,0,96,135,2,0,200,179,8,0,0,0,0,0,96,179,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,86,63,0,0,108,4,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,70,3,0,168,73,3,0,0,0,0,0,0,0,0,0,144,47,2,0,120,69,3,0,0,0,0,0,184,198,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,20,19,0,0,30,1,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,73,3,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,200,72,3,0,0,0,0,0,24,72,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,208,9,0,0,154,24,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,76,3,0,0,81,3,0,0,0,0,0,0,0,0,0,0,46,3,0,72,74,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,110,51,0,0,0,9,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,80,79,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,12,40,0,0,196,6,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,84,3,0,64,88,3,0,0,0,0,0,0,0,0,0,0,46,3,0,232,82,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,108,24,0,0,232,41,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,86,3,0,64,88,3,0,0,0,0,0,0,0,0,0,0,46,3,0,40,85,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,0,15,0,0,24,44,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,88,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,248,86,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,2,35,0,0,162,32,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,119,3,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,192,116,3,0,0,0,0,0,104,113,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,204,48,0,0,86,17,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,124,3,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,176,121,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,168,39,0,0,206,18,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,128,3,0,8,132,3,0,0,0,0,0,0,0,0,0,240,3,2,0,88,126,3,0,0,0,0,0,160,200,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,68,60,0,0,210,0,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,132,3,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,88,130,3,0,0,0,0,0,160,200,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,152,2,0,0,226,7,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,137,3,0,128,61,7,0,0,0,0,0,0,0,0,0,0,46,3,0,64,137,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,246,10,0,0,170,42,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,136,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,232,133,3,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,102,58,0,0,6,0,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,143,3,0,24,182,3,0,0,0,0,0,0,0,0,0,0,38,7,0,8,140,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,132,13,0,0,226,47,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,153,3,0,24,182,3,0,0,0,0,0,0,0,0,0,0,38,7,0,104,151,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,218,45,0,0,48,13,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,162,3,0,24,182,3,0,0,0,0,0,0,0,0,0,0,38,7,0,176,158,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,234,39,0,0,150,11,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,157,3,0,24,182,3,0,0,0,0,0,0,0,0,0,0,38,7,0,128,155,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,200,46,0,0,114,33,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,177,3,0,24,182,3,0,0,0,0,0,0,0,0,0,0,38,7,0,40,175,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,144,38,0,0,178,38,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,173,3,0,24,182,3,0,0,0,0,0,0,0,0,0,0,38,7,0,240,170,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,180,40,0,0,88,21,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,168,3,0,24,182,3,0,0,0,0,0,0,0,0,0,0,38,7,0,56,165,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,26,32,0,0,106,22,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,149,3,0,24,182,3,0,0,0,0,0,0,0,0,0,0,38,7,0,80,146,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,102,17,0,0,204,23,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,182,3,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,160,179,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,154,31,0,0,228,6,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,194,3,0,56,200,3,0,0,0,0,0,0,0,0,0,96,135,2,0,216,190,3,0,0,0,0,0,0,193,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,132,30,0,0,160,1,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,200,3,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,72,197,3,0,0,0,0,0,0,193,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,246,16,0,0,142,26,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,204,3,0,24,212,3,0,0,0,0,0,0,0,0,0,104,221,5,0,160,202,3,0,0,0,0,0,64,207,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,166,28,0,0,182,4,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,212,3,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,184,209,3,0,0,0,0,0,64,207,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,52,48,0,0,154,25,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,171,4,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,104,167,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,138,45,0,0,34,10,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,225,3,0,64,234,3,0,0,0,0,0,0,0,0,0,32,127,5,0,192,220,3,0,0,0,0,0,40,161,4,0,32,20,3,0,112,215,3,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,76,37,0,0,222,34,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,234,3,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,216,231,3,0,0,0,0,0,40,161,4,0,32,20,3,0,24,228,3,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,240,1,0,0,42,47,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,242,3,0,120,253,3,0,0,0,0,0,0,0,0,0,0,38,7,0,232,239,3,0,0,0,0,0,40,161,4,0,32,20,3,0,40,237,3,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,46,53,0,0,186,6,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,253,3,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,136,249,3,0,0,0,0,0,40,161,4,0,32,20,3,0,80,245,3,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,88,39,0,0,226,26,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,138,3,0,200,122,8,0,0,0,0,0,0,0,0,0,0,46,3,0,0,138,3,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,126,56,0,0,210,38,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,95,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,160,95,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,84,49,0,0,108,45,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,182,2,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,104,169,2,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,80,15,0,0,216,27,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,27,4,0,176,33,4,0,0,0,0,0,0,0,0,0,104,221,5,0,24,24,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,26,5,0,0,248,22,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,33,4,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,48,31,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,86,0,0,0,184,17,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,43,4,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,32,41,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,76,54,0,0,110,37,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,48,4,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,0,45,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,132,32,0,0,20,15,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,77,6,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,120,72,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,122,23,0,0,50,44,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,59,4,0,240,67,4,0,0,0,0,0,0,0,0,0,144,47,2,0,168,55,4,0,0,0,0,0,160,51,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,54,44,0,0,196,18,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,67,4,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,8,65,4,0,0,0,0,0,232,62,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,192,46,0,0,156,14,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,71,4,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,232,69,4,0,0,0,0,0,40,47,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,152,49,0,0,68,7,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,21,4,0,0,144,6,0,0,0,0,0,0,0,0,0,168,163,7,0,144,20,4,0,0,0,0,0,80,235,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,116,33,0,0,16,29,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,144,6,0,0,0,0,0,0,0,0,0,0,0,0,0,168,163,7,0,176,143,6,0,0,0,0,0,248,88,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,78,26,0,0,252,39,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,221,2,0,0,0,0,0,0,0,0,0,0,0,0,0,168,163,7,0,56,201,2,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,88,31,0,0,184,20,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,101,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,168,100,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,240,27,0,0,234,33,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,75,4,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,136,73,4,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,16,24,0,0,134,44,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,85,4,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,184,82,4,0,0,0,0,0,88,78,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,32,50,0,0,116,4,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,12,4,0,48,21,4,0,0,0,0,0,0,0,0,0,0,38,7,0,200,9,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,180,16,0,0,198,25,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,17,4,0,48,21,4,0,0,0,0,0,0,0,0,0,0,38,7,0,240,14,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,98,45,0,0,192,23,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,21,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,184,18,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,226,35,0,0,112,37,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,36,3,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,112,11,3,0,0,0,0,0,72,246,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,64,49,0,0,84,46,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,100,4,0,144,108,4,0,0,0,0,0,0,0,0,0,0,38,7,0,56,98,4,0,0,0,0,0,168,95,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,102,62,0,0,52,35,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,108,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,24,105,4,0,0,0,0,0,168,95,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,28,59,0,0,66,9,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,200,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,136,200,6,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,106,15,0,0,140,10,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,126,4,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,152,123,4,0,0,0,0,0,216,121,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,208,21,0,0,176,43,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,214,8,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,168,213,8,0,0,0,0,0,24,125,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,18,45,0,0,26,17,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,149,4,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,152,146,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,102,39,0,0,42,12,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,153,4,0,8,123,3,0,0,0,0,0,0,0,0,0,96,135,2,0,112,151,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,84,50,0,0,28,36,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,162,4,0,8,123,3,0,0,0,0,0,0,0,0,0,96,135,2,0,144,158,4,0,0,0,0,0,80,156,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,246,42,0,0,58,32,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,123,3,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,240,99,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,250,19,0,0,164,45,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,178,4,0,232,182,4,0,0,0,0,0,0,0,0,0,32,127,5,0,0,175,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,176,25,0,0,150,8,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,182,4,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,216,180,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,76,13,0,0,218,15,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,190,4,0,216,208,4,0,0,0,0,0,0,0,0,0,240,3,2,0,232,187,4,0,0,0,0,0,184,198,4,0,32,20,3,0,24,185,4,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,232,17,0,0,158,0,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,208,4,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,32,205,4,0,0,0,0,0,184,198,4,0,32,20,3,0,56,194,4,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,146,22,0,0,182,30,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,215,4,0,208,198,3,0,0,0,0,0,0,0,0,0,184,168,7,0,88,212,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,148,24,0,0,184,18,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,222,4,0,208,198,3,0,0,0,0,0,0,0,0,0,104,221,5,0,104,219,4,0,0,0,0,0,232,217,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,72,18,0,0,140,47,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,230,4,0,208,198,3,0,0,0,0,0,0,0,0,0,184,168,7,0,88,226,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,204,49,0,0,78,38,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,239,4,0,208,198,3,0,0,0,0,0,0,0,0,0,104,221,5,0,128,235,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,226,25,0,0,4,7,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,198,3,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,216,147,3,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,232,36,0,0,8,10,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,253,4,0,216,17,5,0,0,0,0,0,0,0,0,0,240,3,2,0,104,250,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,190,21,0,0,198,3,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,3,5,0,216,17,5,0,0,0,0,0,0,0,0,0,240,3,2,0,208,0,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,226,40,0,0,204,39,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,9,5,0,216,17,5,0,0,0,0,0,0,0,0,0,240,3,2,0,128,6,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,80,63,0,0,64,21,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,247,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,168,242,4,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,32,3,0,0,248,3,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,17,5,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,40,14,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,208,24,0,0,170,45,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,181,1,0,152,186,1,0,0,0,0,0,0,0,0,0,0,38,7,0,0,181,1,0,0,0,0,0,168,95,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,190,27,0,0,160,9,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,71,5,0,192,78,5,0,0,0,0,0,0,0,0,0,0,38,7,0,72,67,5,0,0,0,0,0,160,88,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,144,3,0,0,250,10,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,85,5,0,0,93,5,0,0,0,0,0,0,0,0,0,96,135,2,0,48,82,5,0,0,0,0,0,160,88,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,72,44,0,0,170,28,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,26,5,0,152,33,5,0,0,0,0,0,0,0,0,0,104,221,5,0,32,24,5,0,0,0,0,0,24,21,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,56,38,0,0,132,28,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,33,5,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,16,31,5,0,0,0,0,0,216,28,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,98,46,0,0,82,8,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,52,5,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,168,48,5,0,0,0,0,0,72,187,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,180,14,0,0,138,14,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,114,4,0,216,83,3,0,0,0,0,0,0,0,0,0,96,135,2,0,48,111,4,0,0,0,0,0,184,55,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,102,15,0,0,6,7,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,119,4,0,216,83,3,0,0,0,0,0,0,0,0,0,96,135,2,0,232,116,4,0,0,0,0,0,184,55,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,208,44,0,0,44,22,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,83,3,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,200,68,3,0,0,0,0,0,184,55,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,252,47,0,0,64,2,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,107,5,0,176,118,5,0,0,0,0,0,0,0,0,0,240,3,2,0,88,102,5,0,0,0,0,0,8,116,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,220,51,0,0,58,30,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,113,5,0,176,118,5,0,0,0,0,0,0,0,0,0,240,3,2,0,176,110,5,0,0,0,0,0,8,116,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,102,44,0,0,252,26,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,39,5,0,72,52,5,0,0,0,0,0,0,0,0,0,144,47,2,0,24,36,5,0,0,0,0,0,72,187,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0])
.concat([2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,158,46,0,0,212,46,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,78,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,120,75,5,0,0,0,0,0,160,88,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,200,18,0,0,8,3,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,93,5,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,88,91,5,0,0,0,0,0,160,88,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,198,0,0,0,166,10,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,97,5,0,144,49,7,0,0,0,0,0,0,0,0,0,0,38,7,0,160,95,5,0,0,0,0,0,8,116,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,10,27,0,0,172,43,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,49,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,128,43,7,0,0,0,0,0,8,116,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,76,14,0,0,18,12,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,118,5,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,56,116,5,0,0,0,0,0,8,116,8,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,210,18,0,0,184,46,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,123,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,184,120,5,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,48,15,0,0,24,37,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,246,5,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,136,240,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,2,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,74,18,0,0,48,43,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,145,5,0,104,144,4,0,0,0,0,0,0,0,0,0,32,127,5,0,56,142,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,180,29,0,0,42,35,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,237,5,0,104,144,4,0,0,0,0,0,0,0,0,0,32,127,5,0,160,233,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,100,45,0,0,130,21,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,230,5,0,104,144,4,0,0,0,0,0,0,0,0,0,32,127,5,0,72,227,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,6,40,0,0,46,25,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,222,5,0,104,144,4,0,0,0,0,0,0,0,0,0,32,127,5,0,56,218,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,174,51,0,0,150,47,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,214,5,0,104,144,4,0,0,0,0,0,0,0,0,0,32,127,5,0,8,210,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,68,23,0,0,110,33,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,204,5,0,104,144,4,0,0,0,0,0,0,0,0,0,32,127,5,0,208,200,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,244,32,0,0,144,10,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,197,5,0,104,144,4,0,0,0,0,0,0,0,0,0,32,127,5,0,0,194,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,8,37,0,0,162,44,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,190,5,0,104,144,4,0,0,0,0,0,0,0,0,0,32,127,5,0,32,188,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,150,5,0,0,252,36,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,184,5,0,104,144,4,0,0,0,0,0,0,0,0,0,32,127,5,0,184,180,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,190,38,0,0,208,46,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,175,5,0,104,144,4,0,0,0,0,0,0,0,0,0,32,127,5,0,56,170,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,120,4,0,0,72,11,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,164,5,0,104,144,4,0,0,0,0,0,0,0,0,0,32,127,5,0,232,159,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,22,16,0,0,162,37,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,156,5,0,104,144,4,0,0,0,0,0,0,0,0,0,32,127,5,0,144,153,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,250,54,0,0,54,35,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,151,5,0,104,144,4,0,0,0,0,0,0,0,0,0,32,127,5,0,144,147,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,58,11,0,0,90,19,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,144,4,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,72,90,4,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,228,23,0,0,244,12,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,21,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,56,18,6,0,0,0,0,0,32,230,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,210,33,0,0,14,48,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,3,6,0,0,63,8,0,0,0,0,0,0,0,0,0,0,38,7,0,56,254,5,0,0,0,0,0,40,47,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,90,28,0,0,156,41,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,15,6,0,0,63,8,0,0,0,0,0,0,0,0,0,0,38,7,0,16,10,6,0,0,0,0,0,40,47,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,26,18,0,0,20,19,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,63,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,144,56,8,0,0,0,0,0,40,47,2,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,236,5,0,0,140,26,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,28,6,0,32,41,6,0,0,0,0,0,0,0,0,0,240,3,2,0,176,24,6,0,0,0,0,0,80,31,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,14,20,0,0,86,5,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,41,6,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,80,36,6,0,0,0,0,0,80,31,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,202,62,0,0,162,27,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,60,5,0,104,65,5,0,0,0,0,0,0,0,0,0,104,221,5,0,56,58,5,0,0,0,0,0,88,55,5,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,108,60,0,0,174,44,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,65,5,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,40,63,5,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,32,49,0,0,36,31,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,67,6,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,152,63,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,220,50,0,0,58,40,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,51,6,0,176,60,6,0,0,0,0,0,0,0,0,0,32,127,5,0,200,45,6,0,0,0,0,0,48,55,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,42,56,0,0,14,34,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,60,6,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,200,57,6,0,0,0,0,0,48,55,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,180,49,0,0,164,23,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,102,6,0,0,0,0,0,0,0,0,0,0,0,0,0,168,163,7,0,200,97,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,216,52,0,0,148,3,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,93,6,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,56,86,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,166,9,0,0,178,44,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,170,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,216,169,3,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,38,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,50,13,0,0,142,21,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,137,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,240,132,6,0,0,0,0,0,56,127,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,120,39,0,0,238,34,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,111,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,8,108,6,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,146,0,0,0,68,31,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,122,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,128,118,6,0,0,0,0,0,32,115,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,214,17,0,0,236,32,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,199,6,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,48,196,6,0,0,0,0,0,168,178,1,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,84,13,0,0,162,24,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,155,4,0,160,155,4,0,0,0,0,0,0,0,0,0,0,38,7,0,8,155,4,0,0,0,0,0,80,89,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,222,10,0,0,96,15,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,155,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,80,155,4,0,0,0,0,0,24,245,3,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,146,2,0,0,154,8,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,152,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,128,145,6,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,178,22,0,0,224,47,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,158,6,0,160,168,6,0,0,0,0,0,0,0,0,0,144,47,2,0,56,156,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,168,17,0,0,104,14,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,168,6,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,192,162,6,0,0,0,0,0,40,161,4,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,254,42,0,0,72,18,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,192,6,0,0,0,0,0,0,0,0,0,0,0,0,0,192,177,6,0,208,180,6,0,0,0,0,0,64,175,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,198,51,0,0,172,32,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,170,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,32,170,3,0,0,0,0,0,152,141,6,0,32,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,38,0,0,12,0,0,1,0,0,0,0,0,196,53,0,0,210,1,0,0,32,27,0,0,0,0,0,0,0,0,0,0,218,49,0,0,96,5,0,0,200,8,0,0,226,3,0,0,178,0,0,0,0,0,0,0,224,62,0,0,104,123,145,0,0,1,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,175,8,0,24,116,1,0,0,0,0,0,0,0,0,0,216,194,1,0,200,167,8,0,0,0,0,0,192,154,4,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,15,0,1,0,0,0,0,0,0,0,0,0,0,206,28,0,0,24,5,0,0,0,0,0,0,0,0,0,0,76,35,0,0,72,35,0,0,22,16,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,184,83,2,0,224,177,4,0,0,0,0,0,0,0,0,0,0,38,7,0,32,226,1,0,0,0,0,0,152,230,4,0,136,153,3,0,48,127,1,0,0,0,0,0,0,0,0,0,0,0,0,0,151,0,0,0,2,0,0,0,1,0,0,6,2,0,0,0,0,0,0,0,0,0,0,0,228,41,0,0,198,35,0,0,0,0,0,0,0,0,0,0,124,53,0,0,0,0,0,0,166,15,0,0,118,10,0,0,132,4,0,0,52,14,0,0,90,35,0,0,96,49,216,0,0,128,0,0,240,0,0,0,128,1,0,0,3,0,0,0,4,0,0,0,224,177,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,240,77,6,0,0,0,0,0,152,230,4,0,136,153,3,0,248,235,2,0,0,0,0,0,0,0,0,0,0,0,0,0,135,0,0,0,2,0,0,0,1,0,0,6,2,0,0,0,0,0,0,0,0,0,0,0,188,41,0,0,254,2,0,0,0,0,0,0,0,0,0,0,124,53,0,0,0,0,0,0,166,15,0,0,118,10,0,0,132,4,0,0,52,14,0,0,90,35,0,0,96,49,216,0,0,128,0,0,240,0,0,0,128,1,0,0,3,0,0,0,4,0,0,0,168,83,2,0,168,92,2,0,72,172,6,0,0,0,0,0,56,172,6,0,160,81,2,0,0,0,0,0,192,154,4,0,208,9,3,0,232,79,2,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,32,0,1,133,8,0,0,0,0,1,0,0,0,0,0,0,144,28,0,0,8,44,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,114,16,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,92,2,0,0,0,0,0,72,172,6,0,0,0,0,0,56,172,6,0,16,91,2,0,0,0,0,0,88,89,2,0,208,9,3,0,56,87,2,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,48,1,1,133,8,0,0,0,0,1,0,0,0,0,0,0,152,62,0,0,154,38,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,4,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,183,2,0,0,0,0,0,72,172,6,0,0,0,0,0,32,127,5,0,248,181,2,0,0,0,0,0,232,180,2,0,208,9,3,0,152,178,2,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,0,32,0,0,0,0,0,0,0,0,0,0,86,61,0,0,218,22,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,185,8,0,88,218,8,0,200,240,5,0,0,0,0,0,104,129,6,0,48,176,8,0,0,0,0,0,72,174,3,0,88,0,3,0,136,168,8,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,1,0,0,8,8,0,0,0,0,0,0,0,0,0,0,0,146,58,0,0,170,18,0,0,0,0,0,0,0,0,0,0,104,35,0,0,106,59,0,0,158,18,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,192,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,200,8,0,88,218,8,0,200,240,5,0,0,0,0,0,104,129,6,0,216,194,8,0,0,0,0,0,72,174,3,0,88,0,3,0,240,189,8,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,1,0,0,8,8,0,0,0,0,0,0,0,0,0,0,0,248,52,0,0,42,48,0,0,0,0,0,0,0,0,0,0,104,35,0,0,128,7,0,0,158,18,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,192,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,189,8,0,24,116,1,0,0,0,0,0,0,0,0,0,216,194,1,0,240,184,8,0,0,0,0,0,112,194,8,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,0,15,0,1,0,0,0,0,0,0,0,0,0,0,208,18,0,0,180,10,0,0,0,0,0,0,0,0,0,0,76,35,0,0,194,50,0,0,116,11,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,56,204,8,0,24,116,1,0,0,0,0,0,0,0,0,0,216,194,1,0,128,199,8,0,0,0,0,0,112,194,8,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,0,15,0,1,0,0,0,0,0,0,0,0,0,0,46,22,0,0,164,32,0,0,0,0,0,0,0,0,0,0,76,35,0,0,194,50,0,0,116,11,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,168,38,4,0,0,147,8,0,72,172,6,0,0,0,0,0,104,221,5,0,16,36,4,0,0,0,0,0,208,40,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,133,0,8,0,0,0,0,0,0,0,0,0,0,12,22,0,0,230,7,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,147,8,0,0,0,0,0,72,172,6,0,0,0,0,0,104,221,5,0,24,43,4,0,0,0,0,0,208,40,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,0,8,0,0,0,0,0,0,0,0,0,0,74,7,0,0,196,32,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,90,3,0,0,0,0,0,72,172,6,0,0,0,0,0,184,12,8,0,56,89,3,0,0,0,0,0,176,237,2,0,208,9,3,0,152,87,3,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,0,16,0,0,0,0,0,0,0,0,0,0,2,22,0,0,32,8,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,251,6,0,0,0,0,0,72,172,6,0,0,0,0,0,168,163,7,0,128,96,3,0,0,0,0,0,176,237,2,0,208,9,3,0,48,93,3,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,0,16,0,0,0,0,0,0,0,0,0,0,78,48,0,0,176,37,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,237,1,0,0,0,0,0,72,172,6,0,0,0,0,0,16,63,6,0,48,236,1,0,0,0,0,0,144,81,5,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,0,0,2,0,0,0,0,0,1,5,0,8,0,0,0,0,0,0,0,0,0,0,190,61,0,0,126,2,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,140,4,0,0,0,0,0,0,0,0,0,0,0,0,0,64,164,6,0,48,86,4,0,120,155,4,0,88,31,4,0,120,201,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,150,18,0,0,220,43,0,0,0,0,0,0,0,0,0,0,92,57,0,0,152,12,0,0,174,6,0,0,72,16,0,0,22,17,0,0,242,18,0,0,76,53,0,0,224,132,215,0,0,1,0,0,224,0,0,0,240,0,0,0,3,0,0,0,4,0,0,0,184,155,7,0,0,0,0,0,0,0,0,0,0,0,0,0,64,171,7,0,128,150,7,0,0,0,0,0,40,144,7,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,2,0,0,0,0,0,0,15,0,0,8,0,0,0,0,0,0,0,0,0,16,0,0,0,8,36,0,0,0,0,0,0,0,0,0,0,46,6,0,0,96,34,0,0,222,4,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,8,8,2,0,0,0,0,0,72,172,6,0,0,0,0,0,224,27,2,0,8,7,2,0,120,161,2,0,168,5,2,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,2,0,0,0,0,0,1,5,0,16,0,0,0,0,0,0,0,0,0,0,154,16,0,0,12,6,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,126,6,0,152,197,6,0,72,172,6,0,0,0,0,0,184,12,8,0,200,121,6,0,0,0,0,0,128,145,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,133,8,0,0,0,0,0,0,0,0,0,0,0,18,10,0,0,236,27,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,153,6,0,0,0,0,0,72,172,6,0,0,0,0,0,192,177,6,0,72,14,6,0,0,0,0,0,128,145,4,0,208,9,3,0,160,8,6,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,8,0,0,0,0,0,0,0,0,0,0,0,30,22,0,0,150,38,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,141,6,0,152,197,6,0,72,172,6,0,0,0,0,0,184,12,8,0,200,136,6,0,0,0,0,0,128,145,4,0,168,200,2,0,184,131,6,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,133,8,0,0,0,0,0,0,0,0,0,0,0,106,6,0,0,242,2,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,197,6,0,0,0,0,0,72,172,6,0,0,0,0,0,184,12,8,0,232,148,6,0,0,0,0,0,128,145,4,0,208,9,3,0,168,144,6,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,8,0,0,0,0,0,0,0,0,0,0,0,6,49,0,0,36,26,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,223,2,0,224,226,2,0,72,172,6,0,0,0,0,0,192,177,6,0,192,220,2,0,0,0,0,0,192,154,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,133,2,0,0,0,0,0,0,0,0,0,0,0,168,52,0,0,208,42,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,86,19,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,102,6,0,0,0,0,0,200,240,5,0,0,0,0,0,144,139,6,0,104,96,6,0,144,32,3,0,72,174,3,0,88,0,3,0,0,91,6,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,4,0,0,0,1,0,0,8,4,0,0,0,0,0,0,0,0,0,0,0,174,50,0,0,12,10,0,0,0,0,0,0,0,0,0,0,104,35,0,0,188,9,0,0,202,8,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,192,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,6,5,0,160,126,6,0,200,240,5,0,0,0,0,0,112,177,2,0,232,2,5,0,144,32,3,0,72,174,3,0,88,0,3,0,120,255,4,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,4,0,0,0,1,0,0,8,4,0,0,0,0,0,0,0])
.concat([0,0,0,0,8,6,0,0,12,42,0,0,0,0,0,0,0,0,0,0,104,35,0,0,188,9,0,0,86,9,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,192,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,114,6,0,160,126,6,0,200,240,5,0,0,0,0,0,0,180,6,0,0,111,6,0,144,32,3,0,72,174,3,0,88,0,3,0,8,106,6,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,1,0,0,8,4,0,0,0,0,0,0,0,0,0,0,0,34,52,0,0,70,36,0,0,0,0,0,0,0,0,0,0,104,35,0,0,82,38,0,0,202,8,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,192,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,126,6,0,0,0,0,0,200,240,5,0,0,0,0,0,0,180,6,0,72,121,6,0,144,32,3,0,72,174,3,0,88,0,3,0,72,117,6,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,4,0,0,0,1,0,0,8,4,0,0,0,0,0,0,0,0,0,0,0,68,8,0,0,96,13,0,0,0,0,0,0,0,0,0,0,104,35,0,0,82,38,0,0,202,8,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,192,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,1,8,0,192,177,1,0,200,240,5,0,0,0,0,0,144,139,6,0,176,64,5,0,0,0,0,0,72,174,3,0,88,0,3,0,192,61,5,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,4,0,0,0,1,0,0,8,4,0,0,0,0,0,0,0,0,0,0,0,230,29,0,0,112,31,0,0,0,0,0,0,0,0,0,0,104,35,0,0,82,38,0,0,66,2,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,192,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,53,8,0,192,177,1,0,200,240,5,0,0,0,0,0,144,139,6,0,120,74,5,0,0,0,0,0,72,174,3,0,88,0,3,0,0,70,5,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,4,0,0,0,1,0,0,8,4,0,0,0,0,0,0,0,0,0,0,0,116,28,0,0,76,27,0,0,0,0,0,0,0,0,0,0,104,35,0,0,82,38,0,0,66,2,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,192,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,157,8,0,24,116,1,0,0,0,0,0,0,0,0,0,216,194,1,0,168,151,8,0,0,0,0,0,144,5,1,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,15,0,1,0,0,0,0,0,0,0,0,0,0,20,40,0,0,16,11,0,0,0,0,0,0,0,0,0,0,114,3,0,0,116,42,0,0,242,8,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,168,200,5,0,136,147,6,0,72,172,6,0,0,0,0,0,144,139,6,0,104,197,5,0,0,0,0,0,128,145,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,81,0,0,0,2,0,0,0,0,0,1,133,8,0,0,0,4,0,0,0,0,0,0,0,236,11,0,0,50,43,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,208,5,0,136,147,6,0,72,172,6,0,0,0,0,0,144,139,6,0,120,204,5,0,0,0,0,0,128,145,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,8,0,1,133,8,0,0,0,4,0,0,0,0,0,0,0,198,59,0,0,228,33,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,60,4,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,227,5,0,136,147,6,0,72,172,6,0,0,0,0,0,144,139,6,0,224,221,5,0,0,0,0,0,128,145,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,72,0,1,133,8,0,0,0,4,0,0,0,0,0,0,0,154,6,0,0,78,8,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,130,13,0,0,84,19,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,217,5,0,136,147,6,0,72,172,6,0,0,0,0,0,144,139,6,0,208,213,5,0,0,0,0,0,128,145,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,72,0,1,133,8,0,0,0,4,0,0,0,0,0,0,0,234,47,0,0,58,18,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,130,13,0,0,84,19,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,147,6,0,0,0,0,0,72,172,6,0,0,0,0,0,144,139,6,0,8,230,5,0,0,0,0,0,128,145,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,72,0,1,133,8,0,0,0,4,0,0,0,0,0,0,0,160,42,0,0,172,35,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,130,13,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,9,2,0,240,160,6,0,72,172,6,0,0,0,0,0,224,27,2,0,152,8,2,0,0,0,0,0,144,88,7,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,1,0,0,2,0,0,0,0,0,1,133,8,0,0,0,4,0,0,0,0,0,0,0,36,35,0,0,74,11,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,10,2,0,32,204,6,0,72,172,6,0,0,0,0,0,224,27,2,0,216,9,2,0,0,0,0,0,144,88,7,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,1,0,0,2,0,0,0,0,0,1,133,8,0,0,0,4,0,0,0,0,0,0,0,132,1,0,0,40,12,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,14,2,0,32,204,6,0,72,172,6,0,0,0,0,0,144,33,2,0,136,13,2,0,0,0,0,0,192,154,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,133,8,0,0,0,4,0,0,0,0,0,0,0,234,14,0,0,134,28,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,140,18,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,16,2,0,32,204,6,0,72,172,6,0,0,0,0,0,224,27,2,0,192,15,2,0,0,0,0,0,144,88,7,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,1,0,0,2,0,0,0,0,0,1,133,8,0,0,0,4,0,0,0,0,0,0,0,198,37,0,0,78,36,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,18,2,0,0,47,7,0,72,172,6,0,0,0,0,0,168,163,7,0,168,17,2,0,0,0,0,0,192,154,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,133,8,0,0,0,4,0,0,0,0,0,0,0,232,9,0,0,134,30,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,134,5,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,19,2,0,0,47,7,0,72,172,6,0,0,0,0,0,88,19,2,0,216,18,2,0,0,0,0,0,144,88,7,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,1,0,0,2,0,0,0,0,0,1,133,8,0,0,0,4,0,0,0,0,0,0,0,98,53,0,0,52,30,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,23,2,0,0,47,7,0,72,172,6,0,0,0,0,0,224,27,2,0,104,20,2,0,0,0,0,0,144,88,7,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,1,0,0,2,0,0,0,0,0,1,133,8,0,0,0,4,0,0,0,0,0,0,0,218,5,0,0,180,23,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,226,4,0,112,43,5,0,72,172,6,0,0,0,0,0,0,180,6,0,168,222,4,0,0,0,0,0,192,154,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,133,8,0,0,0,4,0,0,0,0,0,0,0,250,3,0,0,30,24,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,62,16,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,98,4,0,136,101,4,0,72,172,6,0,0,0,0,0,144,33,2,0,104,96,4,0,0,0,0,0,32,215,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,48,3,1,133,8,0,0,0,4,0,0,0,0,0,0,0,146,15,0,0,218,42,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,46,4,0,0,16,11,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,101,4,0,0,0,0,0,72,172,6,0,0,0,0,0,144,33,2,0,216,99,4,0,0,0,0,0,32,215,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,48,3,1,133,8,0,0,0,4,0,0,0,0,0,0,0,158,49,0,0,0,5,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,254,16,0,0,16,11,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,30,5,0,112,43,5,0,72,172,6,0,0,0,0,0,56,172,6,0,152,28,5,0,0,0,0,0,192,154,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,1,1,133,8,0,0,0,4,0,0,0,0,0,0,0,152,11,0,0,220,1,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,252,14,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,43,5,0,0,0,0,0,72,172,6,0,0,0,0,0,56,172,6,0,192,35,5,0,0,0,0,0,56,33,5,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,16,1,1,133,8,0,0,0,4,0,0,0,0,0,0,0,228,53,0,0,24,23,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,200,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,84,5,0,232,92,5,0,72,172,6,0,0,0,0,0,104,129,6,0,200,81,5,0,0,0,0,0,120,88,5,0,168,200,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,16,1,1,133,8,0,0,0,4,0,0,0,0,0,0,0,102,0,0,0,80,1,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,2,10,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,92,5,0,0,0,0,0,72,172,6,0,0,0,0,0,104,129,6,0,8,91,5,0,0,0,0,0,120,88,5,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,16,1,1,133,8,0,0,0,4,0,0,0,0,0,0,0,200,47,0,0,4,13,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,2,10,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,120,5,0,0,125,5,0,72,172,6,0,0,0,0,0,184,230,7,0,96,118,5,0,0,0,0,0,128,145,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,48,1,1,133,8,0,0,0,4,0,0,0,0,0,0,0,128,47,0,0,16,14,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,216,9,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,125,5,0,0,0,0,0,72,172,6,0,0,0,0,0,184,230,7,0,192,122,5,0,0,0,0,0,128,145,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,112,1,1,133,8,0,0,0,4,0,0,0,0,0,0,0,70,26,0,0,158,42,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,184,18,0,0,84,19,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,0,5,0,112,43,5,0,72,172,6,0,0,0,0,0,56,172,6,0,8,253,4,0,0,0,0,0,192,154,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,133,8,0,0,0,4,0,0,0,0,0,0,0,150,46,0,0,120,19,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,16,16,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,239,4,0,112,43,5,0,72,172,6,0,0,0,0,0,0,180,6,0,32,230,4,0,0,0,0,0,192,154,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,133,8,0,0,0,4,0,0,0,0,0,0,0,210,49,0,0,148,1,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,54,8,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,24,2,0,112,43,5,0,72,172,6,0,0,0,0,0,0,180,6,0,208,23,2,0,0,0,0,0,192,154,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,133,8,0,0,0,4,0,0,0,0,0,0,0,0,57,0,0,190,4,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,92,3,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,75,4,0,136,101,4,0,72,172,6,0,0,0,0,0,144,33,2,0,48,73,4,0,0,0,0,0,192,154,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,16,0,1,133,8,0,0,0,4,0,0,0,0,0,0,0,144,23,0,0,238,43,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,124,10,0,0,16,11,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,81,4,0,136,101,4,0,72,172,6,0,0,0,0,0,144,33,2,0,224,77,4,0,0,0,0,0,192,154,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,16,0,1,133,8,0,0,0,4,0,0,0,0,0,0,0,50,7,0,0,58,37,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,156,15,0,0,16,11,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,116,4,0,0,0,0,0,0,0,0,0,0,0,0,0,144,33,2,0,176,113,4,0,192,110,4,0,40,108,4,0,184,104,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,176,3,4,5,8,0,0,0,4,0,0,0,0,0,0,0,110,9,0,0,98,22,0,0,0,0,0,0,0,0,0,0,208,59,0,0,196,26,0,0,212,1,0,0,16,11,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,88,4,0,136,101,4,0,72,172,6,0,0,0,0,0,144,33,2,0,112,85,4,0,0,0,0,0,192,154,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,16,0,1,133,8,0,0,0,4,0,0,0,0,0,0,0,58,36,0,0,154,47,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,156,15,0,0,16,11,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,94,4,0,136,101,4,0,72,172,6,0,0,0,0,0,144,33,2,0,208,91,4,0,0,0,0,0,192,154,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,16,0,1,133,8,0,0,0,4,0,0,0,0,0,0,0,54,9,0,0,186,11,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,26,10,0,0,16,11,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,28,2,0,112,43,5,0,72,172,6,0,0,0,0,0,224,27,2,0,240,26,2,0,0,0,0,0,144,88,7,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,1,0,0,2,0,0,0,0,1,1,133,8,0,0,0,4,0,0,0,0,0,0,0,132,0,0,0,234,31,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,214,15,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,26,5,0,112,43,5,0,72,172,6,0,0,0,0,0,56,172,6,0,216,23,5,0,0,0,0,0,192,154,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,16,1,1,133,8,0,0,0,4,0,0,0,0,0,0,0,10,1,0,0,104,3,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,200,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,29,2,0,112,43,5,0,72,172,6,0,0,0,0,0,56,172,6,0,24,29,2,0,0,0,0,0,192,154,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,16,1,1,133,8,0,0,0,4,0,0,0,0,0,0,0,2,49,0,0,136,42,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,148,17,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,31,2,0,112,43,5,0,72,172,6,0,0,0,0,0,56,172,6,0,56,30,2,0,0,0,0,0,192,154,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,16,1,1,133,8,0,0,0,4,0,0,0,0,0,0,0,106,24,0,0,126,41,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,200,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,20,5,0,112,43,5,0,72,172,6,0,0,0,0,0,56,172,6,0,120,17,5,0,0,0,0,0,192,154,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,16,1,1,133,8,0,0,0,4,0,0,0,0,0,0,0,60,44,0,0,0,26,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,200,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,6,5,0,112,43,5,0,72,172,6,0,0,0,0,0,56,172,6,0,80,3,5,0,0,0,0,0,192,154,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,16,1,1,133,8,0,0,0,4,0,0,0,0,0,0,0,248,50,0,0,126,42,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,172,3,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,12,5,0,112,43,5,0,72,172,6,0,0,0,0,0,56,172,6,0,112,9,5,0,0,0,0,0,192,154,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,16,1,1,133,8,0,0,0,4,0,0,0,0,0,0,0,32,42,0,0,28,5,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,184,8,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,34,2,0,232,92,5,0,72,172,6,0,0,0,0,0,56,172,6,0,40,33,2,0,0,0,0,0,192,154,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,16,1,1,133,8,0,0,0,4,0,0,0,0,0,0,0,100,34,0,0,194,40,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,12,13,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,37,2,0,232,92,5,0,72,172,6,0,0,0,0,0,56,172,6,0,128,35,2,0,0,0,0,0,192,154,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,16,1,1,133,8,0,0,0,4,0,0,0,0,0,0,0,168,62,0,0,88,37,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,218,13,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,250,4,0,112,43,5,0,72,172,6,0,0,0,0,0,16,63,6,0,240,241,4,0,0,0,0,0,192,154,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,133,8,0,0,0,4,0,0,0,0,0,0,0,96,7,0,0,220,21,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,64,19,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,155,5,0,48,240,5,0,0,0,0,0,0,0,0,0,56,172,6,0,8,153,5,0,0,0,0,0,8,190,5,0,216,229,5,0,144,149,5,0,0,0,0,0,0,0,0,0,0,0,0,0,21,1,0,0,4,0,0,0,2,0,0,8,2,0,0,0,0,0,0,0,0,0,0,0,48,34,0,0,202,25,0,0,0,0,0,0,0,0,0,0,104,35,0,0,16,44,0,0,210,15,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,224,0,0,0,192,1,0,0,3,0,0,0,4,0,0,0,120,169,5,0,48,240,5,0,0,0,0,0,0,0,0,0,56,172,6,0,128,163,5,0,0,0,0,0,8,190,5,0,216,229,5,0,176,157,5,0,0,0,0,0,0,0,0,0,0,0,0,0,21,1,0,0,4,0,0,0,2,0,0,8,2,0,0,0,0,0,0,0,0,0,0,0,16,55,0,0,88,1,0,0,0,0,0,0,0,0,0,0,104,35,0,0,16,44,0,0,210,15,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,224,0,0,0,192,1,0,0,3,0,0,0,4,0,0,0,176,183,5,0,48,240,5,0,0,0,0,0,0,0,0,0,56,172,6,0,144,179,5,0,0,0,0,0,8,190,5,0,216,229,5,0,120,173,5,0,0,0,0,0,0,0,0,0,0,0,0,0,21,1,0,0,4,0,0,0,2,0,0,8,2,0,0,0,0,0,0,0,0,0,0,0,62,31,0,0,188,0,0,0,0,0,0,0,0,0,0,0,104,35,0,0,16,44,0,0,210,15,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,224,0,0,0,192,1,0,0,3,0,0,0,4,0,0,0,80,197,5,0,48,240,5,0,0,0,0,0,0,0,0,0,56,172,6,0,88,193,5,0,0,0,0,0,8,190,5,0,216,229,5,0,0,186,5,0,0,0,0,0,0,0,0,0,0,0,0,0,21,1,0,0,4,0,0,0,2,0,0,8,2,0,0,0,0,0,0,0,0,0,0,0,182,24,0,0,98,36,0,0,0,0,0,0,0,0,0,0,104,35,0,0,16,44,0,0,210,15,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,224,0,0,0,192,1,0,0,3,0,0,0,4,0,0,0,240,187,8,0,0,0,0,0,72,172,6,0,0,0,0,0,0,38,7,0,32,110,3,0,0,0,0,0,176,237,2,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,8,0,0,0,0,0,0,0,0,0,0,0,140,58,0,0,64,6,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,235,2,0,0,0,0,0,0,0,0,0,0,0,0,0,232,167,7,0,208,225,1,0,0,0,0,0,152,196,7,0,24,187,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,2,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,114,17,0,0,78,39,0,0,0,0,0,0,0,0,0,0,156,53,0,0,130,31,0,0,236,7,0,0,70,7,0,0,98,6,0,0,184,10,0,0,0,0,0,0,64,175,145,0,8,0,0,0,0,1,0,0,0,2,0,0,3,0,0,0,4,0,0,0,120,165,8,0,184,235,2,0,0,0,0,0,0,0,0,0,232,167,7,0,128,103,8,0,0,0,0,0,88,46,8,0,24,187,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,16,27,0,0,214,17,0,0,0,0,0,0,0,0,0,0,156,53,0,0,130,31,0,0,236,7,0,0,70,7,0,0,98,6,0,0,184,10,0,0,0,0,0,0,64,175,145,0,8,0,0,0,0,1,0,0,0,2,0,0,3,0,0,0,4,0,0,0,0,127,1,0,184,235,2,0,0,0,0,0,0,0,0,0,232,167,7,0,104,42,1,0,0,0,0,0,128,231,8,0,24,187,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,28,45,0,0,212,43,0,0,0,0,0,0,0,0,0,0,156,53,0,0,130,31,0,0,236,7,0,0,70,7,0,0,98,6,0,0,184,10,0,0,0,0,0,0,64,175,145,0,8,0,0,0,0,1,0,0,0,2,0,0,3,0,0,0,4,0,0,0,48,209,7,0,0,0,0,0,72,172,6,0,0,0,0,0,32,127,5,0,40,63,3,0,0,0,0,0,200,196,7,0,208,9,3,0,120,60,3,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,1,0,1,133,8,0,0,0,0,0,0,0,0,0,0,0,108,12,0,0,54,38,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,224,7,0,104,244,7,0,0,0,0,0,0,0,0,0,64,171,7,0,248,219,7,0,0,0,0,0,96,227,7,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,15,0,64,0,0,0,0,0,0,0,0,0,0,160,40,0,0,124,32,0,0,0,0,0,0,0,0,0,0,8,58,0,0,92,10,0,0,42,2,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,104,244,7,0,0,0,0,0,0,0,0,0,0,0,0,0,64,171,7,0,104,231,7,0,0,0,0,0,96,227,7,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,2,0,0,0,0,0,0,15,0,64,0,0,0,0,0,0,0,0,0,0,54,4,0,0,160,41,0,0,0,0,0,0,0,0,0,0,8,58,0,0,86,17,0,0,42,2,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,184,223,3,0,160,203,4,0,0,0,0,0,0,0,0,0,232,167,7,0,208,167,3,0,0,0,0,0,144,88,7,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,15,0,1,0,0,0,0,0,0,0,0,0,0,78,37,0,0,30,39,0,0,0,0,0,0,0,0,0,0,76,35,0,0,154,39,0,0,86,12,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,24,18,5,0,0,0,0,0,0,0,0,0,0,0,0,0,160,234,7,0,80,205,4,0,0,0,0,0,88,171,4,0,120,201,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,88,62,0,0,72,35,0,0,0,0,0,0,0,0,0,0,46,16,0,0,96,52,0,0,222,9,0,0,72,16,0,0,22,17,0,0,242,18,0,0,76,53,0,0,224,132,215,0,0,1,0,0,224,0,0,0,240,0,0,0,3,0,0,0,4,0,0,0,248,76,2,0,72,79,2,0,72,172,6,0,0,0,0,0,104,129,6,0,208,75,2,0,0,0,0,0,200,77,2,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,16,81,1,5,0,0,1,0,0,0,0,0,0,0,0,0,16,15,0,0,42,43,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,150,18,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,79,2,0,0,0,0,0,72,172,6,0,0,0,0,0,104,129,6,0,136,78,2,0,0,0,0,0,200,77,2,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,16,81,1,5,0,0,1,0,0,0,0,0,0,0,0,0,110,24,0,0,92,20,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,150,18,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,197,1,0,0,0,0,0,72,172,6,0,0,0,0,0,0,38,7,0,8,151,3,0,0,0,0,0,168,222,7,0,208,9,3,0,112,145,3,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,64,1,133,0,0,2,0,0,0,0,0,0,0,0,0,192,28,0,0,238,25,0,0,0,0,0,0,0,0,0,0,200,29,0,0,126,48,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,233,1,0,0,64,5,0,0,0,0,0,0,0,0,0,232,167,7,0,16,135,1,0,0,0,0,0,120,248,4,0,120,201,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,88,34,0,0,144,29,0,0,0,0,0,0,0,0,0,0,42,19,0,0,228,26,0,0,36,9,0,0,72,16,0,0,22,17,0,0,242,18,0,0,76,53,0,0,224,132,215,0,0,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,168,247,2,0,0,64,5,0,0,0,0,0,0,0,0,0,232,167,7,0,128,93,2,0,0,0,0,0,120,248,4,0,120,201,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,214,46,0,0,146,13,0,0,0,0,0,0,0,0,0,0,42,19,0,0,114,37,0,0,36,9,0,0,72,16,0,0,22,17,0,0,242,18,0,0,76,53,0,0,224,132,215,0,0,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,0,64,5,0,0,0,0,0,0,0,0,0,0,0,0,0,232,167,7,0,72,104,6,0,0,0,0,0,120,248,4,0,120,201,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,40,52,0,0,200,46,0,0,0,0,0,0,0,0,0,0,42,19,0,0,72,5,0,0,36,9,0,0,72,16,0,0,22,17,0,0,242,18,0,0,76,53,0,0,224,132,215,0,0,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,128,44,2,0,248,8,7,0,72,172,6,0,0,0,0,0,168,163,7,0,24,42,2,0,0,0,0,0,48,236,7,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,81,0,0,0,2,0,0,0,1,0,1,133,1,0,0,0,0,0,0,0,0,0,0,0,146,40,0,0,218,24,0,0,0,0,0,0,0,0,0,0,208,59,0,0,130,16,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,8,7,0,0,0,0,0,72,172,6,0,0,0,0,0,168,163,7,0,152,45,2,0,0,0,0,0,48,236,7,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,65,0,0,0,2,0,0,0,1,0,1,133,1,0,0,0,0,0,0,0,0,0,0,0,196,30,0,0,162,21,0,0,0,0,0,0,0,0,0,0,208,59,0,0,130,16,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,46,6,0,200,137,6,0,0,0,0,0,0,0,0,0,184,168,7,0,32,4,6,0,0,0,0,0,128,145,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,114,29,0,0,78,24,0,0,0,0,0,0,0,0,0,0,42,50,0,0,124,9,0,0,194,1,0,0,62,7,0,0,96,4,0,0,26,8,0,0,134,11,0,0,216,175,145,0,0,8,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,138,5,0,200,137,6,0,0,0,0,0,0,0,0,0,184,168,7,0,16,111,5,0,0,0,0,0,128,145,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,194,2,0,0,84,33,0,0,0,0,0,0,0,0,0,0,42,50,0,0,124,9,0,0,194,1,0,0,62,7,0,0,96,4,0,0,26,8,0,0,134,11,0,0,216,175,145,0,0,8,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,214,5,0,200,137,6,0,0,0,0,0,0,0,0,0,184,168,7,0,56,176,5,0,0,0,0,0,128,145,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,38,36,0,0,12,43,0,0,0,0,0,0,0,0,0,0,42,50,0,0,124,9,0,0,194,1,0,0,62,7,0,0,96,4,0,0,26,8,0,0,134,11,0,0,216,175,145,0,0,8,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,137,6,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,104,93,6,0,0,0,0,0,128,145,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,38,23,0,0,232,23,0,0,0,0,0,0,0,0,0,0,42,50,0,0,124,9,0,0,194,1,0,0,62,7,0,0,96,4,0,0,26,8,0,0,134,11,0,0,216,175,145,0,0,8,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,70,3,0,0,0,0,0,0,0,0,0,0,0,0,0,168,163,7,0,72,22,6,0,0,0,0,0,72,183,4,0,136,153,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,133,0,0,0,2,0,0,0,1,0,0,6,2,0,0,0,0,0,0,0,0,0,0,0,2,14,0,0,252,10,0,0,0,0,0,0,0,0,0,0,64,56,0,0,0,0,0,0,136,17,0,0,108,9,0,0,68,10,0,0,220,0,0,0,18,30,0,0,96,49,216,0,0,128,0,0,240,0,0,0,128,1,0,0,3,0,0,0,4,0,0,0,232,120,4,0,0,0,0,0,0,0,0,0,0,0,0,0,232,233,7,0,112,68,6,0,0,0,0,0,192,223,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,20,0,1,0,0,0,0,0,0,0,0,0,0,14,63,0,0,12,25,0,0,0,0,0,0])
.concat([0,0,0,0,56,51,0,0,202,22,0,0,132,19,0,0,192,11,0,0,160,13,0,0,82,18,0,0,254,8,0,0,8,175,145,0,128,1,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,212,5,0,160,203,4,0,0,0,0,0,0,0,0,0,216,194,1,0,136,172,5,0,0,0,0,0,144,88,7,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,15,0,1,0,0,0,0,0,0,0,0,0,0,168,46,0,0,144,6,0,0,0,0,0,0,0,0,0,0,76,35,0,0,154,39,0,0,86,12,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,24,44,6,0,160,203,4,0,0,0,0,0,0,0,0,0,216,194,1,0,216,1,6,0,0,0,0,0,144,88,7,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,15,0,1,0,0,0,0,0,0,0,0,0,0,20,34,0,0,140,40,0,0,0,0,0,0,0,0,0,0,76,35,0,0,154,39,0,0,86,12,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,216,135,6,0,160,203,4,0,0,0,0,0,0,0,0,0,216,194,1,0,248,89,6,0,0,0,0,0,144,88,7,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,15,0,1,0,0,0,0,0,0,0,0,0,0,60,60,0,0,46,29,0,0,0,0,0,0,0,0,0,0,76,35,0,0,154,39,0,0,86,12,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,248,80,3,0,0,0,0,0,72,172,6,0,0,0,0,0,0,38,7,0,184,78,3,0,0,0,0,0,160,161,8,0,208,9,3,0,16,74,3,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,0,16,0,0,0,0,0,0,0,0,0,0,44,6,0,0,158,45,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,189,7,0,0,0,0,0,72,172,6,0,0,0,0,0,32,127,5,0,136,172,2,0,0,0,0,0,120,58,8,0,208,9,3,0,72,171,2,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,1,0,1,133,8,0,0,0,0,0,0,0,0,0,0,0,114,31,0,0,104,29,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,69,8,0,192,82,8,0,0,0,0,0,0,0,0,0,64,164,6,0,8,61,8,0,0,0,0,0,112,55,8,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,15,0,1,0,0,0,0,0,0,0,0,0,0,120,41,0,0,32,47,0,0,0,0,0,0,0,0,0,0,158,1,0,0,222,15,0,0,86,12,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,240,130,2,0,0,0,0,0,72,172,6,0,0,0,0,0,32,127,5,0,120,129,2,0,0,0,0,0,40,52,7,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,1,0,1,133,0,128,0,0,0,0,0,0,0,0,0,0,6,48,0,0,42,7,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,104,3,0,0,0,0,0,72,172,6,0,0,0,0,0,168,163,7,0,24,103,3,0,0,0,0,0,176,237,2,0,208,9,3,0,208,100,3,0,0,0,0,0,0,0,0,0,0,0,0,0,65,0,0,0,2,0,0,0,0,0,1,133,0,16,0,0,0,0,0,0,0,0,0,0,110,22,0,0,138,42,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,195,1,0,0,0,0,0,72,172,6,0,0,0,0,0,48,57,5,0,64,194,1,0,32,205,1,0,136,203,1,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,4,0,0,2,0,0,0,0,0,1,5,0,0,1,0,0,0,0,0,0,0,0,0,108,58,0,0,202,28,0,0,0,0,0,0,0,0,0,0,208,59,0,0,168,4,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,183,5,0,176,193,5,0,72,172,6,0,0,0,0,0,144,139,6,0,64,180,5,0,0,0,0,0,128,145,4,0,208,9,3,0,208,174,5,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,72,0,1,133,8,0,0,0,0,0,0,0,0,0,0,0,86,24,0,0,152,32,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,188,10,0,0,84,19,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,156,5,0,176,193,5,0,72,172,6,0,0,0,0,0,144,139,6,0,88,153,5,0,0,0,0,0,192,154,4,0,208,9,3,0,200,150,5,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,133,8,0,0,0,0,0,0,0,0,0,0,0,200,41,0,0,220,45,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,184,19,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,108,2,0,0,0,0,0,72,172,6,0,0,0,0,0,144,139,6,0,216,107,2,0,0,0,0,0,40,52,7,0,208,9,3,0,0,107,2,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,9,0,1,133,0,8,0,0,0,0,0,0,0,0,0,0,60,17,0,0,182,29,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,176,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,1,8,0,0,0,0,0,0,0,0,0,0,0,0,0,104,174,7,0,216,173,6,0,0,0,0,0,168,95,8,0,32,253,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,4,0,0,0,0,0,0,3,0,64,0,0,0,0,0,0,0,0,0,0,74,28,0,0,146,43,0,0,0,0,0,0,0,0,0,0,252,5,0,0,236,56,0,0,92,14,0,0,144,5,0,0,134,8,0,0,30,8,0,0,238,55,0,0,168,176,145,0,0,8,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,126,8,0,0,0,0,0,72,172,6,0,0,0,0,0,32,127,5,0,64,216,2,0,0,0,0,0,8,116,8,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,1,0,1,133,8,0,0,0,0,0,0,0,0,0,0,0,84,32,0,0,104,43,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,115,4,0,0,0,0,0,0,0,0,0,0,0,0,0,232,167,7,0,232,67,6,0,0,0,0,0,0,223,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,34,33,0,0,122,46,0,0,0,0,0,0,0,0,0,0,88,16,0,0,232,10,0,0,118,5,0,0,156,11,0,0,20,11,0,0,210,6,0,0,84,15,0,0,0,175,145,0,32,0,0,0,224,0,0,0,236,0,0,0,3,0,0,0,4,0,0,0,240,230,2,0,224,115,4,0,0,0,0,0,0,0,0,0,232,167,7,0,208,80,2,0,0,0,0,0,192,154,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,20,21,0,0,248,2,0,0,0,0,0,0,0,0,0,0,88,16,0,0,106,37,0,0,118,5,0,0,156,11,0,0,20,11,0,0,210,6,0,0,84,15,0,0,0,175,145,0,32,0,0,0,224,0,0,0,236,0,0,0,3,0,0,0,4,0,0,0,152,105,7,0,216,5,8,0,72,172,6,0,0,0,0,0,32,127,5,0,240,98,7,0,0,0,0,0,128,145,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,133,8,0,0,0,32,0,0,0,0,0,0,0,82,30,0,0,170,32,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,233,7,0,80,181,6,0,0,0,0,0,120,248,4,0,120,201,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,130,34,0,0,70,37,0,0,0,0,0,0,0,0,0,0,146,29,0,0,44,23,0,0,36,9,0,0,72,16,0,0,22,17,0,0,242,18,0,0,76,53,0,0,224,132,215,0,0,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,24,50,2,0,0,0,0,0,72,172,6,0,0,0,0,0,32,127,5,0,192,48,2,0,0,0,0,0,144,88,7,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,2,0,0,0,0,0,1,5,0,0,2,0,0,0,0,0,0,0,0,0,182,32,0,0,50,45,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,172,4,0,0,0,0,0,0,0,0,0,0,0,0,0,216,194,1,0,200,76,6,0,0,0,0,0,152,196,7,0,24,187,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,2,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,188,18,0,0,128,17,0,0,0,0,0,0,0,0,0,0,156,53,0,0,130,31,0,0,236,7,0,0,70,7,0,0,98,6,0,0,184,10,0,0,0,0,0,0,64,175,145,0,8,0,0,0,0,1,0,0,0,2,0,0,3,0,0,0,4,0,0,0,56,117,2,0,0,0,0,0,72,172,6,0,0,0,0,0,192,177,6,0,128,114,2,0,0,0,0,0,40,52,7,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,128,0,0,0,0,0,0,0,0,0,0,0,154,13,0,0,20,13,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,155,2,0,72,159,2,0,72,172,6,0,0,0,0,0,0,38,7,0,144,154,2,0,0,0,0,0,248,157,2,0,208,9,3,0,24,152,2,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,133,4,0,0,0,0,0,0,0,0,0,0,0,80,11,0,0,180,46,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,164,0,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,159,2,0,0,0,0,0,72,172,6,0,0,0,0,0,0,38,7,0,136,158,2,0,0,0,0,0,248,157,2,0,208,9,3,0,128,156,2,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,4,0,0,0,0,0,0,0,0,0,0,0,70,56,0,0,172,10,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,95,8,0,56,145,8,0,0,0,0,0,0,0,0,0,232,167,7,0,176,88,8,0,0,0,0,0,192,154,4,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,0,0,0,2,0,0,0,0,0,0,15,0,1,0,0,0,0,0,0,0,0,0,0,212,22,0,0,94,24,0,0,0,0,0,0,0,0,0,0,158,1,0,0,166,32,0,0,86,12,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,0,112,8,0,56,145,8,0,0,0,0,0,0,0,0,0,232,167,7,0,248,104,8,0,0,0,0,0,192,154,4,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,0,0,0,2,0,0,0,0,0,0,15,0,1,0,0,0,0,0,0,0,0,0,0,214,5,0,0,28,24,0,0,0,0,0,0,0,0,0,0,158,1,0,0,166,32,0,0,86,14,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,104,129,8,0,56,145,8,0,0,0,0,0,0,0,0,0,232,167,7,0,24,124,8,0,0,0,0,0,120,118,8,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,15,0,1,0,0,0,0,0,0,0,0,0,0,174,6,0,0,248,0,0,0,0,0,0,0,0,0,0,0,158,1,0,0,166,32,0,0,86,14,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,56,145,8,0,0,0,0,0,0,0,0,0,0,0,0,0,232,167,7,0,120,140,8,0,0,0,0,0,160,134,8,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,2,0,0,0,0,0,0,15,0,1,0,0,0,0,0,0,0,0,0,0,228,27,0,0,182,22,0,0,0,0,0,0,0,0,0,0,158,1,0,0,166,32,0,0,86,14,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,136,126,1,0,240,234,2,0,0,0,0,0,0,0,0,0,64,164,6,0,56,42,1,0,0,0,0,0,56,231,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,0,22,0,1,0,0,0,0,0,0,0,0,0,0,34,12,0,0,168,2,0,0,0,0,0,0,0,0,0,0,154,11,0,0,4,16,0,0,0,6,0,0,156,0,0,0,98,18,0,0,232,14,0,0,224,37,0,0,56,175,145,0,8,0,0,0,240,0,0,0,240,0,0,0,3,0,0,0,4,0,0,0,152,48,8,0,0,0,0,0,0,0,0,0,0,0,0,0,232,167,7,0,56,40,8,0,0,0,0,0,200,71,8,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,2,0,0,0,0,0,0,15,0,1,0,0,0,0,0,0,0,0,0,0,244,26,0,0,208,39,0,0,0,0,0,0,0,0,0,0,158,1,0,0,222,15,0,0,86,14,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,216,233,6,0,0,0,0,0,200,240,5,0,0,0,0,0,104,129,6,0,192,228,6,0,144,236,6,0,208,6,2,0,88,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,4,0,0,0,1,0,0,8,0,16,0,0,0,0,0,0,0,0,0,0,24,24,0,0,202,45,0,0,0,0,0,0,0,0,0,0,104,35,0,0,232,12,0,0,48,15,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,192,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,199,1,0,144,202,1,0,72,172,6,0,0,0,0,0,48,57,5,0,152,197,1,0,32,205,1,0,136,203,1,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,4,0,0,2,0,0,0,0,0,1,5,0,0,1,0,0,0,0,0,0,0,0,0,194,41,0,0,84,36,0,0,0,0,0,0,0,0,0,0,208,59,0,0,168,4,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,202,1,0,0,0,0,0,72,172,6,0,0,0,0,0,48,57,5,0,144,201,1,0,32,205,1,0,136,203,1,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,4,0,0,2,0,0,0,0,0,1,5,0,0,1,0,0,0,0,0,0,0,0,0,136,31,0,0,80,33,0,0,0,0,0,0,0,0,0,0,208,59,0,0,168,4,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,196,1,0,0,0,0,0,72,172,6,0,0,0,0,0,48,57,5,0,192,195,1,0,32,205,1,0,136,203,1,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,4,0,0,2,0,0,0,0,0,1,5,0,0,1,0,0,0,0,0,0,0,0,0,240,16,0,0,182,45,0,0,0,0,0,0,0,0,0,0,208,59,0,0,168,4,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,253,6,0,0,0,0,0,0,0,0,0,0,0,0,0,232,167,7,0,72,249,6,0,0,0,0,0,72,48,7,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,0,15,0,16,0,0,0,0,0,0,0,0,0,0,100,49,0,0,10,36,0,0,0,0,0,0,0,0,0,0,28,58,0,0,38,39,0,0,76,8,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,232,67,8,0,0,0,0,0,72,172,6,0,0,0,0,0,32,127,5,0,224,174,2,0,0,0,0,0,120,58,8,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,1,0,1,133,8,0,0,0,0,0,0,0,0,0,0,0,54,34,0,0,228,20,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,67,3,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,8,21,6,0,0,0,0,0,40,161,4,0,40,153,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,10,2,0,1,0,0,0,0,0,0,0,0,0,0,82,50,0,0,168,30,0,0,0,0,0,0,0,0,0,0,230,4,0,0,0,0,0,0,216,6,0,0,136,12,0,0,38,1,0,0,224,9,0,0,156,40,0,0,184,173,145,0,2,0,0,0,0,1,0,0,192,0,0,0,4,0,0,0,3,0,0,0,112,205,2,0,160,67,3,0,0,0,0,0,0,0,0,0,104,221,5,0,120,66,2,0,0,0,0,0,40,161,4,0,40,153,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,1,0,0,0,0,0,10,2,0,1,0,0,0,0,0,0,0,0,0,0,10,16,0,0,146,46,0,0,0,0,0,0,0,0,0,0,230,4,0,0,0,0,0,0,216,6,0,0,136,12,0,0,38,1,0,0,224,9,0,0,156,40,0,0,184,173,145,0,2,0,0,0,0,1,0,0,192,0,0,0,4,0,0,0,3,0,0,0,120,161,4,0,0,0,0,0,0,0,0,0,0,0,0,0,160,135,3,0,176,75,6,0,0,0,0,0,120,58,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,0,22,0,1,0,0,0,0,0,0,0,0,0,0,156,29,0,0,212,17,0,0,0,0,0,0,0,0,0,0,154,11,0,0,4,16,0,0,8,9,0,0,156,0,0,0,98,18,0,0,232,14,0,0,224,37,0,0,56,175,145,0,8,0,0,0,240,0,0,0,248,0,0,0,3,0,0,0,4,0,0,0,24,205,6,0,144,205,5,0,200,240,5,0,0,0,0,0,56,172,6,0,8,202,6,0,0,0,0,0,72,174,3,0,88,0,3,0,176,198,6,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,1,0,0,8,0,8,0,0,0,0,0,0,0,0,0,0,28,34,0,0,190,21,0,0,0,0,0,0,0,0,0,0,104,35,0,0,82,38,0,0,104,6,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,192,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,195,6,0,144,205,5,0,200,240,5,0,0,0,0,0,56,172,6,0,96,191,6,0,0,0,0,0,72,174,3,0,88,0,3,0,216,185,6,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,1,0,0,8,0,8,0,0,0,0,0,0,0,0,0,0,134,32,0,0,68,0,0,0,0,0,0,0,0,0,0,0,104,35,0,0,82,38,0,0,104,6,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,192,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,67,2,0,0,0,0,0,72,172,6,0,0,0,0,0,184,230,7,0,152,66,2,0,0,0,0,0,208,65,2,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,0,0,2,0,0,0,0,0,1,133,0,1,0,0,0,0,0,0,0,0,0,0,150,44,0,0,54,43,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,80,3,0,160,203,4,0,0,0,0,0,0,0,0,0,232,167,7,0,192,65,3,0,0,0,0,0,144,88,7,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,15,0,1,0,0,0,0,0,0,0,0,0,0,202,15,0,0,90,10,0,0,0,0,0,0,0,0,0,0,76,35,0,0,154,39,0,0,86,12,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,64,113,2,0,0,0,0,0,72,172,6,0,0,0,0,0,144,139,6,0,72,110,2,0,0,0,0,0,40,52,7,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,1,0,1,133,2,0,0,0,0,0,0,0,0,0,0,0,210,3,0,0,88,23,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,54,2,0,232,92,5,0,72,172,6,0,0,0,0,0,144,33,2,0,80,53,2,0,0,0,0,0,192,154,4,0,208,9,3,0,72,51,2,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,133,8,0,0,0,4,0,0,0,0,0,0,0,224,27,0,0,230,47,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,124,18,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,78,5,0,232,92,5,0,72,172,6,0,0,0,0,0,144,33,2,0,56,71,5,0,224,66,5,0,48,65,5,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,133,8,0,0,0,4,0,0,0,0,0,0,0,242,20,0,0,80,5,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,142,3,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,63,5,0,232,92,5,0,72,172,6,0,0,0,0,0,144,33,2,0,16,60,5,0,0,0,0,0,192,154,4,0,208,9,3,0,72,57,5,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,133,8,0,0,0,4,0,0,0,0,0,0,0,124,21,0,0,38,1,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,42,11,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,55,5,0,232,92,5,0,72,172,6,0,0,0,0,0,144,33,2,0,168,51,5,0,0,0,0,0,192,154,4,0,208,9,3,0,80,47,5,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,133,8,0,0,0,4,0,0,0,0,0,0,0,242,16,0,0,116,19,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,46,18,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,225,8,0,24,116,1,0,0,0,0,0,0,0,0,0,40,41,5,0,88,217,8,0,0,0,0,0,152,208,8,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,15,0,1,0,0,0,0,0,0,0,0,0,0,224,33,0,0,156,18,0,0,0,0,0,0,0,0,0,0,76,35,0,0,2,39,0,0,36,14,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,192,60,1,0,24,116,1,0,0,0,0,0,0,0,0,0,216,194,1,0,200,51,1,0,0,0,0,0,192,154,4,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,0,0,0,2,0,0,0,0,0,0,15,0,1,0,0,0,0,0,0,0,0,0,0,126,31,0,0,52,42,0,0,0,0,0,0,0,0,0,0,76,35,0,0,194,50,0,0,86,12,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,208,72,1,0,24,116,1,0,0,0,0,0,0,0,0,0,216,194,1,0,160,66,1,0,0,0,0,0,192,154,4,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,0,0,0,2,0,0,0,0,0,0,15,0,1,0,0,0,0,0,0,0,0,0,0,250,22,0,0,44,43,0,0,0,0,0,0,0,0,0,0,76,35,0,0,194,50,0,0,86,12,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,184,87,1,0,24,116,1,0,0,0,0,0,0,0,0,0,216,194,1,0,48,80,1,0,0,0,0,0,240,93,1,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,15,0,1,0,0,0,0,0,0,0,0,0,0,198,46,0,0,152,1,0,0,0,0,0,0,0,0,0,0,76,35,0,0,194,50,0,0,86,12,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,144,0,1,0,24,116,1,0,0,0,0,0,0,0,0,0,216,194,1,0,96,253,8,0,0,0,0,0,144,247,8,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,15,0,1,0,0,0,0,0,0,0,0,0,0,166,36,0,0,2,47,0,0,0,0,0,0,0,0,0,0,76,35,0,0,194,50,0,0,8,5,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,104,16,1,0,24,116,1,0,0,0,0,0,0,0,0,0,216,194,1,0,136,11,1,0,0,0,0,0,144,5,1,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,15,0,1,0,0,0,0,0,0,0,0,0,0,176,10,0,0,122,47,0,0,0,0,0,0,0,0,0,0,76,35,0,0,194,50,0,0,220,7,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,56,44,1,0,24,116,1,0,0,0,0,0,0,0,0,0,216,194,1,0,0,36,1,0,0,0,0,0,200,25,1,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,15,0,1,0,0,0,0,0,0,0,0,0,0,244,27,0,0,52,38,0,0,0,0,0,0,0,0,0,0,76,35,0,0,194,50,0,0,86,12,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,24,116,1,0,0,0,0,0,0,0,0,0,0,0,0,0,216,194,1,0,32,104,1,0,0,0,0,0,240,93,1,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,2,0,0,0,0,0,0,15,0,1,0,0,0,0,0,0,0,0,0,0,84,43,0,0,114,12,0,0,0,0,0,0,0,0,0,0,76,35,0,0,194,50,0,0,156,12,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,16,17,4,0,0,0,0,0,72,172,6,0,0,0,0,0,144,47,2,0,128,14,4,0,0,0,0,0,208,40,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,0,0,1,0,0,0,0,0,0,0,0,0,78,28,0,0,4,2,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,237,4,0,160,203,4,0,0,0,0,0,0,0,0,0,96,159,4,0,56,202,4,0,0,0,0,0,184,169,4,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,0,0,0,2,0,0,0,0,0,0,15,0,1,0,0,0,0,0,0,0,0,0,0,34,45,0,0,230,34,0,0,0,0,0,0,0,0,0,0,76,35,0,0,154,39,0,0,86,12,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,152,204,2,0,0,0,0,0,0,0,0,0,0,0,0,0,200,190,7,0,104,206,1,0,0,0,0,0,88,108,1,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,3,0,0,0,0,0,10,2,0,0,1,0,0,0,0,0,0,0,0,0,38,54,0,0,142,37,0,0,0,0,0,0,0,0,0,0,198,55,0,0,190,42,0,0,198,14,0,0,136,14,0,0,4,9,0,0,228,0,0,0,224,17,0,0,0,0,0,0,0,1,0,0,224,0,0,0,224,0,0,0,3,0,0,0,4,0,0,0,184,241,1,0,0,0,0,0,72,172,6,0,0,0,0,0,136,232,4,0,208,240,1,0,0,0,0,0,136,239,1,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,0,0,2,0,0,0,0,0,1,5,0,16,0,0,0,0,0,0,0,0,0,0,150,56,0,0,56,19,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,207,1,0,0,0,0,0,72,172,6,0,0,0,0,0,48,57,5,0,24,206,1,0,32,205,1,0,136,203,1,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,4,0,0,2,0,0,0,0,0,1,5,0,0,1,0,0,0,0,0,0,0,0,0,142,50,0,0,168,4,0,0,0,0,0,0,0,0,0,0,208,59,0,0,168,4,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,244,1,0,0,0,0,0,72,172,6,0,0,0,0,0,160,217,6,0,128,243,1,0,0,0,0,0,144,81,5,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,0,0,2,0,0,0,0,0,1,5,2,0,0,0,0,0,0,0,0,0,0,0,38,49,0,0,236,2,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,198,7,0,0,0,0,0,0,0,0,0,0,0,0,0,160,135,3,0,136,192,7,0,200,184,7,0,152,180,7,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,2,0,0,0,0,0,0,15,32,0,0,0,0,0,0,0,0,0,0,0,4,22,0,0,50,19,0,0,0,0,0,0,0,0,0,0,122,11,0,0,52,49,0,0,236,11,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,184,245,6,0,0,0,0,0,0,0,0,0,0,0,0,0,64,164,6,0,192,241,6,0,0,0,0,0,96,239,6,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,2,0,0,0,0,0,0,15,64,0,0,0,0,0,0,0,0,0,0,0,194,26,0,0,240,3,0,0,0,0,0,0,0,0,0,0,162,47,0,0,244,31,0,0,248,10,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,24,142,3,0,160,203,4,0,0,0,0,0,0,0,0,0,40,41,5,0,176,95,3,0,0,0,0,0,144,88,7,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,15,0,1,0,0,0,0,0,0,0,0,0,0,230,40,0,0,224,44,0,0,0,0,0,0,0,0,0,0,76,35,0,0,154,39,0,0,86,12,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,176,106,7,0,136,107,8,0,0,0,0,0,0,0,0,0,232,167,7,0,72,56,7,0,0,0,0,0,224,254,7,0,120,201,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,182,35,0,0,24,45,0,0,0,0,0,0,0,0,0,0,250,46,0,0,170,3,0,0,84,12,0,0,72,16,0,0,22,17,0,0,242,18,0,0,76,53,0,0,224,132,215,0,0,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,88,120,2,0,0,0,0,0,72,172,6,0,0,0,0,0,192,177,6,0,88,119,2,0,0,0,0,0,40,52,7,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,1,0,1,133,8,0,0,0,0,0,0,0,0,0,0,0,126,29,0,0,206,5,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,212,6,0,0,0,0,0,72,172,6,0,0,0,0,0,168,163,7,0,112,122,2,0,0,0,0,0,40,52,7,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,1,0,1,133,8,0,0,0,0,0,0,0,0,0,0,0,232,22,0,0,2,12,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,232,8,0,240,209,4,0,0,0,0,0,0,0,0,0,200,190,7,0,0,167,8,0,0,0,0,0,192,223,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,20,4,8,0,0,0,0,0,0,0,0,0,0,106,29,0,0,56,5,0,0,0,0,0,0,0,0,0,0,12,48,0,0,76,51,0,0,186,9,0,0,204,2,0,0,140,3,0,0,56,2,0,0,80,42,0,0,88,175,145,0,0,4,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,136,3,0,0,0,0,0,72,172,6,0,0,0,0,0,192,177,6,0,128,133,3,0,0,0,0,0,176,131,3,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,1,0,0,0,0,0,0,0,0,0,0,0,66,47,0,0,130,24,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,48,4,0,0,0,0,0,72,172,6,0,0,0,0,0,104,221,5,0,120,18,4,0,0,0,0,0,208,40,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,0,8,0,0,0,0,0,0,0,0,0,0,198,54,0,0,84,12,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,173,6,0,0,0,0,0,0,0,0,0,0,0,0,0,232,167,7,0,24,167,6,0,0,0,0,0,232,161,6,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,0,15,0,1,0,0,0,0,0,0,0,0,0,0,0,28,0,0,142,10,0,0,0,0,0,0,0,0,0,0,76,35,0,0,154,39,0,0,58,2,0,0])
.concat([222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,136,228,1,0,120,225,4,0,0,0,0,0,0,0,0,0,200,190,7,0,240,129,1,0,0,0,0,0,192,223,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,20,0,8,0,0,0,0,0,0,0,0,0,0,56,46,0,0,142,28,0,0,0,0,0,0,0,0,0,0,222,57,0,0,102,37,0,0,130,11,0,0,152,17,0,0,62,14,0,0,138,14,0,0,42,35,0,0,104,175,145,0,0,4,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,240,2,0,120,225,4,0,0,0,0,0,0,0,0,0,200,190,7,0,160,88,2,0,0,0,0,0,192,223,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,20,0,8,0,0,0,0,0,0,0,0,0,0,124,41,0,0,84,7,0,0,0,0,0,0,0,0,0,0,222,57,0,0,102,37,0,0,130,11,0,0,152,17,0,0,62,14,0,0,138,14,0,0,42,35,0,0,104,175,145,0,0,4,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,225,4,0,0,0,0,0,0,0,0,0,0,0,0,0,200,190,7,0,208,88,6,0,0,0,0,0,192,223,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,20,0,8,0,0,0,0,0,0,0,0,0,0,112,8,0,0,72,46,0,0,0,0,0,0,0,0,0,0,222,57,0,0,102,37,0,0,130,11,0,0,152,17,0,0,62,14,0,0,138,14,0,0,42,35,0,0,104,175,145,0,0,4,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,228,6,0,0,0,0,0,0,0,0,0,0,0,0,0,160,234,7,0,80,218,6,0,0,0,0,0,8,214,6,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,2,0,0,0,0,0,0,15,0,32,0,0,0,0,0,0,0,0,0,0,136,34,0,0,138,27,0,0,0,0,0,0,0,0,0,0,254,34,0,0,118,38,0,0,62,2,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,128,73,7,0,184,110,7,0,0,0,0,0,0,0,0,0,232,233,7,0,16,65,7,0,0,0,0,0,40,98,7,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,15,0,8,0,0,0,0,0,0,0,0,0,0,24,25,0,0,106,10,0,0,0,0,0,0,0,0,0,0,248,26,0,0,28,50,0,0,180,3,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,208,249,1,0,0,0,0,0,72,172,6,0,0,0,0,0,136,232,4,0,184,245,1,0,0,0,0,0,120,245,1,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,4,0,0,2,0,0,0,0,0,1,5,0,0,1,0,0,0,0,0,0,0,0,0,222,55,0,0,208,19,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,118,1,0,96,184,3,0,72,172,6,0,0,0,0,0,144,47,2,0,192,105,1,0,0,0,0,0,240,192,1,0,168,200,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,133,0,64,0,0,0,0,0,0,0,0,0,0,72,25,0,0,74,7,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,144,1,0,96,184,3,0,72,172,6,0,0,0,0,0,144,47,2,0,160,132,1,0,0,0,0,0,240,192,1,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,133,0,64,0,0,0,0,0,0,0,0,0,0,166,59,0,0,176,19,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,184,3,0,0,0,0,0,72,172,6,0,0,0,0,0,144,47,2,0,64,156,1,0,0,0,0,0,240,192,1,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,0,64,0,0,0,0,0,0,0,0,0,0,152,42,0,0,42,4,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,57,3,0,0,0,0,0,0,0,0,0,0,0,0,0,232,233,7,0,168,18,6,0,0,0,0,0,8,181,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,3,0,0,0,0,0,10,2,0,0,1,0,0,0,0,0,0,0,0,0,76,33,0,0,252,15,0,0,0,0,0,0,0,0,0,0,230,21,0,0,54,37,0,0,198,14,0,0,136,14,0,0,4,9,0,0,228,0,0,0,224,17,0,0,0,0,0,0,0,1,0,0,224,0,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,59,2,0,112,106,2,0,72,172,6,0,0,0,0,0,184,230,7,0,80,57,2,0,0,0,0,0,40,52,7,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,81,0,0,0,2,0,0,0,1,0,1,133,128,0,0,0,0,0,0,0,0,0,0,0,148,55,0,0,0,31,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,106,2,0,0,0,0,0,72,172,6,0,0,0,0,0,184,230,7,0,96,105,2,0,0,0,0,0,40,52,7,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,9,0,1,133,128,0,0,0,0,0,0,0,0,0,0,0,188,60,0,0,54,4,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,76,13,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,48,3,0,0,0,0,0,72,172,6,0,0,0,0,0,144,47,2,0,192,46,3,0,0,0,0,0,120,53,3,0,208,9,3,0,208,43,3,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,64,1,133,0,0,2,0,0,0,0,0,0,0,0,0,104,53,0,0,50,39,0,0,0,0,0,0,0,0,0,0,200,29,0,0,126,48,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,226,6,0,0,0,0,0,0,0,0,0,0,0,0,0,104,174,7,0,64,183,6,0,0,0,0,0,32,0,1,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,178,62,0,0,18,46,0,0,0,0,0,0,0,0,0,0,20,54,0,0,188,5,0,0,42,3,0,0,90,14,0,0,242,4,0,0,126,18,0,0,176,61,0,0,56,176,145,0,0,4,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,40,2,0,0,0,0,0,72,172,6,0,0,0,0,0,184,230,7,0,208,39,2,0,0,0,0,0,40,52,7,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,65,0,0,0,2,0,0,0,0,0,1,133,0,8,0,0,0,0,0,0,0,0,0,0,226,45,0,0,124,16,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,214,3,0,208,217,2,0,0,0,0,0,0,0,0,0,160,234,7,0,56,186,3,0,0,0,0,0,192,154,4,0,208,138,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,0,0,0,2,0,0,0,0,0,3,11,32,0,0,0,0,0,0,0,0,0,0,0,30,41,0,0,76,8,0,0,0,0,0,0,0,0,0,0,4,31,0,0,162,62,0,0,160,0,0,0,20,7,0,0,122,3,0,0,24,18,0,0,236,62,0,0,152,173,145,0,0,2,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,56,103,1,0,208,217,2,0,0,0,0,0,0,0,0,0,160,234,7,0,224,24,1,0,0,0,0,0,88,90,7,0,208,138,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,3,11,32,0,0,0,0,0,0,0,0,0,0,0,132,47,0,0,226,4,0,0,0,0,0,0,0,0,0,0,4,31,0,0,12,37,0,0,160,0,0,0,20,7,0,0,122,3,0,0,24,18,0,0,236,62,0,0,152,173,145,0,0,2,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,120,195,2,0,208,217,2,0,0,0,0,0,0,0,0,0,160,234,7,0,144,59,2,0,0,0,0,0,88,90,7,0,208,138,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,3,11,32,0,0,0,0,0,0,0,0,0,0,0,52,21,0,0,228,23,0,0,0,0,0,0,0,0,0,0,4,31,0,0,12,37,0,0,160,0,0,0,20,7,0,0,122,3,0,0,24,18,0,0,236,62,0,0,152,173,145,0,0,2,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,32,34,8,0,208,217,2,0,0,0,0,0,0,0,0,0,160,234,7,0,104,237,7,0,0,0,0,0,144,84,8,0,208,138,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,3,11,32,0,0,0,0,0,0,0,0,0,0,0,76,36,0,0,232,33,0,0,0,0,0,0,0,0,0,0,4,31,0,0,156,6,0,0,160,0,0,0,20,7,0,0,122,3,0,0,24,18,0,0,236,62,0,0,152,173,145,0,0,2,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,208,125,6,0,208,217,2,0,0,0,0,0,0,0,0,0,160,234,7,0,0,76,6,0,0,0,0,0,192,154,4,0,208,138,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,0,0,0,2,0,0,0,0,0,3,11,32,0,0,0,0,0,0,0,0,0,0,0,16,49,0,0,98,30,0,0,0,0,0,0,0,0,0,0,4,31,0,0,156,6,0,0,160,0,0,0,20,7,0,0,122,3,0,0,24,18,0,0,236,62,0,0,152,173,145,0,0,2,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,32,138,7,0,208,217,2,0,0,0,0,0,0,0,0,0,160,234,7,0,136,90,7,0,0,0,0,0,192,154,4,0,208,138,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,0,0,0,2,0,0,0,0,0,3,11,32,0,0,0,0,0,0,0,0,0,0,0,190,44,0,0,148,33,0,0,0,0,0,0,0,0,0,0,4,31,0,0,156,6,0,0,160,0,0,0,20,7,0,0,122,3,0,0,24,18,0,0,236,62,0,0,152,173,145,0,0,2,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,88,130,4,0,208,217,2,0,0,0,0,0,0,0,0,0,160,234,7,0,160,103,4,0,0,0,0,0,192,154,4,0,208,138,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,0,0,0,2,0,0,0,0,0,3,11,32,0,0,0,0,0,0,0,0,0,0,0,210,42,0,0,190,12,0,0,0,0,0,0,0,0,0,0,4,31,0,0,162,14,0,0,176,5,0,0,20,7,0,0,122,3,0,0,24,18,0,0,236,62,0,0,152,173,145,0,0,2,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,136,8,5,0,208,217,2,0,0,0,0,0,0,0,0,0,160,234,7,0,232,228,4,0,0,0,0,0,192,154,4,0,208,138,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,0,0,0,2,0,0,0,0,0,3,11,32,0,0,0,0,0,0,0,0,0,0,0,198,11,0,0,132,21,0,0,0,0,0,0,0,0,0,0,4,31,0,0,228,49,0,0,234,16,0,0,20,7,0,0,122,3,0,0,24,18,0,0,236,62,0,0,152,173,145,0,0,2,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,232,192,4,0,208,217,2,0,0,0,0,0,0,0,0,0,160,234,7,0,216,160,4,0,0,0,0,0,192,154,4,0,208,138,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,0,0,0,2,0,0,0,0,0,3,11,32,0,0,0,0,0,0,0,0,0,0,0,112,42,0,0,186,31,0,0,0,0,0,0,0,0,0,0,4,31,0,0,228,49,0,0,176,3,0,0,20,7,0,0,122,3,0,0,24,18,0,0,236,62,0,0,152,173,145,0,0,2,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,184,216,8,0,0,0,0,0,0,0,0,0,0,0,0,0,200,190,7,0,56,88,8,0,0,0,0,0,88,90,7,0,208,138,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,2,0,0,0,0,0,3,11,32,0,0,0,0,0,0,0,0,0,0,0,150,1,0,0,122,16,0,0,0,0,0,0,0,0,0,0,4,31,0,0,12,37,0,0,160,0,0,0,20,7,0,0,122,3,0,0,24,18,0,0,236,62,0,0,152,173,145,0,0,2,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,216,22,4,0,208,217,2,0,0,0,0,0,0,0,0,0,160,234,7,0,16,248,3,0,0,0,0,0,192,154,4,0,208,138,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,0,0,0,2,0,0,0,0,0,3,11,32,0,0,0,0,0,0,0,0,0,0,0,154,62,0,0,164,19,0,0,0,0,0,0,0,0,0,0,4,31,0,0,156,6,0,0,160,0,0,0,20,7,0,0,122,3,0,0,24,18,0,0,236,62,0,0,152,173,145,0,0,2,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,16,253,6,0,208,217,2,0,0,0,0,0,0,0,0,0,160,234,7,0,72,213,6,0,0,0,0,0,144,166,6,0,208,138,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,0,0,0,2,0,0,0,0,0,3,11,32,0,0,0,0,0,0,0,0,0,0,0,14,49,0,0,200,4,0,0,0,0,0,0,0,0,0,0,4,31,0,0,156,6,0,0,160,0,0,0,20,7,0,0,122,3,0,0,24,18,0,0,236,62,0,0,152,173,145,0,0,2,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,208,217,2,0,0,0,0,0,0,0,0,0,0,0,0,0,160,234,7,0,40,252,5,0,0,0,0,0,168,183,7,0,208,138,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,2,0,0,0,0,0,3,11,32,0,0,0,0,0,0,0,0,0,0,0,140,21,0,0,144,7,0,0,0,0,0,0,0,0,0,0,4,31,0,0,12,37,0,0,160,0,0,0,20,7,0,0,122,3,0,0,24,18,0,0,236,62,0,0,152,173,145,0,0,2,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,96,69,5,0,208,217,2,0,0,0,0,0,0,0,0,0,160,234,7,0,80,38,5,0,0,0,0,0,192,154,4,0,208,138,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,0,0,0,2,0,0,0,0,0,3,11,32,0,0,0,0,0,0,0,0,0,0,0,52,16,0,0,230,16,0,0,0,0,0,0,0,0,0,0,4,31,0,0,186,19,0,0,56,11,0,0,20,7,0,0,122,3,0,0,24,18,0,0,236,62,0,0,152,173,145,0,0,2,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,64,129,5,0,208,217,2,0,0,0,0,0,0,0,0,0,160,234,7,0,104,100,5,0,0,0,0,0,192,154,4,0,208,138,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,0,0,0,2,0,0,0,0,0,3,11,32,0,0,0,0,0,0,0,0,0,0,0,238,25,0,0,98,7,0,0,0,0,0,0,0,0,0,0,4,31,0,0,228,49,0,0,162,2,0,0,20,7,0,0,122,3,0,0,24,18,0,0,236,62,0,0,152,173,145,0,0,2,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,120,203,5,0,208,217,2,0,0,0,0,0,0,0,0,0,160,234,7,0,72,162,5,0,0,0,0,0,192,154,4,0,208,138,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,0,0,0,2,0,0,0,0,0,3,11,32,0,0,0,0,0,0,0,0,0,0,0,74,6,0,0,182,39,0,0,0,0,0,0,0,0,0,0,4,31,0,0,6,44,0,0,160,0,0,0,20,7,0,0,122,3,0,0,24,18,0,0,236,62,0,0,152,173,145,0,0,2,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,104,34,6,0,208,217,2,0,0,0,0,0,0,0,0,0,160,234,7,0,104,243,5,0,0,0,0,0,192,154,4,0,208,138,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,0,0,0,2,0,0,0,0,0,3,11,32,0,0,0,0,0,0,0,0,0,0,0,176,3,0,0,96,42,0,0,0,0,0,0,0,0,0,0,4,31,0,0,6,44,0,0,160,0,0,0,20,7,0,0,122,3,0,0,24,18,0,0,236,62,0,0,152,173,145,0,0,2,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,176,251,2,0,240,145,5,0,0,0,0,0,0,0,0,0,64,164,6,0,176,96,2,0,0,0,0,0,128,231,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,180,45,0,0,158,17,0,0,0,0,0,0,0,0,0,0,150,12,0,0,210,54,0,0,96,6,0,0,104,18,0,0,158,0,0,0,102,0,0,0,254,25,0,0,16,176,145,0,0,32,0,0,234,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,240,145,5,0,0,0,0,0,0,0,0,0,0,0,0,0,64,164,6,0,88,115,6,0,0,0,0,0,152,196,7,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,244,52,0,0,194,30,0,0,0,0,0,0,0,0,0,0,150,12,0,0,112,20,0,0,96,6,0,0,104,18,0,0,158,0,0,0,102,0,0,0,254,25,0,0,16,176,145,0,0,32,0,0,234,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,104,149,8,0,0,0,0,0,72,172,6,0,0,0,0,0,0,38,7,0,80,209,3,0,0,0,0,0,80,215,3,0,208,9,3,0,0,206,3,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,1,0,1,133,8,0,0,0,0,0,0,0,0,0,0,0,204,54,0,0,216,3,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,138,2,0,0,0,0,0,72,172,6,0,0,0,0,0,96,135,2,0,168,136,2,0,0,0,0,0,40,52,7,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,1,0,0,0,0,0,0,0,0,0,0,0,86,34,0,0,74,43,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,185,6,0,152,198,6,0,0,0,0,0,0,0,0,0,232,167,7,0,128,179,6,0,0,0,0,0,192,154,4,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,15,0,1,0,0,0,0,0,0,0,0,0,0,172,12,0,0,202,38,0,0,0,0,0,0,0,0,0,0,214,47,0,0,118,50,0,0,136,3,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,152,198,6,0,0,0,0,0,0,0,0,0,0,0,0,0,232,167,7,0,152,195,6,0,0,0,0,0,40,161,4,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,2,0,0,0,0,0,0,15,0,1,0,0,0,0,0,0,0,0,0,0,86,12,0,0,14,20,0,0,0,0,0,0,0,0,0,0,214,47,0,0,118,50,0,0,136,3,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,112,236,6,0,184,245,6,0,0,0,0,0,0,0,0,0,64,164,6,0,192,232,6,0,0,0,0,0,96,239,6,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,15,64,0,0,0,0,0,0,0,0,0,0,0,240,6,0,0,36,18,0,0,0,0,0,0,0,0,0,0,10,14,0,0,246,32,0,0,248,10,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,120,3,8,0,160,203,4,0,0,0,0,0,0,0,0,0,216,194,1,0,40,252,7,0,0,0,0,0,96,25,8,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,15,0,1,0,0,0,0,0,0,0,0,0,0,220,39,0,0,48,42,0,0,0,0,0,0,0,0,0,0,76,35,0,0,76,47,0,0,192,8,0,0,222,17,0,0,200,12,0,0,212,5,0,0,12,53,0,0,80,175,145,0,0,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,192,231,2,0,24,31,8,0,0,0,0,0,0,0,0,0,64,171,7,0,128,125,1,0,0,0,0,0,96,41,1,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,15,0,64,0,0,0,0,0,0,0,0,0,0,4,63,0,0,110,21,0,0,0,0,0,0,0,0,0,0,76,41,0,0,162,12,0,0,8,15,0,0,56,4,0,0,44,2,0,0,96,15,0,0,104,26,0,0,24,175,145,0,128,0,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,8,116,5,0,0,0,0,0,72,172,6,0,0,0,0,0,104,129,6,0,128,110,5,0,0,0,0,0,128,145,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,8,0,1,133,0,8,0,0,0,0,0,0,0,0,0,0,172,46,0,0,202,8,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,28,12,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,213,1,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,136,191,1,0,0,0,0,0,224,183,1,0,0,227,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,21,0,0,1,0,0,0,0,0,0,0,0,0,24,31,0,0,8,31,0,0,0,0,0,0,0,0,0,0,188,34,0,0,70,62,0,0,4,19,0,0,248,19,0,0,72,13,0,0,82,5,0,0,96,10,0,0,224,174,145,0,0,18,0,0,128,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,80,81,4,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,64,55,4,0,80,27,4,0,40,253,3,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,133,0,0,0,2,0,0,0,0,0,0,10,32,0,0,0,0,0,0,0,0,0,0,0,140,20,0,0,162,17,0,0,0,0,0,0,0,0,0,0,196,46,0,0,104,37,0,0,100,0,0,0,8,1,0,0,134,12,0,0,190,17,0,0,4,30,0,0,104,157,215,0,0,4,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,64,166,3,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,192,140,3,0,0,0,0,0,96,117,3,0,0,227,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,1,21,0,0,1,0,0,0,0,0,0,0,0,0,82,0,0,0,72,26,0,0,0,0,0,0,0,0,0,0,50,49,0,0,188,29,0,0,152,14,0,0,248,19,0,0,72,13,0,0,56,10,0,0,96,10,0,0,224,174,145,0,0,12,0,0,240,0,0,0,128,1,0,0,3,0,0,0,4,0,0,0,216,62,7,0,216,75,7,0,0,0,0,0,0,0,0,0,232,167,7,0,24,57,7,0,0,0,0,0,128,67,7,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,8,0,0,2,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,0,0,0,0,38,44,0,0,68,32,0,0,0,0,0,0,0,0,0,0,146,37,0,0,92,30,0,0,250,6,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,216,75,7,0,0,0,0,0,0,0,0,0,0,0,0,0,232,167,7,0,248,71,7,0,0,0,0,0,128,67,7,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,8,0,0,2,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,0,0,0,0,82,27,0,0,12,28,0,0,0,0,0,0,0,0,0,0,146,37,0,0,92,30,0,0,250,6,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,232,177,3,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,120,42,6,0,0,0,0,0,184,191,7,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,8,0,0,0,0,0,0,0,0,0,0,0,6,35,0,0,66,31,0,0,0,0,0,0,0,0,0,0,58,40,0,0,118,44,0,0,16,5,0,0,208,16,0,0,164,3,0,0,100,2,0,0,174,20,0,0,72,174,145,0,0,1,0,0,112,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,186,2,0,232,137,2,0,0,0,0,0,0,0,0,0,184,168,7,0,168,49,2,0,0,0,0,0,224,194,1,0,224,127,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,4,1,0,0,0,0,0,0,0,0,0,0,0,194,34,0,0,108,38,0,0,0,0,0,0,0,0,0,0,146,50,0,0,216,61,0,0,148,8,0,0,26,14,0,0,194,2,0,0,244,13,0,0,12,12,0,0,32,146,215,0,0,4,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,232,137,2,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,48,229,5,0,0,0,0,0,160,150,4,0,224,127,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,4,1,0,0,0,0,0,0,0,0,0,0,0,62,5,0,0,24,28,0,0,0,0,0,0,0,0,0,0,146,50,0,0,242,8,0,0,148,8,0,0,26,14,0,0,194,2,0,0,244,13,0,0,12,12,0,0,32,146,215,0,0,4,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,0,123,4,0,120,136,1,0,0,0,0,0,0,0,0,0,224,56,7,0,184,97,4,0,0,0,0,0,80,71,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,8,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,174,43,0,0,82,26,0,0,0,0,0,0,0,0,0,0,86,51,0,0,250,20,0,0,8,7,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,88,210,1,0,24,160,3,0,0,0,0,0,0,0,0,0,192,177,6,0,32,113,1,0,0,0,0,0,0,192,4,0,0,192,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,10,0,0,8,0,0,0,0,0,0,0,0,0,230,49,0,0,118,32,0,0,0,0,0,0,0,0,0,0,194,13,0,0,124,27,0,0,166,12,0,0,108,6,0,0,110,11,0,0,0,0,0,0,138,47,0,0,0,0,0,0,0,32,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,32,1,0,24,160,3,0,0,0,0,0,0,0,0,0,192,177,6,0,152,222,8,0,0,0,0,0,0,192,4,0,0,192,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,10,0,0,8,0,0,0,0,0,0,0,0,0,6,11,0,0,110,29,0,0,0,0,0,0,0,0,0,0,194,13,0,0,124,27,0,0,166,12,0,0,108,6,0,0,110,11,0,0,0,0,0,0,138,47,0,0,0,0,0,0,0,32,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,156,8,0,0,0,0,0,0,0,0,0,0,0,0,0,144,139,6,0,16,39,8,0,0,0,0,0,0,192,4,0,0,192,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,0,8,0,0,0,0,0,0,0,0,0,38,6,0,0,54,6,0,0,0,0,0,0,0,0,0,0,194,13,0,0,206,52,0,0,156,2,0,0,74,9,0,0,22,5,0,0,0,0,0,0,34,8,0,0,0,0,0,0,0,32,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,160,3,0,0,0,0,0,0,0,0,0,0,0,0,0,192,177,6,0,144,69,2,0,0,0,0,0,0,192,4,0,0,192,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,0,8,0,0,0,0,0,0,0,0,0,176,17,0,0,210,3,0,0,0,0,0,0,0,0,0,0,194,13,0,0,124,27,0,0,166,12,0,0,108,6,0,0,110,11,0,0,0,0,0,0,138,47,0,0,0,0,0,0,0,32,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,28,8,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,56,24,8,0,0,0,0,0,144,84,8,0,208,135,3,0,192,19,8,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,2,11,0,32,0,0,0,0,0,0,0,0,0,0,62,13,0,0,6,1,0,0,0,0,0,0,0,0,0,0,130,13,0,0,114,8,0,0,210,11,0,0,46,7,0,0,246,17,0,0,0,0,0,0,176,18,0,0,0,0,0,0,0,32,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,247,2,0,0,0,0,0,0,0,0,0,0,0,0,0,160,234,7,0,160,223,2,0,0,0,0,0,152,54,6,0,64,10,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,1,17,2,0,0,0,0,0,0,0,0,0,0,0,214,14,0,0,146,3,0,0,0,0,0,0,0,0,0,0,62,25,0,0,154,41,0,0,124,19,0,0,60,6,0,0,250,15,0,0,0,0,0,0,194,0,0,0,0,0,0,0,0,2,0,0,0,1,0,0,0,1,0,0,3,0,0,0,4,0,0,0,48,46,8,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,48,39,8,0,0,0,0,0,144,84,8,0,208,135,3,0,128,32,8,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,2,11,0,32,0,0,0,0,0,0,0,0,0,0,156,28,0,0,152,6,0,0,0,0,0,0,0,0,0,0,168,15,0,0,198,5,0,0,178,3,0,0,46,7,0,0,246,17,0,0,0,0,0,0,176,18,0,0,0,0,0,0,0,32,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,232,3,0,48,117,4,0,0,0,0,0,0,0,0,0,160,234,7,0,112,200,3,0,0,0,0,0,152,54,6,0,64,10,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,17,0,8,0,0,0,0,0,0,0,0,0,0,36,59,0,0,234,38,0,0,0,0,0,0,0,0,0,0,62,25,0,0,144,17,0,0,174,11,0,0,60,6,0,0,250,15,0,0,0,0,0,0,194,0,0,0,0,0,0,0,0,2,0,0,128,1,0,0,0,1,0,0,4,0,0,0,3,0,0,0,168,107,3,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,224,29,6,0,0,0,0,0,216,67,5,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,16,0,0,0,0,0,0,0,0,0,0,154,3,0,0,114,8,0,0,0,0,0,0,0,0,0,0,166,19,0,0,254,18,0,0,28,9,0,0,148,16,0,0,102,2,0,0,130,12,0,0,112,53,0,0,248,173,145,0,0,1,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,23,7,0,96,214,7,0,0,0,0,0,0,0,0,0,184,168,7,0,240,234,6,0,0,0,0,0,152,54,6,0,200,12,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,17,1,0,0,0,0,0,0,0,0,0,0,0,178,6,0,0,88,41,0,0,0,0,0,0,0,0,0,0,198,62,0,0,16,53,0,0,144,14,0,0,230,1,0,0,44,6,0,0,194,15,0,0,0,0,0,0,48,177,145,0,0,2,0,0,128,1,0,0,0,1,0,0,4,0,0,0,3,0,0,0,96,214,7,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,104,118,7,0,0,0,0,0,152,54,6,0,80,67,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,3,17,1,0,0,0,0,0,0,0,0,0,0,0,146,14,0,0,164,1,0,0,0,0,0,0,0,0,0,0,198,62,0,0,16,53,0,0,58,18,0,0,230,1,0,0,44,6,0,0,194,15,0,0,0,0,0,0,48,177,145,0,0,2,0,0,128,1,0,0,0,1,0,0,4,0,0,0,3,0,0,0,216,184,8,0,8,28,8,0,0,0,0,0,0,0,0,0,96,135,2,0,88,118,8,0,0,0,0,0,168,95,8,0,88,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,0,3,4,0,0,0,0,0,0,0,0,0,0,0,14,52,0,0,46,13,0,0,0,0,0,0,0,0,0,0,232,49,0,0,0,0,0,0,148,15,0,0,22,9,0,0,242,1,0,0,50,10,0,0,116,40,0,0,200,176,145,0,0,8,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,60,1,0,8,28,8,0,0,0,0,0,0,0,0,0,96,135,2,0,72,247,8,0,0,0,0,0,168,95,8,0,88,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,0,3,4,0,0,0,0,0,0,0,0,0,0,0,44,4,0,0,240,45,0,0,0,0,0,0,0,0,0,0,232,49,0,0,0,0,0,0,148,15,0,0,22,9,0,0,242,1,0,0,50,10,0,0,116,40,0,0,200,176,145,0,0,8,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,250,1,0,8,28,8,0,0,0,0,0,0,0,0,0,96,135,2,0,24,154,1,0,0,0,0,0,168,95,8,0,88,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,0,3,4,0,0,0,0,0,0,0,0,0,0,0,242,27,0,0,106,37,0,0,0,0,0,0,0,0,0,0,232,49,0,0,0,0,0,0,148,15,0,0,22,9,0,0,242,1,0,0,50,10,0,0,116,40,0,0,200,176,145,0,0,8,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,30,3,0,8,28,8,0,0,0,0,0,0,0,0,0,96,135,2,0,216,113,2,0,0,0,0,0,168,95,8,0,88,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,0,3,4,0,0,0,0,0,0,0,0,0,0,0,114,39,0,0,64,35,0,0,0,0,0,0,0,0,0,0,232,49,0,0,0,0,0,0,148,15,0,0,22,9,0,0,242,1,0,0,50,10,0,0,116,40,0,0,200,176,145,0,0,8,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,116,7,0,8,28,8,0,0,0,0,0,0,0,0,0,96,135,2,0,160,64,7,0,0,0,0,0,168,95,8,0,88,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,3,4,0,0,0,0,0,0,0,0,0,0,0,42,55,0,0,118,44,0,0,0,0,0,0,0,0,0,0,56,18,0,0,0,0,0,0,148,15,0,0,22,9,0,0,242,1,0,0,50,10,0,0,116,40,0,0,200,176,145,0,0,8,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,61,8,0,8,28,8,0,0,0,0,0,0,0,0,0,96,135,2,0,240,8,8,0,0,0,0,0,168,95,8,0,88,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,3,4,0,0,0,0,0,0,0,0,0,0,0,114,45,0,0,32,29,0,0,0,0,0,0,0,0,0,0,56,18,0,0,0,0,0,0,148,15,0,0,22,9,0,0,242,1,0,0,50,10,0,0,116,40,0,0,200,176,145,0,0,8,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,210,7,0,8,28,8,0,0,0,0,0,0,0,0,0,96,135,2,0,200,159,7,0,0,0,0,0,168,95,8,0,88,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,3,4,0,0,0,0,0,0,0,0,0,0,0,102,42,0,0,46,18,0,0,0,0,0,0,0,0,0,0,56,18,0,0,0,0,0,0,148,15,0,0,22,9,0,0,242,1,0,0,50,10,0,0,116,40,0,0,200,176,145,0,0,8,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,28,8,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,104,177,6,0,0,0,0,0,168,95,8,0,88,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,4,0,0,0,0,0,0,3,4,0,0,0,0,0,0,0,0,0,0,0,136,22,0,0,72,37,0,0,0,0,0,0,0,0,0,0,232,49,0,0,0,0,0,0,148,15,0,0,22,9,0,0,242,1,0,0,50,10,0,0,116,40,0,0,200,176,145,0,0,8,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,40,8,0,152,208,3,0,0,0,0,0,0,0,0,0,144,47,2,0,208,244,7,0,0,0,0,0,120,215,1,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,0,22,8,0,0,0,0,0,0,0,0,0,0,0,156,38,0,0,94,28,0,0,0,0,0,0,0,0,0,0,148,56,0,0,184,55,0,0,96,17,0,0,116,14,0,0,42,0,0,0,0,0,0,0,248,19,0,0])
.concat([0,0,0,0,0,32,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,0,158,8,0,152,208,3,0,0,0,0,0,0,0,0,0,144,47,2,0,80,96,8,0,0,0,0,0,72,192,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,0,22,8,0,0,0,0,0,0,0,0,0,0,0,90,9,0,0,22,16,0,0,0,0,0,0,0,0,0,0,148,56,0,0,184,55,0,0,96,17,0,0,116,14,0,0,42,0,0,0,0,0,0,0,248,19,0,0,0,0,0,0,0,32,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,64,117,1,0,152,208,3,0,0,0,0,0,0,0,0,0,144,47,2,0,184,36,1,0,0,0,0,0,192,154,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,4,0,0,0,0,0,0,22,8,0,0,0,0,0,0,0,0,0,0,0,248,39,0,0,160,42,0,0,0,0,0,0,0,0,0,0,148,56,0,0,184,55,0,0,96,17,0,0,116,14,0,0,42,0,0,0,0,0,0,0,248,19,0,0,0,0,0,0,0,32,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,152,219,2,0,152,208,3,0,0,0,0,0,0,0,0,0,144,47,2,0,120,74,2,0,0,0,0,0,120,215,1,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,0,22,8,0,0,0,0,0,0,0,0,0,0,0,248,32,0,0,8,2,0,0,0,0,0,0,0,0,0,0,148,56,0,0,184,55,0,0,96,17,0,0,116,14,0,0,42,0,0,0,0,0,0,0,248,19,0,0,0,0,0,0,0,32,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,152,208,3,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,24,48,6,0,0,0,0,0,72,192,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,4,0,0,0,0,0,0,22,8,0,0,0,0,0,0,0,0,0,0,0,20,33,0,0,246,31,0,0,0,0,0,0,0,0,0,0,148,56,0,0,184,55,0,0,96,17,0,0,116,14,0,0,42,0,0,0,0,0,0,0,248,19,0,0,0,0,0,0,0,32,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,168,225,1,0,232,167,4,0,0,0,0,0,0,0,0,0,184,168,7,0,176,126,1,0,0,0,0,0,72,192,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,22,8,0,0,0,0,0,0,0,0,0,0,0,150,32,0,0,152,3,0,0,0,0,0,0,0,0,0,0,214,50,0,0,46,57,0,0,154,5,0,0,142,19,0,0,88,12,0,0,184,14,0,0,166,47,0,0,0,0,0,0,128,1,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,64,235,2,0,232,167,4,0,0,0,0,0,0,0,0,0,184,168,7,0,8,83,2,0,0,0,0,0,72,192,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,22,8,0,0,0,0,0,0,0,0,0,0,0,52,13,0,0,204,43,0,0,0,0,0,0,0,0,0,0,214,50,0,0,46,57,0,0,154,5,0,0,142,19,0,0,88,12,0,0,184,14,0,0,166,47,0,0,0,0,0,0,128,1,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,88,42,1,0,232,167,4,0,0,0,0,0,0,0,0,0,184,168,7,0,104,231,8,0,0,0,0,0,72,192,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,22,8,0,0,0,0,0,0,0,0,0,0,0,172,19,0,0,134,14,0,0,0,0,0,0,0,0,0,0,214,50,0,0,46,57,0,0,154,5,0,0,142,19,0,0,88,12,0,0,184,14,0,0,166,47,0,0,0,0,0,0,128,1,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,104,165,8,0,232,167,4,0,0,0,0,0,0,0,0,0,184,168,7,0,96,103,8,0,0,0,0,0,192,154,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,0,22,8,0,0,0,0,0,0,0,0,0,0,0,102,34,0,0,206,31,0,0,0,0,0,0,0,0,0,0,214,50,0,0,46,57,0,0,154,5,0,0,142,19,0,0,88,12,0,0,184,14,0,0,166,47,0,0,0,0,0,0,128,1,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,232,167,4,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,56,76,6,0,0,0,0,0,72,192,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,22,8,0,0,0,0,0,0,0,0,0,0,0,92,52,0,0,20,36,0,0,0,0,0,0,0,0,0,0,214,50,0,0,46,57,0,0,154,5,0,0,142,19,0,0,88,12,0,0,184,14,0,0,166,47,0,0,0,0,0,0,128,1,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,184,194,2,0,200,237,2,0,0,0,0,0,0,0,0,0,96,135,2,0,128,177,2,0,0,0,0,0,40,161,4,0,8,153,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,64,0,6,2,0,16,0,0,0,0,0,0,0,0,0,0,126,13,0,0,10,37,0,0,0,0,0,0,0,0,0,0,100,5,0,0,174,55,0,0,250,4,0,0,50,14,0,0,20,14,0,0,0,0,0,0,32,27,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,237,2,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,56,213,2,0,0,0,0,0,40,161,4,0,8,153,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,64,0,6,2,0,16,0,0,0,0,0,0,0,0,0,0,246,59,0,0,172,47,0,0,0,0,0,0,0,0,0,0,100,5,0,0,174,55,0,0,250,4,0,0,50,14,0,0,20,14,0,0,0,0,0,0,32,27,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,28,3,0,240,92,3,0,0,0,0,0,0,0,0,0,104,129,6,0,40,3,3,0,0,0,0,0,136,233,4,0,208,165,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,21,0,0,8,0,0,0,0,0,0,0,0,0,162,50,0,0,74,27,0,0,0,0,0,0,0,0,0,0,110,35,0,0,30,45,0,0,196,10,0,0,198,1,0,0,170,2,0,0,0,0,0,0,236,14,0,0,240,210,148,0,0,128,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,184,64,3,0,240,92,3,0,0,0,0,0,0,0,0,0,104,129,6,0,128,48,3,0,0,0,0,0,136,233,4,0,208,165,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,21,0,0,8,0,0,0,0,0,0,0,0,0,48,39,0,0,70,46,0,0,0,0,0,0,0,0,0,0,110,35,0,0,30,45,0,0,196,10,0,0,198,1,0,0,170,2,0,0,0,0,0,0,236,14,0,0,240,210,148,0,0,128,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,240,92,3,0,0,0,0,0,0,0,0,0,0,0,0,0,104,129,6,0,48,78,3,0,0,0,0,0,136,233,4,0,208,165,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,21,0,0,8,0,0,0,0,0,0,0,0,0,212,46,0,0,0,23,0,0,0,0,0,0,0,0,0,0,110,35,0,0,30,45,0,0,196,10,0,0,198,1,0,0,170,2,0,0,0,0,0,0,236,14,0,0,240,210,148,0,0,128,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,88,254,3,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,208,221,3,0,0,0,0,0,240,191,3,0,0,227,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,1,21,0,0,1,0,0,0,0,0,0,0,0,0,42,17,0,0,0,38,0,0,0,0,0,0,0,0,0,0,220,13,0,0,164,16,0,0,164,16,0,0,248,19,0,0,72,13,0,0,56,10,0,0,96,10,0,0,224,174,145,0,0,6,0,0,240,0,0,0,128,1,0,0,3,0,0,0,4,0,0,0,240,231,6,0,96,245,6,0,0,0,0,0,0,0,0,0,104,174,7,0,224,227,6,0,0,0,0,0,40,161,4,0,80,150,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,64,4,4,2,8,0,0,0,0,0,0,0,0,0,0,0,48,13,0,0,122,29,0,0,0,0,0,0,0,0,0,0,210,8,0,0,6,42,0,0,222,7,0,0,114,17,0,0,134,11,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,224,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,240,238,6,0,96,245,6,0,0,0,0,0,0,0,0,0,104,174,7,0,200,235,6,0,0,0,0,0,40,161,4,0,80,150,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,64,4,4,2,8,0,0,0,0,0,0,0,0,0,0,0,40,46,0,0,138,13,0,0,0,0,0,0,0,0,0,0,210,8,0,0,6,42,0,0,222,7,0,0,114,17,0,0,134,11,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,224,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,96,245,6,0,0,0,0,0,0,0,0,0,0,0,0,0,104,174,7,0,48,241,6,0,0,0,0,0,40,161,4,0,80,150,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,4,4,2,8,0,0,0,0,0,0,0,0,0,0,0,56,61,0,0,2,1,0,0,0,0,0,0,0,0,0,0,210,8,0,0,6,42,0,0,86,8,0,0,114,17,0,0,134,11,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,224,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,184,12,5,0,0,0,0,0,0,0,0,0,0,0,0,0,56,172,6,0,152,197,4,0,0,0,0,0,184,191,7,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,131,0,0,0,2,0,0,0,0,0,0,10,0,16,0,0,0,0,0,0,0,0,0,0,150,13,0,0,180,43,0,0,0,0,0,0,0,0,0,0,236,22,0,0,24,19,0,0,34,1,0,0,8,1,0,0,76,2,0,0,190,17,0,0,4,30,0,0,104,157,215,0,0,4,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,81,6,0,0,0,0,0,0,0,0,0,0,0,0,0,136,232,4,0,208,250,5,0,0,0,0,0,152,190,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,16,0,0,0,0,0,0,0,0,0,0,32,19,0,0,12,18,0,0,0,0,0,0,0,0,0,0,250,33,0,0,190,59,0,0,190,8,0,0,210,18,0,0,126,11,0,0,212,16,0,0,82,63,0,0,16,174,145,0,0,4,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,88,168,4,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,16,137,4,0,0,0,0,0,224,218,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,64,0,0,0,0,0,0,0,0,0,0,178,59,0,0,196,21,0,0,0,0,0,0,0,0,0,0,14,12,0,0,254,27,0,0,10,18,0,0,56,15,0,0,12,17,0,0,0,0,0,0,224,13,0,0,0,0,0,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,200,30,8,0,144,134,2,0,0,0,0,0,0,0,0,0,144,47,2,0,120,233,7,0,0,0,0,0,176,237,2,0,168,84,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,19,4,8,0,0,0,0,0,0,0,0,0,0,176,32,0,0,28,21,0,0,0,0,0,0,0,0,0,0,234,43,0,0,26,15,0,0,168,5,0,0,222,8,0,0,178,15,0,0,174,5,0,0,78,56,0,0,104,173,145,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,104,206,8,0,0,0,0,0,0,0,0,0,0,0,0,0,200,190,7,0,240,141,8,0,0,0,0,0,176,237,2,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,0,19,2,0,0,0,0,0,0,0,0,0,0,0,218,7,0,0,212,4,0,0,0,0,0,0,0,0,0,0,224,53,0,0,14,26,0,0,70,8,0,0,152,11,0,0,102,11,0,0,74,1,0,0,174,15,0,0,64,173,145,0,0,3,0,0,240,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,184,81,8,0,0,0,0,0,0,0,0,0,0,0,0,0,232,233,7,0,72,77,8,0,0,0,0,0,40,161,4,0,192,152,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,9,2,0,64,0,0,0,0,0,0,0,0,0,0,16,46,0,0,212,6,0,0,0,0,0,0,0,0,0,0,114,56,0,0,118,16,0,0,212,19,0,0,42,17,0,0,184,7,0,0,0,0,0,0,216,46,0,0,0,0,0,0,0,6,0,0,224,0,0,0,240,0,0,0,3,0,0,0,4,0,0,0,72,45,5,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,88,15,5,0,0,0,0,0,176,236,4,0,240,185,2,0,192,199,4,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,64,0,0,0,0,0,0,0,0,0,0,126,5,0,0,46,35,0,0,0,0,0,0,0,0,0,0,14,12,0,0,188,43,0,0,248,4,0,0,56,15,0,0,12,17,0,0,0,0,0,0,224,13,0,0,0,0,0,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,168,38,7,0,240,181,7,0,0,0,0,0,0,0,0,0,96,135,2,0,184,250,6,0,0,0,0,0,176,237,2,0,168,84,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,19,4,0,0,0,0,0,0,0,0,0,0,0,40,23,0,0,32,23,0,0,0,0,0,0,0,0,0,0,150,6,0,0,28,32,0,0,92,19,0,0,222,8,0,0,178,15,0,0,206,5,0,0,78,56,0,0,104,173,145,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,240,181,7,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,88,87,7,0,0,0,0,0,176,237,2,0,168,84,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,19,4,0,0,0,0,0,0,0,0,0,0,0,124,25,0,0,102,37,0,0,0,0,0,0,0,0,0,0,150,6,0,0,28,32,0,0,92,19,0,0,222,8,0,0,178,15,0,0,206,5,0,0,78,56,0,0,104,173,145,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,64,88,2,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,192,72,2,0,0,0,0,0,56,60,2,0,0,227,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,4,0,0,0,0,0,1,21,0,0,1,0,0,0,0,0,0,0,0,0,222,52,0,0,140,27,0,0,0,0,0,0,0,0,0,0,74,30,0,0,4,44,0,0,106,15,0,0,248,19,0,0,72,13,0,0,198,3,0,0,96,10,0,0,224,174,145,0,0,2,0,0,128,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,192,139,2,0,112,166,3,0,0,0,0,0,0,0,0,0,104,221,5,0,192,128,2,0,0,0,0,0,192,154,4,0,48,178,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,0,10,0,8,0,0,0,0,0,0,0,0,0,0,8,62,0,0,54,5,0,0,0,0,0,0,0,0,0,0,82,46,0,0,100,14,0,0,124,3,0,0,188,13,0,0,2,7,0,0,0,0,0,0,0,33,0,0,0,0,0,0,0,2,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,202,8,0,0,0,0,0,0,0,0,0,0,0,0,0,232,233,7,0,64,194,6,0,0,0,0,0,152,54,6,0,136,11,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,2,0,0,0,0,0,2,17,0,8,0,0,0,0,0,0,0,0,0,0,36,24,0,0,32,30,0,0,0,0,0,0,0,0,0,0,188,45,0,0,86,29,0,0,102,6,0,0,150,14,0,0,160,6,0,0,224,14,0,0,222,61,0,0,40,177,145,0,4,1,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,98,7,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,88,48,7,0,0,0,0,0,32,0,1,0,240,185,2,0,216,3,7,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,98,63,0,0,172,25,0,0,0,0,0,0,0,0,0,0,222,45,0,0,88,12,0,0,128,17,0,0,14,3,0,0,164,11,0,0,42,4,0,0,242,13,0,0,104,174,145,0,0,16,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,184,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,144,175,8,0,0,0,0,0,80,167,8,0,0,227,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,1,21,0,0,1,0,0,0,0,0,0,0,0,0,192,30,0,0,16,18,0,0,0,0,0,0,0,0,0,0,78,50,0,0,76,19,0,0,38,8,0,0,248,19,0,0,44,3,0,0,198,3,0,0,96,10,0,0,224,174,145,0,0,2,0,0,240,0,0,0,128,1,0,0,3,0,0,0,4,0,0,0,120,195,1,0,72,98,1,0,0,0,0,0,0,0,0,0,144,47,2,0,240,19,1,0,80,152,4,0,160,150,4,0,16,128,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,2,4,0,8,0,0,0,0,0,0,0,0,0,0,16,37,0,0,226,39,0,0,0,0,0,0,0,0,0,0,88,21,0,0,84,51,0,0,48,0,0,0,34,15,0,0,244,18,0,0,56,6,0,0,66,55,0,0,32,146,215,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,112,221,2,0,0,244,3,0,0,0,0,0,0,0,0,0,144,47,2,0,16,76,2,0,0,0,0,0,224,189,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,10,0,16,0,0,0,0,0,0,0,0,0,0,26,11,0,0,124,29,0,0,0,0,0,0,0,0,0,0,88,51,0,0,18,17,0,0,176,18,0,0,122,6,0,0,220,12,0,0,80,15,0,0,102,43,0,0,160,174,145,0,0,8,0,0,96,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,0,244,3,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,192,52,6,0,0,0,0,0,224,189,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,16,0,0,0,0,0,0,0,0,0,0,88,2,0,0,6,15,0,0,0,0,0,0,0,0,0,0,88,51,0,0,18,17,0,0,176,18,0,0,122,6,0,0,220,12,0,0,80,15,0,0,102,43,0,0,160,174,145,0,0,8,0,0,96,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,88,49,1,0,48,71,8,0,0,0,0,0,0,0,0,0,184,168,7,0,24,237,8,0,0,0,0,0,32,0,1,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,38,48,0,0,184,30,0,0,0,0,0,0,0,0,0,0,160,54,0,0,80,41,0,0,2,0,0,0,202,13,0,0,48,17,0,0,0,0,0,0,228,39,0,0,0,0,0,0,0,4,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,96,2,0,48,71,8,0,0,0,0,0,0,0,0,0,184,168,7,0,112,234,1,0,0,0,0,0,192,154,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,48,51,0,0,208,0,0,0,0,0,0,0,0,0,0,0,134,33,0,0,206,51,0,0,66,0,0,0,200,15,0,0,248,3,0,0,0,0,0,0,192,3,0,0,0,0,0,0,0,4,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,130,5,0,48,71,8,0,0,0,0,0,0,0,0,0,184,168,7,0,176,254,4,0,0,0,0,0,192,154,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,128,18,0,0,210,9,0,0,0,0,0,0,0,0,0,0,134,33,0,0,206,51,0,0,66,0,0,0,200,15,0,0,248,3,0,0,0,0,0,0,192,3,0,0,0,0,0,0,0,4,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,235,1,0,48,71,8,0,0,0,0,0,0,0,0,0,184,168,7,0,72,138,1,0,0,0,0,0,32,0,1,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,8,0,0,2,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,38,0,0,0,4,31,0,0,0,0,0,0,0,0,0,0,160,54,0,0,80,41,0,0,188,0,0,0,202,13,0,0,48,17,0,0,0,0,0,0,228,39,0,0,0,0,0,0,0,4,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,251,2,0,48,71,8,0,0,0,0,0,0,0,0,0,184,168,7,0,240,96,2,0,0,0,0,0,32,0,1,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,236,43,0,0,192,14,0,0,0,0,0,0,0,0,0,0,160,54,0,0,80,41,0,0,188,0,0,0,202,13,0,0,48,17,0,0,0,0,0,0,228,39,0,0,0,0,0,0,0,4,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,71,8,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,56,116,6,0,0,0,0,0,32,0,1,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,8,0,0,2,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,192,12,0,0,12,36,0,0,0,0,0,0,0,0,0,0,160,54,0,0,80,41,0,0,188,0,0,0,202,13,0,0,48,17,0,0,0,0,0,0,228,39,0,0,0,0,0,0,0,4,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,110,8,0,152,203,8,0,0,0,0,0,0,0,0,0,160,234,7,0,32,104,8,0,0,0,0,0,184,193,8,0,192,152,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,9,2,0,8,0,0,0,0,0,0,0,0,0,0,8,1,0,0,202,21,0,0,0,0,0,0,0,0,0,0,36,47,0,0,82,7,0,0,94,18,0,0,42,17,0,0,184,7,0,0,0,0,0,0,216,46,0,0,0,0,0,0,0,6,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,188,8,0,152,203,8,0,0,0,0,0,0,0,0,0,160,234,7,0,80,183,8,0,0,0,0,0,184,193,8,0,192,152,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,9,2,0,8,0,0,0,0,0,0,0,0,0,0,232,15,0,0,88,39,0,0,0,0,0,0,0,0,0,0,36,47,0,0,24,14,0,0,118,14,0,0,42,17,0,0,184,7,0,0,0,0,0,0,216,46,0,0,0,0,0,0,0,6,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,123,8,0,152,203,8,0,0,0,0,0,0,0,0,0,160,234,7,0,88,117,8,0,0,0,0,0,192,154,4,0,192,152,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,9,2,0,8,0,0,0,0,0,0,0,0,0,0,120,32,0,0,228,22,0,0,0,0,0,0,0,0,0,0,36,47,0,0,194,14,0,0,118,14,0,0,42,17,0,0,184,7,0,0,0,0,0,0,216,46,0,0,0,0,0,0,0,6,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,133,8,0,152,203,8,0,0,0,0,0,0,0,0,0,160,234,7,0,64,128,8,0,0,0,0,0,184,193,8,0,192,152,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,9,2,0,8,0,0,0,0,0,0,0,0,0,0,210,35,0,0,140,24,0,0,0,0,0,0,0,0,0,0,36,47,0,0,24,14,0,0,30,9,0,0,42,17,0,0,184,7,0,0,0,0,0,0,216,46,0,0,0,0,0,0,0,6,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,144,8,0,152,203,8,0,0,0,0,0,0,0,0,0,160,234,7,0,64,139,8,0,0,0,0,0,184,193,8,0,192,152,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,9,2,0,8,0,0,0,0,0,0,0,0,0,0,84,59,0,0,246,47,0,0,0,0,0,0,0,0,0,0,36,47,0,0,194,14,0,0,118,14,0,0,42,17,0,0,184,7,0,0,0,0,0,0,216,46,0,0,0,0,0,0,0,6,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,156,8,0,152,203,8,0,0,0,0,0,0,0,0,0,160,234,7,0,128,150,8,0,0,0,0,0,184,193,8,0,192,152,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,9,2,0,8,0,0,0,0,0,0,0,0,0,0,168,53,0,0,20,33,0,0,0,0,0,0,0,0,0,0,36,47,0,0,24,14,0,0,68,6,0,0,42,17,0,0,184,7,0,0,0,0,0,0,216,46,0,0,0,0,0,0,0,6,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,175,8,0,152,203,8,0,0,0,0,0,0,0,0,0,160,234,7,0,72,166,8,0,0,0,0,0,184,193,8,0,192,152,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,9,2,0,8,0,0,0,0,0,0,0,0,0,0,240,26,0,0,122,9,0,0,0,0,0,0,0,0,0,0,36,47,0,0,24,14,0,0,238,11,0,0,42,17,0,0,184,7,0,0,0,0,0,0,216,46,0,0,0,0,0,0,0,6,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,203,8,0,0,0,0,0,0,0,0,0,0,0,0,0,160,234,7,0,240,198,8,0,0,0,0,0,184,193,8,0,192,152,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,9,2,0,8,0,0,0,0,0,0,0,0,0,0,104,29,0,0,142,3,0,0,0,0,0,0,0,0,0,0,36,47,0,0,24,14,0,0,198,12,0,0,42,17,0,0,184,7,0,0,0,0,0,0,216,46,0,0,0,0,0,0,0,6,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,94,8,0,152,203,8,0,0,0,0,0,0,0,0,0,160,234,7,0,216,87,8,0,0,0,0,0,184,193,8,0,192,152,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,9,2,0,8,0,0,0,0,0,0,0,0,0,0,238,16,0,0,80,39,0,0,0,0,0,0,0,0,0,0,36,47,0,0,180,1,0,0,68,6,0,0,42,17,0,0,184,7,0,0,0,0,0,0,216,46,0,0,0,0,0,0,0,6,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,227,1,0,200,33,7,0,0,0,0,0,0,0,0,0,104,174,7,0,200,211,1,0,0,0,0,0,104,24,4,0,248,206,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,1,0,3,2,0,8,0,0,0,0,0,0,0,0,0,0,80,6,0,0,78,45,0,0,0,0,0,0,0,0,0,0,50,61,0,0,162,46,0,0,204,18,0,0,114,17,0,0,144,2,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,9,7,0,200,33,7,0,0,0,0,0,0,0,0,0,104,174,7,0,184,2,7,0,0,0,0,0,104,24,4,0,80,150,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,64,4,4,2,0,8,0,0,0,0,0,0,0,0,0,0,26,45,0,0,78,44,0,0,0,0,0,0,0,0,0,0,210,8,0,0,160,4,0,0,220,2,0,0,114,17,0,0,134,11,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,19,7,0,200,33,7,0,0,0,0,0,0,0,0,0,104,174,7,0,112,14,7,0,0,0,0,0,104,24,4,0,80,150,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,64,4,4,2,0,8,0,0,0,0,0,0,0,0,0,0,36,29,0,0,206,7,0,0,0,0,0,0,0,0,0,0,210,8,0,0,160,4,0,0,220,2,0,0,114,17,0,0,134,11,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,26,7,0,200,33,7,0,0,0,0,0,0,0,0,0,104,174,7,0,32,24,7,0,0,0,0,0,104,24,4,0,80,150,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,68,0,4,2,0,8,0,0,0,0,0,0,0,0,0,0,248,12,0,0,146,14,0,0,0,0,0,0,0,0,0,0,210,8,0,0,160,4,0,0,170,11,0,0,114,17,0,0,134,11,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,13,2,0,200,33,7,0,0,0,0,0,0,0,0,0,104,174,7,0,40,248,1,0,0,0,0,0,104,24,4,0,248,206,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,64,0,3,2,0,8,0,0,0,0,0,0,0,0,0,0,202,39,0,0,174,5,0,0,0,0,0,0,0,0,0,0,50,61,0,0,162,46,0,0,204,18,0,0,114,17,0,0,144,2,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,33,7,0,0,0,0,0,0,0,0,0,0,0,0,0,104,174,7,0,128,29,7,0,0,0,0,0,104,24,4,0,80,150,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,4,4,2,0,8,0,0,0,0,0,0,0,0,0,0,234,22,0,0,204,33,0,0,0,0,0,0,0,0,0,0,210,8,0,0,160,4,0,0,34,0,0,0,114,17,0,0,134,11,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,211,1,0,0,0,0,0,0,0,0,0,0,0,0,0,168,163,7,0,144,33,1,0,0,0,0,0,240,222,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,16,0,0,0,0,0,0,0,0,0,0,26,10,0,0,86,13,0,0,0,0,0,0,0,0,0,0,168,23,0,0,222,33,0,0,236,4,0,0,24,4,0,0,186,10,0,0,0,0,0,0,130,3,0,0,0,0,0,0,0,3,0,0,128,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,120,92,1,0,40,190,1,0,0,0,0,0,0,0,0,0,168,163,7,0,24,86,1,0,0,0,0,0,192,223,4,0,0,151,3,0,24,78,1,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,9,8,0,0,0,0,0,0,0,0,0,0,0,222,26,0,0,98,16,0,0,0,0,0,0,0,0,0,0,38,11,0,0,244,59,0,0,82,2,0,0,228,2,0,0,0,13,0,0,0,0,0,0,166,23,0,0,240,121,145,0,0,0,4,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,160,1,0,40,190,1,0,0,0,0,0,0,0,0,0,168,163,7,0,48,151,1,0,0,0,0,0,192,223,4,0,0,151,3,0,160,141,1,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,9,8,0,0,0,0,0,0,0,0,0,0,0,50,63,0,0,88,25,0,0,0,0,0,0,0,0,0,0,38,11,0,0,244,59,0,0,82,2,0,0,228,2,0,0,0,13,0,0,0,0,0,0,166,23,0,0,240,121,145,0,0,0,4,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,43,7,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,40,215,6,0,0,0,0,0,144,84,8,0,128,194,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,3,11,1,0,0,0,0,0,0,0,0,0,0,0,104,25,0,0,198,19,0,0,0,0,0,0,0,0,0,0,106,23,0,0,168,38,0,0,60,8,0,0,70,10,0,0,244,14,0,0,0,0,0,0,122,15,0,0,0,0,0,0,0,32,0,0,128,2,0,0,240,0,0,0,8,0,0,0,3,0,0,0,168,69,1,0,200,109,1,0,0,0,0,0,0,0,0,0,216,194,1,0,56,64,1,0,0,0,0,0,128,90,1,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,8,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,124,37,0,0,108,28,0,0,0,0,0,0,0,0,0,0,114,10,0,0,94,52,0,0,8,7,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,200,109,1,0,0,0,0,0,0,0,0,0,0,0,0,0,216,194,1,0,128,98,1,0,0,0,0,0,128,90,1,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,8,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,252,1,0,0,252,32,0,0,0,0,0,0,0,0,0,0,114,10,0,0,94,52,0,0,8,7,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,88,246,2,0,208,37,5,0,0,0,0,0,0,0,0,0,232,233,7,0,232,91,2,0,0,0,0,0,48,244,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,1,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,158,41,0,0,30,46,0,0,0,0,0,0,0,0,0,0,102,2,0,0,78,8,0,0,124,1,0,0,224,10,0,0,162,19,0,0,232,16,0,0,126,41,0,0,168,175,145,0,8,0,0,0,0,1,0,0,0,1,0,0,4,0,0,0,3,0,0,0,208,37,5,0,0,0,0,0,0,0,0,0,0,0,0,0,232,233,7,0,168,99,6,0,0,0,0,0,48,244,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,240,32,0,0,132,23,0,0,0,0,0,0,0,0,0,0,102,2,0,0,78,8,0,0,152,13,0,0,224,10,0,0,162,19,0,0,232,16,0,0,126,41,0,0,168,175,145,0,8,0,0,0,0,1,0,0,0,1,0,0,4,0,0,0,3,0,0,0,88,160,7,0,184,247,8,0,0,0,0,0,0,0,0,0,104,174,7,0,48,116,7,0,0,0,0,0,168,95,8,0,80,61,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,3,1,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,224,30,0,0,0,0,0,0,0,0,0,0,176,49,0,0,20,10,0,0,44,19,0,0,156,9,0,0,198,15,0,0,232,8,0,0,42,6,0,0,216,176,145,0,0,4,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,9,8,0,184,247,8,0,0,0,0,0,0,0,0,0,104,174,7,0,192,210,7,0,0,0,0,0,168,95,8,0,80,61,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,3,1,0,0,0,0,0,0,0,0,0,0,0,74,23,0,0,60,13,0,0,0,0,0,0,0,0,0,0,176,49,0,0,20,10,0,0,44,19,0,0,156,9,0,0,198,15,0,0,232,8,0,0,42,6,0,0,216,176,145,0,0,4,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,247,8,0,0,0,0,0,0,0,0,0,0,0,0,0,104,174,7,0,208,118,8,0,0,0,0,0,168,95,8,0,80,61,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,3,1,0,0,0,0,0,0,0,0,0,0,0,58,14,0,0,222,0,0,0,0,0,0,0,0,0,0,0,176,49,0,0,20,10,0,0,44,19,0,0,156,9,0,0,198,15,0,0,232,8,0,0,42,6,0,0,216,176,145,0,0,4,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,142,5,0,160,139,5,0,0,0,0,0,0,0,0,0,96,159,4,0,48,135,5,0,0,0,0,0,192,154,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,0,0,0,2,0,0,0,0,0,0,16,0,64,0,0,0,0,0,0,0,0,0,0,134,43,0,0,246,15,0,0,0,0,0,0,0,0,0,0,86,51,0,0,22,14,0,0,206,9,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,72,99,2,0,136,176,2,0,0,0,0,0,0,0,0,0,184,168,7,0,96,83,2,0,0,0,0,0,128,161,4,0,128,194,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,3,11,0,16,0,0,0,0,0,0,0,0,0,0,18,50,0,0,48,22,0,0,0,0,0,0,0,0,0,0,34,47,0,0,234,53,0,0,104,1,0,0,46,1,0,0,106,16,0,0,0,0,0,0,78,54,0,0,0,0,0,0,0,32,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,24,124,2,0,136,176,2,0,0,0,0,0,0,0,0,0,184,168,7,0,248,109,2,0,0,0,0,0,144,84,8,0,128,194,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,3,11,0,16,0,0,0,0,0,0,0,0,0,0,146,7,0,0,140,32,0,0,0,0,0,0,0,0,0,0,34,47,0,0,54,51,0,0,104,1,0,0,46,1,0,0,106,16,0,0,0,0,0,0,78,54,0,0,0,0,0,0,0,32,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,176,148,2,0,136,176,2,0,0,0,0,0,0,0,0,0,184,168,7,0,104,136,2,0,0,0,0,0,144,84,8,0,128,194,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,3,11,0,16,0,0,0,0,0,0,0,0,0,0,66,28,0,0,216,37,0,0,0,0,0,0,0,0,0,0,34,47,0,0,54,51,0,0,104,1,0,0,46,1,0,0,106,16,0,0,0,0,0,0,78,54,0,0,0,0,0,0,0,32,0,0,240,0,0,0,64,1,0,0])
.concat([3,0,0,0,4,0,0,0,136,176,2,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,168,161,2,0,0,0,0,0,168,183,7,0,128,194,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,3,11,0,16,0,0,0,0,0,0,0,0,0,0,254,61,0,0,236,22,0,0,0,0,0,0,0,0,0,0,34,47,0,0,172,7,0,0,104,1,0,0,46,1,0,0,106,16,0,0,0,0,0,0,78,54,0,0,0,0,0,0,0,32,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,184,77,2,0,72,27,4,0,0,0,0,0,0,0,0,0,32,127,5,0,168,219,1,0,120,161,2,0,136,121,1,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,0,10,2,0,0,0,0,0,0,0,0,0,0,0,174,28,0,0,76,44,0,0,0,0,0,0,0,0,0,0,240,50,0,0,66,13,0,0,234,5,0,0,206,15,0,0,142,1,0,0,178,12,0,0,242,12,0,0,208,174,145,0,0,16,0,0,224,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,72,27,4,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,16,57,6,0,120,161,2,0,16,191,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,0,10,2,0,0,0,0,0,0,0,0,0,0,0,200,51,0,0,22,43,0,0,0,0,0,0,0,0,0,0,240,50,0,0,66,13,0,0,234,5,0,0,206,15,0,0,142,1,0,0,178,12,0,0,242,12,0,0,208,174,145,0,0,16,0,0,224,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,56,23,4,0,32,77,4,0,0,0,0,0,0,0,0,0,184,168,7,0,88,248,3,0,0,0,0,0,128,161,4,0,168,196,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,5,11,8,0,0,0,0,0,0,0,0,0,0,0,4,57,0,0,142,35,0,0,0,0,0,0,0,0,0,0,102,1,0,0,20,17,0,0,146,1,0,0,178,11,0,0,82,0,0,0,238,10,0,0,188,1,0,0,0,0,0,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,214,3,0,32,77,4,0,0,0,0,0,0,0,0,0,184,168,7,0,128,186,3,0,0,0,0,0,144,84,8,0,168,196,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,5,11,8,0,0,0,0,0,0,0,0,0,0,0,68,39,0,0,174,38,0,0,0,0,0,0,0,0,0,0,102,1,0,0,20,17,0,0,146,1,0,0,178,11,0,0,82,0,0,0,238,10,0,0,188,1,0,0,0,0,0,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,77,4,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,88,50,4,0,0,0,0,0,168,183,7,0,168,196,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,5,11,8,0,0,0,0,0,0,0,0,0,0,0,126,58,0,0,248,31,0,0,0,0,0,0,0,0,0,0,102,1,0,0,20,17,0,0,146,1,0,0,178,11,0,0,82,0,0,0,238,10,0,0,188,1,0,0,0,0,0,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,53,2,0,80,172,2,0,0,0,0,0,80,172,2,0,144,47,2,0,232,196,1,0,120,155,4,0,0,100,1,0,224,127,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,1,4,2,0,0,0,0,0,0,0,0,0,0,0,20,18,0,0,56,41,0,0,58,63,0,0,202,34,0,0,36,16,0,0,216,60,0,0,142,17,0,0,32,7,0,0,84,0,0,0,52,0,0,0,70,36,0,0,32,146,215,0,0,8,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,32,22,1,0,80,172,2,0,0,0,0,0,80,172,2,0,144,47,2,0,152,213,8,0,120,155,4,0,160,150,4,0,224,127,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,1,4,2,0,0,0,0,0,0,0,0,0,0,0,6,36,0,0,100,41,0,0,58,63,0,0,202,34,0,0,36,16,0,0,26,40,0,0,142,17,0,0,32,7,0,0,84,0,0,0,52,0,0,0,70,36,0,0,32,146,215,0,0,8,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,80,172,2,0,0,0,0,0,0,0,0,0,80,172,2,0,144,47,2,0,8,238,5,0,120,155,4,0,160,150,4,0,224,127,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,1,4,2,0,0,0,0,0,0,0,0,0,0,0,124,24,0,0,180,21,0,0,58,63,0,0,202,34,0,0,36,16,0,0,26,40,0,0,142,17,0,0,32,7,0,0,84,0,0,0,52,0,0,0,70,36,0,0,32,146,215,0,0,8,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,144,250,8,0,216,196,8,0,0,0,0,0,0,0,0,0,104,174,7,0,240,186,8,0,0,0,0,0,64,63,1,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,6,17,4,0,0,0,0,0,0,0,0,0,0,0,224,38,0,0,104,0,0,0,0,0,0,0,0,0,0,0,90,60,0,0,192,5,0,0,224,16,0,0,36,2,0,0,56,3,0,0,0,0,0,0,88,9,0,0,0,0,0,0,32,2,0,0,0,1,0,0,0,1,0,0,4,0,0,0,3,0,0,0,96,1,2,0,216,196,8,0,0,0,0,0,0,0,0,0,104,174,7,0,88,158,1,0,0,0,0,0,64,63,1,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,6,17,4,0,0,0,0,0,0,0,0,0,0,0,126,15,0,0,46,40,0,0,0,0,0,0,0,0,0,0,90,60,0,0,192,5,0,0,224,16,0,0,36,2,0,0,56,3,0,0,0,0,0,0,88,9,0,0,0,0,0,0,32,2,0,0,0,1,0,0,0,1,0,0,4,0,0,0,3,0,0,0,248,121,8,0,216,196,8,0,0,0,0,0,0,0,0,0,104,174,7,0,160,63,8,0,0,0,0,0,152,54,6,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,6,17,4,0,0,0,0,0,0,0,0,0,0,0,20,56,0,0,162,14,0,0,0,0,0,0,0,0,0,0,90,60,0,0,192,5,0,0,224,16,0,0,36,2,0,0,56,3,0,0,0,0,0,0,88,9,0,0,0,0,0,0,32,2,0,0,0,1,0,0,0,1,0,0,4,0,0,0,3,0,0,0,128,38,3,0,216,196,8,0,0,0,0,0,0,0,0,0,104,174,7,0,248,119,2,0,0,0,0,0,152,54,6,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,6,17,4,0,0,0,0,0,0,0,0,0,0,0,28,2,0,0,56,10,0,0,0,0,0,0,0,0,0,0,90,60,0,0,192,5,0,0,224,16,0,0,36,2,0,0,56,3,0,0,0,0,0,0,88,9,0,0,0,0,0,0,32,2,0,0,0,1,0,0,0,1,0,0,4,0,0,0,3,0,0,0,216,196,8,0,0,0,0,0,0,0,0,0,0,0,0,0,104,174,7,0,224,193,6,0,0,0,0,0,152,54,6,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,6,17,4,0,0,0,0,0,0,0,0,0,0,0,104,9,0,0,208,29,0,0,0,0,0,0,0,0,0,0,90,60,0,0,192,5,0,0,224,16,0,0,36,2,0,0,56,3,0,0,0,0,0,0,88,9,0,0,0,0,0,0,32,2,0,0,0,1,0,0,0,1,0,0,4,0,0,0,3,0,0,0,80,185,8,0,112,80,8,0,0,0,0,0,0,0,0,0,64,164,6,0,16,119,8,0,0,0,0,0,192,154,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,0,0,0,2,0,0,0,0,0,0,3,0,0,8,0,0,0,0,0,0,0,0,0,12,15,0,0,62,24,0,0,0,0,0,0,0,0,0,0,132,33,0,0,30,10,0,0,242,17,0,0,176,19,0,0,58,4,0,0,90,2,0,0,80,58,0,0,248,176,145,0,64,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,176,32,3,0,112,90,8,0,0,0,0,0,0,0,0,0,144,47,2,0,112,116,2,0,0,0,0,0,168,95,8,0,72,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,0,3,4,0,0,0,0,0,0,0,0,0,0,0,200,4,0,0,212,14,0,0,0,0,0,0,0,0,0,0,254,59,0,0,0,0,0,0,216,18,0,0,214,8,0,0,238,14,0,0,80,10,0,0,198,2,0,0,0,177,145,0,0,8,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,62,8,0,112,90,8,0,0,0,0,0,0,0,0,0,144,47,2,0,232,9,8,0,0,0,0,0,168,95,8,0,72,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,3,4,0,0,0,0,0,0,0,0,0,0,0,44,2,0,0,38,25,0,0,0,0,0,0,0,0,0,0,124,26,0,0,0,0,0,0,216,18,0,0,214,8,0,0,238,14,0,0,80,10,0,0,198,2,0,0,0,177,145,0,0,8,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,61,1,0,112,90,8,0,0,0,0,0,0,0,0,0,144,47,2,0,0,249,8,0,0,0,0,0,168,95,8,0,72,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,3,4,0,0,0,0,0,0,0,0,0,0,0,26,53,0,0,40,11,0,0,0,0,0,0,0,0,0,0,124,26,0,0,0,0,0,0,216,18,0,0,214,8,0,0,238,14,0,0,80,10,0,0,198,2,0,0,0,177,145,0,0,8,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,185,8,0,112,90,8,0,0,0,0,0,0,0,0,0,144,47,2,0,120,119,8,0,0,0,0,0,168,95,8,0,72,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,3,4,0,0,0,0,0,0,0,0,0,0,0,36,43,0,0,114,9,0,0,0,0,0,0,0,0,0,0,124,26,0,0,0,0,0,0,216,18,0,0,214,8,0,0,238,14,0,0,80,10,0,0,198,2,0,0,0,177,145,0,0,8,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,253,1,0,112,90,8,0,0,0,0,0,0,0,0,0,144,47,2,0,152,155,1,0,0,0,0,0,168,95,8,0,72,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,3,4,0,0,0,0,0,0,0,0,0,0,0,82,60,0,0,254,17,0,0,0,0,0,0,0,0,0,0,124,26,0,0,0,0,0,0,216,18,0,0,214,8,0,0,238,14,0,0,80,10,0,0,198,2,0,0,0,177,145,0,0,8,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,90,8,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,88,184,6,0,0,0,0,0,168,95,8,0,72,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,4,0,0,0,0,0,0,3,4,0,0,0,0,0,0,0,0,0,0,0,208,20,0,0,120,14,0,0,0,0,0,0,0,0,0,0,254,59,0,0,0,0,0,0,216,18,0,0,214,8,0,0,238,14,0,0,80,10,0,0,198,2,0,0,0,177,145,0,0,8,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,163,2,0,248,212,1,0,0,0,0,0,0,0,0,0,184,168,7,0,120,32,2,0,0,0,0,0,176,237,2,0,168,84,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,0,19,2,0,0,0,0,0,0,0,0,0,0,0,60,28,0,0,182,40,0,0,0,0,0,0,0,0,0,0,170,36,0,0,16,3,0,0,210,19,0,0,236,18,0,0,92,5,0,0,208,1,0,0,246,13,0,0,32,173,145,0,0,5,0,0,240,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,80,183,1,0,248,212,1,0,0,0,0,0,0,0,0,0,184,168,7,0,176,86,1,0,0,0,0,0,168,138,8,0,168,84,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,0,19,2,0,0,0,0,0,0,0,0,0,0,0,34,50,0,0,46,21,0,0,0,0,0,0,0,0,0,0,170,36,0,0,16,3,0,0,190,2,0,0,236,18,0,0,92,5,0,0,208,1,0,0,246,13,0,0,32,173,145,0,0,5,0,0,240,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,248,212,1,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,8,168,5,0,0,0,0,0,176,237,2,0,168,84,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,0,19,2,0,0,0,0,0,0,0,0,0,0,0,200,58,0,0,234,13,0,0,0,0,0,0,0,0,0,0,170,36,0,0,16,3,0,0,190,2,0,0,236,18,0,0,92,5,0,0,208,1,0,0,246,13,0,0,32,173,145,0,0,5,0,0,240,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,224,39,8,0,240,68,8,0,0,0,0,0,0,0,0,0,104,221,5,0,0,34,8,0,0,0,0,0,208,47,8,0,80,164,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,0,10,4,0,0,0,0,0,0,0,0,0,0,0,154,32,0,0,220,33,0,0,0,0,0,0,0,0,0,0,244,56,0,0,84,17,0,0,248,18,0,0,56,12,0,0,212,3,0,0,18,2,0,0,0,0,0,0,0,0,0,0,0,4,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,104,60,8,0,240,68,8,0,0,0,0,0,0,0,0,0,104,221,5,0,8,55,8,0,0,0,0,0,208,47,8,0,80,164,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,0,10,4,0,0,0,0,0,0,0,0,0,0,0,188,52,0,0,128,45,0,0,0,0,0,0,0,0,0,0,244,56,0,0,84,17,0,0,248,18,0,0,56,12,0,0,212,3,0,0,18,2,0,0,0,0,0,0,0,0,0,0,0,4,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,248,28,8,0,240,68,8,0,0,0,0,0,0,0,0,0,104,221,5,0,232,24,8,0,120,155,4,0,24,21,8,0,80,164,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,0,10,4,0,0,0,0,0,0,0,0,0,0,0,24,54,0,0,74,32,0,0,0,0,0,0,0,0,0,0,244,56,0,0,84,17,0,0,0,11,0,0,56,12,0,0,212,3,0,0,18,2,0,0,0,0,0,0,0,0,0,0,0,4,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,240,68,8,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,80,65,8,0,0,0,0,0,232,196,4,0,80,164,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,0,10,4,0,0,0,0,0,0,0,0,0,0,0,170,50,0,0,86,26,0,0,0,0,0,0,0,0,0,0,244,56,0,0,84,17,0,0,248,18,0,0,56,12,0,0,212,3,0,0,18,2,0,0,0,0,0,0,0,0,0,0,0,4,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,208,143,2,0,0,171,7,0,0,0,0,0,0,0,0,0,240,3,2,0,152,151,4,0,0,0,0,0,160,150,4,0,16,128,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,2,4,2,0,0,0,0,0,0,0,0,0,0,0,114,16,0,0,210,46,0,0,0,0,0,0,0,0,0,0,64,35,0,0,220,6,0,0,154,17,0,0,90,9,0,0,186,11,0,0,190,19,0,0,8,5,0,0,32,146,215,0,0,8,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,24,145,8,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,32,140,8,0,120,155,4,0,72,129,8,0,0,227,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,21,0,0,1,0,0,0,0,0,0,0,0,0,224,42,0,0,12,19,0,0,0,0,0,0,0,0,0,0,86,43,0,0,78,31,0,0,108,4,0,0,248,19,0,0,196,3,0,0,56,10,0,0,96,10,0,0,224,174,145,0,0,6,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,216,8,0,24,232,8,0,0,0,0,0,0,0,0,0,64,164,6,0,224,207,8,0,0,0,0,0,40,161,4,0,192,152,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,9,2,0,0,1,0,0,0,0,0,0,0,0,0,252,37,0,0,54,40,0,0,0,0,0,0,0,0,0,0,156,52,0,0,176,55,0,0,152,9,0,0,42,17,0,0,184,7,0,0,0,0,0,0,216,46,0,0,0,0,0,0,0,6,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,24,232,8,0,0,0,0,0,0,0,0,0,0,0,0,0,64,164,6,0,64,223,8,0,0,0,0,0,40,161,4,0,192,152,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,9,2,0,0,1,0,0,0,0,0,0,0,0,0,216,14,0,0,216,11,0,0,0,0,0,0,0,0,0,0,156,52,0,0,176,55,0,0,238,8,0,0,42,17,0,0,184,7,0,0,0,0,0,0,216,46,0,0,0,0,0,0,0,6,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,0,234,2,0,200,151,4,0,0,0,0,0,0,0,0,0,144,139,6,0,56,82,2,0,0,0,0,0,32,227,4,0,136,153,3,0,184,223,1,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,6,0,16,0,0,0,0,0,0,0,0,0,0,154,53,0,0,98,13,0,0,0,0,0,0,0,0,0,0,2,44,0,0,0,0,0,0,102,15,0,0,58,12,0,0,20,8,0,0,100,18,0,0,190,56,0,0,96,49,216,0,0,128,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,200,151,4,0,0,0,0,0,0,0,0,0,0,0,0,0,144,139,6,0,224,73,6,0,0,0,0,0,32,227,4,0,136,153,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,6,0,16,0,0,0,0,0,0,0,0,0,0,158,25,0,0,86,20,0,0,0,0,0,0,0,0,0,0,2,44,0,0,0,0,0,0,102,15,0,0,58,12,0,0,20,8,0,0,100,18,0,0,190,56,0,0,96,49,216,0,0,128,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,144,240,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,176,228,1,0,0,0,0,0,128,130,1,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,4,45,0,0,132,3,0,0,0,0,0,0,0,0,0,0,148,4,0,0,134,5,0,0,96,9,0,0,6,0,0,0,188,1,0,0,234,3,0,0,138,21,0,0,120,175,145,0,8,0,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,100,8,0,0,0,0,0,0,0,0,0,0,0,0,0,96,159,4,0,224,92,8,0,0,0,0,0,152,54,6,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,8,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,104,7,0,0,124,36,0,0,0,0,0,0,0,0,0,0,86,51,0,0,114,62,0,0,134,4,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,72,196,2,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,24,180,2,0,0,0,0,0,64,165,2,0,0,227,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,21,0,0,1,0,0,0,0,0,0,0,0,0,138,38,0,0,246,2,0,0,0,0,0,0,0,0,0,0,0,48,0,0,154,5,0,0,210,5,0,0,248,19,0,0,72,13,0,0,198,3,0,0,96,10,0,0,224,174,145,0,0,2,0,0,128,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,64,218,7,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,224,169,6,0,0,0,0,0,240,115,1,0,144,250,3,0,16,26,3,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,3,8,0,0,0,0,0,0,0,0,0,0,0,22,32,0,0,230,11,0,0,0,0,0,0,0,0,0,0,46,20,0,0,216,35,0,0,74,0,0,0,198,11,0,0,48,14,0,0,40,11,0,0,46,47,0,0,128,176,145,0,0,32,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,124,3,0,32,174,3,0,0,0,0,0,0,0,0,0,96,135,2,0,200,101,3,0,240,56,5,0,152,54,6,0,168,38,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,3,0,0,0,0,0,5,17,4,0,0,0,0,0,0,0,0,0,0,0,136,50,0,0,0,24,0,0,0,0,0,0,0,0,0,0,128,17,0,0,40,47,0,0,80,7,0,0,218,2,0,0,114,1,0,0,166,3,0,0,116,50,0,0,8,211,148,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,200,56,3,0,32,174,3,0,0,0,0,0,0,0,0,0,96,135,2,0,232,37,3,0,240,56,5,0,152,54,6,0,168,38,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,3,0,0,0,0,0,5,17,4,0,0,0,0,0,0,0,0,0,0,0,130,58,0,0,234,12,0,0,0,0,0,0,0,0,0,0,128,17,0,0,40,47,0,0,80,7,0,0,218,2,0,0,114,1,0,0,166,3,0,0,116,50,0,0,8,211,148,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,120,84,3,0,32,174,3,0,0,0,0,0,0,0,0,0,96,135,2,0,216,69,3,0,240,56,5,0,152,54,6,0,168,38,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,3,0,0,0,0,0,5,17,4,0,0,0,0,0,0,0,0,0,0,0,174,0,0,0,40,28,0,0,0,0,0,0,0,0,0,0,128,17,0,0,40,47,0,0,80,7,0,0,218,2,0,0,114,1,0,0,166,3,0,0,116,50,0,0,8,211,148,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,32,174,3,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,104,149,3,0,240,56,5,0,152,54,6,0,168,38,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,3,0,0,0,0,0,5,17,4,0,0,0,0,0,0,0,0,0,0,0,242,19,0,0,48,11,0,0,0,0,0,0,0,0,0,0,128,17,0,0,40,47,0,0,80,7,0,0,218,2,0,0,114,1,0,0,166,3,0,0,116,50,0,0,8,211,148,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,56,209,1,0,0,0,0,0,0,0,0,0,0,0,0,0,168,163,7,0,160,32,1,0,0,0,0,0,152,189,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,8,0,0,0,0,0,0,0,0,0,0,164,8,0,0,40,19,0,0,0,0,0,0,0,0,0,0,136,51,0,0,158,31,0,0,180,6,0,0,176,14,0,0,122,17,0,0,90,16,0,0,22,41,0,0,0,174,145,0,0,16,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,113,2,0,48,10,8,0,0,0,0,0,0,0,0,0,200,190,7,0,248,249,1,0,0,0,0,0,168,95,8,0,136,253,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,3,2,0,0,0,0,0,0,0,0,0,0,0,216,0,0,0,162,12,0,0,0,0,0,0,0,0,0,0,194,12,0,0,126,16,0,0,26,5,0,0,24,15,0,0,136,19,0,0,76,19,0,0,202,51,0,0,176,176,145,0,0,8,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,232,9,1,0,72,197,1,0,0,0,0,0,0,0,0,0,104,221,5,0,232,202,8,0,0,0,0,0,168,138,8,0,168,84,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,19,4,8,0,0,0,0,0,0,0,0,0,0,204,1,0,0,136,7,0,0,0,0,0,0,0,0,0,0,204,11,0,0,124,59,0,0,118,4,0,0,44,4,0,0,118,17,0,0,214,13,0,0,210,26,0,0,24,173,145,0,0,8,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,152,42,6,0,0,0,0,0,0,0,0,0,0,0,0,0,184,12,8,0,40,0,6,0,0,0,0,0,224,218,4,0,48,178,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,1,0,0,0,0,0,0,0,0,0,0,18,59,0,0,104,39,0,0,0,0,0,0,0,0,0,0,116,30,0,0,216,16,0,0,164,7,0,0,222,19,0,0,52,15,0,0,0,0,0,0,36,38,0,0,0,0,0,0,0,2,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,36,6,0,88,168,6,0,0,0,0,0,0,0,0,0,184,168,7,0,160,246,5,0,0,0,0,0,128,161,4,0,8,147,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,4,11,2,0,0,0,0,0,0,0,0,0,0,0,56,42,0,0,142,33,0,0,0,0,0,0,0,0,0,0,98,41,0,0,62,16,0,0,58,3,0,0,48,9,0,0,122,0,0,0,0,0,0,0,236,36,0,0,0,0,0,0,0,8,0,0,224,0,0,0,128,1,0,0,3,0,0,0,4,0,0,0,88,168,6,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,0,127,6,0,0,0,0,0,168,183,7,0,8,147,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,4,11,2,0,0,0,0,0,0,0,0,0,0,0,128,51,0,0,224,8,0,0,0,0,0,0,0,0,0,0,98,41,0,0,144,25,0,0,58,3,0,0,48,9,0,0,122,0,0,0,0,0,0,0,236,36,0,0,0,0,0,0,0,8,0,0,224,0,0,0,128,1,0,0,3,0,0,0,4,0,0,0,40,3,8,0,0,0,0,0,0,0,0,0,0,0,0,0,104,174,7,0,32,244,7,0,48,25,8,0,144,237,7,0,0,227,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,1,21,0,0,1,0,0,0,0,0,0,0,0,0,198,24,0,0,8,0,0,0,0,0,0,0,0,0,0,0,102,24,0,0,246,6,0,0,122,1,0,0,248,19,0,0,72,13,0,0,230,0,0,0,96,10,0,0,224,174,145,0,0,2,0,0,224,0,0,0,128,1,0,0,3,0,0,0,4,0,0,0,184,28,4,0,64,109,4,0,0,0,0,0,0,0,0,0,32,127,5,0,184,254,3,0,0,0,0,0,40,253,3,0,48,178,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,10,0,2,0,0,0,0,0,0,0,0,0,0,30,61,0,0,112,39,0,0,0,0,0,0,0,0,0,0,116,30,0,0,58,18,0,0,232,2,0,0,222,19,0,0,214,18,0,0,0,0,0,0,36,38,0,0,0,0,0,0,0,2,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,109,4,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,136,83,4,0,0,0,0,0,40,253,3,0,48,178,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,2,0,0,0,0,0,0,0,0,0,0,4,27,0,0,210,6,0,0,0,0,0,0,0,0,0,0,116,30,0,0,58,18,0,0,232,2,0,0,222,19,0,0,214,18,0,0,0,0,0,0,36,38,0,0,0,0,0,0,0,2,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,128,1,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,40,103,1,0,0,0,0,0,216,164,4,0,80,164,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,1,0,0,0,0,0,0,0,0,0,0,0,144,39,0,0,0,20,0,0,0,0,0,0,0,0,0,0,244,56,0,0,148,31,0,0,114,10,0,0,56,9,0,0,210,3,0,0,210,14,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,152,4,0,0,0,0,0,0,0,0,0,0,0,0,0,216,194,1,0,224,149,4,0,0,0,0,0,200,147,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,8,0,0,2,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,0,0,0,0,68,59,0,0,106,1,0,0,0,0,0,0,0,0,0,0,0,35,0,0,174,14,0,0,72,11,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,120,129,4,0,16,152,4,0,0,0,0,0,0,0,0,0,216,194,1,0,248,126,4,0,24,163,4,0,192,154,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,8,0,0,2,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,0,0,0,0,184,25,0,0,208,28,0,0,0,0,0,0,0,0,0,0,0,35,0,0,174,14,0,0,66,5,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,192,143,4,0,16,152,4,0,0,0,0,0,0,0,0,0,216,194,1,0,232,140,4,0,0,0,0,0,128,199,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,8,0,0,2,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,0,0,0,0,54,28,0,0,64,19,0,0,0,0,0,0,0,0,0,0,0,35,0,0,6,8,0,0,72,11,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,152,164,3,0,0,0,0,0,0,0,0,0,0,0,0,0,104,129,6,0,248,114,3,0,0,0,0,0,136,233,4,0,208,165,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,1,21,0,0,8,0,0,0,0,0,0,0,0,0,156,51,0,0,74,12,0,0,0,0,0,0,0,0,0,0,248,46,0,0,92,55,0,0,196,10,0,0,198,1,0,0,170,2,0,0,0,0,0,0,236,14,0,0,240,210,148,0,0,128,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,120,224,2,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,152,219,1,0,0,0,0,0,224,189,4,0,168,155,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,133,0,0,0,3,0,0,0,0,0,0,10,2,0,0,0,0,0,0,0,0,0,0,0,84,14,0,0,78,13,0,0,0,0,0,0,0,0,0,0,124,15,0,0,152,31,0,0,50,15,0,0,80,4,0,0,254,2,0,0,186,5,0,0,26,56,0,0,0,0,0,0,0,8,0,0,240,0,0,0,96,1,0,0,3,0,0,0,4,0,0,0,32,181,2,0,216,22,8,0,0,0,0,0,0,0,0,0,144,47,2,0,8,46,2,0,0,0,0,0,176,237,2,0,168,84,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,19,0,8,0,0,0,0,0,0,0,0,0,0,106,43,0,0,190,42,0,0,0,0,0,0,0,0,0,0,178,41,0,0,0,37,0,0,172,4,0,0,214,6,0,0,250,16,0,0,138,7,0,0,74,40,0,0,88,173,145,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,216,22,8,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,240,214,5,0,0,0,0,0,176,237,2,0,168,84,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,19,0,8,0,0,0,0,0,0,0,0,0,0,6,32,0,0,118,0,0,0,0,0,0,0,0,0,0,0,178,41,0,0,0,37,0,0,172,4,0,0,214,6,0,0,250,16,0,0,138,7,0,0,74,40,0,0,88,173,145,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,112,79,2,0,216,22,8,0,0,0,0,0,0,0,0,0,144,47,2,0,48,221,1,0,0,0,0,0,176,237,2,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,0,10,0,8,0,0,0,0,0,0,0,0,0,0,70,16,0,0,118,12,0,0,0,0,0,0,0,0,0,0,158,13,0,0,204,4,0,0,60,16,0,0,56,15,0,0,12,17,0,0,0,0,0,0,224,13,0,0,0,0,0,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,0,93,4,0,216,22,8,0,0,0,0,0,0,0,0,0,144,47,2,0,192,219,4,0,0,0,0,0,176,237,2,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,0,10,0,8,0,0,0,0,0,0,0,0,0,0,232,13,0,0,48,15,0,0,0,0,0,0,0,0,0,0,158,13,0,0,204,4,0,0,130,2,0,0,56,15,0,0,12,17,0,0,0,0,0,0,224,13,0,0,0,0,0,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,248,40,7,0,56,64,7,0,0,0,0,0,0,0,0,0,184,168,7,0,120,36,7,0,0,0,0,0,128,47,7,0,80,150,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,4,0,4,2,4,0,0,0,0,0,0,0,0,0,0,0,18,12,0,0,132,45,0,0,0,0,0,0,0,0,0,0,50,22,0,0,36,21,0,0,70,12,0,0,114,17,0,0,134,11,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,64,7,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,24,59,7,0,184,52,7,0,128,47,7,0,80,150,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,4,4,2,4,0,0,0,0,0,0,0,0,0,0,0,180,13,0,0,118,5,0,0,0,0,0,0,0,0,0,0,50,22,0,0,36,21,0,0,18,5,0,0,114,17,0,0,134,11,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,206,2,0,120,136,1,0,0,0,0,0,0,0,0,0,224,56,7,0,112,187,2,0,0,0,0,0,72,173,2,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,87,0,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,100,10,0,0,50,8,0,0,0,0,0,0,0,0,0,0,86,51,0,0,26,31,0,0,8,7,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,192,147,2,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,16,232,5,0,0,0,0,0,160,150,4,0,16,128,3,0,0,187,2,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,3,4,2,0,0,0,0,0,0,0,0,0,0,0,60,52,0,0,238,1,0,0,0,0,0,0,0,0,0,0,178,5,0,0,96,57,0,0,224,3,0,0,204,10,0,0,208,8,0,0,178,1,0,0,66,50,0,0,32,146,215,0,0,8,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,112,174,2,0,0,0,0,0,0,0,0,0,0,0,0,0,104,174,7,0,200,238,5,0,0,0,0,0,88,153,4,0,224,127,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,1,4,2,0,0,0,0,0,0,0,0,0,0,0,14,41,0,0,72,19,0,0,0,0,0,0,0,0,0,0,118,63,0,0,22,1,0,0,62,13,0,0,244,19,0,0,58,16,0,0,46,11,0,0,176,24,0,0,32,146,215,0,0,4,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,112,238,2,0,0,0,0,0,0,0,0,0,0,0,0,0,56,172,6,0,48,195,2,0,0,0,0,0,136,233,4,0,208,165,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,21,0,0,8,0,0,0,0,0,0,0,0,0,18,20,0,0,240,19,0,0,0,0,0,0,0,0,0,0,110,35,0,0,222,44,0,0,196,10,0,0,198,1,0,0,170,2,0,0,0,0,0,0,236,14,0,0,240,210,148,0,0,128,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,24,181,6,0,104,106,7,0,0,0,0,0,0,0,0,0,160,234,7,0,88,137,6,0,0,0,0,0,104,224,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,20,4,8,0,0,0,0,0,0,0,0,0,0,72,63,0,0,224,7,0,0,0,0,0,0,0,0,0,0,194,6,0,0,92,2,0,0,148,9,0,0,248,1,0,0,100,9,0,0,230,11,0,0,254,30,0,0,184,175,145,0,0,4,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,232,45,6,0,104,106,7,0,0,0,0,0,0,0,0,0,160,234,7,0,104,3,6,0,0,0,0,0,192,223,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,20,4,8,0,0,0,0,0,0,0,0,0,0,230,14,0,0,152,12,0,0,0,0,0,0,0,0,0,0,194,6,0,0,92,2,0,0,148,9,0,0,248,1,0,0,100,9,0,0,230,11,0,0,254,30,0,0,184,175,145,0,0,4,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,136,11,7,0,104,106,7,0,0,0,0,0,0,0,0,0,160,234,7,0,0,225,6,0,0,0,0,0,192,223,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,20,4,8,0,0,0,0,0,0,0,0,0,0,66,43,0,0,20,48,0,0,0,0,0,0,0,0,0,0,194,6,0,0,212,0,0,0,148,9,0,0,248,1,0,0,100,9,0,0,230,11,0,0,254,30,0,0,184,175,145,0,0,4,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,104,106,7,0,0,0,0,0,0,0,0,0,0,0,0,0,160,234,7,0,0,56,7,0,0,0,0,0,192,223,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,20,4,8,0,0,0,0,0,0,0,0,0,0,20,32,0,0,0,3,0,0,0,0,0,0,0,0,0,0,194,6,0,0,212,0,0,0,148,9,0,0,248,1,0,0,100,9,0,0,230,11,0,0,254,30,0,0,184,175,145,0,0,4,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,152,87,1,0,168,115,1,0])
.concat([0,0,0,0,0,0,0,0,240,3,2,0,200,79,1,0,0,0,0,0,192,154,4,0,0,227,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,21,0,0,1,0,0,0,0,0,0,0,0,0,230,18,0,0,146,23,0,0,0,0,0,0,0,0,0,0,66,29,0,0,164,35,0,0,34,4,0,0,248,19,0,0,220,14,0,0,234,18,0,0,96,10,0,0,224,174,145,0,0,6,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,169,3,0,32,176,3,0,0,0,0,0,0,0,0,0,232,167,7,0,72,166,3,0,0,0,0,0,208,163,3,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,8,0,0,2,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,0,0,0,0,20,28,0,0,252,42,0,0,0,0,0,0,0,0,0,0,68,15,0,0,64,32,0,0,126,14,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,32,176,3,0,0,0,0,0,0,0,0,0,0,0,0,0,232,167,7,0,80,174,3,0,0,0,0,0,208,171,3,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,8,0,0,2,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,0,0,0,0,164,57,0,0,172,36,0,0,0,0,0,0,0,0,0,0,68,15,0,0,64,32,0,0,126,14,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,152,137,8,0,56,9,1,0,0,0,0,0,0,0,0,0,184,168,7,0,144,75,8,0,0,0,0,0,176,237,2,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,19,4,0,0,0,0,0,0,0,0,0,0,0,62,42,0,0,118,29,0,0,0,0,0,0,0,0,0,0,124,58,0,0,216,24,0,0,68,4,0,0,90,1,0,0,100,8,0,0,66,9,0,0,198,15,0,0,16,173,145,0,0,3,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,56,9,1,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,16,202,8,0,0,0,0,0,176,237,2,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,19,4,0,0,0,0,0,0,0,0,0,0,0,176,42,0,0,76,0,0,0,0,0,0,0,0,0,0,0,124,58,0,0,216,24,0,0,68,4,0,0,90,1,0,0,100,8,0,0,66,9,0,0,198,15,0,0,16,173,145,0,0,3,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,216,164,1,0,168,232,1,0,0,0,0,0,0,0,0,0,104,221,5,0,0,158,1,0,0,0,0,0,168,95,8,0,112,205,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,1,3,2,0,0,0,0,0,0,0,0,0,0,0,104,55,0,0,198,6,0,0,0,0,0,0,0,0,0,0,64,55,0,0,66,62,0,0,48,1,0,0,130,1,0,0,58,7,0,0,0,0,0,0,42,8,0,0,0,0,0,0,0,8,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,112,193,1,0,0,0,0,0,72,172,6,0,0,0,0,0,104,221,5,0,208,186,6,0,0,0,0,0,128,145,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,0,64,0,0,0,0,0,0,0,0,0,0,54,54,0,0,204,11,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,164,5,0,104,36,6,0,0,0,0,0,0,0,0,0,184,168,7,0,120,130,5,0,0,0,0,0,40,161,4,0,160,148,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,192,0,8,2,0,0,4,0,0,0,0,0,0,0,0,0,42,49,0,0,52,22,0,0,0,0,0,0,0,0,0,0,128,24,0,0,186,17,0,0,204,12,0,0,114,17,0,0,204,6,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,48,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,230,4,0,104,36,6,0,0,0,0,0,0,0,0,0,184,168,7,0,168,194,4,0,0,0,0,0,40,161,4,0,160,148,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,192,0,8,2,0,0,4,0,0,0,0,0,0,0,0,0,180,50,0,0,226,31,0,0,0,0,0,0,0,0,0,0,128,24,0,0,104,28,0,0,204,12,0,0,114,17,0,0,204,6,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,48,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,102,5,0,104,36,6,0,0,0,0,0,0,0,0,0,184,168,7,0,184,71,5,0,0,0,0,0,40,161,4,0,160,148,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,192,0,8,2,0,0,4,0,0,0,0,0,0,0,0,0,4,41,0,0,50,48,0,0,0,0,0,0,0,0,0,0,128,24,0,0,226,9,0,0,204,12,0,0,114,17,0,0,204,6,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,48,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,36,6,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,232,204,5,0,0,0,0,0,40,161,4,0,160,148,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,192,0,8,2,0,0,4,0,0,0,0,0,0,0,0,0,34,30,0,0,250,11,0,0,0,0,0,0,0,0,0,0,128,24,0,0,186,17,0,0,204,12,0,0,114,17,0,0,204,6,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,48,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,79,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,24,73,7,0,0,0,0,0,104,24,4,0,80,150,3,0,88,68,7,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,8,4,2,0,16,0,0,0,0,0,0,0,0,0,0,62,19,0,0,26,12,0,0,0,0,0,0,0,0,0,0,172,57,0,0,38,18,0,0,216,16,0,0,114,17,0,0,134,11,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,231,2,0,24,124,4,0,0,0,0,0,0,0,0,0,200,190,7,0,32,81,2,0,0,0,0,0,192,223,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,20,4,8,0,0,0,0,0,0,0,0,0,0,116,51,0,0,154,22,0,0,0,0,0,0,0,0,0,0,212,26,0,0,128,62,0,0,246,0,0,0,36,0,0,0,160,11,0,0,54,16,0,0,250,8,0,0,16,175,145,0,64,2,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,23,3,0,0,63,3,0,0,0,0,0,0,0,0,0,200,190,7,0,24,1,3,0,0,0,0,0,88,90,7,0,128,194,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,11,0,0,4,0,0,0,0,0,0,0,0,0,112,58,0,0,78,2,0,0,0,0,0,0,0,0,0,0,188,7,0,0,168,21,0,0,236,9,0,0,46,1,0,0,106,9,0,0,0,0,0,0,78,54,0,0,0,0,0,0,0,32,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,0,63,3,0,0,0,0,0,0,0,0,0,0,0,0,0,200,190,7,0,144,46,3,0,0,0,0,0,168,183,7,0,128,194,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,3,11,0,0,4,0,0,0,0,0,0,0,0,0,176,57,0,0,144,15,0,0,0,0,0,0,0,0,0,0,188,7,0,0,136,29,0,0,236,9,0,0,46,1,0,0,106,9,0,0,0,0,0,0,78,54,0,0,0,0,0,0,0,32,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,16,134,6,0,0,0,0,0,0,0,0,0,0,0,0,0,168,163,7,0,32,88,6,0,0,0,0,0,224,218,4,0,48,178,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,8,0,0,0,0,0,0,0,0,0,0,140,56,0,0,236,33,0,0,0,0,0,0,0,0,0,0,116,30,0,0,202,17,0,0,170,13,0,0,222,19,0,0,52,15,0,0,0,0,0,0,36,38,0,0,0,0,0,0,0,2,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,230,1,0,144,19,5,0,0,0,0,0,0,0,0,0,184,168,7,0,112,132,1,0,0,0,0,0,32,45,1,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,74,27,0,0,86,22,0,0,0,0,0,0,0,0,0,0,150,57,0,0,148,47,0,0,46,12,0,0,192,19,0,0,240,14,0,0,148,14,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,104,4,0,168,39,5,0,0,0,0,0,0,0,0,0,160,234,7,0,24,78,4,0,0,0,0,0,192,154,4,0,128,194,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,0,0,0,2,0,0,0,0,0,3,11,2,0,0,0,0,0,0,0,0,0,0,0,196,47,0,0,252,7,0,0,0,0,0,0,0,0,0,0,140,41,0,0,124,42,0,0,26,3,0,0,208,9,0,0,12,5,0,0,0,0,0,0,120,21,0,0,0,0,0,0,0,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,168,39,5,0,0,0,0,0,0,0,0,0,0,0,0,0,160,234,7,0,160,9,5,0,0,0,0,0,144,84,8,0,128,194,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,2,0,0,0,0,0,3,11,2,0,0,0,0,0,0,0,0,0,0,0,202,40,0,0,6,41,0,0,0,0,0,0,0,0,0,0,140,41,0,0,124,42,0,0,26,3,0,0,208,9,0,0,12,5,0,0,0,0,0,0,120,21,0,0,0,0,0,0,0,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,104,54,7,0,144,19,5,0,0,0,0,0,0,0,0,0,184,168,7,0,232,10,7,0,0,0,0,0,168,231,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,62,6,0,0,236,19,0,0,0,0,0,0,0,0,0,0,98,20,0,0,130,5,0,0,234,11,0,0,192,19,0,0,250,11,0,0,144,3,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,243,2,0,144,19,5,0,0,0,0,0,0,0,0,0,184,168,7,0,224,90,2,0,0,0,0,0,72,218,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,218,47,0,0,0,11,0,0,0,0,0,0,0,0,0,0,150,57,0,0,148,47,0,0,46,12,0,0,192,19,0,0,240,14,0,0,148,14,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,19,5,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,72,96,6,0,0,0,0,0,72,218,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,224,45,0,0,54,12,0,0,0,0,0,0,0,0,0,0,150,57,0,0,148,47,0,0,46,12,0,0,192,19,0,0,240,14,0,0,148,14,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,235,2,0,152,135,3,0,0,0,0,0,0,0,0,0,104,174,7,0,64,211,2,0,0,0,0,0,168,183,7,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,11,0,0,1,0,0,0,0,0,0,0,0,0,218,13,0,0,194,31,0,0,0,0,0,0,0,0,0,0,68,17,0,0,150,36,0,0,174,0,0,0,82,3,0,0,246,2,0,0,152,1,0,0,92,6,0,0,144,173,145,0,0,2,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,21,3,0,152,135,3,0,0,0,0,0,0,0,0,0,104,174,7,0,128,0,3,0,0,0,0,0,168,183,7,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,11,0,0,1,0,0,0,0,0,0,0,0,0,228,46,0,0,30,47,0,0,0,0,0,0,0,0,0,0,68,17,0,0,150,36,0,0,174,0,0,0,82,3,0,0,246,2,0,0,152,1,0,0,92,6,0,0,144,173,145,0,0,2,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,62,3,0,152,135,3,0,0,0,0,0,0,0,0,0,104,174,7,0,200,45,3,0,0,0,0,0,144,84,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,11,0,0,1,0,0,0,0,0,0,0,0,0,92,4,0,0,218,39,0,0,0,0,0,0,0,0,0,0,68,17,0,0,122,44,0,0,174,0,0,0,82,3,0,0,246,2,0,0,152,1,0,0,92,6,0,0,144,173,145,0,0,2,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,255,1,0,8,147,8,0,0,0,0,0,0,0,0,0,184,168,7,0,240,156,1,0,0,0,0,0,168,95,8,0,112,7,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,1,3,4,0,0,0,0,0,0,0,0,0,0,0,40,4,0,0,40,18,0,0,0,0,0,0,0,0,0,0,0,13,0,0,224,56,0,0,84,1,0,0,206,7,0,0,66,1,0,0,0,0,0,0,158,6,0,0,0,0,0,0,0,4,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,36,3,0,8,147,8,0,0,0,0,0,0,0,0,0,184,168,7,0,72,118,2,0,0,0,0,0,168,95,8,0,112,7,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,1,3,4,0,0,0,0,0,0,0,0,0,0,0,70,8,0,0,14,35,0,0,0,0,0,0,0,0,0,0,0,13,0,0,224,56,0,0,84,1,0,0,206,7,0,0,66,1,0,0,0,0,0,0,158,6,0,0,0,0,0,0,0,4,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,63,8,0,8,147,8,0,0,0,0,0,0,0,0,0,104,221,5,0,88,213,7,0,0,0,0,0,168,95,8,0,112,7,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,1,3,4,0,0,0,0,0,0,0,0,0,0,0,116,7,0,0,40,23,0,0,0,0,0,0,0,0,0,0,0,13,0,0,224,56,0,0,84,1,0,0,206,7,0,0,66,1,0,0,0,0,0,0,158,6,0,0,0,0,0,0,0,4,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,75,1,0,248,145,1,0,0,0,0,0,0,0,0,0,144,47,2,0,72,68,1,0,0,0,0,0,168,95,8,0,8,121,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,1,3,4,0,0,0,0,0,0,0,0,0,0,0,182,37,0,0,128,29,0,0,0,0,0,0,0,0,0,0,174,60,0,0,0,0,0,0,96,0,0,0,130,1,0,0,206,2,0,0,0,0,0,0,180,8,0,0,0,0,0,0,0,8,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,107,1,0,248,145,1,0,0,0,0,0,0,0,0,0,144,47,2,0,24,96,1,0,0,0,0,0,168,95,8,0,8,121,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,3,4,0,0,0,0,0,0,0,0,0,0,0,198,31,0,0,50,7,0,0,0,0,0,0,0,0,0,0,140,55,0,0,0,0,0,0,96,0,0,0,130,1,0,0,206,2,0,0,0,0,0,0,180,8,0,0,0,0,0,0,0,8,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,145,1,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,80,134,1,0,0,0,0,0,168,95,8,0,8,121,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,4,0,0,0,0,0,1,3,4,0,0,0,0,0,0,0,0,0,0,0,126,4,0,0,126,29,0,0,0,0,0,0,0,0,0,0,4,6,0,0,0,0,0,0,96,0,0,0,130,1,0,0,206,2,0,0,0,0,0,0,180,8,0,0,0,0,0,0,0,8,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,147,8,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,48,189,6,0,0,0,0,0,168,95,8,0,112,7,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,4,0,0,0,0,0,1,3,4,0,0,0,0,0,0,0,0,0,0,0,2,47,0,0,30,37,0,0,0,0,0,0,0,0,0,0,0,13,0,0,224,56,0,0,84,1,0,0,206,7,0,0,66,1,0,0,0,0,0,0,158,6,0,0,0,0,0,0,0,4,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,186,8,0,8,147,8,0,0,0,0,0,0,0,0,0,184,168,7,0,160,120,8,0,0,0,0,0,168,95,8,0,112,7,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,1,3,4,0,0,0,0,0,0,0,0,0,0,0,108,19,0,0,36,11,0,0,0,0,0,0,0,0,0,0,0,13,0,0,224,56,0,0,84,1,0,0,206,7,0,0,66,1,0,0,0,0,0,0,158,6,0,0,0,0,0,0,0,4,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,145,6,0,8,147,8,0,0,0,0,0,0,0,0,0,184,168,7,0,168,102,6,0,0,0,0,0,168,95,8,0,112,7,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,3,4,0,0,0,0,0,0,0,0,0,0,0,56,63,0,0,140,18,0,0,0,0,0,0,0,0,0,0,110,15,0,0,120,2,0,0,84,1,0,0,206,7,0,0,66,1,0,0,0,0,0,0,158,6,0,0,0,0,0,0,0,4,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,234,6,0,8,147,8,0,0,0,0,0,0,0,0,0,104,221,5,0,112,192,6,0,0,0,0,0,168,95,8,0,112,7,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,3,4,0,0,0,0,0,0,0,0,0,0,0,78,44,0,0,102,19,0,0,0,0,0,0,0,0,0,0,110,15,0,0,120,2,0,0,84,1,0,0,206,7,0,0,66,1,0,0,0,0,0,0,158,6,0,0,0,0,0,0,0,4,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,66,7,0,8,147,8,0,0,0,0,0,0,0,0,0,184,168,7,0,104,22,7,0,0,0,0,0,168,95,8,0,112,7,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,3,4,0,0,0,0,0,0,0,0,0,0,0,26,9,0,0,240,30,0,0,0,0,0,0,0,0,0,0,110,15,0,0,120,2,0,0,84,1,0,0,206,7,0,0,66,1,0,0,0,0,0,0,158,6,0,0,0,0,0,0,0,4,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,162,7,0,8,147,8,0,0,0,0,0,0,0,0,0,184,168,7,0,192,117,7,0,0,0,0,0,168,95,8,0,112,7,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,3,4,0,0,0,0,0,0,0,0,0,0,0,238,7,0,0,138,7,0,0,0,0,0,0,0,0,0,0,110,15,0,0,120,2,0,0,84,1,0,0,206,7,0,0,66,1,0,0,0,0,0,0,158,6,0,0,0,0,0,0,0,4,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,89,1,0,248,145,1,0,0,0,0,0,0,0,0,0,144,47,2,0,184,82,1,0,0,0,0,0,168,95,8,0,8,121,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,3,4,0,0,0,0,0,0,0,0,0,0,0,76,29,0,0,60,33,0,0,0,0,0,0,0,0,0,0,140,55,0,0,0,0,0,0,96,0,0,0,130,1,0,0,206,2,0,0,0,0,0,0,180,8,0,0,0,0,0,0,0,8,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,62,1,0,8,147,8,0,0,0,0,0,0,0,0,0,184,168,7,0,152,249,8,0,0,0,0,0,168,95,8,0,112,7,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,1,3,4,0,0,0,0,0,0,0,0,0,0,0,18,23,0,0,30,8,0,0,0,0,0,0,0,0,0,0,0,13,0,0,224,56,0,0,84,1,0,0,206,7,0,0,66,1,0,0,0,0,0,0,158,6,0,0,0,0,0,0,0,4,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,218,6,0,72,98,7,0,0,0,0,0,0,0,0,0,184,168,7,0,184,173,6,0,0,0,0,0,32,0,1,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,52,14,0,0,44,34,0,0,0,0,0,0,0,0,0,0,222,45,0,0,226,31,0,0,128,17,0,0,14,3,0,0,164,11,0,0,42,4,0,0,242,13,0,0,104,174,145,0,0,16,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,37,1,0,0,76,2,0,0,0,0,0,0,0,0,0,168,163,7,0,24,227,8,0,120,155,4,0,32,0,1,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,10,8,0,0,0,0,0,0,0,0,0,0,0,88,25,0,0,250,18,0,0,0,0,0,0,0,0,0,0,40,0,0,0,0,0,0,0,126,13,0,0,66,3,0,0,216,3,0,0,240,6,0,0,124,31,0,0,152,174,145,0,0,72,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,0,76,2,0,0,0,0,0,0,0,0,0,0,0,0,0,168,163,7,0,192,118,1,0,120,155,4,0,32,0,1,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,8,0,0,0,0,0,0,0,0,0,0,0,148,19,0,0,208,44,0,0,0,0,0,0,0,0,0,0,40,0,0,0,0,0,0,0,238,16,0,0,66,3,0,0,216,3,0,0,240,6,0,0,124,31,0,0,152,174,145,0,0,72,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,248,43,2,0,0,90,7,0,0,0,0,0,0,0,0,0,200,190,7,0,48,22,2,0,0,0,0,0,40,161,4,0,248,206,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,2,0,3,2,0,4,0,0,0,0,0,0,0,0,0,0,112,9,0,0,50,22,0,0,0,0,0,0,0,0,0,0,152,19,0,0,46,56,0,0,218,12,0,0,114,17,0,0,144,2,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,224,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,0,90,7,0,0,0,0,0,0,0,0,0,0,0,0,0,200,190,7,0,96,83,7,0,0,0,0,0,40,161,4,0,80,150,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,4,0,4,2,0,4,0,0,0,0,0,0,0,0,0,0,110,12,0,0,86,18,0,0,0,0,0,0,0,0,0,0,180,12,0,0,40,29,0,0,10,4,0,0,114,17,0,0,134,11,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,224,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,176,91,5,0,0,0,0,0,0,0,0,0,0,0,0,0,160,135,3,0,120,89,5,0,160,173,1,0,232,98,5,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,192,38,0,0,140,46,0,0,0,0,0,0,0,0,0,0,120,8,0,0,254,62,0,0,130,4,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,112,125,1,0,24,124,4,0,0,0,0,0,0,0,0,0,200,190,7,0,64,41,1,0,0,0,0,0,192,154,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,0,20,4,8,0,0,0,0,0,0,0,0,0,0,190,46,0,0,242,22,0,0,0,0,0,0,0,0,0,0,212,26,0,0,48,56,0,0,32,0,0,0,36,0,0,0,160,11,0,0,54,16,0,0,250,8,0,0,16,175,145,0,64,2,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,124,4,0,0,0,0,0,0,0,0,0,0,0,0,0,200,190,7,0,80,69,6,0,0,0,0,0,104,224,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,20,4,8,0,0,0,0,0,0,0,0,0,0,74,38,0,0,254,26,0,0,0,0,0,0,0,0,0,0,212,26,0,0,48,56,0,0,216,8,0,0,36,0,0,0,160,11,0,0,54,16,0,0,250,8,0,0,16,175,145,0,64,2,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,186,2,0,16,145,2,0,0,0,0,0,0,0,0,0,64,171,7,0,128,50,2,0,0,0,0,0,64,246,3,0,72,129,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,4,4,2,0,0,0,0,0,0,0,0,0,0,0,166,50,0,0,80,12,0,0,0,0,0,0,0,0,0,0,186,49,0,0,98,27,0,0,242,16,0,0,94,12,0,0,120,8,0,0,0,0,0,0,46,35,0,0,56,74,148,0,0,1,0,0,240,0,0,0,24,1,0,0,3,0,0,0,4,0,0,0,40,148,8,0,16,145,2,0,0,0,0,0,0,0,0,0,64,171,7,0,32,85,8,0,0,0,0,0,64,246,3,0,72,129,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,53,0,0,0,2,0,0,0,0,0,4,4,2,0,0,0,0,0,0,0,0,0,0,0,196,38,0,0,52,24,0,0,0,0,0,0,0,0,0,0,186,49,0,0,98,27,0,0,242,16,0,0,94,12,0,0,120,8,0,0,0,0,0,0,46,35,0,0,56,74,148,0,0,1,0,0,240,0,0,0,24,1,0,0,3,0,0,0,4,0,0,0,224,19,1,0,16,145,2,0,0,0,0,0,0,0,0,0,64,171,7,0,112,212,8,0,0,0,0,0,64,246,3,0,72,129,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,53,0,0,0,2,0,0,0,0,0,4,4,2,0,0,0,0,0,0,0,0,0,0,0,226,15,0,0,154,10,0,0,0,0,0,0,0,0,0,0,186,49,0,0,98,27,0,0,242,16,0,0,94,12,0,0,120,8,0,0,0,0,0,0,46,35,0,0,56,74,148,0,0,1,0,0,240,0,0,0,24,1,0,0,3,0,0,0,4,0,0,0,104,195,1,0,16,145,2,0,0,0,0,0,0,0,0,0,64,171,7,0,40,98,1,0,0,0,0,0,64,246,3,0,72,129,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,53,0,0,0,2,0,0,0,0,0,4,4,2,0,0,0,0,0,0,0,0,0,0,0,198,19,0,0,150,26,0,0,0,0,0,0,0,0,0,0,186,49,0,0,98,27,0,0,242,16,0,0,94,12,0,0,120,8,0,0,0,0,0,0,46,35,0,0,56,74,148,0,0,1,0,0,240,0,0,0,24,1,0,0,3,0,0,0,4,0,0,0,16,145,2,0,0,0,0,0,0,0,0,0,0,0,0,0,64,171,7,0,104,231,5,0,0,0,0,0,64,246,3,0,72,129,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,4,4,2,0,0,0,0,0,0,0,0,0,0,0,78,29,0,0,186,9,0,0,0,0,0,0,0,0,0,0,186,49,0,0,98,27,0,0,242,16,0,0,94,12,0,0,120,8,0,0,0,0,0,0,46,35,0,0,56,74,148,0,0,1,0,0,240,0,0,0,24,1,0,0,3,0,0,0,4,0,0,0,24,59,8,0,16,81,8,0,0,0,0,0,0,0,0,0,104,221,5,0,96,54,8,0,232,70,8,0,128,161,4,0,208,135,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,2,11,4,0,0,0,0,0,0,0,0,0,0,0,106,17,0,0,208,34,0,0,0,0,0,0,0,0,0,0,160,44,0,0,68,47,0,0,72,7,0,0,46,7,0,0,246,17,0,0,0,0,0,0,176,18,0,0,0,0,0,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,68,8,0,16,81,8,0,0,0,0,0,0,0,0,0,104,221,5,0,184,64,8,0,232,70,8,0,144,84,8,0,208,135,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,2,11,4,0,0,0,0,0,0,0,0,0,0,0,174,38,0,0,254,38,0,0,0,0,0,0,0,0,0,0,160,44,0,0,124,63,0,0,72,7,0,0,46,7,0,0,246,17,0,0,0,0,0,0,176,18,0,0,0,0,0,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,81,8,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,128,76,8,0,232,70,8,0,168,183,7,0,208,135,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,2,11,4,0,0,0,0,0,0,0,0,0,0,0,8,36,0,0,248,9,0,0,0,0,0,0,0,0,0,0,160,44,0,0,162,49,0,0,72,7,0,0,46,7,0,0,246,17,0,0,0,0,0,0,176,18,0,0,0,0,0,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,210,7,0,0,153,1,0,0,0,0,0,0,0,0,0,104,174,7,0,144,159,7,0,0,0,0,0,168,95,8,0,112,246,8,0,64,115,7,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,3,1,0,0,0,0,0,0,0,0,0,0,0,194,27,0,0,56,42,0,0,0,0,0,0,0,0,0,0,60,6,0,0,100,41,0,0,252,9,0,0,214,2,0,0,232,4,0,0,44,5,0,0,98,39,0,0,152,176,145,0,0,4,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,60,8,0,0,153,1,0,0,0,0,0,0,0,0,0,104,174,7,0,0,8,8,0,0,0,0,0,168,95,8,0,112,246,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,3,1,0,0,0,0,0,0,0,0,0,0,0,140,15,0,0,92,28,0,0,0,0,0,0,0,0,0,0,60,6,0,0,100,41,0,0,252,9,0,0,214,2,0,0,232,4,0,0,44,5,0,0,98,39,0,0,152,176,145,0,0,4,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,183,8,0,0,153,1,0,0,0,0,0,0,0,0,0,104,174,7,0,160,117,8,0,0,0,0,0,168,95,8,0,112,246,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,3,1,0,0,0,0,0,0,0,0,0,0,0,138,59,0,0,246,43,0,0,0,0,0,0,0,0,0,0,60,6,0,0,100,41,0,0,252,9,0,0,214,2,0,0,232,4,0,0,44,5,0,0,98,39,0,0,152,176,145,0,0,4,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,153,1,0,0,0,0,0,0,0,0,0,0,0,0,0,104,174,7,0,240,59,1,0,0,0,0,0,168,95,8,0,112,246,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,3,1,0,0,0,0,0,0,0,0,0,0,0,144,9,0,0,80,35,0,0,0,0,0,0,0,0,0,0,60,6,0,0,100,41,0,0,252,9,0,0,214,2,0,0,232,4,0,0,44,5,0,0,98,39,0,0,152,176,145,0,0,4,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,44,2,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,112,23,2,0,0,0,0,0,0,227,2,0,0,227,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,1,21,0,0,1,0,0,0,0,0,0,0,0,0,210,60,0,0,16,30,0,0,0,0,0,0,0,0,0,0,78,50,0,0,76,19,0,0,106,15,0,0,248,19,0,0,72,13,0,0,198,3,0,0,96,10,0,0,224,174,145,0,0,2,0,0,240,0,0,0,128,1,0,0,3,0,0,0,4,0,0,0,184,221,6,0,0,0,0,0,0,0,0,0,0,0,0,0,184,12,8,0,200,176,6,0,0,0,0,0,224,218,4,0,48,178,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,2,0,0,0,0,0,0,0,0,0,0,100,3,0,0,186,40,0,0,0,0,0,0,0,0,0,0,116,30,0,0,216,16,0,0,170,13,0,0,222,19,0,0,52,15,0,0,0,0,0,0,36,38,0,0,0,0,0,0,0,2,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,99,7,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,56,49,7,0,0,0,0,0,216,67,5,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,8,0,0,0,0,0,0,0,0,0,0,8,34,0,0,168,26,0,0,0,0,0,0,0,0,0,0,244,41,0,0,52,53,0,0,206,1,0,0,0,2,0,0,22,3,0,0,118,1,0,0,152,14,0,0,136,174,145,0,0,4,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,192,12,1,0,96,244,1,0,0,0,0,0,0,0,0,0,144,47,2,0,160,205,8,0,0,0,0,0,176,237,2,0,168,84,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,0,19,4,0,0,0,0,0,0,0,0,0,0,0,138,37,0,0,234,30,0,0,0,0,0,0,0,0,0,0,0,63,0,0,18,11,0,0,116,9,0,0,172,7,0,0,190,13,0,0,14,13,0,0,94,29,0,0,48,173,145,0,0,16,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,80,169,2,0,96,244,1,0,0,0,0,0,0,0,0,0,144,47,2,0,32,36,2,0,0,0,0,0,176,237,2,0,168,84,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,0,19,4,0,0,0,0,0,0,0,0,0,0,0,30,46,0,0,176,44,0,0,0,0,0,0,0,0,0,0,0,63,0,0,18,11,0,0,116,9,0,0,172,7,0,0,190,13,0,0,14,13,0,0,94,29,0,0,48,173,145,0,0,16,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,8,186,1,0,96,244,1,0,0,0,0,0,0,0,0,0,144,47,2,0,208,88,1,0,0,0,0,0,176,237,2,0,168,84,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,0,19,4,0,0,0,0,0,0,0,0,0,0,0,60,53,0,0,150,28,0,0,0,0,0,0,0,0,0,0,0,63,0,0,18,11,0,0,116,9,0,0,172,7,0,0,190,13,0,0,14,13,0,0,94,29,0,0,48,173,145,0,0,16,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,96,244,1,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,152,181,5,0,0,0,0,0,176,237,2,0,168,84,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,4,0,0,0,0,0,0,19,4,0,0,0,0,0,0,0,0,0,0,0,132,46,0,0,200,7,0,0,0,0,0,0,0,0,0,0,0,63,0,0,18,11,0,0,116,9,0,0,172,7,0,0,190,13,0,0,14,13,0,0,94,29,0,0,48,173,145,0,0,16,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,208,0,2,0,232,47,2,0,0,0,0,0,0,0,0,0,144,47,2,0,40,243,1,0,0,0,0,0,168,95,8,0,64,27,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,3,1,0,0,0,0,0,0,0,0,0,0,0,210,46,0,0,82,34,0,0,0,0,0,0,0,0,0,0,26,54,0,0,0,0,0,0,240,9,0,0,130,1,0,0,204,15,0,0,0,0,0,0,42,8,0,0,0,0,0,0,0,8,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,17,2,0,232,47,2,0,0,0,0,0,0,0,0,0,144,47,2,0,56,8,2,0,0,0,0,0,168,95,8,0,64,27,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,3,1,0,0,0,0,0,0,0,0,0,0,0,226,7,0,0,230,5,0,0,0,0,0,0,0,0,0,0,26,54,0,0,0,0,0,0,240,9,0,0,130,1,0,0,204,15,0,0,0,0,0,0,42,8,0,0,0,0,0,0,0,8,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,47,2,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,64,37,2,0,0,0,0,0,168,95,8,0,64,27,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,3,1,0,0,0,0,0,0,0,0,0,0,0,62,10,0,0,246,13,0,0,0,0,0,0,0,0,0,0,26,54,0,0,0,0,0,0,240,9,0,0,130,1,0,0,204,15,0,0,0,0,0,0,42,8,0,0,0,0,0,0,0,8,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,2,3,0,16,48,3,0,0,0,0,0,0,0,0,0,200,190,7,0,224,237,2,0,0,0,0,0,40,161,4,0,240,153,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,128,0,1,2,0,0,8,0,0,0,0,0,0,0,0,0,142,2,0,0,92,32,0,0,0,0,0,0,0,0,0,0,112,2,0,0,216,43,0,0,10,10,0,0,114,5,0,0,164,8,0,0,0,0,0,0,6,14,0,0,0,0,0,0,0,96,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,48,3,0,0,0,0,0,0,0,0,0,0,0,0,0,200,190,7,0,208,26,3,0,0,0,0,0,40,161,4,0,240,153,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,192,0,1,2,0,0,8,0,0,0,0,0,0,0,0,0,186,33,0,0,230,30,0,0,0,0,0,0,0,0,0,0,112,2,0,0,222,36,0,0,10,10,0,0,114,5,0,0,164,8,0,0,0,0,0,0,6,14,0,0,0,0,0,0,0,96,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,65,2,0,88,93,2,0,0,0,0,0,0,0,0,0,144,47,2,0,40,48,2,0])
.concat([240,56,5,0,152,54,6,0,168,38,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,5,17,2,0,0,0,0,0,0,0,0,0,0,0,142,51,0,0,34,28,0,0,0,0,0,0,0,0,0,0,58,34,0,0,200,62,0,0,74,16,0,0,218,2,0,0,114,1,0,0,166,3,0,0,116,50,0,0,8,211,148,0,0,8,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,224,187,7,0,104,92,8,0,0,0,0,0,0,0,0,0,232,233,7,0,160,140,7,0,0,0,0,0,16,182,4,0,192,152,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,9,2,0,0,1,0,0,0,0,0,0,0,0,0,212,6,0,0,104,23,0,0,0,0,0,0,0,0,0,0,94,27,0,0,222,24,0,0,82,13,0,0,42,17,0,0,184,7,0,0,0,0,0,0,216,46,0,0,0,0,0,0,0,6,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,72,2,0,0,0,0,0,0,0,0,0,0,0,0,0,104,129,6,0,8,115,1,0,0,0,0,0,88,34,1,0,136,153,3,0,200,223,8,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,6,4,0,0,0,0,0,0,0,0,0,0,0,214,9,0,0,144,25,0,0,0,0,0,0,0,0,0,0,6,43,0,0,40,12,0,0,20,19,0,0,206,8,0,0,68,9,0,0,198,7,0,0,40,6,0,0,96,49,216,0,0,128,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,202,5,0,200,75,4,0,0,0,0,0,0,0,0,0,160,135,3,0,184,194,5,0,0,0,0,0,240,191,5,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,8,0,0,2,0,0,0,0,0,0,16,0,8,0,0,0,0,0,0,0,0,0,0,106,33,0,0,66,0,0,0,0,0,0,0,0,0,0,0,198,35,0,0,130,62,0,0,230,19,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,200,75,4,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,136,21,4,0,72,150,4,0,64,246,3,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,108,46,0,0,126,33,0,0,0,0,0,0,0,0,0,0,36,31,0,0,0,0,0,0,200,16,0,0,128,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,152,7,0,184,110,7,0,0,0,0,0,0,0,0,0,64,164,6,0,184,106,7,0,0,0,0,0,40,98,7,0,160,201,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,1,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,254,19,0,0,12,20,0,0,0,0,0,0,0,0,0,0,72,61,0,0,98,2,0,0,102,5,0,0,44,18,0,0,234,15,0,0,250,18,0,0,102,10,0,0,208,175,145,0,32,0,0,0,236,0,0,0,16,1,0,0,3,0,0,0,4,0,0,0,16,255,7,0,184,110,7,0,0,0,0,0,0,0,0,0,64,164,6,0,248,201,7,0,0,0,0,0,40,98,7,0,160,201,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,1,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,228,0,0,0,202,16,0,0,0,0,0,0,0,0,0,0,72,61,0,0,98,2,0,0,102,5,0,0,44,18,0,0,234,15,0,0,250,18,0,0,102,10,0,0,208,175,145,0,32,0,0,0,236,0,0,0,16,1,0,0,3,0,0,0,4,0,0,0,152,107,8,0,184,110,7,0,0,0,0,0,0,0,0,0,64,164,6,0,0,51,8,0,0,0,0,0,40,98,7,0,160,201,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,1,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,98,57,0,0,0,48,0,0,0,0,0,0,0,0,0,0,72,61,0,0,98,2,0,0,102,5,0,0,44,18,0,0,234,15,0,0,250,18,0,0,102,10,0,0,208,175,145,0,32,0,0,0,236,0,0,0,16,1,0,0,3,0,0,0,4,0,0,0,128,83,4,0,32,148,1,0,0,0,0,0,0,0,0,0,96,159,4,0,96,79,4,0,0,0,0,0,200,147,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,8,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,38,14,0,0,68,28,0,0,0,0,0,0,0,0,0,0,128,38,0,0,106,56,0,0,214,19,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,32,148,1,0,0,0,0,0,0,0,0,0,0,0,0,0,96,159,4,0,232,86,4,0,0,0,0,0,168,95,8,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,8,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,12,10,0,0,30,3,0,0,0,0,0,0,0,0,0,0,128,38,0,0,106,56,0,0,214,19,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,128,213,2,0,80,162,3,0,0,0,0,0,0,0,0,0,184,168,7,0,232,71,2,0,0,0,0,0,80,212,1,0,80,164,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,106,19,0,0,194,19,0,0,0,0,0,0,0,0,0,0,46,38,0,0,200,12,0,0,112,6,0,0,214,9,0,0,52,19,0,0,100,16,0,0,0,0,0,0,0,0,0,0,0,2,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,80,162,3,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,104,39,6,0,0,0,0,0,232,196,4,0,80,164,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,20,51,0,0,108,5,0,0,0,0,0,0,0,0,0,0,46,38,0,0,200,12,0,0,112,6,0,0,214,9,0,0,52,19,0,0,100,16,0,0,0,0,0,0,0,0,0,0,0,2,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,168,33,6,0,248,38,6,0,0,0,0,0,0,0,0,0,184,230,7,0,80,201,4,0,0,0,0,0,192,15,5,0,152,88,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,13,0,16,0,0,0,0,0,0,0,0,0,0,100,42,0,0,238,23,0,0,0,0,0,0,0,0,0,0,56,14,0,0,228,58,0,0,108,3,0,0,160,16,0,0,104,12,0,0,54,1,0,0,166,39,0,0,0,0,0,0,0,20,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,248,38,6,0,0,0,0,0,0,0,0,0,0,0,0,0,184,230,7,0,104,45,5,0,0,0,0,0,192,15,5,0,152,88,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,13,0,16,0,0,0,0,0,0,0,0,0,0,230,25,0,0,112,44,0,0,0,0,0,0,0,0,0,0,56,14,0,0,228,58,0,0,146,0,0,0,160,16,0,0,104,12,0,0,54,1,0,0,166,39,0,0,0,0,0,0,0,20,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,128,130,4,0,72,229,4,0,0,0,0,0,0,0,0,0,184,168,7,0,8,104,4,0,0,0,0,0,40,161,4,0,168,196,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,5,11,0,16,0,0,0,0,0,0,0,0,0,0,188,38,0,0,244,33,0,0,0,0,0,0,0,0,0,0,184,15,0,0,12,9,0,0,86,6,0,0,178,11,0,0,82,0,0,0,238,10,0,0,188,1,0,0,0,0,0,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,8,5,0,72,229,4,0,0,0,0,0,0,0,0,0,184,168,7,0,24,193,4,0,0,0,0,0,40,161,4,0,168,196,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,5,11,0,16,0,0,0,0,0,0,0,0,0,0,230,9,0,0,92,21,0,0,0,0,0,0,0,0,0,0,184,15,0,0,12,9,0,0,56,18,0,0,178,11,0,0,82,0,0,0,238,10,0,0,188,1,0,0,0,0,0,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,103,7,0,72,229,4,0,0,0,0,0,0,0,0,0,104,174,7,0,120,96,7,0,0,0,0,0,192,154,4,0,80,150,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,4,2,0,16,0,0,0,0,0,0,0,0,0,0,206,20,0,0,196,23,0,0,0,0,0,0,0,0,0,0,172,57,0,0,220,11,0,0,248,8,0,0,114,17,0,0,134,11,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,71,2,0,72,229,4,0,0,0,0,0,0,0,0,0,104,174,7,0,8,59,2,0,0,0,0,0,40,161,4,0,248,206,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,64,0,3,2,0,16,0,0,0,0,0,0,0,0,0,0,176,56,0,0,104,2,0,0,0,0,0,0,0,0,0,0,38,13,0,0,54,49,0,0,218,12,0,0,114,17,0,0,144,2,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,114,7,0,72,229,4,0,0,0,0,0,0,0,0,0,104,174,7,0,200,109,7,0,0,0,0,0,40,161,4,0,80,150,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,64,4,4,2,0,16,0,0,0,0,0,0,0,0,0,0,182,34,0,0,104,27,0,0,0,0,0,0,0,0,0,0,172,57,0,0,220,11,0,0,218,12,0,0,114,17,0,0,134,11,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,126,7,0,72,229,4,0,0,0,0,0,0,0,0,0,104,174,7,0,120,119,7,0,0,0,0,0,40,161,4,0,80,150,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,68,0,4,2,0,16,0,0,0,0,0,0,0,0,0,0,140,39,0,0,30,0,0,0,0,0,0,0,0,0,0,0,172,57,0,0,220,11,0,0,218,12,0,0,114,17,0,0,134,11,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,229,4,0,0,0,0,0,0,0,0,0,0,0,0,0,104,174,7,0,160,85,2,0,0,0,0,0,40,161,4,0,248,206,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,64,0,3,2,0,16,0,0,0,0,0,0,0,0,0,0,218,24,0,0,238,18,0,0,0,0,0,0,0,0,0,0,38,13,0,0,54,49,0,0,218,12,0,0,114,17,0,0,144,2,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,190,6,0,0,0,0,0,232,222,6,0,0,0,0,0,160,217,6,0,128,184,6,0,0,0,0,0,112,204,6,0,48,201,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,68,4,2,4,0,0,0,0,0,0,0,0,0,0,0,26,49,0,0,196,44,0,0,0,0,0,0,0,0,0,0,180,12,0,0,122,4,0,0,246,11,0,0,162,0,0,0,134,11,0,0,0,0,0,0,2,13,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,135,6,0,240,8,7,0,0,0,0,0,0,0,0,0,200,190,7,0,232,88,6,0,168,177,6,0,64,43,6,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,32,46,0,0,6,3,0,0,0,0,0,0,0,0,0,0,152,20,0,0,174,16,0,0,28,15,0,0,62,8,0,0,92,16,0,0,16,7,0,0,172,10,0,0,40,175,145,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,232,0,6,0,240,8,7,0,0,0,0,0,0,0,0,0,200,190,7,0,96,211,5,0,168,177,6,0,192,154,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,174,62,0,0,124,25,0,0,0,0,0,0,0,0,0,0,152,20,0,0,174,16,0,0,96,2,0,0,62,8,0,0,92,16,0,0,16,7,0,0,172,10,0,0,40,175,145,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,216,135,5,0,240,8,7,0,0,0,0,0,0,0,0,0,200,190,7,0,232,108,5,0,168,177,6,0,72,226,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,46,50,0,0,40,34,0,0,0,0,0,0,0,0,0,0,152,20,0,0,174,16,0,0,28,15,0,0,62,8,0,0,92,16,0,0,16,7,0,0,172,10,0,0,40,175,145,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,240,8,7,0,0,0,0,0,0,0,0,0,0,0,0,0,200,190,7,0,120,222,6,0,168,177,6,0,72,226,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,94,50,0,0,176,12,0,0,0,0,0,0,0,0,0,0,152,20,0,0,174,16,0,0,202,10,0,0,62,8,0,0,92,16,0,0,16,7,0,0,172,10,0,0,40,175,145,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,120,243,2,0,160,12,5,0,0,0,0,0,0,0,0,0,64,171,7,0,184,90,2,0,0,0,0,0,72,226,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,202,10,0,0,162,20,0,0,0,0,0,0,0,0,0,0,96,25,0,0,156,34,0,0,86,11,0,0,180,14,0,0,36,3,0,0,0,0,0,0,42,52,0,0,136,35,149,0,16,17,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,248,44,1,0,160,12,5,0,0,0,0,0,0,0,0,0,64,171,7,0,24,234,8,0,0,0,0,0,72,226,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,242,21,0,0,42,33,0,0,0,0,0,0,0,0,0,0,96,25,0,0,156,34,0,0,220,3,0,0,180,14,0,0,36,3,0,0,0,0,0,0,42,52,0,0,136,35,149,0,16,17,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,152,230,1,0,160,12,5,0,0,0,0,0,0,0,0,0,64,171,7,0,64,131,1,0,0,0,0,0,72,226,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,82,42,0,0,214,8,0,0,0,0,0,0,0,0,0,0,96,25,0,0,156,34,0,0,86,11,0,0,180,14,0,0,36,3,0,0,0,0,0,0,42,52,0,0,136,35,149,0,16,17,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,160,12,5,0,0,0,0,0,0,0,0,0,0,0,0,0,64,171,7,0,208,95,6,0,0,0,0,0,72,226,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,156,31,0,0,178,23,0,0,0,0,0,0,0,0,0,0,96,25,0,0,156,34,0,0,142,11,0,0,180,14,0,0,36,3,0,0,0,0,0,0,42,52,0,0,136,35,149,0,16,17,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,48,201,4,0,96,45,5,0,0,0,0,0,0,0,0,0,168,163,7,0,128,168,4,0,0,0,0,0,232,163,8,0,248,180,3,0,64,137,4,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,13,1,0,0,0,0,0,0,0,0,0,0,0,2,1,0,0,176,1,0,0,0,0,0,0,0,0,0,0,32,31,0,0,168,10,0,0,120,5,0,0,66,4,0,0,206,19,0,0,238,15,0,0,232,20,0,0,216,157,215,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,45,5,0,0,0,0,0,0,0,0,0,0,0,0,0,168,163,7,0,240,236,4,0,0,0,0,0,232,163,8,0,248,180,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,13,1,0,0,0,0,0,0,0,0,0,0,0,138,19,0,0,68,25,0,0,0,0,0,0,0,0,0,0,32,31,0,0,168,40,0,0,120,5,0,0,66,4,0,0,206,19,0,0,238,15,0,0,232,20,0,0,216,157,215,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,146,2,0,0,0,0,0,0,0,0,0,160,146,2,0,144,47,2,0,200,231,5,0,80,152,4,0,160,150,4,0,16,128,3,0,152,50,2,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,2,4,0,16,0,0,0,0,0,0,0,0,0,0,250,43,0,0,224,38,0,0,240,5,0,0,218,47,0,0,102,11,0,0,228,34,0,0,48,0,0,0,34,15,0,0,244,18,0,0,56,6,0,0,66,55,0,0,32,146,215,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,72,246,8,0,160,10,1,0,0,0,0,0,0,0,0,0,64,171,7,0,144,239,8,0,0,0,0,0,192,154,4,0,192,152,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,9,2,0,8,0,0,0,0,0,0,0,0,0,0,20,0,0,0,180,13,0,0,0,0,0,0,0,0,0,0,94,27,0,0,192,42,0,0,34,7,0,0,42,17,0,0,184,7,0,0,0,0,0,0,216,46,0,0,0,0,0,0,0,6,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,255,0,0,160,10,1,0,0,0,0,0,0,0,0,0,64,171,7,0,120,252,8,0,0,0,0,0,40,161,4,0,192,152,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,9,2,0,8,0,0,0,0,0,0,0,0,0,0,164,1,0,0,88,8,0,0,0,0,0,0,0,0,0,0,94,27,0,0,192,42,0,0,164,5,0,0,42,17,0,0,184,7,0,0,0,0,0,0,216,46,0,0,0,0,0,0,0,6,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,10,1,0,0,0,0,0,0,0,0,0,0,0,0,0,64,171,7,0,152,4,1,0,0,0,0,0,40,161,4,0,192,152,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,9,2,0,8,0,0,0,0,0,0,0,0,0,0,216,38,0,0,130,6,0,0,0,0,0,0,0,0,0,0,94,27,0,0,192,42,0,0,164,5,0,0,42,17,0,0,184,7,0,0,0,0,0,0,216,46,0,0,0,0,0,0,0,6,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,144,8,0,176,183,8,0,0,0,0,0,0,0,0,0,144,47,2,0,176,139,8,0,120,155,4,0,192,154,4,0,80,164,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,0,10,2,0,0,0,0,0,0,0,0,0,0,0,70,24,0,0,118,10,0,0,0,0,0,0,0,0,0,0,244,56,0,0,114,34,0,0,134,18,0,0,92,15,0,0,82,10,0,0,210,14,0,0,0,0,0,0,0,0,0,0,0,4,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,144,132,5,0,200,251,5,0,0,0,0,0,0,0,0,0,240,3,2,0,48,105,5,0,0,0,0,0,232,167,5,0,80,164,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,0,10,2,0,0,0,0,0,0,0,0,0,0,0,220,24,0,0,152,31,0,0,0,0,0,0,0,0,0,0,116,9,0,0,210,11,0,0,224,7,0,0,214,9,0,0,18,6,0,0,186,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,224,0,0,0,128,1,0,0,3,0,0,0,4,0,0,0,200,251,5,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,96,207,5,0,0,0,0,0,232,167,5,0,80,164,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,0,10,2,0,0,0,0,0,0,0,0,0,0,0,138,33,0,0,8,23,0,0,0,0,0,0,0,0,0,0,116,9,0,0,210,11,0,0,224,7,0,0,214,9,0,0,18,6,0,0,186,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,224,0,0,0,128,1,0,0,3,0,0,0,4,0,0,0,40,157,8,0,176,183,8,0,0,0,0,0,0,0,0,0,144,47,2,0,240,150,8,0,0,0,0,0,168,166,8,0,80,164,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,0,10,2,0,0,0,0,0,0,0,0,0,0,0,88,0,0,0,82,15,0,0,0,0,0,0,0,0,0,0,244,56,0,0,20,36,0,0,30,15,0,0,56,12,0,0,212,3,0,0,250,8,0,0,0,0,0,0,0,0,0,0,0,4,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,176,183,8,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,64,175,8,0,120,155,4,0,168,166,8,0,80,164,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,0,10,2,0,0,0,0,0,0,0,0,0,0,0,32,22,0,0,234,16,0,0,0,0,0,0,0,0,0,0,244,56,0,0,20,36,0,0,30,15,0,0,56,12,0,0,212,3,0,0,250,8,0,0,0,0,0,0,0,0,0,0,0,4,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,240,253,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,164,6,0,32,244,8,0,0,0,0,0,176,236,8,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,39,0,0,0,2,0,0,0,0,0,0,16,64,0,0,0,0,0,0,0,0,0,0,0,100,26,0,0,46,15,0,0,0,0,0,0,0,0,0,0,126,3,0,0,0,0,0,0,144,13,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,184,206,8,0,0,202,8,0,0,0,0,0,0,0,0,0,232,167,7,0,104,197,8,0,0,0,0,0,192,154,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,8,0,0,2,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,0,0,0,0,52,50,0,0,12,35,0,0,0,0,0,0,0,0,0,0,220,28,0,0,86,3,0,0,150,11,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,0,202,8,0,0,0,0,0,0,0,0,0,0,0,0,0,232,167,7,0,8,62,3,0,0,0,0,0,56,72,3,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,8,0,0,2,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,0,0,0,0,6,26,0,0,114,42,0,0,0,0,0,0,0,0,0,0,212,50,0,0,120,15,0,0,254,3,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,80,61,3,0,0,202,8,0,0,0,0,0,0,0,0,0,232,167,7,0,232,59,3,0,0,0,0,0,56,72,3,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,8,0,0,2,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,0,0,0,0,10,58,0,0,24,38,0,0,0,0,0,0,0,0,0,0,212,50,0,0,120,15,0,0,104,19,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,160,209,2,0,232,117,3,0,0,0,0,0,0,0,0,0,240,3,2,0,232,68,2,0,0,0,0,0,224,189,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,10,8,0,0,0,0,0,0,0,0,0,0,0,228,9,0,0,26,37,0,0,0,0,0,0,0,0,0,0,184,11,0,0,54,40,0,0,90,5,0,0,142,7,0,0,166,9,0,0,148,3,0,0,184,45,0,0,8,174,145,0,0,8,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,117,3,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,200,30,6,0,0,0,0,0,224,189,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,0,1,0,0,0,0,0,0,0,0,0,126,25,0,0,78,47,0,0,0,0,0,0,0,0,0,0,122,36,0,0,226,44,0,0,90,5,0,0,142,7,0,0,166,9,0,0,148,3,0,0,184,45,0,0,8,174,145,0,0,8,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,1,7,0,0,0,0,0,0,0,0,0,0,0,0,0,184,230,7,0,8,217,6,0,0,0,0,0,0,188,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,8,0,0,0,0,0,0,0,0,0,0,248,29,0,0,218,32,0,0,0,0,0,0,0,0,0,0,156,30,0,0,0,0,0,0,56,17,0,0,70,9,0,0,40,18,0,0,88,15,0,0,46,51,0,0,224,173,145,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,176,171,6,0,0,0,0,0,0,0,0,0,0,0,0,0,104,129,6,0,80,81,6,0,0,0,0,0,0,188,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,0,8,0,0,0,0,0,0,0,0,0,14,15,0,0,18,21,0,0,0,0,0,0,0,0,0,0,52,32,0,0,0,0,0,0,106,10,0,0,70,9,0,0,40,18,0,0,88,15,0,0,46,51,0,0,224,173,145,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,96,24,1,0,0,0,0,0,0,0,0,0,0,0,0,0,232,233,7,0,128,15,1,0,0,0,0,0,16,182,4,0,192,152,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,9,2,0,0,1,0,0,0,0,0,0,0,0,0,90,14,0,0,96,39,0,0,0,0,0,0,0,0,0,0,94,27,0,0,58,7,0,0,86,16,0,0,42,17,0,0,184,7,0,0,0,0,0,0,216,46,0,0,0,0,0,0,0,6,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,160,61,5,0,120,136,1,0,0,0,0,0,0,0,0,0,224,56,7,0,152,30,5,0,0,0,0,0,80,255,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,8,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,216,3,0,0,114,21,0,0,0,0,0,0,0,0,0,0,86,51,0,0,162,48,0,0,8,7,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,72,53,8,0,128,138,1,0,0,0,0,0,0,0,0,0,184,168,7,0,16,1,8,0,0,0,0,0,128,203,7,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,204,30,0,0,120,35,0,0,0,0,0,0,0,0,0,0,120,43,0,0,140,60,0,0,26,4,0,0,0,7,0,0,156,5,0,0,104,4,0,0,254,2,0,0,40,176,145,0,0,4,0,0,32,1,0,0,216,0,0,0,4,0,0,0,3,0,0,0,56,173,8,0,128,138,1,0,0,0,0,0,0,0,0,0,184,168,7,0,144,109,8,0,0,0,0,0,176,100,7,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,186,35,0,0,22,45,0,0,0,0,0,0,0,0,0,0,120,43,0,0,140,60,0,0,26,4,0,0,0,7,0,0,156,5,0,0,104,4,0,0,254,2,0,0,40,176,145,0,0,4,0,0,32,1,0,0,216,0,0,0,4,0,0,0,3,0,0,0,128,138,1,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,88,237,8,0,0,0,0,0,176,100,7,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,102,35,0,0,94,35,0,0,0,0,0,0,0,0,0,0,120,43,0,0,140,60,0,0,194,8,0,0,0,7,0,0,156,5,0,0,104,4,0,0,254,2,0,0,40,176,145,0,0,4,0,0,32,1,0,0,216,0,0,0,4,0,0,0,3,0,0,0,160,250,1,0,112,34,8,0,0,0,0,0,0,0,0,0,104,221,5,0,80,154,1,0,0,0,0,0,168,95,8,0,160,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,3,5,8,0,0,0,0,0,0,0,0,0,0,18,48,0,0,28,18,0,0,0,0,0,0,0,0,0,0,172,16,0,0,176,4,0,0,194,9,0,0,184,9,0,0,82,16,0,0,22,0,0,0,222,41,0,0,208,176,145,0,0,8,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,30,3,0,112,34,8,0,0,0,0,0,0,0,0,0,104,221,5,0,0,114,2,0,0,0,0,0,168,95,8,0,160,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,3,5,8,0,0,0,0,0,0,0,0,0,0,170,38,0,0,104,26,0,0,0,0,0,0,0,0,0,0,172,16,0,0,8,40,0,0,194,9,0,0,184,9,0,0,82,16,0,0,22,0,0,0,222,41,0,0,208,176,145,0,0,8,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,34,8,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,24,178,6,0,0,0,0,0,168,95,8,0,160,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,3,5,8,0,0,0,0,0,0,0,0,0,0,128,3,0,0,86,0,0,0,0,0,0,0,0,0,0,0,172,16,0,0,8,40,0,0,194,9,0,0,184,9,0,0,82,16,0,0,22,0,0,0,222,41,0,0,208,176,145,0,0,8,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,221,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,16,177,6,0,0,0,0,0,32,134,6,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,8,0,0,0,0,0,0,0,0,0,0,198,22,0,0,82,9,0,0,0,0,0,0,0,0,0,0,156,54,0,0,148,5,0,0,240,2,0,0,56,15,0,0,12,17,0,0,0,0,0,0,224,13,0,0,0,0,0,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,24,206,2,0,216,73,3,0,0,0,0,0,0,0,0,0,232,167,7,0,0,67,2,0,0,0,0,0,40,161,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,10,2,0,0,1,0,0,0,0,0,0,0,0,0,108,34,0,0,174,36,0,0,0,0,0,0,0,0,0,0,150,11,0,0,130,51,0,0,112,16,0,0,110,15,0,0,192,2,0,0,100,19,0,0,104,59,0,0,192,173,145,0,0,3,0,0,240,0,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,73,3,0,0,0,0,0,0,0,0,0,0,0,0,0,232,167,7,0,64,23,6,0,0,0,0,0,40,161,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,10,2,0,0,1,0,0,0,0,0,0,0,0,0,224,23,0,0,144,32,0,0,0,0,0,0,0,0,0,0,150,11,0,0,130,51,0,0,112,16,0,0,110,15,0,0,192,2,0,0,100,19,0,0,104,59,0,0,192,173,145,0,0,3,0,0,240,0,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,133,7,0,0,0,0,0,0,0,0,0,0,0,0,0,200,190,7,0,160,129,7,0,0,0,0,0,40,161,4,0,80,150,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,68,0,4,2,0,64,0,0,0,0,0,0,0,0,0,0,32,56,0,0,128,35,0,0,0,0,0,0,0,0,0,0,170,46,0,0,98,22,0,0,72,17,0,0,236,1,0,0,134,11,0,0,0,0,0,0,90,15,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,77,3,0,96,88,3,0,0,0,0,0,0,0,0,0,216,194,1,0,208,74,3,0,0,0,0,0,192,154,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,0,0,0,2,0,0,0,0,0,0,16,1,0,0,0,0,0,0,0,0,0,0,0,178,4,0,0,8,42,0,0,0,0,0,0,0,0,0,0,100,63,0,0,172,34,0,0,254,3,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,184,110,7,0,0,0,0,0,0,0,0,0,0,0,0,0,64,164,6,0,192,170,8,0,0,0,0,0,40,98,7,0,160,201,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,1,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,222,19,0,0,180,22,0,0,0,0,0,0,0,0,0,0,72,61,0,0,98,2,0,0,102,5,0,0,44,18,0,0,234,15,0,0,250,18,0,0,102,10,0,0,208,175,145,0,32,0,0,0,236,0,0,0,16,1,0,0,3,0,0,0,4,0,0,0,16,158,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,184,96,8,0,0,0,0,0,168,117,1,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,133,0,0,0,2,0,0,0,0,0,0,10,0,16,0,0,0,0,0,0,0,0,0,0,124,3,0,0,88,40,0,0,0,0,0,0,0,0,0,0,236,22,0,0,92,38,0,0,210,17,0,0,8,1,0,0,76,2,0,0,190,17,0,0,4,30,0,0,104,157,215,0,0,4,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,136,31,6,0,0,0,0,0,72,172,6,0,0,0,0,0,104,221,5,0,208,113,4,0,0,0,0,0,128,145,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,0,0,1,0,0,0,0,0,0,0,0,0,212,11,0,0,182,44,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,92,7,0,208,35,8,0,0,0,0,0,0,0,0,0,104,174,7,0,96,43,7,0,0,0,0,0,144,84,8,0,8,147,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,4,11,4,0,0,0,0,0,0,0,0,0,0,0,14,14,0,0,206,32,0,0,0,0,0,0,0,0,0,0,76,58,0,0,218,26,0,0,52,18,0,0,48,9,0,0,126,17,0,0,0,0,0,0,236,36,0,0,0,0,0,0,0,8,0,0,128,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,72,255,6,0,208,35,8,0,0,0,0,0,0,0,0,0,104,174,7,0,16,215,6,0,0,0,0,0,144,84,8,0,8,147,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,4,11,4,0,0,0,0,0,0,0,0,0,0,0,116,58,0,0,82,14,0,0,0,0,0,0,0,0,0,0,76,58,0,0,186,59,0,0,52,18,0,0,48,9,0,0,126,17,0,0,0,0,0,0,236,36,0,0,0,0,0,0,0,8,0,0,128,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,208,35,8,0,0,0,0,0,0,0,0,0,0,0,0,0,104,174,7,0,160,186,7,0,0,0,0,0,144,84,8,0,8,147,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,4,11,4,0,0,0,0,0,0,0,0,0,0,0,148,35,0,0,172,11,0,0,0,0,0,0,0,0,0,0,76,58,0,0,98,5,0,0,52,18,0,0,48,9,0,0,126,17,0,0,0,0,0,0,236,36,0,0,0,0,0,0,0,8,0,0,128,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,128,30,7,0,120,136,1,0,0,0,0,0,0,0,0,0,224,56,7,0,216,241,6,0,0,0,0,0,144,88,7,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,9,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,170,45,0,0,94,36,0,0,0,0,0,0,0,0,0,0,86,51,0,0,114,62,0,0,8,7,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,168,58,2,0,192,204,2,0,0,0,0,0,0,0,0,0,96,135,2,0,104,200,1,0,24,163,4,0,128,161,4,0,128,194,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,11,0,0,4,0,0,0,0,0,0,0,0,0,22,2,0,0,240,17,0,0,0,0,0,0,0,0,0,0,110,56,0,0,0,0,0,0,162,16,0,0,50,12,0,0,96,5,0,0,0,0,0,0,44,40,0,0,0,0,0,0,0,32,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,72,24,1,0,192,204,2,0,0,0,0,0,0,0,0,0,96,135,2,0,240,215,8,0,24,163,4,0,144,84,8,0,128,194,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,11,0,0,4,0,0,0,0,0,0,0,0,0,136,17,0,0,204,6,0,0,0,0,0,0,0,0,0,0,110,56,0,0,0,0,0,0,162,16,0,0,50,12,0,0,96,5,0,0,0,0,0,0,44,40,0,0,0,0,0,0,0,32,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,192,204,2,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,32,248,5,0,24,163,4,0,168,183,7,0,128,194,2,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,3,11,0,0,4,0,0,0,0,0,0,0,0,0,172,52,0,0,122,31,0,0,0,0,0,0,0,0,0,0,110,56,0,0,0,0,0,0,162,16,0,0,50,12,0,0,96,5,0,0,0,0,0,0,44,40,0,0,0,0,0,0,0,32,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,24,39,3,0,0,0,0,0,0,0,0,0,0,0,0,0,64,171,7,0,88,35,3,0,160,173,1,0,56,32,3,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,8,0,0,2,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,0,0,0,0,150,55,0,0,8,18,0,0,0,0,0,0,0,0,0,0,126,30,0,0,20,60,0,0,126,12,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,136,157,8,0,88,184,8,0,0,0,0,0,0,0,0,0,0,38,7,0,136,151,8,0,0,0,0,0,80,167,8,0,0,227,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,1,21,0,0,1,0,0,0,0,0,0,0,0,0,96,32,0,0,70,4,0,0,0,0,0,0,0,0,0,0,78,50,0,0,76,19,0,0,26,15,0,0,248,19,0,0,44,3,0,0,198,3,0,0,96,10,0,0,224,174,145,0,0,2,0,0,240,0,0,0,128,1,0,0,3,0,0,0,4,0,0,0,168,202,1,0,176,247,2,0,0,0,0,0,0,0,0,0,104,221,5,0,112,104,1,0,0,0,0,0,176,237,2,0,168,84,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,19,0,0,1,0,0,0,0,0,0,0,0,0,168,36,0,0,80,19,0,0,0,0,0,0,0,0,0,0,138,11,0,0,254,15,0,0,76,14,0,0,70,0,0,0,218,19,0,0,20,4,0,0,108,31,0,0,56,177,145,0,0,4,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,248,198,2,0,176,247,2,0,0,0,0,0,0,0,0,0,104,221,5,0,48,61,2,0,0,0,0,0,176,237,2,0,168,84,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,19,0,0,1,0,0,0,0,0,0,0,0,0,92,20,0,0,254,37,0,0,0,0,0,0,0,0,0,0,138,11,0,0,254,15,0,0,76,14,0,0,70,0,0,0,218,19,0,0,20,4,0,0,108,31,0,0,56,177,145,0,0,4,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,176,247,2,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,248,3,6,0,0,0,0,0,176,237,2,0,168,84,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,19,0,0,1,0,0,0,0,0,0,0,0,0,106,46,0,0,44,27,0,0,0,0,0,0,0,0,0,0,138,11,0,0,254,15,0,0,76,14,0,0,70,0,0,0,218,19,0,0,20,4,0,0,108,31,0,0,56,177,145,0,0,4,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,136,209,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,192,68,2,0,0,0,0,0,152,189,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,32,0,0,0,0,0,0,0,0,0,0,6,61,0,0,208,3,0,0,0,0,0,0,0,0,0,0,250,6,0,0,236,3,0,0,38,2,0,0,176,14,0,0,18,16,0,0,90,16,0,0,22,41,0,0,0,174,145,0,0,16,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,2,3,0,8,15,3,0,0,0,0,0,0,0,0,0,232,167,7,0,200,255,2,0,0,0,0,0,192,154,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,8,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,72,16,0,0,36,47,0,0,0,0,0,0,0,0,0,0,60,63,0,0,210,61,0,0,6,8,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,166,5,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,96,131,5,0,0,0,0,0,40,161,4,0,144,153,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,2,2,0,0,8,0,0,0,0,0,0,0,0,0,160,29,0,0,204,34,0,0,0,0,0,0,0,0,0,0,222,51,0,0,54,0,0,0,172,5,0,0,66,12,0,0,6,3,0,0,0,0,0,0,214,38,0,0,0,0,0,0,0,96,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,41,4,0,160,187,8,0,0,0,0,0,0,0,0,0,216,194,1,0,128,39,4,0,0,0,0,0,184,37,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,8,0,0,2,0,0,0,0,0,0,16,1,0,0,0,0,0,0,0,0,0,0,0,182,54,0,0,88,7,0,0,0,0,0,0,0,0,0,0,124,45,0,0,114,24,0,0,228,9,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,72,171,7,0,224,182,7,0,0,0,0,0,0,0,0,0,216,194,1,0,112,167,7,0,160,173,1,0,168,175,7,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,0,0,0,0,60,22,0,0,96,7,0,0,0,0,0,0,0,0,0,0,184,43,0,0,138,34,0,0,8,7,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,224,182,7,0,0,0,0,0,0,0,0,0,0,0,0,0,216,194,1,0,208,178,7,0,160,173,1,0,168,175,7,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,2,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,0,0,0,0,118,19,0,0,30,34,0,0,0,0,0,0,0,0,0,0,184,43,0,0,138,34,0,0,8,7,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,56,131,6,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,40,40,6,0,0,0,0,0,32,0,1,0,240,185,2,0,120,252,5,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,1,0,0,0,0,0,0,0,0,0,0,0,106,34,0,0,212,23,0,0,0,0,0,0,0,0,0,0,114,33,0,0,194,17,0,0,118,11,0,0,14,3,0,0,164,11,0,0,42,4,0,0,242,13,0,0,104,174,145,0,0,16,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,15,3,0,0,0,0,0,0,0,0,0,0,0,0,0,216,194,1,0,56,14,3,0,0,0,0,0,168,95,8,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,8,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,216,2,0,0,36,13,0,0,0,0,0,0,0,0,0,0,60,63,0,0,210,61,0,0,6,8,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,10,3,0,8,15,3,0,0,0,0,0,0,0,0,0,216,194,1,0,32,8,3,0,0,0,0,0,64,5,3,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,8,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,218,59,0,0,50,10,0,0,0,0,0,0,0,0,0,0,60,63,0,0,210,61,0,0,6,8,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,251,7,0,24,8,8,0,0,0,0,0,0,0,0,0,96,135,2,0,144,242,7,0,0,0,0,0,232,196,4,0,80,164,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,10,1,0,0,0,0,0,0,0,0,0,0,0,90,39,0,0,138,18,0,0,0,0,0,0,0,0,0,0,244,56,0,0,122,38,0,0,80,2,0,0,56,12,0,0,212,3,0,0,198,4,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,8,8,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,208,2,8,0,0,0,0,0,232,196,4,0,80,164,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,1,0,0,0,0,0,0,0,0,0,0,0,54,2,0,0,48,46,0,0,0,0,0,0,0,0,0,0,244,56,0,0,122,38,0,0,80,2,0,0,56,12,0,0,212,3,0,0,198,4,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,136,8,0,152,159,1,0,0,0,0,0,0,0,0,0,144,47,2,0,176,74,8,0,0,0,0,0,192,154,4,0,168,84,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,0,19,0,8,0,0,0,0,0,0,0,0,0,0,94,17,0,0,106,20,0,0,0,0,0,0,0,0,0,0,122,30,0,0,68,18,0,0,236,5,0,0,192,10,0,0,182,1,0,0,28,16,0,0,176,38,0,0,0,173,145,0,0,8,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,64,176,6,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,128,87,6,0,0,0,0,0,88,42,6,0,0,227,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,1,21,0,0,1,0,0,0,0,0,0,0,0,0,72,4,0,0,2,32,0,0,0,0,0,0,0,0,0,0,102,50,0,0,74,33,0,0,40,9,0,0,248,19,0,0,72,13,0,0,230,0,0,0,96,10,0,0,224,174,145,0,0,2,0,0,240,0,0,0,128,1,0,0,3,0,0,0,4,0,0,0,56,242,5,0,32,18,7,0,0,0,0,0,0,0,0,0,96,159,4,0,64,238,5,0,0,0,0,0,192,154,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,8,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,116,41,0,0,236,7,0,0,0,0,0,0,0,0,0,0,186,23,0,0,246,1,0,0,88,16,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,0,43,1,0,32,59,1,0,0,0,0,0,0,0,0,0,64,164,6,0,224,33,1,0,0,0,0,0,40,161,4,0,192,152,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,9,2,2,0,0,0,0,0,0,0,0,0,0,0,12,17,0,0,206,14,0,0,0,0,0,0,0,0,0,0,94,27,0,0,222,1,0,0,52,6,0,0,42,17,0,0,184,7,0,0,0,0,0,0,216,46,0,0,0,0,0,0,0,6,0,0,224,0,0,0,240,0,0,0,3,0,0,0,4,0,0,0,32,59,1,0,0,0,0,0,0,0,0,0,0,0,0,0,64,164,6,0,200,50,1,0,0,0,0,0,40,161,4,0,192,152,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,9,2,2,0,0,0,0,0,0,0,0,0,0,0,24,41,0,0,114,4,0,0,0,0,0,0,0,0,0,0,94,27,0,0,196,35,0,0,52,6,0,0,42,17,0,0,184,7,0,0,0,0,0,0,216,46,0,0,0,0,0,0,0,6,0,0,224,0,0,0,240,0,0,0,3,0,0,0,4,0,0,0,136,42,6,0,32,18,7,0,0,0,0,0,0,0,0,0,160,135,3,0,136,37,6,0,0,0,0,0,216,32,6,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,8,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,80,59,0,0,142,32,0,0,0,0,0,0,0,0,0,0,70,34,0,0,240,28,0,0,88,16,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,216,42,4,0,120,136,1,0,0,0,0,0,0,0,0,0,224,56,7,0,112,16,4,0,0,0,0,0,104,239,3,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,8,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,36,13,0,0,0,36,0,0,0,0,0,0,0,0,0,0,86,51,0,0,162,48,0,0,8,7,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,240,11,5,0,0,0,0,0,0,0,0,0,0,0,0,0,192,177,6,0,0,197,4,0,0,0,0,0,216,164,4,0,80,164,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,0,10,2,0,0,0,0,0,0,0,0,0,0,0,30,0,0,0,152,10,0,0,0,0,0,0,0,0,0,0,244,56,0,0,28,28,0,0,40,13,0,0,88,18,0,0,228,5,0,0,106,18,0,0,0,0,0,0,0,0,0,0,0,3,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,128,64,6,0,32,18,7,0,0,0,0,0,0,0,0,0,136,80,6,0,152,61,6,0,0,0,0,0,200,58,6,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,8,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,132,54,0,0,58,23,0,0,0,0,0,0,0,0,0,0,70,34,0,0,106,26,0,0,88,16,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,56,124,3,0,32,65,4,0,0,0,0,0,0,0,0,0,144,47,2,0,104,101,3,0,0,0,0,0,168,95,8,0,224,9,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,1,3,0,8,0,0,0,0,0,0,0,0,0,0,146,42,0,0,28,9,0,0,0,0,0,0,0,0,0,0,174,60,0,0,0,0,0,0,38,10,0,0,130,1,0,0,240,7,0,0,0,0,0,0,180,8,0,0,0,0,0,0,16,8,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,223,2,0,32,65,4,0,0,0,0,0,0,0,0,0,144,47,2,0,248,201,2,0,0,0,0,0,168,95,8,0,224,9,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,3,0,8,0,0,0,0,0,0,0,0,0,0,198,43,0,0,242,3,0,0,0,0,0,0,0,0,0,0,140,55,0,0,0,0,0,0,38,10,0,0,130,1,0,0,240,7,0,0,0,0,0,0,180,8,0,0,0,0,0,0,16,8,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,13,3,0,32,65,4,0,0,0,0,0,0,0,0,0,144,47,2,0,248,246,2,0,0,0,0,0,168,95,8,0,224,9,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,1,3,0,8,0,0,0,0,0,0,0,0,0,0,8,43,0,0,114,32,0,0,0,0,0,0,0,0,0,0,4,6,0,0,0,0,0,0,38,10,0,0,130,1,0,0,240,7,0,0,0,0,0,0,180,8,0,0,0,0,0,0,16,8,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,56,3,0,32,65,4,0,0,0,0,0,0,0,0,0,144,47,2,0,160,37,3,0,0,0,0,0,168,95,8,0,224,9,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,1,3,0,8,0,0,0,0,0,0,0,0,0,0,164,13,0,0,164,20,0,0,0,0,0,0,0,0,0,0,4,6,0,0,0,0,0,0,38,10,0,0,130,1,0,0,240,7,0,0,0,0,0,0,180,8,0,0,0,0,0,0,16,8,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,104,2,0,32,65,4,0,0,0,0,0,0,0,0,0,144,47,2,0,240,92,2,0,0,0,0,0,168,95,8,0,224,9,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,3,0,8,0,0,0,0,0,0,0,0,0,0,110,48,0,0,66,3,0,0,0,0,0,0,0,0,0,0,140,55,0,0,0,0,0,0,38,10,0,0,130,1,0,0,240,7,0,0,0,0,0,0,180,8,0,0,0,0,0,0,16,8,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,132,2,0,32,65,4,0,0,0,0,0,0,0,0,0,144,47,2,0,128,119,2,0,0,0,0,0,168,95,8,0,224,9,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,3,0,8,0,0,0,0,0,0,0,0,0,0,102,28,0,0,64,37,0,0,0,0,0,0,0,0,0,0,140,55,0,0,0,0,0,0,38,10,0,0,130,1,0,0,240,7,0,0,0,0,0,0,180,8,0,0,0,0,0,0,16,8,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,232,3,0,32,65,4,0,0,0,0,0,0,0,0,0,144,47,2,0,72,200,3,0,0,0,0,0,168,95,8,0,224,9,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,3,0,8,0,0,0,0,0,0,0,0,0,0,44,39,0,0,208,12,0,0,0,0,0,0,0,0,0,0,140,55,0,0,0,0,0,0,38,10,0,0,130,1,0,0,240,7,0,0,0,0,0,0,180,8,0,0,0,0,0,0,16,8,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,173,3,0,32,65,4,0,0,0,0,0,0,0,0,0,144,47,2,0,24,149,3,0,0,0,0,0,168,95,8,0,224,9,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,3,0,8,0,0,0,0,0,0,0,0,0,0,86,42,0,0,144,41,0,0,0,0,0,0,0,0,0,0,140,55,0,0,0,0,0,0,38,10,0,0,130,1,0,0,240,7,0,0,0,0,0,0,180,8,0,0,0,0,0,0,16,8,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,84,3,0,32,65,4,0,0,0,0,0,0,0,0,0,144,47,2,0,160,69,3,0,0,0,0,0,168,95,8,0,224,9,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,1,3,0,8,0,0,0,0,0,0,0,0,0,0,252,20,0,0,174,40,0,0,0,0,0,0,0,0,0,0,174,60,0,0,0,0,0,0,38,10,0,0,130,1,0,0,240,7,0,0,0,0,0,0,180,8,0,0,0,0,0,0,16,8,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,156,2,0,32,65,4,0,0,0,0,0,0,0,0,0,144,47,2,0,152,143,2,0,0,0,0,0,168,95,8,0,224,9,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,1,3,0,8,0,0,0,0,0,0,0,0,0,0,124,56,0,0,28,23,0,0,0,0,0,0,0,0,0,0,174,60,0,0,0,0,0,0,38,10,0,0,130,1,0,0,240,7,0,0,0,0,0,0,180,8,0,0,0,0,0,0,16,8,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,183,2,0,32,65,4,0,0,0,0,0,0,0,0,0,144,47,2,0,160,170,2,0,0,0,0,0,168,95,8,0,224,9,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,3,0,8,0,0,0,0,0,0,0,0,0,0,214,28,0,0,64,25,0,0,0,0,0,0,0,0,0,0,140,55,0,0,0,0,0,0,38,10,0,0,130,1,0,0,240,7,0,0,0,0,0,0,180,8,0,0,0,0,0,0,16,8,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,65,4,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,160,36,4,0,0,0,0,0,168,95,8,0,224,9,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,4,0,0,0,0,0,1,3,0,8,0,0,0,0,0,0,0,0,0,0,30,43,0,0,32,25,0,0,0,0,0,0,0,0,0,0,4,6,0,0,0,0,0,0,38,10,0,0,130,1,0,0,240,7,0,0,0,0,0,0,180,8,0,0,0,0,0,0,16,8,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,232,1,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,64,219,1,0,240,56,5,0,144,234,6,0,168,38,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,5,17,8,0,0,0,0,0,0,0,0,0,0,0,136,25,0,0,244,39,0,0,0,0,0,0,0,0,0,0,82,26,0,0,98,24,0,0,146,11,0,0,218,2,0,0,114,1,0,0,166,3,0,0,116,50,0,0,8,211,148,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,88,95,8,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,128,242,7,0,0,0,0,0,184,191,7,0,80,164,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,0,10,2,0,0,0,0,0,0,0,0,0,0,0,210,57,0,0,24,42,0,0,0,0,0,0,0,0,0,0,154,20,0,0,14,33,0,0,76,11,0,0,56,9,0,0,210,3,0,0,210,14,0,0,0,0,0,0,0,0,0,0,0,4,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,88,25,7,0,0,0,0,0,72,172,6,0,0,0,0,0,168,163,7,0,208,21,7,0,0,0,0,0,128,145,4,0,208,9,3,0,224,15,7,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,1,0,1,133,0,128,0,0,0,0,0,0,0,0,0,0,64,26,0,0,190,11,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,76,8,0,0,0,0,0,72,172,6,0,0,0,0,0,32,127,5,0,192,161,7,0,0,0,0,0,128,145,4,0,208,9,3,0,80,156,7,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,1,0,1,133,0,128,0,0,0,0,0,0,0,0,0,0,238,50,0,0,196,47,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,244,8,0,0,0,0,0,72,172,6,0,0,0,0,0,0,38,7,0,200,216,7,0,0,0,0,0,128,145,4,0,208,9,3,0,88,211,7,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,0,128,0,0,0,0,0,0,0,0,0,0,26,13,0,0,108,17,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,126,1,0,0,0,0,0,72,172,6,0,0,0,0,0,96,135,2,0,96,69,8,0,0,0,0,0,128,145,4,0,208,9,3,0,24,66,8,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,4,0,1,133,0,128,0,0,0,0,0,0,0,0,0,0,26,48,0,0,204,36,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,200,2,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,110,8,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,16,103,8,0,0,0,0,0,168,183,7,0,208,135,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,2,11,0,0,8,0,0,0,0,0,0,0,0,0,112,54,0,0,112,8,0,0,0,0,0,0,0,0,0,0,12,1,0,0,140,27,0,0,86,18,0,0,46,7,0,0,246,17,0,0,0,0,0,0,176,18,0,0,0,0,0,0,0,32,0,0,224,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,208,91,3,0,88,137,3,0,0,0,0,0,0,0,0,0,64,171,7,0,64,77,3,0,0,0,0,0,16,182,4,0,192,152,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,9,2,0,8,0,0,0,0,0,0,0,0,0,0,60,57,0,0,142,2,0,0,0,0,0,0,0,0,0,0,94,27,0,0,64,2,0,0,204,17,0,0,42,17,0,0,184,7,0,0,0,0,0,0,216,46,0,0,0,0,0,0,0,6,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,71,1,0,112,86,1,0,0,0,0,0,0,0,0,0,232,233,7,0,200,65,1,0,0,0,0,0,40,161,4,0,192,152,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,9,2,0,1,0,0,0,0,0,0,0,0,0,0,26,46,0,0,12,46,0,0,0,0,0,0,0,0,0,0,94,27,0,0,206,38,0,0,124,12,0,0,42,17,0,0,184,7,0,0,0,0,0,0,216,46,0,0,0,0,0,0,0,6,0,0,240,0,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,234,1,0,136,123,5,0,0,0,0,0,0,0,0,0,160,234,7,0,56,137,1,0,0,0,0,0,160,48,1,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,0,20,0,0,8,0,0,0,0,0,0,0,0,0,58,28,0,0,144,9,0,0,0,0,0,0,0,0,0,0,176,58,0,0,112,16,0,0,130,16,0,0,132,2,0,0,2,18,0,0,120,2,0,0,242,56,0,0,0,176,145,0,0,2,0,0,240,0,0,0,96,1,0,0,3,0,0,0,4,0,0,0,80,251,2,0,136,123,5,0,0,0,0,0,0,0,0,0,160,234,7,0,248,95,2,0,0,0,0,0,192,223,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,0,20,0,0,8,0,0,0,0,0,0,0,0,0,20,35,0,0,26,34,0,0,0,0,0,0,0,0,0,0,176,58,0,0,112,16,0,0,130,16,0,0,132,2,0,0,2,18,0,0,120,2,0,0,242,56,0,0,0,176,145,0,0,2,0,0,240,0,0,0,96,1,0,0,3,0,0,0,4,0,0,0,136,123,5,0,0,0,0,0,0,0,0,0,0,0,0,0,160,234,7,0,168,112,6,0,0,0,0,0,192,223,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,0,20,0,0,8,0,0,0,0,0,0,0,0,0,164,55,0,0,176,20,0,0,0,0,0,0,0,0,0,0,176,58,0,0,112,16,0,0,130,16,0,0,132,2,0,0,2,18,0,0,120,2,0,0,242,56,0,0,0,176,145,0,0,2,0,0,240,0,0,0,96,1,0,0,3,0,0,0,4,0,0,0,160,143,3,0,0,0,0,0,0,0,0,0,0,0,0,0,160,234,7,0,176,119,3,0,0,0,0,0,144,84,8,0,136,252,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,198,25,0,0,100,36,0,0,0,0,0,0,0,0,0,0,172,22,0,0,222,7,0,0,124,2,0,0,64,13,0,0,168,2,0,0,0,0,0,0,134,1,0,0,0,0,0,0,0,1,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,24,30,6,0,208,119,6,0,0,0,0,0,0,0,0,0,200,190,7,0,224,238,5,0,0,0,0,0,176,237,2,0,176,109,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,0,19,0,0,1,0,0,0,0,0,0,0,0,0,36,10,0,0,146,38,0,0,0,0,0,0,0,0,0,0,88,8,0,0,214,32,0,0,218,14,0,0,74,15,0,0,16,15,0,0,196,0,0,0,16,30,0,0,72,173,145,0,0,1,0,0,240,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,208,119,6,0,0,0,0,0,0,0,0,0,0,0,0,0,200,190,7,0,160,69,6,0,0,0,0,0,176,237,2,0,176,109,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,0,19,0,0,1,0,0,0,0,0,0,0,0,0,78,9,0,0,32,6,0,0,0,0,0,0,0,0,0,0,88,8,0,0,214,32,0,0,218,14,0,0,74,15,0,0,16,15,0,0,196,0,0,0,16,30,0,0,72,173,145,0,0,1,0,0,240,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,24,224,6,0,0,0,0,0,0,0,0,0,0,0,0,0,232,167,7,0,224,179,6,0,0,0,0,0,104,238,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,254,0,0,0,128,42,0,0,0,0,0,0,0,0,0,0,68,16,0,0,228,10,0,0,124,14,0,0,218,16,0,0,252,12,0,0,136,7,0,0,68,57,0,0,128,175,145,0,130,0,0,0,196,0,0,0,240,0,0,0,3,0,0,0,4,0,0,0,40,246,7,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,40,146,7,0,0,0,0,0,216,67,5,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,64,0,0,0,0,0,0,0,0,0,0,202,47,0,0,234,9,0,0,0,0,0,0,0,0,0,0,244,41,0,0,244,6,0,0,76,3,0,0,0,2,0,0,22,3,0,0,118,1,0,0,152,14,0,0,136,174,145,0,0,4,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,104,32,3,0,32,73,8,0,0,0,0,0,0,0,0,0,184,168,7,0,0,115,2,0,0,0,0,0,168,95,8,0,200,3,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,3,4,0,0,0,0,0,0,0,0,0,0,0,198,16,0,0,46,46,0,0,0,0,0,0,0,0,0,0,226,6,0,0,158,45,0,0,156,1,0,0,176,2,0,0,32,8,0,0,128,5,0,0,210,47,0,0,240,176,145,0,0,4,0,0,48,1,0,0,216,0,0,0,4,0,0,0,3,0,0,0,32,73,8,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,120,182,6,0,0,0,0,0,168,95,8,0,200,3,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,3,4,0,0,0,0,0,0,0,0,0,0,0,242,53,0,0,2,7,0,0,0,0,0,0,0,0,0,0,226,6,0,0,158,45,0,0,156,1,0,0,176,2,0,0,32,8,0,0,128,5,0,0,210,47,0,0,240,176,145,0,0,4,0,0,48,1,0,0,216,0,0,0,4,0,0,0,3,0,0,0,160,250,2,0,0,0,0,0,0,0,0,0,0,0,0,0,232,167,7,0,80,95,2,0,0,0,0,0,0,223,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,82,10,0,0,42,41,0,0,0,0,0,0,0,0,0,0,136,37,0,0,248,47,0,0,144,0,0,0,244,15,0,0,178,2,0,0,134,9,0,0,242,1,0,0,160,134,148,0,0,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,120,6,7,0,224,247,7,0,0,0,0,0,0,0,0,0,104,221,5,0,216,220,6,0,0,0,0,0,176,100,7,0,64,50,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,10,0,0,8,0,0,0,0,0,0,0,0,0,74,19,0,0,58,6,0,0,0,0,0,0,0,0,0,0,54,29,0,0,212,45,0,0,182,11,0,0,80,4,0,0,196,6,0,0,178,7,0,0,26,56,0,0,0,0,0,0,0,8,0,0,96,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,224,247,7,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,56,147,7,0,0,0,0,0,176,100,7,0,64,50,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,10,0,0,8,0,0,0,0,0,0,0,0,0,204,2,0,0,242,43,0,0,0,0,0,0,0,0,0,0,54,29,0,0,130,20,0,0,182,11,0,0,80,4,0,0,196,6,0,0,178,7,0,0,26,56,0,0,0,0,0,0,0,8,0,0,96,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,136,175,6,0,224,247,7,0,0,0,0,0,0,0,0,0,104,221,5,0,72,133,6,0,0,0,0,0,176,100,7,0,64,50,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,10,0,0,8,0,0,0,0,0,0,0,0,0,218,53,0,0,28,7,0,0,0,0,0,0,0,0,0,0,54,29,0,0,60,59,0,0,182,11,0,0,80,4,0,0,196,6,0,0,178,7,0,0,26,56,0,0,0,0,0,0,0,8,0,0,96,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,200,69,3,0,144,101,3,0,0,0,0,0,0,0,0,0,64,171,7,0,176,56,3,0,0,0,0,0,176,192,6,0,64,10,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,17,0,8,0,0,0,0,0,0,0,0,0,0,48,40,0,0,174,13,0,0,0,0,0,0,0,0,0,0,62,25,0,0,60,5,0,0,212,8,0,0,60,6,0,0,250,15,0,0,0,0,0,0,194,0,0,0,0,0,0,0,0,2,0,0,128,1,0,0,0,1,0,0,4,0,0,0,3,0,0,0,144,101,3,0,0,0,0,0,0,0,0,0,0,0,0,0,64,171,7,0,104,84,3,0,0,0,0,0,176,192,6,0,64,10,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,17,0,8,0,0,0,0,0,0,0,0,0,0,90,63,0,0,222,28,0,0,0,0,0,0,0,0,0,0,62,25,0,0,60,5,0,0,212,8,0,0,60,6,0,0,250,15,0,0,0,0,0,0,194,0,0,0,0,0,0,0,0,2,0,0,128,1,0,0,0,1,0,0,4,0,0,0,3,0,0,0,200,37,3,0,0,0,0,0,0,0,0,0,0,0,0,0,160,234,7,0,200,13,3,0,0,0,0,0,176,192,6,0,64,10,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,17,0,8,0,0,0,0,0,0,0,0,0,0,100,48,0,0,184,14,0,0,0,0,0,0,0,0,0,0,62,25,0,0,78,11,0,0,158,9,0,0,60,6,0,0,250,15,0,0,0,0,0,0,194,0,0,0,0,0,0,0,0,3,0,0,128,1,0,0,0,1,0,0,4,0,0,0,3,0,0,0,16,204,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,40,47,6,0,0,0,0,0,232,205,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,2,0,0,0,0,0,0,10,0,64,0,0,0,0,0,0,0,0,0,0,64,61,0,0,246,41,0,0,0,0,0,0,0,0,0,0,14,30,0,0,164,42,0,0,248,7,0,0,54,7,0,0,20,2,0,0,44,14,0,0,100,15,0,0,112,174,145,0,0,4,0,0,128,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,56,161,1,0,0,0,0,0,0,0,0,0,0,0,0,0,184,230,7,0,16,153,1,0,0,0,0,0,144,142,1,0,80,164,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,2,0,0,0,0,0,0,0,0,0,0,0,192,61,0,0,248,34,0,0,0,0,0,0,0,0,0,0,244,56,0,0,220,9,0,0,130,19,0,0,88,18,0,0,228,5,0,0,64,7,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,41,3,0,0,0,0,0,0,0,0,0,0,0,0,0,232,233,7,0,208,40,3,0,0,0,0,0,56,72,3,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,71,0,0,0,2,0,0,0,0,0,0,16,0,0,1,0,0,0,0,0,0,0,0,0,238,59,0,0,36,3,0,0,0,0,0,0,0,0,0,0,54,45,0,0,84,34,0,0,254,3,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,152,119,6,0,32,18,7,0,0,0,0,0,0,0,0,0,240,115,6,0,136,112,6,0,0,0,0,0,64,109,6,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,0,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,244,5,0,0,138,24,0,0,0,0,0,0,0,0,0,0,70,34,0,0,156,44,0,0,246,14,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,40,206,2,0,0,0,0,0,0,0,0,0,0,0,0,0,160,234,7,0,80,207,1,0,0,0,0,0,168,109,1,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,2,0,0,0,0,0,10,2,0,0,4,0,0,0,0,0,0,0,0,0,70,51,0,0,250,2,0,0,0,0,0,0,0,0,0,0,98,47,0,0,114,55,0,0,168,13,0,0,222,5,0,0,170,10,0,0,98,17,0,0,212,43,0,0,0,0,0,0,0,1,0,0,240,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,216,22,6,0,32,18,7,0,0,0,0,0,0,0,0,0,96,159,4,0,24,19,6,0,0,0,0,0,192,154,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,8,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,228,17,0,0,42,31,0,0,0,0,0,0,0,0,0,0,186,23,0,0,246,1,0,0,88,16,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,200,29,6,0,32,18,7,0,0,0,0,0,0,0,0,0,96,159,4,0,136,25,6,0,0,0,0,0,192,154,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,8,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,164,9,0,0,122,0,0,0,0,0,0,0,0,0,0,0,186,23,0,0,246,1,0,0,88,16,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,112,86,1,0,0,0,0,0,0,0,0,0,0,0,0,0,232,233,7,0,200,78,1,0,0,0,0,0,40,161,4,0,192,152,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0])
.concat([2,0,0,0,0,0,9,2,0,1,0,0,0,0,0,0,0,0,0,0,8,44,0,0,240,21,0,0,0,0,0,0,0,0,0,0,94,27,0,0,206,38,0,0,124,12,0,0,42,17,0,0,184,7,0,0,0,0,0,0,216,46,0,0,0,0,0,0,0,6,0,0,240,0,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,158,1,0,136,187,8,0,0,0,0,0,0,0,0,0,232,233,7,0,24,63,1,0,0,0,0,0,152,54,6,0,64,10,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,17,4,0,0,0,0,0,0,0,0,0,0,0,152,24,0,0,66,6,0,0,0,0,0,0,0,0,0,0,62,25,0,0,144,22,0,0,190,12,0,0,60,6,0,0,250,15,0,0,0,0,0,0,194,0,0,0,0,0,0,0,0,2,0,0,0,1,0,0,0,1,0,0,4,0,0,0,3,0,0,0,8,193,3,0,128,0,4,0,0,0,0,0,0,0,0,0,104,221,5,0,112,167,3,0,0,0,0,0,32,46,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,10,0,16,0,0,0,0,0,0,0,0,0,0,34,3,0,0,130,16,0,0,0,0,0,0,0,0,0,0,74,46,0,0,0,0,0,0,42,16,0,0,22,7,0,0,230,18,0,0,0,0,0,0,110,45,0,0,0,0,0,0,0,8,0,0,128,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,128,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,56,223,3,0,0,0,0,0,32,46,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,16,0,0,0,0,0,0,0,0,0,0,210,28,0,0,24,18,0,0,0,0,0,0,0,0,0,0,74,46,0,0,0,0,0,0,150,7,0,0,22,7,0,0,230,18,0,0,0,0,0,0,110,45,0,0,0,0,0,0,0,8,0,0,128,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,208,27,8,0,112,100,8,0,0,0,0,0,0,0,0,0,96,159,4,0,128,23,8,0,0,0,0,0,192,154,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,8,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,216,30,0,0,154,37,0,0,0,0,0,0,0,0,0,0,86,51,0,0,58,31,0,0,134,4,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,72,20,2,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,80,11,2,0,0,0,0,0,168,183,7,0,216,142,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,11,0,0,8,0,0,0,0,0,0,0,0,0,0,45,0,0,120,32,0,0,0,0,0,0,0,0,0,0,184,54,0,0,222,49,0,0,78,15,0,0,24,8,0,0,14,5,0,0,0,0,0,0,60,41,0,0,0,0,0,0,0,16,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,136,160,1,0,224,189,1,0,0,0,0,0,0,0,0,0,0,38,7,0,144,150,1,0,0,0,0,0,144,84,8,0,168,196,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,5,11,0,0,1,0,0,0,0,0,0,0,0,0,206,26,0,0,48,31,0,0,0,0,0,0,0,0,0,0,16,23,0,0,198,8,0,0,4,14,0,0,178,11,0,0,82,0,0,0,238,10,0,0,188,1,0,0,0,0,0,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,175,1,0,224,189,1,0,0,0,0,0,0,0,0,0,0,38,7,0,168,167,1,0,0,0,0,0,144,84,8,0,168,196,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,5,11,0,0,1,0,0,0,0,0,0,0,0,0,32,18,0,0,70,12,0,0,0,0,0,0,0,0,0,0,222,62,0,0,126,42,0,0,50,11,0,0,178,11,0,0,82,0,0,0,238,10,0,0,188,1,0,0,0,0,0,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,189,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,112,182,1,0,0,0,0,0,144,84,8,0,168,196,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,5,11,0,0,1,0,0,0,0,0,0,0,0,0,16,7,0,0,90,35,0,0,0,0,0,0,0,0,0,0,222,62,0,0,126,42,0,0,50,11,0,0,178,11,0,0,82,0,0,0,238,10,0,0,188,1,0,0,0,0,0,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,52,8,0,112,100,8,0,0,0,0,0,0,0,0,0,96,159,4,0,112,44,8,0,0,0,0,0,192,154,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,8,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,124,40,0,0,102,23,0,0,0,0,0,0,0,0,0,0,86,51,0,0,58,31,0,0,134,4,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,80,37,8,0,112,100,8,0,0,0,0,0,0,0,0,0,96,159,4,0,112,31,8,0,0,0,0,0,192,154,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,0,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,224,36,0,0,100,43,0,0,0,0,0,0,0,0,0,0,86,51,0,0,58,31,0,0,134,4,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,88,92,1,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,88,207,8,0,0,0,0,0,136,194,5,0,168,84,3,0,48,81,8,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,19,0,2,0,0,0,0,0,0,0,0,0,0,52,58,0,0,72,30,0,0,0,0,0,0,0,0,0,0,76,59,0,0,18,27,0,0,170,16,0,0,240,12,0,0,80,18,0,0,94,2,0,0,112,63,0,0,80,173,145,0,0,4,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,0,252,2,0,56,161,5,0,0,0,0,0,0,0,0,0,232,233,7,0,16,97,2,0,0,0,0,0,192,223,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,20,0,8,0,0,0,0,0,0,0,0,0,0,154,10,0,0,222,4,0,0,0,0,0,0,0,0,0,0,232,60,0,0,230,31,0,0,240,1,0,0,10,6,0,0,254,11,0,0,184,0,0,0,86,16,0,0,32,176,145,0,0,2,0,0,240,0,0,0,240,0,0,0,4,0,0,0,3,0,0,0,56,161,5,0,0,0,0,0,0,0,0,0,0,0,0,0,232,233,7,0,136,116,6,0,0,0,0,0,192,223,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,20,0,8,0,0,0,0,0,0,0,0,0,0,70,39,0,0,218,21,0,0,0,0,0,0,0,0,0,0,232,60,0,0,230,31,0,0,138,16,0,0,10,6,0,0,254,11,0,0,184,0,0,0,86,16,0,0,32,176,145,0,0,2,0,0,240,0,0,0,240,0,0,0,4,0,0,0,3,0,0,0,0,240,4,0,224,205,4,0,0,0,0,0,0,0,0,0,64,171,7,0,240,171,4,0,0,0,0,0,168,140,4,0,136,252,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,110,13,0,0,2,9,0,0,0,0,0,0,0,0,0,0,172,22,0,0,174,3,0,0,124,2,0,0,64,13,0,0,168,2,0,0,0,0,0,0,134,1,0,0,0,0,0,0,0,1,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,64,44,5,0,112,18,4,0,0,0,0,0,0,0,0,0,96,135,2,0,144,14,5,0,0,0,0,0,224,189,4,0,168,155,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,149,0,0,0,2,0,0,0,0,0,0,10,2,0,0,0,128,0,0,0,0,0,0,0,20,45,0,0,180,0,0,0,0,0,0,0,0,0,0,0,120,27,0,0,136,18,0,0,206,10,0,0,80,4,0,0,236,6,0,0,96,3,0,0,26,56,0,0,0,0,0,0,0,8,0,0,224,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,104,143,7,0,0,0,0,0,0,0,0,0,0,0,0,0,200,190,7,0,152,137,7,0,0,0,0,0,40,161,4,0,80,150,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,68,0,4,2,2,0,0,0,0,0,0,0,0,0,0,0,78,47,0,0,158,26,0,0,0,0,0,0,0,0,0,0,210,8,0,0,70,40,0,0,78,17,0,0,114,17,0,0,134,11,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,224,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,128,242,2,0,96,250,4,0,0,0,0,0,0,0,0,0,160,234,7,0,232,89,2,0,0,0,0,0,32,0,1,0,240,185,2,0,136,229,1,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,192,47,0,0,252,3,0,0,0,0,0,0,0,0,0,0,208,27,0,0,96,62,0,0,178,19,0,0,218,5,0,0,124,15,0,0,0,0,0,0,226,38,0,0,0,0,0,0,0,2,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,250,4,0,0,0,0,0,0,0,0,0,0,0,0,0,160,234,7,0,152,93,6,0,0,0,0,0,32,0,1,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,130,44,0,0,236,44,0,0,0,0,0,0,0,0,0,0,208,27,0,0,96,62,0,0,178,19,0,0,218,5,0,0,124,15,0,0,0,0,0,0,226,38,0,0,0,0,0,0,0,2,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,123,8,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,168,116,8,0,0,0,0,0,168,183,7,0,208,135,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,2,11,8,0,0,0,0,0,0,0,0,0,0,0,252,51,0,0,126,16,0,0,0,0,0,0,0,0,0,0,108,41,0,0,30,12,0,0,66,17,0,0,46,7,0,0,246,17,0,0,0,0,0,0,176,18,0,0,0,0,0,0,0,32,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,30,6,0,0,0,0,0,0,0,0,0,0,0,0,0,184,12,8,0,200,65,6,0,0,0,0,0,232,163,8,0,40,181,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,13,1,0,0,0,0,0,0,0,0,0,0,0,152,10,0,0,170,0,0,0,0,0,0,0,0,0,0,0,56,14,0,0,136,55,0,0,216,1,0,0,160,16,0,0,104,12,0,0,54,1,0,0,166,39,0,0,0,0,0,0,0,20,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,203,8,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,80,199,8,0,0,0,0,0,40,16,1,0,0,227,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,21,0,0,1,0,0,0,0,0,0,0,0,0,168,43,0,0,100,6,0,0,0,0,0,0,0,0,0,0,206,31,0,0,70,57,0,0,246,3,0,0,248,19,0,0,72,13,0,0,56,10,0,0,96,10,0,0,224,174,145,0,0,18,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,80,81,1,0,8,134,3,0,72,172,6,0,0,0,0,0,144,47,2,0,48,74,1,0,0,0,0,0,128,145,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,133,0,128,0,0,0,0,0,0,0,0,0,0,90,13,0,0,36,16,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,134,3,0,0,0,0,0,72,172,6,0,0,0,0,0,144,47,2,0,120,88,1,0,0,0,0,0,128,145,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,0,128,0,0,0,0,0,0,0,0,0,0,234,41,0,0,248,36,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,102,2,0,112,166,3,0,0,0,0,0,0,0,0,0,104,221,5,0,72,88,2,0,0,0,0,0,192,154,4,0,48,178,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,0,10,0,8,0,0,0,0,0,0,0,0,0,0,218,58,0,0,34,30,0,0,0,0,0,0,0,0,0,0,82,46,0,0,100,14,0,0,124,3,0,0,188,13,0,0,2,7,0,0,0,0,0,0,0,33,0,0,0,0,0,0,0,2,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,166,3,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,168,117,3,0,0,0,0,0,160,150,4,0,48,178,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,8,0,0,0,0,0,0,0,0,0,0,218,38,0,0,126,23,0,0,0,0,0,0,0,0,0,0,82,46,0,0,100,14,0,0,24,19,0,0,188,13,0,0,2,7,0,0,0,0,0,0,0,33,0,0,0,0,0,0,0,2,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,217,2,0,112,166,3,0,0,0,0,0,0,0,0,0,104,221,5,0,88,196,2,0,0,0,0,0,160,150,4,0,48,178,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,10,0,8,0,0,0,0,0,0,0,0,0,0,164,43,0,0,212,16,0,0,0,0,0,0,0,0,0,0,82,46,0,0,38,3,0,0,24,19,0,0,188,13,0,0,2,7,0,0,0,0,0,0,0,33,0,0,0,0,0,0,0,2,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,180,2,0,112,166,3,0,0,0,0,0,0,0,0,0,104,221,5,0,104,165,2,0,0,0,0,0,160,99,1,0,48,178,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,10,0,8,0,0,0,0,0,0,0,0,0,0,226,55,0,0,100,44,0,0,0,0,0,0,0,0,0,0,82,46,0,0,38,3,0,0,24,19,0,0,188,13,0,0,2,7,0,0,0,0,0,0,0,33,0,0,0,0,0,0,0,2,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,5,3,0,112,166,3,0,0,0,0,0,0,0,0,0,104,221,5,0,160,239,2,0,0,0,0,0,160,150,4,0,48,178,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,10,0,8,0,0,0,0,0,0,0,0,0,0,142,3,0,0,154,19,0,0,0,0,0,0,0,0,0,0,82,46,0,0,100,14,0,0,24,19,0,0,188,13,0,0,2,7,0,0,0,0,0,0,0,33,0,0,0,0,0,0,0,2,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,49,3,0,112,166,3,0,0,0,0,0,0,0,0,0,104,221,5,0,16,30,3,0,0,0,0,0,160,150,4,0,48,178,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,10,0,8,0,0,0,0,0,0,0,0,0,0,70,59,0,0,42,34,0,0,0,0,0,0,0,0,0,0,82,46,0,0,100,14,0,0,24,19,0,0,188,13,0,0,2,7,0,0,0,0,0,0,0,33,0,0,0,0,0,0,0,2,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,80,3,0,112,166,3,0,0,0,0,0,0,0,0,0,104,221,5,0,96,65,3,0,0,0,0,0,160,150,4,0,48,178,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,10,0,8,0,0,0,0,0,0,0,0,0,0,52,20,0,0,214,28,0,0,0,0,0,0,0,0,0,0,82,46,0,0,100,14,0,0,24,19,0,0,188,13,0,0,2,7,0,0,0,0,0,0,0,33,0,0,0,0,0,0,0,2,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,72,2,0,0,0,0,0,0,0,0,0,0,0,0,0,56,172,6,0,80,60,2,0,0,0,0,0,192,154,4,0,48,178,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,33,0,0,0,2,0,0,0,0,0,0,10,0,8,0,0,0,0,0,0,0,0,0,0,178,31,0,0,12,7,0,0,0,0,0,0,0,0,0,0,82,46,0,0,38,3,0,0,64,5,0,0,188,13,0,0,168,14,0,0,0,0,0,0,208,30,0,0,0,0,0,0,0,4,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,156,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,8,234,5,0,0,0,0,0,24,154,4,0,16,128,3,0,184,188,2,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,4,0,0,0,0,0,3,4,0,8,0,0,0,0,0,0,0,0,0,0,228,36,0,0,84,44,0,0,0,0,0,0,0,0,0,0,204,27,0,0,26,34,0,0,20,16,0,0,40,6,0,0,48,10,0,0,140,17,0,0,26,21,0,0,32,146,215,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,128,230,2,0,8,102,4,0,0,0,0,0,0,0,0,0,240,3,2,0,144,79,2,0,0,0,0,0,184,220,4,0,248,180,3,0,184,221,1,0,0,0,0,0,0,0,0,0,0,0,0,0,149,0,0,0,2,0,0,0,0,0,0,13,2,0,0,0,0,0,0,0,0,0,0,0,234,9,0,0,44,45,0,0,0,0,0,0,0,0,0,0,32,31,0,0,14,6,0,0,120,5,0,0,66,4,0,0,206,19,0,0,238,15,0,0,232,20,0,0,216,157,215,0,0,16,0,0,224,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,80,159,7,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,112,155,7,0,0,0,0,0,200,149,7,0,80,150,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,16,4,2,0,0,1,0,0,0,0,0,0,0,0,0,92,58,0,0,8,4,0,0,0,0,0,0,0,0,0,0,162,0,0,0,214,16,0,0,52,16,0,0,114,17,0,0,134,11,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,233,8,0,0,0,0,0,0,0,0,0,0,0,0,0,232,167,7,0,24,105,8,0,0,0,0,0,104,238,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,128,43,0,0,68,17,0,0,0,0,0,0,0,0,0,0,92,56,0,0,2,58,0,0,42,12,0,0,218,16,0,0,166,13,0,0,164,1,0,0,68,57,0,0,128,175,145,0,96,0,0,0,240,0,0,0,196,0,0,0,4,0,0,0,3,0,0,0,40,104,6,0,32,18,7,0,0,0,0,0,0,0,0,0,240,115,6,0,168,98,6,0,0,0,0,0,72,94,6,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,8,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,4,21,0,0,168,0,0,0,0,0,0,0,0,0,0,0,186,23,0,0,246,1,0,0,88,16,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,232,163,3,0,216,195,4,0,0,0,0,0,0,0,0,0,184,168,7,0,176,137,3,0,0,0,0,0,40,161,4,0,240,153,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,192,0,1,2,0,0,4,0,0,0,0,0,0,0,0,0,136,36,0,0,222,5,0,0,0,0,0,0,0,0,0,0,146,35,0,0,36,2,0,0,120,16,0,0,114,5,0,0,164,8,0,0,0,0,0,0,6,14,0,0,0,0,0,0,0,96,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,218,3,0,216,195,4,0,0,0,0,0,0,0,0,0,184,168,7,0,200,188,3,0,0,0,0,0,40,161,4,0,240,153,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,192,0,1,2,0,0,4,0,0,0,0,0,0,0,0,0,94,13,0,0,158,6,0,0,0,0,0,0,0,0,0,0,146,35,0,0,36,2,0,0,120,16,0,0,114,5,0,0,164,8,0,0,0,0,0,0,6,14,0,0,0,0,0,0,0,96,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,25,4,0,216,195,4,0,0,0,0,0,0,0,0,0,184,168,7,0,248,250,3,0,0,0,0,0,40,161,4,0,240,153,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,192,0,1,2,0,0,4,0,0,0,0,0,0,0,0,0,26,55,0,0,120,31,0,0,0,0,0,0,0,0,0,0,146,35,0,0,36,2,0,0,120,16,0,0,114,5,0,0,164,8,0,0,0,0,0,0,6,14,0,0,0,0,0,0,0,96,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,77,3,0,216,195,4,0,0,0,0,0,0,0,0,0,184,168,7,0,16,64,3,0,0,0,0,0,40,161,4,0,240,153,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,192,0,1,2,0,0,4,0,0,0,0,0,0,0,0,0,68,14,0,0,10,12,0,0,0,0,0,0,0,0,0,0,146,35,0,0,36,2,0,0,120,16,0,0,114,5,0,0,164,8,0,0,0,0,0,0,6,14,0,0,0,0,0,0,0,96,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,114,3,0,216,195,4,0,0,0,0,0,0,0,0,0,184,168,7,0,240,91,3,0,0,0,0,0,40,161,4,0,240,153,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,192,0,1,2,0,0,4,0,0,0,0,0,0,0,0,0,104,1,0,0,64,1,0,0,0,0,0,0,0,0,0,0,146,35,0,0,36,2,0,0,120,16,0,0,114,5,0,0,164,8,0,0,0,0,0,0,6,14,0,0,0,0,0,0,0,96,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,133,4,0,216,195,4,0,0,0,0,0,0,0,0,0,184,168,7,0,248,105,4,0,0,0,0,0,40,161,4,0,240,153,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,192,0,1,2,0,0,4,0,0,0,0,0,0,0,0,0,168,32,0,0,62,39,0,0,0,0,0,0,0,0,0,0,146,35,0,0,36,2,0,0,120,16,0,0,114,5,0,0,164,8,0,0,0,0,0,0,6,14,0,0,0,0,0,0,0,96,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,79,4,0,216,195,4,0,0,0,0,0,0,0,0,0,184,168,7,0,128,53,4,0,0,0,0,0,40,161,4,0,240,153,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,192,0,1,2,0,0,4,0,0,0,0,0,0,0,0,0,146,59,0,0,244,18,0,0,0,0,0,0,0,0,0,0,146,35,0,0,36,2,0,0,120,16,0,0,114,5,0,0,164,8,0,0,0,0,0,0,6,14,0,0,0,0,0,0,0,96,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,195,4,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,200,163,4,0,0,0,0,0,40,161,4,0,240,153,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,192,0,1,2,0,0,4,0,0,0,0,0,0,0,0,0,82,24,0,0,44,24,0,0,0,0,0,0,0,0,0,0,146,35,0,0,36,2,0,0,120,16,0,0,114,5,0,0,164,8,0,0,0,0,0,0,6,14,0,0,0,0,0,0,0,96,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,0,3,0,184,45,3,0,0,0,0,0,0,0,0,0,184,168,7,0,160,234,2,0,0,0,0,0,168,138,8,0,248,135,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,19,0,0,1,0,0,0,0,0,0,0,0,0,226,17,0,0,84,15,0,0,0,0,0,0,0,0,0,0,34,44,0,0,190,30,0,0,136,18,0,0,216,4,0,0,96,1,0,0,0,0,0,0,10,34,0,0,0,0,0,0,0,4,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,184,45,3,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,32,21,3,0,0,0,0,0,168,138,8,0,248,135,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,19,0,0,1,0,0,0,0,0,0,0,0,0,212,51,0,0,114,10,0,0,0,0,0,0,0,0,0,0,34,44,0,0,190,30,0,0,136,18,0,0,216,4,0,0,96,1,0,0,0,0,0,0,10,34,0,0,0,0,0,0,0,4,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,0,232,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,208,0,6,0,0,0,0,0,144,84,8,0,128,194,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,3,11,0,64,0,0,0,0,0,0,0,0,0,0,14,55,0,0,62,32,0,0,0,0,0,0,0,0,0,0,194,29,0,0,4,62,0,0,150,10,0,0,158,4,0,0,132,0,0,0,0,0,0,0,192,32,0,0,0,0,0,0,0,32,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,160,5,0,184,32,6,0,0,0,0,0,0,0,0,0,160,234,7,0,248,127,5,0,0,0,0,0,64,246,3,0,72,129,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,4,4,2,0,0,0,0,0,0,0,0,0,0,0,236,46,0,0,240,29,0,0,0,0,0,0,0,0,0,0,186,49,0,0,226,32,0,0,242,16,0,0,94,12,0,0,120,8,0,0,0,0,0,0,46,35,0,0,56,74,148,0,0,1,0,0,240,0,0,0,24,1,0,0,3,0,0,0,4,0,0,0,104,227,4,0,184,32,6,0,0,0,0,0,0,0,0,0,160,234,7,0,80,191,4,0,0,0,0,0,64,246,3,0,72,129,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,53,0,0,0,2,0,0,0,0,0,4,4,2,0,0,0,0,0,0,0,0,0,0,0,36,60,0,0,26,26,0,0,0,0,0,0,0,0,0,0,186,49,0,0,226,32,0,0,242,16,0,0,94,12,0,0,120,8,0,0,0,0,0,0,46,35,0,0,56,74,148,0,0,1,0,0,240,0,0,0,24,1,0,0,3,0,0,0,4,0,0,0,32,37,5,0,184,32,6,0,0,0,0,0,0,0,0,0,160,234,7,0,72,7,5,0,0,0,0,0,64,246,3,0,72,129,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,53,0,0,0,2,0,0,0,0,0,4,4,2,0,0,0,0,0,0,0,0,0,0,0,142,53,0,0,102,17,0,0,0,0,0,0,0,0,0,0,186,49,0,0,226,32,0,0,242,16,0,0,94,12,0,0,120,8,0,0,0,0,0,0,46,35,0,0,56,74,148,0,0,1,0,0,240,0,0,0,24,1,0,0,3,0,0,0,4,0,0,0,216,98,5,0,184,32,6,0,0,0,0,0,0,0,0,0,160,234,7,0,48,68,5,0,0,0,0,0,64,246,3,0,72,129,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,53,0,0,0,2,0,0,0,0,0,4,4,2,0,0,0,0,0,0,0,0,0,0,0,72,45,0,0,60,15,0,0,0,0,0,0,0,0,0,0,186,49,0,0,226,32,0,0,242,16,0,0,94,12,0,0,120,8,0,0,0,0,0,0,46,35,0,0,56,74,148,0,0,1,0,0,240,0,0,0,24,1,0,0,3,0,0,0,4,0,0,0,152,108,8,0,8,109,5,0,0,0,0,0,0,0,0,0,200,190,7,0,200,51,8,0,0,0,0,0,192,154,4,0,136,252,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,26,22,0,0,158,31,0,0,0,0,0,0,0,0,0,0,172,22,0,0,118,53,0,0,88,19,0,0,64,13,0,0,168,2,0,0,0,0,0,0,134,1,0,0,0,0,0,0,0,1,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,236,8,0,8,109,5,0,0,0,0,0,0,0,0,0,200,190,7,0,0,172,8,0,0,0,0,0,192,154,4,0,136,252,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,184,13,0,0,156,2,0,0,0,0,0,0,0,0,0,0,172,22,0,0,118,53,0,0,124,2,0,0,64,13,0,0,168,2,0,0,0,0,0,0,134,1,0,0,0,0,0,0,0,1,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,234,1,0,8,109,5,0,0,0,0,0,0,0,0,0,200,190,7,0,80,136,1,0,0,0,0,0,192,154,4,0,136,252,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,26,0,0,12,44,0,0,0,0,0,0,0,0,0,0,172,22,0,0,174,12,0,0,124,2,0,0,64,13,0,0,168,2,0,0,0,0,0,0,134,1,0,0,0,0,0,0,0,1,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,44,8,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,0,249,7,0,0,0,0,0,192,195,7,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,0,10,2,0,0,0,0,0,0,0,0,0,0,0,184,57,0,0,228,47,0,0,0,0,0,0,0,0,0,0,244,12,0,0,18,53,0,0,16,6,0,0,6,9,0,0,98,0,0,0,22,8,0,0,218,43,0,0,232,174,145,0,0,8,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,96,19,8,0,112,100,8,0,0,0,0,0,0,0,0,0,96,159,4,0,160,16,8,0,0,0,0,0,192,154,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,0,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,130,23,0,0,104,47,0,0,0,0,0,0,0,0,0,0,86,51,0,0,114,62,0,0,134,4,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,184,48,1,0,64,126,5,0,0,0,0,0,0,0,0,0,64,171,7,0,128,236,8,0,0,0,0,0,88,172,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,62,40,0,0,176,46,0,0,0,0,0,0,0,0,0,0,92,5,0,0,16,32,0,0,0,9,0,0,218,10,0,0,28,3,0,0,34,8,0,0,66,32,0,0,8,176,145,0,0,5,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,251,2,0,64,126,5,0,0,0,0,0,0,0,0,0,64,171,7,0,24,96,2,0,0,0,0,0,248,39,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,190,40,0,0,78,33,0,0,0,0,0,0,0,0,0,0,92,5,0,0,144,15,0,0,0,9,0,0,218,10,0,0,28,3,0,0,34,8,0,0,66,32,0,0,8,176,145,0,0,5,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,234,1,0,64,126,5,0,0,0,0,0,0,0,0,0,64,171,7,0,88,137,1,0,0,0,0,0,248,39,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,136,7,0,0,40,47,0,0,0,0,0,0,0,0,0,0,92,5,0,0,144,15,0,0,0,9,0,0,218,10,0,0,28,3,0,0,34,8,0,0,66,32,0,0,8,176,145,0,0,5,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,126,5,0,0,0,0,0,0,0,0,0,0,0,0,0,64,171,7,0,232,112,6,0,0,0,0,0,248,39,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,132,26,0,0,90,2,0,0,0,0,0,0,0,0,0,0,92,5,0,0,144,15,0,0,0,9,0,0,218,10,0,0,28,3,0,0,34,8,0,0,66,32,0,0,8,176,145,0,0,5,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,129,4,0,0,0,0,0,0,0,0,0,0,0,0,0,200,190,7,0,0,70,6,0,0,0,0,0,232,224,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,1,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,214,26,0,0,90,36,0,0,0,0,0,0,0,0,0,0,2,57,0,0,212,36,0,0,10,19,0,0,176,13,0,0,162,7,0,0,164,4,0,0,192,60,0,0,32,175,145,0,0,2,0,0,224,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,176,188,5,0,0,0,0,0,0,0,0,0,0,0,0,0,232,167,7,0,208,184,5,0,0,0,0,0,184,181,5,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,8,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,254,37,0,0,0,34,0,0,0,0,0,0,0,0,0,0,148,32,0,0,74,39,0,0,194,14,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,208,134,1,0,200,186,1,0,0,0,0,0,0,0,0,0,96,135,2,0,16,121,1,0,240,56,5,0,144,234,6,0,168,38,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,5,17,0,64,0,0,0,0,0,0,0,0,0,0,4,13,0,0,186,17,0,0,0,0,0,0,0,0,0,0,50,9,0,0,64,45,0,0,86,0,0,0,218,2,0,0,114,1,0,0,166,3,0,0,116,50,0,0,8,211,148,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,32,158,1,0,200,186,1,0,0,0,0,0,0,0,0,0,96,135,2,0,0,146,1,0,240,56,5,0,144,234,6,0,168,38,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,5,17,0,64,0,0,0,0,0,0,0,0,0,0,86,62,0,0,74,5,0,0,0,0,0,0,0,0,0,0,50,9,0,0,64,45,0,0,86,0,0,0,218,2,0,0,114,1,0,0,166,3,0,0,116,50,0,0,8,211,148,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,160,163,2,0,96,176,7,0,0,0,0,0,0,0,0,0,200,190,7,0,32,138,2,0,0,0,0,0,144,168,7,0,248,206,2,0,0,111,2,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,2,0,3,2,0,0,2,0,0,0,0,0,0,0,0,0,162,44,0,0,154,35,0,0,0,0,0,0,0,0,0,0,18,60,0,0,218,51,0,0,164,17,0,0,68,18,0,0,144,2,0,0,0,0,0,0,102,41,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,176,7,0,0,0,0,0,0,0,0,0,0,0,0,0,200,190,7,0,40,172,7,0,0,0,0,0,144,168,7,0,80,150,3,0,56,164,7,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,6,0,4,2,0,0,2,0,0,0,0,0,0,0,0,0,236,50,0,0,28,12,0,0,0,0,0,0,0,0,0,0,156,10,0,0,98,37,0,0,38,11,0,0,178,16,0,0,134,11,0,0,0,0,0,0,10,15,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,136,4,0,16,152,4,0,0,0,0,0,0,0,0,0,216,194,1,0,72,133,4,0,0,0,0,0,168,95,8,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,8,0,0,2,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,0,0,0,0,122,20,0,0,78,37,0,0,0,0,0,0,0,0,0,0,0,35,0,0,174,14,0,0,72,11,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,240,106,7,0,40,83,5,0,0,0,0,0,0,0,0,0,64,171,7,0,128,56,7,0,0,0,0,0,192,154,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,53,0,0,0,2,0,0,0,0,0,0,20,2,0,0,0,0,0,0,0,0,0,0,0,240,34,0,0,2,27,0,0,0,0,0,0,0,0,0,0,226,19,0,0,220,30,0,0,12,4,0,0,138,9,0,0,92,12,0,0,0,0,0,0,152,25,0,0,0,0,0,0,0,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,48,202,7,0,40,83,5,0,0,0,0,0,0,0,0,0,64,171,7,0,200,152,7,0,0,0,0,0,192,223,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,0,20,2,0,0,0,0,0,0,0,0,0,0,0,34,37,0,0,84,45,0,0,0,0,0,0,0,0,0,0,226,19,0,0,220,30,0,0,104,9,0,0,138,9,0,0,92,12,0,0,0,0,0,0,152,25,0,0,0,0,0,0,0,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,216,34,3,0,232,117,8,0,0,0,0,0,0,0,0,0,144,47,2,0,128,117,2,0,0,0,0,0,168,95,8,0,112,5,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,0,3,4,0,0,0,0,0,0,0,0,0,0,0,182,11,0,0,44,12,0,0,0,0,0,0,0,0,0,0,126,12,0,0,0,0,0,0,196,14,0,0,246,7,0,0,58,1,0,0,140,2,0,0,154,26,0,0,24,177,145,0,0,8,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,62,8,0,232,117,8,0,0,0,0,0,0,0,0,0,144,47,2,0,40,11,8,0,0,0,0,0,168,95,8,0,112,5,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,3,4,0,0,0,0,0,0,0])
.concat([0,0,0,0,122,6,0,0,26,28,0,0,0,0,0,0,0,0,0,0,50,39,0,0,0,0,0,0,196,14,0,0,246,7,0,0,58,1,0,0,140,2,0,0,154,26,0,0,24,177,145,0,0,8,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,185,8,0,232,117,8,0,0,0,0,0,0,0,0,0,144,47,2,0,0,120,8,0,0,0,0,0,168,95,8,0,112,5,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,3,4,0,0,0,0,0,0,0,0,0,0,0,176,26,0,0,90,41,0,0,0,0,0,0,0,0,0,0,50,39,0,0,0,0,0,0,196,14,0,0,246,7,0,0,58,1,0,0,140,2,0,0,154,26,0,0,24,177,145,0,0,8,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,62,1,0,232,117,8,0,0,0,0,0,0,0,0,0,144,47,2,0,64,249,8,0,0,0,0,0,168,95,8,0,112,5,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,3,4,0,0,0,0,0,0,0,0,0,0,0,72,34,0,0,244,11,0,0,0,0,0,0,0,0,0,0,126,12,0,0,0,0,0,0,196,14,0,0,246,7,0,0,58,1,0,0,140,2,0,0,154,26,0,0,24,177,145,0,0,8,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,255,1,0,232,117,8,0,0,0,0,0,0,0,0,0,144,47,2,0,112,156,1,0,0,0,0,0,168,95,8,0,112,5,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,3,4,0,0,0,0,0,0,0,0,0,0,0,64,0,0,0,220,2,0,0,0,0,0,0,0,0,0,0,50,39,0,0,0,0,0,0,196,14,0,0,246,7,0,0,58,1,0,0,140,2,0,0,154,26,0,0,24,177,145,0,0,8,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,117,8,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,120,187,6,0,0,0,0,0,168,95,8,0,112,5,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,4,0,0,0,0,0,0,3,4,0,0,0,0,0,0,0,0,0,0,0,202,8,0,0,120,2,0,0,0,0,0,0,0,0,0,0,126,12,0,0,0,0,0,0,196,14,0,0,246,7,0,0,58,1,0,0,140,2,0,0,154,26,0,0,24,177,145,0,0,8,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,89,3,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,96,26,6,0,0,0,0,0,208,186,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,0,10,2,0,0,0,0,0,0,0,0,0,0,0,252,9,0,0,180,6,0,0,0,0,0,0,0,0,0,0,168,28,0,0,14,56,0,0,242,12,0,0,120,6,0,0,224,15,0,0,170,8,0,0,38,29,0,0,216,173,145,0,0,3,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,72,154,7,0,88,53,8,0,0,0,0,0,0,0,0,0,104,174,7,0,248,107,7,0,0,0,0,0,32,0,1,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,132,52,0,0,30,13,0,0,0,0,0,0,0,0,0,0,200,39,0,0,142,41,0,0,176,16,0,0,90,14,0,0,242,4,0,0,126,18,0,0,176,61,0,0,56,176,145,0,0,4,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,58,7,0,88,53,8,0,0,0,0,0,0,0,0,0,104,174,7,0,152,13,7,0,0,0,0,0,32,0,1,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,226,24,0,0,18,20,0,0,0,0,0,0,0,0,0,0,200,39,0,0,142,41,0,0,176,16,0,0,90,14,0,0,242,4,0,0,126,18,0,0,176,61,0,0,56,176,145,0,0,4,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,53,8,0,0,0,0,0,0,0,0,0,0,0,0,0,104,174,7,0,168,203,7,0,0,0,0,0,32,0,1,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,178,39,0,0,12,30,0,0,0,0,0,0,0,0,0,0,200,39,0,0,142,41,0,0,176,16,0,0,90,14,0,0,242,4,0,0,126,18,0,0,176,61,0,0,56,176,145,0,0,4,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,225,2,0,64,40,4,0,0,0,0,0,0,0,0,0,144,139,6,0,64,78,2,0,0,0,0,0,0,192,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,10,4,0,0,0,0,0,0,0,0,0,0,0,118,14,0,0,236,31,0,0,0,0,0,0,0,0,0,0,178,23,0,0,48,28,0,0,186,6,0,0,74,17,0,0,190,5,0,0,72,15,0,0,90,55,0,0,0,0,0,0,1,16,0,0,124,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,40,4,0,0,0,0,0,0,0,0,0,0,0,0,0,144,139,6,0,160,58,6,0,0,0,0,0,0,192,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,4,0,0,0,0,0,0,0,0,0,0,0,20,23,0,0,44,40,0,0,0,0,0,0,0,0,0,0,178,23,0,0,48,28,0,0,110,18,0,0,74,17,0,0,190,5,0,0,72,15,0,0,90,55,0,0,0,0,0,0,1,16,0,0,124,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,41,2,0,232,109,2,0,0,0,0,0,0,0,0,0,96,135,2,0,64,31,2,0,0,0,0,0,128,161,4,0,168,196,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,5,11,4,0,0,0,0,0,0,0,0,0,0,0,110,50,0,0,190,47,0,0,0,0,0,0,0,0,0,0,50,26,0,0,148,25,0,0,22,19,0,0,178,11,0,0,82,0,0,0,238,10,0,0,188,1,0,0,0,0,0,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,70,2,0,232,109,2,0,0,0,0,0,0,0,0,0,96,135,2,0,216,56,2,0,0,0,0,0,144,84,8,0,168,196,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,5,11,4,0,0,0,0,0,0,0,0,0,0,0,14,13,0,0,206,3,0,0,0,0,0,0,0,0,0,0,50,26,0,0,148,25,0,0,22,19,0,0,178,11,0,0,82,0,0,0,238,10,0,0,188,1,0,0,0,0,0,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,109,2,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,64,83,2,0,0,0,0,0,168,183,7,0,168,196,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,5,11,4,0,0,0,0,0,0,0,0,0,0,0,220,22,0,0,246,45,0,0,0,0,0,0,0,0,0,0,50,26,0,0,16,17,0,0,22,19,0,0,178,11,0,0,82,0,0,0,238,10,0,0,188,1,0,0,0,0,0,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,159,2,0,0,188,1,0,0,0,0,0,0,0,0,0,160,234,7,0,248,29,2,0,0,0,0,0,176,237,2,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,3,0,0,0,0,0,0,19,0,64,0,0,0,0,0,0,0,0,0,0,224,47,0,0,42,36,0,0,0,0,0,0,0,0,0,0,118,51,0,0,246,35,0,0,24,1,0,0,182,18,0,0,88,3,0,0,0,0,0,0,102,5,0,0,0,0,0,0,0,1,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,202,8,0,0,188,1,0,0,0,0,0,0,0,0,0,160,234,7,0,232,137,8,0,0,0,0,0,192,154,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,3,0,0,0,0,0,0,19,0,64,0,0,0,0,0,0,0,0,0,0,208,47,0,0,10,34,0,0,0,0,0,0,0,0,0,0,118,51,0,0,132,22,0,0,22,2,0,0,182,18,0,0,88,3,0,0,0,0,0,0,102,5,0,0,0,0,0,0,0,1,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,181,1,0,0,188,1,0,0,0,0,0,0,0,0,0,160,234,7,0,248,84,1,0,0,0,0,0,192,154,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,3,0,0,0,0,0,0,19,0,64,0,0,0,0,0,0,0,0,0,0,56,16,0,0,224,18,0,0,0,0,0,0,0,0,0,0,118,51,0,0,186,22,0,0,22,2,0,0,182,18,0,0,88,3,0,0,0,0,0,0,102,5,0,0,0,0,0,0,0,1,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,188,1,0,0,0,0,0,0,0,0,0,0,0,0,0,160,234,7,0,208,156,5,0,0,0,0,0,176,237,2,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,3,0,0,0,0,0,0,19,0,64,0,0,0,0,0,0,0,0,0,0,102,21,0,0,174,7,0,0,0,0,0,0,0,0,0,0,118,51,0,0,132,22,0,0,90,6,0,0,182,18,0,0,88,3,0,0,0,0,0,0,102,5,0,0,0,0,0,0,0,1,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,225,8,0,0,0,0,0,0,0,0,0,0,0,0,0,184,12,8,0,224,95,8,0,0,0,0,0,152,190,4,0,192,167,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,1,0,0,0,0,0,0,0,0,0,0,218,57,0,0,206,40,0,0,0,0,0,0,0,0,0,0,234,32,0,0,226,21,0,0,98,1,0,0,122,2,0,0,166,18,0,0,108,16,0,0,180,44,0,0,88,174,145,0,0,32,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,24,5,0,88,116,5,0,0,0,0,0,0,0,0,0,240,3,2,0,40,247,4,0,0,0,0,0,112,55,5,0,152,8,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,4,17,0,0,1,0,0,0,0,0,0,0,0,0,226,4,0,0,54,45,0,0,0,0,0,0,0,0,0,0,148,21,0,0,194,55,0,0,106,19,0,0,80,0,0,0,228,1,0,0,44,8,0,0,0,0,0,0,32,177,145,0,0,2,0,0,128,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,8,183,2,0,168,181,7,0,0,0,0,0,0,0,0,0,0,38,7,0,176,158,4,0,0,0,0,0,200,150,4,0,16,128,3,0,120,54,2,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,1,4,2,0,0,0,0,0,0,0,0,0,0,0,244,10,0,0,134,16,0,0,0,0,0,0,0,0,0,0,26,41,0,0,208,50,0,0,150,13,0,0,232,7,0,0,124,16,0,0,152,18,0,0,214,1,0,0,32,146,215,0,0,8,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,248,2,3,0,104,219,7,0,0,0,0,0,0,0,0,0,200,190,7,0,16,238,2,0,0,0,0,0,192,154,4,0,248,206,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,3,2,0,8,0,0,0,0,0,0,0,0,0,0,68,43,0,0,160,38,0,0,0,0,0,0,0,0,0,0,244,9,0,0,98,13,0,0,210,10,0,0,114,17,0,0,144,2,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,194,2,0,104,219,7,0,0,0,0,0,0,0,0,0,200,190,7,0,216,177,2,0,0,0,0,0,192,154,4,0,248,206,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,3,2,0,8,0,0,0,0,0,0,0,0,0,0,136,47,0,0,60,27,0,0,0,0,0,0,0,0,0,0,244,9,0,0,98,13,0,0,210,10,0,0,114,17,0,0,144,2,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,184,7,0,104,219,7,0,0,0,0,0,0,0,0,0,200,190,7,0,232,179,7,0,0,0,0,0,40,161,4,0,80,150,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,4,4,2,0,8,0,0,0,0,0,0,0,0,0,0,52,43,0,0,242,38,0,0,0,0,0,0,0,0,0,0,50,22,0,0,90,5,0,0,218,12,0,0,114,17,0,0,134,11,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,197,7,0,104,219,7,0,0,0,0,0,0,0,0,0,200,190,7,0,40,191,7,0,0,0,0,0,40,161,4,0,80,150,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,8,4,4,2,0,8,0,0,0,0,0,0,0,0,0,0,52,37,0,0,218,19,0,0,0,0,0,0,0,0,0,0,50,22,0,0,90,5,0,0,218,12,0,0,114,17,0,0,134,11,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,210,7,0,104,219,7,0,0,0,0,0,0,0,0,0,200,190,7,0,232,204,7,0,0,0,0,0,40,161,4,0,80,150,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,12,0,4,2,0,8,0,0,0,0,0,0,0,0,0,0,118,32,0,0,162,23,0,0,0,0,0,0,0,0,0,0,50,22,0,0,90,5,0,0,218,12,0,0,114,17,0,0,134,11,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,223,7,0,104,219,7,0,0,0,0,0,0,0,0,0,200,190,7,0,120,215,7,0,0,0,0,0,40,161,4,0,80,150,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,68,0,4,2,0,8,0,0,0,0,0,0,0,0,0,0,10,21,0,0,254,35,0,0,0,0,0,0,0,0,0,0,50,22,0,0,90,5,0,0,218,12,0,0,114,17,0,0,134,11,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,48,3,0,104,219,7,0,0,0,0,0,0,0,0,0,200,190,7,0,16,27,3,0,0,0,0,0,40,161,4,0,248,206,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,64,0,3,2,0,8,0,0,0,0,0,0,0,0,0,0,102,63,0,0,46,30,0,0,0,0,0,0,0,0,0,0,244,9,0,0,98,13,0,0,210,10,0,0,114,17,0,0,144,2,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,219,7,0,0,0,0,0,0,0,0,0,0,0,0,0,200,190,7,0,72,64,3,0,0,0,0,0,40,161,4,0,248,206,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,3,2,0,8,0,0,0,0,0,0,0,0,0,0,196,33,0,0,220,4,0,0,0,0,0,0,0,0,0,0,244,9,0,0,98,13,0,0,210,10,0,0,114,17,0,0,144,2,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,197,6,0,0,0,0,0,232,222,6,0,0,0,0,0,160,217,6,0,192,194,6,0,0,0,0,0,112,204,6,0,48,201,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,68,4,2,4,0,0,0,0,0,0,0,0,0,0,0,218,39,0,0,226,44,0,0,0,0,0,0,0,0,0,0,180,12,0,0,50,18,0,0,40,3,0,0,162,0,0,0,134,11,0,0,0,0,0,0,2,13,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,63,3,0,160,163,3,0,0,0,0,0,0,0,0,0,184,168,7,0,224,47,3,0,0,0,0,0,40,161,4,0,8,153,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,6,2,0,8,0,0,0,0,0,0,0,0,0,0,12,16,0,0,206,11,0,0,0,0,0,0,0,0,0,0,196,58,0,0,118,55,0,0,218,12,0,0,164,2,0,0,20,14,0,0,0,0,0,0,106,0,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,91,3,0,160,163,3,0,0,0,0,0,0,0,0,0,184,168,7,0,104,77,3,0,0,0,0,0,40,161,4,0,8,153,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,6,2,0,8,0,0,0,0,0,0,0,0,0,0,130,17,0,0,124,30,0,0,0,0,0,0,0,0,0,0,196,58,0,0,118,55,0,0,218,12,0,0,164,2,0,0,20,14,0,0,0,0,0,0,106,0,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,163,3,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,232,113,3,0,0,0,0,0,40,161,4,0,8,153,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,6,2,0,8,0,0,0,0,0,0,0,0,0,0,46,28,0,0,224,17,0,0,0,0,0,0,0,0,0,0,196,58,0,0,118,55,0,0,218,12,0,0,164,2,0,0,20,14,0,0,0,0,0,0,106,0,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,250,5,0,232,80,6,0,0,0,0,0,0,0,0,0,64,171,7,0,184,206,5,0,0,0,0,0,40,161,4,0,48,156,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,128,1,7,2,0,0,8,0,0,0,0,0,0,0,0,0,38,12,0,0,252,6,0,0,0,0,0,0,0,0,0,0,84,8,0,0,238,57,0,0,132,18,0,0,114,17,0,0,102,17,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,80,6,0,0,0,0,0,0,0,0,0,0,0,0,0,64,171,7,0,168,38,6,0,0,0,0,0,40,161,4,0,48,156,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,128,1,7,2,0,0,8,0,0,0,0,0,0,0,0,0,114,41,0,0,18,10,0,0,0,0,0,0,0,0,0,0,84,8,0,0,238,57,0,0,132,18,0,0,114,17,0,0,102,17,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,168,6,0,40,239,7,0,0,0,0,0,0,0,0,0,144,47,2,0,24,78,6,0,0,0,0,0,40,161,4,0,160,148,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,8,2,0,0,4,0,0,0,0,0,0,0,0,0,196,37,0,0,104,25,0,0,0,0,0,0,0,0,0,0,204,14,0,0,52,26,0,0,138,11,0,0,114,17,0,0,204,6,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,48,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,255,6,0,40,239,7,0,0,0,0,0,0,0,0,0,200,190,7,0,120,215,6,0,0,0,0,0,40,161,4,0,160,148,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,2,0,8,2,0,0,4,0,0,0,0,0,0,0,0,0,104,33,0,0,64,42,0,0,0,0,0,0,0,0,0,0,204,14,0,0,52,26,0,0,166,1,0,0,114,17,0,0,204,6,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,48,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,93,7,0,40,239,7,0,0,0,0,0,0,0,0,0,200,190,7,0,176,43,7,0,0,0,0,0,40,161,4,0,160,148,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,2,0,8,2,0,0,4,0,0,0,0,0,0,0,0,0,222,21,0,0,166,6,0,0,0,0,0,0,0,0,0,0,204,14,0,0,52,26,0,0,166,1,0,0,114,17,0,0,204,6,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,48,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,239,7,0,0,0,0,0,0,0,0,0,0,0,0,0,200,190,7,0,208,139,7,0,0,0,0,0,40,161,4,0,160,148,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,8,2,0,0,4,0,0,0,0,0,0,0,0,0,12,55,0,0,142,25,0,0,0,0,0,0,0,0,0,0,204,14,0,0,52,26,0,0,138,11,0,0,114,17,0,0,204,6,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,48,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,219,2,0,192,201,3,0,0,0,0,0,0,0,0,0,104,174,7,0,40,74,2,0,0,0,0,0,32,0,1,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,180,36,0,0,76,22,0,0,0,0,0,0,0,0,0,0,222,45,0,0,162,51,0,0,128,17,0,0,14,3,0,0,164,11,0,0,42,4,0,0,242,13,0,0,104,174,145,0,0,16,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,201,3,0,0,0,0,0,0,0,0,0,0,0,0,0,104,174,7,0,72,46,6,0,0,0,0,0,32,0,1,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,20,8,0,0,22,23,0,0,0,0,0,0,0,0,0,0,222,45,0,0,162,51,0,0,128,17,0,0,14,3,0,0,164,11,0,0,42,4,0,0,242,13,0,0,104,174,145,0,0,16,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,210,1,0,8,133,3,0,0,0,0,0,0,0,0,0,240,3,2,0,56,113,1,0,0,0,0,0,72,192,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,22,4,0,0,0,0,0,0,0,0,0,0,0,122,5,0,0,14,9,0,0,0,0,0,0,0,0,0,0,246,7,0,0,66,4,0,0,240,3,0,0,88,6,0,0,248,12,0,0,0,0,0,0,244,47,0,0,224,210,148,0,0,128,0,0,64,1,0,0,0,1,0,0,4,0,0,0,3,0,0,0,240,210,2,0,8,133,3,0,0,0,0,0,0,0,0,0,240,3,2,0,208,69,2,0,0,0,0,0,72,192,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,22,4,0,0,0,0,0,0,0,0,0,0,0,24,15,0,0,134,24,0,0,0,0,0,0,0,0,0,0,246,7,0,0,66,4,0,0,240,3,0,0,88,6,0,0,248,12,0,0,0,0,0,0,244,47,0,0,224,210,148,0,0,128,0,0,64,1,0,0,0,1,0,0,4,0,0,0,3,0,0,0,8,133,3,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,136,33,6,0,0,0,0,0,72,192,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,22,4,0,0,0,0,0,0,0,0,0,0,0,178,53,0,0,200,29,0,0,0,0,0,0,0,0,0,0,246,7,0,0,66,4,0,0,240,3,0,0,88,6,0,0,248,12,0,0,0,0,0,0,244,47,0,0,224,210,148,0,0,128,0,0,64,1,0,0,0,1,0,0,4,0,0,0,3,0,0,0,232,73,3,0,0,0,0,0,0,0,0,0,0,0,0,0,160,234,7,0,96,61,3,0,0,0,0,0,168,138,8,0,176,109,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,19,0,0,1,0,0,0,0,0,0,0,0,0,188,8,0,0,10,24,0,0,0,0,0,0,0,0,0,0,36,32,0,0,150,43,0,0,24,7,0,0,158,10,0,0,242,5,0,0,160,5,0,0,6,53,0,0,72,173,145,0,0,4,0,0,240,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,48,105,3,0,0,0,0,0,0,0,0,0,0,0,0,0,64,164,6,0,208,103,3,0,88,1,5,0,72,226,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,8,0,0,2,0,0,0,0,0,0,16,1,0,0,0,0,0,0,0,0,0,0,0,162,59,0,0,252,41,0,0,0,0,0,0,0,0,0,0,100,63,0,0,46,48,0,0,206,16,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,30,1,0,184,54,3,0,0,0,0,0,0,0,0,0,184,12,8,0,200,219,8,0,0,0,0,0,192,223,4,0,0,151,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,1,0,0,9,8,0,0,0,2,0,0,0,0,0,0,0,22,62,0,0,58,10,0,0,0,0,0,0,0,0,0,0,38,11,0,0,180,30,0,0,64,1,0,0,228,2,0,0,0,13,0,0,0,0,0,0,166,23,0,0,240,121,145,0,0,0,4,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,204,2,0,184,54,3,0,0,0,0,0,0,0,0,0,184,12,8,0,128,65,2,0,0,0,0,0,192,223,4,0,0,151,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,9,8,0,0,0,2,0,0,0,0,0,0,0,94,42,0,0,248,19,0,0,0,0,0,0,0,0,0,0,38,11,0,0,182,27,0,0,64,1,0,0,228,2,0,0,0,13,0,0,0,0,0,0,166,23,0,0,240,121,145,0,0,0,4,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,205,1,0,184,54,3,0,0,0,0,0,0,0,0,0,184,12,8,0,224,107,1,0,0,0,0,0,192,223,4,0,0,151,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,9,8,0,0,0,2,0,0,0,0,0,0,0,212,16,0,0,68,42,0,0,0,0,0,0,0,0,0,0,38,11,0,0,148,38,0,0,64,1,0,0,228,2,0,0,0,13,0,0,0,0,0,0,166,23,0,0,240,121,145,0,0,0,4,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,205,5,0,80,93,7,0,0,0,0,0,0,0,0,0,144,139,6,0,184,164,5,0,0,0,0,0,192,223,4,0,0,151,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,9,8,0,0,0,2,0,0,0,0,0,0,0,56,7,0,0,46,45,0,0,0,0,0,0,0,0,0,0,38,11,0,0,140,5,0,0,54,5,0,0,228,2,0,0,0,13,0,0,0,0,0,0,166,23,0,0,240,121,145,0,0,0,4,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,215,6,0,80,93,7,0,0,0,0,0,0,0,0,0,144,139,6,0,248,168,6,0,0,0,0,0,192,223,4,0,0,151,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,9,8,0,0,0,2,0,0,0,0,0,0,0,254,49,0,0,114,47,0,0,0,0,0,0,0,0,0,0,38,11,0,0,140,5,0,0,54,5,0,0,228,2,0,0,0,13,0,0,0,0,0,0,166,23,0,0,240,121,145,0,0,0,4,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,36,6,0,80,93,7,0,0,0,0,0,0,0,0,0,144,139,6,0,56,247,5,0,0,0,0,0,192,223,4,0,0,151,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,9,8,0,0,0,2,0,0,0,0,0,0,0,182,41,0,0,108,14,0,0,0,0,0,0,0,0,0,0,38,11,0,0,136,48,0,0,54,5,0,0,228,2,0,0,0,13,0,0,0,0,0,0,166,23,0,0,240,121,145,0,0,0,4,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,130,5,0,80,93,7,0,0,0,0,0,0,0,0,0,144,139,6,0,152,102,5,0,0,0,0,0,192,223,4,0,0,151,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,1,0,0,9,8,0,0,0,2,0,0,0,0,0,0,0,32,51,0,0,238,39,0,0,0,0,0,0,0,0,0,0,38,11,0,0,140,18,0,0,54,5,0,0,228,2,0,0,0,13,0,0,0,0,0,0,166,23,0,0,240,121,145,0,0,0,4,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,127,6,0,80,93,7,0,0,0,0,0,0,0,0,0,144,139,6,0,80,78,6,0,0,0,0,0,192,223,4,0,0,151,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,1,0,0,9,8,0,0,0,2,0,0,0,0,0,0,0,142,7,0,0,64,4,0,0,0,0,0,0,0,0,0,0,38,11,0,0,140,18,0,0,54,5,0,0,228,2,0,0,0,13,0,0,0,0,0,0,166,23,0,0,240,121,145,0,0,0,4,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,93,7,0,0,0,0,0,0,0,0,0,0,0,0,0,144,139,6,0,192,255,6,0,0,0,0,0,192,223,4,0,0,151,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,9,8,0,0,0,2,0,0,0,0,0,0,0,250,39,0,0,150,46,0,0,0,0,0,0,0,0,0,0,38,11,0,0,136,48,0,0,54,5,0,0,228,2,0,0,0,13,0,0,0,0,0,0,166,23,0,0,240,121,145,0,0,0,4,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,187,7,0,168,153,8,0,0,0,0,0,0,0,0,0,184,12,8,0,48,140,7,0,0,0,0,0,192,223,4,0,0,151,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,1,0,0,9,8,0,0,0,2,0,0,0,0,0,0,0,204,24,0,0,68,47,0,0,0,0,0,0,0,0,0,0,38,11,0,0,68,11,0,0,182,8,0,0,228,2,0,0,0,13,0,0,0,0,0,0,166,23,0,0,240,121,145,0,0,0,4,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,36,8,0,168,153,8,0,0,0,0,0,0,0,0,0,184,12,8,0,120,239,7,0,0,0,0,0,192,223,4,0,0,151,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,9,8,0,0,0,2,0,0,0,0,0,0,0,134,58,0,0,98,47,0,0,0,0,0,0,0,0,0,0,38,11,0,0,140,18,0,0,182,8,0,0,228,2,0,0,0,13,0,0,0,0,0,0,166,23,0,0,240,121,145,0,0,0,4,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,153,8,0,0,0,0,0,0,0,0,0,0,0,0,0,184,12,8,0,240,91,8,0,0,0,0,0,192,223,4,0,0,151,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,9,8,0,0,0,2,0,0,0,0,0,0,0,224,35,0,0,152,7,0,0,0,0,0,0,0,0,0,0,38,11,0,0,140,5,0,0,182,8,0,0,228,2,0,0,0,13,0,0,0,0,0,0,166,23,0,0,240,121,145,0,0,0,4,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,54,3,0,0,0,0,0,0,0,0,0,0,0,0,0,184,12,8,0,240,17,6,0,0,0,0,0,192,223,4,0,0,151,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,9,8,0,0,0,2,0,0,0,0,0,0,0,190,4,0,0,80,42,0,0,0,0,0,0,0,0,0,0,38,11,0,0,52,18,0,0,64,1,0,0,228,2,0,0,0,13,0,0,0,0,0,0,166,23,0,0,240,121,145,0,0,0,4,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,234,2,0,200,154,4,0,0,0,0,0,0,0,0,0,104,174,7,0,152,82,2,0,0,0,0,0,200,227,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,170,47,0,0,98,25,0,0,0,0,0,0,0,0,0,0,222,39,0,0,60,11,0,0,76,1,0,0,22,7,0,0,230,18,0,0,0,0,0,0,110,45,0,0,0,0,0,0,0,4,0,0,128,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,184,82,3,0,240,97,5,0,72,172,6,0,0,0,0,0,144,47,2,0,8,68,3,0,0,0,0,0,128,145,4,0,208,9,3,0,136,53,3,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,133,4,0,0,0,0,0,0,0,0,0,0,0,22,4,0,0,80,10,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,106,5,0,0,0,0,0,72,172,6,0,0,0,0,0,104,129,6,0,152,101,5,0,0,0,0,0,160,97,5,0,208,9,3,0,24,95,5,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,9,0,1,133,4,0,0,0,0,0,0,0,0,0,0,0,54,59,0,0,110,27,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,250,10,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,123,2,0,0,0,0,0,72,172,6,0,0,0,0,0,240,3,2,0,80,234,8,0,0,0,0,0,128,145,4,0,208,9,3,0,176,226,8,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,4,0,1,133,4,0,0,0,0,0,0,0,0,0,0,0,182,1,0,0,132,6,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,97,5,0,0,0,0,0,72,172,6,0,0,0,0,0,144,47,2,0,88,121,3,0,0,0,0,0,128,145,4,0,208,9,3,0,248,97,3,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,4,0,0,0,0,0,0,0,0,0,0,0,104,22,0,0,94,11,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,49,3,0,0,0,0,0,0,0,0,0,0,0,0,0,184,12,8,0,80,30,3,0,0,0,0,0,224,218,4,0,240,185,2,0,160,5,3,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,64,0,0,0,0,0,0,0,0,0,0,188,16,0,0,62,47,0,0,0,0,0,0,0,0,0,0,248,1,0,0,186,58,0,0,80,11,0,0,56,15,0,0,12,17,0,0,0,0,0,0,224,13,0,0,0,0,0,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,144,161,2,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,80,136,2,0,0,0,0,0,216,123,2,0,168,196,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,5,11,0,1,0,0,0,0,0,0,0,0,0,0,80,23,0,0,104,30,0,0,0,0,0,0,0,0,0,0,180,22,0,0,108,25,0,0,12,2,0,0,178,11,0,0,82,0,0,0,238,10,0,0,188,1,0,0,0,0,0,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,211,1,0,160,238,1,0,0,0,0,0,0,0,0,0,64,171,7,0,152,200,1,0,0,0,0,0,40,161,4,0,192,152,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,9,2,2,0,0,0,0,0,0,0,0,0,0,0,192,17,0,0,68,26,0,0,0,0,0,0,0,0,0,0,102,57,0,0,158,0,0,0,162,8,0,0,42,17,0,0,184,7,0,0,0,0,0,0,216,46,0,0,0,0,0,0,0,6,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,238,1,0,0,0,0,0,0,0,0,0,0,0,0,0,64,171,7,0,224,226,1,0,0,0,0,0,40,161,4,0,192,152,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,9,2,2,0,0,0,0,0,0,0,0,0,0,0,250,57,0,0,158,23,0,0,0,0,0,0,0,0,0,0,102,57,0,0,158,0,0,0,108,18,0,0,42,17,0,0,184,7,0,0,0,0,0,0,216,46,0,0,0,0,0,0,0,6,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,52,5,0,0,0,0,0,0,0,0,0,0,0,0,0,64,171,7,0,80,102,6,0,0,0,0,0,192,223,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,20,1,0,0,0,0,0,0,0,0,0,0,0,6,15,0,0,244,37,0,0,0,0,0,0,0,0,0,0,194,6,0,0,144,30,0,0,192,7,0,0,16,3,0,0,100,9,0,0,230,11,0,0,254,30,0,0,184,175,145,0,0,4,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,0,211,2,0,184,45,3,0,0,0,0,0,0,0,0,0,184,168,7,0,152,192,2,0,0,0,0,0,176,237,2,0,248,135,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,19,0,0,1,0,0,0,0,0,0,0,0,0,172,3,0,0,176,17,0,0,0,0,0,0,0,0,0,0,34,44,0,0,190,30,0,0,136,18,0,0,216,4,0,0,96,1,0,0,0,0,0,0,10,34,0,0,0,0,0,0,0,4,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,152,155,8,0,0,0,0,0,0,0,0,0,0,0,0,0,144,139,6,0,216,93,8,0,0,0,0,0,152,190,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,16,0,0,0,0,0,0,0,0,0,0,120,22,0,0,162,19,0,0,0,0,0,0,0,0,0,0,250,33,0,0,252,57,0,0,94,16,0,0,210,18,0,0,126,11,0,0,212,16,0,0,82,63,0,0,16,174,145,0,0,4,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,240,111,1,0,0,0,0,0,0,0,0,0,0,0,0,0,144,139,6,0,80,222,8,0,0,0,0,0,152,190,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,16,0,0,0,0,0,0,0,0,0,0,202,13,0,0,238,7,0,0,0,0,0,0])
.concat([0,0,0,0,250,33,0,0,76,26,0,0,174,1,0,0,210,18,0,0,126,11,0,0,212,16,0,0,82,63,0,0,16,174,145,0,0,4,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,88,242,7,0,152,2,8,0,0,0,0,0,0,0,0,0,200,190,7,0,192,236,7,0,0,0,0,0,40,161,4,0,80,150,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,4,0,4,2,0,0,8,0,0,0,0,0,0,0,0,0,78,45,0,0,166,25,0,0,0,0,0,0,0,0,0,0,214,27,0,0,24,43,0,0,138,18,0,0,174,19,0,0,134,11,0,0,0,0,0,0,92,54,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,7,8,0,152,2,8,0,0,0,0,0,0,0,0,0,200,190,7,0,24,251,7,0,0,0,0,0,40,161,4,0,80,150,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,5,0,4,2,0,0,8,0,0,0,0,0,0,0,0,0,204,31,0,0,24,4,0,0,0,0,0,0,0,0,0,0,214,27,0,0,24,43,0,0,142,0,0,0,174,19,0,0,134,11,0,0,0,0,0,0,92,54,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,2,8,0,0,0,0,0,0,0,0,0,0,0,0,0,200,190,7,0,40,92,3,0,0,0,0,0,40,161,4,0,248,206,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,2,0,3,2,0,0,8,0,0,0,0,0,0,0,0,0,12,3,0,0,0,28,0,0,0,0,0,0,0,0,0,0,10,20,0,0,126,43,0,0,206,0,0,0,86,5,0,0,144,2,0,0,0,0,0,0,240,7,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,217,2,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,168,213,1,0,0,0,0,0,240,115,1,0,240,185,2,0,16,35,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,1,0,0,0,0,0,0,0,0,0,0,0,24,52,0,0,138,34,0,0,0,0,0,0,0,0,0,0,138,12,0,0,154,49,0,0,188,2,0,0,158,5,0,0,172,1,0,0,192,15,0,0,32,32,0,0,80,174,145,0,0,8,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,168,163,7,0,32,192,3,0,0,0,0,0,224,218,4,0,240,185,2,0,128,166,3,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,8,0,0,0,0,0,0,0,0,0,0,0,140,57,0,0,96,4,0,0,0,0,0,0,0,0,0,0,14,12,0,0,72,46,0,0,98,15,0,0,56,15,0,0,12,17,0,0,0,0,0,0,224,13,0,0,0,0,0,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,216,246,2,0,88,52,5,0,0,0,0,0,0,0,0,0,64,171,7,0,176,92,2,0,0,0,0,0,192,223,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,20,1,0,0,0,0,0,0,0,0,0,0,0,234,55,0,0,38,3,0,0,0,0,0,0,0,0,0,0,194,6,0,0,144,30,0,0,192,7,0,0,16,3,0,0,100,9,0,0,230,11,0,0,254,30,0,0,184,175,145,0,0,4,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,120,53,4,0,160,187,8,0,0,0,0,0,0,0,0,0,216,194,1,0,64,49,4,0,0,0,0,0,184,68,6,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,8,0,0,2,0,0,0,0,0,0,16,1,0,0,0,0,0,0,0,0,0,0,0,72,48,0,0,2,2,0,0,0,0,0,0,0,0,0,0,124,45,0,0,126,52,0,0,228,9,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,80,63,4,0,160,187,8,0,0,0,0,0,0,0,0,0,216,194,1,0,136,60,4,0,0,0,0,0,72,56,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,8,0,0,2,0,0,0,0,0,0,16,1,0,0,0,0,0,0,0,0,0,0,0,82,34,0,0,152,9,0,0,0,0,0,0,0,0,0,0,124,45,0,0,126,52,0,0,228,9,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,112,74,4,0,160,187,8,0,0,0,0,0,0,0,0,0,216,194,1,0,32,72,4,0,0,0,0,0,200,147,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,8,0,0,2,0,0,0,0,0,0,16,1,0,0,0,0,0,0,0,0,0,0,0,34,22,0,0,132,32,0,0,0,0,0,0,0,0,0,0,124,45,0,0,126,52,0,0,228,9,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,128,154,8,0,160,187,8,0,0,0,0,0,0,0,0,0,216,194,1,0,56,148,8,0,0,0,0,0,80,142,8,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,8,0,0,2,0,0,0,0,0,0,16,1,0,0,0,0,0,0,0,0,0,0,0,122,3,0,0,46,34,0,0,0,0,0,0,0,0,0,0,26,51,0,0,240,23,0,0,116,10,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,144,70,4,0,160,187,8,0,0,0,0,0,0,0,0,0,216,194,1,0,88,68,4,0,0,0,0,0,8,66,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,8,0,0,2,0,0,0,0,0,0,16,1,0,0,0,0,0,0,0,0,0,0,0,110,4,0,0,218,36,0,0,0,0,0,0,0,0,0,0,124,45,0,0,126,52,0,0,228,9,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,88,46,4,0,160,187,8,0,0,0,0,0,0,0,0,0,216,194,1,0,224,43,4,0,0,0,0,0,248,160,1,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,8,0,0,2,0,0,0,0,0,0,16,1,0,0,0,0,0,0,0,0,0,0,0,224,49,0,0,90,27,0,0,0,0,0,0,0,0,0,0,124,45,0,0,126,52,0,0,228,9,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,160,187,8,0,0,0,0,0,0,0,0,0,0,0,0,0,216,194,1,0,24,76,4,0,0,0,0,0,168,95,8,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,8,0,0,2,0,0,0,0,0,0,16,1,0,0,0,0,0,0,0,0,0,0,0,244,51,0,0,164,17,0,0,0,0,0,0,0,0,0,0,124,45,0,0,126,52,0,0,228,9,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,144,192,8,0,160,187,8,0,0,0,0,0,0,0,0,0,216,194,1,0,24,179,8,0,0,0,0,0,192,154,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,8,0,0,2,0,0,0,0,0,0,16,1,0,0,0,0,0,0,0,0,0,0,0,74,51,0,0,204,46,0,0,0,0,0,0,0,0,0,0,0,4,0,0,94,30,0,0,254,12,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,128,172,8,0,160,187,8,0,0,0,0,0,0,0,0,0,216,194,1,0,88,163,8,0,0,0,0,0,192,154,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,8,0,0,2,0,0,0,0,0,0,16,1,0,0,0,0,0,0,0,0,0,0,0,186,36,0,0,90,40,0,0,0,0,0,0,0,0,0,0,172,18,0,0,34,13,0,0,148,7,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,0,100,8,0,0,0,0,0,0,0,0,0,0,0,0,0,64,171,7,0,40,185,6,0,0,0,0,0,168,95,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,2,0,0,0,0,0,0,3,1,0,0,0,0,0,0,0,0,0,0,0,162,9,0,0,228,15,0,0,0,0,0,0,0,0,0,0,50,31,0,0,24,49,0,0,202,6,0,0,64,2,0,0,138,13,0,0,144,16,0,0,168,13,0,0,8,177,145,0,0,16,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,200,124,3,0,208,140,3,0,0,0,0,0,0,0,0,0,40,41,5,0,64,122,3,0,0,0,0,0,208,119,3,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,8,0,0,2,0,0,0,0,0,0,16,1,0,0,0,0,0,0,0,0,0,0,0,250,10,0,0,224,28,0,0,0,0,0,0,0,0,0,0,140,50,0,0,82,48,0,0,10,17,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,32,129,3,0,208,140,3,0,0,0,0,0,0,0,0,0,232,167,7,0,16,127,3,0,88,1,5,0,136,134,3,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,8,0,0,2,0,0,0,0,0,0,16,1,0,0,0,0,0,0,0,0,0,0,0,12,20,0,0,114,36,0,0,0,0,0,0,0,0,0,0,46,12,0,0,154,25,0,0,36,7,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,64,132,3,0,208,140,3,0,0,0,0,0,0,0,0,0,232,167,7,0,192,130,3,0,88,1,5,0,136,134,3,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,8,0,0,2,0,0,0,0,0,0,16,1,0,0,0,0,0,0,0,0,0,0,0,236,25,0,0,244,1,0,0,0,0,0,0,0,0,0,0,46,12,0,0,154,25,0,0,36,7,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,208,140,3,0,0,0,0,0,0,0,0,0,0,0,0,0,232,167,7,0,136,137,3,0,88,1,5,0,136,134,3,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,8,0,0,2,0,0,0,0,0,0,16,1,0,0,0,0,0,0,0,0,0,0,0,174,42,0,0,16,21,0,0,0,0,0,0,0,0,0,0,46,12,0,0,154,25,0,0,36,7,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,240,27,3,0,152,238,7,0,0,0,0,0,0,0,0,0,104,174,7,0,104,112,2,0,0,0,0,0,168,95,8,0,40,252,3,0,232,248,1,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,3,5,0,0,0,0,0,0,0,0,0,0,0,196,24,0,0,36,9,0,0,0,0,0,0,0,0,0,0,60,6,0,0,140,53,0,0,252,9,0,0,214,2,0,0,232,4,0,0,44,5,0,0,98,39,0,0,152,176,145,0,0,4,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,152,238,7,0,0,0,0,0,0,0,0,0,0,0,0,0,104,174,7,0,176,172,6,0,0,0,0,0,168,95,8,0,40,252,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,2,0,0,0,0,0,0,3,5,0,0,0,0,0,0,0,0,0,0,0,112,0,0,0,242,39,0,0,0,0,0,0,0,0,0,0,60,6,0,0,140,53,0,0,252,9,0,0,214,2,0,0,232,4,0,0,44,5,0,0,98,39,0,0,152,176,145,0,0,4,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,152,84,3,0,96,88,3,0,0,0,0,0,0,0,0,0,216,194,1,0,80,83,3,0,0,0,0,0,128,199,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,16,1,0,0,0,0,0,0,0,0,0,0,0,162,38,0,0,2,11,0,0,0,0,0,0,0,0,0,0,100,63,0,0,172,34,0,0,254,3,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,120,86,3,0,96,88,3,0,0,0,0,0,0,0,0,0,216,194,1,0,184,85,3,0,0,0,0,0,200,147,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,8,0,0,2,0,0,0,0,0,0,16,1,0,0,0,0,0,0,0,0,0,0,0,164,17,0,0,76,38,0,0,0,0,0,0,0,0,0,0,100,63,0,0,172,34,0,0,254,3,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,96,81,3,0,96,88,3,0,0,0,0,0,0,0,0,0,216,194,1,0,224,79,3,0,0,0,0,0,192,154,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,0,0,0,2,0,0,0,0,0,0,16,1,0,0,0,0,0,0,0,0,0,0,0,188,4,0,0,78,42,0,0,0,0,0,0,0,0,0,0,100,63,0,0,172,34,0,0,254,3,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,96,88,3,0,0,0,0,0,0,0,0,0,0,0,0,0,216,194,1,0,96,87,3,0,0,0,0,0,168,95,8,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,8,0,0,2,0,0,0,0,0,0,16,1,0,0,0,0,0,0,0,0,0,0,0,58,16,0,0,134,38,0,0,0,0,0,0,0,0,0,0,100,63,0,0,118,0,0,0,254,3,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,88,83,2,0,160,161,2,0,0,0,0,0,0,0,0,0,184,168,7,0,128,70,2,0,0,0,0,0,128,161,4,0,216,142,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,11,0,0,4,0,0,0,0,0,0,0,0,0,106,31,0,0,124,6,0,0,0,0,0,0,0,0,0,0,74,25,0,0,44,35,0,0,190,6,0,0,24,8,0,0,14,5,0,0,0,0,0,0,60,41,0,0,0,0,0,0,0,16,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,240,56,2,0,160,161,2,0,0,0,0,0,0,0,0,0,184,168,7,0,192,41,2,0,0,0,0,0,88,31,2,0,216,142,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,11,0,0,4,0,0,0,0,0,0,0,0,0,248,16,0,0,112,40,0,0,0,0,0,0,0,0,0,0,74,25,0,0,68,61,0,0,190,6,0,0,24,8,0,0,14,5,0,0,0,0,0,0,60,41,0,0,0,0,0,0,0,16,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,240,109,2,0,160,161,2,0,0,0,0,0,0,0,0,0,184,168,7,0,32,99,2,0,0,0,0,0,144,84,8,0,216,142,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,11,0,0,4,0,0,0,0,0,0,0,0,0,246,9,0,0,74,25,0,0,0,0,0,0,0,0,0,0,74,25,0,0,124,32,0,0,190,6,0,0,24,8,0,0,14,5,0,0,0,0,0,0,60,41,0,0,0,0,0,0,0,16,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,96,136,2,0,160,161,2,0,0,0,0,0,0,0,0,0,184,168,7,0,232,123,2,0,0,0,0,0,168,183,7,0,216,142,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,11,0,0,4,0,0,0,0,0,0,0,0,0,242,39,0,0,38,31,0,0,0,0,0,0,0,0,0,0,74,25,0,0,68,61,0,0,190,6,0,0,24,8,0,0,14,5,0,0,0,0,0,0,60,41,0,0,0,0,0,0,0,16,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,160,161,2,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,128,148,2,0,0,0,0,0,168,183,7,0,216,142,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,11,0,0,4,0,0,0,0,0,0,0,0,0,118,17,0,0,74,33,0,0,0,0,0,0,0,0,0,0,74,25,0,0,68,61,0,0,190,6,0,0,24,8,0,0,14,5,0,0,0,0,0,0,60,41,0,0,0,0,0,0,0,16,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,24,123,6,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,0,32,6,0,0,0,0,0,40,241,5,0,168,84,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,19,8,0,0,0,0,0,0,0,0,0,0,0,238,27,0,0,84,23,0,0,0,0,0,0,0,0,0,0,234,43,0,0,96,45,0,0,194,16,0,0,222,8,0,0,178,15,0,0,250,0,0,0,78,56,0,0,104,173,145,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,144,220,2,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,120,253,5,0,216,165,4,0,80,139,3,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,3,11,0,0,1,0,0,0,0,0,0,0,0,0,108,7,0,0,2,48,0,0,0,0,0,0,0,0,0,0,78,34,0,0,250,55,0,0,26,2,0,0,188,19,0,0,190,3,0,0,26,1,0,0,196,1,0,0,0,0,0,0,0,8,0,0,32,1,0,0,208,0,0,0,4,0,0,0,3,0,0,0,32,227,7,0,72,237,7,0,0,0,0,0,0,0,0,0,104,221,5,0,176,223,7,0,0,0,0,0,232,196,4,0,80,164,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,10,1,0,0,0,0,0,0,0,0,0,0,0,192,2,0,0,198,7,0,0,0,0,0,0,0,0,0,0,244,56,0,0,12,58,0,0,18,15,0,0,56,12,0,0,212,3,0,0,228,19,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,19,6,0,96,23,6,0,0,0,0,0,0,0,0,0,192,177,6,0,72,45,8,0,0,0,0,0,232,163,8,0,40,181,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,0,13,0,0,8,0,0,0,0,0,0,0,0,0,4,61,0,0,50,12,0,0,0,0,0,0,0,0,0,0,184,35,0,0,210,44,0,0,50,1,0,0,160,16,0,0,104,12,0,0,54,1,0,0,166,39,0,0,0,0,0,0,0,20,0,0,224,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,96,23,6,0,0,0,0,0,0,0,0,0,0,0,0,0,192,177,6,0,240,163,8,0,0,0,0,0,232,163,8,0,40,181,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,0,13,0,0,8,0,0,0,0,0,0,0,0,0,140,38,0,0,186,28,0,0,0,0,0,0,0,0,0,0,184,35,0,0,210,44,0,0,50,1,0,0,160,16,0,0,104,12,0,0,54,1,0,0,166,39,0,0,0,0,0,0,0,20,0,0,224,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,56,255,6,0,56,12,3,0,0,0,0,0,0,0,0,0,160,234,7,0,176,214,6,0,0,0,0,0,192,154,4,0,128,194,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,3,11,0,8,0,0,0,0,0,0,0,0,0,0,74,17,0,0,248,40,0,0,0,0,0,0,0,0,0,0,120,36,0,0,24,45,0,0,176,9,0,0,148,18,0,0,100,14,0,0,0,0,0,0,120,21,0,0,0,0,0,0,0,1,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,91,7,0,56,12,3,0,0,0,0,0,0,0,0,0,160,234,7,0,48,43,7,0,0,0,0,0,192,154,4,0,128,194,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,3,11,0,8,0,0,0,0,0,0,0,0,0,0,186,55,0,0,66,46,0,0,0,0,0,0,0,0,0,0,120,36,0,0,146,4,0,0,176,9,0,0,148,18,0,0,100,14,0,0,0,0,0,0,120,21,0,0,0,0,0,0,0,1,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,141,1,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,200,126,1,0,0,0,0,0,144,84,8,0,168,196,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,5,11,0,0,1,0,0,0,0,0,0,0,0,0,90,52,0,0,132,44,0,0,0,0,0,0,0,0,0,0,34,32,0,0,78,36,0,0,28,18,0,0,178,11,0,0,82,0,0,0,238,10,0,0,188,1,0,0,0,0,0,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,141,3,0,128,0,4,0,0,0,0,0,0,0,0,0,104,221,5,0,88,118,3,0,0,0,0,0,96,95,3,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,10,0,16,0,0,0,0,0,0,0,0,0,0,118,2,0,0,114,37,0,0,0,0,0,0,0,0,0,0,74,46,0,0,0,0,0,0,174,15,0,0,22,7,0,0,230,18,0,0,0,0,0,0,110,45,0,0,0,0,0,0,0,8,0,0,128,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,136,91,2,0,232,24,5,0,0,0,0,0,0,0,0,0,64,171,7,0,72,231,1,0,0,0,0,0,216,132,1,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,0,20,2,0,0,0,0,0,0,0,0,0,0,0,254,31,0,0,128,41,0,0,0,0,0,0,0,0,0,0,250,13,0,0,34,57,0,0,54,9,0,0,8,3,0,0,38,12,0,0,164,19,0,0,180,35,0,0,144,175,145,0,0,4,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,208,254,0,0,0,0,0,0,72,172,6,0,0,0,0,0,32,127,5,0,32,228,7,0,0,0,0,0,128,145,4,0,208,9,3,0,152,224,7,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,1,0,1,133,8,0,0,0,0,0,0,0,0,0,0,0,148,14,0,0,222,10,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,136,1,0,0,0,0,0,0,0,0,0,0,0,0,0,64,164,6,0,16,236,8,0,0,0,0,0,216,233,1,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,118,60,0,0,98,0,0,0,0,0,0,0,0,0,0,0,16,29,0,0,106,57,0,0,52,4,0,0,40,2,0,0,154,18,0,0,128,9,0,0,56,24,0,0,240,175,145,0,8,2,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,8,102,4,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,80,65,6,0,0,0,0,0,184,220,4,0,248,180,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,133,0,0,0,2,0,0,0,0,0,0,13,2,0,0,0,0,0,0,0,0,0,0,0,94,24,0,0,116,18,0,0,0,0,0,0,0,0,0,0,32,31,0,0,182,25,0,0,120,5,0,0,66,4,0,0,206,19,0,0,238,15,0,0,232,20,0,0,216,157,215,0,0,16,0,0,224,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,24,183,7,0,152,165,2,0,0,0,0,0,152,165,2,0,184,168,7,0,128,136,7,0,120,155,4,0,160,150,4,0,224,127,3,0,152,88,7,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,1,4,2,0,0,0,0,0,0,0,0,0,0,0,124,8,0,0,188,42,0,0,38,43,0,0,108,39,0,0,54,13,0,0,150,35,0,0,224,12,0,0,46,14,0,0,102,14,0,0,94,13,0,0,238,17,0,0,32,146,215,0,0,8,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,184,148,8,0,152,165,2,0,0,0,0,0,152,165,2,0,184,168,7,0,216,31,8,0,120,155,4,0,160,150,4,0,224,127,3,0,48,235,7,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,1,4,2,0,0,0,0,0,0,0,0,0,0,0,248,43,0,0,182,11,0,0,38,43,0,0,108,39,0,0,54,13,0,0,212,57,0,0,224,12,0,0,46,14,0,0,102,14,0,0,94,13,0,0,238,17,0,0,32,146,215,0,0,8,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,0,141,8,0,216,19,2,0,72,172,6,0,0,0,0,0,240,3,2,0,0,136,8,0,0,0,0,0,128,145,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,133,8,0,0,0,32,0,0,0,0,0,0,0,208,36,0,0,244,42,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,239,6,0,40,245,6,0,72,172,6,0,0,0,0,0,168,163,7,0,200,236,6,0,0,0,0,0,128,145,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,133,8,0,0,0,32,0,0,0,0,0,0,0,134,14,0,0,196,15,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,245,6,0,0,0,0,0,72,172,6,0,0,0,0,0,168,163,7,0,240,246,6,0,0,0,0,0,128,145,4,0,208,9,3,0,104,242,6,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,8,0,0,0,32,0,0,0,0,0,0,0,252,59,0,0,58,5,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,121,7,0,216,5,8,0,72,172,6,0,0,0,0,0,32,127,5,0,240,116,7,0,0,0,0,0,128,145,4,0,208,9,3,0,40,111,7,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,133,8,0,0,0,32,0,0,0,0,0,0,0,172,55,0,0,154,6,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,5,8,0,0,0,0,0,72,172,6,0,0,0,0,0,32,127,5,0,144,127,7,0,0,0,0,0,128,145,4,0,208,9,3,0,184,124,7,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,8,0,0,0,32,0,0,0,0,0,0,0,156,43,0,0,250,16,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,230,8,0,0,0,0,0,72,172,6,0,0,0,0,0,0,38,7,0,104,200,7,0,0,0,0,0,128,145,4,0,208,9,3,0,88,193,7,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,1,0,1,133,8,0,0,0,32,0,0,0,0,0,0,0,32,9,0,0,242,23,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,19,2,0,0,0,0,0,72,172,6,0,0,0,0,0,240,3,2,0,176,145,8,0,0,0,0,0,128,145,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,8,0,0,0,32,0,0,0,0,0,0,0,136,2,0,0,108,36,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,76,2,0,40,250,3,0,0,0,0,0,0,0,0,0,32,127,5,0,160,217,1,0,0,0,0,0,152,210,4,0,136,153,3,0,0,119,1,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,1,0,0,6,4,0,0,0,0,0,0,0,0,0,0,0,238,46,0,0,4,4,0,0,0,0,0,0,0,0,0,0,24,47,0,0,0,0,0,0,108,12,0,0,188,12,0,0,184,4,0,0,36,11,0,0,84,24,0,0,96,49,216,0,0,128,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,168,194,7,0,40,250,3,0,0,0,0,0,0,0,0,0,32,127,5,0,88,146,7,0,0,0,0,0,152,210,4,0,136,153,3,0,104,99,7,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,1,0,0,6,4,0,0,0,0,0,0,0,0,0,0,0,236,2,0,0,56,7,0,0,0,0,0,0,0,0,0,0,24,47,0,0,0,0,0,0,108,12,0,0,188,12,0,0,184,4,0,0,36,11,0,0,84,24,0,0,96,49,216,0,0,128,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,168,97,8,0,40,250,3,0,0,0,0,0,0,0,0,0,32,127,5,0,176,42,8,0,0,0,0,0,152,210,4,0,136,153,3,0,64,246,7,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,1,0,0,6,4,0,0,0,0,0,0,0,0,0,0,0,222,56,0,0,36,14,0,0,0,0,0,0,0,0,0,0,24,47,0,0,0,0,0,0,108,12,0,0,188,12,0,0,184,4,0,0,36,11,0,0,84,24,0,0,96,49,216,0,0,128,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,8,38,1,0,40,250,3,0,0,0,0,0,0,0,0,0,32,127,5,0,112,227,8,0,0,0,0,0,152,210,4,0,136,153,3,0,24,160,8,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,1,0,0,6,4,0,0,0,0,0,0,0,0,0,0,0,40,45,0,0,200,23,0,0,0,0,0,0,0,0,0,0,24,47,0,0,0,0,0,0,108,12,0,0,188,12,0,0,184,4,0,0,36,11,0,0,84,24,0,0,96,49,216,0,0,128,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,128,49,7,0,40,250,3,0,0,0,0,0,0,0,0,0,32,127,5,0,240,5,7,0,0,0,0,0,152,210,4,0,136,153,3,0,96,219,6,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,1,0,0,6,4,0,0,0,0,0,0,0,0,0,0,0,88,56,0,0,204,24,0,0,0,0,0,0,0,0,0,0,24,47,0,0,0,0,0,0,108,12,0,0,188,12,0,0,184,4,0,0,36,11,0,0,84,24,0,0,96,49,216,0,0,128,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,0,41,6,0,40,250,3,0,0,0,0,0,0,0,0,0,32,127,5,0,240,253,5,0,0,0,0,0,152,210,4,0,136,153,3,0,240,208,5,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,1,0,0,6,4,0,0,0,0,0,0,0,0,0,0,0,236,59,0,0,180,35,0,0,0,0,0,0,0,0,0,0,24,47,0,0,0,0,0,0,108,12,0,0,188,12,0,0,184,4,0,0,36,11,0,0,84,24,0,0,96,49,216,0,0,128,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,40,235,4,0,40,250,3,0,0,0,0,0,0,0,0,0,32,127,5,0,24,198,4,0,0,0,0,0,152,210,4,0,136,153,3,0,24,166,4,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,1,0,0,6,4,0,0,0,0,0,0,0,0,0,0,0,196,28,0,0,168,21,0,0,0,0,0,0,0,0,0,0,24,47,0,0,0,0,0,0,108,12,0,0,188,12,0,0,184,4,0,0,36,11,0,0,84,24,0,0,96,49,216,0,0,128,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,80,75,5,0,40,250,3,0,0,0,0,0,0,0,0,0,32,127,5,0,160,43,5,0,0,0,0,0,152,210,4,0,136,153,3,0,224,12,5,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,1,0,0,6,4,0,0,0,0,0,0,0,0,0,0,0,196,54,0,0,252,25,0,0,0,0,0,0,0,0,0,0,24,47,0,0,0,0,0,0,108,12,0,0,188,12,0,0,184,4,0,0,36,11,0,0,84,24,0,0,96,49,216,0,0,128,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,16,170,5,0,40,250,3,0,0,0,0,0,0,0,0,0,32,127,5,0,8,134,5,0,0,0,0,0,152,210,4,0,136,153,3,0,120,106,5,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,1,0,0,6,4,0,0,0,0,0,0,0,0,0,0,0,168,45,0,0,148,5,0,0,0,0,0,0,0,0,0,0,24,47,0,0,0,0,0,0,108,12,0,0,188,12,0,0,184,4,0,0,36,11,0,0,84,24,0,0,96,49,216,0,0,128,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,184,135,4,0,40,250,3,0,0,0,0,0,0,0,0,0,32,127,5,0,64,108,4,0,0,0,0,0,152,210,4,0,136,153,3,0,112,81,4,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,1,0,0,6,4,0,0,0,0,0,0,0,0,0,0,0,222,30,0,0,234,47,0,0,0,0,0,0,0,0,0,0,24,47,0,0,0,0,0,0,108,12,0,0,188,12,0,0,184,4,0,0,36,11,0,0,84,24,0,0,96,49,216,0,0,128,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,48,175,6,0,40,250,3,0,0,0,0,0,0,0,0,0,32,127,5,0,128,132,6,0,0,0,0,0,152,210,4,0,136,153,3,0,208,84,6,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,1,0,0,6,4,0,0,0,0,0,0,0,0,0,0,0,170,26,0,0,146,11,0,0,0,0,0,0,0,0,0,0,24,47,0,0,0,0,0,0,108,12,0,0,188,12,0,0,184,4,0,0,36,11,0,0,84,24,0,0,96,49,216,0,0,128,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,40,250,3,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,160,53,6,0,0,0,0,0,152,210,4,0,136,153,3,0,168,221,2,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,1,0,0,6,4,0,0,0,0,0,0,0,0,0,0,0,114,35,0,0,10,7,0,0,0,0,0,0,0,0,0,0,24,47,0,0,0,0,0,0,108,12,0,0,188,12,0,0,184,4,0,0,36,11,0,0,84,24,0,0,96,49,216,0,0,128,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,184,71,1,0,40,93,1,0,0,0,0,0,0,0,0,0,96,135,2,0,16,66,1,0,0,0,0,0,24,79,1,0,80,164,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,10,0,8,0,0,0,0,0,0,0,0,0,0,228,56,0,0,94,22,0,0,0,0,0,0,0,0,0,0,244,56,0,0,24,5,0,0,32,1,0,0,24,3,0,0,158,1,0,0,70,6,0,0,0,0,0,0,0,0,0,0,0,4,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,93,1,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,224,86,1,0,0,0,0,0,24,79,1,0,80,164,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,8,0,0,0,0,0,0,0,0,0,0,204,15,0,0,248,43,0,0,0,0,0,0,0,0,0,0,244,56,0,0,24,5,0,0,32,1,0,0,24,3,0,0,158,1,0,0,70,6,0,0,0,0,0,0,0,0,0,0,0,4,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,101,1,0,0,182,7,0,0,0,0,0,0,0,0,0,240,3,2,0,240,22,1,0,0,0,0,0,64,134,3,0,16,128,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,1,4,2,0,0,0,0,0,0,0,0,0,0,0,30,16,0,0,134,21,0,0,0,0,0,0,0,0,0,0,34,1,0,0,132,6,0,0,156,6,0,0,66,15,0,0,180,9,0,0,16,18,0,0,72,26,0,0,32,146,215,0,0,8,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,0,182,7,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,32,198,1,0,0,0,0,0,64,134,3,0,16,128,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,1,4,2,0,0,0,0,0,0,0,0,0,0,0,182,42,0,0,22,22,0,0,0,0,0,0,0,0,0,0,34,1,0,0,132,6,0,0,156,6,0,0,66,15,0,0,180,9,0,0,16,18,0,0,72,26,0,0,32,146,215,0,0,8,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,152,171,5,0,56,177,6,0,0,0,0,0,0,0,0,0,32,127,5,0,176,135,5,0,0,0,0,0,232,163,8,0,248,180,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,149,0,0,0,2,0,0,0,0,0,0,13,2,0,0,0,0,0,0,0,0,0,0,0,44,51,0,0,176,35,0,0,0,0,0,0,0,0,0,0,32,31,0,0,130,19,0,0,120,5,0,0,66,4,0,0,206,19,0,0,238,15,0,0,232,20,0,0,216,157,215,0,0,16,0,0,224,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,248,221,6,0,56,177,6,0,0,0,0,0,0,0,0,0,32,127,5,0,112,88,6,0,0,0,0,0,232,163,8,0,248,180,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,149,0,0,0,2,0,0,0,0,0,0,13,2,0,0,0,0,0,0,0,0,0,0,0,204,22,0,0,224,33,0,0,0,0,0,0,0,0,0,0,32,31,0,0,130,19,0,0,120,5,0,0])
.concat([66,4,0,0,206,19,0,0,238,15,0,0,232,20,0,0,216,157,215,0,0,16,0,0,224,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,104,0,6,0,56,177,6,0,0,0,0,0,0,0,0,0,32,127,5,0,40,211,5,0,0,0,0,0,232,163,8,0,248,180,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,149,0,0,0,2,0,0,0,0,0,0,13,2,0,0,0,0,0,0,0,0,0,0,0,250,1,0,0,84,16,0,0,0,0,0,0,0,0,0,0,32,31,0,0,130,19,0,0,120,5,0,0,66,4,0,0,206,19,0,0,238,15,0,0,232,20,0,0,216,157,215,0,0,16,0,0,224,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,144,56,6,0,0,0,0,0,0,0,0,0,0,0,0,0,144,139,6,0,112,8,7,0,0,0,0,0,232,163,8,0,192,148,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,0,13,2,0,0,0,0,0,0,0,0,0,0,0,138,57,0,0,124,43,0,0,0,0,0,0,0,0,0,0,56,14,0,0,96,18,0,0,220,9,0,0,160,16,0,0,104,12,0,0,54,1,0,0,166,39,0,0,0,0,0,0,0,20,0,0,224,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,64,59,6,0,0,0,0,0,0,0,0,0,0,0,0,0,184,12,8,0,184,79,2,0,0,0,0,0,232,163,8,0,40,181,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,0,13,2,0,0,0,0,0,0,0,0,0,0,0,198,44,0,0,232,35,0,0,0,0,0,0,0,0,0,0,184,35,0,0,210,44,0,0,146,14,0,0,160,16,0,0,104,12,0,0,54,1,0,0,166,39,0,0,0,0,0,0,0,20,0,0,224,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,144,108,5,0,56,177,6,0,0,0,0,0,0,0,0,0,32,127,5,0,32,77,5,0,0,0,0,0,232,163,8,0,248,180,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,149,0,0,0,2,0,0,0,0,0,0,13,2,0,0,0,0,0,0,0,0,0,0,0,44,38,0,0,2,44,0,0,0,0,0,0,0,0,0,0,32,31,0,0,108,44,0,0,120,5,0,0,66,4,0,0,206,19,0,0,238,15,0,0,232,20,0,0,216,157,215,0,0,16,0,0,224,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,56,177,6,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,208,42,6,0,0,0,0,0,232,163,8,0,248,180,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,133,0,0,0,2,0,0,0,0,0,0,13,2,0,0,0,0,0,0,0,0,0,0,0,194,31,0,0,18,31,0,0,0,0,0,0,0,0,0,0,32,31,0,0,10,41,0,0,120,5,0,0,66,4,0,0,206,19,0,0,238,15,0,0,232,20,0,0,216,157,215,0,0,16,0,0,224,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,176,20,8,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,80,17,8,0,0,0,0,0,80,85,2,0,80,150,3,0,48,13,8,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,64,4,4,2,0,16,0,0,0,0,0,0,0,0,0,0,188,36,0,0,18,29,0,0,0,0,0,0,0,0,0,0,162,60,0,0,26,27,0,0,8,18,0,0,114,17,0,0,134,11,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,225,8,0,192,201,3,0,0,0,0,0,0,0,0,0,184,168,7,0,0,96,8,0,0,0,0,0,32,0,1,0,240,185,2,0,64,40,8,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,184,30,0,0,236,43,0,0,0,0,0,0,0,0,0,0,222,45,0,0,162,51,0,0,128,17,0,0,14,3,0,0,164,11,0,0,42,4,0,0,242,13,0,0,104,174,145,0,0,16,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,244,7,0,192,201,3,0,0,0,0,0,0,0,0,0,184,168,7,0,168,192,7,0,0,0,0,0,32,0,1,0,240,185,2,0,80,144,7,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,170,34,0,0,90,25,0,0,0,0,0,0,0,0,0,0,222,45,0,0,162,51,0,0,128,17,0,0,14,3,0,0,164,11,0,0,42,4,0,0,242,13,0,0,104,174,145,0,0,16,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,20,2,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,128,4,2,0,0,0,0,0,144,84,8,0,168,196,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,5,11,2,0,0,0,0,0,0,0,0,0,0,0,2,59,0,0,184,2,0,0,0,0,0,0,0,0,0,0,180,22,0,0,210,29,0,0,12,2,0,0,178,11,0,0,82,0,0,0,238,10,0,0,188,1,0,0,0,0,0,0,0,16,0,0,224,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,176,49,1,0,168,188,5,0,0,0,0,0,0,0,0,0,160,234,7,0,192,237,8,0,0,0,0,0,32,0,1,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,252,35,0,0,158,36,0,0,0,0,0,0,0,0,0,0,2,54,0,0,186,4,0,0,114,12,0,0,90,14,0,0,242,4,0,0,126,18,0,0,176,61,0,0,56,176,145,0,0,4,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,173,8,0,168,188,5,0,0,0,0,0,0,0,0,0,160,234,7,0,200,109,8,0,0,0,0,0,32,0,1,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,206,10,0,0,100,17,0,0,0,0,0,0,0,0,0,0,2,54,0,0,186,4,0,0,114,12,0,0,90,14,0,0,242,4,0,0,126,18,0,0,176,61,0,0,56,176,145,0,0,4,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,235,1,0,168,188,5,0,0,0,0,0,0,0,0,0,160,234,7,0,112,139,1,0,0,0,0,0,32,0,1,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,162,40,0,0,196,30,0,0,0,0,0,0,0,0,0,0,2,54,0,0,186,4,0,0,114,12,0,0,90,14,0,0,242,4,0,0,126,18,0,0,176,61,0,0,56,176,145,0,0,4,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,254,2,0,168,188,5,0,0,0,0,0,0,0,0,0,160,234,7,0,200,97,2,0,0,0,0,0,32,0,1,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,126,49,0,0,192,2,0,0,0,0,0,0,0,0,0,0,2,54,0,0,186,4,0,0,114,12,0,0,90,14,0,0,242,4,0,0,126,18,0,0,176,61,0,0,56,176,145,0,0,4,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,188,5,0,0,0,0,0,0,0,0,0,0,0,0,0,160,234,7,0,88,119,6,0,0,0,0,0,32,0,1,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,12,27,0,0,172,18,0,0,0,0,0,0,0,0,0,0,2,54,0,0,186,4,0,0,114,12,0,0,90,14,0,0,242,4,0,0,126,18,0,0,176,61,0,0,56,176,145,0,0,4,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,236,8,0,136,123,5,0,0,0,0,0,0,0,0,0,160,234,7,0,64,172,8,0,0,0,0,0,192,223,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,0,20,0,0,8,0,0,0,0,0,0,0,0,0,228,29,0,0,46,2,0,0,0,0,0,0,0,0,0,0,176,58,0,0,112,16,0,0,130,16,0,0,132,2,0,0,2,18,0,0,120,2,0,0,242,56,0,0,0,176,145,0,0,2,0,0,240,0,0,0,96,1,0,0,3,0,0,0,4,0,0,0,24,23,3,0,248,203,7,0,0,0,0,0,0,0,0,0,64,171,7,0,16,110,2,0,0,0,0,0,168,95,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,3,0,8,0,0,0,0,0,0,0,0,0,0,16,22,0,0,156,19,0,0,0,0,0,0,0,0,0,0,18,28,0,0,176,62,0,0,180,19,0,0,254,15,0,0,6,2,0,0,252,3,0,0,24,13,0,0,144,35,149,0,0,2,0,0,240,0,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,148,2,0,24,211,2,0,0,0,0,0,0,0,0,0,104,221,5,0,24,136,2,0,0,0,0,0,144,84,8,0,208,135,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,2,11,4,0,0,0,0,0,0,0,0,0,0,0,38,34,0,0,130,38,0,0,0,0,0,0,0,0,0,0,188,10,0,0,180,17,0,0,52,11,0,0,46,7,0,0,246,17,0,0,0,0,0,0,176,18,0,0,0,0,0,0,0,32,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,63,1,0,24,251,8,0,0,0,0,0,0,0,0,0,200,190,7,0,208,250,8,0,0,0,0,0,32,187,8,0,200,12,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,17,1,0,0,0,0,0,0,0,0,0,0,0,202,46,0,0,174,12,0,0,0,0,0,0,0,0,0,0,198,62,0,0,58,3,0,0,222,11,0,0,230,1,0,0,44,6,0,0,194,15,0,0,0,0,0,0,48,177,145,0,0,2,0,0,128,1,0,0,0,1,0,0,4,0,0,0,3,0,0,0,104,103,6,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,160,55,6,0,240,56,5,0,152,54,6,0,168,38,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,5,17,1,0,0,0,0,0,0,0,0,0,0,0,132,34,0,0,70,34,0,0,0,0,0,0,0,0,0,0,58,34,0,0,200,30,0,0,166,14,0,0,218,2,0,0,114,1,0,0,166,3,0,0,116,50,0,0,8,211,148,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,240,15,6,0,104,103,6,0,0,0,0,0,0,0,0,0,96,135,2,0,16,223,5,0,240,56,5,0,152,54,6,0,168,38,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,5,17,1,0,0,0,0,0,0,0,0,0,0,0,154,37,0,0,96,27,0,0,0,0,0,0,0,0,0,0,58,34,0,0,200,30,0,0,166,14,0,0,218,2,0,0,114,1,0,0,166,3,0,0,116,50,0,0,8,211,148,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,216,1,2,0,24,251,8,0,0,0,0,0,0,0,0,0,200,190,7,0,160,158,1,0,0,0,0,0,152,54,6,0,200,12,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,17,1,0,0,0,0,0,0,0,0,0,0,0,124,28,0,0,68,14,0,0,0,0,0,0,0,0,0,0,198,62,0,0,64,48,0,0,222,11,0,0,230,1,0,0,44,6,0,0,194,15,0,0,0,0,0,0,48,177,145,0,0,2,0,0,128,1,0,0,0,1,0,0,4,0,0,0,3,0,0,0,0,39,3,0,24,251,8,0,0,0,0,0,0,0,0,0,200,190,7,0,136,120,2,0,0,0,0,0,152,54,6,0,200,12,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,17,1,0,0,0,0,0,0,0,0,0,0,0,16,61,0,0,174,24,0,0,0,0,0,0,0,0,0,0,198,62,0,0,58,3,0,0,222,11,0,0,230,1,0,0,44,6,0,0,194,15,0,0,0,0,0,0,48,177,145,0,0,2,0,0,128,1,0,0,0,1,0,0,4,0,0,0,3,0,0,0,64,122,8,0,24,251,8,0,0,0,0,0,0,0,0,0,200,190,7,0,208,63,8,0,0,0,0,0,192,154,4,0,200,12,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,3,17,1,0,0,0,0,0,0,0,0,0,0,0,180,25,0,0,198,39,0,0,0,0,0,0,0,0,0,0,198,62,0,0,58,3,0,0,222,11,0,0,230,1,0,0,44,6,0,0,194,15,0,0,0,0,0,0,48,177,145,0,0,2,0,0,128,1,0,0,0,1,0,0,4,0,0,0,3,0,0,0,112,124,3,0,152,10,4,0,0,0,0,0,0,0,0,0,184,168,7,0,224,101,3,0,0,0,0,0,152,54,6,0,232,200,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,17,1,0,0,0,0,0,0,0,0,0,0,0,98,4,0,0,92,24,0,0,0,0,0,0,0,0,0,0,198,62,0,0,34,31,0,0,2,12,0,0,230,1,0,0,44,6,0,0,194,15,0,0,0,0,0,0,48,177,145,0,0,2,0,0,128,1,0,0,0,1,0,0,4,0,0,0,3,0,0,0,40,174,3,0,152,10,4,0,0,0,0,0,0,0,0,0,184,168,7,0,136,149,3,0,0,0,0,0,152,54,6,0,232,200,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,17,1,0,0,0,0,0,0,0,0,0,0,0,114,11,0,0,56,24,0,0,0,0,0,0,0,0,0,0,198,62,0,0,34,31,0,0,2,12,0,0,230,1,0,0,44,6,0,0,194,15,0,0,0,0,0,0,48,177,145,0,0,2,0,0,128,1,0,0,0,1,0,0,4,0,0,0,3,0,0,0,152,10,4,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,128,232,3,0,0,0,0,0,152,54,6,0,232,200,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,3,17,1,0,0,0,0,0,0,0,0,0,0,0,236,13,0,0,182,19,0,0,0,0,0,0,0,0,0,0,198,62,0,0,34,31,0,0,2,12,0,0,230,1,0,0,44,6,0,0,194,15,0,0,0,0,0,0,48,177,145,0,0,2,0,0,128,1,0,0,0,1,0,0,4,0,0,0,3,0,0,0,24,251,8,0,0,0,0,0,0,0,0,0,0,0,0,0,200,190,7,0,160,196,6,0,0,0,0,0,152,54,6,0,200,12,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,3,17,1,0,0,0,0,0,0,0,0,0,0,0,18,3,0,0,96,18,0,0,0,0,0,0,0,0,0,0,198,62,0,0,58,3,0,0,222,11,0,0,230,1,0,0,44,6,0,0,194,15,0,0,0,0,0,0,48,177,145,0,0,2,0,0,128,1,0,0,0,1,0,0,4,0,0,0,3,0,0,0,96,253,2,0,88,177,5,0,0,0,0,0,0,0,0,0,200,190,7,0,72,97,2,0,0,0,0,0,24,235,1,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,198,21,0,0,130,46,0,0,0,0,0,0,0,0,0,0,120,43,0,0,154,47,0,0,202,4,0,0,0,7,0,0,156,5,0,0,104,4,0,0,254,2,0,0,40,176,145,0,0,4,0,0,32,1,0,0,216,0,0,0,4,0,0,0,3,0,0,0,160,29,3,0,88,16,8,0,0,0,0,0,0,0,0,0,144,47,2,0,120,113,2,0,0,0,0,0,168,95,8,0,48,254,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,3,0,64,0,0,0,0,0,0,0,0,0,0,12,43,0,0,252,13,0,0,0,0,0,0,0,0,0,0,254,44,0,0,82,14,0,0,38,4,0,0,2,16,0,0,146,18,0,0,142,6,0,0,254,60,0,0,184,176,145,0,0,4,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,16,8,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,208,175,6,0,0,0,0,0,168,95,8,0,48,254,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,3,0,64,0,0,0,0,0,0,0,0,0,0,164,19,0,0,138,38,0,0,0,0,0,0,0,0,0,0,254,44,0,0,82,14,0,0,38,4,0,0,2,16,0,0,146,18,0,0,142,6,0,0,254,60,0,0,184,176,145,0,0,4,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,147,8,0,144,134,2,0,0,0,0,0,0,0,0,0,144,47,2,0,96,84,8,0,0,0,0,0,176,237,2,0,168,84,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,19,4,8,0,0,0,0,0,0,0,0,0,0,10,36,0,0,200,35,0,0,0,0,0,0,0,0,0,0,234,43,0,0,26,15,0,0,168,5,0,0,222,8,0,0,178,15,0,0,174,5,0,0,78,56,0,0,104,173,145,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,64,19,1,0,144,134,2,0,0,0,0,0,0,0,0,0,144,47,2,0,136,211,8,0,0,0,0,0,176,237,2,0,168,84,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,19,4,8,0,0,0,0,0,0,0,0,0,0,20,47,0,0,36,8,0,0,0,0,0,0,0,0,0,0,234,43,0,0,26,15,0,0,168,5,0,0,222,8,0,0,178,15,0,0,174,5,0,0,78,56,0,0,104,173,145,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,192,194,1,0,144,134,2,0,0,0,0,0,0,0,0,0,144,47,2,0,24,97,1,0,0,0,0,0,176,237,2,0,168,84,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,19,4,8,0,0,0,0,0,0,0,0,0,0,182,50,0,0,230,42,0,0,0,0,0,0,0,0,0,0,234,43,0,0,26,15,0,0,168,5,0,0,222,8,0,0,178,15,0,0,174,5,0,0,78,56,0,0,104,173,145,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,224,185,2,0,144,134,2,0,0,0,0,0,0,0,0,0,144,47,2,0,96,49,2,0,0,0,0,0,176,237,2,0,168,84,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,19,4,8,0,0,0,0,0,0,0,0,0,0,226,59,0,0,30,5,0,0,0,0,0,0,0,0,0,0,234,43,0,0,26,15,0,0,168,5,0,0,222,8,0,0,178,15,0,0,174,5,0,0,78,56,0,0,104,173,145,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,144,134,2,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,112,228,5,0,0,0,0,0,176,237,2,0,168,84,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,19,4,8,0,0,0,0,0,0,0,0,0,0,214,11,0,0,60,46,0,0,0,0,0,0,0,0,0,0,234,43,0,0,26,15,0,0,168,5,0,0,222,8,0,0,178,15,0,0,174,5,0,0,78,56,0,0,104,173,145,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,112,87,5,0,0,0,0,0,0,0,0,0,0,0,0,0,216,194,1,0,200,82,5,0,0,0,0,0,64,246,3,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,8,0,0,2,0,0,0,0,0,0,16,0,0,1,0,0,0,0,0,0,0,0,0,236,44,0,0,116,47,0,0,0,0,0,0,0,0,0,0,46,31,0,0,66,60,0,0,162,18,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,22,4,0,152,76,4,0,0,0,0,0,0,0,0,0,104,174,7,0,88,247,3,0,0,0,0,0,176,237,2,0,248,135,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,19,1,0,0,0,0,0,0,0,0,0,0,0,40,5,0,0,130,9,0,0,0,0,0,0,0,0,0,0,72,1,0,0,12,63,0,0,252,0,0,0,116,8,0,0,90,13,0,0,0,0,0,0,68,58,0,0,0,0,0,0,0,4,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,208,111,3,0,152,76,4,0,0,0,0,0,0,0,0,0,104,174,7,0,8,90,3,0,0,0,0,0,168,138,8,0,248,135,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,19,1,0,0,0,0,0,0,0,0,0,0,0,212,8,0,0,6,42,0,0,0,0,0,0,0,0,0,0,72,1,0,0,12,63,0,0,252,0,0,0,116,8,0,0,90,13,0,0,0,0,0,0,68,58,0,0,0,0,0,0,0,4,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,112,160,3,0,152,76,4,0,0,0,0,0,0,0,0,0,104,174,7,0,48,135,3,0,0,0,0,0,168,138,8,0,248,135,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,19,1,0,0,0,0,0,0,0,0,0,0,0,156,1,0,0,120,22,0,0,0,0,0,0,0,0,0,0,72,1,0,0,12,63,0,0,252,0,0,0,116,8,0,0,90,13,0,0,0,0,0,0,68,58,0,0,0,0,0,0,0,4,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,88,213,3,0,152,76,4,0,0,0,0,0,0,0,0,0,104,174,7,0,184,185,3,0,0,0,0,0,176,237,2,0,248,135,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,19,1,0,0,0,0,0,0,0,0,0,0,0,40,56,0,0,40,40,0,0,0,0,0,0,0,0,0,0,72,1,0,0,12,63,0,0,252,0,0,0,116,8,0,0,90,13,0,0,0,0,0,0,68,58,0,0,0,0,0,0,0,4,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,64,75,3,0,152,76,4,0,0,0,0,0,0,0,0,0,104,174,7,0,112,62,3,0,0,0,0,0,192,154,4,0,248,135,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,0,19,1,0,0,0,0,0,0,0,0,0,0,0,230,3,0,0,110,7,0,0,0,0,0,0,0,0,0,0,72,1,0,0,12,63,0,0,72,10,0,0,212,0,0,0,140,12,0,0,0,0,0,0,24,26,0,0,0,0,0,0,0,4,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,184,123,4,0,104,185,4,0,0,0,0,0,0,0,0,0,144,47,2,0,80,98,4,0,0,0,0,0,176,237,2,0,168,84,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,19,4,0,0,0,0,0,0,0,0,0,0,0,94,19,0,0,166,21,0,0,0,0,0,0,0,0,0,0,8,32,0,0,2,37,0,0,134,2,0,0,192,10,0,0,42,10,0,0,2,5,0,0,112,12,0,0,0,173,145,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,208,71,4,0,104,185,4,0,0,0,0,0,0,0,0,0,144,47,2,0,112,43,4,0,0,0,0,0,176,237,2,0,168,84,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,19,4,0,0,0,0,0,0,0,0,0,0,0,90,10,0,0,186,14,0,0,0,0,0,0,0,0,0,0,8,32,0,0,2,37,0,0,134,2,0,0,192,10,0,0,42,10,0,0,2,5,0,0,112,12,0,0,0,173,145,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,104,185,4,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,232,153,4,0,0,0,0,0,176,237,2,0,168,84,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,19,4,0,0,0,0,0,0,0,0,0,0,0,126,59,0,0,156,44,0,0,0,0,0,0,0,0,0,0,8,32,0,0,2,37,0,0,134,2,0,0,192,10,0,0,42,10,0,0,2,5,0,0,112,12,0,0,0,173,145,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,152,76,4,0,0,0,0,0,0,0,0,0,0,0,0,0,104,174,7,0,200,49,4,0,0,0,0,0,176,237,2,0,248,135,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,19,1,0,0,0,0,0,0,0,0,0,0,0,74,49,0,0,102,10,0,0,0,0,0,0,0,0,0,0,72,1,0,0,12,63,0,0,252,0,0,0,116,8,0,0,90,13,0,0,0,0,0,0,68,58,0,0,0,0,0,0,0,4,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,104,89,3,0,0,0,0,0,72,172,6,0,0,0,0,0,144,47,2,0,96,37,1,0,0,0,0,0,128,145,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,4,0,0,0,0,0,0,0,0,0,0,0,4,29,0,0,204,28,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,102,6,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,128,15,6,0,192,222,5,0,152,54,6,0,152,8,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,4,17,0,0,1,0,0,0,0,0,0,0,0,0,54,11,0,0,110,44,0,0,0,0,0,0,0,0,0,0,184,4,0,0,54,41,0,0,244,1,0,0,80,0,0,0,228,1,0,0,44,8,0,0,0,0,0,0,32,177,145,0,0,2,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,176,28,8,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,144,24,8,0,0,0,0,0,104,24,4,0,80,150,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,4,4,2,4,0,0,0,0,0,0,0,0,0,0,0,250,58,0,0,46,23,0,0,0,0,0,0,0,0,0,0,210,8,0,0,20,46,0,0,114,11,0,0,114,17,0,0,134,11,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,5,8,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,136,42,8,0,0,0,0,0,232,167,5,0,240,185,2,0,96,194,7,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,0,8,0,0,0,0,0,0,0,0,0,14,9,0,0,120,1,0,0,0,0,0,0,0,0,0,0,176,60,0,0,0,16,0,0,254,17,0,0,152,4,0,0,116,1,0,0,0,0,0,0,212,49,0,0,0,0,0,0,0,32,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,58,1,0,168,180,7,0,0,0,0,0,0,0,0,0,104,174,7,0,48,245,8,0,0,0,0,0,168,95,8,0,32,247,3,0,160,180,8,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,3,0,64,0,0,0,0,0,0,0,0,0,0,56,34,0,0,172,41,0,0,0,0,0,0,0,0,0,0,236,0,0,0,252,2,0,0,160,17,0,0,14,19,0,0,14,10,0,0,172,8,0,0,148,27,0,0,96,176,145,0,0,1,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,180,5,0,40,233,7,0,72,172,6,0,0,0,0,0,104,221,5,0,224,141,5,0,0,0,0,0,128,145,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,133,0,0,4,0,0,0,0,0,0,0,0,0,40,55,0,0,0,33,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,233,7,0,0,0,0,0,72,172,6,0,0,0,0,0,104,221,5,0,248,217,5,0,0,0,0,0,128,145,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,0,0,4,0,0,0,0,0,0,0,0,0,16,48,0,0,34,24,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,168,4,0,32,15,5,0,0,0,0,0,0,0,0,0,96,135,2,0,96,136,4,0,0,0,0,0,0,109,4,0,0,227,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,21,0,0,1,0,0,0,0,0,0,0,0,0,48,63,0,0,142,20,0,0,0,0,0,0,0,0,0,0,66,52,0,0,248,62,0,0,142,5,0,0,248,19,0,0,72,13,0,0,56,10,0,0,96,10,0,0,224,174,145,0,0,6,0,0,128,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,32,15,5,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,80,236,4,0,0,0,0,0,104,199,4,0,0,227,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,21,0,0,1,0,0,0,0,0,0,0,0,0,178,56,0,0,24,7,0,0,0,0,0,0,0,0,0,0,66,52,0,0,248,62,0,0,142,5,0,0,248,19,0,0,72,13,0,0,56,10,0,0,96,10,0,0,224,174,145,0,0,6,0,0,128,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,240,186,2,0,0,0,0,0,0,0,0,0,0,0,0,0,64,171,7,0,64,242,5,0,0,0,0,0,144,84,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,2,0,0,0,0,0,3,11,0,0,8,0,0,0,0,0,0,0,0,0,64,42,0,0,204,17,0,0,0,0,0,0,0,0,0,0,178,2,0,0,196,25,0,0,192,14,0,0,92,8,0,0,82,6,0,0,230,17,0,0,84,29,0,0,128,173,145,0,0,10,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,72,101,1,0,240,186,2,0,0,0,0,0,0,0,0,0,64,171,7,0,32,23,1,0,0,0,0,0,192,154,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,0,0,0,2,0,0,0,0,0,3,11,0,0,8,0,0,0,0,0,0,0,0,0,70,47,0,0,212,41,0,0,0,0,0,0,0,0,0,0,178,2,0,0,196,25,0,0,192,14,0,0,92,8,0,0,82,6,0,0,230,17,0,0,84,29,0,0,128,173,145,0,0,10,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,48,192,2,0,240,186,2,0,0,0,0,0,0,0,0,0,64,171,7,0,88,56,2,0,0,0,0,0,192,154,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,0,0,0,2,0,0,0,0,0,3,11,0,0,8,0,0,0,0,0,0,0,0,0,218,56,0,0,220,36,0,0,0,0,0,0,0,0,0,0,178,2,0,0,196,25,0,0,192,14,0,0,92,8,0,0,82,6,0,0,230,17,0,0,84,29,0,0,128,173,145,0,0,10,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,240,249,2,0,0,0,0,0,0,0,0,0,0,0,0,0,232,167,7,0,144,247,2,0,0,0,0,0,56,72,3,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,8,0,0,2,0,0,0,0,0,0,16,1,0,0,0,0,0,0,0,0,0,0,0,18,34,0,0,244,41,0,0,0,0,0,0,0,0,0,0,160,8,0,0,202,43,0,0,254,0,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,224,205,4,0,0,0,0,0,0,0,0,0,0,0,0,0,64,171,7,0,72,112,4,0,0,0,0,0,40,161,4,0,136,252,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,2,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,154,30,0,0,194,46,0,0,0,0,0,0,0,0,0,0,172,22,0,0,174,3,0,0,124,2,0,0,64,13,0,0,168,2,0,0,0,0,0,0,134,1,0,0,0,0,0,0,0,1,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,216,95,5,0,0,0,0,0,0,0,0,0,0,0,0,0,160,234,7,0,152,109,6,0,0,0,0,0,128,251,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,22,4,0,0,0,0,0,0,0,0,0,0,0,222,23,0,0,40,46,0,0,0,0,0,0,0,0,0,0,36,61,0,0,142,40,0,0,18,7,0,0,94,5,0,0,2,19,0,0,0,0,0,0,38,20,0,0,0,0,0,0,0,1,0,0,240,0,0,0,240,0,0,0,4,0,0,0,3,0,0,0,24,5,2,0,184,58,2,0,0,0,0,0,0,0,0,0,64,164,6,0,216,247,1,0,0,0,0,0,40,161,4,0,192,152,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,9,2,2,0,0,0,0,0,0,0,0,0,0,0,198,45,0,0,52,21,0,0,0,0,0,0,0,0,0,0,94,27,0,0,226,51,0,0,80,19,0,0,42,17,0,0,184,7,0,0,0,0,0,0,216,46,0,0,0,0,0,0,0,6,0,0,224,0,0,0,240,0,0,0,3,0,0,0,4,0,0,0,240,21,2,0,184,58,2,0,0,0,0,0,0,0,0,0,64,164,6,0,16,13,2,0,0,0,0,0,40,161,4,0,192,152,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,9,2,2,0,0,0,0,0,0,0,0,0,0,0,172,23,0,0,56,26,0,0,0,0,0,0,0,0,0,0,94,27,0,0,104,51,0,0,162,6,0,0,42,17,0,0,184,7,0,0,0,0,0,0,216,46,0,0,0,0,0,0,0,6,0,0,224,0,0,0,240,0,0,0,3,0,0,0,4,0,0,0,184,58,2,0,0,0,0,0,0,0,0,0,0,0,0,0,64,164,6,0,24,32,2,0,0,0,0,0,40,161,4,0,192,152,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,9,2,2,0,0,0,0,0,0,0,0,0,0,0,166,17,0,0,208,38,0,0,0,0,0,0,0,0,0,0,94,27,0,0,226,51,0,0,162,6,0,0,42,17,0,0,184,7,0,0,0,0,0,0,216,46,0,0,0,0,0,0,0,6,0,0,224,0,0,0,240,0,0,0,3,0,0,0,4,0,0,0,192,31,1,0,208,56,1,0,0,0,0,0,0,0,0,0,216,194,1,0,32,20,1,0,0,0,0,0,192,154,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,8,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,16,25,0,0,134,17,0,0,0,0,0,0,0,0,0,0,86,51,0,0,246,24,0,0,8,7,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,208,56,1,0,0,0,0,0,0,0,0,0,0,0,0,0,216,194,1,0,216,48,1,0,0,0,0,0,0,40,1,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,8,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,184,53,0,0,4,17,0,0,0,0,0,0,0,0,0,0,86,51,0,0,2,48,0,0,8,7,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,208,189,3,0,240,11,5,0,0,0,0,0,0,0,0,0,184,12,8,0,128,164,3,0,0,0,0,0,112,138,3,0,80,164,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,10,2,0,0,0,0,0,0,0,0,0,0,0,102,49,0,0,78,28,0,0,0,0,0,0,0,0,0,0,244,56,0,0,28,28,0,0,252,13,0,0,88,18,0,0,228,5,0,0,14,15,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,26,4,0,240,11,5,0,0,0,0,0,0,0,0,0,184,12,8,0,128,252,3,0,0,0,0,0,56,219,3,0,80,164,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,0,10,2,0,0,0,0,0,0,0,0,0,0,0,146,13,0,0,132,17,0,0,0,0,0,0,0,0,0,0,244,56,0,0,28,28,0,0,40,13,0,0,88,18,0,0,228,5,0,0,106,18,0,0,0,0,0,0,0,0,0,0,0,3,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,208,114,3,0,240,11,5,0,0,0,0,0,0,0,0,0,184,12,8,0,184,92,3,0,0,0,0,0,192,154,4,0,80,164,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,10,2,0,0,0,0,0,0,0,0,0,0,0,166,2,0,0,50,42,0,0,0,0,0,0,0,0,0,0,244,56,0,0,46,8,0,0,0,5,0,0,88,18,0,0,228,5,0,0,172,18,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,134,4,0,240,11,5,0,0,0,0,0,0,0,0,0,184,12,8,0,176,80,4,0,0,0,0,0,192,54,4,0,80,164,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,0,10,2,0,0,0,0,0,0,0,0,0,0,0,180,6,0,0,64,43,0,0,0,0,0,0,0,0,0,0,244,56,0,0,28,28,0,0,46,16,0,0,88,18,0,0,228,5,0,0,106,18,0,0,0,0,0,0,0,0,0,0,0,3,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,144,112,2,0,168,64,3,0,0,0,0,0,0,0,0,0,192,177,6,0,16,101,2,0,0,0,0,0,216,164,4,0,80,164,3,0,8,86,2,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,0,10,2,0,0,0,0,0,0,0,0,0,0,0,132,3,0,0,50,36,0,0,0,0,0,0,0,0,0,0,244,56,0,0,190,54,0,0,28,1,0,0,88,18,0,0,228,5,0,0,106,18,0,0,0,0,0,0,0,0,0,0,0,3,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,88,150,2,0,168,64,3,0,0,0,0,0,0,0,0,0,192,177,6,0,128,138,2,0,0,0,0,0,216,164,4,0,80,164,3,0,56,127,2,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,0,10,2,0,0,0,0,0,0,0,0,0,0,0,228,3,0,0,150,35,0,0,0,0,0,0,0,0,0,0,244,56,0,0,190,54,0,0,230,12,0,0,88,18,0,0,228,5,0,0,106,18,0,0,0,0,0,0])
.concat([0,0,0,0,0,3,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,32,128,1,0,40,190,1,0,0,0,0,0,0,0,0,0,168,163,7,0,32,114,1,0,0,0,0,0,192,223,4,0,0,151,3,0,224,101,1,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,9,8,0,0,0,0,0,0,0,0,0,0,0,108,62,0,0,166,3,0,0,0,0,0,0,0,0,0,0,38,11,0,0,220,26,0,0,82,2,0,0,228,2,0,0,0,13,0,0,0,0,0,0,166,23,0,0,240,121,145,0,0,0,4,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,190,1,0,0,0,0,0,0,0,0,0,0,0,0,0,168,163,7,0,120,175,1,0,0,0,0,0,192,223,4,0,0,151,3,0,136,168,1,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,9,8,0,0,0,0,0,0,0,0,0,0,0,6,23,0,0,222,45,0,0,0,0,0,0,0,0,0,0,38,11,0,0,220,26,0,0,82,2,0,0,228,2,0,0,0,13,0,0,0,0,0,0,166,23,0,0,240,121,145,0,0,0,4,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,248,5,0,120,128,6,0,0,0,0,0,0,0,0,0,144,47,2,0,24,206,5,0,0,0,0,0,40,161,4,0,144,153,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,2,2,0,0,8,0,0,0,0,0,0,0,0,0,80,14,0,0,246,27,0,0,0,0,0,0,0,0,0,0,252,0,0,0,226,34,0,0,80,13,0,0,66,12,0,0,6,3,0,0,0,0,0,0,214,38,0,0,0,0,0,0,0,96,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,128,6,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,56,37,6,0,0,0,0,0,40,161,4,0,144,153,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,2,2,0,0,8,0,0,0,0,0,0,0,0,0,114,38,0,0,18,40,0,0,0,0,0,0,0,0,0,0,252,0,0,0,226,34,0,0,80,13,0,0,66,12,0,0,6,3,0,0,0,0,0,0,214,38,0,0,0,0,0,0,0,96,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,163,5,0,32,244,5,0,0,0,0,0,0,0,0,0,200,190,7,0,144,129,5,0,0,0,0,0,144,84,8,0,128,194,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,11,0,8,0,0,0,0,0,0,0,0,0,0,134,53,0,0,176,40,0,0,0,0,0,0,0,0,0,0,128,12,0,0,82,9,0,0,14,16,0,0,46,1,0,0,176,0,0,0,0,0,0,0,78,54,0,0,0,0,0,0,0,32,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,101,5,0,32,244,5,0,0,0,0,0,0,0,0,0,104,174,7,0,24,39,5,0,0,0,0,0,144,84,8,0,128,194,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,11,0,8,0,0,0,0,0,0,0,0,0,0,246,29,0,0,184,11,0,0,0,0,0,0,0,0,0,0,128,12,0,0,82,9,0,0,14,16,0,0,46,1,0,0,176,0,0,0,0,0,0,0,78,54,0,0,0,0,0,0,0,32,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,244,5,0,0,0,0,0,0,0,0,0,0,0,0,0,200,190,7,0,0,204,5,0,0,0,0,0,144,84,8,0,128,194,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,3,11,0,8,0,0,0,0,0,0,0,0,0,0,212,25,0,0,60,0,0,0,0,0,0,0,0,0,0,0,128,12,0,0,82,9,0,0,14,16,0,0,46,1,0,0,176,0,0,0,0,0,0,0,78,54,0,0,0,0,0,0,0,32,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,90,3,0,168,161,4,0,0,0,0,0,0,0,0,0,200,190,7,0,248,75,3,0,0,0,0,0,144,84,8,0,128,194,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,11,0,8,0,0,0,0,0,0,0,0,0,0,240,54,0,0,96,36,0,0,0,0,0,0,0,0,0,0,54,14,0,0,196,57,0,0,126,6,0,0,46,1,0,0,176,0,0,0,0,0,0,0,78,54,0,0,0,0,0,0,0,32,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,0,136,3,0,168,161,4,0,0,0,0,0,0,0,0,0,200,190,7,0,16,113,3,0,0,0,0,0,144,84,8,0,128,194,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,11,0,8,0,0,0,0,0,0,0,0,0,0,234,59,0,0,42,28,0,0,0,0,0,0,0,0,0,0,54,14,0,0,196,57,0,0,126,6,0,0,46,1,0,0,176,0,0,0,0,0,0,0,78,54,0,0,0,0,0,0,0,32,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,176,184,7,0,168,88,8,0,0,0,0,0,0,0,0,0,104,174,7,0,88,138,7,0,0,0,0,0,144,84,8,0,168,196,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,5,11,4,0,0,0,0,0,0,0,0,0,0,0,54,17,0,0,102,12,0,0,0,0,0,0,0,0,0,0,184,15,0,0,226,39,0,0,6,10,0,0,178,11,0,0,82,0,0,0,238,10,0,0,188,1,0,0,0,0,0,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,187,3,0,168,161,4,0,0,0,0,0,0,0,0,0,200,190,7,0,136,161,3,0,0,0,0,0,128,161,4,0,128,194,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,11,0,8,0,0,0,0,0,0,0,0,0,0,224,10,0,0,88,22,0,0,0,0,0,0,0,0,0,0,54,14,0,0,196,57,0,0,126,6,0,0,46,1,0,0,176,0,0,0,0,0,0,0,78,54,0,0,0,0,0,0,0,32,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,40,249,3,0,168,161,4,0,0,0,0,0,0,0,0,0,200,190,7,0,40,215,3,0,0,0,0,0,128,161,4,0,128,194,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,11,0,8,0,0,0,0,0,0,0,0,0,0,100,46,0,0,188,4,0,0,0,0,0,0,0,0,0,0,54,14,0,0,196,57,0,0,126,6,0,0,46,1,0,0,176,0,0,0,0,0,0,0,78,54,0,0,0,0,0,0,0,32,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,248,50,4,0,168,161,4,0,0,0,0,0,0,0,0,0,200,190,7,0,144,23,4,0,0,0,0,0,128,161,4,0,128,194,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,11,0,8,0,0,0,0,0,0,0,0,0,0,56,20,0,0,228,11,0,0,0,0,0,0,0,0,0,0,54,14,0,0,196,57,0,0,126,6,0,0,46,1,0,0,176,0,0,0,0,0,0,0,78,54,0,0,0,0,0,0,0,32,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,144,104,4,0,168,161,4,0,0,0,0,0,0,0,0,0,200,190,7,0,152,77,4,0,0,0,0,0,168,183,7,0,128,194,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,11,0,8,0,0,0,0,0,0,0,0,0,0,154,40,0,0,150,6,0,0,0,0,0,0,0,0,0,0,54,14,0,0,182,58,0,0,126,6,0,0,46,1,0,0,176,0,0,0,0,0,0,0,78,54,0,0,0,0,0,0,0,32,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,168,161,4,0,0,0,0,0,0,0,0,0,0,0,0,0,200,190,7,0,248,130,4,0,0,0,0,0,168,183,7,0,128,194,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,3,11,0,8,0,0,0,0,0,0,0,0,0,0,122,24,0,0,234,43,0,0,0,0,0,0,0,0,0,0,54,14,0,0,182,58,0,0,126,6,0,0,46,1,0,0,176,0,0,0,0,0,0,0,78,54,0,0,0,0,0,0,0,32,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,152,219,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,72,210,7,0,216,165,4,0,64,198,7,0,80,164,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,0,10,2,0,0,0,0,0,0,0,0,0,0,0,252,50,0,0,34,13,0,0,0,0,0,0,0,0,0,0,116,9,0,0,36,50,0,0,212,15,0,0,56,12,0,0,212,3,0,0,96,11,0,0,0,0,0,0,0,0,0,0,0,4,0,0,224,0,0,0,128,1,0,0,3,0,0,0,4,0,0,0,0,126,6,0,112,253,6,0,0,0,0,0,0,0,0,0,184,168,7,0,136,76,6,0,0,0,0,0,248,166,6,0,168,196,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,5,11,0,0,1,0,0,0,0,0,0,0,0,0,104,43,0,0,212,32,0,0,0,0,0,0,0,0,0,0,8,48,0,0,228,6,0,0,178,6,0,0,178,11,0,0,82,0,0,0,238,10,0,0,188,1,0,0,0,0,0,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,34,6,0,112,253,6,0,0,0,0,0,0,0,0,0,184,168,7,0,176,243,5,0,0,0,0,0,248,166,6,0,168,196,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,5,11,0,0,8,0,0,0,0,0,0,0,0,0,174,4,0,0,190,18,0,0,0,0,0,0,0,0,0,0,184,15,0,0,58,44,0,0,158,12,0,0,178,11,0,0,82,0,0,0,238,10,0,0,188,1,0,0,0,0,0,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,253,6,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,232,213,6,0,0,0,0,0,248,166,6,0,168,196,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,5,11,0,0,1,0,0,0,0,0,0,0,0,0,166,55,0,0,174,20,0,0,0,0,0,0,0,0,0,0,8,48,0,0,228,6,0,0,178,6,0,0,178,11,0,0,82,0,0,0,238,10,0,0,188,1,0,0,0,0,0,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,237,8,0,240,168,5,0,0,0,0,0,240,168,5,0,96,159,4,0,248,172,8,0,0,0,0,0,192,154,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,120,57,0,0,200,9,0,0,14,23,0,0,154,31,0,0,8,31,0,0,100,35,0,0,156,17,0,0,102,13,0,0,184,3,0,0,0,0,0,0,220,41,0,0,0,0,0,0,4,1,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,235,1,0,240,168,5,0,0,0,0,0,240,168,5,0,96,159,4,0,104,138,1,0,0,0,0,0,64,49,1,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,154,61,0,0,246,8,0,0,14,23,0,0,154,31,0,0,8,31,0,0,100,35,0,0,202,18,0,0,102,13,0,0,184,3,0,0,0,0,0,0,220,41,0,0,0,0,0,0,4,1,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,252,2,0,240,168,5,0,0,0,0,0,240,168,5,0,96,159,4,0,56,97,2,0,0,0,0,0,248,39,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,232,32,0,0,102,22,0,0,14,23,0,0,154,31,0,0,8,31,0,0,100,35,0,0,156,17,0,0,102,13,0,0,184,3,0,0,0,0,0,0,220,41,0,0,0,0,0,0,4,1,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,168,5,0,0,0,0,0,0,0,0,0,240,168,5,0,96,159,4,0,224,116,6,0,0,0,0,0,248,39,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,120,1,0,0,104,31,0,0,14,23,0,0,154,31,0,0,8,31,0,0,100,35,0,0,202,18,0,0,102,13,0,0,184,3,0,0,0,0,0,0,220,41,0,0,0,0,0,0,4,1,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,153,2,0,0,0,0,0,0,0,0,0,0,0,0,0,104,174,7,0,104,233,5,0,0,0,0,0,88,153,4,0,224,127,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,1,4,2,0,0,0,0,0,0,0,0,0,0,0,198,61,0,0,38,40,0,0,0,0,0,0,0,0,0,0,42,57,0,0,104,11,0,0,90,4,0,0,30,7,0,0,196,18,0,0,178,8,0,0,60,58,0,0,32,146,215,0,0,8,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,32,208,5,0,56,131,6,0,0,0,0,0,0,0,0,0,144,47,2,0,0,169,5,0,0,0,0,0,32,0,1,0,240,185,2,0,0,133,5,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,10,1,0,0,0,0,0,0,0,0,0,0,0,74,14,0,0,118,42,0,0,0,0,0,0,0,0,0,0,114,33,0,0,194,17,0,0,118,11,0,0,14,3,0,0,164,11,0,0,42,4,0,0,242,13,0,0,104,174,145,0,0,16,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,48,7,0,72,167,3,0,0,0,0,0,0,0,0,0,104,221,5,0,80,3,7,0,0,0,0,0,136,95,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,149,0,0,0,2,0,0,0,0,0,0,10,2,0,0,0,0,0,0,0,0,0,0,0,164,11,0,0,194,10,0,0,0,0,0,0,0,0,0,0,160,9,0,0,248,0,0,0,206,6,0,0,158,15,0,0,36,16,0,0,0,0,0,0,136,28,0,0,232,210,148,0,0,16,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,192,223,8,0,72,167,3,0,0,0,0,0,0,0,0,0,104,221,5,0,56,157,8,0,0,0,0,0,136,95,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,149,0,0,0,2,0,0,0,0,0,0,10,2,0,0,0,0,0,0,0,0,0,0,0,230,37,0,0,4,33,0,0,0,0,0,0,0,0,0,0,160,9,0,0,248,0,0,0,206,6,0,0,158,15,0,0,36,16,0,0,0,0,0,0,136,28,0,0,232,210,148,0,0,16,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,160,212,1,0,72,167,3,0,0,0,0,0,0,0,0,0,104,221,5,0,240,114,1,0,0,0,0,0,40,34,1,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,149,0,0,0,2,0,0,0,0,0,0,10,2,0,0,0,0,0,0,0,0,0,0,0,222,13,0,0,178,39,0,0,0,0,0,0,0,0,0,0,160,9,0,0,248,0,0,0,206,6,0,0,158,15,0,0,36,16,0,0,0,0,0,0,136,28,0,0,232,210,148,0,0,16,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,240,39,8,0,72,167,3,0,0,0,0,0,0,0,0,0,104,221,5,0,184,242,7,0,0,0,0,0,216,191,7,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,149,0,0,0,2,0,0,0,0,0,0,10,2,0,0,0,0,0,0,0,0,0,0,0,224,11,0,0,162,1,0,0,0,0,0,0,0,0,0,0,160,9,0,0,248,0,0,0,206,6,0,0,158,15,0,0,36,16,0,0,0,0,0,0,136,28,0,0,232,210,148,0,0,16,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,176,143,7,0,72,167,3,0,0,0,0,0,0,0,0,0,104,221,5,0,208,96,7,0,0,0,0,0,80,197,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,149,0,0,0,2,0,0,0,0,0,0,10,2,0,0,0,0,0,0,0,0,0,0,0,72,9,0,0,38,39,0,0,0,0,0,0,0,0,0,0,160,9,0,0,248,0,0,0,206,6,0,0,158,15,0,0,232,9,0,0,0,0,0,0,136,28,0,0,232,210,148,0,0,16,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,176,213,2,0,72,167,3,0,0,0,0,0,0,0,0,0,104,221,5,0,56,72,2,0,0,0,0,0,80,197,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,149,0,0,0,2,0,0,0,0,0,0,10,2,0,0,0,0,0,0,0,0,0,0,0,92,50,0,0,158,25,0,0,0,0,0,0,0,0,0,0,160,9,0,0,248,0,0,0,206,6,0,0,158,15,0,0,36,16,0,0,0,0,0,0,136,28,0,0,232,210,148,0,0,16,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,72,167,3,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,0,40,6,0,0,0,0,0,80,197,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,133,0,0,0,2,0,0,0,0,0,0,10,2,0,0,0,0,0,0,0,0,0,0,0,172,17,0,0,68,39,0,0,0,0,0,0,0,0,0,0,160,9,0,0,248,0,0,0,206,6,0,0,158,15,0,0,36,16,0,0,0,0,0,0,136,28,0,0,232,210,148,0,0,16,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,160,17,1,0,24,108,2,0,0,0,0,0,0,0,0,0,96,135,2,0,0,210,8,0,0,0,0,0,176,237,2,0,168,84,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,19,1,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,222,13,0,0,0,0,0,0,0,0,0,0,42,18,0,0,22,23,0,0,116,7,0,0,228,7,0,0,132,16,0,0,136,8,0,0,200,59,0,0,96,173,145,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,24,193,1,0,24,108,2,0,0,0,0,0,0,0,0,0,96,135,2,0,72,95,1,0,0,0,0,0,176,237,2,0,168,84,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,19,1,0,0,0,0,0,0,0,0,0,0,0,24,11,0,0,72,47,0,0,0,0,0,0,0,0,0,0,42,18,0,0,22,23,0,0,116,7,0,0,228,7,0,0,132,16,0,0,136,8,0,0,200,59,0,0,96,173,145,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,120,85,2,0,0,0,0,0,0,0,0,0,0,0,0,0,160,234,7,0,136,71,2,0,0,0,0,0,16,182,4,0,192,152,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,9,2,2,0,0,0,0,0,0,0,0,0,0,0,180,18,0,0,216,41,0,0,0,0,0,0,0,0,0,0,94,27,0,0,240,36,0,0,28,14,0,0,42,17,0,0,184,7,0,0,0,0,0,0,216,46,0,0,0,0,0,0,0,6,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,232,242,2,0,208,1,5,0,0,0,0,0,0,0,0,0,96,159,4,0,64,90,2,0,120,155,4,0,24,177,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,112,25,0,0,100,23,0,0,0,0,0,0,0,0,0,0,184,44,0,0,220,19,0,0,84,7,0,0,198,18,0,0,98,13,0,0,246,5,0,0,0,0,0,0,136,175,145,0,0,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,208,1,5,0,0,0,0,0,0,0,0,0,0,0,0,0,96,159,4,0,224,94,6,0,0,0,0,0,24,177,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,2,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,122,58,0,0,90,38,0,0,0,0,0,0,0,0,0,0,184,44,0,0,220,19,0,0,60,13,0,0,198,18,0,0,98,13,0,0,246,5,0,0,0,0,0,0,136,175,145,0,0,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,128,175,2,0,0,0,0,0,0,0,0,0,0,0,0,0,160,234,7,0,216,173,2,0,0,0,0,0,16,173,2,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,8,0,0,2,0,0,0,0,0,0,16,0,64,0,0,0,0,0,0,0,0,0,0,130,57,0,0,166,34,0,0,0,0,0,0,0,0,0,0,100,43,0,0,130,1,0,0,156,18,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,193,2,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,112,176,2,0,0,0,0,0,168,183,7,0,216,142,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,11,0,0,4,0,0,0,0,0,0,0,0,0,122,1,0,0,188,35,0,0,0,0,0,0,0,0,0,0,72,22,0,0,114,7,0,0,154,19,0,0,24,8,0,0,14,5,0,0,0,0,0,0,60,41,0,0,0,0,0,0,0,16,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,128,131,5,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,200,103,5,0,0,0,0,0,40,161,4,0,240,153,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,192,0,1,2,0,0,4,0,0,0,0,0,0,0,0,0,94,37,0,0,34,15,0,0,0,0,0,0,0,0,0,0,16,28,0,0,202,18,0,0,244,17,0,0,114,5,0,0,164,8,0,0,0,0,0,0,6,14,0,0,0,0,0,0,0,96,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,177,5,0,0,0,0,0,0,0,0,0,0,0,0,0,200,190,7,0,48,117,6,0,0,0,0,0,176,100,7,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,144,20,0,0,30,23,0,0,0,0,0,0,0,0,0,0,120,43,0,0,196,45,0,0,202,4,0,0,0,7,0,0,156,5,0,0,104,4,0,0,254,2,0,0,40,176,145,0,0,4,0,0,32,1,0,0,216,0,0,0,4,0,0,0,3,0,0,0,176,246,1,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,0,237,1,0,0,0,0,0,144,84,8,0,168,196,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,5,11,0,32,0,0,0,0,0,0,0,0,0,0,130,26,0,0,166,7,0,0,0,0,0,0,0,0,0,0,140,10,0,0,246,20,0,0,38,3,0,0,178,11,0,0,82,0,0,0,238,10,0,0,188,1,0,0,0,0,0,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,138,8,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,56,133,8,0,0,0,0,0,144,84,8,0,208,135,3,0,192,126,8,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,2,11,0,32,0,0,0,0,0,0,0,0,0,0,86,19,0,0,176,11,0,0,0,0,0,0,0,0,0,0,22,51,0,0,130,47,0,0,40,0,0,0,46,7,0,0,246,17,0,0,0,0,0,0,176,18,0,0,0,0,0,0,0,32,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,101,7,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,216,6,7,0,0,0,0,0,32,0,1,0,0,227,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,21,0,0,1,0,0,0,0,0,0,0,0,0,58,30,0,0,148,41,0,0,0,0,0,0,0,0,0,0,52,40,0,0,94,44,0,0,222,0,0,0,248,19,0,0,72,13,0,0,230,0,0,0,96,10,0,0,224,174,145,0,0,2,0,0,128,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,176,255,5,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,184,210,5,0,0,0,0,0,32,0,1,0,0,227,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,21,0,0,1,0,0,0,0,0,0,0,0,0,130,60,0,0,100,38,0,0,0,0,0,0,0,0,0,0,244,25,0,0,154,57,0,0,62,5,0,0,248,19,0,0,72,13,0,0,230,0,0,0,96,10,0,0,224,174,145,0,0,2,0,0,128,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,88,156,8,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,184,149,8,0,0,0,0,0,144,84,8,0,208,135,3,0,88,143,8,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,2,11,0,32,0,0,0,0,0,0,0,0,0,0,144,0,0,0,172,5,0,0,0,0,0,0,0,0,0,0,62,53,0,0,244,33,0,0,64,0,0,0,46,7,0,0,246,17,0,0,0,0,0,0,176,18,0,0,0,0,0,0,0,32,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,21,5,0,0,0,0,0,0,0,0,0,0,0,0,0,64,171,7,0,80,97,6,0,0,0,0,0,104,242,4,0,240,185,2,0,88,244,2,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,244,30,0,0,34,42,0,0,0,0,0,0,0,0,0,0,154,15,0,0,68,56,0,0,120,9,0,0,238,9,0,0,116,12,0,0,0,0,0,0,76,30,0,0,0,0,0,0,16,0,0,0,64,1,0,0,200,0,0,0,4,0,0,0,3,0,0,0,160,174,8,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,64,165,8,0,0,0,0,0,144,84,8,0,208,135,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,2,11,0,32,0,0,0,0,0,0,0,0,0,0,150,60,0,0,30,15,0,0,0,0,0,0,0,0,0,0,224,7,0,0,52,4,0,0,98,11,0,0,46,7,0,0,246,17,0,0,0,0,0,0,176,18,0,0,0,0,0,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,192,6,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,168,145,6,0,0,0,0,0,152,54,6,0,152,8,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,4,17,0,0,1,0,0,0,0,0,0,0,0,0,180,54,0,0,120,42,0,0,0,0,0,0,0,0,0,0,236,12,0,0,124,1,0,0,132,12,0,0,80,0,0,0,228,1,0,0,44,8,0,0,0,0,0,0,32,177,145,0,0,2,0,0,128,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,8,16,2,0,208,46,2,0,72,172,6,0,0,0,0,0,144,47,2,0,48,7,2,0,0,0,0,0,128,145,4,0,208,9,3,0,248,253,1,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,133,0,32,0,0,0,0,0,0,0,0,0,0,88,50,0,0,224,11,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,46,2,0,0,0,0,0,72,172,6,0,0,0,0,0,144,47,2,0,184,35,2,0,0,0,0,0,128,145,4,0,208,9,3,0,184,24,2,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,0,32,0,0,0,0,0,0,0,0,0,0,60,2,0,0,228,46,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,205,8,0,0,0,0,0,72,172,6,0,0,0,0,0,96,135,2,0,96,200,8,0,0,0,0,0,128,145,4,0,208,9,3,0,40,195,8,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,0,32,0,0,0,0,0,0,0,0,0,0,118,20,0,0,130,8,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,217,1,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,176,37,1,0,0,0,0,0,72,227,8,0,240,185,2,0,48,159,8,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,32,0,0,0,0,0,0,0,0,0,0,134,37,0,0,250,30,0,0,0,0,0,0,0,0,0,0,0,52,0,0,84,3,0,0,176,18,0,0,122,6,0,0,220,12,0,0,80,15,0,0,102,43,0,0,160,174,145,0,0,8,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,31,3,0,128,61,8,0,0,0,0,0,0,0,0,0,184,168,7,0,192,114,2,0,0,0,0,0,168,95,8,0,136,2,4,0,152,251,1,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,3,0,16,0,0,0,0,0,0,0,0,0,0,86,52,0,0,240,37,0,0,0,0,0,0,0,0,0,0,246,8,0,0,110,54,0,0,46,9,0,0,72,3,0,0,210,12,0,0,78,0,0,0,184,1,0,0,224,176,145,0,0,4,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,25,4,0,160,79,4,0,0,0,0,0,0,0,0,0,160,234,7,0,48,251,3,0,0,0,0,0,40,161,4,0,248,206,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,3,2,0,8,0,0,0,0,0,0,0,0,0,0,128,34,0,0,142,11,0,0,0,0,0,0,0,0,0,0,236,39,0,0,178,57,0,0,62,12,0,0,114,17,0,0,144,2,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,163,3,0,160,79,4,0,0,0,0,0,0,0,0,0,160,234,7,0,224,137,3,0,0,0,0,0,40,161,4,0,248,206,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,2,0,8,0,0,0,0,0,0,0,0,0,0,212,59,0,0,70,30,0,0,0,0,0,0,0,0,0,0,50,61,0,0,138,22,0,0,218,12,0,0,114,17,0,0,144,2,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,218,3,0,160,79,4,0,0,0,0,0,0,0,0,0,160,234,7,0,248,188,3,0,0,0,0,0,40,161,4,0,248,206,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,2,0,8,0,0,0,0,0,0,0,0,0,0,88,57,0,0,210,16,0,0,0,0,0,0,0,0,0,0,50,61,0,0,138,22,0,0,62,12,0,0,114,17,0,0,144,2,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,79,4,0,0,0,0,0,0,0,0,0,0,0,0,0,160,234,7,0,192,53,4,0,0,0,0,0,40,161,4,0,248,206,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,4,0,0,0,0,0,3,2,0,8,0,0,0,0,0,0,0,0,0,0,208,32,0,0,60,43,0,0,0,0,0,0,0,0,0,0,236,39,0,0,178,57,0,0,62,12,0,0,114,17,0,0,144,2,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,193,8,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,80,188,8,0,0,0,0,0,144,84,8,0,208,135,3,0,120,181,8,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,2,11,0,32,0,0,0,0,0,0,0,0,0,0,54,32,0,0,162,16,0,0,0,0,0,0,0,0,0,0,18,25,0,0,114,12,0,0,98,9,0,0,46,7,0,0,246,17,0,0,0,0,0,0,176,18,0,0,0,0,0,0,0,8,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,217,2,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,128,180,2,0,0,0,0,0,192,223,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,32,0,0,0,0,0,0,0,0,0,0,96,20,0,0,250,12,0,0,0,0,0,0,0,0,0,0,160,16,0,0,0,0,0,0,136,13,0,0,22,7,0,0,230,18,0,0,0,0,0,0,110,45,0,0,0,0,0,0,0,8,0,0,128,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,200,165,2,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,104,151,2,0,0,0,0,0,192,223,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,32,0,0,0,0,0,0,0,0,0,0,182,45,0,0,92,44,0,0,0,0,0,0,0,0,0,0,160,16,0,0,0,0,0,0,102,7,0,0,22,7,0,0,230,18,0,0,0,0,0,0,110,45,0,0,0,0,0,0,0,8,0,0,128,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,80,207,8,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,16,203,8,0,0,0,0,0,144,84,8,0,208,135,3,0,8,198,8,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,2,11,0,32,0,0,0,0,0,0,0,0,0,0,34,9,0,0,114,25,0,0,0,0,0,0,0,0,0,0,34,61,0,0,158,61,0,0,30,0,0,0,46,7,0,0,246,17,0,0,0,0,0,0,176,18,0,0,0,0,0,0,0,32,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,63,1,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,128,46,1,0,0,0,0,0,168,95,8,0,16,39,1,0,96,29,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,3,0,32,0,0,0,0,0,0,0,0,0,0,22,5,0,0,64,38,0,0,0,0,0,0,0,0,0,0,146,57,0,0,0,0,0,0,38,18,0,0,130,1,0,0,206,2,0,0,0,0,0,0,180,8,0,0,0,0,0,0,0,8,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,231,8,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,176,222,8,0,0,0,0,0,144,84,8,0,208,135,3,0,120,214,8,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,2,11,0,32,0,0,0,0,0,0,0,0,0,0,150,3,0,0,100,47,0,0,0,0,0,0,0,0,0,0,146,23,0,0,220,4,0,0,238,6,0,0,46,7,0,0,246,17,0,0,0,0,0,0,176,18,0,0,0,0,0,0,0,32,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,88,245,8,0,0,0,0,0,144,84,8,0,208,135,3,0,144,238,8,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,2,11,0,32,0,0,0,0,0,0,0,0,0,0,200,11,0,0,212,42,0,0,0,0,0,0,0,0,0,0,122,7,0,0,138,24,0,0,76,16,0,0,46,7,0,0,246,17,0,0,0,0,0,0,176,18,0,0,0,0,0,0,0,32,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,211,5,0,0,0,0,0,0,0,0,0,0,0,0,0,184,12,8,0,112,171,5,0,0,0,0,0,224,218,4,0,48,178,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,1,0,0,0,0,0,0,0,0,0,0,160,37,0,0,122,30,0,0,0,0,0,0,0,0,0,0,116,30,0,0,216,16,0,0,94,17,0,0,222,19,0,0,228,17,0,0,0,0,0,0,36,38,0,0,0,0,0,0,0,2,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,48,7,0,0,0,0,0,0,0,0,0,0,0,0,0,144,139,6,0,0,218,6,0,0,0,0,0,80,173,6,0,208,165,3,0,112,130,6,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,21,0,16,0,0,0,0,0,0,0,0,0,0,104,20,0,0,18,19,0,0,0,0,0,0,0,0,0,0,236,33,0,0,124,60,0,0,6,14,0,0,198,1,0,0,134,15,0,0,0,0,0,0,236,14,0,0,240,210,148,0,0,128,0,0,128,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,128,69,2,0,112,131,3,0,0,0,0,0,0,0,0,0,0,38,7,0,240,209,1,0,0,0,0,0,64,32,1,0,136,153,3,0,72,112,1,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,1,0,0,6,8,0,0,0,0,1,0,0,0,0,0,0,234,45,0,0,106,34,0,0,0,0,0,0,0,0,0,0,168,14,0,0,0,0,0,0,250,1,0,0,78,7,0,0,46,2,0,0,254,7,0,0,174,33,0,0,96,49,216,0,0,128,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,112,131,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,32,33,6,0,208,191,4,0,64,32,1,0,136,153,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,1,0,0,6,8,0,0,0,0,1,0,0,0,0,0,0,192,50,0,0,242,17,0,0,0,0,0,0,0,0,0,0,168,14,0,0,0,0,0,0,250,1,0,0,78,7,0,0,46,2,0,0,254,7,0,0,174,33,0,0,96,49,216,0,0,128,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,128,248,3,0,144,130,4,0,0,0,0,0,0,0,0,0,144,47,2,0,144,214,3,0,0,0,0,0,144,84,8,0,216,142,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,11,0,0,4,0,0,0,0,0,0,0,0,0,20,4,0,0,94,5,0,0,0,0,0,0,0,0,0,0,26,19,0,0,160,0,0,0,6,7,0,0,24,8,0,0,14,5,0,0,0,0,0,0,60,41,0,0,0,0,0,0,0,16,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,0,241,8,0,0,227,6,0,200,240,5,0,0,0,0,0,104,129,6,0,48,226,8,0,96,6,1,0,72,174,3,0,88,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,0,8,0,16,0,0,0,0,0,0,0,0,0,0,2,51,0,0,26,1,0,0,0,0,0,0,0,0,0,0,104,35,0,0,36,46,0,0,204,5,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,192,1,0,0,224,0,0,0])
.concat([4,0,0,0,3,0,0,0,0,227,6,0,0,0,0,0,200,240,5,0,0,0,0,0,144,139,6,0,176,248,8,0,96,6,1,0,72,174,3,0,88,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,4,0,0,0,0,0,0,8,0,16,0,0,0,0,0,0,0,0,0,0,178,42,0,0,124,8,0,0,0,0,0,0,0,0,0,0,104,35,0,0,36,46,0,0,204,5,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,192,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,16,1,0,0,0,0,0,200,240,5,0,0,0,0,0,144,139,6,0,112,12,1,0,96,6,1,0,72,174,3,0,88,0,3,0,80,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,4,0,0,0,0,0,0,8,0,16,0,0,0,0,0,0,0,0,0,0,252,30,0,0,38,5,0,0,0,0,0,0,0,0,0,0,104,35,0,0,82,38,0,0,62,0,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,192,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,216,1,0,8,221,3,0,0,0,0,0,0,0,0,0,104,221,5,0,200,117,1,0,0,0,0,0,16,37,1,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,10,0,16,0,0,0,0,0,0,0,0,0,0,252,40,0,0,168,45,0,0,0,0,0,0,0,0,0,0,68,55,0,0,30,54,0,0,152,10,0,0,240,16,0,0,114,13,0,0,136,10,0,0,148,61,0,0,120,174,145,0,64,2,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,220,2,0,8,221,3,0,0,0,0,0,0,0,0,0,104,221,5,0,56,75,2,0,0,0,0,0,184,191,7,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,10,0,16,0,0,0,0,0,0,0,0,0,0,170,31,0,0,252,28,0,0,0,0,0,0,0,0,0,0,68,55,0,0,30,54,0,0,152,10,0,0,240,16,0,0,114,13,0,0,136,10,0,0,148,61,0,0,120,174,145,0,64,2,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,221,3,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,160,49,6,0,0,0,0,0,184,191,7,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,16,0,0,0,0,0,0,0,0,0,0,70,50,0,0,234,2,0,0,0,0,0,0,0,0,0,0,68,55,0,0,30,54,0,0,152,10,0,0,240,16,0,0,114,13,0,0,136,10,0,0,148,61,0,0,120,174,145,0,64,2,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,250,8,0,120,18,1,0,0,0,0,0,0,0,0,0,104,221,5,0,64,242,8,0,0,0,0,0,168,95,8,0,64,8,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,3,0,64,0,0,0,0,0,0,0,0,0,0,162,24,0,0,102,4,0,0,0,0,0,0,0,0,0,0,254,48,0,0,126,14,0,0,172,16,0,0,106,7,0,0,234,8,0,0,0,0,0,0,42,8,0,0,0,0,0,0,0,8,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,2,1,0,120,18,1,0,0,0,0,0,0,0,0,0,104,221,5,0,56,255,8,0,0,0,0,0,168,95,8,0,64,8,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,3,0,64,0,0,0,0,0,0,0,0,0,0,64,11,0,0,176,3,0,0,0,0,0,0,0,0,0,0,254,48,0,0,84,38,0,0,172,16,0,0,106,7,0,0,234,8,0,0,0,0,0,0,42,8,0,0,0,0,0,0,0,8,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,18,1,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,24,13,1,0,0,0,0,0,168,95,8,0,64,8,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,4,0,0,0,0,0,1,3,0,64,0,0,0,0,0,0,0,0,0,0,134,57,0,0,108,27,0,0,0,0,0,0,0,0,0,0,88,29,0,0,162,1,0,0,172,16,0,0,106,7,0,0,234,8,0,0,0,0,0,0,42,8,0,0,0,0,0,0,0,8,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,9,1,0,8,33,1,0,0,0,0,0,0,0,0,0,144,47,2,0,248,3,1,0,240,14,1,0,144,84,8,0,208,135,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,2,11,4,0,0,0,0,0,0,0,0,0,0,0,160,62,0,0,168,8,0,0,0,0,0,0,0,0,0,0,200,1,0,0,42,32,0,0,40,1,0,0,46,7,0,0,246,17,0,0,0,0,0,0,176,18,0,0,0,0,0,0,0,32,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,33,1,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,88,23,1,0,240,14,1,0,168,183,7,0,208,135,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,2,11,4,0,0,0,0,0,0,0,0,0,0,0,238,21,0,0,104,46,0,0,0,0,0,0,0,0,0,0,200,1,0,0,4,7,0,0,40,1,0,0,46,7,0,0,246,17,0,0,0,0,0,0,176,18,0,0,0,0,0,0,0,32,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,205,1,0,200,232,1,0,0,0,0,0,0,0,0,0,240,3,2,0,208,193,1,0,240,56,5,0,152,54,6,0,168,38,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,5,17,8,0,0,0,0,0,0,0,0,0,0,0,162,45,0,0,182,6,0,0,0,0,0,0,0,0,0,0,82,26,0,0,98,24,0,0,146,11,0,0,218,2,0,0,114,1,0,0,166,3,0,0,116,50,0,0,8,211,148,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,192,78,7,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,176,32,7,0,0,0,0,0,32,46,8,0,240,85,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,2,0,0,0,0,0,0,19,0,0,1,0,0,0,0,0,0,0,0,0,170,44,0,0,154,5,0,0,0,0,0,0,0,0,0,0,108,48,0,0,228,33,0,0,36,8,0,0,32,4,0,0,120,0,0,0,54,14,0,0,62,2,0,0,8,173,145,0,0,4,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,192,236,2,0,72,176,4,0,0,0,0,0,0,0,0,0,184,168,7,0,240,83,2,0,0,0,0,0,88,226,1,0,0,188,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,188,58,0,0,180,37,0,0,0,0,0,0,0,0,0,0,36,25,0,0,166,53,0,0,48,13,0,0,54,11,0,0,174,9,0,0,0,0,0,0,72,51,0,0,0,0,0,0,0,8,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,128,1,0,72,176,4,0,0,0,0,0,0,0,0,0,184,168,7,0,160,42,1,0,0,0,0,0,168,231,8,0,0,188,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,64,16,0,0,246,40,0,0,0,0,0,0,0,0,0,0,36,25,0,0,166,53,0,0,48,13,0,0,54,11,0,0,174,9,0,0,0,0,0,0,72,51,0,0,0,0,0,0,0,8,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,176,4,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,200,77,6,0,0,0,0,0,128,145,4,0,0,188,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,170,13,0,0,100,45,0,0,0,0,0,0,0,0,0,0,36,25,0,0,166,53,0,0,48,13,0,0,54,11,0,0,174,9,0,0,0,0,0,0,72,51,0,0,0,0,0,0,0,8,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,220,2,0,128,225,3,0,0,0,0,0,0,0,0,0,184,12,8,0,104,75,2,0,0,0,0,0,208,207,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,3,0,0,0,0,0,0,10,0,2,0,0,0,0,0,0,0,0,0,0,38,56,0,0,8,20,0,0,0,0,0,0,0,0,0,0,110,38,0,0,186,15,0,0,238,7,0,0,18,1,0,0,42,9,0,0,118,15,0,0,88,11,0,0,128,174,145,0,0,3,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,24,187,8,0,232,228,8,0,0,0,0,0,0,0,0,0,96,135,2,0,32,122,8,0,120,161,2,0,192,154,4,0,168,38,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,5,17,4,0,0,0,0,0,0,0,0,0,0,0,22,50,0,0,174,39,0,0,0,0,0,0,0,0,0,0,50,9,0,0,222,3,0,0,68,1,0,0,218,2,0,0,122,14,0,0,166,3,0,0,116,50,0,0,8,211,148,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,224,3,4,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,128,54,6,0,0,0,0,0,64,32,1,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,8,0,0,0,0,1,0,0,0,0,0,0,126,45,0,0,194,39,0,0,0,0,0,0,0,0,0,0,230,51,0,0,14,46,0,0,96,12,0,0,50,0,0,0,186,8,0,0,0,0,0,0,54,31,0,0,0,211,148,0,0,8,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,223,2,0,224,3,4,0,0,0,0,0,0,0,0,0,240,3,2,0,184,76,2,0,0,0,0,0,64,32,1,0,240,185,2,0,88,218,1,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,10,8,0,0,0,0,1,0,0,0,0,0,0,20,41,0,0,186,15,0,0,0,0,0,0,0,0,0,0,230,51,0,0,226,49,0,0,96,12,0,0,50,0,0,0,186,8,0,0,0,0,0,0,54,31,0,0,0,211,148,0,0,8,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,228,8,0,224,3,4,0,0,0,0,0,0,0,0,0,240,3,2,0,168,161,8,0,0,0,0,0,64,32,1,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,0,10,8,0,0,0,0,1,0,0,0,0,0,0,40,41,0,0,110,2,0,0,0,0,0,0,0,0,0,0,230,51,0,0,14,46,0,0,96,12,0,0,50,0,0,0,186,8,0,0,0,0,0,0,54,31,0,0,0,211,148,0,0,8,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,120,1,0,224,3,4,0,0,0,0,0,0,0,0,0,240,3,2,0,184,38,1,0,0,0,0,0,64,32,1,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,0,10,8,0,0,0,0,1,0,0,0,0,0,0,230,16,0,0,88,46,0,0,0,0,0,0,0,0,0,0,230,51,0,0,14,46,0,0,96,12,0,0,50,0,0,0,186,8,0,0,0,0,0,0,54,31,0,0,0,211,148,0,0,8,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,119,5,0,192,211,8,0,0,0,0,0,0,0,0,0,40,41,5,0,248,113,5,0,0,0,0,0,232,111,5,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,8,0,0,2,0,0,0,0,0,0,16,0,8,0,0,0,0,0,0,0,0,0,0,12,49,0,0,226,23,0,0,0,0,0,0,0,0,0,0,228,44,0,0,120,29,0,0,192,1,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,160,230,8,0,0,0,0,0,0,0,0,0,0,0,0,0,64,171,7,0,120,164,8,0,0,0,0,0,168,224,4,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,2,0,0,0,0,0,0,15,0,0,1,0,0,0,0,0,0,0,0,0,230,11,0,0,80,11,0,0,0,0,0,0,0,0,0,0,248,40,0,0,22,22,0,0,224,18,0,0,56,4,0,0,44,2,0,0,96,15,0,0,104,26,0,0,24,175,145,0,128,0,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,8,72,2,0,0,0,0,0,0,0,0,0,0,0,0,0,144,139,6,0,24,44,2,0,0,0,0,0,216,164,4,0,80,164,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,16,0,0,0,0,0,0,0,0,0,0,54,60,0,0,216,19,0,0,0,0,0,0,0,0,0,0,244,56,0,0,224,34,0,0,186,4,0,0,88,18,0,0,228,5,0,0,4,6,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,34,3,0,48,124,8,0,0,0,0,0,0,0,0,0,232,167,7,0,168,117,2,0,0,0,0,0,128,255,1,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,3,0,0,1,0,0,0,0,0,0,0,0,0,122,13,0,0,150,39,0,0,0,0,0,0,0,0,0,0,148,8,0,0,172,51,0,0,110,7,0,0,28,19,0,0,8,14,0,0,34,6,0,0,130,15,0,0,168,134,148,0,0,2,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,48,124,8,0,0,0,0,0,0,0,0,0,0,0,0,0,232,167,7,0,176,187,6,0,0,0,0,0,168,95,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,2,0,0,0,0,0,0,3,0,0,1,0,0,0,0,0,0,0,0,0,6,56,0,0,100,12,0,0,0,0,0,0,0,0,0,0,148,8,0,0,172,51,0,0,110,7,0,0,28,19,0,0,8,14,0,0,34,6,0,0,130,15,0,0,168,134,148,0,0,2,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,152,156,1,0,48,124,8,0,0,0,0,0,0,0,0,0,232,167,7,0,88,62,1,0,0,0,0,0,192,154,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,0,0,0,2,0,0,0,0,0,0,3,0,0,1,0,0,0,0,0,0,0,0,0,56,17,0,0,104,12,0,0,0,0,0,0,0,0,0,0,148,8,0,0,172,51,0,0,110,7,0,0,28,19,0,0,8,14,0,0,34,6,0,0,130,15,0,0,168,134,148,0,0,2,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,0,172,5,0,64,135,6,0,0,0,0,0,0,0,0,0,184,168,7,0,48,136,5,0,0,0,0,0,32,46,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,62,1,0,0,204,2,0,0,0,0,0,0,0,0,0,0,74,46,0,0,0,0,0,0,208,2,0,0,22,7,0,0,230,18,0,0,0,0,0,0,110,45,0,0,0,0,0,0,0,8,0,0,128,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,224,210,2,0,0,0,0,0,0,0,0,0,0,0,0,0,200,190,7,0,8,251,5,0,0,0,0,0,144,84,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,3,11,0,0,1,0,0,0,0,0,0,0,0,0,46,59,0,0,14,43,0,0,0,0,0,0,0,0,0,0,182,18,0,0,176,1,0,0,234,0,0,0,82,3,0,0,246,2,0,0,152,1,0,0,92,6,0,0,144,173,145,0,0,2,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,241,7,0,232,32,1,0,0,0,0,0,0,0,0,0,32,127,5,0,128,190,7,0,0,0,0,0,64,32,1,0,136,153,3,0,88,142,7,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,1,0,0,6,8,0,0,0,0,1,0,0,0,0,0,0,34,41,0,0,98,11,0,0,0,0,0,0,0,0,0,0,168,14,0,0,0,0,0,0,140,6,0,0,78,7,0,0,46,2,0,0,254,7,0,0,174,33,0,0,96,49,216,0,0,128,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,232,32,1,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,240,155,8,0,0,0,0,0,32,94,8,0,136,153,3,0,88,38,8,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,1,0,0,6,8,0,0,0,0,1,0,0,0,0,0,0,42,21,0,0,24,35,0,0,0,0,0,0,0,0,0,0,168,14,0,0,0,0,0,0,140,6,0,0,78,7,0,0,46,2,0,0,254,7,0,0,174,33,0,0,96,49,216,0,0,128,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,240,170,2,0,88,3,2,0,0,0,0,0,0,0,0,0,240,3,2,0,240,186,1,0,0,0,0,0,192,195,7,0,168,84,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,19,0,0,1,0,0,0,0,0,0,0,0,0,214,56,0,0,122,35,0,0,0,0,0,0,0,0,0,0,88,47,0,0,142,45,0,0,36,19,0,0,158,14,0,0,204,11,0,0,216,0,0,0,50,10,0,0,56,173,145,0,0,4,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,88,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,240,184,5,0,0,0,0,0,176,237,2,0,168,84,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,19,0,0,1,0,0,0,0,0,0,0,0,0,78,42,0,0,46,37,0,0,0,0,0,0,0,0,0,0,88,47,0,0,142,45,0,0,36,19,0,0,158,14,0,0,204,11,0,0,216,0,0,0,50,10,0,0,56,173,145,0,0,4,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,200,102,7,0,224,164,8,0,0,0,0,0,0,0,0,0,184,168,7,0,72,52,7,0,0,0,0,0,104,149,7,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,186,14,0,0,210,23,0,0,0,0,0,0,0,0,0,0,170,59,0,0,0,0,0,0,238,2,0,0,22,7,0,0,230,18,0,0,0,0,0,0,110,45,0,0,0,0,0,0,0,8,0,0,128,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,184,250,7,0,224,164,8,0,0,0,0,0,0,0,0,0,184,168,7,0,48,197,7,0,0,0,0,0,104,149,7,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,138,51,0,0,48,30,0,0,0,0,0,0,0,0,0,0,170,59,0,0,0,0,0,0,238,2,0,0,22,7,0,0,230,18,0,0,0,0,0,0,110,45,0,0,0,0,0,0,0,8,0,0,128,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,224,164,8,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,232,102,8,0,0,0,0,0,32,46,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,74,8,0,0,168,42,0,0,0,0,0,0,0,0,0,0,170,59,0,0,0,0,0,0,238,2,0,0,22,7,0,0,230,18,0,0,0,0,0,0,110,45,0,0,0,0,0,0,0,8,0,0,128,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,192,110,2,0,88,163,2,0,0,0,0,0,0,0,0,0,64,171,7,0,160,100,2,0,0,0,0,0,40,161,4,0,192,152,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,9,2,0,8,0,0,0,0,0,0,0,0,0,0,56,43,0,0,66,19,0,0,0,0,0,0,0,0,0,0,94,27,0,0,116,11,0,0,214,11,0,0,42,17,0,0,184,7,0,0,0,0,0,0,216,46,0,0,0,0,0,0,0,6,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,137,2,0,88,163,2,0,0,0,0,0,0,0,0,0,64,171,7,0,160,126,2,0,0,0,0,0,40,161,4,0,192,152,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,9,2,0,8,0,0,0,0,0,0,0,0,0,0,120,58,0,0,88,38,0,0,0,0,0,0,0,0,0,0,94,27,0,0,52,10,0,0,226,8,0,0,42,17,0,0,184,7,0,0,0,0,0,0,216,46,0,0,0,0,0,0,0,6,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,163,2,0,0,0,0,0,0,0,0,0,0,0,0,0,64,171,7,0,144,149,2,0,0,0,0,0,40,161,4,0,192,152,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,9,2,0,8,0,0,0,0,0,0,0,0,0,0,80,39,0,0,86,3,0,0,0,0,0,0,0,0,0,0,94,27,0,0,52,10,0,0,226,8,0,0,42,17,0,0,184,7,0,0,0,0,0,0,216,46,0,0,0,0,0,0,0,6,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,125,8,0,144,137,8,0,0,0,0,0,0,0,0,0,40,41,5,0,120,122,8,0,0,0,0,0,192,154,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,0,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,226,16,0,0,242,42,0,0,0,0,0,0,0,0,0,0,210,32,0,0,166,29,0,0,134,4,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,144,137,8,0,0,0,0,0,0,0,0,0,0,0,0,0,40,41,5,0,32,132,8,0,0,0,0,0,32,3,1,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,8,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,56,12,0,0,94,10,0,0,0,0,0,0,0,0,0,0,210,32,0,0,152,15,0,0,134,4,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,0,23,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,200,56,6,0,0,0,0,0,216,213,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,0,1,0,0,0,0,0,0,0,0,0,130,32,0,0,132,26,0,0,0,0,0,0,0,0,0,0,96,30,0,0,84,58,0,0,42,14,0,0,164,9,0,0,68,8,0,0,166,0,0,0,206,17,0,0,200,174,145,0,0,32,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,195,1,0,72,98,1,0,0,0,0,0,0,0,0,0,144,47,2,0,88,98,1,0,0,0,0,0,160,150,4,0,16,128,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,81,0,0,0,2,0,0,0,0,0,2,4,0,8,0,0,0,0,0,0,0,0,0,0,186,28,0,0,30,2,0,0,0,0,0,0,0,0,0,0,224,61,0,0,156,56,0,0,98,12,0,0,192,0,0,0,120,19,0,0,58,10,0,0,126,44,0,0,32,146,215,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,80,187,2,0,72,98,1,0,0,0,0,0,0,0,0,0,144,47,2,0,224,50,2,0,0,0,0,0,160,150,4,0,16,128,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,2,4,0,8,0,0,0,0,0,0,0,0,0,0,150,31,0,0,32,1,0,0,0,0,0,0,0,0,0,0,224,61,0,0,156,56,0,0,98,12,0,0,192,0,0,0,120,19,0,0,58,10,0,0,126,44,0,0,32,146,215,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,72,98,1,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,112,232,5,0,0,0,0,0,160,150,4,0,16,128,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,2,4,0,8,0,0,0,0,0,0,0,0,0,0,170,25,0,0,64,30,0,0,0,0,0,0,0,0,0,0,224,61,0,0,156,56,0,0,98,12,0,0,192,0,0,0,120,19,0,0,58,10,0,0,126,44,0,0,32,146,215,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,16,67,1,0,8,88,1,0,200,240,5,0,0,0,0,0,144,139,6,0,96,61,1,0,0,0,0,0,72,174,3,0,88,0,3,0,8,52,1,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,1,0,0,8,0,16,0,0,0,0,0,0,0,0,0,0,142,36,0,0,64,23,0,0,0,0,0,0,0,0,0,0,104,35,0,0,222,12,0,0,236,2,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,192,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,88,1,0,0,0,0,0,200,240,5,0,0,0,0,0,144,139,6,0,248,80,1,0,0,0,0,0,72,174,3,0,88,0,3,0,88,73,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,4,0,0,0,1,0,0,8,0,16,0,0,0,0,0,0,0,0,0,0,142,46,0,0,42,5,0,0,0,0,0,0,0,0,0,0,104,35,0,0,222,12,0,0,236,2,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,192,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,126,7,0,240,190,4,0,0,0,0,0,0,0,0,0,216,194,1,0,120,122,7,0,0,0,0,0,192,154,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,53,8,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,66,6,0,0,180,9,0,0,0,0,0,0,0,0,0,0,202,38,0,0,128,25,0,0,60,14,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,240,190,4,0,0,0,0,0,0,0,0,0,0,0,0,0,96,159,4,0,24,129,4,0,72,150,4,0,240,101,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,32,41,0,0,32,28,0,0,0,0,0,0,0,0,0,0,36,31,0,0,0,0,0,0,200,16,0,0,128,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,136,97,5,0,0,0,0,0,200,240,5,0,0,0,0,0,160,217,6,0,176,92,5,0,0,0,0,0,232,90,5,0,88,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,0,0,4,0,0,0,0,0,0,8,0,0,1,0,0,0,0,0,0,0,0,0,194,25,0,0,56,35,0,0,0,0,0,0,0,0,0,0,104,35,0,0,232,12,0,0,86,15,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,192,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,113,5,0,0,0,0,0,200,240,5,0,0,0,0,0,16,63,6,0,88,110,5,0,216,105,5,0,128,101,5,0,88,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,4,0,0,4,0,0,0,0,0,0,8,0,0,1,0,0,0,0,0,0,0,0,0,28,60,0,0,118,21,0,0,0,0,0,0,0,0,0,0,104,35,0,0,232,12,0,0,86,15,0,0,230,10,0,0,142,4,0,0,186,2,0,0,0,0,0,0,16,249,128,0,0,9,0,0,192,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,240,5,0,0,0,0,0,0,0,0,0,0,0,0,0,184,12,8,0,200,124,6,0,48,208,6,0,72,174,3,0,88,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,8,16,0,0,0,0,0,0,0,0,0,0,0,22,3,0,0,244,43,0,0,0,0,0,0,0,0,0,0,104,35,0,0,232,12,0,0,86,15,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,192,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,88,5,0,0,0,0,0,200,240,5,0,0,0,0,0,160,217,6,0,152,84,5,0,0,0,0,0,144,81,5,0,88,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,0,0,4,0,0,0,0,0,0,8,0,16,0,0,0,0,0,0,0,0,0,0,252,6,0,0,222,1,0,0,0,0,0,0,0,0,0,0,104,35,0,0,232,12,0,0,86,15,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,192,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,142,3,0,208,36,5,0,0,0,0,0,0,0,0,0,64,164,6,0,200,80,3,0,0,0,0,0,192,154,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,19,0,0,0,2,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,234,60,0,0,204,4,0,0,0,0,0,0,0,0,0,0,212,1,0,0,136,58,0,0,90,0,0,0,198,18,0,0,98,13,0,0,2,14,0,0,0,0,0,0,136,175,145,0,0,1,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,82,6,0,0,0,0,0,0,0,0,0,0,0,0,0,184,230,7,0,248,251,5,0,0,0,0,0,224,207,5,0,208,165,3,0,72,168,5,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,21,0,8,0,0,0,0,0,0,0,0,0,0,146,12,0,0,210,5,0,0,0,0,0,0,0,0,0,0,206,22,0,0,104,39,0,0,6,15,0,0,198,1,0,0,134,15,0,0,0,0,0,0,236,14,0,0,240,210,148,0,0,128,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,216,6,0,48,240,7,0,0,0,0,0,0,0,0,0,104,174,7,0,128,170,6,0,0,0,0,0,40,161,4,0,144,153,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,2,2,0,0,4,0,0,0,0,0,0,0,0,0,226,13,0,0,246,24,0,0,0,0,0,0,0,0,0,0,76,61,0,0,90,37,0,0,152,8,0,0,66,12,0,0,6,3,0,0,0,0,0,0,214,38,0,0,0,0,0,0,0,96,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,45,7,0,48,240,7,0,0,0,0,0,0,0,0,0,104,174,7,0,160,0,7,0,0,0,0,0,40,161,4,0,144,153,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,2,2,0,0,4,0,0,0,0,0,0,0,0,0,98,18,0,0,220,9,0,0,0,0,0,0,0,0,0,0,76,61,0,0,78,0,0,0,152,8,0,0,66,12,0,0,6,3,0,0,0,0,0,0,214,38,0,0,0,0,0,0,0,96,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,140,7,0,48,240,7,0,0,0,0,0,0,0,0,0,104,174,7,0,32,94,7,0,0,0,0,0,40,161,4,0,144,153,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,2,2,0,0,4,0,0,0,0,0,0,0,0,0,252,28,0,0,100,34,0,0,0,0,0,0,0,0,0,0,76,61,0,0,158,57,0,0,152,8,0,0,66,12,0,0,6,3,0,0,0,0,0,0,214,38,0,0,0,0,0,0,0,96,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,240,7,0,0,0,0,0,0,0,0,0,0,0,0,0,104,174,7,0,48,188,7,0,0,0,0,0,40,161,4,0,144,153,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,2,2,0,0,4,0,0,0,0,0,0,0,0,0,10,22,0,0,188,2,0,0,0,0,0,0,0,0,0,0,76,61,0,0,158,57,0,0,152,8,0,0,66,12,0,0,6,3,0,0,0,0,0,0,214,38,0,0,0,0,0,0,0,96,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,142,7,0,24,38,8,0,0,0,0,0,0,0,0,0,184,230,7,0,232,95,7,0,0,0,0,0,152,190,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,10,0,2,0,0,0,0,0,0,0,0,0,0,124,5,0,0,14,29,0,0,0,0,0,0,0,0,0,0,226,27,0,0,112,28,0,0,186,14,0,0,210,18,0,0,126,11,0,0,212,16,0,0,82,63,0,0,16,174,145,0,0,4,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,24,38,8,0,0,0,0,0,0,0,0,0,0,0,0,0,184,230,7,0,200,189,7,0,0,0,0,0,152,190,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,2,0,0,0,0,0,0,0,0,0,0,138,56,0,0,98,23,0,0,0,0,0,0,0,0,0,0,226,27,0,0,112,28,0,0,186,14,0,0,210,18,0,0,126,11,0,0,212,16,0,0,82,63,0,0,16,174,145,0,0,4,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,184,225,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,168,198,1,0,0,0,0,0,144,84,8,0,168,196,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,5,11,0,0,1,0,0,0,0,0,0,0,0,0,50,14,0,0,84,27,0,0,0,0,0,0,0,0,0,0,222,62,0,0,126,42,0,0,50,11,0,0,178,11,0,0,82,0,0,0,238,10,0,0,188,1,0,0,0,0,0,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,54,8,0,56,71,8,0,0,0,0,0,0,0,0,0,104,174,7,0,32,47,8,0,0,0,0,0,40,161,4,0,80,150,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,4,0,0,0,68,0,4,2,0,64,0,0,0,0,0,0,0,0,0,0,128,16,0,0,212,8,0,0,0,0,0,0,0,0,0,0,134,6,0,0,96,11,0,0,82,9,0,0,114,17,0,0,134,11,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,224,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,16,65,8,0,56,71,8,0,0,0,0,0,0,0,0,0,104,174,7,0,224,59,8,0,0,0,0,0,40,161,4,0,80,150,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,4,0,0,0,68,0,4,2,0,64,0,0,0,0,0,0,0,0,0,0,154,59,0,0,122,43,0,0,0,0,0,0,0,0,0,0,134,6,0,0,96,11,0,0,82,9,0,0,114,17,0,0,134,11,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,224,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,32,196,4,0,56,71,8,0,0,0,0,0,0,0,0,0,104,174,7,0,72,106,4,0,0,0,0,0,40,161,4,0,248,206,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,4,0,0,0,64,0,3,2,0,64,0,0,0,0,0,0,0,0,0,0,250,18,0,0,236,15,0,0,0,0,0,0,0,0,0,0,104,41,0,0,28,36,0,0,204,8,0,0,114,17,0,0,144,2,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,224,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,56,71,8,0,0,0,0,0,0,0,0,0,0,0,0,0,104,174,7,0,152,68,8,0,0,0,0,0,40,161,4,0,80,150,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,68,0,4,2,0,64,0,0,0,0,0,0,0,0,0,0,176,12,0,0,186,34,0,0,0,0,0,0,0,0,0,0,144,55,0,0,126,17,0,0,116,18,0,0,114,17,0,0,134,11,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,224,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,136,125,3,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,200,31,6,0,0,0,0,0,200,190,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,1,0,0,0,0,0,0,0,0,0,0,38,63,0,0,208,35,0,0,0,0,0,0,0,0,0,0,132,35,0,0,80,52,0,0,130,9,0,0,244,6,0,0,152,3,0,0,238,0,0,0,108,18,0,0,24,174,145,0,0,2,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,58,1,0,32,213,7,0,0,0,0,0,0,0,0,0,104,221,5,0,200,245,8,0,0,0,0,0,168,95,8,0,176,249,3,0,40,182,8,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,3,1,0,0,0,0,0,0,0,0,0,0,0,36,5,0,0,184,45,0,0,0,0,0,0,0,0,0,0,12,62,0,0,38,51,0,0,176,11,0,0,2,11,0,0,170,5,0,0,128,13,0,0,60,39,0,0,120,176,145,0,0,8,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,110,2,0,32,213,7,0,0,0,0,0,0,0,0,0,104,221,5,0,128,247,1,0,0,0,0,0,168,95,8,0,176,249,3,0,88,151,1,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,3,1,0,0,0,0,0,0,0,0,0,0,0,60,0,0,0,126,24,0,0,0,0,0,0,0,0,0,0,12,62,0,0,38,51,0,0,176,11,0,0,2,11,0,0,170,5,0,0,128,13,0,0,60,39,0,0,120,176,145,0,0,8,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,117,8,0,32,213,7,0,0,0,0,0,0,0,0,0,104,221,5,0,200,59,8,0,0,0,0,0,168,95,8,0,176,249,3,0,8,7,8,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,3,1,0,0,0,0,0,0,0,0,0,0,0,20,7,0,0,6,11,0,0,0,0,0,0,0,0,0,0,12,62,0,0,38,51,0,0,176,11,0,0,2,11,0,0,170,5,0,0,128,13,0,0,60,39,0,0,120,176,145,0,0,8,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,213,7,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,200,168,6,0,0,0,0,0,168,95,8,0,176,249,3,0,112,24,3,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,3,1,0,0,0,0,0,0,0,0,0,0,0,78,58,0,0,238,31,0,0,0,0,0,0,0,0,0,0,12,62,0,0,38,51,0,0,176,11,0,0,2,11,0,0,170,5,0,0,128,13,0,0,60,39,0,0,120,176,145,0,0,8,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,213,1,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,168,163,7,0,240,35,1,0,0,0,0,0,152,190,4,0,192,167,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,0,10,0,0,1,0,0,0,0,0,0,0,0,0,172,48,0,0,160,34,0,0,0,0,0,0,0,0,0,0,234,32,0,0,80,44,0,0,84,11,0,0,122,2,0,0,166,18,0,0,108,16,0,0,180,44,0,0,88,174,145,0,0,32,0,0,224,0,0,0,128,1,0,0,3,0,0,0,4,0,0,0,224,101,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,32,51,7,0,0,0,0,0,176,7,7,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,8,0,0,0,0,0,0,0,0,0,0,84,16,0,0,182,33,0,0,0,0,0,0,0,0,0,0,158,13,0,0,204,4,0,0,152,6,0,0,56,15,0,0,12,17,0,0,0,0,0,0,224,13,0,0,0,0,0,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,16,16,5,0,64,135,6,0,0,0,0,0,0,0,0,0,184,168,7,0,88,237,4,0,0,0,0,0,192,154,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,30,4,0,0,190,31,0,0,0,0,0,0,0,0,0,0,74,46,0,0,0,0,0,0,160,12,0,0,22,7,0,0,230,18,0,0,0,0,0,0,110,45,0,0,0,0,0,0,0,8,0,0,128,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,248,201,4,0,64,135,6,0,0,0,0,0,0,0,0,0,184,168,7,0,56,169,4,0,0,0,0,0,192,154,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,250,42,0,0,238,37,0,0,0,0,0,0,0,0,0,0,74,46,0,0,0,0,0,0,214,0,0,0,22,7,0,0,230,18,0,0,0,0,0,0,110,45,0,0,0,0,0,0,0,8,0,0,128,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,40,109,5,0,64,135,6,0,0,0,0,0,0,0,0,0,184,168,7,0,128,77,5,0,0,0,0,0,192,154,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,98,0,0,0,222,29,0,0,0,0,0,0,0,0,0,0,74,46,0,0,0,0,0,0,2,9,0,0,22,7,0,0,230,18,0,0,0,0,0,0,110,45,0,0,0,0,0,0,0,8,0,0,128,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,64,135,6,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,72,89,6,0,0,0,0,0,32,46,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,84,41,0,0,76,33,0,0,0,0,0,0,0,0,0,0,74,46,0,0,0,0,0,0,208,2,0,0,22,7,0,0,230,18,0,0,0,0,0,0,110,45,0,0,0,0,0,0,0,8,0,0,128,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,240,229,7,0,112,100,8,0,0,0,0,0,0,0,0,0,96,159,4,0,224,225,7,0,0,0,0,0,72,222,7,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,0,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,188,2,0,0,56,2,0,0,0,0,0,0,0,0,0,0,86,51,0,0,20,20,0,0,134,4,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,144,66,1,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,144,60,1,0,0,0,0,0,72,108,5,0,0,227,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,1,21,0,0,1,0,0,0,0,0,0,0,0,0,146,48,0,0,210,45,0,0,0,0,0,0,0,0,0,0,10,23,0,0,40,60,0,0,38,19,0,0,248,19,0,0,72,13,0,0,198,3,0,0,96,10,0,0,224,174,145,0,0,2,0,0,240,0,0,0,128,1,0,0,3,0,0,0,4,0,0,0,240,147,7,0,160,203,4,0,0,0,0,0,0,0,0,0,216,194,1,0,16,141,7,0,0,0,0,0,192,154,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,53,8,0,0,2,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,0,0,0,0,80,36,0,0,6,33,0,0,0,0,0,0,0,0,0,0,242,26,0,0,80,38,0,0,86,1,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,64,163,7,0,160,203,4,0,0,0,0,0,0,0,0,0,216,194,1,0,176,153,7,0,0,0,0,0,192,154,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,53,8,0,0,2,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,0,0,0,0,38,58,0,0,16,25,0,0,0,0,0,0,0,0,0,0,242,26,0,0,80,38,0,0,60,14,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,184,167,8,0,240,230,4,0,0,0,0,0,0,0,0,0,232,233,7,0,224,104,8,0,0,0,0,0,120,48,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,126,57,0,0,32,46,0,0,0,0,0,0,0,0,0,0,122,14,0,0,0,24,0,0,182,17,0,0,132,3,0,0,0,14,0,0,14,0,0,0,202,55,0,0,112,175,145,0,0,48,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,44,1,0,240,230,4,0,0,0,0,0,0,0,0,0,232,233,7,0,16,233,8,0,0,0,0,0,248,39,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,180,26,0,0,76,9,0,0,0,0,0,0,0,0,0,0,122,14,0,0,0,24,0,0,182,17,0,0,132,3,0,0,0,14,0,0,14,0,0,0,202,55,0,0,112,175,145,0,0,48,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,228,1,0,240,230,4,0,0,0,0,0,0,0,0,0,232,233,7,0,48,130,1,0,0,0,0,0,248,39,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,226,14,0,0,248,15,0,0,0,0,0,0,0,0,0,0,122,14,0,0,0,24,0,0,182,17,0,0,132,3,0,0,0,14,0,0,14,0,0,0,202,55,0,0,112,175,145,0,0,48,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,240,2,0,240,230,4,0,0,0,0,0,0,0,0,0,232,233,7,0,208,88,2,0,0,0,0,0,248,39,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,88,58,0,0,196,36,0,0,0,0,0,0,0,0,0,0,122,14,0,0,0,24,0,0,182,17,0,0,132,3,0,0,0,14,0,0,14,0,0,0,202,55,0,0,112,175,145,0,0,48,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,230,4,0,0,0,0,0,0,0,0,0,0,0,0,0,232,233,7,0,136,89,6,0,0,0,0,0,248,39,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,182,23,0,0,160,44,0,0,0,0,0,0,0,0,0,0,122,14,0,0,0,24,0,0,182,17,0,0,132,3,0,0,0,14,0,0,14,0,0,0,202,55,0,0,112,175,145,0,0,48,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,50,7,0,0,0,0,0,0,0,0,0,0,0,0,0,64,164,6,0,200,45,7,0,0,0,0,0,0,32,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,8,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,74,56,0,0,142,38,0,0,0,0,0,0,0,0,0,0,180,46,0,0,74,60,0,0,8,10,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,40,29,1,0,168,31,3,0,0,0,0,0,0,0,0,0,160,234,7,0,96,219,8,0,0,0,0,0,40,161,4,0,160,148,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,128,0,8,2,0,0,4,0,0,0,0,0,0,0,0,0,160,20,0,0,40,22,0,0,0,0,0,0,0,0,0,0,218,36,0,0,178,54,0,0,158,19,0,0,114,17,0,0,204,6,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,48,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,201,2,0,168,31,3,0,0,0,0,0,0,0,0,0,160,234,7,0,176,64,2,0,0,0,0,0,40,161,4,0,160,148,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,128,0,8,2,0,0,4,0,0,0,0,0,0,0,0,0,188,14,0,0,218,41,0,0,0,0,0,0,0,0,0,0,218,36,0,0,112,59,0,0,158,19,0,0,114,17,0,0,204,6,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,48,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,204,1,0,168,31,3,0,0,0,0,0,0,0,0,0,160,234,7,0,56,107,1,0,0,0,0,0,40,161,4,0,160,148,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,128,0,8,2,0,0,4,0,0,0,0,0,0,0,0,0,18,49,0,0,60,31,0,0,0,0,0,0,0,0,0,0,218,36,0,0,112,59,0,0,158,19,0,0,114,17,0,0,204,6,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,48,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,153,8,0,168,31,3,0,0,0,0,0,0,0,0,0,160,234,7,0,144,91,8,0,0,0,0,0,192,154,4,0,160,148,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,128,0,8,2,0,0,4,0,0,0,0,0,0,0,0,0,202,11,0,0,54,19,0,0,0,0,0,0,0,0,0,0,218,36,0,0,178,54,0,0,112,17,0,0,114,17,0,0,204,6,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,48,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,31,3,0,0,0,0,0,0,0,0,0,0,0,0,0,160,234,7,0,96,13,6,0,0,0,0,0,40,161,4,0,160,148,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,8,0,0,2,0,0,0,128,0,8,2,0,0,4,0,0,0,0,0,0,0,0,0,138,25,0,0,204,47,0,0,0,0,0,0,0,0,0,0,218,36,0,0,178,54,0,0,158,19,0,0,114,17,0,0,204,6,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,48,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,148,8,0,88,173,2,0,0,0,0,0,0,0,0,0,104,221,5,0,120,86,8,0,0,0,0,0,160,150,4,0,224,127,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,1,4,2,0,0,0,0,0,0,0,0,0,0,0,180,11,0,0,218,46,0,0,0,0,0,0,0,0,0,0,30,47,0,0,178,16,0,0,170,0,0,0,4,1,0,0,222,14,0,0,72,4,0,0,208,15,0,0,32,146,215,0,0,4,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,56,22,1,0,88,173,2,0,0,0,0,0,0,0,0,0,104,221,5,0,208,213,8,0,0,0,0,0,160,150,4,0,224,127,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,1,4,2,0,0,0,0,0,0,0,0,0,0,0,86,22,0,0,6,36,0,0,0,0,0,0,0,0,0,0,30,47,0,0,146,62,0,0,170,0,0,0,4,1,0,0,222,14,0,0,72,4,0,0,208,15,0,0,32,146,215,0,0,4,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,0,197,1,0,88,173,2,0,0,0,0,0,0,0,0,0,104,221,5,0,64,100,1,0,0,0,0,0,160,150,4,0,224,127,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,1,4,2,0,0,0,0,0,0,0,0,0,0,0,22,26,0,0,100,22,0,0,0,0,0,0,0,0,0,0,30,47,0,0,46,33,0,0,170,0,0,0,4,1,0,0,222,14,0,0,72,4,0,0,208,15,0,0,32,146,215,0,0,4,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,8,191,2,0,88,173,2,0,0,0,0,0,0,0,0,0,104,221,5,0,176,53,2,0,0,0,0,0,160,150,4,0,224,127,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,1,4,2,0,0,0,0,0,0,0,0,0,0,0,90,42,0,0,152,17,0,0,0,0,0,0,0,0,0,0,30,47,0,0,6,6,0,0,170,0,0,0,4,1,0,0,222,14,0,0,72,4,0,0,208,15,0,0,32,146,215,0,0,4,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,88,173,2,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,104,238,5,0,0,0,0,0,160,150,4,0,224,127,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,1,4,2,0,0,0,0,0,0,0,0,0,0,0,60,61,0,0,30,22,0,0,0,0,0,0,0,0,0,0,30,47,0,0,6,6,0,0,170,0,0,0,4,1,0,0,222,14,0,0,72,4,0,0,208,15,0,0,32,146,215,0,0,4,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,8,103,1,0,96,206,2,0,0,0,0,0,0,0,0,0,104,174,7,0,120,24,1,0,0,0,0,0,128,161,4,0,128,194,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,11,0,0,8,0,0,0,0,0,0,0,0,0,150,28,0,0,190,23,0,0,0,0,0,0,0,0,0,0,30,9,0,0,182,49,0,0,28,7,0,0,244,2,0,0,180,17,0,0,0,0,0,0,114,6,0,0,0,0,0,0,0,16,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,200,194,2,0,96,206,2,0,0,0,0,0,0,0,0,0,104,174,7,0,232,58,2,0,0,0,0,0,128,161,4,0,128,194,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,11,0,0,8,0,0,0,0,0,0,0,0,0,156,55,0,0,244,3,0,0,0,0,0,0,0,0,0,0,30,9,0,0,182,49,0,0,28,7,0,0,244,2,0,0,180,17,0,0,0,0,0,0,114,6,0,0,0,0,0,0,0,16,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,64,216,8,0,96,206,2,0,0,0,0,0,0,0,0,0,104,174,7,0,168,150,8,0,0,0,0,0,144,84,8,0,128,194,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,11,0,0,8,0,0,0,0,0,0,0,0,0,216,10,0,0,96,0,0,0,0,0,0,0,0,0,0,0,30,9,0,0,198,23,0,0,28,7,0,0,244,2,0,0,180,17,0,0,0,0,0,0,114,6,0,0,0,0,0,0,0,16,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,96,206,2,0,0,0,0,0,0,0,0,0,0,0,0,0,104,174,7,0,8,250,5,0,0,0,0,0,168,183,7,0,128,194,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,3,11,0,0,8,0,0,0,0,0,0,0,0,0,44,47,0,0,20,6,0,0,0,0,0,0,0,0,0,0,30,9,0,0,250,31,0,0,28,7,0,0,244,2,0,0,180,17,0,0,0,0,0,0,114,6,0,0,0,0,0,0,0,16,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,80,157,6,0,0,0,0,0,0,0,0,0,0,0,0,0,168,163,7,0,80,64,6,0,0,0,0,0,32,46,8,0,240,85,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,19,4,8,0,0,0,0,0,0,0,0,0,0,34,19,0,0,90,37,0,0,0,0,0,0,0,0,0,0,108,48,0,0,228,33,0,0,136,6,0,0,32,4,0,0,120,0,0,0,54,14,0,0,62,2,0,0,8,173,145,0,0,4,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,80,157,4,0,160,224,4,0,0,0,0,0,0,0,0,0,200,190,7,0,96,127,4,0,0,0,0,0,168,138,8,0,176,109,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,19,0,0,1,0,0,0,0,0,0,0,0,0,70,54,0,0,168,43,0,0,0,0,0,0,0,0,0,0,66,63,0,0,182,12,0,0,90,8,0,0,216,15,0,0,162,14,0,0,88,14,0,0,250,47,0,0,72,173,145,0,0,2,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,120,46,4,0,160,224,4,0,0,0,0,0,0,0,0,0,200,190,7,0,208,19,4,0,0,0,0,0,176,237,2,0,176,109,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,19,0,0,1,0,0,0,0,0,0,0,0,0,166,35,0,0,250,39,0,0,0,0,0,0,0,0,0,0,66,63,0,0,182,12,0,0,90,8,0,0,216,15,0,0,162,14,0,0,88,14,0,0,250,47,0,0,72,173,145,0,0,2,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,208,100,4,0,160,224,4,0,0,0,0,0,0,0,0,0,200,190,7,0,144,74,4,0,0,0,0,0,176,237,2,0,176,109,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,19,0,0,1,0,0,0,0,0,0,0,0,0,152,37,0,0,58,41,0,0,0,0,0,0,0,0,0,0,66,63,0,0,182,12,0,0,90,8,0,0,216,15,0,0,162,14,0,0,88,14,0,0,250,47,0,0,72,173,145,0,0,2,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,160,224,4,0,0,0,0,0,0,0,0,0,0,0,0,0,104,174,7,0,56,189,4,0,0,0,0,0,176,237,2,0,176,109,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,19,0,0,1,0,0,0,0,0,0,0,0,0,170,12,0,0,14,47,0,0,0,0,0,0,0,0,0,0,66,63,0,0,238,3,0,0,90,8,0,0,216,15,0,0,162,14,0,0,88,14,0,0,250,47,0,0,72,173,145,0,0,2,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,72,50,1,0,176,98,2,0,200,240,5,0,0,0,0,0,184,12,8,0,96,238,8,0,0,0,0,0,72,174,3,0,88,0,3,0,40,174,8,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,0,8,4,0,0,0,0,0,0,0,0,0,0,0,36,17,0,0,126,25,0,0,0,0,0,0,0,0,0,0,104,35,0,0,234,29,0,0,54,13,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,192,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,204,7,0,176,98,2,0,200,240,5,0,0,0,0,0,184,12,8,0,240,154,7,0,0,0,0,0,72,174,3,0,88,0,3,0,200,108,7,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,0,8,4,0,0,0,0,0,0,0,0,0,0,0,72,33,0,0,140,31,0,0,0,0,0,0,0,0,0,0,104,35,0,0,234,29,0,0,54,13,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,192,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,110,8,0,176,98,2,0,200,240,5,0,0,0,0,0,184,12,8,0,40,54,8,0,0,0,0,0,72,174,3,0,88,0,3,0,216,1,8,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,0,8,4,0,0,0,0,0,0,0,0,0,0,0,210,30,0,0,26,42,0,0,0,0,0,0,0,0,0,0,104,35,0,0,234,29,0,0,54,13,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,192,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,58,7,0,176,98,2,0,200,240,5,0,0,0,0,0,184,12,8,0,16,14,7,0,0,0,0,0,72,174,3,0,88,0,3,0,40,227,6,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,0,8,4,0,0,0,0,0,0,0,0,0,0,0,132,60,0,0,72,24,0,0,0,0,0,0,0,0,0,0,104,35,0,0,192,25,0,0,54,13,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,192,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,184,6,0,176,98,2,0,200,240,5,0,0,0,0,0,184,12,8,0,232,139,6,0,0,0,0,0,72,174,3,0,88,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,0,8,4,0,0,0,0,0,0,0,0,0,0,0,86,7,0,0,208,9,0,0,0,0,0,0,0,0,0,0,104,35,0,0,176,28,0,0,54,13,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,192,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,98,2,0,0,0,0,0,200,240,5,0,0,0,0,0,184,12,8,0,176,236,1,0,0,0,0,0,72,174,3,0,88,0,3,0,168,140,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,4,0,0,0,0,0,0,8,4,0,0,0,0,0,0,0,0,0,0,0,232,29,0,0,8,5,0,0,0,0,0,0,0,0,0,0,104,35,0,0,234,29,0,0,54,13,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,192,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,217,6,0,0,0,0,0,0,0,0,0,0,0,0,0,56,172,6,0,160,129,6,0,0,0,0,0,152,190,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,10,64,0,0,0,0,0,0,0,0,0,0,0,50,32,0,0,228,25,0,0,0,0,0,0,0,0,0,0,38,60,0,0,2,45,0,0,138,19,0,0,210,18,0,0,126,11,0,0,212,16,0,0,82,63,0,0,16,174,145,0,0,4,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,136,51,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,176,43,1,0,0,0,0,0,224,183,1,0,0,227,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,21,0,0,1,0,0,0,0,0,0,0,0,0,222,42,0,0,206,0,0,0,0,0,0,0,0,0,0,0,122,19,0,0,108,30,0,0,220,1,0,0,248,19,0,0,72,13,0,0,198,3,0,0,96,10,0,0,224,174,145,0,0,2,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,40,67,2,0,0,0,0,0,0,0,0,0,0,0,0,0,40,41,5,0,16,39,2,0,0,0,0,0,208,28,2,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,8,0,0,2,0,0,0,0,0,0,16,0,0,8,0,0,0,0,0,0,0,0,0,188,12,0,0,14,3,0,0,0,0,0,0,0,0,0,0,42,24,0,0,126,39,0,0,108,15,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,200,253,6,0,80,89,8,0,0,0,0,0,0,0,0,0,200,190,7,0,88,214,6,0,0,0,0,0,128,161,4,0,128,194,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,11,0,0,8,0,0,0,0,0,0,0,0,0,98,32,0,0,172,17,0,0,0,0,0,0,0,0,0,0,50,45,0,0,252,19,0,0,166,16,0,0,46,1,0,0,176,0,0,0,0,0,0,0,78,54,0,0,0,0,0,0,0,32,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,152,91,7,0,80,89,8,0,0,0,0,0,0,0,0,0,200,190,7,0,232,41,7,0,0,0,0,0,144,84,8,0,128,194,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,11,0,0,8,0,0,0,0,0,0,0,0,0,10,40,0,0,194,6,0,0,0,0,0,0,0,0,0,0,50,45,0,0,224,6,0,0,166,16,0,0,46,1,0,0,176,0,0,0,0,0,0,0,78,54,0,0,0,0,0,0,0,32,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,136,126,6,0,80,89,8,0,0,0,0,0,0,0,0,0,200,190,7,0,216,76,6,0,0,0,0,0,192,154,4,0,128,194,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,3,11,0,0,8,0,0,0,0,0,0,0,0,0,72,13,0,0,82,38,0,0,0,0,0,0,0,0,0,0,50,45,0,0,214,7,0,0,0,19,0,0,46,1,0,0,176,0,0,0,0,0,0,0,78,54,0,0,0,0,0,0,0,32,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,72,185,7,0,80,89,8,0,0,0,0,0,0,0,0,0,200,190,7,0,240,138,7,0,0,0,0,0,168,183,7,0,128,194,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,11,0,0,8,0,0,0,0,0,0,0,0,0,34,15,0,0,80,16,0,0,0,0,0,0,0,0,0,0,50,45,0,0,224,6,0,0,166,16,0,0,46,1,0,0,176,0,0,0,0,0,0,0,78,54,0,0,0,0,0,0,0,32,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,16,104,1,0,240,196,2,0,0,0,0,0,0,0,0,0,0,38,7,0,176,25,1,0,0,0,0,0,128,161,4,0,128,194,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,11,0,0,8,0,0,0,0,0,0,0,0,0,64,21,0,0,190,25,0,0,0,0,0,0,0,0,0,0,76,43,0,0,164,60,0,0,214,10,0,0,158,4,0,0,132,0,0,0,0,0,0,0,236,34,0,0,0,0,0,0,0,32,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,196,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,136,60,2,0,0,0,0,0,168,183,7,0,128,194,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,3,11,0,0,8,0,0,0,0,0,0,0,0,0,68,42,0,0,2,26,0,0,0,0,0,0,0,0,0,0,76,43,0,0,164,60,0,0,214,10,0,0,158,4,0,0,132,0,0,0,0,0,0,0,236,34,0,0,0,0,0,0,0,32,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,89,8,0,0,0,0,0,0,0,0,0,0,0,0,0,200,190,7,0,48,238,7,0,0,0,0,0,168,183,7,0,128,194,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,3,11,0,0,8,0,0,0,0,0,0,0,0,0,94,35,0,0,250,1,0,0,0,0,0,0,0,0,0,0,50,45,0,0,224,6,0,0,166,16,0,0,46,1,0,0,176,0,0,0,0,0,0,0,78,54,0,0,0,0,0,0,0,32,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,88,204,1,0,0,0,0,0,0,0,0,0,0,0,0,0,64,171,7,0,200,106,1,0,0,0,0,0,64,246,3,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,3,11,0,0,1,0,0,0,0,0,0,0,0,0,108,0,0,0,128,43,0,0,0,0,0,0,0,0,0,0,162,54,0,0,44,1,0,0,248,6,0,0,32,11,0,0,212,18,0,0,20,12,0,0,0,0,0,0,176,173,145,0,0,2,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,28,1,0,88,204,1,0,0,0,0,0,0,0,0,0,64,171,7,0,8,219,8,0,0,0,0,0,64,246,3,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,11,0,0,1,0,0,0,0,0,0,0,0,0,224,20,0,0,188,41,0,0,0,0,0,0,0,0,0,0,162,54,0,0,44,1,0,0,248,6,0,0,32,11,0,0,212,18,0,0,20,12,0,0,0,0,0,0,176,173,145,0,0,2,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,115,8,0,144,137,8,0,0,0,0,0,0,0,0,0,40,41,5,0,32,109,8,0,0,0,0,0,192,154,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,0,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,124,51,0,0,160,43,0,0,0,0,0,0,0,0,0,0,70,34,0,0,166,29,0,0,134,4,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,112,159,1,0,32,148,1,0,0,0,0,0,0,0,0,0,40,41,5,0,120,137,1,0,0,0,0,0,248,160,1,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,53,8,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,236,48,0,0,12,23,0,0,0,0,0,0,0,0,0,0,70,34,0,0,160,13,0,0,8,7,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,88,153,2,0,184,81,3,0,200,240,5,0,0,0,0,0,144,33,2,0,104,130,2,0,0,0,0,0,72,174,3,0,88,0,3,0,80,115,2,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,0,8,4,0,0,0,0,0,0,0,0,0,0,0,68,46,0,0,228,14,0,0,0,0,0,0,0,0,0,0,104,35,0,0,82,29,0,0,86,15,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,192,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,255,2,0,184,81,3,0,200,240,5,0,0,0,0,0,192,177,6,0,112,181,2,0,144,32,3,0,72,174,3,0,88,0,3,0,128,167,2,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,0,8,4,0,0,0,0,0,0,0,0,0,0,0,2,8,0,0,110,39,0,0,0,0,0,0,0,0,0,0,104,35,0,0,82,29,0,0,254,13,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,192,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,8,3,0,184,81,3,0,200,240,5,0,0,0,0,0,192,177,6,0,40,243,2,0,144,32,3,0,72,174,3,0,88,0,3,0,200,219,2,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,0,8,4,0,0,0,0,0,0,0,0,0,0,0,222,9,0,0,220,8,0,0,0,0,0,0,0,0,0,0,104,35,0,0,82,29,0,0,254,13,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,192,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,81,3,0,0,0,0,0,200,240,5,0,0,0,0,0,144,139,6,0,184,52,3,0,144,32,3,0,72,174,3,0,88,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,4,0,0,0,0,0,0,8,4,0,0,0,0,0,0,0,0,0,0,0,62,3,0,0,162,9,0,0,0,0,0,0,0,0,0,0,104,35,0,0,82,29,0,0,254,13,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,192,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,115,1,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,200,103,1,0,0,0,0,0,160,93,1,0,0,227,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,21,0,0,1,0,0,0,0,0,0,0,0,0,218,8,0,0,144,33,0,0,0,0,0,0,0,0,0,0,66,29,0,0,164,35,0,0,50,16,0,0,248,19,0,0,72,13,0,0,234,18,0,0,96,10,0,0,224,174,145,0,0,6,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,74,4,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,232,61,6,0,0,0,0,0,64,32,1,0,240,185,2,0,32,228,2,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,16,0,0,0,0,0,0,0,0,0,0,84,56,0,0,158,5,0,0,0,0,0,0,0,0,0,0,66,58,0,0,124,22,0,0,28,11,0,0,78,4,0,0,174,13,0,0,0,0,0,0,228,30,0,0,0,0,0,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,120,24,5,0,176,116,5,0,0,0,0,0,0,0,0,0,104,174,7,0,184,247,4,0,0,0,0,0,152,54,6,0,200,12,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,17,4,0,0,0,0,0,0,0,0,0,0,0,46,14,0,0,122,3,0,0,0,0,0,0,0,0,0,0,198,62,0,0,92,8,0,0,116,17,0,0,230,1,0,0,44,6,0,0,194,15,0,0,0,0,0,0,48,177,145,0,0,2,0,0,128,1,0,0,0,1,0,0,4,0,0,0,3,0,0,0,176,116,5,0,0,0,0,0,0,0,0,0,0,0,0,0,104,174,7,0,216,165,1,0,0,0,0,0,152,54,6,0,200,12,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,3,17,4,0,0,0,0,0,0,0,0,0,0,0,94,28,0,0,210,35,0,0,0,0,0,0,0,0,0,0,198,62,0,0,92,8,0,0,146,3,0,0,230,1,0,0,44,6,0,0,194,15,0,0,0,0,0,0,48,177,145,0,0,2,0,0,128,1,0,0,0,1,0,0,4,0,0,0,3,0,0,0,64,53,8,0,0,0,0,0,0,0,0,0,240,168,5,0,216,194,1,0,112,203,7,0,0,0,0,0,248,39,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,168,29,0,0,128,32,0,0,14,23,0,0,154,31,0,0,8,31,0,0,100,35,0,0,226,16,0,0,102,13,0,0,184,3,0,0,0,0,0,0,220,41,0,0,0,0,0,0,4,1,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,128,1,0,160,238,1,0,0,0,0,0,0,0,0,0,64,171,7,0,144,114,1,0,0,0,0,0,40,161,4,0,192,152,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,9,2,2,0,0,0,0,0,0,0,0,0,0,0,62,55,0,0,74,15,0,0,0,0,0,0,0,0,0,0,102,57,0,0,158,0,0,0,180,7,0,0,42,17,0,0,184,7,0,0,0,0,0,0,216,46,0,0,0,0,0,0,0,6,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,152,1,0,160,238,1,0,0,0,0,0,0,0,0,0,64,171,7,0,72,142,1,0,0,0,0,0,40,161,4,0,192,152,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,9,2,2,0,0,0,0,0,0,0,0,0,0,0,202,2,0,0,174,6,0,0,0,0,0,0,0,0,0,0,102,57,0,0,158,0,0,0,26,16,0,0,42,17,0,0,184,7,0,0,0,0,0,0,216,46,0,0,0,0,0,0,0,6,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,102,1,0,160,238,1,0,0,0,0,0,0,0,0,0,64,171,7,0,184,92,1,0,0,0,0,0,248,160,1,0,192,152,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,9,2,2,0,0,0,0,0,0,0,0,0,0,0,186,20,0,0,238,16,0,0,0,0,0,0,0,0,0,0,102,57,0,0,158,0,0,0,0,8,0,0,42,17,0,0,184,7,0,0,0,0,0,0,216,46,0,0,0,0,0,0,0,6,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,175,1,0,160,238,1,0,0,0,0,0,0,0,0,0,64,171,7,0,64,169,1,0,0,0,0,0,248,160,1,0,192,152,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,9,2,2,0,0,0,0,0,0,0,0,0,0,0,54,43,0,0,52,44,0,0,0,0,0,0,0,0,0,0,102,57,0,0,158,0,0,0,16,4,0,0,42,17,0,0,184,7,0,0,0,0,0,0,216,46,0,0,0,0,0,0,0,6,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,10,1,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,248,4,1,0,0,0,0,0,32,0,1,0,80,164,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,32,0,0,0,0,0,0,0,0,0,0,80,48,0,0,102,45,0,0,0,0,0,0,0,0,0,0,244,56,0,0,204,62,0,0,180,18,0,0,24,3,0,0,158,1,0,0,70,6,0,0,0,0,0,0,0,0,0,0,0,4,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,247,7,0,96,38,1,0,0,0,0,0,0,0,0,0,240,3,2,0,240,194,7,0,0,0,0,0,160,161,8,0,144,172,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,0,10,2,0,0,0,0,0,0,0,0,0,0,0,52,31,0,0,36,1,0,0,0,0,0,0,0,0,0,0,32,36,0,0,234,33,0,0,136,11,0,0,132,15,0,0,10,2,0,0,80,6,0,0,38,37,0,0,168,174,145,0,1,16,0,0,224,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,144,99,8,0,96,38,1,0,0,0,0,0,0,0,0,0,240,3,2,0,56,43,8,0,0,0,0,0,160,161,8,0,144,172,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,0,10,2,0,0,0,0,0,0,0,0,0,0,0,236,55,0,0,74,2,0,0,0,0,0,0,0,0,0,0,32,36,0,0,234,33,0,0,136,11,0,0,132,15,0,0,10,2,0,0,80,6,0,0,38,37,0,0,168,174,145,0,1,16,0,0,224,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,96,38,1,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,0,228,8,0])
.concat([0,0,0,0,160,161,8,0,144,172,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,0,10,2,0,0,0,0,0,0,0,0,0,0,0,174,26,0,0,170,10,0,0,0,0,0,0,0,0,0,0,32,36,0,0,234,33,0,0,136,11,0,0,132,15,0,0,10,2,0,0,80,6,0,0,38,37,0,0,168,174,145,0,1,16,0,0,224,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,40,213,2,0,168,26,3,0,0,0,0,0,0,0,0,0,160,234,7,0,144,194,2,0,0,0,0,0,192,154,4,0,192,152,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,53,0,0,0,2,0,0,0,0,0,9,2,2,0,0,0,0,0,0,0,0,0,0,0,70,49,0,0,28,26,0,0,0,0,0,0,0,0,0,0,94,27,0,0,116,47,0,0,64,16,0,0,42,17,0,0,184,7,0,0,0,0,0,0,216,46,0,0,0,0,0,0,0,6,0,0,224,0,0,0,240,0,0,0,3,0,0,0,4,0,0,0,168,26,3,0,0,0,0,0,0,0,0,0,0,0,0,0,160,234,7,0,184,2,3,0,0,0,0,0,176,237,2,0,192,152,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,2,0,0,0,0,0,9,2,2,0,0,0,0,0,0,0,0,0,0,0,98,11,0,0,106,0,0,0,0,0,0,0,0,0,0,0,94,27,0,0,116,47,0,0,64,16,0,0,42,17,0,0,184,7,0,0,0,0,0,0,216,46,0,0,0,0,0,0,0,6,0,0,224,0,0,0,240,0,0,0,3,0,0,0,4,0,0,0,24,210,2,0,160,123,3,0,0,0,0,0,0,0,0,0,184,12,8,0,152,209,1,0,0,0,0,0,152,190,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,10,0,2,0,0,0,0,0,0,0,0,0,0,46,44,0,0,106,15,0,0,0,0,0,0,0,0,0,0,204,44,0,0,138,31,0,0,174,1,0,0,210,18,0,0,126,11,0,0,212,16,0,0,82,63,0,0,16,174,145,0,0,4,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,160,123,3,0,0,0,0,0,0,0,0,0,0,0,0,0,192,177,6,0,104,31,6,0,0,0,0,0,152,190,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,2,0,0,0,0,0,0,0,0,0,0,250,44,0,0,4,44,0,0,0,0,0,0,0,0,0,0,204,44,0,0,138,31,0,0,174,1,0,0,210,18,0,0,126,11,0,0,212,16,0,0,82,63,0,0,16,174,145,0,0,4,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,104,201,5,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,56,160,5,0,0,0,0,0,176,237,2,0,168,84,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,3,0,0,0,0,0,0,19,0,0,8,0,0,0,0,0,0,0,0,0,110,60,0,0,144,37,0,0,0,0,0,0,0,0,0,0,162,56,0,0,38,47,0,0,182,6,0,0,222,8,0,0,178,15,0,0,54,2,0,0,78,56,0,0,104,173,145,0,0,8,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,184,186,7,0,168,28,1,0,0,0,0,0,0,0,0,0,200,190,7,0,144,139,7,0,0,0,0,0,96,92,7,0,128,194,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,11,0,8,0,0,0,0,0,0,0,0,0,0,30,49,0,0,218,45,0,0,0,0,0,0,0,0,0,0,168,9,0,0,230,45,0,0,226,18,0,0,70,10,0,0,6,4,0,0,0,0,0,0,122,15,0,0,0,0,0,0,0,48,0,0,96,3,0,0,224,0,0,0,12,0,0,0,3,0,0,0,232,35,8,0,168,28,1,0,0,0,0,0,0,0,0,0,200,190,7,0,208,238,7,0,0,0,0,0,144,84,8,0,128,194,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,11,0,8,0,0,0,0,0,0,0,0,0,0,82,11,0,0,218,11,0,0,0,0,0,0,0,0,0,0,168,9,0,0,230,45,0,0,226,18,0,0,70,10,0,0,6,4,0,0,0,0,0,0,122,15,0,0,0,0,0,0,0,48,0,0,96,3,0,0,224,0,0,0,12,0,0,0,3,0,0,0,168,28,1,0,0,0,0,0,0,0,0,0,0,0,0,0,200,190,7,0,216,152,8,0,0,0,0,0,168,183,7,0,128,194,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,3,11,0,8,0,0,0,0,0,0,0,0,0,0,166,45,0,0,136,44,0,0,0,0,0,0,0,0,0,0,168,9,0,0,240,62,0,0,226,18,0,0,70,10,0,0,6,4,0,0,0,0,0,0,122,15,0,0,0,0,0,0,0,48,0,0,96,3,0,0,224,0,0,0,12,0,0,0,3,0,0,0,88,50,1,0,104,77,1,0,0,0,0,0,0,0,0,0,104,221,5,0,32,42,1,0,0,0,0,0,128,161,4,0,208,135,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,2,11,4,0,0,0,0,0,0,0,0,0,0,0,116,25,0,0,2,22,0,0,0,0,0,0,0,0,0,0,8,45,0,0,8,30,0,0,4,20,0,0,46,7,0,0,246,17,0,0,0,0,0,0,176,18,0,0,0,0,0,0,0,32,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,65,1,0,104,77,1,0,0,0,0,0,0,0,0,0,104,221,5,0,96,58,1,0,0,0,0,0,144,84,8,0,208,135,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,2,11,4,0,0,0,0,0,0,0,0,0,0,0,20,57,0,0,72,12,0,0,0,0,0,0,0,0,0,0,8,45,0,0,242,22,0,0,4,20,0,0,46,7,0,0,246,17,0,0,0,0,0,0,176,18,0,0,0,0,0,0,0,32,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,77,1,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,16,71,1,0,0,0,0,0,168,183,7,0,208,135,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,4,0,0,0,0,0,2,11,4,0,0,0,0,0,0,0,0,0,0,0,94,57,0,0,212,21,0,0,0,0,0,0,0,0,0,0,8,45,0,0,146,55,0,0,4,20,0,0,46,7,0,0,246,17,0,0,0,0,0,0,176,18,0,0,0,0,0,0,0,32,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,190,1,0,160,238,1,0,0,0,0,0,0,0,0,0,64,171,7,0,248,182,1,0,0,0,0,0,40,161,4,0,192,152,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,9,2,2,0,0,0,0,0,0,0,0,0,0,0,208,10,0,0,200,25,0,0,0,0,0,0,0,0,0,0,102,57,0,0,158,0,0,0,108,18,0,0,42,17,0,0,184,7,0,0,0,0,0,0,216,46,0,0,0,0,0,0,0,6,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,249,2,0,184,89,5,0,0,0,0,0,0,0,0,0,200,190,7,0,88,94,2,0,0,0,0,0,192,223,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,0,20,2,0,0,0,0,0,0,0,0,0,0,0,216,20,0,0,164,40,0,0,0,0,0,0,0,0,0,0,10,55,0,0,2,34,0,0,50,6,0,0,124,4,0,0,128,0,0,0,0,0,0,0,194,28,0,0,0,0,0,0,128,3,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,0,107,7,0,0,0,0,0,0,0,0,0,0,0,0,0,200,190,7,0,160,56,7,0,0,0,0,0,192,223,4,0,240,185,2,0,216,11,7,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,0,20,2,0,0,0,0,0,0,0,0,0,0,0,76,9,0,0,140,11,0,0,0,0,0,0,0,0,0,0,10,55,0,0,2,34,0,0,50,6,0,0,124,4,0,0,128,0,0,0,0,0,0,0,194,28,0,0,0,0,0,0,128,3,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,152,235,8,0,184,89,5,0,0,0,0,0,0,0,0,0,200,190,7,0,56,171,8,0,0,0,0,0,192,223,4,0,240,185,2,0,208,107,8,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,0,20,2,0,0,0,0,0,0,0,0,0,0,0,204,26,0,0,196,46,0,0,0,0,0,0,0,0,0,0,10,55,0,0,2,34,0,0,50,6,0,0,124,4,0,0,128,0,0,0,0,0,0,0,194,28,0,0,0,0,0,0,128,3,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,192,233,1,0,184,89,5,0,0,0,0,0,0,0,0,0,200,190,7,0,128,135,1,0,0,0,0,0,192,223,4,0,240,185,2,0,96,47,1,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,0,20,2,0,0,0,0,0,0,0,0,0,0,0,236,29,0,0,224,19,0,0,0,0,0,0,0,0,0,0,10,55,0,0,2,34,0,0,50,6,0,0,124,4,0,0,128,0,0,0,0,0,0,0,194,28,0,0,0,0,0,0,128,3,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,56,202,7,0,184,89,5,0,0,0,0,0,0,0,0,0,200,190,7,0,232,152,7,0,0,0,0,0,192,223,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,53,0,0,0,2,0,0,0,0,0,0,20,2,0,0,0,0,0,0,0,0,0,0,0,180,24,0,0,28,29,0,0,0,0,0,0,0,0,0,0,10,55,0,0,2,34,0,0,132,7,0,0,124,4,0,0,128,0,0,0,0,0,0,0,194,28,0,0,0,0,0,0,128,3,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,88,51,8,0,184,89,5,0,0,0,0,0,0,0,0,0,200,190,7,0,88,255,7,0,0,0,0,0,192,223,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,53,0,0,0,2,0,0,0,0,0,0,20,2,0,0,0,0,0,0,0,0,0,0,0,64,17,0,0,120,30,0,0,0,0,0,0,0,0,0,0,10,55,0,0,2,34,0,0,114,9,0,0,124,4,0,0,128,0,0,0,0,0,0,0,194,28,0,0,0,0,0,0,128,3,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,184,89,5,0,0,0,0,0,0,0,0,0,0,0,0,0,200,190,7,0,224,108,6,0,0,0,0,0,192,223,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,0,20,2,0,0,0,0,0,0,0,0,0,0,0,130,54,0,0,60,24,0,0,0,0,0,0,0,0,0,0,10,55,0,0,2,34,0,0,50,6,0,0,124,4,0,0,128,0,0,0,0,0,0,0,194,28,0,0,0,0,0,0,128,3,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,8,170,8,0,232,31,5,0,0,0,0,0,0,0,0,0,64,171,7,0,32,50,8,0,0,0,0,0,80,254,7,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,0,20,2,0,0,0,0,0,0,0,0,0,0,0,22,47,0,0,178,16,0,0,0,0,0,0,0,0,0,0,160,11,0,0,236,54,0,0,192,3,0,0,244,5,0,0,118,19,0,0,0,0,0,0,212,60,0,0,0,0,0,0,0,6,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,144,45,1,0,232,31,5,0,0,0,0,0,0,0,0,0,232,233,7,0,168,234,8,0,0,0,0,0,192,223,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,0,20,2,0,0,0,0,0,0,0,0,0,0,0,240,19,0,0,138,33,0,0,0,0,0,0,0,0,0,0,160,11,0,0,236,54,0,0,192,3,0,0,244,5,0,0,118,19,0,0,0,0,0,0,212,60,0,0,0,0,0,0,0,6,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,96,231,1,0,232,31,5,0,0,0,0,0,0,0,0,0,232,233,7,0,56,133,1,0,0,0,0,0,192,223,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,53,0,0,0,2,0,0,0,0,0,0,20,2,0,0,0,0,0,0,0,0,0,0,0,206,35,0,0,12,33,0,0,0,0,0,0,0,0,0,0,160,11,0,0,236,54,0,0,66,14,0,0,244,5,0,0,118,19,0,0,0,0,0,0,212,60,0,0,0,0,0,0,0,6,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,48,246,2,0,232,31,5,0,0,0,0,0,0,0,0,0,232,233,7,0,168,91,2,0,0,0,0,0,192,223,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,0,20,2,0,0,0,0,0,0,0,0,0,0,0,254,58,0,0,26,8,0,0,0,0,0,0,0,0,0,0,160,11,0,0,236,54,0,0,192,3,0,0,244,5,0,0,118,19,0,0,0,0,0,0,212,60,0,0,0,0,0,0,0,6,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,232,31,5,0,0,0,0,0,0,0,0,0,0,0,0,0,232,233,7,0,224,98,6,0,0,0,0,0,192,223,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,0,20,2,0,0,0,0,0,0,0,0,0,0,0,58,61,0,0,250,0,0,0,0,0,0,0,0,0,0,0,160,11,0,0,236,54,0,0,192,3,0,0,244,5,0,0,118,19,0,0,0,0,0,0,212,60,0,0,0,0,0,0,0,6,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,96,235,2,0,208,62,3,0,0,0,0,0,0,0,0,0,184,168,7,0,152,211,2,0,0,0,0,0,128,161,4,0,216,142,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,11,0,0,4,0,0,0,0,0,0,0,0,0,74,31,0,0,198,33,0,0,0,0,0,0,0,0,0,0,182,26,0,0,6,19,0,0,76,18,0,0,24,8,0,0,14,5,0,0,0,0,0,0,60,41,0,0,0,0,0,0,0,16,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,152,21,3,0,208,62,3,0,0,0,0,0,0,0,0,0,184,168,7,0,240,0,3,0,0,0,0,0,144,84,8,0,216,142,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,11,0,0,1,0,0,0,0,0,0,0,0,0,250,38,0,0,192,10,0,0,0,0,0,0,0,0,0,0,182,26,0,0,86,36,0,0,76,18,0,0,24,8,0,0,14,5,0,0,0,0,0,0,60,41,0,0,0,0,0,0,0,16,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,208,62,3,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,48,46,3,0,0,0,0,0,168,183,7,0,216,142,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,11,0,0,1,0,0,0,0,0,0,0,0,0,134,42,0,0,34,1,0,0,0,0,0,0,0,0,0,0,182,26,0,0,120,25,0,0,76,18,0,0,24,8,0,0,14,5,0,0,0,0,0,0,60,41,0,0,0,0,0,0,0,16,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,200,250,3,0,0,0,0,0,0,0,0,0,0,0,0,0,64,164,6,0,128,246,3,0,0,0,0,0,112,243,3,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,8,0,0,2,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,0,0,0,0,84,47,0,0,184,35,0,0,0,0,0,0,0,0,0,0,134,18,0,0,86,33,0,0,58,11,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,216,218,2,0,88,196,3,0,0,0,0,0,0,0,0,0,240,3,2,0,208,73,2,0,0,0,0,0,248,214,1,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,1,0,0,0,0,0,0,10,0,16,0,0,0,0,0,0,0,0,0,0,72,49,0,0,244,0,0,0,0,0,0,0,0,0,0,0,38,19,0,0,68,34,0,0,0,1,0,0,128,8,0,0,68,17,0,0,0,0,0,0,248,20,0,0,0,0,0,0,0,1,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,196,3,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,240,44,6,0,0,0,0,0,168,204,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,10,0,16,0,0,0,0,0,0,0,0,0,0,68,30,0,0,132,40,0,0,0,0,0,0,0,0,0,0,38,19,0,0,116,61,0,0,0,1,0,0,128,8,0,0,68,17,0,0,0,0,0,0,248,20,0,0,0,0,0,0,0,1,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,145,7,0,224,41,8,0,0,0,0,0,0,0,0,0,32,127,5,0,120,98,7,0,0,0,0,0,168,117,1,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,149,0,0,0,2,0,0,0,0,0,0,10,0,16,0,0,0,0,0,0,0,0,0,0,134,26,0,0,6,18,0,0,0,0,0,0,0,0,0,0,236,22,0,0,92,38,0,0,210,17,0,0,8,1,0,0,76,2,0,0,190,17,0,0,4,30,0,0,104,157,215,0,0,4,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,224,41,8,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,48,193,7,0,0,0,0,0,168,117,1,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,133,0,0,0,2,0,0,0,0,0,0,10,0,16,0,0,0,0,0,0,0,0,0,0,40,34,0,0,4,10,0,0,0,0,0,0,0,0,0,0,236,22,0,0,92,38,0,0,210,17,0,0,8,1,0,0,76,2,0,0,190,17,0,0,4,30,0,0,104,157,215,0,0,4,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,192,66,7,0,48,63,8,0,0,0,0,0,0,0,0,0,96,135,2,0,224,22,7,0,0,0,0,0,144,234,6,0,152,8,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,4,17,0,0,1,0,0,0,0,0,0,0,0,0,80,43,0,0,120,40,0,0,0,0,0,0,0,0,0,0,52,51,0,0,214,42,0,0,2,2,0,0,80,0,0,0,228,1,0,0,44,8,0,0,0,0,0,0,32,177,145,0,0,2,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,168,2,6,0,0,0,0,0,72,172,6,0,0,0,0,0,192,177,6,0,168,253,5,0,0,0,0,0,128,145,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,1,0,1,133,0,128,0,0,0,0,0,0,0,0,0,0,2,52,0,0,116,32,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,5,3,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,48,239,2,0,0,0,0,0,16,217,2,0,0,227,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,1,21,0,0,1,0,0,0,0,0,0,0,0,0,192,34,0,0,64,15,0,0,0,0,0,0,0,0,0,0,152,46,0,0,194,46,0,0,210,5,0,0,248,19,0,0,72,13,0,0,198,3,0,0,96,10,0,0,224,174,145,0,0,2,0,0,240,0,0,0,128,1,0,0,3,0,0,0,4,0,0,0,72,172,6,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,232,103,2,0,0,242,1,0,128,145,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,2,5,0,0,0,0,0,0,0,0,0,0,0,0,32,43,0,0,204,41,0,0,0,0,0,0,0,0,0,0,180,61,0,0,56,28,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,172,6,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,208,141,6,0,48,208,6,0,128,145,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,1,5,0,0,0,0,0,0,0,0,0,0,0,0,34,5,0,0,190,16,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,91,7,0,168,88,8,0,0,0,0,0,0,0,0,0,104,174,7,0,104,41,7,0,0,0,0,0,128,161,4,0,168,196,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,5,11,4,0,0,0,0,0,0,0,0,0,0,0,52,46,0,0,114,39,0,0,0,0,0,0,0,0,0,0,184,15,0,0,210,34,0,0,6,10,0,0,178,11,0,0,82,0,0,0,238,10,0,0,188,1,0,0,0,0,0,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,88,8,0,0,0,0,0,0,0,0,0,0,0,0,0,104,174,7,0,168,237,7,0,0,0,0,0,168,183,7,0,168,196,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,5,11,4,0,0,0,0,0,0,0,0,0,0,0,244,17,0,0,240,8,0,0,0,0,0,0,0,0,0,0,184,15,0,0,146,61,0,0,6,10,0,0,178,11,0,0,82,0,0,0,238,10,0,0,188,1,0,0,0,0,0,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,79,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,160,123,1,0,0,0,0,0,64,32,1,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,16,0,0,0,0,0,0,0,0,0,0,178,13,0,0,102,8,0,0,0,0,0,0,0,0,0,0,66,58,0,0,42,48,0,0,28,11,0,0,78,4,0,0,174,13,0,0,0,0,0,0,228,30,0,0,0,0,0,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,208,114,2,0,0,0,0,0,72,172,6,0,0,0,0,0,104,221,5,0,208,206,7,0,0,0,0,0,128,145,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,0,0,1,0,0,0,0,0,0,0,0,0,206,21,0,0,64,40,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,147,4,0,104,24,5,0,0,0,0,0,0,0,0,0,96,135,2,0,72,117,4,0,240,56,5,0,152,54,6,0,168,38,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,5,17,1,0,0,0,0,0,0,0,0,0,0,0,192,20,0,0,158,10,0,0,0,0,0,0,0,0,0,0,58,34,0,0,166,14,0,0,160,1,0,0,218,2,0,0,114,1,0,0,166,3,0,0,116,50,0,0,8,211,148,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,104,24,5,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,160,247,4,0,240,56,5,0,152,54,6,0,168,38,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,5,17,1,0,0,0,0,0,0,0,0,0,0,0,140,62,0,0,78,0,0,0,0,0,0,0,0,0,0,0,58,34,0,0,166,14,0,0,160,1,0,0,218,2,0,0,114,1,0,0,166,3,0,0,116,50,0,0,8,211,148,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,224,63,3,0,88,137,3,0,0,0,0,0,0,0,0,0,64,171,7,0,200,47,3,0,0,0,0,0,16,182,4,0,192,152,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,9,2,0,8,0,0,0,0,0,0,0,0,0,0,184,10,0,0,68,1,0,0,0,0,0,0,0,0,0,0,94,27,0,0,64,2,0,0,34,13,0,0,42,17,0,0,184,7,0,0,0,0,0,0,216,46,0,0,0,0,0,0,0,6,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,137,3,0,0,0,0,0,0,0,0,0,0,0,0,0,64,171,7,0,200,113,3,0,0,0,0,0,40,161,4,0,192,152,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,9,2,0,8,0,0,0,0,0,0,0,0,0,0,46,18,0,0,118,34,0,0,0,0,0,0,0,0,0,0,94,27,0,0,64,2,0,0,30,10,0,0,42,17,0,0,184,7,0,0,0,0,0,0,216,46,0,0,0,0,0,0,0,6,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,192,7,0,0,0,0,0,0,0,0,0,0,0,0,0,168,163,7,0,184,143,7,0,0,0,0,0,248,39,8,0,208,165,3,0,248,96,7,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,21,0,32,0,0,0,0,0,0,0,0,0,0,186,60,0,0,36,10,0,0,0,0,0,0,0,0,0,0,168,49,0,0,110,0,0,0,72,12,0,0,198,1,0,0,134,15,0,0,0,0,0,0,236,14,0,0,240,210,148,0,0,128,0,0,120,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,112,157,8,0,0,0,0,0,0,0,0,0,0,0,0,0,168,163,7,0,176,95,8,0,0,0,0,0,248,39,8,0,208,165,3,0,200,242,7,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,21,0,32,0,0,0,0,0,0,0,0,0,0,26,37,0,0,38,33,0,0,0,0,0,0,0,0,0,0,168,49,0,0,232,43,0,0,8,0,0,0,198,1,0,0,134,15,0,0,0,0,0,0,236,14,0,0,240,210,148,0,0,128,0,0,120,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,144,81,8,0,184,94,8,0,0,0,0,0,0,0,0,0,184,168,7,0,224,76,8,0,0,0,0,0,40,161,4,0,80,150,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,64,4,4,2,0,64,0,0,0,0,0,0,0,0,0,0,166,7,0,0,134,1,0,0,0,0,0,0,0,0,0,0,50,22,0,0,36,6,0,0,58,6,0,0,114,17,0,0,134,11,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,94,8,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,128,87,8,0,0,0,0,0,40,161,4,0,80,150,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,64,8,4,2,0,64,0,0,0,0,0,0,0,0,0,0,230,19,0,0,42,16,0,0,0,0,0,0,0,0,0,0,50,22,0,0,36,6,0,0,172,15,0,0,114,17,0,0,134,11,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,201,5,0,0,0,0,0,72,172,6,0,0,0,0,0,96,135,2,0,96,33,4,0,0,0,0,0,128,145,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,4,0,0,0,0,0,0,0,0,0,0,0,42,27,0,0,134,8,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,244,6,0,72,128,7,0,0,0,0,0,0,0,0,0,96,135,2,0,192,202,6,0,0,0,0,0,176,237,2,0,168,84,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,19,8,0,0,0,0,0,0,0,0,0,0,0,56,36,0,0,76,2,0,0,0,0,0,0,0,0,0,0,122,30,0,0,26,60,0,0,150,16,0,0,192,10,0,0,128,11,0,0,140,16,0,0,112,12,0,0,0,173,145,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,144,156,6,0,72,128,7,0,0,0,0,0,0,0,0,0,96,135,2,0,48,115,6,0,0,0,0,0,176,237,2,0,168,84,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,19,8,0,0,0,0,0,0,0,0,0,0,0,44,59,0,0,126,15,0,0,0,0,0,0,0,0,0,0,122,30,0,0,26,60,0,0,150,16,0,0,192,10,0,0,128,11,0,0,140,16,0,0,112,12,0,0,0,173,145,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,72,128,7,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,24,32,7,0,0,0,0,0,176,237,2,0,168,84,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,19,8,0,0,0,0,0,0,0,0,0,0,0,164,5,0,0,66,5,0,0,0,0,0,0,0,0,0,0,122,30,0,0,26,60,0,0,150,16,0,0,192,10,0,0,128,11,0,0,140,16,0,0,112,12,0,0,0,173,145,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,64,232,8,0,224,252,8,0,0,0,0,0,0,0,0,0,104,221,5,0,120,223,8,0,0,0,0,0,152,216,8,0,80,164,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,10,1,0,0,0,0,0,0,0,0,0,0,0,60,4,0,0,146,37,0,0,0,0,0,0,0,0,0,0,244,56,0,0,242,7,0,0,228,14,0,0,56,12,0,0,212,3,0,0,210,14,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,193,8,0,224,252,8,0,0,0,0,0,0,0,0,0,104,221,5,0,240,188,8,0,120,155,4,0,192,154,4,0,80,164,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,10,1,0,0,0,0,0,0,0,0,0,0,0,232,26,0,0,150,19,0,0,0,0,0,0,0,0,0,0,244,56,0,0,242,7,0,0,232,17,0,0,92,15,0,0,82,10,0,0,210,14,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,208,8,0,224,252,8,0,0,0,0,0,0,0,0,0,104,221,5,0,184,203,8,0,120,155,4,0,192,154,4,0,80,164,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,10,1,0,0,0,0,0,0,0,0,0,0,0,172,24,0,0,130,45,0,0,0,0,0,0,0,0,0,0,244,56,0,0,242,7,0,0,202,3,0,0,92,15,0,0,82,10,0,0,210,14,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,252,8,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,192,239,8,0,0,0,0,0,232,196,4,0,80,164,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,1,0,0,0,0,0,0,0,0,0,0,0,82,4,0,0,128,38,0,0,0,0,0,0,0,0,0,0,244,56,0,0,242,7,0,0,228,14,0,0,56,12,0,0,212,3,0,0,210,14,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,100,3,0,0,0,0,0,0,0,0,0,0,0,0,0,144,139,6,0,160,28,6,0,0,0,0,0,0,188,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,2,0,0,0,0,0,0,0,0,0,0,118,54,0,0,38,6,0,0,0,0,0,0,0,0,0,0,32,48,0,0,10,39,0,0,76,4,0,0,70,9,0,0,40,18,0,0,88,15,0,0,46,51,0,0,224,173,145,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,88,208,2,0,24,100,3,0,0,0,0,0,0,0,0,0,144,139,6,0,104,68,2,0,0,0,0,0,0,188,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,10,0,2,0,0,0,0,0,0,0,0,0,0,72,11,0,0,240,36,0,0,0,0,0,0,0,0,0,0,32,48,0,0,10,39,0,0,76,4,0,0,70,9,0,0,40,18,0,0,88,15,0,0,46,51,0,0,224,173,145,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,240,104,3,0,0,0,0,0,0,0,0,0,0,0,0,0,176,229,7,0,152,29,6,0,0,0,0,0,168,188,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,4,0,0,0,0,0,0,0,0,0,0,0,58,54,0,0,140,17,0,0,0,0,0,0,0,0,0,0,44,62,0,0,162,58,0,0,166,10,0,0,86,7,0,0,156,4,0,0,234,1,0,0,154,22,0,0,240,173,145,0,0,3,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,80,80,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,0,50,3,0,0,0,0,0,232,205,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,16,0,0,0,0,0,0,0,0,0,0,14,54,0,0,12,9,0,0,0,0,0,0,0,0,0,0,76,49,0,0,110,59,0,0,144,18,0,0,30,18,0,0,226,19,0,0,0,0,0,0,240,8,0,0,0,0,0,0,0,8,0,0,128,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,24,248,1,0,16,224,7,0,0,0,0,0,0,0,0,0,184,168,7,0,192,152,1,0,0,0,0,0,168,95,8,0,40,251,3,0,80,59,1,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,3,0,64,0,0,0,0,0,0,0,0,0,0,6,59,0,0,78,15,0,0,0,0,0,0,0,0,0,0,118,10,0,0,222,43,0,0,222,2,0,0,50,17,0,0,194,5,0,0,238,5,0,0,156,33,0,0,136,176,145,0,0,4,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,208,2,0,0,103,3,0,0,0,0,0,0,0,0,0,0,38,7,0,128,68,2,0,0,0,0,0,72,188,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,10,0,16,0,0,0,0,0,0,0,0,0,0,144,7,0,0,182,15,0,0,0,0,0,0,0,0,0,0,104,3,0,0,244,44,0,0,54,10,0,0,82,8,0,0,90,15,0,0,118,13,0,0,48,60,0,0,232,173,145,0,0,2,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,32,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,16,222,8,0,0,0,0,0,72,188,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,2,0,0,0,0,0,0,10,0,16,0,0,0,0,0,0,0,0,0,0,86,56,0,0,200,40,0,0,0,0,0,0,0,0,0,0,104,3,0,0,22,8,0,0,84,14,0,0,82,8,0,0,90,15,0,0,118,13,0,0,48,60,0,0,232,173,145,0,0,2,0,0,224,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,48,240,4,0,104,7,5,0,0,0,0,0,0,0,0,0,216,194,1,0,104,236,4,0,88,1,5,0,72,226,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,198,1,0,0,100,27,0,0,0,0,0,0,0,0,0,0,52,12,0,0,194,33,0,0,42,18,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,248,4,0,104,7,5,0,0,0,0,0,0,0,0,0,216,194,1,0,72,243,4,0,88,1,5,0,72,226,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,146,54,0,0,130,30,0,0,0,0,0,0,0,0,0,0,52,12,0,0,194,33,0,0,42,18,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,254,4,0,104,7,5,0,0,0,0,0,0,0,0,0,216,194,1,0,8,251,4,0,88,1,5,0,72,226,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,16,42,0,0,0,0,0,0,0,0,0,0,52,12,0,0,194,33,0,0,20,0,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,7,5,0,0,0,0,0,0,0,0,0,0,0,0,0,216,194,1,0,144,4,5,0,88,1,5,0,72,226,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,92,13,0,0,8,28,0,0,0,0,0,0,0,0,0,0,52,12,0,0,194,33,0,0,20,0,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,49,3,0,88,94,3,0,0,0,0,0,0,0,0,0,240,3,2,0,192,29,3,0,0,0,0,0,168,39,6,0,0,227,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,21,0,0,1,0,0,0,0,0,0,0,0,0,30,25,0,0,124,13,0,0,0,0,0,0,0,0,0,0,180,27,0,0,32,34,0,0,146,16,0,0,248,19,0,0,72,13,0,0,56,10,0,0,96,10,0,0,224,174,145,0,0,6,0,0,128,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,88,94,3,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,200,79,3,0,0,0,0,0,168,39,6,0,0,227,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,21,0,0,1,0,0,0,0,0,0,0,0,0,10,60,0,0,210,41,0,0,0,0,0,0,0,0,0,0,180,27,0,0,70,27,0,0,146,16,0,0,248,19,0,0,72,13,0,0,56,10,0,0,96,10,0,0,224,174,145,0,0,6,0,0,128,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,248,208,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,216,110,1,0,0,0,0,0,72,188,4,0,240,185,2,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,16,0,0,0,0,0,0,0,0,0,0,66,30,0,0,12,32,0,0,0,0,0,0,0,0,0,0,104,3,0,0,154,35,0,0,84,14,0,0,82,8,0,0,90,15,0,0,118,13,0,0,48,60,0,0,232,173,145,0,0,2,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,188,3,0,152,250,3,0,0,0,0,0,0,0,0,0,232,233,7,0,120,163,3,0,0,0,0,0,40,161,4,0,192,152,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,9,2,2,0,0,0,0,0,0,0,0,0,0,0,164,48,0,0,98,27,0,0,0,0,0,0,0,0,0,0,94,27,0,0,152,51,0,0,4,11,0,0,42,17,0,0,184,7,0,0,0,0,0,0,216,46,0,0,0,0,0,0,0,6,0,0,224,0,0,0,240,0,0,0,3,0,0,0,4,0,0,0,152,250,3,0,0,0,0,0,0,0,0,0,0,0,0,0,232,233,7,0,136,217,3,0,0,0,0,0,40,161,4,0,192,152,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,9,2,2,0,0,0,0,0,0,0,0,0,0,0,56,0,0,0,52,2,0,0,0,0,0,0,0,0,0,0,94,27,0,0,250,52,0,0,4,11,0,0,42,17,0,0,184,7,0,0,0,0,0,0,216,46,0,0,0,0,0,0,0,6,0,0,224,0,0,0,240,0,0,0,3,0,0,0,4,0,0,0,224,217,3,0,96,240,3,0,0,0,0,0,0,0,0,0,64,164,6,0,120,212,3,0,0,0,0,0,192,154,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,8,0,0,2,0,0,0,0,0,0,16,0,8,0,0,0,0,0,0,0,0,0,0,36,42,0,0,194,13,0,0,0,0,0,0,0,0,0,0,128,41,0,0,64,41,0,0,106,6,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,224,225,3,0,96,240,3,0,0,0,0,0,0,0,0,0,64,164,6,0,240,221,3,0,0,0,0,0,192,154,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,8,0,0,2,0,0,0,0,0,0,16,0,8,0,0,0,0,0,0,0,0,0,0,62,26,0,0,118,35,0,0,0,0,0,0,0,0,0,0,128,41,0,0,64,41,0,0,106,6,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,224,232,3,0,96,240,3,0,0,0,0,0,0,0,0,0,64,164,6,0,24,229,3,0,0,0,0,0,232,234,3,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,8,0,0,2,0,0,0,0,0,0,16,0,8,0,0,0,0,0,0,0,0,0,0,40,54,0,0,114,20,0,0,0,0,0,0,0,0,0,0,128,41,0,0,64,41,0,0,20,18,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,96,240,3,0,0,0,0,0,0,0,0,0,0,0,0,0,232,233,7,0,24,238,3,0,0,0,0,0,232,234,3,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,8,0,0,2,0,0,0,0,0,0,16,0,8,0,0,0,0,0,0,0,0,0,0,38,40,0,0,132,10,0,0,0,0,0,0,0,0,0,0,128,41,0,0,64,41,0,0,20,18,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,112,184,5,0,16,16,6,0,0,0,0,0,0,0,0,0,200,190,7,0,248,145,5,0,0,0,0,0,152,54,6,0,200,12,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,17,1,0,0,0,0,0,0,0,0,0,0,0,50,35,0,0,134,0,0,0,0,0,0,0,0,0,0,0,198,62,0,0,80,12,0,0,222,10,0,0,230,1,0,0,44,6,0,0,194,15,0,0,0,0,0,0,48,177,145,0,0,2,0,0,128,1,0,0,0,1,0,0,4,0,0,0,3,0,0,0,160,245,8,0,0,0,0,0,0,0,0,0,0,0,0,0,160,234,7,0,224,116,8,0,0,0,0,0,168,95,8,0,240,185,2,0,56,59,8,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,3,0,8,0,0,0,0,0,0,0,0,0,0,88,52,0,0,104,38,0,0,0,0,0,0,0,0,0,0,18,28,0,0,246,12,0,0,64,8,0,0,254,15,0,0,6,2,0,0,252,3,0,0,24,13,0,0,144,35,149,0,0,2,0,0,240,0,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,51,7,0,0,0,0,0,0,0,0,0,0,0,0,0,144,139,6,0,160,7,7,0,0,0,0,0,0,148,7,0,48,178,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,2,0,0,0,0,0,0,0,0,0,0,96,0,0,0,200,42,0,0,0,0,0,0,0,0,0,0,116,30,0,0,216,16,0,0,170,13,0,0,222,19,0,0,52,15,0,0,0,0,0,0,36,38,0,0,0,0,0,0,0,2,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,44,8,0,0,0,0,0,0,0,0,0,0,0,0,0,144,139,6,0,224,195,7,0,0,0,0,0,0,148,7,0,48,178,3,0,120,101,7,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,2,0,0,0,0,0,0,0,0,0,0,128,59,0,0,190,10,0,0,0,0,0,0,0,0,0,0,116,30,0,0,216,16,0,0,170,13,0,0,222,19,0,0,52,15,0,0,0,0,0,0,36,38,0,0,0,0,0,0,0,2,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,18,3,0,184,20,3,0,0,0,0,0,0,0,0,0,216,194,1,0,64,16,3,0,0,0,0,0,56,72,3,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,8,0,0,2,0,0,0,0,0,0,16,0,0,8,0,0,0,0,0,0,0,0,0,16,5,0,0,208,7,0,0,0,0,0,0,0,0,0,0,20,42,0,0,158,21,0,0,46,5,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,184,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,216,194,1,0,184,19,3,0,0,0,0,0,56,72,3,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,8,0,0,2,0,0,0,0,0,0,16,0,0,8,0,0,0,0,0,0,0,0,0,168,22,0,0,140,13,0,0,0,0,0,0,0,0,0,0,20,42,0,0,24,58,0,0,46,5,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,56,228,5,0,0,0,0,0,0,0,0,0,0,0,0,0,96,159,4,0,184,223,5,0,0,0,0,0,72,226,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,236,16,0,0,212,38,0,0,0,0,0,0,0,0,0,0,70,34,0,0,202,42,0,0,146,5,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,24,248,6,0,32,18,7,0,0,0,0,0,0,0,0,0,96,159,4,0,184,244,6,0,0,0,0,0,168,251,6,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,198,34,0,0,76,21,0,0,0,0,0,0,0,0,0,0,70,34,0,0,216,40,0,0,88,16,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,144,7,7,0,32,18,7,0,0,0,0,0,0,0,0,0,96,159,4,0,248,0,7,0,0,0,0,0,168,251,6,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,194,32,0,0,250,25,0,0,0,0,0,0,0,0,0,0,70,34,0,0,216,40,0,0,6,13,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,128,240,6,0,32,18,7,0,0,0,0,0,0,0,0,0,96,159,4,0,56,238,6,0,0,0,0,0,64,43,6,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,156,13,0,0,36,45,0,0,0,0,0,0,0,0,0,0,70,34,0,0,216,40,0,0,88,16,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,120,230,6,0,32,18,7,0,0,0,0,0,0,0,0,0,96,159,4,0,208,225,6,0,0,0,0,0,72,226,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,8,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,56,62,0,0,166,27,0,0,0,0,0,0,0,0,0,0,70,34,0,0,240,28,0,0,6,13,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,168,221,6,0,32,18,7,0,0,0,0,0,0,0,0,0,96,159,4,0,136,216,6,0,0,0,0,0,144,211,6,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,8,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,172,13,0,0,80,36,0,0,0,0,0,0,0,0,0,0,70,34,0,0,106,26,0,0,88,16,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,32,18,7,0,0,0,0,0,0,0,0,0,0,0,0,0,96,159,4,0,192,12,7,0,0,0,0,0,72,226,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,8,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,122,25,0,0,226,36,0,0,0,0,0,0,0,0,0,0,70,34,0,0,216,40,0,0,6,13,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,0,5,6,0,32,18,7,0,0,0,0,0,0,0,0,0,96,159,4,0,240,255,5,0,0,0,0,0,240,249,5,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,8,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,56,4,0,0,102,27,0,0,0,0,0,0,0,0,0,0,70,34,0,0,22,28,0,0,88,16,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,80,207,6,0,32,18,7,0,0,0,0,0,0,0,0,0,96,159,4,0,192,203,6,0,0,0,0,0,192,154,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,8,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,208,54,0,0,188,20,0,0,0,0,0,0,0,0,0,0,70,34,0,0,240,28,0,0,88,16,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,24,182,6,0,32,18,7,0,0,0,0,0,0,0,0,0,96,159,4,0,160,176,6,0,0,0,0,0,168,170,6,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,8,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,240,53,0,0,246,28,0,0,0,0,0,0,0,0,0,0,70,34,0,0,216,40,0,0,32,10,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,32,194,6,0,32,18,7,0,0,0,0,0,0,0,0,0,96,159,4,0,120,188,6,0,0,0,0,0,192,154,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,8,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,86,58,0,0,192,21,0,0,0,0,0,0,0,0,0,0,70,34,0,0,216,40,0,0,72,2,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,120,200,6,0,32,18,7,0,0,0,0,0,0,0,0,0,96,159,4,0,40,197,6,0,0,0,0,0,72,226,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,8,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,206,56,0,0,178,19,0,0,0,0,0,0,0,0,0,0,70,34,0,0,240,28,0,0,246,14,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,160,234,5,0,32,18,7,0,0,0,0,0,0,0,0,0,96,159,4,0,64,231,5,0,0,0,0,0,192,154,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,53,8,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,160,21,0,0,138,11,0,0,0,0,0,0,0,0,0,0,70,34,0,0,156,49,0,0,162,15,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,80,16,6,0,32,18,7,0,0,0,0,0,0,0,0,0,96,159,4,0,112,11,6,0,0,0,0,0,184,234,7,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,8,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,174,48,0,0,52,11,0,0,0,0,0,0,0,0,0,0,70,34,0,0,124,17,0,0,88,16,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,16,88,6,0,32,18,7,0,0,0,0,0,0,0,0,0,136,80,6,0,104,74,6,0,0,0,0,0,184,68,6,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,8,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,78,22,0,0,214,11,0,0,0,0,0,0,0,0,0,0,186,23,0,0,66,51,0,0,88,16,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,72,56,6,0,32,18,7,0,0,0,0,0,0,0,0,0,160,135,3,0,72,47,6,0,0,0,0,0,192,154,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,8,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,178,52,0,0,124,38,0,0,0,0,0,0,0,0,0,0,70,34,0,0,240,28,0,0,88,16,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,40,173,7,0,120,136,1,0,0,0,0,0,0,0,0,0,224,56,7,0,48,127,7,0,0,0,0,0,104,77,7,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,246,47,0,0,206,26,0,0,0,0,0,0,0,0,0,0,86,51,0,0,114,62,0,0,8,7,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,240,210,5,0,120,136,1,0,0,0,0,0,0,0,0,0,96,159,4,0,88,206,5,0,0,0,0,0,72,226,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,8,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,248,14,0,0,128,30,0,0,0,0,0,0,0,0,0,0,86,51,0,0,218,33,0,0,60,0,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,64,219,5,0,120,136,1,0,0,0,0,0,0,0,0,0,96,159,4,0,120,215,5,0,0,0,0,0,72,226,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,8,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,36,33,0,0,148,4,0,0,0,0,0,0,0,0,0,0,86,51,0,0,218,33,0,0,60,0,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,48,192,5,0,0,0,0,0,0,0,0,0,0,0,0,0,160,234,7,0,136,119,6,0,0,0,0,0,40,223,1,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,46,19,0,0,144,13,0,0,0,0,0,0,0,0,0,0,6,21,0,0,12,42,0,0,210,0,0,0,94,4,0,0,188,3,0,0,42,8,0,0,162,53,0,0,64,176,145,0,0,2,0,0,240,0,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,118,4,0,0,0,0,0,0,0,0,0,0,0,0,0,232,167,7,0,8,68,6,0,0,0,0,0,104,223,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,204,34,0,0,92,15,0,0,0,0,0,0,0,0,0,0,196,5,0,0,250,9,0,0,58,13,0,0,96,8,0,0,168,9,0,0,138,5,0,0,48,19,0,0,0,0,0,0,8,0,0,0,64,1,0,0,200,0,0,0,4,0,0,0,3,0,0,0,240,247,7,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,64,173,6,0,152,42,5,0,168,95,8,0,240,185,2,0,176,112,2,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,4,0,0,0,0,0,0,3,0,0,1,0,0,0,0,0,0,0,0,0,186,24,0,0,208,30,0,0,0,0,0,0,0,0,0,0,238,18,0,0,0,0,0,0,220,5,0,0,34,14,0,0,46,0,0,0,4,2,0,0,80,19,0,0,160,176,145,0,32,0,0,0,64,1,0,0,0,1,0,0,4,0,0,0,3,0,0,0,112,163,5,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,232,129,5,0,0,0,0,0,144,84,8,0,128,194,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,3,11,0,1,0,0,0,0,0,0,0,0,0,0,6,60,0,0,216,4,0,0,0,0,0,0,0,0,0,0,90,22,0,0,134,2,0,0,220,8,0,0,224,17,0,0,188,8,0,0,2,1,0,0,74,29,0,0,0,0,0,0,0,16,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,48,92,1,0,88,113,1,0,0,0,0,0,0,0,0,0,104,221,5,0,200,85,1,0,0,0,0,0,144,84,8,0,208,135,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,2,11,0,0,2,0,0,0,0,0,0,0,0,0,162,3,0,0,208,45,0,0,0,0,0,0,0,0,0,0,244,4,0,0,158,53,0,0,238,18,0,0,46,7,0,0,246,17,0,0,0,0,0,0,176,18,0,0,0,0,0,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,113,1,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,88,101,1,0,0,0,0,0,144,84,8,0,208,135,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,2,11,0,0,2,0,0,0,0,0,0,0,0,0,194,36,0,0,166,19,0,0,0,0,0,0,0,0,0,0,244,4,0,0,158,53,0,0,238,18,0,0,46,7,0,0,246,17,0,0,0,0,0,0,176,18,0,0,0,0,0,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,41,5,0,0,0,0,0,0,0,0,0,0,0,0,0,64,171,7,0,160,232,4,0,0,0,0,0,40,161,4,0,248,206,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,3,2,0,64,0,0,0,0,0,0,0,0,0,0,0,10,0,0,88,14,0,0,0,0,0,0,0,0,0,0,236,61,0,0,116,45,0,0,54,6,0,0,34,3,0,0,144,2,0,0,0,0,0,0,0,56,0,0,0,0,0,0,0,24,0,0,224,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,80,43,6,0,0,0,0,0,0,0,0,0,0,0,0,0,56,172,6,0,152,108,5,0,0,0,0,0,232,163,8,0,152,88,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,13,0,0,2,0,0,0,0,0,0,0,0,0,42,3,0,0,154,14,0,0,0,0,0,0,0,0,0,0,56,14,0,0,228,58,0,0,60,17,0,0,160,16,0,0,104,12,0,0,54,1,0,0,166,39,0,0,0,0,0,0,0,20,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,72,2,0,0,0,0,0,0,0,0,0,0,0,0,0,168,163,7,0,120,115,1,0,0,0,0,0,192,34,1,0,208,165,3,0,48,224,8,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,1,21,0,0,2,0,0,0,0,0,0,0,0,0,124,50,0,0,224,24,0,0,0,0,0,0,0,0,0,0,152,36,0,0,224,9,0,0,92,10,0,0,198,1,0,0,134,15,0,0,0,0,0,0,236,14,0,0,240,210,148,0,0,128,0,0,128,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,144,246,1,0,16,31,2,0,0,0,0,0,0,0,0,0,104,221,5,0,224,236,1,0,0,0,0,0,144,84,8,0,208,135,3,0,208,224,1,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,2,11,0,8,0,0,0,0,0,0,0,0,0,0,104,32,0,0,222,43,0,0,0,0,0,0,0,0,0,0,64,29,0,0,84,39,0,0,44,9,0,0,46,7,0,0,246,17,0,0,0,0,0,0,176,18,0,0,0,0,0,0,0,32,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,173,6,0,0,0,0,0,0,0,0,0,0,0,0,0,168,163,7,0,80,83,6,0,0,0,0,0,184,191,7,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,131,0,0,0,2,0,0,0,0,0,0,10,0,16,0,0,0,0,0,0,0,0,0,0,44,24,0,0,14,17,0,0,0,0,0,0,0,0,0,0,236,22,0,0,24,19,0,0,148,19,0,0,8,1,0,0,76,2,0,0,190,17,0,0,4,30,0,0,104,157,215,0,0,4,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,253,5,0,232,173,6,0,0,0,0,0,0,0,0,0,168,163,7,0,128,208,5,0,0,0,0,0,184,191,7,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,147,0,0,0,2,0,0,0,0,0,0,10,0,16,0,0,0,0,0,0,0,0,0,0,16,35,0,0,182,10,0,0,0,0,0,0,0,0,0,0,236,22,0,0,24,19,0,0,148,19,0,0,8,1,0,0,76,2,0,0,190,17,0,0,4,30,0,0,104,157,215,0,0,4,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,239,2,0,0,0,0,0,0,0,0,0,0,0,0,0,64,164,6,0,208,237,2,0,0,0,0,0,56,72,3,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,8,0,0,2,0,0,0,0,0,0,16,1,0,0,0,0,0,0,0,0,0,0,0,208,38,0,0,104,17,0,0,0,0,0,0,0,0,0,0,160,8,0,0,70,2,0,0,90,12,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,200,182,3,0,104,180,3,0,0,0,0,0,0,0,0,0,160,135,3,0,128,177,3,0,0,0,0,0,192,154,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,0,0,0,2,0,0,0,0,0,0,16,1,0,0,0,0,0,0,0,0,0,0,0,96,43,0,0,98,19,0,0,0,0,0,0,0,0,0,0,46,12,0,0,128,5,0,0,98,10,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,104,219,2,0,104,180,3,0,0,0,0,0,0,0,0,0,160,135,3,0,216,216,2,0,0,0,0,0,192,154,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,0,0,0,2,0,0,0,0,0,0,16,1,0,0,0,0,0,0,0,0,0,0,0,232,56,0,0,80,32,0,0,0,0,0,0,0,0,0,0,46,12,0,0,202,33,0,0,190,18,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,104,180,3,0,0,0,0,0,0,0,0,0,0,0,0,0,160,135,3,0,88,224,2,0,0,0,0,0,72,221,2,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,2,0,0,0,0,0,0,16,1,0,0,0,0,0,0,0,0,0,0,0,30,17,0,0,162,43,0,0,0,0,0,0,0,0,0,0,46,12,0,0,128,5,0,0,142,14,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,136,192,4,0,16,8,5,0,0,0,0,0,0,0,0,0,184,168,7,0,104,160,4,0,0,0,0,0,168,138,8,0,248,135,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,19,0,0,8,0,0,0,0,0,0,0,0,0,34,38,0,0,22,27,0,0,0,0,0,0,0,0,0,0,90,27,0,0,90,47,0,0,132,17,0,0,216,4,0,0,96,1,0,0,0,0,0,0,10,34,0,0,0,0,0,0,0,4,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,16,130,4,0,16,8,5,0,0,0,0,0,0,0,0,0,184,168,7,0,64,103,4,0,0,0,0,0,176,237,2,0,248,135,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,19,0,0,8,0,0,0,0,0,0,0,0,0,162,16,0,0,58,12,0,0,0,0,0,0,0,0,0,0,90,27,0,0,90,47,0,0,132,17,0,0,216,4,0,0,96,1,0,0,0,0,0,0,10,34,0,0,0,0,0,0,0,4,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,16,8,5,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,80,228,4,0,0,0,0,0,176,237,2,0,248,135,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,19,0,0,8,0,0,0,0,0,0,0,0,0,214,18,0,0,236,47,0,0,0,0,0,0,0,0,0,0,90,27,0,0,100,13,0,0,132,17,0,0,216,4,0,0,96,1,0,0,0,0,0,0,10,34,0,0,0,0,0,0,0,4,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,128,177,4,0,64,145,4,0,0,0,0,0,0,0,0,0,184,168,7,0,32,91,4,0,0,0,0,0,168,95,8,0,8,64,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,3,0,8,0,0,0,0,0,0,0,0,0,0,158,15,0,0,36,6,0,0,0,0,0,0,0,0,0,0,176,49,0,0,6,54,0,0,76,10,0,0,156,9,0,0,198,15,0,0,232,8,0,0,42,6,0,0,216,176,145,0,0,4,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,184,5,0,64,145,4,0,0,0,0,0,0,0,0,0,184,168,7,0,120,145,5,0,0,0,0,0,168,95,8,0,8,64,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,3,0,8,0,0,0,0,0,0,0,0,0,0,8,11,0,0,30,9,0,0,0,0,0,0,0,0,0,0,94,40,0,0,160,12,0,0,230,15,0,0,64,11,0,0,232,18,0,0,0,0,0,0,64,19,0,0,0,0,0,0,0,4,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,145,4,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,88,15,6,0,0,0,0,0,168,95,8,0,8,64,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,3,0,8,0,0,0,0,0,0,0,0,0,0,48,26,0,0,140,44,0,0,0,0,0,0,0,0,0,0,94,40,0,0,160,12,0,0,230,15,0,0,64,11,0,0,232,18,0,0,0,0,0,0,64,19,0,0,0,0,0,0,0,4,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,106,4,0,72,164,4,0,0,0,0,0,0,0,0,0,144,47,2,0,192,79,4,0,0,0,0,0,72,187,4,0,200,156,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,14,0,8,0,0,0,0,0,0,0,0,0,0,80,18,0,0,230,17,0,0,0,0,0,0,0,0,0,0,62,43,0,0,188,30,0,0,126,3,0,0,236,10,0,0,222,18,0,0,0,0,0,0,238,10,0,0,0,0,0,0,0,16,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,53,4,0,72,164,4,0,0,0,0,0,0,0,0,0,144,47,2,0,8,26,4,0,0,0,0,0,96,251,3,0,200,156,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,14,0,8,0,0,0,0,0,0,0,0,0,0,110,31,0,0,20,5,0,0,0,0,0,0,0,0,0,0,62,43,0,0,188,30,0,0,126,3,0,0,236,10,0,0,222,18,0,0,0,0,0,0,238,10,0,0,0,0,0,0,0,16,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,164,4,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,152,133,4,0,0,0,0,0,72,187,4,0,200,156,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,14,0,8,0,0,0,0,0,0,0,0,0,0,130,29,0,0,152,18,0,0,0,0,0,0,0,0,0,0,62,43,0,0,188,30,0,0,126,3,0,0,236,10,0,0,222,18,0,0,0,0,0,0,238,10,0,0,0,0,0,0,0,16,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,224,1,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,240,41,1,0,0,0,0,0,160,161,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,40,18,0,0,252,35,0,0,0,0,0,0,0,0,0,0,32,15,0,0,0,0,0,0,154,6,0,0,22,7,0,0,230,18,0,0,0,0,0,0,110,45,0,0,0,0,0,0,0,8,0,0,128,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,200,154,4,0,0,0,0,0,0,0,0,0,0,0,0,0,104,174,7,0,232,74,6,0,0,0,0,0,200,227,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,136,1,0,0,246,10,0,0,0,0,0,0,0,0,0,0,222,39,0,0,60,11,0,0,76,1,0,0,22,7,0,0,230,18,0,0,0,0,0,0,110,45,0,0,0,0,0,0,0,4,0,0,128,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,224,45,1,0,184,231,1,0,0,0,0,0,0,0,0,0,64,171,7,0,240,234,8,0,0,0,0,0,248,39,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,190,55,0,0,172,28,0,0,0,0,0,0,0,0,0,0,74,52,0,0,86,21,0,0,122,18,0,0,182,14,0,0,208,10,0,0,210,13,0,0,106,45,0,0,176,175,145,0,0,8,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,231,1,0,0,0,0,0,0,0,0,0,0,0,0,0,64,171,7,0,176,133,1,0,0,0,0,0,248,39,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,206,25,0,0,96,32,0,0,0,0,0,0,0,0,0,0,74,52,0,0,86,21,0,0,122,18,0,0,182,14,0,0,208,10,0,0,210,13,0,0,106,45,0,0,176,175,145,0,0,8,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,100,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,96,249,7,0,0,0,0,0,16,196,7,0,240,185,2,0,72,148,7,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,8,0,0,0,0,0,0,0,0,0,0,188,17,0,0,188,34,0,0,0,0,0,0,0,0,0,0,14,12,0,0,120,51,0,0,54,17,0,0,56,15,0,0,12,17,0,0,0,0,0,0,224,13,0,0,0,0,0,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,32,141,1,0,80,160,1,0,0,0,0,0,0,0,0,0,144,47,2,0,112,126,1,0,0,0,0,0,144,84,8,0,208,135,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,2,11,1,0,0,0,0,0,0,0,0,0,0,0,16,26,0,0,228,17,0,0,0,0,0,0,0,0,0,0,98,31,0,0,182,60,0,0,194,4,0,0,46,7,0,0,246,17,0,0,0,0,0,0,176,18,0,0,0,0,0,0,0,32,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,160,1,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,64,150,1,0,0,0,0,0,168,183,7,0,208,135,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,2,11,1,0,0,0,0,0,0,0,0,0,0,0,2,42,0,0,100,10,0,0,0,0,0,0,0,0,0,0,98,31,0,0,46,43,0,0,194,4,0,0,46,7,0,0,246,17,0,0,0,0,0,0,176,18,0,0,0,0,0,0,0,32,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,21,8,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,240,17,8,0,48,25,8,0,0,227,2,0,0,227,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,1,21,0,0,1,0,0,0,0,0,0,0,0,0,136,52,0,0,38,47,0,0,0,0,0,0,0,0,0,0,100,61,0,0,180,56,0,0,196,11,0,0,248,19,0,0,72,13,0,0,230,0,0,0,96,10,0,0,224,174,145,0,0,2,0,0,224,0,0,0,128,1,0,0,3,0,0,0,4,0,0,0,8,207,8,0,56,45,2,0,0,0,0,0,0,0,0,0,200,190,7,0,176,142,8,0,0,0,0,0,176,237,2,0,176,109,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,19,0,0,1,0,0,0,0,0,0,0,0,0,28,42,0,0,64,29,0,0,0,0,0,0,0,0,0,0,132,43,0,0,110,39,0,0,140,13,0,0,204,7,0,0,38,6,0,0,242,19,0,0,142,27,0,0,72,173,145,0,0,4,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,0,189,1,0,56,45,2,0,0,0,0,0,0,0,0,0,200,190,7,0,128,91,1,0,0,0,0,0,176,237,2,0,176,109,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,19,0,0,1,0,0,0,0,0,0,0,0,0,78,52,0,0,62,38,0,0,0,0,0,0,0,0,0,0,132,43,0,0,110,39,0,0,140,13,0,0,204,7,0,0,38,6,0,0,242,19,0,0,142,27,0,0,72,173,145,0,0,4,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,128,218,4,0,0,0,0,0,0,0,0,0,0,0,0,0,160,234,7,0,240,87,6,0,0,0,0,0,136,236,4,0,240,185,2,0,96,239,2,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,106,1,0,0,202,39,0,0,0,0,0,0,0,0,0,0,240,52,0,0,96,33,0,0,42,15,0,0,52,7,0,0,84,9,0,0,38,16,0,0,60,20,0,0,96,175,145,0,16,0,0,0,232,0,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,66,5,0,0,0,0,0,0,0,0,0,0,0,0,0,232,167,7,0,160,104,6,0,0,0,0,0,152,248,4,0,160,201,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,1,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,72,0,0,0,8,24,0,0,0,0,0,0,0,0,0,0,18,56,0,0,198,29,0,0,102,5,0,0,44,18,0,0,234,15,0,0,250,18,0,0,102,10,0,0,208,175,145,0,32,0,0,0,236,0,0,0,16,1,0,0,3,0,0,0,4,0,0,0,232,174,1,0,128,210,1,0,0,0,0,0,0,0,0,0,184,168,7,0,128,167,1,0,0,0,0,0,128,161,4,0,208,135,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,2,11,1,0,0,0,0,0,0,0,0,0,0,0,164,20,0,0,110,36,0,0,0,0,0,0,0,0,0,0,234,51,0,0,10,25,0,0,242,14,0,0,46,7,0,0,246,17,0,0,0,0,0,0,176,18,0,0,0,0,0,0,0,32,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,189,1,0,128,210,1,0,0,0,0,0,0,0,0,0,184,168,7,0,72,182,1,0,0,0,0,0,144,84,8,0,208,135,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,2,11,1,0,0,0,0,0,0,0,0,0,0,0,228,51,0,0,156,37,0,0,0,0,0,0,0,0,0,0,234,51,0,0,100,18,0,0,242,14,0,0,46,7,0,0,246,17,0,0,0,0,0,0,176,18,0,0,0,0,0,0,0,32,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,210,1,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,112,198,1,0,0,0,0,0,168,183,7,0,208,135,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0])
.concat([2,0,0,0,0,0,2,11,1,0,0,0,0,0,0,0,0,0,0,0,92,24,0,0,96,29,0,0,0,0,0,0,0,0,0,0,234,51,0,0,164,22,0,0,242,14,0,0,46,7,0,0,246,17,0,0,0,0,0,0,176,18,0,0,0,0,0,0,0,32,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,189,7,0,0,0,0,0,0,0,0,0,0,0,0,0,184,230,7,0,176,141,7,0,0,0,0,0,0,188,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,2,0,0,0,0,0,0,0,0,0,0,46,41,0,0,192,17,0,0,0,0,0,0,0,0,0,0,156,30,0,0,0,0,0,0,250,3,0,0,70,9,0,0,40,18,0,0,88,15,0,0,46,51,0,0,224,173,145,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,24,95,7,0,104,189,7,0,0,0,0,0,0,0,0,0,144,139,6,0,64,46,7,0,0,0,0,0,0,188,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,10,0,2,0,0,0,0,0,0,0,0,0,0,214,45,0,0,0,43,0,0,0,0,0,0,0,0,0,0,156,30,0,0,0,0,0,0,250,3,0,0,70,9,0,0,40,18,0,0,88,15,0,0,46,51,0,0,224,173,145,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,208,222,2,0,16,254,3,0,0,0,0,0,0,0,0,0,240,3,2,0,112,76,2,0,0,0,0,0,208,210,4,0,144,172,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,10,0,8,0,0,0,0,0,0,0,0,0,0,162,27,0,0,28,35,0,0,0,0,0,0,0,0,0,0,130,59,0,0,136,54,0,0,134,0,0,0,132,15,0,0,10,2,0,0,80,6,0,0,38,37,0,0,168,174,145,0,1,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,254,3,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,248,53,6,0,0,0,0,0,208,210,4,0,144,172,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,8,0,0,0,0,0,0,0,0,0,0,148,0,0,0,60,11,0,0,0,0,0,0,0,0,0,0,130,59,0,0,136,54,0,0,134,0,0,0,132,15,0,0,10,2,0,0,80,6,0,0,38,37,0,0,168,174,145,0,1,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,116,5,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,64,85,5,0,0,0,0,0,112,55,5,0,152,8,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,4,17,0,0,1,0,0,0,0,0,0,0,0,0,104,62,0,0,48,14,0,0,0,0,0,0,0,0,0,0,148,21,0,0,118,5,0,0,106,19,0,0,80,0,0,0,228,1,0,0,44,8,0,0,0,0,0,0,32,177,145,0,0,2,0,0,128,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,120,60,2,0,152,230,2,0,0,0,0,0,0,0,0,0,184,168,7,0,24,202,1,0,120,161,2,0,128,161,4,0,168,196,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,5,11,2,0,0,0,0,0,0,0,0,0,0,0,22,43,0,0,40,45,0,0,0,0,0,0,0,0,0,0,184,15,0,0,84,19,0,0,36,5,0,0,178,11,0,0,82,0,0,0,238,10,0,0,188,1,0,0,0,0,0,0,0,16,0,0,224,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,160,25,1,0,152,230,2,0,0,0,0,0,0,0,0,0,184,168,7,0,40,217,8,0,120,161,2,0,144,84,8,0,168,196,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,5,11,2,0,0,0,0,0,0,0,0,0,0,0,116,52,0,0,174,28,0,0,0,0,0,0,0,0,0,0,184,15,0,0,84,19,0,0,36,5,0,0,178,11,0,0,82,0,0,0,238,10,0,0,188,1,0,0,0,0,0,0,0,16,0,0,224,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,152,230,2,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,112,0,6,0,120,161,2,0,168,183,7,0,168,196,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,5,11,2,0,0,0,0,0,0,0,0,0,0,0,8,50,0,0,104,8,0,0,0,0,0,0,0,0,0,0,184,15,0,0,84,19,0,0,36,5,0,0,178,11,0,0,82,0,0,0,238,10,0,0,188,1,0,0,0,0,0,0,0,16,0,0,224,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,176,6,3,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,48,240,2,0,0,0,0,0,200,227,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,0,2,0,0,0,0,0,0,0,0,0,18,7,0,0,164,30,0,0,0,0,0,0,0,0,0,0,32,15,0,0,0,0,0,0,98,2,0,0,22,7,0,0,230,18,0,0,0,0,0,0,110,45,0,0,0,0,0,0,0,8,0,0,128,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,88,218,8,0,0,0,0,0,200,240,5,0,0,0,0,0,104,129,6,0,72,209,8,0,0,0,0,0,72,174,3,0,88,0,3,0,192,204,8,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,4,0,0,0,1,0,0,8,8,0,0,0,0,0,0,0,0,0,0,0,8,61,0,0,116,3,0,0,0,0,0,0,0,0,0,0,104,35,0,0,128,7,0,0,10,8,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,192,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,6,4,0,0,0,0,0,0,0,0,0,0,0,0,0,216,194,1,0,128,3,4,0,0,0,0,0,0,40,1,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,8,0,0,2,0,0,0,0,0,0,16,1,0,0,0,0,0,0,0,0,0,0,0,22,35,0,0,42,20,0,0,0,0,0,0,0,0,0,0,56,1,0,0,140,6,0,0,170,18,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,160,157,4,0,0,0,0,0,0,0,0,0,0,0,0,0,64,164,6,0,16,75,6,0,0,0,0,0,152,196,7,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,180,15,0,0,218,44,0,0,0,0,0,0,0,0,0,0,164,47,0,0,12,50,0,0,38,15,0,0,58,15,0,0,150,1,0,0,100,13,0,0,184,16,0,0,48,175,145,0,0,4,0,0,240,0,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,36,5,0,0,0,0,0,0,0,0,0,0,0,0,0,64,164,6,0,216,6,5,0,72,150,4,0,224,226,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,34,49,0,0,140,39,0,0,0,0,0,0,0,0,0,0,36,31,0,0,0,0,0,0,200,16,0,0,128,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,24,156,3,0,0,0,0,0,0,0,0,0,0,0,0,0,216,194,1,0,176,153,3,0,0,0,0,0,72,152,3,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,8,0,0,2,0,0,0,0,0,0,16,1,0,0,0,0,0,0,0,0,0,0,0,210,53,0,0,88,33,0,0,0,0,0,0,0,0,0,0,124,45,0,0,126,52,0,0,164,10,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,88,112,5,0,0,0,0,0,0,0,0,0,0,0,0,0,232,167,7,0,216,110,6,0,0,0,0,0,0,223,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,100,29,0,0,60,10,0,0,0,0,0,0,0,0,0,0,136,37,0,0,248,47,0,0,10,11,0,0,244,15,0,0,178,2,0,0,134,9,0,0,242,1,0,0,160,134,148,0,0,1,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,114,1,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,104,223,8,0,0,0,0,0,32,157,8,0,80,164,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,0,10,0,16,0,0,0,0,0,0,0,0,0,0,212,47,0,0,78,26,0,0,0,0,0,0,0,0,0,0,102,6,0,0,112,57,0,0,24,5,0,0,214,9,0,0,52,19,0,0,110,17,0,0,0,0,0,0,0,0,0,0,0,2,0,0,240,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,120,160,5,0,0,0,0,0,0,0,0,0,0,0,0,0,168,163,7,0,136,98,5,0,72,150,4,0,216,67,5,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,10,0,16,0,0,0,0,0,0,0,0,0,0,196,12,0,0,38,41,0,0,0,0,0,0,0,0,0,0,36,31,0,0,0,0,0,0,200,16,0,0,128,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,221,2,0,120,160,5,0,0,0,0,0,0,0,0,0,168,163,7,0,80,118,1,0,0,0,0,0,216,67,5,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,10,0,16,0,0,0,0,0,0,0,0,0,0,108,13,0,0,18,24,0,0,0,0,0,0,0,0,0,0,244,41,0,0,82,53,0,0,138,1,0,0,0,2,0,0,22,3,0,0,118,1,0,0,152,14,0,0,136,174,145,0,0,4,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,88,227,1,0,0,0,0,0,0,0,0,0,0,0,0,0,184,230,7,0,16,201,1,0,0,0,0,0,216,164,4,0,80,164,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,16,0,0,0,0,0,0,0,0,0,0,236,49,0,0,176,22,0,0,0,0,0,0,0,0,0,0,244,56,0,0,28,17,0,0,48,5,0,0,88,18,0,0,228,5,0,0,4,6,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,182,6,0,192,138,5,0,0,0,0,0,0,0,0,0,64,171,7,0,8,139,6,0,0,0,0,0,192,223,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,20,0,8,0,0,0,0,0,0,0,0,0,0,242,33,0,0,0,16,0,0,0,0,0,0,0,0,0,0,104,45,0,0,178,24,0,0,56,13,0,0,140,9,0,0,82,7,0,0,0,0,0,0,118,31,0,0,0,0,0,0,0,1,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,5,6,0,192,138,5,0,0,0,0,0,0,0,0,0,64,171,7,0,168,215,5,0,0,0,0,0,192,223,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,20,0,8,0,0,0,0,0,0,0,0,0,0,182,16,0,0,94,15,0,0,0,0,0,0,0,0,0,0,104,45,0,0,178,24,0,0,56,13,0,0,140,9,0,0,82,7,0,0,0,0,0,0,118,31,0,0,0,0,0,0,0,1,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,94,6,0,192,138,5,0,0,0,0,0,0,0,0,0,64,171,7,0,152,47,6,0,0,0,0,0,192,223,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,20,0,8,0,0,0,0,0,0,0,0,0,0,158,29,0,0,0,27,0,0,0,0,0,0,0,0,0,0,104,45,0,0,178,24,0,0,56,13,0,0,140,9,0,0,82,7,0,0,0,0,0,0,118,31,0,0,0,0,0,0,0,1,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,31,3,0,168,54,8,0,0,0,0,0,0,0,0,0,200,190,7,0,88,114,2,0,0,0,0,0,168,95,8,0,8,2,4,0,232,250,1,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,3,0,0,8,0,0,0,0,0,0,0,0,0,210,36,0,0,32,19,0,0,0,0,0,0,0,0,0,0,78,20,0,0,148,54,0,0,162,9,0,0,156,9,0,0,198,15,0,0,232,8,0,0,42,6,0,0,216,176,145,0,0,4,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,134,1,0,48,158,1,0,0,0,0,0,0,0,0,0,104,221,5,0,48,121,1,0,0,0,0,0,152,54,6,0,104,93,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,17,0,64,0,0,0,0,0,0,0,0,0,0,190,39,0,0,248,25,0,0,0,0,0,0,0,0,0,0,198,62,0,0,34,31,0,0,188,11,0,0,230,1,0,0,44,6,0,0,194,15,0,0,0,0,0,0,48,177,145,0,0,2,0,0,128,1,0,0,0,1,0,0,4,0,0,0,3,0,0,0,48,158,1,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,32,146,1,0,0,0,0,0,152,54,6,0,104,93,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,3,17,0,64,0,0,0,0,0,0,0,0,0,0,120,23,0,0,84,41,0,0,0,0,0,0,0,0,0,0,198,62,0,0,34,31,0,0,188,11,0,0,230,1,0,0,44,6,0,0,194,15,0,0,0,0,0,0,48,177,145,0,0,2,0,0,128,1,0,0,0,1,0,0,4,0,0,0,3,0,0,0,16,173,1,0,200,186,1,0,0,0,0,0,0,0,0,0,96,135,2,0,224,164,1,0,240,56,5,0,152,54,6,0,168,38,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,5,17,0,64,0,0,0,0,0,0,0,0,0,0,50,20,0,0,180,27,0,0,0,0,0,0,0,0,0,0,50,9,0,0,64,45,0,0,86,0,0,0,218,2,0,0,114,1,0,0,166,3,0,0,116,50,0,0,8,211,148,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,200,186,1,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,112,179,1,0,240,56,5,0,152,54,6,0,168,38,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,5,17,0,64,0,0,0,0,0,0,0,0,0,0,140,29,0,0,8,9,0,0,0,0,0,0,0,0,0,0,50,9,0,0,64,45,0,0,86,0,0,0,218,2,0,0,114,1,0,0,166,3,0,0,116,50,0,0,8,211,148,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,120,94,8,0,168,110,8,0,0,0,0,0,0,0,0,0,104,221,5,0,240,86,8,0,0,0,0,0,144,84,8,0,208,135,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,2,11,0,0,8,0,0,0,0,0,0,0,0,0,214,13,0,0,52,47,0,0,0,0,0,0,0,0,0,0,12,1,0,0,102,40,0,0,86,18,0,0,46,7,0,0,246,17,0,0,0,0,0,0,176,18,0,0,0,0,0,0,0,32,0,0,224,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,16,21,3,0,168,180,7,0,0,0,0,0,0,0,0,0,104,174,7,0,72,109,2,0,0,0,0,0,168,95,8,0,32,247,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,0,3,0,64,0,0,0,0,0,0,0,0,0,0,162,19,0,0,80,9,0,0,0,0,0,0,0,0,0,0,208,43,0,0,6,27,0,0,160,17,0,0,14,19,0,0,14,10,0,0,172,8,0,0,148,27,0,0,96,176,145,0,0,1,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,246,1,0,168,180,7,0,0,0,0,0,0,0,0,0,104,174,7,0,24,150,1,0,0,0,0,0,168,95,8,0,32,247,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,3,0,64,0,0,0,0,0,0,0,0,0,0,192,16,0,0,60,7,0,0,0,0,0,0,0,0,0,0,236,0,0,0,252,2,0,0,160,17,0,0,14,19,0,0,14,10,0,0,172,8,0,0,148,27,0,0,96,176,145,0,0,1,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,180,7,0,0,0,0,0,0,0,0,0,0,0,0,0,104,174,7,0,96,165,6,0,0,0,0,0,168,95,8,0,32,247,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,4,0,0,0,0,0,0,3,0,64,0,0,0,0,0,0,0,0,0,0,234,30,0,0,62,20,0,0,0,0,0,0,0,0,0,0,208,43,0,0,6,27,0,0,160,17,0,0,14,19,0,0,14,10,0,0,172,8,0,0,148,27,0,0,96,176,145,0,0,1,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,18,1,0,0,0,0,0,72,172,6,0,0,0,0,0,104,221,5,0,32,97,6,0,0,0,0,0,128,145,4,0,208,9,3,0,56,50,6,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,64,1,133,0,0,2,0,0,0,0,0,0,0,0,0,148,44,0,0,156,3,0,0,0,0,0,0,0,0,0,0,200,29,0,0,126,48,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,185,2,0,0,182,7,0,0,0,0,0,0,0,0,0,240,3,2,0,16,159,4,0,0,0,0,0,64,134,3,0,16,128,3,0,160,55,2,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,1,4,2,0,0,0,0,0,0,0,0,0,0,0,92,0,0,0,84,10,0,0,0,0,0,0,0,0,0,0,34,1,0,0,232,25,0,0,156,6,0,0,66,15,0,0,180,9,0,0,16,18,0,0,72,26,0,0,32,146,215,0,0,8,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,176,217,2,0,56,189,3,0,0,0,0,0,0,0,0,0,0,46,3,0,96,73,2,0,0,0,0,0,152,190,4,0,192,167,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,10,0,16,0,0,0,0,0,0,0,0,0,0,246,44,0,0,12,45,0,0,0,0,0,0,0,0,0,0,234,32,0,0,222,4,0,0,28,10,0,0,122,2,0,0,166,18,0,0,108,16,0,0,180,44,0,0,88,174,145,0,0,32,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,189,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,240,43,6,0,0,0,0,0,152,190,4,0,192,167,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,16,0,0,0,0,0,0,0,0,0,0,114,57,0,0,132,33,0,0,0,0,0,0,0,0,0,0,234,32,0,0,244,38,0,0,238,3,0,0,122,2,0,0,166,18,0,0,108,16,0,0,180,44,0,0,88,174,145,0,0,32,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,75,8,0,88,180,1,0,0,0,0,0,0,0,0,0,32,127,5,0,40,23,8,0,0,0,0,0,0,193,8,0,240,85,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,19,0,16,0,0,0,0,0,0,0,0,0,0,184,51,0,0,90,17,0,0,0,0,0,0,0,0,0,0,108,48,0,0,228,33,0,0,224,0,0,0,32,4,0,0,120,0,0,0,54,14,0,0,62,2,0,0,8,173,145,0,0,4,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,208,201,8,0,88,180,1,0,0,0,0,0,0,0,0,0,32,127,5,0,48,137,8,0,0,0,0,0,0,193,8,0,240,85,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,19,0,16,0,0,0,0,0,0,0,0,0,0,88,20,0,0,230,41,0,0,0,0,0,0,0,0,0,0,108,48,0,0,228,33,0,0,114,14,0,0,32,4,0,0,120,0,0,0,54,14,0,0,62,2,0,0,8,173,145,0,0,4,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,144,113,2,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,224,101,2,0,0,0,0,0,104,199,4,0,0,227,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,1,21,0,0,1,0,0,0,0,0,0,0,0,0,6,3,0,0,82,11,0,0,0,0,0,0,0,0,0,0,128,33,0,0,4,46,0,0,76,0,0,0,196,7,0,0,72,13,0,0,56,10,0,0,96,10,0,0,224,174,145,0,0,18,0,0,224,0,0,0,128,1,0,0,3,0,0,0,4,0,0,0,48,107,7,0,192,108,8,0,0,0,0,0,0,0,0,0,104,174,7,0,248,56,7,0,0,0,0,0,192,223,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,0,20,0,0,4,0,0,0,0,0,0,0,0,0,46,0,0,0,190,14,0,0,0,0,0,0,0,0,0,0,192,37,0,0,14,18,0,0,176,10,0,0,108,10,0,0,174,4,0,0,0,0,0,0,126,22,0,0,0,0,0,0,0,8,0,0,240,0,0,0,128,1,0,0,3,0,0,0,4,0,0,0,128,202,7,0,192,108,8,0,0,0,0,0,0,0,0,0,184,168,7,0,72,153,7,0,0,0,0,0,192,223,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,0,20,0,0,4,0,0,0,0,0,0,0,0,0,142,43,0,0,148,38,0,0,0,0,0,0,0,0,0,0,192,37,0,0,14,18,0,0,176,10,0,0,108,10,0,0,174,4,0,0,0,0,0,0,126,22,0,0,0,0,0,0,0,8,0,0,240,0,0,0,128,1,0,0,3,0,0,0,4,0,0,0,192,108,8,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,16,0,8,0,0,0,0,0,192,223,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,0,20,0,0,4,0,0,0,0,0,0,0,0,0,218,34,0,0,238,29,0,0,0,0,0,0,0,0,0,0,192,37,0,0,14,18,0,0,176,10,0,0,108,10,0,0,174,4,0,0,0,0,0,0,126,22,0,0,0,0,0,0,0,8,0,0,240,0,0,0,128,1,0,0,3,0,0,0,4,0,0,0,216,172,6,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,72,82,6,0,0,0,0,0,168,39,6,0,80,164,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,1,0,0,0,0,0,0,0,0,0,0,0,232,11,0,0,160,25,0,0,0,0,0,0,0,0,0,0,244,56,0,0,242,15,0,0,224,7,0,0,214,9,0,0,18,6,0,0,186,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,117,8,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,64,111,8,0,0,0,0,0,168,39,6,0,80,164,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,0,10,2,0,0,0,0,0,0,0,0,0,0,0,210,56,0,0,202,46,0,0,0,0,0,0,0,0,0,0,244,56,0,0,106,18,0,0,8,6,0,0,56,12,0,0,212,3,0,0,210,14,0,0,0,0,0,0,0,0,0,0,0,4,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,168,250,3,0,64,53,4,0,0,0,0,0,0,0,0,0,104,221,5,0,168,217,3,0,0,0,0,0,192,154,4,0,8,153,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,3,0,0,0,0,0,6,2,0,8,0,0,0,0,0,0,0,0,0,0,202,50,0,0,226,15,0,0,0,0,0,0,0,0,0,0,204,36,0,0,140,25,0,0,150,8,0,0,164,2,0,0,20,14,0,0,0,0,0,0,106,0,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,53,4,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,40,25,4,0,0,0,0,0,40,161,4,0,8,153,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,64,0,6,2,0,8,0,0,0,0,0,0,0,0,0,0,148,42,0,0,138,26,0,0,0,0,0,0,0,0,0,0,204,36,0,0,140,25,0,0,218,12,0,0,164,2,0,0,20,14,0,0,0,0,0,0,106,0,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,246,5,0,0,0,0,0,72,172,6,0,0,0,0,0,144,139,6,0,248,236,5,0,0,0,0,0,128,145,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,0,8,0,0,1,0,0,0,0,0,0,0,200,25,0,0,92,30,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,248,2,0,0,176,6,0,0,78,14,0,0,236,13,0,0,42,2,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,172,6,0,0,0,0,0,72,172,6,0,0,0,0,0,192,177,6,0,160,54,6,0,0,0,0,0,128,145,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,0,8,0,0,1,0,0,0,0,0,0,0,84,45,0,0,184,44,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,106,8,0,144,232,1,0,0,0,0,0,0,0,0,0,160,234,7,0,96,50,8,0,0,0,0,0,192,223,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,20,2,0,0,0,0,0,0,0,0,0,0,0,174,30,0,0,96,9,0,0,0,0,0,0,0,0,0,0,194,6,0,0,128,44,0,0,192,7,0,0,16,3,0,0,100,9,0,0,230,11,0,0,254,30,0,0,184,175,145,0,0,4,0,0,240,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,192,254,7,0,144,232,1,0,0,0,0,0,0,0,0,0,160,234,7,0,120,201,7,0,0,0,0,0,192,154,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,20,2,0,0,0,0,0,0,0,0,0,0,0,238,2,0,0,16,36,0,0,0,0,0,0,0,0,0,0,194,6,0,0,164,39,0,0,192,7,0,0,16,3,0,0,100,9,0,0,230,11,0,0,254,30,0,0,184,175,145,0,0,4,0,0,240,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,48,235,8,0,144,232,1,0,0,0,0,0,0,0,0,0,160,234,7,0,96,170,8,0,0,0,0,0,192,223,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,20,2,0,0,0,0,0,0,0,0,0,0,0,4,20,0,0,16,2,0,0,0,0,0,0,0,0,0,0,194,6,0,0,128,44,0,0,192,7,0,0,16,3,0,0,100,9,0,0,230,11,0,0,254,30,0,0,184,175,145,0,0,4,0,0,240,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,144,232,1,0,0,0,0,0,0,0,0,0,0,0,0,0,160,234,7,0,80,46,1,0,0,0,0,0,192,223,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,2,0,0,0,0,0,0,20,2,0,0,0,0,0,0,0,0,0,0,0,188,56,0,0,176,29,0,0,0,0,0,0,0,0,0,0,194,6,0,0,128,44,0,0,192,7,0,0,16,3,0,0,100,9,0,0,230,11,0,0,254,30,0,0,184,175,145,0,0,4,0,0,240,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,56,217,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,96,213,1,0,0,0,0,0,184,191,7,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,8,0,0,0,0,0,0,0,0,0,0,0,160,24,0,0,176,26,0,0,0,0,0,0,0,0,0,0,58,40,0,0,118,44,0,0,16,5,0,0,208,16,0,0,164,3,0,0,100,2,0,0,174,20,0,0,72,174,145,0,0,1,0,0,112,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,96,159,4,0,184,9,2,0,208,2,2,0,120,131,5,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,0,16,64,0,0,0,0,0,0,0,0,0,0,0,70,23,0,0,118,38,0,0,0,0,0,0,0,0,0,0,58,25,0,0,146,24,0,0,122,19,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,120,48,1,0,136,117,5,0,0,0,0,0,0,0,0,0,104,174,7,0,48,236,8,0,0,0,0,0,192,154,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,53,0,0,0,2,0,0,0,0,0,0,20,2,0,0,0,0,0,0,0,0,0,0,0,88,46,0,0,142,24,0,0,0,0,0,0,0,0,0,0,22,19,0,0,66,57,0,0,148,12,0,0,8,11,0,0,92,2,0,0,0,0,0,0,6,37,0,0,0,0,0,0,0,8,0,0,240,0,0,0,128,1,0,0,3,0,0,0,4,0,0,0,0,246,3,0,0,0,0,0,72,172,6,0,0,0,0,0,96,135,2,0,240,230,1,0,0,0,0,0,128,145,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,1,0,0,0,0,0,0,0,0,0,0,0,206,29,0,0,204,15,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,212,4,0,0,0,0,0,0,0,0,0,0,0,0,0,64,171,7,0,216,178,4,0,0,0,0,0,200,146,4,0,64,10,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,17,0,16,0,0,0,0,0,0,0,0,0,0,146,49,0,0,236,18,0,0,0,0,0,0,0,0,0,0,62,25,0,0,138,60,0,0,168,12,0,0,60,6,0,0,250,15,0,0,0,0,0,0,194,0,0,0,0,0,0,0,0,3,0,0,128,1,0,0,0,1,0,0,4,0,0,0,3,0,0,0,248,70,3,0,200,73,3,0,0,0,0,0,0,0,0,0,232,167,7,0,40,70,3,0,0,0,0,0,56,72,3,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,8,0,0,2,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,0,0,0,0,114,51,0,0,200,45,0,0,0,0,0,0,0,0,0,0,230,33,0,0,56,23,0,0,212,9,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,200,73,3,0,0,0,0,0,0,0,0,0,0,0,0,0,232,167,7,0,32,73,3,0,0,0,0,0,56,72,3,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,8,0,0,2,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,0,0,0,0,20,52,0,0,250,44,0,0,0,0,0,0,0,0,0,0,230,33,0,0,56,23,0,0,212,9,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,64,13,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,32,56,6,0,72,213,4,0,72,174,3,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,0,8,0,0,0,0,0,0,0,0,0,108,52,0,0,84,14,0,0,0,0,0,0,0,0,0,0,2,9,0,0,12,0,0,0,132,1,0,0,36,10,0,0,166,5,0,0,32,19,0,0,172,14,0,0,184,174,145,0,0,8,0,0,192,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,27,2,0,72,48,2,0,0,0,0,0,0,0,0,0,184,168,7,0,96,17,2,0,0,0,0,0,152,54,6,0,200,12,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,17,4,0,0,0,0,0,0,0,0,0,0,0,202,24,0,0,60,34,0,0,0,0,0,0,0,0,0,0,198,62,0,0,210,37,0,0,4,5,0,0,230,1,0,0,44,6,0,0,194,15,0,0,0,0,0,0,48,177,145,0,0,2,0,0,128,1,0,0,0,1,0,0,4,0,0,0,3,0,0,0,104,243,1,0,72,48,2,0,0,0,0,0,0,0,0,0,184,168,7,0,216,232,1,0,0,0,0,0,192,154,4,0,200,12,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,3,17,4,0,0,0,0,0,0,0,0,0,0,0,178,43,0,0,212,36,0,0,0,0,0,0,0,0,0,0,198,62,0,0,210,37,0,0,4,5,0,0,230,1,0,0,44,6,0,0,194,15,0,0,0,0,0,0,48,177,145,0,0,2,0,0,128,1,0,0,0,1,0,0,4,0,0,0,3,0,0,0,112,8,2,0,72,48,2,0,0,0,0,0,0,0,0,0,184,168,7,0,32,1,2,0,0,0,0,0,192,154,4,0,200,12,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,3,17,4,0,0,0,0,0,0,0,0,0,0,0,204,13,0,0,72,28,0,0,0,0,0,0,0,0,0,0,198,62,0,0,210,37,0,0,40,10,0,0,230,1,0,0,44,6,0,0,194,15,0,0,0,0,0,0,48,177,145,0,0,2,0,0,128,1,0,0,0,1,0,0,4,0,0,0,3,0,0,0,72,48,2,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,64,239,4,0,0,0,0,0,152,54,6,0,200,12,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,3,17,4,0,0,0,0,0,0,0,0,0,0,0,66,37,0,0,228,40,0,0,0,0,0,0,0,0,0,0,198,62,0,0,210,37,0,0,4,5,0,0,230,1,0,0,44,6,0,0,194,15,0,0,0,0,0,0,48,177,145,0,0,2,0,0,128,1,0,0,0,1,0,0,4,0,0,0,3,0,0,0,80,136,3,0,0,0,0,0,0,0,0,0,0,0,0,0,168,163,7,0,0,34,6,0,0,0,0,0,176,192,4,0,208,160,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,16,0,0,0,0,0,0,0,0,0,0,208,62,0,0,70,42,0,0,0,0,0,0,0,0,0,0,46,49,0,0,120,17,0,0,76,15,0,0,108,13,0,0,240,15,0,0,166,8,0,0,248,24,0,0,40,174,145,0,0,8,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,33,1,0,0,0,0,0,0,0,0,0,0,0,0,0,184,12,8,0,104,156,8,0,0,0,0,0,176,192,4,0,136,94,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,16,0,0,0,0,0,0,0,0,0,0,8,29,0,0,0,35,0,0,0,0,0,0,0,0,0,0,46,49,0,0,120,17,0,0,192,18,0,0,108,13,0,0,240,15,0,0,166,8,0,0,248,24,0,0,40,174,145,0,0,8,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,206,5,0,128,216,6,0,0,0,0,0,0,0,0,0,184,168,7,0,96,166,5,0,0,0,0,0,40,161,4,0,240,153,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,192,0,1,2,0,0,8,0,0,0,0,0,0,0,0,0,188,19,0,0,26,22,0,0,0,0,0,0,0,0,0,0,138,35,0,0,38,21,0,0,168,8,0,0,114,5,0,0,164,8,0,0,0,0,0,0,6,14,0,0,0,0,0,0,0,96,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,80,6,0,128,216,6,0,0,0,0,0,0,0,0,0,184,168,7,0,80,37,6,0,0,0,0,0,40,161,4,0,240,153,3,0,0,249,5,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,192,0,1,2,0,0,8,0,0,0,0,0,0,0,0,0,162,23,0,0,224,0,0,0,0,0,0,0,0,0,0,0,138,35,0,0,38,21,0,0,168,8,0,0,114,5,0,0,164,8,0,0,0,0,0,0,6,14,0,0,0,0,0,0,0,96,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,216,6,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,200,128,6,0,0,0,0,0,40,161,4,0,240,153,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,192,0,1,2,0,0,8,0,0,0,0,0,0,0,0,0,182,13,0,0,176,45,0,0,0,0,0,0,0,0,0,0,138,35,0,0,38,21,0,0,168,8,0,0,114,5,0,0,164,8,0,0,0,0,0,0,6,14,0,0,0,0,0,0,0,96,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,8,7,0,48,102,7,0,0,0,0,0,0,0,0,0,184,230,7,0,0,222,6,0,0,0,0,0,232,163,8,0,192,181,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,13,0,8,0,0,0,0,0,0,0,0,0,0,176,44,0,0,50,46,0,0,0,0,0,0,0,0,0,0,228,31,0,0,194,48,0,0,212,12,0,0,228,6,0,0,224,8,0,0,166,2,0,0,2,43,0,0,0,0,0,0,2,16,0,0,128,2,0,0,240,0,0,0,8,0,0,0,3,0,0,0,48,102,7,0,0,0,0,0,0,0,0,0,0,0,0,0,184,230,7,0,72,51,7,0,0,0,0,0,232,163,8,0,192,181,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,13,0,8,0,0,0,0,0,0,0,0,0,0,250,45,0,0,252,11,0,0,0,0,0,0,0,0,0,0,228,31,0,0,194,48,0,0,40,16,0,0,228,6,0,0,224,8,0,0,166,2,0,0,2,43,0,0,0,0,0,0,2,16,0,0,128,2,0,0,240,0,0,0,8,0,0,0,3,0,0,0,72,200,1,0,72,202,2,0,0,0,0,0,0,0,0,0,232,233,7,0,104,102,1,0,0,0,0,0,144,84,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,11,4,0,0,0,0,0,0,0])
.concat([0,0,0,0,80,51,0,0,22,8,0,0,0,0,0,0,0,0,0,0,22,0,0,0,2,19,0,0,24,6,0,0,246,1,0,0,202,7,0,0,138,15,0,0,142,47,0,0,136,173,145,0,0,4,0,0,240,0,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,194,2,0,72,202,2,0,0,0,0,0,0,0,0,0,232,233,7,0,64,58,2,0,0,0,0,0,144,84,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,11,4,0,0,0,0,0,0,0,0,0,0,0,220,35,0,0,2,10,0,0,0,0,0,0,0,0,0,0,22,0,0,0,2,19,0,0,24,6,0,0,246,1,0,0,202,7,0,0,138,15,0,0,142,47,0,0,136,173,145,0,0,4,0,0,240,0,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,236,7,0,72,202,2,0,0,0,0,0,0,0,0,0,232,233,7,0,232,183,7,0,0,0,0,0,192,154,4,0,136,137,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,3,11,4,0,0,0,0,0,0,0,0,0,0,0,100,37,0,0,238,30,0,0,0,0,0,0,0,0,0,0,22,0,0,0,2,19,0,0,24,6,0,0,246,1,0,0,202,7,0,0,138,15,0,0,142,47,0,0,136,173,145,0,0,4,0,0,240,0,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,87,8,0,72,202,2,0,0,0,0,0,0,0,0,0,232,233,7,0,112,33,8,0,0,0,0,0,192,154,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,3,11,4,0,0,0,0,0,0,0,0,0,0,0,128,26,0,0,54,42,0,0,0,0,0,0,0,0,0,0,22,0,0,0,2,19,0,0,24,6,0,0,246,1,0,0,202,7,0,0,138,15,0,0,142,47,0,0,136,173,145,0,0,4,0,0,240,0,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,23,1,0,72,202,2,0,0,0,0,0,0,0,0,0,232,233,7,0,128,215,8,0,0,0,0,0,192,154,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,3,11,4,0,0,0,0,0,0,0,0,0,0,0,200,34,0,0,102,46,0,0,0,0,0,0,0,0,0,0,22,0,0,0,2,19,0,0,74,10,0,0,246,1,0,0,202,7,0,0,138,15,0,0,142,47,0,0,136,173,145,0,0,4,0,0,240,0,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,202,2,0,0,0,0,0,0,0,0,0,0,0,0,0,232,233,7,0,216,246,5,0,0,0,0,0,144,84,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,3,11,4,0,0,0,0,0,0,0,0,0,0,0,244,20,0,0,76,12,0,0,0,0,0,0,0,0,0,0,22,0,0,0,2,19,0,0,24,6,0,0,246,1,0,0,202,7,0,0,138,15,0,0,142,47,0,0,136,173,145,0,0,4,0,0,240,0,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,94,4,0,0,0,0,0,0,0,0,0,0,0,0,0,144,139,6,0,208,63,6,0,0,0,0,0,248,219,4,0,216,179,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,3,0,0,0,0,0,0,10,0,32,0,0,0,0,0,0,0,0,0,0,60,40,0,0,18,0,0,0,0,0,0,0,0,0,0,0,14,4,0,0,2,63,0,0,142,18,0,0,48,8,0,0,208,4,0,0,170,19,0,0,228,42,0,0,0,0,0,0,0,0,1,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,174,3,0,48,117,4,0,0,0,0,0,0,0,0,0,200,190,7,0,72,124,3,0,0,0,0,0,192,154,4,0,64,10,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,17,0,8,0,0,0,0,0,0,0,0,0,0,184,23,0,0,114,30,0,0,0,0,0,0,0,0,0,0,62,25,0,0,144,17,0,0,178,14,0,0,60,6,0,0,250,15,0,0,0,0,0,0,194,0,0,0,0,0,0,0,0,2,0,0,128,1,0,0,0,1,0,0,4,0,0,0,3,0,0,0,40,11,2,0,16,31,2,0,0,0,0,0,0,0,0,0,104,221,5,0,80,4,2,0,0,0,0,0,128,161,4,0,208,135,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,2,11,0,8,0,0,0,0,0,0,0,0,0,0,104,31,0,0,70,6,0,0,0,0,0,0,0,0,0,0,64,29,0,0,84,39,0,0,44,9,0,0,46,7,0,0,246,17,0,0,0,0,0,0,176,18,0,0,0,0,0,0,0,32,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,31,2,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,32,20,2,0,0,0,0,0,168,183,7,0,208,135,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,2,11,0,8,0,0,0,0,0,0,0,0,0,0,86,14,0,0,124,39,0,0,0,0,0,0,0,0,0,0,64,29,0,0,254,26,0,0,44,9,0,0,46,7,0,0,246,17,0,0,0,0,0,0,176,18,0,0,0,0,0,0,0,32,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,193,1,0,168,232,1,0,0,0,0,0,0,0,0,0,104,221,5,0,168,186,1,0,0,0,0,0,168,95,8,0,112,205,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,1,3,2,0,0,0,0,0,0,0,0,0,0,0,234,25,0,0,56,22,0,0,0,0,0,0,0,0,0,0,64,55,0,0,66,62,0,0,48,1,0,0,130,1,0,0,58,7,0,0,0,0,0,0,42,8,0,0,0,0,0,0,0,8,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,88,179,1,0,168,232,1,0,0,0,0,0,0,0,0,0,104,221,5,0,240,172,1,0,0,0,0,0,168,95,8,0,112,205,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,1,3,2,0,0,0,0,0,0,0,0,0,0,0,146,19,0,0,244,8,0,0,0,0,0,0,0,0,0,0,64,55,0,0,66,62,0,0,48,1,0,0,130,1,0,0,58,7,0,0,0,0,0,0,42,8,0,0,0,0,0,0,0,8,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,168,232,1,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,8,219,1,0,0,0,0,0,168,95,8,0,112,205,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,2,0,0,0,0,0,1,3,2,0,0,0,0,0,0,0,0,0,0,0,174,11,0,0,224,15,0,0,0,0,0,0,0,0,0,0,64,55,0,0,66,62,0,0,48,1,0,0,130,1,0,0,58,7,0,0,0,0,0,0,42,8,0,0,0,0,0,0,0,8,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,200,105,4,0,144,163,4,0,0,0,0,0,0,0,0,0,104,221,5,0,40,79,4,0,0,0,0,0,40,161,4,0,8,153,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,3,0,0,0,64,0,6,2,0,0,8,0,0,0,0,0,0,0,0,0,58,17,0,0,62,27,0,0,0,0,0,0,0,0,0,0,136,56,0,0,108,6,0,0,148,10,0,0,124,8,0,0,20,14,0,0,0,0,0,0,246,5,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,163,4,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,16,133,4,0,0,0,0,0,40,161,4,0,8,153,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,3,0,0,0,64,0,6,2,0,0,8,0,0,0,0,0,0,0,0,0,58,32,0,0,82,33,0,0,0,0,0,0,0,0,0,0,136,56,0,0,108,6,0,0,148,10,0,0,124,8,0,0,20,14,0,0,0,0,0,0,246,5,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,60,5,0,0,0,0,0,0,0,0,0,0,0,0,0,64,164,6,0,160,58,5,0,0,0,0,0,80,68,5,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,8,0,0,2,0,0,0,0,0,0,16,0,0,1,0,0,0,0,0,0,0,0,0,82,51,0,0,190,22,0,0,0,0,0,0,0,0,0,0,172,33,0,0,14,32,0,0,106,0,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,88,93,2,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,64,77,2,0,240,56,5,0,152,54,6,0,168,38,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,5,17,2,0,0,0,0,0,0,0,0,0,0,0,110,25,0,0,136,2,0,0,0,0,0,0,0,0,0,0,58,34,0,0,200,62,0,0,74,16,0,0,218,2,0,0,114,1,0,0,166,3,0,0,116,50,0,0,8,211,148,0,0,8,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,120,228,1,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,192,172,5,0,0,0,0,0,168,138,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,19,0,0,1,0,0,0,0,0,0,0,0,0,236,4,0,0,194,23,0,0,0,0,0,0,0,0,0,0,186,21,0,0,238,20,0,0,68,16,0,0,184,12,0,0,228,8,0,0,248,5,0,0,40,57,0,0,40,173,145,0,0,4,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,102,7,0,168,196,7,0,0,0,0,0,0,0,0,0,200,190,7,0,240,51,7,0,64,250,7,0,72,226,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,30,7,0,0,52,18,0,0,0,0,0,0,0,0,0,0,152,20,0,0,78,35,0,0,8,12,0,0,62,8,0,0,92,16,0,0,16,7,0,0,172,10,0,0,40,175,145,0,0,8,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,168,196,7,0,0,0,0,0,0,0,0,0,0,0,0,0,200,190,7,0,48,149,7,0,64,250,7,0,72,226,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,252,31,0,0,102,3,0,0,0,0,0,0,0,0,0,0,152,20,0,0,78,35,0,0,92,6,0,0,62,8,0,0,92,16,0,0,16,7,0,0,172,10,0,0,40,175,145,0,0,8,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,200,185,1,0,0,0,0,0,72,172,6,0,0,0,0,0,144,47,2,0,48,178,1,0,0,0,0,0,128,145,4,0,208,9,3,0,112,171,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,4,0,0,0,0,0,0,0,0,0,0,0,152,16,0,0,224,35,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,111,5,0,0,0,0,0,0,0,0,0,0,0,0,0,160,234,7,0,144,49,5,0,0,0,0,0,96,195,4,0,136,252,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,134,50,0,0,254,23,0,0,0,0,0,0,0,0,0,0,172,22,0,0,214,37,0,0,124,2,0,0,64,13,0,0,168,2,0,0,0,0,0,0,134,1,0,0,0,0,0,0,0,1,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,12,7,0,192,108,8,0,0,0,0,0,0,0,0,0,104,174,7,0,144,225,6,0,0,0,0,0,192,223,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,0,20,0,0,4,0,0,0,0,0,0,0,0,0,82,22,0,0,22,20,0,0,0,0,0,0,0,0,0,0,192,37,0,0,14,18,0,0,134,17,0,0,108,10,0,0,174,4,0,0,0,0,0,0,126,22,0,0,0,0,0,0,0,8,0,0,240,0,0,0,128,1,0,0,3,0,0,0,4,0,0,0,200,145,6,0,8,23,7,0,0,0,0,0,0,0,0,0,232,233,7,0,240,102,6,0,0,0,0,0,176,192,6,0,64,10,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,17,0,8,0,0,0,0,0,0,0,0,0,0,46,1,0,0,248,42,0,0,0,0,0,0,0,0,0,0,62,25,0,0,244,15,0,0,78,11,0,0,60,6,0,0,250,15,0,0,0,0,0,0,194,0,0,0,0,0,0,0,0,2,0,0,128,1,0,0,0,1,0,0,4,0,0,0,3,0,0,0,120,55,5,0,0,0,0,0,0,0,0,0,0,0,0,0,160,234,7,0,56,247,4,0,0,0,0,0,176,192,6,0,64,10,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,17,0,8,0,0,0,0,0,0,0,0,0,0,126,24,0,0,18,25,0,0,0,0,0,0,0,0,0,0,62,25,0,0,48,49,0,0,36,4,0,0,60,6,0,0,250,15,0,0,0,0,0,0,194,0,0,0,0,0,0,0,0,2,0,0,128,1,0,0,0,1,0,0,4,0,0,0,3,0,0,0,128,116,5,0,224,222,5,0,0,0,0,0,0,0,0,0,64,171,7,0,80,85,5,0,0,0,0,0,176,192,6,0,64,10,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,17,0,8,0,0,0,0,0,0,0,0,0,0,94,16,0,0,144,0,0,0,0,0,0,0,0,0,0,0,62,25,0,0,32,12,0,0,62,10,0,0,60,6,0,0,250,15,0,0,0,0,0,0,194,0,0,0,0,0,0,0,0,2,0,0,128,1,0,0,0,1,0,0,4,0,0,0,3,0,0,0,224,222,5,0,0,0,0,0,0,0,0,0,0,0,0,0,64,171,7,0,184,145,5,0,0,0,0,0,176,192,6,0,64,10,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,17,0,8,0,0,0,0,0,0,0,0,0,0,190,23,0,0,204,16,0,0,0,0,0,0,0,0,0,0,62,25,0,0,32,12,0,0,212,11,0,0,60,6,0,0,250,15,0,0,0,0,0,0,194,0,0,0,0,0,0,0,0,2,0,0,128,1,0,0,0,1,0,0,4,0,0,0,3,0,0,0,80,55,6,0,0,0,0,0,0,0,0,0,0,0,0,0,232,233,7,0,152,15,6,0,0,0,0,0,176,192,6,0,64,10,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,17,0,8,0,0,0,0,0,0,0,0,0,0,66,0,0,0,242,26,0,0,0,0,0,0,0,0,0,0,62,25,0,0,32,12,0,0,142,10,0,0,60,6,0,0,250,15,0,0,0,0,0,0,194,0,0,0,0,0,0,0,0,2,0,0,128,1,0,0,0,1,0,0,4,0,0,0,3,0,0,0,8,23,7,0,0,0,0,0,0,0,0,0,0,0,0,0,232,233,7,0,160,234,6,0,0,0,0,0,176,192,6,0,64,10,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,17,0,8,0,0,0,0,0,0,0,0,0,0,158,55,0,0,20,23,0,0,0,0,0,0,0,0,0,0,62,25,0,0,244,15,0,0,78,11,0,0,60,6,0,0,250,15,0,0,0,0,0,0,194,0,0,0,0,0,0,0,0,2,0,0,128,1,0,0,0,1,0,0,4,0,0,0,3,0,0,0,136,226,4,0,0,0,0,0,72,172,6,0,0,0,0,0,104,221,5,0,144,141,2,0,0,0,0,0,128,145,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,0,64,0,0,0,0,0,0,0,0,0,0,156,41,0,0,24,30,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,45,7,0,0,0,0,0,0,0,0,0,0,0,0,0,200,190,7,0,208,0,7,0,0,0,0,0,40,161,4,0,240,153,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,192,0,1,2,0,0,8,0,0,0,0,0,0,0,0,0,208,35,0,0,10,23,0,0,0,0,0,0,0,0,0,0,0,54,0,0,56,49,0,0,84,17,0,0,114,5,0,0,164,8,0,0,0,0,0,0,6,14,0,0,0,0,0,0,0,96,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,157,3,0,192,243,3,0,0,0,0,0,0,0,0,0,160,234,7,0,120,132,3,0,0,0,0,0,168,138,8,0,176,109,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,0,19,0,0,1,0,0,0,0,0,0,0,0,0,152,9,0,0,242,45,0,0,0,0,0,0,0,0,0,0,12,32,0,0,234,7,0,0,24,7,0,0,158,10,0,0,242,5,0,0,10,5,0,0,6,53,0,0,72,173,145,0,0,4,0,0,240,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,64,109,3,0,192,243,3,0,0,0,0,0,0,0,0,0,160,234,7,0,120,88,3,0,0,0,0,0,176,237,2,0,176,109,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,0,19,0,0,1,0,0,0,0,0,0,0,0,0,248,35,0,0,2,20,0,0,0,0,0,0,0,0,0,0,12,32,0,0,146,21,0,0,24,7,0,0,158,10,0,0,242,5,0,0,10,5,0,0,6,53,0,0,72,173,145,0,0,4,0,0,240,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,192,243,3,0,0,0,0,0,0,0,0,0,0,0,0,0,160,234,7,0,0,183,3,0,0,0,0,0,168,138,8,0,176,109,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,0,19,0,0,1,0,0,0,0,0,0,0,0,0,60,9,0,0,98,12,0,0,0,0,0,0,0,0,0,0,12,32,0,0,234,7,0,0,24,7,0,0,158,10,0,0,242,5,0,0,10,5,0,0,6,53,0,0,72,173,145,0,0,4,0,0,240,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,240,250,2,0,136,117,5,0,0,0,0,0,0,0,0,0,104,174,7,0,176,95,2,0,0,0,0,0,192,223,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,0,20,2,0,0,0,0,0,0,0,0,0,0,0,50,44,0,0,78,32,0,0,0,0,0,0,0,0,0,0,22,19,0,0,66,57,0,0,120,14,0,0,8,11,0,0,92,2,0,0,0,0,0,0,6,37,0,0,0,0,0,0,0,8,0,0,240,0,0,0,128,1,0,0,3,0,0,0,4,0,0,0,64,234,1,0,136,117,5,0,0,0,0,0,0,0,0,0,104,174,7,0,224,136,1,0,0,0,0,0,192,223,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,0,20,2,0,0,0,0,0,0,0,0,0,0,0,202,35,0,0,152,39,0,0,0,0,0,0,0,0,0,0,22,19,0,0,66,57,0,0,120,14,0,0,8,11,0,0,92,2,0,0,0,0,0,0,6,37,0,0,0,0,0,0,0,8,0,0,240,0,0,0,128,1,0,0,3,0,0,0,4,0,0,0,136,117,5,0,0,0,0,0,0,0,0,0,0,0,0,0,104,174,7,0,208,111,6,0,0,0,0,0,192,223,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,0,20,2,0,0,0,0,0,0,0,0,0,0,0,24,61,0,0,100,25,0,0,0,0,0,0,0,0,0,0,22,19,0,0,66,57,0,0,120,14,0,0,8,11,0,0,92,2,0,0,0,0,0,0,6,37,0,0,0,0,0,0,0,8,0,0,240,0,0,0,128,1,0,0,3,0,0,0,4,0,0,0,200,202,7,0,16,247,4,0,0,0,0,0,0,0,0,0,64,164,6,0,152,188,7,0,0,0,0,0,192,154,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,53,0,0,0,2,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,0,0,0,0,106,49,0,0,214,33,0,0,0,0,0,0,0,0,0,0,86,41,0,0,224,5,0,0,132,9,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,96,242,2,0,16,247,4,0,0,0,0,0,0,0,0,0,216,194,1,0,152,89,2,0,0,0,0,0,192,154,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,192,23,0,0,252,30,0,0,0,0,0,0,0,0,0,0,92,56,0,0,66,45,0,0,42,12,0,0,218,16,0,0,166,13,0,0,164,1,0,0,68,57,0,0,128,175,145,0,96,0,0,0,196,0,0,0,240,0,0,0,3,0,0,0,4,0,0,0,16,247,4,0,0,0,0,0,0,0,0,0,0,0,0,0,216,194,1,0,24,93,6,0,0,0,0,0,104,238,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,148,62,0,0,164,31,0,0,0,0,0,0,0,0,0,0,92,56,0,0,66,45,0,0,42,12,0,0,218,16,0,0,166,13,0,0,164,1,0,0,68,57,0,0,128,175,145,0,96,0,0,0,196,0,0,0,240,0,0,0,3,0,0,0,4,0,0,0,216,130,1,0,16,247,4,0,0,0,0,0,0,0,0,0,216,194,1,0,112,44,1,0,0,0,0,0,192,154,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,112,22,0,0,52,26,0,0,0,0,0,0,0,0,0,0,92,56,0,0,66,45,0,0,42,12,0,0,218,16,0,0,166,13,0,0,164,1,0,0,68,57,0,0,128,175,145,0,96,0,0,0,196,0,0,0,240,0,0,0,3,0,0,0,4,0,0,0,168,218,8,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,152,152,8,0,0,0,0,0,216,123,2,0,8,147,3,0,152,90,8,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,2,0,0,0,0,0,4,11,0,128,0,0,0,0,0,0,0,0,0,0,206,58,0,0,162,40,0,0,0,0,0,0,0,0,0,0,98,41,0,0,204,28,0,0,234,9,0,0,48,9,0,0,126,17,0,0,0,0,0,0,236,36,0,0,0,0,0,0,0,8,0,0,128,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,32,136,1,0,216,95,5,0,0,0,0,0,0,0,0,0,160,234,7,0,40,48,1,0,0,0,0,0,192,154,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,0,22,4,0,0,0,0,0,0,0,0,0,0,0,134,4,0,0,212,20,0,0,0,0,0,0,0,0,0,0,36,61,0,0,142,40,0,0,144,8,0,0,94,5,0,0,2,19,0,0,0,0,0,0,38,20,0,0,0,0,0,0,0,1,0,0,240,0,0,0,240,0,0,0,4,0,0,0,3,0,0,0,8,250,2,0,216,95,5,0,0,0,0,0,0,0,0,0,160,234,7,0,160,94,2,0,0,0,0,0,120,58,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,22,4,0,0,0,0,0,0,0,0,0,0,0,64,10,0,0,184,22,0,0,0,0,0,0,0,0,0,0,36,61,0,0,142,40,0,0,160,8,0,0,94,5,0,0,2,19,0,0,0,0,0,0,38,20,0,0,0,0,0,0,0,1,0,0,240,0,0,0,240,0,0,0,4,0,0,0,3,0,0,0,216,37,3,0,136,187,8,0,0,0,0,0,0,0,0,0,232,233,7,0,168,119,2,0,0,0,0,0,240,0,2,0,64,10,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,17,4,0,0,0,0,0,0,0,0,0,0,0,28,29,0,0,240,38,0,0,0,0,0,0,0,0,0,0,62,25,0,0,144,22,0,0,146,4,0,0,60,6,0,0,250,15,0,0,0,0,0,0,194,0,0,0,0,0,0,0,0,2,0,0,0,1,0,0,0,1,0,0,4,0,0,0,3,0,0,0,136,187,8,0,0,0,0,0,0,0,0,0,0,0,0,0,232,233,7,0,8,193,6,0,0,0,0,0,152,54,6,0,64,10,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,17,4,0,0,0,0,0,0,0,0,0,0,0,130,35,0,0,224,16,0,0,0,0,0,0,0,0,0,0,62,25,0,0,144,22,0,0,190,12,0,0,60,6,0,0,250,15,0,0,0,0,0,0,194,0,0,0,0,0,0,0,0,2,0,0,0,1,0,0,0,1,0,0,4,0,0,0,3,0,0,0,24,214,7,0,136,187,8,0,0,0,0,0,0,0,0,0,232,233,7,0,168,162,7,0,0,0,0,0,192,154,4,0,64,10,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,17,4,0,0,0,0,0,0,0,0,0,0,0,206,40,0,0,36,35,0,0,0,0,0,0,0,0,0,0,62,25,0,0,144,22,0,0,94,7,0,0,60,6,0,0,250,15,0,0,0,0,0,0,194,0,0,0,0,0,0,0,0,2,0,0,0,1,0,0,0,1,0,0,4,0,0,0,3,0,0,0,72,63,8,0,136,187,8,0,0,0,0,0,0,0,0,0,232,233,7,0,232,11,8,0,0,0,0,0,192,154,4,0,64,10,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,17,4,0,0,0,0,0,0,0,0,0,0,0,172,32,0,0,72,1,0,0,0,0,0,0,0,0,0,0,62,25,0,0,144,22,0,0,190,12,0,0,60,6,0,0,250,15,0,0,0,0,0,0,194,0,0,0,0,0,0,0,0,2,0,0,0,1,0,0,0,1,0,0,4,0,0,0,3,0,0,0,88,250,8,0,136,187,8,0,0,0,0,0,0,0,0,0,232,233,7,0,192,186,8,0,0,0,0,0,192,154,4,0,64,10,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,17,4,0,0,0,0,0,0,0,0,0,0,0,34,20,0,0,68,8,0,0,0,0,0,0,0,0,0,0,62,25,0,0,144,22,0,0,190,12,0,0,60,6,0,0,250,15,0,0,0,0,0,0,194,0,0,0,0,0,0,0,0,2,0,0,0,1,0,0,0,1,0,0,4,0,0,0,3,0,0,0,176,203,8,0,248,212,1,0,0,0,0,0,0,0,0,0,184,168,7,0,112,139,8,0,0,0,0,0,176,237,2,0,168,84,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,0,19,2,0,0,0,0,0,0,0,0,0,0,0,110,49,0,0,216,25,0,0,0,0,0,0,0,0,0,0,170,36,0,0,16,3,0,0,190,2,0,0,236,18,0,0,92,5,0,0,208,1,0,0,246,13,0,0,32,173,145,0,0,5,0,0,240,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,176,164,8,0,0,0,0,0,0,0,0,0,0,0,0,0,200,190,7,0,216,45,8,0,64,250,7,0,72,226,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,2,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,64,59,0,0,222,27,0,0,0,0,0,0,0,0,0,0,152,20,0,0,82,28,0,0,194,13,0,0,62,8,0,0,92,16,0,0,16,7,0,0,172,10,0,0,40,175,145,0,0,8,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,212,4,0,192,177,1,0,200,240,5,0,0,0,0,0,144,139,6,0,248,207,4,0,0,0,0,0,72,174,3,0,88,0,3,0,168,203,4,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,1,0,0,8,4,0,0,0,0,0,0,0,0,0,0,0,206,27,0,0,64,39,0,0,0,0,0,0,0,0,0,0,104,35,0,0,188,9,0,0,202,9,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,192,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,155,1,0,192,177,1,0,200,240,5,0,0,0,0,0,144,139,6,0,24,144,1,0,0,0,0,0,72,174,3,0,88,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,1,0,0,8,4,0,0,0,0,0,0,0,0,0,0,0,164,2,0,0,156,6,0,0,0,0,0,0,0,0,0,0,104,35,0,0,82,38,0,0,248,11,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,192,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,131,1,0,192,177,1,0,200,240,5,0,0,0,0,0,144,139,6,0,96,117,1,0,0,0,0,0,72,174,3,0,88,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,1,0,0,8,4,0,0,0,0,0,0,0,0,0,0,0,170,35,0,0,154,30,0,0,0,0,0,0,0,0,0,0,104,35,0,0,82,38,0,0,248,11,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,192,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,105,1,0,192,177,1,0,200,240,5,0,0,0,0,0,144,139,6,0,112,94,1,0,0,0,0,0,72,174,3,0,88,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,1,0,0,8,4,0,0,0,0,0,0,0,0,0,0,0,112,34,0,0,198,1,0,0,0,0,0,0,0,0,0,0,104,35,0,0,82,38,0,0,248,11,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,192,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,177,1,0,0,0,0,0,200,240,5,0,0,0,0,0,144,139,6,0,232,170,1,0,0,0,0,0,72,174,3,0,88,0,3,0,88,162,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,4,0,0,0,1,0,0,8,4,0,0,0,0,0,0,0,0,0,0,0,52,17,0,0,8,25,0,0,0,0,0,0,0,0,0,0,104,35,0,0,82,38,0,0,248,11,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,192,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,219,4,0,80,241,1,0,200,240,5,0,0,0,0,0,144,139,6,0,80,217,4,0,0,0,0,0,72,174,3,0,88,0,3,0,40,214,4,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,0,8,4,0,0,0,0,0,0,0,0,0,0,0,48,4,0,0,178,34,0,0,0,0,0,0,0,0,0,0,104,35,0,0,188,9,0,0,162,13,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,192,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,229,4,0,80,241,1,0,200,240,5,0,0,0,0,0,144,139,6,0,192,225,4,0,0,0,0,0,72,174,3,0,88,0,3,0,168,221,4,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,0,8,4,0,0,0,0,0,0,0,0,0,0,0,198,60,0,0,212,18,0,0,0,0,0,0,0,0,0,0,104,35,0,0,188,9,0,0,162,13,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,192,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,241,4,0,80,241,1,0,200,240,5,0,0,0,0,0,144,139,6,0,232,238,4,0,0,0,0,0,72,174,3,0,88,0,3,0,40,234,4,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,0,8,4,0,0,0,0,0,0,0,0,0,0,0,246,48,0,0,140,9,0,0,0,0,0,0,0,0,0,0,104,35,0,0,188,9,0,0,162,13,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,192,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,252,4,0,80,241,1,0,200,240,5,0,0,0,0,0,144,139,6,0,176,249,4,0,0,0,0,0,72,174,3,0,88,0,3,0,208,245,4,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,0,8,4,0,0,0,0,0,0,0,0,0,0,0,84,35,0,0,92,5,0,0,0,0,0,0,0,0,0,0,104,35,0,0,188,9,0,0,162,13,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,192,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,203,1,0,80,241,1,0,200,240,5,0,0,0,0,0,144,139,6,0,64,192,1,0,0,0,0,0,72,174,3,0,88,0,3,0,168,184,1,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,0,8,4,0,0,0,0,0,0,0,0,0,0,0,76,4,0,0,224,41,0,0,0,0,0,0,0,0,0,0,104,35,0,0,82,38,0,0,66,7,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,192,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,241,1,0,0,0,0,0,200,240,5,0,0,0,0,0,144,139,6,0,96,230,1,0,0,0,0,0,72,174,3,0,88,0,3,0,160,215,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,4,0,0,0,0,0,0,8,4,0,0,0,0,0,0,0,0,0,0,0,158,26,0,0,130,5,0,0,0,0,0,0,0,0,0,0,104,35,0,0,82,38,0,0,66,7,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,192,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,21,8,0,208,34,8,0,200,240,5,0,0,0,0,0,104,129,6,0,120,18,8,0,0,0,0,0,72,174,3,0,88,0,3,0,120,14,8,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,1,0,0,8,4,0,0,0,0,0,0,0,0,0,0,0,90,36,0,0,64,7,0,0,0,0,0,0,0,0,0,0,104,35,0,0,82,38,0,0,222,13,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,192,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,9,8,0,208,34,8,0,200,240,5,0,0,0,0,0,104,129,6,0,160,3,8,0,0,0,0,0,72,174,3,0,88,0,3,0,144,252,7,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,1,0,0,8,4,0,0,0,0,0,0,0,0,0,0,0,196,21,0,0,100,18,0,0,0,0,0,0,0,0,0,0,104,35,0,0,82,38,0,0,222,13,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,192,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,34,8,0,0,0,0,0,200,240,5,0,0,0,0,0,104,129,6,0,152,29,8,0,0,0,0,0,72,174,3,0,88,0,3,0,136,25,8,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,4,0,0,0,1,0,0,8,4,0,0,0,0,0,0,0,0,0,0,0,208,25,0,0,220,26,0,0,0,0,0,0,0,0,0,0,104,35,0,0,82,38,0,0,222,13,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,192,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,124,8,0,200,13,7,0,200,240,5,0,0,0,0,0,184,230,7,0,72,119,8,0,0,0,0,0,72,174,3,0,88,0,3,0,24,112,8,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,1,0,0,8,4,0,0,0,0,0,0,0,0,0,0,0,90,45,0,0,36,4,0,0,0,0,0,0,0,0,0,0,104,35,0,0,232,12,0,0,140,10,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,192,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,105,8,0,200,13,7,0,200,240,5,0,0,0,0,0,184,230,7,0,128,96,8,0,0,0,0,0,72,174,3,0,88,0,3,0,128,89,8,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,1,0,0,8,4,0,0,0,0,0,0,0,0,0,0,0,216,37,0,0,128,15,0,0,0,0,0,0,0,0,0,0,104,35,0,0,232,12,0,0,140,10,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,192,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,82,8,0,200,13,7,0,200,240,5,0,0,0,0,0,184,230,7,0,32,78,8,0,0,0,0,0,72,174,3,0,88,0,3,0,0,72,8,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,1,0,0,8,4,0,0,0,0,0,0,0,0,0,0,0,252,43,0,0,32,22,0,0,0,0,0,0,0,0,0,0,104,35,0,0,232,12,0,0,140,10,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,192,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,69,8,0,200,13,7,0,200,240,5,0,0,0,0,0,184,230,7,0,160,65,8,0,0,0,0,0,72,174,3,0,88,0,3,0,144,61,8,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,1,0,0,8,4,0,0,0,0,0,0,0,0,0,0,0,62,9,0,0,166,33,0,0,0,0,0,0,0,0,0,0,104,35,0,0,232,12,0,0,140,10,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,192,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,55,8,0,200,13,7,0,200,240,5,0,0,0,0,0,184,230,7,0,24,49,8,0,0,0,0,0,72,174,3,0,88,0,3,0,0,41,8,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,1,0,0,8,4,0,0,0,0,0,0,0,0,0,0,0,66,17,0,0,246,21,0,0,0,0,0,0,0,0,0,0,104,35,0,0,232,12,0,0,140,10,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,192,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,13,7,0,0,0,0,0,200,240,5,0,0,0,0,0,184,230,7,0,80,135,8,0,0,0,0,0,72,174,3,0,88,0,3,0,208,129,8,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,4,0,0,0,1,0,0,8,4,0,0,0,0,0,0,0,0,0,0,0,70,17,0,0,56,21,0,0,0,0,0,0,0,0,0,0,104,35,0,0,82,38,0,0,140,10,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,192,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,61,2,0,48,103,2,0,200,240,5,0,0,0,0,0,144,139,6,0,80,46,2,0,0,0,0,0,72,174,3,0,88,0,3,0,136,34,2,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,0,8,4,0,0,0,0,0,0,0,0,0,0,0,60,43,0,0,150,27,0,0,0,0,0,0])
.concat([0,0,0,0,104,35,0,0,82,38,0,0,66,7,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,192,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,24,2,0,48,103,2,0,200,240,5,0,0,0,0,0,144,139,6,0,8,15,2,0,0,0,0,0,208,6,2,0,88,0,3,0,216,252,1,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,0,8,4,0,0,0,0,0,0,0,0,0,0,0,130,30,0,0,144,8,0,0,0,0,0,0,0,0,0,0,104,35,0,0,82,38,0,0,66,7,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,192,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,103,2,0,0,0,0,0,200,240,5,0,0,0,0,0,144,139,6,0,112,90,2,0,0,0,0,0,72,174,3,0,88,0,3,0,168,74,2,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,4,0,0,0,0,0,0,8,4,0,0,0,0,0,0,0,0,0,0,0,194,15,0,0,250,36,0,0,0,0,0,0,0,0,0,0,104,35,0,0,82,38,0,0,66,7,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,192,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,197,3,0,56,5,4,0,72,172,6,0,0,0,0,0,144,47,2,0,176,170,3,0,0,0,0,0,128,145,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,133,8,0,0,0,0,0,0,0,0,0,0,0,198,56,0,0,186,43,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,1,1,0,80,160,2,0,72,172,6,0,0,0,0,0,96,135,2,0,96,254,8,0,0,0,0,0,128,145,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,81,0,0,0,2,0,0,0,0,4,1,133,8,0,0,0,0,0,0,0,0,0,0,0,226,1,0,0,2,35,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,86,4,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,160,2,0,0,0,0,0,72,172,6,0,0,0,0,0,96,135,2,0,80,7,1,0,0,0,0,0,128,145,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,4,0,1,133,8,0,0,0,0,0,0,0,0,0,0,0,234,57,0,0,210,39,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,5,4,0,0,0,0,0,72,172,6,0,0,0,0,0,144,47,2,0,184,227,3,0,0,0,0,0,128,145,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,8,0,0,0,0,0,0,0,0,0,0,0,158,7,0,0,182,16,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,69,2,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,160,56,2,0,0,0,0,0,144,84,8,0,208,135,3,0,0,41,2,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,2,11,0,64,0,0,0,0,0,0,0,0,0,0,134,8,0,0,244,7,0,0,0,0,0,0,0,0,0,0,130,40,0,0,250,11,0,0,148,2,0,0,46,7,0,0,246,17,0,0,0,0,0,0,176,18,0,0,0,0,0,0,0,32,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,27,4,0,0,0,0,0,0,0,0,0,0,0,0,0,144,139,6,0,240,56,6,0,0,0,0,0,240,213,4,0,136,153,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,6,0,0,1,0,0,0,0,0,0,0,0,0,202,45,0,0,222,26,0,0,0,0,0,0,0,0,0,0,132,55,0,0,110,40,0,0,202,11,0,0,190,10,0,0,38,7,0,0,70,15,0,0,218,16,0,0,96,49,216,0,0,128,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,72,184,7,0,0,0,0,0,0,0,0,0,0,0,0,0,216,149,8,0,200,165,6,0,0,0,0,0,168,95,8,0,144,247,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,3,0,0,1,0,0,0,0,0,0,0,0,0,146,26,0,0,190,36,0,0,0,0,0,0,0,0,0,0,158,28,0,0,146,53,0,0,156,10,0,0,36,17,0,0,138,4,0,0,110,6,0,0,96,35,0,0,104,176,145,0,32,0,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,108,5,0,0,0,0,0,0,0,0,0,0,0,0,0,160,135,3,0,232,103,5,0,160,173,1,0,232,98,5,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,2,0,0,0,0,0,0,16,0,8,0,0,0,0,0,0,0,0,0,0,96,23,0,0,188,39,0,0,0,0,0,0,0,0,0,0,168,26,0,0,208,14,0,0,130,0,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,168,28,3,0,40,1,8,0,0,0,0,0,0,0,0,0,104,174,7,0,24,113,2,0,0,0,0,0,168,95,8,0,32,253,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,0,3,0,64,0,0,0,0,0,0,0,0,0,0,80,28,0,0,12,16,0,0,0,0,0,0,0,0,0,0,252,5,0,0,236,56,0,0,92,14,0,0,144,5,0,0,134,8,0,0,30,8,0,0,238,55,0,0,168,176,145,0,0,8,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,158,6,0,32,204,6,0,72,172,6,0,0,0,0,0,184,12,8,0,208,155,6,0,0,0,0,0,192,154,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,133,8,0,0,0,4,0,0,0,0,0,0,0,178,19,0,0,0,22,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,4,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,168,6,0,32,204,6,0,72,172,6,0,0,0,0,0,184,12,8,0,72,162,6,0,0,0,0,0,192,154,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,133,8,0,0,0,4,0,0,0,0,0,0,0,110,55,0,0,188,32,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,4,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,31,6,0,240,160,6,0,72,172,6,0,0,0,0,0,192,177,6,0,216,27,6,0,0,0,0,0,128,145,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,133,8,0,0,0,4,0,0,0,0,0,0,0,84,44,0,0,114,3,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,234,10,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,40,6,0,240,160,6,0,72,172,6,0,0,0,0,0,192,177,6,0,144,35,6,0,0,0,0,0,128,145,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,133,8,0,0,0,4,0,0,0,0,0,0,0,58,19,0,0,224,2,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,234,10,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,24,6,0,240,160,6,0,72,172,6,0,0,0,0,0,192,177,6,0,64,21,6,0,0,0,0,0,128,145,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,133,8,0,0,0,4,0,0,0,0,0,0,0,126,20,0,0,82,6,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,160,6,0,0,0,0,0,72,172,6,0,0,0,0,0,192,177,6,0,24,45,6,0,0,0,0,0,128,145,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,8,0,0,0,4,0,0,0,0,0,0,0,246,54,0,0,166,40,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,234,10,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,186,6,0,32,204,6,0,72,172,6,0,0,0,0,0,184,12,8,0,72,180,6,0,0,0,0,0,192,154,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,133,8,0,0,0,4,0,0,0,0,0,0,0,196,61,0,0,172,30,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,102,8,0,32,204,6,0,72,172,6,0,0,0,0,0,184,12,8,0,152,10,2,0,0,0,0,0,192,154,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,133,8,0,0,0,4,0,0,0,0,0,0,0,192,54,0,0,86,2,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,16,17,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,195,6,0,32,204,6,0,72,172,6,0,0,0,0,0,184,12,8,0,208,191,6,0,0,0,0,0,128,145,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,133,8,0,0,0,4,0,0,0,0,0,0,0,126,60,0,0,202,9,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,202,6,0,32,204,6,0,72,172,6,0,0,0,0,0,184,12,8,0,120,199,6,0,0,0,0,0,128,145,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,133,8,0,0,0,4,0,0,0,0,0,0,0,2,4,0,0,126,32,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,204,6,0,0,0,0,0,72,172,6,0,0,0,0,0,184,12,8,0,8,206,6,0,0,0,0,0,128,145,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,8,0,0,0,4,0,0,0,0,0,0,0,122,29,0,0,142,15,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,31,7,0,0,47,7,0,72,172,6,0,0,0,0,0,168,163,7,0,240,27,7,0,0,0,0,0,128,145,4,0,168,200,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,133,8,0,0,0,4,0,0,0,0,0,0,0,142,49,0,0,244,44,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,47,7,0,0,0,0,0,72,172,6,0,0,0,0,0,168,163,7,0,144,34,7,0,0,0,0,0,128,145,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,8,0,0,0,4,0,0,0,0,0,0,0,254,53,0,0,152,5,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,139,7,0,32,38,8,0,72,172,6,0,0,0,0,0,32,127,5,0,48,134,7,0,0,0,0,0,128,145,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,1,0,1,133,8,0,0,0,4,0,0,0,0,0,0,0,82,54,0,0,64,12,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,38,8,0,0,0,0,0,72,172,6,0,0,0,0,0,32,127,5,0,240,145,7,0,0,0,0,0,128,145,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,1,0,1,133,8,0,0,0,4,0,0,0,0,0,0,0,144,19,0,0,178,21,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,70,1,0,0,0,0,0,72,172,6,0,0,0,0,0,0,38,7,0,216,55,8,0,0,0,0,0,128,145,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,1,0,1,133,8,0,0,0,4,0,0,0,0,0,0,0,168,51,0,0,130,29,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,159,3,0,32,176,3,0,0,0,0,0,0,0,0,0,232,167,7,0,160,157,3,0,0,0,0,0,208,163,3,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,8,0,0,2,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,0,0,0,0,208,61,0,0,210,28,0,0,0,0,0,0,0,0,0,0,68,15,0,0,64,32,0,0,126,14,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,248,10,7,0,0,0,0,0,72,172,6,0,0,0,0,0,168,163,7,0,136,5,7,0,0,0,0,0,128,145,4,0,208,9,3,0,40,254,6,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,1,0,1,133,8,0,0,0,0,0,0,0,0,0,0,0,126,21,0,0,10,43,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,181,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,248,197,1,0,0,0,0,0,200,150,4,0,16,128,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,1,4,2,0,0,0,0,0,0,0,0,0,0,0,228,18,0,0,200,1,0,0,0,0,0,0,0,0,0,0,26,41,0,0,128,36,0,0,150,13,0,0,232,7,0,0,124,16,0,0,152,18,0,0,214,1,0,0,32,146,215,0,0,8,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,72,224,4,0,120,232,4,0,0,0,0,0,0,0,0,0,96,159,4,0,88,220,4,0,0,0,0,0,248,39,8,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,126,37,0,0,64,45,0,0,0,0,0,0,0,0,0,0,136,16,0,0,156,61,0,0,44,16,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,120,232,4,0,0,0,0,0,0,0,0,0,0,0,0,0,96,159,4,0,120,227,4,0,0,0,0,0,248,39,8,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,36,9,0,0,116,25,0,0,0,0,0,0,0,0,0,0,136,16,0,0,156,61,0,0,44,16,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,8,113,4,0,152,213,5,0,200,240,5,0,0,0,0,0,192,177,6,0,160,87,4,0,0,0,0,0,72,174,3,0,88,0,3,0,40,61,4,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,0,8,8,0,0,0,0,0,0,0,0,0,0,0,22,49,0,0,42,14,0,0,0,0,0,0,0,0,0,0,104,35,0,0,70,13,0,0,106,11,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,192,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,213,5,0,0,0,0,0,200,240,5,0,0,0,0,0,192,177,6,0,32,173,4,0,0,0,0,0,72,174,3,0,88,0,3,0,128,141,4,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,4,0,0,0,0,0,0,8,8,0,0,0,0,0,0,0,0,0,0,0,132,49,0,0,18,9,0,0,0,0,0,0,0,0,0,0,104,35,0,0,70,13,0,0,106,11,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,192,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,162,7,0,32,12,8,0,0,0,0,0,0,0,0,0,104,174,7,0,64,118,7,0,0,0,0,0,192,154,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,6,17,0,1,0,0,0,0,0,0,0,0,0,0,148,49,0,0,32,26,0,0,0,0,0,0,0,0,0,0,186,38,0,0,46,26,0,0,198,10,0,0,36,2,0,0,56,3,0,0,0,0,0,0,88,9,0,0,0,0,0,0,32,2,0,0,128,1,0,0,0,1,0,0,4,0,0,0,3,0,0,0,32,12,8,0,0,0,0,0,0,0,0,0,0,0,0,0,104,174,7,0,64,214,7,0,0,0,0,0,152,54,6,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,6,17,0,1,0,0,0,0,0,0,0,0,0,0,24,51,0,0,214,2,0,0,0,0,0,0,0,0,0,0,186,38,0,0,46,26,0,0,198,10,0,0,36,2,0,0,56,3,0,0,0,0,0,0,88,9,0,0,0,0,0,0,32,2,0,0,128,1,0,0,0,1,0,0,4,0,0,0,3,0,0,0,48,65,4,0,48,117,4,0,0,0,0,0,0,0,0,0,160,234,7,0,200,36,4,0,0,0,0,0,232,9,4,0,64,10,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,17,0,8,0,0,0,0,0,0,0,0,0,0,232,4,0,0,108,23,0,0,0,0,0,0,0,0,0,0,62,25,0,0,144,17,0,0,174,11,0,0,60,6,0,0,250,15,0,0,0,0,0,0,194,0,0,0,0,0,0,0,0,2,0,0,128,1,0,0,0,1,0,0,4,0,0,0,3,0,0,0,48,117,4,0,0,0,0,0,0,0,0,0,0,0,0,0,160,234,7,0,8,93,4,0,0,0,0,0,152,54,6,0,64,10,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,17,0,8,0,0,0,0,0,0,0,0,0,0,214,55,0,0,186,32,0,0,0,0,0,0,0,0,0,0,62,25,0,0,144,17,0,0,174,11,0,0,60,6,0,0,250,15,0,0,0,0,0,0,194,0,0,0,0,0,0,0,0,2,0,0,128,1,0,0,0,1,0,0,4,0,0,0,3,0,0,0,120,208,5,0,48,240,5,0,0,0,0,0,0,0,0,0,56,172,6,0,64,204,5,0,0,0,0,0,72,233,5,0,216,229,5,0,184,199,5,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,4,0,0,0,2,0,0,8,2,0,0,0,0,0,0,0,0,0,0,0,220,8,0,0,250,13,0,0,0,0,0,0,0,0,0,0,104,35,0,0,16,44,0,0,210,15,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,224,0,0,0,192,1,0,0,3,0,0,0,4,0,0,0,192,221,5,0,48,240,5,0,0,0,0,0,0,0,0,0,56,172,6,0,144,217,5,0,0,0,0,0,72,233,5,0,216,229,5,0,168,212,5,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,4,0,0,0,2,0,0,8,2,0,0,0,0,0,0,0,0,0,0,0,196,36,0,0,164,7,0,0,0,0,0,0,0,0,0,0,104,35,0,0,16,44,0,0,210,15,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,224,0,0,0,192,1,0,0,3,0,0,0,4,0,0,0,48,240,5,0,0,0,0,0,0,0,0,0,0,0,0,0,56,172,6,0,160,236,5,0,0,0,0,0,72,233,5,0,216,229,5,0,8,226,5,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,4,0,0,0,2,0,0,8,2,0,0,0,0,0,0,0,0,0,0,0,168,42,0,0,212,2,0,0,0,0,0,0,0,0,0,0,104,35,0,0,16,44,0,0,210,15,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,224,0,0,0,192,1,0,0,3,0,0,0,4,0,0,0,224,34,1,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,88,25,1,0,0,0,0,0,40,16,1,0,0,227,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,1,21,0,0,1,0,0,0,0,0,0,0,0,0,24,30,0,0,210,20,0,0,0,0,0,0,0,0,0,0,4,8,0,0,234,17,0,0,220,1,0,0,248,19,0,0,72,13,0,0,198,3,0,0,96,10,0,0,224,174,145,0,0,2,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,152,159,2,0,0,0,0,0,0,0,0,0,0,0,0,0,144,139,6,0,192,234,5,0,0,0,0,0,192,154,4,0,16,128,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,3,4,4,0,0,0,0,0,0,0,0,0,0,0,218,62,0,0,228,18,0,0,0,0,0,0,0,0,0,0,116,6,0,0,96,27,0,0,152,16,0,0,56,8,0,0,118,3,0,0,16,2,0,0,134,60,0,0,32,146,215,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,192,187,1,0,240,16,2,0,0,0,0,0,0,0,0,0,200,190,7,0,72,90,1,0,0,0,0,0,176,237,2,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,19,1,8,0,0,0,0,0,0,0,0,0,0,68,38,0,0,250,21,0,0,0,0,0,0,0,0,0,0,224,53,0,0,92,61,0,0,208,14,0,0,152,11,0,0,102,11,0,0,74,1,0,0,174,15,0,0,64,173,145,0,0,3,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,192,172,2,0,240,16,2,0,0,0,0,0,0,0,0,0,200,190,7,0,208,38,2,0,0,0,0,0,168,138,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,19,1,8,0,0,0,0,0,0,0,0,0,0,14,22,0,0,242,7,0,0,0,0,0,0,0,0,0,0,224,53,0,0,92,61,0,0,16,1,0,0,152,11,0,0,102,11,0,0,74,1,0,0,174,15,0,0,64,173,145,0,0,3,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,240,16,2,0,0,0,0,0,0,0,0,0,0,0,0,0,200,190,7,0,224,190,5,0,0,0,0,0,168,138,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,19,1,8,0,0,0,0,0,0,0,0,0,0,32,20,0,0,108,33,0,0,0,0,0,0,0,0,0,0,224,53,0,0,92,61,0,0,16,1,0,0,152,11,0,0,102,11,0,0,74,1,0,0,174,15,0,0,64,173,145,0,0,3,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,144,210,1,0,0,0,0,0,0,0,0,0,0,0,0,0,168,163,7,0,104,113,1,0,0,0,0,0,176,192,4,0,208,160,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,16,0,0,0,0,0,0,0,0,0,0,102,4,0,0,24,13,0,0,0,0,0,0,0,0,0,0,46,49,0,0,66,31,0,0,218,6,0,0,108,13,0,0,240,15,0,0,166,8,0,0,248,24,0,0,40,174,145,0,0,8,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,121,1,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,64,39,1,0,0,0,0,0,224,189,4,0,168,155,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,4,0,0,0,0,0,0,10,4,0,0,0,0,0,0,0,0,0,0,0,202,28,0,0,132,18,0,0,0,0,0,0,0,0,0,0,226,18,0,0,232,34,0,0,52,17,0,0,80,4,0,0,130,18,0,0,68,13,0,0,26,56,0,0,0,0,0,0,0,8,0,0,96,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,104,228,8,0,120,121,1,0,0,0,0,0,0,0,0,0,144,47,2,0,8,162,8,0,0,0,0,0,224,189,4,0,168,155,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,4,0,0,0,0,0,0,10,4,0,0,0,0,0,0,0,0,0,0,0,16,34,0,0,100,15,0,0,0,0,0,0,0,0,0,0,226,18,0,0,232,34,0,0,52,17,0,0,80,4,0,0,130,18,0,0,68,13,0,0,26,56,0,0,0,0,0,0,0,8,0,0,96,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,16,100,8,0,120,121,1,0,0,0,0,0,0,0,0,0,144,47,2,0,152,43,8,0,0,0,0,0,224,189,4,0,168,155,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,4,0,0,0,0,0,0,10,4,0,0,0,0,0,0,0,0,0,0,0,60,3,0,0,60,14,0,0,0,0,0,0,0,0,0,0,226,18,0,0,232,34,0,0,52,17,0,0,80,4,0,0,130,18,0,0,68,13,0,0,26,56,0,0,0,0,0,0,0,8,0,0,96,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,40,151,2,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,152,139,2,0,0,0,0,0,152,128,2,0,0,227,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,21,0,0,1,0,0,0,0,0,0,0,0,0,8,38,0,0,62,8,0,0,0,0,0,0,0,0,0,0,152,0,0,0,66,48,0,0,24,10,0,0,248,19,0,0,72,13,0,0,56,10,0,0,96,10,0,0,224,174,145,0,0,6,0,0,128,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,160,86,3,0,120,136,1,0,0,0,0,0,0,0,0,0,224,56,7,0,64,72,3,0,0,0,0,0,192,154,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,8,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,204,52,0,0,170,31,0,0,0,0,0,0,0,0,0,0,86,51,0,0,114,62,0,0,8,7,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,224,234,6,0,88,214,7,0,0,0,0,0,0,0,0,0,240,3,2,0,48,193,6,0,240,56,5,0,152,54,6,0,168,38,3,0,32,146,6,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,5,17,1,0,0,0,0,0,0,0,0,0,0,0,110,3,0,0,60,18,0,0,0,0,0,0,0,0,0,0,58,34,0,0,120,16,0,0,110,8,0,0,218,2,0,0,114,1,0,0,166,3,0,0,116,50,0,0,8,211,148,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,224,192,4,0,88,69,5,0,0,0,0,0,0,0,0,0,104,174,7,0,200,160,4,0,216,228,4,0,144,84,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,3,11,0,0,1,0,0,0,0,0,0,0,0,0,238,1,0,0,218,28,0,0,0,0,0,0,0,0,0,0,68,17,0,0,70,33,0,0,68,12,0,0,82,3,0,0,246,2,0,0,152,1,0,0,92,6,0,0,144,173,145,0,0,2,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,80,130,4,0,88,69,5,0,0,0,0,0,0,0,0,0,96,135,2,0,224,76,4,0,216,228,4,0,144,84,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,3,11,0,0,1,0,0,0,0,0,0,0,0,0,222,28,0,0,2,30,0,0,0,0,0,0,0,0,0,0,68,17,0,0,70,33,0,0,68,12,0,0,82,3,0,0,246,2,0,0,152,1,0,0,92,6,0,0,144,173,145,0,0,2,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,88,69,5,0,0,0,0,0,0,0,0,0,0,0,0,0,104,174,7,0,120,8,5,0,216,228,4,0,88,90,7,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,2,0,0,0,0,0,3,11,0,0,1,0,0,0,0,0,0,0,0,0,4,47,0,0,6,5,0,0,0,0,0,0,0,0,0,0,68,17,0,0,70,33,0,0,68,12,0,0,82,3,0,0,246,2,0,0,152,1,0,0,92,6,0,0,144,173,145,0,0,2,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,80,170,2,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,144,237,5,0,0,0,0,0,160,150,4,0,16,128,3,0,64,190,2,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,2,4,4,0,0,0,0,0,0,0,0,0,0,0,48,62,0,0,184,37,0,0,0,0,0,0,0,0,0,0,32,62,0,0,32,60,0,0,30,13,0,0,232,10,0,0,26,7,0,0,252,6,0,0,236,6,0,0,32,146,215,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,224,128,2,0,104,180,2,0,0,0,0,0,0,0,0,0,104,129,6,0,192,113,2,0,0,0,0,0,32,102,2,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,10,0,8,0,0,0,0,0,0,0,0,0,0,216,9,0,0,134,20,0,0,0,0,0,0,0,0,0,0,152,7,0,0,220,55,0,0,176,17,0,0,216,14,0,0,236,14,0,0,0,0,0,0,224,13,0,0,0,0,0,0,0,4,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,104,180,2,0,0,0,0,0,0,0,0,0,0,0,0,0,104,129,6,0,72,151,2,0,0,0,0,0,0,188,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,8,0,0,0,0,0,0,0,0,0,0,138,1,0,0,24,26,0,0,0,0,0,0,0,0,0,0,152,7,0,0,220,55,0,0,176,17,0,0,216,14,0,0,236,14,0,0,0,0,0,0,224,13,0,0,0,0,0,0,0,4,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,240,123,1,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,88,229,8,0,0,0,0,0,184,191,7,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,8,0,0,0,0,0,0,0,0,0,0,28,6,0,0,152,41,0,0,0,0,0,0,0,0,0,0,158,13,0,0,204,4,0,0,26,11,0,0,56,15,0,0,12,17,0,0,0,0,0,0,224,13,0,0,0,0,0,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,248,8,5,0,32,244,5,0,0,0,0,0,0,0,0,0,184,168,7,0,112,193,4,0,0,0,0,0,192,154,4,0,128,194,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,3,11,0,8,0,0,0,0,0,0,0,0,0,0,28,63,0,0,0,8,0,0,0,0,0,0,0,0,0,0,2,60,0,0,6,28,0,0,22,13,0,0,46,1,0,0,106,16,0,0,0,0,0,0,78,54,0,0,0,0,0,0,0,32,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,65,5,0,208,76,5,0,0,0,0,0,0,0,0,0,216,194,1,0,160,63,5,0,0,0,0,0,192,154,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,8,0,0,2,0,0,0,0,0,0,16,1,0,0,0,0,0,0,0,0,0,0,0,106,51,0,0,228,36,0,0,0,0,0,0,0,0,0,0,244,36,0,0,30,11,0,0,76,6,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,208,76,5,0,0,0,0,0,0,0,0,0,0,0,0,0,216,194,1,0,184,72,5,0,0,0,0,0,80,68,5,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,8,0,0,2,0,0,0,0,0,0,16,1,0,0,0,0,0,0,0,0,0,0,0,110,63,0,0,204,30,0,0,0,0,0,0,0,0,0,0,244,36,0,0,30,11,0,0,76,6,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,96,200,7,0,144,19,5,0,0,0,0,0,0,0,0,0,184,168,7,0,160,151,7,0,0,0,0,0,192,154,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,192,24,0,0,160,33,0,0,0,0,0,0,0,0,0,0,150,57,0,0,148,47,0,0,222,15,0,0,192,19,0,0,240,14,0,0,148,14,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,105,8,0,144,19,5,0,0,0,0,0,0,0,0,0,184,168,7,0,136,49,8,0,0,0,0,0,128,253,7,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,232,3,0,0,224,1,0,0,0,0,0,0,0,0,0,0,98,20,0,0,130,5,0,0,234,11,0,0,192,19,0,0,250,11,0,0,144,3,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,234,8,0,144,19,5,0,0,0,0,0,0,0,0,0,184,168,7,0,104,169,8,0,0,0,0,0,72,218,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,246,11,0,0,232,21,0,0,0,0,0,0,0,0,0,0,150,57,0,0,148,47,0,0,46,12,0,0,192,19,0,0,240,14,0,0,148,14,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,58,4,0,16,110,5,0,0,0,0,0,16,110,5,0,232,167,7,0,144,30,4,0,0,0,0,0,192,154,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,232,51,0,0,190,26,0,0,64,47,0,0,136,24,0,0,46,36,0,0,104,16,0,0,174,14,0,0,198,18,0,0,98,13,0,0,38,13,0,0,0,0,0,0,136,175,145,0,0,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,240,82,2,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,32,70,2,0,120,161,2,0,200,56,2,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,3,11,0,0,1,0,0,0,0,0,0,0,0,0,34,18,0,0,238,45,0,0,0,0,0,0,0,0,0,0,8,47,0,0,130,22,0,0,142,12,0,0,82,3,0,0,246,2,0,0,152,1,0,0,92,6,0,0,144,173,145,0,0,2,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,101,4,0,0,0,0,0,72,172,6,0,0,0,0,0,104,221,5,0,80,63,2,0,0,0,0,0,128,145,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,0,16,0,0,0,0,0,0,0,0,0,0,136,59,0,0,66,43,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,63,3,0,0,72,5,0,0,0,0,0,0,0,0,0,192,177,6,0,56,47,3,0,0,0,0,0,192,223,4,0,0,151,3,0,40,25,3,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,9,8,0,0,0,0,0,0,0,0,0,0,0,238,49,0,0,106,46,0,0,0,0,0,0,0,0,0,0,38,11,0,0,140,5,0,0,182,19,0,0,228,2,0,0,0,13,0,0,0,0,0,0,166,23,0,0,240,121,145,0,0,0,4,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,24,4,0,0,72,5,0,0,0,0,0,0,0,0,0,192,177,6,0,216,249,3,0,0,0,0,0,192,223,4,0,0,151,3,0,152,216,3,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,9,8,0,0,0,0,0,0,0,0,0,0,0,154,9,0,0,34,26,0,0,0,0,0,0,0,0,0,0,38,11,0,0,140,5,0,0,130,15,0,0])
.concat([228,2,0,0,0,13,0,0,0,0,0,0,166,23,0,0,240,121,145,0,0,0,4,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,194,2,0,0,72,5,0,0,0,0,0,0,0,0,0,192,177,6,0,0,177,2,0,0,0,0,0,192,223,4,0,0,151,3,0,64,162,2,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,1,0,0,9,8,0,0,0,0,0,0,0,0,0,0,0,76,38,0,0,58,46,0,0,0,0,0,0,0,0,0,0,38,11,0,0,68,11,0,0,182,19,0,0,228,2,0,0,0,13,0,0,0,0,0,0,166,23,0,0,240,121,145,0,0,0,4,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,113,3,0,0,72,5,0,0,0,0,0,0,0,0,0,192,177,6,0,32,91,3,0,0,0,0,0,192,223,4,0,0,151,3,0,56,76,3,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,1,0,0,9,8,0,0,0,0,0,0,0,0,0,0,0,86,53,0,0,198,31,0,0,0,0,0,0,0,0,0,0,38,11,0,0,68,11,0,0,130,15,0,0,228,2,0,0,0,13,0,0,0,0,0,0,166,23,0,0,240,121,145,0,0,0,4,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,105,4,0,0,72,5,0,0,0,0,0,0,0,0,0,192,177,6,0,128,78,4,0,0,0,0,0,192,223,4,0,0,151,3,0,0,52,4,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,1,0,0,9,8,0,0,0,0,0,0,0,0,0,0,0,184,40,0,0,62,41,0,0,0,0,0,0,0,0,0,0,38,11,0,0,68,11,0,0,130,15,0,0,228,2,0,0,0,13,0,0,0,0,0,0,166,23,0,0,240,121,145,0,0,0,4,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,2,3,0,0,72,5,0,0,0,0,0,0,0,0,0,192,177,6,0,248,236,2,0,0,0,0,0,192,223,4,0,0,151,3,0,56,212,2,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,9,8,0,0,0,0,0,0,0,0,0,0,0,232,35,0,0,118,27,0,0,0,0,0,0,0,0,0,0,38,11,0,0,140,18,0,0,182,19,0,0,228,2,0,0,0,13,0,0,0,0,0,0,166,23,0,0,240,121,145,0,0,0,4,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,188,3,0,0,72,5,0,0,0,0,0,0,0,0,0,192,177,6,0,216,162,3,0,0,0,0,0,192,223,4,0,0,151,3,0,112,136,3,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,9,8,0,0,0,0,0,0,0,0,0,0,0,26,30,0,0,178,37,0,0,0,0,0,0,0,0,0,0,38,11,0,0,140,18,0,0,130,15,0,0,228,2,0,0,0,13,0,0,0,0,0,0,166,23,0,0,240,121,145,0,0,0,4,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,194,4,0,0,72,5,0,0,0,0,0,0,0,0,0,192,177,6,0,112,162,4,0,0,0,0,0,192,223,4,0,0,151,3,0,208,131,4,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,9,8,0,0,0,0,0,0,0,0,0,0,0,204,32,0,0,100,13,0,0,0,0,0,0,0,0,0,0,38,11,0,0,140,18,0,0,130,15,0,0,228,2,0,0,0,13,0,0,0,0,0,0,166,23,0,0,240,121,145,0,0,0,4,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,31,2,0,72,149,2,0,0,0,0,0,0,0,0,0,144,139,6,0,200,20,2,0,0,0,0,0,192,223,4,0,0,151,3,0,192,11,2,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,0,0,0,9,8,0,0,0,0,0,0,0,0,0,0,0,92,60,0,0,190,43,0,0,0,0,0,0,0,0,0,0,38,11,0,0,50,36,0,0,110,12,0,0,228,2,0,0,0,13,0,0,0,0,0,0,166,23,0,0,240,121,145,0,0,0,4,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,4,2,0,72,149,2,0,0,0,0,0,0,0,0,0,144,139,6,0,0,247,1,0,0,0,0,0,192,223,4,0,0,151,3,0,80,237,1,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,1,0,0,9,8,0,0,0,0,0,0,0,0,0,0,0,218,20,0,0,212,30,0,0,0,0,0,0,0,0,0,0,38,11,0,0,50,36,0,0,110,12,0,0,228,2,0,0,0,13,0,0,0,0,0,0,166,23,0,0,240,121,145,0,0,0,4,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,226,1,0,72,149,2,0,0,0,0,0,0,0,0,0,144,139,6,0,240,210,1,0,0,0,0,0,192,223,4,0,0,151,3,0,56,199,1,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,1,0,0,9,8,0,0,0,0,0,0,0,0,0,0,0,48,12,0,0,154,40,0,0,0,0,0,0,0,0,0,0,38,11,0,0,16,62,0,0,110,12,0,0,228,2,0,0,0,13,0,0,0,0,0,0,166,23,0,0,240,121,145,0,0,0,4,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,71,2,0,72,149,2,0,0,0,0,0,0,0,0,0,144,139,6,0,200,57,2,0,0,0,0,0,192,223,4,0,0,151,3,0,184,42,2,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,1,0,0,9,8,0,0,0,0,0,0,0,0,0,0,0,150,24,0,0,174,3,0,0,0,0,0,0,0,0,0,0,38,11,0,0,16,62,0,0,110,12,0,0,228,2,0,0,0,13,0,0,0,0,0,0,166,23,0,0,240,121,145,0,0,0,4,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,110,2,0,72,149,2,0,0,0,0,0,0,0,0,0,144,139,6,0,248,99,2,0,0,0,0,0,192,223,4,0,0,151,3,0,64,84,2,0,0,0,0,0,0,0,0,0,0,0,0,0,145,0,0,0,2,0,0,0,1,0,0,9,8,0,0,0,0,0,0,0,0,0,0,0,48,17,0,0,64,47,0,0,0,0,0,0,0,0,0,0,38,11,0,0,50,36,0,0,110,12,0,0,228,2,0,0,0,13,0,0,0,0,0,0,166,23,0,0,240,121,145,0,0,0,4,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,149,2,0,0,0,0,0,0,0,0,0,0,0,0,0,144,139,6,0,24,137,2,0,0,0,0,0,192,223,4,0,0,151,3,0,176,124,2,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,9,8,0,0,0,0,0,0,0,0,0,0,0,180,57,0,0,122,23,0,0,0,0,0,0,0,0,0,0,38,11,0,0,50,36,0,0,110,12,0,0,228,2,0,0,0,13,0,0,0,0,0,0,166,23,0,0,240,121,145,0,0,0,4,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,72,5,0,0,0,0,0,0,0,0,0,0,0,0,0,192,177,6,0,0,10,5,0,0,0,0,0,192,223,4,0,0,151,3,0,0,231,4,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,9,8,0,0,0,0,0,0,0,0,0,0,0,188,28,0,0,76,36,0,0,0,0,0,0,0,0,0,0,38,11,0,0,140,5,0,0,130,15,0,0,228,2,0,0,0,13,0,0,0,0,0,0,166,23,0,0,240,121,145,0,0,0,4,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,157,2,0,184,169,1,0,0,0,0,0,0,0,0,0,0,38,7,0,32,28,2,0,0,0,0,0,0,193,8,0,240,85,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,19,0,8,0,0,0,0,0,0,0,0,0,0,142,61,0,0,122,34,0,0,0,0,0,0,0,0,0,0,108,48,0,0,228,33,0,0,38,0,0,0,32,4,0,0,120,0,0,0,54,14,0,0,62,2,0,0,8,173,145,0,0,4,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,184,169,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,224,148,5,0,0,0,0,0,0,193,8,0,240,85,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,19,0,8,0,0,0,0,0,0,0,0,0,0,64,57,0,0,156,42,0,0,0,0,0,0,0,0,0,0,108,48,0,0,228,33,0,0,20,17,0,0,32,4,0,0,120,0,0,0,54,14,0,0,62,2,0,0,8,173,145,0,0,4,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,120,8,1,0,152,159,1,0,0,0,0,0,0,0,0,0,144,47,2,0,104,201,8,0,0,0,0,0,176,237,2,0,168,84,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,19,0,8,0,0,0,0,0,0,0,0,0,0,0,2,0,0,246,39,0,0,0,0,0,0,0,0,0,0,122,30,0,0,68,18,0,0,32,12,0,0,192,10,0,0,42,10,0,0,28,16,0,0,112,12,0,0,0,173,145,0,0,8,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,40,253,8,0,64,11,1,0,0,0,0,0,0,0,0,0,240,3,2,0,240,246,8,0,0,0,0,0,88,0,1,0,0,227,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,21,0,0,1,0,0,0,0,0,0,0,0,0,208,29,0,0,210,17,0,0,0,0,0,0,0,0,0,0,94,4,0,0,44,28,0,0,220,18,0,0,248,19,0,0,72,13,0,0,56,10,0,0,96,10,0,0,224,174,145,0,0,18,0,0,128,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,48,240,8,0,64,11,1,0,0,0,0,0,0,0,0,0,240,3,2,0,184,232,8,0,0,0,0,0,192,154,4,0,0,227,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,21,0,0,1,0,0,0,0,0,0,0,0,0,86,10,0,0,116,21,0,0,0,0,0,0,0,0,0,0,94,4,0,0,44,28,0,0,124,6,0,0,248,19,0,0,72,13,0,0,56,10,0,0,96,10,0,0,224,174,145,0,0,18,0,0,128,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,64,11,1,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,96,5,1,0,0,0,0,0,88,0,1,0,0,227,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,21,0,0,1,0,0,0,0,0,0,0,0,0,48,53,0,0,90,7,0,0,0,0,0,0,0,0,0,0,94,4,0,0,44,28,0,0,220,18,0,0,248,19,0,0,72,13,0,0,56,10,0,0,96,10,0,0,224,174,145,0,0,18,0,0,128,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,56,249,3,0,0,162,4,0,0,0,0,0,0,0,0,0,104,174,7,0,56,215,3,0,0,0,0,0,144,84,8,0,128,194,2,0,40,187,3,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,11,0,8,0,0,0,0,0,0,0,0,0,0,220,43,0,0,114,15,0,0,0,0,0,0,0,0,0,0,20,58,0,0,58,12,0,0,34,12,0,0,224,17,0,0,14,8,0,0,2,1,0,0,74,29,0,0,0,0,0,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,211,2,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,168,70,2,0,0,0,0,0,72,187,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,2,14,8,0,0,0,0,0,0,0,0,0,0,0,96,46,0,0,6,23,0,0,0,0,0,0,0,0,0,0,146,8,0,0,140,3,0,0,220,13,0,0,150,0,0,0,204,16,0,0,92,17,0,0,98,23,0,0,56,174,145,0,0,128,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,168,144,3,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,80,35,6,0,0,0,0,0,72,187,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,2,14,8,0,0,0,0,0,0,0,0,0,0,0,44,27,0,0,126,47,0,0,0,0,0,0,0,0,0,0,146,8,0,0,224,2,0,0,220,13,0,0,150,0,0,0,204,16,0,0,92,17,0,0,98,23,0,0,56,174,145,0,0,128,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,232,222,6,0,0,0,0,0,0,0,0,0,0,0,0,0,160,217,6,0,216,212,6,0,48,208,6,0,112,204,6,0,48,201,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,0,0,0,0,0,0,0,68,4,2,16,0,0,0,0,0,0,0,0,0,0,0,80,56,0,0,224,32,0,0,0,0,0,0,0,0,0,0,180,12,0,0,0,0,0,0,198,17,0,0,162,0,0,0,134,11,0,0,0,0,0,0,2,13,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,118,6,0,0,0,0,0,72,172,6,0,0,0,0,0,184,12,8,0,104,114,6,0,0,0,0,0,104,111,6,0,208,9,3,0,16,107,6,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,32,1,5,0,0,1,0,0,0,0,0,0,0,0,0,122,49,0,0,216,34,0,0,0,0,0,0,0,0,0,0,200,33,0,0,54,39,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,67,7,0,88,214,7,0,0,0,0,0,0,0,0,0,240,3,2,0,56,23,7,0,240,56,5,0,144,234,6,0,168,38,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,5,17,1,0,0,0,0,0,0,0,0,0,0,0,218,3,0,0,14,37,0,0,0,0,0,0,0,0,0,0,58,34,0,0,120,16,0,0,110,8,0,0,218,2,0,0,114,1,0,0,166,3,0,0,116,50,0,0,8,211,148,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,88,214,7,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,80,118,7,0,240,56,5,0,152,54,6,0,168,38,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,5,17,1,0,0,0,0,0,0,0,0,0,0,0,114,59,0,0,22,38,0,0,0,0,0,0,0,0,0,0,58,34,0,0,120,16,0,0,110,8,0,0,218,2,0,0,114,1,0,0,166,3,0,0,116,50,0,0,8,211,148,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,208,123,2,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,240,98,2,0,0,0,0,0,168,183,7,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,3,11,0,0,1,0,0,0,0,0,0,0,0,0,156,62,0,0,6,22,0,0,0,0,0,0,0,0,0,0,78,59,0,0,216,53,0,0,206,3,0,0,82,3,0,0,246,2,0,0,152,1,0,0,92,6,0,0,144,173,145,0,0,2,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,53,4,0,192,105,4,0,0,0,0,0,0,0,0,0,64,171,7,0,0,25,4,0,0,0,0,0,16,182,4,0,192,152,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,9,2,0,1,0,0,0,0,0,0,0,0,0,0,0,18,0,0,158,41,0,0,0,0,0,0,0,0,0,0,94,27,0,0,4,0,0,0,156,7,0,0,42,17,0,0,184,7,0,0,0,0,0,0,216,46,0,0,0,0,0,0,0,6,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,105,4,0,0,0,0,0,0,0,0,0,0,0,0,0,64,171,7,0,8,79,4,0,0,0,0,0,16,182,4,0,192,152,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,9,2,0,1,0,0,0,0,0,0,0,0,0,0,98,58,0,0,234,15,0,0,0,0,0,0,0,0,0,0,94,27,0,0,4,0,0,0,156,7,0,0,42,17,0,0,184,7,0,0,0,0,0,0,216,46,0,0,0,0,0,0,0,6,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,147,4,0,224,212,4,0,0,0,0,0,0,0,0,0,104,174,7,0,112,117,4,0,0,0,0,0,152,54,6,0,200,12,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,3,17,2,0,0,0,0,0,0,0,0,0,0,0,40,7,0,0,248,8,0,0,0,0,0,0,0,0,0,0,198,62,0,0,76,46,0,0,10,3,0,0,230,1,0,0,44,6,0,0,194,15,0,0,0,0,0,0,48,177,145,0,0,2,0,0,0,1,0,0,128,1,0,0,3,0,0,0,4,0,0,0,224,212,4,0,0,0,0,0,0,0,0,0,0,0,0,0,104,174,7,0,0,179,4,0,0,0,0,0,152,54,6,0,200,12,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,3,17,2,0,0,0,0,0,0,0,0,0,0,0,192,36,0,0,116,9,0,0,0,0,0,0,0,0,0,0,198,62,0,0,76,46,0,0,10,3,0,0,230,1,0,0,44,6,0,0,194,15,0,0,0,0,0,0,48,177,145,0,0,2,0,0,0,1,0,0,128,1,0,0,3,0,0,0,4,0,0,0,32,148,5,0,0,0,0,0,0,0,0,0,0,0,0,0,64,171,7,0,216,115,6,0,0,0,0,0,152,196,7,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,0,0,0,0,56,53,0,0,82,43,0,0,0,0,0,0,0,0,0,0,166,44,0,0,60,24,0,0,184,16,0,0,116,6,0,0,6,11,0,0,252,16,0,0,54,48,0,0,24,176,145,0,0,4,0,0,240,0,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,56,7,0,0,0,0,0,0,0,0,0,0,0,0,0,232,233,7,0,80,225,6,0,88,181,6,0,40,98,7,0,160,201,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,1,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,30,40,0,0,150,33,0,0,0,0,0,0,0,0,0,0,72,61,0,0,108,22,0,0,102,5,0,0,44,18,0,0,234,15,0,0,250,18,0,0,102,10,0,0,208,175,145,0,32,0,0,0,236,0,0,0,16,1,0,0,3,0,0,0,4,0,0,0,176,249,1,0,40,1,8,0,0,0,0,0,0,0,0,0,104,174,7,0,80,153,1,0,0,0,0,0,168,95,8,0,32,253,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,0,3,0,64,0,0,0,0,0,0,0,0,0,0,110,41,0,0,108,32,0,0,0,0,0,0,0,0,0,0,252,5,0,0,236,56,0,0,92,14,0,0,144,5,0,0,134,8,0,0,30,8,0,0,238,55,0,0,168,176,145,0,0,8,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,228,2,0,208,82,4,0,0,0,0,0,0,0,0,0,32,127,5,0,24,79,2,0,0,0,0,0,224,218,4,0,48,178,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,0,10,0,1,0,0,0,0,0,0,0,0,0,0,188,24,0,0,186,41,0,0,0,0,0,0,0,0,0,0,116,30,0,0,230,62,0,0,156,19,0,0,222,19,0,0,52,15,0,0,0,0,0,0,36,38,0,0,0,0,0,0,0,2,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,82,4,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,184,62,6,0,0,0,0,0,224,218,4,0,48,178,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,1,0,0,0,0,0,0,0,0,0,0,204,33,0,0,70,7,0,0,0,0,0,0,0,0,0,0,116,30,0,0,230,62,0,0,156,19,0,0,222,19,0,0,52,15,0,0,0,0,0,0,36,38,0,0,0,0,0,0,0,2,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,110,8,0,64,123,8,0,0,0,0,0,0,0,0,0,200,190,7,0,200,103,8,0,0,0,0,0,40,161,4,0,80,150,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,64,4,4,2,8,0,0,0,0,0,0,0,0,0,0,0,122,54,0,0,12,29,0,0,0,0,0,0,0,0,0,0,22,58,0,0,44,46,0,0,48,18,0,0,14,9,0,0,134,11,0,0,0,0,0,0,156,7,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,123,8,0,0,0,0,0,0,0,0,0,0,0,0,0,200,190,7,0,40,117,8,0,0,0,0,0,40,161,4,0,80,150,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,4,4,2,8,0,0,0,0,0,0,0,0,0,0,0,120,56,0,0,86,42,0,0,0,0,0,0,0,0,0,0,22,58,0,0,44,46,0,0,48,18,0,0,14,9,0,0,134,11,0,0,0,0,0,0,156,7,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,163,4,0,0,0,0,0,0,0,0,0,0,0,0,0,64,171,7,0,232,132,4,0,0,0,0,0,40,161,4,0,192,152,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,9,2,2,0,0,0,0,0,0,0,0,0,0,0,4,1,0,0,70,40,0,0,0,0,0,0,0,0,0,0,94,27,0,0,100,59,0,0,46,10,0,0,42,17,0,0,184,7,0,0,0,0,0,0,216,46,0,0,0,0,0,0,0,6,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,227,2,0,160,139,5,0,0,0,0,0,0,0,0,0,216,194,1,0,88,225,2,0,0,0,0,0,192,154,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,8,0,0,2,0,0,0,0,0,0,16,0,64,0,0,0,0,0,0,0,0,0,0,180,34,0,0,4,37,0,0,0,0,0,0,0,0,0,0,26,12,0,0,28,22,0,0,78,2,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,160,139,5,0,0,0,0,0,0,0,0,0,0,0,0,0,216,194,1,0,48,234,2,0,0,0,0,0,168,95,8,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,8,0,0,2,0,0,0,0,0,0,16,0,64,0,0,0,0,0,0,0,0,0,0,36,45,0,0,40,16,0,0,0,0,0,0,0,0,0,0,26,12,0,0,28,22,0,0,102,10,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,56,32,6,0,0,0,0,0,0,0,0,0,0,0,0,0,232,233,7,0,144,241,5,0,72,150,4,0,168,201,5,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,76,57,0,0,228,35,0,0,0,0,0,0,0,0,0,0,36,31,0,0,0,0,0,0,200,16,0,0,128,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,216,160,2,0,8,211,6,0,0,0,0,0,0,0,0,0,64,164,6,0,168,159,2,0,0,0,0,0,152,73,6,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,8,0,0,2,0,0,0,0,0,0,16,0,8,0,0,0,0,0,0,0,0,0,0,50,16,0,0,150,3,0,0,0,0,0,0,0,0,0,0,144,54,0,0,234,28,0,0,74,5,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,24,201,2,0,8,211,6,0,0,0,0,0,0,0,0,0,216,194,1,0,40,196,2,0,0,0,0,0,152,73,6,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,8,0,0,2,0,0,0,0,0,0,16,0,8,0,0,0,0,0,0,0,0,0,0,138,14,0,0,62,43,0,0,0,0,0,0,0,0,0,0,90,40,0,0,208,60,0,0,116,16,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,8,211,6,0,0,0,0,0,0,0,0,0,0,0,0,0,64,164,6,0,136,123,6,0,72,150,4,0,152,73,6,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,188,32,0,0,56,30,0,0,0,0,0,0,0,0,0,0,36,31,0,0,0,0,0,0,200,16,0,0,128,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,192,45,3,0,40,90,3,0,0,0,0,0,0,0,0,0,104,221,5,0,64,21,3,0,0,0,0,0,144,84,8,0,208,135,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,2,11,0,128,0,0,0,0,0,0,0,0,0,0,66,42,0,0,82,1,0,0,0,0,0,0,0,0,0,0,2,46,0,0,208,58,0,0,246,4,0,0,46,7,0,0,246,17,0,0,0,0,0,0,176,18,0,0,0,0,0,0,0,32,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,88,6,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,56,0,6,0,0,0,0,0,224,218,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,16,0,0,0,0,0,0,0,0,0,0,40,53,0,0,62,29,0,0,0,0,0,0,0,0,0,0,124,14,0,0,210,16,0,0,196,2,0,0,56,15,0,0,12,17,0,0,0,0,0,0,224,13,0,0,0,0,0,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,80,23,5,0,24,183,5,0,0,0,0,0,0,0,0,0,104,174,7,0,0,245,4,0,0,0,0,0,168,95,8,0,128,115,5,0,32,211,4,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,3,0,64,0,0,0,0,0,0,0,0,0,0,50,40,0,0,166,0,0,0,0,0,0,0,0,0,0,0,176,49,0,0,78,61,0,0,122,15,0,0,156,9,0,0,198,15,0,0,232,8,0,0,42,6,0,0,216,176,145,0,0,4,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,203,3,0,32,210,3,0,0,0,0,0,0,0,0,0,232,167,7,0,40,201,3,0,0,0,0,0,192,154,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,0,0,0,2,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,0,0,0,0,30,1,0,0,22,5,0,0,0,0,0,0,0,0,0,0,100,28,0,0,252,25,0,0,160,2,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,32,210,3,0,0,0,0,0,0,0,0,0,0,0,0,0,232,167,7,0,160,207,3,0,0,0,0,0,248,204,3,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,2,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,0,0,0,0,180,48,0,0,48,3,0,0,0,0,0,0,0,0,0,0,100,28,0,0,252,25,0,0,160,2,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,96,221,2,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,128,217,1,0,0,0,0,0,160,118,1,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,1,0,0,0,0,0,0,10,0,4,0,0,0,0,0,0,0,0,0,0,80,55,0,0,236,16,0,0,0,0,0,0,0,0,0,0,54,42,0,0,130,0,0,0,114,18,0,0,12,10,0,0,194,10,0,0,228,15,0,0,96,60,0,0,144,174,145,0,0,132,0,0,224,0,0,0,0,2,0,0,3,0,0,0,4,0,0,0,160,228,8,0,0,0,0,0,0,0,0,0,0,0,0,0,168,163,7,0,32,162,8,0,0,0,0,0,160,213,4,0,112,163,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,16,0,0,0,0,0,0,0,0,0,0,144,36,0,0,36,5,0,0,0,0,0,0,0,0,0,0,234,8,0,0,182,39,0,0,242,9,0,0,16,8,0,0,80,3,0,0,0,0,0,0,176,0,0,0,0,0,0,0,0,4,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,249,7,0,0,0,0,0,0,0,0,0,0,0,0,0,104,129,6,0,200,148,7,0,0,0,0,0,232,163,8,0,192,181,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,13,0,0,2,0,0,0,0,0,0,0,0,0,116,62,0,0,138,47,0,0,0,0,0,0,0,0,0,0,40,10,0,0,156,25,0,0,24,17,0,0,228,6,0,0,224,8,0,0,166,2,0,0,2,43,0,0,0,0,0,0,2,16,0,0,128,2,0,0,224,0,0,0,8,0,0,0,3,0,0,0,248,124,1,0,0,0,0,0,0,0,0,0,0,0,0,0,144,139,6,0,56,230,8,0,0,0,0,0,232,163,8,0,192,181,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,13,0,0,2,0,0,0,0,0,0,0,0,0,96,29,0,0,186,47,0,0,0,0,0,0,0,0,0,0,40,10,0,0,156,25,0,0,10,7,0,0,228,6,0,0,224,8,0,0,166,2,0,0,2,43,0,0,0,0,0,0,2,16,0,0,128,2,0,0,224,0,0,0,8,0,0,0,3,0,0,0,72,113,4,0,0,0,0,0,0,0,0,0,0,0,0,0,184,12,8,0,96,66,6,0,0,0,0,0,232,163,8,0,192,181,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,13,0,0,2,0,0,0,0,0,0,0,0,0,242,17,0,0,68,41,0,0,0,0,0,0,0,0,0,0,40,10,0,0,156,25,0,0,68,3,0,0,228,6,0,0,224,8,0,0,166,2,0,0,2,43,0,0,0,0,0,0,2,16,0,0,128,2,0,0,224,0,0,0,8,0,0,0,3,0,0,0,8,164,8,0,0,0,0,0,0,0,0,0,0,0,0,0,184,230,7,0,88,45,8,0,0,0,0,0,232,163,8,0,192,181,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,13,0,0,2,0,0,0,0,0,0,0,0,0,56,55,0,0,164,15,0,0,0,0,0,0,0,0,0,0,40,10,0,0,156,25,0,0,10,7,0,0,228,6,0,0,224,8,0,0,166,2,0,0,2,43,0,0,0,0,0,0,2,16,0,0,128,2,0,0,224,0,0,0,8,0,0,0,3,0,0,0,64,177,6,0,0,0,0,0,0,0,0,0,0,0,0,0,184,230,7,0,136,134,6,0,0,0,0,0,160,88,6,0,192,181,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,13,0,32,0,0,0,0,0,0,0,0,0,0,218,42,0,0,172,34,0,0,0,0,0,0,0,0,0,0,18,39,0,0,126,28,0,0,62,18,0,0,228,6,0,0,224,8,0,0,166,2,0,0,2,43,0,0,0,0,0,0,2,16,0,0,128,2,0,0,240,0,0,0,8,0,0,0,3,0,0,0,88,5,2,0,184,32,2,0,0,0,0,0,0,0,0,0,192,177,6,0,112,249,1,0,0,0,0,0,16,239,1,0,80,164,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,10,0,16,0,0,0,0,0,0,0,0,0,0,202,9,0,0,110,41,0,0,0,0,0,0,0,0,0,0,244,56,0,0,30,6,0,0,44,7,0,0,88,18,0,0,228,5,0,0,4,6,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,202,2,0,0,0,0,0,0,0,0,0,0,0,0,0,64,171,7,0,136,183,2,0,0,0,0,0,152,54,6,0,64,10,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,17,1,0,0,0,0,0,0,0,0,0,0,0,102,31,0,0,72,15,0,0,0,0,0,0,0,0,0,0,62,25,0,0,114,18,0,0,114,2,0,0,60,6,0,0,250,15,0,0,0,0,0,0,194,0,0,0,0,0,0,0,0,2,0,0,0,1,0,0,0,1,0,0,4,0,0,0,3,0,0,0,200,10,7,0,136,151,7,0,0,0,0,0,0,0,0,0,200,190,7,0,104,224,6,0,0,0,0,0,192,154,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,53,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,114,27,0,0,184,24,0,0,0,0,0,0,0,0,0,0,132,5,0,0,158,47,0,0,244,10,0,0,180,14,0,0,36,3,0,0,0,0,0,0,42,52,0,0,136,35,149,0,16,17,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,136,151,7,0,0,0,0,0,0,0,0,0,0,0,0,0,200,190,7,0,40,54,7,0,0,0,0,0,72,226,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,47,0,0,204,3,0,0,0,0,0,0,0,0,0,0,132,5,0,0,158,47,0,0,244,10,0,0,180,14,0,0,36,3,0,0,0,0,0,0,42,52,0,0,136,35,149,0,16,17,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,32,120,2,0,232,228,8,0,0,0,0,0,0,0,0,0,96,135,2,0,144,1,2,0,240,56,5,0,144,234,6,0,168,38,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,5,17,4,0,0,0,0,0,0,0,0,0,0,0,8,41,0,0,62,48,0,0,0,0,0,0,0,0,0,0,50,9,0,0,222,3,0,0,12,1,0,0,218,2,0,0,114,1,0,0,166,3,0,0,116,50,0,0,8,211,148,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,112,63,1,0,232,228,8,0,0,0,0,0,0,0,0,0,96,135,2,0,192,250,8,0,240,56,5,0,152,54,6,0,168,38,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,5,17,4,0,0,0,0,0,0,0,0,0,0,0,6,13,0,0,196,20,0,0,0,0,0,0,0,0,0,0,50,9,0,0,222,3,0,0,12,1,0,0,218,2,0,0,114,1,0,0,166,3,0,0,116,50,0,0,8,211,148,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,232,228,8,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,120,195,6,0,240,56,5,0,152,54,6,0,168,38,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,4,0,0,0,0,0,5,17,4,0,0,0,0,0,0,0,0,0,0,0,80,50,0,0,160,31,0,0,0,0,0,0,0,0,0,0,50,9,0,0,222,3,0,0,12,1,0,0,218,2,0,0,114,1,0,0,166,3,0,0,116,50,0,0,8,211,148,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,88,222,3,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,16,192,3,0,0,0,0,0,40,253,3,0,48,178,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,16,0,0,0,0,0,0,0,0,0,0,120,13,0,0,62,42,0,0,0,0,0,0,0,0,0,0,116,30,0,0,104,4,0,0,42,6,0,0,222,19,0,0,196,19,0,0,0,0,0,0,36,38,0,0,0,0,0,0,0,8,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,159,2,0,56,32,6,0,0,0,0,0,0,0,0,0,232,233,7,0,88,157,2,0,216,228,4,0,152,73,6,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,8,0,0,2,0,0,0,0,0,0,16,0,64,0,0,0,0,0,0,0,0,0,0,134,52,0,0,38,16,0,0,0,0,0,0,0,0,0,0,144,54,0,0,234,28,0,0,160,19,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,136,211,2,0,128,21,3,0,0,0,0,0,0,0,0,0,104,221,5,0,16,193,2,0,120,161,2,0,80,176,2,0,168,196,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,5,11,0,64,0,0,0,0,0,0,0,0,0,0,176,39,0,0,210,34,0,0,0,0,0,0,0,0,0,0,220,20,0,0,244,19,0,0,240,11,0,0,178,11,0,0,82,0,0,0,238,10,0,0,188,1,0,0,0,0,0,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,21,3,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,216,0,3,0,120,161,2,0,80,235,2,0,168,196,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,5,11,0,64,0,0,0,0,0,0,0,0,0,0,166,18,0,0,212,47,0,0,0,0,0,0,0,0,0,0,220,20,0,0,244,19,0,0,240,11,0,0,178,11,0,0,82,0,0,0,238,10,0,0,188,1,0,0,0,0,0,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,33,6,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,240,202,5,0,0,0,0,0,168,138,8,0,248,135,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,19,8,0,0,0,0,0,0,0,0,0,0,0,190,12,0,0,50,37,0,0,0,0,0,0,0,0,0,0,72,1,0,0,114,22,0,0,46,15,0,0,116,8,0,0,90,13,0,0,0,0,0,0,68,58,0,0,0,0,0,0,0,4,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,208,56,3,0,136,84,3,0,0,0,0,0,0,0,0,0,104,221,5,0,8,38,3,0,0,0,0,0,144,234,6,0,232,200,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,17,4,8,0,0,0,0,0,0,0,0,0,0,96,9,0,0,212,31,0,0,0,0,0,0,0,0,0,0,198,62,0,0,64,12,0,0,242,11,0,0,230,1,0,0,44,6,0,0,194,15,0,0,0,0,0,0,48,177,145,0,0,2,0,0,128,1,0,0,0,1,0,0,4,0,0,0,3,0,0,0,136,84,3,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,8,70,3,0,0,0,0,0,152,54,6,0,232,200,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,3,17,4,8,0,0,0,0,0,0,0,0,0,0,56,11,0,0,2,0,0,0,0,0,0,0,0,0,0,0,198,62,0,0,64,12,0,0,36,13,0,0,230,1,0,0,44,6,0,0,194,15,0,0,0,0,0,0])
.concat([48,177,145,0,0,2,0,0,128,1,0,0,0,1,0,0,4,0,0,0,3,0,0,0,168,230,2,0,0,0,0,0,0,0,0,0,0,0,0,0,192,177,6,0,40,222,1,0,0,0,0,0,232,163,8,0,192,181,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,13,0,0,2,0,0,0,0,0,0,0,0,0,236,60,0,0,120,16,0,0,0,0,0,0,0,0,0,0,40,10,0,0,156,25,0,0,154,7,0,0,228,6,0,0,224,8,0,0,166,2,0,0,2,43,0,0,0,0,0,0,2,16,0,0,128,2,0,0,224,0,0,0,8,0,0,0,3,0,0,0,48,167,2,0,128,175,2,0,0,0,0,0,0,0,0,0,64,171,7,0,40,165,2,0,0,0,0,0,152,163,2,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,8,0,0,2,0,0,0,0,0,0,16,0,64,0,0,0,0,0,0,0,0,0,0,148,10,0,0,148,45,0,0,0,0,0,0,0,0,0,0,100,43,0,0,130,1,0,0,148,11,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,72,172,2,0,128,175,2,0,0,0,0,0,0,0,0,0,160,234,7,0,216,170,2,0,0,0,0,0,96,169,2,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,8,0,0,2,0,0,0,0,0,0,16,0,64,0,0,0,0,0,0,0,0,0,0,170,57,0,0,112,24,0,0,0,0,0,0,0,0,0,0,100,43,0,0,130,1,0,0,156,18,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,152,228,7,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,192,171,6,0,0,0,0,0,168,95,8,0,184,251,3,0,112,27,3,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,3,0,16,0,0,0,0,0,0,0,0,0,0,134,62,0,0,104,36,0,0,0,0,0,0,0,0,0,0,64,28,0,0,48,58,0,0,112,9,0,0,120,3,0,0,102,12,0,0,144,19,0,0,188,13,0,0,144,176,145,0,0,1,0,0,0,2,0,0,0,1,0,0,4,0,0,0,3,0,0,0,176,62,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,104,21,3,0,0,0,0,0,184,0,3,0,208,138,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,3,11,0,16,0,0,0,0,0,0,0,0,0,0,254,55,0,0,100,26,0,0,0,0,0,0,0,0,0,0,206,9,0,0,224,32,0,0,216,10,0,0,20,7,0,0,122,3,0,0,24,18,0,0,58,37,0,0,152,173,145,0,0,1,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,229,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,3,0,104,221,1,0,0,0,0,0,216,124,1,0,240,185,2,0,104,40,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,0,1,0,0,0,0,0,0,0,0,0,216,57,0,0,80,30,0,0,0,0,0,0,0,0,0,0,154,43,0,0,180,55,0,0,154,2,0,0,42,7,0,0,158,13,0,0,88,9,0,0,252,45,0,0,248,174,145,0,0,3,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,184,23,2,0,192,87,7,0,0,0,0,0,0,0,0,0,232,233,7,0,56,14,2,0,0,0,0,0,216,33,2,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,30,27,0,0,92,16,0,0,0,0,0,0,0,0,0,0,86,2,0,0,216,51,0,0,254,18,0,0,208,5,0,0,134,6,0,0,38,13,0,0,0,0,0,0,136,175,145,0,0,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,200,73,2,0,192,87,7,0,0,0,0,0,0,0,0,0,232,233,7,0,88,45,2,0,120,155,4,0,216,33,2,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,160,34,0,0,96,14,0,0,0,0,0,0,0,0,0,0,86,2,0,0,216,51,0,0,72,5,0,0,208,5,0,0,134,6,0,0,38,13,0,0,0,0,0,0,136,175,145,0,0,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,192,87,7,0,0,0,0,0,0,0,0,0,0,0,0,0,232,233,7,0,224,38,7,0,72,150,4,0,24,251,6,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,86,18,0,0,18,39,0,0,0,0,0,0,0,0,0,0,36,31,0,0,0,0,0,0,200,16,0,0,128,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,184,180,2,0,56,32,6,0,0,0,0,0,0,0,0,0,232,233,7,0,216,151,2,0,120,155,4,0,24,251,6,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,36,27,0,0,8,41,0,0,0,0,0,0,0,0,0,0,46,36,0,0,112,35,0,0,240,8,0,0,208,5,0,0,134,6,0,0,38,13,0,0,0,0,0,0,136,175,145,0,0,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,112,180,2,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,232,239,5,0,0,0,0,0,224,157,4,0,224,127,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,4,1,0,0,0,0,0,0,0,0,0,0,0,60,46,0,0,92,47,0,0,0,0,0,0,0,0,0,0,158,2,0,0,194,58,0,0,182,10,0,0,22,4,0,0,182,4,0,0,138,2,0,0,206,57,0,0,32,146,215,0,0,4,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,88,22,1,0,112,180,2,0,0,0,0,0,0,0,0,0,184,168,7,0,248,213,8,0,0,0,0,0,224,157,4,0,224,127,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,4,1,0,0,0,0,0,0,0,0,0,0,0,186,26,0,0,112,18,0,0,0,0,0,0,0,0,0,0,158,2,0,0,194,58,0,0,182,10,0,0,22,4,0,0,182,4,0,0,138,2,0,0,206,57,0,0,32,146,215,0,0,4,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,56,197,1,0,112,180,2,0,0,0,0,0,0,0,0,0,184,168,7,0,144,100,1,0,0,0,0,0,224,157,4,0,224,127,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,4,1,0,0,0,0,0,0,0,0,0,0,0,64,60,0,0,44,29,0,0,0,0,0,0,0,0,0,0,158,2,0,0,194,58,0,0,182,10,0,0,22,4,0,0,182,4,0,0,138,2,0,0,206,57,0,0,32,146,215,0,0,4,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,80,191,2,0,112,180,2,0,0,0,0,0,0,0,0,0,184,168,7,0,32,54,2,0,0,0,0,0,224,157,4,0,224,127,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,4,1,0,0,0,0,0,0,0,0,0,0,0,16,38,0,0,98,20,0,0,0,0,0,0,0,0,0,0,158,2,0,0,154,38,0,0,182,10,0,0,22,4,0,0,182,4,0,0,138,2,0,0,206,57,0,0,32,146,215,0,0,4,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,8,155,8,0,232,208,1,0,0,0,0,0,0,0,0,0,184,230,7,0,96,93,8,0,168,37,8,0,56,241,7,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,10,0,8,0,0,0,0,0,0,0,0,0,0,222,32,0,0,238,17,0,0,0,0,0,0,0,0,0,0,156,30,0,0,0,0,0,0,246,18,0,0,70,9,0,0,40,18,0,0,88,15,0,0,46,51,0,0,224,173,145,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,232,208,1,0,0,0,0,0,0,0,0,0,0,0,0,0,184,230,7,0,88,32,1,0,216,221,8,0,0,188,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,8,0,0,0,0,0,0,0,0,0,0,134,20,0,0,2,3,0,0,0,0,0,0,0,0,0,0,156,30,0,0,0,0,0,0,246,18,0,0,70,9,0,0,40,18,0,0,88,15,0,0,46,51,0,0,224,173,145,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,216,20,3,0,8,173,7,0,0,0,0,0,0,0,0,0,104,174,7,0,0,109,2,0,0,0,0,0,168,95,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,3,4,8,0,0,0,0,0,0,0,0,0,0,64,53,0,0,34,3,0,0,0,0,0,0,0,0,0,0,48,43,0,0,216,41,0,0,72,18,0,0,190,0,0,0,226,0,0,0,168,15,0,0,236,31,0,0,88,176,145,0,0,16,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,246,1,0,8,173,7,0,0,0,0,0,0,0,0,0,104,174,7,0,248,149,1,0,0,0,0,0,168,95,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,3,4,8,0,0,0,0,0,0,0,0,0,0,42,61,0,0,250,6,0,0,0,0,0,0,0,0,0,0,48,43,0,0,216,41,0,0,72,18,0,0,190,0,0,0,226,0,0,0,168,15,0,0,236,31,0,0,88,176,145,0,0,16,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,173,7,0,0,0,0,0,0,0,0,0,0,0,0,0,104,174,7,0,224,164,6,0,0,0,0,0,168,95,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,3,4,8,0,0,0,0,0,0,0,0,0,0,158,12,0,0,20,32,0,0,0,0,0,0,0,0,0,0,48,43,0,0,216,41,0,0,72,18,0,0,190,0,0,0,226,0,0,0,168,15,0,0,236,31,0,0,88,176,145,0,0,16,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,125,6,0,104,252,6,0,0,0,0,0,0,0,0,0,200,190,7,0,104,75,6,0,0,0,0,0,168,138,8,0,248,135,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,0,19,2,0,0,0,0,0,0,0,0,0,0,0,220,53,0,0,26,39,0,0,0,0,0,0,0,0,0,0,72,1,0,0,64,24,0,0,12,7,0,0,212,0,0,0,140,12,0,0,0,0,0,0,24,26,0,0,0,0,0,0,0,4,0,0,240,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,104,252,6,0,0,0,0,0,0,0,0,0,0,0,0,0,200,190,7,0,176,165,6,0,0,0,0,0,168,138,8,0,248,135,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,0,19,2,0,0,0,0,0,0,0,0,0,0,0,76,39,0,0,8,30,0,0,0,0,0,0,0,0,0,0,72,1,0,0,64,24,0,0,12,7,0,0,212,0,0,0,140,12,0,0,0,0,0,0,24,26,0,0,0,0,0,0,0,4,0,0,240,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,208,56,4,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,8,29,4,0,0,0,0,0,192,223,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,32,0,0,0,0,0,0,0,0,0,0,202,6,0,0,254,29,0,0,0,0,0,0,0,0,0,0,160,16,0,0,0,0,0,0,42,1,0,0,22,7,0,0,230,18,0,0,0,0,0,0,110,45,0,0,0,0,0,0,0,8,0,0,128,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,112,167,8,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,16,191,6,0,0,0,0,0,152,54,6,0,152,8,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,4,17,0,0,1,0,0,0,0,0,0,0,0,0,228,5,0,0,192,41,0,0,0,0,0,0,0,0,0,0,184,4,0,0,14,47,0,0,244,8,0,0,80,0,0,0,228,1,0,0,44,8,0,0,0,0,0,0,32,177,145,0,0,2,0,0,128,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,56,189,7,0,216,231,4,0,0,0,0,0,0,0,0,0,64,171,7,0,128,141,7,0,0,0,0,0,40,161,4,0,48,156,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,1,7,2,0,0,4,0,0,0,0,0,0,0,0,0,2,23,0,0,242,15,0,0,0,0,0,0,0,0,0,0,104,47,0,0,178,10,0,0,122,16,0,0,114,17,0,0,102,17,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,37,8,0,216,231,4,0,0,0,0,0,0,0,0,0,64,171,7,0,240,240,7,0,0,0,0,0,40,161,4,0,48,156,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,1,7,2,0,0,4,0,0,0,0,0,0,0,0,0,18,33,0,0,200,13,0,0,0,0,0,0,0,0,0,0,104,47,0,0,178,10,0,0,122,16,0,0,114,17,0,0,102,17,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,231,4,0,0,0,0,0,0,0,0,0,0,0,0,0,64,171,7,0,32,93,8,0,0,0,0,0,40,161,4,0,48,156,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,1,7,2,0,0,4,0,0,0,0,0,0,0,0,0,216,32,0,0,26,44,0,0,0,0,0,0,0,0,0,0,104,47,0,0,178,10,0,0,122,16,0,0,114,17,0,0,102,17,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,17,8,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,232,13,8,0,0,0,0,0,232,167,5,0,80,164,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,1,0,0,0,0,0,0,0,0,0,0,0,188,57,0,0,160,19,0,0,0,0,0,0,0,0,0,0,244,56,0,0,100,27,0,0,102,1,0,0,56,12,0,0,212,3,0,0,250,8,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,32,3,0,112,80,8,0,0,0,0,0,0,0,0,0,64,164,6,0,56,115,2,0,0,0,0,0,184,252,1,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,3,0,0,8,0,0,0,0,0,0,0,0,0,16,36,0,0,234,17,0,0,0,0,0,0,0,0,0,0,132,33,0,0,194,49,0,0,242,17,0,0,176,19,0,0,58,4,0,0,90,2,0,0,80,58,0,0,248,176,145,0,64,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,128,155,1,0,112,80,8,0,0,0,0,0,0,0,0,0,64,164,6,0,72,61,1,0,0,0,0,0,192,154,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,3,0,0,8,0,0,0,0,0,0,0,0,0,188,44,0,0,170,30,0,0,0,0,0,0,0,0,0,0,132,33,0,0,30,10,0,0,242,17,0,0,176,19,0,0,58,4,0,0,90,2,0,0,80,58,0,0,248,176,145,0,64,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,112,80,8,0,0,0,0,0,0,0,0,0,0,0,0,0,64,164,6,0,128,183,6,0,0,0,0,0,168,95,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,2,0,0,0,0,0,0,3,0,0,8,0,0,0,0,0,0,0,0,0,142,32,0,0,164,24,0,0,0,0,0,0,0,0,0,0,132,33,0,0,30,10,0,0,242,17,0,0,176,19,0,0,58,4,0,0,90,2,0,0,80,58,0,0,248,176,145,0,64,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,24,47,6,0,128,225,6,0,0,0,0,0,0,0,0,0,232,233,7,0,160,4,6,0,0,0,0,0,8,215,5,0,136,252,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,50,23,0,0,254,25,0,0,0,0,0,0,0,0,0,0,172,22,0,0,0,14,0,0,124,2,0,0,64,13,0,0,168,2,0,0,0,0,0,0,134,1,0,0,0,0,0,0,0,1,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,128,225,6,0,0,0,0,0,0,0,0,0,0,0,0,0,232,233,7,0,88,138,6,0,0,0,0,0,32,94,6,0,136,252,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,112,38,0,0,120,41,0,0,0,0,0,0,0,0,0,0,172,22,0,0,0,14,0,0,124,2,0,0,64,13,0,0,168,2,0,0,0,0,0,0,134,1,0,0,0,0,0,0,0,1,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,160,68,2,0,32,105,3,0,0,0,0,0,0,0,0,0,144,139,6,0,16,209,1,0,0,0,0,0,24,186,4,0,136,153,3,0,232,110,1,0,0,0,0,0,0,0,0,0,0,0,0,0,149,0,0,0,2,0,0,0,0,0,0,6,2,0,0,0,0,0,0,0,0,0,0,0,214,40,0,0,84,20,0,0,0,0,0,0,0,0,0,0,96,59,0,0,0,0,0,0,140,11,0,0,94,15,0,0,132,5,0,0,248,15,0,0,178,29,0,0,96,49,216,0,0,128,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,32,105,3,0,0,0,0,0,0,0,0,0,0,0,0,0,144,139,6,0,112,29,6,0,0,0,0,0,24,186,4,0,136,153,3,0,176,208,2,0,0,0,0,0,0,0,0,0,0,0,0,0,133,0,0,0,2,0,0,0,0,0,0,6,2,0,0,0,0,0,0,0,0,0,0,0,194,44,0,0,220,19,0,0,0,0,0,0,0,0,0,0,96,59,0,0,0,0,0,0,140,11,0,0,94,15,0,0,132,5,0,0,248,15,0,0,178,29,0,0,96,49,216,0,0,128,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,64,184,5,0,224,102,6,0,0,0,0,0,0,0,0,0,240,3,2,0,160,145,5,0,192,222,5,0,152,54,6,0,152,8,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,4,17,0,0,1,0,0,0,0,0,0,0,0,0,108,9,0,0,224,27,0,0,0,0,0,0,0,0,0,0,184,4,0,0,54,41,0,0,244,1,0,0,80,0,0,0,228,1,0,0,44,8,0,0,0,0,0,0,32,177,145,0,0,2,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,80,230,1,0,104,6,5,0,0,0,0,0,0,0,0,0,64,171,7,0,24,131,1,0,0,0,0,0,192,44,1,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,0,20,2,0,0,0,0,0,0,0,0,0,0,0,32,61,0,0,106,27,0,0,0,0,0,0,0,0,0,0,80,31,0,0,156,37,0,0,192,4,0,0,90,11,0,0,80,14,0,0,118,18,0,0,180,39,0,0,216,132,215,0,0,3,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,24,243,2,0,104,6,5,0,0,0,0,0,0,0,0,0,64,171,7,0,88,90,2,0,0,0,0,0,192,223,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,0,20,2,0,0,0,0,0,0,0,0,0,0,0,118,29,0,0,254,15,0,0,0,0,0,0,0,0,0,0,80,31,0,0,156,37,0,0,192,4,0,0,90,11,0,0,80,14,0,0,118,18,0,0,180,39,0,0,216,132,215,0,0,3,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,104,6,5,0,0,0,0,0,0,0,0,0,0,0,0,0,64,171,7,0,64,95,6,0,0,0,0,0,192,223,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,0,20,2,0,0,0,0,0,0,0,0,0,0,0,164,33,0,0,166,36,0,0,0,0,0,0,0,0,0,0,80,31,0,0,156,37,0,0,192,4,0,0,90,11,0,0,80,14,0,0,118,18,0,0,180,39,0,0,216,132,215,0,0,3,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,8,234,8,0,104,6,5,0,0,0,0,0,0,0,0,0,160,234,7,0,128,105,8,0,0,0,0,0,192,44,1,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,0,20,2,0,0,0,0,0,0,0,0,0,0,0,96,63,0,0,210,19,0,0,0,0,0,0,0,0,0,0,80,31,0,0,196,11,0,0,192,4,0,0,90,11,0,0,80,14,0,0,118,18,0,0,180,39,0,0,216,132,215,0,0,3,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,120,104,8,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,104,95,8,0,0,0,0,0,24,79,1,0,80,164,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,0,10,2,0,0,0,0,0,0,0,0,0,0,0,250,14,0,0,170,43,0,0,0,0,0,0,0,0,0,0,244,56,0,0,190,53,0,0,30,2,0,0,56,12,0,0,212,3,0,0,66,19,0,0,0,0,0,0,0,0,0,0,0,4,0,0,224,0,0,0,128,1,0,0,3,0,0,0,4,0,0,0,208,212,4,0,104,24,5,0,0,0,0,0,0,0,0,0,96,135,2,0,232,178,4,0,240,56,5,0,152,54,6,0,168,38,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,5,17,1,0,0,0,0,0,0,0,0,0,0,0,50,8,0,0,82,40,0,0,0,0,0,0,0,0,0,0,58,34,0,0,166,14,0,0,160,1,0,0,218,2,0,0,114,1,0,0,166,3,0,0,116,50,0,0,8,211,148,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,192,98,2,0,160,123,2,0,0,0,0,0,0,0,0,0,104,221,5,0,176,82,2,0,0,0,0,0,144,84,8,0,208,135,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,2,11,2,0,0,0,0,0,0,0,0,0,0,0,50,58,0,0,70,13,0,0,0,0,0,0,0,0,0,0,114,20,0,0,82,8,0,0,232,6,0,0,46,7,0,0,246,17,0,0,0,0,0,0,176,18,0,0,0,0,0,0,0,32,0,0,224,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,160,123,2,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,152,109,2,0,0,0,0,0,168,183,7,0,208,135,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,2,11,2,0,0,0,0,0,0,0,0,0,0,0,100,2,0,0,126,4,0,0,0,0,0,0,0,0,0,0,114,20,0,0,160,28,0,0,232,6,0,0,46,7,0,0,246,17,0,0,0,0,0,0,176,18,0,0,0,0,0,0,0,32,0,0,224,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,112,232,3,0,64,93,4,0,0,0,0,0,0,0,0,0,144,47,2,0,176,200,3,0,240,56,5,0,144,234,6,0,168,38,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,5,17,0,8,0,0,0,0,0,0,0,0,0,0,116,54,0,0,126,9,0,0,0,0,0,0,0,0,0,0,58,34,0,0,224,52,0,0,4,0,0,0,218,2,0,0,114,1,0,0,166,3,0,0,116,50,0,0,8,211,148,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,8,37,4,0,64,93,4,0,0,0,0,0,0,0,0,0,144,47,2,0,96,10,4,0,240,56,5,0,152,54,6,0,168,38,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,5,17,0,8,0,0,0,0,0,0,0,0,0,0,244,43,0,0,86,24,0,0,0,0,0,0,0,0,0,0,58,34,0,0,224,52,0,0,4,0,0,0,218,2,0,0,114,1,0,0,166,3,0,0,116,50,0,0,8,211,148,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,64,93,4,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,120,65,4,0,240,56,5,0,152,54,6,0,168,38,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,5,17,0,8,0,0,0,0,0,0,0,0,0,0,20,5,0,0,76,24,0,0,0,0,0,0,0,0,0,0,58,34,0,0,224,52,0,0,4,0,0,0,218,2,0,0,114,1,0,0,166,3,0,0,116,50,0,0,8,211,148,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,232,13,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,184,223,2,0,240,56,5,0,152,54,6,0,168,38,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,5,17,0,8,0,0,0,0,0,0,0,0,0,0,238,41,0,0,76,15,0,0,0,0,0,0,0,0,0,0,58,34,0,0,4,35,0,0,214,1,0,0,218,2,0,0,114,1,0,0,166,3,0,0,116,50,0,0,8,211,148,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,208,176,1,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,72,170,1,0,0,0,0,0,168,39,6,0,0,227,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,1,21,0,0,1,0,0,0,0,0,0,0,0,0,58,47,0,0,100,31,0,0,0,0,0,0,0,0,0,0,202,41,0,0,120,30,0,0,50,13,0,0,248,19,0,0,72,13,0,0,56,10,0,0,96,10,0,0,224,174,145,0,0,18,0,0,240,0,0,0,128,1,0,0,3,0,0,0,4,0,0,0,200,132,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,8,74,5,0,0,0,0,0,168,39,6,0,208,165,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,21,8,0,0,0,0,0,0,0,0,0,0,0,242,57,0,0,36,24,0,0,0,0,0,0,0,0,0,0,252,49,0,0,254,12,0,0,120,18,0,0,198,1,0,0,134,15,0,0,0,0,0,0,236,14,0,0,240,210,148,0,0,128,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,196,7,0,240,124,1,0,0,0,0,0,0,0,0,0,0,38,7,0,168,148,7,0,0,0,0,0,232,163,8,0,248,180,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,149,0,0,0,2,0,0,0,0,0,0,13,2,0,0,0,0,0,0,0,0,0,0,0,232,0,0,0,72,32,0,0,0,0,0,0,0,0,0,0,32,31,0,0,34,25,0,0,120,5,0,0,66,4,0,0,206,19,0,0,238,15,0,0,232,20,0,0,216,157,215,0,0,16,0,0,224,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,32,102,8,0,240,124,1,0,0,0,0,0,0,0,0,0,0,38,7,0,48,45,8,0,0,0,0,0,232,163,8,0,248,180,3,0,144,249,7,0,0,0,0,0,0,0,0,0,0,0,0,0,149,0,0,0,2,0,0,0,0,0,0,13,2,0,0,0,0,0,0,0,0,0,0,0,206,4,0,0,50,23,0,0,0,0,0,0,0,0,0,0,32,31,0,0,34,25,0,0,120,5,0,0,66,4,0,0,206,19,0,0,238,15,0,0,232,20,0,0,216,157,215,0,0,16,0,0,224,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,8,62,6,0,0,0,0,0,0,0,0,0,0,0,0,0,192,177,6,0,64,196,7,0,0,0,0,0,232,163,8,0,192,148,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,0,13,2,0,0,0,0,0,0,0,0,0,0,0,124,52,0,0,224,23,0,0,0,0,0,0,0,0,0,0,56,14,0,0,126,62,0,0,22,15,0,0,160,16,0,0,104,12,0,0,54,1,0,0,166,39,0,0,0,0,0,0,0,20,0,0,224,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,240,124,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,32,230,8,0,0,0,0,0,232,163,8,0,248,180,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,133,0,0,0,2,0,0,0,0,0,0,13,2,0,0,0,0,0,0,0,0,0,0,0,200,17,0,0,26,4,0,0,0,0,0,0,0,0,0,0,32,31,0,0,78,23,0,0,120,5,0,0,66,4,0,0,206,19,0,0,238,15,0,0,232,20,0,0,216,157,215,0,0,16,0,0,224,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,72,127,5,0,104,201,5,0,0,0,0,0,0,0,0,0,96,135,2,0,8,98,5,0,0,0,0,0,176,237,2,0,168,84,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,3,0,0,0,0,0,0,19,0,0,8,0,0,0,0,0,0,0,0,0,238,11,0,0,244,35,0,0,0,0,0,0,0,0,0,0,162,56,0,0,38,47,0,0,182,6,0,0,222,8,0,0,178,15,0,0,54,2,0,0,78,56,0,0,104,173,145,0,0,8,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,0,103,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,216,28,6,0,0,0,0,0,72,188,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,16,0,0,0,0,0,0,0,0,0,0,250,4,0,0,234,35,0,0,0,0,0,0,0,0,0,0,104,3,0,0,244,44,0,0,54,10,0,0,82,8,0,0,90,15,0,0,118,13,0,0,48,60,0,0,232,173,145,0,0,2,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,206,5,0,0,217,6,0,0,0,0,0,0,0,0,0,0,38,7,0,208,166,5,0,0,0,0,0,72,187,4,0,200,156,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,14,0,0,4,0,0,0,0,0,0,0,0,0,192,22,0,0,202,5,0,0,0,0,0,0,0,0,0,0,148,16,0,0,30,37,0,0,32,13,0,0,204,13,0,0,230,5,0,0,0,0,0,0,198,6,0,0,0,0,0,0,0,0,1,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,224,38,6,0,0,217,6,0,0,0,0,0,0,0,0,0,0,38,7,0,104,250,5,0,0,0,0,0,72,187,4,0,200,156,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,14,0,0,4,0,0,0,0,0,0,0,0,0,76,2,0,0,30,44,0,0,0,0,0,0,0,0,0,0,148,16,0,0,30,37,0,0,32,13,0,0,204,13,0,0,230,5,0,0,0,0,0,0,198,6,0,0,0,0,0,0,0,0,1,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,64,129,6,0,0,217,6,0,0,0,0,0,0,0,0,0,0,38,7,0,32,81,6,0,0,0,0,0,72,187,4,0,200,156,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,14,0,0,4,0,0,0,0,0,0,0,0,0,98,54,0,0,72,6,0,0,0,0,0,0,0,0,0,0,148,16,0,0,30,37,0,0,114,3,0,0,204,13,0,0,230,5,0,0,0,0,0,0,198,6,0,0,0,0,0,0,0,0,1,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,224,232,4,0,224,131,5,0,0,0,0,0,0,0,0,0,32,127,5,0,80,196,4,0,0,0,0,0,72,187,4,0,200,156,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,14,0,0,4,0,0,0,0,0,0,0,0,0,132,27,0,0,68,22,0,0,0,0,0,0,0,0,0,0,148,16,0,0,52,42,0,0,242,7,0,0,204,13,0,0,230,5,0,0,0,0,0,0,198,6,0,0,0,0,0,0,0,0,1,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,136,41,5,0,224,131,5,0,0,0,0,0,0,0,0,0,32,127,5,0,24,11,5,0,0,0,0,0,72,187,4,0,200,156,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,14,0,0,4,0,0,0,0,0,0,0,0,0,136,62,0,0,248,32,0,0,0,0,0,0,0,0,0,0,148,16,0,0,52,42,0,0,132,11,0,0,204,13,0,0,230,5,0,0,0,0,0,0,198,6,0,0,0,0,0,0,0,0,1,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,224,131,5,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,56,73,5,0,0,0,0,0,72,187,4,0,200,156,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,14,0,0,4,0,0,0,0,0,0,0,0,0,42,37,0,0,182,21,0,0,0,0,0,0,0,0,0,0,148,16,0,0,52,42,0,0,132,11,0,0,204,13,0,0,230,5,0,0,0,0,0,0,198,6,0,0,0,0,0,0,0,0,1,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,0,217,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,104,171,6,0,0,0,0,0,72,187,4,0,200,156,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,14,0,0,4,0,0,0,0,0,0,0,0,0,156,22,0,0,46,10,0,0,0,0,0,0,0,0,0,0,148,16,0,0,30,37,0,0,114,3,0,0,204,13,0,0,230,5,0,0,0,0,0,0,198,6,0,0,0,0,0,0,0,0,1,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,96,80,8,0,112,100,8,0,0,0,0,0,0,0,0,0,96,159,4,0,112,75,8,0,0,0,0,0,152,54,6,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,8,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,164,49,0,0,154,36,0,0,0,0,0,0,0,0,0,0,86,51,0,0,114,62,0,0,134,4,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,80,70,8,0,112,100,8,0,0,0,0,0,0,0,0,0,96,159,4,0,64,67,8,0,0,0,0,0,192,154,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,53,0,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,218,10,0,0,148,44,0,0,0,0,0,0,0,0,0,0,70,34,0,0,252,38,0,0,134,4,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,56,64,8,0,112,100,8,0,0,0,0,0,0,0,0,0,96,159,4,0,168,57,8,0,0,0,0,0,192,154,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,0,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,96,22,0,0,42,15,0,0,0,0,0,0,0,0,0,0,70,34,0,0,92,39,0,0,134,4,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,248,115,7,0,168,20,8,0,0,0,0,0,0,0,0,0,200,190,7,0,128,64,7,0,0,0,0,0,168,95,8,0,176,254,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,3,0,0,1,0,0,0,0,0,0,0,0,0,156,8,0,0,8,22,0,0,0,0,0,0,0,0,0,0,6,47,0,0,254,54,0,0,74,6,0,0,150,6,0,0,2,13,0,0,10,1,0,0,172,62,0,0,192,176,145,0,0,16,0,0,224,0,0,0,24,1,0,0,3,0,0,0,4,0,0,0,160,210,7,0,168,20,8,0,0,0,0,0,0,0,0,0,200,190,7,0,184,159,7,0,0,0,0,0,168,95,8,0,176,254,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,3,0,0,1,0,0,0,0,0,0,0,0,0,56,57,0,0,236,11,0,0,0,0,0,0,0,0,0,0,6,47,0,0,254,54,0,0,74,6,0,0,150,6,0,0,2,13,0,0,10,1,0,0,172,62,0,0,192,176,145,0,0,16,0,0,224,0,0,0,24,1,0,0,3,0,0,0,4,0,0,0,16,176,2,0,24,211,2,0,0,0,0,0,0,0,0,0,104,221,5,0,72,161,2,0,0,0,0,0,128,161,4,0,208,135,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,2,11,4,0,0,0,0,0,0,0,0,0,0,0,80,21,0,0,8,14,0,0,0,0,0,0,0,0,0,0,188,10,0,0,212,44,0,0,52,11,0,0,46,7,0,0,246,17,0,0,0,0,0,0,176,18,0,0,0,0,0,0,0,32,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,211,2,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,200,192,2,0,0,0,0,0,168,183,7,0,208,135,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,4,0,0,0,0,0,2,11,4,0,0,0,0,0,0,0,0,0,0,0,142,9,0,0,232,43,0,0,0,0,0,0,0,0,0,0,188,10,0,0,158,37,0,0,52,11,0,0,46,7,0,0,246,17,0,0,0,0,0,0,176,18,0,0,0,0,0,0,0,32,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,98,1,0,0,171,7,0,0,0,0,0,0,0,0,0,96,135,2,0,176,19,1,0,0,0,0,0,16,128,3,0,160,150,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,2,4,2,0,0,0,0,0,0,0,0,0,0,0,122,41,0,0,130,7,0,0,0,0,0,0,0,0,0,0,64,35,0,0,22,59,0,0,154,17,0,0,90,9,0,0,186,11,0,0,190,19,0,0,8,5,0,0,32,146,215,0,0,8,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,0,171,7,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,88,195,1,0,0,0,0,0,160,150,4,0,16,128,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,2,4,2,0,0,0,0,0,0,0,0,0,0,0,40,37,0,0,162,3,0,0,0,0,0,0,0,0,0,0,64,35,0,0,22,59,0,0,154,17,0,0,90,9,0,0,186,11,0,0,190,19,0,0,8,5,0,0,32,146,215,0,0,8,0,0,240,0,0,0,64,1,0,0])
.concat([3,0,0,0,4,0,0,0,160,213,2,0,168,64,3,0,0,0,0,0,0,0,0,0,192,177,6,0,16,195,2,0,0,0,0,0,32,28,3,0,80,164,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,0,10,2,0,0,0,0,0,0,0,0,0,0,0,138,27,0,0,230,45,0,0,0,0,0,0,0,0,0,0,244,56,0,0,190,54,0,0,230,12,0,0,88,18,0,0,228,5,0,0,106,18,0,0,0,0,0,0,0,0,0,0,0,3,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,24,3,3,0,168,64,3,0,0,0,0,0,0,0,0,0,192,177,6,0,72,238,2,0,0,0,0,0,216,164,4,0,80,164,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,0,10,2,0,0,0,0,0,0,0,0,0,0,0,222,22,0,0,80,15,0,0,0,0,0,0,0,0,0,0,244,56,0,0,190,54,0,0,230,12,0,0,88,18,0,0,228,5,0,0,106,18,0,0,0,0,0,0,0,0,0,0,0,3,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,32,178,2,0,168,64,3,0,0,0,0,0,0,0,0,0,192,177,6,0,224,163,2,0,0,0,0,0,216,164,4,0,80,164,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,0,10,2,0,0,0,0,0,0,0,0,0,0,0,188,11,0,0,166,35,0,0,0,0,0,0,0,0,0,0,244,56,0,0,190,54,0,0,240,18,0,0,88,18,0,0,228,5,0,0,106,18,0,0,0,0,0,0,0,0,0,0,0,3,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,168,64,3,0,0,0,0,0,0,0,0,0,0,0,0,0,192,177,6,0,80,48,3,0,0,0,0,0,32,28,3,0,80,164,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,2,0,0,0,0,0,0,0,0,0,0,0,14,25,0,0,198,32,0,0,0,0,0,0,0,0,0,0,244,56,0,0,200,36,0,0,242,13,0,0,88,18,0,0,228,5,0,0,64,7,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,155,1,0,48,68,8,0,0,0,0,0,0,0,0,0,184,168,7,0,8,61,1,0,0,0,0,0,168,95,8,0,104,3,4,0,16,248,8,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,3,1,0,0,0,0,0,0,0,0,0,0,0,22,38,0,0,168,19,0,0,0,0,0,0,0,0,0,0,110,32,0,0,246,21,0,0,20,10,0,0,206,12,0,0,26,19,0,0,152,5,0,0,122,47,0,0,232,176,145,0,0,8,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,68,8,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,240,181,6,0,0,0,0,0,168,95,8,0,104,3,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,3,1,0,0,0,0,0,0,0,0,0,0,0,18,40,0,0,158,29,0,0,0,0,0,0,0,0,0,0,110,32,0,0,246,21,0,0,20,10,0,0,206,12,0,0,26,19,0,0,152,5,0,0,122,47,0,0,232,176,145,0,0,8,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,176,3,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,192,41,6,0,0,0,0,0,168,39,6,0,208,165,3,0,120,216,2,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,21,4,0,0,0,0,0,0,0,0,0,0,0,188,0,0,0,98,42,0,0,0,0,0,0,0,0,0,0,236,33,0,0,110,58,0,0,218,1,0,0,198,1,0,0,134,15,0,0,0,0,0,0,236,14,0,0,240,210,148,0,0,128,0,0,48,1,0,0,232,0,0,0,4,0,0,0,3,0,0,0,16,32,3,0,48,68,8,0,0,0,0,0,0,0,0,0,184,168,7,0,216,114,2,0,0,0,0,0,168,95,8,0,104,3,4,0,0,252,1,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,3,1,0,0,0,0,0,0,0,0,0,0,0,70,5,0,0,182,42,0,0,0,0,0,0,0,0,0,0,110,32,0,0,246,21,0,0,20,10,0,0,206,12,0,0,26,19,0,0,152,5,0,0,122,47,0,0,232,176,145,0,0,8,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,54,6,0,184,247,8,0,0,0,0,0,0,0,0,0,104,174,7,0,48,13,6,0,0,0,0,0,168,95,8,0,80,61,8,0,184,220,5,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,3,1,0,0,0,0,0,0,0,0,0,0,0,154,14,0,0,150,43,0,0,0,0,0,0,0,0,0,0,176,49,0,0,20,10,0,0,44,19,0,0,156,9,0,0,198,15,0,0,232,8,0,0,42,6,0,0,216,176,145,0,0,4,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,191,6,0,184,247,8,0,0,0,0,0,0,0,0,0,104,174,7,0,64,144,6,0,0,0,0,0,168,95,8,0,80,61,8,0,16,101,6,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,3,1,0,0,0,0,0,0,0,0,0,0,0,206,49,0,0,194,15,0,0,0,0,0,0,0,0,0,0,176,49,0,0,20,10,0,0,44,19,0,0,156,9,0,0,198,15,0,0,232,8,0,0,42,6,0,0,216,176,145,0,0,4,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,65,7,0,184,247,8,0,0,0,0,0,0,0,0,0,104,174,7,0,48,20,7,0,0,0,0,0,168,95,8,0,80,61,8,0,216,232,6,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,3,1,0,0,0,0,0,0,0,0,0,0,0,146,18,0,0,28,45,0,0,0,0,0,0,0,0,0,0,176,49,0,0,168,3,0,0,226,12,0,0,156,9,0,0,198,15,0,0,232,8,0,0,42,6,0,0,216,176,145,0,0,4,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,140,7,0,192,92,8,0,0,0,0,0,0,0,0,0,104,221,5,0,72,94,7,0,0,0,0,0,40,161,4,0,240,153,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,192,0,1,2,0,0,4,0,0,0,0,0,0,0,0,0,228,14,0,0,44,20,0,0,0,0,0,0,0,0,0,0,66,8,0,0,98,51,0,0,220,16,0,0,114,5,0,0,164,8,0,0,0,0,0,0,6,14,0,0,0,0,0,0,0,96,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,240,7,0,192,92,8,0,0,0,0,0,0,0,0,0,104,221,5,0,88,188,7,0,0,0,0,0,40,161,4,0,240,153,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,192,0,1,2,0,0,4,0,0,0,0,0,0,0,0,0,204,7,0,0,178,3,0,0,0,0,0,0,0,0,0,0,66,8,0,0,98,51,0,0,220,16,0,0,114,5,0,0,164,8,0,0,0,0,0,0,6,14,0,0,0,0,0,0,0,96,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,92,8,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,16,37,8,0,0,0,0,0,40,161,4,0,240,153,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,192,0,1,2,0,0,4,0,0,0,0,0,0,0,0,0,84,33,0,0,202,0,0,0,0,0,0,0,0,0,0,0,66,8,0,0,98,51,0,0,220,16,0,0,114,5,0,0,164,8,0,0,0,0,0,0,6,14,0,0,0,0,0,0,0,96,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,103,2,0,168,158,4,0,72,172,6,0,0,0,0,0,144,47,2,0,88,91,2,0,0,0,0,0,128,145,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,133,2,0,0,0,0,0,0,0,0,0,0,0,194,1,0,0,96,23,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,158,4,0,0,0,0,0,72,172,6,0,0,0,0,0,144,47,2,0,72,117,2,0,0,0,0,0,128,145,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,2,0,0,0,0,0,0,0,0,0,0,0,200,38,0,0,72,17,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,225,3,0,0,0,0,0,0,0,0,0,0,0,0,0,184,12,8,0,200,49,6,0,0,0,0,0,208,207,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,3,0,0,0,0,0,0,10,0,2,0,0,0,0,0,0,0,0,0,0,60,35,0,0,86,39,0,0,0,0,0,0,0,0,0,0,110,38,0,0,186,15,0,0,238,7,0,0,18,1,0,0,42,9,0,0,118,15,0,0,88,11,0,0,128,174,145,0,0,3,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,184,133,8,0,176,198,8,0,0,0,0,0,0,0,0,0,184,168,7,0,248,127,8,0,0,0,0,0,40,161,4,0,80,150,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,64,8,4,2,4,0,0,0,0,0,0,0,0,0,0,0,96,51,0,0,128,20,0,0,0,0,0,0,0,0,0,0,50,22,0,0,200,45,0,0,168,19,0,0,114,17,0,0,134,11,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,144,8,0,176,198,8,0,0,0,0,0,0,0,0,0,184,168,7,0,0,139,8,0,0,0,0,0,40,161,4,0,80,150,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,64,4,4,2,4,0,0,0,0,0,0,0,0,0,0,0,14,42,0,0,118,2,0,0,0,0,0,0,0,0,0,0,50,22,0,0,200,45,0,0,12,15,0,0,114,17,0,0,134,11,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,156,8,0,176,198,8,0,0,0,0,0,0,0,0,0,184,168,7,0,48,150,8,0,0,0,0,0,40,161,4,0,80,150,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,64,4,4,2,4,0,0,0,0,0,0,0,0,0,0,0,102,13,0,0,214,25,0,0,0,0,0,0,0,0,0,0,50,22,0,0,200,45,0,0,12,15,0,0,114,17,0,0,134,11,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,174,8,0,176,198,8,0,0,0,0,0,0,0,0,0,184,168,7,0,208,165,8,0,0,0,0,0,40,161,4,0,80,150,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,4,4,2,4,0,0,0,0,0,0,0,0,0,0,0,134,30,0,0,110,4,0,0,0,0,0,0,0,0,0,0,50,22,0,0,200,45,0,0,164,6,0,0,114,17,0,0,134,11,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,188,8,0,176,198,8,0,0,0,0,0,0,0,0,0,184,168,7,0,240,182,8,0,0,0,0,0,40,161,4,0,80,150,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,64,8,4,2,4,0,0,0,0,0,0,0,0,0,0,0,228,16,0,0,94,42,0,0,0,0,0,0,0,0,0,0,50,22,0,0,200,45,0,0,168,19,0,0,114,17,0,0,134,11,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,198,8,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,128,193,8,0,0,0,0,0,40,161,4,0,80,150,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,8,4,2,4,0,0,0,0,0,0,0,0,0,0,0,10,59,0,0,200,43,0,0,0,0,0,0,0,0,0,0,50,22,0,0,200,45,0,0,254,6,0,0,114,17,0,0,134,11,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,153,7,0,192,138,5,0,0,0,0,0,0,0,0,0,64,171,7,0,128,107,7,0,0,0,0,0,64,57,7,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,20,0,8,0,0,0,0,0,0,0,0,0,0,188,47,0,0,186,16,0,0,0,0,0,0,0,0,0,0,104,45,0,0,218,48,0,0,56,13,0,0,140,9,0,0,82,7,0,0,0,0,0,0,118,31,0,0,0,0,0,0,0,1,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,0,8,0,192,138,5,0,0,0,0,0,0,0,0,0,64,171,7,0,240,202,7,0,0,0,0,0,192,223,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,20,0,8,0,0,0,0,0,0,0,0,0,0,48,5,0,0,20,8,0,0,0,0,0,0,0,0,0,0,104,45,0,0,218,48,0,0,108,7,0,0,140,9,0,0,82,7,0,0,0,0,0,0,118,31,0,0,0,0,0,0,0,1,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,12,7,0,192,138,5,0,0,0,0,0,0,0,0,0,64,171,7,0,16,226,6,0,0,0,0,0,192,223,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,20,0,8,0,0,0,0,0,0,0,0,0,0,242,60,0,0,188,46,0,0,0,0,0,0,0,0,0,0,104,45,0,0,218,48,0,0,56,13,0,0,140,9,0,0,82,7,0,0,0,0,0,0,118,31,0,0,0,0,0,0,0,1,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,109,8,0,192,138,5,0,0,0,0,0,0,0,0,0,64,171,7,0,16,52,8,0,0,0,0,0,192,154,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,0,20,0,8,0,0,0,0,0,0,0,0,0,0,226,61,0,0,42,22,0,0,0,0,0,0,0,0,0,0,104,45,0,0,218,48,0,0,56,13,0,0,140,9,0,0,82,7,0,0,0,0,0,0,118,31,0,0,0,0,0,0,0,1,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,236,8,0,192,138,5,0,0,0,0,0,0,0,0,0,64,171,7,0,136,172,8,0,0,0,0,0,192,154,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,0,20,0,8,0,0,0,0,0,0,0,0,0,0,106,9,0,0,214,23,0,0,0,0,0,0,0,0,0,0,104,45,0,0,218,48,0,0,108,7,0,0,140,9,0,0,82,7,0,0,0,0,0,0,118,31,0,0,0,0,0,0,0,1,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,234,1,0,192,138,5,0,0,0,0,0,0,0,0,0,64,171,7,0,128,137,1,0,0,0,0,0,192,154,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,0,20,0,8,0,0,0,0,0,0,0,0,0,0,82,59,0,0,242,37,0,0,0,0,0,0,0,0,0,0,104,45,0,0,218,48,0,0,108,7,0,0,140,9,0,0,82,7,0,0,0,0,0,0,118,31,0,0,0,0,0,0,0,1,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,251,2,0,192,138,5,0,0,0,0,0,0,0,0,0,64,171,7,0,88,96,2,0,0,0,0,0,192,223,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,20,0,8,0,0,0,0,0,0,0,0,0,0,88,1,0,0,90,33,0,0,0,0,0,0,0,0,0,0,104,45,0,0,218,48,0,0,108,7,0,0,140,9,0,0,82,7,0,0,0,0,0,0,118,31,0,0,0,0,0,0,0,1,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,138,5,0,0,0,0,0,0,0,0,0,0,0,0,0,64,171,7,0,240,113,6,0,0,0,0,0,192,223,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,20,0,8,0,0,0,0,0,0,0,0,0,0,238,15,0,0,100,1,0,0,0,0,0,0,0,0,0,0,104,45,0,0,218,48,0,0,56,13,0,0,140,9,0,0,82,7,0,0,0,0,0,0,118,31,0,0,0,0,0,0,0,1,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,48,6,0,0,0,0,0,0,0,0,0,0,0,0,0,104,129,6,0,64,211,5,0,0,0,0,0,232,163,8,0,152,88,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,0,13,32,0,0,0,0,0,0,0,0,0,0,0,74,50,0,0,142,0,0,0,0,0,0,0,0,0,0,0,56,14,0,0,96,18,0,0,90,17,0,0,160,16,0,0,104,12,0,0,54,1,0,0,166,39,0,0,0,0,0,0,0,20,0,0,224,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,152,35,7,0,0,0,0,0,0,0,0,0,0,0,0,0,216,194,1,0,40,33,7,0,0,0,0,0,128,67,7,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,39,0,0,0,2,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,0,0,0,0,96,47,0,0,250,38,0,0,0,0,0,0,0,0,0,0,136,45,0,0,200,50,0,0,242,2,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,176,92,8,0,48,31,1,0,0,0,0,0,0,0,0,0,104,221,5,0,240,36,8,0,0,0,0,0,40,161,4,0,144,153,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,2,2,0,0,8,0,0,0,0,0,0,0,0,0,88,15,0,0,44,3,0,0,0,0,0,0,0,0,0,0,156,0,0,0,198,18,0,0,232,3,0,0,66,12,0,0,6,3,0,0,0,0,0,0,214,38,0,0,0,0,0,0,0,96,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,31,1,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,24,154,8,0,0,0,0,0,40,161,4,0,144,153,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,2,2,0,0,8,0,0,0,0,0,0,0,0,0,148,52,0,0,166,2,0,0,0,0,0,0,0,0,0,0,222,51,0,0,48,57,0,0,172,5,0,0,66,12,0,0,6,3,0,0,0,0,0,0,214,38,0,0,0,0,0,0,0,96,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,234,3,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,248,226,8,0,64,193,4,0,32,0,1,0,240,185,2,0,48,97,8,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,2,0,0,0,0,0,0,0,0,0,0,160,43,0,0,168,37,0,0,0,0,0,0,0,0,0,0,74,10,0,0,164,14,0,0,254,17,0,0,152,4,0,0,116,1,0,0,0,0,0,0,212,49,0,0,0,0,0,0,0,32,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,98,2,0,160,203,5,0,0,0,0,0,0,0,0,0,200,190,7,0,216,235,1,0,0,0,0,0,40,223,1,0,240,185,2,0,184,139,1,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,236,58,0,0,216,14,0,0,0,0,0,0,0,0,0,0,2,3,0,0,170,20,0,0,20,9,0,0,152,15,0,0,50,3,0,0,44,10,0,0,162,30,0,0,72,176,145,0,0,4,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,203,5,0,0,0,0,0,0,0,0,0,0,0,0,0,200,190,7,0,40,120,6,0,0,0,0,0,40,223,1,0,240,185,2,0,128,254,2,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,188,27,0,0,124,7,0,0,0,0,0,0,0,0,0,0,2,3,0,0,170,20,0,0,20,9,0,0,152,15,0,0,50,3,0,0,44,10,0,0,162,30,0,0,72,176,145,0,0,4,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,106,1,0,232,200,2,0,0,0,0,0,0,0,0,0,184,168,7,0,104,28,1,0,0,0,0,0,216,123,2,0,8,147,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,4,11,1,0,0,0,0,0,0,0,0,0,0,0,14,40,0,0,138,15,0,0,0,0,0,0,0,0,0,0,98,41,0,0,242,24,0,0,16,10,0,0,48,9,0,0,126,17,0,0,0,0,0,0,236,36,0,0,0,0,0,0,0,8,0,0,128,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,232,200,2,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,224,203,1,0,0,0,0,0,216,123,2,0,8,147,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,4,11,1,0,0,0,0,0,0,0,0,0,0,0,232,47,0,0,252,44,0,0,0,0,0,0,0,0,0,0,98,41,0,0,242,24,0,0,16,10,0,0,48,9,0,0,126,17,0,0,0,0,0,0,236,36,0,0,0,0,0,0,0,8,0,0,128,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,56,53,2,0,120,167,2,0,0,0,0,0,120,167,2,0,144,47,2,0,152,196,1,0,248,155,4,0,160,150,4,0,16,128,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,2,4,32,0,0,0,0,0,0,0,0,0,0,0,66,41,0,0,228,32,0,0,70,35,0,0,166,5,0,0,70,11,0,0,84,55,0,0,26,12,0,0,210,9,0,0,36,6,0,0,18,17,0,0,186,7,0,0,32,146,215,0,0,8,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,120,167,2,0,0,0,0,0,0,0,0,0,120,167,2,0,144,47,2,0,144,236,5,0,248,155,4,0,160,150,4,0,16,128,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,2,4,32,0,0,0,0,0,0,0,0,0,0,0,104,19,0,0,96,33,0,0,70,35,0,0,166,5,0,0,70,11,0,0,84,55,0,0,26,12,0,0,210,9,0,0,36,6,0,0,18,17,0,0,186,7,0,0,32,146,215,0,0,8,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,56,136,7,0,160,203,4,0,0,0,0,0,0,0,0,0,216,194,1,0,72,132,7,0,0,0,0,0,176,128,7,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,8,0,0,2,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,0,0,0,0,144,52,0,0,38,35,0,0,0,0,0,0,0,0,0,0,184,43,0,0,98,43,0,0,140,14,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,176,174,2,0,56,45,2,0,0,0,0,0,0,0,0,0,200,190,7,0,32,40,2,0,0,0,0,0,168,138,8,0,176,109,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,19,0,0,1,0,0,0,0,0,0,0,0,0,248,7,0,0,228,4,0,0,0,0,0,0,0,0,0,0,212,48,0,0,126,53,0,0,140,13,0,0,204,7,0,0,38,6,0,0,242,19,0,0,142,27,0,0,72,173,145,0,0,4,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,56,45,2,0,0,0,0,0,0,0,0,0,0,0,0,0,200,190,7,0,32,199,5,0,0,0,0,0,168,138,8,0,176,109,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,19,0,0,1,0,0,0,0,0,0,0,0,0,198,36,0,0,218,35,0,0,0,0,0,0,0,0,0,0,132,43,0,0,110,39,0,0,140,13,0,0,204,7,0,0,38,6,0,0,242,19,0,0,142,27,0,0,72,173,145,0,0,4,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,32,207,1,0,64,70,3,0,0,0,0,0,0,0,0,0,104,174,7,0,96,109,1,0,0,0,0,0,40,161,4,0,144,153,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,2,2,0,0,8,0,0,0,0,0,0,0,0,0,240,30,0,0,54,25,0,0,0,0,0,0,0,0,0,0,164,15,0,0,116,44,0,0,106,5,0,0,66,12,0,0,6,3,0,0,0,0,0,0,214,38,0,0,0,0,0,0,0,96,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,205,2,0,64,70,3,0,0,0,0,0,0,0,0,0,104,174,7,0,192,66,2,0,0,0,0,0,40,161,4,0,144,153,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,2,2,0,0,8,0,0,0,0,0,0,0,0,0,84,11,0,0,130,22,0,0,0,0,0,0,0,0,0,0,164,15,0,0,116,44,0,0,106,5,0,0,66,12,0,0,6,3,0,0,0,0,0,0,214,38,0,0,0,0,0,0,0,96,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,70,3,0,0,0,0,0,0,0,0,0,0,0,0,0,104,174,7,0,56,22,6,0,0,0,0,0,40,161,4,0,144,153,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,2,2,0,0,8,0,0,0,0,0,0,0,0,0,194,43,0,0,112,9,0,0,0,0,0,0,0,0,0,0,164,15,0,0,116,44,0,0,106,5,0,0,66,12,0,0,6,3,0,0,0,0,0,0,214,38,0,0,0,0,0,0,0,96,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,88,7,0,104,31,8,0,0,0,0,0,0,0,0,0,160,234,7,0,72,39,7,0,0,0,0,0,128,251,6,0,72,129,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,4,4,4,0,0,0,0,0,0,0,0,0,0,0,40,21,0,0,200,18,0,0,0,0,0,0,0,0,0,0,210,6,0,0,152,27,0,0,242,16,0,0,94,12,0,0,120,8,0,0,0,0,0,0,46,35,0,0,56,74,148,0,0,1,0,0,24,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,104,211,6,0,104,31,8,0,0,0,0,0,0,0,0,0,160,234,7,0,152,164,6,0,0,0,0,0,64,246,3,0,72,129,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,4,4,4,0,0,0,0,0,0,0,0,0,0,0,86,23,0,0,96,21,0,0,0,0,0,0,0,0,0,0,186,49,0,0,86,6,0,0,242,16,0,0,94,12,0,0,120,8,0,0,0,0,0,0,46,35,0,0,56,74,148,0,0,1,0,0,24,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,32,124,6,0,104,31,8,0,0,0,0,0,0,0,0,0,160,234,7,0,48,74,6,0,0,0,0,0,64,246,3,0,72,129,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,4,4,4,0,0,0,0,0,0,0,0,0,0,0,90,4,0,0,34,19,0,0,0,0,0,0,0,0,0,0,210,6,0,0,152,27,0,0,242,16,0,0,94,12,0,0,120,8,0,0,0,0,0,0,46,35,0,0,56,74,148,0,0,1,0,0,24,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,104,31,8,0,0,0,0,0,0,0,0,0,0,0,0,0,160,234,7,0,208,182,7,0,0,0,0,0,232,135,7,0,72,129,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,4,4,4,0,0,0,0,0,0,0,0,0,0,0,238,38,0,0,138,36,0,0,0,0,0,0,0,0,0,0,210,6,0,0,152,27,0,0,242,16,0,0,94,12,0,0,120,8,0,0,0,0,0,0,46,35,0,0,56,74,148,0,0,1,0,0,24,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,80,202,2,0,232,13,3,0,0,0,0,0,0,0,0,0,0,38,7,0,152,183,2,0,240,56,5,0,152,54,6,0,168,38,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,5,17,0,8,0,0,0,0,0,0,0,0,0,0,108,17,0,0,4,43,0,0,0,0,0,0,0,0,0,0,58,34,0,0,4,35,0,0,214,1,0,0,218,2,0,0,114,1,0,0,166,3,0,0,116,50,0,0,8,211,148,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,192,165,8,0,72,176,4,0,0,0,0,0,0,0,0,0,184,168,7,0,152,103,8,0,0,0,0,0,128,145,4,0,0,188,3,0,112,46,8,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,212,21,0,0,74,41,0,0,0,0,0,0,0,0,0,0,36,25,0,0,166,53,0,0,48,13,0,0,54,11,0,0,174,9,0,0,0,0,0,0,72,51,0,0,0,0,0,0,0,8,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,224,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,128,77,2,0,0,0,0,0,216,213,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,0,1,0,0,0,0,0,0,0,0,0,132,2,0,0,56,28,0,0,0,0,0,0,0,0,0,0,96,30,0,0,84,58,0,0,42,14,0,0,164,9,0,0,68,8,0,0,166,0,0,0,206,17,0,0,200,174,145,0,0,32,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,139,6,0,0,0,0,0,0,0,0,0,0,0,0,0,200,190,7,0,56,48,6,0,0,0,0,0,32,0,1,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,186,0,0,0,92,1,0,0,0,0,0,0,0,0,0,0,230,54,0,0,216,50,0,0,42,3,0,0,90,14,0,0,242,4,0,0,126,18,0,0,176,61,0,0,56,176,145,0,0,4,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,128,109,8,0,0,0,0,0,0,0,0,0,0,0,0,0,104,174,7,0,192,185,6,0,0,0,0,0,168,95,8,0,16,5,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,2,0,0,0,0,0,0,3,0,0,8,0,0,0,0,0,0,0,0,0,88,13,0,0,84,21,0,0,0,0,0,0,0,0,0,0,110,19,0,0,82,41,0,0,54,12,0,0,196,15,0,0,0,3,0,0,136,9,0,0,246,39,0,0,16,177,145,0,0,4,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,80,34,3,0,128,109,8,0,0,0,0,0,0,0,0,0,104,174,7,0,16,117,2,0,0,0,0,0,168,95,8,0,16,5,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,3,0,0,8,0,0,0,0,0,0,0,0,0,44,25,0,0,50,11,0,0,0,0,0,0,0,0,0,0,110,19,0,0,82,41,0,0,54,12,0,0,196,15,0,0,0,3,0,0,136,9,0,0,246,39,0,0,16,177,145,0,0,4,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,192,246,1,0,248,203,7,0,0,0,0,0,0,0,0,0,64,171,7,0,208,150,1,0,0,0,0,0,192,154,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,0,3,0,8,0,0,0,0,0,0,0,0,0,0,80,22,0,0,150,4,0,0,0,0,0,0,0,0,0,0,60,19,0,0,18,1,0,0,250,9,0,0,254,15,0,0,6,2,0,0,252,3,0,0,24,13,0,0,144,35,149,0,0,2,0,0,240,0,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,203,7,0,0,0,0,0,0,0,0,0,0,0,0,0,64,171,7,0,64,167,6,0,0,0,0,0,168,95,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,3,0,8,0,0,0,0,0,0,0,0,0,0,188,3,0,0,106,33,0,0,0,0,0,0,0,0,0,0,18,28,0,0,176,62,0,0,180,19,0,0,254,15,0,0,6,2,0,0,252,3,0,0,24,13,0,0,144,35,149,0,0,2,0,0,240,0,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,239,2,0,32,216,4,0,0,0,0,0,0,0,0,0,64,171,7,0,24,88,2,0,0,0,0,0,64,236,4,0,224,191,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,108,43,0,0,180,44,0,0,0,0,0,0,0,0,0,0,112,37,0,0,0,0,0,0,186,17,0,0,152,7,0,0,4,4,0,0,0,0,0,0,126,19,0,0,0,0,0,0,0,4,0,0,80,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,72,48,8,0,32,216,4,0,0,0,0,0,0,0,0,0,64,171,7,0,216,251,7,0,0,0,0,0,64,236,4,0,224,191,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,166,4,0,0,76,6,0,0,0,0,0,0,0,0,0,0,112,37,0,0,0,0,0,0,186,17,0,0,152,7,0,0,4,4,0,0,0,0,0,0,126,19,0,0,0,0,0,0,0,4,0,0,80,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,176,103,7,0,32,216,4,0,0,0,0,0,0,0,0,0,64,171,7,0,88,53,7,0,0,0,0,0,64,236,4,0,224,191,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,88,17,0,0,188,12,0,0,0,0,0,0,0,0,0,0,112,37,0,0,0,0,0,0,186,17,0,0,152,7,0,0,4,4,0,0,0,0,0,0,126,19,0,0,0,0,0,0,0,4,0,0,80,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,240,178,6,0,32,216,4,0,0,0,0,0,0,0,0,0,64,171,7,0,232,135,6,0,0,0,0,0,64,236,4,0,224,191,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,40,0,0,246,18,0,0,0,0,0,0,0,0,0,0,112,37,0,0,0,0,0,0,186,17,0,0,152,7,0,0,4,4,0,0,0,0,0,0,126,19,0,0,0,0,0,0,0,4,0,0,80,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,80,90,6,0,32,216,4,0,0,0,0,0,0,0,0,0,64,171,7,0,32,44,6,0,0,0,0,0,64,236,4,0,224,191,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,50,57,0,0,254,34,0,0,0,0,0,0,0,0,0,0,112,37,0,0,0,0,0,0,186,17,0,0,152,7,0,0,4,4,0,0,0,0,0,0,126,19,0,0,0,0,0,0,0,4,0,0,80,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,160,172,5,0,32,216,4,0,0,0,0,0,0,0,0,0,64,171,7,0,240,136,5,0,0,0,0,0,64,236,4,0,224,191,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,62,8,0,0,4,24,0,0,0,0,0,0,0,0,0,0,112,37,0,0,0,0,0,0,186,17,0,0,152,7,0,0,4,4,0,0,0,0,0,0,126,19,0,0,0,0,0,0,0,4,0,0,80,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,144,109,5,0,32,216,4,0,0,0,0,0,0,0,0,0,64,171,7,0,248,77,5,0,0,0,0,0,64,236,4,0,224,191,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,252,12,0,0,228,44,0,0,0,0,0,0,0,0,0,0,112,37,0,0,0,0,0,0,186,17,0,0,152,7,0,0,4,4,0,0,0,0,0,0,126,19,0,0,0,0,0,0,0,4,0,0,80,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,64,167,8,0,32,216,4,0,0,0,0,0,0,0,0,0,64,171,7,0,184,104,8,0,0,0,0,0,64,236,4,0,224,191,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,10,12,0,0,28,11,0,0,0,0,0,0,0,0,0,0,112,37,0,0,0,0,0,0,186,17,0,0,152,7,0,0,4,4,0,0,0,0,0,0,126,19,0,0,0,0,0,0,0,4,0,0,80,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,64,228,1,0,32,216,4,0,0,0,0,0,0,0,0,0,64,171,7,0,128,129,1,0,0,0,0,0,64,236,4,0,224,191,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,30,15,0,0,172,0,0,0,0,0,0,0,0,0,0,0,112,37,0,0,0,0,0,0,186,17,0,0,152,7,0,0,4,4,0,0,0,0,0,0,126,19,0,0,0,0,0,0,0,4,0,0,80,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,128,198,7,0,32,216,4,0,0,0,0,0,0,0,0,0,64,171,7,0,32,150,7,0,0,0,0,0,64,236,4,0,224,191,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,254,20,0,0,168,34,0,0,0,0,0,0,0,0,0,0,112,37,0,0,0,0,0,0,186,17,0,0,152,7,0,0,4,4,0,0,0,0,0,0,126,19,0,0,0,0,0,0,0,4,0,0,80,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,192,9,7,0,32,216,4,0,0,0,0,0,0,0,0,0,64,171,7,0,96,223,6,0,0,0,0,0,64,236,4,0,224,191,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,42,53,0,0,158,43,0,0,0,0,0,0,0,0,0,0,112,37,0,0,0,0,0,0,186,17,0,0,152,7,0,0,4,4,0,0,0,0,0,0,126,19,0,0,0,0,0,0,0,4,0,0,80,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,240,1,6,0,32,216,4,0])
.concat([0,0,0,0,0,0,0,0,64,171,7,0,16,212,5,0,0,0,0,0,64,236,4,0,224,191,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,166,22,0,0,242,4,0,0,0,0,0,0,0,0,0,0,112,37,0,0,0,0,0,0,186,17,0,0,152,7,0,0,4,4,0,0,0,0,0,0,126,19,0,0,0,0,0,0,0,4,0,0,80,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,160,43,1,0,32,216,4,0,0,0,0,0,0,0,0,0,64,171,7,0,152,232,8,0,0,0,0,0,64,236,4,0,224,191,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,128,10,0,0,114,26,0,0,0,0,0,0,0,0,0,0,112,37,0,0,0,0,0,0,186,17,0,0,152,7,0,0,4,4,0,0,0,0,0,0,126,19,0,0,0,0,0,0,0,4,0,0,80,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,64,110,4,0,32,216,4,0,0,0,0,0,0,0,0,0,64,171,7,0,152,84,4,0,0,0,0,0,64,236,4,0,224,191,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,112,11,0,0,118,25,0,0,0,0,0,0,0,0,0,0,112,37,0,0,0,0,0,0,184,11,0,0,152,7,0,0,4,4,0,0,0,0,0,0,126,19,0,0,0,0,0,0,0,4,0,0,80,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,88,57,4,0,32,216,4,0,0,0,0,0,0,0,0,0,64,171,7,0,208,29,4,0,0,0,0,0,64,236,4,0,224,191,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,54,6,0,0,22,40,0,0,0,0,0,0,0,0,0,0,112,37,0,0,0,0,0,0,184,11,0,0,152,7,0,0,4,4,0,0,0,0,0,0,126,19,0,0,0,0,0,0,0,4,0,0,80,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,240,237,4,0,32,216,4,0,0,0,0,0,0,0,0,0,64,171,7,0,96,202,4,0,0,0,0,0,64,236,4,0,224,191,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,56,2,0,0,64,8,0,0,0,0,0,0,0,0,0,0,112,37,0,0,0,0,0,0,184,11,0,0,152,7,0,0,4,4,0,0,0,0,0,0,126,19,0,0,0,0,0,0,0,4,0,0,80,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,80,1,4,0,32,216,4,0,0,0,0,0,0,0,0,0,64,171,7,0,192,223,3,0,0,0,0,0,64,236,4,0,224,191,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,120,24,0,0,46,27,0,0,0,0,0,0,0,0,0,0,112,37,0,0,0,0,0,0,184,11,0,0,152,7,0,0,4,4,0,0,0,0,0,0,126,19,0,0,0,0,0,0,0,4,0,0,80,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,208,169,4,0,32,216,4,0,0,0,0,0,0,0,0,0,64,171,7,0,144,138,4,0,0,0,0,0,64,236,4,0,224,191,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,152,30,0,0,208,1,0,0,0,0,0,0,0,0,0,0,112,37,0,0,0,0,0,0,184,11,0,0,152,7,0,0,4,4,0,0,0,0,0,0,126,19,0,0,0,0,0,0,0,4,0,0,80,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,144,46,5,0,32,216,4,0,0,0,0,0,0,0,0,0,64,171,7,0,160,16,5,0,0,0,0,0,64,236,4,0,224,191,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,106,12,0,0,222,32,0,0,0,0,0,0,0,0,0,0,112,37,0,0,0,0,0,0,184,11,0,0,152,7,0,0,4,4,0,0,0,0,0,0,126,19,0,0,0,0,0,0,0,4,0,0,80,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,32,216,4,0,0,0,0,0,0,0,0,0,0,0,0,0,64,171,7,0,104,87,6,0,0,0,0,0,64,236,4,0,224,191,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,4,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,60,18,0,0,68,24,0,0,0,0,0,0,0,0,0,0,112,37,0,0,0,0,0,0,186,17,0,0,152,7,0,0,4,4,0,0,0,0,0,0,126,19,0,0,0,0,0,0,0,4,0,0,80,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,184,118,3,0,64,193,3,0,0,0,0,0,0,0,0,0,160,234,7,0,192,95,3,0,0,0,0,0,64,236,4,0,224,191,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,244,46,0,0,192,16,0,0,0,0,0,0,0,0,0,0,112,37,0,0,0,0,0,0,238,19,0,0,152,7,0,0,4,4,0,0,0,0,0,0,126,19,0,0,0,0,0,0,0,4,0,0,80,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,248,6,3,0,64,193,3,0,0,0,0,0,0,0,0,0,160,234,7,0,152,240,2,0,0,0,0,0,64,236,4,0,224,191,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,55,0,0,142,22,0,0,0,0,0,0,0,0,0,0,112,37,0,0,0,0,0,0,238,19,0,0,152,7,0,0,4,4,0,0,0,0,0,0,126,19,0,0,0,0,0,0,0,4,0,0,80,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,48,50,3,0,64,193,3,0,0,0,0,0,0,0,0,0,160,234,7,0,216,30,3,0,0,0,0,0,64,236,4,0,224,191,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,32,0,0,196,40,0,0,0,0,0,0,0,0,0,0,112,37,0,0,0,0,0,0,238,19,0,0,152,7,0,0,4,4,0,0,0,0,0,0,126,19,0,0,0,0,0,0,0,4,0,0,80,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,152,80,3,0,64,193,3,0,0,0,0,0,0,0,0,0,160,234,7,0,248,65,3,0,0,0,0,0,64,236,4,0,224,191,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,32,4,0,0,134,4,0,0,0,0,0,0,0,0,0,0,112,37,0,0,0,0,0,0,238,19,0,0,152,7,0,0,4,4,0,0,0,0,0,0,126,19,0,0,0,0,0,0,0,4,0,0,80,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,64,193,3,0,0,0,0,0,0,0,0,0,0,0,0,0,160,234,7,0,32,142,3,0,0,0,0,0,64,236,4,0,224,191,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,4,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,10,56,0,0,74,42,0,0,0,0,0,0,0,0,0,0,112,37,0,0,0,0,0,0,238,19,0,0,152,7,0,0,4,4,0,0,0,0,0,0,126,19,0,0,0,0,0,0,0,4,0,0,80,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,248,24,1,0,104,224,2,0,0,0,0,0,0,0,0,0,104,221,5,0,200,216,8,0,0,0,0,0,176,237,2,0,168,84,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,19,4,1,0,0,0,0,0,0,0,0,0,0,164,4,0,0,246,35,0,0,0,0,0,0,0,0,0,0,228,48,0,0,208,39,0,0,94,3,0,0,158,16,0,0,112,13,0,0,214,17,0,0,128,28,0,0,160,173,145,0,0,8,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,32,151,8,0,104,224,2,0,0,0,0,0,0,0,0,0,104,221,5,0,88,88,8,0,0,0,0,0,176,237,2,0,168,84,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,19,4,1,0,0,0,0,0,0,0,0,0,0,206,6,0,0,126,0,0,0,0,0,0,0,0,0,0,0,228,48,0,0,208,39,0,0,94,3,0,0,158,16,0,0,112,13,0,0,214,17,0,0,128,28,0,0,160,173,145,0,0,8,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,128,34,5,0,0,0,0,0,0,0,0,0,0,0,0,0,200,190,7,0,240,4,5,0,0,0,0,0,176,237,2,0,176,109,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,19,0,0,1,0,0,0,0,0,0,0,0,0,218,1,0,0,164,42,0,0,0,0,0,0,0,0,0,0,72,50,0,0,114,47,0,0,14,2,0,0,216,15,0,0,38,17,0,0,166,4,0,0,250,47,0,0,72,173,145,0,0,4,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,64,19,7,0,152,116,8,0,0,0,0,0,0,0,0,0,104,174,7,0,152,231,6,0,0,0,0,0,168,95,8,0,176,6,8,0,136,189,6,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,3,0,0,8,0,0,0,0,0,0,0,0,0,248,48,0,0,180,5,0,0,0,0,0,0,0,0,0,0,46,52,0,0,116,18,0,0,106,17,0,0,14,19,0,0,14,10,0,0,172,8,0,0,148,27,0,0,96,176,145,0,0,1,0,0,224,0,0,0,48,1,0,0,3,0,0,0,4,0,0,0,208,169,5,0,176,193,5,0,72,172,6,0,0,0,0,0,144,139,6,0,216,163,5,0,0,0,0,0,128,145,4,0,208,9,3,0,40,159,5,0,0,0,0,0,0,0,0,0,0,0,0,0,81,0,0,0,2,0,0,0,0,0,1,133,8,0,0,0,0,0,0,0,0,0,0,0,144,11,0,0,58,16,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,193,5,0,0,0,0,0,72,172,6,0,0,0,0,0,144,139,6,0,24,190,5,0,0,0,0,0,128,145,4,0,208,9,3,0,72,187,5,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,72,0,1,133,8,0,0,0,0,0,0,0,0,0,0,0,162,2,0,0,254,47,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,180,8,0,0,84,19,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,46,7,0,0,0,0,0,0,0,0,0,0,0,0,0,184,230,7,0,32,2,7,0,0,0,0,0,152,190,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,10,0,32,0,0,0,0,0,0,0,0,0,0,64,38,0,0,136,0,0,0,0,0,0,0,0,0,0,0,188,37,0,0,198,42,0,0,178,13,0,0,210,18,0,0,126,11,0,0,212,16,0,0,82,63,0,0,16,174,145,0,0,4,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,144,72,5,0,0,0,0,0,0,0,0,0,0,0,0,0,160,234,7,0,160,40,5,0,0,0,0,0,16,182,4,0,192,152,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,9,2,2,0,0,0,0,0,0,0,0,0,0,0,152,21,0,0,242,19,0,0,0,0,0,0,0,0,0,0,94,27,0,0,168,58,0,0,50,2,0,0,42,17,0,0,184,7,0,0,0,0,0,0,216,46,0,0,0,0,0,0,0,6,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,136,244,6,0,192,78,7,0,0,0,0,0,0,0,0,0,32,127,5,0,104,203,6,0,0,0,0,0,32,46,8,0,240,85,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,19,0,0,1,0,0,0,0,0,0,0,0,0,138,30,0,0,52,43,0,0,0,0,0,0,0,0,0,0,108,48,0,0,228,33,0,0,36,8,0,0,32,4,0,0,120,0,0,0,54,14,0,0,62,2,0,0,8,173,145,0,0,4,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,104,155,6,0,120,136,1,0,0,0,0,0,0,0,0,0,224,56,7,0,192,113,6,0,0,0,0,0,144,88,7,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,9,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,184,61,0,0,214,45,0,0,0,0,0,0,0,0,0,0,86,51,0,0,114,62,0,0,8,7,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,184,237,3,0,0,0,0,0,0,0,0,0,0,0,0,0,168,163,7,0,24,52,6,0,0,0,0,0,184,191,7,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,1,0,0,0,0,0,0,10,0,4,0,0,0,0,0,0,0,0,0,0,72,41,0,0,176,9,0,0,0,0,0,0,0,0,0,0,54,42,0,0,130,0,0,0,178,18,0,0,12,10,0,0,194,10,0,0,228,15,0,0,96,60,0,0,144,174,145,0,0,132,0,0,224,0,0,0,0,2,0,0,3,0,0,0,4,0,0,0,168,213,3,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,216,48,6,0,0,0,0,0,72,187,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,133,0,0,0,2,0,0,0,0,0,0,10,0,16,0,0,0,0,0,0,0,0,0,0,168,18,0,0,78,7,0,0,0,0,0,0,0,0,0,0,236,22,0,0,204,59,0,0,194,0,0,0,8,1,0,0,110,5,0,0,158,7,0,0,4,30,0,0,104,157,215,0,0,4,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,112,101,5,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,128,39,5,0,0,0,0,0,40,52,7,0,128,194,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,3,11,2,0,0,0,0,0,0,0,0,0,0,0,218,21,0,0,190,30,0,0,0,0,0,0,0,0,0,0,90,22,0,0,90,17,0,0,114,8,0,0,224,17,0,0,188,8,0,0,2,1,0,0,74,29,0,0,0,0,0,0,0,16,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,88,77,2,0,200,119,2,0,0,0,0,0,0,0,0,0,144,47,2,0,56,65,2,0,0,0,0,0,152,54,6,0,200,12,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,17,1,0,0,0,0,0,0,0,0,0,0,0,114,21,0,0,248,18,0,0,0,0,0,0,0,0,0,0,198,62,0,0,158,19,0,0,32,18,0,0,230,1,0,0,44,6,0,0,194,15,0,0,0,0,0,0,48,177,145,0,0,2,0,0,128,1,0,0,0,1,0,0,4,0,0,0,3,0,0,0,216,0,8,0,248,152,5,0,0,0,0,0,248,152,5,0,216,194,1,0,32,203,7,0,0,0,0,0,192,154,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,142,20,0,0,234,11,0,0,48,2,0,0,2,43,0,0,110,37,0,0,210,41,0,0,206,13,0,0,130,5,0,0,252,15,0,0,0,0,0,0,18,4,0,0,0,0,0,0,64,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,160,165,4,0,0,0,0,0,0,0,0,0,0,0,0,0,184,12,8,0,232,134,4,0,0,0,0,0,232,107,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,131,0,0,0,2,0,0,0,0,0,0,10,0,64,0,0,0,0,0,0,0,0,0,0,94,48,0,0,58,0,0,0,0,0,0,0,0,0,0,0,196,46,0,0,56,6,0,0,90,10,0,0,8,1,0,0,134,12,0,0,190,17,0,0,4,30,0,0,104,157,215,0,0,4,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,12,8,0,112,100,8,0,0,0,0,0,0,0,0,0,96,159,4,0,80,5,8,0,0,0,0,0,80,0,8,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,0,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,214,41,0,0,64,16,0,0,0,0,0,0,0,0,0,0,86,51,0,0,114,62,0,0,134,4,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,88,158,2,0,120,136,1,0,0,0,0,0,0,0,0,0,96,159,4,0,32,145,2,0,0,0,0,0,120,16,5,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,8,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,78,51,0,0,184,6,0,0,0,0,0,0,0,0,0,0,86,51,0,0,94,2,0,0,8,7,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,208,71,8,0,120,136,1,0,0,0,0,0,0,0,0,0,224,56,7,0,96,21,8,0,0,0,0,0,24,224,7,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,8,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,218,52,0,0,234,32,0,0,0,0,0,0,0,0,0,0,86,51,0,0,114,62,0,0,8,7,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,176,199,8,0,120,136,1,0,0,0,0,0,0,0,0,0,224,56,7,0,248,134,8,0,0,0,0,0,8,6,1,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,8,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,8,53,0,0,252,19,0,0,0,0,0,0,0,0,0,0,86,51,0,0,26,31,0,0,8,7,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,128,177,1,0,120,136,1,0,0,0,0,0,0,0,0,0,224,56,7,0,160,80,1,0,0,0,0,0,8,6,1,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,8,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,160,56,0,0,48,40,0,0,0,0,0,0,0,0,0,0,86,51,0,0,26,31,0,0,8,7,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,224,129,3,0,120,136,1,0,0,0,0,0,0,0,0,0,224,56,7,0,192,105,3,0,0,0,0,0,192,154,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,8,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,232,7,0,0,128,22,0,0,0,0,0,0,0,0,0,0,86,51,0,0,158,8,0,0,8,7,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,224,152,2,0,120,136,1,0,0,0,0,0,0,0,0,0,224,56,7,0,48,24,2,0,0,0,0,0,248,39,8,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,8,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,246,30,0,0,56,9,0,0,0,0,0,0,0,0,0,0,86,51,0,0,114,62,0,0,8,7,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,120,136,1,0,0,0,0,0,0,0,0,0,0,0,0,0,224,56,7,0,32,139,5,0,0,0,0,0,248,39,8,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,8,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,2,7,0,0,226,5,0,0,0,0,0,0,0,0,0,0,86,51,0,0,26,31,0,0,8,7,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,184,205,3,0,120,136,1,0,0,0,0,0,0,0,0,0,224,56,7,0,96,178,3,0,0,0,0,0,192,154,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,8,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,202,12,0,0,44,41,0,0,0,0,0,0,0,0,0,0,86,51,0,0,26,31,0,0,8,7,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,240,62,6,0,120,136,1,0,0,0,0,0,0,0,0,0,224,56,7,0,40,24,6,0,0,0,0,0,144,88,7,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,9,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,66,11,0,0,6,30,0,0,0,0,0,0,0,0,0,0,86,51,0,0,114,62,0,0,8,7,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,216,152,5,0,120,136,1,0,0,0,0,0,0,0,0,0,224,56,7,0,104,122,5,0,0,0,0,0,144,92,5,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,9,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,104,60,0,0,38,18,0,0,0,0,0,0,0,0,0,0,86,51,0,0,114,62,0,0,8,7,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,8,233,5,0,120,136,1,0,0,0,0,0,0,0,0,0,224,56,7,0,16,193,5,0,0,0,0,0,144,88,7,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,9,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,212,12,0,0,112,6,0,0,0,0,0,0,0,0,0,0,86,51,0,0,114,62,0,0,8,7,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,240,251,2,0,248,152,5,0,0,0,0,0,248,152,5,0,216,194,1,0,224,96,2,0,0,0,0,0,248,39,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,82,19,0,0,98,38,0,0,48,2,0,0,2,43,0,0,110,37,0,0,210,41,0,0,154,1,0,0,130,5,0,0,252,15,0,0,0,0,0,0,18,4,0,0,0,0,0,0,64,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,248,234,1,0,248,152,5,0,0,0,0,0,248,152,5,0,216,194,1,0,48,138,1,0,0,0,0,0,64,49,1,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,62,20,0,0,234,5,0,0,48,2,0,0,2,43,0,0,110,37,0,0,208,53,0,0,154,1,0,0,130,5,0,0,252,15,0,0,0,0,0,0,18,4,0,0,0,0,0,0,64,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,8,237,8,0,248,152,5,0,0,0,0,0,248,152,5,0,216,194,1,0,224,172,8,0,0,0,0,0,64,49,1,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,162,37,0,0,68,9,0,0,48,2,0,0,2,43,0,0,110,37,0,0,210,41,0,0,154,1,0,0,130,5,0,0,252,15,0,0,0,0,0,0,18,4,0,0,0,0,0,0,64,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,96,109,8,0,248,152,5,0,0,0,0,0,248,152,5,0,216,194,1,0,184,52,8,0,0,0,0,0,64,49,1,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,144,31,0,0,198,44,0,0,48,2,0,0,2,43,0,0,110,37,0,0,210,41,0,0,154,1,0,0,130,5,0,0,252,15,0,0,0,0,0,0,18,4,0,0,0,0,0,0,64,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,248,152,5,0,0,0,0,0,0,0,0,0,248,152,5,0,216,194,1,0,248,115,6,0,0,0,0,0,248,39,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,54,55,0,0,136,12,0,0,48,2,0,0,2,43,0,0,110,37,0,0,210,41,0,0,154,1,0,0,130,5,0,0,252,15,0,0,0,0,0,0,18,4,0,0,0,0,0,0,64,2,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,64,215,1,0,192,201,3,0,0,0,0,0,0,0,0,0,104,174,7,0,24,117,1,0,0,0,0,0,32,0,1,0,240,185,2,0,64,36,1,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,176,45,0,0,150,10,0,0,0,0,0,0,0,0,0,0,222,45,0,0,162,51,0,0,128,17,0,0,14,3,0,0,164,11,0,0,42,4,0,0,242,13,0,0,104,174,145,0,0,16,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,171,3,0,0,0,0,0,0,0,0,0,0,0,0,0,144,139,6,0,200,40,6,0,0,0,0,0,232,197,4,0,136,153,3,0,248,214,2,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,6,4,0,0,0,0,0,0,0,0,0,0,0,4,12,0,0,62,25,0,0,0,0,0,0,0,0,0,0,6,43,0,0,170,30,0,0,20,19,0,0,206,8,0,0,68,9,0,0,198,7,0,0,40,6,0,0,96,49,216,0,0,128,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,52,3,0,160,143,3,0,0,0,0,0,0,0,0,0,160,234,7,0,32,32,3,0,0,0,0,0,192,154,4,0,136,252,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,126,9,0,0,202,40,0,0,0,0,0,0,0,0,0,0,172,22,0,0,222,7,0,0,124,2,0,0,64,13,0,0,168,2,0,0,0,0,0,0,134,1,0,0,0,0,0,0,0,1,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,88,81,3,0,160,143,3,0,0,0,0,0,0,0,0,0,160,234,7,0,48,67,3,0,0,0,0,0,192,154,4,0,136,252,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,234,52,0,0,206,24,0,0,0,0,0,0,0,0,0,0,172,22,0,0,222,7,0,0,124,2,0,0,64,13,0,0,168,2,0,0,0,0,0,0,134,1,0,0,0,0,0,0,0,1,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,104,88,3,0,0,0,0,0,0,0,0,0,0,0,0,0,144,139,6,0,56,26,6,0,0,0,0,0,136,186,4,0,120,156,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,16,0,0,0,0,0,0,0,0,0,0,18,29,0,0,86,25,0,0,0,0,0,0,0,0,0,0,200,23,0,0,180,58,0,0,238,12,0,0,58,5,0,0,16,14,0,0,248,17,0,0,206,30,0,0,208,173,145,0,0,3,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,207,2,0,104,88,3,0,0,0,0,0,0,0,0,0,144,139,6,0,240,67,2,0,0,0,0,0,136,208,1,0,120,156,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,10,0,16,0,0,0,0,0,0,0,0,0,0,46,5,0,0,240,39,0,0,0,0,0,0,0,0,0,0,200,23,0,0,180,58,0,0,238,12,0,0,58,5,0,0,16,14,0,0,248,17,0,0,206,30,0,0,208,173,145,0,0,3,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,176,2,0,96,65,2,0,0,0,0,0,0,0,0,0,96,135,2,0,96,42,2,0,0,0,0,0,176,237,2,0,168,84,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,19,0,8,0,0,0,0,0,0,0,0,0,0,48,38,0,0,148,17,0,0,0,0,0,0,0,0,0,0,76,59,0,0,68,26,0,0,170,16,0,0,240,12,0,0,80,18,0,0,94,2,0,0,112,63,0,0,80,173,145,0,0,4,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,96,65,2,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,32,205,5,0,0,0,0,0,160,131,4,0,168,84,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,19,0,8,0,0,0,0,0,0,0,0,0,0,142,10,0,0,186,18,0,0,0,0,0,0,0,0,0,0,76,59,0,0,36,62,0,0,170,16,0,0,240,12,0,0,80,18,0,0,94,2,0,0,112,63,0,0,80,173,145,0,0,4,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,184,211,2,0,0,63,3,0,0,0,0,0,0,0,0,0,200,190,7,0,80,193,2,0,0,0,0,0,144,84,8,0,128,194,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,11,0,0,4,0,0,0,0,0,0,0,0,0,152,45,0,0,42,17,0,0,0,0,0,0,0,0,0,0,188,7,0,0,168,21,0,0,236,9,0,0,46,1,0,0,106,9,0,0,0,0,0,0,78,54,0,0,0,0,0,0,0,32,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,80,217,1,0,144,51,6,0,0,0,0,0,0,0,0,0,96,135,2,0,112,118,1,0,0,0,0,0,32,0,1,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,10,2,0,0,0,0,0,0,0,0,0,0,0,6,38,0,0,76,13,0,0,0,0,0,0,0,0,0,0,74,10,0,0,108,36,0,0,254,17,0,0,152,4,0,0,116,1,0,0,0,0,0,0,212,49,0,0,0,0,0,0,0,32,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,144,51,6,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,104,171,3,0,0,0,0,0,32,0,1,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,2,0,0,0,0,0,0,10,2,0,0,0,0,0,0,0,0,0,0,0,22,42,0,0,194,36,0,0,0,0,0,0,0,0,0,0,74,10,0,0,108,36,0,0,254,17,0,0,152,4,0,0,116,1,0,0,0,0,0,0,212,49,0,0,0,0,0,0,0,32,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,56,84,5,0,24,183,5,0,0,0,0,0,0,0,0,0,104,174,7,0,120,54,5,0,0,0,0,0,168,95,8,0,128,115,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,3,0,64,0,0,0,0,0,0,0,0,0,0,46,29,0,0,2,31,0,0,0,0,0,0,0,0,0,0,176,49,0,0,78,61,0,0,116,4,0,0,156,9,0,0,198,15,0,0,232,8,0,0,42,6,0,0,216,176,145,0,0,4,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,183,5,0,0,0,0,0,0,0,0,0,0,0,0,0,104,174,7,0,40,144,5,0,0,0,0,0,168,95,8,0,128,115,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,3,0,64,0,0,0,0,0,0,0,0,0,0,200,42,0,0,122,32,0,0,0,0,0,0,0,0,0,0,176,49,0,0,78,61,0,0,116,4,0,0,156,9,0,0,198,15,0,0,232,8,0,0,42,6,0,0,216,176,145,0,0,4,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,159,4,0,104,218,4,0,0,0,0,0,0,0,0,0,216,194,1,0,240,156,4,0,0,0,0,0,152,154,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,8,0,0,2,0,0,0,0,0,0,16,0,0,1,0,0,0,0,0,0,0,0,0,92,18,0,0,74,23,0,0,0,0,0,0,0,0,0,0,234,16,0,0,244,49,0,0,46,19,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,200,195,4,0,104,218,4,0,0,0,0,0,0,0,0,0,216,194,1,0,112,191,4,0,0,0,0,0,128,199,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,8,0,0,2,0,0,0,0,0,0,16,0,0,1,0,0,0,0,0,0,0,0,0,140,37,0,0,8,38,0,0,0,0,0,0,0,0,0,0,234,16,0,0,244,49,0,0,80,9,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,88,209,4,0,104,218,4,0,0,0,0,0,0,0,0,0,216,194,1,0,24,206,4,0,0,0,0,0,128,199,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,8,0,0,2,0,0,0,0,0,0,16,0,0,1,0,0,0,0,0,0,0,0,0,116,35,0,0,82,44,0,0,0,0,0,0,0,0,0,0,234,16,0,0,244,49,0,0,80,9,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,120,181,4,0,104,218,4,0,0,0,0,0,0,0,0,0,216,194,1,0,160,179,4,0,0,0,0,0,192,154,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,8,0,0,2,0,0,0,0,0,0,16,0,0,1,0,0,0,0,0,0,0,0,0,90,53,0,0,202,36,0,0,0,0,0,0,0,0,0,0,234,16,0,0,244,49,0,0,232,12,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,232,188,4,0,104,218,4,0,0,0,0,0,0,0,0,0,216,194,1,0,248,185,4,0,24,163,4,0,128,199,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,8,0,0,2,0,0,0,0,0,0,16,0,0,1,0,0,0,0,0,0,0,0,0,142,35,0,0,88,20,0,0,0,0,0,0,0,0,0,0,182,21,0,0,56,30,0,0,70,4,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,104,218,4,0,0,0,0,0,0,0,0,0,0,0,0,0,216,194,1,0,240,215,4,0,0,0,0,0,168,95,8,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,8,0,0,2,0,0,0,0,0,0,16,0,0,1,0,0,0,0,0,0,0,0,0,2,32,0,0,50,28,0,0,0,0,0,0,0,0,0,0,234,16,0,0,244,49,0,0,80,9,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,40,168,4,0,104,218,4,0,0,0,0,0,0,0,0,0,216,194,1,0,168,163,4,0,0,0,0,0,192,154,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,0,0,0,2,0,0,0,0,0,0,16,0,0,1,0,0,0,0,0,0,0,0,0,180,43,0,0,188,7,0,0,0,0,0,0,0,0,0,0,182,3,0,0,172,1,0,0,208,15,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,168,175,4,0,104,218,4,0,0,0,0,0,0,0,0,0,216,194,1,0,40,172,4,0,0,0,0,0,192,154,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,8,0,0,2,0,0,0,0,0,0,16,0,0,1,0,0,0,0,0,0,0,0,0,118,11,0,0,12,13,0,0,0,0,0,0,0,0,0,0,234,16,0,0,244,49,0,0,142,8,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,248,222,8,0,56,252,8,0,0,0,0,0,0,0,0,0,184,168,7,0,168,215,8,0,0,0,0,0,192,154,4,0,80,150,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,2,4,2,0,16,0,0,0,0,0,0,0,0,0,0,96,28,0,0,146,21,0,0,0,0,0,0,0,0,0,0,148,18,0,0,194,51,0,0,128,3,0,0,114,17,0,0,134,11,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,207,8,0,56,252,8,0,0,0,0,0,0,0,0,0,184,168,7,0,64,203,8,0,0,0,0,0,192,154,4,0,80,150,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,2,4,2,0,16,0,0,0,0,0,0,0,0,0,0,226,42,0,0,72,10,0,0,0,0,0,0,0,0,0,0,148,18,0,0,194,51,0,0,128,3,0,0,114,17,0,0,134,11,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,239,8,0,56,252,8,0,0,0,0,0,0,0,0,0,184,168,7,0,208,231,8,0,0,0,0,0,40,161,4,0,80,150,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,64,4,4,2,0,16,0,0,0,0,0,0,0,0,0,0,14,37,0,0,250,17,0,0,0,0,0,0,0,0,0,0,172,57,0,0,194,51,0,0,218,12,0,0,114,17,0,0,134,11,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,252,8,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,224,245,8,0])
.concat([0,0,0,0,40,161,4,0,80,150,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,68,0,4,2,0,16,0,0,0,0,0,0,0,0,0,0,128,35,0,0,10,44,0,0,0,0,0,0,0,0,0,0,172,57,0,0,194,51,0,0,218,12,0,0,114,17,0,0,134,11,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,135,5,0,0,0,0,0,0,0,0,0,0,0,0,0,56,172,6,0,216,76,5,0,0,0,0,0,40,45,5,0,48,178,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,33,0,0,0,2,0,0,0,0,0,0,10,0,2,0,0,0,0,0,0,0,0,0,0,248,11,0,0,130,40,0,0,0,0,0,0,0,0,0,0,116,30,0,0,8,23,0,0,234,13,0,0,222,19,0,0,52,15,0,0,0,0,0,0,36,38,0,0,0,0,0,0,0,2,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,68,4,0,0,0,0,0,0,0,0,0,0,0,0,0,216,194,1,0,48,26,7,0,0,0,0,0,160,23,7,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,39,0,0,0,2,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,0,0,0,0,120,42,0,0,202,30,0,0,0,0,0,0,0,0,0,0,204,20,0,0,174,40,0,0,152,2,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,32,62,3,0,0,0,0,0,0,0,0,0,0,0,0,0,64,171,7,0,160,19,6,0,0,0,0,0,16,182,4,0,192,152,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,9,2,1,0,0,0,0,0,0,0,0,0,0,0,12,29,0,0,72,40,0,0,0,0,0,0,0,0,0,0,94,27,0,0,4,58,0,0,26,13,0,0,42,17,0,0,184,7,0,0,0,0,0,0,216,46,0,0,0,0,0,0,0,6,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,90,3,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,144,62,3,0,0,0,0,0,168,183,7,0,208,135,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,4,0,0,0,0,0,2,11,0,128,0,0,0,0,0,0,0,0,0,0,242,34,0,0,214,39,0,0,0,0,0,0,0,0,0,0,2,46,0,0,72,19,0,0,246,4,0,0,46,7,0,0,246,17,0,0,0,0,0,0,176,18,0,0,0,0,0,0,0,32,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,201,2,0,8,21,3,0,0,0,0,0,0,0,0,0,64,171,7,0,48,64,2,0,0,0,0,0,64,246,3,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,19,0,0,0,2,0,0,0,0,0,3,11,0,0,1,0,0,0,0,0,0,0,0,0,196,40,0,0,144,11,0,0,0,0,0,0,0,0,0,0,252,33,0,0,248,10,0,0,110,4,0,0,32,11,0,0,212,18,0,0,20,12,0,0,0,0,0,0,176,173,145,0,0,2,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,21,3,0,0,0,0,0,0,0,0,0,0,0,0,0,64,171,7,0,120,12,6,0,0,0,0,0,64,246,3,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,2,0,0,0,0,0,3,11,0,0,1,0,0,0,0,0,0,0,0,0,172,27,0,0,224,3,0,0,0,0,0,0,0,0,0,0,252,33,0,0,248,10,0,0,110,4,0,0,32,11,0,0,212,18,0,0,20,12,0,0,0,0,0,0,176,173,145,0,0,2,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,205,5,0,232,93,7,0,0,0,0,0,0,0,0,0,232,233,7,0,144,165,5,0,0,0,0,0,40,161,4,0,192,152,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,9,2,0,8,0,0,0,0,0,0,0,0,0,0,100,55,0,0,146,12,0,0,0,0,0,0,0,0,0,0,154,55,0,0,48,47,0,0,164,12,0,0,42,17,0,0,184,7,0,0,0,0,0,0,216,46,0,0,0,0,0,0,0,6,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,37,6,0,232,93,7,0,0,0,0,0,0,0,0,0,232,233,7,0,80,248,5,0,0,0,0,0,40,161,4,0,192,152,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,9,2,0,8,0,0,0,0,0,0,0,0,0,0,214,44,0,0,8,45,0,0,0,0,0,0,0,0,0,0,154,55,0,0,48,47,0,0,82,4,0,0,42,17,0,0,184,7,0,0,0,0,0,0,216,46,0,0,0,0,0,0,0,6,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,128,6,0,232,93,7,0,0,0,0,0,0,0,0,0,232,233,7,0,248,79,6,0,0,0,0,0,40,161,4,0,192,152,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,9,2,0,8,0,0,0,0,0,0,0,0,0,0,158,38,0,0,128,31,0,0,0,0,0,0,0,0,0,0,154,55,0,0,48,47,0,0,166,11,0,0,42,17,0,0,184,7,0,0,0,0,0,0,216,46,0,0,0,0,0,0,0,6,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,131,5,0,232,93,7,0,0,0,0,0,0,0,0,0,232,233,7,0,80,103,5,0,0,0,0,0,40,161,4,0,192,152,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,9,2,0,8,0,0,0,0,0,0,0,0,0,0,150,26,0,0,40,9,0,0,0,0,0,0,0,0,0,0,154,55,0,0,48,47,0,0,166,11,0,0,42,17,0,0,184,7,0,0,0,0,0,0,216,46,0,0,0,0,0,0,0,6,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,216,6,0,232,93,7,0,0,0,0,0,0,0,0,0,232,233,7,0,248,169,6,0,0,0,0,0,40,161,4,0,192,152,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,9,2,0,8,0,0,0,0,0,0,0,0,0,0,76,7,0,0,80,24,0,0,0,0,0,0,0,0,0,0,154,55,0,0,48,47,0,0,38,14,0,0,42,17,0,0,184,7,0,0,0,0,0,0,216,46,0,0,0,0,0,0,0,6,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,93,7,0,0,0,0,0,0,0,0,0,0,0,0,0,232,233,7,0,72,45,7,0,0,0,0,0,40,161,4,0,192,152,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,9,2,0,8,0,0,0,0,0,0,0,0,0,0,36,39,0,0,118,30,0,0,0,0,0,0,0,0,0,0,154,55,0,0,48,47,0,0,224,11,0,0,42,17,0,0,184,7,0,0,0,0,0,0,216,46,0,0,0,0,0,0,0,6,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,56,7,0,240,255,7,0,0,0,0,0,0,0,0,0,64,171,7,0,96,12,7,0,0,0,0,0,40,161,4,0,136,252,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,40,11,0,0,12,1,0,0,0,0,0,0,0,0,0,0,172,22,0,0,236,21,0,0,124,2,0,0,64,13,0,0,168,2,0,0,0,0,0,0,134,1,0,0,0,0,0,0,0,1,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,255,7,0,0,0,0,0,0,0,0,0,0,0,0,0,64,171,7,0,48,153,7,0,0,0,0,0,40,161,4,0,136,252,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,134,25,0,0,72,36,0,0,0,0,0,0,0,0,0,0,172,22,0,0,236,21,0,0,124,2,0,0,64,13,0,0,168,2,0,0,0,0,0,0,134,1,0,0,0,0,0,0,0,1,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,73,6,0,56,142,2,0,0,0,0,0,0,0,0,0,96,135,2,0,120,32,6,0,0,0,0,0,160,150,4,0,16,128,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,3,0,0,0,0,0,2,4,0,0,8,0,0,0,0,0,0,0,0,0,86,32,0,0,162,28,0,0,0,0,0,0,0,0,0,0,224,1,0,0,10,53,0,0,218,7,0,0,218,18,0,0,104,7,0,0,188,17,0,0,168,20,0,0,32,146,215,0,0,8,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,184,241,5,0,56,142,2,0,0,0,0,0,0,0,0,0,96,135,2,0,216,201,5,0,0,0,0,0,160,150,4,0,16,128,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,3,0,0,0,0,0,2,4,0,0,8,0,0,0,0,0,0,0,0,0,108,39,0,0,32,33,0,0,0,0,0,0,0,0,0,0,224,1,0,0,10,53,0,0,194,12,0,0,218,18,0,0,104,7,0,0,188,17,0,0,168,20,0,0,32,146,215,0,0,8,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,80,31,8,0,56,142,2,0,0,0,0,0,0,0,0,0,96,135,2,0,64,234,7,0,0,0,0,0,160,150,4,0,16,128,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,3,0,0,0,0,0,2,4,0,0,8,0,0,0,0,0,0,0,0,0,66,44,0,0,160,21,0,0,0,0,0,0,0,0,0,0,224,1,0,0,10,53,0,0,208,12,0,0,218,18,0,0,104,7,0,0,188,17,0,0,168,20,0,0,32,146,215,0,0,8,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,176,182,7,0,56,142,2,0,0,0,0,0,0,0,0,0,96,135,2,0,168,135,7,0,0,0,0,0,160,150,4,0,16,128,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,3,0,0,0,0,0,2,4,0,0,8,0,0,0,0,0,0,0,0,0,30,3,0,0,116,12,0,0,0,0,0,0,0,0,0,0,224,1,0,0,10,53,0,0,110,3,0,0,218,18,0,0,104,7,0,0,188,17,0,0,168,20,0,0,32,146,215,0,0,8,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,104,164,6,0,56,142,2,0,0,0,0,0,0,0,0,0,96,135,2,0,184,123,6,0,0,0,0,0,160,150,4,0,16,128,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,3,0,0,0,0,0,2,4,0,0,8,0,0,0,0,0,0,0,0,0,152,28,0,0,84,4,0,0,0,0,0,0,0,0,0,0,224,1,0,0,10,53,0,0,30,6,0,0,218,18,0,0,104,7,0,0,188,17,0,0,168,20,0,0,32,146,215,0,0,8,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,104,186,2,0,56,142,2,0,0,0,0,0,0,0,0,0,96,135,2,0,32,50,2,0,0,0,0,0,160,150,4,0,16,128,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,3,0,0,0,0,0,2,4,0,0,8,0,0,0,0,0,0,0,0,0,196,27,0,0,58,42,0,0,0,0,0,0,0,0,0,0,224,1,0,0,10,53,0,0,184,5,0,0,218,18,0,0,104,7,0,0,188,17,0,0,168,20,0,0,32,146,215,0,0,8,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,56,195,1,0,56,142,2,0,0,0,0,0,0,0,0,0,96,135,2,0,216,97,1,0,0,0,0,0,160,150,4,0,16,128,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,3,0,0,0,0,0,2,4,0,0,8,0,0,0,0,0,0,0,0,0,76,20,0,0,66,14,0,0,0,0,0,0,0,0,0,0,224,1,0,0,10,53,0,0,120,1,0,0,218,18,0,0,104,7,0,0,188,17,0,0,168,20,0,0,32,146,215,0,0,8,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,176,160,5,0,56,142,2,0,0,0,0,0,0,0,0,0,96,135,2,0,168,127,5,0,0,0,0,0,160,150,4,0,16,128,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,3,0,0,0,0,0,2,4,0,0,8,0,0,0,0,0,0,0,0,0,142,23,0,0,54,13,0,0,0,0,0,0,0,0,0,0,224,1,0,0,10,53,0,0,36,15,0,0,218,18,0,0,104,7,0,0,188,17,0,0,168,20,0,0,32,146,215,0,0,8,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,192,98,5,0,56,142,2,0,0,0,0,0,0,0,0,0,96,135,2,0,248,67,5,0,0,0,0,0,160,150,4,0,16,128,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,3,0,0,0,0,0,2,4,0,0,8,0,0,0,0,0,0,0,0,0,232,54,0,0,146,34,0,0,0,0,0,0,0,0,0,0,224,1,0,0,10,53,0,0,134,13,0,0,218,18,0,0,104,7,0,0,188,17,0,0,168,20,0,0,32,146,215,0,0,8,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,144,19,1,0,56,142,2,0,0,0,0,0,0,0,0,0,96,135,2,0,24,212,8,0,0,0,0,0,160,150,4,0,16,128,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,3,0,0,0,0,0,2,4,0,0,8,0,0,0,0,0,0,0,0,0,74,4,0,0,16,43,0,0,0,0,0,0,0,0,0,0,224,1,0,0,10,53,0,0,12,6,0,0,218,18,0,0,104,7,0,0,188,17,0,0,168,20,0,0,32,146,215,0,0,8,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,248,147,8,0,56,142,2,0,0,0,0,0,0,0,0,0,96,135,2,0,240,84,8,0,0,0,0,0,160,150,4,0,16,128,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,3,0,0,0,0,0,2,4,0,0,8,0,0,0,0,0,0,0,0,0,56,56,0,0,224,34,0,0,0,0,0,0,0,0,0,0,224,1,0,0,10,53,0,0,214,4,0,0,218,18,0,0,104,7,0,0,188,17,0,0,168,20,0,0,32,146,215,0,0,8,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,224,87,7,0,56,142,2,0,0,0,0,0,0,0,0,0,96,135,2,0,0,39,7,0,0,0,0,0,160,150,4,0,16,128,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,3,0,0,0,0,0,2,4,0,0,8,0,0,0,0,0,0,0,0,0,88,43,0,0,18,33,0,0,0,0,0,0,0,0,0,0,224,1,0,0,10,53,0,0,88,1,0,0,218,18,0,0,104,7,0,0,188,17,0,0,168,20,0,0,32,146,215,0,0,8,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,88,251,6,0,56,142,2,0,0,0,0,0,0,0,0,0,96,135,2,0,56,211,6,0,0,0,0,0,160,150,4,0,16,128,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,3,0,0,0,0,0,2,4,0,0,8,0,0,0,0,0,0,0,0,0,78,24,0,0,172,26,0,0,0,0,0,0,0,0,0,0,224,1,0,0,10,53,0,0,0,10,0,0,218,18,0,0,104,7,0,0,188,17,0,0,168,20,0,0,32,146,215,0,0,8,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,56,142,2,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,152,230,5,0,0,0,0,0,160,150,4,0,16,128,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,3,0,0,0,0,0,2,4,0,0,8,0,0,0,0,0,0,0,0,0,250,34,0,0,246,25,0,0,0,0,0,0,0,0,0,0,224,1,0,0,10,53,0,0,246,8,0,0,218,18,0,0,104,7,0,0,188,17,0,0,168,20,0,0,32,146,215,0,0,8,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,216,21,1,0,152,165,2,0,0,0,0,0,152,165,2,0,104,221,5,0,104,213,8,0,120,155,4,0,160,99,1,0,224,127,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,1,4,2,0,0,0,0,0,0,0,0,0,0,0,168,12,0,0,170,39,0,0,38,43,0,0,108,39,0,0,54,13,0,0,150,35,0,0,224,12,0,0,46,14,0,0,102,14,0,0,94,13,0,0,238,17,0,0,32,146,215,0,0,8,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,24,53,2,0,152,165,2,0,0,0,0,0,152,165,2,0,104,221,5,0,112,196,1,0,120,155,4,0,160,99,1,0,224,127,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,1,4,2,0,0,0,0,0,0,0,0,0,0,0,236,15,0,0,62,21,0,0,38,43,0,0,108,39,0,0,54,13,0,0,150,35,0,0,224,12,0,0,46,14,0,0,102,14,0,0,94,13,0,0,238,17,0,0,32,146,215,0,0,8,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,152,165,2,0,0,0,0,0,0,0,0,0,152,165,2,0,104,221,5,0,16,236,5,0,120,155,4,0,160,150,4,0,224,127,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,1,4,2,0,0,0,0,0,0,0,0,0,0,0,70,42,0,0,130,37,0,0,38,43,0,0,108,39,0,0,54,13,0,0,82,17,0,0,224,12,0,0,46,14,0,0,102,14,0,0,94,13,0,0,238,17,0,0,32,146,215,0,0,8,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,168,190,1,0,0,0,0,0,0,0,0,0,0,0,0,0,104,129,6,0,56,176,1,0,0,0,0,0,0,188,4,0,80,164,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,2,0,0,0,0,0,0,0,0,0,0,0,114,46,0,0,138,17,0,0,0,0,0,0,0,0,0,0,244,56,0,0,250,59,0,0,48,2,0,0,88,18,0,0,228,5,0,0,64,7,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,15,5,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,176,199,4,0,0,0,0,0,64,168,4,0,48,178,3,0,176,136,4,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,16,0,0,0,0,0,0,0,0,0,0,170,37,0,0,226,12,0,0,0,0,0,0,0,0,0,0,116,30,0,0,22,54,0,0,190,16,0,0,222,19,0,0,54,3,0,0,0,0,0,0,36,38,0,0,0,0,0,0,0,2,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,135,3,0,144,22,4,0,0,0,0,0,0,0,0,0,104,174,7,0,8,112,3,0,0,0,0,0,128,161,4,0,208,135,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,2,11,8,0,0,0,0,0,0,0,0,0,0,0,50,51,0,0,240,25,0,0,0,0,0,0,0,0,0,0,230,17,0,0,72,24,0,0,188,9,0,0,46,7,0,0,246,17,0,0,0,0,0,0,176,18,0,0,0,0,0,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,185,3,0,144,22,4,0,0,0,0,0,0,0,0,0,104,174,7,0,168,160,3,0,0,0,0,0,144,84,8,0,208,135,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,2,11,8,0,0,0,0,0,0,0,0,0,0,0,22,20,0,0,222,24,0,0,0,0,0,0,0,0,0,0,230,17,0,0,72,24,0,0,188,9,0,0,46,7,0,0,246,17,0,0,0,0,0,0,176,18,0,0,0,0,0,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,22,4,0,0,0,0,0,0,0,0,0,0,0,0,0,104,174,7,0,128,213,3,0,0,0,0,0,168,183,7,0,208,135,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,2,11,8,0,0,0,0,0,0,0,0,0,0,0,254,57,0,0,196,0,0,0,0,0,0,0,0,0,0,0,230,17,0,0,174,2,0,0,188,9,0,0,46,7,0,0,246,17,0,0,0,0,0,0,176,18,0,0,0,0,0,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,187,8,0,0,0,0,0,0,0,0,0,0,0,0,0,232,233,7,0,8,122,8,0,0,0,0,0,184,63,8,0,136,11,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,2,17,0,64,0,0,0,0,0,0,0,0,0,0,134,34,0,0,116,16,0,0,0,0,0,0,0,0,0,0,238,42,0,0,52,52,0,0,48,16,0,0,150,14,0,0,160,6,0,0,224,14,0,0,222,61,0,0,40,177,145,0,0,1,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,68,5,0,200,33,6,0,0,0,0,0,0,0,0,0,184,168,7,0,216,37,5,0,0,0,0,0,168,99,5,0,248,135,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,19,8,0,0,0,0,0,0,0,0,0,0,0,252,32,0,0,30,28,0,0,0,0,0,0,0,0,0,0,72,1,0,0,120,0,0,0,46,15,0,0,116,8,0,0,90,13,0,0,0,0,0,0,68,58,0,0,0,0,0,0,0,4,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,152,161,5,0,200,33,6,0,0,0,0,0,0,0,0,0,184,168,7,0,160,128,5,0,0,0,0,0,168,99,5,0,248,135,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,19,8,0,0,0,0,0,0,0,0,0,0,0,136,33,0,0,24,6,0,0,0,0,0,0,0,0,0,0,72,1,0,0,120,0,0,0,46,15,0,0,116,8,0,0,90,13,0,0,0,0,0,0,68,58,0,0,0,0,0,0,0,4,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,56,196,3,0,0,0,0,0,0,0,0,0,0,0,0,0,192,177,6,0,152,44,6,0,0,0,0,0,32,203,4,0,136,153,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,133,0,0,0,2,0,0,0,0,0,0,6,2,0,0,0,0,0,0,0,0,0,0,0,214,29,0,0,100,40,0,0,0,0,0,0,0,0,0,0,60,48,0,0,0,0,0,0,230,6,0,0,172,19,0,0,240,19,0,0,224,6,0,0,188,42,0,0,96,49,216,0,0,128,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,120,20,3,0,0,0,0,0,72,172,6,0,0,0,0,0,96,135,2,0,72,17,1,0,0,0,0,0,128,145,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,0,64,0,0,0,0,0,0,0,0,0,0,68,51,0,0,12,0,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,135,6,0,0,0,0,0,72,172,6,0,0,0,0,0,32,127,5,0,112,174,7,0,0,0,0,0,128,145,4,0,208,9,3,0,144,169,7,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,8,0,0,0,16,0,0,0,0,0,0,0,110,29,0,0,76,7,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,223,1,0,0,0,0,0,72,172,6,0,0,0,0,0,96,135,2,0,16,83,8,0,0,0,0,0,128,145,4,0,208,9,3,0,104,78,8,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,4,0,1,133,8,0,0,0,16,0,0,0,0,0,0,0,22,31,0,0,92,18,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,200,2,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,4,8,0,160,9,1,0,72,172,6,0,0,0,0,0,240,3,2,0,152,253,7,0,0,0,0,0,128,145,4,0,208,9,3,0,56,245,7,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,133,8,0,0,0,16,0,0,0,0,0,0,0,184,9,0,0,210,18,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,178,4,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,9,1,0,0,0,0,0,72,172,6,0,0,0,0,0,240,3,2,0,136,15,8,0,0,0,0,0,128,145,4,0,208,9,3,0,56,10,8,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,8,0,0,0,16,0,0,0,0,0,0,0,214,36,0,0,10,9,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,67,1,0,0,0,0,0,72,172,6,0,0,0,0,0,96,135,2,0,200,61,1,0,0,0,0,0,128,145,4,0,208,9,3,0,240,52,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,8,0,0,0,16,0,0,0,0,0,0,0,86,5,0,0,80,27,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,251,2,0,32,148,5,0,0,0,0,0,0,0,0,0,64,171,7,0,200,96,2,0,0,0,0,0,152,196,7,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,0,0,0,0,74,3,0,0,70,25,0,0,0,0,0,0,0,0,0,0,166,44,0,0,60,24,0,0,184,16,0,0,116,6,0,0,6,11,0,0,252,16,0,0,54,48,0,0,24,176,145,0,0,4,0,0,240,0,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,104,5,0,40,250,5,0,0,0,0,0,0,0,0,0,160,234,7,0,0,73,5,0,0,0,0,0,40,161,4,0,248,206,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,2,1,0,0,0,0,0,0,0,0,0,0,0,220,52,0,0,182,31,0,0,0,0,0,0,0,0,0,0,50,61,0,0,28,33,0,0,244,0,0,0,2,17,0,0,144,2,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,166,5,0,40,250,5,0,0,0,0,0,0,0,0,0,160,234,7,0,144,131,5,0,0,0,0,0,40,161,4,0,248,206,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,2,1,0,0,0,0,0,0,0,0,0,0,0,124,20,0,0,254,44,0,0,0,0,0,0,0,0,0,0,50,61,0,0,28,33,0,0,218,12,0,0,114,17,0,0,144,2,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,250,5,0,0,0,0,0,0,0,0,0,0,0,0,0,160,234,7,0,128,206,5,0,0,0,0,0,40,161,4,0,248,206,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,3,2,1,0,0,0,0,0,0,0,0,0,0,0,180,28,0,0,46,47,0,0,0,0,0,0,0,0,0,0,50,61,0,0,28,33,0,0,218,12,0,0,114,17,0,0,144,2,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,4,1,0,152,65,1,0,0,0,0,0,0,0,0,0,112,177,2,0,96,255,0,0,0,0,0,0,40,161,4,0,80,150,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,128,4,2,1,0,0,0,0,0,0,0,0,0,0,0,244,57,0,0,54,36,0,0,0,0,0,0,0,0,0,0,210,8,0,0,120,5,0,0,104,10,0,0,114,17,0,0,134,11,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,15,1,0,152,65,1,0,0,0,0,0,0,0,0,0,112,177,2,0,56,10,1,0,0,0,0,0,144,50,1,0,216,42,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,128,4,2,1,0,0,0,0,0,0,0,0,0,0,0,174,61,0,0,164,41,0,0,0,0,0,0,0,0,0,0,210,8,0,0,120,5,0,0,230,16,0,0,114,17,0,0,134,11,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,33,1,0,152,65,1,0,0,0,0,0,0,0,0,0,112,177,2,0,248,23,1,0,0,0,0,0,144,50,1,0,216,42,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,128,4,2,1,0,0,0,0,0,0,0,0,0,0,0,206,12,0,0,12,37,0,0,0,0,0,0,0,0,0,0,210,8,0,0,120,5,0,0,254,10,0,0,114,17,0,0,134,11,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,65,1,0,0,0,0,0,0,0,0,0,0,0,0,0,112,177,2,0,216,58,1,0,0,0,0,0,144,50,1,0,216,42,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,128,4,2,1,0,0,0,0,0,0,0,0,0,0,0,130,33,0,0,210,33,0,0,0,0,0,0,0,0,0,0,210,8,0,0,120,5,0,0,254,10,0,0,114,17,0,0,134,11,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,48,7,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,32,5,7,0,0,0,0,0,144,218,6,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,133,0,0,0,2,0,0,0,0,0,0,10,0,16,0,0,0,0,0,0,0,0,0,0,170,42,0,0,62,9,0,0,0,0,0,0,0,0,0,0,236,22,0,0,92,38,0,0,210,17,0,0,8,1,0,0,76,2,0,0,190,17,0,0,4,30,0,0,104,157,215,0,0,4,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,224,74,5,0,136,169,5,0,0,0,0,0,0,0,0,0,184,12,8,0,56,43,5,0,0,0,0,0,184,191,7,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,147,0,0,0,2,0,0,0,0,0,0,10,0,16,0,0,0,0,0,0,0,0,0,0,202,14,0,0,72,4,0,0,0,0,0,0,0,0,0,0,236,22,0,0,24,19,0,0,20,15,0,0,8,1,0,0,76,2,0,0,190,17,0,0,4,30,0,0,104,157,215,0,0,4,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,169,5,0,0,0,0,0,0,0,0,0,0,0,0,0,184,12,8,0,232,105,5,0,0,0,0,0,184,191,7,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,131,0,0,0,2,0,0,0,0,0,0,10,0,16,0,0,0,0,0,0,0,0,0,0,86,31,0,0,54,37,0,0,0,0,0,0,0,0,0,0,236,22,0,0,24,19,0,0,20,15,0,0,8,1,0,0,76,2,0,0,190,17,0,0,4,30,0,0,104,157,215,0,0,4,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,164,6,0,32,18,7,0,0,0,0,0,0,0,0,0,96,159,4,0,176,160,6,0,0,0,0,0,104,157,6,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,8,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,110,11,0,0,240,2,0,0,0,0,0,0,0,0,0,0,70,34,0,0,214,34,0,0,88,16,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,64,96,5,0,0,0,0,0,0,0,0,0,0,0,0,0,160,135,3,0,168,93,5,0,0,0,0,0,232,98,5,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,30,14,0,0,214,46,0,0,0,0,0,0,0,0,0,0,238,9,0,0,78,40,0,0,52,8,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,0,37,1,0,112,220,2,0,0,0,0,0,0,0,0,0,0,38,7,0,72,226,8,0,0,0,0,0,168,117,1,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,149,0,0,0,2,0,0,0,0,0,0,10,0,16,0,0,0,0,0,0,0,0,0,0,18,19,0,0,116,6,0,0,0,0,0,0,0,0,0,0,236,22,0,0,92,38,0,0,210,17,0,0,8,1,0,0,76,2,0,0,190,17,0,0,4,30,0,0,104,157,215,0,0,4,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,112,220,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,112,216,1,0,0,0,0,0,168,117,1,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,133,0,0,0,2,0,0,0,0,0,0,10,0,16,0,0,0,0,0,0,0,0,0,0,70,4,0,0,104,5,0,0,0,0,0,0,0,0,0,0,236,22,0,0,92,38,0,0,210,17,0,0,8,1,0,0,76,2,0,0,190,17,0,0,4,30,0,0,104,157,215,0,0,4,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,72,109,4,0,0,0,0,0,0,0,0,0,0,0,0,0,168,163,7,0,96,56,4,0,0,0,0,0,0,192,4,0,240,185,2,0,232,254,3,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,8,0,0,0,0,0,0,0,0,0,0,58,29,0,0,254,6,0,0,0,0,0,0,0,0,0,0,130,10,0,0,240,43,0,0,158,8,0,0,56,15,0,0,12,17,0,0,0,0,0,0,224,13,0,0,0,0,0,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,152,123,1,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,24,229,8,0,0,0,0,0,224,189,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,1,0,0,0,0,0,0,10,0,0,4,0,0,0,0,0,0,0,0,0,62,63,0,0,94,43,0,0,0,0,0,0,0,0,0,0,174,36,0,0,194,7,0,0,0,20,0,0,72,9,0,0,196,5,0,0,122,11,0,0,82,12,0,0,240,174,145,0,1,4,0,0,224,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,152,71,4,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,176,61,6,0,0,0,0,0,224,189,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,1,0,0,0,0,0,0,10,0,0,4,0,0,0,0,0,0,0,0,0,136,35,0,0,66,13,0,0,0,0,0,0,0,0,0,0,134,16,0,0,138,43,0,0,84,15,0,0,72,9,0,0,196,5,0,0,186,13,0,0,82,12,0,0,240,174,145,0,1,4,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,32,250,7,0,112,164,8,0,0,0,0,0,0,0,0,0,104,174,7,0,128,196,7,0,0,0,0,0,192,154,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,0,20,0,0,4,0,0,0,0,0,0,0,0,0,246,61,0,0,74,21,0,0,0,0,0,0,0,0,0,0,212,26,0,0,132,41,0,0,146,7,0,0,36,0,0,0,160,11,0,0,54,16,0,0,250,8,0,0,16,175,145,0,64,2,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,164,8,0,0,0,0,0,0,0,0,0,0,0,0,0,104,174,7,0,192,45,8,0,0,0,0,0,104,224,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,20,0,0,4,0,0,0,0,0,0,0,0,0,160,15,0,0,122,13,0,0,0,0,0,0,0,0,0,0,212,26,0,0,132,41,0,0,112,1,0,0,36,0,0,0,160,11,0,0,54,16,0,0,250,8,0,0,16,175,145,0,64,2,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,103,1,0,240,194,2,0,0,0,0,0,0,0,0,0,200,190,7,0,176,24,1,0,0,0,0,0,128,216,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,3,11,0,0,1,0,0,0,0,0,0,0,0,0,210,14,0,0,246,26,0,0,0,0,0,0,0,0,0,0,68,17,0,0,142,12,0,0,112,15,0,0,82,3,0,0,246,2,0,0,152,1,0,0,92,6,0,0,144,173,145,0,0,2,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,240,194,2,0,0,0,0,0,0,0,0,0,0,0,0,0,200,190,7,0,88,59,2,0,0,0,0,0,168,183,7,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,3,11,0,0,1,0,0,0,0,0,0,0,0,0,152,18,0,0,92,34,0,0,0,0,0,0,0,0,0,0,68,17,0,0,142,12,0,0,112,15,0,0,82,3,0,0,246,2,0,0,152,1,0,0,92,6,0,0,144,173,145,0,0,2,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,216,150,8,0,240,194,2,0,0,0,0,0,0,0,0,0,200,190,7,0,16,88,8,0,0,0,0,0,144,84,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,3,11,0,0,1,0,0,0,0,0,0,0,0,0,62,7,0,0,186,37,0,0,0,0,0,0,0,0,0,0,68,17,0,0,142,12,0,0,112,15,0,0,82,3,0,0,246,2,0,0,152,1,0,0,92,6,0,0,144,173,145,0,0,2,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,40,225,8,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,248,216,8,0,0,0,0,0,96,208,8,0,0,227,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,21,0,0,1,0,0,0,0,0,0,0,0,0,184,14,0,0,162,41,0,0,0,0,0,0,0,0,0,0,98,19,0,0,228,32,0,0,246,3,0,0,248,19,0,0,72,13,0,0,56,10,0,0,96,10,0,0,224,174,145,0,0,18,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,32,34,4,0,160,187,8,0,0,0,0,0,0,0,0,0,216,194,1,0,40,32,4,0,0,0,0,0,192,154,4,0,72,81,3,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,55,8,0,0,2,0,0,0,0,0,0,16,1,0,0,0,0,0,0,0,0,0,0,0,24,28,0,0,6,14,0,0,0,0,0,0,0,0,0,0,20,1,0,0,68,22,0,0,122,13,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,88,189,7,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,0,95,7,0,0,0,0,0,72,187,4,0,200,156,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,2,0,0,0,0,0,1,14,2,0,0,0,0,0,0,0,0,0,0,0,46,32,0,0,178,7,0,0,0,0,0,0,0,0,0,0,238,62,0,0,182,2,0,0,88,10,0,0,236,10,0,0,222,18,0,0,0,0,0,0,238,10,0,0,0,0,0,0,0,16,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,216,13,1,0,208,56,1,0,0,0,0,0,0,0,0,0,40,41,5,0,32,9,1,0,0,0,0,0,32,3,1,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,0,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,178,3,0,0,34,21,0,0,0,0,0,0,0,0,0,0,70,34,0,0,24,62,0,0,8,7,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,200,231,2,0,56,129,4,0,0,0,0,0,0,0,0,0,200,190,7,0,72,81,2,0,0,0,0,0,40,223,1,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,1,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,198,12,0,0,236,45,0,0,0,0,0,0,0,0,0,0,2,57,0,0,212,36,0,0,10,19,0,0,176,13,0,0,162,7,0,0,164,4,0,0,0,0,0,0,32,175,145,0,0,2,0,0,224,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,232,24,5,0,0,0,0,0,0,0,0,0,0,0,0,0,64,171,7,0,216,97,6,0,0,0,0,0,192,223,4,0,240,185,2,0,200,244,2,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,0,20,2,0,0,0,0,0,0,0,0,0,0,0,230,34,0,0,158,15,0,0,0,0,0,0,0,0,0,0,250,13,0,0,34,57,0,0,54,9,0,0,8,3,0,0,38,12,0,0,164,19,0,0,180,35,0,0,144,175,145,0,0,4,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,168,78,1,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,80,71,1,0,0,0,0,0,40,161,4,0,80,150,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,68,0,4,2,0,64,0,0,0,0,0,0,0,0,0,0,84,28,0,0,228,5,0,0,0,0,0,0,0,0,0,0,170,46,0,0,98,22,0,0,72,17,0,0,236,1,0,0,134,11,0,0,0,0,0,0,90,15,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,121,1,0,184,224,2,0,0,0,0,0,0,0,0,0,168,163,7,0,96,39,1,0,0,0,0,0,160,213,4,0,112,163,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,10,0,16,0,0,0,0,0,0,0,0,0,0,192,15,0,0,206,15,0,0,0,0,0,0,0,0,0,0,154,54,0,0,222,29,0,0,172,11,0,0,16,8,0,0,80,3,0,0,0,0,0,0,176,0,0,0,0,0,0,0,0,4,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,184,224,2,0,0,0,0,0,0,0,0,0,0,0,0,0,168,163,7,0,208,219,1,0,0,0,0,0,160,213,4,0,112,163,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,16,0,0,0,0,0,0,0,0,0,0,72,3,0,0,254,39,0,0,0,0,0,0,0,0,0,0,154,54,0,0,222,29,0,0,172,11,0,0,16,8,0,0,80,3,0,0,0,0,0,0,176,0,0,0,0,0,0,0,0,4,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,104,0,3,0,40,90,3,0,0,0,0,0,0,0,0,0,96,135,2,0,216,234,2,0,0,0,0,0,168,183,7,0,208,135,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,2,11,0,128,0,0,0,0,0,0,0,0,0,0,204,12,0,0,42,46,0,0,0,0,0,0,0,0,0,0,2,46,0,0,72,19,0,0,246,4,0,0,46,7,0,0,246,17,0,0,0,0,0,0,176,18,0,0,0,0,0,0,0,32,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,91,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,208,253,6,0,0,0,0,0,40,52,7,0,128,194,2,0,80,167,6,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,3,11,0,16,0,0,0,0,0,0,0,0,0,0,246,40,0,0,220,5,0,0,0,0,0,0,0,0,0,0,90,22,0,0,20,2,0,0,224,2,0,0,224,17,0,0,188,8,0,0,2,1,0,0,74,29,0,0,0,0,0,0,0,16,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,72,114,1,0,240,160,1,0,0,0,0,0,0,0,0,0,184,168,7,0,136,102,1,0,0,0,0,0,40,161,4,0,80,150,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,64,8,4,2,0,8,0,0,0,0,0,0,0,0,0,0,146,45,0,0,18,14,0,0,0,0,0,0,0,0,0,0,50,22,0,0,188,54,0,0,248,9,0,0,114,17,0,0,134,11,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,142,1,0,240,160,1,0,0,0,0,0,0,0,0,0,184,168,7,0,48,128,1,0,0,0,0,0,40,161,4,0,80,150,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,64,8,4,2,0,8,0,0,0,0,0,0,0,0,0,0,50,0,0,0,210,10,0,0,0,0,0,0,0,0,0,0,50,22,0,0,188,54,0,0,248,9,0,0,114,17,0,0,134,11,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,92,1,0,240,160,1,0,0,0,0,0,0,0,0,0,184,168,7,0,64,86,1,0,0,0,0,0,192,154,4,0,80,150,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,8,4,2,0,8,0,0,0,0,0,0,0,0,0,0,18,41,0,0,232,17,0,0,0,0,0,0,0,0,0,0,50,22,0,0,188,54,0,0,168,6,0,0,114,17,0,0,134,11,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,160,1,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,56,152,1,0,0,0,0,0,40,161,4,0,80,150,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,64,8,4,2,0,8,0,0,0,0,0,0,0,0,0,0,32,40,0,0,0,2,0,0,0,0,0,0,0,0,0,0,50,22,0,0,188,54,0,0,248,9,0,0,114,17,0,0,134,11,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,110,1,0,152,86,3,0,0,0,0,0,0,0,0,0,192,177,6,0,24,32,1,0,0,0,0,0,24,186,4,0,136,153,3,0,16,221,8,0,0,0,0,0,0,0,0,0,0,0,0,0,149,0,0,0,2,0,0,0,0,0,0,6,2,0,0,0,0,0,0,0,0,0,0,0,24,60,0,0,122,18,0,0,0,0,0,0,0,0,0,0,232,18,0,0,0,0,0,0,188,15,0,0,74,12,0,0,62,17,0,0,8,17,0,0,72,8,0,0,96,49,216,0,0,128,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,32,207,2,0,152,86,3,0,0,0,0,0,0,0,0,0,192,177,6,0,152,67,2,0,0,0,0,0,24,186,4,0,136,153,3,0,208,207,1,0,0,0,0,0,0,0,0,0,0,0,0,0,149,0,0,0,2,0,0,0,0,0,0,6,2,0,0,0,0,0,0,0,0,0,0,0,30,8,0,0,0,44,0,0,0,0,0,0,0,0,0,0,232,18,0,0,0,0,0,0,188,15,0,0,74,12,0,0,62,17,0,0,8,17,0,0,72,8,0,0,96,49,216,0,0,128,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,152,86,3,0,0,0,0,0,0,0,0,0,0,0,0,0,192,177,6,0,184,25,6,0,0,0,0,0,24,186,4,0,136,153,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,133,0,0,0,2,0,0,0,0,0,0,6,2,0,0,0,0,0,0,0,0,0,0,0,132,37,0,0,142,40,0,0,0,0,0,0,0,0,0,0,232,18,0,0,0,0,0,0,188,15,0,0,74,12,0,0,62,17,0,0,8,17,0,0,72,8,0,0,96,49,216,0,0,128,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,88,147,5,0,0,0,0,0,0,0,0,0,0,0,0,0,144,33,2,0,176,144,5,0,0,0,0,0,72,233,5,0,216,229,5,0,24,141,5,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,4,0,0,0,2,0,0,8,2,0,0,0,0,0,0,0,0,0,0,0,58,59,0,0,188,37,0,0,0,0,0,0,0,0,0,0,104,35,0,0,16,44,0,0,12,12,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,224,0,0,0,192,1,0,0,3,0,0,0,4,0,0,0,176,65,7,0,48,211,7,0,0,0,0,0,0,0,0,0,144,47,2,0,104,21,7,0,0,0,0,0,168,95,8,0,176,116,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,3,0,0,1,0,0,0,0,0,0,0,0,0,92,9,0,0,38,44,0,0,0,0,0,0,0,0,0,0,82,61,0,0,0,0,0,0,78,10,0,0,214,8,0,0,238,14,0,0,80,10,0,0,198,2,0,0,0,177,145,0,0,8,0,0,32,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,48,211,7,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,88,161,7,0,0,0,0,0,168,95,8,0,176,116,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,4,0,0,0,0,0,0,3,0,0,1,0,0,0,0,0,0,0,0,0,120,44,0,0,70,31,0,0,0,0,0,0,0,0,0,0,108,53,0,0,0,0,0,0,78,10,0,0,214,8,0,0,238,14,0,0,80,10,0,0,0,0,0,0,0,177,145,0,0,8,0,0,32,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,192,235,4,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,64,90,6,0,0,0,0,0,232,237,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,86,13,0,0,138,10,0,0,0,0,0,0,0,0,0,0,152,53,0,0,108,14,0,0,2,3,0,0,6,0,0,0,188,1,0,0,234,3,0,0,138,21,0,0,120,175,145,0,8,0,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,90,3,0,184,186,3,0,0,0,0,0,0,0,0,0,104,174,7,0,208,75,3,0,0,0,0,0,144,84,8,0,216,142,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,11,0,0,8,0,0,0,0,0,0,0,0,0,192,33,0,0,96,11,0,0,0,0,0,0,0,0,0,0,236,45,0,0,10,11,0,0,252,10,0,0,24,8,0,0,14,5,0,0,0,0,0,0,60,41,0,0,0,0,0,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,135,3,0,184,186,3,0,0,0,0,0,0,0,0,0,104,174,7,0,200,112,3,0,0,0,0,0,144,84,8,0,216,142,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,11,0,0,8,0,0,0,0,0,0,0,0,0,30,13,0,0,108,34,0,0,0,0,0,0,0,0,0,0,236,45,0,0,176,59,0,0,252,10,0,0,24,8,0,0,14,5,0,0,0,0,0,0,60,41,0,0,0,0,0,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,186,3,0,0,0,0,0,0,0,0,0,0,0,0,0,104,174,7,0,80,161,3,0,0,0,0,0,168,183,7,0,216,142,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,11,0,0,8,0,0,0,0,0,0,0,0,0,132,50,0,0,130,15,0,0,0,0,0,0,0,0,0,0,236,45,0,0,232,27,0,0,252,10,0,0,24,8,0,0,14,5,0,0,0,0,0,0,60,41,0,0,0,0,0,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,207,2,0,128,86,3,0,0,0,0,0,0,0,0,0,160,234,7,0,192,67,2,0,0,0,0,0,40,161,4,0,48,156,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,130,1,7,2,0,0,4,0,0,0,0,0,0,0,0,0,166,62,0,0,84,18,0,0,0,0,0,0,0,0,0,0,234,24,0,0,130,7,0,0,250,7,0,0,114,17,0,0,102,17,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,86,3,0,0,0,0,0,0,0,0,0,0,0,0,0,160,234,7,0,88,25,6,0,0,0,0,0,40,161,4,0,48,156,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,130,0,7,2,0,0,4,0,0,0,0,0,0,0,0,0,56,10,0,0,50,13,0,0,0,0,0,0,0,0,0,0,234,24,0,0,130,7,0,0,190,7,0,0,114,17,0,0,208,6,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,208,1,0,128,86,3,0,0,0,0,0,0,0,0,0,160,234,7,0,88,110,1,0,0,0,0,0,192,154,4,0,48,156,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,128,1,7,2,0,0,4,0,0,0,0,0,0,0,0,0,58,24,0,0,148,35,0,0,0,0,0,0,0,0,0,0,234,24,0,0,130,7,0,0,24,13,0,0,114,17,0,0,102,17,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,217,1,0,0,0,0,0,72,172,6,0,0,0,0,0,144,47,2,0,144,203,1,0,0,0,0,0,240,192,1,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,4,0,0,0,0,0,0,0,0,0,0,0,122,33,0,0,232,24,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,149,3,0,24,156,3,0,0,0,0,0,0,0,0,0,216,194,1,0,48,147,3,0,0,0,0,0,176,143,3,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,8,0,0,2,0,0,0,0,0,0,16,1,0,0,0,0,0,0,0,0,0,0,0,36,58,0,0,210,26,0,0,0,0,0,0,0,0,0,0,124,45,0,0,126,52,0,0,164,10,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,96,83,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,128,28,4,0,0,0,0,0,32,0,1,0,0,227,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,2,0,0,0,0,0,1,21,0,0,1,0,0,0,0,0,0,0,0,0,244,18,0,0,218,16,0,0,0,0,0,0,0,0,0,0,176,23,0,0,172,28,0,0,198,8,0,0,248,19,0,0,72,13,0,0,56,10,0,0,96,10,0,0,224,174,145,0,0,6,0,0,224,0,0,0,128,1,0,0,3,0,0,0,4,0,0,0,24,31,8,0,0,0,0,0,0,0,0,0,0,0,0,0,232,233,7,0,112,182,7,0,72,150,4,0,48,135,7,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,152,43,0,0,216,16,0,0,0,0,0,0,0,0,0,0,36,31,0,0,0,0,0,0,200,16,0,0,128,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,6,4,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,16,55,6,0,0,0,0,0,72,212,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,16,0,0,0,0,0,0,0,0,0,0,244,45,0,0,112,35,0,0,0,0,0,0,0,0,0,0,38,10,0,0,162,35,0,0,74,11,0,0,192,17,0,0,68,5,0,0,110,13,0,0,94,60,0,0,176,174,145,0,0,4,0,0,128,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,232,0,5,0,216,233,5,0,0,0,0,0,0,0,0,0,104,221,5,0,144,219,4,0,0,0,0,0,176,237,2,0,168,84,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,19,4,0,0,0,0,0,0,0,0,0,0,0,102,54,0,0,126,17,0,0,0,0,0,0,0,0,0,0,122,30,0,0,46,17,0,0,60,10,0,0,192,10,0,0,42,10,0,0,190,1,0,0,112,12,0,0,0,173,145,0,0,8,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,24,123,5,0,216,233,5,0,0,0,0,0,0,0,0,0,104,221,5,0,16,93,5,0,0,0,0,0,176,237,2,0,168,84,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,19,4,0,0,0,0,0,0,0,0,0,0,0,132,25,0,0,134,36,0,0,0,0,0,0,0,0,0,0,122,30,0,0,46,17,0,0,60,10,0,0,192,10,0,0,42,10,0,0,190,1,0,0,112,12,0,0,0,173,145,0,0,8,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,72,63,5,0,216,233,5,0,0,0,0,0,0,0,0,0,104,221,5,0,40,31,5,0,0,0,0,0,176,237,2,0,168,84,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,19,4,0,0,0,0,0,0,0,0,0,0,0,100,53,0,0,46,16,0,0,0,0,0,0,0,0,0,0,122,30,0,0,46,17,0,0,60,10,0,0,192,10,0,0,42,10,0,0,190,1,0,0,112,12,0,0,0,173,145,0,0,8,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,216,233,5,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,0,154,5,0,0,0,0,0,176,237,2,0,168,84,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,19,4,0,0,0,0,0,0,0,0,0,0,0,36,51,0,0,4,18,0,0,0,0,0,0,0,0,0,0,122,30,0,0,222,38,0,0,60,10,0,0,192,10,0,0,42,10,0,0,190,1,0,0,112,12,0,0,0,173,145,0,0,8,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,72,9,5,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,208,193,4,0,0,0,0,0,40,52,7,0,128,194,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,3,11,2,0,0,0,0,0,0,0,0,0,0,0,142,18,0,0,94,13,0,0,0,0,0,0,0,0,0,0,90,22,0,0,134,22,0,0,114,8,0,0,224,17,0,0,188,8,0,0,2,1,0,0,74,29,0,0,0,0,0,0,0,16,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,8,134,6,0,32,18,7,0,0,0,0,0,0,0,0,0,96,159,4,0,0,129,6,0,0,0,0,0,48,124,6,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,8,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,58,9,0,0,208,10,0,0,0,0,0,0,0,0,0,0,70,34,0,0,240,28,0,0,246,14,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,128,142,6,0,32,18,7,0,0,0,0,0,0,0,0,0,96,159,4,0,144,138,6,0,0,0,0,0,24,202,3,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,8,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,14,10,0,0,136,36,0,0,0,0,0,0,0,0,0,0,70,34,0,0,156,44,0,0,246,14,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,136,153,6,0,32,18,7,0,0,0,0,0,0,0,0,0,96,159,4,0,80,150,6,0,0,0,0,0,24,202,3,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,8,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,144,34,0,0,28,41,0,0,0,0,0,0,0,0,0,0,70,34,0,0,240,28,0,0,246,14,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,24,48,1,0,104,92,5,0,0,0,0,0,0,0,0,0,184,168,7,0,232,235,8,0,0,0,0,0,136,95,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,210,2,0,0,8,33,0,0,0,0,0,0,0,0,0,0,182,48,0,0,162,15,0,0,32,6,0,0,60,19,0,0,194,11,0,0,44,17,0,0,0,0,0,0,232,175,145,0,0,8,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,233,1,0,104,92,5,0,0,0,0,0,0,0,0,0,184,168,7,0,8,136,1,0,0,0,0,0,80,197,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,184,50,0,0,36,44,0,0,0,0,0,0,0,0,0,0,182,48,0,0,162,15,0,0,32,6,0,0,60,19,0,0,194,11,0,0,44,17,0,0,0,0,0,0,232,175,145,0,0,8,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,249,2,0,104,92,5,0,0,0,0,0,0,0,0,0,184,168,7,0,128,94,2,0,0,0,0,0,80,197,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,176,30,0,0,52,9,0,0,0,0,0,0,0,0,0,0,182,48,0,0,162,15,0,0,32,6,0,0,60,19,0,0,194,11,0,0,44,17,0,0,0,0,0,0,232,175,145,0,0,8,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,92,5,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,88,109,6,0,0,0,0,0,80,197,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,194,4,0,0,130,18,0,0,0,0,0,0,0,0,0,0,182,48,0,0,162,15,0,0,32,6,0,0,60,19,0,0,194,11,0,0,44,17,0,0,0,0,0,0,232,175,145,0,0,8,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,36,3,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,24,119,2,0,0,0,0,0,96,0,2,0,152,8,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,4,0,0,0,0,0,4,17,0,0,1,0,0,0,0,0,0,0,0,0,48,20,0,0,82,46,0,0,0,0,0,0,0,0,0,0,52,51,0,0,202,49,0,0,6,6,0,0,80,0,0,0,228,1,0,0,44,8,0,0,0,0,0,0,32,177,145,0,0,2,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,32,242,6,0,0,0,0,0,200,240,5,0,0,0,0,0,104,129,6,0,168,239,6,0,144,236,6,0,208,6,2,0,88,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,4,0,0,0,1,0,0,8,0,16,0,0,0,0,0,0,0,0,0,0,212,61,0,0,198,36,0,0,0,0,0,0,0,0,0,0,104,35,0,0,232,12,0,0,48,15,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,192,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,182,1,0,0,0,0,0,0,0,0,0,0,0,0,0,160,234,7,0,32,169,1,0,0,0,0,0,40,161,4,0,80,150,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,4,0,0,0,5,0,4,2,0,64,0,0,0,0,0,0,0,0,0,0,100,38,0,0,196,7,0,0,0,0,0,0,0,0,0,0,30,53,0,0,204,8,0,0,18,9,0,0,24,0,0,0,134,11,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,129,6,0,168,216,6,0,0,0,0,0,0,0,0,0,160,234,7,0,144,80,6,0,0,0,0,0,40,161,4,0,248,206,2,0,176,37,6,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,2,8,0,0,0,0,0,0,0,0,0,0,0,64,8,0,0,50,31,0,0,0,0,0,0,0,0,0,0,50,61,0,0,120,9,0,0,252,2,0,0,114,17,0,0,144,2,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,1,2,0,120,37,2,0,0,0,0,0,0,0,0,0,0,38,7,0,72,243,1,0,240,56,5,0,152,54,6,0,168,38,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,5,17,0,128,0,0,0,0,0,0,0,0,0,0,192,11,0,0,46,1,0,0,0,0,0,0,0,0,0,0,50,9,0,0,82,39,0,0,86,3,0,0,218,2,0,0,114,1,0,0,166,3,0,0,116,50,0,0,8,211,148,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,120,37,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,120,27,2,0,240,56,5,0,56,17,2,0,104,8,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,5,17,0,128,0,0,0,0,0,0,0,0,0,0,34,46,0,0,150,18,0,0,0,0,0,0,0,0,0,0,50,9,0,0,0,0,0,0,182,3,0,0,218,2,0,0,114,1,0,0,166,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,4,0,0,0,3,0,0,0,72,243,5,0,240,75,6,0,0,0,0,0,0,0,0,0,200,190,7,0,56,203,5,0,0,0,0,0,128,161,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,3,11,0,0,1,0,0,0,0,0,0,0,0,0,168,47,0,0,18,16,0,0,0,0,0,0,0,0,0,0,68,17,0,0,112,32,0,0,174,7,0,0,82,3,0,0,246,2,0,0,152,1,0,0,92,6,0,0,144,173,145,0,0,2,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,32,129,5,0,240,75,6,0,0,0,0,0,0,0,0,0,200,190,7,0,48,100,5,0,0,0,0,0,144,84,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,3,11,0,0,1,0,0,0,0,0,0,0,0,0,16,33,0,0,54,18,0,0,0,0,0,0,0,0,0,0,68,17,0,0,112,32,0,0,174,7,0,0,82,3,0,0,246,2,0,0,152,1,0,0,92,6,0,0,144,173,145,0,0,2,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,240,75,6,0,0,0,0,0,0,0,0,0,0,0,0,0,200,190,7,0,72,34,6,0,0,0,0,0,168,183,7,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,2,0,0,0,0,0,3,11,0,0,1,0,0,0,0,0,0,0,0,0,208,23,0,0,148,21,0,0,0,0,0,0,0,0,0,0,68,17,0,0,232,31,0,0,174,7,0,0,82,3,0,0,246,2,0,0,152,1,0,0,92,6,0,0,144,173,145,0,0,2,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,24,21,4,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,128,56,6,0,0,0,0,0,160,213,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,16,0,0,0,0,0,0,0,0,0,0,178,11,0,0,244,17,0,0,0,0,0,0,0,0,0,0,230,52,0,0,86,57,0,0,46,13,0,0,140,8,0,0,74,7,0,0,204,19,0,0,40,44,0,0,192,174,145,0,0,4,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,8,229,1,0,96,6,2,0,0,0,0,0,0,0,0,0,232,233,7,0,216,214,1,0,120,155,4,0,40,98,7,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,214,19,0,0,14,12,0,0,0,0,0,0,0,0,0,0,46,36,0,0,178,36,0,0,110,19,0,0,198,18,0,0,98,13,0,0,38,13,0,0,0,0,0,0,136,175,145,0,0,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,192,185,2,0,32,127,4,0,0,0,0,0,0,0,0,0,64,171,7,0,32,184,2,0,0,0,0,0,144,182,2,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,8,0,0,2,0,0,0,0,0,0,16,0,0,4,0,0,0,0,0,0,0,0,0,82,40,0,0,42,38,0,0,0,0,0,0,0,0,0,0,200,19,0,0,228,12,0,0,236,16,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,32,127,4,0,0,0,0,0,0,0,0,0,0,0,0,0,232,233,7,0,120,69,6,0,0,0,0,0,168,224,4,0,72,183,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,1,0,0,0,0,0,0,15,0,0,4,0,0,0,0,0,0,0,0,0,94,53,0,0,126,46,0,0,0,0,0,0,0,0,0,0,68,5,0,0,74,55,0,0,52,12,0,0,56,4,0,0,44,2,0,0,96,15,0,0,104,26,0,0,24,175,145,0,128,0,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,16,192,2,0,32,127,4,0,0,0,0,0,0,0,0,0,232,233,7,0,160,189,2,0,0,0,0,0,184,186,2,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,8,0,0,2,0,0,0,0,0,0,16,0,0,4,0,0,0,0,0,0,0,0,0,130,42,0,0,64,20,0,0,0,0,0,0,0,0,0,0,200,19,0,0,228,12,0,0,232,0,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,56,181,2,0,32,127,4,0,0,0,0,0,0,0,0,0,64,171,7,0,232,179,2,0,0,0,0,0,184,177,2,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,8,0,0,2,0,0,0,0,0,0,16,0,0,4,0,0,0,0,0,0,0,0,0,16,59,0,0,222,19,0,0,0,0,0,0,0,0,0,0,200,19,0,0,228,12,0,0,236,16,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,112,103,4,0,8,69,5,0,0,0,0,0,0,0,0,0,144,47,2,0,176,76,4,0,0,0,0,0,192,154,4,0,208,135,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,53,0,0,0,2,0,0,0,0,0,2,11,0,0,4,0,0,0,0,0,0,0,0,0,232,59,0,0,100,2,0,0,0,0,0,0,0,0,0,0,24,55,0,0,100,20,0,0,182,15,0,0,46,7,0,0,76,9,0,0,0,0,0,0,176,18,0,0,0,0,0,0,0,32,0,0,224,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,160,192,4,0,8,69,5,0,0,0,0,0,0,0,0,0,144,47,2,0,136,160,4,0,0,0,0,0,48,130,4,0,208,135,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,2,11,0,0,4,0,0,0,0,0,0,0,0,0,90,50,0,0,136,1,0,0,0,0,0,0,0,0,0,0,24,55,0,0,100,20,0,0,112,0,0,0,46,7,0,0,246,17,0,0,0,0,0,0,176,18,0,0,0,0,0,0,0,32,0,0,224,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,8,69,5,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,32,8,5,0,0,0,0,0,136,228,4,0,208,135,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,2,11,0,0,4,0,0,0,0,0,0,0,0,0,108,55,0,0,200,6,0,0,0,0,0,0,0,0,0,0,24,55,0,0,100,20,0,0,112,0,0,0,46,7,0,0,246,17,0,0,0,0,0,0,176,18,0,0,0,0,0,0,0,32,0,0,224,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,248,120,6,0,200,82,8,0,200,240,5,0,0,0,0,0,184,12,8,0,192,19,5,0,0,0,0,0,72,174,3,0,88,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,0,8,0,16,0,0,0,0,0,0,0,0,0,0,240,59,0,0,200,10,0,0,0,0,0,0,0,0,0,0,104,35,0,0,232,12,0,0,182,16,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,192,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,211,3,0,200,82,8,0,200,240,5,0,0,0,0,0,184,12,8,0,152,112,5,0,0,0,0,0,72,174,3,0,88,0,3,0,160,80,5,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,0,8,0,16,0,0,0,0,0,0,0,0,0,0,232,21,0,0,152,28,0,0,0,0,0,0,0,0,0,0,104,35,0,0,232,12,0,0,152,0,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,192,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,5,5,0,200,82,8,0,200,240,5,0,0,0,0,0,184,12,8,0,168,216,5,0,0,0,0,0,72,174,3,0,88,0,3,0,104,178,5,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,0,8,0,16,0,0,0,0,0,0,0,0,0,0,94,11,0,0,28,1,0,0,0,0,0,0,0,0,0,0,104,35,0,0,232,12,0,0,200,18,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,192,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,82,8,0,0,0,0,0,200,240,5,0,0,0,0,0,184,12,8,0,168,48,6,0,0,0,0,0,72,174,3,0,88,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,4,0,0,0,0,0,0,8,0,16,0,0,0,0,0,0,0,0,0,0,116,57,0,0,158,18,0,0,0,0,0,0,0,0,0,0,104,35,0,0,232,12,0,0,22,14,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,192,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,248,7,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,136,147,7,0,0,0,0,0,0,227,2,0,0,227,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,21,0,0,1,0,0,0,0,0,0,0,0,0,12,41,0,0,234,14,0,0,0,0,0,0,0,0,0,0,40,19,0,0,210,9,0,0,44,0,0,0,248,19,0,0,72,13,0,0,230,0,0,0,96,10,0,0,224,174,145,0,0,2,0,0,128,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,160,152,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,0,37,6,0,0,0,0,0,0,192,4,0,112,163,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,0,1,0,0,0,0,0,0,0,0,0,226,3,0,0,142,30,0,0,0,0,0,0,0,0,0,0,82,52,0,0,242,4,0,0,80,8,0,0,180,10,0,0,94,11,0,0,48,7,0,0,0,5,0,0,64,174,145,0,0,32,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,149,8,0,232,199,2,0,0,0,0,0,0,0,0,0,104,174,7,0,56,87,8,0,0,0,0,0,192,154,4,0,248,135,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,0,19,4,0,0,0,0,0,0,0,0,0,0,0,134,10,0,0,142,19,0,0,0,0,0,0,0,0,0,0,72,1,0,0,104,15,0,0,62,1,0,0,212,0,0,0,140,12,0,0,0,0,0,0,24,26,0,0,0,0,0,0,0,4,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,112,101,1,0,232,199,2,0,0,0,0,0,0,0,0,0,104,174,7,0,144,23,1,0,0,0,0,0,192,154,4,0,248,135,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,0,19,4,0,0,0,0,0,0,0,0,0,0,0,234,23,0,0,202,37,0,0,0,0,0,0,0,0,0,0,72,1,0,0,104,15,0,0,18,8,0,0,212,0,0,0,140,12,0,0,0,0,0,0,24,26,0,0,0,0,0,0,0,4,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,64,193,2,0,232,199,2,0,0,0,0,0,0,0,0,0,104,174,7,0,0,57,2,0,0,0,0,0,176,237,2,0,248,135,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,19,4,0,0,0,0,0,0,0,0,0,0,0,236,35,0,0,200,14,0,0,0,0,0,0,0,0,0,0,72,1,0,0,104,15,0,0,18,8,0,0,212,0,0,0,140,12,0,0,0,0,0,0,24,26,0,0,0,0,0,0,0,4,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,0,109,8,0,0,0,0,0,0,0,0,0,0,0,0,0,232,233,7,0,48,0,8,0,184,202,7,0,248,39,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0])
.concat([2,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,194,61,0,0,246,20,0,0,0,0,0,0,0,0,0,0,92,5,0,0,112,61,0,0,0,9,0,0,218,10,0,0,28,3,0,0,34,8,0,0,66,32,0,0,8,176,145,0,0,5,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,105,5,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,224,42,5,0,0,0,0,0,200,56,2,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,4,0,0,0,0,0,0,0,0,0,0,0,168,16,0,0,150,40,0,0,0,0,0,0,0,0,0,0,222,45,0,0,236,18,0,0,158,2,0,0,14,3,0,0,164,11,0,0,242,10,0,0,242,13,0,0,104,174,145,0,0,16,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,6,2,0,0,0,0,0,0,0,0,0,0,0,0,0,232,233,7,0,200,250,1,0,120,155,4,0,40,98,7,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,2,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,216,42,0,0,228,2,0,0,0,0,0,0,0,0,0,0,46,36,0,0,178,36,0,0,184,15,0,0,198,18,0,0,98,13,0,0,38,13,0,0,0,0,0,0,136,175,145,0,0,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,32,53,6,0,0,0,0,0,0,0,0,0,0,0,0,0,184,230,7,0,120,134,6,0,0,0,0,0,232,163,8,0,152,88,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,0,13,2,0,0,0,0,0,0,0,0,0,0,0,186,50,0,0,88,47,0,0,0,0,0,0,0,0,0,0,56,14,0,0,208,41,0,0,98,14,0,0,160,16,0,0,104,12,0,0,54,1,0,0,166,39,0,0,0,0,0,0,0,20,0,0,224,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,200,239,2,0,0,0,0,0,0,0,0,0,0,0,0,0,192,177,6,0,136,196,2,0,0,0,0,0,224,218,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,32,0,0,0,0,0,0,0,0,0,0,38,42,0,0,66,24,0,0,0,0,0,0,0,0,0,0,14,12,0,0,58,43,0,0,32,14,0,0,56,15,0,0,12,17,0,0,0,0,0,0,224,13,0,0,0,0,0,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,152,88,8,0,8,124,8,0,0,0,0,0,0,0,0,0,184,168,7,0,152,82,8,0,208,111,8,0,0,227,2,0,0,227,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,1,21,0,0,1,0,0,0,0,0,0,0,0,0,160,47,0,0,220,41,0,0,0,0,0,0,0,0,0,0,110,33,0,0,2,11,0,0,140,7,0,0,248,19,0,0,72,13,0,0,230,0,0,0,96,10,0,0,224,174,145,0,0,2,0,0,224,0,0,0,128,1,0,0,3,0,0,0,4,0,0,0,8,124,8,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,40,118,8,0,208,111,8,0,0,227,2,0,0,227,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,2,0,0,0,0,0,1,21,0,0,1,0,0,0,0,0,0,0,0,0,234,0,0,0,194,28,0,0,0,0,0,0,0,0,0,0,110,33,0,0,2,11,0,0,140,7,0,0,248,19,0,0,72,13,0,0,230,0,0,0,96,10,0,0,224,174,145,0,0,2,0,0,224,0,0,0,128,1,0,0,3,0,0,0,4,0,0,0,176,53,7,0,96,199,7,0,0,0,0,0,0,0,0,0,232,167,7,0,40,10,7,0,0,0,0,0,88,19,1,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,64,20,0,0,8,12,0,0,0,0,0,0,0,0,0,0,92,56,0,0,156,42,0,0,22,11,0,0,218,16,0,0,166,13,0,0,164,1,0,0,68,57,0,0,128,175,145,0,96,0,0,0,196,0,0,0,240,0,0,0,3,0,0,0,4,0,0,0,96,199,7,0,0,0,0,0,0,0,0,0,0,0,0,0,232,167,7,0,184,150,7,0,0,0,0,0,88,19,1,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,158,20,0,0,232,2,0,0,0,0,0,0,0,0,0,0,92,56,0,0,156,42,0,0,22,11,0,0,218,16,0,0,166,13,0,0,164,1,0,0,68,57,0,0,128,175,145,0,96,0,0,0,196,0,0,0,240,0,0,0,3,0,0,0,4,0,0,0,224,39,1,0,24,71,4,0,0,0,0,0,0,0,0,0,32,127,5,0,240,228,8,0,0,0,0,0,24,186,4,0,136,153,3,0,96,162,8,0,0,0,0,0,0,0,0,0,0,0,0,0,149,0,0,0,2,0,0,0,2,0,0,6,2,0,0,0,0,0,0,0,0,0,0,0,200,16,0,0,124,26,0,0,0,0,0,0,0,0,0,0,128,8,0,0,0,0,0,0,186,19,0,0,84,5,0,0,128,12,0,0,254,5,0,0,142,34,0,0,96,49,216,0,0,128,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,240,78,2,0,24,71,4,0,0,0,0,0,0,0,0,0,32,127,5,0,152,220,1,0,0,0,0,0,24,186,4,0,136,153,3,0,208,122,1,0,0,0,0,0,0,0,0,0,0,0,0,0,149,0,0,0,2,0,0,0,2,0,0,6,2,0,0,0,0,0,0,0,0,0,0,0,74,53,0,0,170,6,0,0,0,0,0,0,0,0,0,0,128,8,0,0,0,0,0,0,186,19,0,0,84,5,0,0,128,12,0,0,254,5,0,0,142,34,0,0,96,49,216,0,0,128,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,56,100,8,0,24,71,4,0,0,0,0,0,0,0,0,0,32,127,5,0,16,44,8,0,0,0,0,0,24,186,4,0,136,153,3,0,40,248,7,0,0,0,0,0,0,0,0,0,0,0,0,0,149,0,0,0,2,0,0,0,2,0,0,6,2,0,0,0,0,0,0,0,0,0,0,0,72,32,0,0,48,47,0,0,0,0,0,0,0,0,0,0,128,8,0,0,0,0,0,0,186,19,0,0,84,5,0,0,128,12,0,0,254,5,0,0,142,34,0,0,96,49,216,0,0,128,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,24,71,4,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,112,61,6,0,0,0,0,0,24,186,4,0,136,153,3,0,120,227,2,0,0,0,0,0,0,0,0,0,0,0,0,0,133,0,0,0,2,0,0,0,2,0,0,6,2,0,0,0,0,0,0,0,0,0,0,0,96,56,0,0,182,23,0,0,0,0,0,0,0,0,0,0,128,8,0,0,0,0,0,0,186,19,0,0,84,5,0,0,128,12,0,0,254,5,0,0,142,34,0,0,96,49,216,0,0,128,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,200,128,5,0,240,33,6,0,0,0,0,0,0,0,0,0,184,168,7,0,208,99,5,0,0,0,0,0,144,84,8,0,208,135,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,2,11,0,8,0,0,0,0,0,0,0,0,0,0,248,13,0,0,90,18,0,0,0,0,0,0,0,0,0,0,86,9,0,0,196,2,0,0,108,8,0,0,46,7,0,0,246,17,0,0,0,0,0,0,176,18,0,0,0,0,0,0,0,32,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,203,5,0,240,33,6,0,0,0,0,0,0,0,0,0,184,168,7,0,184,161,5,0,0,0,0,0,144,84,8,0,208,135,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,2,11,0,8,0,0,0,0,0,0,0,0,0,0,248,4,0,0,132,7,0,0,0,0,0,0,0,0,0,0,86,9,0,0,72,14,0,0,108,8,0,0,46,7,0,0,246,17,0,0,0,0,0,0,176,18,0,0,0,0,0,0,0,32,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,33,6,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,0,243,5,0,0,0,0,0,168,183,7,0,208,135,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,2,11,0,8,0,0,0,0,0,0,0,0,0,0,230,5,0,0,58,17,0,0,0,0,0,0,0,0,0,0,86,9,0,0,246,22,0,0,108,8,0,0,46,7,0,0,246,17,0,0,0,0,0,0,176,18,0,0,0,0,0,0,0,32,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,9,7,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,168,222,6,0,0,0,0,0,240,177,6,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,160,61,0,0,62,0,0,0,0,0,0,0,0,0,0,0,74,46,0,0,0,0,0,0,232,11,0,0,22,7,0,0,230,18,0,0,0,0,0,0,110,45,0,0,0,0,0,0,0,8,0,0,128,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,232,212,8,0,144,175,7,0,0,0,0,0,0,0,0,0,96,135,2,0,128,148,8,0,0,0,0,0,160,150,4,0,240,129,3,0,88,85,8,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,2,4,2,0,0,0,0,0,0,0,0,0,0,0,114,2,0,0,152,45,0,0,0,0,0,0,0,0,0,0,70,0,0,0,32,1,0,0,118,6,0,0,126,9,0,0,124,13,0,0,172,2,0,0,148,34,0,0,32,146,215,0,0,8,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,40,196,1,0,144,175,7,0,0,0,0,0,0,0,0,0,96,135,2,0,16,99,1,0,0,0,0,0,160,150,4,0,240,129,3,0,192,20,1,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,2,4,2,0,0,0,0,0,0,0,0,0,0,0,162,61,0,0,182,18,0,0,0,0,0,0,0,0,0,0,70,0,0,0,242,18,0,0,118,6,0,0,126,9,0,0,124,13,0,0,172,2,0,0,148,34,0,0,32,146,215,0,0,8,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,144,175,7,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,120,154,4,0,0,0,0,0,160,150,4,0,240,129,3,0,80,52,2,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,2,4,2,0,0,0,0,0,0,0,0,0,0,0,90,23,0,0,40,25,0,0,0,0,0,0,0,0,0,0,70,0,0,0,228,59,0,0,118,6,0,0,126,9,0,0,124,13,0,0,172,2,0,0,148,34,0,0,32,146,215,0,0,8,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,192,211,8,0,0,0,0,0,0,0,0,0,0,0,0,0,232,167,7,0,200,147,8,0,72,150,4,0,144,84,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,182,28,0,0,116,36,0,0,0,0,0,0,0,0,0,0,36,31,0,0,0,0,0,0,200,16,0,0,128,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,88,40,1,0,168,97,4,0,0,0,0,0,0,0,0,0,184,12,8,0,136,229,8,0,0,0,0,0,8,190,5,0,136,153,3,0,160,100,8,0,0,0,0,0,0,0,0,0,0,0,0,0,149,1,0,0,2,0,0,0,0,0,0,6,2,0,0,0,0,0,0,0,0,0,0,0,150,0,0,0,240,47,0,0,0,0,0,0,0,0,0,0,202,57,0,0,0,0,0,0,132,10,0,0,50,9,0,0,244,11,0,0,142,15,0,0,10,57,0,0,96,49,216,0,0,128,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,128,79,2,0,168,97,4,0,0,0,0,0,0,0,0,0,184,12,8,0,136,221,1,0,0,0,0,0,24,186,4,0,136,153,3,0,24,124,1,0,0,0,0,0,0,0,0,0,0,0,0,0,149,0,0,0,2,0,0,0,0,0,0,6,2,0,0,0,0,0,0,0,0,0,0,0,154,58,0,0,140,43,0,0,0,0,0,0,0,0,0,0,202,57,0,0,0,0,0,0,132,10,0,0,50,9,0,0,244,11,0,0,142,15,0,0,10,57,0,0,96,49,216,0,0,128,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,168,97,4,0,0,0,0,0,0,0,0,0,0,0,0,0,184,12,8,0,144,64,6,0,0,0,0,0,24,186,4,0,136,153,3,0,160,229,2,0,0,0,0,0,0,0,0,0,0,0,0,0,133,0,0,0,2,0,0,0,0,0,0,6,2,0,0,0,0,0,0,0,0,0,0,0,188,21,0,0,38,10,0,0,0,0,0,0,0,0,0,0,202,57,0,0,0,0,0,0,132,10,0,0,50,9,0,0,244,11,0,0,142,15,0,0,10,57,0,0,96,49,216,0,0,128,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,144,205,5,0,0,0,0,0,200,240,5,0,0,0,0,0,56,172,6,0,112,214,6,0,0,0,0,0,72,174,3,0,88,0,3,0,0,209,6,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,4,0,0,0,1,0,0,8,0,8,0,0,0,0,0,0,0,0,0,0,248,44,0,0,88,17,0,0,0,0,0,0,0,0,0,0,104,35,0,0,82,38,0,0,104,6,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,192,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,77,6,0,56,12,3,0,0,0,0,0,0,0,0,0,200,190,7,0,96,246,5,0,0,0,0,0,192,154,4,0,128,194,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,3,11,0,8,0,0,0,0,0,0,0,0,0,0,34,7,0,0,222,11,0,0,0,0,0,0,0,0,0,0,120,36,0,0,230,13,0,0,204,1,0,0,148,18,0,0,100,14,0,0,0,0,0,0,120,21,0,0,0,0,0,0,0,1,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,173,5,0,240,130,1,0,0,0,0,0,240,130,1,0,160,217,6,0,80,137,5,0,0,0,0,0,144,88,7,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,116,13,0,0,234,21,0,0,248,38,0,0,2,23,0,0,46,36,0,0,0,0,0,0,66,13,0,0,198,18,0,0,98,13,0,0,38,13,0,0,0,0,0,0,136,175,145,0,0,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,144,44,6,0,240,130,1,0,0,0,0,0,240,130,1,0,160,217,6,0,112,212,5,0,0,0,0,0,144,88,7,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,174,31,0,0,122,33,0,0,248,38,0,0,2,23,0,0,46,36,0,0,0,0,0,0,66,13,0,0,198,18,0,0,98,13,0,0,38,13,0,0,0,0,0,0,136,175,145,0,0,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,104,105,8,0,240,130,1,0,0,0,0,0,240,130,1,0,216,194,1,0,0,49,8,0,0,0,0,0,24,177,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,112,55,0,0,86,9,0,0,248,38,0,0,2,23,0,0,46,36,0,0,104,16,0,0,224,1,0,0,198,18,0,0,98,13,0,0,38,13,0,0,0,0,0,0,136,175,145,0,0,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,24,152,5,0,16,110,5,0,0,0,0,0,0,0,0,0,232,167,7,0,120,146,5,0,160,173,1,0,192,154,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,8,0,0,2,0,0,0,0,0,0,16,0,8,0,0,0,0,0,0,0,0,0,0,68,12,0,0,10,20,0,0,0,0,0,0,0,0,0,0,226,29,0,0,236,19,0,0,60,1,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,248,16,5,0,16,110,5,0,0,0,0,0,16,110,5,0,232,167,7,0,120,238,4,0,0,0,0,0,24,177,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,182,8,0,0,120,46,0,0,64,47,0,0,136,24,0,0,46,36,0,0,104,16,0,0,174,14,0,0,198,18,0,0,98,13,0,0,38,13,0,0,0,0,0,0,136,175,145,0,0,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,112,139,4,0,16,110,5,0,0,0,0,0,16,110,5,0,232,167,7,0,128,110,4,0,0,0,0,0,192,154,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,218,37,0,0,172,42,0,0,64,47,0,0,136,24,0,0,46,36,0,0,104,16,0,0,174,14,0,0,198,18,0,0,98,13,0,0,38,13,0,0,0,0,0,0,136,175,145,0,0,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,16,110,5,0,0,0,0,0,0,0,0,0,16,110,5,0,232,167,7,0,216,46,5,0,0,0,0,0,224,226,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,2,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,2,36,0,0,46,8,0,0,64,47,0,0,136,24,0,0,46,36,0,0,104,16,0,0,174,14,0,0,198,18,0,0,98,13,0,0,38,13,0,0,0,0,0,0,136,175,145,0,0,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,248,53,7,0,240,130,1,0,0,0,0,0,240,130,1,0,216,194,1,0,120,10,7,0,0,0,0,0,24,177,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,20,24,0,0,134,34,0,0,248,38,0,0,2,23,0,0,46,36,0,0,104,16,0,0,224,1,0,0,198,18,0,0,98,13,0,0,38,13,0,0,0,0,0,0,136,175,145,0,0,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,240,150,7,0,240,130,1,0,0,0,0,0,240,130,1,0,216,194,1,0,144,104,7,0,0,0,0,0,24,177,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,198,27,0,0,126,27,0,0,248,38,0,0,2,23,0,0,46,36,0,0,104,16,0,0,224,1,0,0,198,18,0,0,98,13,0,0,38,13,0,0,0,0,0,0,136,175,145,0,0,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,144,203,4,0,16,110,5,0,0,0,0,0,16,110,5,0,232,167,7,0,152,170,4,0,0,0,0,0,24,177,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,20,30,0,0,92,31,0,0,64,47,0,0,136,24,0,0,46,36,0,0,104,16,0,0,174,14,0,0,198,18,0,0,98,13,0,0,38,13,0,0,0,0,0,0,136,175,145,0,0,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,120,252,7,0,240,130,1,0,0,0,0,0,240,130,1,0,216,194,1,0,104,199,7,0,0,0,0,0,24,177,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,42,38,0,0,108,25,0,0,248,38,0,0,2,23,0,0,46,36,0,0,104,16,0,0,224,1,0,0,198,18,0,0,98,13,0,0,38,13,0,0,0,0,0,0,136,175,145,0,0,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,80,224,6,0,240,130,1,0,0,0,0,0,240,130,1,0,0,180,6,0,128,136,6,0,0,0,0,0,144,88,7,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,8,25,0,0,2,14,0,0,248,38,0,0,2,23,0,0,46,36,0,0,52,30,0,0,224,1,0,0,198,18,0,0,98,13,0,0,38,13,0,0,0,0,0,0,136,175,145,0,0,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,64,31,3,0,72,66,3,0,0,0,0,0,0,0,0,0,64,164,6,0,104,7,3,0,120,155,4,0,24,177,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,102,7,0,0,50,30,0,0,0,0,0,0,0,0,0,0,102,16,0,0,174,21,0,0,126,15,0,0,198,18,0,0,98,13,0,0,38,13,0,0,0,0,0,0,136,175,145,0,0,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,16,242,2,0,72,66,3,0,0,0,0,0,0,0,0,0,232,233,7,0,8,198,2,0,0,0,0,0,192,154,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,0,0,0,2,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,232,42,0,0,78,12,0,0,0,0,0,0,0,0,0,0,46,36,0,0,200,5,0,0,212,6,0,0,198,18,0,0,98,13,0,0,38,13,0,0,0,0,0,0,136,175,145,0,0,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,72,66,3,0,0,0,0,0,0,0,0,0,0,0,0,0,64,164,6,0,224,50,3,0,120,155,4,0,224,226,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,2,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,176,48,0,0,34,22,0,0,0,0,0,0,0,0,0,0,102,16,0,0,174,21,0,0,126,15,0,0,198,18,0,0,98,13,0,0,38,13,0,0,0,0,0,0,136,175,145,0,0,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,240,130,1,0,0,0,0,0,0,0,0,0,240,130,1,0,216,194,1,0,184,233,8,0,0,0,0,0,224,226,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,2,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,160,23,0,0,216,12,0,0,248,38,0,0,2,23,0,0,46,36,0,0,104,16,0,0,224,1,0,0,198,18,0,0,98,13,0,0,38,13,0,0,0,0,0,0,136,175,145,0,0,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,0,2,4,0,16,110,5,0,0,0,0,0,16,110,5,0,232,167,7,0,216,224,3,0,0,0,0,0,192,154,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,94,7,0,0,160,12,0,0,64,47,0,0,136,24,0,0,46,36,0,0,104,16,0,0,216,19,0,0,198,18,0,0,98,13,0,0,38,13,0,0,0,0,0,0,136,175,145,0,0,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,96,202,2,0,136,84,3,0,0,0,0,0,0,0,0,0,104,221,5,0,176,183,2,0,0,0,0,0,152,54,6,0,200,12,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,17,4,8,0,0,0,0,0,0,0,0,0,0,186,1,0,0,56,16,0,0,0,0,0,0,0,0,0,0,198,62,0,0,64,12,0,0,252,8,0,0,230,1,0,0,44,6,0,0,194,15,0,0,0,0,0,0,48,177,145,0,0,2,0,0,128,1,0,0,0,1,0,0,4,0,0,0,3,0,0,0,64,247,2,0,136,84,3,0,0,0,0,0,0,0,0,0,104,221,5,0,208,223,2,0,0,0,0,0,152,54,6,0,232,200,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,17,4,8,0,0,0,0,0,0,0,0,0,0,62,59,0,0,170,44,0,0,0,0,0,0,0,0,0,0,198,62,0,0,64,12,0,0,242,11,0,0,230,1,0,0,44,6,0,0,194,15,0,0,0,0,0,0,48,177,145,0,0,2,0,0,128,1,0,0,0,1,0,0,4,0,0,0,3,0,0,0,112,87,3,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,8,26,6,0,0,0,0,0,88,186,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,0,1,0,0,0,0,0,0,0,0,0,140,47,0,0,70,20,0,0,0,0,0,0,0,0,0,0,82,1,0,0,14,61,0,0,6,18,0,0,2,8,0,0,16,12,0,0,120,11,0,0,30,34,0,0,200,173,145,0,0,4,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,88,125,6,0,240,40,7,0,0,0,0,0,0,0,0,0,96,135,2,0,160,75,6,0,0,0,0,0,128,161,4,0,208,135,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,2,11,8,0,0,0,0,0,0,0,0,0,0,0,60,54,0,0,32,9,0,0,0,0,0,0,0,0,0,0,98,38,0,0,142,8,0,0,32,15,0,0,46,7,0,0,246,17,0,0,0,0,0,0,176,18,0,0,0,0,0,0,0,32,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,212,6,0,240,40,7,0,0,0,0,0,0,0,0,0,96,135,2,0,8,166,6,0,0,0,0,0,144,84,8,0,208,135,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,2,11,8,0,0,0,0,0,0,0,0,0,0,0,108,38,0,0,112,32,0,0,0,0,0,0,0,0,0,0,98,38,0,0,44,0,0,0,32,15,0,0,46,7,0,0,246,17,0,0,0,0,0,0,176,18,0,0,0,0,0,0,0,32,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,40,7,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,112,252,6,0,0,0,0,0,168,183,7,0,208,135,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,2,11,8,0,0,0,0,0,0,0,0,0,0,0,166,37,0,0,38,21,0,0,0,0,0,0,0,0,0,0,98,38,0,0,142,8,0,0,32,15,0,0,46,7,0,0,246,17,0,0,0,0,0,0,176,18,0,0,0,0,0,0,0,32,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,27,5,0,0,0,0,0,0,0,0,0,0,0,0,0,64,164,6,0,208,24,5,0,0,0,0,0,176,21,5,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,2,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,0,0,0,0,130,21,0,0,186,4,0,0,0,0,0,0,0,0,0,0,28,3,0,0,12,45,0,0,214,7,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,56,160,2,0,232,175,7,0,0,0,0,0,0,0,0,0,96,135,2,0,224,154,4,0,0,0,0,0,176,237,2,0,168,84,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,19,0,8,0,0,0,0,0,0,0,0,0,0,22,44,0,0,0,40,0,0,0,0,0,0,0,0,0,0,44,48,0,0,54,8,0,0,246,16,0,0,160,4,0,0,178,9,0,0,202,19,0,0,78,3,0,0,120,173,145,0,0,3,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,192,21,1,0,232,175,7,0,0,0,0,0,0,0,0,0,96,135,2,0,248,212,8,0,0,0,0,0,176,237,2,0,168,84,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,19,0,8,0,0,0,0,0,0,0,0,0,0,80,3,0,0,148,43,0,0,0,0,0,0,0,0,0,0,44,48,0,0,54,8,0,0,246,16,0,0,160,4,0,0,178,9,0,0,202,19,0,0,78,3,0,0,120,173,145,0,0,3,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,208,52,2,0,232,175,7,0,0,0,0,0,0,0,0,0,96,135,2,0,56,196,1,0,0,0,0,0,176,237,2,0,168,84,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,19,0,8,0,0,0,0,0,0,0,0,0,0,112,5,0,0,138,23,0,0,0,0,0,0,0,0,0,0,44,48,0,0,54,8,0,0,246,16,0,0,160,4,0,0,178,9,0,0,202,19,0,0,78,3,0,0,120,173,145,0,0,3,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,232,175,7,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,64,99,1,0,0,0,0,0,176,237,2,0,168,84,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,19,0,8,0,0,0,0,0,0,0,0,0,0,52,15,0,0,118,19,0,0,0,0,0,0,0,0,0,0,44,48,0,0,54,8,0,0,246,16,0,0,160,4,0,0,178,9,0,0,202,19,0,0,78,3,0,0,120,173,145,0,0,3,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,128,177,5,0,0,0,0,0,0,0,0,0,0,0,0,0,64,171,7,0,192,139,5,0,0,0,0,0,16,112,5,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,20,0,8,0,0,0,0,0,0,0,0,0,0,34,24,0,0,140,1,0,0,0,0,0,0,0,0,0,0,132,28,0,0,96,42,0,0,100,5,0,0,140,9,0,0,82,7,0,0,0,0,0,0,118,31,0,0,0,0,0,0,0,1,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,114,7,0,152,116,8,0,0,0,0,0,0,0,0,0,104,174,7,0,192,63,7,0,0,0,0,0,168,95,8,0,176,6,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,3,0,0,8,0,0,0,0,0,0,0,0,0,126,38,0,0,56,39,0,0,0,0,0,0,0,0,0,0,46,52,0,0,200,32,0,0,106,17,0,0,14,19,0,0,14,10,0,0,172,8,0,0,148,27,0,0,96,176,145,0,0,1,0,0,224,0,0,0,48,1,0,0,3,0,0,0,4,0,0,0,208,209,7,0,152,116,8,0,0,0,0,0,0,0,0,0,104,174,7,0,248,158,7,0,0,0,0,0,168,95,8,0,176,6,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,3,0,0,8,0,0,0,0,0,0,0,0,0,78,6,0,0,230,35,0,0,0,0,0,0,0,0,0,0,46,52,0,0,116,18,0,0,106,17,0,0,14,19,0,0,14,10,0,0,172,8,0,0,148,27,0,0,96,176,145,0,0,1,0,0,224,0,0,0,48,1,0,0,3,0,0,0,4,0,0,0,152,116,8,0,0,0,0,0,0,0,0,0,0,0,0,0,104,174,7,0,0,59,8,0,0,0,0,0,168,95,8,0,176,6,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,2,0,0,0,0,0,0,3,0,0,8,0,0,0,0,0,0,0,0,0,4,52,0,0,188,10,0,0,0,0,0,0,0,0,0,0,46,52,0,0,200,32,0,0,106,17,0,0,14,19,0,0,14,10,0,0,172,8,0,0,148,27,0,0,96,176,145,0,0,1,0,0,224,0,0,0,48,1,0,0,3,0,0,0,4,0,0,0,168,54,8,0,0,0,0,0,0,0,0,0,0,0,0,0,200,190,7,0,40,180,6,0,0,0,0,0,168,95,8,0,8,2,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,3,0,0,8,0,0,0,0,0,0,0,0,0,70,30,0,0,78,17,0,0,0,0,0,0,0,0,0,0,78,20,0,0,148,54,0,0,162,9,0,0,156,9,0,0,198,15,0,0,232,8,0,0,42,6,0,0,216,176,145,0,0,4,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,94,7,0,0,0,0,0,0,0,0,0,0,0,0,0,232,167,7,0,104,254,3,0,0,0,0,0,0,40,1,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,8,0,0,2,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,0,0,0,0,2,26,0,0,10,35,0,0,0,0,0,0,0,0,0,0,134,18,0,0,216,31,0,0,122,9,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,80,101,7,0,104,94,7,0,0,0,0,0,0,0,0,0,232,233,7,0,128,82,7,0,0,0,0,0,232,78,7,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,53,8,0,0,2,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,0,0,0,0,248,31,0,0,254,1,0,0,0,0,0,0,0,0,0,0,40,13,0,0,162,5,0,0,122,10,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,184,146,4,0,56,24,5,0,0,0,0,0,0,0,0,0,144,47,2,0,8,117,4,0,0,0,0,0,168,95,8,0,192,178,4,0,104,92,4,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,1,3,2,0,0,0,0,0,0,0,0,0,0,0,32,37,0,0,130,34,0,0,0,0,0,0,0,0,0,0,202,23,0,0,0,0,0,0,34,11,0,0,130,1,0,0,64,17,0,0,0,0,0,0,90,16,0,0,0,0,0,0,16,8,0,0,224,0,0,0,24,1,0,0,3,0,0,0,4,0,0,0,88,232,4,0,152,72,5,0,0,0,0,0,0,0,0,0,96,135,2,0,136,195,4,0,0,0,0,0,40,161,4,0,8,153,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,3,0,0,0,64,0,6,2,2,0,0,0,0,0,0,0,0,0,0,0,168,44,0,0,104,16,0,0,0,0,0,0,0,0,0,0,254,10,0,0,218,55,0,0,200,0,0,0,164,2,0,0,20,14,0,0,0,0,0,0,106,0,0,0,0,0,0,0,0,24,0,0,224,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,152,72,5,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,160,10,5,0,0,0,0,0,40,161,4,0,8,153,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,3,0,0,0,64,0,6,2,2,0,0,0,0,0,0,0,0,0,0,0,132,45,0,0,222,7,0,0,0,0,0,0,0,0,0,0,254,10,0,0,218,55,0,0,200,0,0,0,164,2,0,0,20,14,0,0,0,0,0,0,106,0,0,0,0,0,0,0,0,24,0,0,224,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,88,240,3,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,64,52,6,0,120,155,4,0,32,0,1,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,16,0,0,0,0,0,0,0,0,0,0,34,53,0,0,72,29,0,0,0,0,0,0,0,0,0,0,40,0,0,0,0,0,0,0,30,4,0,0,66,3,0,0,216,3,0,0,240,6,0,0,124,31,0,0,152,174,145,0,0,72,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,24,214,8,0,184,181,2,0,0,0,0,0,0,0,0,0,184,168,7,0,240,148,8,0,0,0,0,0,160,150,4,0,224,127,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,4,0,8,0,0,0,0,0,0,0,0,0,0,90,49,0,0,140,29,0,0,0,0,0,0,0,0,0,0,248,2,0,0,206,8,0,0,252,5,0,0,224,5,0,0,190,4,0,0,166,6,0,0,174,39,0,0,32,146,215,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,184,100,1,0,184,181,2,0,0,0,0,0,0,0,0,0,184,168,7,0,128,22,1,0,0,0,0,0,160,150,4,0,224,127,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,4,0,8,0,0,0,0,0,0,0,0,0,0,108,42,0,0,96,20,0,0,0,0,0,0,0,0,0,0,248,2,0,0,206,8,0,0,232,1,0,0,224,5,0,0,190,4,0,0,166,6,0,0,174,39,0,0,32,146,215,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,144,191,2,0,184,181,2,0,0,0,0,0,0,0,0,0,184,168,7,0,80,197,1,0,0,0,0,0,160,150,4,0,224,127,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,4,0,8,0,0,0,0,0,0,0,0,0,0,100,36,0,0,150,37,0,0,0,0,0,0,0,0,0,0,248,2,0,0,206,8,0,0,232,1,0,0,224,5,0,0,190,4,0,0,166,6,0,0,174,39,0,0,32,146,215,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,184,181,2,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,56,240,5,0,0,0,0,0,160,150,4,0,224,127,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,4,0,8,0,0,0,0,0,0,0,0,0,0,204,37,0,0,178,12,0,0,0,0,0,0,0,0,0,0,248,2,0,0,136,26,0,0,106,2,0,0,224,5,0,0,190,4,0,0,166,6,0,0,174,39,0,0,32,146,215,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,232,230,7,0,152,2,8,0,0,0,0,0,0,0,0,0,200,190,7,0,200,226,7,0,0,0,0,0,40,161,4,0,80,150,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,5,0,4,2,0,0,8,0,0,0,0,0,0,0,0,0,160,2,0,0,64,36,0,0,0,0,0,0,0,0,0,0,214,27,0,0,24,43,0,0,142,0,0,0,174,19,0,0,134,11,0,0,0,0,0,0,92,54,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,42,5,0,0,0,0,0,0,0,0,0,0,0,0,0,184,230,7,0,16,12,5,0,0,0,0,0,136,233,4,0,208,165,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,1,21,0,0,8,0,0,0,0,0,0,0,0,0,150,8,0,0,232,18,0,0,0,0,0,0,0,0,0,0,248,46,0,0,44,45,0,0,196,10,0,0,198,1,0,0,170,2,0,0,0,0,0,0,236,14,0,0,240,210,148,0,0,128,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,112,219,3,0,176,42,5,0,0,0,0,0,0,0,0,0,184,230,7,0,248,189,3,0,0,0,0,0,136,233,4,0,208,165,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,1,0,0,0,0,0,1,21,0,0,8,0,0,0,0,0])
.concat([0,0,0,0,80,60,0,0,198,0,0,0,0,0,0,0,0,0,0,0,248,46,0,0,44,45,0,0,196,10,0,0,198,1,0,0,170,2,0,0,0,0,0,0,236,14,0,0,240,210,148,0,0,128,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,248,26,4,0,176,42,5,0,0,0,0,0,0,0,0,0,184,230,7,0,160,252,3,0,0,0,0,0,136,233,4,0,208,165,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,1,0,0,0,0,0,1,21,0,0,8,0,0,0,0,0,0,0,0,0,208,8,0,0,166,37,0,0,0,0,0,0,0,0,0,0,248,46,0,0,44,45,0,0,196,10,0,0,198,1,0,0,170,2,0,0,0,0,0,0,236,14,0,0,240,210,148,0,0,128,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,216,80,4,0,176,42,5,0,0,0,0,0,0,0,0,0,184,230,7,0,224,54,4,0,0,0,0,0,136,233,4,0,208,165,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,1,0,0,0,0,0,1,21,0,0,8,0,0,0,0,0,0,0,0,0,90,11,0,0,124,24,0,0,0,0,0,0,0,0,0,0,248,46,0,0,44,45,0,0,196,10,0,0,198,1,0,0,170,2,0,0,0,0,0,0,236,14,0,0,240,210,148,0,0,128,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,120,134,4,0,176,42,5,0,0,0,0,0,0,0,0,0,184,230,7,0,152,107,4,0,0,0,0,0,136,233,4,0,208,165,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,1,0,0,0,0,0,1,21,0,0,8,0,0,0,0,0,0,0,0,0,224,46,0,0,26,38,0,0,0,0,0,0,0,0,0,0,248,46,0,0,44,45,0,0,196,10,0,0,198,1,0,0,170,2,0,0,0,0,0,0,236,14,0,0,240,210,148,0,0,128,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,24,197,4,0,176,42,5,0,0,0,0,0,0,0,0,0,184,230,7,0,224,164,4,0,0,0,0,0,136,233,4,0,208,165,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,1,0,0,0,0,0,1,21,0,0,8,0,0,0,0,0,0,0,0,0,180,33,0,0,158,28,0,0,0,0,0,0,0,0,0,0,248,46,0,0,44,45,0,0,196,10,0,0,198,1,0,0,170,2,0,0,0,0,0,0,236,14,0,0,240,210,148,0,0,128,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,176,63,6,0,72,128,7,0,0,0,0,0,0,0,0,0,96,135,2,0,200,24,6,0,0,0,0,0,176,237,2,0,168,84,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,19,8,0,0,0,0,0,0,0,0,0,0,0,52,47,0,0,174,33,0,0,0,0,0,0,0,0,0,0,122,30,0,0,26,60,0,0,150,16,0,0,192,10,0,0,128,11,0,0,140,16,0,0,112,12,0,0,0,173,145,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,192,137,6,0,0,0,0,0,0,0,0,0,0,0,0,0,160,135,3,0,56,46,6,0,88,181,6,0,40,98,7,0,160,201,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,1,0,0,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,120,59,0,0,46,42,0,0,0,0,0,0,0,0,0,0,16,54,0,0,84,46,0,0,218,17,0,0,44,18,0,0,234,15,0,0,250,18,0,0,102,10,0,0,208,175,145,0,32,0,0,0,236,0,0,0,16,1,0,0,3,0,0,0,4,0,0,0,80,137,7,0,88,87,8,0,0,0,0,0,0,0,0,0,96,135,2,0,200,89,7,0,0,0,0,0,144,84,8,0,208,135,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,2,11,0,0,8,0,0,0,0,0,0,0,0,0,108,35,0,0,184,28,0,0,0,0,0,0,0,0,0,0,94,58,0,0,82,33,0,0,188,14,0,0,46,7,0,0,246,17,0,0,0,0,0,0,176,18,0,0,0,0,0,0,0,32,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,87,8,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,128,236,7,0,0,0,0,0,168,183,7,0,208,135,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,2,11,0,0,8,0,0,0,0,0,0,0,0,0,52,1,0,0,40,41,0,0,0,0,0,0,0,0,0,0,94,58,0,0,166,60,0,0,188,14,0,0,46,7,0,0,246,17,0,0,0,0,0,0,176,18,0,0,0,0,0,0,0,32,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,211,1,0,8,5,2,0,0,0,0,0,0,0,0,0,184,168,7,0,80,200,1,0,0,0,0,0,192,154,4,0,80,150,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,4,2,4,2,4,0,0,0,0,0,0,0,0,0,0,0,234,48,0,0,62,31,0,0,0,0,0,0,0,0,0,0,210,8,0,0,230,32,0,0,150,4,0,0,114,17,0,0,134,11,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,238,1,0,8,5,2,0,0,0,0,0,0,0,0,0,184,168,7,0,144,226,1,0,0,0,0,0,40,161,4,0,80,150,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,4,4,2,4,0,0,0,0,0,0,0,0,0,0,0,246,41,0,0,172,24,0,0,0,0,0,0,0,0,0,0,210,8,0,0,230,32,0,0,242,3,0,0,114,17,0,0,134,11,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,5,2,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,168,247,1,0,0,0,0,0,40,161,4,0,80,150,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,64,4,4,2,4,0,0,0,0,0,0,0,0,0,0,0,142,14,0,0,226,42,0,0,0,0,0,0,0,0,0,0,210,8,0,0,230,32,0,0,130,6,0,0,114,17,0,0,134,11,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,204,7,0,160,198,5,0,0,0,0,0,0,0,0,0,200,190,7,0,104,154,7,0,0,0,0,0,232,109,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,22,4,0,0,0,0,0,0,0,0,0,0,0,32,28,0,0,110,23,0,0,0,0,0,0,0,0,0,0,112,17,0,0,92,21,0,0,238,4,0,0,170,7,0,0,222,6,0,0,0,0,0,0,122,53,0,0,0,0,0,0,128,1,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,120,53,8,0,160,198,5,0,0,0,0,0,0,0,0,0,200,190,7,0,64,1,8,0,0,0,0,0,232,109,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,22,4,0,0,0,0,0,0,0,0,0,0,0,54,57,0,0,46,39,0,0,0,0,0,0,0,0,0,0,112,17,0,0,92,21,0,0,238,4,0,0,170,7,0,0,222,6,0,0,0,0,0,0,122,53,0,0,0,0,0,0,128,1,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,112,254,2,0,160,198,5,0,0,0,0,0,0,0,0,0,200,190,7,0,8,98,2,0,0,0,0,0,184,235,1,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,22,4,0,0,0,0,0,0,0,0,0,0,0,10,38,0,0,232,39,0,0,0,0,0,0,0,0,0,0,112,17,0,0,92,21,0,0,238,4,0,0,170,7,0,0,222,6,0,0,0,0,0,0,122,53,0,0,0,0,0,0,128,1,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,240,237,8,0,160,198,5,0,0,0,0,0,0,0,0,0,200,190,7,0,128,173,8,0,0,0,0,0,232,109,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,22,4,0,0,0,0,0,0,0,0,0,0,0,168,27,0,0,110,31,0,0,0,0,0,0,0,0,0,0,112,17,0,0,92,21,0,0,238,4,0,0,170,7,0,0,222,6,0,0,0,0,0,0,122,53,0,0,0,0,0,0,128,1,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,232,226,6,0,160,198,5,0,0,0,0,0,0,0,0,0,200,190,7,0,152,183,6,0,0,0,0,0,192,154,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,0,22,4,0,0,0,0,0,0,0,0,0,0,0,166,41,0,0,68,44,0,0,0,0,0,0,0,0,0,0,112,17,0,0,92,21,0,0,160,7,0,0,170,7,0,0,222,6,0,0,0,0,0,0,122,53,0,0,0,0,0,0,128,1,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,232,37,4,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,248,57,6,0,0,0,0,0,120,58,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,3,0,0,0,0,0,0,22,4,0,0,0,0,0,0,0,0,0,0,0,150,62,0,0,176,42,0,0,0,0,0,0,0,0,0,0,42,46,0,0,64,50,0,0,146,12,0,0,212,4,0,0,24,14,0,0,0,0,0,0,76,63,0,0,0,0,0,0,0,6,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,40,178,5,0,88,48,6,0,0,0,0,0,0,0,0,0,104,174,7,0,64,140,5,0,0,0,0,0,120,58,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,22,4,0,0,0,0,0,0,0,0,0,0,0,0,46,0,0,218,37,0,0,0,0,0,0,0,0,0,0,112,17,0,0,44,58,0,0,120,15,0,0,170,7,0,0,222,6,0,0,0,0,0,0,122,53,0,0,0,0,0,0,128,1,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,88,48,6,0,0,0,0,0,0,0,0,0,0,0,0,0,104,174,7,0,64,216,5,0,0,0,0,0,120,58,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,22,4,0,0,0,0,0,0,0,0,0,0,0,186,41,0,0,174,14,0,0,0,0,0,0,0,0,0,0,112,17,0,0,44,58,0,0,120,15,0,0,170,7,0,0,222,6,0,0,0,0,0,0,122,53,0,0,0,0,0,0,128,1,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,160,198,5,0,0,0,0,0,0,0,0,0,0,0,0,0,200,190,7,0,224,119,6,0,0,0,0,0,120,58,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,22,4,0,0,0,0,0,0,0,0,0,0,0,120,45,0,0,18,47,0,0,0,0,0,0,0,0,0,0,112,17,0,0,92,21,0,0,238,4,0,0,170,7,0,0,222,6,0,0,0,0,0,0,122,53,0,0,0,0,0,0,128,1,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,32,108,7,0,160,198,5,0,0,0,0,0,0,0,0,0,200,190,7,0,72,58,7,0,0,0,0,0,192,154,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,0,22,4,0,0,0,0,0,0,0,0,0,0,0,186,56,0,0,130,42,0,0,0,0,0,0,0,0,0,0,112,17,0,0,92,21,0,0,238,4,0,0,170,7,0,0,222,6,0,0,0,0,0,0,122,53,0,0,0,0,0,0,128,1,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,56,220,1,0,232,37,4,0,0,0,0,0,0,0,0,0,104,221,5,0,0,122,1,0,0,0,0,0,120,58,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,81,0,0,0,3,0,0,0,0,0,0,22,4,0,0,0,0,0,0,0,0,0,0,0,44,41,0,0,10,42,0,0,0,0,0,0,0,0,0,0,42,46,0,0,64,50,0,0,234,17,0,0,212,4,0,0,24,14,0,0,0,0,0,0,76,63,0,0,0,0,0,0,0,6,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,40,225,2,0,232,37,4,0,0,0,0,0,0,0,0,0,104,221,5,0,248,77,2,0,0,0,0,0,120,58,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,3,0,0,0,0,0,0,22,4,0,0,0,0,0,0,0,0,0,0,0,36,37,0,0,156,1,0,0,0,0,0,0,0,0,0,0,42,46,0,0,64,50,0,0,146,12,0,0,212,4,0,0,24,14,0,0,0,0,0,0,76,63,0,0,0,0,0,0,0,6,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,160,39,1,0,232,37,4,0,0,0,0,0,0,0,0,0,104,221,5,0,168,228,8,0,0,0,0,0,192,154,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,3,0,0,0,0,0,0,22,4,0,0,0,0,0,0,0,0,0,0,0,216,47,0,0,238,3,0,0,0,0,0,0,0,0,0,0,42,46,0,0,86,54,0,0,4,10,0,0,212,4,0,0,24,14,0,0,0,0,0,0,76,63,0,0,0,0,0,0,0,6,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,168,139,1,0,160,198,5,0,0,0,0,0,0,0,0,0,200,190,7,0,192,49,1,0,0,0,0,0,184,235,1,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,22,4,0,0,0,0,0,0,0,0,0,0,0,182,31,0,0,212,5,0,0,0,0,0,0,0,0,0,0,112,17,0,0,92,21,0,0,238,4,0,0,170,7,0,0,222,6,0,0,0,0,0,0,122,53,0,0,0,0,0,0,128,1,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,112,139,6,0,160,198,5,0,0,0,0,0,0,0,0,0,200,190,7,0,8,95,6,0,0,0,0,0,192,154,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,0,22,4,0,0,0,0,0,0,0,0,0,0,0,100,33,0,0,214,9,0,0,0,0,0,0,0,0,0,0,112,17,0,0,92,21,0,0,60,3,0,0,170,7,0,0,222,6,0,0,0,0,0,0,122,53,0,0,0,0,0,0,128,1,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,136,2,6,0,232,44,6,0,0,0,0,0,0,0,0,0,56,172,6,0,0,253,5,0,0,0,0,0,64,35,6,0,88,0,3,0,152,244,5,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,4,0,0,0,0,0,0,8,2,0,0,0,0,0,0,0,0,0,0,0,90,54,0,0,144,16,0,0,0,0,0,0,0,0,0,0,104,35,0,0,16,44,0,0,246,9,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,224,0,0,0,192,1,0,0,3,0,0,0,4,0,0,0,200,17,6,0,232,44,6,0,0,0,0,0,0,0,0,0,56,172,6,0,232,13,6,0,0,0,0,0,64,35,6,0,88,0,3,0,24,7,6,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,4,0,0,0,0,0,0,8,2,0,0,0,0,0,0,0,0,0,0,0,178,37,0,0,14,8,0,0,0,0,0,0,0,0,0,0,104,35,0,0,16,44,0,0,246,9,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,224,0,0,0,192,1,0,0,3,0,0,0,4,0,0,0,120,24,6,0,232,44,6,0,0,0,0,0,0,0,0,0,56,172,6,0,208,20,6,0,0,0,0,0,64,35,6,0,88,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,4,0,0,0,0,0,0,8,2,0,0,0,0,0,0,0,0,0,0,0,240,17,0,0,106,16,0,0,0,0,0,0,0,0,0,0,104,35,0,0,16,44,0,0,122,7,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,224,0,0,0,192,1,0,0,3,0,0,0,4,0,0,0,24,31,6,0,232,44,6,0,0,0,0,0,0,0,0,0,56,172,6,0,128,27,6,0,0,0,0,0,64,35,6,0,88,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,4,0,0,0,0,0,0,8,2,0,0,0,0,0,0,0,0,0,0,0,128,55,0,0,130,12,0,0,0,0,0,0,0,0,0,0,104,35,0,0,16,44,0,0,122,7,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,224,0,0,0,192,1,0,0,3,0,0,0,4,0,0,0,232,44,6,0,0,0,0,0,0,0,0,0,0,0,0,0,56,172,6,0,136,40,6,0,0,0,0,0,64,35,6,0,88,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,4,0,0,0,0,0,0,8,2,0,0,0,0,0,0,0,0,0,0,0,134,21,0,0,42,9,0,0,0,0,0,0,0,0,0,0,104,35,0,0,16,44,0,0,122,7,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,224,0,0,0,192,1,0,0,3,0,0,0,4,0,0,0,72,69,7,0,240,244,7,0,200,240,5,0,0,0,0,0,104,129,6,0,128,65,7,0,0,0,0,0,72,174,3,0,88,0,3,0,16,60,7,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,4,0,0,0,1,0,0,8,2,0,0,0,0,0,0,0,0,0,0,0,38,61,0,0,146,20,0,0,0,0,0,0,0,0,0,0,104,35,0,0,122,51,0,0,170,9,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,224,0,0,0,192,1,0,0,3,0,0,0,4,0,0,0,16,156,7,0,240,244,7,0,200,240,5,0,0,0,0,0,104,129,6,0,8,151,7,0,0,0,0,0,72,174,3,0,88,0,3,0,240,144,7,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,4,0,0,0,1,0,0,8,2,0,0,0,0,0,0,0,0,0,0,0,14,7,0,0,80,37,0,0,0,0,0,0,0,0,0,0,104,35,0,0,98,14,0,0,170,9,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,224,0,0,0,192,1,0,0,3,0,0,0,4,0,0,0,168,116,7,0,240,244,7,0,200,240,5,0,0,0,0,0,104,129,6,0,240,110,7,0,0,0,0,0,72,174,3,0,88,0,3,0,176,104,7,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,4,0,0,0,1,0,0,8,2,0,0,0,0,0,0,0,0,0,0,0,92,3,0,0,218,3,0,0,0,0,0,0,0,0,0,0,104,35,0,0,184,42,0,0,170,9,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,224,0,0,0,192,1,0,0,3,0,0,0,4,0,0,0,152,199,7,0,240,244,7,0,200,240,5,0,0,0,0,0,104,129,6,0,0,193,7,0,0,0,0,0,72,174,3,0,88,0,3,0,88,185,7,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,4,0,0,0,1,0,0,8,2,0,0,0,0,0,0,0,0,0,0,0,178,30,0,0,230,22,0,0,0,0,0,0,0,0,0,0,104,35,0,0,176,40,0,0,170,9,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,224,0,0,0,192,1,0,0,3,0,0,0,4,0,0,0,200,27,7,0,240,244,7,0,200,240,5,0,0,0,0,0,104,129,6,0,24,25,7,0,0,0,0,0,72,174,3,0,88,0,3,0,160,20,7,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,4,0,0,0,1,0,0,8,2,0,0,0,0,0,0,0,0,0,0,0,36,0,0,0,184,5,0,0,0,0,0,0,0,0,0,0,104,35,0,0,160,25,0,0,170,9,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,224,0,0,0,192,1,0,0,3,0,0,0,4,0,0,0,16,54,7,0,240,244,7,0,200,240,5,0,0,0,0,0,104,129,6,0,168,48,7,0,0,0,0,0,72,174,3,0,88,0,3,0,0,42,7,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,4,0,0,0,1,0,0,8,2,0,0,0,0,0,0,0,0,0,0,0,194,23,0,0,226,32,0,0,0,0,0,0,0,0,0,0,104,35,0,0,122,51,0,0,170,9,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,224,0,0,0,192,1,0,0,3,0,0,0,4,0,0,0,40,139,7,0,240,244,7,0,200,240,5,0,0,0,0,0,104,129,6,0,224,133,7,0,0,0,0,0,72,174,3,0,88,0,3,0,112,130,7,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,4,0,0,0,1,0,0,8,2,0,0,0,0,0,0,0,0,0,0,0,162,52,0,0,226,18,0,0,0,0,0,0,0,0,0,0,104,35,0,0,98,14,0,0,170,9,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,224,0,0,0,192,1,0,0,3,0,0,0,4,0,0,0,104,98,7,0,240,244,7,0,200,240,5,0,0,0,0,0,104,129,6,0,168,91,7,0,0,0,0,0,72,174,3,0,88,0,3,0,176,84,7,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,4,0,0,0,1,0,0,8,2,0,0,0,0,0,0,0,0,0,0,0,138,9,0,0,226,2,0,0,0,0,0,0,0,0,0,0,104,35,0,0,184,42,0,0,170,9,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,224,0,0,0,192,1,0,0,3,0,0,0,4,0,0,0,208,180,7,0,240,244,7,0,200,240,5,0,0,0,0,0,104,129,6,0,56,177,7,0,0,0,0,0,72,174,3,0,88,0,3,0,112,173,7,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,4,0,0,0,1,0,0,8,2,0,0,0,0,0,0,0,0,0,0,0,158,42,0,0,104,13,0,0,0,0,0,0,0,0,0,0,104,35,0,0,176,40,0,0,170,9,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,224,0,0,0,192,1,0,0,3,0,0,0,4,0,0,0,160,15,7,0,240,244,7,0,200,240,5,0,0,0,0,0,104,129,6,0,152,10,7,0,0,0,0,0,72,174,3,0,88,0,3,0,88,4,7,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,4,0,0,0,1,0,0,8,2,0,0,0,0,0,0,0,0,0,0,0,64,51,0,0,68,29,0,0,0,0,0,0,0,0,0,0,104,35,0,0,160,25,0,0,170,9,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,224,0,0,0,192,1,0,0,3,0,0,0,4,0,0,0,128,227,7,0,240,244,7,0,200,240,5,0,0,0,0,0,104,129,6,0,72,224,7,0,0,0,0,0,72,174,3,0,88,0,3,0,40,220,7,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,4,0,0,0,1,0,0,8,2,0,0,0,0,0,0,0,0,0,0,0,136,0,0,0,102,39,0,0,0,0,0,0,0,0,0,0,104,35,0,0,128,15,0,0,170,9,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,224,0,0,0,192,1,0,0,3,0,0,0,4,0,0,0,88,37,7,0,240,244,7,0,200,240,5,0,0,0,0,0,104,129,6,0,80,34,7,0,0,0,0,0,72,174,3,0,88,0,3,0,192,30,7,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,4,0,0,0,1,0,0,8,2,0,0,0,0,0,0,0,0,0,0,0,208,6,0,0,72,45,0,0,0,0,0,0,0,0,0,0,104,35,0,0,122,51,0,0,170,9,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,224,0,0,0,192,1,0,0,3,0,0,0,4,0,0,0,96,127,7,0,240,244,7,0,200,240,5,0,0,0,0,0,104,129,6,0,40,124,7,0,0,0,0,0,72,174,3,0,88,0,3,0,136,120,7,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,4,0,0,0,1,0,0,8,2,0,0,0,0,0,0,0,0,0,0,0,232,62,0,0,70,41,0,0,0,0,0,0,0,0,0,0,104,35,0,0,98,14,0,0,170,9,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,224,0,0,0,192,1,0,0,3,0,0,0,4,0,0,0,144,80,7,0,240,244,7,0,200,240,5,0,0,0,0,0,104,129,6,0,184,77,7,0,0,0,0,0,72,174,3,0,88,0,3,0,184,73,7,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,4,0,0,0,1,0,0,8,2,0,0,0,0,0,0,0,0,0,0,0,242,29,0,0,190,7,0,0,0,0,0,0,0,0,0,0,104,35,0,0,184,42,0,0,170,9,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,224,0,0,0,192,1,0,0,3,0,0,0,4,0,0,0,56,169,7,0,240,244,7,0,200,240,5,0,0,0,0,0,104,129,6,0,24,166,7,0,0,0,0,0,72,174,3,0,88,0,3,0,128,160,7,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,4,0,0,0,1,0,0,8,2,0,0,0,0,0,0,0,0,0,0,0,252,34,0,0,52,0,0,0,0,0,0,0,0,0,0,0,104,35,0,0,176,40,0,0,170,9,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,224,0,0,0,192,1,0,0,3,0,0,0,4,0,0,0,248,253,6,0,240,244,7,0,200,240,5,0,0,0,0,0,104,129,6,0,136,249,6,0,0,0,0,0,72,174,3,0,88,0,3,0,240,245,6,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,4,0,0,0,1,0,0,8,2,0,0,0,0,0,0,0,0,0,0,0,124,7,0,0,12,24,0,0,0,0,0,0,0,0,0,0,104,35,0,0,160,25,0,0,170,9,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,224,0,0,0,192,1,0,0,3,0,0,0,4,0,0,0,24,216,7,0,240,244,7,0,200,240,5,0,0,0,0,0,104,129,6,0,0,211,7,0,0,0,0,0,72,174,3,0,88,0,3,0,192,205,7,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,4,0,0,0,1,0,0,8,2,0,0,0,0,0,0,0,0,0,0,0,8,16,0,0,104,44,0,0,0,0,0,0,0,0,0,0,104,35,0,0,128,15,0,0,170,9,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,224,0,0,0,192,1,0,0,3,0,0,0,4,0,0,0,240,244,7,0,0,0,0,0,200,240,5,0,0,0,0,0,104,129,6,0,104,238,7,0,0,0,0,0,72,174,3,0,88,0,3,0,232,231,7,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,4,0,0,0,1,0,0,8,2,0,0,0,0,0,0,0,0,0,0,0,220,42,0,0,38,4,0,0,0,0,0,0,0,0,0,0,104,35,0,0,128,15,0,0,170,9,0,0,230,10,0,0,142,4,0,0,186,2,0,0,104,61,0,0,16,249,128,0,0,9,0,0,224,0,0,0,192,1,0,0,3,0,0,0,4,0,0,0,64,131,5,0,120,45,7,0,0,0,0,0,0,0,0,0,144,47,2,0,136,103,5,0,0,0,0,0,40,161,4,0,8,153,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,64,0,6,2,4,0,0,0,0,0,0,0,0,0,0,0,160,26,0,0,206,29,0,0,0,0,0,0,0,0,0,0,254,56,0,0,28,25,0,0,116,3,0,0,164,2,0,0,20,14,0,0,0,0,0,0,106,0,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,206,5,0,120,45,7,0,0,0,0,0,0,0,0,0,144,47,2,0,208,165,5,0,0,0,0,0,40,161,4,0,8,153,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,64,0,6,2,4,0,0,0,0,0,0,0,0,0,0,0,42,16,0,0,86,15,0,0,0,0,0,0,0,0,0,0,224,29,0,0,188,59,0,0,14,4,0,0,164,2,0,0,20,14,0,0,0,0,0,0,106,0,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,37,6,0,120,45,7,0,0,0,0,0,0,0,0,0,144,47,2,0,144,248,5,0,0,0,0,0,40,161,4,0,8,153,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,64,0,6,2,4,0,0,0,0,0,0,0,0,0,0,0,40,22,0,0,140,2,0,0,0,0,0,0,0,0,0,0,254,56,0,0,28,25,0,0,116,3,0,0,164,2,0,0,20,14,0,0,0,0,0,0,106,0,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,128,6,0,120,45,7,0,0,0,0,0,0,0,0,0,144,47,2,0,48,80,6,0,0,0,0,0,40,161,4,0,8,153,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,64,0,6,2,4,0,0,0,0,0,0,0,0,0,0,0,232,53,0,0,228,1,0,0,0,0,0,0,0,0,0,0,224,29,0,0,188,59,0,0,14,4,0,0,164,2,0,0,20,14,0,0,0,0,0,0,106,0,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,216,6,0,120,45,7,0,0,0,0,0,0,0,0,0,144,47,2,0,72,170,6,0,0,0,0,0,40,161,4,0,8,153,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,64,0,6,2,4,0,0,0,0,0,0,0,0,0,0,0,54,36,0,0,250,22,0,0,0,0,0,0,0,0,0,0,254,56,0,0,28,25,0,0,116,3,0,0,164,2,0,0,20,14,0,0,0,0,0,0,106,0,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,45,7,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,104,0,7,0,0,0,0,0,40,161,4,0,8,153,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,3,0,0,0,64,0,6,2,4,0,0,0,0,0,0,0,0,0,0,0,4,15,0,0,88,19,0,0,0,0,0,0,0,0,0,0,232,23,0,0,14,48,0,0,14,4,0,0,164,2,0,0,20,14,0,0,0,0,0,0,106,0,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,184,3,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,56,43,6,0,0,0,0,0,160,201,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,0,8,0,0,0,0,0,0,0,0,0,40,58,0,0,86,43,0,0,0,0,0,0,0,0,0,0,138,12,0,0,112,4,0,0,184,1,0,0,158,5,0,0,172,1,0,0,200,3,0,0,32,32,0,0,80,174,145,0,0,8,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,103,6,0,80,193,6,0,0,0,0,0,0,0,0,0,184,168,7,0,184,55,6,0,0,0,0,0,152,54,6,0,200,12,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,17,1,0,0,0,0,0,0,0,0,0,0,0,252,54,0,0,54,33,0,0,0,0,0,0,0,0,0,0,198,62,0,0,138,52,0,0,150,15,0,0,230,1,0,0,44,6,0,0,194,15,0,0,0,0,0,0,48,177,145,0,0,2,0,0,128,1,0,0,0,1,0,0,4,0,0,0,3,0,0,0,80,193,6,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,160,146,6,0,0,0,0,0,152,54,6,0,80,67,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,3,17,1,0,0,0,0,0,0,0,0,0,0,0,252,27,0,0,102,47,0,0,0,0,0,0,0,0,0,0,198,62,0,0,138,52,0,0,88,17,0,0,230,1,0,0,44,6,0,0,194,15,0,0,0,0,0,0,48,177,145,0,0,2,0,0,128,1,0,0,0,1,0,0,4,0,0,0,3,0,0,0,224,37,8,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,120,189,7,0,0,0,0,0,72,188,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,16,0,0,0,0,0,0,0,0,0,0,246,49,0,0,174,26,0,0,0,0,0,0,0,0,0,0,62,47,0,0,14,8,0,0,54,10,0,0,82,8,0,0,90,15,0,0,118,13,0,0,48,60,0,0,232,173,145,0,0,2,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,141,7,0,224,37,8,0,0,0,0,0,0,0,0,0,32,127,5,0,40,95,7,0,0,0,0,0,112,46,7,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,10,0,16,0,0,0,0,0,0,0,0,0,0,10,51,0,0,114,13,0,0,0,0,0,0,0,0,0,0,62,47,0,0,14,8,0,0,54,10,0,0,82,8,0,0,90,15,0,0,118,13,0,0,48,60,0,0,232,173,145,0,0,2,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,255,7,0,104,92,5,0,0,0,0,0,0,0,0,0,184,168,7,0,96,202,7,0,0,0,0,0,136,95,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,156,35,0,0,224,9,0,0,0,0,0,0,0,0,0,0,182,48,0,0,162,15,0,0,32,6,0,0,60,19,0,0,194,11,0,0,44,17,0,0,0,0,0,0,232,175,145,0,0,8,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,108,8,0,104,92,5,0,0,0,0,0,0,0,0,0,184,168,7,0,168,51,8,0,0,0,0,0,80,197,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,176,50,0,0,6,48,0,0,0,0,0,0,0,0,0,0,182,48,0,0,162,15,0,0,130,3,0,0,60,19,0,0,194,11,0,0,44,17,0,0,0,0,0,0,232,175,145,0,0,8,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,50,4,0,144,130,4,0,0,0,0,0,0,0,0,0,144,47,2,0,80,23,4,0,0,0,0,0,128,161,4,0,216,142,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,11,0,0,4,0,0,0,0,0,0,0,0,0,162,20,0,0,150,15,0,0,0,0,0,0,0,0,0,0,26,19,0,0,226,43,0,0,6,7,0,0,24,8,0,0,14,5,0,0,0,0,0,0,60,41,0,0,0,0,0,0,0,16,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,144,130,4,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,48,77,4,0,0,0,0,0,128,161,4,0,216,142,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,11,0,0,4,0,0,0,0,0,0,0,0,0,140,17,0,0,240,27,0,0,0,0,0,0,0,0,0,0,26,19,0,0,226,43,0,0,6,7,0,0,24,8,0,0,14,5,0,0,0,0,0,0,60,41,0,0,0,0,0,0,0,16,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,184,26,8,0,96,244,1,0,0,0,0,0,0,0,0,0,144,47,2,0,88,228,7,0,0,0,0,0,176,237,2,0,168,84,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,0,19,4,0,0,0,0,0,0,0,0,0,0,0,224,22,0,0,222,41,0,0,0,0,0,0,0,0,0,0,0,63,0,0,80,10,0,0,116,9,0,0,172,7,0,0,190,13,0,0,14,13,0,0,94,29,0,0,48,173,145,0,0,16,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,8,141,8,0,96,244,1,0,0,0,0,0,0,0,0,0,144,47,2,0,40,79,8,0,0,0,0,0,176,237,2,0,168,84,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,19,4,0,0,0,0,0,0,0,0,0,0,0,164,25,0,0,182,17,0,0,0,0,0,0,0,0,0,0,0,63,0,0,28,13,0,0,116,9,0,0,172,7,0,0,190,13,0,0,14,13,0,0,94,29,0,0,48,173,145,0,0,16,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,200,240,4,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,224,206,4,0,0,0,0,0,128,19,5,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,22,4,0,0,0,0,0,0,0,0,0,0,0,254,50,0,0,84,26,0,0,0,0,0,0,0,0,0,0,112,17,0,0,66,22,0,0,106,14,0,0,170,7,0,0,222,6,0,0,0,0,0,0,122,53,0,0,0,0,0,0,128,1,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,160,210,6,0,240,181,7,0,0,0,0,0,0,0,0,0,96,135,2,0,152,163,6,0,0,0,0,0,176,237,2,0,168,84,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,19,4,0,0,0,0,0,0,0,0,0,0,0,24,12,0,0,34,4,0,0,0,0,0,0,0,0,0,0,150,6,0,0,28,32,0,0,92,19,0,0,222,8,0,0,178,15,0,0,206,5,0,0,78,56,0,0,104,173,145,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,104,224,2,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,120,254,5,0,0,0,0,0,176,237,2,0,168,84,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,19,4,1,0,0,0,0,0,0,0,0,0,0,242,42,0,0,106,40,0,0,0,0,0,0,0,0,0,0,228,48,0,0,208,39,0,0,94,3,0,0,158,16,0,0,112,13,0,0,214,17,0,0,128,28,0,0,160,173,145,0,0,8,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,176,201,1,0,104,224,2,0,0,0,0,0,0,0,0,0,104,221,5,0,88,103,1,0,0,0,0,0,176,237,2,0,168,84,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,19,4,1,0,0,0,0,0,0,0,0,0,0,254,13,0,0,248,26,0,0,0,0,0,0,0,0,0,0,228,48,0,0,208,39,0,0,94,3,0,0,158,16,0,0,112,13,0,0,214,17,0,0,128,28,0,0,160,173,145,0,0,8,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,248,195,2,0,104,224,2,0,0,0,0,0,0,0,0,0,104,221,5,0,0,60,2,0,0,0,0,0,176,237,2,0,168,84,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,19,4,1,0,0,0,0,0,0,0,0,0,0,248,56,0,0,112,10,0,0,0,0,0,0])
.concat([0,0,0,0,228,48,0,0,208,39,0,0,94,3,0,0,158,16,0,0,112,13,0,0,214,17,0,0,128,28,0,0,160,173,145,0,0,8,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,32,254,2,0,0,0,0,0,0,0,0,0,0,0,0,0,232,167,7,0,224,251,2,0,48,251,2,0,56,72,3,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,8,0,0,2,0,0,0,0,0,0,16,0,0,8,0,0,0,0,0,0,0,0,0,8,13,0,0,180,47,0,0,0,0,0,0,0,0,0,0,238,33,0,0,22,30,0,0,200,13,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,154,1,0,168,54,8,0,0,0,0,0,0,0,0,0,200,190,7,0,216,60,1,0,0,0,0,0,168,95,8,0,8,2,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,3,0,0,0,0,0,0,3,0,0,8,0,0,0,0,0,0,0,0,0,26,2,0,0,106,26,0,0,0,0,0,0,0,0,0,0,152,40,0,0,16,1,0,0,162,9,0,0,156,9,0,0,198,15,0,0,232,8,0,0,42,6,0,0,216,176,145,0,0,4,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,105,1,0,192,251,2,0,0,0,0,0,0,0,0,0,160,234,7,0,168,26,1,0,0,0,0,0,144,84,8,0,128,194,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,11,1,0,0,0,0,0,0,0,0,0,0,0,100,22,0,0,162,34,0,0,0,0,0,0,0,0,0,0,222,50,0,0,162,11,0,0,62,3,0,0,46,1,0,0,118,7,0,0,0,0,0,0,78,54,0,0,0,0,0,0,0,32,0,0,96,3,0,0,224,0,0,0,12,0,0,0,3,0,0,0,128,199,2,0,192,251,2,0,0,0,0,0,0,0,0,0,160,234,7,0,152,61,2,0,0,0,0,0,144,84,8,0,128,194,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,11,1,0,0,0,0,0,0,0,0,0,0,0,68,9,0,0,204,38,0,0,0,0,0,0,0,0,0,0,222,50,0,0,162,11,0,0,62,3,0,0,46,1,0,0,118,7,0,0,0,0,0,0,78,54,0,0,0,0,0,0,0,32,0,0,96,3,0,0,224,0,0,0,12,0,0,0,3,0,0,0,56,218,8,0,192,251,2,0,0,0,0,0,0,0,0,0,160,234,7,0,48,152,8,0,0,0,0,0,144,84,8,0,128,194,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,11,1,0,0,0,0,0,0,0,0,0,0,0,120,63,0,0,170,23,0,0,0,0,0,0,0,0,0,0,222,50,0,0,108,3,0,0,62,3,0,0,46,1,0,0,118,7,0,0,0,0,0,0,78,54,0,0,0,0,0,0,0,32,0,0,96,3,0,0,224,0,0,0,12,0,0,0,3,0,0,0,40,204,1,0,152,18,3,0,0,0,0,0,0,0,0,0,184,168,7,0,104,106,1,0,0,0,0,0,144,84,8,0,128,194,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,11,1,0,0,0,0,0,0,0,0,0,0,0,58,53,0,0,138,35,0,0,0,0,0,0,0,0,0,0,36,28,0,0,134,7,0,0,206,17,0,0,70,10,0,0,244,14,0,0,0,0,0,0,122,15,0,0,0,0,0,0,0,32,0,0,128,2,0,0,224,0,0,0,8,0,0,0,3,0,0,0,40,201,2,0,152,18,3,0,0,0,0,0,0,0,0,0,184,168,7,0,216,63,2,0,0,0,0,0,144,84,8,0,128,194,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,11,1,0,0,0,0,0,0,0,0,0,0,0,198,49,0,0,34,39,0,0,0,0,0,0,0,0,0,0,36,28,0,0,134,7,0,0,206,17,0,0,70,10,0,0,244,14,0,0,0,0,0,0,122,15,0,0,0,0,0,0,0,32,0,0,128,2,0,0,224,0,0,0,8,0,0,0,3,0,0,0,152,18,3,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,216,11,6,0,0,0,0,0,144,84,8,0,128,194,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,3,11,1,0,0,0,0,0,0,0,0,0,0,0,244,14,0,0,28,3,0,0,0,0,0,0,0,0,0,0,168,9,0,0,78,19,0,0,58,17,0,0,70,10,0,0,6,4,0,0,0,0,0,0,122,15,0,0,0,0,0,0,0,48,0,0,96,3,0,0,224,0,0,0,12,0,0,0,3,0,0,0,192,251,2,0,0,0,0,0,0,0,0,0,0,0,0,0,160,234,7,0,56,5,6,0,0,0,0,0,168,183,7,0,128,194,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,3,11,1,0,0,0,0,0,0,0,0,0,0,0,206,55,0,0,134,15,0,0,0,0,0,0,0,0,0,0,222,50,0,0,162,6,0,0,62,3,0,0,46,1,0,0,118,7,0,0,0,0,0,0,78,54,0,0,0,0,0,0,0,32,0,0,96,3,0,0,224,0,0,0,12,0,0,0,3,0,0,0,72,26,6,0,0,0,0,0,0,0,0,0,0,0,0,0,192,177,6,0,248,40,1,0,0,0,0,0,232,163,8,0,40,181,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,13,8,0,0,0,0,0,0,0,0,0,0,0,106,14,0,0,90,9,0,0,0,0,0,0,0,0,0,0,180,38,0,0,10,5,0,0,178,5,0,0,160,16,0,0,104,12,0,0,54,1,0,0,166,39,0,0,0,0,0,0,0,20,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,204,2,0,112,213,2,0,0,0,0,0,0,0,0,0,216,194,1,0,184,202,2,0,0,0,0,0,96,209,2,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,16,1,0,0,0,0,0,0,0,0,0,0,0,196,59,0,0,18,32,0,0,0,0,0,0,0,0,0,0,68,35,0,0,168,50,0,0,56,5,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,16,207,2,0,112,213,2,0,0,0,0,0,0,0,0,0,216,194,1,0,248,205,2,0,0,0,0,0,96,209,2,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,16,1,0,0,0,0,0,0,0,0,0,0,0,254,45,0,0,60,32,0,0,0,0,0,0,0,0,0,0,68,35,0,0,168,50,0,0,56,5,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,112,213,2,0,0,0,0,0,0,0,0,0,0,0,0,0,216,194,1,0,96,210,2,0,0,0,0,0,96,209,2,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,2,0,0,0,0,0,0,16,1,0,0,0,0,0,0,0,0,0,0,0,198,47,0,0,80,28,0,0,0,0,0,0,0,0,0,0,68,35,0,0,168,50,0,0,56,5,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,32,164,5,0,88,168,6,0,0,0,0,0,0,0,0,0,184,168,7,0,56,130,5,0,0,0,0,0,144,84,8,0,8,147,3,0,208,101,5,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,4,11,2,0,0,0,0,0,0,0,0,0,0,0,194,20,0,0,38,20,0,0,0,0,0,0,0,0,0,0,98,41,0,0,68,19,0,0,58,3,0,0,48,9,0,0,122,0,0,0,0,0,0,0,236,36,0,0,0,0,0,0,0,8,0,0,224,0,0,0,128,1,0,0,3,0,0,0,4,0,0,0,168,76,5,0,56,171,5,0,0,0,0,0,0,0,0,0,240,3,2,0,208,44,5,0,0,0,0,0,72,108,5,0,0,227,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,1,21,0,0,1,0,0,0,0,0,0,0,0,0,174,49,0,0,54,9,0,0,0,0,0,0,0,0,0,0,196,18,0,0,240,49,0,0,34,18,0,0,248,19,0,0,72,13,0,0,56,10,0,0,96,10,0,0,224,174,145,0,0,6,0,0,240,0,0,0,128,1,0,0,3,0,0,0,4,0,0,0,56,171,5,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,16,135,5,0,0,0,0,0,72,108,5,0,0,227,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,1,21,0,0,1,0,0,0,0,0,0,0,0,0,190,2,0,0,234,28,0,0,0,0,0,0,0,0,0,0,196,18,0,0,240,49,0,0,34,18,0,0,248,19,0,0,72,13,0,0,56,10,0,0,96,10,0,0,224,174,145,0,0,6,0,0,240,0,0,0,128,1,0,0,3,0,0,0,4,0,0,0,224,217,2,0,56,196,3,0,0,0,0,0,0,0,0,0,192,177,6,0,144,73,2,0,0,0,0,0,32,203,4,0,136,153,3,0,0,214,1,0,0,0,0,0,0,0,0,0,0,0,0,0,149,0,0,0,2,0,0,0,0,0,0,6,2,0,0,0,0,0,0,0,0,0,0,0,190,5,0,0,8,17,0,0,0,0,0,0,0,0,0,0,60,48,0,0,0,0,0,0,230,6,0,0,172,19,0,0,240,19,0,0,224,6,0,0,188,42,0,0,96,49,216,0,0,128,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,56,35,5,0,0,0,0,0,0,0,0,0,0,0,0,0,104,174,7,0,96,99,6,0,0,0,0,0,0,244,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,240,15,0,0,232,19,0,0,0,0,0,0,0,0,0,0,36,48,0,0,222,20,0,0,208,11,0,0,198,9,0,0,160,18,0,0,56,0,0,0,234,4,0,0,160,175,145,0,0,32,0,0,0,2,0,0,224,0,0,0,8,0,0,0,3,0,0,0,104,122,6,0,0,0,0,0,72,172,6,0,0,0,0,0,104,221,5,0,192,174,4,0,0,0,0,0,128,145,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,0,8,0,0,0,0,0,0,0,0,0,0,218,31,0,0,160,18,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,138,4,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,48,84,4,0,0,0,0,0,192,223,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,32,0,0,0,0,0,0,0,0,0,0,184,7,0,0,108,19,0,0,0,0,0,0,0,0,0,0,160,16,0,0,0,0,0,0,84,18,0,0,22,7,0,0,230,18,0,0,0,0,0,0,110,45,0,0,0,0,0,0,0,8,0,0,128,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,176,8,4,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,32,85,5,0,0,0,0,0,168,95,8,0,112,199,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,3,0,16,0,0,0,0,0,0,0,0,0,0,146,60,0,0,34,8,0,0,0,0,0,0,0,0,0,0,94,40,0,0,160,12,0,0,156,8,0,0,114,0,0,0,154,11,0,0,0,0,0,0,210,43,0,0,0,0,0,0,0,4,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,35,4,0,176,8,4,0,0,0,0,0,0,0,0,0,184,168,7,0,224,230,3,0,0,0,0,0,168,95,8,0,112,199,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,3,0,16,0,0,0,0,0,0,0,0,0,0,118,57,0,0,204,32,0,0,0,0,0,0,0,0,0,0,176,49,0,0,102,48,0,0,70,14,0,0,156,9,0,0,198,15,0,0,232,8,0,0,42,6,0,0,216,176,145,0,0,4,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,147,7,0,32,100,8,0,0,0,0,0,0,0,0,0,104,221,5,0,192,100,7,0,0,0,0,0,120,58,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,3,0,0,0,0,0,0,22,4,0,0,0,0,0,0,0,0,0,0,0,174,17,0,0,124,47,0,0,0,0,0,0,0,0,0,0,42,46,0,0,164,50,0,0,110,9,0,0,212,4,0,0,24,14,0,0,0,0,0,0,76,63,0,0,0,0,0,0,0,6,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,0,221,6,0,32,100,8,0,0,0,0,0,0,0,0,0,104,221,5,0,168,175,6,0,0,0,0,0,192,154,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,3,0,0,0,0,0,0,22,4,0,0,0,0,0,0,0,0,0,0,0,102,61,0,0,218,8,0,0,0,0,0,0,0,0,0,0,42,46,0,0,164,50,0,0,110,9,0,0,212,4,0,0,24,14,0,0,0,0,0,0,76,63,0,0,0,0,0,0,0,6,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,80,50,7,0,32,100,8,0,0,0,0,0,0,0,0,0,104,221,5,0,152,6,7,0,0,0,0,0,192,154,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,3,0,0,0,0,0,0,22,4,0,0,0,0,0,0,0,0,0,0,0,70,6,0,0,80,6,0,0,0,0,0,0,0,0,0,0,42,46,0,0,164,50,0,0,110,9,0,0,212,4,0,0,24,14,0,0,0,0,0,0,76,63,0,0,0,0,0,0,0,6,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,248,247,7,0,32,100,8,0,0,0,0,0,0,0,0,0,104,221,5,0,96,195,7,0,0,0,0,0,120,58,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,3,0,0,0,0,0,0,22,4,0,0,0,0,0,0,0,0,0,0,0,184,34,0,0,232,42,0,0,0,0,0,0,0,0,0,0,42,46,0,0,164,50,0,0,110,9,0,0,212,4,0,0,24,14,0,0,0,0,0,0,76,63,0,0,0,0,0,0,0,6,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,32,100,8,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,176,43,8,0,0,0,0,0,120,58,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,3,0,0,0,0,0,0,22,4,0,0,0,0,0,0,0,0,0,0,0,54,35,0,0,174,25,0,0,0,0,0,0,0,0,0,0,42,46,0,0,164,50,0,0,110,9,0,0,212,4,0,0,24,14,0,0,0,0,0,0,76,63,0,0,0,0,0,0,0,6,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,120,209,2,0,104,254,2,0,0,0,0,0,0,0,0,0,200,190,7,0,24,191,2,0,0,0,0,0,176,237,2,0,176,109,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,19,0,0,1,0,0,0,0,0,0,0,0,0,222,17,0,0,40,32,0,0,0,0,0,0,0,0,0,0,220,12,0,0,162,4,0,0,162,12,0,0,32,3,0,0,160,15,0,0,10,5,0,0,18,42,0,0,72,173,145,0,0,4,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,104,254,2,0,0,0,0,0,0,0,0,0,0,0,0,0,200,190,7,0,168,231,2,0,0,0,0,0,176,237,2,0,176,109,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,19,0,0,1,0,0,0,0,0,0,0,0,0,208,28,0,0,82,4,0,0,0,0,0,0,0,0,0,0,220,12,0,0,162,4,0,0,162,12,0,0,32,3,0,0,160,15,0,0,10,5,0,0,18,42,0,0,72,173,145,0,0,4,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,160,224,2,0,0,0,0,0,0,0,0,0,0,0,0,0,144,139,6,0,144,77,2,0,0,0,0,0,240,213,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,6,0,0,1,0,0,0,0,0,0,0,0,0,84,54,0,0,58,24,0,0,0,0,0,0,0,0,0,0,132,55,0,0,110,40,0,0,122,8,0,0,190,10,0,0,38,7,0,0,70,15,0,0,218,16,0,0,96,49,216,0,0,128,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,184,73,2,0,240,194,3,0,0,0,0,0,0,0,0,0,240,3,2,0,184,214,1,0,0,0,0,0,224,189,4,0,240,185,2,0,32,116,1,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,0,10,0,0,4,0,0,0,0,0,0,0,0,0,134,61,0,0,104,35,0,0,0,0,0,0,0,0,0,0,104,13,0,0,212,13,0,0,220,11,0,0,182,13,0,0,208,18,0,0,72,14,0,0,0,42,0,0,96,174,145,0,1,4,0,0,224,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,240,194,3,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,96,44,6,0,0,0,0,0,224,189,4,0,240,185,2,0,48,218,2,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,0,10,0,0,4,0,0,0,0,0,0,0,0,0,44,50,0,0,58,31,0,0,0,0,0,0,0,0,0,0,104,13,0,0,212,13,0,0,220,11,0,0,182,13,0,0,208,18,0,0,72,14,0,0,0,42,0,0,96,174,145,0,1,4,0,0,224,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,136,85,5,0,104,184,5,0,0,0,0,0,0,0,0,0,144,47,2,0,160,55,5,0,240,56,5,0,152,54,6,0,168,38,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,5,17,4,0,0,0,0,0,0,0,0,0,0,0,182,46,0,0,202,42,0,0,0,0,0,0,0,0,0,0,58,34,0,0,244,42,0,0,14,11,0,0,218,2,0,0,114,1,0,0,166,3,0,0,116,50,0,0,8,211,148,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,72,96,4,0,0,0,0,0,0,0,0,0,0,0,0,0,192,177,6,0,96,64,6,0,0,0,0,0,48,220,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,16,0,0,0,0,0,0,0,0,0,0,126,34,0,0,130,1,0,0,0,0,0,0,0,0,0,0,154,43,0,0,124,47,0,0,218,8,0,0,42,7,0,0,158,13,0,0,88,9,0,0,252,45,0,0,248,174,145,0,0,3,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,32,211,2,0,80,136,3,0,0,0,0,0,0,0,0,0,168,163,7,0,8,70,2,0,0,0,0,0,176,192,4,0,208,160,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,10,0,16,0,0,0,0,0,0,0,0,0,0,196,42,0,0,252,33,0,0,0,0,0,0,0,0,0,0,46,49,0,0,120,17,0,0,76,15,0,0,108,13,0,0,240,15,0,0,166,8,0,0,248,24,0,0,40,174,145,0,0,8,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,20,3,0,200,167,7,0,0,0,0,0,0,0,0,0,184,168,7,0,200,108,2,0,0,0,0,0,168,95,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,3,4,0,0,0,0,0,0,0,0,0,0,0,52,29,0,0,214,42,0,0,0,0,0,0,0,0,0,0,58,21,0,0,112,36,0,0,194,17,0,0,118,2,0,0,218,11,0,0,118,8,0,0,100,39,0,0,80,176,145,0,0,2,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,246,1,0,200,167,7,0,0,0,0,0,0,0,0,0,184,168,7,0,160,149,1,0,0,0,0,0,168,95,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,3,4,0,0,0,0,0,0,0,0,0,0,0,116,19,0,0,122,25,0,0,0,0,0,0,0,0,0,0,58,21,0,0,112,36,0,0,194,17,0,0,118,2,0,0,218,11,0,0,118,8,0,0,100,39,0,0,80,176,145,0,0,2,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,167,7,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,32,164,6,0,0,0,0,0,168,95,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,4,0,0,0,0,0,0,3,4,0,0,0,0,0,0,0,0,0,0,0,96,14,0,0,104,6,0,0,0,0,0,0,0,0,0,0,254,21,0,0,150,37,0,0,194,17,0,0,118,2,0,0,218,11,0,0,118,8,0,0,100,39,0,0,80,176,145,0,0,2,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,129,5,0,176,203,5,0,0,0,0,0,0,0,0,0,184,168,7,0,224,100,5,0,0,0,0,0,128,161,4,0,168,196,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,5,11,0,8,0,0,0,0,0,0,0,0,0,0,74,62,0,0,18,27,0,0,0,0,0,0,0,0,0,0,184,15,0,0,10,45,0,0,30,11,0,0,178,11,0,0,82,0,0,0,238,10,0,0,188,1,0,0,0,0,0,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,69,5,0,176,203,5,0,0,0,0,0,0,0,0,0,184,168,7,0,168,38,5,0,0,0,0,0,144,84,8,0,168,196,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,5,11,0,8,0,0,0,0,0,0,0,0,0,0,90,29,0,0,20,34,0,0,0,0,0,0,0,0,0,0,184,15,0,0,212,41,0,0,30,11,0,0,178,11,0,0,82,0,0,0,238,10,0,0,188,1,0,0,0,0,0,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,203,5,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,160,162,5,0,0,0,0,0,168,183,7,0,168,196,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,5,11,0,8,0,0,0,0,0,0,0,0,0,0,92,31,0,0,142,34,0,0,0,0,0,0,0,0,0,0,184,15,0,0,136,30,0,0,30,11,0,0,178,11,0,0,82,0,0,0,238,10,0,0,188,1,0,0,0,0,0,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,210,7,0,0,0,0,0,0,0,0,0,0,0,0,0,168,163,7,0,160,198,7,0,0,0,0,0,224,207,5,0,0,227,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,21,0,0,1,0,0,0,0,0,0,0,0,0,64,33,0,0,250,40,0,0,0,0,0,0,0,0,0,0,0,58,0,0,72,21,0,0,60,18,0,0,248,19,0,0,196,9,0,0,56,10,0,0,96,10,0,0,224,174,145,0,0,18,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,253,1,0,128,109,8,0,0,0,0,0,0,0,0,0,104,174,7,0,32,156,1,0,0,0,0,0,168,95,8,0,16,5,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,3,0,0,8,0,0,0,0,0,0,0,0,0,242,46,0,0,30,35,0,0,0,0,0,0,0,0,0,0,110,19,0,0,82,41,0,0,54,12,0,0,196,15,0,0,0,3,0,0,136,9,0,0,246,39,0,0,16,177,145,0,0,4,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,48,52,3,0,144,84,3,0,0,0,0,0,0,0,0,0,168,163,7,0,72,49,3,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,0,29,0,0,68,10,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,132,2,0,144,84,3,0,0,0,0,0,0,0,0,0,168,163,7,0,8,131,2,0,0,0,0,0,192,154,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,184,20,0,0,210,22,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,202,14,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,56,3,0,144,84,3,0,0,0,0,0,0,0,0,0,168,163,7,0,128,54,3,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,134,38,0,0,202,44,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,81,3,0,144,84,3,0,0,0,0,0,0,0,0,0,168,163,7,0,160,79,3,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,124,49,0,0,34,46,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,59,3,0,144,84,3,0,0,0,0,0,0,0,0,0,168,163,7,0,128,58,3,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,76,32,0,0,190,45,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,61,3,0,144,84,3,0,0,0,0,0,0,0,0,0,168,163,7,0,192,59,3,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,156,48,0,0,30,41,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,63,3,0,144,84,3,0,0,0,0,0,0,0,0,0,168,163,7,0,208,61,3,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,22,34,0,0,50,3,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,67,3,0,144,84,3,0,0,0,0,0,0,0,0,0,168,163,7,0,16,65,3,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,170,51,0,0,44,2,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,69,3,0,144,84,3,0,0,0,0,0,0,0,0,0,168,163,7,0,104,68,3,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,142,11,0,0,122,8,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,72,3,0,144,84,3,0,0,0,0,0,0,0,0,0,168,163,7,0,160,70,3,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,16,45,0,0,22,42,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,73,3,0,144,84,3,0,0,0,0,0,0,0,0,0,168,163,7,0,240,72,3,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,44,19,0,0,52,14,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,77,3,0,144,84,3,0,0,0,0,0,0,0,0,0,168,163,7,0,136,74,3,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,124,4,0,0,36,34,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,84,3,0,0,0,0,0,0,0,0,0,0,0,0,0,168,163,7,0,40,83,3,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,36,44,0,0,154,33,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,86,3,0,56,132,3,0,0,0,0,0,0,0,0,0,32,127,5,0,88,85,3,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,0,0,0,0,0,0,0,0,210,62,0,0,120,0,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,254,1,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,133,2,0,56,132,3,0,0,0,0,0,0,0,0,0,32,127,5,0,176,132,2,0,0,0,0,0,192,154,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,0,0,0,0,0,0,0,0,38,25,0,0,160,40,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,202,14,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,128,3,0,56,132,3,0,0,0,0,0,0,0,0,0,32,127,5,0,160,126,3,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,0,0,0,0,0,0,0,0,176,47,0,0,108,15,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,254,1,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,88,3,0,56,132,3,0,0,0,0,0,0,0,0,0,0,38,7,0,32,87,3,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,0,0,0,0,0,0,0,0,190,6,0,0,108,0,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,254,1,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,91,3,0,56,132,3,0,0,0,0,0,0,0,0,0,0,38,7,0,152,89,3,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,0,0,0,0,0,0,0,0,200,37,0,0,118,43,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,254,1,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,97,3,0,56,132,3,0,0,0,0,0,0,0,0,0,0,38,7,0,40,94,3,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,0,0,0,0,0,0,0,0,178,33,0,0,188,15,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,254,1,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,102,3,0,56,132,3,0,0,0,0,0,0,0,0,0,0,38,7,0,40,99,3,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,0,0,0,0,0,0,0,0,186,10,0,0,110,5,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,254,1,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,105,3,0,56,132,3,0,0,0,0,0,0,0,0,0,0,38,7,0,64,103,3,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,0,0,0,0,0,0,0,0,116,53,0,0,20,42,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,254,1,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,108,3,0,56,132,3,0,0,0,0,0,0,0,0,0,32,127,5,0,216,106,3,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,0,0,0,0,0,0,0,0,198,28,0,0,96,16,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,254,1,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,113,3,0,56,132,3,0,0,0,0,0,0,0,0,0,32,127,5,0,8,111,3,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,0,0,0,0,0,0,0,0,196,0,0,0,48,36,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,254,1,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,119,3,0,56,132,3,0,0,0,0,0,0,0,0,0,32,127,5,0,48,117,3,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,0,0,0,0,0,0,0,0,10,13,0,0,228,12,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,254,1,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,124,3,0,56,132,3,0,0,0,0,0,0,0,0,0,32,127,5,0,16,122,3,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,0,0,0,0,0,0,0,0,64,14,0,0,40,38,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,254,1,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,132,3,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,144,130,3,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,0,0,0,0,0,0,0,0,188,48,0,0,218,40,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,254,1,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,61,7,0,192,176,8,0,0,0,0,0,0,0,0,0,144,47,2,0,200,16,7,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,1,0,2,0,0,0,0,0,0,0,0,0,0,70,46,0,0,156,30,0,0,0,0,0,0,0,0,0,0,50,46,0,0,162,29,0,0,170,15,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,61,3,0,200,67,3,0,0,0,0,0,0,0,0,0,96,135,2,0,16,60,3,0,0,0,0,0,192,223,4,0,96,103,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,3,0,0,0,0,0,2,1,4,0,0,0,0,0,0,0,0,0,0,0,68,41,0,0,112,27,0,0,0,0,0,0,0,0,0,0,70,25,0,0,242,28,0,0,44,13,0,0])
.concat([100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,230,2,0,200,67,3,0,0,0,0,0,0,0,0,0,96,135,2,0,224,228,2,0,120,155,4,0,192,154,4,0,160,229,3,0,136,225,2,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,3,0,0,0,0,0,1,1,4,0,0,0,0,0,0,0,0,0,0,0,82,20,0,0,0,15,0,0,0,0,0,0,0,0,0,0,56,40,0,0,0,0,0,0,76,12,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,238,2,0,200,67,3,0,0,0,0,0,0,0,0,0,96,135,2,0,112,235,2,0,0,0,0,0,192,154,4,0,160,229,3,0,16,232,2,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,3,0,0,0,0,0,1,1,4,0,0,0,0,0,0,0,0,0,0,0,124,61,0,0,162,6,0,0,0,0,0,0,0,0,0,0,118,49,0,0,142,6,0,0,54,4,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,246,2,0,200,67,3,0,0,0,0,0,0,0,0,0,96,135,2,0,152,243,2,0,0,0,0,0,192,154,4,0,160,229,3,0,192,240,2,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,3,0,0,0,0,0,1,1,4,0,0,0,0,0,0,0,0,0,0,0,126,51,0,0,156,36,0,0,0,0,0,0,0,0,0,0,118,49,0,0,142,6,0,0,54,4,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,64,3,0,200,67,3,0,0,0,0,0,0,0,0,0,96,135,2,0,224,62,3,0,0,0,0,0,192,223,4,0,96,103,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,3,0,0,0,0,0,2,1,4,0,0,0,0,0,0,0,0,0,0,0,190,24,0,0,42,37,0,0,0,0,0,0,0,0,0,0,70,25,0,0,242,28,0,0,44,13,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,220,2,0,200,67,3,0,0,0,0,0,0,0,0,0,96,135,2,0,240,217,2,0,0,0,0,0,144,88,7,0,96,103,2,0,184,213,2,0,0,0,0,0,0,0,0,0,0,0,0,0,17,1,0,0,3,0,0,0,0,0,2,1,4,0,0,0,0,0,0,0,0,0,0,0,54,61,0,0,112,33,0,0,0,0,0,0,0,0,0,0,70,25,0,0,242,28,0,0,44,13,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,59,3,0,200,67,3,0,0,0,0,0,0,0,0,0,96,135,2,0,192,58,3,0,0,0,0,0,192,223,4,0,96,103,2,0,40,57,3,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,3,0,0,0,0,0,2,1,4,0,0,0,0,0,0,0,0,0,0,0,206,47,0,0,64,46,0,0,0,0,0,0,0,0,0,0,70,25,0,0,242,28,0,0,44,13,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,41,3,0,200,67,3,0,0,0,0,0,0,0,0,0,96,135,2,0,248,40,3,0,0,0,0,0,192,154,4,0,160,229,3,0,40,39,3,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,3,0,0,0,0,0,1,1,4,0,0,0,0,0,0,0,0,0,0,0,208,40,0,0,242,16,0,0,0,0,0,0,0,0,0,0,74,45,0,0,214,4,0,0,44,13,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,31,3,0,200,67,3,0,0,0,0,0,0,0,0,0,96,135,2,0,88,28,3,0,0,0,0,0,192,154,4,0,160,229,3,0,168,21,3,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,3,0,0,0,0,0,1,1,4,0,0,0,0,0,0,0,0,0,0,0,214,24,0,0,2,17,0,0,0,0,0,0,0,0,0,0,118,49,0,0,190,1,0,0,34,19,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,38,3,0,200,67,3,0,0,0,0,0,0,0,0,0,96,135,2,0,0,37,3,0,0,0,0,0,192,154,4,0,160,229,3,0,240,32,3,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,3,0,0,0,0,0,1,1,4,0,0,0,0,0,0,0,0,0,0,0,220,27,0,0,74,14,0,0,0,0,0,0,0,0,0,0,118,49,0,0,190,1,0,0,34,19,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,48,3,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,72,46,3,0,0,0,0,0,192,223,4,0,208,164,3,0,96,42,3,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,3,0,0,0,0,0,4,1,4,0,0,0,0,0,0,0,0,0,0,0,116,49,0,0,0,6,0,0,0,0,0,0,0,0,0,0,208,16,0,0,0,0,0,0,16,9,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,224,2,0,200,67,3,0,0,0,0,0,0,0,0,0,96,135,2,0,248,222,2,0,0,0,0,0,192,154,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,3,0,0,0,0,0,1,1,4,0,0,0,0,0,0,0,0,0,0,0,92,63,0,0,54,15,0,0,0,0,0,0,0,0,0,0,70,25,0,0,242,28,0,0,62,19,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,201,2,0,200,67,3,0,0,0,0,0,0,0,0,0,96,135,2,0,56,200,2,0,0,0,0,0,144,88,7,0,96,103,2,0,72,197,2,0,0,0,0,0,0,0,0,0,0,0,0,0,17,1,0,0,3,0,0,0,0,0,2,1,4,0,0,0,0,0,0,0,0,0,0,0,174,8,0,0,72,13,0,0,0,0,0,0,0,0,0,0,70,25,0,0,242,28,0,0,44,13,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,206,2,0,200,67,3,0,0,0,0,0,0,0,0,0,96,135,2,0,32,205,2,0,0,0,0,0,144,88,7,0,96,103,2,0,72,203,2,0,0,0,0,0,0,0,0,0,0,0,0,0,17,1,0,0,3,0,0,0,0,0,2,1,4,0,0,0,0,0,0,0,0,0,0,0,148,59,0,0,168,3,0,0,0,0,0,0,0,0,0,0,70,25,0,0,242,28,0,0,44,13,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,211,2,0,200,67,3,0,0,0,0,0,0,0,0,0,96,135,2,0,176,209,2,0,0,0,0,0,144,88,7,0,96,103,2,0,88,207,2,0,0,0,0,0,0,0,0,0,0,0,0,0,17,1,0,0,3,0,0,0,0,0,2,1,4,0,0,0,0,0,0,0,0,0,0,0,244,3,0,0,88,3,0,0,0,0,0,0,0,0,0,0,70,25,0,0,242,28,0,0,44,13,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,56,3,0,200,67,3,0,0,0,0,0,0,0,0,0,96,135,2,0,0,53,3,0,0,0,0,0,192,223,4,0,96,103,2,0,80,50,3,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,3,0,0,0,0,0,2,1,4,0,0,0,0,0,0,0,0,0,0,0,250,23,0,0,254,9,0,0,0,0,0,0,0,0,0,0,70,25,0,0,242,28,0,0,44,13,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,251,2,0,200,67,3,0,0,0,0,0,0,0,0,0,96,135,2,0,72,250,2,0,0,0,0,0,192,154,4,0,160,229,3,0,224,247,2,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,3,0,0,0,0,0,1,1,4,0,0,0,0,0,0,0,0,0,0,0,2,28,0,0,112,19,0,0,0,0,0,0,0,0,0,0,118,49,0,0,142,6,0,0,188,4,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,1,3,0,200,67,3,0,0,0,0,0,0,0,0,0,96,135,2,0,32,255,2,0,0,0,0,0,192,154,4,0,160,229,3,0,32,252,2,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,3,0,0,0,0,0,1,1,4,0,0,0,0,0,0,0,0,0,0,0,96,37,0,0,74,18,0,0,0,0,0,0,0,0,0,0,118,49,0,0,142,6,0,0,188,4,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,8,3,0,200,67,3,0,0,0,0,0,0,0,0,0,96,135,2,0,32,7,3,0,0,0,0,0,192,154,4,0,160,229,3,0,96,3,3,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,3,0,0,0,0,0,1,1,4,0,0,0,0,0,0,0,0,0,0,0,106,21,0,0,120,8,0,0,0,0,0,0,0,0,0,0,140,40,0,0,166,30,0,0,112,18,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,15,3,0,200,67,3,0,0,0,0,0,0,0,0,0,96,135,2,0,88,14,3,0,0,0,0,0,192,154,4,0,160,229,3,0,72,12,3,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,3,0,0,0,0,0,1,1,4,0,0,0,0,0,0,0,0,0,0,0,24,4,0,0,238,42,0,0,0,0,0,0,0,0,0,0,140,40,0,0,254,24,0,0,60,7,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,67,3,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,40,66,3,0,0,0,0,0,192,223,4,0,96,103,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,3,0,0,0,0,0,2,1,4,0,0,0,0,0,0,0,0,0,0,0,54,25,0,0,90,5,0,0,0,0,0,0,0,0,0,0,70,25,0,0,242,28,0,0,44,13,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,72,3,0,248,73,3,0,0,0,0,0,0,0,0,0,184,168,7,0,24,71,3,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,1,0,8,0,0,0,0,0,0,0,0,0,0,10,26,0,0,222,31,0,0,0,0,0,0,0,0,0,0,138,10,0,0,92,17,0,0,170,15,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,70,3,0,248,73,3,0,0,0,0,0,0,0,0,0,184,168,7,0,48,69,3,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,1,0,8,0,0,0,0,0,0,0,0,0,0,14,59,0,0,108,9,0,0,0,0,0,0,0,0,0,0,138,10,0,0,92,17,0,0,170,15,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,73,3,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,56,73,3,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,1,0,8,0,0,0,0,0,0,0,0,0,0,148,30,0,0,202,11,0,0,0,0,0,0,0,0,0,0,138,10,0,0,92,17,0,0,170,15,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,143,3,0,104,163,3,0,0,0,0,0,0,0,0,0,184,12,8,0,136,140,3,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,8,0,0,0,0,0,0,0,12,26,0,0,76,19,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,149,3,0,104,163,3,0,0,0,0,0,0,0,0,0,184,12,8,0,192,146,3,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,8,0,0,0,0,0,0,0,210,39,0,0,48,1,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,153,3,0,104,163,3,0,0,0,0,0,0,0,0,0,184,12,8,0,224,151,3,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,8,0,0,0,0,0,0,0,16,51,0,0,130,26,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,140,2,0,104,163,3,0,0,0,0,0,0,0,0,0,184,12,8,0,32,139,2,0,0,0,0,0,192,154,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,8,0,0,0,0,0,0,0,76,1,0,0,136,37,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,202,14,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,157,3,0,104,163,3,0,0,0,0,0,0,0,0,0,184,12,8,0,224,155,3,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,8,0,0,0,0,0,0,0,118,3,0,0,204,21,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,135,2,0,80,137,3,0,0,0,0,0,0,0,0,0,184,12,8,0,40,134,2,0,0,0,0,0,192,154,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,8,0,0,0,0,0,0,0,210,55,0,0,156,20,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,202,14,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,137,3,0,0,0,0,0,0,0,0,0,0,0,0,0,184,12,8,0,176,133,3,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,8,0,0,0,0,0,0,0,22,15,0,0,50,34,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,163,3,0,0,0,0,0,0,0,0,0,0,0,0,0,184,12,8,0,48,159,3,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,8,0,0,0,0,0,0,0,220,36,0,0,252,21,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,142,5,0,136,201,5,0,0,0,0,0,0,0,0,0,32,127,5,0,232,138,5,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,8,0,0,0,0,0,0,0,52,19,0,0,50,29,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,154,5,0,136,201,5,0,0,0,0,0,0,0,0,0,32,127,5,0,192,151,5,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,8,0,0,0,0,0,0,0,88,14,0,0,80,41,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,147,5,0,136,201,5,0,0,0,0,0,0,0,0,0,32,127,5,0,48,146,5,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,8,0,0,0,0,0,0,0,252,53,0,0,130,17,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,160,5,0,136,201,5,0,0,0,0,0,0,0,0,0,32,127,5,0,80,156,5,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,8,0,0,0,0,0,0,0,50,2,0,0,62,18,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,169,3,0,64,174,3,0,0,0,0,0,0,0,0,0,184,12,8,0,8,166,3,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,8,0,0,0,0,0,0,0,30,60,0,0,216,26,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,137,2,0,64,174,3,0,0,0,0,0,0,0,0,0,184,12,8,0,120,135,2,0,0,0,0,0,192,154,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,8,0,0,0,0,0,0,0,12,25,0,0,44,36,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,202,14,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,174,3,0,0,0,0,0,0,0,0,0,0,0,0,0,184,12,8,0,136,171,3,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,8,0,0,0,0,0,0,0,156,12,0,0,110,47,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,80,3,0,136,87,3,0,0,0,0,0,0,0,0,0,96,135,2,0,104,78,3,0,0,0,0,0,104,224,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,1,1,2,0,0,0,0,0,0,0,0,0,0,0,188,49,0,0,34,34,0,0,0,0,0,0,0,0,0,0,138,42,0,0,50,33,0,0,44,13,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,224,0,0,0,128,1,0,0,3,0,0,0,4,0,0,0,40,86,3,0,136,87,3,0,0,0,0,0,0,0,0,0,96,135,2,0,208,84,3,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,1,1,2,0,0,0,0,0,0,0,0,0,0,0,38,9,0,0,20,38,0,0,0,0,0,0,0,0,0,0,138,42,0,0,50,33,0,0,44,13,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,224,0,0,0,128,1,0,0,3,0,0,0,4,0,0,0,40,84,3,0,136,87,3,0,0,0,0,0,0,0,0,0,96,135,2,0,232,81,3,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,1,1,2,0,0,0,0,0,0,0,0,0,0,0,122,37,0,0,234,29,0,0,0,0,0,0,0,0,0,0,138,42,0,0,50,33,0,0,44,13,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,224,0,0,0,128,1,0,0,3,0,0,0,4,0,0,0,136,87,3,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,176,86,3,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,1,1,2,0,0,0,0,0,0,0,0,0,0,0,144,1,0,0,96,3,0,0,0,0,0,0,0,0,0,0,138,42,0,0,50,33,0,0,44,13,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,224,0,0,0,128,1,0,0,3,0,0,0,4,0,0,0,32,239,7,0,24,63,8,0,0,0,0,0,0,0,0,0,0,38,7,0,248,232,7,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,8,0,0,0,0,0,0,0,220,48,0,0,150,17,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,254,7,0,24,63,8,0,0,0,0,0,0,0,0,0,0,38,7,0,88,247,7,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,8,0,0,0,0,0,0,0,164,10,0,0,96,22,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,11,8,0,24,63,8,0,0,0,0,0,0,0,0,0,0,38,7,0,104,4,8,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,8,0,0,0,0,0,0,0,100,19,0,0,162,31,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,105,3,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,72,104,3,0,0,0,0,0,176,102,3,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,1,1,0,0,0,0,0,0,0,0,0,0,0,114,54,0,0,240,4,0,0,0,0,0,0,0,0,0,0,252,61,0,0,244,50,0,0,170,15,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,175,7,0,208,228,7,0,0,0,0,0,0,0,0,0,240,3,2,0,184,170,7,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,1,0,0,0,0,0,0,0,0,0,0,0,88,59,0,0,204,22,0,0,0,0,0,0,0,0,0,0,104,50,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,125,3,0,16,130,3,0,0,0,0,0,0,0,0,0,184,168,7,0,176,123,3,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,1,0,8,0,0,0,0,0,0,0,0,0,0,244,22,0,0,72,23,0,0,0,0,0,0,0,0,0,0,22,6,0,0,114,36,0,0,2,4,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,120,3,0,16,130,3,0,0,0,0,0,0,0,0,0,184,168,7,0,248,118,3,0,0,0,0,0,192,223,4,0,160,229,3,0,112,115,3,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,1,0,8,0,0,0,0,0,0,0,0,0,0,102,38,0,0,82,28,0,0,0,0,0,0,0,0,0,0,22,6,0,0,6,17,0,0,120,13,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,112,3,0,16,130,3,0,0,0,0,0,0,0,0,0,184,168,7,0,200,109,3,0,0,0,0,0,192,223,4,0,160,229,3,0,192,107,3,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,1,0,8,0,0,0,0,0,0,0,0,0,0,114,60,0,0,248,11,0,0,0,0,0,0,0,0,0,0,22,6,0,0,6,17,0,0,118,12,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,130,3,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,40,128,3,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,1,0,8,0,0,0,0,0,0,0,0,0,0,18,6,0,0,206,44,0,0,0,0,0,0,0,0,0,0,22,6,0,0,6,17,0,0,2,4,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,177,3,0,240,204,3,0,0,0,0,0,0,0,0,0,0,38,7,0,128,175,3,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,174,24,0,0,230,0,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,158,6,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,143,2,0,240,204,3,0,0,0,0,0,0,0,0,0,0,38,7,0,200,141,2,0,0,0,0,0,192,154,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,34,28,0,0,182,38,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,86,17,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,182,3,0,240,204,3,0,0,0,0,0,0,0,0,0,0,38,7,0,8,180,3,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,194,47,0,0,234,1,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,158,6,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,152,2,0,120,28,4,0,0,0,0,0,0,0,0,0,240,3,2,0,192,150,2,0,0,0,0,0,192,154,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,20,12,0,0,234,8,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,248,14,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,240,3,0,120,28,4,0,0,0,0,0,0,0,0,0,240,3,2,0,208,236,3,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,66,3,0,0,96,40,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,210,16,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,188,3,0,240,204,3,0,0,0,0,0,0,0,0,0,0,38,7,0,224,184,3,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,184,49,0,0,142,5,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,158,6,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,195,3,0,240,204,3,0,0,0,0,0,0,0,0,0,0,38,7,0,152,191,3,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,242,58,0,0,138,4,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,158,6,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,146,2,0,240,204,3,0,0,0,0,0,0,0,0,0,0,38,7,0,208,145,2,0,0,0,0,0,192,154,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,112,31,0,0,34,14,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,86,17,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,225,3,0,120,28,4,0,0,0,0,0,0,0,0,0,240,3,2,0,144,221,3,0,248,227,3,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,204,55,0,0,154,26,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,104,15,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,217,3,0,120,28,4,0,0,0,0,0,0,0,0,0,240,3,2,0,216,211,3,0,248,227,3,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,222,46,0,0,54,26,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,104,15,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,209,3,0,120,28,4,0,0,0,0,0,0,0,0,0,240,3,2,0,248,206,3,0,248,227,3,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,122,12,0,0,84,35,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,104,15,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,149,2,0,120,28,4,0,0,0,0,0,0,0,0,0,240,3,2,0,48,147,2,0,248,227,3,0,192,154,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,4,53,0,0,42,19,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,86,13,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,234,3,0,120,28,4,0,0,0,0,0,0,0,0,0,240,3,2,0,160,232,3,0,248,227,3,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,116,17,0,0,128,25,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,104,15,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,145,2,0,240,204,3,0,0,0,0,0,0,0,0,0,0,38,7,0,40,144,2,0,0,0,0,0,192,154,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,166,20,0,0,198,17,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,86,17,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,201,3,0,240,204,3,0,0,0,0,0,0,0,0,0,0,38,7,0,160,197,3,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,36,56,0,0,56,3,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,158,6,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,204,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,248,202,3,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,12,4,0,0,118,31,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,158,6,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,246,3,0,120,28,4,0,0,0,0,0,0,0,0,0,240,3,2,0,120,242,3,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,216,62,0,0,234,10,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,210,16,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,253,3,0,120,28,4,0,0,0,0,0,0,0,0,0,240,3,2,0,56,250,3,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,140,1,0,0,208,36,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,210,16,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,5,4,0,120,28,4,0,0,0,0,0,0,0,0,0,240,3,2,0,16,3,4,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,52,45,0,0,150,5,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,210,16,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,13,4,0,120,28,4,0,0,0,0,0,0,0,0,0,240,3,2,0,176,10,4,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,160,41,0,0,102,18,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,210,16,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0])
.concat([160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,155,2,0,120,28,4,0,0,0,0,0,0,0,0,0,240,3,2,0,200,154,2,0,0,0,0,0,192,154,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,36,1,0,0,124,34,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,248,14,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,17,4,0,120,28,4,0,0,0,0,0,0,0,0,0,240,3,2,0,64,15,4,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,118,40,0,0,6,37,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,210,16,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,21,4,0,120,28,4,0,0,0,0,0,0,0,0,0,240,3,2,0,56,19,4,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,104,8,0,0,18,44,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,210,16,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,28,4,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,168,24,4,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,122,40,0,0,112,5,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,210,16,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,158,2,0,0,49,4,0,0,0,0,0,0,0,0,0,168,163,7,0,248,156,2,0,0,0,0,0,192,154,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,7,0,16,0,0,2,0,0,0,0,0,0,0,116,39,0,0,102,31,0,0,0,0,0,0,0,0,0,0,248,34,0,0,0,0,0,0,202,14,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,43,4,0,0,49,4,0,0,0,0,0,0,0,0,0,168,163,7,0,152,41,4,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,0,16,0,0,2,0,0,0,0,0,0,0,128,23,0,0,232,1,0,0,0,0,0,0,0,0,0,0,248,34,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,33,4,0,0,49,4,0,0,0,0,0,0,0,0,0,168,163,7,0,176,31,4,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,0,16,0,0,2,0,0,0,0,0,0,0,18,54,0,0,200,26,0,0,0,0,0,0,0,0,0,0,248,34,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,159,2,0,0,49,4,0,0,0,0,0,0,0,0,0,168,163,7,0,192,158,2,0,0,0,0,0,192,154,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,7,0,16,0,0,2,0,0,0,0,0,0,0,118,39,0,0,8,6,0,0,0,0,0,0,0,0,0,0,248,34,0,0,0,0,0,0,202,14,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,39,4,0,0,49,4,0,0,0,0,0,0,0,0,0,168,163,7,0,88,37,4,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,0,16,0,0,2,0,0,0,0,0,0,0,246,28,0,0,108,24,0,0,0,0,0,0,0,0,0,0,248,34,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,49,4,0,0,0,0,0,0,0,0,0,0,0,0,0,168,163,7,0,224,45,4,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,7,0,16,0,0,2,0,0,0,0,0,0,0,26,24,0,0,150,31,0,0,0,0,0,0,0,0,0,0,248,34,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,67,5,0,152,82,5,0,0,0,0,0,0,0,0,0,0,38,7,0,168,65,5,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,0,0,0,0,0,0,0,0,236,42,0,0,148,46,0,0,0,0,0,0,0,0,0,0,72,60,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,76,5,0,152,82,5,0,0,0,0,0,0,0,0,0,0,38,7,0,80,72,5,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,0,0,0,0,0,0,0,0,94,34,0,0,176,47,0,0,0,0,0,0,0,0,0,0,72,60,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,135,3,0,104,161,3,0,0,0,0,0,0,0,0,0,240,3,2,0,32,133,3,0,24,163,4,0,192,154,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,4,0,0,0,0,0,1,1,8,0,0,0,0,0,0,0,0,0,0,0,16,47,0,0,94,46,0,0,0,0,0,0,0,0,0,0,158,36,0,0,154,21,0,0,10,0,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,156,3,0,104,161,3,0,0,0,0,0,0,0,0,0,240,3,2,0,208,154,3,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,1,1,8,0,0,0,0,0,0,0,0,0,0,0,90,21,0,0,190,40,0,0,0,0,0,0,0,0,0,0,158,36,0,0,154,21,0,0,44,13,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,161,3,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,40,158,3,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,4,0,0,0,0,0,1,1,8,0,0,0,0,0,0,0,0,0,0,0,142,55,0,0,100,32,0,0,0,0,0,0,0,0,0,0,158,36,0,0,154,21,0,0,44,13,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,20,3,0,200,67,3,0,0,0,0,0,0,0,0,0,96,135,2,0,160,18,3,0,0,0,0,0,192,154,4,0,160,229,3,0,192,16,3,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,3,0,0,0,0,0,1,1,4,0,0,0,0,0,0,0,0,0,0,0,80,49,0,0,38,37,0,0,0,0,0,0,0,0,0,0,118,49,0,0,190,1,0,0,230,2,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,56,4,0,8,72,4,0,0,0,0,0,0,0,0,0,184,12,8,0,0,53,4,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,70,28,0,0,20,47,0,0,0,0,0,0,0,0,0,0,204,58,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,163,2,0,8,72,4,0,0,0,0,0,0,0,0,0,184,12,8,0,120,160,2,0,0,0,0,0,192,154,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,190,35,0,0,110,22,0,0,0,0,0,0,0,0,0,0,204,58,0,0,0,0,0,0,202,14,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,63,4,0,8,72,4,0,0,0,0,0,0,0,0,0,184,12,8,0,32,60,4,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,164,23,0,0,54,14,0,0,0,0,0,0,0,0,0,0,204,58,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,72,4,0,0,0,0,0,0,0,0,0,0,0,0,0,184,12,8,0,80,70,4,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,8,15,0,0,212,15,0,0,0,0,0,0,0,0,0,0,204,58,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,226,4,0,136,58,5,0,0,0,0,0,0,0,0,0,32,127,5,0,152,223,4,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,240,58,0,0,196,12,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,236,4,0,136,58,5,0,0,0,0,0,0,0,0,0,32,127,5,0,8,232,4,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,8,20,0,0,238,46,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,242,4,0,136,58,5,0,0,0,0,0,0,0,0,0,32,127,5,0,216,239,4,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,4,11,0,0,208,16,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,250,4,0,136,58,5,0,0,0,0,0,0,0,0,0,32,127,5,0,0,248,4,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,210,5,0,0,10,48,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,0,5,0,136,58,5,0,0,0,0,0,0,0,0,0,32,127,5,0,216,253,4,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,198,4,0,0,190,38,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,170,3,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,40,168,3,0,0,0,0,0,192,223,4,0,208,164,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,4,1,8,0,0,0,2,0,0,0,0,0,0,0,248,6,0,0,22,28,0,0,0,0,0,0,0,0,0,0,64,22,0,0,0,0,0,0,220,15,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,6,5,0,136,58,5,0,0,0,0,0,0,0,0,0,32,127,5,0,192,3,5,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,10,30,0,0,186,45,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,15,5,0,136,58,5,0,0,0,0,0,0,0,0,0,32,127,5,0,120,10,5,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,34,55,0,0,76,47,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,21,5,0,136,58,5,0,0,0,0,0,0,0,0,0,32,127,5,0,112,18,5,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,234,18,0,0,32,35,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,27,5,0,136,58,5,0,0,0,0,0,0,0,0,0,32,127,5,0,168,24,5,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,162,34,0,0,132,42,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,166,2,0,96,128,4,0,0,0,0,0,0,0,0,0,192,177,6,0,240,164,2,0,0,0,0,0,192,154,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,18,0,0,0,94,8,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,202,14,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,75,4,0,96,128,4,0,0,0,0,0,0,0,0,0,192,177,6,0,56,74,4,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,12,24,0,0,252,16,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,83,4,0,96,128,4,0,0,0,0,0,0,0,0,0,192,177,6,0,224,78,4,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,248,21,0,0,112,25,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,89,4,0,96,128,4,0,0,0,0,0,0,0,0,0,192,177,6,0,136,86,4,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,98,7,0,0,114,46,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,95,4,0,96,128,4,0,0,0,0,0,0,0,0,0,192,177,6,0,160,93,4,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,214,15,0,0,168,33,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,98,4,0,96,128,4,0,0,0,0,0,0,0,0,0,192,177,6,0,200,96,4,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,234,58,0,0,250,23,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,159,4,0,40,220,4,0,0,0,0,0,0,0,0,0,168,163,7,0,184,156,4,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,118,36,0,0,126,22,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,168,4,0,40,220,4,0,0,0,0,0,0,0,0,0,168,163,7,0,240,162,4,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,84,0,0,0,160,37,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,174,2,0,40,220,4,0,0,0,0,0,0,0,0,0,168,163,7,0,160,173,2,0,0,0,0,0,192,154,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,166,34,0,0,146,39,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,202,14,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,175,4,0,40,220,4,0,0,0,0,0,0,0,0,0,168,163,7,0,176,171,4,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,132,4,0,0,120,24,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,181,4,0,40,220,4,0,0,0,0,0,0,0,0,0,168,163,7,0,96,179,4,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,192,40,0,0,34,20,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,185,4,0,40,220,4,0,0,0,0,0,0,0,0,0,168,163,7,0,112,183,4,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,204,61,0,0,10,15,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,190,4,0,40,220,4,0,0,0,0,0,0,0,0,0,168,163,7,0,128,188,4,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,12,19,0,0,168,7,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,136,4,0,112,154,4,0,0,0,0,0,0,0,0,0,168,163,7,0,184,132,4,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,22,10,0,0,90,32,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,143,4,0,112,154,4,0,0,0,0,0,0,0,0,0,168,163,7,0,56,140,4,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,222,2,0,0,166,32,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,173,2,0,112,154,4,0,0,0,0,0,0,0,0,0,168,163,7,0,248,171,2,0,0,0,0,0,192,154,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,242,3,0,0,28,2,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,202,14,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,149,4,0,112,154,4,0,0,0,0,0,0,0,0,0,168,163,7,0,104,147,4,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,76,55,0,0,168,20,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,154,4,0,0,0,0,0,0,0,0,0,0,0,0,0,168,163,7,0,208,151,4,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,226,30,0,0,102,15,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,177,2,0,40,220,4,0,0,0,0,0,0,0,0,0,168,163,7,0,56,175,2,0,0,0,0,0,192,154,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,94,8,0,0,224,20,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,202,14,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,199,4,0,40,220,4,0,0,0,0,0,0,0,0,0,168,163,7,0,56,195,4,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,84,42,0,0,226,33,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,181,2,0,136,58,5,0,0,0,0,0,0,0,0,0,32,127,5,0,160,179,2,0,0,0,0,0,192,154,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,110,26,0,0,90,44,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,202,14,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,31,5,0,136,58,5,0,0,0,0,0,0,0,0,0,32,127,5,0,24,29,5,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,102,52,0,0,178,10,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,36,5,0,136,58,5,0,0,0,0,0,0,0,0,0,32,127,5,0,80,33,5,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,176,2,0,0,200,20,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,44,5,0,136,58,5,0,0,0,0,0,0,0,0,0,32,127,5,0,104,40,5,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,20,37,0,0,206,13,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,52,5,0,136,58,5,0,0,0,0,0,0,0,0,0,32,127,5,0,112,48,5,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,58,23,0,0,154,21,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,183,2,0,136,58,5,0,0,0,0,0,0,0,0,0,32,127,5,0,72,182,2,0,0,0,0,0,192,154,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,232,41,0,0,198,13,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,202,14,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,101,4,0,96,128,4,0,0,0,0,0,0,0,0,0,192,177,6,0,128,100,4,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,96,40,0,0,254,11,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,170,2,0,96,128,4,0,0,0,0,0,0,0,0,0,192,177,6,0,248,168,2,0,0,0,0,0,192,154,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,226,26,0,0,242,32,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,202,14,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,108,4,0,96,128,4,0,0,0,0,0,0,0,0,0,192,177,6,0,152,105,4,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,150,58,0,0,44,25,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,114,4,0,96,128,4,0,0,0,0,0,0,0,0,0,192,177,6,0,24,112,4,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,94,1,0,0,72,31,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,120,4,0,96,128,4,0,0,0,0,0,0,0,0,0,192,177,6,0,168,117,4,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,150,50,0,0,218,17,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,124,4,0,96,128,4,0,0,0,0,0,0,0,0,0,192,177,6,0,176,121,4,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,68,54,0,0,236,21,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,128,4,0,0,0,0,0,0,0,0,0,0,0,0,0,192,177,6,0,192,126,4,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,254,35,0,0,148,42,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,209,4,0,40,220,4,0,0,0,0,0,0,0,0,0,168,163,7,0,152,205,4,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,160,30,0,0,188,8,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,215,4,0,40,220,4,0,0,0,0,0,0,0,0,0,168,163,7,0,32,213,4,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,220,31,0,0,32,38,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,220,4,0,0,0,0,0,0,0,0,0,0,0,0,0,168,163,7,0,32,218,4,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,134,29,0,0,170,29,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,58,5,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,224,55,5,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,118,35,0,0,46,44,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,94,4,0,120,35,5,0,0,0,0,0,0,0,0,0,96,135,2,0,96,91,4,0,0,0,0,0,192,154,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,90,44,0,0,168,12,0,0,0,0,0,0,0,0,0,0,228,62,0,0,238,13,0,0,126,4,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,97,4,0,120,35,5,0,0,0,0,0,0,0,0,0,96,135,2,0,0,96,4,0,0,0,0,0,192,154,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,212,53,0,0,204,44,0,0,0,0,0,0,0,0,0,0,228,62,0,0,238,13,0,0,126,4,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,148,4,0,120,35,5,0,0,0,0,0,0,0,0,0,96,135,2,0,176,145,4,0,0,0,0,0,192,154,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,192,48,0,0,154,32,0,0,0,0,0,0,0,0,0,0,202,26,0,0,238,13,0,0,194,7,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,153,4,0,120,35,5,0,0,0,0,0,0,0,0,0,96,135,2,0,232,150,4,0,0,0,0,0,192,154,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,214,43,0,0,60,47,0,0,0,0,0,0,0,0,0,0,228,62,0,0,238,40,0,0,126,4,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0])
.concat([4,0,0,0,3,0,0,0,40,158,4,0,120,35,5,0,0,0,0,0,0,0,0,0,96,135,2,0,176,155,4,0,0,0,0,0,192,154,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,96,49,0,0,146,26,0,0,0,0,0,0,0,0,0,0,202,26,0,0,238,13,0,0,194,7,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,105,5,0,80,193,5,0,0,0,0,0,0,0,0,0,144,47,2,0,56,101,5,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,122,42,0,0,238,22,0,0,0,0,0,0,0,0,0,0,202,26,0,0,238,13,0,0,170,15,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,113,5,0,80,193,5,0,0,0,0,0,0,0,0,0,144,47,2,0,24,110,5,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,158,44,0,0,26,47,0,0,0,0,0,0,0,0,0,0,202,26,0,0,238,13,0,0,170,15,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,118,5,0,80,193,5,0,0,0,0,0,0,0,0,0,144,47,2,0,184,115,5,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,122,45,0,0,32,34,0,0,0,0,0,0,0,0,0,0,202,26,0,0,238,13,0,0,170,15,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,122,5,0,80,193,5,0,0,0,0,0,0,0,0,0,144,47,2,0,80,120,5,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,40,33,0,0,38,29,0,0,0,0,0,0,0,0,0,0,202,26,0,0,238,13,0,0,170,15,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,126,5,0,80,193,5,0,0,0,0,0,0,0,0,0,144,47,2,0,184,124,5,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,100,62,0,0,34,18,0,0,0,0,0,0,0,0,0,0,72,28,0,0,238,13,0,0,170,15,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,133,5,0,80,193,5,0,0,0,0,0,0,0,0,0,144,47,2,0,176,129,5,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,248,17,0,0,132,16,0,0,0,0,0,0,0,0,0,0,202,26,0,0,238,13,0,0,170,15,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,141,5,0,80,193,5,0,0,0,0,0,0,0,0,0,144,47,2,0,128,137,5,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,144,50,0,0,208,31,0,0,0,0,0,0,0,0,0,0,202,26,0,0,238,13,0,0,170,15,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,147,5,0,80,193,5,0,0,0,0,0,0,0,0,0,144,47,2,0,120,144,5,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,162,31,0,0,92,33,0,0,0,0,0,0,0,0,0,0,202,26,0,0,238,13,0,0,170,15,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,153,5,0,80,193,5,0,0,0,0,0,0,0,0,0,144,47,2,0,88,149,5,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,198,33,0,0,228,10,0,0,0,0,0,0,0,0,0,0,202,26,0,0,238,13,0,0,170,15,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,174,3,0,120,35,5,0,0,0,0,0,0,0,0,0,96,135,2,0,192,172,3,0,0,0,0,0,192,154,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,160,58,0,0,82,35,0,0,0,0,0,0,0,0,0,0,228,62,0,0,238,13,0,0,50,19,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,178,3,0,120,35,5,0,0,0,0,0,0,0,0,0,96,135,2,0,184,176,3,0,0,0,0,0,192,154,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,16,4,0,0,240,15,0,0,0,0,0,0,0,0,0,0,228,62,0,0,238,13,0,0,50,19,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,183,3,0,120,35,5,0,0,0,0,0,0,0,0,0,96,135,2,0,104,181,3,0,0,0,0,0,192,154,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,198,9,0,0,176,5,0,0,0,0,0,0,0,0,0,0,228,62,0,0,238,13,0,0,50,19,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,57,5,0,80,193,5,0,0,0,0,0,0,0,0,0,144,47,2,0,208,54,5,0,0,0,0,0,192,154,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,84,37,0,0,228,3,0,0,0,0,0,0,0,0,0,0,202,26,0,0,238,13,0,0,172,17,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,157,5,0,80,193,5,0,0,0,0,0,0,0,0,0,96,135,2,0,144,155,5,0,0,0,0,0,192,154,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,252,52,0,0,50,33,0,0,0,0,0,0,0,0,0,0,228,62,0,0,238,13,0,0,210,8,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,165,4,0,120,35,5,0,0,0,0,0,0,0,0,0,96,135,2,0,176,161,4,0,0,0,0,0,192,154,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,192,45,0,0,116,0,0,0,0,0,0,0,0,0,0,0,228,62,0,0,238,40,0,0,126,4,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,173,4,0,120,35,5,0,0,0,0,0,0,0,0,0,96,135,2,0,72,170,4,0,0,0,0,0,192,154,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,190,18,0,0,192,33,0,0,0,0,0,0,0,0,0,0,202,26,0,0,238,13,0,0,194,7,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,180,4,0,120,35,5,0,0,0,0,0,0,0,0,0,96,135,2,0,8,178,4,0,0,0,0,0,192,154,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,40,17,0,0,132,35,0,0,0,0,0,0,0,0,0,0,202,26,0,0,238,13,0,0,0,16,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,184,4,0,120,35,5,0,0,0,0,0,0,0,0,0,96,135,2,0,112,182,4,0,0,0,0,0,192,154,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,206,23,0,0,240,9,0,0,0,0,0,0,0,0,0,0,228,62,0,0,238,40,0,0,124,17,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,190,4,0,120,35,5,0,0,0,0,0,0,0,0,0,96,135,2,0,96,187,4,0,0,0,0,0,192,154,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,104,18,0,0,192,46,0,0,0,0,0,0,0,0,0,0,228,62,0,0,238,40,0,0,124,17,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,197,4,0,120,35,5,0,0,0,0,0,0,0,0,0,96,135,2,0,128,193,4,0,0,0,0,0,192,154,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,184,12,0,0,100,20,0,0,0,0,0,0,0,0,0,0,202,26,0,0,238,13,0,0,194,7,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,207,4,0,120,35,5,0,0,0,0,0,0,0,0,0,96,135,2,0,64,203,4,0,0,0,0,0,192,154,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,68,4,0,0,80,13,0,0,0,0,0,0,0,0,0,0,202,26,0,0,238,13,0,0,192,12,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,214,4,0,120,35,5,0,0,0,0,0,0,0,0,0,96,135,2,0,184,211,4,0,0,0,0,0,192,154,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,184,32,0,0,12,26,0,0,0,0,0,0,0,0,0,0,202,26,0,0,238,13,0,0,202,15,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,61,5,0,80,193,5,0,0,0,0,0,0,0,0,0,144,47,2,0,176,59,5,0,0,0,0,0,192,154,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,146,51,0,0,74,1,0,0,0,0,0,0,0,0,0,0,202,26,0,0,238,13,0,0,180,12,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,23,4,0,120,35,5,0,0,0,0,0,0,0,0,0,96,135,2,0,184,20,4,0,0,0,0,0,64,27,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,134,39,0,0,80,22,0,0,0,0,0,0,0,0,0,0,228,62,0,0,212,17,0,0,50,19,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,33,4,0,120,35,5,0,0,0,0,0,0,0,0,0,96,135,2,0,64,30,4,0,0,0,0,0,64,27,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,158,52,0,0,26,23,0,0,0,0,0,0,0,0,0,0,228,62,0,0,212,17,0,0,50,19,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,14,4,0,120,35,5,0,0,0,0,0,0,0,0,0,96,135,2,0,32,12,4,0,56,9,4,0,192,154,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,118,27,0,0,2,18,0,0,0,0,0,0,0,0,0,0,202,26,0,0,238,13,0,0,52,5,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,18,4,0,120,35,5,0,0,0,0,0,0,0,0,0,96,135,2,0,160,16,4,0,0,0,0,0,192,154,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,26,63,0,0,104,20,0,0,0,0,0,0,0,0,0,0,202,26,0,0,238,13,0,0,28,5,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,75,4,0,120,35,5,0,0,0,0,0,0,0,0,0,96,135,2,0,224,72,4,0,0,0,0,0,192,154,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,130,25,0,0,198,11,0,0,0,0,0,0,0,0,0,0,228,62,0,0,238,13,0,0,50,19,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,81,4,0,120,35,5,0,0,0,0,0,0,0,0,0,96,135,2,0,88,77,4,0,0,0,0,0,192,154,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,6,18,0,0,98,26,0,0,0,0,0,0,0,0,0,0,228,62,0,0,238,13,0,0,50,19,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,88,4,0,120,35,5,0,0,0,0,0,0,0,0,0,96,135,2,0,40,85,4,0,0,0,0,0,192,154,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,216,55,0,0,156,40,0,0,0,0,0,0,0,0,0,0,228,62,0,0,238,13,0,0,234,12,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,66,5,0,80,193,5,0,0,0,0,0,0,0,0,0,144,47,2,0,120,64,5,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,104,40,0,0,6,43,0,0,0,0,0,0,0,0,0,0,202,26,0,0,238,40,0,0,170,15,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,74,5,0,80,193,5,0,0,0,0,0,0,0,0,0,144,47,2,0,200,69,5,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,68,50,0,0,138,22,0,0,0,0,0,0,0,0,0,0,202,26,0,0,238,40,0,0,170,15,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,81,5,0,80,193,5,0,0,0,0,0,0,0,0,0,144,47,2,0,64,78,5,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,202,20,0,0,2,19,0,0,0,0,0,0,0,0,0,0,202,26,0,0,238,40,0,0,170,15,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,88,5,0,80,193,5,0,0,0,0,0,0,0,0,0,144,47,2,0,96,84,5,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,168,57,0,0,156,22,0,0,0,0,0,0,0,0,0,0,202,26,0,0,238,40,0,0,188,7,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,92,5,0,80,193,5,0,0,0,0,0,0,0,0,0,144,47,2,0,176,90,5,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,78,60,0,0,254,22,0,0,0,0,0,0,0,0,0,0,202,26,0,0,238,40,0,0,170,15,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,97,5,0,80,193,5,0,0,0,0,0,0,0,0,0,144,47,2,0,208,94,5,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,12,51,0,0,184,13,0,0,0,0,0,0,0,0,0,0,202,26,0,0,238,40,0,0,170,15,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,123,4,0,16,128,4,0,0,0,0,0,0,0,0,0,96,135,2,0,8,121,4,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,160,3,0,0,90,6,0,0,0,0,0,0,0,0,0,0,202,26,0,0,238,13,0,0,194,7,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,101,4,0,16,128,4,0,0,0,0,0,0,0,0,0,96,135,2,0,120,99,4,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,58,50,0,0,74,44,0,0,0,0,0,0,0,0,0,0,228,62,0,0,238,40,0,0,32,2,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,107,4,0,16,128,4,0,0,0,0,0,0,0,0,0,96,135,2,0,64,104,4,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,120,12,0,0,94,2,0,0,0,0,0,0,0,0,0,0,228,62,0,0,238,40,0,0,32,2,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,118,4,0,16,128,4,0,0,0,0,0,0,0,0,0,96,135,2,0,0,116,4,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,98,59,0,0,168,29,0,0,0,0,0,0,0,0,0,0,202,26,0,0,238,40,0,0,194,7,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,128,4,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,24,125,4,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,134,31,0,0,176,30,0,0,0,0,0,0,0,0,0,0,202,26,0,0,238,13,0,0,194,7,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,179,5,0,80,193,5,0,0,0,0,0,0,0,0,0,144,47,2,0,64,173,5,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,16,63,0,0,110,35,0,0,0,0,0,0,0,0,0,0,72,28,0,0,238,13,0,0,170,15,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,169,5,0,80,193,5,0,0,0,0,0,0,0,0,0,96,135,2,0,32,163,5,0,0,0,0,0,192,154,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,26,52,0,0,14,6,0,0,0,0,0,0,0,0,0,0,228,62,0,0,238,13,0,0,14,12,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,185,5,0,80,193,5,0,0,0,0,0,0,0,0,0,144,47,2,0,120,183,5,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,242,30,0,0,74,19,0,0,0,0,0,0,0,0,0,0,202,26,0,0,238,13,0,0,170,15,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,142,4,0,120,35,5,0,0,0,0,0,0,0,0,0,96,135,2,0,24,139,4,0,0,0,0,0,192,154,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,120,20,0,0,114,40,0,0,0,0,0,0,0,0,0,0,202,26,0,0,238,13,0,0,56,1,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,219,4,0,120,35,5,0,0,0,0,0,0,0,0,0,96,135,2,0,248,216,4,0,0,0,0,0,192,154,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,200,28,0,0,128,18,0,0,0,0,0,0,0,0,0,0,202,26,0,0,238,13,0,0,104,0,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,190,3,0,120,35,5,0,0,0,0,0,0,0,0,0,96,135,2,0,192,186,3,0,0,0,0,0,192,154,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,224,50,0,0,210,47,0,0,0,0,0,0,0,0,0,0,202,26,0,0,238,13,0,0,206,4,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,249,4,0,120,35,5,0,0,0,0,0,0,0,0,0,96,135,2,0,136,245,4,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,136,32,0,0,114,22,0,0,0,0,0,0,0,0,0,0,202,26,0,0,238,13,0,0,194,7,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,255,4,0,120,35,5,0,0,0,0,0,0,0,0,0,96,135,2,0,160,252,4,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,78,63,0,0,124,46,0,0,0,0,0,0,0,0,0,0,202,26,0,0,238,13,0,0,194,7,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,227,3,0,120,35,5,0,0,0,0,0,0,0,0,0,96,135,2,0,144,224,3,0,0,0,0,0,192,154,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,152,50,0,0,116,29,0,0,0,0,0,0,0,0,0,0,4,2,0,0,238,13,0,0,126,5,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,196,3,0,120,35,5,0,0,0,0,0,0,0,0,0,96,135,2,0,200,193,3,0,0,0,0,0,192,154,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,92,37,0,0,62,16,0,0,0,0,0,0,0,0,0,0,202,26,0,0,238,13,0,0,154,4,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,202,3,0,120,35,5,0,0,0,0,0,0,0,0,0,96,135,2,0,160,199,3,0,0,0,0,0,192,154,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,228,38,0,0,134,19,0,0,0,0,0,0,0,0,0,0,4,2,0,0,238,13,0,0,126,5,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,205,3,0,120,35,5,0,0,0,0,0,0,0,0,0,96,135,2,0,48,204,3,0,0,0,0,0,192,154,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,246,14,0,0,146,18,0,0,0,0,0,0,0,0,0,0,4,2,0,0,238,13,0,0,70,18,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,211,3,0,120,35,5,0,0,0,0,0,0,0,0,0,96,135,2,0,240,208,3,0,0,0,0,0,192,154,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,132,62,0,0,76,30,0,0,0,0,0,0,0,0,0,0,4,2,0,0,238,13,0,0,66,18,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,219,3,0,120,35,5,0,0,0,0,0,0,0,0,0,96,135,2,0,224,214,3,0,0,0,0,0,192,154,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,72,27,0,0,0,37,0,0,0,0,0,0,0,0,0,0,4,2,0,0,238,13,0,0,84,16,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,6,5,0,120,35,5,0,0,0,0,0,0,0,0,0,96,135,2,0,160,2,5,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,182,53,0,0,208,4,0,0,0,0,0,0,0,0,0,0,202,26,0,0,238,13,0,0,194,7,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,12,5,0,120,35,5,0,0,0,0,0,0,0,0,0,96,135,2,0,0,9,5,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,252,26,0,0,196,39,0,0,0,0,0,0,0,0,0,0,202,26,0,0,238,13,0,0,194,7,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,20,5,0,120,35,5,0,0,0,0,0,0,0,0,0,96,135,2,0,8,17,5,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,240,33,0,0,116,7,0,0,0,0,0,0,0,0,0,0,202,26,0,0,238,13,0,0,194,7,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,239,3,0,120,35,5,0,0,0,0,0,0,0,0,0,96,135,2,0,72,236,3,0,0,0,0,0,192,154,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,40,49,0,0,188,13,0,0,0,0,0,0,0,0,0,0,228,62,0,0,238,40,0,0,124,17,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,234,3,0,120,35,5,0,0,0,0,0,0,0,0,0,96,135,2,0,56,231,3,0,0,0,0,0,192,154,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,4,40,0,0,112,15,0,0,0,0,0,0,0,0,0,0,228,62,0,0,238,40,0,0,124,17,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,26,5,0,120,35,5,0,0,0,0,0,0,0,0,0,96,135,2,0,128,23,5,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,200,60,0,0,32,18,0,0,0,0,0,0,0,0,0,0,202,26,0,0,238,13,0,0,194,7,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,253,3,0,120,35,5,0,0,0,0,0,0,0,0,0,96,135,2,0,224,248,3,0,0,0,0,0,192,154,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,82,2,0,0,232,32,0,0,0,0,0,0,0,0,0,0,114,48,0,0,238,13,0,0,252,18,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,244,3,0,120,35,5,0,0,0,0,0,0,0,0,0,96,135,2,0,248,241,3,0,0,0,0,0,192,154,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,252,18,0,0,144,38,0,0,0,0,0,0,0,0,0,0,114,48,0,0,238,13,0,0,148,0,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,30,5,0,120,35,5,0,0,0,0,0,0,0,0,0,96,135,2,0,56,28,5,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,64,9,0,0,116,14,0,0,0,0,0,0,0,0,0,0,202,26,0,0,238,13,0,0,194,7,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,35,5,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,232,32,5,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,180,10,0,0,156,17,0,0,0,0,0,0,0,0,0,0,202,26,0,0,238,13,0,0,194,7,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,134,4,0,120,35,5,0,0,0,0,0,0,0,0,0,96,135,2,0,168,130,4,0,0,0,0,0,192,154,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,116,32,0,0,20,24,0,0,0,0,0,0,0,0,0,0,202,26,0,0,196,44,0,0,154,14,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,43,5,0,80,193,5,0,0,0,0,0,0,0,0,0,144,47,2,0,56,39,5,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,242,44,0,0,190,19,0,0,0,0,0,0,0,0,0,0,202,26,0,0,238,13,0,0,214,12,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,51,5,0,80,193,5,0,0,0,0,0,0,0,0,0,144,47,2,0,248,46,5,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,236,41,0,0,14,10,0,0,0,0,0,0,0,0,0,0,202,26,0,0,238,13,0,0,170,15,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,38,4,0,120,35,5,0,0,0,0,0,0,0,0,0,96,135,2,0,160,35,4,0,0,0,0,0,192,154,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,236,10,0,0,90,15,0,0,0,0,0,0,0,0,0,0,228,62,0,0,48,18,0,0,126,10,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,43,4,0,120,35,5,0,0,0,0,0,0,0,0,0,96,135,2,0,112,40,4,0,0,0,0,0,192,154,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,242,62,0,0,44,28,0,0,0,0,0,0,0,0,0,0,228,62,0,0,48,18,0,0,50,19,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,47,4,0,120,35,5,0])
.concat([0,0,0,0,0,0,0,0,96,135,2,0,120,44,4,0,0,0,0,0,192,154,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,222,40,0,0,36,37,0,0,0,0,0,0,0,0,0,0,228,62,0,0,48,18,0,0,50,19,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,55,4,0,120,35,5,0,0,0,0,0,0,0,0,0,96,135,2,0,168,50,4,0,0,0,0,0,192,154,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,240,47,0,0,230,4,0,0,0,0,0,0,0,0,0,0,228,62,0,0,48,18,0,0,50,19,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,62,4,0,120,35,5,0,0,0,0,0,0,0,0,0,96,135,2,0,208,57,4,0,0,0,0,0,192,154,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,196,17,0,0,194,43,0,0,0,0,0,0,0,0,0,0,228,62,0,0,48,18,0,0,50,19,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,66,4,0,120,35,5,0,0,0,0,0,0,0,0,0,96,135,2,0,88,64,4,0,0,0,0,0,192,154,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,40,32,0,0,60,36,0,0,0,0,0,0,0,0,0,0,228,62,0,0,48,18,0,0,50,19,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,71,4,0,120,35,5,0,0,0,0,0,0,0,0,0,96,135,2,0,24,69,4,0,0,0,0,0,192,154,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,234,42,0,0,190,27,0,0,0,0,0,0,0,0,0,0,228,62,0,0,48,18,0,0,126,10,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,225,4,0,120,35,5,0,0,0,0,0,0,0,0,0,96,135,2,0,80,221,4,0,0,0,0,0,192,154,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,118,62,0,0,22,31,0,0,0,0,0,0,0,0,0,0,202,26,0,0,238,13,0,0,64,9,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,234,4,0,120,35,5,0,0,0,0,0,0,0,0,0,96,135,2,0,144,229,4,0,0,0,0,0,192,154,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,158,40,0,0,242,47,0,0,0,0,0,0,0,0,0,0,202,26,0,0,238,13,0,0,194,7,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,241,4,0,120,35,5,0,0,0,0,0,0,0,0,0,96,135,2,0,152,238,4,0,0,0,0,0,192,154,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,178,27,0,0,216,9,0,0,0,0,0,0,0,0,0,0,202,26,0,0,238,13,0,0,194,7,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,193,5,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,208,189,5,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,2,0,0,0,0,0,0,0,170,6,0,0,86,8,0,0,0,0,0,0,0,0,0,0,202,26,0,0,238,13,0,0,170,15,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,246,6,0,176,15,7,0,0,0,0,0,0,0,0,0,32,127,5,0,40,242,6,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,0,0,0,0,0,0,0,0,58,5,0,0,210,11,0,0,0,0,0,0,0,0,0,0,56,13,0,0,110,17,0,0,44,13,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,34,7,0,176,66,7,0,0,0,0,0,0,0,0,0,168,163,7,0,208,31,7,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,0,0,0,0,0,0,0,0,106,54,0,0,40,30,0,0,0,0,0,0,0,0,0,0,102,46,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,17,7,0,72,28,7,0,0,0,0,0,0,0,0,0,144,139,6,0,72,11,7,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,0,0,0,0,0,0,0,0,212,30,0,0,28,42,0,0,0,0,0,0,0,0,0,0,164,12,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,186,2,0,152,82,5,0,0,0,0,0,0,0,0,0,0,38,7,0,80,185,2,0,0,0,0,0,192,154,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,0,0,0,0,0,0,0,0,22,45,0,0,16,47,0,0,0,0,0,0,0,0,0,0,72,60,0,0,0,0,0,0,202,14,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,63,5,0,152,82,5,0,0,0,0,0,0,0,0,0,0,38,7,0,144,60,5,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,0,0,0,0,0,0,0,0,140,61,0,0,164,16,0,0,0,0,0,0,0,0,0,0,72,60,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,82,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,88,79,5,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,0,0,0,0,0,0,0,0,240,21,0,0,140,37,0,0,0,0,0,0,0,0,0,0,72,60,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,204,5,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,120,199,5,0,0,0,0,0,192,223,4,0,160,229,3,0,240,195,5,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,1,0,32,0,0,0,0,0,0,0,0,0,0,88,28,0,0,114,44,0,0,0,0,0,0,0,0,0,0,156,45,0,0,166,54,0,0,44,13,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,91,5,0,0,0,0,0,0,0,0,0,0,0,0,0,168,163,7,0,216,88,5,0,0,0,0,0,192,223,4,0,152,4,4,0,200,85,5,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,7,0,32,0,0,0,0,0,0,0,0,0,0,50,24,0,0,226,27,0,0,0,0,0,0,0,0,0,0,146,10,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,212,5,0,184,221,5,0,0,0,0,0,0,0,0,0,96,135,2,0,72,208,5,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,1,0,32,0,0,0,0,0,0,0,0,0,0,102,9,0,0,254,24,0,0,0,0,0,0,0,0,0,0,76,17,0,0,186,61,0,0,70,17,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,221,5,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,96,217,5,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,1,0,32,0,0,0,0,0,0,0,0,0,0,240,45,0,0,0,25,0,0,0,0,0,0,0,0,0,0,76,17,0,0,164,0,0,0,70,17,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,96,5,0,208,113,5,0,0,0,0,0,0,0,0,0,104,129,6,0,120,93,5,0,0,0,0,0,8,108,5,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,2,0,1,7,0,16,0,0,0,0,0,0,0,0,0,0,134,44,0,0,40,44,0,0,0,0,0,0,0,0,0,0,130,4,0,0,0,0,0,0,190,14,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,103,5,0,208,113,5,0,0,0,0,0,0,0,0,0,104,129,6,0,64,98,5,0,0,0,0,0,8,108,5,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,2,0,1,7,0,16,0,0,0,0,0,0,0,0,0,0,34,36,0,0,242,9,0,0,0,0,0,0,0,0,0,0,130,4,0,0,0,0,0,0,190,14,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,113,5,0,0,0,0,0,0,0,0,0,0,0,0,0,104,129,6,0,128,111,5,0,0,0,0,0,8,108,5,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,2,0,1,7,0,16,0,0,0,0,0,0,0,0,0,0,254,41,0,0,154,7,0,0,0,0,0,0,0,0,0,0,130,4,0,0,0,0,0,0,190,14,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,31,6,0,120,40,6,0,0,0,0,0,0,0,0,0,240,3,2,0,96,27,6,0,0,0,0,0,192,223,4,0,96,103,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,2,1,4,0,0,0,0,0,0,0,0,0,0,0,88,6,0,0,168,44,0,0,0,0,0,0,0,0,0,0,104,38,0,0,26,6,0,0,44,13,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,24,6,0,120,40,6,0,0,0,0,0,0,0,0,0,240,3,2,0,176,20,6,0,0,0,0,0,192,223,4,0,96,103,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,2,1,4,0,0,0,0,0,0,0,0,0,0,0,118,6,0,0,218,34,0,0,0,0,0,0,0,0,0,0,104,38,0,0,26,6,0,0,44,13,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,17,6,0,120,40,6,0,0,0,0,0,0,0,0,0,240,3,2,0,200,13,6,0,0,0,0,0,192,223,4,0,96,103,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,2,1,4,0,0,0,0,0,0,0,0,0,0,0,88,19,0,0,62,3,0,0,0,0,0,0,0,0,0,0,104,38,0,0,26,6,0,0,44,13,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,233,5,0,120,40,6,0,0,0,0,0,0,0,0,0,56,172,6,0,176,229,5,0,0,0,0,0,192,154,4,0,160,229,3,0,32,225,5,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,1,4,0,0,0,0,0,0,0,0,0,0,0,0,51,0,0,168,16,0,0,0,0,0,0,0,0,0,0,148,53,0,0,68,2,0,0,44,13,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,40,6,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,32,35,6,0,0,0,0,0,192,223,4,0,96,103,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,2,1,4,0,0,0,0,0,0,0,0,0,0,0,154,28,0,0,126,40,0,0,0,0,0,0,0,0,0,0,104,38,0,0,26,6,0,0,44,13,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,240,5,0,120,40,6,0,0,0,0,0,0,0,0,0,240,3,2,0,80,236,5,0,120,155,4,0,192,154,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,1,4,0,0,0,0,0,0,0,0,0,0,0,186,9,0,0,46,0,0,0,0,0,0,0,0,0,0,0,104,38,0,0,26,6,0,0,174,2,0,0,70,19,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,252,5,0,120,40,6,0,0,0,0,0,0,0,0,0,240,3,2,0,80,244,5,0,120,155,4,0,192,154,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,1,4,0,0,0,0,0,0,0,0,0,0,0,206,24,0,0,80,29,0,0,0,0,0,0,0,0,0,0,104,38,0,0,26,6,0,0,70,5,0,0,70,19,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,7,6,0,120,40,6,0,0,0,0,0,0,0,0,0,240,3,2,0,72,2,6,0,120,155,4,0,192,154,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,1,4,0,0,0,0,0,0,0,0,0,0,0,30,28,0,0,94,6,0,0,0,0,0,0,0,0,0,0,104,38,0,0,26,6,0,0,16,19,0,0,70,19,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,196,2,0,232,134,5,0,0,0,0,0,0,0,0,0,104,129,6,0,88,194,2,0,0,0,0,0,192,154,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,2,0,1,7,1,0,0,0,0,0,0,0,0,0,0,0,52,25,0,0,44,11,0,0,0,0,0,0,0,0,0,0,92,42,0,0,0,0,0,0,202,14,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,191,2,0,232,134,5,0,0,0,0,0,0,0,0,0,104,129,6,0,208,190,2,0,0,0,0,0,192,154,4,0,152,4,4,0,192,187,2,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,2,0,1,7,1,0,0,0,0,0,0,0,0,0,0,0,142,5,0,0,154,9,0,0,0,0,0,0,0,0,0,0,92,42,0,0,0,0,0,0,202,14,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,129,2,0,232,134,5,0,0,0,0,0,0,0,0,0,104,129,6,0,96,128,2,0,0,0,0,0,192,154,4,0,152,4,4,0,192,125,2,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,2,0,1,7,1,0,0,0,0,0,0,0,0,0,0,0,250,62,0,0,54,29,0,0,0,0,0,0,0,0,0,0,92,42,0,0,0,0,0,0,202,14,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,121,5,0,232,134,5,0,0,0,0,0,0,0,0,0,104,129,6,0,232,118,5,0,0,0,0,0,96,127,5,0,152,4,4,0,208,116,5,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,2,0,1,7,1,0,0,0,0,0,0,0,0,0,0,0,244,58,0,0,40,48,0,0,0,0,0,0,0,0,0,0,92,42,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,125,5,0,232,134,5,0,0,0,0,0,0,0,0,0,104,129,6,0,112,123,5,0,0,0,0,0,96,127,5,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,2,0,1,7,1,0,0,0,0,0,0,0,0,0,0,0,182,4,0,0,6,32,0,0,0,0,0,0,0,0,0,0,92,42,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,134,5,0,0,0,0,0,0,0,0,0,0,0,0,0,104,129,6,0,32,131,5,0,0,0,0,0,96,127,5,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,2,0,1,7,1,0,0,0,0,0,0,0,0,0,0,0,130,52,0,0,6,31,0,0,0,0,0,0,0,0,0,0,92,42,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,57,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,248,49,6,0,0,0,0,0,200,44,6,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,1,0,16,0,0,0,0,0,0,0,0,0,0,166,38,0,0,202,19,0,0,0,0,0,0,0,0,0,0,180,51,0,0,82,43,0,0,44,13,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,211,4,0,88,191,6,0,0,0,0,0,0,0,0,0,0,38,7,0,152,177,4,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,3,0,0,0,0,0,1,7,4,0,0,0,0,0,0,0,0,0,0,0,102,45,0,0,20,28,0,0,0,0,0,0,0,0,0,0,216,27,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,23,5,0,88,191,6,0,0,0,0,0,0,0,0,0,0,38,7,0,24,245,4,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,3,0,0,0,0,0,1,7,4,0,0,0,0,0,0,0,0,0,0,0,6,63,0,0,152,0,0,0,0,0,0,0,0,0,0,0,216,27,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,68,4,0,8,72,4,0,0,0,0,0,0,0,0,0,184,12,8,0,184,65,4,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,88,10,0,0,88,43,0,0,0,0,0,0,0,0,0,0,204,58,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,105,6,0,152,126,6,0,0,0,0,0,0,0,0,0,32,127,5,0,8,102,6,0,0,0,0,0,32,46,8,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,1,0,16,0,0,0,0,0,0,0,0,0,0,28,54,0,0,122,20,0,0,0,0,0,0,0,0,0,0,220,17,0,0,46,61,0,0,208,19,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,114,6,0,152,126,6,0,0,0,0,0,0,0,0,0,32,127,5,0,232,110,6,0,0,0,0,0,32,46,8,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,1,0,16,0,0,0,0,0,0,0,0,0,0,240,38,0,0,232,47,0,0,0,0,0,0,0,0,0,0,220,17,0,0,46,61,0,0,30,1,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,63,6,0,152,126,6,0,0,0,0,0,0,0,0,0,32,127,5,0,248,59,6,0,0,0,0,0,32,46,8,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,1,0,16,0,0,0,0,0,0,0,0,0,0,196,50,0,0,88,34,0,0,0,0,0,0,0,0,0,0,220,17,0,0,46,61,0,0,30,1,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,70,6,0,152,126,6,0,0,0,0,0,0,0,0,0,32,127,5,0,56,66,6,0,0,0,0,0,32,46,8,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,1,0,16,0,0,0,0,0,0,0,0,0,0,84,62,0,0,144,3,0,0,0,0,0,0,0,0,0,0,220,17,0,0,46,61,0,0,30,1,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,83,6,0,152,126,6,0,0,0,0,0,0,0,0,0,32,127,5,0,232,76,6,0,0,0,0,0,32,46,8,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,1,0,16,0,0,0,0,0,0,0,0,0,0,46,63,0,0,114,29,0,0,0,0,0,0,0,0,0,0,220,17,0,0,46,61,0,0,30,1,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,96,6,0,152,126,6,0,0,0,0,0,0,0,0,0,32,127,5,0,216,90,6,0,0,0,0,0,32,46,8,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,1,0,16,0,0,0,0,0,0,0,0,0,0,168,1,0,0,132,0,0,0,0,0,0,0,0,0,0,0,220,17,0,0,46,61,0,0,50,5,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,126,6,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,48,121,6,0,0,0,0,0,32,46,8,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,3,1,0,16,0,0,0,0,0,0,0,0,0,0,140,44,0,0,24,36,0,0,0,0,0,0,0,0,0,0,220,17,0,0,46,61,0,0,30,1,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,200,2,0,136,201,5,0,0,0,0,0,0,0,0,0,32,127,5,0,24,199,2,0,0,0,0,0,192,154,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,8,0,0,0,0,0,0,0,120,49,0,0,128,46,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,202,14,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,170,5,0,136,201,5,0,0,0,0,0,0,0,0,0,32,127,5,0,88,165,5,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,8,0,0,0,0,0,0,0,44,34,0,0,164,43,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,181,5,0,136,201,5,0,0,0,0,0,0,0,0,0,32,127,5,0,152,176,5,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,8,0,0,0,0,0,0,0,132,9,0,0,168,36,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,188,5,0,136,201,5,0,0,0,0,0,0,0,0,0,32,127,5,0,128,184,5,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,8,0,0,0,0,0,0,0,114,43,0,0,96,47,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,193,5,0,136,201,5,0,0,0,0,0,0,0,0,0,32,127,5,0,152,190,5,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,8,0,0,0,0,0,0,0,66,14,0,0,168,6,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,201,5,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,24,198,5,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,8,0,0,0,0,0,0,0,88,61,0,0,80,7,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,136,6,0,144,144,6,0,0,0,0,0,0,0,0,0,104,221,5,0,120,131,6,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,1,0,8,0,0,0,0,0,0,0,0,0,0,40,2,0,0,4,47,0,0,0,0,0,0,0,0,0,0,96,3,0,0,98,30,0,0,170,15,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,144,6,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,192,140,6,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,1,0,8,0,0,0,0,0,0,0,0,0,0,190,11,0,0,142,16,0,0,0,0,0,0,0,0,0,0,96,3,0,0,98,30,0,0,170,15,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,217,5,0,128,45,6,0,0,0,0,0,0,0,0,0,192,177,6,0,8,214,5,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,114,40,0,0,86,36,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,204,2,0,128,45,6,0,0,0,0,0,0,0,0,0,192,177,6,0,112,202,2,0,0,0,0,0,192,154,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,90,26,0,0,28,19,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,202,14,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,227,5,0,128,45,6,0,0,0,0,0,0,0,0,0,192,177,6,0,32,222,5,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,106,44,0,0,146,32,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,31,6,0,128,45,6,0,0,0,0,0,0,0,0,0,192,177,6,0,88,28,6,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,206,3,0,0,94,44,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,210,5,0,128,45,6,0,0,0,0,0,0,0,0,0,192,177,6,0,176,205,5,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,146,20,0,0,98,45,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,196,17,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,233,5,0,128,45,6,0,0,0,0,0,0,0,0,0,192,177,6,0,72,230,5,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,132,7,0,0,132,9,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,240,5,0,128,45,6,0,0,0,0,0,0,0,0,0,192,177,6,0,48,237,5,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,128,61,0,0,142,39,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,253,5,0,128,45,6,0,0,0,0,0,0,0,0,0,192,177,6,0,32,246,5,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,24,17,0,0,158,16,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,9,6,0,128,45,6,0,0,0,0,0,0,0,0,0,192,177,6,0,184,2,6,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,190,22,0,0,54,30,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,17,6,0,128,45,6,0,0,0,0,0,0,0,0,0,192,177,6,0,160,14,6,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,132,29,0,0,6,46,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,24,6,0,128,45,6,0,0,0,0,0,0,0,0,0,192,177,6,0,168,21,6,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,220,1,0,0,126,21,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,45,6,0,0,0,0,0,0,0,0,0,0,0,0,0,192,177,6,0,248,35,6,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,196,10,0,0,6,13,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,158,6,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,120,155,6,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,1,0,8,0,0,0,0,0,0,0,0,0,0,58,13,0,0,180,18,0,0,0,0,0,0,0,0,0,0,170,62,0,0,78,41,0,0,170,15,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,168,6,0,32,202,6,0,0,0,0,0,0,0,0,0,104,221,5,0,8,162,6,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,1,4,0,0,0,0,0,0,0,0,0,0,0,130,46,0,0,190,24,0,0,0,0,0,0,0,0,0,0,114,5,0,0,232,46,0,0,170,15,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,195,6,0,32,202,6,0,0,0,0,0,0,0,0,0,104,221,5,0,128,191,6,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,1,4,0,0,0,0,0,0,0,0,0,0,0,252,8,0,0,122,27,0,0,0,0,0,0,0,0,0,0,114,5,0,0,232,46,0,0,170,15,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,186,6,0,32,202,6,0,0,0,0,0,0,0,0,0,104,221,5,0,8,180,6,0,0,0,0,0,192,223,4,0,160,229,3,0,240,173,6,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,1,4,0,0,0,0,0,0,0,0,0,0,0,248,53,0,0,168,28,0,0,0,0,0,0,0,0,0,0,114,5,0,0,232,46,0,0,170,15,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,202,6,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,40,199,6,0])
.concat([0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,1,4,0,0,0,0,0,0,0,0,0,0,0,34,59,0,0,42,21,0,0,0,0,0,0,0,0,0,0,114,5,0,0,232,46,0,0,170,15,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,206,2,0,120,145,6,0,0,0,0,0,0,0,0,0,184,12,8,0,176,205,2,0,0,0,0,0,192,154,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,0,41,0,0,18,4,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,202,14,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,55,6,0,120,145,6,0,0,0,0,0,0,0,0,0,184,12,8,0,40,51,6,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,222,47,0,0,244,22,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,60,6,0,120,145,6,0,0,0,0,0,0,0,0,0,184,12,8,0,144,57,6,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,98,29,0,0,184,1,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,67,6,0,120,145,6,0,0,0,0,0,0,0,0,0,184,12,8,0,96,63,6,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,92,40,0,0,208,8,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,77,6,0,120,145,6,0,0,0,0,0,0,0,0,0,184,12,8,0,64,72,6,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,140,4,0,0,122,1,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,92,6,0,120,145,6,0,0,0,0,0,0,0,0,0,184,12,8,0,0,86,6,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,248,45,0,0,120,12,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,102,6,0,120,145,6,0,0,0,0,0,0,0,0,0,184,12,8,0,136,97,6,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,170,5,0,0,70,10,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,111,6,0,120,145,6,0,0,0,0,0,0,0,0,0,184,12,8,0,208,107,6,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,52,62,0,0,250,37,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,118,6,0,120,145,6,0,0,0,0,0,0,0,0,0,184,12,8,0,232,114,6,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,138,17,0,0,96,45,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,127,6,0,120,145,6,0,0,0,0,0,0,0,0,0,184,12,8,0,32,122,6,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,234,31,0,0,212,34,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,137,6,0,120,145,6,0,0,0,0,0,0,0,0,0,184,12,8,0,184,132,6,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,38,15,0,0,196,10,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,145,6,0,0,0,0,0,0,0,0,0,0,0,0,0,184,12,8,0,96,141,6,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,234,26,0,0,168,35,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,210,2,0,144,206,6,0,0,0,0,0,0,0,0,0,32,127,5,0,120,208,2,0,0,0,0,0,192,154,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,0,0,0,0,0,0,0,0,94,12,0,0,198,15,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,202,14,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,152,6,0,144,206,6,0,0,0,0,0,0,0,0,0,32,127,5,0,72,149,6,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,0,0,0,0,0,0,0,0,70,61,0,0,58,47,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,158,6,0,144,206,6,0,0,0,0,0,0,0,0,0,32,127,5,0,104,156,6,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,0,0,0,0,0,0,0,0,28,14,0,0,194,37,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,168,6,0,144,206,6,0,0,0,0,0,0,0,0,0,32,127,5,0,216,162,6,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,0,0,0,0,0,0,0,0,192,6,0,0,52,37,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,181,6,0,144,206,6,0,0,0,0,0,0,0,0,0,32,127,5,0,72,175,6,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,0,0,0,0,0,0,0,0,42,43,0,0,62,45,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,192,6,0,144,206,6,0,0,0,0,0,0,0,0,0,32,127,5,0,80,187,6,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,0,0,0,0,0,0,0,0,152,35,0,0,214,44,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,199,6,0,144,206,6,0,0,0,0,0,0,0,0,0,32,127,5,0,104,196,6,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,0,0,0,0,0,0,0,0,136,41,0,0,136,34,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,206,6,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,152,202,6,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,0,0,0,0,0,0,0,0,182,20,0,0,116,13,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,28,7,0,176,15,7,0,0,0,0,0,0,0,0,0,144,139,6,0,160,22,7,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,0,0,0,0,0,0,0,0,56,58,0,0,214,5,0,0,0,0,0,0,0,0,0,0,164,12,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,224,6,0,208,239,6,0,0,0,0,0,0,0,0,0,104,221,5,0,168,218,6,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,3,0,0,0,0,0,1,1,2,0,0,0,0,0,0,0,0,0,0,0,198,50,0,0,254,40,0,0,0,0,0,0,0,0,0,0,66,16,0,0,20,49,0,0,250,14,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,224,0,0,0,128,1,0,0,3,0,0,0,4,0,0,0,224,233,6,0,208,239,6,0,0,0,0,0,0,0,0,0,104,221,5,0,240,228,6,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,3,0,0,0,0,0,1,1,2,0,0,0,0,0,0,0,0,0,0,0,190,62,0,0,156,10,0,0,0,0,0,0,0,0,0,0,66,16,0,0,20,49,0,0,250,14,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,224,0,0,0,128,1,0,0,3,0,0,0,4,0,0,0,136,214,6,0,208,239,6,0,0,0,0,0,0,0,0,0,104,221,5,0,120,209,6,0,0,0,0,0,192,223,4,0,160,229,3,0,40,205,6,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,3,0,0,0,0,0,1,1,2,0,0,0,0,0,0,0,0,0,0,0,208,11,0,0,70,24,0,0,0,0,0,0,0,0,0,0,66,16,0,0,20,49,0,0,250,14,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,224,0,0,0,128,1,0,0,3,0,0,0,4,0,0,0,208,239,6,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,160,236,6,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,3,0,0,0,0,0,1,1,2,0,0,0,0,0,0,0,0,0,0,0,116,34,0,0,154,27,0,0,0,0,0,0,0,0,0,0,66,16,0,0,20,49,0,0,250,14,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,224,0,0,0,128,1,0,0,3,0,0,0,4,0,0,0,56,221,2,0,176,66,7,0,0,0,0,0,0,0,0,0,168,163,7,0,40,219,2,0,0,0,0,0,192,154,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,0,0,0,0,0,0,0,0,110,62,0,0,176,27,0,0,0,0,0,0,0,0,0,0,102,46,0,0,0,0,0,0,202,14,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,254,6,0,176,15,7,0,0,0,0,0,0,0,0,0,32,127,5,0,184,249,6,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,0,0,0,0,0,0,0,0,76,18,0,0,60,1,0,0,0,0,0,0,0,0,0,0,56,13,0,0,212,28,0,0,44,13,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,43,7,0,176,66,7,0,0,0,0,0,0,0,0,0,168,163,7,0,184,37,7,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,0,0,0,0,0,0,0,0,222,0,0,0,148,26,0,0,0,0,0,0,0,0,0,0,102,46,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,55,7,0,176,66,7,0,0,0,0,0,0,0,0,0,168,163,7,0,160,49,7,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,0,0,0,0,0,0,0,0,74,61,0,0,18,23,0,0,0,0,0,0,0,0,0,0,102,46,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,66,7,0,0,0,0,0,0,0,0,0,0,0,0,0,168,163,7,0,216,61,7,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,0,0,0,0,0,0,0,0,200,53,0,0,158,19,0,0,0,0,0,0,0,0,0,0,102,46,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,15,7,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,48,5,7,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,1,8,0,0,0,0,0,0,0,0,0,0,0,2,5,0,0,148,18,0,0,0,0,0,0,0,0,0,0,56,13,0,0,212,28,0,0,44,13,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,142,3,0,168,148,3,0,0,0,0,0,0,0,0,0,240,3,2,0,224,138,3,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,1,1,8,0,0,0,0,0,0,0,0,0,0,0,6,30,0,0,150,25,0,0,0,0,0,0,0,0,0,0,158,36,0,0,154,21,0,0,44,13,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,148,3,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,240,144,3,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,4,0,0,0,0,0,1,1,8,0,0,0,0,0,0,0,0,0,0,0,246,58,0,0,194,34,0,0,0,0,0,0,0,0,0,0,158,36,0,0,154,21,0,0,44,13,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,152,3,0,104,161,3,0,0,0,0,0,0,0,0,0,240,3,2,0,144,150,3,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,1,1,8,0,0,0,0,0,0,0,0,0,0,0,12,21,0,0,152,46,0,0,0,0,0,0,0,0,0,0,158,36,0,0,154,21,0,0,44,13,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,216,2,0,56,6,7,0,0,0,0,0,0,0,0,0,184,230,7,0,248,212,2,0,0,0,0,0,192,154,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,7,2,0,0,0,0,0,0,0,0,0,0,0,252,58,0,0,58,2,0,0,0,0,0,0,0,0,0,0,146,16,0,0,0,0,0,0,202,14,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,247,6,0,56,6,7,0,0,0,0,0,0,0,0,0,184,230,7,0,224,243,6,0,0,0,0,0,16,250,6,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,2,0,0,0,0,0,0,0,0,0,0,0,68,24,0,0,70,47,0,0,0,0,0,0,0,0,0,0,146,16,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,6,7,0,0,0,0,0,0,0,0,0,0,0,0,0,184,230,7,0,112,255,6,0,0,0,0,0,16,250,6,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,7,2,0,0,0,0,0,0,0,0,0,0,0,6,29,0,0,162,46,0,0,0,0,0,0,0,0,0,0,146,16,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,224,6,0,32,240,6,0,0,0,0,0,0,0,0,0,184,230,7,0,152,220,6,0,0,0,0,0,32,46,8,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,0,16,0,0,0,0,0,0,0,0,0,0,58,48,0,0,152,30,0,0,0,0,0,0,0,0,0,0,94,14,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,234,6,0,32,240,6,0,0,0,0,0,0,0,0,0,184,230,7,0,160,229,6,0,0,0,0,0,32,46,8,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,2,0,1,7,0,16,0,0,0,0,0,0,0,0,0,0,102,27,0,0,48,12,0,0,0,0,0,0,0,0,0,0,94,14,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,215,6,0,32,240,6,0,0,0,0,0,0,0,0,0,184,230,7,0,24,210,6,0,0,0,0,0,32,46,8,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,2,0,1,7,0,16,0,0,0,0,0,0,0,0,0,0,118,24,0,0,184,8,0,0,0,0,0,0,0,0,0,0,94,14,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,240,6,0,0,0,0,0,0,0,0,0,0,0,0,0,184,230,7,0,72,237,6,0,0,0,0,0,32,46,8,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,2,0,1,7,0,16,0,0,0,0,0,0,0,0,0,0,210,10,0,0,168,23,0,0,0,0,0,0,0,0,0,0,94,14,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,26,8,0,216,96,8,0,0,0,0,0,0,0,0,0,104,174,7,0,176,21,8,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,1,1,0,0,0,0,0,0,0,0,0,0,0,28,23,0,0,58,45,0,0,0,0,0,0,0,0,0,0,70,12,0,0,102,47,0,0,240,17,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,34,8,0,216,96,8,0,0,0,0,0,0,0,0,0,104,174,7,0,216,29,8,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,1,1,0,0,0,0,0,0,0,0,0,0,0,28,47,0,0,172,9,0,0,0,0,0,0,0,0,0,0,70,12,0,0,102,47,0,0,240,17,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,74,7,0,216,91,7,0,0,0,0,0,0,0,0,0,144,47,2,0,80,69,7,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,3,0,0,0,0,0,1,1,4,0,0,0,0,0,0,0,0,0,0,0,144,57,0,0,74,17,0,0,0,0,0,0,0,0,0,0,222,16,0,0,210,13,0,0,170,15,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,80,7,0,216,91,7,0,0,0,0,0,0,0,0,0,144,47,2,0,232,77,7,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,3,0,0,0,0,0,1,1,4,0,0,0,0,0,0,0,0,0,0,0,248,42,0,0,246,4,0,0,0,0,0,0,0,0,0,0,222,16,0,0,204,46,0,0,170,15,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,54,7,0,216,91,7,0,0,0,0,0,0,0,0,0,144,47,2,0,232,48,7,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,3,0,0,0,0,0,1,1,4,0,0,0,0,0,0,0,0,0,0,0,30,31,0,0,168,47,0,0,0,0,0,0,0,0,0,0,222,16,0,0,210,13,0,0,170,15,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,65,7,0,216,91,7,0,0,0,0,0,0,0,0,0,144,47,2,0,224,60,7,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,3,0,0,0,0,0,1,1,4,0,0,0,0,0,0,0,0,0,0,0,54,24,0,0,172,38,0,0,0,0,0,0,0,0,0,0,222,16,0,0,210,13,0,0,170,15,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,34,7,0,216,91,7,0,0,0,0,0,0,0,0,0,56,172,6,0,208,27,7,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,1,0,0,3,0,0,0,0,0,1,1,4,0,0,0,0,0,0,0,0,0,0,0,170,17,0,0,216,47,0,0,0,0,0,0,0,0,0,0,116,60,0,0,210,13,0,0,26,9,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,25,7,0,216,91,7,0,0,0,0,0,0,0,0,0,144,47,2,0,136,21,7,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,3,0,0,0,0,0,1,1,4,0,0,0,0,0,0,0,0,0,0,0,26,50,0,0,66,16,0,0,0,0,0,0,0,0,0,0,222,16,0,0,210,13,0,0,170,15,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,42,7,0,216,91,7,0,0,0,0,0,0,0,0,0,144,47,2,0,104,37,7,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,3,0,0,0,0,0,1,1,4,0,0,0,0,0,0,0,0,0,0,0,208,5,0,0,150,12,0,0,0,0,0,0,0,0,0,0,222,16,0,0,210,13,0,0,64,18,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,91,7,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,120,85,7,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,3,0,0,0,0,0,1,1,4,0,0,0,0,0,0,0,0,0,0,0,194,52,0,0,170,38,0,0,0,0,0,0,0,0,0,0,222,16,0,0,210,13,0,0,170,15,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,180,7,0,64,193,7,0,0,0,0,0,0,0,0,0,144,47,2,0,104,177,7,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,3,0,0,0,0,0,1,1,4,0,0,0,0,0,0,0,0,0,0,0,90,62,0,0,58,29,0,0,0,0,0,0,0,0,0,0,118,61,0,0,50,56,0,0,170,15,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,166,7,0,64,193,7,0,0,0,0,0,0,0,0,0,144,47,2,0,120,161,7,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,3,0,0,0,0,0,1,1,4,0,0,0,0,0,0,0,0,0,0,0,108,27,0,0,22,29,0,0,0,0,0,0,0,0,0,0,118,61,0,0,50,56,0,0,170,15,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,174,7,0,64,193,7,0,0,0,0,0,0,0,0,0,144,47,2,0,72,169,7,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,3,0,0,0,0,0,1,1,4,0,0,0,0,0,0,0,0,0,0,0,216,29,0,0,250,46,0,0,0,0,0,0,0,0,0,0,118,61,0,0,50,56,0,0,170,15,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,105,7,0,64,193,7,0,0,0,0,0,0,0,0,0,144,47,2,0,144,98,7,0,0,0,0,0,144,88,7,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,1,0,0,3,0,0,0,0,0,1,1,4,0,0,0,0,0,0,0,0,0,0,0,214,59,0,0,184,7,0,0,0,0,0,0,0,0,0,0,118,61,0,0,50,56,0,0,170,15,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,121,7,0,64,193,7,0,0,0,0,0,0,0,0,0,144,47,2,0,184,116,7,0,0,0,0,0,144,88,7,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,1,0,0,3,0,0,0,0,0,1,1,4,0,0,0,0,0,0,0,0,0,0,0,82,45,0,0,252,2,0,0,0,0,0,0,0,0,0,0,118,61,0,0,50,56,0,0,170,15,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,127,7,0,64,193,7,0,0,0,0,0,0,0,0,0,144,47,2,0,88,124,7,0,0,0,0,0,192,154,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,3,0,0,0,0,0,1,1,4,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,52,28,0,0,0,0,0,0,0,0,0,0,118,61,0,0,50,56,0,0,12,3,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,134,7,0,64,193,7,0,0,0,0,0,0,0,0,0,144,47,2,0,56,131,7,0,0,0,0,0,192,154,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,3,0,0,0,0,0,1,1,4,0,0,0,0,0,0,0,0,0,0,0,74,24,0,0,214,14,0,0,0,0,0,0,0,0,0,0,118,61,0,0,50,56,0,0,170,15,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,145,7,0,64,193,7,0,0,0,0,0,0,0,0,0,144,47,2,0,56,139,7,0,0,0,0,0,192,154,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,3,0,0,0,0,0,1,1,4,0,0,0,0,0,0,0,0,0,0,0,244,16,0,0,172,23,0,0,0,0,0,0,0,0,0,0,118,61,0,0,50,56,0,0,84,6,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,156,7,0,64,193,7,0,0,0,0,0,0,0,0,0,144,47,2,0,56,151,7,0,0,0,0,0,192,154,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,3,0,0,0,0,0,1,1,4,0,0,0,0,0,0,0,0,0,0,0,184,22,0,0,58,14,0,0,0,0,0,0,0,0,0,0,118,61,0,0,50,56,0,0,12,3,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,193,7,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,48,186,7,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,3,0,0,0,0,0,1,1,4,0,0,0,0,0,0,0,0,0,0,0,122,0,0,0,122,10,0,0,0,0,0,0,0,0,0,0,118,61,0,0,50,56,0,0,170,15,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,78,7,0,0,0,0,0,0,0,0,0,0,0,0,0,144,139,6,0,40,75,7,0,0,0,0,0,32,46,8,0,152,4,4,0,208,70,7,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,2,0,1,7,0,0,2,0,0,0,0,0,0,0,0,0,66,34,0,0,8,15,0,0,0,0,0,0,0,0,0,0,238,23,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,86,7,0,248,117,7,0,0,0,0,0,0,0,0,0,0,180,6,0,224,81,7,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,72,57,0,0,214,41,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,158,6,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,225,2,0,248,117,7,0,0,0,0,0,0,0,0,0,0,180,6,0,240,223,2,0,0,0,0,0,192,154,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,150,10,0,0,250,3,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,86,17,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,229,2,0,248,117,7,0,0,0,0,0,0,0,0,0,0,180,6,0,8,227,2,0,0,0,0,0,192,154,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,2,50,0,0,208,17,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,86,17,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,100,7,0,248,117,7,0,0,0,0,0,0,0,0,0,0,180,6,0,224,92,7,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,132,23,0,0,172,1,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,158,6,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,117,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,180,6,0,40,106,7,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,2,0,0,0,0,0,0,0,212,33,0,0,60,12,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,158,6,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,83,8,0,80,106,8,0,0,0,0,0,0,0,0,0,184,230,7,0,120,79,8,0,0,0,0,0,104,91,8,0,152,4,4,0,144,73,8,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,1,7,2,0,0,0,0,0,0,0,0,0,0,0,250,12,0,0,110,24,0,0,0,0,0,0,0,0,0,0,220,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,224,0,0,0,128,1,0,0,3,0,0,0,4,0,0,0,240,233,2,0,200,166,7,0,0,0,0,0,0,0,0,0,144,139,6,0,80,231,2,0,0,0,0,0,192,154,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,7,2,0,0,0,0,0,0,0,0,0,0,0,196,14,0,0,88,27,0,0,0,0,0,0,0,0,0,0,238,58,0,0,0,0,0,0,202,14,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,125,7,0,200,166,7,0,0,0,0,0,0,0,0,0,144,139,6,0,160,121,7,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,2,0,0,0,0,0,0,0,0,0,0,0,252,44,0,0,218,33,0,0,0,0,0,0,0,0,0,0,238,58,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,131,7,0,200,166,7,0,0,0,0,0,0,0,0,0,144,139,6,0,0,128,7,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,2,0,0,0,0,0,0,0,0,0,0,0,38,46,0,0,100,14,0,0,0,0,0,0,0,0,0,0,238,58,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,239,2,0,200,166,7,0,0,0,0,0,0,0,0,0,144,139,6,0,136,237,2,0,0,0,0,0,192,154,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,7,2,0,0,0,0,0,0,0,0,0,0,0,200,3,0,0,58,48,0,0,0,0,0,0,0,0,0,0,238,58,0,0,0,0,0,0,202,14,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,139,7,0,200,166,7,0,0,0,0,0,0,0,0,0,144,139,6,0,144,134,7,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,2,0,0,0,0,0,0,0,0,0,0,0,74,41,0,0,16,32,0,0,0,0,0,0,0,0,0,0,238,58,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,152,7,0,200,166,7,0,0,0,0,0,0,0,0,0,144,139,6,0,200,146,7,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,2,0,0,0,0,0,0,0,0,0,0,0,210,7,0,0,244,36,0,0,0,0,0,0,0,0,0,0,238,58,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,166,7,0,0,0,0,0,0,0,0,0,0,0,0,0,144,139,6,0,104,157,7,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,7,2,0,0,0,0,0,0,0,0,0,0,0,120,31,0,0,12,41,0,0,0,0,0,0,0,0,0,0,238,58,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,123,2,0,176,66,7,0,0,0,0,0,0,0,0,0,168,163,7,0,128,122,2,0,16,122,2,0,192,154,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,0,0,0,0,0,0,0,0,2,24,0,0,154,34,0,0,0,0,0,0,0,0,0,0,102,46,0,0,0,0,0,0,120,17,0,0,188,16,0,0,174,12,0,0,146,13,0,0,166,31,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,253,7,0,24,10,8,0,0,0,0,0,0,0,0,0,104,174,7,0,248,244,7,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,1,0,8,0,0,0,0,0,0,0,0,0,0,18,22,0,0,216,10,0,0,0,0,0,0,0,0,0,0,92,12,0,0,74,43,0,0,130,14,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,10,8,0,0,0,0,0,0,0,0,0,0,0,0,0,104,174,7,0,216,3,8,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,1,0,8,0,0,0,0,0,0,0,0,0,0,94,51,0,0,14,5,0,0,0,0,0,0,0,0,0,0,92,12,0,0,158,10,0,0,130,14,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,18,8,0,0,0,0,0,0,0,0,0,0,0,0,0,184,230,7,0,64,15,8,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,3,1,1,0,0,0,0,0,0,0,0,0,0,0,144,35,0,0,90,20,0,0,0,0,0,0,0,0,0,0,232,37,0,0,160,57,0,0,164,18,0,0,52,9,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,49,8,0,216,96,8,0,0,0,0,0,0,0,0,0,104,174,7,0,232,41,8,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,1,1,0,0,0,0,0,0,0,0,0,0,0,98,15,0,0,18,11,0,0,0,0,0,0,0,0,0,0,70,12,0,0,102,47,0,0,240,17,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,62,8,0,216,96,8,0,0,0,0,0,0,0,0,0,104,174,7,0,152,55,8,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,1,1,0,0,0,0,0,0,0,0,0,0,0,186,48,0,0,252,24,0,0,0,0,0,0,0,0,0,0,70,12,0,0,102,47,0,0,240,17,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,69,8,0,216,96,8,0,0,0,0,0,0,0,0,0,104,174,7,0,216,65,8,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,1,1,0,0,0,0,0,0,0,0,0,0,0,108,57,0,0,92,36,0,0,0,0,0,0,0,0,0,0,70,12,0,0,102,47,0,0,240,17,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,78,8,0,216,96,8,0,0,0,0,0,0,0,0,0,104,174,7,0,224,72,8,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,1,1,0,0,0,0,0,0,0,0,0,0,0,50,41,0,0,46,7,0,0,0,0,0,0,0,0,0,0,70,12,0,0,102,47,0,0,44,11,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,96,8,0,0,0,0,0,0,0,0,0,0,0,0,0,104,174,7,0,0,213,7,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,3,1,1,0,0,0,0,0,0,0,0,0,0,0,32,59,0,0,38,48,0,0,0,0,0,0,0,0,0,0,70,12,0,0,102,47,0,0,156,14,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,195,8,0,224,1,1,0,0,0,0,0,0,0,0,0,184,168,7,0,200,190,8,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,1,4,0,0,0,0,0,0,0,0,0,0,0,232,2,0,0,52,34,0,0,0,0,0,0,0,0,0,0,158,51,0,0,100,23,0,0,170,15,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,205,8,0,224,1,1,0,0,0,0,0,0,0,0,0,184,168,7,0,64,200,8,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,1,4,0,0,0,0,0,0,0,0,0,0,0,184,17,0,0,122,40,0,0,0,0,0,0,0,0,0,0,158,51,0,0,100,23,0,0,170,15,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,218,8,0,224,1,1,0,0,0,0,0,0,0,0,0,184,168,7,0,160,209,8,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,1,4,0,0,0,0,0,0,0,0,0,0,0,60,42,0,0,142,41,0,0,0,0,0,0,0,0,0,0,158,51,0,0,100,23,0,0,170,15,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,234,8,0,224,1,1,0,0,0,0,0,0,0,0,0,184,168,7,0,144,226,8,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,1,4,0,0,0,0,0,0,0,0,0,0,0,120,7,0,0,224,29,0,0,0,0,0,0,0,0,0,0,158,51,0,0,100,23,0,0,170,15,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,140,8,0,224,1,1,0,0,0,0,0,0,0,0,0,184,168,7,0,208,135,8,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,1,4,0,0,0,0,0,0,0,0,0,0,0,14,60,0,0,108,29,0,0,0,0,0,0,0,0,0,0,158,51,0,0,100,23,0,0,170,15,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,152,8,0,224,1,1,0,0,0,0,0,0,0,0,0,184,168,7,0,136,145,8,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,1,4,0,0,0,0,0,0,0,0,0,0,0,8,59,0,0,122,6,0,0,0,0,0,0,0,0,0,0,158,51,0,0,100,23,0,0,170,15,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,169,8,0,224,1,1,0,0,0,0,0,0,0,0,0,184,168,7,0,48,158,8,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,1,4,0,0,0,0,0,0,0,0,0,0,0,170,15,0,0,50,17,0,0,0,0,0,0,0,0,0,0,158,51,0,0,100,23,0,0,170,15,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,185,8,0,224,1,1,0,0,0,0,0,0,0,0,0,184,168,7,0,112,176,8,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,1,4,0,0,0,0,0,0,0,0,0,0,0,212,15,0,0,22,33,0,0,0,0,0,0,0,0,0,0,158,51,0,0,100,23,0,0,170,15,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,130,8,0,224,1,1,0,0,0,0,0,0,0,0,0,104,221,5,0,96,124,8,0,0,0,0,0,192,154,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,1,4,0,0,0,0,0,0,0,0,0,0,0,228,35,0,0,246,44,0,0,0,0,0,0,0,0,0,0,158,51,0,0,100,23,0,0,134,3,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,249,8,0,224,1,1,0,0,0,0,0,0,0,0,0,184,168,7,0,40,241,8,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,1,4,0,0,0,0,0,0,0,0,0,0,0,114,30,0,0,118,33,0,0,0,0,0,0,0,0,0,0,158,51,0,0,100,23,0,0,170,15,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,48,254,8,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,1,4,0,0,0,0,0,0,0,0,0,0,0,152,34,0,0,226,9,0,0,0,0,0,0,0,0,0,0,158,51,0,0,100,23,0,0,170,15,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,119,8,0,224,1,1,0,0,0,0,0,0,0,0,0,104,221,5,0,248,112,8,0,0,0,0,0,160,213,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,1,4,0,0,0,0,0,0,0,0,0,0,0,226,28,0,0,232,3,0,0,0,0,0,0,0,0,0,0,158,51,0,0,100,23,0,0,172,14,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,181,7,0,208,228,7,0,0,0,0,0,0,0,0,0,240,3,2,0,216,177,7,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,1,0,0,0,0,0,0,0,0,0,0,0,74,48,0,0,156,46,0,0,0,0,0,0,0,0,0,0,104,50,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,194,7,0,208,228,7,0,0,0,0,0,0,0,0,0,240,3,2,0,200,186,7,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,1,0,0,0,0,0,0,0,0,0,0,0,18,52,0,0,248,44,0,0,0,0,0,0,0,0,0,0,104,50,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,207,7,0,208,228,7,0,0,0,0,0,0,0,0,0,240,3,2,0,88,201,7,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,1,0,0,0,0,0,0,0,0,0,0,0,196,34,0,0,70,23,0,0,0,0,0,0,0,0,0,0,104,50,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,245,2,0,208,228,7,0,0,0,0,0,0,0,0,0,240,3,2,0,144,242,2,0,0,0,0,0,192,154,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,7,1,0,0,0,0,0,0,0,0,0,0,0,82,62,0,0,214,4,0,0,0,0,0,0,0,0,0,0,104,50,0,0,0,0,0,0,202,14,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,217,7,0,208,228,7,0,0,0,0,0,0,0,0,0,240,3,2,0,176,213,7,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,1,0,0,0,0,0,0,0,0,0,0,0,86,4,0,0,232,34,0,0,0,0,0,0,0,0,0,0,104,50,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,228,7,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,120,221,7,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,7,1,0,0,0,0,0,0,0,0,0,0,0,56,44,0,0,222,36,0,0,0,0,0,0,0,0,0,0,104,50,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,17,1,0,48,81,1,0,0,0,0,0,0,0,0,0,184,168,7,0,136,12,1,0,0,0,0,0,192,223,4,0,160,229,3,0,128,6,1,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,1,4,0,0,0,0,0,0,0,0,0,0,0,122,8,0,0,0,41,0,0,0,0,0,0,0,0,0,0,252,29,0,0,152,39,0,0,44,13,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,45,1,0,48,81,1,0,0,0,0,0,0,0,0,0,184,168,7,0,64,37,1,0,0,0,0,0,192,223,4,0,160,229,3,0,208,27,1,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,1,4,0,0,0,0,0,0,0,0,0,0,0,230,30,0,0,34,35,0,0,0,0,0,0,0,0,0,0,252,29,0,0,152,39,0,0,170,15,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,61,1,0,48,81,1,0,0,0,0,0,0,0,0,0,184,168,7,0,208,52,1,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,1,4,0,0,0,0,0,0,0,0,0,0,0,116,55,0,0,232,31,0,0,0,0,0,0,0,0,0,0,252,29,0,0,152,39,0,0,170,15,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,81,1,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,48,67,1,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,1,4,0,0,0,0,0,0,0,0,0,0,0,142,1,0,0,156,28,0,0,0,0,0,0,0,0,0,0,252,29,0,0,152,39,0,0,170,15,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,18,8,0,24,63,8,0,0,0,0,0,0,0,0,0,0,38,7,0,248,15,8,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,8,0,0,0,0,0,0,0,230,61,0,0,172,27,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,249,2,0,24,63,8,0,0,0,0,0,0,0,0,0,0,38,7,0,80,247,2,0,0,0,0,0,192,154,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,8,0,0,0,0,0,0,0,26,58,0,0,242,36,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,202,14,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,27,8,0,24,63,8,0,0,0,0,0,0,0,0,0,0,38,7,0,168,22,8,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,8,0,0,0,0,0,0,0,186,5,0,0,152,40,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,36,8,0,24,63,8,0,0,0,0,0,0,0,0,0,0,38,7,0,56,30,8,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,8,0,0,0,0,0,0,0,164,18,0,0,24,46,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,50,8,0,24,63,8,0,0,0,0,0,0,0,0,0,0,38,7,0,0,43,8,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,8,0,0,0,0,0,0,0,50,34,0,0,226,34,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,63,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,176,56,8,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,8,0,0,0,0,0,0,0,112,62,0,0,216,36,0,0,0,0,0,0,0,0,0,0,16,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,46,2,0,80,141,2,0,0,0,0,0,0,0,0,0,240,3,2,0,40,35,2,0,0,0,0,0,192,223,4,0,96,103,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,3,0,0,0,0,0,2,1,4,0,0,0,0,0,0,0,0,0,0,0,124,16,0,0,156,26,0,0,0,0,0,0,0,0,0,0,84,6,0,0,158,18,0,0,44,13,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,171,1,0,80,141,2,0,0,0,0,0,0,0,0,0,240,3,2,0,88,163,1,0,120,155,4,0,192,154,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,3,0,0,0,0,0,1,1,4,0,0,0,0,0,0,0,0,0,0,0,48,1,0,0,252,46,0,0,0,0,0,0,0,0,0,0,84,6,0,0,158,18,0,0,172,9,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,185,1,0,80,141,2,0,0,0,0,0,0,0,0,0,240,3,2,0,216,177,1,0,0,0,0,0,192,154,4,0,96,103,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,3,0,0,0,0,0,2,1,4,0,0,0,0,0,0,0,0,0,0,0,238,45,0,0,72,38,0,0,0,0,0,0,0,0,0,0,74,9,0,0,30,36,0,0,144,6,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,230,1,0,80,141,2,0,0,0,0,0,0,0,0,0,240,3,2,0,192,216,1,0,120,155,4,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,3,0,0,0,0,0,1,1,4,0,0,0,0,0,0,0,0,0,0,0,90,32,0,0,240,18,0,0,0,0,0,0,0,0,0,0,84,6,0,0,158,18,0,0,84,13,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,253,1,0,80,141,2,0,0,0,0,0,0,0,0,0,240,3,2,0,104,241,1,0,120,155,4,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,3,0,0,0,0,0,1,1,4,0,0,0,0,0,0,0,0,0,0,0,96,8,0,0,32,45,0,0,0,0,0,0,0,0,0,0,84,6,0,0,158,18,0,0,84,13,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,24,2,0,80,141,2,0,0,0,0,0,0,0,0,0,240,3,2,0,96,15,2,0,120,155,4,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,3,0,0,0,0,0,1,1,4,0,0,0,0,0,0,0,0,0,0,0,172,6,0,0,142,46,0,0,0,0,0,0,0,0,0,0,84,6,0,0,158,18,0,0,84,13,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,90,2,0,80,141,2,0,0,0,0,0,0,0,0,0,240,3,2,0,144,75,2,0,0,0,0,0,192,223,4,0,96,103,2,0,24,62,2,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,3,0,0,0,0,0,2,1,4,0,0,0,0,0,0,0,0,0,0,0,178,26,0,0,190,15,0,0,0,0,0,0,0,0,0,0,84,6,0,0,158,18,0,0,44,13,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,156,1,0,80,141,2,0,0,0,0,0,0,0,0,0,240,3,2,0,112,144,1,0,0,0,0,0,192,154,4,0,160,229,3,0,144,131,1,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,3,0,0,0,0,0,1,1,4,0,0,0,0,0,0,0,0,0,0,0,90,51,0,0,144,19,0,0,0,0,0,0,0,0,0,0,84,6,0,0,158,18,0,0,150,12,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,94,1,0,80,141,2,0,0,0,0,0,0,0,0,0,240,3,2,0,40,88,1,0,0,0,0,0,192,154,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,3,0,0,0,0,0,1,1,4,0,0,0,0,0,0,0,0,0,0,0,224,57,0,0,220,14,0,0,0,0,0,0,0,0,0,0,84,6,0,0,158,18,0,0,150,12,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,203,1,0,80,141,2,0,0,0,0,0,0,0,0,0,240,3,2,0,136,192,1,0,0,0,0,0,192,154,4,0,96,103,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,3,0,0,0,0,0,2,1,4,0,0,0,0,0,0,0,0,0,0,0,138,41,0,0,234,34,0,0,0,0,0,0,0,0,0,0,74,9,0,0,30,36,0,0,24,9,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,118,1,0,80,141,2,0,0,0,0,0,0,0,0,0,240,3,2,0,112,105,1,0,0,0,0,0,192,223,4,0,96,103,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,1,0,0,3,0,0,0,0,0,2,1,4,0,0,0,0,0,0,0,0,0,0,0,40,15,0,0,188,28,0,0,0,0,0,0,0,0,0,0,84,6,0,0,158,18,0,0,44,13,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,141,2,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,232,116,2,0,0,0,0,0,192,223,4,0,96,103,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,3,0,0,0,0,0,2,1,4,0,0,0,0,0,0,0,0,0,0,0,236,38,0,0,160,16,0,0,0,0,0,0,0,0,0,0,84,6,0,0,158,18,0,0,44,13,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,251,2,0,80,106,8,0,0,0,0,0,0,0,0,0,184,230,7,0,0,251,2,0,0,0,0,0,192,154,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,53,0,0,0,2,0,0,0,0,0,1,7,2,0,0,0,0,0,0,0,0,0,0,0,132,59,0,0,96,41,0,0,0,0,0,0,0,0,0,0,220,56,0,0,0,0,0,0,202,14,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,224,0,0,0,128,1,0,0,3,0,0,0,4,0,0,0,160,69,8,0,80,106,8,0,0,0,0,0,0,0,0,0,184,230,7,0,168,66,8,0,0,0,0,0,104,91,8,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,1,7,2,0,0,0,0,0,0,0,0,0,0,0,106,4,0,0,132,4,0,0,0,0,0,0,0,0,0,0,220,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,224,0,0,0,128,1,0,0,3,0,0,0,4,0,0,0,80,106,8,0,0,0,0,0,0,0,0,0,0,0,0,0,184,230,7,0,56,99,8,0,0,0,0,0,104,91,8,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,1,7,2,0,0,0,0,0,0,0,0,0,0,0,184,41,0,0,60,4,0,0,0,0,0,0,0,0,0,0,220,56,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,224,0,0,0,128,1,0,0,3,0,0,0,4,0,0,0,72,121,8,0,40,2,1,0,0,0,0,0,0,0,0,0,0,38,7,0,216,113,8,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,1,7,4,0,0,0,0,0,0,0,0,0,0,0,20,29,0,0,132,43,0,0,0,0,0,0,0,0,0,0,136,20,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,131,8,0,40,2,1,0,0,0,0,0,0,0,0,0,0,38,7,0,208,124,8,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,1,7,4,0,0,0,0,0,0,0,0,0,0,0,228,50,0,0,44,17,0,0,0,0,0,0,0,0,0,0,136,20,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,250,8,0,40,2,1,0,0,0,0,0,0,0,0,0,0,38,7,0,216,241,8,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,1,7,4,0,0,0,0,0,0,0,0,0,0,0,2,56,0,0,20,29,0,0,0,0,0,0,0,0,0,0,136,20,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,141,8,0,40,2,1,0,0,0,0,0,0,0,0,0,0,38,7,0,96,136,8,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,1,7,4,0,0,0,0,0,0,0,0,0,0,0,74,20,0,0,52,31,0,0,0,0,0,0,0,0,0,0,136,20,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,153,8,0,40,2,1,0,0,0,0,0,0,0,0,0,0,38,7,0,160,146,8,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,1,7,4,0,0,0,0,0,0,0,0,0,0,0,6,50,0,0,168,38,0,0,0,0,0,0,0,0,0,0,136,20,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,170,8,0,40,2,1,0,0,0,0,0,0,0,0,0,0,38,7,0,72,161,8,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,1,7,4,0,0,0,0,0,0,0,0,0,0,0,2,25,0,0,66,47,0,0,0,0,0,0,0,0,0,0,136,20,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,186,8,0,40,2,1,0,0,0,0,0,0,0,0,0,0,38,7,0,240,176,8,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,1,7,4,0,0,0,0,0,0,0,0,0,0,0,114,61,0,0,228,43,0,0,0,0,0,0,0,0,0,0,136,20,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,196,8,0,40,2,1,0,0,0,0,0,0,0,0,0,0,38,7,0,48,191,8,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,1,7,4,0,0,0,0,0,0,0,0,0,0,0,86,8,0,0,104,18,0,0,0,0,0,0,0,0,0,0,136,20,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,205,8,0,40,2,1,0,0,0,0,0,0,0,0,0,0,38,7,0,208,200,8,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,1,7,4,0,0,0,0,0,0,0,0,0,0,0,196,15,0,0,84,29,0,0,0,0,0,0,0,0,0,0,136,20,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,255,2,0,40,2,1,0,0,0,0,0,0,0,0,0,0,38,7,0,208,253,2,0,0,0,0,0,192,154,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,4,0,0,0,0,0,1,7,4,0,0,0,0,0,0,0,0,0,0,0,86,55,0,0,132,5,0,0,0,0,0,0,0,0,0,0,136,20,0,0,0,0,0,0,202,14,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,219,8,0,40,2,1,0,0,0,0,0,0,0,0,0,0,38,7,0,88,210,8,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,1,7,4,0,0,0,0,0,0,0,0,0,0,0,172,45,0,0,110,26,0,0,0,0,0,0,0,0,0,0,136,20,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,235,8,0,40,2,1,0,0,0,0,0,0,0,0,0,0,38,7,0,184,227,8,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,1,7,4,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,86,10,0,0,0,0,0,0,0,0,0,0,136,20,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,232,254,8,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,4,0,0,0,0,0,1,7,4,0,0,0,0,0,0,0,0,0,0,0,152,59,0,0,28,48,0,0,0,0,0,0,0,0,0,0,136,20,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,12,1,0,104,193,1,0,0,0,0,0,0,0,0,0,168,163,7,0,232,7,1,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,1,7,4,0,0,0,0,0,0,0,0,0,0,0,204,35,0,0,58,20,0,0,0,0,0,0,0,0,0,0,72,20,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,5,3,0,104,193,1,0,0,0,0,0,0,0,0,0,168,163,7,0,112,2,3,0,0,0,0,0,192,154,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0])
.concat([4,0,0,0,0,0,1,7,4,0,0,0,0,0,0,0,0,0,0,0,126,0,0,0,184,32,0,0,0,0,0,0,0,0,0,0,72,20,0,0,0,0,0,0,202,14,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,29,1,0,104,193,1,0,0,0,0,0,0,0,0,0,168,163,7,0,8,18,1,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,1,7,4,0,0,0,0,0,0,0,0,0,0,0,224,58,0,0,76,23,0,0,0,0,0,0,0,0,0,0,72,20,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,134,1,0,104,193,1,0,0,0,0,0,0,0,0,0,168,163,7,0,96,120,1,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,1,7,4,0,0,0,0,0,0,0,0,0,0,0,102,59,0,0,46,17,0,0,0,0,0,0,0,0,0,0,72,20,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,157,1,0,104,193,1,0,0,0,0,0,0,0,0,0,168,163,7,0,120,145,1,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,1,7,4,0,0,0,0,0,0,0,0,0,0,0,246,15,0,0,108,1,0,0,0,0,0,0,0,0,0,0,72,20,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,172,1,0,104,193,1,0,0,0,0,0,0,0,0,0,168,163,7,0,72,164,1,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,1,7,4,0,0,0,0,0,0,0,0,0,0,0,8,42,0,0,228,7,0,0,0,0,0,0,0,0,0,0,72,20,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,46,1,0,104,193,1,0,0,0,0,0,0,0,0,0,168,163,7,0,104,38,1,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,1,7,4,0,0,0,0,0,0,0,0,0,0,0,28,56,0,0,166,46,0,0,0,0,0,0,0,0,0,0,72,20,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,62,1,0,104,193,1,0,0,0,0,0,0,0,0,0,168,163,7,0,168,54,1,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,1,7,4,0,0,0,0,0,0,0,0,0,0,0,186,45,0,0,212,9,0,0,0,0,0,0,0,0,0,0,72,20,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,75,1,0,104,193,1,0,0,0,0,0,0,0,0,0,168,163,7,0,232,67,1,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,1,7,4,0,0,0,0,0,0,0,0,0,0,0,172,59,0,0,200,19,0,0,0,0,0,0,0,0,0,0,72,20,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,89,1,0,104,193,1,0,0,0,0,0,0,0,0,0,168,163,7,0,64,82,1,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,1,7,4,0,0,0,0,0,0,0,0,0,0,0,62,56,0,0,178,42,0,0,0,0,0,0,0,0,0,0,72,20,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,107,1,0,104,193,1,0,0,0,0,0,0,0,0,0,168,163,7,0,176,95,1,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,1,7,4,0,0,0,0,0,0,0,0,0,0,0,142,24,0,0,32,48,0,0,0,0,0,0,0,0,0,0,72,20,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,193,1,0,0,0,0,0,0,0,0,0,0,0,0,0,168,163,7,0,224,178,1,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,4,0,0,0,0,0,1,7,4,0,0,0,0,0,0,0,0,0,0,0,250,56,0,0,212,45,0,0,0,0,0,0,0,0,0,0,72,20,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,224,7,0,24,10,8,0,0,0,0,0,0,0,0,0,104,174,7,0,240,220,7,0,0,0,0,0,192,223,4,0,160,229,3,0,32,216,7,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,1,0,8,0,0,0,0,0,0,0,0,0,0,46,55,0,0,126,45,0,0,0,0,0,0,0,0,0,0,92,12,0,0,92,26,0,0,44,13,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,211,7,0,24,10,8,0,0,0,0,0,0,0,0,0,104,174,7,0,136,206,7,0,0,0,0,0,192,223,4,0,160,229,3,0,160,199,7,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,1,0,8,0,0,0,0,0,0,0,0,0,0,138,0,0,0,194,25,0,0,0,0,0,0,0,0,0,0,92,12,0,0,92,26,0,0,86,10,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,238,7,0,24,10,8,0,0,0,0,0,0,0,0,0,104,174,7,0,176,232,7,0,0,0,0,0,192,223,4,0,160,229,3,0,136,227,7,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,1,0,8,0,0,0,0,0,0,0,0,0,0,116,56,0,0,80,8,0,0,0,0,0,0,0,0,0,0,92,12,0,0,92,26,0,0,30,3,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,14,3,0,232,7,2,0,0,0,0,0,0,0,0,0,32,127,5,0,248,13,3,0,0,0,0,0,192,154,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,0,0,0,0,0,0,0,0,240,44,0,0,34,36,0,0,0,0,0,0,0,0,0,0,28,30,0,0,0,0,0,0,202,14,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,218,1,0,232,7,2,0,0,0,0,0,0,0,0,0,32,127,5,0,136,204,1,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,0,0,0,0,0,0,0,0,138,62,0,0,48,39,0,0,0,0,0,0,0,0,0,0,28,30,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,9,3,0,232,7,2,0,0,0,0,0,0,0,0,0,32,127,5,0,176,7,3,0,0,0,0,0,192,154,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,0,0,0,0,0,0,0,0,24,6,0,0,102,9,0,0,0,0,0,0,0,0,0,0,28,30,0,0,0,0,0,0,202,14,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,242,1,0,232,7,2,0,0,0,0,0,0,0,0,0,32,127,5,0,16,232,1,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,0,0,0,0,0,0,0,0,254,23,0,0,84,1,0,0,0,0,0,0,0,0,0,0,28,30,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,7,2,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,40,0,2,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,7,8,0,0,0,0,0,0,0,0,0,0,0,42,4,0,0,190,0,0,0,0,0,0,0,0,0,0,0,28,30,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,200,2,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,104,168,2,0,0,0,0,0,192,223,4,0,160,229,3,0,152,153,2,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,1,0,16,0,0,0,0,0,0,0,0,0,0,60,37,0,0,180,2,0,0,0,0,0,0,0,0,0,0,140,24,0,0,220,2,0,0,44,13,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,26,2,0,144,155,2,0,0,0,0,0,0,0,0,0,184,12,8,0,144,16,2,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,0,64,0,0,0,0,0,0,0,0,0,0,230,28,0,0,254,13,0,0,0,0,0,0,0,0,0,0,4,5,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,47,2,0,144,155,2,0,0,0,0,0,0,0,0,0,184,12,8,0,168,36,2,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,0,64,0,0,0,0,0,0,0,0,0,0,8,52,0,0,108,6,0,0,0,0,0,0,0,0,0,0,4,5,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,76,2,0,144,155,2,0,0,0,0,0,0,0,0,0,184,12,8,0,120,64,2,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,0,64,0,0,0,0,0,0,0,0,0,0,204,45,0,0,124,28,0,0,0,0,0,0,0,0,0,0,4,5,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,104,2,0,144,155,2,0,0,0,0,0,0,0,0,0,184,12,8,0,96,92,2,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,0,64,0,0,0,0,0,0,0,0,0,0,226,12,0,0,198,4,0,0,0,0,0,0,0,0,0,0,4,5,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,18,3,0,144,155,2,0,0,0,0,0,0,0,0,0,184,12,8,0,176,15,3,0,0,0,0,0,192,154,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,7,0,64,0,0,0,0,0,0,0,0,0,0,160,19,0,0,122,38,0,0,0,0,0,0,0,0,0,0,4,5,0,0,0,0,0,0,202,14,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,131,2,0,144,155,2,0,0,0,0,0,0,0,0,0,184,12,8,0,240,118,2,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,0,64,0,0,0,0,0,0,0,0,0,0,220,15,0,0,188,14,0,0,0,0,0,0,0,0,0,0,4,5,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,155,2,0,0,0,0,0,0,0,0,0,0,0,0,0,184,12,8,0,0,143,2,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,7,0,64,0,0,0,0,0,0,0,0,0,0,236,30,0,0,72,42,0,0,0,0,0,0,0,0,0,0,4,5,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,195,2,0,0,0,0,0,0,0,0,0,0,0,0,0,160,217,6,0,96,191,2,0,0,0,0,0,232,189,2,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,0,0,2,0,0,0,0,0,1,1,0,0,1,0,0,0,0,0,0,0,0,0,202,30,0,0,54,10,0,0,0,0,0,0,0,0,0,0,158,51,0,0,100,23,0,0,12,11,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,34,3,0,0,0,0,0,0,0,0,0,0,0,0,0,184,230,7,0,224,243,2,0,0,0,0,0,136,232,1,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,4,0,0,2,0,0,0,0,0,1,1,0,0,1,0,0,0,0,0,0,0,0,0,174,5,0,0,170,19,0,0,0,0,0,0,0,0,0,0,158,51,0,0,100,23,0,0,12,11,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,246,2,0,0,0,0,0,0,0,0,0,0,0,0,0,104,129,6,0,144,201,2,0,0,0,0,0,32,46,8,0,152,4,4,0,200,169,2,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,2,0,1,7,0,16,0,0,0,0,0,0,0,0,0,0,228,19,0,0,66,40,0,0,0,0,0,0,0,0,0,0,182,7,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,152,6,0,136,158,6,0,0,0,0,0,0,0,0,0,104,221,5,0,152,148,6,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,1,0,8,0,0,0,0,0,0,0,0,0,0,104,63,0,0,40,3,0,0,0,0,0,0,0,0,0,0,170,62,0,0,78,41,0,0,170,15,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,196,3,0,72,62,4,0,0,0,0,0,0,0,0,0,104,221,5,0,104,170,3,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,1,1,0,0,0,0,0,0,0,0,0,0,0,192,57,0,0,240,24,0,0,0,0,0,0,0,0,0,0,14,0,0,0,132,44,0,0,170,15,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,5,4,0,72,62,4,0,0,0,0,0,0,0,0,0,104,221,5,0,120,227,3,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,1,1,0,0,0,0,0,0,0,0,0,0,0,152,56,0,0,162,42,0,0,0,0,0,0,0,0,0,0,14,0,0,0,132,44,0,0,170,15,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,145,3,0,72,62,4,0,0,0,0,0,0,0,0,0,104,221,5,0,8,121,3,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,1,1,0,0,0,0,0,0,0,0,0,0,0,8,18,0,0,196,11,0,0,0,0,0,0,0,0,0,0,14,0,0,0,132,44,0,0,170,15,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,97,3,0,72,62,4,0,0,0,0,0,0,0,0,0,104,221,5,0,40,82,3,0,0,0,0,0,192,154,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,1,1,0,0,0,0,0,0,0,0,0,0,0,38,1,0,0,126,34,0,0,0,0,0,0,0,0,0,0,14,0,0,0,132,44,0,0,152,19,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,67,3,0,72,62,4,0,0,0,0,0,0,0,0,0,104,221,5,0,32,53,3,0,0,0,0,0,192,154,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,1,1,0,0,0,0,0,0,0,0,0,0,0,212,42,0,0,110,1,0,0,0,0,0,0,0,0,0,0,14,0,0,0,132,44,0,0,144,7,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,62,4,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,32,33,4,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,1,1,0,0,0,0,0,0,0,0,0,0,0,206,61,0,0,172,46,0,0,0,0,0,0,0,0,0,0,14,0,0,0,132,44,0,0,170,15,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,141,5,0,40,50,6,0,0,0,0,0,0,0,0,0,144,47,2,0,80,113,5,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,1,1,4,0,0,0,0,0,0,0,0,0,0,0,220,47,0,0,64,41,0,0,0,0,0,0,0,0,0,0,54,23,0,0,242,2,0,0,170,15,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,217,5,0,40,50,6,0,0,0,0,0,0,0,0,0,144,47,2,0,16,180,5,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,1,1,4,0,0,0,0,0,0,0,0,0,0,0,110,23,0,0,178,13,0,0,0,0,0,0,0,0,0,0,54,23,0,0,242,2,0,0,170,15,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,20,5,0,40,50,6,0,0,0,0,0,0,0,0,0,144,47,2,0,200,241,4,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,1,1,4,0,0,0,0,0,0,0,0,0,0,0,94,31,0,0,74,22,0,0,0,0,0,0,0,0,0,0,54,23,0,0,242,2,0,0,170,15,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,81,5,0,40,50,6,0,0,0,0,0,0,0,0,0,144,47,2,0,128,51,5,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,1,1,4,0,0,0,0,0,0,0,0,0,0,0,18,15,0,0,208,26,0,0,0,0,0,0,0,0,0,0,54,23,0,0,242,2,0,0,170,15,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,113,4,0,40,50,6,0,0,0,0,0,0,0,0,0,144,47,2,0,32,88,4,0,0,0,0,0,192,154,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,4,0,0,0,0,0,1,1,4,0,0,0,0,0,0,0,0,0,0,0,140,45,0,0,94,3,0,0,0,0,0,0,0,0,0,0,54,23,0,0,242,2,0,0,130,8,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,208,4,0,40,50,6,0,0,0,0,0,0,0,0,0,144,47,2,0,32,174,4,0,0,0,0,0,192,154,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,4,0,0,0,0,0,1,1,4,0,0,0,0,0,0,0,0,0,0,0,246,43,0,0,142,23,0,0,0,0,0,0,0,0,0,0,54,23,0,0,242,2,0,0,226,11,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,50,6,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,192,9,6,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,4,0,0,0,0,0,1,1,4,0,0,0,0,0,0,0,0,0,0,0,242,52,0,0,170,9,0,0,0,0,0,0,0,0,0,0,54,23,0,0,242,2,0,0,170,15,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,36,3,0,168,123,3,0,0,0,0,0,0,0,0,0,184,12,8,0,24,12,3,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,1,7,4,0,0,0,0,0,0,0,0,0,0,0,64,4,0,0,182,13,0,0,0,0,0,0,0,0,0,0,220,3,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,20,3,0,168,123,3,0,0,0,0,0,0,0,0,0,184,12,8,0,136,19,3,0,0,0,0,0,192,154,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,4,0,0,0,0,0,1,7,4,0,0,0,0,0,0,0,0,0,0,0,42,23,0,0,50,9,0,0,0,0,0,0,0,0,0,0,220,3,0,0,0,0,0,0,202,14,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,69,3,0,168,123,3,0,0,0,0,0,0,0,0,0,184,12,8,0,24,56,3,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,1,7,4,0,0,0,0,0,0,0,0,0,0,0,28,61,0,0,198,10,0,0,0,0,0,0,0,0,0,0,220,3,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,123,3,0,0,0,0,0,0,0,0,0,0,0,0,0,184,12,8,0,8,84,3,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,4,0,0,0,0,0,1,7,4,0,0,0,0,0,0,0,0,0,0,0,104,10,0,0,124,20,0,0,0,0,0,0,0,0,0,0,220,3,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,172,3,0,136,165,6,0,0,0,0,0,0,0,0,0,0,38,7,0,128,148,3,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,3,0,0,0,0,0,1,7,4,0,0,0,0,0,0,0,0,0,0,0,180,52,0,0,18,18,0,0,0,0,0,0,0,0,0,0,90,58,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,230,3,0,136,165,6,0,0,0,0,0,0,0,0,0,0,38,7,0,120,199,3,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,3,0,0,0,0,0,1,7,4,0,0,0,0,0,0,0,0,0,0,0,64,3,0,0,24,48,0,0,0,0,0,0,0,0,0,0,90,58,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,35,4,0,136,165,6,0,0,0,0,0,0,0,0,0,0,38,7,0,192,8,4,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,3,0,0,0,0,0,1,7,4,0,0,0,0,0,0,0,0,0,0,0,182,14,0,0,60,25,0,0,0,0,0,0,0,0,0,0,90,58,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,29,3,0,136,165,6,0,0,0,0,0,0,0,0,0,0,38,7,0,248,23,3,0,0,0,0,0,192,154,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,3,0,0,0,0,0,1,7,4,0,0,0,0,0,0,0,0,0,0,0,86,27,0,0,38,36,0,0,0,0,0,0,0,0,0,0,90,58,0,0,0,0,0,0,202,14,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,91,4,0,136,165,6,0,0,0,0,0,0,0,0,0,0,38,7,0,16,64,4,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,3,0,0,0,0,0,1,7,4,0,0,0,0,0,0,0,0,0,0,0,186,53,0,0,118,20,0,0,0,0,0,0,0,0,0,0,90,58,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,165,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,184,115,4,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,3,0,0,0,0,0,1,7,4,0,0,0,0,0,0,0,0,0,0,0,210,15,0,0,60,30,0,0,0,0,0,0,0,0,0,0,90,58,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,84,5,0,88,191,6,0,0,0,0,0,0,0,0,0,0,38,7,0,176,54,5,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,3,0,0,0,0,0,1,7,4,0,0,0,0,0,0,0,0,0,0,0,168,54,0,0,76,1,0,0,0,0,0,0,0,0,0,0,216,27,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,144,5,0,88,191,6,0,0,0,0,0,0,0,0,0,0,38,7,0,152,115,5,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,3,0,0,0,0,0,1,7,4,0,0,0,0,0,0,0,0,0,0,0,40,16,0,0,110,32,0,0,0,0,0,0,0,0,0,0,216,27,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,54,6,0,88,191,6,0,0,0,0,0,0,0,0,0,0,38,7,0,160,13,6,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,3,0,0,0,0,0,1,7,4,0,0,0,0,0,0,0,0,0,0,0,208,31,0,0,92,9,0,0,0,0,0,0,0,0,0,0,216,27,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,221,5,0,88,191,6,0,0,0,0,0,0,0,0,0,0,38,7,0,64,183,5,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,3,0,0,0,0,0,1,7,4,0,0,0,0,0,0,0,0,0,0,0,130,56,0,0,136,17,0,0,0,0,0,0,0,0,0,0,216,27,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,35,3,0,88,191,6,0,0,0,0,0,0,0,0,0,0,38,7,0,216,31,3,0,0,0,0,0,192,154,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,3,0,0,0,0,0,1,7,4,0,0,0,0,0,0,0,0,0,0,0,190,34,0,0,18,7,0,0,0,0,0,0,0,0,0,0,216,27,0,0,0,0,0,0,202,14,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,191,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,224,101,6,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,3,0,0,0,0,0,1,7,4,0,0,0,0,0,0,0,0,0,0,0,218,28,0,0,230,29,0,0,0,0,0,0,0,0,0,0,216,27,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,93,3,0,224,105,3,0,0,0,0,0,0,0,0,0,184,168,7,0,120,90,3,0,0,0,0,0,176,102,3,0,160,229,3,0,152,88,3,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,1,1,0,0,0,0,0,0,0,0,0,0,0,220,38,0,0,92,35,0,0,0,0,0,0,0,0,0,0,252,61,0,0,244,50,0,0,44,13,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,100,3,0,224,105,3,0,0,0,0,0,0,0,0,0,184,168,7,0,152,97,3,0,0,0,0,0,176,102,3,0,160,229,3,0,248,95,3,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,1,1,0,0,0,0,0,0,0,0,0,0,0,90,46,0,0,90,4,0,0,0,0,0,0,0,0,0,0,252,61,0,0,244,50,0,0,170,15,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,157,7,0,192,176,8,0,0,0,0,0,0,0,0,0,144,47,2,0,24,112,7,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,1,0,2,0,0,0,0,0,0,0,0,0,0,54,18,0,0,12,2,0,0,0,0,0,0,0,0,0,0,50,46,0,0,162,29,0,0,170,15,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,4,8,0,192,176,8,0,0,0,0,0,0,0,0,0,144,47,2,0,240,206,7,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,1,0,2,0,0,0,0,0,0,0,0,0,0,50,29,0,0,36,25,0,0,0,0,0,0,0,0,0,0,50,46,0,0,162,29,0,0,170,15,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,229,6,0,192,176,8,0,0,0,0,0,0,0,0,0,144,47,2,0,152,186,6,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,1,0,2,0,0,0,0,0,0,0,0,0,0,246,0,0,0,206,1,0,0,0,0,0,0,0,0,0,0,50,46,0,0,162,29,0,0,170,15,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,141,6,0,192,176,8,0,0,0,0,0,0,0,0,0,144,47,2,0,232,96,6,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,1,0,2,0,0,0,0,0,0,0,0,0,0,40,59,0,0,6,25,0,0,0,0,0,0,0,0,0,0,50,46,0,0,162,29,0,0,64,12,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,176,8,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,104,56,8,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,1,0,2,0,0,0,0,0,0,0,0,0,0,6,4,0,0,232,9,0,0,0,0,0,0,0,0,0,0,50,46,0,0,162,29,0,0,170,15,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,61,8,0,248,99,8,0,0,0,0,0,0,0,0,0,32,127,5,0,168,9,8,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,1,7,2,0,0,0,64,0,0,0,0,0,0,0,226,53,0,0,164,25,0,0,0,0,0,0,0,0,0,0,34,60,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,224,0,0,0,128,1,0,0,3,0,0,0,4,0,0,0,88,185,8,0,248,99,8,0,0,0,0,0,0,0,0,0,32,127,5,0,24,119,8,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,1,7,2,0,0,0,64,0,0,0,0,0,0,0,158,14,0,0,158,13,0,0,0,0,0,0,0,0,0,0,34,60,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,224,0,0,0,128,1,0,0,3,0,0,0,4,0,0,0,136,61,1,0,248,99,8,0,0,0,0,0,0,0,0,0,32,127,5,0,200,248,8,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,1,7,2,0,0,0,64,0,0,0,0,0,0,0,40,43,0,0,204,29,0,0,0,0,0,0,0,0,0,0,34,60,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,224,0,0,0,128,1,0,0,3,0,0,0,4,0,0,0,192,47,3,0,248,99,8,0,0,0,0,0,0,0,0,0,32,127,5,0,240,44,3,0,0,0,0,0,192,154,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,53,0,0,0,2,0,0,0,0,0,1,7,2,0,0,0,64,0,0,0,0,0,0,0,150,14,0,0,222,47,0,0,0,0,0,0,0,0,0,0,34,60,0,0,0,0,0,0,202,14,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,224,0,0,0,128,1,0,0,3,0,0,0,4,0,0,0,152,253,1,0,248,99,8,0,0,0,0,0,0,0,0,0,32,127,5,0,192,155,1,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,1,7,2,0,0,0,64,0,0,0])
.concat([0,0,0,0,174,18,0,0,174,15,0,0,0,0,0,0,0,0,0,0,34,60,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,224,0,0,0,128,1,0,0,3,0,0,0,4,0,0,0,208,32,3,0,248,99,8,0,0,0,0,0,0,0,0,0,32,127,5,0,168,116,2,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,1,7,2,0,0,0,64,0,0,0,0,0,0,0,222,58,0,0,214,37,0,0,0,0,0,0,0,0,0,0,34,60,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,224,0,0,0,128,1,0,0,3,0,0,0,4,0,0,0,248,99,8,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,248,184,6,0,0,0,0,0,192,223,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,1,7,2,0,0,0,64,0,0,0,0,0,0,0,20,62,0,0,170,24,0,0,0,0,0,0,0,0,0,0,34,60,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,224,0,0,0,128,1,0,0,3,0,0,0,4,0,0,0,152,20,7,0,248,210,7,0,0,0,0,0,0,0,0,0,184,230,7,0,152,233,6,0,0,0,0,0,104,65,7,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,7,2,0,0,0,64,0,0,0,0,0,0,0,186,11,0,0,16,1,0,0,0,0,0,0,0,0,0,0,152,3,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,41,3,0,248,210,7,0,0,0,0,0,0,0,0,0,184,230,7,0,152,40,3,0,0,0,0,0,192,154,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,7,2,0,0,0,64,0,0,0,0,0,0,0,148,22,0,0,188,16,0,0,0,0,0,0,0,0,0,0,152,3,0,0,0,0,0,0,202,14,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,39,3,0,248,210,7,0,0,0,0,0,0,0,0,0,184,230,7,0,32,38,3,0,0,0,0,0,192,154,4,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,7,2,0,0,0,64,0,0,0,0,0,0,0,178,51,0,0,166,18,0,0,0,0,0,0,0,0,0,0,152,3,0,0,0,0,0,0,202,14,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,210,7,0,0,0,0,0,0,0,0,0,0,0,0,0,184,230,7,0,128,116,7,0,0,0,0,0,104,65,7,0,152,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,7,2,0,0,0,64,0,0,0,0,0,0,0,250,61,0,0,168,46,0,0,0,0,0,0,0,0,0,0,152,3,0,0,0,0,0,0,88,7,0,0,174,3,0,0,174,12,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,242,1,0,184,157,6,0,0,0,0,0,0,0,0,0,104,221,5,0,240,144,1,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,1,1,2,0,0,0,64,0,0,0,0,0,0,0,72,62,0,0,22,10,0,0,0,0,0,0,0,0,0,0,16,43,0,0,106,52,0,0,170,15,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,224,0,0,0,128,1,0,0,3,0,0,0,4,0,0,0,240,10,3,0,184,157,6,0,0,0,0,0,0,0,0,0,104,221,5,0,24,104,2,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,1,1,2,0,0,0,64,0,0,0,0,0,0,0,156,2,0,0,178,35,0,0,0,0,0,0,0,0,0,0,16,43,0,0,106,52,0,0,170,15,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,224,0,0,0,128,1,0,0,3,0,0,0,4,0,0,0,48,54,1,0,184,157,6,0,0,0,0,0,0,0,0,0,104,221,5,0,136,241,8,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,1,1,2,0,0,0,64,0,0,0,0,0,0,0,28,5,0,0,64,26,0,0,0,0,0,0,0,0,0,0,16,43,0,0,106,52,0,0,170,15,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,224,0,0,0,128,1,0,0,3,0,0,0,4,0,0,0,184,157,6,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,176,142,6,0,0,0,0,0,192,223,4,0,160,229,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,1,1,2,0,0,0,64,0,0,0,0,0,0,0,160,32,0,0,118,15,0,0,0,0,0,0,0,0,0,0,16,43,0,0,106,52,0,0,170,15,0,0,100,12,0,0,6,19,0,0,146,13,0,0,198,32,0,0,160,46,216,0,0,16,0,0,224,0,0,0,128,1,0,0,3,0,0,0,4,0,0,0,96,71,2,0,184,125,2,0,0,0,0,0,0,0,0,0,144,47,2,0,112,58,2,0,0,0,0,0,80,85,2,0,80,150,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,64,4,4,2,1,0,0,0,0,0,0,0,0,0,0,0,136,14,0,0,92,41,0,0,0,0,0,0,0,0,0,0,210,8,0,0,54,20,0,0,154,8,0,0,114,17,0,0,134,11,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,21,2,0,184,125,2,0,0,0,0,0,0,0,0,0,144,47,2,0,184,12,2,0,0,0,0,0,80,85,2,0,80,150,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,64,4,4,2,1,0,0,0,0,0,0,0,0,0,0,0,172,11,0,0,4,19,0,0,0,0,0,0,0,0,0,0,210,8,0,0,54,20,0,0,154,8,0,0,114,17,0,0,134,11,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,43,2,0,184,125,2,0,0,0,0,0,0,0,0,0,144,47,2,0,200,31,2,0,0,0,0,0,80,85,2,0,80,150,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,64,4,4,2,1,0,0,0,0,0,0,0,0,0,0,0,56,35,0,0,70,28,0,0,0,0,0,0,0,0,0,0,210,8,0,0,54,20,0,0,154,8,0,0,114,17,0,0,134,11,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,125,2,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,112,100,2,0,0,0,0,0,80,85,2,0,80,150,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,64,4,4,2,1,0,0,0,0,0,0,0,0,0,0,0,254,5,0,0,50,32,0,0,0,0,0,0,0,0,0,0,210,8,0,0,54,20,0,0,154,8,0,0,114,17,0,0,134,11,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,119,2,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,0,105,2,0,0,0,0,0,152,54,6,0,104,93,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,3,17,1,0,0,0,0,0,0,0,0,0,0,0,194,59,0,0,110,6,0,0,0,0,0,0,0,0,0,0,198,62,0,0,158,19,0,0,156,13,0,0,230,1,0,0,44,6,0,0,194,15,0,0,0,0,0,0,48,177,145,0,0,2,0,0,128,1,0,0,0,1,0,0,4,0,0,0,3,0,0,0,72,229,8,0,0,0,0,0,0,0,0,0,0,0,0,0,184,12,8,0,120,100,8,0,0,0,0,0,224,218,4,0,48,178,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,16,0,0,0,0,0,0,0,0,0,0,170,28,0,0,188,5,0,0,0,0,0,0,0,0,0,0,116,30,0,0,184,47,0,0,192,5,0,0,222,19,0,0,52,15,0,0,0,0,0,0,36,38,0,0,0,0,0,0,0,2,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,220,1,0,0,0,0,0,0,0,0,0,0,0,0,0,168,163,7,0,8,40,1,0,0,0,0,0,224,218,4,0,48,178,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,16,0,0,0,0,0,0,0,0,0,0,104,46,0,0,80,0,0,0,0,0,0,0,0,0,0,0,116,30,0,0,180,9,0,0,146,19,0,0,222,19,0,0,52,15,0,0,0,0,0,0,36,38,0,0,0,0,0,0,0,2,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,171,5,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,112,135,5,0,0,0,0,0,224,218,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,16,0,0,0,0,0,0,0,0,0,0,116,43,0,0,74,37,0,0,0,0,0,0,0,0,0,0,124,14,0,0,118,52,0,0,226,6,0,0,56,15,0,0,12,17,0,0,0,0,0,0,224,13,0,0,0,0,0,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,160,60,1,0,168,20,8,0,0,0,0,0,0,0,0,0,200,190,7,0,32,247,8,0,0,0,0,0,168,95,8,0,176,254,3,0,96,184,8,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,3,0,0,1,0,0,0,0,0,0,0,0,0,132,58,0,0,108,11,0,0,0,0,0,0,0,0,0,0,6,47,0,0,172,26,0,0,74,6,0,0,150,6,0,0,2,13,0,0,10,1,0,0,172,62,0,0,192,176,145,0,0,16,0,0,224,0,0,0,24,1,0,0,3,0,0,0,4,0,0,0,72,118,8,0,168,20,8,0,0,0,0,0,0,0,0,0,200,190,7,0,208,60,8,0,0,0,0,0,168,95,8,0,176,254,3,0,64,8,8,0,0,0,0,0,0,0,0,0,0,0,0,0,55,0,0,0,2,0,0,0,0,0,0,3,0,0,1,0,0,0,0,0,0,0,0,0,0,50,0,0,202,1,0,0,0,0,0,0,0,0,0,0,6,47,0,0,172,26,0,0,74,6,0,0,150,6,0,0,2,13,0,0,10,1,0,0,172,62,0,0,192,176,145,0,0,16,0,0,224,0,0,0,24,1,0,0,3,0,0,0,4,0,0,0,80,250,1,0,168,20,8,0,0,0,0,0,0,0,0,0,200,190,7,0,0,154,1,0,0,0,0,0,168,95,8,0,176,254,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,0,0,0,2,0,0,0,0,0,0,3,0,0,1,0,0,0,0,0,0,0,0,0,50,50,0,0,78,40,0,0,0,0,0,0,0,0,0,0,6,47,0,0,172,26,0,0,74,6,0,0,150,6,0,0,2,13,0,0,10,1,0,0,172,62,0,0,192,176,145,0,0,16,0,0,224,0,0,0,24,1,0,0,3,0,0,0,4,0,0,0,8,30,3,0,168,20,8,0,0,0,0,0,0,0,0,0,200,190,7,0,168,113,2,0,0,0,0,0,168,95,8,0,176,254,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,3,0,0,1,0,0,0,0,0,0,0,0,0,40,20,0,0,192,19,0,0,0,0,0,0,0,0,0,0,6,47,0,0,172,26,0,0,74,6,0,0,150,6,0,0,2,13,0,0,10,1,0,0,172,62,0,0,192,176,145,0,0,16,0,0,224,0,0,0,24,1,0,0,3,0,0,0,4,0,0,0,168,20,8,0,0,0,0,0,0,0,0,0,0,0,0,0,200,190,7,0,176,176,6,0,0,0,0,0,168,95,8,0,176,254,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,2,0,0,0,0,0,0,3,0,0,1,0,0,0,0,0,0,0,0,0,190,33,0,0,62,34,0,0,0,0,0,0,0,0,0,0,6,47,0,0,172,26,0,0,74,6,0,0,150,6,0,0,2,13,0,0,10,1,0,0,172,62,0,0,192,176,145,0,0,16,0,0,224,0,0,0,24,1,0,0,3,0,0,0,4,0,0,0,216,8,5,0,184,162,5,0,0,0,0,0,0,0,0,0,200,190,7,0,96,229,4,0,0,0,0,0,128,161,4,0,216,142,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,11,0,0,4,0,0,0,0,0,0,0,0,0,246,56,0,0,46,38,0,0,0,0,0,0,0,0,0,0,14,50,0,0,228,37,0,0,18,12,0,0,24,8,0,0,14,5,0,0,0,0,0,0,60,41,0,0,0,0,0,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,69,5,0,184,162,5,0,0,0,0,0,0,0,0,0,200,190,7,0,192,38,5,0,0,0,0,0,128,161,4,0,216,142,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,11,0,0,4,0,0,0,0,0,0,0,0,0,66,21,0,0,36,43,0,0,0,0,0,0,0,0,0,0,14,50,0,0,96,12,0,0,18,12,0,0,24,8,0,0,14,5,0,0,0,0,0,0,60,41,0,0,0,0,0,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,193,4,0,184,162,5,0,0,0,0,0,0,0,0,0,200,190,7,0,72,161,4,0,0,0,0,0,144,84,8,0,216,142,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,11,0,0,4,0,0,0,0,0,0,0,0,0,88,60,0,0,222,12,0,0,0,0,0,0,0,0,0,0,14,50,0,0,228,37,0,0,18,12,0,0,24,8,0,0,14,5,0,0,0,0,0,0,60,41,0,0,0,0,0,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,162,5,0,0,0,0,0,0,0,0,0,0,0,0,0,200,190,7,0,248,100,5,0,0,0,0,0,168,183,7,0,216,142,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,11,0,0,4,0,0,0,0,0,0,0,0,0,186,40,0,0,172,44,0,0,0,0,0,0,0,0,0,0,14,50,0,0,32,17,0,0,18,12,0,0,24,8,0,0,14,5,0,0,0,0,0,0,60,41,0,0,0,0,0,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,249,2,0,40,83,5,0,0,0,0,0,0,0,0,0,64,171,7,0,24,94,2,0,0,0,0,0,80,233,1,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,0,20,2,0,0,0,0,0,0,0,0,0,0,0,60,12,0,0,24,29,0,0,0,0,0,0,0,0,0,0,226,19,0,0,220,30,0,0,104,9,0,0,138,9,0,0,92,12,0,0,0,0,0,0,152,25,0,0,0,0,0,0,0,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,40,83,5,0,0,0,0,0,0,0,0,0,0,0,0,0,64,171,7,0,184,107,6,0,0,0,0,0,192,223,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,0,20,2,0,0,0,0,0,0,0,0,0,0,0,8,10,0,0,214,31,0,0,0,0,0,0,0,0,0,0,226,19,0,0,220,30,0,0,104,9,0,0,138,9,0,0,92,12,0,0,0,0,0,0,152,25,0,0,0,0,0,0,0,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,96,135,1,0,40,83,5,0,0,0,0,0,0,0,0,0,64,171,7,0,32,47,1,0,0,0,0,0,192,223,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,0,20,2,0,0,0,0,0,0,0,0,0,0,0,84,9,0,0,154,13,0,0,0,0,0,0,0,0,0,0,226,19,0,0,220,30,0,0,104,9,0,0,138,9,0,0,92,12,0,0,0,0,0,0,152,25,0,0,0,0,0,0,0,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,72,51,8,0,40,83,5,0,0,0,0,0,0,0,0,0,64,171,7,0,64,255,7,0,0,0,0,0,192,154,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,53,0,0,0,2,0,0,0,0,0,0,20,2,0,0,0,0,0,0,0,0,0,0,0,238,39,0,0,204,26,0,0,0,0,0,0,0,0,0,0,226,19,0,0,220,30,0,0,104,9,0,0,138,9,0,0,92,12,0,0,0,0,0,0,152,25,0,0,0,0,0,0,0,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,136,235,8,0,40,83,5,0,0,0,0,0,0,0,0,0,64,171,7,0,32,171,8,0,0,0,0,0,192,154,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,53,0,0,0,2,0,0,0,0,0,0,20,2,0,0,0,0,0,0,0,0,0,0,0,212,24,0,0,92,14,0,0,0,0,0,0,0,0,0,0,226,19,0,0,220,30,0,0,12,4,0,0,138,9,0,0,92,12,0,0,0,0,0,0,152,25,0,0,0,0,0,0,0,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,88,248,6,0,176,80,8,0,0,0,0,0,0,0,0,0,104,174,7,0,160,207,6,0,0,0,0,0,192,154,4,0,176,109,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,19,0,0,1,0,0,0,0,0,0,0,0,0,248,27,0,0,222,21,0,0,0,0,0,0,0,0,0,0,164,53,0,0,12,23,0,0,168,17,0,0,74,15,0,0,88,5,0,0,158,3,0,0,16,30,0,0,72,173,145,0,0,1,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,176,80,8,0,0,0,0,0,0,0,0,0,0,0,0,0,104,174,7,0,40,230,7,0,0,0,0,0,176,237,2,0,176,109,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,19,0,0,1,0,0,0,0,0,0,0,0,0,134,27,0,0,142,17,0,0,0,0,0,0,0,0,0,0,164,53,0,0,12,23,0,0,168,17,0,0,74,15,0,0,88,5,0,0,158,3,0,0,16,30,0,0,72,173,145,0,0,1,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,240,82,7,0,176,80,8,0,0,0,0,0,0,0,0,0,104,174,7,0,248,35,7,0,0,0,0,0,176,237,2,0,176,109,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,19,0,0,1,0,0,0,0,0,0,0,0,0,200,10,0,0,178,30,0,0,0,0,0,0,0,0,0,0,164,53,0,0,12,23,0,0,168,17,0,0,74,15,0,0,88,5,0,0,158,3,0,0,16,30,0,0,72,173,145,0,0,1,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,88,179,7,0,176,80,8,0,0,0,0,0,0,0,0,0,104,174,7,0,152,132,7,0,0,0,0,0,176,237,2,0,176,109,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,19,0,0,1,0,0,0,0,0,0,0,0,0,238,36,0,0,52,15,0,0,0,0,0,0,0,0,0,0,164,53,0,0,12,23,0,0,168,17,0,0,74,15,0,0,88,5,0,0,158,3,0,0,16,30,0,0,72,173,145,0,0,1,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,168,179,1,0,152,159,1,0,0,0,0,0,0,0,0,0,144,47,2,0,72,83,1,0,0,0,0,0,176,237,2,0,168,84,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,19,0,8,0,0,0,0,0,0,0,0,0,0,100,54,0,0,140,35,0,0,0,0,0,0,0,0,0,0,122,30,0,0,44,61,0,0,32,12,0,0,192,10,0,0,42,10,0,0,28,16,0,0,112,12,0,0,0,173,145,0,0,8,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,104,225,7,0,152,159,1,0,0,0,0,0,0,0,0,0,144,47,2,0,48,175,7,0,0,0,0,0,192,154,4,0,168,84,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,0,19,0,8,0,0,0,0,0,0,0,0,0,0,116,46,0,0,224,21,0,0,0,0,0,0,0,0,0,0,122,30,0,0,68,18,0,0,118,9,0,0,192,10,0,0,182,1,0,0,108,14,0,0,176,38,0,0,0,173,145,0,0,8,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,48,156,2,0,152,159,1,0,0,0,0,0,0,0,0,0,144,47,2,0,152,27,2,0,0,0,0,0,176,237,2,0,168,84,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,19,0,8,0,0,0,0,0,0,0,0,0,0,92,28,0,0,4,23,0,0,0,0,0,0,0,0,0,0,122,30,0,0,68,18,0,0,32,12,0,0,192,10,0,0,42,10,0,0,28,16,0,0,112,12,0,0,0,173,145,0,0,8,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,152,159,1,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,160,146,5,0,0,0,0,0,176,237,2,0,168,84,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,19,0,8,0,0,0,0,0,0,0,0,0,0,118,43,0,0,108,18,0,0,0,0,0,0,0,0,0,0,122,30,0,0,68,18,0,0,32,12,0,0,192,10,0,0,42,10,0,0,28,16,0,0,112,12,0,0,0,173,145,0,0,8,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,192,140,7,0,208,36,8,0,0,0,0,0,0,0,0,0,144,47,2,0,240,93,7,0,0,0,0,0,40,161,4,0,8,153,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,64,0,6,2,0,64,0,0,0,0,0,0,0,0,0,0,206,62,0,0,238,2,0,0,0,0,0,0,0,0,0,0,196,58,0,0,246,27,0,0,14,4,0,0,164,2,0,0,20,14,0,0,0,0,0,0,106,0,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,36,8,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,240,187,7,0,0,0,0,0,40,161,4,0,8,153,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,64,0,6,2,0,64,0,0,0,0,0,0,0,0,0,0,28,4,0,0,20,25,0,0,0,0,0,0,0,0,0,0,196,58,0,0,246,27,0,0,14,4,0,0,164,2,0,0,20,14,0,0,0,0,0,0,106,0,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,13,4,0,160,49,2,0,0,0,0,0,0,0,0,0,216,194,1,0,32,11,4,0,0,0,0,0,192,154,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,8,0,0,2,0,0,0,0,0,0,16,0,8,0,0,0,0,0,0,0,0,0,0,208,46,0,0,238,6,0,0,0,0,0,0,0,0,0,0,138,50,0,0,100,60,0,0,2,20,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,208,123,5,0,160,49,2,0,0,0,0,0,0,0,0,0,216,194,1,0,72,121,5,0,0,0,0,0,192,154,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,8,0,0,2,0,0,0,0,0,0,16,0,8,0,0,0,0,0,0,0,0,0,0,112,41,0,0,248,29,0,0,0,0,0,0,0,0,0,0,198,52,0,0,40,51,0,0,8,2,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,136,131,5,0,160,49,2,0,0,0,0,0,0,0,0,0,216,194,1,0,144,125,5,0,0,0,0,0,192,154,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,39,8,0,0,2,0,0,0,0,0,0,16,0,8,0,0,0,0,0,0,0,0,0,0,80,0,0,0,198,18,0,0,0,0,0,0,0,0,0,0,52,6,0,0,250,0,0,0,118,16,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,160,49,2,0,0,0,0,0,0,0,0,0,0,0,0,0,216,194,1,0,88,97,1,0,72,150,4,0,88,19,1,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,118,34,0,0,62,28,0,0,0,0,0,0,0,0,0,0,36,31,0,0,0,0,0,0,200,16,0,0,128,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,0,248,3,0,16,50,4,0,0,0,0,0,0,0,0,0,104,174,7,0,40,214,3,0,0,0,0,0,128,161,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,11,0,0,1,0,0,0,0,0,0,0,0,0,90,3,0,0,218,12,0,0,0,0,0,0,0,0,0,0,68,17,0,0,144,45,0,0,92,18,0,0,82,3,0,0,246,2,0,0,152,1,0,0,92,6,0,0,144,173,145,0,0,2,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,186,3,0,16,50,4,0,0,0,0,0,0,0,0,0,104,174,7,0,248,160,3,0,0,0,0,0,144,84,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,11,0,0,1,0,0,0,0,0,0,0,0,0,44,22,0,0,12,21,0,0,0,0,0,0,0,0,0,0,68,17,0,0,144,45,0,0,92,18,0,0,82,3,0,0,246,2,0,0,152,1,0,0,92,6,0,0,144,173,145,0,0,2,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,50,4,0,0,0,0,0,0,0,0,0,0,0,0,0,104,174,7,0,192,22,4,0,0,0,0,0,168,183,7,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,3,11,0,0,1,0,0,0,0,0,0,0,0,0,42,60,0,0,78,10,0,0,0,0,0,0,0,0,0,0,68,17,0,0,18,62,0,0,92,18,0,0,82,3,0,0,246,2,0,0,152,1,0,0,92,6,0,0,144,173,145,0,0,2,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,108,5,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,232,76,5,0,0,0,0,0,224,218,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,16,0,0,0,0,0,0,0,0,0,0,196,9,0,0,136,13,0,0,0,0,0,0,0,0,0,0,124,14,0,0,134,59,0,0,96,16,0,0,56,15,0,0,12,17,0,0,0,0,0,0,224,13,0,0,0,0,0,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,32,26,1,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,192,151,8,0,0,0,0,0,176,237,2,0,168,84,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,19,0,0,1,0,0,0,0,0,0,0,0,0,252,15,0,0,104,33,0,0,0,0,0,0,0,0,0,0,138,11,0,0,202,3,0,0,102,9,0,0,70,0,0,0,218,19,0,0,20,4,0,0,108,31,0,0,56,177,145,0,0,4,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,144,234,1,0,152,18,2,0,0,0,0,0,0,0,0,0,96,159,4,0,224,220,1,0,0,0,0,0,128,130,1,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,16,64,0,0,0,0,0,0,0,0,0,0,0,244,40,0,0,118,45,0,0,0,0,0,0,0,0,0,0,58,25,0,0,146,24,0,0,98,3,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,128,178,7,0,16,80,8,0,0,0,0,0,0,0,0,0,104,174,7,0,0,132,7,0,0,0,0,0,168,138,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,19,1,8,0,0,0,0,0,0,0,0,0,0,6,57,0,0,134,26,0,0,0,0,0,0,0,0,0,0,80,35,0,0,132,38,0,0,24,16,0,0,152,11,0,0,102,11,0,0,74,1,0,0,174,15,0,0,64,173,145,0,0,3,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,80,82,7,0,16,80,8,0,0,0,0,0,0,0,0,0,104,174,7,0,56,35,7,0,0,0,0,0,176,237,2,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,19,1,8,0,0,0,0,0,0,0,0,0,0,26,26,0,0,254,4,0,0,0,0,0,0,0,0,0,0,80,35,0,0,132,38,0,0,144,17,0,0,152,11,0,0,102,11,0,0,74,1,0,0,174,15,0,0,64,173,145,0,0,3,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,16,80,8,0,0,0,0,0,0,0,0,0,0,0,0,0,104,174,7,0,120,229,7,0,0,0,0,0,176,237,2,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,19,1,8,0,0,0,0,0,0,0,0,0,0,148,23,0,0,190,39,0,0,0,0,0,0,0,0,0,0,80,35,0,0,212,5,0,0,242,0,0,0,152,11,0,0,102,11,0,0,74,1,0,0,174,15,0,0,64,173,145,0,0,3,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,56,34,5,0,8,45,5,0,0,0,0,0,0,0,0,0,232,167,7,0,192,31,5,0,0,0,0,0,40,223,1,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,0,0,0,0,30,44,0,0,166,13,0,0,0,0,0,0,0,0,0,0,162,41,0,0,146,32,0,0,150,19,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,8,45,5,0,0,0,0,0,0,0,0,0,0,0,0,0,232,167,7,0,48,41,5,0,0,0,0,0,48,37,5,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,2,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,0,0,0,0,130,11,0,0,230,32,0,0,0,0,0,0,0,0,0,0,250,32,0,0,218,41,0,0,146,8,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,208,243,5,0,24,214,6,0,0,0,0,0,0,0,0,0,104,174,7,0,208,203,5,0,0,0,0,0,128,161,4,0,216,142,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,11,0,0,4,0,0,0,0,0,0,0,0,0,102,30,0,0,50,41,0,0,0,0,0,0,0,0,0,0,130,36,0,0,220,62,0,0,174,16,0,0,24,8,0,0,14,5,0,0,0,0,0,0,60,41,0,0,0,0,0,0,0,16,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,168,76,6,0,24,214,6,0,0,0,0,0,0,0,0,0,104,174,7,0,216,34,6,0,0,0,0,0,144,84,8,0,216,142,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,11,0,0,4,0,0,0,0,0,0,0,0,0,34,63,0,0,34,40,0,0,0,0,0,0,0,0,0,0,130,36,0,0,38,4,0,0,174,16,0,0,24,8,0,0,14,5,0,0,0,0,0,0,60,41,0,0,0,0,0,0,0,16,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,24,214,6,0,0,0,0,0,0,0,0,0,0,0,0,0,104,174,7,0,16,126,6,0,0,0,0,0,168,183,7,0,216,142,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,11,0,0,4,0,0,0,0,0,0,0,0,0,136,10,0,0,62,26,0,0,0,0,0,0,0,0,0,0,130,36,0,0,220,62,0,0,174,16,0,0,24,8,0,0,14,5,0,0,0,0,0,0,60,41,0,0,0,0,0,0,0,16,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,192,225,7,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,128,175,7,0,0,0,0,0,32,46,8,0,240,85,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,19,4,8,0,0,0,0,0,0,0,0,0,0,4,51,0,0,132,31,0,0,0,0,0,0,0,0,0,0,108,48,0,0,228,33,0,0,22,18,0,0,32,4,0,0,120,0,0,0,54,14,0,0,62,2,0,0,8,173,145,0,0,4,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,72,224,2,0,0,0,0,0,0,0,0,0,0,0,0,0,64,164,6,0,200,254,5,0,0,0,0,0,144,84,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,3,11,0,1,0,0,0,0,0,0,0,0,0,0,248,55,0,0,24,34,0,0,0,0,0,0,0,0,0,0,62,35,0,0,50,28,0,0,136,5,0,0,186,3,0,0,250,19,0,0,76,17,0,0,194,11,0,0,168,173,145,0,0,4,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,180,1,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,176,8,1,0,0,0,0,0,0,193,8,0,240,85,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,19,0,16,0,0,0,0,0,0,0,0,0,0,16,41,0,0,86,11,0,0,0,0,0,0,0,0,0,0,108,48,0,0,228,33,0,0,228,3,0,0,32,4,0,0,120,0,0,0,54,14,0,0,62,2,0,0,8,173,145,0,0,4,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,144,41,1,0,120,223,1,0,0,0,0,0,0,0,0,0,104,174,7,0,176,230,8,0,0,0,0,0,72,226,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,190,47,0,0,98,24,0,0,0,0,0,0,0,0,0,0,190,37,0,0,28,52,0,0,114,6,0,0,62,8,0,0,92,16,0,0,16,7,0,0,172,10,0,0,40,175,145,0,0,8,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,223,1,0,0,0,0,0,0,0,0,0,0,0,0,0,104,174,7,0,240,125,1,0,0,0,0,0,72,226,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,28,21,0,0,70,14,0,0,0,0,0,0,0,0,0,0,190,37,0,0,28,52,0,0,114,6,0,0,62,8,0,0,92,16,0,0,16,7,0,0,172,10,0,0,40,175,145,0,0,8,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,161,2,0,72,197,1,0,0,0,0,0,0,0,0,0,104,221,5,0,232,30,2,0,0,0,0,0,176,237,2,0,168,84,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,19,4,8,0,0,0,0,0,0,0,0,0,0,40,48,0,0,242,12,0,0,0,0,0,0,0,0,0,0,204,11,0,0,124,59,0,0,118,4,0,0,44,4,0,0,118,17,0,0,214,13,0,0,210,26,0,0,24,173,145,0,0,8,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,56,182,1,0,72,197,1,0,0,0,0,0,0,0,0,0,104,221,5,0,176,85,1,0,0,0,0,0,176,237,2,0,168,84,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,19,4,8,0,0,0,0,0,0,0,0,0,0,132,8,0,0,114,43,0,0,0,0,0,0,0,0,0,0,204,11,0,0,124,59,0,0,118,4,0,0,44,4,0,0,118,17,0,0,214,13,0,0,210,26,0,0,24,173,145,0,0,8,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,72,197,1,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,88,161,5,0,0,0,0,0,176,237,2,0,168,84,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,19,4,8,0,0,0,0,0,0,0,0,0,0,52,56,0,0,8,16,0,0,0,0,0,0,0,0,0,0,204,11,0,0,124,59,0,0,118,4,0,0,44,4,0,0,118,17,0,0,214,13,0,0,210,26,0,0,24,173,145,0,0,8,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,192,48,8,0,0,0,0,0,0,0,0,0,0,0,0,0,216,194,1,0,72,252,7,0,0,0,0,0,104,238,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,216,1,0,0,78,46,0,0,0,0,0,0,0,0,0,0,92,56,0,0,248,61,0,0,104,5,0,0,218,16,0,0,166,13,0,0,164,1,0,0,68,57,0,0,128,175,145,0,96,0,0,0,240,0,0,0,196,0,0,0,4,0,0,0,3,0,0,0,176,188,3,0,0,0,0,0,0,0,0,0,0,0,0,0,64,164,6,0,88,185,3,0,0,0,0,0,240,49,5,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,8,0,0,2,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,0,0,0,0,100,24,0,0,28,17,0,0,0,0,0,0,0,0,0,0,46,12,0,0,182,52,0,0,128,1,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,8,218,1,0,16,254,3,0,0,0,0,0,0,0,0,0,240,3,2,0,8,120,1,0,0,0,0,0,208,210,4,0,144,172,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,10,0,8,0,0,0,0,0,0,0,0,0,0,178,18,0,0,10,45,0,0,0,0,0,0])
.concat([0,0,0,0,130,59,0,0,136,54,0,0,134,0,0,0,132,15,0,0,10,2,0,0,80,6,0,0,38,37,0,0,168,174,145,0,1,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,195,1,0,0,0,0,0,0,0,0,0,0,0,0,0,232,167,7,0,184,180,1,0,160,173,1,0,8,166,1,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,40,14,0,0,236,3,0,0,0,0,0,0,0,0,0,0,70,34,0,0,236,20,0,0,172,10,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,40,25,6,0,80,157,6,0,0,0,0,0,0,0,0,0,168,163,7,0,104,234,5,0,0,0,0,0,136,194,5,0,240,85,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,19,4,8,0,0,0,0,0,0,0,0,0,0,252,42,0,0,72,3,0,0,0,0,0,0,0,0,0,0,108,48,0,0,228,33,0,0,136,6,0,0,32,4,0,0,120,0,0,0,54,14,0,0,62,2,0,0,8,173,145,0,0,4,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,176,23,1,0,232,198,2,0,0,0,0,0,0,0,0,0,184,168,7,0,80,215,8,0,0,0,0,0,144,84,8,0,208,135,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,2,11,0,1,0,0,0,0,0,0,0,0,0,0,226,36,0,0,188,19,0,0,0,0,0,0,0,0,0,0,78,16,0,0,56,33,0,0,82,15,0,0,46,7,0,0,246,17,0,0,0,0,0,0,176,18,0,0,0,0,0,0,0,32,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,193,2,0,232,198,2,0,0,0,0,0,0,0,0,0,184,168,7,0,24,57,2,0,0,0,0,0,128,161,4,0,208,135,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,2,11,0,1,0,0,0,0,0,0,0,0,0,0,64,27,0,0,108,2,0,0,0,0,0,0,0,0,0,0,78,16,0,0,58,49,0,0,96,14,0,0,46,7,0,0,246,17,0,0,0,0,0,0,176,18,0,0,0,0,0,0,0,32,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,198,1,0,232,198,2,0,0,0,0,0,0,0,0,0,184,168,7,0,152,101,1,0,0,0,0,0,128,161,4,0,208,135,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,2,11,0,1,0,0,0,0,0,0,0,0,0,0,218,2,0,0,214,18,0,0,0,0,0,0,0,0,0,0,78,16,0,0,58,49,0,0,96,14,0,0,46,7,0,0,246,17,0,0,0,0,0,0,176,18,0,0,0,0,0,0,0,32,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,198,2,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,224,243,5,0,0,0,0,0,128,161,4,0,208,135,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,2,11,0,1,0,0,0,0,0,0,0,0,0,0,222,11,0,0,132,22,0,0,0,0,0,0,0,0,0,0,78,16,0,0,58,49,0,0,82,15,0,0,46,7,0,0,246,17,0,0,0,0,0,0,176,18,0,0,0,0,0,0,0,32,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,29,3,0,0,0,0,0,0,0,0,0,0,0,0,0,232,167,7,0,192,26,3,0,0,0,0,0,224,56,3,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,8,0,0,2,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,0,0,0,0,32,45,0,0,92,40,0,0,0,0,0,0,0,0,0,0,242,5,0,0,114,4,0,0,242,15,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,240,223,7,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,224,219,7,0,208,111,8,0,232,215,7,0,0,227,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,1,21,0,0,1,0,0,0,0,0,0,0,0,0,218,12,0,0,98,2,0,0,0,0,0,0,0,0,0,0,72,15,0,0,162,26,0,0,22,1,0,0,248,19,0,0,40,15,0,0,230,0,0,0,96,10,0,0,224,174,145,0,0,2,0,0,240,0,0,0,128,1,0,0,3,0,0,0,4,0,0,0,64,105,1,0,176,255,2,0,0,0,0,0,0,0,0,0,184,168,7,0,224,26,1,0,0,0,0,0,128,161,4,0,128,194,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,11,4,0,0,0,0,0,0,0,0,0,0,0,214,21,0,0,2,37,0,0,0,0,0,0,0,0,0,0,106,10,0,0,116,63,0,0,252,1,0,0,224,17,0,0,166,7,0,0,2,1,0,0,74,29,0,0,0,0,0,0,0,16,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,192,199,2,0,176,255,2,0,0,0,0,0,0,0,0,0,184,168,7,0,184,61,2,0,0,0,0,0,144,84,8,0,128,194,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,11,4,0,0,0,0,0,0,0,0,0,0,0,28,18,0,0,254,43,0,0,0,0,0,0,0,0,0,0,106,10,0,0,94,45,0,0,252,1,0,0,224,17,0,0,166,7,0,0,2,1,0,0,74,29,0,0,0,0,0,0,0,16,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,72,152,8,0,176,255,2,0,0,0,0,0,0,0,0,0,184,168,7,0,112,89,8,0,0,0,0,0,168,183,7,0,128,194,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,11,4,0,0,0,0,0,0,0,0,0,0,0,90,12,0,0,68,6,0,0,0,0,0,0,0,0,0,0,106,10,0,0,18,16,0,0,252,1,0,0,224,17,0,0,166,7,0,0,2,1,0,0,74,29,0,0,0,0,0,0,0,16,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,80,185,7,0,176,255,2,0,0,0,0,0,0,0,0,0,184,168,7,0,16,139,7,0,0,0,0,0,168,183,7,0,128,194,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,11,4,0,0,0,0,0,0,0,0,0,0,0,100,4,0,0,152,23,0,0,0,0,0,0,0,0,0,0,106,10,0,0,18,16,0,0,252,1,0,0,224,17,0,0,166,7,0,0,2,1,0,0,74,29,0,0,0,0,0,0,0,16,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,200,34,8,0,176,255,2,0,0,0,0,0,0,0,0,0,184,168,7,0,80,238,7,0,0,0,0,0,168,183,7,0,128,194,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,11,4,0,0,0,0,0,0,0,0,0,0,0,110,47,0,0,144,42,0,0,0,0,0,0,0,0,0,0,106,10,0,0,18,16,0,0,252,1,0,0,224,17,0,0,166,7,0,0,2,1,0,0,74,29,0,0,0,0,0,0,0,16,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,176,255,2,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,16,6,6,0,0,0,0,0,168,183,7,0,128,194,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,3,11,4,0,0,0,0,0,0,0,0,0,0,0,220,40,0,0,36,36,0,0,0,0,0,0,0,0,0,0,106,10,0,0,18,16,0,0,252,1,0,0,224,17,0,0,166,7,0,0,2,1,0,0,74,29,0,0,0,0,0,0,0,16,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,8,60,1,0,40,93,1,0,0,0,0,0,0,0,0,0,96,135,2,0,240,50,1,0,0,0,0,0,192,154,4,0,80,164,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,10,0,8,0,0,0,0,0,0,0,0,0,0,46,37,0,0,22,15,0,0,0,0,0,0,0,0,0,0,244,56,0,0,24,5,0,0,94,19,0,0,24,3,0,0,158,1,0,0,70,6,0,0,0,0,0,0,0,0,0,0,0,4,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,89,7,0,0,0,0,0,0,0,0,0,0,0,0,0,64,171,7,0,152,252,6,0,200,212,6,0,144,84,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,3,11,4,0,0,0,0,0,0,0,0,0,0,0,36,19,0,0,142,44,0,0,0,0,0,0,0,0,0,0,22,0,0,0,208,4,0,0,24,6,0,0,246,1,0,0,202,7,0,0,138,15,0,0,142,47,0,0,136,173,145,0,0,4,0,0,240,0,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,176,5,0,128,225,6,0,0,0,0,0,0,0,0,0,232,233,7,0,56,139,5,0,0,0,0,0,32,94,6,0,136,252,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,156,27,0,0,120,9,0,0,0,0,0,0,0,0,0,0,172,22,0,0,0,14,0,0,124,2,0,0,64,13,0,0,168,2,0,0,0,0,0,0,134,1,0,0,0,0,0,0,0,1,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,24,182,2,0,104,36,5,0,72,172,6,0,0,0,0,0,144,47,2,0,216,168,2,0,0,0,0,0,128,145,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,81,0,0,0,2,0,0,0,0,4,1,133,4,0,0,0,0,0,0,0,0,0,0,0,66,25,0,0,240,44,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,204,4,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,244,2,0,104,36,5,0,72,172,6,0,0,0,0,0,144,47,2,0,248,220,2,0,0,0,0,0,128,145,4,0,168,200,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,133,4,0,0,0,0,0,0,0,0,0,0,0,252,41,0,0,4,8,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,36,5,0,0,0,0,0,72,172,6,0,0,0,0,0,144,47,2,0,152,9,3,0,0,0,0,0,128,145,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,4,0,0,0,0,0,0,0,0,0,0,0,116,22,0,0,210,13,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,131,3,0,0,0,0,0,0,0,0,0,0,0,0,0,184,12,8,0,72,33,6,0,0,0,0,0,0,192,4,0,0,192,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,1,0,0,0,0,0,0,0,0,0,0,36,26,0,0,40,27,0,0,0,0,0,0,0,0,0,0,116,36,0,0,178,20,0,0,82,11,0,0,108,6,0,0,110,11,0,0,0,0,0,0,198,20,0,0,0,0,0,0,0,32,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,48,5,0,96,214,5,0,0,0,0,0,0,0,0,0,200,190,7,0,232,17,5,0,0,0,0,0,192,223,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,20,4,0,0,0,0,0,0,0,0,0,0,0,84,4,0,0,142,27,0,0,0,0,0,0,0,0,0,0,194,6,0,0,206,33,0,0,60,9,0,0,248,1,0,0,100,9,0,0,230,11,0,0,254,30,0,0,184,175,145,0,0,4,0,0,240,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,104,92,8,0,0,0,0,0,0,0,0,0,0,0,0,0,232,233,7,0,8,240,7,0,0,0,0,0,16,182,4,0,192,152,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,9,2,0,0,1,0,0,0,0,0,0,0,0,0,216,15,0,0,14,44,0,0,0,0,0,0,0,0,0,0,94,27,0,0,222,24,0,0,140,4,0,0,42,17,0,0,184,7,0,0,0,0,0,0,216,46,0,0,0,0,0,0,0,6,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,149,2,0,0,0,0,0,0,0,0,0,0,0,0,0,200,190,7,0,152,137,2,0,0,0,0,0,40,161,4,0,80,150,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,3,0,0,0,68,0,4,2,2,0,0,0,0,0,0,0,0,0,0,0,246,17,0,0,60,20,0,0,0,0,0,0,0,0,0,0,92,51,0,0,8,35,0,0,186,18,0,0,114,17,0,0,134,11,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,103,6,0,40,23,7,0,0,0,0,0,0,0,0,0,184,168,7,0,120,55,6,0,0,0,0,0,0,146,6,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,6,17,4,0,0,0,0,0,0,0,0,0,0,0,158,50,0,0,242,18,0,0,0,0,0,0,0,0,0,0,14,29,0,0,252,21,0,0,46,17,0,0,36,2,0,0,56,3,0,0,0,0,0,0,88,9,0,0,0,0,0,0,32,2,0,0,0,1,0,0,0,1,0,0,4,0,0,0,3,0,0,0,40,23,7,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,240,192,6,0,0,0,0,0,0,146,6,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,6,17,4,0,0,0,0,0,0,0,0,0,0,0,242,45,0,0,186,5,0,0,0,0,0,0,0,0,0,0,244,37,0,0,254,6,0,0,46,17,0,0,36,2,0,0,56,3,0,0,0,0,0,0,88,9,0,0,0,0,0,0,32,2,0,0,0,1,0,0,0,1,0,0,4,0,0,0,3,0,0,0,192,101,5,0,56,12,3,0,0,0,0,0,0,0,0,0,160,234,7,0,104,71,5,0,0,0,0,0,32,130,5,0,128,194,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,2,0,0,2,0,0,0,0,0,3,11,0,8,0,0,0,0,0,0,0,0,0,0,94,43,0,0,76,34,0,0,0,0,0,0,0,0,0,0,152,6,0,0,164,40,0,0,28,17,0,0,148,18,0,0,100,14,0,0,0,0,0,0,120,21,0,0,0,0,0,0,0,1,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,204,5,0,56,12,3,0,0,0,0,0,0,0,0,0,160,234,7,0,0,164,5,0,0,0,0,0,32,130,5,0,128,194,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,2,0,0,2,0,0,0,0,0,3,11,0,8,0,0,0,0,0,0,0,0,0,0,86,11,0,0,248,10,0,0,0,0,0,0,0,0,0,0,152,6,0,0,164,40,0,0,28,17,0,0,148,18,0,0,100,14,0,0,0,0,0,0,120,21,0,0,0,0,0,0,0,1,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,203,1,0,56,12,3,0,0,0,0,0,0,0,0,0,160,234,7,0,240,105,1,0,0,0,0,0,88,90,7,0,128,194,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,11,0,8,0,0,0,0,0,0,0,0,0,0,186,57,0,0,230,43,0,0,0,0,0,0,0,0,0,0,152,6,0,0,164,40,0,0,28,17,0,0,148,18,0,0,100,14,0,0,0,0,0,0,120,21,0,0,0,0,0,0,0,1,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,12,3,0,0,0,0,0,0,0,0,0,0,0,0,0,160,234,7,0,56,10,6,0,0,0,0,0,144,84,8,0,128,194,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,3,11,0,8,0,0,0,0,0,0,0,0,0,0,46,24,0,0,42,2,0,0,0,0,0,0,0,0,0,0,152,6,0,0,164,40,0,0,28,17,0,0,148,18,0,0,100,14,0,0,0,0,0,0,120,21,0,0,0,0,0,0,0,1,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,200,2,0,56,12,3,0,0,0,0,0,0,0,0,0,160,234,7,0,144,63,2,0,0,0,0,0,144,84,8,0,128,194,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,11,0,8,0,0,0,0,0,0,0,0,0,0,252,56,0,0,204,7,0,0,0,0,0,0,0,0,0,0,152,6,0,0,164,40,0,0,28,17,0,0,148,18,0,0,100,14,0,0,0,0,0,0,120,21,0,0,0,0,0,0,0,1,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,32,2,0,0,0,0,0,0,0,0,0,0,0,0,0,192,177,6,0,128,22,2,0,0,0,0,0,72,13,2,0,80,164,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,16,0,0,0,0,0,0,0,0,0,0,194,22,0,0,86,31,0,0,0,0,0,0,0,0,0,0,244,56,0,0,30,6,0,0,44,7,0,0,88,18,0,0,228,5,0,0,4,6,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,136,218,8,0,56,12,3,0,0,0,0,0,0,0,0,0,160,234,7,0,112,152,8,0,0,0,0,0,88,90,7,0,128,194,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,11,0,8,0,0,0,0,0,0,0,0,0,0,66,1,0,0,206,34,0,0,0,0,0,0,0,0,0,0,152,6,0,0,164,40,0,0,28,17,0,0,148,18,0,0,100,14,0,0,0,0,0,0,120,21,0,0,0,0,0,0,0,1,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,72,168,6,0,56,12,3,0,0,0,0,0,0,0,0,0,160,234,7,0,216,126,6,0,0,0,0,0,192,154,4,0,128,194,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,3,11,0,8,0,0,0,0,0,0,0,0,0,0,50,21,0,0,162,10,0,0,0,0,0,0,0,0,0,0,152,6,0,0,164,40,0,0,136,0,0,0,148,18,0,0,100,14,0,0,0,0,0,0,120,21,0,0,0,0,0,0,0,1,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,102,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,56,51,7,0,0,0,0,0,232,163,8,0,248,180,3,0,216,7,7,0,0,0,0,0,0,0,0,0,0,0,0,0,129,0,0,0,2,0,0,0,0,0,0,13,8,0,0,0,0,0,0,0,0,0,0,0,100,8,0,0,148,23,0,0,0,0,0,0,0,0,0,0,216,33,0,0,154,34,0,0,120,5,0,0,66,4,0,0,206,19,0,0,238,15,0,0,232,20,0,0,216,157,215,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,61,7,0,200,123,3,0,72,172,6,0,0,0,0,0,104,221,5,0,232,16,7,0,0,0,0,0,128,145,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,133,0,64,0,0,0,0,0,0,0,0,0,0,164,32,0,0,170,17,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,98,2,0,0,0,0,0,72,172,6,0,0,0,0,0,96,135,2,0,192,209,8,0,0,0,0,0,128,145,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,0,64,0,0,0,0,0,0,0,0,0,0,8,12,0,0,52,27,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,123,3,0,0,0,0,0,72,172,6,0,0,0,0,0,104,221,5,0,240,111,7,0,0,0,0,0,128,145,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,0,64,0,0,0,0,0,0,0,0,0,0,8,49,0,0,120,39,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,222,8,0,0,0,0,0,0,0,0,0,0,0,0,0,168,163,7,0,48,155,8,0,176,93,8,0,152,189,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,4,0,0,0,0,0,0,10,0,128,0,0,0,0,0,0,0,0,0,0,90,24,0,0,188,26,0,0,0,0,0,0,0,0,0,0,140,22,0,0,128,50,0,0,114,4,0,0,176,14,0,0,68,11,0,0,90,16,0,0,22,41,0,0,0,174,145,0,0,16,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,91,7,0,120,217,8,0,0,0,0,0,0,0,0,0,184,168,7,0,152,41,7,0,0,0,0,0,128,161,4,0,216,142,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,11,0,0,8,0,0,0,0,0,0,0,0,0,38,38,0,0,242,13,0,0,0,0,0,0,0,0,0,0,152,41,0,0,200,44,0,0,40,14,0,0,24,8,0,0,14,5,0,0,0,0,0,0,60,41,0,0,0,0,0,0,0,16,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,8,185,7,0,120,217,8,0,0,0,0,0,0,0,0,0,184,168,7,0,152,138,7,0,0,0,0,0,144,84,8,0,216,142,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,11,0,0,8,0,0,0,0,0,0,0,0,0,150,39,0,0,130,36,0,0,0,0,0,0,0,0,0,0,24,56,0,0,136,3,0,0,40,14,0,0,24,8,0,0,14,5,0,0,0,0,0,0,60,41,0,0,0,0,0,0,0,16,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,128,34,8,0,120,217,8,0,0,0,0,0,0,0,0,0,184,168,7,0,200,237,7,0,0,0,0,0,144,84,8,0,216,142,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,11,0,0,8,0,0,0,0,0,0,0,0,0,10,28,0,0,170,20,0,0,0,0,0,0,0,0,0,0,152,41,0,0,174,1,0,0,40,14,0,0,24,8,0,0,14,5,0,0,0,0,0,0,60,41,0,0,0,0,0,0,0,16,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,120,217,8,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,216,88,8,0,0,0,0,0,168,183,7,0,216,142,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,11,0,0,8,0,0,0,0,0,0,0,0,0,94,10,0,0,248,28,0,0,0,0,0,0,0,0,0,0,152,41,0,0,90,0,0,0,40,14,0,0,24,8,0,0,14,5,0,0,0,0,0,0,60,41,0,0,0,0,0,0,0,16,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,64,42,3,0,232,73,3,0,0,0,0,0,0,0,0,0,160,234,7,0,200,19,3,0,0,0,0,0,176,237,2,0,176,109,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,19,0,0,1,0,0,0,0,0,0,0,0,0,160,51,0,0,150,1,0,0,0,0,0,0,0,0,0,0,36,32,0,0,150,43,0,0,24,7,0,0,158,10,0,0,242,5,0,0,160,5,0,0,6,53,0,0,72,173,145,0,0,4,0,0,240,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,8,31,1,0,0,0,0,0,0,0,0,0,0,0,0,0,160,234,7,0,8,154,8,0,0,0,0,0,16,182,4,0,192,152,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,9,2,1,0,0,0,0,0,0,0,0,0,0,0,224,21,0,0,96,24,0,0,0,0,0,0,0,0,0,0,94,27,0,0,218,15,0,0,84,8,0,0,42,17,0,0,184,7,0,0,0,0,0,0,216,46,0,0,0,0,0,0,0,6,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,89,7,0,64,33,8,0,0,0,0,0,0,0,0,0,104,221,5,0,168,40,7,0,0,0,0,0,248,136,7,0,248,135,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,19,0,1,0,0,0,0,0,0,0,0,0,0,68,10,0,0,156,25,0,0,0,0,0,0,0,0,0,0,34,44,0,0,138,61,0,0,236,3,0,0,216,4,0,0,96,1,0,0,0,0,0,0,10,34,0,0,0,0,0,0,0,4,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,64,33,8,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,104,183,7,0,0,0,0,0,248,136,7,0,248,135,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,19,0,1,0,0,0,0,0,0,0,0,0,0,134,47,0,0,108,8,0,0,0,0,0,0,0,0,0,0,34,44,0,0,138,61,0,0,236,3,0,0,216,4,0,0,96,1,0,0,0,0,0,0,10,34,0,0,0,0,0,0,0,4,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,0,27,3,0,16,224,7,0,0,0,0,0,0,0,0,0,184,168,7,0,224,110,2,0,0,0,0,0,168,95,8,0,40,251,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,3,0,64,0,0,0,0,0,0,0,0,0,0,216,19,0,0,32,17,0,0,0,0,0,0,0,0,0,0,118,10,0,0,80,29,0,0,222,2,0,0,50,17,0,0,194,5,0,0,238,5,0,0,156,33,0,0,136,176,145,0,0,4,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,224,7,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,0,171,6,0,0,0,0,0,168,95,8,0,40,251,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,3,0,64,0,0,0,0,0,0,0,0,0,0,114,14,0,0,206,16,0,0,0,0,0,0,0,0,0,0,118,10,0,0,80,29,0,0,222,2,0,0,50,17,0,0,194,5,0,0,238,5,0,0,156,33,0,0,136,176,145,0,0,4,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,182,2,0,24,108,2,0,0,0,0,0,0,0,0,0,96,135,2,0,0,47,2,0,0,0,0,0,176,237,2,0,168,84,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,19,1,0,0,0,0,0,0,0,0,0,0,0,152,8,0,0,28,40,0,0,0,0,0,0,0,0,0,0,42,18,0,0,22,23,0,0,116,7,0,0,228,7,0,0,132,16,0,0,136,8,0,0,200,59,0,0,96,173,145,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,24,108,2,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,176,219,5,0,0,0,0,0,176,237,2,0,168,84,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,19,1,0,0,0,0,0,0,0,0,0,0,0,52,0,0,0,106,14,0,0,0,0,0,0,0,0,0,0,42,18,0,0,22,23,0,0,116,7,0,0,228,7,0,0,132,16,0,0,136,8,0,0,200,59,0,0,96,173,145,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,168,136,6,0,136,151,7,0,0,0,0,0,0,0,0,0,200,190,7,0,16,92,6,0,0,0,0,0,192,154,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,53,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,30,18,0,0,146,15,0,0,0,0,0,0,0,0,0,0,132,5,0,0,158,47,0,0,244,10,0,0,180,14,0,0,36,3,0,0,0,0,0,0,42,52,0,0,136,35,149,0,16,17,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,0,51,4,0,0,162,4,0,0,0,0,0,0,0,0,0,104,174,7,0,168,23,4,0,0,0,0,0,128,161,4,0,128,194,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,11,0,8,0,0,0,0,0,0,0,0,0,0,98,3,0,0,212,25,0,0,0,0,0,0,0,0,0,0,20,58,0,0,58,12,0,0,34,12,0,0,224,17,0,0,14,8,0,0,2,1,0,0,74,29,0,0,0,0,0,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,104,4,0,0,162,4,0,0,0,0,0,0,0,0,0,104,174,7,0,168,77,4,0,0,0,0,0,168,183,7,0,128,194,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,11,0,8,0,0,0,0,0,0,0,0,0,0,120,48,0,0,72,25,0,0,0,0,0,0,0,0,0,0,20,58,0,0,192,51,0,0,34,12,0,0,224,17,0,0,14,8,0,0,2,1,0,0,74,29,0,0,0,0,0,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,162,4,0,0,0,0,0,0,0,0,0,0,0,0,0,104,174,7,0,16,131,4,0,0,0,0,0,168,183,7,0,128,194,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,3,11,0,8,0,0,0,0,0,0,0,0,0,0,206,7,0,0,56,0,0,0,0,0,0,0,0,0,0,0,20,58,0,0,192,51,0,0,34,12,0,0,224,17,0,0,14,8,0,0,2,1,0,0,74,29,0,0,0,0,0,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,37,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,0,241,7,0,0,0,0,0,72,187,4,0,200,156,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,14,0,8,0,0,0,0,0,0,0,0,0,0,58,33,0,0,26,25,0,0,0,0,0,0,0,0,0,0,220,21,0,0,132,10,0,0,128,18,0,0,204,13,0,0,230,5,0,0,0,0,0,0,198,6,0,0,0,0,0,0,0,0,1,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,72,56,5,0,0,0,0,0,0,0,0,0,0,0,0,0,64,164,6,0,32,53,5,0,0,0,0,0,240,49,5,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,8,0,0,2,0,0,0,0,0,0,16,0,8,0,0,0,0,0,0,0,0,0,0,214,62,0,0,2,16,0,0,0,0,0,0,0,0,0,0,244,24,0,0,76,27,0,0,182,0,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,136,157,1,0,232,36,3,0,0,0,0,0,0,0,0,0,144,47,2,0,208,62,1,0,0,0,0,0,96,0,2,0,152,8,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,4,17,0,0,1,0,0,0,0,0,0,0,0,0,32,10,0,0,254,27,0,0,0,0,0,0,0,0,0,0,184,4,0,0,142,60,0,0,6,6,0,0,80,0,0,0,228,1,0,0,44,8,0,0,0,0,0,0,32,177,145,0,0,2,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,24,144,7,0,40,40,8,0,0,0,0,0,0,0,0,0,192,177,6,0,16,98,7,0,0,0,0,0,152,190,4,0,192,167,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,10,0,8,0,0,0,0,0,0,0,0,0,0,74,54,0,0,30,18,0,0,0,0,0,0,0,0,0,0,30,42,0,0,232,52,0,0,98,1,0,0,122,2,0,0,166,18,0,0,108,16,0,0,180,44,0,0,88,174,145,0,0,32,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,40,8,0,0,0,0,0,0,0,0,0,0,0,0,0,192,177,6,0,112,192,7,0,0,0,0,0,152,190,4,0,192,167,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,8,0,0,0,0,0,0,0,0,0,0,176,13,0,0,100,16,0,0,0,0,0,0,0,0,0,0,30,42,0,0,232,52,0,0,98,1,0,0,122,2,0,0,166,18,0,0,108,16,0,0,180,44,0,0,88,174,145,0,0,32,0,0,128,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,228,1,0,128,220,4,0,0,0,0,0,0,0,0,0,232,233,7,0,208,129,1,0,0,0,0,0,224,43,1,0,104,192,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,32,16,0,0,140,7,0,0,0,0,0,0,0,0,0,0,194,42,0,0,132,53,0,0,52,13,0,0,226,7,0,0,218,0,0,0,0,0,0,0,18,5,0,0,0,0,0,0,128,0,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,128,220,4,0,0,0,0,0,0,0,0,0,0,0,0,0,232,233,7,0,88,88,6,0,0,0,0,0,232,236,4,0,104,192,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,154,29,0,0,38,45,0,0,0,0,0,0,0,0,0,0,194,42,0,0,132,53,0,0,92,9,0,0,226,7,0,0,218,0,0,0,0,0,0,0,18,5,0,0,0,0,0,0,128,0,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,216,239,2,0,128,220,4,0,0,0,0,0,0,0,0,0,232,233,7,0,136,88,2,0,0,0,0,0,232,236,4,0,104,192,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,22,60,0,0,22,18,0,0,0,0,0,0,0,0,0,0,194,42,0,0,132,53,0,0,92,9,0,0,226,7,0,0,218,0,0,0,0,0,0,0,18,5,0,0,0,0,0,0,128,0,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,160,28,4,0,160,187,8,0,0,0,0,0,0,0,0,0,216,194,1,0,152,25,4,0,0,0,0,0,192,154,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,8,0,0,2,0,0,0,0,0,0,16,1,0,0,0,0,0,0,0,0,0,0,0,92,62,0,0,214,29,0,0,0,0,0,0,0,0,0,0,124,45,0,0,126,52,0,0,228,9,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,168,216,6,0,0,0,0,0,0,0,0,0,0,0,0,0,160,234,7,0,32,171,6,0,0,0,0,0,40,161,4,0,248,206,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,3,2,8,0,0,0,0,0,0,0,0,0,0,0,4,19,0,0,76,25,0,0,0,0,0,0,0,0,0,0,50,61,0,0,120,9,0,0,252,2,0,0,114,17,0,0,144,2,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,90,8,0,56,12,3,0,0,0,0,0,0,0,0,0,160,234,7,0,136,35,8,0,0,0,0,0,192,154,4,0,128,194,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,3,11,0,8,0,0,0,0,0,0,0,0,0,0,162,32,0,0,168,17,0,0,0,0,0,0,0,0,0,0,120,36,0,0,146,4,0,0,176,9,0,0,148,18,0,0,100,14,0,0,0,0,0,0,120,21,0,0,0,0,0,0,0,1,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,184,5,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,152,116,5,0,240,56,5,0,152,54,6,0,168,38,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,5,17,4,0,0,0,0,0,0,0,0,0,0,0,208,13,0,0,26,7,0,0,0,0,0,0,0,0,0,0,58,34,0,0,244,42,0,0,14,11,0,0,218,2,0,0,114,1,0,0,166,3,0,0,116,50,0,0,8,211,148,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,72,99,5,0,0,0,0,0,0,0,0,0,0,0,0,0,232,167,7,0,8,110,6,0,0,0,0,0,224,251,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,226,50,0,0,42,26,0,0,0,0,0,0,0,0,0,0,134,41,0,0,216,25,0,0,52,4,0,0,40,2,0,0,154,18,0,0,128,9,0,0,56,24,0,0,240,175,145,0,8,2,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,24,250,2,0,72,99,5,0,0,0,0,0,0,0,0,0,232,167,7,0,200,94,2,0,0,0,0,0,216,233,1,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,38,45,0,0,136,32,0,0,0,0,0,0,0,0,0,0,134,41,0,0,216,25,0,0,52,4,0,0,40,2,0,0,154,18,0,0,128,9,0,0,56,24,0,0,240,175,145,0,8,2,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,56,24,5,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,136,212,4,0,0,0,0,0,168,95,8,0,192,178,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,2,0,0,0,0,0,1,3,2,0,0,0,0,0,0,0,0,0,0,0,148,45,0,0,68,15,0,0,0,0,0,0,0,0,0,0,202,23,0,0,0,0,0,0,34,11,0,0,130,1,0,0,64,17,0,0,0,0,0,0,90,16,0,0,0,0,0,0,16,8,0,0,224,0,0,0,24,1,0,0,3,0,0,0,4,0,0,0,80,194,2,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,112,92,8,0,0,0,0,0,40,161,4,0,8,153,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,64,0,6,2,0,16,0,0,0,0,0,0,0,0,0,0,80,27,0,0,60,6,0,0,0,0,0,0,0,0,0,0,196,58,0,0,0,0,0,0,218,12,0,0])
.concat([164,2,0,0,20,14,0,0,0,0,0,0,106,0,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,232,212,2,0,80,194,2,0,0,0,0,0,0,0,0,0,112,177,2,0,40,163,2,0,0,0,0,0,40,161,4,0,80,150,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,128,4,2,0,16,0,0,0,0,0,0,0,0,0,0,98,42,0,0,18,43,0,0,0,0,0,0,0,0,0,0,50,22,0,0,122,52,0,0,64,3,0,0,114,17,0,0,134,11,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,221,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,80,93,8,0,0,0,0,0,72,187,4,0,200,156,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,14,8,0,0,0,0,0,0,0,0,0,0,0,126,11,0,0,110,9,0,0,0,0,0,0,0,0,0,0,102,53,0,0,106,2,0,0,168,16,0,0,204,13,0,0,230,5,0,0,0,0,0,0,198,6,0,0,0,0,0,0,0,0,1,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,192,220,1,0,104,69,4,0,0,0,0,0,0,0,0,0,104,221,5,0,128,123,1,0,0,0,0,0,72,218,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,10,0,0,8,0,0,0,0,0,0,0,0,0,152,33,0,0,244,21,0,0,0,0,0,0,0,0,0,0,40,61,0,0,88,27,0,0,16,6,0,0,6,9,0,0,98,0,0,0,22,8,0,0,218,43,0,0,232,174,145,0,0,8,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,227,2,0,104,69,4,0,0,0,0,0,0,0,0,0,104,221,5,0,216,78,2,0,0,0,0,0,72,218,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,10,0,0,8,0,0,0,0,0,0,0,0,0,194,62,0,0,124,33,0,0,0,0,0,0,0,0,0,0,40,61,0,0,88,27,0,0,16,6,0,0,6,9,0,0,98,0,0,0,22,8,0,0,218,43,0,0,232,174,145,0,0,8,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,69,4,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,64,61,6,0,0,0,0,0,72,218,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,0,8,0,0,0,0,0,0,0,0,0,210,50,0,0,154,16,0,0,0,0,0,0,0,0,0,0,40,61,0,0,88,27,0,0,16,6,0,0,6,9,0,0,98,0,0,0,22,8,0,0,218,43,0,0,232,174,145,0,0,8,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,56,180,4,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,80,79,6,0,0,0,0,0,184,231,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,22,0,16,0,0,0,0,0,0,0,0,0,0,124,33,0,0,244,31,0,0,0,0,0,0,0,0,0,0,20,50,0,0,212,7,0,0,200,14,0,0,202,16,0,0,72,1,0,0,100,15,0,0,160,18,0,0,72,175,145,0,1,2,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,192,88,2,0,0,140,2,0,0,0,0,0,0,0,0,0,144,47,2,0,56,73,2,0,0,0,0,0,192,223,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,0,10,32,0,0,0,0,0,0,0,0,0,0,0,42,47,0,0,66,30,0,0,0,0,0,0,0,0,0,0,76,12,0,0,0,0,0,0,4,3,0,0,22,7,0,0,230,18,0,0,0,0,0,0,110,45,0,0,0,0,0,0,0,8,0,0,240,0,0,0,128,1,0,0,3,0,0,0,4,0,0,0,248,113,2,0,0,140,2,0,0,0,0,0,0,0,0,0,144,47,2,0,96,102,2,0,0,0,0,0,192,223,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,0,10,32,0,0,0,0,0,0,0,0,0,0,0,112,23,0,0,24,10,0,0,0,0,0,0,0,0,0,0,28,19,0,0,0,0,0,0,40,7,0,0,22,7,0,0,230,18,0,0,0,0,0,0,110,45,0,0,0,0,0,0,0,8,0,0,240,0,0,0,128,1,0,0,3,0,0,0,4,0,0,0,128,61,8,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,8,181,6,0,0,0,0,0,168,95,8,0,136,2,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,3,0,16,0,0,0,0,0,0,0,0,0,0,80,40,0,0,220,17,0,0,0,0,0,0,0,0,0,0,246,8,0,0,110,54,0,0,46,9,0,0,72,3,0,0,210,12,0,0,78,0,0,0,184,1,0,0,224,176,145,0,0,4,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,204,2,0,0,0,0,0,0,0,0,0,0,0,0,0,200,190,7,0,168,206,1,0,0,0,0,0,192,108,1,0,192,152,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,2,0,0,0,0,0,9,2,0,16,0,0,0,0,0,0,0,0,0,0,240,12,0,0,148,27,0,0,0,0,0,0,0,0,0,0,190,57,0,0,10,7,0,0,196,12,0,0,42,17,0,0,184,7,0,0,0,0,0,0,216,46,0,0,0,0,0,0,0,6,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,64,250,1,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,16,240,1,0,0,0,0,0,40,52,7,0,0,227,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,2,0,0,0,0,0,1,21,0,0,1,0,0,0,0,0,0,0,0,0,244,48,0,0,210,14,0,0,0,0,0,0,0,0,0,0,240,35,0,0,28,62,0,0,84,10,0,0,248,19,0,0,72,13,0,0,198,3,0,0,96,10,0,0,224,174,145,0,0,2,0,0,240,0,0,0,128,1,0,0,3,0,0,0,4,0,0,0,168,60,2,0,0,140,2,0,0,0,0,0,0,0,0,0,144,47,2,0,16,45,2,0,0,0,0,0,192,154,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,53,0,0,0,2,0,0,0,0,0,0,10,32,0,0,0,0,0,0,0,0,0,0,0,142,59,0,0,250,34,0,0,0,0,0,0,0,0,0,0,28,19,0,0,0,0,0,0,92,1,0,0,22,7,0,0,230,18,0,0,0,0,0,0,110,45,0,0,0,0,0,0,0,8,0,0,240,0,0,0,128,1,0,0,3,0,0,0,4,0,0,0,0,140,2,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,40,129,2,0,0,0,0,0,192,223,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,0,10,32,0,0,0,0,0,0,0,0,0,0,0,8,8,0,0,68,45,0,0,0,0,0,0,0,0,0,0,28,19,0,0,0,0,0,0,40,7,0,0,22,7,0,0,230,18,0,0,0,0,0,0,110,45,0,0,0,0,0,0,0,8,0,0,240,0,0,0,128,1,0,0,3,0,0,0,4,0,0,0,40,212,2,0,64,149,3,0,0,0,0,0,0,0,0,0,0,38,7,0,64,71,2,0,0,0,0,0,216,194,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,10,0,0,4,0,0,0,0,0,0,0,0,0,124,23,0,0,90,0,0,0,0,0,0,0,0,0,0,0,168,23,0,0,170,39,0,0,168,7,0,0,24,4,0,0,186,10,0,0,0,0,0,0,130,3,0,0,0,0,0,0,0,3,0,0,128,1,0,0,0,1,0,0,4,0,0,0,3,0,0,0,64,149,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,120,36,6,0,0,0,0,0,216,194,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,0,4,0,0,0,0,0,0,0,0,0,18,13,0,0,150,7,0,0,0,0,0,0,0,0,0,0,168,23,0,0,170,39,0,0,30,12,0,0,24,4,0,0,186,10,0,0,0,0,0,0,130,3,0,0,0,0,0,0,0,3,0,0,128,1,0,0,0,1,0,0,4,0,0,0,3,0,0,0,224,227,1,0,240,209,4,0,0,0,0,0,0,0,0,0,200,190,7,0,56,129,1,0,0,0,0,0,192,154,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,20,4,8,0,0,0,0,0,0,0,0,0,0,110,1,0,0,206,47,0,0,0,0,0,0,0,0,0,0,12,48,0,0,76,51,0,0,186,9,0,0,204,2,0,0,140,3,0,0,56,2,0,0,80,42,0,0,88,175,145,0,0,4,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,238,2,0,240,209,4,0,0,0,0,0,0,0,0,0,200,190,7,0,240,87,2,0,0,0,0,0,192,223,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,20,4,8,0,0,0,0,0,0,0,0,0,0,154,42,0,0,192,39,0,0,0,0,0,0,0,0,0,0,12,48,0,0,76,51,0,0,186,9,0,0,204,2,0,0,140,3,0,0,56,2,0,0,80,42,0,0,88,175,145,0,0,4,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,209,4,0,0,0,0,0,0,0,0,0,0,0,0,0,200,190,7,0,240,85,6,0,0,0,0,0,192,223,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,20,4,8,0,0,0,0,0,0,0,0,0,0,46,11,0,0,158,11,0,0,0,0,0,0,0,0,0,0,12,48,0,0,76,51,0,0,186,9,0,0,204,2,0,0,140,3,0,0,56,2,0,0,80,42,0,0,88,175,145,0,0,4,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,121,2,0,0,0,0,0,0,0,0,0,0,0,0,0,216,194,1,0,72,96,2,0,0,0,0,0,48,79,2,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,8,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,14,51,0,0,52,3,0,0,0,0,0,0,0,0,0,0,48,21,0,0,92,22,0,0,8,7,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,152,77,8,0,40,88,8,0,0,0,0,0,0,0,0,0,144,47,2,0,160,71,8,0,0,0,0,0,232,196,4,0,80,164,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,10,1,0,0,0,0,0,0,0,0,0,0,0,68,63,0,0,114,38,0,0,0,0,0,0,0,0,0,0,244,56,0,0,70,7,0,0,12,14,0,0,56,12,0,0,212,3,0,0,210,14,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,88,8,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,0,82,8,0,0,0,0,0,232,196,4,0,80,164,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,1,0,0,0,0,0,0,0,0,0,0,0,44,13,0,0,94,41,0,0,0,0,0,0,0,0,0,0,244,56,0,0,70,7,0,0,12,14,0,0,56,12,0,0,212,3,0,0,210,14,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,251,7,0,240,209,4,0,0,0,0,0,0,0,0,0,200,190,7,0,96,198,7,0,0,0,0,0,192,154,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,20,4,8,0,0,0,0,0,0,0,0,0,0,110,53,0,0,174,30,0,0,0,0,0,0,0,0,0,0,12,48,0,0,76,51,0,0,186,9,0,0,204,2,0,0,140,3,0,0,56,2,0,0,80,42,0,0,88,175,145,0,0,4,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,128,104,8,0,240,209,4,0,0,0,0,0,0,0,0,0,200,190,7,0,8,48,8,0,0,0,0,0,192,223,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,20,4,8,0,0,0,0,0,0,0,0,0,0,166,61,0,0,210,2,0,0,0,0,0,0,0,0,0,0,12,48,0,0,76,51,0,0,186,9,0,0,204,2,0,0,140,3,0,0,56,2,0,0,80,42,0,0,88,175,145,0,0,4,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,226,1,0,56,180,4,0,0,0,0,0,0,0,0,0,184,168,7,0,104,128,1,0,0,0,0,0,184,231,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,22,0,16,0,0,0,0,0,0,0,0,0,0,214,35,0,0,66,17,0,0,0,0,0,0,0,0,0,0,46,39,0,0,212,7,0,0,200,14,0,0,202,16,0,0,72,1,0,0,100,15,0,0,160,18,0,0,72,175,145,0,1,2,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,96,237,2,0,56,180,4,0,0,0,0,0,0,0,0,0,184,168,7,0,96,85,2,0,0,0,0,0,184,231,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,22,0,16,0,0,0,0,0,0,0,0,0,0,92,29,0,0,242,14,0,0,0,0,0,0,0,0,0,0,20,50,0,0,212,7,0,0,200,14,0,0,202,16,0,0,72,1,0,0,100,15,0,0,160,18,0,0,72,175,145,0,1,2,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,160,208,1,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,120,110,1,0,0,0,0,0,64,32,1,0,200,156,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,14,1,0,0,0,0,0,0,0,0,0,0,0,24,20,0,0,200,33,0,0,0,0,0,0,0,0,0,0,6,1,0,0,26,33,0,0,216,11,0,0,14,7,0,0,156,3,0,0,0,0,0,0,162,43,0,0,0,0,0,0,0,16,0,0,64,1,0,0,232,0,0,0,4,0,0,0,3,0,0,0,56,143,1,0,152,161,1,0,0,0,0,0,0,0,0,0,96,135,2,0,168,129,1,0,0,0,0,0,104,199,4,0,0,227,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,21,0,0,1,0,0,0,0,0,0,0,0,0,48,50,0,0,114,0,0,0,0,0,0,0,0,0,0,0,168,61,0,0,4,38,0,0,54,18,0,0,248,19,0,0,72,13,0,0,56,10,0,0,96,10,0,0,224,174,145,0,0,18,0,0,128,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,152,161,1,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,240,153,1,0,0,0,0,0,104,199,4,0,0,227,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,21,0,0,1,0,0,0,0,0,0,0,0,0,98,28,0,0,134,40,0,0,0,0,0,0,0,0,0,0,168,61,0,0,4,38,0,0,250,17,0,0,248,19,0,0,72,13,0,0,56,10,0,0,96,10,0,0,224,174,145,0,0,18,0,0,128,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,200,24,1,0,48,43,1,0,0,0,0,0,0,0,0,0,240,3,2,0,168,15,1,0,0,0,0,0,232,167,5,0,80,164,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,0,10,0,8,0,0,0,0,0,0,0,0,0,0,138,32,0,0,128,8,0,0,0,0,0,0,0,0,0,0,244,56,0,0,12,33,0,0,128,19,0,0,24,3,0,0,158,1,0,0,70,6,0,0,0,0,0,0,0,0,0,0,0,4,0,0,224,0,0,0,128,1,0,0,3,0,0,0,4,0,0,0,48,43,1,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,16,34,1,0,0,0,0,0,232,167,5,0,80,164,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,0,10,0,8,0,0,0,0,0,0,0,0,0,0,34,34,0,0,128,3,0,0,0,0,0,0,0,0,0,0,244,56,0,0,12,33,0,0,128,19,0,0,24,3,0,0,158,1,0,0,70,6,0,0,0,0,0,0,0,0,0,0,0,4,0,0,224,0,0,0,128,1,0,0,3,0,0,0,4,0,0,0,72,237,7,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,24,231,7,0,0,0,0,0,80,212,1,0,80,164,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,1,0,0,0,0,0,0,0,0,0,0,0,106,48,0,0,70,9,0,0,0,0,0,0,0,0,0,0,244,56,0,0,12,58,0,0,18,15,0,0,56,12,0,0,212,3,0,0,228,19,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,97,8,0,152,37,1,0,0,0,0,0,0,0,0,0,32,127,5,0,96,42,8,0,0,0,0,0,216,67,5,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,10,0,8,0,0,0,0,0,0,0,0,0,0,90,31,0,0,238,40,0,0,0,0,0,0,0,0,0,0,244,41,0,0,96,26,0,0,228,10,0,0,0,2,0,0,22,3,0,0,118,1,0,0,152,14,0,0,136,174,145,0,0,4,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,152,37,1,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,248,158,8,0,0,0,0,0,216,67,5,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,8,0,0,0,0,0,0,0,0,0,0,114,42,0,0,10,30,0,0,0,0,0,0,0,0,0,0,244,41,0,0,96,26,0,0,228,10,0,0,0,2,0,0,22,3,0,0,118,1,0,0,152,14,0,0,136,174,145,0,0,4,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,136,231,2,0,160,139,5,0,0,0,0,0,0,0,0,0,216,194,1,0,144,229,2,0,0,0,0,0,192,154,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,8,0,0,2,0,0,0,0,0,0,16,0,64,0,0,0,0,0,0,0,0,0,0,222,8,0,0,230,46,0,0,0,0,0,0,0,0,0,0,26,12,0,0,28,22,0,0,28,2,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,104,32,4,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,80,57,6,0,0,0,0,0,160,213,4,0,112,163,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,16,0,0,0,0,0,0,0,0,0,0,242,38,0,0,220,35,0,0,0,0,0,0,0,0,0,0,48,16,0,0,94,55,0,0,196,1,0,0,16,8,0,0,80,3,0,0,0,0,0,0,176,0,0,0,0,0,0,0,0,4,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,176,230,3,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,112,51,6,0,0,0,0,0,216,67,5,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,4,8,0,0,0,0,0,0,0,0,0,0,220,10,0,0,118,41,0,0,0,0,0,0,0,0,0,0,74,59,0,0,222,27,0,0,74,19,0,0,0,2,0,0,162,3,0,0,34,16,0,0,152,14,0,0,136,174,145,0,0,4,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,240,73,5,0,200,251,5,0,0,0,0,0,0,0,0,0,240,3,2,0,120,42,5,0,0,0,0,0,232,167,5,0,80,164,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,0,10,2,0,0,0,0,0,0,0,0,0,0,0,226,33,0,0,178,27,0,0,0,0,0,0,0,0,0,0,116,9,0,0,210,11,0,0,224,7,0,0,214,9,0,0,18,6,0,0,186,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,224,0,0,0,128,1,0,0,3,0,0,0,4,0,0,0,200,31,8,0,240,161,2,0,0,0,0,0,0,0,0,0,168,163,7,0,248,234,7,0,0,0,0,0,200,150,4,0,16,128,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,1,4,2,0,0,0,0,0,0,0,0,0,0,0,186,52,0,0,104,10,0,0,0,0,0,0,0,0,0,0,118,59,0,0,202,29,0,0,226,4,0,0,244,7,0,0,100,4,0,0,82,1,0,0,214,23,0,0,32,146,215,0,0,8,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,96,196,1,0,240,161,2,0,0,0,0,0,0,0,0,0,168,163,7,0,104,99,1,0,0,0,0,0,200,150,4,0,16,128,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,1,4,2,0,0,0,0,0,0,0,0,0,0,0,18,26,0,0,70,45,0,0,0,0,0,0,0,0,0,0,118,59,0,0,254,46,0,0,226,4,0,0,244,7,0,0,100,4,0,0,82,1,0,0,214,23,0,0,32,146,215,0,0,8,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,200,21,1,0,240,161,2,0,0,0,0,0,0,0,0,0,168,163,7,0,32,213,8,0,0,0,0,0,200,150,4,0,16,128,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,1,4,2,0,0,0,0,0,0,0,0,0,0,0,116,3,0,0,246,6,0,0,0,0,0,0,0,0,0,0,118,59,0,0,104,58,0,0,226,4,0,0,244,7,0,0,100,4,0,0,82,1,0,0,214,23,0,0,32,146,215,0,0,8,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,168,148,8,0,240,161,2,0,0,0,0,0,0,0,0,0,168,163,7,0,32,86,8,0,0,0,0,0,200,150,4,0,16,128,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,1,4,2,0,0,0,0,0,0,0,0,0,0,0,6,52,0,0,220,13,0,0,0,0,0,0,0,0,0,0,118,59,0,0,104,58,0,0,226,4,0,0,244,7,0,0,100,4,0,0,82,1,0,0,214,23,0,0,32,146,215,0,0,8,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,8,183,7,0,240,161,2,0,0,0,0,0,0,0,0,0,168,163,7,0,88,136,7,0,0,0,0,0,144,88,7,0,16,128,3,0,136,39,7,0,0,0,0,0,0,0,0,0,0,0,0,0,21,1,0,0,2,0,0,0,0,0,1,4,2,0,0,0,0,0,0,0,0,0,0,0,142,15,0,0,44,32,0,0,0,0,0,0,0,0,0,0,118,59,0,0,254,46,0,0,96,18,0,0,244,7,0,0,100,4,0,0,82,1,0,0,214,23,0,0,32,146,215,0,0,8,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,240,161,2,0,0,0,0,0,0,0,0,0,0,0,0,0,168,163,7,0,104,235,5,0,0,0,0,0,200,150,4,0,16,128,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,1,4,2,0,0,0,0,0,0,0,0,0,0,0,178,14,0,0,190,2,0,0,0,0,0,0,0,0,0,0,118,59,0,0,254,46,0,0,226,4,0,0,244,7,0,0,100,4,0,0,82,1,0,0,214,23,0,0,32,146,215,0,0,8,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,200,189,2,0,240,161,2,0,0,0,0,0,0,0,0,0,168,163,7,0,216,52,2,0,0,0,0,0,200,150,4,0,16,128,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,1,4,2,0,0,0,0,0,0,0,0,0,0,0,10,19,0,0,92,25,0,0,0,0,0,0,0,0,0,0,118,59,0,0,70,22,0,0,226,4,0,0,244,7,0,0,100,4,0,0,82,1,0,0,214,23,0,0,32,146,215,0,0,8,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,192,229,8,0,0,0,0,0,0,0,0,0,0,0,0,0,192,177,6,0,152,163,8,0,0,0,0,0,48,220,4,0,240,185,2,0,176,101,8,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,2,0,0,0,0,0,0,0,0,0,0,176,20,0,0,168,14,0,0,0,0,0,0,0,0,0,0,154,43,0,0,160,50,0,0,114,15,0,0,42,7,0,0,158,13,0,0,88,9,0,0,252,45,0,0,248,174,145,0,0,3,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,0,113,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,88,30,6,0,0,0,0,0,152,189,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,8,0,0,0,0,0,0,0,0,0,0,0,132,40,0,0,68,35,0,0,0,0,0,0,0,0,0,0,74,63,0,0,136,4,0,0,28,8,0,0,176,14,0,0,218,15,0,0,90,16,0,0,22,41,0,0,0,174,145,0,0,16,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,208,2,0,216,96,3,0,0,0,0,0,0,0,0,0,144,47,2,0,16,68,2,0,0,0,0,0,72,187,4,0,200,156,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,1,14,0,8,0,0,0,0,0,0,0,0,0,0,236,28,0,0,140,20,0,0,0,0,0,0,0,0,0,0,216,58,0,0,204,42,0,0,68,15,0,0,136,15,0,0,222,18,0,0,0,0,0,0,238,10,0,0,168,33,148,0,0,144,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,96,3,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,40,27,6,0,0,0,0,0,72,187,4,0,200,156,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,14,0,8,0,0,0,0,0,0,0,0,0,0,204,18,0,0,184,23,0,0,0,0,0,0,0,0,0,0,216,58,0,0,32,52,0,0,68,15,0,0,136,15,0,0,222,18,0,0,0,0,0,0,238,10,0,0,168,33,148,0,0,144,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,80,3,0,0,141,3,0,0,0,0,0,0,0,0,0,184,12,8,0,136,65,3,0,0,0,0,0,224,218,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,10,0,64,0,0,0,0,0,0,0,0,0,0,94,39,0,0,214,32,0,0,0,0,0,0,0,0,0,0,14,12,0,0,68,0,0,0,138,8,0,0,56,15,0,0,12,17,0,0,0,0,0,0,224,13,0,0,0,0,0,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,0,141,3,0,0,0,0,0,0,0,0,0,0,0,0,0,184,12,8,0,176,94,3,0,0,0,0,0,224,218,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,64,0,0,0,0,0,0,0,0,0,0,28,7,0,0,180,24,0,0,0,0,0,0,0,0,0,0,14,12,0,0,68,0,0,0,138,8,0,0,56,15,0,0,12,17,0,0,0,0,0,0,224,13,0,0,0,0,0,0,0,8,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,16,16,6,0,0,0,0,0,0,0,0,0,0,0,0,0,200,190,7,0,40,223,5,0,0,0,0,0,152,54,6,0,200,12,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,3,17,1,0,0,0,0,0,0,0,0,0,0,0,106,28,0,0,12,27,0,0,0,0,0,0,0,0,0,0,198,62,0,0,80,12,0,0,10,16,0,0,230,1,0,0,44,6,0,0,194,15,0,0,0,0,0,0,48,177,145,0,0,2,0,0,128,1,0,0,0,1,0,0,4,0,0,0,3,0,0,0,128,43,6,0,64,135,6,0,0,0,0,0,0,0,0,0,184,168,7,0,40,1,6,0,0,0,0,0,192,223,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,42,15,0,0,242,31,0,0,0,0,0,0,0,0,0,0,74,46,0,0,0,0,0,0,208,2,0,0,22,7,0,0,230,18,0,0,0,0,0,0,110,45,0,0,0,0,0,0,0,8,0,0,128,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,120,162,7,0,48,63,8,0,0,0,0,0,0,0,0,0,96,135,2,0,0,118,7,0,0,0,0,0,152,54,6,0,152,8,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,4,17,0,0,1,0,0,0,0,0,0,0,0,0,0,20,0,0,198,46,0,0,0,0,0,0,0,0,0,0,52,51,0,0,214,42,0,0,2,2,0,0,80,0,0,0,228,1,0,0,44,8,0,0,0,0,0,0,32,177,145,0,0,2,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,48,63,8,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,208,213,7,0,0,0,0,0,152,54,6,0,152,8,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,4,17,0,0,1,0,0,0,0,0,0,0,0,0,170,43,0,0,164,34,0,0,0,0,0,0,0,0,0,0,52,51,0,0,148,2,0,0,2,2,0,0,80,0,0,0,228,1,0,0,44,8,0,0,0,0,0,0,32,177,145,0,0,2,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,96,226,8,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,200,96,8,0,0,0,0,0,184,191,7,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,16,0,0,0,0,0,0,0,0,0,0,130,38,0,0,232,14,0,0,0,0,0,0,0,0,0,0,240,48,0,0,42,11,0,0,100,17,0,0,240,16,0,0,114,13,0,0,136,10,0,0,148,61,0,0,120,174,145,0,64,2,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,160,63,3,0,48,137,3,0,0,0,0,0,0,0,0,0,184,168,7,0,112,47,3,0,0,0,0,0,16,77,3,0,80,150,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,64,4,4,2,0,8,0,0,0,0,0,0,0,0,0,0,58,10,0,0,216,30,0,0,0,0,0,0,0,0,0,0,50,22,0,0,190,10,0,0,174,8,0,0,114,17,0,0,134,11,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,25,3,0,48,137,3,0,0,0,0,0,0,0,0,0,184,168,7,0,48,2,3,0,56,237,2,0,16,77,3,0,80,150,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,4,0,4,2,0,8,0,0,0,0,0,0,0,0,0,0,220,46,0,0,252,14,0,0,0,0,0,0,0,0,0,0,50,22,0,0,190,10,0,0,68,7,0,0,114,17,0,0,134,11,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,137,3,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,120,91,3,0,0,0,0,0,16,77,3,0,80,150,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,64,4,4,2,0,8,0,0,0,0,0,0,0,0,0,0,200,20,0,0,50,14,0,0,0,0,0,0,0,0,0,0,50,22,0,0,190,10,0,0,174,8,0,0,114,17,0,0,134,11,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,118,7,0,0,0,0,0,0,0,0,0,0,0,0,0,232,233,7,0,224,66,7,0,0,0,0,0,152,54,6,0,64,10,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,2,0,0,0,0,0,1,17,4,0,0,0,0,0,0,0,0,0,0,0,8,55,0,0,118,47,0,0,0,0,0,0,0,0,0,0,62,25,0,0,10,32,0,0,138,3,0,0,60,6,0,0,250,15,0,0,0,0,0,0,194,0,0,0,0,0,0,0,32,2,0,0,0,1,0,0,0,1,0,0,3,0,0,0,4,0,0,0,48,191,2,0,96,177,2,0,0,0,0,0,0,0,0,0,144,139,6,0,200,53,2,0,0,0,0,0,128,157,4,0,16,128,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,1,4,2,0,0,0,0,0,0,0,0,0,0,0,46,23,0,0,112,3,0,0,0,0,0,0,0,0,0,0,14,35,0,0,204,9,0,0,186,1,0,0,134,1,0,0,78,18,0,0,96,13,0,0,188,53,0,0,32,146,215,0,0,8,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,96,177,2,0,0,0,0,0,0,0,0,0,0,0,0,0,144,139,6,0,120,239,5,0,0,0,0,0,128,157,4,0,16,128,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,1,4,2,0,0,0,0,0,0,0,0,0,0,0,78,18,0,0,26,21,0,0,0,0,0,0,0,0,0,0,14,35,0,0,72,59,0,0,186,1,0,0,134,1,0,0,78,18,0,0,96,13,0,0,188,53,0,0,32,146,215,0,0,8,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,16,197,1,0,96,177,2,0,0,0,0,0,0,0,0,0,144,139,6,0,96,100,1,0,0,0,0,0,128,157,4,0,16,128,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,1,4,2,0,0,0,0,0,0,0,0,0,0,0,96,24,0,0,6,40,0,0,0,0,0,0,0,0,0,0,14,35,0,0,204,9,0,0,186,1,0,0,134,1,0,0,78,18,0,0,96,13,0,0,188,53,0,0,32,146,215,0,0,8,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,136,187,2,0,200,151,2,0,0,0,0,0,0,0,0,0,240,3,2,0,24,51,2,0,0,0,0,0,160,195,1,0,16,128,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,2,4,2,0,0,0,0,0,0,0,0,0,0,0,142,29,0,0,184,9,0,0,0,0,0,0,0,0,0,0,208,49,0,0,232,38,0,0,72,0,0,0,210,7,0,0,112,14,0,0,8,19,0,0,28,31,0,0,32,146,215,0,0,8,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,200,151,2,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,240,232,5,0,0,0,0,0,160,150,4,0,240,129,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,2,4,2,0,0,0,0,0,0,0,0,0,0,0,90,57,0,0,108,10,0,0,0,0,0,0,0,0,0,0,208,49,0,0,232,38,0,0,72,0,0,0,210,7,0,0,112,14,0,0,8,19,0,0,28,31,0,0,32,146,215,0,0,8,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,88,20,1,0,200,151,2,0,0,0,0,0,0,0,0,0,240,3,2,0,184,212,8,0,0,0,0,0,160,195,1,0,16,128,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,2,4,2,0,0,0,0,0,0,0,0,0,0,0,50,25,0,0,200,12,0,0,0,0,0,0,0,0,0,0,208,49,0,0,232,38,0,0,72,0,0,0,210,7,0,0,112,14,0,0,8,19,0,0,28,31,0,0,32,146,215,0,0,8,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,48,186,2,0,152,140,2,0,0,0,0,0,0,0,0,0,192,177,6,0,208,49,2,0,0,0,0,0,200,150,4,0,16,128,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,1,4,2,0,0,0,0,0,0,0,0,0,0,0,132,17,0,0,60,38,0,0,0,0,0,0,0,0,0,0,102,55,0,0,26,44,0,0,122,12,0,0,66,11,0,0,168,10,0,0,246,6,0,0,24,44,0,0,32,146,215,0,0,8,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,160,182,7,0,152,140,2,0,0,0,0,0,0,0,0,0,192,177,6,0,104,135,7,0,0,0,0,0,200,150,4,0,16,128,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,1,4,2,0,0,0,0,0,0,0,0,0,0,0,206,5,0,0,14,27,0,0,0,0,0,0,0,0,0,0,102,55,0,0,32,23,0,0,122,12,0,0,66,11,0,0,168,10,0,0,246,6,0,0,24,44,0,0,32,146,215,0,0,8,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,232,147,8,0,152,140,2,0,0,0,0,0,0,0,0,0,192,177,6,0,184,84,8,0,0,0,0,0,200,150,4,0,16,128,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,1,4,2,0,0,0,0,0,0,0,0,0,0,0,88,18,0,0,98,37,0,0,0,0,0,0,0,0,0,0,102,55,0,0,2,15,0,0,122,12,0,0,66,11,0,0,168,10,0,0,246,6,0,0,24,44,0,0,32,146,215,0,0,8,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,64,31,8,0,152,140,2,0,0,0,0,0,0,0,0,0,192,177,6,0,0,234,7,0,0,0,0,0,200,150,4,0,16,128,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,1,4,2,0,0,0,0,0,0,0,0,0,0,0,230,58,0,0,230,27,0,0,0,0,0,0,0,0,0,0,102,55,0,0,68,20,0,0,122,12,0,0,66,11,0,0,168,10,0,0,246,6,0,0,24,44,0,0,32,146,215,0,0,8,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,112,19,1,0,152,140,2,0,0,0,0,0,0,0,0,0,192,177,6,0,216,211,8,0,0,0,0,0,200,150,4,0,16,128,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,1,4,2,0,0,0,0,0,0,0,0,0,0,0,100,12,0,0,244,9,0,0,0,0,0,0,0,0,0,0,102,55,0,0,68,20,0,0,122,12,0,0,66,11,0,0,168,10,0,0,246,6,0,0,24,44,0,0,32,146,215,0,0,8,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,16,195,1,0,152,140,2,0,0,0,0,0,0,0,0,0,192,177,6,0,128,97,1,0,0,0,0,0,200,150,4,0,16,128,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,1,4,2,0,0,0,0,0,0,0,0,0,0,0,92,34,0,0,120,26,0,0,0,0,0,0,0,0,0,0,102,55,0,0,68,25,0,0,122,12,0,0,66,11,0,0,168,10,0,0,246,6,0,0,24,44,0,0])
.concat([32,146,215,0,0,8,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,152,140,2,0,0,0,0,0,0,0,0,0,0,0,0,0,192,177,6,0,80,229,5,0,0,0,0,0,200,150,4,0,16,128,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,1,4,2,0,0,0,0,0,0,0,0,0,0,0,8,26,0,0,186,35,0,0,0,0,0,0,0,0,0,0,102,55,0,0,72,47,0,0,122,12,0,0,66,11,0,0,168,10,0,0,246,6,0,0,24,44,0,0,32,146,215,0,0,8,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,56,218,7,0,240,190,4,0,0,0,0,0,0,0,0,0,216,194,1,0,56,208,7,0,0,0,0,0,192,154,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,53,0,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,42,7,0,0,174,16,0,0,0,0,0,0,0,0,0,0,192,58,0,0,216,56,0,0,110,1,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,136,246,2,0,208,42,5,0,0,0,0,0,0,0,0,0,64,171,7,0,48,92,2,0,0,0,0,0,248,39,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,142,28,0,0,210,32,0,0,0,0,0,0,0,0,0,0,74,52,0,0,86,30,0,0,40,17,0,0,182,14,0,0,208,10,0,0,210,13,0,0,106,45,0,0,176,175,145,0,0,8,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,15,3,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,232,10,6,0,0,0,0,0,216,123,2,0,8,147,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,4,11,0,16,0,0,0,0,0,0,0,0,0,0,78,62,0,0,246,0,0,0,0,0,0,0,0,0,0,0,98,41,0,0,204,10,0,0,234,9,0,0,48,9,0,0,126,17,0,0,0,0,0,0,236,36,0,0,0,0,0,0,0,8,0,0,128,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,8,45,2,0,208,72,2,0,0,0,0,0,0,0,0,0,144,33,2,0,136,23,2,0,0,0,0,0,192,154,4,0,48,178,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,0,10,0,8,0,0,0,0,0,0,0,0,0,0,14,38,0,0,248,16,0,0,0,0,0,0,0,0,0,0,82,46,0,0,38,3,0,0,64,5,0,0,188,13,0,0,168,14,0,0,0,0,0,0,208,30,0,0,0,0,0,0,0,4,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,46,7,0,88,189,7,0,0,0,0,0,0,0,0,0,96,135,2,0,176,1,7,0,0,0,0,0,72,187,4,0,200,156,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,1,14,2,0,0,0,0,0,0,0,0,0,0,0,136,13,0,0,76,39,0,0,0,0,0,0,0,0,0,0,238,62,0,0,182,2,0,0,88,10,0,0,236,10,0,0,222,18,0,0,0,0,0,0,238,10,0,0,0,0,0,0,0,16,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,232,160,5,0,104,135,2,0,0,0,0,0,0,0,0,0,232,167,7,0,160,156,5,0,160,173,1,0,144,127,3,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,0,0,0,2,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,0,0,0,0,172,56,0,0,152,42,0,0,0,0,0,0,0,0,0,0,150,22,0,0,222,53,0,0,108,0,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,104,135,2,0,0,0,0,0,0,0,0,0,0,0,0,0,232,167,7,0,184,228,5,0,72,150,4,0,144,127,3,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,180,41,0,0,76,35,0,0,0,0,0,0,0,0,0,0,36,31,0,0,0,0,0,0,200,16,0,0,128,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,232,199,2,0,0,0,0,0,0,0,0,0,0,0,0,0,104,174,7,0,48,244,5,0,0,0,0,0,168,138,8,0,248,135,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,19,4,0,0,0,0,0,0,0,0,0,0,0,126,7,0,0,198,45,0,0,0,0,0,0,0,0,0,0,72,1,0,0,104,15,0,0,18,8,0,0,212,0,0,0,140,12,0,0,0,0,0,0,24,26,0,0,0,0,0,0,0,4,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,40,146,2,0,0,0,0,0,0,0,0,0,0,0,0,0,32,127,5,0,144,231,5,0,0,0,0,0,176,237,2,0,168,84,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,19,0,0,4,0,0,0,0,0,0,0,0,0,108,54,0,0,54,1,0,0,0,0,0,0,0,0,0,0,114,1,0,0,150,30,0,0,168,11,0,0,100,6,0,0,246,12,0,0,112,10,0,0,10,62,0,0,112,173,145,0,0,8,0,0,128,2,0,0,240,0,0,0,8,0,0,0,3,0,0,0,64,229,8,0,0,0,0,0,0,0,0,0,0,0,0,0,232,167,7,0,224,220,8,0,0,0,0,0,160,212,8,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,8,0,0,2,0,0,0,0,0,0,16,0,0,8,0,0,0,0,0,0,0,0,0,212,9,0,0,12,4,0,0,0,0,0,0,0,0,0,0,38,17,0,0,140,28,0,0,138,0,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,88,77,5,0,0,0,0,0,0,0,0,0,0,0,0,0,64,164,6,0,168,105,6,0,120,249,4,0,24,202,3,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,18,9,0,0,140,38,0,0,0,0,0,0,0,0,0,0,16,10,0,0,0,0,0,0,238,13,0,0,14,18,0,0,222,16,0,0,118,0,0,0,30,5,0,0,224,175,145,0,0,64,0,0,0,4,0,0,0,3,0,0,4,0,0,0,3,0,0,0,96,214,5,0,0,0,0,0,0,0,0,0,0,0,0,0,200,190,7,0,80,138,5,0,0,0,0,0,192,223,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,2,0,0,0,0,0,0,20,4,0,0,0,0,0,0,0,0,0,0,0,184,28,0,0,188,24,0,0,0,0,0,0,0,0,0,0,194,6,0,0,206,33,0,0,60,9,0,0,248,1,0,0,100,9,0,0,230,11,0,0,254,30,0,0,184,175,145,0,0,4,0,0,240,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,208,110,5,0,96,214,5,0,0,0,0,0,0,0,0,0,200,190,7,0,208,78,5,0,0,0,0,0,192,223,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,20,4,0,0,0,0,0,0,0,0,0,0,0,254,16,0,0,212,37,0,0,0,0,0,0,0,0,0,0,194,6,0,0,206,33,0,0,60,9,0,0,248,1,0,0,100,9,0,0,230,11,0,0,254,30,0,0,184,175,145,0,0,4,0,0,240,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,64,188,3,0,192,78,4,0,0,0,0,0,0,0,0,0,104,221,5,0,24,163,3,0,0,0,0,0,104,24,4,0,80,150,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,1,4,4,2,2,0,0,0,0,0,0,0,0,0,0,0,230,36,0,0,132,30,0,0,0,0,0,0,0,0,0,0,50,22,0,0,214,6,0,0,98,4,0,0,114,17,0,0,134,11,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,250,3,0,192,78,4,0,0,0,0,0,0,0,0,0,104,221,5,0,64,217,3,0,0,0,0,0,104,24,4,0,80,150,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,2,4,4,2,2,0,0,0,0,0,0,0,0,0,0,0,224,30,0,0,170,8,0,0,0,0,0,0,0,0,0,0,50,22,0,0,214,6,0,0,54,0,0,0,114,17,0,0,134,11,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,192,78,4,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,200,52,4,0,0,0,0,0,104,24,4,0,80,150,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,4,4,2,2,0,0,0,0,0,0,0,0,0,0,0,150,48,0,0,168,27,0,0,0,0,0,0,0,0,0,0,50,22,0,0,214,6,0,0,206,11,0,0,114,17,0,0,134,11,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,48,250,8,0,232,36,3,0,0,0,0,0,0,0,0,0,144,47,2,0,152,186,8,0,0,0,0,0,152,121,8,0,152,8,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,4,0,0,0,0,0,4,17,0,0,1,0,0,0,0,0,0,0,0,0,24,33,0,0,132,15,0,0,0,0,0,0,0,0,0,0,52,51,0,0,42,0,0,0,6,6,0,0,80,0,0,0,228,1,0,0,44,8,0,0,0,0,0,0,32,177,145,0,0,2,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,0,195,4,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,128,132,4,0,0,0,0,0,80,105,4,0,80,150,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,16,4,2,0,0,1,0,0,0,0,0,0,0,0,0,26,39,0,0,70,43,0,0,0,0,0,0,0,0,0,0,82,36,0,0,240,29,0,0,238,1,0,0,114,17,0,0,134,11,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,63,1,0,144,202,8,0,0,0,0,0,0,0,0,0,64,171,7,0,160,250,8,0,0,0,0,0,104,158,1,0,136,11,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,19,0,0,0,2,0,0,0,0,0,2,17,0,8,0,0,0,0,0,0,0,0,0,0,150,54,0,0,244,19,0,0,0,0,0,0,0,0,0,0,188,45,0,0,86,29,0,0,44,12,0,0,150,14,0,0,160,6,0,0,224,14,0,0,222,61,0,0,40,177,145,0,4,1,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,144,38,3,0,144,202,8,0,0,0,0,0,0,0,0,0,64,171,7,0,112,1,2,0,0,0,0,0,104,158,1,0,136,11,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,19,0,0,0,2,0,0,0,0,0,2,17,0,8,0,0,0,0,0,0,0,0,0,0,102,29,0,0,188,43,0,0,0,0,0,0,0,0,0,0,188,45,0,0,86,29,0,0,44,12,0,0,150,14,0,0,160,6,0,0,224,14,0,0,222,61,0,0,40,177,145,0,4,1,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,118,7,0,80,113,7,0,0,0,0,0,0,0,0,0,216,194,1,0,80,107,7,0,0,0,0,0,192,154,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,53,8,0,0,2,0,0,0,0,0,0,16,1,0,0,0,0,0,0,0,0,0,0,0,44,21,0,0,16,23,0,0,0,0,0,0,0,0,0,0,202,38,0,0,150,25,0,0,80,1,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,96,17,4,0,80,113,7,0,0,0,0,0,0,0,0,0,216,194,1,0,152,15,4,0,0,0,0,0,184,19,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,8,0,0,2,0,0,0,0,0,0,16,1,0,0,0,0,0,0,0,0,0,0,0,194,18,0,0,176,39,0,0,0,0,0,0,0,0,0,0,46,12,0,0,110,61,0,0,220,19,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,80,113,7,0,0,0,0,0,0,0,0,0,0,0,0,0,216,194,1,0,192,21,4,0,0,0,0,0,184,19,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,8,0,0,2,0,0,0,0,0,0,16,1,0,0,0,0,0,0,0,0,0,0,0,230,53,0,0,220,16,0,0,0,0,0,0,0,0,0,0,46,12,0,0,110,61,0,0,220,19,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,64,152,7,0,96,58,5,0,0,0,0,0,0,0,0,0,184,168,7,0,128,106,7,0,120,155,4,0,64,236,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,182,17,0,0,98,21,0,0,0,0,0,0,0,0,0,0,142,19,0,0,206,53,0,0,18,18,0,0,202,2,0,0,166,19,0,0,188,6,0,0,214,31,0,0,200,175,145,0,0,1,0,0,240,0,0,0,80,1,0,0,3,0,0,0,4,0,0,0,192,50,8,0,96,58,5,0,0,0,0,0,0,0,0,0,184,168,7,0,160,201,7,0,120,155,4,0,64,236,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,212,62,0,0,74,10,0,0,0,0,0,0,0,0,0,0,142,19,0,0,206,53,0,0,18,18,0,0,202,2,0,0,166,19,0,0,188,6,0,0,214,31,0,0,200,175,145,0,0,1,0,0,240,0,0,0,80,1,0,0,3,0,0,0,4,0,0,0,128,170,8,0,96,58,5,0,0,0,0,0,0,0,0,0,104,174,7,0,40,107,8,0,0,0,0,0,192,154,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,124,46,0,0,28,20,0,0,0,0,0,0,0,0,0,0,142,19,0,0,142,26,0,0,154,12,0,0,202,2,0,0,166,19,0,0,188,6,0,0,214,31,0,0,200,175,145,0,0,1,0,0,80,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,240,134,1,0,96,58,5,0,0,0,0,0,0,0,0,0,104,174,7,0,176,46,1,0,120,155,4,0,192,154,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,218,22,0,0,74,0,0,0,0,0,0,0,0,0,0,0,142,19,0,0,142,26,0,0,18,18,0,0,202,2,0,0,166,19,0,0,188,6,0,0,214,31,0,0,200,175,145,0,0,1,0,0,80,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,112,93,2,0,96,58,5,0,0,0,0,0,0,0,0,0,104,174,7,0,0,233,1,0,120,155,4,0,64,236,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,250,51,0,0,54,16,0,0,0,0,0,0,0,0,0,0,142,19,0,0,142,26,0,0,18,18,0,0,202,2,0,0,166,19,0,0,188,6,0,0,214,31,0,0,200,175,145,0,0,1,0,0,80,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,96,58,5,0,0,0,0,0,0,0,0,0,0,0,0,0,104,174,7,0,136,103,6,0,120,155,4,0,64,236,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,122,2,0,0,132,34,0,0,0,0,0,0,0,0,0,0,142,19,0,0,142,26,0,0,18,18,0,0,202,2,0,0,166,19,0,0,188,6,0,0,214,31,0,0,200,175,145,0,0,1,0,0,80,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,0,14,2,0,0,0,0,0,0,0,0,0,0,0,0,0,240,3,2,0,8,6,2,0,0,0,0,0,72,108,5,0,0,227,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,21,0,0,1,0,0,0,0,0,0,0,0,0,154,52,0,0,32,14,0,0,0,0,0,0,0,0,0,0,94,49,0,0,12,38,0,0,170,17,0,0,248,19,0,0,72,13,0,0,198,3,0,0,96,10,0,0,224,174,145,0,0,2,0,0,128,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,112,70,2,0,0,0,0,0,0,0,0,0,0,0,0,0,184,230,7,0,152,113,1,0,64,33,1,0,72,161,3,0,144,211,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,8,0,0,0,0,0,0,0,0,0,0,0,212,20,0,0,116,17,0,0,0,0,0,0,0,0,0,0,76,11,0,0,104,44,0,0,104,17,0,0,208,0,0,0,74,4,0,0,94,9,0,0,144,53,0,0,48,174,145,0,0,32,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,112,141,3,0,0,0,0,0,0,0,0,0,0,0,0,0,192,177,6,0,160,34,6,0,64,193,4,0,72,161,3,0,144,211,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,8,0,0,0,0,0,0,0,0,0,0,0,92,19,0,0,120,5,0,0,0,0,0,0,0,0,0,0,76,11,0,0,104,44,0,0,104,17,0,0,208,0,0,0,74,4,0,0,94,9,0,0,144,53,0,0,48,174,145,0,0,32,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,144,244,5,0,144,126,6,0,0,0,0,0,0,0,0,0,104,174,7,0,40,204,5,0,0,0,0,0,144,84,8,0,128,194,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,3,11,2,0,0,0,0,0,0,0,0,0,0,0,8,27,0,0,250,14,0,0,0,0,0,0,0,0,0,0,90,22,0,0,196,16,0,0,220,8,0,0,224,17,0,0,188,8,0,0,2,1,0,0,74,29,0,0,0,0,0,0,0,16,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,144,126,6,0,0,0,0,0,0,0,0,0,0,0,0,0,104,174,7,0,8,35,6,0,0,0,0,0,144,84,8,0,128,194,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,3,11,2,0,0,0,0,0,0,0,0,0,0,0,46,4,0,0,76,40,0,0,0,0,0,0,0,0,0,0,90,22,0,0,196,16,0,0,220,8,0,0,224,17,0,0,188,8,0,0,2,1,0,0,74,29,0,0,0,0,0,0,0,16,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,248,218,4,0,120,136,1,0,0,0,0,0,0,0,0,0,224,56,7,0,128,184,4,0,0,0,0,0,16,153,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,8,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,206,2,0,0,250,31,0,0,0,0,0,0,0,0,0,0,86,51,0,0,162,48,0,0,8,7,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,16,31,1,0,80,67,3,0,0,0,0,0,0,0,0,0,104,221,5,0,96,220,8,0,0,0,0,0,40,161,4,0,8,153,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,3,0,0,0,64,0,6,2,0,8,0,0,0,0,0,0,0,0,0,0,144,40,0,0,20,27,0,0,0,0,0,0,0,0,0,0,138,49,0,0,94,41,0,0,232,15,0,0,164,2,0,0,20,14,0,0,0,0,0,0,106,0,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,206,1,0,80,67,3,0,0,0,0,0,0,0,0,0,104,221,5,0,216,108,1,0,0,0,0,0,40,161,4,0,8,153,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,64,0,6,2,0,8,0,0,0,0,0,0,0,0,0,0,26,3,0,0,78,31,0,0,0,0,0,0,0,0,0,0,196,58,0,0,110,52,0,0,232,15,0,0,164,2,0,0,20,14,0,0,0,0,0,0,106,0,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,205,2,0,80,67,3,0,0,0,0,0,0,0,0,0,104,221,5,0,48,66,2,0,0,0,0,0,40,161,4,0,8,153,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,3,0,0,0,64,0,6,2,0,8,0,0,0,0,0,0,0,0,0,0,250,50,0,0,254,5,0,0,0,0,0,0,0,0,0,0,138,49,0,0,94,41,0,0,232,15,0,0,164,2,0,0,20,14,0,0,0,0,0,0,106,0,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,80,67,3,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,120,20,6,0,0,0,0,0,40,161,4,0,8,153,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,64,0,6,2,0,8,0,0,0,0,0,0,0,0,0,0,94,36,0,0,236,37,0,0,0,0,0,0,0,0,0,0,196,58,0,0,110,52,0,0,232,15,0,0,164,2,0,0,20,14,0,0,0,0,0,0,106,0,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,249,7,0,112,100,8,0,0,0,0,0,0,0,0,0,96,159,4,0,120,240,7,0,0,0,0,0,184,234,7,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,0,0,0,2,0,0,0,0,0,0,16,2,0,0,0,0,0,0,0,0,0,0,0,130,2,0,0,38,26,0,0,0,0,0,0,0,0,0,0,86,51,0,0,20,20,0,0,134,4,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,184,62,3,0,64,161,3,0,0,0,0,0,0,0,0,0,104,221,5,0,24,46,3,0,0,0,0,0,128,161,4,0,168,196,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,5,11,2,0,0,0,0,0,0,0,0,0,0,0,48,0,0,0,160,10,0,0,0,0,0,0,0,0,0,0,184,15,0,0,62,39,0,0,6,10,0,0,178,11,0,0,82,0,0,0,238,10,0,0,188,1,0,0,0,0,0,0,0,16,0,0,224,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,96,90,3,0,64,161,3,0,0,0,0,0,0,0,0,0,104,221,5,0,168,75,3,0,0,0,0,0,144,84,8,0,168,196,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,5,11,2,0,0,0,0,0,0,0,0,0,0,0,164,31,0,0,156,9,0,0,0,0,0,0,0,0,0,0,184,15,0,0,62,14,0,0,6,10,0,0,178,11,0,0,82,0,0,0,238,10,0,0,188,1,0,0,0,0,0,0,0,16,0,0,224,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,64,161,3,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,160,112,3,0,0,0,0,0,168,183,7,0,168,196,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,5,11,2,0,0,0,0,0,0,0,0,0,0,0,94,5,0,0,128,33,0,0,0,0,0,0,0,0,0,0,184,15,0,0,64,5,0,0,6,10,0,0,178,11,0,0,82,0,0,0,238,10,0,0,188,1,0,0,0,0,0,0,0,16,0,0,224,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,208,59,2,0,144,220,2,0,0,0,0,0,0,0,0,0,104,221,5,0,120,201,1,0,216,165,4,0,80,139,3,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,3,11,0,0,1,0,0,0,0,0,0,0,0,0,38,26,0,0,186,27,0,0,0,0,0,0,0,0,0,0,78,34,0,0,250,55,0,0,26,2,0,0,188,19,0,0,190,3,0,0,26,1,0,0,196,1,0,0,0,0,0,0,0,8,0,0,32,1,0,0,208,0,0,0,4,0,0,0,3,0,0,0,64,65,3,0,152,68,3,0,0,0,0,0,0,0,0,0,216,194,1,0,248,63,3,0,0,0,0,0,56,72,3,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,8,0,0,2,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,0,0,0,0,100,30,0,0,40,8,0,0,0,0,0,0,0,0,0,0,46,12,0,0,120,15,0,0,254,3,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,152,68,3,0,0,0,0,0,0,0,0,0,0,0,0,0,216,194,1,0,56,67,3,0,0,0,0,0,56,72,3,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,8,0,0,2,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,0,0,0,0,198,14,0,0,30,30,0,0,0,0,0,0,0,0,0,0,46,12,0,0,120,15,0,0,254,3,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,160,233,2,0,200,143,4,0,0,0,0,0,0,0,0,0,104,174,7,0,216,81,2,0,0,0,0,0,72,226,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,54,52,0,0,10,47,0,0,0,0,0,0,0,0,0,0,152,20,0,0,60,25,0,0,106,13,0,0,62,8,0,0,92,16,0,0,16,7,0,0,172,10,0,0,40,175,145,0,0,8,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,200,143,4,0,0,0,0,0,0,0,0,0,0,0,0,0,104,174,7,0,40,72,6,0,0,0,0,0,72,226,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,110,10,0,0,72,9,0,0,0,0,0,0,0,0,0,0,152,20,0,0,60,25,0,0,106,13,0,0,62,8,0,0,92,16,0,0,16,7,0,0,172,10,0,0,40,175,145,0,0,8,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,240,33,8,0,0,0,0,0,0,0,0,0,0,0,0,0,200,190,7,0,32,237,7,0,0,0,0,0,168,183,7,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,3,11,0,0,1,0,0,0,0,0,0,0,0,0,44,53,0,0,52,12,0,0,0,0,0,0,0,0,0,0,186,32,0,0,70,43,0,0,108,11,0,0,82,3,0,0,246,2,0,0,152,1,0,0,92,6,0,0,144,173,145,0,0,2,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,96,184,7,0,240,33,8,0,0,0,0,0,0,0,0,0,200,190,7,0,0,138,7,0,0,0,0,0,88,90,7,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,3,11,0,0,1,0,0,0,0,0,0,0,0,0,70,63,0,0,220,0,0,0,0,0,0,0,0,0,0,0,186,32,0,0,134,35,0,0,108,11,0,0,82,3,0,0,246,2,0,0,152,1,0,0,92,6,0,0,144,173,145,0,0,2,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,56,41,7,0,240,33,8,0,0,0,0,0,0,0,0,0,200,190,7,0,208,252,6,0,0,0,0,0,144,84,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,3,11,0,0,1,0,0,0,0,0,0,0,0,0,220,7,0,0,234,3,0,0,0,0,0,0,0,0,0,0,186,32,0,0,134,35,0,0,108,11,0,0,82,3,0,0,246,2,0,0,152,1,0,0,92,6,0,0,144,173,145,0,0,2,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,56,213,6,0,240,33,8,0,0,0,0,0,0,0,0,0,200,190,7,0,72,166,6,0,0,0,0,0,192,154,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,3,11,0,0,1,0,0,0,0,0,0,0,0,0,58,20,0,0,10,18,0,0,0,0,0,0,0,0,0,0,186,32,0,0,134,35,0,0,108,11,0,0,82,3,0,0,246,2,0,0,152,1,0,0,92,6,0,0,144,173,145,0,0,2,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,192,191,7,0,152,219,7,0,0,0,0,0,0,0,0,0,0,38,7,0,112,184,7,0,216,165,4,0,232,167,5,0,80,164,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,0,10,2,0,0,0,0,0,0,0,0,0,0,0,12,36,0,0,24,14,0,0,0,0,0,0,0,0,0,0,116,9,0,0,36,50,0,0,212,15,0,0,56,12,0,0,212,3,0,0,96,11,0,0,0,0,0,0,0,0,0,0,0,4,0,0,224,0,0,0,128,1,0,0,3,0,0,0,4,0,0,0,80,34,8,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,64,29,8,0,48,25,8,0,0,227,2,0,0,227,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,1,21,0,0,1,0,0,0,0,0,0,0,0,0,176,54,0,0,106,41,0,0,0,0,0,0,0,0,0,0,100,61,0,0,88,42,0,0,128,16,0,0,248,19,0,0,72,13,0,0,230,0,0,0,96,10,0,0,224,174,145,0,0,2,0,0,224,0,0,0,128,1,0,0,3,0,0,0,4,0,0,0,112,117,3,0,208,140,3,0,0,0,0,0,0,0,0,0,40,41,5,0,8,114,3,0,0,0,0,0,192,154,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,8,0,0,2,0,0,0,0,0,0,16,1,0,0,0,0,0,0,0,0,0,0,0,148,15,0,0,192,1,0,0,0,0,0,0,0,0,0,0,128,9,0,0,204,41,0,0,10,17,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,88,128,3,0,0,0,0,0,0,0,0,0,0,0,0,0,168,163,7,0,96,32,6,0,0,0,0,0,16,191,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,0,16,0,0,0,0,0,0,0,0,0,0,116,48,0,0,246,30,0,0,0,0,0,0,0,0,0,0,170,55,0,0,34,14,0,0,132,13,0,0,110,10,0,0,180,5,0,0,218,4,0,0,240,13,0,0,32,174,145,0,0,8,0,0,64,1,0,0,0,1,0,0,4,0,0,0,3,0,0,0,96,104,1,0,168,244,2,0,0,0,0,0,0,0,0,0,104,221,5,0,16,26,1,0,0,0,0,0,144,84,8,0,216,142,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,11,0,0,1,0,0,0,0,0,0,0,0,0,22,56,0,0,236,30,0,0,0,0,0,0,0,0,0,0,114,13,0,0,186,12,0,0,36,18,0,0,24,8,0,0,14,5,0,0,0,0,0,0,60,41,0,0,0,0,0,0,0,16,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,160,198,2,0,168,244,2,0,0,0,0,0,0,0,0,0,104,221,5,0,208,60,2,0,0,0,0,0,144,84,8,0,216,142,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,11,0,0,1,0,0,0,0,0,0,0,0,0,216,17,0,0,114,2,0,0,0,0,0,0,0,0,0,0,114,13,0,0,186,12,0,0,36,18,0,0,24,8,0,0,14,5,0,0,0,0,0,0,60,41,0,0,0,0,0,0,0,16,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,168,244,2,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,248,2,6,0,0,0,0,0,168,183,7,0,216,142,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,11,0,0,1,0,0,0,0,0,0,0,0,0,10,33,0,0,18,2,0,0,0,0,0,0,0,0,0,0,114,13,0,0,250,49,0,0,36,18,0,0,24,8,0,0,14,5,0,0,0,0,0,0,60,41,0,0,0,0,0,0,0,16,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,96,245,2,0,240,249,2,0,0,0,0,0,0,0,0,0,232,167,7,0,192,242,2,0,0,0,0,0,192,154,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,0,0,0,2,0,0,0,0,0,0,16,1,0,0,0,0,0,0,0,0,0,0,0,100,50,0,0,102,38,0,0,0,0,0,0,0,0,0,0,160,8,0,0,202,43,0,0,254,0,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,48,49,7,0,176,171,7,0,72,172,6,0,0,0,0,0,168,163,7,0,240,42,7,0,0,0,0,0,128,145,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,133,8,0,0,0,0,0,0,0,0,0,0,0,14,24,0,0,182,8,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,171,7,0,0,0,0,0,72,172,6,0,0,0,0,0,168,163,7,0,40,61,7,0,0,0,0,0,128,145,4,0,208,9,3,0,112,54,7,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,8,0,0,0,0,0,0,0,0,0,0,0,0,39,0,0,138,12,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,30,8,0,200,41,1,0,72,172,6,0,0,0,0,0,0,38,7,0,136,26,8,0,0,0,0,0,128,145,4,0,208,9,3,0,224,21,8,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,1,133,8,0,0,0,0,0,0,0,0,0,0,0,66,15,0,0,14,46,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,198,16,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,200,41,1,0,0,0,0,0,72,172,6,0,0,0,0,0,0,38,7,0,48,42,8,0,0,0,0,0,128,145,4,0,208,9,3,0,248,34,8,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,8,0,0,0,0,0,0,0,0,0,0,0,8,22,0,0,96,2,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,40,2,0,0,0,0,0,72,172,6,0,0,0,0,0,96,135,2,0,128,169,8,0,0,0,0,0,128,145,4,0,208,9,3,0,80,158,8,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,4,0,1,133,8,0,0,0,0,0,0,0,0,0,0,0,168,0,0,0,206,19,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,48,3,0,80,59,3,0,0,0,0,0,0,0,0,0,64,164,6,0,56,45,3,0,0,0,0,0,40,42,3,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,8,0,0,2,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,0,0,0,0,6,16,0,0,14,45,0,0,0,0,0,0,0,0,0,0,144,18,0,0,94,32,0,0,184,13,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,168,54,3,0,80,59,3,0,0,0,0,0,0,0,0,0,64,164,6,0,72,52,3,0,0,0,0,0,112,49,3,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,0,0,0,0,250,35,0,0,128,7,0,0,0,0,0,0,0,0,0,0,156,50,0,0,2,41,0,0,196,16,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,80,59,3,0,0,0,0,0,0,0,0,0,0,0,0,0,232,167,7,0,176,58,3,0,0,0,0,0,224,56,3,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,8,0,0,2,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,0,0,0,0,118,41,0,0,116,35,0,0,0,0,0,0,0,0,0,0,190,49,0,0,116,1,0,0,8,4,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,0,77,3,0,0,0,0,0,0,0,0,0,0,0,0,0,104,174,7,0,160,23,6,0,0,0,0,0,32,184,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,2,0,0,0,0,0,10,2,0,0,1,0,0,0,0,0,0,0,0,0,128,19,0,0,240,46,0,0,0,0,0,0,0,0,0,0,110,27,0,0,22,52,0,0,78,6,0,0,222,5,0,0,170,10,0,0,98,17,0,0,212,43,0,0,0,0,0,0,0,1,0,0,240,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,40,97,4,0,16,124,4,0,0,0,0,0,0,0,0,0,232,167,7,0,72,95,4,0,0,0,0,0,192,154,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,8,0,0,2,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,0,0,0,0,190,26,0,0,56,13,0,0,0,0,0,0,0,0,0,0,68,15,0,0,172,61,0,0,72,11,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0])
.concat([3,0,0,0,4,0,0,0,144,114,4,0,16,124,4,0,0,0,0,0,0,0,0,0,232,167,7,0,104,112,4,0,0,0,0,0,200,147,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,8,0,0,2,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,0,0,0,0,208,1,0,0,192,8,0,0,0,0,0,0,0,0,0,0,68,15,0,0,172,61,0,0,72,11,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,216,93,4,0,16,124,4,0,0,0,0,0,0,0,0,0,232,167,7,0,104,89,4,0,0,0,0,0,168,95,8,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,0,0,0,0,60,30,0,0,150,41,0,0,0,0,0,0,0,0,0,0,68,15,0,0,14,2,0,0,228,9,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,40,109,4,0,16,124,4,0,0,0,0,0,0,0,0,0,232,167,7,0,224,105,4,0,0,0,0,0,88,102,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,8,0,0,2,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,0,0,0,0,142,38,0,0,234,46,0,0,0,0,0,0,0,0,0,0,68,15,0,0,192,1,0,0,72,11,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,176,100,4,0,16,124,4,0,0,0,0,0,0,0,0,0,232,167,7,0,208,98,4,0,0,0,0,0,192,154,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,8,0,0,2,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,0,0,0,0,42,40,0,0,142,1,0,0,0,0,0,0,0,0,0,0,68,15,0,0,172,61,0,0,72,11,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,40,120,4,0,16,124,4,0,0,0,0,0,0,0,0,0,216,194,1,0,232,117,4,0,0,0,0,0,168,95,8,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,8,0,0,2,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,0,0,0,0,208,55,0,0,230,8,0,0,0,0,0,0,0,0,0,0,68,15,0,0,28,44,0,0,72,11,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,16,124,4,0,0,0,0,0,0,0,0,0,0,0,0,0,216,194,1,0,72,122,4,0,0,0,0,0,168,95,8,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,8,0,0,2,0,0,0,0,0,0,16,0,1,0,0,0,0,0,0,0,0,0,0,78,30,0,0,62,46,0,0,0,0,0,0,0,0,0,0,68,15,0,0,172,61,0,0,72,11,0,0,64,4,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,176,237,8,0,16,182,5,0,0,0,0,0,0,0,0,0,64,164,6,0,72,173,8,0,0,0,0,0,176,109,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,234,2,0,0,224,4,0,0,0,0,0,0,0,0,0,0,202,27,0,0,88,63,0,0,182,7,0,0,228,13,0,0,116,2,0,0,234,4,0,0,228,2,0,0,48,176,145,0,0,1,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,253,2,0,16,182,5,0,0,0,0,0,0,0,0,0,64,164,6,0,144,97,2,0,0,0,0,0,96,235,1,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,46,30,0,0,162,4,0,0,0,0,0,0,0,0,0,0,202,27,0,0,88,63,0,0,182,7,0,0,228,13,0,0,116,2,0,0,234,4,0,0,228,2,0,0,48,176,145,0,0,1,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,138,1,0,16,182,5,0,0,0,0,0,0,0,0,0,64,164,6,0,144,49,1,0,0,0,0,0,232,3,5,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,206,59,0,0,170,13,0,0,0,0,0,0,0,0,0,0,202,27,0,0,88,63,0,0,182,7,0,0,228,13,0,0,116,2,0,0,234,4,0,0,228,2,0,0,48,176,145,0,0,1,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,182,5,0,0,0,0,0,0,0,0,0,0,0,0,0,64,164,6,0,112,118,6,0,0,0,0,0,232,3,5,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,204,0,0,0,194,47,0,0,0,0,0,0,0,0,0,0,202,27,0,0,88,63,0,0,182,7,0,0,228,13,0,0,116,2,0,0,234,4,0,0,228,2,0,0,48,176,145,0,0,1,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,169,8,0,0,0,0,0,0,0,0,0,0,0,0,0,160,234,7,0,80,49,8,0,0,0,0,0,72,226,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,112,24,0,0,254,3,0,0,0,0,0,0,0,0,0,0,130,27,0,0,216,21,0,0,174,17,0,0,180,14,0,0,36,3,0,0,0,0,0,0,42,52,0,0,136,35,149,0,16,17,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,88,253,7,0,64,169,8,0,0,0,0,0,0,0,0,0,160,234,7,0,56,200,7,0,0,0,0,0,72,226,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,8,3,0,0,108,41,0,0,0,0,0,0,0,0,0,0,130,27,0,0,216,21,0,0,96,7,0,0,180,14,0,0,36,3,0,0,0,0,0,0,42,52,0,0,136,35,149,0,16,17,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,64,169,6,0,104,239,7,0,0,0,0,0,0,0,0,0,104,174,7,0,184,127,6,0,0,0,0,0,40,161,4,0,80,150,3,0,160,78,6,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,64,4,4,2,4,0,0,0,0,0,0,0,0,0,0,0,170,4,0,0,188,17,0,0,0,0,0,0,0,0,0,0,50,22,0,0,130,43,0,0,198,13,0,0,114,17,0,0,134,11,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,32,140,7,0,104,239,7,0,0,0,0,0,0,0,0,0,104,174,7,0,88,93,7,0,0,0,0,0,40,161,4,0,80,150,3,0,80,44,7,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,4,4,2,4,0,0,0,0,0,0,0,0,0,0,0,8,24,0,0,186,19,0,0,0,0,0,0,0,0,0,0,50,22,0,0,130,43,0,0,116,19,0,0,114,17,0,0,134,11,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,72,5,0,104,239,7,0,0,0,0,0,0,0,0,0,104,174,7,0,16,40,5,0,56,10,5,0,168,231,4,0,80,150,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,4,2,4,2,4,0,0,0,0,0,0,0,0,0,0,0,188,26,0,0,254,33,0,0,0,0,0,0,0,0,0,0,50,22,0,0,130,43,0,0,186,15,0,0,114,17,0,0,134,11,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,216,130,5,0,104,239,7,0,0,0,0,0,0,0,0,0,104,174,7,0,232,102,5,0,0,0,0,0,40,161,4,0,80,150,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,4,4,2,4,0,0,0,0,0,0,0,0,0,0,0,148,39,0,0,34,7,0,0,0,0,0,0,0,0,0,0,50,22,0,0,130,43,0,0,146,9,0,0,114,17,0,0,134,11,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,112,205,5,0,104,239,7,0,0,0,0,0,0,0,0,0,104,174,7,0,0,165,5,0,0,0,0,0,40,161,4,0,80,150,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,64,4,4,2,4,0,0,0,0,0,0,0,0,0,0,0,6,34,0,0,184,10,0,0,0,0,0,0,0,0,0,0,50,22,0,0,130,43,0,0,30,17,0,0,114,17,0,0,134,11,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,36,6,0,104,239,7,0,0,0,0,0,0,0,0,0,104,174,7,0,128,247,5,0,0,0,0,0,40,161,4,0,80,150,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,8,4,4,2,4,0,0,0,0,0,0,0,0,0,0,0,92,23,0,0,102,33,0,0,0,0,0,0,0,0,0,0,50,22,0,0,130,43,0,0,30,17,0,0,114,17,0,0,134,11,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,0,7,0,104,239,7,0,0,0,0,0,0,0,0,0,104,174,7,0,200,215,6,0,0,0,0,0,40,161,4,0,80,150,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,8,4,4,2,4,0,0,0,0,0,0,0,0,0,0,0,246,50,0,0,158,22,0,0,0,0,0,0,0,0,0,0,50,22,0,0,130,43,0,0,218,12,0,0,114,17,0,0,134,11,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,104,239,7,0,0,0,0,0,0,0,0,0,0,0,0,0,104,174,7,0,32,187,7,0,0,0,0,0,40,161,4,0,80,150,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,4,4,2,4,0,0,0,0,0,0,0,0,0,0,0,108,63,0,0,232,12,0,0,0,0,0,0,0,0,0,0,50,22,0,0,130,43,0,0,144,1,0,0,114,17,0,0,134,11,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,248,20,5,0,176,134,7,0,72,172,6,0,0,0,0,0,144,47,2,0,48,242,4,0,0,0,0,0,128,145,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,81,0,0,0,2,0,0,0,0,4,1,133,2,0,0,0,0,0,0,0,0,0,0,0,62,37,0,0,230,40,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,130,17,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,134,7,0,0,0,0,0,72,172,6,0,0,0,0,0,144,47,2,0,232,51,5,0,0,0,0,0,128,145,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,1,133,2,0,0,0,0,0,0,0,0,0,0,0,172,50,0,0,48,35,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,93,8,0,0,203,2,0,0,0,0,0,0,0,0,0,200,190,7,0,216,188,7,0,0,0,0,0,40,161,4,0,248,206,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,1,0,3,2,0,1,0,0,0,0,0,0,0,0,0,0,60,15,0,0,80,47,0,0,0,0,0,0,0,0,0,0,38,13,0,0,190,15,0,0,176,15,0,0,114,17,0,0,144,2,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,91,8,0,0,203,2,0,0,0,0,0,0,0,0,0,200,190,7,0,40,36,8,0,0,0,0,0,40,161,4,0,80,150,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,5,0,4,2,0,1,0,0,0,0,0,0,0,0,0,0,122,50,0,0,248,23,0,0,0,0,0,0,0,0,0,0,172,57,0,0,176,36,0,0,248,16,0,0,114,17,0,0,134,11,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,219,8,0,0,203,2,0,0,0,0,0,0,0,0,0,200,190,7,0,112,153,8,0,0,0,0,0,40,161,4,0,80,150,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,12,0,4,2,0,1,0,0,0,0,0,0,0,0,0,0,106,5,0,0,170,11,0,0,0,0,0,0,0,0,0,0,172,57,0,0,92,43,0,0,228,12,0,0,114,17,0,0,134,11,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,45,7,0,0,203,2,0,0,0,0,0,0,0,0,0,200,190,7,0,64,1,7,0,0,0,0,0,40,161,4,0,248,206,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,2,0,3,2,0,1,0,0,0,0,0,0,0,0,0,0,76,31,0,0,10,27,0,0,0,0,0,0,0,0,0,0,38,13,0,0,190,15,0,0,210,2,0,0,114,17,0,0,144,2,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,107,1,0,0,203,2,0,0,0,0,0,0,0,0,0,200,190,7,0,104,30,1,0,0,0,0,0,40,161,4,0,80,150,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,5,0,4,2,0,1,0,0,0,0,0,0,0,0,0,0,238,51,0,0,106,31,0,0,0,0,0,0,0,0,0,0,172,57,0,0,92,43,0,0,248,16,0,0,114,17,0,0,134,11,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,141,7,0,0,203,2,0,0,0,0,0,0,0,0,0,200,190,7,0,136,94,7,0,0,0,0,0,40,161,4,0,248,206,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,1,0,3,2,0,1,0,0,0,0,0,0,0,0,0,0,244,54,0,0,184,19,0,0,0,0,0,0,0,0,0,0,38,13,0,0,190,15,0,0,176,15,0,0,114,17,0,0,144,2,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,0,203,2,0,0,0,0,0,0,0,0,0,0,0,0,0,200,190,7,0,176,205,1,0,0,0,0,0,40,161,4,0,80,150,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,4,0,4,2,0,1,0,0,0,0,0,0,0,0,0,0,20,6,0,0,26,5,0,0,0,0,0,0,0,0,0,0,172,57,0,0,92,43,0,0,228,12,0,0,114,17,0,0,134,11,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,58,1,0,88,195,7,0,0,0,0,0,0,0,0,0,104,221,5,0,144,245,8,0,0,0,0,0,168,95,8,0,72,248,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,3,1,8,0,0,0,0,0,0,0,0,0,0,218,44,0,0,230,18,0,0,0,0,0,0,0,0,0,0,228,28,0,0,154,44,0,0,58,9,0,0,88,11,0,0,62,6,0,0,112,7,0,0,18,2,0,0,112,176,145,0,0,2,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,40,59,8,0,88,195,7,0,0,0,0,0,0,0,0,0,104,221,5,0,184,6,8,0,0,0,0,0,168,95,8,0,72,248,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,3,1,8,0,0,0,0,0,0,0,0,0,0,192,55,0,0,48,9,0,0,0,0,0,0,0,0,0,0,228,28,0,0,154,44,0,0,58,9,0,0,88,11,0,0,62,6,0,0,112,7,0,0,18,2,0,0,112,176,145,0,0,2,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,182,8,0,88,195,7,0,0,0,0,0,0,0,0,0,104,221,5,0,200,116,8,0,0,0,0,0,168,95,8,0,72,248,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,3,1,8,0,0,0,0,0,0,0,0,0,0,222,37,0,0,212,28,0,0,0,0,0,0,0,0,0,0,228,28,0,0,154,44,0,0,58,9,0,0,88,11,0,0,62,6,0,0,112,7,0,0,18,2,0,0,112,176,145,0,0,2,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,208,42,5,0,0,0,0,0,0,0,0,0,0,0,0,0,64,171,7,0,152,100,6,0,0,0,0,0,248,39,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,42,33,0,0,122,21,0,0,0,0,0,0,0,0,0,0,74,52,0,0,86,30,0,0,40,17,0,0,182,14,0,0,208,10,0,0,210,13,0,0,106,45,0,0,176,175,145,0,0,8,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,224,209,7,0,88,195,7,0,0,0,0,0,0,0,0,0,104,221,5,0,24,159,7,0,0,0,0,0,168,95,8,0,72,248,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,3,1,8,0,0,0,0,0,0,0,0,0,0,14,5,0,0,42,25,0,0,0,0,0,0,0,0,0,0,228,28,0,0,154,44,0,0,58,9,0,0,88,11,0,0,62,6,0,0,112,7,0,0,18,2,0,0,112,176,145,0,0,2,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,168,246,1,0,88,195,7,0,0,0,0,0,0,0,0,0,104,221,5,0,120,150,1,0,0,0,0,0,168,95,8,0,72,248,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,3,1,8,0,0,0,0,0,0,0,0,0,0,204,23,0,0,140,23,0,0,0,0,0,0,0,0,0,0,228,28,0,0,154,44,0,0,58,9,0,0,88,11,0,0,62,6,0,0,112,7,0,0,18,2,0,0,112,176,145,0,0,2,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,21,3,0,88,195,7,0,0,0,0,0,0,0,0,0,104,221,5,0,208,109,2,0,0,0,0,0,168,95,8,0,72,248,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,3,1,8,0,0,0,0,0,0,0,0,0,0,88,54,0,0,146,16,0,0,0,0,0,0,0,0,0,0,228,28,0,0,154,44,0,0,58,9,0,0,88,11,0,0,62,6,0,0,112,7,0,0,18,2,0,0,112,176,145,0,0,2,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,195,7,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,160,166,6,0,0,0,0,0,168,95,8,0,72,248,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,3,1,8,0,0,0,0,0,0,0,0,0,0,16,12,0,0,68,2,0,0,0,0,0,0,0,0,0,0,228,28,0,0,154,44,0,0,58,9,0,0,88,11,0,0,62,6,0,0,112,7,0,0,18,2,0,0,112,176,145,0,0,2,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,39,1,0,96,77,2,0,0,0,0,0,0,0,0,0,0,38,7,0,56,228,8,0,200,212,6,0,72,174,3,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,10,8,0,0,0,0,0,0,0,0,0,0,0,170,16,0,0,56,38,0,0,0,0,0,0,0,0,0,0,26,0,0,0,108,26,0,0,70,1,0,0,36,10,0,0,24,11,0,0,102,19,0,0,172,14,0,0,184,174,145,0,0,8,0,0,192,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,77,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,7,0,88,219,1,0,200,212,6,0,72,174,3,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,10,8,0,0,0,0,0,0,0,0,0,0,0,62,44,0,0,196,22,0,0,0,0,0,0,0,0,0,0,26,0,0,0,158,24,0,0,124,5,0,0,36,10,0,0,24,11,0,0,102,19,0,0,172,14,0,0,184,174,145,0,0,8,0,0,192,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,240,220,8,0,16,110,1,0,0,0,0,0,0,0,0,0,160,234,7,0,192,154,8,0,0,0,0,0,40,161,4,0,248,206,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,1,0,3,2,0,8,0,0,0,0,0,0,0,0,0,0,96,6,0,0,214,35,0,0,0,0,0,0,0,0,0,0,50,61,0,0,156,3,0,0,218,12,0,0,114,17,0,0,144,2,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,110,1,0,0,0,0,0,0,0,0,0,0,0,0,0,160,234,7,0,232,31,1,0,0,0,0,0,40,161,4,0,248,206,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,3,2,0,8,0,0,0,0,0,0,0,0,0,0,254,32,0,0,100,28,0,0,0,0,0,0,0,0,0,0,50,61,0,0,156,3,0,0,218,12,0,0,114,17,0,0,144,2,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,184,32,6,0,0,0,0,0,0,0,0,0,0,0,0,0,160,234,7,0,16,242,5,0,0,0,0,0,40,202,5,0,72,129,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,4,4,2,0,0,0,0,0,0,0,0,0,0,0,156,18,0,0,132,36,0,0,0,0,0,0,0,0,0,0,186,49,0,0,226,32,0,0,242,16,0,0,94,12,0,0,120,8,0,0,0,0,0,0,46,35,0,0,56,74,148,0,0,1,0,0,240,0,0,0,24,1,0,0,3,0,0,0,4,0,0,0,96,116,8,0,8,173,7,0,0,0,0,0,0,0,0,0,104,174,7,0,216,58,8,0,0,0,0,0,168,95,8,0,240,185,2,0,0,6,8,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,3,4,8,0,0,0,0,0,0,0,0,0,0,106,39,0,0,134,25,0,0,0,0,0,0,0,0,0,0,48,43,0,0,216,41,0,0,72,18,0,0,190,0,0,0,226,0,0,0,168,15,0,0,236,31,0,0,88,176,145,0,0,16,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,58,1,0,8,173,7,0,0,0,0,0,0,0,0,0,104,174,7,0,248,244,8,0,0,0,0,0,168,95,8,0,240,185,2,0,224,179,8,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,3,4,8,0,0,0,0,0,0,0,0,0,0,194,24,0,0,124,45,0,0,0,0,0,0,0,0,0,0,48,43,0,0,216,41,0,0,72,18,0,0,190,0,0,0,226,0,0,0,168,15,0,0,236,31,0,0,88,176,145,0,0,16,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,153,1,0,48,10,8,0,0,0,0,0,0,0,0,0,200,190,7,0,96,60,1,0,0,0,0,0,168,95,8,0,136,253,3,0,136,246,8,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,3,2,0,0,0,0,0,0,0,0,0,0,0,100,58,0,0,16,38,0,0,0,0,0,0,0,0,0,0,194,12,0,0,126,16,0,0,26,5,0,0,24,15,0,0,136,19,0,0,76,19,0,0,202,51,0,0,176,176,145,0,0,8,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,48,10,8,0,0,0,0,0,0,0,0,0,0,0,0,0,200,190,7,0,112,175,6,0,0,0,0,0,168,95,8,0,136,253,3,0,96,29,3,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,2,0,0,0,0,0,0,3,2,0,0,0,0,0,0,0,0,0,0,0,134,15,0,0,126,10,0,0,0,0,0,0,0,0,0,0,194,12,0,0,126,16,0,0,26,5,0,0,24,15,0,0,136,19,0,0,76,19,0,0,202,51,0,0,176,176,145,0,0,8,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,0,204,3,0,8,109,5,0,0,0,0,0,0,0,0,0,200,190,7,0,56,250,2,0,0,0,0,0,48,95,2,0,136,252,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,102,36,0,0,86,30,0,0,0,0,0,0,0,0,0,0,172,22,0,0,118,53,0,0,124,2,0,0,64,13,0,0,168,2,0,0,0,0,0,0,134,1,0,0,0,0,0,0,0,1,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,109,5,0,0,0,0,0,0,0,0,0,0,0,0,0,200,190,7,0,184,110,6,0,0,0,0,0,136,252,4,0,136,252,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,114,63,0,0,194,20,0,0,0,0,0,0,0,0,0,0,172,22,0,0,118,53,0,0,124,2,0,0,64,13,0,0,168,2,0,0,0,0,0,0,134,1,0,0,0,0,0,0,0,1,0,0,32,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,96,93,4,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,24,37,4,0,0,0,0,0,152,54,6,0,200,12,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,3,17,2,0,0,0,0,0,0,0,0,0,0,0,56,26,0,0,58,44,0,0,0,0,0,0,0,0,0,0,198,62,0,0,238,53,0,0,234,7,0,0,230,1,0,0,44,6,0,0,194,15,0,0,0,0,0,0,48,177,145,0,0,2,0,0,0,1,0,0,128,1,0,0,3,0,0,0,4,0,0,0,104,217,2,0,8,181,3,0,0,0,0,0,0,0,0,0,104,221,5,0,224,72,2,0,0,0,0,0,56,201,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,2,14,0,0,1,0,0,0,0,0,0,0,0,0,10,6,0,0,96,34,0,0,0,0,0,0,0,0,0,0,108,61,0,0,238,22,0,0,18,11,0,0,236,19,0,0,208,13,0,0,88,4,0,0,136,15,0,0,0,0,0,0,0,3,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,152,213,1,0,8,181,3,0,0,0,0,0,0,0,0,0,104,221,5,0,184,115,1,0,0,0,0,0,192,154,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,0,0,0,2,0,0,0,0,0,2,14,0,0,1,0,0,0,0,0,0,0,0,0,252,17,0,0,90,12,0,0,0,0,0,0,0,0,0,0,108,61,0,0,238,22,0,0,18,11,0,0,236,19,0,0,208,13,0,0,88,4,0,0,136,15,0,0,0,0,0,0,0,3,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,8,181,3,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,224,42,6,0,0,0,0,0,56,201,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,2,14,0,0,1,0,0,0,0,0,0,0,0,0,28,8,0,0,82,13,0,0,0,0,0,0,0,0,0,0,108,61,0,0,128,52,0,0,18,11,0,0,236,19,0,0,208,13,0,0,88,4,0,0,136,15,0,0,0,0,0,0,0,3,0,0,0,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,3,7,0,160,143,7,0,0,0,0,0,0,0,0,0,168,163,7,0,216,217,6,0,0,0,0,0,184,191,7,0,80,164,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,0,0,0,10,2,0,0,0,0,0,0,0,0,0,0,0,238,14,0,0,180,34,0,0,0,0,0,0,0,0,0,0,154,20,0,0,14,33,0,0,76,11,0,0,56,9,0,0,210,3,0,0,210,14,0,0,0,0,0,0,0,0,0,0,0,4,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,160,143,7,0,0,0,0,0,0,0,0,0,0,0,0,0,168,163,7,0,0,48,7,0,0,0,0,0,184,191,7,0,80,164,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,0,10,2,0,0,0,0,0,0,0,0,0,0,0,146,33,0,0,98,28,0,0,0,0,0,0,0,0,0,0,154,20,0,0,14,33,0,0,76,11,0,0,56,9,0,0,210,3,0,0,210,14,0,0,0,0,0,0,0,0,0,0,0,4,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,152,190,3,0,144,55,4,0,0,0,0,0,0,0,0,0,168,163,7,0,0,165,3,0,0,0,0,0,152,210,4,0,136,153,3,0,128,139,3,0,0,0,0,0,0,0,0,0,0,0,0,0,149,0,0,0,2,0,0,0,1,0,0,6,2,0,0,0,0,0,0,0,0,0,0,0,196,8,0,0,78,34,0,0,0,0,0,0,0,0,0,0,24,47,0,0,0,0,0,0,78,3,0,0,188,12,0,0,184,4,0,0,36,11,0,0,84,24,0,0,96,49,216,0,0,128,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,184,4,3,0,144,55,4,0,0,0,0,0,0,0,0,0,168,163,7,0,160,238,2,0,0,0,0,0,152,210,4,0,136,153,3,0,200,215,2,0,0,0,0,0,0,0,0,0,0,0,0,0,149,0,0,0,2,0,0,0,1,0,0,6,2,0,0,0,0,0,0,0,0,0,0,0,220,60,0,0,32,2,0,0,0,0,0,0,0,0,0,0,24,47,0,0,0,0,0,0,78,3,0,0,188,12,0,0,184,4,0,0,36,11,0,0,84,24,0,0,96,49,216,0,0,128,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,240,64,3,0,144,55,4,0,0,0,0,0,0,0,0,0,168,163,7,0,208,48,3,0,0,0,0,0,152,210,4,0,136,153,3,0,200,28,3,0,0,0,0,0,0,0,0,0,0,0,0,0,149,0,0,0,2,0,0,0,1,0,0,6,2,0,0,0,0,0,0,0,0,0,0,0,164,36,0,0,204,14,0,0,0,0,0,0,0,0,0,0,24,47,0,0,0,0,0,0,78,3,0,0,188,12,0,0,184,4,0,0,36,11,0,0,84,24,0,0,96,49,216,0,0,128,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,136,116,3,0,144,55,4,0,0,0,0,0,0,0,0,0,168,163,7,0,160,93,3,0,0,0,0,0,152,210,4,0,136,153,3,0,200,78,3,0,0,0,0,0,0,0,0,0,0,0,0,0,149,0,0,0,2,0,0,0,1,0,0,6,2,0,0,0,0,0,0,0,0,0,0,0,88,5,0,0,200,5,0,0,0,0,0,0,0,0,0,0,24,47,0,0,0,0,0,0,78,3,0,0,188,12,0,0,184,4,0,0,36,11,0,0,84,24,0,0,96,49,216,0,0,128,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,200,195,2,0,144,55,4,0,0,0,0,0,0,0,0,0,168,163,7,0,128,178,2,0,0,0,0,0,152,210,4,0,136,153,3,0,64,164,2,0,0,0,0,0,0,0,0,0,0,0,0,0,149,0,0,0,2,0,0,0,1,0,0,6,2,0,0,0,0,0,0,0,0,0,0,0,142,58,0,0,244,23,0,0,0,0,0,0,0,0,0,0,24,47,0,0,0,0,0,0,78,3,0,0,188,12,0,0,184,4,0,0,36,11,0,0,84,24,0,0,96,49,216,0,0,128,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,144,55,4,0,0,0,0,0,0,0,0,0,0,0,0,0,168,163,7,0,72,253,3,0,0,0,0,0,152,210,4,0,136,153,3,0,56,220,3,0,0,0,0,0,0,0,0,0,0,0,0,0,133,0,0,0,2,0,0,0,1,0,0,6,2,0,0,0,0,0,0,0,0,0,0,0,230,46,0,0,6,38,0,0,0,0,0,0,0,0,0,0,24,47,0,0,0,0,0,0,78,3,0,0,188,12,0,0,184,4,0,0,36,11,0,0,84,24,0,0,96,49,216,0,0,128,0,0,240,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,88,47,8,0,232,42,1,0,0,0,0,0,0,0,0,0,144,33,2,0,208,197,7,0,0,0,0,0,248,103,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,22,0,16,0,0,0,0,0,0,0,0,0,0,126,47,0,0,240,42,0,0,0,0,0,0,0,0,0,0,20,50,0,0,22,25,0,0,200,14,0,0,202,16,0,0,72,1,0,0,100,15,0,0,160,18,0,0,72,175,145,0,1,2,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,232,42,1,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,248,165,8,0,0,0,0,0,248,103,8,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,22,0,16,0,0,0,0,0,0,0,0,0,0,86,59,0,0,134,18,0,0,0,0,0,0,0,0,0,0,20,50,0,0,22,25,0,0,200,14,0,0,202,16,0,0,72,1,0,0,100,15,0,0,160,18,0,0,72,175,145,0,1,2,0,0,64,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,200,107,5,0,112,18,4,0,0,0,0,0,0,0,0,0,96,135,2,0,184,75,5,0,0,0,0,0,224,189,4,0,168,155,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,149,0,0,0,2,0,0,0,0,0,0,10,2,0,0,0,128,0,0,0,0,0,0,0,248,30,0,0,58,21,0,0,0,0,0,0,0,0,0,0,120,27,0,0,136,18,0,0,206,10,0,0,80,4,0,0,236,6,0,0,96,3,0,0,26,56,0,0,0,0,0,0,0,8,0,0,224,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,128,170,5,0,112,18,4,0,0,0,0,0,0,0,0,0,96,135,2,0,144,134,5,0,0,0,0,0,224,189,4,0,168,155,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,149,0,0,0,2,0,0,0,0,0,0,10,2,0,0,0,128,0,0,0,0,0,0,0,22,39,0,0,64,9,0,0,0,0,0,0,0,0,0,0,120,27,0,0,24,3,0,0,206,10,0,0,80,4,0,0,236,6,0,0,96,3,0,0,26,56,0,0,0,0,0,0,0,8,0,0,224,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,112,18,4,0,0,0,0,0,0,0,0,0,0,0,0,0,96,135,2,0,96,56,6,0,0,0,0,0,224,189,4,0,168,155,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,133,0,0,0,2,0,0,0,0,0,0,10,2,0,0,0,128,0,0,0,0,0,0,0,40,25,0,0,198,14,0,0,0,0,0,0,0,0,0,0,120,27,0,0,136,18,0,0,102,8,0,0,80,4,0,0,154,3,0,0,4,15,0,0,26,56,0,0,0,0,0,0,0,8,0,0,224,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,72,111,3,0,0,0,0,0,0,0,0,0,0,0,0,0,64,164,6,0,8,109,3,0,88,1,5,0,48,244,4,0,72,81,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,8,0,0,2,0,0,0,0,0,0,16,1,0,0,0,0,0,0,0,0,0,0,0,248,37,0,0,234,18,0,0,0,0,0,0,0,0,0,0,32,26,0,0,50,52,0,0,116,5,0,0,74,18,0,0,174,10,0,0,0,0,0,0,104,34,0,0,0,0,0,0,136,1,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,232,180,1,0,56,179,1,0,0,0,0,0,0,0,0,0,184,168,7,0,56,84,1,0,0,0,0,0,176,237,2,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,19,1,0,0,0,0,0,0,0,0,0,0,0,56,47,0,0,248,5,0,0,0,0,0,0,0,0,0,0,106,13,0,0,128,27,0,0,26,6,0,0,90,1,0,0,100,8,0,0,66,9,0,0,198,15,0,0,16,173,145,0,0,3,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,160,158,2,0,56,179,1,0,0,0,0,0,0,0,0,0,184,168,7,0,72,29,2,0,0,0,0,0,176,237,2,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,0,0,0,19,1,0,0,0,0,0,0,0,0,0,0,0,170,48,0,0,182,24,0,0,0,0,0,0,0,0,0,0,106,13,0,0,128,27,0,0,26,6,0,0,90,1,0,0,100,8,0,0,66,9,0,0,198,15,0,0,16,173,145,0,0,3,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,56,179,1,0,0,0,0,0,0,0,0,0,0,0,0,0,184,168,7,0,200,153,5,0,0,0,0,0,176,237,2,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,19,1,0,0,0,0,0,0,0,0,0,0,0,48,10,0,0,236,34,0,0,0,0,0,0,0,0,0,0,106,13,0,0,128,27,0,0,26,6,0,0,90,1,0,0,100,8,0,0,66,9,0,0,198,15,0,0,16,173,145,0,0,3,0,0,0,1,0,0,240,0,0,0,4,0,0,0,3,0,0,0,64,134,8,0,0,0,0,0,0,0,0,0,0,0,0,0,144,47,2,0,176,128,8,0,0,0,0,0,168,123,8,0,80,164,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,0,10,2,0,0,0,0,0,0,0,0,0,0,0,24,27,0,0,158,7,0,0,0,0,0,0,0,0,0,0,98,44,0,0,254,28,0,0,220,4,0,0,56,12,0,0,212,3,0,0,210,14,0,0,0,0,0,0,0,0,0,0,0,3,0,0,224,0,0,0,0,1,0,0,3,0,0,0,4,0,0,0,168,85,3,0,48,48,3,0,0,0,0,0,0,0,0,0,160,234,7,0,136,185,4,0,0,0,0,0,40,161,4,0,248,206,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,2,0,0,0,64,0,3,2,0,64,0,0,0,0,0,0,0,0,0,0,54,30,0,0,72,41,0,0,0,0,0,0,0,0,0,0,66,46,0,0,14,34,0,0,220,17,0,0,82,17,0,0,144,2,0,0,0,0,0,0,232,6,0,0,0,0,0,0,0,24,0,0,224,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,48,48,3,0,0,0,0,0])
.concat([0,0,0,0,0,0,0,0,104,174,7,0,72,17,6,0,0,0,0,0,40,161,4,0,80,150,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,2,0,0,0,68,0,4,2,0,64,0,0,0,0,0,0,0,0,0,0,84,25,0,0,66,37,0,0,0,0,0,0,0,0,0,0,180,12,0,0,0,0,0,0,218,12,0,0,114,17,0,0,134,11,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,224,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,64,207,1,0,0,0,0,0,0,0,0,0,0,0,0,0,200,190,7,0,88,31,1,0,0,0,0,0,40,161,4,0,240,153,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,128,0,1,2,0,0,8,0,0,0,0,0,0,0,0,0,164,38,0,0,98,3,0,0,0,0,0,0,0,0,0,0,52,24,0,0,142,48,0,0,172,6,0,0,114,5,0,0,164,8,0,0,0,0,0,0,6,14,0,0,0,0,0,0,0,96,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,176,220,8,0,64,207,1,0,0,0,0,0,0,0,0,0,200,190,7,0,64,154,8,0,0,0,0,0,40,161,4,0,240,153,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,128,0,1,2,0,0,8,0,0,0,0,0,0,0,0,0,52,41,0,0,138,6,0,0,0,0,0,0,0,0,0,0,52,24,0,0,214,3,0,0,172,6,0,0,114,5,0,0,164,8,0,0,0,0,0,0,6,14,0,0,0,0,0,0,0,96,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,16,206,2,0,24,73,3,0,0,0,0,0,0,0,0,0,104,221,5,0,216,66,2,0,0,0,0,0,40,161,4,0,240,153,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,2,0,0,0,192,0,1,2,0,0,4,0,0,0,0,0,0,0,0,0,198,30,0,0,122,4,0,0,0,0,0,0,0,0,0,0,86,44,0,0,42,26,0,0,110,16,0,0,114,5,0,0,164,8,0,0,0,0,0,0,6,14,0,0,0,0,0,0,0,96,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,24,73,3,0,0,0,0,0,0,0,0,0,0,0,0,0,104,221,5,0,248,22,6,0,0,0,0,0,40,161,4,0,240,153,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,192,0,1,2,0,0,4,0,0,0,0,0,0,0,0,0,96,13,0,0,20,0,0,0,0,0,0,0,0,0,0,0,86,44,0,0,42,26,0,0,110,16,0,0,114,5,0,0,164,8,0,0,0,0,0,0,6,14,0,0,0,0,0,0,0,96,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,120,67,2,0,0,0,0,0,0,0,0,0,0,0,0,0,160,234,7,0,168,207,1,0,0,0,0,0,40,161,4,0,248,206,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,1,0,3,2,0,0,4,0,0,0,0,0,0,0,0,0,234,11,0,0,4,32,0,0,0,0,0,0,0,0,0,0,50,61,0,0,158,5,0,0,218,12,0,0,114,17,0,0,144,2,0,0,0,0,0,0,114,44,0,0,0,0,0,0,0,24,0,0,224,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,96,195,3,0,224,205,4,0,0,0,0,0,0,0,0,0,64,171,7,0,80,169,3,0,0,0,0,0,136,252,4,0,136,252,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,168,25,0,0,10,11,0,0,0,0,0,0,0,0,0,0,172,22,0,0,174,3,0,0,124,2,0,0,64,13,0,0,168,2,0,0,0,0,0,0,134,1,0,0,0,0,0,0,0,1,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,112,3,4,0,224,205,4,0,0,0,0,0,0,0,0,0,64,171,7,0,192,225,3,0,0,0,0,0,0,32,4,0,136,252,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,218,23,0,0,54,2,0,0,0,0,0,0,0,0,0,0,172,22,0,0,174,3,0,0,124,2,0,0,64,13,0,0,168,2,0,0,0,0,0,0,134,1,0,0,0,0,0,0,0,1,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,176,86,4,0,224,205,4,0,0,0,0,0,0,0,0,0,64,171,7,0,80,60,4,0,0,0,0,0,0,32,4,0,136,252,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,2,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,184,18,0,0,30,45,0,0,0,0,0,0,0,0,0,0,172,22,0,0,174,3,0,0,124,2,0,0,64,13,0,0,168,2,0,0,0,0,0,0,134,1,0,0,0,0,0,0,0,1,0,0,224,0,0,0,32,1,0,0,3,0,0,0,4,0,0,0,176,1,2,0,0,0,0,0,72,172,6,0,0,0,0,0,184,0,2,0,224,253,1,0,88,251,1,0,128,145,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,4,0,0,4,0,0,0,0,48,1,5,0,0,1,0,0,0,0,0,0,0,0,0,40,38,0,0,10,6,0,0,0,0,0,0,0,0,0,0,98,36,0,0,178,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,48,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,88,69,2,0,0,0,0,0,72,172,6,0,0,0,0,0,240,3,2,0,152,185,8,0,0,0,0,0,128,145,4,0,208,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,4,0,1,133,8,0,0,0,0,0,0,0,0,0,0,0,236,47,0,0,242,34,0,0,0,0,0,0,0,0,0,0,208,59,0,0,246,38,0,0,120,7,0,0,176,6,0,0,78,14,0,0,236,13,0,0,78,53,0,0,208,32,216,0,0,16,0,0,64,1,0,0,224,0,0,0,4,0,0,0,3,0,0,0,64,247,3,0,0,0,0,0,0,0,0,0,0,0,0,0,184,230,7,0,104,53,6,0,0,0,0,0,104,210,4,0,240,185,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,2,0,0,0,0,0,0,10,2,0,0,0,0,0,0,0,0,0,0,0,116,21,0,0,86,4,0,0,0,0,0,0,0,0,0,0,24,46,0,0,216,59,0,0,160,14,0,0,148,13,0,0,196,8,0,0,144,4,0,0,184,33,0,0,248,210,148,0,0,2,0,0,224,0,0,0,64,1,0,0,3,0,0,0,4,0,0,0,200,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
, "i8", ALLOC_NONE, Runtime.GLOBAL_BASE)
var tempDoublePtr = Runtime.alignMemory(allocate(12, "i8", ALLOC_STATIC), 8);
assert(tempDoublePtr % 8 == 0);
function copyTempFloat(ptr) { // functions, because inlining this code increases code size too much
  HEAP8[tempDoublePtr] = HEAP8[ptr];
  HEAP8[tempDoublePtr+1] = HEAP8[ptr+1];
  HEAP8[tempDoublePtr+2] = HEAP8[ptr+2];
  HEAP8[tempDoublePtr+3] = HEAP8[ptr+3];
}
function copyTempDouble(ptr) {
  HEAP8[tempDoublePtr] = HEAP8[ptr];
  HEAP8[tempDoublePtr+1] = HEAP8[ptr+1];
  HEAP8[tempDoublePtr+2] = HEAP8[ptr+2];
  HEAP8[tempDoublePtr+3] = HEAP8[ptr+3];
  HEAP8[tempDoublePtr+4] = HEAP8[ptr+4];
  HEAP8[tempDoublePtr+5] = HEAP8[ptr+5];
  HEAP8[tempDoublePtr+6] = HEAP8[ptr+6];
  HEAP8[tempDoublePtr+7] = HEAP8[ptr+7];
}
  function _emscripten_set_canvas_size(width, height) {
      Browser.setCanvasSize(width, height);
    }
  function _emscripten_set_main_loop(func, fps, simulateInfiniteLoop) {
      Module['noExitRuntime'] = true;
      Browser.mainLoop.runner = function Browser_mainLoop_runner() {
        if (ABORT) return;
        if (Browser.mainLoop.queue.length > 0) {
          var start = Date.now();
          var blocker = Browser.mainLoop.queue.shift();
          blocker.func(blocker.arg);
          if (Browser.mainLoop.remainingBlockers) {
            var remaining = Browser.mainLoop.remainingBlockers;
            var next = remaining%1 == 0 ? remaining-1 : Math.floor(remaining);
            if (blocker.counted) {
              Browser.mainLoop.remainingBlockers = next;
            } else {
              // not counted, but move the progress along a tiny bit
              next = next + 0.5; // do not steal all the next one's progress
              Browser.mainLoop.remainingBlockers = (8*remaining + next)/9;
            }
          }
          console.log('main loop blocker "' + blocker.name + '" took ' + (Date.now() - start) + ' ms'); //, left: ' + Browser.mainLoop.remainingBlockers);
          Browser.mainLoop.updateStatus();
          setTimeout(Browser.mainLoop.runner, 0);
          return;
        }
        if (Browser.mainLoop.shouldPause) {
          // catch pauses from non-main loop sources
          Browser.mainLoop.paused = true;
          Browser.mainLoop.shouldPause = false;
          return;
        }
        if (Module['preMainLoop']) {
          Module['preMainLoop']();
        }
        try {
          Runtime.dynCall('v', func);
        } catch (e) {
          if (e instanceof ExitStatus) {
            return;
          } else {
            if (e && typeof e === 'object' && e.stack) Module.printErr('exception thrown: ' + [e, e.stack]);
            throw e;
          }
        }
        if (Module['postMainLoop']) {
          Module['postMainLoop']();
        }
        if (Browser.mainLoop.shouldPause) {
          // catch pauses from the main loop itself
          Browser.mainLoop.paused = true;
          Browser.mainLoop.shouldPause = false;
          return;
        }
        Browser.mainLoop.scheduler();
      }
      if (fps && fps > 0) {
        Browser.mainLoop.scheduler = function Browser_mainLoop_scheduler() {
          setTimeout(Browser.mainLoop.runner, 1000/fps); // doing this each time means that on exception, we stop
        }
      } else {
        Browser.mainLoop.scheduler = function Browser_mainLoop_scheduler() {
          Browser.requestAnimationFrame(Browser.mainLoop.runner);
        }
      }
      Browser.mainLoop.scheduler();
      if (simulateInfiniteLoop) {
        throw 'SimulateInfiniteLoop';
      }
    }
  var ERRNO_CODES={EPERM:1,ENOENT:2,ESRCH:3,EINTR:4,EIO:5,ENXIO:6,E2BIG:7,ENOEXEC:8,EBADF:9,ECHILD:10,EAGAIN:11,EWOULDBLOCK:11,ENOMEM:12,EACCES:13,EFAULT:14,ENOTBLK:15,EBUSY:16,EEXIST:17,EXDEV:18,ENODEV:19,ENOTDIR:20,EISDIR:21,EINVAL:22,ENFILE:23,EMFILE:24,ENOTTY:25,ETXTBSY:26,EFBIG:27,ENOSPC:28,ESPIPE:29,EROFS:30,EMLINK:31,EPIPE:32,EDOM:33,ERANGE:34,ENOMSG:42,EIDRM:43,ECHRNG:44,EL2NSYNC:45,EL3HLT:46,EL3RST:47,ELNRNG:48,EUNATCH:49,ENOCSI:50,EL2HLT:51,EDEADLK:35,ENOLCK:37,EBADE:52,EBADR:53,EXFULL:54,ENOANO:55,EBADRQC:56,EBADSLT:57,EDEADLOCK:35,EBFONT:59,ENOSTR:60,ENODATA:61,ETIME:62,ENOSR:63,ENONET:64,ENOPKG:65,EREMOTE:66,ENOLINK:67,EADV:68,ESRMNT:69,ECOMM:70,EPROTO:71,EMULTIHOP:72,EDOTDOT:73,EBADMSG:74,ENOTUNIQ:76,EBADFD:77,EREMCHG:78,ELIBACC:79,ELIBBAD:80,ELIBSCN:81,ELIBMAX:82,ELIBEXEC:83,ENOSYS:38,ENOTEMPTY:39,ENAMETOOLONG:36,ELOOP:40,EOPNOTSUPP:95,EPFNOSUPPORT:96,ECONNRESET:104,ENOBUFS:105,EAFNOSUPPORT:97,EPROTOTYPE:91,ENOTSOCK:88,ENOPROTOOPT:92,ESHUTDOWN:108,ECONNREFUSED:111,EADDRINUSE:98,ECONNABORTED:103,ENETUNREACH:101,ENETDOWN:100,ETIMEDOUT:110,EHOSTDOWN:112,EHOSTUNREACH:113,EINPROGRESS:115,EALREADY:114,EDESTADDRREQ:89,EMSGSIZE:90,EPROTONOSUPPORT:93,ESOCKTNOSUPPORT:94,EADDRNOTAVAIL:99,ENETRESET:102,EISCONN:106,ENOTCONN:107,ETOOMANYREFS:109,EUSERS:87,EDQUOT:122,ESTALE:116,ENOTSUP:95,ENOMEDIUM:123,EILSEQ:84,EOVERFLOW:75,ECANCELED:125,ENOTRECOVERABLE:131,EOWNERDEAD:130,ESTRPIPE:86};
  var ERRNO_MESSAGES={0:"Success",1:"Not super-user",2:"No such file or directory",3:"No such process",4:"Interrupted system call",5:"I/O error",6:"No such device or address",7:"Arg list too long",8:"Exec format error",9:"Bad file number",10:"No children",11:"No more processes",12:"Not enough core",13:"Permission denied",14:"Bad address",15:"Block device required",16:"Mount device busy",17:"File exists",18:"Cross-device link",19:"No such device",20:"Not a directory",21:"Is a directory",22:"Invalid argument",23:"Too many open files in system",24:"Too many open files",25:"Not a typewriter",26:"Text file busy",27:"File too large",28:"No space left on device",29:"Illegal seek",30:"Read only file system",31:"Too many links",32:"Broken pipe",33:"Math arg out of domain of func",34:"Math result not representable",35:"File locking deadlock error",36:"File or path name too long",37:"No record locks available",38:"Function not implemented",39:"Directory not empty",40:"Too many symbolic links",42:"No message of desired type",43:"Identifier removed",44:"Channel number out of range",45:"Level 2 not synchronized",46:"Level 3 halted",47:"Level 3 reset",48:"Link number out of range",49:"Protocol driver not attached",50:"No CSI structure available",51:"Level 2 halted",52:"Invalid exchange",53:"Invalid request descriptor",54:"Exchange full",55:"No anode",56:"Invalid request code",57:"Invalid slot",59:"Bad font file fmt",60:"Device not a stream",61:"No data (for no delay io)",62:"Timer expired",63:"Out of streams resources",64:"Machine is not on the network",65:"Package not installed",66:"The object is remote",67:"The link has been severed",68:"Advertise error",69:"Srmount error",70:"Communication error on send",71:"Protocol error",72:"Multihop attempted",73:"Cross mount point (not really error)",74:"Trying to read unreadable message",75:"Value too large for defined data type",76:"Given log. name not unique",77:"f.d. invalid for this operation",78:"Remote address changed",79:"Can   access a needed shared lib",80:"Accessing a corrupted shared lib",81:".lib section in a.out corrupted",82:"Attempting to link in too many libs",83:"Attempting to exec a shared library",84:"Illegal byte sequence",86:"Streams pipe error",87:"Too many users",88:"Socket operation on non-socket",89:"Destination address required",90:"Message too long",91:"Protocol wrong type for socket",92:"Protocol not available",93:"Unknown protocol",94:"Socket type not supported",95:"Not supported",96:"Protocol family not supported",97:"Address family not supported by protocol family",98:"Address already in use",99:"Address not available",100:"Network interface is not configured",101:"Network is unreachable",102:"Connection reset by network",103:"Connection aborted",104:"Connection reset by peer",105:"No buffer space available",106:"Socket is already connected",107:"Socket is not connected",108:"Can't send after socket shutdown",109:"Too many references",110:"Connection timed out",111:"Connection refused",112:"Host is down",113:"Host is unreachable",114:"Socket already connected",115:"Connection already in progress",116:"Stale file handle",122:"Quota exceeded",123:"No medium (in tape drive)",125:"Operation canceled",130:"Previous owner died",131:"State not recoverable"};
  var ___errno_state=0;function ___setErrNo(value) {
      // For convenient setting and returning of errno.
      HEAP32[((___errno_state)>>2)]=value
      return value;
    }
  var PATH={splitPath:function (filename) {
        var splitPathRe = /^(\/?|)([\s\S]*?)((?:\.{1,2}|[^\/]+?|)(\.[^.\/]*|))(?:[\/]*)$/;
        return splitPathRe.exec(filename).slice(1);
      },normalizeArray:function (parts, allowAboveRoot) {
        // if the path tries to go above the root, `up` ends up > 0
        var up = 0;
        for (var i = parts.length - 1; i >= 0; i--) {
          var last = parts[i];
          if (last === '.') {
            parts.splice(i, 1);
          } else if (last === '..') {
            parts.splice(i, 1);
            up++;
          } else if (up) {
            parts.splice(i, 1);
            up--;
          }
        }
        // if the path is allowed to go above the root, restore leading ..s
        if (allowAboveRoot) {
          for (; up--; up) {
            parts.unshift('..');
          }
        }
        return parts;
      },normalize:function (path) {
        var isAbsolute = path.charAt(0) === '/',
            trailingSlash = path.substr(-1) === '/';
        // Normalize the path
        path = PATH.normalizeArray(path.split('/').filter(function(p) {
          return !!p;
        }), !isAbsolute).join('/');
        if (!path && !isAbsolute) {
          path = '.';
        }
        if (path && trailingSlash) {
          path += '/';
        }
        return (isAbsolute ? '/' : '') + path;
      },dirname:function (path) {
        var result = PATH.splitPath(path),
            root = result[0],
            dir = result[1];
        if (!root && !dir) {
          // No dirname whatsoever
          return '.';
        }
        if (dir) {
          // It has a dirname, strip trailing slash
          dir = dir.substr(0, dir.length - 1);
        }
        return root + dir;
      },basename:function (path) {
        // EMSCRIPTEN return '/'' for '/', not an empty string
        if (path === '/') return '/';
        var lastSlash = path.lastIndexOf('/');
        if (lastSlash === -1) return path;
        return path.substr(lastSlash+1);
      },extname:function (path) {
        return PATH.splitPath(path)[3];
      },join:function () {
        var paths = Array.prototype.slice.call(arguments, 0);
        return PATH.normalize(paths.join('/'));
      },join2:function (l, r) {
        return PATH.normalize(l + '/' + r);
      },resolve:function () {
        var resolvedPath = '',
          resolvedAbsolute = false;
        for (var i = arguments.length - 1; i >= -1 && !resolvedAbsolute; i--) {
          var path = (i >= 0) ? arguments[i] : FS.cwd();
          // Skip empty and invalid entries
          if (typeof path !== 'string') {
            throw new TypeError('Arguments to path.resolve must be strings');
          } else if (!path) {
            continue;
          }
          resolvedPath = path + '/' + resolvedPath;
          resolvedAbsolute = path.charAt(0) === '/';
        }
        // At this point the path should be resolved to a full absolute path, but
        // handle relative paths to be safe (might happen when process.cwd() fails)
        resolvedPath = PATH.normalizeArray(resolvedPath.split('/').filter(function(p) {
          return !!p;
        }), !resolvedAbsolute).join('/');
        return ((resolvedAbsolute ? '/' : '') + resolvedPath) || '.';
      },relative:function (from, to) {
        from = PATH.resolve(from).substr(1);
        to = PATH.resolve(to).substr(1);
        function trim(arr) {
          var start = 0;
          for (; start < arr.length; start++) {
            if (arr[start] !== '') break;
          }
          var end = arr.length - 1;
          for (; end >= 0; end--) {
            if (arr[end] !== '') break;
          }
          if (start > end) return [];
          return arr.slice(start, end - start + 1);
        }
        var fromParts = trim(from.split('/'));
        var toParts = trim(to.split('/'));
        var length = Math.min(fromParts.length, toParts.length);
        var samePartsLength = length;
        for (var i = 0; i < length; i++) {
          if (fromParts[i] !== toParts[i]) {
            samePartsLength = i;
            break;
          }
        }
        var outputParts = [];
        for (var i = samePartsLength; i < fromParts.length; i++) {
          outputParts.push('..');
        }
        outputParts = outputParts.concat(toParts.slice(samePartsLength));
        return outputParts.join('/');
      }};
  var TTY={ttys:[],init:function () {
        // https://github.com/kripken/emscripten/pull/1555
        // if (ENVIRONMENT_IS_NODE) {
        //   // currently, FS.init does not distinguish if process.stdin is a file or TTY
        //   // device, it always assumes it's a TTY device. because of this, we're forcing
        //   // process.stdin to UTF8 encoding to at least make stdin reading compatible
        //   // with text files until FS.init can be refactored.
        //   process['stdin']['setEncoding']('utf8');
        // }
      },shutdown:function () {
        // https://github.com/kripken/emscripten/pull/1555
        // if (ENVIRONMENT_IS_NODE) {
        //   // inolen: any idea as to why node -e 'process.stdin.read()' wouldn't exit immediately (with process.stdin being a tty)?
        //   // isaacs: because now it's reading from the stream, you've expressed interest in it, so that read() kicks off a _read() which creates a ReadReq operation
        //   // inolen: I thought read() in that case was a synchronous operation that just grabbed some amount of buffered data if it exists?
        //   // isaacs: it is. but it also triggers a _read() call, which calls readStart() on the handle
        //   // isaacs: do process.stdin.pause() and i'd think it'd probably close the pending call
        //   process['stdin']['pause']();
        // }
      },register:function (dev, ops) {
        TTY.ttys[dev] = { input: [], output: [], ops: ops };
        FS.registerDevice(dev, TTY.stream_ops);
      },stream_ops:{open:function (stream) {
          var tty = TTY.ttys[stream.node.rdev];
          if (!tty) {
            throw new FS.ErrnoError(ERRNO_CODES.ENODEV);
          }
          stream.tty = tty;
          stream.seekable = false;
        },close:function (stream) {
          // flush any pending line data
          if (stream.tty.output.length) {
            stream.tty.ops.put_char(stream.tty, 10);
          }
        },read:function (stream, buffer, offset, length, pos /* ignored */) {
          if (!stream.tty || !stream.tty.ops.get_char) {
            throw new FS.ErrnoError(ERRNO_CODES.ENXIO);
          }
          var bytesRead = 0;
          for (var i = 0; i < length; i++) {
            var result;
            try {
              result = stream.tty.ops.get_char(stream.tty);
            } catch (e) {
              throw new FS.ErrnoError(ERRNO_CODES.EIO);
            }
            if (result === undefined && bytesRead === 0) {
              throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
            }
            if (result === null || result === undefined) break;
            bytesRead++;
            buffer[offset+i] = result;
          }
          if (bytesRead) {
            stream.node.timestamp = Date.now();
          }
          return bytesRead;
        },write:function (stream, buffer, offset, length, pos) {
          if (!stream.tty || !stream.tty.ops.put_char) {
            throw new FS.ErrnoError(ERRNO_CODES.ENXIO);
          }
          for (var i = 0; i < length; i++) {
            try {
              stream.tty.ops.put_char(stream.tty, buffer[offset+i]);
            } catch (e) {
              throw new FS.ErrnoError(ERRNO_CODES.EIO);
            }
          }
          if (length) {
            stream.node.timestamp = Date.now();
          }
          return i;
        }},default_tty_ops:{get_char:function (tty) {
          if (!tty.input.length) {
            var result = null;
            if (ENVIRONMENT_IS_NODE) {
              result = process['stdin']['read']();
              if (!result) {
                if (process['stdin']['_readableState'] && process['stdin']['_readableState']['ended']) {
                  return null;  // EOF
                }
                return undefined;  // no data available
              }
            } else if (typeof window != 'undefined' &&
              typeof window.prompt == 'function') {
              // Browser.
              result = window.prompt('Input: ');  // returns null on cancel
              if (result !== null) {
                result += '\n';
              }
            } else if (typeof readline == 'function') {
              // Command line.
              result = readline();
              if (result !== null) {
                result += '\n';
              }
            }
            if (!result) {
              return null;
            }
            tty.input = intArrayFromString(result, true);
          }
          return tty.input.shift();
        },put_char:function (tty, val) {
          if (val === null || val === 10) {
            Module['print'](tty.output.join(''));
            tty.output = [];
          } else {
            tty.output.push(TTY.utf8.processCChar(val));
          }
        }},default_tty1_ops:{put_char:function (tty, val) {
          if (val === null || val === 10) {
            Module['printErr'](tty.output.join(''));
            tty.output = [];
          } else {
            tty.output.push(TTY.utf8.processCChar(val));
          }
        }}};
  var MEMFS={ops_table:null,CONTENT_OWNING:1,CONTENT_FLEXIBLE:2,CONTENT_FIXED:3,mount:function (mount) {
        return MEMFS.createNode(null, '/', 16384 | 0777, 0);
      },createNode:function (parent, name, mode, dev) {
        if (FS.isBlkdev(mode) || FS.isFIFO(mode)) {
          // no supported
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (!MEMFS.ops_table) {
          MEMFS.ops_table = {
            dir: {
              node: {
                getattr: MEMFS.node_ops.getattr,
                setattr: MEMFS.node_ops.setattr,
                lookup: MEMFS.node_ops.lookup,
                mknod: MEMFS.node_ops.mknod,
                mknod: MEMFS.node_ops.mknod,
                rename: MEMFS.node_ops.rename,
                unlink: MEMFS.node_ops.unlink,
                rmdir: MEMFS.node_ops.rmdir,
                readdir: MEMFS.node_ops.readdir,
                symlink: MEMFS.node_ops.symlink
              },
              stream: {
                llseek: MEMFS.stream_ops.llseek
              }
            },
            file: {
              node: {
                getattr: MEMFS.node_ops.getattr,
                setattr: MEMFS.node_ops.setattr
              },
              stream: {
                llseek: MEMFS.stream_ops.llseek,
                read: MEMFS.stream_ops.read,
                write: MEMFS.stream_ops.write,
                allocate: MEMFS.stream_ops.allocate,
                mmap: MEMFS.stream_ops.mmap
              }
            },
            link: {
              node: {
                getattr: MEMFS.node_ops.getattr,
                setattr: MEMFS.node_ops.setattr,
                readlink: MEMFS.node_ops.readlink
              },
              stream: {}
            },
            chrdev: {
              node: {
                getattr: MEMFS.node_ops.getattr,
                setattr: MEMFS.node_ops.setattr
              },
              stream: FS.chrdev_stream_ops
            },
          };
        }
        var node = FS.createNode(parent, name, mode, dev);
        if (FS.isDir(node.mode)) {
          node.node_ops = MEMFS.ops_table.dir.node;
          node.stream_ops = MEMFS.ops_table.dir.stream;
          node.contents = {};
        } else if (FS.isFile(node.mode)) {
          node.node_ops = MEMFS.ops_table.file.node;
          node.stream_ops = MEMFS.ops_table.file.stream;
          node.contents = [];
          node.contentMode = MEMFS.CONTENT_FLEXIBLE;
        } else if (FS.isLink(node.mode)) {
          node.node_ops = MEMFS.ops_table.link.node;
          node.stream_ops = MEMFS.ops_table.link.stream;
        } else if (FS.isChrdev(node.mode)) {
          node.node_ops = MEMFS.ops_table.chrdev.node;
          node.stream_ops = MEMFS.ops_table.chrdev.stream;
        }
        node.timestamp = Date.now();
        // add the new node to the parent
        if (parent) {
          parent.contents[name] = node;
        }
        return node;
      },ensureFlexible:function (node) {
        if (node.contentMode !== MEMFS.CONTENT_FLEXIBLE) {
          var contents = node.contents;
          node.contents = Array.prototype.slice.call(contents);
          node.contentMode = MEMFS.CONTENT_FLEXIBLE;
        }
      },node_ops:{getattr:function (node) {
          var attr = {};
          // device numbers reuse inode numbers.
          attr.dev = FS.isChrdev(node.mode) ? node.id : 1;
          attr.ino = node.id;
          attr.mode = node.mode;
          attr.nlink = 1;
          attr.uid = 0;
          attr.gid = 0;
          attr.rdev = node.rdev;
          if (FS.isDir(node.mode)) {
            attr.size = 4096;
          } else if (FS.isFile(node.mode)) {
            attr.size = node.contents.length;
          } else if (FS.isLink(node.mode)) {
            attr.size = node.link.length;
          } else {
            attr.size = 0;
          }
          attr.atime = new Date(node.timestamp);
          attr.mtime = new Date(node.timestamp);
          attr.ctime = new Date(node.timestamp);
          // NOTE: In our implementation, st_blocks = Math.ceil(st_size/st_blksize),
          //       but this is not required by the standard.
          attr.blksize = 4096;
          attr.blocks = Math.ceil(attr.size / attr.blksize);
          return attr;
        },setattr:function (node, attr) {
          if (attr.mode !== undefined) {
            node.mode = attr.mode;
          }
          if (attr.timestamp !== undefined) {
            node.timestamp = attr.timestamp;
          }
          if (attr.size !== undefined) {
            MEMFS.ensureFlexible(node);
            var contents = node.contents;
            if (attr.size < contents.length) contents.length = attr.size;
            else while (attr.size > contents.length) contents.push(0);
          }
        },lookup:function (parent, name) {
          throw FS.genericErrors[ERRNO_CODES.ENOENT];
        },mknod:function (parent, name, mode, dev) {
          return MEMFS.createNode(parent, name, mode, dev);
        },rename:function (old_node, new_dir, new_name) {
          // if we're overwriting a directory at new_name, make sure it's empty.
          if (FS.isDir(old_node.mode)) {
            var new_node;
            try {
              new_node = FS.lookupNode(new_dir, new_name);
            } catch (e) {
            }
            if (new_node) {
              for (var i in new_node.contents) {
                throw new FS.ErrnoError(ERRNO_CODES.ENOTEMPTY);
              }
            }
          }
          // do the internal rewiring
          delete old_node.parent.contents[old_node.name];
          old_node.name = new_name;
          new_dir.contents[new_name] = old_node;
          old_node.parent = new_dir;
        },unlink:function (parent, name) {
          delete parent.contents[name];
        },rmdir:function (parent, name) {
          var node = FS.lookupNode(parent, name);
          for (var i in node.contents) {
            throw new FS.ErrnoError(ERRNO_CODES.ENOTEMPTY);
          }
          delete parent.contents[name];
        },readdir:function (node) {
          var entries = ['.', '..']
          for (var key in node.contents) {
            if (!node.contents.hasOwnProperty(key)) {
              continue;
            }
            entries.push(key);
          }
          return entries;
        },symlink:function (parent, newname, oldpath) {
          var node = MEMFS.createNode(parent, newname, 0777 | 40960, 0);
          node.link = oldpath;
          return node;
        },readlink:function (node) {
          if (!FS.isLink(node.mode)) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
          return node.link;
        }},stream_ops:{read:function (stream, buffer, offset, length, position) {
          var contents = stream.node.contents;
          if (position >= contents.length)
            return 0;
          var size = Math.min(contents.length - position, length);
          assert(size >= 0);
          if (size > 8 && contents.subarray) { // non-trivial, and typed array
            buffer.set(contents.subarray(position, position + size), offset);
          } else
          {
            for (var i = 0; i < size; i++) {
              buffer[offset + i] = contents[position + i];
            }
          }
          return size;
        },write:function (stream, buffer, offset, length, position, canOwn) {
          var node = stream.node;
          node.timestamp = Date.now();
          var contents = node.contents;
          if (length && contents.length === 0 && position === 0 && buffer.subarray) {
            // just replace it with the new data
            if (canOwn && offset === 0) {
              node.contents = buffer; // this could be a subarray of Emscripten HEAP, or allocated from some other source.
              node.contentMode = (buffer.buffer === HEAP8.buffer) ? MEMFS.CONTENT_OWNING : MEMFS.CONTENT_FIXED;
            } else {
              node.contents = new Uint8Array(buffer.subarray(offset, offset+length));
              node.contentMode = MEMFS.CONTENT_FIXED;
            }
            return length;
          }
          MEMFS.ensureFlexible(node);
          var contents = node.contents;
          while (contents.length < position) contents.push(0);
          for (var i = 0; i < length; i++) {
            contents[position + i] = buffer[offset + i];
          }
          return length;
        },llseek:function (stream, offset, whence) {
          var position = offset;
          if (whence === 1) {  // SEEK_CUR.
            position += stream.position;
          } else if (whence === 2) {  // SEEK_END.
            if (FS.isFile(stream.node.mode)) {
              position += stream.node.contents.length;
            }
          }
          if (position < 0) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
          stream.ungotten = [];
          stream.position = position;
          return position;
        },allocate:function (stream, offset, length) {
          MEMFS.ensureFlexible(stream.node);
          var contents = stream.node.contents;
          var limit = offset + length;
          while (limit > contents.length) contents.push(0);
        },mmap:function (stream, buffer, offset, length, position, prot, flags) {
          if (!FS.isFile(stream.node.mode)) {
            throw new FS.ErrnoError(ERRNO_CODES.ENODEV);
          }
          var ptr;
          var allocated;
          var contents = stream.node.contents;
          // Only make a new copy when MAP_PRIVATE is specified.
          if ( !(flags & 2) &&
                (contents.buffer === buffer || contents.buffer === buffer.buffer) ) {
            // We can't emulate MAP_SHARED when the file is not backed by the buffer
            // we're mapping to (e.g. the HEAP buffer).
            allocated = false;
            ptr = contents.byteOffset;
          } else {
            // Try to avoid unnecessary slices.
            if (position > 0 || position + length < contents.length) {
              if (contents.subarray) {
                contents = contents.subarray(position, position + length);
              } else {
                contents = Array.prototype.slice.call(contents, position, position + length);
              }
            }
            allocated = true;
            ptr = _malloc(length);
            if (!ptr) {
              throw new FS.ErrnoError(ERRNO_CODES.ENOMEM);
            }
            buffer.set(contents, ptr);
          }
          return { ptr: ptr, allocated: allocated };
        }}};
  var IDBFS={dbs:{},indexedDB:function () {
        return window.indexedDB || window.mozIndexedDB || window.webkitIndexedDB || window.msIndexedDB;
      },DB_VERSION:20,DB_STORE_NAME:"FILE_DATA",mount:function (mount) {
        return MEMFS.mount.apply(null, arguments);
      },syncfs:function (mount, populate, callback) {
        IDBFS.getLocalSet(mount, function(err, local) {
          if (err) return callback(err);
          IDBFS.getRemoteSet(mount, function(err, remote) {
            if (err) return callback(err);
            var src = populate ? remote : local;
            var dst = populate ? local : remote;
            IDBFS.reconcile(src, dst, callback);
          });
        });
      },reconcile:function (src, dst, callback) {
        var total = 0;
        var create = {};
        for (var key in src.files) {
          if (!src.files.hasOwnProperty(key)) continue;
          var e = src.files[key];
          var e2 = dst.files[key];
          if (!e2 || e.timestamp > e2.timestamp) {
            create[key] = e;
            total++;
          }
        }
        var remove = {};
        for (var key in dst.files) {
          if (!dst.files.hasOwnProperty(key)) continue;
          var e = dst.files[key];
          var e2 = src.files[key];
          if (!e2) {
            remove[key] = e;
            total++;
          }
        }
        if (!total) {
          // early out
          return callback(null);
        }
        var completed = 0;
        function done(err) {
          if (err) return callback(err);
          if (++completed >= total) {
            return callback(null);
          }
        };
        // create a single transaction to handle and IDB reads / writes we'll need to do
        var db = src.type === 'remote' ? src.db : dst.db;
        var transaction = db.transaction([IDBFS.DB_STORE_NAME], 'readwrite');
        transaction.onerror = function transaction_onerror() { callback(this.error); };
        var store = transaction.objectStore(IDBFS.DB_STORE_NAME);
        for (var path in create) {
          if (!create.hasOwnProperty(path)) continue;
          var entry = create[path];
          if (dst.type === 'local') {
            // save file to local
            try {
              if (FS.isDir(entry.mode)) {
                FS.mkdir(path, entry.mode);
              } else if (FS.isFile(entry.mode)) {
                var stream = FS.open(path, 'w+', 0666);
                FS.write(stream, entry.contents, 0, entry.contents.length, 0, true /* canOwn */);
                FS.close(stream);
              }
              done(null);
            } catch (e) {
              return done(e);
            }
          } else {
            // save file to IDB
            var req = store.put(entry, path);
            req.onsuccess = function req_onsuccess() { done(null); };
            req.onerror = function req_onerror() { done(this.error); };
          }
        }
        for (var path in remove) {
          if (!remove.hasOwnProperty(path)) continue;
          var entry = remove[path];
          if (dst.type === 'local') {
            // delete file from local
            try {
              if (FS.isDir(entry.mode)) {
                // TODO recursive delete?
                FS.rmdir(path);
              } else if (FS.isFile(entry.mode)) {
                FS.unlink(path);
              }
              done(null);
            } catch (e) {
              return done(e);
            }
          } else {
            // delete file from IDB
            var req = store.delete(path);
            req.onsuccess = function req_onsuccess() { done(null); };
            req.onerror = function req_onerror() { done(this.error); };
          }
        }
      },getLocalSet:function (mount, callback) {
        var files = {};
        function isRealDir(p) {
          return p !== '.' && p !== '..';
        };
        function toAbsolute(root) {
          return function(p) {
            return PATH.join2(root, p);
          }
        };
        var check = FS.readdir(mount.mountpoint)
          .filter(isRealDir)
          .map(toAbsolute(mount.mountpoint));
        while (check.length) {
          var path = check.pop();
          var stat, node;
          try {
            var lookup = FS.lookupPath(path);
            node = lookup.node;
            stat = FS.stat(path);
          } catch (e) {
            return callback(e);
          }
          if (FS.isDir(stat.mode)) {
            check.push.apply(check, FS.readdir(path)
              .filter(isRealDir)
              .map(toAbsolute(path)));
            files[path] = { mode: stat.mode, timestamp: stat.mtime };
          } else if (FS.isFile(stat.mode)) {
            files[path] = { contents: node.contents, mode: stat.mode, timestamp: stat.mtime };
          } else {
            return callback(new Error('node type not supported'));
          }
        }
        return callback(null, { type: 'local', files: files });
      },getDB:function (name, callback) {
        // look it up in the cache
        var db = IDBFS.dbs[name];
        if (db) {
          return callback(null, db);
        }
        var req;
        try {
          req = IDBFS.indexedDB().open(name, IDBFS.DB_VERSION);
        } catch (e) {
          return onerror(e);
        }
        req.onupgradeneeded = function req_onupgradeneeded() {
          db = req.result;
          db.createObjectStore(IDBFS.DB_STORE_NAME);
        };
        req.onsuccess = function req_onsuccess() {
          db = req.result;
          // add to the cache
          IDBFS.dbs[name] = db;
          callback(null, db);
        };
        req.onerror = function req_onerror() {
          callback(this.error);
        };
      },getRemoteSet:function (mount, callback) {
        var files = {};
        IDBFS.getDB(mount.mountpoint, function(err, db) {
          if (err) return callback(err);
          var transaction = db.transaction([IDBFS.DB_STORE_NAME], 'readonly');
          transaction.onerror = function transaction_onerror() { callback(this.error); };
          var store = transaction.objectStore(IDBFS.DB_STORE_NAME);
          store.openCursor().onsuccess = function store_openCursor_onsuccess(event) {
            var cursor = event.target.result;
            if (!cursor) {
              return callback(null, { type: 'remote', db: db, files: files });
            }
            files[cursor.key] = cursor.value;
            cursor.continue();
          };
        });
      }};
  var NODEFS={isWindows:false,staticInit:function () {
        NODEFS.isWindows = !!process.platform.match(/^win/);
      },mount:function (mount) {
        assert(ENVIRONMENT_IS_NODE);
        return NODEFS.createNode(null, '/', NODEFS.getMode(mount.opts.root), 0);
      },createNode:function (parent, name, mode, dev) {
        if (!FS.isDir(mode) && !FS.isFile(mode) && !FS.isLink(mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var node = FS.createNode(parent, name, mode);
        node.node_ops = NODEFS.node_ops;
        node.stream_ops = NODEFS.stream_ops;
        return node;
      },getMode:function (path) {
        var stat;
        try {
          stat = fs.lstatSync(path);
          if (NODEFS.isWindows) {
            // On Windows, directories return permission bits 'rw-rw-rw-', even though they have 'rwxrwxrwx', so 
            // propagate write bits to execute bits.
            stat.mode = stat.mode | ((stat.mode & 146) >> 1);
          }
        } catch (e) {
          if (!e.code) throw e;
          throw new FS.ErrnoError(ERRNO_CODES[e.code]);
        }
        return stat.mode;
      },realPath:function (node) {
        var parts = [];
        while (node.parent !== node) {
          parts.push(node.name);
          node = node.parent;
        }
        parts.push(node.mount.opts.root);
        parts.reverse();
        return PATH.join.apply(null, parts);
      },flagsToPermissionStringMap:{0:"r",1:"r+",2:"r+",64:"r",65:"r+",66:"r+",129:"rx+",193:"rx+",514:"w+",577:"w",578:"w+",705:"wx",706:"wx+",1024:"a",1025:"a",1026:"a+",1089:"a",1090:"a+",1153:"ax",1154:"ax+",1217:"ax",1218:"ax+",4096:"rs",4098:"rs+"},flagsToPermissionString:function (flags) {
        if (flags in NODEFS.flagsToPermissionStringMap) {
          return NODEFS.flagsToPermissionStringMap[flags];
        } else {
          return flags;
        }
      },node_ops:{getattr:function (node) {
          var path = NODEFS.realPath(node);
          var stat;
          try {
            stat = fs.lstatSync(path);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
          // node.js v0.10.20 doesn't report blksize and blocks on Windows. Fake them with default blksize of 4096.
          // See http://support.microsoft.com/kb/140365
          if (NODEFS.isWindows && !stat.blksize) {
            stat.blksize = 4096;
          }
          if (NODEFS.isWindows && !stat.blocks) {
            stat.blocks = (stat.size+stat.blksize-1)/stat.blksize|0;
          }
          return {
            dev: stat.dev,
            ino: stat.ino,
            mode: stat.mode,
            nlink: stat.nlink,
            uid: stat.uid,
            gid: stat.gid,
            rdev: stat.rdev,
            size: stat.size,
            atime: stat.atime,
            mtime: stat.mtime,
            ctime: stat.ctime,
            blksize: stat.blksize,
            blocks: stat.blocks
          };
        },setattr:function (node, attr) {
          var path = NODEFS.realPath(node);
          try {
            if (attr.mode !== undefined) {
              fs.chmodSync(path, attr.mode);
              // update the common node structure mode as well
              node.mode = attr.mode;
            }
            if (attr.timestamp !== undefined) {
              var date = new Date(attr.timestamp);
              fs.utimesSync(path, date, date);
            }
            if (attr.size !== undefined) {
              fs.truncateSync(path, attr.size);
            }
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },lookup:function (parent, name) {
          var path = PATH.join2(NODEFS.realPath(parent), name);
          var mode = NODEFS.getMode(path);
          return NODEFS.createNode(parent, name, mode);
        },mknod:function (parent, name, mode, dev) {
          var node = NODEFS.createNode(parent, name, mode, dev);
          // create the backing node for this in the fs root as well
          var path = NODEFS.realPath(node);
          try {
            if (FS.isDir(node.mode)) {
              fs.mkdirSync(path, node.mode);
            } else {
              fs.writeFileSync(path, '', { mode: node.mode });
            }
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
          return node;
        },rename:function (oldNode, newDir, newName) {
          var oldPath = NODEFS.realPath(oldNode);
          var newPath = PATH.join2(NODEFS.realPath(newDir), newName);
          try {
            fs.renameSync(oldPath, newPath);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },unlink:function (parent, name) {
          var path = PATH.join2(NODEFS.realPath(parent), name);
          try {
            fs.unlinkSync(path);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },rmdir:function (parent, name) {
          var path = PATH.join2(NODEFS.realPath(parent), name);
          try {
            fs.rmdirSync(path);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },readdir:function (node) {
          var path = NODEFS.realPath(node);
          try {
            return fs.readdirSync(path);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },symlink:function (parent, newName, oldPath) {
          var newPath = PATH.join2(NODEFS.realPath(parent), newName);
          try {
            fs.symlinkSync(oldPath, newPath);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },readlink:function (node) {
          var path = NODEFS.realPath(node);
          try {
            return fs.readlinkSync(path);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        }},stream_ops:{open:function (stream) {
          var path = NODEFS.realPath(stream.node);
          try {
            if (FS.isFile(stream.node.mode)) {
              stream.nfd = fs.openSync(path, NODEFS.flagsToPermissionString(stream.flags));
            }
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },close:function (stream) {
          try {
            if (FS.isFile(stream.node.mode) && stream.nfd) {
              fs.closeSync(stream.nfd);
            }
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },read:function (stream, buffer, offset, length, position) {
          // FIXME this is terrible.
          var nbuffer = new Buffer(length);
          var res;
          try {
            res = fs.readSync(stream.nfd, nbuffer, 0, length, position);
          } catch (e) {
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
          if (res > 0) {
            for (var i = 0; i < res; i++) {
              buffer[offset + i] = nbuffer[i];
            }
          }
          return res;
        },write:function (stream, buffer, offset, length, position) {
          // FIXME this is terrible.
          var nbuffer = new Buffer(buffer.subarray(offset, offset + length));
          var res;
          try {
            res = fs.writeSync(stream.nfd, nbuffer, 0, length, position);
          } catch (e) {
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
          return res;
        },llseek:function (stream, offset, whence) {
          var position = offset;
          if (whence === 1) {  // SEEK_CUR.
            position += stream.position;
          } else if (whence === 2) {  // SEEK_END.
            if (FS.isFile(stream.node.mode)) {
              try {
                var stat = fs.fstatSync(stream.nfd);
                position += stat.size;
              } catch (e) {
                throw new FS.ErrnoError(ERRNO_CODES[e.code]);
              }
            }
          }
          if (position < 0) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
          stream.position = position;
          return position;
        }}};
  var _stdin=allocate(1, "i32*", ALLOC_STATIC);
  var _stdout=allocate(1, "i32*", ALLOC_STATIC);
  var _stderr=allocate(1, "i32*", ALLOC_STATIC);var FS={root:null,mounts:[],devices:[null],streams:[null],nextInode:1,nameTable:null,currentPath:"/",initialized:false,ignorePermissions:true,ErrnoError:null,genericErrors:{},handleFSError:function (e) {
        if (!(e instanceof FS.ErrnoError)) throw e + ' : ' + stackTrace();
        return ___setErrNo(e.errno);
      },lookupPath:function (path, opts) {
        path = PATH.resolve(FS.cwd(), path);
        opts = opts || { recurse_count: 0 };
        if (opts.recurse_count > 8) {  // max recursive lookup of 8
          throw new FS.ErrnoError(ERRNO_CODES.ELOOP);
        }
        // split the path
        var parts = PATH.normalizeArray(path.split('/').filter(function(p) {
          return !!p;
        }), false);
        // start at the root
        var current = FS.root;
        var current_path = '/';
        for (var i = 0; i < parts.length; i++) {
          var islast = (i === parts.length-1);
          if (islast && opts.parent) {
            // stop resolving
            break;
          }
          current = FS.lookupNode(current, parts[i]);
          current_path = PATH.join2(current_path, parts[i]);
          // jump to the mount's root node if this is a mountpoint
          if (FS.isMountpoint(current)) {
            current = current.mount.root;
          }
          // follow symlinks
          // by default, lookupPath will not follow a symlink if it is the final path component.
          // setting opts.follow = true will override this behavior.
          if (!islast || opts.follow) {
            var count = 0;
            while (FS.isLink(current.mode)) {
              var link = FS.readlink(current_path);
              current_path = PATH.resolve(PATH.dirname(current_path), link);
              var lookup = FS.lookupPath(current_path, { recurse_count: opts.recurse_count });
              current = lookup.node;
              if (count++ > 40) {  // limit max consecutive symlinks to 40 (SYMLOOP_MAX).
                throw new FS.ErrnoError(ERRNO_CODES.ELOOP);
              }
            }
          }
        }
        return { path: current_path, node: current };
      },getPath:function (node) {
        var path;
        while (true) {
          if (FS.isRoot(node)) {
            var mount = node.mount.mountpoint;
            if (!path) return mount;
            return mount[mount.length-1] !== '/' ? mount + '/' + path : mount + path;
          }
          path = path ? node.name + '/' + path : node.name;
          node = node.parent;
        }
      },hashName:function (parentid, name) {
        var hash = 0;
        for (var i = 0; i < name.length; i++) {
          hash = ((hash << 5) - hash + name.charCodeAt(i)) | 0;
        }
        return ((parentid + hash) >>> 0) % FS.nameTable.length;
      },hashAddNode:function (node) {
        var hash = FS.hashName(node.parent.id, node.name);
        node.name_next = FS.nameTable[hash];
        FS.nameTable[hash] = node;
      },hashRemoveNode:function (node) {
        var hash = FS.hashName(node.parent.id, node.name);
        if (FS.nameTable[hash] === node) {
          FS.nameTable[hash] = node.name_next;
        } else {
          var current = FS.nameTable[hash];
          while (current) {
            if (current.name_next === node) {
              current.name_next = node.name_next;
              break;
            }
            current = current.name_next;
          }
        }
      },lookupNode:function (parent, name) {
        var err = FS.mayLookup(parent);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        var hash = FS.hashName(parent.id, name);
        for (var node = FS.nameTable[hash]; node; node = node.name_next) {
          var nodeName = node.name;
          if (node.parent.id === parent.id && nodeName === name) {
            return node;
          }
        }
        // if we failed to find it in the cache, call into the VFS
        return FS.lookup(parent, name);
      },createNode:function (parent, name, mode, rdev) {
        if (!FS.FSNode) {
          FS.FSNode = function(parent, name, mode, rdev) {
            this.id = FS.nextInode++;
            this.name = name;
            this.mode = mode;
            this.node_ops = {};
            this.stream_ops = {};
            this.rdev = rdev;
            this.parent = null;
            this.mount = null;
            if (!parent) {
              parent = this;  // root node sets parent to itself
            }
            this.parent = parent;
            this.mount = parent.mount;
            FS.hashAddNode(this);
          };
          // compatibility
          var readMode = 292 | 73;
          var writeMode = 146;
          FS.FSNode.prototype = {};
          // NOTE we must use Object.defineProperties instead of individual calls to
          // Object.defineProperty in order to make closure compiler happy
          Object.defineProperties(FS.FSNode.prototype, {
            read: {
              get: function() { return (this.mode & readMode) === readMode; },
              set: function(val) { val ? this.mode |= readMode : this.mode &= ~readMode; }
            },
            write: {
              get: function() { return (this.mode & writeMode) === writeMode; },
              set: function(val) { val ? this.mode |= writeMode : this.mode &= ~writeMode; }
            },
            isFolder: {
              get: function() { return FS.isDir(this.mode); },
            },
            isDevice: {
              get: function() { return FS.isChrdev(this.mode); },
            },
          });
        }
        return new FS.FSNode(parent, name, mode, rdev);
      },destroyNode:function (node) {
        FS.hashRemoveNode(node);
      },isRoot:function (node) {
        return node === node.parent;
      },isMountpoint:function (node) {
        return node.mounted;
      },isFile:function (mode) {
        return (mode & 61440) === 32768;
      },isDir:function (mode) {
        return (mode & 61440) === 16384;
      },isLink:function (mode) {
        return (mode & 61440) === 40960;
      },isChrdev:function (mode) {
        return (mode & 61440) === 8192;
      },isBlkdev:function (mode) {
        return (mode & 61440) === 24576;
      },isFIFO:function (mode) {
        return (mode & 61440) === 4096;
      },isSocket:function (mode) {
        return (mode & 49152) === 49152;
      },flagModes:{"r":0,"rs":1052672,"r+":2,"w":577,"wx":705,"xw":705,"w+":578,"wx+":706,"xw+":706,"a":1089,"ax":1217,"xa":1217,"a+":1090,"ax+":1218,"xa+":1218},modeStringToFlags:function (str) {
        var flags = FS.flagModes[str];
        if (typeof flags === 'undefined') {
          throw new Error('Unknown file open mode: ' + str);
        }
        return flags;
      },flagsToPermissionString:function (flag) {
        var accmode = flag & 2097155;
        var perms = ['r', 'w', 'rw'][accmode];
        if ((flag & 512)) {
          perms += 'w';
        }
        return perms;
      },nodePermissions:function (node, perms) {
        if (FS.ignorePermissions) {
          return 0;
        }
        // return 0 if any user, group or owner bits are set.
        if (perms.indexOf('r') !== -1 && !(node.mode & 292)) {
          return ERRNO_CODES.EACCES;
        } else if (perms.indexOf('w') !== -1 && !(node.mode & 146)) {
          return ERRNO_CODES.EACCES;
        } else if (perms.indexOf('x') !== -1 && !(node.mode & 73)) {
          return ERRNO_CODES.EACCES;
        }
        return 0;
      },mayLookup:function (dir) {
        return FS.nodePermissions(dir, 'x');
      },mayCreate:function (dir, name) {
        try {
          var node = FS.lookupNode(dir, name);
          return ERRNO_CODES.EEXIST;
        } catch (e) {
        }
        return FS.nodePermissions(dir, 'wx');
      },mayDelete:function (dir, name, isdir) {
        var node;
        try {
          node = FS.lookupNode(dir, name);
        } catch (e) {
          return e.errno;
        }
        var err = FS.nodePermissions(dir, 'wx');
        if (err) {
          return err;
        }
        if (isdir) {
          if (!FS.isDir(node.mode)) {
            return ERRNO_CODES.ENOTDIR;
          }
          if (FS.isRoot(node) || FS.getPath(node) === FS.cwd()) {
            return ERRNO_CODES.EBUSY;
          }
        } else {
          if (FS.isDir(node.mode)) {
            return ERRNO_CODES.EISDIR;
          }
        }
        return 0;
      },mayOpen:function (node, flags) {
        if (!node) {
          return ERRNO_CODES.ENOENT;
        }
        if (FS.isLink(node.mode)) {
          return ERRNO_CODES.ELOOP;
        } else if (FS.isDir(node.mode)) {
          if ((flags & 2097155) !== 0 ||  // opening for write
              (flags & 512)) {
            return ERRNO_CODES.EISDIR;
          }
        }
        return FS.nodePermissions(node, FS.flagsToPermissionString(flags));
      },MAX_OPEN_FDS:4096,nextfd:function (fd_start, fd_end) {
        fd_start = fd_start || 1;
        fd_end = fd_end || FS.MAX_OPEN_FDS;
        for (var fd = fd_start; fd <= fd_end; fd++) {
          if (!FS.streams[fd]) {
            return fd;
          }
        }
        throw new FS.ErrnoError(ERRNO_CODES.EMFILE);
      },getStream:function (fd) {
        return FS.streams[fd];
      },createStream:function (stream, fd_start, fd_end) {
        if (!FS.FSStream) {
          FS.FSStream = function(){};
          FS.FSStream.prototype = {};
          // compatibility
          Object.defineProperties(FS.FSStream.prototype, {
            object: {
              get: function() { return this.node; },
              set: function(val) { this.node = val; }
            },
            isRead: {
              get: function() { return (this.flags & 2097155) !== 1; }
            },
            isWrite: {
              get: function() { return (this.flags & 2097155) !== 0; }
            },
            isAppend: {
              get: function() { return (this.flags & 1024); }
            }
          });
        }
        if (stream.__proto__) {
          // reuse the object
          stream.__proto__ = FS.FSStream.prototype;
        } else {
          var newStream = new FS.FSStream();
          for (var p in stream) {
            newStream[p] = stream[p];
          }
          stream = newStream;
        }
        var fd = FS.nextfd(fd_start, fd_end);
        stream.fd = fd;
        FS.streams[fd] = stream;
        return stream;
      },closeStream:function (fd) {
        FS.streams[fd] = null;
      },chrdev_stream_ops:{open:function (stream) {
          var device = FS.getDevice(stream.node.rdev);
          // override node's stream ops with the device's
          stream.stream_ops = device.stream_ops;
          // forward the open call
          if (stream.stream_ops.open) {
            stream.stream_ops.open(stream);
          }
        },llseek:function () {
          throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);
        }},major:function (dev) {
        return ((dev) >> 8);
      },minor:function (dev) {
        return ((dev) & 0xff);
      },makedev:function (ma, mi) {
        return ((ma) << 8 | (mi));
      },registerDevice:function (dev, ops) {
        FS.devices[dev] = { stream_ops: ops };
      },getDevice:function (dev) {
        return FS.devices[dev];
      },syncfs:function (populate, callback) {
        if (typeof(populate) === 'function') {
          callback = populate;
          populate = false;
        }
        var completed = 0;
        var total = FS.mounts.length;
        function done(err) {
          if (err) {
            return callback(err);
          }
          if (++completed >= total) {
            callback(null);
          }
        };
        // sync all mounts
        for (var i = 0; i < FS.mounts.length; i++) {
          var mount = FS.mounts[i];
          if (!mount.type.syncfs) {
            done(null);
            continue;
          }
          mount.type.syncfs(mount, populate, done);
        }
      },mount:function (type, opts, mountpoint) {
        var lookup;
        if (mountpoint) {
          lookup = FS.lookupPath(mountpoint, { follow: false });
          mountpoint = lookup.path;  // use the absolute path
        }
        var mount = {
          type: type,
          opts: opts,
          mountpoint: mountpoint,
          root: null
        };
        // create a root node for the fs
        var root = type.mount(mount);
        root.mount = mount;
        mount.root = root;
        // assign the mount info to the mountpoint's node
        if (lookup) {
          lookup.node.mount = mount;
          lookup.node.mounted = true;
          // compatibility update FS.root if we mount to /
          if (mountpoint === '/') {
            FS.root = mount.root;
          }
        }
        // add to our cached list of mounts
        FS.mounts.push(mount);
        return root;
      },lookup:function (parent, name) {
        return parent.node_ops.lookup(parent, name);
      },mknod:function (path, mode, dev) {
        var lookup = FS.lookupPath(path, { parent: true });
        var parent = lookup.node;
        var name = PATH.basename(path);
        var err = FS.mayCreate(parent, name);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        if (!parent.node_ops.mknod) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        return parent.node_ops.mknod(parent, name, mode, dev);
      },create:function (path, mode) {
        mode = mode !== undefined ? mode : 0666;
        mode &= 4095;
        mode |= 32768;
        return FS.mknod(path, mode, 0);
      },mkdir:function (path, mode) {
        mode = mode !== undefined ? mode : 0777;
        mode &= 511 | 512;
        mode |= 16384;
        return FS.mknod(path, mode, 0);
      },mkdev:function (path, mode, dev) {
        if (typeof(dev) === 'undefined') {
          dev = mode;
          mode = 0666;
        }
        mode |= 8192;
        return FS.mknod(path, mode, dev);
      },symlink:function (oldpath, newpath) {
        var lookup = FS.lookupPath(newpath, { parent: true });
        var parent = lookup.node;
        var newname = PATH.basename(newpath);
        var err = FS.mayCreate(parent, newname);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        if (!parent.node_ops.symlink) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        return parent.node_ops.symlink(parent, newname, oldpath);
      },rename:function (old_path, new_path) {
        var old_dirname = PATH.dirname(old_path);
        var new_dirname = PATH.dirname(new_path);
        var old_name = PATH.basename(old_path);
        var new_name = PATH.basename(new_path);
        // parents must exist
        var lookup, old_dir, new_dir;
        try {
          lookup = FS.lookupPath(old_path, { parent: true });
          old_dir = lookup.node;
          lookup = FS.lookupPath(new_path, { parent: true });
          new_dir = lookup.node;
        } catch (e) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        }
        // need to be part of the same mount
        if (old_dir.mount !== new_dir.mount) {
          throw new FS.ErrnoError(ERRNO_CODES.EXDEV);
        }
        // source must exist
        var old_node = FS.lookupNode(old_dir, old_name);
        // old path should not be an ancestor of the new path
        var relative = PATH.relative(old_path, new_dirname);
        if (relative.charAt(0) !== '.') {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        // new path should not be an ancestor of the old path
        relative = PATH.relative(new_path, old_dirname);
        if (relative.charAt(0) !== '.') {
          throw new FS.ErrnoError(ERRNO_CODES.ENOTEMPTY);
        }
        // see if the new path already exists
        var new_node;
        try {
          new_node = FS.lookupNode(new_dir, new_name);
        } catch (e) {
          // not fatal
        }
        // early out if nothing needs to change
        if (old_node === new_node) {
          return;
        }
        // we'll need to delete the old entry
        var isdir = FS.isDir(old_node.mode);
        var err = FS.mayDelete(old_dir, old_name, isdir);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        // need delete permissions if we'll be overwriting.
        // need create permissions if new doesn't already exist.
        err = new_node ?
          FS.mayDelete(new_dir, new_name, isdir) :
          FS.mayCreate(new_dir, new_name);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        if (!old_dir.node_ops.rename) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (FS.isMountpoint(old_node) || (new_node && FS.isMountpoint(new_node))) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        }
        // if we are going to change the parent, check write permissions
        if (new_dir !== old_dir) {
          err = FS.nodePermissions(old_dir, 'w');
          if (err) {
            throw new FS.ErrnoError(err);
          }
        }
        // remove the node from the lookup hash
        FS.hashRemoveNode(old_node);
        // do the underlying fs rename
        try {
          old_dir.node_ops.rename(old_node, new_dir, new_name);
        } catch (e) {
          throw e;
        } finally {
          // add the node back to the hash (in case node_ops.rename
          // changed its name)
          FS.hashAddNode(old_node);
        }
      },rmdir:function (path) {
        var lookup = FS.lookupPath(path, { parent: true });
        var parent = lookup.node;
        var name = PATH.basename(path);
        var node = FS.lookupNode(parent, name);
        var err = FS.mayDelete(parent, name, true);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        if (!parent.node_ops.rmdir) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (FS.isMountpoint(node)) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        }
        parent.node_ops.rmdir(parent, name);
        FS.destroyNode(node);
      },readdir:function (path) {
        var lookup = FS.lookupPath(path, { follow: true });
        var node = lookup.node;
        if (!node.node_ops.readdir) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOTDIR);
        }
        return node.node_ops.readdir(node);
      },unlink:function (path) {
        var lookup = FS.lookupPath(path, { parent: true });
        var parent = lookup.node;
        var name = PATH.basename(path);
        var node = FS.lookupNode(parent, name);
        var err = FS.mayDelete(parent, name, false);
        if (err) {
          // POSIX says unlink should set EPERM, not EISDIR
          if (err === ERRNO_CODES.EISDIR) err = ERRNO_CODES.EPERM;
          throw new FS.ErrnoError(err);
        }
        if (!parent.node_ops.unlink) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (FS.isMountpoint(node)) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        }
        parent.node_ops.unlink(parent, name);
        FS.destroyNode(node);
      },readlink:function (path) {
        var lookup = FS.lookupPath(path, { follow: false });
        var link = lookup.node;
        if (!link.node_ops.readlink) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        return link.node_ops.readlink(link);
      },stat:function (path, dontFollow) {
        var lookup = FS.lookupPath(path, { follow: !dontFollow });
        var node = lookup.node;
        if (!node.node_ops.getattr) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        return node.node_ops.getattr(node);
      },lstat:function (path) {
        return FS.stat(path, true);
      },chmod:function (path, mode, dontFollow) {
        var node;
        if (typeof path === 'string') {
          var lookup = FS.lookupPath(path, { follow: !dontFollow });
          node = lookup.node;
        } else {
          node = path;
        }
        if (!node.node_ops.setattr) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        node.node_ops.setattr(node, {
          mode: (mode & 4095) | (node.mode & ~4095),
          timestamp: Date.now()
        });
      },lchmod:function (path, mode) {
        FS.chmod(path, mode, true);
      },fchmod:function (fd, mode) {
        var stream = FS.getStream(fd);
        if (!stream) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        FS.chmod(stream.node, mode);
      },chown:function (path, uid, gid, dontFollow) {
        var node;
        if (typeof path === 'string') {
          var lookup = FS.lookupPath(path, { follow: !dontFollow });
          node = lookup.node;
        } else {
          node = path;
        }
        if (!node.node_ops.setattr) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        node.node_ops.setattr(node, {
          timestamp: Date.now()
          // we ignore the uid / gid for now
        });
      },lchown:function (path, uid, gid) {
        FS.chown(path, uid, gid, true);
      },fchown:function (fd, uid, gid) {
        var stream = FS.getStream(fd);
        if (!stream) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        FS.chown(stream.node, uid, gid);
      },truncate:function (path, len) {
        if (len < 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var node;
        if (typeof path === 'string') {
          var lookup = FS.lookupPath(path, { follow: true });
          node = lookup.node;
        } else {
          node = path;
        }
        if (!node.node_ops.setattr) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (FS.isDir(node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EISDIR);
        }
        if (!FS.isFile(node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var err = FS.nodePermissions(node, 'w');
        if (err) {
          throw new FS.ErrnoError(err);
        }
        node.node_ops.setattr(node, {
          size: len,
          timestamp: Date.now()
        });
      },ftruncate:function (fd, len) {
        var stream = FS.getStream(fd);
        if (!stream) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        if ((stream.flags & 2097155) === 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        FS.truncate(stream.node, len);
      },utime:function (path, atime, mtime) {
        var lookup = FS.lookupPath(path, { follow: true });
        var node = lookup.node;
        node.node_ops.setattr(node, {
          timestamp: Math.max(atime, mtime)
        });
      },open:function (path, flags, mode, fd_start, fd_end) {
        flags = typeof flags === 'string' ? FS.modeStringToFlags(flags) : flags;
        mode = typeof mode === 'undefined' ? 0666 : mode;
        if ((flags & 64)) {
          mode = (mode & 4095) | 32768;
        } else {
          mode = 0;
        }
        var node;
        if (typeof path === 'object') {
          node = path;
        } else {
          path = PATH.normalize(path);
          try {
            var lookup = FS.lookupPath(path, {
              follow: !(flags & 131072)
            });
            node = lookup.node;
          } catch (e) {
            // ignore
          }
        }
        // perhaps we need to create the node
        if ((flags & 64)) {
          if (node) {
            // if O_CREAT and O_EXCL are set, error out if the node already exists
            if ((flags & 128)) {
              throw new FS.ErrnoError(ERRNO_CODES.EEXIST);
            }
          } else {
            // node doesn't exist, try to create it
            node = FS.mknod(path, mode, 0);
          }
        }
        if (!node) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
        }
        // can't truncate a device
        if (FS.isChrdev(node.mode)) {
          flags &= ~512;
        }
        // check permissions
        var err = FS.mayOpen(node, flags);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        // do truncation if necessary
        if ((flags & 512)) {
          FS.truncate(node, 0);
        }
        // we've already handled these, don't pass down to the underlying vfs
        flags &= ~(128 | 512);
        // register the stream with the filesystem
        var stream = FS.createStream({
          node: node,
          path: FS.getPath(node),  // we want the absolute path to the node
          flags: flags,
          seekable: true,
          position: 0,
          stream_ops: node.stream_ops,
          // used by the file family libc calls (fopen, fwrite, ferror, etc.)
          ungotten: [],
          error: false
        }, fd_start, fd_end);
        // call the new stream's open function
        if (stream.stream_ops.open) {
          stream.stream_ops.open(stream);
        }
        if (Module['logReadFiles'] && !(flags & 1)) {
          if (!FS.readFiles) FS.readFiles = {};
          if (!(path in FS.readFiles)) {
            FS.readFiles[path] = 1;
            Module['printErr']('read file: ' + path);
          }
        }
        return stream;
      },close:function (stream) {
        try {
          if (stream.stream_ops.close) {
            stream.stream_ops.close(stream);
          }
        } catch (e) {
          throw e;
        } finally {
          FS.closeStream(stream.fd);
        }
      },llseek:function (stream, offset, whence) {
        if (!stream.seekable || !stream.stream_ops.llseek) {
          throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);
        }
        return stream.stream_ops.llseek(stream, offset, whence);
      },read:function (stream, buffer, offset, length, position) {
        if (length < 0 || position < 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        if ((stream.flags & 2097155) === 1) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        if (FS.isDir(stream.node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EISDIR);
        }
        if (!stream.stream_ops.read) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var seeking = true;
        if (typeof position === 'undefined') {
          position = stream.position;
          seeking = false;
        } else if (!stream.seekable) {
          throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);
        }
        var bytesRead = stream.stream_ops.read(stream, buffer, offset, length, position);
        if (!seeking) stream.position += bytesRead;
        return bytesRead;
      },write:function (stream, buffer, offset, length, position, canOwn) {
        if (length < 0 || position < 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        if ((stream.flags & 2097155) === 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        if (FS.isDir(stream.node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EISDIR);
        }
        if (!stream.stream_ops.write) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var seeking = true;
        if (typeof position === 'undefined') {
          position = stream.position;
          seeking = false;
        } else if (!stream.seekable) {
          throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);
        }
        if (stream.flags & 1024) {
          // seek to the end before writing in append mode
          FS.llseek(stream, 0, 2);
        }
        var bytesWritten = stream.stream_ops.write(stream, buffer, offset, length, position, canOwn);
        if (!seeking) stream.position += bytesWritten;
        return bytesWritten;
      },allocate:function (stream, offset, length) {
        if (offset < 0 || length <= 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        if ((stream.flags & 2097155) === 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        if (!FS.isFile(stream.node.mode) && !FS.isDir(node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.ENODEV);
        }
        if (!stream.stream_ops.allocate) {
          throw new FS.ErrnoError(ERRNO_CODES.EOPNOTSUPP);
        }
        stream.stream_ops.allocate(stream, offset, length);
      },mmap:function (stream, buffer, offset, length, position, prot, flags) {
        // TODO if PROT is PROT_WRITE, make sure we have write access
        if ((stream.flags & 2097155) === 1) {
          throw new FS.ErrnoError(ERRNO_CODES.EACCES);
        }
        if (!stream.stream_ops.mmap) {
          throw new FS.errnoError(ERRNO_CODES.ENODEV);
        }
        return stream.stream_ops.mmap(stream, buffer, offset, length, position, prot, flags);
      },ioctl:function (stream, cmd, arg) {
        if (!stream.stream_ops.ioctl) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOTTY);
        }
        return stream.stream_ops.ioctl(stream, cmd, arg);
      },readFile:function (path, opts) {
        opts = opts || {};
        opts.flags = opts.flags || 'r';
        opts.encoding = opts.encoding || 'binary';
        var ret;
        var stream = FS.open(path, opts.flags);
        var stat = FS.stat(path);
        var length = stat.size;
        var buf = new Uint8Array(length);
        FS.read(stream, buf, 0, length, 0);
        if (opts.encoding === 'utf8') {
          ret = '';
          var utf8 = new Runtime.UTF8Processor();
          for (var i = 0; i < length; i++) {
            ret += utf8.processCChar(buf[i]);
          }
        } else if (opts.encoding === 'binary') {
          ret = buf;
        } else {
          throw new Error('Invalid encoding type "' + opts.encoding + '"');
        }
        FS.close(stream);
        return ret;
      },writeFile:function (path, data, opts) {
        opts = opts || {};
        opts.flags = opts.flags || 'w';
        opts.encoding = opts.encoding || 'utf8';
        var stream = FS.open(path, opts.flags, opts.mode);
        if (opts.encoding === 'utf8') {
          var utf8 = new Runtime.UTF8Processor();
          var buf = new Uint8Array(utf8.processJSString(data));
          FS.write(stream, buf, 0, buf.length, 0);
        } else if (opts.encoding === 'binary') {
          FS.write(stream, data, 0, data.length, 0);
        } else {
          throw new Error('Invalid encoding type "' + opts.encoding + '"');
        }
        FS.close(stream);
      },cwd:function () {
        return FS.currentPath;
      },chdir:function (path) {
        var lookup = FS.lookupPath(path, { follow: true });
        if (!FS.isDir(lookup.node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOTDIR);
        }
        var err = FS.nodePermissions(lookup.node, 'x');
        if (err) {
          throw new FS.ErrnoError(err);
        }
        FS.currentPath = lookup.path;
      },createDefaultDirectories:function () {
        FS.mkdir('/tmp');
      },createDefaultDevices:function () {
        // create /dev
        FS.mkdir('/dev');
        // setup /dev/null
        FS.registerDevice(FS.makedev(1, 3), {
          read: function() { return 0; },
          write: function() { return 0; }
        });
        FS.mkdev('/dev/null', FS.makedev(1, 3));
        // setup /dev/tty and /dev/tty1
        // stderr needs to print output using Module['printErr']
        // so we register a second tty just for it.
        TTY.register(FS.makedev(5, 0), TTY.default_tty_ops);
        TTY.register(FS.makedev(6, 0), TTY.default_tty1_ops);
        FS.mkdev('/dev/tty', FS.makedev(5, 0));
        FS.mkdev('/dev/tty1', FS.makedev(6, 0));
        // we're not going to emulate the actual shm device,
        // just create the tmp dirs that reside in it commonly
        FS.mkdir('/dev/shm');
        FS.mkdir('/dev/shm/tmp');
      },createStandardStreams:function () {
        // TODO deprecate the old functionality of a single
        // input / output callback and that utilizes FS.createDevice
        // and instead require a unique set of stream ops
        // by default, we symlink the standard streams to the
        // default tty devices. however, if the standard streams
        // have been overwritten we create a unique device for
        // them instead.
        if (Module['stdin']) {
          FS.createDevice('/dev', 'stdin', Module['stdin']);
        } else {
          FS.symlink('/dev/tty', '/dev/stdin');
        }
        if (Module['stdout']) {
          FS.createDevice('/dev', 'stdout', null, Module['stdout']);
        } else {
          FS.symlink('/dev/tty', '/dev/stdout');
        }
        if (Module['stderr']) {
          FS.createDevice('/dev', 'stderr', null, Module['stderr']);
        } else {
          FS.symlink('/dev/tty1', '/dev/stderr');
        }
        // open default streams for the stdin, stdout and stderr devices
        var stdin = FS.open('/dev/stdin', 'r');
        HEAP32[((_stdin)>>2)]=stdin.fd;
        assert(stdin.fd === 1, 'invalid handle for stdin (' + stdin.fd + ')');
        var stdout = FS.open('/dev/stdout', 'w');
        HEAP32[((_stdout)>>2)]=stdout.fd;
        assert(stdout.fd === 2, 'invalid handle for stdout (' + stdout.fd + ')');
        var stderr = FS.open('/dev/stderr', 'w');
        HEAP32[((_stderr)>>2)]=stderr.fd;
        assert(stderr.fd === 3, 'invalid handle for stderr (' + stderr.fd + ')');
      },ensureErrnoError:function () {
        if (FS.ErrnoError) return;
        FS.ErrnoError = function ErrnoError(errno) {
          this.errno = errno;
          for (var key in ERRNO_CODES) {
            if (ERRNO_CODES[key] === errno) {
              this.code = key;
              break;
            }
          }
          this.message = ERRNO_MESSAGES[errno];
          this.stack = stackTrace();
        };
        FS.ErrnoError.prototype = new Error();
        FS.ErrnoError.prototype.constructor = FS.ErrnoError;
        // Some errors may happen quite a bit, to avoid overhead we reuse them (and suffer a lack of stack info)
        [ERRNO_CODES.ENOENT].forEach(function(code) {
          FS.genericErrors[code] = new FS.ErrnoError(code);
          FS.genericErrors[code].stack = '<generic error, no stack>';
        });
      },staticInit:function () {
        FS.ensureErrnoError();
        FS.nameTable = new Array(4096);
        FS.root = FS.createNode(null, '/', 16384 | 0777, 0);
        FS.mount(MEMFS, {}, '/');
        FS.createDefaultDirectories();
        FS.createDefaultDevices();
      },init:function (input, output, error) {
        assert(!FS.init.initialized, 'FS.init was previously called. If you want to initialize later with custom parameters, remove any earlier calls (note that one is automatically added to the generated code)');
        FS.init.initialized = true;
        FS.ensureErrnoError();
        // Allow Module.stdin etc. to provide defaults, if none explicitly passed to us here
        Module['stdin'] = input || Module['stdin'];
        Module['stdout'] = output || Module['stdout'];
        Module['stderr'] = error || Module['stderr'];
        FS.createStandardStreams();
      },quit:function () {
        FS.init.initialized = false;
        for (var i = 0; i < FS.streams.length; i++) {
          var stream = FS.streams[i];
          if (!stream) {
            continue;
          }
          FS.close(stream);
        }
      },getMode:function (canRead, canWrite) {
        var mode = 0;
        if (canRead) mode |= 292 | 73;
        if (canWrite) mode |= 146;
        return mode;
      },joinPath:function (parts, forceRelative) {
        var path = PATH.join.apply(null, parts);
        if (forceRelative && path[0] == '/') path = path.substr(1);
        return path;
      },absolutePath:function (relative, base) {
        return PATH.resolve(base, relative);
      },standardizePath:function (path) {
        return PATH.normalize(path);
      },findObject:function (path, dontResolveLastLink) {
        var ret = FS.analyzePath(path, dontResolveLastLink);
        if (ret.exists) {
          return ret.object;
        } else {
          ___setErrNo(ret.error);
          return null;
        }
      },analyzePath:function (path, dontResolveLastLink) {
        // operate from within the context of the symlink's target
        try {
          var lookup = FS.lookupPath(path, { follow: !dontResolveLastLink });
          path = lookup.path;
        } catch (e) {
        }
        var ret = {
          isRoot: false, exists: false, error: 0, name: null, path: null, object: null,
          parentExists: false, parentPath: null, parentObject: null
        };
        try {
          var lookup = FS.lookupPath(path, { parent: true });
          ret.parentExists = true;
          ret.parentPath = lookup.path;
          ret.parentObject = lookup.node;
          ret.name = PATH.basename(path);
          lookup = FS.lookupPath(path, { follow: !dontResolveLastLink });
          ret.exists = true;
          ret.path = lookup.path;
          ret.object = lookup.node;
          ret.name = lookup.node.name;
          ret.isRoot = lookup.path === '/';
        } catch (e) {
          ret.error = e.errno;
        };
        return ret;
      },createFolder:function (parent, name, canRead, canWrite) {
        var path = PATH.join2(typeof parent === 'string' ? parent : FS.getPath(parent), name);
        var mode = FS.getMode(canRead, canWrite);
        return FS.mkdir(path, mode);
      },createPath:function (parent, path, canRead, canWrite) {
        parent = typeof parent === 'string' ? parent : FS.getPath(parent);
        var parts = path.split('/').reverse();
        while (parts.length) {
          var part = parts.pop();
          if (!part) continue;
          var current = PATH.join2(parent, part);
          try {
            FS.mkdir(current);
          } catch (e) {
            // ignore EEXIST
          }
          parent = current;
        }
        return current;
      },createFile:function (parent, name, properties, canRead, canWrite) {
        var path = PATH.join2(typeof parent === 'string' ? parent : FS.getPath(parent), name);
        var mode = FS.getMode(canRead, canWrite);
        return FS.create(path, mode);
      },createDataFile:function (parent, name, data, canRead, canWrite, canOwn) {
        var path = name ? PATH.join2(typeof parent === 'string' ? parent : FS.getPath(parent), name) : parent;
        var mode = FS.getMode(canRead, canWrite);
        var node = FS.create(path, mode);
        if (data) {
          if (typeof data === 'string') {
            var arr = new Array(data.length);
            for (var i = 0, len = data.length; i < len; ++i) arr[i] = data.charCodeAt(i);
            data = arr;
          }
          // make sure we can write to the file
          FS.chmod(node, mode | 146);
          var stream = FS.open(node, 'w');
          FS.write(stream, data, 0, data.length, 0, canOwn);
          FS.close(stream);
          FS.chmod(node, mode);
        }
        return node;
      },createDevice:function (parent, name, input, output) {
        var path = PATH.join2(typeof parent === 'string' ? parent : FS.getPath(parent), name);
        var mode = FS.getMode(!!input, !!output);
        if (!FS.createDevice.major) FS.createDevice.major = 64;
        var dev = FS.makedev(FS.createDevice.major++, 0);
        // Create a fake device that a set of stream ops to emulate
        // the old behavior.
        FS.registerDevice(dev, {
          open: function(stream) {
            stream.seekable = false;
          },
          close: function(stream) {
            // flush any pending line data
            if (output && output.buffer && output.buffer.length) {
              output(10);
            }
          },
          read: function(stream, buffer, offset, length, pos /* ignored */) {
            var bytesRead = 0;
            for (var i = 0; i < length; i++) {
              var result;
              try {
                result = input();
              } catch (e) {
                throw new FS.ErrnoError(ERRNO_CODES.EIO);
              }
              if (result === undefined && bytesRead === 0) {
                throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
              }
              if (result === null || result === undefined) break;
              bytesRead++;
              buffer[offset+i] = result;
            }
            if (bytesRead) {
              stream.node.timestamp = Date.now();
            }
            return bytesRead;
          },
          write: function(stream, buffer, offset, length, pos) {
            for (var i = 0; i < length; i++) {
              try {
                output(buffer[offset+i]);
              } catch (e) {
                throw new FS.ErrnoError(ERRNO_CODES.EIO);
              }
            }
            if (length) {
              stream.node.timestamp = Date.now();
            }
            return i;
          }
        });
        return FS.mkdev(path, mode, dev);
      },createLink:function (parent, name, target, canRead, canWrite) {
        var path = PATH.join2(typeof parent === 'string' ? parent : FS.getPath(parent), name);
        return FS.symlink(target, path);
      },forceLoadFile:function (obj) {
        if (obj.isDevice || obj.isFolder || obj.link || obj.contents) return true;
        var success = true;
        if (typeof XMLHttpRequest !== 'undefined') {
          throw new Error("Lazy loading should have been performed (contents set) in createLazyFile, but it was not. Lazy loading only works in web workers. Use --embed-file or --preload-file in emcc on the main thread.");
        } else if (Module['read']) {
          // Command-line.
          try {
            // WARNING: Can't read binary files in V8's d8 or tracemonkey's js, as
            //          read() will try to parse UTF8.
            obj.contents = intArrayFromString(Module['read'](obj.url), true);
          } catch (e) {
            success = false;
          }
        } else {
          throw new Error('Cannot load without read() or XMLHttpRequest.');
        }
        if (!success) ___setErrNo(ERRNO_CODES.EIO);
        return success;
      },createLazyFile:function (parent, name, url, canRead, canWrite) {
        if (typeof XMLHttpRequest !== 'undefined') {
          if (!ENVIRONMENT_IS_WORKER) throw 'Cannot do synchronous binary XHRs outside webworkers in modern browsers. Use --embed-file or --preload-file in emcc';
          // Lazy chunked Uint8Array (implements get and length from Uint8Array). Actual getting is abstracted away for eventual reuse.
          function LazyUint8Array() {
            this.lengthKnown = false;
            this.chunks = []; // Loaded chunks. Index is the chunk number
          }
          LazyUint8Array.prototype.get = function LazyUint8Array_get(idx) {
            if (idx > this.length-1 || idx < 0) {
              return undefined;
            }
            var chunkOffset = idx % this.chunkSize;
            var chunkNum = Math.floor(idx / this.chunkSize);
            return this.getter(chunkNum)[chunkOffset];
          }
          LazyUint8Array.prototype.setDataGetter = function LazyUint8Array_setDataGetter(getter) {
            this.getter = getter;
          }
          LazyUint8Array.prototype.cacheLength = function LazyUint8Array_cacheLength() {
              // Find length
              var xhr = new XMLHttpRequest();
              xhr.open('HEAD', url, false);
              xhr.send(null);
              if (!(xhr.status >= 200 && xhr.status < 300 || xhr.status === 304)) throw new Error("Couldn't load " + url + ". Status: " + xhr.status);
              var datalength = Number(xhr.getResponseHeader("Content-length"));
              var header;
              var hasByteServing = (header = xhr.getResponseHeader("Accept-Ranges")) && header === "bytes";
              var chunkSize = 1024*1024; // Chunk size in bytes
              if (!hasByteServing) chunkSize = datalength;
              // Function to get a range from the remote URL.
              var doXHR = (function(from, to) {
                if (from > to) throw new Error("invalid range (" + from + ", " + to + ") or no bytes requested!");
                if (to > datalength-1) throw new Error("only " + datalength + " bytes available! programmer error!");
                // TODO: Use mozResponseArrayBuffer, responseStream, etc. if available.
                var xhr = new XMLHttpRequest();
                xhr.open('GET', url, false);
                if (datalength !== chunkSize) xhr.setRequestHeader("Range", "bytes=" + from + "-" + to);
                // Some hints to the browser that we want binary data.
                if (typeof Uint8Array != 'undefined') xhr.responseType = 'arraybuffer';
                if (xhr.overrideMimeType) {
                  xhr.overrideMimeType('text/plain; charset=x-user-defined');
                }
                xhr.send(null);
                if (!(xhr.status >= 200 && xhr.status < 300 || xhr.status === 304)) throw new Error("Couldn't load " + url + ". Status: " + xhr.status);
                if (xhr.response !== undefined) {
                  return new Uint8Array(xhr.response || []);
                } else {
                  return intArrayFromString(xhr.responseText || '', true);
                }
              });
              var lazyArray = this;
              lazyArray.setDataGetter(function(chunkNum) {
                var start = chunkNum * chunkSize;
                var end = (chunkNum+1) * chunkSize - 1; // including this byte
                end = Math.min(end, datalength-1); // if datalength-1 is selected, this is the last block
                if (typeof(lazyArray.chunks[chunkNum]) === "undefined") {
                  lazyArray.chunks[chunkNum] = doXHR(start, end);
                }
                if (typeof(lazyArray.chunks[chunkNum]) === "undefined") throw new Error("doXHR failed!");
                return lazyArray.chunks[chunkNum];
              });
              this._length = datalength;
              this._chunkSize = chunkSize;
              this.lengthKnown = true;
          }
          var lazyArray = new LazyUint8Array();
          Object.defineProperty(lazyArray, "length", {
              get: function() {
                  if(!this.lengthKnown) {
                      this.cacheLength();
                  }
                  return this._length;
              }
          });
          Object.defineProperty(lazyArray, "chunkSize", {
              get: function() {
                  if(!this.lengthKnown) {
                      this.cacheLength();
                  }
                  return this._chunkSize;
              }
          });
          var properties = { isDevice: false, contents: lazyArray };
        } else {
          var properties = { isDevice: false, url: url };
        }
        var node = FS.createFile(parent, name, properties, canRead, canWrite);
        // This is a total hack, but I want to get this lazy file code out of the
        // core of MEMFS. If we want to keep this lazy file concept I feel it should
        // be its own thin LAZYFS proxying calls to MEMFS.
        if (properties.contents) {
          node.contents = properties.contents;
        } else if (properties.url) {
          node.contents = null;
          node.url = properties.url;
        }
        // override each stream op with one that tries to force load the lazy file first
        var stream_ops = {};
        var keys = Object.keys(node.stream_ops);
        keys.forEach(function(key) {
          var fn = node.stream_ops[key];
          stream_ops[key] = function forceLoadLazyFile() {
            if (!FS.forceLoadFile(node)) {
              throw new FS.ErrnoError(ERRNO_CODES.EIO);
            }
            return fn.apply(null, arguments);
          };
        });
        // use a custom read function
        stream_ops.read = function stream_ops_read(stream, buffer, offset, length, position) {
          if (!FS.forceLoadFile(node)) {
            throw new FS.ErrnoError(ERRNO_CODES.EIO);
          }
          var contents = stream.node.contents;
          if (position >= contents.length)
            return 0;
          var size = Math.min(contents.length - position, length);
          assert(size >= 0);
          if (contents.slice) { // normal array
            for (var i = 0; i < size; i++) {
              buffer[offset + i] = contents[position + i];
            }
          } else {
            for (var i = 0; i < size; i++) { // LazyUint8Array from sync binary XHR
              buffer[offset + i] = contents.get(position + i);
            }
          }
          return size;
        };
        node.stream_ops = stream_ops;
        return node;
      },createPreloadedFile:function (parent, name, url, canRead, canWrite, onload, onerror, dontCreateFile, canOwn) {
        Browser.init();
        // TODO we should allow people to just pass in a complete filename instead
        // of parent and name being that we just join them anyways
        var fullname = name ? PATH.resolve(PATH.join2(parent, name)) : parent;
        function processData(byteArray) {
          function finish(byteArray) {
            if (!dontCreateFile) {
              FS.createDataFile(parent, name, byteArray, canRead, canWrite, canOwn);
            }
            if (onload) onload();
            removeRunDependency('cp ' + fullname);
          }
          var handled = false;
          Module['preloadPlugins'].forEach(function(plugin) {
            if (handled) return;
            if (plugin['canHandle'](fullname)) {
              plugin['handle'](byteArray, fullname, finish, function() {
                if (onerror) onerror();
                removeRunDependency('cp ' + fullname);
              });
              handled = true;
            }
          });
          if (!handled) finish(byteArray);
        }
        addRunDependency('cp ' + fullname);
        if (typeof url == 'string') {
          Browser.asyncLoad(url, function(byteArray) {
            processData(byteArray);
          }, onerror);
        } else {
          processData(url);
        }
      },indexedDB:function () {
        return window.indexedDB || window.mozIndexedDB || window.webkitIndexedDB || window.msIndexedDB;
      },DB_NAME:function () {
        return 'EM_FS_' + window.location.pathname;
      },DB_VERSION:20,DB_STORE_NAME:"FILE_DATA",saveFilesToDB:function (paths, onload, onerror) {
        onload = onload || function(){};
        onerror = onerror || function(){};
        var indexedDB = FS.indexedDB();
        try {
          var openRequest = indexedDB.open(FS.DB_NAME(), FS.DB_VERSION);
        } catch (e) {
          return onerror(e);
        }
        openRequest.onupgradeneeded = function openRequest_onupgradeneeded() {
          console.log('creating db');
          var db = openRequest.result;
          db.createObjectStore(FS.DB_STORE_NAME);
        };
        openRequest.onsuccess = function openRequest_onsuccess() {
          var db = openRequest.result;
          var transaction = db.transaction([FS.DB_STORE_NAME], 'readwrite');
          var files = transaction.objectStore(FS.DB_STORE_NAME);
          var ok = 0, fail = 0, total = paths.length;
          function finish() {
            if (fail == 0) onload(); else onerror();
          }
          paths.forEach(function(path) {
            var putRequest = files.put(FS.analyzePath(path).object.contents, path);
            putRequest.onsuccess = function putRequest_onsuccess() { ok++; if (ok + fail == total) finish() };
            putRequest.onerror = function putRequest_onerror() { fail++; if (ok + fail == total) finish() };
          });
          transaction.onerror = onerror;
        };
        openRequest.onerror = onerror;
      },loadFilesFromDB:function (paths, onload, onerror) {
        onload = onload || function(){};
        onerror = onerror || function(){};
        var indexedDB = FS.indexedDB();
        try {
          var openRequest = indexedDB.open(FS.DB_NAME(), FS.DB_VERSION);
        } catch (e) {
          return onerror(e);
        }
        openRequest.onupgradeneeded = onerror; // no database to load from
        openRequest.onsuccess = function openRequest_onsuccess() {
          var db = openRequest.result;
          try {
            var transaction = db.transaction([FS.DB_STORE_NAME], 'readonly');
          } catch(e) {
            onerror(e);
            return;
          }
          var files = transaction.objectStore(FS.DB_STORE_NAME);
          var ok = 0, fail = 0, total = paths.length;
          function finish() {
            if (fail == 0) onload(); else onerror();
          }
          paths.forEach(function(path) {
            var getRequest = files.get(path);
            getRequest.onsuccess = function getRequest_onsuccess() {
              if (FS.analyzePath(path).exists) {
                FS.unlink(path);
              }
              FS.createDataFile(PATH.dirname(path), PATH.basename(path), getRequest.result, true, true, true);
              ok++;
              if (ok + fail == total) finish();
            };
            getRequest.onerror = function getRequest_onerror() { fail++; if (ok + fail == total) finish() };
          });
          transaction.onerror = onerror;
        };
        openRequest.onerror = onerror;
      }};function _fflush(stream) {
      // int fflush(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fflush.html
      // we don't currently perform any user-space buffering of data
    }
  function __exit(status) {
      // void _exit(int status);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/exit.html
      Module.print('exit(' + status + ') called');
      Module['exit'](status);
    }function _exit(status) {
      __exit(status);
    }
  var SOCKFS={mount:function (mount) {
        return FS.createNode(null, '/', 16384 | 0777, 0);
      },createSocket:function (family, type, protocol) {
        var streaming = type == 1;
        if (protocol) {
          assert(streaming == (protocol == 6)); // if SOCK_STREAM, must be tcp
        }
        // create our internal socket structure
        var sock = {
          family: family,
          type: type,
          protocol: protocol,
          server: null,
          peers: {},
          pending: [],
          recv_queue: [],
          sock_ops: SOCKFS.websocket_sock_ops
        };
        // create the filesystem node to store the socket structure
        var name = SOCKFS.nextname();
        var node = FS.createNode(SOCKFS.root, name, 49152, 0);
        node.sock = sock;
        // and the wrapping stream that enables library functions such
        // as read and write to indirectly interact with the socket
        var stream = FS.createStream({
          path: name,
          node: node,
          flags: FS.modeStringToFlags('r+'),
          seekable: false,
          stream_ops: SOCKFS.stream_ops
        });
        // map the new stream to the socket structure (sockets have a 1:1
        // relationship with a stream)
        sock.stream = stream;
        return sock;
      },getSocket:function (fd) {
        var stream = FS.getStream(fd);
        if (!stream || !FS.isSocket(stream.node.mode)) {
          return null;
        }
        return stream.node.sock;
      },stream_ops:{poll:function (stream) {
          var sock = stream.node.sock;
          return sock.sock_ops.poll(sock);
        },ioctl:function (stream, request, varargs) {
          var sock = stream.node.sock;
          return sock.sock_ops.ioctl(sock, request, varargs);
        },read:function (stream, buffer, offset, length, position /* ignored */) {
          var sock = stream.node.sock;
          var msg = sock.sock_ops.recvmsg(sock, length);
          if (!msg) {
            // socket is closed
            return 0;
          }
          buffer.set(msg.buffer, offset);
          return msg.buffer.length;
        },write:function (stream, buffer, offset, length, position /* ignored */) {
          var sock = stream.node.sock;
          return sock.sock_ops.sendmsg(sock, buffer, offset, length);
        },close:function (stream) {
          var sock = stream.node.sock;
          sock.sock_ops.close(sock);
        }},nextname:function () {
        if (!SOCKFS.nextname.current) {
          SOCKFS.nextname.current = 0;
        }
        return 'socket[' + (SOCKFS.nextname.current++) + ']';
      },websocket_sock_ops:{createPeer:function (sock, addr, port) {
          var ws;
          if (typeof addr === 'object') {
            ws = addr;
            addr = null;
            port = null;
          }
          if (ws) {
            // for sockets that've already connected (e.g. we're the server)
            // we can inspect the _socket property for the address
            if (ws._socket) {
              addr = ws._socket.remoteAddress;
              port = ws._socket.remotePort;
            }
            // if we're just now initializing a connection to the remote,
            // inspect the url property
            else {
              var result = /ws[s]?:\/\/([^:]+):(\d+)/.exec(ws.url);
              if (!result) {
                throw new Error('WebSocket URL must be in the format ws(s)://address:port');
              }
              addr = result[1];
              port = parseInt(result[2], 10);
            }
          } else {
            // create the actual websocket object and connect
            try {
              var url = 'ws://' + addr + ':' + port;
              // the node ws library API is slightly different than the browser's
              var opts = ENVIRONMENT_IS_NODE ? {headers: {'websocket-protocol': ['binary']}} : ['binary'];
              // If node we use the ws library.
              var WebSocket = ENVIRONMENT_IS_NODE ? require('ws') : window['WebSocket'];
              ws = new WebSocket(url, opts);
              ws.binaryType = 'arraybuffer';
            } catch (e) {
              throw new FS.ErrnoError(ERRNO_CODES.EHOSTUNREACH);
            }
          }
          var peer = {
            addr: addr,
            port: port,
            socket: ws,
            dgram_send_queue: []
          };
          SOCKFS.websocket_sock_ops.addPeer(sock, peer);
          SOCKFS.websocket_sock_ops.handlePeerEvents(sock, peer);
          // if this is a bound dgram socket, send the port number first to allow
          // us to override the ephemeral port reported to us by remotePort on the
          // remote end.
          if (sock.type === 2 && typeof sock.sport !== 'undefined') {
            peer.dgram_send_queue.push(new Uint8Array([
                255, 255, 255, 255,
                'p'.charCodeAt(0), 'o'.charCodeAt(0), 'r'.charCodeAt(0), 't'.charCodeAt(0),
                ((sock.sport & 0xff00) >> 8) , (sock.sport & 0xff)
            ]));
          }
          return peer;
        },getPeer:function (sock, addr, port) {
          return sock.peers[addr + ':' + port];
        },addPeer:function (sock, peer) {
          sock.peers[peer.addr + ':' + peer.port] = peer;
        },removePeer:function (sock, peer) {
          delete sock.peers[peer.addr + ':' + peer.port];
        },handlePeerEvents:function (sock, peer) {
          var first = true;
          var handleOpen = function () {
            try {
              var queued = peer.dgram_send_queue.shift();
              while (queued) {
                peer.socket.send(queued);
                queued = peer.dgram_send_queue.shift();
              }
            } catch (e) {
              // not much we can do here in the way of proper error handling as we've already
              // lied and said this data was sent. shut it down.
              peer.socket.close();
            }
          };
          function handleMessage(data) {
            assert(typeof data !== 'string' && data.byteLength !== undefined);  // must receive an ArrayBuffer
            data = new Uint8Array(data);  // make a typed array view on the array buffer
            // if this is the port message, override the peer's port with it
            var wasfirst = first;
            first = false;
            if (wasfirst &&
                data.length === 10 &&
                data[0] === 255 && data[1] === 255 && data[2] === 255 && data[3] === 255 &&
                data[4] === 'p'.charCodeAt(0) && data[5] === 'o'.charCodeAt(0) && data[6] === 'r'.charCodeAt(0) && data[7] === 't'.charCodeAt(0)) {
              // update the peer's port and it's key in the peer map
              var newport = ((data[8] << 8) | data[9]);
              SOCKFS.websocket_sock_ops.removePeer(sock, peer);
              peer.port = newport;
              SOCKFS.websocket_sock_ops.addPeer(sock, peer);
              return;
            }
            sock.recv_queue.push({ addr: peer.addr, port: peer.port, data: data });
          };
          if (ENVIRONMENT_IS_NODE) {
            peer.socket.on('open', handleOpen);
            peer.socket.on('message', function(data, flags) {
              if (!flags.binary) {
                return;
              }
              handleMessage((new Uint8Array(data)).buffer);  // copy from node Buffer -> ArrayBuffer
            });
            peer.socket.on('error', function() {
              // don't throw
            });
          } else {
            peer.socket.onopen = handleOpen;
            peer.socket.onmessage = function peer_socket_onmessage(event) {
              handleMessage(event.data);
            };
          }
        },poll:function (sock) {
          if (sock.type === 1 && sock.server) {
            // listen sockets should only say they're available for reading
            // if there are pending clients.
            return sock.pending.length ? (64 | 1) : 0;
          }
          var mask = 0;
          var dest = sock.type === 1 ?  // we only care about the socket state for connection-based sockets
            SOCKFS.websocket_sock_ops.getPeer(sock, sock.daddr, sock.dport) :
            null;
          if (sock.recv_queue.length ||
              !dest ||  // connection-less sockets are always ready to read
              (dest && dest.socket.readyState === dest.socket.CLOSING) ||
              (dest && dest.socket.readyState === dest.socket.CLOSED)) {  // let recv return 0 once closed
            mask |= (64 | 1);
          }
          if (!dest ||  // connection-less sockets are always ready to write
              (dest && dest.socket.readyState === dest.socket.OPEN)) {
            mask |= 4;
          }
          if ((dest && dest.socket.readyState === dest.socket.CLOSING) ||
              (dest && dest.socket.readyState === dest.socket.CLOSED)) {
            mask |= 16;
          }
          return mask;
        },ioctl:function (sock, request, arg) {
          switch (request) {
            case 21531:
              var bytes = 0;
              if (sock.recv_queue.length) {
                bytes = sock.recv_queue[0].data.length;
              }
              HEAP32[((arg)>>2)]=bytes;
              return 0;
            default:
              return ERRNO_CODES.EINVAL;
          }
        },close:function (sock) {
          // if we've spawned a listen server, close it
          if (sock.server) {
            try {
              sock.server.close();
            } catch (e) {
            }
            sock.server = null;
          }
          // close any peer connections
          var peers = Object.keys(sock.peers);
          for (var i = 0; i < peers.length; i++) {
            var peer = sock.peers[peers[i]];
            try {
              peer.socket.close();
            } catch (e) {
            }
            SOCKFS.websocket_sock_ops.removePeer(sock, peer);
          }
          return 0;
        },bind:function (sock, addr, port) {
          if (typeof sock.saddr !== 'undefined' || typeof sock.sport !== 'undefined') {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);  // already bound
          }
          sock.saddr = addr;
          sock.sport = port || _mkport();
          // in order to emulate dgram sockets, we need to launch a listen server when
          // binding on a connection-less socket
          // note: this is only required on the server side
          if (sock.type === 2) {
            // close the existing server if it exists
            if (sock.server) {
              sock.server.close();
              sock.server = null;
            }
            // swallow error operation not supported error that occurs when binding in the
            // browser where this isn't supported
            try {
              sock.sock_ops.listen(sock, 0);
            } catch (e) {
              if (!(e instanceof FS.ErrnoError)) throw e;
              if (e.errno !== ERRNO_CODES.EOPNOTSUPP) throw e;
            }
          }
        },connect:function (sock, addr, port) {
          if (sock.server) {
            throw new FS.ErrnoError(ERRNO_CODS.EOPNOTSUPP);
          }
          // TODO autobind
          // if (!sock.addr && sock.type == 2) {
          // }
          // early out if we're already connected / in the middle of connecting
          if (typeof sock.daddr !== 'undefined' && typeof sock.dport !== 'undefined') {
            var dest = SOCKFS.websocket_sock_ops.getPeer(sock, sock.daddr, sock.dport);
            if (dest) {
              if (dest.socket.readyState === dest.socket.CONNECTING) {
                throw new FS.ErrnoError(ERRNO_CODES.EALREADY);
              } else {
                throw new FS.ErrnoError(ERRNO_CODES.EISCONN);
              }
            }
          }
          // add the socket to our peer list and set our
          // destination address / port to match
          var peer = SOCKFS.websocket_sock_ops.createPeer(sock, addr, port);
          sock.daddr = peer.addr;
          sock.dport = peer.port;
          // always "fail" in non-blocking mode
          throw new FS.ErrnoError(ERRNO_CODES.EINPROGRESS);
        },listen:function (sock, backlog) {
          if (!ENVIRONMENT_IS_NODE) {
            throw new FS.ErrnoError(ERRNO_CODES.EOPNOTSUPP);
          }
          if (sock.server) {
             throw new FS.ErrnoError(ERRNO_CODES.EINVAL);  // already listening
          }
          var WebSocketServer = require('ws').Server;
          var host = sock.saddr;
          sock.server = new WebSocketServer({
            host: host,
            port: sock.sport
            // TODO support backlog
          });
          sock.server.on('connection', function(ws) {
            if (sock.type === 1) {
              var newsock = SOCKFS.createSocket(sock.family, sock.type, sock.protocol);
              // create a peer on the new socket
              var peer = SOCKFS.websocket_sock_ops.createPeer(newsock, ws);
              newsock.daddr = peer.addr;
              newsock.dport = peer.port;
              // push to queue for accept to pick up
              sock.pending.push(newsock);
            } else {
              // create a peer on the listen socket so calling sendto
              // with the listen socket and an address will resolve
              // to the correct client
              SOCKFS.websocket_sock_ops.createPeer(sock, ws);
            }
          });
          sock.server.on('closed', function() {
            sock.server = null;
          });
          sock.server.on('error', function() {
            // don't throw
          });
        },accept:function (listensock) {
          if (!listensock.server) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
          var newsock = listensock.pending.shift();
          newsock.stream.flags = listensock.stream.flags;
          return newsock;
        },getname:function (sock, peer) {
          var addr, port;
          if (peer) {
            if (sock.daddr === undefined || sock.dport === undefined) {
              throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN);
            }
            addr = sock.daddr;
            port = sock.dport;
          } else {
            // TODO saddr and sport will be set for bind()'d UDP sockets, but what
            // should we be returning for TCP sockets that've been connect()'d?
            addr = sock.saddr || 0;
            port = sock.sport || 0;
          }
          return { addr: addr, port: port };
        },sendmsg:function (sock, buffer, offset, length, addr, port) {
          if (sock.type === 2) {
            // connection-less sockets will honor the message address,
            // and otherwise fall back to the bound destination address
            if (addr === undefined || port === undefined) {
              addr = sock.daddr;
              port = sock.dport;
            }
            // if there was no address to fall back to, error out
            if (addr === undefined || port === undefined) {
              throw new FS.ErrnoError(ERRNO_CODES.EDESTADDRREQ);
            }
          } else {
            // connection-based sockets will only use the bound
            addr = sock.daddr;
            port = sock.dport;
          }
          // find the peer for the destination address
          var dest = SOCKFS.websocket_sock_ops.getPeer(sock, addr, port);
          // early out if not connected with a connection-based socket
          if (sock.type === 1) {
            if (!dest || dest.socket.readyState === dest.socket.CLOSING || dest.socket.readyState === dest.socket.CLOSED) {
              throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN);
            } else if (dest.socket.readyState === dest.socket.CONNECTING) {
              throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
            }
          }
          // create a copy of the incoming data to send, as the WebSocket API
          // doesn't work entirely with an ArrayBufferView, it'll just send
          // the entire underlying buffer
          var data;
          if (buffer instanceof Array || buffer instanceof ArrayBuffer) {
            data = buffer.slice(offset, offset + length);
          } else {  // ArrayBufferView
            data = buffer.buffer.slice(buffer.byteOffset + offset, buffer.byteOffset + offset + length);
          }
          // if we're emulating a connection-less dgram socket and don't have
          // a cached connection, queue the buffer to send upon connect and
          // lie, saying the data was sent now.
          if (sock.type === 2) {
            if (!dest || dest.socket.readyState !== dest.socket.OPEN) {
              // if we're not connected, open a new connection
              if (!dest || dest.socket.readyState === dest.socket.CLOSING || dest.socket.readyState === dest.socket.CLOSED) {
                dest = SOCKFS.websocket_sock_ops.createPeer(sock, addr, port);
              }
              dest.dgram_send_queue.push(data);
              return length;
            }
          }
          try {
            // send the actual data
            dest.socket.send(data);
            return length;
          } catch (e) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
        },recvmsg:function (sock, length) {
          // http://pubs.opengroup.org/onlinepubs/7908799/xns/recvmsg.html
          if (sock.type === 1 && sock.server) {
            // tcp servers should not be recv()'ing on the listen socket
            throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN);
          }
          var queued = sock.recv_queue.shift();
          if (!queued) {
            if (sock.type === 1) {
              var dest = SOCKFS.websocket_sock_ops.getPeer(sock, sock.daddr, sock.dport);
              if (!dest) {
                // if we have a destination address but are not connected, error out
                throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN);
              }
              else if (dest.socket.readyState === dest.socket.CLOSING || dest.socket.readyState === dest.socket.CLOSED) {
                // return null if the socket has closed
                return null;
              }
              else {
                // else, our socket is in a valid state but truly has nothing available
                throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
              }
            } else {
              throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
            }
          }
          // queued.data will be an ArrayBuffer if it's unadulterated, but if it's
          // requeued TCP data it'll be an ArrayBufferView
          var queuedLength = queued.data.byteLength || queued.data.length;
          var queuedOffset = queued.data.byteOffset || 0;
          var queuedBuffer = queued.data.buffer || queued.data;
          var bytesRead = Math.min(length, queuedLength);
          var res = {
            buffer: new Uint8Array(queuedBuffer, queuedOffset, bytesRead),
            addr: queued.addr,
            port: queued.port
          };
          // push back any unread data for TCP connections
          if (sock.type === 1 && bytesRead < queuedLength) {
            var bytesRemaining = queuedLength - bytesRead;
            queued.data = new Uint8Array(queuedBuffer, queuedOffset + bytesRead, bytesRemaining);
            sock.recv_queue.unshift(queued);
          }
          return res;
        }}};function _send(fd, buf, len, flags) {
      var sock = SOCKFS.getSocket(fd);
      if (!sock) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      // TODO honor flags
      return _write(fd, buf, len);
    }
  function _pwrite(fildes, buf, nbyte, offset) {
      // ssize_t pwrite(int fildes, const void *buf, size_t nbyte, off_t offset);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/write.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      try {
        var slab = HEAP8;
        return FS.write(stream, slab, buf, nbyte, offset);
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _write(fildes, buf, nbyte) {
      // ssize_t write(int fildes, const void *buf, size_t nbyte);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/write.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      try {
        var slab = HEAP8;
        return FS.write(stream, slab, buf, nbyte);
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _fwrite(ptr, size, nitems, stream) {
      // size_t fwrite(const void *restrict ptr, size_t size, size_t nitems, FILE *restrict stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fwrite.html
      var bytesToWrite = nitems * size;
      if (bytesToWrite == 0) return 0;
      var bytesWritten = _write(stream, ptr, bytesToWrite);
      if (bytesWritten == -1) {
        var streamObj = FS.getStream(stream);
        if (streamObj) streamObj.error = true;
        return 0;
      } else {
        return Math.floor(bytesWritten / size);
      }
    }
  Module["_strlen"] = _strlen;
  function __reallyNegative(x) {
      return x < 0 || (x === 0 && (1/x) === -Infinity);
    }function __formatString(format, varargs) {
      var textIndex = format;
      var argIndex = 0;
      function getNextArg(type) {
        // NOTE: Explicitly ignoring type safety. Otherwise this fails:
        //       int x = 4; printf("%c\n", (char)x);
        var ret;
        if (type === 'double') {
          ret = HEAPF64[(((varargs)+(argIndex))>>3)];
        } else if (type == 'i64') {
          ret = [HEAP32[(((varargs)+(argIndex))>>2)],
                 HEAP32[(((varargs)+(argIndex+8))>>2)]];
          argIndex += 8; // each 32-bit chunk is in a 64-bit block
        } else {
          type = 'i32'; // varargs are always i32, i64, or double
          ret = HEAP32[(((varargs)+(argIndex))>>2)];
        }
        argIndex += Math.max(Runtime.getNativeFieldSize(type), Runtime.getAlignSize(type, null, true));
        return ret;
      }
      var ret = [];
      var curr, next, currArg;
      while(1) {
        var startTextIndex = textIndex;
        curr = HEAP8[(textIndex)];
        if (curr === 0) break;
        next = HEAP8[((textIndex+1)|0)];
        if (curr == 37) {
          // Handle flags.
          var flagAlwaysSigned = false;
          var flagLeftAlign = false;
          var flagAlternative = false;
          var flagZeroPad = false;
          var flagPadSign = false;
          flagsLoop: while (1) {
            switch (next) {
              case 43:
                flagAlwaysSigned = true;
                break;
              case 45:
                flagLeftAlign = true;
                break;
              case 35:
                flagAlternative = true;
                break;
              case 48:
                if (flagZeroPad) {
                  break flagsLoop;
                } else {
                  flagZeroPad = true;
                  break;
                }
              case 32:
                flagPadSign = true;
                break;
              default:
                break flagsLoop;
            }
            textIndex++;
            next = HEAP8[((textIndex+1)|0)];
          }
          // Handle width.
          var width = 0;
          if (next == 42) {
            width = getNextArg('i32');
            textIndex++;
            next = HEAP8[((textIndex+1)|0)];
          } else {
            while (next >= 48 && next <= 57) {
              width = width * 10 + (next - 48);
              textIndex++;
              next = HEAP8[((textIndex+1)|0)];
            }
          }
          // Handle precision.
          var precisionSet = false;
          if (next == 46) {
            var precision = 0;
            precisionSet = true;
            textIndex++;
            next = HEAP8[((textIndex+1)|0)];
            if (next == 42) {
              precision = getNextArg('i32');
              textIndex++;
            } else {
              while(1) {
                var precisionChr = HEAP8[((textIndex+1)|0)];
                if (precisionChr < 48 ||
                    precisionChr > 57) break;
                precision = precision * 10 + (precisionChr - 48);
                textIndex++;
              }
            }
            next = HEAP8[((textIndex+1)|0)];
          } else {
            var precision = 6; // Standard default.
          }
          // Handle integer sizes. WARNING: These assume a 32-bit architecture!
          var argSize;
          switch (String.fromCharCode(next)) {
            case 'h':
              var nextNext = HEAP8[((textIndex+2)|0)];
              if (nextNext == 104) {
                textIndex++;
                argSize = 1; // char (actually i32 in varargs)
              } else {
                argSize = 2; // short (actually i32 in varargs)
              }
              break;
            case 'l':
              var nextNext = HEAP8[((textIndex+2)|0)];
              if (nextNext == 108) {
                textIndex++;
                argSize = 8; // long long
              } else {
                argSize = 4; // long
              }
              break;
            case 'L': // long long
            case 'q': // int64_t
            case 'j': // intmax_t
              argSize = 8;
              break;
            case 'z': // size_t
            case 't': // ptrdiff_t
            case 'I': // signed ptrdiff_t or unsigned size_t
              argSize = 4;
              break;
            default:
              argSize = null;
          }
          if (argSize) textIndex++;
          next = HEAP8[((textIndex+1)|0)];
          // Handle type specifier.
          switch (String.fromCharCode(next)) {
            case 'd': case 'i': case 'u': case 'o': case 'x': case 'X': case 'p': {
              // Integer.
              var signed = next == 100 || next == 105;
              argSize = argSize || 4;
              var currArg = getNextArg('i' + (argSize * 8));
              var origArg = currArg;
              var argText;
              // Flatten i64-1 [low, high] into a (slightly rounded) double
              if (argSize == 8) {
                currArg = Runtime.makeBigInt(currArg[0], currArg[1], next == 117);
              }
              // Truncate to requested size.
              if (argSize <= 4) {
                var limit = Math.pow(256, argSize) - 1;
                currArg = (signed ? reSign : unSign)(currArg & limit, argSize * 8);
              }
              // Format the number.
              var currAbsArg = Math.abs(currArg);
              var prefix = '';
              if (next == 100 || next == 105) {
                if (argSize == 8 && i64Math) argText = i64Math.stringify(origArg[0], origArg[1], null); else
                argText = reSign(currArg, 8 * argSize, 1).toString(10);
              } else if (next == 117) {
                if (argSize == 8 && i64Math) argText = i64Math.stringify(origArg[0], origArg[1], true); else
                argText = unSign(currArg, 8 * argSize, 1).toString(10);
                currArg = Math.abs(currArg);
              } else if (next == 111) {
                argText = (flagAlternative ? '0' : '') + currAbsArg.toString(8);
              } else if (next == 120 || next == 88) {
                prefix = (flagAlternative && currArg != 0) ? '0x' : '';
                if (argSize == 8 && i64Math) {
                  if (origArg[1]) {
                    argText = (origArg[1]>>>0).toString(16);
                    var lower = (origArg[0]>>>0).toString(16);
                    while (lower.length < 8) lower = '0' + lower;
                    argText += lower;
                  } else {
                    argText = (origArg[0]>>>0).toString(16);
                  }
                } else
                if (currArg < 0) {
                  // Represent negative numbers in hex as 2's complement.
                  currArg = -currArg;
                  argText = (currAbsArg - 1).toString(16);
                  var buffer = [];
                  for (var i = 0; i < argText.length; i++) {
                    buffer.push((0xF - parseInt(argText[i], 16)).toString(16));
                  }
                  argText = buffer.join('');
                  while (argText.length < argSize * 2) argText = 'f' + argText;
                } else {
                  argText = currAbsArg.toString(16);
                }
                if (next == 88) {
                  prefix = prefix.toUpperCase();
                  argText = argText.toUpperCase();
                }
              } else if (next == 112) {
                if (currAbsArg === 0) {
                  argText = '(nil)';
                } else {
                  prefix = '0x';
                  argText = currAbsArg.toString(16);
                }
              }
              if (precisionSet) {
                while (argText.length < precision) {
                  argText = '0' + argText;
                }
              }
              // Add sign if needed
              if (currArg >= 0) {
                if (flagAlwaysSigned) {
                  prefix = '+' + prefix;
                } else if (flagPadSign) {
                  prefix = ' ' + prefix;
                }
              }
              // Move sign to prefix so we zero-pad after the sign
              if (argText.charAt(0) == '-') {
                prefix = '-' + prefix;
                argText = argText.substr(1);
              }
              // Add padding.
              while (prefix.length + argText.length < width) {
                if (flagLeftAlign) {
                  argText += ' ';
                } else {
                  if (flagZeroPad) {
                    argText = '0' + argText;
                  } else {
                    prefix = ' ' + prefix;
                  }
                }
              }
              // Insert the result into the buffer.
              argText = prefix + argText;
              argText.split('').forEach(function(chr) {
                ret.push(chr.charCodeAt(0));
              });
              break;
            }
            case 'f': case 'F': case 'e': case 'E': case 'g': case 'G': {
              // Float.
              var currArg = getNextArg('double');
              var argText;
              if (isNaN(currArg)) {
                argText = 'nan';
                flagZeroPad = false;
              } else if (!isFinite(currArg)) {
                argText = (currArg < 0 ? '-' : '') + 'inf';
                flagZeroPad = false;
              } else {
                var isGeneral = false;
                var effectivePrecision = Math.min(precision, 20);
                // Convert g/G to f/F or e/E, as per:
                // http://pubs.opengroup.org/onlinepubs/9699919799/functions/printf.html
                if (next == 103 || next == 71) {
                  isGeneral = true;
                  precision = precision || 1;
                  var exponent = parseInt(currArg.toExponential(effectivePrecision).split('e')[1], 10);
                  if (precision > exponent && exponent >= -4) {
                    next = ((next == 103) ? 'f' : 'F').charCodeAt(0);
                    precision -= exponent + 1;
                  } else {
                    next = ((next == 103) ? 'e' : 'E').charCodeAt(0);
                    precision--;
                  }
                  effectivePrecision = Math.min(precision, 20);
                }
                if (next == 101 || next == 69) {
                  argText = currArg.toExponential(effectivePrecision);
                  // Make sure the exponent has at least 2 digits.
                  if (/[eE][-+]\d$/.test(argText)) {
                    argText = argText.slice(0, -1) + '0' + argText.slice(-1);
                  }
                } else if (next == 102 || next == 70) {
                  argText = currArg.toFixed(effectivePrecision);
                  if (currArg === 0 && __reallyNegative(currArg)) {
                    argText = '-' + argText;
                  }
                }
                var parts = argText.split('e');
                if (isGeneral && !flagAlternative) {
                  // Discard trailing zeros and periods.
                  while (parts[0].length > 1 && parts[0].indexOf('.') != -1 &&
                         (parts[0].slice(-1) == '0' || parts[0].slice(-1) == '.')) {
                    parts[0] = parts[0].slice(0, -1);
                  }
                } else {
                  // Make sure we have a period in alternative mode.
                  if (flagAlternative && argText.indexOf('.') == -1) parts[0] += '.';
                  // Zero pad until required precision.
                  while (precision > effectivePrecision++) parts[0] += '0';
                }
                argText = parts[0] + (parts.length > 1 ? 'e' + parts[1] : '');
                // Capitalize 'E' if needed.
                if (next == 69) argText = argText.toUpperCase();
                // Add sign.
                if (currArg >= 0) {
                  if (flagAlwaysSigned) {
                    argText = '+' + argText;
                  } else if (flagPadSign) {
                    argText = ' ' + argText;
                  }
                }
              }
              // Add padding.
              while (argText.length < width) {
                if (flagLeftAlign) {
                  argText += ' ';
                } else {
                  if (flagZeroPad && (argText[0] == '-' || argText[0] == '+')) {
                    argText = argText[0] + '0' + argText.slice(1);
                  } else {
                    argText = (flagZeroPad ? '0' : ' ') + argText;
                  }
                }
              }
              // Adjust case.
              if (next < 97) argText = argText.toUpperCase();
              // Insert the result into the buffer.
              argText.split('').forEach(function(chr) {
                ret.push(chr.charCodeAt(0));
              });
              break;
            }
            case 's': {
              // String.
              var arg = getNextArg('i8*');
              var argLength = arg ? _strlen(arg) : '(null)'.length;
              if (precisionSet) argLength = Math.min(argLength, precision);
              if (!flagLeftAlign) {
                while (argLength < width--) {
                  ret.push(32);
                }
              }
              if (arg) {
                for (var i = 0; i < argLength; i++) {
                  ret.push(HEAPU8[((arg++)|0)]);
                }
              } else {
                ret = ret.concat(intArrayFromString('(null)'.substr(0, argLength), true));
              }
              if (flagLeftAlign) {
                while (argLength < width--) {
                  ret.push(32);
                }
              }
              break;
            }
            case 'c': {
              // Character.
              if (flagLeftAlign) ret.push(getNextArg('i8'));
              while (--width > 0) {
                ret.push(32);
              }
              if (!flagLeftAlign) ret.push(getNextArg('i8'));
              break;
            }
            case 'n': {
              // Write the length written so far to the next parameter.
              var ptr = getNextArg('i32*');
              HEAP32[((ptr)>>2)]=ret.length
              break;
            }
            case '%': {
              // Literal percent sign.
              ret.push(curr);
              break;
            }
            default: {
              // Unknown specifiers remain untouched.
              for (var i = startTextIndex; i < textIndex + 2; i++) {
                ret.push(HEAP8[(i)]);
              }
            }
          }
          textIndex += 2;
          // TODO: Support a/A (hex float) and m (last error) specifiers.
          // TODO: Support %1${specifier} for arg selection.
        } else {
          ret.push(curr);
          textIndex += 1;
        }
      }
      return ret;
    }function _fprintf(stream, format, varargs) {
      // int fprintf(FILE *restrict stream, const char *restrict format, ...);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/printf.html
      var result = __formatString(format, varargs);
      var stack = Runtime.stackSave();
      var ret = _fwrite(allocate(result, 'i8', ALLOC_STACK), 1, result.length, stream);
      Runtime.stackRestore(stack);
      return ret;
    }
  function _snprintf(s, n, format, varargs) {
      // int snprintf(char *restrict s, size_t n, const char *restrict format, ...);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/printf.html
      var result = __formatString(format, varargs);
      var limit = (n === undefined) ? result.length
                                    : Math.min(result.length, Math.max(n - 1, 0));
      if (s < 0) {
        s = -s;
        var buf = _malloc(limit+1);
        HEAP32[((s)>>2)]=buf;
        s = buf;
      }
      for (var i = 0; i < limit; i++) {
        HEAP8[(((s)+(i))|0)]=result[i];
      }
      if (limit < n || (n === undefined)) HEAP8[(((s)+(i))|0)]=0;
      return result.length;
    }
  Module["_memset"] = _memset;var _llvm_memset_p0i8_i32=_memset;
  function _close(fildes) {
      // int close(int fildes);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/close.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      try {
        FS.close(stream);
        return 0;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }
  function _fsync(fildes) {
      // int fsync(int fildes);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fsync.html
      var stream = FS.getStream(fildes);
      if (stream) {
        // We write directly to the file system, so there's nothing to do here.
        return 0;
      } else {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
    }function _fclose(stream) {
      // int fclose(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fclose.html
      _fsync(stream);
      return _close(stream);
    }
  function _fputc(c, stream) {
      // int fputc(int c, FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fputc.html
      var chr = unSign(c & 0xFF);
      HEAP8[((_fputc.ret)|0)]=chr
      var ret = _write(stream, _fputc.ret, 1);
      if (ret == -1) {
        var streamObj = FS.getStream(stream);
        if (streamObj) streamObj.error = true;
        return -1;
      } else {
        return chr;
      }
    }function _putchar(c) {
      // int putchar(int c);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/putchar.html
      return _fputc(c, HEAP32[((_stdout)>>2)]);
    } 
  Module["_saveSetjmp"] = _saveSetjmp;
  Module["_testSetjmp"] = _testSetjmp;var _setjmp=undefined;
  function _unlink(path) {
      // int unlink(const char *path);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/unlink.html
      path = Pointer_stringify(path);
      try {
        FS.unlink(path);
        return 0;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }
  function _rmdir(path) {
      // int rmdir(const char *path);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/rmdir.html
      path = Pointer_stringify(path);
      try {
        FS.rmdir(path);
        return 0;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _remove(path) {
      // int remove(const char *path);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/remove.html
      var ret = _unlink(path);
      if (ret == -1) ret = _rmdir(path);
      return ret;
    }
  function _strdup(ptr) {
      var len = _strlen(ptr);
      var newStr = _malloc(len + 1);
      (_memcpy(newStr, ptr, len)|0);
      HEAP8[(((newStr)+(len))|0)]=0;
      return newStr;
    }
  Module["_memcpy"] = _memcpy;var _llvm_memcpy_p0i8_p0i8_i32=_memcpy;
  function _usleep(useconds) {
      // int usleep(useconds_t useconds);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/usleep.html
      // We're single-threaded, so use a busy loop. Super-ugly.
      var msec = useconds / 1000;
      if (ENVIRONMENT_IS_WEB && window['performance'] && window['performance']['now']) {
        var start = window['performance']['now']();
        while (window['performance']['now']() - start < msec) {
          // Do nothing.
        }
      } else {
        var start = Date.now();
        while (Date.now() - start < msec) {
          // Do nothing.
        }
      }
      return 0;
    }function _nanosleep(rqtp, rmtp) {
      // int nanosleep(const struct timespec  *rqtp, struct timespec *rmtp);
      var seconds = HEAP32[((rqtp)>>2)];
      var nanoseconds = HEAP32[(((rqtp)+(4))>>2)];
      if (rmtp !== 0) {
        HEAP32[((rmtp)>>2)]=0
        HEAP32[(((rmtp)+(4))>>2)]=0
      }
      return _usleep((seconds * 1e6) + (nanoseconds / 1000));
    }
  function _strrchr(ptr, chr) {
      var ptr2 = ptr + _strlen(ptr);
      do {
        if (HEAP8[(ptr2)] == chr) return ptr2;
        ptr2--;
      } while (ptr2 >= ptr);
      return 0;
    }
  function _strncmp(px, py, n) {
      var i = 0;
      while (i < n) {
        var x = HEAPU8[(((px)+(i))|0)];
        var y = HEAPU8[(((py)+(i))|0)];
        if (x == y && x == 0) return 0;
        if (x == 0) return -1;
        if (y == 0) return 1;
        if (x == y) {
          i ++;
          continue;
        } else {
          return x > y ? 1 : -1;
        }
      }
      return 0;
    }function _strcmp(px, py) {
      return _strncmp(px, py, TOTAL_MEMORY);
    }
  var _llvm_pow_f32=Math_pow;
  function _round(x) {
      return (x < 0) ? -Math.round(-x) : Math.round(x);
    }var _roundf=_round;
  function _longjmp(env, value) {
      asm['setThrew'](env, value || 1);
      throw 'longjmp';
    }
  function _isspace(chr) {
      return (chr == 32) || (chr >= 9 && chr <= 13);
    }function __parseInt(str, endptr, base, min, max, bits, unsign) {
      // Skip space.
      while (_isspace(HEAP8[(str)])) str++;
      // Check for a plus/minus sign.
      var multiplier = 1;
      if (HEAP8[(str)] == 45) {
        multiplier = -1;
        str++;
      } else if (HEAP8[(str)] == 43) {
        str++;
      }
      // Find base.
      var finalBase = base;
      if (!finalBase) {
        if (HEAP8[(str)] == 48) {
          if (HEAP8[((str+1)|0)] == 120 ||
              HEAP8[((str+1)|0)] == 88) {
            finalBase = 16;
            str += 2;
          } else {
            finalBase = 8;
            str++;
          }
        }
      } else if (finalBase==16) {
        if (HEAP8[(str)] == 48) {
          if (HEAP8[((str+1)|0)] == 120 ||
              HEAP8[((str+1)|0)] == 88) {
            str += 2;
          }
        }
      }
      if (!finalBase) finalBase = 10;
      // Get digits.
      var chr;
      var ret = 0;
      while ((chr = HEAP8[(str)]) != 0) {
        var digit = parseInt(String.fromCharCode(chr), finalBase);
        if (isNaN(digit)) {
          break;
        } else {
          ret = ret * finalBase + digit;
          str++;
        }
      }
      // Apply sign.
      ret *= multiplier;
      // Set end pointer.
      if (endptr) {
        HEAP32[((endptr)>>2)]=str
      }
      // Unsign if needed.
      if (unsign) {
        if (Math.abs(ret) > max) {
          ret = max;
          ___setErrNo(ERRNO_CODES.ERANGE);
        } else {
          ret = unSign(ret, bits);
        }
      }
      // Validate range.
      if (ret > max || ret < min) {
        ret = ret > max ? max : min;
        ___setErrNo(ERRNO_CODES.ERANGE);
      }
      if (bits == 64) {
        return ((asm["setTempRet0"]((tempDouble=ret,(+(Math_abs(tempDouble))) >= (+1) ? (tempDouble > (+0) ? ((Math_min((+(Math_floor((tempDouble)/(+4294967296)))), (+4294967295)))|0)>>>0 : (~~((+(Math_ceil((tempDouble - +(((~~(tempDouble)))>>>0))/(+4294967296))))))>>>0) : 0)),ret>>>0)|0);
      }
      return ret;
    }function _strtoul(str, endptr, base) {
      return __parseInt(str, endptr, base, 0, 4294967295, 32, true);  // ULONG_MAX.
    }
  function _strtol(str, endptr, base) {
      return __parseInt(str, endptr, base, -2147483648, 2147483647, 32);  // LONG_MIN, LONG_MAX.
    }
  function _fputs(s, stream) {
      // int fputs(const char *restrict s, FILE *restrict stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fputs.html
      return _write(stream, s, _strlen(s));
    }function _puts(s) {
      // int puts(const char *s);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/puts.html
      // NOTE: puts() always writes an extra newline.
      var stdout = HEAP32[((_stdout)>>2)];
      var ret = _fputs(s, stdout);
      if (ret < 0) {
        return ret;
      } else {
        var newlineRet = _fputc(10, stdout);
        return (newlineRet < 0) ? -1 : ret + 1;
      }
    }
  function _printf(format, varargs) {
      // int printf(const char *restrict format, ...);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/printf.html
      var stdout = HEAP32[((_stdout)>>2)];
      return _fprintf(stdout, format, varargs);
    }
  function _llvm_lifetime_start() {}
  function _llvm_lifetime_end() {}
  var _llvm_memset_p0i8_i64=_memset;
  Module["_tolower"] = _tolower; 
  Module["_strncasecmp"] = _strncasecmp; 
  Module["_strcasecmp"] = _strcasecmp;
  var _environ=allocate(1, "i32*", ALLOC_STATIC);var ___environ=_environ;function ___buildEnvironment(env) {
      // WARNING: Arbitrary limit!
      var MAX_ENV_VALUES = 64;
      var TOTAL_ENV_SIZE = 1024;
      // Statically allocate memory for the environment.
      var poolPtr;
      var envPtr;
      if (!___buildEnvironment.called) {
        ___buildEnvironment.called = true;
        // Set default values. Use string keys for Closure Compiler compatibility.
        ENV['USER'] = 'root';
        ENV['PATH'] = '/';
        ENV['PWD'] = '/';
        ENV['HOME'] = '/home/emscripten';
        ENV['LANG'] = 'en_US.UTF-8';
        ENV['_'] = './this.program';
        // Allocate memory.
        poolPtr = allocate(TOTAL_ENV_SIZE, 'i8', ALLOC_STATIC);
        envPtr = allocate(MAX_ENV_VALUES * 4,
                          'i8*', ALLOC_STATIC);
        HEAP32[((envPtr)>>2)]=poolPtr
        HEAP32[((_environ)>>2)]=envPtr;
      } else {
        envPtr = HEAP32[((_environ)>>2)];
        poolPtr = HEAP32[((envPtr)>>2)];
      }
      // Collect key=value lines.
      var strings = [];
      var totalSize = 0;
      for (var key in env) {
        if (typeof env[key] === 'string') {
          var line = key + '=' + env[key];
          strings.push(line);
          totalSize += line.length;
        }
      }
      if (totalSize > TOTAL_ENV_SIZE) {
        throw new Error('Environment size exceeded TOTAL_ENV_SIZE!');
      }
      // Make new.
      var ptrSize = 4;
      for (var i = 0; i < strings.length; i++) {
        var line = strings[i];
        for (var j = 0; j < line.length; j++) {
          HEAP8[(((poolPtr)+(j))|0)]=line.charCodeAt(j);
        }
        HEAP8[(((poolPtr)+(j))|0)]=0;
        HEAP32[(((envPtr)+(i * ptrSize))>>2)]=poolPtr;
        poolPtr += line.length + 1;
      }
      HEAP32[(((envPtr)+(strings.length * ptrSize))>>2)]=0;
    }var ENV={};function _getenv(name) {
      // char *getenv(const char *name);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/getenv.html
      if (name === 0) return 0;
      name = Pointer_stringify(name);
      if (!ENV.hasOwnProperty(name)) return 0;
      if (_getenv.ret) _free(_getenv.ret);
      _getenv.ret = allocate(intArrayFromString(ENV[name]), 'i8', ALLOC_NORMAL);
      return _getenv.ret;
    }
  function _time(ptr) {
      var ret = Math.floor(Date.now()/1000);
      if (ptr) {
        HEAP32[((ptr)>>2)]=ret
      }
      return ret;
    }
  function __isLeapYear(year) {
        return year%4 === 0 && (year%100 !== 0 || year%400 === 0);
    }
  function __arraySum(array, index) {
      var sum = 0;
      for (var i = 0; i <= index; sum += array[i++]);
      return sum;
    }
  var __MONTH_DAYS_LEAP=[31,29,31,30,31,30,31,31,30,31,30,31];
  var __MONTH_DAYS_REGULAR=[31,28,31,30,31,30,31,31,30,31,30,31];function __addDays(date, days) {
      var newDate = new Date(date.getTime());
      while(days > 0) {
        var leap = __isLeapYear(newDate.getFullYear());
        var currentMonth = newDate.getMonth();
        var daysInCurrentMonth = (leap ? __MONTH_DAYS_LEAP : __MONTH_DAYS_REGULAR)[currentMonth];
        if (days > daysInCurrentMonth-newDate.getDate()) {
          // we spill over to next month
          days -= (daysInCurrentMonth-newDate.getDate()+1);
          newDate.setDate(1);
          if (currentMonth < 11) {
            newDate.setMonth(currentMonth+1)
          } else {
            newDate.setMonth(0);
            newDate.setFullYear(newDate.getFullYear()+1);
          }
        } else {
          // we stay in current month 
          newDate.setDate(newDate.getDate()+days);
          return newDate;
        }
      }
      return newDate;
    }function _strftime(s, maxsize, format, tm) {
      // size_t strftime(char *restrict s, size_t maxsize, const char *restrict format, const struct tm *restrict timeptr);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/strftime.html
      var date = {
        tm_sec: HEAP32[((tm)>>2)],
        tm_min: HEAP32[(((tm)+(4))>>2)],
        tm_hour: HEAP32[(((tm)+(8))>>2)],
        tm_mday: HEAP32[(((tm)+(12))>>2)],
        tm_mon: HEAP32[(((tm)+(16))>>2)],
        tm_year: HEAP32[(((tm)+(20))>>2)],
        tm_wday: HEAP32[(((tm)+(24))>>2)],
        tm_yday: HEAP32[(((tm)+(28))>>2)],
        tm_isdst: HEAP32[(((tm)+(32))>>2)]
      };
      var pattern = Pointer_stringify(format);
      // expand format
      var EXPANSION_RULES_1 = {
        '%c': '%a %b %d %H:%M:%S %Y',     // Replaced by the locale's appropriate date and time representation - e.g., Mon Aug  3 14:02:01 2013
        '%D': '%m/%d/%y',                 // Equivalent to %m / %d / %y
        '%F': '%Y-%m-%d',                 // Equivalent to %Y - %m - %d
        '%h': '%b',                       // Equivalent to %b
        '%r': '%I:%M:%S %p',              // Replaced by the time in a.m. and p.m. notation
        '%R': '%H:%M',                    // Replaced by the time in 24-hour notation
        '%T': '%H:%M:%S',                 // Replaced by the time
        '%x': '%m/%d/%y',                 // Replaced by the locale's appropriate date representation
        '%X': '%H:%M:%S',                 // Replaced by the locale's appropriate date representation
      };
      for (var rule in EXPANSION_RULES_1) {
        pattern = pattern.replace(new RegExp(rule, 'g'), EXPANSION_RULES_1[rule]);
      }
      var WEEKDAYS = ['Sunday', 'Monday', 'Tuesday', 'Wednesday', 'Thursday', 'Friday', 'Saturday'];
      var MONTHS = ['January', 'February', 'March', 'April', 'May', 'June', 'July', 'August', 'September', 'October', 'November', 'December'];
      function leadingSomething(value, digits, character) {
        var str = typeof value === 'number' ? value.toString() : (value || '');
        while (str.length < digits) {
          str = character[0]+str;
        }
        return str;
      };
      function leadingNulls(value, digits) {
        return leadingSomething(value, digits, '0');
      };
      function compareByDay(date1, date2) {
        function sgn(value) {
          return value < 0 ? -1 : (value > 0 ? 1 : 0);
        };
        var compare;
        if ((compare = sgn(date1.getFullYear()-date2.getFullYear())) === 0) {
          if ((compare = sgn(date1.getMonth()-date2.getMonth())) === 0) {
            compare = sgn(date1.getDate()-date2.getDate());
          }
        }
        return compare;
      };
      function getFirstWeekStartDate(janFourth) {
          switch (janFourth.getDay()) {
            case 0: // Sunday
              return new Date(janFourth.getFullYear()-1, 11, 29);
            case 1: // Monday
              return janFourth;
            case 2: // Tuesday
              return new Date(janFourth.getFullYear(), 0, 3);
            case 3: // Wednesday
              return new Date(janFourth.getFullYear(), 0, 2);
            case 4: // Thursday
              return new Date(janFourth.getFullYear(), 0, 1);
            case 5: // Friday
              return new Date(janFourth.getFullYear()-1, 11, 31);
            case 6: // Saturday
              return new Date(janFourth.getFullYear()-1, 11, 30);
          }
      };
      function getWeekBasedYear(date) {
          var thisDate = __addDays(new Date(date.tm_year+1900, 0, 1), date.tm_yday);
          var janFourthThisYear = new Date(thisDate.getFullYear(), 0, 4);
          var janFourthNextYear = new Date(thisDate.getFullYear()+1, 0, 4);
          var firstWeekStartThisYear = getFirstWeekStartDate(janFourthThisYear);
          var firstWeekStartNextYear = getFirstWeekStartDate(janFourthNextYear);
          if (compareByDay(firstWeekStartThisYear, thisDate) <= 0) {
            // this date is after the start of the first week of this year
            if (compareByDay(firstWeekStartNextYear, thisDate) <= 0) {
              return thisDate.getFullYear()+1;
            } else {
              return thisDate.getFullYear();
            }
          } else { 
            return thisDate.getFullYear()-1;
          }
      };
      var EXPANSION_RULES_2 = {
        '%a': function(date) {
          return WEEKDAYS[date.tm_wday].substring(0,3);
        },
        '%A': function(date) {
          return WEEKDAYS[date.tm_wday];
        },
        '%b': function(date) {
          return MONTHS[date.tm_mon].substring(0,3);
        },
        '%B': function(date) {
          return MONTHS[date.tm_mon];
        },
        '%C': function(date) {
          var year = date.tm_year+1900;
          return leadingNulls(Math.floor(year/100),2);
        },
        '%d': function(date) {
          return leadingNulls(date.tm_mday, 2);
        },
        '%e': function(date) {
          return leadingSomething(date.tm_mday, 2, ' ');
        },
        '%g': function(date) {
          // %g, %G, and %V give values according to the ISO 8601:2000 standard week-based year. 
          // In this system, weeks begin on a Monday and week 1 of the year is the week that includes 
          // January 4th, which is also the week that includes the first Thursday of the year, and 
          // is also the first week that contains at least four days in the year. 
          // If the first Monday of January is the 2nd, 3rd, or 4th, the preceding days are part of 
          // the last week of the preceding year; thus, for Saturday 2nd January 1999, 
          // %G is replaced by 1998 and %V is replaced by 53. If December 29th, 30th, 
          // or 31st is a Monday, it and any following days are part of week 1 of the following year. 
          // Thus, for Tuesday 30th December 1997, %G is replaced by 1998 and %V is replaced by 01.
          return getWeekBasedYear(date).toString().substring(2);
        },
        '%G': function(date) {
          return getWeekBasedYear(date);
        },
        '%H': function(date) {
          return leadingNulls(date.tm_hour, 2);
        },
        '%I': function(date) {
          return leadingNulls(date.tm_hour < 13 ? date.tm_hour : date.tm_hour-12, 2);
        },
        '%j': function(date) {
          // Day of the year (001-366)
          return leadingNulls(date.tm_mday+__arraySum(__isLeapYear(date.tm_year+1900) ? __MONTH_DAYS_LEAP : __MONTH_DAYS_REGULAR, date.tm_mon-1), 3);
        },
        '%m': function(date) {
          return leadingNulls(date.tm_mon+1, 2);
        },
        '%M': function(date) {
          return leadingNulls(date.tm_min, 2);
        },
        '%n': function() {
          return '\n';
        },
        '%p': function(date) {
          if (date.tm_hour > 0 && date.tm_hour < 13) {
            return 'AM';
          } else {
            return 'PM';
          }
        },
        '%S': function(date) {
          return leadingNulls(date.tm_sec, 2);
        },
        '%t': function() {
          return '\t';
        },
        '%u': function(date) {
          var day = new Date(date.tm_year+1900, date.tm_mon+1, date.tm_mday, 0, 0, 0, 0);
          return day.getDay() || 7;
        },
        '%U': function(date) {
          // Replaced by the week number of the year as a decimal number [00,53]. 
          // The first Sunday of January is the first day of week 1; 
          // days in the new year before this are in week 0. [ tm_year, tm_wday, tm_yday]
          var janFirst = new Date(date.tm_year+1900, 0, 1);
          var firstSunday = janFirst.getDay() === 0 ? janFirst : __addDays(janFirst, 7-janFirst.getDay());
          var endDate = new Date(date.tm_year+1900, date.tm_mon, date.tm_mday);
          // is target date after the first Sunday?
          if (compareByDay(firstSunday, endDate) < 0) {
            // calculate difference in days between first Sunday and endDate
            var februaryFirstUntilEndMonth = __arraySum(__isLeapYear(endDate.getFullYear()) ? __MONTH_DAYS_LEAP : __MONTH_DAYS_REGULAR, endDate.getMonth()-1)-31;
            var firstSundayUntilEndJanuary = 31-firstSunday.getDate();
            var days = firstSundayUntilEndJanuary+februaryFirstUntilEndMonth+endDate.getDate();
            return leadingNulls(Math.ceil(days/7), 2);
          }
          return compareByDay(firstSunday, janFirst) === 0 ? '01': '00';
        },
        '%V': function(date) {
          // Replaced by the week number of the year (Monday as the first day of the week) 
          // as a decimal number [01,53]. If the week containing 1 January has four 
          // or more days in the new year, then it is considered week 1. 
          // Otherwise, it is the last week of the previous year, and the next week is week 1. 
          // Both January 4th and the first Thursday of January are always in week 1. [ tm_year, tm_wday, tm_yday]
          var janFourthThisYear = new Date(date.tm_year+1900, 0, 4);
          var janFourthNextYear = new Date(date.tm_year+1901, 0, 4);
          var firstWeekStartThisYear = getFirstWeekStartDate(janFourthThisYear);
          var firstWeekStartNextYear = getFirstWeekStartDate(janFourthNextYear);
          var endDate = __addDays(new Date(date.tm_year+1900, 0, 1), date.tm_yday);
          if (compareByDay(endDate, firstWeekStartThisYear) < 0) {
            // if given date is before this years first week, then it belongs to the 53rd week of last year
            return '53';
          } 
          if (compareByDay(firstWeekStartNextYear, endDate) <= 0) {
            // if given date is after next years first week, then it belongs to the 01th week of next year
            return '01';
          }
          // given date is in between CW 01..53 of this calendar year
          var daysDifference;
          if (firstWeekStartThisYear.getFullYear() < date.tm_year+1900) {
            // first CW of this year starts last year
            daysDifference = date.tm_yday+32-firstWeekStartThisYear.getDate()
          } else {
            // first CW of this year starts this year
            daysDifference = date.tm_yday+1-firstWeekStartThisYear.getDate();
          }
          return leadingNulls(Math.ceil(daysDifference/7), 2);
        },
        '%w': function(date) {
          var day = new Date(date.tm_year+1900, date.tm_mon+1, date.tm_mday, 0, 0, 0, 0);
          return day.getDay();
        },
        '%W': function(date) {
          // Replaced by the week number of the year as a decimal number [00,53]. 
          // The first Monday of January is the first day of week 1; 
          // days in the new year before this are in week 0. [ tm_year, tm_wday, tm_yday]
          var janFirst = new Date(date.tm_year, 0, 1);
          var firstMonday = janFirst.getDay() === 1 ? janFirst : __addDays(janFirst, janFirst.getDay() === 0 ? 1 : 7-janFirst.getDay()+1);
          var endDate = new Date(date.tm_year+1900, date.tm_mon, date.tm_mday);
          // is target date after the first Monday?
          if (compareByDay(firstMonday, endDate) < 0) {
            var februaryFirstUntilEndMonth = __arraySum(__isLeapYear(endDate.getFullYear()) ? __MONTH_DAYS_LEAP : __MONTH_DAYS_REGULAR, endDate.getMonth()-1)-31;
            var firstMondayUntilEndJanuary = 31-firstMonday.getDate();
            var days = firstMondayUntilEndJanuary+februaryFirstUntilEndMonth+endDate.getDate();
            return leadingNulls(Math.ceil(days/7), 2);
          }
          return compareByDay(firstMonday, janFirst) === 0 ? '01': '00';
        },
        '%y': function(date) {
          // Replaced by the last two digits of the year as a decimal number [00,99]. [ tm_year]
          return (date.tm_year+1900).toString().substring(2);
        },
        '%Y': function(date) {
          // Replaced by the year as a decimal number (for example, 1997). [ tm_year]
          return date.tm_year+1900;
        },
        '%z': function(date) {
          // Replaced by the offset from UTC in the ISO 8601:2000 standard format ( +hhmm or -hhmm ),
          // or by no characters if no timezone is determinable. 
          // For example, "-0430" means 4 hours 30 minutes behind UTC (west of Greenwich). 
          // If tm_isdst is zero, the standard time offset is used. 
          // If tm_isdst is greater than zero, the daylight savings time offset is used. 
          // If tm_isdst is negative, no characters are returned. 
          // FIXME: we cannot determine time zone (or can we?)
          return '';
        },
        '%Z': function(date) {
          // Replaced by the timezone name or abbreviation, or by no bytes if no timezone information exists. [ tm_isdst]
          // FIXME: we cannot determine time zone (or can we?)
          return '';
        },
        '%%': function() {
          return '%';
        }
      };
      for (var rule in EXPANSION_RULES_2) {
        if (pattern.indexOf(rule) >= 0) {
          pattern = pattern.replace(new RegExp(rule, 'g'), EXPANSION_RULES_2[rule](date));
        }
      }
      var bytes = intArrayFromString(pattern, false);
      if (bytes.length > maxsize) {
        return 0;
      } 
      writeArrayToMemory(bytes, s);
      return bytes.length-1;
    }
  var ___tm_current=allocate(44, "i8", ALLOC_STATIC);
  var ___tm_timezone=allocate(intArrayFromString("GMT"), "i8", ALLOC_STATIC);
  var _tzname=allocate(8, "i32*", ALLOC_STATIC);
  var _daylight=allocate(1, "i32*", ALLOC_STATIC);
  var _timezone=allocate(1, "i32*", ALLOC_STATIC);function _tzset() {
      // TODO: Use (malleable) environment variables instead of system settings.
      if (_tzset.called) return;
      _tzset.called = true;
      HEAP32[((_timezone)>>2)]=-(new Date()).getTimezoneOffset() * 60
      var winter = new Date(2000, 0, 1);
      var summer = new Date(2000, 6, 1);
      HEAP32[((_daylight)>>2)]=Number(winter.getTimezoneOffset() != summer.getTimezoneOffset())
      var winterName = 'GMT'; // XXX do not rely on browser timezone info, it is very unpredictable | winter.toString().match(/\(([A-Z]+)\)/)[1];
      var summerName = 'GMT'; // XXX do not rely on browser timezone info, it is very unpredictable | summer.toString().match(/\(([A-Z]+)\)/)[1];
      var winterNamePtr = allocate(intArrayFromString(winterName), 'i8', ALLOC_NORMAL);
      var summerNamePtr = allocate(intArrayFromString(summerName), 'i8', ALLOC_NORMAL);
      HEAP32[((_tzname)>>2)]=winterNamePtr
      HEAP32[(((_tzname)+(4))>>2)]=summerNamePtr
    }function _localtime_r(time, tmPtr) {
      _tzset();
      var date = new Date(HEAP32[((time)>>2)]*1000);
      HEAP32[((tmPtr)>>2)]=date.getSeconds()
      HEAP32[(((tmPtr)+(4))>>2)]=date.getMinutes()
      HEAP32[(((tmPtr)+(8))>>2)]=date.getHours()
      HEAP32[(((tmPtr)+(12))>>2)]=date.getDate()
      HEAP32[(((tmPtr)+(16))>>2)]=date.getMonth()
      HEAP32[(((tmPtr)+(20))>>2)]=date.getFullYear()-1900
      HEAP32[(((tmPtr)+(24))>>2)]=date.getDay()
      var start = new Date(date.getFullYear(), 0, 1);
      var yday = Math.floor((date.getTime() - start.getTime()) / (1000 * 60 * 60 * 24));
      HEAP32[(((tmPtr)+(28))>>2)]=yday
      HEAP32[(((tmPtr)+(36))>>2)]=start.getTimezoneOffset() * 60
      var dst = Number(start.getTimezoneOffset() != date.getTimezoneOffset());
      HEAP32[(((tmPtr)+(32))>>2)]=dst
      HEAP32[(((tmPtr)+(40))>>2)]=___tm_timezone
      return tmPtr;
    }function _localtime(time) {
      return _localtime_r(time, ___tm_current);
    }
  function _open(path, oflag, varargs) {
      // int open(const char *path, int oflag, ...);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/open.html
      var mode = HEAP32[((varargs)>>2)];
      path = Pointer_stringify(path);
      try {
        var stream = FS.open(path, oflag, mode);
        return stream.fd;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _fopen(filename, mode) {
      // FILE *fopen(const char *restrict filename, const char *restrict mode);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fopen.html
      var flags;
      mode = Pointer_stringify(mode);
      if (mode[0] == 'r') {
        if (mode.indexOf('+') != -1) {
          flags = 2;
        } else {
          flags = 0;
        }
      } else if (mode[0] == 'w') {
        if (mode.indexOf('+') != -1) {
          flags = 2;
        } else {
          flags = 1;
        }
        flags |= 64;
        flags |= 512;
      } else if (mode[0] == 'a') {
        if (mode.indexOf('+') != -1) {
          flags = 2;
        } else {
          flags = 1;
        }
        flags |= 64;
        flags |= 1024;
      } else {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return 0;
      }
      var ret = _open(filename, flags, allocate([0x1FF, 0, 0, 0], 'i32', ALLOC_STACK));  // All creation permissions.
      return (ret == -1) ? 0 : ret;
    }
  function _lseek(fildes, offset, whence) {
      // off_t lseek(int fildes, off_t offset, int whence);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/lseek.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      try {
        return FS.llseek(stream, offset, whence);
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _fseek(stream, offset, whence) {
      // int fseek(FILE *stream, long offset, int whence);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fseek.html
      var ret = _lseek(stream, offset, whence);
      if (ret == -1) {
        return -1;
      }
      stream = FS.getStream(stream);
      stream.eof = false;
      return 0;
    }
  function _ftell(stream) {
      // long ftell(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/ftell.html
      stream = FS.getStream(stream);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      if (FS.isChrdev(stream.node.mode)) {
        ___setErrNo(ERRNO_CODES.ESPIPE);
        return -1;
      } else {
        return stream.position;
      }
    }
  function _rewind(stream) {
      // void rewind(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/rewind.html
      _fseek(stream, 0, 0);  // SEEK_SET.
      var streamObj = FS.getStream(stream);
      if (streamObj) streamObj.error = false;
    }
  function _recv(fd, buf, len, flags) {
      var sock = SOCKFS.getSocket(fd);
      if (!sock) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      // TODO honor flags
      return _read(fd, buf, len);
    }
  function _pread(fildes, buf, nbyte, offset) {
      // ssize_t pread(int fildes, void *buf, size_t nbyte, off_t offset);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/read.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      try {
        var slab = HEAP8;
        return FS.read(stream, slab, buf, nbyte, offset);
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _read(fildes, buf, nbyte) {
      // ssize_t read(int fildes, void *buf, size_t nbyte);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/read.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      try {
        var slab = HEAP8;
        return FS.read(stream, slab, buf, nbyte);
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _fread(ptr, size, nitems, stream) {
      // size_t fread(void *restrict ptr, size_t size, size_t nitems, FILE *restrict stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fread.html
      var bytesToRead = nitems * size;
      if (bytesToRead == 0) {
        return 0;
      }
      var bytesRead = 0;
      var streamObj = FS.getStream(stream);
      while (streamObj.ungotten.length && bytesToRead > 0) {
        HEAP8[((ptr++)|0)]=streamObj.ungotten.pop()
        bytesToRead--;
        bytesRead++;
      }
      var err = _read(stream, ptr, bytesToRead);
      if (err == -1) {
        if (streamObj) streamObj.error = true;
        return 0;
      }
      bytesRead += err;
      if (bytesRead < bytesToRead) streamObj.eof = true;
      return Math.floor(bytesRead / size);
    }
  function _feof(stream) {
      // int feof(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/feof.html
      stream = FS.getStream(stream);
      return Number(stream && stream.eof);
    }
  function _fgetc(stream) {
      // int fgetc(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fgetc.html
      var streamObj = FS.getStream(stream);
      if (!streamObj) return -1;
      if (streamObj.eof || streamObj.error) return -1;
      var ret = _fread(_fgetc.ret, 1, 1, stream);
      if (ret == 0) {
        return -1;
      } else if (ret == -1) {
        streamObj.error = true;
        return -1;
      } else {
        return HEAPU8[((_fgetc.ret)|0)];
      }
    }function _fgets(s, n, stream) {
      // char *fgets(char *restrict s, int n, FILE *restrict stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fgets.html
      var streamObj = FS.getStream(stream);
      if (!streamObj) return 0;
      if (streamObj.error || streamObj.eof) return 0;
      var byte_;
      for (var i = 0; i < n - 1 && byte_ != 10; i++) {
        byte_ = _fgetc(stream);
        if (byte_ == -1) {
          if (streamObj.error || (streamObj.eof && i == 0)) return 0;
          else if (streamObj.eof) break;
        }
        HEAP8[(((s)+(i))|0)]=byte_
      }
      HEAP8[(((s)+(i))|0)]=0
      return s;
    }
  function _strchr(ptr, chr) {
      ptr--;
      do {
        ptr++;
        var val = HEAP8[(ptr)];
        if (val == chr) return ptr;
      } while (val);
      return 0;
    }
  function _strtok_r(s, delim, lasts) {
      var skip_leading_delim = 1;
      var spanp;
      var c, sc;
      var tok;
      if (s == 0 && (s = getValue(lasts, 'i8*')) == 0) {
        return 0;
      }
      cont: while (1) {
        c = getValue(s++, 'i8');
        for (spanp = delim; (sc = getValue(spanp++, 'i8')) != 0;) {
          if (c == sc) {
            if (skip_leading_delim) {
              continue cont;
            } else {
              setValue(lasts, s, 'i8*');
              setValue(s - 1, 0, 'i8');
              return s - 1;
            }
          }
        }
        break;
      }
      if (c == 0) {
        setValue(lasts, 0, 'i8*');
        return 0;
      }
      tok = s - 1;
      for (;;) {
        c = getValue(s++, 'i8');
        spanp = delim;
        do {
          if ((sc = getValue(spanp++, 'i8')) == c) {
            if (c == 0) {
              s = 0;
            } else {
              setValue(s - 1, 0, 'i8');
            }
            setValue(lasts, s, 'i8*');
            return tok;
          }
        } while (sc != 0);
      }
      abort('strtok_r error!');
    }
  function _qsort(base, num, size, cmp) {
      if (num == 0 || size == 0) return;
      // forward calls to the JavaScript sort method
      // first, sort the items logically
      var keys = [];
      for (var i = 0; i < num; i++) keys.push(i);
      keys.sort(function(a, b) {
        return Module['dynCall_iii'](cmp, base+a*size, base+b*size);
      });
      // apply the sort
      var temp = _malloc(num*size);
      _memcpy(temp, base, num*size);
      for (var i = 0; i < num; i++) {
        if (keys[i] == i) continue; // already in place
        _memcpy(base+i*size, temp+keys[i]*size, size);
      }
      _free(temp);
    }
  function _opendir(dirname) {
      // DIR *opendir(const char *dirname);
      // http://pubs.opengroup.org/onlinepubs/007908799/xsh/opendir.html
      // NOTE: Calculating absolute path redundantly since we need to associate it
      //       with the opened stream.
      var path = Pointer_stringify(dirname);
      if (!path) {
        ___setErrNo(ERRNO_CODES.ENOENT);
        return 0;
      }
      var node;
      try {
        var lookup = FS.lookupPath(path, { follow: true });
        node = lookup.node;
      } catch (e) {
        FS.handleFSError(e);
        return 0;
      }
      if (!FS.isDir(node.mode)) {
        ___setErrNo(ERRNO_CODES.ENOTDIR);
        return 0;
      }
      var err = _open(dirname, 0, allocate([0, 0, 0, 0], 'i32', ALLOC_STACK));
      // open returns 0 on failure, not -1
      return err === -1 ? 0 : err;
    }
  function _readdir_r(dirp, entry, result) {
      // int readdir_r(DIR *dirp, struct dirent *entry, struct dirent **result);
      // http://pubs.opengroup.org/onlinepubs/007908799/xsh/readdir_r.html
      var stream = FS.getStream(dirp);
      if (!stream) {
        return ___setErrNo(ERRNO_CODES.EBADF);
      }
      var entries;
      try {
        entries = FS.readdir(stream.path);
      } catch (e) {
        return FS.handleFSError(e);
      }
      if (stream.position < 0 || stream.position >= entries.length) {
        HEAP32[((result)>>2)]=0
        return 0;
      }
      var id;
      var type;
      var name = entries[stream.position];
      var offset = stream.position + 1;
      if (!name.indexOf('.')) {
        id = 1;
        type = 4;
      } else {
        var child = FS.lookupNode(stream.node, name);
        id = child.id;
        type = FS.isChrdev(child.mode) ? 2 :  // DT_CHR, character device.
               FS.isDir(child.mode) ? 4 :     // DT_DIR, directory.
               FS.isLink(child.mode) ? 10 :   // DT_LNK, symbolic link.
               8;                             // DT_REG, regular file.
      }
      HEAP32[((entry)>>2)]=id
      HEAP32[(((entry)+(4))>>2)]=offset
      HEAP32[(((entry)+(8))>>2)]=name.length + 1
      for (var i = 0; i < name.length; i++) {
        HEAP8[(((entry + 11)+(i))|0)]=name.charCodeAt(i)
      }
      HEAP8[(((entry + 11)+(i))|0)]=0
      HEAP8[(((entry)+(10))|0)]=type
      HEAP32[((result)>>2)]=entry
      stream.position++;
      return 0;
    }function _readdir(dirp) {
      // struct dirent *readdir(DIR *dirp);
      // http://pubs.opengroup.org/onlinepubs/007908799/xsh/readdir_r.html
      var stream = FS.getStream(dirp);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return 0;
      }
      // TODO Is it supposed to be safe to execute multiple readdirs?
      if (!_readdir.entry) _readdir.entry = _malloc(268);
      if (!_readdir.result) _readdir.result = _malloc(4);
      var err = _readdir_r(dirp, _readdir.entry, _readdir.result);
      if (err) {
        ___setErrNo(err);
        return 0;
      }
      return HEAP32[((_readdir.result)>>2)];
    }
  function _closedir(dirp) {
      // int closedir(DIR *dirp);
      // http://pubs.opengroup.org/onlinepubs/007908799/xsh/closedir.html
      return _close(dirp);
    }
  function _stat(path, buf, dontResolveLastLink) {
      // http://pubs.opengroup.org/onlinepubs/7908799/xsh/stat.html
      // int stat(const char *path, struct stat *buf);
      // NOTE: dontResolveLastLink is a shortcut for lstat(). It should never be
      //       used in client code.
      path = typeof path !== 'string' ? Pointer_stringify(path) : path;
      try {
        var stat = dontResolveLastLink ? FS.lstat(path) : FS.stat(path);
        HEAP32[((buf)>>2)]=stat.dev;
        HEAP32[(((buf)+(4))>>2)]=0;
        HEAP32[(((buf)+(8))>>2)]=stat.ino;
        HEAP32[(((buf)+(12))>>2)]=stat.mode
        HEAP32[(((buf)+(16))>>2)]=stat.nlink
        HEAP32[(((buf)+(20))>>2)]=stat.uid
        HEAP32[(((buf)+(24))>>2)]=stat.gid
        HEAP32[(((buf)+(28))>>2)]=stat.rdev
        HEAP32[(((buf)+(32))>>2)]=0;
        HEAP32[(((buf)+(36))>>2)]=stat.size
        HEAP32[(((buf)+(40))>>2)]=4096
        HEAP32[(((buf)+(44))>>2)]=stat.blocks
        HEAP32[(((buf)+(48))>>2)]=Math.floor(stat.atime.getTime() / 1000)
        HEAP32[(((buf)+(52))>>2)]=0
        HEAP32[(((buf)+(56))>>2)]=Math.floor(stat.mtime.getTime() / 1000)
        HEAP32[(((buf)+(60))>>2)]=0
        HEAP32[(((buf)+(64))>>2)]=Math.floor(stat.ctime.getTime() / 1000)
        HEAP32[(((buf)+(68))>>2)]=0
        HEAP32[(((buf)+(72))>>2)]=stat.ino
        return 0;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }
  function _realpath(file_name, resolved_name) {
      // char *realpath(const char *restrict file_name, char *restrict resolved_name);
      // http://pubs.opengroup.org/onlinepubs/009604499/functions/realpath.html
      var absolute = FS.analyzePath(Pointer_stringify(file_name));
      if (absolute.error) {
        ___setErrNo(absolute.error);
        return 0;
      } else {
        var size = Math.min(4095, absolute.path.length);  // PATH_MAX - 1.
        for (var i = 0; i < size; i++) {
          HEAP8[(((resolved_name)+(i))|0)]=absolute.path.charCodeAt(i)
        }
        HEAP8[(((resolved_name)+(size))|0)]=0
        return resolved_name;
      }
    }
  function _getgid() {
      // gid_t getgid(void);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/getgid.html
      // We have just one process/group/user, all with ID 0.
      return 0;
    }var _getpid=_getgid;
  function _readlink(path, buf, bufsize) {
      // ssize_t readlink(const char *restrict path, char *restrict buf, size_t bufsize);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/readlink.html
      path = Pointer_stringify(path);
      var str;
      try {
        str = FS.readlink(path);
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
      str = str.slice(0, Math.max(0, bufsize - 1));
      writeStringToMemory(str, buf, true);
      return str.length;
    }
  function _mknod(path, mode, dev) {
      // int mknod(const char *path, mode_t mode, dev_t dev);
      // http://pubs.opengroup.org/onlinepubs/7908799/xsh/mknod.html
      path = Pointer_stringify(path);
      // we don't want this in the JS API as the JS API
      // uses mknod to create all nodes.
      switch (mode & 61440) {
        case 32768:
        case 8192:
        case 24576:
        case 4096:
        case 49152:
          break;
        default:
          ___setErrNo(ERRNO_CODES.EINVAL);
          return -1;
      }
      try {
        FS.mknod(path, mode, dev);
        return 0;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _mkdir(path, mode) {
      // int mkdir(const char *path, mode_t mode);
      // http://pubs.opengroup.org/onlinepubs/7908799/xsh/mkdir.html
      path = Pointer_stringify(path);
      try {
        FS.mkdir(path, mode, 0);
        return 0;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }
  function ___errno_location() {
      return ___errno_state;
    }
  function _strerror_r(errnum, strerrbuf, buflen) {
      if (errnum in ERRNO_MESSAGES) {
        if (ERRNO_MESSAGES[errnum].length > buflen - 1) {
          return ___setErrNo(ERRNO_CODES.ERANGE);
        } else {
          var msg = ERRNO_MESSAGES[errnum];
          for (var i = 0; i < msg.length; i++) {
            HEAP8[(((strerrbuf)+(i))|0)]=msg.charCodeAt(i)
          }
          HEAP8[(((strerrbuf)+(i))|0)]=0
          return 0;
        }
      } else {
        return ___setErrNo(ERRNO_CODES.EINVAL);
      }
    }function _strerror(errnum) {
      if (!_strerror.buffer) _strerror.buffer = _malloc(256);
      _strerror_r(errnum, _strerror.buffer, 256);
      return _strerror.buffer;
    }
  var _sqrt=Math_sqrt;
  var _fabs=Math_abs;
  function __parseInt64(str, endptr, base, min, max, unsign) {
      var isNegative = false;
      // Skip space.
      while (_isspace(HEAP8[(str)])) str++;
      // Check for a plus/minus sign.
      if (HEAP8[(str)] == 45) {
        str++;
        isNegative = true;
      } else if (HEAP8[(str)] == 43) {
        str++;
      }
      // Find base.
      var ok = false;
      var finalBase = base;
      if (!finalBase) {
        if (HEAP8[(str)] == 48) {
          if (HEAP8[((str+1)|0)] == 120 ||
              HEAP8[((str+1)|0)] == 88) {
            finalBase = 16;
            str += 2;
          } else {
            finalBase = 8;
            ok = true; // we saw an initial zero, perhaps the entire thing is just "0"
          }
        }
      } else if (finalBase==16) {
        if (HEAP8[(str)] == 48) {
          if (HEAP8[((str+1)|0)] == 120 ||
              HEAP8[((str+1)|0)] == 88) {
            str += 2;
          }
        }
      }
      if (!finalBase) finalBase = 10;
      start = str;
      // Get digits.
      var chr;
      while ((chr = HEAP8[(str)]) != 0) {
        var digit = parseInt(String.fromCharCode(chr), finalBase);
        if (isNaN(digit)) {
          break;
        } else {
          str++;
          ok = true;
        }
      }
      if (!ok) {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return ((asm["setTempRet0"](0),0)|0);
      }
      // Set end pointer.
      if (endptr) {
        HEAP32[((endptr)>>2)]=str
      }
      try {
        var numberString = isNegative ? '-'+Pointer_stringify(start, str - start) : Pointer_stringify(start, str - start);
        i64Math.fromString(numberString, finalBase, min, max, unsign);
      } catch(e) {
        ___setErrNo(ERRNO_CODES.ERANGE); // not quite correct
      }
      return ((asm["setTempRet0"](((HEAP32[(((tempDoublePtr)+(4))>>2)])|0)),((HEAP32[((tempDoublePtr)>>2)])|0))|0);
    }function _strtoull(str, endptr, base) {
      return __parseInt64(str, endptr, base, 0, '18446744073709551615', true);  // ULONG_MAX.
    }
  var _getc=_fgetc;
  function _isgraph(chr) {
      return 0x20 < chr && chr < 0x7F;
    }
  function _llvm_bswap_i32(x) {
      return ((x&0xff)<<24) | (((x>>8)&0xff)<<16) | (((x>>16)&0xff)<<8) | (x>>>24);
    }
  function _isalpha(chr) {
      return (chr >= 97 && chr <= 122) ||
             (chr >= 65 && chr <= 90);
    }
  var Browser={mainLoop:{scheduler:null,shouldPause:false,paused:false,queue:[],pause:function () {
          Browser.mainLoop.shouldPause = true;
        },resume:function () {
          if (Browser.mainLoop.paused) {
            Browser.mainLoop.paused = false;
            Browser.mainLoop.scheduler();
          }
          Browser.mainLoop.shouldPause = false;
        },updateStatus:function () {
          if (Module['setStatus']) {
            var message = Module['statusMessage'] || 'Please wait...';
            var remaining = Browser.mainLoop.remainingBlockers;
            var expected = Browser.mainLoop.expectedBlockers;
            if (remaining) {
              if (remaining < expected) {
                Module['setStatus'](message + ' (' + (expected - remaining) + '/' + expected + ')');
              } else {
                Module['setStatus'](message);
              }
            } else {
              Module['setStatus']('');
            }
          }
        }},isFullScreen:false,pointerLock:false,moduleContextCreatedCallbacks:[],workers:[],init:function () {
        if (!Module["preloadPlugins"]) Module["preloadPlugins"] = []; // needs to exist even in workers
        if (Browser.initted || ENVIRONMENT_IS_WORKER) return;
        Browser.initted = true;
        try {
          new Blob();
          Browser.hasBlobConstructor = true;
        } catch(e) {
          Browser.hasBlobConstructor = false;
          console.log("warning: no blob constructor, cannot create blobs with mimetypes");
        }
        Browser.BlobBuilder = typeof MozBlobBuilder != "undefined" ? MozBlobBuilder : (typeof WebKitBlobBuilder != "undefined" ? WebKitBlobBuilder : (!Browser.hasBlobConstructor ? console.log("warning: no BlobBuilder") : null));
        Browser.URLObject = typeof window != "undefined" ? (window.URL ? window.URL : window.webkitURL) : undefined;
        if (!Module.noImageDecoding && typeof Browser.URLObject === 'undefined') {
          console.log("warning: Browser does not support creating object URLs. Built-in browser image decoding will not be available.");
          Module.noImageDecoding = true;
        }
        // Support for plugins that can process preloaded files. You can add more of these to
        // your app by creating and appending to Module.preloadPlugins.
        //
        // Each plugin is asked if it can handle a file based on the file's name. If it can,
        // it is given the file's raw data. When it is done, it calls a callback with the file's
        // (possibly modified) data. For example, a plugin might decompress a file, or it
        // might create some side data structure for use later (like an Image element, etc.).
        var imagePlugin = {};
        imagePlugin['canHandle'] = function imagePlugin_canHandle(name) {
          return !Module.noImageDecoding && /\.(jpg|jpeg|png|bmp)$/i.test(name);
        };
        imagePlugin['handle'] = function imagePlugin_handle(byteArray, name, onload, onerror) {
          var b = null;
          if (Browser.hasBlobConstructor) {
            try {
              b = new Blob([byteArray], { type: Browser.getMimetype(name) });
              if (b.size !== byteArray.length) { // Safari bug #118630
                // Safari's Blob can only take an ArrayBuffer
                b = new Blob([(new Uint8Array(byteArray)).buffer], { type: Browser.getMimetype(name) });
              }
            } catch(e) {
              Runtime.warnOnce('Blob constructor present but fails: ' + e + '; falling back to blob builder');
            }
          }
          if (!b) {
            var bb = new Browser.BlobBuilder();
            bb.append((new Uint8Array(byteArray)).buffer); // we need to pass a buffer, and must copy the array to get the right data range
            b = bb.getBlob();
          }
          var url = Browser.URLObject.createObjectURL(b);
          var img = new Image();
          img.onload = function img_onload() {
            assert(img.complete, 'Image ' + name + ' could not be decoded');
            var canvas = document.createElement('canvas');
            canvas.width = img.width;
            canvas.height = img.height;
            var ctx = canvas.getContext('2d');
            ctx.drawImage(img, 0, 0);
            Module["preloadedImages"][name] = canvas;
            Browser.URLObject.revokeObjectURL(url);
            if (onload) onload(byteArray);
          };
          img.onerror = function img_onerror(event) {
            console.log('Image ' + url + ' could not be decoded');
            if (onerror) onerror();
          };
          img.src = url;
        };
        Module['preloadPlugins'].push(imagePlugin);
        var audioPlugin = {};
        audioPlugin['canHandle'] = function audioPlugin_canHandle(name) {
          return !Module.noAudioDecoding && name.substr(-4) in { '.ogg': 1, '.wav': 1, '.mp3': 1 };
        };
        audioPlugin['handle'] = function audioPlugin_handle(byteArray, name, onload, onerror) {
          var done = false;
          function finish(audio) {
            if (done) return;
            done = true;
            Module["preloadedAudios"][name] = audio;
            if (onload) onload(byteArray);
          }
          function fail() {
            if (done) return;
            done = true;
            Module["preloadedAudios"][name] = new Audio(); // empty shim
            if (onerror) onerror();
          }
          if (Browser.hasBlobConstructor) {
            try {
              var b = new Blob([byteArray], { type: Browser.getMimetype(name) });
            } catch(e) {
              return fail();
            }
            var url = Browser.URLObject.createObjectURL(b); // XXX we never revoke this!
            var audio = new Audio();
            audio.addEventListener('canplaythrough', function() { finish(audio) }, false); // use addEventListener due to chromium bug 124926
            audio.onerror = function audio_onerror(event) {
              if (done) return;
              console.log('warning: browser could not fully decode audio ' + name + ', trying slower base64 approach');
              function encode64(data) {
                var BASE = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/';
                var PAD = '=';
                var ret = '';
                var leftchar = 0;
                var leftbits = 0;
                for (var i = 0; i < data.length; i++) {
                  leftchar = (leftchar << 8) | data[i];
                  leftbits += 8;
                  while (leftbits >= 6) {
                    var curr = (leftchar >> (leftbits-6)) & 0x3f;
                    leftbits -= 6;
                    ret += BASE[curr];
                  }
                }
                if (leftbits == 2) {
                  ret += BASE[(leftchar&3) << 4];
                  ret += PAD + PAD;
                } else if (leftbits == 4) {
                  ret += BASE[(leftchar&0xf) << 2];
                  ret += PAD;
                }
                return ret;
              }
              audio.src = 'data:audio/x-' + name.substr(-3) + ';base64,' + encode64(byteArray);
              finish(audio); // we don't wait for confirmation this worked - but it's worth trying
            };
            audio.src = url;
            // workaround for chrome bug 124926 - we do not always get oncanplaythrough or onerror
            Browser.safeSetTimeout(function() {
              finish(audio); // try to use it even though it is not necessarily ready to play
            }, 10000);
          } else {
            return fail();
          }
        };
        Module['preloadPlugins'].push(audioPlugin);
        // Canvas event setup
        var canvas = Module['canvas'];
        canvas.requestPointerLock = canvas['requestPointerLock'] ||
                                    canvas['mozRequestPointerLock'] ||
                                    canvas['webkitRequestPointerLock'];
        canvas.exitPointerLock = document['exitPointerLock'] ||
                                 document['mozExitPointerLock'] ||
                                 document['webkitExitPointerLock'] ||
                                 function(){}; // no-op if function does not exist
        canvas.exitPointerLock = canvas.exitPointerLock.bind(document);
        function pointerLockChange() {
          Browser.pointerLock = document['pointerLockElement'] === canvas ||
                                document['mozPointerLockElement'] === canvas ||
                                document['webkitPointerLockElement'] === canvas;
        }
        document.addEventListener('pointerlockchange', pointerLockChange, false);
        document.addEventListener('mozpointerlockchange', pointerLockChange, false);
        document.addEventListener('webkitpointerlockchange', pointerLockChange, false);
        if (Module['elementPointerLock']) {
          canvas.addEventListener("click", function(ev) {
            if (!Browser.pointerLock && canvas.requestPointerLock) {
              canvas.requestPointerLock();
              ev.preventDefault();
            }
          }, false);
        }
      },createContext:function (canvas, useWebGL, setInModule, webGLContextAttributes) {
        var ctx;
        try {
          if (useWebGL) {
            var contextAttributes = {
              antialias: false,
              alpha: false
            };
            if (webGLContextAttributes) {
              for (var attribute in webGLContextAttributes) {
                contextAttributes[attribute] = webGLContextAttributes[attribute];
              }
            }
            ctx = canvas.getContext('experimental-webgl', contextAttributes);
          } else {
            ctx = canvas.getContext('2d');
          }
          if (!ctx) throw ':(';
        } catch (e) {
          Module.print('Could not create canvas - ' + e);
          return null;
        }
        if (useWebGL) {
          // Set the background of the WebGL canvas to black
          canvas.style.backgroundColor = "black";
          // Warn on context loss
          canvas.addEventListener('webglcontextlost', function(event) {
            alert('WebGL context lost. You will need to reload the page.');
          }, false);
        }
        if (setInModule) {
          Module.ctx = ctx;
          Module.useWebGL = useWebGL;
          Browser.moduleContextCreatedCallbacks.forEach(function(callback) { callback() });
          Browser.init();
        }
        return ctx;
      },destroyContext:function (canvas, useWebGL, setInModule) {},fullScreenHandlersInstalled:false,lockPointer:undefined,resizeCanvas:undefined,requestFullScreen:function (lockPointer, resizeCanvas) {
        Browser.lockPointer = lockPointer;
        Browser.resizeCanvas = resizeCanvas;
        if (typeof Browser.lockPointer === 'undefined') Browser.lockPointer = true;
        if (typeof Browser.resizeCanvas === 'undefined') Browser.resizeCanvas = false;
        var canvas = Module['canvas'];
        function fullScreenChange() {
          Browser.isFullScreen = false;
          if ((document['webkitFullScreenElement'] || document['webkitFullscreenElement'] ||
               document['mozFullScreenElement'] || document['mozFullscreenElement'] ||
               document['fullScreenElement'] || document['fullscreenElement']) === canvas) {
            canvas.cancelFullScreen = document['cancelFullScreen'] ||
                                      document['mozCancelFullScreen'] ||
                                      document['webkitCancelFullScreen'];
            canvas.cancelFullScreen = canvas.cancelFullScreen.bind(document);
            if (Browser.lockPointer) canvas.requestPointerLock();
            Browser.isFullScreen = true;
            if (Browser.resizeCanvas) Browser.setFullScreenCanvasSize();
          } else if (Browser.resizeCanvas){
            Browser.setWindowedCanvasSize();
          }
          if (Module['onFullScreen']) Module['onFullScreen'](Browser.isFullScreen);
        }
        if (!Browser.fullScreenHandlersInstalled) {
          Browser.fullScreenHandlersInstalled = true;
          document.addEventListener('fullscreenchange', fullScreenChange, false);
          document.addEventListener('mozfullscreenchange', fullScreenChange, false);
          document.addEventListener('webkitfullscreenchange', fullScreenChange, false);
        }
        canvas.requestFullScreen = canvas['requestFullScreen'] ||
                                   canvas['mozRequestFullScreen'] ||
                                   (canvas['webkitRequestFullScreen'] ? function() { canvas['webkitRequestFullScreen'](Element['ALLOW_KEYBOARD_INPUT']) } : null);
        canvas.requestFullScreen();
      },requestAnimationFrame:function requestAnimationFrame(func) {
        if (typeof window === 'undefined') { // Provide fallback to setTimeout if window is undefined (e.g. in Node.js)
          setTimeout(func, 1000/60);
        } else {
          if (!window.requestAnimationFrame) {
            window.requestAnimationFrame = window['requestAnimationFrame'] ||
                                           window['mozRequestAnimationFrame'] ||
                                           window['webkitRequestAnimationFrame'] ||
                                           window['msRequestAnimationFrame'] ||
                                           window['oRequestAnimationFrame'] ||
                                           window['setTimeout'];
          }
          window.requestAnimationFrame(func);
        }
      },safeCallback:function (func) {
        return function() {
          if (!ABORT) return func.apply(null, arguments);
        };
      },safeRequestAnimationFrame:function (func) {
        return Browser.requestAnimationFrame(function() {
          if (!ABORT) func();
        });
      },safeSetTimeout:function (func, timeout) {
        return setTimeout(function() {
          if (!ABORT) func();
        }, timeout);
      },safeSetInterval:function (func, timeout) {
        return setInterval(function() {
          if (!ABORT) func();
        }, timeout);
      },getMimetype:function (name) {
        return {
          'jpg': 'image/jpeg',
          'jpeg': 'image/jpeg',
          'png': 'image/png',
          'bmp': 'image/bmp',
          'ogg': 'audio/ogg',
          'wav': 'audio/wav',
          'mp3': 'audio/mpeg'
        }[name.substr(name.lastIndexOf('.')+1)];
      },getUserMedia:function (func) {
        if(!window.getUserMedia) {
          window.getUserMedia = navigator['getUserMedia'] ||
                                navigator['mozGetUserMedia'];
        }
        window.getUserMedia(func);
      },getMovementX:function (event) {
        return event['movementX'] ||
               event['mozMovementX'] ||
               event['webkitMovementX'] ||
               0;
      },getMovementY:function (event) {
        return event['movementY'] ||
               event['mozMovementY'] ||
               event['webkitMovementY'] ||
               0;
      },mouseX:0,mouseY:0,mouseMovementX:0,mouseMovementY:0,calculateMouseEvent:function (event) { // event should be mousemove, mousedown or mouseup
        if (Browser.pointerLock) {
          // When the pointer is locked, calculate the coordinates
          // based on the movement of the mouse.
          // Workaround for Firefox bug 764498
          if (event.type != 'mousemove' &&
              ('mozMovementX' in event)) {
            Browser.mouseMovementX = Browser.mouseMovementY = 0;
          } else {
            Browser.mouseMovementX = Browser.getMovementX(event);
            Browser.mouseMovementY = Browser.getMovementY(event);
          }
          // check if SDL is available
          if (typeof SDL != "undefined") {
          	Browser.mouseX = SDL.mouseX + Browser.mouseMovementX;
          	Browser.mouseY = SDL.mouseY + Browser.mouseMovementY;
          } else {
          	// just add the mouse delta to the current absolut mouse position
          	// FIXME: ideally this should be clamped against the canvas size and zero
          	Browser.mouseX += Browser.mouseMovementX;
          	Browser.mouseY += Browser.mouseMovementY;
          }        
        } else {
          // Otherwise, calculate the movement based on the changes
          // in the coordinates.
          var rect = Module["canvas"].getBoundingClientRect();
          var x, y;
          if (event.type == 'touchstart' ||
              event.type == 'touchend' ||
              event.type == 'touchmove') {
            var t = event.touches.item(0);
            if (t) {
              x = t.pageX - (window.scrollX + rect.left);
              y = t.pageY - (window.scrollY + rect.top);
            } else {
              return;
            }
          } else {
            x = event.pageX - (window.scrollX + rect.left);
            y = event.pageY - (window.scrollY + rect.top);
          }
          // the canvas might be CSS-scaled compared to its backbuffer;
          // SDL-using content will want mouse coordinates in terms
          // of backbuffer units.
          var cw = Module["canvas"].width;
          var ch = Module["canvas"].height;
          x = x * (cw / rect.width);
          y = y * (ch / rect.height);
          Browser.mouseMovementX = x - Browser.mouseX;
          Browser.mouseMovementY = y - Browser.mouseY;
          Browser.mouseX = x;
          Browser.mouseY = y;
        }
      },xhrLoad:function (url, onload, onerror) {
        var xhr = new XMLHttpRequest();
        xhr.open('GET', url, true);
        xhr.responseType = 'arraybuffer';
        xhr.onload = function xhr_onload() {
          if (xhr.status == 200 || (xhr.status == 0 && xhr.response)) { // file URLs can return 0
            onload(xhr.response);
          } else {
            onerror();
          }
        };
        xhr.onerror = onerror;
        xhr.send(null);
      },asyncLoad:function (url, onload, onerror, noRunDep) {
        Browser.xhrLoad(url, function(arrayBuffer) {
          assert(arrayBuffer, 'Loading data file "' + url + '" failed (no arrayBuffer).');
          onload(new Uint8Array(arrayBuffer));
          if (!noRunDep) removeRunDependency('al ' + url);
        }, function(event) {
          if (onerror) {
            onerror();
          } else {
            throw 'Loading data file "' + url + '" failed.';
          }
        });
        if (!noRunDep) addRunDependency('al ' + url);
      },resizeListeners:[],updateResizeListeners:function () {
        var canvas = Module['canvas'];
        Browser.resizeListeners.forEach(function(listener) {
          listener(canvas.width, canvas.height);
        });
      },setCanvasSize:function (width, height, noUpdates) {
        var canvas = Module['canvas'];
        canvas.width = width;
        canvas.height = height;
        if (!noUpdates) Browser.updateResizeListeners();
      },windowedWidth:0,windowedHeight:0,setFullScreenCanvasSize:function () {
        var canvas = Module['canvas'];
        this.windowedWidth = canvas.width;
        this.windowedHeight = canvas.height;
        canvas.width = screen.width;
        canvas.height = screen.height;
        // check if SDL is available   
        if (typeof SDL != "undefined") {
        	var flags = HEAPU32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)];
        	flags = flags | 0x00800000; // set SDL_FULLSCREEN flag
        	HEAP32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)]=flags
        }
        Browser.updateResizeListeners();
      },setWindowedCanvasSize:function () {
        var canvas = Module['canvas'];
        canvas.width = this.windowedWidth;
        canvas.height = this.windowedHeight;
        // check if SDL is available       
        if (typeof SDL != "undefined") {
        	var flags = HEAPU32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)];
        	flags = flags & ~0x00800000; // clear SDL_FULLSCREEN flag
        	HEAP32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)]=flags
        }
        Browser.updateResizeListeners();
      }};var RI={temp:null,contexts:[],eventHandler:function (event) {
           var i;
           switch (event.type) {
              case 'mousemove':
                 var x = event['movementX'] || event['mozMovementX'] || event['webkitMovementX'];
                 var y = event['movementY'] || event['mozMovementY'] || event['webkitMovementY'];
                 for (i = 0; i < RI.contexts.length; i++) {
                    var oldX = HEAP32[(((RI.contexts[i].state)+(32))>>2)];
                    var oldY = HEAP32[(((RI.contexts[i].state)+(36))>>2)];
                    x += oldX;
                    y += oldY;
                    HEAP32[(((RI.contexts[i].state)+(32))>>2)]=x;
                    HEAP32[(((RI.contexts[i].state)+(36))>>2)]=y;
                 }
                 break;
              case 'mouseup':
              case 'mousedown':
                 var value;
                 var offset;
                 if (event.button === 0) offset = 40;
                 else if (event.button === 2) offset = 41;
                 else break;
                 if (event.type === 'mouseup') value = 0;
                 else value = 1;
                 for (i = 0; i < RI.contexts.length; i++) {
                    HEAP8[(((RI.contexts[i].state)+(offset))|0)]=value;
                 }
                 break;
              case 'keyup':
              case 'keydown':
                 var key = event.keyCode;
                 var offset = key >> 3;
                 var bit = 1 << (key & 7);
                 if (offset >= 32) throw 'key code error! bad code: ' + key;
                 for (i = 0; i < RI.contexts.length; i++) {
                    var value = HEAP8[(((RI.contexts[i].state)+(offset))|0)];
                    if (event.type === 'keyup') value &= ~bit;
                    else value |= bit;
                    HEAP8[(((RI.contexts[i].state)+(offset))|0)]=value;
                 }
                 event.preventDefault();
                 break;
              case 'blur':
              case 'visibilitychange':
                 for (i = 0; i < RI.contexts.length; i++) {
                    _memset(RI.contexts[i].state, 0, 42);
                 }
                 break;
           }
        }};function _RWebInputDestroy(context) {
        if (context === RI.contexts.length) {
           RI.contexts.pop();
           if (RI.contexts.length === 0) {
              document.removeEventListener('keyup', RI.eventHandler, false);
              document.removeEventListener('keydown', RI.eventHandler, false);
              document.removeEventListener('mousemove', RI.eventHandler, false);
              document.removeEventListener('mouseup', RI.eventHandler, false);
              document.removeEventListener('mousedown', RI.eventHandler, false);
              document.removeEventListener('blur', RI.eventHandler, false);
              document.removeEventListener('onvisbilitychange', RI.eventHandler, false);
           }
        }
     }
  function _RWebInputPoll(context) {
        context -= 1;
        var state = RI.contexts[context].state;
        _memcpy(RI.temp, state, 42);
        // reset mouse movements
        HEAP32[(((RI.contexts[context].state)+(32))>>2)]=0;
        HEAP32[(((RI.contexts[context].state)+(36))>>2)]=0;
        return RI.temp;
     }
  function _RWebInputInit(latency) {
        if (RI.contexts.length === 0) {
           document.addEventListener('keyup', RI.eventHandler, false);
           document.addEventListener('keydown', RI.eventHandler, false);
           document.addEventListener('mousemove', RI.eventHandler, false);
           document.addEventListener('mouseup', RI.eventHandler, false);
           document.addEventListener('mousedown', RI.eventHandler, false);
           document.addEventListener('blur', RI.eventHandler, false);
           document.addEventListener('onvisbilitychange', RI.eventHandler, false);
        }
        if (RI.temp === null) RI.temp = _malloc(42);
        var s = _malloc(42);
        _memset(s, 0, 42);
        RI.contexts.push({
           state: s
        });
        return RI.contexts.length;
     }
  function _strstr(ptr1, ptr2) {
      var check = 0, start;
      do {
        if (!check) {
          start = ptr1;
          check = ptr2;
        }
        var curr1 = HEAP8[((ptr1++)|0)];
        var curr2 = HEAP8[((check++)|0)];
        if (curr2 == 0) return start;
        if (curr2 != curr1) {
          // rewind to one character after start, to find ez in eeez
          ptr1 = start + 1;
          check = 0;
        }
      } while (curr1);
      return 0;
    }
  Module["_memmove"] = _memmove;var _llvm_memmove_p0i8_p0i8_i32=_memmove;
  Module["_memcmp"] = _memcmp;
  var RA={BUFFER_SIZE:256,context:null,buffers:[],numBuffers:0,bufIndex:0,bufOffset:0,startTime:0,nonblock:false,currentTimeWorkaround:false,setStartTime:function () {
           if (RA.context.currentTime) {
              RA.startTime = window['performance']['now']() - RA.context.currentTime * 1000;
              Module["resumeMainLoop"]();
           } else window['setTimeout'](RA.setStartTime, 0);
        },getCurrentPerfTime:function () {
           if (RA.startTime) return (window['performance']['now']() - RA.startTime) / 1000;
           else throw 'getCurrentPerfTime() called before start time set';
        },process:function (queueBuffers) {
           var currentTime = RA.getCurrentPerfTime();
           for (var i = 0; i < RA.bufIndex; i++) {
              if (RA.buffers[i].endTime < currentTime) {
                 var buf = RA.buffers.splice(i, 1);
                 RA.buffers[RA.numBuffers - 1] = buf[0];
                 i--;
                 RA.bufIndex--;
              }
           }
        },fillBuffer:function (buf, samples) {
           var count = 0;
           var leftBuffer = RA.buffers[RA.bufIndex].getChannelData(0);
           var rightBuffer = RA.buffers[RA.bufIndex].getChannelData(1);
           while (samples && RA.bufOffset !== RA.BUFFER_SIZE) {
              leftBuffer[RA.bufOffset] = HEAPF32[(((buf)+(count * 8))>>2)];
              rightBuffer[RA.bufOffset] = HEAPF32[(((buf)+(count * 8 + 4))>>2)];
              RA.bufOffset++;
              count++;
              samples--;
           }
           return count;
        },queueAudio:function () {
           var index = RA.bufIndex;
           var startTime;
           if (RA.bufIndex) startTime = RA.buffers[RA.bufIndex - 1].endTime;
           else startTime = RA.context.currentTime;
           RA.buffers[index].endTime = startTime + RA.buffers[index].duration;
           var bufferSource = RA.context.createBufferSource();
           bufferSource.buffer = RA.buffers[index];
           bufferSource.connect(RA.context.destination);
           bufferSource.start(startTime);
           RA.bufIndex++;
           RA.bufOffset = 0;
        },block:function () {
           do {
              RA.process();
           } while (RA.bufIndex === RA.numBuffers - 1);
        }};function _RWebAudioBufferSize() {
        return RA.numBuffers * RA.BUFFER_SIZE + RA.BUFFER_SIZE;
     }
  function _RWebAudioWriteAvail() {
        RA.process();
        return ((RA.numBuffers - RA.bufIndex) * RA.BUFFER_SIZE - RA.bufOffset) * 8;
     }
  function _RWebAudioFree() {
        RA.bufIndex = 0;
        RA.bufOffset = 0;
        return;
     }
  function _RWebAudioSetNonblockState(state) {
        RA.nonblock = state;
     }
  function _RWebAudioStart() {
        return true;
     }
  function _RWebAudioStop() {
        RA.bufIndex = 0;
        RA.bufOffset = 0;
        return true;
     }
  function _RWebAudioWrite(buf, size) {
        RA.process();
        var samples = size / 8;
        var count = 0;
        while (samples) {
           var fill = RA.fillBuffer(buf, samples);
           samples -= fill;
           count += fill;
           buf += fill * 8;
           if (RA.bufOffset === RA.BUFFER_SIZE) {
              if (RA.bufIndex === RA.numBuffers - 1) {
                 if (RA.nonblock) break;
                 else RA.block();
              }
              RA.queueAudio();
           }
        }
        return count * 8;
     }
  function _RWebAudioInit(latency) {
        var ac = window['AudioContext'] || window['webkitAudioContext'];
        if (!ac) return 0;
        RA.context = new ac();
        RA.numBuffers = ((latency * RA.context.sampleRate) / (1000 * RA.BUFFER_SIZE))|0;
        if (RA.numBuffers < 2) RA.numBuffers = 2;
        for (var i = 0; i < RA.numBuffers; i++) RA.buffers[i] = RA.context.createBuffer(2, RA.BUFFER_SIZE, RA.context.sampleRate);
        RA.nonblock = false;
        RA.startTime = 0;
        // chrome hack to get currentTime running
        RA.context.createGain();
        window['setTimeout'](RA.setStartTime, 0);
        Module["pauseMainLoop"]();
        return 1;
     }
  function _RWebAudioSampleRate() {
        return RA.context.sampleRate;
     }
  var _fabsf=Math_abs;
  var _sin=Math_sin;
  var _ceil=Math_ceil;
  function _clock_gettime(clk_id, tp) {
      // int clock_gettime(clockid_t clk_id, struct timespec *tp);
      var now = Date.now();
      HEAP32[((tp)>>2)]=Math.floor(now/1000); // seconds
      HEAP32[(((tp)+(4))>>2)]=(now % 1000) * 1000 * 1000; // nanoseconds (really milliseconds)
      return 0;
    }
  function _llvm_uadd_with_overflow_i32(x, y) {
      x = x>>>0;
      y = y>>>0;
      return ((asm["setTempRet0"](x+y > 4294967295),(x+y)>>>0)|0);
    }
  var GL={counter:1,lastError:0,buffers:[],programs:[],framebuffers:[],renderbuffers:[],textures:[],uniforms:[],shaders:[],currArrayBuffer:0,currElementArrayBuffer:0,byteSizeByTypeRoot:5120,byteSizeByType:[1,1,2,2,4,4,4,2,3,4,8],uniformTable:{},stringCache:{},packAlignment:4,unpackAlignment:4,init:function () {
        Browser.moduleContextCreatedCallbacks.push(GL.initExtensions);
      },recordError:function recordError(errorCode) {
        if (!GL.lastError) {
          GL.lastError = errorCode;
        }
      },getNewId:function (table) {
        var ret = GL.counter++;
        for (var i = table.length; i < ret; i++) {
          table[i] = null;
        }
        return ret;
      },MINI_TEMP_BUFFER_SIZE:16,miniTempBuffer:null,miniTempBufferViews:[0],MAX_TEMP_BUFFER_SIZE:2097152,tempBufferIndexLookup:null,tempVertexBuffers:null,tempIndexBuffers:null,tempQuadIndexBuffer:null,generateTempBuffers:function (quads) {
        GL.tempBufferIndexLookup = new Uint8Array(GL.MAX_TEMP_BUFFER_SIZE+1);
        GL.tempVertexBuffers = [];
        GL.tempIndexBuffers = [];
        var last = -1, curr = -1;
        var size = 1;
        for (var i = 0; i <= GL.MAX_TEMP_BUFFER_SIZE; i++) {
          if (i > size) {
            size <<= 1;
          }
          if (size != last) {
            curr++;
            GL.tempVertexBuffers[curr] = Module.ctx.createBuffer();
            Module.ctx.bindBuffer(Module.ctx.ARRAY_BUFFER, GL.tempVertexBuffers[curr]);
            Module.ctx.bufferData(Module.ctx.ARRAY_BUFFER, size, Module.ctx.DYNAMIC_DRAW);
            Module.ctx.bindBuffer(Module.ctx.ARRAY_BUFFER, null);
            GL.tempIndexBuffers[curr] = Module.ctx.createBuffer();
            Module.ctx.bindBuffer(Module.ctx.ELEMENT_ARRAY_BUFFER, GL.tempIndexBuffers[curr]);
            Module.ctx.bufferData(Module.ctx.ELEMENT_ARRAY_BUFFER, size, Module.ctx.DYNAMIC_DRAW);
            Module.ctx.bindBuffer(Module.ctx.ELEMENT_ARRAY_BUFFER, null);
            last = size;
          }
          GL.tempBufferIndexLookup[i] = curr;
        }
        if (quads) {
          // GL_QUAD indexes can be precalculated
          GL.tempQuadIndexBuffer = Module.ctx.createBuffer();
          Module.ctx.bindBuffer(Module.ctx.ELEMENT_ARRAY_BUFFER, GL.tempQuadIndexBuffer);
          var numIndexes = GL.MAX_TEMP_BUFFER_SIZE >> 1;
          var quadIndexes = new Uint16Array(numIndexes);
          var i = 0, v = 0;
          while (1) {
            quadIndexes[i++] = v;
            if (i >= numIndexes) break;
            quadIndexes[i++] = v+1;
            if (i >= numIndexes) break;
            quadIndexes[i++] = v+2;
            if (i >= numIndexes) break;
            quadIndexes[i++] = v;
            if (i >= numIndexes) break;
            quadIndexes[i++] = v+2;
            if (i >= numIndexes) break;
            quadIndexes[i++] = v+3;
            if (i >= numIndexes) break;
            v += 4;
          }
          Module.ctx.bufferData(Module.ctx.ELEMENT_ARRAY_BUFFER, quadIndexes, Module.ctx.STATIC_DRAW);
          Module.ctx.bindBuffer(Module.ctx.ELEMENT_ARRAY_BUFFER, null);
        }
      },findToken:function (source, token) {
        function isIdentChar(ch) {
          if (ch >= 48 && ch <= 57) // 0-9
            return true;
          if (ch >= 65 && ch <= 90) // A-Z
            return true;
          if (ch >= 97 && ch <= 122) // a-z
            return true;
          return false;
        }
        var i = -1;
        do {
          i = source.indexOf(token, i + 1);
          if (i < 0) {
            break;
          }
          if (i > 0 && isIdentChar(source[i - 1])) {
            continue;
          }
          i += token.length;
          if (i < source.length - 1 && isIdentChar(source[i + 1])) {
            continue;
          }
          return true;
        } while (true);
        return false;
      },getSource:function (shader, count, string, length) {
        var source = '';
        for (var i = 0; i < count; ++i) {
          var frag;
          if (length) {
            var len = HEAP32[(((length)+(i*4))>>2)];
            if (len < 0) {
              frag = Pointer_stringify(HEAP32[(((string)+(i*4))>>2)]);
            } else {
              frag = Pointer_stringify(HEAP32[(((string)+(i*4))>>2)], len);
            }
          } else {
            frag = Pointer_stringify(HEAP32[(((string)+(i*4))>>2)]);
          }
          source += frag;
        }
        // Let's see if we need to enable the standard derivatives extension
        type = Module.ctx.getShaderParameter(GL.shaders[shader], 0x8B4F /* GL_SHADER_TYPE */);
        if (type == 0x8B30 /* GL_FRAGMENT_SHADER */) {
          if (GL.findToken(source, "dFdx") ||
              GL.findToken(source, "dFdy") ||
              GL.findToken(source, "fwidth")) {
            source = "#extension GL_OES_standard_derivatives : enable\n" + source;
            var extension = Module.ctx.getExtension("OES_standard_derivatives");
          }
        }
        return source;
      },computeImageSize:function (width, height, sizePerPixel, alignment) {
        function roundedToNextMultipleOf(x, y) {
          return Math.floor((x + y - 1) / y) * y
        }
        var plainRowSize = width * sizePerPixel;
        var alignedRowSize = roundedToNextMultipleOf(plainRowSize, alignment);
        return (height <= 0) ? 0 :
                 ((height - 1) * alignedRowSize + plainRowSize);
      },getTexPixelData:function (type, format, width, height, pixels, internalFormat) {
        var sizePerPixel;
        switch (type) {
          case 0x1401 /* GL_UNSIGNED_BYTE */:
            switch (format) {
              case 0x1906 /* GL_ALPHA */:
              case 0x1909 /* GL_LUMINANCE */:
                sizePerPixel = 1;
                break;
              case 0x1907 /* GL_RGB */:
                sizePerPixel = 3;
                break;
              case 0x1908 /* GL_RGBA */:
                sizePerPixel = 4;
                break;
              case 0x190A /* GL_LUMINANCE_ALPHA */:
                sizePerPixel = 2;
                break;
              default:
                throw 'Invalid format (' + format + ')';
            }
            break;
          case 0x1403 /* GL_UNSIGNED_SHORT */:
            if (format == 0x1902 /* GL_DEPTH_COMPONENT */) {
              sizePerPixel = 2;
            } else {
              throw 'Invalid format (' + format + ')';
            }
            break;
          case 0x1405 /* GL_UNSIGNED_INT */:
            if (format == 0x1902 /* GL_DEPTH_COMPONENT */) {
              sizePerPixel = 4;
            } else {
              throw 'Invalid format (' + format + ')';
            }
            break;
          case 0x84FA /* UNSIGNED_INT_24_8_WEBGL */:
            sizePerPixel = 4;
            break;
          case 0x8363 /* GL_UNSIGNED_SHORT_5_6_5 */:
          case 0x8033 /* GL_UNSIGNED_SHORT_4_4_4_4 */:
          case 0x8034 /* GL_UNSIGNED_SHORT_5_5_5_1 */:
            sizePerPixel = 2;
            break;
          case 0x1406 /* GL_FLOAT */:
            switch (format) {
              case 0x1907 /* GL_RGB */:
                sizePerPixel = 3*4;
                break;
              case 0x1908 /* GL_RGBA */:
                sizePerPixel = 4*4;
                break;
              default:
                throw 'Invalid format (' + format + ')';
            }
            internalFormat = Module.ctx.RGBA;
            break;
          default:
            throw 'Invalid type (' + type + ')';
        }
        var bytes = GL.computeImageSize(width, height, sizePerPixel, GL.unpackAlignment);
        if (type == 0x1401 /* GL_UNSIGNED_BYTE */) {
          pixels = HEAPU8.subarray((pixels),(pixels+bytes));
        } else if (type == 0x1406 /* GL_FLOAT */) {
          pixels = HEAPF32.subarray((pixels)>>2,(pixels+bytes)>>2);
        } else if (type == 0x1405 /* GL_UNSIGNED_INT */ || type == 0x84FA /* UNSIGNED_INT_24_8_WEBGL */) {
          pixels = HEAPU32.subarray((pixels)>>2,(pixels+bytes)>>2);
        } else {
          pixels = HEAPU16.subarray((pixels)>>1,(pixels+bytes)>>1);
        }
        return {
          pixels: pixels,
          internalFormat: internalFormat
        }
      },initExtensions:function () {
        if (GL.initExtensions.done) return;
        GL.initExtensions.done = true;
        if (!Module.useWebGL) return; // an app might link both gl and 2d backends
        GL.miniTempBuffer = new Float32Array(GL.MINI_TEMP_BUFFER_SIZE);
        for (var i = 0; i < GL.MINI_TEMP_BUFFER_SIZE; i++) {
          GL.miniTempBufferViews[i] = GL.miniTempBuffer.subarray(0, i+1);
        }
        GL.maxVertexAttribs = Module.ctx.getParameter(Module.ctx.MAX_VERTEX_ATTRIBS);
        // Detect the presence of a few extensions manually, this GL interop layer itself will need to know if they exist. 
        GL.compressionExt = Module.ctx.getExtension('WEBGL_compressed_texture_s3tc') ||
                            Module.ctx.getExtension('MOZ_WEBGL_compressed_texture_s3tc') ||
                            Module.ctx.getExtension('WEBKIT_WEBGL_compressed_texture_s3tc');
        GL.anisotropicExt = Module.ctx.getExtension('EXT_texture_filter_anisotropic') ||
                            Module.ctx.getExtension('MOZ_EXT_texture_filter_anisotropic') ||
                            Module.ctx.getExtension('WEBKIT_EXT_texture_filter_anisotropic');
        GL.floatExt = Module.ctx.getExtension('OES_texture_float');
        // These are the 'safe' feature-enabling extensions that don't add any performance impact related to e.g. debugging, and
        // should be enabled by default so that client GLES2/GL code will not need to go through extra hoops to get its stuff working.
        // As new extensions are ratified at http://www.khronos.org/registry/webgl/extensions/ , feel free to add your new extensions
        // here, as long as they don't produce a performance impact for users that might not be using those extensions.
        // E.g. debugging-related extensions should probably be off by default.
        var automaticallyEnabledExtensions = [ "OES_texture_float", "OES_texture_half_float", "OES_standard_derivatives",
                                               "OES_vertex_array_object", "WEBGL_compressed_texture_s3tc", "WEBGL_depth_texture",
                                               "OES_element_index_uint", "EXT_texture_filter_anisotropic", "ANGLE_instanced_arrays",
                                               "OES_texture_float_linear", "OES_texture_half_float_linear", "WEBGL_compressed_texture_atc",
                                               "WEBGL_compressed_texture_pvrtc", "EXT_color_buffer_half_float", "WEBGL_color_buffer_float",
                                               "EXT_frag_depth", "EXT_sRGB", "WEBGL_draw_buffers", "WEBGL_shared_resources" ];
        function shouldEnableAutomatically(extension) {
          for(var i in automaticallyEnabledExtensions) {
            var include = automaticallyEnabledExtensions[i];
            if (ext.indexOf(include) != -1) {
              return true;
            }
          }
          return false;
        }
        var extensions = Module.ctx.getSupportedExtensions();
        for(var e in extensions) {
          var ext = extensions[e].replace('MOZ_', '').replace('WEBKIT_', '');
          if (automaticallyEnabledExtensions.indexOf(ext) != -1) {
            Module.ctx.getExtension(ext); // Calling .getExtension enables that extension permanently, no need to store the return value to be enabled.
          }
        }
      },populateUniformTable:function (program) {
        var p = GL.programs[program];
        GL.uniformTable[program] = {};
        var ptable = GL.uniformTable[program];
        // A program's uniformTable maps the string name of an uniform to an integer location of that uniform.
        // The global GL.uniforms map maps integer locations to WebGLUniformLocations.
        var numUniforms = Module.ctx.getProgramParameter(p, Module.ctx.ACTIVE_UNIFORMS);
        for (var i = 0; i < numUniforms; ++i) {
          var u = Module.ctx.getActiveUniform(p, i);
          var name = u.name;
          // Strip off any trailing array specifier we might have got, e.g. "[0]".
          if (name.indexOf(']', name.length-1) !== -1) {
            var ls = name.lastIndexOf('[');
            name = name.slice(0, ls);
          }
          // Optimize memory usage slightly: If we have an array of uniforms, e.g. 'vec3 colors[3];', then 
          // only store the string 'colors' in ptable, and 'colors[0]', 'colors[1]' and 'colors[2]' will be parsed as 'colors'+i.
          // Note that for the GL.uniforms table, we still need to fetch the all WebGLUniformLocations for all the indices.
          var loc = Module.ctx.getUniformLocation(p, name);
          var id = GL.getNewId(GL.uniforms);
          ptable[name] = [u.size, id];
          GL.uniforms[id] = loc;
          for (var j = 1; j < u.size; ++j) {
            var n = name + '['+j+']';
            loc = Module.ctx.getUniformLocation(p, n);
            id = GL.getNewId(GL.uniforms);
            GL.uniforms[id] = loc;
          }
        }
      }};function _glDeleteTextures(n, textures) {
      for (var i = 0; i < n; i++) {
        var id = HEAP32[(((textures)+(i*4))>>2)];
        var texture = GL.textures[id];
        Module.ctx.deleteTexture(texture);
        texture.name = 0;
        GL.textures[id] = null;
      }
    }
  function _glDeleteFramebuffers(n, framebuffers) {
      for (var i = 0; i < n; ++i) {
        var id = HEAP32[(((framebuffers)+(i*4))>>2)];
        var framebuffer = GL.framebuffers[id];
        Module.ctx.deleteFramebuffer(framebuffer);
        framebuffer.name = 0;
        GL.framebuffers[id] = null;
      }
    }
  function _glViewport(x0, x1, x2, x3) { Module.ctx.viewport(x0, x1, x2, x3) }
  function _glGenTextures(n, textures) {
      for (var i = 0; i < n; i++) {
        var id = GL.getNewId(GL.textures);
        var texture = Module.ctx.createTexture();
        texture.name = id;
        GL.textures[id] = texture;
        HEAP32[(((textures)+(i*4))>>2)]=id;
      }
    }
  function _glBindTexture(target, texture) {
      Module.ctx.bindTexture(target, texture ? GL.textures[texture] : null);
    }
  function _glTexParameteri(x0, x1, x2) { Module.ctx.texParameteri(x0, x1, x2) }
  function _glPixelStorei(pname, param) {
      if (pname == 0x0D05 /* GL_PACK_ALIGNMENT */) {
        GL.packAlignment = param;
      } else if (pname == 0x0cf5 /* GL_UNPACK_ALIGNMENT */) {
        GL.unpackAlignment = param;
      }
      Module.ctx.pixelStorei(pname, param);
    }
  function _glTexImage2D(target, level, internalFormat, width, height, border, format, type, pixels) {
      if (pixels) {
        var data = GL.getTexPixelData(type, format, width, height, pixels, internalFormat);
        pixels = data.pixels;
        internalFormat = data.internalFormat;
      } else {
        pixels = null;
      }
      Module.ctx.texImage2D(target, level, internalFormat, width, height, border, format, type, pixels);
    }
  function _glBindFramebuffer(target, framebuffer) {
      Module.ctx.bindFramebuffer(target, framebuffer ? GL.framebuffers[framebuffer] : null);
    }
  function _glReadPixels(x, y, width, height, format, type, pixels) {
      var sizePerPixel;
      switch (format) {
        case 0x1907 /* GL_RGB */:
          sizePerPixel = 3;
          break;
        case 0x1908 /* GL_RGBA */:
          sizePerPixel = 4;
          break;
        default: throw 'unsupported glReadPixels format';
      }
      var totalSize = width*height*sizePerPixel;
      Module.ctx.readPixels(x, y, width, height, format, type, HEAPU8.subarray(pixels, pixels + totalSize));
    }
  function _glDeleteRenderbuffers(n, renderbuffers) {
      for (var i = 0; i < n; i++) {
        var id = HEAP32[(((renderbuffers)+(i*4))>>2)];
        var renderbuffer = GL.renderbuffers[id];
        Module.ctx.deleteRenderbuffer(renderbuffer);
        renderbuffer.name = 0;
        GL.renderbuffers[id] = null;
      }
    }
  function _glGetIntegerv(name_, p) {
      switch(name_) { // Handle a few trivial GLES values
        case 0x8DFA: // GL_SHADER_COMPILER
          HEAP32[((p)>>2)]=1;
          return;
        case 0x8DF9: // GL_NUM_SHADER_BINARY_FORMATS
          HEAP32[((p)>>2)]=0;
          return;
        case 0x86A2: // GL_NUM_COMPRESSED_TEXTURE_FORMATS
          // WebGL doesn't have GL_NUM_COMPRESSED_TEXTURE_FORMATS (it's obsolete since GL_COMPRESSED_TEXTURE_FORMATS returns a JS array that can be queried for length),
          // so implement it ourselves to allow C++ GLES2 code get the length.
          var formats = Module.ctx.getParameter(0x86A3 /*GL_COMPRESSED_TEXTURE_FORMATS*/);
          HEAP32[((p)>>2)]=formats.length;
          return;
      }
      var result = Module.ctx.getParameter(name_);
      switch (typeof(result)) {
        case "number":
          HEAP32[((p)>>2)]=result;
          break;
        case "boolean":
          HEAP8[(p)]=result ? 1 : 0;
          break;
        case "string":
          throw 'Native code calling glGetIntegerv(' + name_ + ') on a name which returns a string!';
        case "object":
          if (result === null) {
            HEAP32[((p)>>2)]=0;
          } else if (result instanceof Float32Array ||
                     result instanceof Uint32Array ||
                     result instanceof Int32Array ||
                     result instanceof Array) {
            for (var i = 0; i < result.length; ++i) {
              HEAP32[(((p)+(i*4))>>2)]=result[i];
            }
          } else if (result instanceof WebGLBuffer) {
            HEAP32[((p)>>2)]=result.name | 0;
          } else if (result instanceof WebGLProgram) {
            HEAP32[((p)>>2)]=result.name | 0;
          } else if (result instanceof WebGLFramebuffer) {
            HEAP32[((p)>>2)]=result.name | 0;
          } else if (result instanceof WebGLRenderbuffer) {
            HEAP32[((p)>>2)]=result.name | 0;
          } else if (result instanceof WebGLTexture) {
            HEAP32[((p)>>2)]=result.name | 0;
          } else {
            throw 'Unknown object returned from WebGL getParameter';
          }
          break;
        case "undefined":
          throw 'Native code calling glGetIntegerv(' + name_ + ') and it returns undefined';
        default:
          throw 'Why did we hit the default case?';
      }
    }
  function _glGenFramebuffers(n, ids) {
      for (var i = 0; i < n; ++i) {
        var id = GL.getNewId(GL.framebuffers);
        var framebuffer = Module.ctx.createFramebuffer();
        framebuffer.name = id;
        GL.framebuffers[id] = framebuffer;
        HEAP32[(((ids)+(i*4))>>2)]=id;
      }
    }
  function _glGenRenderbuffers(n, renderbuffers) {
      for (var i = 0; i < n; i++) {
        var id = GL.getNewId(GL.renderbuffers);
        var renderbuffer = Module.ctx.createRenderbuffer();
        renderbuffer.name = id;
        GL.renderbuffers[id] = renderbuffer;
        HEAP32[(((renderbuffers)+(i*4))>>2)]=id;
      }
    }
  function _glFramebufferTexture2D(target, attachment, textarget, texture, level) {
      Module.ctx.framebufferTexture2D(target, attachment, textarget,
                                      GL.textures[texture], level);
    }
  function _glBindRenderbuffer(target, renderbuffer) {
      Module.ctx.bindRenderbuffer(target, renderbuffer ? GL.renderbuffers[renderbuffer] : null);
    }
  function _glRenderbufferStorage(x0, x1, x2, x3) { Module.ctx.renderbufferStorage(x0, x1, x2, x3) }
  function _glFramebufferRenderbuffer(target, attachment, renderbuffertarget, renderbuffer) {
      Module.ctx.framebufferRenderbuffer(target, attachment, renderbuffertarget,
                                         GL.renderbuffers[renderbuffer]);
    }
  function _glCheckFramebufferStatus(x0) { return Module.ctx.checkFramebufferStatus(x0) }
  function _glGetString(name_) {
      if (GL.stringCache[name_]) return GL.stringCache[name_];
      var ret; 
      switch(name_) {
        case 0x1F00 /* GL_VENDOR */:
        case 0x1F01 /* GL_RENDERER */:
        case 0x1F02 /* GL_VERSION */:
          ret = allocate(intArrayFromString(Module.ctx.getParameter(name_)), 'i8', ALLOC_NORMAL);
          break;
        case 0x1F03 /* GL_EXTENSIONS */:
          var exts = Module.ctx.getSupportedExtensions();
          var gl_exts = [];
          for (i in exts) {
            gl_exts.push(exts[i]);
            gl_exts.push("GL_" + exts[i]);
          }
          ret = allocate(intArrayFromString(gl_exts.join(' ')), 'i8', ALLOC_NORMAL);
          break;
        case 0x8B8C /* GL_SHADING_LANGUAGE_VERSION */:
          ret = allocate(intArrayFromString('OpenGL ES GLSL 1.00 (WebGL)'), 'i8', ALLOC_NORMAL);
          break;
        default:
          throw 'Failure: Invalid glGetString value: ' + name_;
      }
      GL.stringCache[name_] = ret;
      return ret;
    }
  function _glDisable(x0) { Module.ctx.disable(x0) }
  function _glBlendFunc(x0, x1) { Module.ctx.blendFunc(x0, x1) }
  function _glClearColor(x0, x1, x2, x3) { Module.ctx.clearColor(x0, x1, x2, x3) }
  function _glClear(x0) { Module.ctx.clear(x0) }
  function _glDrawArrays(mode, first, count) {
      Module.ctx.drawArrays(mode, first, count);
    }
  function _glEnable(x0) { Module.ctx.enable(x0) }
  function _glTexSubImage2D(target, level, xoffset, yoffset, width, height, format, type, pixels) {
      if (pixels) {
        var data = GL.getTexPixelData(type, format, width, height, pixels, -1);
        pixels = data.pixels;
      } else {
        pixels = null;
      }
      Module.ctx.texSubImage2D(target, level, xoffset, yoffset, width, height, format, type, pixels);
    }
  function _glGetError() {
      // First return any GL error generated by the emscripten library_gl.js interop layer.
      if (GL.lastError) {
        var error = GL.lastError;
        GL.lastError = 0/*GL_NO_ERROR*/;
        return error;
      } else { // If there were none, return the GL error from the browser GL context.
        return Module.ctx.getError();
      }
    }
  var _cosf=Math_cos;
  var _sinf=Math_sin;
  function _glGetFloatv(name_, p) {
      var result = Module.ctx.getParameter(name_);
      switch (typeof(result)) {
        case "number":
          HEAPF32[((p)>>2)]=result;
          break;
        case "boolean":
          HEAPF32[((p)>>2)]=result ? 1.0 : 0.0;
          break;
        case "string":
            HEAPF32[((p)>>2)]=0;
        case "object":
          if (result === null) {
            throw 'Native code calling glGetFloatv(' + name_ + ') and it returns null';
          } else if (result instanceof Float32Array ||
                     result instanceof Uint32Array ||
                     result instanceof Int32Array ||
                     result instanceof Array) {
            for (var i = 0; i < result.length; ++i) {
              HEAPF32[(((p)+(i*4))>>2)]=result[i];
            }
          } else if (result instanceof WebGLBuffer) {
            HEAPF32[((p)>>2)]=result.name | 0;
          } else if (result instanceof WebGLProgram) {
            HEAPF32[((p)>>2)]=result.name | 0;
          } else if (result instanceof WebGLFramebuffer) {
            HEAPF32[((p)>>2)]=result.name | 0;
          } else if (result instanceof WebGLRenderbuffer) {
            HEAPF32[((p)>>2)]=result.name | 0;
          } else if (result instanceof WebGLTexture) {
            HEAPF32[((p)>>2)]=result.name | 0;
          } else {
            throw 'Unknown object returned from WebGL getParameter';
          }
          break;
        case "undefined":
          throw 'Native code calling glGetFloatv(' + name_ + ') and it returns undefined';
        default:
          throw 'Why did we hit the default case?';
      }
    }
  function _glGetBooleanv(name_, p) {
      var result = Module.ctx.getParameter(name_);
      switch (typeof(result)) {
        case "number":
          HEAP8[(p)]=result != 0;
          break;
        case "boolean":
          HEAP8[(p)]=result != 0;
          break;
        case "string":
          throw 'Native code calling glGetBooleanv(' + name_ + ') on a name which returns a string!';
        case "object":
          if (result === null) {
            HEAP8[(p)]=0;
          } else if (result instanceof Float32Array ||
                     result instanceof Uint32Array ||
                     result instanceof Int32Array ||
                     result instanceof Array) {
            for (var i = 0; i < result.length; ++i) {
              HEAP8[(((p)+(i))|0)]=result[i] != 0;
            }
          } else if (result instanceof WebGLBuffer ||
                     result instanceof WebGLProgram ||
                     result instanceof WebGLFramebuffer ||
                     result instanceof WebGLRenderbuffer ||
                     result instanceof WebGLTexture) {
            HEAP8[(p)]=1; // non-zero ID is always 1!
          } else {
            throw 'Unknown object returned from WebGL getParameter';
          }
          break;
        case "undefined":
            throw 'Unknown object returned from WebGL getParameter';
        default:
          throw 'Why did we hit the default case?';
      }
    }
  function _glCompressedTexImage2D(target, level, internalFormat, width, height, border, imageSize, data) {
      if (data) {
        data = HEAPU8.subarray((data),(data+imageSize));
      } else {
        data = null;
      }
      Module.ctx['compressedTexImage2D'](target, level, internalFormat, width, height, border, data);
    }
  function _glCompressedTexSubImage2D(target, level, xoffset, yoffset, width, height, format, imageSize, data) {
      if (data) {
        data = HEAPU8.subarray((data),(data+imageSize));
      } else {
        data = null;
      }
      Module.ctx['compressedTexSubImage2D'](target, level, xoffset, yoffset, width, height, data);
    }
  function _glGetTexParameterfv(target, pname, params) {
      HEAPF32[((params)>>2)]=Module.getTexParameter(target, pname);
    }
  function _glGetTexParameteriv(target, pname, params) {
      HEAP32[((params)>>2)]=Module.getTexParameter(target, pname);
    }
  function _glTexParameterfv(target, pname, params) {
      var param = HEAPF32[((params)>>2)];
      Module.ctx.texParameterf(target, pname, param);
    }
  function _glTexParameteriv(target, pname, params) {
      var param = HEAP32[((params)>>2)];
      Module.ctx.texParameteri(target, pname, param);
    }
  function _glIsTexture(texture) {
      var texture = GL.textures[texture];
      if (!texture) return 0;
      return Module.ctx.isTexture(texture);
    }
  function _glGenBuffers(n, buffers) {
      for (var i = 0; i < n; i++) {
        var id = GL.getNewId(GL.buffers);
        var buffer = Module.ctx.createBuffer();
        buffer.name = id;
        GL.buffers[id] = buffer;
        HEAP32[(((buffers)+(i*4))>>2)]=id;
      }
    }
  function _glDeleteBuffers(n, buffers) {
      for (var i = 0; i < n; i++) {
        var id = HEAP32[(((buffers)+(i*4))>>2)];
        var buffer = GL.buffers[id];
        // From spec: "glDeleteBuffers silently ignores 0's and names that do not
        // correspond to existing buffer objects."
        if (!buffer) continue;
        Module.ctx.deleteBuffer(buffer);
        buffer.name = 0;
        GL.buffers[id] = null;
        if (id == GL.currArrayBuffer) GL.currArrayBuffer = 0;
        if (id == GL.currElementArrayBuffer) GL.currElementArrayBuffer = 0;
      }
    }
  function _glGetBufferParameteriv(target, value, data) {
      HEAP32[((data)>>2)]=Module.ctx.getBufferParameter(target, value);
    }
  function _glBufferData(target, size, data, usage) {
      switch (usage) { // fix usages, WebGL only has *_DRAW
        case 0x88E1: // GL_STREAM_READ
        case 0x88E2: // GL_STREAM_COPY
          usage = 0x88E0; // GL_STREAM_DRAW
          break;
        case 0x88E5: // GL_STATIC_READ
        case 0x88E6: // GL_STATIC_COPY
          usage = 0x88E4; // GL_STATIC_DRAW
          break;
        case 0x88E9: // GL_DYNAMIC_READ
        case 0x88EA: // GL_DYNAMIC_COPY
          usage = 0x88E8; // GL_DYNAMIC_DRAW
          break;
      }
      Module.ctx.bufferData(target, HEAPU8.subarray(data, data+size), usage);
    }
  function _glBufferSubData(target, offset, size, data) {
      Module.ctx.bufferSubData(target, offset, HEAPU8.subarray(data, data+size));
    }
  function _glIsBuffer(buffer) {
      var b = GL.buffers[buffer];
      if (!b) return 0;
      return Module.ctx.isBuffer(b);
    }
  function _glGetRenderbufferParameteriv(target, pname, params) {
      HEAP32[((params)>>2)]=Module.ctx.getRenderbufferParameter(target, pname);
    }
  function _glIsRenderbuffer(renderbuffer) {
      var rb = GL.renderbuffers[renderbuffer];
      if (!rb) return 0;
      return Module.ctx.isRenderbuffer(rb);
    }
  function _glGetUniformfv(program, location, params) {
      var data = Module.ctx.getUniform(GL.programs[program], GL.uniforms[location]);
      if (typeof data == 'number') {
        HEAPF32[((params)>>2)]=data;
      } else {
        for (var i = 0; i < data.length; i++) {
          HEAPF32[(((params)+(i))>>2)]=data[i];
        }
      }
    }
  function _glGetUniformiv(program, location, params) {
      var data = Module.ctx.getUniform(GL.programs[program], GL.uniforms[location]);
      if (typeof data == 'number' || typeof data == 'boolean') {
        HEAP32[((params)>>2)]=data;
      } else {
        for (var i = 0; i < data.length; i++) {
          HEAP32[(((params)+(i))>>2)]=data[i];
        }
      }
    }
  function _glGetUniformLocation(program, name) {
      name = Pointer_stringify(name);
      var arrayOffset = 0;
      // If user passed an array accessor "[index]", parse the array index off the accessor.
      if (name.indexOf(']', name.length-1) !== -1) {
        var ls = name.lastIndexOf('[');
        var arrayIndex = name.slice(ls+1, -1);
        if (arrayIndex.length > 0) {
          arrayOffset = parseInt(arrayIndex);
          if (arrayOffset < 0) {
            return -1;
          }
        }
        name = name.slice(0, ls);
      }
      var ptable = GL.uniformTable[program];
      if (!ptable) {
        return -1;
      }
      var uniformInfo = ptable[name]; // returns pair [ dimension_of_uniform_array, uniform_location ]
      if (uniformInfo && arrayOffset < uniformInfo[0]) { // Check if user asked for an out-of-bounds element, i.e. for 'vec4 colors[3];' user could ask for 'colors[10]' which should return -1.
        return uniformInfo[1]+arrayOffset;
      } else {
        return -1;
      }
    }
  function _glGetVertexAttribfv(index, pname, params) {
      var data = Module.ctx.getVertexAttrib(index, pname);
      if (typeof data == 'number') {
        HEAPF32[((params)>>2)]=data;
      } else {
        for (var i = 0; i < data.length; i++) {
          HEAPF32[(((params)+(i))>>2)]=data[i];
        }
      }
    }
  function _glGetVertexAttribiv(index, pname, params) {
      var data = Module.ctx.getVertexAttrib(index, pname);
      if (typeof data == 'number' || typeof data == 'boolean') {
        HEAP32[((params)>>2)]=data;
      } else {
        for (var i = 0; i < data.length; i++) {
          HEAP32[(((params)+(i))>>2)]=data[i];
        }
      }
    }
  function _glGetVertexAttribPointerv(index, pname, pointer) {
      HEAP32[((pointer)>>2)]=Module.ctx.getVertexAttribOffset(index, pname);
    }
  function _glGetActiveUniform(program, index, bufSize, length, size, type, name) {
      program = GL.programs[program];
      var info = Module.ctx.getActiveUniform(program, index);
      var infoname = info.name.slice(0, Math.max(0, bufSize - 1));
      writeStringToMemory(infoname, name);
      if (length) {
        HEAP32[((length)>>2)]=infoname.length;
      }
      if (size) {
        HEAP32[((size)>>2)]=info.size;
      }
      if (type) {
        HEAP32[((type)>>2)]=info.type;
      }
    }
  function _glUniform1f(location, v0) {
      location = GL.uniforms[location];
      Module.ctx.uniform1f(location, v0);
    }
  function _glUniform2f(location, v0, v1) {
      location = GL.uniforms[location];
      Module.ctx.uniform2f(location, v0, v1);
    }
  function _glUniform3f(location, v0, v1, v2) {
      location = GL.uniforms[location];
      Module.ctx.uniform3f(location, v0, v1, v2);
    }
  function _glUniform4f(location, v0, v1, v2, v3) {
      location = GL.uniforms[location];
      Module.ctx.uniform4f(location, v0, v1, v2, v3);
    }
  function _glUniform1i(location, v0) {
      location = GL.uniforms[location];
      Module.ctx.uniform1i(location, v0);
    }
  function _glUniform2i(location, v0, v1) {
      location = GL.uniforms[location];
      Module.ctx.uniform2i(location, v0, v1);
    }
  function _glUniform3i(location, v0, v1, v2) {
      location = GL.uniforms[location];
      Module.ctx.uniform3i(location, v0, v1, v2);
    }
  function _glUniform4i(location, v0, v1, v2, v3) {
      location = GL.uniforms[location];
      Module.ctx.uniform4i(location, v0, v1, v2, v3);
    }
  function _glUniform1iv(location, count, value) {
      location = GL.uniforms[location];
      value = HEAP32.subarray((value)>>2,(value+count*4)>>2);
      Module.ctx.uniform1iv(location, value);
    }
  function _glUniform2iv(location, count, value) {
      location = GL.uniforms[location];
      count *= 2;
      value = HEAP32.subarray((value)>>2,(value+count*4)>>2);
      Module.ctx.uniform2iv(location, value);
    }
  function _glUniform3iv(location, count, value) {
      location = GL.uniforms[location];
      count *= 3;
      value = HEAP32.subarray((value)>>2,(value+count*4)>>2);
      Module.ctx.uniform3iv(location, value);
    }
  function _glUniform4iv(location, count, value) {
      location = GL.uniforms[location];
      count *= 4;
      value = HEAP32.subarray((value)>>2,(value+count*4)>>2);
      Module.ctx.uniform4iv(location, value);
    }
  function _glUniform1fv(location, count, value) {
      location = GL.uniforms[location];
      var view;
      if (count == 1) {
        // avoid allocation for the common case of uploading one uniform
        view = GL.miniTempBufferViews[0];
        view[0] = HEAPF32[((value)>>2)];
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*4)>>2);
      }
      Module.ctx.uniform1fv(location, view);
    }
  function _glUniform2fv(location, count, value) {
      location = GL.uniforms[location];
      var view;
      if (count == 1) {
        // avoid allocation for the common case of uploading one uniform
        view = GL.miniTempBufferViews[1];
        view[0] = HEAPF32[((value)>>2)];
        view[1] = HEAPF32[(((value)+(4))>>2)];
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*8)>>2);
      }
      Module.ctx.uniform2fv(location, view);
    }
  function _glUniform3fv(location, count, value) {
      location = GL.uniforms[location];
      var view;
      if (count == 1) {
        // avoid allocation for the common case of uploading one uniform
        view = GL.miniTempBufferViews[2];
        view[0] = HEAPF32[((value)>>2)];
        view[1] = HEAPF32[(((value)+(4))>>2)];
        view[2] = HEAPF32[(((value)+(8))>>2)];
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*12)>>2);
      }
      Module.ctx.uniform3fv(location, view);
    }
  function _glUniform4fv(location, count, value) {
      location = GL.uniforms[location];
      var view;
      if (count == 1) {
        // avoid allocation for the common case of uploading one uniform
        view = GL.miniTempBufferViews[3];
        view[0] = HEAPF32[((value)>>2)];
        view[1] = HEAPF32[(((value)+(4))>>2)];
        view[2] = HEAPF32[(((value)+(8))>>2)];
        view[3] = HEAPF32[(((value)+(12))>>2)];
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*16)>>2);
      }
      Module.ctx.uniform4fv(location, view);
    }
  function _glUniformMatrix2fv(location, count, transpose, value) {
      location = GL.uniforms[location];
      var view;
      if (count == 1) {
        // avoid allocation for the common case of uploading one uniform matrix
        view = GL.miniTempBufferViews[3];
        for (var i = 0; i < 4; i++) {
          view[i] = HEAPF32[(((value)+(i*4))>>2)];
        }
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*16)>>2);
      }
      Module.ctx.uniformMatrix2fv(location, transpose, view);
    }
  function _glUniformMatrix3fv(location, count, transpose, value) {
      location = GL.uniforms[location];
      var view;
      if (count == 1) {
        // avoid allocation for the common case of uploading one uniform matrix
        view = GL.miniTempBufferViews[8];
        for (var i = 0; i < 9; i++) {
          view[i] = HEAPF32[(((value)+(i*4))>>2)];
        }
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*36)>>2);
      }
      Module.ctx.uniformMatrix3fv(location, transpose, view);
    }
  function _glUniformMatrix4fv(location, count, transpose, value) {
      location = GL.uniforms[location];
      var view;
      if (count == 1) {
        // avoid allocation for the common case of uploading one uniform matrix
        view = GL.miniTempBufferViews[15];
        for (var i = 0; i < 16; i++) {
          view[i] = HEAPF32[(((value)+(i*4))>>2)];
        }
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*64)>>2);
      }
      Module.ctx.uniformMatrix4fv(location, transpose, view);
    }
  function _glBindBuffer(target, buffer) {
      var bufferObj = buffer ? GL.buffers[buffer] : null;
      if (target == Module.ctx.ARRAY_BUFFER) {
        GL.currArrayBuffer = buffer;
      } else if (target == Module.ctx.ELEMENT_ARRAY_BUFFER) {
        GL.currElementArrayBuffer = buffer;
      }
      Module.ctx.bindBuffer(target, bufferObj);
    }
  function _glVertexAttrib1fv(index, v) {
      v = HEAPF32.subarray((v)>>2,(v+4)>>2);
      Module.ctx.vertexAttrib1fv(index, v);
    }
  function _glVertexAttrib2fv(index, v) {
      v = HEAPF32.subarray((v)>>2,(v+8)>>2);
      Module.ctx.vertexAttrib2fv(index, v);
    }
  function _glVertexAttrib3fv(index, v) {
      v = HEAPF32.subarray((v)>>2,(v+12)>>2);
      Module.ctx.vertexAttrib3fv(index, v);
    }
  function _glVertexAttrib4fv(index, v) {
      v = HEAPF32.subarray((v)>>2,(v+16)>>2);
      Module.ctx.vertexAttrib4fv(index, v);
    }
  function _glGetAttribLocation(program, name) {
      program = GL.programs[program];
      name = Pointer_stringify(name);
      return Module.ctx.getAttribLocation(program, name);
    }
  function _glGetActiveAttrib(program, index, bufSize, length, size, type, name) {
      program = GL.programs[program];
      var info = Module.ctx.getActiveAttrib(program, index);
      var infoname = info.name.slice(0, Math.max(0, bufSize - 1));
      writeStringToMemory(infoname, name);
      if (length) {
        HEAP32[((length)>>2)]=infoname.length;
      }
      if (size) {
        HEAP32[((size)>>2)]=info.size;
      }
      if (type) {
        HEAP32[((type)>>2)]=info.type;
      }
    }
  function _glCreateShader(shaderType) {
      var id = GL.getNewId(GL.shaders);
      GL.shaders[id] = Module.ctx.createShader(shaderType);
      return id;
    }
  function _glDeleteShader(shader) {
      Module.ctx.deleteShader(GL.shaders[shader]);
      GL.shaders[shader] = null;
    }
  function _glGetAttachedShaders(program, maxCount, count, shaders) {
      var result = Module.ctx.getAttachedShaders(GL.programs[program]);
      var len = result.length;
      if (len > maxCount) {
        len = maxCount;
      }
      HEAP32[((count)>>2)]=len;
      for (var i = 0; i < len; ++i) {
        var id = GL.shaders.indexOf(result[i]);
        HEAP32[(((shaders)+(i*4))>>2)]=id;
      }
    }
  function _glShaderSource(shader, count, string, length) {
      var source = GL.getSource(shader, count, string, length);
      Module.ctx.shaderSource(GL.shaders[shader], source);
    }
  function _glGetShaderSource(shader, bufSize, length, source) {
      var result = Module.ctx.getShaderSource(GL.shaders[shader]);
      result = result.slice(0, Math.max(0, bufSize - 1));
      writeStringToMemory(result, source);
      if (length) {
        HEAP32[((length)>>2)]=result.length;
      }
    }
  function _glCompileShader(shader) {
      Module.ctx.compileShader(GL.shaders[shader]);
    }
  function _glGetShaderInfoLog(shader, maxLength, length, infoLog) {
      var log = Module.ctx.getShaderInfoLog(GL.shaders[shader]);
      // Work around a bug in Chromium which causes getShaderInfoLog to return null
      if (!log) {
        log = "";
      }
      log = log.substr(0, maxLength - 1);
      writeStringToMemory(log, infoLog);
      if (length) {
        HEAP32[((length)>>2)]=log.length
      }
    }
  function _glGetShaderiv(shader, pname, p) {
      if (pname == 0x8B84) { // GL_INFO_LOG_LENGTH
        HEAP32[((p)>>2)]=Module.ctx.getShaderInfoLog(GL.shaders[shader]).length + 1;
      } else {
        HEAP32[((p)>>2)]=Module.ctx.getShaderParameter(GL.shaders[shader], pname);
      }
    }
  function _glGetProgramiv(program, pname, p) {
      if (pname == 0x8B84) { // GL_INFO_LOG_LENGTH
        HEAP32[((p)>>2)]=Module.ctx.getProgramInfoLog(GL.programs[program]).length + 1;
      } else {
        HEAP32[((p)>>2)]=Module.ctx.getProgramParameter(GL.programs[program], pname);
      }
    }
  function _glIsShader(shader) {
      var s = GL.shaders[shader];
      if (!s) return 0;
      return Module.ctx.isShader(s);
    }
  function _glCreateProgram() {
      var id = GL.getNewId(GL.programs);
      var program = Module.ctx.createProgram();
      program.name = id;
      GL.programs[id] = program;
      return id;
    }
  function _glDeleteProgram(program) {
      var program = GL.programs[program];
      Module.ctx.deleteProgram(program);
      program.name = 0;
      GL.programs[program] = null;
      GL.uniformTable[program] = null;
    }
  function _glAttachShader(program, shader) {
      Module.ctx.attachShader(GL.programs[program],
                              GL.shaders[shader]);
    }
  function _glDetachShader(program, shader) {
      Module.ctx.detachShader(GL.programs[program],
                              GL.shaders[shader]);
    }
  function _glGetShaderPrecisionFormat(shaderType, precisionType, range, precision) {
      var result = Module.ctx.getShaderPrecisionFormat(shaderType, precisionType);
      HEAP32[((range)>>2)]=result.rangeMin;
      HEAP32[(((range)+(4))>>2)]=result.rangeMax;
      HEAP32[((precision)>>2)]=result.precision;
    }
  function _glLinkProgram(program) {
      Module.ctx.linkProgram(GL.programs[program]);
      GL.uniformTable[program] = {}; // uniforms no longer keep the same names after linking
      GL.populateUniformTable(program);
    }
  function _glGetProgramInfoLog(program, maxLength, length, infoLog) {
      var log = Module.ctx.getProgramInfoLog(GL.programs[program]);
      // Work around a bug in Chromium which causes getProgramInfoLog to return null
      if (!log) {
        log = "";
      }
      log = log.substr(0, maxLength - 1);
      writeStringToMemory(log, infoLog);
      if (length) {
        HEAP32[((length)>>2)]=log.length
      }
    }
  function _glUseProgram(program) {
      Module.ctx.useProgram(program ? GL.programs[program] : null);
    }
  function _glValidateProgram(program) {
      Module.ctx.validateProgram(GL.programs[program]);
    }
  function _glIsProgram(program) {
      var program = GL.programs[program];
      if (!program) return 0;
      return Module.ctx.isProgram(program);
    }
  function _glBindAttribLocation(program, index, name) {
      name = Pointer_stringify(name);
      Module.ctx.bindAttribLocation(GL.programs[program], index, name);
    }
  function _glGetFramebufferAttachmentParameteriv(target, attachment, pname, params) {
      var result = Module.ctx.getFramebufferAttachmentParameter(target, attachment, pname);
      HEAP32[((params)>>2)]=params;
    }
  function _glIsFramebuffer(framebuffer) {
      var fb = GL.framebuffers[framebuffer];
      if (!fb) return 0;
      return Module.ctx.isFramebuffer(fb);
    }
  function _glVertexPointer(){ throw 'Legacy GL function (glVertexPointer) called. You need to compile with -s LEGACY_GL_EMULATION=1 to enable legacy GL emulation.'; }
  function _glGenVertexArrays(){ throw 'Legacy GL function (glGenVertexArrays) called. You need to compile with -s LEGACY_GL_EMULATION=1 to enable legacy GL emulation.'; }
  function _glMatrixMode(){ throw 'Legacy GL function (glMatrixMode) called. You need to compile with -s LEGACY_GL_EMULATION=1 to enable legacy GL emulation.'; }
  function _glBegin(){ throw 'Legacy GL function (glBegin) called. You need to compile with -s LEGACY_GL_EMULATION=1 to enable legacy GL emulation.'; }
  function _glLoadIdentity(){ throw 'Legacy GL function (glLoadIdentity) called. You need to compile with -s LEGACY_GL_EMULATION=1 to enable legacy GL emulation.'; }
  function _gluPerspective(fov, aspect, near, far) {
      GL.immediate.matricesModified = true;
      GL.immediate.matrix[GL.immediate.currentMatrix] =
        GL.immediate.matrix.lib.mat4.perspective(fov, aspect, near, far,
                                                 GL.immediate.matrix[GL.immediate.currentMatrix]);
    }
  function _gluLookAt(ex, ey, ez, cx, cy, cz, ux, uy, uz) {
      GL.immediate.matricesModified = true;
      GL.immediate.matrix.lib.mat4.lookAt(GL.immediate.matrix[GL.immediate.currentMatrix], [ex, ey, ez],
          [cx, cy, cz], [ux, uy, uz]);
    }
  function _gluProject(objX, objY, objZ, model, proj, view, winX, winY, winZ) {
      // The algorithm for this functions comes from Mesa
      var inVec = new Float32Array(4);
      var outVec = new Float32Array(4);
      GL.immediate.matrix.lib.mat4.multiplyVec4(HEAPF64.subarray((model)>>3,(model+128)>>3),
          [objX, objY, objZ, 1.0], outVec);
      GL.immediate.matrix.lib.mat4.multiplyVec4(HEAPF64.subarray((proj)>>3,(proj+128)>>3),
          outVec, inVec);
      if (inVec[3] == 0.0) {
        return 0 /* GL_FALSE */;
      }
      inVec[0] /= inVec[3];
      inVec[1] /= inVec[3];
      inVec[2] /= inVec[3];
      // Map x, y and z to range 0-1 */
      inVec[0] = inVec[0] * 0.5 + 0.5;
      inVec[1] = inVec[1] * 0.5 + 0.5;
      inVec[2] = inVec[2] * 0.5 + 0.5;
      // Map x, y to viewport
      inVec[0] = inVec[0] * HEAP32[(((view)+(8))>>2)] + HEAP32[((view)>>2)];
      inVec[1] = inVec[1] * HEAP32[(((view)+(12))>>2)] + HEAP32[(((view)+(4))>>2)];
      HEAPF64[((winX)>>3)]=inVec[0];
      HEAPF64[((winY)>>3)]=inVec[1];
      HEAPF64[((winZ)>>3)]=inVec[2];
      return 1 /* GL_TRUE */;
    }
  function _gluUnProject(winX, winY, winZ, model, proj, view, objX, objY, objZ) {
      var result = GL.immediate.matrix.lib.mat4.unproject([winX, winY, winZ],
          HEAPF64.subarray((model)>>3,(model+128)>>3),
          HEAPF64.subarray((proj)>>3,(proj+128)>>3),
          HEAP32.subarray((view)>>2,(view+16)>>2));
      if (result === null) {
        return 0 /* GL_FALSE */;
      }
      HEAPF64[((objX)>>3)]=result[0];
      HEAPF64[((objY)>>3)]=result[1];
      HEAPF64[((objZ)>>3)]=result[2];
      return 1 /* GL_TRUE */;
    }
  var _glOrtho=undefined;function _gluOrtho2D(left, right, bottom, top) {
      _glOrtho(left, right, bottom, top, -1, 1);
    }
  function _glVertexAttribPointer(index, size, type, normalized, stride, ptr) {
      Module.ctx.vertexAttribPointer(index, size, type, normalized, stride, ptr);
    }
  function _glEnableVertexAttribArray(index) {
      Module.ctx.enableVertexAttribArray(index);
    }
  function _glDisableVertexAttribArray(index) {
      Module.ctx.disableVertexAttribArray(index);
    }
  function _glDrawElements(mode, count, type, indices) {
      Module.ctx.drawElements(mode, count, type, indices);
    }
  function _glShaderBinary() {
      GL.recordError(0x0500/*GL_INVALID_ENUM*/);
    }
  function _glReleaseShaderCompiler() {
      // NOP (as allowed by GLES 2.0 spec)
    }
  function _glFinish() { Module.ctx.finish() }
  function _glFlush() { Module.ctx.flush() }
  function _glClearDepth(x0) { Module.ctx.clearDepth(x0) }
  function _glClearDepthf(x0) { Module.ctx.clearDepth(x0) }
  function _glDepthFunc(x0) { Module.ctx.depthFunc(x0) }
  function _glFrontFace(x0) { Module.ctx.frontFace(x0) }
  function _glCullFace(x0) { Module.ctx.cullFace(x0) }
  function _glLineWidth(x0) { Module.ctx.lineWidth(x0) }
  function _glClearStencil(x0) { Module.ctx.clearStencil(x0) }
  function _glDepthMask(x0) { Module.ctx.depthMask(x0) }
  function _glStencilMask(x0) { Module.ctx.stencilMask(x0) }
  function _glGenerateMipmap(x0) { Module.ctx.generateMipmap(x0) }
  function _glActiveTexture(x0) { Module.ctx.activeTexture(x0) }
  function _glBlendEquation(x0) { Module.ctx.blendEquation(x0) }
  function _glSampleCoverage(x0) { Module.ctx.sampleCoverage(x0) }
  function _glIsEnabled(x0) { return Module.ctx.isEnabled(x0) }
  function _glBlendEquationSeparate(x0, x1) { Module.ctx.blendEquationSeparate(x0, x1) }
  function _glDepthRange(x0, x1) { Module.ctx.depthRange(x0, x1) }
  function _glDepthRangef(x0, x1) { Module.ctx.depthRange(x0, x1) }
  function _glStencilMaskSeparate(x0, x1) { Module.ctx.stencilMaskSeparate(x0, x1) }
  function _glHint(x0, x1) { Module.ctx.hint(x0, x1) }
  function _glPolygonOffset(x0, x1) { Module.ctx.polygonOffset(x0, x1) }
  function _glVertexAttrib1f(x0, x1) { Module.ctx.vertexAttrib1f(x0, x1) }
  function _glTexParameterf(x0, x1, x2) { Module.ctx.texParameterf(x0, x1, x2) }
  function _glVertexAttrib2f(x0, x1, x2) { Module.ctx.vertexAttrib2f(x0, x1, x2) }
  function _glStencilFunc(x0, x1, x2) { Module.ctx.stencilFunc(x0, x1, x2) }
  function _glStencilOp(x0, x1, x2) { Module.ctx.stencilOp(x0, x1, x2) }
  function _glScissor(x0, x1, x2, x3) { Module.ctx.scissor(x0, x1, x2, x3) }
  function _glVertexAttrib3f(x0, x1, x2, x3) { Module.ctx.vertexAttrib3f(x0, x1, x2, x3) }
  function _glColorMask(x0, x1, x2, x3) { Module.ctx.colorMask(x0, x1, x2, x3) }
  function _glBlendFuncSeparate(x0, x1, x2, x3) { Module.ctx.blendFuncSeparate(x0, x1, x2, x3) }
  function _glBlendColor(x0, x1, x2, x3) { Module.ctx.blendColor(x0, x1, x2, x3) }
  function _glStencilFuncSeparate(x0, x1, x2, x3) { Module.ctx.stencilFuncSeparate(x0, x1, x2, x3) }
  function _glStencilOpSeparate(x0, x1, x2, x3) { Module.ctx.stencilOpSeparate(x0, x1, x2, x3) }
  function _glVertexAttrib4f(x0, x1, x2, x3, x4) { Module.ctx.vertexAttrib4f(x0, x1, x2, x3, x4) }
  function _glCopyTexImage2D(x0, x1, x2, x3, x4, x5, x6, x7) { Module.ctx.copyTexImage2D(x0, x1, x2, x3, x4, x5, x6, x7) }
  function _glCopyTexSubImage2D(x0, x1, x2, x3, x4, x5, x6, x7) { Module.ctx.copyTexSubImage2D(x0, x1, x2, x3, x4, x5, x6, x7) }function _emscripten_procAddressTable(name) {
  switch(name) {
  case "glPixelStorei": return 992; break;
  case "glGetString": return 1298; break;
  case "glGetIntegerv": return 1396; break;
  case "glGetFloatv": return 22; break;
  case "glGetBooleanv": return 598; break;
  case "glGenTextures": return 2804; break;
  case "glDeleteTextures": return 2594; break;
  case "glCompressedTexImage2D": return 16; break;
  case "glCompressedTexSubImage2D": return 12; break;
  case "glTexImage2D": return 6; break;
  case "glTexSubImage2D": return 8; break;
  case "glReadPixels": return 44; break;
  case "glBindTexture": return 344; break;
  case "glGetTexParameterfv": return 32; break;
  case "glGetTexParameteriv": return 126; break;
  case "glTexParameterfv": return 26; break;
  case "glTexParameteriv": return 64; break;
  case "glIsTexture": return 1206; break;
  case "glGenBuffers": return 1768; break;
  case "glDeleteBuffers": return 1802; break;
  case "glGetBufferParameteriv": return 116; break;
  case "glBufferData": return 78; break;
  case "glBufferSubData": return 116; break;
  case "glIsBuffer": return 900; break;
  case "glGenRenderbuffers": return 672; break;
  case "glDeleteRenderbuffers": return 3294; break;
  case "glBindRenderbuffer": return 1030; break;
  case "glGetRenderbufferParameteriv": return 102; break;
  case "glIsRenderbuffer": return 814; break;
  case "glGetUniformfv": return 56; break;
  case "glGetUniformiv": return 84; break;
  case "glGetUniformLocation": return 3190; break;
  case "glGetVertexAttribfv": return 38; break;
  case "glGetVertexAttribiv": return 28; break;
  case "glGetVertexAttribPointerv": return 8; break;
  case "glGetActiveUniform": return 10; break;
  case "glUniform1f": return 2; break;
  case "glUniform2f": return 2; break;
  case "glUniform3f": return 2; break;
  case "glUniform4f": return 2; break;
  case "glUniform1i": return 804; break;
  case "glUniform2i": return 52; break;
  case "glUniform3i": return 156; break;
  case "glUniform4i": return 30; break;
  case "glUniform1iv": return 104; break;
  case "glUniform2iv": return 96; break;
  case "glUniform3iv": return 44; break;
  case "glUniform4iv": return 54; break;
  case "glUniform1fv": return 42; break;
  case "glUniform2fv": return 120; break;
  case "glUniform3fv": return 24; break;
  case "glUniform4fv": return 86; break;
  case "glUniformMatrix2fv": return 140; break;
  case "glUniformMatrix3fv": return 80; break;
  case "glUniformMatrix4fv": return 132; break;
  case "glBindBuffer": return 880; break;
  case "glVertexAttrib1fv": return 782; break;
  case "glVertexAttrib2fv": return 3286; break;
  case "glVertexAttrib3fv": return 1202; break;
  case "glVertexAttrib4fv": return 252; break;
  case "glGetAttribLocation": return 3072; break;
  case "glGetActiveAttrib": return 78; break;
  case "glCreateShader": return 1296; break;
  case "glDeleteShader": return 134; break;
  case "glGetAttachedShaders": return 4; break;
  case "glShaderSource": return 100; break;
  case "glGetShaderSource": return 72; break;
  case "glCompileShader": return 784; break;
  case "glGetShaderInfoLog": return 126; break;
  case "glGetShaderiv": return 106; break;
  case "glGetProgramiv": return 114; break;
  case "glIsShader": return 2172; break;
  case "glCreateProgram": return 1358; break;
  case "glDeleteProgram": return 582; break;
  case "glAttachShader": return 330; break;
  case "glDetachShader": return 2236; break;
  case "glLinkProgram": return 648; break;
  case "glGetProgramInfoLog": return 94; break;
  case "glUseProgram": return 1022; break;
  case "glValidateProgram": return 1112; break;
  case "glIsProgram": return 452; break;
  case "glBindAttribLocation": return 58; break;
  case "glBindFramebuffer": return 3118; break;
  case "glGenFramebuffers": return 1988; break;
  case "glDeleteFramebuffers": return 1566; break;
  case "glFramebufferRenderbuffer": return 154; break;
  case "glFramebufferTexture2D": return 28; break;
  case "glGetFramebufferAttachmentParameteriv": return 104; break;
  case "glIsFramebuffer": return 1986; break;
  case "glVertexAttribPointer": return 88; break;
  case "glEnableVertexAttribArray": return 912; break;
  case "glDisableVertexAttribArray": return 938; break;
  case "glDrawArrays": return 40; break;
  case "glDrawElements": return 106; break;
  case "glShaderBinary": return 11298; break;
  case "glReleaseShaderCompiler": return 11856; break;
  case "glGetError": return 4918; break;
  case "glFinish": return 8818; break;
  case "glFlush": return 6442; break;
  case "glClearDepth": return 1228; break;
  case "glClearDepthf": return 366; break;
  case "glDepthFunc": return 844; break;
  case "glEnable": return 170; break;
  case "glDisable": return 288; break;
  case "glFrontFace": return 210; break;
  case "glCullFace": return 542; break;
  case "glClear": return 1426; break;
  case "glLineWidth": return 94; break;
  case "glClearStencil": return 2; break;
  case "glDepthMask": return 794; break;
  case "glStencilMask": return 80; break;
  case "glCheckFramebufferStatus": return 204; break;
  case "glGenerateMipmap": return 944; break;
  case "glActiveTexture": return 1452; break;
  case "glBlendEquation": return 400; break;
  case "glSampleCoverage": return 1028; break;
  case "glIsEnabled": return 266; break;
  case "glBlendFunc": return 2752; break;
  case "glBlendEquationSeparate": return 776; break;
  case "glDepthRange": return 3250; break;
  case "glDepthRangef": return 522; break;
  case "glStencilMaskSeparate": return 3416; break;
  case "glHint": return 2112; break;
  case "glPolygonOffset": return 1560; break;
  case "glVertexAttrib1f": return 1012; break;
  case "glTexParameteri": return 132; break;
  case "glTexParameterf": return 134; break;
  case "glVertexAttrib2f": return 122; break;
  case "glStencilFunc": return 18; break;
  case "glStencilOp": return 22; break;
  case "glViewport": return 76; break;
  case "glClearColor": return 46; break;
  case "glScissor": return 70; break;
  case "glVertexAttrib3f": return 88; break;
  case "glColorMask": return 98; break;
  case "glRenderbufferStorage": return 34; break;
  case "glBlendFuncSeparate": return 56; break;
  case "glBlendColor": return 6; break;
  case "glStencilFuncSeparate": return 150; break;
  case "glStencilOpSeparate": return 64; break;
  case "glVertexAttrib4f": return 10; break;
  case "glCopyTexImage2D": return 14; break;
  case "glCopyTexSubImage2D": return 2; break;
  }
  return 0;
  }function _emscripten_GetProcAddress(name) {
    name = name.replace('EXT', '').replace('ARB', '');
    switch(name) { // misc renamings
      case 'glCreateProgramObject': name = 'glCreateProgram'; break;
      case 'glUseProgramObject': name = 'glUseProgram'; break;
      case 'glCreateShaderObject': name = 'glCreateShader'; break;
      case 'glAttachObject': name = 'glAttachShader'; break;
      case 'glDetachObject': name = 'glDetachShader'; break;
    }
    var ret = _emscripten_procAddressTable(name);
    if (!ret) Module.printErr('WARNING: getProcAddress failed for ' + name);
    return ret;
  }function _eglGetProcAddress(name_) {
      return _emscripten_GetProcAddress(Pointer_stringify(name_));
    }
  function _emscripten_get_canvas_size(width, height, isFullscreen) {
      var canvas = Module['canvas'];
      HEAP32[((width)>>2)]=canvas.width;
      HEAP32[((height)>>2)]=canvas.height;
      HEAP32[((isFullscreen)>>2)]=Browser.isFullScreen ? 1 : 0;
    }
  var EGL={eglErrorCode:12288,stringCache:{},setErrorCode:function (code) {
        EGL.eglErrorCode = code;
      },chooseConfig:function (display, attribList, config, config_size, numConfigs) { 
        if (display != 62000 /* Magic ID for Emscripten 'default display' */) {
          EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
          return 0;
        }
        // TODO: read attribList.
        if ((!config || !config_size) && !numConfigs) {
          EGL.setErrorCode(0x300C /* EGL_BAD_PARAMETER */);
          return 0;
        }
        if (numConfigs) {
          HEAP32[((numConfigs)>>2)]=1; // Total number of supported configs: 1.
        }
        if (config && config_size > 0) {
          HEAP32[((config)>>2)]=62002; 
        }
        EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
        return 1;
      }};function _eglBindAPI(api) {
      if (api == 0x30A0 /* EGL_OPENGL_ES_API */) {
        EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
        return 1;
      } else { // if (api == 0x30A1 /* EGL_OPENVG_API */ || api == 0x30A2 /* EGL_OPENGL_API */) {
        EGL.setErrorCode(0x300C /* EGL_BAD_PARAMETER */);
        return 0;
      }
    }
  function _eglMakeCurrent(display, draw, read, context) { 
      if (display != 62000 /* Magic ID for Emscripten 'default display' */) {
        EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
        return 0;
      }
      //\todo An EGL_NOT_INITIALIZED error is generated if EGL is not initialized for dpy. 
      if (context != 62004 /* Magic ID for Emscripten EGLContext */) {
        EGL.setErrorCode(0x3006 /* EGL_BAD_CONTEXT */);
        return 0;
      }
      if (read != 62006 || draw != 62006 /* Magic ID for Emscripten 'default surface' */) {
        EGL.setErrorCode(0x300D /* EGL_BAD_SURFACE */);
        return 0;
      }
      EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
      return 1;
    }
  function _glutDestroyWindow(name) {
      Module.ctx = Browser.destroyContext(Module['canvas'], true, true);
      return 1;
    }function _eglDestroyContext(display, context) {
      if (display != 62000 /* Magic ID for Emscripten 'default display' */) {
        EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
        return 0;
      }
      if (context != 62004 /* Magic ID for Emscripten EGLContext */) {
        EGL.setErrorCode(0x3006 /* EGL_BAD_CONTEXT */);
        return 0;
      }
      EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
      return 1;
    }
  function _eglDestroySurface(display, surface) { 
      if (display != 62000 /* Magic ID for Emscripten 'default display' */) {
        EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
        return 0; 
      }
      if (surface != 62006 /* Magic ID for the only EGLSurface supported by Emscripten */) {
        EGL.setErrorCode(0x300D /* EGL_BAD_SURFACE */);
        return 1;
      }
      EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
      return 1; /* Magic ID for Emscripten 'default surface' */
    }
  function _eglTerminate(display) {
      if (display != 62000 /* Magic ID for Emscripten 'default display' */) {
        EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
        return 0;
      }
      // TODO: Tear down EGL here. Currently a no-op since we don't need to actually do anything here for the browser.
      EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
      return 1;
    }
  function _eglGetDisplay(nativeDisplayType) {
      EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
      // Note: As a 'conformant' implementation of EGL, we would prefer to init here only if the user
      //       calls this function with EGL_DEFAULT_DISPLAY. Other display IDs would be preferred to be unsupported
      //       and EGL_NO_DISPLAY returned. Uncomment the following code lines to do this.
      // Instead, an alternative route has been preferred, namely that the Emscripten EGL implementation
      // "emulates" X11, and eglGetDisplay is expected to accept/receive a pointer to an X11 Display object.
      // Therefore, be lax and allow anything to be passed in, and return the magic handle to our default EGLDisplay object.
  //    if (nativeDisplayType == 0 /* EGL_DEFAULT_DISPLAY */) {
          return 62000; // Magic ID for Emscripten 'default display'
  //    }
  //    else
  //      return 0; // EGL_NO_DISPLAY
    }
  function _eglInitialize(display, majorVersion, minorVersion) {
      if (display == 62000 /* Magic ID for Emscripten 'default display' */) {
        if (majorVersion) {
          HEAP32[((majorVersion)>>2)]=1; // Advertise EGL Major version: '1'
        }
        if (minorVersion) {
          HEAP32[((minorVersion)>>2)]=4; // Advertise EGL Minor version: '4'
        }
        EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
        return 1;
      } 
      else {
        EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
        return 0;
      }
    }
  function _eglChooseConfig(display, attrib_list, configs, config_size, numConfigs) { 
      return EGL.chooseConfig(display, attrib_list, configs, config_size, numConfigs);
    }
  var GLUT={initTime:null,idleFunc:null,displayFunc:null,keyboardFunc:null,keyboardUpFunc:null,specialFunc:null,specialUpFunc:null,reshapeFunc:null,motionFunc:null,passiveMotionFunc:null,mouseFunc:null,buttons:0,modifiers:0,initWindowWidth:256,initWindowHeight:256,initDisplayMode:18,windowX:0,windowY:0,windowWidth:0,windowHeight:0,saveModifiers:function (event) {
        GLUT.modifiers = 0;
        if (event['shiftKey'])
          GLUT.modifiers += 1; /* GLUT_ACTIVE_SHIFT */
        if (event['ctrlKey'])
          GLUT.modifiers += 2; /* GLUT_ACTIVE_CTRL */
        if (event['altKey'])
          GLUT.modifiers += 4; /* GLUT_ACTIVE_ALT */
      },onMousemove:function (event) {
        /* Send motion event only if the motion changed, prevents
         * spamming our app with uncessary callback call. It does happen in
         * Chrome on Windows.
         */
        var lastX = Browser.mouseX;
        var lastY = Browser.mouseY;
        Browser.calculateMouseEvent(event);
        var newX = Browser.mouseX;
        var newY = Browser.mouseY;
        if (newX == lastX && newY == lastY) return;
        if (GLUT.buttons == 0 && event.target == Module["canvas"] && GLUT.passiveMotionFunc) {
          event.preventDefault();
          GLUT.saveModifiers(event);
          Runtime.dynCall('vii', GLUT.passiveMotionFunc, [lastX, lastY]);
        } else if (GLUT.buttons != 0 && GLUT.motionFunc) {
          event.preventDefault();
          GLUT.saveModifiers(event);
          Runtime.dynCall('vii', GLUT.motionFunc, [lastX, lastY]);
        }
      },getSpecialKey:function (keycode) {
          var key = null;
          switch (keycode) {
            case 8:  key = 120 /* backspace */; break;
            case 46: key = 111 /* delete */; break;
            case 0x70 /*DOM_VK_F1*/: key = 1 /* GLUT_KEY_F1 */; break;
            case 0x71 /*DOM_VK_F2*/: key = 2 /* GLUT_KEY_F2 */; break;
            case 0x72 /*DOM_VK_F3*/: key = 3 /* GLUT_KEY_F3 */; break;
            case 0x73 /*DOM_VK_F4*/: key = 4 /* GLUT_KEY_F4 */; break;
            case 0x74 /*DOM_VK_F5*/: key = 5 /* GLUT_KEY_F5 */; break;
            case 0x75 /*DOM_VK_F6*/: key = 6 /* GLUT_KEY_F6 */; break;
            case 0x76 /*DOM_VK_F7*/: key = 7 /* GLUT_KEY_F7 */; break;
            case 0x77 /*DOM_VK_F8*/: key = 8 /* GLUT_KEY_F8 */; break;
            case 0x78 /*DOM_VK_F9*/: key = 9 /* GLUT_KEY_F9 */; break;
            case 0x79 /*DOM_VK_F10*/: key = 10 /* GLUT_KEY_F10 */; break;
            case 0x7a /*DOM_VK_F11*/: key = 11 /* GLUT_KEY_F11 */; break;
            case 0x7b /*DOM_VK_F12*/: key = 12 /* GLUT_KEY_F12 */; break;
            case 0x25 /*DOM_VK_LEFT*/: key = 100 /* GLUT_KEY_LEFT */; break;
            case 0x26 /*DOM_VK_UP*/: key = 101 /* GLUT_KEY_UP */; break;
            case 0x27 /*DOM_VK_RIGHT*/: key = 102 /* GLUT_KEY_RIGHT */; break;
            case 0x28 /*DOM_VK_DOWN*/: key = 103 /* GLUT_KEY_DOWN */; break;
            case 0x21 /*DOM_VK_PAGE_UP*/: key = 104 /* GLUT_KEY_PAGE_UP */; break;
            case 0x22 /*DOM_VK_PAGE_DOWN*/: key = 105 /* GLUT_KEY_PAGE_DOWN */; break;
            case 0x24 /*DOM_VK_HOME*/: key = 106 /* GLUT_KEY_HOME */; break;
            case 0x23 /*DOM_VK_END*/: key = 107 /* GLUT_KEY_END */; break;
            case 0x2d /*DOM_VK_INSERT*/: key = 108 /* GLUT_KEY_INSERT */; break;
            case 16   /*DOM_VK_SHIFT*/:
            case 0x05 /*DOM_VK_LEFT_SHIFT*/:
              key = 112 /* GLUT_KEY_SHIFT_L */;
              break;
            case 0x06 /*DOM_VK_RIGHT_SHIFT*/:
              key = 113 /* GLUT_KEY_SHIFT_R */;
              break;
            case 17   /*DOM_VK_CONTROL*/:
            case 0x03 /*DOM_VK_LEFT_CONTROL*/:
              key = 114 /* GLUT_KEY_CONTROL_L */;
              break;
            case 0x04 /*DOM_VK_RIGHT_CONTROL*/:
              key = 115 /* GLUT_KEY_CONTROL_R */;
              break;
            case 18   /*DOM_VK_ALT*/:
            case 0x02 /*DOM_VK_LEFT_ALT*/:
              key = 116 /* GLUT_KEY_ALT_L */;
              break;
            case 0x01 /*DOM_VK_RIGHT_ALT*/:
              key = 117 /* GLUT_KEY_ALT_R */;
              break;
          };
          return key;
      },getASCIIKey:function (event) {
        if (event['ctrlKey'] || event['altKey'] || event['metaKey']) return null;
        var keycode = event['keyCode'];
        /* The exact list is soooo hard to find in a canonical place! */
        if (48 <= keycode && keycode <= 57)
          return keycode; // numeric  TODO handle shift?
        if (65 <= keycode && keycode <= 90)
          return event['shiftKey'] ? keycode : keycode + 32;
        if (106 <= keycode && keycode <= 111)
          return keycode - 106 + 42; // *,+-./  TODO handle shift?
        switch (keycode) {
          case 27: // escape
          case 32: // space
          case 61: // equal
            return keycode;
        }
        var s = event['shiftKey'];
        switch (keycode) {
          case 186: return s ? 58 : 59; // colon / semi-colon
          case 187: return s ? 43 : 61; // add / equal (these two may be wrong)
          case 188: return s ? 60 : 44; // less-than / comma
          case 189: return s ? 95 : 45; // dash
          case 190: return s ? 62 : 46; // greater-than / period
          case 191: return s ? 63 : 47; // forward slash
          case 219: return s ? 123 : 91; // open bracket
          case 220: return s ? 124 : 47; // back slash
          case 221: return s ? 125 : 93; // close braket
          case 222: return s ? 34 : 39; // single quote
        }
        return null;
      },onKeydown:function (event) {
        if (GLUT.specialFunc || GLUT.keyboardFunc) {
          var key = GLUT.getSpecialKey(event['keyCode']);
          if (key !== null) {
            if( GLUT.specialFunc ) {
              event.preventDefault();
              GLUT.saveModifiers(event);
              Runtime.dynCall('viii', GLUT.specialFunc, [key, Browser.mouseX, Browser.mouseY]);
            }
          }
          else
          {
            key = GLUT.getASCIIKey(event);
            if( key !== null && GLUT.keyboardFunc ) {
              event.preventDefault();
              GLUT.saveModifiers(event);
              Runtime.dynCall('viii', GLUT.keyboardFunc, [key, Browser.mouseX, Browser.mouseY]);
            }
          }
        }
      },onKeyup:function (event) {
        if (GLUT.specialUpFunc || GLUT.keyboardUpFunc) {
          var key = GLUT.getSpecialKey(event['keyCode']);
          if (key !== null) {
            if(GLUT.specialUpFunc) {
              event.preventDefault ();
              GLUT.saveModifiers(event);
              Runtime.dynCall('viii', GLUT.specialUpFunc, [key, Browser.mouseX, Browser.mouseY]);
            }
          }
          else
          {
            key = GLUT.getASCIIKey(event);
            if( key !== null && GLUT.keyboardUpFunc ) {
              event.preventDefault ();
              GLUT.saveModifiers(event);
              Runtime.dynCall('viii', GLUT.keyboardUpFunc, [key, Browser.mouseX, Browser.mouseY]);
            }
          }
        }
      },onMouseButtonDown:function (event) {
        Browser.calculateMouseEvent(event);
        GLUT.buttons |= (1 << event['button']);
        if (event.target == Module["canvas"] && GLUT.mouseFunc) {
          try {
            event.target.setCapture();
          } catch (e) {}
          event.preventDefault();
          GLUT.saveModifiers(event);
          Runtime.dynCall('viiii', GLUT.mouseFunc, [event['button'], 0/*GLUT_DOWN*/, Browser.mouseX, Browser.mouseY]);
        }
      },onMouseButtonUp:function (event) {
        Browser.calculateMouseEvent(event);
        GLUT.buttons &= ~(1 << event['button']);
        if (GLUT.mouseFunc) {
          event.preventDefault();
          GLUT.saveModifiers(event);
          Runtime.dynCall('viiii', GLUT.mouseFunc, [event['button'], 1/*GLUT_UP*/, Browser.mouseX, Browser.mouseY]);
        }
      },onMouseWheel:function (event) {
        Browser.calculateMouseEvent(event);
        // cross-browser wheel delta
        var e = window.event || event; // old IE support
        var delta = Math.max(-1, Math.min(1, (e.wheelDelta || -e.detail)));
        var button = 3; // wheel up
        if (delta < 0) {
          button = 4; // wheel down
        }
        if (GLUT.mouseFunc) {
          event.preventDefault();
          GLUT.saveModifiers(event);
          Runtime.dynCall('viiii', GLUT.mouseFunc, [button, 0/*GLUT_DOWN*/, Browser.mouseX, Browser.mouseY]);
        }
      },onFullScreenEventChange:function (event) {
        var width;
        var height;
        if (document["fullScreen"] || document["mozFullScreen"] || document["webkitIsFullScreen"]) {
          width = screen["width"];
          height = screen["height"];
        } else {
          width = GLUT.windowWidth;
          height = GLUT.windowHeight;
          // TODO set position
          document.removeEventListener('fullscreenchange', GLUT.onFullScreenEventChange, true);
          document.removeEventListener('mozfullscreenchange', GLUT.onFullScreenEventChange, true);
          document.removeEventListener('webkitfullscreenchange', GLUT.onFullScreenEventChange, true);
        }
        Browser.setCanvasSize(width, height);
        /* Can't call _glutReshapeWindow as that requests cancelling fullscreen. */
        if (GLUT.reshapeFunc) {
          // console.log("GLUT.reshapeFunc (from FS): " + width + ", " + height);
          Runtime.dynCall('vii', GLUT.reshapeFunc, [width, height]);
        }
        _glutPostRedisplay();
      },requestFullScreen:function () {
        var RFS = Module["canvas"]['requestFullscreen'] ||
                  Module["canvas"]['requestFullScreen'] ||
                  Module["canvas"]['mozRequestFullScreen'] ||
                  Module["canvas"]['webkitRequestFullScreen'] ||
                  (function() {});
        RFS.apply(Module["canvas"], []);
      },cancelFullScreen:function () {
        var CFS = document['exitFullscreen'] ||
                  document['cancelFullScreen'] ||
                  document['mozCancelFullScreen'] ||
                  document['webkitCancelFullScreen'] ||
                  (function() {});
        CFS.apply(document, []);
      }};function _glutInitDisplayMode(mode) {
      GLUT.initDisplayMode = mode;
    }
  function _glutCreateWindow(name) {
      var contextAttributes = {
        antialias: ((GLUT.initDisplayMode & 0x0080 /*GLUT_MULTISAMPLE*/) != 0),
        depth: ((GLUT.initDisplayMode & 0x0010 /*GLUT_DEPTH*/) != 0),
        stencil: ((GLUT.initDisplayMode & 0x0020 /*GLUT_STENCIL*/) != 0)
      };
      Module.ctx = Browser.createContext(Module['canvas'], true, true, contextAttributes);
      return Module.ctx ? 1 /* a new GLUT window ID for the created context */ : 0 /* failure */;
    }function _eglCreateContext(display, config, hmm, contextAttribs) {
      if (display != 62000 /* Magic ID for Emscripten 'default display' */) {
        EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
        return 0;
      }
      _glutInitDisplayMode(0x92 /* GLUT_RGBA | GLUT_DOUBLE | GLUT_DEPTH | GLUT_MULTISAMPLE */);
      EGL.windowID = _glutCreateWindow();
      if (EGL.windowID != 0) {
        EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
        return 62004; // Magic ID for Emscripten EGLContext
      } else {
        EGL.setErrorCode(0x3009 /* EGL_BAD_MATCH */); // By the EGL 1.4 spec, an implementation that does not support GLES2 (WebGL in this case), this error code is set.
        return 0; /* EGL_NO_CONTEXT */
      }
    }
  function _eglCreateWindowSurface(display, config, win, attrib_list) { 
      if (display != 62000 /* Magic ID for Emscripten 'default display' */) {
        EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
        return 0;
      }
      if (config != 62002 /* Magic ID for the only EGLConfig supported by Emscripten */) {
        EGL.setErrorCode(0x3005 /* EGL_BAD_CONFIG */);
        return 0;
      }
      // TODO: Examine attrib_list! Parameters that can be present there are:
      // - EGL_RENDER_BUFFER (must be EGL_BACK_BUFFER)
      // - EGL_VG_COLORSPACE (can't be set)
      // - EGL_VG_ALPHA_FORMAT (can't be set)
      EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
      return 62006; /* Magic ID for Emscripten 'default surface' */
    }
  function _eglQuerySurface(display, surface, attribute, value) { 
      if (display != 62000 /* Magic ID for Emscripten 'default display' */) {
        EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
        return 0;
      }
      if (surface != 62006 /* Magic ID for Emscripten 'default surface' */) {
        EGL.setErrorCode(0x300D /* EGL_BAD_SURFACE */);
        return 0;
      }
      if (!value) {
        EGL.setErrorCode(0x300C /* EGL_BAD_PARAMETER */);
        return 0;
      }
      EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
      switch(attribute) {
      case 0x3028: // EGL_CONFIG_ID
        HEAP32[((value)>>2)]=62002;
          return 1;
      case 0x3058: // EGL_LARGEST_PBUFFER
        // Odd EGL API: If surface is not a pbuffer surface, 'value' should not be written to. It's not specified as an error, so true should(?) be returned.
        // Existing Android implementation seems to do so at least.
        return 1;
      case 0x3057: // EGL_WIDTH
        HEAP32[((value)>>2)]=Module.canvas.width;
        return 1;
      case 0x3056: // EGL_HEIGHT
        HEAP32[((value)>>2)]=Module.canvas.height;
        return 1;
      case 0x3090: // EGL_HORIZONTAL_RESOLUTION
        HEAP32[((value)>>2)]=-1;
        return 1;
      case 0x3091: // EGL_VERTICAL_RESOLUTION
        HEAP32[((value)>>2)]=-1;
        return 1;
      case 0x3092: // EGL_PIXEL_ASPECT_RATIO
        HEAP32[((value)>>2)]=-1;
        return 1;
      case 0x3086: // EGL_RENDER_BUFFER
        // The main surface is bound to the visible canvas window - it's always backbuffered. 
        // Alternative to EGL_BACK_BUFFER would be EGL_SINGLE_BUFFER.
        HEAP32[((value)>>2)]=0x3084; 
        return 1;
      case 0x3099: // EGL_MULTISAMPLE_RESOLVE
        HEAP32[((value)>>2)]=0x309A; 
        return 1;
      case 0x3093: // EGL_SWAP_BEHAVIOR
        // The two possibilities are EGL_BUFFER_PRESERVED and EGL_BUFFER_DESTROYED. Slightly unsure which is the
        // case for browser environment, but advertise the 'weaker' behavior to be sure.
        HEAP32[((value)>>2)]=0x3095;
        return 1;
      case 0x3080: // EGL_TEXTURE_FORMAT
      case 0x3081: // EGL_TEXTURE_TARGET
      case 0x3082: // EGL_MIPMAP_TEXTURE
      case 0x3083: // EGL_MIPMAP_LEVEL
        // This is a window surface, not a pbuffer surface. Spec:
        // "Querying EGL_TEXTURE_FORMAT, EGL_TEXTURE_TARGET, EGL_MIPMAP_TEXTURE, or EGL_MIPMAP_LEVEL for a non-pbuffer surface is not an error, but value is not modified."
        // So pass-through.
        return 1;
      default:
        EGL.setErrorCode(0x3004 /* EGL_BAD_ATTRIBUTE */);
        return 0;
      }
    }
  function _ferror(stream) {
      // int ferror(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/ferror.html
      stream = FS.getStream(stream);
      return Number(stream && stream.error);
    }
  var _floor=Math_floor;
  var _log=Math_log;
  function _exp2(x) {
      return Math.pow(2, x);
    }
  function _sprintf(s, format, varargs) {
      // int sprintf(char *restrict s, const char *restrict format, ...);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/printf.html
      return _snprintf(s, undefined, format, varargs);
    }
  function _vsnprintf(s, n, format, va_arg) {
      return _snprintf(s, n, format, HEAP32[((va_arg)>>2)]);
    }
  var _llvm_va_start=undefined;
  function _llvm_va_end() {}
  function _memchr(ptr, chr, num) {
      chr = unSign(chr);
      for (var i = 0; i < num; i++) {
        if (HEAP8[(ptr)] == chr) return ptr;
        ptr++;
      }
      return 0;
    }
  Module["_strcpy"] = _strcpy;
  function _rand() {
      return Math.floor(Math.random()*0x80000000);
    }
  var _llvm_pow_f64=Math_pow;
  var _exp=Math_exp;
  function _llvm_bswap_i16(x) {
      return ((x&0xff)<<8) | ((x>>8)&0xff);
    }
  function _srand(seed) {}
  function _atexit(func, arg) {
      __ATEXIT__.unshift({ func: func, arg: arg });
    }var ___cxa_atexit=_atexit;
  function ___gxx_personality_v0() {
    }
  function ___cxa_allocate_exception(size) {
      return _malloc(size);
    }
  function ___cxa_free_exception(ptr) {
      try {
        return _free(ptr);
      } catch(e) { // XXX FIXME
      }
    }
  function _llvm_eh_exception() {
      return HEAP32[((_llvm_eh_exception.buf)>>2)];
    }
  function __ZSt18uncaught_exceptionv() { // std::uncaught_exception()
      return !!__ZSt18uncaught_exceptionv.uncaught_exception;
    }
  function ___cxa_is_number_type(type) {
      var isNumber = false;
      try { if (type == __ZTIi) isNumber = true } catch(e){}
      try { if (type == __ZTIj) isNumber = true } catch(e){}
      try { if (type == __ZTIl) isNumber = true } catch(e){}
      try { if (type == __ZTIm) isNumber = true } catch(e){}
      try { if (type == __ZTIx) isNumber = true } catch(e){}
      try { if (type == __ZTIy) isNumber = true } catch(e){}
      try { if (type == __ZTIf) isNumber = true } catch(e){}
      try { if (type == __ZTId) isNumber = true } catch(e){}
      try { if (type == __ZTIe) isNumber = true } catch(e){}
      try { if (type == __ZTIc) isNumber = true } catch(e){}
      try { if (type == __ZTIa) isNumber = true } catch(e){}
      try { if (type == __ZTIh) isNumber = true } catch(e){}
      try { if (type == __ZTIs) isNumber = true } catch(e){}
      try { if (type == __ZTIt) isNumber = true } catch(e){}
      return isNumber;
    }function ___cxa_does_inherit(definiteType, possibilityType, possibility) {
      if (possibility == 0) return false;
      if (possibilityType == 0 || possibilityType == definiteType)
        return true;
      var possibility_type_info;
      if (___cxa_is_number_type(possibilityType)) {
        possibility_type_info = possibilityType;
      } else {
        var possibility_type_infoAddr = HEAP32[((possibilityType)>>2)] - 8;
        possibility_type_info = HEAP32[((possibility_type_infoAddr)>>2)];
      }
      switch (possibility_type_info) {
      case 0: // possibility is a pointer
        // See if definite type is a pointer
        var definite_type_infoAddr = HEAP32[((definiteType)>>2)] - 8;
        var definite_type_info = HEAP32[((definite_type_infoAddr)>>2)];
        if (definite_type_info == 0) {
          // Also a pointer; compare base types of pointers
          var defPointerBaseAddr = definiteType+8;
          var defPointerBaseType = HEAP32[((defPointerBaseAddr)>>2)];
          var possPointerBaseAddr = possibilityType+8;
          var possPointerBaseType = HEAP32[((possPointerBaseAddr)>>2)];
          return ___cxa_does_inherit(defPointerBaseType, possPointerBaseType, possibility);
        } else
          return false; // one pointer and one non-pointer
      case 1: // class with no base class
        return false;
      case 2: // class with base class
        var parentTypeAddr = possibilityType + 8;
        var parentType = HEAP32[((parentTypeAddr)>>2)];
        return ___cxa_does_inherit(definiteType, parentType, possibility);
      default:
        return false; // some unencountered type
      }
    }
  function ___resumeException(ptr) {
      if (HEAP32[((_llvm_eh_exception.buf)>>2)] == 0) HEAP32[((_llvm_eh_exception.buf)>>2)]=ptr;
      throw ptr + " - Exception catching is disabled, this exception cannot be caught. Compile with -s DISABLE_EXCEPTION_CATCHING=0 or DISABLE_EXCEPTION_CATCHING=2 to catch.";;
    }function ___cxa_find_matching_catch(thrown, throwntype) {
      if (thrown == -1) thrown = HEAP32[((_llvm_eh_exception.buf)>>2)];
      if (throwntype == -1) throwntype = HEAP32[(((_llvm_eh_exception.buf)+(4))>>2)];
      var typeArray = Array.prototype.slice.call(arguments, 2);
      // If throwntype is a pointer, this means a pointer has been
      // thrown. When a pointer is thrown, actually what's thrown
      // is a pointer to the pointer. We'll dereference it.
      if (throwntype != 0 && !___cxa_is_number_type(throwntype)) {
        var throwntypeInfoAddr= HEAP32[((throwntype)>>2)] - 8;
        var throwntypeInfo= HEAP32[((throwntypeInfoAddr)>>2)];
        if (throwntypeInfo == 0)
          thrown = HEAP32[((thrown)>>2)];
      }
      // The different catch blocks are denoted by different types.
      // Due to inheritance, those types may not precisely match the
      // type of the thrown object. Find one which matches, and
      // return the type of the catch block which should be called.
      for (var i = 0; i < typeArray.length; i++) {
        if (___cxa_does_inherit(typeArray[i], throwntype, thrown))
          return ((asm["setTempRet0"](typeArray[i]),thrown)|0);
      }
      // Shouldn't happen unless we have bogus data in typeArray
      // or encounter a type for which emscripten doesn't have suitable
      // typeinfo defined. Best-efforts match just in case.
      return ((asm["setTempRet0"](throwntype),thrown)|0);
    }function ___cxa_throw(ptr, type, destructor) {
      if (!___cxa_throw.initialized) {
        try {
          HEAP32[((__ZTVN10__cxxabiv119__pointer_type_infoE)>>2)]=0; // Workaround for libcxxabi integration bug
        } catch(e){}
        try {
          HEAP32[((__ZTVN10__cxxabiv117__class_type_infoE)>>2)]=1; // Workaround for libcxxabi integration bug
        } catch(e){}
        try {
          HEAP32[((__ZTVN10__cxxabiv120__si_class_type_infoE)>>2)]=2; // Workaround for libcxxabi integration bug
        } catch(e){}
        ___cxa_throw.initialized = true;
      }
      HEAP32[((_llvm_eh_exception.buf)>>2)]=ptr
      HEAP32[(((_llvm_eh_exception.buf)+(4))>>2)]=type
      HEAP32[(((_llvm_eh_exception.buf)+(8))>>2)]=destructor
      if (!("uncaught_exception" in __ZSt18uncaught_exceptionv)) {
        __ZSt18uncaught_exceptionv.uncaught_exception = 1;
      } else {
        __ZSt18uncaught_exceptionv.uncaught_exception++;
      }
      throw ptr + " - Exception catching is disabled, this exception cannot be caught. Compile with -s DISABLE_EXCEPTION_CATCHING=0 or DISABLE_EXCEPTION_CATCHING=2 to catch.";;
    }
  Module["_strncpy"] = _strncpy;
  function __getFloat(text) {
      return /^[+-]?[0-9]*\.?[0-9]+([eE][+-]?[0-9]+)?/.exec(text);
    }function __scanString(format, get, unget, varargs) {
      if (!__scanString.whiteSpace) {
        __scanString.whiteSpace = {};
        __scanString.whiteSpace[32] = 1;
        __scanString.whiteSpace[9] = 1;
        __scanString.whiteSpace[10] = 1;
        __scanString.whiteSpace[11] = 1;
        __scanString.whiteSpace[12] = 1;
        __scanString.whiteSpace[13] = 1;
      }
      // Supports %x, %4x, %d.%d, %lld, %s, %f, %lf.
      // TODO: Support all format specifiers.
      format = Pointer_stringify(format);
      var soFar = 0;
      if (format.indexOf('%n') >= 0) {
        // need to track soFar
        var _get = get;
        get = function get() {
          soFar++;
          return _get();
        }
        var _unget = unget;
        unget = function unget() {
          soFar--;
          return _unget();
        }
      }
      var formatIndex = 0;
      var argsi = 0;
      var fields = 0;
      var argIndex = 0;
      var next;
      mainLoop:
      for (var formatIndex = 0; formatIndex < format.length;) {
        if (format[formatIndex] === '%' && format[formatIndex+1] == 'n') {
          var argPtr = HEAP32[(((varargs)+(argIndex))>>2)];
          argIndex += Runtime.getAlignSize('void*', null, true);
          HEAP32[((argPtr)>>2)]=soFar;
          formatIndex += 2;
          continue;
        }
        if (format[formatIndex] === '%') {
          var nextC = format.indexOf('c', formatIndex+1);
          if (nextC > 0) {
            var maxx = 1;
            if (nextC > formatIndex+1) {
              var sub = format.substring(formatIndex+1, nextC);
              maxx = parseInt(sub);
              if (maxx != sub) maxx = 0;
            }
            if (maxx) {
              var argPtr = HEAP32[(((varargs)+(argIndex))>>2)];
              argIndex += Runtime.getAlignSize('void*', null, true);
              fields++;
              for (var i = 0; i < maxx; i++) {
                next = get();
                HEAP8[((argPtr++)|0)]=next;
              }
              formatIndex += nextC - formatIndex + 1;
              continue;
            }
          }
        }
        // handle %[...]
        if (format[formatIndex] === '%' && format.indexOf('[', formatIndex+1) > 0) {
          var match = /\%([0-9]*)\[(\^)?(\]?[^\]]*)\]/.exec(format.substring(formatIndex));
          if (match) {
            var maxNumCharacters = parseInt(match[1]) || Infinity;
            var negateScanList = (match[2] === '^');
            var scanList = match[3];
            // expand "middle" dashs into character sets
            var middleDashMatch;
            while ((middleDashMatch = /([^\-])\-([^\-])/.exec(scanList))) {
              var rangeStartCharCode = middleDashMatch[1].charCodeAt(0);
              var rangeEndCharCode = middleDashMatch[2].charCodeAt(0);
              for (var expanded = ''; rangeStartCharCode <= rangeEndCharCode; expanded += String.fromCharCode(rangeStartCharCode++));
              scanList = scanList.replace(middleDashMatch[1] + '-' + middleDashMatch[2], expanded);
            }
            var argPtr = HEAP32[(((varargs)+(argIndex))>>2)];
            argIndex += Runtime.getAlignSize('void*', null, true);
            fields++;
            for (var i = 0; i < maxNumCharacters; i++) {
              next = get();
              if (negateScanList) {
                if (scanList.indexOf(String.fromCharCode(next)) < 0) {
                  HEAP8[((argPtr++)|0)]=next;
                } else {
                  unget();
                  break;
                }
              } else {
                if (scanList.indexOf(String.fromCharCode(next)) >= 0) {
                  HEAP8[((argPtr++)|0)]=next;
                } else {
                  unget();
                  break;
                }
              }
            }
            // write out null-terminating character
            HEAP8[((argPtr++)|0)]=0;
            formatIndex += match[0].length;
            continue;
          }
        }      
        // remove whitespace
        while (1) {
          next = get();
          if (next == 0) return fields;
          if (!(next in __scanString.whiteSpace)) break;
        }
        unget();
        if (format[formatIndex] === '%') {
          formatIndex++;
          var suppressAssignment = false;
          if (format[formatIndex] == '*') {
            suppressAssignment = true;
            formatIndex++;
          }
          var maxSpecifierStart = formatIndex;
          while (format[formatIndex].charCodeAt(0) >= 48 &&
                 format[formatIndex].charCodeAt(0) <= 57) {
            formatIndex++;
          }
          var max_;
          if (formatIndex != maxSpecifierStart) {
            max_ = parseInt(format.slice(maxSpecifierStart, formatIndex), 10);
          }
          var long_ = false;
          var half = false;
          var longLong = false;
          if (format[formatIndex] == 'l') {
            long_ = true;
            formatIndex++;
            if (format[formatIndex] == 'l') {
              longLong = true;
              formatIndex++;
            }
          } else if (format[formatIndex] == 'h') {
            half = true;
            formatIndex++;
          }
          var type = format[formatIndex];
          formatIndex++;
          var curr = 0;
          var buffer = [];
          // Read characters according to the format. floats are trickier, they may be in an unfloat state in the middle, then be a valid float later
          if (type == 'f' || type == 'e' || type == 'g' ||
              type == 'F' || type == 'E' || type == 'G') {
            next = get();
            while (next > 0 && (!(next in __scanString.whiteSpace)))  {
              buffer.push(String.fromCharCode(next));
              next = get();
            }
            var m = __getFloat(buffer.join(''));
            var last = m ? m[0].length : 0;
            for (var i = 0; i < buffer.length - last + 1; i++) {
              unget();
            }
            buffer.length = last;
          } else {
            next = get();
            var first = true;
            // Strip the optional 0x prefix for %x.
            if ((type == 'x' || type == 'X') && (next == 48)) {
              var peek = get();
              if (peek == 120 || peek == 88) {
                next = get();
              } else {
                unget();
              }
            }
            while ((curr < max_ || isNaN(max_)) && next > 0) {
              if (!(next in __scanString.whiteSpace) && // stop on whitespace
                  (type == 's' ||
                   ((type === 'd' || type == 'u' || type == 'i') && ((next >= 48 && next <= 57) ||
                                                                     (first && next == 45))) ||
                   ((type === 'x' || type === 'X') && (next >= 48 && next <= 57 ||
                                     next >= 97 && next <= 102 ||
                                     next >= 65 && next <= 70))) &&
                  (formatIndex >= format.length || next !== format[formatIndex].charCodeAt(0))) { // Stop when we read something that is coming up
                buffer.push(String.fromCharCode(next));
                next = get();
                curr++;
                first = false;
              } else {
                break;
              }
            }
            unget();
          }
          if (buffer.length === 0) return 0;  // Failure.
          if (suppressAssignment) continue;
          var text = buffer.join('');
          var argPtr = HEAP32[(((varargs)+(argIndex))>>2)];
          argIndex += Runtime.getAlignSize('void*', null, true);
          switch (type) {
            case 'd': case 'u': case 'i':
              if (half) {
                HEAP16[((argPtr)>>1)]=parseInt(text, 10);
              } else if (longLong) {
                (tempI64 = [parseInt(text, 10)>>>0,(tempDouble=parseInt(text, 10),(+(Math_abs(tempDouble))) >= (+1) ? (tempDouble > (+0) ? ((Math_min((+(Math_floor((tempDouble)/(+4294967296)))), (+4294967295)))|0)>>>0 : (~~((+(Math_ceil((tempDouble - +(((~~(tempDouble)))>>>0))/(+4294967296))))))>>>0) : 0)],HEAP32[((argPtr)>>2)]=tempI64[0],HEAP32[(((argPtr)+(4))>>2)]=tempI64[1]);
              } else {
                HEAP32[((argPtr)>>2)]=parseInt(text, 10);
              }
              break;
            case 'X':
            case 'x':
              HEAP32[((argPtr)>>2)]=parseInt(text, 16)
              break;
            case 'F':
            case 'f':
            case 'E':
            case 'e':
            case 'G':
            case 'g':
            case 'E':
              // fallthrough intended
              if (long_) {
                HEAPF64[((argPtr)>>3)]=parseFloat(text)
              } else {
                HEAPF32[((argPtr)>>2)]=parseFloat(text)
              }
              break;
            case 's':
              var array = intArrayFromString(text);
              for (var j = 0; j < array.length; j++) {
                HEAP8[(((argPtr)+(j))|0)]=array[j]
              }
              break;
          }
          fields++;
        } else if (format[formatIndex].charCodeAt(0) in __scanString.whiteSpace) {
          next = get();
          while (next in __scanString.whiteSpace) {
            if (next <= 0) break mainLoop;  // End of input.
            next = get();
          }
          unget(next);
          formatIndex++;
        } else {
          // Not a specifier.
          next = get();
          if (format[formatIndex].charCodeAt(0) !== next) {
            unget(next);
            break mainLoop;
          }
          formatIndex++;
        }
      }
      return fields;
    }function _sscanf(s, format, varargs) {
      // int sscanf(const char *restrict s, const char *restrict format, ... );
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/scanf.html
      var index = 0;
      function get() { return HEAP8[(((s)+(index++))|0)]; };
      function unget() { index--; };
      return __scanString(format, get, unget, varargs);
    }
  function _pthread_mutex_lock() {}
  function _pthread_mutex_unlock() {}
  function __ZSt9terminatev() {
      _exit(-1234);
    }
  function ___cxa_guard_acquire(variable) {
      if (!HEAP8[(variable)]) { // ignore SAFE_HEAP stuff because llvm mixes i64 and i8 here
        HEAP8[(variable)]=1;
        return 1;
      }
      return 0;
    }
  function ___cxa_guard_release() {}
  function _pthread_cond_broadcast() {
      return 0;
    }
  function _pthread_cond_wait() {
      return 0;
    }
  function ___cxa_begin_catch(ptr) {
      __ZSt18uncaught_exceptionv.uncaught_exception--;
      return ptr;
    }
  function ___cxa_end_catch() {
      if (___cxa_end_catch.rethrown) {
        ___cxa_end_catch.rethrown = false;
        return;
      }
      // Clear state flag.
      asm['setThrew'](0);
      // Clear type.
      HEAP32[(((_llvm_eh_exception.buf)+(4))>>2)]=0
      // Call destructor if one is registered then clear it.
      var ptr = HEAP32[((_llvm_eh_exception.buf)>>2)];
      var destructor = HEAP32[(((_llvm_eh_exception.buf)+(8))>>2)];
      if (destructor) {
        Runtime.dynCall('vi', destructor, [ptr]);
        HEAP32[(((_llvm_eh_exception.buf)+(8))>>2)]=0
      }
      // Free ptr if it isn't null.
      if (ptr) {
        ___cxa_free_exception(ptr);
        HEAP32[((_llvm_eh_exception.buf)>>2)]=0
      }
    }
  function _ungetc(c, stream) {
      // int ungetc(int c, FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/ungetc.html
      stream = FS.getStream(stream);
      if (!stream) {
        return -1;
      }
      if (c === -1) {
        // do nothing for EOF character
        return c;
      }
      c = unSign(c & 0xFF);
      stream.ungotten.push(c);
      stream.eof = false;
      return c;
    }
  function _abort() {
      Module['abort']();
    }
  function ___cxa_rethrow() {
      ___cxa_end_catch.rethrown = true;
      throw HEAP32[((_llvm_eh_exception.buf)>>2)] + " - Exception catching is disabled, this exception cannot be caught. Compile with -s DISABLE_EXCEPTION_CATCHING=0 or DISABLE_EXCEPTION_CATCHING=2 to catch.";;
    }
  function _sysconf(name) {
      // long sysconf(int name);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/sysconf.html
      switch(name) {
        case 30: return PAGE_SIZE;
        case 132:
        case 133:
        case 12:
        case 137:
        case 138:
        case 15:
        case 235:
        case 16:
        case 17:
        case 18:
        case 19:
        case 20:
        case 149:
        case 13:
        case 10:
        case 236:
        case 153:
        case 9:
        case 21:
        case 22:
        case 159:
        case 154:
        case 14:
        case 77:
        case 78:
        case 139:
        case 80:
        case 81:
        case 79:
        case 82:
        case 68:
        case 67:
        case 164:
        case 11:
        case 29:
        case 47:
        case 48:
        case 95:
        case 52:
        case 51:
        case 46:
          return 200809;
        case 27:
        case 246:
        case 127:
        case 128:
        case 23:
        case 24:
        case 160:
        case 161:
        case 181:
        case 182:
        case 242:
        case 183:
        case 184:
        case 243:
        case 244:
        case 245:
        case 165:
        case 178:
        case 179:
        case 49:
        case 50:
        case 168:
        case 169:
        case 175:
        case 170:
        case 171:
        case 172:
        case 97:
        case 76:
        case 32:
        case 173:
        case 35:
          return -1;
        case 176:
        case 177:
        case 7:
        case 155:
        case 8:
        case 157:
        case 125:
        case 126:
        case 92:
        case 93:
        case 129:
        case 130:
        case 131:
        case 94:
        case 91:
          return 1;
        case 74:
        case 60:
        case 69:
        case 70:
        case 4:
          return 1024;
        case 31:
        case 42:
        case 72:
          return 32;
        case 87:
        case 26:
        case 33:
          return 2147483647;
        case 34:
        case 1:
          return 47839;
        case 38:
        case 36:
          return 99;
        case 43:
        case 37:
          return 2048;
        case 0: return 2097152;
        case 3: return 65536;
        case 28: return 32768;
        case 44: return 32767;
        case 75: return 16384;
        case 39: return 1000;
        case 89: return 700;
        case 71: return 256;
        case 40: return 255;
        case 2: return 100;
        case 180: return 64;
        case 25: return 20;
        case 5: return 16;
        case 6: return 6;
        case 73: return 4;
        case 84: return 1;
      }
      ___setErrNo(ERRNO_CODES.EINVAL);
      return -1;
    }
  function ___cxa_guard_abort() {}
  function _isxdigit(chr) {
      return (chr >= 48 && chr <= 57) ||
             (chr >= 97 && chr <= 102) ||
             (chr >= 65 && chr <= 70);
    }var _isxdigit_l=_isxdigit;
  function _isdigit(chr) {
      return chr >= 48 && chr <= 57;
    }var _isdigit_l=_isdigit;
  function _catopen() { throw 'TODO: ' + aborter }
  function _catgets() { throw 'TODO: ' + aborter }
  function _catclose() { throw 'TODO: ' + aborter }
  function _newlocale(mask, locale, base) {
      return _malloc(4);
    }
  function _freelocale(locale) {
      _free(locale);
    }
  function _isascii(chr) {
      return chr >= 0 && (chr & 0x80) == 0;
    }
  function ___ctype_b_loc() {
      // http://refspecs.freestandards.org/LSB_3.0.0/LSB-Core-generic/LSB-Core-generic/baselib---ctype-b-loc.html
      var me = ___ctype_b_loc;
      if (!me.ret) {
        var values = [
          0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
          0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
          0,0,0,0,0,0,0,0,0,0,2,2,2,2,2,2,2,2,2,8195,8194,8194,8194,8194,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,24577,49156,49156,49156,
          49156,49156,49156,49156,49156,49156,49156,49156,49156,49156,49156,49156,55304,55304,55304,55304,55304,55304,55304,55304,
          55304,55304,49156,49156,49156,49156,49156,49156,49156,54536,54536,54536,54536,54536,54536,50440,50440,50440,50440,50440,
          50440,50440,50440,50440,50440,50440,50440,50440,50440,50440,50440,50440,50440,50440,50440,49156,49156,49156,49156,49156,
          49156,54792,54792,54792,54792,54792,54792,50696,50696,50696,50696,50696,50696,50696,50696,50696,50696,50696,50696,50696,
          50696,50696,50696,50696,50696,50696,50696,49156,49156,49156,49156,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
          0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
          0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
        ];
        var i16size = 2;
        var arr = _malloc(values.length * i16size);
        for (var i = 0; i < values.length; i++) {
          HEAP16[(((arr)+(i * i16size))>>1)]=values[i]
        }
        me.ret = allocate([arr + 128 * i16size], 'i16*', ALLOC_NORMAL);
      }
      return me.ret;
    }
  function ___ctype_tolower_loc() {
      // http://refspecs.freestandards.org/LSB_3.1.1/LSB-Core-generic/LSB-Core-generic/libutil---ctype-tolower-loc.html
      var me = ___ctype_tolower_loc;
      if (!me.ret) {
        var values = [
          128,129,130,131,132,133,134,135,136,137,138,139,140,141,142,143,144,145,146,147,148,149,150,151,152,153,154,155,156,157,
          158,159,160,161,162,163,164,165,166,167,168,169,170,171,172,173,174,175,176,177,178,179,180,181,182,183,184,185,186,187,
          188,189,190,191,192,193,194,195,196,197,198,199,200,201,202,203,204,205,206,207,208,209,210,211,212,213,214,215,216,217,
          218,219,220,221,222,223,224,225,226,227,228,229,230,231,232,233,234,235,236,237,238,239,240,241,242,243,244,245,246,247,
          248,249,250,251,252,253,254,-1,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,
          33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57,58,59,60,61,62,63,64,97,98,99,100,101,102,103,
          104,105,106,107,108,109,110,111,112,113,114,115,116,117,118,119,120,121,122,91,92,93,94,95,96,97,98,99,100,101,102,103,
          104,105,106,107,108,109,110,111,112,113,114,115,116,117,118,119,120,121,122,123,124,125,126,127,128,129,130,131,132,133,
          134,135,136,137,138,139,140,141,142,143,144,145,146,147,148,149,150,151,152,153,154,155,156,157,158,159,160,161,162,163,
          164,165,166,167,168,169,170,171,172,173,174,175,176,177,178,179,180,181,182,183,184,185,186,187,188,189,190,191,192,193,
          194,195,196,197,198,199,200,201,202,203,204,205,206,207,208,209,210,211,212,213,214,215,216,217,218,219,220,221,222,223,
          224,225,226,227,228,229,230,231,232,233,234,235,236,237,238,239,240,241,242,243,244,245,246,247,248,249,250,251,252,253,
          254,255
        ];
        var i32size = 4;
        var arr = _malloc(values.length * i32size);
        for (var i = 0; i < values.length; i++) {
          HEAP32[(((arr)+(i * i32size))>>2)]=values[i]
        }
        me.ret = allocate([arr + 128 * i32size], 'i32*', ALLOC_NORMAL);
      }
      return me.ret;
    }
  function ___ctype_toupper_loc() {
      // http://refspecs.freestandards.org/LSB_3.1.1/LSB-Core-generic/LSB-Core-generic/libutil---ctype-toupper-loc.html
      var me = ___ctype_toupper_loc;
      if (!me.ret) {
        var values = [
          128,129,130,131,132,133,134,135,136,137,138,139,140,141,142,143,144,145,146,147,148,149,150,151,152,153,154,155,156,157,
          158,159,160,161,162,163,164,165,166,167,168,169,170,171,172,173,174,175,176,177,178,179,180,181,182,183,184,185,186,187,
          188,189,190,191,192,193,194,195,196,197,198,199,200,201,202,203,204,205,206,207,208,209,210,211,212,213,214,215,216,217,
          218,219,220,221,222,223,224,225,226,227,228,229,230,231,232,233,234,235,236,237,238,239,240,241,242,243,244,245,246,247,
          248,249,250,251,252,253,254,-1,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,
          33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57,58,59,60,61,62,63,64,65,66,67,68,69,70,71,72,
          73,74,75,76,77,78,79,80,81,82,83,84,85,86,87,88,89,90,91,92,93,94,95,96,65,66,67,68,69,70,71,72,73,74,75,76,77,78,79,80,
          81,82,83,84,85,86,87,88,89,90,123,124,125,126,127,128,129,130,131,132,133,134,135,136,137,138,139,140,141,142,143,144,
          145,146,147,148,149,150,151,152,153,154,155,156,157,158,159,160,161,162,163,164,165,166,167,168,169,170,171,172,173,174,
          175,176,177,178,179,180,181,182,183,184,185,186,187,188,189,190,191,192,193,194,195,196,197,198,199,200,201,202,203,204,
          205,206,207,208,209,210,211,212,213,214,215,216,217,218,219,220,221,222,223,224,225,226,227,228,229,230,231,232,233,234,
          235,236,237,238,239,240,241,242,243,244,245,246,247,248,249,250,251,252,253,254,255
        ];
        var i32size = 4;
        var arr = _malloc(values.length * i32size);
        for (var i = 0; i < values.length; i++) {
          HEAP32[(((arr)+(i * i32size))>>2)]=values[i]
        }
        me.ret = allocate([arr + 128 * i32size], 'i32*', ALLOC_NORMAL);
      }
      return me.ret;
    }
  var _strftime_l=_strftime;
  var _strtoull_l=_strtoull;
  function _strtoll(str, endptr, base) {
      return __parseInt64(str, endptr, base, '-9223372036854775808', '9223372036854775807');  // LLONG_MIN, LLONG_MAX.
    }var _strtoll_l=_strtoll;
  function _uselocale(locale) {
      return 0;
    }
  function _asprintf(s, format, varargs) {
      return _sprintf(-s, format, varargs);
    }function _vasprintf(s, format, va_arg) {
      return _asprintf(s, format, HEAP32[((va_arg)>>2)]);
    }
  function _vsscanf(s, format, va_arg) {
      return _sscanf(s, format, HEAP32[((va_arg)>>2)]);
    }
  function _sbrk(bytes) {
      // Implement a Linux-like 'memory area' for our 'process'.
      // Changes the size of the memory area by |bytes|; returns the
      // address of the previous top ('break') of the memory area
      // We control the "dynamic" memory - DYNAMIC_BASE to DYNAMICTOP
      var self = _sbrk;
      if (!self.called) {
        DYNAMICTOP = alignMemoryPage(DYNAMICTOP); // make sure we start out aligned
        self.called = true;
        assert(Runtime.dynamicAlloc);
        self.alloc = Runtime.dynamicAlloc;
        Runtime.dynamicAlloc = function() { abort('cannot dynamically allocate, sbrk now has control') };
      }
      var ret = DYNAMICTOP;
      if (bytes != 0) self.alloc(bytes);
      return ret;  // Previous break location.
    }
  function ___cxa_call_unexpected(exception) {
      Module.printErr('Unexpected exception thrown, this is not properly supported - aborting');
      ABORT = true;
      throw exception;
    }
FS.staticInit();__ATINIT__.unshift({ func: function() { if (!Module["noFSInit"] && !FS.init.initialized) FS.init() } });__ATMAIN__.push({ func: function() { FS.ignorePermissions = false } });__ATEXIT__.push({ func: function() { FS.quit() } });Module["FS_createFolder"] = FS.createFolder;Module["FS_createPath"] = FS.createPath;Module["FS_createDataFile"] = FS.createDataFile;Module["FS_createPreloadedFile"] = FS.createPreloadedFile;Module["FS_createLazyFile"] = FS.createLazyFile;Module["FS_createLink"] = FS.createLink;Module["FS_createDevice"] = FS.createDevice;
___errno_state = Runtime.staticAlloc(4); HEAP32[((___errno_state)>>2)]=0;
__ATINIT__.unshift({ func: function() { TTY.init() } });__ATEXIT__.push({ func: function() { TTY.shutdown() } });TTY.utf8 = new Runtime.UTF8Processor();
if (ENVIRONMENT_IS_NODE) { var fs = require("fs"); NODEFS.staticInit(); }
__ATINIT__.push({ func: function() { SOCKFS.root = FS.mount(SOCKFS, {}, null); } });
_fputc.ret = allocate([0], "i8", ALLOC_STATIC);
___buildEnvironment(ENV);
_fgetc.ret = allocate([0], "i8", ALLOC_STATIC);
Module["requestFullScreen"] = function Module_requestFullScreen(lockPointer, resizeCanvas) { Browser.requestFullScreen(lockPointer, resizeCanvas) };
  Module["requestAnimationFrame"] = function Module_requestAnimationFrame(func) { Browser.requestAnimationFrame(func) };
  Module["setCanvasSize"] = function Module_setCanvasSize(width, height, noUpdates) { Browser.setCanvasSize(width, height, noUpdates) };
  Module["pauseMainLoop"] = function Module_pauseMainLoop() { Browser.mainLoop.pause() };
  Module["resumeMainLoop"] = function Module_resumeMainLoop() { Browser.mainLoop.resume() };
  Module["getUserMedia"] = function Module_getUserMedia() { Browser.getUserMedia() }
GL.init()
_llvm_eh_exception.buf = allocate(12, "void*", ALLOC_STATIC);
STACK_BASE = STACKTOP = Runtime.alignMemory(STATICTOP);
staticSealed = true; // seal the static portion of memory
STACK_MAX = STACK_BASE + 5242880;
DYNAMIC_BASE = DYNAMICTOP = Runtime.alignMemory(STACK_MAX);
assert(DYNAMIC_BASE < TOTAL_MEMORY); // Stack must fit in TOTAL_MEMORY; allocations from here on may enlarge TOTAL_MEMORY
 var ctlz_i8 = allocate([8,7,6,6,5,5,5,5,4,4,4,4,4,4,4,4,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0], "i8", ALLOC_DYNAMIC);
 var cttz_i8 = allocate([8,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,6,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,7,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,6,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0], "i8", ALLOC_DYNAMIC);
var Math_min = Math.min;
function invoke_iiiiiiii(index,a1,a2,a3,a4,a5,a6,a7) {
  try {
    return Module["dynCall_iiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_vif(index,a1,a2) {
  try {
    Module["dynCall_vif"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viiiii(index,a1,a2,a3,a4,a5) {
  try {
    Module["dynCall_viiiii"](index,a1,a2,a3,a4,a5);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_vi(index,a1) {
  try {
    Module["dynCall_vi"](index,a1);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_vii(index,a1,a2) {
  try {
    Module["dynCall_vii"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_iiiiiii(index,a1,a2,a3,a4,a5,a6) {
  try {
    return Module["dynCall_iiiiiii"](index,a1,a2,a3,a4,a5,a6);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viff(index,a1,a2,a3) {
  try {
    Module["dynCall_viff"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_ii(index,a1) {
  try {
    return Module["dynCall_ii"](index,a1);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viiiiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11) {
  try {
    Module["dynCall_viiiiiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viffff(index,a1,a2,a3,a4,a5) {
  try {
    Module["dynCall_viffff"](index,a1,a2,a3,a4,a5);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_if(index,a1) {
  try {
    return Module["dynCall_if"](index,a1);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viiif(index,a1,a2,a3,a4) {
  try {
    Module["dynCall_viiif"](index,a1,a2,a3,a4);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_iiifii(index,a1,a2,a3,a4,a5) {
  try {
    return Module["dynCall_iiifii"](index,a1,a2,a3,a4,a5);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_iiii(index,a1,a2,a3) {
  try {
    return Module["dynCall_iiii"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viiiiif(index,a1,a2,a3,a4,a5,a6) {
  try {
    Module["dynCall_viiiiif"](index,a1,a2,a3,a4,a5,a6);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8) {
  try {
    Module["dynCall_viiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_vifff(index,a1,a2,a3,a4) {
  try {
    Module["dynCall_vifff"](index,a1,a2,a3,a4);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_fii(index,a1,a2) {
  try {
    return Module["dynCall_fii"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_v(index) {
  try {
    Module["dynCall_v"](index);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_iif(index,a1,a2) {
  try {
    return Module["dynCall_iif"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viiiiiii(index,a1,a2,a3,a4,a5,a6,a7) {
  try {
    Module["dynCall_viiiiiii"](index,a1,a2,a3,a4,a5,a6,a7);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_ff(index,a1) {
  try {
    return Module["dynCall_ff"](index,a1);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9) {
  try {
    Module["dynCall_viiiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viiiiiif(index,a1,a2,a3,a4,a5,a6,a7) {
  try {
    Module["dynCall_viiiiiif"](index,a1,a2,a3,a4,a5,a6,a7);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_iii(index,a1,a2) {
  try {
    return Module["dynCall_iii"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viiiiii(index,a1,a2,a3,a4,a5,a6) {
  try {
    Module["dynCall_viiiiii"](index,a1,a2,a3,a4,a5,a6);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_f(index) {
  try {
    return Module["dynCall_f"](index);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_i(index) {
  try {
    return Module["dynCall_i"](index);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_vff(index,a1,a2) {
  try {
    Module["dynCall_vff"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_iiiiii(index,a1,a2,a3,a4,a5) {
  try {
    return Module["dynCall_iiiiii"](index,a1,a2,a3,a4,a5);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viii(index,a1,a2,a3) {
  try {
    Module["dynCall_viii"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viiffff(index,a1,a2,a3,a4,a5,a6) {
  try {
    Module["dynCall_viiffff"](index,a1,a2,a3,a4,a5,a6);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_iiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8) {
  try {
    return Module["dynCall_iiiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_iiiii(index,a1,a2,a3,a4) {
  try {
    return Module["dynCall_iiiii"](index,a1,a2,a3,a4);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viif(index,a1,a2,a3) {
  try {
    Module["dynCall_viif"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viiii(index,a1,a2,a3,a4) {
  try {
    Module["dynCall_viiii"](index,a1,a2,a3,a4);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function asmPrintInt(x, y) {
  Module.print('int ' + x + ',' + y);// + ' ' + new Error().stack);
}
function asmPrintFloat(x, y) {
  Module.print('float ' + x + ',' + y);// + ' ' + new Error().stack);
}
// EMSCRIPTEN_START_ASM
var asm=(function(global,env,buffer){"use asm";var a=new global.Int8Array(buffer);var b=new global.Int16Array(buffer);var c=new global.Int32Array(buffer);var d=new global.Uint8Array(buffer);var e=new global.Uint16Array(buffer);var f=new global.Uint32Array(buffer);var g=new global.Float32Array(buffer);var h=new global.Float64Array(buffer);var i=env.STACKTOP|0;var j=env.STACK_MAX|0;var k=env.tempDoublePtr|0;var l=env.ABORT|0;var m=env.cttz_i8|0;var n=env.ctlz_i8|0;var o=env.__ZTVN10__cxxabiv117__class_type_infoE|0;var p=env._stdin|0;var q=env.___fsmu8|0;var r=env.__ZTVN10__cxxabiv120__si_class_type_infoE|0;var s=env._stdout|0;var t=env.___dso_handle|0;var u=env._stderr|0;var v=+env.NaN;var w=+env.Infinity;var x=0;var y=0;var z=0;var A=0;var B=0,C=0,D=0,E=0,F=0.0,G=0,H=0,I=0,J=0.0;var K=0;var L=0;var M=0;var N=0;var O=0;var P=0;var Q=0;var R=0;var S=0;var T=0;var U=global.Math.floor;var V=global.Math.abs;var W=global.Math.sqrt;var X=global.Math.pow;var Y=global.Math.cos;var Z=global.Math.sin;var _=global.Math.tan;var $=global.Math.acos;var aa=global.Math.asin;var ab=global.Math.atan;var ac=global.Math.atan2;var ad=global.Math.exp;var ae=global.Math.log;var af=global.Math.ceil;var ag=global.Math.imul;var ah=env.abort;var ai=env.assert;var aj=env.asmPrintInt;var ak=env.asmPrintFloat;var al=env.min;var am=env.invoke_iiiiiiii;var an=env.invoke_vif;var ao=env.invoke_viiiii;var ap=env.invoke_vi;var aq=env.invoke_vii;var ar=env.invoke_iiiiiii;var as=env.invoke_viff;var at=env.invoke_ii;var au=env.invoke_viiiiiiiiiii;var av=env.invoke_viffff;var aw=env.invoke_if;var ax=env.invoke_viiif;var ay=env.invoke_iiifii;var az=env.invoke_iiii;var aA=env.invoke_viiiiif;var aB=env.invoke_viiiiiiii;var aC=env.invoke_vifff;var aD=env.invoke_fii;var aE=env.invoke_v;var aF=env.invoke_iif;var aG=env.invoke_viiiiiii;var aH=env.invoke_ff;var aI=env.invoke_viiiiiiiii;var aJ=env.invoke_viiiiiif;var aK=env.invoke_iii;var aL=env.invoke_viiiiii;var aM=env.invoke_f;var aN=env.invoke_i;var aO=env.invoke_vff;var aP=env.invoke_iiiiii;var aQ=env.invoke_viii;var aR=env.invoke_viiffff;var aS=env.invoke_iiiiiiiii;var aT=env.invoke_iiiii;var aU=env.invoke_viif;var aV=env.invoke_viiii;var aW=env._RWebInputDestroy;var aX=env.__scanString;var aY=env._fclose;var aZ=env._glStencilMaskSeparate;var a_=env._pthread_mutex_lock;var a$=env.___cxa_end_catch;var a0=env._glFramebufferRenderbuffer;var a1=env._send;var a2=env._glLineWidth;var a3=env._glCompileShader;var a4=env._isspace;var a5=env._localtime;var a6=env._glDepthRangef;var a7=env._opendir;var a8=env.___resumeException;var a9=env._glCreateShader;var ba=env._round;var bb=env._glGenRenderbuffers;var bc=env._cosf;var bd=env._glCompressedTexImage2D;var be=env._snprintf;var bf=env._glBlendFuncSeparate;var bg=env._glHint;var bh=env._mknod;var bi=env.___cxa_free_exception;var bj=env._glDeleteProgram;var bk=env._glRenderbufferStorage;var bl=env._glLoadIdentity;var bm=env._glUniform3i;var bn=env._localtime_r;var bo=env._glUniform3f;var bp=env.___cxa_guard_acquire;var bq=env._glGetBufferParameteriv;var br=env._sinf;var bs=env._glGenVertexArrays;var bt=env._eglChooseConfig;var bu=env._eglQuerySurface;var bv=env._glBegin;var bw=env._printf;var bx=env._glVertexPointer;var by=env._glDeleteFramebuffers;var bz=env._glDrawArrays;var bA=env._llvm_pow_f32;var bB=env.__arraySum;var bC=env._glClear;var bD=env._gluProject;var bE=env._glIsEnabled;var bF=env._glStencilOp;var bG=env._strdup;var bH=env._glFramebufferTexture2D;var bI=env._glGetFramebufferAttachmentParameteriv;var bJ=env._eglCreateWindowSurface;var bK=env._pthread_cond_broadcast;var bL=env.__ZSt9terminatev;var bM=env._glTexParameteriv;var bN=env._glGenFramebuffers;var bO=env.___errno_location;var bP=env._strerror;var bQ=env._glGetAttachedShaders;var bR=env._catclose;var bS=env._glIsRenderbuffer;var bT=env.__parseInt;var bU=env._fprintf;var bV=env._glDisableVertexAttribArray;var bW=env._sysconf;var bX=env._abort;var bY=env._glIsShader;var bZ=env._strtoll;var b_=env._glDisable;var b$=env._glEnable;var b0=env._feof;var b1=env._eglDestroySurface;var b2=env._write;var b3=env._glGetAttribLocation;var b4=env._rewind;var b5=env._sin;var b6=env._vasprintf;var b7=env._emscripten_set_main_loop;var b8=env._glGetUniformfv;var b9=env._unlink;var ca=env._gluOrtho2D;var cb=env._glDepthRange;var cc=env._pwrite;var cd=env._RWebAudioStart;var ce=env._glFlush;var cf=env._glGetRenderbufferParameteriv;var cg=env._glGetVertexAttribPointerv;var ch=env._strtoul;var ci=env.__isLeapYear;var cj=env._fwrite;var ck=env._gluUnProject;var cl=env._eglBindAPI;var cm=env._glStencilFuncSeparate;var cn=env._glUniform4iv;var co=env._glClearStencil;var cp=env._glGenTextures;var cq=env.___cxa_rethrow;var cr=env._RWebAudioWrite;var cs=env._memchr;var ct=env._llvm_va_end;var cu=env._clock_gettime;var cv=env._vsscanf;var cw=env._glDeleteRenderbuffers;var cx=env._glUniform2i;var cy=env._glUniform2f;var cz=env._glGetProgramiv;var cA=env._glVertexAttribPointer;var cB=env._glutInitDisplayMode;var cC=env._sprintf;var cD=env.___ctype_b_loc;var cE=env._strrchr;var cF=env._RWebInputPoll;var cG=env._catgets;var cH=env._asprintf;var cI=env._ferror;var cJ=env._llvm_uadd_with_overflow_i32;var cK=env._glCopyTexImage2D;var cL=env.___cxa_begin_catch;var cM=env._recv;var cN=env._glUniform2iv;var cO=env.__ZSt18uncaught_exceptionv;var cP=env._putchar;var cQ=env._glMatrixMode;var cR=env._glIsBuffer;var cS=env._glGetShaderiv;var cT=env._rand;var cU=env._RWebAudioSampleRate;var cV=env._glCopyTexSubImage2D;var cW=env._mkdir;var cX=env._glPolygonOffset;var cY=env._open;var cZ=env._usleep;var c_=env._glVertexAttrib1fv;var c$=env._exp2;var c0=env._qsort;var c1=env._isalpha;var c2=env._glUniform3fv;var c3=env._glGetVertexAttribiv;var c4=env._isascii;var c5=env._glVertexAttrib3fv;var c6=env._glUniform3iv;var c7=env._llvm_pow_f64;var c8=env._strerror_r;var c9=env._llvm_bswap_i32;var da=env.___cxa_guard_release;var db=env._vsnprintf;var dc=env._glUseProgram;var dd=env._glGetProgramInfoLog;var de=env._strtok_r;var df=env.___buildEnvironment;var dg=env.__addDays;var dh=env._fseek;var di=env._glFinish;var dj=env._gluLookAt;var dk=env._glDeleteShader;var dl=env._realpath;var dm=env._glViewport;var dn=env._catopen;var dp=env._RWebAudioWriteAvail;var dq=env._glClearDepth;var dr=env._glTexParameterf;var ds=env._glTexParameteri;var dt=env._glCullFace;var du=env._glGetShaderSource;var dv=env._eglGetDisplay;var dw=env._emscripten_set_canvas_size;var dx=env._exp;var dy=env._glValidateProgram;var dz=env._RWebAudioBufferSize;var dA=env._eglTerminate;var dB=env._glLinkProgram;var dC=env._strtoull;var dD=env._glBindTexture;var dE=env._strtol;var dF=env._fputc;var dG=env._glGetString;var dH=env._glDetachShader;var dI=env._fputs;var dJ=env._RWebAudioFree;var dK=env._glDeleteTextures;var dL=env._glStencilOpSeparate;var dM=env._glVertexAttrib4f;var dN=env._ceil;var dO=env._glGetTexParameteriv;var dP=env._glutDestroyWindow;var dQ=env._glSampleCoverage;var dR=env._remove;var dS=env._pthread_cond_wait;var dT=env._glUniform1f;var dU=env._glGetVertexAttribfv;var dV=env._glUniform1i;var dW=env._strncmp;var dX=env._glTexSubImage2D;var dY=env._glGetUniformiv;var dZ=env._atexit;var d_=env._close;var d$=env._glBindFramebuffer;var d0=env._strchr;var d1=env.___setErrNo;var d2=env._emscripten_GetProcAddress;var d3=env._eglGetProcAddress;var d4=env._freelocale;var d5=env._glAttachShader;var d6=env._glShaderBinary;var d7=env.___cxa_is_number_type;var d8=env.___cxa_does_inherit;var d9=env._emscripten_get_canvas_size;var ea=env._glDrawElements;var eb=env._glUniform1iv;var ec=env._glGenerateMipmap;var ed=env._strftime;var ee=env._glVertexAttrib3f;var ef=env._tzset;var eg=env._fabsf;var eh=env.___cxa_throw;var ei=env._glBindRenderbuffer;var ej=env._pread;var ek=env._glIsProgram;var el=env._puts;var em=env._nanosleep;var en=env._glVertexAttrib4fv;var eo=env._glReleaseShaderCompiler;var ep=env._glUniform4i;var eq=env._glActiveTexture;var er=env._glEnableVertexAttribArray;var es=env.___cxa_find_matching_catch;var et=env._glReadPixels;var eu=env._glUniform4f;var ev=env.___gxx_personality_v0;var ew=env._fread;var ex=env._glUniformMatrix3fv;var ey=env.__formatString;var ez=env._emscripten_procAddressTable;var eA=env._glIsTexture;var eB=env._glStencilFunc;var eC=env._srand;var eD=env._glGetShaderInfoLog;var eE=env._RWebAudioSetNonblockState;var eF=env._fabs;var eG=env._RWebAudioStop;var eH=env._sqrt;var eI=env._glBlendEquationSeparate;var eJ=env._glGenBuffers;var eK=env._glBlendFunc;var eL=env._glCreateProgram;var eM=env._longjmp;var eN=env._glIsFramebuffer;var eO=env._isgraph;var eP=env.___ctype_tolower_loc;var eQ=env._glDeleteBuffers;var eR=env._glScissor;var eS=env._glGetBooleanv;var eT=env._llvm_lifetime_end;var eU=env._lseek;var eV=env._glClearColor;var eW=env._RWebAudioInit;var eX=env._glBlendColor;var eY=env._fflush;var eZ=env._llvm_eh_exception;var e_=env._glUniform2fv;var e$=env._eglCreateContext;var e0=env._read;var e1=env._RWebInputInit;var e2=env._glClearDepthf;var e3=env._strstr;var e4=env._fsync;var e5=env.___cxa_guard_abort;var e6=env._newlocale;var e7=env._glDepthFunc;var e8=env._glCompressedTexSubImage2D;var e9=env._glGetTexParameterfv;var fa=env._strcmp;var fb=env._glVertexAttrib1f;var fc=env._fgetc;var fd=env._readdir;var fe=env._glColorMask;var ff=env.__getFloat;var fg=env._glBlendEquation;var fh=env._fgets;var fi=env._getgid;var fj=env._glUniform4fv;var fk=env._isxdigit;var fl=env._ftell;var fm=env._exit;var fn=env._glCheckFramebufferStatus;var fo=env._glBindAttribLocation;var fp=env._eglInitialize;var fq=env.__parseInt64;var fr=env._glBufferSubData;var fs=env.___cxa_call_unexpected;var ft=env.__exit;var fu=env._glGetShaderPrecisionFormat;var fv=env._glShaderSource;var fw=env._fopen;var fx=env._log;var fy=env._eglDestroyContext;var fz=env._rmdir;var fA=env._glBindBuffer;var fB=env._glUniformMatrix2fv;var fC=env._glutCreateWindow;var fD=env._glBufferData;var fE=env._getenv;var fF=env._glGetError;var fG=env._pthread_mutex_unlock;var fH=env._glGetFloatv;var fI=env._glVertexAttrib2fv;var fJ=env._sbrk;var fK=env._glGetIntegerv;var fL=env._llvm_lifetime_start;var fM=env._ungetc;var fN=env._uselocale;var fO=env._sscanf;var fP=env._glTexImage2D;var fQ=env._glStencilMask;var fR=env._eglMakeCurrent;var fS=env._glGetUniformLocation;var fT=env._glUniform1fv;var fU=env._gluPerspective;var fV=env._isdigit;var fW=env.__reallyNegative;var fX=env._glTexParameterfv;var fY=env._floor;var fZ=env._glGetActiveAttrib;var f_=env.___cxa_allocate_exception;var f$=env._stat;var f0=env._glPixelStorei;var f1=env._readdir_r;var f2=env.___ctype_toupper_loc;var f3=env._glVertexAttrib2f;var f4=env._closedir;var f5=env._readlink;var f6=env._glDepthMask;var f7=env._glUniformMatrix4fv;var f8=env._glGetActiveUniform;var f9=env._glFrontFace;var ga=env._llvm_bswap_i16;var gb=env._time;
// EMSCRIPTEN_START_FUNCS
function e2V(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;e=b-2097152|0;if(e>>>0>=65536){return}b=e^1;f=(c[3532278]|0)+b|0;do{if((a[f]|0)!=d<<24>>24){g=(e|0)>-1;if((c[3532284]|0)==0){if(g&(b|0)<16384){a[14129208]=1}if(g&(b|0)<32768){a[14129128]=1}if((b-24576|0)>>>0>=4096){break}a[14129200]=1;break}else{if(g&(b|0)<32768){a[14129208]=1}if((b-32768|0)>>>0<32768){a[14129128]=1}if((b-69632|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);a[f]=d;return}function e2W(d,e){d=d|0;e=e|0;var f=0,g=0;f=d-2097152|0;if(f>>>0<65536){g=(c[3532278]|0)+(f>>>1<<1)|0;do{if((b[g>>1]|0)!=e<<16>>16){if((c[3532284]|0)==0){if(f>>>0<16384){a[14129208]=1}if((d-2129920|0)>>>0<16384){a[14129128]=1}if((d-2121728|0)>>>0>=4096){break}a[14129200]=1;break}else{if(f>>>0<32768){a[14129208]=1}if((d-2129920|0)>>>0<32768){a[14129128]=1}if((d-2166784|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);b[g>>1]=e;return}g=d-2228224|0;if(g>>>0<16){f=g>>>1;b[14129152+(f<<1)>>1]=e;switch(f|0){case 4:{c[2385820]=-(e&65535);return};case 6:{c[3532284]=(e&65535)>>>4&1;return};case 7:{c[2439396]=e&1;return};case 0:{c[2388344]=-(e&65535);return};case 5:{c[3527494]=-(e&65535);return};case 1:{c[2385826]=-(e&65535);return};case 2:{c[3527502]=-(e&65535);return};case 3:{c[2388334]=-(e&65535);return};default:{return}}}if((d|0)==589824){c[3532014]=(e&65535)>>>6&3;b[7064256]=e;if((e&1)!=0){return}f=c[2394]|0;g=c[14130368+(f<<2)>>2]|0;if((g|0)!=0){gGC(g|0,9104152,280)|0}c[8452240+(f<<2)>>2]=c[2113054];c[2394]=1;c[2112932]=c[3532597];f=c[3532593]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113061];RI();f=c[2394]|0;g=c[14130368+(f<<2)>>2]|0;if((g|0)!=0){gGC(g|0,9104152,280)|0}c[8452240+(f<<2)>>2]=c[2113054];c[2394]=0;c[2112932]=c[3532596];f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];return}else if((d|0)==1048576|(d|0)==1048578){f=(d-1048576|0)>>>1;if((f|0)==0){c[2439392]=e&4095;return}else if((f|0)==1){b[(c[2442928]|0)+(c[2439392]<<1)>>1]=e;c[(c[3532276]|0)+(c[2439392]<<2)>>2]=((e&65535)>>>10<<3&248)<<8|((e&255)<<3&255)>>>3|(((e&65535)>>>7&4|(e&65535)>>>5<<3&255)&255)<<3&2016;return}else{return}}else{return}}function e2X(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;L54260:do{if((b|0)==1048577){e=(c[3532186]|0)>>>4&4095;f=(e|0)==0?0:e^4095;e=(f-96|0)>>>0<32?95:f;f=(e-3968|0)>>>0<32?4e3:e;e=f&255;g=f>>>8;if(f>>>0>3967){h=(g|240)&255}else{h=g&255}g=d[9757560]|0;if((g|0)==9){i=h;break}else if((g|0)==8){i=e;break}switch(g|0){case 1:{i=a[14129049]|0;break L54260;break};case 2:{i=a[14129040]|0;break L54260;break};case 3:{i=a[14129041]|0;break L54260;break};case 4:{i=a[9757556]|0;break L54260;break};case 7:{i=a[14129042]|0;break L54260;break};case 0:{i=a[14129048]|0;break L54260;break};default:{i=0;break L54260}}}else{i=0}}while(0);return i|0}function e2Y(b,d){b=b|0;d=d|0;if((b|0)!=1048577){return}b=a[9757560]|0;a[9757552+(b&255)|0]=d;if((b<<24>>24|0)==0){c[3531956]=0;return}else if((b<<24>>24|0)==4){b=~d;a[14128520]=b&1;a[14128521]=b&2;return}else{return}}function e2Z(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;if((b|0)==1048578){e=d[9757560]|0;return e|0}else if((b|0)==2097154){f=a[9540896]|0;switch(f&255|0){case 2:{a[9540896]=f+1&255;g=a[9540894]|0;break};case 3:{a[9540898]=a[9540898]&-9;a[9540896]=f+1&255;g=a[9540895]|0;break};case 1:{a[9540898]=a[9540898]&-5;a[9540896]=f+1&255;g=a[9540893]|0;break};case 0:{a[9540896]=f+1&255;g=a[9540892]|0;break};case 4:{g=a[9540898]|0;break};default:{g=0}}e=g&255;return e|0}else if((b|0)==1048576){b=(c[3532186]|0)>>>4&4095;g=(b|0)==0?0:b^4095;b=(g-96|0)>>>0<32?95:g;g=(b-3968|0)>>>0<32?4e3:b;b=g>>>8;if(g>>>0>3967){h=(b|240)&255}else{h=b&255}b=d[9757560]|0;L54304:do{if((b|0)==8){i=g&255}else if((b|0)==9){i=h}else{switch(b|0){case 3:{i=a[14129041]|0;break L54304;break};case 1:{i=a[14129049]|0;break L54304;break};case 2:{i=a[14129040]|0;break L54304;break};case 4:{i=a[9757556]|0;break L54304;break};case 7:{i=a[14129042]|0;break L54304;break};case 0:{i=a[14129048]|0;break L54304;break};default:{i=0;break L54304}}}}while(0);e=i&255;return e|0}else{e=0;return e|0}return 0}function e2_(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;if((b|0)==1048576){e=a[9757560]|0;f=d&255;a[9757552+(e&255)|0]=f;if((e<<24>>24|0)==4){g=~f;a[14128520]=g&1;a[14128521]=g&2;return}else if((e<<24>>24|0)==0){c[3531956]=0;return}else{return}}else if((b|0)==2097152){a[9540896]=d&15;return}else if((b|0)==2097154){e=d&15;g=a[9540896]|0;switch(g&255|0){case 0:{a[9540896]=g+1&255;a[9540888]=e;return};case 1:{a[9540896]=g+1&255;a[9540889]=e;a[9540898]=a[9540898]|1;a[9540900]=1;return};case 2:{a[9540896]=g+1&255;a[9540890]=e;return};case 4:{if(e<<24>>24==0){return}f=c[2439330]|0;h=(f|0)==0;if(!h){i=f;gGC(9706056,i|0,76)|0}i=c[2438118]|0;c[2433530]=i;j=c[3528484]|0;c[2076596]=j;k=c[2417276]|0;c[3541536]=k;c[1836236]=0;gGz(9706056,0,76);if(!h){h=f;gGC(h|0,9706056,76)|0}c[2438118]=i;c[3528484]=j;c[2417276]=k;c[1836236]=-1;return};case 3:{a[9540896]=g+1&255;a[9540891]=e;a[9540898]=a[9540898]|2;a[9540900]=1;return};default:{return}}}else if((b|0)==1048578){a[9757560]=d&255;return}else{return}}function e2$(b){b=b|0;var c=0,d=0,e=0;c=b-4194304|0;L54353:do{if(c>>>0<16){switch(c>>>1^1|0){case 4:{d=a[9757532]|0;break L54353;break};case 2:{d=a[14128912]|0;break L54353;break};case 7:{d=a[14128914]|0;break L54353;break};case 0:{d=a[14128920]|0;break L54353;break};case 3:{d=a[14128913]|0;break L54353;break};case 1:{d=a[14128921]|0;break L54353;break};default:{d=-1;break L54353}}}else{if((b|0)!=6422531){d=0;break}e=a[9540896]|0;switch(e&255|0){case 0:{a[9540896]=e+1&255;d=a[9540892]|0;break L54353;break};case 1:{a[9540898]=a[9540898]&-5;a[9540896]=e+1&255;d=a[9540893]|0;break L54353;break};case 2:{a[9540896]=e+1&255;d=a[9540894]|0;break L54353;break};case 3:{a[9540898]=a[9540898]&-9;a[9540896]=e+1&255;d=a[9540895]|0;break L54353;break};case 4:{d=a[9540898]|0;break L54353;break};default:{d=0;break L54353}}}}while(0);return d|0}function e20(d,e){d=d|0;e=e|0;var f=0,g=0,h=0;f=d-4194304|0;if(f>>>0<16){g=f>>>1^1;a[9757528+g|0]=e;if((g|0)==0){c[3531956]=0;return}else if((g|0)==4){g=~e;a[14128520]=g&1;a[14128521]=g&2;return}else{return}}if((d|0)==6422529){a[9540896]=e&15;return}else if((d|0)==6291457){g=e&255;b[7064256]=g;if((g&1)!=0){return}g=c[2394]|0;f=c[14130368+(g<<2)>>2]|0;if((f|0)!=0){gGC(f|0,9104152,280)|0}c[8452240+(g<<2)>>2]=c[2113054];c[2394]=1;c[2112932]=c[3532597];g=c[3532593]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113061];RI();g=c[2394]|0;f=c[14130368+(g<<2)>>2]|0;if((f|0)!=0){gGC(f|0,9104152,280)|0}c[8452240+(g<<2)>>2]=c[2113054];c[2394]=0;c[2112932]=c[3532596];g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060];return}else if((d|0)==6422531){d=e&15;e=a[9540896]|0;switch(e&255|0){case 0:{a[9540896]=e+1&255;a[9540888]=d;return};case 3:{a[9540896]=e+1&255;a[9540891]=d;a[9540898]=a[9540898]|2;a[9540900]=1;return};case 2:{a[9540896]=e+1&255;a[9540890]=d;return};case 1:{a[9540896]=e+1&255;a[9540889]=d;a[9540898]=a[9540898]|1;a[9540900]=1;return};case 4:{if(d<<24>>24==0){return}d=c[2439330]|0;e=(d|0)==0;if(!e){g=d;gGC(9706056,g|0,76)|0}g=c[2438118]|0;c[2433530]=g;f=c[3528484]|0;c[2076596]=f;h=c[2417276]|0;c[3541536]=h;c[1836236]=0;gGz(9706056,0,76);if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=g;c[3528484]=f;c[2417276]=h;c[1836236]=-1;return};default:{return}}}else{return}}function e21(b){b=b|0;var d=0,e=0,f=0,g=0,h=0;d=b-4194304|0;if(d>>>0<16){switch(d>>>1^1|0){case 4:{e=a[9757532]|0;break};case 3:{e=a[14128913]|0;break};case 1:{e=a[14128921]|0;break};case 7:{e=a[14128914]|0;break};case 0:{e=a[14128920]|0;break};case 2:{e=a[14128912]|0;break};default:{e=-1}}f=e&255;return f|0}if(!((b|0)==4194328|(b|0)==4194330)){f=0;return f|0}e=(b-4194320|0)>>>1;b=c[3532186]>>5;if((b|0)>63){d=b|63488;g=d>>>8&65535;h=d&65535}else{g=b>>>8&65535;h=b&65535}if((e|0)==4){f=g;return f|0}else if((e|0)==5){f=h&255;return f|0}else{f=0;return f|0}return 0}function e22(b,d){b=b|0;d=d|0;var e=0,f=0;e=b-4194304|0;if(e>>>0>=16){f=b-10682368|0;if(f>>>0>=48){return}eXO(f>>>1,d);return}f=e>>>1^1;e=d&255;a[9757528+f|0]=e;if((f|0)==4){d=~e;a[14128520]=d&1;a[14128521]=d&2;return}else if((f|0)==0){c[3531956]=0;return}else{return}}function e23(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;e=b-6291456|0;if(e>>>0>=65536){return}b=e^1;f=(c[3532278]|0)+b|0;do{if((a[f]|0)!=d<<24>>24){g=(e|0)>-1;if((c[3532284]|0)==0){if(g&(b|0)<16384){a[14129208]=1}if(g&(b|0)<32768){a[14129128]=1}if((b-24576|0)>>>0>=4096){break}a[14129200]=1;break}else{if(g&(b|0)<32768){a[14129208]=1}if((b-32768|0)>>>0<32768){a[14129128]=1}if((b-69632|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);a[f]=d;return}function e24(a){a=a|0;var d=0;if((a|0)!=5242882){d=0;return d|0}d=b[(c[2442928]|0)+(c[2439392]<<1)>>1]|0;return d|0}function e25(d,e){d=d|0;e=e|0;var f=0,g=0;f=d-6291456|0;if(f>>>0<65536){g=(c[3532278]|0)+(f>>>1<<1)|0;do{if((b[g>>1]|0)!=e<<16>>16){if((c[3532284]|0)==0){if(f>>>0<16384){a[14129208]=1}if((d-6324224|0)>>>0<16384){a[14129128]=1}if((d-6316032|0)>>>0>=4096){break}a[14129200]=1;break}else{if(f>>>0<32768){a[14129208]=1}if((d-6324224|0)>>>0<32768){a[14129128]=1}if((d-6361088|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);b[g>>1]=e;return}g=d-6422528|0;if(g>>>0<16){f=g>>>1;b[14129152+(f<<1)>>1]=e;switch(f|0){case 0:{c[2388344]=-(e&65535);return};case 7:{c[2439396]=e&1;return};case 5:{c[3527494]=-(e&65535);return};case 4:{c[2385820]=-(e&65535);return};case 1:{c[2385826]=-(e&65535);return};case 3:{c[2388334]=-(e&65535);return};case 6:{c[3532284]=(e&65535)>>>4&1;return};case 2:{c[3527502]=-(e&65535);return};default:{return}}}if((d|0)==2097152){b[7064256]=e;if((e&1)!=0){return}f=c[2394]|0;g=c[14130368+(f<<2)>>2]|0;if((g|0)!=0){gGC(g|0,9104152,280)|0}c[8452240+(f<<2)>>2]=c[2113054];c[2394]=1;c[2112932]=c[3532597];f=c[3532593]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113061];RI();f=c[2394]|0;g=c[14130368+(f<<2)>>2]|0;if((g|0)!=0){gGC(g|0,9104152,280)|0}c[8452240+(f<<2)>>2]=c[2113054];c[2394]=0;c[2112932]=c[3532596];f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];return}else if((d|0)==5242880|(d|0)==5242882){f=(d-5242880|0)>>>1;if((f|0)==0){c[2439392]=e&4095;return}else if((f|0)==1){b[(c[2442928]|0)+(c[2439392]<<1)>>1]=e;c[(c[3532276]|0)+(c[2439392]<<2)>>2]=((e&65535)>>>10<<3&248)<<8|((e&255)<<3&255)>>>3|(((e&65535)>>>7&4|(e&65535)>>>5<<3&255)&255)<<3&2016;return}else{return}}else{return}}function e26(b){b=b|0;var c=0;L54566:do{if((b|0)==3145729){switch(d[9757560]|0|0){case 4:{c=a[9757556]|0;break L54566;break};case 1:{c=a[14129049]|0;break L54566;break};case 7:{c=a[14129042]|0;break L54566;break};case 3:{c=a[14129041]|0;break L54566;break};case 0:{c=a[14129048]|0;break L54566;break};case 2:{c=a[14129040]|0;break L54566;break};default:{c=0;break L54566}}}else{c=0}}while(0);return c|0}function e27(b,d){b=b|0;d=d|0;var e=0;if((b|0)!=3145729){return}b=a[9757560]|0;a[9757552+(b&255)|0]=d;if((b<<24>>24|0)==4){e=~d;a[14128520]=e&1;a[14128521]=e&2;return}else if((b<<24>>24|0)==0){c[3531956]=0;return}else{return}}function e28(b){b=b|0;var c=0,e=0,f=0;if((b|0)==3145728){switch(d[9757560]|0|0){case 7:{c=a[14129042]|0;break};case 3:{c=a[14129041]|0;break};case 0:{c=a[14129048]|0;break};case 1:{c=a[14129049]|0;break};case 2:{c=a[14129040]|0;break};case 4:{c=a[9757556]|0;break};default:{c=0}}e=c&255;return e|0}else if((b|0)==2097154){c=a[9540896]|0;switch(c&255|0){case 3:{a[9540898]=a[9540898]&-9;a[9540896]=c+1&255;f=a[9540895]|0;break};case 0:{a[9540896]=c+1&255;f=a[9540892]|0;break};case 4:{f=a[9540898]|0;break};case 2:{a[9540896]=c+1&255;f=a[9540894]|0;break};case 1:{a[9540898]=a[9540898]&-5;a[9540896]=c+1&255;f=a[9540893]|0;break};default:{f=0}}e=f&255;return e|0}else if((b|0)==3145730){e=d[9757560]|0;return e|0}else{e=0;return e|0}return 0}function e29(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;if((b|0)==2097154){e=d&15;f=a[9540896]|0;switch(f&255|0){case 0:{a[9540896]=f+1&255;a[9540888]=e;return};case 3:{a[9540896]=f+1&255;a[9540891]=e;a[9540898]=a[9540898]|2;a[9540900]=1;return};case 2:{a[9540896]=f+1&255;a[9540890]=e;return};case 4:{if(e<<24>>24==0){return}g=c[2439330]|0;h=(g|0)==0;if(!h){i=g;gGC(9706056,i|0,76)|0}i=c[2438118]|0;c[2433530]=i;j=c[3528484]|0;c[2076596]=j;k=c[2417276]|0;c[3541536]=k;c[1836236]=0;gGz(9706056,0,76);if(!h){h=g;gGC(h|0,9706056,76)|0}c[2438118]=i;c[3528484]=j;c[2417276]=k;c[1836236]=-1;return};case 1:{a[9540896]=f+1&255;a[9540889]=e;a[9540898]=a[9540898]|1;a[9540900]=1;return};default:{return}}}else if((b|0)==2097152){a[9540896]=d&15;return}else if((b|0)==3145728){e=a[9757560]|0;f=d&255;a[9757552+(e&255)|0]=f;if((e<<24>>24|0)==4){k=~f;a[14128520]=k&1;a[14128521]=k&2;return}else if((e<<24>>24|0)==0){c[3531956]=0;return}else{return}}else if((b|0)==3145730){a[9757560]=d&255;return}else{return}}function e3a(b){b=b|0;var d=0,e=0,f=0,g=0,h=0;d=b-4194304|0;L54647:do{if(d>>>0<16){switch(d>>>1&255|0){case 4:{e=a[9757556]|0;break L54647;break};case 2:{e=a[14129040]|0;break L54647;break};case 7:{e=a[14129042]|0;break L54647;break};case 3:{e=a[14129041]|0;break L54647;break};case 0:{e=a[14129048]|0;break L54647;break};case 1:{e=a[14129049]|0;break L54647;break};default:{e=0;break L54647}}}else{if(!((b|0)==14942209|(b|0)==14942211|(b|0)==14942213|(b|0)==14942215)){e=0;break}f=(b-14942208|0)>>>1;if((f|0)==1){g=127-((c[3532184]|0)>>>4)|0;h=(g&255|0)==0?1:g&255;e=a[4512944+(h<<24>>24==-1?99:((h&255)*100|0)>>>8)|0]|0;break}else if((f|0)==0){f=((c[3532186]|0)>>>4)+127|0;h=(f&255|0)==0?1:f&255;e=a[4512944+(h<<24>>24==-1?99:((h&255)*100|0)>>>8)|0]|0;break}else{e=-1;break}}}while(0);return e|0}function e3b(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;e=b-4194304|0;if(e>>>0<16){f=e>>>1;e=f&255;a[9757552+(f&255)|0]=d;if((e<<24>>24|0)==4){f=~d;a[14128520]=f&1;a[14128521]=f&2;return}else if((e<<24>>24|0)==0){c[3531956]=0;return}else{return}}e=b-12582912|0;if(e>>>0>=65536){return}b=e^1;f=(c[3532278]|0)+b|0;do{if((a[f]|0)!=d<<24>>24){g=(e|0)>-1;if((c[3532284]|0)==0){if(g&(b|0)<16384){a[14129208]=1}if(g&(b|0)<32768){a[14129128]=1}if((b-24576|0)>>>0>=4096){break}a[14129200]=1;break}else{if(g&(b|0)<32768){a[14129208]=1}if((b-32768|0)>>>0<32768){a[14129128]=1}if((b-69632|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);a[f]=d;return}function e3c(d){d=d|0;var e=0,f=0;if((d|0)==10485762){e=b[(c[2442928]|0)+(c[2439392]<<1)>>1]|0;return e|0}else if((d|0)==8519682){d=a[9540896]|0;switch(d&255|0){case 4:{f=a[9540898]|0;break};case 2:{a[9540896]=d+1&255;f=a[9540894]|0;break};case 3:{a[9540898]=a[9540898]&-9;a[9540896]=d+1&255;f=a[9540895]|0;break};case 0:{a[9540896]=d+1&255;f=a[9540892]|0;break};case 1:{a[9540898]=a[9540898]&-5;a[9540896]=d+1&255;f=a[9540893]|0;break};default:{f=0}}e=f&255;return e|0}else{e=0;return e|0}return 0}function e3d(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=d-4194304|0;if(f>>>0<16){g=f>>>1;f=g&255;h=e&255;a[9757552+(g&255)|0]=h;if((f<<24>>24|0)==4){g=~h;a[14128520]=g&1;a[14128521]=g&2;return}else if((f<<24>>24|0)==0){c[3531956]=0;return}else{return}}f=d-12582912|0;if(f>>>0<65536){g=(c[3532278]|0)+(f>>>1<<1)|0;do{if((b[g>>1]|0)!=e<<16>>16){if((c[3532284]|0)==0){if(f>>>0<16384){a[14129208]=1}if((d-12615680|0)>>>0<16384){a[14129128]=1}if((d-12607488|0)>>>0>=4096){break}a[14129200]=1;break}else{if(f>>>0<32768){a[14129208]=1}if((d-12615680|0)>>>0<32768){a[14129128]=1}if((d-12652544|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);b[g>>1]=e;return}g=d-12713984|0;if(g>>>0<16){f=g>>>1;b[14129152+(f<<1)>>1]=e;switch(f|0){case 2:{c[3527502]=-(e&65535);return};case 3:{c[2388334]=-(e&65535);return};case 6:{c[3532284]=(e&65535)>>>4&1;return};case 1:{c[2385826]=-(e&65535);return};case 7:{c[2439396]=e&1;return};case 5:{c[3527494]=-(e&65535);return};case 0:{c[2388344]=-(e&65535);return};case 4:{c[2385820]=-(e&65535);return};default:{return}}}if((d|0)==8519680){a[9540896]=e&15;return}else if((d|0)==8388608){b[7064256]=e;if((e&1)!=0){return}f=c[2394]|0;g=c[14130368+(f<<2)>>2]|0;if((g|0)!=0){gGC(g|0,9104152,280)|0}c[8452240+(f<<2)>>2]=c[2113054];c[2394]=1;c[2112932]=c[3532597];f=c[3532593]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113061];RI();f=c[2394]|0;g=c[14130368+(f<<2)>>2]|0;if((g|0)!=0){gGC(g|0,9104152,280)|0}c[8452240+(f<<2)>>2]=c[2113054];c[2394]=0;c[2112932]=c[3532596];f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];return}else if((d|0)==8519682){f=e&15;g=a[9540896]|0;switch(g&255|0){case 0:{a[9540896]=g+1&255;a[9540888]=f;return};case 1:{a[9540896]=g+1&255;a[9540889]=f;a[9540898]=a[9540898]|1;a[9540900]=1;return};case 3:{a[9540896]=g+1&255;a[9540891]=f;a[9540898]=a[9540898]|2;a[9540900]=1;return};case 4:{if(f<<24>>24==0){return}h=c[2439330]|0;i=(h|0)==0;if(!i){j=h;gGC(9706056,j|0,76)|0}j=c[2438118]|0;c[2433530]=j;k=c[3528484]|0;c[2076596]=k;l=c[2417276]|0;c[3541536]=l;c[1836236]=0;gGz(9706056,0,76);if(!i){i=h;gGC(i|0,9706056,76)|0}c[2438118]=j;c[3528484]=k;c[2417276]=l;c[1836236]=-1;return};case 2:{a[9540896]=g+1&255;a[9540890]=f;return};default:{return}}}else if((d|0)==10485760|(d|0)==10485762){f=(d-10485760|0)>>>1;if((f|0)==0){c[2439392]=e&4095;return}else if((f|0)==1){b[(c[2442928]|0)+(c[2439392]<<1)>>1]=e;c[(c[3532276]|0)+(c[2439392]<<2)>>2]=((e&65535)>>>10<<3&248)>>>3|((e&255)<<3&255)<<8|(((e&65535)>>>7&4|(e&65535)>>>5<<3&255)&255)<<3&2016;return}else{return}}else if((d|0)==14942222|(d|0)==14942220|(d|0)==14942218|(d|0)==14942208|(d|0)==14942210|(d|0)==14942212|(d|0)==14942214|(d|0)==14942216){c[2113056]=1e4;d=RG(1e4)|0;c[2113054]=(c[2113054]|0)+d;c[2276108]=-1;c[2113056]=-1;c[2113030]=(c[2113030]|0)+d;c[8452200+(c[2394]<<2)>>2]=8198;c[2276080]=1536;if((c[2276079]|0)>>>0>=1536){return}RH(6);return}else{return}}function e3e(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=b-3145728|0;L54821:do{if(d>>>0<16){switch(d>>>1^1|0){case 7:{e=a[14128914]|0;break L54821;break};case 3:{e=a[14128913]|0;break L54821;break};case 0:{e=a[14128920]|0;break L54821;break};case 4:{e=a[9757532]|0;break L54821;break};case 1:{e=a[14128921]|0;break L54821;break};case 2:{e=a[14128912]|0;break L54821;break};default:{e=-1;break L54821}}}else{if((b|0)==3145753|(b|0)==3145755){f=(b-3145744|0)>>>1;g=c[3532186]>>5;h=g>>>8;i=g&255;if((g|0)>63){j=(h|248)&255}else{j=h&255}if((f|0)==4){e=j;break}else if((f|0)==5){e=i;break}else{e=0;break}}else if((b|0)!=5373955){e=0;break}i=a[9540896]|0;switch(i&255|0){case 0:{a[9540896]=i+1&255;e=a[9540892]|0;break L54821;break};case 1:{a[9540898]=a[9540898]&-5;a[9540896]=i+1&255;e=a[9540893]|0;break L54821;break};case 2:{a[9540896]=i+1&255;e=a[9540894]|0;break L54821;break};case 3:{a[9540898]=a[9540898]&-9;a[9540896]=i+1&255;e=a[9540895]|0;break L54821;break};case 4:{e=a[9540898]|0;break L54821;break};default:{e=0;break L54821}}}}while(0);return e|0}function e3f(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=d-3145728|0;if(f>>>0<16){g=f>>>1^1;a[9757528+g|0]=e;if((g|0)==0){c[3531956]=0;return}else if((g|0)==4){g=~e;a[14128520]=g&1;a[14128521]=g&2;return}else{return}}if((d|0)==5373953){a[9540896]=e&15;return}else if((d|0)==5373955){g=e&15;f=a[9540896]|0;switch(f&255|0){case 2:{a[9540896]=f+1&255;a[9540890]=g;return};case 1:{a[9540896]=f+1&255;a[9540889]=g;a[9540898]=a[9540898]|1;a[9540900]=1;return};case 0:{a[9540896]=f+1&255;a[9540888]=g;return};case 3:{a[9540896]=f+1&255;a[9540891]=g;a[9540898]=a[9540898]|2;a[9540900]=1;return};case 4:{if(g<<24>>24==0){return}g=c[2439330]|0;f=(g|0)==0;if(!f){h=g;gGC(9706056,h|0,76)|0}h=c[2438118]|0;c[2433530]=h;i=c[3528484]|0;c[2076596]=i;j=c[2417276]|0;c[3541536]=j;c[1836236]=0;gGz(9706056,0,76);if(!f){f=g;gGC(f|0,9706056,76)|0}c[2438118]=h;c[3528484]=i;c[2417276]=j;c[1836236]=-1;return};default:{return}}}else if((d|0)==11567104){c[2438578]=e&255;return}else if((d|0)==5242882){d=e&255;b[7064256]=d;if((d&1)!=0){return}d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=1;c[2112932]=c[3532597];d=c[3532593]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113061];RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];return}else{return}}function e3g(a){a=a|0;return 0}function e3h(b,d){b=b|0;d=d|0;var e=0,f=0;e=b-3145728|0;if(e>>>0>=16){f=b-9633792|0;if(f>>>0>=48){return}eXO(f>>>1,d);return}f=e>>>1^1;e=d&255;a[9757528+f|0]=e;if((f|0)==0){c[3531956]=0;return}else if((f|0)==4){f=~e;a[14128520]=f&1;a[14128521]=f&2;return}else{return}}function e3i(b){b=b|0;var d=0,e=0,f=0,g=0,h=0;d=b-2097152|0;L54918:do{if(d>>>0<16){switch(d>>>1&255|0){case 1:{e=a[14129049]|0;break L54918;break};case 0:{e=a[14129048]|0;break L54918;break};case 3:{e=a[14129041]|0;break L54918;break};case 2:{e=a[14129040]|0;break L54918;break};case 7:{e=a[14129042]|0;break L54918;break};case 4:{e=a[9757556]|0;break L54918;break};default:{e=0;break L54918}}}else{if(!((b|0)==2097177|(b|0)==2097179)){e=0;break}f=(b-2097168|0)>>>1;g=c[3532186]>>4;h=(g-96|0)>>>0<32?95:g;g=(h-3969|0)>>>0<31?4e3:h;h=(c[2405756]|0)<(g|0)&(g|0)>4032?0:g;c[2405756]=h;if((f|0)==4){e=h&255;break}else if((f|0)==5){e=h>>>8&255;break}else{e=-1;break}}}while(0);return e|0}function e3j(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=d-2097152|0;if(f>>>0<16){g=f>>>1;f=g&255;a[9757552+(g&255)|0]=e;if((f<<24>>24|0)==0){c[3531956]=0;return}else if((f<<24>>24|0)==4){f=~e;a[14128520]=f&1;a[14128521]=f&2;return}else{return}}f=d-10485760|0;if(f>>>0<65536){g=f^1;h=(c[3532278]|0)+g|0;do{if((a[h]|0)!=e<<24>>24){i=(f|0)>-1;if((c[3532284]|0)==0){if(i&(g|0)<16384){a[14129208]=1}if(i&(g|0)<32768){a[14129128]=1}if((g-24576|0)>>>0>=4096){break}a[14129200]=1;break}else{if(i&(g|0)<32768){a[14129208]=1}if((g-32768|0)>>>0<32768){a[14129128]=1}if((g-69632|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);a[h]=e;return}if((d|0)==4325377){a[9540896]=e&15;return}else if((d|0)==4194305){h=e&255;b[7064256]=h;if((h&1)!=0){return}h=c[2394]|0;g=c[14130368+(h<<2)>>2]|0;if((g|0)!=0){gGC(g|0,9104152,280)|0}c[8452240+(h<<2)>>2]=c[2113054];c[2394]=1;c[2112932]=c[3532597];h=c[3532593]|0;if((h|0)!=0){gGC(9104152,h|0,280)|0}c[2113054]=c[2113061];RI();h=c[2394]|0;g=c[14130368+(h<<2)>>2]|0;if((g|0)!=0){gGC(g|0,9104152,280)|0}c[8452240+(h<<2)>>2]=c[2113054];c[2394]=0;c[2112932]=c[3532596];h=c[3532592]|0;if((h|0)!=0){gGC(9104152,h|0,280)|0}c[2113054]=c[2113060];return}else if((d|0)==4325379){h=e&15;g=a[9540896]|0;switch(g&255|0){case 1:{a[9540896]=g+1&255;a[9540889]=h;a[9540898]=a[9540898]|1;a[9540900]=1;return};case 2:{a[9540896]=g+1&255;a[9540890]=h;return};case 3:{a[9540896]=g+1&255;a[9540891]=h;a[9540898]=a[9540898]|2;a[9540900]=1;return};case 4:{if(h<<24>>24==0){return}f=c[2439330]|0;i=(f|0)==0;if(!i){j=f;gGC(9706056,j|0,76)|0}j=c[2438118]|0;c[2433530]=j;k=c[3528484]|0;c[2076596]=k;l=c[2417276]|0;c[3541536]=l;c[1836236]=0;gGz(9706056,0,76);if(!i){i=f;gGC(i|0,9706056,76)|0}c[2438118]=j;c[3528484]=k;c[2417276]=l;c[1836236]=-1;return};case 0:{a[9540896]=g+1&255;a[9540888]=h;return};default:{return}}}else if((d|0)==12615680){c[2438578]=e&255;return}else{return}}function e3k(d,e){d=d|0;e=e|0;var f=0,g=0;f=d-10485760|0;if(f>>>0<65536){g=(c[3532278]|0)+(f>>>1<<1)|0;do{if((b[g>>1]|0)!=e<<16>>16){if((c[3532284]|0)==0){if(f>>>0<16384){a[14129208]=1}if((d-10518528|0)>>>0<16384){a[14129128]=1}if((d-10510336|0)>>>0>=4096){break}a[14129200]=1;break}else{if(f>>>0<32768){a[14129208]=1}if((d-10518528|0)>>>0<32768){a[14129128]=1}if((d-10555392|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);b[g>>1]=e;return}g=d-10616832|0;if(g>>>0>=16){return}d=g>>>1;b[14129152+(d<<1)>>1]=e;switch(d|0){case 0:{c[2388344]=-(e&65535);return};case 1:{c[2385826]=-(e&65535);return};case 2:{c[3527502]=-(e&65535);return};case 3:{c[2388334]=-(e&65535);return};case 4:{c[2385820]=-(e&65535);return};case 5:{c[3527494]=-(e&65535);return};case 6:{c[3532284]=(e&65535)>>>4&1;return};case 7:{c[2439396]=e&1;return};default:{return}}}function e3l(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;e=b-9437184|0;if(e>>>0>=65536){return}b=e^1;f=(c[3532278]|0)+b|0;do{if((a[f]|0)!=d<<24>>24){g=(e|0)>-1;if((c[3532284]|0)==0){if(g&(b|0)<16384){a[14129208]=1}if(g&(b|0)<32768){a[14129128]=1}if((b-24576|0)>>>0>=4096){break}a[14129200]=1;break}else{if(g&(b|0)<32768){a[14129208]=1}if((b-32768|0)>>>0<32768){a[14129128]=1}if((b-69632|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);a[f]=d;return}function e3m(a){a=a|0;var d=0;if((a|0)!=11534338){d=0;return d|0}d=b[(c[2442928]|0)+(c[2439392]<<1)>>1]|0;return d|0}function e3n(d,e){d=d|0;e=e|0;var f=0,g=0;f=d-9437184|0;if(f>>>0<65536){g=(c[3532278]|0)+(f>>>1<<1)|0;do{if((b[g>>1]|0)!=e<<16>>16){if((c[3532284]|0)==0){if(f>>>0<16384){a[14129208]=1}if((d-9469952|0)>>>0<16384){a[14129128]=1}if((d-9461760|0)>>>0>=4096){break}a[14129200]=1;break}else{if(f>>>0<32768){a[14129208]=1}if((d-9469952|0)>>>0<32768){a[14129128]=1}if((d-9506816|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);b[g>>1]=e;return}g=d-9568256|0;if(g>>>0>=16){if(!((d|0)==11534336|(d|0)==11534338)){return}f=(d-11534336|0)>>>1;if((f|0)==1){b[(c[2442928]|0)+(c[2439392]<<1)>>1]=e;c[(c[3532276]|0)+(c[2439392]<<2)>>2]=((e&65535)>>>10<<3&248)<<8|((e&255)<<3&255)>>>3|(((e&65535)>>>7&4|(e&65535)>>>5<<3&255)&255)<<3&2016;return}else if((f|0)==0){c[2439392]=e&4095;return}else{return}}f=g>>>1;b[14129152+(f<<1)>>1]=e;switch(f|0){case 6:{c[3532284]=(e&65535)>>>4&1;return};case 1:{c[2385826]=-(e&65535);return};case 0:{c[2388344]=-(e&65535);return};case 3:{c[2388334]=-(e&65535);return};case 5:{c[3527494]=-(e&65535);return};case 7:{c[2439396]=e&1;return};case 2:{c[3527502]=-(e&65535);return};case 4:{c[2385820]=-(e&65535);return};default:{return}}}function e3o(a){a=a|0;var b=0;if((a|0)==15728643){b=~~(+((c[3542192]>>8)+8|0)/+(c[2440574]|0)*255.0);return b|0}else if((a|0)==15728645){b=~~(+((c[3542197]>>8)+8|0)/+(c[2440576]|0)*255.0)^-1;return b|0}else if((a|0)==15728641){b=~~(+((c[3542196]>>8)+8|0)/+(c[2440576]|0)*255.0)^-1;return b|0}else if((a|0)==15728647){b=~~(+((c[3542193]>>8)+8|0)/+(c[2440574]|0)*255.0);return b|0}else{b=0;return b|0}return 0}function e3p(b,c){b=b|0;c=c|0;if((b|0)!=8388616){return}a[9757556]=c;b=~c;a[14128520]=b&1;a[14128521]=b&2;return}function e3q(b){b=b|0;var d=0,e=0,f=0.0,g=0.0,i=0,j=0,k=0,l=0;if((b|0)==12582912){d=c[3541514]|0;e=d+552|0;f=+h[e>>3];do{if(f!=0.0){g=+h[6675];if(f-(g+ +gC[c[2429842]&255]())>0.0){i=a[d+563|0]|-128;break}else{h[e>>3]=0.0;j=42123;break}}else{j=42123}}while(0);if((j|0)==42123){i=a[d+563|0]|0}k=i&-125&255;return k|0}else if((b|0)==8388608|(b|0)==8388610|(b|0)==8388612|(b|0)==8388614|(b|0)==8388616|(b|0)==8388618|(b|0)==8388620|(b|0)==8388622){i=(b-8388608|0)>>>1;L55172:do{if((i|0)==3){if((c[2406632]|0)!=0){l=(c[2432962]|0)>>>((c[(c[2420380]|0)+4>>2]|0)>>>0)<<7&255;break}b=c[2443744]|0;if((b|0)<=0){l=-128;break}c[2443744]=b-1;l=0}else{switch(i&255|0){case 7:{l=a[14129042]|0;break L55172;break};case 4:{l=a[9757556]|0;break L55172;break};case 3:{l=a[14129041]|0;break L55172;break};case 1:{l=a[14129049]|0;break L55172;break};case 0:{l=a[14129048]|0;break L55172;break};case 2:{l=a[14129040]|0;break L55172;break};default:{l=0;break L55172}}}}while(0);k=l&255;return k|0}else{k=0;return k|0}return 0}function e3r(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;if((b|0)==8388608|(b|0)==8388610|(b|0)==8388612|(b|0)==8388614|(b|0)==8388616|(b|0)==8388618|(b|0)==8388620|(b|0)==8388622){e=(b-8388608|0)>>>1;if((e|0)==3){f=d&65535;c[2415256]=f&64;g=f>>>4&1;c[3528406]=g^1;if((g|0)==0){c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2]}Tr(f>>>5&1);return}f=e&255;g=d&255;a[9757552+(e&255)|0]=g;if((f<<24>>24|0)==0){c[3531956]=0;return}else if((f<<24>>24|0)==4){f=~g;a[14128520]=f&1;a[14128521]=f&2;return}else{return}}else if((b|0)==12582918){l7(3,d&255);return}else if((b|0)==12582914){l7(1,d&255);return}else if((b|0)==15728646|(b|0)==15728644|(b|0)==15728642|(b|0)==15728640){c[2113056]=1e4;f=RG(1e4)|0;c[2113054]=(c[2113054]|0)+f;c[2276108]=-1;c[2113056]=-1;c[2113031]=(c[2113031]|0)+f;c[8452200+(c[2394]<<2)>>2]=8197;c[2276080]=1280;if((c[2276079]|0)>>>0>=1280){return}RH(5);return}else if((b|0)==12582912){f=d&255;g=c[3541514]|0;a[g+560|0]=f;a[g+20408|0]=0;if((f&255)>=16){return}c[14168912+((c[2383582]|0)*252|0)>>2]=d&15;return}else if((b|0)==12582916){b=c[3541514]|0;a[b+560|0]=d&255;a[b+20408|0]=1;return}else{return}}function e3s(b){b=b|0;var d=0,e=0,f=0,g=0,i=0,j=0,k=0.0,l=0.0,m=0,n=0;d=b&65535;if((d|0)==57345){b=a[(c[3541514]|0)+560|0]|0;do{if((b&255)<16){e=c[2383582]|0;f=c[14168912+(e*252|0)>>2]|0;if((f|0)>15){g=0;break}do{if((f|0)==15){i=c[14168900+(e*252|0)>>2]|0;if((i|0)==0){break}a[14168931+(e*252|0)|0]=gj[i&4095](0)|0}else if((f|0)==14){i=c[14168896+(e*252|0)>>2]|0;if((i|0)==0){break}a[14168930+(e*252|0)|0]=gj[i&4095](0)|0}}while(0);g=a[14168916+(e*252|0)+f|0]|0}else{g=0}}while(0);j=b<<24>>24==-1?1:g;return j|0}else if((d|0)==57857){j=fdZ()|0;return j|0}else if((d|0)==57346){j=a[(c[3541514]|0)+20904|0]|0;return j|0}else if((d|0)==57344){d=c[3541514]|0;g=d+552|0;k=+h[g>>3];do{if(k!=0.0){l=+h[6675];if(k-(l+ +gC[c[2429842]&255]())>0.0){m=a[d+563|0]|-128;break}else{h[g>>3]=0.0;n=42162;break}}else{n=42162}}while(0);if((n|0)==42162){m=a[d+563|0]|0}j=m&-125;return j|0}else{j=0;return j|0}return 0}function e3t(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,i=0,j=0,k=0,l=0;switch(b&65535|0){case 57344:{b=c[3541514]|0;a[b+560|0]=d;a[b+20408|0]=0;if((d&255)>=16){return}c[14168912+((c[2383582]|0)*252|0)>>2]=d&15;return};case 57345:{l7(1,d);return};case 58370:{h[118355]=+(d&255|0)*+h[85208]/255.0;return};case 57347:{l7(3,d);return};case 58371:{h[146570]=+(d&255|0)*+h[85208]/255.0;return};case 57856:{a[9540897]=d&15;return};case 58369:{h[146571]=+(d&255|0)*+h[85208]/255.0;return};case 57346:{b=c[3541514]|0;a[b+560|0]=d;a[b+20408|0]=1;return};case 61952:{b=d+7&7;a[14127752]=b;e=c[3531932]|0;f=(b&255)<<14;b=c[9757320+(c[1836236]<<2)>>2]|0;g=64;i=64;while(1){c[b+76+(i<<2)>>2]=e+((i<<8)+f);j=g+1&65535;if((j&65535)>127){k=64;l=64;break}else{g=j;i=j&65535}}while(1){i=e+((l<<8)+f)|0;c[b+76+(l+512<<2)>>2]=i;c[b+76+(l+768<<2)>>2]=i;i=k+1&65535;if((i&65535)>127){break}else{k=i;l=i&65535}}return};case 57857:{fd_(d);return};case 58368:{h[118356]=+(d&255|0)*+h[85208]/255.0;return};default:{return}}}function e3u(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4277628+(b*112|0)>>2];c[a+104>>2]=c[4277632+(b*112|0)>>2];c[a+108>>2]=c[4277636+(b*112|0)>>2];d=0;return d|0}function e3v(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=4277528+(b*112|0);e=0;return e|0}function e3w(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1315528+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function e3x(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>35){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4279320+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e3y(){var b=0,d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;c[3532162]=256;c[3532160]=4;c[3532142]=8;c[3532164]=8;c[3532148]=1983640;c[3532140]=6964216;c[3532138]=6963960;c[3532042]=16384;c[3532002]=512;c[3532e3]=4;a[7460944]=1;c[3532004]=8;c[3531998]=961392;c[3531992]=4969496;c[3531990]=961552;c[3532034]=32768;c[3532044]=2;c[3532030]=1;a[7460960]=1;eZ9(0)|0;c[3532204]=0;b=c[3532200]|0;c[3532198]=b;d=(c[3532194]|0)+b|0;c[3531932]=d;e=d+(c[3531928]|0)|0;c[3531976]=e;f=e+(c[3531972]|0)|0;c[3531952]=f;g=f+(c[3531948]|0)|0;c[3531946]=g;i=g+(c[3531942]|0)|0;j=i|0;c[3532020]=j;c[3532208]=j;j=i+65536|0;c[3532206]=j;k=i+98304|0;c[3532008]=k;l=i+163840|0;c[3531936]=l;m=i+172032|0;c[3531970]=m;n=i+188416|0;c[3532026]=n;o=i+196608|0;p=o|0;c[3532022]=p;c[3532136]=p;p=ag(c[3532142]|0,c[3532042]|0)|0;q=(ag(p,c[3532164]|0)|0)+o|0;c[3531962]=q;p=ag(a[7460944]|0?16:0,c[3532034]|0)|0;r=(ag(p,c[3532004]|0)|0)+q|0;c[3531960]=r;p=ag(a[7460912]|0?16:0,a[7460976]|0?16384:0)|0;s=(ag(p,a[7460936]|0?16:0)|0)+r|0;c[3532028]=s;p=s+16384|0;t=p|0;c[3532046]=t;u=t;t=gGq(u)|0;c[3532048]=t;if((t|0)==0){v=1;return v|0}gGz(t|0,0,u|0);c[3532204]=t;c[3532198]=t+b;c[3531932]=t+d;c[3531976]=t+e;c[3531952]=t+f;c[3531946]=t+g;g=t+i|0;c[3532020]=g;c[3532208]=g;c[3532206]=t+j;c[3532008]=t+k;c[3531936]=t+l;c[3531970]=t+m;c[3532026]=t+n;n=t+o|0;c[3532022]=n;c[3532136]=n;c[3531962]=t+q;c[3531960]=t+r;c[3532028]=t+s;c[3532046]=t+p;p=c[642608+(c[2436]<<2)>>2]|0;t=c[p+128>>2]|0;if((c[p+52>>2]&4|0)==0){c[2113068]=t;s=c[p+132>>2]|0;c[2113070]=s;c[2443814]=t;c[2440436]=s;w=t;x=s}else{c[2113070]=t;s=c[p+132>>2]|0;c[2113068]=s;c[2440436]=t;c[2443814]=s;w=s;x=t}t=ag(w<<1,x)|0;x=gGq(t)|0;c[2112926]=x;if((x|0)!=0){gGz(x|0,0,t|0)}eX5(0,c[3532042]|0,0,8,0,0);t=0;while(1){if((t|0)>=1024){y=0;break}z=9638528+(t<<2)|0;if((c[z>>2]|0)==0){A=42245;break}else{t=t+1|0}}do{if((A|0)==42245){t=gGq(16384)|0;c[z>>2]=t;if((t|0)==0){y=0;break}gGz(t|0,0,16384);y=t}}while(0);c[2442928]=y;gGz(y|0,0,16384);y=0;while(1){if((y|0)>=1024){B=0;break}C=9638528+(y<<2)|0;if((c[C>>2]|0)==0){A=42250;break}else{y=y+1|0}}do{if((A|0)==42250){y=gGq(16384)|0;c[C>>2]=y;if((y|0)==0){B=0;break}gGz(y|0,0,16384);B=y}}while(0);c[3532276]=B;gGz(B|0,0,4096);c[3532274]=4096;a[7461088]=1;B=c[3532010]|0;C=0;while(1){if((C|0)>=1024){D=0;break}E=9638528+(C<<2)|0;if((c[E>>2]|0)==0){A=42255;break}else{C=C+1|0}}do{if((A|0)==42255){C=gGq(B)|0;c[E>>2]=C;if((C|0)==0){D=0;break}gGz(C|0,0,B|0);D=C}}while(0);c[3532270]=D;gGz(D|0,0,B|0);B=0;while(1){if((B|0)>=1024){F=0;break}G=9638528+(B<<2)|0;if((c[G>>2]|0)==0){A=42260;break}else{B=B+1|0}}do{if((A|0)==42260){B=gGq(8192)|0;c[G>>2]=B;if((B|0)==0){F=0;break}gGz(B|0,0,8192);F=B}}while(0);c[3532272]=F;gGz(F|0,0,8192);a[725176]=0;a[7461072]=1;a[7461080]=1;a[7461056]=1;if((eZ9(1)|0)!=0){v=1;return v|0}fxU(0,425984);if((c[2394]|0)==0){H=c[2112932]|0}else{c[2394]=0;F=c[3532596]|0;c[2112932]=F;G=c[3532592]|0;if((G|0)!=0){gGC(9104152,G|0,280)|0}c[2113054]=c[2113060];H=F}F=c[3532204]|0;G=H|0;A=0;while(1){B=F+A|0;c[G>>2]=B;c[G+131072>>2]=B;B=A+1024|0;if(B>>>0>262143){break}else{G=G+4|0;A=B}}A=c[3532208]|0;c[H+4096>>2]=A;c[H+69632>>2]=A;c[H+135168>>2]=A;G=A+1024|0;c[H+4100>>2]=G;c[H+69636>>2]=G;c[H+135172>>2]=G;G=A+2048|0;c[H+4104>>2]=G;c[H+69640>>2]=G;c[H+135176>>2]=G;G=A+3072|0;c[H+4108>>2]=G;c[H+69644>>2]=G;c[H+135180>>2]=G;G=A+4096|0;c[H+4112>>2]=G;c[H+69648>>2]=G;c[H+135184>>2]=G;G=A+5120|0;c[H+4116>>2]=G;c[H+69652>>2]=G;c[H+135188>>2]=G;G=A+6144|0;c[H+4120>>2]=G;c[H+69656>>2]=G;c[H+135192>>2]=G;G=A+7168|0;c[H+4124>>2]=G;c[H+69660>>2]=G;c[H+135196>>2]=G;G=A+8192|0;c[H+4128>>2]=G;c[H+69664>>2]=G;c[H+135200>>2]=G;G=A+9216|0;c[H+4132>>2]=G;c[H+69668>>2]=G;c[H+135204>>2]=G;G=A+10240|0;c[H+4136>>2]=G;c[H+69672>>2]=G;c[H+135208>>2]=G;G=A+11264|0;c[H+4140>>2]=G;c[H+69676>>2]=G;c[H+135212>>2]=G;G=A+12288|0;c[H+4144>>2]=G;c[H+69680>>2]=G;c[H+135216>>2]=G;G=A+13312|0;c[H+4148>>2]=G;c[H+69684>>2]=G;c[H+135220>>2]=G;G=A+14336|0;c[H+4152>>2]=G;c[H+69688>>2]=G;c[H+135224>>2]=G;G=A+15360|0;c[H+4156>>2]=G;c[H+69692>>2]=G;c[H+135228>>2]=G;G=c[3532008]|0;c[H+4160>>2]=G;c[H+69696>>2]=G;c[H+135232>>2]=G;A=G+1024|0;c[H+4164>>2]=A;c[H+69700>>2]=A;c[H+135236>>2]=A;A=G+2048|0;c[H+4168>>2]=A;c[H+69704>>2]=A;c[H+135240>>2]=A;A=G+3072|0;c[H+4172>>2]=A;c[H+69708>>2]=A;c[H+135244>>2]=A;A=G+4096|0;c[H+4176>>2]=A;c[H+69712>>2]=A;c[H+135248>>2]=A;A=G+5120|0;c[H+4180>>2]=A;c[H+69716>>2]=A;c[H+135252>>2]=A;A=G+6144|0;c[H+4184>>2]=A;c[H+69720>>2]=A;c[H+135256>>2]=A;A=G+7168|0;c[H+4188>>2]=A;c[H+69724>>2]=A;c[H+135260>>2]=A;A=G+8192|0;c[H+4192>>2]=A;c[H+69728>>2]=A;c[H+135264>>2]=A;A=G+9216|0;c[H+4196>>2]=A;c[H+69732>>2]=A;c[H+135268>>2]=A;A=G+10240|0;c[H+4200>>2]=A;c[H+69736>>2]=A;c[H+135272>>2]=A;A=G+11264|0;c[H+4204>>2]=A;c[H+69740>>2]=A;c[H+135276>>2]=A;A=G+12288|0;c[H+4208>>2]=A;c[H+69744>>2]=A;c[H+135280>>2]=A;A=G+13312|0;c[H+4212>>2]=A;c[H+69748>>2]=A;c[H+135284>>2]=A;A=G+14336|0;c[H+4216>>2]=A;c[H+69752>>2]=A;c[H+135288>>2]=A;A=G+15360|0;c[H+4220>>2]=A;c[H+69756>>2]=A;c[H+135292>>2]=A;A=c[3532272]|0;c[H+32768>>2]=A;c[H+98304>>2]=A;c[H+163840>>2]=A;G=A+1024|0;c[H+32772>>2]=G;c[H+98308>>2]=G;c[H+163844>>2]=G;G=A+2048|0;c[H+32776>>2]=G;c[H+98312>>2]=G;c[H+163848>>2]=G;G=A+3072|0;c[H+32780>>2]=G;c[H+98316>>2]=G;c[H+163852>>2]=G;G=A+4096|0;c[H+32784>>2]=G;c[H+98320>>2]=G;c[H+163856>>2]=G;G=A+5120|0;c[H+32788>>2]=G;c[H+98324>>2]=G;c[H+163860>>2]=G;G=A+6144|0;c[H+32792>>2]=G;c[H+98328>>2]=G;c[H+163864>>2]=G;G=A+7168|0;c[H+32796>>2]=G;c[H+98332>>2]=G;c[H+163868>>2]=G;G=c[3532278]|0;A=H+40960|0;F=10485760;while(1){c[A>>2]=G+(F-10485760);B=F+1024|0;if(B>>>0>10551295){break}else{A=A+4|0;F=B}}F=c[3531970]|0;c[H+50176>>2]=F;c[H+115712>>2]=F;c[H+181248>>2]=F;c[H+196648>>2]=3108;c[H+196728>>2]=2264;H=c[3532592]|0;if((H|0)!=0){gGC(H|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fxU(1,425984);if((c[2394]|0)==1){I=c[2112932]|0}else{c[2394]=1;H=c[3532597]|0;c[2112932]=H;F=c[3532593]|0;if((F|0)!=0){gGC(9104152,F|0,280)|0}c[2113054]=c[2113061];I=H}H=c[3532198]|0;F=I|0;A=0;while(1){G=H+A|0;c[F>>2]=G;c[F+131072>>2]=G;G=A+1024|0;if(G>>>0>262143){break}else{F=F+4|0;A=G}}A=c[3532206]|0;c[I+4096>>2]=A;c[I+69632>>2]=A;c[I+135168>>2]=A;F=A+1024|0;c[I+4100>>2]=F;c[I+69636>>2]=F;c[I+135172>>2]=F;F=A+2048|0;c[I+4104>>2]=F;c[I+69640>>2]=F;c[I+135176>>2]=F;F=A+3072|0;c[I+4108>>2]=F;c[I+69644>>2]=F;c[I+135180>>2]=F;F=A+4096|0;c[I+4112>>2]=F;c[I+69648>>2]=F;c[I+135184>>2]=F;F=A+5120|0;c[I+4116>>2]=F;c[I+69652>>2]=F;c[I+135188>>2]=F;F=A+6144|0;c[I+4120>>2]=F;c[I+69656>>2]=F;c[I+135192>>2]=F;F=A+7168|0;c[I+4124>>2]=F;c[I+69660>>2]=F;c[I+135196>>2]=F;F=A+8192|0;c[I+4128>>2]=F;c[I+69664>>2]=F;c[I+135200>>2]=F;F=A+9216|0;c[I+4132>>2]=F;c[I+69668>>2]=F;c[I+135204>>2]=F;F=A+10240|0;c[I+4136>>2]=F;c[I+69672>>2]=F;c[I+135208>>2]=F;F=A+11264|0;c[I+4140>>2]=F;c[I+69676>>2]=F;c[I+135212>>2]=F;F=A+12288|0;c[I+4144>>2]=F;c[I+69680>>2]=F;c[I+135216>>2]=F;F=A+13312|0;c[I+4148>>2]=F;c[I+69684>>2]=F;c[I+135220>>2]=F;F=A+14336|0;c[I+4152>>2]=F;c[I+69688>>2]=F;c[I+135224>>2]=F;F=A+15360|0;c[I+4156>>2]=F;c[I+69692>>2]=F;c[I+135228>>2]=F;F=c[3532008]|0;c[I+4160>>2]=F;c[I+69696>>2]=F;c[I+135232>>2]=F;A=F+1024|0;c[I+4164>>2]=A;c[I+69700>>2]=A;c[I+135236>>2]=A;A=F+2048|0;c[I+4168>>2]=A;c[I+69704>>2]=A;c[I+135240>>2]=A;A=F+3072|0;c[I+4172>>2]=A;c[I+69708>>2]=A;c[I+135244>>2]=A;A=F+4096|0;c[I+4176>>2]=A;c[I+69712>>2]=A;c[I+135248>>2]=A;A=F+5120|0;c[I+4180>>2]=A;c[I+69716>>2]=A;c[I+135252>>2]=A;A=F+6144|0;c[I+4184>>2]=A;c[I+69720>>2]=A;c[I+135256>>2]=A;A=F+7168|0;c[I+4188>>2]=A;c[I+69724>>2]=A;c[I+135260>>2]=A;A=F+8192|0;c[I+4192>>2]=A;c[I+69728>>2]=A;c[I+135264>>2]=A;A=F+9216|0;c[I+4196>>2]=A;c[I+69732>>2]=A;c[I+135268>>2]=A;A=F+10240|0;c[I+4200>>2]=A;c[I+69736>>2]=A;c[I+135272>>2]=A;A=F+11264|0;c[I+4204>>2]=A;c[I+69740>>2]=A;c[I+135276>>2]=A;A=F+12288|0;c[I+4208>>2]=A;c[I+69744>>2]=A;c[I+135280>>2]=A;A=F+13312|0;c[I+4212>>2]=A;c[I+69748>>2]=A;c[I+135284>>2]=A;A=F+14336|0;c[I+4216>>2]=A;c[I+69752>>2]=A;c[I+135288>>2]=A;A=F+15360|0;c[I+4220>>2]=A;c[I+69756>>2]=A;c[I+135292>>2]=A;c[I+196688>>2]=800;c[I+196728>>2]=1938;c[I+196608>>2]=2236;I=c[3532593]|0;if((I|0)!=0){gGC(I|0,9104152,280)|0}c[2113061]=c[2113054];c[2394]=-1;e5g();TW(c[3531952]|0,14127792,c[3531946]|0,14127768,3028,908,12);c[2438228]=4e6;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=511;h[146569]=.25;h[118354]=.25;h[85208]=2.0;a[64232]=1;c[3532050]=12274;c[3532118]=6644;c[3532064]=4;c[3532082]=500;c[2113026]=2e5;c[2113024]=2e5;c[2113022]=66666;eZ8()|0;c[2438578]=0;c[2405756]=0;v=0;return v|0}function e3z(){e_a()|0;c[2438578]=0;c[2405756]=0;a[681304]=0;return 0}function e3A(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=c[3532082]|0;if((a[14128072]|0)!=0){eZ8()|0;c[2438578]=0;c[2405756]=0}gu[c[3532050]&16383]();c[2113032]=0;c[2113031]=0;c[2113030]=0;e=c[2392]|0;if((e|0)>=0){gGz(8452240,0,((e|0)>0?(e<<2)+4|0:4)|0)}c[2113054]=0;e=c[3532030]|0;if((e|0)!=0){f=c[2385548]|0;if((f|0)>0){gGz(9752472,0,((f|0)>1?f<<2:4)|0)}c[2433530]=0}if((d|0)>0){f=0;while(1){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060]}g=f+1|0;h=(ag(c[2113026]|0,g)|0)/(d|0)|0;i=h-(c[2113030]|0)|0;c[2113028]=i;c[2113056]=i;h=RG(i)|0;c[2113054]=(c[2113054]|0)+h;c[2276108]=-1;c[2113056]=-1;c[2113030]=(c[2113030]|0)+h;do{if((f|0)==10&a[681304]){if((c[2113222]&1|0)!=0){break}c[8452200+(c[2394]<<2)>>2]=8198;c[2276080]=1536;if((c[2276079]|0)>>>0>=1536){break}RH(6)}}while(0);do{if((f|0)==((c[3532082]|0)-1|0)){h=c[3532064]|0;c[8452200+(c[2394]<<2)>>2]=h|8192;i=c[2276080]|0;j=h<<8;c[2276080]=j;if((i|0)!=1792&(j|0)==1792){RH(7);break}if(j>>>0<=(c[2276079]|0)>>>0){break}RH(h&16777215)}}while(0);h=c[2394]|0;j=c[14130368+(h<<2)>>2]|0;if((j|0)!=0){gGC(j|0,9104152,280)|0}c[8452240+(h<<2)>>2]=c[2113054];c[2394]=-1;h=c[3532030]|0;if((b[7064256]&1)!=0&(h|0)!=0){c[2394]=1;c[2112932]=c[3532597];j=c[3532593]|0;if((j|0)!=0){gGC(9104152,j|0,280)|0}c[2113054]=c[2113061];j=(ag(c[2113024]|0,g)|0)/(d|0)|0;i=j-(c[2113031]|0)|0;c[2113028]=i;c[2113056]=i;j=RG(i)|0;c[2113054]=(c[2113054]|0)+j;c[2276108]=-1;c[2113056]=-1;c[2113031]=(c[2113031]|0)+j;do{if((f|0)==((c[3532082]|0)-1|0)){j=c[3532064]|0;c[8452200+(c[2394]<<2)>>2]=j|8192;i=c[2276080]|0;k=j<<8;c[2276080]=k;if((i|0)!=1792&(k|0)==1792){RH(7);break}if(k>>>0<=(c[2276079]|0)>>>0){break}RH(j&16777215)}}while(0);j=c[2394]|0;k=c[14130368+(j<<2)>>2]|0;if((k|0)!=0){gGC(k|0,9104152,280)|0}c[8452240+(j<<2)>>2]=c[2113054];c[2394]=-1;l=c[3532030]|0}else{l=h}if((l|0)!=0){j=c[2439330]|0;if((j|0)!=0){k=j;gGC(9706056,k|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;Sb(ag((c[2113022]|0)/(d|0)|0,f)|0);k=c[1836236]|0;j=c[9757320+(k<<2)>>2]|0;if((j|0)!=0){i=j;gGC(i|0,9706056,76)|0}c[9752472+(k<<2)>>2]=c[2433530];c[14113936+(k<<2)>>2]=c[2076596];c[9669104+(k<<2)>>2]=c[3541536];c[1836236]=-1}if((g|0)<(d|0)){f=g}else{break}}m=c[3532030]|0}else{m=e}if((m|0)==0){if((c[2394]|0)!=1){c[2394]=1;c[2112932]=c[3532597];m=c[3532593]|0;if((m|0)!=0){gGC(9104152,m|0,280)|0}c[2113054]=c[2113061]}if((b[7064256]&1)!=0){m=c[2113024]|0;e=gGU(m,(m|0)<0|0?-1:0,2048e6,0)|0;f=c[2438228]|0;d=gGS(e,K,f,(f|0)<0|0?-1:0)|0;f=d;Sb(m);m=c[2443830]|0;if((m|0)<1073676288){c[2443830]=m-f}m=c[2443831]|0;if((m|0)<1073676288){c[2443831]=m-f}m=(c[3528512]|0)-f|0;c[3528512]=(m|0)<0?0:m}m=c[2112964]|0;if((m|0)!=0){gg[c[3542118]&4095](m,a[9688]|0?534:0)}do{if((b[7064256]&1)!=0){m=c[3532064]|0;c[8452200+(c[2394]<<2)>>2]=m|8192;f=c[2276080]|0;d=m<<8;c[2276080]=d;if((f|0)!=1792&(d|0)==1792){RH(7);break}if(d>>>0<=(c[2276079]|0)>>>0){break}RH(m&16777215)}}while(0);m=c[2394]|0;d=c[14130368+(m<<2)>>2]|0;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[8452240+(m<<2)>>2]=c[2113054];c[2394]=-1}else{m=c[2439330]|0;if((m|0)!=0){d=m;gGC(9706056,d|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;d=c[2113022]|0;m=gGU(d,(d|0)<0|0?-1:0,2048e6,0)|0;f=c[2438228]|0;e=gGS(m,K,f,(f|0)<0|0?-1:0)|0;f=e;Sb(d);d=c[2443830]|0;if((d|0)<1073676288){c[2443830]=d-f}d=c[2443831]|0;if((d|0)<1073676288){c[2443831]=d-f}d=(c[3528512]|0)-f|0;c[3528512]=(d|0)<0?0:d;d=c[2112964]|0;if((d|0)!=0){gg[c[3542118]&4095](d,a[9688]|0?534:0)}d=c[1836236]|0;f=c[9757320+(d<<2)>>2]|0;if((f|0)!=0){e=f;gGC(e|0,9706056,76)|0}c[9752472+(d<<2)>>2]=c[2433530];c[14113936+(d<<2)>>2]=c[2076596];c[9669104+(d<<2)>>2]=c[3541536];c[1836236]=-1}if((c[2112968]|0)==0){return 0}gu[c[3532118]&16383]();return 0}function e3B(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;g=i;i=i+288|0;h=g|0;j=g+16|0;k=g+32|0;l=g+48|0;m=g+64|0;n=g+80|0;o=g+96|0;p=g+112|0;q=g+128|0;r=g+144|0;s=g+160|0;t=g+176|0;u=g+192|0;v=g+208|0;w=g+224|0;x=g+240|0;y=g+256|0;z=g+272|0;if((f|0)!=0){c[f>>2]=169588}if((e&32|0)!=0){gGz(z|0,0,12);A=c[3532020]|0;c[z>>2]=A;c[z+4>>2]=(c[3532022]|0)-A;c[z+12>>2]=162152;A=c[2076592]|0;gj[A&4095](z)|0}eZ7(e);if((e&64|0)!=0){z=m|0;gGz(l|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){A=m+9|0;m=k;B=k|0;C=k+4|0;D=k+12|0;E=l|0;F=l+4|0;G=l+12|0;H=0;do{gGC(z|0,614896,11)|0;a[A]=H+48&255;I=8452256+(H<<2)|0;gGz(m|0,0,12);c[B>>2]=I;c[C>>2]=4;c[D>>2]=164976;gj[c[2076592]&4095](k)|0;if((c[I>>2]|0)!=0){c[E>>2]=c[14130368+(H<<2)>>2];c[F>>2]=c[8452184+(H<<2)>>2];c[G>>2]=z;I=c[2076592]|0;gj[I&4095](l)|0}H=H+1|0;}while((H|0)<=(c[2392]|0))}if((c[3532030]|0)!=0){fw$(e)}T0(e,f);gGz(j|0,0,12);c[j>>2]=14168784;c[j+4>>2]=16;c[j+12>>2]=249744;f=c[2076592]|0;gj[f&4095](j)|0;gGz(h|0,0,12);c[h>>2]=14168768;c[h+4>>2]=16;c[h+12>>2]=524320;j=c[2076592]|0;gj[j&4095](h)|0;gGz(y|0,0,12);c[y>>2]=14128744;c[y+4>>2]=4;c[y+12>>2]=400008;h=c[2076592]|0;gj[h&4095](y)|0;gGz(x|0,0,12);c[x>>2]=14128736;c[x+4>>2]=4;c[x+12>>2]=399240;y=c[2076592]|0;gj[y&4095](x)|0;gGz(w|0,0,12);c[w>>2]=14128728;c[w+4>>2]=4;c[w+12>>2]=398304;x=c[2076592]|0;gj[x&4095](w)|0;gGz(v|0,0,12);c[v>>2]=14128720;c[v+4>>2]=4;c[v+12>>2]=397552;w=c[2076592]|0;gj[w&4095](v)|0;gGz(u|0,0,12);c[u>>2]=14128320;c[u+4>>2]=6;c[u+12>>2]=273024;v=c[2076592]|0;gj[v&4095](u)|0;gGz(t|0,0,12);c[t>>2]=9623024;c[t+4>>2]=4;c[t+12>>2]=394848;u=c[2076592]|0;gj[u&4095](t)|0;gGz(s|0,0,12);c[s>>2]=14128512;c[s+4>>2]=2;c[s+12>>2]=393592;t=c[2076592]|0;gj[t&4095](s)|0;gGz(r|0,0,12);c[r>>2]=14127752;c[r+4>>2]=1;c[r+12>>2]=272344;s=c[2076592]|0;gj[s&4095](r)|0;gGz(q|0,0,12);c[q>>2]=9754312;c[q+4>>2]=4;c[q+12>>2]=389912;r=c[2076592]|0;gj[r&4095](q)|0;gGz(p|0,0,12);c[p>>2]=14128056;c[p+4>>2]=4;c[p+12>>2]=388960;q=c[2076592]|0;gj[q&4095](p)|0;gGz(o|0,0,12);c[o>>2]=8452120;c[o+4>>2]=16;c[o+12>>2]=270496;p=c[2076592]|0;gj[p&4095](o)|0;gGz(n|0,0,12);c[n>>2]=8452112;c[n+4>>2]=4;c[n+12>>2]=269664;o=c[2076592]|0;gj[o&4095](n)|0}if(!((e&2|0)!=0&(c[3532030]|0)!=0)){i=g;return 0}e=c[2439330]|0;n=(e|0)==0;if(!n){o=e;gGC(9706056,o|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];o=c[3528484]|0;c[2076596]=o;p=c[2417276]|0;c[3541536]=p;c[1836236]=0;q=c[3531932]|0;r=(d[14127752]|0)<<14;s=64;t=64;while(1){c[e+76+(t<<2)>>2]=q+((t<<8)+r);u=s+1&65535;if((u&65535)>127){J=64;K=64;break}else{s=u;t=u&65535}}while(1){t=q+((K<<8)+r)|0;c[e+76+(K+512<<2)>>2]=t;c[e+76+(K+768<<2)>>2]=t;t=J+1&65535;if((t&65535)>127){break}else{J=t;K=t&65535}}if(!n){n=e;gGC(n|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=o;c[2417276]=p;c[1836236]=-1;i=g;return 0}function e3C(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2017708+(b*112|0)>>2];c[a+104>>2]=c[2017712+(b*112|0)>>2];c[a+108>>2]=c[2017716+(b*112|0)>>2];d=0;return d|0}function e3D(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=2017608+(b*112|0);e=0;return e|0}function e3E(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>35){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=2019400+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e3F(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2015916+(b*112|0)>>2];c[a+104>>2]=c[2015920+(b*112|0)>>2];c[a+108>>2]=c[2015924+(b*112|0)>>2];d=0;return d|0}function e3G(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=2015816+(b*112|0);e=0;return e|0}function e3H(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6410900+(b*112|0)>>2];c[a+104>>2]=c[6410904+(b*112|0)>>2];c[a+108>>2]=c[6410908+(b*112|0)>>2];d=0;return d|0}function e3I(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<22&(d|0)==0)){e=1;return e|0}c[a>>2]=6410800+(b*112|0);e=0;return e|0}function e3J(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4211784+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function e3K(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>30){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6413264+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e3L(){var b=0,d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;a[681304]=1;c[3532162]=256;c[3532160]=4;c[3532142]=8;c[3532164]=8;c[3532148]=1983640;c[3532140]=6964216;c[3532138]=6963960;c[3532042]=16384;c[3532002]=512;c[3532e3]=4;a[7460944]=1;c[3532004]=8;c[3531998]=961392;c[3531992]=4969496;c[3531990]=961552;c[3532034]=32768;c[3532044]=2;a[7460960]=1;eZ9(0)|0;c[3532204]=0;b=c[3532200]|0;c[3532198]=b;d=(c[3532194]|0)+b|0;c[3531932]=d;e=d+(c[3531928]|0)|0;c[3531976]=e;f=e+(c[3531972]|0)|0;c[3531952]=f;g=f+(c[3531948]|0)|0;c[3531946]=g;i=g+(c[3531942]|0)|0;j=i|0;c[3532020]=j;c[3532208]=j;j=i+65536|0;c[3532206]=j;k=i+98304|0;c[3532008]=k;l=i+163840|0;c[3531936]=l;m=i+172032|0;c[3531970]=m;n=i+188416|0;c[3532026]=n;o=i+196608|0;p=o|0;c[3532022]=p;c[3532136]=p;p=ag(c[3532142]|0,c[3532042]|0)|0;q=(ag(p,c[3532164]|0)|0)+o|0;c[3531962]=q;p=ag(a[7460944]|0?16:0,c[3532034]|0)|0;r=(ag(p,c[3532004]|0)|0)+q|0;c[3531960]=r;p=ag(a[7460912]|0?16:0,a[7460976]|0?16384:0)|0;s=(ag(p,a[7460936]|0?16:0)|0)+r|0;c[3532028]=s;p=s+16384|0;t=p|0;c[3532046]=t;u=t;t=gGq(u)|0;c[3532048]=t;if((t|0)==0){v=1;return v|0}gGz(t|0,0,u|0);c[3532204]=t;c[3532198]=t+b;c[3531932]=t+d;c[3531976]=t+e;c[3531952]=t+f;c[3531946]=t+g;g=t+i|0;c[3532020]=g;c[3532208]=g;c[3532206]=t+j;c[3532008]=t+k;c[3531936]=t+l;c[3531970]=t+m;c[3532026]=t+n;n=t+o|0;c[3532022]=n;c[3532136]=n;c[3531962]=t+q;c[3531960]=t+r;c[3532028]=t+s;c[3532046]=t+p;p=c[642608+(c[2436]<<2)>>2]|0;t=c[p+128>>2]|0;if((c[p+52>>2]&4|0)==0){c[2113068]=t;s=c[p+132>>2]|0;c[2113070]=s;c[2443814]=t;c[2440436]=s;w=t;x=s}else{c[2113070]=t;s=c[p+132>>2]|0;c[2113068]=s;c[2440436]=t;c[2443814]=s;w=s;x=t}t=ag(w<<1,x)|0;x=gGq(t)|0;c[2112926]=x;if((x|0)!=0){gGz(x|0,0,t|0)}eX5(0,c[3532042]|0,0,8,1,0);t=c[3532010]|0;x=0;while(1){if((x|0)>=1024){y=0;break}z=9638528+(x<<2)|0;if((c[z>>2]|0)==0){A=42460;break}else{x=x+1|0}}do{if((A|0)==42460){x=gGq(t)|0;c[z>>2]=x;if((x|0)==0){y=0;break}gGz(x|0,0,t|0);y=x}}while(0);c[3532270]=y;gGz(y|0,0,t|0);t=0;while(1){if((t|0)>=1024){B=0;break}C=9638528+(t<<2)|0;if((c[C>>2]|0)==0){A=42465;break}else{t=t+1|0}}do{if((A|0)==42465){t=gGq(8192)|0;c[C>>2]=t;if((t|0)==0){B=0;break}gGz(t|0,0,8192);B=t}}while(0);c[3532272]=B;gGz(B|0,0,8192);a[725176]=1;a[7461072]=1;a[7461056]=1;if((eZ9(1)|0)!=0){v=1;return v|0}fxU(0,425984);if((c[2394]|0)==0){D=c[2112932]|0}else{c[2394]=0;B=c[3532596]|0;c[2112932]=B;C=c[3532592]|0;if((C|0)!=0){gGC(9104152,C|0,280)|0}c[2113054]=c[2113060];D=B}B=c[3532204]|0;C=D|0;A=0;while(1){t=B+A|0;c[C>>2]=t;c[C+131072>>2]=t;t=A+1024|0;if(t>>>0>524287){break}else{C=C+4|0;A=t}}A=c[3532208]|0;C=D+4096|0;B=1048576;while(1){t=A+(B-1048576)|0;c[C>>2]=t;c[C+65536>>2]=t;c[C+131072>>2]=t;t=B+1024|0;if(t>>>0>1114111){break}else{C=C+4|0;B=t}}B=c[3532008]|0;c[D+4352>>2]=B;c[D+69888>>2]=B;c[D+135424>>2]=B;C=B+1024|0;c[D+4356>>2]=C;c[D+69892>>2]=C;c[D+135428>>2]=C;C=B+2048|0;c[D+4360>>2]=C;c[D+69896>>2]=C;c[D+135432>>2]=C;C=B+3072|0;c[D+4364>>2]=C;c[D+69900>>2]=C;c[D+135436>>2]=C;C=B+4096|0;c[D+4368>>2]=C;c[D+69904>>2]=C;c[D+135440>>2]=C;C=B+5120|0;c[D+4372>>2]=C;c[D+69908>>2]=C;c[D+135444>>2]=C;C=B+6144|0;c[D+4376>>2]=C;c[D+69912>>2]=C;c[D+135448>>2]=C;C=B+7168|0;c[D+4380>>2]=C;c[D+69916>>2]=C;c[D+135452>>2]=C;C=B+8192|0;c[D+4384>>2]=C;c[D+69920>>2]=C;c[D+135456>>2]=C;C=B+9216|0;c[D+4388>>2]=C;c[D+69924>>2]=C;c[D+135460>>2]=C;C=B+10240|0;c[D+4392>>2]=C;c[D+69928>>2]=C;c[D+135464>>2]=C;C=B+11264|0;c[D+4396>>2]=C;c[D+69932>>2]=C;c[D+135468>>2]=C;C=B+12288|0;c[D+4400>>2]=C;c[D+69936>>2]=C;c[D+135472>>2]=C;C=B+13312|0;c[D+4404>>2]=C;c[D+69940>>2]=C;c[D+135476>>2]=C;C=B+14336|0;c[D+4408>>2]=C;c[D+69944>>2]=C;c[D+135480>>2]=C;C=B+15360|0;c[D+4412>>2]=C;c[D+69948>>2]=C;c[D+135484>>2]=C;C=c[3532026]|0;c[D+40960>>2]=C;c[D+106496>>2]=C;c[D+172032>>2]=C;B=C+1024|0;c[D+40964>>2]=B;c[D+106500>>2]=B;c[D+172036>>2]=B;B=C+2048|0;c[D+40968>>2]=B;c[D+106504>>2]=B;c[D+172040>>2]=B;B=C+3072|0;c[D+40972>>2]=B;c[D+106508>>2]=B;c[D+172044>>2]=B;B=C+4096|0;c[D+40976>>2]=B;c[D+106512>>2]=B;c[D+172048>>2]=B;B=C+5120|0;c[D+40980>>2]=B;c[D+106516>>2]=B;c[D+172052>>2]=B;B=C+6144|0;c[D+40984>>2]=B;c[D+106520>>2]=B;c[D+172056>>2]=B;B=C+7168|0;c[D+40988>>2]=B;c[D+106524>>2]=B;c[D+172060>>2]=B;B=c[3531970]|0;c[D+49152>>2]=B;c[D+114688>>2]=B;c[D+180224>>2]=B;C=B+1024|0;c[D+49156>>2]=C;c[D+114692>>2]=C;c[D+180228>>2]=C;C=B+2048|0;c[D+49160>>2]=C;c[D+114696>>2]=C;c[D+180232>>2]=C;C=B+3072|0;c[D+49164>>2]=C;c[D+114700>>2]=C;c[D+180236>>2]=C;C=c[3532278]|0;B=D+53248|0;A=13631488;while(1){c[B>>2]=C+(A-13631488);t=A+1024|0;if(t>>>0>13697023){break}else{B=B+4|0;A=t}}c[D+196728>>2]=2692;c[D+196608>>2]=1386;c[D+196648>>2]=2374;D=c[3532592]|0;if((D|0)!=0){gGC(D|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fxU(1,425984);if((c[2394]|0)==1){E=c[2112932]|0}else{c[2394]=1;D=c[3532597]|0;c[2112932]=D;A=c[3532593]|0;if((A|0)!=0){gGC(9104152,A|0,280)|0}c[2113054]=c[2113061];E=D}D=c[3532198]|0;A=E|0;B=0;while(1){C=D+B|0;c[A>>2]=C;c[A+131072>>2]=C;C=B+1024|0;if(C>>>0>524287){break}else{A=A+4|0;B=C}}B=c[3532206]|0;c[E+4224>>2]=B;c[E+69760>>2]=B;c[E+135296>>2]=B;A=B+1024|0;c[E+4228>>2]=A;c[E+69764>>2]=A;c[E+135300>>2]=A;A=B+2048|0;c[E+4232>>2]=A;c[E+69768>>2]=A;c[E+135304>>2]=A;A=B+3072|0;c[E+4236>>2]=A;c[E+69772>>2]=A;c[E+135308>>2]=A;A=B+4096|0;c[E+4240>>2]=A;c[E+69776>>2]=A;c[E+135312>>2]=A;A=B+5120|0;c[E+4244>>2]=A;c[E+69780>>2]=A;c[E+135316>>2]=A;A=B+6144|0;c[E+4248>>2]=A;c[E+69784>>2]=A;c[E+135320>>2]=A;A=B+7168|0;c[E+4252>>2]=A;c[E+69788>>2]=A;c[E+135324>>2]=A;A=B+8192|0;c[E+4256>>2]=A;c[E+69792>>2]=A;c[E+135328>>2]=A;A=B+9216|0;c[E+4260>>2]=A;c[E+69796>>2]=A;c[E+135332>>2]=A;A=B+10240|0;c[E+4264>>2]=A;c[E+69800>>2]=A;c[E+135336>>2]=A;A=B+11264|0;c[E+4268>>2]=A;c[E+69804>>2]=A;c[E+135340>>2]=A;A=B+12288|0;c[E+4272>>2]=A;c[E+69808>>2]=A;c[E+135344>>2]=A;A=B+13312|0;c[E+4276>>2]=A;c[E+69812>>2]=A;c[E+135348>>2]=A;A=B+14336|0;c[E+4280>>2]=A;c[E+69816>>2]=A;c[E+135352>>2]=A;A=B+15360|0;c[E+4284>>2]=A;c[E+69820>>2]=A;c[E+135356>>2]=A;A=c[3532008]|0;c[E+4352>>2]=A;c[E+69888>>2]=A;c[E+135424>>2]=A;B=A+1024|0;c[E+4356>>2]=B;c[E+69892>>2]=B;c[E+135428>>2]=B;B=A+2048|0;c[E+4360>>2]=B;c[E+69896>>2]=B;c[E+135432>>2]=B;B=A+3072|0;c[E+4364>>2]=B;c[E+69900>>2]=B;c[E+135436>>2]=B;B=A+4096|0;c[E+4368>>2]=B;c[E+69904>>2]=B;c[E+135440>>2]=B;B=A+5120|0;c[E+4372>>2]=B;c[E+69908>>2]=B;c[E+135444>>2]=B;B=A+6144|0;c[E+4376>>2]=B;c[E+69912>>2]=B;c[E+135448>>2]=B;B=A+7168|0;c[E+4380>>2]=B;c[E+69916>>2]=B;c[E+135452>>2]=B;B=A+8192|0;c[E+4384>>2]=B;c[E+69920>>2]=B;c[E+135456>>2]=B;B=A+9216|0;c[E+4388>>2]=B;c[E+69924>>2]=B;c[E+135460>>2]=B;B=A+10240|0;c[E+4392>>2]=B;c[E+69928>>2]=B;c[E+135464>>2]=B;B=A+11264|0;c[E+4396>>2]=B;c[E+69932>>2]=B;c[E+135468>>2]=B;B=A+12288|0;c[E+4400>>2]=B;c[E+69936>>2]=B;c[E+135472>>2]=B;B=A+13312|0;c[E+4404>>2]=B;c[E+69940>>2]=B;c[E+135476>>2]=B;B=A+14336|0;c[E+4408>>2]=B;c[E+69944>>2]=B;c[E+135480>>2]=B;B=A+15360|0;c[E+4412>>2]=B;c[E+69948>>2]=B;c[E+135484>>2]=B;B=c[3532272]|0;c[E+32768>>2]=B;c[E+98304>>2]=B;c[E+163840>>2]=B;A=B+1024|0;c[E+32772>>2]=A;c[E+98308>>2]=A;c[E+163844>>2]=A;A=B+2048|0;c[E+32776>>2]=A;c[E+98312>>2]=A;c[E+163848>>2]=A;A=B+3072|0;c[E+32780>>2]=A;c[E+98316>>2]=A;c[E+163852>>2]=A;A=B+4096|0;c[E+32784>>2]=A;c[E+98320>>2]=A;c[E+163856>>2]=A;A=B+5120|0;c[E+32788>>2]=A;c[E+98324>>2]=A;c[E+163860>>2]=A;A=B+6144|0;c[E+32792>>2]=A;c[E+98328>>2]=A;c[E+163864>>2]=A;A=B+7168|0;c[E+32796>>2]=A;c[E+98332>>2]=A;c[E+163868>>2]=A;c[E+196688>>2]=404;c[E+196728>>2]=628;E=c[3532593]|0;if((E|0)!=0){gGC(E|0,9104152,280)|0}c[2113061]=c[2113054];c[2394]=-1;TW(c[3531952]|0,14127792,c[3531946]|0,14127768,0,2262,104);c[2438228]=12e6;c[2433526]=3248;c[2406676]=148;c[3528472]=444;c[2443846]=169;h[745406]=1.0;c[2436786]=3;h[745405]=1.0;c[2436784]=3;h[745404]=.25;a[3203280]=1;c[3532050]=144;c[3532118]=1238;c[3532064]=4;c[3532082]=100;a[7461152]=1;c[2113026]=2e5;c[2113024]=2e5;eZ8()|0;c[2438578]=0;c[2405756]=0;v=0;return v|0}function e3M(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5559332+(b*112|0)>>2];c[a+104>>2]=c[5559336+(b*112|0)>>2];c[a+108>>2]=c[5559340+(b*112|0)>>2];d=0;return d|0}function e3N(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<22&(d|0)==0)){e=1;return e|0}c[a>>2]=5559232+(b*112|0);e=0;return e|0}function e3O(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>30){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5561696+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e3P(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1995220+(b*112|0)>>2];c[a+104>>2]=c[1995224+(b*112|0)>>2];c[a+108>>2]=c[1995228+(b*112|0)>>2];d=0;return d|0}function e3Q(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<22&(d|0)==0)){e=1;return e|0}c[a>>2]=1995120+(b*112|0);e=0;return e|0}function e3R(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=990504+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function e3S(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>30){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1997584+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e3T(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5556492+(b*112|0)>>2];c[a+104>>2]=c[5556496+(b*112|0)>>2];c[a+108>>2]=c[5556500+(b*112|0)>>2];d=0;return d|0}function e3U(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<22&(d|0)==0)){e=1;return e|0}c[a>>2]=5556392+(b*112|0);e=0;return e|0}function e3V(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>30){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5558856+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e3W(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>52){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5535540+(b*112|0)>>2];c[a+104>>2]=c[5535544+(b*112|0)>>2];c[a+108>>2]=c[5535548+(b*112|0)>>2];d=0;return d|0}function e3X(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<53&(d|0)==0)){e=1;return e|0}c[a>>2]=5535440+(b*112|0);e=0;return e|0}function e3Y(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1983368+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function e3Z(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>44){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5541376+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e3_(){var b=0,d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;c[3532162]=256;c[3532160]=4;c[3532142]=8;c[3532164]=8;c[3532148]=1983640;c[3532140]=6964216;c[3532138]=6963960;c[3532042]=16384;c[3532002]=1024;c[3532e3]=4;a[7460944]=1;c[3532004]=16;c[3531998]=961392;c[3531992]=4969496;c[3531990]=4969048;c[3532034]=16384;a[7460928]=1;a[7460920]=1;a[7460912]=1;a[7460936]=1;c[3531988]=961392;c[3531982]=4969496;c[3531980]=4969048;a[7460976]=1;c[3532044]=2;c[3532030]=1;a[7460960]=1;eZ9(0)|0;c[3532204]=0;b=c[3532200]|0;c[3532198]=b;d=(c[3532194]|0)+b|0;c[3531932]=d;e=d+(c[3531928]|0)|0;c[3531976]=e;f=e+(c[3531972]|0)|0;c[3531952]=f;g=f+(c[3531948]|0)|0;c[3531946]=g;i=g+(c[3531942]|0)|0;j=i|0;c[3532020]=j;c[3532208]=j;j=i+65536|0;c[3532206]=j;k=i+98304|0;c[3532008]=k;l=i+163840|0;c[3531936]=l;m=i+172032|0;c[3531970]=m;n=i+188416|0;c[3532026]=n;o=i+196608|0;p=o|0;c[3532022]=p;c[3532136]=p;p=ag(c[3532142]|0,c[3532042]|0)|0;q=(ag(p,c[3532164]|0)|0)+o|0;c[3531962]=q;p=ag(a[7460944]|0?16:0,c[3532034]|0)|0;r=(ag(p,c[3532004]|0)|0)+q|0;c[3531960]=r;p=ag(a[7460912]|0?16:0,a[7460976]|0?16384:0)|0;s=(ag(p,a[7460936]|0?16:0)|0)+r|0;c[3532028]=s;p=s+16384|0;t=p|0;c[3532046]=t;u=t;t=gGq(u)|0;c[3532048]=t;if((t|0)==0){v=1;return v|0}gGz(t|0,0,u|0);c[3532204]=t;c[3532198]=t+b;c[3531932]=t+d;c[3531976]=t+e;c[3531952]=t+f;c[3531946]=t+g;g=t+i|0;c[3532020]=g;c[3532208]=g;c[3532206]=t+j;c[3532008]=t+k;c[3531936]=t+l;c[3531970]=t+m;c[3532026]=t+n;n=t+o|0;c[3532022]=n;c[3532136]=n;c[3531962]=t+q;c[3531960]=t+r;c[3532028]=t+s;c[3532046]=t+p;p=c[642608+(c[2436]<<2)>>2]|0;t=c[p+128>>2]|0;if((c[p+52>>2]&4|0)==0){c[2113068]=t;s=c[p+132>>2]|0;c[2113070]=s;c[2443814]=t;c[2440436]=s;w=t;x=s}else{c[2113070]=t;s=c[p+132>>2]|0;c[2113068]=s;c[2440436]=t;c[2443814]=s;w=s;x=t}t=ag(w<<1,x)|0;x=gGq(t)|0;c[2112926]=x;if((x|0)!=0){gGz(x|0,0,t|0)}eX5(0,c[3532042]|0,0,8,0,0);t=0;while(1){if((t|0)>=1024){y=0;break}z=9638528+(t<<2)|0;if((c[z>>2]|0)==0){A=42594;break}else{t=t+1|0}}do{if((A|0)==42594){t=gGq(16384)|0;c[z>>2]=t;if((t|0)==0){y=0;break}gGz(t|0,0,16384);y=t}}while(0);c[2442928]=y;gGz(y|0,0,16384);y=0;while(1){if((y|0)>=1024){B=0;break}C=9638528+(y<<2)|0;if((c[C>>2]|0)==0){A=42599;break}else{y=y+1|0}}do{if((A|0)==42599){y=gGq(16384)|0;c[C>>2]=y;if((y|0)==0){B=0;break}gGz(y|0,0,16384);B=y}}while(0);c[3532276]=B;gGz(B|0,0,4096);c[3532274]=4096;a[7461088]=1;B=c[3532010]|0;C=0;while(1){if((C|0)>=1024){D=0;break}E=9638528+(C<<2)|0;if((c[E>>2]|0)==0){A=42604;break}else{C=C+1|0}}do{if((A|0)==42604){C=gGq(B)|0;c[E>>2]=C;if((C|0)==0){D=0;break}gGz(C|0,0,B|0);D=C}}while(0);c[3532270]=D;gGz(D|0,0,B|0);B=0;while(1){if((B|0)>=1024){F=0;break}G=9638528+(B<<2)|0;if((c[G>>2]|0)==0){A=42609;break}else{B=B+1|0}}do{if((A|0)==42609){B=gGq(8192)|0;c[G>>2]=B;if((B|0)==0){F=0;break}gGz(B|0,0,8192);F=B}}while(0);c[3532272]=F;gGz(F|0,0,8192);a[725176]=0;a[7461072]=1;a[7461080]=1;a[7461056]=1;if((eZ9(1)|0)!=0){v=1;return v|0}fxU(0,425984);if((c[2394]|0)==0){H=c[2112932]|0}else{c[2394]=0;F=c[3532596]|0;c[2112932]=F;G=c[3532592]|0;if((G|0)!=0){gGC(9104152,G|0,280)|0}c[2113054]=c[2113060];H=F}F=c[3532204]|0;G=H|0;A=0;while(1){B=F+A|0;c[G>>2]=B;c[G+131072>>2]=B;B=A+1024|0;if(B>>>0>524287){break}else{G=G+4|0;A=B}}A=c[3532208]|0;G=H+4096|0;F=1048576;while(1){B=A+(F-1048576)|0;c[G>>2]=B;c[G+65536>>2]=B;c[G+131072>>2]=B;B=F+1024|0;if(B>>>0>1081343){break}else{G=G+4|0;F=B}}F=c[3532008]|0;c[H+4224>>2]=F;c[H+69760>>2]=F;c[H+135296>>2]=F;G=F+1024|0;c[H+4228>>2]=G;c[H+69764>>2]=G;c[H+135300>>2]=G;G=F+2048|0;c[H+4232>>2]=G;c[H+69768>>2]=G;c[H+135304>>2]=G;G=F+3072|0;c[H+4236>>2]=G;c[H+69772>>2]=G;c[H+135308>>2]=G;G=F+4096|0;c[H+4240>>2]=G;c[H+69776>>2]=G;c[H+135312>>2]=G;G=F+5120|0;c[H+4244>>2]=G;c[H+69780>>2]=G;c[H+135316>>2]=G;G=F+6144|0;c[H+4248>>2]=G;c[H+69784>>2]=G;c[H+135320>>2]=G;G=F+7168|0;c[H+4252>>2]=G;c[H+69788>>2]=G;c[H+135324>>2]=G;G=F+8192|0;c[H+4256>>2]=G;c[H+69792>>2]=G;c[H+135328>>2]=G;G=F+9216|0;c[H+4260>>2]=G;c[H+69796>>2]=G;c[H+135332>>2]=G;G=F+10240|0;c[H+4264>>2]=G;c[H+69800>>2]=G;c[H+135336>>2]=G;G=F+11264|0;c[H+4268>>2]=G;c[H+69804>>2]=G;c[H+135340>>2]=G;G=F+12288|0;c[H+4272>>2]=G;c[H+69808>>2]=G;c[H+135344>>2]=G;G=F+13312|0;c[H+4276>>2]=G;c[H+69812>>2]=G;c[H+135348>>2]=G;G=F+14336|0;c[H+4280>>2]=G;c[H+69816>>2]=G;c[H+135352>>2]=G;G=F+15360|0;c[H+4284>>2]=G;c[H+69820>>2]=G;c[H+135356>>2]=G;G=c[3532278]|0;F=H+49152|0;A=12582912;while(1){c[F>>2]=G+(A-12582912);B=A+1024|0;if(B>>>0>12648447){break}else{F=F+4|0;A=B}}A=c[3531970]|0;c[H+53248>>2]=A;c[H+118784>>2]=A;c[H+184320>>2]=A;F=A+1024|0;c[H+53252>>2]=F;c[H+118788>>2]=F;c[H+184324>>2]=F;c[H+196688>>2]=842;c[H+196728>>2]=434;c[H+196608>>2]=1362;c[H+196648>>2]=3180;H=c[3532592]|0;if((H|0)!=0){gGC(H|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fxU(1,425984);if((c[2394]|0)==1){I=c[2112932]|0}else{c[2394]=1;H=c[3532597]|0;c[2112932]=H;F=c[3532593]|0;if((F|0)!=0){gGC(9104152,F|0,280)|0}c[2113054]=c[2113061];I=H}H=c[3532198]|0;F=I|0;A=0;while(1){G=H+A|0;c[F>>2]=G;c[F+131072>>2]=G;G=A+1024|0;if(G>>>0>131071){break}else{F=F+4|0;A=G}}A=c[3532206]|0;c[I+4096>>2]=A;c[I+69632>>2]=A;c[I+135168>>2]=A;F=A+1024|0;c[I+4100>>2]=F;c[I+69636>>2]=F;c[I+135172>>2]=F;F=A+2048|0;c[I+4104>>2]=F;c[I+69640>>2]=F;c[I+135176>>2]=F;F=A+3072|0;c[I+4108>>2]=F;c[I+69644>>2]=F;c[I+135180>>2]=F;F=A+4096|0;c[I+4112>>2]=F;c[I+69648>>2]=F;c[I+135184>>2]=F;F=A+5120|0;c[I+4116>>2]=F;c[I+69652>>2]=F;c[I+135188>>2]=F;F=A+6144|0;c[I+4120>>2]=F;c[I+69656>>2]=F;c[I+135192>>2]=F;F=A+7168|0;c[I+4124>>2]=F;c[I+69660>>2]=F;c[I+135196>>2]=F;F=A+8192|0;c[I+4128>>2]=F;c[I+69664>>2]=F;c[I+135200>>2]=F;F=A+9216|0;c[I+4132>>2]=F;c[I+69668>>2]=F;c[I+135204>>2]=F;F=A+10240|0;c[I+4136>>2]=F;c[I+69672>>2]=F;c[I+135208>>2]=F;F=A+11264|0;c[I+4140>>2]=F;c[I+69676>>2]=F;c[I+135212>>2]=F;F=A+12288|0;c[I+4144>>2]=F;c[I+69680>>2]=F;c[I+135216>>2]=F;F=A+13312|0;c[I+4148>>2]=F;c[I+69684>>2]=F;c[I+135220>>2]=F;F=A+14336|0;c[I+4152>>2]=F;c[I+69688>>2]=F;c[I+135224>>2]=F;F=A+15360|0;c[I+4156>>2]=F;c[I+69692>>2]=F;c[I+135228>>2]=F;F=c[3532008]|0;c[I+4224>>2]=F;c[I+69760>>2]=F;c[I+135296>>2]=F;A=F+1024|0;c[I+4228>>2]=A;c[I+69764>>2]=A;c[I+135300>>2]=A;A=F+2048|0;c[I+4232>>2]=A;c[I+69768>>2]=A;c[I+135304>>2]=A;A=F+3072|0;c[I+4236>>2]=A;c[I+69772>>2]=A;c[I+135308>>2]=A;A=F+4096|0;c[I+4240>>2]=A;c[I+69776>>2]=A;c[I+135312>>2]=A;A=F+5120|0;c[I+4244>>2]=A;c[I+69780>>2]=A;c[I+135316>>2]=A;A=F+6144|0;c[I+4248>>2]=A;c[I+69784>>2]=A;c[I+135320>>2]=A;A=F+7168|0;c[I+4252>>2]=A;c[I+69788>>2]=A;c[I+135324>>2]=A;A=F+8192|0;c[I+4256>>2]=A;c[I+69792>>2]=A;c[I+135328>>2]=A;A=F+9216|0;c[I+4260>>2]=A;c[I+69796>>2]=A;c[I+135332>>2]=A;A=F+10240|0;c[I+4264>>2]=A;c[I+69800>>2]=A;c[I+135336>>2]=A;A=F+11264|0;c[I+4268>>2]=A;c[I+69804>>2]=A;c[I+135340>>2]=A;A=F+12288|0;c[I+4272>>2]=A;c[I+69808>>2]=A;c[I+135344>>2]=A;A=F+13312|0;c[I+4276>>2]=A;c[I+69812>>2]=A;c[I+135348>>2]=A;A=F+14336|0;c[I+4280>>2]=A;c[I+69816>>2]=A;c[I+135352>>2]=A;A=F+15360|0;c[I+4284>>2]=A;c[I+69820>>2]=A;c[I+135356>>2]=A;A=c[3532272]|0;c[I+32768>>2]=A;c[I+98304>>2]=A;c[I+163840>>2]=A;F=A+1024|0;c[I+32772>>2]=F;c[I+98308>>2]=F;c[I+163844>>2]=F;F=A+2048|0;c[I+32776>>2]=F;c[I+98312>>2]=F;c[I+163848>>2]=F;F=A+3072|0;c[I+32780>>2]=F;c[I+98316>>2]=F;c[I+163852>>2]=F;F=A+4096|0;c[I+32784>>2]=F;c[I+98320>>2]=F;c[I+163856>>2]=F;F=A+5120|0;c[I+32788>>2]=F;c[I+98324>>2]=F;c[I+163860>>2]=F;F=A+6144|0;c[I+32792>>2]=F;c[I+98328>>2]=F;c[I+163864>>2]=F;F=A+7168|0;c[I+32796>>2]=F;c[I+98332>>2]=F;c[I+163868>>2]=F;F=c[3532593]|0;if((F|0)!=0){gGC(F|0,9104152,280)|0}c[2113061]=c[2113054];c[2394]=-1;e5g();TW(c[3531952]|0,14127792,c[3531946]|0,14127768,3028,908,12);c[2438228]=4e6;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=511;h[146569]=.2;h[118354]=.2;h[85208]=1.0;a[64232]=1;c[3532050]=3932;c[3532118]=6706;c[3532064]=4;c[3532082]=100;c[2113026]=2e5;c[2113024]=2e5;c[2113022]=66666;eZ8()|0;c[2438578]=0;c[2405756]=0;v=0;return v|0}function e3$(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>52){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4169924+(b*112|0)>>2];c[a+104>>2]=c[4169928+(b*112|0)>>2];c[a+108>>2]=c[4169932+(b*112|0)>>2];d=0;return d|0}function e30(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<53&(d|0)==0)){e=1;return e|0}c[a>>2]=4169824+(b*112|0);e=0;return e|0}function e31(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>44){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4175760+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e32(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>52){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4163988+(b*112|0)>>2];c[a+104>>2]=c[4163992+(b*112|0)>>2];c[a+108>>2]=c[4163996+(b*112|0)>>2];d=0;return d|0}function e33(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<53&(d|0)==0)){e=1;return e|0}c[a>>2]=4163888+(b*112|0);e=0;return e|0}function e34(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4151492+(b*112|0)>>2];c[a+104>>2]=c[4151496+(b*112|0)>>2];c[a+108>>2]=c[4151500+(b*112|0)>>2];d=0;return d|0}function e35(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=4151392+(b*112|0);e=0;return e|0}function e36(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1292792+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function e37(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>36){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4153520+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e38(){var b=0,d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;c[3532162]=256;c[3532160]=4;c[3532142]=8;c[3532164]=8;c[3532148]=1983640;c[3532140]=6964216;c[3532138]=6963960;c[3532042]=16384;c[3532002]=512;c[3532e3]=4;a[7460944]=1;c[3532004]=8;c[3531998]=961392;c[3531992]=4969496;c[3531990]=961552;c[3532034]=32768;c[3532044]=2;c[3532030]=1;a[7460960]=1;eZ9(0)|0;c[3532204]=0;b=c[3532200]|0;c[3532198]=b;d=(c[3532194]|0)+b|0;c[3531932]=d;e=d+(c[3531928]|0)|0;c[3531976]=e;f=e+(c[3531972]|0)|0;c[3531952]=f;g=f+(c[3531948]|0)|0;c[3531946]=g;i=g+(c[3531942]|0)|0;j=i|0;c[3532020]=j;c[3532208]=j;j=i+65536|0;c[3532206]=j;k=i+98304|0;c[3532008]=k;l=i+163840|0;c[3531936]=l;m=i+172032|0;c[3531970]=m;n=i+188416|0;c[3532026]=n;o=i+196608|0;p=o|0;c[3532022]=p;c[3532136]=p;p=ag(c[3532142]|0,c[3532042]|0)|0;q=(ag(p,c[3532164]|0)|0)+o|0;c[3531962]=q;p=ag(a[7460944]|0?16:0,c[3532034]|0)|0;r=(ag(p,c[3532004]|0)|0)+q|0;c[3531960]=r;p=ag(a[7460912]|0?16:0,a[7460976]|0?16384:0)|0;s=(ag(p,a[7460936]|0?16:0)|0)+r|0;c[3532028]=s;p=s+16384|0;t=p|0;c[3532046]=t;u=t;t=gGq(u)|0;c[3532048]=t;if((t|0)==0){v=1;return v|0}gGz(t|0,0,u|0);c[3532204]=t;c[3532198]=t+b;c[3531932]=t+d;c[3531976]=t+e;c[3531952]=t+f;c[3531946]=t+g;g=t+i|0;c[3532020]=g;c[3532208]=g;c[3532206]=t+j;c[3532008]=t+k;c[3531936]=t+l;c[3531970]=t+m;c[3532026]=t+n;n=t+o|0;c[3532022]=n;c[3532136]=n;c[3531962]=t+q;c[3531960]=t+r;c[3532028]=t+s;c[3532046]=t+p;p=c[642608+(c[2436]<<2)>>2]|0;t=c[p+128>>2]|0;if((c[p+52>>2]&4|0)==0){c[2113068]=t;s=c[p+132>>2]|0;c[2113070]=s;c[2443814]=t;c[2440436]=s;w=t;x=s}else{c[2113070]=t;s=c[p+132>>2]|0;c[2113068]=s;c[2440436]=t;c[2443814]=s;w=s;x=t}t=ag(w<<1,x)|0;x=gGq(t)|0;c[2112926]=x;if((x|0)!=0){gGz(x|0,0,t|0)}eX5(0,c[3532042]|0,0,16,0,0);t=0;while(1){if((t|0)>=1024){y=0;break}z=9638528+(t<<2)|0;if((c[z>>2]|0)==0){A=42705;break}else{t=t+1|0}}do{if((A|0)==42705){t=gGq(16384)|0;c[z>>2]=t;if((t|0)==0){y=0;break}gGz(t|0,0,16384);y=t}}while(0);c[2442928]=y;gGz(y|0,0,16384);y=0;while(1){if((y|0)>=1024){B=0;break}C=9638528+(y<<2)|0;if((c[C>>2]|0)==0){A=42710;break}else{y=y+1|0}}do{if((A|0)==42710){y=gGq(16384)|0;c[C>>2]=y;if((y|0)==0){B=0;break}gGz(y|0,0,16384);B=y}}while(0);c[3532276]=B;gGz(B|0,0,4096);c[3532274]=4096;a[7461088]=1;B=c[3532010]|0;C=0;while(1){if((C|0)>=1024){D=0;break}E=9638528+(C<<2)|0;if((c[E>>2]|0)==0){A=42715;break}else{C=C+1|0}}do{if((A|0)==42715){C=gGq(B)|0;c[E>>2]=C;if((C|0)==0){D=0;break}gGz(C|0,0,B|0);D=C}}while(0);c[3532270]=D;gGz(D|0,0,B|0);B=0;while(1){if((B|0)>=1024){F=0;break}G=9638528+(B<<2)|0;if((c[G>>2]|0)==0){A=42720;break}else{B=B+1|0}}do{if((A|0)==42720){B=gGq(8192)|0;c[G>>2]=B;if((B|0)==0){F=0;break}gGz(B|0,0,8192);F=B}}while(0);c[3532272]=F;gGz(F|0,0,8192);a[725176]=0;a[7461072]=1;a[7461080]=1;a[7461056]=1;if((eZ9(1)|0)!=0){v=1;return v|0}fxU(0,425984);if((c[2394]|0)==0){H=c[2112932]|0}else{c[2394]=0;F=c[3532596]|0;c[2112932]=F;G=c[3532592]|0;if((G|0)!=0){gGC(9104152,G|0,280)|0}c[2113054]=c[2113060];H=F}F=c[3532204]|0;G=H|0;A=0;while(1){B=F+A|0;c[G>>2]=B;c[G+131072>>2]=B;B=A+1024|0;if(B>>>0>262143){break}else{G=G+4|0;A=B}}A=c[3532208]|0;c[H+2048>>2]=A;c[H+67584>>2]=A;c[H+133120>>2]=A;G=A+1024|0;c[H+2052>>2]=G;c[H+67588>>2]=G;c[H+133124>>2]=G;G=A+2048|0;c[H+2056>>2]=G;c[H+67592>>2]=G;c[H+133128>>2]=G;G=A+3072|0;c[H+2060>>2]=G;c[H+67596>>2]=G;c[H+133132>>2]=G;G=A+4096|0;c[H+2064>>2]=G;c[H+67600>>2]=G;c[H+133136>>2]=G;G=A+5120|0;c[H+2068>>2]=G;c[H+67604>>2]=G;c[H+133140>>2]=G;G=A+6144|0;c[H+2072>>2]=G;c[H+67608>>2]=G;c[H+133144>>2]=G;G=A+7168|0;c[H+2076>>2]=G;c[H+67612>>2]=G;c[H+133148>>2]=G;G=A+8192|0;c[H+2080>>2]=G;c[H+67616>>2]=G;c[H+133152>>2]=G;G=A+9216|0;c[H+2084>>2]=G;c[H+67620>>2]=G;c[H+133156>>2]=G;G=A+10240|0;c[H+2088>>2]=G;c[H+67624>>2]=G;c[H+133160>>2]=G;G=A+11264|0;c[H+2092>>2]=G;c[H+67628>>2]=G;c[H+133164>>2]=G;G=A+12288|0;c[H+2096>>2]=G;c[H+67632>>2]=G;c[H+133168>>2]=G;G=A+13312|0;c[H+2100>>2]=G;c[H+67636>>2]=G;c[H+133172>>2]=G;G=A+14336|0;c[H+2104>>2]=G;c[H+67640>>2]=G;c[H+133176>>2]=G;G=A+15360|0;c[H+2108>>2]=G;c[H+67644>>2]=G;c[H+133180>>2]=G;G=c[3532008]|0;c[H+2112>>2]=G;c[H+67648>>2]=G;c[H+133184>>2]=G;A=G+1024|0;c[H+2116>>2]=A;c[H+67652>>2]=A;c[H+133188>>2]=A;A=G+2048|0;c[H+2120>>2]=A;c[H+67656>>2]=A;c[H+133192>>2]=A;A=G+3072|0;c[H+2124>>2]=A;c[H+67660>>2]=A;c[H+133196>>2]=A;A=G+4096|0;c[H+2128>>2]=A;c[H+67664>>2]=A;c[H+133200>>2]=A;A=G+5120|0;c[H+2132>>2]=A;c[H+67668>>2]=A;c[H+133204>>2]=A;A=G+6144|0;c[H+2136>>2]=A;c[H+67672>>2]=A;c[H+133208>>2]=A;A=G+7168|0;c[H+2140>>2]=A;c[H+67676>>2]=A;c[H+133212>>2]=A;A=G+8192|0;c[H+2144>>2]=A;c[H+67680>>2]=A;c[H+133216>>2]=A;A=G+9216|0;c[H+2148>>2]=A;c[H+67684>>2]=A;c[H+133220>>2]=A;A=G+10240|0;c[H+2152>>2]=A;c[H+67688>>2]=A;c[H+133224>>2]=A;A=G+11264|0;c[H+2156>>2]=A;c[H+67692>>2]=A;c[H+133228>>2]=A;A=G+12288|0;c[H+2160>>2]=A;c[H+67696>>2]=A;c[H+133232>>2]=A;A=G+13312|0;c[H+2164>>2]=A;c[H+67700>>2]=A;c[H+133236>>2]=A;A=G+14336|0;c[H+2168>>2]=A;c[H+67704>>2]=A;c[H+133240>>2]=A;A=G+15360|0;c[H+2172>>2]=A;c[H+67708>>2]=A;c[H+133244>>2]=A;A=c[3532278]|0;G=H+8192|0;F=2097152;while(1){c[G>>2]=A+(F-2097152);B=F+1024|0;if(B>>>0>2162687){break}else{G=G+4|0;F=B}}F=c[3532272]|0;c[H+12288>>2]=F;c[H+77824>>2]=F;c[H+143360>>2]=F;G=F+1024|0;c[H+12292>>2]=G;c[H+77828>>2]=G;c[H+143364>>2]=G;G=F+2048|0;c[H+12296>>2]=G;c[H+77832>>2]=G;c[H+143368>>2]=G;G=F+3072|0;c[H+12300>>2]=G;c[H+77836>>2]=G;c[H+143372>>2]=G;G=F+4096|0;c[H+12304>>2]=G;c[H+77840>>2]=G;c[H+143376>>2]=G;G=F+5120|0;c[H+12308>>2]=G;c[H+77844>>2]=G;c[H+143380>>2]=G;G=F+6144|0;c[H+12312>>2]=G;c[H+77848>>2]=G;c[H+143384>>2]=G;G=F+7168|0;c[H+12316>>2]=G;c[H+77852>>2]=G;c[H+143388>>2]=G;G=c[3531970]|0;c[H+16384>>2]=G;c[H+81920>>2]=G;c[H+147456>>2]=G;F=G+1024|0;c[H+16388>>2]=F;c[H+81924>>2]=F;c[H+147460>>2]=F;c[H+196648>>2]=428;c[H+196728>>2]=928;H=c[3532592]|0;if((H|0)!=0){gGC(H|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fxU(1,425984);if((c[2394]|0)==1){I=c[2112932]|0}else{c[2394]=1;H=c[3532597]|0;c[2112932]=H;F=c[3532593]|0;if((F|0)!=0){gGC(9104152,F|0,280)|0}c[2113054]=c[2113061];I=H}H=c[3532198]|0;F=I|0;G=0;while(1){A=H+G|0;c[F>>2]=A;c[F+131072>>2]=A;A=G+1024|0;if(A>>>0>262143){break}else{F=F+4|0;G=A}}G=c[3532206]|0;c[I+2048>>2]=G;c[I+67584>>2]=G;c[I+133120>>2]=G;F=G+1024|0;c[I+2052>>2]=F;c[I+67588>>2]=F;c[I+133124>>2]=F;F=G+2048|0;c[I+2056>>2]=F;c[I+67592>>2]=F;c[I+133128>>2]=F;F=G+3072|0;c[I+2060>>2]=F;c[I+67596>>2]=F;c[I+133132>>2]=F;F=G+4096|0;c[I+2064>>2]=F;c[I+67600>>2]=F;c[I+133136>>2]=F;F=G+5120|0;c[I+2068>>2]=F;c[I+67604>>2]=F;c[I+133140>>2]=F;F=G+6144|0;c[I+2072>>2]=F;c[I+67608>>2]=F;c[I+133144>>2]=F;F=G+7168|0;c[I+2076>>2]=F;c[I+67612>>2]=F;c[I+133148>>2]=F;F=G+8192|0;c[I+2080>>2]=F;c[I+67616>>2]=F;c[I+133152>>2]=F;F=G+9216|0;c[I+2084>>2]=F;c[I+67620>>2]=F;c[I+133156>>2]=F;F=G+10240|0;c[I+2088>>2]=F;c[I+67624>>2]=F;c[I+133160>>2]=F;F=G+11264|0;c[I+2092>>2]=F;c[I+67628>>2]=F;c[I+133164>>2]=F;F=G+12288|0;c[I+2096>>2]=F;c[I+67632>>2]=F;c[I+133168>>2]=F;F=G+13312|0;c[I+2100>>2]=F;c[I+67636>>2]=F;c[I+133172>>2]=F;F=G+14336|0;c[I+2104>>2]=F;c[I+67640>>2]=F;c[I+133176>>2]=F;F=G+15360|0;c[I+2108>>2]=F;c[I+67644>>2]=F;c[I+133180>>2]=F;F=c[3532008]|0;c[I+2112>>2]=F;c[I+67648>>2]=F;c[I+133184>>2]=F;G=F+1024|0;c[I+2116>>2]=G;c[I+67652>>2]=G;c[I+133188>>2]=G;G=F+2048|0;c[I+2120>>2]=G;c[I+67656>>2]=G;c[I+133192>>2]=G;G=F+3072|0;c[I+2124>>2]=G;c[I+67660>>2]=G;c[I+133196>>2]=G;G=F+4096|0;c[I+2128>>2]=G;c[I+67664>>2]=G;c[I+133200>>2]=G;G=F+5120|0;c[I+2132>>2]=G;c[I+67668>>2]=G;c[I+133204>>2]=G;G=F+6144|0;c[I+2136>>2]=G;c[I+67672>>2]=G;c[I+133208>>2]=G;G=F+7168|0;c[I+2140>>2]=G;c[I+67676>>2]=G;c[I+133212>>2]=G;G=F+8192|0;c[I+2144>>2]=G;c[I+67680>>2]=G;c[I+133216>>2]=G;G=F+9216|0;c[I+2148>>2]=G;c[I+67684>>2]=G;c[I+133220>>2]=G;G=F+10240|0;c[I+2152>>2]=G;c[I+67688>>2]=G;c[I+133224>>2]=G;G=F+11264|0;c[I+2156>>2]=G;c[I+67692>>2]=G;c[I+133228>>2]=G;G=F+12288|0;c[I+2160>>2]=G;c[I+67696>>2]=G;c[I+133232>>2]=G;G=F+13312|0;c[I+2164>>2]=G;c[I+67700>>2]=G;c[I+133236>>2]=G;G=F+14336|0;c[I+2168>>2]=G;c[I+67704>>2]=G;c[I+133240>>2]=G;G=F+15360|0;c[I+2172>>2]=G;c[I+67708>>2]=G;c[I+133244>>2]=G;c[I+196688>>2]=1776;c[I+196728>>2]=2674;c[I+196608>>2]=240;c[I+196648>>2]=1836;I=c[3532593]|0;if((I|0)!=0){gGC(I|0,9104152,280)|0}c[2113061]=c[2113054];c[2394]=-1;e5g();TW(c[3531952]|0,14127792,c[3531946]|0,14127768,3028,908,12);c[2438228]=4e6;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=511;h[146569]=.2;h[118354]=.2;h[85208]=2.0;a[64232]=1;c[3532050]=3076;c[3532118]=2924;c[3532064]=6;c[3532082]=100;c[2113026]=2e5;c[2113024]=2e5;c[2113022]=66666;eZ8()|0;c[2438578]=0;c[2405756]=0;v=0;return v|0}function e39(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1974612+(b*112|0)>>2];c[a+104>>2]=c[1974616+(b*112|0)>>2];c[a+108>>2]=c[1974620+(b*112|0)>>2];d=0;return d|0}function e4a(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=1974512+(b*112|0);e=0;return e|0}function e4b(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>36){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1976640+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e4c(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1290764+(b*112|0)>>2];c[a+104>>2]=c[1290768+(b*112|0)>>2];c[a+108>>2]=c[1290772+(b*112|0)>>2];d=0;return d|0}function e4d(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=1290664+(b*112|0);e=0;return e|0}function e4e(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>33){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1979216+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e4f(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1977188+(b*112|0)>>2];c[a+104>>2]=c[1977192+(b*112|0)>>2];c[a+108>>2]=c[1977196+(b*112|0)>>2];d=0;return d|0}function e4g(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=1977088+(b*112|0);e=0;return e|0}function e4h(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5488012+(b*112|0)>>2];c[a+104>>2]=c[5488016+(b*112|0)>>2];c[a+108>>2]=c[5488020+(b*112|0)>>2];d=0;return d|0}function e4i(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=5487912+(b*112|0);e=0;return e|0}function e4j(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1963360+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function e4k(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>34){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5490488+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e4l(){var b=0,d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;c[3532162]=1024;c[3532160]=4;c[3532142]=16;c[3532164]=16;c[3532148]=688432;c[3532140]=818264;c[3532138]=818200;c[3532042]=8192;c[3532002]=512;c[3532e3]=4;a[7460944]=1;c[3532004]=8;c[3531998]=961392;c[3531992]=4969496;c[3531990]=961552;c[3532034]=65536;c[3532044]=2;c[3532030]=1;a[7460960]=1;eZ9(0)|0;c[3532204]=0;b=c[3532200]|0;c[3532198]=b;d=(c[3532194]|0)+b|0;c[3531932]=d;e=d+(c[3531928]|0)|0;c[3531976]=e;f=e+(c[3531972]|0)|0;c[3531952]=f;g=f+(c[3531948]|0)|0;c[3531946]=g;i=g+(c[3531942]|0)|0;j=i|0;c[3532020]=j;c[3532208]=j;j=i+65536|0;c[3532206]=j;k=i+98304|0;c[3532008]=k;l=i+163840|0;c[3531936]=l;m=i+172032|0;c[3531970]=m;n=i+188416|0;c[3532026]=n;o=i+196608|0;p=o|0;c[3532022]=p;c[3532136]=p;p=ag(c[3532142]|0,c[3532042]|0)|0;q=(ag(p,c[3532164]|0)|0)+o|0;c[3531962]=q;p=ag(a[7460944]|0?16:0,c[3532034]|0)|0;r=(ag(p,c[3532004]|0)|0)+q|0;c[3531960]=r;p=ag(a[7460912]|0?16:0,a[7460976]|0?16384:0)|0;s=(ag(p,a[7460936]|0?16:0)|0)+r|0;c[3532028]=s;p=s+16384|0;t=p|0;c[3532046]=t;u=t;t=gGq(u)|0;c[3532048]=t;if((t|0)==0){v=1;return v|0}gGz(t|0,0,u|0);c[3532204]=t;c[3532198]=t+b;c[3531932]=t+d;c[3531976]=t+e;c[3531952]=t+f;c[3531946]=t+g;g=t+i|0;c[3532020]=g;c[3532208]=g;c[3532206]=t+j;c[3532008]=t+k;c[3531936]=t+l;c[3531970]=t+m;c[3532026]=t+n;n=t+o|0;c[3532022]=n;c[3532136]=n;c[3531962]=t+q;c[3531960]=t+r;c[3532028]=t+s;c[3532046]=t+p;p=c[3532010]|0;t=0;while(1){if((t|0)>=1024){w=0;break}x=9638528+(t<<2)|0;if((c[x>>2]|0)==0){y=42828;break}else{t=t+1|0}}do{if((y|0)==42828){t=gGq(p)|0;c[x>>2]=t;if((t|0)==0){w=0;break}gGz(t|0,0,p|0);w=t}}while(0);c[3532270]=w;gGz(w|0,0,p|0);p=0;while(1){if((p|0)>=1024){z=0;break}A=9638528+(p<<2)|0;if((c[A>>2]|0)==0){y=42833;break}else{p=p+1|0}}do{if((y|0)==42833){p=gGq(8192)|0;c[A>>2]=p;if((p|0)==0){z=0;break}gGz(p|0,0,8192);z=p}}while(0);c[3532272]=z;gGz(z|0,0,8192);a[725176]=0;a[7461072]=1;eXS(c[3532042]|0,0,33,8,4,0,0);a[7461080]=1;a[7461016]=1;if((eZ9(1)|0)!=0){v=1;return v|0}fxU(0,425984);if((c[2394]|0)==0){B=c[2112932]|0}else{c[2394]=0;z=c[3532596]|0;c[2112932]=z;A=c[3532592]|0;if((A|0)!=0){gGC(9104152,A|0,280)|0}c[2113054]=c[2113060];B=z}z=c[3532204]|0;A=B|0;y=0;while(1){p=z+y|0;c[A>>2]=p;c[A+131072>>2]=p;p=y+1024|0;if(p>>>0>524287){break}else{A=A+4|0;y=p}}y=c[3532208]|0;c[B+8192>>2]=y;c[B+73728>>2]=y;c[B+139264>>2]=y;A=y+1024|0;c[B+8196>>2]=A;c[B+73732>>2]=A;c[B+139268>>2]=A;A=y+2048|0;c[B+8200>>2]=A;c[B+73736>>2]=A;c[B+139272>>2]=A;A=y+3072|0;c[B+8204>>2]=A;c[B+73740>>2]=A;c[B+139276>>2]=A;A=y+4096|0;c[B+8208>>2]=A;c[B+73744>>2]=A;c[B+139280>>2]=A;A=y+5120|0;c[B+8212>>2]=A;c[B+73748>>2]=A;c[B+139284>>2]=A;A=y+6144|0;c[B+8216>>2]=A;c[B+73752>>2]=A;c[B+139288>>2]=A;A=y+7168|0;c[B+8220>>2]=A;c[B+73756>>2]=A;c[B+139292>>2]=A;A=y+8192|0;c[B+8224>>2]=A;c[B+73760>>2]=A;c[B+139296>>2]=A;A=y+9216|0;c[B+8228>>2]=A;c[B+73764>>2]=A;c[B+139300>>2]=A;A=y+10240|0;c[B+8232>>2]=A;c[B+73768>>2]=A;c[B+139304>>2]=A;A=y+11264|0;c[B+8236>>2]=A;c[B+73772>>2]=A;c[B+139308>>2]=A;A=y+12288|0;c[B+8240>>2]=A;c[B+73776>>2]=A;c[B+139312>>2]=A;A=y+13312|0;c[B+8244>>2]=A;c[B+73780>>2]=A;c[B+139316>>2]=A;A=y+14336|0;c[B+8248>>2]=A;c[B+73784>>2]=A;c[B+139320>>2]=A;A=y+15360|0;c[B+8252>>2]=A;c[B+73788>>2]=A;c[B+139324>>2]=A;A=c[3532008]|0;y=B+8448|0;z=2162688;while(1){p=A+(z-2162688)|0;c[y>>2]=p;c[y+65536>>2]=p;c[y+131072>>2]=p;p=z+1024|0;if(p>>>0>2228223){break}else{y=y+4|0;z=p}}z=c[3532026]|0;c[B+32768>>2]=z;c[B+98304>>2]=z;c[B+163840>>2]=z;y=z+1024|0;c[B+32772>>2]=y;c[B+98308>>2]=y;c[B+163844>>2]=y;y=z+2048|0;c[B+32776>>2]=y;c[B+98312>>2]=y;c[B+163848>>2]=y;y=z+3072|0;c[B+32780>>2]=y;c[B+98316>>2]=y;c[B+163852>>2]=y;y=z+4096|0;c[B+32784>>2]=y;c[B+98320>>2]=y;c[B+163856>>2]=y;y=z+5120|0;c[B+32788>>2]=y;c[B+98324>>2]=y;c[B+163860>>2]=y;y=z+6144|0;c[B+32792>>2]=y;c[B+98328>>2]=y;c[B+163864>>2]=y;y=z+7168|0;c[B+32796>>2]=y;c[B+98332>>2]=y;c[B+163868>>2]=y;y=c[3532232]|0;z=B+36864|0;A=9437184;while(1){p=y+(A-9437184)|0;c[z>>2]=p;c[z+65536>>2]=p;c[z+131072>>2]=p;p=A+1024|0;if(p>>>0>9502719){break}else{z=z+4|0;A=p}}A=B+40960|0;z=10485760;while(1){p=y+(z-10485760)|0;c[A>>2]=p;c[A+65536>>2]=p;c[A+131072>>2]=p;p=z+1024|0;if(p>>>0>10551295){break}else{A=A+4|0;z=p}}z=c[3531970]|0;c[B+49152>>2]=z;c[B+114688>>2]=z;c[B+180224>>2]=z;A=z+1024|0;c[B+49156>>2]=A;c[B+114692>>2]=A;c[B+180228>>2]=A;A=z+2048|0;c[B+49160>>2]=A;c[B+114696>>2]=A;c[B+180232>>2]=A;A=z+3072|0;c[B+49164>>2]=A;c[B+114700>>2]=A;c[B+180236>>2]=A;A=z+4096|0;c[B+49168>>2]=A;c[B+114704>>2]=A;c[B+180240>>2]=A;A=z+5120|0;c[B+49172>>2]=A;c[B+114708>>2]=A;c[B+180244>>2]=A;A=z+6144|0;c[B+49176>>2]=A;c[B+114712>>2]=A;c[B+180248>>2]=A;A=z+7168|0;c[B+49180>>2]=A;c[B+114716>>2]=A;c[B+180252>>2]=A;A=z+8192|0;c[B+49184>>2]=A;c[B+114720>>2]=A;c[B+180256>>2]=A;A=z+9216|0;c[B+49188>>2]=A;c[B+114724>>2]=A;c[B+180260>>2]=A;A=z+10240|0;c[B+49192>>2]=A;c[B+114728>>2]=A;c[B+180264>>2]=A;A=z+11264|0;c[B+49196>>2]=A;c[B+114732>>2]=A;c[B+180268>>2]=A;A=z+12288|0;c[B+49200>>2]=A;c[B+114736>>2]=A;c[B+180272>>2]=A;A=z+13312|0;c[B+49204>>2]=A;c[B+114740>>2]=A;c[B+180276>>2]=A;A=z+14336|0;c[B+49208>>2]=A;c[B+114744>>2]=A;c[B+180280>>2]=A;A=z+15360|0;c[B+49212>>2]=A;c[B+114748>>2]=A;c[B+180284>>2]=A;c[B+196688>>2]=282;c[B+196728>>2]=1326;c[B+196608>>2]=2446;c[B+196648>>2]=1812;B=c[3532592]|0;if((B|0)!=0){gGC(B|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fxU(1,425984);if((c[2394]|0)==1){C=c[2112932]|0}else{c[2394]=1;B=c[3532597]|0;c[2112932]=B;A=c[3532593]|0;if((A|0)!=0){gGC(9104152,A|0,280)|0}c[2113054]=c[2113061];C=B}B=c[3532198]|0;A=C|0;z=0;while(1){y=B+z|0;c[A>>2]=y;c[A+131072>>2]=y;y=z+1024|0;if(y>>>0>262143){break}else{A=A+4|0;z=y}}z=c[3532206]|0;c[C+4096>>2]=z;c[C+69632>>2]=z;c[C+135168>>2]=z;A=z+1024|0;c[C+4100>>2]=A;c[C+69636>>2]=A;c[C+135172>>2]=A;A=z+2048|0;c[C+4104>>2]=A;c[C+69640>>2]=A;c[C+135176>>2]=A;A=z+3072|0;c[C+4108>>2]=A;c[C+69644>>2]=A;c[C+135180>>2]=A;A=z+4096|0;c[C+4112>>2]=A;c[C+69648>>2]=A;c[C+135184>>2]=A;A=z+5120|0;c[C+4116>>2]=A;c[C+69652>>2]=A;c[C+135188>>2]=A;A=z+6144|0;c[C+4120>>2]=A;c[C+69656>>2]=A;c[C+135192>>2]=A;A=z+7168|0;c[C+4124>>2]=A;c[C+69660>>2]=A;c[C+135196>>2]=A;A=z+8192|0;c[C+4128>>2]=A;c[C+69664>>2]=A;c[C+135200>>2]=A;A=z+9216|0;c[C+4132>>2]=A;c[C+69668>>2]=A;c[C+135204>>2]=A;A=z+10240|0;c[C+4136>>2]=A;c[C+69672>>2]=A;c[C+135208>>2]=A;A=z+11264|0;c[C+4140>>2]=A;c[C+69676>>2]=A;c[C+135212>>2]=A;A=z+12288|0;c[C+4144>>2]=A;c[C+69680>>2]=A;c[C+135216>>2]=A;A=z+13312|0;c[C+4148>>2]=A;c[C+69684>>2]=A;c[C+135220>>2]=A;A=z+14336|0;c[C+4152>>2]=A;c[C+69688>>2]=A;c[C+135224>>2]=A;A=z+15360|0;c[C+4156>>2]=A;c[C+69692>>2]=A;c[C+135228>>2]=A;A=c[3532008]|0;z=C+4352|0;B=1114112;while(1){y=A+(B-1114112)|0;c[z>>2]=y;c[z+65536>>2]=y;c[z+131072>>2]=y;y=B+1024|0;if(y>>>0>1179647){break}else{z=z+4|0;B=y}}B=c[3532272]|0;c[C+12288>>2]=B;c[C+77824>>2]=B;c[C+143360>>2]=B;z=B+1024|0;c[C+12292>>2]=z;c[C+77828>>2]=z;c[C+143364>>2]=z;z=B+2048|0;c[C+12296>>2]=z;c[C+77832>>2]=z;c[C+143368>>2]=z;z=B+3072|0;c[C+12300>>2]=z;c[C+77836>>2]=z;c[C+143372>>2]=z;z=B+4096|0;c[C+12304>>2]=z;c[C+77840>>2]=z;c[C+143376>>2]=z;z=B+5120|0;c[C+12308>>2]=z;c[C+77844>>2]=z;c[C+143380>>2]=z;z=B+6144|0;c[C+12312>>2]=z;c[C+77848>>2]=z;c[C+143384>>2]=z;z=B+7168|0;c[C+12316>>2]=z;c[C+77852>>2]=z;c[C+143388>>2]=z;z=c[3532593]|0;if((z|0)!=0){gGC(z|0,9104152,280)|0}c[2113061]=c[2113054];c[2394]=-1;e5g();TW(c[3531952]|0,14127792,c[3531946]|0,14127768,3028,908,12);c[2438228]=4e6;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=511;h[146569]=.25;h[118354]=.25;h[85208]=8.0;a[64232]=1;c[3532050]=11826;c[3532118]=11414;c[3532064]=4;c[3532082]=100;c[2113026]=266666;c[2113024]=266666;c[2113022]=66666;z=c[642608+(c[2436]<<2)>>2]|0;C=c[z+128>>2]|0;if((c[z+52>>2]&4|0)==0){c[2113068]=C;B=c[z+132>>2]|0;c[2113070]=B;c[2443814]=C;c[2440436]=B;D=C;E=B}else{c[2113070]=C;B=c[z+132>>2]|0;c[2113068]=B;c[2440436]=C;c[2443814]=B;D=B;E=C}C=ag(D<<1,E)|0;E=gGq(C)|0;c[2112926]=E;if((E|0)!=0){gGz(E|0,0,C|0)}eZ8()|0;c[2438578]=0;c[2405756]=0;v=0;return v|0}function e4m(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4096988+(b*112|0)>>2];c[a+104>>2]=c[4096992+(b*112|0)>>2];c[a+108>>2]=c[4096996+(b*112|0)>>2];d=0;return d|0}function e4n(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=4096888+(b*112|0);e=0;return e|0}function e4o(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3599268+(b*112|0)>>2];c[a+104>>2]=c[3599272+(b*112|0)>>2];c[a+108>>2]=c[3599276+(b*112|0)>>2];d=0;return d|0}function e4p(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=3599168+(b*112|0);e=0;return e|0}function e4q(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>34){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5490488+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e4r(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5426812+(b*112|0)>>2];c[a+104>>2]=c[5426816+(b*112|0)>>2];c[a+108>>2]=c[5426820+(b*112|0)>>2];d=0;return d|0}function e4s(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=5426712+(b*112|0);e=0;return e|0}function e4t(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1942184+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function e4u(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5428952+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e4v(){var b=0,d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;c[3532162]=256;c[3532160]=4;c[3532142]=8;c[3532164]=8;c[3532148]=1983640;c[3532140]=6964216;c[3532138]=6963960;c[3532042]=16384;c[3532002]=512;c[3532e3]=4;a[7460944]=1;c[3532004]=8;c[3531998]=961392;c[3531992]=4969496;c[3531990]=961552;c[3532034]=32768;c[3532044]=2;c[3532030]=1;a[7460960]=1;eZ9(0)|0;c[3532204]=0;b=c[3532200]|0;c[3532198]=b;d=(c[3532194]|0)+b|0;c[3531932]=d;e=d+(c[3531928]|0)|0;c[3531976]=e;f=e+(c[3531972]|0)|0;c[3531952]=f;g=f+(c[3531948]|0)|0;c[3531946]=g;i=g+(c[3531942]|0)|0;j=i|0;c[3532020]=j;c[3532208]=j;j=i+65536|0;c[3532206]=j;k=i+98304|0;c[3532008]=k;l=i+163840|0;c[3531936]=l;m=i+172032|0;c[3531970]=m;n=i+188416|0;c[3532026]=n;o=i+196608|0;p=o|0;c[3532022]=p;c[3532136]=p;p=ag(c[3532142]|0,c[3532042]|0)|0;q=(ag(p,c[3532164]|0)|0)+o|0;c[3531962]=q;p=ag(a[7460944]|0?16:0,c[3532034]|0)|0;r=(ag(p,c[3532004]|0)|0)+q|0;c[3531960]=r;p=ag(a[7460912]|0?16:0,a[7460976]|0?16384:0)|0;s=(ag(p,a[7460936]|0?16:0)|0)+r|0;c[3532028]=s;p=s+16384|0;t=p|0;c[3532046]=t;u=t;t=gGq(u)|0;c[3532048]=t;if((t|0)==0){v=1;return v|0}gGz(t|0,0,u|0);c[3532204]=t;c[3532198]=t+b;c[3531932]=t+d;c[3531976]=t+e;c[3531952]=t+f;c[3531946]=t+g;g=t+i|0;c[3532020]=g;c[3532208]=g;c[3532206]=t+j;c[3532008]=t+k;c[3531936]=t+l;c[3531970]=t+m;c[3532026]=t+n;n=t+o|0;c[3532022]=n;c[3532136]=n;c[3531962]=t+q;c[3531960]=t+r;c[3532028]=t+s;c[3532046]=t+p;p=c[642608+(c[2436]<<2)>>2]|0;t=c[p+128>>2]|0;if((c[p+52>>2]&4|0)==0){c[2113068]=t;s=c[p+132>>2]|0;c[2113070]=s;c[2443814]=t;c[2440436]=s;w=t;x=s}else{c[2113070]=t;s=c[p+132>>2]|0;c[2113068]=s;c[2440436]=t;c[2443814]=s;w=s;x=t}t=ag(w<<1,x)|0;x=gGq(t)|0;c[2112926]=x;if((x|0)!=0){gGz(x|0,0,t|0)}eX5(0,c[3532042]|0,0,16,0,0);t=0;while(1){if((t|0)>=1024){y=0;break}z=9638528+(t<<2)|0;if((c[z>>2]|0)==0){A=42938;break}else{t=t+1|0}}do{if((A|0)==42938){t=gGq(16384)|0;c[z>>2]=t;if((t|0)==0){y=0;break}gGz(t|0,0,16384);y=t}}while(0);c[2442928]=y;gGz(y|0,0,16384);y=0;while(1){if((y|0)>=1024){B=0;break}C=9638528+(y<<2)|0;if((c[C>>2]|0)==0){A=42943;break}else{y=y+1|0}}do{if((A|0)==42943){y=gGq(16384)|0;c[C>>2]=y;if((y|0)==0){B=0;break}gGz(y|0,0,16384);B=y}}while(0);c[3532276]=B;gGz(B|0,0,4096);c[3532274]=4096;a[7461088]=1;B=c[3532010]|0;C=0;while(1){if((C|0)>=1024){D=0;break}E=9638528+(C<<2)|0;if((c[E>>2]|0)==0){A=42948;break}else{C=C+1|0}}do{if((A|0)==42948){C=gGq(B)|0;c[E>>2]=C;if((C|0)==0){D=0;break}gGz(C|0,0,B|0);D=C}}while(0);c[3532270]=D;gGz(D|0,0,B|0);B=0;while(1){if((B|0)>=1024){F=0;break}G=9638528+(B<<2)|0;if((c[G>>2]|0)==0){A=42953;break}else{B=B+1|0}}do{if((A|0)==42953){B=gGq(8192)|0;c[G>>2]=B;if((B|0)==0){F=0;break}gGz(B|0,0,8192);F=B}}while(0);c[3532272]=F;gGz(F|0,0,8192);a[725176]=0;a[7461072]=1;a[7461080]=1;a[7461056]=1;if((eZ9(1)|0)!=0){v=1;return v|0}fxU(0,425984);if((c[2394]|0)==0){H=c[2112932]|0}else{c[2394]=0;F=c[3532596]|0;c[2112932]=F;G=c[3532592]|0;if((G|0)!=0){gGC(9104152,G|0,280)|0}c[2113054]=c[2113060];H=F}F=c[3532204]|0;G=H|0;A=0;while(1){B=F+A|0;c[G>>2]=B;c[G+131072>>2]=B;B=A+1024|0;if(B>>>0>262143){break}else{G=G+4|0;A=B}}A=c[3532208]|0;c[H+4096>>2]=A;c[H+69632>>2]=A;c[H+135168>>2]=A;G=A+1024|0;c[H+4100>>2]=G;c[H+69636>>2]=G;c[H+135172>>2]=G;G=A+2048|0;c[H+4104>>2]=G;c[H+69640>>2]=G;c[H+135176>>2]=G;G=A+3072|0;c[H+4108>>2]=G;c[H+69644>>2]=G;c[H+135180>>2]=G;G=A+4096|0;c[H+4112>>2]=G;c[H+69648>>2]=G;c[H+135184>>2]=G;G=A+5120|0;c[H+4116>>2]=G;c[H+69652>>2]=G;c[H+135188>>2]=G;G=A+6144|0;c[H+4120>>2]=G;c[H+69656>>2]=G;c[H+135192>>2]=G;G=A+7168|0;c[H+4124>>2]=G;c[H+69660>>2]=G;c[H+135196>>2]=G;G=A+8192|0;c[H+4128>>2]=G;c[H+69664>>2]=G;c[H+135200>>2]=G;G=A+9216|0;c[H+4132>>2]=G;c[H+69668>>2]=G;c[H+135204>>2]=G;G=A+10240|0;c[H+4136>>2]=G;c[H+69672>>2]=G;c[H+135208>>2]=G;G=A+11264|0;c[H+4140>>2]=G;c[H+69676>>2]=G;c[H+135212>>2]=G;G=A+12288|0;c[H+4144>>2]=G;c[H+69680>>2]=G;c[H+135216>>2]=G;G=A+13312|0;c[H+4148>>2]=G;c[H+69684>>2]=G;c[H+135220>>2]=G;G=A+14336|0;c[H+4152>>2]=G;c[H+69688>>2]=G;c[H+135224>>2]=G;G=A+15360|0;c[H+4156>>2]=G;c[H+69692>>2]=G;c[H+135228>>2]=G;G=c[3532008]|0;c[H+4160>>2]=G;c[H+69696>>2]=G;c[H+135232>>2]=G;A=G+1024|0;c[H+4164>>2]=A;c[H+69700>>2]=A;c[H+135236>>2]=A;A=G+2048|0;c[H+4168>>2]=A;c[H+69704>>2]=A;c[H+135240>>2]=A;A=G+3072|0;c[H+4172>>2]=A;c[H+69708>>2]=A;c[H+135244>>2]=A;A=G+4096|0;c[H+4176>>2]=A;c[H+69712>>2]=A;c[H+135248>>2]=A;A=G+5120|0;c[H+4180>>2]=A;c[H+69716>>2]=A;c[H+135252>>2]=A;A=G+6144|0;c[H+4184>>2]=A;c[H+69720>>2]=A;c[H+135256>>2]=A;A=G+7168|0;c[H+4188>>2]=A;c[H+69724>>2]=A;c[H+135260>>2]=A;A=G+8192|0;c[H+4192>>2]=A;c[H+69728>>2]=A;c[H+135264>>2]=A;A=G+9216|0;c[H+4196>>2]=A;c[H+69732>>2]=A;c[H+135268>>2]=A;A=G+10240|0;c[H+4200>>2]=A;c[H+69736>>2]=A;c[H+135272>>2]=A;A=G+11264|0;c[H+4204>>2]=A;c[H+69740>>2]=A;c[H+135276>>2]=A;A=G+12288|0;c[H+4208>>2]=A;c[H+69744>>2]=A;c[H+135280>>2]=A;A=G+13312|0;c[H+4212>>2]=A;c[H+69748>>2]=A;c[H+135284>>2]=A;A=G+14336|0;c[H+4216>>2]=A;c[H+69752>>2]=A;c[H+135288>>2]=A;A=G+15360|0;c[H+4220>>2]=A;c[H+69756>>2]=A;c[H+135292>>2]=A;A=c[3531970]|0;c[H+12288>>2]=A;c[H+77824>>2]=A;c[H+143360>>2]=A;G=A+1024|0;c[H+12292>>2]=G;c[H+77828>>2]=G;c[H+143364>>2]=G;G=c[3532272]|0;c[H+16384>>2]=G;c[H+81920>>2]=G;c[H+147456>>2]=G;A=G+1024|0;c[H+16388>>2]=A;c[H+81924>>2]=A;c[H+147460>>2]=A;A=G+2048|0;c[H+16392>>2]=A;c[H+81928>>2]=A;c[H+147464>>2]=A;A=G+3072|0;c[H+16396>>2]=A;c[H+81932>>2]=A;c[H+147468>>2]=A;A=G+4096|0;c[H+16400>>2]=A;c[H+81936>>2]=A;c[H+147472>>2]=A;A=G+5120|0;c[H+16404>>2]=A;c[H+81940>>2]=A;c[H+147476>>2]=A;A=G+6144|0;c[H+16408>>2]=A;c[H+81944>>2]=A;c[H+147480>>2]=A;A=G+7168|0;c[H+16412>>2]=A;c[H+81948>>2]=A;c[H+147484>>2]=A;A=c[3532278]|0;G=H+24576|0;F=6291456;while(1){c[G>>2]=A+(F-6291456);B=F+1024|0;if(B>>>0>6356991){break}else{G=G+4|0;F=B}}c[H+196648>>2]=1946;c[H+196688>>2]=1648;c[H+196728>>2]=284;H=c[3532592]|0;if((H|0)!=0){gGC(H|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fxU(1,425984);if((c[2394]|0)==1){I=c[2112932]|0}else{c[2394]=1;H=c[3532597]|0;c[2112932]=H;F=c[3532593]|0;if((F|0)!=0){gGC(9104152,F|0,280)|0}c[2113054]=c[2113061];I=H}H=c[3532198]|0;F=I|0;G=0;while(1){A=H+G|0;c[F>>2]=A;c[F+131072>>2]=A;A=G+1024|0;if(A>>>0>262143){break}else{F=F+4|0;G=A}}G=c[3532206]|0;c[I+4096>>2]=G;c[I+69632>>2]=G;c[I+135168>>2]=G;F=G+1024|0;c[I+4100>>2]=F;c[I+69636>>2]=F;c[I+135172>>2]=F;F=G+2048|0;c[I+4104>>2]=F;c[I+69640>>2]=F;c[I+135176>>2]=F;F=G+3072|0;c[I+4108>>2]=F;c[I+69644>>2]=F;c[I+135180>>2]=F;F=G+4096|0;c[I+4112>>2]=F;c[I+69648>>2]=F;c[I+135184>>2]=F;F=G+5120|0;c[I+4116>>2]=F;c[I+69652>>2]=F;c[I+135188>>2]=F;F=G+6144|0;c[I+4120>>2]=F;c[I+69656>>2]=F;c[I+135192>>2]=F;F=G+7168|0;c[I+4124>>2]=F;c[I+69660>>2]=F;c[I+135196>>2]=F;F=G+8192|0;c[I+4128>>2]=F;c[I+69664>>2]=F;c[I+135200>>2]=F;F=G+9216|0;c[I+4132>>2]=F;c[I+69668>>2]=F;c[I+135204>>2]=F;F=G+10240|0;c[I+4136>>2]=F;c[I+69672>>2]=F;c[I+135208>>2]=F;F=G+11264|0;c[I+4140>>2]=F;c[I+69676>>2]=F;c[I+135212>>2]=F;F=G+12288|0;c[I+4144>>2]=F;c[I+69680>>2]=F;c[I+135216>>2]=F;F=G+13312|0;c[I+4148>>2]=F;c[I+69684>>2]=F;c[I+135220>>2]=F;F=G+14336|0;c[I+4152>>2]=F;c[I+69688>>2]=F;c[I+135224>>2]=F;F=G+15360|0;c[I+4156>>2]=F;c[I+69692>>2]=F;c[I+135228>>2]=F;F=c[3532008]|0;c[I+4160>>2]=F;c[I+69696>>2]=F;c[I+135232>>2]=F;G=F+1024|0;c[I+4164>>2]=G;c[I+69700>>2]=G;c[I+135236>>2]=G;G=F+2048|0;c[I+4168>>2]=G;c[I+69704>>2]=G;c[I+135240>>2]=G;G=F+3072|0;c[I+4172>>2]=G;c[I+69708>>2]=G;c[I+135244>>2]=G;G=F+4096|0;c[I+4176>>2]=G;c[I+69712>>2]=G;c[I+135248>>2]=G;G=F+5120|0;c[I+4180>>2]=G;c[I+69716>>2]=G;c[I+135252>>2]=G;G=F+6144|0;c[I+4184>>2]=G;c[I+69720>>2]=G;c[I+135256>>2]=G;G=F+7168|0;c[I+4188>>2]=G;c[I+69724>>2]=G;c[I+135260>>2]=G;G=F+8192|0;c[I+4192>>2]=G;c[I+69728>>2]=G;c[I+135264>>2]=G;G=F+9216|0;c[I+4196>>2]=G;c[I+69732>>2]=G;c[I+135268>>2]=G;G=F+10240|0;c[I+4200>>2]=G;c[I+69736>>2]=G;c[I+135272>>2]=G;G=F+11264|0;c[I+4204>>2]=G;c[I+69740>>2]=G;c[I+135276>>2]=G;G=F+12288|0;c[I+4208>>2]=G;c[I+69744>>2]=G;c[I+135280>>2]=G;G=F+13312|0;c[I+4212>>2]=G;c[I+69748>>2]=G;c[I+135284>>2]=G;G=F+14336|0;c[I+4216>>2]=G;c[I+69752>>2]=G;c[I+135288>>2]=G;G=F+15360|0;c[I+4220>>2]=G;c[I+69756>>2]=G;c[I+135292>>2]=G;c[I+196688>>2]=38;c[I+196728>>2]=2920;c[I+196608>>2]=3194;c[I+196648>>2]=50;I=c[3532593]|0;if((I|0)!=0){gGC(I|0,9104152,280)|0}c[2113061]=c[2113054];c[2394]=-1;e5g();TW(c[3531952]|0,14127792,c[3531946]|0,14127768,3028,908,12);c[2438228]=4e6;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=511;h[146569]=.2;h[118354]=.2;h[85208]=20.0;a[64232]=1;c[3532050]=146;c[3532118]=1486;c[3532064]=6;c[3532082]=100;c[2113026]=2e5;c[2113024]=2e5;c[2113022]=66666;eZ8()|0;c[2438578]=0;c[2405756]=0;v=0;return v|0}function e4w(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4007212+(b*112|0)>>2];c[a+104>>2]=c[4007216+(b*112|0)>>2];c[a+108>>2]=c[4007220+(b*112|0)>>2];d=0;return d|0}function e4x(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=4007112+(b*112|0);e=0;return e|0}function e4y(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4009352+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e4z(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1939764+(b*112|0)>>2];c[a+104>>2]=c[1939768+(b*112|0)>>2];c[a+108>>2]=c[1939772+(b*112|0)>>2];d=0;return d|0}function e4A(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=1939664+(b*112|0);e=0;return e|0}function e4B(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1941904+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e4C(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>28){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3663660+(b*112|0)>>2];c[a+104>>2]=c[3663664+(b*112|0)>>2];c[a+108>>2]=c[3663668+(b*112|0)>>2];d=0;return d|0}function e4D(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<29&(d|0)==0)){e=1;return e|0}c[a>>2]=3663560+(b*112|0);e=0;return e|0}function e4E(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1225272+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function e4F(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>41){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3666808+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e4G(){var b=0,d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;c[3532162]=256;c[3532160]=4;c[3532142]=8;c[3532164]=8;c[3532148]=1983640;c[3532140]=6964216;c[3532138]=6963960;c[3532042]=16384;c[3532002]=1024;c[3532e3]=4;a[7460944]=1;c[3532004]=16;c[3531998]=961392;c[3531992]=4969496;c[3531990]=4969048;c[3532034]=16384;a[7460928]=1;a[7460920]=1;a[7460912]=1;a[7460936]=1;c[3531988]=961392;c[3531982]=4969496;c[3531980]=4969048;a[7460976]=1;c[3532044]=2;c[3532030]=1;a[7460960]=1;eZ9(0)|0;c[3532204]=0;b=c[3532200]|0;c[3532198]=b;d=(c[3532194]|0)+b|0;c[3531932]=d;e=d+(c[3531928]|0)|0;c[3531976]=e;f=e+(c[3531972]|0)|0;c[3531952]=f;g=f+(c[3531948]|0)|0;c[3531946]=g;i=g+(c[3531942]|0)|0;j=i|0;c[3532020]=j;c[3532208]=j;j=i+65536|0;c[3532206]=j;k=i+98304|0;c[3532008]=k;l=i+163840|0;c[3531936]=l;m=i+172032|0;c[3531970]=m;n=i+188416|0;c[3532026]=n;o=i+196608|0;p=o|0;c[3532022]=p;c[3532136]=p;p=ag(c[3532142]|0,c[3532042]|0)|0;q=(ag(p,c[3532164]|0)|0)+o|0;c[3531962]=q;p=ag(a[7460944]|0?16:0,c[3532034]|0)|0;r=(ag(p,c[3532004]|0)|0)+q|0;c[3531960]=r;p=ag(a[7460912]|0?16:0,a[7460976]|0?16384:0)|0;s=(ag(p,a[7460936]|0?16:0)|0)+r|0;c[3532028]=s;p=s+16384|0;t=p|0;c[3532046]=t;u=t;t=gGq(u)|0;c[3532048]=t;if((t|0)==0){v=1;return v|0}gGz(t|0,0,u|0);c[3532204]=t;c[3532198]=t+b;c[3531932]=t+d;c[3531976]=t+e;c[3531952]=t+f;c[3531946]=t+g;g=t+i|0;c[3532020]=g;c[3532208]=g;c[3532206]=t+j;c[3532008]=t+k;c[3531936]=t+l;c[3531970]=t+m;c[3532026]=t+n;n=t+o|0;c[3532022]=n;c[3532136]=n;c[3531962]=t+q;c[3531960]=t+r;c[3532028]=t+s;c[3532046]=t+p;p=c[642608+(c[2436]<<2)>>2]|0;t=c[p+128>>2]|0;if((c[p+52>>2]&4|0)==0){c[2113068]=t;s=c[p+132>>2]|0;c[2113070]=s;c[2443814]=t;c[2440436]=s;w=t;x=s}else{c[2113070]=t;s=c[p+132>>2]|0;c[2113068]=s;c[2440436]=t;c[2443814]=s;w=s;x=t}t=ag(w<<1,x)|0;x=gGq(t)|0;c[2112926]=x;if((x|0)!=0){gGz(x|0,0,t|0)}eX5(0,c[3532042]|0,0,8,0,0);t=0;while(1){if((t|0)>=1024){y=0;break}z=9638528+(t<<2)|0;if((c[z>>2]|0)==0){A=43054;break}else{t=t+1|0}}do{if((A|0)==43054){t=gGq(16384)|0;c[z>>2]=t;if((t|0)==0){y=0;break}gGz(t|0,0,16384);y=t}}while(0);c[2442928]=y;gGz(y|0,0,16384);y=0;while(1){if((y|0)>=1024){B=0;break}C=9638528+(y<<2)|0;if((c[C>>2]|0)==0){A=43059;break}else{y=y+1|0}}do{if((A|0)==43059){y=gGq(16384)|0;c[C>>2]=y;if((y|0)==0){B=0;break}gGz(y|0,0,16384);B=y}}while(0);c[3532276]=B;gGz(B|0,0,4096);c[3532274]=4096;a[7461088]=1;B=c[3532010]|0;C=0;while(1){if((C|0)>=1024){D=0;break}E=9638528+(C<<2)|0;if((c[E>>2]|0)==0){A=43064;break}else{C=C+1|0}}do{if((A|0)==43064){C=gGq(B)|0;c[E>>2]=C;if((C|0)==0){D=0;break}gGz(C|0,0,B|0);D=C}}while(0);c[3532270]=D;gGz(D|0,0,B|0);B=0;while(1){if((B|0)>=1024){F=0;break}G=9638528+(B<<2)|0;if((c[G>>2]|0)==0){A=43069;break}else{B=B+1|0}}do{if((A|0)==43069){B=gGq(8192)|0;c[G>>2]=B;if((B|0)==0){F=0;break}gGz(B|0,0,8192);F=B}}while(0);c[3532272]=F;gGz(F|0,0,8192);a[725176]=0;a[7461072]=1;a[7461080]=1;a[7461056]=1;if((eZ9(1)|0)!=0){v=1;return v|0}fxU(0,425984);if((c[2394]|0)==0){H=c[2112932]|0}else{c[2394]=0;F=c[3532596]|0;c[2112932]=F;G=c[3532592]|0;if((G|0)!=0){gGC(9104152,G|0,280)|0}c[2113054]=c[2113060];H=F}F=c[3532204]|0;G=H|0;A=0;while(1){B=F+A|0;c[G>>2]=B;c[G+131072>>2]=B;B=A+1024|0;if(B>>>0>524287){break}else{G=G+4|0;A=B}}A=c[3532208]|0;G=H+4096|0;F=1048576;while(1){B=A+(F-1048576)|0;c[G>>2]=B;c[G+65536>>2]=B;c[G+131072>>2]=B;B=F+1024|0;if(B>>>0>1114111){break}else{G=G+4|0;F=B}}F=c[3532008]|0;c[H+4352>>2]=F;c[H+69888>>2]=F;c[H+135424>>2]=F;G=F+1024|0;c[H+4356>>2]=G;c[H+69892>>2]=G;c[H+135428>>2]=G;G=F+2048|0;c[H+4360>>2]=G;c[H+69896>>2]=G;c[H+135432>>2]=G;G=F+3072|0;c[H+4364>>2]=G;c[H+69900>>2]=G;c[H+135436>>2]=G;G=F+4096|0;c[H+4368>>2]=G;c[H+69904>>2]=G;c[H+135440>>2]=G;G=F+5120|0;c[H+4372>>2]=G;c[H+69908>>2]=G;c[H+135444>>2]=G;G=F+6144|0;c[H+4376>>2]=G;c[H+69912>>2]=G;c[H+135448>>2]=G;G=F+7168|0;c[H+4380>>2]=G;c[H+69916>>2]=G;c[H+135452>>2]=G;G=F+8192|0;c[H+4384>>2]=G;c[H+69920>>2]=G;c[H+135456>>2]=G;G=F+9216|0;c[H+4388>>2]=G;c[H+69924>>2]=G;c[H+135460>>2]=G;G=F+10240|0;c[H+4392>>2]=G;c[H+69928>>2]=G;c[H+135464>>2]=G;G=F+11264|0;c[H+4396>>2]=G;c[H+69932>>2]=G;c[H+135468>>2]=G;G=F+12288|0;c[H+4400>>2]=G;c[H+69936>>2]=G;c[H+135472>>2]=G;G=F+13312|0;c[H+4404>>2]=G;c[H+69940>>2]=G;c[H+135476>>2]=G;G=F+14336|0;c[H+4408>>2]=G;c[H+69944>>2]=G;c[H+135480>>2]=G;G=F+15360|0;c[H+4412>>2]=G;c[H+69948>>2]=G;c[H+135484>>2]=G;G=c[3532278]|0;F=H+49152|0;A=12582912;while(1){c[F>>2]=G+(A-12582912);B=A+1024|0;if(B>>>0>12648447){break}else{F=F+4|0;A=B}}A=c[3531970]|0;c[H+53248>>2]=A;c[H+118784>>2]=A;c[H+184320>>2]=A;F=A+1024|0;c[H+53252>>2]=F;c[H+118788>>2]=F;c[H+184324>>2]=F;c[H+196688>>2]=1132;c[H+196728>>2]=1736;c[H+196608>>2]=3410;c[H+196648>>2]=2958;H=c[3532592]|0;if((H|0)!=0){gGC(H|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fxU(1,425984);if((c[2394]|0)==1){I=c[2112932]|0}else{c[2394]=1;H=c[3532597]|0;c[2112932]=H;F=c[3532593]|0;if((F|0)!=0){gGC(9104152,F|0,280)|0}c[2113054]=c[2113061];I=H}H=c[3532198]|0;F=I|0;A=0;while(1){G=H+A|0;c[F>>2]=G;c[F+131072>>2]=G;G=A+1024|0;if(G>>>0>262143){break}else{F=F+4|0;A=G}}A=c[3532206]|0;c[I+4096>>2]=A;c[I+69632>>2]=A;c[I+135168>>2]=A;F=A+1024|0;c[I+4100>>2]=F;c[I+69636>>2]=F;c[I+135172>>2]=F;F=A+2048|0;c[I+4104>>2]=F;c[I+69640>>2]=F;c[I+135176>>2]=F;F=A+3072|0;c[I+4108>>2]=F;c[I+69644>>2]=F;c[I+135180>>2]=F;F=A+4096|0;c[I+4112>>2]=F;c[I+69648>>2]=F;c[I+135184>>2]=F;F=A+5120|0;c[I+4116>>2]=F;c[I+69652>>2]=F;c[I+135188>>2]=F;F=A+6144|0;c[I+4120>>2]=F;c[I+69656>>2]=F;c[I+135192>>2]=F;F=A+7168|0;c[I+4124>>2]=F;c[I+69660>>2]=F;c[I+135196>>2]=F;F=A+8192|0;c[I+4128>>2]=F;c[I+69664>>2]=F;c[I+135200>>2]=F;F=A+9216|0;c[I+4132>>2]=F;c[I+69668>>2]=F;c[I+135204>>2]=F;F=A+10240|0;c[I+4136>>2]=F;c[I+69672>>2]=F;c[I+135208>>2]=F;F=A+11264|0;c[I+4140>>2]=F;c[I+69676>>2]=F;c[I+135212>>2]=F;F=A+12288|0;c[I+4144>>2]=F;c[I+69680>>2]=F;c[I+135216>>2]=F;F=A+13312|0;c[I+4148>>2]=F;c[I+69684>>2]=F;c[I+135220>>2]=F;F=A+14336|0;c[I+4152>>2]=F;c[I+69688>>2]=F;c[I+135224>>2]=F;F=A+15360|0;c[I+4156>>2]=F;c[I+69692>>2]=F;c[I+135228>>2]=F;F=c[3532008]|0;c[I+4160>>2]=F;c[I+69696>>2]=F;c[I+135232>>2]=F;A=F+1024|0;c[I+4164>>2]=A;c[I+69700>>2]=A;c[I+135236>>2]=A;A=F+2048|0;c[I+4168>>2]=A;c[I+69704>>2]=A;c[I+135240>>2]=A;A=F+3072|0;c[I+4172>>2]=A;c[I+69708>>2]=A;c[I+135244>>2]=A;A=F+4096|0;c[I+4176>>2]=A;c[I+69712>>2]=A;c[I+135248>>2]=A;A=F+5120|0;c[I+4180>>2]=A;c[I+69716>>2]=A;c[I+135252>>2]=A;A=F+6144|0;c[I+4184>>2]=A;c[I+69720>>2]=A;c[I+135256>>2]=A;A=F+7168|0;c[I+4188>>2]=A;c[I+69724>>2]=A;c[I+135260>>2]=A;A=F+8192|0;c[I+4192>>2]=A;c[I+69728>>2]=A;c[I+135264>>2]=A;A=F+9216|0;c[I+4196>>2]=A;c[I+69732>>2]=A;c[I+135268>>2]=A;A=F+10240|0;c[I+4200>>2]=A;c[I+69736>>2]=A;c[I+135272>>2]=A;A=F+11264|0;c[I+4204>>2]=A;c[I+69740>>2]=A;c[I+135276>>2]=A;A=F+12288|0;c[I+4208>>2]=A;c[I+69744>>2]=A;c[I+135280>>2]=A;A=F+13312|0;c[I+4212>>2]=A;c[I+69748>>2]=A;c[I+135284>>2]=A;A=F+14336|0;c[I+4216>>2]=A;c[I+69752>>2]=A;c[I+135288>>2]=A;A=F+15360|0;c[I+4220>>2]=A;c[I+69756>>2]=A;c[I+135292>>2]=A;A=c[3532272]|0;c[I+32768>>2]=A;c[I+98304>>2]=A;c[I+163840>>2]=A;F=A+1024|0;c[I+32772>>2]=F;c[I+98308>>2]=F;c[I+163844>>2]=F;F=A+2048|0;c[I+32776>>2]=F;c[I+98312>>2]=F;c[I+163848>>2]=F;F=A+3072|0;c[I+32780>>2]=F;c[I+98316>>2]=F;c[I+163852>>2]=F;F=A+4096|0;c[I+32784>>2]=F;c[I+98320>>2]=F;c[I+163856>>2]=F;F=A+5120|0;c[I+32788>>2]=F;c[I+98324>>2]=F;c[I+163860>>2]=F;F=A+6144|0;c[I+32792>>2]=F;c[I+98328>>2]=F;c[I+163864>>2]=F;F=A+7168|0;c[I+32796>>2]=F;c[I+98332>>2]=F;c[I+163868>>2]=F;F=c[3532593]|0;if((F|0)!=0){gGC(F|0,9104152,280)|0}c[2113061]=c[2113054];c[2394]=-1;e5g();TW(c[3531952]|0,14127792,c[3531946]|0,14127768,3028,908,12);c[2438228]=4e6;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=511;h[146569]=.2;h[118354]=.2;h[85208]=1.0;a[64232]=1;c[3532050]=7762;c[3532118]=6706;c[3532064]=4;c[3532082]=100;c[2113026]=2e5;c[2113024]=2e5;c[2113022]=66666;eZ8()|0;c[2438578]=0;c[2405756]=0;v=0;return v|0}function e4H(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>28){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1807316+(b*112|0)>>2];c[a+104>>2]=c[1807320+(b*112|0)>>2];c[a+108>>2]=c[1807324+(b*112|0)>>2];d=0;return d|0}function e4I(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<29&(d|0)==0)){e=1;return e|0}c[a>>2]=1807216+(b*112|0);e=0;return e|0}function e4J(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>41){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1810464+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e4K(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>28){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1803564+(b*112|0)>>2];c[a+104>>2]=c[1803568+(b*112|0)>>2];c[a+108>>2]=c[1803572+(b*112|0)>>2];d=0;return d|0}function e4L(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<29&(d|0)==0)){e=1;return e|0}c[a>>2]=1803464+(b*112|0);e=0;return e|0}function e4M(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>41){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1806712+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e4N(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5118332+(b*112|0)>>2];c[a+104>>2]=c[5118336+(b*112|0)>>2];c[a+108>>2]=c[5118340+(b*112|0)>>2];d=0;return d|0}function e4O(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=5118232+(b*112|0);e=0;return e|0}function e4P(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1760736+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function e4Q(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>34){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5120808+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e4R(){var b=0,d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;a[681304]=1;c[3532162]=1024;c[3532160]=4;c[3532142]=16;c[3532164]=16;c[3532148]=688432;c[3532140]=818264;c[3532138]=818200;c[3532042]=8192;c[3532002]=512;c[3532e3]=4;a[7460944]=1;c[3532004]=8;c[3531998]=961392;c[3531992]=4969496;c[3531990]=961552;c[3532034]=65536;c[3532044]=2;c[3532030]=1;a[7460960]=1;eZ9(0)|0;c[3532204]=0;b=c[3532200]|0;c[3532198]=b;d=(c[3532194]|0)+b|0;c[3531932]=d;e=d+(c[3531928]|0)|0;c[3531976]=e;f=e+(c[3531972]|0)|0;c[3531952]=f;g=f+(c[3531948]|0)|0;c[3531946]=g;i=g+(c[3531942]|0)|0;j=i|0;c[3532020]=j;c[3532208]=j;j=i+65536|0;c[3532206]=j;k=i+98304|0;c[3532008]=k;l=i+163840|0;c[3531936]=l;m=i+172032|0;c[3531970]=m;n=i+188416|0;c[3532026]=n;o=i+196608|0;p=o|0;c[3532022]=p;c[3532136]=p;p=ag(c[3532142]|0,c[3532042]|0)|0;q=(ag(p,c[3532164]|0)|0)+o|0;c[3531962]=q;p=ag(a[7460944]|0?16:0,c[3532034]|0)|0;r=(ag(p,c[3532004]|0)|0)+q|0;c[3531960]=r;p=ag(a[7460912]|0?16:0,a[7460976]|0?16384:0)|0;s=(ag(p,a[7460936]|0?16:0)|0)+r|0;c[3532028]=s;p=s+16384|0;t=p|0;c[3532046]=t;u=t;t=gGq(u)|0;c[3532048]=t;if((t|0)==0){v=1;return v|0}gGz(t|0,0,u|0);c[3532204]=t;c[3532198]=t+b;c[3531932]=t+d;c[3531976]=t+e;c[3531952]=t+f;c[3531946]=t+g;g=t+i|0;c[3532020]=g;c[3532208]=g;c[3532206]=t+j;c[3532008]=t+k;c[3531936]=t+l;c[3531970]=t+m;c[3532026]=t+n;n=t+o|0;c[3532022]=n;c[3532136]=n;c[3531962]=t+q;c[3531960]=t+r;c[3532028]=t+s;c[3532046]=t+p;p=c[3532010]|0;t=0;while(1){if((t|0)>=1024){w=0;break}x=9638528+(t<<2)|0;if((c[x>>2]|0)==0){y=43167;break}else{t=t+1|0}}do{if((y|0)==43167){t=gGq(p)|0;c[x>>2]=t;if((t|0)==0){w=0;break}gGz(t|0,0,p|0);w=t}}while(0);c[3532270]=w;gGz(w|0,0,p|0);p=0;while(1){if((p|0)>=1024){z=0;break}A=9638528+(p<<2)|0;if((c[A>>2]|0)==0){y=43172;break}else{p=p+1|0}}do{if((y|0)==43172){p=gGq(8192)|0;c[A>>2]=p;if((p|0)==0){z=0;break}gGz(p|0,0,8192);z=p}}while(0);c[3532272]=z;gGz(z|0,0,8192);a[725176]=0;a[7461072]=1;eXS(c[3532042]|0,0,31,8,4,0,0);a[7461080]=1;a[7461016]=1;if((eZ9(1)|0)!=0){v=1;return v|0}fxU(0,425984);if((c[2394]|0)==0){B=c[2112932]|0}else{c[2394]=0;z=c[3532596]|0;c[2112932]=z;A=c[3532592]|0;if((A|0)!=0){gGC(9104152,A|0,280)|0}c[2113054]=c[2113060];B=z}z=c[3532204]|0;A=B|0;y=0;while(1){p=z+y|0;c[A>>2]=p;c[A+131072>>2]=p;p=y+1024|0;if(p>>>0>524287){break}else{A=A+4|0;y=p}}y=c[3532208]|0;c[B+4096>>2]=y;c[B+69632>>2]=y;c[B+135168>>2]=y;A=y+1024|0;c[B+4100>>2]=A;c[B+69636>>2]=A;c[B+135172>>2]=A;A=y+2048|0;c[B+4104>>2]=A;c[B+69640>>2]=A;c[B+135176>>2]=A;A=y+3072|0;c[B+4108>>2]=A;c[B+69644>>2]=A;c[B+135180>>2]=A;A=y+4096|0;c[B+4112>>2]=A;c[B+69648>>2]=A;c[B+135184>>2]=A;A=y+5120|0;c[B+4116>>2]=A;c[B+69652>>2]=A;c[B+135188>>2]=A;A=y+6144|0;c[B+4120>>2]=A;c[B+69656>>2]=A;c[B+135192>>2]=A;A=y+7168|0;c[B+4124>>2]=A;c[B+69660>>2]=A;c[B+135196>>2]=A;A=y+8192|0;c[B+4128>>2]=A;c[B+69664>>2]=A;c[B+135200>>2]=A;A=y+9216|0;c[B+4132>>2]=A;c[B+69668>>2]=A;c[B+135204>>2]=A;A=y+10240|0;c[B+4136>>2]=A;c[B+69672>>2]=A;c[B+135208>>2]=A;A=y+11264|0;c[B+4140>>2]=A;c[B+69676>>2]=A;c[B+135212>>2]=A;A=y+12288|0;c[B+4144>>2]=A;c[B+69680>>2]=A;c[B+135216>>2]=A;A=y+13312|0;c[B+4148>>2]=A;c[B+69684>>2]=A;c[B+135220>>2]=A;A=y+14336|0;c[B+4152>>2]=A;c[B+69688>>2]=A;c[B+135224>>2]=A;A=y+15360|0;c[B+4156>>2]=A;c[B+69692>>2]=A;c[B+135228>>2]=A;A=c[3532008]|0;y=B+4352|0;z=1114112;while(1){p=A+(z-1114112)|0;c[y>>2]=p;c[y+65536>>2]=p;c[y+131072>>2]=p;p=z+1024|0;if(p>>>0>1179647){break}else{y=y+4|0;z=p}}z=c[3532026]|0;c[B+28672>>2]=z;c[B+94208>>2]=z;c[B+159744>>2]=z;y=z+1024|0;c[B+28676>>2]=y;c[B+94212>>2]=y;c[B+159748>>2]=y;y=z+2048|0;c[B+28680>>2]=y;c[B+94216>>2]=y;c[B+159752>>2]=y;y=z+3072|0;c[B+28684>>2]=y;c[B+94220>>2]=y;c[B+159756>>2]=y;y=z+4096|0;c[B+28688>>2]=y;c[B+94224>>2]=y;c[B+159760>>2]=y;y=z+5120|0;c[B+28692>>2]=y;c[B+94228>>2]=y;c[B+159764>>2]=y;y=z+6144|0;c[B+28696>>2]=y;c[B+94232>>2]=y;c[B+159768>>2]=y;y=z+7168|0;c[B+28700>>2]=y;c[B+94236>>2]=y;c[B+159772>>2]=y;y=c[3532232]|0;z=B+36864|0;A=9437184;while(1){p=y+(A-9437184)|0;c[z>>2]=p;c[z+65536>>2]=p;c[z+131072>>2]=p;p=A+1024|0;if(p>>>0>9502719){break}else{z=z+4|0;A=p}}A=c[3531970]|0;c[B+45056>>2]=A;c[B+110592>>2]=A;c[B+176128>>2]=A;z=A+1024|0;c[B+45060>>2]=z;c[B+110596>>2]=z;c[B+176132>>2]=z;z=A+2048|0;c[B+45064>>2]=z;c[B+110600>>2]=z;c[B+176136>>2]=z;z=A+3072|0;c[B+45068>>2]=z;c[B+110604>>2]=z;c[B+176140>>2]=z;z=A+4096|0;c[B+45072>>2]=z;c[B+110608>>2]=z;c[B+176144>>2]=z;z=A+5120|0;c[B+45076>>2]=z;c[B+110612>>2]=z;c[B+176148>>2]=z;z=A+6144|0;c[B+45080>>2]=z;c[B+110616>>2]=z;c[B+176152>>2]=z;z=A+7168|0;c[B+45084>>2]=z;c[B+110620>>2]=z;c[B+176156>>2]=z;z=A+8192|0;c[B+45088>>2]=z;c[B+110624>>2]=z;c[B+176160>>2]=z;z=A+9216|0;c[B+45092>>2]=z;c[B+110628>>2]=z;c[B+176164>>2]=z;z=A+10240|0;c[B+45096>>2]=z;c[B+110632>>2]=z;c[B+176168>>2]=z;z=A+11264|0;c[B+45100>>2]=z;c[B+110636>>2]=z;c[B+176172>>2]=z;z=A+12288|0;c[B+45104>>2]=z;c[B+110640>>2]=z;c[B+176176>>2]=z;z=A+13312|0;c[B+45108>>2]=z;c[B+110644>>2]=z;c[B+176180>>2]=z;z=A+14336|0;c[B+45112>>2]=z;c[B+110648>>2]=z;c[B+176184>>2]=z;z=A+15360|0;c[B+45116>>2]=z;c[B+110652>>2]=z;c[B+176188>>2]=z;c[B+196688>>2]=1292;c[B+196728>>2]=384;c[B+196608>>2]=490;c[B+196648>>2]=1204;B=c[3532592]|0;if((B|0)!=0){gGC(B|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fxU(1,425984);if((c[2394]|0)==1){C=c[2112932]|0}else{c[2394]=1;B=c[3532597]|0;c[2112932]=B;z=c[3532593]|0;if((z|0)!=0){gGC(9104152,z|0,280)|0}c[2113054]=c[2113061];C=B}B=c[3532198]|0;z=C|0;A=0;while(1){y=B+A|0;c[z>>2]=y;c[z+131072>>2]=y;y=A+1024|0;if(y>>>0>262143){break}else{z=z+4|0;A=y}}A=c[3532206]|0;c[C+16384>>2]=A;c[C+81920>>2]=A;c[C+147456>>2]=A;z=A+1024|0;c[C+16388>>2]=z;c[C+81924>>2]=z;c[C+147460>>2]=z;z=A+2048|0;c[C+16392>>2]=z;c[C+81928>>2]=z;c[C+147464>>2]=z;z=A+3072|0;c[C+16396>>2]=z;c[C+81932>>2]=z;c[C+147468>>2]=z;z=A+4096|0;c[C+16400>>2]=z;c[C+81936>>2]=z;c[C+147472>>2]=z;z=A+5120|0;c[C+16404>>2]=z;c[C+81940>>2]=z;c[C+147476>>2]=z;z=A+6144|0;c[C+16408>>2]=z;c[C+81944>>2]=z;c[C+147480>>2]=z;z=A+7168|0;c[C+16412>>2]=z;c[C+81948>>2]=z;c[C+147484>>2]=z;z=A+8192|0;c[C+16416>>2]=z;c[C+81952>>2]=z;c[C+147488>>2]=z;z=A+9216|0;c[C+16420>>2]=z;c[C+81956>>2]=z;c[C+147492>>2]=z;z=A+10240|0;c[C+16424>>2]=z;c[C+81960>>2]=z;c[C+147496>>2]=z;z=A+11264|0;c[C+16428>>2]=z;c[C+81964>>2]=z;c[C+147500>>2]=z;z=A+12288|0;c[C+16432>>2]=z;c[C+81968>>2]=z;c[C+147504>>2]=z;z=A+13312|0;c[C+16436>>2]=z;c[C+81972>>2]=z;c[C+147508>>2]=z;z=A+14336|0;c[C+16440>>2]=z;c[C+81976>>2]=z;c[C+147512>>2]=z;z=A+15360|0;c[C+16444>>2]=z;c[C+81980>>2]=z;c[C+147516>>2]=z;z=c[3532008]|0;A=C+16640|0;B=4259840;while(1){y=z+(B-4259840)|0;c[A>>2]=y;c[A+65536>>2]=y;c[A+131072>>2]=y;y=B+1024|0;if(y>>>0>4325375){break}else{A=A+4|0;B=y}}B=c[3532272]|0;c[C+40960>>2]=B;c[C+106496>>2]=B;c[C+172032>>2]=B;A=B+1024|0;c[C+40964>>2]=A;c[C+106500>>2]=A;c[C+172036>>2]=A;A=B+2048|0;c[C+40968>>2]=A;c[C+106504>>2]=A;c[C+172040>>2]=A;A=B+3072|0;c[C+40972>>2]=A;c[C+106508>>2]=A;c[C+172044>>2]=A;A=B+4096|0;c[C+40976>>2]=A;c[C+106512>>2]=A;c[C+172048>>2]=A;A=B+5120|0;c[C+40980>>2]=A;c[C+106516>>2]=A;c[C+172052>>2]=A;A=B+6144|0;c[C+40984>>2]=A;c[C+106520>>2]=A;c[C+172056>>2]=A;A=B+7168|0;c[C+40988>>2]=A;c[C+106524>>2]=A;c[C+172060>>2]=A;A=c[3532593]|0;if((A|0)!=0){gGC(A|0,9104152,280)|0}c[2113061]=c[2113054];c[2394]=-1;e5g();TW(c[3531952]|0,14127792,c[3531946]|0,14127768,3028,908,12);c[2438228]=4e6;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=511;h[146569]=.25;h[118354]=.25;h[85208]=8.0;a[64232]=1;c[3532050]=11826;c[3532118]=6760;c[3532064]=4;c[3532082]=100;c[2113026]=266666;c[2113024]=266666;c[2113022]=66666;A=c[642608+(c[2436]<<2)>>2]|0;C=c[A+128>>2]|0;if((c[A+52>>2]&4|0)==0){c[2113068]=C;B=c[A+132>>2]|0;c[2113070]=B;c[2443814]=C;c[2440436]=B;D=C;E=B}else{c[2113070]=C;B=c[A+132>>2]|0;c[2113068]=B;c[2440436]=C;c[2443814]=B;D=B;E=C}C=ag(D<<1,E)|0;E=gGq(C)|0;c[2112926]=E;if((E|0)!=0){gGz(E|0,0,C|0)}eZ8()|0;c[2438578]=0;c[2405756]=0;v=0;return v|0}function e4S(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7381028+(b*112|0)>>2];c[a+104>>2]=c[7381032+(b*112|0)>>2];c[a+108>>2]=c[7381036+(b*112|0)>>2];d=0;return d|0}function e4T(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<21&(d|0)==0)){e=1;return e|0}c[a>>2]=7380928+(b*112|0);e=0;return e|0}function e4U(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6808856+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function e4V(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>42){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7383280+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e4W(){var b=0,d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;a[681304]=1;c[3532162]=256;c[3532160]=4;c[3532142]=8;c[3532164]=8;c[3532148]=1983640;c[3532140]=6964216;c[3532138]=6963960;c[3532042]=16384;c[3532002]=512;c[3532e3]=4;a[7460944]=1;c[3532004]=8;c[3531998]=961392;c[3531992]=4969496;c[3531990]=961552;c[3532034]=32768;c[3532044]=2;c[3532030]=1;a[7460960]=1;eZ9(0)|0;c[3532204]=0;b=c[3532200]|0;c[3532198]=b;d=(c[3532194]|0)+b|0;c[3531932]=d;e=d+(c[3531928]|0)|0;c[3531976]=e;f=e+(c[3531972]|0)|0;c[3531952]=f;g=f+(c[3531948]|0)|0;c[3531946]=g;i=g+(c[3531942]|0)|0;j=i|0;c[3532020]=j;c[3532208]=j;j=i+65536|0;c[3532206]=j;k=i+98304|0;c[3532008]=k;l=i+163840|0;c[3531936]=l;m=i+172032|0;c[3531970]=m;n=i+188416|0;c[3532026]=n;o=i+196608|0;p=o|0;c[3532022]=p;c[3532136]=p;p=ag(c[3532142]|0,c[3532042]|0)|0;q=(ag(p,c[3532164]|0)|0)+o|0;c[3531962]=q;p=ag(a[7460944]|0?16:0,c[3532034]|0)|0;r=(ag(p,c[3532004]|0)|0)+q|0;c[3531960]=r;p=ag(a[7460912]|0?16:0,a[7460976]|0?16384:0)|0;s=(ag(p,a[7460936]|0?16:0)|0)+r|0;c[3532028]=s;p=s+16384|0;t=p|0;c[3532046]=t;u=t;t=gGq(u)|0;c[3532048]=t;if((t|0)==0){v=1;return v|0}gGz(t|0,0,u|0);c[3532204]=t;c[3532198]=t+b;c[3531932]=t+d;c[3531976]=t+e;c[3531952]=t+f;c[3531946]=t+g;g=t+i|0;c[3532020]=g;c[3532208]=g;c[3532206]=t+j;c[3532008]=t+k;c[3531936]=t+l;c[3531970]=t+m;c[3532026]=t+n;n=t+o|0;c[3532022]=n;c[3532136]=n;c[3531962]=t+q;c[3531960]=t+r;c[3532028]=t+s;c[3532046]=t+p;p=c[642608+(c[2436]<<2)>>2]|0;t=c[p+128>>2]|0;if((c[p+52>>2]&4|0)==0){c[2113068]=t;s=c[p+132>>2]|0;c[2113070]=s;c[2443814]=t;c[2440436]=s;w=t;x=s}else{c[2113070]=t;s=c[p+132>>2]|0;c[2113068]=s;c[2440436]=t;c[2443814]=s;w=s;x=t}t=ag(w<<1,x)|0;x=gGq(t)|0;c[2112926]=x;if((x|0)!=0){gGz(x|0,0,t|0)}eX5(0,c[3532042]|0,0,8,0,0);t=c[3532010]|0;x=0;while(1){if((x|0)>=1024){y=0;break}z=9638528+(x<<2)|0;if((c[z>>2]|0)==0){A=43244;break}else{x=x+1|0}}do{if((A|0)==43244){x=gGq(t)|0;c[z>>2]=x;if((x|0)==0){y=0;break}gGz(x|0,0,t|0);y=x}}while(0);c[3532270]=y;gGz(y|0,0,t|0);t=0;while(1){if((t|0)>=1024){B=0;break}C=9638528+(t<<2)|0;if((c[C>>2]|0)==0){A=43249;break}else{t=t+1|0}}do{if((A|0)==43249){t=gGq(8192)|0;c[C>>2]=t;if((t|0)==0){B=0;break}gGz(t|0,0,8192);B=t}}while(0);c[3532272]=B;gGz(B|0,0,8192);a[725176]=0;a[7461072]=1;a[7461080]=1;a[7461056]=1;if((eZ9(1)|0)!=0){v=1;return v|0}fxU(0,425984);if((c[2394]|0)==0){D=c[2112932]|0}else{c[2394]=0;B=c[3532596]|0;c[2112932]=B;C=c[3532592]|0;if((C|0)!=0){gGC(9104152,C|0,280)|0}c[2113054]=c[2113060];D=B}B=c[3532204]|0;C=D|0;A=0;while(1){t=B+A|0;c[C>>2]=t;c[C+131072>>2]=t;t=A+1024|0;if(t>>>0>524287){break}else{C=C+4|0;A=t}}A=c[3532208]|0;C=D+4096|0;B=1048576;while(1){t=A+(B-1048576)|0;c[C>>2]=t;c[C+65536>>2]=t;c[C+131072>>2]=t;t=B+1024|0;if(t>>>0>1081343){break}else{C=C+4|0;B=t}}B=c[3532008]|0;c[D+4224>>2]=B;c[D+69760>>2]=B;c[D+135296>>2]=B;C=B+1024|0;c[D+4228>>2]=C;c[D+69764>>2]=C;c[D+135300>>2]=C;C=B+2048|0;c[D+4232>>2]=C;c[D+69768>>2]=C;c[D+135304>>2]=C;C=B+3072|0;c[D+4236>>2]=C;c[D+69772>>2]=C;c[D+135308>>2]=C;C=B+4096|0;c[D+4240>>2]=C;c[D+69776>>2]=C;c[D+135312>>2]=C;C=B+5120|0;c[D+4244>>2]=C;c[D+69780>>2]=C;c[D+135316>>2]=C;C=B+6144|0;c[D+4248>>2]=C;c[D+69784>>2]=C;c[D+135320>>2]=C;C=B+7168|0;c[D+4252>>2]=C;c[D+69788>>2]=C;c[D+135324>>2]=C;C=B+8192|0;c[D+4256>>2]=C;c[D+69792>>2]=C;c[D+135328>>2]=C;C=B+9216|0;c[D+4260>>2]=C;c[D+69796>>2]=C;c[D+135332>>2]=C;C=B+10240|0;c[D+4264>>2]=C;c[D+69800>>2]=C;c[D+135336>>2]=C;C=B+11264|0;c[D+4268>>2]=C;c[D+69804>>2]=C;c[D+135340>>2]=C;C=B+12288|0;c[D+4272>>2]=C;c[D+69808>>2]=C;c[D+135344>>2]=C;C=B+13312|0;c[D+4276>>2]=C;c[D+69812>>2]=C;c[D+135348>>2]=C;C=B+14336|0;c[D+4280>>2]=C;c[D+69816>>2]=C;c[D+135352>>2]=C;C=B+15360|0;c[D+4284>>2]=C;c[D+69820>>2]=C;c[D+135356>>2]=C;C=c[3532026]|0;c[D+32768>>2]=C;c[D+98304>>2]=C;c[D+163840>>2]=C;B=C+1024|0;c[D+32772>>2]=B;c[D+98308>>2]=B;c[D+163844>>2]=B;B=C+2048|0;c[D+32776>>2]=B;c[D+98312>>2]=B;c[D+163848>>2]=B;B=C+3072|0;c[D+32780>>2]=B;c[D+98316>>2]=B;c[D+163852>>2]=B;B=C+4096|0;c[D+32784>>2]=B;c[D+98320>>2]=B;c[D+163856>>2]=B;B=C+5120|0;c[D+32788>>2]=B;c[D+98324>>2]=B;c[D+163860>>2]=B;B=C+6144|0;c[D+32792>>2]=B;c[D+98328>>2]=B;c[D+163864>>2]=B;B=C+7168|0;c[D+32796>>2]=B;c[D+98332>>2]=B;c[D+163868>>2]=B;B=c[3532278]|0;C=D+40960|0;A=10485760;while(1){c[C>>2]=B+(A-10485760);t=A+1024|0;if(t>>>0>10551295){break}else{C=C+4|0;A=t}}A=c[3531970]|0;c[D+49152>>2]=A;c[D+114688>>2]=A;c[D+180224>>2]=A;C=A+1024|0;c[D+49156>>2]=C;c[D+114692>>2]=C;c[D+180228>>2]=C;C=A+2048|0;c[D+49160>>2]=C;c[D+114696>>2]=C;c[D+180232>>2]=C;C=A+3072|0;c[D+49164>>2]=C;c[D+114700>>2]=C;c[D+180236>>2]=C;C=A+4096|0;c[D+49168>>2]=C;c[D+114704>>2]=C;c[D+180240>>2]=C;C=A+5120|0;c[D+49172>>2]=C;c[D+114708>>2]=C;c[D+180244>>2]=C;C=A+6144|0;c[D+49176>>2]=C;c[D+114712>>2]=C;c[D+180248>>2]=C;C=A+7168|0;c[D+49180>>2]=C;c[D+114716>>2]=C;c[D+180252>>2]=C;C=A+8192|0;c[D+49184>>2]=C;c[D+114720>>2]=C;c[D+180256>>2]=C;C=A+9216|0;c[D+49188>>2]=C;c[D+114724>>2]=C;c[D+180260>>2]=C;C=A+10240|0;c[D+49192>>2]=C;c[D+114728>>2]=C;c[D+180264>>2]=C;C=A+11264|0;c[D+49196>>2]=C;c[D+114732>>2]=C;c[D+180268>>2]=C;C=A+12288|0;c[D+49200>>2]=C;c[D+114736>>2]=C;c[D+180272>>2]=C;C=A+13312|0;c[D+49204>>2]=C;c[D+114740>>2]=C;c[D+180276>>2]=C;C=A+14336|0;c[D+49208>>2]=C;c[D+114744>>2]=C;c[D+180280>>2]=C;C=A+15360|0;c[D+49212>>2]=C;c[D+114748>>2]=C;c[D+180284>>2]=C;c[D+196728>>2]=616;c[D+196608>>2]=1782;c[D+196648>>2]=2412;D=c[3532592]|0;if((D|0)!=0){gGC(D|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fxU(1,425984);if((c[2394]|0)==1){E=c[2112932]|0}else{c[2394]=1;D=c[3532597]|0;c[2112932]=D;C=c[3532593]|0;if((C|0)!=0){gGC(9104152,C|0,280)|0}c[2113054]=c[2113061];E=D}D=c[3532198]|0;C=E|0;A=0;while(1){B=D+A|0;c[C>>2]=B;c[C+131072>>2]=B;B=A+1024|0;if(B>>>0>131071){break}else{C=C+4|0;A=B}}A=c[3532206]|0;c[E+8192>>2]=A;c[E+73728>>2]=A;c[E+139264>>2]=A;C=A+1024|0;c[E+8196>>2]=C;c[E+73732>>2]=C;c[E+139268>>2]=C;C=A+2048|0;c[E+8200>>2]=C;c[E+73736>>2]=C;c[E+139272>>2]=C;C=A+3072|0;c[E+8204>>2]=C;c[E+73740>>2]=C;c[E+139276>>2]=C;C=A+4096|0;c[E+8208>>2]=C;c[E+73744>>2]=C;c[E+139280>>2]=C;C=A+5120|0;c[E+8212>>2]=C;c[E+73748>>2]=C;c[E+139284>>2]=C;C=A+6144|0;c[E+8216>>2]=C;c[E+73752>>2]=C;c[E+139288>>2]=C;C=A+7168|0;c[E+8220>>2]=C;c[E+73756>>2]=C;c[E+139292>>2]=C;C=A+8192|0;c[E+8224>>2]=C;c[E+73760>>2]=C;c[E+139296>>2]=C;C=A+9216|0;c[E+8228>>2]=C;c[E+73764>>2]=C;c[E+139300>>2]=C;C=A+10240|0;c[E+8232>>2]=C;c[E+73768>>2]=C;c[E+139304>>2]=C;C=A+11264|0;c[E+8236>>2]=C;c[E+73772>>2]=C;c[E+139308>>2]=C;C=A+12288|0;c[E+8240>>2]=C;c[E+73776>>2]=C;c[E+139312>>2]=C;C=A+13312|0;c[E+8244>>2]=C;c[E+73780>>2]=C;c[E+139316>>2]=C;C=A+14336|0;c[E+8248>>2]=C;c[E+73784>>2]=C;c[E+139320>>2]=C;C=A+15360|0;c[E+8252>>2]=C;c[E+73788>>2]=C;c[E+139324>>2]=C;C=c[3532008]|0;c[E+8320>>2]=C;c[E+73856>>2]=C;c[E+139392>>2]=C;A=C+1024|0;c[E+8324>>2]=A;c[E+73860>>2]=A;c[E+139396>>2]=A;A=C+2048|0;c[E+8328>>2]=A;c[E+73864>>2]=A;c[E+139400>>2]=A;A=C+3072|0;c[E+8332>>2]=A;c[E+73868>>2]=A;c[E+139404>>2]=A;A=C+4096|0;c[E+8336>>2]=A;c[E+73872>>2]=A;c[E+139408>>2]=A;A=C+5120|0;c[E+8340>>2]=A;c[E+73876>>2]=A;c[E+139412>>2]=A;A=C+6144|0;c[E+8344>>2]=A;c[E+73880>>2]=A;c[E+139416>>2]=A;A=C+7168|0;c[E+8348>>2]=A;c[E+73884>>2]=A;c[E+139420>>2]=A;A=C+8192|0;c[E+8352>>2]=A;c[E+73888>>2]=A;c[E+139424>>2]=A;A=C+9216|0;c[E+8356>>2]=A;c[E+73892>>2]=A;c[E+139428>>2]=A;A=C+10240|0;c[E+8360>>2]=A;c[E+73896>>2]=A;c[E+139432>>2]=A;A=C+11264|0;c[E+8364>>2]=A;c[E+73900>>2]=A;c[E+139436>>2]=A;A=C+12288|0;c[E+8368>>2]=A;c[E+73904>>2]=A;c[E+139440>>2]=A;A=C+13312|0;c[E+8372>>2]=A;c[E+73908>>2]=A;c[E+139444>>2]=A;A=C+14336|0;c[E+8376>>2]=A;c[E+73912>>2]=A;c[E+139448>>2]=A;A=C+15360|0;c[E+8380>>2]=A;c[E+73916>>2]=A;c[E+139452>>2]=A;A=c[3532272]|0;c[E+40960>>2]=A;c[E+106496>>2]=A;c[E+172032>>2]=A;C=A+1024|0;c[E+40964>>2]=C;c[E+106500>>2]=C;c[E+172036>>2]=C;C=A+2048|0;c[E+40968>>2]=C;c[E+106504>>2]=C;c[E+172040>>2]=C;C=A+3072|0;c[E+40972>>2]=C;c[E+106508>>2]=C;c[E+172044>>2]=C;C=A+4096|0;c[E+40976>>2]=C;c[E+106512>>2]=C;c[E+172048>>2]=C;C=A+5120|0;c[E+40980>>2]=C;c[E+106516>>2]=C;c[E+172052>>2]=C;C=A+6144|0;c[E+40984>>2]=C;c[E+106520>>2]=C;c[E+172056>>2]=C;C=A+7168|0;c[E+40988>>2]=C;c[E+106524>>2]=C;c[E+172060>>2]=C;C=c[3532593]|0;if((C|0)!=0){gGC(C|0,9104152,280)|0}c[2113061]=c[2113054];c[2394]=-1;e5g();TW(c[3531952]|0,14127792,c[3531946]|0,14127768,3028,908,12);c[2438228]=4e6;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=511;h[146569]=.25;h[118354]=.25;h[85208]=1.0;a[64232]=1;c[3532050]=5184;c[3532118]=10928;c[3532064]=4;c[3532082]=100;c[2113026]=2e5;c[2113024]=2e5;c[2113022]=66666;eZ8()|0;c[2438578]=0;c[2405756]=0;v=0;return v|0}function e4X(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7156876+(b*112|0)>>2];c[a+104>>2]=c[7156880+(b*112|0)>>2];c[a+108>>2]=c[7156884+(b*112|0)>>2];d=0;return d|0}function e4Y(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<21&(d|0)==0)){e=1;return e|0}c[a>>2]=7156776+(b*112|0);e=0;return e|0}function e4Z(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7154004+(b*112|0)>>2];c[a+104>>2]=c[7154008+(b*112|0)>>2];c[a+108>>2]=c[7154012+(b*112|0)>>2];d=0;return d|0}function e4_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<21&(d|0)==0)){e=1;return e|0}c[a>>2]=7153904+(b*112|0);e=0;return e|0}function e4$(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>42){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7156256+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e40(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7151132+(b*112|0)>>2];c[a+104>>2]=c[7151136+(b*112|0)>>2];c[a+108>>2]=c[7151140+(b*112|0)>>2];d=0;return d|0}function e41(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<21&(d|0)==0)){e=1;return e|0}c[a>>2]=7151032+(b*112|0);e=0;return e|0}function e42(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>42){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7153384+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e43(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3523532+(b*112|0)>>2];c[a+104>>2]=c[3523536+(b*112|0)>>2];c[a+108>>2]=c[3523540+(b*112|0)>>2];d=0;return d|0}function e44(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<21&(d|0)==0)){e=1;return e|0}c[a>>2]=3523432+(b*112|0);e=0;return e|0}function e45(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3403100+(b*112|0)>>2];c[a+104>>2]=c[3403104+(b*112|0)>>2];c[a+108>>2]=c[3403108+(b*112|0)>>2];d=0;return d|0}function e46(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=3403e3+(b*112|0);e=0;return e|0}function e47(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1189112+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function e48(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>31){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3405240+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e49(){var b=0,d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;c[3532162]=256;c[3532160]=4;c[3532142]=8;c[3532164]=8;c[3532148]=1983640;c[3532140]=6964216;c[3532138]=6963960;c[3532042]=16384;c[3532002]=512;c[3532e3]=4;a[7460944]=1;c[3532004]=8;c[3531998]=961392;c[3531992]=4969496;c[3531990]=961552;c[3532034]=65536;c[3532044]=2;a[7460960]=1;eZ9(0)|0;c[3532204]=0;b=c[3532200]|0;c[3532198]=b;d=(c[3532194]|0)+b|0;c[3531932]=d;e=d+(c[3531928]|0)|0;c[3531976]=e;f=e+(c[3531972]|0)|0;c[3531952]=f;g=f+(c[3531948]|0)|0;c[3531946]=g;i=g+(c[3531942]|0)|0;j=i|0;c[3532020]=j;c[3532208]=j;j=i+65536|0;c[3532206]=j;k=i+98304|0;c[3532008]=k;l=i+163840|0;c[3531936]=l;m=i+172032|0;c[3531970]=m;n=i+188416|0;c[3532026]=n;o=i+196608|0;p=o|0;c[3532022]=p;c[3532136]=p;p=ag(c[3532142]|0,c[3532042]|0)|0;q=(ag(p,c[3532164]|0)|0)+o|0;c[3531962]=q;p=ag(a[7460944]|0?16:0,c[3532034]|0)|0;r=(ag(p,c[3532004]|0)|0)+q|0;c[3531960]=r;p=ag(a[7460912]|0?16:0,a[7460976]|0?16384:0)|0;s=(ag(p,a[7460936]|0?16:0)|0)+r|0;c[3532028]=s;p=s+16384|0;t=p|0;c[3532046]=t;u=t;t=gGq(u)|0;c[3532048]=t;if((t|0)==0){v=1;return v|0}gGz(t|0,0,u|0);c[3532204]=t;c[3532198]=t+b;c[3531932]=t+d;c[3531976]=t+e;c[3531952]=t+f;c[3531946]=t+g;g=t+i|0;c[3532020]=g;c[3532208]=g;c[3532206]=t+j;c[3532008]=t+k;c[3531936]=t+l;c[3531970]=t+m;c[3532026]=t+n;n=t+o|0;c[3532022]=n;c[3532136]=n;c[3531962]=t+q;c[3531960]=t+r;c[3532028]=t+s;c[3532046]=t+p;p=c[642608+(c[2436]<<2)>>2]|0;t=c[p+128>>2]|0;if((c[p+52>>2]&4|0)==0){c[2113068]=t;s=c[p+132>>2]|0;c[2113070]=s;c[2443814]=t;c[2440436]=s;w=t;x=s}else{c[2113070]=t;s=c[p+132>>2]|0;c[2113068]=s;c[2440436]=t;c[2443814]=s;w=s;x=t}t=ag(w<<1,x)|0;x=gGq(t)|0;c[2112926]=x;if((x|0)!=0){gGz(x|0,0,t|0)}eX5(0,c[3532042]|0,4,8,1,0);t=0;while(1){if((t|0)>=1024){y=0;break}z=9638528+(t<<2)|0;if((c[z>>2]|0)==0){A=43376;break}else{t=t+1|0}}do{if((A|0)==43376){t=gGq(16384)|0;c[z>>2]=t;if((t|0)==0){y=0;break}gGz(t|0,0,16384);y=t}}while(0);c[2442928]=y;gGz(y|0,0,16384);y=0;while(1){if((y|0)>=1024){B=0;break}C=9638528+(y<<2)|0;if((c[C>>2]|0)==0){A=43381;break}else{y=y+1|0}}do{if((A|0)==43381){y=gGq(16384)|0;c[C>>2]=y;if((y|0)==0){B=0;break}gGz(y|0,0,16384);B=y}}while(0);c[3532276]=B;gGz(B|0,0,4096);c[3532274]=4096;a[7461088]=1;a[7461056]=1;if((eZ9(1)|0)!=0){v=1;return v|0}fxU(0,425984);if((c[2394]|0)==0){D=c[2112932]|0}else{c[2394]=0;B=c[3532596]|0;c[2112932]=B;C=c[3532592]|0;if((C|0)!=0){gGC(9104152,C|0,280)|0}c[2113054]=c[2113060];D=B}B=c[3532204]|0;C=D|0;A=0;while(1){y=B+A|0;c[C>>2]=y;c[C+131072>>2]=y;y=A+1024|0;if(y>>>0>524287){break}else{C=C+4|0;A=y}}A=c[3532208]|0;c[D+12480>>2]=A;c[D+78016>>2]=A;c[D+143552>>2]=A;C=A+1024|0;c[D+12484>>2]=C;c[D+78020>>2]=C;c[D+143556>>2]=C;C=A+2048|0;c[D+12488>>2]=C;c[D+78024>>2]=C;c[D+143560>>2]=C;C=A+3072|0;c[D+12492>>2]=C;c[D+78028>>2]=C;c[D+143564>>2]=C;C=A+4096|0;c[D+12496>>2]=C;c[D+78032>>2]=C;c[D+143568>>2]=C;C=A+5120|0;c[D+12500>>2]=C;c[D+78036>>2]=C;c[D+143572>>2]=C;C=A+6144|0;c[D+12504>>2]=C;c[D+78040>>2]=C;c[D+143576>>2]=C;C=A+7168|0;c[D+12508>>2]=C;c[D+78044>>2]=C;c[D+143580>>2]=C;C=A+8192|0;c[D+12512>>2]=C;c[D+78048>>2]=C;c[D+143584>>2]=C;C=A+9216|0;c[D+12516>>2]=C;c[D+78052>>2]=C;c[D+143588>>2]=C;C=A+10240|0;c[D+12520>>2]=C;c[D+78056>>2]=C;c[D+143592>>2]=C;C=A+11264|0;c[D+12524>>2]=C;c[D+78060>>2]=C;c[D+143596>>2]=C;C=A+12288|0;c[D+12528>>2]=C;c[D+78064>>2]=C;c[D+143600>>2]=C;C=A+13312|0;c[D+12532>>2]=C;c[D+78068>>2]=C;c[D+143604>>2]=C;C=A+14336|0;c[D+12536>>2]=C;c[D+78072>>2]=C;c[D+143608>>2]=C;C=A+15360|0;c[D+12540>>2]=C;c[D+78076>>2]=C;c[D+143612>>2]=C;C=c[3532008]|0;A=D+12544|0;B=3211264;while(1){y=C+(B-3211264)|0;c[A>>2]=y;c[A+65536>>2]=y;c[A+131072>>2]=y;y=B+1024|0;if(y>>>0>3276799){break}else{A=A+4|0;B=y}}B=c[3531970]|0;c[D+20480>>2]=B;c[D+86016>>2]=B;c[D+151552>>2]=B;A=B+1024|0;c[D+20484>>2]=A;c[D+86020>>2]=A;c[D+151556>>2]=A;A=c[3532278]|0;B=D+36864|0;C=9437184;while(1){c[B>>2]=A+(C-9437184);y=C+1024|0;if(y>>>0>9502719){break}else{B=B+4|0;C=y}}c[D+196688>>2]=954;c[D+196728>>2]=410;c[D+196648>>2]=1320;D=c[3532592]|0;if((D|0)!=0){gGC(D|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fxU(1,425984);if((c[2394]|0)==1){E=c[2112932]|0}else{c[2394]=1;D=c[3532597]|0;c[2112932]=D;C=c[3532593]|0;if((C|0)!=0){gGC(9104152,C|0,280)|0}c[2113054]=c[2113061];E=D}D=c[3532198]|0;C=E|0;B=0;while(1){A=D+B|0;c[C>>2]=A;c[C+131072>>2]=A;A=B+1024|0;if(A>>>0>262143){break}else{C=C+4|0;B=A}}B=c[3532206]|0;c[E+8384>>2]=B;c[E+73920>>2]=B;c[E+139456>>2]=B;C=B+1024|0;c[E+8388>>2]=C;c[E+73924>>2]=C;c[E+139460>>2]=C;C=B+2048|0;c[E+8392>>2]=C;c[E+73928>>2]=C;c[E+139464>>2]=C;C=B+3072|0;c[E+8396>>2]=C;c[E+73932>>2]=C;c[E+139468>>2]=C;C=B+4096|0;c[E+8400>>2]=C;c[E+73936>>2]=C;c[E+139472>>2]=C;C=B+5120|0;c[E+8404>>2]=C;c[E+73940>>2]=C;c[E+139476>>2]=C;C=B+6144|0;c[E+8408>>2]=C;c[E+73944>>2]=C;c[E+139480>>2]=C;C=B+7168|0;c[E+8412>>2]=C;c[E+73948>>2]=C;c[E+139484>>2]=C;C=B+8192|0;c[E+8416>>2]=C;c[E+73952>>2]=C;c[E+139488>>2]=C;C=B+9216|0;c[E+8420>>2]=C;c[E+73956>>2]=C;c[E+139492>>2]=C;C=B+10240|0;c[E+8424>>2]=C;c[E+73960>>2]=C;c[E+139496>>2]=C;C=B+11264|0;c[E+8428>>2]=C;c[E+73964>>2]=C;c[E+139500>>2]=C;C=B+12288|0;c[E+8432>>2]=C;c[E+73968>>2]=C;c[E+139504>>2]=C;C=B+13312|0;c[E+8436>>2]=C;c[E+73972>>2]=C;c[E+139508>>2]=C;C=B+14336|0;c[E+8440>>2]=C;c[E+73976>>2]=C;c[E+139512>>2]=C;C=B+15360|0;c[E+8444>>2]=C;c[E+73980>>2]=C;c[E+139516>>2]=C;C=c[3532008]|0;B=E+8448|0;D=2162688;while(1){A=C+(D-2162688)|0;c[B>>2]=A;c[B+65536>>2]=A;c[B+131072>>2]=A;A=D+1024|0;if(A>>>0>2228223){break}else{B=B+4|0;D=A}}c[E+196688>>2]=348;c[E+196728>>2]=1184;c[E+196608>>2]=2654;c[E+196648>>2]=2430;E=c[3532593]|0;if((E|0)!=0){gGC(E|0,9104152,280)|0}c[2113061]=c[2113054];c[2394]=-1;TW(c[3531952]|0,14127792,c[3531946]|0,14127768,0,2262,104);c[2438228]=16e6;c[2433526]=3248;c[2406676]=148;c[3528472]=444;c[2443846]=127;h[745406]=1.0;c[2436786]=3;h[745405]=1.0;c[2436784]=3;h[745404]=.25;a[3203280]=1;Tq(704784);if(!(a[1040128]|0)){gGC(14100392,684144,128)|0}c[3532050]=2828;c[3532118]=7744;c[3532064]=4;c[3532082]=100;a[7461152]=1;a[7460992]=1;c[2113026]=266666;c[2113024]=266666;c[2113302]=2;a[801640]=0;E=c[642608+(c[2436]<<2)>>2]|0;D=c[E+128>>2]|0;if((c[E+52>>2]&4|0)==0){c[2440576]=D;B=c[E+132>>2]|0;c[2440574]=B;F=D;G=B}else{c[2440574]=D;B=c[E+132>>2]|0;c[2440576]=B;F=B;G=D}D=(((F|0)/2|0)<<8)-1792|0;F=(((G|0)/2|0)<<8)-2048|0;c[3542196]=D;c[3542192]=F;c[3542197]=D;c[3542193]=F;c[3542198]=D;c[3542194]=F;c[3542199]=D;c[3542195]=F;eZ8()|0;c[2438578]=0;c[2405756]=0;v=0;return v|0}function e5a(a){a=a|0;var b=0,d=0;b=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=(c[2113024]|0)*60|0;b=gGS(d,K,a,(a|0)<0|0?-1:0)|0;return b|0}function e5b(){return+(+((c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0)/+((c[2113024]|0)*60|0|0))}function e5c(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;a[14129040]=-1;a[14129041]=-1;a[14129042]=-1;if((a[14129032]|0)==0){b=-1}else{a[14129040]=-2;b=-2}if((a[14129033]|0)==0){d=b}else{e=b-2&255;a[14129040]=e;d=e}if((a[14129034]|0)==0){f=d}else{e=d-4&255;a[14129040]=e;f=e}if((a[14129035]|0)==0){g=f}else{e=f-8&255;a[14129040]=e;g=e}if((a[14129036]|0)==0){h=g}else{e=g-16&255;a[14129040]=e;h=e}if((a[14129037]|0)==0){i=h}else{e=h-32&255;a[14129040]=e;i=e}if((a[14129038]|0)==0){j=i}else{e=i-64&255;a[14129040]=e;j=e}if((a[14129039]|0)!=0){a[14129040]=j^-128}if((a[14129016]|0)==0){k=-1}else{a[14129042]=-2;k=-2}if((a[14129017]|0)==0){l=k}else{j=k-2&255;a[14129042]=j;l=j}if((a[14129018]|0)==0){m=l}else{j=l-4&255;a[14129042]=j;m=j}if((a[14129019]|0)==0){n=m}else{j=m-8&255;a[14129042]=j;n=j}if((a[14129020]|0)==0){o=n}else{j=n-16&255;a[14129042]=j;o=j}if((a[14129021]|0)==0){p=o}else{j=o-32&255;a[14129042]=j;p=j}if((a[14129022]|0)==0){q=p}else{j=p-64&255;a[14129042]=j;q=j}if((a[14129023]|0)!=0){a[14129042]=q^-128}q=c[3532184]|0;j=(c[3542196]|0)+(c[3532186]<<16>>16)|0;c[3542196]=j;p=(c[3542192]|0)+(q<<16>>16)|0;c[3542192]=p;if((j|0)<-2048){c[3542196]=-2048;r=-2048}else{r=j}j=(c[2440576]<<8)-2048|0;if((r|0)>(j|0)){c[3542196]=j}if((p|0)<-2048){c[3542192]=-2048;s=-2048}else{s=p}p=(c[2440574]<<8)-2048|0;if((s|0)>(p|0)){c[3542192]=p}s=c[3532180]|0;r=(c[3542197]|0)+(c[3532182]<<16>>16)|0;c[3542197]=r;q=(c[3542193]|0)+(s<<16>>16)|0;c[3542193]=q;if((r|0)<-2048){c[3542197]=-2048;t=-2048}else{t=r}if((t|0)>(j|0)){c[3542197]=j}if((q|0)<-2048){c[3542193]=-2048;u=-2048}else{u=q}if((u|0)<=(p|0)){return}c[3542193]=p;return}function e5d(){var a=0,d=0,f=0;a=e[7064582]|0;d=c[2112926]|0;gGz(d|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);do{if((b[7064582]&8)==0){if((a&1|0)==0){eX0(0,1,c[3532136]|0)}e5e(1);if((a&2|0)!=0){break}eX3(0,0,c[3532136]|0)}else{if((a&2|0)==0){eX3(0,1,c[3532136]|0)}e5e(1);if((a&1|0)!=0){break}eX0(0,0,c[3532136]|0)}}while(0);e5e(0);if((a&4|0)==0){eX4(0)}R8(c[3532276]|0);a=c[2113302]|0;if((a|0)>0){f=0}else{return}do{R7(f,c[14168784+(f<<2)>>2]>>8,c[14168768+(f<<2)>>2]>>8);f=f+1|0;}while((f|0)<(a|0));return}function e5e(a){a=a|0;var b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;b=c[3531976]|0;d=c[3531970]|0;f=c[3531962]|0;g=764;do{h=e[d+((g|1)<<1)>>1]|0;do{if((h>>>15|0)==(a|0)){i=h>>>14&1;j=h&511;k=e[d+((g|3)<<1)>>1]|0;l=k>>>15;m=k&8191;if((m|0)==0){break}k=e[d+(g<<1)>>1]|0;n=k&511;o=e[d+((g|2)<<1)>>1]|0;p=o>>>8;q=m<<5;m=(o&127)+1|0;o=(k>>>9)+1|0;k=n+4|0;r=j>>>0>320?h|-512:j;j=k>>>0>320?n-508|0:k;k=(l|0)!=0;if((i|0)==0){n=j-16|0;s=c[3532034]|0;if(k){t=0;do{u=(t|0)%4|0;v=(t|0)/4|0;w=s+65535&(e[b+(u+q+(7-v<<2)<<1)>>1]|0);x=(ag(u,m)|0)/4|0;y=(ag(v,o)|0)/8|0;z=((ag(u+1|0,m)|0)/4|0)-x|0;e5f(w,x+r|0,n+y|0,p,0,l,z<<12,((ag(v+1|0,o)|0)/8|0)-y<<13,f);t=t+1|0;}while((t|0)<32)}else{t=0;do{y=(t|0)%4|0;v=(t|0)/4|0;z=s+65535&(e[b+(y+q+(v<<2)<<1)>>1]|0);x=(ag(y,m)|0)/4|0;w=(ag(v,o)|0)/8|0;u=((ag(y+1|0,m)|0)/4|0)-x|0;e5f(z,x+r|0,n+w|0,p,0,0,u<<12,((ag(v+1|0,o)|0)/8|0)-w<<13,f);t=t+1|0;}while((t|0)<32)}}else{t=q|3;n=j-16|0;s=c[3532034]|0;if(k){w=0;do{v=(w|0)%4|0;u=(w|0)/4|0;x=s+65535&(e[b+(t-v+(7-u<<2)<<1)>>1]|0);z=(ag(v,m)|0)/4|0;y=(ag(u,o)|0)/8|0;A=((ag(v+1|0,m)|0)/4|0)-z|0;e5f(x,z+r|0,n+y|0,p,i,l,A<<12,((ag(u+1|0,o)|0)/8|0)-y<<13,f);w=w+1|0;}while((w|0)<32)}else{w=0;do{l=(w|0)%4|0;k=(w|0)/4|0;j=s+65535&(e[b+(t-l+(k<<2)<<1)>>1]|0);q=(ag(l,m)|0)/4|0;y=(ag(k,o)|0)/8|0;u=((ag(l+1|0,m)|0)/4|0)-q|0;e5f(j,q+r|0,n+y|0,p,i,0,u<<12,((ag(k+1|0,o)|0)/8|0)-y<<13,f);w=w+1|0;}while((w|0)<32)}}}}while(0);g=g-4|0;}while((g|0)>-1);return}function e5f(d,e,f,g,h,i,j,k,l){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;m=a[7460944]|0?16:0;n=ag(m,(d>>>0)%((c[3532034]|0)>>>0)|0)|0;d=c[3532004]|0;o=ag(n,d)|0;n=((ag(d,k)|0)+32768|0)>>>16;k=((ag(m,j)|0)+32768|0)>>>16;p=((g|0)%256|0)<<4;if(a[7461152]|0){q=320-e-(j>>12)|0;r=(h|0)==0|0}else{q=e;r=h}if((k|0)==0|(n|0)==0){return}h=(m<<16>>>0)/(k>>>0)|0;e=(d<<16>>>0)/(n>>>0)|0;d=q+k|0;j=n+f|0;if((r|0)==0){s=h;t=0}else{s=-h|0;t=ag(h,k-1|0)|0}if((i|0)==0){u=e;v=0}else{u=-e|0;v=ag(e,n-1|0)|0}if((q|0)<0){w=0;x=t-(ag(s,q)|0)|0}else{w=q;x=t}if((f|0)<0){y=0;z=v-(ag(u,f)|0)|0}else{y=f;z=v}v=c[2113068]|0;f=(d|0)>(v|0)?v:d;d=c[2113070]|0;t=(j|0)>(d|0)?d:j;if(!((f|0)>(w|0)&(y|0)<(t|0))){return}j=c[2112926]|0;d=z;z=y;while(1){y=(ag(d>>16,m)|0)+o|0;q=ag(z,v)|0;n=w;e=x;while(1){i=a[l+(y+(e>>16))|0]|0;if(i<<24>>24!=0){b[j+(n+q<<1)>>1]=(i&255|p)&65535}i=n+1|0;if((i|0)<(f|0)){n=i;e=e+s|0}else{break}}e=z+1|0;if((e|0)>=(t|0)){break}d=d+u|0;z=e}return}function e5g(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;fwR(0);a=c[2439330]|0;d=(a|0)==0;if(!d){e=a;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];e=c[3528484]|0;c[2076596]=e;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;c[a+4180>>2]=2274;c[a+4184>>2]=2684;g=c[3531932]|0;h=0;i=0;while(1){c[a+76+(i<<2)>>2]=g+(i<<8);j=h+1&65535;if((j&65535)>63){k=0;l=0;break}else{h=j;i=j&65535}}while(1){i=g+(l<<8)|0;c[a+76+(l+512<<2)>>2]=i;c[a+76+(l+768<<2)>>2]=i;i=k+1&65535;if((i&65535)>63){m=64;n=64;break}else{k=i;l=i&65535}}while(1){c[a+76+(n<<2)>>2]=g+(n<<8);l=m+1&65535;if((l&65535)>127){o=64;p=64;break}else{m=l;n=l&65535}}while(1){n=g+(p<<8)|0;c[a+76+(p+512<<2)>>2]=n;c[a+76+(p+768<<2)>>2]=n;n=o+1&65535;if((n&65535)>127){break}else{o=n;p=n&65535}}p=c[3531936]|0;o=192;g=192;while(1){c[a+76+(g<<2)>>2]=p+((g<<8)-49152);n=o+1&65535;if((n&65535)>223){q=192;r=192;break}else{o=n;g=n&65535}}while(1){c[a+76+(r+256<<2)>>2]=p+((r<<8)-49152);g=q+1&65535;if((g&65535)>223){s=192;t=192;break}else{q=g;r=g&65535}}while(1){r=p+((t<<8)-49152)|0;c[a+76+(t+512<<2)>>2]=r;c[a+76+(t+768<<2)>>2]=r;r=s+1&65535;if((r&65535)>223){break}else{s=r;t=r&65535}}if(d){u=c[2433530]|0;c[2438118]=u;c[3528484]=e;c[2417276]=f;c[1836236]=-1;c[3532030]=1;return}d=a;gGC(d|0,9706056,76)|0;u=c[2433530]|0;c[2438118]=u;c[3528484]=e;c[2417276]=f;c[1836236]=-1;c[3532030]=1;return}function e5h(b,c){b=b|0;c=c|0;a[9706117]=c&1;return}function e5i(a){a=a|0;var b=0,d=0;b=(c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,4e6,0)|0;return a|0}function e5j(){return+(+((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)/4.0e6)}function e5k(){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;a[14129040]=-1;a[14129041]=-17;a[14129042]=-1;if((a[14129032]|0)==0){b=-1}else{a[14129040]=-2;b=-2}if((a[14129033]|0)==0){c=b}else{d=b-2&255;a[14129040]=d;c=d}if((a[14129034]|0)==0){e=c}else{d=c-4&255;a[14129040]=d;e=d}if((a[14129035]|0)==0){f=e}else{d=e-8&255;a[14129040]=d;f=d}if((a[14129036]|0)==0){g=f}else{d=f-16&255;a[14129040]=d;g=d}if((a[14129037]|0)==0){h=g}else{d=g-32&255;a[14129040]=d;h=d}if((a[14129038]|0)==0){i=h}else{d=h-64&255;a[14129040]=d;i=d}if((a[14129039]|0)!=0){a[14129040]=i^-128}if((a[14129024]|0)==0){j=-17}else{a[14129041]=-18;j=-18}if((a[14129025]|0)==0){k=j}else{i=j-2&255;a[14129041]=i;k=i}if((a[14129026]|0)==0){l=k}else{i=k-4&255;a[14129041]=i;l=i}if((a[14129027]|0)==0){m=l}else{i=l-8&255;a[14129041]=i;m=i}if((a[14129028]|0)==0){n=m}else{i=m|16;a[14129041]=i;n=i}if((a[14129029]|0)==0){o=n}else{i=n-32&255;a[14129041]=i;o=i}if((a[14129030]|0)==0){p=o}else{i=o-64&255;a[14129041]=i;p=i}if((a[14129031]|0)==0){return}a[14129041]=p^-128;return}function e5l(){var a=0,d=0,e=0,f=0,g=0,h=0;a=b[7064582]|0;d=c[2112926]|0;gGz(d|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);d=c[3532028]|0;e=0;f=c[3532026]|0;g=d;while(1){h=b[f>>1]|0;c[g>>2]=((h&65535)>>>10<<3&248)>>>3|((h&255)<<3&255)<<8|(((h&65535)>>>7&4|(h&65535)>>>5<<3&255)&255)<<3&2016;h=e+1|0;if((h|0)<4096){e=h;f=f+2|0;g=g+4|0}else{break}}g=a&65535;do{if((b[7064582]&8)==0){if((g&1|0)==0){eX0(0,1,c[3532136]|0)}if((g&2|0)!=0){break}eX3(0,0,c[3532136]|0)}else{if((g&2|0)==0){eX3(0,1,c[3532136]|0)}if((g&1|0)!=0){break}eX0(0,0,c[3532136]|0)}}while(0);e5m(1,6);e2G(-1,192,0,0);e5m(0,6);if((g&4|0)!=0){R8(d);return}eX4(0);R8(d);return}function e5m(a,d){a=a|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;f=c[3531976]|0;g=c[3531970]|0;h=c[2438578]<<11&2048;i=h+2048|0;j=c[3531962]|0;k=h;do{h=e[g+(k+1<<1)>>1]|0;do{if((h>>>15|0)==(a|0)){l=h>>>7&255;m=b[g+(k+3<<1)>>1]&8191;if((m|0)==0){break}n=e[g+(k<<1)>>1]|0;o=n>>>9&63;p=e[g+(k+2<<1)>>1]|0;q=p>>>15;r=p>>>14&1;s=p&511;t=m<<5;m=(h&63)+1|0;u=o+1|0;v=(n&511)+d+(o^63)|0;o=s>>>0>320?p|-512:s;s=(v|0)>320?v-512|0:v;v=(q|0)!=0;if((r|0)==0){p=s-16|0;n=c[3532034]|0;if(v){w=0;do{x=(w|0)%4|0;y=(w|0)/4|0;z=n+65535&(e[f+(x+t+(7-y<<2)<<1)>>1]|0);A=(ag(x,m)|0)/4|0;B=(ag(y,u)|0)/8|0;C=((ag(x+1|0,m)|0)/4|0)-A|0;e5f(z,A+o|0,p+B|0,l,0,q,C<<12,((ag(y+1|0,u)|0)/8|0)-B<<13,j);w=w+1|0;}while((w|0)<32)}else{w=0;do{B=(w|0)%4|0;y=(w|0)/4|0;C=n+65535&(e[f+(B+t+(y<<2)<<1)>>1]|0);A=(ag(B,m)|0)/4|0;z=(ag(y,u)|0)/8|0;x=((ag(B+1|0,m)|0)/4|0)-A|0;e5f(C,A+o|0,p+z|0,l,0,0,x<<12,((ag(y+1|0,u)|0)/8|0)-z<<13,j);w=w+1|0;}while((w|0)<32)}}else{w=t|3;p=s-16|0;n=c[3532034]|0;if(v){z=0;do{y=(z|0)%4|0;x=(z|0)/4|0;A=n+65535&(e[f+(w-y+(7-x<<2)<<1)>>1]|0);C=(ag(y,m)|0)/4|0;B=(ag(x,u)|0)/8|0;D=((ag(y+1|0,m)|0)/4|0)-C|0;e5f(A,C+o|0,p+B|0,l,r,q,D<<12,((ag(x+1|0,u)|0)/8|0)-B<<13,j);z=z+1|0;}while((z|0)<32)}else{z=0;do{q=(z|0)%4|0;v=(z|0)/4|0;s=n+65535&(e[f+(w-q+(v<<2)<<1)>>1]|0);t=(ag(q,m)|0)/4|0;B=(ag(v,u)|0)/8|0;x=((ag(q+1|0,m)|0)/4|0)-t|0;e5f(s,t+o|0,p+B|0,l,r,0,x<<12,((ag(v+1|0,u)|0)/8|0)-B<<13,j);z=z+1|0;}while((z|0)<32)}}}}while(0);k=k+4|0;}while((k|0)<(i|0));return}function e5n(){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;a[14128912]=-1;a[14128913]=-1;a[14128914]=-1;if((a[14128904]|0)==0){b=-1}else{a[14128912]=-2;b=-2}if((a[14128905]|0)==0){c=b}else{d=b-2&255;a[14128912]=d;c=d}if((a[14128906]|0)==0){e=c}else{d=c-4&255;a[14128912]=d;e=d}if((a[14128907]|0)==0){f=e}else{d=e-8&255;a[14128912]=d;f=d}if((a[14128908]|0)==0){g=f}else{d=f-16&255;a[14128912]=d;g=d}if((a[14128909]|0)==0){h=g}else{d=g-32&255;a[14128912]=d;h=d}if((a[14128910]|0)==0){i=h}else{d=h-64&255;a[14128912]=d;i=d}if((a[14128911]|0)!=0){a[14128912]=i^-128}if((a[14128896]|0)==0){j=-1}else{a[14128913]=-2;j=-2}if((a[14128897]|0)==0){k=j}else{i=j-2&255;a[14128913]=i;k=i}if((a[14128898]|0)==0){l=k}else{i=k-4&255;a[14128913]=i;l=i}if((a[14128899]|0)==0){m=l}else{i=l-8&255;a[14128913]=i;m=i}if((a[14128900]|0)==0){n=m}else{i=m-16&255;a[14128913]=i;n=i}if((a[14128901]|0)==0){o=n}else{i=n-32&255;a[14128913]=i;o=i}if((a[14128902]|0)==0){p=o}else{i=o-64&255;a[14128913]=i;p=i}if((a[14128903]|0)==0){return}a[14128913]=p^-128;return}function e5o(){var a=0,d=0,f=0,g=0,h=0,i=0;a=e[725160+(((c[2436808]|0)>>>2&7)<<1)>>1]|0;d=c[2112926]|0;gGz(d|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);d=c[3532028]|0;f=0;g=c[3532026]|0;h=d;while(1){i=b[g>>1]|0;c[h>>2]=((i&65535)>>>10<<3&248)>>>3|((i&255)<<3&255)<<8|(((i&65535)>>>7&4|(i&65535)>>>5<<3&255)&255)<<3&2016;i=f+1|0;if((i|0)<4096){f=i;g=g+2|0;h=h+4|0}else{break}}h=a>>>8;g=a>>>12;f=a>>>4;i=c[3532136]|0;if((g|0)==3){eXQ(3,1,i)}else if((g|0)==1){eXP(1,1,i)}else if((g|0)==0){eXP(0,1,i)}else if((g|0)==2){eXQ(2,1,i)}g=h&15;if((g|0)==0){eXP(0,0,i)}else if((g|0)==1){eXP(1,0,i)}else if((g|0)==2){eXQ(2,0,i)}else if((g|0)==3){eXQ(3,0,i)}e5m(1,7);g=f&15;if((g|0)==0){eXP(0,0,i)}else if((g|0)==1){eXP(1,0,i)}else if((g|0)==2){eXQ(2,0,i)}else if((g|0)==3){eXQ(3,0,i)}g=a&15;if((g|0)==2){eXQ(2,0,i)}else if((g|0)==1){eXP(1,0,i)}else if((g|0)==3){eXQ(3,0,i)}else if((g|0)==0){eXP(0,0,i)}e2G(-1,192,0,0);e5m(0,7);eXR();R8(d);return}function e5p(){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;a[14129040]=-1;a[14129041]=-1;a[14129042]=-1;if((a[14129032]|0)==0){b=-1}else{a[14129040]=-2;b=-2}if((a[14129033]|0)==0){c=b}else{d=b-2&255;a[14129040]=d;c=d}if((a[14129034]|0)==0){e=c}else{d=c-4&255;a[14129040]=d;e=d}if((a[14129035]|0)==0){f=e}else{d=e-8&255;a[14129040]=d;f=d}if((a[14129036]|0)==0){g=f}else{d=f-16&255;a[14129040]=d;g=d}if((a[14129037]|0)==0){h=g}else{d=g-32&255;a[14129040]=d;h=d}if((a[14129038]|0)==0){i=h}else{d=h-64&255;a[14129040]=d;i=d}if((a[14129039]|0)!=0){a[14129040]=i^-128}if((a[14129016]|0)==0){j=-1}else{a[14129042]=-2;j=-2}if((a[14129017]|0)==0){k=j}else{i=j-2&255;a[14129042]=i;k=i}if((a[14129018]|0)==0){l=k}else{i=k-4&255;a[14129042]=i;l=i}if((a[14129019]|0)==0){m=l}else{i=l-8&255;a[14129042]=i;m=i}if((a[14129020]|0)==0){n=m}else{i=m-16&255;a[14129042]=i;n=i}if((a[14129021]|0)==0){o=n}else{i=n-32&255;a[14129042]=i;o=i}if((a[14129022]|0)==0){p=o}else{i=o-64&255;a[14129042]=i;p=i}if((a[14129023]|0)==0){return}a[14129042]=p^-128;return}function e5q(){var a=0,d=0,f=0;a=e[7064582]|0;d=c[2112926]|0;gGz(d|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);do{if((b[7064582]&8)==0){if((a&1|0)==0){eX0(0,1,c[3532136]|0)}if((a&2|0)!=0){break}eX3(0,0,c[3532136]|0)}else{if((a&2|0)==0){eX3(0,1,c[3532136]|0)}if((a&1|0)!=0){break}eX0(0,0,c[3532136]|0)}}while(0);e5r(1);e2G(-1,192,0,0);e5r(0);if((a&4|0)!=0){f=c[3532276]|0;R8(f);return}eX4(0);f=c[3532276]|0;R8(f);return}function e5r(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;f=c[3531976]|0;g=c[3531970]|0;h=a[7460976]|0?16383:65535;i=c[3531960]|0;j=c[3531962]|0;k=0;do{l=e[g+((k|1)<<1)>>1]|0;L57211:do{if((l>>>15|0)==(d|0)){m=l>>>7&255;n=b[g+((k|3)<<1)>>1]&2047;if((n|0)==0){break}o=e[g+(k<<1)>>1]|0;p=o>>>9;q=e[g+((k|2)<<1)>>1]|0;r=q>>>15;s=q>>>14&1;t=q&511;u=(l&127)+1|0;v=p+1|0;w=(o&511)+7+(p^127)|0;p=t>>>0>320?q|-512:t;t=(w|0)>320?w-512|0:w;if((l&64|0)!=0){w=n<<6;q=(r|0)!=0;if((s|0)==0){o=t-16|0;x=c[3532034]|0;if(q){y=0;while(1){z=(y|0)/8|0;A=(y|0)%8|0;B=x+65535&(e[f+(A+w+(7-z<<3)<<1)>>1]|0);C=(ag(A,u)|0)/8|0;D=(ag(z,v)|0)/8|0;E=((ag(A+1|0,u)|0)/8|0)-C|0;e5f(B,C+p|0,o+D|0,m,0,r,E<<12,((ag(z+1|0,v)|0)/8|0)-D<<12,j);y=y+1|0;if((y|0)>=64){break L57211}}}else{y=0;while(1){D=(y|0)/8|0;z=(y|0)%8|0;E=x+65535&(e[f+(z+w+(D<<3)<<1)>>1]|0);C=(ag(z,u)|0)/8|0;B=(ag(D,v)|0)/8|0;A=((ag(z+1|0,u)|0)/8|0)-C|0;e5f(E,C+p|0,o+B|0,m,0,0,A<<12,((ag(D+1|0,v)|0)/8|0)-B<<12,j);y=y+1|0;if((y|0)>=64){break L57211}}}}else{y=w|7;o=t-16|0;x=c[3532034]|0;if(q){B=0;while(1){D=(B|0)/8|0;A=(B|0)%8|0;C=x+65535&(e[f+(y-A+(7-D<<3)<<1)>>1]|0);E=(ag(A,u)|0)/8|0;z=(ag(D,v)|0)/8|0;F=((ag(A+1|0,u)|0)/8|0)-E|0;e5f(C,E+p|0,o+z|0,m,s,r,F<<12,((ag(D+1|0,v)|0)/8|0)-z<<12,j);B=B+1|0;if((B|0)>=64){break L57211}}}else{B=0;while(1){q=(B|0)/8|0;w=(B|0)%8|0;z=x+65535&(e[f+(y-w+(q<<3)<<1)>>1]|0);D=(ag(w,u)|0)/8|0;F=(ag(q,v)|0)/8|0;E=((ag(w+1|0,u)|0)/8|0)-D|0;e5f(z,D+p|0,o+F|0,m,s,0,E<<12,((ag(q+1|0,v)|0)/8|0)-F<<12,j);B=B+1|0;if((B|0)>=64){break L57211}}}}}if((l&32|0)==0){if((l&96|0)!=0){break}B=n<<4|196608;o=(s|0)!=0;y=(r|0)!=0;x=t-16|0;F=0;while(1){q=(F|0)/2|0;E=(F|0)%2|0;D=h&(e[f+((o?1-E|0:E)+B+((y?7-q|0:q)<<1)<<1)>>1]|0);z=(ag(E,u)|0)/2|0;w=(ag(q,v)|0)/8|0;C=((ag(E+1|0,u)|0)/2|0)-z|0;e5f(D,z+p|0,x+w|0,m,s,r,C<<12,((ag(q+1|0,v)|0)/8|0)-w<<12,i);F=F+1|0;if((F|0)>=16){break L57211}}}F=n<<5;x=F|131072;y=(r|0)!=0;if((s|0)==0){B=t-16|0;o=0;do{w=(o|0)/4|0;q=(o|0)%4|0;C=h&(e[f+(q+x+((y?7-w|0:w)<<2)<<1)>>1]|0);z=(ag(q,u)|0)/4|0;D=(ag(w,v)|0)/8|0;E=((ag(q+1|0,u)|0)/4|0)-z|0;e5f(C,z+p|0,B+D|0,m,0,r,E<<12,((ag(w+1|0,v)|0)/8|0)-D<<12,i);o=o+1|0;}while((o|0)<32)}else{o=F|131075;B=t-16|0;x=0;do{n=(x|0)/4|0;D=(x|0)%4|0;w=h&(e[f+(o-D+((y?7-n|0:n)<<2)<<1)>>1]|0);E=(ag(D,u)|0)/4|0;z=(ag(n,v)|0)/8|0;C=((ag(D+1|0,u)|0)/4|0)-E|0;e5f(w,E+p|0,B+z|0,m,s,r,C<<12,((ag(n+1|0,v)|0)/8|0)-z<<12,i);x=x+1|0;}while((x|0)<32)}}}while(0);k=k+4|0;}while((k|0)<1024);return}function e5s(){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;a[14129040]=-13;a[14129041]=-1;a[14129042]=-1;if((a[14129032]|0)==0){b=-13}else{a[14129040]=-14;b=-14}if((a[14129033]|0)==0){c=b}else{d=b-2&255;a[14129040]=d;c=d}if((a[14129034]|0)==0){e=c}else{d=c|4;a[14129040]=d;e=d}if((a[14129035]|0)==0){f=e}else{d=e|8;a[14129040]=d;f=d}if((a[14129036]|0)==0){g=f}else{d=f-16&255;a[14129040]=d;g=d}if((a[14129037]|0)==0){h=g}else{d=g-32&255;a[14129040]=d;h=d}if((a[14129038]|0)==0){i=h}else{d=h-64&255;a[14129040]=d;i=d}if((a[14129039]|0)!=0){a[14129040]=i^-128}if((a[14129024]|0)==0){j=-1}else{a[14129041]=-2;j=-2}if((a[14129025]|0)==0){k=j}else{i=j-2&255;a[14129041]=i;k=i}if((a[14129026]|0)==0){l=k}else{i=k-4&255;a[14129041]=i;l=i}if((a[14129027]|0)==0){m=l}else{i=l-8&255;a[14129041]=i;m=i}if((a[14129028]|0)==0){n=m}else{i=m-16&255;a[14129041]=i;n=i}if((a[14129029]|0)==0){o=n}else{i=n-32&255;a[14129041]=i;o=i}if((a[14129030]|0)==0){p=o}else{i=o-64&255;a[14129041]=i;p=i}if((a[14129031]|0)==0){return}a[14129041]=p^-128;return}function e5t(){var a=0,d=0,f=0;a=e[7064582]|0;d=c[2112926]|0;gGz(d|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);do{if((b[7064582]&8)==0){if((a&1|0)==0){eX0(0,0,c[3532136]|0)}if((a&2|0)!=0){break}eX3(0,0,c[3532136]|0)}else{if((a&2|0)==0){eX3(0,0,c[3532136]|0)}if((a&1|0)!=0){break}eX0(0,0,c[3532136]|0)}}while(0);e5u(1);e2G(5,192,1,0);e5u(0);if((a&4|0)!=0){f=c[3532276]|0;R8(f);return}eX4(0);f=c[3532276]|0;R8(f);return}function e5u(a){a=a|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;d=c[3531976]|0;f=c[3531970]|0;g=c[3531962]|0;h=892;do{i=e[f+((h|2)<<1)>>1]|0;do{if((i>>>15|0)==(a|0)){j=i>>>14&1;k=i>>>13&1;l=i&511;m=b[f+((h|1)<<1)>>1]&2047;if((m|0)==0){break}n=e[f+(h<<1)>>1]|0;o=n>>>9;p=e[f+((h|3)<<1)>>1]|0;q=p>>>8;r=m<<7;m=(p&127)+1|0;p=o+1|0;s=(n&511)+5+(o^127)|0;o=l>>>0>320?i|-512:l;l=(s|0)>320?s-512|0:s;s=(k|0)!=0;if((j|0)==0){n=l-24|0;t=c[3532034]|0;if(s){u=0;do{v=(u|0)%8|0;w=(u|0)/8|0;x=t+65535&(e[d+(v+r+(15-w<<3)<<1)>>1]|0);y=(ag(v,m)|0)/8|0;z=(ag(w,p)|0)/16|0;A=((ag(v+1|0,m)|0)/8|0)-y|0;e5f(x,y+o|0,n+z|0,q,0,k,A<<12,((ag(w+1|0,p)|0)/16|0)-z<<13,g);u=u+1|0;}while((u|0)<128)}else{u=0;do{z=(u|0)%8|0;w=(u|0)/8|0;A=t+65535&(e[d+(z+r+(w<<3)<<1)>>1]|0);y=(ag(z,m)|0)/8|0;x=(ag(w,p)|0)/16|0;v=((ag(z+1|0,m)|0)/8|0)-y|0;e5f(A,y+o|0,n+x|0,q,0,0,v<<12,((ag(w+1|0,p)|0)/16|0)-x<<13,g);u=u+1|0;}while((u|0)<128)}}else{u=r|7;n=l-24|0;t=c[3532034]|0;if(s){x=0;do{w=(x|0)%8|0;v=(x|0)/8|0;y=t+65535&(e[d+(u-w+(15-v<<3)<<1)>>1]|0);A=(ag(w,m)|0)/8|0;z=(ag(v,p)|0)/16|0;B=((ag(w+1|0,m)|0)/8|0)-A|0;e5f(y,A+o|0,n+z|0,q,j,k,B<<12,((ag(v+1|0,p)|0)/16|0)-z<<13,g);x=x+1|0;}while((x|0)<128)}else{x=0;do{k=(x|0)%8|0;s=(x|0)/8|0;l=t+65535&(e[d+(u-k+(s<<3)<<1)>>1]|0);r=(ag(k,m)|0)/8|0;z=(ag(s,p)|0)/16|0;v=((ag(k+1|0,m)|0)/8|0)-r|0;e5f(l,r+o|0,n+z|0,q,j,0,v<<12,((ag(s+1|0,p)|0)/16|0)-z<<13,g);x=x+1|0;}while((x|0)<128)}}}}while(0);h=h-4|0;}while((h|0)>-1);return}function e5v(){var a=0,d=0,f=0,g=0,h=0,i=0;a=e[725160+(((c[2436808]|0)>>>2&7)<<1)>>1]|0;d=c[2112926]|0;gGz(d|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);d=c[3532028]|0;f=0;g=c[3532026]|0;h=d;while(1){i=b[g>>1]|0;c[h>>2]=((i&65535)>>>10<<3&248)>>>3|((i&255)<<3&255)<<8|(((i&65535)>>>7&4|(i&65535)>>>5<<3&255)&255)<<3&2016;i=f+1|0;if((i|0)<4096){f=i;g=g+2|0;h=h+4|0}else{break}}h=a>>>8;g=a>>>12;f=a>>>4;i=c[3532136]|0;if((g|0)==1){eXP(1,1,i)}else if((g|0)==2){eXQ(2,1,i)}else if((g|0)==0){eXP(0,1,i)}else if((g|0)==3){eXQ(3,1,i)}g=h&15;if((g|0)==1){eXP(1,0,i)}else if((g|0)==3){eXQ(3,0,i)}else if((g|0)==2){eXQ(2,0,i)}else if((g|0)==0){eXP(0,0,i)}g=f&15;if((g|0)==3){eXQ(3,0,i)}else if((g|0)==1){eXP(1,0,i)}else if((g|0)==0){eXP(0,0,i)}else if((g|0)==2){eXQ(2,0,i)}e5w(1,7,8192);e2G(-1,192,0,0);e5w(0,7,8192);g=a&15;if((g|0)==1){eXP(1,0,i);eXR();R8(d);return}else if((g|0)==0){eXP(0,0,i);eXR();R8(d);return}else if((g|0)==3){eXQ(3,0,i);eXR();R8(d);return}else if((g|0)==2){eXQ(2,0,i);eXR();R8(d);return}else{eXR();R8(d);return}}function e5w(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;g=c[3531976]|0;h=c[3531970]|0;i=f-4|0;if((i|0)<=0){return}f=c[3531962]|0;j=0;do{k=e[h+((j|1)<<1)>>1]|0;do{if((k>>>15|0)==(a|0)){l=k>>>7&255;m=b[h+((j|3)<<1)>>1]&8191;if((m|0)==0){break}n=e[h+(j<<1)>>1]|0;o=n>>>9&63;p=e[h+((j|2)<<1)>>1]|0;q=p>>>15;r=p>>>14&1;s=p&511;t=m<<5;m=(k&63)+1|0;u=o+1|0;v=(n&511)+d+(o^63)|0;o=s>>>0>320?p|-512:s;s=(r|0)!=0;p=(q|0)!=0;n=((v|0)>320?v-512|0:v)-16|0;v=c[3532034]|0;w=0;do{x=(w|0)%4|0;y=(w|0)/4|0;z=v+65535&(e[g+((s?3-x|0:x)+t+((p?7-y|0:y)<<2)<<1)>>1]|0);A=(ag(x,m)|0)/4|0;B=(ag(y,u)|0)/8|0;C=((ag(x+1|0,m)|0)/4|0)-A|0;e5f(z,A+o|0,n+B|0,l,r,q,C<<12,((ag(y+1|0,u)|0)/8|0)-B<<13,f);w=w+1|0;}while((w|0)<32)}}while(0);j=j+4|0;}while((j|0)<(i|0));return}function e5x(){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;a[14129040]=19;a[14129041]=15;a[14129042]=-1;if((a[14129032]|0)==0){b=19}else{a[14129040]=18;b=18}if((a[14129033]|0)==0){c=b}else{d=b-2&255;a[14129040]=d;c=d}if((a[14129034]|0)==0){e=c}else{d=c|4;a[14129040]=d;e=d}if((a[14129035]|0)==0){f=e}else{d=e|8;a[14129040]=d;f=d}if((a[14129036]|0)==0){g=f}else{d=f-16&255;a[14129040]=d;g=d}if((a[14129037]|0)==0){h=g}else{d=g|32;a[14129040]=d;h=d}if((a[14129038]|0)==0){i=h}else{d=h|64;a[14129040]=d;i=d}if((a[14129039]|0)!=0){a[14129040]=i|-128}if((a[14129024]|0)==0){j=15}else{a[14129041]=14;j=14}if((a[14129025]|0)==0){k=j}else{i=j-2&255;a[14129041]=i;k=i}if((a[14129026]|0)==0){l=k}else{i=k-4&255;a[14129041]=i;l=i}if((a[14129027]|0)==0){m=l}else{i=l-8&255;a[14129041]=i;m=i}if((a[14129028]|0)==0){n=m}else{i=m|16;a[14129041]=i;n=i}if((a[14129029]|0)==0){o=n}else{i=n|32;a[14129041]=i;o=i}if((a[14129030]|0)==0){p=o}else{i=o|64;a[14129041]=i;p=i}if((a[14129031]|0)==0){return}a[14129041]=p|-128;return}function e5y(){var a=0,d=0,f=0;a=e[7064582]|0;d=c[2112926]|0;gGz(d|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);do{if((b[7064582]&8)==0){if((a&1|0)==0){eX0(0,0,c[3532136]|0)}if((a&2|0)!=0){break}eX3(0,0,c[3532136]|0)}else{if((a&2|0)==0){eX3(0,0,c[3532136]|0)}if((a&1|0)!=0){break}eX0(0,0,c[3532136]|0)}}while(0);e5u(1);e2G(5,c[3532014]<<6,1,0);e5u(0);if((a&4|0)!=0){f=c[3532276]|0;R8(f);return}eX4(0);f=c[3532276]|0;R8(f);return}function e5z(){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;a[14129040]=-13;a[14129041]=-17;a[14129042]=-1;if((a[14129032]|0)==0){b=-13}else{a[14129040]=-14;b=-14}if((a[14129033]|0)==0){c=b}else{d=b-2&255;a[14129040]=d;c=d}if((a[14129034]|0)==0){e=c}else{d=c|4;a[14129040]=d;e=d}if((a[14129035]|0)==0){f=e}else{d=e|8;a[14129040]=d;f=d}if((a[14129036]|0)==0){g=f}else{d=f-16&255;a[14129040]=d;g=d}if((a[14129037]|0)==0){h=g}else{d=g-32&255;a[14129040]=d;h=d}if((a[14129038]|0)==0){i=h}else{d=h-64&255;a[14129040]=d;i=d}if((a[14129039]|0)!=0){a[14129040]=i^-128}if((a[14129024]|0)==0){j=-17}else{a[14129041]=-18;j=-18}if((a[14129025]|0)==0){k=j}else{i=j-2&255;a[14129041]=i;k=i}if((a[14129026]|0)==0){l=k}else{i=k-4&255;a[14129041]=i;l=i}if((a[14129027]|0)==0){m=l}else{i=l-8&255;a[14129041]=i;m=i}if((a[14129028]|0)==0){n=m}else{i=m|16;a[14129041]=i;n=i}if((a[14129029]|0)==0){o=n}else{i=n-32&255;a[14129041]=i;o=i}if((a[14129030]|0)==0){p=o}else{i=o-64&255;a[14129041]=i;p=i}if((a[14129031]|0)==0){return}a[14129041]=p^-128;return}function e5A(){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;a[14129040]=-1;a[14129041]=-1;a[14129042]=-1;if((a[14129032]|0)==0){b=-1}else{a[14129040]=-2;b=-2}if((a[14129033]|0)==0){c=b}else{d=b-2&255;a[14129040]=d;c=d}if((a[14129034]|0)==0){e=c}else{d=c-4&255;a[14129040]=d;e=d}if((a[14129035]|0)==0){f=e}else{d=e-8&255;a[14129040]=d;f=d}if((a[14129036]|0)==0){g=f}else{d=f-16&255;a[14129040]=d;g=d}if((a[14129037]|0)==0){h=g}else{d=g-32&255;a[14129040]=d;h=d}if((a[14129038]|0)==0){i=h}else{d=h-64&255;a[14129040]=d;i=d}if((a[14129039]|0)!=0){a[14129040]=i^-128}if((a[14129016]|0)==0){j=-1}else{a[14129042]=-2;j=-2}if((a[14129017]|0)==0){k=j}else{i=j-2&255;a[14129042]=i;k=i}if((a[14129018]|0)==0){l=k}else{i=k-4&255;a[14129042]=i;l=i}if((a[14129019]|0)==0){m=l}else{i=l-8&255;a[14129042]=i;m=i}if((a[14129020]|0)==0){n=m}else{i=m-16&255;a[14129042]=i;n=i}if((a[14129021]|0)==0){o=n}else{i=n-32&255;a[14129042]=i;o=i}if((a[14129022]|0)==0){p=o}else{i=o-64&255;a[14129042]=i;p=i}if((a[14129023]|0)==0){return}a[14129042]=p^-128;return}function e5B(){var a=0,d=0,e=0,f=0,g=0,h=0;a=b[7064582]|0;d=c[2112926]|0;gGz(d|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);d=c[3532028]|0;e=0;f=c[3532026]|0;g=d;while(1){h=b[f>>1]|0;c[g>>2]=((h&65535)>>>10<<3&248)>>>3|((h&255)<<3&255)<<8|(((h&65535)>>>7&4|(h&65535)>>>5<<3&255)&255)<<3&2016;h=e+1|0;if((h|0)<4096){e=h;f=f+2|0;g=g+4|0}else{break}}g=a&65535;do{if((b[7064582]&8)==0){if((g&1|0)==0){eX0(0,1,c[3532136]|0)}if((g&2|0)!=0){break}eX3(0,0,c[3532136]|0)}else{if((g&2|0)==0){eX3(0,1,c[3532136]|0)}if((g&1|0)!=0){break}eX0(0,0,c[3532136]|0)}}while(0);e5w(1,8,2048);e2G(-1,192,0,1);e5w(0,8,2048);if((g&4|0)!=0){R8(d);return}eX4(0);R8(d);return}function e5C(){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;a[14129040]=-1;a[14129041]=-1;a[14129042]=-1;if((a[14129032]|0)==0){b=-1}else{a[14129040]=-2;b=-2}if((a[14129033]|0)==0){c=b}else{d=b-2&255;a[14129040]=d;c=d}if((a[14129034]|0)==0){e=c}else{d=c-4&255;a[14129040]=d;e=d}if((a[14129035]|0)==0){f=e}else{d=e-8&255;a[14129040]=d;f=d}if((a[14129036]|0)==0){g=f}else{d=f-16&255;a[14129040]=d;g=d}if((a[14129037]|0)==0){h=g}else{d=g-32&255;a[14129040]=d;h=d}if((a[14129038]|0)==0){i=h}else{d=h-64&255;a[14129040]=d;i=d}if((a[14129039]|0)!=0){a[14129040]=i^-128}if((a[14129024]|0)==0){j=-1}else{a[14129041]=-2;j=-2}if((a[14129025]|0)==0){k=j}else{i=j-2&255;a[14129041]=i;k=i}if((a[14129026]|0)==0){l=k}else{i=k-4&255;a[14129041]=i;l=i}if((a[14129027]|0)==0){m=l}else{i=l-8&255;a[14129041]=i;m=i}if((a[14129028]|0)==0){n=m}else{i=m-16&255;a[14129041]=i;n=i}if((a[14129029]|0)==0){o=n}else{i=n-32&255;a[14129041]=i;o=i}if((a[14129030]|0)==0){p=o}else{i=o-64&255;a[14129041]=i;p=i}if((a[14129031]|0)==0){return}a[14129041]=p^-128;return}function e5D(){var a=0,d=0,f=0;a=e[7064582]|0;d=c[2112926]|0;gGz(d|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);do{if((b[7064582]&8)==0){if((a&1|0)==0){eX0(0,1,c[3532136]|0)}if((a&2|0)!=0){break}eX3(0,0,c[3532136]|0)}else{if((a&2|0)==0){eX3(0,1,c[3532136]|0)}if((a&1|0)!=0){break}eX0(0,0,c[3532136]|0)}}while(0);e5E(1);e2G(-1,0,2,1);e5E(0);if((a&4|0)!=0){f=c[3532276]|0;R8(f);return}eX4(0);f=c[3532276]|0;R8(f);return}function e5E(a){a=a|0;var b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;b=c[3531976]|0;d=c[3531970]|0;f=c[3531962]|0;g=508;do{h=e[d+((g|1)<<1)>>1]|0;do{if((h>>>15|0)==(a|0)){i=h>>>14&1;j=h&511;k=e[d+((g|3)<<1)>>1]|0;l=k>>>15;m=k&8191;if((m|0)==0){break}k=e[d+(g<<1)>>1]|0;n=k&511;o=e[d+((g|2)<<1)>>1]|0;p=o>>>8;q=m<<5;m=(o&63)+1|0;o=(k>>>9&63)+1|0;k=n+3|0;r=j>>>0>320?h|-512:j;j=(i|0)!=0;s=(l|0)!=0;t=(k>>>0>320?n-509|0:k)-16|0;k=c[3532034]|0;n=0;do{u=(n|0)%4|0;v=(n|0)/4|0;w=k+65535&(e[b+((j?3-u|0:u)+q+((s?7-v|0:v)<<2)<<1)>>1]|0);x=(ag(u,m)|0)/4|0;y=(ag(v,o)|0)/8|0;z=((ag(u+1|0,m)|0)/4|0)-x|0;e5f(w,x+r|0,t+y|0,p,i,l,z<<12,((ag(v+1|0,o)|0)/8|0)-y<<13,f);n=n+1|0;}while((n|0)<32)}}while(0);g=g-4|0;}while((g|0)>-1);return}function e5F(d,f,g){d=d|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;h=c[3540978]|0;i=h;j=(c[2437032]|0)==0;L57643:do{if(j){k=h+16384|0;l=k;if((k|0)==0){m=1;n=0;break}else{o=0}while(1){if((o|0)>=512){m=1;n=l;break L57643}if((b[l+(o<<1)>>1]|0)==0){o=o+1|0}else{m=0;n=l;break}}}else{m=1;n=0}}while(0);o=(d|0)==0;d=c[3527054]|0;h=(c[2437030]|0)+65535|0;l=c[2438630]|0;k=c[2438626]|0;p=0;q=0;while(1){if((d|0)>0){r=(q<<3)-k|0;s=p;t=0;while(1){u=s<<1;if(j){v=u;w=h&e[i+((u|1)<<1)>>1]}else{v=s;w=b[i+(s+8192<<1)>>1]&16383}u=e[i+(v<<1)>>1]|0;x=u&511;y=u>>>14&1;z=u>>>15;u=(t<<3)-16-l|0;L57659:do{if(m){A=c[2388342]|0;do{if(j){B=u-(A&511)|0;C=(B|0)<-8?B+512|0:B;if((C|0)<=511){D=C;break}D=C-512|0}else{C=u-(A&1023)|0;B=(C|0)<-8?C+1024|0:C;if((B|0)<=1023){D=B;break}D=B-1024|0}}while(0);A=r-(c[2388332]&511)|0;B=(A|0)<-8?A+512|0:A;A=(B|0)>511?B-512|0:B;B=(D|0)>8;if(o){do{if(B){if(!((D|0)<((c[2113068]|0)-8|0)&(A|0)>8)){break}if((A|0)>=((c[2113070]|0)-8|0)){break}C=(z|0)!=0;if((y|0)==0){if(C){Su(g,w,D,A,x,4,0,0,f);break L57659}else{Sq(g,w,D,A,x,4,0,0,f);break L57659}}else{if(C){Sw(g,w,D,A,x,4,0,0,f);break L57659}else{Ss(g,w,D,A,x,4,0,0,f);break L57659}}}}while(0);C=(z|0)!=0;if((y|0)==0){if(C){Sv(g,w,D,A,x,4,0,0,f);break}else{Sr(g,w,D,A,x,4,0,0,f);break}}else{if(C){Sx(g,w,D,A,x,4,0,0,f);break}else{St(g,w,D,A,x,4,0,0,f);break}}}else{do{if(B){if(!((D|0)<((c[2113068]|0)-8|0)&(A|0)>8)){break}if((A|0)>=((c[2113070]|0)-8|0)){break}C=(z|0)!=0;if((y|0)==0){if(C){Sm(g,w,D,A,x,4,0,f);break L57659}else{Si(g,w,D,A,x,4,0,f);break L57659}}else{if(C){So(g,w,D,A,x,4,0,f);break L57659}else{Sk(g,w,D,A,x,4,0,f);break L57659}}}}while(0);B=(z|0)!=0;if((y|0)==0){if(B){Sn(g,w,D,A,x,4,0,f);break}else{Sj(g,w,D,A,x,4,0,f);break}}else{if(B){Sp(g,w,D,A,x,4,0,f);break}else{Sl(g,w,D,A,x,4,0,f);break}}}}else{B=x<<4;C=w<<6;E=(y|0)!=0;F=(z|0)!=0;G=E&F;H=c[2113070]|0;I=c[2113068]|0;J=0;do{K=(7-J<<3)+C|0;L=J+r|0;M=(J<<3)+C|0;if(F){N=0;do{O=a[f+(K+(G?7-N|0:N))|0]|0;do{if(!(O<<24>>24==0&o)){P=N+u|0;Q=L-(c[2388332]&511)|0;R=(Q|0)<-8?Q+512|0:Q;Q=(R|0)>511?R-512|0:R;if(!((Q|0)>-1&(Q|0)<(H|0))){break}R=c[2388342]|0;do{if(j){S=P-(R-(e[n+(k+Q<<1)>>1]|0)&511)|0;T=(S|0)<-8?S+512|0:S;U=(T|0)>511?T-512|0:T}else{T=P-(R&1023)|0;S=(T|0)<-8?T+1024|0:T;if((S|0)<=1023){U=S;break}U=S-1024|0}}while(0);if(!((U|0)>-1&(U|0)<(I|0))){break}b[g+((ag(I,Q)|0)+U<<1)>>1]=(O&255|B)&65535}}while(0);N=N+1|0;}while((N|0)<8)}else{N=0;do{K=a[f+(M+(E?7-N|0:N))|0]|0;do{if(!(K<<24>>24==0&o)){O=N+u|0;R=L-(c[2388332]&511)|0;P=(R|0)<-8?R+512|0:R;R=(P|0)>511?P-512|0:P;if(!((R|0)>-1&(R|0)<(H|0))){break}P=c[2388342]|0;do{if(j){S=O-(P-(e[n+(k+R<<1)>>1]|0)&511)|0;T=(S|0)<-8?S+512|0:S;V=(T|0)>511?T-512|0:T}else{T=O-(P&1023)|0;S=(T|0)<-8?T+1024|0:T;if((S|0)<=1023){V=S;break}V=S-1024|0}}while(0);if(!((V|0)>-1&(V|0)<(I|0))){break}b[g+((ag(I,R)|0)+V<<1)>>1]=(K&255|B)&65535}}while(0);N=N+1|0;}while((N|0)<8)}J=J+1|0;}while((J|0)<8)}}while(0);u=s+1|0;z=t+1|0;if((z|0)<(d|0)){s=u;t=z}else{W=u;break}}}else{W=p}t=q+1|0;if((t|0)<64){p=W;q=t}else{break}}return}function e5G(a,f,g,h){a=a|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0;i=c[14163912+(a<<2)>>2]|0;j=i+32768|0;k=(c[9748128+(a<<2)>>2]|0)==0;L57749:do{if(k){l=i+49152|0;m=l;if((l|0)==0){n=1;o=0;break}else{p=0}while(1){if((p|0)>=512){n=1;o=m;break L57749}if((b[m+(p<<1)>>1]|0)==0){p=p+1|0}else{n=0;o=m;break}}}else{n=1;o=0}}while(0);p=9748120+(a<<2)|0;i=9754520+(a<<2)|0;m=9754504+(a<<2)|0;l=9543296+(a<<2)|0;q=9543272+(a<<2)|0;r=(f|0)==0;f=9708200+(a<<2)|0;s=c[14108216+(a<<2)>>2]|0;a=0;t=0;while(1){if((s|0)>0){u=c[i>>2]|0;v=c[m>>2]|0;w=(t<<3)-v|0;x=a;y=0;while(1){z=x<<1;if(k){A=z;B=(c[p>>2]|0)+65535&e[j+((z|1)<<1)>>1]}else{A=x;B=b[j+(x+8192<<1)>>1]&16383}z=e[j+(A<<1)>>1]|0;C=z&511;D=z>>>14&1;E=z>>>15;z=(y<<3)-16-u|0;L57765:do{if(n){F=c[l>>2]|0;do{if(k){G=z-(F&511)|0;H=(G|0)<-8?G+512|0:G;if((H|0)<=511){I=H;break}I=H-512|0}else{H=z-(F&1023)|0;G=(H|0)<-8?H+1024|0:H;if((G|0)<=1023){I=G;break}I=G-1024|0}}while(0);F=w-(c[q>>2]&511)|0;G=(F|0)<-8?F+512|0:F;F=(G|0)>511?G-512|0:G;G=(I|0)>8;if(r){do{if(G){if(!((I|0)<((c[2113068]|0)-8|0)&(F|0)>8)){break}if((F|0)>=((c[2113070]|0)-8|0)){break}H=(E|0)!=0;J=c[f>>2]|0;if((D|0)==0){if(H){Su(h,B,I,F,C,4,J,0,g);break L57765}else{Sq(h,B,I,F,C,4,J,0,g);break L57765}}else{if(H){Sw(h,B,I,F,C,4,J,0,g);break L57765}else{Ss(h,B,I,F,C,4,J,0,g);break L57765}}}}while(0);J=(E|0)!=0;H=c[f>>2]|0;if((D|0)==0){if(J){Sv(h,B,I,F,C,4,H,0,g);break}else{Sr(h,B,I,F,C,4,H,0,g);break}}else{if(J){Sx(h,B,I,F,C,4,H,0,g);break}else{St(h,B,I,F,C,4,H,0,g);break}}}else{do{if(G){if(!((I|0)<((c[2113068]|0)-8|0)&(F|0)>8)){break}if((F|0)>=((c[2113070]|0)-8|0)){break}H=(E|0)!=0;if((D|0)==0){if(H){Sm(h,B,I,F,C,4,0,g);break L57765}else{Si(h,B,I,F,C,4,0,g);break L57765}}else{if(H){So(h,B,I,F,C,4,0,g);break L57765}else{Sk(h,B,I,F,C,4,0,g);break L57765}}}}while(0);G=(E|0)!=0;if((D|0)==0){if(G){Sn(h,B,I,F,C,4,0,g);break}else{Sj(h,B,I,F,C,4,0,g);break}}else{if(G){Sp(h,B,I,F,C,4,0,g);break}else{Sl(h,B,I,F,C,4,0,g);break}}}}else{G=C<<4;H=B<<6;J=(D|0)!=0;K=(E|0)!=0;L=J&K;M=c[f>>2]|0;N=c[2113070]|0;O=c[2113068]|0;P=0;do{Q=(7-P<<3)+H|0;R=P+w|0;S=(P<<3)+H|0;T=0;do{U=7-T|0;do{if(K){if(L){V=g+(U+Q)|0;break}else{V=g+(T+Q)|0;break}}else{V=g+(S+(J?U:T))|0}}while(0);U=d[V]|0;do{if(!((U|0)==(M|0)&r)){W=T+z|0;X=R-(c[q>>2]&511)|0;Y=(X|0)<-8?X+512|0:X;X=(Y|0)>511?Y-512|0:Y;if(!((X|0)>-1&(X|0)<(N|0))){break}Y=c[l>>2]|0;do{if(k){Z=W-(Y-(e[o+(v+X<<1)>>1]|0)&511)|0;_=(Z|0)<-8?Z+512|0:Z;$=(_|0)>511?_-512|0:_}else{_=W-(Y&1023)|0;Z=(_|0)<-8?_+1024|0:_;if((Z|0)<=1023){$=Z;break}$=Z-1024|0}}while(0);if(!(($|0)>-1&($|0)<(O|0))){break}b[h+((ag(O,X)|0)+$<<1)>>1]=(U|G)&65535}}while(0);T=T+1|0;}while((T|0)<8);P=P+1|0;}while((P|0)<8)}}while(0);z=x+1|0;E=y+1|0;if((E|0)<(s|0)){x=z;y=E}else{aa=z;break}}}else{aa=a}y=t+1|0;if((y|0)<64){a=aa;t=y}else{break}}return}function e5H(d,e,f,g,h,i){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0;j=h<<4;h=i+(e<<6)|0;c[2112928]=h;e=d+(f+3584+(g<<9)<<1)|0;g=7;f=h;while(1){h=a[f]|0;if(h<<24>>24!=0){b[e+14>>1]=(h&255|j)&65535}h=a[f+1|0]|0;if(h<<24>>24!=0){b[e+12>>1]=(h&255|j)&65535}h=a[f+2|0]|0;if(h<<24>>24!=0){b[e+10>>1]=(h&255|j)&65535}h=a[f+3|0]|0;if(h<<24>>24!=0){b[e+8>>1]=(h&255|j)&65535}h=a[f+4|0]|0;if(h<<24>>24!=0){b[e+6>>1]=(h&255|j)&65535}h=a[f+5|0]|0;if(h<<24>>24!=0){b[e+4>>1]=(h&255|j)&65535}h=a[f+6|0]|0;if(h<<24>>24!=0){b[e+2>>1]=(h&255|j)&65535}h=a[f+7|0]|0;if(h<<24>>24!=0){b[e>>1]=(h&255|j)&65535}k=f+8|0;if((g|0)>0){e=e-1024|0;g=g-1|0;f=k}else{break}}c[2112928]=k;return}function e5I(d,e,f,g,h,i){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0;j=h<<4;h=i+(e<<6)|0;c[2112928]=h;e=d+((g<<9)+f<<1)|0;f=0;g=h;while(1){h=a[g]|0;if(h<<24>>24!=0){b[e+14>>1]=(h&255|j)&65535}h=a[g+1|0]|0;if(h<<24>>24!=0){b[e+12>>1]=(h&255|j)&65535}h=a[g+2|0]|0;if(h<<24>>24!=0){b[e+10>>1]=(h&255|j)&65535}h=a[g+3|0]|0;if(h<<24>>24!=0){b[e+8>>1]=(h&255|j)&65535}h=a[g+4|0]|0;if(h<<24>>24!=0){b[e+6>>1]=(h&255|j)&65535}h=a[g+5|0]|0;if(h<<24>>24!=0){b[e+4>>1]=(h&255|j)&65535}h=a[g+6|0]|0;if(h<<24>>24!=0){b[e+2>>1]=(h&255|j)&65535}h=a[g+7|0]|0;if(h<<24>>24!=0){b[e>>1]=(h&255|j)&65535}h=f+1|0;k=g+8|0;if((h|0)<8){e=e+1024|0;f=h;g=k}else{break}}c[2112928]=k;return}function e5J(d,e,f,g,h,i){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0;j=h<<4;h=i+(e<<6)|0;c[2112928]=h;e=d+(f+3584+(g<<9)<<1)|0;g=7;f=h;while(1){h=a[f]|0;if(h<<24>>24!=0){b[e>>1]=(h&255|j)&65535}h=a[f+1|0]|0;if(h<<24>>24!=0){b[e+2>>1]=(h&255|j)&65535}h=a[f+2|0]|0;if(h<<24>>24!=0){b[e+4>>1]=(h&255|j)&65535}h=a[f+3|0]|0;if(h<<24>>24!=0){b[e+6>>1]=(h&255|j)&65535}h=a[f+4|0]|0;if(h<<24>>24!=0){b[e+8>>1]=(h&255|j)&65535}h=a[f+5|0]|0;if(h<<24>>24!=0){b[e+10>>1]=(h&255|j)&65535}h=a[f+6|0]|0;if(h<<24>>24!=0){b[e+12>>1]=(h&255|j)&65535}h=a[f+7|0]|0;if(h<<24>>24!=0){b[e+14>>1]=(h&255|j)&65535}k=f+8|0;if((g|0)>0){e=e-1024|0;g=g-1|0;f=k}else{break}}c[2112928]=k;return}function e5K(d,e,f,g,h,i){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0;j=h<<4;h=i+(e<<6)|0;c[2112928]=h;e=d+((g<<9)+f<<1)|0;f=0;g=h;while(1){h=a[g]|0;if(h<<24>>24!=0){b[e>>1]=(h&255|j)&65535}h=a[g+1|0]|0;if(h<<24>>24!=0){b[e+2>>1]=(h&255|j)&65535}h=a[g+2|0]|0;if(h<<24>>24!=0){b[e+4>>1]=(h&255|j)&65535}h=a[g+3|0]|0;if(h<<24>>24!=0){b[e+6>>1]=(h&255|j)&65535}h=a[g+4|0]|0;if(h<<24>>24!=0){b[e+8>>1]=(h&255|j)&65535}h=a[g+5|0]|0;if(h<<24>>24!=0){b[e+10>>1]=(h&255|j)&65535}h=a[g+6|0]|0;if(h<<24>>24!=0){b[e+12>>1]=(h&255|j)&65535}h=a[g+7|0]|0;if(h<<24>>24!=0){b[e+14>>1]=(h&255|j)&65535}h=f+1|0;k=g+8|0;if((h|0)<8){e=e+1024|0;f=h;g=k}else{break}}c[2112928]=k;return}function e5L(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;f=c[3540976]|0;g=f;h=(b[f+7166>>1]&1)==0;f=(a[726072]|0?256:0)|c[3540974]<<4&240;i=c[2437028]|0;j=c[2438624]|0;k=c[2112926]|0;l=1020;do{m=e[g+(l<<1)>>1]|0;n=m>>>15;o=m>>>14&1;p=f|m&15;m=b[g+((l|2)<<1)>>1]&8191;if((m|0)<(i|0)){q=m}else{q=(m|0)%(i|0)|0}m=e[g+((l|3)<<1)>>1]|0;r=m&511;s=e[g+((l|1)<<1)>>1]|0;t=s&511;u=r>>>0>320?m|-512:r;r=t>>>0>320?s|-512:t;if(h){v=o^1;w=240-r|0;x=304-u|0;y=n^1}else{v=o;w=r;x=u;y=n}n=w-j|0;do{if((x|0)>16){if(!((x|0)<((c[2113068]|0)-16|0)&(n|0)>16)){z=44260;break}if((n|0)>=((c[2113070]|0)-16|0)){z=44260;break}u=(y|0)!=0;if((v|0)==0){if(u){SK(k,q,x,n,p,4,0,0,d);break}else{SG(k,q,x,n,p,4,0,0,d);break}}else{if(u){SM(k,q,x,n,p,4,0,0,d);break}else{SI(k,q,x,n,p,4,0,0,d);break}}}else{z=44260}}while(0);do{if((z|0)==44260){z=0;u=(y|0)!=0;if((v|0)==0){if(u){SL(k,q,x,n,p,4,0,0,d);break}else{SH(k,q,x,n,p,4,0,0,d);break}}else{if(u){SN(k,q,x,n,p,4,0,0,d);break}else{SJ(k,q,x,n,p,4,0,0,d);break}}}}while(0);l=l-4|0;}while((l|0)>-1);return}function e5M(b){b=b|0;var d=0,e=0,f=0;d=b-10485760|0;L57996:do{if(d>>>0<16384){e=a[(c[2424883]|0)+(d>>>1)|0]|0}else{f=b-12582912|0;if(f>>>0<16){switch(f>>>1|0){case 3:{e=a[14128883]|0;break L57996;break};case 1:{e=a[14128881]|0;break L57996;break};case 4:{e=a[9757524]|0;break L57996;break};case 7:{e=a[14128884]|0;break L57996;break};case 0:{e=a[14128880]|0;break L57996;break};case 2:{e=a[14128882]|0;break L57996;break};default:{e=-1;break L57996}}}f=b-12582944|0;if(f>>>0>=16){e=0;break}if((b|0)==12582950){e=a[14128480]&16|a[14128882]&-17;break}switch(f>>>1|0){case 1:{e=a[14128881]|0;break L57996;break};case 0:{e=a[14128880]|0;break L57996;break};case 4:{e=a[9757524]|0;break L57996;break};case 7:{e=a[14128884]|0;break L57996;break};case 3:{e=a[14128883]|0;break L57996;break};case 2:{e=a[14128882]|0;break L57996;break};default:{e=-1;break L57996}}}}while(0);return e|0}function e5N(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;if(b>>>0<1048576){return}e=b-10485760|0;if(e>>>0<16384){Tt(e>>>1,d);return}e=b-11534336|0;if(e>>>0<32){a[14128984+(e>>>1)|0]=d;return}e=b-12582912|0;if(e>>>0<16){f=e>>>1;a[9757520+f|0]=d;if((f|0)!=0){return}c[3531956]=0;return}if((b-12582928|0)>>>0<32){return}if((b|0)==13631488){a[9540896]=d&15;return}else if((b|0)==13631490){b=d&15;d=a[9540896]|0;switch(d&255|0){case 3:{a[9540896]=d+1&255;a[9540891]=b;a[9540898]=a[9540898]|2;a[9540900]=1;return};case 4:{if(b<<24>>24==0){return}f=c[2439330]|0;e=(f|0)==0;if(!e){g=f;gGC(9706056,g|0,76)|0}g=c[2438118]|0;c[2433530]=g;h=c[3528484]|0;c[2076596]=h;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);if(!e){e=f;gGC(e|0,9706056,76)|0}c[2438118]=g;c[3528484]=h;c[2417276]=i;c[1836236]=-1;return};case 1:{a[9540896]=d+1&255;a[9540889]=b;a[9540898]=a[9540898]|1;a[9540900]=1;return};case 0:{a[9540896]=d+1&255;a[9540888]=b;return};case 2:{a[9540896]=d+1&255;a[9540890]=b;return};default:{return}}}else{return}}function e5O(a){a=a|0;return 0}function e5P(b,d){b=b|0;d=d|0;var e=0;e=b-8585216|0;if(e>>>0<48){eXO(e>>>1,d);return}e=b-12582912|0;if(e>>>0>=16){return}b=e>>>1;a[9757520+b|0]=d&255;if((b|0)!=0){return}c[3531956]=0;return}function e5Q(a){a=a|0;var b=0;if((a|0)==14680066){b=~~(+((~~(+((c[3542192]>>8)+8|0)/+(c[2440574]|0)*255.0)&255)>>>0)*.00390625*112.0)+8&255;return b|0}else if((a|0)==14680068){b=~~(+(~(~~(+((c[3542197]>>8)+8|0)/+(c[2440576]|0)*255.0)&255)|0)*.00390625*160.0)-91&255;return b|0}else if((a|0)==14680064){b=~~(+(~(~~(+((c[3542196]>>8)+8|0)/+(c[2440576]|0)*255.0)&255)|0)*.00390625*160.0)-91&255;return b|0}else if((a|0)==14680070){b=~~(+((~~(+((c[3542193]>>8)+8|0)/+(c[2440574]|0)*255.0)&255)>>>0)*.00390625*112.0)+8&255;return b|0}else{b=0;return b|0}return 0}function e5R(a,b){a=a|0;b=b|0;if(!((a|0)==14680064|(a|0)==14680066|(a|0)==14680068|(a|0)==14680070)){return}c[8452200+(c[2394]<<2)>>2]=8195;c[2276080]=768;if((c[2276079]|0)>>>0>=768){return}RH(3);return}function e5S(a){a=a|0;return 0}function e5T(a,b){a=a|0;b=b|0;return}function e5U(b){b=b|0;var d=0,e=0,f=0.0,g=0.0,i=0,j=0;d=b&65535;if((d|0)==57857){e=fdZ()|0;return e|0}else if((d|0)==57344){d=c[3541514]|0;b=d+552|0;f=+h[b>>3];do{if(f!=0.0){g=+h[6675];if(f-(g+ +gC[c[2429842]&255]())>0.0){i=a[d+563|0]|-128;break}else{h[b>>3]=0.0;j=44364;break}}else{j=44364}}while(0);if((j|0)==44364){i=a[d+563|0]|0}e=i&-125;return e|0}else{e=0;return e|0}return 0}function e5V(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;switch(b&65535|0){case 57344:{b=c[3541514]|0;a[b+560|0]=d;a[b+20408|0]=0;if((d&255)>=16){return}c[14168912+((c[2383582]|0)*252|0)>>2]=d&15;return};case 57856:{a[9540897]=d&15;return};case 57857:{fd_(d);return};case 57345:{l7(1,d);return};case 57346:{b=c[3541514]|0;a[b+560|0]=d;a[b+20408|0]=1;return};case 57347:{l7(3,d);return};case 61952:{b=d+7&7;a[14127752]=b;d=c[3531932]|0;e=(b&255)<<14;b=c[9757320+(c[1836236]<<2)>>2]|0;f=64;g=64;while(1){c[b+76+(g<<2)>>2]=d+((g<<8)+e);h=f+1&65535;if((h&65535)>127){i=64;j=64;break}else{f=h;g=h&65535}}while(1){g=d+((j<<8)+e)|0;c[b+76+(j+512<<2)>>2]=g;c[b+76+(j+768<<2)>>2]=g;g=i+1&65535;if((g&65535)>127){break}else{i=g;j=g&65535}}return};default:{return}}}function e5W(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3428476+(b*112|0)>>2];c[a+104>>2]=c[3428480+(b*112|0)>>2];c[a+108>>2]=c[3428484+(b*112|0)>>2];d=0;return d|0}function e5X(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=3428376+(b*112|0);e=0;return e|0}function e5Y(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1192456+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function e5Z(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>3){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3429384+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e5_(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;b=i;i=i+120|0;e=b|0;f=b+112|0;c[3532162]=1024;c[3532160]=4;c[3532142]=16;c[3532164]=16;c[3532148]=1983624;c[3532140]=6964152;c[3532138]=6963896;c[3532042]=8192;c[3532002]=1024;c[3532e3]=6;a[7460944]=1;c[3532004]=16;c[3531998]=961368;c[3531992]=4969432;c[3531990]=4968984;c[3532034]=16384;if((e6a()|0)==0){g=0}else{h=1;i=b;return h|0}while(1){if((g|0)>=1024){j=0;break}k=9638528+(g<<2)|0;if((c[k>>2]|0)==0){l=44421;break}else{g=g+1|0}}do{if((l|0)==44421){g=gGq(4194304)|0;c[k>>2]=g;if((g|0)==0){j=0;break}gGz(g|0,0,4194304);j=g}}while(0);gGz(j|0,0,4194304);if((R6(j,6,2)|0)!=0){h=1;i=b;return h|0}if((R6(j+1|0,7,2)|0)!=0){h=1;i=b;return h|0}k=j+3145728|0;if((c[3542200]|0)==0){h=1;i=b;return h|0}g=e+108|0;c[g>>2]=0;m=e+100|0;c[m>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,8)|0;do{if((c[g>>2]|0)==0){n=3145728;o=2097152}else{e=c[m>>2]|0;c[f>>2]=9534384;p=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[p&16383](f,8,0)|0;if((e|0)<1){h=1;i=b;return h|0}if((gzL(k,0,8)|0)==0){n=3145728;o=2097152;break}else{h=1}i=b;return h|0}}while(0);while(1){k=a[j+n|0]|0;a[j+o|0]=k<<2&12|(k&255)>>>2<<6;a[j+(o|1)|0]=(k&255)>>>4<<2&12|k&-64;k=n+1|0;if((k|0)<4194304){n=k;o=o+2|0}else{break}}o=c[3532034]|0;n=c[3532e3]|0;k=a[7460944]|0;f=k?16:0;m=c[3532004]|0;g=c[3531998]|0;e=c[3531992]|0;p=c[3531990]|0;q=c[3532002]|0;r=c[3531962]|0;if((o|0)>0){s=ag(m,f)|0;t=(n|0)>0;u=n-1|0;v=(m|0)<1|k^1;k=0;while(1){w=ag(k,s)|0;gGz(r+w|0,0,s|0);if(t){x=ag(k,q)|0;y=0;do{z=1<<u-y;A=(c[g+(y<<2)>>2]|0)+x|0;if(!v){B=0;do{C=A+(c[p+(B<<2)>>2]|0)|0;D=(ag(B,f)|0)+w|0;E=0;do{F=C+(c[e+(E<<2)>>2]|0)|0;if(((d[j+((F|0)/8|0)|0]|0)&128>>>((F&7)>>>0)|0)!=0){F=r+(D+E)|0;a[F]=(d[F]|0|z)&255}E=E+1|0;}while((E|0)<(f|0));B=B+1|0;}while((B|0)<(m|0))}y=y+1|0;}while((y|0)<(n|0))}y=k+1|0;if((y|0)<(o|0)){k=y}else{G=0;break}}}else{G=0}while(1){if((G|0)>=1024){break}H=9638528+(G<<2)|0;if((c[H>>2]|0)==(j|0)){l=44444;break}else{G=G+1|0}}if((l|0)==44444){gGr(j);c[H>>2]=0}eZ8()|0;h=0;i=b;return h|0}function e5$(){e_a()|0;if(a[727232]|0){gGr(c[2424883]|0);c[2424883]=0}a[727232]=0;gGz(9699520|0,0|0,64|0);return 0}function e50(){var d=0,e=0,f=0,g=0,h=0;if((a[14128072]|0)!=0){eZ8()|0}gu[c[3532050]&16383]();c[2113031]=0;c[2113030]=0;d=c[2392]|0;if((d|0)>=0){gGz(8452240,0,((d|0)>0?(d<<2)+4|0:4)|0)}c[2113054]=0;d=c[2385548]|0;if((d|0)>0){gGz(9752472,0,((d|0)>1?d<<2:4)|0)}c[2433530]=0;if(((c[2113222]|0)%60|0|0)==0){Tu();e=0}else{e=0}while(1){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}d=e+1|0;f=(ag(c[2113026]|0,d)|0)/100|0;g=f-(c[2113030]|0)|0;c[2113028]=g;c[2113056]=g;f=RG(g)|0;c[2113054]=(c[2113054]|0)+f;c[2276108]=-1;c[2113056]=-1;c[2113030]=(c[2113030]|0)+f;do{if((e|0)==10){c[8452200+(c[2394]<<2)>>2]=8198;c[2276080]=1536;if((c[2276079]|0)>>>0<1536){RH(6)}c[2113056]=199500;f=RG(199500)|0;c[2113054]=(c[2113054]|0)+f;c[2276108]=-1;c[2113056]=-1;c[2113030]=(c[2113030]|0)+f}else if((e|0)==99){c[8452200+(c[2394]<<2)>>2]=8197;c[2276080]=1280;if((c[2276079]|0)>>>0>=1280){break}RH(5)}}while(0);f=c[2394]|0;g=c[14130368+(f<<2)>>2]|0;if((g|0)!=0){gGC(g|0,9104152,280)|0}c[8452240+(f<<2)>>2]=c[2113054];c[2394]=-1;f=c[2439330]|0;if((f|0)!=0){g=f;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;Sb(ag((c[2113024]|0)/100|0,e)|0);g=c[1836236]|0;f=c[9757320+(g<<2)>>2]|0;if((f|0)!=0){h=f;gGC(h|0,9706056,76)|0}c[9752472+(g<<2)>>2]=c[2433530];c[14113936+(g<<2)>>2]=c[2076596];c[9669104+(g<<2)>>2]=c[3541536];c[1836236]=-1;if((d|0)<100){e=d}else{break}}e=c[2439330]|0;if((e|0)!=0){g=e;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;g=c[2113024]|0;e=gGU(g,(g|0)<0|0?-1:0,2048e6,0)|0;h=c[2438228]|0;f=gGS(e,K,h,(h|0)<0|0?-1:0)|0;h=f;Sb(g);g=c[2443830]|0;if((g|0)<1073676288){c[2443830]=g-h}g=c[2443831]|0;if((g|0)<1073676288){c[2443831]=g-h}g=(c[3528512]|0)-h|0;c[3528512]=(g|0)<0?0:g;gg[c[3542118]&4095](c[2112964]|0,a[9688]|0?534:0);g=c[1836236]|0;h=c[9757320+(g<<2)>>2]|0;if((h|0)!=0){f=h;gGC(f|0,9706056,76)|0}c[9752472+(g<<2)>>2]=c[2433530];c[14113936+(g<<2)>>2]=c[2076596];c[9669104+(g<<2)>>2]=c[3541536];c[1836236]=-1;if(a[7461160]|0){g=c[3531966]|0;f=c[3531970]|0;gGC(g|0,f|0,65536)|0;a[7461160]=0}if((c[2112968]|0)==0){ffV();a[7461160]=1;return 0}gu[c[3532118]&16383]();ffV();a[7461160]=1;return 0}function e51(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;f=i;i=i+176|0;g=f|0;h=f+16|0;j=f+32|0;k=f+48|0;l=f+64|0;m=f+80|0;n=f+96|0;o=f+112|0;p=f+128|0;q=f+144|0;r=f+160|0;if((e|0)!=0){c[e>>2]=169737}if((d&32|0)!=0){gGz(r|0,0,12);s=c[3532020]|0;c[r>>2]=s;c[r+4>>2]=(c[3532022]|0)-s;c[r+12>>2]=162152;s=c[2076592]|0;gj[s&4095](r)|0}eZ7(d);if((d&8|0)!=0){gGz(k|0,0,12);c[k>>2]=c[2424883];c[k+4>>2]=c[2424885];c[k+12>>2]=174400;r=c[2076592]|0;gj[r&4095](k)|0}if((d&64|0)!=0){k=j|0;gGz(h|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){r=j+9|0;j=g;s=g|0;t=g+4|0;u=g+12|0;v=h|0;w=h+4|0;x=h+12|0;y=0;do{gGC(k|0,614896,11)|0;a[r]=y+48&255;z=8452256+(y<<2)|0;gGz(j|0,0,12);c[s>>2]=z;c[t>>2]=4;c[u>>2]=164976;gj[c[2076592]&4095](g)|0;if((c[z>>2]|0)!=0){c[v>>2]=c[14130368+(y<<2)>>2];c[w>>2]=c[8452184+(y<<2)>>2];c[x>>2]=k;z=c[2076592]|0;gj[z&4095](h)|0}y=y+1|0;}while((y|0)<=(c[2392]|0))}fw$(d);T0(d,e);gGz(q|0,0,12);c[q>>2]=14128880;c[q+4>>2]=5;c[q+12>>2]=202120;e=c[2076592]|0;gj[e&4095](q)|0;gGz(p|0,0,12);c[p>>2]=14127752;c[p+4>>2]=1;c[p+12>>2]=272344;q=c[2076592]|0;gj[q&4095](p)|0;gGz(o|0,0,12);c[o>>2]=8452120;c[o+4>>2]=16;c[o+12>>2]=270496;p=c[2076592]|0;gj[p&4095](o)|0;gGz(n|0,0,12);c[n>>2]=8452112;c[n+4>>2]=4;c[n+12>>2]=269664;o=c[2076592]|0;gj[o&4095](n)|0;gGz(m|0,0,12);c[m>>2]=14128432;c[m+4>>2]=16;c[m+12>>2]=271896;n=c[2076592]|0;gj[n&4095](m)|0;gGz(l|0,0,12);c[l>>2]=14128416;c[l+4>>2]=16;c[l+12>>2]=271088;m=c[2076592]|0;gj[m&4095](l)|0}l=a[14127752]|0;if(!((d&2|0)!=0&l<<24>>24!=0)){i=f;return 0}d=c[2439330]|0;m=(d|0)==0;if(!m){n=d;gGC(9706056,n|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];n=c[3528484]|0;c[2076596]=n;o=c[2417276]|0;c[3541536]=o;c[1836236]=0;p=c[3531932]|0;q=(l&255)<<14;l=64;e=64;while(1){c[d+76+(e<<2)>>2]=p+((e<<8)+q);y=l+1&65535;if((y&65535)>127){A=64;B=64;break}else{l=y;e=y&65535}}while(1){e=p+((B<<8)+q)|0;c[d+76+(B+512<<2)>>2]=e;c[d+76+(B+768<<2)>>2]=e;e=A+1&65535;if((e&65535)>127){break}else{A=e;B=e&65535}}if(!m){m=d;gGC(m|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=n;c[2417276]=o;c[1836236]=-1;i=f;return 0}function e52(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5194836+(b*112|0)>>2];c[a+104>>2]=c[5194840+(b*112|0)>>2];c[a+108>>2]=c[5194844+(b*112|0)>>2];d=0;return d|0}function e53(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=5194736+(b*112|0);e=0;return e|0}function e54(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1795480+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function e55(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>3){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5195968+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e56(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;b=i;i=i+120|0;e=b|0;f=b+112|0;c[3532162]=1024;c[3532160]=4;c[3532142]=16;c[3532164]=16;c[3532148]=1983624;c[3532140]=6964152;c[3532138]=6963896;c[3532042]=32768;c[3532002]=1024;c[3532e3]=6;a[7460944]=1;c[3532004]=16;c[3531998]=683208;c[3531992]=4969432;c[3531990]=4968984;c[3532034]=32768;if((e6a()|0)==0){g=0}else{h=1;i=b;return h|0}while(1){if((g|0)>=1024){j=0;break}k=9638528+(g<<2)|0;if((c[k>>2]|0)==0){l=44551;break}else{g=g+1|0}}do{if((l|0)==44551){g=gGq(8388608)|0;c[k>>2]=g;if((g|0)==0){j=0;break}gGz(g|0,0,8388608);j=g}}while(0);gGz(j|0,0,4194304);if((R6(j,8,2)|0)!=0){h=1;i=b;return h|0}if((R6(j+1|0,9,2)|0)!=0){h=1;i=b;return h|0}k=j+6291456|0;if((c[3542200]|0)==0){h=1;i=b;return h|0}g=e+108|0;c[g>>2]=0;m=e+100|0;c[m>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,10)|0;do{if((c[g>>2]|0)==0){n=6291456;o=4194304}else{e=c[m>>2]|0;c[f>>2]=9534384;p=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[p&16383](f,10,0)|0;if((e|0)<1){h=1;i=b;return h|0}if((gzL(k,0,10)|0)==0){n=6291456;o=4194304;break}else{h=1}i=b;return h|0}}while(0);while(1){k=a[j+n|0]|0;a[j+o|0]=k<<2&12|(k&255)>>>2<<6;a[j+(o|1)|0]=(k&255)>>>4<<2&12|k&-64;k=n+1|0;if((k|0)<8388608){n=k;o=o+2|0}else{break}}o=c[3532034]|0;n=c[3532e3]|0;k=a[7460944]|0;f=k?16:0;m=c[3532004]|0;g=c[3531998]|0;e=c[3531992]|0;p=c[3531990]|0;q=c[3532002]|0;r=c[3531962]|0;if((o|0)>0){s=ag(m,f)|0;t=(n|0)>0;u=n-1|0;v=(m|0)<1|k^1;k=0;while(1){w=ag(k,s)|0;gGz(r+w|0,0,s|0);if(t){x=ag(k,q)|0;y=0;do{z=1<<u-y;A=(c[g+(y<<2)>>2]|0)+x|0;if(!v){B=0;do{C=A+(c[p+(B<<2)>>2]|0)|0;D=(ag(B,f)|0)+w|0;E=0;do{F=C+(c[e+(E<<2)>>2]|0)|0;if(((d[j+((F|0)/8|0)|0]|0)&128>>>((F&7)>>>0)|0)!=0){F=r+(D+E)|0;a[F]=(d[F]|0|z)&255}E=E+1|0;}while((E|0)<(f|0));B=B+1|0;}while((B|0)<(m|0))}y=y+1|0;}while((y|0)<(n|0))}y=k+1|0;if((y|0)<(o|0)){k=y}else{G=0;break}}}else{G=0}while(1){if((G|0)>=1024){break}H=9638528+(G<<2)|0;if((c[H>>2]|0)==(j|0)){l=44574;break}else{G=G+1|0}}if((l|0)==44574){gGr(j);c[H>>2]=0}if((c[2394]|0)==0){I=c[2112932]|0;J=c[3532592]|0}else{c[2394]=0;H=c[3532596]|0;c[2112932]=H;j=c[3532592]|0;if((j|0)!=0){gGC(9104152,j|0,280)|0}c[2113054]=c[2113060];I=H;J=j}c[I+57344>>2]=1;c[I+122880>>2]=1;c[I+188416>>2]=1;c[I+196692>>2]=3e3;c[I+196732>>2]=1540;c[I+196612>>2]=1144;c[I+196652>>2]=2890;if((J|0)!=0){gGC(J|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;c[3532050]=3434;c[3532118]=2980;c[2113302]=2;a[801640]=0;J=c[642608+(c[2436]<<2)>>2]|0;I=c[J+128>>2]|0;if((c[J+52>>2]&4|0)==0){c[2440576]=I;j=c[J+132>>2]|0;c[2440574]=j;K=I;L=j}else{c[2440574]=I;j=c[J+132>>2]|0;c[2440576]=j;K=j;L=I}I=(((K|0)/2|0)<<8)-1792|0;K=(((L|0)/2|0)<<8)-2048|0;c[3542196]=I;c[3542192]=K;c[3542197]=I;c[3542193]=K;c[3542198]=I;c[3542194]=K;c[3542199]=I;c[3542195]=K;eZ8()|0;h=0;i=b;return h|0}function e57(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=i;i=i+32|0;e=d|0;f=d+16|0;e51(a,b)|0;if((a&64|0)==0){i=d;return 0}gGz(f|0,0,12);c[f>>2]=14168784;c[f+4>>2]=16;c[f+12>>2]=249744;gj[c[2076592]&4095](f)|0;gGz(e|0,0,12);c[e>>2]=14168768;c[e+4>>2]=16;c[e+12>>2]=524320;gj[c[2076592]&4095](e)|0;i=d;return 0}function e58(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3655652+(b*112|0)>>2];c[a+104>>2]=c[3655656+(b*112|0)>>2];c[a+108>>2]=c[3655660+(b*112|0)>>2];d=0;return d|0}function e59(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=3655552+(b*112|0);e=0;return e|0}function e6a(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;c[3532044]=1;c[3532030]=1;a[7460960]=1;eZ9(0)|0;c[3532048]=0;c[3532204]=0;d=c[3532200]|0;c[3531932]=d;e=(c[3531928]|0)+d|0;c[3531952]=e;d=e+(c[3531948]|0)|0;c[3531946]=d;e=d+(c[3531942]|0)|0;d=e|0;c[3532020]=d;c[3532208]=d;c[3531936]=e+65536;c[3531970]=e+73728;c[3531966]=e+139264;c[3531978]=e+204800;c[3532026]=e+212992;d=e+245760|0;e=d|0;c[3532022]=e;c[3532136]=e;e=ag(c[3532142]|0,c[3532042]|0)|0;f=(ag(e,c[3532164]|0)|0)+d|0;c[3531962]=f;d=ag(a[7460944]|0?16:0,c[3532034]|0)|0;e=(ag(d,c[3532004]|0)|0)+f|0;c[3532028]=e;c[3532100]=e+32768;f=e+69632|0;c[3532046]=f;e=f;f=0;while(1){if((f|0)>=1024){break}g=9638528+(f<<2)|0;if((c[g>>2]|0)==0){i=44614;break}else{f=f+1|0}}do{if((i|0)==44614){f=gGq(e)|0;c[g>>2]=f;if((f|0)==0){break}gGz(f|0,0,e|0);c[3532048]=f;gGz(f|0,0,e|0);c[3532204]=f;d=c[3532200]|0;c[3531932]=f+d;j=(c[3531928]|0)+d|0;c[3531952]=f+j;d=j+(c[3531948]|0)|0;c[3531946]=f+d;j=d+(c[3531942]|0)|0;d=f+j|0;c[3532020]=d;c[3532208]=d;c[3531936]=f+(j+65536);c[3531970]=f+(j+73728);c[3531966]=f+(j+139264);c[3531978]=f+(j+204800);c[3532026]=f+(j+212992);d=j+245760|0;j=f+d|0;c[3532022]=j;c[3532136]=j;j=ag(c[3532142]|0,c[3532042]|0)|0;k=(ag(j,c[3532164]|0)|0)+d|0;c[3531962]=f+k;d=ag(a[7460944]|0?16:0,c[3532034]|0)|0;j=(ag(d,c[3532004]|0)|0)+k|0;c[3532028]=f+j;c[3532100]=f+(j+32768);c[3532046]=f+(j+69632);j=c[642608+(c[2436]<<2)>>2]|0;f=c[j+128>>2]|0;if((c[j+52>>2]&4|0)==0){c[2113068]=f;k=c[j+132>>2]|0;c[2113070]=k;c[2443814]=f;c[2440436]=k;l=f;m=k}else{c[2113070]=f;k=c[j+132>>2]|0;c[2113068]=k;c[2440436]=f;c[2443814]=k;l=k;m=f}f=ag(l<<1,m)|0;k=gGq(f)|0;c[2112926]=k;if((k|0)!=0){gGz(k|0,0,f|0)}eXS(c[3532042]|0,3,30,9,-1,1,-2);a[1666920]=1;a[7461080]=1;a[7461040]=1;a[7461008]=1;if((eZ9(1)|0)!=0){n=1;return n|0}fxU(0,425984);if((c[2394]|0)==0){o=c[2112932]|0}else{c[2394]=0;f=c[3532596]|0;c[2112932]=f;k=c[3532592]|0;if((k|0)!=0){gGC(9104152,k|0,280)|0}c[2113054]=c[2113060];o=f}f=c[3532204]|0;k=(c[3532200]|0)-1|0;j=o|0;d=0;while(1){p=f+d|0;c[j>>2]=p;c[j+131072>>2]=p;p=d+1024|0;if(p>>>0>k>>>0){break}else{j=j+4|0;d=p}}d=c[3532208]|0;j=o+20480|0;k=5242880;while(1){f=d+(k-5242880)|0;c[j>>2]=f;c[j+65536>>2]=f;c[j+131072>>2]=f;f=k+1024|0;if(f>>>0>5308415){break}else{j=j+4|0;k=f}}k=c[3531970]|0;j=o+24576|0;d=6291456;while(1){f=k+(d-6291456)|0;c[j>>2]=f;c[j+65536>>2]=f;c[j+131072>>2]=f;f=d+1024|0;if(f>>>0>6356991){break}else{j=j+4|0;d=f}}d=c[3531978]|0;c[o+28672>>2]=d;c[o+94208>>2]=d;c[o+159744>>2]=d;j=d+1024|0;c[o+28676>>2]=j;c[o+94212>>2]=j;c[o+159748>>2]=j;j=d+2048|0;c[o+28680>>2]=j;c[o+94216>>2]=j;c[o+159752>>2]=j;j=d+3072|0;c[o+28684>>2]=j;c[o+94220>>2]=j;c[o+159756>>2]=j;j=d+4096|0;c[o+28688>>2]=j;c[o+94224>>2]=j;c[o+159760>>2]=j;j=d+5120|0;c[o+28692>>2]=j;c[o+94228>>2]=j;c[o+159764>>2]=j;j=d+6144|0;c[o+28696>>2]=j;c[o+94232>>2]=j;c[o+159768>>2]=j;j=d+7168|0;c[o+28700>>2]=j;c[o+94236>>2]=j;c[o+159772>>2]=j;j=c[3532232]|0;d=o+32768|0;k=8388608;while(1){f=j+(k-8388608)|0;c[d>>2]=f;c[d+65536>>2]=f;c[d+131072>>2]=f;f=k+1024|0;if(f>>>0>8454143){break}else{d=d+4|0;k=f}}k=c[3532026]|0;d=o+36864|0;j=9437184;while(1){f=k+(j-9437184)|0;c[d>>2]=f;c[d+65536>>2]=f;c[d+131072>>2]=f;f=j+1024|0;if(f>>>0>9469951){break}else{d=d+4|0;j=f}}c[o+196688>>2]=608;c[o+196728>>2]=1888;c[o+196608>>2]=2726;c[o+196648>>2]=3246;j=c[3532592]|0;if((j|0)!=0){gGC(j|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);j=c[2439330]|0;d=(j|0)==0;if(!d){k=j;gGC(9706056,k|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];k=c[3528484]|0;c[2076596]=k;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;c[j+4180>>2]=1546;c[j+4184>>2]=688;p=c[3531932]|0;q=0;r=0;while(1){c[j+76+(r<<2)>>2]=p+(r<<8);s=q+1&65535;if((s&65535)>63){t=0;u=0;break}else{q=s;r=s&65535}}while(1){r=p+(u<<8)|0;c[j+76+(u+512<<2)>>2]=r;c[j+76+(u+768<<2)>>2]=r;r=t+1&65535;if((r&65535)>63){v=64;w=64;break}else{t=r;u=r&65535}}while(1){c[j+76+(w<<2)>>2]=p+(w<<8);r=v+1&65535;if((r&65535)>127){x=64;y=64;break}else{v=r;w=r&65535}}while(1){r=p+(y<<8)|0;c[j+76+(y+512<<2)>>2]=r;c[j+76+(y+768<<2)>>2]=r;r=x+1&65535;if((r&65535)>127){break}else{x=r;y=r&65535}}p=c[3531936]|0;r=192;q=192;while(1){c[j+76+(q<<2)>>2]=p+((q<<8)-49152);s=r+1&65535;if((s&65535)>223){z=192;A=192;break}else{r=s;q=s&65535}}while(1){c[j+76+(A+256<<2)>>2]=p+((A<<8)-49152);q=z+1&65535;if((q&65535)>223){B=192;C=192;break}else{z=q;A=q&65535}}while(1){q=p+((C<<8)-49152)|0;c[j+76+(C+512<<2)>>2]=q;c[j+76+(C+768<<2)>>2]=q;q=B+1&65535;if((q&65535)>223){break}else{B=q;C=q&65535}}if(!d){p=j;gGC(p|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=k;c[2417276]=f;c[1836236]=-1;TW(c[3531952]|0,14127792,c[3531946]|0,14127768,3158,1074,10);c[2438228]=4e6;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=511;h[745406]=1.0;c[2436786]=1;h[745405]=1.0;c[2436784]=2;h[745404]=.25;a[3203280]=1;c[3532050]=1672;c[3532118]=12648;c[2113026]=239400;c[2113024]=66666;Tv(5);c[3532092]=1;c[3532094]=0;c[3532096]=2;c[3531954]=3;b[7064208]=0;b[7064216]=0;b[7064209]=1024;b[7064217]=1024;b[7064210]=2048;b[7064218]=2048;b[7064211]=3072;b[7064219]=3072;b[7064212]=4096;b[7064220]=4096;b[7064213]=5120;b[7064221]=5120;b[7064214]=6144;b[7064222]=6144;b[7064215]=7168;b[7064223]=7168;n=0;return n|0}}while(0);c[3532048]=0;n=1;return n|0}function e6b(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;gGz(14128880,-1|0,5);b=0;d=-1;e=-1;f=-1;g=-1;h=-1;do{d=(d&255)-((a[14128872+b|0]&1)<<b)&255;e=(e&255)-((a[14128864+b|0]&1)<<b)&255;f=(f&255)-((a[14128856+b|0]&1)<<b)&255;g=(g&255)-((a[14128848+b|0]&1)<<b)&255;h=(h&255)-((a[14128840+b|0]&1)<<b)&255;b=b+1|0;}while((b|0)<8);a[14128880]=d;a[14128881]=e;a[14128882]=f;a[14128883]=g;a[14128884]=h;h=c[3532184]|0;g=(c[3542196]|0)+(c[3532186]<<16>>16)|0;c[3542196]=g;f=(c[3542192]|0)+(h<<16>>16)|0;c[3542192]=f;if((g|0)<-2048){c[3542196]=-2048;i=-2048}else{i=g}g=(c[2440576]<<8)-2048|0;if((i|0)>(g|0)){c[3542196]=g}if((f|0)<-2048){c[3542192]=-2048;j=-2048}else{j=f}f=(c[2440574]<<8)-2048|0;if((j|0)>(f|0)){c[3542192]=f}j=c[3532180]|0;i=(c[3542197]|0)+(c[3532182]<<16>>16)|0;c[3542197]=i;h=(c[3542193]|0)+(j<<16>>16)|0;c[3542193]=h;if((i|0)<-2048){c[3542197]=-2048;k=-2048}else{k=i}if((k|0)>(g|0)){c[3542197]=g}if((h|0)<-2048){c[3542193]=-2048;l=-2048}else{l=h}if((l|0)<=(f|0)){return}c[3542193]=f;return}function e6c(){var a=0,b=0;e6d();a=c[2113302]|0;if((a|0)>0){b=0}else{return}do{R7(b,c[14168784+(b<<2)>>2]>>8,c[14168768+(b<<2)>>2]>>8);b=b+1|0;}while((b|0)<(a|0));return}function e6d(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=e[725160+(((c[2436808]|0)>>>2&7)<<1)>>1]|0;f=b>>>12;g=a[14128988]|0;a[14128336+f|0]=g&15;h=b>>>8&15;a[14128336+h|0]=(g&255)>>>4;g=a[14128989]|0;i=b>>>4&15;a[14128336+i|0]=g&15;j=b&15;a[14128336+j|0]=(g&255)>>>4;g=a[14128990]|0;b=g&15;a[14128392]=b;k=(g&255)>>>4;a[14128393]=k;g=a[14128991]|0;l=g&15;a[14128394]=l;m=(g&255)>>>4;a[14128395]=m;g=c[3532028]|0;n=0;o=c[3532026]|0;p=g;while(1){q=c[o>>2]|0;c[p>>2]=q>>>19&31|q<<8&63488|q>>>24<<3&2016;q=n+1|0;if((q|0)<8192){n=q;o=o+4|0;p=p+4|0}else{break}}p=c[2112926]|0;gGz(p|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);ffS();p=c[3532136]|0;o=m&255;m=l&255;l=k&255;k=b&255;b=0;do{do{if((d[14128336]|0|0)==(b|0)){if((f|0)==2){eXQ(2,0,p);break}else if((f|0)==0){eXP(0,0,p);break}else if((f|0)==1){eXP(1,0,p);break}else if((f|0)==3){eXQ(3,0,p);break}else{break}}}while(0);do{if((d[14128337]|0|0)==(b|0)){if((h|0)==2){eXQ(2,0,p);break}else if((h|0)==0){eXP(0,0,p);break}else if((h|0)==1){eXP(1,0,p);break}else if((h|0)==3){eXQ(3,0,p);break}else{break}}}while(0);do{if((d[14128338]|0|0)==(b|0)){if((i|0)==0){eXP(0,0,p);break}else if((i|0)==1){eXP(1,0,p);break}else if((i|0)==2){eXQ(2,0,p);break}else if((i|0)==3){eXQ(3,0,p);break}else{break}}}while(0);do{if((d[14128339]|0|0)==(b|0)){if((j|0)==2){eXQ(2,0,p);break}else if((j|0)==0){eXP(0,0,p);break}else if((j|0)==3){eXQ(3,0,p);break}else if((j|0)==1){eXP(1,0,p);break}else{break}}}while(0);if((o|0)==(b|0)){ffT(o)}if((m|0)==(b|0)){ffT(m)}if((l|0)==(b|0)){ffT(l)}if((k|0)==(b|0)){ffT(k)}b=b+1|0;}while((b|0)<16);eXR();R8(g);return}function e6e(){var b=0,c=0,d=0,e=0,f=0,g=0;gGz(14128880,-1|0,5);b=0;c=-1;d=-1;e=-1;f=-1;g=-1;do{c=(c&255)-((a[14128872+b|0]&1)<<b)&255;d=(d&255)-((a[14128864+b|0]&1)<<b)&255;e=(e&255)-((a[14128856+b|0]&1)<<b)&255;f=(f&255)-((a[14128848+b|0]&1)<<b)&255;g=(g&255)-((a[14128840+b|0]&1)<<b)&255;b=b+1|0;}while((b|0)<8);a[14128880]=c;a[14128881]=d;a[14128882]=e;a[14128883]=f;a[14128884]=g;return}function e6f(b,c){b=b|0;c=c|0;a[9706117]=c&1;return}function e6g(a){a=a|0;var b=0,d=0;b=(c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,4e6,0)|0;return a|0}function e6h(){return+(+((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)/4.0e6)}function e6i(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=b&65535;switch(e|0){case 61952:{b=d&3;a[14127752]=b;f=c[3531932]|0;g=c[9757320+(c[1836236]<<2)>>2]|0;h=((b&255)<<14)-16384|0;b=64;i=64;while(1){c[g+76+(i<<2)>>2]=f+(h+(i<<8));j=b+1&65535;if((j&65535)>127){k=64;l=64;break}else{b=j;i=j&65535}}while(1){i=f+(h+(l<<8))|0;c[g+76+(l+512<<2)>>2]=i;c[g+76+(l+768<<2)>>2]=i;i=k+1&65535;if((i&65535)>127){break}else{k=i;l=i&65535}}return};case 57856:{a[9540897]=d&15;return};case 57857:{fd_(d);return};case 57344:case 57345:case 57346:case 57347:{l7(e&3,d);return};default:{return}}}function e6j(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=d&3;a[14127752]=b;d=c[3531932]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=((b&255)<<14)-16384|0;b=64;g=64;while(1){c[e+76+(g<<2)>>2]=d+(f+(g<<8));h=b+1&65535;if((h&65535)>127){i=64;j=64;break}else{b=h;g=h&65535}}while(1){g=d+(f+(j<<8))|0;c[e+76+(j+512<<2)>>2]=g;c[e+76+(j+768<<2)>>2]=g;g=i+1&65535;if((g&65535)>127){break}else{i=g;j=g&65535}}return}function e6k(a){a=a|0;var b=0,c=0;b=a&65535;switch(b|0){case 57857:{c=fdZ()|0;break};case 57344:case 57345:case 57346:case 57347:{c=l8(b&3)|0;break};default:{c=0}}return c|0}function e6l(b,c){b=b|0;c=c|0;var d=0;d=b&65535;if((d|0)==40961){fd_(c);return}else if((d|0)==36864|(d|0)==36865){lS(0,d&1,c);return}else if((d|0)==45056|(d|0)==45057){Uv(0,c);return}else if((d|0)==40960){a[9540897]=c&15;return}else{return}}function e6m(b){b=b|0;var e=0,f=0,g=0.0,i=0.0,j=0,k=0;e=b&65535;if((e|0)==36864|(e|0)==36865){b=c[3541518]|0;if((e&1|0)==0){f=b+296|0;g=+h[f>>3];do{if(g!=0.0){i=+h[6675];if(g-(i+ +gC[c[2429842]&255]())<=0.0){h[f>>3]=0.0;break}j=a[b+307|0]|-128;return j|0}}while(0);j=a[b+307|0]|0;return j|0}if((d[b+304|0]|0)>=16){j=0;return j|0}b=c[2383582]|0;f=c[14168912+(b*252|0)>>2]|0;if((f|0)>15){j=0;return j|0}do{if((f|0)==15){k=c[14168900+(b*252|0)>>2]|0;if((k|0)==0){break}a[14168931+(b*252|0)|0]=gj[k&4095](0)|0}else if((f|0)==14){k=c[14168896+(b*252|0)>>2]|0;if((k|0)==0){break}a[14168930+(b*252|0)|0]=gj[k&4095](0)|0}}while(0);j=a[14168916+(b*252|0)+f|0]|0;return j|0}else if((e|0)==45056|(e|0)==45057){j=c[2113156]&255;return j|0}else if((e|0)==40961){j=fdZ()|0;return j|0}else{j=0;return j|0}return 0}function e6n(d){d=d|0;var e=0,f=0,g=0;L58667:do{if((d-4456448|0)>>>0<262144){e=d&131070;f=c[9717840+((d>>>17&1)<<2)>>2]|0;if((d&1|0)==0){g=b[f+((e|1)<<1)>>1]&255;break}else{g=b[f+(e<<1)>>1]&255;break}}else{if((d-4292608|0)>>>0<32){g=a[9733144+(d>>>1&15)|0]|0;break}e=d-10485760|0;if(e>>>0<16){switch(e>>>1&255|0){case 0:{g=a[14129048]|0;break L58667;break};case 2:{g=a[14129040]|0;break L58667;break};case 3:{g=a[14129041]|0;break L58667;break};case 4:{g=a[9757556]|0;break L58667;break};case 7:{g=a[14129042]|0;break L58667;break};case 1:{g=a[14129049]|0;break L58667;break};default:{g=0;break L58667}}}else{if((d|0)!=8388610){g=0;break}e=a[9540896]|0;switch(e&255|0){case 3:{a[9540898]=a[9540898]&-9;a[9540896]=e+1&255;g=a[9540895]|0;break L58667;break};case 1:{a[9540898]=a[9540898]&-5;a[9540896]=e+1&255;g=a[9540893]|0;break L58667;break};case 4:{g=a[9540898]|0;break L58667;break};case 2:{a[9540896]=e+1&255;g=a[9540894]|0;break L58667;break};case 0:{a[9540896]=e+1&255;g=a[9540892]|0;break L58667;break};default:{g=0;break L58667}}}}}while(0);return g|0}function e6o(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;if((d-4456448|0)>>>0<262144){f=c[3532268]|0;a[f+(d&262143^1)|0]=e;g=b[f+(d&262142)>>1]|0;f=d&131070;h=c[9717840+((d>>>17&1)<<2)>>2]|0;b[h+(f<<1)>>1]=(g&65535)>>>8;b[h+((f|1)<<1)>>1]=g&255;return}if((d-4292608|0)>>>0<32){g=e&255;f=d>>>1&15;a[9733144+f|0]=e;if((f|0)!=7){return}if((g&128|0)==0){return}c[2432956]=g>>>6&1^1;return}g=d-10485760|0;if(g>>>0<16){f=g>>>1;g=f&255;a[9757552+(f&255)|0]=e;if((g<<24>>24|0)==4){f=~e;a[14128520]=f&1;a[14128521]=f&2;return}else if((g<<24>>24|0)==0){c[3531956]=0;return}else{return}}if((d|0)==8388610){g=c[1836236]|0;f=c[9757320+(g<<2)>>2]|0;if((f|0)!=0){h=f;gGC(h|0,9706056,76)|0}c[9752472+(g<<2)>>2]=c[2433530];c[14113936+(g<<2)>>2]=c[2076596];c[9669104+(g<<2)>>2]=c[3541536];c[1836236]=-1;g=e&15;h=a[9540896]|0;L58723:do{switch(h&255|0){case 0:{a[9540896]=h+1&255;a[9540888]=g;break};case 1:{a[9540896]=h+1&255;a[9540889]=g;a[9540898]=a[9540898]|1;a[9540900]=1;break};case 3:{a[9540896]=h+1&255;a[9540891]=g;a[9540898]=a[9540898]|2;a[9540900]=1;break};case 4:{if(g<<24>>24==0){break L58723}f=c[2439330]|0;i=(f|0)==0;if(!i){j=f;gGC(9706056,j|0,76)|0}j=c[2438118]|0;c[2433530]=j;k=c[3528484]|0;c[2076596]=k;l=c[2417276]|0;c[3541536]=l;c[1836236]=0;gGz(9706056,0,76);if(!i){i=f;gGC(i|0,9706056,76)|0}c[2438118]=j;c[3528484]=k;c[2417276]=l;c[1836236]=-1;break};case 2:{a[9540896]=h+1&255;a[9540890]=g;break};default:{}}}while(0);g=c[2439330]|0;if((g|0)!=0){h=g;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;return}else if((d|0)==8388608){a[9540896]=e&15;return}else{return}}function e6p(d,e){d=d|0;e=e|0;var f=0,g=0;if((d-4456448|0)>>>0<262144){b[(c[3532268]|0)+(d&262142)>>1]=e;f=d&131070;g=c[9717840+((d>>>17&1)<<2)>>2]|0;b[g+(f<<1)>>1]=(e&65535)>>>8;b[g+((f|1)<<1)>>1]=e&255;return}if((d-4292608|0)>>>0>=32){return}f=e&65535;e=f>>>8;g=d>>>1&15;a[9733144+g|0]=e&255;if((g|0)!=7){return}if((e&128|0)==0){return}c[2432956]=f>>>14&1^1;return}function e6q(d){d=d|0;var e=0,f=0,g=0,h=0;e=d-2097152|0;L58760:do{if(e>>>0<16){switch(e>>>1&255|0){case 3:{f=a[14129041]|0;break L58760;break};case 1:{f=a[14129049]|0;break L58760;break};case 0:{f=a[14129048]|0;break L58760;break};case 7:{f=a[14129042]|0;break L58760;break};case 4:{f=a[9757556]|0;break L58760;break};case 2:{f=a[14129040]|0;break L58760;break};default:{f=0;break L58760}}}else{if((d-4456448|0)>>>0<262144){g=d&131070;h=c[9717840+((d>>>17&1)<<2)>>2]|0;if((d&1|0)==0){f=b[h+((g|1)<<1)>>1]&255;break}else{f=b[h+(g<<1)>>1]&255;break}}if((d-4292608|0)>>>0<32){f=a[9733144+(d>>>1&15)|0]|0;break}if((d|0)!=6291458){f=0;break}g=a[9540896]|0;switch(g&255|0){case 2:{a[9540896]=g+1&255;f=a[9540894]|0;break L58760;break};case 3:{a[9540898]=a[9540898]&-9;a[9540896]=g+1&255;f=a[9540895]|0;break L58760;break};case 4:{f=a[9540898]|0;break L58760;break};case 0:{a[9540896]=g+1&255;f=a[9540892]|0;break L58760;break};case 1:{a[9540898]=a[9540898]&-5;a[9540896]=g+1&255;f=a[9540893]|0;break L58760;break};default:{f=0;break L58760}}}}while(0);return f|0}function e6r(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=d-2097152|0;if(f>>>0<16){g=f>>>1;f=g&255;a[9757552+(g&255)|0]=e;if((f<<24>>24|0)==0){c[3531956]=0;return}else if((f<<24>>24|0)==4){f=~e;a[14128520]=f&1;a[14128521]=f&2;return}else{return}}if((d-4456448|0)>>>0<262144){f=c[3532268]|0;a[f+(d&262143^1)|0]=e;g=b[f+(d&262142)>>1]|0;f=d&131070;h=c[9717840+((d>>>17&1)<<2)>>2]|0;b[h+(f<<1)>>1]=(g&65535)>>>8;b[h+((f|1)<<1)>>1]=g&255;return}if((d-4292608|0)>>>0<32){g=e&255;f=d>>>1&15;a[9733144+f|0]=e;if((f|0)!=7){return}if((g&128|0)==0){return}c[2432956]=g>>>6&1^1;return}if((d|0)==6291456){a[9540896]=e&15;return}else if((d|0)==6291458){d=c[1836236]|0;g=c[9757320+(d<<2)>>2]|0;if((g|0)!=0){f=g;gGC(f|0,9706056,76)|0}c[9752472+(d<<2)>>2]=c[2433530];c[14113936+(d<<2)>>2]=c[2076596];c[9669104+(d<<2)>>2]=c[3541536];c[1836236]=-1;d=e&15;e=a[9540896]|0;L58818:do{switch(e&255|0){case 4:{if(d<<24>>24==0){break L58818}f=c[2439330]|0;g=(f|0)==0;if(!g){h=f;gGC(9706056,h|0,76)|0}h=c[2438118]|0;c[2433530]=h;i=c[3528484]|0;c[2076596]=i;j=c[2417276]|0;c[3541536]=j;c[1836236]=0;gGz(9706056,0,76);if(!g){g=f;gGC(g|0,9706056,76)|0}c[2438118]=h;c[3528484]=i;c[2417276]=j;c[1836236]=-1;break};case 3:{a[9540896]=e+1&255;a[9540891]=d;a[9540898]=a[9540898]|2;a[9540900]=1;break};case 1:{a[9540896]=e+1&255;a[9540889]=d;a[9540898]=a[9540898]|1;a[9540900]=1;break};case 2:{a[9540896]=e+1&255;a[9540890]=d;break};case 0:{a[9540896]=e+1&255;a[9540888]=d;break};default:{}}}while(0);d=c[2439330]|0;if((d|0)!=0){e=d;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;return}else{return}}function e6s(d,e){d=d|0;e=e|0;var f=0,g=0;if((d-4456448|0)>>>0<262144){b[(c[3532268]|0)+(d&262142)>>1]=e;f=d&131070;g=c[9717840+((d>>>17&1)<<2)>>2]|0;b[g+(f<<1)>>1]=(e&65535)>>>8;b[g+((f|1)<<1)>>1]=e&255;return}if((d-4292608|0)>>>0>=32){return}f=e&65535;e=f>>>8;g=d>>>1&15;a[9733144+g|0]=e&255;if((g|0)!=7){return}if((e&128|0)==0){return}c[2432956]=f>>>14&1^1;return}function e6t(d){d=d|0;var e=0,f=0,g=0;L58853:do{if((d-4456448|0)>>>0<262144){e=d&131070;f=c[9717840+((d>>>17&1)<<2)>>2]|0;if((d&1|0)==0){g=b[f+((e|1)<<1)>>1]&255;break}else{g=b[f+(e<<1)>>1]&255;break}}else{if((d-4292608|0)>>>0<32){g=a[9733144+(d>>>1&15)|0]|0;break}e=d-6291456|0;if(e>>>0<16){switch(e>>>1&255|0){case 0:{g=a[14129048]|0;break L58853;break};case 3:{g=a[14129041]|0;break L58853;break};case 4:{g=a[9757556]|0;break L58853;break};case 7:{g=a[14129042]|0;break L58853;break};case 1:{g=a[14129049]|0;break L58853;break};case 2:{g=a[14129040]|0;break L58853;break};default:{g=0;break L58853}}}if((d|0)==6291480){e=(c[3532180]|0)>>>4;if((e&65535|0)==65535){g=0;break}g=e+1&255;break}else if((d|0)==6291476){e=(c[3532186]|0)>>>4^65535;if((e&65535|0)==65535){g=0;break}g=e+1&255;break}else if((d|0)==2097154){e=a[9540896]|0;switch(e&255|0){case 3:{a[9540898]=a[9540898]&-9;a[9540896]=e+1&255;g=a[9540895]|0;break L58853;break};case 1:{a[9540898]=a[9540898]&-5;a[9540896]=e+1&255;g=a[9540893]|0;break L58853;break};case 2:{a[9540896]=e+1&255;g=a[9540894]|0;break L58853;break};case 4:{g=a[9540898]|0;break L58853;break};case 0:{a[9540896]=e+1&255;g=a[9540892]|0;break L58853;break};default:{g=0;break L58853}}}else if((d|0)==6291472){e=(c[3532184]|0)>>>4;if((e&65535|0)==65535){g=0;break}g=e+1&255;break}else if((d|0)==6291484){e=(c[3532182]|0)>>>4^65535;if((e&65535|0)==65535){g=0;break}g=e+1&255;break}else{g=0;break}}}while(0);return g|0}function e6u(b){b=b|0;var d=0,e=0,f=0,g=0;d=b-6291456|0;do{if(d>>>0<16){switch(d>>>1&255|0){case 4:{e=a[9757556]|0;break};case 2:{e=a[14129040]|0;break};case 1:{e=a[14129049]|0;break};case 0:{e=a[14129048]|0;break};case 3:{e=a[14129041]|0;break};case 7:{e=a[14129042]|0;break};default:{e=0}}f=e&255}else{if((b|0)==6291474){g=(c[3532184]|0)>>>4;if((g&65535|0)==65535){f=0;break}f=g+1&65535;break}else if((b|0)==6291478){g=(c[3532186]|0)>>>4^65535;if((g&65535|0)==65535){f=0;break}f=g+1&65535;break}else if((b|0)==6291482){g=(c[3532180]|0)>>>4;if((g&65535|0)==65535){f=0;break}f=g+1&65535;break}else if((b|0)==6291486){g=(c[3532182]|0)>>>4^65535;if((g&65535|0)==65535){f=0;break}f=g+1&65535;break}else{f=0;break}}}while(0);return f|0}function e6v(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;if((d-4456448|0)>>>0<262144){f=c[3532268]|0;a[f+(d&262143^1)|0]=e;g=b[f+(d&262142)>>1]|0;f=d&131070;h=c[9717840+((d>>>17&1)<<2)>>2]|0;b[h+(f<<1)>>1]=(g&65535)>>>8;b[h+((f|1)<<1)>>1]=g&255;return}if((d-4292608|0)>>>0<32){g=e&255;f=d>>>1&15;a[9733144+f|0]=e;if((f|0)!=7){return}if((g&128|0)==0){return}c[2432956]=g>>>6&1^1;return}g=d-6291456|0;if(g>>>0<16){f=g>>>1;g=f&255;a[9757552+(f&255)|0]=e;if((g<<24>>24|0)==0){c[3531956]=0;return}else if((g<<24>>24|0)==4){g=~e;a[14128520]=g&1;a[14128521]=g&2;return}else{return}}if((d|0)==2097152){a[9540896]=e&15;return}else if((d|0)==2097154){d=c[1836236]|0;g=c[9757320+(d<<2)>>2]|0;if((g|0)!=0){f=g;gGC(f|0,9706056,76)|0}c[9752472+(d<<2)>>2]=c[2433530];c[14113936+(d<<2)>>2]=c[2076596];c[9669104+(d<<2)>>2]=c[3541536];c[1836236]=-1;d=e&15;e=a[9540896]|0;L58942:do{switch(e&255|0){case 0:{a[9540896]=e+1&255;a[9540888]=d;break};case 3:{a[9540896]=e+1&255;a[9540891]=d;a[9540898]=a[9540898]|2;a[9540900]=1;break};case 4:{if(d<<24>>24==0){break L58942}f=c[2439330]|0;g=(f|0)==0;if(!g){h=f;gGC(9706056,h|0,76)|0}h=c[2438118]|0;c[2433530]=h;i=c[3528484]|0;c[2076596]=i;j=c[2417276]|0;c[3541536]=j;c[1836236]=0;gGz(9706056,0,76);if(!g){g=f;gGC(g|0,9706056,76)|0}c[2438118]=h;c[3528484]=i;c[2417276]=j;c[1836236]=-1;break};case 1:{a[9540896]=e+1&255;a[9540889]=d;a[9540898]=a[9540898]|1;a[9540900]=1;break};case 2:{a[9540896]=e+1&255;a[9540890]=d;break};default:{}}}while(0);d=c[2439330]|0;if((d|0)!=0){e=d;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;return}else{return}}function e6w(d,e){d=d|0;e=e|0;var f=0,g=0,h=0;if((d-4456448|0)>>>0<262144){b[(c[3532268]|0)+(d&262142)>>1]=e;f=d&131070;g=c[9717840+((d>>>17&1)<<2)>>2]|0;b[g+(f<<1)>>1]=(e&65535)>>>8;b[g+((f|1)<<1)>>1]=e&255;return}if((d-4292608|0)>>>0<32){f=e&65535;g=f>>>8;h=d>>>1&15;a[9733144+h|0]=g&255;if((h|0)!=7){return}if((g&128|0)==0){return}c[2432956]=f>>>14&1^1;return}f=d-6291456|0;if(f>>>0>=16){return}d=f>>>1;f=d&255;g=e&255;a[9757552+(d&255)|0]=g;if((f<<24>>24|0)==4){d=~g;a[14128520]=d&1;a[14128521]=d&2;return}else if((f<<24>>24|0)==0){c[3531956]=0;return}else{return}}function e6x(d){d=d|0;var e=0,f=0,g=0,h=0;L58986:do{if((d-4456448|0)>>>0<262144){e=d&131070;f=c[9717840+((d>>>17&1)<<2)>>2]|0;if((d&1|0)==0){g=b[f+((e|1)<<1)>>1]&255;break}else{g=b[f+(e<<1)>>1]&255;break}}else{if((d-4292608|0)>>>0<32){g=a[9733144+(d>>>1&15)|0]|0;break}if((d|0)==5242882){e=a[14129040]&254;do{if((c[2406632]|0)==0){f=c[2443744]|0;if((f|0)<=0){h=1;break}c[2443744]=f-1;h=0}else{h=(c[2432962]|0)>>>((c[(c[2420380]|0)+4>>2]|0)>>>0)&1}}while(0);g=(h|e)&255;break}else if((d|0)==5242888){g=a[9757556]|0;break}else if((d|0)==5242884){g=a[14129041]|0;break}else if((d|0)==5242886){g=a[14129042]|0;break}else if((d|0)==5242880){g=a[14129048]|0;break}else if((d|0)==5242918){g=c[2440826]&255;break}else if((d|0)==5242916){g=a[14128324]|0;break}else if((d|0)==5242926){g=a[14128325]|0;break}else if((d|0)==7340034){f=a[9540896]|0;switch(f&255|0){case 1:{a[9540898]=a[9540898]&-5;a[9540896]=f+1&255;g=a[9540893]|0;break L58986;break};case 0:{a[9540896]=f+1&255;g=a[9540892]|0;break L58986;break};case 2:{a[9540896]=f+1&255;g=a[9540894]|0;break L58986;break};case 3:{a[9540898]=a[9540898]&-9;a[9540896]=f+1&255;g=a[9540895]|0;break L58986;break};case 4:{g=a[9540898]|0;break L58986;break};default:{g=0;break L58986}}}else if((d|0)==5242894){g=a[14128323]|0;break}else{g=0;break}}}while(0);return g|0}function e6y(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;if((d-4456448|0)>>>0<262144){f=c[3532268]|0;a[f+(d&262143^1)|0]=e;g=b[f+(d&262142)>>1]|0;f=d&131070;h=c[9717840+((d>>>17&1)<<2)>>2]|0;b[h+(f<<1)>>1]=(g&65535)>>>8;b[h+((f|1)<<1)>>1]=g&255;return}if((d-4292608|0)>>>0<32){g=e&255;f=d>>>1&15;a[9733144+f|0]=e;if((f|0)!=7){return}if((g&128|0)==0){return}c[2432956]=g>>>6&1^1;return}g=d-5242880|0;if(g>>>0<16){f=g>>>1;g=f&255;a[9757552+(f&255)|0]=e;if((g<<24>>24|0)==4){f=~e;a[14128520]=f&1;a[14128521]=f&2;return}else if((g<<24>>24|0)==0){c[3531956]=0;return}else{return}}if((d|0)==5242918){g=e&255;c[2440826]=g;c[2415256]=g&4;f=g>>>4&1;c[3528406]=f^1;if((f|0)==0){c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2]}Tr(g>>>3&1);return}else if((d|0)==5242920){c[2442904]=e&255;g=~e;a[14128522]=g&1;a[14128523]=g&2;return}else if((d|0)==7340032){a[9540896]=e&15;return}else if((d|0)==7340034){d=c[1836236]|0;g=c[9757320+(d<<2)>>2]|0;if((g|0)!=0){f=g;gGC(f|0,9706056,76)|0}c[9752472+(d<<2)>>2]=c[2433530];c[14113936+(d<<2)>>2]=c[2076596];c[9669104+(d<<2)>>2]=c[3541536];c[1836236]=-1;d=e&15;e=a[9540896]|0;L59057:do{switch(e&255|0){case 0:{a[9540896]=e+1&255;a[9540888]=d;break};case 1:{a[9540896]=e+1&255;a[9540889]=d;a[9540898]=a[9540898]|1;a[9540900]=1;break};case 2:{a[9540896]=e+1&255;a[9540890]=d;break};case 3:{a[9540896]=e+1&255;a[9540891]=d;a[9540898]=a[9540898]|2;a[9540900]=1;break};case 4:{if(d<<24>>24==0){break L59057}f=c[2439330]|0;g=(f|0)==0;if(!g){h=f;gGC(9706056,h|0,76)|0}h=c[2438118]|0;c[2433530]=h;i=c[3528484]|0;c[2076596]=i;j=c[2417276]|0;c[3541536]=j;c[1836236]=0;gGz(9706056,0,76);if(!g){g=f;gGC(g|0,9706056,76)|0}c[2438118]=h;c[3528484]=i;c[2417276]=j;c[1836236]=-1;break};default:{}}}while(0);d=c[2439330]|0;if((d|0)!=0){e=d;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;return}else{return}}function e6z(d,e){d=d|0;e=e|0;var f=0,g=0,h=0;if((d-4456448|0)>>>0<262144){b[(c[3532268]|0)+(d&262142)>>1]=e;f=d&131070;g=c[9717840+((d>>>17&1)<<2)>>2]|0;b[g+(f<<1)>>1]=(e&65535)>>>8;b[g+((f|1)<<1)>>1]=e&255;return}if((d-4292608|0)>>>0<32){f=e&65535;g=f>>>8;h=d>>>1&15;a[9733144+h|0]=g&255;if((h|0)!=7){return}if((g&128|0)==0){return}c[2432956]=f>>>14&1^1;return}f=d-5242880|0;if(f>>>0>=16){return}d=f>>>1;f=d&255;g=e&255;a[9757552+(d&255)|0]=g;if((f<<24>>24|0)==0){c[3531956]=0;return}else if((f<<24>>24|0)==4){f=~g;a[14128520]=f&1;a[14128521]=f&2;return}else{return}}function e6A(b){b=b|0;var c=0,d=0,e=0;c=b-4194304|0;L59100:do{if(c>>>0<16){switch(c>>>1&255|0){case 0:{d=a[14129048]|0;break L59100;break};case 7:{d=a[14129042]|0;break L59100;break};case 3:{d=a[14129041]|0;break L59100;break};case 2:{d=a[14129040]|0;break L59100;break};case 1:{d=a[14129049]|0;break L59100;break};case 4:{d=a[9757556]|0;break L59100;break};default:{d=0;break L59100}}}else{e=b-4259840|0;if(e>>>0<16){switch(e>>>1&255|0){case 1:{d=a[14129049]|0;break L59100;break};case 4:{d=a[9757556]|0;break L59100;break};case 3:{d=a[14129041]|0;break L59100;break};case 2:{d=a[14129040]|0;break L59100;break};case 0:{d=a[14129048]|0;break L59100;break};case 7:{d=a[14129042]|0;break L59100;break};default:{d=0;break L59100}}}if((b-2195456|0)>>>0<32){d=a[9733144+(b>>>1&15)|0]|0;break}if((b|0)!=5242882){d=0;break}e=a[9540896]|0;switch(e&255|0){case 0:{a[9540896]=e+1&255;d=a[9540892]|0;break L59100;break};case 3:{a[9540898]=a[9540898]&-9;a[9540896]=e+1&255;d=a[9540895]|0;break L59100;break};case 2:{a[9540896]=e+1&255;d=a[9540894]|0;break L59100;break};case 1:{a[9540898]=a[9540898]&-5;a[9540896]=e+1&255;d=a[9540893]|0;break L59100;break};case 4:{d=a[9540898]|0;break L59100;break};default:{d=0;break L59100}}}}while(0);return d|0}function e6B(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;if((d-2359296|0)>>>0<262144){f=c[3532268]|0;a[f+(d&262143^1)|0]=e;g=b[f+(d&262142)>>1]|0;f=d&131070;h=c[9717840+((d>>>17&1)<<2)>>2]|0;b[h+(f<<1)>>1]=(g&65535)>>>8;b[h+((f|1)<<1)>>1]=g&255;return}if((d-2195456|0)>>>0<32){g=e&255;f=d>>>1&15;a[9733144+f|0]=e;if((f|0)!=7){return}if((g&128|0)==0){return}c[2432956]=g>>>6&1^1;return}g=d-4194304|0;if(g>>>0<16){f=g>>>1;g=f&255;a[9757552+(f&255)|0]=e;if((g<<24>>24|0)==0){c[3531956]=0;return}else if((g<<24>>24|0)==4){g=~e;a[14128520]=g&1;a[14128521]=g&2;return}else{return}}g=d-4259840|0;if(g>>>0<16){f=g>>>1;g=f&255;a[9757552+(f&255)|0]=e;if((g<<24>>24|0)==0){c[3531956]=0;return}else if((g<<24>>24|0)==4){g=~e;a[14128520]=g&1;a[14128521]=g&2;return}else{return}}if((d|0)==5242880){a[9540896]=e&15;return}else if((d|0)==5242882){d=c[1836236]|0;g=c[9757320+(d<<2)>>2]|0;if((g|0)!=0){f=g;gGC(f|0,9706056,76)|0}c[9752472+(d<<2)>>2]=c[2433530];c[14113936+(d<<2)>>2]=c[2076596];c[9669104+(d<<2)>>2]=c[3541536];c[1836236]=-1;d=e&15;e=a[9540896]|0;L59172:do{switch(e&255|0){case 3:{a[9540896]=e+1&255;a[9540891]=d;a[9540898]=a[9540898]|2;a[9540900]=1;break};case 4:{if(d<<24>>24==0){break L59172}f=c[2439330]|0;g=(f|0)==0;if(!g){h=f;gGC(9706056,h|0,76)|0}h=c[2438118]|0;c[2433530]=h;i=c[3528484]|0;c[2076596]=i;j=c[2417276]|0;c[3541536]=j;c[1836236]=0;gGz(9706056,0,76);if(!g){g=f;gGC(g|0,9706056,76)|0}c[2438118]=h;c[3528484]=i;c[2417276]=j;c[1836236]=-1;break};case 1:{a[9540896]=e+1&255;a[9540889]=d;a[9540898]=a[9540898]|1;a[9540900]=1;break};case 0:{a[9540896]=e+1&255;a[9540888]=d;break};case 2:{a[9540896]=e+1&255;a[9540890]=d;break};default:{}}}while(0);d=c[2439330]|0;if((d|0)!=0){e=d;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;return}else{return}}function e6C(d,e){d=d|0;e=e|0;var f=0,g=0;if((d-2359296|0)>>>0<262144){b[(c[3532268]|0)+(d&262142)>>1]=e;f=d&131070;g=c[9717840+((d>>>17&1)<<2)>>2]|0;b[g+(f<<1)>>1]=(e&65535)>>>8;b[g+((f|1)<<1)>>1]=e&255;return}if((d-2195456|0)>>>0>=32){return}f=e&65535;e=f>>>8;g=d>>>1&15;a[9733144+g|0]=e&255;if((g|0)!=7){return}if((e&128|0)==0){return}c[2432956]=f>>>14&1^1;return}function e6D(d){d=d|0;var e=0,f=0,g=0,h=0;e=(d&268435440|0)==3145728?d^2:d;d=e-3145728|0;L59206:do{if(d>>>0<16){switch(d>>>1&255|0){case 7:{f=a[14129042]|0;break L59206;break};case 1:{f=a[14129049]|0;break L59206;break};case 0:{f=a[14129048]|0;break L59206;break};case 4:{f=a[9757556]|0;break L59206;break};case 3:{f=a[14129041]|0;break L59206;break};case 2:{f=a[14129040]|0;break L59206;break};default:{f=0;break L59206}}}else{if((e-9699328|0)>>>0<262144){g=e&131070;h=c[9717840+((e>>>17&1)<<2)>>2]|0;if((e&1|0)==0){f=b[h+((g|1)<<1)>>1]&255;break}else{f=b[h+(g<<1)>>1]&255;break}}if((e-9535488|0)>>>0<32){f=a[9733144+(e>>>1&15)|0]|0;break}if((e|0)!=3276802){f=0;break}g=a[9540896]|0;switch(g&255|0){case 1:{a[9540898]=a[9540898]&-5;a[9540896]=g+1&255;f=a[9540893]|0;break L59206;break};case 2:{a[9540896]=g+1&255;f=a[9540894]|0;break L59206;break};case 0:{a[9540896]=g+1&255;f=a[9540892]|0;break L59206;break};case 4:{f=a[9540898]|0;break L59206;break};case 3:{a[9540898]=a[9540898]&-9;a[9540896]=g+1&255;f=a[9540895]|0;break L59206;break};default:{f=0;break L59206}}}}while(0);return f|0}function e6E(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=(d&268435440|0)==3145728?d^2:d;d=f-3145728|0;if(d>>>0<16){g=d>>>1;d=g&255;a[9757552+(g&255)|0]=e;if((d<<24>>24|0)==4){g=~e;a[14128520]=g&1;a[14128521]=g&2;return}else if((d<<24>>24|0)==0){c[3531956]=0;return}else{return}}if((f-9699328|0)>>>0<262144){d=c[3532268]|0;a[d+(f&262143^1)|0]=e;g=b[d+(f&262142)>>1]|0;d=f&131070;h=c[9717840+((f>>>17&1)<<2)>>2]|0;b[h+(d<<1)>>1]=(g&65535)>>>8;b[h+((d|1)<<1)>>1]=g&255;return}if((f-9535488|0)>>>0<32){g=e&255;d=f>>>1&15;a[9733144+d|0]=e;if((d|0)!=7){return}if((g&128|0)==0){return}c[2432956]=g>>>6&1^1;return}if((f|0)==3276802){g=c[1836236]|0;d=c[9757320+(g<<2)>>2]|0;if((d|0)!=0){h=d;gGC(h|0,9706056,76)|0}c[9752472+(g<<2)>>2]=c[2433530];c[14113936+(g<<2)>>2]=c[2076596];c[9669104+(g<<2)>>2]=c[3541536];c[1836236]=-1;g=e&15;h=a[9540896]|0;L59262:do{switch(h&255|0){case 1:{a[9540896]=h+1&255;a[9540889]=g;a[9540898]=a[9540898]|1;a[9540900]=1;break};case 3:{a[9540896]=h+1&255;a[9540891]=g;a[9540898]=a[9540898]|2;a[9540900]=1;break};case 0:{a[9540896]=h+1&255;a[9540888]=g;break};case 2:{a[9540896]=h+1&255;a[9540890]=g;break};case 4:{if(g<<24>>24==0){break L59262}d=c[2439330]|0;i=(d|0)==0;if(!i){j=d;gGC(9706056,j|0,76)|0}j=c[2438118]|0;c[2433530]=j;k=c[3528484]|0;c[2076596]=k;l=c[2417276]|0;c[3541536]=l;c[1836236]=0;gGz(9706056,0,76);if(!i){i=d;gGC(i|0,9706056,76)|0}c[2438118]=j;c[3528484]=k;c[2417276]=l;c[1836236]=-1;break};default:{}}}while(0);g=c[2439330]|0;if((g|0)!=0){h=g;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;return}else if((f|0)==3276800){a[9540896]=e&15;return}else{return}}function e6F(d,e){d=d|0;e=e|0;var f=0,g=0,h=0;f=(d&268435440|0)==3145728?d^2:d;d=f-3145728|0;if(d>>>0<16){g=d>>>1;d=g&255;h=e&255;a[9757552+(g&255)|0]=h;if((d<<24>>24|0)==0){c[3531956]=0;return}else if((d<<24>>24|0)==4){d=~h;a[14128520]=d&1;a[14128521]=d&2;return}else{return}}if((f-9699328|0)>>>0<262144){b[(c[3532268]|0)+(f&262142)>>1]=e;d=f&131070;h=c[9717840+((f>>>17&1)<<2)>>2]|0;b[h+(d<<1)>>1]=(e&65535)>>>8;b[h+((d|1)<<1)>>1]=e&255;return}if((f-9535488|0)>>>0>=32){return}d=e&65535;e=d>>>8;h=f>>>1&15;a[9733144+h|0]=e&255;if((h|0)!=7){return}if((e&128|0)==0){return}c[2432956]=d>>>14&1^1;return}function e6G(d){d=d|0;var e=0,f=0,g=0,h=0;e=d-2097152|0;L59308:do{if(e>>>0<16){switch(e>>>1&255|0){case 2:{f=a[14129040]|0;break L59308;break};case 1:{f=a[14129049]|0;break L59308;break};case 4:{f=a[9757556]|0;break L59308;break};case 7:{f=a[14129042]|0;break L59308;break};case 0:{f=a[14129048]|0;break L59308;break};case 3:{f=a[14129041]|0;break L59308;break};default:{f=0;break L59308}}}else{if((d-5505024|0)>>>0<262144){g=d&131070;h=c[9717840+((d>>>17&1)<<2)>>2]|0;if((d&1|0)==0){f=b[h+((g|1)<<1)>>1]&255;break}else{f=b[h+(g<<1)>>1]&255;break}}if((d-5341184|0)>>>0<32){f=a[9733144+(d>>>1&15)|0]|0;break}if((d|0)==2228225){f=a[14128324]|0;break}else if((d|0)==2162689){f=a[14128323]|0;break}else if((d|0)==1048579){g=a[9540896]|0;switch(g&255|0){case 2:{a[9540896]=g+1&255;f=a[9540894]|0;break L59308;break};case 1:{a[9540898]=a[9540898]&-5;a[9540896]=g+1&255;f=a[9540893]|0;break L59308;break};case 0:{a[9540896]=g+1&255;f=a[9540892]|0;break L59308;break};case 4:{f=a[9540898]|0;break L59308;break};case 3:{a[9540898]=a[9540898]&-9;a[9540896]=g+1&255;f=a[9540895]|0;break L59308;break};default:{f=0;break L59308}}}else if((d|0)==2293761){f=a[14128325]|0;break}else{f=0;break}}}while(0);return f|0}function e6H(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=d-2097152|0;if(f>>>0<16){g=f>>>1;f=g&255;a[9757552+(g&255)|0]=e;if((f<<24>>24|0)==0){c[3531956]=0;return}else if((f<<24>>24|0)==4){f=~e;a[14128520]=f&1;a[14128521]=f&2;return}else{return}}if((d-5505024|0)>>>0<262144){f=c[3532268]|0;a[f+(d&262143^1)|0]=e;g=b[f+(d&262142)>>1]|0;f=d&131070;h=c[9717840+((d>>>17&1)<<2)>>2]|0;b[h+(f<<1)>>1]=(g&65535)>>>8;b[h+((f|1)<<1)>>1]=g&255;return}if((d-5341184|0)>>>0<32){g=e&255;f=d>>>1&15;a[9733144+f|0]=e;if((f|0)!=7){return}if((g&128|0)==0){return}c[2432956]=g>>>6&1^1;return}if((d|0)==1048578){g=c[1836236]|0;f=c[9757320+(g<<2)>>2]|0;if((f|0)!=0){h=f;gGC(h|0,9706056,76)|0}c[9752472+(g<<2)>>2]=c[2433530];c[14113936+(g<<2)>>2]=c[2076596];c[9669104+(g<<2)>>2]=c[3541536];c[1836236]=-1;g=e&15;h=a[9540896]|0;L59369:do{switch(h&255|0){case 4:{if(g<<24>>24==0){break L59369}f=c[2439330]|0;i=(f|0)==0;if(!i){j=f;gGC(9706056,j|0,76)|0}j=c[2438118]|0;c[2433530]=j;k=c[3528484]|0;c[2076596]=k;l=c[2417276]|0;c[3541536]=l;c[1836236]=0;gGz(9706056,0,76);if(!i){i=f;gGC(i|0,9706056,76)|0}c[2438118]=j;c[3528484]=k;c[2417276]=l;c[1836236]=-1;break};case 1:{a[9540896]=h+1&255;a[9540889]=g;a[9540898]=a[9540898]|1;a[9540900]=1;break};case 2:{a[9540896]=h+1&255;a[9540890]=g;break};case 3:{a[9540896]=h+1&255;a[9540891]=g;a[9540898]=a[9540898]|2;a[9540900]=1;break};case 0:{a[9540896]=h+1&255;a[9540888]=g;break};default:{}}}while(0);g=c[2439330]|0;if((g|0)!=0){h=g;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;return}else if((d|0)==1048576){a[9540896]=e&15;return}else{return}}function e6I(d,e){d=d|0;e=e|0;var f=0,g=0;if((d-5505024|0)>>>0<262144){b[(c[3532268]|0)+(d&262142)>>1]=e;f=d&131070;g=c[9717840+((d>>>17&1)<<2)>>2]|0;b[g+(f<<1)>>1]=(e&65535)>>>8;b[g+((f|1)<<1)>>1]=e&255;return}if((d-5341184|0)>>>0>=32){return}f=e&65535;e=f>>>8;g=d>>>1&15;a[9733144+g|0]=e&255;if((g|0)!=7){return}if((e&128|0)==0){return}c[2432956]=f>>>14&1^1;return}function e6J(d){d=d|0;var e=0,f=0,g=0;L59405:do{if((d-4456448|0)>>>0<262144){e=d&131070;f=c[9717840+((d>>>17&1)<<2)>>2]|0;if((d&1|0)==0){g=b[f+((e|1)<<1)>>1]&255;break}else{g=b[f+(e<<1)>>1]&255;break}}else{if((d-4292608|0)>>>0<32){g=a[9733144+(d>>>1&15)|0]|0;break}e=d-8388608|0;if(e>>>0<16){switch(e>>>1&255|0){case 0:{g=a[14129048]|0;break L59405;break};case 4:{g=a[9757556]|0;break L59405;break};case 7:{g=a[14129042]|0;break L59405;break};case 1:{g=a[14129049]|0;break L59405;break};case 3:{g=a[14129041]|0;break L59405;break};case 2:{g=a[14129040]|0;break L59405;break};default:{g=0;break L59405}}}else{if((d|0)!=2097154){g=0;break}e=a[9540896]|0;switch(e&255|0){case 4:{g=a[9540898]|0;break L59405;break};case 3:{a[9540898]=a[9540898]&-9;a[9540896]=e+1&255;g=a[9540895]|0;break L59405;break};case 2:{a[9540896]=e+1&255;g=a[9540894]|0;break L59405;break};case 1:{a[9540898]=a[9540898]&-5;a[9540896]=e+1&255;g=a[9540893]|0;break L59405;break};case 0:{a[9540896]=e+1&255;g=a[9540892]|0;break L59405;break};default:{g=0;break L59405}}}}}while(0);return g|0}function e6K(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;if((d-4456448|0)>>>0<262144){f=c[3532268]|0;a[f+(d&262143^1)|0]=e;g=b[f+(d&262142)>>1]|0;f=d&131070;h=c[9717840+((d>>>17&1)<<2)>>2]|0;b[h+(f<<1)>>1]=(g&65535)>>>8;b[h+((f|1)<<1)>>1]=g&255;return}if((d-4292608|0)>>>0<32){g=e&255;f=d>>>1&15;a[9733144+f|0]=e;if((f|0)!=7){return}if((g&128|0)==0){return}c[2432956]=g>>>6&1^1;return}g=d-8388608|0;if(g>>>0<16){f=g>>>1;g=f&255;a[9757552+(f&255)|0]=e;if((g<<24>>24|0)==0){c[3531956]=0;return}else if((g<<24>>24|0)==4){g=~e;a[14128520]=g&1;a[14128521]=g&2;return}else{return}}if((d|0)==2097154){g=c[1836236]|0;f=c[9757320+(g<<2)>>2]|0;if((f|0)!=0){h=f;gGC(h|0,9706056,76)|0}c[9752472+(g<<2)>>2]=c[2433530];c[14113936+(g<<2)>>2]=c[2076596];c[9669104+(g<<2)>>2]=c[3541536];c[1836236]=-1;g=e&15;h=a[9540896]|0;L59462:do{switch(h&255|0){case 0:{a[9540896]=h+1&255;a[9540888]=g;break};case 1:{a[9540896]=h+1&255;a[9540889]=g;a[9540898]=a[9540898]|1;a[9540900]=1;break};case 2:{a[9540896]=h+1&255;a[9540890]=g;break};case 3:{a[9540896]=h+1&255;a[9540891]=g;a[9540898]=a[9540898]|2;a[9540900]=1;break};case 4:{if(g<<24>>24==0){break L59462}f=c[2439330]|0;i=(f|0)==0;if(!i){j=f;gGC(9706056,j|0,76)|0}j=c[2438118]|0;c[2433530]=j;k=c[3528484]|0;c[2076596]=k;l=c[2417276]|0;c[3541536]=l;c[1836236]=0;gGz(9706056,0,76);if(!i){i=f;gGC(i|0,9706056,76)|0}c[2438118]=j;c[3528484]=k;c[2417276]=l;c[1836236]=-1;break};default:{}}}while(0);g=c[2439330]|0;if((g|0)!=0){h=g;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;return}else if((d|0)==2097152){a[9540896]=e&15;return}else{return}}function e6L(d,e){d=d|0;e=e|0;var f=0,g=0,h=0;if((d-4456448|0)>>>0<262144){b[(c[3532268]|0)+(d&262142)>>1]=e;f=d&131070;g=c[9717840+((d>>>17&1)<<2)>>2]|0;b[g+(f<<1)>>1]=(e&65535)>>>8;b[g+((f|1)<<1)>>1]=e&255;return}if((d-4292608|0)>>>0<32){f=e&65535;g=f>>>8;h=d>>>1&15;a[9733144+h|0]=g&255;if((h|0)!=7){return}if((g&128|0)==0){return}c[2432956]=f>>>14&1^1;return}f=d-8388608|0;if(f>>>0>=16){return}d=f>>>1;f=d&255;g=e&255;a[9757552+(d&255)|0]=g;if((f<<24>>24|0)==4){d=~g;a[14128520]=d&1;a[14128521]=d&2;return}else if((f<<24>>24|0)==0){c[3531956]=0;return}else{return}}function e6M(d){d=d|0;var e=0,f=0,g=0;L59507:do{if((d-4456448|0)>>>0<262144){e=d&131070;f=c[9717840+((d>>>17&1)<<2)>>2]|0;if((d&1|0)==0){g=b[f+((e|1)<<1)>>1]&255;break}else{g=b[f+(e<<1)>>1]&255;break}}else{if((d-4292608|0)>>>0<32){g=a[9733144+(d>>>1&15)|0]|0;break}e=d-6291456|0;if(e>>>0<16){switch(e>>>1&255|0){case 7:{g=a[14129042]|0;break L59507;break};case 2:{g=a[14129040]|0;break L59507;break};case 4:{g=a[9757556]|0;break L59507;break};case 0:{g=a[14129048]|0;break L59507;break};case 1:{g=a[14129049]|0;break L59507;break};case 3:{g=a[14129041]|0;break L59507;break};default:{g=0;break L59507}}}if((d|0)==6356993){g=a[14129043]|0;break}else if((d|0)==7340034){e=a[9540896]|0;switch(e&255|0){case 3:{a[9540898]=a[9540898]&-9;a[9540896]=e+1&255;g=a[9540895]|0;break L59507;break};case 1:{a[9540898]=a[9540898]&-5;a[9540896]=e+1&255;g=a[9540893]|0;break L59507;break};case 4:{g=a[9540898]|0;break L59507;break};case 2:{a[9540896]=e+1&255;g=a[9540894]|0;break L59507;break};case 0:{a[9540896]=e+1&255;g=a[9540892]|0;break L59507;break};default:{g=0;break L59507}}}else if((d|0)==6356992){g=a[14129044]|0;break}else{g=0;break}}}while(0);return g|0}function e6N(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;if((d-4456448|0)>>>0<262144){f=c[3532268]|0;a[f+(d&262143^1)|0]=e;g=b[f+(d&262142)>>1]|0;f=d&131070;h=c[9717840+((d>>>17&1)<<2)>>2]|0;b[h+(f<<1)>>1]=(g&65535)>>>8;b[h+((f|1)<<1)>>1]=g&255;return}if((d-4292608|0)>>>0<32){g=e&255;f=d>>>1&15;a[9733144+f|0]=e;if((f|0)!=7){return}if((g&128|0)==0){return}c[2432956]=g>>>6&1^1;return}g=d-6291456|0;if(g>>>0<16){f=g>>>1;g=f&255;a[9757552+(f&255)|0]=e;if((g<<24>>24|0)==4){f=~e;a[14128520]=f&1;a[14128521]=f&2;return}else if((g<<24>>24|0)==0){c[3531956]=0;return}else{return}}if((d-11534336|0)>>>0<524288){g=c[2387030]|0;a[g+(d&524287^1)|0]=e;f=d&524286;h=g+f|0;g=c[2438796]|0;a[g+f|0]=a[h]|0;a[g+(f|1)|0]=a[h]|0;return}if((d|0)==7340032){a[9540896]=e&15;return}else if((d|0)==7340034){d=c[1836236]|0;h=c[9757320+(d<<2)>>2]|0;if((h|0)!=0){f=h;gGC(f|0,9706056,76)|0}c[9752472+(d<<2)>>2]=c[2433530];c[14113936+(d<<2)>>2]=c[2076596];c[9669104+(d<<2)>>2]=c[3541536];c[1836236]=-1;d=e&15;e=a[9540896]|0;L59572:do{switch(e&255|0){case 0:{a[9540896]=e+1&255;a[9540888]=d;break};case 1:{a[9540896]=e+1&255;a[9540889]=d;a[9540898]=a[9540898]|1;a[9540900]=1;break};case 2:{a[9540896]=e+1&255;a[9540890]=d;break};case 3:{a[9540896]=e+1&255;a[9540891]=d;a[9540898]=a[9540898]|2;a[9540900]=1;break};case 4:{if(d<<24>>24==0){break L59572}f=c[2439330]|0;h=(f|0)==0;if(!h){g=f;gGC(9706056,g|0,76)|0}g=c[2438118]|0;c[2433530]=g;i=c[3528484]|0;c[2076596]=i;j=c[2417276]|0;c[3541536]=j;c[1836236]=0;gGz(9706056,0,76);if(!h){h=f;gGC(h|0,9706056,76)|0}c[2438118]=g;c[3528484]=i;c[2417276]=j;c[1836236]=-1;break};default:{}}}while(0);d=c[2439330]|0;if((d|0)!=0){e=d;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;return}else{return}}function e6O(d,e){d=d|0;e=e|0;var f=0,g=0,h=0;if((d-4456448|0)>>>0<262144){b[(c[3532268]|0)+(d&262142)>>1]=e;f=d&131070;g=c[9717840+((d>>>17&1)<<2)>>2]|0;b[g+(f<<1)>>1]=(e&65535)>>>8;b[g+((f|1)<<1)>>1]=e&255;return}if((d-4292608|0)>>>0<32){f=e&65535;g=f>>>8;h=d>>>1&15;a[9733144+h|0]=g&255;if((h|0)!=7){return}if((g&128|0)==0){return}c[2432956]=f>>>14&1^1;return}f=d-6291456|0;if(f>>>0<16){g=f>>>1;f=g&255;h=e&255;a[9757552+(g&255)|0]=h;if((f<<24>>24|0)==4){g=~h;a[14128520]=g&1;a[14128521]=g&2;return}else if((f<<24>>24|0)==0){c[3531956]=0;return}else{return}}if((d-11534336|0)>>>0<524288){f=d&524286;g=(c[2387030]|0)+f|0;b[g>>1]=e;h=c[2438796]|0;a[h+f|0]=e&255;a[h+(f|1)|0]=a[g]|0;return}if((d|0)==12582900){b[(c[2443496]|0)+2>>1]=e;return}else if((d|0)==12582898){b[c[2443496]>>1]=e;return}else{return}}function e6P(e){e=e|0;var f=0,g=0,h=0;L59626:do{if((e-4456448|0)>>>0<262144){f=e&131070;g=c[9717840+((e>>>17&1)<<2)>>2]|0;if((e&1|0)==0){h=b[g+((f|1)<<1)>>1]&255;break}else{h=b[g+(f<<1)>>1]&255;break}}else{if((e-4292608|0)>>>0<32){h=a[9733144+(e>>>1&15)|0]|0;break}if((e|0)==6291458|(e|0)==8388610){h=a[9757560]|0;break}else if((e|0)==6291456|(e|0)==8388608){switch(d[9757560]|0|0){case 1:{h=a[14129049]|0;break L59626;break};case 7:{h=a[14129042]|0;break L59626;break};case 2:{h=a[14129040]|0;break L59626;break};case 4:{h=a[9757556]|0;break L59626;break};case 3:{h=a[14129041]|0;break L59626;break};case 0:{h=a[14129048]|0;break L59626;break};default:{h=0;break L59626}}}else if((e|0)==10485762){f=a[9540896]|0;switch(f&255|0){case 2:{a[9540896]=f+1&255;h=a[9540894]|0;break L59626;break};case 3:{a[9540898]=a[9540898]&-9;a[9540896]=f+1&255;h=a[9540895]|0;break L59626;break};case 1:{a[9540898]=a[9540898]&-5;a[9540896]=f+1&255;h=a[9540893]|0;break L59626;break};case 4:{h=a[9540898]|0;break L59626;break};case 0:{a[9540896]=f+1&255;h=a[9540892]|0;break L59626;break};default:{h=0;break L59626}}}else{h=0;break}}}while(0);return h|0}function e6Q(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;if((d-4456448|0)>>>0<262144){f=c[3532268]|0;a[f+(d&262143^1)|0]=e;g=b[f+(d&262142)>>1]|0;f=d&131070;h=c[9717840+((d>>>17&1)<<2)>>2]|0;b[h+(f<<1)>>1]=(g&65535)>>>8;b[h+((f|1)<<1)>>1]=g&255;return}if((d-4292608|0)>>>0<32){g=e&255;f=d>>>1&15;a[9733144+f|0]=e;if((f|0)!=7){return}if((g&128|0)==0){return}c[2432956]=g>>>6&1^1;return}if((d|0)==6291456|(d|0)==8388608){c[3531956]=0;g=a[9757560]|0;a[9757552+(g&255)|0]=e;if((g<<24>>24|0)==4){f=~e;a[14128520]=f&1;a[14128521]=f&2;return}else if((g<<24>>24|0)==0){c[3531956]=0;return}else{return}}else if((d|0)==10485760){a[9540896]=e&15;return}else if((d|0)==6291458|(d|0)==8388610){a[9757560]=e;return}else if((d|0)==10485762){d=c[1836236]|0;g=c[9757320+(d<<2)>>2]|0;if((g|0)!=0){f=g;gGC(f|0,9706056,76)|0}c[9752472+(d<<2)>>2]=c[2433530];c[14113936+(d<<2)>>2]=c[2076596];c[9669104+(d<<2)>>2]=c[3541536];c[1836236]=-1;d=e&15;e=a[9540896]|0;L59685:do{switch(e&255|0){case 2:{a[9540896]=e+1&255;a[9540890]=d;break};case 1:{a[9540896]=e+1&255;a[9540889]=d;a[9540898]=a[9540898]|1;a[9540900]=1;break};case 3:{a[9540896]=e+1&255;a[9540891]=d;a[9540898]=a[9540898]|2;a[9540900]=1;break};case 4:{if(d<<24>>24==0){break L59685}f=c[2439330]|0;g=(f|0)==0;if(!g){h=f;gGC(9706056,h|0,76)|0}h=c[2438118]|0;c[2433530]=h;i=c[3528484]|0;c[2076596]=i;j=c[2417276]|0;c[3541536]=j;c[1836236]=0;gGz(9706056,0,76);if(!g){g=f;gGC(g|0,9706056,76)|0}c[2438118]=h;c[3528484]=i;c[2417276]=j;c[1836236]=-1;break};case 0:{a[9540896]=e+1&255;a[9540888]=d;break};default:{}}}while(0);d=c[2439330]|0;if((d|0)!=0){e=d;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;return}else{return}}function e6R(d,e){d=d|0;e=e|0;var f=0,g=0;if((d-4456448|0)>>>0<262144){b[(c[3532268]|0)+(d&262142)>>1]=e;f=d&131070;g=c[9717840+((d>>>17&1)<<2)>>2]|0;b[g+(f<<1)>>1]=(e&65535)>>>8;b[g+((f|1)<<1)>>1]=e&255;return}if((d-4292608|0)>>>0>=32){return}f=e&65535;e=f>>>8;g=d>>>1&15;a[9733144+g|0]=e&255;if((g|0)!=7){return}if((e&128|0)==0){return}c[2432956]=f>>>14&1^1;return}function e6S(d){d=d|0;var e=0,f=0,g=0,h=0,i=0;e=d-2097152|0;L59719:do{if((d|0)!=2097154&e>>>0<16){switch(e>>>1&255|0){case 3:{f=a[14129041]|0;break L59719;break};case 7:{f=a[14129042]|0;break L59719;break};case 1:{f=a[14129049]|0;break L59719;break};case 2:{f=a[14129040]|0;break L59719;break};case 0:{f=a[14129048]|0;break L59719;break};case 4:{f=a[9757556]|0;break L59719;break};default:{f=0;break L59719}}}else{if((d-4456448|0)>>>0<262144){g=d&131070;h=c[9717840+((d>>>17&1)<<2)>>2]|0;if((d&1|0)==0){f=b[h+((g|1)<<1)>>1]&255;break}else{f=b[h+(g<<1)>>1]&255;break}}if((d-4292608|0)>>>0<32){f=a[9733144+(d>>>1&15)|0]|0;break}if((d|0)==6291458){g=a[9540896]|0;switch(g&255|0){case 0:{a[9540896]=g+1&255;f=a[9540892]|0;break L59719;break};case 3:{a[9540898]=a[9540898]&-9;a[9540896]=g+1&255;f=a[9540895]|0;break L59719;break};case 4:{f=a[9540898]|0;break L59719;break};case 1:{a[9540898]=a[9540898]&-5;a[9540896]=g+1&255;f=a[9540893]|0;break L59719;break};case 2:{a[9540896]=g+1&255;f=a[9540894]|0;break L59719;break};default:{f=0;break L59719}}}else if((d|0)==2097188){f=a[14129044]|0;break}else if((d|0)==2097154){g=a[14129040]&254;do{if((c[2406632]|0)==0){h=c[2443744]|0;if((h|0)<=0){i=1;break}c[2443744]=h-1;i=0}else{i=(c[2432962]|0)>>>((c[(c[2420380]|0)+4>>2]|0)>>>0)&1}}while(0);f=(i|g)&255;break}else if((d|0)==2097192){f=c[2442904]&255;break}else if((d|0)==2097198){f=a[14129045]|0;break}else{f=0;break}}}while(0);return f|0}function e6T(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=d-2097152|0;if(f>>>0<16){g=f>>>1;f=g&255;a[9757552+(g&255)|0]=e;if((f<<24>>24|0)==4){g=~e;a[14128520]=g&1;a[14128521]=g&2;return}else if((f<<24>>24|0)==0){c[3531956]=0;return}else{return}}if((d-4456448|0)>>>0<262144){f=c[3532268]|0;a[f+(d&262143^1)|0]=e;g=b[f+(d&262142)>>1]|0;f=d&131070;h=c[9717840+((d>>>17&1)<<2)>>2]|0;b[h+(f<<1)>>1]=(g&65535)>>>8;b[h+((f|1)<<1)>>1]=g&255;return}if((d-4292608|0)>>>0<32){g=e&255;f=d>>>1&15;a[9733144+f|0]=e;if((f|0)!=7){return}if((g&128|0)==0){return}c[2432956]=g>>>6&1^1;return}if((d|0)==6291456){a[9540896]=e&15;return}else if((d|0)==6291458){g=c[1836236]|0;f=c[9757320+(g<<2)>>2]|0;if((f|0)!=0){h=f;gGC(h|0,9706056,76)|0}c[9752472+(g<<2)>>2]=c[2433530];c[14113936+(g<<2)>>2]=c[2076596];c[9669104+(g<<2)>>2]=c[3541536];c[1836236]=-1;g=e&15;h=a[9540896]|0;L59787:do{switch(h&255|0){case 0:{a[9540896]=h+1&255;a[9540888]=g;break};case 1:{a[9540896]=h+1&255;a[9540889]=g;a[9540898]=a[9540898]|1;a[9540900]=1;break};case 2:{a[9540896]=h+1&255;a[9540890]=g;break};case 3:{a[9540896]=h+1&255;a[9540891]=g;a[9540898]=a[9540898]|2;a[9540900]=1;break};case 4:{if(g<<24>>24==0){break L59787}f=c[2439330]|0;i=(f|0)==0;if(!i){j=f;gGC(9706056,j|0,76)|0}j=c[2438118]|0;c[2433530]=j;k=c[3528484]|0;c[2076596]=k;l=c[2417276]|0;c[3541536]=l;c[1836236]=0;gGz(9706056,0,76);if(!i){i=f;gGC(i|0,9706056,76)|0}c[2438118]=j;c[3528484]=k;c[2417276]=l;c[1836236]=-1;break};default:{}}}while(0);g=c[2439330]|0;if((g|0)!=0){h=g;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;return}else if((d|0)==2097192){c[2442904]=e&255;h=~e;a[14128522]=h&1;a[14128523]=h&2;return}else if((d|0)==2097190){d=e&255;c[2415256]=d&4;e=d>>>4&1;c[3528406]=e^1;if((e|0)==0){c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2]}Tr(d>>>3&1);return}else{return}}function e6U(d,e){d=d|0;e=e|0;var f=0,g=0,h=0;if((d-4456448|0)>>>0<262144){b[(c[3532268]|0)+(d&262142)>>1]=e;f=d&131070;g=c[9717840+((d>>>17&1)<<2)>>2]|0;b[g+(f<<1)>>1]=(e&65535)>>>8;b[g+((f|1)<<1)>>1]=e&255;return}if((d-4292608|0)>>>0<32){f=e&65535;g=f>>>8;h=d>>>1&15;a[9733144+h|0]=g&255;if((h|0)!=7){return}if((g&128|0)==0){return}c[2432956]=f>>>14&1^1;return}f=d-2097152|0;if(f>>>0>=16){return}d=f>>>1;f=d&255;g=e&255;a[9757552+(d&255)|0]=g;if((f<<24>>24|0)==4){d=~g;a[14128520]=d&1;a[14128521]=d&2;return}else if((f<<24>>24|0)==0){c[3531956]=0;return}else{return}}function e6V(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4557924+(b*112|0)>>2];c[a+104>>2]=c[4557928+(b*112|0)>>2];c[a+108>>2]=c[4557932+(b*112|0)>>2];d=0;return d|0}function e6W(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=4557824+(b*112|0);e=0;return e|0}function e6X(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4154304+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function e6Y(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>41){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5292992+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e6Z(){return e8L(354,1,2,0,4,5)|0}function e6_(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;b=i;i=i+128|0;d=b|0;e=c[c[642608+(c[2436]<<2)>>2]>>2]|0;be(d|0,128,179600,(f=i,i=i+24|0,c[f>>2]=9374064,c[f+8>>2]=47,c[f+16>>2]=e,f)|0)|0;i=f;a[1040128]=0;f=c[2420380]|0;e=c[f>>2]|0;g=c[f+4>>2]|0;f=fw(d|0,389440)|0;if((f|0)!=0){d=g>>3<<e&1023;cj(14100392,d|0,1,f|0)|0;aY(f|0)|0}if((c[2392]|0)>=0){f=0;do{d=14130368+(f<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}d=14130384+(f<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}f=f+1|0;}while((f|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;fwZ();if(a[6482904]|0){f=c[3541518]|0;if((f|0)!=0){gGr(f|0);c[3541518]=0}if((c[2385508]|0)>0){c[2113008]=0;c[2076598]=0;c[2383582]=0}c[2438228]=0;c[2433526]=0;c[2406676]=0;c[3528472]=0;f=c[2406680]|0;if((f|0)!=0){gGr(f);c[2406680]=0}c[2385508]=0;c[2432978]=0;a[64240]=0;Uw(0);c[3541206]=0}else{f=c[3541514]|0;if((f|0)!=0){gGr(f|0);c[3541514]=0}c[2113008]=0;c[2076598]=0;c[2383582]=0;c[2438228]=0;c[2433526]=0;c[2406676]=0;c[3528472]=0;f=c[2406698]|0;if((f|0)!=0){gGr(f);c[2406698]=0}f=c[2385412]|0;if((f|0)!=0){gGr(f);c[2385412]=0}a[64232]=0}f=c[2438796]|0;d=0;while(1){if((d|0)>=1024){h=45765;break}j=9638528+(d<<2)|0;if((c[j>>2]|0)==(f|0)){break}else{d=d+1|0}}if((h|0)==45765){c[2438796]=0;gGz(9721680,0,5);k=e_a()|0;i=b;return 0}gGr(f);c[j>>2]=0;c[2438796]=0;gGz(9721680,0,5);k=e_a()|0;i=b;return 0}function e6$(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((a[14128072]|0)!=0){e8O(1)}d=c[2392]|0;if((d|0)>=0){gGz(8452240,0,((d|0)>0?(d<<2)+4|0:4)|0)}c[2113054]=0;d=c[2385548]|0;if((d|0)>0){gGz(9752472,0,((d|0)>1?d<<2:4)|0)}c[2433530]=0;d=(c[3531956]|0)+1|0;c[3531956]=d;if((d|0)>180){e8O(0)}gu[c[3532050]&16383]();if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}d=c[2439330]|0;if((d|0)!=0){e=d;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;e=c[2385704]|0;d=c[2438]|0;f=d;g=(d|0)<0|0?-1:0;d=gGU(f,g,e,(e|0)<0|0?-1:0)|0;e=gGS(d,K,256,0)|0;d=c[2385702]|0;h=gGU(d,(d|0)<0|0?-1:0,f,g)|0;g=gGS(h,K,256,0)|0;h=g;g=(e|0)/12e3|0;e=(h|0)/12e3|0;f=0;d=0;i=0;j=0;do{i=i+g|0;k=i-f|0;c[2113056]=k;l=RG(k)|0;c[2113054]=(c[2113054]|0)+l;c[2276108]=-1;c[2113056]=-1;f=l+f|0;do{if((j|0)==199){l=c[3528618]|0;c[8452200+(c[2394]<<2)>>2]=l|8192;k=c[2276080]|0;m=l<<8;c[2276080]=m;if((k|0)!=1792&(m|0)==1792){RH(7);break}if(m>>>0<=(c[2276079]|0)>>>0){break}RH(l&16777215)}else if((j|0)==4){l=c[3528620]|0;c[8452200+(c[2394]<<2)>>2]=l|8192;m=c[2276080]|0;k=l<<8;c[2276080]=k;if((m|0)!=1792&(k|0)==1792){RH(7);break}if(k>>>0<=(c[2276079]|0)>>>0){break}RH(l&16777215)}}while(0);d=d+e|0;Sb(d);j=j+1|0;}while((j|0)<200);j=(h|0)/60|0;h=gGU(j,(j|0)<0|0?-1:0,2048e6,0)|0;d=c[2438228]|0;e=gGS(h,K,d,(d|0)<0|0?-1:0)|0;d=e;Sb(j);j=c[2443830]|0;if((j|0)<1073676288){c[2443830]=j-d}j=c[2443831]|0;if((j|0)<1073676288){c[2443831]=j-d}j=(c[3528512]|0)-d|0;c[3528512]=(j|0)<0?0:j;j=c[2112964]|0;do{if((j|0)!=0){if(a[6482904]|0){gg[c[3542122]&4095](j,a[9688]|0?534:0);Uu(0,c[2112964]|0,a[9688]|0?534:0);break}else{gg[c[3542118]&4095](j,a[9688]|0?534:0);break}}}while(0);j=c[1836236]|0;d=c[9757320+(j<<2)>>2]|0;if((d|0)!=0){e=d;gGC(e|0,9706056,76)|0}c[9752472+(j<<2)>>2]=c[2433530];c[14113936+(j<<2)>>2]=c[2076596];c[9669104+(j<<2)>>2]=c[3541536];c[1836236]=-1;j=c[2394]|0;e=c[14130368+(j<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(j<<2)>>2]=c[2113054];c[2394]=-1;if((c[2112968]|0)==0){return 0}e60()|0;return 0}function e60(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0;f=c[3532026]|0;g=c[3532028]|0;h=0;do{i=e[f+(h<<1)>>1]|0;j=i>>>12;k=i>>>8;l=i>>>4&15;c[g+(h<<2)>>2]=(j<<4|j)<<8&63488|(k&12|k<<4)<<3&2016|(l<<4|l)>>>3;h=h+1|0;}while((h|0)<4096);if((a[9733151]&32)==0){h=c[2112926]|0;gGz(h|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);R8(g);return 0}e_b(d[9771536]|0,1,-1);h=d[9771539]<<4;e_c(1,h);e_b(d[9771537]|0,0,0);f=c[2438796]|0;do{if((f|0)!=0){l=c[2443496]|0;k=e[l>>1]<<1;j=c[2113070]|0;if((j|0)<=0){break}i=-16-(e[l+2>>1]|0)|0;l=c[2113068]|0;m=c[2112926]|0;n=0;do{o=ag(n,l)|0;p=i+n<<10&523264;if((l|0)>0){q=0;do{r=a[f+(q-k&1023|p)|0]|0;if(r<<24>>24!=0){b[m+(q+o<<1)>>1]=r&255|2048}q=q+1|0;}while((q|0)<(l|0))}n=n+1|0;}while((n|0)<(j|0))}}while(0);e_c(0,h);h=d[9771538]|0;f=c[2388448]|0;if((f|0)!=0){j=c[3532266]|0;n=d[9733150]<<11&30720;l=c[2440184]|0;m=(c[3528672]|0)==0;k=c[2112926]|0;i=a[947416]|0?16:0;q=c[2388452]|0;o=0;do{p=o<<3&504;r=o>>6<<3;s=e[j+(o+n<<1)>>1]|0;t=(s>>>12)+h|0;u=(d[9733144+(s>>>11&1|4)|0]<<11|s&2047)&f;do{if((a[l+u|0]|0)==0){if(m){Sr(k,u,p,r-i|0,t,4,0,0,q);break}else{Sx(k,u,-8-p+(c[2113068]|0)|0,248-r-i|0,t,4,0,0,q);break}}}while(0);o=o+1|0;}while((o|0)<2048)}R8(g);g=~d[9733151];if((g&1|0)!=0){o=c[2432956]|0;gGz((c[3532268]|0)+(o<<17)|0,0,131072);gGz(c[9717840+(o<<2)>>2]|0,0,262144)}if((g&128|0)!=0){c[2432956]=c[2432956]^1}g=c[2388446]|0;if((g|0)==0){return 0}o=c[9717840+(c[2432956]<<2)>>2]|0;q=c[2113068]|0;c[2113068]=512;i=c[2113070]|0;c[2113070]=256;k=c[3531970]|0;m=c[2388450]|0;l=0;f=0;h=0;n=0;j=0;t=3256;r=0;p=0;u=0;s=0;while(1){v=e[k+(t<<1)>>1]&g;w=e[k+((t|1)<<1)>>1]|0;x=e[k+((t|2)<<1)>>1]|0;y=x&1023;z=e[k+((t|3)<<1)>>1]|0;A=z&1023;B=b[k+((t|5)<<1)>>1]|0;C=B&65535;D=w&16384;E=w&32768;F=y>>>0>511?x|-1024:y;y=A>>>0>511?z|-1024:A;if(B<<16>>16!=0&(f|0)==0){B=b[k+((t|4)<<1)>>1]|0;A=B&65535;G=F;H=y;I=0;J=0;K=C>>>8;L=A&255;M=A>>>8;N=1;O=C&255;P=B}else{G=s;H=u;I=p;J=r;K=j;L=n;M=h;N=f;O=l;P=b[k+((t|4)<<1)>>1]|0}B=P&65535;C=B>>>8;A=B&255;do{if((N|0)==0){Q=y;R=F;S=I;T=J;U=(256-A|0)>>>4;V=(256-C|0)>>>4;W=A;X=C;Y=0}else{B=256-M|0;z=G+((ag(I,B)|0)>>>4)|0;x=256-L|0;Z=H+((ag(J,x)|0)>>>4)|0;_=I+1|0;$=((ag(_,B)|0)>>>4)+G-z|0;B=J+1|0;aa=((ag(B,x)|0)>>>4)+H-Z|0;if((B|0)<=(O|0)){Q=Z;R=z;S=I;T=B;U=aa;V=$;W=L;X=M;Y=N;break}Q=Z;R=z;S=_;T=0;U=aa;V=$;W=L;X=M;Y=(_|0)>(K|0)?0:N}}while(0);do{if((W|X|0)==0){C=(D|0)!=0;A=w&63;if((E|0)==0){if(C){SJ(o,v,R,Q,A,4,0,0,m);break}else{SH(o,v,R,Q,A,4,0,0,m);break}}else{if(C){SN(o,v,R,Q,A,4,0,0,m);break}else{SL(o,v,R,Q,A,4,0,0,m);break}}}else{S2(o,m,v,w<<4&1008,0,R,Q,D,E,V<<12,U<<12)}}while(0);E=t-8|0;if((E|0)>-1){l=O;f=Y;h=M;n=L;j=K;t=E;r=T;p=S;u=H;s=G}else{break}}c[2113068]=q;c[2113070]=i;return 0}function e61(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;f=i;i=i+96|0;g=f|0;h=f+16|0;j=f+32|0;k=f+48|0;l=f+64|0;m=f+80|0;if((e|0)!=0){c[e>>2]=169736}if((d&96|0)!=0){gGz(m|0,0,12);n=c[3532020]|0;c[m>>2]=n;c[m+4>>2]=(c[3532022]|0)-n;c[m+12>>2]=162152;n=c[2076592]|0;gj[n&4095](m)|0;m=j|0;do{if((d&64|0)!=0){gGz(h|0,0,16);c[2394]=-1;if((c[2392]|0)<0){break}n=j+9|0;o=g;p=g|0;q=g+4|0;r=g+12|0;s=h|0;t=h+4|0;u=h+12|0;v=0;do{gGC(m|0,614896,11)|0;a[n]=v+48&255;w=8452256+(v<<2)|0;gGz(o|0,0,12);c[p>>2]=w;c[q>>2]=4;c[r>>2]=164976;gj[c[2076592]&4095](g)|0;if((c[w>>2]|0)!=0){c[s>>2]=c[14130368+(v<<2)>>2];c[t>>2]=c[8452184+(v<<2)>>2];c[u>>2]=m;w=c[2076592]|0;gj[w&4095](h)|0}v=v+1|0;}while((v|0)<=(c[2392]|0))}}while(0);fw$(d);eZ7(d);if(a[6482904]|0){Vx(d,e);Ut(0)}else{T0(d,e)}gGz(l|0,0,12);c[l>>2]=14127752;c[l+4>>2]=1;c[l+12>>2]=272344;e=c[2076592]|0;gj[e&4095](l)|0;gGz(k|0,0,12);c[k>>2]=14127824;c[k+4>>2]=4;c[k+12>>2]=369064;l=c[2076592]|0;gj[l&4095](k)|0}if((d&2|0)==0){i=f;return 0}d=c[2439330]|0;k=(d|0)==0;if(!k){l=d;gGC(9706056,l|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];l=c[3528484]|0;c[2076596]=l;e=c[2417276]|0;c[3541536]=e;c[1836236]=0;h=a[14127752]&3;a[14127752]=h;m=c[3531932]|0;g=((h&255)<<14)-16384|0;h=64;j=64;while(1){c[d+76+(j<<2)>>2]=m+(g+(j<<8));v=h+1&65535;if((v&65535)>127){x=64;y=64;break}else{h=v;j=v&65535}}while(1){j=m+(g+(y<<8))|0;c[d+76+(y+512<<2)>>2]=j;c[d+76+(y+768<<2)>>2]=j;j=x+1&65535;if((j&65535)>127){break}else{x=j;y=j&65535}}if(!k){k=d;gGC(k|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=l;c[2417276]=e;c[1836236]=-1;i=f;return 0}function e62(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2609508+(b*112|0)>>2];c[a+104>>2]=c[2609512+(b*112|0)>>2];c[a+108>>2]=c[2609516+(b*112|0)>>2];d=0;return d|0}function e63(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=2609408+(b*112|0);e=0;return e|0}function e64(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2610292+(b*112|0)>>2];c[a+104>>2]=c[2610296+(b*112|0)>>2];c[a+108>>2]=c[2610300+(b*112|0)>>2];d=0;return d|0}function e65(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=2610192+(b*112|0);e=0;return e|0}function e66(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5765364+(b*112|0)>>2];c[a+104>>2]=c[5765368+(b*112|0)>>2];c[a+108>>2]=c[5765372+(b*112|0)>>2];d=0;return d|0}function e67(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=5765264+(b*112|0);e=0;return e|0}function e68(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>33){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6208184+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e69(){return e8L(12124,0,0,0,2,4)|0}function e7a(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2396868+(b*112|0)>>2];c[a+104>>2]=c[2396872+(b*112|0)>>2];c[a+108>>2]=c[2396876+(b*112|0)>>2];d=0;return d|0}function e7b(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=2396768+(b*112|0);e=0;return e|0}function e7c(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>33){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3573176+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e7d(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4519980+(b*112|0)>>2];c[a+104>>2]=c[4519984+(b*112|0)>>2];c[a+108>>2]=c[4519988+(b*112|0)>>2];d=0;return d|0}function e7e(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=4519880+(b*112|0);e=0;return e|0}function e7f(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>36){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5226056+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e7g(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5732604+(b*112|0)>>2];c[a+104>>2]=c[5732608+(b*112|0)>>2];c[a+108>>2]=c[5732612+(b*112|0)>>2];d=0;return d|0}function e7h(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=5732504+(b*112|0);e=0;return e|0}function e7i(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>24){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1760128+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function e7j(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>30){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5114304+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e7k(){var b=0,d=0,e=0,f=0,g=0;a[9721681]=48;c[2113302]=2;a[801640]=1;b=c[642608+(c[2436]<<2)>>2]|0;d=c[b+128>>2]|0;if((c[b+52>>2]&4|0)==0){c[2440576]=d;e=c[b+132>>2]|0;c[2440574]=e;f=d;g=e}else{c[2440574]=d;e=c[b+132>>2]|0;c[2440576]=e;f=e;g=d}d=(((f|0)/2|0)<<8)-1792|0;f=(((g|0)/2|0)<<8)-2048|0;c[3542196]=d;c[3542192]=f;c[3542197]=d;c[3542193]=f;c[3542198]=d;c[3542194]=f;c[3542199]=d;c[3542195]=f;return e8L(1160,0,2,0,1,6)|0}function e7l(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4449892+(b*112|0)>>2];c[a+104>>2]=c[4449896+(b*112|0)>>2];c[a+108>>2]=c[4449900+(b*112|0)>>2];d=0;return d|0}function e7m(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=4449792+(b*112|0);e=0;return e|0}function e7n(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>24){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4451012+(b*112|0)>>2];c[a+104>>2]=c[4451016+(b*112|0)>>2];c[a+108>>2]=c[4451020+(b*112|0)>>2];d=0;return d|0}function e7o(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<25&(d|0)==0)){e=1;return e|0}c[a>>2]=4450912+(b*112|0);e=0;return e|0}function e7p(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>28){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6157656+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e7q(){var a=0,b=0;a=e8L(1160,0,0,0,1,6)|0;if((a|0)!=0){return a|0}b=c[3532204]|0;gGG(b+262144|0,b+131072|0,262144);return a|0}function e7r(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5931236+(b*112|0)>>2];c[a+104>>2]=c[5931240+(b*112|0)>>2];c[a+108>>2]=c[5931244+(b*112|0)>>2];d=0;return d|0}function e7s(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=5931136+(b*112|0);e=0;return e|0}function e7t(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>43){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6393032+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e7u(){return e8L(5272,0,1,0,3,5)|0}function e7v(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4769236+(b*112|0)>>2];c[a+104>>2]=c[4769240+(b*112|0)>>2];c[a+108>>2]=c[4769244+(b*112|0)>>2];d=0;return d|0}function e7w(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=4769136+(b*112|0);e=0;return e|0}function e7x(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>43){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5523232+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e7y(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4770132+(b*112|0)>>2];c[a+104>>2]=c[4770136+(b*112|0)>>2];c[a+108>>2]=c[4770140+(b*112|0)>>2];d=0;return d|0}function e7z(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=4770032+(b*112|0);e=0;return e|0}function e7A(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>43){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5523760+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e7B(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>4){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4363228+(b*112|0)>>2];c[a+104>>2]=c[4363232+(b*112|0)>>2];c[a+108>>2]=c[4363236+(b*112|0)>>2];d=0;return d|0}function e7C(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<5&(d|0)==0)){e=1;return e|0}c[a>>2]=4363128+(b*112|0);e=0;return e|0}function e7D(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4930488+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e7E(){return e8L(1160,0,0,0,2,4)|0}function e7F(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2170468+(b*112|0)>>2];c[a+104>>2]=c[2170472+(b*112|0)>>2];c[a+108>>2]=c[2170476+(b*112|0)>>2];d=0;return d|0}function e7G(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=2170368+(b*112|0);e=0;return e|0}function e7H(){return e8L(12672,1,2,0,4,5)|0}function e7I(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2095772+(b*112|0)>>2];c[a+104>>2]=c[2095776+(b*112|0)>>2];c[a+108>>2]=c[2095780+(b*112|0)>>2];d=0;return d|0}function e7J(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=2095672+(b*112|0);e=0;return e|0}function e7K(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1175264+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function e7L(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>25){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3262408+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e7M(){return e8L(8566,1,2,0,1,4)|0}function e7N(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1343540+(b*112|0)>>2];c[a+104>>2]=c[1343544+(b*112|0)>>2];c[a+108>>2]=c[1343548+(b*112|0)>>2];d=0;return d|0}function e7O(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=1343440+(b*112|0);e=0;return e|0}function e7P(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1344884+(b*112|0)>>2];c[a+104>>2]=c[1344888+(b*112|0)>>2];c[a+108>>2]=c[1344892+(b*112|0)>>2];d=0;return d|0}function e7Q(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=1344784+(b*112|0);e=0;return e|0}function e7R(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5951380+(b*112|0)>>2];c[a+104>>2]=c[5951384+(b*112|0)>>2];c[a+108>>2]=c[5951388+(b*112|0)>>2];d=0;return d|0}function e7S(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=5951280+(b*112|0);e=0;return e|0}function e7T(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>41){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6430752+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e7U(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4828388+(b*112|0)>>2];c[a+104>>2]=c[4828392+(b*112|0)>>2];c[a+108>>2]=c[4828396+(b*112|0)>>2];d=0;return d|0}function e7V(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=4828288+(b*112|0);e=0;return e|0}function e7W(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>41){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5601016+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e7X(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4827492+(b*112|0)>>2];c[a+104>>2]=c[4827496+(b*112|0)>>2];c[a+108>>2]=c[4827500+(b*112|0)>>2];d=0;return d|0}function e7Y(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=4827392+(b*112|0);e=0;return e|0}function e7Z(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>41){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5600512+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e7_(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5865836+(b*112|0)>>2];c[a+104>>2]=c[5865840+(b*112|0)>>2];c[a+108>>2]=c[5865844+(b*112|0)>>2];d=0;return d|0}function e7$(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=5865736+(b*112|0);e=0;return e|0}function e70(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>38){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3868288+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function e71(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>33){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6275312+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e72(){return e8L(4380,1,0,1,6,4)|0}function e73(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4667100+(b*112|0)>>2];c[a+104>>2]=c[4667104+(b*112|0)>>2];c[a+108>>2]=c[4667108+(b*112|0)>>2];d=0;return d|0}function e74(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=4667e3+(b*112|0);e=0;return e|0}function e75(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>5){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2308828+(b*112|0)>>2];c[a+104>>2]=c[2308832+(b*112|0)>>2];c[a+108>>2]=c[2308836+(b*112|0)>>2];d=0;return d|0}function e76(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<6&(d|0)==0)){e=1;return e|0}c[a>>2]=2308728+(b*112|0);e=0;return e|0}function e77(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1197056+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function e78(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>35){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3509848+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e79(){return e8L(8958,0,2,1,4,6)|0}function e8a(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4396604+(b*112|0)>>2];c[a+104>>2]=c[4396608+(b*112|0)>>2];c[a+108>>2]=c[4396612+(b*112|0)>>2];d=0;return d|0}function e8b(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=4396504+(b*112|0);e=0;return e|0}function e8c(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>40){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1696144+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function e8d(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>37){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4993528+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e8e(){var a=0;a=e8L(440,0,2,2,4,6)|0;if((a|0)!=0){return a|0}c[2385704]=16e6;return a|0}function e8f(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2282076+(b*112|0)>>2];c[a+104>>2]=c[2282080+(b*112|0)>>2];c[a+108>>2]=c[2282084+(b*112|0)>>2];d=0;return d|0}function e8g(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=2281976+(b*112|0);e=0;return e|0}function e8h(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>42){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3446504+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e8i(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2280844+(b*112|0)>>2];c[a+104>>2]=c[2280848+(b*112|0)>>2];c[a+108>>2]=c[2280852+(b*112|0)>>2];d=0;return d|0}function e8j(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=2280744+(b*112|0);e=0;return e|0}function e8k(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5695860+(b*112|0)>>2];c[a+104>>2]=c[5695864+(b*112|0)>>2];c[a+108>>2]=c[5695868+(b*112|0)>>2];d=0;return d|0}function e8l(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=5695760+(b*112|0);e=0;return e|0}function e8m(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>30){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6144704+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e8n(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2408820+(b*112|0)>>2];c[a+104>>2]=c[2408824+(b*112|0)>>2];c[a+108>>2]=c[2408828+(b*112|0)>>2];d=0;return d|0}function e8o(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=2408720+(b*112|0);e=0;return e|0}function e8p(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>29){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1206656+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function e8q(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>3){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3583664+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e8r(){return e8L(11212,0,1,3,5,3)|0}function e8s(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>5){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4490748+(b*112|0)>>2];c[a+104>>2]=c[4490752+(b*112|0)>>2];c[a+108>>2]=c[4490756+(b*112|0)>>2];d=0;return d|0}function e8t(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<6&(d|0)==0)){e=1;return e|0}c[a>>2]=4490648+(b*112|0);e=0;return e|0}function e8u(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>41){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1787944+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function e8v(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>3){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5167704+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e8w(){return e8L(1646,0,1,3,5,3)|0}function e8x(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4384396+(b*112|0)>>2];c[a+104>>2]=c[4384400+(b*112|0)>>2];c[a+108>>2]=c[4384404+(b*112|0)>>2];d=0;return d|0}function e8y(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=4384296+(b*112|0);e=0;return e|0}function e8z(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2248924+(b*112|0)>>2];c[a+104>>2]=c[2248928+(b*112|0)>>2];c[a+108>>2]=c[2248932+(b*112|0)>>2];d=0;return d|0}function e8A(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=2248824+(b*112|0);e=0;return e|0}function e8B(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>5){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2248252+(b*112|0)>>2];c[a+104>>2]=c[2248256+(b*112|0)>>2];c[a+108>>2]=c[2248260+(b*112|0)>>2];d=0;return d|0}function e8C(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<6&(d|0)==0)){e=1;return e|0}c[a>>2]=2248152+(b*112|0);e=0;return e|0}function e8D(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>42){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1189400+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function e8E(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>44){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3405624+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e8F(){return e8L(440,0,2,3,4,6)|0}function e8G(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>23){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7338564+(b*112|0)>>2];c[a+104>>2]=c[7338568+(b*112|0)>>2];c[a+108>>2]=c[7338572+(b*112|0)>>2];d=0;return d|0}function e8H(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<24&(d|0)==0)){e=1;return e|0}c[a>>2]=7338464+(b*112|0);e=0;return e|0}function e8I(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6809096+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function e8J(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7383800+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e8K(){a[9721682]=96;return e8L(8540,0,0,0,5,4)|0}function e8L(e,f,g,j,k,l){e=e|0;f=f|0;g=g|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0;m=i;i=i+32|0;n=m|0;o=m+16|0;p=m+24|0;eZ9(0)|0;c[3532048]=0;c[3532204]=0;q=((c[3532200]|0)-1|524287)+1|0;c[3531932]=q;r=q+(c[3531928]|0)|0;c[3532136]=r;q=c[3532144]<<1&1073741822;s=r+q|0;c[3531962]=s;r=s+q|0;c[3532056]=r;q=c[3532052]|0;s=r+q|0;c[3531952]=s;r=c[3531948]|0;t=s+r|0;c[3531946]=t;s=t+(c[3531942]|0)|0;t=(r|q|0)==0?s+262144|0:s;s=t|0;c[3532020]=s;c[3532208]=s;c[3532026]=t+65536;c[3531970]=t+73728;c[2387030]=t+81920;c[2443496]=t+606208;c[3531936]=t+606212;s=t+614404|0;c[3532022]=s;c[3532028]=s;s=t+630788|0;c[3532046]=s;t=s;s=0;while(1){if((s|0)>=1024){break}u=9638528+(s<<2)|0;if((c[u>>2]|0)==0){v=46508;break}else{s=s+1|0}}do{if((v|0)==46508){s=gGq(t)|0;c[u>>2]=s;if((s|0)==0){break}gGz(s|0,0,t|0);c[3532048]=s;gGz(s|0,0,t|0);c[3532204]=s;q=((c[3532200]|0)-1|524287)+1|0;c[3531932]=s+q;r=q+(c[3531928]|0)|0;c[3532136]=s+r;q=c[3532144]<<1&1073741822;w=r+q|0;c[3531962]=s+w;r=w+q|0;c[3532056]=s+r;q=c[3532052]|0;w=r+q|0;c[3531952]=s+w;r=c[3531948]|0;x=w+r|0;c[3531946]=s+x;w=x+(c[3531942]|0)|0;x=(r|q|0)==0?w+262144|0:w;w=s+x|0;c[3532020]=w;c[3532208]=w;c[3532026]=s+(x+65536);c[3531970]=s+(x+73728);c[2387030]=s+(x+81920);c[2443496]=s+(x+606208);c[3531936]=s+(x+606212);w=s+(x+614404)|0;c[3532022]=w;c[3532028]=w;c[3532046]=s+(x+630788);if((eZ9(1)|0)!=0){y=1;i=m;return y|0}x=c[3532144]|0;L60770:do{if((x|0)==0){z=0;A=0}else{c[n>>2]=0;c[n+4>>2]=8;s=x<<3;w=(s|0)/2|0;c[n+8>>2]=w;c[n+12>>2]=w+8;w=0;while(1){if((w|0)>=1024){z=0;A=0;break L60770}B=9638528+(w<<2)|0;if((c[B>>2]|0)==0){break}else{w=w+1|0}}w=gGq(x)|0;c[B>>2]=w;if((w|0)==0){z=0;A=0;break}gGz(w|0,0,x|0);q=c[3532136]|0;gGC(w|0,q|0,x)|0;r=(s|0)/256|0;do{if((s|0)>255){C=0;do{D=C<<6;gGz(q+D|0,0,64);E=C<<7;F=0;do{G=1<<3-F;H=(c[n+(F<<2)>>2]|0)+E|0;I=0;do{J=H+(c[597800+(I<<2)>>2]|0)|0;L=(I<<3)+D|0;M=0;do{N=J+(c[597864+(M<<2)>>2]|0)|0;if((d[w+((N|0)/8|0)|0]&128>>>((N&7)>>>0)|0)!=0){N=q+(L+M)|0;a[N]=(d[N]|G)&255}M=M+1|0;}while((M|0)<8);I=I+1|0;}while((I|0)<8);F=F+1|0;}while((F|0)<4);C=C+1|0;}while((C|0)<(r|0));C=(s|0)/1024|0;F=c[3531962]|0;if((s|0)>1023){O=0}else{P=C;break}while(1){D=O<<8;gGz(F+D|0,0,256);E=O<<9;I=0;do{G=1<<3-I;H=(c[n+(I<<2)>>2]|0)+E|0;M=0;do{L=H+(c[597800+(M<<2)>>2]|0)|0;J=(M<<4)+D|0;N=0;do{Q=L+(c[597864+(N<<2)>>2]|0)|0;if((d[w+((Q|0)/8|0)|0]&128>>>((Q&7)>>>0)|0)!=0){Q=F+(J+N)|0;a[Q]=(d[Q]|G)&255}N=N+1|0;}while((N|0)<16);M=M+1|0;}while((M|0)<16);I=I+1|0;}while((I|0)<4);I=O+1|0;if((I|0)<(C|0)){O=I}else{P=C;break}}}else{P=(s|0)/1024|0}}while(0);s=r-1|0;q=P-1|0;C=0;while(1){if((C|0)>=1024){z=q;A=s;break L60770}R=9638528+(C<<2)|0;if((c[R>>2]|0)==(w|0)){break}else{C=C+1|0}}gGr(w);c[R>>2]=0;z=q;A=s}}while(0);x=614728+(g<<2)|0;c[2442884]=d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24;c[3528620]=k;c[3528618]=l;c[2385704]=12e6;c[2385702]=4e6;a[9721684]=j&255;a[7461056]=1;c[3532050]=4250;x=c[3532136]|0;C=c[3531962]|0;a[7461064]=1;r=0;while(1){if((r|0)>=1024){S=0;break}T=9638528+(r<<2)|0;if((c[T>>2]|0)==0){v=46544;break}else{r=r+1|0}}do{if((v|0)==46544){r=gGq(262144)|0;c[T>>2]=r;if((r|0)==0){S=0;break}gGz(r|0,0,262144);S=r}}while(0);c[2429460]=S;r=0;while(1){if((r|0)>=1024){U=0;break}V=9638528+(r<<2)|0;if((c[V>>2]|0)==0){v=46549;break}else{r=r+1|0}}do{if((v|0)==46549){r=gGq(1028)|0;c[V>>2]=r;if((r|0)==0){U=0;break}gGz(r|0,0,1028);U=r}}while(0);c[2430810]=U;r=0;while(1){if((r|0)>=1024){W=0;break}X=9638528+(r<<2)|0;if((c[X>>2]|0)==0){v=46554;break}else{r=r+1|0}}do{if((v|0)==46554){r=gGq(1028)|0;c[X>>2]=r;if((r|0)==0){W=0;break}gGz(r|0,0,1028);W=r}}while(0);c[2430808]=W;r=0;while(1){if((r|0)>=1024){Y=0;break}Z=9638528+(r<<2)|0;if((c[Z>>2]|0)==0){v=46559;break}else{r=r+1|0}}do{if((v|0)==46559){r=gGq(262144)|0;c[Z>>2]=r;if((r|0)==0){Y=0;break}gGz(r|0,0,262144);Y=r}}while(0);c[2429461]=Y;r=0;while(1){if((r|0)>=1024){_=0;break}$=9638528+(r<<2)|0;if((c[$>>2]|0)==0){v=46564;break}else{r=r+1|0}}do{if((v|0)==46564){r=gGq(1028)|0;c[$>>2]=r;if((r|0)==0){_=0;break}gGz(r|0,0,1028);_=r}}while(0);c[2430811]=_;r=0;while(1){if((r|0)>=1024){aa=0;break}ab=9638528+(r<<2)|0;if((c[ab>>2]|0)==0){v=46569;break}else{r=r+1|0}}do{if((v|0)==46569){r=gGq(1028)|0;c[ab>>2]=r;if((r|0)==0){aa=0;break}gGz(r|0,0,1028);aa=r}}while(0);c[2430809]=aa;r=0;while(1){if((r|0)>=1024){ac=0;break}ad=9638528+(r<<2)|0;if((c[ad>>2]|0)==0){v=46574;break}else{r=r+1|0}}do{if((v|0)==46574){r=gGq(65536)|0;c[ad>>2]=r;if((r|0)==0){ac=0;break}gGz(r|0,0,65536);ac=r}}while(0);c[3532266]=ac;r=0;while(1){if((r|0)>=1024){ae=0;break}af=9638528+(r<<2)|0;if((c[af>>2]|0)==0){v=46579;break}else{r=r+1|0}}do{if((v|0)==46579){r=gGq(2048)|0;c[af>>2]=r;if((r|0)==0){ae=0;break}gGz(r|0,0,2048);ae=r}}while(0);c[3532264]=ae;r=0;while(1){if((r|0)>=1024){ah=0;break}ai=9638528+(r<<2)|0;if((c[ai>>2]|0)==0){v=46584;break}else{r=r+1|0}}do{if((v|0)==46584){r=gGq(262144)|0;c[ai>>2]=r;if((r|0)==0){ah=0;break}gGz(r|0,0,262144);ah=r}}while(0);c[3532268]=ah;c[2388448]=A;c[2388446]=z;c[2388452]=x;c[2388450]=C;r=(A|0)==0;do{if(!r){F=A+1|0;I=0;while(1){if((I|0)>=1024){aj=0;break}ak=9638528+(I<<2)|0;if((c[ak>>2]|0)==0){v=46590;break}else{I=I+1|0}}do{if((v|0)==46590){I=gGq(F)|0;c[ak>>2]=I;if((I|0)==0){aj=0;break}gGz(I|0,0,F|0);aj=I}}while(0);c[2440184]=aj;gGz(aj|0,1,F|0);I=F<<6;if((I|0)<=0){break}s=c[2388452]|0;q=0;do{if((a[s+q|0]|0)==0){al=q}else{a[aj+((q|0)/64|0)|0]=0;al=q|63}q=al+1|0;}while((q|0)<(I|0))}}while(0);do{if((z|0)!=0){C=c[2388446]|0;if((C|0)==0){break}x=C+1|0;C=0;while(1){if((C|0)>=1024){am=0;break}an=9638528+(C<<2)|0;if((c[an>>2]|0)==0){v=46602;break}else{C=C+1|0}}do{if((v|0)==46602){C=gGq(x)|0;c[an>>2]=C;if((C|0)==0){am=0;break}gGz(C|0,0,x|0);am=C}}while(0);c[2440182]=am;gGz(am|0,1,x|0);C=x<<8;if((C|0)<=0){break}I=c[2388450]|0;q=0;do{if((a[I+q|0]|0)==0){ao=q}else{a[am+((q|0)/256|0)|0]=0;ao=q|255}q=ao+1|0;}while((q|0)<(C|0))}}while(0);if(r){C=0;while(1){if((C|0)>=1024){ap=0;break}aq=9638528+(C<<2)|0;if((c[aq>>2]|0)==0){v=46612;break}else{C=C+1|0}}do{if((v|0)==46612){C=gGq(256)|0;c[aq>>2]=C;if((C|0)==0){ap=0;break}gGz(C|0,0,256);ap=C}}while(0);c[3528790]=ap;C=0;while(1){if((C|0)>=1024){ar=0;break}as=9638528+(C<<2)|0;if((c[as>>2]|0)==0){v=46617;break}else{C=C+1|0}}do{if((v|0)==46617){C=gGq(1)|0;c[as>>2]=C;if((C|0)==0){ar=0;break}a[C]=0;ar=C}}while(0);c[2440182]=ar;c[2388450]=c[3528790]}a[947416]=1;gGz(c[2429460]|0,0,262144);gGz(c[2430810]|0,0,1024);gGz(c[2430808]|0,0,1024);gGz(c[2429461]|0,0,262144);gGz(c[2430811]|0,0,1024);gGz(c[2430809]|0,0,1024);gGz(9733144,0,16);gGz(c[3532266]|0,0,65536);gGz(c[3532264]|0,0,2048);gGz(c[3532268]|0,0,262144);c[3528672]=0;c[2432956]=0;Tq(830288);if((e|0)!=0){gu[e&16383]()}if((f|0)==0){a[6482904]=0;fwR(0);C=c[2439330]|0;r=(C|0)==0;if(!r){q=C;gGC(9706056,q|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];q=c[3528484]|0;c[2076596]=q;I=c[2417276]|0;c[3541536]=I;c[1836236]=0;x=c[3531932]|0;s=0;F=0;while(1){c[C+76+(F<<2)>>2]=x+(F<<8);w=s+1&65535;if((w&65535)>63){at=0;au=0;break}else{s=w;F=w&65535}}while(1){F=x+(au<<8)|0;c[C+76+(au+512<<2)>>2]=F;c[C+76+(au+768<<2)>>2]=F;F=at+1&65535;if((F&65535)>63){break}else{at=F;au=F&65535}}x=c[3531936]|0;F=192;s=192;while(1){c[C+76+(s<<2)>>2]=x+((s<<8)-49152);w=F+1&65535;if((w&65535)>223){av=192;aw=192;break}else{F=w;s=w&65535}}while(1){c[C+76+(aw+256<<2)>>2]=x+((aw<<8)-49152);s=av+1&65535;if((s&65535)>223){ax=192;ay=192;break}else{av=s;aw=s&65535}}while(1){s=x+((ay<<8)-49152)|0;c[C+76+(ay+512<<2)>>2]=s;c[C+76+(ay+768<<2)>>2]=s;s=ax+1&65535;if((s&65535)>223){break}else{ax=s;ay=s&65535}}c[C+4184>>2]=2042;c[C+4180>>2]=1816;if(!r){x=C;gGC(x|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=q;c[2417276]=I;c[1836236]=-1;a[7461080]=1;c[o>>2]=c[3531948];c[p>>2]=c[3531942];TW(c[3531952]|0,o,c[3531946]|0,p,258,2916,112);x=c[2385702]|0;c[2438228]=x;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;s=gGS(2048e6,0,x,(x|0)<0|0?-1:0)|0;x=gGK(s,K,-1,0)|0;c[2443846]=x;h[745406]=1.0;c[2436786]=3;h[745405]=1.0;c[2436784]=3;h[745404]=.25;a[3203280]=1}else{a[6482904]=1;fwR(0);x=c[2439330]|0;s=(x|0)==0;if(!s){F=x;gGC(9706056,F|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];F=c[3528484]|0;c[2076596]=F;w=c[2417276]|0;c[3541536]=w;c[1836236]=0;D=c[3531932]|0;E=0;M=0;while(1){c[x+76+(M<<2)>>2]=D+(M<<8);G=E+1&65535;if((G&65535)>63){az=0;aA=0;break}else{E=G;M=G&65535}}while(1){M=D+(aA<<8)|0;c[x+76+(aA+512<<2)>>2]=M;c[x+76+(aA+768<<2)>>2]=M;M=az+1&65535;if((M&65535)>63){break}else{az=M;aA=M&65535}}D=c[3531936]|0;c[x+588>>2]=D;c[x+592>>2]=D+256;c[x+596>>2]=D+512;c[x+600>>2]=D+768;c[x+604>>2]=D+1024;c[x+608>>2]=D+1280;c[x+612>>2]=D+1536;c[x+616>>2]=D+1792;c[x+620>>2]=D+2048;c[x+624>>2]=D+2304;c[x+628>>2]=D+2560;c[x+632>>2]=D+2816;c[x+636>>2]=D+3072;c[x+640>>2]=D+3328;c[x+644>>2]=D+3584;c[x+648>>2]=D+3840;M=128;E=128;while(1){c[x+76+(E+256<<2)>>2]=D+((E<<8)-32768);I=M+1&65535;if((I&65535)>143){aB=128;aC=128;break}else{M=I;E=I&65535}}while(1){E=D+((aC<<8)-32768)|0;c[x+76+(aC+512<<2)>>2]=E;c[x+76+(aC+768<<2)>>2]=E;E=aB+1&65535;if((E&65535)>143){break}else{aB=E;aC=E&65535}}c[x+4184>>2]=1434;c[x+4180>>2]=16;if(!s){D=x;gGC(D|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=F;c[2417276]=w;c[1836236]=-1;a[7461080]=1;Vr(1,3e6,258,2916,112,0);c[3542224]=0;c[3542225]=0;c[3542226]=2206;c[3542227]=0;D=c[2385702]|0;c[2438228]=D;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;E=gGS(2048e6,0,D,(D|0)<0|0?-1:0)|0;D=gGK(E,K,-1,0)|0;c[2443846]=D;h[745419]=.8;a[3203368]=1;h[745418]=.25;a[3203360]=1;h[745417]=.25;a[3203352]=1;h[745416]=.25;a[3203344]=1;c[3541206]=c[3532056];Ux(0,8e3,1);c[2407030]=128;c[2407068]=3}D=c[642608+(c[2436]<<2)>>2]|0;E=c[D+128>>2]|0;if((c[D+52>>2]&4|0)==0){c[2113068]=E;M=c[D+132>>2]|0;c[2113070]=M;c[2443814]=E;c[2440436]=M;aD=E;aE=M}else{c[2113070]=E;M=c[D+132>>2]|0;c[2113068]=M;c[2440436]=E;c[2443814]=M;aD=M;aE=E}E=ag(aD<<1,aE)|0;M=gGq(E)|0;c[2112926]=M;if((M|0)!=0){gGz(M|0,0,E|0)}e8O(1);y=0;i=m;return y|0}}while(0);c[3532048]=0;y=1;i=m;return y|0}function e8M(){var a=0,b=0,d=0,e=0,f=0,g=0;fxU(0,425984);if((c[2394]|0)==0){a=c[2112932]|0}else{c[2394]=0;b=c[3532596]|0;c[2112932]=b;d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];a=b}b=c[3532204]|0;d=a|0;e=0;while(1){f=b+e|0;c[d>>2]=f;c[d+131072>>2]=f;f=e+1024|0;if(f>>>0>524287){break}else{d=d+4|0;e=f}}e=c[3532208]|0;d=a+4096|0;b=1048576;while(1){f=e+(b-1048576)|0;c[d>>2]=f;c[d+65536>>2]=f;c[d+131072>>2]=f;f=b+1024|0;if(f>>>0>1114111){break}else{d=d+4|0;b=f}}b=c[3532026]|0;c[a+8192>>2]=b;c[a+73728>>2]=b;c[a+139264>>2]=b;d=b+1024|0;c[a+8196>>2]=d;c[a+73732>>2]=d;c[a+139268>>2]=d;d=b+2048|0;c[a+8200>>2]=d;c[a+73736>>2]=d;c[a+139272>>2]=d;d=b+3072|0;c[a+8204>>2]=d;c[a+73740>>2]=d;c[a+139276>>2]=d;d=b+4096|0;c[a+8208>>2]=d;c[a+73744>>2]=d;c[a+139280>>2]=d;d=b+5120|0;c[a+8212>>2]=d;c[a+73748>>2]=d;c[a+139284>>2]=d;d=b+6144|0;c[a+8216>>2]=d;c[a+73752>>2]=d;c[a+139288>>2]=d;d=b+7168|0;c[a+8220>>2]=d;c[a+73756>>2]=d;c[a+139292>>2]=d;d=c[3532266]|0;b=a+36864|0;e=9437184;while(1){f=d+(e-9437184)|0;c[b>>2]=f;c[b+65536>>2]=f;c[b+131072>>2]=f;f=e+1024|0;if(f>>>0>9502719){break}else{b=b+4|0;e=f}}e=c[3531970]|0;c[a+37120>>2]=e;c[a+102656>>2]=e;c[a+168192>>2]=e;b=e+1024|0;c[a+37124>>2]=b;c[a+102660>>2]=b;c[a+168196>>2]=b;b=e+2048|0;c[a+37128>>2]=b;c[a+102664>>2]=b;c[a+168200>>2]=b;b=e+3072|0;c[a+37132>>2]=b;c[a+102668>>2]=b;c[a+168204>>2]=b;b=e+4096|0;c[a+37136>>2]=b;c[a+102672>>2]=b;c[a+168208>>2]=b;b=e+5120|0;c[a+37140>>2]=b;c[a+102676>>2]=b;c[a+168212>>2]=b;b=e+6144|0;c[a+37144>>2]=b;c[a+102680>>2]=b;c[a+168216>>2]=b;b=e+7168|0;c[a+37148>>2]=b;c[a+102684>>2]=b;c[a+168220>>2]=b;b=e+8192|0;c[a+37152>>2]=b;c[a+102688>>2]=b;c[a+168224>>2]=b;b=e+9216|0;c[a+37156>>2]=b;c[a+102692>>2]=b;c[a+168228>>2]=b;b=e+10240|0;c[a+37160>>2]=b;c[a+102696>>2]=b;c[a+168232>>2]=b;b=e+11264|0;c[a+37164>>2]=b;c[a+102700>>2]=b;c[a+168236>>2]=b;b=e+12288|0;c[a+37168>>2]=b;c[a+102704>>2]=b;c[a+168240>>2]=b;b=e+13312|0;c[a+37172>>2]=b;c[a+102708>>2]=b;c[a+168244>>2]=b;b=c[3532264]|0;c[a+37176>>2]=b;c[a+102712>>2]=b;c[a+168248>>2]=b;e=b+1024|0;c[a+37180>>2]=e;c[a+102716>>2]=e;c[a+168252>>2]=e;c[a+196648>>2]=1734;c[a+196728>>2]=454;c[a+196608>>2]=766;a=c[3532592]|0;if((a|0)==0){g=c[2113054]|0;c[2113060]=g;c[2394]=-1;return}gGC(a|0,9104152,280)|0;g=c[2113054]|0;c[2113060]=g;c[2394]=-1;return}function e8N(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;gGz(14129040,-1|0,3);gGz(14128323,-1|0,3);b=0;e=-1;f=-1;g=-1;h=-1;i=-1;j=-1;do{e=((a[14129032+b|0]&1)<<b^e&255)&255;f=((a[14129024+b|0]&1)<<b^f&255)&255;g=((a[14129016+b|0]&1)<<b^g&255)&255;h=((a[14128288+b|0]&1)<<b^h&255)&255;i=((a[14128280+b|0]&1)<<b^i&255)&255;j=((a[14128264+b|0]&1)<<b^j&255)&255;b=b+1|0;}while((b|0)<8);a[14128324]=i;a[14128325]=j;i=a[9721680]^e;a[14129040]=i;e=a[9721681]^f;a[14129041]=e;f=a[9721682]^g;a[14129042]=f;a[14128323]=a[9721683]^h;h=d[9721684]|0;do{if((h|0)==0){if((a[14128520]|0)==0){k=f}else{g=f|4;a[14129042]=g;k=g}if((a[14128521]|0)==0){break}a[14129042]=k|8}else if((h|0)==1){if((a[14128520]|0)==0){l=e}else{g=e|16;a[14129041]=g;l=g}if((a[14128521]|0)==0){break}a[14129041]=l|32}else if((h|0)==2){if((a[14128520]|0)==0){m=e}else{g=e|16;a[14129041]=g;m=g}if((a[14128521]|0)!=0){a[14129041]=m|32}if((a[14128522]|0)==0){n=j}else{g=j|1;a[14128325]=g;n=g}if((a[14128523]|0)==0){break}a[14128325]=n|4}else if((h|0)==3){if((a[14128520]|0)==0){o=i}else{g=i|16;a[14129040]=g;o=g}if((a[14128521]|0)==0){p=o}else{g=o|32;a[14129040]=g;p=g}if((a[14128522]|0)==0){q=p}else{g=p|64;a[14129040]=g;q=g}if((a[14128523]|0)==0){break}a[14129040]=q|-128}}while(0);if((c[2113302]|0)==0){return}q=c[3532184]|0;p=(c[3542196]|0)+(c[3532186]<<16>>16)|0;c[3542196]=p;o=(c[3542192]|0)+(q<<16>>16)|0;c[3542192]=o;if((p|0)<-2048){c[3542196]=-2048;r=-2048}else{r=p}p=(c[2440576]<<8)-2048|0;if((r|0)>(p|0)){c[3542196]=p}if((o|0)<-2048){c[3542192]=-2048;s=-2048}else{s=o}o=(c[2440574]<<8)-2048|0;if((s|0)>(o|0)){c[3542192]=o}s=c[3532180]|0;r=(c[3542197]|0)+(c[3532182]<<16>>16)|0;c[3542197]=r;q=(c[3542193]|0)+(s<<16>>16)|0;c[3542193]=q;if((r|0)<-2048){c[3542197]=-2048;t=-2048}else{t=r}if((t|0)>(p|0)){c[3542197]=p}if((q|0)<-2048){c[3542193]=-2048;u=-2048}else{u=q}if((u|0)<=(o|0)){return}c[3542193]=o;return}function e8O(d){d=d|0;var e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((d|0)!=0){d=c[3532020]|0;gGz(d|0,0,(c[3532022]|0)-d|0)}d=c[2438796]|0;if((d|0)!=0){gGz(d|0,0,524288)}if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);if(!e){j=d;gGC(j|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=i;c[1836236]=-1;if(!(a[6482904]|0)){c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;l6(0);eZ6();c[2440216]=0;c[2406632]=0;k=c[2420380]|0;l=k+32|0;m=c[l>>2]|0;c[2443744]=m;c[2442904]=0;c[2440826]=0;a[14127752]=0;return}if(!e){e=d;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=f;c[2076596]=g;c[3541536]=i;c[1836236]=0;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){i=0;do{lN(i);mB(i);i=i+1|0;}while((i|0)<(c[2385508]|0));i=c[1836236]|0;n=i;o=c[9757320+(i<<2)>>2]|0}else{n=0;o=d}if((o|0)!=0){d=o;gGC(d|0,9706056,76)|0}c[9752472+(n<<2)>>2]=c[2433530];c[14113936+(n<<2)>>2]=c[2076596];c[9669104+(n<<2)>>2]=c[3541536];c[1836236]=-1;c[2113156]=0;a[9628264]=0;c[2407033]=0;n=c[3541206]|0;c[3541190]=n;c[3541198]=n;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=n+256;c[3541199]=n+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=n+512;c[3541200]=n+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=n+768;c[3541201]=n+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;eZ6();c[2440216]=0;c[2406632]=0;k=c[2420380]|0;l=k+32|0;m=c[l>>2]|0;c[2443744]=m;c[2442904]=0;c[2440826]=0;a[14127752]=0;return}function e8P(b,c){b=b|0;c=c|0;a[9706117]=(c|0)!=0|0;return}function e8Q(a){a=a|0;var b=0,d=0;b=(c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=c[2385702]|0;b=gGS(d,K,a,(a|0)<0|0?-1:0)|0;return b|0}function e8R(){return+(+((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)/+(c[2385702]|0))}function e8S(){var a=0,b=0,d=0,e=0,f=0,g=0;fxU(0,425984);if((c[2394]|0)==0){a=c[2112932]|0}else{c[2394]=0;b=c[3532596]|0;c[2112932]=b;d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];a=b}b=c[3532204]|0;d=a|0;e=0;while(1){f=b+e|0;c[d>>2]=f;c[d+131072>>2]=f;f=e+1024|0;if(f>>>0>524287){break}else{d=d+4|0;e=f}}e=c[3532026]|0;c[a+12288>>2]=e;c[a+77824>>2]=e;c[a+143360>>2]=e;d=e+1024|0;c[a+12292>>2]=d;c[a+77828>>2]=d;c[a+143364>>2]=d;d=e+2048|0;c[a+12296>>2]=d;c[a+77832>>2]=d;c[a+143368>>2]=d;d=e+3072|0;c[a+12300>>2]=d;c[a+77836>>2]=d;c[a+143372>>2]=d;d=e+4096|0;c[a+12304>>2]=d;c[a+77840>>2]=d;c[a+143376>>2]=d;d=e+5120|0;c[a+12308>>2]=d;c[a+77844>>2]=d;c[a+143380>>2]=d;d=e+6144|0;c[a+12312>>2]=d;c[a+77848>>2]=d;c[a+143384>>2]=d;d=e+7168|0;c[a+12316>>2]=d;c[a+77852>>2]=d;c[a+143388>>2]=d;d=c[3532208]|0;c[a+16384>>2]=d;c[a+81920>>2]=d;c[a+147456>>2]=d;e=d+1024|0;c[a+16388>>2]=e;c[a+81924>>2]=e;c[a+147460>>2]=e;e=d+2048|0;c[a+16392>>2]=e;c[a+81928>>2]=e;c[a+147464>>2]=e;e=d+3072|0;c[a+16396>>2]=e;c[a+81932>>2]=e;c[a+147468>>2]=e;e=d+4096|0;c[a+16400>>2]=e;c[a+81936>>2]=e;c[a+147472>>2]=e;e=d+5120|0;c[a+16404>>2]=e;c[a+81940>>2]=e;c[a+147476>>2]=e;e=d+6144|0;c[a+16408>>2]=e;c[a+81944>>2]=e;c[a+147480>>2]=e;e=d+7168|0;c[a+16412>>2]=e;c[a+81948>>2]=e;c[a+147484>>2]=e;e=d+8192|0;c[a+16416>>2]=e;c[a+81952>>2]=e;c[a+147488>>2]=e;e=d+9216|0;c[a+16420>>2]=e;c[a+81956>>2]=e;c[a+147492>>2]=e;e=d+10240|0;c[a+16424>>2]=e;c[a+81960>>2]=e;c[a+147496>>2]=e;e=d+11264|0;c[a+16428>>2]=e;c[a+81964>>2]=e;c[a+147500>>2]=e;e=d+12288|0;c[a+16432>>2]=e;c[a+81968>>2]=e;c[a+147504>>2]=e;e=d+13312|0;c[a+16436>>2]=e;c[a+81972>>2]=e;c[a+147508>>2]=e;e=d+14336|0;c[a+16440>>2]=e;c[a+81976>>2]=e;c[a+147512>>2]=e;e=d+15360|0;c[a+16444>>2]=e;c[a+81980>>2]=e;c[a+147516>>2]=e;e=c[3532266]|0;d=a+20480|0;b=5242880;while(1){f=e+(b-5242880)|0;c[d>>2]=f;c[d+65536>>2]=f;c[d+131072>>2]=f;f=b+1024|0;if(f>>>0>5308415){break}else{d=d+4|0;b=f}}b=c[3531970]|0;c[a+20736>>2]=b;c[a+86272>>2]=b;c[a+151808>>2]=b;d=b+1024|0;c[a+20740>>2]=d;c[a+86276>>2]=d;c[a+151812>>2]=d;d=b+2048|0;c[a+20744>>2]=d;c[a+86280>>2]=d;c[a+151816>>2]=d;d=b+3072|0;c[a+20748>>2]=d;c[a+86284>>2]=d;c[a+151820>>2]=d;d=b+4096|0;c[a+20752>>2]=d;c[a+86288>>2]=d;c[a+151824>>2]=d;d=b+5120|0;c[a+20756>>2]=d;c[a+86292>>2]=d;c[a+151828>>2]=d;d=b+6144|0;c[a+20760>>2]=d;c[a+86296>>2]=d;c[a+151832>>2]=d;d=b+7168|0;c[a+20764>>2]=d;c[a+86300>>2]=d;c[a+151836>>2]=d;d=b+8192|0;c[a+20768>>2]=d;c[a+86304>>2]=d;c[a+151840>>2]=d;d=b+9216|0;c[a+20772>>2]=d;c[a+86308>>2]=d;c[a+151844>>2]=d;d=b+10240|0;c[a+20776>>2]=d;c[a+86312>>2]=d;c[a+151848>>2]=d;d=b+11264|0;c[a+20780>>2]=d;c[a+86316>>2]=d;c[a+151852>>2]=d;d=b+12288|0;c[a+20784>>2]=d;c[a+86320>>2]=d;c[a+151856>>2]=d;d=b+13312|0;c[a+20788>>2]=d;c[a+86324>>2]=d;c[a+151860>>2]=d;d=c[3532264]|0;c[a+20792>>2]=d;c[a+86328>>2]=d;c[a+151864>>2]=d;b=d+1024|0;c[a+20796>>2]=b;c[a+86332>>2]=b;c[a+151868>>2]=b;c[a+196648>>2]=2622;c[a+196728>>2]=3346;c[a+196608>>2]=2704;a=c[3532592]|0;if((a|0)==0){g=c[2113054]|0;c[2113060]=g;c[2394]=-1;return}gGC(a|0,9104152,280)|0;g=c[2113054]|0;c[2113060]=g;c[2394]=-1;return}function e8T(){var a=0,b=0,d=0,e=0,f=0,g=0;fxU(0,425984);if((c[2394]|0)==0){a=c[2112932]|0}else{c[2394]=0;b=c[3532596]|0;c[2112932]=b;d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];a=b}b=c[3532204]|0;d=a|0;e=0;while(1){f=b+e|0;c[d>>2]=f;c[d+131072>>2]=f;f=e+1024|0;if(f>>>0>524287){break}else{d=d+4|0;e=f}}e=c[3532266]|0;d=a+16384|0;b=4194304;while(1){f=e+(b-4194304)|0;c[d>>2]=f;c[d+65536>>2]=f;c[d+131072>>2]=f;f=b+1024|0;if(f>>>0>4259839){break}else{d=d+4|0;b=f}}b=c[3531970]|0;c[a+16640>>2]=b;c[a+82176>>2]=b;c[a+147712>>2]=b;d=b+1024|0;c[a+16644>>2]=d;c[a+82180>>2]=d;c[a+147716>>2]=d;d=b+2048|0;c[a+16648>>2]=d;c[a+82184>>2]=d;c[a+147720>>2]=d;d=b+3072|0;c[a+16652>>2]=d;c[a+82188>>2]=d;c[a+147724>>2]=d;d=b+4096|0;c[a+16656>>2]=d;c[a+82192>>2]=d;c[a+147728>>2]=d;d=b+5120|0;c[a+16660>>2]=d;c[a+82196>>2]=d;c[a+147732>>2]=d;d=b+6144|0;c[a+16664>>2]=d;c[a+82200>>2]=d;c[a+147736>>2]=d;d=b+7168|0;c[a+16668>>2]=d;c[a+82204>>2]=d;c[a+147740>>2]=d;d=b+8192|0;c[a+16672>>2]=d;c[a+82208>>2]=d;c[a+147744>>2]=d;d=b+9216|0;c[a+16676>>2]=d;c[a+82212>>2]=d;c[a+147748>>2]=d;d=b+10240|0;c[a+16680>>2]=d;c[a+82216>>2]=d;c[a+147752>>2]=d;d=b+11264|0;c[a+16684>>2]=d;c[a+82220>>2]=d;c[a+147756>>2]=d;d=b+12288|0;c[a+16688>>2]=d;c[a+82224>>2]=d;c[a+147760>>2]=d;d=b+13312|0;c[a+16692>>2]=d;c[a+82228>>2]=d;c[a+147764>>2]=d;d=c[3532264]|0;c[a+16696>>2]=d;c[a+82232>>2]=d;c[a+147768>>2]=d;b=d+1024|0;c[a+16700>>2]=b;c[a+82236>>2]=b;c[a+147772>>2]=b;b=c[3532026]|0;c[a+32768>>2]=b;c[a+98304>>2]=b;c[a+163840>>2]=b;d=b+1024|0;c[a+32772>>2]=d;c[a+98308>>2]=d;c[a+163844>>2]=d;d=b+2048|0;c[a+32776>>2]=d;c[a+98312>>2]=d;c[a+163848>>2]=d;d=b+3072|0;c[a+32780>>2]=d;c[a+98316>>2]=d;c[a+163852>>2]=d;d=b+4096|0;c[a+32784>>2]=d;c[a+98320>>2]=d;c[a+163856>>2]=d;d=b+5120|0;c[a+32788>>2]=d;c[a+98324>>2]=d;c[a+163860>>2]=d;d=b+6144|0;c[a+32792>>2]=d;c[a+98328>>2]=d;c[a+163864>>2]=d;d=b+7168|0;c[a+32796>>2]=d;c[a+98332>>2]=d;c[a+163868>>2]=d;d=c[3532208]|0;b=a+36864|0;e=9437184;while(1){f=d+(e-9437184)|0;c[b>>2]=f;c[b+65536>>2]=f;c[b+131072>>2]=f;f=e+1024|0;if(f>>>0>9502719){break}else{b=b+4|0;e=f}}c[a+196648>>2]=3284;c[a+196728>>2]=2074;c[a+196608>>2]=1536;a=c[3532592]|0;if((a|0)==0){g=c[2113054]|0;c[2113060]=g;c[2394]=-1;return}gGC(a|0,9104152,280)|0;g=c[2113054]|0;c[2113060]=g;c[2394]=-1;return}function e8U(){var a=0,b=0,d=0,e=0,f=0,g=0;fxU(0,425984);if((c[2394]|0)==0){a=c[2112932]|0}else{c[2394]=0;b=c[3532596]|0;c[2112932]=b;d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];a=b}b=c[3532204]|0;d=a|0;e=0;while(1){f=b+e|0;c[d>>2]=f;c[d+131072>>2]=f;f=e+1024|0;if(f>>>0>1048575){break}else{d=d+4|0;e=f}}e=c[3532266]|0;d=a+16384|0;b=4194304;while(1){f=e+(b-4194304)|0;c[d>>2]=f;c[d+65536>>2]=f;c[d+131072>>2]=f;f=b+1024|0;if(f>>>0>4259839){break}else{d=d+4|0;b=f}}b=c[3531970]|0;c[a+16640>>2]=b;c[a+82176>>2]=b;c[a+147712>>2]=b;d=b+1024|0;c[a+16644>>2]=d;c[a+82180>>2]=d;c[a+147716>>2]=d;d=b+2048|0;c[a+16648>>2]=d;c[a+82184>>2]=d;c[a+147720>>2]=d;d=b+3072|0;c[a+16652>>2]=d;c[a+82188>>2]=d;c[a+147724>>2]=d;d=b+4096|0;c[a+16656>>2]=d;c[a+82192>>2]=d;c[a+147728>>2]=d;d=b+5120|0;c[a+16660>>2]=d;c[a+82196>>2]=d;c[a+147732>>2]=d;d=b+6144|0;c[a+16664>>2]=d;c[a+82200>>2]=d;c[a+147736>>2]=d;d=b+7168|0;c[a+16668>>2]=d;c[a+82204>>2]=d;c[a+147740>>2]=d;d=b+8192|0;c[a+16672>>2]=d;c[a+82208>>2]=d;c[a+147744>>2]=d;d=b+9216|0;c[a+16676>>2]=d;c[a+82212>>2]=d;c[a+147748>>2]=d;d=b+10240|0;c[a+16680>>2]=d;c[a+82216>>2]=d;c[a+147752>>2]=d;d=b+11264|0;c[a+16684>>2]=d;c[a+82220>>2]=d;c[a+147756>>2]=d;d=b+12288|0;c[a+16688>>2]=d;c[a+82224>>2]=d;c[a+147760>>2]=d;d=b+13312|0;c[a+16692>>2]=d;c[a+82228>>2]=d;c[a+147764>>2]=d;d=c[3532264]|0;c[a+16696>>2]=d;c[a+82232>>2]=d;c[a+147768>>2]=d;b=d+1024|0;c[a+16700>>2]=b;c[a+82236>>2]=b;c[a+147772>>2]=b;b=c[3532026]|0;c[a+32768>>2]=b;c[a+98304>>2]=b;c[a+163840>>2]=b;d=b+1024|0;c[a+32772>>2]=d;c[a+98308>>2]=d;c[a+163844>>2]=d;d=b+2048|0;c[a+32776>>2]=d;c[a+98312>>2]=d;c[a+163848>>2]=d;d=b+3072|0;c[a+32780>>2]=d;c[a+98316>>2]=d;c[a+163852>>2]=d;d=b+4096|0;c[a+32784>>2]=d;c[a+98320>>2]=d;c[a+163856>>2]=d;d=b+5120|0;c[a+32788>>2]=d;c[a+98324>>2]=d;c[a+163860>>2]=d;d=b+6144|0;c[a+32792>>2]=d;c[a+98328>>2]=d;c[a+163864>>2]=d;d=b+7168|0;c[a+32796>>2]=d;c[a+98332>>2]=d;c[a+163868>>2]=d;d=c[3532208]|0;b=a+36864|0;e=9437184;while(1){f=d+(e-9437184)|0;c[b>>2]=f;c[b+65536>>2]=f;c[b+131072>>2]=f;f=e+1024|0;if(f>>>0>9502719){break}else{b=b+4|0;e=f}}c[a+196648>>2]=3338;c[a+196728>>2]=1448;c[a+196608>>2]=156;a=c[3532592]|0;if((a|0)==0){g=c[2113054]|0;c[2113060]=g;c[2394]=-1;return}gGC(a|0,9104152,280)|0;g=c[2113054]|0;c[2113060]=g;c[2394]=-1;return}function e8V(){var a=0,b=0,d=0,e=0,f=0,g=0;fxU(0,425984);if((c[2394]|0)==0){a=c[2112932]|0}else{c[2394]=0;b=c[3532596]|0;c[2112932]=b;d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];a=b}b=c[3532204]|0;d=a|0;e=0;while(1){f=b+e|0;c[d>>2]=f;c[d+131072>>2]=f;f=e+1024|0;if(f>>>0>524287){break}else{d=d+4|0;e=f}}e=c[3532208]|0;c[a+4096>>2]=e;c[a+69632>>2]=e;c[a+135168>>2]=e;d=e+1024|0;c[a+4100>>2]=d;c[a+69636>>2]=d;c[a+135172>>2]=d;d=e+2048|0;c[a+4104>>2]=d;c[a+69640>>2]=d;c[a+135176>>2]=d;d=e+3072|0;c[a+4108>>2]=d;c[a+69644>>2]=d;c[a+135180>>2]=d;d=e+4096|0;c[a+4112>>2]=d;c[a+69648>>2]=d;c[a+135184>>2]=d;d=e+5120|0;c[a+4116>>2]=d;c[a+69652>>2]=d;c[a+135188>>2]=d;d=e+6144|0;c[a+4120>>2]=d;c[a+69656>>2]=d;c[a+135192>>2]=d;d=e+7168|0;c[a+4124>>2]=d;c[a+69660>>2]=d;c[a+135196>>2]=d;d=e+8192|0;c[a+4128>>2]=d;c[a+69664>>2]=d;c[a+135200>>2]=d;d=e+9216|0;c[a+4132>>2]=d;c[a+69668>>2]=d;c[a+135204>>2]=d;d=e+10240|0;c[a+4136>>2]=d;c[a+69672>>2]=d;c[a+135208>>2]=d;d=e+11264|0;c[a+4140>>2]=d;c[a+69676>>2]=d;c[a+135212>>2]=d;d=e+12288|0;c[a+4144>>2]=d;c[a+69680>>2]=d;c[a+135216>>2]=d;d=e+13312|0;c[a+4148>>2]=d;c[a+69684>>2]=d;c[a+135220>>2]=d;d=e+14336|0;c[a+4152>>2]=d;c[a+69688>>2]=d;c[a+135224>>2]=d;d=e+15360|0;c[a+4156>>2]=d;c[a+69692>>2]=d;c[a+135228>>2]=d;d=c[3532266]|0;e=a+8192|0;b=2097152;while(1){f=d+(b-2097152)|0;c[e>>2]=f;c[e+65536>>2]=f;c[e+131072>>2]=f;f=b+1024|0;if(f>>>0>2162687){break}else{e=e+4|0;b=f}}b=c[3531970]|0;c[a+8448>>2]=b;c[a+73984>>2]=b;c[a+139520>>2]=b;e=b+1024|0;c[a+8452>>2]=e;c[a+73988>>2]=e;c[a+139524>>2]=e;e=b+2048|0;c[a+8456>>2]=e;c[a+73992>>2]=e;c[a+139528>>2]=e;e=b+3072|0;c[a+8460>>2]=e;c[a+73996>>2]=e;c[a+139532>>2]=e;e=b+4096|0;c[a+8464>>2]=e;c[a+74e3>>2]=e;c[a+139536>>2]=e;e=b+5120|0;c[a+8468>>2]=e;c[a+74004>>2]=e;c[a+139540>>2]=e;e=b+6144|0;c[a+8472>>2]=e;c[a+74008>>2]=e;c[a+139544>>2]=e;e=b+7168|0;c[a+8476>>2]=e;c[a+74012>>2]=e;c[a+139548>>2]=e;e=b+8192|0;c[a+8480>>2]=e;c[a+74016>>2]=e;c[a+139552>>2]=e;e=b+9216|0;c[a+8484>>2]=e;c[a+74020>>2]=e;c[a+139556>>2]=e;e=b+10240|0;c[a+8488>>2]=e;c[a+74024>>2]=e;c[a+139560>>2]=e;e=b+11264|0;c[a+8492>>2]=e;c[a+74028>>2]=e;c[a+139564>>2]=e;e=b+12288|0;c[a+8496>>2]=e;c[a+74032>>2]=e;c[a+139568>>2]=e;e=b+13312|0;c[a+8500>>2]=e;c[a+74036>>2]=e;c[a+139572>>2]=e;e=c[3532264]|0;c[a+8504>>2]=e;c[a+74040>>2]=e;c[a+139576>>2]=e;b=e+1024|0;c[a+8508>>2]=b;c[a+74044>>2]=b;c[a+139580>>2]=b;b=c[3532026]|0;c[a+12288>>2]=b;c[a+77824>>2]=b;c[a+143360>>2]=b;e=b+1024|0;c[a+12292>>2]=e;c[a+77828>>2]=e;c[a+143364>>2]=e;e=b+2048|0;c[a+12296>>2]=e;c[a+77832>>2]=e;c[a+143368>>2]=e;e=b+3072|0;c[a+12300>>2]=e;c[a+77836>>2]=e;c[a+143372>>2]=e;e=b+4096|0;c[a+12304>>2]=e;c[a+77840>>2]=e;c[a+143376>>2]=e;e=b+5120|0;c[a+12308>>2]=e;c[a+77844>>2]=e;c[a+143380>>2]=e;e=b+6144|0;c[a+12312>>2]=e;c[a+77848>>2]=e;c[a+143384>>2]=e;e=b+7168|0;c[a+12316>>2]=e;c[a+77852>>2]=e;c[a+143388>>2]=e;c[a+196648>>2]=2166;c[a+196728>>2]=3470;c[a+196608>>2]=3210;a=c[3532592]|0;if((a|0)==0){g=c[2113054]|0;c[2113060]=g;c[2394]=-1;return}gGC(a|0,9104152,280)|0;g=c[2113054]|0;c[2113060]=g;c[2394]=-1;return}function e8W(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0;fxU(0,425984);if((c[2394]|0)==0){a=c[2112932]|0}else{c[2394]=0;b=c[3532596]|0;c[2112932]=b;d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];a=b}b=c[3532204]|0;d=a|0;e=0;while(1){f=b+e|0;c[d>>2]=f;c[d+131072>>2]=f;f=e+1024|0;if(f>>>0>524287){break}else{d=d+4|0;e=f}}e=c[3532266]|0;d=a+16384|0;b=4194304;while(1){f=e+(b-4194304)|0;c[d>>2]=f;c[d+65536>>2]=f;c[d+131072>>2]=f;f=b+1024|0;if(f>>>0>4259839){break}else{d=d+4|0;b=f}}b=c[3531970]|0;c[a+16640>>2]=b;c[a+82176>>2]=b;c[a+147712>>2]=b;d=b+1024|0;c[a+16644>>2]=d;c[a+82180>>2]=d;c[a+147716>>2]=d;d=b+2048|0;c[a+16648>>2]=d;c[a+82184>>2]=d;c[a+147720>>2]=d;d=b+3072|0;c[a+16652>>2]=d;c[a+82188>>2]=d;c[a+147724>>2]=d;d=b+4096|0;c[a+16656>>2]=d;c[a+82192>>2]=d;c[a+147728>>2]=d;d=b+5120|0;c[a+16660>>2]=d;c[a+82196>>2]=d;c[a+147732>>2]=d;d=b+6144|0;c[a+16664>>2]=d;c[a+82200>>2]=d;c[a+147736>>2]=d;d=b+7168|0;c[a+16668>>2]=d;c[a+82204>>2]=d;c[a+147740>>2]=d;d=b+8192|0;c[a+16672>>2]=d;c[a+82208>>2]=d;c[a+147744>>2]=d;d=b+9216|0;c[a+16676>>2]=d;c[a+82212>>2]=d;c[a+147748>>2]=d;d=b+10240|0;c[a+16680>>2]=d;c[a+82216>>2]=d;c[a+147752>>2]=d;d=b+11264|0;c[a+16684>>2]=d;c[a+82220>>2]=d;c[a+147756>>2]=d;d=b+12288|0;c[a+16688>>2]=d;c[a+82224>>2]=d;c[a+147760>>2]=d;d=b+13312|0;c[a+16692>>2]=d;c[a+82228>>2]=d;c[a+147764>>2]=d;d=c[3532264]|0;c[a+16696>>2]=d;c[a+82232>>2]=d;c[a+147768>>2]=d;b=d+1024|0;c[a+16700>>2]=b;c[a+82236>>2]=b;c[a+147772>>2]=b;b=c[3532208]|0;c[a+32768>>2]=b;c[a+98304>>2]=b;c[a+163840>>2]=b;d=b+1024|0;c[a+32772>>2]=d;c[a+98308>>2]=d;c[a+163844>>2]=d;d=b+2048|0;c[a+32776>>2]=d;c[a+98312>>2]=d;c[a+163848>>2]=d;d=b+3072|0;c[a+32780>>2]=d;c[a+98316>>2]=d;c[a+163852>>2]=d;d=b+4096|0;c[a+32784>>2]=d;c[a+98320>>2]=d;c[a+163856>>2]=d;d=b+5120|0;c[a+32788>>2]=d;c[a+98324>>2]=d;c[a+163860>>2]=d;d=b+6144|0;c[a+32792>>2]=d;c[a+98328>>2]=d;c[a+163864>>2]=d;d=b+7168|0;c[a+32796>>2]=d;c[a+98332>>2]=d;c[a+163868>>2]=d;d=b+8192|0;c[a+32800>>2]=d;c[a+98336>>2]=d;c[a+163872>>2]=d;d=b+9216|0;c[a+32804>>2]=d;c[a+98340>>2]=d;c[a+163876>>2]=d;d=b+10240|0;c[a+32808>>2]=d;c[a+98344>>2]=d;c[a+163880>>2]=d;d=b+11264|0;c[a+32812>>2]=d;c[a+98348>>2]=d;c[a+163884>>2]=d;d=b+12288|0;c[a+32816>>2]=d;c[a+98352>>2]=d;c[a+163888>>2]=d;d=b+13312|0;c[a+32820>>2]=d;c[a+98356>>2]=d;c[a+163892>>2]=d;d=b+14336|0;c[a+32824>>2]=d;c[a+98360>>2]=d;c[a+163896>>2]=d;d=b+15360|0;c[a+32828>>2]=d;c[a+98364>>2]=d;c[a+163900>>2]=d;d=c[3532026]|0;c[a+40960>>2]=d;c[a+106496>>2]=d;c[a+172032>>2]=d;b=d+1024|0;c[a+40964>>2]=b;c[a+106500>>2]=b;c[a+172036>>2]=b;b=d+2048|0;c[a+40968>>2]=b;c[a+106504>>2]=b;c[a+172040>>2]=b;b=d+3072|0;c[a+40972>>2]=b;c[a+106508>>2]=b;c[a+172044>>2]=b;b=d+4096|0;c[a+40976>>2]=b;c[a+106512>>2]=b;c[a+172048>>2]=b;b=d+5120|0;c[a+40980>>2]=b;c[a+106516>>2]=b;c[a+172052>>2]=b;b=d+6144|0;c[a+40984>>2]=b;c[a+106520>>2]=b;c[a+172056>>2]=b;b=d+7168|0;c[a+40988>>2]=b;c[a+106524>>2]=b;c[a+172060>>2]=b;b=c[2387030]|0;d=a+45056|0;e=11534336;while(1){f=b+(e-11534336)|0;c[d>>2]=f;c[d+131072>>2]=f;f=e+1024|0;if(f>>>0>12058623){break}else{d=d+4|0;e=f}}c[a+196648>>2]=1008;c[a+196728>>2]=2552;c[a+196608>>2]=20;a=c[3532592]|0;if((a|0)!=0){gGC(a|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;a=0;while(1){if((a|0)>=1024){g=0;h=46829;break}i=9638528+(a<<2)|0;if((c[i>>2]|0)==0){break}else{a=a+1|0}}if((h|0)==46829){c[2438796]=g;return}h=gGq(524288)|0;c[i>>2]=h;if((h|0)==0){g=0;c[2438796]=g;return}gGz(h|0,0,524288);g=h;c[2438796]=g;return}function e8X(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;fxU(0,425984);if((c[2394]|0)==0){a=c[2112932]|0}else{c[2394]=0;b=c[3532596]|0;c[2112932]=b;d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];a=b}b=c[3532204]|0;d=a|0;e=0;while(1){f=b+e|0;c[d>>2]=f;c[d+131072>>2]=f;f=e+1024|0;if(f>>>0>524287){break}else{d=d+4|0;e=f}}e=c[3532266]|0;d=a+16384|0;f=4194304;while(1){g=e+(f-4194304)|0;c[d>>2]=g;c[d+65536>>2]=g;c[d+131072>>2]=g;g=f+1024|0;if(g>>>0>4259839){break}else{d=d+4|0;f=g}}f=c[3531970]|0;c[a+16640>>2]=f;c[a+82176>>2]=f;c[a+147712>>2]=f;d=f+1024|0;c[a+16644>>2]=d;c[a+82180>>2]=d;c[a+147716>>2]=d;d=f+2048|0;c[a+16648>>2]=d;c[a+82184>>2]=d;c[a+147720>>2]=d;d=f+3072|0;c[a+16652>>2]=d;c[a+82188>>2]=d;c[a+147724>>2]=d;d=f+4096|0;c[a+16656>>2]=d;c[a+82192>>2]=d;c[a+147728>>2]=d;d=f+5120|0;c[a+16660>>2]=d;c[a+82196>>2]=d;c[a+147732>>2]=d;d=f+6144|0;c[a+16664>>2]=d;c[a+82200>>2]=d;c[a+147736>>2]=d;d=f+7168|0;c[a+16668>>2]=d;c[a+82204>>2]=d;c[a+147740>>2]=d;d=f+8192|0;c[a+16672>>2]=d;c[a+82208>>2]=d;c[a+147744>>2]=d;d=f+9216|0;c[a+16676>>2]=d;c[a+82212>>2]=d;c[a+147748>>2]=d;d=f+10240|0;c[a+16680>>2]=d;c[a+82216>>2]=d;c[a+147752>>2]=d;d=f+11264|0;c[a+16684>>2]=d;c[a+82220>>2]=d;c[a+147756>>2]=d;d=f+12288|0;c[a+16688>>2]=d;c[a+82224>>2]=d;c[a+147760>>2]=d;d=f+13312|0;c[a+16692>>2]=d;c[a+82228>>2]=d;c[a+147764>>2]=d;d=c[3532264]|0;c[a+16696>>2]=d;c[a+82232>>2]=d;c[a+147768>>2]=d;f=d+1024|0;c[a+16700>>2]=f;c[a+82236>>2]=f;c[a+147772>>2]=f;f=c[3532026]|0;c[a+24576>>2]=f;c[a+90112>>2]=f;c[a+155648>>2]=f;d=f+1024|0;c[a+24580>>2]=d;c[a+90116>>2]=d;c[a+155652>>2]=d;d=f+2048|0;c[a+24584>>2]=d;c[a+90120>>2]=d;c[a+155656>>2]=d;d=f+3072|0;c[a+24588>>2]=d;c[a+90124>>2]=d;c[a+155660>>2]=d;d=f+4096|0;c[a+24592>>2]=d;c[a+90128>>2]=d;c[a+155664>>2]=d;d=f+5120|0;c[a+24596>>2]=d;c[a+90132>>2]=d;c[a+155668>>2]=d;d=f+6144|0;c[a+24600>>2]=d;c[a+90136>>2]=d;c[a+155672>>2]=d;d=f+7168|0;c[a+24604>>2]=d;c[a+90140>>2]=d;c[a+155676>>2]=d;d=c[3532208]|0;c[a+40960>>2]=d;c[a+106496>>2]=d;c[a+172032>>2]=d;f=d+1024|0;c[a+40964>>2]=f;c[a+106500>>2]=f;c[a+172036>>2]=f;f=d+2048|0;c[a+40968>>2]=f;c[a+106504>>2]=f;c[a+172040>>2]=f;f=d+3072|0;c[a+40972>>2]=f;c[a+106508>>2]=f;c[a+172044>>2]=f;f=d+4096|0;c[a+40976>>2]=f;c[a+106512>>2]=f;c[a+172048>>2]=f;f=d+5120|0;c[a+40980>>2]=f;c[a+106516>>2]=f;c[a+172052>>2]=f;f=d+6144|0;c[a+40984>>2]=f;c[a+106520>>2]=f;c[a+172056>>2]=f;f=d+7168|0;c[a+40988>>2]=f;c[a+106524>>2]=f;c[a+172060>>2]=f;f=d+8192|0;c[a+40992>>2]=f;c[a+106528>>2]=f;c[a+172064>>2]=f;f=d+9216|0;c[a+40996>>2]=f;c[a+106532>>2]=f;c[a+172068>>2]=f;f=d+10240|0;c[a+41e3>>2]=f;c[a+106536>>2]=f;c[a+172072>>2]=f;f=d+11264|0;c[a+41004>>2]=f;c[a+106540>>2]=f;c[a+172076>>2]=f;f=d+12288|0;c[a+41008>>2]=f;c[a+106544>>2]=f;c[a+172080>>2]=f;f=d+13312|0;c[a+41012>>2]=f;c[a+106548>>2]=f;c[a+172084>>2]=f;f=d+14336|0;c[a+41016>>2]=f;c[a+106552>>2]=f;c[a+172088>>2]=f;f=d+15360|0;c[a+41020>>2]=f;c[a+106556>>2]=f;c[a+172092>>2]=f;c[a+196648>>2]=1318;c[a+196728>>2]=2504;c[a+196608>>2]=1994;a=c[3532592]|0;if((a|0)==0){h=c[2113054]|0;c[2113060]=h;c[2394]=-1;i=b+262144|0;j=b+131072|0;gGC(i|0,j|0,262144)|0;c[2385702]=6e6;return}gGC(a|0,9104152,280)|0;h=c[2113054]|0;c[2113060]=h;c[2394]=-1;i=b+262144|0;j=b+131072|0;gGC(i|0,j|0,262144)|0;c[2385702]=6e6;return}function e8Y(){var a=0,b=0,d=0,e=0,f=0,g=0;fxU(0,425984);if((c[2394]|0)==0){a=c[2112932]|0}else{c[2394]=0;b=c[3532596]|0;c[2112932]=b;d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];a=b}b=c[3532204]|0;d=a|0;e=0;while(1){f=b+e|0;c[d>>2]=f;c[d+131072>>2]=f;f=e+1024|0;if(f>>>0>524287){break}else{d=d+4|0;e=f}}e=c[3532026]|0;c[a+8192>>2]=e;c[a+73728>>2]=e;c[a+139264>>2]=e;d=e+1024|0;c[a+8196>>2]=d;c[a+73732>>2]=d;c[a+139268>>2]=d;d=e+2048|0;c[a+8200>>2]=d;c[a+73736>>2]=d;c[a+139272>>2]=d;d=e+3072|0;c[a+8204>>2]=d;c[a+73740>>2]=d;c[a+139276>>2]=d;d=e+4096|0;c[a+8208>>2]=d;c[a+73744>>2]=d;c[a+139280>>2]=d;d=e+5120|0;c[a+8212>>2]=d;c[a+73748>>2]=d;c[a+139284>>2]=d;d=e+6144|0;c[a+8216>>2]=d;c[a+73752>>2]=d;c[a+139288>>2]=d;d=e+7168|0;c[a+8220>>2]=d;c[a+73756>>2]=d;c[a+139292>>2]=d;d=c[3532266]|0;e=a+16384|0;b=4194304;while(1){f=d+(b-4194304)|0;c[e>>2]=f;c[e+65536>>2]=f;c[e+131072>>2]=f;f=b+1024|0;if(f>>>0>4259839){break}else{e=e+4|0;b=f}}b=c[3531970]|0;c[a+16640>>2]=b;c[a+82176>>2]=b;c[a+147712>>2]=b;e=b+1024|0;c[a+16644>>2]=e;c[a+82180>>2]=e;c[a+147716>>2]=e;e=b+2048|0;c[a+16648>>2]=e;c[a+82184>>2]=e;c[a+147720>>2]=e;e=b+3072|0;c[a+16652>>2]=e;c[a+82188>>2]=e;c[a+147724>>2]=e;e=b+4096|0;c[a+16656>>2]=e;c[a+82192>>2]=e;c[a+147728>>2]=e;e=b+5120|0;c[a+16660>>2]=e;c[a+82196>>2]=e;c[a+147732>>2]=e;e=b+6144|0;c[a+16664>>2]=e;c[a+82200>>2]=e;c[a+147736>>2]=e;e=b+7168|0;c[a+16668>>2]=e;c[a+82204>>2]=e;c[a+147740>>2]=e;e=b+8192|0;c[a+16672>>2]=e;c[a+82208>>2]=e;c[a+147744>>2]=e;e=b+9216|0;c[a+16676>>2]=e;c[a+82212>>2]=e;c[a+147748>>2]=e;e=b+10240|0;c[a+16680>>2]=e;c[a+82216>>2]=e;c[a+147752>>2]=e;e=b+11264|0;c[a+16684>>2]=e;c[a+82220>>2]=e;c[a+147756>>2]=e;e=b+12288|0;c[a+16688>>2]=e;c[a+82224>>2]=e;c[a+147760>>2]=e;e=b+13312|0;c[a+16692>>2]=e;c[a+82228>>2]=e;c[a+147764>>2]=e;e=c[3532264]|0;c[a+16696>>2]=e;c[a+82232>>2]=e;c[a+147768>>2]=e;b=e+1024|0;c[a+16700>>2]=b;c[a+82236>>2]=b;c[a+147772>>2]=b;b=c[3532208]|0;c[a+32768>>2]=b;c[a+98304>>2]=b;c[a+163840>>2]=b;e=b+1024|0;c[a+32772>>2]=e;c[a+98308>>2]=e;c[a+163844>>2]=e;e=b+2048|0;c[a+32776>>2]=e;c[a+98312>>2]=e;c[a+163848>>2]=e;e=b+3072|0;c[a+32780>>2]=e;c[a+98316>>2]=e;c[a+163852>>2]=e;e=b+4096|0;c[a+32784>>2]=e;c[a+98320>>2]=e;c[a+163856>>2]=e;e=b+5120|0;c[a+32788>>2]=e;c[a+98324>>2]=e;c[a+163860>>2]=e;e=b+6144|0;c[a+32792>>2]=e;c[a+98328>>2]=e;c[a+163864>>2]=e;e=b+7168|0;c[a+32796>>2]=e;c[a+98332>>2]=e;c[a+163868>>2]=e;e=b+8192|0;c[a+32800>>2]=e;c[a+98336>>2]=e;c[a+163872>>2]=e;e=b+9216|0;c[a+32804>>2]=e;c[a+98340>>2]=e;c[a+163876>>2]=e;e=b+10240|0;c[a+32808>>2]=e;c[a+98344>>2]=e;c[a+163880>>2]=e;e=b+11264|0;c[a+32812>>2]=e;c[a+98348>>2]=e;c[a+163884>>2]=e;e=b+12288|0;c[a+32816>>2]=e;c[a+98352>>2]=e;c[a+163888>>2]=e;e=b+13312|0;c[a+32820>>2]=e;c[a+98356>>2]=e;c[a+163892>>2]=e;e=b+14336|0;c[a+32824>>2]=e;c[a+98360>>2]=e;c[a+163896>>2]=e;e=b+15360|0;c[a+32828>>2]=e;c[a+98364>>2]=e;c[a+163900>>2]=e;c[a+196648>>2]=2782;c[a+196728>>2]=3360;c[a+196608>>2]=2408;a=c[3532592]|0;if((a|0)==0){g=c[2113054]|0;c[2113060]=g;c[2394]=-1;return}gGC(a|0,9104152,280)|0;g=c[2113054]|0;c[2113060]=g;c[2394]=-1;return}function e8Z(){var a=0,b=0,d=0,e=0,f=0,g=0;fxU(0,425984);if((c[2394]|0)==0){a=c[2112932]|0}else{c[2394]=0;b=c[3532596]|0;c[2112932]=b;d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];a=b}b=c[3532204]|0;d=a|0;e=0;while(1){f=b+e|0;c[d>>2]=f;c[d+131072>>2]=f;f=e+1024|0;if(f>>>0>524287){break}else{d=d+4|0;e=f}}e=c[3532266]|0;d=a+16384|0;b=4194304;while(1){f=e+(b-4194304)|0;c[d>>2]=f;c[d+65536>>2]=f;c[d+131072>>2]=f;f=b+1024|0;if(f>>>0>4259839){break}else{d=d+4|0;b=f}}b=c[3531970]|0;c[a+16640>>2]=b;c[a+82176>>2]=b;c[a+147712>>2]=b;d=b+1024|0;c[a+16644>>2]=d;c[a+82180>>2]=d;c[a+147716>>2]=d;d=b+2048|0;c[a+16648>>2]=d;c[a+82184>>2]=d;c[a+147720>>2]=d;d=b+3072|0;c[a+16652>>2]=d;c[a+82188>>2]=d;c[a+147724>>2]=d;d=b+4096|0;c[a+16656>>2]=d;c[a+82192>>2]=d;c[a+147728>>2]=d;d=b+5120|0;c[a+16660>>2]=d;c[a+82196>>2]=d;c[a+147732>>2]=d;d=b+6144|0;c[a+16664>>2]=d;c[a+82200>>2]=d;c[a+147736>>2]=d;d=b+7168|0;c[a+16668>>2]=d;c[a+82204>>2]=d;c[a+147740>>2]=d;d=b+8192|0;c[a+16672>>2]=d;c[a+82208>>2]=d;c[a+147744>>2]=d;d=b+9216|0;c[a+16676>>2]=d;c[a+82212>>2]=d;c[a+147748>>2]=d;d=b+10240|0;c[a+16680>>2]=d;c[a+82216>>2]=d;c[a+147752>>2]=d;d=b+11264|0;c[a+16684>>2]=d;c[a+82220>>2]=d;c[a+147756>>2]=d;d=b+12288|0;c[a+16688>>2]=d;c[a+82224>>2]=d;c[a+147760>>2]=d;d=b+13312|0;c[a+16692>>2]=d;c[a+82228>>2]=d;c[a+147764>>2]=d;d=c[3532264]|0;c[a+16696>>2]=d;c[a+82232>>2]=d;c[a+147768>>2]=d;b=d+1024|0;c[a+16700>>2]=b;c[a+82236>>2]=b;c[a+147772>>2]=b;b=c[3532208]|0;d=a+32768|0;e=8388608;while(1){f=b+(e-8388608)|0;c[d>>2]=f;c[d+65536>>2]=f;c[d+131072>>2]=f;f=e+1024|0;if(f>>>0>8421375){break}else{d=d+4|0;e=f}}e=c[3532026]|0;c[a+40960>>2]=e;c[a+106496>>2]=e;c[a+172032>>2]=e;d=e+1024|0;c[a+40964>>2]=d;c[a+106500>>2]=d;c[a+172036>>2]=d;d=e+2048|0;c[a+40968>>2]=d;c[a+106504>>2]=d;c[a+172040>>2]=d;d=e+3072|0;c[a+40972>>2]=d;c[a+106508>>2]=d;c[a+172044>>2]=d;d=e+4096|0;c[a+40976>>2]=d;c[a+106512>>2]=d;c[a+172048>>2]=d;d=e+5120|0;c[a+40980>>2]=d;c[a+106516>>2]=d;c[a+172052>>2]=d;d=e+6144|0;c[a+40984>>2]=d;c[a+106520>>2]=d;c[a+172056>>2]=d;d=e+7168|0;c[a+40988>>2]=d;c[a+106524>>2]=d;c[a+172060>>2]=d;c[a+196648>>2]=130;c[a+196728>>2]=2220;c[a+196608>>2]=1048;c[a+196688>>2]=1054;a=c[3532592]|0;if((a|0)==0){g=c[2113054]|0;c[2113060]=g;c[2394]=-1;return}gGC(a|0,9104152,280)|0;g=c[2113054]|0;c[2113060]=g;c[2394]=-1;return}function e8_(){var a=0,b=0,d=0,e=0,f=0,g=0;fxU(0,425984);if((c[2394]|0)==0){a=c[2112932]|0}else{c[2394]=0;b=c[3532596]|0;c[2112932]=b;d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];a=b}b=c[3532204]|0;d=a|0;e=0;while(1){f=b+e|0;c[d>>2]=f;c[d+131072>>2]=f;f=e+1024|0;if(f>>>0>524287){break}else{d=d+4|0;e=f}}e=c[3532266]|0;d=a+16384|0;b=4194304;while(1){f=e+(b-4194304)|0;c[d>>2]=f;c[d+65536>>2]=f;c[d+131072>>2]=f;f=b+1024|0;if(f>>>0>4259839){break}else{d=d+4|0;b=f}}b=c[3531970]|0;c[a+16640>>2]=b;c[a+82176>>2]=b;c[a+147712>>2]=b;d=b+1024|0;c[a+16644>>2]=d;c[a+82180>>2]=d;c[a+147716>>2]=d;d=b+2048|0;c[a+16648>>2]=d;c[a+82184>>2]=d;c[a+147720>>2]=d;d=b+3072|0;c[a+16652>>2]=d;c[a+82188>>2]=d;c[a+147724>>2]=d;d=b+4096|0;c[a+16656>>2]=d;c[a+82192>>2]=d;c[a+147728>>2]=d;d=b+5120|0;c[a+16660>>2]=d;c[a+82196>>2]=d;c[a+147732>>2]=d;d=b+6144|0;c[a+16664>>2]=d;c[a+82200>>2]=d;c[a+147736>>2]=d;d=b+7168|0;c[a+16668>>2]=d;c[a+82204>>2]=d;c[a+147740>>2]=d;d=b+8192|0;c[a+16672>>2]=d;c[a+82208>>2]=d;c[a+147744>>2]=d;d=b+9216|0;c[a+16676>>2]=d;c[a+82212>>2]=d;c[a+147748>>2]=d;d=b+10240|0;c[a+16680>>2]=d;c[a+82216>>2]=d;c[a+147752>>2]=d;d=b+11264|0;c[a+16684>>2]=d;c[a+82220>>2]=d;c[a+147756>>2]=d;d=b+12288|0;c[a+16688>>2]=d;c[a+82224>>2]=d;c[a+147760>>2]=d;d=b+13312|0;c[a+16692>>2]=d;c[a+82228>>2]=d;c[a+147764>>2]=d;d=c[3532264]|0;c[a+16696>>2]=d;c[a+82232>>2]=d;c[a+147768>>2]=d;b=d+1024|0;c[a+16700>>2]=b;c[a+82236>>2]=b;c[a+147772>>2]=b;b=c[3532026]|0;c[a+32768>>2]=b;c[a+98304>>2]=b;c[a+163840>>2]=b;d=b+1024|0;c[a+32772>>2]=d;c[a+98308>>2]=d;c[a+163844>>2]=d;d=b+2048|0;c[a+32776>>2]=d;c[a+98312>>2]=d;c[a+163848>>2]=d;d=b+3072|0;c[a+32780>>2]=d;c[a+98316>>2]=d;c[a+163852>>2]=d;d=b+4096|0;c[a+32784>>2]=d;c[a+98320>>2]=d;c[a+163856>>2]=d;d=b+5120|0;c[a+32788>>2]=d;c[a+98324>>2]=d;c[a+163860>>2]=d;d=b+6144|0;c[a+32792>>2]=d;c[a+98328>>2]=d;c[a+163864>>2]=d;d=b+7168|0;c[a+32796>>2]=d;c[a+98332>>2]=d;c[a+163868>>2]=d;d=c[3532208]|0;b=a+40960|0;e=10485760;while(1){f=d+(e-10485760)|0;c[b>>2]=f;c[b+65536>>2]=f;c[b+131072>>2]=f;f=e+1024|0;if(f>>>0>10551295){break}else{b=b+4|0;e=f}}c[a+196648>>2]=466;c[a+196728>>2]=1730;c[a+196608>>2]=2592;a=c[3532592]|0;if((a|0)==0){g=c[2113054]|0;c[2113060]=g;c[2394]=-1;return}gGC(a|0,9104152,280)|0;g=c[2113054]|0;c[2113060]=g;c[2394]=-1;return}function e8$(){var a=0,b=0,d=0,e=0,f=0,g=0;fxU(0,425984);if((c[2394]|0)==0){a=c[2112932]|0}else{c[2394]=0;b=c[3532596]|0;c[2112932]=b;d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];a=b}b=c[3532204]|0;d=a|0;e=0;while(1){f=b+e|0;c[d>>2]=f;c[d+131072>>2]=f;f=e+1024|0;if(f>>>0>524287){break}else{d=d+4|0;e=f}}e=c[3532026]|0;c[a+8192>>2]=e;c[a+73728>>2]=e;c[a+139264>>2]=e;d=e+1024|0;c[a+8196>>2]=d;c[a+73732>>2]=d;c[a+139268>>2]=d;d=e+2048|0;c[a+8200>>2]=d;c[a+73736>>2]=d;c[a+139272>>2]=d;d=e+3072|0;c[a+8204>>2]=d;c[a+73740>>2]=d;c[a+139276>>2]=d;d=e+4096|0;c[a+8208>>2]=d;c[a+73744>>2]=d;c[a+139280>>2]=d;d=e+5120|0;c[a+8212>>2]=d;c[a+73748>>2]=d;c[a+139284>>2]=d;d=e+6144|0;c[a+8216>>2]=d;c[a+73752>>2]=d;c[a+139288>>2]=d;d=e+7168|0;c[a+8220>>2]=d;c[a+73756>>2]=d;c[a+139292>>2]=d;d=c[3532266]|0;e=a+16384|0;b=4194304;while(1){f=d+(b-4194304)|0;c[e>>2]=f;c[e+65536>>2]=f;c[e+131072>>2]=f;f=b+1024|0;if(f>>>0>4259839){break}else{e=e+4|0;b=f}}b=c[3531970]|0;c[a+16640>>2]=b;c[a+82176>>2]=b;c[a+147712>>2]=b;e=b+1024|0;c[a+16644>>2]=e;c[a+82180>>2]=e;c[a+147716>>2]=e;e=b+2048|0;c[a+16648>>2]=e;c[a+82184>>2]=e;c[a+147720>>2]=e;e=b+3072|0;c[a+16652>>2]=e;c[a+82188>>2]=e;c[a+147724>>2]=e;e=b+4096|0;c[a+16656>>2]=e;c[a+82192>>2]=e;c[a+147728>>2]=e;e=b+5120|0;c[a+16660>>2]=e;c[a+82196>>2]=e;c[a+147732>>2]=e;e=b+6144|0;c[a+16664>>2]=e;c[a+82200>>2]=e;c[a+147736>>2]=e;e=b+7168|0;c[a+16668>>2]=e;c[a+82204>>2]=e;c[a+147740>>2]=e;e=b+8192|0;c[a+16672>>2]=e;c[a+82208>>2]=e;c[a+147744>>2]=e;e=b+9216|0;c[a+16676>>2]=e;c[a+82212>>2]=e;c[a+147748>>2]=e;e=b+10240|0;c[a+16680>>2]=e;c[a+82216>>2]=e;c[a+147752>>2]=e;e=b+11264|0;c[a+16684>>2]=e;c[a+82220>>2]=e;c[a+147756>>2]=e;e=b+12288|0;c[a+16688>>2]=e;c[a+82224>>2]=e;c[a+147760>>2]=e;e=b+13312|0;c[a+16692>>2]=e;c[a+82228>>2]=e;c[a+147764>>2]=e;e=c[3532264]|0;c[a+16696>>2]=e;c[a+82232>>2]=e;c[a+147768>>2]=e;b=e+1024|0;c[a+16700>>2]=b;c[a+82236>>2]=b;c[a+147772>>2]=b;b=c[3532208]|0;e=a+24576|0;d=6291456;while(1){f=b+(d-6291456)|0;c[e>>2]=f;c[e+65536>>2]=f;c[e+131072>>2]=f;f=d+1024|0;if(f>>>0>6324223){break}else{e=e+4|0;d=f}}c[a+196648>>2]=38;c[a+196728>>2]=2524;c[a+196608>>2]=42;a=c[3532592]|0;if((a|0)==0){g=c[2113054]|0;c[2113060]=g;c[2394]=-1;return}gGC(a|0,9104152,280)|0;g=c[2113054]|0;c[2113060]=g;c[2394]=-1;return}function e80(){var a=0,b=0,d=0,e=0,f=0,g=0;fxU(0,425984);if((c[2394]|0)==0){a=c[2112932]|0}else{c[2394]=0;b=c[3532596]|0;c[2112932]=b;d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];a=b}b=c[3532204]|0;d=a|0;e=0;while(1){f=b+e|0;c[d>>2]=f;c[d+131072>>2]=f;f=e+1024|0;if(f>>>0>524287){break}else{d=d+4|0;e=f}}e=c[3532208]|0;c[a+8192>>2]=e;c[a+73728>>2]=e;c[a+139264>>2]=e;d=e+1024|0;c[a+8196>>2]=d;c[a+73732>>2]=d;c[a+139268>>2]=d;d=e+2048|0;c[a+8200>>2]=d;c[a+73736>>2]=d;c[a+139272>>2]=d;d=e+3072|0;c[a+8204>>2]=d;c[a+73740>>2]=d;c[a+139276>>2]=d;d=e+4096|0;c[a+8208>>2]=d;c[a+73744>>2]=d;c[a+139280>>2]=d;d=e+5120|0;c[a+8212>>2]=d;c[a+73748>>2]=d;c[a+139284>>2]=d;d=e+6144|0;c[a+8216>>2]=d;c[a+73752>>2]=d;c[a+139288>>2]=d;d=e+7168|0;c[a+8220>>2]=d;c[a+73756>>2]=d;c[a+139292>>2]=d;d=e+8192|0;c[a+8224>>2]=d;c[a+73760>>2]=d;c[a+139296>>2]=d;d=e+9216|0;c[a+8228>>2]=d;c[a+73764>>2]=d;c[a+139300>>2]=d;d=e+10240|0;c[a+8232>>2]=d;c[a+73768>>2]=d;c[a+139304>>2]=d;d=e+11264|0;c[a+8236>>2]=d;c[a+73772>>2]=d;c[a+139308>>2]=d;d=e+12288|0;c[a+8240>>2]=d;c[a+73776>>2]=d;c[a+139312>>2]=d;d=e+13312|0;c[a+8244>>2]=d;c[a+73780>>2]=d;c[a+139316>>2]=d;d=e+14336|0;c[a+8248>>2]=d;c[a+73784>>2]=d;c[a+139320>>2]=d;d=e+15360|0;c[a+8252>>2]=d;c[a+73788>>2]=d;c[a+139324>>2]=d;d=c[3532266]|0;e=a+16384|0;b=4194304;while(1){f=d+(b-4194304)|0;c[e>>2]=f;c[e+65536>>2]=f;c[e+131072>>2]=f;f=b+1024|0;if(f>>>0>4259839){break}else{e=e+4|0;b=f}}b=c[3531970]|0;c[a+16640>>2]=b;c[a+82176>>2]=b;c[a+147712>>2]=b;e=b+1024|0;c[a+16644>>2]=e;c[a+82180>>2]=e;c[a+147716>>2]=e;e=b+2048|0;c[a+16648>>2]=e;c[a+82184>>2]=e;c[a+147720>>2]=e;e=b+3072|0;c[a+16652>>2]=e;c[a+82188>>2]=e;c[a+147724>>2]=e;e=b+4096|0;c[a+16656>>2]=e;c[a+82192>>2]=e;c[a+147728>>2]=e;e=b+5120|0;c[a+16660>>2]=e;c[a+82196>>2]=e;c[a+147732>>2]=e;e=b+6144|0;c[a+16664>>2]=e;c[a+82200>>2]=e;c[a+147736>>2]=e;e=b+7168|0;c[a+16668>>2]=e;c[a+82204>>2]=e;c[a+147740>>2]=e;e=b+8192|0;c[a+16672>>2]=e;c[a+82208>>2]=e;c[a+147744>>2]=e;e=b+9216|0;c[a+16676>>2]=e;c[a+82212>>2]=e;c[a+147748>>2]=e;e=b+10240|0;c[a+16680>>2]=e;c[a+82216>>2]=e;c[a+147752>>2]=e;e=b+11264|0;c[a+16684>>2]=e;c[a+82220>>2]=e;c[a+147756>>2]=e;e=b+12288|0;c[a+16688>>2]=e;c[a+82224>>2]=e;c[a+147760>>2]=e;e=b+13312|0;c[a+16692>>2]=e;c[a+82228>>2]=e;c[a+147764>>2]=e;e=c[3532264]|0;c[a+16696>>2]=e;c[a+82232>>2]=e;c[a+147768>>2]=e;b=e+1024|0;c[a+16700>>2]=b;c[a+82236>>2]=b;c[a+147772>>2]=b;b=c[3532026]|0;c[a+24576>>2]=b;c[a+90112>>2]=b;c[a+155648>>2]=b;e=b+1024|0;c[a+24580>>2]=e;c[a+90116>>2]=e;c[a+155652>>2]=e;e=b+2048|0;c[a+24584>>2]=e;c[a+90120>>2]=e;c[a+155656>>2]=e;e=b+3072|0;c[a+24588>>2]=e;c[a+90124>>2]=e;c[a+155660>>2]=e;e=b+4096|0;c[a+24592>>2]=e;c[a+90128>>2]=e;c[a+155664>>2]=e;e=b+5120|0;c[a+24596>>2]=e;c[a+90132>>2]=e;c[a+155668>>2]=e;e=b+6144|0;c[a+24600>>2]=e;c[a+90136>>2]=e;c[a+155672>>2]=e;e=b+7168|0;c[a+24604>>2]=e;c[a+90140>>2]=e;c[a+155676>>2]=e;c[a+196648>>2]=2782;c[a+196728>>2]=3360;c[a+196608>>2]=2408;a=c[3532592]|0;if((a|0)==0){g=c[2113054]|0;c[2113060]=g;c[2394]=-1;return}gGC(a|0,9104152,280)|0;g=c[2113054]|0;c[2113060]=g;c[2394]=-1;return}function e81(b){b=b|0;var d=0,e=0,f=0,g=0;L61331:do{switch(b&65535|0){case 34824:{d=a[9634802]|0;break};case 34825:{d=a[9550257]|0;break};case 34826:{d=a[9550256]|0;break};case 34816:{d=a[14114240]|0;break};case 34817:case 34818:{d=-1;break};case 34822:case 34823:{e=c[3542291]|0;if((e|0)>15){d=0;break L61331}do{if((e|0)==14){f=c[3542287]|0;if((f|0)==0){break}a[14169182]=gj[f&4095](0)|0}else if((e|0)==15){f=c[3542288]|0;if((f|0)==0){break}a[14169183]=gj[f&4095](0)|0}}while(0);d=a[14169168+e|0]|0;break};case 34820:case 34821:{f=c[3542228]|0;if((f|0)>15){d=0;break L61331}do{if((f|0)==14){g=c[3542224]|0;if((g|0)==0){break}a[14168930]=gj[g&4095](0)|0}else if((f|0)==15){g=c[3542225]|0;if((g|0)==0){break}a[14168931]=gj[g&4095](0)|0}}while(0);d=a[14168916+f|0]|0;break};case 34827:{d=a[9550258]|0;break};case 34828:{d=a[c[2406746]|0]|0;break};default:{d=0}}}while(0);return d|0}function e82(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=b&65535;switch(f|0){case 34816:{b=a[9579160]|0;g=b+e&255;a[14114240]=0;h=g&255;if((g&255)<8){if(e<<24>>24<0){i=b}else{j=b-125&255;k=j&-128|(j&255)>>>1;a[9579160]=k;i=k}k=i+25&255;a[9579160]=k;j=(a[(c[2387332]|0)+((d[14114232]<<3)+h)|0]|0)-k&255;a[14114240]=j;if(j<<24>>24<0){l=k}else{k=i-100&255;i=k&-128|(k&255)>>>1;a[9579160]=i;l=i}a[9579160]=l+25&255;return}if((g-40&255)<3){if(e<<24>>24<0){m=b}else{l=b-125&255;i=l&-128|(l&255)>>>1;a[9579160]=i;m=i}i=m+25&255;a[9579160]=i;l=(a[(c[2387332]|0)+(h+896)|0]|0)-i&255;a[14114240]=l;if(l<<24>>24<0){n=i}else{i=m-100&255;m=i&-128|(i&255)>>>1;a[9579160]=m;n=m}a[9579160]=n+25&255;return}if(g<<24>>24>-1){if(e<<24>>24<0){o=b}else{n=b-125&255;m=n&-128|(n&255)>>>1;a[9579160]=m;o=m}a[9579160]=o+25&255;o=g-64&255;if((o&255)>=32){return}a[14114232]=o;return}else{if(!((g<<24>>24|0)==(-100|0)|(g<<24>>24|0)==(-34|0))){return}if(e<<24>>24<0){p=b}else{g=b-125&255;b=g&-128|(g&255)>>>1;a[9579160]=b;p=b}a[9579160]=p+25&255;return}break};case 34823:case 34822:{p=e&255;if((f&1|0)==0){c[3542291]=p&15;return}b=c[3542291]|0;if((b|0)>15){return}do{if((b|0)<14){if((b|0)!=13){if((a[14169168+b|0]|0)==e<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(1,b,p);return};case 34820:case 34821:{p=e&255;if((f&1|0)==0){c[3542228]=p&15;return}f=c[3542228]|0;if((f|0)>15){return}do{if((f|0)<14){if((f|0)!=13){if((a[14168916+f|0]|0)==e<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(0,f,p);return};case 34828:{p=c[2406748]|0;a[p]=e&1;a[p+1|0]=e&2;p=e&4;f=c[2406654]|0;if((d[f]|0)!=(p|0)){a[f]=p&255;f=c[2386032]|0;b=c[9757320+(c[1836236]<<2)>>2]|0;g=(p<<12)-49152|0;p=192;o=192;while(1){c[b+76+(o<<2)>>2]=f+(g+(o<<8));m=p+1&65535;if((m&65535)>255){q=192;r=192;break}else{p=m;o=m&65535}}while(1){c[b+76+(r+256<<2)>>2]=f+(g+(r<<8));o=q+1&65535;if((o&65535)>255){s=192;t=192;break}else{q=o;r=o&65535}}while(1){r=f+(g+(t<<8))|0;c[b+76+(t+512<<2)>>2]=r;c[b+76+(t+768<<2)>>2]=r;r=s+1&65535;if((r&65535)>255){break}else{s=r;t=r&65535}}}a[c[2406746]|0]=e;return};default:{return}}}function e83(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3021556+(b*112|0)>>2];c[a+104>>2]=c[3021560+(b*112|0)>>2];c[a+108>>2]=c[3021564+(b*112|0)>>2];d=0;return d|0}function e84(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=3021456+(b*112|0);e=0;return e|0}function e85(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1293640+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function e86(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>79){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4176304+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e87(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0.0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0;e=i;i=i+1320|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;B=e+1200|0;C=e+1312|0;c[2414890]=0;c[2385878]=0;c[3530774]=51200;c[3530538]=116736;c[3530996]=182272;c[3529922]=184320;c[2438988]=188416;D=a[9688]|0?1068:0;E=D|188416;c[2438989]=E;F=E+D|0;c[2438990]=F;E=F+D|0;c[2438991]=E;F=E+D|0;c[2438992]=F;E=F+D|0;c[2438993]=E;F=E+D|0;D=F|0;c[2414592]=D;c[2386032]=D;c[2386322]=F+32768;c[2386402]=F+33792;c[2387332]=F+34048;c[2406748]=F+36096;c[2406746]=F+36098;c[2406654]=F+36099;D=F+36100|0;c[2411536]=D;c[2414076]=D;F=D;D=0;while(1){if((D|0)>=1024){break}G=9638528+(D<<2)|0;if((c[G>>2]|0)==0){H=47033;break}else{D=D+1|0}}do{if((H|0)==47033){D=gGq(F)|0;c[G>>2]=D;if((D|0)==0){break}gGz(D|0,0,F|0);c[2414890]=D;gGz(D|0,0,F|0);c[2385878]=D;c[2387320]=D+49152;c[3530774]=D+51200;c[3530538]=D+116736;c[3530996]=D+182272;c[3529922]=D+184320;c[2438988]=D+188416;E=a[9688]|0?1068:0;I=E|188416;c[2438989]=D+I;J=I+E|0;c[2438990]=D+J;I=J+E|0;c[2438991]=D+I;J=I+E|0;c[2438992]=D+J;I=J+E|0;c[2438993]=D+I;J=I+E|0;E=D+J|0;c[2414592]=E;c[2386032]=E;c[2386322]=D+(J+32768);c[2386402]=D+(J+33792);c[2387332]=D+(J+34048);c[2406748]=D+(J+36096);c[2406746]=D+(J+36098);c[2406654]=D+(J+36099);E=D+(J+36100)|0;c[2411536]=E;c[2414076]=E;if((c[3542200]|0)==0){K=1;i=e;return K|0}E=B+108|0;c[E>>2]=0;J=B+100|0;c[J>>2]=0;I=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[I&16383](B,0)|0;do{if((c[E>>2]|0)!=0){I=c[J>>2]|0;c[C>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](C,0,0)|0;if((I|0)<1){K=1;i=e;return K|0}if((gzL(D,0,0)|0)==0){break}else{K=1}i=e;return K|0}}while(0);D=(c[2385878]|0)+8192|0;if((c[3542200]|0)==0){K=1;i=e;return K|0}J=z+108|0;c[J>>2]=0;E=z+100|0;c[E>>2]=0;I=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[I&16383](z,1)|0;do{if((c[J>>2]|0)!=0){I=c[E>>2]|0;c[A>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](A,1,0)|0;if((I|0)<1){K=1;i=e;return K|0}if((gzL(D,0,1)|0)==0){break}else{K=1}i=e;return K|0}}while(0);D=(c[2385878]|0)+16384|0;if((c[3542200]|0)==0){K=1;i=e;return K|0}E=x+108|0;c[E>>2]=0;J=x+100|0;c[J>>2]=0;I=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[I&16383](x,2)|0;do{if((c[E>>2]|0)!=0){I=c[J>>2]|0;c[y>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](y,2,0)|0;if((I|0)<1){K=1;i=e;return K|0}if((gzL(D,0,2)|0)==0){break}else{K=1}i=e;return K|0}}while(0);D=(c[2385878]|0)+24576|0;if((c[3542200]|0)==0){K=1;i=e;return K|0}J=v+108|0;c[J>>2]=0;E=v+100|0;c[E>>2]=0;I=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[I&16383](v,3)|0;do{if((c[J>>2]|0)!=0){I=c[E>>2]|0;c[w>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](w,3,0)|0;if((I|0)<1){K=1;i=e;return K|0}if((gzL(D,0,3)|0)==0){break}else{K=1}i=e;return K|0}}while(0);D=(c[2385878]|0)+40960|0;if((c[3542200]|0)==0){K=1;i=e;return K|0}E=t+108|0;c[E>>2]=0;J=t+100|0;c[J>>2]=0;I=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[I&16383](t,4)|0;do{if((c[E>>2]|0)!=0){I=c[J>>2]|0;c[u>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](u,4,0)|0;if((I|0)<1){K=1;i=e;return K|0}if((gzL(D,0,4)|0)==0){break}else{K=1}i=e;return K|0}}while(0);D=c[3530774]|0;if((c[3542200]|0)==0){K=1;i=e;return K|0}J=r+108|0;c[J>>2]=0;E=r+100|0;c[E>>2]=0;I=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[I&16383](r,6)|0;do{if((c[J>>2]|0)!=0){I=c[E>>2]|0;c[s>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](s,6,0)|0;if((I|0)<1){K=1;i=e;return K|0}if((gzL(D,0,6)|0)==0){break}else{K=1}i=e;return K|0}}while(0);D=(c[3530774]|0)+8192|0;if((c[3542200]|0)==0){K=1;i=e;return K|0}E=p+108|0;c[E>>2]=0;J=p+100|0;c[J>>2]=0;I=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[I&16383](p,7)|0;do{if((c[E>>2]|0)!=0){I=c[J>>2]|0;c[q>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](q,7,0)|0;if((I|0)<1){K=1;i=e;return K|0}if((gzL(D,0,7)|0)==0){break}else{K=1}i=e;return K|0}}while(0);D=c[3530538]|0;if((c[3542200]|0)==0){K=1;i=e;return K|0}J=n+108|0;c[J>>2]=0;E=n+100|0;c[E>>2]=0;I=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[I&16383](n,8)|0;do{if((c[J>>2]|0)!=0){I=c[E>>2]|0;c[o>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](o,8,0)|0;if((I|0)<1){K=1;i=e;return K|0}if((gzL(D,0,8)|0)==0){break}else{K=1}i=e;return K|0}}while(0);D=(c[3530538]|0)+8192|0;if((c[3542200]|0)==0){K=1;i=e;return K|0}E=l+108|0;c[E>>2]=0;J=l+100|0;c[J>>2]=0;I=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[I&16383](l,9)|0;do{if((c[E>>2]|0)!=0){I=c[J>>2]|0;c[m>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](m,9,0)|0;if((I|0)<1){K=1;i=e;return K|0}if((gzL(D,0,9)|0)==0){break}else{K=1}i=e;return K|0}}while(0);D=c[3530996]|0;if((c[3542200]|0)==0){K=1;i=e;return K|0}J=j+108|0;c[J>>2]=0;E=j+100|0;c[E>>2]=0;I=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[I&16383](j,10)|0;do{if((c[J>>2]|0)!=0){I=c[E>>2]|0;c[k>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](k,10,0)|0;if((I|0)<1){K=1;i=e;return K|0}if((gzL(D,0,10)|0)==0){break}else{K=1}i=e;return K|0}}while(0);D=(c[3530996]|0)+1024|0;if((c[3542200]|0)==0){K=1;i=e;return K|0}E=f+108|0;c[E>>2]=0;J=f+100|0;c[J>>2]=0;I=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[I&16383](f,11)|0;do{if((c[E>>2]|0)==0){M=0}else{I=c[J>>2]|0;c[g>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](g,11,0)|0;if((I|0)<1){K=1;i=e;return K|0}if((gzL(D,0,11)|0)==0){M=0;break}else{K=1}i=e;return K|0}}while(0);while(1){if((M|0)>=1024){break}N=9638528+(M<<2)|0;if((c[N>>2]|0)==0){H=47081;break}else{M=M+1|0}}L61586:do{if((H|0)==47081){D=gGq(16384)|0;c[N>>2]=D;if((D|0)==0){break}gGz(D|0,0,16384);J=c[3530774]|0;gGC(D|0,J|0,16384)|0;E=0;do{I=E<<8;gGz(J+I|0,0,256);L=0;do{O=I+(c[611776+(L<<2)>>2]|0)|0;P=(L<<4)+I|0;Q=0;do{R=O+(c[601400+(Q<<2)>>2]|0)|0;if((d[D+((R|0)/8|0)|0]&128>>>((R&7)>>>0)|0)!=0){R=J+(P+Q)|0;a[R]=a[R]|2}Q=Q+1|0;}while((Q|0)<16);L=L+1|0;}while((L|0)<16);L=I+65536|0;Q=0;do{P=L+(c[611776+(Q<<2)>>2]|0)|0;O=(Q<<4)+I|0;R=0;do{S=P+(c[601400+(R<<2)>>2]|0)|0;if((d[D+((S|0)/8|0)|0]&128>>>((S&7)>>>0)|0)!=0){S=J+(O+R)|0;a[S]=a[S]|1}R=R+1|0;}while((R|0)<16);Q=Q+1|0;}while((Q|0)<16);E=E+1|0;}while((E|0)<256);E=c[3530538]|0;gGC(D|0,E|0,16384)|0;J=0;while(1){Q=J<<6;gGz(E+Q|0,0,64);I=0;do{L=Q+(c[611776+(I<<2)>>2]|0)|0;R=(I<<3)+Q|0;O=0;do{P=L+(c[601400+(O<<2)>>2]|0)|0;if((d[D+((P|0)/8|0)|0]&128>>>((P&7)>>>0)|0)!=0){P=E+(R+O)|0;a[P]=a[P]|2}O=O+1|0;}while((O|0)<8);I=I+1|0;}while((I|0)<8);I=Q+65536|0;O=0;do{R=I+(c[611776+(O<<2)>>2]|0)|0;L=(O<<3)+Q|0;P=0;do{S=R+(c[601400+(P<<2)>>2]|0)|0;if((d[D+((S|0)/8|0)|0]&128>>>((S&7)>>>0)|0)!=0){S=E+(L+P)|0;a[S]=a[S]|1}P=P+1|0;}while((P|0)<8);O=O+1|0;}while((O|0)<8);O=J+1|0;if((O|0)<1024){J=O}else{T=0;break}}while(1){if((T|0)>=1024){break L61586}U=9638528+(T<<2)|0;if((c[U>>2]|0)==(D|0)){break}else{T=T+1|0}}gGr(D);c[U>>2]=0}}while(0);e9c();fwR(0);J=c[2439330]|0;E=(J|0)==0;if(!E){O=J;gGC(9706056,O|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];O=c[3528484]|0;c[2076596]=O;Q=c[2417276]|0;c[3541536]=Q;c[1836236]=0;I=c[2385878]|0;P=0;L=0;while(1){c[J+76+(L<<2)>>2]=I+(L<<8);R=P+1&65535;if((R&65535)>127){V=0;W=0;break}else{P=R;L=R&65535}}while(1){L=I+(W<<8)|0;c[J+76+(W+512<<2)>>2]=L;c[J+76+(W+768<<2)>>2]=L;L=V+1&65535;if((L&65535)>127){break}else{V=L;W=L&65535}}L=c[2387332]|0;c[J+588>>2]=L;P=L+256|0;c[J+592>>2]=P;R=L+512|0;c[J+596>>2]=R;S=L+768|0;c[J+600>>2]=S;X=L+1024|0;c[J+604>>2]=X;Y=L+1280|0;c[J+608>>2]=Y;Z=L+1536|0;c[J+612>>2]=Z;_=L+1792|0;c[J+616>>2]=_;c[J+1612>>2]=L;c[J+1616>>2]=P;c[J+1620>>2]=R;c[J+1624>>2]=S;c[J+1628>>2]=X;c[J+1632>>2]=Y;c[J+1636>>2]=Z;c[J+1640>>2]=_;c[J+2636>>2]=L;c[J+3660>>2]=L;c[J+2640>>2]=P;c[J+3664>>2]=P;c[J+2644>>2]=R;c[J+3668>>2]=R;c[J+2648>>2]=S;c[J+3672>>2]=S;c[J+2652>>2]=X;c[J+3676>>2]=X;c[J+2656>>2]=Y;c[J+3680>>2]=Y;c[J+2660>>2]=Z;c[J+3684>>2]=Z;c[J+2664>>2]=_;c[J+3688>>2]=_;_=c[2386322]|0;c[J+652>>2]=_;Z=_+256|0;c[J+656>>2]=Z;Y=_+512|0;c[J+660>>2]=Y;X=_+768|0;c[J+664>>2]=X;c[J+1676>>2]=_;c[J+1680>>2]=Z;c[J+1684>>2]=Y;c[J+1688>>2]=X;c[J+2700>>2]=_;c[J+3724>>2]=_;c[J+2704>>2]=Z;c[J+3728>>2]=Z;c[J+2708>>2]=Y;c[J+3732>>2]=Y;c[J+2712>>2]=X;c[J+3736>>2]=X;X=c[2386402]|0;c[J+684>>2]=X;c[J+1708>>2]=X;c[J+2732>>2]=X;c[J+3756>>2]=X;X=160;Y=160;while(1){c[J+76+(Y<<2)>>2]=I+(Y<<8);Z=X+1&65535;if((Z&65535)>191){$=160;aa=160;break}else{X=Z;Y=Z&65535}}while(1){Y=I+(aa<<8)|0;c[J+76+(aa+512<<2)>>2]=Y;c[J+76+(aa+768<<2)>>2]=Y;Y=$+1&65535;if((Y&65535)>191){break}else{$=Y;aa=Y&65535}}I=c[2406654]|0;if((a[I]|0)!=0){a[I]=0;I=c[2386032]|0;Y=192;X=192;while(1){c[J+76+(X<<2)>>2]=I+((X<<8)-49152);Z=Y+1&65535;if((Z&65535)>255){ab=192;ac=192;break}else{Y=Z;X=Z&65535}}while(1){c[J+76+(ac+256<<2)>>2]=I+((ac<<8)-49152);X=ab+1&65535;if((X&65535)>255){ad=192;ae=192;break}else{ab=X;ac=X&65535}}while(1){X=I+((ae<<8)-49152)|0;c[J+76+(ae+512<<2)>>2]=X;c[J+76+(ae+768<<2)>>2]=X;X=ad+1&65535;if((X&65535)>255){break}else{ad=X;ae=X&65535}}}c[J+4184>>2]=2182;c[J+4180>>2]=3598;if(!E){I=J;gGC(I|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=O;c[2417276]=Q;c[1836236]=-1;I=a[9680]|0?32e3:0;c[3542220]=11200;X=c[2113008]|0;if((X|0)==0){gGz(14168888,0,252);c[3542223]=I;c[3542224]=2518;c[3542225]=744;c[3542226]=0;c[3542227]=0;c[3542234]=~~((+(I|0)*32768.0*8.0+768.0e3)/1536.0e3);Y=31;af=32767.0;while(1){c[14169012+(Y<<2)>>2]=~~(af+.5);Z=Y-1|0;if((Z|0)>0){Y=Z;af=af/1.188502227}else{break}}c[3542253]=0;h[1771269]=1.0;h[1771270]=1.0;h[1771271]=1.0;c[3542574]=3;c[3542575]=3;c[3542576]=3;mB(0);Y=(c[2113008]|0)+1|0;c[2113008]=Y;ah=Y;ai=a[9680]|0?32e3:0}else{ah=X;ai=I}c[3542220]=11200;if((ah|0)==1){gGz(14169140,0,252);c[3542286]=ai;gGz(14169148,0,16);c[3542297]=~~((+(ai|0)*32768.0*8.0+768.0e3)/1536.0e3);Y=31;af=32767.0;while(1){c[14169264+(Y<<2)>>2]=~~(af+.5);Q=Y-1|0;if((Q|0)>0){Y=Q;af=af/1.188502227}else{break}}c[3542316]=0;h[1771272]=1.0;h[1771273]=1.0;h[1771274]=1.0;c[3542577]=3;c[3542578]=3;c[3542579]=3;mB(1);c[2113008]=(c[2113008]|0)+1}h[1771269]=.1;c[3542574]=3;h[1771270]=.1;c[3542575]=3;h[1771271]=.1;c[3542576]=3;Y=c[642608+(c[2436]<<2)>>2]|0;I=c[Y+128>>2]|0;if((c[Y+52>>2]&4|0)==0){c[2113068]=I;X=c[Y+132>>2]|0;c[2113070]=X;c[2443814]=I;c[2440436]=X;aj=I;ak=X}else{c[2113070]=I;X=c[Y+132>>2]|0;c[2113068]=X;c[2440436]=I;c[2443814]=X;aj=X;ak=I}I=ag(aj<<1,ak)|0;X=gGq(I)|0;c[2112926]=X;if((X|0)!=0){gGz(X|0,0,I|0)}I=c[2414592]|0;gGz(I|0,0,(c[2411536]|0)-I|0);I=c[2439330]|0;X=(I|0)==0;if(!X){Y=I;gGC(9706056,Y|0,76)|0}Y=c[2438118]|0;c[2433530]=Y;Q=c[3528484]|0;c[2076596]=Q;O=c[2417276]|0;c[3541536]=O;c[1836236]=0;gGz(9706056,0,76);if(!X){X=I;gGC(X|0,9706056,76)|0}c[2438118]=Y;c[3528484]=Q;c[2417276]=O;c[1836236]=-1;mB(0);mB(1);a[9579160]=-127;a[14114240]=0;a[14114232]=0;O=c[2406654]|0;a[O]=-1;Q=c[2439330]|0;Y=(Q|0)==0;if(!Y){X=Q;gGC(9706056,X|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];X=c[3528484]|0;c[2076596]=X;I=c[2417276]|0;c[3541536]=I;c[1836236]=0;if((a[O]|0)!=0){a[O]=0;O=c[2386032]|0;J=192;E=192;while(1){c[Q+76+(E<<2)>>2]=O+((E<<8)-49152);Z=J+1&65535;if((Z&65535)>255){al=192;am=192;break}else{J=Z;E=Z&65535}}while(1){c[Q+76+(am+256<<2)>>2]=O+((am<<8)-49152);E=al+1&65535;if((E&65535)>255){an=192;ao=192;break}else{al=E;am=E&65535}}while(1){E=O+((ao<<8)-49152)|0;c[Q+76+(ao+512<<2)>>2]=E;c[Q+76+(ao+768<<2)>>2]=E;E=an+1&65535;if((E&65535)>255){break}else{an=E;ao=E&65535}}}if(!Y){O=Q;gGC(O|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=X;c[2417276]=I;c[1836236]=-1;K=0;i=e;return K|0}}while(0);c[2414890]=0;K=1;i=e;return K|0}function e88(){var a=0,b=0,d=0,e=0;c[2113070]=0;c[2113068]=0;a=c[2112926]|0;if((a|0)!=0){gGr(a);c[2112926]=0}fwZ();c[2113008]=0;c[2076598]=0;c[2383582]=0;a=c[2414890]|0;b=0;while(1){if((b|0)>=1024){d=47198;break}e=9638528+(b<<2)|0;if((c[e>>2]|0)==(a|0)){break}else{b=b+1|0}}if((d|0)==47198){c[2414890]=0;return 0}gGr(a);c[e>>2]=0;c[2414890]=0;return 0}function e89(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;if((a[9623704]|0)!=0){d=c[2414592]|0;gGz(d|0,0,(c[2411536]|0)-d|0);d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;h=c[2417276]|0;c[3541536]=h;c[1836236]=0;gGz(9706056,0,76);if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=h;c[1836236]=-1;mB(0);mB(1);a[9579160]=-127;a[14114240]=0;a[14114232]=0;h=c[2406654]|0;a[h]=-1;g=c[2439330]|0;f=(g|0)==0;if(!f){e=g;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];e=c[3528484]|0;c[2076596]=e;d=c[2417276]|0;c[3541536]=d;c[1836236]=0;if((a[h]|0)!=0){a[h]=0;h=c[2386032]|0;i=192;j=192;while(1){c[g+76+(j<<2)>>2]=h+((j<<8)-49152);k=i+1&65535;if((k&65535)>255){l=192;m=192;break}else{i=k;j=k&65535}}while(1){c[g+76+(m+256<<2)>>2]=h+((m<<8)-49152);j=l+1&65535;if((j&65535)>255){n=192;o=192;break}else{l=j;m=j&65535}}while(1){m=h+((o<<8)-49152)|0;c[g+76+(o+512<<2)>>2]=m;c[g+76+(o+768<<2)>>2]=m;m=n+1&65535;if((m&65535)>255){break}else{n=m;o=m&65535}}}if(!f){f=g;gGC(f|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=e;c[2417276]=d;c[1836236]=-1}gGz(9550256,-1|0,3);d=0;e=-1;f=-1;do{e=((a[9632752+d|0]&1)<<d^e&255)&255;f=((a[9630648+d|0]&1)<<d^f&255)&255;d=d+1|0;}while((d|0)<8);a[9550256]=e;a[9550257]=f;f=c[2439330]|0;if((f|0)!=0){e=f;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;e=c[2438118]|0;c[2433530]=e;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;if((a[f+4188|0]|0)==0){f=gfc(39166)|0;p=(c[2433530]|0)+f|0}else{p=e+39166|0}c[2433530]=p;a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0;p=c[1836236]|0;e=c[9757320+(p<<2)>>2]|0;if((e|0)!=0){f=e;gGC(f|0,9706056,76)|0}c[9752472+(p<<2)>>2]=c[2433530];c[14113936+(p<<2)>>2]=c[2076596];c[9669104+(p<<2)>>2]=c[3541536];c[1836236]=-1;p=c[2112964]|0;if((p|0)!=0){mF(9755952,p,a[9688]|0?534:0,0)}if((c[2112968]|0)==0){return 0}e9a()|0;return 0}function e9a(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;if((a[9547176]|0)!=0){e9c();a[9547176]=0}f=c[2386322]|0;g=c[2386402]|0;h=g+11|0;i=g+1|0;j=c[2406746]|0;k=c[2406748]|0;l=k+1|0;m=c[2112926]|0;n=c[3530538]|0;o=64;do{p=o<<3&248;q=o>>5<<3;r=a[f+o|0]|0;s=r&255;t=a[j]|0;u=((t&32)!=0&(r&255)>191?s+192|0:s)|(t&255)<<2&512;t=(a[l]|0)==0;s=(t?q:q^255)-16|0;q=a[k]|0;v=q<<24>>24==0?p:p^255;p=q<<24>>24!=0;q=(d[r<<24>>24==116?h:i]|0)+8|0;do{if(t){if(p){Sl(m,u,v,s,q,2,0,n);break}else{Sj(m,u,v,s,q,2,0,n);break}}else{if(p){Sp(m,u,v,s,q,2,0,n);break}else{Sn(m,u,v,s,q,2,0,n);break}}}while(0);o=o+1|0;}while((o|0)<960);o=c[3530774]|0;n=0;do{i=241-(d[g+(n+64)|0]|0)|0;h=d[g+(n+65)|0]|0;j=d[g+(n+66)|0]|0;f=j&7;q=d[g+(n+67)|0]|0;s=h&64;v=j<<3&448|h&63;if((a[k]|0)==0){w=s;x=q}else{w=s>>>6^1;x=240-q|0}if((a[l]|0)==0){y=h&128;z=i}else{y=h>>>7^1;z=242-i|0}i=(w|0)!=0;h=z-16|0;do{if((y|0)==0){if(i){SJ(m,v,x,h,f,2,0,0,o);break}else{SH(m,v,x,h,f,2,0,0,o);break}}else{if(i){SN(m,v,x,h,f,2,0,0,o);break}else{SL(m,v,x,h,f,2,0,0,o);break}}}while(0);n=n+4|0;}while((n|0)<192);n=(a[k]|0)!=0?-1:1;o=c[2113070]|0;x=c[2113068]|0;y=c[2386032]|0;z=512;do{w=z<<3&248;g=z>>5;f=(a[l]|0)==0?271-g|0:g-16|0;L61797:do{if((f|0)>-1&(f|0)<(o|0)){g=(a[k]|0)==0?w^248:w|7;h=y+z|0;v=y+(z+16384)|0;i=y+(z+8192)|0;q=y+(z+24576)|0;s=ag(x,f)|0;j=g;g=128;while(1){do{if(!((j|0)>=(x|0)|(j|0)<0)){u=(d[h]&g|0)==0?0:512;p=(d[v]&g|0)==0?u:u|256;u=(d[i]&g|0)==0?p:p|128;p=(d[q]&g|0)==0?u:u|64;if((p|0)==0){break}u=m+(s+j<<1)|0;b[u>>1]=(e[u>>1]|p)&65535}}while(0);p=g>>1;if((p|0)<=0){break L61797}j=j+n|0;g=p}}}while(0);z=z+1|0;}while((z|0)<7680);R8(c[3529922]|0);return 0}function e9b(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=i;i=i+96|0;g=f|0;h=f+32|0;j=f+48|0;k=f+64|0;l=f+80|0;m=(e|0)==0;if(!m){c[e>>2]=169730}if((d&96|0)!=0){gGz(l|0,0,12);n=c[2414592]|0;c[l>>2]=n;c[l+4>>2]=(c[2411536]|0)-n;c[l+12>>2]=162152;n=c[2076592]|0;gj[n&4095](l)|0;fw$(d);l=f+16|0;do{if((d&64|0)!=0){do{if(!m){if((c[e>>2]|0)>=169110){break}c[e>>2]=169110}}while(0);if((c[2113008]|0)<=0){break}n=g|0;o=g+4|0;p=g+8|0;q=g+12|0;r=0;do{cC(l|0,531144,(s=i,i=i+8|0,c[s>>2]=r,s)|0)|0;i=s;c[n>>2]=14168888+(r*252|0);c[o>>2]=252;c[p>>2]=0;c[q>>2]=l;gj[c[2076592]&4095](g)|0;r=r+1|0;}while((r|0)<(c[2113008]|0))}}while(0);gGz(k|0,0,12);c[k>>2]=9579160;c[k+4>>2]=1;c[k+12>>2]=146464;g=c[2076592]|0;gj[g&4095](k)|0;gGz(j|0,0,12);c[j>>2]=14114240;c[j+4>>2]=1;c[j+12>>2]=117208;k=c[2076592]|0;gj[k&4095](j)|0;gGz(h|0,0,12);c[h>>2]=14114232;c[h+4>>2]=1;c[h+12>>2]=92056;j=c[2076592]|0;gj[j&4095](h)|0}if((d&2|0)==0){i=f;return 0}d=c[2406654]|0;h=a[d]|0;a[d]=-1;j=c[2439330]|0;k=(j|0)==0;if(!k){g=j;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];g=c[3528484]|0;c[2076596]=g;l=c[2417276]|0;c[3541536]=l;c[1836236]=0;if((a[d]|0)!=h<<24>>24){a[d]=h;d=c[2386032]|0;e=h<<24>>24!=0?-32768:-49152;h=192;m=192;while(1){c[j+76+(m<<2)>>2]=d+(e+(m<<8));r=h+1&65535;if((r&65535)>255){t=192;u=192;break}else{h=r;m=r&65535}}while(1){c[j+76+(u+256<<2)>>2]=d+(e+(u<<8));m=t+1&65535;if((m&65535)>255){v=192;w=192;break}else{t=m;u=m&65535}}while(1){u=d+(e+(w<<8))|0;c[j+76+(w+512<<2)>>2]=u;c[j+76+(w+768<<2)>>2]=u;u=v+1&65535;if((u&65535)>255){break}else{v=u;w=u&65535}}}if(!k){k=j;gGC(k|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=g;c[2417276]=l;c[1836236]=-1;i=f;return 0}function e9c(){var a=0,b=0,e=0,f=0,g=0;a=c[3530996]|0;b=c[3529922]|0;e=0;do{f=d[a+e|0]|0;g=d[a+(e+1024)|0]|0;c[b+(e<<2)>>2]=(-(f>>>1&1)&71)+(-(f&1)&33)+(-(f>>>2&1)&151)<<8&63488|(-(f>>>3&1)&33)+(-(g&1)&71)+(-(g>>>1&1)&151)<<3&2016|((-(g>>>2&1)&71)+(-(g>>>3&1)&151)|0)>>>3&31;e=e+1|0;}while((e|0)<1024);return}function e9d(b){b=b|0;return a[9634800]|0}function e9e(b){b=b|0;return a[9634801]|0}function e9f(a,b){a=a|0;b=b|0;return}function e9g(d,e){d=d|0;e=e|0;switch(d|0){case 303112:{a[c[3528220]|0]=e&255;a[c[2443710]|0]=1;return};case 303136:case 303138:case 303140:case 303142:case 303144:{b[(c[2406634]|0)+((d>>>1&7)<<1)>>1]=e;return};case 303120:case 303122:case 303124:case 303126:case 303128:{b[(c[2406644]|0)+((d>>>1&7)<<1)>>1]=e;return};case 303110:{a[c[2443686]|0]=e&255;return};default:{return}}}function e9h(a){a=a|0;return 0}function e9i(a){a=a|0;var c=0;if((a|0)==303108){c=(d[9634793]|0)<<8|(d[9634792]|0)}else if((a|0)==303104){c=b[4775124]|0}else if((a|0)==303106){c=b[4775125]|0}else{c=0}return c|0}function e9j(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=b&255;if((e|0)==2){a[14115664]=d;return}else if((e|0)==1){lS(0,1,d);return}else if((e|0)==0){e=c[3541518]|0;b=e+256|0;a[e+304|0]=d;f=d&255;if((d&255)<16){c[14168912+((c[2383582]|0)*252|0)>>2]=f&15}if((d-45&255)>=3){return}if((f|0)==45){d=e+312|0;g=a[d]|2;a[d]=g;h=g}else if((f|0)==46){g=e+312|0;d=a[g]|1;a[g]=d;h=d}else if((f|0)==0){a[e+312|0]=2;h=2}else if((f|0)==47){a[e+312|0]=0;h=0}else{h=a[e+312|0]|0}e=h&3;h=c[7461744+(e<<2)>>2]|0;lI(b,h,h,c[7461728+(e<<2)>>2]|0);return}else{return}}function e9k(b){b=b|0;var e=0,f=0,g=0,i=0,j=0.0,k=0.0;e=b&255;if((e|0)==4){a[c[2443710]|0]=0;f=a[c[3528220]|0]|0;return f|0}else if((e|0)==6){f=a[c[2443710]|0]|0;return f|0}else if((e|0)==1){if((d[(c[3541518]|0)+304|0]|0)>=16){f=0;return f|0}b=c[2383582]|0;g=c[14168912+(b*252|0)>>2]|0;if((g|0)>15){f=0;return f|0}do{if((g|0)==15){i=c[14168900+(b*252|0)>>2]|0;if((i|0)==0){break}a[14168931+(b*252|0)|0]=gj[i&4095](0)|0}else if((g|0)==14){i=c[14168896+(b*252|0)>>2]|0;if((i|0)==0){break}a[14168930+(b*252|0)|0]=gj[i&4095](0)|0}}while(0);f=a[14168916+(b*252|0)+g|0]|0;return f|0}else if((e|0)==0){e=c[3541518]|0;g=e+296|0;j=+h[g>>3];do{if(j!=0.0){k=+h[6675];if(j-(k+ +gC[c[2429842]&255]())<=0.0){h[g>>3]=0.0;break}f=a[e+307|0]|-128;return f|0}}while(0);f=a[e+307|0]|0;return f|0}else{f=0;return f|0}return 0}function e9l(a,b){a=a|0;b=b|0;c[2415126]=9662152;c[2415540]=b&1^1;return}function e9m(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;a=c[3527212]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=(b<<15&491520)-32768|0;b=128;f=128;while(1){c[d+76+(f<<2)>>2]=a+(e+(f<<8));g=b+1&65535;if((g&65535)>255){h=128;i=128;break}else{b=g;f=g&65535}}while(1){f=a+(e+(i<<8))|0;c[d+76+(i+512<<2)>>2]=f;c[d+76+(i+768<<2)>>2]=f;f=h+1&65535;if((f&65535)>255){break}else{h=f;i=f&65535}}return}function e9n(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2327308+(b*112|0)>>2];c[a+104>>2]=c[2327312+(b*112|0)>>2];c[a+108>>2]=c[2327316+(b*112|0)>>2];d=0;return d|0}function e9o(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=2327208+(b*112|0);e=0;return e|0}function e9p(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1314608+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function e9q(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>26){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4265808+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e9r(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0;e=i;i=i+2040|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;B=e+1200|0;C=e+1312|0;D=e+1320|0;E=e+1432|0;F=e+1440|0;G=e+1552|0;H=e+1560|0;I=e+1672|0;J=e+1680|0;K=e+1792|0;L=e+1800|0;M=e+1912|0;N=e+1920|0;O=e+2032|0;c[2414888]=0;c[2388096]=0;c[2385876]=1048576;c[3527212]=1114112;c[3530772]=1638400;c[3530536]=1900544;c[3530402]=2162688;c[3530316]=2424832;c[3530290]=4521984;c[3529920]=10813440;c[2414590]=10821632;c[2406286]=10821632;c[2388226]=10858496;c[2387128]=10874880;c[2386030]=10878976;c[3528220]=10887168;c[2443710]=10887169;c[2443686]=10887170;c[2406644]=10887171;c[2406634]=10887187;c[2411534]=10887203;P=0;while(1){if((P|0)>=1024){break}Q=9638528+(P<<2)|0;if((c[Q>>2]|0)==0){R=47391;break}else{P=P+1|0}}do{if((R|0)==47391){P=gGq(10887203)|0;c[Q>>2]=P;if((P|0)==0){break}c[2414888]=P;gGz(P|0,0,10887203);c[2388096]=P;c[2385876]=P+1048576;c[3527212]=P+1114112;c[3530772]=P+1638400;c[3530536]=P+1900544;c[3530402]=P+2162688;c[3530316]=P+2424832;c[3530290]=P+4521984;c[3529920]=P+10813440;S=P+10821632|0;c[2414590]=S;c[2406286]=S;c[2388226]=P+10858496;c[2387128]=P+10874880;c[2386030]=P+10878976;c[3528220]=P+10887168;c[2443710]=P+10887169;c[2443686]=P+10887170;c[2406644]=P+10887171;c[2406634]=P+10887187;S=P+10887203|0;c[2411534]=S;c[2414074]=S;if((R6(P+1|0,0,2)|0)!=0){T=1;i=e;return T|0}if((R6(c[2388096]|0,1,2)|0)!=0){T=1;i=e;return T|0}P=(c[2388096]|0)+524288|0;if((c[3542200]|0)==0){T=1;i=e;return T|0}S=N+108|0;c[S>>2]=0;U=N+100|0;c[U>>2]=0;V=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[V&16383](N,2)|0;do{if((c[S>>2]|0)!=0){V=c[U>>2]|0;c[O>>2]=9534384;W=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[W&16383](O,2,0)|0;if((V|0)<1){T=1;i=e;return T|0}if((gzL(P,0,2)|0)==0){break}else{T=1}i=e;return T|0}}while(0);P=c[2385876]|0;if((c[3542200]|0)==0){T=1;i=e;return T|0}U=L+108|0;c[U>>2]=0;S=L+100|0;c[S>>2]=0;V=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[V&16383](L,3)|0;do{if((c[U>>2]|0)!=0){V=c[S>>2]|0;c[M>>2]=9534384;W=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[W&16383](M,3,0)|0;if((V|0)<1){T=1;i=e;return T|0}if((gzL(P,0,3)|0)==0){break}else{T=1}i=e;return T|0}}while(0);P=c[3530772]|0;if((c[3542200]|0)==0){T=1;i=e;return T|0}S=J+108|0;c[S>>2]=0;U=J+100|0;c[U>>2]=0;V=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[V&16383](J,4)|0;do{if((c[S>>2]|0)!=0){V=c[U>>2]|0;c[K>>2]=9534384;W=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[W&16383](K,4,0)|0;if((V|0)<1){T=1;i=e;return T|0}if((gzL(P,0,4)|0)==0){break}else{T=1}i=e;return T|0}}while(0);P=(c[3530772]|0)+65536|0;if((c[3542200]|0)==0){T=1;i=e;return T|0}U=H+108|0;c[U>>2]=0;S=H+100|0;c[S>>2]=0;V=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[V&16383](H,5)|0;do{if((c[U>>2]|0)!=0){V=c[S>>2]|0;c[I>>2]=9534384;W=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[W&16383](I,5,0)|0;if((V|0)<1){T=1;i=e;return T|0}if((gzL(P,0,5)|0)==0){break}else{T=1}i=e;return T|0}}while(0);P=c[3530536]|0;if((c[3542200]|0)==0){T=1;i=e;return T|0}S=F+108|0;c[S>>2]=0;U=F+100|0;c[U>>2]=0;V=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[V&16383](F,6)|0;do{if((c[S>>2]|0)!=0){V=c[U>>2]|0;c[G>>2]=9534384;W=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[W&16383](G,6,0)|0;if((V|0)<1){T=1;i=e;return T|0}if((gzL(P,0,6)|0)==0){break}else{T=1}i=e;return T|0}}while(0);P=(c[3530536]|0)+65536|0;if((c[3542200]|0)==0){T=1;i=e;return T|0}U=D+108|0;c[U>>2]=0;S=D+100|0;c[S>>2]=0;V=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[V&16383](D,7)|0;do{if((c[U>>2]|0)!=0){V=c[S>>2]|0;c[E>>2]=9534384;W=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[W&16383](E,7,0)|0;if((V|0)<1){T=1;i=e;return T|0}if((gzL(P,0,7)|0)==0){break}else{T=1}i=e;return T|0}}while(0);P=c[3530402]|0;if((c[3542200]|0)==0){T=1;i=e;return T|0}S=B+108|0;c[S>>2]=0;U=B+100|0;c[U>>2]=0;V=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[V&16383](B,8)|0;do{if((c[S>>2]|0)!=0){V=c[U>>2]|0;c[C>>2]=9534384;W=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[W&16383](C,8,0)|0;if((V|0)<1){T=1;i=e;return T|0}if((gzL(P,0,8)|0)==0){break}else{T=1}i=e;return T|0}}while(0);P=(c[3530402]|0)+65536|0;if((c[3542200]|0)==0){T=1;i=e;return T|0}U=z+108|0;c[U>>2]=0;S=z+100|0;c[S>>2]=0;V=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[V&16383](z,9)|0;do{if((c[U>>2]|0)!=0){V=c[S>>2]|0;c[A>>2]=9534384;W=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[W&16383](A,9,0)|0;if((V|0)<1){T=1;i=e;return T|0}if((gzL(P,0,9)|0)==0){break}else{T=1}i=e;return T|0}}while(0);P=c[3530316]|0;if((c[3542200]|0)==0){T=1;i=e;return T|0}S=x+108|0;c[S>>2]=0;U=x+100|0;c[U>>2]=0;V=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[V&16383](x,10)|0;do{if((c[S>>2]|0)!=0){V=c[U>>2]|0;c[y>>2]=9534384;W=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[W&16383](y,10,0)|0;if((V|0)<1){T=1;i=e;return T|0}if((gzL(P,0,10)|0)==0){break}else{T=1}i=e;return T|0}}while(0);P=(c[3530316]|0)+524288|0;if((c[3542200]|0)==0){T=1;i=e;return T|0}U=v+108|0;c[U>>2]=0;S=v+100|0;c[S>>2]=0;V=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[V&16383](v,11)|0;do{if((c[U>>2]|0)!=0){V=c[S>>2]|0;c[w>>2]=9534384;W=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[W&16383](w,11,0)|0;if((V|0)<1){T=1;i=e;return T|0}if((gzL(P,0,11)|0)==0){break}else{T=1}i=e;return T|0}}while(0);P=c[3530290]|0;if((c[3542200]|0)==0){T=1;i=e;return T|0}S=t+108|0;c[S>>2]=0;U=t+100|0;c[U>>2]=0;V=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[V&16383](t,12)|0;do{if((c[S>>2]|0)!=0){V=c[U>>2]|0;c[u>>2]=9534384;W=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[W&16383](u,12,0)|0;if((V|0)<1){T=1;i=e;return T|0}if((gzL(P,0,12)|0)==0){break}else{T=1}i=e;return T|0}}while(0);P=(c[3530290]|0)+524288|0;if((c[3542200]|0)==0){T=1;i=e;return T|0}U=r+108|0;c[U>>2]=0;S=r+100|0;c[S>>2]=0;V=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[V&16383](r,13)|0;do{if((c[U>>2]|0)!=0){V=c[S>>2]|0;c[s>>2]=9534384;W=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[W&16383](s,13,0)|0;if((V|0)<1){T=1;i=e;return T|0}if((gzL(P,0,13)|0)==0){break}else{T=1}i=e;return T|0}}while(0);P=(c[3530290]|0)+1048576|0;if((c[3542200]|0)==0){T=1;i=e;return T|0}S=p+108|0;c[S>>2]=0;U=p+100|0;c[U>>2]=0;V=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[V&16383](p,14)|0;do{if((c[S>>2]|0)!=0){V=c[U>>2]|0;c[q>>2]=9534384;W=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[W&16383](q,14,0)|0;if((V|0)<1){T=1;i=e;return T|0}if((gzL(P,0,14)|0)==0){break}else{T=1}i=e;return T|0}}while(0);P=(c[3530290]|0)+1572864|0;if((c[3542200]|0)==0){T=1;i=e;return T|0}U=n+108|0;c[U>>2]=0;S=n+100|0;c[S>>2]=0;V=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[V&16383](n,15)|0;do{if((c[U>>2]|0)!=0){V=c[S>>2]|0;c[o>>2]=9534384;W=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[W&16383](o,15,0)|0;if((V|0)<1){T=1;i=e;return T|0}if((gzL(P,0,15)|0)==0){break}else{T=1}i=e;return T|0}}while(0);P=(c[3530290]|0)+2097152|0;if((c[3542200]|0)==0){T=1;i=e;return T|0}S=l+108|0;c[S>>2]=0;U=l+100|0;c[U>>2]=0;V=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[V&16383](l,16)|0;do{if((c[S>>2]|0)!=0){V=c[U>>2]|0;c[m>>2]=9534384;W=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[W&16383](m,16,0)|0;if((V|0)<1){T=1;i=e;return T|0}if((gzL(P,0,16)|0)==0){break}else{T=1}i=e;return T|0}}while(0);P=(c[3530290]|0)+2621440|0;if((c[3542200]|0)==0){T=1;i=e;return T|0}U=j+108|0;c[U>>2]=0;S=j+100|0;c[S>>2]=0;V=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[V&16383](j,17)|0;do{if((c[U>>2]|0)!=0){V=c[S>>2]|0;c[k>>2]=9534384;W=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[W&16383](k,17,0)|0;if((V|0)<1){T=1;i=e;return T|0}if((gzL(P,0,17)|0)==0){break}else{T=1}i=e;return T|0}}while(0);P=c[3527212]|0;if((c[3542200]|0)==0){T=1;i=e;return T|0}S=f+108|0;c[S>>2]=0;U=f+100|0;c[U>>2]=0;V=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[V&16383](f,18)|0;do{if((c[S>>2]|0)!=0){V=c[U>>2]|0;c[g>>2]=9534384;W=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[W&16383](g,18,0)|0;if((V|0)<1){T=1;i=e;return T|0}if((gzL(P,0,18)|0)==0){break}else{T=1}i=e;return T|0}}while(0);P=c[3530772]|0;U=131072;do{U=U-1|0;S=P+U|0;V=U<<1;a[P+(V|1)|0]=a[S]&15;a[P+V|0]=(d[S]|0)>>>4;}while((U|0)>0);U=c[3530536]|0;P=131072;do{P=P-1|0;S=U+P|0;V=P<<1;a[U+(V|1)|0]=a[S]&15;a[U+V|0]=(d[S]|0)>>>4;}while((P|0)>0);P=c[3530402]|0;U=131072;do{U=U-1|0;S=P+U|0;V=U<<1;a[P+(V|1)|0]=a[S]&15;a[P+V|0]=(d[S]|0)>>>4;}while((U|0)>0);U=c[3530316]|0;P=0;S=U;while(1){V=a[S]|0;W=S+1|0;a[S]=a[W]|0;a[W]=V;V=P+1|0;if((V|0)<524288){P=V;S=S+2|0}else{X=1048576;break}}do{X=X-1|0;S=U+X|0;P=X<<1;a[U+(P|1)|0]=a[S]&15;a[U+P|0]=(d[S]|0)>>>4;}while((X|0)>0);U=c[3530290]|0;S=0;P=U;while(1){V=a[P]|0;W=P+1|0;a[P]=a[W]|0;a[W]=V;V=S+1|0;if((V|0)<1572864){S=V;P=P+2|0}else{Y=3145728;break}}do{Y=Y-1|0;P=U+Y|0;S=Y<<1;a[U+(S|1)|0]=a[P]&15;a[U+S|0]=(d[P]|0)>>>4;}while((Y|0)>0);fxU(0,425984);if((c[2394]|0)==0){Z=c[2112932]|0}else{c[2394]=0;U=c[3532596]|0;c[2112932]=U;P=c[3532592]|0;if((P|0)!=0){gGC(9104152,P|0,280)|0}c[2113054]=c[2113060];Z=U}U=c[2388096]|0;P=Z|0;S=0;while(1){V=U+S|0;c[P>>2]=V;c[P+131072>>2]=V;V=S+1024|0;if(V>>>0>262143){break}else{P=P+4|0;S=V}}S=c[2406286]|0;P=Z+1024|0;V=262144;while(1){W=S+(V-262144)|0;c[P>>2]=W;c[P+65536>>2]=W;c[P+131072>>2]=W;W=V+1024|0;if(W>>>0>299007){break}else{P=P+4|0;V=W}}V=c[2387128]|0;c[Z+1168>>2]=V;c[Z+66704>>2]=V;c[Z+132240>>2]=V;P=V+1024|0;c[Z+1172>>2]=P;c[Z+66708>>2]=P;c[Z+132244>>2]=P;P=V+2048|0;c[Z+1176>>2]=P;c[Z+66712>>2]=P;c[Z+132248>>2]=P;P=V+3072|0;c[Z+1180>>2]=P;c[Z+66716>>2]=P;c[Z+132252>>2]=P;P=c[2388226]|0;c[Z+1216>>2]=P;c[Z+66752>>2]=P;c[Z+132288>>2]=P;V=P+1024|0;c[Z+1220>>2]=V;c[Z+66756>>2]=V;c[Z+132292>>2]=V;V=P+2048|0;c[Z+1224>>2]=V;c[Z+66760>>2]=V;c[Z+132296>>2]=V;V=P+3072|0;c[Z+1228>>2]=V;c[Z+66764>>2]=V;c[Z+132300>>2]=V;V=P+4096|0;c[Z+1232>>2]=V;c[Z+66768>>2]=V;c[Z+132304>>2]=V;V=P+5120|0;c[Z+1236>>2]=V;c[Z+66772>>2]=V;c[Z+132308>>2]=V;V=P+6144|0;c[Z+1240>>2]=V;c[Z+66776>>2]=V;c[Z+132312>>2]=V;V=P+7168|0;c[Z+1244>>2]=V;c[Z+66780>>2]=V;c[Z+132316>>2]=V;V=P+8192|0;c[Z+1248>>2]=V;c[Z+66784>>2]=V;c[Z+132320>>2]=V;V=P+9216|0;c[Z+1252>>2]=V;c[Z+66788>>2]=V;c[Z+132324>>2]=V;V=P+10240|0;c[Z+1256>>2]=V;c[Z+66792>>2]=V;c[Z+132328>>2]=V;V=P+11264|0;c[Z+1260>>2]=V;c[Z+66796>>2]=V;c[Z+132332>>2]=V;V=P+12288|0;c[Z+1264>>2]=V;c[Z+66800>>2]=V;c[Z+132336>>2]=V;V=P+13312|0;c[Z+1268>>2]=V;c[Z+66804>>2]=V;c[Z+132340>>2]=V;V=P+14336|0;c[Z+1272>>2]=V;c[Z+66808>>2]=V;c[Z+132344>>2]=V;V=P+15360|0;c[Z+1276>>2]=V;c[Z+66812>>2]=V;c[Z+132348>>2]=V;V=Z+2048|0;P=524288;while(1){S=U+P|0;c[V>>2]=S;c[V+131072>>2]=S;S=P+1024|0;if(S>>>0>786431){break}else{V=V+4|0;P=S}}c[Z+196728>>2]=620;c[Z+196648>>2]=1758;c[Z+196688>>2]=2258;c[Z+196608>>2]=1666;P=c[3532592]|0;if((P|0)!=0){gGC(P|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);P=c[2439330]|0;if((P|0)!=0){V=P;gGC(9706056,V|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;V=c[2385876]|0;U=0;S=0;while(1){c[P+76+(S<<2)>>2]=V+(S<<8);W=U+1&65535;if((W&65535)>95){_=0;$=0;break}else{U=W;S=W&65535}}while(1){S=V+($<<8)|0;c[P+76+($+512<<2)>>2]=S;c[P+76+($+768<<2)>>2]=S;S=_+1&65535;if((S&65535)>95){break}else{_=S;$=S&65535}}V=c[2386030]|0;S=96;U=96;while(1){c[P+76+(U<<2)>>2]=V+((U<<8)-24576);W=S+1&65535;if((W&65535)>127){aa=96;ab=96;break}else{S=W;U=W&65535}}while(1){c[P+76+(ab+256<<2)>>2]=V+((ab<<8)-24576);U=aa+1&65535;if((U&65535)>127){ac=96;ad=96;break}else{aa=U;ab=U&65535}}while(1){U=V+((ad<<8)-24576)|0;c[P+76+(ad+512<<2)>>2]=U;c[P+76+(ad+768<<2)>>2]=U;U=ac+1&65535;if((U&65535)>127){break}else{ac=U;ad=U&65535}}c[P+4176>>2]=1536;c[P+4172>>2]=2974;UB(0,1724,384e3,2464,5);c[2415126]=9662152;h[1207773]=1.0;c[2415548]=3;Vr(1,4e6,968,1724,60,0);c[3542224]=0;c[3542225]=0;c[3542226]=1466;c[3542227]=3086;c[2438228]=4e6;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=511;h[745419]=.1;a[3203368]=1;h[745418]=.1;a[3203360]=1;h[745417]=.1;a[3203352]=1;h[745416]=.1;a[3203344]=1;V=c[1836236]|0;U=c[9757320+(V<<2)>>2]|0;if((U|0)!=0){S=U;gGC(S|0,9706056,76)|0}c[9752472+(V<<2)>>2]=c[2433530];c[14113936+(V<<2)>>2]=c[2076596];c[9669104+(V<<2)>>2]=c[3541536];c[1836236]=-1;V=c[642608+(c[2436]<<2)>>2]|0;S=c[V+128>>2]|0;if((c[V+52>>2]&4|0)==0){c[2113068]=S;U=c[V+132>>2]|0;c[2113070]=U;c[2443814]=S;c[2440436]=U;ae=S;af=U}else{c[2113070]=S;U=c[V+132>>2]|0;c[2113068]=U;c[2440436]=S;c[2443814]=U;ae=U;af=S}S=ag(ae<<1,af)|0;U=gGq(S)|0;c[2112926]=U;if((U|0)!=0){gGz(U|0,0,S|0)}S=c[2414590]|0;gGz(S|0,0,(c[2411534]|0)-S|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];S=c[3532592]|0;if((S|0)!=0){gGC(9104152,S|0,280)|0}c[2113054]=c[2113060]}RI();S=c[2394]|0;U=c[14130368+(S<<2)>>2]|0;if((U|0)!=0){gGC(U|0,9104152,280)|0}c[8452240+(S<<2)>>2]=c[2113054];c[2394]=-1;S=c[2439330]|0;if((S|0)!=0){U=S;gGC(9706056,U|0,76)|0}c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;gGz(9706056,0,76);c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){U=0;do{lN(U);mB(U);U=U+1|0;}while((U|0)<(c[2385508]|0));U=c[1836236]|0;ah=U;ai=c[9757320+(U<<2)>>2]|0}else{ah=0;ai=S}UA();if((ai|0)!=0){U=ai;gGC(U|0,9706056,76)|0}c[9752472+(ah<<2)>>2]=c[2433530];c[14113936+(ah<<2)>>2]=c[2076596];c[9669104+(ah<<2)>>2]=c[3541536];c[1836236]=-1;a[14115664]=0;a[9718888]=0;T=0;i=e;return T|0}}while(0);c[2414888]=0;T=1;i=e;return T|0}function e9s(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}if((c[2392]|0)>=0){b=0;do{d=14130368+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}d=14130384+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}b=b+1|0;}while((b|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;fwZ();b=c[3541518]|0;if((b|0)!=0){gGr(b|0);c[3541518]=0}if((c[2385508]|0)>0){c[2113008]=0;c[2076598]=0;c[2383582]=0}c[2438228]=0;c[2433526]=0;c[2406676]=0;c[3528472]=0;b=c[2406680]|0;if((b|0)!=0){gGr(b);c[2406680]=0}c[2385508]=0;c[2432978]=0;a[64240]=0;c[2415126]=9662152;b=c[2408988]|0;if((b|0)!=0){gGz(9662152,0,3224);d=b;b=0;while(1){if((b|0)>=1024){break}f=9638528+(b<<2)|0;if((c[f>>2]|0)==(d|0)){g=47592;break}else{b=b+1|0}}if((g|0)==47592){gGr(d);c[f>>2]=0}c[2408988]=0}c[2415126]=9665376;f=c[2408989]|0;if((f|0)!=0){gGz(9665376,0,3224);d=f;f=0;while(1){if((f|0)>=1024){break}h=9638528+(f<<2)|0;if((c[h>>2]|0)==(d|0)){g=47598;break}else{f=f+1|0}}if((g|0)==47598){gGr(d);c[h>>2]=0}c[2408989]=0}h=c[2414888]|0;d=0;while(1){if((d|0)>=1024){g=47606;break}i=9638528+(d<<2)|0;if((c[i>>2]|0)==(h|0)){break}else{d=d+1|0}}if((g|0)==47606){c[2414888]=0;return 0}gGr(h);c[i>>2]=0;c[2414888]=0;return 0}function e9t(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0;if((a[9623696]|0)!=0){d=c[2414590]|0;gGz(d|0,0,(c[2411534]|0)-d|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;d=c[2439330]|0;if((d|0)!=0){e=d;gGC(9706056,e|0,76)|0}c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;gGz(9706056,0,76);c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){e=0;do{lN(e);mB(e);e=e+1|0;}while((e|0)<(c[2385508]|0));e=c[1836236]|0;f=e;g=c[9757320+(e<<2)>>2]|0}else{f=0;g=d}UA();if((g|0)!=0){d=g;gGC(d|0,9706056,76)|0}c[9752472+(f<<2)>>2]=c[2433530];c[14113936+(f<<2)>>2]=c[2076596];c[9669104+(f<<2)>>2]=c[3541536];c[1836236]=-1;a[14115664]=0;a[9718888]=0}f=c[2385548]|0;if((f|0)>0){gGz(9752472,0,((f|0)>1?f<<2:4)|0)}c[2433530]=0;c[2387562]=0;f=0;d=0;g=0;do{d=((a[9632736+f|0]&1)<<f^d&65535)&65535;g=((a[9630632+f|0]&1)<<f^g&65535)&65535;f=f+1|0;}while((f|0)<16);b[4775124]=d;b[4775125]=g;c[2415126]=9662152;g=c[2415557]|0;d=g&3;if((d|0)==3){i=133}else{i=(4e6/(4e6/((c[2415554]|0)/(c[600992+((g>>>3&1)<<4)+(d<<2)>>2]|0)|0|0)|0|0)|0|0)/((c[2424]|0)/100|0|0)|0}if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}d=c[2439330]|0;if((d|0)!=0){g=d;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;if((i|0)>0){g=i-1|0;d=0;f=0;e=0;j=0;do{e=(133333/(i|0)|0)+e|0;k=e-d|0;c[2113056]=k;l=RG(k)|0;c[2113054]=(c[2113054]|0)+l;c[2276108]=-1;c[2113056]=-1;d=l+d|0;do{if((j|0)==(g|0)){c[8452200+(c[2394]<<2)>>2]=8193;c[2276080]=256;if((c[2276079]|0)>>>0>=256){break}RH(1)}}while(0);f=(66666/(i|0)|0)+f|0;Sb(f);UD();j=j+1|0;}while((j|0)<(i|0))}i=c[2438228]|0;j=gGS(-747372544,31788,i,(i|0)<0|0?-1:0)|0;i=j;Sb(66666);j=c[2443830]|0;if((j|0)<1073676288){c[2443830]=j-i}j=c[2443831]|0;if((j|0)<1073676288){c[2443831]=j-i}j=(c[3528512]|0)-i|0;c[3528512]=(j|0)<0?0:j;j=c[2112964]|0;if((j|0)!=0){gg[c[3542122]&4095](j,a[9688]|0?534:0);Uz(0,c[2112964]|0,a[9688]|0?534:0)}j=c[1836236]|0;i=c[9757320+(j<<2)>>2]|0;if((i|0)!=0){f=i;gGC(f|0,9706056,76)|0}c[9752472+(j<<2)>>2]=c[2433530];c[14113936+(j<<2)>>2]=c[2076596];c[9669104+(j<<2)>>2]=c[3541536];c[1836236]=-1;j=c[2394]|0;f=c[14130368+(j<<2)>>2]|0;if((f|0)!=0){gGC(f|0,9104152,280)|0}c[8452240+(j<<2)>>2]=c[2113054];c[2394]=-1;if((c[2112968]|0)==0){return 0}e9u()|0;return 0}function e9u(){var d=0,e=0,f=0,g=0;d=c[2387128]|0;e=c[3529920]|0;f=0;do{g=b[d+(f<<1)>>1]|0;c[e+(f<<2)>>2]=((g&65535)>>>10<<3&248)<<8|((g&255)<<3&255)>>>3|(((g&65535)>>>5<<3&255|(g&65535)>>>7&4)&255)<<3&2016;f=f+1|0;}while((f|0)<2048);f=a[c[2443686]|0]|0;c[3528668]=f&1;d=c[2406286]|0;e9y(d+((f&2)!=0?28672:24576)|0,c[3530316]|0,112,4,8191,0);e9z(d+8192|0,c[3530536]|0,96,3);f=c[3530290]|0;e9y(d+20480|0,f,64,2,32767,1);e9y(d+16384|0,f,32,1,32767,1);e9z(d,c[3530772]|0,16,0);e9z(d+32768|0,c[3530402]|0,0,5);R8(e);return 0}function e9v(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=i;i=i+64|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;if((d|0)!=0){c[d>>2]=169624}if((b&32|0)!=0){gGz(j|0,0,12);k=c[2414590]|0;c[j>>2]=k;c[j+4>>2]=(c[2411534]|0)-k;c[j+12>>2]=162152;k=c[2076592]|0;gj[k&4095](j)|0}if((b&64|0)==0){i=e;return 0}j=h|0;gGz(g|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){k=h+9|0;h=f;l=f|0;m=f+4|0;n=f+12|0;o=g|0;p=g+4|0;q=g+12|0;r=0;do{gGC(j|0,614896,11)|0;a[k]=r+48&255;s=8452256+(r<<2)|0;gGz(h|0,0,12);c[l>>2]=s;c[m>>2]=4;c[n>>2]=164976;gj[c[2076592]&4095](f)|0;if((c[s>>2]|0)!=0){c[o>>2]=c[14130368+(r<<2)>>2];c[p>>2]=c[8452184+(r<<2)>>2];c[q>>2]=j;s=c[2076592]|0;gj[s&4095](g)|0}r=r+1|0;}while((r|0)<=(c[2392]|0))}fw$(b);Vx(b,d);UE(b,d);i=e;return 0}function e9w(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3136564+(b*112|0)>>2];c[a+104>>2]=c[3136568+(b*112|0)>>2];c[a+108>>2]=c[3136572+(b*112|0)>>2];d=0;return d|0}function e9x(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=3136464+(b*112|0);e=0;return e|0}function e9y(a,b,d,f,g,h){a=a|0;b=b|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;i=(e[(c[2406644]|0)+(f<<1)>>1]|0)+112&511;j=(e[(c[2406634]|0)+(f<<1)>>1]|0)+24&511;f=a;a=(c[3528668]|0)==0;k=c[2112926]|0;l=c[2113068]|0;m=c[2113070]|0;if((h|0)==0){h=0;do{n=(h<<4&496)-i|0;o=(n|0)<-15?n+512|0:n;n=(h>>5<<4)-j|0;p=(n|0)<-15?n+512|0:n;do{if((o|0)<(l|0)&(p|0)<(m|0)){n=h<<1;q=(e[f+(n<<1)>>1]|0)&g;r=((e[f+((n|1)<<1)>>1]|0)>>>8&31)+d|0;if(a){Sz(k,q,o,p,r,4,0,b);break}else{SF(k,q,272-o|0,192-p|0,r,4,0,b);break}}}while(0);h=h+1|0;}while((h|0)<1024);return}else{h=0;do{p=(h<<4&496)-i|0;o=(p|0)<-15?p+512|0:p;p=(h>>5<<4)-j|0;r=(p|0)<-15?p+512|0:p;do{if((o|0)<(l|0)&(r|0)<(m|0)){p=h<<1;q=(e[f+(p<<1)>>1]|0)&g;n=((e[f+((p|1)<<1)>>1]|0)>>>8&31)+d|0;if(a){SH(k,q,o,r,n,4,15,0,b);break}else{SN(k,q,272-o|0,192-r|0,n,4,15,0,b);break}}}while(0);h=h+1|0;}while((h|0)<1024);return}}function e9z(a,b,d,f){a=a|0;b=b|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=(e[(c[2406644]|0)+(f<<1)>>1]|0)+112&511;h=(e[(c[2406634]|0)+(f<<1)>>1]|0)+24&511;f=a;a=(c[3528668]|0)==0;i=c[2112926]|0;j=c[2113068]|0;k=c[2113070]|0;l=0;do{m=(l<<3&504)-g|0;n=(m|0)<-7?m+512|0:m;m=(l>>6<<3)-h|0;o=(m|0)<-7?m+512|0:m;do{if((n|0)<(j|0)&(o|0)<(k|0)){m=e[f+(l<<1)>>1]|0;p=m&4095;q=(m>>>12)+d|0;if(a){Sr(i,p,n,o,q,4,15,0,b);break}else{Sx(i,p,280-n|0,200-o|0,q,4,15,0,b);break}}}while(0);l=l+1|0;}while((l|0)<4096);return}function e9A(a){a=a|0;var b=0.0,d=0,e=0;b=+((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0);d=+V(b)>=1.0?b>0.0?(al(+U(b/4294967296.0),4294967295.0)|0)>>>0:~~+af((b- +(~~b>>>0))/4294967296.0)>>>0:0;e=gGU(~~b>>>0,d,a,(a|0)<0|0?-1:0)|0;a=gGS(e,K,4e6,0)|0;return a|0}function e9B(){var b=0,e=0,f=0,g=0;b=d[14115664]|0;if((a[9718888]|0)==0){e=b>>>4;c[2415126]=9662152;if((c[2415542]|0)==4){c[2415538]=e;f=1;a[9718888]=f;return}else{c[2415538]=e<<1&14;f=1;a[9718888]=f;return}}c[2415126]=9662152;if((c[2415542]|0)==4){g=b&15}else{g=b<<1&14}c[2415538]=g;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12;f=a[9718888]^1;a[9718888]=f;return}function e9C(b,c){b=b|0;c=c|0;a[9706117]=c&1;return}function e9D(){return+(+((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)/4.0e6)}function e9E(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;e=b&65535;L62431:do{if((e|0)==53256){f=c[2429684]|0;if((f|0)==2){g=2;break}else if((f|0)==6){g=((d[9550242]|0)<64)<<5|15;break}else if((f|0)==4){g=((d[9550242]|0)<64)<<5;break}else if((f|0)==5){g=((d[9550242]|0)<64)<<5|2;break}else{g=0;break}}else if((e|0)==53249){f=c[3542228]|0;if((f|0)>15){g=0;break}do{if((f|0)==15){h=c[3542225]|0;if((h|0)==0){break}a[14168931]=gj[h&4095](0)|0}else if((f|0)==14){h=c[3542224]|0;if((h|0)==0){break}a[14168930]=gj[h&4095](0)|0}}while(0);g=a[14168916+f|0]|0}else if((e|0)==61442){h=c[2429684]|0;if((h|0)==5){i=d[9717800]|0;if((i|0)==138){g=-91;break}else if((i|0)==255){g=-30;break}else{g=0;break}}else if((h|0)!=6){g=0;break}switch(d[9717800]|0|0){case 195:{g=29;break L62431;break};case 227:{g=97;break L62431;break};case 56:{g=-13;break L62431;break};case 138:{g=-91;break L62431;break};case 36:{g=-101;break L62431;break};case 54:{g=45;break L62431;break};case 255:{g=-30;break L62431;break};default:{g=0;break L62431}}}else if((e|0)==53260){h=a[9550240]|0;if(!(a[642576]|0)){g=h;break}i=h&63;h=(c[2161344]|0)==0?i|64:i;if((c[2161338]|0)!=0){g=h&255;break}g=(h|128)&255}else if((e|0)==53272){if(a[642576]|0){c[2161338]=0;g=a[9533344]|0;break}else{g=a[9550242]|0;break}}else if((e|0)==53264){g=a[9550241]|0}else{if((b&65535)<=61439){g=0;break}g=a[(c[2385874]|0)+e|0]|0}}while(0);return g|0}function e9F(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=d&65535;if((f|0)==53248|(f|0)==53249){d=e&255;if((f&1|0)==0){c[3542228]=d&15;return}g=c[3542228]|0;if((g|0)>15){return}do{if((g|0)<14){if((g|0)!=13){if((a[14168916+g|0]|0)==e<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(0,g,d);return}else if((f|0)==53272){if(a[642576]|0){a[9533352]=e;c[2161344]=1;return}a[9717800]=0;switch(c[2429684]|0){case 1:case 3:{switch(e&255|0){case 54:{if((b[4853030]|0)!=31815){return}a[9717800]=0;return};case 56:{if((b[4853030]|0)!=31623){return}a[9717800]=0;return};case 255:{if((b[4853030]|0)!=-27024){return}a[9717800]=0;return};case 247:{if((b[4853030]|0)!=841){return}a[9717800]=0;return};case 138:{if((b[4853030]|0)!=-27039){return}a[9717800]=0;return};case 227:{if((b[4853030]|0)!=26595){return}a[9717800]=0;return};default:{a[9717800]=0;return}}break};case 2:{switch(e&255|0){case 54:{if((b[4853030]|0)!=31820){return}a[9717800]=0;return};case 255:{if((b[4853030]|0)!=-27024){return}a[9717800]=0;return};case 192:{if((b[4853030]|0)!=26599){return}a[9717800]=0;return};case 136:{d=b[4853030]|0;if((d<<16>>16|0)==26595){a[9717800]=0;return}else if((d<<16>>16|0)==31815){a[9717800]=0;return}else{return}break};case 227:{if((b[4853030]|0)!=26601){return}a[9717800]=0;return};case 137:{if((b[4853030]|0)!=26597){return}a[9717800]=0;return};case 138:{if((b[4853030]|0)!=-27039){return}a[9717800]=0;return};case 56:{if((b[4853030]|0)!=31623){return}a[9717800]=0;return};default:{a[9717800]=0;return}}break};case 4:{switch(e&255|0){case 137:{if((b[4853030]|0)!=26597){return}a[9717800]=0;return};case 255:{if((b[4853030]|0)!=-27024){return}a[9717800]=0;return};case 56:{if((b[4853030]|0)!=31623){return}a[9717800]=0;return};case 54:{if((b[4853030]|0)!=31820){return}a[9717800]=0;return};case 136:{d=b[4853030]|0;if((d<<16>>16|0)==31815){a[9717800]=0;return}else if((d<<16>>16|0)==26595){a[9717800]=0;return}else{return}break};case 138:{if((b[4853030]|0)!=-27039){return}a[9717800]=0;return};case 247:{if((b[4853030]|0)!=841){return}a[9717800]=0;return};case 192:{if((b[4853030]|0)!=26599){return}a[9717800]=0;return};case 227:{if((b[4853030]|0)!=26601){return}a[9717800]=0;return};default:{a[9717800]=0;return}}break};case 5:{L62627:do{switch(e&255|0){case 138:{if((b[4853030]|0)!=-27039){return}a[9717800]=e;return};case 247:{if((b[4853030]|0)!=841){return}a[9717800]=0;return};case 56:{if((b[4853030]|0)!=31623){return}a[9717800]=0;return};case 255:{if((b[4853030]|0)!=-27024){return}a[9717800]=e;return};case 136:{d=b[4853030]|0;if((d<<16>>16|0)==26595){a[9717800]=0;return}else if((d<<16>>16|0)==31815){a[9717800]=0;return}else{h=d;break L62627}break};case 227:{if((b[4853030]|0)!=26601){return}a[9717800]=0;return};case 137:{h=b[4853030]|0;break};case 54:{if((b[4853030]|0)!=31820){return}a[9717800]=0;return};case 192:{if((b[4853030]|0)!=26599){return}a[9717800]=0;return};default:{a[9717800]=0;return}}}while(0);if(h<<16>>16!=26597){return}a[9717800]=0;return};case 6:{L62678:do{switch(e&255|0){case 136:{h=b[4853030]|0;if((h<<16>>16|0)==26595){a[9717800]=0;return}else if((h<<16>>16|0)==31815){a[9717800]=0;return}else{i=h;break L62678}break};case 255:{if((b[4853030]|0)!=-27024){return}a[9717800]=e;return};case 54:{if((b[4853030]|0)!=31820){return}a[9717800]=e;return};case 138:{if((b[4853030]|0)!=-27039){return}a[9717800]=e;return};case 192:{if((b[4853030]|0)!=26599){return}a[9717800]=0;return};case 195:{if((b[4853030]|0)!=-17014){return}a[9717800]=e;return};case 56:{if((b[4853030]|0)!=31623){return}a[9717800]=e;return};case 227:{if((b[4853030]|0)!=26601){return}a[9717800]=e;return};case 247:{if((b[4853030]|0)!=841){return}a[9717800]=e;return};case 137:{i=b[4853030]|0;break};case 36:{if((b[4853030]|0)!=-17030){return}a[9717800]=e;return};default:{a[9717800]=0;return}}}while(0);if(i<<16>>16!=26597){return}a[9717800]=0;return};default:{return}}}else if((f|0)==53256){a[c[3528666]|0]=e&3;a[c[2406754]|0]=(e&255)>>>5&1;a[c[2443752]|0]=(e&255)>>>6&1;a[c[2440372]|0]=(e&255)>>>2&1;return}else{return}}function e9G(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=b&65535;if((e|0)==53256){a[c[3528666]|0]=d&3;a[c[2406754]|0]=(d&255)>>>5&1;a[c[3528836]|0]=d;b=c[2385874]|0;f=c[9757320+(c[1836236]<<2)>>2]|0;g=((d&255)>>>4<<14&16384|32768)-32768|0;h=128;i=128;while(1){c[f+76+(i<<2)>>2]=b+(g+(i<<8));j=h+1&65535;if((j&65535)>191){k=128;l=128;break}else{h=j;i=j&65535}}while(1){i=b+(g+(l<<8))|0;c[f+76+(l+512<<2)>>2]=i;c[f+76+(l+768<<2)>>2]=i;i=k+1&65535;if((i&65535)>191){break}else{k=i;l=i&65535}}return}else if((e|0)==53248|(e|0)==53249){l=d&255;if((e&1|0)==0){c[3542228]=l&15;return}e=c[3542228]|0;if((e|0)>15){return}do{if((e|0)<14){if((e|0)!=13){if((a[14168916+e|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(0,e,l);return}else{return}}function e9H(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3151988+(b*112|0)>>2];c[a+104>>2]=c[3151992+(b*112|0)>>2];c[a+108>>2]=c[3151996+(b*112|0)>>2];d=0;return d|0}function e9I(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=3151888+(b*112|0);e=0;return e|0}function e9J(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6923872+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function e9K(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3153232+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e9L(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0.0,$=0,aa=0,ab=0;e=i;i=i+600|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+488|0;c[2414884]=0;c[2385874]=0;c[2387318]=65536;c[2387810]=67584;c[3530994]=329728;c[3529916]=331776;c[2414586]=333824;c[2386028]=333824;c[2387330]=335872;c[2386192]=336e3;c[2386400]=338048;c[3528666]=340096;c[2406754]=340097;c[2443752]=340098;c[2440372]=340099;c[3528836]=340100;c[2411530]=340101;c[2438984]=340101;r=a[9688]|0?1068:0;s=r+340101|0;c[2438985]=s;t=s+r|0;c[2438986]=t;s=t+r|0;c[2414070]=s;r=s;s=0;while(1){if((s|0)>=1024){break}u=9638528+(s<<2)|0;if((c[u>>2]|0)==0){v=48020;break}else{s=s+1|0}}do{if((v|0)==48020){s=gGq(r)|0;c[u>>2]=s;if((s|0)==0){break}gGz(s|0,0,r|0);c[2414884]=s;gGz(s|0,0,r|0);c[2385874]=s;c[2387318]=s+65536;t=s+67584|0;c[2387810]=t;w=s+329728|0;c[3530994]=w;c[3529916]=s+331776;x=s+333824|0;c[2414586]=x;c[2386028]=x;c[2387330]=s+335872;c[2386192]=s+336e3;c[2386400]=s+338048;c[3528666]=s+340096;c[2406754]=s+340097;c[2443752]=s+340098;c[2440372]=s+340099;c[3528836]=s+340100;x=s+340101|0;c[2411530]=x;c[2438984]=x;x=a[9688]|0?1068:0;y=x+340101|0;c[2438985]=s+y;z=y+x|0;c[2438986]=s+z;c[2414070]=s+(z+x);a[642576]=0;L62802:do{if((gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](p,0,0)|0)==0){x=q+108|0;z=q+100|0;y=n+108|0;A=n+100|0;B=l+108|0;C=l+100|0;D=j+108|0;E=j+100|0;F=f+108|0;G=f+100|0;H=s;I=t;J=w;K=0;while(1){gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](q,K)|0;L=c[x>>2]&7;if((L|0)==1){if((c[3542200]|0)==0){M=1;v=48084;break}c[y>>2]=0;c[A>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](n,K)|0;if((c[y>>2]|0)!=0){N=c[A>>2]|0;c[o>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](o,K,0)|0;if((N|0)<1){M=1;v=48086;break}if((gzL(H,0,K)|0)!=0){M=1;v=48085;break}}P=J;Q=I;R=H+(c[z>>2]|0)|0}else if((L|0)==2){N=c[2387318]|0;if((c[3542200]|0)==0){M=1;v=48087;break}c[B>>2]=0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,K)|0;if((c[B>>2]|0)!=0){O=c[C>>2]|0;c[m>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](m,K,0)|0;if((O|0)<1){M=1;v=48088;break}if((gzL(N,0,K)|0)!=0){M=1;v=48089;break}}a[642576]=1;P=J;Q=I;R=H}else if((L|0)==3){if((c[3542200]|0)==0){M=1;v=48090;break}c[D>>2]=0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,K)|0;if((c[D>>2]|0)!=0){N=c[E>>2]|0;c[k>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](k,K,0)|0;if((N|0)<1){M=1;v=48091;break}if((gzL(I,0,K)|0)!=0){M=1;v=48092;break}}P=J;Q=I+(c[z>>2]|0)|0;R=H}else if((L|0)==4){if((c[3542200]|0)==0){M=1;v=48093;break}c[F>>2]=0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,K)|0;if((c[F>>2]|0)!=0){L=c[G>>2]|0;c[g>>2]=9534384;N=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[N&16383](g,K,0)|0;if((L|0)<1){M=1;v=48094;break}if((gzL(J,0,K)|0)!=0){M=1;v=48095;break}}P=J+(c[z>>2]|0)|0;Q=I;R=H}else{P=J;Q=I;R=H}L=K+1|0;if((gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](p,L,0)|0)==0){H=R;I=Q;J=P;K=L}else{T=0;break L62802}}if((v|0)==48088){i=e;return M|0}else if((v|0)==48092){i=e;return M|0}else if((v|0)==48085){i=e;return M|0}else if((v|0)==48089){i=e;return M|0}else if((v|0)==48086){i=e;return M|0}else if((v|0)==48095){i=e;return M|0}else if((v|0)==48091){i=e;return M|0}else if((v|0)==48094){i=e;return M|0}else if((v|0)==48090){i=e;return M|0}else if((v|0)==48084){i=e;return M|0}else if((v|0)==48093){i=e;return M|0}else if((v|0)==48087){i=e;return M|0}}else{T=0}}while(0);while(1){if((T|0)>=1024){U=0;break}V=9638528+(T<<2)|0;if((c[V>>2]|0)==0){v=48048;break}else{T=T+1|0}}do{if((v|0)==48048){w=gGq(262144)|0;c[V>>2]=w;if((w|0)==0){U=0;break}gGz(w|0,0,262144);U=w}}while(0);w=c[2387810]|0;t=0;do{s=(t|0)/8|0;K=t&7;J=(d[w+s|0]|0)>>>(K>>>0)&1;I=U+t|0;a[I]=J;H=(d[w+(s+32768)|0]|0)>>>(K>>>0)<<1&2|J&255;a[I]=H&255;a[I]=((d[w+(s+65536)|0]|0)>>>(K>>>0)<<2&4|H)&255;t=t+1|0;}while((t|0)<262144);gGC(w|0,U|0,262144)|0;t=0;while(1){if((t|0)>=1024){break}W=9638528+(t<<2)|0;if((c[W>>2]|0)==(U|0)){v=48055;break}else{t=t+1|0}}if((v|0)==48055){gGr(U);c[W>>2]=0}faK();fwR(0);t=c[2439330]|0;if((t|0)!=0){w=t;gGC(9706056,w|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];w=c[3528484]|0;c[2076596]=w;H=c[2417276]|0;c[3541536]=H;c[1836236]=0;K=c[2385874]|0;s=0;I=0;while(1){c[t+76+(I<<2)>>2]=K+(I<<8);J=s+1&65535;if((J&65535)>191){X=0;Y=0;break}else{s=J;I=J&65535}}while(1){I=K+(Y<<8)|0;c[t+76+(Y+512<<2)>>2]=I;c[t+76+(Y+768<<2)>>2]=I;I=X+1&65535;if((I&65535)>191){break}else{X=I;Y=I&65535}}I=c[2386028]|0;c[t+844>>2]=I;s=I+256|0;c[t+848>>2]=s;J=I+512|0;c[t+852>>2]=J;z=I+768|0;c[t+856>>2]=z;G=I+1024|0;c[t+860>>2]=G;F=I+1280|0;c[t+864>>2]=F;E=I+1536|0;c[t+868>>2]=E;D=I+1792|0;c[t+872>>2]=D;c[t+1868>>2]=I;c[t+1872>>2]=s;c[t+1876>>2]=J;c[t+1880>>2]=z;c[t+1884>>2]=G;c[t+1888>>2]=F;c[t+1892>>2]=E;c[t+1896>>2]=D;c[t+2892>>2]=I;c[t+3916>>2]=I;c[t+2896>>2]=s;c[t+3920>>2]=s;c[t+2900>>2]=J;c[t+3924>>2]=J;c[t+2904>>2]=z;c[t+3928>>2]=z;c[t+2908>>2]=G;c[t+3932>>2]=G;c[t+2912>>2]=F;c[t+3936>>2]=F;c[t+2916>>2]=E;c[t+3940>>2]=E;c[t+2920>>2]=D;c[t+3944>>2]=D;D=c[2386192]|0;c[t+972>>2]=D;E=D+256|0;c[t+976>>2]=E;F=D+512|0;c[t+980>>2]=F;G=D+768|0;c[t+984>>2]=G;z=D+1024|0;c[t+988>>2]=z;J=D+1280|0;c[t+992>>2]=J;s=D+1536|0;c[t+996>>2]=s;I=D+1792|0;c[t+1e3>>2]=I;c[t+1996>>2]=D;c[t+2e3>>2]=E;c[t+2004>>2]=F;c[t+2008>>2]=G;c[t+2012>>2]=z;c[t+2016>>2]=J;c[t+2020>>2]=s;c[t+2024>>2]=I;c[t+3020>>2]=D;c[t+4044>>2]=D;c[t+3024>>2]=E;c[t+4048>>2]=E;c[t+3028>>2]=F;c[t+4052>>2]=F;c[t+3032>>2]=G;c[t+4056>>2]=G;c[t+3036>>2]=z;c[t+4060>>2]=z;c[t+3040>>2]=J;c[t+4064>>2]=J;c[t+3044>>2]=s;c[t+4068>>2]=s;c[t+3048>>2]=I;c[t+4072>>2]=I;I=c[2386400]|0;c[t+1004>>2]=I;s=I+256|0;c[t+1008>>2]=s;J=I+512|0;c[t+1012>>2]=J;z=I+768|0;c[t+1016>>2]=z;G=I+1024|0;c[t+1020>>2]=G;F=I+1280|0;c[t+1024>>2]=F;E=I+1536|0;c[t+1028>>2]=E;D=I+1792|0;c[t+1032>>2]=D;c[t+2028>>2]=I;c[t+2032>>2]=s;c[t+2036>>2]=J;c[t+2040>>2]=z;c[t+2044>>2]=G;c[t+2048>>2]=F;c[t+2052>>2]=E;c[t+2056>>2]=D;c[t+3052>>2]=I;c[t+4076>>2]=I;c[t+3056>>2]=s;c[t+4080>>2]=s;c[t+3060>>2]=J;c[t+4084>>2]=J;c[t+3064>>2]=z;c[t+4088>>2]=z;c[t+3068>>2]=G;c[t+4092>>2]=G;c[t+3072>>2]=F;c[t+4096>>2]=F;c[t+3076>>2]=E;c[t+4100>>2]=E;c[t+3080>>2]=D;c[t+4104>>2]=D;D=240;E=240;while(1){F=K+(E<<8)|0;c[t+76+(E+512<<2)>>2]=F;c[t+76+(E+768<<2)>>2]=F;F=D+1&65535;if((F&65535)>255){break}else{D=F;E=F&65535}}E=c[2429684]|0;c[t+4184>>2]=(E|0)==7?484:2118;c[t+4180>>2]=1e3;D=t;gGC(D|0,9706056,76)|0;c[2438118]=c[2433530];c[3528484]=w;c[2417276]=H;c[1836236]=-1;D=c[2387318]|0;K=c[2387330]|0;c[2424906]=682992;c[2443666]=2047;c[2385780]=7;c[3528996]=3;gGz(9702704,0,32);gGz(9703728,0,32);gGz(9704752,0,32);F=c[2427044]|0;c[9681616+(F<<3)>>2]=809328;c[9681620+(F<<3)>>2]=0;c[2427044]=F+1;F=2;while(1){G=K+((F<<3)-16)|0;c[9702704+(F<<2)>>2]=G;c[9703728+(F<<2)>>2]=G;c[9704752+(F<<2)>>2]=G;G=F+1|0;if((G|0)<16){F=G}else{Z=16;break}}do{F=D+(Z<<3)|0;c[9702704+(Z<<2)>>2]=F;c[9704752+(Z<<2)>>2]=F;Z=Z+1|0;}while((Z|0)<256);c[3528586]=3404;c[2385590]=1124;D=a[9680]|0?32e3:0;c[3542220]=11200;if((c[2113008]|0)==0){gGz(14168888,0,252);c[3542223]=D;c[3542224]=2588;c[3542225]=1274;c[3542226]=0;c[3542227]=0;c[3542234]=~~((+(D|0)*32768.0*8.0+75.0e4)/15.0e5);D=31;_=32767.0;while(1){c[14169012+(D<<2)>>2]=~~(_+.5);F=D-1|0;if((F|0)>0){D=F;_=_/1.188502227}else{break}}c[3542253]=0;h[1771269]=1.0;h[1771270]=1.0;h[1771271]=1.0;c[3542574]=3;c[3542575]=3;c[3542576]=3;mB(0);c[2113008]=(c[2113008]|0)+1;$=c[2429684]|0}else{$=E}h[1771269]=.33;c[3542574]=3;h[1771270]=.33;c[3542575]=3;h[1771271]=.33;c[3542576]=3;if(($|0)==7){h[1771269]=.5;c[3542574]=3}h[1771270]=.5;c[3542575]=3;h[1771271]=.5;c[3542576]=3;D=c[642608+(c[2436]<<2)>>2]|0;F=c[D+128>>2]|0;if((c[D+52>>2]&4|0)==0){c[2113068]=F;K=c[D+132>>2]|0;c[2113070]=K;c[2443814]=F;c[2440436]=K;aa=F;ab=K}else{c[2113070]=F;K=c[D+132>>2]|0;c[2113068]=K;c[2440436]=F;c[2443814]=K;aa=K;ab=F}F=ag(aa<<1,ab)|0;K=gGq(F)|0;c[2112926]=K;if((K|0)!=0){gGz(K|0,0,F|0)}a[9623680]=0;F=c[2414586]|0;gGz(F|0,0,(c[2411530]|0)-F|0);F=c[2439330]|0;K=(F|0)==0;if(!K){D=F;gGC(9706056,D|0,76)|0}D=c[2438118]|0;c[2433530]=D;H=c[3528484]|0;c[2076596]=H;w=c[2417276]|0;c[3541536]=w;c[1836236]=0;gGz(9706056,0,76);if(!K){K=F;gGC(K|0,9706056,76)|0}c[2438118]=D;c[3528484]=H;c[2417276]=w;c[1836236]=-1;f42();a[8451544]=0;a[8451536]=0;a[9533800]=0;a[8451528]=0;a[8451520]=0;a[9533792]=0;a[8451512]=0;a[8451504]=0;a[9533784]=0;a[9533352]=0;a[9533344]=0;c[2161338]=0;c[2161344]=0;mB(0);c[2444136]=0;c[2444137]=0;a[9717800]=0;M=0;i=e;return M|0}}while(0);c[2414884]=0;M=1;i=e;return M|0}function e9M(){var b=0,d=0,e=0,f=0;c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}fwZ();a[8451544]=0;a[8451536]=0;a[9533800]=0;a[8451528]=0;a[8451520]=0;a[9533792]=0;a[8451512]=0;a[8451504]=0;a[9533784]=0;a[9533352]=0;a[9533344]=0;c[2161338]=0;c[2161344]=0;c[2424906]=0;c[2443666]=0;c[2385780]=0;c[3528996]=0;c[2113008]=0;c[2076598]=0;c[2383582]=0;b=c[2414884]|0;d=0;while(1){if((d|0)>=1024){e=48105;break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==(b|0)){break}else{d=d+1|0}}if((e|0)==48105){c[2414884]=0;c[2429684]=0;return 0}gGr(b);c[f>>2]=0;c[2414884]=0;c[2429684]=0;return 0}function e9N(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((a[9623680]|0)!=0){a[9623680]=0;d=c[2414586]|0;gGz(d|0,0,(c[2411530]|0)-d|0);d=c[2439330]|0;f=(d|0)==0;if(!f){g=d;gGC(9706056,g|0,76)|0}g=c[2438118]|0;c[2433530]=g;h=c[3528484]|0;c[2076596]=h;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);if(!f){f=d;gGC(f|0,9706056,76)|0}c[2438118]=g;c[3528484]=h;c[2417276]=i;c[1836236]=-1;f42();a[8451544]=0;a[8451536]=0;a[9533800]=0;a[8451528]=0;a[8451520]=0;a[9533792]=0;a[8451512]=0;a[8451504]=0;a[9533784]=0;a[9533352]=0;a[9533344]=0;c[2161338]=0;c[2161344]=0;mB(0);c[2444136]=0;c[2444137]=0;a[9717800]=0}b[4775120]=-1;if((c[2429684]|0)==7){j=0;k=-1;l=-1}else{a[9550240]=79;j=0;k=79;l=-1}do{k=((a[9632712+j|0]&1)<<j^k&255)&255;l=((a[9630608+j|0]&1)<<j^l&255)&255;j=j+1|0;}while((j|0)<8);a[9550240]=k;a[9550241]=l;l=(c[2444136]|0)-(e[4817904]|0)|0;c[2444136]=l;a[9550242]=(l>>>8&254^254)&255;l=(c[2444137]|0)-(e[4817905]|0)|0;c[2444137]=l;a[9550243]=(l>>>8&254^254)&255;l=c[2439330]|0;if((l|0)!=0){k=l;gGC(9706056,k|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;k=1;j=l;while(1){if((a[j+4188|0]|0)==0){l=gfc(1e3)|0;m=(c[2433530]|0)+l|0}else{m=(c[2433530]|0)+1e3|0}c[2433530]=m;if(a[642576]|0){f4Y(500)|0}if((k|0)>=100){break}k=k+1|0;j=c[9757320+(c[1836236]<<2)>>2]|0}a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0;j=c[1836236]|0;k=c[9757320+(j<<2)>>2]|0;if((k|0)!=0){m=k;gGC(m|0,9706056,76)|0}c[9752472+(j<<2)>>2]=c[2433530];c[14113936+(j<<2)>>2]=c[2076596];c[9669104+(j<<2)>>2]=c[3541536];c[1836236]=-1;j=c[2112964]|0;if((j|0)!=0){mF(9755936,j,a[9688]|0?534:0,0)}if((c[2112968]|0)==0){return 0}e9O()|0;return 0}function e9O(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if((a[9547160]|0)!=0){faK();a[9547160]=0}b=c[3528666]|0;e=c[2113070]|0;f=c[2386192]|0;g=c[2406754]|0;h=c[2443752]|0;i=c[2112926]|0;j=c[2387810]|0;k=0;do{l=k<<3&248;m=k>>5<<3;n=(a[b]|0)==0;if(n){o=l;p=m}else{o=l^248;p=m^248}m=p-16|0;do{if((m|0)>-1&(m|0)<(e|0)){l=k<<1;q=d[f+l|0]|0;r=q<<8&1792|d[f+(l|1)|0]|d[g]<<11;l=d[h]<<5|q>>>3;if(n){Sk(i,r,o,m,l,3,0,j);break}else{Sm(i,r,o,m,l,3,0,j);break}}}while(0);k=k+1|0;}while((k|0)<960);k=c[2386400]|0;o=0;do{f=d[k+o|0]|0;e=d[k+(o|1)|0]|0;p=248-e|0;m=d[k+(o|2)|0]|0;n=m<<8&768|d[k+(o|3)|0]|d[g]<<10;l=d[h]<<5|m>>>3;if((a[b]|0)==0){m=n<<1;St(i,m,f,p-24|0,l,3,0,0,j);St(i,m|1,f,p-16|0,l,3,0,0,j)}else{p=248-f|0;f=n<<1;Sv(i,f,p,e-8|0,l,3,0,0,j);Sv(i,f|1,p,e-16|0,l,3,0,0,j)}o=o+4|0;}while((o|0)<64);R8(c[3529916]|0);return 0}function e9P(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=i;i=i+96|0;f=e|0;g=e+32|0;h=e+48|0;j=e+64|0;k=e+80|0;l=(d|0)==0;if(!l){c[d>>2]=169735}if((b&96|0)==0){i=e;return 0}gGz(k|0,0,12);m=c[2414586]|0;c[k>>2]=m;c[k+4>>2]=(c[2411530]|0)-m;c[k+12>>2]=162152;gj[c[2076592]&4095](k)|0;fw$(b);if(a[642576]|0){eZ3(b)}k=e+16|0;do{if((b&64|0)!=0){do{if(!l){if((c[d>>2]|0)>=169110){break}c[d>>2]=169110}}while(0);if((c[2113008]|0)<=0){break}m=f|0;n=f+4|0;o=f+8|0;p=f+12|0;q=0;do{cC(k|0,531144,(r=i,i=i+8|0,c[r>>2]=q,r)|0)|0;i=r;c[m>>2]=14168888+(q*252|0);c[n>>2]=252;c[o>>2]=0;c[p>>2]=k;gj[c[2076592]&4095](f)|0;q=q+1|0;}while((q|0)<(c[2113008]|0))}}while(0);gGz(j|0,0,12);c[j>>2]=9776544;c[j+4>>2]=4;c[j+12>>2]=473856;gj[c[2076592]&4095](j)|0;gGz(h|0,0,12);c[h>>2]=9776548;c[h+4>>2]=4;c[h+12>>2]=472176;gj[c[2076592]&4095](h)|0;gGz(g|0,0,12);c[g>>2]=9717800;c[g+4>>2]=1;c[g+12>>2]=530528;gj[c[2076592]&4095](g)|0;i=e;return 0}function e9Q(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3140860+(b*112|0)>>2];c[a+104>>2]=c[3140864+(b*112|0)>>2];c[a+108>>2]=c[3140868+(b*112|0)>>2];d=0;return d|0}function e9R(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=3140760+(b*112|0);e=0;return e|0}function e9S(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3139852+(b*112|0)>>2];c[a+104>>2]=c[3139856+(b*112|0)>>2];c[a+108>>2]=c[3139860+(b*112|0)>>2];d=0;return d|0}function e9T(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=3139752+(b*112|0);e=0;return e|0}function e9U(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3150084+(b*112|0)>>2];c[a+104>>2]=c[3150088+(b*112|0)>>2];c[a+108>>2]=c[3150092+(b*112|0)>>2];d=0;return d|0}function e9V(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=3149984+(b*112|0);e=0;return e|0}function e9W(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3141868+(b*112|0)>>2];c[a+104>>2]=c[3141872+(b*112|0)>>2];c[a+108>>2]=c[3141876+(b*112|0)>>2];d=0;return d|0}function e9X(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=3141768+(b*112|0);e=0;return e|0}function e9Y(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3142776+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e9Z(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3147172+(b*112|0)>>2];c[a+104>>2]=c[3147176+(b*112|0)>>2];c[a+108>>2]=c[3147180+(b*112|0)>>2];d=0;return d|0}function e9_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=3147072+(b*112|0);e=0;return e|0}function e9$(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[945572+(b*112|0)>>2];c[a+104>>2]=c[945576+(b*112|0)>>2];c[a+108>>2]=c[945580+(b*112|0)>>2];d=0;return d|0}function e90(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=945472+(b*112|0);e=0;return e|0}function e91(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1617044+(b*112|0)>>2];c[a+104>>2]=c[1617048+(b*112|0)>>2];c[a+108>>2]=c[1617052+(b*112|0)>>2];d=0;return d|0}function e92(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=1616944+(b*112|0);e=0;return e|0}function e93(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3154748+(b*112|0)>>2];c[a+104>>2]=c[3154752+(b*112|0)>>2];c[a+108>>2]=c[3154756+(b*112|0)>>2];d=0;return d|0}function e94(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=3154648+(b*112|0);e=0;return e|0}function e95(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3155656+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e96(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1618164+(b*112|0)>>2];c[a+104>>2]=c[1618168+(b*112|0)>>2];c[a+108>>2]=c[1618172+(b*112|0)>>2];d=0;return d|0}function e97(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=1618064+(b*112|0);e=0;return e|0}function e98(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4832428+(b*112|0)>>2];c[a+104>>2]=c[4832432+(b*112|0)>>2];c[a+108>>2]=c[4832436+(b*112|0)>>2];d=0;return d|0}function e99(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=4832328+(b*112|0);e=0;return e|0}function faa(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4833224+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fab(){c[2429684]=1;return e9L()|0}function fac(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3153588+(b*112|0)>>2];c[a+104>>2]=c[3153592+(b*112|0)>>2];c[a+108>>2]=c[3153596+(b*112|0)>>2];d=0;return d|0}function fad(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=3153488+(b*112|0);e=0;return e|0}function fae(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3154384+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function faf(){c[2429684]=2;return e9L()|0}function fag(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3148292+(b*112|0)>>2];c[a+104>>2]=c[3148296+(b*112|0)>>2];c[a+108>>2]=c[3148300+(b*112|0)>>2];d=0;return d|0}function fah(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=3148192+(b*112|0);e=0;return e|0}function fai(){c[2429684]=3;return e9L()|0}function faj(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3149188+(b*112|0)>>2];c[a+104>>2]=c[3149192+(b*112|0)>>2];c[a+108>>2]=c[3149196+(b*112|0)>>2];d=0;return d|0}function fak(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=3149088+(b*112|0);e=0;return e|0}function fal(){c[2429684]=4;return e9L()|0}function fam(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4830852+(b*112|0)>>2];c[a+104>>2]=c[4830856+(b*112|0)>>2];c[a+108>>2]=c[4830860+(b*112|0)>>2];d=0;return d|0}function fan(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=4830752+(b*112|0);e=0;return e|0}function fao(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4832096+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fap(){c[2429684]=5;return e9L()|0}function faq(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4491420+(b*112|0)>>2];c[a+104>>2]=c[4491424+(b*112|0)>>2];c[a+108>>2]=c[4491428+(b*112|0)>>2];d=0;return d|0}function far(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=4491320+(b*112|0);e=0;return e|0}function fas(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>24){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4492216+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fat(){c[2429684]=6;return e9L()|0}function fau(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3151092+(b*112|0)>>2];c[a+104>>2]=c[3151096+(b*112|0)>>2];c[a+108>>2]=c[3151100+(b*112|0)>>2];d=0;return d|0}function fav(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=3150992+(b*112|0);e=0;return e|0}function faw(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3138692+(b*112|0)>>2];c[a+104>>2]=c[3138696+(b*112|0)>>2];c[a+108>>2]=c[3138700+(b*112|0)>>2];d=0;return d|0}function fax(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=3138592+(b*112|0);e=0;return e|0}function fay(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3139488+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function faz(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2169428+(b*112|0)>>2];c[a+104>>2]=c[2169432+(b*112|0)>>2];c[a+108>>2]=c[2169436+(b*112|0)>>2];d=0;return d|0}function faA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=2169328+(b*112|0);e=0;return e|0}function faB(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1002184+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function faC(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=2170224+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function faD(){var b=0,d=0,e=0,f=0;c[2429684]=8;b=e9L()|0;if((b|0)!=0){return b|0}d=c[2385874]|0;e=0;do{f=d+e|0;a[f]=a[f]^-108;e=e+1|0;}while((e|0)<32768);return b|0}function faE(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7050060+(b*112|0)>>2];c[a+104>>2]=c[7050064+(b*112|0)>>2];c[a+108>>2]=c[7050068+(b*112|0)>>2];d=0;return d|0}function faF(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=7049960+(b*112|0);e=0;return e|0}function faG(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6276648+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function faH(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7205272+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function faI(){c[2429684]=7;return e9L()|0}function faJ(a,e){a=a|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e9P(a,e)|0;if((a&2|0)==0){return 0}a=c[2439330]|0;e=(a|0)==0;if(!e){f=a;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];f=c[3528484]|0;c[2076596]=f;g=c[2417276]|0;c[3541536]=g;c[1836236]=0;h=c[2385874]|0;i=((d[c[3528836]|0]|0)>>>4<<14&16384|32768)-32768|0;j=128;k=128;while(1){c[a+76+(k<<2)>>2]=h+(i+(k<<8));l=j+1&65535;if((l&65535)>191){m=128;n=128;break}else{j=l;k=l&65535}}while(1){k=h+(i+(n<<8))|0;c[a+76+(n+512<<2)>>2]=k;c[a+76+(n+768<<2)>>2]=k;k=m+1&65535;if((k&65535)>191){break}else{m=k;n=k&65535}}if(!e){e=a;gGC(e|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=f;c[2417276]=g;c[1836236]=-1;return 0}function faK(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0;a=c[(c[642608+(c[2436]<<2)>>2]|0)+124>>2]|0;if((a|0)<=0){return}b=a<<1;e=c[3530994]|0;f=c[3529916]|0;g=0;do{h=d[e+g|0]|0;i=d[e+(g+a)|0]|0;j=d[e+(g+b)|0]|0;c[f+(g<<2)>>2]=(-(i>>>1&1)&31)+(-(i&1)&14)+(-(i>>>2&1)&67)+(-(i>>>3&1)&143)<<3&2016|(-(h>>>1&1)&31)+(-(h&1)&14)+(-(h>>>2&1)&67)+(-(h>>>3&1)&143)<<8&63488|((-(j>>>1&1)&31)+(-(j&1)&14)+(-(j>>>2&1)&67)+(-(j>>>3&1)&143)|0)>>>3&31;g=g+1|0;}while((g|0)<(a|0));return}function faL(b){b=b|0;return a[9550240]|0}function faM(b){b=b|0;var d=0;b=a[9634784]|0;if((c[2429684]|0)!=8){d=b;return d|0}d=a[9550241]|b;return d|0}function faN(b){b=b|0;var d=0;d=a[9533784]|0;do{if((d&4)!=0){if((a[b]&4)!=0){break}if((a[8451504]&4)==0){break}c[2161344]=0;a[8451544]=a[9533352]|0}}while(0);do{if((d&8)!=0){if((a[b]&8)!=0){break}if((a[8451504]&8)==0){break}c[2161338]=1;a[9533344]=a[8451536]|0}}while(0);a[8451504]=a[b]|0;return}function faO(){a[9533792]=-1;a[8451520]=(a[c[2440372]|0]|0)!=0?a[9550243]|0:a[9550242]|0;return}function faP(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=a&255;a=d&16;e=a^16;if((e|0)!=(c[3528804]|0)){f=c[2433530]|0;g=c[2076596]|0;h=(c[2426530]|0)+f-g|0;i=c[1836236]|0;j=c[9757320+(i<<2)>>2]|0;if((j|0)!=0){k=j;gGC(k|0,9706056,76)|0}c[9752472+(i<<2)>>2]=f;c[14113936+(i<<2)>>2]=g;c[9669104+(i<<2)>>2]=c[3541536];c[1836236]=-1;i=c[2439331]|0;g=(i|0)==0;if(!g){f=i;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;f=c[3528485]|0;c[2076596]=f;k=c[2417277]|0;c[3541536]=k;c[1836236]=1;j=h+f-(c[2426530]|0)|0;c[2433530]=j;if((a|0)==0){gGz(9706056,0,76)}if(!g){g=i;gGC(g|0,9706056,76)|0}c[2438119]=j;c[3528485]=f;c[2417277]=k;c[1836236]=-1;k=c[2439330]|0;if((k|0)!=0){f=k;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0}c[3528804]=e;c[3528186]=d;e=d<<14&114688;if((d&6|0)==0){d=c[3529312]|0;f=c[9757320+(c[1836236]<<2)>>2]|0;k=e-32768|0;j=128;g=128;while(1){c[f+76+(g<<2)>>2]=d+(k+(g<<8));i=j+1&65535;if((i&65535)>191){l=128;m=128;break}else{j=i;g=i&65535}}while(1){c[f+76+(m+256<<2)>>2]=d+(k+(m<<8));g=l+1&65535;if((g&65535)>191){n=128;o=128;break}else{l=g;m=g&65535}}while(1){m=d+(k+(o<<8))|0;c[f+76+(o+512<<2)>>2]=m;c[f+76+(o+768<<2)>>2]=m;m=n+1&65535;if((m&65535)>191){break}else{n=m;o=m&65535}}return}else{o=c[3529224]|0;n=c[9757320+(c[1836236]<<2)>>2]|0;f=e+32768|0;e=128;k=128;while(1){c[n+76+(k<<2)>>2]=o+(f+(k<<8));d=e+1&65535;if((d&65535)>191){p=128;q=128;break}else{e=d;k=d&65535}}while(1){c[n+76+(q+256<<2)>>2]=o+((q<<8)+32768);k=p+1&65535;if((k&65535)>191){r=128;s=128;break}else{p=k;q=k&65535}}while(1){q=o+(f+(s<<8))|0;c[n+76+(s+512<<2)>>2]=q;c[n+76+(s+768<<2)>>2]=q;q=r+1&65535;if((q&65535)>191){break}else{r=q;s=q&65535}}return}}function faQ(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((e|0)==62976){faP(d);return}else if((e|0)==62464){a[c[2440188]|0]=d;return}else{if((e&65280|0)!=62208){return}a[(c[3530260]|0)+(e&3)|0]=d;return}}function faR(b){b=b|0;var d=0,e=0,f=0;d=b&65535;if((d&61440|0)!=57344){e=0;return e|0}f=c[3527294]|0;do{if(b<<16>>16==-4336){if((a[f+3856|0]|0)==-1){e=0}else{break}return e|0}}while(0);e=a[f+(d&4095)|0]|0;return e|0}function faS(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=d&65535;if((f|0)==45060){a[c[3528218]|0]=e;d=c[1836236]|0;g=c[9757320+(d<<2)>>2]|0;if((g|0)!=0){h=g;gGC(h|0,9706056,76)|0}c[9752472+(d<<2)>>2]=c[2433530];c[14113936+(d<<2)>>2]=c[2076596];c[9669104+(d<<2)>>2]=c[3541536];c[1836236]=-1;d=c[2439332]|0;h=(d|0)==0;if(!h){g=d;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;g=c[2438120]|0;c[2433530]=g;i=c[3528486]|0;c[2076596]=i;j=c[2417278]|0;c[3541536]=j;c[1836236]=2;a[14125144]=-1;a[9706117]=1;if(!h){h=d;gGC(h|0,9706056,76)|0}c[2438120]=g;c[3528486]=i;c[2417278]=j;c[1836236]=-1;j=c[2439331]|0;if((j|0)!=0){i=j;gGC(9706056,i|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;return}else if((f|0)==40960){f=e&255;c[3528187]=f&251;if((f&4|0)!=0){c[2432900]=3;c[2432902]=0;c[2444150]=16843009;a[14114256]=0;a[14114248]=0;a[9776584]=0;c[2438236]=0;c[2444148]=0;a[9731616]=12}a[c[2442886]|0]=e&48^48;e=c[3529180]|0;i=c[9757320+(c[1836236]<<2)>>2]|0;j=(f<<13&24576|32768)-32768|0;f=128;g=128;while(1){c[i+76+(g<<2)>>2]=e+(j+(g<<8));h=f+1&65535;if((h&65535)>159){k=128;l=128;break}else{f=h;g=h&65535}}while(1){g=e+(j+(l<<8))|0;c[i+76+(l+512<<2)>>2]=g;c[i+76+(l+768<<2)>>2]=g;g=k+1&65535;if((g&65535)>159){break}else{k=g;l=g&65535}}return}else{return}}function faT(b){b=b|0;var d=0,e=0;d=b&65535;L63469:do{switch(d|0){case 45059:{e=a[9634777]|0;break};case 45058:{e=a[9634776]|0;break};case 49152:case 49153:{e=a[9550232+(d&1)|0]|0;break};case 49154:{e=a[c[2442886]|0]|a[9550234];break};default:{if((b+4096&65535)>=4){e=0;break L63469}e=a[(c[2387124]|0)+(d&3)|0]|0}}}while(0);return e|0}function faU(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=b&65535;if((e|0)==45057){if((c[2394788]|0)==9){b=c[2113304]|0;a[14168504+b|0]=d;mv(0,b,d&255);return}else{lS(0,1,d);return}}else if((e|0)==40960){b=d&255;c[3528187]=b&251;if((b&4|0)!=0){c[2432900]=3;c[2432902]=0;c[2444150]=16843009;a[14114256]=0;a[14114248]=0;a[9776584]=0;c[2438236]=0;c[2444148]=0;a[9731616]=12}a[c[2442886]|0]=d&48^48;f=c[3529180]|0;g=c[9757320+(c[1836236]<<2)>>2]|0;h=(b<<13&24576|32768)-32768|0;b=128;i=128;while(1){c[g+76+(i<<2)>>2]=f+(h+(i<<8));j=b+1&65535;if((j&65535)>159){k=128;l=128;break}else{b=j;i=j&65535}}while(1){i=f+(h+(l<<8))|0;c[g+76+(l+512<<2)>>2]=i;c[g+76+(l+768<<2)>>2]=i;i=k+1&65535;if((i&65535)>159){break}else{k=i;l=i&65535}}return}else if((e|0)==49152|(e|0)==49153){l=d&255;k=c[2394788]|0;switch(k|0){case 2:{if((e&1|0)==0){if((c[2444148]|0)!=65){return}a[9776584]=(a[9776584]|0)+d&255;return}do{if((c[2432900]|0)!=0){g=c[2432902]|0;h=g+1|0;c[2432902]=h;a[9776600+g|0]=d;if((h|0)!=4){break}c[2432902]=0}}while(0);if((l|0)==193){c[2433584]=0}else if((l|0)==21){a[9776584]=(a[9776584]|0)-1&255}c[2444148]=l;return};case 4:{if((e&1|0)==0){if((c[2444148]|0)!=65){return}a[9776584]=(a[9776584]|0)+d&255;return}do{if((c[2432900]|0)!=0){h=c[2432902]|0;g=h+1|0;c[2432902]=g;a[9776600+h|0]=d;if((g|0)!=4){break}c[2432902]=0}}while(0);if(d<<24>>24==-109){c[2433584]=0}c[2444148]=l;return};case 1:case 3:case 6:case 5:{if((e&1|0)==0){if((c[2444148]|0)!=65){return}a[9776584]=(a[9776584]|0)+d&255;return}do{if((c[2432900]|0)!=0){g=c[2432902]|0;h=g+1|0;c[2432902]=h;a[9776600+g|0]=d;if((h|0)!=4){break}c[2432902]=0}}while(0);do{if((l|0)==161){c[2433584]=0}else if((l|0)==9){if(!((k|0)==5|(k|0)==3)){break}a[9776584]=(a[9776584]|0)-1&255}else if((l|0)==24){if(!((k|0)==5|(k|0)==3)){break}a[9776584]=(a[9776584]|0)-2&255}}while(0);c[2444148]=l;return};default:{return}}}else if((e|0)==45056){if((c[2394788]|0)==9){c[2113304]=d&255;return}e=c[3541518]|0;l=e+256|0;a[e+304|0]=d;k=d&255;if((d&255)<16){c[14168912+((c[2383582]|0)*252|0)>>2]=k&15}if((d-45&255)>=3){return}if((k|0)==45){d=e+312|0;h=a[d]|2;a[d]=h;m=h}else if((k|0)==46){h=e+312|0;d=a[h]|1;a[h]=d;m=d}else if((k|0)==47){a[e+312|0]=0;m=0}else if((k|0)==0){a[e+312|0]=2;m=2}else{m=a[e+312|0]|0}e=m&3;m=c[7461744+(e<<2)>>2]|0;lI(l,m,m,c[7461728+(e<<2)>>2]|0);return}else{return}}function faV(b){b=b|0;var e=0,f=0,g=0,i=0,j=0,k=0.0,l=0.0;e=b&65535;L63571:do{if((e|0)==61443){f=((c[2444135]|0)>>>20^15)&15}else if((e|0)==49152|(e|0)==49153){b=c[2394788]|0;switch(b|0){case 4:{if((e&1|0)!=0){g=c[2438236]|0;if((g&8|0)!=0){f=-31;break L63571}if((g&1|0)!=0){f=17;break L63571}if((g&2|0)!=0){f=33;break L63571}f=(g&4|0)==0?1:49;break L63571}g=c[2432900]|0;if((g|0)!=0){c[2432900]=g-1;f=a[533472+(3-g)|0]|0;break L63571}g=c[2444148]|0;if((g|0)==147){i=c[2433584]|0;if((i|0)==2){f=a[9550233]|0;break L63571}else if((i|0)==0){c[2433584]=1;if((c[2438236]&8|0)==0){f=a[9776584]|0;break L63571}else{c[2432900]=3;f=-18;break L63571}}else if((i|0)==1){c[2433584]=2;f=a[9550232]|0;break L63571}else{f=-1;break L63571}}else if((g|0)==65){f=a[9776584]|0;break L63571}else if((g|0)==3){f=a[9550234]&15;break L63571}else if((g|0)==31){f=(d[9550234]|0)>>>4^15;break L63571}else{f=-1;break L63571}break};case 1:case 3:case 6:case 5:{if((e&1|0)!=0){g=c[2438236]|0;if((g&8|0)!=0){f=-31;break L63571}i=(g&1|0)!=0;if((b|0)==6){if(i){f=49;break L63571}if((g&2|0)!=0){f=33;break L63571}if((g&4|0)!=0){f=17;break L63571}}else{if(i){f=17;break L63571}if((g&2|0)!=0){f=33;break L63571}if((g&4|0)!=0){f=49;break L63571}}f=1;break L63571}g=c[2432900]|0;if((g|0)!=0){c[2432900]=g-1;f=a[547616+(3-g)|0]|0;break L63571}switch(c[2444148]|0){case 26:{g=a[9550234]|0;if((b|0)==3){f=(g&255)>>>2^3;break L63571}else{f=(g&255)>>>4;break L63571}break};case 161:{if((c[2433584]|0)!=0){f=~(a[9550233]&15|a[9550232]&-16);break L63571}c[2433584]=1;if((c[2438236]&8|0)==0){f=a[9776584]|0;break L63571}else{c[2432900]=3;f=-18;break L63571}break};case 1:{f=~a[9550232];break L63571;break};case 2:{f=~a[9550233];break L63571;break};case 33:{f=a[9550234]&15;break L63571;break};case 65:{f=a[9776584]|0;break L63571;break};case 160:{if((c[2438236]&8|0)==0){f=a[9776584]|0;break L63571}else{c[2432900]=3;f=-18;break L63571}break};default:{f=-1;break L63571}}break};case 7:case 8:case 9:case 0:{f=a[(c[2077652]|0)+(e&1)|0]|0;break L63571;break};case 2:{if((e&1|0)!=0){g=c[2438236]|0;if((g&8|0)!=0){f=-31;break L63571}if((g&1|0)!=0){f=17;break L63571}if((g&2|0)!=0){f=33;break L63571}f=(g&4|0)==0?1:49;break L63571}g=c[2432900]|0;if((g|0)!=0){c[2432900]=g-1;f=a[519880+(3-g)|0]|0;break L63571}g=c[2444148]|0;if((g|0)==65){f=a[9776584]|0;break L63571}else if((g|0)!=193){f=-1;break L63571}if((c[2433584]|0)!=0){f=a[9550232]|0;break L63571}c[2433584]=1;if((c[2438236]&8|0)==0){f=a[9776584]|0;break L63571}else{c[2432900]=3;f=-18;break L63571}break};default:{f=-1;break L63571}}}else if((e|0)==45057){if((c[2394788]|0)==9){f=c[(c[3531464]|0)+4240>>2]&255;break}if((d[(c[3541518]|0)+304|0]|0)>=16){f=0;break}g=c[2383582]|0;b=c[14168912+(g*252|0)>>2]|0;if((b|0)>15){f=0;break}do{if((b|0)==14){i=c[14168896+(g*252|0)>>2]|0;if((i|0)==0){break}a[14168930+(g*252|0)|0]=gj[i&4095](0)|0}else if((b|0)==15){i=c[14168900+(g*252|0)>>2]|0;if((i|0)==0){break}a[14168931+(g*252|0)|0]=gj[i&4095](0)|0}}while(0);f=a[14168916+(g*252|0)+b|0]|0}else if((e|0)==45056){if((c[2394788]|0)==9){f=0;break}i=c[3541518]|0;j=i+296|0;k=+h[j>>3];do{if(k!=0.0){l=+h[6675];if(k-(l+ +gC[c[2429842]&255]())>0.0){f=a[i+307|0]|-128;break L63571}else{h[j>>3]=0.0;break}}}while(0);f=a[i+307|0]|0}else if((e|0)==50688){f=a[9634776]|0}else if((e|0)==61441){f=((c[2444134]|0)>>>20^15)&15}else if((e|0)==61442){f=((c[2444135]|0)>>>12^255)&255}else if((e|0)==50689){f=a[9634777]|0}else if((e|0)==61440){f=((c[2444134]|0)>>>12^255)&255}else if((e|0)==49154){f=a[9550234]|0}else{f=0}}while(0);return f|0}function faW(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=b&255;if((e|0)==1){lS(0,1,d);return}else if((e|0)==0){e=c[3541518]|0;b=e+256|0;a[e+304|0]=d;f=d&255;if((d&255)<16){c[14168912+((c[2383582]|0)*252|0)>>2]=f&15}if((d-45&255)>=3){return}if((f|0)==45){d=e+312|0;g=a[d]|2;a[d]=g;h=g}else if((f|0)==46){g=e+312|0;d=a[g]|1;a[g]=d;h=d}else if((f|0)==47){a[e+312|0]=0;h=0}else if((f|0)==0){a[e+312|0]=2;h=2}else{h=a[e+312|0]|0}e=h&3;h=c[7461744+(e<<2)>>2]|0;lI(b,h,h,c[7461728+(e<<2)>>2]|0);return}else{return}}function faX(b){b=b|0;var d=0,e=0,f=0.0,g=0.0;d=b&255;if((d|0)==2){a[9706117]=0;e=a[c[3528218]|0]|0;return e|0}else if((d|0)==0){d=c[3541518]|0;b=d+296|0;f=+h[b>>3];do{if(f!=0.0){g=+h[6675];if(f-(g+ +gC[c[2429842]&255]())<=0.0){h[b>>3]=0.0;break}e=a[d+307|0]|-128;return e|0}}while(0);e=a[d+307|0]|0;return e|0}else{e=0;return e|0}return 0}function faY(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2449092+(b*112|0)>>2];c[a+104>>2]=c[2449096+(b*112|0)>>2];c[a+108>>2]=c[2449100+(b*112|0)>>2];d=0;return d|0}function faZ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=2448992+(b*112|0);e=0;return e|0}function fa_(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1215504+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function fa$(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>41){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3618896+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fa0(){return fce(5)|0}function fa1(){var b=0,d=0,e=0,f=0,g=0,h=0;c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}fwZ();if((c[2394788]|0)==9){d=48811}else{b=c[3541518]|0;if((b|0)!=0){gGr(b|0);c[3541518]=0}if((c[2385508]|0)>0){c[2113008]=0;c[2076598]=0;c[2383582]=0}c[2438228]=0;c[2433526]=0;c[2406676]=0;c[3528472]=0;b=c[2406680]|0;if((b|0)!=0){gGr(b);c[2406680]=0}c[2385508]=0;c[2432978]=0;a[64240]=0;if((c[2394788]|0)==9){d=48811}}do{if((d|0)==48811){b=c[3531464]|0;c[b+44344>>2]=0;c[b+44348>>2]=0;if((b|0)!=0){gGr(b);c[3531464]=0}b=c[2406684]|0;if((b|0)==0){break}gGr(b);c[2406684]=0}}while(0);UT();b=c[2414882]|0;e=0;while(1){if((e|0)>=1024){break}f=9638528+(e<<2)|0;if((c[f>>2]|0)==(b|0)){d=48818;break}else{e=e+1|0}}if((d|0)==48818){gGr(b);c[f>>2]=0}c[2414882]=0;if((c[2394788]|0)==8){g=0}else{c[2432900]=3;c[2432902]=0;c[2444150]=16843009;a[14114256]=0;a[14114248]=0;a[9776584]=0;c[2438236]=0;c[2444148]=0;a[9731616]=12;c[2394788]=0;return 0}do{f=9719832+(g<<2)|0;b=c[f>>2]|0;e=0;while(1){if((e|0)>=1024){break}h=9638528+(e<<2)|0;if((c[h>>2]|0)==(b|0)){d=48823;break}else{e=e+1|0}}if((d|0)==48823){d=0;gGr(b);c[h>>2]=0}c[f>>2]=0;g=g+1|0;}while((g|0)<48);c[2432900]=3;c[2432902]=0;c[2444150]=16843009;a[14114256]=0;a[14114248]=0;a[9776584]=0;c[2438236]=0;c[2444148]=0;a[9731616]=12;c[2394788]=0;return 0}function fa2(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;if((a[9623672]|0)!=0){fcm()}f=c[2385548]|0;if((f|0)>0){gGz(9752472,0,((f|0)>1?f<<2:4)|0)}c[2433530]=0;c[2077652]=9550232;gGz(9550232,-1|0,3);f=0;g=-1;h=-1;i=-1;do{g=(d[9632704+f|0]<<f^g&255)&255;h=(d[9630600+f|0]<<f^h&255)&255;i=(d[9629272+f|0]<<f^i&255)&255;f=f+1|0;}while((f|0)<8);a[9550232]=g;a[9550233]=h;a[9550234]=i;c[2444134]=(c[2444134]|0)-(e[4817900]<<7);c[2444135]=(c[2444135]|0)-(e[4817901]<<7);i=(c[2394788]|0)==8?a[9688]|0?534:0:100;h=i-2|0;g=i-1|0;f=0;j=0;k=0;l=0;L63793:while(1){m=j;n=k;o=l;while(1){if((m|0)>=(i|0)){break L63793}p=c[2439330]|0;if((p|0)!=0){q=p;gGC(9706056,q|0,76)|0}b[4853030]=c[2426515]&65535;q=c[2438118]|0;c[2433530]=q;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;r=m+1|0;s=(r*1e5|0|0)/(i|0)|0;t=s-n|0;do{if((t|0)<1){u=0}else{if((a[p+4188|0]|0)==0){v=gfc(t)|0;c[2433530]=(c[2433530]|0)+v;u=v;break}else{c[2433530]=q+t;u=t;break}}}while(0);w=u+n|0;t=(m|0)==(h|0);if(t){switch(c[2394788]|0){case 2:{q=d[9550233]^240;p=q>>>4;eX6((q>>>6&1|p&8|p<<1&6)&d[9731616]);break};case 1:case 3:case 5:case 4:case 6:{p=~d[9550234];eX6((p>>>4&3|p<<2&12)&d[9731616]);break};default:{}}a[9706117]=1}p=(m|0)==(g|0);if(p){a[9706117]=0}q=c[1836236]|0;v=c[9757320+(q<<2)>>2]|0;if((v|0)!=0){x=v;gGC(x|0,9706056,76)|0}c[9752472+(q<<2)>>2]=c[2433530];c[14113936+(q<<2)>>2]=c[2076596];c[9669104+(q<<2)>>2]=c[3541536];c[1836236]=-1;q=c[2439331]|0;if((q|0)!=0){x=q;gGC(9706056,x|0,76)|0}b[4853030]=c[2426515]&65535;x=c[2438119]|0;c[2433530]=x;c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;if((c[3528804]|0)==0){v=s-o|0;do{if((v|0)<1){y=0;z=x}else{if((a[q+4188|0]|0)==0){A=gfc(v)|0;B=(c[2433530]|0)+A|0;c[2433530]=B;y=A;z=B;break}else{B=x+v|0;c[2433530]=B;y=v;z=B;break}}}while(0);C=y+o|0;D=z}else{C=s;D=x}if(t){a[9706117]=1}if(p){a[9706117]=0}v=c[1836236]|0;q=c[9757320+(v<<2)>>2]|0;if((q|0)!=0){B=q;gGC(B|0,9706056,76)|0}c[9752472+(v<<2)>>2]=D;c[14113936+(v<<2)>>2]=c[2076596];c[9669104+(v<<2)>>2]=c[3541536];c[1836236]=-1;if((c[2394788]|0)==0){v=c[2439332]|0;if((v|0)!=0){B=v;gGC(9706056,B|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438120];c[2076596]=c[3528486];c[3541536]=c[2417278];c[1836236]=2;Sb(ag(1e5/(i>>>0)|0,m)|0);B=c[1836236]|0;v=c[9757320+(B<<2)>>2]|0;if((v|0)!=0){q=v;gGC(q|0,9706056,76)|0}c[9752472+(B<<2)>>2]=c[2433530];c[14113936+(B<<2)>>2]=c[2076596];c[9669104+(B<<2)>>2]=c[3541536];c[1836236]=-1}E=c[2112964]|0;if((E|0)==0){m=r;n=w;o=C}else{break}}o=((a[9688]|0?534:0)>>>0)/(i>>>0)|0;n=f<<1;m=(c[2442958]|0)+(n<<1)|0;B=c[2439332]|0;if((B|0)!=0){q=B;gGC(9706056,q|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438120];c[2076596]=c[3528486];c[3541536]=c[2417278];c[1836236]=2;if((c[2394788]|0)==9){gg[c[3542124]&4095](E+(n<<1)|0,o);n=c[1836236]|0;F=n;G=c[9757320+(n<<2)>>2]|0}else{F=2;G=B}fcr(m,o);if((G|0)!=0){m=G;gGC(m|0,9706056,76)|0}c[9752472+(F<<2)>>2]=c[2433530];c[14113936+(F<<2)>>2]=c[2076596];c[9669104+(F<<2)>>2]=c[3541536];c[1836236]=-1;f=o+f|0;j=r;k=w;l=C}C=c[2439332]|0;if((C|0)!=0){l=C;gGC(9706056,l|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438120];c[2076596]=c[3528486];c[3541536]=c[2417278];c[1836236]=2;if((c[2394788]|0)==0){l=c[2438228]|0;C=gGS(-1220542464,47683,l,(l|0)<0|0?-1:0)|0;l=C;Sb(1e5);C=c[2443830]|0;if((C|0)<1073676288){c[2443830]=C-l}C=c[2443831]|0;if((C|0)<1073676288){c[2443831]=C-l}C=(c[3528512]|0)-l|0;c[3528512]=(C|0)<0?0:C}C=c[2112964]|0;do{if((C|0)!=0){l=a[9688]|0?534:0;w=l-f|0;k=f<<1;r=C+(k<<1)|0;j=(c[2442958]|0)+(k<<1)|0;if((l|0)==(f|0)){H=C}else{if((c[2394788]|0)==9){gg[c[3542124]&4095](r,w);I=c[2112964]|0}else{I=C}fcr(j,w);H=I}if(!((c[2394788]|0)!=9&(H|0)!=0)){break}gg[c[3542122]&4095](H,a[9688]|0?534:0);UR(c[2112964]|0,a[9688]|0?534:0);if(!(a[9688]|0)){break}w=c[2442958]|0;j=c[2112964]|0;r=0;do{l=r<<1;k=j+(l<<1)|0;b[k>>1]=(b[k>>1]|0)+(b[w+(l<<1)>>1]|0)&65535;k=l|1;l=j+(k<<1)|0;b[l>>1]=(b[l>>1]|0)+(b[w+(k<<1)>>1]|0)&65535;r=r+1|0;}while((r|0)<534)}}while(0);H=c[1836236]|0;I=c[9757320+(H<<2)>>2]|0;if((I|0)!=0){C=I;gGC(C|0,9706056,76)|0}c[9752472+(H<<2)>>2]=c[2433530];c[14113936+(H<<2)>>2]=c[2076596];c[9669104+(H<<2)>>2]=c[3541536];c[1836236]=-1;if((c[2112968]|0)==0){return 0}fa3()|0;return 0}function fa3(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;e=c[2387124]|0;f=c[3529914]|0;if((c[2394788]|0)==9){g=0;while(1){h=a[e+g|0]|0;i=(d[e+(g|1)|0]|0)>>>4;j=(h&255)>>>4;c[f+(((g|0)/2|0)<<2)>>2]=((j<<4|j)&255)<<3&2016|((h&8|h<<4)&255)>>>3|((i<<4|i)&255)<<8&63488;i=g+2|0;if((i|0)<1024){g=i}else{k=f;break}}}else{g=0;while(1){i=a[e+(g|1)|0]|0;h=a[e+g|0]|0;c[f+(((g|0)/2|0)<<2)>>2]=(h<<3&255)>>>3|((i&255)>>>2<<3&255)<<8|(((((i&255)<<8|h&255)&65535)>>>5<<3&255|i<<1&4)&255)<<3&2016;i=g+2|0;if((i|0)<1024){g=i}else{k=f;break}}}f=c[3530260]|0;g=a[f]&64;e=f+1|0;i=a[e]|0;h=i&96^32;j=c[2113068]|0;l=c[2113070]|0;m=ag(l,j)|0;if((m|0)>0){n=c[2112926]|0;o=0;do{b[n+(o<<1)>>1]=496;o=o+1|0;}while((o|0)<(m|0));p=a[e]|0}else{p=i}i=c[2386398]|0;e=i+1024|0;m=((h<<1^h)&64|0)==0;o=i+3072|0;n=m?e:o;q=a[c[2440188]|0]&128^128;r=p&31;p=(r|0)==1?16:r;L63906:do{if((p|0)!=0){r=(g|0)!=0;s=c[2443466]|0;t=(d[f+3|0]|0)<<8|(d[f+2|0]|0);u=0;while(1){v=u<<4;w=(d[s+(v|4)|0]|0)-(t<<8&256)|0;x=d[s+v|0]|0;v=r?x:-x|0;x=v+1|0;y=u<<5^256;z=v+241|0;v=(w|0)<-15;A=w+16|0;B=(A|0)<-15;C=0;do{D=C<<1|y;E=C<<4;F=d[n+(D+4096)|0]|0;G=F<<8&16128|(d[n+D|0]|0);H=(d[n+(D+4608)|0]|0)>>>3;do{if(r){I=F>>>7^1;J=F>>>6&1^1;K=z-E&255;do{if(!((w|0)>=(j|0)|v)){if((K|0)>=(l+16|0)|(K|0)==0){break}fcq(w,K-16|0,G,H,I,J,q)}}while(0);J=D|1;I=d[n+(J+4096)|0]|0;if((A|0)>=(j|0)|B){break}if((K|0)>=(l+16|0)|(K|0)==0){break}fcq(A,K-16|0,I<<8&16128|(d[n+J|0]|0),(d[n+(J+4608)|0]|0)>>>3,I>>>7^1,I>>>6&1^1,q)}else{I=F&128;J=F&64;L=x+E&255;do{if(!((w|0)>=(j|0)|v)){if((L|0)>=(l+16|0)|(L|0)==0){break}fcq(w,L-16|0,G,H,I,J,q)}}while(0);J=D|1;I=d[n+(J+4096)|0]|0;if((A|0)>=(j|0)|B){break}if((L|0)>=(l+16|0)|(L|0)==0){break}fcq(A,L-16|0,I<<8&16128|(d[n+J|0]|0),(d[n+(J+4608)|0]|0)>>>3,I&128,I&64,q)}}while(0);C=C+1|0;}while((C|0)<16);C=u+1|0;if((C|0)>=(p|0)){break L63906}t=t>>>1;u=C}}}while(0);p=c[2386190]|0;q=i+4096|0;if(m){M=i;N=i+512|0;O=q;P=i+4608|0}else{M=i+2048|0;N=i+2560|0;O=i+6144|0;P=i+6656|0}L63934:do{if((g|0)==0){m=511;while(1){n=d[O+m|0]|0;l=d[P+m|0]|0;f=(d[N+m|0]|0)-(l<<8&256)|0;if(!((f|0)>=(j|0)|(f|0)<-15)){fcq(f,226-(d[p+m|0]|0)|0,d[M+m|0]|0|n<<8&16128,l>>>3,n&128,n&64,1)}if((m|0)<=0){break L63934}m=m-1|0}}else{m=511;while(1){n=d[O+m|0]|0;l=n<<8&16128|(d[M+m|0]|0);f=d[P+m|0]|0;u=(d[N+m|0]|0)-(f<<8&256)|0;t=a[p+m|0]|0;r=t&255;if(!((u|0)>=(j|0)|(u|0)<-15)){fcq(u,(t<<24>>24==0&(l|0)==0?r+240|0:r)-14|0,l,f>>>3,n>>>7^1,n>>>6&1^1,1)}if((m|0)<=0){break L63934}m=m-1|0}}}while(0);R8(k);if((h&32|0)==0){return 0}k=i+2048|0;if((h&64|0)==0){gGC(k|0,i|0,1024)|0;h=i+6144|0;gGC(h|0,q|0,1024)|0}else{gGC(i|0,k|0,1024)|0;k=i+6144|0;gGC(q|0,k|0,1024)|0}gGC(e|0,o|0,1024)|0;o=i+5120|0;e=i+7168|0;gGC(o|0,e|0,1024)|0;return 0}function fa4(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;g=i;i=i+400|0;h=g|0;j=g+16|0;k=g+32|0;l=g+48|0;m=g+64|0;n=g+80|0;o=g+96|0;p=g+112|0;q=g+128|0;r=g+144|0;s=g+160|0;t=g+176|0;u=g+192|0;v=g+208|0;w=g+224|0;x=g+240|0;y=g+256|0;z=g+272|0;A=g+288|0;B=g+304|0;C=g+320|0;D=g+336|0;E=g+352|0;F=g+368|0;G=g+384|0;H=(f|0)==0;if(!H){c[f>>2]=169735}if((e&96|0)!=0){I=c[2414584]|0;c[G>>2]=I;c[G+4>>2]=(c[2411528]|0)-I;c[G+12>>2]=162152;I=c[2076592]|0;gj[I&4095](G)|0;fw$(e);Vx(e,f);G=e&64;do{if((G|0)!=0){gGz(w|0,0,12);c[w>>2]=8453216;c[w+4>>2]=4;c[w+12>>2]=107480;I=c[2076592]|0;gj[I&4095](w)|0;gGz(v|0,0,12);c[v>>2]=14168504;c[v+4>>2]=256;c[v+12>>2]=476464;I=c[2076592]|0;gj[I&4095](v)|0;if((e&2|0)==0){break}else{J=0}do{mv(0,J,d[14168504+J|0]|0);J=J+1|0;}while((J|0)<256)}}while(0);if(!H){c[f>>2]=169753}if((G|0)!=0&(c[2405758]|0)>0){G=u;f=u|0;H=u+4|0;J=u+12|0;v=0;do{gGz(G|0,0,12);c[f>>2]=9542544+(v<<5);c[H>>2]=2;c[J>>2]=119040;gj[c[2076592]&4095](u)|0;v=v+1|0;}while((v|0)<(c[2405758]|0))}gGz(t|0,0,12);c[t>>2]=9731600;c[t+4>>2]=4;c[t+12>>2]=200512;v=c[2076592]|0;gj[v&4095](t)|0;gGz(s|0,0,12);c[s>>2]=9731608;c[s+4>>2]=4;c[s+12>>2]=511944;t=c[2076592]|0;gj[t&4095](s)|0;gGz(r|0,0,12);c[r>>2]=9776600;c[r+4>>2]=1;c[r+12>>2]=396032;s=c[2076592]|0;gj[s&4095](r)|0;gGz(q|0,0,12);c[q>>2]=9776601;c[q+4>>2]=1;c[q+12>>2]=307064;r=c[2076592]|0;gj[r&4095](q)|0;gGz(p|0,0,12);c[p>>2]=9776602;c[p+4>>2]=1;c[p+12>>2]=234256;q=c[2076592]|0;gj[q&4095](p)|0;gGz(o|0,0,12);c[o>>2]=9776603;c[o+4>>2]=1;c[o+12>>2]=182520;p=c[2076592]|0;gj[p&4095](o)|0;gGz(n|0,0,12);c[n>>2]=14114256;c[n+4>>2]=1;c[n+12>>2]=147368;o=c[2076592]|0;gj[o&4095](n)|0;gGz(m|0,0,12);c[m>>2]=14114248;c[m+4>>2]=1;c[m+12>>2]=117744;n=c[2076592]|0;gj[n&4095](m)|0;gGz(l|0,0,12);c[l>>2]=9776584;c[l+4>>2]=1;c[l+12>>2]=92744;m=c[2076592]|0;gj[m&4095](l)|0;gGz(k|0,0,12);c[k>>2]=9752944;c[k+4>>2]=4;c[k+12>>2]=72832;l=c[2076592]|0;gj[l&4095](k)|0;gGz(j|0,0,12);c[j>>2]=9776592;c[j+4>>2]=4;c[j+12>>2]=580280;k=c[2076592]|0;gj[k&4095](j)|0;gGz(h|0,0,12);c[h>>2]=9731616;c[h+4>>2]=1;c[h+12>>2]=563392;j=c[2076592]|0;gj[j&4095](h)|0;gGz(F|0,0,12);c[F>>2]=14112744;c[F+4>>2]=4;c[F+12>>2]=478312;h=c[2076592]|0;gj[h&4095](F)|0;gGz(E|0,0,12);c[E>>2]=14112748;c[E+4>>2]=4;c[E+12>>2]=477408;F=c[2076592]|0;gj[F&4095](E)|0;gGz(D|0,0,12);c[D>>2]=14112752;c[D+4>>2]=4;c[D+12>>2]=476192;E=c[2076592]|0;gj[E&4095](D)|0;gGz(C|0,0,12);c[C>>2]=14115216;c[C+4>>2]=4;c[C+12>>2]=475112;D=c[2076592]|0;gj[D&4095](C)|0;gGz(B|0,0,12);c[B>>2]=9776536;c[B+4>>2]=4;c[B+12>>2]=473856;C=c[2076592]|0;gj[C&4095](B)|0;gGz(A|0,0,12);c[A>>2]=9776540;c[A+4>>2]=4;c[A+12>>2]=472176;B=c[2076592]|0;gj[B&4095](A)|0;gGz(z|0,0,12);c[z>>2]=9721880;c[z+4>>2]=4;c[z+12>>2]=470824;A=c[2076592]|0;gj[A&4095](z)|0;gGz(y|0,0,12);c[y>>2]=1091232;c[y+4>>2]=8;c[y+12>>2]=469208;z=c[2076592]|0;gj[z&4095](y)|0;gGz(x|0,0,12);c[x>>2]=9717568;c[x+4>>2]=4;c[x+12>>2]=468064;y=c[2076592]|0;gj[y&4095](x)|0}if((e&2|0)==0){i=g;return 0}e=c[2439330]|0;if((e|0)!=0){x=e;gGC(9706056,x|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;faP(c[3528186]&255);x=c[1836236]|0;e=c[9757320+(x<<2)>>2]|0;if((e|0)!=0){y=e;gGC(y|0,9706056,76)|0}c[9752472+(x<<2)>>2]=c[2433530];c[14113936+(x<<2)>>2]=c[2076596];c[9669104+(x<<2)>>2]=c[3541536];c[1836236]=-1;x=c[2439331]|0;y=(x|0)==0;if(!y){e=x;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];e=c[3528485]|0;c[2076596]=e;z=c[2417277]|0;c[3541536]=z;c[1836236]=1;A=c[3528187]|0;c[3528187]=A&251;if((A&4|0)!=0){c[2432900]=3;c[2432902]=0;c[2444150]=16843009;a[14114256]=0;a[14114248]=0;a[9776584]=0;c[2438236]=0;c[2444148]=0;a[9731616]=12}a[c[2442886]|0]=A&48^48;B=c[3529180]|0;C=(A<<13&24576|32768)-32768|0;A=128;D=128;while(1){c[x+76+(D<<2)>>2]=B+(C+(D<<8));E=A+1&65535;if((E&65535)>159){K=128;L=128;break}else{A=E;D=E&65535}}while(1){D=B+(C+(L<<8))|0;c[x+76+(L+512<<2)>>2]=D;c[x+76+(L+768<<2)>>2]=D;D=K+1&65535;if((D&65535)>159){break}else{K=D;L=D&65535}}if(!y){y=x;gGC(y|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=e;c[2417277]=z;c[1836236]=-1;z=c[2439332]|0;e=(z|0)==0;if(!e){y=z;gGC(9706056,y|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438120];y=c[3528486]|0;c[2076596]=y;x=c[2417278]|0;c[3541536]=x;c[1836236]=2;L=c[3528188]|0;if((L|0)!=255){c[3528188]=L;K=c[3529166]|0;C=(L<<14&114688)-32768|0;L=128;B=128;while(1){c[z+76+(B<<2)>>2]=K+(C+(B<<8));D=L+1&65535;if((D&65535)>191){M=128;N=128;break}else{L=D;B=D&65535}}while(1){B=K+(C+(N<<8))|0;c[z+76+(N+512<<2)>>2]=B;c[z+76+(N+768<<2)>>2]=B;B=M+1&65535;if((B&65535)>191){break}else{M=B;N=B&65535}}}if(!e){e=z;gGC(e|0,9706056,76)|0}c[2438120]=c[2433530];c[3528486]=y;c[2417278]=x;c[1836236]=-1;i=g;return 0}function fa5(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2875060+(b*112|0)>>2];c[a+104>>2]=c[2875064+(b*112|0)>>2];c[a+108>>2]=c[2875068+(b*112|0)>>2];d=0;return d|0}function fa6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=2874960+(b*112|0);e=0;return e|0}function fa7(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4153968+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function fa8(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>30){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3997248+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fa9(){return fce(1)|0}function fba(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2873940+(b*112|0)>>2];c[a+104>>2]=c[2873944+(b*112|0)>>2];c[a+108>>2]=c[2873948+(b*112|0)>>2];d=0;return d|0}function fbb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=2873840+(b*112|0);e=0;return e|0}function fbc(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2876180+(b*112|0)>>2];c[a+104>>2]=c[2876184+(b*112|0)>>2];c[a+108>>2]=c[2876188+(b*112|0)>>2];d=0;return d|0}function fbd(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=2876080+(b*112|0);e=0;return e|0}function fbe(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3143140+(b*112|0)>>2];c[a+104>>2]=c[3143144+(b*112|0)>>2];c[a+108>>2]=c[3143148+(b*112|0)>>2];d=0;return d|0}function fbf(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=3143040+(b*112|0);e=0;return e|0}function fbg(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1314984+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function fbh(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>41){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4275064+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fbi(){return fce(2)|0}function fbj(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3144148+(b*112|0)>>2];c[a+104>>2]=c[3144152+(b*112|0)>>2];c[a+108>>2]=c[3144156+(b*112|0)>>2];d=0;return d|0}function fbk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=3144048+(b*112|0);e=0;return e|0}function fbl(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>41){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4275568+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fbm(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3145156+(b*112|0)>>2];c[a+104>>2]=c[3145160+(b*112|0)>>2];c[a+108>>2]=c[3145164+(b*112|0)>>2];d=0;return d|0}function fbn(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=3145056+(b*112|0);e=0;return e|0}function fbo(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3146164+(b*112|0)>>2];c[a+104>>2]=c[3146168+(b*112|0)>>2];c[a+108>>2]=c[3146172+(b*112|0)>>2];d=0;return d|0}function fbp(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=3146064+(b*112|0);e=0;return e|0}function fbq(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2911804+(b*112|0)>>2];c[a+104>>2]=c[2911808+(b*112|0)>>2];c[a+108>>2]=c[2911812+(b*112|0)>>2];d=0;return d|0}function fbr(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=2911704+(b*112|0);e=0;return e|0}function fbs(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>38){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=404e4+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fbt(){return fce(3)|0}function fbu(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2908668+(b*112|0)>>2];c[a+104>>2]=c[2908672+(b*112|0)>>2];c[a+108>>2]=c[2908676+(b*112|0)>>2];d=0;return d|0}function fbv(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=2908568+(b*112|0);e=0;return e|0}function fbw(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>38){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4039528+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fbx(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2910236+(b*112|0)>>2];c[a+104>>2]=c[2910240+(b*112|0)>>2];c[a+108>>2]=c[2910244+(b*112|0)>>2];d=0;return d|0}function fby(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=2910136+(b*112|0);e=0;return e|0}function fbz(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5836828+(b*112|0)>>2];c[a+104>>2]=c[5836832+(b*112|0)>>2];c[a+108>>2]=c[5836836+(b*112|0)>>2];d=0;return d|0}function fbA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=5836728+(b*112|0);e=0;return e|0}function fbB(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>31){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6270144+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fbC(){return fce(8)|0}function fbD(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4631420+(b*112|0)>>2];c[a+104>>2]=c[4631424+(b*112|0)>>2];c[a+108>>2]=c[4631428+(b*112|0)>>2];d=0;return d|0}function fbE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=4631320+(b*112|0);e=0;return e|0}function fbF(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4632764+(b*112|0)>>2];c[a+104>>2]=c[4632768+(b*112|0)>>2];c[a+108>>2]=c[4632772+(b*112|0)>>2];d=0;return d|0}function fbG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=4632664+(b*112|0);e=0;return e|0}function fbH(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3014500+(b*112|0)>>2];c[a+104>>2]=c[3014504+(b*112|0)>>2];c[a+108>>2]=c[3014508+(b*112|0)>>2];d=0;return d|0}function fbI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=3014400+(b*112|0);e=0;return e|0}function fbJ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>38){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4159432+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fbK(){return fce(4)|0}function fbL(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3011812+(b*112|0)>>2];c[a+104>>2]=c[3011816+(b*112|0)>>2];c[a+108>>2]=c[3011820+(b*112|0)>>2];d=0;return d|0}function fbM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=3011712+(b*112|0);e=0;return e|0}function fbN(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>38){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4158960+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fbO(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3013156+(b*112|0)>>2];c[a+104>>2]=c[3013160+(b*112|0)>>2];c[a+108>>2]=c[3013164+(b*112|0)>>2];d=0;return d|0}function fbP(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=3013056+(b*112|0);e=0;return e|0}function fbQ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6990332+(b*112|0)>>2];c[a+104>>2]=c[6990336+(b*112|0)>>2];c[a+108>>2]=c[6990340+(b*112|0)>>2];d=0;return d|0}function fbR(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=6990232+(b*112|0);e=0;return e|0}function fbS(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>38){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7111968+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fbT(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0;e=i;i=i+1680|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;B=e+1200|0;C=e+1312|0;D=e+1320|0;E=e+1432|0;F=e+1440|0;G=e+1552|0;H=e+1560|0;I=e+1672|0;c[2414882]=0;c[3529224]=0;c[3529180]=262144;c[3529166]=393216;c[2387808]=524288;c[3530992]=4718592;c[2386602]=4719616;c[3529914]=4785152;c[2442958]=4787200;J=a[9688]|0?2136:0;K=J+4787200|0;c[2414584]=K;c[3530260]=K;c[2387124]=J+4787204;c[2386398]=J|4788228;c[3527294]=J|4796420;c[2443466]=J|4800516;c[2386190]=J|4800772;c[3529312]=J|4801284;c[3529274]=J|4834052;c[3529266]=J|4838148;c[2442886]=J|4846340;c[3528218]=J|4846341;c[2440188]=J|4846342;K=J|4846343|0;c[2411528]=K;c[2414068]=K;J=K;K=0;while(1){if((K|0)>=1024){break}L=9638528+(K<<2)|0;if((c[L>>2]|0)==0){M=49276;break}else{K=K+1|0}}do{if((M|0)==49276){K=gGq(J)|0;c[L>>2]=K;if((K|0)==0){break}gGz(K|0,0,J|0);c[2414882]=K;gGz(K|0,0,J|0);c[3529224]=K;c[3529180]=K+262144;c[3529166]=K+393216;c[2387808]=K+524288;c[3530992]=K+4718592;c[2386602]=K+4719616;c[3529914]=K+4785152;c[2442958]=K+4787200;N=a[9688]|0?2136:0;O=K+(N+4787200)|0;c[2414584]=O;c[3530260]=O;c[2387124]=K+(N+4787204);c[2386398]=K+(N|4788228);c[3527294]=K+(N|4796420);c[2443466]=K+(N|4800516);c[2386190]=K+(N|4800772);c[3529312]=K+(N|4801284);c[3529274]=K+(N|4834052);c[3529266]=K+(N|4838148);c[2442886]=K+(N|4846340);c[3528218]=K+(N|4846341);c[2440188]=K+(N|4846342);O=K+(N|4846343)|0;c[2411528]=O;c[2414068]=O;O=K+65536|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}K=H+108|0;c[K>>2]=0;N=H+100|0;c[N>>2]=0;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Q&16383](H,0)|0;do{if((c[K>>2]|0)!=0){Q=c[N>>2]|0;c[I>>2]=9534384;R=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[R&16383](I,0,0)|0;if((Q|0)<1){P=1;i=e;return P|0}if((gzL(O,0,0)|0)==0){break}else{P=1}i=e;return P|0}}while(0);O=c[3529224]|0;N=O+65536|0;gGC(O|0,N|0,32768)|0;N=c[3529180]|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}O=F+108|0;c[O>>2]=0;K=F+100|0;c[K>>2]=0;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Q&16383](F,1)|0;do{if((c[O>>2]|0)!=0){Q=c[K>>2]|0;c[G>>2]=9534384;R=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[R&16383](G,1,0)|0;if((Q|0)<1){P=1;i=e;return P|0}if((gzL(N,0,1)|0)==0){break}else{P=1}i=e;return P|0}}while(0);N=c[3529166]|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}K=D+108|0;c[K>>2]=0;O=D+100|0;c[O>>2]=0;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Q&16383](D,2)|0;do{if((c[K>>2]|0)!=0){Q=c[O>>2]|0;c[E>>2]=9534384;R=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[R&16383](E,2,0)|0;if((Q|0)<1){P=1;i=e;return P|0}if((gzL(N,0,2)|0)==0){break}else{P=1}i=e;return P|0}}while(0);N=c[642608+(c[2436]<<2)>>2]|0;O=(dW(c[N>>2]|0,180472,7)|0)==0;K=c[2387808]|0;do{if((c[3542200]|0)==0){S=1}else{Q=B+108|0;c[Q>>2]=0;R=B+100|0;c[R>>2]=0;T=c[N+76>>2]|0;gA[T&16383](B,3)|0;if((c[Q>>2]|0)==0){S=0;break}Q=c[R>>2]|0;c[C>>2]=9534384;R=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[R&16383](C,3,0)|0;if((Q|0)<1){S=1;break}S=(gzL(K,0,3)|0)!=0}}while(0);do{if(O){if(S){P=1;i=e;return P|0}K=(c[2387808]|0)+524288|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}N=z+108|0;c[N>>2]=0;Q=z+100|0;c[Q>>2]=0;R=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[R&16383](z,4)|0;do{if((c[N>>2]|0)!=0){R=c[Q>>2]|0;c[A>>2]=9534384;T=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[T&16383](A,4,0)|0;if((R|0)<1){P=1;i=e;return P|0}if((gzL(K,0,4)|0)==0){break}else{P=1}i=e;return P|0}}while(0);K=(c[2387808]|0)+1048576|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}Q=x+108|0;c[Q>>2]=0;N=x+100|0;c[N>>2]=0;R=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[R&16383](x,5)|0;do{if((c[Q>>2]|0)!=0){R=c[N>>2]|0;c[y>>2]=9534384;T=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[T&16383](y,5,0)|0;if((R|0)<1){P=1;i=e;return P|0}if((gzL(K,0,5)|0)==0){break}else{P=1}i=e;return P|0}}while(0);K=(c[2387808]|0)+1572864|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}N=v+108|0;c[N>>2]=0;Q=v+100|0;c[Q>>2]=0;R=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[R&16383](v,6)|0;if((c[N>>2]|0)==0){U=0;break}N=c[Q>>2]|0;c[w>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](w,6,0)|0;if((N|0)<1){P=1;i=e;return P|0}if((gzL(K,0,6)|0)==0){U=0;break}else{P=1}i=e;return P|0}else{if(S){P=1;i=e;return P|0}K=(c[2387808]|0)+131072|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}N=t+108|0;c[N>>2]=0;Q=t+100|0;c[Q>>2]=0;R=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[R&16383](t,4)|0;do{if((c[N>>2]|0)!=0){R=c[Q>>2]|0;c[u>>2]=9534384;T=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[T&16383](u,4,0)|0;if((R|0)<1){P=1;i=e;return P|0}if((gzL(K,0,4)|0)==0){break}else{P=1}i=e;return P|0}}while(0);K=(c[2387808]|0)+524288|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}Q=r+108|0;c[Q>>2]=0;N=r+100|0;c[N>>2]=0;R=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[R&16383](r,5)|0;do{if((c[Q>>2]|0)!=0){R=c[N>>2]|0;c[s>>2]=9534384;T=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[T&16383](s,5,0)|0;if((R|0)<1){P=1;i=e;return P|0}if((gzL(K,0,5)|0)==0){break}else{P=1}i=e;return P|0}}while(0);K=(c[2387808]|0)+655360|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}N=p+108|0;c[N>>2]=0;Q=p+100|0;c[Q>>2]=0;R=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[R&16383](p,6)|0;do{if((c[N>>2]|0)!=0){R=c[Q>>2]|0;c[q>>2]=9534384;T=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[T&16383](q,6,0)|0;if((R|0)<1){P=1;i=e;return P|0}if((gzL(K,0,6)|0)==0){break}else{P=1}i=e;return P|0}}while(0);K=(c[2387808]|0)+1048576|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}Q=n+108|0;c[Q>>2]=0;N=n+100|0;c[N>>2]=0;R=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[R&16383](n,7)|0;do{if((c[Q>>2]|0)!=0){R=c[N>>2]|0;c[o>>2]=9534384;T=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[T&16383](o,7,0)|0;if((R|0)<1){P=1;i=e;return P|0}if((gzL(K,0,7)|0)==0){break}else{P=1}i=e;return P|0}}while(0);K=(c[2387808]|0)+1179648|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}N=l+108|0;c[N>>2]=0;Q=l+100|0;c[Q>>2]=0;R=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[R&16383](l,8)|0;do{if((c[N>>2]|0)!=0){R=c[Q>>2]|0;c[m>>2]=9534384;T=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[T&16383](m,8,0)|0;if((R|0)<1){P=1;i=e;return P|0}if((gzL(K,0,8)|0)==0){break}else{P=1}i=e;return P|0}}while(0);K=(c[2387808]|0)+1572864|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}Q=j+108|0;c[Q>>2]=0;N=j+100|0;c[N>>2]=0;R=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[R&16383](j,9)|0;do{if((c[Q>>2]|0)!=0){R=c[N>>2]|0;c[k>>2]=9534384;T=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[T&16383](k,9,0)|0;if((R|0)<1){P=1;i=e;return P|0}if((gzL(K,0,9)|0)==0){break}else{P=1}i=e;return P|0}}while(0);K=(c[2387808]|0)+1703936|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}N=f+108|0;c[N>>2]=0;Q=f+100|0;c[Q>>2]=0;R=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[R&16383](f,10)|0;if((c[N>>2]|0)==0){U=0;break}N=c[Q>>2]|0;c[g>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](g,10,0)|0;if((N|0)<1){P=1;i=e;return P|0}if((gzL(K,0,10)|0)==0){U=0;break}else{P=1}i=e;return P|0}}while(0);while(1){if((U|0)>=1024){P=1;M=49456;break}V=9638528+(U<<2)|0;if((c[V>>2]|0)==0){break}else{U=U+1|0}}if((M|0)==49456){i=e;return P|0}O=gGq(2097152)|0;c[V>>2]=O;if((O|0)==0){P=1;i=e;return P|0}gGz(O|0,0,2097152);K=c[2387808]|0;gGC(O|0,K|0,2097152)|0;N=0;do{Q=N<<8;gGz(K+Q|0,0,256);R=0;do{T=1<<3-R;W=(c[601464+(R<<2)>>2]|0)+Q|0;X=0;do{Y=W+(c[611776+(X<<2)>>2]|0)|0;Z=(X<<4)+Q|0;_=0;do{$=Y+(c[601400+(_<<2)>>2]|0)|0;if(((d[O+(($|0)/8|0)|0]|0)&128>>>(($&7)>>>0)|0)!=0){$=K+(Z+_)|0;a[$]=(d[$]|0|T)&255}_=_+1|0;}while((_|0)<16);X=X+1|0;}while((X|0)<16);R=R+1|0;}while((R|0)<4);N=N+1|0;}while((N|0)<16384);N=K+2097152|0;if((gGH(N|0,K+3145728|0,1048576)|0)==0){gGC(N|0,K|0,2097152)|0;aa=0}else{aa=0}while(1){if((aa|0)>=1024){break}ab=9638528+(aa<<2)|0;if((c[ab>>2]|0)==(O|0)){M=49354;break}else{aa=aa+1|0}}if((M|0)==49354){gGr(O);c[ab>>2]=0}fwR(0);K=c[2439330]|0;N=(K|0)==0;if(!N){R=K;gGC(9706056,R|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];R=c[3528484]|0;c[2076596]=R;Q=c[2417276]|0;c[3541536]=Q;c[1836236]=0;X=c[3529224]|0;T=0;W=0;while(1){c[K+76+(W<<2)>>2]=X+(W<<8);_=T+1&65535;if((_&65535)>127){ac=0;ad=0;break}else{T=_;W=_&65535}}while(1){W=X+(ad<<8)|0;c[K+76+(ad+512<<2)>>2]=W;c[K+76+(ad+768<<2)>>2]=W;W=ac+1&65535;if((W&65535)>127){ae=128;af=128;break}else{ac=W;ad=W&65535}}while(1){c[K+76+(af<<2)>>2]=X+((af<<8)+65536);W=ae+1&65535;if((W&65535)>191){ah=128;ai=128;break}else{ae=W;af=W&65535}}while(1){c[K+76+(ai+256<<2)>>2]=X+((ai<<8)+65536);W=ah+1&65535;if((W&65535)>191){aj=128;ak=128;break}else{ah=W;ai=W&65535}}while(1){W=X+((ak<<8)+65536)|0;c[K+76+(ak+512<<2)>>2]=W;c[K+76+(ak+768<<2)>>2]=W;W=aj+1&65535;if((W&65535)>191){break}else{aj=W;ak=W&65535}}X=c[2386398]|0;W=192;T=192;while(1){c[K+76+(T<<2)>>2]=X+((T<<8)-49152);O=W+1&65535;if((O&65535)>223){al=192;am=192;break}else{W=O;T=O&65535}}while(1){c[K+76+(am+256<<2)>>2]=X+((am<<8)-49152);T=al+1&65535;if((T&65535)>223){an=192;ao=192;break}else{al=T;am=T&65535}}while(1){T=X+((ao<<8)-49152)|0;c[K+76+(ao+512<<2)>>2]=T;c[K+76+(ao+768<<2)>>2]=T;T=an+1&65535;if((T&65535)>223){break}else{an=T;ao=T&65535}}X=c[3527294]|0;c[K+972>>2]=X;c[K+976>>2]=X+256;c[K+980>>2]=X+512;c[K+984>>2]=X+768;c[K+988>>2]=X+1024;c[K+992>>2]=X+1280;c[K+996>>2]=X+1536;c[K+1e3>>2]=X+1792;c[K+1004>>2]=X+2048;c[K+1008>>2]=X+2304;c[K+1012>>2]=X+2560;c[K+1016>>2]=X+2816;c[K+1020>>2]=X+3072;c[K+1024>>2]=X+3328;c[K+1028>>2]=X+3584;if((dW(c[c[642608+(c[2436]<<2)>>2]>>2]|0,180472,7)|0)==0){c[K+1032>>2]=X+3840;ap=224;aq=224}else{ap=224;aq=224}while(1){c[K+76+(aq+256<<2)>>2]=X+((aq<<8)-57344);T=ap+1&65535;if((T&65535)>239){ar=224;as=224;break}else{ap=T;aq=T&65535}}while(1){T=X+((as<<8)-57344)|0;c[K+76+(as+512<<2)>>2]=T;c[K+76+(as+768<<2)>>2]=T;T=ar+1&65535;if((T&65535)>239){break}else{ar=T;as=T&65535}}X=c[2386190]|0;c[K+1036>>2]=X;T=X+256|0;c[K+1040>>2]=T;c[K+2060>>2]=X;c[K+2064>>2]=T;c[K+3084>>2]=X;c[K+4108>>2]=X;c[K+3088>>2]=T;c[K+4112>>2]=T;T=c[2443466]|0;c[K+1044>>2]=T;c[K+2068>>2]=T;c[K+4184>>2]=1286;c[K+4180>>2]=122;if(!N){T=K;gGC(T|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=R;c[2417276]=Q;c[1836236]=-1;fwR(1);T=c[2439331]|0;X=(T|0)==0;if(!X){W=T;gGC(9706056,W|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];W=c[3528485]|0;c[2076596]=W;O=c[2417277]|0;c[3541536]=O;c[1836236]=1;_=c[3529180]|0;Z=0;Y=0;while(1){c[T+76+(Y<<2)>>2]=_+(Y<<8);$=Z+1&65535;if(($&65535)>159){at=0;au=0;break}else{Z=$;Y=$&65535}}while(1){Y=_+(au<<8)|0;c[T+76+(au+512<<2)>>2]=Y;c[T+76+(au+768<<2)>>2]=Y;Y=at+1&65535;if((Y&65535)>159){break}else{at=Y;au=Y&65535}}_=c[3529274]|0;c[T+908>>2]=_;c[T+912>>2]=_+256;c[T+916>>2]=_+512;c[T+920>>2]=_+768;c[T+924>>2]=_+1024;c[T+928>>2]=_+1280;c[T+932>>2]=_+1536;c[T+936>>2]=_+1792;c[T+940>>2]=_+2048;c[T+944>>2]=_+2304;c[T+948>>2]=_+2560;c[T+952>>2]=_+2816;c[T+956>>2]=_+3072;c[T+960>>2]=_+3328;c[T+964>>2]=_+3584;c[T+968>>2]=_+3840;Y=208;Z=208;while(1){c[T+76+(Z+256<<2)>>2]=_+((Z<<8)-53248);Q=Y+1&65535;if((Q&65535)>223){av=208;aw=208;break}else{Y=Q;Z=Q&65535}}while(1){Z=_+((aw<<8)-53248)|0;c[T+76+(aw+512<<2)>>2]=Z;c[T+76+(aw+768<<2)>>2]=Z;Z=av+1&65535;if((Z&65535)>223){break}else{av=Z;aw=Z&65535}}_=c[3527294]|0;c[T+972>>2]=_;c[T+976>>2]=_+256;c[T+980>>2]=_+512;c[T+984>>2]=_+768;c[T+988>>2]=_+1024;c[T+992>>2]=_+1280;c[T+996>>2]=_+1536;c[T+1e3>>2]=_+1792;c[T+1004>>2]=_+2048;c[T+1008>>2]=_+2304;c[T+1012>>2]=_+2560;c[T+1016>>2]=_+2816;c[T+1020>>2]=_+3072;c[T+1024>>2]=_+3328;c[T+1028>>2]=_+3584;c[T+1032>>2]=_+3840;Z=224;Y=224;while(1){c[T+76+(Y+256<<2)>>2]=_+((Y<<8)-57344);Q=Z+1&65535;if((Q&65535)>239){ax=224;ay=224;break}else{Z=Q;Y=Q&65535}}while(1){Y=_+((ay<<8)-57344)|0;c[T+76+(ay+512<<2)>>2]=Y;c[T+76+(ay+768<<2)>>2]=Y;Y=ax+1&65535;if((Y&65535)>239){break}else{ax=Y;ay=Y&65535}}_=c[2387124]|0;c[T+2060>>2]=_;Y=_+256|0;c[T+2064>>2]=Y;Z=_+512|0;c[T+2068>>2]=Z;Q=_+768|0;c[T+2072>>2]=Q;c[T+2092>>2]=_;c[T+2096>>2]=Y;c[T+2100>>2]=Z;c[T+2104>>2]=Q;c[T+4184>>2]=1958;c[T+4180>>2]=290;if(!X){Q=T;gGC(Q|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=W;c[2417277]=O;c[1836236]=-1;fwR(2);Q=c[2439332]|0;Z=(Q|0)==0;if(!Z){Y=Q;gGC(9706056,Y|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438120];Y=c[3528486]|0;c[2076596]=Y;_=c[2417278]|0;c[3541536]=_;c[1836236]=2;R=c[3529166]|0;K=0;N=0;while(1){c[Q+76+(N<<2)>>2]=R+(N<<8);$=K+1&65535;if(($&65535)>127){az=0;aA=0;break}else{K=$;N=$&65535}}while(1){N=R+(aA<<8)|0;c[Q+76+(aA+512<<2)>>2]=N;c[Q+76+(aA+768<<2)>>2]=N;N=az+1&65535;if((N&65535)>127){break}else{az=N;aA=N&65535}}R=c[3529266]|0;N=192;K=192;while(1){c[Q+76+(K<<2)>>2]=R+((K<<8)-49152);O=N+1&65535;if((O&65535)>223){aB=192;aC=192;break}else{N=O;K=O&65535}}while(1){c[Q+76+(aC+256<<2)>>2]=R+((aC<<8)-49152);K=aB+1&65535;if((K&65535)>223){aD=192;aE=192;break}else{aB=K;aC=K&65535}}while(1){K=R+((aE<<8)-49152)|0;c[Q+76+(aE+512<<2)>>2]=K;c[Q+76+(aE+768<<2)>>2]=K;K=aD+1&65535;if((K&65535)>223){aF=224;aG=224;break}else{aD=K;aE=K&65535}}while(1){c[Q+76+(aG<<2)>>2]=R+((aG<<8)-57344);K=aF+1&65535;if((K&65535)>255){aH=224;aI=224;break}else{aF=K;aG=K&65535}}while(1){c[Q+76+(aI+256<<2)>>2]=R+((aI<<8)-57344);K=aH+1&65535;if((K&65535)>255){aJ=224;aK=224;break}else{aH=K;aI=K&65535}}while(1){K=R+((aK<<8)-57344)|0;c[Q+76+(aK+512<<2)>>2]=K;c[Q+76+(aK+768<<2)>>2]=K;K=aJ+1&65535;if((K&65535)>255){break}else{aJ=K;aK=K&65535}}c[Q+4176>>2]=904;c[Q+4172>>2]=450;if(!Z){R=Q;gGC(R|0,9706056,76)|0}c[2438120]=c[2433530];c[3528486]=Y;c[2417278]=_;c[1836236]=-1;Vr(1,3e6,1160,1468,56,0);c[3542224]=0;c[3542225]=0;c[3542226]=2686;c[3542227]=198;c[2438228]=6e6;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=340;h[745419]=.3;a[3203368]=1;h[745418]=.3;a[3203360]=1;h[745417]=.3;a[3203352]=1;h[745416]=.3;a[3203344]=1;R=c[642608+(c[2436]<<2)>>2]|0;K=c[R>>2]|0;if((dW(K|0,180472,7)|0)==0){M=49402}else{if((dW(K|0,499472,5)|0)==0){M=49402}}if((M|0)==49402){h[745419]=2.0;a[3203368]=1;h[745418]=1.0;a[3203360]=1;h[745417]=1.0;a[3203352]=1;h[745416]=1.0;a[3203344]=1}c[2405758]=1;gGz(9542544,0,32);c[2385641]=1;h[1192819]=1.0;c[2385642]=3;c[2385643]=3336;K=0;do{N=K*257|0;b[9732544+(K<<1)>>1]=((N|0)/2|0)&65535;b[9753784+(K<<1)>>1]=N+32768&65535;K=K+1|0;}while((K|0)<256);c[3528842]=1;K=c[R+128>>2]|0;if((c[R+52>>2]&4|0)==0){c[2113068]=K;_=c[R+132>>2]|0;c[2113070]=_;c[2443814]=K;c[2440436]=_;aL=K;aM=_}else{c[2113070]=K;_=c[R+132>>2]|0;c[2113068]=_;c[2440436]=K;c[2443814]=_;aL=_;aM=K}K=ag(aL<<1,aM)|0;_=gGq(K)|0;c[2112926]=_;if((_|0)!=0){gGz(_|0,0,K|0)}fcm();P=0;i=e;return P|0}}while(0);c[2414882]=0;P=1;i=e;return P|0}function fbU(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6472444+(b*112|0)>>2];c[a+104>>2]=c[6472448+(b*112|0)>>2];c[a+108>>2]=c[6472452+(b*112|0)>>2];d=0;return d|0}function fbV(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=6472344+(b*112|0);e=0;return e|0}function fbW(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>38){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6663376+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fbX(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5649316+(b*112|0)>>2];c[a+104>>2]=c[5649320+(b*112|0)>>2];c[a+108>>2]=c[5649324+(b*112|0)>>2];d=0;return d|0}function fbY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=5649216+(b*112|0);e=0;return e|0}function fbZ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>41){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6027912+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fb_(){return fce(6)|0}function fb$(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6471212+(b*112|0)>>2];c[a+104>>2]=c[6471216+(b*112|0)>>2];c[a+108>>2]=c[6471220+(b*112|0)>>2];d=0;return d|0}function fb0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=6471112+(b*112|0);e=0;return e|0}function fb1(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>38){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6027440+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fb2(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5648084+(b*112|0)>>2];c[a+104>>2]=c[5648088+(b*112|0)>>2];c[a+108>>2]=c[5648092+(b*112|0)>>2];d=0;return d|0}function fb3(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=5647984+(b*112|0);e=0;return e|0}function fb4(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>3){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4653820+(b*112|0)>>2];c[a+104>>2]=c[4653824+(b*112|0)>>2];c[a+108>>2]=c[4653828+(b*112|0)>>2];d=0;return d|0}function fb5(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<4&(d|0)==0)){e=1;return e|0}c[a>>2]=4653720+(b*112|0);e=0;return e|0}function fb6(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1867984+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function fb7(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>38){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5341816+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fb8(){return fce(7)|0}function fb9(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>5){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2732356+(b*112|0)>>2];c[a+104>>2]=c[2732360+(b*112|0)>>2];c[a+108>>2]=c[2732364+(b*112|0)>>2];d=0;return d|0}function fca(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<6&(d|0)==0)){e=1;return e|0}c[a>>2]=2732256+(b*112|0);e=0;return e|0}function fcb(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1237920+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function fcc(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>31){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3843184+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fcd(){return fce(9)|0}function fce(e){e=e|0;var f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0,cf=0,cg=0,ch=0,ci=0,cj=0,ck=0,cl=0,cm=0,cn=0,co=0,cp=0,cq=0,cr=0,cs=0,ct=0,cu=0,cv=0,cw=0,cx=0,cy=0,cz=0,cA=0,cB=0,cC=0,cD=0,cE=0,cF=0,cG=0,cH=0,cI=0,cJ=0,cK=0,cL=0,cM=0,cN=0,cO=0,cP=0,cQ=0,cR=0,cS=0,cT=0,cU=0,cV=0,cW=0,cX=0,cY=0,cZ=0,c_=0,c$=0,c0=0,c1=0,c2=0,c3=0,c4=0,c5=0,c6=0,c7=0,c8=0,c9=0,da=0,db=0,dc=0,dd=0,de=0,df=0,dg=0,dh=0,di=0,dj=0,dk=0,dl=0;f=i;i=i+10320|0;g=f|0;j=f+112|0;k=f+120|0;l=f+232|0;m=f+240|0;n=f+352|0;o=f+360|0;p=f+472|0;q=f+480|0;r=f+592|0;s=f+600|0;t=f+712|0;u=f+720|0;v=f+832|0;w=f+840|0;x=f+952|0;y=f+960|0;z=f+1072|0;A=f+1080|0;B=f+1192|0;C=f+1200|0;D=f+1312|0;E=f+1320|0;F=f+1432|0;G=f+1440|0;H=f+1552|0;I=f+1560|0;J=f+1672|0;K=f+1680|0;L=f+1792|0;M=f+1800|0;N=f+1912|0;O=f+1920|0;P=f+2032|0;Q=f+2040|0;R=f+2152|0;S=f+2160|0;T=f+2272|0;U=f+2280|0;V=f+2392|0;W=f+2400|0;X=f+2512|0;Y=f+2520|0;Z=f+2632|0;_=f+2640|0;$=f+2752|0;aa=f+2760|0;ab=f+2872|0;ac=f+2880|0;ad=f+2992|0;ae=f+3e3|0;af=f+3112|0;ah=f+3120|0;ai=f+3232|0;aj=f+3240|0;ak=f+3352|0;al=f+3360|0;am=f+3472|0;an=f+3480|0;ao=f+3592|0;ap=f+3600|0;aq=f+3712|0;ar=f+3720|0;as=f+3832|0;at=f+3840|0;au=f+3952|0;av=f+3960|0;aw=f+4072|0;ax=f+4080|0;ay=f+4192|0;az=f+4200|0;aA=f+4312|0;aB=f+4320|0;aC=f+4432|0;aD=f+4440|0;aE=f+4552|0;aF=f+4560|0;aG=f+4672|0;aH=f+4680|0;aI=f+4792|0;aJ=f+4800|0;aK=f+4912|0;aL=f+4920|0;aM=f+5032|0;aN=f+5040|0;aO=f+5152|0;aP=f+5160|0;aQ=f+5272|0;aR=f+5280|0;aS=f+5392|0;aT=f+5400|0;aU=f+5512|0;aV=f+5520|0;aW=f+5632|0;aX=f+5640|0;aY=f+5752|0;aZ=f+5760|0;a_=f+5872|0;a$=f+5880|0;a0=f+5992|0;a1=f+6e3|0;a2=f+6112|0;a3=f+6120|0;a4=f+6232|0;a5=f+6240|0;a6=f+6352|0;a7=f+6360|0;a8=f+6472|0;a9=f+6480|0;ba=f+6592|0;bb=f+6600|0;bc=f+6712|0;bd=f+6720|0;be=f+6832|0;bf=f+6840|0;bg=f+6952|0;bh=f+6960|0;bi=f+7072|0;bj=f+7080|0;bk=f+7192|0;bl=f+7200|0;bm=f+7312|0;bn=f+7320|0;bo=f+7432|0;bp=f+7440|0;bq=f+7552|0;br=f+7560|0;bs=f+7672|0;bt=f+7680|0;bu=f+7792|0;bv=f+7800|0;bw=f+7912|0;bx=f+7920|0;by=f+8032|0;bz=f+8040|0;bA=f+8152|0;bB=f+8160|0;bC=f+8272|0;bD=f+8280|0;bE=f+8392|0;bF=f+8400|0;bG=f+8512|0;bH=f+8520|0;bI=f+8632|0;bJ=f+8640|0;bK=f+8752|0;bL=f+8760|0;bM=f+8872|0;bN=f+8880|0;bO=f+8992|0;bP=f+9e3|0;bQ=f+9112|0;bR=f+9120|0;bS=f+9232|0;bT=f+9240|0;bU=f+9352|0;bV=f+9360|0;bW=f+9472|0;bX=f+9480|0;bY=f+9592|0;bZ=f+9600|0;b_=f+9712|0;b$=f+9720|0;b0=f+9832|0;b1=f+9840|0;b2=f+9952|0;b3=f+9960|0;b4=f+10072|0;b5=f+10080|0;b6=f+10192|0;b7=f+10200|0;b8=f+10312|0;c[2414882]=0;c[3529224]=0;c[3529180]=262144;c[3529166]=393216;c[2387808]=524288;c[3530992]=4718592;c[2386602]=4719616;c[3529914]=4785152;c[2442958]=4787200;b9=a[9688]|0?2136:0;ca=b9+4787200|0;c[2414584]=ca;c[3530260]=ca;c[2387124]=b9+4787204;c[2386398]=b9|4788228;c[3527294]=b9|4796420;c[2443466]=b9|4800516;c[2386190]=b9|4800772;c[3529312]=b9|4801284;c[3529274]=b9|4834052;c[3529266]=b9|4838148;c[2442886]=b9|4846340;c[3528218]=b9|4846341;c[2440188]=b9|4846342;ca=b9|4846343|0;c[2411528]=ca;c[2414068]=ca;b9=ca;ca=0;while(1){if((ca|0)>=1024){break}cb=9638528+(ca<<2)|0;if((c[cb>>2]|0)==0){cc=49584;break}else{ca=ca+1|0}}do{if((cc|0)==49584){ca=gGq(b9)|0;c[cb>>2]=ca;if((ca|0)==0){break}gGz(ca|0,0,b9|0);c[2414882]=ca;gGz(ca|0,0,b9|0);c[3529224]=ca;c[3529180]=ca+262144;c[3529166]=ca+393216;c[2387808]=ca+524288;c[3530992]=ca+4718592;c[2386602]=ca+4719616;c[3529914]=ca+4785152;c[2442958]=ca+4787200;cd=a[9688]|0?2136:0;ce=ca+(cd+4787200)|0;c[2414584]=ce;c[3530260]=ce;c[2387124]=ca+(cd+4787204);c[2386398]=ca+(cd|4788228);c[3527294]=ca+(cd|4796420);c[2443466]=ca+(cd|4800516);c[2386190]=ca+(cd|4800772);c[3529312]=ca+(cd|4801284);c[3529274]=ca+(cd|4834052);c[3529266]=ca+(cd|4838148);c[2442886]=ca+(cd|4846340);c[3528218]=ca+(cd|4846341);c[2440188]=ca+(cd|4846342);ce=ca+(cd|4846343)|0;c[2411528]=ce;c[2414068]=ce;L64744:do{switch(e|0){case 3:{ce=ca+65536|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}cd=bt+108|0;c[cd>>2]=0;cg=bt+100|0;c[cg>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](bt,0)|0;do{if((c[cd>>2]|0)!=0){ch=c[cg>>2]|0;c[bu>>2]=9534384;ci=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ci&16383](bu,0,0)|0;if((ch|0)<1){cf=1;i=f;return cf|0}if((gzL(ce,0,0)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);ce=c[3529224]|0;gGC(ce|0,ce+65536|0,32768)|0;cg=ce+131072|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}ce=br+108|0;c[ce>>2]=0;cd=br+100|0;c[cd>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](br,1)|0;do{if((c[ce>>2]|0)!=0){ch=c[cd>>2]|0;c[bs>>2]=9534384;ci=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ci&16383](bs,1,0)|0;if((ch|0)<1){cf=1;i=f;return cf|0}if((gzL(cg,0,1)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);cg=c[3529180]|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}cd=bp+108|0;c[cd>>2]=0;ce=bp+100|0;c[ce>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](bp,2)|0;do{if((c[cd>>2]|0)!=0){ch=c[ce>>2]|0;c[bq>>2]=9534384;ci=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ci&16383](bq,2,0)|0;if((ch|0)<1){cf=1;i=f;return cf|0}if((gzL(cg,0,2)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);cg=c[2387808]|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}ce=bn+108|0;c[ce>>2]=0;cd=bn+100|0;c[cd>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](bn,4)|0;do{if((c[ce>>2]|0)!=0){ch=c[cd>>2]|0;c[bo>>2]=9534384;ci=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ci&16383](bo,4,0)|0;if((ch|0)<1){cf=1;i=f;return cf|0}if((gzL(cg,0,4)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);cg=(c[2387808]|0)+131072|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}cd=bl+108|0;c[cd>>2]=0;ce=bl+100|0;c[ce>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](bl,5)|0;do{if((c[cd>>2]|0)!=0){ch=c[ce>>2]|0;c[bm>>2]=9534384;ci=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ci&16383](bm,5,0)|0;if((ch|0)<1){cf=1;i=f;return cf|0}if((gzL(cg,0,5)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);cg=(c[2387808]|0)+524288|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}ce=bj+108|0;c[ce>>2]=0;cd=bj+100|0;c[cd>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](bj,6)|0;do{if((c[ce>>2]|0)!=0){ch=c[cd>>2]|0;c[bk>>2]=9534384;ci=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ci&16383](bk,6,0)|0;if((ch|0)<1){cf=1;i=f;return cf|0}if((gzL(cg,0,6)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);cg=(c[2387808]|0)+655360|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}cd=bh+108|0;c[cd>>2]=0;ce=bh+100|0;c[ce>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](bh,7)|0;do{if((c[cd>>2]|0)!=0){ch=c[ce>>2]|0;c[bi>>2]=9534384;ci=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ci&16383](bi,7,0)|0;if((ch|0)<1){cf=1;i=f;return cf|0}if((gzL(cg,0,7)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);cg=(c[2387808]|0)+1048576|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}ce=bf+108|0;c[ce>>2]=0;cd=bf+100|0;c[cd>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](bf,8)|0;do{if((c[ce>>2]|0)!=0){ch=c[cd>>2]|0;c[bg>>2]=9534384;ci=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ci&16383](bg,8,0)|0;if((ch|0)<1){cf=1;i=f;return cf|0}if((gzL(cg,0,8)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);cg=(c[2387808]|0)+1179648|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}cd=bd+108|0;c[cd>>2]=0;ce=bd+100|0;c[ce>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](bd,9)|0;do{if((c[cd>>2]|0)!=0){ch=c[ce>>2]|0;c[be>>2]=9534384;ci=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ci&16383](be,9,0)|0;if((ch|0)<1){cf=1;i=f;return cf|0}if((gzL(cg,0,9)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);cg=(c[2387808]|0)+1572864|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}ce=bb+108|0;c[ce>>2]=0;cd=bb+100|0;c[cd>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](bb,10)|0;do{if((c[ce>>2]|0)!=0){ch=c[cd>>2]|0;c[bc>>2]=9534384;ci=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ci&16383](bc,10,0)|0;if((ch|0)<1){cf=1;i=f;return cf|0}if((gzL(cg,0,10)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);cg=(c[2387808]|0)+1703936|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}cd=a9+108|0;c[cd>>2]=0;ce=a9+100|0;c[ce>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](a9,11)|0;do{if((c[cd>>2]|0)!=0){ch=c[ce>>2]|0;c[ba>>2]=9534384;ci=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ci&16383](ba,11,0)|0;if((ch|0)<1){cf=1;i=f;return cf|0}if((gzL(cg,0,11)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);if((R6((c[3530992]|0)+1|0,12,2)|0)!=0){cf=1;i=f;return cf|0}if((R6(c[3530992]|0,13,2)|0)==0){cj=0}else{cf=1;i=f;return cf|0}while(1){if((cj|0)>=1024){cf=1;cc=50200;break}ck=9638528+(cj<<2)|0;if((c[ck>>2]|0)==0){break}else{cj=cj+1|0}}if((cc|0)==50200){i=f;return cf|0}cg=gGq(2097152)|0;c[ck>>2]=cg;if((cg|0)==0){cf=1;i=f;return cf|0}gGz(cg|0,0,2097152);ce=c[2387808]|0;gGC(cg|0,ce|0,2097152)|0;cd=0;do{ch=cd<<8;gGz(ce+ch|0,0,256);ci=0;do{cl=1<<3-ci;cm=(c[601464+(ci<<2)>>2]|0)+ch|0;cn=0;do{co=cm+(c[611776+(cn<<2)>>2]|0)|0;cp=(cn<<4)+ch|0;cq=0;do{cr=co+(c[601400+(cq<<2)>>2]|0)|0;if((d[cg+((cr|0)/8|0)|0]&128>>>((cr&7)>>>0)|0)!=0){cr=ce+(cp+cq)|0;a[cr]=(d[cr]|cl)&255}cq=cq+1|0;}while((cq|0)<16);cn=cn+1|0;}while((cn|0)<16);ci=ci+1|0;}while((ci|0)<4);cd=cd+1|0;}while((cd|0)<16384);cd=ce+2097152|0;if((gGH(cd|0,ce+3145728|0,1048576)|0)==0){gGC(cd|0,ce|0,2097152)|0;cs=0}else{cs=0}while(1){if((cs|0)>=1024){break L64744}ct=9638528+(cs<<2)|0;if((c[ct>>2]|0)==(cg|0)){break}else{cs=cs+1|0}}gGr(cg);c[ct>>2]=0;break};case 6:{ce=ca+65536|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}cd=bN+108|0;c[cd>>2]=0;ci=bN+100|0;c[ci>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](bN,0)|0;do{if((c[cd>>2]|0)!=0){ch=c[ci>>2]|0;c[bO>>2]=9534384;cn=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[cn&16383](bO,0,0)|0;if((ch|0)<1){cf=1;i=f;return cf|0}if((gzL(ce,0,0)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);ce=c[3529224]|0;ci=ce+65536|0;gGC(ce|0,ci|0,32768)|0;ci=c[3529180]|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}ce=bL+108|0;c[ce>>2]=0;cd=bL+100|0;c[cd>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](bL,1)|0;do{if((c[ce>>2]|0)!=0){cg=c[cd>>2]|0;c[bM>>2]=9534384;ch=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ch&16383](bM,1,0)|0;if((cg|0)<1){cf=1;i=f;return cf|0}if((gzL(ci,0,1)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);ci=c[2387808]|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}cd=bJ+108|0;c[cd>>2]=0;ce=bJ+100|0;c[ce>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](bJ,3)|0;do{if((c[cd>>2]|0)!=0){cg=c[ce>>2]|0;c[bK>>2]=9534384;ch=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ch&16383](bK,3,0)|0;if((cg|0)<1){cf=1;i=f;return cf|0}if((gzL(ci,0,3)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);ci=(c[2387808]|0)+131072|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}ce=bH+108|0;c[ce>>2]=0;cd=bH+100|0;c[cd>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](bH,4)|0;do{if((c[ce>>2]|0)!=0){cg=c[cd>>2]|0;c[bI>>2]=9534384;ch=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ch&16383](bI,4,0)|0;if((cg|0)<1){cf=1;i=f;return cf|0}if((gzL(ci,0,4)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);ci=(c[2387808]|0)+524288|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}cd=bF+108|0;c[cd>>2]=0;ce=bF+100|0;c[ce>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](bF,5)|0;do{if((c[cd>>2]|0)!=0){cg=c[ce>>2]|0;c[bG>>2]=9534384;ch=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ch&16383](bG,5,0)|0;if((cg|0)<1){cf=1;i=f;return cf|0}if((gzL(ci,0,5)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);ci=(c[2387808]|0)+655360|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}ce=bD+108|0;c[ce>>2]=0;cd=bD+100|0;c[cd>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](bD,6)|0;do{if((c[ce>>2]|0)!=0){cg=c[cd>>2]|0;c[bE>>2]=9534384;ch=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ch&16383](bE,6,0)|0;if((cg|0)<1){cf=1;i=f;return cf|0}if((gzL(ci,0,6)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);ci=(c[2387808]|0)+1048576|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}cd=bB+108|0;c[cd>>2]=0;ce=bB+100|0;c[ce>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](bB,7)|0;do{if((c[cd>>2]|0)!=0){cg=c[ce>>2]|0;c[bC>>2]=9534384;ch=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ch&16383](bC,7,0)|0;if((cg|0)<1){cf=1;i=f;return cf|0}if((gzL(ci,0,7)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);ci=(c[2387808]|0)+1179648|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}ce=bz+108|0;c[ce>>2]=0;cd=bz+100|0;c[cd>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](bz,8)|0;do{if((c[ce>>2]|0)!=0){cg=c[cd>>2]|0;c[bA>>2]=9534384;ch=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ch&16383](bA,8,0)|0;if((cg|0)<1){cf=1;i=f;return cf|0}if((gzL(ci,0,8)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);ci=(c[2387808]|0)+1572864|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}cd=bx+108|0;c[cd>>2]=0;ce=bx+100|0;c[ce>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](bx,9)|0;do{if((c[cd>>2]|0)!=0){cg=c[ce>>2]|0;c[by>>2]=9534384;ch=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ch&16383](by,9,0)|0;if((cg|0)<1){cf=1;i=f;return cf|0}if((gzL(ci,0,9)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);ci=(c[2387808]|0)+1703936|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}ce=bv+108|0;c[ce>>2]=0;cd=bv+100|0;c[cd>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](bv,10)|0;do{if((c[ce>>2]|0)==0){cu=0}else{cg=c[cd>>2]|0;c[bw>>2]=9534384;ch=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ch&16383](bw,10,0)|0;if((cg|0)<1){cf=1;i=f;return cf|0}if((gzL(ci,0,10)|0)==0){cu=0;break}else{cf=1}i=f;return cf|0}}while(0);while(1){if((cu|0)>=1024){cf=1;cc=50187;break}cv=9638528+(cu<<2)|0;if((c[cv>>2]|0)==0){break}else{cu=cu+1|0}}if((cc|0)==50187){i=f;return cf|0}ci=gGq(2097152)|0;c[cv>>2]=ci;if((ci|0)==0){cf=1;i=f;return cf|0}gGz(ci|0,0,2097152);cd=c[2387808]|0;gGC(ci|0,cd|0,2097152)|0;ce=0;do{cg=ce<<8;gGz(cd+cg|0,0,256);ch=0;do{cn=1<<3-ch;cl=(c[601464+(ch<<2)>>2]|0)+cg|0;cm=0;do{cq=cl+(c[611776+(cm<<2)>>2]|0)|0;cp=(cm<<4)+cg|0;co=0;do{cr=cq+(c[601400+(co<<2)>>2]|0)|0;if((d[ci+((cr|0)/8|0)|0]&128>>>((cr&7)>>>0)|0)!=0){cr=cd+(cp+co)|0;a[cr]=(d[cr]|cn)&255}co=co+1|0;}while((co|0)<16);cm=cm+1|0;}while((cm|0)<16);ch=ch+1|0;}while((ch|0)<4);ce=ce+1|0;}while((ce|0)<16384);ce=cd+2097152|0;if((gGH(ce|0,cd+3145728|0,1048576)|0)==0){gGC(ce|0,cd|0,2097152)|0;cw=0}else{cw=0}while(1){if((cw|0)>=1024){break L64744}cx=9638528+(cw<<2)|0;if((c[cx>>2]|0)==(ci|0)){break}else{cw=cw+1|0}}gGr(ci);c[cx>>2]=0;break};case 4:{cd=ca+65536|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}ce=b7+108|0;c[ce>>2]=0;ch=b7+100|0;c[ch>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](b7,0)|0;do{if((c[ce>>2]|0)!=0){cg=c[ch>>2]|0;c[b8>>2]=9534384;cm=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[cm&16383](b8,0,0)|0;if((cg|0)<1){cf=1;i=f;return cf|0}if((gzL(cd,0,0)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);cd=c[3529224]|0;ch=cd+65536|0;gGC(cd|0,ch|0,32768)|0;ch=cd+131072|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}cd=b5+108|0;c[cd>>2]=0;ce=b5+100|0;c[ce>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](b5,1)|0;do{if((c[cd>>2]|0)!=0){ci=c[ce>>2]|0;c[b6>>2]=9534384;cg=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[cg&16383](b6,1,0)|0;if((ci|0)<1){cf=1;i=f;return cf|0}if((gzL(ch,0,1)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);ch=c[3529180]|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}ce=b3+108|0;c[ce>>2]=0;cd=b3+100|0;c[cd>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](b3,2)|0;do{if((c[ce>>2]|0)!=0){ci=c[cd>>2]|0;c[b4>>2]=9534384;cg=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[cg&16383](b4,2,0)|0;if((ci|0)<1){cf=1;i=f;return cf|0}if((gzL(ch,0,2)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);ch=c[2387808]|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}cd=b1+108|0;c[cd>>2]=0;ce=b1+100|0;c[ce>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](b1,4)|0;do{if((c[cd>>2]|0)!=0){ci=c[ce>>2]|0;c[b2>>2]=9534384;cg=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[cg&16383](b2,4,0)|0;if((ci|0)<1){cf=1;i=f;return cf|0}if((gzL(ch,0,4)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);ch=(c[2387808]|0)+131072|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}ce=b$+108|0;c[ce>>2]=0;cd=b$+100|0;c[cd>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](b$,5)|0;do{if((c[ce>>2]|0)!=0){ci=c[cd>>2]|0;c[b0>>2]=9534384;cg=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[cg&16383](b0,5,0)|0;if((ci|0)<1){cf=1;i=f;return cf|0}if((gzL(ch,0,5)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);ch=(c[2387808]|0)+524288|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}cd=bZ+108|0;c[cd>>2]=0;ce=bZ+100|0;c[ce>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](bZ,6)|0;do{if((c[cd>>2]|0)!=0){ci=c[ce>>2]|0;c[b_>>2]=9534384;cg=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[cg&16383](b_,6,0)|0;if((ci|0)<1){cf=1;i=f;return cf|0}if((gzL(ch,0,6)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);ch=(c[2387808]|0)+655360|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}ce=bX+108|0;c[ce>>2]=0;cd=bX+100|0;c[cd>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](bX,7)|0;do{if((c[ce>>2]|0)!=0){ci=c[cd>>2]|0;c[bY>>2]=9534384;cg=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[cg&16383](bY,7,0)|0;if((ci|0)<1){cf=1;i=f;return cf|0}if((gzL(ch,0,7)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);ch=(c[2387808]|0)+1048576|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}cd=bV+108|0;c[cd>>2]=0;ce=bV+100|0;c[ce>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](bV,8)|0;do{if((c[cd>>2]|0)!=0){ci=c[ce>>2]|0;c[bW>>2]=9534384;cg=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[cg&16383](bW,8,0)|0;if((ci|0)<1){cf=1;i=f;return cf|0}if((gzL(ch,0,8)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);ch=(c[2387808]|0)+1179648|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}ce=bT+108|0;c[ce>>2]=0;cd=bT+100|0;c[cd>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](bT,9)|0;do{if((c[ce>>2]|0)!=0){ci=c[cd>>2]|0;c[bU>>2]=9534384;cg=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[cg&16383](bU,9,0)|0;if((ci|0)<1){cf=1;i=f;return cf|0}if((gzL(ch,0,9)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);ch=(c[2387808]|0)+1572864|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}cd=bR+108|0;c[cd>>2]=0;ce=bR+100|0;c[ce>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](bR,10)|0;do{if((c[cd>>2]|0)!=0){ci=c[ce>>2]|0;c[bS>>2]=9534384;cg=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[cg&16383](bS,10,0)|0;if((ci|0)<1){cf=1;i=f;return cf|0}if((gzL(ch,0,10)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);ch=(c[2387808]|0)+1703936|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}ce=bP+108|0;c[ce>>2]=0;cd=bP+100|0;c[cd>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](bP,11)|0;do{if((c[ce>>2]|0)==0){cy=0}else{ci=c[cd>>2]|0;c[bQ>>2]=9534384;cg=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[cg&16383](bQ,11,0)|0;if((ci|0)<1){cf=1;i=f;return cf|0}if((gzL(ch,0,11)|0)==0){cy=0;break}else{cf=1}i=f;return cf|0}}while(0);while(1){if((cy|0)>=1024){cf=1;cc=50224;break}cz=9638528+(cy<<2)|0;if((c[cz>>2]|0)==0){break}else{cy=cy+1|0}}if((cc|0)==50224){i=f;return cf|0}ch=gGq(2097152)|0;c[cz>>2]=ch;if((ch|0)==0){cf=1;i=f;return cf|0}gGz(ch|0,0,2097152);cd=c[2387808]|0;gGC(ch|0,cd|0,2097152)|0;ce=0;do{ci=ce<<8;gGz(cd+ci|0,0,256);cg=0;do{cm=1<<3-cg;cn=(c[601464+(cg<<2)>>2]|0)+ci|0;cl=0;do{co=cn+(c[611776+(cl<<2)>>2]|0)|0;cp=(cl<<4)+ci|0;cq=0;do{cr=co+(c[601400+(cq<<2)>>2]|0)|0;if((d[ch+((cr|0)/8|0)|0]&128>>>((cr&7)>>>0)|0)!=0){cr=cd+(cp+cq)|0;a[cr]=(d[cr]|cm)&255}cq=cq+1|0;}while((cq|0)<16);cl=cl+1|0;}while((cl|0)<16);cg=cg+1|0;}while((cg|0)<4);ce=ce+1|0;}while((ce|0)<16384);ce=cd+2097152|0;if((gGH(ce|0,cd+3145728|0,1048576)|0)==0){gGC(ce|0,cd|0,2097152)|0;cA=0}else{cA=0}while(1){if((cA|0)>=1024){break L64744}cB=9638528+(cA<<2)|0;if((c[cB>>2]|0)==(ch|0)){break}else{cA=cA+1|0}}gGr(ch);c[cB>>2]=0;break};case 1:{cd=ca+65536|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}ce=a7+108|0;c[ce>>2]=0;cg=a7+100|0;c[cg>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](a7,0)|0;do{if((c[ce>>2]|0)!=0){ci=c[cg>>2]|0;c[a8>>2]=9534384;cl=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[cl&16383](a8,0,0)|0;if((ci|0)<1){cf=1;i=f;return cf|0}if((gzL(cd,0,0)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);cd=c[3529224]|0;cg=cd+65536|0;gGC(cd|0,cg|0,32768)|0;cg=cd+131072|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}cd=a5+108|0;c[cd>>2]=0;ce=a5+100|0;c[ce>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](a5,1)|0;do{if((c[cd>>2]|0)!=0){ch=c[ce>>2]|0;c[a6>>2]=9534384;ci=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ci&16383](a6,1,0)|0;if((ch|0)<1){cf=1;i=f;return cf|0}if((gzL(cg,0,1)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);cg=c[3529180]|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}ce=a3+108|0;c[ce>>2]=0;cd=a3+100|0;c[cd>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](a3,2)|0;do{if((c[ce>>2]|0)!=0){ch=c[cd>>2]|0;c[a4>>2]=9534384;ci=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ci&16383](a4,2,0)|0;if((ch|0)<1){cf=1;i=f;return cf|0}if((gzL(cg,0,2)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);cg=c[2387808]|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}cd=a1+108|0;c[cd>>2]=0;ce=a1+100|0;c[ce>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](a1,4)|0;do{if((c[cd>>2]|0)!=0){ch=c[ce>>2]|0;c[a2>>2]=9534384;ci=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ci&16383](a2,4,0)|0;if((ch|0)<1){cf=1;i=f;return cf|0}if((gzL(cg,0,4)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);cg=(c[2387808]|0)+524288|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}ce=a$+108|0;c[ce>>2]=0;cd=a$+100|0;c[cd>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](a$,5)|0;do{if((c[ce>>2]|0)!=0){ch=c[cd>>2]|0;c[a0>>2]=9534384;ci=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ci&16383](a0,5,0)|0;if((ch|0)<1){cf=1;i=f;return cf|0}if((gzL(cg,0,5)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);cg=(c[2387808]|0)+1048576|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}cd=aZ+108|0;c[cd>>2]=0;ce=aZ+100|0;c[ce>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](aZ,6)|0;do{if((c[cd>>2]|0)!=0){ch=c[ce>>2]|0;c[a_>>2]=9534384;ci=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ci&16383](a_,6,0)|0;if((ch|0)<1){cf=1;i=f;return cf|0}if((gzL(cg,0,6)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);cg=(c[2387808]|0)+1572864|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}ce=aX+108|0;c[ce>>2]=0;cd=aX+100|0;c[cd>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](aX,7)|0;do{if((c[ce>>2]|0)!=0){ch=c[cd>>2]|0;c[aY>>2]=9534384;ci=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ci&16383](aY,7,0)|0;if((ch|0)<1){cf=1;i=f;return cf|0}if((gzL(cg,0,7)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);if((R6((c[3530992]|0)+1|0,8,2)|0)!=0){cf=1;i=f;return cf|0}if((R6(c[3530992]|0,9,2)|0)==0){cC=0}else{cf=1;i=f;return cf|0}while(1){if((cC|0)>=1024){cf=1;cc=50293;break}cD=9638528+(cC<<2)|0;if((c[cD>>2]|0)==0){break}else{cC=cC+1|0}}if((cc|0)==50293){i=f;return cf|0}cg=gGq(2097152)|0;c[cD>>2]=cg;if((cg|0)==0){cf=1;i=f;return cf|0}gGz(cg|0,0,2097152);cd=c[2387808]|0;gGC(cg|0,cd|0,2097152)|0;ce=0;do{ch=ce<<8;gGz(cd+ch|0,0,256);ci=0;do{cl=1<<3-ci;cm=(c[601464+(ci<<2)>>2]|0)+ch|0;cn=0;do{cq=cm+(c[611776+(cn<<2)>>2]|0)|0;cp=(cn<<4)+ch|0;co=0;do{cr=cq+(c[601400+(co<<2)>>2]|0)|0;if((d[cg+((cr|0)/8|0)|0]&128>>>((cr&7)>>>0)|0)!=0){cr=cd+(cp+co)|0;a[cr]=(d[cr]|cl)&255}co=co+1|0;}while((co|0)<16);cn=cn+1|0;}while((cn|0)<16);ci=ci+1|0;}while((ci|0)<4);ce=ce+1|0;}while((ce|0)<16384);ce=cd+2097152|0;if((gGH(ce|0,cd+3145728|0,1048576)|0)==0){gGC(ce|0,cd|0,2097152)|0;cE=0}else{cE=0}while(1){if((cE|0)>=1024){break L64744}cF=9638528+(cE<<2)|0;if((c[cF>>2]|0)==(cg|0)){break}else{cE=cE+1|0}}gGr(cg);c[cF>>2]=0;break};case 7:{cd=ca+65536|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}ce=aV+108|0;c[ce>>2]=0;ci=aV+100|0;c[ci>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](aV,0)|0;do{if((c[ce>>2]|0)!=0){ch=c[ci>>2]|0;c[aW>>2]=9534384;cn=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[cn&16383](aW,0,0)|0;if((ch|0)<1){cf=1;i=f;return cf|0}if((gzL(cd,0,0)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);cd=c[3529224]|0;ci=cd+65536|0;gGC(cd|0,ci|0,32768)|0;ci=c[3529180]|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}cd=aT+108|0;c[cd>>2]=0;ce=aT+100|0;c[ce>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](aT,1)|0;do{if((c[cd>>2]|0)!=0){cg=c[ce>>2]|0;c[aU>>2]=9534384;ch=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ch&16383](aU,1,0)|0;if((cg|0)<1){cf=1;i=f;return cf|0}if((gzL(ci,0,1)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);ci=c[2387808]|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}ce=aR+108|0;c[ce>>2]=0;cd=aR+100|0;c[cd>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](aR,2)|0;do{if((c[ce>>2]|0)!=0){cg=c[cd>>2]|0;c[aS>>2]=9534384;ch=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ch&16383](aS,2,0)|0;if((cg|0)<1){cf=1;i=f;return cf|0}if((gzL(ci,0,2)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);ci=(c[2387808]|0)+524288|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}cd=aP+108|0;c[cd>>2]=0;ce=aP+100|0;c[ce>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](aP,3)|0;do{if((c[cd>>2]|0)==0){cG=0}else{cg=c[ce>>2]|0;c[aQ>>2]=9534384;ch=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ch&16383](aQ,3,0)|0;if((cg|0)<1){cf=1;i=f;return cf|0}if((gzL(ci,0,3)|0)==0){cG=0;break}else{cf=1}i=f;return cf|0}}while(0);while(1){if((cG|0)>=1024){break L64744}cH=9638528+(cG<<2)|0;if((c[cH>>2]|0)==0){break}else{cG=cG+1|0}}ci=gGq(1048576)|0;c[cH>>2]=ci;if((ci|0)==0){break L64744}gGz(ci|0,0,1048576);ce=c[2387808]|0;gGC(ci|0,ce|0,1048576)|0;cd=0;do{cg=cd<<8;gGz(ce+cg|0,0,256);ch=cd<<9;cn=0;do{cl=1<<3-cn;cm=(c[597928+(cn<<2)>>2]|0)+ch|0;co=0;do{cp=cm+(c[597800+(co<<2)>>2]|0)|0;cq=(co<<4)+cg|0;cr=0;do{cI=cp+(c[597864+(cr<<2)>>2]|0)|0;if((d[ci+((cI|0)/8|0)|0]&128>>>((cI&7)>>>0)|0)!=0){cI=ce+(cq+cr)|0;a[cI]=(d[cI]|cl)&255}cr=cr+1|0;}while((cr|0)<16);co=co+1|0;}while((co|0)<16);cn=cn+1|0;}while((cn|0)<4);cd=cd+1|0;}while((cd|0)<8192);cd=ce+2097152|0;gGC(cd|0,ce|0,2097152)|0;cd=0;while(1){if((cd|0)>=1024){break L64744}cJ=9638528+(cd<<2)|0;if((c[cJ>>2]|0)==(ci|0)){break}else{cd=cd+1|0}}gGr(ci);c[cJ>>2]=0;break};case 2:{cd=ca+65536|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}ce=aN+108|0;c[ce>>2]=0;cn=aN+100|0;c[cn>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](aN,0)|0;do{if((c[ce>>2]|0)!=0){cg=c[cn>>2]|0;c[aO>>2]=9534384;ch=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ch&16383](aO,0,0)|0;if((cg|0)<1){cf=1;i=f;return cf|0}if((gzL(cd,0,0)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);cd=c[3529224]|0;cn=cd+65536|0;gGC(cd|0,cn|0,32768)|0;cn=c[3529180]|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}cd=aL+108|0;c[cd>>2]=0;ce=aL+100|0;c[ce>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](aL,1)|0;do{if((c[cd>>2]|0)!=0){ci=c[ce>>2]|0;c[aM>>2]=9534384;cg=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[cg&16383](aM,1,0)|0;if((ci|0)<1){cf=1;i=f;return cf|0}if((gzL(cn,0,1)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);cn=c[2387808]|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}ce=aJ+108|0;c[ce>>2]=0;cd=aJ+100|0;c[cd>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](aJ,3)|0;do{if((c[ce>>2]|0)!=0){ci=c[cd>>2]|0;c[aK>>2]=9534384;cg=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[cg&16383](aK,3,0)|0;if((ci|0)<1){cf=1;i=f;return cf|0}if((gzL(cn,0,3)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);cn=(c[2387808]|0)+524288|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}cd=aH+108|0;c[cd>>2]=0;ce=aH+100|0;c[ce>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](aH,4)|0;do{if((c[cd>>2]|0)!=0){ci=c[ce>>2]|0;c[aI>>2]=9534384;cg=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[cg&16383](aI,4,0)|0;if((ci|0)<1){cf=1;i=f;return cf|0}if((gzL(cn,0,4)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);cn=(c[2387808]|0)+1048576|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}ce=aF+108|0;c[ce>>2]=0;cd=aF+100|0;c[cd>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](aF,5)|0;do{if((c[ce>>2]|0)!=0){ci=c[cd>>2]|0;c[aG>>2]=9534384;cg=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[cg&16383](aG,5,0)|0;if((ci|0)<1){cf=1;i=f;return cf|0}if((gzL(cn,0,5)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);cn=(c[2387808]|0)+1572864|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}cd=aD+108|0;c[cd>>2]=0;ce=aD+100|0;c[ce>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](aD,6)|0;do{if((c[cd>>2]|0)!=0){ci=c[ce>>2]|0;c[aE>>2]=9534384;cg=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[cg&16383](aE,6,0)|0;if((ci|0)<1){cf=1;i=f;return cf|0}if((gzL(cn,0,6)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);if((R6((c[3530992]|0)+1|0,7,2)|0)!=0){cf=1;i=f;return cf|0}if((R6(c[3530992]|0,8,2)|0)==0){cK=0}else{cf=1;i=f;return cf|0}while(1){if((cK|0)>=1024){cf=1;cc=50327;break}cL=9638528+(cK<<2)|0;if((c[cL>>2]|0)==0){break}else{cK=cK+1|0}}if((cc|0)==50327){i=f;return cf|0}cn=gGq(2097152)|0;c[cL>>2]=cn;if((cn|0)==0){cf=1;i=f;return cf|0}gGz(cn|0,0,2097152);ce=c[2387808]|0;gGC(cn|0,ce|0,2097152)|0;cd=0;do{ci=cd<<8;gGz(ce+ci|0,0,256);cg=0;do{ch=1<<3-cg;co=(c[601464+(cg<<2)>>2]|0)+ci|0;cl=0;do{cm=co+(c[611776+(cl<<2)>>2]|0)|0;cr=(cl<<4)+ci|0;cq=0;do{cp=cm+(c[601400+(cq<<2)>>2]|0)|0;if((d[cn+((cp|0)/8|0)|0]&128>>>((cp&7)>>>0)|0)!=0){cp=ce+(cr+cq)|0;a[cp]=(d[cp]|ch)&255}cq=cq+1|0;}while((cq|0)<16);cl=cl+1|0;}while((cl|0)<16);cg=cg+1|0;}while((cg|0)<4);cd=cd+1|0;}while((cd|0)<16384);cd=ce+2097152|0;if((gGH(cd|0,ce+3145728|0,1048576)|0)==0){gGC(cd|0,ce|0,2097152)|0;cM=0}else{cM=0}while(1){if((cM|0)>=1024){break L64744}cN=9638528+(cM<<2)|0;if((c[cN>>2]|0)==(cn|0)){break}else{cM=cM+1|0}}gGr(cn);c[cN>>2]=0;break};case 5:{ce=ca+65536|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}cd=aB+108|0;c[cd>>2]=0;cg=aB+100|0;c[cg>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](aB,0)|0;do{if((c[cd>>2]|0)!=0){ci=c[cg>>2]|0;c[aC>>2]=9534384;cl=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[cl&16383](aC,0,0)|0;if((ci|0)<1){cf=1;i=f;return cf|0}if((gzL(ce,0,0)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);ce=c[3529224]|0;cg=ce+65536|0;gGC(ce|0,cg|0,32768)|0;cg=ce+131072|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}ce=az+108|0;c[ce>>2]=0;cd=az+100|0;c[cd>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](az,1)|0;do{if((c[ce>>2]|0)!=0){cn=c[cd>>2]|0;c[aA>>2]=9534384;ci=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ci&16383](aA,1,0)|0;if((cn|0)<1){cf=1;i=f;return cf|0}if((gzL(cg,0,1)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);cg=c[3529180]|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}cd=ax+108|0;c[cd>>2]=0;ce=ax+100|0;c[ce>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](ax,2)|0;do{if((c[cd>>2]|0)!=0){cn=c[ce>>2]|0;c[ay>>2]=9534384;ci=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ci&16383](ay,2,0)|0;if((cn|0)<1){cf=1;i=f;return cf|0}if((gzL(cg,0,2)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);cg=c[2387808]|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}ce=av+108|0;c[ce>>2]=0;cd=av+100|0;c[cd>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](av,4)|0;do{if((c[ce>>2]|0)!=0){cn=c[cd>>2]|0;c[aw>>2]=9534384;ci=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ci&16383](aw,4,0)|0;if((cn|0)<1){cf=1;i=f;return cf|0}if((gzL(cg,0,4)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);cg=(c[2387808]|0)+65536|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}cd=at+108|0;c[cd>>2]=0;ce=at+100|0;c[ce>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](at,4)|0;do{if((c[cd>>2]|0)!=0){cn=c[ce>>2]|0;c[au>>2]=9534384;ci=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ci&16383](au,4,0)|0;if((cn|0)<1){cf=1;i=f;return cf|0}if((gzL(cg,0,4)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);cg=(c[2387808]|0)+131072|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}ce=ar+108|0;c[ce>>2]=0;cd=ar+100|0;c[cd>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](ar,5)|0;do{if((c[ce>>2]|0)!=0){cn=c[cd>>2]|0;c[as>>2]=9534384;ci=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ci&16383](as,5,0)|0;if((cn|0)<1){cf=1;i=f;return cf|0}if((gzL(cg,0,5)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);cg=(c[2387808]|0)+196608|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}cd=ap+108|0;c[cd>>2]=0;ce=ap+100|0;c[ce>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](ap,5)|0;do{if((c[cd>>2]|0)!=0){cn=c[ce>>2]|0;c[aq>>2]=9534384;ci=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ci&16383](aq,5,0)|0;if((cn|0)<1){cf=1;i=f;return cf|0}if((gzL(cg,0,5)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);cg=(c[2387808]|0)+524288|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}ce=an+108|0;c[ce>>2]=0;cd=an+100|0;c[cd>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](an,6)|0;do{if((c[ce>>2]|0)!=0){cn=c[cd>>2]|0;c[ao>>2]=9534384;ci=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ci&16383](ao,6,0)|0;if((cn|0)<1){cf=1;i=f;return cf|0}if((gzL(cg,0,6)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);cg=(c[2387808]|0)+589824|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}cd=al+108|0;c[cd>>2]=0;ce=al+100|0;c[ce>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](al,6)|0;do{if((c[cd>>2]|0)!=0){cn=c[ce>>2]|0;c[am>>2]=9534384;ci=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ci&16383](am,6,0)|0;if((cn|0)<1){cf=1;i=f;return cf|0}if((gzL(cg,0,6)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);cg=(c[2387808]|0)+655360|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}ce=aj+108|0;c[ce>>2]=0;cd=aj+100|0;c[cd>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](aj,7)|0;do{if((c[ce>>2]|0)!=0){cn=c[cd>>2]|0;c[ak>>2]=9534384;ci=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ci&16383](ak,7,0)|0;if((cn|0)<1){cf=1;i=f;return cf|0}if((gzL(cg,0,7)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);cg=(c[2387808]|0)+720896|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}cd=ah+108|0;c[cd>>2]=0;ce=ah+100|0;c[ce>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](ah,7)|0;do{if((c[cd>>2]|0)!=0){cn=c[ce>>2]|0;c[ai>>2]=9534384;ci=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ci&16383](ai,7,0)|0;if((cn|0)<1){cf=1;i=f;return cf|0}if((gzL(cg,0,7)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);cg=(c[2387808]|0)+1048576|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}ce=ae+108|0;c[ce>>2]=0;cd=ae+100|0;c[cd>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](ae,8)|0;do{if((c[ce>>2]|0)!=0){cn=c[cd>>2]|0;c[af>>2]=9534384;ci=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ci&16383](af,8,0)|0;if((cn|0)<1){cf=1;i=f;return cf|0}if((gzL(cg,0,8)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);cg=(c[2387808]|0)+1114112|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}cd=ac+108|0;c[cd>>2]=0;ce=ac+100|0;c[ce>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](ac,8)|0;do{if((c[cd>>2]|0)!=0){cn=c[ce>>2]|0;c[ad>>2]=9534384;ci=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ci&16383](ad,8,0)|0;if((cn|0)<1){cf=1;i=f;return cf|0}if((gzL(cg,0,8)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);cg=(c[2387808]|0)+1179648|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}ce=aa+108|0;c[ce>>2]=0;cd=aa+100|0;c[cd>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](aa,9)|0;do{if((c[ce>>2]|0)!=0){cn=c[cd>>2]|0;c[ab>>2]=9534384;ci=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ci&16383](ab,9,0)|0;if((cn|0)<1){cf=1;i=f;return cf|0}if((gzL(cg,0,9)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);cg=(c[2387808]|0)+1245184|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}cd=_+108|0;c[cd>>2]=0;ce=_+100|0;c[ce>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](_,9)|0;do{if((c[cd>>2]|0)!=0){cn=c[ce>>2]|0;c[$>>2]=9534384;ci=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ci&16383]($,9,0)|0;if((cn|0)<1){cf=1;i=f;return cf|0}if((gzL(cg,0,9)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);cg=(c[2387808]|0)+1572864|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}ce=Y+108|0;c[ce>>2]=0;cd=Y+100|0;c[cd>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](Y,10)|0;do{if((c[ce>>2]|0)!=0){cn=c[cd>>2]|0;c[Z>>2]=9534384;ci=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ci&16383](Z,10,0)|0;if((cn|0)<1){cf=1;i=f;return cf|0}if((gzL(cg,0,10)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);cg=(c[2387808]|0)+1638400|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}cd=W+108|0;c[cd>>2]=0;ce=W+100|0;c[ce>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](W,10)|0;do{if((c[cd>>2]|0)!=0){cn=c[ce>>2]|0;c[X>>2]=9534384;ci=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ci&16383](X,10,0)|0;if((cn|0)<1){cf=1;i=f;return cf|0}if((gzL(cg,0,10)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);cg=(c[2387808]|0)+1703936|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}ce=U+108|0;c[ce>>2]=0;cd=U+100|0;c[cd>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](U,11)|0;do{if((c[ce>>2]|0)!=0){cn=c[cd>>2]|0;c[V>>2]=9534384;ci=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ci&16383](V,11,0)|0;if((cn|0)<1){cf=1;i=f;return cf|0}if((gzL(cg,0,11)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);cg=(c[2387808]|0)+1769472|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}cd=S+108|0;c[cd>>2]=0;ce=S+100|0;c[ce>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](S,11)|0;do{if((c[cd>>2]|0)!=0){cn=c[ce>>2]|0;c[T>>2]=9534384;ci=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ci&16383](T,11,0)|0;if((cn|0)<1){cf=1;i=f;return cf|0}if((gzL(cg,0,11)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);if((R6((c[3530992]|0)+1|0,12,2)|0)!=0){cf=1;i=f;return cf|0}if((R6(c[3530992]|0,13,2)|0)==0){cO=0}else{cf=1;i=f;return cf|0}while(1){if((cO|0)>=1024){cf=1;cc=50388;break}cP=9638528+(cO<<2)|0;if((c[cP>>2]|0)==0){break}else{cO=cO+1|0}}if((cc|0)==50388){i=f;return cf|0}cg=gGq(2097152)|0;c[cP>>2]=cg;if((cg|0)==0){cf=1;i=f;return cf|0}gGz(cg|0,0,2097152);ce=c[2387808]|0;gGC(cg|0,ce|0,2097152)|0;cd=0;do{cn=cd<<8;gGz(ce+cn|0,0,256);ci=0;do{cl=1<<3-ci;ch=(c[601464+(ci<<2)>>2]|0)+cn|0;co=0;do{cq=ch+(c[611776+(co<<2)>>2]|0)|0;cr=(co<<4)+cn|0;cm=0;do{cp=cq+(c[601400+(cm<<2)>>2]|0)|0;if((d[cg+((cp|0)/8|0)|0]&128>>>((cp&7)>>>0)|0)!=0){cp=ce+(cr+cm)|0;a[cp]=(d[cp]|cl)&255}cm=cm+1|0;}while((cm|0)<16);co=co+1|0;}while((co|0)<16);ci=ci+1|0;}while((ci|0)<4);cd=cd+1|0;}while((cd|0)<16384);cd=ce+2097152|0;if((gGH(cd|0,ce+3145728|0,1048576)|0)==0){gGC(cd|0,ce|0,2097152)|0;cQ=0}else{cQ=0}while(1){if((cQ|0)>=1024){break L64744}cR=9638528+(cQ<<2)|0;if((c[cR>>2]|0)==(cg|0)){break}else{cQ=cQ+1|0}}gGr(cg);c[cR>>2]=0;break};case 8:{ce=ca+65536|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}cd=Q+108|0;c[cd>>2]=0;ci=Q+100|0;c[ci>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](Q,0)|0;do{if((c[cd>>2]|0)!=0){cn=c[ci>>2]|0;c[R>>2]=9534384;co=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[co&16383](R,0,0)|0;if((cn|0)<1){cf=1;i=f;return cf|0}if((gzL(ce,0,0)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);ce=c[3529224]|0;ci=ce+65536|0;gGC(ce|0,ci|0,32768)|0;ci=ce+131072|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}ce=O+108|0;c[ce>>2]=0;cd=O+100|0;c[cd>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](O,1)|0;do{if((c[ce>>2]|0)!=0){cg=c[cd>>2]|0;c[P>>2]=9534384;cn=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[cn&16383](P,1,0)|0;if((cg|0)<1){cf=1;i=f;return cf|0}if((gzL(ci,0,1)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);ci=c[3529180]|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}cd=M+108|0;c[cd>>2]=0;ce=M+100|0;c[ce>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](M,2)|0;do{if((c[cd>>2]|0)!=0){cg=c[ce>>2]|0;c[N>>2]=9534384;cn=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[cn&16383](N,2,0)|0;if((cg|0)<1){cf=1;i=f;return cf|0}if((gzL(ci,0,2)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);ci=c[2387808]|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}ce=K+108|0;c[ce>>2]=0;cd=K+100|0;c[cd>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](K,3)|0;do{if((c[ce>>2]|0)!=0){cg=c[cd>>2]|0;c[L>>2]=9534384;cn=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[cn&16383](L,3,0)|0;if((cg|0)<1){cf=1;i=f;return cf|0}if((gzL(ci,0,3)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);ci=(c[2387808]|0)+131072|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}cd=I+108|0;c[cd>>2]=0;ce=I+100|0;c[ce>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](I,4)|0;do{if((c[cd>>2]|0)!=0){cg=c[ce>>2]|0;c[J>>2]=9534384;cn=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[cn&16383](J,4,0)|0;if((cg|0)<1){cf=1;i=f;return cf|0}if((gzL(ci,0,4)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);ci=(c[2387808]|0)+524288|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}ce=G+108|0;c[ce>>2]=0;cd=G+100|0;c[cd>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](G,5)|0;do{if((c[ce>>2]|0)!=0){cg=c[cd>>2]|0;c[H>>2]=9534384;cn=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[cn&16383](H,5,0)|0;if((cg|0)<1){cf=1;i=f;return cf|0}if((gzL(ci,0,5)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);ci=(c[2387808]|0)+655360|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}cd=E+108|0;c[cd>>2]=0;ce=E+100|0;c[ce>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](E,6)|0;do{if((c[cd>>2]|0)!=0){cg=c[ce>>2]|0;c[F>>2]=9534384;cn=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[cn&16383](F,6,0)|0;if((cg|0)<1){cf=1;i=f;return cf|0}if((gzL(ci,0,6)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);ci=(c[2387808]|0)+1048576|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}ce=C+108|0;c[ce>>2]=0;cd=C+100|0;c[cd>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](C,7)|0;do{if((c[ce>>2]|0)!=0){cg=c[cd>>2]|0;c[D>>2]=9534384;cn=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[cn&16383](D,7,0)|0;if((cg|0)<1){cf=1;i=f;return cf|0}if((gzL(ci,0,7)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);ci=(c[2387808]|0)+1179648|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}cd=A+108|0;c[cd>>2]=0;ce=A+100|0;c[ce>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](A,8)|0;do{if((c[cd>>2]|0)!=0){cg=c[ce>>2]|0;c[B>>2]=9534384;cn=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[cn&16383](B,8,0)|0;if((cg|0)<1){cf=1;i=f;return cf|0}if((gzL(ci,0,8)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);ci=(c[2387808]|0)+1572864|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}ce=y+108|0;c[ce>>2]=0;cd=y+100|0;c[cd>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](y,9)|0;do{if((c[ce>>2]|0)!=0){cg=c[cd>>2]|0;c[z>>2]=9534384;cn=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[cn&16383](z,9,0)|0;if((cg|0)<1){cf=1;i=f;return cf|0}if((gzL(ci,0,9)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);ci=(c[2387808]|0)+1703936|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}cd=w+108|0;c[cd>>2]=0;ce=w+100|0;c[ce>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](w,10)|0;do{if((c[cd>>2]|0)!=0){cg=c[ce>>2]|0;c[x>>2]=9534384;cn=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[cn&16383](x,10,0)|0;if((cg|0)<1){cf=1;i=f;return cf|0}if((gzL(ci,0,10)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);ci=c[2386602]|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}ce=u+108|0;c[ce>>2]=0;cd=u+100|0;c[cd>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](u,11)|0;do{if((c[ce>>2]|0)==0){cS=0}else{cg=c[cd>>2]|0;c[v>>2]=9534384;cn=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[cn&16383](v,11,0)|0;if((cg|0)<1){cf=1;i=f;return cf|0}if((gzL(ci,0,11)|0)==0){cS=0;break}else{cf=1}i=f;return cf|0}}while(0);while(1){if((cS|0)>=1024){cf=1;cc=50426;break}cT=9638528+(cS<<2)|0;if((c[cT>>2]|0)==0){break}else{cS=cS+1|0}}if((cc|0)==50426){i=f;return cf|0}ci=gGq(2097152)|0;c[cT>>2]=ci;if((ci|0)==0){cf=1;i=f;return cf|0}gGz(ci|0,0,2097152);cd=c[2387808]|0;gGC(ci|0,cd|0,2097152)|0;ce=0;do{cg=ce<<8;gGz(cd+cg|0,0,256);cn=0;do{co=1<<3-cn;cl=(c[601464+(cn<<2)>>2]|0)+cg|0;ch=0;do{cm=cl+(c[611776+(ch<<2)>>2]|0)|0;cr=(ch<<4)+cg|0;cq=0;do{cp=cm+(c[601400+(cq<<2)>>2]|0)|0;if((d[ci+((cp|0)/8|0)|0]&128>>>((cp&7)>>>0)|0)!=0){cp=cd+(cr+cq)|0;a[cp]=(d[cp]|co)&255}cq=cq+1|0;}while((cq|0)<16);ch=ch+1|0;}while((ch|0)<16);cn=cn+1|0;}while((cn|0)<4);ce=ce+1|0;}while((ce|0)<16384);ce=cd+2097152|0;if((gGH(ce|0,cd+3145728|0,1048576)|0)==0){gGC(ce|0,cd|0,2097152)|0;cU=0}else{cU=0}while(1){if((cU|0)>=1024){break}cV=9638528+(cU<<2)|0;if((c[cV>>2]|0)==(ci|0)){cc=50057;break}else{cU=cU+1|0}}if((cc|0)==50057){gGr(ci);c[cV>>2]=0}cd=c[2386602]|0;ce=0;do{cn=ce<<1;cg=d[cd+((cn|1)+144)|0]<<8|d[cd+(cn+144)|0];cn=cg+144|0;ch=cd+cn|0;if((a[ch]|0)==0){cW=0}else{co=ch;ch=0;while(1){cl=co+1|0;cq=ch+1|0;if((a[cl]|0)==0){cW=cq;break}else{co=cl;ch=cq}}}ch=cW<<1;co=0;while(1){if((co|0)>=1024){cX=0;break}cY=9638528+(co<<2)|0;if((c[cY>>2]|0)==0){cc=50064;break}else{co=co+1|0}}do{if((cc|0)==50064){cc=0;co=gGq(ch)|0;c[cY>>2]=co;if((co|0)==0){cX=0;break}gGz(co|0,0,ch|0);cX=co}}while(0);c[9719832+(ce<<2)>>2]=cX;c[9719640+(ce<<2)>>2]=cW;ch=cg>>>0<256;co=ch?0:cW;if((co|0)>0){cq=cd+(ch?144:cn)|0;ch=cX;cl=0;while(1){b[ch>>1]=d[cq]<<8^-32768;cr=cl+1|0;if((cr|0)<(co|0)){cq=cq+1|0;ch=ch+2|0;cl=cr}else{break}}}ce=ce+1|0;}while((ce|0)<47);h[117832]=1.0;a[683840]=1;break};case 9:{ce=ca+65536|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}cd=s+108|0;c[cd>>2]=0;ci=s+100|0;c[ci>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](s,0)|0;do{if((c[cd>>2]|0)!=0){cl=c[ci>>2]|0;c[t>>2]=9534384;ch=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ch&16383](t,0,0)|0;if((cl|0)<1){cf=1;i=f;return cf|0}if((gzL(ce,0,0)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);ce=c[3529224]|0;ci=ce+65536|0;gGC(ce|0,ci|0,32768)|0;ci=c[3529180]|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}ce=q+108|0;c[ce>>2]=0;cd=q+100|0;c[cd>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](q,1)|0;do{if((c[ce>>2]|0)!=0){cl=c[cd>>2]|0;c[r>>2]=9534384;ch=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ch&16383](r,1,0)|0;if((cl|0)<1){cf=1;i=f;return cf|0}if((gzL(ci,0,1)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);ci=c[2387808]|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}cd=o+108|0;c[cd>>2]=0;ce=o+100|0;c[ce>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](o,2)|0;do{if((c[cd>>2]|0)!=0){cl=c[ce>>2]|0;c[p>>2]=9534384;ch=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ch&16383](p,2,0)|0;if((cl|0)<1){cf=1;i=f;return cf|0}if((gzL(ci,0,2)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);ci=c[2387808]|0;ce=ci+131072|0;cd=ci+65536|0;gGC(ce|0,cd|0,65536)|0;cd=ci+524288|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}ci=m+108|0;c[ci>>2]=0;ce=m+100|0;c[ce>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,3)|0;do{if((c[ci>>2]|0)!=0){cl=c[ce>>2]|0;c[n>>2]=9534384;ch=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ch&16383](n,3,0)|0;if((cl|0)<1){cf=1;i=f;return cf|0}if((gzL(cd,0,3)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);cd=c[2387808]|0;ce=cd+655360|0;ci=cd+589824|0;gGC(ce|0,ci|0,65536)|0;ci=cd+1048576|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}cd=k+108|0;c[cd>>2]=0;ce=k+100|0;c[ce>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,4)|0;do{if((c[cd>>2]|0)!=0){cl=c[ce>>2]|0;c[l>>2]=9534384;ch=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ch&16383](l,4,0)|0;if((cl|0)<1){cf=1;i=f;return cf|0}if((gzL(ci,0,4)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);ci=c[2387808]|0;ce=ci+1179648|0;cd=ci+1114112|0;gGC(ce|0,cd|0,65536)|0;cd=ci+1572864|0;if((c[3542200]|0)==0){cf=1;i=f;return cf|0}ci=g+108|0;c[ci>>2]=0;ce=g+100|0;c[ce>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,5)|0;do{if((c[ci>>2]|0)!=0){cl=c[ce>>2]|0;c[j>>2]=9534384;ch=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ch&16383](j,5,0)|0;if((cl|0)<1){cf=1;i=f;return cf|0}if((gzL(cd,0,5)|0)==0){break}else{cf=1}i=f;return cf|0}}while(0);cd=c[2387808]|0;ce=cd+1703936|0;ci=cd+1638400|0;gGC(ce|0,ci|0,65536)|0;ci=0;while(1){if((ci|0)>=1024){cf=1;cc=50446;break}cZ=9638528+(ci<<2)|0;if((c[cZ>>2]|0)==0){break}else{ci=ci+1|0}}if((cc|0)==50446){i=f;return cf|0}ci=gGq(2097152)|0;c[cZ>>2]=ci;if((ci|0)==0){cf=1;i=f;return cf|0}gGz(ci|0,0,2097152);ce=c[2387808]|0;gGC(ci|0,ce|0,2097152)|0;cd=0;do{cl=cd<<8;gGz(ce+cl|0,0,256);ch=0;do{cq=1<<3-ch;co=(c[601464+(ch<<2)>>2]|0)+cl|0;cn=0;do{cg=co+(c[611776+(cn<<2)>>2]|0)|0;cr=(cn<<4)+cl|0;cm=0;do{cp=cg+(c[601400+(cm<<2)>>2]|0)|0;if((d[ci+((cp|0)/8|0)|0]&128>>>((cp&7)>>>0)|0)!=0){cp=ce+(cr+cm)|0;a[cp]=(d[cp]|cq)&255}cm=cm+1|0;}while((cm|0)<16);cn=cn+1|0;}while((cn|0)<16);ch=ch+1|0;}while((ch|0)<4);cd=cd+1|0;}while((cd|0)<16384);cd=ce+2097152|0;if((gGH(cd|0,ce+3145728|0,1048576)|0)==0){gGC(cd|0,ce|0,2097152)|0;c_=0}else{c_=0}while(1){if((c_|0)>=1024){break L64744}c$=9638528+(c_<<2)|0;if((c[c$>>2]|0)==(ci|0)){break}else{c_=c_+1|0}}gGr(ci);c[c$>>2]=0;break};default:{}}}while(0);fwR(0);ca=c[2439330]|0;ce=(ca|0)==0;if(!ce){cd=ca;gGC(9706056,cd|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];cd=c[3528484]|0;c[2076596]=cd;ch=c[2417276]|0;c[3541536]=ch;c[1836236]=0;cl=c[3529224]|0;cn=0;cq=0;while(1){c[ca+76+(cq<<2)>>2]=cl+(cq<<8);co=cn+1&65535;if((co&65535)>127){c0=0;c1=0;break}else{cn=co;cq=co&65535}}while(1){cq=cl+(c1<<8)|0;c[ca+76+(c1+512<<2)>>2]=cq;c[ca+76+(c1+768<<2)>>2]=cq;cq=c0+1&65535;if((cq&65535)>127){c2=128;c3=128;break}else{c0=cq;c1=cq&65535}}while(1){c[ca+76+(c3<<2)>>2]=cl+((c3<<8)+65536);cq=c2+1&65535;if((cq&65535)>191){c4=128;c5=128;break}else{c2=cq;c3=cq&65535}}while(1){cq=cl+((c5<<8)+65536)|0;c[ca+76+(c5+512<<2)>>2]=cq;c[ca+76+(c5+768<<2)>>2]=cq;cq=c4+1&65535;if((cq&65535)>191){break}else{c4=cq;c5=cq&65535}}cl=c[2386398]|0;cq=192;cn=192;while(1){c[ca+76+(cn<<2)>>2]=cl+((cn<<8)-49152);co=cq+1&65535;if((co&65535)>223){c6=192;c7=192;break}else{cq=co;cn=co&65535}}while(1){c[ca+76+(c7+256<<2)>>2]=cl+((c7<<8)-49152);cn=c6+1&65535;if((cn&65535)>223){break}else{c6=cn;c7=cn&65535}}cl=c[3527294]|0;c[ca+972>>2]=cl;c[ca+976>>2]=cl+256;c[ca+980>>2]=cl+512;c[ca+984>>2]=cl+768;c[ca+988>>2]=cl+1024;c[ca+992>>2]=cl+1280;c[ca+996>>2]=cl+1536;c[ca+1e3>>2]=cl+1792;c[ca+1004>>2]=cl+2048;c[ca+1008>>2]=cl+2304;c[ca+1012>>2]=cl+2560;c[ca+1016>>2]=cl+2816;c[ca+1020>>2]=cl+3072;c[ca+1024>>2]=cl+3328;c[ca+1028>>2]=cl+3584;if((e|0)==6){c8=224;c9=224}else{c[ca+1032>>2]=cl+3840;c8=224;c9=224}while(1){c[ca+76+(c9+256<<2)>>2]=cl+((c9<<8)-57344);cn=c8+1&65535;if((cn&65535)>239){da=224;db=224;break}else{c8=cn;c9=cn&65535}}while(1){cn=cl+((db<<8)-57344)|0;c[ca+76+(db+512<<2)>>2]=cn;c[ca+76+(db+768<<2)>>2]=cn;cn=da+1&65535;if((cn&65535)>239){break}else{da=cn;db=cn&65535}}cl=c[2386190]|0;c[ca+1036>>2]=cl;cn=cl+256|0;c[ca+1040>>2]=cn;c[ca+2060>>2]=cl;c[ca+2064>>2]=cn;c[ca+2068>>2]=c[2443466];if((e|0)!=3){cn=c[2387124]|0;c[ca+1068>>2]=cn;cl=cn+256|0;c[ca+1072>>2]=cl;cq=cn+512|0;c[ca+1076>>2]=cq;co=cn+768|0;c[ca+1080>>2]=co;c[ca+2092>>2]=cn;c[ca+2096>>2]=cl;c[ca+2100>>2]=cq;c[ca+2104>>2]=co}c[ca+4184>>2]=1286;c[ca+4180>>2]=122;if(!ce){co=ca;gGC(co|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=cd;c[2417276]=ch;c[1836236]=-1;fwR(1);co=c[2439331]|0;cq=(co|0)==0;if(!cq){cl=co;gGC(9706056,cl|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];cl=c[3528485]|0;c[2076596]=cl;cn=c[2417277]|0;c[3541536]=cn;c[1836236]=1;cm=c[3529180]|0;cr=0;cg=0;while(1){c[co+76+(cg<<2)>>2]=cm+(cg<<8);cp=cr+1&65535;if((cp&65535)>159){dc=0;dd=0;break}else{cr=cp;cg=cp&65535}}while(1){cg=cm+(dd<<8)|0;c[co+76+(dd+512<<2)>>2]=cg;c[co+76+(dd+768<<2)>>2]=cg;cg=dc+1&65535;if((cg&65535)>159){break}else{dc=cg;dd=cg&65535}}cm=c[3529274]|0;c[co+908>>2]=cm;c[co+912>>2]=cm+256;c[co+916>>2]=cm+512;c[co+920>>2]=cm+768;c[co+924>>2]=cm+1024;c[co+928>>2]=cm+1280;c[co+932>>2]=cm+1536;c[co+936>>2]=cm+1792;c[co+940>>2]=cm+2048;c[co+944>>2]=cm+2304;c[co+948>>2]=cm+2560;c[co+952>>2]=cm+2816;c[co+956>>2]=cm+3072;c[co+960>>2]=cm+3328;c[co+964>>2]=cm+3584;c[co+968>>2]=cm+3840;cg=208;cr=208;while(1){c[co+76+(cr+256<<2)>>2]=cm+((cr<<8)-53248);ch=cg+1&65535;if((ch&65535)>223){de=208;df=208;break}else{cg=ch;cr=ch&65535}}while(1){cr=cm+((df<<8)-53248)|0;c[co+76+(df+512<<2)>>2]=cr;c[co+76+(df+768<<2)>>2]=cr;cr=de+1&65535;if((cr&65535)>223){break}else{de=cr;df=cr&65535}}cm=c[3527294]|0;c[co+972>>2]=cm;c[co+976>>2]=cm+256;c[co+980>>2]=cm+512;c[co+984>>2]=cm+768;c[co+988>>2]=cm+1024;c[co+992>>2]=cm+1280;c[co+996>>2]=cm+1536;c[co+1e3>>2]=cm+1792;c[co+1004>>2]=cm+2048;c[co+1008>>2]=cm+2304;c[co+1012>>2]=cm+2560;c[co+1016>>2]=cm+2816;c[co+1020>>2]=cm+3072;c[co+1024>>2]=cm+3328;c[co+1028>>2]=cm+3584;c[co+1032>>2]=cm+3840;cr=224;cg=224;while(1){c[co+76+(cg+256<<2)>>2]=cm+((cg<<8)-57344);ch=cr+1&65535;if((ch&65535)>239){dg=224;dh=224;break}else{cr=ch;cg=ch&65535}}while(1){cg=cm+((dh<<8)-57344)|0;c[co+76+(dh+512<<2)>>2]=cg;c[co+76+(dh+768<<2)>>2]=cg;cg=dg+1&65535;if((cg&65535)>239){break}else{dg=cg;dh=cg&65535}}c[co+4184>>2]=1028;c[co+4180>>2]=1282;if(!cq){cm=co;gGC(cm|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=cl;c[2417277]=cn;c[1836236]=-1;fwR(2);c[2432900]=3;c[2432902]=0;c[2444150]=16843009;a[14114256]=0;a[14114248]=0;a[9776584]=0;c[2438236]=0;c[2444148]=0;a[9731616]=12;c[2394788]=e;do{if((e|0)==9){cm=a[9680]|0;cg=cm?32e3:0;if(cm){if(a[9624]|0){cm=cg*3|0;cr=46875;while(1){if((cr|0)>(cm|0)){cr=cr>>1}else{di=1222;dj=cr;break}}}else{di=2462;dj=cg}c[2429380]=dj;c[3542124]=di;mw(3e6,dj);cr=gGq(262144)|0;c[2406684]=cr;gGz(cr|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(3e6,11025)}h[745421]=.3;c[2436794]=3;h[745420]=.3;c[2436792]=3}else{Vr(1,3e6,0,1468,56,0);h[745419]=.3;a[3203368]=1;h[745418]=.3;a[3203360]=1;h[745417]=.3;a[3203352]=1;h[745416]=.3;a[3203344]=1;if((e|0)==8){c[3542224]=1178;c[3542225]=0;c[3542226]=0;c[3542227]=3380;h[745419]=.35;a[3203368]=1;h[745418]=.15;a[3203360]=1;h[745417]=.15;a[3203352]=1;h[745416]=.15;a[3203344]=1;break}else{c[3542224]=1966;c[3542225]=1980;c[3542226]=0;c[3542227]=0;break}}}while(0);c[2405758]=1;gGz(9542544,0,32);c[2385641]=1;h[1192819]=1.0;c[2385642]=3;c[2385643]=3336;cn=0;do{cl=cn*257|0;b[9732544+(cn<<1)>>1]=((cl|0)/2|0)&65535;b[9753784+(cn<<1)>>1]=cl+32768&65535;cn=cn+1|0;}while((cn|0)<256);c[3528842]=1;h[1192819]=1.0;c[2385642]=3;cn=c[642608+(c[2436]<<2)>>2]|0;cl=c[cn+128>>2]|0;if((c[cn+52>>2]&4|0)==0){c[2113068]=cl;co=c[cn+132>>2]|0;c[2113070]=co;c[2443814]=cl;c[2440436]=co;dk=cl;dl=co}else{c[2113070]=cl;co=c[cn+132>>2]|0;c[2113068]=co;c[2440436]=cl;c[2443814]=co;dk=co;dl=cl}cl=ag(dk<<1,dl)|0;co=gGq(cl)|0;c[2112926]=co;if((co|0)!=0){gGz(co|0,0,cl|0)}fcm();cf=0;i=f;return cf|0}}while(0);c[2414882]=0;cf=1;i=f;return cf|0}function fcf(a){a=a|0;var b=0,d=0;b=(c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,6e6,0)|0;return a|0}function fcg(){return+(+((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)/6.0e6)}function fch(b){b=b|0;var d=0,e=0,f=0;b=a[9634776]|0;d=a[9634777]|0;e=c[2430470]&3;if((e|0)==1){f=(b&255)>>>5&2|d&4|(b&255)>>>2&1|(d&255)>>>3&8;return f|0}else if((e|0)==0){f=(b&255)>>>3&2|b&1|d<<2&4|(d&255)>>>1&8;return f|0}else if((e|0)==2){f=(b&255)>>>1&1|(b&255)>>>4&2|d<<1&4|(d&255)>>>2&8;return f|0}else if((e|0)==3){f=(b&255)>>>3&1|(b&255)>>>6&2|(d&255)>>>1&4|(d&255)>>>4&8;return f|0}else{f=15;return f|0}return 0}function fci(a,b){a=a|0;b=b|0;if(b>>>0>63){c[2430470]=b;return}if(b>>>0>47){c[2429392]=-1;return}else{c[2429392]=b;h[136404]=0.0;return}}function fcj(b){b=b|0;return a[9634776]|0}function fck(b){b=b|0;return a[9634777]|0}function fcl(){return~~((a[9688]|0?534.0:0.0)*(+((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)/(6.0e6/(+(c[2424]|0)/100.0))))|0}function fcm(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=c[2414584]|0;gGz(d|0,0,(c[2411528]|0)-d|0);d=c[2387124]|0;e=c[3530992]|0;gGC(d|0,e|0,1024)|0;c[3528804]=0;e=c[2439330]|0;if((e|0)!=0){d=e;gGC(9706056,d|0,76)|0}c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;gGz(9706056,0,76);faP(18);d=c[1836236]|0;e=c[9757320+(d<<2)>>2]|0;if((e|0)!=0){f=e;gGC(f|0,9706056,76)|0}c[9752472+(d<<2)>>2]=c[2433530];c[14113936+(d<<2)>>2]=c[2076596];c[9669104+(d<<2)>>2]=c[3541536];c[1836236]=-1;d=c[2439331]|0;f=(d|0)==0;if(!f){e=d;gGC(9706056,e|0,76)|0}c[2433530]=c[2438119];e=c[3528485]|0;c[2076596]=e;g=c[2417277]|0;c[3541536]=g;c[1836236]=1;gGz(9706056,0,76);c[3528187]=0;a[c[2442886]|0]=48;i=c[3529180]|0;j=128;k=128;while(1){c[d+76+(k<<2)>>2]=i+(k<<8);l=j+1&65535;if((l&65535)>159){m=128;n=128;break}else{j=l;k=l&65535}}while(1){k=i+(n<<8)|0;c[d+76+(n+512<<2)>>2]=k;c[d+76+(n+768<<2)>>2]=k;k=m+1&65535;if((k&65535)>159){break}else{m=k;n=k&65535}}if(!f){f=d;gGC(f|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=e;c[2417277]=g;c[1836236]=-1;g=c[2439332]|0;e=(g|0)==0;if(!e){f=g;gGC(9706056,f|0,76)|0}c[2433530]=c[2438120];f=c[3528486]|0;c[2076596]=f;d=c[2417278]|0;c[3541536]=d;c[1836236]=2;gGz(9706056,0,76);c[3528188]=0;n=c[3529166]|0;m=128;i=128;while(1){c[g+76+(i<<2)>>2]=n+((i<<8)-32768);k=m+1&65535;if((k&65535)>191){o=128;p=128;break}else{m=k;i=k&65535}}while(1){i=n+((p<<8)-32768)|0;c[g+76+(p+512<<2)>>2]=i;c[g+76+(p+768<<2)>>2]=i;i=o+1&65535;if((i&65535)>191){break}else{o=i;p=i&65535}}if(!e){e=g;gGC(e|0,9706056,76)|0}c[2438120]=c[2433530];c[3528486]=f;c[2417278]=d;c[1836236]=-1;c[2432900]=3;c[2432902]=0;c[2444150]=16843009;a[14114256]=0;a[14114248]=0;a[9776584]=0;c[2438236]=0;c[2444148]=0;a[9731616]=12;do{if((c[2394788]|0)==9){mx(0)}else{c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){q=0}else{break}do{lN(q);mB(q);q=q+1|0;}while((q|0)<(c[2385508]|0))}}while(0);q=c[2405758]|0;if((q|0)>0){r=0}else{h[136404]=0.0;c[2429392]=-1;return}do{c[9542560+(r<<5)>>2]=0;b[9542544+(r<<5)>>1]=0;r=r+1|0;}while((r|0)<(q|0));h[136404]=0.0;c[2429392]=-1;return}function fcn(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;if((b|0)==255){return}c[3528188]=b;a=c[3529166]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=(b<<14&114688)-32768|0;b=128;f=128;while(1){c[d+76+(f<<2)>>2]=a+(e+(f<<8));g=b+1&65535;if((g&65535)>191){h=128;i=128;break}else{b=g;f=g&65535}}while(1){f=a+(e+(i<<8))|0;c[d+76+(i+512<<2)>>2]=f;c[d+76+(i+768<<2)>>2]=f;f=h+1&65535;if((f&65535)>191){break}else{h=f;i=f&65535}}return}function fco(b,c){b=b|0;c=c|0;b=c&1;if(!((a[9706115]|0)!=0|(b|0)==0)){a[9706116]=1}a[9706115]=b&255;return}function fcp(a,d){a=a|0;d=d|0;if((d|0)==255){return}US(0,gD[c[2385643]&8191]()|0);b[4771272]=~~(+(b[9732544+((d&255)<<1)>>1]|0)*+h[1192819])&65535;return}function fcq(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0;i=(g|0)!=0;g=(f|0)!=0;f=c[2112926]|0;j=c[2387808]|0;if((h|0)==0){if(i){if(g){SF(f,d,a,b,e,4,0,j);return}else{SD(f,d,a,b,e,4,0,j);return}}else{if(g){SB(f,d,a,b,e,4,0,j);return}else{Sz(f,d,a,b,e,4,0,j);return}}}else{if(i){if(g){SN(f,d,a,b,e,4,0,0,j);return}else{SL(f,d,a,b,e,4,0,0,j);return}}else{if(g){SJ(f,d,a,b,e,4,0,0,j);return}else{SH(f,d,a,b,e,4,0,0,j);return}}}}function fcr(d,f){d=d|0;f=f|0;var g=0,i=0.0,j=0.0,k=0.0,l=0,m=0,n=0,o=0,p=0.0,q=0.0,r=0,s=0,t=0,u=0.0,v=0,w=0.0,x=0;gGz(d|0,0,f<<2|0);g=c[2429392]|0;if((g|0)==-1){return}i=+h[136404];j=7.0e3/(a[9680]|0?32.0e3:0.0);k=+(c[9719640+(g<<2)>>2]|0);l=c[9719832+(g<<2)>>2]|0;g=i<k;if((f|0)>0&g){m=a[683840]|0?3:0;n=(m&1|0)==0;o=(m&2|0)==0;p=+h[117832];m=0;q=i;while(1){r=b[l+(~~q<<1)>>1]|0;if(n){s=0}else{s=~~(+(r<<16>>16|0)*p)<<16>>16}if(o){t=0}else{t=~~(+(r<<16>>16|0)*p)<<16>>16}r=d+(m<<1)|0;b[r>>1]=(e[r>>1]|0)+s&65535;r=d+((m|1)<<1)|0;b[r>>1]=(e[r>>1]|0)+t&65535;u=j+q;r=m+2|0;v=u<k;if((r|0)<(f|0)&v){m=r;q=u}else{w=u;x=v;break}}}else{w=i;x=g}h[136404]=w;if(x){return}c[2429392]=-1;return}function fcs(a){a=a|0;var b=0;if((a|0)==5242887){b=~~(+((c[3542193]>>8)+8|0)/+(c[2440574]|0)*255.0);return b|0}else if((a|0)==5242885){b=~~(+((c[3542197]>>8)+8|0)/+(c[2440576]|0)*255.0)^-1;return b|0}else if((a|0)==5242881){b=~~(+((c[3542196]>>8)+8|0)/+(c[2440576]|0)*255.0)^-1;return b|0}else if((a|0)==5242883){b=~~(+((c[3542192]>>8)+8|0)/+(c[2440574]|0)*255.0);return b|0}else{b=0;return b|0}return 0}function fct(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;e=b-2097152|0;if(e>>>0>=65536){if(!((b|0)==5242881|(b|0)==5242883|(b|0)==5242885|(b|0)==5242887)){return}c[2113056]=10;b=RG(10)|0;c[2113054]=(c[2113054]|0)+b;c[2276108]=-1;c[2113056]=-1;c[2113030]=(c[2113030]|0)+b;c[8452200+(c[2394]<<2)>>2]=8198;c[2276080]=1536;if((c[2276079]|0)>>>0>=1536){return}RH(6);return}b=e^1;f=(c[3532278]|0)+b|0;do{if((a[f]|0)!=d<<24>>24){g=(e|0)>-1;if((c[3532284]|0)==0){if(g&(b|0)<16384){a[14129208]=1}if(g&(b|0)<32768){a[14129128]=1}if((b-24576|0)>>>0>=4096){break}a[14129200]=1;break}else{if(g&(b|0)<32768){a[14129208]=1}if((b-32768|0)>>>0<32768){a[14129128]=1}if((b-69632|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);a[f]=d;return}function fcu(d){d=d|0;var e=0,f=0,g=0;if((d|0)==1048578){e=b[(c[2442928]|0)+(c[2439392]<<1)>>1]|0;return e|0}else if((d|0)==589824|(d|0)==589826|(d|0)==589828|(d|0)==589830|(d|0)==589832|(d|0)==589834|(d|0)==589836|(d|0)==589838){f=(d-589824|0)>>>1;L66177:do{if((f|0)==3){if((c[2406632]|0)!=0){g=(c[2432962]|0)>>>((c[(c[2420380]|0)+4>>2]|0)>>>0)<<7&255;break}d=c[2443744]|0;if((d|0)<=0){g=-128;break}c[2443744]=d-1;g=0}else{switch(f&255|0){case 3:{g=a[14129041]|0;break L66177;break};case 7:{g=a[14129042]|0;break L66177;break};case 1:{g=a[14129049]|0;break L66177;break};case 0:{g=a[14129048]|0;break L66177;break};case 2:{g=a[14129040]|0;break L66177;break};case 4:{g=a[9757556]|0;break L66177;break};default:{g=0;break L66177}}}}while(0);e=g&255;return e|0}else{e=0;return e|0}return 0}function fcv(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=d-2097152|0;if(f>>>0<65536){g=(c[3532278]|0)+(f>>>1<<1)|0;do{if((b[g>>1]|0)!=e<<16>>16){if((c[3532284]|0)==0){if(f>>>0<16384){a[14129208]=1}if((d-2129920|0)>>>0<16384){a[14129128]=1}if((d-2121728|0)>>>0>=4096){break}a[14129200]=1;break}else{if(f>>>0<32768){a[14129208]=1}if((d-2129920|0)>>>0<32768){a[14129128]=1}if((d-2166784|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);b[g>>1]=e;return}g=d-2228224|0;if(g>>>0<16){f=g>>>1;b[14129152+(f<<1)>>1]=e;switch(f|0){case 0:{c[2388344]=-(e&65535);return};case 1:{c[2385826]=-(e&65535);return};case 3:{c[2388334]=-(e&65535);return};case 5:{c[3527494]=-(e&65535);return};case 2:{c[3527502]=-(e&65535);return};case 7:{c[2439396]=e&1;return};case 4:{c[2385820]=-(e&65535);return};case 6:{c[3532284]=(e&65535)>>>4&1;return};default:{return}}}if((d|0)==3145728){a[9540896]=e&15;return}else if((d|0)==3145730){f=e&15;g=a[9540896]|0;switch(g&255|0){case 1:{a[9540896]=g+1&255;a[9540889]=f;a[9540898]=a[9540898]|1;a[9540900]=1;return};case 2:{a[9540896]=g+1&255;a[9540890]=f;return};case 3:{a[9540896]=g+1&255;a[9540891]=f;a[9540898]=a[9540898]|2;a[9540900]=1;return};case 0:{a[9540896]=g+1&255;a[9540888]=f;return};case 4:{if(f<<24>>24==0){return}f=c[2439330]|0;g=(f|0)==0;if(!g){h=f;gGC(9706056,h|0,76)|0}h=c[2438118]|0;c[2433530]=h;i=c[3528484]|0;c[2076596]=i;j=c[2417276]|0;c[3541536]=j;c[1836236]=0;gGz(9706056,0,76);if(!g){g=f;gGC(g|0,9706056,76)|0}c[2438118]=h;c[3528484]=i;c[2417276]=j;c[1836236]=-1;return};default:{return}}}else if((d|0)==589824|(d|0)==589826|(d|0)==589828|(d|0)==589830|(d|0)==589832|(d|0)==589834|(d|0)==589836|(d|0)==589838){j=(d-589824|0)>>>1;if((j|0)==3){i=e&65535;c[2415256]=i&64;h=i>>>4&1;c[3528406]=h^1;if((h|0)==0){c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2]}Tr(i>>>5&1);return}i=j&255;h=e&255;a[9757552+(j&255)|0]=h;if((i<<24>>24|0)==0){c[3531956]=0;return}else if((i<<24>>24|0)==4){i=~h;a[14128520]=i&1;a[14128521]=i&2;return}else{return}}else if((d|0)==5242880|(d|0)==5242882|(d|0)==5242884|(d|0)==5242886){c[2113056]=10;i=RG(10)|0;c[2113054]=(c[2113054]|0)+i;c[2276108]=-1;c[2113056]=-1;c[2113030]=(c[2113030]|0)+i;c[8452200+(c[2394]<<2)>>2]=8198;c[2276080]=1536;if((c[2276079]|0)>>>0>=1536){return}RH(6);return}else if((d|0)==1048576|(d|0)==1048578|(d|0)==1048580){i=(d-1048576|0)>>>1;if((i|0)==0){c[2439392]=e&4095;return}else if((i|0)==1){b[(c[2442928]|0)+(c[2439392]<<1)>>1]=e;c[(c[3532276]|0)+(c[2439392]<<2)>>2]=((e&65535)>>>10<<3&248)<<8|((e&255)<<3&255)>>>3|(((e&65535)>>>7&4|(e&65535)>>>5<<3&255)&255)<<3&2016;return}else{return}}else{return}}function fcw(b){b=b|0;var d=0,e=0,f=0,g=0.0,i=0.0,j=0,k=0;d=b&65535;if((d|0)==59904){e=a[14128480]|0;return e|0}else if((d|0)==57344){b=c[3541514]|0;f=b+552|0;g=+h[f>>3];do{if(g!=0.0){i=+h[6675];if(g-(i+ +gC[c[2429842]&255]())>0.0){j=a[b+563|0]|-128;break}else{h[f>>3]=0.0;k=50693;break}}else{k=50693}}while(0);if((k|0)==50693){j=a[b+563|0]|0}e=j&-125;return e|0}else if((d|0)==57346){e=a[(c[3541514]|0)+20904|0]|0;return e|0}else if((d|0)==57857){e=fdZ()|0;return e|0}else{e=0;return e|0}return 0}function fcx(b,e){b=b|0;e=e|0;var f=0,g=0,i=0,j=0,k=0.0,l=0,m=0,n=0;f=b&65535;switch(f|0){case 57346:{b=c[3541514]|0;a[b+560|0]=e;a[b+20408|0]=1;return};case 58368:case 58369:case 58370:case 58371:{b=c[3527056]|0;a[b+(f&3)|0]=e&31;f=d[b]|0;g=d[b+2|0]|0;i=d[b+1|0]|0;j=d[b+3|0]|0;k=+h[85164];h[146569]=k*+((((j+i|0)*100|0)>>>0)/62|0|0)/100.0;h[118354]=+((((g+f|0)*100|0)>>>0)/62|0|0)*k/100.0;k=+h[85169];h[146571]=k*+(((i*100|0)>>>0)/31|0|0)/100.0;h[118356]=+(((f*100|0)>>>0)/31|0|0)*k/100.0;k=+h[85168];h[146570]=k*+(((j*100|0)>>>0)/31|0|0)/100.0;h[118355]=+(((g*100|0)>>>0)/31|0|0)*k/100.0;return};case 57345:{l7(1,e);return};case 57856:{a[9540897]=e&15;return};case 61952:{g=e+7&7;a[14127752]=g;j=c[3531932]|0;f=(g&255)<<14;g=c[9757320+(c[1836236]<<2)>>2]|0;i=64;b=64;while(1){c[g+76+(b<<2)>>2]=j+((b<<8)+f);l=i+1&65535;if((l&65535)>127){m=64;n=64;break}else{i=l;b=l&65535}}while(1){b=j+((n<<8)+f)|0;c[g+76+(n+512<<2)>>2]=b;c[g+76+(n+768<<2)>>2]=b;b=m+1&65535;if((b&65535)>127){break}else{m=b;n=b&65535}}return};case 57347:{l7(3,e);return};case 57857:{fd_(e);return};case 57344:{n=c[3541514]|0;a[n+560|0]=e;a[n+20408|0]=0;if((e&255)>=16){return}c[14168912+((c[2383582]|0)*252|0)>>2]=e&15;return};default:{return}}}function fcy(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3651860+(b*112|0)>>2];c[a+104>>2]=c[3651864+(b*112|0)>>2];c[a+108>>2]=c[3651868+(b*112|0)>>2];d=0;return d|0}function fcz(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=3651760+(b*112|0);e=0;return e|0}function fcA(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1223592+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function fcB(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>44){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3653776+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fcC(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;c[3532162]=256;c[3532160]=4;c[3532142]=8;c[3532164]=8;c[3532148]=1983608;c[3532140]=6964120;c[3532138]=6963864;c[3532042]=16384;c[3532002]=512;c[3532e3]=4;a[7460944]=1;c[3532004]=8;c[3531998]=961352;c[3531992]=4969368;c[3531990]=4968952;c[3532034]=32768;c[3532044]=1;c[3532030]=1;a[7460960]=1;a[7460992]=1;eZ9(0)|0;c[3532048]=0;c[3532204]=0;d=c[3532200]|0;c[3531932]=d;e=(c[3531928]|0)+d|0;c[3531976]=e;d=e+(c[3531972]|0)|0;c[3531952]=d;e=d+(c[3531948]|0)|0;c[3531946]=e;d=e+(c[3531942]|0)|0;c[3532126]=d;e=d+(c[3532122]|0)|0;d=e|0;c[3532020]=d;c[3532208]=d;c[3531936]=e+65536;c[3531970]=e+73728;c[3527056]=e+75264;d=e+75268|0;e=d|0;c[3532022]=e;c[3532136]=e;e=ag(c[3532142]|0,c[3532042]|0)|0;f=(ag(e,c[3532164]|0)|0)+d|0;c[3531962]=f;d=ag(a[7460944]|0?16:0,c[3532034]|0)|0;e=(ag(d,c[3532004]|0)|0)+f|0;c[3532028]=e;f=e+16384|0;c[3532046]=f;e=f;f=0;while(1){if((f|0)>=1024){break}g=9638528+(f<<2)|0;if((c[g>>2]|0)==0){i=50756;break}else{f=f+1|0}}do{if((i|0)==50756){f=gGq(e)|0;c[g>>2]=f;if((f|0)==0){break}gGz(f|0,0,e|0);c[3532048]=f;gGz(f|0,0,e|0);c[3532204]=f;d=c[3532200]|0;c[3531932]=f+d;j=(c[3531928]|0)+d|0;c[3531976]=f+j;d=j+(c[3531972]|0)|0;c[3531952]=f+d;j=d+(c[3531948]|0)|0;c[3531946]=f+j;d=j+(c[3531942]|0)|0;c[3532126]=f+d;j=d+(c[3532122]|0)|0;d=f+j|0;c[3532020]=d;c[3532208]=d;c[3531936]=f+(j+65536);c[3531970]=f+(j+73728);c[3527056]=f+(j+75264);d=j+75268|0;j=f+d|0;c[3532022]=j;c[3532136]=j;j=ag(c[3532142]|0,c[3532042]|0)|0;k=(ag(j,c[3532164]|0)|0)+d|0;c[3531962]=f+k;d=ag(a[7460944]|0?16:0,c[3532034]|0)|0;j=(ag(d,c[3532004]|0)|0)+k|0;c[3532028]=f+j;c[3532046]=f+(j+16384);j=c[642608+(c[2436]<<2)>>2]|0;f=c[j+128>>2]|0;if((c[j+52>>2]&4|0)==0){c[2113068]=f;k=c[j+132>>2]|0;c[2113070]=k;c[2443814]=f;c[2440436]=k;l=f;m=k}else{c[2113070]=f;k=c[j+132>>2]|0;c[2113068]=k;c[2440436]=f;c[2443814]=k;l=k;m=f}f=ag(l<<1,m)|0;k=gGq(f)|0;c[2112926]=k;if((k|0)!=0){gGz(k|0,0,f|0)}eX5(0,c[3532042]|0,4,8,1,0);f=0;while(1){if((f|0)>=1024){n=0;break}o=9638528+(f<<2)|0;if((c[o>>2]|0)==0){i=50766;break}else{f=f+1|0}}do{if((i|0)==50766){f=gGq(16384)|0;c[o>>2]=f;if((f|0)==0){n=0;break}gGz(f|0,0,16384);n=f}}while(0);c[2442928]=n;gGz(n|0,0,16384);f=0;while(1){if((f|0)>=1024){p=0;break}q=9638528+(f<<2)|0;if((c[q>>2]|0)==0){i=50771;break}else{f=f+1|0}}do{if((i|0)==50771){f=gGq(16384)|0;c[q>>2]=f;if((f|0)==0){p=0;break}gGz(f|0,0,16384);p=f}}while(0);c[3532276]=p;gGz(p|0,0,4096);c[3532274]=4096;a[7461088]=1;a[7461080]=1;a[7461056]=1;if((eZ9(1)|0)!=0){r=1;return r|0}fxU(0,425984);if((c[2394]|0)==0){s=c[2112932]|0}else{c[2394]=0;f=c[3532596]|0;c[2112932]=f;k=c[3532592]|0;if((k|0)!=0){gGC(9104152,k|0,280)|0}c[2113054]=c[2113060];s=f}f=c[3532204]|0;k=s|0;j=0;while(1){d=f+j|0;c[k>>2]=d;c[k+131072>>2]=d;d=j+1024|0;if(d>>>0>524287){break}else{k=k+4|0;j=d}}j=c[3532208]|0;k=s+2048|0;f=524288;while(1){d=j+(f-524288)|0;c[k>>2]=d;c[k+65536>>2]=d;c[k+131072>>2]=d;d=f+1024|0;if(d>>>0>589823){break}else{k=k+4|0;f=d}}f=c[3532278]|0;k=s+8192|0;j=2097152;while(1){c[k>>2]=f+(j-2097152);d=j+1024|0;if(d>>>0>2162687){break}else{k=k+4|0;j=d}}j=c[3531970]|0;c[s+16384>>2]=j;c[s+81920>>2]=j;c[s+147456>>2]=j;k=j+1024|0;c[s+16388>>2]=k;c[s+81924>>2]=k;c[s+147460>>2]=k;c[s+196688>>2]=664;c[s+196728>>2]=3452;c[s+196608>>2]=626;c[s+196648>>2]=1478;k=c[3532592]|0;if((k|0)!=0){gGC(k|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);k=c[2439330]|0;j=(k|0)==0;if(!j){f=k;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];f=c[3528484]|0;c[2076596]=f;d=c[2417276]|0;c[3541536]=d;c[1836236]=0;c[k+4180>>2]=798;c[k+4184>>2]=956;t=c[3531932]|0;u=0;v=0;while(1){c[k+76+(v<<2)>>2]=t+(v<<8);w=u+1&65535;if((w&65535)>63){x=0;y=0;break}else{u=w;v=w&65535}}while(1){v=t+(y<<8)|0;c[k+76+(y+512<<2)>>2]=v;c[k+76+(y+768<<2)>>2]=v;v=x+1&65535;if((v&65535)>63){z=64;A=64;break}else{x=v;y=v&65535}}while(1){c[k+76+(A<<2)>>2]=t+(A<<8);v=z+1&65535;if((v&65535)>127){B=64;C=64;break}else{z=v;A=v&65535}}while(1){v=t+(C<<8)|0;c[k+76+(C+512<<2)>>2]=v;c[k+76+(C+768<<2)>>2]=v;v=B+1&65535;if((v&65535)>127){break}else{B=v;C=v&65535}}t=c[3531936]|0;v=192;u=192;while(1){c[k+76+(u<<2)>>2]=t+((u<<8)-49152);w=v+1&65535;if((w&65535)>223){D=192;E=192;break}else{v=w;u=w&65535}}while(1){c[k+76+(E+256<<2)>>2]=t+((E<<8)-49152);u=D+1&65535;if((u&65535)>223){F=192;G=192;break}else{D=u;E=u&65535}}while(1){u=t+((G<<8)-49152)|0;c[k+76+(G+512<<2)>>2]=u;c[k+76+(G+768<<2)>>2]=u;u=F+1&65535;if((u&65535)>223){break}else{F=u;G=u&65535}}if(!j){t=k;gGC(t|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=f;c[2417276]=d;c[1836236]=-1;TW(c[3531952]|0,14127792,c[3531946]|0,14127768,3462,82,24);c[2438228]=4e6;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=511;h[85164]=.25;h[85169]=1.0;h[85168]=1.0;a[64232]=1;Tq(682400);if(!(a[1040128]|0)){t=c[3532126]|0;gGC(14100392,t|0,128)|0}c[3532050]=2542;c[3532118]=9376;c[3532064]=5;c[3532082]=100;a[7461152]=1;c[2113026]=216666;c[2113024]=66666;c[2113302]=2;a[801640]=0;t=c[642608+(c[2436]<<2)>>2]|0;u=c[t+128>>2]|0;if((c[t+52>>2]&4|0)==0){c[2440576]=u;v=c[t+132>>2]|0;c[2440574]=v;H=u;I=v}else{c[2440574]=u;v=c[t+132>>2]|0;c[2440576]=v;H=v;I=u}u=(((H|0)/2|0)<<8)-1792|0;v=(((I|0)/2|0)<<8)-2048|0;c[3542196]=u;c[3542192]=v;c[3542197]=u;c[3542193]=v;c[3542198]=u;c[3542194]=v;c[3542199]=u;c[3542195]=v;eZ8()|0;r=0;return r|0}}while(0);c[3532048]=0;r=1;return r|0}function fcD(){e_a()|0;return 0}function fcE(){var d=0,e=0,f=0,g=0,h=0,i=0;d=c[3532082]|0;if((a[14128072]|0)!=0){eZ8()|0}gu[c[3532050]&16383]();c[2113031]=0;c[2113030]=0;e=c[2392]|0;if((e|0)>=0){gGz(8452240,0,((e|0)>0?(e<<2)+4|0:4)|0)}c[2113054]=0;e=c[2385548]|0;if((e|0)>0){gGz(9752472,0,((e|0)>1?e<<2:4)|0)}c[2433530]=0;if((d|0)>0){e=0;while(1){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060]}f=e+1|0;g=(ag(c[2113026]|0,f)|0)/(d|0)|0;h=g-(c[2113030]|0)|0;c[2113028]=h;c[2113056]=h;g=RG(h)|0;c[2113054]=(c[2113054]|0)+g;c[2276108]=-1;c[2113056]=-1;c[2113030]=(c[2113030]|0)+g;do{if((e|0)==((c[3532082]|0)-1|0)){g=c[3532064]|0;c[8452200+(c[2394]<<2)>>2]=g|8192;h=c[2276080]|0;i=g<<8;c[2276080]=i;if((h|0)!=1792&(i|0)==1792){RH(7);break}if(i>>>0<=(c[2276079]|0)>>>0){break}RH(g&16777215)}}while(0);g=c[2394]|0;i=c[14130368+(g<<2)>>2]|0;if((i|0)!=0){gGC(i|0,9104152,280)|0}c[8452240+(g<<2)>>2]=c[2113054];c[2394]=-1;g=c[2439330]|0;if((g|0)!=0){i=g;gGC(9706056,i|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;Sb(ag((c[2113024]|0)/(d|0)|0,e)|0);i=c[1836236]|0;g=c[9757320+(i<<2)>>2]|0;if((g|0)!=0){h=g;gGC(h|0,9706056,76)|0}c[9752472+(i<<2)>>2]=c[2433530];c[14113936+(i<<2)>>2]=c[2076596];c[9669104+(i<<2)>>2]=c[3541536];c[1836236]=-1;if((f|0)<(d|0)){e=f}else{break}}}e=c[2439330]|0;if((e|0)!=0){d=e;gGC(9706056,d|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;d=c[2113024]|0;e=gGU(d,(d|0)<0|0?-1:0,2048e6,0)|0;i=c[2438228]|0;h=gGS(e,K,i,(i|0)<0|0?-1:0)|0;i=h;Sb(d);d=c[2443830]|0;if((d|0)<1073676288){c[2443830]=d-i}d=c[2443831]|0;if((d|0)<1073676288){c[2443831]=d-i}d=(c[3528512]|0)-i|0;c[3528512]=(d|0)<0?0:d;gg[c[3542118]&4095](c[2112964]|0,a[9688]|0?534:0);d=c[1836236]|0;i=c[9757320+(d<<2)>>2]|0;if((i|0)!=0){h=i;gGC(h|0,9706056,76)|0}c[9752472+(d<<2)>>2]=c[2433530];c[14113936+(d<<2)>>2]=c[2076596];c[9669104+(d<<2)>>2]=c[3541536];c[1836236]=-1;if((c[2112968]|0)==0){return 0}gu[c[3532118]&16383]();return 0}function fcF(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;f=i;i=i+160|0;g=f|0;h=f+16|0;j=f+32|0;k=f+48|0;l=f+64|0;m=f+80|0;n=f+96|0;o=f+112|0;p=f+128|0;q=f+144|0;if((e|0)!=0){c[e>>2]=169737}if((d&32|0)!=0){gGz(q|0,0,12);r=c[3532020]|0;c[q>>2]=r;c[q+4>>2]=(c[3532022]|0)-r;c[q+12>>2]=162152;r=c[2076592]|0;gj[r&4095](q)|0}eZ7(d);if((d&64|0)!=0){q=l|0;gGz(k|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){r=l+9|0;l=j;s=j|0;t=j+4|0;u=j+12|0;v=k|0;w=k+4|0;x=k+12|0;y=0;do{gGC(q|0,614896,11)|0;a[r]=y+48&255;z=8452256+(y<<2)|0;gGz(l|0,0,12);c[s>>2]=z;c[t>>2]=4;c[u>>2]=164976;gj[c[2076592]&4095](j)|0;if((c[z>>2]|0)!=0){c[v>>2]=c[14130368+(y<<2)>>2];c[w>>2]=c[8452184+(y<<2)>>2];c[x>>2]=q;z=c[2076592]|0;gj[z&4095](k)|0}y=y+1|0;}while((y|0)<=(c[2392]|0))}fw$(d);T0(d,e);gGz(h|0,0,12);c[h>>2]=14168784;c[h+4>>2]=16;c[h+12>>2]=249744;e=c[2076592]|0;gj[e&4095](h)|0;gGz(g|0,0,12);c[g>>2]=14168768;c[g+4>>2]=16;c[g+12>>2]=524320;h=c[2076592]|0;gj[h&4095](g)|0;gGz(p|0,0,12);c[p>>2]=14128320;c[p+4>>2]=6;c[p+12>>2]=273024;g=c[2076592]|0;gj[g&4095](p)|0;gGz(o|0,0,12);c[o>>2]=14127752;c[o+4>>2]=1;c[o+12>>2]=272344;p=c[2076592]|0;gj[p&4095](o)|0;gGz(n|0,0,12);c[n>>2]=8452120;c[n+4>>2]=16;c[n+12>>2]=270496;o=c[2076592]|0;gj[o&4095](n)|0;gGz(m|0,0,12);c[m>>2]=8452112;c[m+4>>2]=4;c[m+12>>2]=269664;n=c[2076592]|0;gj[n&4095](m)|0}m=a[14127752]|0;if(!((d&2|0)!=0&m<<24>>24!=0)){i=f;return 0}d=c[2439330]|0;n=(d|0)==0;if(!n){o=d;gGC(9706056,o|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];o=c[3528484]|0;c[2076596]=o;p=c[2417276]|0;c[3541536]=p;c[1836236]=0;g=c[3531932]|0;h=(m&255)<<14;m=64;e=64;while(1){c[d+76+(e<<2)>>2]=g+((e<<8)+h);y=m+1&65535;if((y&65535)>127){A=64;B=64;break}else{m=y;e=y&65535}}while(1){e=g+((B<<8)+h)|0;c[d+76+(B+512<<2)>>2]=e;c[d+76+(B+768<<2)>>2]=e;e=A+1&65535;if((e&65535)>127){break}else{A=e;B=e&65535}}if(!n){n=d;gGC(n|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=o;c[2417276]=p;c[1836236]=-1;i=f;return 0}function fcG(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1790428+(b*112|0)>>2];c[a+104>>2]=c[1790432+(b*112|0)>>2];c[a+108>>2]=c[1790436+(b*112|0)>>2];d=0;return d|0}function fcH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=1790328+(b*112|0);e=0;return e|0}function fcI(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>47){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1792344+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fcJ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1221676+(b*112|0)>>2];c[a+104>>2]=c[1221680+(b*112|0)>>2];c[a+108>>2]=c[1221684+(b*112|0)>>2];d=0;return d|0}function fcK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=1221576+(b*112|0);e=0;return e|0}function fcL(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1793020+(b*112|0)>>2];c[a+104>>2]=c[1793024+(b*112|0)>>2];c[a+108>>2]=c[1793028+(b*112|0)>>2];d=0;return d|0}function fcM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=1792920+(b*112|0);e=0;return e|0}function fcN(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>44){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1794936+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fcO(b,c){b=b|0;c=c|0;a[9706117]=c&1;return}function fcP(a){a=a|0;var b=0,d=0;b=(c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,4e6,0)|0;return a|0}function fcQ(){return+(+((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)/4.0e6)}function fcR(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a[14129040]=-1;a[14129041]=-1;a[14129042]=-1;b=0;d=-1;e=-1;f=-1;do{d=(d&255)-((a[14129032+b|0]&1)<<b)&255;e=(e&255)-((a[14129024+b|0]&1)<<b)&255;f=(f&255)-((a[14129016+b|0]&1)<<b)&255;b=b+1|0;}while((b|0)<8);a[14129040]=d;a[14129041]=e;a[14129042]=f;f=c[3532184]|0;e=(c[3542196]|0)+(c[3532186]<<16>>16)|0;c[3542196]=e;d=(c[3542192]|0)+(f<<16>>16)|0;c[3542192]=d;if((e|0)<-2048){c[3542196]=-2048;g=-2048}else{g=e}e=(c[2440576]<<8)-2048|0;if((g|0)>(e|0)){c[3542196]=e}if((d|0)<-2048){c[3542192]=-2048;h=-2048}else{h=d}d=(c[2440574]<<8)-2048|0;if((h|0)>(d|0)){c[3542192]=d}h=c[3532180]|0;g=(c[3542197]|0)+(c[3532182]<<16>>16)|0;c[3542197]=g;f=(c[3542193]|0)+(h<<16>>16)|0;c[3542193]=f;if((g|0)<-2048){c[3542197]=-2048;i=-2048}else{i=g}if((i|0)>(e|0)){c[3542197]=e}if((f|0)<-2048){c[3542193]=-2048;j=-2048}else{j=f}if((j|0)<=(d|0)){return}c[3542193]=d;return}function fcS(){var a=0,d=0,f=0;a=e[7064582]|0;d=c[2112926]|0;gGz(d|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);do{if((b[7064582]&8)==0){if((a&1|0)==0){eX0(0,1,c[3532136]|0)}fcT(1);if((a&2|0)!=0){break}eX3(0,0,c[3532136]|0)}else{if((a&2|0)==0){eX3(0,1,c[3532136]|0)}fcT(1);if((a&1|0)!=0){break}eX0(0,0,c[3532136]|0)}}while(0);fcT(0);if((a&4|0)==0){eX4(0)}R8(c[3532276]|0);a=c[2113302]|0;if((a|0)>0){f=0}else{return}do{R7(f,c[14168784+(f<<2)>>2]>>8,c[14168768+(f<<2)>>2]>>8);f=f+1|0;}while((f|0)<(a|0));return}function fcT(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0;f=c[3531976]|0;g=c[3531970]|0;h=c[3532034]|0;i=h+65535|0;j=c[3531962]|0;k=a[7460944]|0?16:0;l=c[3532004]|0;m=a[7461152]|0;n=k<<16;o=l<<16;p=c[2113068]|0;q=c[2113070]|0;r=c[2112926]|0;s=764;do{t=e[g+((s|1)<<1)>>1]|0;do{if((t>>>15|0)==(d|0)){u=t>>>14&1;v=t&511;w=e[g+((s|3)<<1)>>1]|0;x=w>>>15;y=w&8191;if((y|0)==0){break}w=e[g+(s<<1)>>1]|0;z=w&511;A=b[g+((s|2)<<1)>>1]|0;B=y<<5;y=(A&127)+1|0;C=(w>>>9)+1|0;w=z+3|0;D=v>>>0>320?t|-512:v;v=(u|0)!=0;E=(x|0)!=0;F=(A&65535)>>>8<<4;A=(x|0)==0;x=u^1;G=(w>>>0>320?z-509|0:w)-16|0;w=0;do{z=(w|0)%4|0;H=(w|0)/4|0;I=i&(e[f+((v?3-z|0:z)+B+((E?7-H|0:H)<<2)<<1)>>1]|0);L66650:do{if((I|0)!=65535){J=(ag(z,y)|0)/4|0;K=J+D|0;L=(ag(H,C)|0)/8|0;M=((ag(z+1|0,y)|0)/4|0)-J|0;J=G+L|0;N=M<<12;M=((ag(H+1|0,C)|0)/8|0)-L<<13;L=ag(ag(k,(I>>>0)%(h>>>0)|0)|0,l)|0;O=((ag(M,l)|0)+32768|0)>>>16;M=(ag(k,N)|0)>>>16;if(m){P=320-K-(N>>12)|0;Q=x}else{P=K;Q=u}if((M|0)==0|(O|0)==0){break}K=(n>>>0)/(M>>>0)|0;N=(o>>>0)/(O>>>0)|0;R=P+M|0;S=O+J|0;if((Q|0)==0){T=K;U=0}else{T=-K|0;U=ag(K,M-1|0)|0}if(A){V=N;W=0}else{V=-N|0;W=ag(N,O-1|0)|0}if((P|0)<0){X=0;Y=U-(ag(T,P)|0)|0}else{X=P;Y=U}if((J|0)<0){Z=0;_=W-(ag(V,J)|0)|0}else{Z=J;_=W}J=(R|0)>(p|0)?p:R;R=(S|0)>(q|0)?q:S;if((J|0)>(X|0)&(Z|0)<(R|0)){$=_;aa=Z}else{break}while(1){S=(ag($>>16,k)|0)+L|0;O=ag(aa,p)|0;N=X;M=Y;while(1){K=a[j+(S+(M>>16))|0]|0;if(K<<24>>24!=0){b[r+(N+O<<1)>>1]=K&255|F}K=N+1|0;if((K|0)<(J|0)){N=K;M=M+T|0}else{break}}M=aa+1|0;if((M|0)>=(R|0)){break L66650}$=$+V|0;aa=M}}}while(0);w=w+1|0;}while((w|0)<32)}}while(0);s=s-4|0;}while((s|0)>-1);return}function fcU(b){b=b|0;return(b<<16>>16==-8184?a[9549912]|0:0)|0}function fcV(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2573008:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function fcW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2573008:0;e=0;return e|0}function fcX(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>4){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6923792+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function fcY(){var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;d=i;i=i+120|0;e=d|0;f=d+112|0;c[2414880]=0;c[2385872]=0;c[2414582]=65536;c[2386026]=65536;c[2411526]=73728;g=0;while(1){if((g|0)>=1024){break}h=9638528+(g<<2)|0;if((c[h>>2]|0)==0){j=51009;break}else{g=g+1|0}}do{if((j|0)==51009){g=gGq(73728)|0;c[h>>2]=g;if((g|0)==0){break}c[2414880]=g;gGz(g|0,0,73728);c[2385872]=g;k=g+65536|0;c[2414582]=k;c[2386026]=k;k=g+73728|0;c[2411526]=k;c[2414066]=k;if((c[3542200]|0)==0){l=1;i=d;return l|0}k=e+108|0;c[k>>2]=0;m=e+100|0;c[m>>2]=0;n=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[n&16383](e,0)|0;do{if((c[k>>2]|0)!=0){n=c[m>>2]|0;c[f>>2]=9534384;o=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[o&16383](f,0,0)|0;if((n|0)<1){l=1;i=d;return l|0}if((gzL(g,0,0)|0)==0){break}else{l=1}i=d;return l|0}}while(0);fwR(0);g=c[2439330]|0;m=(g|0)==0;if(!m){k=g;gGC(9706056,k|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];k=c[3528484]|0;c[2076596]=k;n=c[2417276]|0;c[3541536]=n;c[1836236]=0;o=c[2385872]|0;p=0;q=0;while(1){c[g+76+(q<<2)>>2]=o+(q<<8);r=p+1&65535;if((r&65535)>31){s=0;t=0;break}else{p=r;q=r&65535}}while(1){q=o+(t<<8)|0;c[g+76+(t+512<<2)>>2]=q;c[g+76+(t+768<<2)>>2]=q;q=s+1&65535;if((q&65535)>31){break}else{s=q;t=q&65535}}o=c[2386026]|0;q=160;p=160;while(1){c[g+76+(p<<2)>>2]=o+((p<<8)-40960);r=q+1&65535;if((r&65535)>191){u=160;v=160;break}else{q=r;p=r&65535}}while(1){c[g+76+(v+256<<2)>>2]=o+((v<<8)-40960);p=u+1&65535;if((p&65535)>191){w=160;x=160;break}else{u=p;v=p&65535}}while(1){p=o+((x<<8)-40960)|0;c[g+76+(x+512<<2)>>2]=p;c[g+76+(x+768<<2)>>2]=p;p=w+1&65535;if((p&65535)>191){break}else{w=p;x=p&65535}}c[g+4180>>2]=1526;if(!m){o=g;gGC(o|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=k;c[2417276]=n;c[1836236]=-1;o=c[642608+(c[2436]<<2)>>2]|0;p=c[o+128>>2]|0;if((c[o+52>>2]&4|0)==0){c[2113068]=p;q=c[o+132>>2]|0;c[2113070]=q;c[2443814]=p;c[2440436]=q;y=p;z=q}else{c[2113070]=p;q=c[o+132>>2]|0;c[2113068]=q;c[2440436]=p;c[2443814]=q;y=q;z=p}p=ag(y<<1,z)|0;q=gGq(p)|0;c[2112926]=q;if((q|0)!=0){gGz(q|0,0,p|0)}a[9623664]=0;p=c[2414582]|0;gGz(p|0,0,(c[2411526]|0)-p|0);p=c[2439330]|0;q=(p|0)==0;if(!q){o=p;gGC(9706056,o|0,76)|0}o=c[2438118]|0;c[2433530]=o;r=c[3528484]|0;c[2076596]=r;A=c[2417276]|0;c[3541536]=A;c[1836236]=0;gGz(9706056,0,76);if(!q){q=p;gGC(q|0,9706056,76)|0}c[2438118]=o;c[3528484]=r;c[2417276]=A;c[1836236]=-1;l=0;i=d;return l|0}}while(0);c[2414880]=0;l=1;i=d;return l|0}function fcZ(){var a=0,b=0,d=0,e=0;c[2113070]=0;c[2113068]=0;a=c[2112926]|0;if((a|0)!=0){gGr(a);c[2112926]=0}fwZ();a=c[2414880]|0;b=0;while(1){if((b|0)>=1024){d=51050;break}e=9638528+(b<<2)|0;if((c[e>>2]|0)==(a|0)){break}else{b=b+1|0}}if((d|0)==51050){c[2414880]=0;return 0}gGr(a);c[e>>2]=0;c[2414880]=0;return 0}function fc_(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;if((a[9623664]|0)==0){d=c[2439330]|0}else{a[9623664]=0;e=c[2414582]|0;gGz(e|0,0,(c[2411526]|0)-e|0);e=c[2439330]|0;f=(e|0)==0;if(!f){g=e;gGC(9706056,g|0,76)|0}g=c[2438118]|0;c[2433530]=g;h=c[3528484]|0;c[2076596]=h;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);if(!f){f=e;gGC(f|0,9706056,76)|0}c[2438118]=g;c[3528484]=h;c[2417276]=i;c[1836236]=-1;d=e}a[9549912]=(a[9632696]|-2)^1^a[9632697]<<1&2^a[9632698]<<2&4^a[9632699]<<3&8;if((d|0)!=0){e=d;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;e=c[2438118]|0;c[2433530]=e;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;if((a[d+4188|0]|0)==0){d=gfc(66666)|0;j=(c[2433530]|0)+d|0}else{j=e+66666|0}c[2433530]=j;a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0;j=c[1836236]|0;e=c[9757320+(j<<2)>>2]|0;if((e|0)!=0){d=e;gGC(d|0,9706056,76)|0}c[9752472+(j<<2)>>2]=c[2433530];c[14113936+(j<<2)>>2]=c[2076596];c[9669104+(j<<2)>>2]=c[3541536];c[1836236]=-1;if((c[2112968]|0)==0){return 0}fc$()|0;return 0}function fc$(){var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;i=i+8|0;e=d|0;f=e|0;c[f>>2]=0;c[e+4>>2]=65535;e=c[2386026]|0;g=c[2112926]|0;h=512;do{j=h<<3&248;k=(h>>>5<<8)-4096|0;l=a[e+h|0]|0;m=k|j;b[g+(m<<1)>>1]=(l&255)>>>7&255;n=j|1;b[g+((k|n)<<1)>>1]=(l&255)>>>6&1;b[g+(n+1+k<<1)>>1]=(l&255)>>>5&1;n=j|3;b[g+((k|n)<<1)>>1]=(l&255)>>>4&1;b[g+(n+1+k<<1)>>1]=(l&255)>>>3&1;b[g+(n+2+k<<1)>>1]=(l&255)>>>2&1;b[g+(n+3+k<<1)>>1]=(l&255)>>>1&1;b[g+((m|7)<<1)>>1]=l&1;h=h+1|0;}while((h|0)<7680);R8(f);i=d;return 0}function fc0(a,b){a=a|0;b=b|0;var d=0,e=0;d=i;i=i+16|0;e=d|0;if((b|0)!=0){c[b>>2]=169730}if((a&96|0)==0){i=d;return 0}gGz(e|0,0,12);b=c[2414582]|0;c[e>>2]=b;c[e+4>>2]=(c[2411526]|0)-b;c[e+12>>2]=162152;gj[c[2076592]&4095](e)|0;fw$(a);i=d;return 0}function fc1(a){a=a|0;var d=0,e=0,f=0;do{if((a-1310720|0)>>>0<4096){d=0}else{e=a-2490368|0;if(e>>>0<512){f=e>>>1;if((f|0)==18){d=0;break}else if((f|0)==22){d=39;break}else{d=b[(c[2430802]|0)+(f<<1)>>1]&255;break}}f=a-2621440|0;if(f>>>0>=32){d=0;break}e=f>>>1;if((e|0)==5){f=c[2385810]|0;c[2385810]=0;d=f&255;break}else if((e|0)==14){d=1;break}else if((e|0)==15){c[8452200+(c[2394]<<2)>>2]=0;c[2276080]=0;d=0;break}else{d=-1;break}}}while(0);return d|0}function fc2(a,e){a=a|0;e=e|0;var f=0,g=0,h=0;f=a-2490368|0;if(f>>>0<512){g=f>>>1;b[(c[2430802]|0)+(g<<1)>>1]=e&255;switch(g|0){case 128:{if((e&255)>=192){return}c[2429694]=c[(c[2438404]|0)+((e&255)<<2)>>2];return};case 160:{if((e&255)>=192){return}c[(c[2438404]|0)+((e&255)<<2)>>2]=d[(c[3532116]|0)+((c[3532112]|0)+16777215&(c[2429694]|0)>>>8)|0]|0;return};case 2:{c[2429694]=c[2429694]&16776960|e&255;return};case 1:{c[2429694]=c[2429694]&16711935|(e&255)<<8;return};case 0:{c[2429694]=c[2429694]&65535|(e&255)<<16;return};default:{return}}}g=a-2621440|0;if(g>>>0>=32){f=a-3145728|0;if(f>>>0>=64){return}c[(c[2420430]|0)+48+((f>>>1)*92|0)+80>>2]=(((c[3532112]|0)>>>21)+255&(e&255))<<20;return}L66845:do{switch(g>>>1|0){case 4:{f=e&255;switch(f>>>4&7|0){case 3:{c[2426848]=1;c[2426844]=0;c[2426960]=c[2438402]<<7;return};case 6:{c[2426848]=2;c[2426842]=0;c[2426846]=c[2438402]<<3;return};case 0:case 1:case 2:case 4:case 5:case 7:{return};default:{h=f;break L66845}}break};case 5:{h=e&255;break};case 12:{c[2433276]=e&255;return};case 6:{c[2438402]=c[2438402]&255|(e&255)<<8;return};case 7:{c[2438402]=c[2438402]&65280|e&255;return};default:{return}}}while(0);c[2385796]=h;return}function fc3(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=b-2097152|0;if(f>>>0>=32){g=0;return g|0}b=f>>>1;f=c[2420430]|0;h=a[f+40|0]|0;i=h&31;j=f+48+(i*92|0)|0;if((h&255)<32){switch(b|0){case 3:{g=(c[f+48+(i*92|0)+8>>2]|0)>>>2&65535;return g|0};case 8:{g=c[f+48+(i*92|0)+12>>2]&65535;return g|0};case 7:{g=c[f+48+(i*92|0)+48>>2]&65535;return g|0};case 0:{k=c[j>>2]|0;g=(k&251|k>>>12&4|k<<2&3072|k>>>2&768|61440)&65535;return g|0};case 11:{g=(c[f+48+(i*92|0)+24>>2]|0)>>>2&65535;return g|0};case 5:{g=(c[f+48+(i*92|0)+16>>2]|0)>>>2&65535;return g|0};case 4:{g=(c[f+48+(i*92|0)+16>>2]|0)>>>18&65535;return g|0};case 10:{g=(c[f+48+(i*92|0)+24>>2]|0)>>>18&65535;return g|0};case 15:{g=h&255;return g|0};case 13:{g=d[f+41|0]|0;return g|0};case 1:{g=(c[f+48+(i*92|0)+4>>2]|0)>>>1&65535;return g|0};case 6:{g=c[f+48+(i*92|0)+40>>2]&65535;return g|0};case 14:{k=f+46|0;l=d[k]|0;a[k]=-128;k=c[f+32>>2]|0;if((k|0)==0){g=l;return g|0}gf[k&2047](0);g=l;return g|0};case 2:{g=(c[f+48+(i*92|0)+8>>2]|0)>>>18&65535;return g|0};case 9:{g=c[f+48+(i*92|0)+28>>2]&65535;return g|0};default:{g=0;return g|0}}}if((h&255)>=64){if((b|0)==9){l=c[f+36>>2]|0;if((l|0)==0){g=0;return g|0}g=gD[l&8191]()|0;return g|0}else if((b|0)==15){g=h&255;return g|0}else if((b|0)==8){g=d[f+42|0]|0;return g|0}else{g=0;return g|0}}switch(b|0){case 1:{g=c[f+48+(i*92|0)+56>>2]&65535;return g|0};case 2:{g=c[f+48+(i*92|0)+60>>2]&65535;return g|0};case 5:{g=c[f+48+(i*92|0)+72>>2]&65535;return g|0};case 6:{b=c[j>>2]|0;do{if((b&3|0)!=0){l=c[f+4+(b>>>14<<2)>>2]|0;if((l|0)==0){break}c[f+48+(i*92|0)+76>>2]=e[l+(((c[f+48+(i*92|0)+24>>2]|0)>>>11)+(c[f+48+(i*92|0)+80>>2]|0)<<1)>>1]|0}}while(0);g=c[f+48+(i*92|0)+76>>2]&65535;return g|0};case 14:{b=f+46|0;l=d[b]|0;a[b]=-128;b=c[f+32>>2]|0;if((b|0)==0){g=l;return g|0}gf[b&2047](0);g=l;return g|0};case 0:{l=c[j>>2]|0;g=(l&251|l>>>12&4|l<<2&3072|l>>>2&768|61440)&65535;return g|0};case 3:{g=c[f+48+(i*92|0)+64>>2]&65535;return g|0};case 4:{g=c[f+48+(i*92|0)+68>>2]&65535;return g|0};case 15:{g=h&255;return g|0};case 13:{g=d[f+41|0]|0;return g|0};default:{g=0;return g|0}}return 0}function fc4(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=b-2097152|0;if(e>>>0>=32){return}b=e>>>1;e=c[2420430]|0;f=e+40|0;g=a[f]|0;h=g&31;i=e+48+(h*92|0)|0;if((g&255)>=32){if((g&255)>=64){if((b|0)==15){if((d&255)==0){return}a[f]=d&127;return}else if((b|0)==8){a[e+42|0]=d&7;return}else if((b|0)==13){if((d&255)==0){return}g=d&31;a[e+41|0]=g;c[e>>2]=((c[e+28>>2]|0)>>>0)/((((g&255)<<4)+16|0)>>>0)|0;return}else{return}}switch(b|0){case 13:{if((d&255)==0){return}g=d&31;a[e+41|0]=g;c[e>>2]=((c[e+28>>2]|0)>>>0)/((((g&255)<<4)+16|0)>>>0)|0;return};case 6:{g=d&65535;j=g&255;if((j|0)!=0){k=e+48+(h*92|0)+76|0;c[k>>2]=c[k>>2]&-256|j}j=g&65280;if((j|0)==0){return}g=e+48+(h*92|0)+76|0;c[g>>2]=(c[g>>2]&255|j)<<16>>16;return};case 5:{j=d&65535;g=j&255;if((g|0)!=0){k=e+48+(h*92|0)+72|0;c[k>>2]=c[k>>2]&-256|g}g=j&65280;if((g|0)==0){return}j=e+48+(h*92|0)+72|0;c[j>>2]=(c[j>>2]&255|g)<<16>>16;return};case 4:{g=d&65535;j=g&255;if((j|0)!=0){k=e+48+(h*92|0)+68|0;c[k>>2]=c[k>>2]&-256|j}j=g&65280;if((j|0)==0){return}g=e+48+(h*92|0)+68|0;c[g>>2]=(c[g>>2]&255|j)<<16>>16;return};case 3:{j=d&65535;g=j&255;if((g|0)!=0){k=e+48+(h*92|0)+64|0;c[k>>2]=c[k>>2]&-256|g}g=j&65280;if((g|0)==0){return}j=e+48+(h*92|0)+64|0;c[j>>2]=(c[j>>2]&255|g)<<16>>16;return};case 0:{g=d&65535;if((g&255|0)!=0){j=i|0;c[j>>2]=g<<12&16384|g&251|c[j>>2]&-16636}if((g&65280|0)==0){return}j=i|0;c[j>>2]=g>>>2&768|g<<2&3072|c[j>>2]&-3841;return};case 15:{if((d&255)==0){return}a[f]=d&127;return};case 1:{j=d&65535;g=j&255;if((g|0)!=0){k=e+48+(h*92|0)+56|0;c[k>>2]=c[k>>2]&-256|g}g=j&65280;if((g|0)==0){return}j=e+48+(h*92|0)+56|0;c[j>>2]=(c[j>>2]&255|g)<<16>>16;return};case 2:{g=d&65535;j=g&255;if((j|0)!=0){k=e+48+(h*92|0)+60|0;c[k>>2]=c[k>>2]&-256|j}j=g&65280;if((j|0)==0){return}g=e+48+(h*92|0)+60|0;c[g>>2]=(c[g>>2]&255|j)<<16>>16;return};default:{return}}}switch(b|0){case 1:{b=d&65535;j=b&255;if((j|0)!=0){g=e+48+(h*92|0)+4|0;c[g>>2]=c[g>>2]&-511|j<<1}j=b&65280;if((j|0)==0){return}b=e+48+(h*92|0)+4|0;c[b>>2]=c[b>>2]&-130561|j<<1;return};case 15:{if((d&255)==0){return}a[f]=d&127;return};case 5:{f=d&65535;if((f&255|0)!=0){j=e+48+(h*92|0)+16|0;c[j>>2]=c[j>>2]&-897|f<<2&896}j=f&65280;if((j|0)==0){return}f=e+48+(h*92|0)+16|0;c[f>>2]=c[f>>2]&-261121|j<<2;return};case 2:{j=d&65535;f=j&255;if((f|0)!=0){b=e+48+(h*92|0)+8|0;c[b>>2]=c[b>>2]&-66846721|f<<18}if((j&65280|0)==0){return}f=e+48+(h*92|0)+8|0;c[f>>2]=c[f>>2]&-2080374785|j<<18&2080374784;return};case 11:{j=d&65535;f=j&255;if((f|0)!=0){b=e+48+(h*92|0)+24|0;c[b>>2]=c[b>>2]&-1021|f<<2}f=j&65280;if((f|0)==0){return}j=e+48+(h*92|0)+24|0;c[j>>2]=c[j>>2]&-261121|f<<2;return};case 9:{f=d&65280;if((f|0)==0){return}j=e+48+(h*92|0)+28|0;c[j>>2]=c[j>>2]&-65281|f;return};case 3:{f=d&65535;if((f&255|0)!=0){j=e+48+(h*92|0)+8|0;c[j>>2]=c[j>>2]&-897|f<<2&896}j=f&65280;if((j|0)==0){return}f=e+48+(h*92|0)+8|0;c[f>>2]=c[f>>2]&-261121|j<<2;return};case 8:{j=d&65280;if((j|0)==0){return}f=e+48+(h*92|0)+12|0;c[f>>2]=c[f>>2]&-65281|j;return};case 10:{j=d&65535;f=j&255;if((f|0)!=0){b=e+48+(h*92|0)+24|0;c[b>>2]=c[b>>2]&-66846721|f<<18}if((j&65280|0)==0){return}f=e+48+(h*92|0)+24|0;c[f>>2]=c[f>>2]&-2080374785|j<<18&2080374784;return};case 0:{j=d&65535;if((j&255|0)!=0){f=i|0;c[f>>2]=j<<12&16384|j&251|c[f>>2]&-16636}if((j&65280|0)==0){return}f=i|0;c[f>>2]=j>>>2&768|j<<2&3072|c[f>>2]&-3841;return};case 6:{f=d&65535;if((f&255|0)!=0){j=e+48+(h*92|0)+40|0;c[j>>2]=c[j>>2]&-241|f&240}j=f&65280;if((j|0)==0){return}f=e+48+(h*92|0)+40|0;c[f>>2]=c[f>>2]&-65281|j;return};case 7:{j=d&65535;if((j&255|0)!=0){f=e+48+(h*92|0)+48|0;c[f>>2]=c[f>>2]&-241|j&240}f=j&65280;if((f|0)==0){return}j=e+48+(h*92|0)+48|0;c[j>>2]=c[j>>2]&-65281|f;return};case 13:{if((d&255)==0){return}f=d&31;a[e+41|0]=f;c[e>>2]=((c[e+28>>2]|0)>>>0)/((((f&255)<<4)+16|0)>>>0)|0;return};case 4:{f=d&65535;d=f&255;if((d|0)!=0){j=e+48+(h*92|0)+16|0;c[j>>2]=c[j>>2]&-66846721|d<<18}if((f&65280|0)==0){return}d=e+48+(h*92|0)+16|0;c[d>>2]=c[d>>2]&-2080374785|f<<18&2080374784;return};default:{return}}}function fc5(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;if((b|0)==3145732){e=a[9733288]|0;return e|0}else if((b|0)==3145731){f=d[14128320]|0;do{if((c[2406632]|0)==0){g=c[2443744]|0;if((g|0)<=0){h=128;break}c[2443744]=g-1;h=0}else{h=(c[2432962]|0)>>>((c[(c[2420380]|0)+4>>2]|0)>>>0)<<7&128}}while(0);e=(h|f)&255;return e|0}else if((b|0)==3407873){e=((a[14128288]|0)==0)<<31>>31;return e|0}else if((b|0)==3407874){e=127;return e|0}else if((b|0)==3407875){e=127;return e|0}else if((b|0)==3407872){f=(a[14128290]|0)==0?(a[14128289]|0)==0?128:255:0;h=c[2439402]|0;if((h|0)==(f|0)){e=f&255;return e|0}g=f-h|0;if(h>>>0<f>>>0){i=(g|0)>2?2:g}else{i=(g|0)<-2?-2:g}g=i+h|0;c[2439402]=g;e=g&255;return e|0}else if((b|0)==3145730){e=a[14128321]|0;return e|0}else if((b|0)==3145729){e=a[14128480]|a[14128322];return e|0}else{e=-1;return e|0}return 0}function fc6(b,d){b=b|0;d=d|0;if((b|0)==3407874|(b|0)==3407873|(b|0)==3407872){c[8452200+(c[2394]<<2)>>2]=8195;c[2276080]=768;if((c[2276079]|0)>>>0>=768){return}RH(3);return}else if((b|0)==3145732){a[9733288]=d;return}else if((b|0)==3145731){b=d&255;c[2415256]=b&64;d=b>>>4&1;c[3528406]=d^1;if((d|0)==0){c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2]}Tr(b>>>5&1);return}else{return}}function fc7(a){a=a|0;return 0}function fc8(a,d){a=a|0;d=d|0;var e=0;e=a-1310720|0;if(e>>>0<8192){b[(c[3531970]|0)+(e>>>1<<1)>>1]=d;return}e=a-1769472|0;if(e>>>0<48){eXO(e>>>1,d);return}if((a|0)!=2359298){return}b[4866640]=d;if((d&512)!=0){return}d=c[2394]|0;a=c[14130368+(d<<2)>>2]|0;if((a|0)!=0){gGC(a|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=1;c[2112932]=c[3532597];d=c[3532593]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113061];RI();d=c[2394]|0;a=c[14130368+(d<<2)>>2]|0;if((a|0)!=0){gGC(a|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];return}function fc9(a){a=a|0;return 0}function fda(a,d){a=a|0;d=d|0;var e=0,f=0;e=a-1310720|0;if(e>>>0>=8192){return}a=c[3531970]|0;f=e>>>1;b[a+(f<<1)>>1]=d&65535;b[a+(f+1<<1)>>1]=d>>>16&65535;return}function fdb(a){a=a|0;return 0}function fdc(a,b){a=a|0;b=b|0;return}function fdd(a){a=a|0;return 0}function fde(a,b){a=a|0;b=b|0;return}function fdf(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>28){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3339268+(b*112|0)>>2];c[a+104>>2]=c[3339272+(b*112|0)>>2];c[a+108>>2]=c[3339276+(b*112|0)>>2];d=0;return d|0}function fdg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<29&(d|0)==0)){e=1;return e|0}c[a>>2]=3339168+(b*112|0);e=0;return e|0}function fdh(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1186072+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function fdi(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=c[642608+(c[2436]<<2)>>2]|0;e=c[d+128>>2]|0;if((c[d+52>>2]&4|0)==0){c[2113068]=e;f=c[d+132>>2]|0;c[2113070]=f;c[2443814]=e;c[2440436]=f;g=e;h=f}else{c[2113070]=e;f=c[d+132>>2]|0;c[2113068]=f;c[2440436]=e;c[2443814]=f;g=f;h=e}e=ag(g<<1,h)|0;h=gGq(e)|0;c[2112926]=h;if((h|0)!=0){gGz(h|0,0,e|0)}c[3532162]=1024;c[3532160]=4;c[3532142]=16;c[3532164]=16;c[3532148]=1983592;c[3532140]=6964056;c[3532138]=6963800;c[3532042]=16384;c[3532002]=1024;c[3532e3]=4;a[7460944]=1;c[3532004]=16;c[3531998]=961336;c[3531992]=4969304;c[3531990]=4968888;c[3532034]=65536;c[3532112]=10485760;c[3532044]=3;a[7460992]=1;c[2113026]=266666;c[2113024]=266666;c[2113022]=266666;eZ9(0)|0;c[3532048]=0;c[3532204]=0;e=c[3532200]|0;c[3532198]=e;h=(c[3532194]|0)+e|0;c[3532192]=h;e=h+(c[3532188]|0)|0;c[3531976]=e;h=e+(c[3531972]|0)|0;c[3532116]=h;e=h+(c[3532112]|0)|0;c[3532126]=e;h=e+(c[3532122]|0)|0;e=h|0;c[3532020]=e;c[3532208]=e;c[3532206]=h+131072;c[3531970]=h+197120;c[3532026]=h+205312;c[3532008]=h+238080;c[2436806]=h+303616;c[2433278]=h+369152;c[2430802]=h+371200;c[2438404]=h+371712;e=h+372480|0;h=e|0;c[3532022]=h;c[3532136]=h;h=ag(c[3532142]|0,c[3532042]|0)|0;g=(ag(h,c[3532164]|0)|0)+e|0;c[3531962]=g;e=ag(a[7460944]|0?16:0,c[3532034]|0)|0;h=(ag(e,c[3532004]|0)|0)+g|0;c[3532028]=h;c[3528928]=h+32768;g=h+622592|0;c[3532046]=g;h=g;g=0;while(1){if((g|0)>=1024){break}i=9638528+(g<<2)|0;if((c[i>>2]|0)==0){j=51454;break}else{g=g+1|0}}do{if((j|0)==51454){g=gGq(h)|0;c[i>>2]=g;if((g|0)==0){break}gGz(g|0,0,h|0);c[3532048]=g;gGz(g|0,0,h|0);c[3532204]=g;e=c[3532200]|0;c[3532198]=g+e;f=(c[3532194]|0)+e|0;c[3532192]=g+f;e=f+(c[3532188]|0)|0;c[3531976]=g+e;f=e+(c[3531972]|0)|0;c[3532116]=g+f;e=f+(c[3532112]|0)|0;c[3532126]=g+e;f=e+(c[3532122]|0)|0;e=g+f|0;c[3532020]=e;c[3532208]=e;c[3532206]=g+(f+131072);c[3531970]=g+(f+197120);c[3532026]=g+(f+205312);c[3532008]=g+(f+238080);c[2436806]=g+(f+303616);c[2433278]=g+(f+369152);c[2430802]=g+(f+371200);c[2438404]=g+(f+371712);e=f+372480|0;f=g+e|0;c[3532022]=f;c[3532136]=f;f=ag(c[3532142]|0,c[3532042]|0)|0;d=(ag(f,c[3532164]|0)|0)+e|0;c[3531962]=g+d;e=ag(a[7460944]|0?16:0,c[3532034]|0)|0;f=(ag(e,c[3532004]|0)|0)+d|0;c[3532028]=g+f;c[3528928]=g+(f+32768);c[3532046]=g+(f+622592);if((eZ9(1)|0)!=0){k=1;return k|0}eXS(c[3532042]|0,0,32,8,-1,0,0);f=0;while(1){if((f|0)>=1024){l=0;break}m=9638528+(f<<2)|0;if((c[m>>2]|0)==0){j=51460;break}else{f=f+1|0}}do{if((j|0)==51460){f=gGq(12582912)|0;c[m>>2]=f;if((f|0)==0){l=0;break}gGz(f|0,0,12582912);l=f}}while(0);f=c[3532116]|0;gGC(l|0,f|0,12582912)|0;gGz(f|0,0,c[3532112]|0);g=f+12582912|0;gGC(g|0,l|0,4194304)|0;g=l+4194304|0;gGC(f|0,g|0,4194304)|0;d=f+4194304|0;gGC(d|0,g|0,4194304)|0;g=f+8388608|0;f=l+8388608|0;gGC(g|0,f|0,4194304)|0;f=0;while(1){if((f|0)>=1024){break}n=9638528+(f<<2)|0;if((c[n>>2]|0)==(l|0)){j=51465;break}else{f=f+1|0}}if((j|0)==51465){gGr(l);c[n>>2]=0}fxU(0,110018592);if((c[2394]|0)==0){o=c[2112932]|0}else{c[2394]=0;f=c[3532596]|0;c[2112932]=f;g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060];o=f}f=c[3532204]|0;g=o|0;d=0;while(1){e=f+d|0;c[g>>2]=e;c[g+131072>>2]=e;e=d+1024|0;if(e>>>0>1048575){break}else{g=g+4|0;d=e}}d=c[3532208]|0;g=o+4096|0;f=1048576;while(1){e=d+(f-1048576)|0;c[g>>2]=e;c[g+65536>>2]=e;c[g+131072>>2]=e;e=f+1024|0;if(e>>>0>1179647){break}else{g=g+4|0;f=e}}f=c[3532232]|0;g=o+6144|0;d=1572864;while(1){e=f+(d-1572864)|0;c[g>>2]=e;c[g+65536>>2]=e;c[g+131072>>2]=e;e=d+1024|0;if(e>>>0>1638399){break}else{g=g+4|0;d=e}}d=c[3532008]|0;g=o+8192|0;f=2097152;while(1){e=d+(f-2097152)|0;c[g>>2]=e;c[g+65536>>2]=e;c[g+131072>>2]=e;e=f+1024|0;if(e>>>0>2162687){break}else{g=g+4|0;f=e}}f=c[2433278]|0;c[o+11264>>2]=f;c[o+76800>>2]=f;c[o+142336>>2]=f;g=f+1024|0;c[o+11268>>2]=g;c[o+76804>>2]=g;c[o+142340>>2]=g;g=c[3532026]|0;f=o+10240|0;d=2621440;while(1){e=g+(d-2621440)|0;c[f>>2]=e;c[f+65536>>2]=e;c[f+131072>>2]=e;e=d+1024|0;if(e>>>0>2654207){break}else{f=f+4|0;d=e}}c[o+196608>>2]=848;c[o+196648>>2]=2194;c[o+196688>>2]=296;c[o+196728>>2]=2700;c[o+196768>>2]=166;c[o+196808>>2]=2022;d=c[3532592]|0;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fxU(1,425984);if((c[2394]|0)==1){p=c[2112932]|0}else{c[2394]=1;d=c[3532597]|0;c[2112932]=d;f=c[3532593]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113061];p=d}d=c[3532198]|0;f=p|0;g=0;while(1){e=d+g|0;c[f>>2]=e;c[f+131072>>2]=e;e=g+1024|0;if(e>>>0>262143){break}else{f=f+4|0;g=e}}g=c[3532206]|0;f=p+8192|0;d=2097152;while(1){e=g+(d-2097152)|0;c[f>>2]=e;c[f+65536>>2]=e;c[f+131072>>2]=e;e=d+1024|0;if(e>>>0>2162687){break}else{f=f+4|0;d=e}}d=c[3532008]|0;f=p+32768|0;e=8388608;while(1){q=d+(e-8388608)|0;c[f>>2]=q;c[f+65536>>2]=q;c[f+131072>>2]=q;q=e+1024|0;if(q>>>0>8454143){break}else{f=f+4|0;e=q}}e=g+65536|0;c[p+40960>>2]=e;c[p+106496>>2]=e;c[p+172032>>2]=e;c[p+196608>>2]=1644;c[p+196648>>2]=2008;c[p+196688>>2]=3224;c[p+196728>>2]=2892;e=c[3532593]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[2113061]=c[2113054];c[2394]=-1;fxU(2,425984);if((c[2394]|0)==2){r=c[2112932]|0}else{c[2394]=2;e=c[3532598]|0;c[2112932]=e;f=c[3532594]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113062];r=e}e=c[2436806]|0;f=r|0;d=0;while(1){q=e+d|0;c[f>>2]=q;c[f+65536>>2]=q;c[f+131072>>2]=q;q=d+1024|0;if(q>>>0>65535){break}else{f=f+4|0;d=q}}d=r+256|0;f=65536;while(1){g=e+(f-65536)|0;c[d>>2]=g;c[d+65536>>2]=g;c[d+131072>>2]=g;g=f+1024|0;if(g>>>0>131071){break}else{d=d+4|0;f=g}}f=r+512|0;d=131072;while(1){g=e+(d-131072)|0;c[f>>2]=g;c[f+65536>>2]=g;c[f+131072>>2]=g;g=d+1024|0;if(g>>>0>196607){break}else{f=f+4|0;d=g}}d=r+768|0;f=196608;while(1){g=e+(f-196608)|0;c[d>>2]=g;c[d+65536>>2]=g;c[d+131072>>2]=g;g=f+1024|0;if(g>>>0>262143){break}else{d=d+4|0;f=g}}f=c[3532192]|0;d=r+49152|0;g=12582912;while(1){q=f+(g-12582912)|0;c[d>>2]=q;c[d+131072>>2]=q;q=g+1024|0;if(q>>>0>12713983){break}else{d=d+4|0;g=q}}g=r+49664|0;d=12713984;while(1){q=f+(d-12582912)|0;c[g>>2]=q;c[g+131072>>2]=q;q=d+1024|0;if(q>>>0>12845055){break}else{g=g+4|0;d=q}}d=r+65280|0;g=16711680;while(1){f=e+(g-16711680)|0;c[d>>2]=f;c[d+65536>>2]=f;c[d+131072>>2]=f;f=g+1024|0;if(f>>>0>16777215){break}else{d=d+4|0;g=f}}c[r+196608>>2]=198;c[r+196648>>2]=3456;c[r+196688>>2]=528;c[r+196728>>2]=1528;c[r+196856>>2]=974;g=c[3532594]|0;if((g|0)!=0){gGC(g|0,9104152,280)|0}c[2113062]=c[2113054];c[2394]=-1;Tq(682320);if(!(a[1040128]|0)){g=c[3532126]|0;gGC(14100392,g|0,128)|0}g=c[3532116]|0;d=gGq(3004)|0;c[2420430]=d;gGz(d|0,0,3004);if((g|0)==0){c[d+4>>2]=0;s=0}else{e=g;c[d+4>>2]=e;s=e}c[d+8>>2]=s;c[d+12>>2]=0;c[d+16>>2]=0;c[d+28>>2]=15238050;c[d+32>>2]=0;a[d+46|0]=-128;c[d+2996>>2]=gGq(512)|0;d=(c[2420430]|0)+2996|0;e=0;do{g=e<<11;f=e>>>5&524287;q=g&63488|1024;if((f|0)==0){b[(c[d>>2]|0)+(e<<1)>>1]=q<<16>>23&65535}else{b[(c[d>>2]|0)+(e<<1)>>1]=((q>>>1|g&32768)<<16^-2147483648)>>16>>(f^7)&65535}e=e+1|0;}while((e|0)<256);e=gGq(8192)|0;d=c[2420430]|0;f=d+3e3|0;c[f>>2]=e;g=0;q=e;while(1){b[q+(g<<1)>>1]=(g<<11&522240|524288)>>>((20-(g>>>8&255)|0)>>>0)&65535;e=g+1|0;if((e|0)>=4096){t=0;break}g=e;q=c[f>>2]|0}do{a[d+48+(t*92|0)+84|0]=t&255;c[d+48+(t*92|0)>>2]=3;c[d+48+(t*92|0)+12>>2]=65535;c[d+48+(t*92|0)+28>>2]=65535;c[d+48+(t*92|0)+80>>2]=0;c[d+48+(t*92|0)+88>>2]=2147483647;t=t+1|0;}while((t|0)<32);d=gGq(8e4)|0;c[(c[2420430]|0)+2992>>2]=d;eZ8()|0;a[9733288]=0;b[4866640]=0;c[2439402]=0;d=c[2436806]|0;f=c[3532192]|0;b[d>>1]=b[f>>1]|0;b[d+2>>1]=b[f+2>>1]|0;b[d+4>>1]=b[f+4>>1]|0;b[d+6>>1]=b[f+6>>1]|0;if((c[2394]|0)!=2){c[2394]=2;c[2112932]=c[3532598];f=c[3532594]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113062]}RI();f=c[2394]|0;d=c[14130368+(f<<2)>>2]|0;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[8452240+(f<<2)>>2]=c[2113054];c[2394]=-1;k=0;return k|0}}while(0);c[3532048]=0;k=1;return k|0}function fdj(){e_a()|0;a[9733288]=0;b[4866640]=0;c[2439402]=0;return 0}function fdk(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;if((a[14128072]|0)!=0){eZ8()|0;a[9733288]=0;b[4866640]=0;c[2439402]=0;d=c[2436806]|0;e=c[3532192]|0;b[d>>1]=b[e>>1]|0;b[d+2>>1]=b[e+2>>1]|0;b[d+4>>1]=b[e+4>>1]|0;b[d+6>>1]=b[e+6>>1]|0;if((c[2394]|0)!=2){c[2394]=2;c[2112932]=c[3532598];e=c[3532594]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113062]}RI();e=c[2394]|0;d=c[14130368+(e<<2)>>2]|0;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[8452240+(e<<2)>>2]=c[2113054];c[2394]=-1}a[14128320]=127;a[14128321]=-1;a[14128322]=-25;e=0;d=127;f=-1;g=-25;do{d=(d&255)-((a[14128312+e|0]&1)<<e)&255;f=(f&255)-((a[14128304+e|0]&1)<<e)&255;g=(g&255)-((a[14128296+e|0]&1)<<e)&255;e=e+1|0;}while((e|0)<8);a[14128320]=d;a[14128321]=f;a[14128322]=g;c[2113032]=0;c[2113031]=0;c[2113030]=0;g=c[2392]|0;if((g|0)>=0){gGz(8452240,0,((g|0)>0?(g<<2)+4|0:4)|0)}c[2113054]=0;g=0;f=0;L67405:while(1){d=f;while(1){if((d|0)>=100){break L67405}if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060]}h=d+1|0;e=(ag(c[2113026]|0,h)|0)/100|0;i=e-(c[2113030]|0)|0;c[2113028]=i;c[2113056]=i;e=RG(i)|0;c[2113054]=(c[2113054]|0)+e;c[2276108]=-1;c[2113056]=-1;c[2113030]=(c[2113030]|0)+e;e=(d|0)==99;do{if(e){c[8452200+(c[2394]<<2)>>2]=8194;c[2276080]=512;if((c[2276079]|0)>>>0>=512){break}RH(2)}}while(0);i=c[2394]|0;j=c[14130368+(i<<2)>>2]|0;if((j|0)!=0){gGC(j|0,9104152,280)|0}c[8452240+(i<<2)>>2]=c[2113054];c[2394]=-1;if((b[4866640]&512)!=0){c[2394]=1;c[2112932]=c[3532597];i=c[3532593]|0;if((i|0)!=0){gGC(9104152,i|0,280)|0}c[2113054]=c[2113061];i=(ag(c[2113024]|0,h)|0)/100|0;j=i-(c[2113031]|0)|0;c[2113028]=j;c[2113056]=j;i=RG(j)|0;c[2113054]=(c[2113054]|0)+i;c[2276108]=-1;c[2113056]=-1;c[2113031]=(c[2113031]|0)+i;do{if(e){c[8452200+(c[2394]<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0>=1024){break}RH(4)}}while(0);e=c[2394]|0;i=c[14130368+(e<<2)>>2]|0;if((i|0)!=0){gGC(i|0,9104152,280)|0}c[8452240+(e<<2)>>2]=c[2113054];c[2394]=-1}c[2394]=2;c[2112932]=c[3532598];e=c[3532594]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113062];e=(ag(c[2113022]|0,h)|0)/100|0;i=e-(c[2113032]|0)|0;c[2113028]=i;c[2113056]=i;e=RG(i)|0;c[2113054]=(c[2113054]|0)+e;c[2276108]=-1;c[2113056]=-1;c[2113032]=(c[2113032]|0)+e;e=c[2426848]|0;do{if((e|0)==1){i=(c[2426844]|0)+(c[2113028]|0)|0;c[2426844]=i;if(i>>>0<(c[2426960]|0)>>>0){break}c[2426848]=0;if((c[2385796]&8|0)==0){break}c[8452200+(c[2394]<<2)>>2]=8198;c[2276080]=1536;if((c[2276079]|0)>>>0<1536){RH(6);k=c[2426848]|0}else{k=0}c[2385810]=c[2385810]|8;l=k;m=51584}else{l=e;m=51584}}while(0);do{if((m|0)==51584){m=0;if((l|0)!=2){break}e=(c[2426842]|0)+(c[2113028]|0)|0;c[2426842]=e;if(e>>>0<(c[2426846]|0)>>>0){break}if((c[2385796]&8|0)!=0){c[8452200+(c[2394]<<2)>>2]=8198;c[2276080]=1536;if((c[2276079]|0)>>>0<1536){RH(6)}c[2385810]=c[2385810]|8}c[2426842]=0}}while(0);e=c[2394]|0;i=c[14130368+(e<<2)>>2]|0;if((i|0)!=0){gGC(i|0,9104152,280)|0}c[8452240+(e<<2)>>2]=c[2113054];c[2394]=-1;n=c[2112964]|0;if((n|0)==0){d=h}else{break}}d=a[9688]|0?5:0;TL(n+(g<<1<<1)|0,d);g=d+g|0;f=h}h=c[2112964]|0;do{if((h|0)!=0){f=a[9688]|0?534:0;if((f|0)==(g|0)){break}TL(h+(g<<1<<1)|0,f-g|0)}}while(0);if((c[2112968]|0)==0){return 0}g=b[725160+(((c[2436808]|0)>>>2&7)<<1)>>1]|0;h=c[3532028]|0;f=0;n=c[3532026]|0;l=h;while(1){m=c[n>>2]|0;c[l>>2]=m>>>19&31|m<<8&63488|m>>>24<<3&2016;m=f+1|0;if((m|0)<8192){f=m;n=n+4|0;l=l+4|0}else{break}}l=g&65535;g=l>>>8;n=c[2112926]|0;gGz(n|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);n=c[3531970]|0;f=c[3531976]|0;m=c[3528928]|0;gGz(m|0,0,589824);k=2044;d=m;while(1){m=c[n+(k<<2)>>2]|0;e=m>>>23&1;i=m&32767;j=c[n+((k|2)<<2)>>2]|0;o=j>>>18&3;p=j&1023;q=c[n+((k|3)<<2)>>2]|0;r=q>>>18&1;s=j>>>10&255|256;if((i|0)==0){t=d}else{u=q&1023;v=q>>>17&1;w=v^1;x=(m>>>16&127)+1|0;m=(q>>>10&127)+1|0;q=u-132|0;y=(q|0)>832?u-1156|0:q;q=(p>>>0>832?j|-1024:p)-48|0;p=r<<1;j=p+2|0;u=(-r<<2&12)+4|0;z=i<<2;i=(v|0)==0;v=p|1;p=r+1|0;r=e^1;if((e|0)==0){if(i){e=0;A=d;while(1){B=(e|0)/(j|0)|0;C=(e|0)%(j|0)|0;D=b[f+(C+z+(v-B<<p)<<1)>>1]|0;if(D<<16>>16==-1){E=A}else{F=(ag(C,x)|0)/(j|0)|0;G=((ag(B,m)|0)/(j|0)|0)+y|0;H=ag(B+1|0,m)|0;B=((ag(C+1|0,x)|0)/(j|0)|0)-F|0;c[A>>2]=D&65535;c[A+12>>2]=s;c[A+16>>2]=r;c[A+20>>2]=w;c[A+4>>2]=F+q;c[A+8>>2]=G;c[A+24>>2]=B<<12;c[A+28>>2]=((H|0)/(j|0)|0)+y-G<<12;c[A+32>>2]=o;E=A+36|0}G=e+1|0;if((G|0)<(u|0)){e=G;A=E}else{t=E;break}}}else{A=0;e=d;while(1){G=(A|0)/(j|0)|0;H=(A|0)%(j|0)|0;B=b[f+(H+z+(G<<p)<<1)>>1]|0;if(B<<16>>16==-1){I=e}else{F=(ag(H,x)|0)/(j|0)|0;D=((ag(G,m)|0)/(j|0)|0)+y|0;C=ag(G+1|0,m)|0;G=((ag(H+1|0,x)|0)/(j|0)|0)-F|0;c[e>>2]=B&65535;c[e+12>>2]=s;c[e+16>>2]=r;c[e+20>>2]=w;c[e+4>>2]=F+q;c[e+8>>2]=D;c[e+24>>2]=G<<12;c[e+28>>2]=((C|0)/(j|0)|0)+y-D<<12;c[e+32>>2]=o;I=e+36|0}D=A+1|0;if((D|0)<(u|0)){A=D;e=I}else{t=I;break}}}}else{e=v|z;if(i){A=0;D=d;while(1){C=(A|0)/(j|0)|0;G=(A|0)%(j|0)|0;F=b[f+(e-G+(v-C<<p)<<1)>>1]|0;if(F<<16>>16==-1){J=D}else{B=(ag(G,x)|0)/(j|0)|0;H=((ag(C,m)|0)/(j|0)|0)+y|0;K=ag(C+1|0,m)|0;C=((ag(G+1|0,x)|0)/(j|0)|0)-B|0;c[D>>2]=F&65535;c[D+12>>2]=s;c[D+16>>2]=r;c[D+20>>2]=w;c[D+4>>2]=B+q;c[D+8>>2]=H;c[D+24>>2]=C<<12;c[D+28>>2]=((K|0)/(j|0)|0)+y-H<<12;c[D+32>>2]=o;J=D+36|0}H=A+1|0;if((H|0)<(u|0)){A=H;D=J}else{t=J;break}}}else{D=0;A=d;while(1){v=(D|0)/(j|0)|0;i=(D|0)%(j|0)|0;z=b[f+(e-i+(v<<p)<<1)>>1]|0;if(z<<16>>16==-1){L=A}else{H=(ag(i,x)|0)/(j|0)|0;K=((ag(v,m)|0)/(j|0)|0)+y|0;C=ag(v+1|0,m)|0;v=((ag(i+1|0,x)|0)/(j|0)|0)-H|0;c[A>>2]=z&65535;c[A+12>>2]=s;c[A+16>>2]=r;c[A+20>>2]=w;c[A+4>>2]=H+q;c[A+8>>2]=K;c[A+24>>2]=v<<12;c[A+28>>2]=((C|0)/(j|0)|0)+y-K<<12;c[A+32>>2]=o;L=A+36|0}K=D+1|0;if((K|0)<(u|0)){D=K;A=L}else{t=L;break}}}}}A=k-4|0;if((A|0)>-1){k=A;d=t}else{break}}t=l>>>12;d=l>>>4;k=c[3532136]|0;if((t|0)==2){eXQ(2,1,k)}else if((t|0)==3){eXQ(3,1,k)}else if((t|0)==0){eXP(0,1,k)}else if((t|0)==1){eXP(1,1,k)}t=g&15;if((t|0)==1){eXP(1,0,k)}else if((t|0)==0){eXP(0,0,k)}else if((t|0)==3){eXQ(3,0,k)}else if((t|0)==2){eXQ(2,0,k)}fdq(0);t=d&15;if((t|0)==2){eXQ(2,0,k)}else if((t|0)==3){eXQ(3,0,k)}else if((t|0)==0){eXP(0,0,k)}else if((t|0)==1){eXP(1,0,k)}t=l&15;if((t|0)==1){eXP(1,0,k)}else if((t|0)==0){eXP(0,0,k)}else if((t|0)==2){eXQ(2,0,k)}else if((t|0)==3){eXQ(3,0,k)}fdq(1);fdq(2);eXR();fdq(3);R8(h);return 0}function fdl(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=i;i=i+64|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;if((d|0)!=0){c[d>>2]=169737}if((b&32|0)!=0){gGz(j|0,0,12);d=c[3532020]|0;c[j>>2]=d;c[j+4>>2]=(c[3532022]|0)-d;c[j+12>>2]=162152;d=c[2076592]|0;gj[d&4095](j)|0}eZ7(b);if((b&64|0)==0){i=e;return 0}b=h|0;gGz(g|0,0,16);c[2394]=-1;if((c[2392]|0)<0){i=e;return 0}j=h+9|0;h=f;d=f|0;k=f+4|0;l=f+12|0;m=g|0;n=g+4|0;o=g+12|0;p=0;do{gGC(b|0,614896,11)|0;a[j]=p+48&255;q=8452256+(p<<2)|0;gGz(h|0,0,12);c[d>>2]=q;c[k>>2]=4;c[l>>2]=164976;gj[c[2076592]&4095](f)|0;if((c[q>>2]|0)!=0){c[m>>2]=c[14130368+(p<<2)>>2];c[n>>2]=c[8452184+(p<<2)>>2];c[o>>2]=b;q=c[2076592]|0;gj[q&4095](g)|0}p=p+1|0;}while((p|0)<=(c[2392]|0));i=e;return 0}function fdm(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>28){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1670324+(b*112|0)>>2];c[a+104>>2]=c[1670328+(b*112|0)>>2];c[a+108>>2]=c[1670332+(b*112|0)>>2];d=0;return d|0}function fdn(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<29&(d|0)==0)){e=1;return e|0}c[a>>2]=1670224+(b*112|0);e=0;return e|0}function fdo(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>28){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1673572+(b*112|0)>>2];c[a+104>>2]=c[1673576+(b*112|0)>>2];c[a+108>>2]=c[1673580+(b*112|0)>>2];d=0;return d|0}function fdp(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<29&(d|0)==0)){e=1;return e|0}c[a>>2]=1673472+(b*112|0);e=0;return e|0}function fdq(d){d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;e=c[3528928]|0;f=c[3531962]|0;g=c[3532034]|0;h=a[7460944]|0?16:0;i=c[3532004]|0;j=a[7461152]|0;k=h<<16;l=i<<16;m=c[2113068]|0;n=c[2113070]|0;o=c[2112926]|0;p=0;do{L67576:do{if((c[e+(p*36|0)+32>>2]|0)==(d|0)){q=c[e+(p*36|0)+4>>2]|0;r=c[e+(p*36|0)+8>>2]|0;s=c[e+(p*36|0)+12>>2]|0;t=c[e+(p*36|0)+16>>2]|0;u=c[e+(p*36|0)+20>>2]|0;v=c[e+(p*36|0)+24>>2]|0;w=c[e+(p*36|0)+28>>2]|0;x=ag(ag(h,((c[e+(p*36|0)>>2]|0)>>>0)%(g>>>0)|0)|0,i)|0;y=((ag(i,w)|0)+32768|0)>>>16;w=((ag(h,v)|0)+32768|0)>>>16;z=((s|0)%512|0)<<4;if(j){A=320-q-(v>>12)|0;B=(t|0)==0|0}else{A=q;B=t}if((w|0)==0|(y|0)==0){break}t=(k>>>0)/(w>>>0)|0;q=(l>>>0)/(y>>>0)|0;v=A+w|0;s=y+r|0;if((B|0)==0){C=t;D=0}else{C=-t|0;D=ag(t,w-1|0)|0}if((u|0)==0){E=q;F=0}else{E=-q|0;F=ag(q,y-1|0)|0}if((A|0)<0){G=0;H=D-(ag(C,A)|0)|0}else{G=A;H=D}if((r|0)<0){I=0;J=F-(ag(E,r)|0)|0}else{I=r;J=F}r=(v|0)>(m|0)?m:v;v=(s|0)>(n|0)?n:s;if((r|0)>(G|0)&(I|0)<(v|0)){K=J;L=I}else{break}while(1){s=(ag(K>>16,h)|0)+x|0;y=ag(L,m)|0;q=G;u=H;while(1){w=a[f+(s+(u>>16))|0]|0;if(w<<24>>24!=0){b[o+(q+y<<1)>>1]=(w&255|z)&65535}w=q+1|0;if((w|0)<(r|0)){q=w;u=u+C|0}else{break}}u=L+1|0;if((u|0)>=(v|0)){break L67576}K=K+E|0;L=u}}}while(0);p=p+1|0;}while((p|0)<16384);return}function fdr(a){a=a|0;return c[2433276]|0}function fds(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=d&65535;if((f&63488|0)==59392){d=f&2047;g=c[2387122]|0;a[g+d|0]=e;h=f&2046;i=a[g+(h|1)|0]|0;j=a[g+h|0]|0;h=(j&255)>>>4;g=(i&15|i<<4)&255;i=(h<<4|h)&255;h=(j&15|j<<4)&255;j=d>>>1;c[(c[2406910]|0)+(j<<2)>>2]=h|g<<16|i<<8;c[(c[3529912]|0)+(j<<2)>>2]=h>>>3|g<<8&63488|i<<3&2016;return}switch(f|0){case 61440:case 61441:case 61442:case 61443:{a[(c[2386180]|0)+(f&3)|0]=e;return};case 61637:case 61636:case 61635:case 61632:case 61633:case 61634:{a[(c[2440602]|0)+(f&7)|0]=e;return};case 61600:case 61601:case 61602:case 61603:{a[(c[2386314]|0)+(f&3)|0]=e;return};case 61536:{a[14112864]=e;if((c[2443510]|0)==0){c[2443746]=1;return}f=c[1836236]|0;i=c[9757320+(f<<2)>>2]|0;if((i|0)!=0){g=i;gGC(g|0,9706056,76)|0}c[9752472+(f<<2)>>2]=c[2433530];c[14113936+(f<<2)>>2]=c[2076596];c[9669104+(f<<2)>>2]=c[3541536];c[1836236]=-1;f=c[2439331]|0;if((f|0)!=0){g=f;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;g=(c[2433530]|0)+12|0;c[2433530]=g;f=c[1836236]|0;i=c[9757320+(f<<2)>>2]|0;if((i|0)!=0){h=i;gGC(h|0,9706056,76)|0}c[9752472+(f<<2)>>2]=g;c[14113936+(f<<2)>>2]=c[2076596];c[9669104+(f<<2)>>2]=c[3541536];c[1836236]=-1;f=c[2439330]|0;if((f|0)!=0){g=f;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;return};case 61538:{if(a[673144]|0){c[3529094]=e&255;return}a[9533352]=e;c[2161344]=1;if((c[2415208]|0)==1){return}c[2415208]=1;b[4830412]=b[4830412]|1;return};default:{return}}}function fdt(b){b=b|0;var d=0,e=0;d=b&65535;L67650:do{switch(d|0){case 61538:{if(!(a[673144]|0)){c[2161338]=0;e=a[9533344]|0;break L67650}b=c[3529094]|0;switch(b|0){case 52:{e=-77;break L67650;break};case 1:{e=0;break L67650;break};case 166:{e=-51;break L67650;break};case 72:{e=-1;break L67650;break};case 144:{e=-45;break L67650;break};default:{e=b&255;break L67650}}break};case 61568:case 61569:case 61570:{e=a[9634768+(d&3)|0]|0;break};case 61575:{if(a[673144]|0){e=3;break L67650}b=(c[2161344]|0)==0|0;if((c[2161338]|0)==0){e=b;break L67650}e=b|2;break};case 61537:{e=-1;break};case 61571:{e=a[9634512]|0;break};case 61572:case 61573:{e=a[9634512+(d-61571)|0]|0;break};case 61600:case 61601:case 61602:case 61603:{e=a[(c[2386314]|0)+(d&3)|0]|0;break};case 61632:case 61633:case 61634:case 61635:case 61636:case 61637:{e=a[(c[2440602]|0)+(d&7)|0]|0;break};case 61440:case 61441:case 61442:case 61443:{e=a[(c[2386180]|0)+(d&3)|0]|0;break};default:{e=0}}}while(0);return e|0}function fdu(b){b=b|0;var d=0,e=0;d=b&65535;if((d&49152|0)!=16384){e=0;return e|0}e=a[(c[3527348]|0)+(d&16383)|0]|0;return e|0}function fdv(b){b=b|0;var d=0,e=0,f=0.0,g=0.0,i=0;d=b&65535;if((d|0)==36864){b=c[3541518]|0;e=b+296|0;f=+h[e>>3];do{if(f!=0.0){g=+h[6675];if(f-(g+ +gC[c[2429842]&255]())<=0.0){h[e>>3]=0.0;break}i=a[b+307|0]|-128;return i|0}}while(0);i=a[b+307|0]|0;return i|0}else if((d|0)==40960){b=c[3541518]|0;e=b+19320|0;f=+h[e>>3];do{if(f!=0.0){g=+h[6675];if(f-(g+ +gC[c[2429842]&255]())<=0.0){h[e>>3]=0.0;break}i=a[b+19331|0]|-128;return i|0}}while(0);i=a[b+19331|0]|0;return i|0}else if((d|0)==45056){i=a[14112864]|0;return i|0}else{i=0;return i|0}return 0}function fdw(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((e|0)==40960|(e|0)==40961){lS(1,e&1,d);return}else if((e|0)==45058){c[2443510]=0;return}else if((e|0)==45057){c[2443510]=1;if((c[2443746]|0)==0){return}if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12;c[2443746]=0;return}else if((e|0)==36864|(e|0)==36865){lS(0,e&1,d);return}else{return}}function fdx(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6531076+(b*112|0)>>2];c[a+104>>2]=c[6531080+(b*112|0)>>2];c[a+108>>2]=c[6531084+(b*112|0)>>2];d=0;return d|0}function fdy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=6530976+(b*112|0);e=0;return e|0}function fdz(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5303824+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function fdA(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>78){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6856624+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fdB(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0;e=i;i=i+1080|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;c[2414878]=0;c[3529222]=0;c[3529178]=65536;c[2387316]=131072;c[3527348]=133120;c[3530768]=149504;c[3530532]=280576;c[3529912]=411648;c[2406910]=415744;c[2414580]=419840;c[2386188]=419840;c[3529310]=422912;c[3529272]=424960;c[2387122]=427008;c[2386396]=429056;c[2386314]=429312;c[2387328]=429316;c[2440602]=429444;c[2386180]=429450;c[2411524]=429454;z=0;while(1){if((z|0)>=1024){break}A=9638528+(z<<2)|0;if((c[A>>2]|0)==0){B=51826;break}else{z=z+1|0}}do{if((B|0)==51826){z=gGq(429454)|0;c[A>>2]=z;if((z|0)==0){break}c[2414878]=z;gGz(z|0,0,429454);c[3529222]=z;c[3529178]=z+65536;c[2387316]=z+131072;c[3527348]=z+133120;c[3530768]=z+149504;c[3530532]=z+280576;c[3529912]=z+411648;c[2406910]=z+415744;C=z+419840|0;c[2414580]=C;c[2386188]=C;c[3529310]=z+422912;c[3529272]=z+424960;c[2387122]=z+427008;c[2386396]=z+429056;c[2386314]=z+429312;c[2387328]=z+429316;c[2440602]=z+429444;c[2386180]=z+429450;C=z+429454|0;c[2411524]=C;c[2414064]=C;C=c[642608+(c[2436]<<2)>>2]|0;c[2406624]=c[C+52>>2]&32^32;if((c[3542200]|0)==0){D=1;i=e;return D|0}E=x+108|0;c[E>>2]=0;F=x+100|0;c[F>>2]=0;G=c[C+76>>2]|0;gA[G&16383](x,0)|0;do{if((c[E>>2]|0)!=0){G=c[F>>2]|0;c[y>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](y,0,0)|0;if((G|0)<1){D=1;i=e;return D|0}if((gzL(z,0,0)|0)==0){break}else{D=1}i=e;return D|0}}while(0);z=(c[3529222]|0)+32768|0;if((c[3542200]|0)==0){D=1;i=e;return D|0}F=v+108|0;c[F>>2]=0;E=v+100|0;c[E>>2]=0;G=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[G&16383](v,1)|0;do{if((c[F>>2]|0)!=0){G=c[E>>2]|0;c[w>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](w,1,0)|0;if((G|0)<1){D=1;i=e;return D|0}if((gzL(z,0,1)|0)==0){break}else{D=1}i=e;return D|0}}while(0);z=c[3529178]|0;if((c[3542200]|0)==0){D=1;i=e;return D|0}E=t+108|0;c[E>>2]=0;F=t+100|0;c[F>>2]=0;G=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[G&16383](t,2)|0;do{if((c[E>>2]|0)!=0){G=c[F>>2]|0;c[u>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](u,2,0)|0;if((G|0)<1){D=1;i=e;return D|0}if((gzL(z,0,2)|0)==0){break}else{D=1}i=e;return D|0}}while(0);z=c[3527348]|0;if((c[3542200]|0)==0){D=1;i=e;return D|0}F=r+108|0;c[F>>2]=0;E=r+100|0;c[E>>2]=0;G=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[G&16383](r,3)|0;do{if((c[F>>2]|0)!=0){G=c[E>>2]|0;c[s>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](s,3,0)|0;if((G|0)<1){D=1;i=e;return D|0}if((gzL(z,0,3)|0)==0){break}else{D=1}i=e;return D|0}}while(0);z=c[3530768]|0;if((c[3542200]|0)==0){D=1;i=e;return D|0}E=p+108|0;c[E>>2]=0;F=p+100|0;c[F>>2]=0;G=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[G&16383](p,4)|0;do{if((c[E>>2]|0)!=0){G=c[F>>2]|0;c[q>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](q,4,0)|0;if((G|0)<1){D=1;i=e;return D|0}if((gzL(z,0,4)|0)==0){break}else{D=1}i=e;return D|0}}while(0);z=(c[3530768]|0)+16384|0;if((c[3542200]|0)==0){D=1;i=e;return D|0}F=n+108|0;c[F>>2]=0;E=n+100|0;c[E>>2]=0;G=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[G&16383](n,5)|0;do{if((c[F>>2]|0)!=0){G=c[E>>2]|0;c[o>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](o,5,0)|0;if((G|0)<1){D=1;i=e;return D|0}if((gzL(z,0,5)|0)==0){break}else{D=1}i=e;return D|0}}while(0);z=(c[3530768]|0)+32768|0;if((c[3542200]|0)==0){D=1;i=e;return D|0}E=l+108|0;c[E>>2]=0;F=l+100|0;c[F>>2]=0;G=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[G&16383](l,6)|0;do{if((c[E>>2]|0)!=0){G=c[F>>2]|0;c[m>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](m,6,0)|0;if((G|0)<1){D=1;i=e;return D|0}if((gzL(z,0,6)|0)==0){break}else{D=1}i=e;return D|0}}while(0);z=(c[3530768]|0)+49152|0;if((c[3542200]|0)==0){D=1;i=e;return D|0}F=j+108|0;c[F>>2]=0;E=j+100|0;c[E>>2]=0;G=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[G&16383](j,7)|0;do{if((c[F>>2]|0)!=0){G=c[E>>2]|0;c[k>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](k,7,0)|0;if((G|0)<1){D=1;i=e;return D|0}if((gzL(z,0,7)|0)==0){break}else{D=1}i=e;return D|0}}while(0);do{if((c[2406624]|0)==0){H=0}else{z=c[2387316]|0;if((c[3542200]|0)==0){D=1;i=e;return D|0}E=f+108|0;c[E>>2]=0;F=f+100|0;c[F>>2]=0;G=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[G&16383](f,9)|0;if((c[E>>2]|0)==0){H=0;break}E=c[F>>2]|0;c[g>>2]=9534384;F=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[F&16383](g,9,0)|0;if((E|0)<1){D=1;i=e;return D|0}if((gzL(z,0,9)|0)==0){H=0;break}else{D=1}i=e;return D|0}}while(0);while(1){if((H|0)>=1024){break}I=9638528+(H<<2)|0;if((c[I>>2]|0)==0){B=51867;break}else{H=H+1|0}}L67846:do{if((B|0)==51867){z=gGq(65536)|0;c[I>>2]=z;if((z|0)==0){break}gGz(z|0,0,65536);E=c[3530768]|0;gGC(z|0,E|0,65536)|0;F=0;do{G=F<<6;gGz(E+G|0,0,64);C=0;do{J=1<<3-C;K=(c[613056+(C<<2)>>2]|0)+G|0;L=0;do{M=K+(c[611776+(L<<2)>>2]|0)|0;N=(L<<3)+G|0;O=0;do{P=M+(c[612224+(O<<2)>>2]|0)|0;if(((d[z+((P|0)/8|0)|0]|0)&128>>>((P&7)>>>0)|0)!=0){P=E+(N+O)|0;a[P]=(d[P]|0|J)&255}O=O+1|0;}while((O|0)<8);L=L+1|0;}while((L|0)<8);C=C+1|0;}while((C|0)<4);F=F+1|0;}while((F|0)<2048);F=c[3530532]|0;E=0;while(1){C=E<<8;gGz(F+C|0,0,256);G=0;do{L=1<<3-G;J=(c[613056+(G<<2)>>2]|0)+C|0;K=0;do{O=J+(c[611776+(K<<2)>>2]|0)|0;N=(K<<4)+C|0;M=0;do{P=O+(c[612224+(M<<2)>>2]|0)|0;if(((d[z+((P|0)/8|0)|0]|0)&128>>>((P&7)>>>0)|0)!=0){P=F+(N+M)|0;a[P]=(d[P]|0|L)&255}M=M+1|0;}while((M|0)<16);K=K+1|0;}while((K|0)<16);G=G+1|0;}while((G|0)<4);G=E+1|0;if((G|0)<512){E=G}else{Q=0;break}}while(1){if((Q|0)>=1024){break L67846}R=9638528+(Q<<2)|0;if((c[R>>2]|0)==(z|0)){break}else{Q=Q+1|0}}gGr(z);c[R>>2]=0}}while(0);fwR(0);E=c[2439330]|0;if((E|0)!=0){F=E;gGC(9706056,F|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];F=c[3528484]|0;c[2076596]=F;G=c[2417276]|0;c[3541536]=G;c[1836236]=0;C=c[3529222]|0;K=0;L=0;while(1){c[E+76+(L<<2)>>2]=C+(L<<8);J=K+1&65535;if((J&65535)>223){S=0;T=0;break}else{K=J;L=J&65535}}while(1){L=C+(T<<8)|0;c[E+76+(T+512<<2)>>2]=L;c[E+76+(T+768<<2)>>2]=L;L=S+1&65535;if((L&65535)>223){break}else{S=L;T=L&65535}}C=c[3529310]|0;c[E+972>>2]=C;L=C+256|0;c[E+976>>2]=L;K=C+512|0;c[E+980>>2]=K;J=C+768|0;c[E+984>>2]=J;M=C+1024|0;c[E+988>>2]=M;N=C+1280|0;c[E+992>>2]=N;O=C+1536|0;c[E+996>>2]=O;P=C+1792|0;c[E+1e3>>2]=P;c[E+1996>>2]=C;c[E+2e3>>2]=L;c[E+2004>>2]=K;c[E+2008>>2]=J;c[E+2012>>2]=M;c[E+2016>>2]=N;c[E+2020>>2]=O;c[E+2024>>2]=P;c[E+3020>>2]=C;c[E+4044>>2]=C;c[E+3024>>2]=L;c[E+4048>>2]=L;c[E+3028>>2]=K;c[E+4052>>2]=K;c[E+3032>>2]=J;c[E+4056>>2]=J;c[E+3036>>2]=M;c[E+4060>>2]=M;c[E+3040>>2]=N;c[E+4064>>2]=N;c[E+3044>>2]=O;c[E+4068>>2]=O;c[E+3048>>2]=P;c[E+4072>>2]=P;P=c[2387122]|0;c[E+1004>>2]=P;O=P+256|0;c[E+1008>>2]=O;N=P+512|0;c[E+1012>>2]=N;M=P+768|0;c[E+1016>>2]=M;J=P+1024|0;c[E+1020>>2]=J;K=P+1280|0;c[E+1024>>2]=K;L=P+1536|0;c[E+1028>>2]=L;C=P+1792|0;c[E+1032>>2]=C;c[E+3052>>2]=P;c[E+4076>>2]=P;c[E+3056>>2]=O;c[E+4080>>2]=O;c[E+3060>>2]=N;c[E+4084>>2]=N;c[E+3064>>2]=M;c[E+4088>>2]=M;c[E+3068>>2]=J;c[E+4092>>2]=J;c[E+3072>>2]=K;c[E+4096>>2]=K;c[E+3076>>2]=L;c[E+4100>>2]=L;c[E+3080>>2]=C;c[E+4104>>2]=C;C=c[2386396]|0;c[E+1040>>2]=C;c[E+2064>>2]=C;c[E+3088>>2]=C;c[E+4112>>2]=C;C=c[2386188]|0;c[E+1052>>2]=C;L=C+256|0;c[E+1056>>2]=L;K=C+512|0;c[E+1060>>2]=K;J=C+768|0;c[E+1064>>2]=J;M=C+1024|0;c[E+1068>>2]=M;N=C+1280|0;c[E+1072>>2]=N;O=C+1536|0;c[E+1076>>2]=O;P=C+1792|0;c[E+1080>>2]=P;U=C+2048|0;c[E+1084>>2]=U;V=C+2304|0;c[E+1088>>2]=V;W=C+2560|0;c[E+1092>>2]=W;X=C+2816|0;c[E+1096>>2]=X;c[E+2076>>2]=C;c[E+2080>>2]=L;c[E+2084>>2]=K;c[E+2088>>2]=J;c[E+2092>>2]=M;c[E+2096>>2]=N;c[E+2100>>2]=O;c[E+2104>>2]=P;c[E+2108>>2]=U;c[E+2112>>2]=V;c[E+2116>>2]=W;c[E+2120>>2]=X;X=244;W=244;while(1){V=C+((W<<8)-62464)|0;c[E+76+(W+512<<2)>>2]=V;c[E+76+(W+768<<2)>>2]=V;V=X+1&65535;if((V&65535)>255){break}else{X=V;W=V&65535}}c[E+4184>>2]=2102;c[E+4180>>2]=3034;c[E+4172>>2]=110;W=E;gGC(W|0,9706056,76)|0;c[2438118]=c[2433530];c[3528484]=F;c[2417276]=G;c[1836236]=-1;fwR(1);W=c[2439331]|0;X=(W|0)==0;if(!X){C=W;gGC(9706056,C|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];C=c[3528485]|0;c[2076596]=C;V=c[2417277]|0;c[3541536]=V;c[1836236]=1;U=c[3529178]|0;P=0;O=0;while(1){c[W+76+(O<<2)>>2]=U+(O<<8);N=P+1&65535;if((N&65535)>127){Y=0;Z=0;break}else{P=N;O=N&65535}}while(1){O=U+(Z<<8)|0;c[W+76+(Z+512<<2)>>2]=O;c[W+76+(Z+768<<2)>>2]=O;O=Y+1&65535;if((O&65535)>127){break}else{Y=O;Z=O&65535}}U=c[3529272]|0;c[W+588>>2]=U;O=U+256|0;c[W+592>>2]=O;P=U+512|0;c[W+596>>2]=P;G=U+768|0;c[W+600>>2]=G;F=U+1024|0;c[W+604>>2]=F;E=U+1280|0;c[W+608>>2]=E;N=U+1536|0;c[W+612>>2]=N;M=U+1792|0;c[W+616>>2]=M;c[W+1612>>2]=U;c[W+1616>>2]=O;c[W+1620>>2]=P;c[W+1624>>2]=G;c[W+1628>>2]=F;c[W+1632>>2]=E;c[W+1636>>2]=N;c[W+1640>>2]=M;c[W+2636>>2]=U;c[W+3660>>2]=U;c[W+2640>>2]=O;c[W+3664>>2]=O;c[W+2644>>2]=P;c[W+3668>>2]=P;c[W+2648>>2]=G;c[W+3672>>2]=G;c[W+2652>>2]=F;c[W+3676>>2]=F;c[W+2656>>2]=E;c[W+3680>>2]=E;c[W+2660>>2]=N;c[W+3684>>2]=N;c[W+2664>>2]=M;c[W+3688>>2]=M;c[W+4184>>2]=240;c[W+4180>>2]=2198;if(!X){M=W;gGC(M|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=C;c[2417277]=V;c[1836236]=-1;M=c[2387316]|0;N=c[2387328]|0;c[2424906]=2536;c[2443666]=2047;c[2385780]=7;c[3528996]=3;gGz(9702704,0,32);gGz(9703728,0,32);gGz(9704752,0,32);E=c[2427044]|0;c[9681616+(E<<3)>>2]=809328;c[9681620+(E<<3)>>2]=0;c[2427044]=E+1;E=2;while(1){F=N+((E<<3)-16)|0;c[9702704+(E<<2)>>2]=F;c[9703728+(E<<2)>>2]=F;c[9704752+(E<<2)>>2]=F;F=E+1|0;if((F|0)<16){E=F}else{_=16;break}}do{E=M+(_<<3)|0;c[9702704+(_<<2)>>2]=E;c[9704752+(_<<2)>>2]=E;_=_+1|0;}while((_|0)<256);c[3528586]=3404;c[2385590]=1124;Vr(2,4e6,2762,1258,30,0);c[2438228]=6e6;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=340;h[745419]=.4;a[3203368]=1;h[745418]=.15;a[3203360]=1;h[745417]=.15;a[3203352]=1;h[745416]=.15;a[3203344]=1;h[745415]=.4;a[3203336]=1;h[745414]=.15;a[3203328]=1;h[745413]=.15;a[3203320]=1;h[745412]=.15;a[3203312]=1;M=c[2414580]|0;gGz(M|0,0,(c[2411524]|0)-M|0);M=c[2439330]|0;E=(M|0)==0;if(!E){N=M;gGC(9706056,N|0,76)|0}N=c[2438118]|0;c[2433530]=N;V=c[3528484]|0;c[2076596]=V;C=c[2417276]|0;c[3541536]=C;c[1836236]=0;gGz(9706056,0,76);if(!E){E=M;gGC(E|0,9706056,76)|0}c[2438118]=N;c[3528484]=V;c[2417276]=C;c[1836236]=-1;C=c[2439331]|0;V=(C|0)==0;if(!V){N=C;gGC(9706056,N|0,76)|0}N=c[2438119]|0;c[2433530]=N;E=c[3528485]|0;c[2076596]=E;M=c[2417277]|0;c[3541536]=M;c[1836236]=1;gGz(9706056,0,76);if(!V){V=C;gGC(V|0,9706056,76)|0}c[2438119]=N;c[3528485]=E;c[2417277]=M;c[1836236]=-1;f42();a[8451544]=0;a[8451536]=0;a[9533800]=0;a[8451528]=0;a[8451520]=0;a[9533792]=0;a[8451512]=0;a[8451504]=0;a[9533784]=0;a[9533352]=0;a[9533344]=0;c[2161338]=0;c[2161344]=0;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){M=0;do{lN(M);mB(M);M=M+1|0;}while((M|0)<(c[2385508]|0))}a[14112864]=0;a[9762944]=0;a[9762936]=0;c[2443510]=0;c[2443746]=0;M=c[642608+(c[2436]<<2)>>2]|0;E=c[M+128>>2]|0;if((c[M+52>>2]&4|0)==0){c[2113068]=E;N=c[M+132>>2]|0;c[2113070]=N;c[2443814]=E;c[2440436]=N;$=E;aa=N}else{c[2113070]=E;N=c[M+132>>2]|0;c[2113068]=N;c[2440436]=E;c[2443814]=N;$=N;aa=E}E=ag($<<1,aa)|0;N=gGq(E)|0;c[2112926]=N;if((N|0)==0){D=0;i=e;return D|0}gGz(N|0,0,E|0);D=0;i=e;return D|0}}while(0);c[2414878]=0;D=1;i=e;return D|0}function fdC(){var b=0,d=0,e=0,f=0;c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}fwZ();a[8451544]=0;a[8451536]=0;a[9533800]=0;a[8451528]=0;a[8451520]=0;a[9533792]=0;a[8451512]=0;a[8451504]=0;a[9533784]=0;a[9533352]=0;a[9533344]=0;c[2161338]=0;c[2161344]=0;c[2424906]=0;c[2443666]=0;c[2385780]=0;c[3528996]=0;b=c[3541518]|0;if((b|0)!=0){gGr(b|0);c[3541518]=0}if((c[2385508]|0)>0){c[2113008]=0;c[2076598]=0;c[2383582]=0}c[2438228]=0;c[2433526]=0;c[2406676]=0;c[3528472]=0;b=c[2406680]|0;if((b|0)!=0){gGr(b);c[2406680]=0}c[2385508]=0;c[2432978]=0;a[64240]=0;b=c[2414878]|0;d=0;while(1){if((d|0)>=1024){e=51968;break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==(b|0)){break}else{d=d+1|0}}if((e|0)==51968){c[2414878]=0;a[673144]=0;c[3529094]=0;return 0}gGr(b);c[f>>2]=0;c[2414878]=0;a[673144]=0;c[3529094]=0;return 0}function fdD(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0;if((a[9623656]|0)!=0){d=c[2414580]|0;gGz(d|0,0,(c[2411524]|0)-d|0);d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=i;c[1836236]=-1;i=c[2439331]|0;g=(i|0)==0;if(!g){f=i;gGC(9706056,f|0,76)|0}f=c[2438119]|0;c[2433530]=f;e=c[3528485]|0;c[2076596]=e;d=c[2417277]|0;c[3541536]=d;c[1836236]=1;gGz(9706056,0,76);if(!g){g=i;gGC(g|0,9706056,76)|0}c[2438119]=f;c[3528485]=e;c[2417277]=d;c[1836236]=-1;f42();a[8451544]=0;a[8451536]=0;a[9533800]=0;a[8451528]=0;a[8451520]=0;a[9533792]=0;a[8451512]=0;a[8451504]=0;a[9533784]=0;a[9533352]=0;a[9533344]=0;c[2161338]=0;c[2161344]=0;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){d=0;do{lN(d);mB(d);d=d+1|0;}while((d|0)<(c[2385508]|0))}a[14112864]=0;a[9762944]=0;a[9762936]=0;c[2443510]=0;c[2443746]=0}d=c[2385548]|0;if((d|0)>0){gGz(9752472,0,((d|0)>1?d<<2:4)|0)}c[2433530]=0;a[9634512]=11;a[9634514]=-1;a[9634513]=-1;d=0;e=11;f=-1;g=-1;do{e=((a[9632688+d|0]&1)<<d^e&255)&255;f=((a[9630592+d|0]&1)<<d^f&255)&255;g=((a[9629264+d|0]&1)<<d^g&255)&255;d=d+1|0;}while((d|0)<8);a[9634512]=e;a[9634513]=f;a[9634514]=g;g=0;f=0;while(1){e=c[2439330]|0;if((e|0)!=0){d=e;gGC(9706056,d|0,76)|0}b[4853030]=c[2426515]&65535;d=c[2438118]|0;c[2433530]=d;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;i=f+1|0;j=((i*1e5|0|0)/100|0)-g|0;do{if((j|0)<1){k=0}else{if((a[e+4188|0]|0)==0){l=gfc(j)|0;c[2433530]=(c[2433530]|0)+l;k=l;break}else{c[2433530]=d+j;k=j;break}}}while(0);if((f|0)==99){a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0}j=c[1836236]|0;d=c[9757320+(j<<2)>>2]|0;if((d|0)!=0){e=d;gGC(e|0,9706056,76)|0}c[9752472+(j<<2)>>2]=c[2433530];c[14113936+(j<<2)>>2]=c[2076596];c[9669104+(j<<2)>>2]=c[3541536];c[1836236]=-1;j=c[2439331]|0;if((j|0)!=0){e=j;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;Sb(f*1e3|0);e=c[1836236]|0;j=c[9757320+(e<<2)>>2]|0;if((j|0)!=0){d=j;gGC(d|0,9706056,76)|0}c[9752472+(e<<2)>>2]=c[2433530];c[14113936+(e<<2)>>2]=c[2076596];c[9669104+(e<<2)>>2]=c[3541536];c[1836236]=-1;if((c[2406624]|0)!=0){f4Y(666)|0}if((i|0)<100){g=k+g|0;f=i}else{break}}f=c[2439331]|0;if((f|0)!=0){g=f;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;g=c[2438228]|0;f=gGS(-1220542464,47683,g,(g|0)<0|0?-1:0)|0;g=f;Sb(1e5);f=c[2443830]|0;if((f|0)<1073676288){c[2443830]=f-g}f=c[2443831]|0;if((f|0)<1073676288){c[2443831]=f-g}f=(c[3528512]|0)-g|0;c[3528512]=(f|0)<0?0:f;gg[c[3542122]&4095](c[2112964]|0,a[9688]|0?534:0);f=c[1836236]|0;g=c[9757320+(f<<2)>>2]|0;if((g|0)!=0){k=g;gGC(k|0,9706056,76)|0}c[9752472+(f<<2)>>2]=c[2433530];c[14113936+(f<<2)>>2]=c[2076596];c[9669104+(f<<2)>>2]=c[3541536];c[1836236]=-1;if((c[2112968]|0)==0){return 0}fdE()|0;return 0}function fdE(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0;if((a[9547144]|0)!=0){b=c[2406910]|0;e=c[3529912]|0;f=0;do{g=c[b+(f<<2)>>2]|0;c[e+(f<<2)>>2]=g>>8<<3&2016|g>>>3&31|g>>16<<8&63488;f=f+1|0;}while((f|0)<1024);a[9547144]=0}f=c[2386180]|0;e=f+2|0;a[9762944]=a[e]&1^1;a[9762936]=a[e]&2^2;b=f+1|0;g=d[b]|0;h=g&240;i=d[f]|0;if((a[e]&15)!=3){e=c[2440602]|0;fdU(0,0,272,0,(d[e]|0)+1|0,d[e+1|0]|0);j=c[3529912]|0;R8(j);return 0}e=c[2440602]|0;fdU(2048,g>>>1&4|1,h|768,0,(d[e+4|0]|0)+5|0,d[e+5|0]|0);fdV(1);if((a[b]&2)==0){fdV(0)}fdU(1024,i>>>2&1,h|512,1,(d[e+2|0]|0)+3|0,d[e+3|0]|0);if((a[b]&2)!=0){fdV(0)}fdU(0,i<<1&4,272,1,(d[e]|0)+1|0,d[e+1|0]|0);j=c[3529912]|0;R8(j);return 0}function fdF(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;i=i+96|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;l=e+80|0;if((d|0)!=0){c[d>>2]=169623}if((b&96|0)==0){i=e;return 0}m=c[2414580]|0;c[l>>2]=m;c[l+4>>2]=(c[2411524]|0)-m;c[l+12>>2]=196728;gj[c[2076592]&4095](l)|0;fw$(b);Vx(b,d);gGz(k|0,0,12);c[k>>2]=14112864;c[k+4>>2]=1;c[k+12>>2]=191240;gj[c[2076592]&4095](k)|0;gGz(j|0,0,12);c[j>>2]=9762944;c[j+4>>2]=1;c[j+12>>2]=185128;gj[c[2076592]&4095](j)|0;gGz(h|0,0,12);c[h>>2]=9762936;c[h+4>>2]=1;c[h+12>>2]=180440;gj[c[2076592]&4095](h)|0;gGz(g|0,0,12);c[g>>2]=9774040;c[g+4>>2]=4;c[g+12>>2]=176152;gj[c[2076592]&4095](g)|0;gGz(f|0,0,12);c[f>>2]=9774984;c[f+4>>2]=4;c[f+12>>2]=172376;gj[c[2076592]&4095](f)|0;a[9547144]=1;i=e;return 0}function fdG(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5795612+(b*112|0)>>2];c[a+104>>2]=c[5795616+(b*112|0)>>2];c[a+108>>2]=c[5795620+(b*112|0)>>2];d=0;return d|0}function fdH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=5795512+(b*112|0);e=0;return e|0}function fdI(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4573484+(b*112|0)>>2];c[a+104>>2]=c[4573488+(b*112|0)>>2];c[a+108>>2]=c[4573492+(b*112|0)>>2];d=0;return d|0}function fdJ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=4573384+(b*112|0);e=0;return e|0}function fdK(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5797180+(b*112|0)>>2];c[a+104>>2]=c[5797184+(b*112|0)>>2];c[a+108>>2]=c[5797188+(b*112|0)>>2];d=0;return d|0}function fdL(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=5797080+(b*112|0);e=0;return e|0}function fdM(){a[673144]=1;return fdB()|0}function fdN(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4576060+(b*112|0)>>2];c[a+104>>2]=c[4576064+(b*112|0)>>2];c[a+108>>2]=c[4576068+(b*112|0)>>2];d=0;return d|0}function fdO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=4575960+(b*112|0);e=0;return e|0}function fdP(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4575052+(b*112|0)>>2];c[a+104>>2]=c[4575056+(b*112|0)>>2];c[a+108>>2]=c[4575060+(b*112|0)>>2];d=0;return d|0}function fdQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=4574952+(b*112|0);e=0;return e|0}function fdR(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5938404+(b*112|0)>>2];c[a+104>>2]=c[5938408+(b*112|0)>>2];c[a+108>>2]=c[5938412+(b*112|0)>>2];d=0;return d|0}function fdS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=5938304+(b*112|0);e=0;return e|0}function fdT(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>53){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6407480+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fdU(b,e,f,g,h,i){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;j=f>>4;f=a[9762944]|0;k=f<<24>>24==0?h:-h|0;h=a[9762936]|0;l=h<<24>>24==0?i:-i|0;i=c[2386188]|0;m=e<<8;e=f<<24>>24!=0?-24:-16;n=c[2112926]|0;o=c[3530768]|0;if((g|0)==0){g=0;p=f;q=h;while(1){r=d[i+(g+b)|0]|0|m;s=g<<3&248;t=g>>5<<3;u=q<<24>>24==0;v=(u?t:t^248)-l|0;t=(p<<24>>24==0?s:s^248)-k+e|0;s=v-16|0;w=(t|0)<-7?t+256|0:t;t=(s|0)<-15?v+240|0:s;s=(w|0)>239?w-256|0:w;w=(t|0)>223?t-256|0:t;t=p<<24>>24!=0;do{if(u){if(t){Sl(n,r,s,w,j,4,0,o);break}else{Sj(n,r,s,w,j,4,0,o);break}}else{if(t){Sp(n,r,s,w,j,4,0,o);break}else{Sn(n,r,s,w,j,4,0,o);break}}}while(0);w=g+1|0;if((w|0)>=1024){break}g=w;p=a[9762944]|0;q=a[9762936]|0}return}else{q=0;p=f;f=h;while(1){h=d[i+(q+b)|0]|0|m;g=q<<3&248;w=q>>5<<3;s=f<<24>>24==0;r=(s?w:w^248)-l|0;w=(p<<24>>24==0?g:g^248)-k+e|0;g=r-16|0;t=(w|0)<-7?w+256|0:w;w=(g|0)<-15?r+240|0:g;g=(t|0)>239?t-256|0:t;t=(w|0)>223?w-256|0:w;w=p<<24>>24!=0;do{if(s){if(w){St(n,h,g,t,j,4,0,0,o);break}else{Sr(n,h,g,t,j,4,0,0,o);break}}else{if(w){Sx(n,h,g,t,j,4,0,0,o);break}else{Sv(n,h,g,t,j,4,0,0,o);break}}}while(0);t=q+1|0;if((t|0)>=1024){break}q=t;p=a[9762944]|0;f=a[9762936]|0}return}}function fdV(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;e=c[2386396]|0;f=(fa(481784,c[c[642608+(c[2436]<<2)>>2]>>2]|0)|0)==0;g=f?-14:-15;f=c[2112926]|0;h=c[3530532]|0;i=e+92|0;do{j=d[i+2|0]|0;if((j>>>7|0)==(b|0)){k=j>>>4&7;l=j&1;m=j&2;n=j&8;o=(n>>>3)+1|0;p=(d[i]|0)+g|0;q=o<<4;r=256-q-(d[i+1|0]|0)|0;if((a[9762944]|0)==0){s=p;t=l}else{s=231-p|0;t=l^1}if((a[9762936]|0)==0){u=r;v=m}else{u=254-q-r|0;v=m>>>1^1}m=(v|0)==0;r=(n|0)!=0&m&1^(d[i+3|0]|j<<6&256);j=s-16|0;n=u-16|0;q=(j|0)<-15?s+240|0:j;j=(t|0)!=0;l=0;do{p=r^l;w=n+(l<<4)|0;do{if(m){if(j){SJ(f,p,q,w,k,4,0,0,h);break}else{SH(f,p,q,w,k,4,0,0,h);break}}else{if(j){SN(f,p,q,w,k,4,0,0,h);break}else{SL(f,p,q,w,k,4,0,0,h);break}}}while(0);l=l+1|0;}while((l|0)<(o|0))}i=i-4|0;}while(i>>>0>=e>>>0);return}function fdW(b,c){b=b|0;c=c|0;a[9706117]=c&1;return}function fdX(a){a=a|0;var b=0,d=0;b=(c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,6e6,0)|0;return a|0}function fdY(){return+(+((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)/6.0e6)}function fdZ(){var b=0,d=0;b=a[9540897]|0;switch(b&255|0){case 1:{a[9540898]=a[9540898]&-2;a[9540897]=b+1&255;d=a[9540889]|0;break};case 4:{d=a[9540898]|0;break};case 0:{a[9540897]=b+1&255;d=a[9540888]|0;break};case 3:{a[9540898]=a[9540898]&-3;a[9540897]=b+1&255;d=a[9540891]|0;break};case 2:{a[9540897]=b+1&255;d=a[9540890]|0;break};default:{d=0}}if(!((a[9540900]|0)!=0&(a[9540899]|0)!=0)){return d|0}if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12;a[9540900]=0;return d|0}function fd_(b){b=b|0;var d=0;d=b&15;b=a[9540897]|0;switch(b&255|0){case 1:{a[9540897]=b+1&255;a[9540893]=d;a[9540898]=a[9540898]|4;break};case 3:{a[9540897]=b+1&255;a[9540895]=d;a[9540898]=a[9540898]|8;break};case 5:{a[9540899]=0;break};case 2:{a[9540897]=b+1&255;a[9540894]=d;break};case 0:{a[9540897]=b+1&255;a[9540892]=d;break};case 6:{a[9540899]=1;break};default:{}}if(!((a[9540900]|0)!=0&(a[9540899]|0)!=0)){return}if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12;a[9540900]=0;return}function fd$(b){b=b|0;var c=0,d=0;c=b-3145728|0;L68228:do{if(c>>>0<16){switch(c>>>1&255|0){case 1:{d=a[14129049]|0;break L68228;break};case 7:{d=a[14129042]|0;break L68228;break};case 4:{d=a[9757556]|0;break L68228;break};case 3:{d=a[14129041]|0;break L68228;break};case 2:{d=a[14129040]|0;break L68228;break};case 0:{d=a[14129048]|0;break L68228;break};default:{d=0;break L68228}}}else{d=0}}while(0);return d|0}function fd0(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=b-3145728|0;if(e>>>0<16){f=e>>>1;e=f&255;a[9757552+(f&255)|0]=d;if((e<<24>>24|0)==0){c[3531956]=0;return}else if((e<<24>>24|0)==4){e=~d;a[14128520]=e&1;a[14128521]=e&2;return}else{return}}e=b-8388608|0;if(e>>>0<81920){f=e^1;g=(c[3532278]|0)+f|0;do{if((a[g]|0)!=d<<24>>24){h=(e|0)>-1;if((c[3532284]|0)==0){if(h&(f|0)<16384){a[14129208]=1}if(h&(f|0)<32768){a[14129128]=1}if((f-24576|0)>>>0>=4096){break}a[14129200]=1;break}else{if(h&(f|0)<32768){a[14129208]=1}if((f-32768|0)>>>0<32768){a[14129128]=1}if((f-69632|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);a[g]=d;return}if((b|0)==3276800){a[9540896]=d&15;return}else if((b|0)==3276802){b=d&15;d=a[9540896]|0;switch(d&255|0){case 0:{a[9540896]=d+1&255;a[9540888]=b;return};case 1:{a[9540896]=d+1&255;a[9540889]=b;a[9540898]=a[9540898]|1;a[9540900]=1;return};case 3:{a[9540896]=d+1&255;a[9540891]=b;a[9540898]=a[9540898]|2;a[9540900]=1;return};case 4:{if(b<<24>>24==0){return}g=c[2439330]|0;f=(g|0)==0;if(!f){e=g;gGC(9706056,e|0,76)|0}e=c[2438118]|0;c[2433530]=e;h=c[3528484]|0;c[2076596]=h;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);if(!f){f=g;gGC(f|0,9706056,76)|0}c[2438118]=e;c[3528484]=h;c[2417276]=i;c[1836236]=-1;return};case 2:{a[9540896]=d+1&255;a[9540890]=b;return};default:{return}}}else{return}}function fd1(b){b=b|0;var d=0,e=0,f=0,g=0,h=0;d=b-3145728|0;if(d>>>0>=16){if((b|0)==3145756){e=c[3532184]>>6;f=(e-20|0)>>>0<108?20:e;g=(f-129|0)>>>0<876?1004:f&65535;return g|0}else if((b|0)==3145752){b=c[3532186]>>6;f=(b-20|0)>>>0<108?20:b;g=(f-129|0)>>>0<876?1004:f&65535;return g|0}else{g=0;return g|0}}switch(d>>>1&255|0){case 4:{h=a[9757556]|0;break};case 1:{h=a[14129049]|0;break};case 3:{h=a[14129041]|0;break};case 0:{h=a[14129048]|0;break};case 7:{h=a[14129042]|0;break};case 2:{h=a[14129040]|0;break};default:{h=0}}g=h&255;return g|0}function fd2(d,e){d=d|0;e=e|0;var f=0,g=0,h=0;f=d-3145728|0;if(f>>>0<16){g=f>>>1;f=g&255;h=e&255;a[9757552+(g&255)|0]=h;if((f<<24>>24|0)==0){c[3531956]=0;return}else if((f<<24>>24|0)==4){f=~h;a[14128520]=f&1;a[14128521]=f&2;return}else{return}}f=d-8388608|0;if(f>>>0<81920){h=(c[3532278]|0)+(f>>>1<<1)|0;do{if((b[h>>1]|0)!=e<<16>>16){if((c[3532284]|0)==0){if(f>>>0<16384){a[14129208]=1}if((d-8421376|0)>>>0<16384){a[14129128]=1}if((d-8413184|0)>>>0>=4096){break}a[14129200]=1;break}else{if(f>>>0<32768){a[14129208]=1}if((d-8421376|0)>>>0<32768){a[14129128]=1}if((d-8458240|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);b[h>>1]=e;return}h=d-8519680|0;if(h>>>0>=16){f=d-10493952|0;if(f>>>0<16){b[9757536+(f>>>1<<1)>>1]=e;return}f=d-13631488|0;if(f>>>0>=32){return}a[14128984+(f>>>1)|0]=e&255;return}f=h>>>1;b[14129152+(f<<1)>>1]=e;switch(f|0){case 6:{c[3532284]=(e&65535)>>>4&1;return};case 7:{c[2439396]=e&1;return};case 4:{c[2385820]=-(e&65535);return};case 5:{c[3527494]=-(e&65535);return};case 3:{c[2388334]=-(e&65535);return};case 0:{c[2388344]=-(e&65535);return};case 2:{c[3527502]=-(e&65535);return};case 1:{c[2385826]=-(e&65535);return};default:{return}}}function fd3(b){b=b|0;var c=0,d=0;L68381:do{if((b|0)==7340037){c=a[14128322]|0}else if((b|0)==7340035){c=a[14128481]|0}else if((b|0)==7340039|(b|0)==7340047|(b|0)==7340049){c=-1}else if((b|0)==10485762){d=a[9540896]|0;switch(d&255|0){case 4:{c=a[9540898]|0;break L68381;break};case 3:{a[9540898]=a[9540898]&-9;a[9540896]=d+1&255;c=a[9540895]|0;break L68381;break};case 0:{a[9540896]=d+1&255;c=a[9540892]|0;break L68381;break};case 2:{a[9540896]=d+1&255;c=a[9540894]|0;break L68381;break};case 1:{a[9540898]=a[9540898]&-5;a[9540896]=d+1&255;c=a[9540893]|0;break L68381;break};default:{c=0;break L68381}}}else if((b|0)==7340043){c=a[14128320]|0}else if((b|0)==7340045){c=a[14128321]|0}else if((b|0)==7340033){c=a[14128480]|0}else{c=0}}while(0);return c|0}function fd4(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;if((b|0)==10485760){a[9540896]=d&15;return}else if((b|0)==10485762){b=d&15;d=a[9540896]|0;switch(d&255|0){case 0:{a[9540896]=d+1&255;a[9540888]=b;return};case 2:{a[9540896]=d+1&255;a[9540890]=b;return};case 3:{a[9540896]=d+1&255;a[9540891]=b;a[9540898]=a[9540898]|2;a[9540900]=1;return};case 1:{a[9540896]=d+1&255;a[9540889]=b;a[9540898]=a[9540898]|1;a[9540900]=1;return};case 4:{if(b<<24>>24==0){return}b=c[2439330]|0;d=(b|0)==0;if(!d){e=b;gGC(9706056,e|0,76)|0}e=c[2438118]|0;c[2433530]=e;f=c[3528484]|0;c[2076596]=f;g=c[2417276]|0;c[3541536]=g;c[1836236]=0;gGz(9706056,0,76);if(!d){d=b;gGC(d|0,9706056,76)|0}c[2438118]=e;c[3528484]=f;c[2417276]=g;c[1836236]=-1;return};default:{return}}}else{return}}function fd5(a){a=a|0;return 0}function fd6(c,d){c=c|0;d=d|0;var e=0,f=0;e=c-4390912|0;if(e>>>0<48){eXO(e>>>1,d);return}e=c-5242880|0;if(e>>>0<32){a[14128984+(e>>>1)|0]=d&255;return}switch(c|0){case 3145728:case 3145730:case 3145732:case 3145734:case 3145736:case 3145738:case 3145740:case 3145742:{break};default:{return}}e=c-3145728|0;c=e>>>1;if(e>>>0<4){return}if(e>>>0<8){e=c<<1&2;f=(d&65535)<<11;b[14128416+(e<<1)>>1]=f&65535;b[14128416+((e|1)<<1)>>1]=(f|1024)&65535;return}else{b[14128416+(c<<1)>>1]=d<<10;return}}function fd7(b){b=b|0;var c=0,d=0,e=0;c=b-3145728|0;L68445:do{if(c>>>0<16){switch(c>>>1|0){case 7:{d=a[14128914]|0;break L68445;break};case 0:{d=a[14128920]|0;break L68445;break};case 2:{d=a[14128912]|0;break L68445;break};case 4:{d=a[9757532]|0;break L68445;break};case 1:{d=a[14128921]|0;break L68445;break};case 3:{d=a[14128913]|0;break L68445;break};default:{d=-1;break L68445}}}else{if((b|0)!=10485762){d=0;break}e=a[9540896]|0;switch(e&255|0){case 4:{d=a[9540898]|0;break L68445;break};case 3:{a[9540898]=a[9540898]&-9;a[9540896]=e+1&255;d=a[9540895]|0;break L68445;break};case 2:{a[9540896]=e+1&255;d=a[9540894]|0;break L68445;break};case 0:{a[9540896]=e+1&255;d=a[9540892]|0;break L68445;break};case 1:{a[9540898]=a[9540898]&-5;a[9540896]=e+1&255;d=a[9540893]|0;break L68445;break};default:{d=0;break L68445}}}}while(0);return d|0}function fd8(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=b-3145728|0;if(e>>>0<16){f=e>>>1;a[9757528+f|0]=d;if((f|0)==0){c[3531956]=0;return}else if((f|0)==4){f=~d;a[14128520]=f&1;a[14128521]=f&2;return}else{return}}f=b-9437184|0;if(f>>>0<65536){e=f^1;g=(c[3532278]|0)+e|0;do{if((a[g]|0)!=d<<24>>24){h=(f|0)>-1;if((c[3532284]|0)==0){if(h&(e|0)<16384){a[14129208]=1}if(h&(e|0)<32768){a[14129128]=1}if((e-24576|0)>>>0>=4096){break}a[14129200]=1;break}else{if(h&(e|0)<32768){a[14129208]=1}if((e-32768|0)>>>0<32768){a[14129128]=1}if((e-69632|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);a[g]=d;return}if((b|0)==10485760){a[9540896]=d&15;return}else if((b|0)==10485762){b=d&15;d=a[9540896]|0;switch(d&255|0){case 4:{if(b<<24>>24==0){return}g=c[2439330]|0;e=(g|0)==0;if(!e){f=g;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;h=c[3528484]|0;c[2076596]=h;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);if(!e){e=g;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=h;c[2417276]=i;c[1836236]=-1;return};case 3:{a[9540896]=d+1&255;a[9540891]=b;a[9540898]=a[9540898]|2;a[9540900]=1;return};case 0:{a[9540896]=d+1&255;a[9540888]=b;return};case 1:{a[9540896]=d+1&255;a[9540889]=b;a[9540898]=a[9540898]|1;a[9540900]=1;return};case 2:{a[9540896]=d+1&255;a[9540890]=b;return};default:{return}}}else{return}}function fd9(a){a=a|0;return 0}function fea(d,e){d=d|0;e=e|0;var f=0,g=0;f=d-3145728|0;if(f>>>0<16){g=f>>>1;f=e&255;a[9757528+g|0]=f;if((g|0)==0){c[3531956]=0;return}else if((g|0)==4){g=~f;a[14128520]=g&1;a[14128521]=g&2;return}else{return}}g=d-7340032|0;if(g>>>0<32){a[14128984+(g>>>1)|0]=e&255;return}g=d-9437184|0;if(g>>>0<65536){f=(c[3532278]|0)+(g>>>1<<1)|0;do{if((b[f>>1]|0)!=e<<16>>16){if((c[3532284]|0)==0){if(g>>>0<16384){a[14129208]=1}if((d-9469952|0)>>>0<16384){a[14129128]=1}if((d-9461760|0)>>>0>=4096){break}a[14129200]=1;break}else{if(g>>>0<32768){a[14129208]=1}if((d-9469952|0)>>>0<32768){a[14129128]=1}if((d-9506816|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);b[f>>1]=e;return}f=d-9568256|0;if(f>>>0>=16){return}d=f>>>1;b[14129152+(d<<1)>>1]=e;switch(d|0){case 7:{c[2439396]=e&1;return};case 2:{c[3527502]=-(e&65535);return};case 3:{c[2388334]=-(e&65535);return};case 6:{c[3532284]=(e&65535)>>>4&1;return};case 1:{c[2385826]=-(e&65535);return};case 0:{c[2388344]=-(e&65535);return};case 5:{c[3527494]=-(e&65535);return};case 4:{c[2385820]=-(e&65535);return};default:{return}}}function feb(b){b=b|0;var c=0,d=0,e=0;c=b-3145728|0;L68584:do{if(c>>>0<16){switch(c>>>1&255|0){case 0:{d=a[14129048]|0;break L68584;break};case 1:{d=a[14129049]|0;break L68584;break};case 2:{d=a[14129040]|0;break L68584;break};case 3:{d=a[14129041]|0;break L68584;break};case 7:{d=a[14129042]|0;break L68584;break};case 4:{d=a[9757556]|0;break L68584;break};default:{d=0;break L68584}}}else{if((b|0)!=3276802){d=0;break}e=a[9540896]|0;switch(e&255|0){case 4:{d=a[9540898]|0;break L68584;break};case 1:{a[9540898]=a[9540898]&-5;a[9540896]=e+1&255;d=a[9540893]|0;break L68584;break};case 3:{a[9540898]=a[9540898]&-9;a[9540896]=e+1&255;d=a[9540895]|0;break L68584;break};case 2:{a[9540896]=e+1&255;d=a[9540894]|0;break L68584;break};case 0:{a[9540896]=e+1&255;d=a[9540892]|0;break L68584;break};default:{d=0;break L68584}}}}while(0);return d|0}function fec(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=b-3145728|0;if(e>>>0<16){f=e>>>1;e=f&255;a[9757552+(f&255)|0]=d;if((e<<24>>24|0)==0){c[3531956]=0;return}else if((e<<24>>24|0)==4){e=~d;a[14128520]=e&1;a[14128521]=e&2;return}else{return}}e=b-8388608|0;if(e>>>0<65536){f=e^1;g=(c[3532278]|0)+f|0;do{if((a[g]|0)!=d<<24>>24){h=(e|0)>-1;if((c[3532284]|0)==0){if(h&(f|0)<16384){a[14129208]=1}if(h&(f|0)<32768){a[14129128]=1}if((f-24576|0)>>>0>=4096){break}a[14129200]=1;break}else{if(h&(f|0)<32768){a[14129208]=1}if((f-32768|0)>>>0<32768){a[14129128]=1}if((f-69632|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);a[g]=d;return}if((b|0)==3276800|(b|0)==3276801){a[9540896]=d&15;return}else if((b|0)==3276802|(b|0)==3276803){b=d&15;d=a[9540896]|0;switch(d&255|0){case 2:{a[9540896]=d+1&255;a[9540890]=b;return};case 4:{if(b<<24>>24==0){return}g=c[2439330]|0;f=(g|0)==0;if(!f){e=g;gGC(9706056,e|0,76)|0}e=c[2438118]|0;c[2433530]=e;h=c[3528484]|0;c[2076596]=h;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);if(!f){f=g;gGC(f|0,9706056,76)|0}c[2438118]=e;c[3528484]=h;c[2417276]=i;c[1836236]=-1;return};case 0:{a[9540896]=d+1&255;a[9540888]=b;return};case 3:{a[9540896]=d+1&255;a[9540891]=b;a[9540898]=a[9540898]|2;a[9540900]=1;return};case 1:{a[9540896]=d+1&255;a[9540889]=b;a[9540898]=a[9540898]|1;a[9540900]=1;return};default:{return}}}else{return}}function fed(b){b=b|0;var c=0,d=0,e=0;c=b-3145728|0;if(c>>>0>=16){d=0;return d|0}switch(c>>>1&255|0){case 1:{e=a[14129049]|0;break};case 2:{e=a[14129040]|0;break};case 3:{e=a[14129041]|0;break};case 4:{e=a[9757556]|0;break};case 0:{e=a[14129048]|0;break};case 7:{e=a[14129042]|0;break};default:{e=0}}d=e&255;return d|0}function fee(d,e){d=d|0;e=e|0;var f=0,g=0,h=0;f=d-3145728|0;if(f>>>0<16){g=f>>>1;f=g&255;h=e&255;a[9757552+(g&255)|0]=h;if((f<<24>>24|0)==4){g=~h;a[14128520]=g&1;a[14128521]=g&2;return}else if((f<<24>>24|0)==0){c[3531956]=0;return}else{return}}f=d-8388608|0;if(f>>>0<65536){g=(c[3532278]|0)+(f>>>1<<1)|0;do{if((b[g>>1]|0)!=e<<16>>16){if((c[3532284]|0)==0){if(f>>>0<16384){a[14129208]=1}if((d-8421376|0)>>>0<16384){a[14129128]=1}if((d-8413184|0)>>>0>=4096){break}a[14129200]=1;break}else{if(f>>>0<32768){a[14129208]=1}if((d-8421376|0)>>>0<32768){a[14129128]=1}if((d-8458240|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);b[g>>1]=e;return}g=d-8519680|0;if(g>>>0>=16){f=d-10493952|0;if(f>>>0<16){b[9757536+(f>>>1<<1)>>1]=e;return}f=d-11534336|0;if(f>>>0>=32){return}a[14128984+(f>>>1)|0]=e&255;return}f=g>>>1;b[14129152+(f<<1)>>1]=e;switch(f|0){case 2:{c[3527502]=-(e&65535);return};case 7:{c[2439396]=e&1;return};case 1:{c[2385826]=-(e&65535);return};case 0:{c[2388344]=-(e&65535);return};case 3:{c[2388334]=-(e&65535);return};case 4:{c[2385820]=-(e&65535);return};case 6:{c[3532284]=(e&65535)>>>4&1;return};case 5:{c[3527494]=-(e&65535);return};default:{return}}}function fef(b){b=b|0;var c=0,d=0;c=b-11534336|0;L68739:do{if(c>>>0<16){switch(c>>>1|0){case 0:{d=a[14128920]|0;break L68739;break};case 2:{d=a[14128912]|0;break L68739;break};case 4:{d=a[9757532]|0;break L68739;break};case 7:{d=a[14128914]|0;break L68739;break};case 1:{d=a[14128921]|0;break L68739;break};case 3:{d=a[14128913]|0;break L68739;break};default:{d=-1;break L68739}}}else{d=0}}while(0);return d|0}function feg(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=b-8388608|0;if(e>>>0<65536){f=e^1;g=(c[3532278]|0)+f|0;do{if((a[g]|0)!=d<<24>>24){h=(e|0)>-1;if((c[3532284]|0)==0){if(h&(f|0)<16384){a[14129208]=1}if(h&(f|0)<32768){a[14129128]=1}if((f-24576|0)>>>0>=4096){break}a[14129200]=1;break}else{if(h&(f|0)<32768){a[14129208]=1}if((f-32768|0)>>>0<32768){a[14129128]=1}if((f-69632|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);a[g]=d;return}g=b-11534336|0;if(g>>>0<16){f=g>>>1;a[9757528+f|0]=d;if((f|0)==0){c[3531956]=0;return}else if((f|0)==4){f=~d;a[14128520]=f&1;a[14128521]=f&2;return}else{return}}if((b|0)==2097154){f=d&15;g=a[9540896]|0;switch(g&255|0){case 4:{if(f<<24>>24==0){return}e=c[2439330]|0;h=(e|0)==0;if(!h){i=e;gGC(9706056,i|0,76)|0}i=c[2438118]|0;c[2433530]=i;j=c[3528484]|0;c[2076596]=j;k=c[2417276]|0;c[3541536]=k;c[1836236]=0;gGz(9706056,0,76);if(!h){h=e;gGC(h|0,9706056,76)|0}c[2438118]=i;c[3528484]=j;c[2417276]=k;c[1836236]=-1;return};case 3:{a[9540896]=g+1&255;a[9540891]=f;a[9540898]=a[9540898]|2;a[9540900]=1;return};case 0:{a[9540896]=g+1&255;a[9540888]=f;return};case 1:{a[9540896]=g+1&255;a[9540889]=f;a[9540898]=a[9540898]|1;a[9540900]=1;return};case 2:{a[9540896]=g+1&255;a[9540890]=f;return};default:{return}}}else if((b|0)==2097152){a[9540896]=d&15;return}else{return}}function feh(b){b=b|0;var c=0,d=0,e=0;c=b-11534336|0;if(c>>>0>=16){if(!((b|0)==11534362|(b|0)==11534360)){d=0;return d|0}d=255;return d|0}switch(c>>>1|0){case 1:{e=a[14128921]|0;break};case 7:{e=a[14128914]|0;break};case 0:{e=a[14128920]|0;break};case 4:{e=a[9757532]|0;break};case 3:{e=a[14128913]|0;break};case 2:{e=a[14128912]|0;break};default:{e=-1}}d=e&255;return d|0}function fei(d,e){d=d|0;e=e|0;var f=0,g=0,h=0;f=d-4202496|0;if(f>>>0<16){b[9757536+(f>>>1<<1)>>1]=e;return}f=d-8388608|0;if(f>>>0<65536){g=(c[3532278]|0)+(f>>>1<<1)|0;do{if((b[g>>1]|0)!=e<<16>>16){if((c[3532284]|0)==0){if(f>>>0<16384){a[14129208]=1}if((d-8421376|0)>>>0<16384){a[14129128]=1}if((d-8413184|0)>>>0>=4096){break}a[14129200]=1;break}else{if(f>>>0<32768){a[14129208]=1}if((d-8421376|0)>>>0<32768){a[14129128]=1}if((d-8458240|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);b[g>>1]=e;return}g=d-8519680|0;if(g>>>0>=16){f=d-10485760|0;if(f>>>0<32){if((e&65535)<256){return}a[14128984+(f>>>1)|0]=(e&65535)>>>8&255;return}f=d-11534336|0;if(f>>>0>=16){return}d=f>>>1;f=e&255;a[9757528+d|0]=f;if((d|0)==4){h=~f;a[14128520]=h&1;a[14128521]=h&2;return}else if((d|0)==0){c[3531956]=0;return}else{return}}d=g>>>1;b[14129152+(d<<1)>>1]=e;switch(d|0){case 3:{c[2388334]=-(e&65535);return};case 1:{c[2385826]=-(e&65535);return};case 5:{c[3527494]=-(e&65535);return};case 0:{c[2388344]=-(e&65535);return};case 7:{c[2439396]=e&1;return};case 4:{c[2385820]=-(e&65535);return};case 2:{c[3527502]=-(e&65535);return};case 6:{c[3532284]=(e&65535)>>>4&1;return};default:{return}}}function fej(d,e){d=d|0;e=e|0;var f=0,g=0,h=0;f=d-11534336|0;if(f>>>0<16){g=f>>>1;a[9757528+g|0]=e;if((g|0)==0){c[3531956]=0;return}else if((g|0)==4){g=~e;a[14128520]=g&1;a[14128521]=g&2;return}else{return}}if((d|0)==2097154){if((c[2429772]|0)==0){a[14128024]=a[14128024]&-16|e&15;return}a[14128024]=a[14128024]&15|e<<4;g=c[2439330]|0;if((g|0)!=0){f=g;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0;f=c[1836236]|0;g=c[9757320+(f<<2)>>2]|0;if((g|0)!=0){h=g;gGC(h|0,9706056,76)|0}c[9752472+(f<<2)>>2]=c[2433530];c[14113936+(f<<2)>>2]=c[2076596];c[9669104+(f<<2)>>2]=c[3541536];c[1836236]=-1;return}else if((d|0)==2097152){c[2429772]=e&1;return}else{return}}function fek(b){b=b|0;var c=0,d=0;c=b-3145728|0;L68919:do{if(c>>>0<16){switch(c>>>1&255|0){case 4:{d=a[9757556]|0;break L68919;break};case 1:{d=a[14129049]|0;break L68919;break};case 3:{d=a[14129041]|0;break L68919;break};case 0:{d=a[14129048]|0;break L68919;break};case 2:{d=a[14129040]|0;break L68919;break};case 7:{d=a[14129042]|0;break L68919;break};default:{d=0;break L68919}}}else{d=0}}while(0);return d|0}function fel(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=b-3145728|0;if(e>>>0<16){f=e>>>1;e=f&255;a[9757552+(f&255)|0]=d;if((e<<24>>24|0)==4){f=~d;a[14128520]=f&1;a[14128521]=f&2;return}else if((e<<24>>24|0)==0){c[3531956]=0;return}else{return}}e=b-8388608|0;if(e>>>0<65536){f=e^1;g=(c[3532278]|0)+f|0;do{if((a[g]|0)!=d<<24>>24){h=(e|0)>-1;if((c[3532284]|0)==0){if(h&(f|0)<16384){a[14129208]=1}if(h&(f|0)<32768){a[14129128]=1}if((f-24576|0)>>>0>=4096){break}a[14129200]=1;break}else{if(h&(f|0)<32768){a[14129208]=1}if((f-32768|0)>>>0<32768){a[14129128]=1}if((f-69632|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);a[g]=d;return}if((b|0)==3276803){g=d&15;f=a[9540896]|0;switch(f&255|0){case 3:{a[9540896]=f+1&255;a[9540891]=g;a[9540898]=a[9540898]|2;a[9540900]=1;return};case 0:{a[9540896]=f+1&255;a[9540888]=g;return};case 4:{if(g<<24>>24==0){return}e=c[2439330]|0;h=(e|0)==0;if(!h){i=e;gGC(9706056,i|0,76)|0}i=c[2438118]|0;c[2433530]=i;j=c[3528484]|0;c[2076596]=j;k=c[2417276]|0;c[3541536]=k;c[1836236]=0;gGz(9706056,0,76);if(!h){h=e;gGC(h|0,9706056,76)|0}c[2438118]=i;c[3528484]=j;c[2417276]=k;c[1836236]=-1;return};case 1:{a[9540896]=f+1&255;a[9540889]=g;a[9540898]=a[9540898]|1;a[9540900]=1;return};case 2:{a[9540896]=f+1&255;a[9540890]=g;return};default:{return}}}else if((b|0)==3276801){a[9540896]=d&15;return}else{return}}function fem(d){d=d|0;var e=0,f=0,g=0;e=d-3145728|0;if(e>>>0>=16){if((d|0)!=2097154){f=0;return f|0}f=b[(c[2442928]|0)+(c[2439392]<<1)>>1]|0;return f|0}switch(e>>>1&255|0){case 1:{g=a[14129049]|0;break};case 0:{g=a[14129048]|0;break};case 4:{g=a[9757556]|0;break};case 2:{g=a[14129040]|0;break};case 7:{g=a[14129042]|0;break};case 3:{g=a[14129041]|0;break};default:{g=0}}f=g&255;return f|0}function fen(d,e){d=d|0;e=e|0;var f=0,g=0,h=0;f=d-3145728|0;if(f>>>0<16){g=f>>>1;f=g&255;h=e&255;a[9757552+(g&255)|0]=h;if((f<<24>>24|0)==4){g=~h;a[14128520]=g&1;a[14128521]=g&2;return}else if((f<<24>>24|0)==0){c[3531956]=0;return}else{return}}f=d-8388608|0;if(f>>>0<65536){g=(c[3532278]|0)+(f>>>1<<1)|0;do{if((b[g>>1]|0)!=e<<16>>16){if((c[3532284]|0)==0){if(f>>>0<16384){a[14129208]=1}if((d-8421376|0)>>>0<16384){a[14129128]=1}if((d-8413184|0)>>>0>=4096){break}a[14129200]=1;break}else{if(f>>>0<32768){a[14129208]=1}if((d-8421376|0)>>>0<32768){a[14129128]=1}if((d-8458240|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);b[g>>1]=e;return}g=d-8519680|0;if(g>>>0>=16){if((d-8454144|0)>>>0<65536){return}if(!((d|0)==2097152|(d|0)==2097154)){return}f=(d-2097152|0)>>>1;if((f|0)==0){c[2439392]=(e&65535)>>>1&4095;return}else if((f|0)==1){b[(c[2442928]|0)+(c[2439392]<<1)>>1]=e;c[(c[3532276]|0)+(c[2439392]<<2)>>2]=((e&65535)>>>10<<3&248)>>>3|((e&255)<<3&255)<<8|(((e&65535)>>>7&4|(e&65535)>>>5<<3&255)&255)<<3&2016;return}else{return}}f=g>>>1;b[14129152+(f<<1)>>1]=e;switch(f|0){case 5:{c[3527494]=-(e&65535);return};case 2:{c[3527502]=-(e&65535);return};case 0:{c[2388344]=-(e&65535);return};case 7:{c[2439396]=e&1;return};case 1:{c[2385826]=-(e&65535);return};case 6:{c[3532284]=(e&65535)>>>4&1;return};case 4:{c[2385820]=-(e&65535);return};case 3:{c[2388334]=-(e&65535);return};default:{return}}}function feo(a){a=a|0;return 0}function fep(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;if((b|0)==10485763){e=d&15;f=a[9540896]|0;switch(f&255|0){case 0:{a[9540896]=f+1&255;a[9540888]=e;return};case 2:{a[9540896]=f+1&255;a[9540890]=e;return};case 1:{a[9540896]=f+1&255;a[9540889]=e;a[9540898]=a[9540898]|1;a[9540900]=1;return};case 4:{if(e<<24>>24==0){return}g=c[2439330]|0;h=(g|0)==0;if(!h){i=g;gGC(9706056,i|0,76)|0}i=c[2438118]|0;c[2433530]=i;j=c[3528484]|0;c[2076596]=j;k=c[2417276]|0;c[3541536]=k;c[1836236]=0;gGz(9706056,0,76);if(!h){h=g;gGC(h|0,9706056,76)|0}c[2438118]=i;c[3528484]=j;c[2417276]=k;c[1836236]=-1;return};case 3:{a[9540896]=f+1&255;a[9540891]=e;a[9540898]=a[9540898]|2;a[9540900]=1;return};default:{return}}}else if((b|0)==10485761){a[9540896]=d&15;return}else{return}}function feq(a){a=a|0;var b=0;switch(a|0){case 7340034:{b=d[14128481]|0;break};case 7340044:{b=d[14128321]|0;break};case 7340032:{b=d[14128480]|0;break};case 7340036:{b=d[14128322]|0;break};case 7340046:{b=d[14128323]|0;break};case 7340042:{b=d[14128320]|0;break};case 7340048:{b=d[14128324]|0;break};default:{b=-1}}return b|0}function fer(c,d){c=c|0;d=d|0;var e=0,f=0;e=c-4390912|0;if(e>>>0<48){eXO(e>>>1,d);return}e=c-5242880|0;if(e>>>0<32){a[14128984+(e>>>1)|0]=d&255;return}switch(c|0){case 3145728:case 3145730:case 3145732:case 3145734:case 3145736:case 3145738:case 3145740:case 3145742:{break};default:{return}}e=c-3145728|0;c=e>>>1;if(e>>>0<4){return}if(e>>>0<8){e=c<<1&2;f=(d&65535)<<11;b[14128416+(e<<1)>>1]=f&65535;b[14128416+((e|1)<<1)>>1]=(f|1024)&65535;return}else{b[14128416+(c<<1)>>1]=d<<10;return}}function fes(b){b=b|0;var c=0,d=0;L69132:do{if((b|0)==5275649){c=a[14128323]|0}else if((b|0)==5275648){c=a[14128324]|0}else if((b|0)==3276803){c=a[14128321]|0}else if((b|0)==3276801){c=a[14128320]|0}else if((b|0)==4194306){d=a[9540896]|0;switch(d&255|0){case 4:{c=a[9540898]|0;break L69132;break};case 2:{a[9540896]=d+1&255;c=a[9540894]|0;break L69132;break};case 0:{a[9540896]=d+1&255;c=a[9540892]|0;break L69132;break};case 1:{a[9540898]=a[9540898]&-5;a[9540896]=d+1&255;c=a[9540893]|0;break L69132;break};case 3:{a[9540898]=a[9540898]&-9;a[9540896]=d+1&255;c=a[9540895]|0;break L69132;break};default:{c=0;break L69132}}}else{c=0}}while(0);return c|0}function fet(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=b-8388608|0;if(e>>>0<65536){f=e^1;g=(c[3532278]|0)+f|0;do{if((a[g]|0)!=d<<24>>24){h=(e|0)>-1;if((c[3532284]|0)==0){if(h&(f|0)<16384){a[14129208]=1}if(h&(f|0)<32768){a[14129128]=1}if((f-24576|0)>>>0>=4096){break}a[14129200]=1;break}else{if(h&(f|0)<32768){a[14129208]=1}if((f-32768|0)>>>0<32768){a[14129128]=1}if((f-69632|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);a[g]=d;return}if((b|0)==4194306){g=d&15;f=a[9540896]|0;switch(f&255|0){case 3:{a[9540896]=f+1&255;a[9540891]=g;a[9540898]=a[9540898]|2;a[9540900]=1;return};case 0:{a[9540896]=f+1&255;a[9540888]=g;return};case 1:{a[9540896]=f+1&255;a[9540889]=g;a[9540898]=a[9540898]|1;a[9540900]=1;return};case 2:{a[9540896]=f+1&255;a[9540890]=g;return};case 4:{if(g<<24>>24==0){return}g=c[2439330]|0;f=(g|0)==0;if(!f){e=g;gGC(9706056,e|0,76)|0}e=c[2438118]|0;c[2433530]=e;h=c[3528484]|0;c[2076596]=h;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);if(!f){f=g;gGC(f|0,9706056,76)|0}c[2438118]=e;c[3528484]=h;c[2417276]=i;c[1836236]=-1;return};default:{return}}}else if((b|0)==4194304){a[9540896]=d&15;return}else{return}}function feu(a){a=a|0;var b=0;if((a|0)==3145730){b=d[14128481]|0}else if((a|0)==3276804){b=d[14128322]|0}else if((a|0)==5292032){b=d[14128325]|0}else if((a|0)==3276800){b=d[14128320]|0}else if((a|0)==3145728){b=d[14128480]|0}else{b=0}return b|0}function fev(d,e){d=d|0;e=e|0;var f=0,g=0,h=0;f=d-11534336|0;if(f>>>0<32){a[14128984+(f>>>1)|0]=e&255;return}f=d-8388608|0;if(f>>>0<65536){g=(c[3532278]|0)+(f>>>1<<1)|0;do{if((b[g>>1]|0)!=e<<16>>16){if((c[3532284]|0)==0){if(f>>>0<16384){a[14129208]=1}if((d-8421376|0)>>>0<16384){a[14129128]=1}if((d-8413184|0)>>>0>=4096){break}a[14129200]=1;break}else{if(f>>>0<32768){a[14129208]=1}if((d-8421376|0)>>>0<32768){a[14129128]=1}if((d-8458240|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);b[g>>1]=e;return}g=d-8519680|0;if(g>>>0>=16){switch(d|0){case 5242894:case 5242892:case 5242880:case 5242882:case 5242884:case 5242886:case 5242888:case 5242890:{break};default:{return}}f=d-5242880|0;d=f>>>1;if(f>>>0<4){return}if(f>>>0<8){f=d<<1&2;h=(e&65535)<<11;b[14128416+(f<<1)>>1]=h&65535;b[14128416+((f|1)<<1)>>1]=(h|1024)&65535;return}else{b[14128416+(d<<1)>>1]=e<<10;return}}d=g>>>1;b[14129152+(d<<1)>>1]=e;switch(d|0){case 6:{c[3532284]=(e&65535)>>>4&1;return};case 2:{c[3527502]=-(e&65535);return};case 5:{c[3527494]=-(e&65535);return};case 0:{c[2388344]=-(e&65535);return};case 7:{c[2439396]=e&1;return};case 1:{c[2385826]=-(e&65535);return};case 3:{c[2388334]=-(e&65535);return};case 4:{c[2385820]=-(e&65535);return};default:{return}}}function few(b){b=b|0;var c=0,d=0,e=0;c=b-3145728|0;L69266:do{if(c>>>0<16){switch(c>>>1^1|0){case 1:{d=a[14128921]|0;break L69266;break};case 7:{d=a[14128914]|0;break L69266;break};case 2:{d=a[14128912]|0;break L69266;break};case 4:{d=a[9757532]|0;break L69266;break};case 3:{d=a[14128913]|0;break L69266;break};case 0:{d=a[14128920]|0;break L69266;break};default:{d=-1;break L69266}}}else{if((b|0)!=3276802){d=0;break}e=a[9540896]|0;switch(e&255|0){case 2:{a[9540896]=e+1&255;d=a[9540894]|0;break L69266;break};case 4:{d=a[9540898]|0;break L69266;break};case 0:{a[9540896]=e+1&255;d=a[9540892]|0;break L69266;break};case 1:{a[9540898]=a[9540898]&-5;a[9540896]=e+1&255;d=a[9540893]|0;break L69266;break};case 3:{a[9540898]=a[9540898]&-9;a[9540896]=e+1&255;d=a[9540895]|0;break L69266;break};default:{d=0;break L69266}}}}while(0);return d|0}function fex(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=b-3145728|0;if(e>>>0<16){f=e>>>1^1;a[9757528+f|0]=d;if((f|0)==0){c[3531956]=0;return}else if((f|0)==4){f=~d;a[14128520]=f&1;a[14128521]=f&2;return}else{return}}f=b-8388608|0;if(f>>>0<65536){e=f^1;g=(c[3532278]|0)+e|0;do{if((a[g]|0)!=d<<24>>24){h=(f|0)>-1;if((c[3532284]|0)==0){if(h&(e|0)<16384){a[14129208]=1}if(h&(e|0)<32768){a[14129128]=1}if((e-24576|0)>>>0>=4096){break}a[14129200]=1;break}else{if(h&(e|0)<32768){a[14129208]=1}if((e-32768|0)>>>0<32768){a[14129128]=1}if((e-69632|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);a[g]=d;return}if((b|0)==3276802){g=d&15;e=a[9540896]|0;switch(e&255|0){case 1:{a[9540896]=e+1&255;a[9540889]=g;a[9540898]=a[9540898]|1;a[9540900]=1;return};case 2:{a[9540896]=e+1&255;a[9540890]=g;return};case 0:{a[9540896]=e+1&255;a[9540888]=g;return};case 4:{if(g<<24>>24==0){return}f=c[2439330]|0;h=(f|0)==0;if(!h){i=f;gGC(9706056,i|0,76)|0}i=c[2438118]|0;c[2433530]=i;j=c[3528484]|0;c[2076596]=j;k=c[2417276]|0;c[3541536]=k;c[1836236]=0;gGz(9706056,0,76);if(!h){h=f;gGC(h|0,9706056,76)|0}c[2438118]=i;c[3528484]=j;c[2417276]=k;c[1836236]=-1;return};case 3:{a[9540896]=e+1&255;a[9540891]=g;a[9540898]=a[9540898]|2;a[9540900]=1;return};default:{return}}}else if((b|0)==3276800){a[9540896]=d&15;return}else{return}}function fey(a){a=a|0;return 0}function fez(d,e){d=d|0;e=e|0;var f=0,g=0;f=d-3145728|0;if(f>>>0<16){g=f>>>1^1;f=e&255;a[9757528+g|0]=f;if((g|0)==0){c[3531956]=0;return}else if((g|0)==4){g=~f;a[14128520]=g&1;a[14128521]=g&2;return}else{return}}g=d-8388608|0;if(g>>>0<65536){f=(c[3532278]|0)+(g>>>1<<1)|0;do{if((b[f>>1]|0)!=e<<16>>16){if((c[3532284]|0)==0){if(g>>>0<16384){a[14129208]=1}if((d-8421376|0)>>>0<16384){a[14129128]=1}if((d-8413184|0)>>>0>=4096){break}a[14129200]=1;break}else{if(g>>>0<32768){a[14129208]=1}if((d-8421376|0)>>>0<32768){a[14129128]=1}if((d-8458240|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);b[f>>1]=e;return}f=d-8519680|0;if(f>>>0>=16){g=d-11534336|0;if(g>>>0>=32){return}a[14128984+(g>>>1)|0]=e&255;return}g=f>>>1;b[14129152+(g<<1)>>1]=e;switch(g|0){case 2:{c[3527502]=-(e&65535);return};case 4:{c[2385820]=-(e&65535);return};case 1:{c[2385826]=-(e&65535);return};case 7:{c[2439396]=e&1;return};case 0:{c[2388344]=-(e&65535);return};case 6:{c[3532284]=(e&65535)>>>4&1;return};case 3:{c[2388334]=-(e&65535);return};case 5:{c[3527494]=-(e&65535);return};default:{return}}}function feA(b){b=b|0;var c=0,d=0;c=b-3145728|0;L69405:do{if(c>>>0<16){switch(c>>>1|0){case 4:{d=a[9757532]|0;break L69405;break};case 2:{d=a[14128912]|0;break L69405;break};case 1:{d=a[14128921]|0;break L69405;break};case 3:{d=a[14128913]|0;break L69405;break};case 0:{d=a[14128920]|0;break L69405;break};case 7:{d=a[14128914]|0;break L69405;break};default:{d=-1;break L69405}}}else{d=0}}while(0);return d|0}function feB(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=b-3145728|0;if(e>>>0<16){f=e>>>1;a[9757528+f|0]=d;if((f|0)==0){c[3531956]=0;return}else if((f|0)==4){f=~d;a[14128520]=f&1;a[14128521]=f&2;return}else{return}}f=b-8388608|0;if(f>>>0<65536){e=f^1;g=(c[3532278]|0)+e|0;do{if((a[g]|0)!=d<<24>>24){h=(f|0)>-1;if((c[3532284]|0)==0){if(h&(e|0)<16384){a[14129208]=1}if(h&(e|0)<32768){a[14129128]=1}if((e-24576|0)>>>0>=4096){break}a[14129200]=1;break}else{if(h&(e|0)<32768){a[14129208]=1}if((e-32768|0)>>>0<32768){a[14129128]=1}if((e-69632|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);a[g]=d;return}g=b-11534336|0;if(g>>>0<32){a[14128984+(g>>>1)|0]=d;return}if((b|0)==3276802){g=d&15;e=a[9540896]|0;switch(e&255|0){case 3:{a[9540896]=e+1&255;a[9540891]=g;a[9540898]=a[9540898]|2;a[9540900]=1;return};case 2:{a[9540896]=e+1&255;a[9540890]=g;return};case 0:{a[9540896]=e+1&255;a[9540888]=g;return};case 4:{if(g<<24>>24==0){return}f=c[2439330]|0;h=(f|0)==0;if(!h){i=f;gGC(9706056,i|0,76)|0}i=c[2438118]|0;c[2433530]=i;j=c[3528484]|0;c[2076596]=j;k=c[2417276]|0;c[3541536]=k;c[1836236]=0;gGz(9706056,0,76);if(!h){h=f;gGC(h|0,9706056,76)|0}c[2438118]=i;c[3528484]=j;c[2417276]=k;c[1836236]=-1;return};case 1:{a[9540896]=e+1&255;a[9540889]=g;a[9540898]=a[9540898]|1;a[9540900]=1;return};default:{return}}}else if((b|0)==3276800){a[9540896]=d&15;return}else{return}}function feC(b){b=b|0;var c=0,d=0,e=0;c=b-3145728|0;if(c>>>0>=16){d=0;return d|0}switch(c>>>1|0){case 2:{e=a[14128912]|0;break};case 3:{e=a[14128913]|0;break};case 1:{e=a[14128921]|0;break};case 4:{e=a[9757532]|0;break};case 7:{e=a[14128914]|0;break};case 0:{e=a[14128920]|0;break};default:{e=-1}}d=e&255;return d|0}function feD(d,e){d=d|0;e=e|0;var f=0,g=0,h=0;f=d-3145728|0;if(f>>>0<16){g=f>>>1;f=e&255;a[9757528+g|0]=f;if((g|0)==0){c[3531956]=0;return}else if((g|0)==4){g=~f;a[14128520]=g&1;a[14128521]=g&2;return}else{return}}g=d-8388608|0;if(g>>>0<65536){f=(c[3532278]|0)+(g>>>1<<1)|0;do{if((b[f>>1]|0)!=e<<16>>16){if((c[3532284]|0)==0){if(g>>>0<16384){a[14129208]=1}if((d-8421376|0)>>>0<16384){a[14129128]=1}if((d-8413184|0)>>>0>=4096){break}a[14129200]=1;break}else{if(g>>>0<32768){a[14129208]=1}if((d-8421376|0)>>>0<32768){a[14129128]=1}if((d-8458240|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);b[f>>1]=e;return}f=d-8519680|0;if(f>>>0>=16){g=d-11534336|0;if(g>>>0<32){a[14128984+(g>>>1)|0]=e&255;return}if((d|0)!=10616832){return}b[7064208]=0;b[7064209]=1024;d=e<<11&30720;b[7064210]=d+2048&65535;g=(e&65535)>>>4<<11&30720;b[7064212]=g+2048&65535;h=(e&65535)>>>8<<11&30720;b[7064214]=h+2048&65535;b[7064211]=d+3072&65535;b[7064213]=g+3072&65535;b[7064215]=h+3072&65535;return}h=f>>>1;b[14129152+(h<<1)>>1]=e;switch(h|0){case 4:{c[2385820]=-(e&65535);return};case 6:{c[3532284]=(e&65535)>>>4&1;return};case 7:{c[2439396]=e&1;return};case 0:{c[2388344]=-(e&65535);return};case 1:{c[2385826]=-(e&65535);return};case 2:{c[3527502]=-(e&65535);return};case 3:{c[2388334]=-(e&65535);return};case 5:{c[3527494]=-(e&65535);return};default:{return}}}function feE(b){b=b|0;var c=0,d=0;c=b-3145728|0;L69556:do{if(c>>>0<16){switch(c>>>1&255|0){case 2:{d=a[14129040]|0;break L69556;break};case 4:{d=a[9757556]|0;break L69556;break};case 3:{d=a[14129041]|0;break L69556;break};case 1:{d=a[14129049]|0;break L69556;break};case 0:{d=a[14129048]|0;break L69556;break};case 7:{d=a[14129042]|0;break L69556;break};default:{d=0;break L69556}}}else{d=0}}while(0);return d|0}function feF(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=b-3145728|0;if(e>>>0<16){f=e>>>1;e=f&255;a[9757552+(f&255)|0]=d;if((e<<24>>24|0)==0){c[3531956]=0;return}else if((e<<24>>24|0)==4){e=~d;a[14128520]=e&1;a[14128521]=e&2;return}else{return}}e=b-8388608|0;if(e>>>0<65536){f=e^1;g=(c[3532278]|0)+f|0;do{if((a[g]|0)!=d<<24>>24){h=(e|0)>-1;if((c[3532284]|0)==0){if(h&(f|0)<16384){a[14129208]=1}if(h&(f|0)<32768){a[14129128]=1}if((f-24576|0)>>>0>=4096){break}a[14129200]=1;break}else{if(h&(f|0)<32768){a[14129208]=1}if((f-32768|0)>>>0<32768){a[14129128]=1}if((f-69632|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);a[g]=d;return}if((b|0)==3276801){a[9540896]=d&15;return}else if((b|0)==3276803){b=d&15;d=a[9540896]|0;switch(d&255|0){case 4:{if(b<<24>>24==0){return}g=c[2439330]|0;f=(g|0)==0;if(!f){e=g;gGC(9706056,e|0,76)|0}e=c[2438118]|0;c[2433530]=e;h=c[3528484]|0;c[2076596]=h;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);if(!f){f=g;gGC(f|0,9706056,76)|0}c[2438118]=e;c[3528484]=h;c[2417276]=i;c[1836236]=-1;return};case 2:{a[9540896]=d+1&255;a[9540890]=b;return};case 0:{a[9540896]=d+1&255;a[9540888]=b;return};case 1:{a[9540896]=d+1&255;a[9540889]=b;a[9540898]=a[9540898]|1;a[9540900]=1;return};case 3:{a[9540896]=d+1&255;a[9540891]=b;a[9540898]=a[9540898]|2;a[9540900]=1;return};default:{return}}}else{return}}function feG(b){b=b|0;var c=0,d=0,e=0;c=b-3145728|0;if(c>>>0>=16){d=0;return d|0}switch(c>>>1&255|0){case 7:{e=a[14129042]|0;break};case 1:{e=a[14129049]|0;break};case 0:{e=a[14129048]|0;break};case 3:{e=a[14129041]|0;break};case 2:{e=a[14129040]|0;break};case 4:{e=a[9757556]|0;break};default:{e=0}}d=e&255;return d|0}function feH(d,e){d=d|0;e=e|0;var f=0,g=0,h=0;f=d-3145728|0;if(f>>>0<16){g=f>>>1;f=g&255;h=e&255;a[9757552+(g&255)|0]=h;if((f<<24>>24|0)==4){g=~h;a[14128520]=g&1;a[14128521]=g&2;return}else if((f<<24>>24|0)==0){c[3531956]=0;return}else{return}}f=d-8388608|0;if(f>>>0<65536){g=(c[3532278]|0)+(f>>>1<<1)|0;do{if((b[g>>1]|0)!=e<<16>>16){if((c[3532284]|0)==0){if(f>>>0<16384){a[14129208]=1}if((d-8421376|0)>>>0<16384){a[14129128]=1}if((d-8413184|0)>>>0>=4096){break}a[14129200]=1;break}else{if(f>>>0<32768){a[14129208]=1}if((d-8421376|0)>>>0<32768){a[14129128]=1}if((d-8458240|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);b[g>>1]=e;return}g=d-8519680|0;if(g>>>0>=16){f=d-11534336|0;if(f>>>0>=32){return}a[14128984+(f>>>1)|0]=e&255;return}f=g>>>1;b[14129152+(f<<1)>>1]=e;switch(f|0){case 6:{c[3532284]=(e&65535)>>>4&1;return};case 7:{c[2439396]=e&1;return};case 2:{c[3527502]=-(e&65535);return};case 1:{c[2385826]=-(e&65535);return};case 3:{c[2388334]=-(e&65535);return};case 4:{c[2385820]=-(e&65535);return};case 0:{c[2388344]=-(e&65535);return};case 5:{c[3527494]=-(e&65535);return};default:{return}}}function feI(b){b=b|0;var d=0,e=0,f=0,g=0;d=b-1179648|0;L69699:do{if(d>>>0<16){switch(d>>>1&255|0){case 3:{e=a[14129041]|0;break L69699;break};case 1:{e=a[14129049]|0;break L69699;break};case 0:{e=a[14129048]|0;break L69699;break};case 2:{e=a[14129040]|0;break L69699;break};case 7:{e=a[14129042]|0;break L69699;break};case 4:{e=a[9757556]|0;break L69699;break};default:{e=0;break L69699}}}else{f=b-1572864|0;if(f>>>0<4096){g=f>>>1;if((g|0)==1025){e=1;break}e=a[(c[2439440]|0)+g|0]|0;break}if((b|0)!=1048578){e=0;break}g=a[9540896]|0;switch(g&255|0){case 2:{a[9540896]=g+1&255;e=a[9540894]|0;break L69699;break};case 0:{a[9540896]=g+1&255;e=a[9540892]|0;break L69699;break};case 3:{a[9540898]=a[9540898]&-9;a[9540896]=g+1&255;e=a[9540895]|0;break L69699;break};case 4:{e=a[9540898]|0;break L69699;break};case 1:{a[9540898]=a[9540898]&-5;a[9540896]=g+1&255;e=a[9540893]|0;break L69699;break};default:{e=0;break L69699}}}}while(0);return e|0}function feJ(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=b-1179648|0;if(e>>>0<16){f=e>>>1;e=f&255;a[9757552+(f&255)|0]=d;if((e<<24>>24|0)==0){c[3531956]=0;return}else if((e<<24>>24|0)==4){e=~d;a[14128520]=e&1;a[14128521]=e&2;return}else{return}}e=b-4194304|0;if(e>>>0<32){a[14128984+(e>>>1)|0]=d;return}e=b-6291456|0;if(e>>>0<65536){f=e^1;g=(c[3532278]|0)+f|0;do{if((a[g]|0)!=d<<24>>24){h=(e|0)>-1;if((c[3532284]|0)==0){if(h&(f|0)<16384){a[14129208]=1}if(h&(f|0)<32768){a[14129128]=1}if((f-24576|0)>>>0>=4096){break}a[14129200]=1;break}else{if(h&(f|0)<32768){a[14129208]=1}if((f-32768|0)>>>0<32768){a[14129128]=1}if((f-69632|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);a[g]=d;return}g=b-1572864|0;if(g>>>0<4096){a[(c[2439440]|0)+(g>>>1)|0]=d;return}if((b|0)==1048576){a[9540896]=d&15;return}else if((b|0)==1048578){b=d&15;d=a[9540896]|0;switch(d&255|0){case 4:{if(b<<24>>24==0){return}g=c[2439330]|0;f=(g|0)==0;if(!f){e=g;gGC(9706056,e|0,76)|0}e=c[2438118]|0;c[2433530]=e;h=c[3528484]|0;c[2076596]=h;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);if(!f){f=g;gGC(f|0,9706056,76)|0}c[2438118]=e;c[3528484]=h;c[2417276]=i;c[1836236]=-1;return};case 1:{a[9540896]=d+1&255;a[9540889]=b;a[9540898]=a[9540898]|1;a[9540900]=1;return};case 0:{a[9540896]=d+1&255;a[9540888]=b;return};case 3:{a[9540896]=d+1&255;a[9540891]=b;a[9540898]=a[9540898]|2;a[9540900]=1;return};case 2:{a[9540896]=d+1&255;a[9540890]=b;return};default:{return}}}else{return}}function feK(b){b=b|0;var c=0,d=0,e=0;c=b-1179648|0;if(c>>>0>=16){d=0;return d|0}switch(c>>>1&255|0){case 4:{e=a[9757556]|0;break};case 1:{e=a[14129049]|0;break};case 2:{e=a[14129040]|0;break};case 0:{e=a[14129048]|0;break};case 3:{e=a[14129041]|0;break};case 7:{e=a[14129042]|0;break};default:{e=0}}d=e&255;return d|0}function feL(d,e){d=d|0;e=e|0;var f=0,g=0,h=0;f=d-1179648|0;if(f>>>0<16){g=f>>>1;f=g&255;h=e&255;a[9757552+(g&255)|0]=h;if((f<<24>>24|0)==0){c[3531956]=0;return}else if((f<<24>>24|0)==4){f=~h;a[14128520]=f&1;a[14128521]=f&2;return}else{return}}f=d-4194304|0;if(f>>>0<32){a[14128984+(f>>>1)|0]=e&255;return}f=d-6291456|0;if(f>>>0<65536){h=(c[3532278]|0)+(f>>>1<<1)|0;do{if((b[h>>1]|0)!=e<<16>>16){if((c[3532284]|0)==0){if(f>>>0<16384){a[14129208]=1}if((d-6324224|0)>>>0<16384){a[14129128]=1}if((d-6316032|0)>>>0>=4096){break}a[14129200]=1;break}else{if(f>>>0<32768){a[14129208]=1}if((d-6324224|0)>>>0<32768){a[14129128]=1}if((d-6361088|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);b[h>>1]=e;return}h=d-6422528|0;if(h>>>0>=16){return}d=h>>>1;b[14129152+(d<<1)>>1]=e;switch(d|0){case 3:{c[2388334]=-(e&65535);return};case 6:{c[3532284]=(e&65535)>>>4&1;return};case 7:{c[2439396]=e&1;return};case 5:{c[3527494]=-(e&65535);return};case 1:{c[2385826]=-(e&65535);return};case 0:{c[2388344]=-(e&65535);return};case 2:{c[3527502]=-(e&65535);return};case 4:{c[2385820]=-(e&65535);return};default:{return}}}function feM(b){b=b|0;var c=0,d=0,e=0;c=b-8388608|0;L69862:do{if(c>>>0<16){switch(c>>>1^1|0){case 3:{d=a[14128913]|0;break L69862;break};case 4:{d=a[9757532]|0;break L69862;break};case 1:{d=a[14128921]|0;break L69862;break};case 0:{d=a[14128920]|0;break L69862;break};case 7:{d=a[14128914]|0;break L69862;break};case 2:{d=a[14128912]|0;break L69862;break};default:{d=-1;break L69862}}}else{if((b|0)!=9437186){d=0;break}e=a[9540896]|0;switch(e&255|0){case 3:{a[9540898]=a[9540898]&-9;a[9540896]=e+1&255;d=a[9540895]|0;break L69862;break};case 1:{a[9540898]=a[9540898]&-5;a[9540896]=e+1&255;d=a[9540893]|0;break L69862;break};case 0:{a[9540896]=e+1&255;d=a[9540892]|0;break L69862;break};case 2:{a[9540896]=e+1&255;d=a[9540894]|0;break L69862;break};case 4:{d=a[9540898]|0;break L69862;break};default:{d=0;break L69862}}}}while(0);return d|0}function feN(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=b-8388608|0;if(e>>>0<16){f=e>>>1^1;a[9757528+f|0]=d;if((f|0)==0){c[3531956]=0;return}else if((f|0)==4){f=~d;a[14128520]=f&1;a[14128521]=f&2;return}else{return}}if((b|0)==9437186){f=d&15;e=a[9540896]|0;switch(e&255|0){case 0:{a[9540896]=e+1&255;a[9540888]=f;return};case 4:{if(f<<24>>24==0){return}g=c[2439330]|0;h=(g|0)==0;if(!h){i=g;gGC(9706056,i|0,76)|0}i=c[2438118]|0;c[2433530]=i;j=c[3528484]|0;c[2076596]=j;k=c[2417276]|0;c[3541536]=k;c[1836236]=0;gGz(9706056,0,76);if(!h){h=g;gGC(h|0,9706056,76)|0}c[2438118]=i;c[3528484]=j;c[2417276]=k;c[1836236]=-1;return};case 3:{a[9540896]=e+1&255;a[9540891]=f;a[9540898]=a[9540898]|2;a[9540900]=1;return};case 1:{a[9540896]=e+1&255;a[9540889]=f;a[9540898]=a[9540898]|1;a[9540900]=1;return};case 2:{a[9540896]=e+1&255;a[9540890]=f;return};default:{return}}}else if((b|0)==9437184){a[9540896]=d&15;return}else{return}}function feO(a){a=a|0;return 0}function feP(b,d){b=b|0;d=d|0;var e=0;e=b-5439488|0;if(e>>>0<48){eXO(e>>>1,d);return}e=b-6291456|0;if(e>>>0<32){a[14128984+(e>>>1)|0]=d&255;return}e=b-8388608|0;if(e>>>0>=16){return}b=e>>>1^1;e=d&255;a[9757528+b|0]=e;if((b|0)==0){c[3531956]=0;return}else if((b|0)==4){b=~e;a[14128520]=b&1;a[14128521]=b&2;return}else{return}}function feQ(b){b=b|0;var c=0,d=0;L69936:do{if((b|0)==3145728){c=a[14128324]|0}else if((b|0)==3145729){c=a[14128480]|0}else if((b|0)==3145731){c=a[14128481]|0}else if((b|0)==3145730){c=a[14128325]|0}else if((b|0)==3538946){d=a[9540896]|0;switch(d&255|0){case 2:{a[9540896]=d+1&255;c=a[9540894]|0;break L69936;break};case 0:{a[9540896]=d+1&255;c=a[9540892]|0;break L69936;break};case 4:{c=a[9540898]|0;break L69936;break};case 3:{a[9540898]=a[9540898]&-9;a[9540896]=d+1&255;c=a[9540895]|0;break L69936;break};case 1:{a[9540898]=a[9540898]&-5;a[9540896]=d+1&255;c=a[9540893]|0;break L69936;break};default:{c=0;break L69936}}}else{c=0}}while(0);return c|0}function feR(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=b-4194304|0;if(e>>>0<65536){f=e^1;g=(c[3532278]|0)+f|0;do{if((a[g]|0)!=d<<24>>24){h=(e|0)>-1;if((c[3532284]|0)==0){if(h&(f|0)<16384){a[14129208]=1}if(h&(f|0)<32768){a[14129128]=1}if((f-24576|0)>>>0>=4096){break}a[14129200]=1;break}else{if(h&(f|0)<32768){a[14129208]=1}if((f-32768|0)>>>0<32768){a[14129128]=1}if((f-69632|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);a[g]=d;return}if((b|0)==3538944){a[9540896]=d&15;return}else if((b|0)==3538946){b=d&15;d=a[9540896]|0;switch(d&255|0){case 2:{a[9540896]=d+1&255;a[9540890]=b;return};case 1:{a[9540896]=d+1&255;a[9540889]=b;a[9540898]=a[9540898]|1;a[9540900]=1;return};case 0:{a[9540896]=d+1&255;a[9540888]=b;return};case 3:{a[9540896]=d+1&255;a[9540891]=b;a[9540898]=a[9540898]|2;a[9540900]=1;return};case 4:{if(b<<24>>24==0){return}b=c[2439330]|0;d=(b|0)==0;if(!d){g=b;gGC(9706056,g|0,76)|0}g=c[2438118]|0;c[2433530]=g;f=c[3528484]|0;c[2076596]=f;e=c[2417276]|0;c[3541536]=e;c[1836236]=0;gGz(9706056,0,76);if(!d){d=b;gGC(d|0,9706056,76)|0}c[2438118]=g;c[3528484]=f;c[2417276]=e;c[1836236]=-1;return};default:{return}}}else{return}}function feS(a){a=a|0;var b=0,e=0;do{if((a|0)==3211264){b=c[2439438]|0;if((b|0)==8){e=d[14128323]|0;break}else if((b|0)==1){e=d[14128320]|0;break}else if((b|0)==4){e=d[14128322]|0;break}else if((b|0)==2){e=d[14128321]|0;break}else{e=255;break}}else{e=0}}while(0);return e|0}function feT(d,e){d=d|0;e=e|0;var f=0,g=0;f=d-4194304|0;if(f>>>0<65536){g=(c[3532278]|0)+(f>>>1<<1)|0;do{if((b[g>>1]|0)!=e<<16>>16){if((c[3532284]|0)==0){if(f>>>0<16384){a[14129208]=1}if((d-4227072|0)>>>0<16384){a[14129128]=1}if((d-4218880|0)>>>0>=4096){break}a[14129200]=1;break}else{if(f>>>0<32768){a[14129208]=1}if((d-4227072|0)>>>0<32768){a[14129128]=1}if((d-4263936|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);b[g>>1]=e;return}g=d-4325376|0;if(g>>>0>=16){if((d|0)==3670016){c[2433302]=e&1;return}else if((d|0)==3276800){c[2439438]=(e&65535)>>>6;return}else if((d|0)==2097152|(d|0)==2097154){f=(d-2097152|0)>>>1;if((f|0)==0){c[2439392]=(e&65535)>>>1&4095;return}else if((f|0)==1){b[(c[2442928]|0)+(c[2439392]<<1)>>1]=e;c[(c[3532276]|0)+(c[2439392]<<2)>>2]=((e&65535)>>>10<<3&248)>>>3|((e&255)<<3&255)<<8|(((e&65535)>>>7&4|(e&65535)>>>5<<3&255)&255)<<3&2016;return}else{return}}else{return}}f=g>>>1;b[14129152+(f<<1)>>1]=e;switch(f|0){case 3:{c[2388334]=-(e&65535);return};case 7:{c[2439396]=e&1;return};case 0:{c[2388344]=-(e&65535);return};case 4:{c[2385820]=-(e&65535);return};case 6:{c[3532284]=(e&65535)>>>4&1;return};case 1:{c[2385826]=-(e&65535);return};case 5:{c[3527494]=-(e&65535);return};case 2:{c[3527502]=-(e&65535);return};default:{return}}}function feU(b){b=b|0;var c=0,d=0;L70069:do{if((b|0)==3145734){c=a[14128321]|0}else if((b|0)==3145730){c=a[14128481]|0}else if((b|0)==3145728){c=a[14128480]|0}else if((b|0)==4194306){d=a[9540896]|0;switch(d&255|0){case 1:{a[9540898]=a[9540898]&-5;a[9540896]=d+1&255;c=a[9540893]|0;break L70069;break};case 0:{a[9540896]=d+1&255;c=a[9540892]|0;break L70069;break};case 4:{c=a[9540898]|0;break L70069;break};case 2:{a[9540896]=d+1&255;c=a[9540894]|0;break L70069;break};case 3:{a[9540898]=a[9540898]&-9;a[9540896]=d+1&255;c=a[9540895]|0;break L70069;break};default:{c=0;break L70069}}}else if((b|0)==3145740){c=a[14128322]|0}else if((b|0)==3145732){c=a[14128320]|0}else if((b|0)==3145736){c=a[14128323]|0}else if((b|0)==3145738){c=a[14128324]|0}else{c=0}}while(0);return c|0}function feV(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=b-8388608|0;if(e>>>0<65536){f=e^1;g=(c[3532278]|0)+f|0;do{if((a[g]|0)!=d<<24>>24){h=(e|0)>-1;if((c[3532284]|0)==0){if(h&(f|0)<16384){a[14129208]=1}if(h&(f|0)<32768){a[14129128]=1}if((f-24576|0)>>>0>=4096){break}a[14129200]=1;break}else{if(h&(f|0)<32768){a[14129208]=1}if((f-32768|0)>>>0<32768){a[14129128]=1}if((f-69632|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);a[g]=d;return}if((b|0)==4194304){a[9540896]=d&15;return}else if((b|0)==4194306){b=d&15;d=a[9540896]|0;switch(d&255|0){case 2:{a[9540896]=d+1&255;a[9540890]=b;return};case 1:{a[9540896]=d+1&255;a[9540889]=b;a[9540898]=a[9540898]|1;a[9540900]=1;return};case 3:{a[9540896]=d+1&255;a[9540891]=b;a[9540898]=a[9540898]|2;a[9540900]=1;return};case 4:{if(b<<24>>24==0){return}g=c[2439330]|0;f=(g|0)==0;if(!f){e=g;gGC(9706056,e|0,76)|0}e=c[2438118]|0;c[2433530]=e;h=c[3528484]|0;c[2076596]=h;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);if(!f){f=g;gGC(f|0,9706056,76)|0}c[2438118]=e;c[3528484]=h;c[2417276]=i;c[1836236]=-1;return};case 0:{a[9540896]=d+1&255;a[9540888]=b;return};default:{return}}}else{return}}function feW(a){a=a|0;return 0}function feX(d,e){d=d|0;e=e|0;var f=0,g=0,h=0;f=d-8388608|0;if(f>>>0<65536){g=(c[3532278]|0)+(f>>>1<<1)|0;do{if((b[g>>1]|0)!=e<<16>>16){if((c[3532284]|0)==0){if(f>>>0<16384){a[14129208]=1}if((d-8421376|0)>>>0<16384){a[14129128]=1}if((d-8413184|0)>>>0>=4096){break}a[14129200]=1;break}else{if(f>>>0<32768){a[14129208]=1}if((d-8421376|0)>>>0<32768){a[14129128]=1}if((d-8458240|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);b[g>>1]=e;return}g=d-8519680|0;if(g>>>0>=16){f=d-11534336|0;if(f>>>0<32){a[14128984+(f>>>1)|0]=e&255;return}switch(d|0){case 6291470:case 6291468:case 6291466:case 6291464:case 6291462:case 6291460:case 6291456:case 6291458:{break};default:{return}}f=d-6291456|0;d=f>>>1;if(f>>>0<4){return}if(f>>>0<8){f=d<<1&2;h=(e&65535)<<11;b[14128416+(f<<1)>>1]=h&65535;b[14128416+((f|1)<<1)>>1]=(h|1024)&65535;return}else{b[14128416+(d<<1)>>1]=e<<10;return}}d=g>>>1;b[14129152+(d<<1)>>1]=e;switch(d|0){case 5:{c[3527494]=-(e&65535);return};case 1:{c[2385826]=-(e&65535);return};case 2:{c[3527502]=-(e&65535);return};case 0:{c[2388344]=-(e&65535);return};case 3:{c[2388334]=-(e&65535);return};case 6:{c[3532284]=(e&65535)>>>4&1;return};case 7:{c[2439396]=e&1;return};case 4:{c[2385820]=-(e&65535);return};default:{return}}}function feY(b){b=b|0;var c=0,d=0,e=0;c=b-11534336|0;L70199:do{if(c>>>0<16){switch(c>>>1|0){case 7:{d=a[14128914]|0;break L70199;break};case 2:{d=a[14128912]|0;break L70199;break};case 0:{d=a[14128920]|0;break L70199;break};case 4:{d=a[9757532]|0;break L70199;break};case 3:{d=a[14128913]|0;break L70199;break};case 1:{d=a[14128921]|0;break L70199;break};default:{d=-1;break L70199}}}else{if((b|0)!=2097154){d=0;break}e=a[9540896]|0;switch(e&255|0){case 0:{a[9540896]=e+1&255;d=a[9540892]|0;break L70199;break};case 1:{a[9540898]=a[9540898]&-5;a[9540896]=e+1&255;d=a[9540893]|0;break L70199;break};case 4:{d=a[9540898]|0;break L70199;break};case 2:{a[9540896]=e+1&255;d=a[9540894]|0;break L70199;break};case 3:{a[9540898]=a[9540898]&-9;a[9540896]=e+1&255;d=a[9540895]|0;break L70199;break};default:{d=0;break L70199}}}}while(0);return d|0}function feZ(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=b-8388608|0;if(e>>>0<65536){f=e^1;g=(c[3532278]|0)+f|0;do{if((a[g]|0)!=d<<24>>24){h=(e|0)>-1;if((c[3532284]|0)==0){if(h&(f|0)<16384){a[14129208]=1}if(h&(f|0)<32768){a[14129128]=1}if((f-24576|0)>>>0>=4096){break}a[14129200]=1;break}else{if(h&(f|0)<32768){a[14129208]=1}if((f-32768|0)>>>0<32768){a[14129128]=1}if((f-69632|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);a[g]=d;return}g=b-11534336|0;if(g>>>0<16){f=g>>>1;a[9757528+f|0]=d;if((f|0)==4){g=~d;a[14128520]=g&1;a[14128521]=g&2;return}else if((f|0)==0){c[3531956]=0;return}else{return}}if((b|0)==2097152){a[9540896]=d&15;return}else if((b|0)==2097154){b=d&15;d=a[9540896]|0;switch(d&255|0){case 4:{if(b<<24>>24==0){return}f=c[2439330]|0;g=(f|0)==0;if(!g){e=f;gGC(9706056,e|0,76)|0}e=c[2438118]|0;c[2433530]=e;h=c[3528484]|0;c[2076596]=h;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);if(!g){g=f;gGC(g|0,9706056,76)|0}c[2438118]=e;c[3528484]=h;c[2417276]=i;c[1836236]=-1;return};case 2:{a[9540896]=d+1&255;a[9540890]=b;return};case 0:{a[9540896]=d+1&255;a[9540888]=b;return};case 1:{a[9540896]=d+1&255;a[9540889]=b;a[9540898]=a[9540898]|1;a[9540900]=1;return};case 3:{a[9540896]=d+1&255;a[9540891]=b;a[9540898]=a[9540898]|2;a[9540900]=1;return};default:{return}}}else{return}}function fe_(a){a=a|0;return 0}function fe$(d,e){d=d|0;e=e|0;var f=0,g=0;f=d-4202496|0;if(f>>>0<16){b[9757536+(f>>>1<<1)>>1]=e;return}f=d-8388608|0;if(f>>>0<65536){g=(c[3532278]|0)+(f>>>1<<1)|0;do{if((b[g>>1]|0)!=e<<16>>16){if((c[3532284]|0)==0){if(f>>>0<16384){a[14129208]=1}if((d-8421376|0)>>>0<16384){a[14129128]=1}if((d-8413184|0)>>>0>=4096){break}a[14129200]=1;break}else{if(f>>>0<32768){a[14129208]=1}if((d-8421376|0)>>>0<32768){a[14129128]=1}if((d-8458240|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);b[g>>1]=e;return}g=d-8519680|0;if(g>>>0>=16){f=d-10485760|0;if(f>>>0<32){if((e&65535)<256){return}a[14128984+(f>>>1)|0]=(e&65535)>>>8&255;return}f=d-11534336|0;if(f>>>0>=16){return}d=f>>>1;f=e&255;a[9757528+d|0]=f;if((d|0)==0){c[3531956]=0;return}else if((d|0)==4){d=~f;a[14128520]=d&1;a[14128521]=d&2;return}else{return}}d=g>>>1;b[14129152+(d<<1)>>1]=e;switch(d|0){case 1:{c[2385826]=-(e&65535);return};case 3:{c[2388334]=-(e&65535);return};case 6:{c[3532284]=(e&65535)>>>4&1;return};case 4:{c[2385820]=-(e&65535);return};case 0:{c[2388344]=-(e&65535);return};case 2:{c[3527502]=-(e&65535);return};case 7:{c[2439396]=e&1;return};case 5:{c[3527494]=-(e&65535);return};default:{return}}}function fe0(b){b=b|0;var c=0,d=0,e=0;c=b-10485760|0;L70345:do{if(c>>>0<16){switch(c>>>1|0){case 4:{d=a[9757532]|0;break L70345;break};case 0:{d=a[14128920]|0;break L70345;break};case 3:{d=a[14128913]|0;break L70345;break};case 7:{d=a[14128914]|0;break L70345;break};case 1:{d=a[14128921]|0;break L70345;break};case 2:{d=a[14128912]|0;break L70345;break};default:{d=-1;break L70345}}}else{if((b|0)!=5242882){d=0;break}e=a[9540896]|0;switch(e&255|0){case 2:{a[9540896]=e+1&255;d=a[9540894]|0;break L70345;break};case 0:{a[9540896]=e+1&255;d=a[9540892]|0;break L70345;break};case 1:{a[9540898]=a[9540898]&-5;a[9540896]=e+1&255;d=a[9540893]|0;break L70345;break};case 4:{d=a[9540898]|0;break L70345;break};case 3:{a[9540898]=a[9540898]&-9;a[9540896]=e+1&255;d=a[9540895]|0;break L70345;break};default:{d=0;break L70345}}}}while(0);return d|0}function fe1(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=b-9437184|0;if(e>>>0<65536){f=e^1;g=(c[3532278]|0)+f|0;do{if((a[g]|0)!=d<<24>>24){h=(e|0)>-1;if((c[3532284]|0)==0){if(h&(f|0)<16384){a[14129208]=1}if(h&(f|0)<32768){a[14129128]=1}if((f-24576|0)>>>0>=4096){break}a[14129200]=1;break}else{if(h&(f|0)<32768){a[14129208]=1}if((f-32768|0)>>>0<32768){a[14129128]=1}if((f-69632|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);a[g]=d;return}g=b-10485760|0;if(g>>>0<16){f=g>>>1;a[9757528+f|0]=d;if((f|0)==0){c[3531956]=0;return}else if((f|0)==4){f=~d;a[14128520]=f&1;a[14128521]=f&2;return}else{return}}if((b|0)==5242882){f=d&15;g=a[9540896]|0;switch(g&255|0){case 2:{a[9540896]=g+1&255;a[9540890]=f;return};case 0:{a[9540896]=g+1&255;a[9540888]=f;return};case 3:{a[9540896]=g+1&255;a[9540891]=f;a[9540898]=a[9540898]|2;a[9540900]=1;return};case 4:{if(f<<24>>24==0){return}e=c[2439330]|0;h=(e|0)==0;if(!h){i=e;gGC(9706056,i|0,76)|0}i=c[2438118]|0;c[2433530]=i;j=c[3528484]|0;c[2076596]=j;k=c[2417276]|0;c[3541536]=k;c[1836236]=0;gGz(9706056,0,76);if(!h){h=e;gGC(h|0,9706056,76)|0}c[2438118]=i;c[3528484]=j;c[2417276]=k;c[1836236]=-1;return};case 1:{a[9540896]=g+1&255;a[9540889]=f;a[9540898]=a[9540898]|1;a[9540900]=1;return};default:{return}}}else if((b|0)==5242880){a[9540896]=d&15;return}else{return}}function fe2(a){a=a|0;return 0}function fe3(d,e){d=d|0;e=e|0;var f=0,g=0,h=0;f=d-9437184|0;if(f>>>0<65536){g=(c[3532278]|0)+(f>>>1<<1)|0;do{if((b[g>>1]|0)!=e<<16>>16){if((c[3532284]|0)==0){if(f>>>0<16384){a[14129208]=1}if((d-9469952|0)>>>0<16384){a[14129128]=1}if((d-9461760|0)>>>0>=4096){break}a[14129200]=1;break}else{if(f>>>0<32768){a[14129208]=1}if((d-9469952|0)>>>0<32768){a[14129128]=1}if((d-9506816|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);b[g>>1]=e;return}g=d-9568256|0;if(g>>>0>=16){f=d-10485760|0;if(f>>>0>=16){h=d-11534336|0;if(h>>>0>=32){return}a[14128984+(h>>>1)|0]=e&255;return}h=f>>>1;f=e&255;a[9757528+h|0]=f;if((h|0)==4){d=~f;a[14128520]=d&1;a[14128521]=d&2;return}else if((h|0)==0){c[3531956]=0;return}else{return}}h=g>>>1;b[14129152+(h<<1)>>1]=e;switch(h|0){case 2:{c[3527502]=-(e&65535);return};case 5:{c[3527494]=-(e&65535);return};case 0:{c[2388344]=-(e&65535);return};case 1:{c[2385826]=-(e&65535);return};case 6:{c[3532284]=(e&65535)>>>4&1;return};case 4:{c[2385820]=-(e&65535);return};case 7:{c[2439396]=e&1;return};case 3:{c[2388334]=-(e&65535);return};default:{return}}}function fe4(b){b=b|0;var c=0,d=0,e=0;c=b-7340032|0;L70484:do{if(c>>>0<16){switch(c>>>1|0){case 7:{d=a[14128914]|0;break L70484;break};case 1:{d=a[14128921]|0;break L70484;break};case 0:{d=a[14128920]|0;break L70484;break};case 3:{d=a[14128913]|0;break L70484;break};case 2:{d=a[14128912]|0;break L70484;break};case 4:{d=a[9757532]|0;break L70484;break};default:{d=-1;break L70484}}}else{if((b|0)!=10485762){d=0;break}e=a[9540896]|0;switch(e&255|0){case 3:{a[9540898]=a[9540898]&-9;a[9540896]=e+1&255;d=a[9540895]|0;break L70484;break};case 1:{a[9540898]=a[9540898]&-5;a[9540896]=e+1&255;d=a[9540893]|0;break L70484;break};case 2:{a[9540896]=e+1&255;d=a[9540894]|0;break L70484;break};case 0:{a[9540896]=e+1&255;d=a[9540892]|0;break L70484;break};case 4:{d=a[9540898]|0;break L70484;break};default:{d=0;break L70484}}}}while(0);return d|0}function fe5(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=b-5242880|0;if(e>>>0<65536){f=e^1;g=(c[3532278]|0)+f|0;do{if((a[g]|0)!=d<<24>>24){h=(e|0)>-1;if((c[3532284]|0)==0){if(h&(f|0)<16384){a[14129208]=1}if(h&(f|0)<32768){a[14129128]=1}if((f-24576|0)>>>0>=4096){break}a[14129200]=1;break}else{if(h&(f|0)<32768){a[14129208]=1}if((f-32768|0)>>>0<32768){a[14129128]=1}if((f-69632|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);a[g]=d;return}g=b-7340032|0;if(g>>>0<16){f=g>>>1;a[9757528+f|0]=d;if((f|0)==0){c[3531956]=0;return}else if((f|0)==4){f=~d;a[14128520]=f&1;a[14128521]=f&2;return}else{return}}if((b|0)==10485760){a[9540896]=d&15;return}else if((b|0)==10485762){b=d&15;d=a[9540896]|0;switch(d&255|0){case 3:{a[9540896]=d+1&255;a[9540891]=b;a[9540898]=a[9540898]|2;a[9540900]=1;return};case 1:{a[9540896]=d+1&255;a[9540889]=b;a[9540898]=a[9540898]|1;a[9540900]=1;return};case 2:{a[9540896]=d+1&255;a[9540890]=b;return};case 0:{a[9540896]=d+1&255;a[9540888]=b;return};case 4:{if(b<<24>>24==0){return}b=c[2439330]|0;d=(b|0)==0;if(!d){f=b;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;e=c[2417276]|0;c[3541536]=e;c[1836236]=0;gGz(9706056,0,76);if(!d){d=b;gGC(d|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=e;c[1836236]=-1;return};default:{return}}}else{return}}function fe6(a){a=a|0;return 0}function fe7(d,e){d=d|0;e=e|0;var f=0,g=0,h=0;f=d-5242880|0;if(f>>>0<65536){g=(c[3532278]|0)+(f>>>1<<1)|0;do{if((b[g>>1]|0)!=e<<16>>16){if((c[3532284]|0)==0){if(f>>>0<16384){a[14129208]=1}if((d-5275648|0)>>>0<16384){a[14129128]=1}if((d-5267456|0)>>>0>=4096){break}a[14129200]=1;break}else{if(f>>>0<32768){a[14129208]=1}if((d-5275648|0)>>>0<32768){a[14129128]=1}if((d-5312512|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);b[g>>1]=e;return}g=d-5373952|0;if(g>>>0>=16){f=d-7340032|0;if(f>>>0>=16){h=d-9437184|0;if(h>>>0>=32){return}a[14128984+(h>>>1)|0]=e&255;return}h=f>>>1;f=e&255;a[9757528+h|0]=f;if((h|0)==4){d=~f;a[14128520]=d&1;a[14128521]=d&2;return}else if((h|0)==0){c[3531956]=0;return}else{return}}h=g>>>1;b[14129152+(h<<1)>>1]=e;switch(h|0){case 6:{c[3532284]=(e&65535)>>>4&1;return};case 7:{c[2439396]=e&1;return};case 0:{c[2388344]=-(e&65535);return};case 4:{c[2385820]=-(e&65535);return};case 5:{c[3527494]=-(e&65535);return};case 2:{c[3527502]=-(e&65535);return};case 3:{c[2388334]=-(e&65535);return};case 1:{c[2385826]=-(e&65535);return};default:{return}}}function fe8(b){b=b|0;var c=0,d=0,e=0;c=b-11534336|0;L70623:do{if(c>>>0<16){switch(c>>>1|0){case 1:{d=a[14128921]|0;break L70623;break};case 0:{d=a[14128920]|0;break L70623;break};case 4:{d=a[9757532]|0;break L70623;break};case 2:{d=a[14128912]|0;break L70623;break};case 7:{d=a[14128914]|0;break L70623;break};case 3:{d=a[14128913]|0;break L70623;break};default:{d=-1;break L70623}}}else{if((b|0)!=2097154){d=0;break}e=a[9540896]|0;switch(e&255|0){case 3:{a[9540898]=a[9540898]&-9;a[9540896]=e+1&255;d=a[9540895]|0;break L70623;break};case 4:{d=a[9540898]|0;break L70623;break};case 1:{a[9540898]=a[9540898]&-5;a[9540896]=e+1&255;d=a[9540893]|0;break L70623;break};case 0:{a[9540896]=e+1&255;d=a[9540892]|0;break L70623;break};case 2:{a[9540896]=e+1&255;d=a[9540894]|0;break L70623;break};default:{d=0;break L70623}}}}while(0);return d|0}function fe9(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=b-8388608|0;if(e>>>0<65536){f=e^1;g=(c[3532278]|0)+f|0;do{if((a[g]|0)!=d<<24>>24){h=(e|0)>-1;if((c[3532284]|0)==0){if(h&(f|0)<16384){a[14129208]=1}if(h&(f|0)<32768){a[14129128]=1}if((f-24576|0)>>>0>=4096){break}a[14129200]=1;break}else{if(h&(f|0)<32768){a[14129208]=1}if((f-32768|0)>>>0<32768){a[14129128]=1}if((f-69632|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);a[g]=d;return}g=b-11534336|0;if(g>>>0<16){f=g>>>1;a[9757528+f|0]=d;if((f|0)==4){g=~d;a[14128520]=g&1;a[14128521]=g&2;return}else if((f|0)==0){c[3531956]=0;return}else{return}}if((b|0)==2097154){f=d&15;g=a[9540896]|0;switch(g&255|0){case 2:{a[9540896]=g+1&255;a[9540890]=f;return};case 0:{a[9540896]=g+1&255;a[9540888]=f;return};case 4:{if(f<<24>>24==0){return}e=c[2439330]|0;h=(e|0)==0;if(!h){i=e;gGC(9706056,i|0,76)|0}i=c[2438118]|0;c[2433530]=i;j=c[3528484]|0;c[2076596]=j;k=c[2417276]|0;c[3541536]=k;c[1836236]=0;gGz(9706056,0,76);if(!h){h=e;gGC(h|0,9706056,76)|0}c[2438118]=i;c[3528484]=j;c[2417276]=k;c[1836236]=-1;return};case 1:{a[9540896]=g+1&255;a[9540889]=f;a[9540898]=a[9540898]|1;a[9540900]=1;return};case 3:{a[9540896]=g+1&255;a[9540891]=f;a[9540898]=a[9540898]|2;a[9540900]=1;return};default:{return}}}else if((b|0)==2097152){a[9540896]=d&15;return}else{return}}function ffa(a){a=a|0;return 0}function ffb(d,e){d=d|0;e=e|0;var f=0,g=0;f=d-8388608|0;if(f>>>0<65536){g=(c[3532278]|0)+(f>>>1<<1)|0;do{if((b[g>>1]|0)!=e<<16>>16){if((c[3532284]|0)==0){if(f>>>0<16384){a[14129208]=1}if((d-8421376|0)>>>0<16384){a[14129128]=1}if((d-8413184|0)>>>0>=4096){break}a[14129200]=1;break}else{if(f>>>0<32768){a[14129208]=1}if((d-8421376|0)>>>0<32768){a[14129128]=1}if((d-8458240|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);b[g>>1]=e;return}g=d-8519680|0;if(g>>>0>=16){f=d-10485760|0;if(f>>>0<32){a[14128984+(f>>>1)|0]=e&255;return}f=d-11534336|0;if(f>>>0>=16){return}d=f>>>1;f=e&255;a[9757528+d|0]=f;if((d|0)==0){c[3531956]=0;return}else if((d|0)==4){d=~f;a[14128520]=d&1;a[14128521]=d&2;return}else{return}}d=g>>>1;b[14129152+(d<<1)>>1]=e;switch(d|0){case 3:{c[2388334]=-(e&65535);return};case 5:{c[3527494]=-(e&65535);return};case 1:{c[2385826]=-(e&65535);return};case 0:{c[2388344]=-(e&65535);return};case 4:{c[2385820]=-(e&65535);return};case 6:{c[3532284]=(e&65535)>>>4&1;return};case 7:{c[2439396]=e&1;return};case 2:{c[3527502]=-(e&65535);return};default:{return}}}function ffc(b){b=b|0;var c=0,d=0,e=0;c=b-5242880|0;L70762:do{if(c>>>0<16){switch(c>>>1&255|0){case 0:{d=a[14129048]|0;break L70762;break};case 7:{d=a[14129042]|0;break L70762;break};case 4:{d=a[9757556]|0;break L70762;break};case 1:{d=a[14129049]|0;break L70762;break};case 3:{d=a[14129041]|0;break L70762;break};case 2:{d=a[14129040]|0;break L70762;break};default:{d=0;break L70762}}}else{if((b|0)!=6291458){d=0;break}e=a[9540896]|0;switch(e&255|0){case 0:{a[9540896]=e+1&255;d=a[9540892]|0;break L70762;break};case 4:{d=a[9540898]|0;break L70762;break};case 3:{a[9540898]=a[9540898]&-9;a[9540896]=e+1&255;d=a[9540895]|0;break L70762;break};case 1:{a[9540898]=a[9540898]&-5;a[9540896]=e+1&255;d=a[9540893]|0;break L70762;break};case 2:{a[9540896]=e+1&255;d=a[9540894]|0;break L70762;break};default:{d=0;break L70762}}}}while(0);return d|0}function ffd(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=b-5242880|0;if(e>>>0<16){f=e>>>1;e=f&255;a[9757552+(f&255)|0]=d;if((e<<24>>24|0)==0){c[3531956]=0;return}else if((e<<24>>24|0)==4){e=~d;a[14128520]=e&1;a[14128521]=e&2;return}else{return}}e=b-8388608|0;if(e>>>0<65536){f=e^1;g=(c[3532278]|0)+f|0;do{if((a[g]|0)!=d<<24>>24){h=(e|0)>-1;if((c[3532284]|0)==0){if(h&(f|0)<16384){a[14129208]=1}if(h&(f|0)<32768){a[14129128]=1}if((f-24576|0)>>>0>=4096){break}a[14129200]=1;break}else{if(h&(f|0)<32768){a[14129208]=1}if((f-32768|0)>>>0<32768){a[14129128]=1}if((f-69632|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);a[g]=d;return}if((b|0)==6291458){g=d&15;f=a[9540896]|0;switch(f&255|0){case 3:{a[9540896]=f+1&255;a[9540891]=g;a[9540898]=a[9540898]|2;a[9540900]=1;return};case 0:{a[9540896]=f+1&255;a[9540888]=g;return};case 1:{a[9540896]=f+1&255;a[9540889]=g;a[9540898]=a[9540898]|1;a[9540900]=1;return};case 2:{a[9540896]=f+1&255;a[9540890]=g;return};case 4:{if(g<<24>>24==0){return}g=c[2439330]|0;f=(g|0)==0;if(!f){e=g;gGC(9706056,e|0,76)|0}e=c[2438118]|0;c[2433530]=e;h=c[3528484]|0;c[2076596]=h;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);if(!f){f=g;gGC(f|0,9706056,76)|0}c[2438118]=e;c[3528484]=h;c[2417276]=i;c[1836236]=-1;return};default:{return}}}else if((b|0)==6291456){a[9540896]=d&15;return}else{return}}function ffe(a){a=a|0;var d=0;if((a|0)!=2097154){d=0;return d|0}d=b[(c[2442928]|0)+(c[2439392]<<1)>>1]|0;return d|0}function fff(d,e){d=d|0;e=e|0;var f=0,g=0,h=0;f=d-5242880|0;if(f>>>0<16){g=f>>>1;f=g&255;h=e&255;a[9757552+(g&255)|0]=h;if((f<<24>>24|0)==4){g=~h;a[14128520]=g&1;a[14128521]=g&2;return}else if((f<<24>>24|0)==0){c[3531956]=0;return}else{return}}f=d-8388608|0;if(f>>>0<65536){g=(c[3532278]|0)+(f>>>1<<1)|0;do{if((b[g>>1]|0)!=e<<16>>16){if((c[3532284]|0)==0){if(f>>>0<16384){a[14129208]=1}if((d-8421376|0)>>>0<16384){a[14129128]=1}if((d-8413184|0)>>>0>=4096){break}a[14129200]=1;break}else{if(f>>>0<32768){a[14129208]=1}if((d-8421376|0)>>>0<32768){a[14129128]=1}if((d-8458240|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);b[g>>1]=e;return}g=d-8519680|0;if(g>>>0>=16){if((d-8454144|0)>>>0<65536){return}if(!((d|0)==2097152|(d|0)==2097154)){return}f=(d-2097152|0)>>>1;if((f|0)==1){b[(c[2442928]|0)+(c[2439392]<<1)>>1]=e;c[(c[3532276]|0)+(c[2439392]<<2)>>2]=((e&65535)>>>10<<3&248)>>>3|((e&255)<<3&255)<<8|(((e&65535)>>>7&4|(e&65535)>>>5<<3&255)&255)<<3&2016;return}else if((f|0)==0){c[2439392]=(e&65535)>>>1&4095;return}else{return}}f=g>>>1;b[14129152+(f<<1)>>1]=e;switch(f|0){case 6:{c[3532284]=(e&65535)>>>4&1;return};case 2:{c[3527502]=-(e&65535);return};case 4:{c[2385820]=-(e&65535);return};case 3:{c[2388334]=-(e&65535);return};case 7:{c[2439396]=e&1;return};case 0:{c[2388344]=-(e&65535);return};case 1:{c[2385826]=-(e&65535);return};case 5:{c[3527494]=-(e&65535);return};default:{return}}}function ffg(b){b=b|0;var c=0;if((b|0)==5242881){c=a[14128481]|0}else if((b|0)==5767169){c=a[14128480]|0}else if((b|0)==5767171){c=a[14128321]|0}else if((b|0)==5767173){c=a[14128322]|0}else if((b|0)==5242883){c=a[14128320]|0}else{c=0}return c|0}function ffh(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=b-8388608|0;if(e>>>0<65536){f=e^1;g=(c[3532278]|0)+f|0;do{if((a[g]|0)!=d<<24>>24){h=(e|0)>-1;if((c[3532284]|0)==0){if(h&(f|0)<16384){a[14129208]=1}if(h&(f|0)<32768){a[14129128]=1}if((f-24576|0)>>>0>=4096){break}a[14129200]=1;break}else{if(h&(f|0)<32768){a[14129208]=1}if((f-32768|0)>>>0<32768){a[14129128]=1}if((f-69632|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);a[g]=d;return}if((b|0)==6291457){a[9540896]=d&15;return}else if((b|0)==6291459){b=d&15;d=a[9540896]|0;switch(d&255|0){case 3:{a[9540896]=d+1&255;a[9540891]=b;a[9540898]=a[9540898]|2;a[9540900]=1;return};case 2:{a[9540896]=d+1&255;a[9540890]=b;return};case 1:{a[9540896]=d+1&255;a[9540889]=b;a[9540898]=a[9540898]|1;a[9540900]=1;return};case 4:{if(b<<24>>24==0){return}g=c[2439330]|0;f=(g|0)==0;if(!f){e=g;gGC(9706056,e|0,76)|0}e=c[2438118]|0;c[2433530]=e;h=c[3528484]|0;c[2076596]=h;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);if(!f){f=g;gGC(f|0,9706056,76)|0}c[2438118]=e;c[3528484]=h;c[2417276]=i;c[1836236]=-1;return};case 0:{a[9540896]=d+1&255;a[9540888]=b;return};default:{return}}}else{return}}function ffi(a){a=a|0;var b=0;if((a|0)==5767172){b=d[14128322]|0}else if((a|0)==5242882){b=d[14128320]|0}else if((a|0)==5767168){b=d[14128480]|0}else if((a|0)==5242880){b=d[14128481]|0}else if((a|0)==5767170){b=d[14128321]|0}else{b=0}return b|0}function ffj(d,e){d=d|0;e=e|0;var f=0,g=0;f=d-8388608|0;if(f>>>0<65536){g=(c[3532278]|0)+(f>>>1<<1)|0;do{if((b[g>>1]|0)!=e<<16>>16){if((c[3532284]|0)==0){if(f>>>0<16384){a[14129208]=1}if((d-8421376|0)>>>0<16384){a[14129128]=1}if((d-8413184|0)>>>0>=4096){break}a[14129200]=1;break}else{if(f>>>0<32768){a[14129208]=1}if((d-8421376|0)>>>0<32768){a[14129128]=1}if((d-8458240|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);b[g>>1]=e;return}g=d-8519680|0;if(g>>>0>=16){if((d-8454144|0)>>>0<65536){return}if(!((d|0)==2097152|(d|0)==2097154)){return}f=(d-2097152|0)>>>1;if((f|0)==0){c[2439392]=(e&65535)>>>1&4095;return}else if((f|0)==1){b[(c[2442928]|0)+(c[2439392]<<1)>>1]=e;c[(c[3532276]|0)+(c[2439392]<<2)>>2]=((e&65535)>>>10<<3&248)>>>3|((e&255)<<3&255)<<8|(((e&65535)>>>7&4|(e&65535)>>>5<<3&255)&255)<<3&2016;return}else{return}}f=g>>>1;b[14129152+(f<<1)>>1]=e;switch(f|0){case 4:{c[2385820]=-(e&65535);return};case 7:{c[2439396]=e&1;return};case 1:{c[2385826]=-(e&65535);return};case 0:{c[2388344]=-(e&65535);return};case 5:{c[3527494]=-(e&65535);return};case 2:{c[3527502]=-(e&65535);return};case 3:{c[2388334]=-(e&65535);return};case 6:{c[3532284]=(e&65535)>>>4&1;return};default:{return}}}function ffk(b){b=b|0;var c=0,d=0;c=b-2097152|0;L71038:do{if(c>>>0<16){switch(c>>>1|0){case 4:{d=a[9757532]|0;break L71038;break};case 7:{d=a[14128914]|0;break L71038;break};case 1:{d=a[14128921]|0;break L71038;break};case 0:{d=a[14128920]|0;break L71038;break};case 3:{d=a[14128913]|0;break L71038;break};case 2:{d=a[14128912]|0;break L71038;break};default:{d=-1;break L71038}}}else{d=0}}while(0);return d|0}function ffl(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=b-2097152|0;if(e>>>0<16){f=e>>>1;a[9757528+f|0]=d;if((f|0)==4){e=~d;a[14128520]=e&1;a[14128521]=e&2;return}else if((f|0)==0){c[3531956]=0;return}else{return}}f=b-7340032|0;if(f>>>0<65536){e=f^1;g=(c[3532278]|0)+e|0;do{if((a[g]|0)!=d<<24>>24){h=(f|0)>-1;if((c[3532284]|0)==0){if(h&(e|0)<16384){a[14129208]=1}if(h&(e|0)<32768){a[14129128]=1}if((e-24576|0)>>>0>=4096){break}a[14129200]=1;break}else{if(h&(e|0)<32768){a[14129208]=1}if((e-32768|0)>>>0<32768){a[14129128]=1}if((e-69632|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);a[g]=d;return}if((b|0)==3145731){g=d&15;e=a[9540896]|0;switch(e&255|0){case 3:{a[9540896]=e+1&255;a[9540891]=g;a[9540898]=a[9540898]|2;a[9540900]=1;return};case 2:{a[9540896]=e+1&255;a[9540890]=g;return};case 0:{a[9540896]=e+1&255;a[9540888]=g;return};case 1:{a[9540896]=e+1&255;a[9540889]=g;a[9540898]=a[9540898]|1;a[9540900]=1;return};case 4:{if(g<<24>>24==0){return}g=c[2439330]|0;e=(g|0)==0;if(!e){f=g;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;h=c[3528484]|0;c[2076596]=h;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);if(!e){e=g;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=h;c[2417276]=i;c[1836236]=-1;return};default:{return}}}else if((b|0)==3145729){a[9540896]=d&15;return}else{return}}function ffm(a){a=a|0;return 0}function ffn(d,e){d=d|0;e=e|0;var f=0,g=0,h=0;f=d-2097152|0;if(f>>>0<16){g=f>>>1;f=e&255;a[9757528+g|0]=f;if((g|0)==4){h=~f;a[14128520]=h&1;a[14128521]=h&2;return}else if((g|0)==0){c[3531956]=0;return}else{return}}g=d-7340032|0;if(g>>>0<65536){h=(c[3532278]|0)+(g>>>1<<1)|0;do{if((b[h>>1]|0)!=e<<16>>16){if((c[3532284]|0)==0){if(g>>>0<16384){a[14129208]=1}if((d-7372800|0)>>>0<16384){a[14129128]=1}if((d-7364608|0)>>>0>=4096){break}a[14129200]=1;break}else{if(g>>>0<32768){a[14129208]=1}if((d-7372800|0)>>>0<32768){a[14129128]=1}if((d-7409664|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);b[h>>1]=e;return}h=d-7471104|0;if(h>>>0>=16){return}d=h>>>1;b[14129152+(d<<1)>>1]=e;switch(d|0){case 5:{c[3527494]=-(e&65535);return};case 4:{c[2385820]=-(e&65535);return};case 6:{c[3532284]=(e&65535)>>>4&1;return};case 7:{c[2439396]=e&1;return};case 2:{c[3527502]=-(e&65535);return};case 1:{c[2385826]=-(e&65535);return};case 0:{c[2388344]=-(e&65535);return};case 3:{c[2388334]=-(e&65535);return};default:{return}}}function ffo(b){b=b|0;var c=0,d=0;c=b-2097152|0;L71165:do{if(c>>>0<16){switch(c>>>1|0){case 0:{d=a[14128920]|0;break L71165;break};case 1:{d=a[14128921]|0;break L71165;break};case 4:{d=a[9757532]|0;break L71165;break};case 3:{d=a[14128913]|0;break L71165;break};case 7:{d=a[14128914]|0;break L71165;break};case 2:{d=a[14128912]|0;break L71165;break};default:{d=-1;break L71165}}}else{d=0}}while(0);return d|0}function ffp(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=b-2097152|0;if(e>>>0<16){f=e>>>1;a[9757528+f|0]=d;if((f|0)==0){c[3531956]=0;return}else if((f|0)==4){f=~d;a[14128520]=f&1;a[14128521]=f&2;return}else{return}}f=b-7340032|0;if(f>>>0<65536){e=f^1;g=(c[3532278]|0)+e|0;do{if((a[g]|0)!=d<<24>>24){h=(f|0)>-1;if((c[3532284]|0)==0){if(h&(e|0)<16384){a[14129208]=1}if(h&(e|0)<32768){a[14129128]=1}if((e-24576|0)>>>0>=4096){break}a[14129200]=1;break}else{if(h&(e|0)<32768){a[14129208]=1}if((e-32768|0)>>>0<32768){a[14129128]=1}if((e-69632|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);a[g]=d;return}if((b|0)==3145731){g=d&15;e=a[9540896]|0;switch(e&255|0){case 0:{a[9540896]=e+1&255;a[9540888]=g;return};case 3:{a[9540896]=e+1&255;a[9540891]=g;a[9540898]=a[9540898]|2;a[9540900]=1;return};case 1:{a[9540896]=e+1&255;a[9540889]=g;a[9540898]=a[9540898]|1;a[9540900]=1;return};case 2:{a[9540896]=e+1&255;a[9540890]=g;return};case 4:{if(g<<24>>24==0){return}g=c[2439330]|0;e=(g|0)==0;if(!e){f=g;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;h=c[3528484]|0;c[2076596]=h;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);if(!e){e=g;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=h;c[2417276]=i;c[1836236]=-1;return};default:{return}}}else if((b|0)==3145729){a[9540896]=d&15;return}else{return}}function ffq(a){a=a|0;return 0}function ffr(d,e){d=d|0;e=e|0;var f=0,g=0,h=0;f=d-2097152|0;if(f>>>0<16){g=f>>>1;f=e&255;a[9757528+g|0]=f;if((g|0)==4){h=~f;a[14128520]=h&1;a[14128521]=h&2;return}else if((g|0)==0){c[3531956]=0;return}else{return}}g=d-7340032|0;if(g>>>0<65536){h=(c[3532278]|0)+(g>>>1<<1)|0;do{if((b[h>>1]|0)!=e<<16>>16){if((c[3532284]|0)==0){if(g>>>0<16384){a[14129208]=1}if((d-7372800|0)>>>0<16384){a[14129128]=1}if((d-7364608|0)>>>0>=4096){break}a[14129200]=1;break}else{if(g>>>0<32768){a[14129208]=1}if((d-7372800|0)>>>0<32768){a[14129128]=1}if((d-7409664|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);b[h>>1]=e;return}h=d-7471104|0;if(h>>>0>=16){return}d=h>>>1;b[14129152+(d<<1)>>1]=e;switch(d|0){case 6:{c[3532284]=(e&65535)>>>4&1;return};case 7:{c[2439396]=e&1;return};case 3:{c[2388334]=-(e&65535);return};case 1:{c[2385826]=-(e&65535);return};case 0:{c[2388344]=-(e&65535);return};case 2:{c[3527502]=-(e&65535);return};case 4:{c[2385820]=-(e&65535);return};case 5:{c[3527494]=-(e&65535);return};default:{return}}}function ffs(b){b=b|0;var c=0,d=0;L71292:do{if((b|0)==3276803){c=a[14128321]|0}else if((b|0)==3276801){c=a[14128320]|0}else if((b|0)==3145729){c=a[14128480]|0}else if((b|0)==4194306){d=a[9540896]|0;switch(d&255|0){case 2:{a[9540896]=d+1&255;c=a[9540894]|0;break L71292;break};case 0:{a[9540896]=d+1&255;c=a[9540892]|0;break L71292;break};case 1:{a[9540898]=a[9540898]&-5;a[9540896]=d+1&255;c=a[9540893]|0;break L71292;break};case 3:{a[9540898]=a[9540898]&-9;a[9540896]=d+1&255;c=a[9540895]|0;break L71292;break};case 4:{c=a[9540898]|0;break L71292;break};default:{c=0;break L71292}}}else if((b|0)==3145731){c=a[14128481]|0}else if((b|0)==3276805){c=a[14128322]|0}else{c=0}}while(0);return c|0}function fft(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=b-8388608|0;if(e>>>0<65536){f=e^1;g=(c[3532278]|0)+f|0;do{if((a[g]|0)!=d<<24>>24){h=(e|0)>-1;if((c[3532284]|0)==0){if(h&(f|0)<16384){a[14129208]=1}if(h&(f|0)<32768){a[14129128]=1}if((f-24576|0)>>>0>=4096){break}a[14129200]=1;break}else{if(h&(f|0)<32768){a[14129208]=1}if((f-32768|0)>>>0<32768){a[14129128]=1}if((f-69632|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);a[g]=d;return}if((b|0)==4194304){a[9540896]=d&15;return}else if((b|0)==4194306){b=d&15;d=a[9540896]|0;switch(d&255|0){case 0:{a[9540896]=d+1&255;a[9540888]=b;return};case 2:{a[9540896]=d+1&255;a[9540890]=b;return};case 4:{if(b<<24>>24==0){return}g=c[2439330]|0;f=(g|0)==0;if(!f){e=g;gGC(9706056,e|0,76)|0}e=c[2438118]|0;c[2433530]=e;h=c[3528484]|0;c[2076596]=h;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);if(!f){f=g;gGC(f|0,9706056,76)|0}c[2438118]=e;c[3528484]=h;c[2417276]=i;c[1836236]=-1;return};case 3:{a[9540896]=d+1&255;a[9540891]=b;a[9540898]=a[9540898]|2;a[9540900]=1;return};case 1:{a[9540896]=d+1&255;a[9540889]=b;a[9540898]=a[9540898]|1;a[9540900]=1;return};default:{return}}}else{return}}function ffu(a){a=a|0;return 0}function ffv(d,e){d=d|0;e=e|0;var f=0,g=0,h=0;f=d-8388608|0;if(f>>>0<65536){g=(c[3532278]|0)+(f>>>1<<1)|0;do{if((b[g>>1]|0)!=e<<16>>16){if((c[3532284]|0)==0){if(f>>>0<16384){a[14129208]=1}if((d-8421376|0)>>>0<16384){a[14129128]=1}if((d-8413184|0)>>>0>=4096){break}a[14129200]=1;break}else{if(f>>>0<32768){a[14129208]=1}if((d-8421376|0)>>>0<32768){a[14129128]=1}if((d-8458240|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);b[g>>1]=e;return}g=d-8519680|0;if(g>>>0>=16){f=d-11534336|0;if(f>>>0<32){a[14128984+(f>>>1)|0]=e&255;return}switch(d|0){case 5242894:case 5242892:case 5242890:case 5242880:case 5242882:case 5242884:case 5242886:case 5242888:{break};default:{return}}f=d-5242880|0;d=f>>>1;if(f>>>0<4){return}if(f>>>0<8){f=d<<1&2;h=(e&65535)<<11;b[14128416+(f<<1)>>1]=h&65535;b[14128416+((f|1)<<1)>>1]=(h|1024)&65535;return}else{b[14128416+(d<<1)>>1]=e<<10;return}}d=g>>>1;b[14129152+(d<<1)>>1]=e;switch(d|0){case 3:{c[2388334]=-(e&65535);return};case 5:{c[3527494]=-(e&65535);return};case 7:{c[2439396]=e&1;return};case 6:{c[3532284]=(e&65535)>>>4&1;return};case 1:{c[2385826]=-(e&65535);return};case 0:{c[2388344]=-(e&65535);return};case 2:{c[3527502]=-(e&65535);return};case 4:{c[2385820]=-(e&65535);return};default:{return}}}function ffw(b){b=b|0;var c=0,d=0,e=0;c=b-1048576|0;L71420:do{if(c>>>0<16){switch(c>>>1|0){case 1:{d=a[14128921]|0;break L71420;break};case 7:{d=a[14128914]|0;break L71420;break};case 3:{d=a[14128913]|0;break L71420;break};case 2:{d=a[14128912]|0;break L71420;break};case 4:{d=a[9757532]|0;break L71420;break};case 0:{d=a[14128920]|0;break L71420;break};default:{d=-1;break L71420}}}else{if((b|0)!=4194306){d=0;break}e=a[9540896]|0;switch(e&255|0){case 0:{a[9540896]=e+1&255;d=a[9540892]|0;break L71420;break};case 1:{a[9540898]=a[9540898]&-5;a[9540896]=e+1&255;d=a[9540893]|0;break L71420;break};case 4:{d=a[9540898]|0;break L71420;break};case 2:{a[9540896]=e+1&255;d=a[9540894]|0;break L71420;break};case 3:{a[9540898]=a[9540898]&-9;a[9540896]=e+1&255;d=a[9540895]|0;break L71420;break};default:{d=0;break L71420}}}}while(0);return d|0}function ffx(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=b-1048576|0;if(e>>>0<16){f=e>>>1;a[9757528+f|0]=d;if((f|0)==0){c[3531956]=0;return}else if((f|0)==4){f=~d;a[14128520]=f&1;a[14128521]=f&2;return}else{return}}f=b-6291456|0;if(f>>>0<65536){e=f^1;g=(c[3532278]|0)+e|0;do{if((a[g]|0)!=d<<24>>24){h=(f|0)>-1;if((c[3532284]|0)==0){if(h&(e|0)<16384){a[14129208]=1}if(h&(e|0)<32768){a[14129128]=1}if((e-24576|0)>>>0>=4096){break}a[14129200]=1;break}else{if(h&(e|0)<32768){a[14129208]=1}if((e-32768|0)>>>0<32768){a[14129128]=1}if((e-69632|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);a[g]=d;return}if((b|0)==4194306){g=d&15;e=a[9540896]|0;switch(e&255|0){case 1:{a[9540896]=e+1&255;a[9540889]=g;a[9540898]=a[9540898]|1;a[9540900]=1;return};case 2:{a[9540896]=e+1&255;a[9540890]=g;return};case 3:{a[9540896]=e+1&255;a[9540891]=g;a[9540898]=a[9540898]|2;a[9540900]=1;return};case 4:{if(g<<24>>24==0){return}f=c[2439330]|0;h=(f|0)==0;if(!h){i=f;gGC(9706056,i|0,76)|0}i=c[2438118]|0;c[2433530]=i;j=c[3528484]|0;c[2076596]=j;k=c[2417276]|0;c[3541536]=k;c[1836236]=0;gGz(9706056,0,76);if(!h){h=f;gGC(h|0,9706056,76)|0}c[2438118]=i;c[3528484]=j;c[2417276]=k;c[1836236]=-1;return};case 0:{a[9540896]=e+1&255;a[9540888]=g;return};default:{return}}}else if((b|0)==4194304){a[9540896]=d&15;return}else{return}}function ffy(a){a=a|0;return 0}function ffz(e,f){e=e|0;f=f|0;var g=0,h=0,i=0,j=0;g=e-1048576|0;if(g>>>0<16){h=g>>>1;g=f&255;a[9757528+h|0]=g;if((h|0)==0){c[3531956]=0;return}else if((h|0)==4){h=~g;a[14128520]=h&1;a[14128521]=h&2;return}else{return}}h=e-6291456|0;if(h>>>0<65536){g=h^1;i=(c[3532278]|0)+g|0;do{if((d[i]|0|0)!=(f&65535|0)){j=(h|0)>-1;if((c[3532284]|0)==0){if(j&(g|0)<16384){a[14129208]=1}if(j&(g|0)<32768){a[14129128]=1}if((g-24576|0)>>>0>=4096){break}a[14129200]=1;break}else{if(j&(g|0)<32768){a[14129208]=1}if((g-32768|0)>>>0<32768){a[14129128]=1}if((g-69632|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);a[i]=f&255;return}i=e-6422528|0;if(i>>>0>=16){return}e=i>>>1;b[14129152+(e<<1)>>1]=f;switch(e|0){case 2:{c[3527502]=-(f&65535);return};case 3:{c[2388334]=-(f&65535);return};case 6:{c[3532284]=(f&65535)>>>4&1;return};case 1:{c[2385826]=-(f&65535);return};case 5:{c[3527494]=-(f&65535);return};case 4:{c[2385820]=-(f&65535);return};case 0:{c[2388344]=-(f&65535);return};case 7:{c[2439396]=f&1;return};default:{return}}}function ffA(b){b=b|0;var c=0,d=0;c=b-2097152|0;L71555:do{if(c>>>0<16){switch(c>>>1&255|0){case 7:{d=a[14129042]|0;break L71555;break};case 0:{d=a[14129048]|0;break L71555;break};case 2:{d=a[14129040]|0;break L71555;break};case 1:{d=a[14129049]|0;break L71555;break};case 3:{d=a[14129041]|0;break L71555;break};case 4:{d=a[9757556]|0;break L71555;break};default:{d=0;break L71555}}}else{d=0}}while(0);return d|0}function ffB(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=b-2097152|0;if(e>>>0<16){f=e>>>1;e=f&255;a[9757552+(f&255)|0]=d;if((e<<24>>24|0)==4){f=~d;a[14128520]=f&1;a[14128521]=f&2;return}else if((e<<24>>24|0)==0){c[3531956]=0;return}else{return}}e=b-4194304|0;if(e>>>0<65536){f=e^1;g=(c[3532278]|0)+f|0;do{if((a[g]|0)!=d<<24>>24){h=(e|0)>-1;if((c[3532284]|0)==0){if(h&(f|0)<16384){a[14129208]=1}if(h&(f|0)<32768){a[14129128]=1}if((f-24576|0)>>>0>=4096){break}a[14129200]=1;break}else{if(h&(f|0)<32768){a[14129208]=1}if((f-32768|0)>>>0<32768){a[14129128]=1}if((f-69632|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);a[g]=d;return}g=b-8388608|0;if(g>>>0<32){a[14128984+(g>>>1)|0]=d;return}if((b|0)==2228226){g=d&15;f=a[9540896]|0;switch(f&255|0){case 4:{if(g<<24>>24==0){return}e=c[2439330]|0;h=(e|0)==0;if(!h){i=e;gGC(9706056,i|0,76)|0}i=c[2438118]|0;c[2433530]=i;j=c[3528484]|0;c[2076596]=j;k=c[2417276]|0;c[3541536]=k;c[1836236]=0;gGz(9706056,0,76);if(!h){h=e;gGC(h|0,9706056,76)|0}c[2438118]=i;c[3528484]=j;c[2417276]=k;c[1836236]=-1;return};case 2:{a[9540896]=f+1&255;a[9540890]=g;return};case 3:{a[9540896]=f+1&255;a[9540891]=g;a[9540898]=a[9540898]|2;a[9540900]=1;return};case 1:{a[9540896]=f+1&255;a[9540889]=g;a[9540898]=a[9540898]|1;a[9540900]=1;return};case 0:{a[9540896]=f+1&255;a[9540888]=g;return};default:{return}}}else if((b|0)==2228224){a[9540896]=d&15;return}else{return}}function ffC(b){b=b|0;var c=0,d=0,e=0;c=b-2097152|0;if(c>>>0>=16){d=0;return d|0}switch(c>>>1&255|0){case 1:{e=a[14129049]|0;break};case 3:{e=a[14129041]|0;break};case 0:{e=a[14129048]|0;break};case 2:{e=a[14129040]|0;break};case 4:{e=a[9757556]|0;break};case 7:{e=a[14129042]|0;break};default:{e=0}}d=e&255;return d|0}function ffD(d,e){d=d|0;e=e|0;var f=0,g=0,h=0;f=d-2097152|0;if(f>>>0<16){g=f>>>1;f=g&255;h=e&255;a[9757552+(g&255)|0]=h;if((f<<24>>24|0)==0){c[3531956]=0;return}else if((f<<24>>24|0)==4){f=~h;a[14128520]=f&1;a[14128521]=f&2;return}else{return}}f=d-4194304|0;if(f>>>0<65536){h=(c[3532278]|0)+(f>>>1<<1)|0;do{if((b[h>>1]|0)!=e<<16>>16){if((c[3532284]|0)==0){if(f>>>0<16384){a[14129208]=1}if((d-4227072|0)>>>0<16384){a[14129128]=1}if((d-4218880|0)>>>0>=4096){break}a[14129200]=1;break}else{if(f>>>0<32768){a[14129208]=1}if((d-4227072|0)>>>0<32768){a[14129128]=1}if((d-4263936|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);b[h>>1]=e;return}h=d-4325376|0;if(h>>>0<16){f=h>>>1;b[14129152+(f<<1)>>1]=e;switch(f|0){case 2:{c[3527502]=-(e&65535);return};case 4:{c[2385820]=-(e&65535);return};case 3:{c[2388334]=-(e&65535);return};case 0:{c[2388344]=-(e&65535);return};case 5:{c[3527494]=-(e&65535);return};case 6:{c[3532284]=(e&65535)>>>4&1;return};case 7:{c[2439396]=e&1;return};case 1:{c[2385826]=-(e&65535);return};default:{return}}}f=d-5242880|0;if(f>>>0<65536){h=(c[3532279]|0)+(f>>>1<<1)|0;do{if((b[h>>1]|0)!=e<<16>>16){if((c[3532285]|0)==0){if(f>>>0<16384){a[14129209]=1}if((d-5275648|0)>>>0<16384){a[14129129]=1}if((d-5267456|0)>>>0>=4096){break}a[14129201]=1;break}else{if(f>>>0<32768){a[14129209]=1}if((d-5275648|0)>>>0<32768){a[14129129]=1}if((d-5312512|0)>>>0>=4096){break}a[14129201]=1;break}}}while(0);b[h>>1]=e;return}h=d-5373952|0;if(h>>>0>=16){return}d=h>>>1;b[14129168+(d<<1)>>1]=e;switch(d|0){case 6:{c[3532285]=(e&65535)>>>4&1;return};case 3:{c[2388335]=-(e&65535);return};case 4:{c[2385821]=-(e&65535);return};case 5:{c[3527495]=-(e&65535);return};case 0:{c[2388345]=-(e&65535);return};case 1:{c[2385827]=-(e&65535);return};case 7:{c[2439397]=e&1;return};case 2:{c[3527503]=-(e&65535);return};default:{return}}}function ffE(b){b=b|0;var c=0,d=0;L71743:do{if((b-7340032|0)>>>0<32){c=0}else{if((b|0)==10485761){c=a[14128320]|0;break}else if((b|0)!=8388610){c=0;break}d=a[9540896]|0;switch(d&255|0){case 4:{c=a[9540898]|0;break L71743;break};case 2:{a[9540896]=d+1&255;c=a[9540894]|0;break L71743;break};case 1:{a[9540898]=a[9540898]&-5;a[9540896]=d+1&255;c=a[9540893]|0;break L71743;break};case 3:{a[9540898]=a[9540898]&-9;a[9540896]=d+1&255;c=a[9540895]|0;break L71743;break};case 0:{a[9540896]=d+1&255;c=a[9540892]|0;break L71743;break};default:{c=0;break L71743}}}}while(0);return c|0}function ffF(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=b-5242880|0;if(e>>>0<65536){f=e^1;g=(c[3532278]|0)+f|0;do{if((a[g]|0)!=d<<24>>24){h=(e|0)>-1;if((c[3532284]|0)==0){if(h&(f|0)<16384){a[14129208]=1}if(h&(f|0)<32768){a[14129128]=1}if((f-24576|0)>>>0>=4096){break}a[14129200]=1;break}else{if(h&(f|0)<32768){a[14129208]=1}if((f-32768|0)>>>0<32768){a[14129128]=1}if((f-69632|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);a[g]=d;return}if((b|0)==8388610){g=d&15;f=a[9540896]|0;switch(f&255|0){case 3:{a[9540896]=f+1&255;a[9540891]=g;a[9540898]=a[9540898]|2;a[9540900]=1;return};case 2:{a[9540896]=f+1&255;a[9540890]=g;return};case 1:{a[9540896]=f+1&255;a[9540889]=g;a[9540898]=a[9540898]|1;a[9540900]=1;return};case 0:{a[9540896]=f+1&255;a[9540888]=g;return};case 4:{if(g<<24>>24==0){return}g=c[2439330]|0;f=(g|0)==0;if(!f){e=g;gGC(9706056,e|0,76)|0}e=c[2438118]|0;c[2433530]=e;h=c[3528484]|0;c[2076596]=h;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);if(!f){f=g;gGC(f|0,9706056,76)|0}c[2438118]=e;c[3528484]=h;c[2417276]=i;c[1836236]=-1;return};default:{return}}}else if((b|0)==8388608){a[9540896]=d&15;return}else{return}}function ffG(a){a=a|0;var b=0,e=0;do{if((a|0)==11534336){b=c[2405144]|0;c[2405144]=1-b;if((b|0)==1){e=d[14128481]|0;break}else{e=d[14128480]|0;break}}else if((a|0)==10485764){e=d[14128321]|0}else{e=0}}while(0);return e|0}function ffH(d,e){d=d|0;e=e|0;var f=0,g=0;f=d-5242880|0;if(f>>>0<65536){g=(c[3532278]|0)+(f>>>1<<1)|0;do{if((b[g>>1]|0)!=e<<16>>16){if((c[3532284]|0)==0){if(f>>>0<16384){a[14129208]=1}if((d-5275648|0)>>>0<16384){a[14129128]=1}if((d-5267456|0)>>>0>=4096){break}a[14129200]=1;break}else{if(f>>>0<32768){a[14129208]=1}if((d-5275648|0)>>>0<32768){a[14129128]=1}if((d-5312512|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);b[g>>1]=e;return}g=d-5373952|0;if(g>>>0>=16){return}d=g>>>1;b[14129152+(d<<1)>>1]=e;switch(d|0){case 5:{c[3527494]=-(e&65535);return};case 0:{c[2388344]=-(e&65535);return};case 3:{c[2388334]=-(e&65535);return};case 7:{c[2439396]=e&1;return};case 1:{c[2385826]=-(e&65535);return};case 2:{c[3527502]=-(e&65535);return};case 4:{c[2385820]=-(e&65535);return};case 6:{c[3532284]=(e&65535)>>>4&1;return};default:{return}}}function ffI(b){b=b|0;var c=0,d=0,e=0;c=b-2097152|0;L71861:do{if(c>>>0<16){switch(c>>>1|0){case 1:{d=a[14128921]|0;break L71861;break};case 2:{d=a[14128912]|0;break L71861;break};case 7:{d=a[14128914]|0;break L71861;break};case 4:{d=a[9757532]|0;break L71861;break};case 3:{d=a[14128913]|0;break L71861;break};case 0:{d=a[14128920]|0;break L71861;break};default:{d=-1;break L71861}}}else{if((b|0)!=4194306){d=0;break}e=a[9540896]|0;switch(e&255|0){case 3:{a[9540898]=a[9540898]&-9;a[9540896]=e+1&255;d=a[9540895]|0;break L71861;break};case 2:{a[9540896]=e+1&255;d=a[9540894]|0;break L71861;break};case 0:{a[9540896]=e+1&255;d=a[9540892]|0;break L71861;break};case 1:{a[9540898]=a[9540898]&-5;a[9540896]=e+1&255;d=a[9540893]|0;break L71861;break};case 4:{d=a[9540898]|0;break L71861;break};default:{d=0;break L71861}}}}while(0);return d|0}function ffJ(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=b-2097152|0;if(e>>>0<16){f=e>>>1;a[9757528+f|0]=d;if((f|0)==0){c[3531956]=0;return}else if((f|0)==4){f=~d;a[14128520]=f&1;a[14128521]=f&2;return}else{return}}f=b-8388608|0;if(f>>>0<65536){e=f^1;g=(c[3532278]|0)+e|0;do{if((a[g]|0)!=d<<24>>24){h=(f|0)>-1;if((c[3532284]|0)==0){if(h&(e|0)<16384){a[14129208]=1}if(h&(e|0)<32768){a[14129128]=1}if((e-24576|0)>>>0>=4096){break}a[14129200]=1;break}else{if(h&(e|0)<32768){a[14129208]=1}if((e-32768|0)>>>0<32768){a[14129128]=1}if((e-69632|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);a[g]=d;return}if((b|0)==4194306){g=d&15;e=a[9540896]|0;switch(e&255|0){case 3:{a[9540896]=e+1&255;a[9540891]=g;a[9540898]=a[9540898]|2;a[9540900]=1;return};case 0:{a[9540896]=e+1&255;a[9540888]=g;return};case 1:{a[9540896]=e+1&255;a[9540889]=g;a[9540898]=a[9540898]|1;a[9540900]=1;return};case 4:{if(g<<24>>24==0){return}f=c[2439330]|0;h=(f|0)==0;if(!h){i=f;gGC(9706056,i|0,76)|0}i=c[2438118]|0;c[2433530]=i;j=c[3528484]|0;c[2076596]=j;k=c[2417276]|0;c[3541536]=k;c[1836236]=0;gGz(9706056,0,76);if(!h){h=f;gGC(h|0,9706056,76)|0}c[2438118]=i;c[3528484]=j;c[2417276]=k;c[1836236]=-1;return};case 2:{a[9540896]=e+1&255;a[9540890]=g;return};default:{return}}}else if((b|0)==4194304){a[9540896]=d&15;return}else{return}}function ffK(a){a=a|0;return 0}function ffL(d,e){d=d|0;e=e|0;var f=0,g=0;f=d-2097152|0;if(f>>>0<16){g=f>>>1;f=e&255;a[9757528+g|0]=f;if((g|0)==0){c[3531956]=0;return}else if((g|0)==4){g=~f;a[14128520]=g&1;a[14128521]=g&2;return}else{return}}g=d-8388608|0;if(g>>>0<65536){f=(c[3532278]|0)+(g>>>1<<1)|0;do{if((b[f>>1]|0)!=e<<16>>16){if((c[3532284]|0)==0){if(g>>>0<16384){a[14129208]=1}if((d-8421376|0)>>>0<16384){a[14129128]=1}if((d-8413184|0)>>>0>=4096){break}a[14129200]=1;break}else{if(g>>>0<32768){a[14129208]=1}if((d-8421376|0)>>>0<32768){a[14129128]=1}if((d-8458240|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);b[f>>1]=e;return}f=d-8519680|0;if(f>>>0>=16){return}d=f>>>1;b[14129152+(d<<1)>>1]=e;switch(d|0){case 5:{c[3527494]=-(e&65535);return};case 2:{c[3527502]=-(e&65535);return};case 7:{c[2439396]=e&1;return};case 1:{c[2385826]=-(e&65535);return};case 3:{c[2388334]=-(e&65535);return};case 0:{c[2388344]=-(e&65535);return};case 6:{c[3532284]=(e&65535)>>>4&1;return};case 4:{c[2385820]=-(e&65535);return};default:{return}}}function ffM(b){b=b|0;var d=0,e=0,f=0.0,g=0.0,i=0,j=0,k=0;d=b&65535;if((d|0)==57344){b=c[3541514]|0;e=b+552|0;f=+h[e>>3];do{if(f!=0.0){g=+h[6675];if(f-(g+ +gC[c[2429842]&255]())>0.0){i=a[b+563|0]|-128;break}else{h[e>>3]=0.0;j=55238;break}}else{j=55238}}while(0);if((j|0)==55238){i=a[b+563|0]|0}k=i&-125;return k|0}else if((d|0)==57346){k=a[(c[3541514]|0)+20904|0]|0;return k|0}else if((d|0)==57857){k=fdZ()|0;return k|0}else{k=0;return k|0}return 0}function ffN(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;switch(b&65535|0){case 57347:{l7(3,d);return};case 57346:{b=c[3541514]|0;a[b+560|0]=d;a[b+20408|0]=1;return};case 57857:{fd_(d);return};case 57345:{l7(1,d);return};case 57344:{b=c[3541514]|0;a[b+560|0]=d;a[b+20408|0]=0;if((d&255)>=16){return}c[14168912+((c[2383582]|0)*252|0)>>2]=d&15;return};case 61952:{b=d+7&7;a[14127752]=b;e=c[3531932]|0;f=(b&255)<<14;b=c[9757320+(c[1836236]<<2)>>2]|0;g=64;h=64;while(1){c[b+76+(h<<2)>>2]=e+((h<<8)+f);i=g+1&65535;if((i&65535)>127){j=64;k=64;break}else{g=i;h=i&65535}}while(1){h=e+((k<<8)+f)|0;c[b+76+(k+512<<2)>>2]=h;c[b+76+(k+768<<2)>>2]=h;h=j+1&65535;if((h&65535)>127){break}else{j=h;k=h&65535}}return};case 57856:{a[9540897]=d&15;return};default:{return}}}function ffO(b){b=b|0;var d=0,e=0,f=0.0,g=0.0,i=0;d=b&65535;if((d|0)==36864){b=c[3541518]|0;e=b+296|0;f=+h[e>>3];do{if(f!=0.0){g=+h[6675];if(f-(g+ +gC[c[2429842]&255]())<=0.0){h[e>>3]=0.0;break}i=a[b+307|0]|-128;return i|0}}while(0);i=a[b+307|0]|0;return i|0}else if((d|0)==45056){i=c[2113156]&255;return i|0}else if((d|0)==40961){i=fdZ()|0;return i|0}else{i=0;return i|0}return 0}function ffP(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=b&65535;if((e|0)==36864){b=c[3541518]|0;f=b+256|0;a[b+304|0]=d;g=d&255;if((d&255)<16){c[14168912+((c[2383582]|0)*252|0)>>2]=g&15}if((d-45&255)>=3){return}if((g|0)==46){h=b+312|0;i=a[h]|1;a[h]=i;j=i}else if((g|0)==45){i=b+312|0;h=a[i]|2;a[i]=h;j=h}else if((g|0)==0){a[b+312|0]=2;j=2}else if((g|0)==47){a[b+312|0]=0;j=0}else{j=a[b+312|0]|0}b=j&3;j=c[7461744+(b<<2)>>2]|0;lI(f,j,j,c[7461728+(b<<2)>>2]|0);return}else if((e|0)==40960){a[9540897]=d&15;return}else if((e|0)==45056|(e|0)==45057){Uv(0,d);return}else if((e|0)==36865){lS(0,1,d);return}else if((e|0)==40961){fd_(d);return}else{return}}function ffQ(b){b=b|0;var d=0,e=0;d=b&65535;if((d|0)==38912){e=c[2113156]&255}else if((d|0)==40960){e=a[14128024]|0}else{e=0}return e|0}function ffR(a,b){a=a|0;b=b|0;var d=0;d=a&65535;if((d|0)==38912){Uv(0,b);return}else if((d|0)==36864){d=b&255;if((d&4|0)==0){return}b=d&3;c[2437780]=b;d=c[3541206]|0;a=(c[3532056]|0)+(b<<18)|0;gGC(d|0,a|0,262144)|0;return}else{return}}function ffS(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0;f=c[3532092]|0;g=c[3532088]|0;h=c[3532086]|0;i=c[3532094]|0;j=c[3531966]|0;k=j;l=c[3531978]|0;m=c[3532100]|0;gGz(m|0,0,36864);n=c[3531954]|0;o=c[3532090]|0;p=-n|0;q=(o|0)==0?n:p;do{if((i|0)==32768){if((b[j+32774>>1]|0)!=0){r=32768;break}r=(b[j+32778>>1]|0)==0?0:32768}else{r=i}}while(0);i=a[642488]|0;j=c[3532096]|0;s=0;t=0;u=0;v=0;w=0;x=0;y=0;z=0;A=0;B=0;C=0;D=0;E=0;F=0;G=q;q=f;f=g;g=h;h=r;r=0;H=0;I=m;m=0;J=o;while(1){o=h+r|0;K=b[k+(((o+6|0)/2|0)<<1)>>1]|0;do{if(K<<16>>16<0){L=e[k+(((o+10|0)/2|0)<<1)>>1]|0;M=L&4096;N=L&8192;c[3532090]=N;O=(N|0)==0?n:p;if(i){P=(K&65535)<<15&32768;Q=M;R=O;S=N;break}else{P=L<<15&32768;Q=M;R=O;S=N;break}}else{P=h;Q=q;R=G;S=J}}while(0);N=e[k+(((o+4|0)/2|0)<<1)>>1]|0;O=N&61440;do{if((O|0)==20480){M=N&4095;L=M>>>0>2047?N|-4096:M;M=K&65535;T=M&4095;if(T>>>0<=2047){U=T;V=L;W=f;X=g;break}U=M|-4096;V=L;W=f;X=g}else if((O|0)==40960){L=N&4095;M=L>>>0>2047?N|-4096:L;L=K&65535;T=L&4095;if(T>>>0<=2047){U=D;V=C;W=M;X=T;break}U=D;V=C;W=M;X=L|-4096}else{U=D;V=C;W=f;X=g}}while(0);do{if((Q|0)==0){O=e[k+(((o+8|0)/2|0)<<1)>>1]|0;L=O>>>8;M=(v|0)==0;if((L&8|0)==0){T=M&1^1;Y=(L&4|0)==0?O&255:s;if(M){Z=0;_=w;$=x;aa=y;ab=z;ac=T;ad=A;ae=B;af=Y;ah=1;ai=55338}else{aj=v;ak=w;al=x;am=y;an=z;ao=T;ap=A;aq=B;ar=Y;as=0;ai=55337}}else{if(M){M=e[k+(((o+2|0)/2|0)<<1)>>1]|0;at=M>>>8;au=M&255;av=K&4095;aw=N&4095;ax=0;ay=0;az=1}else{at=B;au=A;av=z;aw=y;ax=x;ay=w;az=v}aj=az;ak=ay;al=ax;am=aw;an=av;ao=0;ap=au;aq=at;ar=(L&4|0)==0?O&255:s;as=(az|0)==0;ai=55337}L72120:do{if((ai|0)==55337){ai=0;if((L&240|0)==0){Z=aj;_=ak;$=al;aa=am;ab=an;ac=ao;ad=ap;ae=aq;af=ar;ah=as;ai=55338;break}do{if((L&16|0)==0){aA=u;aB=ak}else{if((L&32|0)==0){aA=H;aB=ak;break}aA=H+16|0;aB=ak+1|0}}while(0);do{if((L&64|0)==0){aC=t}else{if((L&128|0)==0){aC=m;break}O=m+16|0;M=al+1|0;if(as){aD=ar;aE=aq;aF=ap;aG=ao;aH=an;aI=am;aJ=aj;aK=t;aL=u;aM=0;aN=M;aO=E;aP=F;aQ=aA;aR=O;ai=55351;break L72120}else{aS=ar;aT=aq;aU=ap;aV=ao;aW=an;aX=am;aY=aj;aZ=t;a_=u;a$=0;a0=M;a1=E;a2=F;a3=aA;a4=O;ai=55349;break L72120}}}while(0);if(as){aD=ar;aE=aq;aF=ap;aG=ao;aH=an;aI=am;aJ=aj;aK=t;aL=u;aM=aB;aN=al;aO=E;aP=F;aQ=aA;aR=aC;ai=55351}else{aS=ar;aT=aq;aU=ap;aV=ao;aW=an;aX=am;aY=aj;aZ=t;a_=u;a$=aB;a0=al;a1=E;a2=F;a3=aA;a4=aC;ai=55349}}}while(0);if((ai|0)==55338){ai=0;do{if((N&32768|0)==0){if((N&16384|0)!=0){a5=X;a6=W;break}a5=U+X|0;a6=V+W|0}else{a5=0;a6=0}}while(0);O=a6-R-96|0;M=N&4095;Y=K&4095;if(ah){aD=af;aE=ae;aF=ad;aG=ac;aH=ab;aI=aa;aJ=Z;aK=M;aL=Y;aM=_;aN=$;aO=O;aP=a5;aQ=Y;aR=M;ai=55351}else{aS=af;aT=ae;aU=ad;aV=ac;aW=ab;aX=aa;aY=Z;aZ=M;a_=Y;a$=_;a0=$;a1=O;a2=a5;a3=Y;a4=M;ai=55349}}do{if((ai|0)==55349){ai=0;if((aT|aU|0)==0){a7=a4;a8=a3;a9=16;ba=16;bb=aS;bc=aT;bd=aU;be=aV;bf=aW;bg=aX;bh=aY;bi=aZ;bj=a_;bk=a$;bl=a0;bm=a1;bn=a2;break}M=256-aU|0;Y=(((ag(M,a0)|0)+12|0)>>>4)+aX|0;O=256-aT|0;T=(((ag(O,a$)|0)+12|0)>>>4)+aW|0;bo=(((ag(M,a0+1|0)|0)+12|0)>>>4)+aX-Y|0;a7=Y;a8=T;a9=(((ag(O,a$+1|0)|0)+12|0)>>>4)+aW-T|0;ba=bo;bb=aS;bc=aT;bd=aU;be=aV;bf=aW;bg=aX;bh=aY;bi=aZ;bj=a_;bk=a$;bl=a0;bm=a1;bn=a2}else if((ai|0)==55351){ai=0;bo=e[k+(((o+2|0)/2|0)<<1)>>1]|0;a7=aR;a8=aQ;a9=(256-(bo>>>8)|0)>>>4;ba=(256-(bo&255)|0)>>>4;bb=aD;bc=aE;bd=aF;be=aG;bf=aH;bg=aI;bh=aJ;bi=aK;bj=aL;bk=aM;bl=aN;bm=aO;bn=aP}}while(0);bo=(be|0)==0?bh:0;T=(o|0)>32767?o-16384|0:o;if((j|0)==2){bp=b[l+(T>>4<<1)>>1]&65280|b[k+(((o|0)/2|0)<<1)>>1]&255}else if((j|0)==0){O=e[k+(((o|0)/2|0)<<1)>>1]|0;bp=(e[14128432+((O>>>10&7)<<1)>>1]|0)+(O&1023)|0}else if((j|0)==1){bp=e[l+(T>>4<<1)>>1]<<10&64512|b[k+(((o|0)/2|0)<<1)>>1]&1023}else if((j|0)==3){bp=e[l+(T>>4<<1)>>1]<<8&65280|b[k+(((o|0)/2|0)<<1)>>1]&255}else{bq=a7;br=I;bs=a8;bt=bn;bu=bm;bv=bc;bw=bd;bx=bf;by=bg;bz=bl;bA=bk;bB=bo;bC=bj;bD=bi;bE=bb;break}if((bp|0)==0){bq=a7;br=I;bs=a8;bt=bn;bu=bm;bv=bc;bw=bd;bx=bf;by=bg;bz=bl;bA=bk;bB=bo;bC=bj;bD=bi;bE=bb;break}T=a7+bm|0;O=T&4095;Y=a8+bn|0;M=Y&4095;c[I>>2]=bp;c[I+4>>2]=O>>>0>2047?T|-4096:O;c[I+8>>2]=((S|0)==0?-16:16)+(M>>>0>2047?Y|-4096:M);c[I+12>>2]=bb;c[I+16>>2]=L&1;c[I+20>>2]=L&2;c[I+24>>2]=ba<<12;c[I+28>>2]=a9<<12;c[I+32>>2]=d[14128392+(bb>>>6&3)|0]|0;bq=a7;br=I+36|0;bs=a8;bt=bn;bu=bm;bv=bc;bw=bd;bx=bf;by=bg;bz=bl;bA=bk;bB=bo;bC=bj;bD=bi;bE=bb}else{bq=m;br=I;bs=H;bt=F;bu=E;bv=B;bw=A;bx=z;by=y;bz=x;bA=w;bB=v;bC=u;bD=t;bE=s}}while(0);o=r+16|0;if((o|0)<16384){s=bE;t=bD;u=bC;v=bB;w=bA;x=bz;y=by;z=bx;A=bw;B=bv;C=V;D=U;E=bu;F=bt;G=R;q=Q;f=W;g=X;h=P;r=o;H=bs;I=br;m=bq;J=S}else{break}}return}function ffT(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;g=c[3532100]|0;h=c[3531962]|0;i=c[3532034]|0;j=a[7460944]|0?16:0;k=c[3532004]|0;l=(c[3532090]|0)==0;m=j<<16;n=k<<16;o=c[2113068]|0;p=c[2113070]|0;q=c[2112926]|0;r=c[3532102]|0;s=(r|0)==0;t=a[7461096]|0;u=c[3532024]|0;v=r&192;r=0;do{L72154:do{if((c[g+(r*36|0)+32>>2]|0)==(f|0)){w=c[g+(r*36|0)+4>>2]|0;x=c[g+(r*36|0)+8>>2]|0;y=c[g+(r*36|0)+12>>2]|0;z=c[g+(r*36|0)+16>>2]|0;A=c[g+(r*36|0)+20>>2]|0;B=c[g+(r*36|0)+24>>2]|0;C=c[g+(r*36|0)+28>>2]|0;D=ag(ag(j,((c[g+(r*36|0)>>2]|0)>>>0)%(i>>>0)|0)|0,k)|0;E=((ag(k,C)|0)+32768|0)>>>16;F=((ag(j,B)|0)+32768|0)>>>16;G=((y|0)%256|0)<<4;if(l){H=w;I=x;J=z;K=A}else{H=320-w-(B>>12)|0;I=256-x-(C>>12)|0;J=(z|0)==0|0;K=(A|0)==0|0}if((F|0)==0|(E|0)==0){break}A=(m>>>0)/(F>>>0)|0;z=(n>>>0)/(E>>>0)|0;C=H+F|0;x=I+E|0;if((J|0)==0){L=A;M=0}else{L=-A|0;M=ag(A,F-1|0)|0}if((K|0)==0){N=z;O=0}else{N=-z|0;O=ag(z,E-1|0)|0}if((H|0)<0){P=0;Q=M-(ag(L,H)|0)|0}else{P=H;Q=M}if((I|0)<0){R=0;S=O-(ag(N,I)|0)|0}else{R=I;S=O}E=(C|0)>(o|0)?o:C;C=(x|0)>(p|0)?p:x;if((E|0)>(P|0)&(R|0)<(C|0)){T=S;U=R}else{break}while(1){x=(ag(T>>16,j)|0)+D|0;z=ag(U,o)|0;F=P;A=Q;while(1){B=a[h+(x+(A>>16))|0]|0;w=B&255;L72176:do{if(B<<24>>24!=0){if(s){b[q+(F+z<<1)>>1]=(w|G)&65535;break}do{if(t){y=a[u+(z+F)|0]|0;if((y<<24>>24|0)==2){V=d[14128337]|0;break}else if((y<<24>>24|0)==1){V=d[14128336]|0;break}else if((y<<24>>24|0)==4){V=d[14128338]|0;break}else{V=0;break}}else{V=0}}while(0);do{if((v|0)==192){if((V-1|0)==(f|0)){y=q+(F+z<<1)|0;b[y>>1]=(b[y>>1]&15|(w|G)&65520)&65535;break L72176}if((V+1|0)!=(f|0)){break}y=q+(F+z<<1)|0;W=e[y>>1]|0;if((W&15|0)==0){b[y>>1]=(w|G)&65535;break L72176}else{b[y>>1]=(W&65520|w&15)&65535;break L72176}}else if((v|0)==128){if((V-1|0)==(f|0)){W=q+(F+z<<1)|0;b[W>>1]=b[W>>1]&-17;break L72176}if((V+1|0)!=(f|0)){break}b[q+(F+z<<1)>>1]=(w|G)&65535&-17;break L72176}}while(0);b[q+(F+z<<1)>>1]=(w|G)&65535}}while(0);w=F+1|0;if((w|0)<(E|0)){F=w;A=A+L|0}else{break}}A=U+1|0;if((A|0)>=(C|0)){break L72154}T=T+N|0;U=A}}}while(0);r=r+1|0;}while((r|0)<1024);return}function ffU(){ffV();a[7461160]=1;return}function ffV(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=c[3531966]|0;f=d;gGC(14128432,14128416,16)|0;if(a[7461160]|0){g=c[3531970]|0;gGC(d|0,g|0,65536)|0;a[7461160]=0}g=c[3532094]|0;do{if((g|0)==32768){if((b[d+32774>>1]|0)!=0){h=32768;break}if((b[d+32778>>1]|0)!=0){h=32768;break}c[3532094]=0;h=0}else{h=g}}while(0);if(a[642488]|0){g=0;d=h;while(1){i=g+d|0;j=b[f+(((i+6|0)/2|0)<<1)>>1]|0;if(j<<16>>16<0){c[3532092]=b[f+(((i+10|0)/2|0)<<1)>>1]&4096;k=(j&65535)<<15&32768;c[3532094]=k;l=k}else{l=d}k=e[f+(((i+4|0)/2|0)<<1)>>1]|0;do{if((k&61440|0)==40960){i=k&4095;c[3532088]=i>>>0>2047?k|-4096:i;i=j&65535;m=i&4095;c[3532086]=m;if(m>>>0<=2047){break}c[3532086]=i|-4096}}while(0);j=g+16|0;if((j|0)<16384){g=j;d=l}else{break}}return}else{l=0;d=h;while(1){h=l+d|0;g=b[f+(((h+6|0)/2|0)<<1)>>1]|0;if(g<<16>>16<0){j=e[f+(((h+10|0)/2|0)<<1)>>1]|0;c[3532092]=j&4096;k=j<<15&32768;c[3532094]=k;n=k}else{n=d}k=e[f+(((h+4|0)/2|0)<<1)>>1]|0;do{if((k&61440|0)==40960){h=k&4095;c[3532088]=h>>>0>2047?k|-4096:h;h=g&65535;j=h&4095;c[3532086]=j;if(j>>>0<=2047){break}c[3532086]=h|-4096}}while(0);g=l+16|0;if((g|0)<16384){l=g;d=n}else{break}}return}}function ffW(){var d=0,e=0,f=0,g=0,h=0;d=c[3531970]|0;e=d;f=c[3531966]|0;g=f;ffV();a[7461160]=0;h=c[3531964]|0;gGC(f|0,h|0,65536)|0;f=0;do{b[g+(f<<1)>>1]=b[e+(f<<1)>>1]|0;f=f+4|0;}while((f|0)<32768);gGC(h|0,d|0,65536)|0;return}function ffX(){var d=0,e=0,f=0,g=0,h=0,i=0;d=c[3531970]|0;e=d;f=c[3531966]|0;g=f;ffV();a[7461160]=0;h=c[3531964]|0;gGC(f|0,h|0,65536)|0;f=0;do{b[g+(f<<1)>>1]=b[e+(f<<1)>>1]|0;i=f|1;b[g+(i<<1)>>1]=b[e+(i<<1)>>1]|0;i=f|4;b[g+(i<<1)>>1]=b[e+(i<<1)>>1]|0;i=f|5;b[g+(i<<1)>>1]=b[e+(i<<1)>>1]|0;i=f|6;b[g+(i<<1)>>1]=b[e+(i<<1)>>1]|0;i=f|7;b[g+(i<<1)>>1]=b[e+(i<<1)>>1]|0;f=f+8|0;}while((f|0)<32768);gGC(h|0,d|0,65536)|0;return}function ffY(){var d=0,e=0,f=0,g=0,h=0,i=0;d=c[3531970]|0;e=d;f=c[3531966]|0;g=f;ffV();a[7461160]=0;h=c[3531964]|0;gGC(f|0,h|0,65536)|0;f=0;do{b[g+(f<<1)>>1]=b[e+(f<<1)>>1]|0;i=f|1;b[g+(i<<1)>>1]=b[e+(i<<1)>>1]|0;i=f|4;b[g+(i<<1)>>1]=b[e+(i<<1)>>1]|0;f=f+8|0;}while((f|0)<32768);gGC(h|0,d|0,65536)|0;return}function ffZ(){var d=0,e=0,f=0,g=0,h=0;d=c[3531970]|0;e=d;f=c[3531966]|0;g=f;ffV();a[7461160]=0;h=c[3531964]|0;gGC(f|0,h|0,65536)|0;f=0;do{b[g+(f<<1)>>1]=b[e+(f<<1)>>1]|0;f=f+1|0;}while((f|0)<32768);gGC(h|0,d|0,65536)|0;return}function ff_(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>5){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4188900+(b*112|0)>>2];c[a+104>>2]=c[4188904+(b*112|0)>>2];c[a+108>>2]=c[4188908+(b*112|0)>>2];d=0;return d|0}function ff$(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<6&(d|0)==0)){e=1;return e|0}c[a>>2]=4188800+(b*112|0);e=0;return e|0}function ff0(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1299928+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function ff1(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>44){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4189472+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function ff2(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=c[642608+(c[2436]<<2)>>2]|0;e=c[d+128>>2]|0;if((c[d+52>>2]&4|0)==0){c[2113068]=e;f=c[d+132>>2]|0;c[2113070]=f;c[2443814]=e;c[2440436]=f;g=e;h=f}else{c[2113070]=e;f=c[d+132>>2]|0;c[2113068]=f;c[2440436]=e;c[2443814]=f;g=f;h=e}e=ag(g<<1,h)|0;h=gGq(e)|0;c[2112926]=h;if((h|0)!=0){gGz(h|0,0,e|0)}c[3532162]=256;c[3532160]=4;c[3532142]=8;c[3532164]=8;c[3532148]=1983576;c[3532140]=6964024;c[3532138]=6963768;c[3532042]=0;c[3532002]=1024;c[3532e3]=4;a[7460944]=1;c[3532004]=16;c[3531998]=961320;c[3531992]=4969240;c[3531990]=4968824;c[3532044]=1;c[3532030]=1;a[7460960]=1;c[3532092]=1;c[3532094]=0;c[3531954]=0;c[3532096]=0;c[2426962]=10922;c[3532118]=7616;b[7064208]=0;b[7064216]=0;b[7064209]=1024;b[7064217]=1024;b[7064210]=2048;b[7064218]=2048;b[7064211]=3072;b[7064219]=3072;b[7064212]=4096;b[7064220]=4096;b[7064213]=5120;b[7064221]=5120;b[7064214]=6144;b[7064222]=6144;b[7064215]=7168;b[7064223]=7168;c[2113026]=2e5;c[2113024]=66666;a[7461184]=1;a[7461176]=1;a[7461168]=1;a[7461192]=1;c[3532158]=1217568;c[3532152]=6168528;c[3532150]=6168496;c[3532038]=4096;c[3532034]=4096;eZ9(0)|0;c[3532048]=0;fju();e=c[3532046]|0;h=0;while(1){if((h|0)>=1024){break}i=9638528+(h<<2)|0;if((c[i>>2]|0)==0){j=55470;break}else{h=h+1|0}}do{if((j|0)==55470){h=gGq(e)|0;c[i>>2]=h;if((h|0)==0){break}gGz(h|0,0,e|0);c[3532048]=h;gGz(h|0,0,e|0);fju();if((eZ9(1)|0)!=0){k=1;return k|0}eX5(0,c[3532042]|0,3,8,0,0);a[7461080]=1;a[7461056]=1;h=c[3532132]|0;g=0;while(1){if((g|0)>=1024){l=0;break}m=9638528+(g<<2)|0;if((c[m>>2]|0)==0){j=55476;break}else{g=g+1|0}}do{if((j|0)==55476){g=gGq(8192)|0;c[m>>2]=g;if((g|0)==0){l=0;break}gGz(g|0,0,8192);l=g}}while(0);c[3532250]=l;gGz(l|0,0,8192);g=0;while(1){if((g|0)>=1024){n=0;break}o=9638528+(g<<2)|0;if((c[o>>2]|0)==0){j=55481;break}else{g=g+1|0}}do{if((j|0)==55481){g=gGq(524288)|0;c[o>>2]=g;if((g|0)==0){n=0;break}gGz(g|0,0,524288);n=g}}while(0);c[2433518]=n;gGz(n|0,0,524288);c[2433284]=-16;a[1666928]=1;c[2438974]=h;c[2430058]=2;a[7461048]=1;a[7461040]=1;fxU(0,425984);if((c[2394]|0)==0){p=c[2112932]|0}else{c[2394]=0;g=c[3532596]|0;c[2112932]=g;f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];p=g}g=c[3532204]|0;f=p|0;d=0;while(1){q=g+d|0;c[f>>2]=q;c[f+131072>>2]=q;q=d+1024|0;if(q>>>0>262143){break}else{f=f+4|0;d=q}}d=c[3532208]|0;f=p+4096|0;g=1048576;while(1){h=d+(g-1048576)|0;c[f>>2]=h;c[f+65536>>2]=h;c[f+131072>>2]=h;h=g+1024|0;if(h>>>0>1114111){break}else{f=f+4|0;g=h}}g=c[3532026]|0;c[p+8192>>2]=g;c[p+73728>>2]=g;c[p+139264>>2]=g;f=g+1024|0;c[p+8196>>2]=f;c[p+73732>>2]=f;c[p+139268>>2]=f;f=g+2048|0;c[p+8200>>2]=f;c[p+73736>>2]=f;c[p+139272>>2]=f;f=g+3072|0;c[p+8204>>2]=f;c[p+73740>>2]=f;c[p+139276>>2]=f;f=g+4096|0;c[p+8208>>2]=f;c[p+73744>>2]=f;c[p+139280>>2]=f;f=g+5120|0;c[p+8212>>2]=f;c[p+73748>>2]=f;c[p+139284>>2]=f;f=g+6144|0;c[p+8216>>2]=f;c[p+73752>>2]=f;c[p+139288>>2]=f;f=g+7168|0;c[p+8220>>2]=f;c[p+73756>>2]=f;c[p+139292>>2]=f;f=c[3532278]|0;g=p+32768|0;d=8388608;while(1){c[g>>2]=f+(d-8388608);h=d+1024|0;if(h>>>0>8470527){break}else{g=g+4|0;d=h}}d=c[3531970]|0;g=p+36864|0;f=9437184;while(1){h=d+(f-9437184)|0;c[g>>2]=h;c[g+65536>>2]=h;c[g+131072>>2]=h;h=f+1024|0;if(h>>>0>9502719){break}else{g=g+4|0;f=h}}f=c[3532250]|0;c[p+40960>>2]=f;c[p+106496>>2]=f;c[p+172032>>2]=f;g=f+1024|0;c[p+40964>>2]=g;c[p+106500>>2]=g;c[p+172036>>2]=g;g=f+2048|0;c[p+40968>>2]=g;c[p+106504>>2]=g;c[p+172040>>2]=g;g=f+3072|0;c[p+40972>>2]=g;c[p+106508>>2]=g;c[p+172044>>2]=g;g=f+4096|0;c[p+40976>>2]=g;c[p+106512>>2]=g;c[p+172048>>2]=g;g=f+5120|0;c[p+40980>>2]=g;c[p+106516>>2]=g;c[p+172052>>2]=g;g=f+6144|0;c[p+40984>>2]=g;c[p+106520>>2]=g;c[p+172056>>2]=g;g=f+7168|0;c[p+40988>>2]=g;c[p+106524>>2]=g;c[p+172060>>2]=g;c[p+196608>>2]=2280;c[p+196648>>2]=440;c[p+196688>>2]=1976;c[p+196728>>2]=2318;g=c[3532592]|0;if((g|0)!=0){gGC(g|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fjv();c[3531954]=3;c[3532118]=4386;eZ8()|0;c[2405144]=0;c[2439438]=0;c[2429772]=0;c[2437780]=0;c[3532090]=0;c[3532102]=0;gGz(14128336,0,5);c[3532098]=0;k=0;return k|0}}while(0);c[3532048]=0;k=1;return k|0}function ff3(){e_a()|0;c[3532090]=0;c[3532102]=0;gGz(14128336|0,0|0,5|0);c[3532098]=0;c[3532096]=0;a[642488]=0;c[2405144]=0;c[2439438]=0;c[2429772]=0;c[2437780]=0;c[2426962]=0;return 0}function ff4(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if((a[14128072]|0)!=0){eZ8()|0;c[2405144]=0;c[2439438]=0;c[2429772]=0;c[2437780]=0;c[3532090]=0;c[3532102]=0;gGz(14128336,0,5);c[3532098]=0}do{if(a[7461056]|0){a[14129040]=-1;a[14129041]=-1;a[14129042]=-1;d=0;e=-1;f=-1;g=-1;do{e=(e&255)-((a[14129032+d|0]&1)<<d)&255;f=(f&255)-((a[14129024+d|0]&1)<<d)&255;g=(g&255)-((a[14129016+d|0]&1)<<d)&255;d=d+1|0;}while((d|0)<8);a[14129040]=e;a[14129041]=f;a[14129042]=g}else{if(!(a[7461016]|0)){fjJ();break}a[14128912]=-1;a[14128913]=-1;a[14128914]=-1;d=0;h=-1;i=-1;j=-1;do{h=(h&255)-((a[14128904+d|0]&1)<<d)&255;i=(i&255)-((a[14128896+d|0]&1)<<d)&255;j=(j&255)-((a[14128888+d|0]&1)<<d)&255;d=d+1|0;}while((d|0)<8);a[14128912]=h;a[14128913]=i;a[14128914]=j}}while(0);c[2113031]=0;c[2113030]=0;d=c[2392]|0;if((d|0)>=0){gGz(8452240,0,((d|0)>0?(d<<2)+4|0:4)|0)}c[2113054]=0;d=c[2385548]|0;if((d|0)>0){gGz(9752472,0,((d|0)>1?d<<2:4)|0)}c[2433530]=0;d=0;while(1){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060]}g=d+1|0;f=(ag(c[2113026]|0,g)|0)/10|0;e=f-(c[2113030]|0)|0;f=(d|0)==9;k=f?e-500|0:e;c[2113028]=k;c[2113056]=k;e=RG(k)|0;c[2113054]=(c[2113054]|0)+e;c[2276108]=-1;c[2113056]=-1;c[2113030]=(c[2113030]|0)+e;do{if(f){c[8452200+(c[2394]<<2)>>2]=8197;c[2276080]=1280;if((c[2276079]|0)>>>0<1280){RH(5)}c[2113056]=500;e=RG(500)|0;c[2113054]=(c[2113054]|0)+e;c[2276108]=-1;c[2113056]=-1;c[2113030]=(c[2113030]|0)+e;c[8452200+(c[2394]<<2)>>2]=8198;c[2276080]=1536;if((c[2276079]|0)>>>0>=1536){break}RH(6)}}while(0);f=c[2394]|0;j=c[14130368+(f<<2)>>2]|0;if((j|0)!=0){gGC(j|0,9104152,280)|0}c[8452240+(f<<2)>>2]=c[2113054];c[2394]=-1;f=c[2439330]|0;if((f|0)!=0){j=f;gGC(9706056,j|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;Sb(ag((c[2113024]|0)/10|0,d)|0);j=c[1836236]|0;f=c[9757320+(j<<2)>>2]|0;if((f|0)!=0){i=f;gGC(i|0,9706056,76)|0}c[9752472+(j<<2)>>2]=c[2433530];c[14113936+(j<<2)>>2]=c[2076596];c[9669104+(j<<2)>>2]=c[3541536];c[1836236]=-1;if((g|0)<10){d=g}else{break}}d=c[2439330]|0;if((d|0)!=0){j=d;gGC(9706056,j|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;j=c[2113024]|0;d=gGU(j,(j|0)<0|0?-1:0,2048e6,0)|0;i=c[2438228]|0;f=gGS(d,K,i,(i|0)<0|0?-1:0)|0;i=f;Sb(j);j=c[2443830]|0;if((j|0)<1073676288){c[2443830]=j-i}j=c[2443831]|0;if((j|0)<1073676288){c[2443831]=j-i}j=(c[3528512]|0)-i|0;c[3528512]=(j|0)<0?0:j;j=c[2112964]|0;do{if((j|0)!=0){if(a[7460960]|0){gg[c[3542118]&4095](j,a[9688]|0?534:0)}if((c[3532032]|0)!=0){gg[c[3542122]&4095](c[2112964]|0,a[9688]|0?534:0)}if(!(a[7460984]|0)){break}Uu(0,c[2112964]|0,a[9688]|0?534:0)}}while(0);j=c[1836236]|0;i=c[9757320+(j<<2)>>2]|0;if((i|0)!=0){f=i;gGC(f|0,9706056,76)|0}c[9752472+(j<<2)>>2]=c[2433530];c[14113936+(j<<2)>>2]=c[2076596];c[9669104+(j<<2)>>2]=c[3541536];c[1836236]=-1;if(a[7461160]|0){j=c[3531966]|0;f=c[3531970]|0;gGC(j|0,f|0,65536)|0;a[7461160]=0}if((c[2112968]|0)==0){l=c[2426962]|0;gu[l&16383]();return 0}gu[c[3532118]&16383]();l=c[2426962]|0;gu[l&16383]();return 0}function ff5(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;f=i;i=i+224|0;g=f|0;h=f+16|0;j=f+32|0;k=f+48|0;l=f+64|0;m=f+80|0;n=f+96|0;o=f+112|0;p=f+128|0;q=f+144|0;r=f+160|0;s=f+176|0;t=f+192|0;u=f+208|0;if((e|0)!=0){c[e>>2]=169602}if((d&32|0)!=0){gGz(u|0,0,12);v=c[3532020]|0;c[u>>2]=v;c[u+4>>2]=(c[3532022]|0)-v;c[u+12>>2]=162152;v=c[2076592]|0;gj[v&4095](u)|0}eZ7(d);if((d&64|0)!=0){u=j|0;gGz(h|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){v=j+9|0;j=g;w=g|0;x=g+4|0;y=g+12|0;z=h|0;A=h+4|0;B=h+12|0;C=0;do{gGC(u|0,614896,11)|0;a[v]=C+48&255;D=8452256+(C<<2)|0;gGz(j|0,0,12);c[w>>2]=D;c[x>>2]=4;c[y>>2]=164976;gj[c[2076592]&4095](g)|0;if((c[D>>2]|0)!=0){c[z>>2]=c[14130368+(C<<2)>>2];c[A>>2]=c[8452184+(C<<2)>>2];c[B>>2]=u;D=c[2076592]|0;gj[D&4095](h)|0}C=C+1|0;}while((C|0)<=(c[2392]|0))}fw$(d);T0(d,e);gGz(t|0,0,12);c[t>>2]=14128320;c[t+4>>2]=6;c[t+12>>2]=273024;e=c[2076592]|0;gj[e&4095](t)|0;gGz(s|0,0,12);c[s>>2]=14127752;c[s+4>>2]=1;c[s+12>>2]=272344;t=c[2076592]|0;gj[t&4095](s)|0;gGz(r|0,0,12);c[r>>2]=14128432;c[r+4>>2]=16;c[r+12>>2]=271896;s=c[2076592]|0;gj[s&4095](r)|0;gGz(q|0,0,12);c[q>>2]=14128416;c[q+4>>2]=16;c[q+12>>2]=271088;r=c[2076592]|0;gj[r&4095](q)|0;gGz(p|0,0,12);c[p>>2]=8452120;c[p+4>>2]=16;c[p+12>>2]=270496;q=c[2076592]|0;gj[q&4095](p)|0;gGz(o|0,0,12);c[o>>2]=8452112;c[o+4>>2]=4;c[o+12>>2]=269664;p=c[2076592]|0;gj[p&4095](o)|0;gGz(n|0,0,12);c[n>>2]=9620576;c[n+4>>2]=4;c[n+12>>2]=268912;o=c[2076592]|0;gj[o&4095](n)|0;gGz(m|0,0,12);c[m>>2]=9757752;c[m+4>>2]=4;c[m+12>>2]=267904;n=c[2076592]|0;gj[n&4095](m)|0;gGz(l|0,0,12);c[l>>2]=9719088;c[l+4>>2]=4;c[l+12>>2]=267312;m=c[2076592]|0;gj[m&4095](l)|0;gGz(k|0,0,12);c[k>>2]=9751120;c[k+4>>2]=4;c[k+12>>2]=266696;l=c[2076592]|0;gj[l&4095](k)|0}if((d&2|0)==0){i=f;return 0}d=a[14127752]|0;if(d<<24>>24!=0){k=c[2439330]|0;l=(k|0)==0;if(!l){m=k;gGC(9706056,m|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];m=c[3528484]|0;c[2076596]=m;n=c[2417276]|0;c[3541536]=n;c[1836236]=0;o=c[3531932]|0;p=(d&255)<<14;d=64;q=64;while(1){c[k+76+(q<<2)>>2]=o+((q<<8)+p);r=d+1&65535;if((r&65535)>127){E=64;F=64;break}else{d=r;q=r&65535}}while(1){q=o+((F<<8)+p)|0;c[k+76+(F+512<<2)>>2]=q;c[k+76+(F+768<<2)>>2]=q;q=E+1&65535;if((q&65535)>127){break}else{E=q;F=q&65535}}if(!l){l=k;gGC(l|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=m;c[2417276]=n;c[1836236]=-1}n=c[2437780]|0;if((n|0)!=0){m=c[3541206]|0;l=(c[3532056]|0)+(n<<18)|0;gGC(m|0,l|0,262144)|0}gu[c[2426962]&16383]();if(!(a[7461160]|0)){i=f;return 0}l=c[3531966]|0;m=c[3531970]|0;gGC(l|0,m|0,65536)|0;a[7461160]=0;i=f;return 0}function ff6(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>5){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1299356+(b*112|0)>>2];c[a+104>>2]=c[1299360+(b*112|0)>>2];c[a+108>>2]=c[1299364+(b*112|0)>>2];d=0;return d|0}function ff7(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<6&(d|0)==0)){e=1;return e|0}c[a>>2]=1299256+(b*112|0);e=0;return e|0}function ff8(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;d=c[642608+(c[2436]<<2)>>2]|0;e=c[d+128>>2]|0;if((c[d+52>>2]&4|0)==0){c[2113068]=e;f=c[d+132>>2]|0;c[2113070]=f;c[2443814]=e;c[2440436]=f;g=e;i=f}else{c[2113070]=e;f=c[d+132>>2]|0;c[2113068]=f;c[2440436]=e;c[2443814]=f;g=f;i=e}e=ag(g<<1,i)|0;i=gGq(e)|0;c[2112926]=i;if((i|0)!=0){gGz(i|0,0,e|0)}c[3532162]=256;c[3532160]=4;c[3532142]=8;c[3532164]=8;c[3532148]=1983576;c[3532140]=6964024;c[3532138]=6963768;c[3532042]=0;c[3532002]=1024;c[3532e3]=4;a[7460944]=1;c[3532004]=16;c[3531998]=961320;c[3531992]=4969240;c[3531990]=4968824;c[3532044]=1;c[3532030]=1;c[3532092]=1;c[3532094]=0;c[3531954]=0;c[3532096]=0;c[2426962]=10922;c[3532118]=7616;b[7064208]=0;b[7064216]=0;b[7064209]=1024;b[7064217]=1024;b[7064210]=2048;b[7064218]=2048;b[7064211]=3072;b[7064219]=3072;b[7064212]=4096;b[7064220]=4096;b[7064213]=5120;b[7064221]=5120;b[7064214]=6144;b[7064222]=6144;b[7064215]=7168;b[7064223]=7168;c[2113026]=2e5;c[2113024]=66666;a[7460960]=0;c[3532032]=1;a[7460984]=1;a[7461184]=1;a[7461176]=1;a[7461168]=1;a[7461192]=1;c[3532158]=1217568;c[3532152]=6168528;c[3532150]=6168496;c[3532038]=4096;c[3532034]=4096;eZ9(0)|0;c[3532048]=0;fju();e=c[3532046]|0;i=0;while(1){if((i|0)>=1024){break}j=9638528+(i<<2)|0;if((c[j>>2]|0)==0){k=55607;break}else{i=i+1|0}}do{if((k|0)==55607){i=gGq(e)|0;c[j>>2]=i;if((i|0)==0){break}gGz(i|0,0,e|0);c[3532048]=i;gGz(i|0,0,e|0);fju();if((eZ9(1)|0)!=0){l=1;return l|0}eX5(0,c[3532042]|0,3,8,0,0);a[7461080]=1;a[7461056]=1;i=c[3532132]|0;g=0;while(1){if((g|0)>=1024){m=0;break}n=9638528+(g<<2)|0;if((c[n>>2]|0)==0){k=55613;break}else{g=g+1|0}}do{if((k|0)==55613){g=gGq(8192)|0;c[n>>2]=g;if((g|0)==0){m=0;break}gGz(g|0,0,8192);m=g}}while(0);c[3532250]=m;gGz(m|0,0,8192);g=0;while(1){if((g|0)>=1024){o=0;break}p=9638528+(g<<2)|0;if((c[p>>2]|0)==0){k=55618;break}else{g=g+1|0}}do{if((k|0)==55618){g=gGq(524288)|0;c[p>>2]=g;if((g|0)==0){o=0;break}gGz(g|0,0,524288);o=g}}while(0);c[2433518]=o;gGz(o|0,0,524288);c[2433284]=-16;a[1666928]=1;c[2438974]=i;c[2430058]=2;a[7461048]=1;a[7461040]=1;fxU(0,425984);if((c[2394]|0)==0){q=c[2112932]|0}else{c[2394]=0;g=c[3532596]|0;c[2112932]=g;f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];q=g}g=c[3532204]|0;f=q|0;d=0;while(1){r=g+d|0;c[f>>2]=r;c[f+131072>>2]=r;r=d+1024|0;if(r>>>0>262143){break}else{f=f+4|0;d=r}}d=c[3532208]|0;f=q+4096|0;g=1048576;while(1){i=d+(g-1048576)|0;c[f>>2]=i;c[f+65536>>2]=i;c[f+131072>>2]=i;i=g+1024|0;if(i>>>0>1114111){break}else{f=f+4|0;g=i}}g=c[3532026]|0;c[q+8192>>2]=g;c[q+73728>>2]=g;c[q+139264>>2]=g;f=g+1024|0;c[q+8196>>2]=f;c[q+73732>>2]=f;c[q+139268>>2]=f;f=g+2048|0;c[q+8200>>2]=f;c[q+73736>>2]=f;c[q+139272>>2]=f;f=g+3072|0;c[q+8204>>2]=f;c[q+73740>>2]=f;c[q+139276>>2]=f;f=g+4096|0;c[q+8208>>2]=f;c[q+73744>>2]=f;c[q+139280>>2]=f;f=g+5120|0;c[q+8212>>2]=f;c[q+73748>>2]=f;c[q+139284>>2]=f;f=g+6144|0;c[q+8216>>2]=f;c[q+73752>>2]=f;c[q+139288>>2]=f;f=g+7168|0;c[q+8220>>2]=f;c[q+73756>>2]=f;c[q+139292>>2]=f;f=c[3532278]|0;g=q+32768|0;d=8388608;while(1){c[g>>2]=f+(d-8388608);i=d+1024|0;if(i>>>0>8470527){break}else{g=g+4|0;d=i}}d=c[3531970]|0;g=q+36864|0;f=9437184;while(1){i=d+(f-9437184)|0;c[g>>2]=i;c[g+65536>>2]=i;c[g+131072>>2]=i;i=f+1024|0;if(i>>>0>9502719){break}else{g=g+4|0;f=i}}f=c[3532250]|0;c[q+40960>>2]=f;c[q+106496>>2]=f;c[q+172032>>2]=f;g=f+1024|0;c[q+40964>>2]=g;c[q+106500>>2]=g;c[q+172036>>2]=g;g=f+2048|0;c[q+40968>>2]=g;c[q+106504>>2]=g;c[q+172040>>2]=g;g=f+3072|0;c[q+40972>>2]=g;c[q+106508>>2]=g;c[q+172044>>2]=g;g=f+4096|0;c[q+40976>>2]=g;c[q+106512>>2]=g;c[q+172048>>2]=g;g=f+5120|0;c[q+40980>>2]=g;c[q+106516>>2]=g;c[q+172052>>2]=g;g=f+6144|0;c[q+40984>>2]=g;c[q+106520>>2]=g;c[q+172056>>2]=g;g=f+7168|0;c[q+40988>>2]=g;c[q+106524>>2]=g;c[q+172060>>2]=g;c[q+196608>>2]=2280;c[q+196648>>2]=440;c[q+196688>>2]=1976;c[q+196728>>2]=2318;g=c[3532592]|0;if((g|0)!=0){gGC(g|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);g=c[2439330]|0;f=(g|0)==0;if(!f){d=g;gGC(9706056,d|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];d=c[3528484]|0;c[2076596]=d;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;c[g+4180>>2]=384;c[g+4184>>2]=1e3;r=c[3531932]|0;s=0;t=0;while(1){c[g+76+(t<<2)>>2]=r+(t<<8);u=s+1&65535;if((u&65535)>127){v=0;w=0;break}else{s=u;t=u&65535}}while(1){t=r+(w<<8)|0;c[g+76+(w+512<<2)>>2]=t;c[g+76+(w+768<<2)>>2]=t;t=v+1&65535;if((t&65535)>127){break}else{v=t;w=t&65535}}r=c[3531936]|0;c[g+588>>2]=r;c[g+592>>2]=r+256;c[g+596>>2]=r+512;c[g+600>>2]=r+768;c[g+604>>2]=r+1024;c[g+608>>2]=r+1280;c[g+612>>2]=r+1536;c[g+616>>2]=r+1792;c[g+620>>2]=r+2048;c[g+624>>2]=r+2304;c[g+628>>2]=r+2560;c[g+632>>2]=r+2816;c[g+636>>2]=r+3072;c[g+640>>2]=r+3328;c[g+644>>2]=r+3584;c[g+648>>2]=r+3840;t=128;s=128;while(1){c[g+76+(s+256<<2)>>2]=r+((s<<8)-32768);u=t+1&65535;if((u&65535)>143){x=128;y=128;break}else{t=u;s=u&65535}}while(1){s=r+((y<<8)-32768)|0;c[g+76+(y+512<<2)>>2]=s;c[g+76+(y+768<<2)>>2]=s;s=x+1&65535;if((s&65535)>143){break}else{x=s;y=s&65535}}if(!f){r=g;gGC(r|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=d;c[2417276]=i;c[1836236]=-1;Vr(1,3e6,1410,2612,124,0);c[2438228]=6e6;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=340;h[745419]=.6;a[3203368]=1;h[745418]=.2;a[3203360]=1;h[745417]=.2;a[3203352]=1;h[745416]=.2;a[3203344]=1;Ux(0,8e3,1);c[2407030]=26;c[2407068]=3;c[2113024]=1e5;c[3531954]=3;c[3532118]=4386;eZ8()|0;c[2405144]=0;c[2439438]=0;c[2429772]=0;c[2437780]=0;c[3532090]=0;c[3532102]=0;gGz(14128336,0,5);c[3532098]=0;l=0;return l|0}}while(0);c[3532048]=0;l=1;return l|0}function ff9(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>5){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1991532+(b*112|0)>>2];c[a+104>>2]=c[1991536+(b*112|0)>>2];c[a+108>>2]=c[1991540+(b*112|0)>>2];d=0;return d|0}function fga(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<6&(d|0)==0)){e=1;return e|0}c[a>>2]=1991432+(b*112|0);e=0;return e|0}function fgb(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>5){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1990860+(b*112|0)>>2];c[a+104>>2]=c[1990864+(b*112|0)>>2];c[a+108>>2]=c[1990868+(b*112|0)>>2];d=0;return d|0}function fgc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<6&(d|0)==0)){e=1;return e|0}c[a>>2]=1990760+(b*112|0);e=0;return e|0}function fgd(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>44){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4190016+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fge(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4077244+(b*112|0)>>2];c[a+104>>2]=c[4077248+(b*112|0)>>2];c[a+108>>2]=c[4077252+(b*112|0)>>2];d=0;return d|0}function fgf(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=4077144+(b*112|0);e=0;return e|0}function fgg(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1284808+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function fgh(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>36){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4078264+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fgi(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[642608+(c[2436]<<2)>>2]|0;e=c[d+128>>2]|0;if((c[d+52>>2]&4|0)==0){c[2113068]=e;f=c[d+132>>2]|0;c[2113070]=f;c[2443814]=e;c[2440436]=f;g=e;h=f}else{c[2113070]=e;f=c[d+132>>2]|0;c[2113068]=f;c[2440436]=e;c[2443814]=f;g=f;h=e}e=ag(g<<1,h)|0;h=gGq(e)|0;c[2112926]=h;if((h|0)!=0){gGz(h|0,0,e|0)}c[3532044]=1;c[3532030]=1;a[7460960]=1;c[3532092]=1;c[3532094]=0;c[3531954]=0;c[3532096]=0;c[2426962]=10922;c[3532118]=7616;b[7064208]=0;b[7064216]=0;b[7064209]=1024;b[7064217]=1024;b[7064210]=2048;b[7064218]=2048;b[7064211]=3072;b[7064219]=3072;b[7064212]=4096;b[7064220]=4096;b[7064213]=5120;b[7064221]=5120;b[7064214]=6144;b[7064222]=6144;b[7064215]=7168;b[7064223]=7168;c[2113026]=2e5;c[2113024]=66666;c[3532162]=1024;c[3532160]=4;c[3532142]=16;c[3532164]=16;c[3532148]=683048;c[3532140]=703496;c[3532138]=703432;c[3532042]=8192;c[3532002]=1024;c[3532e3]=4;a[7460944]=1;c[3532004]=16;c[3531998]=961320;c[3531992]=4969240;c[3531990]=4968824;c[3532034]=16384;eZ9(0)|0;c[3532048]=0;fju();e=c[3532046]|0;h=0;while(1){if((h|0)>=1024){break}i=9638528+(h<<2)|0;if((c[i>>2]|0)==0){j=55715;break}else{h=h+1|0}}do{if((j|0)==55715){h=gGq(e)|0;c[i>>2]=h;if((h|0)==0){break}gGz(h|0,0,e|0);c[3532048]=h;gGz(h|0,0,e|0);fju();if((eZ9(1)|0)!=0){k=1;return k|0}h=(fa(c[c[642608+(c[2436]<<2)>>2]>>2]|0,493904)|0)==0;g=c[3532042]|0;if(h){eXS(g,3,52,-5,-1,0,26)}else{eXS(g,3,30,8,-1,0,0)}a[7461080]=1;a[7461040]=1;fxU(0,425984);if((c[2394]|0)==0){l=c[2112932]|0}else{c[2394]=0;g=c[3532596]|0;c[2112932]=g;h=c[3532592]|0;if((h|0)!=0){gGC(9104152,h|0,280)|0}c[2113054]=c[2113060];l=g}g=c[3532204]|0;h=l|0;f=0;while(1){d=g+f|0;c[h>>2]=d;c[h+131072>>2]=d;d=f+1024|0;if(d>>>0>1048575){break}else{h=h+4|0;f=d}}f=c[3532208]|0;h=l+4096|0;g=1048576;while(1){d=f+(g-1048576)|0;c[h>>2]=d;c[h+65536>>2]=d;c[h+131072>>2]=d;d=g+1024|0;if(d>>>0>1114111){break}else{h=h+4|0;g=d}}g=c[3531970]|0;h=l+8192|0;f=2097152;while(1){d=g+(f-2097152)|0;c[h>>2]=d;c[h+65536>>2]=d;c[h+131072>>2]=d;d=f+1024|0;if(d>>>0>2162687){break}else{h=h+4|0;f=d}}f=c[3532232]|0;h=l+16384|0;g=4194304;while(1){d=f+(g-4194304)|0;c[h>>2]=d;c[h+65536>>2]=d;c[h+131072>>2]=d;d=g+1024|0;if(d>>>0>4259839){break}else{h=h+4|0;g=d}}g=c[3532026]|0;c[l+24576>>2]=g;c[l+90112>>2]=g;c[l+155648>>2]=g;h=g+1024|0;c[l+24580>>2]=h;c[l+90116>>2]=h;c[l+155652>>2]=h;h=g+2048|0;c[l+24584>>2]=h;c[l+90120>>2]=h;c[l+155656>>2]=h;h=g+3072|0;c[l+24588>>2]=h;c[l+90124>>2]=h;c[l+155660>>2]=h;h=g+4096|0;c[l+24592>>2]=h;c[l+90128>>2]=h;c[l+155664>>2]=h;h=g+5120|0;c[l+24596>>2]=h;c[l+90132>>2]=h;c[l+155668>>2]=h;h=g+6144|0;c[l+24600>>2]=h;c[l+90136>>2]=h;c[l+155672>>2]=h;h=g+7168|0;c[l+24604>>2]=h;c[l+90140>>2]=h;c[l+155676>>2]=h;c[l+196608>>2]=1148;c[l+196648>>2]=2660;c[l+196688>>2]=332;c[l+196728>>2]=118;h=c[3532592]|0;if((h|0)!=0){gGC(h|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fjv();c[3531954]=3;c[3532118]=11584;eZ8()|0;c[2405144]=0;c[2439438]=0;c[2429772]=0;c[2437780]=0;c[3532090]=0;c[3532102]=0;gGz(14128336,0,5);c[3532098]=0;k=0;return k|0}}while(0);c[3532048]=0;k=1;return k|0}function fgj(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1960964+(b*112|0)>>2];c[a+104>>2]=c[1960968+(b*112|0)>>2];c[a+108>>2]=c[1960972+(b*112|0)>>2];d=0;return d|0}function fgk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=1960864+(b*112|0);e=0;return e|0}function fgl(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>36){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1961984+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fgm(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5455836+(b*112|0)>>2];c[a+104>>2]=c[5455840+(b*112|0)>>2];c[a+108>>2]=c[5455844+(b*112|0)>>2];d=0;return d|0}function fgn(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=5455736+(b*112|0);e=0;return e|0}function fgo(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1956936+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function fgp(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>42){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5456968+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fgq(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[642608+(c[2436]<<2)>>2]|0;e=c[d+128>>2]|0;if((c[d+52>>2]&4|0)==0){c[2113068]=e;f=c[d+132>>2]|0;c[2113070]=f;c[2443814]=e;c[2440436]=f;g=e;h=f}else{c[2113070]=e;f=c[d+132>>2]|0;c[2113068]=f;c[2440436]=e;c[2443814]=f;g=f;h=e}e=ag(g<<1,h)|0;h=gGq(e)|0;c[2112926]=h;if((h|0)!=0){gGz(h|0,0,e|0)}c[3532162]=256;c[3532160]=4;c[3532142]=8;c[3532164]=8;c[3532148]=1983576;c[3532140]=6964024;c[3532138]=6963768;c[3532002]=1024;c[3532e3]=4;a[7460944]=1;c[3532004]=16;c[3531998]=961320;c[3531992]=4969240;c[3531990]=4968824;c[3532044]=1;c[3532030]=1;a[7460960]=1;c[3532092]=1;c[3532094]=0;c[3531954]=0;c[3532096]=0;c[2426962]=10922;c[3532118]=7616;b[7064208]=0;b[7064216]=0;b[7064209]=1024;b[7064217]=1024;b[7064210]=2048;b[7064218]=2048;b[7064211]=3072;b[7064219]=3072;b[7064212]=4096;b[7064220]=4096;b[7064213]=5120;b[7064221]=5120;b[7064214]=6144;b[7064222]=6144;b[7064215]=7168;b[7064223]=7168;c[2113026]=2e5;c[2113024]=66666;c[3532042]=32768;c[3532034]=49152;eZ9(0)|0;c[3532048]=0;fju();e=c[3532046]|0;h=0;while(1){if((h|0)>=1024){break}i=9638528+(h<<2)|0;if((c[i>>2]|0)==0){j=55794;break}else{h=h+1|0}}do{if((j|0)==55794){h=gGq(e)|0;c[i>>2]=h;if((h|0)==0){break}gGz(h|0,0,e|0);c[3532048]=h;gGz(h|0,0,e|0);fju();if((eZ9(1)|0)!=0){k=1;return k|0}eX5(0,c[3532042]|0,3,8,0,c[3532024]|0);a[7461080]=1;a[7461040]=1;a[7461016]=1;fxU(0,425984);if((c[2394]|0)==0){l=c[2112932]|0}else{c[2394]=0;h=c[3532596]|0;c[2112932]=h;g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060];l=h}h=c[3532204]|0;g=l|0;f=0;while(1){d=h+f|0;c[g>>2]=d;c[g+131072>>2]=d;d=f+1024|0;if(d>>>0>3145727){break}else{g=g+4|0;f=d}}f=c[3531978]|0;c[l+16384>>2]=f;c[l+81920>>2]=f;c[l+147456>>2]=f;g=f+1024|0;c[l+16388>>2]=g;c[l+81924>>2]=g;c[l+147460>>2]=g;g=f+2048|0;c[l+16392>>2]=g;c[l+81928>>2]=g;c[l+147464>>2]=g;g=f+3072|0;c[l+16396>>2]=g;c[l+81932>>2]=g;c[l+147468>>2]=g;g=c[3532026]|0;c[l+20480>>2]=g;c[l+86016>>2]=g;c[l+151552>>2]=g;f=g+1024|0;c[l+20484>>2]=f;c[l+86020>>2]=f;c[l+151556>>2]=f;f=g+2048|0;c[l+20488>>2]=f;c[l+86024>>2]=f;c[l+151560>>2]=f;f=g+3072|0;c[l+20492>>2]=f;c[l+86028>>2]=f;c[l+151564>>2]=f;f=g+4096|0;c[l+20496>>2]=f;c[l+86032>>2]=f;c[l+151568>>2]=f;f=g+5120|0;c[l+20500>>2]=f;c[l+86036>>2]=f;c[l+151572>>2]=f;f=g+6144|0;c[l+20504>>2]=f;c[l+86040>>2]=f;c[l+151576>>2]=f;f=g+7168|0;c[l+20508>>2]=f;c[l+86044>>2]=f;c[l+151580>>2]=f;f=c[3532208]|0;g=l+24576|0;h=6291456;while(1){d=f+(h-6291456)|0;c[g>>2]=d;c[g+65536>>2]=d;c[g+131072>>2]=d;d=h+1024|0;if(d>>>0>6356991){break}else{g=g+4|0;h=d}}h=c[3531970]|0;g=l+32768|0;f=8388608;while(1){d=h+(f-8388608)|0;c[g>>2]=d;c[g+65536>>2]=d;c[g+131072>>2]=d;d=f+1024|0;if(d>>>0>8454143){break}else{g=g+4|0;f=d}}f=c[3532278]|0;g=l+36864|0;h=9437184;while(1){c[g>>2]=f+(h-9437184);d=h+1024|0;if(d>>>0>9502719){break}else{g=g+4|0;h=d}}c[l+196608>>2]=3026;c[l+196648>>2]=376;c[l+196688>>2]=3344;c[l+196728>>2]=1498;h=c[3532592]|0;if((h|0)!=0){gGC(h|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fjv();c[3531954]=3;c[3532096]=3;eZ8()|0;c[2405144]=0;c[2439438]=0;c[2429772]=0;c[2437780]=0;c[3532090]=0;c[3532102]=0;gGz(14128336,0,5);c[3532098]=0;k=0;return k|0}}while(0);c[3532048]=0;k=1;return k|0}function fgr(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4056476+(b*112|0)>>2];c[a+104>>2]=c[4056480+(b*112|0)>>2];c[a+108>>2]=c[4056484+(b*112|0)>>2];d=0;return d|0}function fgs(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=4056376+(b*112|0);e=0;return e|0}function fgt(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>42){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4057608+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fgu(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4055244+(b*112|0)>>2];c[a+104>>2]=c[4055248+(b*112|0)>>2];c[a+108>>2]=c[4055252+(b*112|0)>>2];d=0;return d|0}function fgv(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=4055144+(b*112|0);e=0;return e|0}function fgw(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4049892+(b*112|0)>>2];c[a+104>>2]=c[4049896+(b*112|0)>>2];c[a+108>>2]=c[4049900+(b*112|0)>>2];d=0;return d|0}function fgx(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=4049792+(b*112|0);e=0;return e|0}function fgy(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1280832+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function fgz(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>35){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4050800+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fgA(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=c[642608+(c[2436]<<2)>>2]|0;e=c[d+128>>2]|0;if((c[d+52>>2]&4|0)==0){c[2113068]=e;f=c[d+132>>2]|0;c[2113070]=f;c[2443814]=e;c[2440436]=f;g=e;h=f}else{c[2113070]=e;f=c[d+132>>2]|0;c[2113068]=f;c[2440436]=e;c[2443814]=f;g=f;h=e}e=ag(g<<1,h)|0;h=gGq(e)|0;c[2112926]=h;if((h|0)!=0){gGz(h|0,0,e|0)}c[3532162]=256;c[3532160]=4;c[3532142]=8;c[3532164]=8;c[3532148]=1983576;c[3532140]=6964024;c[3532138]=6963768;c[3532002]=1024;c[3532e3]=4;a[7460944]=1;c[3532004]=16;c[3531998]=961320;c[3531992]=4969240;c[3531990]=4968824;c[3532044]=1;c[3532030]=1;a[7460960]=1;c[3532092]=1;c[3532094]=0;c[3531954]=0;c[3532096]=0;c[2426962]=10922;c[3532118]=7616;b[7064208]=0;b[7064216]=0;b[7064209]=1024;b[7064217]=1024;b[7064210]=2048;b[7064218]=2048;b[7064211]=3072;b[7064219]=3072;b[7064212]=4096;b[7064220]=4096;b[7064213]=5120;b[7064221]=5120;b[7064214]=6144;b[7064222]=6144;b[7064215]=7168;b[7064223]=7168;c[2113026]=2e5;c[2113024]=66666;a[7461184]=1;a[7461176]=1;a[7461168]=1;a[7461192]=1;c[3532158]=1217568;c[3532152]=6168528;c[3532150]=6168496;c[3532038]=16384;c[3532042]=16384;c[3532034]=4096;eZ9(0)|0;c[3532048]=0;fju();e=c[3532046]|0;h=0;while(1){if((h|0)>=1024){break}i=9638528+(h<<2)|0;if((c[i>>2]|0)==0){j=55882;break}else{h=h+1|0}}do{if((j|0)==55882){h=gGq(e)|0;c[i>>2]=h;if((h|0)==0){break}gGz(h|0,0,e|0);c[3532048]=h;gGz(h|0,0,e|0);fju();if((eZ9(1)|0)!=0){k=1;return k|0}eX5(0,c[3532042]|0,3,8,0,c[3532024]|0);a[7461080]=1;a[7461056]=1;h=c[3532132]|0;g=0;while(1){if((g|0)>=1024){l=0;break}m=9638528+(g<<2)|0;if((c[m>>2]|0)==0){j=55888;break}else{g=g+1|0}}do{if((j|0)==55888){g=gGq(8192)|0;c[m>>2]=g;if((g|0)==0){l=0;break}gGz(g|0,0,8192);l=g}}while(0);c[3532250]=l;gGz(l|0,0,8192);g=0;while(1){if((g|0)>=1024){n=0;break}o=9638528+(g<<2)|0;if((c[o>>2]|0)==0){j=55893;break}else{g=g+1|0}}do{if((j|0)==55893){g=gGq(524288)|0;c[o>>2]=g;if((g|0)==0){n=0;break}gGz(g|0,0,524288);n=g}}while(0);c[2433518]=n;gGz(n|0,0,524288);c[2433284]=-16;a[1666928]=1;c[2438974]=h;c[2430058]=2;a[7461048]=1;a[7461040]=1;fxU(0,425984);if((c[2394]|0)==0){p=c[2112932]|0}else{c[2394]=0;g=c[3532596]|0;c[2112932]=g;f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];p=g}g=c[3532204]|0;f=p|0;d=0;while(1){q=g+d|0;c[f>>2]=q;c[f+131072>>2]=q;q=d+1024|0;if(q>>>0>524287){break}else{f=f+4|0;d=q}}d=c[3532208]|0;f=p+4096|0;g=1048576;while(1){h=d+(g-1048576)|0;c[f>>2]=h;c[f+65536>>2]=h;c[f+131072>>2]=h;h=g+1024|0;if(h>>>0>1114111){break}else{f=f+4|0;g=h}}g=c[3532026]|0;c[p+8192>>2]=g;c[p+73728>>2]=g;c[p+139264>>2]=g;f=g+1024|0;c[p+8196>>2]=f;c[p+73732>>2]=f;c[p+139268>>2]=f;f=g+2048|0;c[p+8200>>2]=f;c[p+73736>>2]=f;c[p+139272>>2]=f;f=g+3072|0;c[p+8204>>2]=f;c[p+73740>>2]=f;c[p+139276>>2]=f;f=g+4096|0;c[p+8208>>2]=f;c[p+73744>>2]=f;c[p+139280>>2]=f;f=g+5120|0;c[p+8212>>2]=f;c[p+73748>>2]=f;c[p+139284>>2]=f;f=g+6144|0;c[p+8216>>2]=f;c[p+73752>>2]=f;c[p+139288>>2]=f;f=g+7168|0;c[p+8220>>2]=f;c[p+73756>>2]=f;c[p+139292>>2]=f;f=c[3532278]|0;g=p+32768|0;d=8388608;while(1){c[g>>2]=f+(d-8388608);h=d+1024|0;if(h>>>0>8454143){break}else{g=g+4|0;d=h}}d=c[3531970]|0;g=p+36864|0;f=9437184;while(1){h=d+(f-9437184)|0;c[g>>2]=h;c[g+65536>>2]=h;c[g+131072>>2]=h;h=f+1024|0;if(h>>>0>9502719){break}else{g=g+4|0;f=h}}f=c[3532250]|0;c[p+40960>>2]=f;c[p+106496>>2]=f;c[p+172032>>2]=f;g=f+1024|0;c[p+40964>>2]=g;c[p+106500>>2]=g;c[p+172036>>2]=g;g=f+2048|0;c[p+40968>>2]=g;c[p+106504>>2]=g;c[p+172040>>2]=g;g=f+3072|0;c[p+40972>>2]=g;c[p+106508>>2]=g;c[p+172044>>2]=g;g=f+4096|0;c[p+40976>>2]=g;c[p+106512>>2]=g;c[p+172048>>2]=g;g=f+5120|0;c[p+40980>>2]=g;c[p+106516>>2]=g;c[p+172052>>2]=g;g=f+6144|0;c[p+40984>>2]=g;c[p+106520>>2]=g;c[p+172056>>2]=g;g=f+7168|0;c[p+40988>>2]=g;c[p+106524>>2]=g;c[p+172060>>2]=g;c[p+196608>>2]=298;c[p+196648>>2]=2150;c[p+196688>>2]=454;c[p+196728>>2]=2854;g=c[3532592]|0;if((g|0)!=0){gGC(g|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fjv();c[3531954]=3;c[2426962]=11852;c[3532118]=5004;eZ8()|0;c[2405144]=0;c[2439438]=0;c[2429772]=0;c[2437780]=0;c[3532090]=0;c[3532102]=0;gGz(14128336,0,5);c[3532098]=0;k=0;return k|0}}while(0);c[3532048]=0;k=1;return k|0}function fgB(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1955596+(b*112|0)>>2];c[a+104>>2]=c[1955600+(b*112|0)>>2];c[a+108>>2]=c[1955604+(b*112|0)>>2];d=0;return d|0}function fgC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=1955496+(b*112|0);e=0;return e|0}function fgD(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>35){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1956504+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fgE(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1954156+(b*112|0)>>2];c[a+104>>2]=c[1954160+(b*112|0)>>2];c[a+108>>2]=c[1954164+(b*112|0)>>2];d=0;return d|0}function fgF(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=1954056+(b*112|0);e=0;return e|0}function fgG(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>35){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1955064+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fgH(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>5){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4044036+(b*112|0)>>2];c[a+104>>2]=c[4044040+(b*112|0)>>2];c[a+108>>2]=c[4044044+(b*112|0)>>2];d=0;return d|0}function fgI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<6&(d|0)==0)){e=1;return e|0}c[a>>2]=4043936+(b*112|0);e=0;return e|0}function fgJ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1277040+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function fgK(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>30){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4044608+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fgL(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=c[642608+(c[2436]<<2)>>2]|0;e=c[d+128>>2]|0;if((c[d+52>>2]&4|0)==0){c[2113068]=e;f=c[d+132>>2]|0;c[2113070]=f;c[2443814]=e;c[2440436]=f;g=e;h=f}else{c[2113070]=e;f=c[d+132>>2]|0;c[2113068]=f;c[2440436]=e;c[2443814]=f;g=f;h=e}e=ag(g<<1,h)|0;h=gGq(e)|0;c[2112926]=h;if((h|0)!=0){gGz(h|0,0,e|0)}c[3532162]=256;c[3532160]=4;c[3532142]=8;c[3532164]=8;c[3532148]=1983576;c[3532140]=6964024;c[3532138]=6963768;c[3532042]=0;c[3532002]=1024;c[3532e3]=4;a[7460944]=1;c[3532004]=16;c[3531998]=961320;c[3531992]=4969240;c[3531990]=4968824;c[3532044]=1;c[3532030]=1;a[7460960]=1;c[3532092]=1;c[3532094]=0;c[3531954]=0;c[3532096]=0;c[2426962]=10922;c[3532118]=7616;b[7064208]=0;b[7064216]=0;b[7064209]=1024;b[7064217]=1024;b[7064210]=2048;b[7064218]=2048;b[7064211]=3072;b[7064219]=3072;b[7064212]=4096;b[7064220]=4096;b[7064213]=5120;b[7064221]=5120;b[7064214]=6144;b[7064222]=6144;b[7064215]=7168;b[7064223]=7168;c[2113026]=2e5;c[2113024]=66666;a[7461184]=1;a[7461176]=1;a[7461168]=1;a[7461192]=1;c[3532158]=1217568;c[3532152]=6168528;c[3532150]=6168496;c[3532038]=16384;c[3532034]=4096;eZ9(0)|0;c[3532048]=0;fju();e=c[3532046]|0;h=0;while(1){if((h|0)>=1024){break}i=9638528+(h<<2)|0;if((c[i>>2]|0)==0){j=55987;break}else{h=h+1|0}}do{if((j|0)==55987){h=gGq(e)|0;c[i>>2]=h;if((h|0)==0){break}gGz(h|0,0,e|0);c[3532048]=h;gGz(h|0,0,e|0);fju();if((eZ9(1)|0)!=0){k=1;return k|0}eX5(0,c[3532042]|0,3,8,0,0);a[7461080]=1;a[7461040]=1;h=c[3532132]|0;g=0;while(1){if((g|0)>=1024){l=0;break}m=9638528+(g<<2)|0;if((c[m>>2]|0)==0){j=55993;break}else{g=g+1|0}}do{if((j|0)==55993){g=gGq(8192)|0;c[m>>2]=g;if((g|0)==0){l=0;break}gGz(g|0,0,8192);l=g}}while(0);c[3532250]=l;gGz(l|0,0,8192);g=0;while(1){if((g|0)>=1024){n=0;break}o=9638528+(g<<2)|0;if((c[o>>2]|0)==0){j=55998;break}else{g=g+1|0}}do{if((j|0)==55998){g=gGq(524288)|0;c[o>>2]=g;if((g|0)==0){n=0;break}gGz(g|0,0,524288);n=g}}while(0);c[2433518]=n;gGz(n|0,0,524288);c[2433284]=-16;a[1666928]=0;c[2438974]=h;c[2430058]=1;a[7461048]=0;a[7461032]=1;a[7461016]=1;fxU(0,425984);if((c[2394]|0)==0){p=c[2112932]|0}else{c[2394]=0;g=c[3532596]|0;c[2112932]=g;f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];p=g}g=c[3532204]|0;f=p|0;d=0;while(1){q=g+d|0;c[f>>2]=q;c[f+131072>>2]=q;q=d+1024|0;if(q>>>0>1048575){break}else{f=f+4|0;d=q}}d=c[3532208]|0;f=p+12288|0;g=3145728;while(1){h=d+(g-3145728)|0;c[f>>2]=h;c[f+65536>>2]=h;c[f+131072>>2]=h;h=g+1024|0;if(h>>>0>3211263){break}else{f=f+4|0;g=h}}g=c[3532250]|0;c[p+16384>>2]=g;c[p+81920>>2]=g;c[p+147456>>2]=g;f=g+1024|0;c[p+16388>>2]=f;c[p+81924>>2]=f;c[p+147460>>2]=f;f=g+2048|0;c[p+16392>>2]=f;c[p+81928>>2]=f;c[p+147464>>2]=f;f=g+3072|0;c[p+16396>>2]=f;c[p+81932>>2]=f;c[p+147468>>2]=f;f=g+4096|0;c[p+16400>>2]=f;c[p+81936>>2]=f;c[p+147472>>2]=f;f=g+5120|0;c[p+16404>>2]=f;c[p+81940>>2]=f;c[p+147476>>2]=f;f=g+6144|0;c[p+16408>>2]=f;c[p+81944>>2]=f;c[p+147480>>2]=f;f=g+7168|0;c[p+16412>>2]=f;c[p+81948>>2]=f;c[p+147484>>2]=f;f=c[3532026]|0;c[p+28672>>2]=f;c[p+94208>>2]=f;c[p+159744>>2]=f;g=f+1024|0;c[p+28676>>2]=g;c[p+94212>>2]=g;c[p+159748>>2]=g;g=f+2048|0;c[p+28680>>2]=g;c[p+94216>>2]=g;c[p+159752>>2]=g;g=f+3072|0;c[p+28684>>2]=g;c[p+94220>>2]=g;c[p+159756>>2]=g;g=f+4096|0;c[p+28688>>2]=g;c[p+94224>>2]=g;c[p+159760>>2]=g;g=f+5120|0;c[p+28692>>2]=g;c[p+94228>>2]=g;c[p+159764>>2]=g;g=f+6144|0;c[p+28696>>2]=g;c[p+94232>>2]=g;c[p+159768>>2]=g;g=f+7168|0;c[p+28700>>2]=g;c[p+94236>>2]=g;c[p+159772>>2]=g;g=c[3532278]|0;f=p+32768|0;d=8388608;while(1){c[f>>2]=g+(d-8388608);h=d+1024|0;if(h>>>0>8454143){break}else{f=f+4|0;d=h}}d=c[3531970]|0;f=p+36864|0;g=9437184;while(1){h=d+(g-9437184)|0;c[f>>2]=h;c[f+65536>>2]=h;c[f+131072>>2]=h;h=g+1024|0;if(h>>>0>9502719){break}else{f=f+4|0;g=h}}c[p+196608>>2]=2782;c[p+196648>>2]=3278;c[p+196688>>2]=3392;c[p+196728>>2]=792;g=c[3532592]|0;if((g|0)!=0){gGC(g|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fjv();c[3531954]=3;c[3532118]=2032;eZ8()|0;c[2405144]=0;c[2439438]=0;c[2429772]=0;c[2437780]=0;c[3532090]=0;c[3532102]=0;gGz(14128336,0,5);c[3532098]=0;k=0;return k|0}}while(0);c[3532048]=0;k=1;return k|0}function fgM(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>5){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1950908+(b*112|0)>>2];c[a+104>>2]=c[1950912+(b*112|0)>>2];c[a+108>>2]=c[1950916+(b*112|0)>>2];d=0;return d|0}function fgN(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<6&(d|0)==0)){e=1;return e|0}c[a>>2]=1950808+(b*112|0);e=0;return e|0}function fgO(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4043140+(b*112|0)>>2];c[a+104>>2]=c[4043144+(b*112|0)>>2];c[a+108>>2]=c[4043148+(b*112|0)>>2];d=0;return d|0}function fgP(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=4043040+(b*112|0);e=0;return e|0}function fgQ(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;d=c[642608+(c[2436]<<2)>>2]|0;e=c[d+128>>2]|0;if((c[d+52>>2]&4|0)==0){c[2113068]=e;f=c[d+132>>2]|0;c[2113070]=f;c[2443814]=e;c[2440436]=f;g=e;h=f}else{c[2113070]=e;f=c[d+132>>2]|0;c[2113068]=f;c[2440436]=e;c[2443814]=f;g=f;h=e}e=ag(g<<1,h)|0;h=gGq(e)|0;c[2112926]=h;if((h|0)!=0){gGz(h|0,0,e|0)}c[3532162]=256;c[3532160]=4;c[3532142]=8;c[3532164]=8;c[3532148]=1983576;c[3532140]=6964024;c[3532138]=6963768;c[3532042]=0;c[3532002]=1024;c[3532e3]=4;a[7460944]=1;c[3532004]=16;c[3531998]=961320;c[3531992]=4969240;c[3531990]=4968824;c[3532044]=1;c[3532030]=1;c[3532092]=1;c[3532094]=0;c[3531954]=0;c[3532096]=0;c[2426962]=10922;c[3532118]=7616;b[7064208]=0;b[7064216]=0;b[7064209]=1024;b[7064217]=1024;b[7064210]=2048;b[7064218]=2048;b[7064211]=3072;b[7064219]=3072;b[7064212]=4096;b[7064220]=4096;b[7064213]=5120;b[7064221]=5120;b[7064214]=6144;b[7064222]=6144;b[7064215]=7168;b[7064223]=7168;c[2113026]=2e5;c[2113024]=66666;a[7460960]=0;a[7460984]=1;a[7461184]=1;a[7461176]=1;a[7461168]=1;a[7461192]=1;c[3532158]=1217568;c[3532152]=6168528;c[3532150]=6168496;c[3532038]=16384;c[3532034]=4096;eZ9(0)|0;c[3532052]=1048576;c[3532048]=0;fju();e=c[3532046]|0;h=0;while(1){if((h|0)>=1024){break}i=9638528+(h<<2)|0;if((c[i>>2]|0)==0){j=56052;break}else{h=h+1|0}}do{if((j|0)==56052){h=gGq(e)|0;c[i>>2]=h;if((h|0)==0){break}gGz(h|0,0,e|0);c[3532048]=h;gGz(h|0,0,e|0);fju();if((eZ9(1)|0)==0){k=0}else{l=1;return l|0}while(1){if((k|0)>=1024){m=0;break}n=9638528+(k<<2)|0;if((c[n>>2]|0)==0){j=56057;break}else{k=k+1|0}}do{if((j|0)==56057){h=gGq(1048576)|0;c[n>>2]=h;if((h|0)==0){m=0;break}gGz(h|0,0,1048576);m=h}}while(0);h=c[3532056]|0;gGC(m|0,h|0,1048576)|0;gGz(h|0,0,1048576);gGC(h|0,m|0,131072)|0;g=h+131072|0;f=m+524288|0;gGC(g|0,f|0,131072)|0;g=h+262144|0;d=m+131072|0;gGC(g|0,d|0,131072)|0;d=h+393216|0;gGC(d|0,f|0,131072)|0;d=h+524288|0;g=m+262144|0;gGC(d|0,g|0,131072)|0;g=h+655360|0;gGC(g|0,f|0,131072)|0;g=h+786432|0;d=m+393216|0;gGC(g|0,d|0,131072)|0;d=h+917504|0;gGC(d|0,f|0,131072)|0;f=0;while(1){if((f|0)>=1024){break}o=9638528+(f<<2)|0;if((c[o>>2]|0)==(m|0)){j=56062;break}else{f=f+1|0}}if((j|0)==56062){gGr(m);c[o>>2]=0}eX5(0,c[3532042]|0,3,8,0,0);a[7461040]=1;f=c[3532132]|0;d=0;while(1){if((d|0)>=1024){p=0;break}q=9638528+(d<<2)|0;if((c[q>>2]|0)==0){j=56066;break}else{d=d+1|0}}do{if((j|0)==56066){d=gGq(8192)|0;c[q>>2]=d;if((d|0)==0){p=0;break}gGz(d|0,0,8192);p=d}}while(0);c[3532250]=p;gGz(p|0,0,8192);d=0;while(1){if((d|0)>=1024){r=0;break}s=9638528+(d<<2)|0;if((c[s>>2]|0)==0){j=56071;break}else{d=d+1|0}}do{if((j|0)==56071){d=gGq(524288)|0;c[s>>2]=d;if((d|0)==0){r=0;break}gGz(d|0,0,524288);r=d}}while(0);c[2433518]=r;gGz(r|0,0,524288);c[2433284]=-16;a[1666928]=0;c[2438974]=f;c[2430058]=1;a[7461048]=0;a[7461032]=1;a[7461016]=1;fxU(0,425984);if((c[2394]|0)==0){t=c[2112932]|0}else{c[2394]=0;d=c[3532596]|0;c[2112932]=d;h=c[3532592]|0;if((h|0)!=0){gGC(9104152,h|0,280)|0}c[2113054]=c[2113060];t=d}d=c[3532204]|0;h=t|0;g=0;while(1){u=d+g|0;c[h>>2]=u;c[h+131072>>2]=u;u=g+1024|0;if(u>>>0>1048575){break}else{h=h+4|0;g=u}}g=c[3532208]|0;h=t+12288|0;d=3145728;while(1){f=g+(d-3145728)|0;c[h>>2]=f;c[h+65536>>2]=f;c[h+131072>>2]=f;f=d+1024|0;if(f>>>0>3211263){break}else{h=h+4|0;d=f}}d=c[3532250]|0;c[t+16384>>2]=d;c[t+81920>>2]=d;c[t+147456>>2]=d;h=d+1024|0;c[t+16388>>2]=h;c[t+81924>>2]=h;c[t+147460>>2]=h;h=d+2048|0;c[t+16392>>2]=h;c[t+81928>>2]=h;c[t+147464>>2]=h;h=d+3072|0;c[t+16396>>2]=h;c[t+81932>>2]=h;c[t+147468>>2]=h;h=d+4096|0;c[t+16400>>2]=h;c[t+81936>>2]=h;c[t+147472>>2]=h;h=d+5120|0;c[t+16404>>2]=h;c[t+81940>>2]=h;c[t+147476>>2]=h;h=d+6144|0;c[t+16408>>2]=h;c[t+81944>>2]=h;c[t+147480>>2]=h;h=d+7168|0;c[t+16412>>2]=h;c[t+81948>>2]=h;c[t+147484>>2]=h;h=c[3532026]|0;c[t+28672>>2]=h;c[t+94208>>2]=h;c[t+159744>>2]=h;d=h+1024|0;c[t+28676>>2]=d;c[t+94212>>2]=d;c[t+159748>>2]=d;d=h+2048|0;c[t+28680>>2]=d;c[t+94216>>2]=d;c[t+159752>>2]=d;d=h+3072|0;c[t+28684>>2]=d;c[t+94220>>2]=d;c[t+159756>>2]=d;d=h+4096|0;c[t+28688>>2]=d;c[t+94224>>2]=d;c[t+159760>>2]=d;d=h+5120|0;c[t+28692>>2]=d;c[t+94228>>2]=d;c[t+159764>>2]=d;d=h+6144|0;c[t+28696>>2]=d;c[t+94232>>2]=d;c[t+159768>>2]=d;d=h+7168|0;c[t+28700>>2]=d;c[t+94236>>2]=d;c[t+159772>>2]=d;d=c[3532278]|0;h=t+32768|0;g=8388608;while(1){c[h>>2]=d+(g-8388608);f=g+1024|0;if(f>>>0>8454143){break}else{h=h+4|0;g=f}}g=c[3531970]|0;h=t+36864|0;d=9437184;while(1){f=g+(d-9437184)|0;c[h>>2]=f;c[h+65536>>2]=f;c[h+131072>>2]=f;f=d+1024|0;if(f>>>0>9502719){break}else{h=h+4|0;d=f}}c[t+196608>>2]=2782;c[t+196648>>2]=1962;c[t+196688>>2]=3392;c[t+196728>>2]=792;d=c[3532592]|0;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);d=c[2439330]|0;h=(d|0)==0;if(!h){g=d;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];g=c[3528484]|0;c[2076596]=g;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;c[d+4180>>2]=1204;c[d+4184>>2]=2494;u=c[3531932]|0;v=0;w=0;while(1){c[d+76+(w<<2)>>2]=u+(w<<8);x=v+1&65535;if((x&65535)>127){y=0;z=0;break}else{v=x;w=x&65535}}while(1){w=u+(z<<8)|0;c[d+76+(z+512<<2)>>2]=w;c[d+76+(z+768<<2)>>2]=w;w=y+1&65535;if((w&65535)>127){break}else{y=w;z=w&65535}}u=c[3531936]|0;c[d+588>>2]=u;w=u+256|0;c[d+592>>2]=w;v=u+512|0;c[d+596>>2]=v;x=u+768|0;c[d+600>>2]=x;A=u+1024|0;c[d+604>>2]=A;B=u+1280|0;c[d+608>>2]=B;C=u+1536|0;c[d+612>>2]=C;D=u+1792|0;c[d+616>>2]=D;c[d+1612>>2]=u;c[d+1616>>2]=w;c[d+1620>>2]=v;c[d+1624>>2]=x;c[d+1628>>2]=A;c[d+1632>>2]=B;c[d+1636>>2]=C;c[d+1640>>2]=D;c[d+2636>>2]=u;c[d+3660>>2]=u;c[d+2640>>2]=w;c[d+3664>>2]=w;c[d+2644>>2]=v;c[d+3668>>2]=v;c[d+2648>>2]=x;c[d+3672>>2]=x;c[d+2652>>2]=A;c[d+3676>>2]=A;c[d+2656>>2]=B;c[d+3680>>2]=B;c[d+2660>>2]=C;c[d+3684>>2]=C;c[d+2664>>2]=D;c[d+3688>>2]=D;if(!h){D=d;gGC(D|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=g;c[2417276]=f;c[1836236]=-1;Ux(0,8e3,0);c[2407030]=256;c[2407068]=3;c[3531954]=3;c[3532118]=2032;eZ8()|0;c[2405144]=0;c[2439438]=0;c[2429772]=0;c[2437780]=0;c[3532090]=0;c[3532102]=0;gGz(14128336,0,5);c[3532098]=0;l=0;return l|0}}while(0);c[3532048]=0;l=1;return l|0}function fgR(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if((a[14128072]|0)!=0){eZ8()|0;c[2405144]=0;c[2439438]=0;c[2429772]=0;c[2437780]=0;c[3532090]=0;c[3532102]=0;gGz(14128336,0,5);c[3532098]=0}do{if(a[7461056]|0){a[14129040]=-1;a[14129041]=-1;a[14129042]=-1;d=0;e=-1;f=-1;g=-1;do{e=(e&255)-((a[14129032+d|0]&1)<<d)&255;f=(f&255)-((a[14129024+d|0]&1)<<d)&255;g=(g&255)-((a[14129016+d|0]&1)<<d)&255;d=d+1|0;}while((d|0)<8);a[14129040]=e;a[14129041]=f;a[14129042]=g}else{if(!(a[7461016]|0)){fjJ();break}a[14128912]=-1;a[14128913]=-1;a[14128914]=-1;d=0;h=-1;i=-1;j=-1;do{h=(h&255)-((a[14128904+d|0]&1)<<d)&255;i=(i&255)-((a[14128896+d|0]&1)<<d)&255;j=(j&255)-((a[14128888+d|0]&1)<<d)&255;d=d+1|0;}while((d|0)<8);a[14128912]=h;a[14128913]=i;a[14128914]=j}}while(0);c[2113031]=0;c[2113030]=0;d=c[2392]|0;if((d|0)>=0){gGz(8452240,0,((d|0)>0?(d<<2)+4|0:4)|0)}c[2113054]=0;d=c[2385548]|0;if((d|0)>0){gGz(9752472,0,((d|0)>1?d<<2:4)|0)}c[2433530]=0;d=0;while(1){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060]}g=d+1|0;f=(ag(c[2113026]|0,g)|0)/10|0;e=f-(c[2113030]|0)|0;f=(d|0)==9;k=f?e-500|0:e;c[2113028]=k;c[2113056]=k;e=RG(k)|0;c[2113054]=(c[2113054]|0)+e;c[2276108]=-1;c[2113056]=-1;c[2113030]=(c[2113030]|0)+e;do{if(f){c[8452200+(c[2394]<<2)>>2]=8197;c[2276080]=1280;if((c[2276079]|0)>>>0<1280){RH(5)}c[2113056]=500;e=RG(500)|0;c[2113054]=(c[2113054]|0)+e;c[2276108]=-1;c[2113056]=-1;c[2113030]=(c[2113030]|0)+e;c[8452200+(c[2394]<<2)>>2]=8198;c[2276080]=1536;if((c[2276079]|0)>>>0>=1536){break}RH(6)}}while(0);f=c[2394]|0;j=c[14130368+(f<<2)>>2]|0;if((j|0)!=0){gGC(j|0,9104152,280)|0}c[8452240+(f<<2)>>2]=c[2113054];c[2394]=-1;f=c[2439330]|0;if((f|0)!=0){j=f;gGC(9706056,j|0,76)|0}b[4853030]=c[2426515]&65535;j=c[2438118]|0;c[2433530]=j;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;i=(ag(c[2113024]|0,g)|0)/10|0;h=c[2113031]|0;e=i-h|0;c[2113028]=e;do{if((e|0)<1){l=0;m=h;n=0;o=f;p=j}else{if((a[f+4188|0]|0)==0){i=gfc(e)|0;k=(c[2433530]|0)+i|0;c[2433530]=k;q=c[1836236]|0;l=i;m=c[2113031]|0;n=q;o=c[9757320+(q<<2)>>2]|0;p=k;break}else{k=j+e|0;c[2433530]=k;l=e;m=h;n=0;o=f;p=k;break}}}while(0);c[2113028]=l;c[2113031]=m+l;if((o|0)!=0){f=o;gGC(f|0,9706056,76)|0}c[9752472+(n<<2)>>2]=p;c[14113936+(n<<2)>>2]=c[2076596];c[9669104+(n<<2)>>2]=c[3541536];c[1836236]=-1;if((g|0)<10){d=g}else{break}}d=c[2112964]|0;if((d|0)!=0){Uu(0,d,a[9688]|0?534:0)}if(a[7461160]|0){d=c[3531966]|0;n=c[3531970]|0;gGC(d|0,n|0,65536)|0;a[7461160]=0}if((c[2112968]|0)==0){r=c[2426962]|0;gu[r&16383]();return 0}gu[c[3532118]&16383]();r=c[2426962]|0;gu[r&16383]();return 0}function fgS(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6312532+(b*112|0)>>2];c[a+104>>2]=c[6312536+(b*112|0)>>2];c[a+108>>2]=c[6312540+(b*112|0)>>2];d=0;return d|0}function fgT(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=6312432+(b*112|0);e=0;return e|0}function fgU(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>26){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3961744+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function fgV(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>28){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6314112+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fgW(){var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;e=i;i=i+120|0;f=e|0;g=e+112|0;h=c[642608+(c[2436]<<2)>>2]|0;j=c[h+128>>2]|0;if((c[h+52>>2]&4|0)==0){c[2113068]=j;k=c[h+132>>2]|0;c[2113070]=k;c[2443814]=j;c[2440436]=k;l=j;m=k}else{c[2113070]=j;k=c[h+132>>2]|0;c[2113068]=k;c[2440436]=j;c[2443814]=k;l=k;m=j}j=ag(l<<1,m)|0;m=gGq(j)|0;c[2112926]=m;if((m|0)!=0){gGz(m|0,0,j|0)}c[3532162]=256;c[3532160]=4;c[3532142]=8;c[3532164]=8;c[3532148]=1983576;c[3532140]=6964024;c[3532138]=6963768;c[3532044]=1;c[3532030]=1;a[7460960]=1;c[3532092]=1;c[3532094]=0;c[3531954]=0;c[3532096]=0;c[2426962]=10922;c[3532118]=7616;b[7064208]=0;b[7064216]=0;b[7064209]=1024;b[7064217]=1024;b[7064210]=2048;b[7064218]=2048;b[7064211]=3072;b[7064219]=3072;b[7064212]=4096;b[7064220]=4096;b[7064213]=5120;b[7064221]=5120;b[7064214]=6144;b[7064222]=6144;b[7064215]=7168;b[7064223]=7168;c[2113026]=2e5;c[2113024]=66666;c[3532042]=8192;c[3532002]=1024;c[3532e3]=6;a[7460944]=1;c[3532004]=16;c[3531998]=684032;c[3531992]=727024;c[3531990]=726960;c[3532034]=8192;eZ9(0)|0;c[3532048]=0;fju();j=c[3532046]|0;m=0;while(1){if((m|0)>=1024){break}n=9638528+(m<<2)|0;if((c[n>>2]|0)==0){o=56179;break}else{m=m+1|0}}do{if((o|0)==56179){m=gGq(j)|0;c[n>>2]=m;if((m|0)==0){break}gGz(m|0,0,j|0);c[3532048]=m;gGz(m|0,0,j|0);fju();c[3532034]=0;if((eZ9(1)|0)==0){p=0}else{q=1;i=e;return q|0}while(1){if((p|0)>=1024){r=0;break}s=9638528+(p<<2)|0;if((c[s>>2]|0)==0){o=56184;break}else{p=p+1|0}}do{if((o|0)==56184){m=gGq(16384)|0;c[s>>2]=m;if((m|0)==0){r=0;break}gGz(m|0,0,16384);r=m}}while(0);c[2442928]=r;gGz(r|0,0,16384);m=0;while(1){if((m|0)>=1024){t=0;break}u=9638528+(m<<2)|0;if((c[u>>2]|0)==0){o=56189;break}else{m=m+1|0}}do{if((o|0)==56189){m=gGq(16384)|0;c[u>>2]=m;if((m|0)==0){t=0;break}gGz(m|0,0,16384);t=m}}while(0);c[3532276]=t;gGz(t|0,0,4096);c[3532274]=4096;a[7461088]=1;eX5(0,c[3532042]|0,1,8,0,0);a[7461080]=1;a[7461056]=1;c[3532034]=8192;m=0;while(1){if((m|0)>=1024){v=0;break}w=9638528+(m<<2)|0;if((c[w>>2]|0)==0){o=56194;break}else{m=m+1|0}}do{if((o|0)==56194){m=gGq(2097152)|0;c[w>>2]=m;if((m|0)==0){v=0;break}gGz(m|0,0,2097152);v=m}}while(0);gGz(v|0,0,2097152);if((R6(v,5,2)|0)!=0){q=1;i=e;return q|0}if((R6(v+1|0,6,2)|0)!=0){q=1;i=e;return q|0}m=v+1572864|0;if((c[3542200]|0)==0){q=1;i=e;return q|0}l=f+108|0;c[l>>2]=0;k=f+100|0;c[k>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,7)|0;do{if((c[l>>2]|0)==0){x=1048576;y=1572864}else{h=c[k>>2]|0;c[g>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](g,7,0)|0;if((h|0)<1){q=1;i=e;return q|0}if((gzL(m,0,7)|0)==0){x=1048576;y=1572864;break}else{q=1}i=e;return q|0}}while(0);while(1){m=a[v+y|0]|0;a[v+x|0]=(m&255)>>>4<<2&12|m&-64;a[v+(x|1)|0]=m<<2&12|(m&255)>>>2<<6;m=y+1|0;if((m|0)<2097152){x=x+2|0;y=m}else{break}}m=c[3532034]|0;k=c[3532e3]|0;l=a[7460944]|0;h=l?16:0;z=c[3532004]|0;A=c[3532002]|0;B=c[3531962]|0;if((m|0)>0){C=ag(z,h)|0;D=(k|0)>0;E=k-1|0;F=(z|0)<1|l^1;l=0;while(1){G=ag(l,C)|0;gGz(B+G|0,0,C|0);if(D){H=ag(l,A)|0;I=0;do{J=1<<E-I;K=(c[684032+(I<<2)>>2]|0)+H|0;if(!F){L=0;do{M=K+(c[726960+(L<<2)>>2]|0)|0;N=(ag(L,h)|0)+G|0;O=0;do{P=M+(c[727024+(O<<2)>>2]|0)|0;if(((d[v+((P|0)/8|0)|0]|0)&128>>>((P&7)>>>0)|0)!=0){P=B+(N+O)|0;a[P]=(d[P]|0|J)&255}O=O+1|0;}while((O|0)<(h|0));L=L+1|0;}while((L|0)<(z|0))}I=I+1|0;}while((I|0)<(k|0))}I=l+1|0;if((I|0)<(m|0)){l=I}else{Q=0;break}}}else{Q=0}while(1){if((Q|0)>=1024){break}R=9638528+(Q<<2)|0;if((c[R>>2]|0)==(v|0)){o=56217;break}else{Q=Q+1|0}}if((o|0)==56217){gGr(v);c[R>>2]=0}fxU(0,425984);if((c[2394]|0)==0){S=c[2112932]|0}else{c[2394]=0;l=c[3532596]|0;c[2112932]=l;m=c[3532592]|0;if((m|0)!=0){gGC(9104152,m|0,280)|0}c[2113054]=c[2113060];S=l}l=c[3532204]|0;m=S|0;k=0;while(1){z=l+k|0;c[m>>2]=z;c[m+131072>>2]=z;z=k+1024|0;if(z>>>0>262143){break}else{m=m+4|0;k=z}}k=c[3532208]|0;m=S+4096|0;l=1048576;while(1){z=k+(l-1048576)|0;c[m>>2]=z;c[m+65536>>2]=z;c[m+131072>>2]=z;z=l+1024|0;if(z>>>0>1114111){break}else{m=m+4|0;l=z}}l=c[3532278]|0;m=S+32768|0;k=8388608;while(1){c[m>>2]=l+(k-8388608);z=k+1024|0;if(z>>>0>8454143){break}else{m=m+4|0;k=z}}k=c[3531970]|0;m=S+36864|0;l=9437184;while(1){z=k+(l-9437184)|0;c[m>>2]=z;c[m+65536>>2]=z;c[m+131072>>2]=z;z=l+1024|0;if(z>>>0>9502719){break}else{m=m+4|0;l=z}}c[S+196608>>2]=1460;c[S+196648>>2]=2714;c[S+196688>>2]=1508;c[S+196728>>2]=3436;l=c[3532592]|0;if((l|0)!=0){gGC(l|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fjv();c[3531954]=1;c[2426962]=11852;c[3532118]=8172;eZ8()|0;c[2405144]=0;c[2439438]=0;c[2429772]=0;c[2437780]=0;c[3532090]=0;c[3532102]=0;gGz(14128336,0,5);c[3532098]=0;q=0;i=e;return q|0}}while(0);c[3532048]=0;q=1;i=e;return q|0}function fgX(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5411316+(b*112|0)>>2];c[a+104>>2]=c[5411320+(b*112|0)>>2];c[a+108>>2]=c[5411324+(b*112|0)>>2];d=0;return d|0}function fgY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=5411216+(b*112|0);e=0;return e|0}function fgZ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>28){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5412896+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fg_(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5409636+(b*112|0)>>2];c[a+104>>2]=c[5409640+(b*112|0)>>2];c[a+108>>2]=c[5409644+(b*112|0)>>2];d=0;return d|0}function fg$(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=5409536+(b*112|0);e=0;return e|0}function fg0(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3951460+(b*112|0)>>2];c[a+104>>2]=c[3951464+(b*112|0)>>2];c[a+108>>2]=c[3951468+(b*112|0)>>2];d=0;return d|0}function fg1(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=3951360+(b*112|0);e=0;return e|0}function fg2(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>38){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1270312+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function fg3(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>44){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3952480+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fg4(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[642608+(c[2436]<<2)>>2]|0;e=c[d+128>>2]|0;if((c[d+52>>2]&4|0)==0){c[2113068]=e;f=c[d+132>>2]|0;c[2113070]=f;c[2443814]=e;c[2440436]=f;g=e;h=f}else{c[2113070]=e;f=c[d+132>>2]|0;c[2113068]=f;c[2440436]=e;c[2443814]=f;g=f;h=e}e=ag(g<<1,h)|0;h=gGq(e)|0;c[2112926]=h;if((h|0)!=0){gGz(h|0,0,e|0)}c[3532044]=1;c[3532030]=1;a[7460960]=1;c[3532092]=1;c[3532094]=0;c[3531954]=0;c[3532096]=0;c[2426962]=10922;c[3532118]=7616;b[7064208]=0;b[7064216]=0;b[7064209]=1024;b[7064217]=1024;b[7064210]=2048;b[7064218]=2048;b[7064211]=3072;b[7064219]=3072;b[7064212]=4096;b[7064220]=4096;b[7064213]=5120;b[7064221]=5120;b[7064214]=6144;b[7064222]=6144;b[7064215]=7168;b[7064223]=7168;c[2113026]=2e5;c[2113024]=66666;a[642488]=1;c[3532162]=1024;c[3532160]=4;c[3532142]=16;c[3532164]=16;c[3532148]=683048;c[3532140]=703496;c[3532138]=703432;c[3532042]=8192;c[3532002]=1024;c[3532e3]=4;a[7460944]=1;c[3532004]=16;c[3531998]=961320;c[3531992]=4969240;c[3531990]=4968824;c[3532034]=16384;eZ9(0)|0;c[3532048]=0;fju();e=c[3532046]|0;h=0;while(1){if((h|0)>=1024){break}i=9638528+(h<<2)|0;if((c[i>>2]|0)==0){j=56308;break}else{h=h+1|0}}do{if((j|0)==56308){h=gGq(e)|0;c[i>>2]=h;if((h|0)==0){break}gGz(h|0,0,e|0);c[3532048]=h;gGz(h|0,0,e|0);fju();h=(fa(c[c[642608+(c[2436]<<2)>>2]>>2]|0,208320)|0)==0;g=c[3532042]|0;if(h){eXS(g,3,51,-4,-1,0,24)}else{eXS(g,3,29,8,-1,0,0)}a[7461080]=1;a[7461040]=1;if((eZ9(1)|0)!=0){k=1;return k|0}fxU(0,425984);if((c[2394]|0)==0){l=c[2112932]|0}else{c[2394]=0;g=c[3532596]|0;c[2112932]=g;h=c[3532592]|0;if((h|0)!=0){gGC(9104152,h|0,280)|0}c[2113054]=c[2113060];l=g}g=c[3532204]|0;h=l|0;f=0;while(1){d=g+f|0;c[h>>2]=d;c[h+131072>>2]=d;d=f+1024|0;if(d>>>0>524287){break}else{h=h+4|0;f=d}}f=c[3532208]|0;h=l+4096|0;g=1048576;while(1){d=f+(g-1048576)|0;c[h>>2]=d;c[h+65536>>2]=d;c[h+131072>>2]=d;d=g+1024|0;if(d>>>0>1114111){break}else{h=h+4|0;g=d}}g=c[3531970]|0;h=l+8192|0;f=2097152;while(1){d=g+(f-2097152)|0;c[h>>2]=d;c[h+65536>>2]=d;c[h+131072>>2]=d;d=f+1024|0;if(d>>>0>2162687){break}else{h=h+4|0;f=d}}f=c[3532232]|0;h=l+16384|0;g=4194304;while(1){d=f+(g-4194304)|0;c[h>>2]=d;c[h+65536>>2]=d;c[h+131072>>2]=d;d=g+1024|0;if(d>>>0>4259839){break}else{h=h+4|0;g=d}}g=c[3532026]|0;c[l+24576>>2]=g;c[l+90112>>2]=g;c[l+155648>>2]=g;h=g+1024|0;c[l+24580>>2]=h;c[l+90116>>2]=h;c[l+155652>>2]=h;h=g+2048|0;c[l+24584>>2]=h;c[l+90120>>2]=h;c[l+155656>>2]=h;h=g+3072|0;c[l+24588>>2]=h;c[l+90124>>2]=h;c[l+155660>>2]=h;h=g+4096|0;c[l+24592>>2]=h;c[l+90128>>2]=h;c[l+155664>>2]=h;h=g+5120|0;c[l+24596>>2]=h;c[l+90132>>2]=h;c[l+155668>>2]=h;h=g+6144|0;c[l+24600>>2]=h;c[l+90136>>2]=h;c[l+155672>>2]=h;h=g+7168|0;c[l+24604>>2]=h;c[l+90140>>2]=h;c[l+155676>>2]=h;c[l+196608>>2]=3308;c[l+196648>>2]=1168;c[l+196688>>2]=1664;c[l+196728>>2]=1788;h=c[3532592]|0;if((h|0)!=0){gGC(h|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fjv();c[3531954]=3;c[2426962]=3132;c[3532118]=11584;eZ8()|0;c[2405144]=0;c[2439438]=0;c[2429772]=0;c[2437780]=0;c[3532090]=0;c[3532102]=0;gGz(14128336,0,5);c[3532098]=0;k=0;return k|0}}while(0);c[3532048]=0;k=1;return k|0}function fg5(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6271548+(b*112|0)>>2];c[a+104>>2]=c[6271552+(b*112|0)>>2];c[a+108>>2]=c[6271556+(b*112|0)>>2];d=0;return d|0}function fg6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=6271448+(b*112|0);e=0;return e|0}function fg7(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>41){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6272568+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fg8(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4006092+(b*112|0)>>2];c[a+104>>2]=c[4006096+(b*112|0)>>2];c[a+108>>2]=c[4006100+(b*112|0)>>2];d=0;return d|0}function fg9(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=4005992+(b*112|0);e=0;return e|0}function fha(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6884524+(b*112|0)>>2];c[a+104>>2]=c[6884528+(b*112|0)>>2];c[a+108>>2]=c[6884532+(b*112|0)>>2];d=0;return d|0}function fhb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=6884424+(b*112|0);e=0;return e|0}function fhc(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>41){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5371144+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function fhd(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>33){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6885544+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fhe(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[642608+(c[2436]<<2)>>2]|0;e=c[d+128>>2]|0;if((c[d+52>>2]&4|0)==0){c[2113068]=e;f=c[d+132>>2]|0;c[2113070]=f;c[2443814]=e;c[2440436]=f;g=e;h=f}else{c[2113070]=e;f=c[d+132>>2]|0;c[2113068]=f;c[2440436]=e;c[2443814]=f;g=f;h=e}e=ag(g<<1,h)|0;h=gGq(e)|0;c[2112926]=h;if((h|0)!=0){gGz(h|0,0,e|0)}c[3532162]=256;c[3532160]=4;c[3532142]=8;c[3532164]=8;c[3532148]=1983576;c[3532140]=6964024;c[3532138]=6963768;c[3532002]=1024;c[3532e3]=4;a[7460944]=1;c[3532004]=16;c[3531998]=961320;c[3531992]=4969240;c[3531990]=4968824;c[3532044]=1;c[3532030]=1;a[7460960]=1;c[3532092]=1;c[3532094]=0;c[3531954]=0;c[3532096]=0;c[2426962]=10922;c[3532118]=7616;b[7064208]=0;b[7064216]=0;b[7064209]=1024;b[7064217]=1024;b[7064210]=2048;b[7064218]=2048;b[7064211]=3072;b[7064219]=3072;b[7064212]=4096;b[7064220]=4096;b[7064213]=5120;b[7064221]=5120;b[7064214]=6144;b[7064222]=6144;b[7064215]=7168;b[7064223]=7168;c[2113026]=2e5;c[2113024]=66666;c[3532042]=32768;c[3532034]=16384;eZ9(0)|0;c[3532048]=0;fju();e=c[3532046]|0;h=0;while(1){if((h|0)>=1024){break}i=9638528+(h<<2)|0;if((c[i>>2]|0)==0){j=56399;break}else{h=h+1|0}}do{if((j|0)==56399){h=gGq(e)|0;c[i>>2]=h;if((h|0)==0){break}gGz(h|0,0,e|0);c[3532048]=h;gGz(h|0,0,e|0);fju();if((eZ9(1)|0)!=0){k=1;return k|0}eX5(0,c[3532042]|0,3,8,0,c[3532024]|0);a[7461080]=1;a[7461040]=1;fxU(0,425984);if((c[2394]|0)==0){l=c[2112932]|0}else{c[2394]=0;h=c[3532596]|0;c[2112932]=h;g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060];l=h}h=c[3532204]|0;g=l|0;f=0;while(1){d=h+f|0;c[g>>2]=d;c[g+131072>>2]=d;d=f+1024|0;if(d>>>0>1048575){break}else{g=g+4|0;f=d}}f=c[3532208]|0;g=l+4096|0;h=1048576;while(1){d=f+(h-1048576)|0;c[g>>2]=d;c[g+65536>>2]=d;c[g+131072>>2]=d;d=h+1024|0;if(d>>>0>1114111){break}else{g=g+4|0;h=d}}h=c[3532026]|0;c[l+8192>>2]=h;c[l+73728>>2]=h;c[l+139264>>2]=h;g=h+1024|0;c[l+8196>>2]=g;c[l+73732>>2]=g;c[l+139268>>2]=g;g=h+2048|0;c[l+8200>>2]=g;c[l+73736>>2]=g;c[l+139272>>2]=g;g=h+3072|0;c[l+8204>>2]=g;c[l+73740>>2]=g;c[l+139276>>2]=g;g=h+4096|0;c[l+8208>>2]=g;c[l+73744>>2]=g;c[l+139280>>2]=g;g=h+5120|0;c[l+8212>>2]=g;c[l+73748>>2]=g;c[l+139284>>2]=g;g=h+6144|0;c[l+8216>>2]=g;c[l+73752>>2]=g;c[l+139288>>2]=g;g=h+7168|0;c[l+8220>>2]=g;c[l+73756>>2]=g;c[l+139292>>2]=g;g=c[3532278]|0;h=l+32768|0;f=8388608;while(1){c[h>>2]=g+(f-8388608);d=f+1024|0;if(d>>>0>8454143){break}else{h=h+4|0;f=d}}f=c[3531970]|0;h=l+36864|0;g=9437184;while(1){d=f+(g-9437184)|0;c[h>>2]=d;c[h+65536>>2]=d;c[h+131072>>2]=d;d=g+1024|0;if(d>>>0>9502719){break}else{h=h+4|0;g=d}}c[l+196608>>2]=2678;c[l+196648>>2]=2510;c[l+196688>>2]=258;c[l+196728>>2]=2144;g=c[3532592]|0;if((g|0)!=0){gGC(g|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fjv();c[3531954]=3;eZ8()|0;c[2405144]=0;c[2439438]=0;c[2429772]=0;c[2437780]=0;c[3532090]=0;c[3532102]=0;gGz(14128336,0,5);c[3532098]=0;k=0;return k|0}}while(0);c[3532048]=0;k=1;return k|0}function fhf(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6287172+(b*112|0)>>2];c[a+104>>2]=c[6287176+(b*112|0)>>2];c[a+108>>2]=c[6287180+(b*112|0)>>2];d=0;return d|0}function fhg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=6287072+(b*112|0);e=0;return e|0}function fhh(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>33){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6288192+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fhi(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6145180+(b*112|0)>>2];c[a+104>>2]=c[6145184+(b*112|0)>>2];c[a+108>>2]=c[6145188+(b*112|0)>>2];d=0;return d|0}function fhj(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=6145080+(b*112|0);e=0;return e|0}function fhk(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>33){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6146200+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fhl(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3881092+(b*112|0)>>2];c[a+104>>2]=c[3881096+(b*112|0)>>2];c[a+108>>2]=c[3881100+(b*112|0)>>2];d=0;return d|0}function fhm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=3880992+(b*112|0);e=0;return e|0}function fhn(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1240352+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function fho(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>41){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3882112+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fhp(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[642608+(c[2436]<<2)>>2]|0;e=c[d+128>>2]|0;if((c[d+52>>2]&4|0)==0){c[2113068]=e;f=c[d+132>>2]|0;c[2113070]=f;c[2443814]=e;c[2440436]=f;g=e;h=f}else{c[2113070]=e;f=c[d+132>>2]|0;c[2113068]=f;c[2440436]=e;c[2443814]=f;g=f;h=e}e=ag(g<<1,h)|0;h=gGq(e)|0;c[2112926]=h;if((h|0)!=0){gGz(h|0,0,e|0)}c[3532162]=256;c[3532160]=4;c[3532142]=8;c[3532164]=8;c[3532148]=1983576;c[3532140]=6964024;c[3532138]=6963768;c[3532002]=1024;c[3532e3]=4;a[7460944]=1;c[3532004]=16;c[3531998]=961320;c[3531992]=4969240;c[3531990]=4968824;c[3532044]=1;c[3532030]=1;a[7460960]=1;c[3532092]=1;c[3532094]=0;c[3531954]=0;c[3532096]=0;c[2426962]=10922;c[3532118]=7616;b[7064208]=0;b[7064216]=0;b[7064209]=1024;b[7064217]=1024;b[7064210]=2048;b[7064218]=2048;b[7064211]=3072;b[7064219]=3072;b[7064212]=4096;b[7064220]=4096;b[7064213]=5120;b[7064221]=5120;b[7064214]=6144;b[7064222]=6144;b[7064215]=7168;b[7064223]=7168;c[2113026]=2e5;c[2113024]=66666;c[3532042]=32768;c[3532034]=8192;eZ9(0)|0;c[3532048]=0;fju();e=c[3532046]|0;h=0;while(1){if((h|0)>=1024){break}i=9638528+(h<<2)|0;if((c[i>>2]|0)==0){j=56494;break}else{h=h+1|0}}do{if((j|0)==56494){h=gGq(e)|0;c[i>>2]=h;if((h|0)==0){break}gGz(h|0,0,e|0);c[3532048]=h;gGz(h|0,0,e|0);fju();if((eZ9(1)|0)!=0){k=1;return k|0}eX5(0,c[3532042]|0,3,8,0,c[3532024]|0);a[7461080]=1;a[7461040]=1;a[7461016]=1;fxU(0,425984);if((c[2394]|0)==0){l=c[2112932]|0}else{c[2394]=0;h=c[3532596]|0;c[2112932]=h;g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060];l=h}h=c[3532204]|0;g=l|0;f=0;while(1){d=h+f|0;c[g>>2]=d;c[g+131072>>2]=d;d=f+1024|0;if(d>>>0>786431){break}else{g=g+4|0;f=d}}f=c[3532208]|0;g=l+4096|0;h=1048576;while(1){d=f+(h-1048576)|0;c[g>>2]=d;c[g+65536>>2]=d;c[g+131072>>2]=d;d=h+1024|0;if(d>>>0>1114111){break}else{g=g+4|0;h=d}}h=c[3532026]|0;c[l+8192>>2]=h;c[l+73728>>2]=h;c[l+139264>>2]=h;g=h+1024|0;c[l+8196>>2]=g;c[l+73732>>2]=g;c[l+139268>>2]=g;g=h+2048|0;c[l+8200>>2]=g;c[l+73736>>2]=g;c[l+139272>>2]=g;g=h+3072|0;c[l+8204>>2]=g;c[l+73740>>2]=g;c[l+139276>>2]=g;g=h+4096|0;c[l+8208>>2]=g;c[l+73744>>2]=g;c[l+139280>>2]=g;g=h+5120|0;c[l+8212>>2]=g;c[l+73748>>2]=g;c[l+139284>>2]=g;g=h+6144|0;c[l+8216>>2]=g;c[l+73752>>2]=g;c[l+139288>>2]=g;g=h+7168|0;c[l+8220>>2]=g;c[l+73756>>2]=g;c[l+139292>>2]=g;g=c[3532278]|0;h=l+32768|0;f=8388608;while(1){c[h>>2]=g+(f-8388608);d=f+1024|0;if(d>>>0>8454143){break}else{h=h+4|0;f=d}}f=c[3531970]|0;h=l+36864|0;g=9437184;while(1){d=f+(g-9437184)|0;c[h>>2]=d;c[h+65536>>2]=d;c[h+131072>>2]=d;d=g+1024|0;if(d>>>0>9502719){break}else{h=h+4|0;g=d}}c[l+196608>>2]=2960;c[l+196648>>2]=2946;c[l+196688>>2]=3244;c[l+196728>>2]=1116;g=c[3532592]|0;if((g|0)!=0){gGC(g|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fjv();c[3531954]=3;eZ8()|0;c[2405144]=0;c[2439438]=0;c[2429772]=0;c[2437780]=0;c[3532090]=0;c[3532102]=0;gGz(14128336,0,5);c[3532098]=0;k=0;return k|0}}while(0);c[3532048]=0;k=1;return k|0}function fhq(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1874228+(b*112|0)>>2];c[a+104>>2]=c[1874232+(b*112|0)>>2];c[a+108>>2]=c[1874236+(b*112|0)>>2];d=0;return d|0}function fhr(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=1874128+(b*112|0);e=0;return e|0}function fhs(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>41){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1875248+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fht(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5323428+(b*112|0)>>2];c[a+104>>2]=c[5323432+(b*112|0)>>2];c[a+108>>2]=c[5323436+(b*112|0)>>2];d=0;return d|0}function fhu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=5323328+(b*112|0);e=0;return e|0}function fhv(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1851248+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function fhw(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>39){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5324672+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fhx(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[642608+(c[2436]<<2)>>2]|0;e=c[d+128>>2]|0;if((c[d+52>>2]&4|0)==0){c[2113068]=e;f=c[d+132>>2]|0;c[2113070]=f;c[2443814]=e;c[2440436]=f;g=e;h=f}else{c[2113070]=e;f=c[d+132>>2]|0;c[2113068]=f;c[2440436]=e;c[2443814]=f;g=f;h=e}e=ag(g<<1,h)|0;h=gGq(e)|0;c[2112926]=h;if((h|0)!=0){gGz(h|0,0,e|0)}c[3532162]=256;c[3532160]=4;c[3532142]=8;c[3532164]=8;c[3532148]=1983576;c[3532140]=6964024;c[3532138]=6963768;c[3532002]=1024;c[3532e3]=4;a[7460944]=1;c[3532004]=16;c[3531998]=961320;c[3531992]=4969240;c[3531990]=4968824;c[3532044]=1;c[3532030]=1;a[7460960]=1;c[3532092]=1;c[3532094]=0;c[3531954]=0;c[3532096]=0;c[2426962]=10922;c[3532118]=7616;b[7064208]=0;b[7064216]=0;b[7064209]=1024;b[7064217]=1024;b[7064210]=2048;b[7064218]=2048;b[7064211]=3072;b[7064219]=3072;b[7064212]=4096;b[7064220]=4096;b[7064213]=5120;b[7064221]=5120;b[7064214]=6144;b[7064222]=6144;b[7064215]=7168;b[7064223]=7168;c[2113026]=2e5;c[2113024]=66666;c[3532042]=32768;c[3532034]=16384;eZ9(0)|0;c[3532048]=0;fju();e=c[3532046]|0;h=0;while(1){if((h|0)>=1024){break}i=9638528+(h<<2)|0;if((c[i>>2]|0)==0){j=56570;break}else{h=h+1|0}}do{if((j|0)==56570){h=gGq(e)|0;c[i>>2]=h;if((h|0)==0){break}gGz(h|0,0,e|0);c[3532048]=h;gGz(h|0,0,e|0);fju();if((eZ9(1)|0)!=0){k=1;return k|0}eX5(0,c[3532042]|0,1,8,0,c[3532024]|0);a[7461080]=1;a[7461040]=1;a[7461016]=1;fxU(0,425984);if((c[2394]|0)==0){l=c[2112932]|0}else{c[2394]=0;h=c[3532596]|0;c[2112932]=h;g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060];l=h}h=c[3532204]|0;g=l|0;f=0;while(1){d=h+f|0;c[g>>2]=d;c[g+131072>>2]=d;d=f+1024|0;if(d>>>0>262143){break}else{g=g+4|0;f=d}}f=l+2048|0;g=524288;while(1){d=h+(g-262144)|0;c[f>>2]=d;c[f+131072>>2]=d;d=g+1024|0;if(d>>>0>1048575){break}else{f=f+4|0;g=d}}g=c[3532208]|0;f=l+4096|0;h=1048576;while(1){d=g+(h-1048576)|0;c[f>>2]=d;c[f+65536>>2]=d;c[f+131072>>2]=d;d=h+1024|0;if(d>>>0>1114111){break}else{f=f+4|0;h=d}}h=c[3532026]|0;c[l+8192>>2]=h;c[l+73728>>2]=h;c[l+139264>>2]=h;f=h+1024|0;c[l+8196>>2]=f;c[l+73732>>2]=f;c[l+139268>>2]=f;f=h+2048|0;c[l+8200>>2]=f;c[l+73736>>2]=f;c[l+139272>>2]=f;f=h+3072|0;c[l+8204>>2]=f;c[l+73740>>2]=f;c[l+139276>>2]=f;f=h+4096|0;c[l+8208>>2]=f;c[l+73744>>2]=f;c[l+139280>>2]=f;f=h+5120|0;c[l+8212>>2]=f;c[l+73748>>2]=f;c[l+139284>>2]=f;f=h+6144|0;c[l+8216>>2]=f;c[l+73752>>2]=f;c[l+139288>>2]=f;f=h+7168|0;c[l+8220>>2]=f;c[l+73756>>2]=f;c[l+139292>>2]=f;f=c[3532278]|0;h=l+32768|0;g=8388608;while(1){c[h>>2]=f+(g-8388608);d=g+1024|0;if(d>>>0>8454143){break}else{h=h+4|0;g=d}}g=c[3531970]|0;h=l+36864|0;f=9437184;while(1){d=g+(f-9437184)|0;c[h>>2]=d;c[h+65536>>2]=d;c[h+131072>>2]=d;d=f+1024|0;if(d>>>0>9502719){break}else{h=h+4|0;f=d}}c[l+196608>>2]=2978;c[l+196648>>2]=3162;c[l+196688>>2]=222;c[l+196728>>2]=416;f=c[3532592]|0;if((f|0)!=0){gGC(f|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fjv();c[3531954]=1;eZ8()|0;c[2405144]=0;c[2439438]=0;c[2429772]=0;c[2437780]=0;c[3532090]=0;c[3532102]=0;gGz(14128336,0,5);c[3532098]=0;k=0;return k|0}}while(0);c[3532048]=0;k=1;return k|0}function fhy(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5307300+(b*112|0)>>2];c[a+104>>2]=c[5307304+(b*112|0)>>2];c[a+108>>2]=c[5307308+(b*112|0)>>2];d=0;return d|0}function fhz(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=5307200+(b*112|0);e=0;return e|0}function fhA(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1280832+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function fhB(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>44){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5308208+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fhC(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[642608+(c[2436]<<2)>>2]|0;e=c[d+128>>2]|0;if((c[d+52>>2]&4|0)==0){c[2113068]=e;f=c[d+132>>2]|0;c[2113070]=f;c[2443814]=e;c[2440436]=f;g=e;h=f}else{c[2113070]=e;f=c[d+132>>2]|0;c[2113068]=f;c[2440436]=e;c[2443814]=f;g=f;h=e}e=ag(g<<1,h)|0;h=gGq(e)|0;c[2112926]=h;if((h|0)!=0){gGz(h|0,0,e|0)}c[3532162]=256;c[3532160]=4;c[3532142]=8;c[3532164]=8;c[3532148]=1983576;c[3532140]=6964024;c[3532138]=6963768;c[3532002]=1024;c[3532e3]=4;a[7460944]=1;c[3532004]=16;c[3531998]=961320;c[3531992]=4969240;c[3531990]=4968824;c[3532044]=1;c[3532030]=1;a[7460960]=1;c[3532092]=1;c[3532094]=0;c[3531954]=0;c[3532096]=0;c[2426962]=10922;c[3532118]=7616;b[7064208]=0;b[7064216]=0;b[7064209]=1024;b[7064217]=1024;b[7064210]=2048;b[7064218]=2048;b[7064211]=3072;b[7064219]=3072;b[7064212]=4096;b[7064220]=4096;b[7064213]=5120;b[7064221]=5120;b[7064214]=6144;b[7064222]=6144;b[7064215]=7168;b[7064223]=7168;c[2113026]=2e5;c[2113024]=66666;c[3532042]=16384;c[3532034]=8192;eZ9(0)|0;c[3532048]=0;fju();e=c[3532046]|0;h=0;while(1){if((h|0)>=1024){break}i=9638528+(h<<2)|0;if((c[i>>2]|0)==0){j=56629;break}else{h=h+1|0}}do{if((j|0)==56629){h=gGq(e)|0;c[i>>2]=h;if((h|0)==0){break}gGz(h|0,0,e|0);c[3532048]=h;gGz(h|0,0,e|0);fju();if((eZ9(1)|0)!=0){k=1;return k|0}eX5(0,c[3532042]|0,3,8,0,c[3532024]|0);a[7461080]=1;a[7461056]=1;fxU(0,425984);if((c[2394]|0)==0){l=c[2112932]|0}else{c[2394]=0;h=c[3532596]|0;c[2112932]=h;g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060];l=h}h=c[3532204]|0;g=l|0;f=0;while(1){d=h+f|0;c[g>>2]=d;c[g+131072>>2]=d;d=f+1024|0;if(d>>>0>524287){break}else{g=g+4|0;f=d}}f=c[3532208]|0;g=l+4096|0;h=1048576;while(1){d=f+(h-1048576)|0;c[g>>2]=d;c[g+65536>>2]=d;c[g+131072>>2]=d;d=h+1024|0;if(d>>>0>1114111){break}else{g=g+4|0;h=d}}h=c[3532026]|0;c[l+8192>>2]=h;c[l+73728>>2]=h;c[l+139264>>2]=h;g=h+1024|0;c[l+8196>>2]=g;c[l+73732>>2]=g;c[l+139268>>2]=g;g=h+2048|0;c[l+8200>>2]=g;c[l+73736>>2]=g;c[l+139272>>2]=g;g=h+3072|0;c[l+8204>>2]=g;c[l+73740>>2]=g;c[l+139276>>2]=g;g=h+4096|0;c[l+8208>>2]=g;c[l+73744>>2]=g;c[l+139280>>2]=g;g=h+5120|0;c[l+8212>>2]=g;c[l+73748>>2]=g;c[l+139284>>2]=g;g=h+6144|0;c[l+8216>>2]=g;c[l+73752>>2]=g;c[l+139288>>2]=g;g=h+7168|0;c[l+8220>>2]=g;c[l+73756>>2]=g;c[l+139292>>2]=g;g=c[3532278]|0;h=l+32768|0;f=8388608;while(1){c[h>>2]=g+(f-8388608);d=f+1024|0;if(d>>>0>8454143){break}else{h=h+4|0;f=d}}f=c[3531970]|0;h=l+36864|0;g=9437184;while(1){d=f+(g-9437184)|0;c[h>>2]=d;c[h+65536>>2]=d;c[h+131072>>2]=d;d=g+1024|0;if(d>>>0>9502719){break}else{h=h+4|0;g=d}}c[l+196608>>2]=1954;c[l+196648>>2]=3420;c[l+196688>>2]=2950;c[l+196728>>2]=430;g=c[3532592]|0;if((g|0)!=0){gGC(g|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fjv();c[3531954]=3;c[2426962]=11852;eZ8()|0;c[2405144]=0;c[2439438]=0;c[2429772]=0;c[2437780]=0;c[3532090]=0;c[3532102]=0;gGz(14128336,0,5);c[3532098]=0;k=0;return k|0}}while(0);c[3532048]=0;k=1;return k|0}function fhD(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3796652+(b*112|0)>>2];c[a+104>>2]=c[3796656+(b*112|0)>>2];c[a+108>>2]=c[3796660+(b*112|0)>>2];d=0;return d|0}function fhE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=3796552+(b*112|0);e=0;return e|0}function fhF(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>44){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3797560+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fhG(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3732540+(b*112|0)>>2];c[a+104>>2]=c[3732544+(b*112|0)>>2];c[a+108>>2]=c[3732548+(b*112|0)>>2];d=0;return d|0}function fhH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=3732440+(b*112|0);e=0;return e|0}function fhI(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3753668+(b*112|0)>>2];c[a+104>>2]=c[3753672+(b*112|0)>>2];c[a+108>>2]=c[3753676+(b*112|0)>>2];d=0;return d|0}function fhJ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=3753568+(b*112|0);e=0;return e|0}function fhK(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1232112+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function fhL(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>41){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3755360+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fhM(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=c[642608+(c[2436]<<2)>>2]|0;e=c[d+128>>2]|0;if((c[d+52>>2]&4|0)==0){c[2113068]=e;f=c[d+132>>2]|0;c[2113070]=f;c[2443814]=e;c[2440436]=f;g=e;h=f}else{c[2113070]=e;f=c[d+132>>2]|0;c[2113068]=f;c[2440436]=e;c[2443814]=f;g=f;h=e}e=ag(g<<1,h)|0;h=gGq(e)|0;c[2112926]=h;if((h|0)!=0){gGz(h|0,0,e|0)}c[3532162]=256;c[3532160]=4;c[3532142]=8;c[3532164]=8;c[3532148]=1983576;c[3532140]=6964024;c[3532138]=6963768;c[3532002]=1024;c[3532e3]=4;a[7460944]=1;c[3532004]=16;c[3531998]=961320;c[3531992]=4969240;c[3531990]=4968824;c[3532044]=1;c[3532030]=1;a[7460960]=1;c[3532092]=1;c[3532094]=0;c[3531954]=0;c[3532096]=0;c[2426962]=10922;c[3532118]=7616;b[7064208]=0;b[7064216]=0;b[7064209]=1024;b[7064217]=1024;b[7064210]=2048;b[7064218]=2048;b[7064211]=3072;b[7064219]=3072;b[7064212]=4096;b[7064220]=4096;b[7064213]=5120;b[7064221]=5120;b[7064214]=6144;b[7064222]=6144;b[7064215]=7168;b[7064223]=7168;c[2113026]=2e5;c[2113024]=66666;c[3532042]=16384;c[3532034]=8192;eZ9(0)|0;c[3532048]=0;fju();e=c[3532046]|0;h=0;while(1){if((h|0)>=1024){break}i=9638528+(h<<2)|0;if((c[i>>2]|0)==0){j=56717;break}else{h=h+1|0}}do{if((j|0)==56717){h=gGq(e)|0;c[i>>2]=h;if((h|0)==0){break}gGz(h|0,0,e|0);c[3532048]=h;gGz(h|0,0,e|0);fju();if((eZ9(1)|0)!=0){k=1;return k|0}eX5(0,c[3532042]|0,3,8,0,c[3532024]|0);a[7461080]=1;a[7461056]=1;fxU(0,425984);if((c[2394]|0)==0){l=c[2112932]|0}else{c[2394]=0;h=c[3532596]|0;c[2112932]=h;g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060];l=h}h=c[3532204]|0;g=l|0;f=0;while(1){d=h+f|0;c[g>>2]=d;c[g+131072>>2]=d;d=f+1024|0;if(d>>>0>524287){break}else{g=g+4|0;f=d}}f=c[3532208]|0;g=l+8192|0;h=2097152;while(1){d=f+(h-2097152)|0;c[g>>2]=d;c[g+65536>>2]=d;c[g+131072>>2]=d;d=h+1024|0;if(d>>>0>2162687){break}else{g=g+4|0;h=d}}h=c[3532026]|0;c[l+12288>>2]=h;c[l+77824>>2]=h;c[l+143360>>2]=h;g=h+1024|0;c[l+12292>>2]=g;c[l+77828>>2]=g;c[l+143364>>2]=g;g=h+2048|0;c[l+12296>>2]=g;c[l+77832>>2]=g;c[l+143368>>2]=g;g=h+3072|0;c[l+12300>>2]=g;c[l+77836>>2]=g;c[l+143372>>2]=g;g=h+4096|0;c[l+12304>>2]=g;c[l+77840>>2]=g;c[l+143376>>2]=g;g=h+5120|0;c[l+12308>>2]=g;c[l+77844>>2]=g;c[l+143380>>2]=g;g=h+6144|0;c[l+12312>>2]=g;c[l+77848>>2]=g;c[l+143384>>2]=g;g=h+7168|0;c[l+12316>>2]=g;c[l+77852>>2]=g;c[l+143388>>2]=g;g=c[3532278]|0;h=l+24576|0;d=6291456;while(1){c[h>>2]=g+(d-6291456);m=d+1024|0;if(m>>>0>6356991){break}else{h=h+4|0;d=m}}d=l+24832|0;h=6356992;while(1){g=f+(h-6291456)|0;c[d>>2]=g;c[d+65536>>2]=g;c[d+131072>>2]=g;g=h+1024|0;if(g>>>0>6422527){break}else{d=d+4|0;h=g}}h=c[3531970]|0;d=l+32768|0;f=8388608;while(1){g=h+(f-8388608)|0;c[d>>2]=g;c[d+65536>>2]=g;c[d+131072>>2]=g;g=f+1024|0;if(g>>>0>8454143){break}else{d=d+4|0;f=g}}c[l+196608>>2]=1498;c[l+196648>>2]=758;c[l+196688>>2]=1464;c[l+196728>>2]=3186;f=c[3532592]|0;if((f|0)!=0){gGC(f|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fjv();f=0;while(1){if((f|0)>=1024){n=0;break}o=9638528+(f<<2)|0;if((c[o>>2]|0)==0){j=56740;break}else{f=f+1|0}}do{if((j|0)==56740){f=gGq(2048)|0;c[o>>2]=f;if((f|0)==0){n=0;break}gGz(f|0,0,2048);n=f}}while(0);c[2439440]=n;gGz(n|0,0,2048);a[7461144]=1;c[3531954]=3;eZ8()|0;c[2405144]=0;c[2439438]=0;c[2429772]=0;c[2437780]=0;c[3532090]=0;c[3532102]=0;gGz(14128336,0,5);c[3532098]=0;k=0;return k|0}}while(0);c[3532048]=0;k=1;return k|0}function fhN(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1835308+(b*112|0)>>2];c[a+104>>2]=c[1835312+(b*112|0)>>2];c[a+108>>2]=c[1835316+(b*112|0)>>2];d=0;return d|0}function fhO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=1835208+(b*112|0);e=0;return e|0}function fhP(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>41){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1836328+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fhQ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1833684+(b*112|0)>>2];c[a+104>>2]=c[1833688+(b*112|0)>>2];c[a+108>>2]=c[1833692+(b*112|0)>>2];d=0;return d|0}function fhR(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=1833584+(b*112|0);e=0;return e|0}function fhS(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>41){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1834704+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fhT(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6233420+(b*112|0)>>2];c[a+104>>2]=c[6233424+(b*112|0)>>2];c[a+108>>2]=c[6233428+(b*112|0)>>2];d=0;return d|0}function fhU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=6233320+(b*112|0);e=0;return e|0}function fhV(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1956936+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function fhW(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>41){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6234440+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fhX(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[642608+(c[2436]<<2)>>2]|0;e=c[d+128>>2]|0;if((c[d+52>>2]&4|0)==0){c[2113068]=e;f=c[d+132>>2]|0;c[2113070]=f;c[2443814]=e;c[2440436]=f;g=e;h=f}else{c[2113070]=e;f=c[d+132>>2]|0;c[2113068]=f;c[2440436]=e;c[2443814]=f;g=f;h=e}e=ag(g<<1,h)|0;h=gGq(e)|0;c[2112926]=h;if((h|0)!=0){gGz(h|0,0,e|0)}c[3532002]=1024;c[3532e3]=4;a[7460944]=1;c[3532004]=16;c[3531998]=961320;c[3531992]=4969240;c[3531990]=4968824;c[3532044]=1;c[3532030]=1;a[7460960]=1;c[3532092]=1;c[3532094]=0;c[3531954]=0;c[3532096]=0;c[2426962]=10922;c[3532118]=7616;b[7064208]=0;b[7064216]=0;b[7064209]=1024;b[7064217]=1024;b[7064210]=2048;b[7064218]=2048;b[7064211]=3072;b[7064219]=3072;b[7064212]=4096;b[7064220]=4096;b[7064213]=5120;b[7064221]=5120;b[7064214]=6144;b[7064222]=6144;b[7064215]=7168;b[7064223]=7168;c[2113026]=2e5;c[2113024]=66666;c[3532162]=1024;c[3532160]=4;c[3532142]=16;c[3532164]=16;c[3532148]=683048;c[3532140]=703496;c[3532138]=703432;c[3532042]=8192;c[3532034]=8192;eZ9(0)|0;c[3532048]=0;fju();e=c[3532046]|0;h=0;while(1){if((h|0)>=1024){break}i=9638528+(h<<2)|0;if((c[i>>2]|0)==0){j=56819;break}else{h=h+1|0}}do{if((j|0)==56819){h=gGq(e)|0;c[i>>2]=h;if((h|0)==0){break}gGz(h|0,0,e|0);c[3532048]=h;gGz(h|0,0,e|0);fju();if((eZ9(1)|0)!=0){k=1;return k|0}eXS(c[3532042]|0,3,50,-4,1,0,24);a[1666920]=1;a[7461080]=1;a[7461040]=1;a[7461016]=1;fxU(0,425984);if((c[2394]|0)==0){l=c[2112932]|0}else{c[2394]=0;h=c[3532596]|0;c[2112932]=h;g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060];l=h}h=c[3532204]|0;g=l|0;f=0;while(1){d=h+f|0;c[g>>2]=d;c[g+131072>>2]=d;d=f+1024|0;if(d>>>0>786431){break}else{g=g+4|0;f=d}}f=c[3532208]|0;g=l+4096|0;h=1048576;while(1){d=f+(h-1048576)|0;c[g>>2]=d;c[g+65536>>2]=d;c[g+131072>>2]=d;d=h+1024|0;if(d>>>0>1114111){break}else{g=g+4|0;h=d}}h=c[3531970]|0;g=l+12288|0;f=3145728;while(1){d=h+(f-3145728)|0;c[g>>2]=d;c[g+65536>>2]=d;c[g+131072>>2]=d;d=f+1024|0;if(d>>>0>3211263){break}else{g=g+4|0;f=d}}f=c[3532232]|0;g=l+20480|0;h=5242880;while(1){d=f+(h-5242880)|0;c[g>>2]=d;c[g+65536>>2]=d;c[g+131072>>2]=d;d=h+1024|0;if(d>>>0>5308415){break}else{g=g+4|0;h=d}}h=c[3532026]|0;c[l+28672>>2]=h;c[l+94208>>2]=h;c[l+159744>>2]=h;g=h+1024|0;c[l+28676>>2]=g;c[l+94212>>2]=g;c[l+159748>>2]=g;g=h+2048|0;c[l+28680>>2]=g;c[l+94216>>2]=g;c[l+159752>>2]=g;g=h+3072|0;c[l+28684>>2]=g;c[l+94220>>2]=g;c[l+159756>>2]=g;g=h+4096|0;c[l+28688>>2]=g;c[l+94224>>2]=g;c[l+159760>>2]=g;g=h+5120|0;c[l+28692>>2]=g;c[l+94228>>2]=g;c[l+159764>>2]=g;g=h+6144|0;c[l+28696>>2]=g;c[l+94232>>2]=g;c[l+159768>>2]=g;g=h+7168|0;c[l+28700>>2]=g;c[l+94236>>2]=g;c[l+159772>>2]=g;g=h+8192|0;c[l+28704>>2]=g;c[l+94240>>2]=g;c[l+159776>>2]=g;g=h+9216|0;c[l+28708>>2]=g;c[l+94244>>2]=g;c[l+159780>>2]=g;g=h+10240|0;c[l+28712>>2]=g;c[l+94248>>2]=g;c[l+159784>>2]=g;g=h+11264|0;c[l+28716>>2]=g;c[l+94252>>2]=g;c[l+159788>>2]=g;g=h+12288|0;c[l+28720>>2]=g;c[l+94256>>2]=g;c[l+159792>>2]=g;g=h+13312|0;c[l+28724>>2]=g;c[l+94260>>2]=g;c[l+159796>>2]=g;g=h+14336|0;c[l+28728>>2]=g;c[l+94264>>2]=g;c[l+159800>>2]=g;g=h+15360|0;c[l+28732>>2]=g;c[l+94268>>2]=g;c[l+159804>>2]=g;c[l+196608>>2]=12;c[l+196648>>2]=1936;c[l+196688>>2]=992;c[l+196728>>2]=1702;g=c[3532592]|0;if((g|0)!=0){gGC(g|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fjv();c[3531954]=3;c[3532118]=12028;eZ8()|0;c[2405144]=0;c[2439438]=0;c[2429772]=0;c[2437780]=0;c[3532090]=0;c[3532102]=0;gGz(14128336,0,5);c[3532098]=0;k=0;return k|0}}while(0);c[3532048]=0;k=1;return k|0}function fhY(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5280588+(b*112|0)>>2];c[a+104>>2]=c[5280592+(b*112|0)>>2];c[a+108>>2]=c[5280596+(b*112|0)>>2];d=0;return d|0}function fhZ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=5280488+(b*112|0);e=0;return e|0}function fh_(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>41){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5281608+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fh$(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3728156+(b*112|0)>>2];c[a+104>>2]=c[3728160+(b*112|0)>>2];c[a+108>>2]=c[3728164+(b*112|0)>>2];d=0;return d|0}function fh0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=3728056+(b*112|0);e=0;return e|0}function fh1(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>26){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1230504+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function fh2(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>25){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3728952+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fh3(){var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;e=i;i=i+120|0;f=e|0;g=e+112|0;h=c[642608+(c[2436]<<2)>>2]|0;j=c[h+128>>2]|0;if((c[h+52>>2]&4|0)==0){c[2113068]=j;k=c[h+132>>2]|0;c[2113070]=k;c[2443814]=j;c[2440436]=k;l=j;m=k}else{c[2113070]=j;k=c[h+132>>2]|0;c[2113068]=k;c[2440436]=j;c[2443814]=k;l=k;m=j}j=ag(l<<1,m)|0;m=gGq(j)|0;c[2112926]=m;if((m|0)!=0){gGz(m|0,0,j|0)}c[3532162]=256;c[3532160]=4;c[3532142]=8;c[3532164]=8;c[3532148]=1983576;c[3532140]=6964024;c[3532138]=6963768;c[3532002]=1024;c[3532e3]=4;a[7460944]=1;c[3532004]=16;c[3531998]=961320;c[3531992]=4969240;c[3531990]=4968824;c[3532044]=1;c[3532030]=1;a[7460960]=1;c[3532092]=1;c[3532094]=0;c[3531954]=0;c[3532096]=0;c[2426962]=10922;c[3532118]=7616;b[7064208]=0;b[7064216]=0;b[7064209]=1024;b[7064217]=1024;b[7064210]=2048;b[7064218]=2048;b[7064211]=3072;b[7064219]=3072;b[7064212]=4096;b[7064220]=4096;b[7064213]=5120;b[7064221]=5120;b[7064214]=6144;b[7064222]=6144;b[7064215]=7168;b[7064223]=7168;c[2113026]=2e5;c[2113024]=66666;c[3532042]=65536;c[3532034]=4096;eZ9(0)|0;c[3532048]=0;fju();j=c[3532046]|0;m=0;while(1){if((m|0)>=1024){break}n=9638528+(m<<2)|0;if((c[n>>2]|0)==0){o=56895;break}else{m=m+1|0}}do{if((o|0)==56895){m=gGq(j)|0;c[n>>2]=m;if((m|0)==0){break}gGz(m|0,0,j|0);c[3532048]=m;gGz(m|0,0,j|0);fju();if((eZ9(1)|0)!=0){p=1;i=e;return p|0}m=c[3531994]|0;l=0;while(1){if((l|0)>=1024){q=0;break}r=9638528+(l<<2)|0;if((c[r>>2]|0)==0){o=56901;break}else{l=l+1|0}}do{if((o|0)==56901){l=gGq(m)|0;c[r>>2]=l;if((l|0)==0){q=0;break}gGz(l|0,0,m|0);q=l}}while(0);gGz(q|0,0,c[3531994]|0);if((c[3542200]|0)==0){p=1;i=e;return p|0}m=f+108|0;c[m>>2]=0;l=f+100|0;c[l>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,6)|0;do{if((c[m>>2]|0)!=0){k=c[l>>2]|0;c[g>>2]=9534384;h=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[h&16383](g,6,0)|0;if((k|0)<1){p=1;i=e;return p|0}if((gzL(q,0,6)|0)==0){break}else{p=1}i=e;return p|0}}while(0);l=c[3531994]|0;if((l|0)!=0){m=0;do{k=q+m|0;h=a[k]|0;s=q+(m|1)|0;t=a[s]|0;a[k]=(t&255)>>>4|t<<4;a[s]=(h&255)>>>4|h<<4;m=m+2|0;}while(m>>>0<l>>>0)}l=c[3532034]|0;m=c[3532e3]|0;h=a[7460944]|0;s=h?16:0;t=c[3532004]|0;k=c[3531998]|0;u=c[3531992]|0;v=c[3531990]|0;w=c[3532002]|0;x=c[3531962]|0;if((l|0)>0){y=ag(t,s)|0;z=(m|0)>0;A=m-1|0;B=(t|0)<1|h^1;h=0;while(1){C=ag(h,y)|0;gGz(x+C|0,0,y|0);if(z){D=ag(h,w)|0;E=0;do{F=1<<A-E;G=(c[k+(E<<2)>>2]|0)+D|0;if(!B){H=0;do{I=G+(c[v+(H<<2)>>2]|0)|0;J=(ag(H,s)|0)+C|0;K=0;do{L=I+(c[u+(K<<2)>>2]|0)|0;if(((d[q+((L|0)/8|0)|0]|0)&128>>>((L&7)>>>0)|0)!=0){L=x+(J+K)|0;a[L]=(d[L]|0|F)&255}K=K+1|0;}while((K|0)<(s|0));H=H+1|0;}while((H|0)<(t|0))}E=E+1|0;}while((E|0)<(m|0))}E=h+1|0;if((E|0)<(l|0)){h=E}else{M=0;break}}}else{M=0}while(1){if((M|0)>=1024){N=0;break}O=9638528+(M<<2)|0;if((c[O>>2]|0)==(q|0)){o=56923;break}else{M=M+1|0}}if((o|0)==56923){gGr(q);c[O>>2]=0;N=0}while(1){if((N|0)>=1024){P=0;break}Q=9638528+(N<<2)|0;if((c[Q>>2]|0)==0){o=56926;break}else{N=N+1|0}}do{if((o|0)==56926){h=gGq(16384)|0;c[Q>>2]=h;if((h|0)==0){P=0;break}gGz(h|0,0,16384);P=h}}while(0);c[2442928]=P;gGz(P|0,0,16384);h=0;while(1){if((h|0)>=1024){R=0;break}S=9638528+(h<<2)|0;if((c[S>>2]|0)==0){o=56931;break}else{h=h+1|0}}do{if((o|0)==56931){h=gGq(16384)|0;c[S>>2]=h;if((h|0)==0){R=0;break}gGz(h|0,0,16384);R=h}}while(0);c[3532276]=R;gGz(R|0,0,4096);c[3532274]=4096;a[7461088]=1;eX5(0,c[3532042]|0,0,8,0,0);c[2433298]=32767;a[7461080]=1;fxU(0,425984);if((c[2394]|0)==0){T=c[2112932]|0}else{c[2394]=0;h=c[3532596]|0;c[2112932]=h;l=c[3532592]|0;if((l|0)!=0){gGC(9104152,l|0,280)|0}c[2113054]=c[2113060];T=h}h=c[3532204]|0;l=T|0;m=0;while(1){t=h+m|0;c[l>>2]=t;c[l+131072>>2]=t;t=m+1024|0;if(t>>>0>262143){break}else{l=l+4|0;m=t}}m=T+2048|0;l=524288;while(1){t=h+(l-262144)|0;c[m>>2]=t;c[m+131072>>2]=t;t=l+1024|0;if(t>>>0>1048575){break}else{m=m+4|0;l=t}}l=c[3532208]|0;m=T+4352|0;h=1114112;while(1){t=l+(h-1114112)|0;c[m>>2]=t;c[m+65536>>2]=t;c[m+131072>>2]=t;t=h+1024|0;if(t>>>0>1245183){break}else{m=m+4|0;h=t}}h=c[3532278]|0;m=T+16384|0;l=4194304;while(1){c[m>>2]=h+(l-4194304);t=l+1024|0;if(t>>>0>4259839){break}else{m=m+4|0;l=t}}l=c[3531970]|0;m=T+20480|0;h=5242880;while(1){t=l+(h-5242880)|0;c[m>>2]=t;c[m+65536>>2]=t;c[m+131072>>2]=t;t=h+1024|0;if(t>>>0>5308415){break}else{m=m+4|0;h=t}}c[T+196608>>2]=1458;c[T+196648>>2]=1052;c[T+196688>>2]=1636;c[T+196728>>2]=280;h=c[3532592]|0;if((h|0)!=0){gGC(h|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fjv();c[3532118]=8172;eZ8()|0;c[2405144]=0;c[2439438]=0;c[2429772]=0;c[2437780]=0;c[3532090]=0;c[3532102]=0;gGz(14128336,0,5);c[3532098]=0;p=0;i=e;return p|0}}while(0);c[3532048]=0;p=1;i=e;return p|0}function fh4(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1826748+(b*112|0)>>2];c[a+104>>2]=c[1826752+(b*112|0)>>2];c[a+108>>2]=c[1826756+(b*112|0)>>2];d=0;return d|0}function fh5(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=1826648+(b*112|0);e=0;return e|0}function fh6(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6203140+(b*112|0)>>2];c[a+104>>2]=c[6203144+(b*112|0)>>2];c[a+108>>2]=c[6203148+(b*112|0)>>2];d=0;return d|0}function fh7(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=6203040+(b*112|0);e=0;return e|0}function fh8(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>37){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3661048+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function fh9(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>41){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6204160+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fia(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[642608+(c[2436]<<2)>>2]|0;e=c[d+128>>2]|0;if((c[d+52>>2]&4|0)==0){c[2113068]=e;f=c[d+132>>2]|0;c[2113070]=f;c[2443814]=e;c[2440436]=f;g=e;h=f}else{c[2113070]=e;f=c[d+132>>2]|0;c[2113068]=f;c[2440436]=e;c[2443814]=f;g=f;h=e}e=ag(g<<1,h)|0;h=gGq(e)|0;c[2112926]=h;if((h|0)!=0){gGz(h|0,0,e|0)}c[3532162]=256;c[3532160]=4;c[3532142]=8;c[3532164]=8;c[3532148]=1983576;c[3532140]=6964024;c[3532138]=6963768;c[3532002]=1024;c[3532e3]=4;a[7460944]=1;c[3532004]=16;c[3531998]=961320;c[3531992]=4969240;c[3531990]=4968824;c[3532044]=1;c[3532030]=1;a[7460960]=1;c[3532092]=1;c[3532094]=0;c[3531954]=0;c[3532096]=0;c[2426962]=10922;c[3532118]=7616;b[7064208]=0;b[7064216]=0;b[7064209]=1024;b[7064217]=1024;b[7064210]=2048;b[7064218]=2048;b[7064211]=3072;b[7064219]=3072;b[7064212]=4096;b[7064220]=4096;b[7064213]=5120;b[7064221]=5120;b[7064214]=6144;b[7064222]=6144;b[7064215]=7168;b[7064223]=7168;c[2113026]=2e5;c[2113024]=66666;c[3532042]=16384;c[3532034]=16384;eZ9(0)|0;c[3532048]=0;fju();e=c[3532046]|0;h=0;while(1){if((h|0)>=1024){break}i=9638528+(h<<2)|0;if((c[i>>2]|0)==0){j=57004;break}else{h=h+1|0}}do{if((j|0)==57004){h=gGq(e)|0;c[i>>2]=h;if((h|0)==0){break}gGz(h|0,0,e|0);c[3532048]=h;gGz(h|0,0,e|0);fju();if((eZ9(1)|0)!=0){k=1;return k|0}eX5(0,c[3532042]|0,0,8,0,c[3532024]|0);a[7461080]=1;fxU(0,425984);if((c[2394]|0)==0){l=c[2112932]|0}else{c[2394]=0;h=c[3532596]|0;c[2112932]=h;g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060];l=h}h=c[3532204]|0;g=l|0;f=0;while(1){d=h+f|0;c[g>>2]=d;c[g+131072>>2]=d;d=f+1024|0;if(d>>>0>524287){break}else{g=g+4|0;f=d}}f=c[3532208]|0;g=l+4096|0;h=1048576;while(1){d=f+(h-1048576)|0;c[g>>2]=d;c[g+65536>>2]=d;c[g+131072>>2]=d;d=h+1024|0;if(d>>>0>1114111){break}else{g=g+4|0;h=d}}h=c[3532026]|0;c[l+8192>>2]=h;c[l+73728>>2]=h;c[l+139264>>2]=h;g=h+1024|0;c[l+8196>>2]=g;c[l+73732>>2]=g;c[l+139268>>2]=g;g=h+2048|0;c[l+8200>>2]=g;c[l+73736>>2]=g;c[l+139272>>2]=g;g=h+3072|0;c[l+8204>>2]=g;c[l+73740>>2]=g;c[l+139276>>2]=g;g=h+4096|0;c[l+8208>>2]=g;c[l+73744>>2]=g;c[l+139280>>2]=g;g=h+5120|0;c[l+8212>>2]=g;c[l+73748>>2]=g;c[l+139284>>2]=g;g=h+6144|0;c[l+8216>>2]=g;c[l+73752>>2]=g;c[l+139288>>2]=g;g=h+7168|0;c[l+8220>>2]=g;c[l+73756>>2]=g;c[l+139292>>2]=g;g=c[3532278]|0;h=l+32768|0;f=8388608;while(1){c[h>>2]=g+(f-8388608);d=f+1024|0;if(d>>>0>8454143){break}else{h=h+4|0;f=d}}f=c[3531970]|0;h=l+36864|0;g=9437184;while(1){d=f+(g-9437184)|0;c[h>>2]=d;c[h+65536>>2]=d;c[h+131072>>2]=d;d=g+1024|0;if(d>>>0>9502719){break}else{h=h+4|0;g=d}}c[l+196608>>2]=2980;c[l+196648>>2]=982;c[l+196688>>2]=2298;c[l+196728>>2]=184;g=c[3532592]|0;if((g|0)!=0){gGC(g|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fjv();eZ8()|0;c[2405144]=0;c[2439438]=0;c[2429772]=0;c[2437780]=0;c[3532090]=0;c[3532102]=0;gGz(14128336,0,5);c[3532098]=0;k=0;return k|0}}while(0);c[3532048]=0;k=1;return k|0}function fib(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5209468+(b*112|0)>>2];c[a+104>>2]=c[5209472+(b*112|0)>>2];c[a+108>>2]=c[5209476+(b*112|0)>>2];d=0;return d|0}function fic(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=5209368+(b*112|0);e=0;return e|0}function fid(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>41){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5210488+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fie(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5207844+(b*112|0)>>2];c[a+104>>2]=c[5207848+(b*112|0)>>2];c[a+108>>2]=c[5207852+(b*112|0)>>2];d=0;return d|0}function fif(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=5207744+(b*112|0);e=0;return e|0}function fig(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>41){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5208864+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fih(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3607932+(b*112|0)>>2];c[a+104>>2]=c[3607936+(b*112|0)>>2];c[a+108>>2]=c[3607940+(b*112|0)>>2];d=0;return d|0}function fii(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=3607832+(b*112|0);e=0;return e|0}function fij(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1956936+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function fik(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>37){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3608952+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fil(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=c[642608+(c[2436]<<2)>>2]|0;e=c[d+128>>2]|0;if((c[d+52>>2]&4|0)==0){c[2113068]=e;f=c[d+132>>2]|0;c[2113070]=f;c[2443814]=e;c[2440436]=f;g=e;h=f}else{c[2113070]=e;f=c[d+132>>2]|0;c[2113068]=f;c[2440436]=e;c[2443814]=f;g=f;h=e}e=ag(g<<1,h)|0;h=gGq(e)|0;c[2112926]=h;if((h|0)!=0){gGz(h|0,0,e|0)}c[3532162]=256;c[3532160]=4;c[3532142]=8;c[3532164]=8;c[3532148]=1983576;c[3532140]=6964024;c[3532138]=6963768;c[3532002]=1024;c[3532e3]=4;a[7460944]=1;c[3532004]=16;c[3531998]=961320;c[3531992]=4969240;c[3531990]=4968824;c[3532044]=1;c[3532030]=1;a[7460960]=1;c[3532092]=1;c[3532094]=0;c[3531954]=0;c[3532096]=0;c[2426962]=10922;c[3532118]=7616;b[7064208]=0;b[7064216]=0;b[7064209]=1024;b[7064217]=1024;b[7064210]=2048;b[7064218]=2048;b[7064211]=3072;b[7064219]=3072;b[7064212]=4096;b[7064220]=4096;b[7064213]=5120;b[7064221]=5120;b[7064214]=6144;b[7064222]=6144;b[7064215]=7168;b[7064223]=7168;c[2113026]=2e5;c[2113024]=66666;a[7461184]=1;a[7461176]=1;a[7461168]=1;a[7461192]=1;c[3532158]=1217568;c[3532152]=6168528;c[3532150]=6168496;c[3532038]=16384;c[3532042]=32768;c[3532034]=16384;eZ9(0)|0;c[3532048]=0;fju();e=c[3532046]|0;h=0;while(1){if((h|0)>=1024){break}i=9638528+(h<<2)|0;if((c[i>>2]|0)==0){j=57099;break}else{h=h+1|0}}do{if((j|0)==57099){h=gGq(e)|0;c[i>>2]=h;if((h|0)==0){break}gGz(h|0,0,e|0);c[3532048]=h;gGz(h|0,0,e|0);fju();if((eZ9(1)|0)!=0){k=1;return k|0}eX5(0,c[3532042]|0,3,8,0,c[3532024]|0);a[7461080]=1;a[7461040]=1;h=c[3532132]|0;g=0;while(1){if((g|0)>=1024){l=0;break}m=9638528+(g<<2)|0;if((c[m>>2]|0)==0){j=57105;break}else{g=g+1|0}}do{if((j|0)==57105){g=gGq(8192)|0;c[m>>2]=g;if((g|0)==0){l=0;break}gGz(g|0,0,8192);l=g}}while(0);c[3532250]=l;gGz(l|0,0,8192);g=0;while(1){if((g|0)>=1024){n=0;break}o=9638528+(g<<2)|0;if((c[o>>2]|0)==0){j=57110;break}else{g=g+1|0}}do{if((j|0)==57110){g=gGq(524288)|0;c[o>>2]=g;if((g|0)==0){n=0;break}gGz(g|0,0,524288);n=g}}while(0);c[2433518]=n;gGz(n|0,0,524288);c[2433284]=-10;a[1666928]=0;c[2438974]=h;c[2430058]=1;a[7461048]=0;a[7461032]=1;a[7461016]=1;fxU(0,425984);if((c[2394]|0)==0){p=c[2112932]|0}else{c[2394]=0;g=c[3532596]|0;c[2112932]=g;f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];p=g}g=c[3532204]|0;f=p|0;d=0;while(1){q=g+d|0;c[f>>2]=q;c[f+131072>>2]=q;q=d+1024|0;if(q>>>0>786431){break}else{f=f+4|0;d=q}}d=c[3532208]|0;f=p+12288|0;g=3145728;while(1){h=d+(g-3145728)|0;c[f>>2]=h;c[f+65536>>2]=h;c[f+131072>>2]=h;h=g+1024|0;if(h>>>0>3211263){break}else{f=f+4|0;g=h}}g=c[3532250]|0;c[p+16384>>2]=g;c[p+81920>>2]=g;c[p+147456>>2]=g;f=g+1024|0;c[p+16388>>2]=f;c[p+81924>>2]=f;c[p+147460>>2]=f;f=g+2048|0;c[p+16392>>2]=f;c[p+81928>>2]=f;c[p+147464>>2]=f;f=g+3072|0;c[p+16396>>2]=f;c[p+81932>>2]=f;c[p+147468>>2]=f;f=g+4096|0;c[p+16400>>2]=f;c[p+81936>>2]=f;c[p+147472>>2]=f;f=g+5120|0;c[p+16404>>2]=f;c[p+81940>>2]=f;c[p+147476>>2]=f;f=g+6144|0;c[p+16408>>2]=f;c[p+81944>>2]=f;c[p+147480>>2]=f;f=g+7168|0;c[p+16412>>2]=f;c[p+81948>>2]=f;c[p+147484>>2]=f;f=c[3532026]|0;c[p+28672>>2]=f;c[p+94208>>2]=f;c[p+159744>>2]=f;g=f+1024|0;c[p+28676>>2]=g;c[p+94212>>2]=g;c[p+159748>>2]=g;g=f+2048|0;c[p+28680>>2]=g;c[p+94216>>2]=g;c[p+159752>>2]=g;g=f+3072|0;c[p+28684>>2]=g;c[p+94220>>2]=g;c[p+159756>>2]=g;g=f+4096|0;c[p+28688>>2]=g;c[p+94224>>2]=g;c[p+159760>>2]=g;g=f+5120|0;c[p+28692>>2]=g;c[p+94228>>2]=g;c[p+159764>>2]=g;g=f+6144|0;c[p+28696>>2]=g;c[p+94232>>2]=g;c[p+159768>>2]=g;g=f+7168|0;c[p+28700>>2]=g;c[p+94236>>2]=g;c[p+159772>>2]=g;g=c[3532278]|0;f=p+32768|0;d=8388608;while(1){c[f>>2]=g+(d-8388608);h=d+1024|0;if(h>>>0>8454143){break}else{f=f+4|0;d=h}}d=c[3531978]|0;c[p+24576>>2]=d;c[p+90112>>2]=d;c[p+155648>>2]=d;f=d+1024|0;c[p+24580>>2]=f;c[p+90116>>2]=f;c[p+155652>>2]=f;f=d+2048|0;c[p+24584>>2]=f;c[p+90120>>2]=f;c[p+155656>>2]=f;f=d+3072|0;c[p+24588>>2]=f;c[p+90124>>2]=f;c[p+155660>>2]=f;f=d+4096|0;c[p+24592>>2]=f;c[p+90128>>2]=f;c[p+155664>>2]=f;f=d+5120|0;c[p+24596>>2]=f;c[p+90132>>2]=f;c[p+155668>>2]=f;f=d+6144|0;c[p+24600>>2]=f;c[p+90136>>2]=f;c[p+155672>>2]=f;f=d+7168|0;c[p+24604>>2]=f;c[p+90140>>2]=f;c[p+155676>>2]=f;f=d+8192|0;c[p+24608>>2]=f;c[p+90144>>2]=f;c[p+155680>>2]=f;f=d+9216|0;c[p+24612>>2]=f;c[p+90148>>2]=f;c[p+155684>>2]=f;f=d+10240|0;c[p+24616>>2]=f;c[p+90152>>2]=f;c[p+155688>>2]=f;f=d+11264|0;c[p+24620>>2]=f;c[p+90156>>2]=f;c[p+155692>>2]=f;f=d+12288|0;c[p+24624>>2]=f;c[p+90160>>2]=f;c[p+155696>>2]=f;f=d+13312|0;c[p+24628>>2]=f;c[p+90164>>2]=f;c[p+155700>>2]=f;f=d+14336|0;c[p+24632>>2]=f;c[p+90168>>2]=f;c[p+155704>>2]=f;f=d+15360|0;c[p+24636>>2]=f;c[p+90172>>2]=f;c[p+155708>>2]=f;f=c[3531970]|0;d=p+36864|0;g=9437184;while(1){h=f+(g-9437184)|0;c[d>>2]=h;c[d+65536>>2]=h;c[d+131072>>2]=h;h=g+1024|0;if(h>>>0>9502719){break}else{d=d+4|0;g=h}}c[p+196608>>2]=160;c[p+196648>>2]=1928;c[p+196688>>2]=104;c[p+196728>>2]=274;g=c[3532592]|0;if((g|0)!=0){gGC(g|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fjv();c[3531954]=3;c[3532096]=2;c[3532118]=12392;eZ8()|0;c[2405144]=0;c[2439438]=0;c[2429772]=0;c[2437780]=0;c[3532090]=0;c[3532102]=0;gGz(14128336,0,5);c[3532098]=0;k=0;return k|0}}while(0);c[3532048]=0;k=1;return k|0}function fim(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1778068+(b*112|0)>>2];c[a+104>>2]=c[1778072+(b*112|0)>>2];c[a+108>>2]=c[1778076+(b*112|0)>>2];d=0;return d|0}function fin(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=1777968+(b*112|0);e=0;return e|0}function fio(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>37){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1779088+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fip(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5136188+(b*112|0)>>2];c[a+104>>2]=c[5136192+(b*112|0)>>2];c[a+108>>2]=c[5136196+(b*112|0)>>2];d=0;return d|0}function fiq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=5136088+(b*112|0);e=0;return e|0}function fir(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1764912+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function fis(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>27){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5136984+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fit(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=c[642608+(c[2436]<<2)>>2]|0;e=c[d+128>>2]|0;if((c[d+52>>2]&4|0)==0){c[2113068]=e;f=c[d+132>>2]|0;c[2113070]=f;c[2443814]=e;c[2440436]=f;g=e;h=f}else{c[2113070]=e;f=c[d+132>>2]|0;c[2113068]=f;c[2440436]=e;c[2443814]=f;g=f;h=e}e=ag(g<<1,h)|0;h=gGq(e)|0;c[2112926]=h;if((h|0)!=0){gGz(h|0,0,e|0)}c[3532162]=256;c[3532160]=4;c[3532142]=8;c[3532164]=8;c[3532148]=1983576;c[3532140]=6964024;c[3532138]=6963768;c[3532002]=1024;c[3532e3]=4;a[7460944]=1;c[3532004]=16;c[3531998]=961320;c[3531992]=4969240;c[3531990]=4968824;c[3532044]=1;c[3532030]=1;a[7460960]=1;c[3532092]=1;c[3532094]=0;c[3531954]=0;c[3532096]=0;c[2426962]=10922;c[3532118]=7616;b[7064208]=0;b[7064216]=0;b[7064209]=1024;b[7064217]=1024;b[7064210]=2048;b[7064218]=2048;b[7064211]=3072;b[7064219]=3072;b[7064212]=4096;b[7064220]=4096;b[7064213]=5120;b[7064221]=5120;b[7064214]=6144;b[7064222]=6144;b[7064215]=7168;b[7064223]=7168;c[2113026]=2e5;c[2113024]=66666;c[3532042]=32768;c[3532034]=16384;eZ9(0)|0;c[3532048]=0;fju();e=c[3532046]|0;h=0;while(1){if((h|0)>=1024){break}i=9638528+(h<<2)|0;if((c[i>>2]|0)==0){j=57185;break}else{h=h+1|0}}do{if((j|0)==57185){h=gGq(e)|0;c[i>>2]=h;if((h|0)==0){break}gGz(h|0,0,e|0);c[3532048]=h;gGz(h|0,0,e|0);fju();if((eZ9(1)|0)!=0){k=1;return k|0}eX5(0,c[3532042]|0,3,8,0,c[3532024]|0);a[7461080]=1;a[7461040]=1;a[7461016]=1;fxU(0,425984);if((c[2394]|0)==0){l=c[2112932]|0}else{c[2394]=0;h=c[3532596]|0;c[2112932]=h;g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060];l=h}h=c[3532204]|0;g=l|0;f=0;while(1){d=h+f|0;c[g>>2]=d;c[g+131072>>2]=d;d=f+1024|0;if(d>>>0>524287){break}else{g=g+4|0;f=d}}f=c[3532208]|0;g=l+4096|0;d=1048576;while(1){m=f+(d-1048576)|0;c[g>>2]=m;c[g+65536>>2]=m;c[g+131072>>2]=m;m=d+1024|0;if(m>>>0>1114111){break}else{g=g+4|0;d=m}}d=l+12288|0;g=3145728;while(1){f=h+(g-2621440)|0;c[d>>2]=f;c[d+131072>>2]=f;f=g+1024|0;if(f>>>0>4194303){break}else{d=d+4|0;g=f}}g=c[3531978]|0;c[l+24576>>2]=g;c[l+90112>>2]=g;c[l+155648>>2]=g;d=g+1024|0;c[l+24580>>2]=d;c[l+90116>>2]=d;c[l+155652>>2]=d;d=g+2048|0;c[l+24584>>2]=d;c[l+90120>>2]=d;c[l+155656>>2]=d;d=g+3072|0;c[l+24588>>2]=d;c[l+90124>>2]=d;c[l+155660>>2]=d;d=g+4096|0;c[l+24592>>2]=d;c[l+90128>>2]=d;c[l+155664>>2]=d;d=g+5120|0;c[l+24596>>2]=d;c[l+90132>>2]=d;c[l+155668>>2]=d;d=g+6144|0;c[l+24600>>2]=d;c[l+90136>>2]=d;c[l+155672>>2]=d;d=g+7168|0;c[l+24604>>2]=d;c[l+90140>>2]=d;c[l+155676>>2]=d;d=g+8192|0;c[l+24608>>2]=d;c[l+90144>>2]=d;c[l+155680>>2]=d;d=g+9216|0;c[l+24612>>2]=d;c[l+90148>>2]=d;c[l+155684>>2]=d;d=g+10240|0;c[l+24616>>2]=d;c[l+90152>>2]=d;c[l+155688>>2]=d;d=g+11264|0;c[l+24620>>2]=d;c[l+90156>>2]=d;c[l+155692>>2]=d;d=g+12288|0;c[l+24624>>2]=d;c[l+90160>>2]=d;c[l+155696>>2]=d;d=g+13312|0;c[l+24628>>2]=d;c[l+90164>>2]=d;c[l+155700>>2]=d;d=g+14336|0;c[l+24632>>2]=d;c[l+90168>>2]=d;c[l+155704>>2]=d;d=g+15360|0;c[l+24636>>2]=d;c[l+90172>>2]=d;c[l+155708>>2]=d;d=c[3532026]|0;c[l+28672>>2]=d;c[l+94208>>2]=d;c[l+159744>>2]=d;g=d+1024|0;c[l+28676>>2]=g;c[l+94212>>2]=g;c[l+159748>>2]=g;g=d+2048|0;c[l+28680>>2]=g;c[l+94216>>2]=g;c[l+159752>>2]=g;g=d+3072|0;c[l+28684>>2]=g;c[l+94220>>2]=g;c[l+159756>>2]=g;g=d+4096|0;c[l+28688>>2]=g;c[l+94224>>2]=g;c[l+159760>>2]=g;g=d+5120|0;c[l+28692>>2]=g;c[l+94228>>2]=g;c[l+159764>>2]=g;g=d+6144|0;c[l+28696>>2]=g;c[l+94232>>2]=g;c[l+159768>>2]=g;g=d+7168|0;c[l+28700>>2]=g;c[l+94236>>2]=g;c[l+159772>>2]=g;g=c[3531970]|0;d=l+32768|0;h=8388608;while(1){f=g+(h-8388608)|0;c[d>>2]=f;c[d+65536>>2]=f;c[d+131072>>2]=f;f=h+1024|0;if(f>>>0>8454143){break}else{d=d+4|0;h=f}}h=c[3532278]|0;d=l+36864|0;g=9437184;while(1){c[d>>2]=h+(g-9437184);f=g+1024|0;if(f>>>0>9502719){break}else{d=d+4|0;g=f}}c[l+196608>>2]=2130;c[l+196648>>2]=326;c[l+196688>>2]=2134;c[l+196728>>2]=2840;g=c[3532592]|0;if((g|0)!=0){gGC(g|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fjv();c[3531954]=3;c[3532096]=3;eZ8()|0;c[2405144]=0;c[2439438]=0;c[2429772]=0;c[2437780]=0;c[3532090]=0;c[3532102]=0;gGz(14128336,0,5);c[3532098]=0;k=0;return k|0}}while(0);c[3532048]=0;k=1;return k|0}function fiu(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3595596+(b*112|0)>>2];c[a+104>>2]=c[3595600+(b*112|0)>>2];c[a+108>>2]=c[3595604+(b*112|0)>>2];d=0;return d|0}function fiv(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=3595496+(b*112|0);e=0;return e|0}function fiw(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1208544+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function fix(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>25){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3596280+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fiy(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=c[642608+(c[2436]<<2)>>2]|0;e=c[d+128>>2]|0;if((c[d+52>>2]&4|0)==0){c[2113068]=e;f=c[d+132>>2]|0;c[2113070]=f;c[2443814]=e;c[2440436]=f;g=e;h=f}else{c[2113070]=e;f=c[d+132>>2]|0;c[2113068]=f;c[2440436]=e;c[2443814]=f;g=f;h=e}e=ag(g<<1,h)|0;h=gGq(e)|0;c[2112926]=h;if((h|0)!=0){gGz(h|0,0,e|0)}c[3532162]=256;c[3532160]=4;c[3532142]=8;c[3532164]=8;c[3532148]=1983576;c[3532140]=6964024;c[3532138]=6963768;c[3532002]=1024;c[3532e3]=4;a[7460944]=1;c[3532004]=16;c[3531998]=961320;c[3531992]=4969240;c[3531990]=4968824;c[3532044]=1;c[3532030]=1;a[7460960]=1;c[3532092]=1;c[3532094]=0;c[3531954]=0;c[3532096]=0;c[2426962]=10922;c[3532118]=7616;b[7064208]=0;b[7064216]=0;b[7064209]=1024;b[7064217]=1024;b[7064210]=2048;b[7064218]=2048;b[7064211]=3072;b[7064219]=3072;b[7064212]=4096;b[7064220]=4096;b[7064213]=5120;b[7064221]=5120;b[7064214]=6144;b[7064222]=6144;b[7064215]=7168;b[7064223]=7168;c[2113026]=2e5;c[2113024]=66666;c[3532042]=32768;c[3532034]=16384;eZ9(0)|0;c[3532048]=0;fju();e=c[3532046]|0;h=0;while(1){if((h|0)>=1024){break}i=9638528+(h<<2)|0;if((c[i>>2]|0)==0){j=57244;break}else{h=h+1|0}}do{if((j|0)==57244){h=gGq(e)|0;c[i>>2]=h;if((h|0)==0){break}gGz(h|0,0,e|0);c[3532048]=h;gGz(h|0,0,e|0);fju();if((eZ9(1)|0)!=0){k=1;return k|0}eX5(0,c[3532042]|0,3,8,0,c[3532024]|0);a[7461080]=1;a[7461040]=1;a[7461016]=1;fxU(0,425984);if((c[2394]|0)==0){l=c[2112932]|0}else{c[2394]=0;h=c[3532596]|0;c[2112932]=h;g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060];l=h}h=c[3532204]|0;g=l|0;f=0;while(1){d=h+f|0;c[g>>2]=d;c[g+131072>>2]=d;d=f+1024|0;if(d>>>0>524287){break}else{g=g+4|0;f=d}}f=c[3532208]|0;g=l+8192|0;d=2097152;while(1){m=f+(d-2097152)|0;c[g>>2]=m;c[g+65536>>2]=m;c[g+131072>>2]=m;m=d+1024|0;if(m>>>0>2162687){break}else{g=g+4|0;d=m}}d=c[3532026]|0;c[l+12288>>2]=d;c[l+77824>>2]=d;c[l+143360>>2]=d;g=d+1024|0;c[l+12292>>2]=g;c[l+77828>>2]=g;c[l+143364>>2]=g;g=d+2048|0;c[l+12296>>2]=g;c[l+77832>>2]=g;c[l+143368>>2]=g;g=d+3072|0;c[l+12300>>2]=g;c[l+77836>>2]=g;c[l+143372>>2]=g;g=d+4096|0;c[l+12304>>2]=g;c[l+77840>>2]=g;c[l+143376>>2]=g;g=d+5120|0;c[l+12308>>2]=g;c[l+77844>>2]=g;c[l+143380>>2]=g;g=d+6144|0;c[l+12312>>2]=g;c[l+77848>>2]=g;c[l+143384>>2]=g;g=d+7168|0;c[l+12316>>2]=g;c[l+77852>>2]=g;c[l+143388>>2]=g;g=c[3531970]|0;d=l+16384|0;f=4194304;while(1){m=g+(f-4194304)|0;c[d>>2]=m;c[d+65536>>2]=m;c[d+131072>>2]=m;m=f+1024|0;if(m>>>0>4259839){break}else{d=d+4|0;f=m}}f=c[3532278]|0;d=l+20480|0;g=5242880;while(1){c[d>>2]=f+(g-5242880);m=g+1024|0;if(m>>>0>5308415){break}else{d=d+4|0;g=m}}g=l+24576|0;d=6291456;while(1){f=h+(d-5767168)|0;c[g>>2]=f;c[g+131072>>2]=f;f=d+1024|0;if(f>>>0>7340031){break}else{g=g+4|0;d=f}}d=c[3531978]|0;c[l+45056>>2]=d;c[l+110592>>2]=d;c[l+176128>>2]=d;g=d+1024|0;c[l+45060>>2]=g;c[l+110596>>2]=g;c[l+176132>>2]=g;g=d+2048|0;c[l+45064>>2]=g;c[l+110600>>2]=g;c[l+176136>>2]=g;g=d+3072|0;c[l+45068>>2]=g;c[l+110604>>2]=g;c[l+176140>>2]=g;g=d+4096|0;c[l+45072>>2]=g;c[l+110608>>2]=g;c[l+176144>>2]=g;g=d+5120|0;c[l+45076>>2]=g;c[l+110612>>2]=g;c[l+176148>>2]=g;c[l+196608>>2]=3504;c[l+196648>>2]=3336;c[l+196688>>2]=256;c[l+196728>>2]=1580;g=c[3532592]|0;if((g|0)!=0){gGC(g|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fjv();c[3531954]=3;c[3532096]=3;eZ8()|0;c[2405144]=0;c[2439438]=0;c[2429772]=0;c[2437780]=0;c[3532090]=0;c[3532102]=0;gGz(14128336,0,5);c[3532098]=0;k=0;return k|0}}while(0);c[3532048]=0;k=1;return k|0}function fiz(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5135012+(b*112|0)>>2];c[a+104>>2]=c[5135016+(b*112|0)>>2];c[a+108>>2]=c[5135020+(b*112|0)>>2];d=0;return d|0}function fiA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=5134912+(b*112|0);e=0;return e|0}function fiB(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1764912+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function fiC(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5135808+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fiD(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[642608+(c[2436]<<2)>>2]|0;e=c[d+128>>2]|0;if((c[d+52>>2]&4|0)==0){c[2113068]=e;f=c[d+132>>2]|0;c[2113070]=f;c[2443814]=e;c[2440436]=f;g=e;h=f}else{c[2113070]=e;f=c[d+132>>2]|0;c[2113068]=f;c[2440436]=e;c[2443814]=f;g=f;h=e}e=ag(g<<1,h)|0;h=gGq(e)|0;c[2112926]=h;if((h|0)!=0){gGz(h|0,0,e|0)}c[3532162]=256;c[3532160]=4;c[3532142]=8;c[3532164]=8;c[3532148]=1983576;c[3532140]=6964024;c[3532138]=6963768;c[3532002]=1024;c[3532e3]=4;a[7460944]=1;c[3532004]=16;c[3531998]=961320;c[3531992]=4969240;c[3531990]=4968824;c[3532044]=1;c[3532030]=1;a[7460960]=1;c[3532092]=1;c[3532094]=0;c[3531954]=0;c[3532096]=0;c[2426962]=10922;c[3532118]=7616;b[7064208]=0;b[7064216]=0;b[7064209]=1024;b[7064217]=1024;b[7064210]=2048;b[7064218]=2048;b[7064211]=3072;b[7064219]=3072;b[7064212]=4096;b[7064220]=4096;b[7064213]=5120;b[7064221]=5120;b[7064214]=6144;b[7064222]=6144;b[7064215]=7168;b[7064223]=7168;c[2113026]=2e5;c[2113024]=66666;c[3532042]=32768;c[3532034]=16384;eZ9(0)|0;c[3532048]=0;fju();e=c[3532046]|0;h=0;while(1){if((h|0)>=1024){break}i=9638528+(h<<2)|0;if((c[i>>2]|0)==0){j=57303;break}else{h=h+1|0}}do{if((j|0)==57303){h=gGq(e)|0;c[i>>2]=h;if((h|0)==0){break}gGz(h|0,0,e|0);c[3532048]=h;gGz(h|0,0,e|0);fju();if((eZ9(1)|0)!=0){k=1;return k|0}eX5(0,c[3532042]|0,3,8,0,c[3532024]|0);a[7461080]=1;a[7461040]=1;a[7461016]=1;fxU(0,425984);if((c[2394]|0)==0){l=c[2112932]|0}else{c[2394]=0;h=c[3532596]|0;c[2112932]=h;g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060];l=h}h=c[3532204]|0;g=l|0;f=0;while(1){d=h+f|0;c[g>>2]=d;c[g+131072>>2]=d;d=f+1024|0;if(d>>>0>524287){break}else{g=g+4|0;f=d}}f=l+4096|0;g=1048576;while(1){d=h+(g-524288)|0;c[f>>2]=d;c[f+131072>>2]=d;d=g+1024|0;if(d>>>0>2097151){break}else{f=f+4|0;g=d}}g=c[3532208]|0;f=l+12288|0;h=3145728;while(1){d=g+(h-3145728)|0;c[f>>2]=d;c[f+65536>>2]=d;c[f+131072>>2]=d;d=h+1024|0;if(d>>>0>3211263){break}else{f=f+4|0;h=d}}h=c[3531978]|0;c[l+24576>>2]=h;c[l+90112>>2]=h;c[l+155648>>2]=h;f=h+1024|0;c[l+24580>>2]=f;c[l+90116>>2]=f;c[l+155652>>2]=f;f=h+2048|0;c[l+24584>>2]=f;c[l+90120>>2]=f;c[l+155656>>2]=f;f=h+3072|0;c[l+24588>>2]=f;c[l+90124>>2]=f;c[l+155660>>2]=f;f=h+4096|0;c[l+24592>>2]=f;c[l+90128>>2]=f;c[l+155664>>2]=f;f=h+5120|0;c[l+24596>>2]=f;c[l+90132>>2]=f;c[l+155668>>2]=f;f=h+6144|0;c[l+24600>>2]=f;c[l+90136>>2]=f;c[l+155672>>2]=f;f=h+7168|0;c[l+24604>>2]=f;c[l+90140>>2]=f;c[l+155676>>2]=f;f=h+8192|0;c[l+24608>>2]=f;c[l+90144>>2]=f;c[l+155680>>2]=f;f=h+9216|0;c[l+24612>>2]=f;c[l+90148>>2]=f;c[l+155684>>2]=f;f=h+10240|0;c[l+24616>>2]=f;c[l+90152>>2]=f;c[l+155688>>2]=f;f=h+11264|0;c[l+24620>>2]=f;c[l+90156>>2]=f;c[l+155692>>2]=f;f=h+12288|0;c[l+24624>>2]=f;c[l+90160>>2]=f;c[l+155696>>2]=f;f=h+13312|0;c[l+24628>>2]=f;c[l+90164>>2]=f;c[l+155700>>2]=f;f=h+14336|0;c[l+24632>>2]=f;c[l+90168>>2]=f;c[l+155704>>2]=f;f=h+15360|0;c[l+24636>>2]=f;c[l+90172>>2]=f;c[l+155708>>2]=f;f=c[3532026]|0;c[l+28672>>2]=f;c[l+94208>>2]=f;c[l+159744>>2]=f;h=f+1024|0;c[l+28676>>2]=h;c[l+94212>>2]=h;c[l+159748>>2]=h;h=f+2048|0;c[l+28680>>2]=h;c[l+94216>>2]=h;c[l+159752>>2]=h;h=f+3072|0;c[l+28684>>2]=h;c[l+94220>>2]=h;c[l+159756>>2]=h;h=f+4096|0;c[l+28688>>2]=h;c[l+94224>>2]=h;c[l+159760>>2]=h;h=f+5120|0;c[l+28692>>2]=h;c[l+94228>>2]=h;c[l+159764>>2]=h;h=f+6144|0;c[l+28696>>2]=h;c[l+94232>>2]=h;c[l+159768>>2]=h;h=f+7168|0;c[l+28700>>2]=h;c[l+94236>>2]=h;c[l+159772>>2]=h;h=c[3532278]|0;f=l+32768|0;g=8388608;while(1){c[f>>2]=h+(g-8388608);d=g+1024|0;if(d>>>0>8454143){break}else{f=f+4|0;g=d}}g=c[3531970]|0;f=l+36864|0;h=9437184;while(1){d=g+(h-9437184)|0;c[f>>2]=d;c[f+65536>>2]=d;c[f+131072>>2]=d;d=h+1024|0;if(d>>>0>9502719){break}else{f=f+4|0;h=d}}c[l+196608>>2]=3312;c[l+196648>>2]=96;c[l+196688>>2]=494;c[l+196728>>2]=2542;h=c[3532592]|0;if((h|0)!=0){gGC(h|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fjv();c[3531954]=3;c[3532096]=3;eZ8()|0;c[2405144]=0;c[2439438]=0;c[2429772]=0;c[2437780]=0;c[3532090]=0;c[3532102]=0;gGz(14128336,0,5);c[3532098]=0;k=0;return k|0}}while(0);c[3532048]=0;k=1;return k|0}function fiE(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3592532+(b*112|0)>>2];c[a+104>>2]=c[3592536+(b*112|0)>>2];c[a+108>>2]=c[3592540+(b*112|0)>>2];d=0;return d|0}function fiF(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=3592432+(b*112|0);e=0;return e|0}function fiG(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1208e3+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function fiH(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>30){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3593328+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fiI(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=c[642608+(c[2436]<<2)>>2]|0;e=c[d+128>>2]|0;if((c[d+52>>2]&4|0)==0){c[2113068]=e;f=c[d+132>>2]|0;c[2113070]=f;c[2443814]=e;c[2440436]=f;g=e;h=f}else{c[2113070]=e;f=c[d+132>>2]|0;c[2113068]=f;c[2440436]=e;c[2443814]=f;g=f;h=e}e=ag(g<<1,h)|0;h=gGq(e)|0;c[2112926]=h;if((h|0)!=0){gGz(h|0,0,e|0)}c[3532162]=256;c[3532160]=4;c[3532142]=8;c[3532164]=8;c[3532148]=1983576;c[3532140]=6964024;c[3532138]=6963768;c[3532042]=0;c[3532002]=1024;c[3532e3]=4;a[7460944]=1;c[3532004]=16;c[3531998]=961320;c[3531992]=4969240;c[3531990]=4968824;c[3532044]=1;c[3532030]=1;a[7460960]=1;c[3532092]=1;c[3532094]=0;c[3531954]=0;c[3532096]=0;c[2426962]=10922;c[3532118]=7616;b[7064208]=0;b[7064216]=0;b[7064209]=1024;b[7064217]=1024;b[7064210]=2048;b[7064218]=2048;b[7064211]=3072;b[7064219]=3072;b[7064212]=4096;b[7064220]=4096;b[7064213]=5120;b[7064221]=5120;b[7064214]=6144;b[7064222]=6144;b[7064215]=7168;b[7064223]=7168;c[2113026]=2e5;c[2113024]=66666;c[3532034]=2048;eZ9(0)|0;c[3532048]=0;fju();e=c[3532046]|0;h=0;while(1){if((h|0)>=1024){break}i=9638528+(h<<2)|0;if((c[i>>2]|0)==0){j=57362;break}else{h=h+1|0}}do{if((j|0)==57362){h=gGq(e)|0;c[i>>2]=h;if((h|0)==0){break}gGz(h|0,0,e|0);c[3532048]=h;gGz(h|0,0,e|0);fju();if((eZ9(1)|0)==0){k=0}else{l=1;return l|0}while(1){if((k|0)>=1024){m=0;break}n=9638528+(k<<2)|0;if((c[n>>2]|0)==0){j=57367;break}else{k=k+1|0}}do{if((j|0)==57367){h=gGq(16384)|0;c[n>>2]=h;if((h|0)==0){m=0;break}gGz(h|0,0,16384);m=h}}while(0);c[2442928]=m;gGz(m|0,0,16384);h=0;while(1){if((h|0)>=1024){o=0;break}p=9638528+(h<<2)|0;if((c[p>>2]|0)==0){j=57372;break}else{h=h+1|0}}do{if((j|0)==57372){h=gGq(16384)|0;c[p>>2]=h;if((h|0)==0){o=0;break}gGz(h|0,0,16384);o=h}}while(0);c[3532276]=o;gGz(o|0,0,4096);c[3532274]=4096;a[7461088]=1;eX5(0,c[3532042]|0,0,8,0,0);a[7461080]=1;a[7461056]=1;fxU(0,425984);if((c[2394]|0)==0){q=c[2112932]|0}else{c[2394]=0;h=c[3532596]|0;c[2112932]=h;g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060];q=h}h=c[3532204]|0;g=q|0;f=0;while(1){d=h+f|0;c[g>>2]=d;c[g+131072>>2]=d;d=f+1024|0;if(d>>>0>524287){break}else{g=g+4|0;f=d}}f=c[3532208]|0;g=q+4096|0;h=1048576;while(1){d=f+(h-1048576)|0;c[g>>2]=d;c[g+65536>>2]=d;c[g+131072>>2]=d;d=h+1024|0;if(d>>>0>1114111){break}else{g=g+4|0;h=d}}h=c[3532278]|0;g=q+32768|0;f=8388608;while(1){c[g>>2]=h+(f-8388608);d=f+1024|0;if(d>>>0>8454143){break}else{g=g+4|0;f=d}}f=c[3531970]|0;g=q+36864|0;h=9437184;while(1){d=f+(h-9437184)|0;c[g>>2]=d;c[g+65536>>2]=d;c[g+131072>>2]=d;d=h+1024|0;if(d>>>0>9502719){break}else{g=g+4|0;h=d}}c[q+196608>>2]=2920;c[q+196648>>2]=1218;c[q+196688>>2]=784;c[q+196728>>2]=276;h=c[3532592]|0;if((h|0)!=0){gGC(h|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fjv();c[2426962]=11852;c[3532118]=298;eZ8()|0;c[2405144]=0;c[2439438]=0;c[2429772]=0;c[2437780]=0;c[3532090]=0;c[3532102]=0;gGz(14128336,0,5);c[3532098]=0;l=0;return l|0}}while(0);c[3532048]=0;l=1;return l|0}function fiJ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6159452+(b*112|0)>>2];c[a+104>>2]=c[6159456+(b*112|0)>>2];c[a+108>>2]=c[6159460+(b*112|0)>>2];d=0;return d|0}function fiK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=6159352+(b*112|0);e=0;return e|0}function fiL(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3586032+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function fiM(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>38){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6160472+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fiN(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=c[642608+(c[2436]<<2)>>2]|0;e=c[d+128>>2]|0;if((c[d+52>>2]&4|0)==0){c[2113068]=e;f=c[d+132>>2]|0;c[2113070]=f;c[2443814]=e;c[2440436]=f;g=e;h=f}else{c[2113070]=e;f=c[d+132>>2]|0;c[2113068]=f;c[2440436]=e;c[2443814]=f;g=f;h=e}e=ag(g<<1,h)|0;h=gGq(e)|0;c[2112926]=h;if((h|0)!=0){gGz(h|0,0,e|0)}c[3532162]=256;c[3532160]=4;c[3532142]=8;c[3532164]=8;c[3532148]=1983576;c[3532140]=6964024;c[3532138]=6963768;c[3532042]=0;c[3532002]=1024;c[3532e3]=4;a[7460944]=1;c[3532004]=16;c[3531998]=961320;c[3531992]=4969240;c[3531990]=4968824;c[3532044]=1;c[3532030]=1;a[7460960]=1;c[3532092]=1;c[3532094]=0;c[3531954]=0;c[3532096]=0;c[2426962]=10922;c[3532118]=7616;b[7064208]=0;b[7064216]=0;b[7064209]=1024;b[7064217]=1024;b[7064210]=2048;b[7064218]=2048;b[7064211]=3072;b[7064219]=3072;b[7064212]=4096;b[7064220]=4096;b[7064213]=5120;b[7064221]=5120;b[7064214]=6144;b[7064222]=6144;b[7064215]=7168;b[7064223]=7168;c[2113026]=2e5;c[2113024]=66666;c[3532034]=4096;eZ9(0)|0;c[3532200]=786432;c[3532048]=0;fju();e=c[3532046]|0;h=0;while(1){if((h|0)>=1024){break}i=9638528+(h<<2)|0;if((c[i>>2]|0)==0){j=57428;break}else{h=h+1|0}}do{if((j|0)==57428){h=gGq(e)|0;c[i>>2]=h;if((h|0)==0){break}gGz(h|0,0,e|0);c[3532048]=h;gGz(h|0,0,e|0);fju();if((eZ9(1)|0)!=0){k=1;return k|0}h=c[3532204]|0;g=h+524288|0;f=h+262144|0;gGC(g|0,f|0,262144)|0;gGz(f|0,0,262144);f=0;while(1){if((f|0)>=1024){l=0;break}m=9638528+(f<<2)|0;if((c[m>>2]|0)==0){j=57434;break}else{f=f+1|0}}do{if((j|0)==57434){f=gGq(16384)|0;c[m>>2]=f;if((f|0)==0){l=0;break}gGz(f|0,0,16384);l=f}}while(0);c[2442928]=l;gGz(l|0,0,16384);f=0;while(1){if((f|0)>=1024){n=0;break}o=9638528+(f<<2)|0;if((c[o>>2]|0)==0){j=57439;break}else{f=f+1|0}}do{if((j|0)==57439){f=gGq(16384)|0;c[o>>2]=f;if((f|0)==0){n=0;break}gGz(f|0,0,16384);n=f}}while(0);c[3532276]=n;gGz(n|0,0,4096);c[3532274]=4096;a[7461088]=1;eX5(0,c[3532042]|0,0,8,0,0);a[7461080]=1;fxU(0,425984);if((c[2394]|0)==0){p=c[2112932]|0}else{c[2394]=0;f=c[3532596]|0;c[2112932]=f;g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060];p=f}f=c[3532204]|0;g=p|0;h=0;while(1){d=f+h|0;c[g>>2]=d;c[g+131072>>2]=d;d=h+1024|0;if(d>>>0>786431){break}else{g=g+4|0;h=d}}h=c[3532208]|0;g=p+4096|0;f=1048576;while(1){d=h+(f-1048576)|0;c[g>>2]=d;c[g+65536>>2]=d;c[g+131072>>2]=d;d=f+1024|0;if(d>>>0>1114111){break}else{g=g+4|0;f=d}}f=c[3532278]|0;g=p+32768|0;h=8388608;while(1){c[g>>2]=f+(h-8388608);d=h+1024|0;if(d>>>0>8454143){break}else{g=g+4|0;h=d}}h=c[3531970]|0;g=p+36864|0;f=9437184;while(1){d=h+(f-9437184)|0;c[g>>2]=d;c[g+65536>>2]=d;c[g+131072>>2]=d;d=f+1024|0;if(d>>>0>9502719){break}else{g=g+4|0;f=d}}c[p+196608>>2]=106;c[p+196648>>2]=2228;c[p+196688>>2]=794;c[p+196728>>2]=2036;f=c[3532592]|0;if((f|0)!=0){gGC(f|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fjv();c[2426962]=11852;c[3532118]=298;eZ8()|0;c[2405144]=0;c[2439438]=0;c[2429772]=0;c[2437780]=0;c[3532090]=0;c[3532102]=0;gGz(14128336,0,5);c[3532098]=0;k=0;return k|0}}while(0);c[3532048]=0;k=1;return k|0}function fiO(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3584700+(b*112|0)>>2];c[a+104>>2]=c[3584704+(b*112|0)>>2];c[a+108>>2]=c[3584708+(b*112|0)>>2];d=0;return d|0}function fiP(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=3584600+(b*112|0);e=0;return e|0}function fiQ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1207696+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function fiR(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>25){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3585720+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fiS(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[642608+(c[2436]<<2)>>2]|0;e=c[d+128>>2]|0;if((c[d+52>>2]&4|0)==0){c[2113068]=e;f=c[d+132>>2]|0;c[2113070]=f;c[2443814]=e;c[2440436]=f;g=e;h=f}else{c[2113070]=e;f=c[d+132>>2]|0;c[2113068]=f;c[2440436]=e;c[2443814]=f;g=f;h=e}e=ag(g<<1,h)|0;h=gGq(e)|0;c[2112926]=h;if((h|0)!=0){gGz(h|0,0,e|0)}c[3532162]=256;c[3532160]=4;c[3532142]=8;c[3532164]=8;c[3532148]=1983576;c[3532140]=6964024;c[3532138]=6963768;c[3532002]=1024;c[3532e3]=4;a[7460944]=1;c[3532004]=16;c[3531998]=961320;c[3531992]=4969240;c[3531990]=4968824;c[3532044]=1;c[3532030]=1;a[7460960]=1;c[3532092]=1;c[3532094]=0;c[3531954]=0;c[3532096]=0;c[2426962]=10922;c[3532118]=7616;b[7064208]=0;b[7064216]=0;b[7064209]=1024;b[7064217]=1024;b[7064210]=2048;b[7064218]=2048;b[7064211]=3072;b[7064219]=3072;b[7064212]=4096;b[7064220]=4096;b[7064213]=5120;b[7064221]=5120;b[7064214]=6144;b[7064222]=6144;b[7064215]=7168;b[7064223]=7168;c[2113026]=2e5;c[2113024]=66666;c[3532042]=32768;c[3532034]=8192;eZ9(0)|0;c[3532048]=0;fju();e=c[3532046]|0;h=0;while(1){if((h|0)>=1024){break}i=9638528+(h<<2)|0;if((c[i>>2]|0)==0){j=57495;break}else{h=h+1|0}}do{if((j|0)==57495){h=gGq(e)|0;c[i>>2]=h;if((h|0)==0){break}gGz(h|0,0,e|0);c[3532048]=h;gGz(h|0,0,e|0);fju();if((eZ9(1)|0)!=0){k=1;return k|0}eX5(0,c[3532042]|0,0,8,0,0);a[7461080]=1;a[7461016]=1;fxU(0,425984);if((c[2394]|0)==0){l=c[2112932]|0}else{c[2394]=0;h=c[3532596]|0;c[2112932]=h;g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060];l=h}h=c[3532204]|0;g=l|0;f=0;while(1){d=h+f|0;c[g>>2]=d;c[g+131072>>2]=d;d=f+1024|0;if(d>>>0>262143){break}else{g=g+4|0;f=d}}f=l+4096|0;g=1048576;while(1){d=h+(g-786432)|0;c[f>>2]=d;c[f+131072>>2]=d;d=g+1024|0;if(d>>>0>1572863){break}else{f=f+4|0;g=d}}g=c[3532026]|0;c[l+16384>>2]=g;c[l+81920>>2]=g;c[l+147456>>2]=g;f=g+1024|0;c[l+16388>>2]=f;c[l+81924>>2]=f;c[l+147460>>2]=f;f=g+2048|0;c[l+16392>>2]=f;c[l+81928>>2]=f;c[l+147464>>2]=f;f=g+3072|0;c[l+16396>>2]=f;c[l+81932>>2]=f;c[l+147468>>2]=f;f=g+4096|0;c[l+16400>>2]=f;c[l+81936>>2]=f;c[l+147472>>2]=f;f=g+5120|0;c[l+16404>>2]=f;c[l+81940>>2]=f;c[l+147476>>2]=f;f=g+6144|0;c[l+16408>>2]=f;c[l+81944>>2]=f;c[l+147480>>2]=f;f=g+7168|0;c[l+16412>>2]=f;c[l+81948>>2]=f;c[l+147484>>2]=f;f=c[3532208]|0;g=l+20480|0;h=5242880;while(1){d=f+(h-5242880)|0;c[g>>2]=d;c[g+65536>>2]=d;c[g+131072>>2]=d;d=h+1024|0;if(d>>>0>5308415){break}else{g=g+4|0;h=d}}h=c[3531970]|0;g=l+24576|0;f=6291456;while(1){d=h+(f-6291456)|0;c[g>>2]=d;c[g+65536>>2]=d;c[g+131072>>2]=d;d=f+1024|0;if(d>>>0>6356991){break}else{g=g+4|0;f=d}}f=c[3532278]|0;g=l+28672|0;h=7340032;while(1){c[g>>2]=f+(h-7340032);d=h+1024|0;if(d>>>0>7405567){break}else{g=g+4|0;h=d}}c[l+196608>>2]=1232;c[l+196648>>2]=614;c[l+196688>>2]=230;c[l+196728>>2]=3172;h=c[3532592]|0;if((h|0)!=0){gGC(h|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fjv();c[2426962]=7100;c[3532118]=1494;eZ8()|0;c[2405144]=0;c[2439438]=0;c[2429772]=0;c[2437780]=0;c[3532090]=0;c[3532102]=0;gGz(14128336,0,5);c[3532098]=0;k=0;return k|0}}while(0);c[3532048]=0;k=1;return k|0}function fiT(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5125356+(b*112|0)>>2];c[a+104>>2]=c[5125360+(b*112|0)>>2];c[a+108>>2]=c[5125364+(b*112|0)>>2];d=0;return d|0}function fiU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=5125256+(b*112|0);e=0;return e|0}function fiV(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1207696+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function fiW(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>25){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3585720+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fiX(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[642608+(c[2436]<<2)>>2]|0;e=c[d+128>>2]|0;if((c[d+52>>2]&4|0)==0){c[2113068]=e;f=c[d+132>>2]|0;c[2113070]=f;c[2443814]=e;c[2440436]=f;g=e;h=f}else{c[2113070]=e;f=c[d+132>>2]|0;c[2113068]=f;c[2440436]=e;c[2443814]=f;g=f;h=e}e=ag(g<<1,h)|0;h=gGq(e)|0;c[2112926]=h;if((h|0)!=0){gGz(h|0,0,e|0)}c[3532162]=256;c[3532160]=4;c[3532142]=8;c[3532164]=8;c[3532148]=1983576;c[3532140]=6964024;c[3532138]=6963768;c[3532002]=1024;c[3532e3]=4;a[7460944]=1;c[3532004]=16;c[3531998]=961320;c[3531992]=4969240;c[3531990]=4968824;c[3532044]=1;c[3532030]=1;a[7460960]=1;c[3532092]=1;c[3532094]=0;c[3531954]=0;c[3532096]=0;c[2426962]=10922;c[3532118]=7616;b[7064208]=0;b[7064216]=0;b[7064209]=1024;b[7064217]=1024;b[7064210]=2048;b[7064218]=2048;b[7064211]=3072;b[7064219]=3072;b[7064212]=4096;b[7064220]=4096;b[7064213]=5120;b[7064221]=5120;b[7064214]=6144;b[7064222]=6144;b[7064215]=7168;b[7064223]=7168;c[2113026]=2e5;c[2113024]=66666;c[3532042]=32768;c[3532034]=8192;eZ9(0)|0;c[3532048]=0;fju();e=c[3532046]|0;h=0;while(1){if((h|0)>=1024){break}i=9638528+(h<<2)|0;if((c[i>>2]|0)==0){j=57554;break}else{h=h+1|0}}do{if((j|0)==57554){h=gGq(e)|0;c[i>>2]=h;if((h|0)==0){break}gGz(h|0,0,e|0);c[3532048]=h;gGz(h|0,0,e|0);fju();if((eZ9(1)|0)!=0){k=1;return k|0}eX5(0,c[3532042]|0,0,8,0,0);a[7461080]=1;a[7461016]=1;fxU(0,425984);if((c[2394]|0)==0){l=c[2112932]|0}else{c[2394]=0;h=c[3532596]|0;c[2112932]=h;g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060];l=h}h=c[3532204]|0;g=l|0;f=0;while(1){d=h+f|0;c[g>>2]=d;c[g+131072>>2]=d;d=f+1024|0;if(d>>>0>262143){break}else{g=g+4|0;f=d}}f=l+4096|0;g=1048576;while(1){d=h+(g-786432)|0;c[f>>2]=d;c[f+131072>>2]=d;d=g+1024|0;if(d>>>0>2097151){break}else{f=f+4|0;g=d}}g=c[3532026]|0;c[l+16384>>2]=g;c[l+81920>>2]=g;c[l+147456>>2]=g;f=g+1024|0;c[l+16388>>2]=f;c[l+81924>>2]=f;c[l+147460>>2]=f;f=g+2048|0;c[l+16392>>2]=f;c[l+81928>>2]=f;c[l+147464>>2]=f;f=g+3072|0;c[l+16396>>2]=f;c[l+81932>>2]=f;c[l+147468>>2]=f;f=g+4096|0;c[l+16400>>2]=f;c[l+81936>>2]=f;c[l+147472>>2]=f;f=g+5120|0;c[l+16404>>2]=f;c[l+81940>>2]=f;c[l+147476>>2]=f;f=g+6144|0;c[l+16408>>2]=f;c[l+81944>>2]=f;c[l+147480>>2]=f;f=g+7168|0;c[l+16412>>2]=f;c[l+81948>>2]=f;c[l+147484>>2]=f;f=c[3532208]|0;g=l+20480|0;h=5242880;while(1){d=f+(h-5242880)|0;c[g>>2]=d;c[g+65536>>2]=d;c[g+131072>>2]=d;d=h+1024|0;if(d>>>0>5308415){break}else{g=g+4|0;h=d}}h=c[3531970]|0;g=l+24576|0;f=6291456;while(1){d=h+(f-6291456)|0;c[g>>2]=d;c[g+65536>>2]=d;c[g+131072>>2]=d;d=f+1024|0;if(d>>>0>6356991){break}else{g=g+4|0;f=d}}f=c[3532278]|0;g=l+28672|0;h=7340032;while(1){c[g>>2]=f+(h-7340032);d=h+1024|0;if(d>>>0>7405567){break}else{g=g+4|0;h=d}}c[l+196608>>2]=1926;c[l+196648>>2]=2904;c[l+196688>>2]=1320;c[l+196728>>2]=930;h=c[3532592]|0;if((h|0)!=0){gGC(h|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fjv();c[2426962]=11852;c[3532118]=1494;eZ8()|0;c[2405144]=0;c[2439438]=0;c[2429772]=0;c[2437780]=0;c[3532090]=0;c[3532102]=0;gGz(14128336,0,5);c[3532098]=0;k=0;return k|0}}while(0);c[3532048]=0;k=1;return k|0}function fiY(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3417356+(b*112|0)>>2];c[a+104>>2]=c[3417360+(b*112|0)>>2];c[a+108>>2]=c[3417364+(b*112|0)>>2];d=0;return d|0}function fiZ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=3417256+(b*112|0);e=0;return e|0}function fi_(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1190088+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function fi$(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>25){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3418152+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fi0(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[642608+(c[2436]<<2)>>2]|0;e=c[d+128>>2]|0;if((c[d+52>>2]&4|0)==0){c[2113068]=e;f=c[d+132>>2]|0;c[2113070]=f;c[2443814]=e;c[2440436]=f;g=e;h=f}else{c[2113070]=e;f=c[d+132>>2]|0;c[2113068]=f;c[2440436]=e;c[2443814]=f;g=f;h=e}e=ag(g<<1,h)|0;h=gGq(e)|0;c[2112926]=h;if((h|0)!=0){gGz(h|0,0,e|0)}c[3532162]=256;c[3532160]=4;c[3532142]=8;c[3532164]=8;c[3532148]=1983576;c[3532140]=6964024;c[3532138]=6963768;c[3532002]=1024;c[3532e3]=4;a[7460944]=1;c[3532004]=16;c[3531998]=961320;c[3531992]=4969240;c[3531990]=4968824;c[3532044]=1;c[3532030]=1;a[7460960]=1;c[3532092]=1;c[3532094]=0;c[3531954]=0;c[3532096]=0;c[2426962]=10922;c[3532118]=7616;b[7064208]=0;b[7064216]=0;b[7064209]=1024;b[7064217]=1024;b[7064210]=2048;b[7064218]=2048;b[7064211]=3072;b[7064219]=3072;b[7064212]=4096;b[7064220]=4096;b[7064213]=5120;b[7064221]=5120;b[7064214]=6144;b[7064222]=6144;b[7064215]=7168;b[7064223]=7168;c[2113026]=2e5;c[2113024]=66666;c[3532042]=32768;c[3532034]=16384;eZ9(0)|0;c[3532048]=0;fju();e=c[3532046]|0;h=0;while(1){if((h|0)>=1024){break}i=9638528+(h<<2)|0;if((c[i>>2]|0)==0){j=57613;break}else{h=h+1|0}}do{if((j|0)==57613){h=gGq(e)|0;c[i>>2]=h;if((h|0)==0){break}gGz(h|0,0,e|0);c[3532048]=h;gGz(h|0,0,e|0);fju();if((eZ9(1)|0)!=0){k=1;return k|0}eX5(0,c[3532042]|0,3,8,0,c[3532024]|0);a[7461080]=1;a[7461040]=1;fxU(0,425984);if((c[2394]|0)==0){l=c[2112932]|0}else{c[2394]=0;h=c[3532596]|0;c[2112932]=h;g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060];l=h}h=c[3532204]|0;g=l|0;f=0;while(1){d=h+f|0;c[g>>2]=d;c[g+131072>>2]=d;d=f+1024|0;if(d>>>0>524287){break}else{g=g+4|0;f=d}}f=c[3532208]|0;g=l+4096|0;h=1048576;while(1){d=f+(h-1048576)|0;c[g>>2]=d;c[g+65536>>2]=d;c[g+131072>>2]=d;d=h+1024|0;if(d>>>0>1114111){break}else{g=g+4|0;h=d}}h=c[3532026]|0;c[l+8192>>2]=h;c[l+73728>>2]=h;c[l+139264>>2]=h;g=h+1024|0;c[l+8196>>2]=g;c[l+73732>>2]=g;c[l+139268>>2]=g;g=h+2048|0;c[l+8200>>2]=g;c[l+73736>>2]=g;c[l+139272>>2]=g;g=h+3072|0;c[l+8204>>2]=g;c[l+73740>>2]=g;c[l+139276>>2]=g;g=h+4096|0;c[l+8208>>2]=g;c[l+73744>>2]=g;c[l+139280>>2]=g;g=h+5120|0;c[l+8212>>2]=g;c[l+73748>>2]=g;c[l+139284>>2]=g;g=h+6144|0;c[l+8216>>2]=g;c[l+73752>>2]=g;c[l+139288>>2]=g;g=h+7168|0;c[l+8220>>2]=g;c[l+73756>>2]=g;c[l+139292>>2]=g;g=c[3532278]|0;h=l+32768|0;f=8388608;while(1){c[h>>2]=g+(f-8388608);d=f+1024|0;if(d>>>0>8454143){break}else{h=h+4|0;f=d}}f=c[3531970]|0;h=l+36864|0;g=9437184;while(1){d=f+(g-9437184)|0;c[h>>2]=d;c[h+65536>>2]=d;c[h+131072>>2]=d;d=g+1024|0;if(d>>>0>9502719){break}else{h=h+4|0;g=d}}c[l+196608>>2]=3154;c[l+196648>>2]=1616;c[l+196688>>2]=1426;c[l+196728>>2]=1106;g=c[3532592]|0;if((g|0)!=0){gGC(g|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fjv();c[3531954]=3;eZ8()|0;c[2405144]=0;c[2439438]=0;c[2429772]=0;c[2437780]=0;c[3532090]=0;c[3532102]=0;gGz(14128336,0,5);c[3532098]=0;k=0;return k|0}}while(0);c[3532048]=0;k=1;return k|0}function fi1(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>4){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7368932+(b*112|0)>>2];c[a+104>>2]=c[7368936+(b*112|0)>>2];c[a+108>>2]=c[7368940+(b*112|0)>>2];d=0;return d|0}function fi2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<5&(d|0)==0)){e=1;return e|0}c[a>>2]=7368832+(b*112|0);e=0;return e|0}function fi3(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1240352+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function fi4(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>44){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7369392+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fi5(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[642608+(c[2436]<<2)>>2]|0;e=c[d+128>>2]|0;if((c[d+52>>2]&4|0)==0){c[2113068]=e;f=c[d+132>>2]|0;c[2113070]=f;c[2443814]=e;c[2440436]=f;g=e;h=f}else{c[2113070]=e;f=c[d+132>>2]|0;c[2113068]=f;c[2440436]=e;c[2443814]=f;g=f;h=e}e=ag(g<<1,h)|0;h=gGq(e)|0;c[2112926]=h;if((h|0)!=0){gGz(h|0,0,e|0)}c[3532162]=256;c[3532160]=4;c[3532142]=8;c[3532164]=8;c[3532148]=1983576;c[3532140]=6964024;c[3532138]=6963768;c[3532042]=0;c[3532002]=1024;c[3532e3]=4;a[7460944]=1;c[3532004]=16;c[3531998]=961320;c[3531992]=4969240;c[3531990]=4968824;c[3532044]=1;c[3532030]=1;a[7460960]=1;c[3532092]=1;c[3532094]=0;c[3531954]=0;c[3532096]=0;c[2426962]=10922;c[3532118]=7616;b[7064208]=0;b[7064216]=0;b[7064209]=1024;b[7064217]=1024;b[7064210]=2048;b[7064218]=2048;b[7064211]=3072;b[7064219]=3072;b[7064212]=4096;b[7064220]=4096;b[7064213]=5120;b[7064221]=5120;b[7064214]=6144;b[7064222]=6144;b[7064215]=7168;b[7064223]=7168;c[2113026]=2e5;c[2113024]=66666;c[3532034]=8192;eZ9(0)|0;c[3532048]=0;fju();e=c[3532046]|0;h=0;while(1){if((h|0)>=1024){break}i=9638528+(h<<2)|0;if((c[i>>2]|0)==0){j=57670;break}else{h=h+1|0}}do{if((j|0)==57670){h=gGq(e)|0;c[i>>2]=h;if((h|0)==0){break}gGz(h|0,0,e|0);c[3532048]=h;gGz(h|0,0,e|0);fju();if((eZ9(1)|0)!=0){k=1;return k|0}eX5(0,c[3532042]|0,0,0,0,0);a[7461080]=1;a[7461016]=1;fxU(0,425984);if((c[2394]|0)==0){l=c[2112932]|0}else{c[2394]=0;h=c[3532596]|0;c[2112932]=h;g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060];l=h}h=c[3532204]|0;g=l|0;f=0;while(1){d=h+f|0;c[g>>2]=d;c[g+131072>>2]=d;d=f+1024|0;if(d>>>0>524287){break}else{g=g+4|0;f=d}}f=c[3532208]|0;g=l+8192|0;h=2097152;while(1){d=f+(h-2097152)|0;c[g>>2]=d;c[g+65536>>2]=d;c[g+131072>>2]=d;d=h+1024|0;if(d>>>0>2162687){break}else{g=g+4|0;h=d}}h=c[3532026]|0;c[l+12288>>2]=h;c[l+77824>>2]=h;c[l+143360>>2]=h;g=h+1024|0;c[l+12292>>2]=g;c[l+77828>>2]=g;c[l+143364>>2]=g;g=h+2048|0;c[l+12296>>2]=g;c[l+77832>>2]=g;c[l+143368>>2]=g;g=h+3072|0;c[l+12300>>2]=g;c[l+77836>>2]=g;c[l+143372>>2]=g;g=h+4096|0;c[l+12304>>2]=g;c[l+77840>>2]=g;c[l+143376>>2]=g;g=h+5120|0;c[l+12308>>2]=g;c[l+77844>>2]=g;c[l+143380>>2]=g;g=h+6144|0;c[l+12312>>2]=g;c[l+77848>>2]=g;c[l+143384>>2]=g;g=h+7168|0;c[l+12316>>2]=g;c[l+77852>>2]=g;c[l+143388>>2]=g;g=c[3532278]|0;h=l+24576|0;f=6291456;while(1){c[h>>2]=g+(f-6291456);d=f+1024|0;if(d>>>0>6356991){break}else{h=h+4|0;f=d}}f=c[3531970]|0;h=l+32768|0;g=8388608;while(1){d=f+(g-8388608)|0;c[h>>2]=d;c[h+65536>>2]=d;c[h+131072>>2]=d;d=g+1024|0;if(d>>>0>8454143){break}else{h=h+4|0;g=d}}c[l+196608>>2]=1944;c[l+196648>>2]=1332;c[l+196688>>2]=2944;c[l+196728>>2]=2054;g=c[3532592]|0;if((g|0)!=0){gGC(g|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fjv();c[3531954]=3;c[2426962]=3882;c[3532118]=9536;eZ8()|0;c[2405144]=0;c[2439438]=0;c[2429772]=0;c[2437780]=0;c[3532090]=0;c[3532102]=0;gGz(14128336,0,5);c[3532098]=0;k=0;return k|0}}while(0);c[3532048]=0;k=1;return k|0}function fi6(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3774428+(b*112|0)>>2];c[a+104>>2]=c[3774432+(b*112|0)>>2];c[a+108>>2]=c[3774436+(b*112|0)>>2];d=0;return d|0}function fi7(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=3774328+(b*112|0);e=0;return e|0}function fi8(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>44){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3775112+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fi9(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3310700+(b*112|0)>>2];c[a+104>>2]=c[3310704+(b*112|0)>>2];c[a+108>>2]=c[3310708+(b*112|0)>>2];d=0;return d|0}function fja(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=3310600+(b*112|0);e=0;return e|0}function fjb(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1179320+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function fjc(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>39){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3312504+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fjd(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[642608+(c[2436]<<2)>>2]|0;e=c[d+128>>2]|0;if((c[d+52>>2]&4|0)==0){c[2113068]=e;f=c[d+132>>2]|0;c[2113070]=f;c[2443814]=e;c[2440436]=f;g=e;h=f}else{c[2113070]=e;f=c[d+132>>2]|0;c[2113068]=f;c[2440436]=e;c[2443814]=f;g=f;h=e}e=ag(g<<1,h)|0;h=gGq(e)|0;c[2112926]=h;if((h|0)!=0){gGz(h|0,0,e|0)}c[3532162]=256;c[3532160]=4;c[3532142]=8;c[3532164]=8;c[3532148]=1983576;c[3532140]=6964024;c[3532138]=6963768;c[3532002]=1024;c[3532e3]=4;a[7460944]=1;c[3532004]=16;c[3531998]=961320;c[3531992]=4969240;c[3531990]=4968824;c[3532044]=1;c[3532030]=1;a[7460960]=1;c[3532092]=1;c[3532094]=0;c[3531954]=0;c[3532096]=0;c[2426962]=10922;c[3532118]=7616;b[7064208]=0;b[7064216]=0;b[7064209]=1024;b[7064217]=1024;b[7064210]=2048;b[7064218]=2048;b[7064211]=3072;b[7064219]=3072;b[7064212]=4096;b[7064220]=4096;b[7064213]=5120;b[7064221]=5120;b[7064214]=6144;b[7064222]=6144;b[7064215]=7168;b[7064223]=7168;c[2113026]=2e5;c[2113024]=66666;c[3532042]=16384;c[3532178]=256;c[3532176]=4;a[7461200]=1;a[7461208]=1;c[3532174]=1983576;c[3532168]=6964024;c[3532166]=6963768;c[3532040]=16384;c[3532034]=8192;eZ9(0)|0;c[3532048]=0;fju();e=c[3532046]|0;h=0;while(1){if((h|0)>=1024){break}i=9638528+(h<<2)|0;if((c[i>>2]|0)==0){j=57746;break}else{h=h+1|0}}do{if((j|0)==57746){h=gGq(e)|0;c[i>>2]=h;if((h|0)==0){break}gGz(h|0,0,e|0);c[3532048]=h;gGz(h|0,0,e|0);fju();if((eZ9(1)|0)!=0){k=1;return k|0}eX5(0,c[3532042]|0,3,8,0,0);h=c[2113070]|0;c[2430060]=c[2113068];c[2429702]=h;c[2429698]=0;eX5(1,c[3532040]|0,3,16,0,0);h=c[2113070]|0;c[2430061]=c[2113068];c[2429703]=h;c[2429699]=0;a[7461080]=1;a[7461056]=1;a[7461040]=1;fxU(0,425984);if((c[2394]|0)==0){l=c[2112932]|0}else{c[2394]=0;h=c[3532596]|0;c[2112932]=h;g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060];l=h}h=c[3532204]|0;g=l|0;f=0;while(1){d=h+f|0;c[g>>2]=d;c[g+131072>>2]=d;d=f+1024|0;if(d>>>0>524287){break}else{g=g+4|0;f=d}}f=c[3532026]|0;c[l+4096>>2]=f;c[l+69632>>2]=f;c[l+135168>>2]=f;g=f+1024|0;c[l+4100>>2]=g;c[l+69636>>2]=g;c[l+135172>>2]=g;g=f+2048|0;c[l+4104>>2]=g;c[l+69640>>2]=g;c[l+135176>>2]=g;g=f+3072|0;c[l+4108>>2]=g;c[l+69644>>2]=g;c[l+135180>>2]=g;g=f+4096|0;c[l+4112>>2]=g;c[l+69648>>2]=g;c[l+135184>>2]=g;g=f+5120|0;c[l+4116>>2]=g;c[l+69652>>2]=g;c[l+135188>>2]=g;g=f+6144|0;c[l+4120>>2]=g;c[l+69656>>2]=g;c[l+135192>>2]=g;g=f+7168|0;c[l+4124>>2]=g;c[l+69660>>2]=g;c[l+135196>>2]=g;g=c[3532208]|0;f=l+12288|0;h=3145728;while(1){d=g+(h-3145728)|0;c[f>>2]=d;c[f+65536>>2]=d;c[f+131072>>2]=d;d=h+1024|0;if(d>>>0>3211263){break}else{f=f+4|0;h=d}}h=c[3532278]|0;f=l+16384|0;g=4194304;while(1){c[f>>2]=h+(g-4194304);d=g+1024|0;if(d>>>0>4259839){break}else{f=f+4|0;g=d}}g=c[3532279]|0;f=l+20480|0;h=5242880;while(1){c[f>>2]=g+(h-5242880);d=h+1024|0;if(d>>>0>5308415){break}else{f=f+4|0;h=d}}h=c[3531970]|0;f=l+24576|0;g=6291456;while(1){d=h+(g-6291456)|0;c[f>>2]=d;c[f+65536>>2]=d;c[f+131072>>2]=d;d=g+1024|0;if(d>>>0>6356991){break}else{f=f+4|0;g=d}}c[l+196608>>2]=2362;c[l+196648>>2]=2300;c[l+196688>>2]=600;c[l+196728>>2]=2814;g=c[3532592]|0;if((g|0)!=0){gGC(g|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fjv();c[3531954]=3;c[2426962]=3882;c[3532118]=8748;eZ8()|0;c[2405144]=0;c[2439438]=0;c[2429772]=0;c[2437780]=0;c[3532090]=0;c[3532102]=0;gGz(14128336,0,5);c[3532098]=0;k=0;return k|0}}while(0);c[3532048]=0;k=1;return k|0}function fje(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1659860+(b*112|0)>>2];c[a+104>>2]=c[1659864+(b*112|0)>>2];c[a+108>>2]=c[1659868+(b*112|0)>>2];d=0;return d|0}function fjf(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=1659760+(b*112|0);e=0;return e|0}function fjg(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>39){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5324672+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fjh(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1658148+(b*112|0)>>2];c[a+104>>2]=c[1658152+(b*112|0)>>2];c[a+108>>2]=c[1658156+(b*112|0)>>2];d=0;return d|0}function fji(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=1658048+(b*112|0);e=0;return e|0}function fjj(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>39){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1659280+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fjk(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>5){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5962452+(b*112|0)>>2];c[a+104>>2]=c[5962456+(b*112|0)>>2];c[a+108>>2]=c[5962460+(b*112|0)>>2];d=0;return d|0}function fjl(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<6&(d|0)==0)){e=1;return e|0}c[a>>2]=5962352+(b*112|0);e=0;return e|0}function fjm(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3199280+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function fjn(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5963024+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fjo(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[642608+(c[2436]<<2)>>2]|0;e=c[d+128>>2]|0;if((c[d+52>>2]&4|0)==0){c[2113068]=e;f=c[d+132>>2]|0;c[2113070]=f;c[2443814]=e;c[2440436]=f;g=e;h=f}else{c[2113070]=e;f=c[d+132>>2]|0;c[2113068]=f;c[2440436]=e;c[2443814]=f;g=f;h=e}e=ag(g<<1,h)|0;h=gGq(e)|0;c[2112926]=h;if((h|0)!=0){gGz(h|0,0,e|0)}c[3532002]=1024;c[3532e3]=4;a[7460944]=1;c[3532004]=16;c[3531998]=961320;c[3531992]=4969240;c[3531990]=4968824;c[3532044]=1;c[3532030]=1;a[7460960]=1;c[3532092]=1;c[3532094]=0;c[3531954]=0;c[3532096]=0;c[2426962]=10922;c[3532118]=7616;b[7064208]=0;b[7064216]=0;b[7064209]=1024;b[7064217]=1024;b[7064210]=2048;b[7064218]=2048;b[7064211]=3072;b[7064219]=3072;b[7064212]=4096;b[7064220]=4096;b[7064213]=5120;b[7064221]=5120;b[7064214]=6144;b[7064222]=6144;b[7064215]=7168;b[7064223]=7168;c[2113026]=2e5;c[2113024]=66666;c[3532162]=64;c[3532160]=1;c[3532142]=8;c[3532164]=8;c[3532148]=9708032;c[3532140]=725056;c[3532138]=725024;c[3532042]=65536;c[3532034]=8192;eZ9(0)|0;c[3532048]=0;fju();e=c[3532046]|0;h=0;while(1){if((h|0)>=1024){break}i=9638528+(h<<2)|0;if((c[i>>2]|0)==0){j=57843;break}else{h=h+1|0}}do{if((j|0)==57843){h=gGq(e)|0;c[i>>2]=h;if((h|0)==0){break}gGz(h|0,0,e|0);c[3532048]=h;gGz(h|0,0,e|0);fju();if((eZ9(1)|0)!=0){k=1;return k|0}eX5(0,c[3532042]|0,3,8,0,0);a[7461080]=1;fxU(0,425984);if((c[2394]|0)==0){l=c[2112932]|0}else{c[2394]=0;h=c[3532596]|0;c[2112932]=h;g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060];l=h}h=c[3532204]|0;g=l|0;f=0;while(1){d=h+f|0;c[g>>2]=d;c[g+131072>>2]=d;d=f+1024|0;if(d>>>0>524287){break}else{g=g+4|0;f=d}}f=c[3532208]|0;g=l+8192|0;h=2097152;while(1){d=f+(h-2097152)|0;c[g>>2]=d;c[g+65536>>2]=d;c[g+131072>>2]=d;d=h+1024|0;if(d>>>0>2162687){break}else{g=g+4|0;h=d}}h=c[3531970]|0;g=l+16384|0;f=4194304;while(1){d=h+(f-4194304)|0;c[g>>2]=d;c[g+65536>>2]=d;c[g+131072>>2]=d;d=f+1024|0;if(d>>>0>4259839){break}else{g=g+4|0;f=d}}f=c[3532278]|0;g=l+20480|0;h=5242880;while(1){c[g>>2]=f+(h-5242880);d=h+1024|0;if(d>>>0>5308415){break}else{g=g+4|0;h=d}}h=c[3532026]|0;c[l+24576>>2]=h;c[l+90112>>2]=h;c[l+155648>>2]=h;g=h+1024|0;c[l+24580>>2]=g;c[l+90116>>2]=g;c[l+155652>>2]=g;g=h+2048|0;c[l+24584>>2]=g;c[l+90120>>2]=g;c[l+155656>>2]=g;g=h+3072|0;c[l+24588>>2]=g;c[l+90124>>2]=g;c[l+155660>>2]=g;g=h+4096|0;c[l+24592>>2]=g;c[l+90128>>2]=g;c[l+155664>>2]=g;g=h+5120|0;c[l+24596>>2]=g;c[l+90132>>2]=g;c[l+155668>>2]=g;g=h+6144|0;c[l+24600>>2]=g;c[l+90136>>2]=g;c[l+155672>>2]=g;g=h+7168|0;c[l+24604>>2]=g;c[l+90140>>2]=g;c[l+155676>>2]=g;c[l+196608>>2]=448;c[l+196648>>2]=2848;c[l+196688>>2]=304;c[l+196728>>2]=2850;g=c[3532592]|0;if((g|0)!=0){gGC(g|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fjv();c[3532118]=12514;c[3531954]=3;eZ8()|0;c[2405144]=0;c[2439438]=0;c[2429772]=0;c[2437780]=0;c[3532090]=0;c[3532102]=0;gGz(14128336,0,5);c[3532098]=0;k=0;return k|0}}while(0);c[3532048]=0;k=1;return k|0}function fjp(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3194164+(b*112|0)>>2];c[a+104>>2]=c[3194168+(b*112|0)>>2];c[a+108>>2]=c[3194172+(b*112|0)>>2];d=0;return d|0}function fjq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=3194064+(b*112|0);e=0;return e|0}function fjr(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1764912+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function fjs(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>25){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3194960+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fjt(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=c[642608+(c[2436]<<2)>>2]|0;e=c[d+128>>2]|0;if((c[d+52>>2]&4|0)==0){c[2113068]=e;f=c[d+132>>2]|0;c[2113070]=f;c[2443814]=e;c[2440436]=f;g=e;h=f}else{c[2113070]=e;f=c[d+132>>2]|0;c[2113068]=f;c[2440436]=e;c[2443814]=f;g=f;h=e}e=ag(g<<1,h)|0;h=gGq(e)|0;c[2112926]=h;if((h|0)!=0){gGz(h|0,0,e|0)}c[3532002]=1024;c[3532e3]=4;a[7460944]=1;c[3532004]=16;c[3531998]=961320;c[3531992]=4969240;c[3531990]=4968824;c[3532044]=1;c[3532030]=1;a[7460960]=1;c[3532092]=1;c[3532094]=0;c[3531954]=0;c[3532096]=0;c[2426962]=10922;c[3532118]=7616;b[7064208]=0;b[7064216]=0;b[7064209]=1024;b[7064217]=1024;b[7064210]=2048;b[7064218]=2048;b[7064211]=3072;b[7064219]=3072;b[7064212]=4096;b[7064220]=4096;b[7064213]=5120;b[7064221]=5120;b[7064214]=6144;b[7064222]=6144;b[7064215]=7168;b[7064223]=7168;c[2113026]=2e5;c[2113024]=66666;c[3532162]=64;c[3532160]=1;c[3532142]=8;c[3532164]=8;c[3532148]=9708032;c[3532140]=725056;c[3532138]=725024;c[3532042]=16384;c[3532034]=16384;eZ9(0)|0;c[3532048]=0;fju();e=c[3532046]|0;h=0;while(1){if((h|0)>=1024){break}i=9638528+(h<<2)|0;if((c[i>>2]|0)==0){j=57900;break}else{h=h+1|0}}do{if((j|0)==57900){h=gGq(e)|0;c[i>>2]=h;if((h|0)==0){break}gGz(h|0,0,e|0);c[3532048]=h;gGz(h|0,0,e|0);fju();if((eZ9(1)|0)!=0){k=1;return k|0}eX5(0,c[3532042]|0,3,8,0,0);a[7461080]=1;a[7461016]=1;fxU(0,425984);if((c[2394]|0)==0){l=c[2112932]|0}else{c[2394]=0;h=c[3532596]|0;c[2112932]=h;g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060];l=h}h=c[3532204]|0;g=l|0;f=0;while(1){d=h+f|0;c[g>>2]=d;c[g+131072>>2]=d;d=f+1024|0;if(d>>>0>262143){break}else{g=g+4|0;f=d}}f=c[3532278]|0;g=l+32768|0;d=8388608;while(1){c[g>>2]=f+(d-8388608);m=d+1024|0;if(m>>>0>8454143){break}else{g=g+4|0;d=m}}d=c[3531970]|0;g=l+36864|0;f=9437184;while(1){m=d+(f-9437184)|0;c[g>>2]=m;c[g+65536>>2]=m;c[g+131072>>2]=m;m=f+1024|0;if(m>>>0>9502719){break}else{g=g+4|0;f=m}}f=c[3532026]|0;c[l+40960>>2]=f;c[l+106496>>2]=f;c[l+172032>>2]=f;g=f+1024|0;c[l+40964>>2]=g;c[l+106500>>2]=g;c[l+172036>>2]=g;g=f+2048|0;c[l+40968>>2]=g;c[l+106504>>2]=g;c[l+172040>>2]=g;g=f+3072|0;c[l+40972>>2]=g;c[l+106508>>2]=g;c[l+172044>>2]=g;g=f+4096|0;c[l+40976>>2]=g;c[l+106512>>2]=g;c[l+172048>>2]=g;g=f+5120|0;c[l+40980>>2]=g;c[l+106516>>2]=g;c[l+172052>>2]=g;g=f+6144|0;c[l+40984>>2]=g;c[l+106520>>2]=g;c[l+172056>>2]=g;g=f+7168|0;c[l+40988>>2]=g;c[l+106524>>2]=g;c[l+172060>>2]=g;g=c[3532208]|0;f=l+45056|0;d=11534336;while(1){m=g+(d-11534336)|0;c[f>>2]=m;c[f+65536>>2]=m;c[f+131072>>2]=m;m=d+1024|0;if(m>>>0>11603967){break}else{f=f+4|0;d=m}}d=c[3531978]|0;c[l+49152>>2]=d;c[l+114688>>2]=d;c[l+180224>>2]=d;f=d+1024|0;c[l+49156>>2]=f;c[l+114692>>2]=f;c[l+180228>>2]=f;f=d+2048|0;c[l+49160>>2]=f;c[l+114696>>2]=f;c[l+180232>>2]=f;f=d+3072|0;c[l+49164>>2]=f;c[l+114700>>2]=f;c[l+180236>>2]=f;f=d+4096|0;c[l+49168>>2]=f;c[l+114704>>2]=f;c[l+180240>>2]=f;f=d+5120|0;c[l+49172>>2]=f;c[l+114708>>2]=f;c[l+180244>>2]=f;f=d+6144|0;c[l+49176>>2]=f;c[l+114712>>2]=f;c[l+180248>>2]=f;f=d+7168|0;c[l+49180>>2]=f;c[l+114716>>2]=f;c[l+180252>>2]=f;f=l+53248|0;d=13631488;while(1){g=h+(d-13369344)|0;c[f>>2]=g;c[f+131072>>2]=g;g=d+1024|0;if(g>>>0>14680063){break}else{f=f+4|0;d=g}}c[l+196608>>2]=918;c[l+196648>>2]=1296;c[l+196688>>2]=3160;c[l+196728>>2]=3224;d=c[3532592]|0;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fjv();c[3532118]=12514;c[3532096]=1;c[3531954]=3;eZ8()|0;c[2405144]=0;c[2439438]=0;c[2429772]=0;c[2437780]=0;c[3532090]=0;c[3532102]=0;gGz(14128336,0,5);c[3532098]=0;k=0;return k|0}}while(0);c[3532048]=0;k=1;return k|0}function fju(){var b=0,d=0,e=0,f=0;b=c[3532048]|0;c[3532204]=b;d=c[3532200]|0;c[3531932]=b+d;e=(c[3531928]|0)+d|0;c[3531952]=b+e;d=e+(c[3531948]|0)|0;c[3531946]=b+d;e=d+(c[3531942]|0)|0;if(a[7460984]|0){c[3541206]=b+e}d=e+262144|0;c[3532056]=b+d;e=(c[3532052]|0)+d|0;d=b+e|0;c[3532020]=d;c[3532208]=d;c[3531936]=b+(e+131072);c[3531970]=b+(e+139264);c[3531966]=b+(e+204800);c[3531964]=b+(e+270336);c[3531978]=b+(e+335872);c[3532026]=b+(e+352256);d=e+368640|0;e=b+d|0;c[3532022]=e;c[3532136]=e;e=ag(c[3532142]|0,c[3532042]|0)|0;f=(ag(e,c[3532164]|0)|0)+d|0;d=c[3532040]|0;if((d|0)!=0){c[3532134]=b+f}e=ag(a[7461200]|0?8:0,d)|0;d=(ag(e,a[7461208]|0?8:0)|0)+f|0;c[3532132]=b+d;f=ag(a[7461168]|0?8:0,c[3532038]|0)|0;e=(ag(f,a[7461192]|0?8:0)|0)+d|0;c[3531962]=b+e;d=ag(a[7460944]|0?16:0,c[3532034]|0)|0;f=(ag(d,c[3532004]|0)|0)+e|0;c[3532028]=b+f;e=f+32768|0;c[3532024]=b+e;f=e+(ag(c[2113070]|0,c[2113068]|0)|0)|0;c[3532100]=b+f;c[3532046]=b+(f+36864);return}function fjv(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;fwR(0);d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];f=c[3528484]|0;c[2076596]=f;g=c[2417276]|0;c[3541536]=g;c[1836236]=0;c[d+4180>>2]=3220;c[d+4184>>2]=1578;i=c[3531932]|0;j=0;k=0;while(1){c[d+76+(k<<2)>>2]=i+(k<<8);l=j+1&65535;if((l&65535)>63){m=0;n=0;break}else{j=l;k=l&65535}}while(1){k=i+(n<<8)|0;c[d+76+(n+512<<2)>>2]=k;c[d+76+(n+768<<2)>>2]=k;k=m+1&65535;if((k&65535)>63){o=64;p=64;break}else{m=k;n=k&65535}}while(1){c[d+76+(p<<2)>>2]=i+(p<<8);n=o+1&65535;if((n&65535)>127){q=64;r=64;break}else{o=n;p=n&65535}}while(1){p=i+(r<<8)|0;c[d+76+(r+512<<2)>>2]=p;c[d+76+(r+768<<2)>>2]=p;p=q+1&65535;if((p&65535)>127){break}else{q=p;r=p&65535}}r=c[3531936]|0;q=192;i=192;while(1){c[d+76+(i<<2)>>2]=r+((i<<8)-49152);p=q+1&65535;if((p&65535)>223){s=192;t=192;break}else{q=p;i=p&65535}}while(1){c[d+76+(t+256<<2)>>2]=r+((t<<8)-49152);i=s+1&65535;if((i&65535)>223){u=192;v=192;break}else{s=i;t=i&65535}}while(1){t=r+((v<<8)-49152)|0;c[d+76+(v+512<<2)>>2]=t;c[d+76+(v+768<<2)>>2]=t;t=u+1&65535;if((t&65535)>223){break}else{u=t;v=t&65535}}if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=f;c[2417276]=g;c[1836236]=-1;TW(c[3531952]|0,14127792,c[3531946]|0,14127768,1410,2458,94);c[2438228]=4e6;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=511;h[745406]=1.0;c[2436786]=1;h[745405]=1.0;c[2436784]=2;h[745404]=.25;a[3203280]=1;return}function fjw(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;a=b[7064582]|0;d=c[2112926]|0;gGz(d|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);d=c[3532028]|0;e=0;f=c[3532026]|0;g=d;while(1){h=b[f>>1]|0;i=(h&65535)>>>12;j=(h&65535)>>>8;k=(h&65535)>>>4;c[g>>2]=((k<<4&255|k&8)&255)>>>3|((i<<4|i)&65535)<<8&63488|((j<<4&255|j&12)&255)<<3&2016;j=e+1|0;if((j|0)<4096){e=j;f=f+2|0;g=g+4|0}else{break}}g=a&65535;c[3532098]=0;ffS();ffT(0);do{if((b[7064582]&8)==0){if((g&1|0)==0){eX0(0,0,c[3532136]|0)}if((g&2|0)!=0){break}eX3(0,0,c[3532136]|0)}else{if((g&2|0)==0){eX3(0,0,c[3532136]|0)}if((g&1|0)!=0){break}eX0(0,0,c[3532136]|0)}}while(0);if((g&4|0)!=0){R8(d);return}eX4(0);R8(d);return}function fjx(b,c){b=b|0;c=c|0;a[9706117]=c&1;return}function fjy(a){a=a|0;var b=0,d=0;b=(c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,4e6,0)|0;return a|0}function fjz(){return+(+((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)/4.0e6)}function fjA(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;f=e[7064582]|0;g=a[14128989]|0;h=g&15;if((f&8|0)==0){a[14128336]=h;i=(g&255)>>>4;a[14128337]=i;j=i;k=h}else{a[14128337]=h;i=(g&255)>>>4;a[14128336]=i;j=h;k=i}a[14128338]=(d[14128988]|0)>>>4;if((j&255)<(k&255)){a[14128337]=k}k=a[14128990]|0;j=k&15;a[14128392]=j;i=(k&255)>>>4;a[14128393]=i;k=a[14128991]|0;h=k&15;a[14128394]=h;g=(k&255)>>>4;a[14128395]=g;k=a[14128984]&192;c[3532102]=k;l=c[2112926]|0;gGz(l|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);l=c[3532028]|0;m=0;n=c[3532026]|0;o=l;while(1){p=b[n>>1]|0;q=(p&65535)>>>12;r=(p&65535)>>>8;s=(p&65535)>>>4;c[o>>2]=((s<<4&255|s&8)&255)>>>3|((q<<4|q)&65535)<<8&63488|((r<<4&255|r&12)&255)<<3&2016;r=m+1|0;if((r|0)<4096){m=r;n=n+2|0;o=o+4|0}else{break}}if((k|0)==0){t=255;u=255;v=255;w=1;x=1;y=1}else{k=(d[14128336]|0)-1|0;o=(d[14128337]|0)-1|0;n=(d[14128338]|0)-1|0;m=j&255;r=(m|0)==(k|0);q=(m|0)==(o|0);s=(m|0)==(n|0);m=i&255;p=(m|0)==(k|0);z=(m|0)==(o|0);A=(m|0)==(n|0);m=h&255;B=(m|0)==(k|0);C=(m|0)==(o|0);D=(m|0)==(n|0);m=g&255;E=(m|0)==(k|0);k=(m|0)==(o|0);o=(m|0)==(n|0);t=(E?g:B?h:p?i:r?j:-1)&255;u=(k?g:C?h:z?i:q?j:-1)&255;v=(o?g:D?h:A?i:s?j:-1)&255;w=o?0:D?0:A?0:s&1^1;x=k?0:C?0:z?0:q&1^1;y=E?0:B?0:p?0:r&1^1}ffS();if((b[7064582]&8)==0){r=(y|0)==0;p=(x|0)==0;B=(w|0)==0;E=(f&1|0)!=0;q=(f&2|0)!=0;z=(f&4|0)!=0;C=g&255;k=h&255;s=i&255;A=j&255;D=c[3532136]|0;o=0;do{if(!((t|0)!=(o|0)|E)){eX0(0,0,D)}if(!((u|0)!=(o|0)|q)){eX3(0,0,D)}if(!((v|0)!=(o|0)|z)){eX4(0)}if((C|0)==(o|0)){ffT(C)}if((k|0)==(o|0)){ffT(k)}if((s|0)==(o|0)){ffT(s)}if((A|0)==(o|0)){ffT(A)}if(!((d[14128336]|0|0)!=(o|0)|r|E)){eX0(0,0,D)}if(!((d[14128337]|0|0)!=(o|0)|p|q)){eX3(0,0,D)}if(!((d[14128338]|0|0)!=(o|0)|B|z)){eX4(0)}o=o+1|0;}while((o|0)<16);R8(l);return}else{o=(y|0)==0;y=(x|0)==0;x=(w|0)==0;w=(f&2|0)!=0;z=(f&1|0)!=0;B=(f&4|0)!=0;f=g&255;g=h&255;h=i&255;i=j&255;j=c[3532136]|0;D=0;do{if(!((t|0)!=(D|0)|w)){eX3(0,0,j)}if(!((u|0)!=(D|0)|z)){eX0(0,0,j)}if(!((v|0)!=(D|0)|B)){eX4(0)}if((f|0)==(D|0)){ffT(f)}if((g|0)==(D|0)){ffT(g)}if((h|0)==(D|0)){ffT(h)}if((i|0)==(D|0)){ffT(i)}if(!((d[14128336]|0|0)!=(D|0)|o|w)){eX3(0,0,j)}if(!((d[14128337]|0|0)!=(D|0)|y|z)){eX0(0,0,j)}if(!((d[14128338]|0|0)!=(D|0)|x|B)){eX4(0)}D=D+1|0;}while((D|0)<16);R8(l);return}}function fjB(){var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;f=i;i=i+24|0;g=f|0;h=b[7064582]|0;j=b[7064590]|0;k=c[2112926]|0;gGz(k|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);k=c[3532028]|0;l=0;m=c[3532026]|0;n=k;while(1){o=b[m>>1]|0;p=(o&65535)>>>12;q=(o&65535)>>>8;r=(o&65535)>>>4;c[n>>2]=((r<<4&255|r&8)&255)>>>3|((p<<4|p)&65535)<<8&63488|((q<<4&255|q&12)&255)<<3&2016;q=l+1|0;if((q|0)<4096){l=q;m=m+2|0;n=n+4|0}else{break}}n=h&65535;h=j&65535;ffS();j=(e[7064582]|0)>>>3&1;m=d[14128989]|0;c[g+(j<<2)>>2]=m&15;c[g+((j^1)<<2)>>2]=m>>>4;m=g+8|0;c[m>>2]=(d[14128988]|0)>>>4;j=(e[7064590]|0)>>>3&1;l=d[14128993]|0;c[g+12+(j<<2)>>2]=l&15;c[g+12+((j^1)<<2)>>2]=l>>>4;l=(d[14128992]|0)>>>4;c[g+20>>2]=l;j=a[14128990]|0;q=j&15;a[14128392]=q;p=(j&255)>>>4;a[14128393]=p;j=a[14128991]|0;r=j&15;a[14128394]=r;o=(j&255)>>>4;a[14128395]=o;j=c[g+12>>2]|0;s=(h&1|0)==0;t=(h&2|0)==0;u=c[g>>2]|0;v=(n&1|0)==0;w=(n&2|0)==0;x=c[g+16>>2]|0;y=c[g+4>>2]|0;g=c[m>>2]|0;m=(h&4|0)!=0;h=(n&4|0)!=0;n=c[3532134]|0;z=c[3532136]|0;A=o&255;o=r&255;r=p&255;p=q&255;q=0;do{do{if((j|0)==(q|0)){if((b[7064590]&8)==0){if(!s){break}eX0(1,0,n);break}else{if(!t){break}eX3(1,0,n);break}}}while(0);do{if((u|0)==(q|0)){if((b[7064582]&8)==0){if(!v){break}eX0(0,0,z);break}else{if(!w){break}eX3(0,0,z);break}}}while(0);do{if((x|0)==(q|0)){if((b[7064590]&8)==0){if(!t){break}eX3(1,0,n);break}else{if(!s){break}eX0(1,0,n);break}}}while(0);do{if((y|0)==(q|0)){if((b[7064582]&8)==0){if(!w){break}eX3(0,0,z);break}else{if(!v){break}eX0(0,0,z);break}}}while(0);if((A|0)==(q|0)){ffT(A)}if((o|0)==(q|0)){ffT(o)}if((r|0)==(q|0)){ffT(r)}if((p|0)==(q|0)){ffT(p)}if(!((l|0)!=(q|0)|m)){eX4(1)}if(!((g|0)!=(q|0)|h)){eX4(0)}q=q+1|0;}while((q|0)<16);R8(k);i=f;return}function fjC(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a=c[2112926]|0;gGz(a|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);a=c[3532028]|0;d=0;e=c[3532026]|0;f=a;while(1){g=b[e>>1]|0;h=(g&65535)>>>12;i=(g&65535)>>>8;j=(g&65535)>>>4;c[f>>2]=((j<<4&255|j&8)&255)>>>3|((h<<4|h)&65535)<<8&63488|((i<<4&255|i&12)&255)<<3&2016;i=d+1|0;if((i|0)<4096){d=i;e=e+2|0;f=f+4|0}else{break}}c[3532098]=0;ffS();ffT(0);R8(a);return}function fjD(){var a=0,d=0,e=0,f=0,g=0,h=0;a=b[7064582]|0;d=c[2112926]|0;gGz(d|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);d=c[3532028]|0;e=0;f=c[3532026]|0;g=d;while(1){h=b[f>>1]|0;c[g>>2]=((h&65535)>>>10<<3&248)<<8|((h&255)<<3&255)>>>3|(((h&65535)>>>7&4|(h&65535)>>>5<<3&255)&255)<<3&2016;h=e+1|0;if((h|0)<4096){e=h;f=f+2|0;g=g+4|0}else{break}}g=a&65535;do{if((b[7064582]&8)==0){if((g&1|0)==0){eX0(0,0,c[3532136]|0)}if((g&2|0)!=0){break}eX3(0,0,c[3532136]|0)}else{if((g&2|0)==0){eX3(0,0,c[3532136]|0)}if((g&1|0)!=0){break}eX0(0,0,c[3532136]|0)}}while(0);c[3532098]=0;ffS();ffT(0);if((g&4|0)!=0){R8(d);return}eX4(0);R8(d);return}function fjE(){var a=0,d=0,e=0;a=b[7064582]|0;d=c[2112926]|0;gGz(d|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);c[3532098]=0;ffS();ffT(0);if((a&4)!=0){e=c[3532276]|0;R8(e);return}eX4(0);e=c[3532276]|0;R8(e);return}function fjF(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;f=e[7064582]|0;g=a[14128989]|0;h=g&15;if((f&8|0)==0){a[14128336]=h;i=(g&255)>>>4;a[14128337]=i;j=i;k=h}else{a[14128337]=h;i=(g&255)>>>4;a[14128336]=i;j=h;k=i}a[14128338]=(d[14128988]|0)>>>4;if((j&255)<(k&255)){a[14128337]=k}k=a[14128990]|0;j=k&15;a[14128392]=j;i=(k&255)>>>4;a[14128393]=i;k=a[14128991]|0;h=k&15;a[14128394]=h;g=(k&255)>>>4;a[14128395]=g;k=a[14128984]&192;c[3532102]=k;l=d[14128985]|0;m=a[14128984+(l>>>7|8)|0]|0;n=l>>>6<<2&4;c[3532252]=l<<2&252;l=c[2112926]|0;gGz(l|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);l=c[3532028]|0;o=0;p=c[3532026]|0;q=l;while(1){r=b[p>>1]|0;c[q>>2]=((r&65535)>>>10<<3&248)<<8|((r&255)<<3&255)>>>3|(((r&65535)>>>7&4|(r&65535)>>>5<<3&255)&255)<<3&2016;r=o+1|0;if((r|0)<4096){o=r;p=p+2|0;q=q+4|0}else{break}}q=(m&255)>>>(n>>>0)&15;if((k|0)==0){s=255;t=255;u=255;v=1;w=1;x=1}else{k=(d[14128336]|0)-1|0;n=(d[14128337]|0)-1|0;m=(d[14128338]|0)-1|0;p=j&255;o=(p|0)==(k|0);r=(p|0)==(n|0);y=(p|0)==(m|0);p=i&255;z=(p|0)==(k|0);A=(p|0)==(n|0);B=(p|0)==(m|0);p=h&255;C=(p|0)==(k|0);D=(p|0)==(n|0);E=(p|0)==(m|0);p=g&255;F=(p|0)==(k|0);k=(p|0)==(n|0);n=(p|0)==(m|0);s=(F?g:C?h:z?i:o?j:-1)&255;t=(k?g:D?h:A?i:r?j:-1)&255;u=(n?g:E?h:B?i:y?j:-1)&255;v=n?0:E?0:B?0:y&1^1;w=k?0:D?0:A?0:r&1^1;x=F?0:C?0:z?0:o&1^1}ffS();if((b[7064582]&8)==0){o=(x|0)==0;z=(w|0)==0;C=(v|0)==0;F=(f&1|0)!=0;r=(f&2|0)!=0;A=(f&4|0)!=0;D=g&255;k=h&255;y=i&255;B=j&255;E=c[3532136]|0;n=0;do{if(!((s|0)!=(n|0)|F)){eX0(0,0,E)}if(!((t|0)!=(n|0)|r)){eX3(0,0,E)}if(!((u|0)!=(n|0)|A)){eX4(0)}if((D|0)==(n|0)){ffT(D)}if((k|0)==(n|0)){ffT(k)}if((y|0)==(n|0)){ffT(y)}if((B|0)==(n|0)){ffT(B)}if((q|0)==(n|0)){eX$()}if(!((d[14128336]|0|0)!=(n|0)|o|F)){eX0(0,0,E)}if(!((d[14128337]|0|0)!=(n|0)|z|r)){eX3(0,0,E)}if(!((d[14128338]|0|0)!=(n|0)|C|A)){eX4(0)}n=n+1|0;}while((n|0)<16);R8(l);return}else{n=(x|0)==0;x=(w|0)==0;w=(v|0)==0;v=(f&2|0)!=0;A=(f&1|0)!=0;C=(f&4|0)!=0;f=g&255;g=h&255;h=i&255;i=j&255;j=c[3532136]|0;E=0;do{if(!((s|0)!=(E|0)|v)){eX3(0,0,j)}if(!((t|0)!=(E|0)|A)){eX0(0,0,j)}if(!((u|0)!=(E|0)|C)){eX4(0)}if((f|0)==(E|0)){ffT(f)}if((g|0)==(E|0)){ffT(g)}if((h|0)==(E|0)){ffT(h)}if((i|0)==(E|0)){ffT(i)}if((q|0)==(E|0)){eX$()}if(!((d[14128336]|0|0)!=(E|0)|n|v)){eX3(0,0,j)}if(!((d[14128337]|0|0)!=(E|0)|x|A)){eX0(0,0,j)}if(!((d[14128338]|0|0)!=(E|0)|w|C)){eX4(0)}E=E+1|0;}while((E|0)<16);R8(l);return}}function fjG(){var a=0,d=0,f=0;a=e[7064582]|0;d=c[2112926]|0;gGz(d|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);c[3532098]=0;do{if((b[7064582]&8)==0){if((a&1|0)==0){eX0(0,0,c[3532136]|0)}if((a&2|0)!=0){break}eX3(0,0,c[3532136]|0)}else{if((a&2|0)==0){eX3(0,0,c[3532136]|0)}if((a&1|0)!=0){break}eX0(0,0,c[3532136]|0)}}while(0);ffS();ffT(0);if((a&4|0)!=0){f=c[3532276]|0;R8(f);return}eX4(0);f=c[3532276]|0;R8(f);return}function fjH(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=e[725160+(((c[2436808]|0)>>>2&7)<<1)>>1]|0;g=f>>>12;h=a[14128988]|0;a[14128336+g|0]=h&15;i=f>>>8&15;a[14128336+i|0]=(h&255)>>>4;h=a[14128989]|0;j=f>>>4&15;a[14128336+j|0]=h&15;k=f&15;a[14128336+k|0]=(h&255)>>>4;a[14128340]=a[14128993]&15;h=a[14128337]|0;f=a[14128336]|0;if((h&255)<(f&255)){a[14128337]=f;l=f}else{l=h}h=a[14128338]|0;if((h&255)<(l&255)){a[14128338]=l;m=l}else{m=h}if((d[14128339]|0)<(m&255)){a[14128339]=m}m=a[14128990]|0;h=m&15;a[14128392]=h;l=(m&255)>>>4;a[14128393]=l;m=a[14128991]|0;f=m&15;a[14128394]=f;n=(m&255)>>>4;a[14128395]=n;c[3532102]=a[14128984]&192;m=c[2112926]|0;gGz(m|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);m=c[3532028]|0;o=0;p=c[3532026]|0;q=m;while(1){r=b[p>>1]|0;s=(r&65535)>>>12;t=(r&65535)>>>8;u=(r&65535)>>>4;c[q>>2]=((u<<4&255|u&8)&255)>>>3|((s<<4|s)&65535)<<8&63488|((t<<4&255|t&12)&255)<<3&2016;t=o+1|0;if((t|0)<8192){o=t;p=p+2|0;q=q+4|0}else{break}}ffS();q=n&255;n=f&255;f=l&255;l=h&255;h=c[3532136]|0;p=0;do{if((q|0)==(p|0)){ffT(q)}if((n|0)==(p|0)){ffT(n)}if((f|0)==(p|0)){ffT(f)}if((l|0)==(p|0)){ffT(l)}do{if((d[14128336]|0|0)==(p|0)){if((g|0)==1){eXP(1,0,h);break}else if((g|0)==0){eXP(0,0,h);break}else if((g|0)==2){eXQ(2,0,h);break}else if((g|0)==3){eXQ(3,0,h);break}else{break}}}while(0);do{if((d[14128337]|0|0)==(p|0)){if((i|0)==0){eXP(0,0,h);break}else if((i|0)==1){eXP(1,0,h);break}else if((i|0)==2){eXQ(2,0,h);break}else if((i|0)==3){eXQ(3,0,h);break}else{break}}}while(0);do{if((d[14128338]|0|0)==(p|0)){if((j|0)==2){eXQ(2,0,h);break}else if((j|0)==3){eXQ(3,0,h);break}else if((j|0)==0){eXP(0,0,h);break}else if((j|0)==1){eXP(1,0,h);break}else{break}}}while(0);do{if((d[14128339]|0|0)==(p|0)){if((k|0)==0){eXP(0,0,h);break}else if((k|0)==1){eXP(1,0,h);break}else if((k|0)==2){eXQ(2,0,h);break}else if((k|0)==3){eXQ(3,0,h);break}else{break}}}while(0);p=p+1|0;}while((p|0)<16);eXR();R8(m);return}function fjI(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=e[725160+(((c[2436808]|0)>>>2&7)<<1)>>1]|0;g=a[14128988]|0;a[14128336]=(g&255)>>>4;h=a[14128989]|0;a[14128337]=h&15;a[14128338]=(h&255)>>>4;a[14128339]=g&15;g=a[14128991]|0;h=(g&255)>>>4;a[14128340]=h;i=a[14128990]|0;j=i&15;a[14128392]=j;k=(i&255)>>>4;a[14128393]=k;i=g&15;a[14128394]=i;a[14128395]=h;g=c[2112926]|0;gGz(g|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);g=c[3532028]|0;l=0;m=c[3532026]|0;n=g;while(1){o=b[m>>1]|0;p=(o&65535)>>>12;q=(o&65535)>>>8;r=(o&65535)>>>4;c[n>>2]=((r<<4&255|r&8)&255)>>>3|((p<<4|p)&65535)<<8&63488|((q<<4&255|q&12)&255)<<3&2016;q=l+1|0;if((q|0)<4096){l=q;m=m+2|0;n=n+4|0}else{break}}n=f>>>12;ffS();m=f>>>8&15;l=f>>>4&15;q=f&15;f=h&255;h=i&255;i=k&255;k=j&255;j=c[3532136]|0;p=0;do{if((f|0)==(p|0)){ffT(f)}if((h|0)==(p|0)){ffT(h)}if((i|0)==(p|0)){ffT(i)}if((k|0)==(p|0)){ffT(k)}do{if((d[14128336]|0|0)==(p|0)){if((n|0)==0){eXP(0,0,j);break}else if((n|0)==1){eXP(1,0,j);break}else if((n|0)==2){eXQ(2,0,j);break}else if((n|0)==3){eXQ(3,0,j);break}else{break}}}while(0);do{if((d[14128337]|0|0)==(p|0)){if((m|0)==0){eXP(0,0,j);break}else if((m|0)==1){eXP(1,0,j);break}else if((m|0)==3){eXQ(3,0,j);break}else if((m|0)==2){eXQ(2,0,j);break}else{break}}}while(0);do{if((d[14128338]|0|0)==(p|0)){if((l|0)==1){eXP(1,0,j);break}else if((l|0)==2){eXQ(2,0,j);break}else if((l|0)==3){eXQ(3,0,j);break}else if((l|0)==0){eXP(0,0,j);break}else{break}}}while(0);do{if((d[14128339]|0|0)==(p|0)){if((q|0)==2){eXQ(2,0,j);break}else if((q|0)==3){eXQ(3,0,j);break}else if((q|0)==0){eXP(0,0,j);break}else if((q|0)==1){eXP(1,0,j);break}else{break}}}while(0);p=p+1|0;}while((p|0)<16);eXR();R8(g);return}function fjJ(){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;gGz(14128320,-1|0,6);b=0;c=-1;d=-1;e=-1;f=-1;g=-1;h=-1;do{c=(c&255)-((a[14128312+b|0]&1)<<b)&255;d=(d&255)-((a[14128304+b|0]&1)<<b)&255;e=(e&255)-((a[14128296+b|0]&1)<<b)&255;f=(f&255)-((a[14128288+b|0]&1)<<b)&255;g=(g&255)-((a[14128280+b|0]&1)<<b)&255;h=(h&255)-((a[14128264+b|0]&1)<<b)&255;b=b+1|0;}while((b|0)<8);a[14128320]=c;a[14128321]=d;a[14128322]=e;a[14128323]=f;a[14128324]=g;a[14128325]=h;return}function fjK(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=b[7064582]|0;a[14128338]=(d[14128988]|0)>>>4;f=a[14128990]|0;g=f&15;a[14128392]=g;h=(f&255)>>>4;a[14128393]=h;f=a[14128991]|0;i=f&15;a[14128394]=i;j=(f&255)>>>4;a[14128395]=j;f=d[14128985]|0;k=a[14128984+(f>>>7|8)|0]|0;l=f>>>6<<2&4;c[3532252]=f<<2&252;f=c[2112926]|0;gGz(f|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);f=c[3532028]|0;m=0;n=c[3532026]|0;o=f;while(1){p=b[n>>1]|0;c[o>>2]=((p&65535)>>>10<<3&248)<<8|((p&255)<<3&255)>>>3|(((p&65535)>>>7&4|(p&65535)>>>5<<3&255)&255)<<3&2016;p=m+1|0;if((p|0)<4096){m=p;n=n+2|0;o=o+4|0}else{break}}o=(k&255)>>>(l>>>0)&15;ffS();l=j&255;j=i&255;i=h&255;h=g&255;if((e&4)==0){q=0}else{e=0;do{if((l|0)==(e|0)){ffT(l)}if((j|0)==(e|0)){ffT(j)}if((i|0)==(e|0)){ffT(i)}if((h|0)==(e|0)){ffT(h)}if((o|0)==(e|0)){eX$()}e=e+1|0;}while((e|0)<16);R8(f);return}do{if((l|0)==(q|0)){ffT(l)}if((j|0)==(q|0)){ffT(j)}if((i|0)==(q|0)){ffT(i)}if((h|0)==(q|0)){ffT(h)}if((o|0)==(q|0)){eX$()}if((d[14128338]|0|0)==(q|0)){eX4(0)}q=q+1|0;}while((q|0)<16);R8(f);return}function fjL(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;f=e[7064582]|0;g=a[14128989]|0;h=g&15;if((f&8|0)==0){a[14128336]=h;i=(g&255)>>>4;a[14128337]=i;j=i;k=h}else{a[14128337]=h;i=(g&255)>>>4;a[14128336]=i;j=h;k=i}a[14128338]=(d[14128988]|0)>>>4;if((j&255)<(k&255)){a[14128337]=k}k=a[14128990]|0;j=k&15;a[14128392]=j;i=(k&255)>>>4;a[14128393]=i;k=a[14128991]|0;h=k&15;a[14128394]=h;g=(k&255)>>>4;a[14128395]=g;k=a[14128984]&192;c[3532102]=k;l=d[14128985]|0;m=a[14128984+(l>>>7|8)|0]|0;n=l>>>6<<2&4;c[3532252]=l<<2&252;l=c[2112926]|0;gGz(l|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);l=c[3532028]|0;o=0;p=c[3532026]|0;q=l;while(1){r=b[p>>1]|0;s=(r&65535)>>>12;t=(r&65535)>>>8;u=(r&65535)>>>4;c[q>>2]=((u<<4&255|u&8)&255)>>>3|((s<<4|s)&65535)<<8&63488|((t<<4&255|t&12)&255)<<3&2016;t=o+1|0;if((t|0)<4096){o=t;p=p+2|0;q=q+4|0}else{break}}q=(m&255)>>>(n>>>0)&15;if((k|0)==0){v=255;w=255;x=255;y=1;z=1;A=1}else{k=(d[14128336]|0)-1|0;n=(d[14128337]|0)-1|0;m=(d[14128338]|0)-1|0;p=j&255;o=(p|0)==(k|0);t=(p|0)==(n|0);s=(p|0)==(m|0);p=i&255;u=(p|0)==(k|0);r=(p|0)==(n|0);B=(p|0)==(m|0);p=h&255;C=(p|0)==(k|0);D=(p|0)==(n|0);E=(p|0)==(m|0);p=g&255;F=(p|0)==(k|0);k=(p|0)==(n|0);n=(p|0)==(m|0);v=(F?g:C?h:u?i:o?j:-1)&255;w=(k?g:D?h:r?i:t?j:-1)&255;x=(n?g:E?h:B?i:s?j:-1)&255;y=n?0:E?0:B?0:s&1^1;z=k?0:D?0:r?0:t&1^1;A=F?0:C?0:u?0:o&1^1}ffS();if((b[7064582]&8)==0){o=(A|0)==0;u=(z|0)==0;C=(y|0)==0;F=(f&1|0)!=0;t=(f&2|0)!=0;r=(f&4|0)!=0;D=g&255;k=h&255;s=i&255;B=j&255;E=c[3532136]|0;n=0;do{if(!((v|0)!=(n|0)|F)){eX0(0,0,E)}if(!((w|0)!=(n|0)|t)){eX3(0,0,E)}if(!((x|0)!=(n|0)|r)){eX4(0)}if((D|0)==(n|0)){ffT(D)}if((k|0)==(n|0)){ffT(k)}if((s|0)==(n|0)){ffT(s)}if((B|0)==(n|0)){ffT(B)}if((q|0)==(n|0)){eX$()}if(!((d[14128336]|0|0)!=(n|0)|o|F)){eX0(0,0,E)}if(!((d[14128337]|0|0)!=(n|0)|u|t)){eX3(0,0,E)}if(!((d[14128338]|0|0)!=(n|0)|C|r)){eX4(0)}n=n+1|0;}while((n|0)<16);R8(l);return}else{n=(A|0)==0;A=(z|0)==0;z=(y|0)==0;y=(f&2|0)!=0;r=(f&1|0)!=0;C=(f&4|0)!=0;f=g&255;g=h&255;h=i&255;i=j&255;j=c[3532136]|0;E=0;do{if(!((v|0)!=(E|0)|y)){eX3(0,0,j)}if(!((w|0)!=(E|0)|r)){eX0(0,0,j)}if(!((x|0)!=(E|0)|C)){eX4(0)}if((f|0)==(E|0)){ffT(f)}if((g|0)==(E|0)){ffT(g)}if((h|0)==(E|0)){ffT(h)}if((i|0)==(E|0)){ffT(i)}if((q|0)==(E|0)){eX$()}if(!((d[14128336]|0|0)!=(E|0)|n|y)){eX3(0,0,j)}if(!((d[14128337]|0|0)!=(E|0)|A|r)){eX0(0,0,j)}if(!((d[14128338]|0|0)!=(E|0)|z|C)){eX4(0)}E=E+1|0;}while((E|0)<16);R8(l);return}}function fjM(a){a=a|0;var b=0,d=0;b=(c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,6e6,0)|0;return a|0}function fjN(){return+(+((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)/6.0e6)}function fjO(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=b[7064582]|0;a[14128338]=(d[14128988]|0)>>>4;f=a[14128990]|0;g=f&15;a[14128392]=g;h=(f&255)>>>4;a[14128393]=h;f=a[14128991]|0;i=f&15;a[14128394]=i;j=(f&255)>>>4;a[14128395]=j;f=d[14128985]|0;k=a[14128984+(f>>>7|8)|0]|0;l=f>>>6<<2&4;c[3532252]=f<<2&252;f=c[2112926]|0;gGz(f|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);f=c[3532028]|0;m=0;n=c[3532026]|0;o=f;while(1){p=b[n>>1]|0;q=(p&65535)>>>12;r=(p&65535)>>>8;s=(p&65535)>>>4;c[o>>2]=((s<<4&255|s&8)&255)>>>3|((q<<4|q)&65535)<<8&63488|((r<<4&255|r&12)&255)<<3&2016;r=m+1|0;if((r|0)<4096){m=r;n=n+2|0;o=o+4|0}else{break}}o=(k&255)>>>(l>>>0)&15;ffS();l=(e&4)!=0;e=j&255;j=i&255;i=h&255;h=g&255;g=0;do{if((e|0)==(g|0)){ffT(e)}if((j|0)==(g|0)){ffT(j)}if((i|0)==(g|0)){ffT(i)}if((h|0)==(g|0)){ffT(h)}if((o|0)==(g|0)){eX$()}if(!((d[14128338]|0|0)!=(g|0)|l)){eX4(0)}g=g+1|0;}while((g|0)<16);R8(f);return}function fjP(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=d&65535;if((f|0)==51202){fjQ(2,e&255);return}else if((f|0)==47105){a[c[2406752]|0]=e&1;return}else if((f|0)==47104){a[c[3528664]|0]=e&1;return}else if((f|0)==53248){c[2388356]=0;return}else if((f|0)==55296){a[c[3528214]|0]=e;d=c[1836236]|0;g=c[9757320+(d<<2)>>2]|0;if((g|0)!=0){h=g;gGC(h|0,9706056,76)|0}c[9752472+(d<<2)>>2]=c[2433530];c[14113936+(d<<2)>>2]=c[2076596];c[9669104+(d<<2)>>2]=c[3541536];c[1836236]=-1;d=c[2439332]|0;h=(d|0)==0;if(!h){g=d;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;g=c[2438120]|0;c[2433530]=g;i=c[3528486]|0;c[2076596]=i;j=c[2417278]|0;c[3541536]=j;c[1836236]=2;a[9706117]=1;if(!h){h=d;gGC(h|0,9706056,76)|0}c[2438120]=g;c[3528486]=i;c[2417278]=j;c[1836236]=-1;j=c[2439330]|0;if((j|0)!=0){i=j;gGC(9706056,i|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;return}else if((f|0)==59392){a[9533352]=e;c[2161344]=1;if((c[2415208]|0)==1){return}c[2415208]=1;b[4830412]=b[4830412]|1;return}else if((f|0)==51203){f42();a[8451544]=0;a[8451536]=0;a[9533800]=0;a[8451528]=0;a[8451520]=0;a[9533792]=0;a[8451512]=0;a[8451504]=0;a[9533784]=0;a[9533352]=0;a[9533344]=0;c[2161338]=0;c[2161344]=0;c[3525364]=e&255;return}else if((f|0)==51201){a[c[3526938]|0]=-(e&1)&255;return}else if((f|0)==47106){a[(c[2406752]|0)+1|0]=e&1;return}else if((f|0)==51200){i=e&1;if(i<<24>>24==0){a[9706117]=0}c[2432960]=i&255;return}else if((f|0)==51205){fjQ(1,e&255);return}else if((f|0)==51204){f=e&1;if(f<<24>>24==0){a[9706117]=0}c[2432961]=f&255;return}else{return}}function fjQ(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=c[2433530]|0;g=c[2076596]|0;h=(c[2426530]|0)+f-g|0;i=c[1836236]|0;j=c[9757320+(i<<2)>>2]|0;if((j|0)!=0){k=j;gGC(k|0,9706056,76)|0}c[9752472+(i<<2)>>2]=f;c[14113936+(i<<2)>>2]=g;c[9669104+(i<<2)>>2]=c[3541536];c[1836236]=-1;i=c[9757320+(d<<2)>>2]|0;if((i|0)!=0){g=i;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;g=c[9752472+(d<<2)>>2]|0;c[2433530]=g;f=c[14113936+(d<<2)>>2]|0;c[2076596]=f;c[3541536]=c[9669104+(d<<2)>>2];c[1836236]=d;k=f-((c[2426530]|0)+g)|0;f=h+k|0;if((e|0)==0){do{if((f|0)<1){l=g;m=d;n=i}else{if((a[i+4188|0]|0)==0){h=gfc(f)|0;j=(c[2433530]|0)+h|0;c[2433530]=j;h=c[1836236]|0;l=j;m=h;n=c[9757320+(h<<2)>>2]|0;break}else{h=f+g|0;c[2433530]=h;l=h;m=d;n=i;break}}}while(0);gGz(9706056,0,76);o=m;p=n;q=l}else{l=k+g+f|0;c[2433530]=l;o=d;p=i;q=l}c[14101448+(d-1<<2)>>2]=e;if((p|0)!=0){e=p;gGC(e|0,9706056,76)|0}c[9752472+(o<<2)>>2]=q;c[14113936+(o<<2)>>2]=c[2076596];c[9669104+(o<<2)>>2]=c[3541536];c[1836236]=-1;o=c[2439330]|0;if((o|0)==0){r=c[2426515]|0;s=r&65535;b[4853030]=s;t=c[2438118]|0;c[2433530]=t;u=c[3528484]|0;c[2076596]=u;v=c[2417276]|0;c[3541536]=v;c[1836236]=0;return}q=o;gGC(9706056,q|0,76)|0;r=c[2426515]|0;s=r&65535;b[4853030]=s;t=c[2438118]|0;c[2433530]=t;u=c[3528484]|0;c[2076596]=u;v=c[2417276]|0;c[3541536]=v;c[1836236]=0;return}function fjR(b){b=b|0;var d=0,e=0;d=b&65535;do{if((d|0)==49153){e=a[9549752]|0}else if((d|0)==49158){e=a[9634761]|0}else if((d|0)==49159){e=a[9634762]|0}else if((d|0)==63488){e=a[c[2443714]|0]|0}else if((d|0)==57344){c[2161338]=0;e=a[9533344]|0}else if((d|0)==49157){e=a[9634760]|0}else if((d|0)==49156){e=(a[c[3526938]|0]|-49)&a[9549688]}else if((d|0)==49155){b=(c[2161344]|0)==0?16:0;if((c[2161338]|0)==0){e=b&255;break}e=(b|32)&255}else if((d|0)==49152){e=a[9549904]|0}else{e=0}}while(0);return e|0}function fjS(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((e|0)==24576){a[c[2443714]|0]=d;return}else if((e|0)==40960){TR(1,d&255);return}else if((e|0)==32768){TR(0,d&255);return}else{return}}function fjT(b){b=b|0;var d=0;if(b<<16>>16!=16384){d=0;return d|0}a[9706117]=0;d=a[c[3528214]|0]|0;return d|0}function fjU(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2384772+(b*112|0)>>2];c[a+104>>2]=c[2384776+(b*112|0)>>2];c[a+108>>2]=c[2384780+(b*112|0)>>2];d=0;return d|0}function fjV(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=2384672+(b*112|0);e=0;return e|0}function fjW(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1205384+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function fjX(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>70){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3563112+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fjY(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0;e=i;i=i+2520|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;B=e+1200|0;C=e+1312|0;D=e+1320|0;E=e+1432|0;F=e+1440|0;G=e+1552|0;H=e+1560|0;I=e+1672|0;J=e+1680|0;K=e+1792|0;L=e+1800|0;M=e+1912|0;N=e+1920|0;O=e+2032|0;P=e+2040|0;Q=e+2152|0;R=e+2160|0;S=e+2272|0;T=e+2280|0;U=e+2392|0;V=e+2400|0;W=e+2512|0;c[2414876]=0;c[3529220]=0;c[3529176]=65536;c[3529164]=131072;c[2387314]=196608;c[3530766]=198656;c[3530530]=264192;c[3530398]=329728;c[3530990]=362496;c[2414578]=365312;c[2387844]=365312;c[2387962]=367360;c[3527292]=369408;c[3529264]=375552;c[2387326]=377600;c[3526938]=377728;c[3528214]=377729;c[2443714]=377730;c[3528664]=377731;c[2406752]=377732;c[2411522]=377734;c[3527460]=377734;c[2406908]=380294;c[3529910]=390534;c[3527250]=400774;X=0;while(1){if((X|0)>=1024){break}Y=9638528+(X<<2)|0;if((c[Y>>2]|0)==0){Z=58467;break}else{X=X+1|0}}do{if((Z|0)==58467){X=gGq(402822)|0;c[Y>>2]=X;if((X|0)==0){break}c[2414876]=X;gGz(X|0,0,402822);c[3529220]=X;c[3529176]=X+65536;c[3529164]=X+131072;c[2387314]=X+196608;c[3530766]=X+198656;c[3530530]=X+264192;c[3530398]=X+329728;c[3530990]=X+362496;_=X+365312|0;c[2414578]=_;c[2387844]=_;c[2387962]=X+367360;c[3527292]=X+369408;c[3529264]=X+375552;c[2387326]=X+377600;c[3526938]=X+377728;c[3528214]=X+377729;c[2443714]=X+377730;c[3528664]=X+377731;c[2406752]=X+377732;_=X+377734|0;c[2411522]=_;c[3527460]=_;c[2406908]=X+380294;c[3529910]=X+390534;c[3527250]=X+400774;c[2414062]=X+402822;if((c[3542200]|0)==0){$=1;i=e;return $|0}_=V+108|0;c[_>>2]=0;aa=V+100|0;c[aa>>2]=0;ab=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ab&16383](V,0)|0;do{if((c[_>>2]|0)!=0){ab=c[aa>>2]|0;c[W>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](W,0,0)|0;if((ab|0)<1){$=1;i=e;return $|0}if((gzL(X,0,0)|0)==0){break}else{$=1}i=e;return $|0}}while(0);X=(c[3529220]|0)+8192|0;if((c[3542200]|0)==0){$=1;i=e;return $|0}aa=T+108|0;c[aa>>2]=0;_=T+100|0;c[_>>2]=0;ab=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ab&16383](T,1)|0;do{if((c[aa>>2]|0)!=0){ab=c[_>>2]|0;c[U>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](U,1,0)|0;if((ab|0)<1){$=1;i=e;return $|0}if((gzL(X,0,1)|0)==0){break}else{$=1}i=e;return $|0}}while(0);X=(c[3529220]|0)+16384|0;if((c[3542200]|0)==0){$=1;i=e;return $|0}_=R+108|0;c[_>>2]=0;aa=R+100|0;c[aa>>2]=0;ab=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ab&16383](R,2)|0;do{if((c[_>>2]|0)!=0){ab=c[aa>>2]|0;c[S>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](S,2,0)|0;if((ab|0)<1){$=1;i=e;return $|0}if((gzL(X,0,2)|0)==0){break}else{$=1}i=e;return $|0}}while(0);X=c[3529176]|0;if((c[3542200]|0)==0){$=1;i=e;return $|0}aa=P+108|0;c[aa>>2]=0;_=P+100|0;c[_>>2]=0;ab=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ab&16383](P,3)|0;do{if((c[aa>>2]|0)!=0){ab=c[_>>2]|0;c[Q>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](Q,3,0)|0;if((ab|0)<1){$=1;i=e;return $|0}if((gzL(X,0,3)|0)==0){break}else{$=1}i=e;return $|0}}while(0);X=c[3529164]|0;if((c[3542200]|0)==0){$=1;i=e;return $|0}_=N+108|0;c[_>>2]=0;aa=N+100|0;c[aa>>2]=0;ab=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ab&16383](N,4)|0;do{if((c[_>>2]|0)!=0){ab=c[aa>>2]|0;c[O>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](O,4,0)|0;if((ab|0)<1){$=1;i=e;return $|0}if((gzL(X,0,4)|0)==0){break}else{$=1}i=e;return $|0}}while(0);X=c[3530766]|0;if((c[3542200]|0)==0){$=1;i=e;return $|0}aa=L+108|0;c[aa>>2]=0;_=L+100|0;c[_>>2]=0;ab=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ab&16383](L,5)|0;do{if((c[aa>>2]|0)!=0){ab=c[_>>2]|0;c[M>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](M,5,0)|0;if((ab|0)<1){$=1;i=e;return $|0}if((gzL(X,0,5)|0)==0){break}else{$=1}i=e;return $|0}}while(0);X=c[3530530]|0;if((c[3542200]|0)==0){$=1;i=e;return $|0}_=J+108|0;c[_>>2]=0;aa=J+100|0;c[aa>>2]=0;ab=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ab&16383](J,6)|0;do{if((c[_>>2]|0)!=0){ab=c[aa>>2]|0;c[K>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](K,6,0)|0;if((ab|0)<1){$=1;i=e;return $|0}if((gzL(X,0,6)|0)==0){break}else{$=1}i=e;return $|0}}while(0);X=(c[3530530]|0)+8192|0;if((c[3542200]|0)==0){$=1;i=e;return $|0}aa=H+108|0;c[aa>>2]=0;_=H+100|0;c[_>>2]=0;ab=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ab&16383](H,7)|0;do{if((c[aa>>2]|0)!=0){ab=c[_>>2]|0;c[I>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](I,7,0)|0;if((ab|0)<1){$=1;i=e;return $|0}if((gzL(X,0,7)|0)==0){break}else{$=1}i=e;return $|0}}while(0);X=(c[3530530]|0)+16384|0;if((c[3542200]|0)==0){$=1;i=e;return $|0}_=F+108|0;c[_>>2]=0;aa=F+100|0;c[aa>>2]=0;ab=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ab&16383](F,8)|0;do{if((c[_>>2]|0)!=0){ab=c[aa>>2]|0;c[G>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](G,8,0)|0;if((ab|0)<1){$=1;i=e;return $|0}if((gzL(X,0,8)|0)==0){break}else{$=1}i=e;return $|0}}while(0);X=(c[3530530]|0)+24576|0;if((c[3542200]|0)==0){$=1;i=e;return $|0}aa=D+108|0;c[aa>>2]=0;_=D+100|0;c[_>>2]=0;ab=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ab&16383](D,9)|0;do{if((c[aa>>2]|0)!=0){ab=c[_>>2]|0;c[E>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](E,9,0)|0;if((ab|0)<1){$=1;i=e;return $|0}if((gzL(X,0,9)|0)==0){break}else{$=1}i=e;return $|0}}while(0);X=c[3530398]|0;if((c[3542200]|0)==0){$=1;i=e;return $|0}_=B+108|0;c[_>>2]=0;aa=B+100|0;c[aa>>2]=0;ab=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ab&16383](B,10)|0;do{if((c[_>>2]|0)!=0){ab=c[aa>>2]|0;c[C>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](C,10,0)|0;if((ab|0)<1){$=1;i=e;return $|0}if((gzL(X,0,10)|0)==0){break}else{$=1}i=e;return $|0}}while(0);X=(c[3530398]|0)+16384|0;if((c[3542200]|0)==0){$=1;i=e;return $|0}aa=z+108|0;c[aa>>2]=0;_=z+100|0;c[_>>2]=0;ab=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ab&16383](z,11)|0;do{if((c[aa>>2]|0)!=0){ab=c[_>>2]|0;c[A>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](A,11,0)|0;if((ab|0)<1){$=1;i=e;return $|0}if((gzL(X,0,11)|0)==0){break}else{$=1}i=e;return $|0}}while(0);X=c[3530990]|0;if((c[3542200]|0)==0){$=1;i=e;return $|0}_=x+108|0;c[_>>2]=0;aa=x+100|0;c[aa>>2]=0;ab=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ab&16383](x,12)|0;do{if((c[_>>2]|0)!=0){ab=c[aa>>2]|0;c[y>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](y,12,0)|0;if((ab|0)<1){$=1;i=e;return $|0}if((gzL(X,0,12)|0)==0){break}else{$=1}i=e;return $|0}}while(0);X=(c[3530990]|0)+256|0;if((c[3542200]|0)==0){$=1;i=e;return $|0}aa=v+108|0;c[aa>>2]=0;_=v+100|0;c[_>>2]=0;ab=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ab&16383](v,13)|0;do{if((c[aa>>2]|0)!=0){ab=c[_>>2]|0;c[w>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](w,13,0)|0;if((ab|0)<1){$=1;i=e;return $|0}if((gzL(X,0,13)|0)==0){break}else{$=1}i=e;return $|0}}while(0);X=(c[3530990]|0)+512|0;if((c[3542200]|0)==0){$=1;i=e;return $|0}_=t+108|0;c[_>>2]=0;aa=t+100|0;c[aa>>2]=0;ab=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ab&16383](t,14)|0;do{if((c[_>>2]|0)!=0){ab=c[aa>>2]|0;c[u>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](u,14,0)|0;if((ab|0)<1){$=1;i=e;return $|0}if((gzL(X,0,14)|0)==0){break}else{$=1}i=e;return $|0}}while(0);X=c[642608+(c[2436]<<2)>>2]|0;do{if((fa(c[X>>2]|0,447616)|0)==0){aa=c[3530398]|0;_=aa+32768|0;if((c[3542200]|0)==0){break}ab=r+108|0;c[ab>>2]=0;ac=r+100|0;c[ac>>2]=0;ad=c[X+76>>2]|0;gA[ad&16383](r,16)|0;if((c[ab>>2]|0)!=0){ab=c[ac>>2]|0;c[s>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](s,16,0)|0;if((ab|0)<1){break}if((gzL(_,0,16)|0)!=0){break}}ab=aa+33792|0;if((c[3542200]|0)==0){break}ac=p+108|0;c[ac>>2]=0;ad=p+100|0;c[ad>>2]=0;ae=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ae&16383](p,18)|0;if((c[ac>>2]|0)!=0){ac=c[ad>>2]|0;c[q>>2]=9534384;ad=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ad&16383](q,18,0)|0;if((ac|0)<1){break}if((gzL(ab,0,18)|0)!=0){break}}ab=aa+34816|0;if((c[3542200]|0)==0){break}ac=n+108|0;c[ac>>2]=0;ad=n+100|0;c[ad>>2]=0;ae=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ae&16383](n,15)|0;if((c[ac>>2]|0)!=0){ac=c[ad>>2]|0;c[o>>2]=9534384;ad=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ad&16383](o,15,0)|0;if((ac|0)<1){break}if((gzL(ab,0,15)|0)!=0){break}}ab=aa+35840|0;if((c[3542200]|0)==0){break}ac=l+108|0;c[ac>>2]=0;ad=l+100|0;c[ad>>2]=0;ae=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ae&16383](l,17)|0;if((c[ac>>2]|0)!=0){ac=c[ad>>2]|0;c[m>>2]=9534384;ad=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ad&16383](m,17,0)|0;if((ac|0)<1){break}if((gzL(ab,0,17)|0)!=0){break}}ab=c[3530990]|0;ac=0;do{a[ab+(ac+768)|0]=a[aa+(ac+34816)|0]<<4|a[aa+(ac+32768)|0]&15;ac=ac+1|0;}while((ac|0)<2048);gGz(_|0,0,4096)}else{ac=(c[3530990]|0)+768|0;if((c[3542200]|0)==0){$=1;i=e;return $|0}aa=j+108|0;c[aa>>2]=0;ab=j+100|0;c[ab>>2]=0;gA[c[X+76>>2]&16383](j,15)|0;do{if((c[aa>>2]|0)!=0){ad=c[ab>>2]|0;c[k>>2]=9534384;ae=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ae&16383](k,15,0)|0;if((ad|0)<1){$=1;i=e;return $|0}if((gzL(ac,0,15)|0)==0){break}else{$=1}i=e;return $|0}}while(0);ac=c[2387314]|0;if((c[3542200]|0)==0){$=1;i=e;return $|0}ab=f+108|0;c[ab>>2]=0;aa=f+100|0;c[aa>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,16)|0;if((c[ab>>2]|0)==0){break}ab=c[aa>>2]|0;c[g>>2]=9534384;gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](g,16,0)|0;if((ab|0)<1){$=1;i=e;return $|0}if((gzL(ac,0,16)|0)==0){break}else{$=1}i=e;return $|0}}while(0);X=c[3527250]|0;ac=0;do{ab=((ac|0)%36|0)-2|0;aa=((ac|0)/36|0)+2|0;if((ab&32|0)==0){b[X+(ac<<1)>>1]=(aa<<5)+ab&65535}else{b[X+(ac<<1)>>1]=(ab<<5&992)+aa&65535}ac=ac+1|0;}while((ac|0)<1008);ac=c[3530990]|0;X=c[3529910]|0;aa=0;do{ab=a[ac+aa|0]&15;_=a[ac+(aa+256)|0]&15;ad=a[ac+(aa+512)|0]&15;c[X+(aa<<2)>>2]=(ab<<4|ab)<<16|ad|ad<<4|(_<<4|_)<<8;aa=aa+1|0;}while((aa|0)<256);aa=c[3527460]|0;_=c[2406908]|0;ad=0;while(1){ab=ad>>>1&-(ad&1);a[aa+ad|0]=ab&255;c[_+(ad<<2)>>2]=c[X+((ab&255)<<2)>>2];ab=ad+1|0;if((ab|0)<512){ad=ab}else{af=0;break}}do{ad=a[ac+(af+768)|0]|0;ab=(ad&255)>>>4<<7|ad&15|(ad&255)>>>7<<4|(ad&255)>>>5<<6&64|(ad&255)>>>6<<5&32;ad=af+512|0;ae=aa+ad|0;a[ae]=ab;c[_+(ad<<2)>>2]=c[X+((ab&255)<<2)>>2];a[ae]=(a[ae]|0)!=-1|0;af=af+1|0;}while((af|0)<2048);a[9547136]=1;X=0;while(1){if((X|0)>=1024){break}ah=9638528+(X<<2)|0;if((c[ah>>2]|0)==0){Z=58570;break}else{X=X+1|0}}L76316:do{if((Z|0)==58570){X=gGq(32768)|0;c[ah>>2]=X;if((X|0)==0){break}gGz(X|0,0,32768);_=c[3530766]|0;gGC(X|0,_|0,8192)|0;aa=0;do{ac=aa<<6;gGz(_+ac|0,0,64);ae=0;do{ab=ac+(c[611712+(ae<<2)>>2]|0)|0;ad=(ae<<3)+ac|0;ai=0;do{aj=ab+(c[610352+(ai<<2)>>2]|0)|0;if((d[X+((aj|0)/8|0)|0]&128>>>((aj&7)>>>0)|0)!=0){aj=_+(ad+ai)|0;a[aj]=a[aj]|1}ai=ai+1|0;}while((ai|0)<8);ae=ae+1|0;}while((ae|0)<8);aa=aa+1|0;}while((aa|0)<512);aa=c[3530530]|0;gGC(X|0,aa|0,32768)|0;_=0;do{ae=_<<8;gGz(aa+ae|0,0,256);ac=_<<9;ai=0;do{ad=1<<3-ai;ab=(c[611216+(ai<<2)>>2]|0)+ac|0;aj=0;do{ak=ab+(c[611712+(aj<<2)>>2]|0)|0;al=(aj<<4)+ae|0;am=0;do{an=ak+(c[609488+(am<<2)>>2]|0)|0;if((d[X+((an|0)/8|0)|0]&128>>>((an&7)>>>0)|0)!=0){an=aa+(al+am)|0;a[an]=(d[an]|ad)&255}am=am+1|0;}while((am|0)<16);aj=aj+1|0;}while((aj|0)<16);ai=ai+1|0;}while((ai|0)<4);_=_+1|0;}while((_|0)<256);_=c[3530398]|0;gGC(X|0,_|0,32768)|0;aa=0;while(1){ai=aa<<6;gGz(_+ai|0,0,64);ae=aa<<7;ac=0;do{aj=1<<3-ac;ad=(c[611216+(ac<<2)>>2]|0)+ae|0;ab=0;do{am=ad+(c[611712+(ab<<2)>>2]|0)|0;al=(ab<<3)+ai|0;ak=0;do{an=am+(c[609488+(ak<<2)>>2]|0)|0;if((d[X+((an|0)/8|0)|0]&128>>>((an&7)>>>0)|0)!=0){an=_+(al+ak)|0;a[an]=(d[an]|aj)&255}ak=ak+1|0;}while((ak|0)<8);ab=ab+1|0;}while((ab|0)<8);ac=ac+1|0;}while((ac|0)<4);ac=aa+1|0;if((ac|0)<512){aa=ac}else{ao=0;break}}while(1){if((ao|0)>=1024){break L76316}ap=9638528+(ao<<2)|0;if((c[ap>>2]|0)==(X|0)){break}else{ao=ao+1|0}}gGr(X);c[ap>>2]=0}}while(0);fwR(0);aa=c[2439330]|0;_=(aa|0)==0;if(!_){ac=aa;gGC(9706056,ac|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];ac=c[3528484]|0;c[2076596]=ac;ai=c[2417276]|0;c[3541536]=ai;c[1836236]=0;ae=c[3529220]|0;ab=0;aj=0;while(1){c[aa+76+(aj<<2)>>2]=ae+(aj<<8);ad=ab+1&65535;if((ad&65535)>127){aq=0;ar=0;break}else{ab=ad;aj=ad&65535}}while(1){aj=ae+(ar<<8)|0;c[aa+76+(ar+512<<2)>>2]=aj;c[aa+76+(ar+768<<2)>>2]=aj;aj=aq+1&65535;if((aj&65535)>127){break}else{aq=aj;ar=aj&65535}}ae=c[2387844]|0;c[aa+588>>2]=ae;aj=ae+256|0;c[aa+592>>2]=aj;ab=ae+512|0;c[aa+596>>2]=ab;ad=ae+768|0;c[aa+600>>2]=ad;ak=ae+1024|0;c[aa+604>>2]=ak;al=ae+1280|0;c[aa+608>>2]=al;am=ae+1536|0;c[aa+612>>2]=am;an=ae+1792|0;c[aa+616>>2]=an;c[aa+1612>>2]=ae;c[aa+1616>>2]=aj;c[aa+1620>>2]=ab;c[aa+1624>>2]=ad;c[aa+1628>>2]=ak;c[aa+1632>>2]=al;c[aa+1636>>2]=am;c[aa+1640>>2]=an;c[aa+2636>>2]=ae;c[aa+3660>>2]=ae;c[aa+2640>>2]=aj;c[aa+3664>>2]=aj;c[aa+2644>>2]=ab;c[aa+3668>>2]=ab;c[aa+2648>>2]=ad;c[aa+3672>>2]=ad;c[aa+2652>>2]=ak;c[aa+3676>>2]=ak;c[aa+2656>>2]=al;c[aa+3680>>2]=al;c[aa+2660>>2]=am;c[aa+3684>>2]=am;c[aa+2664>>2]=an;c[aa+3688>>2]=an;an=c[3527292]|0;am=136;al=136;while(1){c[aa+76+(al<<2)>>2]=an+((al<<8)-34816);ak=am+1&65535;if((ak&65535)>159){as=136;at=136;break}else{am=ak;al=ak&65535}}while(1){c[aa+76+(at+256<<2)>>2]=an+((at<<8)-34816);al=as+1&65535;if((al&65535)>159){au=136;av=136;break}else{as=al;at=al&65535}}while(1){al=an+((av<<8)-34816)|0;c[aa+76+(av+512<<2)>>2]=al;c[aa+76+(av+768<<2)>>2]=al;al=au+1&65535;if((al&65535)>159){break}else{au=al;av=al&65535}}an=c[2387962]|0;c[aa+716>>2]=an;al=an+256|0;c[aa+720>>2]=al;am=an+512|0;c[aa+724>>2]=am;ak=an+768|0;c[aa+728>>2]=ak;ad=an+1024|0;c[aa+732>>2]=ad;ab=an+1280|0;c[aa+736>>2]=ab;aj=an+1536|0;c[aa+740>>2]=aj;ae=an+1792|0;c[aa+744>>2]=ae;c[aa+1740>>2]=an;c[aa+1744>>2]=al;c[aa+1748>>2]=am;c[aa+1752>>2]=ak;c[aa+1756>>2]=ad;c[aa+1760>>2]=ab;c[aa+1764>>2]=aj;c[aa+1768>>2]=ae;c[aa+2764>>2]=an;c[aa+3788>>2]=an;c[aa+2768>>2]=al;c[aa+3792>>2]=al;c[aa+2772>>2]=am;c[aa+3796>>2]=am;c[aa+2776>>2]=ak;c[aa+3800>>2]=ak;c[aa+2780>>2]=ad;c[aa+3804>>2]=ad;c[aa+2784>>2]=ab;c[aa+3808>>2]=ab;c[aa+2788>>2]=aj;c[aa+3812>>2]=aj;c[aa+2792>>2]=ae;c[aa+3816>>2]=ae;c[aa+4184>>2]=2032;c[aa+4180>>2]=1568;if(!_){ae=aa;gGC(ae|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=ac;c[2417276]=ai;c[1836236]=-1;fwR(1);ae=c[2439331]|0;aj=(ae|0)==0;if(!aj){ab=ae;gGC(9706056,ab|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];ab=c[3528485]|0;c[2076596]=ab;ad=c[2417277]|0;c[3541536]=ad;c[1836236]=1;ak=c[3529176]|0;am=0;al=0;while(1){c[ae+76+(al<<2)>>2]=ak+(al<<8);an=am+1&65535;if((an&65535)>127){aw=0;ax=0;break}else{am=an;al=an&65535}}while(1){al=ak+(ax<<8)|0;c[ae+76+(ax+512<<2)>>2]=al;c[ae+76+(ax+768<<2)>>2]=al;al=aw+1&65535;if((al&65535)>127){break}else{aw=al;ax=al&65535}}ak=c[2387844]|0;c[ae+588>>2]=ak;al=ak+256|0;c[ae+592>>2]=al;am=ak+512|0;c[ae+596>>2]=am;ai=ak+768|0;c[ae+600>>2]=ai;ac=ak+1024|0;c[ae+604>>2]=ac;aa=ak+1280|0;c[ae+608>>2]=aa;_=ak+1536|0;c[ae+612>>2]=_;an=ak+1792|0;c[ae+616>>2]=an;c[ae+1612>>2]=ak;c[ae+1616>>2]=al;c[ae+1620>>2]=am;c[ae+1624>>2]=ai;c[ae+1628>>2]=ac;c[ae+1632>>2]=aa;c[ae+1636>>2]=_;c[ae+1640>>2]=an;c[ae+2636>>2]=ak;c[ae+3660>>2]=ak;c[ae+2640>>2]=al;c[ae+3664>>2]=al;c[ae+2644>>2]=am;c[ae+3668>>2]=am;c[ae+2648>>2]=ai;c[ae+3672>>2]=ai;c[ae+2652>>2]=ac;c[ae+3676>>2]=ac;c[ae+2656>>2]=aa;c[ae+3680>>2]=aa;c[ae+2660>>2]=_;c[ae+3684>>2]=_;c[ae+2664>>2]=an;c[ae+3688>>2]=an;an=c[3527292]|0;_=136;aa=136;while(1){c[ae+76+(aa<<2)>>2]=an+((aa<<8)-34816);ac=_+1&65535;if((ac&65535)>159){ay=136;az=136;break}else{_=ac;aa=ac&65535}}while(1){c[ae+76+(az+256<<2)>>2]=an+((az<<8)-34816);aa=ay+1&65535;if((aa&65535)>159){aA=136;aB=136;break}else{ay=aa;az=aa&65535}}while(1){aa=an+((aB<<8)-34816)|0;c[ae+76+(aB+512<<2)>>2]=aa;c[ae+76+(aB+768<<2)>>2]=aa;aa=aA+1&65535;if((aa&65535)>159){break}else{aA=aa;aB=aa&65535}}an=c[2387962]|0;c[ae+716>>2]=an;aa=an+256|0;c[ae+720>>2]=aa;_=an+512|0;c[ae+724>>2]=_;ac=an+768|0;c[ae+728>>2]=ac;ai=an+1024|0;c[ae+732>>2]=ai;am=an+1280|0;c[ae+736>>2]=am;al=an+1536|0;c[ae+740>>2]=al;ak=an+1792|0;c[ae+744>>2]=ak;c[ae+1740>>2]=an;c[ae+1744>>2]=aa;c[ae+1748>>2]=_;c[ae+1752>>2]=ac;c[ae+1756>>2]=ai;c[ae+1760>>2]=am;c[ae+1764>>2]=al;c[ae+1768>>2]=ak;c[ae+2764>>2]=an;c[ae+3788>>2]=an;c[ae+2768>>2]=aa;c[ae+3792>>2]=aa;c[ae+2772>>2]=_;c[ae+3796>>2]=_;c[ae+2776>>2]=ac;c[ae+3800>>2]=ac;c[ae+2780>>2]=ai;c[ae+3804>>2]=ai;c[ae+2784>>2]=am;c[ae+3808>>2]=am;c[ae+2788>>2]=al;c[ae+3812>>2]=al;c[ae+2792>>2]=ak;c[ae+3816>>2]=ak;c[ae+4184>>2]=2032;c[ae+4180>>2]=1568;if(!aj){ak=ae;gGC(ak|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=ab;c[2417277]=ad;c[1836236]=-1;fwR(2);ak=c[2439332]|0;al=(ak|0)==0;if(!al){am=ak;gGC(9706056,am|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438120];am=c[3528486]|0;c[2076596]=am;ai=c[2417278]|0;c[3541536]=ai;c[1836236]=2;ac=c[3529164]|0;_=0;aa=0;while(1){c[ak+76+(aa<<2)>>2]=ac+(aa<<8);an=_+1&65535;if((an&65535)>31){aC=0;aD=0;break}else{_=an;aa=an&65535}}while(1){aa=ac+(aD<<8)|0;c[ak+76+(aD+512<<2)>>2]=aa;c[ak+76+(aD+768<<2)>>2]=aa;aa=aC+1&65535;if((aa&65535)>31){break}else{aC=aa;aD=aa&65535}}aa=c[3529264]|0;c[ak+204>>2]=aa;_=aa+256|0;c[ak+208>>2]=_;ad=aa+512|0;c[ak+212>>2]=ad;ab=aa+768|0;c[ak+216>>2]=ab;ae=aa+1024|0;c[ak+220>>2]=ae;aj=aa+1280|0;c[ak+224>>2]=aj;an=aa+1536|0;c[ak+228>>2]=an;aE=aa+1792|0;c[ak+232>>2]=aE;c[ak+1228>>2]=aa;c[ak+1232>>2]=_;c[ak+1236>>2]=ad;c[ak+1240>>2]=ab;c[ak+1244>>2]=ae;c[ak+1248>>2]=aj;c[ak+1252>>2]=an;c[ak+1256>>2]=aE;c[ak+2252>>2]=aa;c[ak+3276>>2]=aa;c[ak+2256>>2]=_;c[ak+3280>>2]=_;c[ak+2260>>2]=ad;c[ak+3284>>2]=ad;c[ak+2264>>2]=ab;c[ak+3288>>2]=ab;c[ak+2268>>2]=ae;c[ak+3292>>2]=ae;c[ak+2272>>2]=aj;c[ak+3296>>2]=aj;c[ak+2276>>2]=an;c[ak+3300>>2]=an;c[ak+2280>>2]=aE;c[ak+3304>>2]=aE;aE=224;an=224;while(1){c[ak+76+(an<<2)>>2]=ac+(an<<8);aj=aE+1&65535;if((aj&65535)>255){aF=224;aG=224;break}else{aE=aj;an=aj&65535}}while(1){an=ac+(aG<<8)|0;c[ak+76+(aG+512<<2)>>2]=an;c[ak+76+(aG+768<<2)>>2]=an;an=aF+1&65535;if((an&65535)>255){break}else{aF=an;aG=an&65535}}c[ak+4184>>2]=526;c[ak+4180>>2]=350;if(!al){ac=ak;gGC(ac|0,9706056,76)|0}c[2438120]=c[2433530];c[3528486]=am;c[2417278]=ai;c[1836236]=-1;ac=c[2387314]|0;an=c[2387326]|0;c[2424906]=2536;c[2443666]=2047;c[2385780]=7;c[3528996]=3;gGz(9702704,0,32);gGz(9703728,0,32);gGz(9704752,0,32);aE=c[2427044]|0;c[9681616+(aE<<3)>>2]=809328;c[9681620+(aE<<3)>>2]=0;c[2427044]=aE+1;aE=2;while(1){aj=an+((aE<<3)-16)|0;c[9702704+(aE<<2)>>2]=aj;c[9703728+(aE<<2)>>2]=aj;c[9704752+(aE<<2)>>2]=aj;aj=aE+1|0;if((aj|0)<16){aE=aj}else{aH=16;break}}do{aE=ac+(aH<<3)|0;c[9702704+(aH<<2)>>2]=aE;c[9704752+(aH<<2)>>2]=aE;aH=aH+1|0;}while((aH|0)<256);c[3528586]=3404;c[2385590]=1124;c[2406622]=c[(c[642608+(c[2436]<<2)>>2]|0)+52>>2]&32^32;TS(0,3072e3,32768,6,0,0);TS(1,3072e3,32768,6,0,1);ac=c[2420348]|0;h[ac+192>>3]=.8;c[ac+200>>2]=3;ac=c[2420346]|0;h[ac+192>>3]=.8;c[ac+200>>2]=3;ac=c[642608+(c[2436]<<2)>>2]|0;aE=c[ac+128>>2]|0;if((c[ac+52>>2]&4|0)==0){c[2113068]=aE;an=c[ac+132>>2]|0;c[2113070]=an;c[2443814]=aE;c[2440436]=an;aI=aE;aJ=an}else{c[2113070]=aE;an=c[ac+132>>2]|0;c[2113068]=an;c[2440436]=aE;c[2443814]=an;aI=an;aJ=aE}aE=ag(aI<<1,aJ)|0;an=gGq(aE)|0;c[2112926]=an;if((an|0)!=0){gGz(an|0,0,aE|0)}a[9623648]=0;aE=c[2414578]|0;gGz(aE|0,0,(c[2411522]|0)-aE|0);aE=c[2439330]|0;an=(aE|0)==0;if(!an){ac=aE;gGC(9706056,ac|0,76)|0}ac=c[2438118]|0;c[2433530]=ac;ai=c[3528484]|0;c[2076596]=ai;am=c[2417276]|0;c[3541536]=am;c[1836236]=0;gGz(9706056,0,76);if(!an){an=aE;gGC(an|0,9706056,76)|0}c[2438118]=ac;c[3528484]=ai;c[2417276]=am;c[1836236]=-1;am=c[2439331]|0;ai=(am|0)==0;if(!ai){ac=am;gGC(9706056,ac|0,76)|0}ac=c[2438119]|0;c[2433530]=ac;an=c[3528485]|0;c[2076596]=an;aE=c[2417277]|0;c[3541536]=aE;c[1836236]=1;gGz(9706056,0,76);if(!ai){ai=am;gGC(ai|0,9706056,76)|0}c[2438119]=ac;c[3528485]=an;c[2417277]=aE;c[1836236]=-1;aE=c[2439332]|0;an=(aE|0)==0;if(!an){ac=aE;gGC(9706056,ac|0,76)|0}ac=c[2438120]|0;c[2433530]=ac;ai=c[3528486]|0;c[2076596]=ai;am=c[2417278]|0;c[3541536]=am;c[1836236]=2;gGz(9706056,0,76);if(!an){an=aE;gGC(an|0,9706056,76)|0}c[2438120]=ac;c[3528486]=ai;c[2417278]=am;c[1836236]=-1;f42();a[8451544]=0;a[8451536]=0;a[9533800]=0;a[8451528]=0;a[8451520]=0;a[9533792]=0;a[8451512]=0;a[8451504]=0;a[9533784]=0;a[9533352]=0;a[9533344]=0;c[2161338]=0;c[2161344]=0;c[2432960]=0;c[2432961]=0;c[3525362]=1;c[3525363]=1;c[3525364]=1;c[2388356]=0;$=0;i=e;return $|0}}while(0);c[2414876]=0;$=1;i=e;return $|0}function fjZ(){var b=0,d=0,e=0,f=0;c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}fwZ();a[8451544]=0;a[8451536]=0;a[9533800]=0;a[8451528]=0;a[8451520]=0;a[9533792]=0;a[8451512]=0;a[8451504]=0;a[9533784]=0;a[9533352]=0;a[9533344]=0;c[2161338]=0;c[2161344]=0;c[2424906]=0;c[2443666]=0;c[2385780]=0;c[3528996]=0;TT();b=c[2414876]|0;d=0;while(1){if((d|0)>=1024){e=58716;break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==(b|0)){break}else{d=d+1|0}}if((e|0)==58716){c[2414876]=0;return 0}gGr(b);c[f>>2]=0;c[2414876]=0;return 0}function fj_(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=(c[2388356]|0)+1|0;c[2388356]=d;if((a[9623648]|0)!=0|(d|0)>59){a[9623648]=0;d=c[2414578]|0;gGz(d|0,0,(c[2411522]|0)-d|0);d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;h=c[2417276]|0;c[3541536]=h;c[1836236]=0;gGz(9706056,0,76);if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=h;c[1836236]=-1;h=c[2439331]|0;g=(h|0)==0;if(!g){f=h;gGC(9706056,f|0,76)|0}f=c[2438119]|0;c[2433530]=f;e=c[3528485]|0;c[2076596]=e;d=c[2417277]|0;c[3541536]=d;c[1836236]=1;gGz(9706056,0,76);if(!g){g=h;gGC(g|0,9706056,76)|0}c[2438119]=f;c[3528485]=e;c[2417277]=d;c[1836236]=-1;d=c[2439332]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438120]|0;c[2433530]=f;g=c[3528486]|0;c[2076596]=g;h=c[2417278]|0;c[3541536]=h;c[1836236]=2;gGz(9706056,0,76);if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438120]=f;c[3528486]=g;c[2417278]=h;c[1836236]=-1;f42();a[8451544]=0;a[8451536]=0;a[9533800]=0;a[8451528]=0;a[8451520]=0;a[9533792]=0;a[8451512]=0;a[8451504]=0;a[9533784]=0;a[9533352]=0;a[9533344]=0;c[2161338]=0;c[2161344]=0;c[2432960]=0;c[2432961]=0;c[3525362]=1;c[3525363]=1;c[3525364]=1;c[2388356]=0}h=c[2385548]|0;if((h|0)>0){gGz(9752472,0,((h|0)>1?h<<2:4)|0)}c[2433530]=0;a[9549904]=-1;a[9549752]=-1;a[9549688]=-49;h=0;g=-1;f=-1;e=-49;do{g=((a[9632680+h|0]&1)<<h^g&255)&255;f=((a[9630584+h|0]&1)<<h^f&255)&255;e=((a[9629256+h|0]&1)<<h^e&255)&255;h=h+1|0;}while((h|0)<8);a[9549904]=g;a[9549752]=f;a[9549688]=e;e=0;while(1){f=c[2439330]|0;if((f|0)!=0){g=f;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;g=c[2438118]|0;c[2433530]=g;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;if((a[f+4188|0]|0)==0){f=gfc(512)|0;i=(c[2433530]|0)+f|0}else{i=g+512|0}c[2433530]=i;g=(e|0)==99;if(g&(c[2432960]|0)!=0){a[9706117]=1}f=c[1836236]|0;h=c[9757320+(f<<2)>>2]|0;if((h|0)!=0){d=h;gGC(d|0,9706056,76)|0}c[9752472+(f<<2)>>2]=i;c[14113936+(f<<2)>>2]=c[2076596];c[9669104+(f<<2)>>2]=c[3541536];c[1836236]=-1;f=e+1|0;d=f<<9;if((c[3525362]|0)!=0){h=c[2439331]|0;if((h|0)!=0){j=h;gGC(9706056,j|0,76)|0}b[4853030]=c[2426515]&65535;j=c[2438119]|0;c[2433530]=j;k=c[3528485]|0;c[2076596]=k;c[3541536]=c[2417277];c[1836236]=1;l=d-j+k-(c[2426530]|0)|0;do{if((l|0)<1){m=j}else{if((a[h+4188|0]|0)==0){k=gfc(l)|0;n=(c[2433530]|0)+k|0;c[2433530]=n;m=n;break}else{n=l+j|0;c[2433530]=n;m=n;break}}}while(0);if(g&(c[2432961]|0)!=0){a[9706117]=1}j=c[1836236]|0;l=c[9757320+(j<<2)>>2]|0;if((l|0)!=0){h=l;gGC(h|0,9706056,76)|0}c[9752472+(j<<2)>>2]=m;c[14113936+(j<<2)>>2]=c[2076596];c[9669104+(j<<2)>>2]=c[3541536];c[1836236]=-1}if((c[3525363]|0)!=0){j=c[2439332]|0;if((j|0)!=0){h=j;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;h=c[2438120]|0;c[2433530]=h;l=c[3528486]|0;c[2076596]=l;c[3541536]=c[2417278];c[1836236]=2;n=d-h+l-(c[2426530]|0)|0;do{if((n|0)<1){o=h}else{if((a[j+4188|0]|0)==0){l=gfc(n)|0;k=(c[2433530]|0)+l|0;c[2433530]=k;o=k;break}else{k=n+h|0;c[2433530]=k;o=k;break}}}while(0);if((e|0)==99|(e|0)==49){if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;h=(c[2433530]|0)+12|0;c[2433530]=h;p=h}else{p=o}h=c[1836236]|0;n=c[9757320+(h<<2)>>2]|0;if((n|0)!=0){j=n;gGC(j|0,9706056,76)|0}c[9752472+(h<<2)>>2]=p;c[14113936+(h<<2)>>2]=c[2076596];c[9669104+(h<<2)>>2]=c[3541536];c[1836236]=-1}if((c[3525364]|0)!=0&(c[2406622]|0)!=0){f4Y(512)|0}if((f|0)<100){e=f}else{break}}e=c[2112964]|0;if((e|0)!=0){p=a[9688]|0?534:0;TQ(0,e,p);TQ(1,e,p)}if((c[2112968]|0)==0){return 0}fj$()|0;return 0}function fj$(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;if((a[9547136]|0)!=0){f=c[2406908]|0;g=c[3529910]|0;h=0;do{i=c[f+(h<<2)>>2]|0;c[g+(h<<2)>>2]=i>>>8<<3&2016|i>>>3&31|i>>16<<8&63488;h=h+1|0;}while((h|0)<2560);a[9547136]=0}h=c[3527250]|0;g=c[2387962]|0;f=c[2406752]|0;i=f+1|0;j=c[3528664]|0;k=c[2112926]|0;l=c[3530398]|0;m=0;do{n=((m|0)%36|0)<<3;o=((m|0)/36|0)<<3;p=e[h+(m<<1)>>1]|0;q=d[i]<<8|d[g+p|0];r=(a[g+(p+1024)|0]&63)+96|0;if((a[j]|0)==0){Sj(k,q,n,o,r,4,0,l)}else{Sp(k,q,280-n|0,216-o|0,r,4,0,l)}m=m+1|0;}while((m|0)<1008);m=c[3527292]|0;l=c[3530530]|0;g=c[2113070]|0;i=c[2113068]|0;r=c[3527460]|0;o=0;do{n=d[m+(o+6016)|0]|0;q=o|1;p=((d[m+(q+6016)|0]|0)>>>7|d[m+(q+3968)|0]<<1)-39|0;s=n&1;t=n>>>1&1;u=n>>>2&1;v=n>>>3;w=v&1;x=((v|254)^1)&d[m+(o+1920)|0]&(u<<1^16777215);if((a[j]|0)==0){y=t;z=s}else{y=t^1;z=s^1}s=(257-(u<<4)-(d[m+(o+3968)|0]<<1|n>>>7)&255)-32|0;n=z&-w;t=y&-u;v=(d[m+(q+1920)|0]<<4&1008)+512|0;q=(z|0)==0?0:15;A=(y|0)==0?q:q|240;q=0;do{B=q^t;C=s+(q<<4)|0;D=0;do{E=p+(D<<4)|0;F=(c[607912+(B<<3)+((D^n)<<2)>>2]|0)+x<<8;G=C;H=0;while(1){L76579:do{if((G|0)>-1&(G|0)<(g|0)){I=ag(i,G)|0;J=H<<4;K=0;L=E;while(1){do{if((L|0)>-1&(L|0)<(i|0)){M=d[l+(((K|J)^A)+F)|0]|v;if((a[r+M|0]|0)==0){break}b[k+(L+I<<1)>>1]=M&65535}}while(0);M=K+1|0;if((M|0)>=16){break L76579}K=M;L=L+1|0}}}while(0);L=H+1|0;if((L|0)>=16){break}G=G+1|0;H=L}D=D+1|0;}while((D|0)<=(w|0));q=q+1|0;}while((q|0)<=(u|0));o=o+2|0;}while((o|0)<128);o=a[j]|0;l=o<<24>>24!=0?63:0;g=c[2387844]|0;y=c[3530766]|0;z=0;m=o;while(1){o=((z|0)%36|0)<<3;u=((z|0)/36|0)<<3;if(m<<24>>24==0){N=o;O=u}else{N=280-o|0;O=216-u|0}u=e[h+(z<<1)>>1]|0;o=d[g+(u+1024)|0]<<1;q=(d[f]<<8|d[g+u|0])<<6;u=k+((ag(i,O)|0)+N<<1)|0;w=0;while(1){v=w<<3;A=0;do{x=d[y+(((A|v)^l)+q)|0]|o;if((a[r+x|0]|0)!=0){b[u+(A<<1)>>1]=x&65535}A=A+1|0;}while((A|0)<8);A=w+1|0;if((A|0)<8){u=u+(i<<1)|0;w=A}else{break}}w=z+1|0;if((w|0)>=1008){break}z=w;m=a[j]|0}R8(c[3529910]|0);return 0}function fj0(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=i;i=i+160|0;e=d|0;f=d+16|0;g=d+32|0;h=d+48|0;j=d+64|0;k=d+80|0;l=d+96|0;m=d+112|0;n=d+128|0;o=d+144|0;if((b|0)!=0){c[b>>2]=169735}if((a&96|0)==0){i=d;return 0}gGz(o|0,0,12);p=c[2414578]|0;c[o>>2]=p;c[o+4>>2]=(c[2411522]|0)-p;c[o+12>>2]=162152;gj[c[2076592]&4095](o)|0;fw$(a);TU(a,b);gGz(n|0,0,12);c[n>>2]=9731840;c[n+4>>2]=4;c[n+12>>2]=562584;gj[c[2076592]&4095](n)|0;gGz(m|0,0,12);c[m>>2]=9731844;c[m+4>>2]=4;c[m+12>>2]=546496;gj[c[2076592]&4095](m)|0;gGz(l|0,0,12);c[l>>2]=14101448;c[l+4>>2]=4;c[l+12>>2]=532592;gj[c[2076592]&4095](l)|0;gGz(k|0,0,12);c[k>>2]=14101452;c[k+4>>2]=4;c[k+12>>2]=519256;gj[c[2076592]&4095](k)|0;gGz(j|0,0,12);c[j>>2]=14101456;c[j+4>>2]=4;c[j+12>>2]=505688;gj[c[2076592]&4095](j)|0;gGz(h|0,0,12);c[h>>2]=9533352;c[h+4>>2]=1;c[h+12>>2]=493800;gj[c[2076592]&4095](h)|0;gGz(g|0,0,12);c[g>>2]=9533344;c[g+4>>2]=1;c[g+12>>2]=481680;gj[c[2076592]&4095](g)|0;gGz(f|0,0,12);c[f>>2]=8645352;c[f+4>>2]=4;c[f+12>>2]=469144;gj[c[2076592]&4095](f)|0;gGz(e|0,0,12);c[e>>2]=8645376;c[e+4>>2]=4;c[e+12>>2]=457792;gj[c[2076592]&4095](e)|0;i=d;return 0}function fj1(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2388468+(b*112|0)>>2];c[a+104>>2]=c[2388472+(b*112|0)>>2];c[a+108>>2]=c[2388476+(b*112|0)>>2];d=0;return d|0}function fj2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=2388368+(b*112|0);e=0;return e|0}function fj3(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2386676+(b*112|0)>>2];c[a+104>>2]=c[2386680+(b*112|0)>>2];c[a+108>>2]=c[2386684+(b*112|0)>>2];d=0;return d|0}function fj4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=2386576+(b*112|0);e=0;return e|0}function fj5(a){a=a|0;var b=0;if((a<<16>>16|0)==(-8188|0)){b=c[2113156]&255}else if((a<<16>>16|0)==(-8191|0)){b=c[(c[3531464]|0)+4240>>2]&255}else{b=0}return b|0}function fj6(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((e|0)==57344){c[2113304]=d&255;return}else if((e|0)==57348){Uv(0,d);return}else if((e|0)==57345){e=c[2113304]|0;a[14168504+e|0]=d;mv(0,e,d&255);return}else{return}}function fj7(b){b=b|0;var d=0,e=0;do{if((b|0)==2211873){d=a[9625528]|0}else if((b|0)==3145741){e=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;if((e|0)>=(c[2113018]|0)){d=1;break}d=e>>>31&255}else if((b|0)==2211881){d=a[9625530]|0}else if((b|0)==2211889){d=a[9625532]|0}else if((b|0)==2211885){d=a[9625531]|0}else if((b|0)==2211877){d=a[9625529]|0}else if((b|0)==2211893){d=a[9625533]|0}else{if((b&16760832|0)!=2195456){d=0;break}d=a[(c[3532636]|0)+(b>>>1&8191)|0]|0}}while(0);return d|0}function fj8(a){a=a|0;var e=0,f=0,g=0;if((a|0)==2211900){e=((c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0)/(c[2113058]|0)|0;if((e|0)==(c[2384356]|0)){f=65024}else{c[2384356]=e;f=32256}g=(f|e)&65535;return g|0}else if((a|0)==2211872){g=d[9625528]|0;return g|0}else if((a|0)==3145732){g=b[c[3541508]>>1]|0;return g|0}else if((a|0)==3145734){g=b[(c[3541508]|0)+2>>1]|0;return g|0}else if((a|0)==3145740){e=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;if((e|0)>=(c[2113018]|0)){g=1;return g|0}g=e>>>31&65535;return g|0}else if((a|0)==2211888){g=d[9625532]|0;return g|0}else if((a|0)==2211880){g=d[9625530]|0;return g|0}else if((a|0)==2211884){g=d[9625531]|0;return g|0}else if((a|0)==2211892){g=d[9625533]|0;return g|0}else if((a|0)==2211876){g=d[9625529]|0;return g|0}else{if((a&16760832|0)!=2195456){g=0;return g|0}g=d[(c[3532636]|0)+(a>>>1&8191)|0]|0;return g|0}return 0}function fj9(b,d){b=b|0;d=d|0;if((b&16760832|0)!=2195456){return}a[(c[3532636]|0)+(b>>>1&8191)|0]=d;return}function fka(d,e){d=d|0;e=e|0;switch(d|0){case 3145734:{b[c[3541508]>>1]=e;c[3541508]=(c[3541508]|0)+2;return};case 3145736:{c[3541498]=e&255;return};case 3145728:{c[3541508]=(c[3541506]|0)+((e&65535)<<1&16382);return};case 3145732:{b[c[3541508]>>1]=e;c[3541508]=(c[3541508]|0)+2;return};case 3145740:{b[(c[3541500]|0)+(c[3541498]<<1)>>1]=e;return};default:{if((d&16760832|0)!=2195456){return}a[(c[3532636]|0)+(d>>>1&8191)|0]=e&255;return}}}function fkb(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>5){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2625676+(b*112|0)>>2];c[a+104>>2]=c[2625680+(b*112|0)>>2];c[a+108>>2]=c[2625684+(b*112|0)>>2];d=0;return d|0}function fkc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<6&(d|0)==0)){e=1;return e|0}c[a>>2]=2625576+(b*112|0);e=0;return e|0}function fkd(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1086688+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function fke(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=44){if((a|0)==0){d=0;return d|0}e=a;f=2288248+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}f=b-45|0;if(f>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;a=692376+(f*12|0)|0;c[b>>2]=c[a>>2];c[b+4>>2]=c[a+4>>2];c[b+8>>2]=c[a+8>>2];d=0;return d|0}function fkf(){var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;d=i;i=i+480|0;e=d|0;f=d+112|0;g=d+120|0;j=d+232|0;k=d+240|0;l=d+352|0;m=d+360|0;n=d+472|0;c[2113208]=2097152;c[2426668]=0;c[2418134]=0;c[3532626]=524288;c[3541502]=589824;c[3541532]=2686976;c[3541206]=2719744;c[2405606]=2981888;c[2418248]=2981888;c[2418202]=3047424;c[3541534]=3049472;c[3541530]=3057664;c[3541528]=3061760;c[2411416]=3065856;c[3532636]=3069952;c[3541506]=3086336;c[3541500]=3102720;c[2411520]=3103232;c[3531916]=3103232;o=0;while(1){if((o|0)>=1024){break}p=9638528+(o<<2)|0;if((c[p>>2]|0)==0){q=58962;break}else{o=o+1|0}}do{if((q|0)==58962){o=gGq(3111424)|0;c[p>>2]=o;if((o|0)==0){break}c[2426668]=o;gGz(o|0,0,3111424);c[2418134]=o;c[3532626]=o+524288;c[3541502]=o+589824;r=c[2113208]|0;c[3541532]=o+(r+589824);c[3541206]=o+(r+622592);s=o+(r+884736)|0;c[2405606]=s;c[2418248]=s;c[2418202]=o+(r+950272);c[3541534]=o+(r+952320);c[3541530]=o+(r+960512);c[3541528]=o+(r+964608);c[2411416]=o+(r+968704);c[3532636]=o+(r+972800);c[3541506]=o+(r+989184);c[3541500]=o+(r+1005568);s=o+(r+1006080)|0;c[2411520]=s;c[3531916]=s;c[2414060]=o+(r+1014272);do{if((c[3542200]|0)!=0){r=m+108|0;c[r>>2]=0;s=m+100|0;c[s>>2]=0;t=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[t&16383](m,0)|0;if((c[r>>2]|0)==0){break}r=c[s>>2]|0;c[n>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](n,0,0)|0;if((r|0)<1){break}gzL(o,0,0)|0}}while(0);fpl(c[3541502]|0,1,2,c[2113208]|0,0);o=c[3541532]|0;do{if((c[3542200]|0)!=0){r=k+108|0;c[r>>2]=0;s=k+100|0;c[s>>2]=0;t=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[t&16383](k,3)|0;if((c[r>>2]|0)==0){break}r=c[s>>2]|0;c[l>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](l,3,0)|0;if((r|0)<1){break}gzL(o,0,3)|0}}while(0);o=c[3532626]|0;do{if((c[3542200]|0)!=0){r=g+108|0;c[r>>2]=0;s=g+100|0;c[s>>2]=0;t=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[t&16383](g,4)|0;if((c[r>>2]|0)==0){break}r=c[s>>2]|0;c[j>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](j,4,0)|0;if((r|0)<1){break}gzL(o,0,4)|0}}while(0);o=c[3541206]|0;do{if((c[3542200]|0)!=0){r=e+108|0;c[r>>2]=0;s=e+100|0;c[s>>2]=0;t=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[t&16383](e,5)|0;if((c[r>>2]|0)==0){break}r=c[s>>2]|0;c[f>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](f,5,0)|0;if((r|0)<1){break}gzL(o,0,5)|0}}while(0);fxU(0,425984);if((c[2394]|0)==0){u=c[2112932]|0}else{c[2394]=0;o=c[3532596]|0;c[2112932]=o;r=c[3532592]|0;if((r|0)!=0){gGC(9104152,r|0,280)|0}c[2113054]=c[2113060];u=o}o=c[2418134]|0;r=u|0;s=0;while(1){t=o+s|0;c[r>>2]=t;c[r+131072>>2]=t;t=s+1024|0;if(t>>>0>524287){break}else{r=r+4|0;s=t}}s=c[2418248]|0;r=u+4096|0;o=1048576;while(1){t=s+(o-1048576)|0;c[r>>2]=t;c[r+65536>>2]=t;c[r+131072>>2]=t;t=o+1024|0;if(t>>>0>1114111){break}else{r=r+4|0;o=t}}o=c[2411416]|0;c[u+16384>>2]=o;c[u+81920>>2]=o;c[u+147456>>2]=o;r=o+1024|0;c[u+16388>>2]=r;c[u+81924>>2]=r;c[u+147460>>2]=r;r=o+2048|0;c[u+16392>>2]=r;c[u+81928>>2]=r;c[u+147464>>2]=r;r=o+3072|0;c[u+16396>>2]=r;c[u+81932>>2]=r;c[u+147468>>2]=r;r=c[2418202]|0;c[u+16400>>2]=r;c[u+81936>>2]=r;c[u+147472>>2]=r;o=r+1024|0;c[u+16404>>2]=o;c[u+81940>>2]=o;c[u+147476>>2]=o;o=c[3541534]|0;c[u+20480>>2]=o;c[u+86016>>2]=o;c[u+151552>>2]=o;r=o+1024|0;c[u+20484>>2]=r;c[u+86020>>2]=r;c[u+151556>>2]=r;r=o+2048|0;c[u+20488>>2]=r;c[u+86024>>2]=r;c[u+151560>>2]=r;r=o+3072|0;c[u+20492>>2]=r;c[u+86028>>2]=r;c[u+151564>>2]=r;r=o+4096|0;c[u+20496>>2]=r;c[u+86032>>2]=r;c[u+151568>>2]=r;r=o+5120|0;c[u+20500>>2]=r;c[u+86036>>2]=r;c[u+151572>>2]=r;r=o+6144|0;c[u+20504>>2]=r;c[u+86040>>2]=r;c[u+151576>>2]=r;r=o+7168|0;c[u+20508>>2]=r;c[u+86044>>2]=r;c[u+151580>>2]=r;r=c[3541528]|0;c[u+20512>>2]=r;c[u+86048>>2]=r;c[u+151584>>2]=r;o=r+1024|0;c[u+20516>>2]=o;c[u+86052>>2]=o;c[u+151588>>2]=o;o=r+2048|0;c[u+20520>>2]=o;c[u+86056>>2]=o;c[u+151592>>2]=o;o=r+3072|0;c[u+20524>>2]=o;c[u+86060>>2]=o;c[u+151596>>2]=o;o=c[3541530]|0;c[u+20528>>2]=o;c[u+86064>>2]=o;c[u+151600>>2]=o;r=o+1024|0;c[u+20532>>2]=r;c[u+86068>>2]=r;c[u+151604>>2]=r;r=o+2048|0;c[u+20536>>2]=r;c[u+86072>>2]=r;c[u+151608>>2]=r;r=o+3072|0;c[u+20540>>2]=r;c[u+86076>>2]=r;c[u+151612>>2]=r;c[u+196688>>2]=2220;c[u+196608>>2]=2780;c[u+196728>>2]=2050;c[u+196648>>2]=596;r=c[3532592]|0;if((r|0)!=0){gGC(r|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;a[9560]=1;fl6(1);if((c[2408]|0)==39321){c[2408]=43}fwR(0);r=c[2439330]|0;o=(r|0)==0;if(!o){s=r;gGC(9706056,s|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];s=c[3528484]|0;c[2076596]=s;t=c[2417276]|0;c[3541536]=t;c[1836236]=0;c[r+4180>>2]=1572;c[r+4184>>2]=2296;v=c[3532626]|0;w=0;x=0;while(1){c[r+76+(x<<2)>>2]=v+(x<<8);y=w+1&65535;if((y&65535)>191){z=0;A=0;break}else{w=y;x=y&65535}}while(1){x=v+(A<<8)|0;c[r+76+(A+512<<2)>>2]=x;c[r+76+(A+768<<2)>>2]=x;x=z+1&65535;if((x&65535)>191){break}else{z=x;A=x&65535}}v=c[3532636]|0;x=192;w=192;while(1){c[r+76+(w<<2)>>2]=v+((w<<8)-49152);y=x+1&65535;if((y&65535)>223){B=192;C=192;break}else{x=y;w=y&65535}}while(1){c[r+76+(C+256<<2)>>2]=v+((C<<8)-49152);w=B+1&65535;if((w&65535)>223){D=192;E=192;break}else{B=w;C=w&65535}}while(1){w=v+((E<<8)-49152)|0;c[r+76+(E+512<<2)>>2]=w;c[r+76+(E+768<<2)>>2]=w;w=D+1&65535;if((w&65535)>223){break}else{D=w;E=w&65535}}c[r+972>>2]=0;c[r+1996>>2]=0;if(!o){v=r;gGC(v|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=s;c[2417276]=t;c[1836236]=-1;c[2113016]=2048;c[3531920]=c[2411416];v=a[9680]|0;w=v?32e3:0;if(v){if(a[9624]|0){v=w*3|0;x=52734;while(1){if((x|0)>(v|0)){x=x>>1}else{F=1222;G=x;break}}}else{F=2462;G=w}c[2429380]=G;c[3542124]=F;mw(3375e3,G);x=gGq(262144)|0;c[2406684]=x;gGz(x|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(3375e3,11025)}h[745421]=1.0;c[2436794]=3;h[745420]=1.0;c[2436792]=3;Ux(0,7575,1);c[2407030]=256;c[2407068]=3;a[7072712]=1;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];x=c[3532592]|0;if((x|0)!=0){gGC(9104152,x|0,280)|0}c[2113054]=c[2113060]}RI();x=c[2394]|0;v=c[14130368+(x<<2)>>2]|0;if((v|0)!=0){gGC(v|0,9104152,280)|0}c[8452240+(x<<2)>>2]=c[2113054];c[2394]=-1;x=c[2439330]|0;v=(x|0)==0;if(!v){t=x;gGC(9706056,t|0,76)|0}t=c[2438118]|0;c[2433530]=t;s=c[3528484]|0;c[2076596]=s;r=c[2417276]|0;c[3541536]=r;c[1836236]=0;gGz(9706056,0,76);if(!v){v=x;gGC(v|0,9706056,76)|0}c[2438118]=t;c[3528484]=s;c[2417276]=r;c[1836236]=-1;c[2113156]=0;a[9628264]=0;c[2407033]=0;r=c[3541206]|0;c[3541190]=r;c[3541198]=r;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=r+256;c[3541199]=r+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=r+512;c[3541200]=r+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=r+768;c[3541201]=r+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;mx(0);H=0;i=d;return H|0}}while(0);c[2426668]=0;H=1;i=d;return H|0}function fkg(){var a=0,b=0,d=0,e=0,f=0;Uw(0);a=c[3531464]|0;c[a+44344>>2]=0;c[a+44348>>2]=0;if((a|0)!=0){gGr(a);c[3531464]=0}a=c[2406684]|0;if((a|0)!=0){gGr(a);c[2406684]=0}fl7();c[2408]=39321;fwZ();if((c[2392]|0)>=0){a=0;do{b=14130368+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}b=14130384+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}a=a+1|0;}while((a|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;a=c[2426668]|0;b=0;while(1){if((b|0)>=1024){e=59039;break}f=9638528+(b<<2)|0;if((c[f>>2]|0)==(a|0)){break}else{b=b+1|0}}if((e|0)==59039){c[2426668]=0;return 0}gGr(a);c[f>>2]=0;c[2426668]=0;return 0}function fkh(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((a[9623640]|0)!=0){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;h=c[2417276]|0;c[3541536]=h;c[1836236]=0;gGz(9706056,0,76);if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=h;c[1836236]=-1;c[2113156]=0;a[9628264]=0;c[2407033]=0;h=c[3541206]|0;c[3541190]=h;c[3541198]=h;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=h+256;c[3541199]=h+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=h+512;c[3541200]=h+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=h+768;c[3541201]=h+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;mx(0)}a[9625528]=0;a[9625529]=0;a[9625530]=0;h=0;g=0;f=0;e=0;do{g=((a[9632672+h|0]&1)<<h|g&255)&255;f=((a[9630576+h|0]&1)<<h|f&255)&255;e=((a[9551752+h|0]&1)<<h|e&255)&255;h=h+1|0;}while((h|0)<8);a[9625528]=g;a[9625529]=f;a[9625530]=e;if((g&3)==3){e=g&-4;a[9625528]=e;i=e}else{i=g}if((i&12)==12){a[9625528]=i&-13}if((f&3)==3){i=f&-4;a[9625529]=i;j=i}else{j=f}if((j&12)==12){a[9625529]=j&-13}j=c[2392]|0;if((j|0)>=0){gGz(8452240,0,((j|0)>0?(j<<2)+4|0:4)|0)}c[2113054]=0;j=c[2438]|0;f=gGU(j,(j|0)<0|0?-1:0,16e6,0)|0;j=gGS(f,K,15360,0)|0;f=j;c[2113218]=f;c[2113216]=66666;c[2113221]=0;c[2113220]=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];j=c[3532592]|0;if((j|0)!=0){gGC(9104152,j|0,280)|0}c[2113054]=c[2113060]}c[2113058]=(f|0)/262|0;c[2113018]=f-((f*22|0|0)/262|0);f=c[2439330]|0;if((f|0)!=0){j=f;gGC(9706056,j|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;j=0;f=0;L76923:while(1){i=f;do{if((i|0)>=4){break L76923}i=i+1|0;g=(ag(c[2113218]|0,i)|0)/4|0;e=c[2113018]|0;do{if((g|0)>(e|0)){h=c[2113220]|0;if((h|0)<(e|0)){d=e-h|0;c[2113056]=d;h=RG(d)|0;c[2113054]=(c[2113054]|0)+h;c[2276108]=-1;c[2113056]=-1;c[2113220]=(c[2113220]|0)+h}h=c[2430398]|0;d=c[2439196]|0;k=d<<11;c[2438976]=h+k;l=(c[2440572]|0)>1;if(l){c[2438977]=(c[2430399]|0)+k}k=d^1;c[2439196]=k;d=k<<11;k=h+d|0;h=(c[3541506]|0)+12288|0;gGC(k|0,h|0,2048)|0;if(l){l=(c[2430399]|0)+d|0;d=(c[3541504]|0)+12288|0;gGC(l|0,d|0,2048)|0}c[8452200+(c[2394]<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0>=1024){break}RH(4)}}while(0);e=g-(c[2113220]|0)|0;c[2113056]=e;d=RG(e)|0;c[2113054]=(c[2113054]|0)+d;c[2276108]=-1;c[2113056]=-1;c[2113220]=(c[2113220]|0)+d;d=(ag(c[2113216]|0,i)|0)/4|0;e=c[2113221]|0;l=d-e|0;do{if((l|0)<1){m=0;n=e}else{if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){d=gfc(l)|0;c[2433530]=(c[2433530]|0)+d;m=d;n=c[2113221]|0;break}else{c[2433530]=(c[2433530]|0)+l;m=l;n=e;break}}}while(0);c[2113221]=n+m;o=c[2112964]|0;}while((o|0)==0);e=a[9688]|0?133:0;l=o+(j<<1<<1)|0;gg[c[3542124]&4095](l,e);Uu(0,l,e);j=e+j|0;f=i}f=c[2112964]|0;do{if((f|0)!=0){o=a[9688]|0?534:0;m=o-j|0;n=f+(j<<1<<1)|0;if((o|0)==(j|0)){break}gg[c[3542124]&4095](n,m);Uu(0,n,m)}}while(0);j=c[2394]|0;f=c[14130368+(j<<2)>>2]|0;if((f|0)!=0){gGC(f|0,9104152,280)|0}c[8452240+(j<<2)>>2]=c[2113054];c[2394]=-1;j=c[1836236]|0;f=c[9757320+(j<<2)>>2]|0;if((f|0)!=0){m=f;gGC(m|0,9706056,76)|0}c[9752472+(j<<2)>>2]=c[2433530];c[14113936+(j<<2)>>2]=c[2076596];c[9669104+(j<<2)>>2]=c[3541536];c[1836236]=-1;j=c[2112968]|0;if((j|0)==0){return 0}m=c[3531916]|0;f=c[m>>2]|0;n=c[2113308]|0;do{if((f|0)==0){gGz(j|0,0,n*76800|0|0)}else{if((n|0)==4){o=0;e=j;while(1){c[e>>2]=f;c[e+4>>2]=f;c[e+8>>2]=f;c[e+12>>2]=f;c[e+16>>2]=f;c[e+20>>2]=f;c[e+24>>2]=f;c[e+28>>2]=f;l=o+1|0;if((l|0)<9600){o=l;e=e+32|0}else{break}}}else if((n|0)==3){e=f>>>8&255;o=f>>>16&255;i=f&255;l=j;g=0;while(1){a[l]=i;a[l+1|0]=e;a[l+2|0]=o;d=g+1|0;if((d|0)<76800){l=l+3|0;g=d}else{break}}}else if((n|0)==2){g=f<<16|f;l=j;o=0;while(1){c[l>>2]=g;c[l+4>>2]=g;c[l+8>>2]=g;c[l+12>>2]=g;c[l+16>>2]=g;c[l+20>>2]=g;c[l+24>>2]=g;c[l+28>>2]=g;e=o+1|0;if((e|0)<4800){l=l+32|0;o=e}else{break}}}else{break}}}while(0);if(a[7072712]|0){c[2112970]=j;c[2113306]=n;c[2113298]=c[2113300];fl3();fnZ();p=c[3531916]|0}else{p=m}c[2112966]=p;m=c[2113016]|0;if((m|0)>0){q=0}else{return 0}do{c[p+(q<<2)>>2]=65535;q=q+1|0;}while((q|0)<(m|0));return 0}function fki(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[3531916]|0;d=c[b>>2]|0;do{if((d|0)==0){e=c[2113308]|0;gGz(c[2112968]|0,0,e*76800|0|0);f=e}else{e=c[2113308]|0;if((e|0)==3){g=d>>>8&255;h=d>>>16&255;i=d&255;j=c[2112968]|0;k=0;while(1){a[j]=i;a[j+1|0]=g;a[j+2|0]=h;l=k+1|0;if((l|0)<76800){j=j+3|0;k=l}else{f=3;break}}}else if((e|0)==2){k=d<<16|d;j=c[2112968]|0;h=0;while(1){c[j>>2]=k;c[j+4>>2]=k;c[j+8>>2]=k;c[j+12>>2]=k;c[j+16>>2]=k;c[j+20>>2]=k;c[j+24>>2]=k;c[j+28>>2]=k;g=h+1|0;if((g|0)<4800){j=j+32|0;h=g}else{f=2;break}}}else if((e|0)==4){h=0;j=c[2112968]|0;while(1){c[j>>2]=d;c[j+4>>2]=d;c[j+8>>2]=d;c[j+12>>2]=d;c[j+16>>2]=d;c[j+20>>2]=d;c[j+24>>2]=d;c[j+28>>2]=d;k=h+1|0;if((k|0)<9600){h=k;j=j+32|0}else{f=4;break}}}else{f=e;break}}}while(0);if(a[7072712]|0){c[2112970]=c[2112968];c[2113306]=f;c[2113298]=c[2113300];fl3();fnZ();m=c[3531916]|0}else{m=b}c[2112966]=m;b=c[2113016]|0;if((b|0)>0){n=0}else{return 0}do{c[m+(n<<2)>>2]=65535;n=n+1|0;}while((n|0)<(b|0));return 0}function fkj(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;f=i;i=i+176|0;g=f|0;h=f+16|0;j=f+32|0;k=f+48|0;l=f+64|0;m=f+80|0;n=f+96|0;o=f+112|0;p=f+128|0;q=f+144|0;r=f+160|0;s=(e|0)==0;if(!s){c[e>>2]=169111}if((b&96|0)==0){i=f;return 0}gGz(r|0,0,12);t=c[2405606]|0;c[r>>2]=t;c[r+4>>2]=(c[2411520]|0)-t;c[r+12>>2]=162152;gj[c[2076592]&4095](r)|0;r=p|0;do{if((b&64|0)==0){fw$(b);Ut(0)}else{gGz(o|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){t=p+9|0;u=n;v=n|0;w=n+4|0;x=n+12|0;y=o|0;z=o+4|0;A=o+12|0;B=0;do{gGC(r|0,614896,11)|0;a[t]=B+48&255;C=8452256+(B<<2)|0;gGz(u|0,0,12);c[v>>2]=C;c[w>>2]=4;c[x>>2]=164976;gj[c[2076592]&4095](n)|0;if((c[C>>2]|0)!=0){c[y>>2]=c[14130368+(B<<2)>>2];c[z>>2]=c[8452184+(B<<2)>>2];c[A>>2]=r;C=c[2076592]|0;gj[C&4095](o)|0}B=B+1|0;}while((B|0)<=(c[2392]|0))}fw$(b);Ut(0);gGz(m|0,0,12);c[m>>2]=8453216;c[m+4>>2]=4;c[m+12>>2]=107480;B=c[2076592]|0;gj[B&4095](m)|0;gGz(l|0,0,12);c[l>>2]=14168504;c[l+4>>2]=256;c[l+12>>2]=476464;B=c[2076592]|0;gj[B&4095](l)|0;if((b&2|0)==0){break}else{D=0}do{mv(0,D,d[14168504+D|0]|0);D=D+1|0;}while((D|0)<256)}}while(0);if(!s){c[e>>2]=169110}gGz(k|0,0,12);c[k>>2]=9756784;c[k+4>>2]=4;c[k+12>>2]=175504;gj[c[2076592]&4095](k)|0;gGz(j|0,0,12);c[j>>2]=14166032;c[j+4>>2]=8;c[j+12>>2]=504552;gj[c[2076592]&4095](j)|0;gGz(h|0,0,12);c[h>>2]=14165992;c[h+4>>2]=8;c[h+12>>2]=388736;gj[c[2076592]&4095](h)|0;gGz(g|0,0,12);c[g>>2]=14165960;c[g+4>>2]=32;c[g+12>>2]=302352;gj[c[2076592]&4095](g)|0;gGz(q|0,0,12);c[q>>2]=9625528;c[q+4>>2]=6;c[q+12>>2]=215728;gj[c[2076592]&4095](q)|0;i=f;return 0}function fkk(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>5){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2209172+(b*112|0)>>2];c[a+104>>2]=c[2209176+(b*112|0)>>2];c[a+108>>2]=c[2209180+(b*112|0)>>2];d=0;return d|0}function fkl(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<6&(d|0)==0)){e=1;return e|0}c[a>>2]=2209072+(b*112|0);e=0;return e|0}function fkm(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=44){if((a|0)==0){d=0;return d|0}e=a;f=2288248+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}f=b-45|0;if(f>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;a=698200+(f*12|0)|0;c[b>>2]=c[a>>2];c[b+4>>2]=c[a+4>>2];c[b+8>>2]=c[a+8>>2];d=0;return d|0}function fkn(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>5){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2208500+(b*112|0)>>2];c[a+104>>2]=c[2208504+(b*112|0)>>2];c[a+108>>2]=c[2208508+(b*112|0)>>2];d=0;return d|0}function fko(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<6&(d|0)==0)){e=1;return e|0}c[a>>2]=2208400+(b*112|0);e=0;return e|0}function fkp(a){a=a|0;var b=0;if((a<<16>>16|0)==(-8191|0)){b=c[(c[3531464]|0)+4240>>2]&255}else if((a<<16>>16|0)==(-8188|0)){b=c[2113156]&255}else{b=0}return b|0}function fkq(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((e|0)==57345){b=c[2113304]|0;a[14168504+b|0]=d;mv(0,b,d&255);return}else if((e|0)==57348){Uv(0,d);return}else if((e|0)==57344){c[2113304]=d&255;return}else{return}}function fkr(b){b=b|0;var d=0,e=0;do{if((b|0)==2211885){d=a[9625523]|0}else if((b|0)==2211893){d=a[9625525]|0}else if((b|0)==2211889){d=a[9625524]|0}else if((b|0)==3145741){e=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;if((e|0)>=(c[2113018]|0)){d=1;break}d=e>>>31&255}else if((b|0)==2211873){d=a[9625520]|0}else if((b|0)==2211877){d=a[9625521]|0}else if((b|0)==2211881){d=a[9625522]|0}else{if((b&16760832|0)!=2195456){d=0;break}d=a[(c[3532636]|0)+(b>>>1&8191)|0]|0}}while(0);return d|0}function fks(a){a=a|0;var e=0,f=0,g=0;if((a|0)==2211884){e=d[9625523]|0;return e|0}else if((a|0)==2211876){e=d[9625521]|0;return e|0}else if((a|0)==2211880){e=d[9625522]|0;return e|0}else if((a|0)==3145732){e=b[c[3541508]>>1]|0;return e|0}else if((a|0)==3145734){e=b[(c[3541508]|0)+2>>1]|0;return e|0}else if((a|0)==3145740){f=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;if((f|0)>=(c[2113018]|0)){e=1;return e|0}e=f>>>31&65535;return e|0}else if((a|0)==2211872){e=d[9625520]|0;return e|0}else if((a|0)==2211900){f=((c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0)/(c[2113058]|0)|0;if((f|0)==(c[2384354]|0)){g=65024}else{c[2384354]=f;g=32256}e=(g|f)&65535;return e|0}else if((a|0)==2211892){e=d[9625525]|0;return e|0}else if((a|0)==2211888){e=d[9625524]|0;return e|0}else{if((a&16760832|0)!=2195456){e=0;return e|0}e=d[(c[3532636]|0)+(a>>>1&8191)|0]|0;return e|0}return 0}function fkt(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;if((b|0)==2211869){e=(d&16)==0?0:262144;f=c[3541206]|0;g=f+e|0;c[3541190]=g;c[3541198]=g;c[3541191]=f+(e|256);c[3541199]=f+(e|65536);c[3541192]=f+(e|512);c[3541200]=f+(e|131072);c[3541193]=f+(e|768);c[3541201]=f+(e|196608);return}if((b&16760832|0)!=2195456){return}a[(c[3532636]|0)+(b>>>1&8191)|0]=d;return}function fku(d,e){d=d|0;e=e|0;var f=0,g=0,h=0;if((d|0)==3145732|(d|0)==3145734){b[c[3541508]>>1]=e;c[3541508]=(c[3541508]|0)+2;return}else if((d|0)==2211868){f=(e&16)==0?0:262144;g=c[3541206]|0;h=g+f|0;c[3541190]=h;c[3541198]=h;c[3541191]=g+(f|256);c[3541199]=g+(f|65536);c[3541192]=g+(f|512);c[3541200]=g+(f|131072);c[3541193]=g+(f|768);c[3541201]=g+(f|196608);return}else if((d|0)==3145728){c[3541508]=(c[3541506]|0)+((e&65535)<<1&16382);return}else if((d|0)==3145740){b[(c[3541500]|0)+(c[3541498]<<1)>>1]=e;return}else if((d|0)==3145736){c[3541498]=e&255;return}else{if((d&16760832|0)!=2195456){return}a[(c[3532636]|0)+(d>>>1&8191)|0]=e&255;return}}function fkv(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2287564+(b*112|0)>>2];c[a+104>>2]=c[2287568+(b*112|0)>>2];c[a+108>>2]=c[2287572+(b*112|0)>>2];d=0;return d|0}function fkw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=2287464+(b*112|0);e=0;return e|0}function fkx(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1008736+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function fky(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=44){if((a|0)==0){d=0;return d|0}e=a;f=2288248+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}f=b-45|0;if(f>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;a=692376+(f*12|0)|0;c[b>>2]=c[a>>2];c[b+4>>2]=c[a+4>>2];c[b+8>>2]=c[a+8>>2];d=0;return d|0}function fkz(){var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;d=i;i=i+360|0;e=d|0;f=d+112|0;g=d+120|0;j=d+232|0;k=d+240|0;l=d+352|0;c[2113208]=4194304;c[2426666]=0;c[2418132]=0;c[3532626]=1048576;c[3541502]=1114112;c[3541532]=5308416;c[3541206]=5341184;c[2405604]=5865472;c[2418246]=5865472;c[2418200]=5931008;c[3541534]=5933056;c[3541530]=5941248;c[3541528]=5945344;c[2411414]=5949440;c[3532636]=5953536;c[3541506]=5969920;c[3541500]=5986304;c[2411518]=5986816;c[3531916]=5986816;m=0;while(1){if((m|0)>=1024){break}n=9638528+(m<<2)|0;if((c[n>>2]|0)==0){o=59297;break}else{m=m+1|0}}do{if((o|0)==59297){m=gGq(5995008)|0;c[n>>2]=m;if((m|0)==0){break}c[2426666]=m;gGz(m|0,0,5995008);c[2418132]=m;c[3532626]=m+1048576;c[3541502]=m+1114112;p=c[2113208]|0;c[3541532]=m+(p+1114112);c[3541206]=m+(p+1146880);q=m+(p+1671168)|0;c[2405604]=q;c[2418246]=q;c[2418200]=m+(p+1736704);c[3541534]=m+(p+1738752);c[3541530]=m+(p+1746944);c[3541528]=m+(p+1751040);c[2411414]=m+(p+1755136);c[3532636]=m+(p+1759232);c[3541506]=m+(p+1775616);c[3541500]=m+(p+1792e3);q=m+(p+1792512)|0;c[2411518]=q;c[3531916]=q;c[2414058]=m+(p+1800704);if((fpk(m,2)|0)!=0){r=1;i=d;return r|0}fpl(c[3541502]|0,2,2,c[2113208]|0,0);m=c[3541532]|0;do{if((c[3542200]|0)!=0){p=k+108|0;c[p>>2]=0;q=k+100|0;c[q>>2]=0;s=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[s&16383](k,4)|0;if((c[p>>2]|0)==0){break}p=c[q>>2]|0;c[l>>2]=9534384;q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[q&16383](l,4,0)|0;if((p|0)<1){break}gzL(m,0,4)|0}}while(0);m=c[3532626]|0;do{if((c[3542200]|0)!=0){p=g+108|0;c[p>>2]=0;q=g+100|0;c[q>>2]=0;s=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[s&16383](g,5)|0;if((c[p>>2]|0)==0){break}p=c[q>>2]|0;c[j>>2]=9534384;q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[q&16383](j,5,0)|0;if((p|0)<1){break}gzL(m,0,5)|0}}while(0);m=c[3541206]|0;do{if((c[3542200]|0)!=0){p=e+108|0;c[p>>2]=0;q=e+100|0;c[q>>2]=0;s=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[s&16383](e,6)|0;if((c[p>>2]|0)==0){break}p=c[q>>2]|0;c[f>>2]=9534384;q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[q&16383](f,6,0)|0;if((p|0)<1){break}gzL(m,0,6)|0}}while(0);fxU(0,425984);if((c[2394]|0)==0){t=c[2112932]|0}else{c[2394]=0;m=c[3532596]|0;c[2112932]=m;p=c[3532592]|0;if((p|0)!=0){gGC(9104152,p|0,280)|0}c[2113054]=c[2113060];t=m}m=c[2418132]|0;p=t|0;q=0;while(1){s=m+q|0;c[p>>2]=s;c[p+131072>>2]=s;s=q+1024|0;if(s>>>0>1048575){break}else{p=p+4|0;q=s}}q=c[2418246]|0;p=t+4096|0;m=1048576;while(1){s=q+(m-1048576)|0;c[p>>2]=s;c[p+65536>>2]=s;c[p+131072>>2]=s;s=m+1024|0;if(s>>>0>1114111){break}else{p=p+4|0;m=s}}m=c[2411414]|0;c[t+16384>>2]=m;c[t+81920>>2]=m;c[t+147456>>2]=m;p=m+1024|0;c[t+16388>>2]=p;c[t+81924>>2]=p;c[t+147460>>2]=p;p=m+2048|0;c[t+16392>>2]=p;c[t+81928>>2]=p;c[t+147464>>2]=p;p=m+3072|0;c[t+16396>>2]=p;c[t+81932>>2]=p;c[t+147468>>2]=p;p=c[2418200]|0;c[t+16400>>2]=p;c[t+81936>>2]=p;c[t+147472>>2]=p;m=p+1024|0;c[t+16404>>2]=m;c[t+81940>>2]=m;c[t+147476>>2]=m;m=c[3541534]|0;c[t+20480>>2]=m;c[t+86016>>2]=m;c[t+151552>>2]=m;p=m+1024|0;c[t+20484>>2]=p;c[t+86020>>2]=p;c[t+151556>>2]=p;p=m+2048|0;c[t+20488>>2]=p;c[t+86024>>2]=p;c[t+151560>>2]=p;p=m+3072|0;c[t+20492>>2]=p;c[t+86028>>2]=p;c[t+151564>>2]=p;p=m+4096|0;c[t+20496>>2]=p;c[t+86032>>2]=p;c[t+151568>>2]=p;p=m+5120|0;c[t+20500>>2]=p;c[t+86036>>2]=p;c[t+151572>>2]=p;p=m+6144|0;c[t+20504>>2]=p;c[t+86040>>2]=p;c[t+151576>>2]=p;p=m+7168|0;c[t+20508>>2]=p;c[t+86044>>2]=p;c[t+151580>>2]=p;p=c[3541528]|0;c[t+20512>>2]=p;c[t+86048>>2]=p;c[t+151584>>2]=p;m=p+1024|0;c[t+20516>>2]=m;c[t+86052>>2]=m;c[t+151588>>2]=m;m=p+2048|0;c[t+20520>>2]=m;c[t+86056>>2]=m;c[t+151592>>2]=m;m=p+3072|0;c[t+20524>>2]=m;c[t+86060>>2]=m;c[t+151596>>2]=m;m=c[3541530]|0;c[t+20528>>2]=m;c[t+86064>>2]=m;c[t+151600>>2]=m;p=m+1024|0;c[t+20532>>2]=p;c[t+86068>>2]=p;c[t+151604>>2]=p;p=m+2048|0;c[t+20536>>2]=p;c[t+86072>>2]=p;c[t+151608>>2]=p;p=m+3072|0;c[t+20540>>2]=p;c[t+86076>>2]=p;c[t+151612>>2]=p;c[t+196688>>2]=1934;c[t+196608>>2]=924;c[t+196728>>2]=2098;c[t+196648>>2]=2922;p=c[3532592]|0;if((p|0)!=0){gGC(p|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;c[2113182]=-470;c[2113178]=-472;c[2113174]=-474;fl6(1);c[2408]=44;fwR(0);p=c[2439330]|0;m=(p|0)==0;if(!m){q=p;gGC(9706056,q|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];q=c[3528484]|0;c[2076596]=q;s=c[2417276]|0;c[3541536]=s;c[1836236]=0;c[p+4180>>2]=964;c[p+4184>>2]=3206;u=c[3532626]|0;v=0;w=0;while(1){c[p+76+(w<<2)>>2]=u+(w<<8);x=v+1&65535;if((x&65535)>255){y=0;z=0;break}else{v=x;w=x&65535}}while(1){w=u+(z<<8)|0;c[p+76+(z+512<<2)>>2]=w;c[p+76+(z+768<<2)>>2]=w;w=y+1&65535;if((w&65535)>255){break}else{y=w;z=w&65535}}u=c[3532636]|0;w=192;v=192;while(1){c[p+76+(v<<2)>>2]=u+((v<<8)-49152);x=w+1&65535;if((x&65535)>223){A=192;B=192;break}else{w=x;v=x&65535}}while(1){c[p+76+(B+256<<2)>>2]=u+((B<<8)-49152);v=A+1&65535;if((v&65535)>223){C=192;D=192;break}else{A=v;B=v&65535}}while(1){v=u+((D<<8)-49152)|0;c[p+76+(D+512<<2)>>2]=v;c[p+76+(D+768<<2)>>2]=v;v=C+1&65535;if((v&65535)>223){break}else{C=v;D=v&65535}}c[p+972>>2]=0;c[p+1996>>2]=0;if(!m){u=p;gGC(u|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=q;c[2417276]=s;c[1836236]=-1;c[2113016]=2048;c[3531920]=c[2411414];u=a[9680]|0;v=u?32e3:0;if(u){if(a[9624]|0){u=v*3|0;w=52734;while(1){if((w|0)>(u|0)){w=w>>1}else{E=1222;F=w;break}}}else{E=2462;F=v}c[2429380]=F;c[3542124]=E;mw(3375e3,F);w=gGq(262144)|0;c[2406684]=w;gGz(w|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(3375e3,11025)}h[745421]=1.0;c[2436794]=3;h[745420]=1.0;c[2436792]=3;Ux(0,7575,1);c[2407030]=256;c[2407068]=3;a[7072704]=1;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];w=c[3532592]|0;if((w|0)!=0){gGC(9104152,w|0,280)|0}c[2113054]=c[2113060]}RI();w=c[2394]|0;u=c[14130368+(w<<2)>>2]|0;if((u|0)!=0){gGC(u|0,9104152,280)|0}c[8452240+(w<<2)>>2]=c[2113054];c[2394]=-1;w=c[2439330]|0;u=(w|0)==0;if(!u){s=w;gGC(9706056,s|0,76)|0}s=c[2438118]|0;c[2433530]=s;q=c[3528484]|0;c[2076596]=q;p=c[2417276]|0;c[3541536]=p;c[1836236]=0;gGz(9706056,0,76);if(!u){u=w;gGC(u|0,9706056,76)|0}c[2438118]=s;c[3528484]=q;c[2417276]=p;c[1836236]=-1;c[2113156]=0;a[9628264]=0;c[2407033]=0;p=c[3541206]|0;c[3541190]=p;c[3541198]=p;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=p+256;c[3541199]=p+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=p+512;c[3541200]=p+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=p+768;c[3541201]=p+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;mx(0);r=0;i=d;return r|0}}while(0);c[2426666]=0;r=1;i=d;return r|0}function fkA(){var a=0,b=0,d=0,e=0,f=0;Uw(0);a=c[3531464]|0;c[a+44344>>2]=0;c[a+44348>>2]=0;if((a|0)!=0){gGr(a);c[3531464]=0}a=c[2406684]|0;if((a|0)!=0){gGr(a);c[2406684]=0}fl7();c[2408]=39321;fwZ();if((c[2392]|0)>=0){a=0;do{b=14130368+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}b=14130384+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}a=a+1|0;}while((a|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;a=c[2426666]|0;b=0;while(1){if((b|0)>=1024){e=59370;break}f=9638528+(b<<2)|0;if((c[f>>2]|0)==(a|0)){break}else{b=b+1|0}}if((e|0)==59370){c[2426666]=0;return 0}gGr(a);c[f>>2]=0;c[2426666]=0;return 0}function fkB(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((a[9623632]|0)!=0){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;h=c[2417276]|0;c[3541536]=h;c[1836236]=0;gGz(9706056,0,76);if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=h;c[1836236]=-1;c[2113156]=0;a[9628264]=0;c[2407033]=0;h=c[3541206]|0;c[3541190]=h;c[3541198]=h;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=h+256;c[3541199]=h+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=h+512;c[3541200]=h+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=h+768;c[3541201]=h+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;mx(0)}a[9625520]=0;a[9625521]=0;a[9625522]=0;h=0;g=0;f=0;e=0;do{g=((a[9632664+h|0]&1)<<h|g&255)&255;f=((a[9630568+h|0]&1)<<h|f&255)&255;e=((a[9551744+h|0]&1)<<h|e&255)&255;h=h+1|0;}while((h|0)<8);a[9625520]=g;a[9625521]=f;a[9625522]=e;if((g&3)==3){e=g&-4;a[9625520]=e;i=e}else{i=g}if((i&12)==12){a[9625520]=i&-13}if((f&3)==3){i=f&-4;a[9625521]=i;j=i}else{j=f}if((j&12)==12){a[9625521]=j&-13}j=c[2392]|0;if((j|0)>=0){gGz(8452240,0,((j|0)>0?(j<<2)+4|0:4)|0)}c[2113054]=0;j=c[2438]|0;f=gGU(j,(j|0)<0|0?-1:0,16e6,0)|0;j=gGS(f,K,15360,0)|0;f=j;c[2113218]=f;c[2113216]=66666;c[2113221]=0;c[2113220]=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];j=c[3532592]|0;if((j|0)!=0){gGC(9104152,j|0,280)|0}c[2113054]=c[2113060]}c[2113058]=(f|0)/262|0;c[2113018]=f-((f*22|0|0)/262|0);f=c[2439330]|0;if((f|0)!=0){j=f;gGC(9706056,j|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;j=0;f=0;L77351:while(1){i=f;do{if((i|0)>=4){break L77351}i=i+1|0;g=(ag(c[2113218]|0,i)|0)/4|0;e=c[2113018]|0;do{if((g|0)>(e|0)){h=c[2113220]|0;if((h|0)<(e|0)){d=e-h|0;c[2113056]=d;h=RG(d)|0;c[2113054]=(c[2113054]|0)+h;c[2276108]=-1;c[2113056]=-1;c[2113220]=(c[2113220]|0)+h}h=c[2430398]|0;d=c[2439196]|0;k=d<<11;c[2438976]=h+k;l=(c[2440572]|0)>1;if(l){c[2438977]=(c[2430399]|0)+k}k=d^1;c[2439196]=k;d=k<<11;k=h+d|0;h=(c[3541506]|0)+12288|0;gGC(k|0,h|0,2048)|0;if(l){l=(c[2430399]|0)+d|0;d=(c[3541504]|0)+12288|0;gGC(l|0,d|0,2048)|0}c[8452200+(c[2394]<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0>=1024){break}RH(4)}}while(0);e=g-(c[2113220]|0)|0;c[2113056]=e;d=RG(e)|0;c[2113054]=(c[2113054]|0)+d;c[2276108]=-1;c[2113056]=-1;c[2113220]=(c[2113220]|0)+d;d=(ag(c[2113216]|0,i)|0)/4|0;e=c[2113221]|0;l=d-e|0;do{if((l|0)<1){m=0;n=e}else{if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){d=gfc(l)|0;c[2433530]=(c[2433530]|0)+d;m=d;n=c[2113221]|0;break}else{c[2433530]=(c[2433530]|0)+l;m=l;n=e;break}}}while(0);c[2113221]=n+m;o=c[2112964]|0;}while((o|0)==0);e=a[9688]|0?133:0;l=o+(j<<1<<1)|0;gg[c[3542124]&4095](l,e);Uu(0,l,e);j=e+j|0;f=i}f=c[2112964]|0;do{if((f|0)!=0){o=a[9688]|0?534:0;m=o-j|0;n=f+(j<<1<<1)|0;if((o|0)==(j|0)){break}gg[c[3542124]&4095](n,m);Uu(0,n,m)}}while(0);j=c[2394]|0;f=c[14130368+(j<<2)>>2]|0;if((f|0)!=0){gGC(f|0,9104152,280)|0}c[8452240+(j<<2)>>2]=c[2113054];c[2394]=-1;j=c[1836236]|0;f=c[9757320+(j<<2)>>2]|0;if((f|0)!=0){m=f;gGC(m|0,9706056,76)|0}c[9752472+(j<<2)>>2]=c[2433530];c[14113936+(j<<2)>>2]=c[2076596];c[9669104+(j<<2)>>2]=c[3541536];c[1836236]=-1;j=c[2112968]|0;if((j|0)==0){return 0}m=c[3531916]|0;f=c[m>>2]|0;n=c[2113308]|0;do{if((f|0)==0){gGz(j|0,0,n*76800|0|0)}else{if((n|0)==4){o=0;e=j;while(1){c[e>>2]=f;c[e+4>>2]=f;c[e+8>>2]=f;c[e+12>>2]=f;c[e+16>>2]=f;c[e+20>>2]=f;c[e+24>>2]=f;c[e+28>>2]=f;l=o+1|0;if((l|0)<9600){o=l;e=e+32|0}else{break}}}else if((n|0)==3){e=f>>>8&255;o=f>>>16&255;i=f&255;l=j;g=0;while(1){a[l]=i;a[l+1|0]=e;a[l+2|0]=o;d=g+1|0;if((d|0)<76800){l=l+3|0;g=d}else{break}}}else if((n|0)==2){g=f<<16|f;l=j;o=0;while(1){c[l>>2]=g;c[l+4>>2]=g;c[l+8>>2]=g;c[l+12>>2]=g;c[l+16>>2]=g;c[l+20>>2]=g;c[l+24>>2]=g;c[l+28>>2]=g;e=o+1|0;if((e|0)<4800){l=l+32|0;o=e}else{break}}}else{break}}}while(0);if(a[7072704]|0){c[2112970]=j;c[2113306]=n;c[2113298]=c[2113300];fl3();fnZ();p=c[3531916]|0}else{p=m}c[2112966]=p;m=c[2113016]|0;if((m|0)>0){q=0}else{return 0}do{c[p+(q<<2)>>2]=65535;q=q+1|0;}while((q|0)<(m|0));return 0}function fkC(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[3531916]|0;d=c[b>>2]|0;do{if((d|0)==0){e=c[2113308]|0;gGz(c[2112968]|0,0,e*76800|0|0);f=e}else{e=c[2113308]|0;if((e|0)==3){g=d>>>8&255;h=d>>>16&255;i=d&255;j=c[2112968]|0;k=0;while(1){a[j]=i;a[j+1|0]=g;a[j+2|0]=h;l=k+1|0;if((l|0)<76800){j=j+3|0;k=l}else{f=3;break}}}else if((e|0)==4){k=0;j=c[2112968]|0;while(1){c[j>>2]=d;c[j+4>>2]=d;c[j+8>>2]=d;c[j+12>>2]=d;c[j+16>>2]=d;c[j+20>>2]=d;c[j+24>>2]=d;c[j+28>>2]=d;h=k+1|0;if((h|0)<9600){k=h;j=j+32|0}else{f=4;break}}}else if((e|0)==2){j=d<<16|d;k=c[2112968]|0;h=0;while(1){c[k>>2]=j;c[k+4>>2]=j;c[k+8>>2]=j;c[k+12>>2]=j;c[k+16>>2]=j;c[k+20>>2]=j;c[k+24>>2]=j;c[k+28>>2]=j;g=h+1|0;if((g|0)<4800){k=k+32|0;h=g}else{f=2;break}}}else{f=e;break}}}while(0);if(a[7072704]|0){c[2112970]=c[2112968];c[2113306]=f;c[2113298]=c[2113300];fl3();fnZ();m=c[3531916]|0}else{m=b}c[2112966]=m;b=c[2113016]|0;if((b|0)>0){n=0}else{return 0}do{c[m+(n<<2)>>2]=65535;n=n+1|0;}while((n|0)<(b|0));return 0}function fkD(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;f=i;i=i+176|0;g=f|0;h=f+16|0;j=f+32|0;k=f+48|0;l=f+64|0;m=f+80|0;n=f+96|0;o=f+112|0;p=f+128|0;q=f+144|0;r=f+160|0;s=(e|0)==0;if(!s){c[e>>2]=169111}if((b&96|0)==0){i=f;return 0}gGz(r|0,0,12);t=c[2405604]|0;c[r>>2]=t;c[r+4>>2]=(c[2411518]|0)-t;c[r+12>>2]=162152;gj[c[2076592]&4095](r)|0;r=p|0;do{if((b&64|0)==0){fw$(b);Ut(0)}else{gGz(o|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){t=p+9|0;u=n;v=n|0;w=n+4|0;x=n+12|0;y=o|0;z=o+4|0;A=o+12|0;B=0;do{gGC(r|0,614896,11)|0;a[t]=B+48&255;C=8452256+(B<<2)|0;gGz(u|0,0,12);c[v>>2]=C;c[w>>2]=4;c[x>>2]=164976;gj[c[2076592]&4095](n)|0;if((c[C>>2]|0)!=0){c[y>>2]=c[14130368+(B<<2)>>2];c[z>>2]=c[8452184+(B<<2)>>2];c[A>>2]=r;C=c[2076592]|0;gj[C&4095](o)|0}B=B+1|0;}while((B|0)<=(c[2392]|0))}fw$(b);Ut(0);gGz(m|0,0,12);c[m>>2]=8453216;c[m+4>>2]=4;c[m+12>>2]=107480;B=c[2076592]|0;gj[B&4095](m)|0;gGz(l|0,0,12);c[l>>2]=14168504;c[l+4>>2]=256;c[l+12>>2]=476464;B=c[2076592]|0;gj[B&4095](l)|0;if((b&2|0)==0){break}else{D=0}do{mv(0,D,d[14168504+D|0]|0);D=D+1|0;}while((D|0)<256)}}while(0);if(!s){c[e>>2]=169110}gGz(k|0,0,12);c[k>>2]=9756784;c[k+4>>2]=4;c[k+12>>2]=175504;gj[c[2076592]&4095](k)|0;gGz(j|0,0,12);c[j>>2]=14166032;c[j+4>>2]=8;c[j+12>>2]=504552;gj[c[2076592]&4095](j)|0;gGz(h|0,0,12);c[h>>2]=14165992;c[h+4>>2]=8;c[h+12>>2]=388736;gj[c[2076592]&4095](h)|0;gGz(g|0,0,12);c[g>>2]=14165960;c[g+4>>2]=32;c[g+12>>2]=302352;gj[c[2076592]&4095](g)|0;gGz(q|0,0,12);c[q>>2]=9625520;c[q+4>>2]=6;c[q+12>>2]=215728;gj[c[2076592]&4095](q)|0;i=f;return 0}function fkE(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2693716+(b*112|0)>>2];c[a+104>>2]=c[2693720+(b*112|0)>>2];c[a+108>>2]=c[2693724+(b*112|0)>>2];d=0;return d|0}function fkF(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=2693616+(b*112|0);e=0;return e|0}function fkG(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=44){if((a|0)==0){d=0;return d|0}e=a;f=2288248+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}f=b-45|0;if(f>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;a=698200+(f*12|0)|0;c[b>>2]=c[a>>2];c[b+4>>2]=c[a+4>>2];c[b+8>>2]=c[a+8>>2];d=0;return d|0}function fkH(d,e){d=d|0;e=e|0;var f=0;if((d|0)==8388624|(d|0)==8388626|(d|0)==8388628|(d|0)==8388630|(d|0)==8388632|(d|0)==8388634|(d|0)==8388636|(d|0)==8388638){b[14168832+((d>>>1&7)<<1)>>1]=e;return}else if((d|0)==8388610){c[3542216]=(e&65535)<<1&32766;return}else if((d|0)==8388612|(d|0)==8388614){f=c[3542216]|0;b[(c[3542214]|0)+((f&32767)<<1)>>1]=e;c[3542216]=f+1;return}else if((d|0)==14680072){if(e<<16>>16!=0){return}gGz(9706056,0,76);return}else if((d|0)==10485766){f=c[3541526]|0;b[(c[3541522]|0)+((f&63)<<1)>>1]=e;c[3541526]=f+1;return}else if((d|0)==14680066){c[2113312]=e&65535;return}else if((d|0)==14680064){c[2113314]=e&65535;return}else if((d|0)==10485762){c[3541526]=e&1023;return}else if((d|0)==10485764){f=c[3541526]|0;b[(c[3541524]|0)+((f&1023)<<1)>>1]=e;c[3541526]=f+1;return}else if((d|0)==4194306){a[9722080]=(e&255)!=0|0;return}else{return}}function fkI(a,b){a=a|0;b=b|0;return}function fkJ(a){a=a|0;var d=0,e=0;if((a|0)==8388612){d=b[(c[3542214]|0)+((c[3542216]&32767)<<1)>>1]|0;return d|0}else if((a|0)==8388610){d=(c[3542216]|0)>>>1&16383;return d|0}else if((a|0)==10485766){d=b[(c[3541522]|0)+((c[3541526]&63)<<1)>>1]|0;return d|0}else if((a|0)==14680078){e=(c[2439292]|0)+1|0;c[2439292]=e;d=(e&4|0)==0?0:118;return d|0}else if((a|0)==10485764){d=b[(c[3541524]|0)+((c[3541526]&1023)<<1)>>1]|0;return d|0}else if((a|0)==10485762){d=c[3541526]&1023;return d|0}else if((a|0)==8388614){d=b[(c[3542214]|0)+((c[3542216]&32767)+1<<1)>>1]|0;return d|0}else if((a|0)==8388624|(a|0)==8388626|(a|0)==8388628|(a|0)==8388630|(a|0)==8388632|(a|0)==8388634|(a|0)==8388636|(a|0)==8388638){d=b[14168832+((a>>>1&7)<<1)>>1]|0;return d|0}else{d=0;return d|0}return 0}function fkK(a){a=a|0;var b=0;if(!((a|0)==4194305|(a|0)==10485761)){b=0;return b|0}a=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;if((a|0)>=(c[2113018]|0)){b=1;return b|0}b=a>>>31&255;return b|0}function fkL(b,e){b=b|0;e=e|0;var f=0;f=b&255;if((f|0)==0){a[(c[3540984]|0)+5885|0]=e;return}else if((f|0)==1){f=c[3540984]|0;b=c[f+5876>>2]|0;if((b|0)!=0){gg[b&4095](c[f+5880>>2]|0,0)}lH(f,d[f+5885|0]|0,e&255);return}else{return}}function fkM(b){b=b|0;var d=0,e=0;d=b&65535;switch(d&255|0){case 192:{e=a[9550225]|0;break};case 160:{e=a[9634753]|0;break};case 224:{e=a[9634752]|0;break};case 0:case 1:{e=lx(c[3540984]|0,d&1)|0|6;break};case 32:{e=a[9634754]|0;break};case 128:{e=a[9550224]|0;break};case 96:{e=a[9550226]|0;break};default:{e=0}}return e|0}function fkN(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2945956+(b*112|0)>>2];c[a+104>>2]=c[2945960+(b*112|0)>>2];c[a+108>>2]=c[2945964+(b*112|0)>>2];d=0;return d|0}function fkO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=2945856+(b*112|0);e=0;return e|0}function fkP(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>23){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1284232+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function fkQ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>42){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4075328+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fkR(){var a=0,d=0,e=0,f=0,g=0,h=0;a=fk3()|0;if((a|0)!=0){return a|0}d=c[2388092]|0;e=d+262144|0;f=d+5120|0;gGC(e|0,f|0,1024)|0;b[d+262192>>1]=20081;b[d+262200>>1]=24586;if((c[2394]|0)==0){g=c[2112932]|0;h=c[3532592]|0}else{c[2394]=0;d=c[3532596]|0;c[2112932]=d;f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];g=d;h=f}c[g+131092>>2]=e;if((h|0)!=0){gGC(h|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;return a|0}function fkS(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=a[7452584]|0;if(b){d=0;e=b&1;while(1){b=14163936+(d<<2)|0;f=c[b>>2]|0;g=c[2113006]|0;if((g|0)==0){h=59615}else{i=g-1|0;c[2113006]=i;if((i|0)==0){h=59615}}if((h|0)==59615){h=0;c[2383474]=0}if((f|0)==0){j=e}else{gGr(f);j=a[7452584]&1}c[b>>2]=0;b=d+1|0;if((b|0)<(j|0)){d=b;e=j}else{break}}}a[7452584]=0;c[2438224]=0;c[2433522]=0;c[2406672]=0;c[3528468]=0;j=c[2406688]|0;if((j|0)!=0){gGr(j);c[2406688]=0}c[2432972]=0;fpB();fwZ();if((c[2392]|0)>=0){j=0;do{e=14130368+(j<<2)|0;d=c[e>>2]|0;if((d|0)!=0){gGr(d);c[e>>2]=0}e=14130384+(j<<2)|0;d=c[e>>2]|0;if((d|0)!=0){gGr(d);c[e>>2]=0}j=j+1|0;}while((j|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;j=c[2414874]|0;e=0;while(1){if((e|0)>=1024){h=59632;break}k=9638528+(e<<2)|0;if((c[k>>2]|0)==(j|0)){break}else{e=e+1|0}}if((h|0)==59632){c[2414874]=0;return 0}gGr(j);c[k>>2]=0;c[2414874]=0;return 0}function fkT(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;if((a[9623624]|0)!=0){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=i;c[1836236]=-1;c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;lw(c[3540984]|0);a[9722080]=0;c[2439292]=0}gGz(9550224,0,3);i=0;g=0;f=0;e=0;do{g=((a[9632656+i|0]&1)<<i|g&255)&255;f=((a[9630560+i|0]&1)<<i|f&255)&255;e=((a[9629248+i|0]&1)<<i|e&255)&255;i=i+1|0;}while((i|0)<8);a[9550224]=g;a[9550225]=f;a[9550226]=e;if((g&3)==3){e=g&-4;a[9550224]=e;j=e}else{j=g}if((j&12)==12){a[9550224]=j&-13}if((f&3)==3){j=f&-4;a[9550225]=j;k=j}else{k=f}if((k&12)==12){a[9550225]=k&-13}k=c[2392]|0;if((k|0)>=0){gGz(8452240,0,((k|0)>0?(k<<2)+4|0:4)|0)}c[2113054]=0;k=c[2385548]|0;if((k|0)>0){gGz(9752472,0,((k|0)>1?k<<2:4)|0)}c[2433530]=0;if((c[2394]|0)==0){l=0}else{c[2394]=0;c[2112932]=c[3532596];k=c[3532592]|0;if((k|0)!=0){gGC(9104152,k|0,280)|0}k=c[2113060]|0;c[2113054]=k;l=k}k=c[2439330]|0;if((k|0)!=0){f=k;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;f=c[2438118]|0;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;c[2113054]=l+(c[2113220]|0);c[2433530]=f+(c[2113221]|0);f=c[2438]|0;l=gGU(f,(f|0)<0|0?-1:0,1e7,0)|0;f=gGS(l,K,15360,0)|0;l=f;c[2113218]=l;c[2113216]=58333;c[2113058]=(l|0)/262|0;f=l-((l*22|0|0)/262|0)|0;c[2113018]=f;k=0;j=l;l=f;while(1){f=k+1|0;g=(ag(f,j)|0)/4|0;do{if((g|0)>(l|0)){e=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;if((e|0)<(l|0)){i=l-e|0;c[2113056]=i;e=RG(i)|0;c[2113054]=(c[2113054]|0)+e;c[2276108]=-1;c[2113056]=-1}e=c[2112968]|0;do{if((e|0)!=0){i=c[3531916]|0;d=c[2113308]|0;do{if((c[i>>2]|0)==0){gGz(e|0,0,d*76800|0|0)}else{if((d|0)==3){m=c[i+1152>>2]|0;n=m>>>8&255;o=m>>>16&255;p=m&255;m=e;q=0;while(1){a[m]=p;a[m+1|0]=n;a[m+2|0]=o;r=q+1|0;if((r|0)<76800){m=m+3|0;q=r}else{break}}}else if((d|0)==2){q=c[i+1152>>2]|0;m=q<<16|q;q=e;o=0;while(1){c[q>>2]=m;c[q+4>>2]=m;c[q+8>>2]=m;c[q+12>>2]=m;c[q+16>>2]=m;c[q+20>>2]=m;c[q+24>>2]=m;c[q+28>>2]=m;n=o+1|0;if((n|0)<4800){q=q+32|0;o=n}else{break}}}else if((d|0)==4){o=c[i+1152>>2]|0;q=0;m=e;while(1){c[m>>2]=o;c[m+4>>2]=o;c[m+8>>2]=o;c[m+12>>2]=o;c[m+16>>2]=o;c[m+20>>2]=o;c[m+24>>2]=o;c[m+28>>2]=o;n=q+1|0;if((n|0)<9600){q=n;m=m+32|0}else{break}}}else{break}}}while(0);if(a[7072696]|0){c[2112970]=e;c[2113306]=d;c[2113298]=c[2113300];fpz();s=c[3531916]|0}else{s=i}c[2112966]=s;m=c[2113016]|0;if((m|0)>0){t=0}else{break}do{c[s+(t<<2)>>2]=65535;t=t+1|0;}while((t|0)<(m|0));i=c[3531914]|0;d=0;do{c[i+(d<<2)>>2]=65535;d=d+1|0;}while((d|0)<(m|0))}}while(0);e=c[2430400]|0;m=c[3541524]|0;gGC(e|0,m|0,2048)|0;if((a[9722080]&1)==0){break}c[8452200+(c[2394]<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0>=1024){break}RH(4)}}while(0);m=g-(c[2113054]|0)-(c[2113056]|0)+(c[2276108]|0)|0;c[2113056]=m;e=RG(m)|0;c[2113054]=(c[2113054]|0)+e;c[2276108]=-1;c[2113056]=-1;UF(ag((c[2113216]|0)/4|0,k)|0)|0;if((f|0)>=4){break}k=f;j=c[2113218]|0;l=c[2113018]|0}l=c[2113216]|0;j=gGU(l,(l|0)<0|0?-1:0,2048e6,0)|0;k=c[2438224]|0;t=gGS(j,K,k,(k|0)<0|0?-1:0)|0;k=t;UF(l)|0;l=c[2443826]|0;if((l|0)<1073676288){c[2443826]=l-k}l=c[2443827]|0;if((l|0)<1073676288){c[2443827]=l-k}l=(c[3528508]|0)-k|0;c[3528508]=(l|0)<0?0:l;l=c[2112964]|0;if((l|0)!=0){gg[c[3542112]&4095](l,a[9688]|0?534:0)}l=c[2113054]|0;c[2113220]=(c[2113056]|0)+l-(c[2276108]|0)-(c[2113218]|0);k=c[2394]|0;t=c[14130368+(k<<2)>>2]|0;if((t|0)!=0){gGC(t|0,9104152,280)|0}c[8452240+(k<<2)>>2]=l;c[2394]=-1;l=c[1836236]|0;k=c[9757320+(l<<2)>>2]|0;if((k|0)==0){u=c[2433530]|0;v=9752472+(l<<2)|0;c[v>>2]=u;w=c[2076596]|0;x=14113936+(l<<2)|0;c[x>>2]=w;y=c[3541536]|0;z=9669104+(l<<2)|0;c[z>>2]=y;c[1836236]=-1;return 0}t=k;gGC(t|0,9706056,76)|0;u=c[2433530]|0;v=9752472+(l<<2)|0;c[v>>2]=u;w=c[2076596]|0;x=14113936+(l<<2)|0;c[x>>2]=w;y=c[3541536]|0;z=9669104+(l<<2)|0;c[z>>2]=y;c[1836236]=-1;return 0}function fkU(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=c[3531916]|0;do{if((c[b>>2]|0)==0){d=c[2113308]|0;gGz(c[2112968]|0,0,d*76800|0|0);e=d}else{d=c[2113308]|0;if((d|0)==3){f=c[b+1152>>2]|0;g=f>>>8&255;h=f>>>16&255;i=f&255;f=c[2112968]|0;j=0;while(1){a[f]=i;a[f+1|0]=g;a[f+2|0]=h;k=j+1|0;if((k|0)<76800){f=f+3|0;j=k}else{e=3;break}}}else if((d|0)==2){j=c[b+1152>>2]|0;f=j<<16|j;j=c[2112968]|0;h=0;while(1){c[j>>2]=f;c[j+4>>2]=f;c[j+8>>2]=f;c[j+12>>2]=f;c[j+16>>2]=f;c[j+20>>2]=f;c[j+24>>2]=f;c[j+28>>2]=f;g=h+1|0;if((g|0)<4800){j=j+32|0;h=g}else{e=2;break}}}else if((d|0)==4){h=c[b+1152>>2]|0;j=0;f=c[2112968]|0;while(1){c[f>>2]=h;c[f+4>>2]=h;c[f+8>>2]=h;c[f+12>>2]=h;c[f+16>>2]=h;c[f+20>>2]=h;c[f+24>>2]=h;c[f+28>>2]=h;g=j+1|0;if((g|0)<9600){j=g;f=f+32|0}else{e=4;break}}}else{e=d;break}}}while(0);if(a[7072696]|0){c[2112970]=c[2112968];c[2113306]=e;c[2113298]=c[2113300];fpz();l=c[3531916]|0}else{l=b}c[2112966]=l;b=c[2113016]|0;if((b|0)>0){m=0}else{return 0}do{c[l+(m<<2)>>2]=65535;m=m+1|0;}while((m|0)<(b|0));m=c[3531914]|0;l=0;do{c[m+(l<<2)>>2]=65535;l=l+1|0;}while((l|0)<(b|0));return 0}function fkV(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=i;i=i+96|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;l=e+80|0;if((d|0)!=0){c[d>>2]=169735}if((b&96|0)==0){i=e;return 0}gGz(l|0,0,12);m=c[2414576]|0;c[l>>2]=m;c[l+4>>2]=(c[2411516]|0)-m;c[l+12>>2]=219592;gj[c[2076592]&4095](l)|0;l=h|0;do{if((b&64|0)!=0){gGz(g|0,0,16);c[2394]=-1;if((c[2392]|0)<0){break}m=h+9|0;n=f;o=f|0;p=f+4|0;q=f+12|0;r=g|0;s=g+4|0;t=g+12|0;u=0;do{gGC(l|0,614896,11)|0;a[m]=u+48&255;v=8452256+(u<<2)|0;gGz(n|0,0,12);c[o>>2]=v;c[p>>2]=4;c[q>>2]=164976;gj[c[2076592]&4095](f)|0;if((c[v>>2]|0)!=0){c[r>>2]=c[14130368+(u<<2)>>2];c[s>>2]=c[8452184+(u<<2)>>2];c[t>>2]=l;v=c[2076592]|0;gj[v&4095](g)|0}u=u+1|0;}while((u|0)<=(c[2392]|0))}}while(0);fw$(b);UQ(b,d);gGz(k|0,0,12);c[k>>2]=8452880;c[k+4>>2]=8;c[k+12>>2]=212472;gj[c[2076592]&4095](k)|0;gGz(j|0,0,12);c[j>>2]=9757168;c[j+4>>2]=4;c[j+12>>2]=208296;gj[c[2076592]&4095](j)|0;i=e;return 0}function fkW(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1570428+(b*112|0)>>2];c[a+104>>2]=c[1570432+(b*112|0)>>2];c[a+108>>2]=c[1570436+(b*112|0)>>2];d=0;return d|0}function fkX(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=1570328+(b*112|0);e=0;return e|0}function fkY(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>44){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4075848+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fkZ(){var a=0,d=0,e=0,f=0,g=0,h=0;a=fk3()|0;if((a|0)!=0){return a|0}d=c[2388092]|0;e=d+262144|0;f=d+6144|0;gGC(e|0,f|0,1024)|0;b[d+262172>>1]=20081;b[d+262180>>1]=24586;if((c[2394]|0)==0){g=c[2112932]|0;h=c[3532592]|0}else{c[2394]=0;d=c[3532596]|0;c[2112932]=d;f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];g=d;h=f}c[g+131096>>2]=e;if((h|0)!=0){gGC(h|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;return a|0}function fk_(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1568748+(b*112|0)>>2];c[a+104>>2]=c[1568752+(b*112|0)>>2];c[a+108>>2]=c[1568756+(b*112|0)>>2];d=0;return d|0}function fk$(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=1568648+(b*112|0);e=0;return e|0}function fk0(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1567068+(b*112|0)>>2];c[a+104>>2]=c[1567072+(b*112|0)>>2];c[a+108>>2]=c[1567076+(b*112|0)>>2];d=0;return d|0}function fk1(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=1566968+(b*112|0);e=0;return e|0}function fk2(){var a=0,d=0,e=0,f=0,g=0,h=0;a=fk3()|0;if((a|0)!=0){return a|0}d=c[2388092]|0;e=d+262144|0;f=d+6144|0;gGC(e|0,f|0,1024)|0;b[d+262184>>1]=20081;b[d+262192>>1]=24586;if((c[2394]|0)==0){g=c[2112932]|0;h=c[3532592]|0}else{c[2394]=0;d=c[3532596]|0;c[2112932]=d;f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];g=d;h=f}c[g+131096>>2]=e;if((h|0)!=0){gGC(h|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;return a|0}function fk3(){var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;d=i;i=i+120|0;e=d|0;f=d+112|0;c[2424]=6e3;c[2113316]=524288;c[2113212]=524288;c[2414874]=0;c[2388092]=0;c[2385870]=263168;c[3542212]=328704;c[3541520]=852992;c[2414576]=1377280;c[2388222]=1377280;c[2387120]=1393664;c[3530222]=1395712;c[3532636]=1397760;c[3527290]=1397760;c[3542214]=1430528;c[3541524]=1496064;c[3541522]=1498112;c[2411516]=1498240;c[3531916]=1498240;c[3531914]=1506432;g=0;while(1){if((g|0)>=1024){break}j=9638528+(g<<2)|0;if((c[j>>2]|0)==0){k=59805;break}else{g=g+1|0}}do{if((k|0)==59805){g=gGq(1514624)|0;c[j>>2]=g;if((g|0)==0){break}c[2414874]=g;gGz(g|0,0,1514624);c[2388092]=g;c[2385870]=g+263168;c[3542212]=g+328704;l=(c[2113316]|0)+328704|0;c[3541520]=g+l;m=l+(c[2113212]|0)|0;l=g+m|0;c[2414576]=l;c[2388222]=l;c[2387120]=g+(m+16384);c[3530222]=g+(m+18432);l=g+(m+20480)|0;c[3532636]=l;c[3527290]=l;c[3542214]=g+(m+53248);c[3541524]=g+(m+118784);c[3541522]=g+(m+120832);l=g+(m+120960)|0;c[2411516]=l;c[3531916]=l;c[3531914]=g+(m+129152);c[2414056]=g+(m+137344);if((R6(g+1|0,0,2)|0)!=0){n=1;i=d;return n|0}if((R6(c[2388092]|0,1,2)|0)!=0){n=1;i=d;return n|0}g=c[2385870]|0;if((c[3542200]|0)==0){n=1;i=d;return n|0}m=e+108|0;c[m>>2]=0;l=e+100|0;c[l>>2]=0;o=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[o&16383](e,2)|0;do{if((c[m>>2]|0)!=0){o=c[l>>2]|0;c[f>>2]=9534384;p=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[p&16383](f,2,0)|0;if((o|0)<1){n=1;i=d;return n|0}if((gzL(g,0,2)|0)==0){break}else{n=1}i=d;return n|0}}while(0);fni(c[3542212]|0,5,c[2113316]|0);fni(c[3541520]|0,9,c[2113212]|0);fxU(0,425984);if((c[2394]|0)==0){q=c[2112932]|0}else{c[2394]=0;g=c[3532596]|0;c[2112932]=g;l=c[3532592]|0;if((l|0)!=0){gGC(9104152,l|0,280)|0}c[2113054]=c[2113060];q=g}g=c[2388092]|0;l=q|0;m=0;while(1){o=g+m|0;c[l>>2]=o;c[l+131072>>2]=o;o=m+1024|0;if(o>>>0>262143){break}else{l=l+4|0;m=o}}m=c[2387120]|0;c[q+16448>>2]=m;c[q+81984>>2]=m;c[q+147520>>2]=m;l=m+1024|0;c[q+16452>>2]=l;c[q+81988>>2]=l;c[q+147524>>2]=l;l=c[3530222]|0;c[q+16480>>2]=l;c[q+82016>>2]=l;c[q+147552>>2]=l;m=l+1024|0;c[q+16484>>2]=m;c[q+82020>>2]=m;c[q+147556>>2]=m;m=c[2388222]|0;c[q+49152>>2]=m;c[q+114688>>2]=m;c[q+180224>>2]=m;l=m+1024|0;c[q+49156>>2]=l;c[q+114692>>2]=l;c[q+180228>>2]=l;l=m+2048|0;c[q+49160>>2]=l;c[q+114696>>2]=l;c[q+180232>>2]=l;l=m+3072|0;c[q+49164>>2]=l;c[q+114700>>2]=l;c[q+180236>>2]=l;l=m+4096|0;c[q+49168>>2]=l;c[q+114704>>2]=l;c[q+180240>>2]=l;l=m+5120|0;c[q+49172>>2]=l;c[q+114708>>2]=l;c[q+180244>>2]=l;l=m+6144|0;c[q+49176>>2]=l;c[q+114712>>2]=l;c[q+180248>>2]=l;l=m+7168|0;c[q+49180>>2]=l;c[q+114716>>2]=l;c[q+180252>>2]=l;l=m+8192|0;c[q+49184>>2]=l;c[q+114720>>2]=l;c[q+180256>>2]=l;l=m+9216|0;c[q+49188>>2]=l;c[q+114724>>2]=l;c[q+180260>>2]=l;l=m+10240|0;c[q+49192>>2]=l;c[q+114728>>2]=l;c[q+180264>>2]=l;l=m+11264|0;c[q+49196>>2]=l;c[q+114732>>2]=l;c[q+180268>>2]=l;l=m+12288|0;c[q+49200>>2]=l;c[q+114736>>2]=l;c[q+180272>>2]=l;l=m+13312|0;c[q+49204>>2]=l;c[q+114740>>2]=l;c[q+180276>>2]=l;l=m+14336|0;c[q+49208>>2]=l;c[q+114744>>2]=l;c[q+180280>>2]=l;l=m+15360|0;c[q+49212>>2]=l;c[q+114748>>2]=l;c[q+180284>>2]=l;c[q+196688>>2]=2912;c[q+196608>>2]=564;c[q+196728>>2]=2140;c[q+196648>>2]=1090;c[q+24576>>2]=1;c[q+90112>>2]=1;c[q+155648>>2]=1;c[q+24580>>2]=1;c[q+90116>>2]=1;c[q+155652>>2]=1;c[q+24584>>2]=1;c[q+90120>>2]=1;c[q+155656>>2]=1;c[q+24588>>2]=1;c[q+90124>>2]=1;c[q+155660>>2]=1;c[q+196612>>2]=594;c[q+196692>>2]=2082;c[q+196652>>2]=1774;c[q+196732>>2]=1304;l=c[3532592]|0;if((l|0)!=0){gGC(l|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);l=c[2439330]|0;m=(l|0)==0;if(!m){g=l;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];g=c[3528484]|0;c[2076596]=g;o=c[2417276]|0;c[3541536]=o;c[1836236]=0;p=c[2385870]|0;r=0;s=0;while(1){c[l+76+(s<<2)>>2]=p+(s<<8);t=r+1&65535;if((t&65535)>127){u=0;v=0;break}else{r=t;s=t&65535}}while(1){s=p+(v<<8)|0;c[l+76+(v+512<<2)>>2]=s;c[l+76+(v+768<<2)>>2]=s;s=u+1&65535;if((s&65535)>127){break}else{u=s;v=s&65535}}p=c[3527290]|0;s=128;r=128;while(1){c[l+76+(r<<2)>>2]=p+((r<<8)-32768);t=s+1&65535;if((t&65535)>255){w=128;x=128;break}else{s=t;r=t&65535}}while(1){c[l+76+(x+256<<2)>>2]=p+((x<<8)-32768);r=w+1&65535;if((r&65535)>255){y=128;z=128;break}else{w=r;x=r&65535}}while(1){r=p+((z<<8)-32768)|0;c[l+76+(z+512<<2)>>2]=r;c[l+76+(z+768<<2)>>2]=r;r=y+1&65535;if((r&65535)>255){break}else{y=r;z=r&65535}}c[l+4176>>2]=1206;c[l+4172>>2]=1938;if(!m){p=l;gGC(p|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=g;c[2417276]=o;c[1836236]=-1;fpA();c[2113016]=2048;c[3531920]=c[2387120];c[3531918]=c[3530222];a[7460904]=1;UL(35e5,1078,3456,0);c[2438224]=35e5;c[2433522]=3416;c[2406672]=1752;c[3528468]=9362;c[2443842]=584;h[745398]=1.0;a[3203264]=1;a[7072696]=1;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];p=c[3532592]|0;if((p|0)!=0){gGC(9104152,p|0,280)|0}c[2113054]=c[2113060]}RI();p=c[2394]|0;r=c[14130368+(p<<2)>>2]|0;if((r|0)!=0){gGC(r|0,9104152,280)|0}c[8452240+(p<<2)>>2]=c[2113054];c[2394]=-1;p=c[2439330]|0;r=(p|0)==0;if(!r){s=p;gGC(9706056,s|0,76)|0}s=c[2438118]|0;c[2433530]=s;t=c[3528484]|0;c[2076596]=t;A=c[2417276]|0;c[3541536]=A;c[1836236]=0;gGz(9706056,0,76);if(!r){r=p;gGC(r|0,9706056,76)|0}c[2438118]=s;c[3528484]=t;c[2417276]=A;c[1836236]=-1;c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;lw(c[3540984]|0);a[9722080]=0;c[2439292]=0;n=0;i=d;return n|0}}while(0);c[2414874]=0;n=1;i=d;return n|0}function fk4(b){b=b|0;var e=0,f=0,g=0;switch(b&255|0){case 96:{b=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;if((b|0)<(c[2113018]|0)){e=b>>>31<<7&255}else{e=-128}f=e|a[9625516];return f|0};case 0:{f=a[9625514]|0;return f|0};case 112:{e=c[3540984]|0;b=(d[e+5887|0]|0|128)&(d[e+5886|0]|0);if((a[e+5884|0]&2)==0){g=b&255}else{g=(a[(c[e+5828>>2]|0)+100|0]&1|b)&255}f=g|6;return f|0};case 32:{f=a[9625517]|0;return f|0};case 16:{f=a[9625515]|0;return f|0};case 64:{f=a[9625512]|0;return f|0};case 80:{f=a[9625513]|0;return f|0};default:{f=0;return f|0}}return 0}function fk5(b,e){b=b|0;e=e|0;var f=0;f=b&255;if((f|0)==112){a[(c[3540984]|0)+5885|0]=e;return}else if((f|0)==113){f=c[3540984]|0;b=c[f+5876>>2]|0;if((b|0)!=0){gg[b&4095](c[f+5880>>2]|0,0)}lH(f,d[f+5885|0]|0,e&255);return}else{return}}function fk6(a){a=a|0;var b=0;if(!((a|0)==524289|(a|0)==1310721)){b=0;return b|0}a=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;if((a|0)>=(c[2113018]|0)){b=1;return b|0}b=a>>>31&255;return b|0}function fk7(a){a=a|0;var d=0,e=0;if((a|0)==1048578){d=(c[3542216]|0)>>>1&16383;return d|0}else if((a|0)==524288|(a|0)==1310720){e=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;if((e|0)>=(c[2113018]|0)){d=1;return d|0}d=e>>>31&65535;return d|0}else if((a|0)==1048580){d=b[(c[3542214]|0)+((c[3542216]&32767)<<1)>>1]|0;return d|0}else if((a|0)==1310724){d=b[(c[3541524]|0)+((c[3541526]&1023)<<1)>>1]|0;return d|0}else if((a|0)==1310726){d=b[(c[3541522]|0)+((c[3541526]&63)<<1)>>1]|0;return d|0}else if((a|0)==1310722){d=c[3541526]&1023;return d|0}else if((a|0)==1048592|(a|0)==1048593|(a|0)==1048594|(a|0)==1048595|(a|0)==1048596|(a|0)==1048597|(a|0)==1048598|(a|0)==1048599|(a|0)==1048600|(a|0)==1048601|(a|0)==1048602|(a|0)==1048603|(a|0)==1048604|(a|0)==1048605|(a|0)==1048606|(a|0)==1048607){d=b[14168832+((a>>>1&7)<<1)>>1]|0;return d|0}else if((a|0)==1048582){d=b[(c[3542214]|0)+((c[3542216]&32767)+1<<1)>>1]|0;return d|0}else{d=0;return d|0}return 0}function fk8(d,e){d=d|0;e=e|0;if((d|0)==524291){a[9722072]=e<<24>>24!=0|0;return}else if((d|0)==1310726){d=c[3541526]|0;b[(c[3541522]|0)+((d&63)<<1)>>1]=e&255;c[3541526]=d+1;return}else{return}}function fk9(d,e){d=d|0;e=e|0;var f=0;if((d|0)==1572864){c[2113314]=e&65535;return}else if((d|0)==1048578){c[3542216]=(e&65535)<<1&32766;return}else if((d|0)==1572866){c[2113312]=e&65535;return}else if((d|0)==1048580){f=c[3542216]|0;b[(c[3542214]|0)+((f&32767)<<1)>>1]=e;c[3542216]=f+1;return}else if((d|0)==524290){a[9722072]=(e&255)!=0|0;return}else if((d|0)==1572872){if(e<<16>>16!=0){return}gGz(9706056,0,76);c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;lw(c[3540984]|0);return}else if((d|0)==1310726){f=c[3541526]|0;b[(c[3541522]|0)+((f&63)<<1)>>1]=e;c[3541526]=f+1;return}else if((d|0)==1310722){c[3541526]=e&1023;return}else if((d|0)==1310724){f=c[3541526]|0;b[(c[3541524]|0)+((f&1023)<<1)>>1]=e;c[3541526]=f+1;return}else if((d|0)==1048592|(d|0)==1048593|(d|0)==1048594|(d|0)==1048595|(d|0)==1048596|(d|0)==1048597|(d|0)==1048598|(d|0)==1048599|(d|0)==1048600|(d|0)==1048601|(d|0)==1048602|(d|0)==1048603|(d|0)==1048604|(d|0)==1048605|(d|0)==1048606|(d|0)==1048607){b[14168832+((d>>>1&7)<<1)>>1]=e;return}else if((d|0)==1048582){d=c[3542216]|0;b[(c[3542214]|0)+((d&32767)<<1)>>1]=e;c[3542216]=d+1;return}else{return}}function fla(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2770324+(b*112|0)>>2];c[a+104>>2]=c[2770328+(b*112|0)>>2];c[a+108>>2]=c[2770332+(b*112|0)>>2];d=0;return d|0}function flb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=2770224+(b*112|0);e=0;return e|0}function flc(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1096584+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function fld(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>43){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=2771680+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fle(){var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;d=i;i=i+120|0;e=d|0;f=d+112|0;a[7461832]=1;c[2424]=6e3;c[2113316]=524288;c[2113212]=524288;c[2426662]=0;c[2418130]=0;c[3532626]=262144;c[3542212]=294912;c[3541520]=819200;c[2405600]=1343488;c[2418244]=1343488;c[2411412]=1376256;c[2406888]=1380352;c[3532636]=1384448;c[3542214]=1417216;c[3541524]=1482752;c[3541522]=1484800;c[2411512]=1484928;c[3531916]=1484928;c[3531914]=1489024;g=0;while(1){if((g|0)>=1024){break}j=9638528+(g<<2)|0;if((c[j>>2]|0)==0){k=59973;break}else{g=g+1|0}}do{if((k|0)==59973){g=gGq(1493120)|0;c[j>>2]=g;if((g|0)==0){break}c[2426662]=g;gGz(g|0,0,1493120);c[2418130]=g;c[3532626]=g+262144;c[3542212]=g+294912;l=(c[2113316]|0)+294912|0;c[3541520]=g+l;m=l+(c[2113212]|0)|0;l=g+m|0;c[2405600]=l;c[2418244]=l;c[2411412]=g+(m+32768);c[2406888]=g+(m+36864);c[3532636]=g+(m+40960);c[3542214]=g+(m+73728);c[3541524]=g+(m+139264);c[3541522]=g+(m+141312);l=g+(m+141440)|0;c[2411512]=l;c[3531916]=l;c[3531914]=g+(m+145536);c[2414052]=g+(m+149632);fpk(g,2)|0;fni(c[3542212]|0,2,c[2113316]|0);fni(c[3541520]|0,6,c[2113212]|0);g=c[3532626]|0;do{if((c[3542200]|0)!=0){m=e+108|0;c[m>>2]=0;l=e+100|0;c[l>>2]=0;n=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[n&16383](e,10)|0;if((c[m>>2]|0)==0){break}m=c[l>>2]|0;c[f>>2]=9534384;l=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[l&16383](f,10,0)|0;if((m|0)<1){break}gzL(g,0,10)|0}}while(0);fxU(0,425984);if((c[2394]|0)==0){o=c[2112932]|0}else{c[2394]=0;g=c[3532596]|0;c[2112932]=g;m=c[3532592]|0;if((m|0)!=0){gGC(9104152,m|0,280)|0}c[2113054]=c[2113060];o=g}g=c[2418130]|0;m=o|0;l=0;while(1){n=g+l|0;c[m>>2]=n;c[m+131072>>2]=n;n=l+1024|0;if(n>>>0>262143){break}else{m=m+4|0;l=n}}l=c[2418244]|0;m=o+1024|0;g=262144;while(1){n=l+(g-262144)|0;c[m>>2]=n;c[m+65536>>2]=n;c[m+131072>>2]=n;n=g+1024|0;if(n>>>0>294911){break}else{m=m+4|0;g=n}}g=c[2411412]|0;c[o+2112>>2]=g;c[o+67648>>2]=g;c[o+133184>>2]=g;m=g+1024|0;c[o+2116>>2]=m;c[o+67652>>2]=m;c[o+133188>>2]=m;m=c[2406888]|0;c[o+2144>>2]=m;c[o+67680>>2]=m;c[o+133216>>2]=m;g=m+1024|0;c[o+2148>>2]=g;c[o+67684>>2]=g;c[o+133220>>2]=g;c[o+196688>>2]=434;c[o+196608>>2]=98;c[o+196728>>2]=1084;c[o+196648>>2]=2106;c[o+3072>>2]=1;c[o+68608>>2]=1;c[o+134144>>2]=1;c[o+3076>>2]=1;c[o+68612>>2]=1;c[o+134148>>2]=1;c[o+3080>>2]=1;c[o+68616>>2]=1;c[o+134152>>2]=1;c[o+3084>>2]=1;c[o+68620>>2]=1;c[o+134156>>2]=1;c[o+196612>>2]=594;c[o+196692>>2]=2082;c[o+196652>>2]=1774;c[o+196732>>2]=1304;g=c[3532592]|0;if((g|0)!=0){gGC(g|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fpA();fwR(0);g=c[2439330]|0;m=(g|0)==0;if(!m){l=g;gGC(9706056,l|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];l=c[3528484]|0;c[2076596]=l;n=c[2417276]|0;c[3541536]=n;c[1836236]=0;c[g+4172>>2]=526;c[g+4176>>2]=1064;p=c[3532626]|0;q=0;r=0;while(1){c[g+76+(r<<2)>>2]=p+(r<<8);s=q+1&65535;if((s&65535)>127){t=0;u=0;break}else{q=s;r=s&65535}}while(1){r=p+(u<<8)|0;c[g+76+(u+512<<2)>>2]=r;c[g+76+(u+768<<2)>>2]=r;r=t+1&65535;if((r&65535)>127){break}else{t=r;u=r&65535}}p=c[3532636]|0;r=128;q=128;while(1){c[g+76+(q<<2)>>2]=p+((q<<8)-32768);s=r+1&65535;if((s&65535)>255){v=128;w=128;break}else{r=s;q=s&65535}}while(1){c[g+76+(w+256<<2)>>2]=p+((w<<8)-32768);q=v+1&65535;if((q&65535)>255){x=128;y=128;break}else{v=q;w=q&65535}}while(1){q=p+((y<<8)-32768)|0;c[g+76+(y+512<<2)>>2]=q;c[g+76+(y+768<<2)>>2]=q;q=x+1&65535;if((q&65535)>255){break}else{x=q;y=q&65535}}if(!m){p=g;gGC(p|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=l;c[2417276]=n;c[1836236]=-1;c[2113016]=1024;c[3531920]=c[2411412];c[3531918]=c[2406888];UL(35e5,1078,3456,0);c[2438224]=35e5;c[2433522]=3416;c[2406672]=1752;c[3528468]=9362;c[2443842]=584;h[745398]=1.0;a[3203264]=1;a[7072688]=1;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];p=c[3532592]|0;if((p|0)!=0){gGC(9104152,p|0,280)|0}c[2113054]=c[2113060]}RI();p=c[2394]|0;q=c[14130368+(p<<2)>>2]|0;if((q|0)!=0){gGC(q|0,9104152,280)|0}c[8452240+(p<<2)>>2]=c[2113054];c[2394]=-1;p=c[2439330]|0;q=(p|0)==0;if(!q){r=p;gGC(9706056,r|0,76)|0}r=c[2438118]|0;c[2433530]=r;s=c[3528484]|0;c[2076596]=s;z=c[2417276]|0;c[3541536]=z;c[1836236]=0;gGz(9706056,0,76);if(!q){q=p;gGC(q|0,9706056,76)|0}c[2438118]=r;c[3528484]=s;c[2417276]=z;c[1836236]=-1;c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;lw(c[3540984]|0);a[9722072]=0;A=0;i=d;return A|0}}while(0);c[2426662]=0;A=1;i=d;return A|0}function flf(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=a[7452584]|0;if(b){d=0;e=b&1;while(1){b=14163936+(d<<2)|0;f=c[b>>2]|0;g=c[2113006]|0;if((g|0)==0){h=60019}else{i=g-1|0;c[2113006]=i;if((i|0)==0){h=60019}}if((h|0)==60019){h=0;c[2383474]=0}if((f|0)==0){j=e}else{gGr(f);j=a[7452584]&1}c[b>>2]=0;b=d+1|0;if((b|0)<(j|0)){d=b;e=j}else{break}}}a[7452584]=0;c[2438224]=0;c[2433522]=0;c[2406672]=0;c[3528468]=0;j=c[2406688]|0;if((j|0)!=0){gGr(j);c[2406688]=0}c[2432972]=0;fpB();fwZ();if((c[2392]|0)>=0){j=0;do{e=14130368+(j<<2)|0;d=c[e>>2]|0;if((d|0)!=0){gGr(d);c[e>>2]=0}e=14130384+(j<<2)|0;d=c[e>>2]|0;if((d|0)!=0){gGr(d);c[e>>2]=0}j=j+1|0;}while((j|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;j=c[2426662]|0;e=0;while(1){if((e|0)>=1024){h=60036;break}k=9638528+(e<<2)|0;if((c[k>>2]|0)==(j|0)){break}else{e=e+1|0}}if((h|0)==60036){c[2426662]=0;a[7461832]=0;return 0}gGr(j);c[k>>2]=0;c[2426662]=0;a[7461832]=0;return 0}function flg(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;if((a[9623616]|0)!=0){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=i;c[1836236]=-1;c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;lw(c[3540984]|0);a[9722072]=0}a[9625512]=0;a[9625513]=0;a[9625516]=0;i=0;g=0;f=0;e=0;do{g=((a[9632648+i|0]&1)<<i|g&255)&255;f=((a[9630552+i|0]&1)<<i|f&255)&255;e=((a[9551736+i|0]&1)<<i|e&255)&255;i=i+1|0;}while((i|0)<8);a[9625512]=g;a[9625513]=f;a[9625516]=e;if((g&3)==3){e=g&-4;a[9625512]=e;j=e}else{j=g}if((j&12)==12){a[9625512]=j&-13}if((f&3)==3){j=f&-4;a[9625513]=j;k=j}else{k=f}if((k&12)==12){a[9625513]=k&-13}k=c[2392]|0;if((k|0)>=0){gGz(8452240,0,((k|0)>0?(k<<2)+4|0:4)|0)}c[2113054]=0;k=c[2385548]|0;if((k|0)>0){gGz(9752472,0,((k|0)>1?k<<2:4)|0)}c[2433530]=0;if((c[2394]|0)==0){l=0}else{c[2394]=0;c[2112932]=c[3532596];k=c[3532592]|0;if((k|0)!=0){gGC(9104152,k|0,280)|0}k=c[2113060]|0;c[2113054]=k;l=k}k=c[2439330]|0;if((k|0)!=0){f=k;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;f=c[2438118]|0;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;c[2113054]=l+(c[2113220]|0);c[2433530]=f+(c[2113221]|0);f=c[2438]|0;l=gGU(f,(f|0)<0|0?-1:0,1e7,0)|0;f=gGS(l,K,15360,0)|0;l=f;c[2113218]=l;c[2113216]=58333;c[2113058]=(l|0)/262|0;f=l-((l*22|0|0)/262|0)|0;c[2113018]=f;k=0;j=l;l=f;while(1){f=k+1|0;g=(ag(f,j)|0)/4|0;do{if((g|0)>(l|0)){e=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;if((e|0)<(l|0)){i=l-e|0;c[2113056]=i;e=RG(i)|0;c[2113054]=(c[2113054]|0)+e;c[2276108]=-1;c[2113056]=-1}e=c[2112968]|0;do{if((e|0)!=0){i=c[3531916]|0;d=c[2113308]|0;do{if((c[i>>2]|0)==0){gGz(e|0,0,d*76800|0|0)}else{if((d|0)==4){m=c[i+1152>>2]|0;n=0;o=e;while(1){c[o>>2]=m;c[o+4>>2]=m;c[o+8>>2]=m;c[o+12>>2]=m;c[o+16>>2]=m;c[o+20>>2]=m;c[o+24>>2]=m;c[o+28>>2]=m;p=n+1|0;if((p|0)<9600){n=p;o=o+32|0}else{break}}}else if((d|0)==3){o=c[i+1152>>2]|0;n=o>>>8&255;m=o>>>16&255;p=o&255;o=e;q=0;while(1){a[o]=p;a[o+1|0]=n;a[o+2|0]=m;r=q+1|0;if((r|0)<76800){o=o+3|0;q=r}else{break}}}else if((d|0)==2){q=c[i+1152>>2]|0;o=q<<16|q;q=e;m=0;while(1){c[q>>2]=o;c[q+4>>2]=o;c[q+8>>2]=o;c[q+12>>2]=o;c[q+16>>2]=o;c[q+20>>2]=o;c[q+24>>2]=o;c[q+28>>2]=o;n=m+1|0;if((n|0)<4800){q=q+32|0;m=n}else{break}}}else{break}}}while(0);if(a[7072688]|0){c[2112970]=e;c[2113306]=d;c[2113298]=c[2113300];fpz();s=c[3531916]|0}else{s=i}c[2112966]=s;m=c[2113016]|0;if((m|0)>0){t=0}else{break}do{c[s+(t<<2)>>2]=65535;t=t+1|0;}while((t|0)<(m|0));i=c[3531914]|0;d=0;do{c[i+(d<<2)>>2]=65535;d=d+1|0;}while((d|0)<(m|0))}}while(0);e=c[2430400]|0;m=c[3541524]|0;gGC(e|0,m|0,2048)|0;if((a[9722072]&1)==0){break}c[8452200+(c[2394]<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0>=1024){break}RH(4)}}while(0);m=g-(c[2113054]|0)-(c[2113056]|0)+(c[2276108]|0)|0;c[2113056]=m;e=RG(m)|0;c[2113054]=(c[2113054]|0)+e;c[2276108]=-1;c[2113056]=-1;UF(ag((c[2113216]|0)/4|0,k)|0)|0;if((f|0)>=4){break}k=f;j=c[2113218]|0;l=c[2113018]|0}l=c[2113216]|0;j=gGU(l,(l|0)<0|0?-1:0,2048e6,0)|0;k=c[2438224]|0;t=gGS(j,K,k,(k|0)<0|0?-1:0)|0;k=t;UF(l)|0;l=c[2443826]|0;if((l|0)<1073676288){c[2443826]=l-k}l=c[2443827]|0;if((l|0)<1073676288){c[2443827]=l-k}l=(c[3528508]|0)-k|0;c[3528508]=(l|0)<0?0:l;l=c[2112964]|0;if((l|0)!=0){gg[c[3542112]&4095](l,a[9688]|0?534:0)}l=c[2113054]|0;c[2113220]=(c[2113056]|0)+l-(c[2276108]|0)-(c[2113218]|0);k=c[2433530]|0;t=c[2076596]|0;c[2113221]=(c[2426530]|0)+k-t-(c[2113216]|0);j=c[1836236]|0;s=c[9757320+(j<<2)>>2]|0;if((s|0)!=0){e=s;gGC(e|0,9706056,76)|0}c[9752472+(j<<2)>>2]=k;c[14113936+(j<<2)>>2]=t;c[9669104+(j<<2)>>2]=c[3541536];c[1836236]=-1;j=c[2394]|0;t=c[14130368+(j<<2)>>2]|0;if((t|0)==0){u=8452240+(j<<2)|0;c[u>>2]=l;c[2394]=-1;return 0}gGC(t|0,9104152,280)|0;u=8452240+(j<<2)|0;c[u>>2]=l;c[2394]=-1;return 0}function flh(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=c[3531916]|0;do{if((c[b>>2]|0)==0){d=c[2113308]|0;gGz(c[2112968]|0,0,d*76800|0|0);e=d}else{d=c[2113308]|0;if((d|0)==3){f=c[b+1152>>2]|0;g=f>>>8&255;h=f>>>16&255;i=f&255;f=c[2112968]|0;j=0;while(1){a[f]=i;a[f+1|0]=g;a[f+2|0]=h;k=j+1|0;if((k|0)<76800){f=f+3|0;j=k}else{e=3;break}}}else if((d|0)==2){j=c[b+1152>>2]|0;f=j<<16|j;j=c[2112968]|0;h=0;while(1){c[j>>2]=f;c[j+4>>2]=f;c[j+8>>2]=f;c[j+12>>2]=f;c[j+16>>2]=f;c[j+20>>2]=f;c[j+24>>2]=f;c[j+28>>2]=f;g=h+1|0;if((g|0)<4800){j=j+32|0;h=g}else{e=2;break}}}else if((d|0)==4){h=c[b+1152>>2]|0;j=0;f=c[2112968]|0;while(1){c[f>>2]=h;c[f+4>>2]=h;c[f+8>>2]=h;c[f+12>>2]=h;c[f+16>>2]=h;c[f+20>>2]=h;c[f+24>>2]=h;c[f+28>>2]=h;g=j+1|0;if((g|0)<9600){j=g;f=f+32|0}else{e=4;break}}}else{e=d;break}}}while(0);if(a[7072688]|0){c[2112970]=c[2112968];c[2113306]=e;c[2113298]=c[2113300];fpz();l=c[3531916]|0}else{l=b}c[2112966]=l;b=c[2113016]|0;if((b|0)>0){m=0}else{return 0}do{c[l+(m<<2)>>2]=65535;m=m+1|0;}while((m|0)<(b|0));m=c[3531914]|0;l=0;do{c[m+(l<<2)>>2]=65535;l=l+1|0;}while((l|0)<(b|0));return 0}function fli(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=i;i=i+96|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;l=e+80|0;if((d|0)!=0){c[d>>2]=168962}if((b&96|0)==0){i=e;return 0}gGz(l|0,0,12);m=c[2405600]|0;c[l>>2]=m;c[l+4>>2]=(c[2411512]|0)-m;c[l+12>>2]=219592;gj[c[2076592]&4095](l)|0;l=h|0;do{if((b&64|0)!=0){gGz(g|0,0,16);c[2394]=-1;if((c[2392]|0)<0){break}m=h+9|0;n=f;o=f|0;p=f+4|0;q=f+12|0;r=g|0;s=g+4|0;t=g+12|0;u=0;do{gGC(l|0,614896,11)|0;a[m]=u+48&255;v=8452256+(u<<2)|0;gGz(n|0,0,12);c[o>>2]=v;c[p>>2]=4;c[q>>2]=164976;gj[c[2076592]&4095](f)|0;if((c[v>>2]|0)!=0){c[r>>2]=c[14130368+(u<<2)>>2];c[s>>2]=c[8452184+(u<<2)>>2];c[t>>2]=l;v=c[2076592]|0;gj[v&4095](g)|0}u=u+1|0;}while((u|0)<=(c[2392]|0))}}while(0);fw$(b);UQ(b,d);gGz(k|0,0,12);c[k>>2]=9625512;c[k+4>>2]=6;c[k+12>>2]=215728;gj[c[2076592]&4095](k)|0;gGz(j|0,0,12);c[j>>2]=8452880;c[j+4>>2]=8;c[j+12>>2]=212472;gj[c[2076592]&4095](j)|0;i=e;return 0}function flj(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2775220+(b*112|0)>>2];c[a+104>>2]=c[2775224+(b*112|0)>>2];c[a+108>>2]=c[2775228+(b*112|0)>>2];d=0;return d|0}function flk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=2775120+(b*112|0);e=0;return e|0}function fll(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>49){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=2776576+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function flm(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2773764+(b*112|0)>>2];c[a+104>>2]=c[2773768+(b*112|0)>>2];c[a+108>>2]=c[2773772+(b*112|0)>>2];d=0;return d|0}function fln(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=2773664+(b*112|0);e=0;return e|0}function flo(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2772308+(b*112|0)>>2];c[a+104>>2]=c[2772312+(b*112|0)>>2];c[a+108>>2]=c[2772316+(b*112|0)>>2];d=0;return d|0}function flp(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=2772208+(b*112|0);e=0;return e|0}function flq(a){a=a|0;var b=0,d=0,e=0;b=a&255;if((b|0)==72){d=c[3528516]&255;return d|0}else if((b|0)==129){a=c[2113010]|0;c[2113010]=0;c[2430402]=0;e=c[3531294]|0;if((e|0)!=0){gf[e&2047](0)}d=a&255;return d|0}else if((b|0)==74){d=c[3528517]&255;return d|0}else{d=0;return d|0}return 0}function flr(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;e=b&255;if((e|0)==129){Ui(d);return}else if((e|0)==64){b=a[9752568]|0;do{if((b&1)==0){if(((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)<=(c[2438214]|0)){f=b;break}gu[c[3528472]&16383]();c[2443838]=0;f=a[9752568]|0}else{f=b}}while(0);a[9752568]=f|1;c[3528518]=d&255;return}else if((e|0)==128){c[2113012]=d&255;return}else if((e|0)==66){e=a[9752568]|0;do{if((e&2)==0){if(((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)<=(c[2438214]|0)){g=e;break}gu[c[3528472]&16383]();c[2443838]=0;g=a[9752568]|0}else{g=e}}while(0);a[9752568]=g|2;c[3528519]=d&255;return}else{return}}function fls(b){b=b|0;var d=0,e=0;switch(b|0){case 5242885:{d=a[9625507]|0;break};case 5242883:{d=a[9625506]|0;break};case 5242905:{do{if((c[2406632]|0)==0){b=c[2443744]|0;if((b|0)<=0){e=16;break}c[2443744]=b-1;e=0}else{e=(c[2432962]|0)>>>((c[(c[2420380]|0)+4>>2]|0)>>>0)<<4&16}}while(0);d=((c[2405142]|0)>>>4|e)&255;break};case 5242880:{d=a[9625505]|0;break};case 5242884:{d=a[9625508]|0;break};case 5242899:{d=c[3528519]&255;break};case 5242897:{d=c[3528518]&255;break};case 5242881:{d=a[9625504]|0;break};case 5242882:{d=a[9625509]|0;break};default:{d=0}}return d|0}function flt(b){b=b|0;var d=0,e=0,f=0,g=0;if((b|0)==5242886){d=((c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0)/(c[2113058]|0)|0;if((d|0)==(c[2384352]|0)){e=65024}else{c[2384352]=d;e=32256}f=(e|d)&65535;return f|0}else if((b|0)==5242904){do{if((c[2406632]|0)==0){d=c[2443744]|0;if((d|0)<=0){g=16;break}c[2443744]=d-1;g=0}else{g=(c[2432962]|0)>>>((c[(c[2420380]|0)+4>>2]|0)>>>0)<<4&16}}while(0);f=((c[2405142]|0)>>>4|g)&65535;return f|0}else if((b|0)==5242898){do{if((a[9752568]&2)==0){g=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;d=c[2113216]|0;e=gGU(g,(g|0)<0|0?-1:0,d,(d|0)<0|0?-1:0)|0;d=c[2113218]|0;g=gGS(e,K,d,(d|0)<0|0?-1:0)|0;d=gGK(g,K,256,0)|0;g=d;if((g|0)<=((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)){break}c[2438214]=g-256;Sb(g)}}while(0);f=c[3528519]&65535;return f|0}else if((b|0)==5242896){do{if((a[9752568]&1)==0){b=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;g=c[2113216]|0;d=gGU(b,(b|0)<0|0?-1:0,g,(g|0)<0|0?-1:0)|0;g=c[2113218]|0;b=gGS(d,K,g,(g|0)<0|0?-1:0)|0;g=gGK(b,K,256,0)|0;b=g;if((b|0)<=((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)){break}c[2438214]=b-256;Sb(b)}}while(0);f=c[3528518]&65535;return f|0}else{f=0;return f|0}return 0}function flu(a,b){a=a|0;b=b|0;if((a|0)!=5242911){return}a=b&255;c[2405142]=a&16;c[2415256]=a&4;b=a&1;c[3528406]=b^1;if((b|0)==0){c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2]}Tr(a>>>3&1);return}function flv(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0;switch(b|0){case 5242902:{a[9752568]=a[9752568]&-3;c[3528517]=d&65535;return};case 5243008:{if((c[2438132]|0)==0){return}e=c[3541534]|0;f=c[2112932]|0;c[f+8192>>2]=e;c[f+73728>>2]=e;c[f+139264>>2]=e;g=e+1024|0;c[f+8196>>2]=g;c[f+73732>>2]=g;c[f+139268>>2]=g;g=e+2048|0;c[f+8200>>2]=g;c[f+73736>>2]=g;c[f+139272>>2]=g;g=e+3072|0;c[f+8204>>2]=g;c[f+73740>>2]=g;c[f+139276>>2]=g;g=e+4096|0;c[f+8208>>2]=g;c[f+73744>>2]=g;c[f+139280>>2]=g;g=e+5120|0;c[f+8212>>2]=g;c[f+73748>>2]=g;c[f+139284>>2]=g;g=e+6144|0;c[f+8216>>2]=g;c[f+73752>>2]=g;c[f+139288>>2]=g;g=e+7168|0;c[f+8220>>2]=g;c[f+73756>>2]=g;c[f+139292>>2]=g;g=c[2411410]|0;c[f+8224>>2]=g;c[f+73760>>2]=g;c[f+139296>>2]=g;e=g+1024|0;c[f+8228>>2]=e;c[f+73764>>2]=e;c[f+139300>>2]=e;e=g+2048|0;c[f+8232>>2]=e;c[f+73768>>2]=e;c[f+139304>>2]=e;e=g+3072|0;c[f+8236>>2]=e;c[f+73772>>2]=e;c[f+139308>>2]=e;e=c[2418242]|0;g=f+8240|0;f=2109440;while(1){h=e+(f-2109440)|0;c[g>>2]=h;c[g+65536>>2]=h;c[g+131072>>2]=h;h=f+1024|0;if(h>>>0>2129919){break}else{g=g+4|0;f=h}}c[2438132]=0;return};case 5242910:{f=d&65535;c[2405142]=f&16;c[2415256]=f&4;g=f&1;c[3528406]=g^1;if((g|0)==0){c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2]}Tr(f>>>3&1);return};case 5243010:{c[8452200+(c[2394]<<2)>>2]=0;c[2276080]=0;a[9775624]=0;return};case 5242906:{f=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;g=c[2113216]|0;e=gGU(f,(f|0)<0|0?-1:0,g,(g|0)<0|0?-1:0)|0;g=c[2113218]|0;f=gGS(e,K,g,(g|0)<0|0?-1:0)|0;g=f;if((g|0)>((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)){c[2438214]=g;Sb(g)}if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12;return};case 5243086:case 5243072:case 5243073:case 5243074:case 5243075:case 5243076:case 5243077:case 5243078:case 5243079:case 5243080:case 5243081:case 5243082:case 5243083:case 5243084:case 5243085:{c[14165960+((b>>>1&7)<<2)>>2]=(d&65535)<<15&491520;return};case 5242900:{a[9752568]=a[9752568]&-2;c[3528516]=d&65535;return};default:{return}}}function flw(a){a=a|0;var d=0;if((a|0)==4194314){d=b[(c[3541508]|0)+2>>1]|0}else if((a|0)==4194312){d=b[c[3541508]>>1]|0}else{d=0}return d|0}function flx(a,d){a=a|0;d=d|0;switch(a|0){case 4194308:{c[3541498]=d&255;return};case 4194316:{c[3541508]=(c[3541506]|0)+((d&65535)<<1&16382);return};case 4194304:{b[(c[3541500]|0)+(c[3541498]<<1)>>1]=d;return};case 4194312:case 4194314:{b[c[3541508]>>1]=d;c[3541508]=(c[3541508]|0)+2;return};default:{return}}}function fly(b){b=b|0;return a[(c[3532626]|0)+(b>>>1&262143)|0]|0}function flz(a){a=a|0;return d[(c[3532626]|0)+(a>>>1&262143)|0]|0|0}function flA(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4803684+(b*112|0)>>2];c[a+104>>2]=c[4803688+(b*112|0)>>2];c[a+108>>2]=c[4803692+(b*112|0)>>2];d=0;return d|0}function flB(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=4803584+(b*112|0);e=0;return e|0}function flC(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>24){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1170840+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function flD(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=94){if((a|0)==0){d=0;return d|0}e=a;f=3104664+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}f=b-95|0;if(f>>>0>27){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;a=724632+(f*12|0)|0;c[b>>2]=c[a>>2];c[b+4>>2]=c[a+4>>2];c[b+8>>2]=c[a+8>>2];d=0;return d|0}function flE(){var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;d=i;i=i+600|0;e=d|0;f=d+112|0;g=d+120|0;j=d+232|0;k=d+240|0;l=d+352|0;m=d+360|0;n=d+472|0;o=d+480|0;p=d+592|0;c[2113208]=16777216;c[2426660]=0;c[2418128]=0;c[3532626]=2097152;c[3541502]=2228224;c[3531292]=19005440;c[2439990]=31588352;c[2405598]=31588864;c[3541532]=31588864;c[3541534]=31621632;c[2418242]=31629824;c[2418198]=31650304;c[2411410]=31683072;c[3532636]=31687168;c[3541506]=31703552;c[3541500]=31719936;c[2411510]=31720448;c[3531916]=31720448;c[3541528]=31629824;c[3541530]=31630336;q=0;while(1){if((q|0)>=1024){break}r=9638528+(q<<2)|0;if((c[r>>2]|0)==0){s=60333;break}else{q=q+1|0}}do{if((s|0)==60333){q=gGq(31728640)|0;c[r>>2]=q;if((q|0)==0){break}c[2426660]=q;gGz(q|0,0,31728640);c[2418128]=q;c[3532626]=q+2097152;c[3541502]=q+2228224;t=c[2113208]|0;c[3531292]=q+(t+2228224);c[2439990]=q+(t+14811136);u=q+(t+14811648)|0;c[2405598]=u;c[3541532]=u;c[3541534]=q+(t+14844416);u=q+(t+14852608)|0;c[2418242]=u;c[2418198]=q+(t+14873088);c[2411410]=q+(t+14905856);c[3532636]=q+(t+14909952);c[3541506]=q+(t+14926336);c[3541500]=q+(t+14942720);v=q+(t+14943232)|0;c[2411510]=v;c[3531916]=v;c[2414050]=q+(t+14951424);c[3541528]=u;c[3541530]=q+(t+14853120);if((fpk(q,4)|0)!=0){w=1;i=d;return w|0}fpl(c[3541502]|0,4,4,c[2113208]|0,0);q=c[3532626]|0;do{if((c[3542200]|0)!=0){t=o+108|0;c[t>>2]=0;u=o+100|0;c[u>>2]=0;v=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[v&16383](o,8)|0;if((c[t>>2]|0)==0){break}t=c[u>>2]|0;c[p>>2]=9534384;u=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[u&16383](p,8,0)|0;if((t|0)<1){break}gzL(q,0,8)|0}}while(0);q=c[3531292]|0;do{if((c[3542200]|0)!=0){t=m+108|0;c[t>>2]=0;u=m+100|0;c[u>>2]=0;v=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[v&16383](m,9)|0;if((c[t>>2]|0)==0){break}t=c[u>>2]|0;c[n>>2]=9534384;u=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[u&16383](n,9,0)|0;if((t|0)<1){break}gzL(q,0,9)|0}}while(0);q=(c[3531292]|0)+4194304|0;do{if((c[3542200]|0)!=0){t=k+108|0;c[t>>2]=0;u=k+100|0;c[u>>2]=0;v=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[v&16383](k,10)|0;if((c[t>>2]|0)==0){break}t=c[u>>2]|0;c[l>>2]=9534384;u=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[u&16383](l,10,0)|0;if((t|0)<1){break}gzL(q,0,10)|0}}while(0);q=(c[3531292]|0)+8388608|0;do{if((c[3542200]|0)!=0){t=g+108|0;c[t>>2]=0;u=g+100|0;c[u>>2]=0;v=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[v&16383](g,11)|0;if((c[t>>2]|0)==0){break}t=c[u>>2]|0;c[j>>2]=9534384;u=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[u&16383](j,11,0)|0;if((t|0)<1){break}gzL(q,0,11)|0}}while(0);q=c[2439990]|0;do{if((c[3542200]|0)!=0){t=e+108|0;c[t>>2]=0;u=e+100|0;c[u>>2]=0;v=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[v&16383](e,12)|0;if((c[t>>2]|0)==0){break}t=c[u>>2]|0;c[f>>2]=9534384;u=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[u&16383](f,12,0)|0;if((t|0)<1){break}gzL(q,0,12)|0}}while(0);Tq(689416);if(!(a[1040128]|0)){q=c[2439990]|0;gGC(14100392,q|0,512)|0}fxU(0,425984);if((c[2394]|0)==0){x=c[2112932]|0}else{c[2394]=0;q=c[3532596]|0;c[2112932]=q;t=c[3532592]|0;if((t|0)!=0){gGC(9104152,t|0,280)|0}c[2113054]=c[2113060];x=q}q=c[2418128]|0;t=x|0;u=0;while(1){v=q+u|0;c[t>>2]=v;c[t+131072>>2]=v;v=u+1024|0;if(v>>>0>2097151){break}else{t=t+4|0;u=v}}u=c[2418198]|0;t=x+8320|0;q=2129920;while(1){v=u+(q-2129920)|0;c[t>>2]=v;c[t+65536>>2]=v;c[t+131072>>2]=v;v=q+1024|0;if(v>>>0>2162687){break}else{t=t+4|0;q=v}}if((c[2438132]|0)!=1){q=c[3541532]|0;t=x+8192|0;u=2097152;while(1){v=q+(u-2097152)|0;c[t>>2]=v;c[t+65536>>2]=v;c[t+131072>>2]=v;v=u+1024|0;if(v>>>0>2129919){break}else{t=t+4|0;u=v}}c[2438132]=1}c[x+196688>>2]=236;c[x+196608>>2]=2010;c[x+196728>>2]=958;c[x+196648>>2]=2768;c[x+16384>>2]=1;c[x+81920>>2]=1;c[x+147456>>2]=1;c[x+16388>>2]=1;c[x+81924>>2]=1;c[x+147460>>2]=1;c[x+196692>>2]=1030;c[x+196732>>2]=1680;u=x+12288|0;t=3145728;while(1){c[u>>2]=2;c[u+131072>>2]=2;q=t+1024|0;if(q>>>0>3670015){break}else{u=u+4|0;t=q}}c[x+196616>>2]=3360;c[x+196696>>2]=550;t=c[3532592]|0;if((t|0)!=0){gGC(t|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;c[2113040]=1;c[2113182]=-470;c[2113178]=-472;c[2113174]=-474;fl6(1);c[2408]=44;fwR(0);t=c[2439330]|0;u=(t|0)==0;if(!u){q=t;gGC(9706056,q|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];q=c[3528484]|0;c[2076596]=q;v=c[2417276]|0;c[3541536]=v;c[1836236]=0;c[t+4172>>2]=1066;c[t+4176>>2]=842;y=c[3532626]|0;z=0;A=0;while(1){c[t+76+(A<<2)>>2]=y+(A<<8);B=z+1&65535;if((B&65535)>191){C=0;D=0;break}else{z=B;A=B&65535}}while(1){A=y+(D<<8)|0;c[t+76+(D+512<<2)>>2]=A;c[t+76+(D+768<<2)>>2]=A;A=C+1&65535;if((A&65535)>191){break}else{C=A;D=A&65535}}y=c[3532636]|0;A=192;z=192;while(1){c[t+76+(z<<2)>>2]=y+((z<<8)-49152);B=A+1&65535;if((B&65535)>255){E=192;F=192;break}else{A=B;z=B&65535}}while(1){c[t+76+(F+256<<2)>>2]=y+((F<<8)-49152);z=E+1&65535;if((z&65535)>255){G=192;H=192;break}else{E=z;F=z&65535}}while(1){z=y+((H<<8)-49152)|0;c[t+76+(H+512<<2)>>2]=z;c[t+76+(H+768<<2)>>2]=z;z=G+1&65535;if((z&65535)>255){break}else{G=z;H=z&65535}}if(!u){y=t;gGC(y|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=q;c[2417276]=v;c[1836236]=-1;Uf(16934400,0);h[607287]=1.0;c[2433116]=3;h[607286]=1.0;c[2433114]=3;c[2429844]=5470;c[2429842]=80;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;c[2438228]=4e6;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=511;c[2113016]=2048;c[3531920]=c[2411410];c[2438132]=-1;a[7072680]=1;flO();w=0;i=d;return w|0}}while(0);c[2426660]=0;w=1;i=d;return w|0}function flF(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;i=i+128|0;d=b|0;c[2438228]=0;c[2433526]=0;c[2406676]=0;c[3528472]=0;e=c[2406694]|0;if((e|0)!=0){gGr(e);c[2406694]=0}c[3531294]=0;fl7();c[2408]=39321;fwZ();if((c[2392]|0)>=0){e=0;do{f=14130368+(e<<2)|0;g=c[f>>2]|0;if((g|0)!=0){gGr(g);c[f>>2]=0}f=14130384+(e<<2)|0;g=c[f>>2]|0;if((g|0)!=0){gGr(g);c[f>>2]=0}e=e+1|0;}while((e|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;e=d|0;d=c[c[642608+(c[2436]<<2)>>2]>>2]|0;be(e|0,128,179600,(f=i,i=i+24|0,c[f>>2]=9374064,c[f+8>>2]=47,c[f+16>>2]=d,f)|0)|0;i=f;a[1040128]=0;f=c[2420380]|0;d=c[f>>2]|0;g=c[f+4>>2]|0;f=fw(e|0,389440)|0;if((f|0)!=0){e=g>>3<<d&1023;cj(14100392,e|0,1,f|0)|0;aY(f|0)|0}f=c[2426660]|0;e=0;while(1){if((e|0)>=1024){h=60406;break}j=9638528+(e<<2)|0;if((c[j>>2]|0)==(f|0)){break}else{e=e+1|0}}if((h|0)==60406){c[2426660]=0;i=b;return 0}gGr(f);c[j>>2]=0;c[2426660]=0;i=b;return 0}function flG(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;if((a[9623608]|0)!=0){flO()}a[9625504]=0;a[9625505]=0;a[9625506]=0;d=0;e=0;f=0;g=0;do{e=((a[9632640+d|0]&1)<<d|e&255)&255;f=((a[9630544+d|0]&1)<<d|f&255)&255;g=((a[9551728+d|0]&1)<<d|g&255)&255;d=d+1|0;}while((d|0)<8);a[9625504]=e;a[9625505]=f;a[9625506]=g;if((e&3)==3){g=e&-4;a[9625504]=g;h=g}else{h=e}if((h&12)==12){a[9625504]=h&-13}if((f&3)==3){h=f&-4;a[9625505]=h;i=h}else{i=f}if((i&12)==12){a[9625505]=i&-13}i=c[2392]|0;if((i|0)>=0){gGz(8452240,0,((i|0)>0?(i<<2)+4|0:4)|0)}c[2113054]=0;i=c[2385548]|0;if((i|0)>0){gGz(9752472,0,((i|0)>1?i<<2:4)|0)}c[2433530]=0;i=c[2438]|0;f=gGU(i,(i|0)<0|0?-1:0,16e6,0)|0;i=gGS(f,K,15360,0)|0;f=i;c[2113218]=f;c[2113216]=66666;if((c[2394]|0)==0){j=0}else{c[2394]=0;c[2112932]=c[3532596];i=c[3532592]|0;if((i|0)!=0){gGC(9104152,i|0,280)|0}i=c[2113060]|0;c[2113054]=i;j=i}c[2113058]=(f|0)/262|0;i=f-((f*22|0|0)/262|0)|0;c[2113018]=i;a[670640]=0;h=c[2439330]|0;if((h|0)!=0){e=h;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;e=c[2438118]|0;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;c[2113054]=j+(c[2113220]|0);c[2433530]=e+(c[2113221]|0);e=1;j=0;h=f;f=1;g=i;while(1){i=(ag(h,e)|0)/8|0;if((i|0)>(g|0)&f){d=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;if((d|0)<(g|0)){k=g-d|0;c[2113056]=k;d=RG(k)|0;c[2113054]=(c[2113054]|0)+d;c[2276108]=-1;c[2113056]=-1}a[9775624]=1;c[8452200+(c[2394]<<2)>>2]=4099;c[2276080]=768;if((c[2276079]|0)>>>0<768){RH(3)}d=c[2430398]|0;k=c[2439196]|0;l=k<<11;c[2438976]=d+l;m=(c[2440572]|0)>1;if(m){c[2438977]=(c[2430399]|0)+l}l=k^1;c[2439196]=l;k=l<<11;l=d+k|0;d=(c[3541506]|0)+12288|0;gGC(l|0,d|0,2048)|0;if(m){m=(c[2430399]|0)+k|0;k=(c[3541504]|0)+12288|0;gGC(m|0,k|0,2048)|0}k=c[2112968]|0;do{if((k|0)!=0){m=c[3531916]|0;d=c[m>>2]|0;l=c[2113308]|0;do{if((d|0)==0){gGz(k|0,0,l*76800|0|0)}else{if((l|0)==4){n=0;o=k;while(1){c[o>>2]=d;c[o+4>>2]=d;c[o+8>>2]=d;c[o+12>>2]=d;c[o+16>>2]=d;c[o+20>>2]=d;c[o+24>>2]=d;c[o+28>>2]=d;p=n+1|0;if((p|0)<9600){n=p;o=o+32|0}else{break}}}else if((l|0)==3){o=d>>>8&255;n=d>>>16&255;p=d&255;q=k;r=0;while(1){a[q]=p;a[q+1|0]=o;a[q+2|0]=n;s=r+1|0;if((s|0)<76800){q=q+3|0;r=s}else{break}}}else if((l|0)==2){r=d<<16|d;q=k;n=0;while(1){c[q>>2]=r;c[q+4>>2]=r;c[q+8>>2]=r;c[q+12>>2]=r;c[q+16>>2]=r;c[q+20>>2]=r;c[q+24>>2]=r;c[q+28>>2]=r;o=n+1|0;if((o|0)<4800){q=q+32|0;n=o}else{break}}}else{break}}}while(0);if(a[7072680]|0){c[2112970]=k;c[2113306]=l;c[2113298]=c[2113300];fl3();fnZ();t=c[3531916]|0}else{t=m}c[2112966]=t;d=c[2113016]|0;if((d|0)>0){u=0}else{break}do{c[t+(u<<2)>>2]=65535;u=u+1|0;}while((u|0)<(d|0))}}while(0);a[670640]=1}k=i-(c[2113054]|0)-(c[2113056]|0)+(c[2276108]|0)|0;c[2113056]=k;d=RG(k)|0;c[2113054]=(c[2113054]|0)+d;c[2276108]=-1;c[2113056]=-1;d=c[2112964]|0;if((e&1|0)==0&(d|0)!=0){k=(ag(a[9688]|0?534:0,e)|0)/8|0;Ug(d+(j<<1<<1)|0,k-j|0);v=k}else{v=j}k=e+1|0;if((k|0)>=9){break}e=k;j=v;h=c[2113218]|0;f=a[670640]^1;g=c[2113018]|0}c[2438214]=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0);g=c[2113216]|0;f=gGU(g,(g|0)<0|0?-1:0,2048e6,0)|0;h=c[2438228]|0;j=gGS(f,K,h,(h|0)<0|0?-1:0)|0;h=j;Sb(g);g=c[2443830]|0;if((g|0)<1073676288){c[2443830]=g-h}g=c[2443831]|0;if((g|0)<1073676288){c[2443831]=g-h}g=(c[3528512]|0)-h|0;c[3528512]=(g|0)<0?0:g;g=c[2113054]|0;c[2113220]=(c[2113056]|0)+g-(c[2276108]|0)-(c[2113218]|0);c[2113221]=(c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)-(c[2113216]|0);h=c[2394]|0;j=c[14130368+(h<<2)>>2]|0;if((j|0)!=0){gGC(j|0,9104152,280)|0}c[8452240+(h<<2)>>2]=g;c[2394]=-1;g=c[2112964]|0;do{if((g|0)!=0){h=a[9688]|0?534:0;if((h|0)==(v|0)){break}Ug(g+(v<<1<<1)|0,h-v|0)}}while(0);v=c[1836236]|0;g=c[9757320+(v<<2)>>2]|0;if((g|0)==0){w=c[2433530]|0;x=9752472+(v<<2)|0;c[x>>2]=w;y=c[2076596]|0;z=14113936+(v<<2)|0;c[z>>2]=y;A=c[3541536]|0;B=9669104+(v<<2)|0;c[B>>2]=A;c[1836236]=-1;return 0}h=g;gGC(h|0,9706056,76)|0;w=c[2433530]|0;x=9752472+(v<<2)|0;c[x>>2]=w;y=c[2076596]|0;z=14113936+(v<<2)|0;c[z>>2]=y;A=c[3541536]|0;B=9669104+(v<<2)|0;c[B>>2]=A;c[1836236]=-1;return 0}function flH(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[3531916]|0;d=c[b>>2]|0;do{if((d|0)==0){e=c[2113308]|0;gGz(c[2112968]|0,0,e*76800|0|0);f=e}else{e=c[2113308]|0;if((e|0)==2){g=d<<16|d;h=c[2112968]|0;i=0;while(1){c[h>>2]=g;c[h+4>>2]=g;c[h+8>>2]=g;c[h+12>>2]=g;c[h+16>>2]=g;c[h+20>>2]=g;c[h+24>>2]=g;c[h+28>>2]=g;j=i+1|0;if((j|0)<4800){h=h+32|0;i=j}else{f=2;break}}}else if((e|0)==4){i=0;h=c[2112968]|0;while(1){c[h>>2]=d;c[h+4>>2]=d;c[h+8>>2]=d;c[h+12>>2]=d;c[h+16>>2]=d;c[h+20>>2]=d;c[h+24>>2]=d;c[h+28>>2]=d;g=i+1|0;if((g|0)<9600){i=g;h=h+32|0}else{f=4;break}}}else if((e|0)==3){h=d>>>8&255;i=d>>>16&255;g=d&255;j=c[2112968]|0;k=0;while(1){a[j]=g;a[j+1|0]=h;a[j+2|0]=i;l=k+1|0;if((l|0)<76800){j=j+3|0;k=l}else{f=3;break}}}else{f=e;break}}}while(0);if(a[7072680]|0){c[2112970]=c[2112968];c[2113306]=f;c[2113298]=c[2113300];fl3();fnZ();m=c[3531916]|0}else{m=b}c[2112966]=m;b=c[2113016]|0;if((b|0)>0){n=0}else{return 0}do{c[m+(n<<2)>>2]=65535;n=n+1|0;}while((n|0)<(b|0));return 0}function flI(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;e=i;i=i+256|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;l=e+80|0;m=e+96|0;n=e+112|0;o=e+128|0;p=e+144|0;q=e+160|0;r=e+176|0;s=e+192|0;t=e+208|0;u=e+224|0;v=e+240|0;w=(d|0)==0;if(!w){c[d>>2]=169249}Ts(b,d);if((b&96|0)==0){i=e;return 0}gGz(v|0,0,12);x=c[2405598]|0;c[v>>2]=x;c[v+4>>2]=(c[2411510]|0)-x;c[v+12>>2]=219592;gj[c[2076592]&4095](v)|0;v=q|0;x=(b&64|0)==0;do{if(!x){gGz(p|0,0,16);c[2394]=-1;if((c[2392]|0)<0){break}y=q+9|0;z=o;A=o|0;B=o+4|0;C=o+12|0;D=p|0;E=p+4|0;F=p+12|0;G=0;do{gGC(v|0,614896,11)|0;a[y]=G+48&255;H=8452256+(G<<2)|0;gGz(z|0,0,12);c[A>>2]=H;c[B>>2]=4;c[C>>2]=164976;gj[c[2076592]&4095](o)|0;if((c[H>>2]|0)!=0){c[D>>2]=c[14130368+(G<<2)>>2];c[E>>2]=c[8452184+(G<<2)>>2];c[F>>2]=v;H=c[2076592]|0;gj[H&4095](p)|0}G=G+1|0;}while((G|0)<=(c[2392]|0))}}while(0);fw$(b);Ue();do{if(!w){if((c[d>>2]|0)>=169249){break}c[d>>2]=169249}}while(0);if(!x){gGz(n|0,0,12);c[n>>2]=9775320;c[n+4>>2]=8;c[n+12>>2]=111920;x=c[2076592]|0;gj[x&4095](n)|0;gGz(m|0,0,12);c[m>>2]=9775288;c[m+4>>2]=8;c[m+12>>2]=478936;n=c[2076592]|0;gj[n&4095](m)|0;gGz(l|0,0,12);c[l>>2]=53400;c[l+4>>2]=8;c[l+12>>2]=398448;m=c[2076592]|0;gj[m&4095](l)|0;gGz(k|0,0,12);c[k>>2]=14114048;c[k+4>>2]=4;c[k+12>>2]=287368;l=c[2076592]|0;gj[l&4095](k)|0}if(!w){c[d>>2]=169110}gGz(j|0,0,12);c[j>>2]=9756784;c[j+4>>2]=4;c[j+12>>2]=175504;gj[c[2076592]&4095](j)|0;gGz(h|0,0,12);c[h>>2]=14166032;c[h+4>>2]=8;c[h+12>>2]=504552;gj[c[2076592]&4095](h)|0;gGz(g|0,0,12);c[g>>2]=14165992;c[g+4>>2]=8;c[g+12>>2]=388736;gj[c[2076592]&4095](g)|0;gGz(f|0,0,12);c[f>>2]=14165960;c[f+4>>2]=32;c[f+12>>2]=302352;gj[c[2076592]&4095](f)|0;gGz(u|0,0,12);c[u>>2]=9625504;c[u+4>>2]=6;c[u+12>>2]=215728;gj[c[2076592]&4095](u)|0;gGz(t|0,0,12);c[t>>2]=14114064;c[t+4>>2]=16;c[t+12>>2]=83712;gj[c[2076592]&4095](t)|0;gGz(s|0,0,12);c[s>>2]=9620568;c[s+4>>2]=4;c[s+12>>2]=82264;gj[c[2076592]&4095](s)|0;gGz(r|0,0,12);c[r>>2]=9775624;c[r+4>>2]=1;c[r+12>>2]=68056;gj[c[2076592]&4095](r)|0;i=e;return 0}function flJ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3079492+(b*112|0)>>2];c[a+104>>2]=c[3079496+(b*112|0)>>2];c[a+108>>2]=c[3079500+(b*112|0)>>2];d=0;return d|0}function flK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=3079392+(b*112|0);e=0;return e|0}function flL(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=94){if((a|0)==0){d=0;return d|0}e=a;f=3104664+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}f=b-95|0;if(f>>>0>27){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;a=699472+(f*12|0)|0;c[b>>2]=c[a>>2];c[b+4>>2]=c[a+4>>2];c[b+8>>2]=c[a+8>>2];d=0;return d|0}function flM(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4805140+(b*112|0)>>2];c[a+104>>2]=c[4805144+(b*112|0)>>2];c[a+108>>2]=c[4805148+(b*112|0)>>2];d=0;return d|0}function flN(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=4805040+(b*112|0);e=0;return e|0}function flO(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=a[9547e3]|0;if((d&30)>>>0<26){a[(c[2418128]|0)+1|0]=d&31}if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}a[9775624]=0;c[2113050]=0;c[2276080]=0;RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);if(!e){j=d;gGC(j|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=i;c[1836236]=-1;c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];c[2405142]=0;gGz(14114064,0,16);a[9752568]=0;gGz(14125184,0,668);c[2433532]=0;c[2430402]=0;c[2113010]=0;a[9753304]=0;c[2433552]=0;gGz(c[2430036]|0,0,16384);c[3531316]=4;gGz(c[2430037]|0,0,16384);c[3531337]=4;gGz(c[2430038]|0,0,16384);c[3531358]=4;gGz(c[2430039]|0,0,16384);c[3531379]=4;gGz(c[2430040]|0,0,16384);c[3531400]=4;gGz(c[2430041]|0,0,16384);c[3531421]=4;gGz(c[2430042]|0,0,16384);c[3531442]=4;gGz(c[2430043]|0,0,16384);c[3531463]=4;c[2113221]=0;c[2113220]=0;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if(!e){e=d;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=f;c[2076596]=g;c[3541536]=i;c[1836236]=0;gu[c[3528472]&16383]();c[2443830]=4602247;c[2443822]=4602247;i=gD[c[2433526]&8191]()|0;g=gGU(i,(i|0)<0|0?-1:0,2048e6,0)|0;i=c[2438228]|0;f=gGS(g,K,i,(i|0)<0|0?-1:0)|0;i=gGK(c[2443830]|0,0,f,K)|0;c[2443830]=i;i=c[1836236]|0;f=c[9757320+(i<<2)>>2]|0;if((f|0)==0){k=c[2433530]|0;l=9752472+(i<<2)|0;c[l>>2]=k;m=c[2076596]|0;n=14113936+(i<<2)|0;c[n>>2]=m;o=c[3541536]|0;p=9669104+(i<<2)|0;c[p>>2]=o;c[1836236]=-1;return}g=f;gGC(g|0,9706056,76)|0;k=c[2433530]|0;l=9752472+(i<<2)|0;c[l>>2]=k;m=c[2076596]|0;n=14113936+(i<<2)|0;c[n>>2]=m;o=c[3541536]|0;p=9669104+(i<<2)|0;c[p>>2]=o;c[1836236]=-1;return}function flP(b,c){b=b|0;c=c|0;a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0;return 0}function flQ(b){b=b|0;var e=0,f=0,g=0,h=0;switch(b&255|0){case 96:{b=c[3540984]|0;e=(d[b+5887|0]|0|128)&(d[b+5886|0]|0);if((a[b+5884|0]&2)==0){f=e&255}else{f=(a[(c[b+5828>>2]|0)+100|0]&1|e)&255}g=f|6;return g|0};case 32:{f=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;if((f|0)<(c[2113018]|0)){h=f>>>31<<7&255}else{h=-128}g=h|a[9625500];return g|0};case 16:{g=a[9625497]|0;return g|0};case 112:{g=a[9625501]|0;return g|0};case 64:{g=a[9625498]|0;return g|0};case 80:{g=a[9625499]|0;return g|0};case 0:{g=a[9625496]|0;return g|0};default:{g=0;return g|0}}return 0}function flR(b,e){b=b|0;e=e|0;var f=0,g=0;f=b&255;if((f|0)==97){b=c[3540984]|0;g=c[b+5876>>2]|0;if((g|0)!=0){gg[g&4095](c[b+5880>>2]|0,0)}lH(b,d[b+5885|0]|0,e&255);return}else if((f|0)==96){a[(c[3540984]|0)+5885|0]=e;return}else{return}}function flS(a){a=a|0;var b=0;if(!((a|0)==786433|(a|0)==1310721)){b=0;return b|0}a=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;if((a|0)>=(c[2113018]|0)){b=1;return b|0}b=a>>>31&255;return b|0}function flT(a){a=a|0;var d=0,e=0;if((a|0)==1048582){d=b[(c[3542214]|0)+((c[3542216]&32767)+1<<1)>>1]|0;return d|0}else if((a|0)==786438){d=b[(c[3541522]|0)+((c[3541526]&63)<<1)>>1]|0;return d|0}else if((a|0)==1048578){d=(c[3542216]|0)>>>1&16383;return d|0}else if((a|0)==786432|(a|0)==1310720){e=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;if((e|0)>=(c[2113018]|0)){d=1;return d|0}d=e>>>31&65535;return d|0}else if((a|0)==786436){d=b[(c[3541524]|0)+((c[3541526]&1023)<<1)>>1]|0;return d|0}else if((a|0)==1048580){d=b[(c[3542214]|0)+((c[3542216]&32767)<<1)>>1]|0;return d|0}else if((a|0)==1048592|(a|0)==1048593|(a|0)==1048594|(a|0)==1048595|(a|0)==1048596|(a|0)==1048597|(a|0)==1048598|(a|0)==1048599|(a|0)==1048600|(a|0)==1048601|(a|0)==1048602|(a|0)==1048603|(a|0)==1048604|(a|0)==1048605|(a|0)==1048606|(a|0)==1048607){d=b[14168832+((a>>>1&7)<<1)>>1]|0;return d|0}else if((a|0)==786434){d=c[3541526]&1023;return d|0}else{d=0;return d|0}return 0}function flU(d,e){d=d|0;e=e|0;var f=0;if((d|0)==786438){f=c[3541526]|0;b[(c[3541522]|0)+((f&63)<<1)>>1]=e&255;c[3541526]=f+1;return}else if((d|0)==1310723){a[9722064]=e<<24>>24!=0|0;return}else{return}}function flV(d,e){d=d|0;e=e|0;var f=0;if((d|0)==1835010){c[2113312]=e&65535;return}else if((d|0)==1048580){f=c[3542216]|0;b[(c[3542214]|0)+((f&32767)<<1)>>1]=e;c[3542216]=f+1;return}else if((d|0)==786436){f=c[3541526]|0;b[(c[3541524]|0)+((f&1023)<<1)>>1]=e;c[3541526]=f+1;return}else if((d|0)==1900544){if(e<<16>>16!=0){return}gGz(9706056,0,76);c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;lw(c[3540984]|0);return}else if((d|0)==1835008){c[2113314]=e&65535;return}else if((d|0)==786438){f=c[3541526]|0;b[(c[3541522]|0)+((f&63)<<1)>>1]=e;c[3541526]=f+1;return}else if((d|0)==1048582){f=c[3542216]|0;b[(c[3542214]|0)+((f&32767)<<1)>>1]=e;c[3542216]=f+1;return}else if((d|0)==1310722){a[9722064]=(e&255)!=0|0;return}else if((d|0)==1048578){c[3542216]=(e&65535)<<1&32766;return}else if((d|0)==1048592|(d|0)==1048593|(d|0)==1048594|(d|0)==1048595|(d|0)==1048596|(d|0)==1048597|(d|0)==1048598|(d|0)==1048599|(d|0)==1048600|(d|0)==1048601|(d|0)==1048602|(d|0)==1048603|(d|0)==1048604|(d|0)==1048605|(d|0)==1048606|(d|0)==1048607){b[14168832+((d>>>1&7)<<1)>>1]=e;return}else if((d|0)==786434){c[3541526]=e&1023;return}else{return}}function flW(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4341972+(b*112|0)>>2];c[a+104>>2]=c[4341976+(b*112|0)>>2];c[a+108>>2]=c[4341980+(b*112|0)>>2];d=0;return d|0}function flX(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=4341872+(b*112|0);e=0;return e|0}function flY(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1350688+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function flZ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>51){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4343328+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fl_(){var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;d=i;i=i+120|0;e=d|0;f=d+112|0;c[2424]=5761;c[2113316]=524288;c[2113212]=524288;c[2426658]=0;c[2418126]=0;c[3532626]=262144;c[3542212]=294912;c[3541520]=819200;c[2405596]=1343488;c[2418240]=1343488;c[2411408]=1359872;c[2406886]=1363968;c[3532636]=1368064;c[3542214]=1400832;c[3541524]=1466368;c[3541522]=1468416;c[2411508]=1468544;c[3531916]=1468544;c[3531914]=1472640;g=0;while(1){if((g|0)>=1024){break}j=9638528+(g<<2)|0;if((c[j>>2]|0)==0){k=60686;break}else{g=g+1|0}}do{if((k|0)==60686){g=gGq(1476736)|0;c[j>>2]=g;if((g|0)==0){break}c[2426658]=g;gGz(g|0,0,1476736);c[2418126]=g;c[3532626]=g+262144;c[3542212]=g+294912;l=(c[2113316]|0)+294912|0;c[3541520]=g+l;m=l+(c[2113212]|0)|0;l=g+m|0;c[2405596]=l;c[2418240]=l;c[2411408]=g+(m+16384);c[2406886]=g+(m+20480);c[3532636]=g+(m+24576);c[3542214]=g+(m+57344);c[3541524]=g+(m+122880);c[3541522]=g+(m+124928);l=g+(m+125056)|0;c[2411508]=l;c[3531916]=l;c[3531914]=g+(m+129152);c[2414048]=g+(m+133248);fpk(g,2)|0;fni(c[3542212]|0,2,c[2113316]|0);fni(c[3541520]|0,6,c[2113212]|0);g=c[3532626]|0;do{if((c[3542200]|0)!=0){m=e+108|0;c[m>>2]=0;l=e+100|0;c[l>>2]=0;n=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[n&16383](e,10)|0;if((c[m>>2]|0)==0){break}m=c[l>>2]|0;c[f>>2]=9534384;l=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[l&16383](f,10,0)|0;if((m|0)<1){break}gzL(g,0,10)|0}}while(0);fxU(0,425984);if((c[2394]|0)==0){o=c[2112932]|0}else{c[2394]=0;g=c[3532596]|0;c[2112932]=g;m=c[3532592]|0;if((m|0)!=0){gGC(9104152,m|0,280)|0}c[2113054]=c[2113060];o=g}g=c[2418126]|0;m=o|0;l=0;while(1){n=g+l|0;c[m>>2]=n;c[m+131072>>2]=n;n=l+1024|0;if(n>>>0>262143){break}else{m=m+4|0;l=n}}l=c[2418240]|0;c[o+2048>>2]=l;c[o+67584>>2]=l;c[o+133120>>2]=l;m=l+1024|0;c[o+2052>>2]=m;c[o+67588>>2]=m;c[o+133124>>2]=m;m=l+2048|0;c[o+2056>>2]=m;c[o+67592>>2]=m;c[o+133128>>2]=m;m=l+3072|0;c[o+2060>>2]=m;c[o+67596>>2]=m;c[o+133132>>2]=m;m=l+4096|0;c[o+2064>>2]=m;c[o+67600>>2]=m;c[o+133136>>2]=m;m=l+5120|0;c[o+2068>>2]=m;c[o+67604>>2]=m;c[o+133140>>2]=m;m=l+6144|0;c[o+2072>>2]=m;c[o+67608>>2]=m;c[o+133144>>2]=m;m=l+7168|0;c[o+2076>>2]=m;c[o+67612>>2]=m;c[o+133148>>2]=m;m=l+8192|0;c[o+2080>>2]=m;c[o+67616>>2]=m;c[o+133152>>2]=m;m=l+9216|0;c[o+2084>>2]=m;c[o+67620>>2]=m;c[o+133156>>2]=m;m=l+10240|0;c[o+2088>>2]=m;c[o+67624>>2]=m;c[o+133160>>2]=m;m=l+11264|0;c[o+2092>>2]=m;c[o+67628>>2]=m;c[o+133164>>2]=m;m=l+12288|0;c[o+2096>>2]=m;c[o+67632>>2]=m;c[o+133168>>2]=m;m=l+13312|0;c[o+2100>>2]=m;c[o+67636>>2]=m;c[o+133172>>2]=m;m=l+14336|0;c[o+2104>>2]=m;c[o+67640>>2]=m;c[o+133176>>2]=m;m=l+15360|0;c[o+2108>>2]=m;c[o+67644>>2]=m;c[o+133180>>2]=m;m=c[2411408]|0;c[o+5184>>2]=m;c[o+70720>>2]=m;c[o+136256>>2]=m;l=m+1024|0;c[o+5188>>2]=l;c[o+70724>>2]=l;c[o+136260>>2]=l;l=c[2406886]|0;c[o+5216>>2]=l;c[o+70752>>2]=l;c[o+136288>>2]=l;m=l+1024|0;c[o+5220>>2]=m;c[o+70756>>2]=m;c[o+136292>>2]=m;c[o+196688>>2]=3552;c[o+196608>>2]=264;c[o+196728>>2]=618;c[o+196648>>2]=1926;c[o+6144>>2]=1;c[o+71680>>2]=1;c[o+137216>>2]=1;c[o+6148>>2]=1;c[o+71684>>2]=1;c[o+137220>>2]=1;c[o+6152>>2]=1;c[o+71688>>2]=1;c[o+137224>>2]=1;c[o+6156>>2]=1;c[o+71692>>2]=1;c[o+137228>>2]=1;c[o+196612>>2]=594;c[o+196692>>2]=2082;c[o+196652>>2]=1774;c[o+196732>>2]=1304;m=c[3532592]|0;if((m|0)!=0){gGC(m|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fpA();fwR(0);m=c[2439330]|0;l=(m|0)==0;if(!l){g=m;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];g=c[3528484]|0;c[2076596]=g;n=c[2417276]|0;c[3541536]=n;c[1836236]=0;c[m+4172>>2]=820;c[m+4176>>2]=2158;p=c[3532626]|0;q=0;r=0;while(1){c[m+76+(r<<2)>>2]=p+(r<<8);s=q+1&65535;if((s&65535)>127){t=0;u=0;break}else{q=s;r=s&65535}}while(1){r=p+(u<<8)|0;c[m+76+(u+512<<2)>>2]=r;c[m+76+(u+768<<2)>>2]=r;r=t+1&65535;if((r&65535)>127){break}else{t=r;u=r&65535}}p=c[3532636]|0;r=128;q=128;while(1){c[m+76+(q<<2)>>2]=p+((q<<8)-32768);s=r+1&65535;if((s&65535)>255){v=128;w=128;break}else{r=s;q=s&65535}}while(1){c[m+76+(w+256<<2)>>2]=p+((w<<8)-32768);q=v+1&65535;if((q&65535)>255){x=128;y=128;break}else{v=q;w=q&65535}}while(1){q=p+((y<<8)-32768)|0;c[m+76+(y+512<<2)>>2]=q;c[m+76+(y+768<<2)>>2]=q;q=x+1&65535;if((q&65535)>255){break}else{x=q;y=q&65535}}if(!l){p=m;gGC(p|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=g;c[2417276]=n;c[1836236]=-1;c[2113016]=1024;c[3531920]=c[2411408];c[3531918]=c[2406886];UL(35e5,1078,3456,0);c[2438224]=35e5;c[2433522]=3416;c[2406672]=1752;c[3528468]=9362;c[2443842]=584;h[745398]=1.0;a[3203264]=1;a[7072672]=1;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];p=c[3532592]|0;if((p|0)!=0){gGC(9104152,p|0,280)|0}c[2113054]=c[2113060]}RI();p=c[2394]|0;q=c[14130368+(p<<2)>>2]|0;if((q|0)!=0){gGC(q|0,9104152,280)|0}c[8452240+(p<<2)>>2]=c[2113054];c[2394]=-1;p=c[2439330]|0;q=(p|0)==0;if(!q){r=p;gGC(9706056,r|0,76)|0}r=c[2438118]|0;c[2433530]=r;s=c[3528484]|0;c[2076596]=s;z=c[2417276]|0;c[3541536]=z;c[1836236]=0;gGz(9706056,0,76);if(!q){q=p;gGC(q|0,9706056,76)|0}c[2438118]=r;c[3528484]=s;c[2417276]=z;c[1836236]=-1;c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;lw(c[3540984]|0);a[9722064]=0;A=0;i=d;return A|0}}while(0);c[2426658]=0;A=1;i=d;return A|0}function fl$(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=a[7452584]|0;if(b){d=0;e=b&1;while(1){b=14163936+(d<<2)|0;f=c[b>>2]|0;g=c[2113006]|0;if((g|0)==0){h=60730}else{i=g-1|0;c[2113006]=i;if((i|0)==0){h=60730}}if((h|0)==60730){h=0;c[2383474]=0}if((f|0)==0){j=e}else{gGr(f);j=a[7452584]&1}c[b>>2]=0;b=d+1|0;if((b|0)<(j|0)){d=b;e=j}else{break}}}a[7452584]=0;c[2438224]=0;c[2433522]=0;c[2406672]=0;c[3528468]=0;j=c[2406688]|0;if((j|0)!=0){gGr(j);c[2406688]=0}c[2432972]=0;fpB();fwZ();if((c[2392]|0)>=0){j=0;do{e=14130368+(j<<2)|0;d=c[e>>2]|0;if((d|0)!=0){gGr(d);c[e>>2]=0}e=14130384+(j<<2)|0;d=c[e>>2]|0;if((d|0)!=0){gGr(d);c[e>>2]=0}j=j+1|0;}while((j|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;j=c[2426658]|0;e=0;while(1){if((e|0)>=1024){h=60747;break}k=9638528+(e<<2)|0;if((c[k>>2]|0)==(j|0)){break}else{e=e+1|0}}if((h|0)==60747){c[2426658]=0;return 0}gGr(j);c[k>>2]=0;c[2426658]=0;return 0}function fl0(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;if((a[9623600]|0)!=0){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=i;c[1836236]=-1;c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;lw(c[3540984]|0);a[9722064]=0}a[9625496]=0;a[9625497]=0;a[9625500]=0;i=0;g=0;f=0;e=0;do{g=((a[9632632+i|0]&1)<<i|g&255)&255;f=((a[9630536+i|0]&1)<<i|f&255)&255;e=((a[9551720+i|0]&1)<<i|e&255)&255;i=i+1|0;}while((i|0)<8);a[9625496]=g;a[9625497]=f;a[9625500]=e;if((g&3)==3){e=g&-4;a[9625496]=e;j=e}else{j=g}if((j&12)==12){a[9625496]=j&-13}if((f&3)==3){j=f&-4;a[9625497]=j;k=j}else{k=f}if((k&12)==12){a[9625497]=k&-13}k=c[2392]|0;if((k|0)>=0){gGz(8452240,0,((k|0)>0?(k<<2)+4|0:4)|0)}c[2113054]=0;k=c[2385548]|0;if((k|0)>0){gGz(9752472,0,((k|0)>1?k<<2:4)|0)}c[2433530]=0;if((c[2394]|0)==0){l=0}else{c[2394]=0;c[2112932]=c[3532596];k=c[3532592]|0;if((k|0)!=0){gGC(9104152,k|0,280)|0}k=c[2113060]|0;c[2113054]=k;l=k}k=c[2439330]|0;if((k|0)!=0){f=k;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;f=c[2438118]|0;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;c[2113054]=l+(c[2113220]|0);c[2433530]=f+(c[2113221]|0);f=c[2438]|0;l=gGU(f,(f|0)<0|0?-1:0,1e7,0)|0;f=~~((+(l>>>0)+ +(K|0)*4294967296.0)/14748.971193415638);c[2113218]=f;c[2113216]=60750;c[2113058]=(f|0)/262|0;l=f-((f*22|0|0)/262|0)|0;c[2113018]=l;k=0;j=f;f=l;while(1){l=k+1|0;g=(ag(l,j)|0)/4|0;do{if((g|0)>(f|0)){e=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;if((e|0)<(f|0)){i=f-e|0;c[2113056]=i;e=RG(i)|0;c[2113054]=(c[2113054]|0)+e;c[2276108]=-1;c[2113056]=-1}e=c[2112968]|0;do{if((e|0)!=0){i=c[3531916]|0;d=c[2113308]|0;do{if((c[i>>2]|0)==0){gGz(e|0,0,d*76800|0|0)}else{if((d|0)==2){m=c[i+1152>>2]|0;n=m<<16|m;m=e;o=0;while(1){c[m>>2]=n;c[m+4>>2]=n;c[m+8>>2]=n;c[m+12>>2]=n;c[m+16>>2]=n;c[m+20>>2]=n;c[m+24>>2]=n;c[m+28>>2]=n;p=o+1|0;if((p|0)<4800){m=m+32|0;o=p}else{break}}}else if((d|0)==4){o=c[i+1152>>2]|0;m=0;n=e;while(1){c[n>>2]=o;c[n+4>>2]=o;c[n+8>>2]=o;c[n+12>>2]=o;c[n+16>>2]=o;c[n+20>>2]=o;c[n+24>>2]=o;c[n+28>>2]=o;p=m+1|0;if((p|0)<9600){m=p;n=n+32|0}else{break}}}else if((d|0)==3){n=c[i+1152>>2]|0;m=n>>>8&255;o=n>>>16&255;p=n&255;n=e;q=0;while(1){a[n]=p;a[n+1|0]=m;a[n+2|0]=o;r=q+1|0;if((r|0)<76800){n=n+3|0;q=r}else{break}}}else{break}}}while(0);if(a[7072672]|0){c[2112970]=e;c[2113306]=d;c[2113298]=c[2113300];fpz();s=c[3531916]|0}else{s=i}c[2112966]=s;q=c[2113016]|0;if((q|0)>0){t=0}else{break}do{c[s+(t<<2)>>2]=65535;t=t+1|0;}while((t|0)<(q|0));i=c[3531914]|0;d=0;do{c[i+(d<<2)>>2]=65535;d=d+1|0;}while((d|0)<(q|0))}}while(0);e=c[2430400]|0;q=c[3541524]|0;gGC(e|0,q|0,2048)|0;if((a[9722064]&1)==0){break}c[8452200+(c[2394]<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0>=1024){break}RH(4)}}while(0);q=g-(c[2113054]|0)-(c[2113056]|0)+(c[2276108]|0)|0;c[2113056]=q;e=RG(q)|0;c[2113054]=(c[2113054]|0)+e;c[2276108]=-1;c[2113056]=-1;UF(ag((c[2113216]|0)/4|0,k)|0)|0;if((l|0)>=4){break}k=l;j=c[2113218]|0;f=c[2113018]|0}f=c[2113216]|0;j=gGU(f,(f|0)<0|0?-1:0,2048e6,0)|0;k=c[2438224]|0;t=gGS(j,K,k,(k|0)<0|0?-1:0)|0;k=t;UF(f)|0;f=c[2443826]|0;if((f|0)<1073676288){c[2443826]=f-k}f=c[2443827]|0;if((f|0)<1073676288){c[2443827]=f-k}f=(c[3528508]|0)-k|0;c[3528508]=(f|0)<0?0:f;f=c[2112964]|0;if((f|0)!=0){gg[c[3542112]&4095](f,a[9688]|0?534:0)}f=c[2113054]|0;c[2113220]=(c[2113056]|0)+f-(c[2276108]|0)-(c[2113218]|0);k=c[2433530]|0;t=c[2076596]|0;c[2113221]=(c[2426530]|0)+k-t-(c[2113216]|0);j=c[1836236]|0;s=c[9757320+(j<<2)>>2]|0;if((s|0)!=0){e=s;gGC(e|0,9706056,76)|0}c[9752472+(j<<2)>>2]=k;c[14113936+(j<<2)>>2]=t;c[9669104+(j<<2)>>2]=c[3541536];c[1836236]=-1;j=c[2394]|0;t=c[14130368+(j<<2)>>2]|0;if((t|0)==0){u=8452240+(j<<2)|0;c[u>>2]=f;c[2394]=-1;return 0}gGC(t|0,9104152,280)|0;u=8452240+(j<<2)|0;c[u>>2]=f;c[2394]=-1;return 0}function fl1(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=c[3531916]|0;do{if((c[b>>2]|0)==0){d=c[2113308]|0;gGz(c[2112968]|0,0,d*76800|0|0);e=d}else{d=c[2113308]|0;if((d|0)==3){f=c[b+1152>>2]|0;g=f>>>8&255;h=f>>>16&255;i=f&255;f=c[2112968]|0;j=0;while(1){a[f]=i;a[f+1|0]=g;a[f+2|0]=h;k=j+1|0;if((k|0)<76800){f=f+3|0;j=k}else{e=3;break}}}else if((d|0)==4){j=c[b+1152>>2]|0;f=0;h=c[2112968]|0;while(1){c[h>>2]=j;c[h+4>>2]=j;c[h+8>>2]=j;c[h+12>>2]=j;c[h+16>>2]=j;c[h+20>>2]=j;c[h+24>>2]=j;c[h+28>>2]=j;g=f+1|0;if((g|0)<9600){f=g;h=h+32|0}else{e=4;break}}}else if((d|0)==2){h=c[b+1152>>2]|0;f=h<<16|h;h=c[2112968]|0;j=0;while(1){c[h>>2]=f;c[h+4>>2]=f;c[h+8>>2]=f;c[h+12>>2]=f;c[h+16>>2]=f;c[h+20>>2]=f;c[h+24>>2]=f;c[h+28>>2]=f;g=j+1|0;if((g|0)<4800){h=h+32|0;j=g}else{e=2;break}}}else{e=d;break}}}while(0);if(a[7072672]|0){c[2112970]=c[2112968];c[2113306]=e;c[2113298]=c[2113300];fpz();l=c[3531916]|0}else{l=b}c[2112966]=l;b=c[2113016]|0;if((b|0)>0){m=0}else{return 0}do{c[l+(m<<2)>>2]=65535;m=m+1|0;}while((m|0)<(b|0));m=c[3531914]|0;l=0;do{c[m+(l<<2)>>2]=65535;l=l+1|0;}while((l|0)<(b|0));return 0}function fl2(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=i;i=i+96|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;l=e+80|0;if((d|0)!=0){c[d>>2]=168962}if((b&96|0)==0){i=e;return 0}gGz(l|0,0,12);m=c[2405596]|0;c[l>>2]=m;c[l+4>>2]=(c[2411508]|0)-m;c[l+12>>2]=219592;gj[c[2076592]&4095](l)|0;l=h|0;do{if((b&64|0)!=0){gGz(g|0,0,16);c[2394]=-1;if((c[2392]|0)<0){break}m=h+9|0;n=f;o=f|0;p=f+4|0;q=f+12|0;r=g|0;s=g+4|0;t=g+12|0;u=0;do{gGC(l|0,614896,11)|0;a[m]=u+48&255;v=8452256+(u<<2)|0;gGz(n|0,0,12);c[o>>2]=v;c[p>>2]=4;c[q>>2]=164976;gj[c[2076592]&4095](f)|0;if((c[v>>2]|0)!=0){c[r>>2]=c[14130368+(u<<2)>>2];c[s>>2]=c[8452184+(u<<2)>>2];c[t>>2]=l;v=c[2076592]|0;gj[v&4095](g)|0}u=u+1|0;}while((u|0)<=(c[2392]|0))}}while(0);fw$(b);UQ(b,d);gGz(k|0,0,12);c[k>>2]=9625496;c[k+4>>2]=6;c[k+12>>2]=215728;gj[c[2076592]&4095](k)|0;gGz(j|0,0,12);c[j>>2]=8452880;c[j+4>>2]=8;c[j+12>>2]=212472;gj[c[2076592]&4095](j)|0;i=e;return 0}function fl3(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;f=c[2113308]|0;if((c[2394750]|0)!=(f|0)){c[2394750]=f;c[3528970]=c[3564272+(f-2<<2)>>2]}f=c[2440572]|0;g=(f|0)>0;do{if(g){h=0;do{i=h<<4;j=c[9752368+(h<<2)>>2]|0;c[14113704+(i<<2)>>2]=j;c[14113704+((i|1)<<2)>>2]=j+12288;c[14113704+((i|2)<<2)>>2]=j+24576;c[14113704+((i|3)<<2)>>2]=j+36864;c[14113704+((i|4)<<2)>>2]=j+49152;c[14113704+((i|5)<<2)>>2]=j+61440;c[14113704+((i|6)<<2)>>2]=j+73728;c[14113704+((i|7)<<2)>>2]=j+86016;c[14113704+((i|8)<<2)>>2]=j+98304;c[14113704+((i|9)<<2)>>2]=j+110592;c[14113704+((i|10)<<2)>>2]=j+122880;c[14113704+((i|11)<<2)>>2]=j+135168;c[14113704+((i|12)<<2)>>2]=j+147456;c[14113704+((i|13)<<2)>>2]=j+159744;c[14113704+((i|14)<<2)>>2]=j+172032;c[14113704+((i|15)<<2)>>2]=j+184320;h=h+1|0;}while((h|0)<(f|0));if((f|0)!=1){k=60873;break}h=c[3541506]|0;j=h;i=c[3541500]|0;l=c[2113182]|0;m=(e[i>>1]|0)+l|0;n=(e[i+2>>1]|0)+(c[2113180]|0)|0;o=n>>>4;p=m>>>4;q=m&15;m=n&15;n=c[2394742]|0;r=0;do{s=r+o<<6&1984;t=(r<<4)-m|0;u=t&65535;v=0;do{w=v+p<<1&62|s;x=b[j+((w|1)<<1)>>1]|0;y=x&65535;if(!(x<<16>>16==0|y>>>0>n>>>0)){x=e[j+(w<<1)>>1]|0;w=14113704+((x>>>8&15)<<2)|0;z=c[w>>2]|0;c[z>>2]=x<<16|y;y=(v<<4)-q|0;c[2385466]=y;c[2385454]=t;c[w>>2]=z+8;c[z+4>>2]=y<<16|u}v=v+1|0;}while((v|0)<21);r=r+1|0;}while((r|0)<16);r=h+4096|0;q=c[2113178]|0;j=(e[i+4>>1]|0)+q|0;p=(e[i+6>>1]|0)+(c[2113176]|0)|0;m=p>>>4;o=j>>>4;v=j&15;j=p&15;p=0;do{u=p+m<<6&1984;t=(p<<4)-j|0;s=t&65535;y=0;do{z=y+o<<1&62|u;w=b[r+((z|1)<<1)>>1]|0;x=w&65535;if(!(w<<16>>16==0|x>>>0>n>>>0)){w=e[r+(z<<1)>>1]|0;z=14113704+((w>>>8&15)<<2)|0;A=c[z>>2]|0;c[A>>2]=w<<16|x;x=(y<<4)-v|0;c[2385466]=x;c[2385454]=t;c[z>>2]=A+8;c[A+4>>2]=x<<16|s}y=y+1|0;}while((y|0)<21);p=p+1|0;}while((p|0)<16);p=h+8192|0;v=c[2113174]|0;r=(e[i+8>>1]|0)+v|0;o=(e[i+10>>1]|0)+(c[2113172]|0)|0;j=o>>>4;m=r>>>4;y=r&15;r=o&15;o=0;while(1){s=o+j<<6&1984;t=(o<<4)-r|0;u=t&65535;x=0;do{A=x+m<<1&62|s;z=b[p+((A|1)<<1)>>1]|0;w=z&65535;if(!(z<<16>>16==0|w>>>0>n>>>0)){z=e[p+(A<<1)>>1]|0;A=14113704+((z>>>8&15)<<2)|0;B=c[A>>2]|0;c[B>>2]=z<<16|w;w=(x<<4)-y|0;c[2385466]=w;c[2385454]=t;c[A>>2]=B+8;c[B+4>>2]=w<<16|u}x=x+1|0;}while((x|0)<21);x=o+1|0;if((x|0)<16){o=x}else{C=l;D=q;E=i;F=v;break}}}else{k=60873}}while(0);L79243:do{if((k|0)==60873){v=c[2415170]|0;i=c[3541506]|0;q=i;l=c[3541500]|0;o=c[2113182]|0;y=(e[l>>1]|0)+o|0;p=c[2113180]|0;n=(e[l+2>>1]|0)+p|0;m=n>>>4;r=y>>>4;j=y&15;y=n&15;n=c[2394742]|0;h=0;do{x=h+m<<6&1984;u=(h<<4)-y|0;t=u&65535;s=0;do{w=s+r<<1&62|x;B=b[q+((w|1)<<1)>>1]|0;A=B&65535;if(!(B<<16>>16==0|A>>>0>n>>>0)){B=e[q+(w<<1)>>1]|0;w=14113704+((B>>>8&15)<<2)|0;z=c[w>>2]|0;c[z>>2]=B<<16|A;A=(s<<4)-j|0;c[2385466]=A;c[2385454]=u;c[w>>2]=z+8;c[z+4>>2]=A<<16|t}s=s+1|0;}while((s|0)<21);h=h+1|0;}while((h|0)<16);h=i+4096|0;j=c[2113178]|0;q=(e[l+4>>1]|0)+j|0;r=c[2113176]|0;y=(e[l+6>>1]|0)+r|0;m=y>>>4;s=q>>>4;t=q&15;q=y&15;y=0;do{u=y+m<<6&1984;x=(y<<4)-q|0;A=x&65535;z=0;do{w=z+s<<1&62|u;B=b[h+((w|1)<<1)>>1]|0;G=B&65535;if(!(B<<16>>16==0|G>>>0>n>>>0)){B=e[h+(w<<1)>>1]|0;w=14113704+((B>>>8&15)<<2)|0;H=c[w>>2]|0;c[H>>2]=B<<16|G;G=(z<<4)-t|0;c[2385466]=G;c[2385454]=x;c[w>>2]=H+8;c[H+4>>2]=G<<16|A}z=z+1|0;}while((z|0)<21);y=y+1|0;}while((y|0)<16);if((v|0)==2){y=i+8192|0;t=c[2113174]|0;h=(e[l+8>>1]|0)+t|0;s=c[2113172]|0;q=(e[l+10>>1]|0)+s|0;m=q>>>4;z=h>>>4;A=h&15;h=q&15;q=0;do{x=q+m<<6&1984;u=(q<<4)-h|0;G=u&65535;H=0;do{w=H+z<<1&62|x;B=b[y+((w|1)<<1)>>1]|0;I=B&65535;if(!(B<<16>>16==0|I>>>0>n>>>0)){B=e[y+(w<<1)>>1]|0;w=14113704+((B>>>8&15)<<2)|0;J=c[w>>2]|0;c[J>>2]=B<<16|I;I=(H<<4)-A|0;c[2385466]=I;c[2385454]=u;c[w>>2]=J+8;c[J+4>>2]=I<<16|G}H=H+1|0;}while((H|0)<21);q=q+1|0;}while((q|0)<16);q=c[3541504]|0;A=q;y=c[3541501]|0;z=(e[y>>1]|0)+o|0;h=(e[y+2>>1]|0)+p|0;m=h>>>4;v=z>>>4;H=z&15;z=h&15;h=c[2394743]|0;G=0;do{u=G+m<<6&1984;x=(G<<4)-z|0;I=x&65535;J=0;do{w=J+v<<1&62|u;B=b[A+((w|1)<<1)>>1]|0;K=B&65535;if(!(B<<16>>16==0|K>>>0>h>>>0)){B=e[A+(w<<1)>>1]|0;w=14113704+((B>>>8&15|16)<<2)|0;L=c[w>>2]|0;c[L>>2]=B<<16|K;K=(J<<4)-H|0;c[2385466]=K;c[2385454]=x;c[w>>2]=L+8;c[L+4>>2]=K<<16|I}J=J+1|0;}while((J|0)<21);G=G+1|0;}while((G|0)<16);G=q+4096|0;H=(e[y+4>>1]|0)+j|0;A=(e[y+6>>1]|0)+r|0;v=A>>>4;z=H>>>4;m=H&15;H=A&15;A=0;do{J=A+v<<6&1984;I=(A<<4)-H|0;x=I&65535;u=0;do{K=u+z<<1&62|J;L=b[G+((K|1)<<1)>>1]|0;w=L&65535;if(!(L<<16>>16==0|w>>>0>h>>>0)){L=e[G+(K<<1)>>1]|0;K=14113704+((L>>>8&15|16)<<2)|0;B=c[K>>2]|0;c[B>>2]=L<<16|w;w=(u<<4)-m|0;c[2385466]=w;c[2385454]=I;c[K>>2]=B+8;c[B+4>>2]=w<<16|x}u=u+1|0;}while((u|0)<21);A=A+1|0;}while((A|0)<16);A=q+8192|0;m=(e[y+8>>1]|0)+t|0;G=(e[y+10>>1]|0)+s|0;z=G>>>4;H=m>>>4;v=m&15;m=G&15;G=0;while(1){u=G+z<<6&1984;x=(G<<4)-m|0;I=x&65535;J=0;do{w=J+H<<1&62|u;B=b[A+((w|1)<<1)>>1]|0;K=B&65535;if(!(B<<16>>16==0|K>>>0>h>>>0)){B=e[A+(w<<1)>>1]|0;w=14113704+((B>>>8&15|16)<<2)|0;L=c[w>>2]|0;c[L>>2]=B<<16|K;K=(J<<4)-v|0;c[2385466]=K;c[2385454]=x;c[w>>2]=L+8;c[L+4>>2]=K<<16|I}J=J+1|0;}while((J|0)<21);J=G+1|0;if((J|0)<16){G=J}else{C=o;D=j;E=l;F=t;break L79243}}}t=c[2113174]|0;G=(e[l+8>>1]|0)+t|0;v=i+8192|0;A=c[2113172]|0;h=(e[l+10>>1]|0)+A|0;H=h>>>4;m=G>>>4;z=G&15;s=h&15;if((G|0)==0){G=0;do{h=G+H<<6&1984;y=(G<<4)-s|0;q=y&65535;J=0;do{I=J+m<<1&62|h;x=b[v+((I|1)<<1)>>1]|0;u=x&65535;if(!(x<<16>>16==0|u>>>0>n>>>0)){x=e[v+(I<<1)>>1]|0;I=14113704+((x>>>8&15)<<2)|0;K=c[I>>2]|0;c[K>>2]=x<<16|u;u=(J<<4)-z|0;c[2385466]=u;c[2385454]=y;c[I>>2]=K+8;c[K+4>>2]=u<<16|q}J=J+1|0;}while((J|0)<21);G=G+1|0;}while((G|0)<16)}else{G=0;do{i=G+H<<6&1984;J=(G<<4)-s|0;q=J&65535;y=0;do{h=y+m<<1&62|i;u=b[v+((h|1)<<1)>>1]|0;K=u&65535;if(!(u<<16>>16==0|K>>>0>n>>>0)){u=e[v+(h<<1)>>1]|0;h=(u&3840|0)==0?u|256:u;u=14113704+((h>>>8&15)<<2)|0;I=c[u>>2]|0;c[I>>2]=h<<16|K;K=(y<<4)-z|0;c[2385466]=K;c[2385454]=J;c[u>>2]=I+8;c[I+4>>2]=K<<16|q}y=y+1|0;}while((y|0)<21);G=G+1|0;}while((G|0)<16)}G=c[3541504]|0;z=G;v=c[3541501]|0;n=(e[v>>1]|0)+o|0;m=(e[v+2>>1]|0)+p|0;s=m>>>4;H=n>>>4;y=n&15;n=m&15;m=c[2394743]|0;q=0;do{J=q+s<<6&1984;i=(q<<4)-n|0;K=i&65535;I=0;do{u=I+H<<1&62|J;h=b[z+((u|1)<<1)>>1]|0;x=h&65535;if(!(h<<16>>16==0|x>>>0>m>>>0)){h=e[z+(u<<1)>>1]|0;u=14113704+((h>>>8&15|16)<<2)|0;L=c[u>>2]|0;c[L>>2]=h<<16|x;x=(I<<4)-y|0;c[2385466]=x;c[2385454]=i;c[u>>2]=L+8;c[L+4>>2]=x<<16|K}I=I+1|0;}while((I|0)<21);q=q+1|0;}while((q|0)<16);q=G+4096|0;y=(e[v+4>>1]|0)+j|0;z=(e[v+6>>1]|0)+r|0;H=z>>>4;n=y>>>4;s=y&15;y=z&15;z=0;do{p=z+H<<6&1984;I=(z<<4)-y|0;K=I&65535;i=0;do{J=i+n<<1&62|p;x=b[q+((J|1)<<1)>>1]|0;L=x&65535;if(!(x<<16>>16==0|L>>>0>m>>>0)){x=e[q+(J<<1)>>1]|0;J=14113704+((x>>>8&15|16)<<2)|0;u=c[J>>2]|0;c[u>>2]=x<<16|L;L=(i<<4)-s|0;c[2385466]=L;c[2385454]=I;c[J>>2]=u+8;c[u+4>>2]=L<<16|K}i=i+1|0;}while((i|0)<21);z=z+1|0;}while((z|0)<16);z=G+8192|0;s=(e[v+8>>1]|0)+t|0;q=(e[v+10>>1]|0)+A|0;n=q>>>4;y=s>>>4;H=s&15;s=q&15;q=0;while(1){r=q+n<<6&1984;i=(q<<4)-s|0;K=i&65535;I=0;do{p=I+y<<1&62|r;L=b[z+((p|1)<<1)>>1]|0;u=L&65535;if(!(L<<16>>16==0|u>>>0>m>>>0)){L=e[z+(p<<1)>>1]|0;p=14113704+((L>>>8&15|16)<<2)|0;J=c[p>>2]|0;c[J>>2]=L<<16|u;u=(I<<4)-H|0;c[2385466]=u;c[2385454]=i;c[p>>2]=J+8;c[J+4>>2]=u<<16|K}I=I+1|0;}while((I|0)<21);I=q+1|0;if((I|0)<16){q=I}else{C=o;D=j;E=l;F=t;break}}}}while(0);do{if(g){t=0;do{l=t<<4;j=c[9731184+(t<<2)>>2]|0;c[9761584+(l<<2)>>2]=j;c[9761584+((l|1)<<2)>>2]=j+1028;c[9761584+((l|2)<<2)>>2]=j+2056;c[9761584+((l|3)<<2)>>2]=j+3084;c[9761584+((l|4)<<2)>>2]=j+4112;c[9761584+((l|5)<<2)>>2]=j+5140;c[9761584+((l|6)<<2)>>2]=j+6168;c[9761584+((l|7)<<2)>>2]=j+7196;c[9761584+((l|8)<<2)>>2]=j+8224;c[9761584+((l|9)<<2)>>2]=j+9252;c[9761584+((l|10)<<2)>>2]=j+10280;c[9761584+((l|11)<<2)>>2]=j+11308;c[9761584+((l|12)<<2)>>2]=j+12336;c[9761584+((l|13)<<2)>>2]=j+13364;c[9761584+((l|14)<<2)>>2]=j+14392;c[9761584+((l|15)<<2)>>2]=j+15420;j=0;o=c[9755904+(t<<2)>>2]|0;while(1){q=d[o+1|0]|0;if((q&128|0)!=0){H=9761584+((q&15|l)<<2)|0;q=c[H>>2]|0;c[H>>2]=q+4;c[q>>2]=o}q=j+1|0;if((q|0)<256){j=q;o=o+8|0}else{break}}t=t+1|0;}while((t|0)<(f|0));if((f|0)<=1){break}if((c[2415170]|0)==2){fl4(1,0);fl5(1,0);fl4(1,1);fl5(1,1);fl4(1,2);fl5(1,2);fl4(1,3);fl5(1,3);fl4(1,4);fl5(1,4);fl4(1,5);fl5(1,5);fl4(1,6);fl5(1,6);fl4(1,7);fl5(1,7);fl4(1,8);fl5(1,8);fl4(1,9);fl5(1,9);fl4(1,10);fl5(1,10);fl4(1,11);fl5(1,11);fl4(1,12);fl5(1,12);fl4(1,13);fl5(1,13);fl4(1,14);fl5(1,14);fl4(1,15);fl5(1,15);fl4(0,0);fl5(0,0);fl4(0,1);fl5(0,1);fl4(0,2);fl5(0,2);fl4(0,3);fl5(0,3);fl4(0,4);fl5(0,4);fl4(0,5);fl5(0,5);fl4(0,6);fl5(0,6);fl4(0,7);fl5(0,7);fl4(0,8);fl5(0,8);fl4(0,9);fl5(0,9);fl4(0,10);fl5(0,10);fl4(0,11);fl5(0,11);fl4(0,12);fl5(0,12);fl4(0,13);fl5(0,13);fl4(0,14);fl5(0,14);fl4(0,15);fl5(0,15);return}t=c[3541501]|0;if((e[t>>1]|0|0)==(-C|0)){k=60950}else{if((e[t+4>>1]|0|0)==(-D|0)){k=60950}else{k=60951}}if((k|0)==60950){if(((e[E+8>>1]|0)+D|0)<0){k=60951}else{k=60953}}do{if((k|0)==60951){if((e[t+8>>1]|0|0)!=(-F|0)){k=60953;break}fl4(0,0);fl4(1,0);M=1}}while(0);if((k|0)==60953){fl4(1,0);fl4(0,0);M=1}do{fl4(0,M);if((M|0)<4){fl4(1,M)}fl5(0,M-1|0);M=M+1|0;}while((M|0)<16);fl5(0,15);fl5(1,0);t=1;do{if((t|0)>3){fl4(1,t)}fl5(1,t);t=t+1|0;}while((t|0)<16);return}}while(0);if(a[9560]|0){M=0;while(1){fl4(0,M);k=M+1|0;F=a[9560]&1;if((k|0)<(F|0)){M=k}else{N=F;break}}}else{N=0}do{fl4(0,N);fl5(0,N-(a[9560]&1)|0);N=N+1|0;}while((N|0)<16);N=a[9560]|0;if(!N){return}M=16-(N&1)|0;do{fl5(0,M);M=M+1|0;}while((M|0)<16);return}function fl4(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;e=14113704+((b<<4)+d<<2)|0;c[c[e>>2]>>2]=0;f=d*3072|0;d=c[9752368+(b<<2)>>2]|0;g=d+((f|1)<<2)|0;c[e>>2]=g;h=c[d+(f<<2)>>2]|0;if((h|0)==0){return}f=14166008+(b<<2)|0;d=9733712+(b<<2)|0;b=g;g=h;do{h=c[b>>2]|0;i=h>>16;c[2385466]=i;c[e>>2]=b+4;j=h<<16;h=j>>16;c[2385454]=h;k=(c[14165960+((g>>>13&7)<<2)>>2]|0)+(g<<2&32764)|0;l=c[f>>2]|0;m=k<<5;n=l+m|0;c[2440384]=(c[3531916]|0)+((g>>>12&2032)<<2);o=c[2113306]|0;p=o<<3;q=c[2112970]|0;r=ag(o,i)|0;c[2415148]=q+((ag(c[2113298]|0,h)|0)+r);r=c[d>>2]|0;h=a[r+k|0]|0;do{if(i>>>0<304&(j|0)>-65536&(j|0)<14680064){if(h<<24>>24==0){s=r}else{c[2385336]=n;gu[c[(c[3528970]|0)+((h&255)-1<<2)>>2]&16383]();s=c[d>>2]|0}q=a[s+(k+1)|0]|0;if(q<<24>>24==0){t=s;u=c[2415148]|0}else{c[2415148]=(c[2415148]|0)+p;c[2385336]=l+(m+32);gu[c[(c[3528970]|0)+((q&255)-1<<2)>>2]&16383]();q=(c[2415148]|0)+(-p|0)|0;c[2415148]=q;t=c[d>>2]|0;u=q}c[2415148]=u+(c[2113298]<<3);q=a[t+(k+2)|0]|0;if(q<<24>>24==0){v=t}else{c[2385336]=l+(m+64);gu[c[(c[3528970]|0)+((q&255)-1<<2)>>2]&16383]();v=c[d>>2]|0}q=a[v+(k+3)|0]|0;if(q<<24>>24==0){break}c[2415148]=(c[2415148]|0)+p;c[2385336]=l+(m+96);gu[c[(c[3528970]|0)+((q&255)-1<<2)>>2]&16383]()}else{q=h&255;do{if(h<<24>>24!=0){if(!((i+7|0)>>>0<327&(j|0)>-524288&(j|0)<15728640)){break}c[2385336]=n;if((i-1|0)>>>0<312&(j|0)>0&(j|0)<15269888){gu[c[(c[3528970]|0)+(q-1<<2)>>2]&16383]();break}else{gu[c[(c[3528970]|0)+(q<<2)>>2]&16383]();break}}}while(0);q=c[d>>2]|0;o=a[q+(k+1)|0]|0;w=o&255;x=c[2415148]|0;if(o<<24>>24==0){y=q;z=x}else{c[2415148]=x+p;x=c[2385466]|0;c[2385466]=x+8;q=c[2385454]|0;do{if((x+15|0)>>>0<327&(q|0)>-8&(q|0)<240){c[2385336]=l+(m+32);if((x+7|0)>>>0<312&(q|0)>0&(q|0)<233){gu[c[(c[3528970]|0)+(w-1<<2)>>2]&16383]();break}else{gu[c[(c[3528970]|0)+(w<<2)>>2]&16383]();break}}}while(0);c[2385466]=(c[2385466]|0)-8;w=(c[2415148]|0)+(-p|0)|0;c[2415148]=w;y=c[d>>2]|0;z=w}w=(c[2385454]|0)+8|0;c[2385454]=w;c[2415148]=z+(c[2113298]<<3);q=a[y+(k+2)|0]|0;x=q&255;do{if(q<<24>>24!=0){o=c[2385466]|0;if(!((o+7|0)>>>0<327&(w|0)>-8&(w|0)<240)){break}c[2385336]=l+(m+64);if((o-1|0)>>>0<312&(w|0)>0&(w|0)<233){gu[c[(c[3528970]|0)+(x-1<<2)>>2]&16383]();break}else{gu[c[(c[3528970]|0)+(x<<2)>>2]&16383]();break}}}while(0);x=a[(c[d>>2]|0)+(k+3)|0]|0;w=x&255;if(x<<24>>24==0){break}x=c[2385466]|0;c[2385466]=x+8;c[2415148]=(c[2415148]|0)+p;q=c[2385454]|0;if(!((x+15|0)>>>0<327&(q|0)>-8&(q|0)<240)){break}c[2385336]=l+(m+96);if((x+7|0)>>>0<312&(q|0)>0&(q|0)<233){gu[c[(c[3528970]|0)+(w-1<<2)>>2]&16383]();break}else{gu[c[(c[3528970]|0)+(w<<2)>>2]&16383]();break}}}while(0);m=c[e>>2]|0;b=m+4|0;c[e>>2]=b;g=c[m>>2]|0;}while((g|0)!=0);return}function fl5(b,f){b=b|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;g=9761584+((b<<4)+f<<2)|0;c[c[g>>2]>>2]=0;h=f*257|0;f=c[9731184+(b<<2)>>2]|0;c[g>>2]=f+(h+1<<2);i=c[f+(h<<2)>>2]|0;if((i|0)==0){return}h=14166008+(b<<2)|0;f=14166e3+(b<<2)|0;j=14114136+(b<<2)|0;k=9733712+(b<<2)|0;b=i;do{i=(d[b+1|0]|0)>>>3;l=i&6;m=d[b]|0;c[2440384]=(c[3531916]|0)+((m<<2&1008)<<2);n=d[b+3|0]|0;o=(n<<8&32512|d[b+2|0])+(c[14165960+((m<<1&6|n>>>7)<<2)>>2]|0)|0;n=(c[h>>2]|0)+(o<<5)|0;m=d[b+4|0]|0;p=m&15;q=c[f>>2]|0;r=(d[b+5|0]<<1|m>>>7)+(e[q+12>>1]|0)+(a[9552]|0?36:0)|0;m=r&511;s=d[b+6|0]|0;t=s&15;u=(c[2113040]|0)+(e[q+14>>1]|0)+(d[b+7|0]<<1|s>>>7)&511;if((i&2|0)==0){v=m>>>0>384?r|-512:m;w=8}else{r=m-7|0;v=(r|0)>448?m-519|0:r;w=-8}r=i&4;i=(r|0)==0?u:u-7|0;u=(r<<2^16)-8|0;c[2385454]=(i|0)>384?i-512|0:i;i=l|1;r=o;o=0;m=n;while(1){c[2385466]=v;n=r;s=1;q=m;x=v;while(1){if(n>>>0>(c[j>>2]|0)>>>0){y=n;z=q;break}do{if((a[(c[k>>2]|0)+n|0]|0)!=0){A=c[2385454]|0;if((x+7|0)>>>0>326|(A|0)<-7|(A|0)>239){break}c[2385336]=q;B=c[2112970]|0;C=ag(c[2113306]|0,x)|0;c[2415148]=B+((ag(c[2113298]|0,A)|0)+C);C=c[3528970]|0;if(x>>>0>312|(A|0)<0|(A|0)>232){gu[c[C+(i<<2)>>2]&16383]();break}else{gu[c[C+(l<<2)>>2]&16383]();break}}}while(0);C=(c[2385466]|0)+w|0;c[2385466]=C;A=n+1|0;B=q+32|0;if((s|0)>(p|0)){y=A;z=B;break}n=A;s=s+1|0;q=B;x=C}x=o+1|0;c[2385454]=u+(c[2385454]|0);if((x|0)>(t|0)){break}else{r=y;o=x;m=z}}m=c[g>>2]|0;c[g>>2]=m+4;b=c[m>>2]|0;}while((b|0)!=0);return}function fl6(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;if((b-1|0)>>>0>2){return}c[2415170]=b;c[2440572]=(b|0)>1?2:1;c[2394750]=0;b=0;do{d=8452832+(b<<2)|0;e=(c[d>>2]|0)-1|0;c[9578968+(b<<2)>>2]=e>>>7;c[14114136+(b<<2)>>2]=e>>>5;e=0;while(1){if((e|0)>=1024){f=0;break}g=9638528+(e<<2)|0;if((c[g>>2]|0)==0){h=61034;break}else{e=e+1|0}}do{if((h|0)==61034){h=0;e=gGq(196608)|0;c[g>>2]=e;if((e|0)==0){f=0;break}gGz(e|0,0,196608);f=e}}while(0);c[9752368+(b<<2)>>2]=f;gGz(f|0,0,196608);e=0;while(1){if((e|0)>=1024){i=0;break}j=9638528+(e<<2)|0;if((c[j>>2]|0)==0){h=61039;break}else{e=e+1|0}}do{if((h|0)==61039){h=0;e=gGq(16448)|0;c[j>>2]=e;if((e|0)==0){i=0;break}gGz(e|0,0,16448);i=e}}while(0);c[9731184+(b<<2)>>2]=i;gGz(i|0,0,16448);e=0;while(1){if((e|0)>=1024){k=0;break}l=9638528+(e<<2)|0;if((c[l>>2]|0)==0){h=61044;break}else{e=e+1|0}}do{if((h|0)==61044){h=0;e=gGq(4096)|0;c[l>>2]=e;if((e|0)==0){k=0;break}gGz(e|0,0,4096);k=e}}while(0);c[9721592+(b<<2)>>2]=k;gGz(k|0,0,4096);e=(c[d>>2]|0)>>>5;m=0;while(1){if((m|0)>=1024){n=0;break}o=9638528+(m<<2)|0;if((c[o>>2]|0)==0){h=61049;break}else{m=m+1|0}}do{if((h|0)==61049){h=0;m=gGq(e)|0;c[o>>2]=m;if((m|0)==0){n=0;break}gGz(m|0,0,e|0);n=m}}while(0);c[9733712+(b<<2)>>2]=n;e=c[d>>2]|0;if(e>>>0>31){m=14166008+(b<<2)|0;p=e>>>5;e=0;do{q=e<<5;r=q+32|0;do{if((q|0)==-32){s=n+e|0;h=61058}else{t=c[m>>2]|0;u=1;v=1;w=q;do{x=a[t+w|0]|0;y=x&255;u=x<<24>>24==0&u;v=v&((y&15|0)!=0&(y&240|0)!=0);w=w+1|0;}while(w>>>0<r>>>0);w=n+e|0;if(u){s=w;h=61058;break}if(v){a[w]=9;break}else{a[w]=1;break}}}while(0);if((h|0)==61058){h=0;a[s]=0}e=e+1|0;}while(e>>>0<p>>>0)}b=b+1|0;z=c[2440572]|0;}while((b|0)<(z|0));if((c[2415170]|0)==3){gGz((c[2433429]|0)+35184|0,0,16)}c[3541490]=0;c[3541491]=32768;c[3541492]=65536;c[3541493]=98304;c[3541494]=131072;c[3541495]=163840;c[3541496]=196608;c[3541497]=229376;c[2439196]=0;b=c[2430398]|0;c[2438976]=b;if((z|0)>1){z=c[2430399]|0;s=b+2048|0;h=(c[3541506]|0)+12288|0;gGC(s|0,h|0,2048)|0;n=z+2048|0;o=(c[3541504]|0)+12288|0;gGC(n|0,o|0,2048)|0;c[2438976]=s;c[2438977]=n;c[2439196]=0;gGC(b|0,h|0,2048)|0;gGC(z|0,o|0,2048)|0}else{o=b+2048|0;z=(c[3541506]|0)+12288|0;gGC(o|0,z|0,2048)|0;c[2438976]=o;c[2439196]=0;gGC(b|0,z|0,2048)|0}if(!(a[9552]|0)){a[9552]=1}if((c[2113040]|0)==0){c[2113040]=-1}if((c[2113182]|0)==0){c[2113182]=-469}if((c[2113178]|0)==0){c[2113178]=-471}if((c[2113174]|0)==0){c[2113174]=-473}if((c[2113180]|0)==0){c[2113180]=-495}if((c[2113176]|0)==0){c[2113176]=-495}if((c[2113172]|0)!=0){return}c[2113172]=-495;return}function fl7(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a[9552]=0;c[2113040]=0;a[9560]=0;c[2113182]=0;c[2113178]=0;c[2113174]=0;c[2113180]=0;c[2113176]=0;c[2113172]=0;if((c[2440572]|0)>0){b=0}else{return}do{d=9721592+(b<<2)|0;e=c[d>>2]|0;f=0;while(1){if((f|0)>=1024){break}g=9638528+(f<<2)|0;if((c[g>>2]|0)==(e|0)){h=61093;break}else{f=f+1|0}}if((h|0)==61093){h=0;gGr(e);c[g>>2]=0}c[d>>2]=0;f=9731184+(b<<2)|0;i=c[f>>2]|0;j=0;while(1){if((j|0)>=1024){break}k=9638528+(j<<2)|0;if((c[k>>2]|0)==(i|0)){h=61097;break}else{j=j+1|0}}if((h|0)==61097){h=0;gGr(i);c[k>>2]=0}c[f>>2]=0;j=9752368+(b<<2)|0;d=c[j>>2]|0;e=0;while(1){if((e|0)>=1024){break}l=9638528+(e<<2)|0;if((c[l>>2]|0)==(d|0)){h=61101;break}else{e=e+1|0}}if((h|0)==61101){h=0;gGr(d);c[l>>2]=0}c[j>>2]=0;e=9733712+(b<<2)|0;f=c[e>>2]|0;i=0;while(1){if((i|0)>=1024){break}m=9638528+(i<<2)|0;if((c[m>>2]|0)==(f|0)){h=61105;break}else{i=i+1|0}}if((h|0)==61105){h=0;gGr(f);c[m>>2]=0}c[e>>2]=0;b=b+1|0;}while((b|0)<(c[2440572]|0));return}function fl8(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0;a=c[2440384]|0;d=c[2415148]|0;e=1;f=c[2385336]|0;while(1){g=f+4|0;h=c[f>>2]|0;i=h&15;if((i|0)!=0){b[d>>1]=c[a+(i<<2)>>2]&65535}i=h>>>4&15;if((i|0)!=0){b[d+2>>1]=c[a+(i<<2)>>2]&65535}i=h>>>8&15;if((i|0)!=0){b[d+4>>1]=c[a+(i<<2)>>2]&65535}i=h>>>12&15;if((i|0)!=0){b[d+6>>1]=c[a+(i<<2)>>2]&65535}i=h>>>16&15;if((i|0)!=0){b[d+8>>1]=c[a+(i<<2)>>2]&65535}i=h>>>20&15;if((i|0)!=0){b[d+10>>1]=c[a+(i<<2)>>2]&65535}i=h>>>24&15;if((i|0)!=0){b[d+12>>1]=c[a+(i<<2)>>2]&65535}i=h>>>28;if((i|0)!=0){b[d+14>>1]=c[a+(i<<2)>>2]&65535}if((e|0)>=8){break}d=d+640|0;e=e+1|0;f=g}c[2385336]=g;return}function fl9(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[2385454]|0;d=c[2385466]|0;e=(d|0)>-1;f=(d|0)<320;g=c[2440384]|0;h=c[2415148]|0;i=0;j=c[2385336]|0;while(1){k=j+4|0;do{if((a+i|0)>>>0<=239){l=c[j>>2]|0;m=l&15;if((m|0)!=0&e&f){b[h>>1]=c[g+(m<<2)>>2]&65535}m=l>>>4&15;if((m|0)!=0&(d|0)>-2&(d|0)<319){b[h+2>>1]=c[g+(m<<2)>>2]&65535}m=l>>>8&15;if((m|0)!=0&(d|0)>-3&(d|0)<318){b[h+4>>1]=c[g+(m<<2)>>2]&65535}m=l>>>12&15;if((m|0)!=0&(d|0)>-4&(d|0)<317){b[h+6>>1]=c[g+(m<<2)>>2]&65535}m=l>>>16&15;if((m|0)!=0&(d|0)>-5&(d|0)<316){b[h+8>>1]=c[g+(m<<2)>>2]&65535}m=l>>>20&15;if((m|0)!=0&(d|0)>-6&(d|0)<315){b[h+10>>1]=c[g+(m<<2)>>2]&65535}m=l>>>24&15;if((m|0)!=0&(d|0)>-7&(d|0)<314){b[h+12>>1]=c[g+(m<<2)>>2]&65535}m=l>>>28;if(!((m|0)!=0&(d|0)>-8&(d|0)<313)){break}b[h+14>>1]=c[g+(m<<2)>>2]&65535}}while(0);m=i+1|0;if((m|0)>=8){break}h=h+640|0;i=m;j=k}c[2385336]=k;return}function fma(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0;a=c[2440384]|0;d=c[2415148]|0;e=1;f=c[2385336]|0;while(1){g=f+4|0;h=c[f>>2]|0;i=h&15;if((i|0)!=0){b[d+14>>1]=c[a+(i<<2)>>2]&65535}i=h>>>4&15;if((i|0)!=0){b[d+12>>1]=c[a+(i<<2)>>2]&65535}i=h>>>8&15;if((i|0)!=0){b[d+10>>1]=c[a+(i<<2)>>2]&65535}i=h>>>12&15;if((i|0)!=0){b[d+8>>1]=c[a+(i<<2)>>2]&65535}i=h>>>16&15;if((i|0)!=0){b[d+6>>1]=c[a+(i<<2)>>2]&65535}i=h>>>20&15;if((i|0)!=0){b[d+4>>1]=c[a+(i<<2)>>2]&65535}i=h>>>24&15;if((i|0)!=0){b[d+2>>1]=c[a+(i<<2)>>2]&65535}i=h>>>28;if((i|0)!=0){b[d>>1]=c[a+(i<<2)>>2]&65535}if((e|0)>=8){break}d=d+640|0;e=e+1|0;f=g}c[2385336]=g;return}function fmb(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[2385454]|0;d=c[2385466]|0;e=(d|0)>-8;f=(d|0)<313;g=c[2440384]|0;h=c[2415148]|0;i=0;j=c[2385336]|0;while(1){k=j+4|0;do{if((a+i|0)>>>0<=239){l=c[j>>2]|0;m=l&15;if((m|0)!=0&e&f){b[h+14>>1]=c[g+(m<<2)>>2]&65535}m=l>>>4&15;if((m|0)!=0&(d|0)>-7&(d|0)<314){b[h+12>>1]=c[g+(m<<2)>>2]&65535}m=l>>>8&15;if((m|0)!=0&(d|0)>-6&(d|0)<315){b[h+10>>1]=c[g+(m<<2)>>2]&65535}m=l>>>12&15;if((m|0)!=0&(d|0)>-5&(d|0)<316){b[h+8>>1]=c[g+(m<<2)>>2]&65535}m=l>>>16&15;if((m|0)!=0&(d|0)>-4&(d|0)<317){b[h+6>>1]=c[g+(m<<2)>>2]&65535}m=l>>>20&15;if((m|0)!=0&(d|0)>-3&(d|0)<318){b[h+4>>1]=c[g+(m<<2)>>2]&65535}m=l>>>24&15;if((m|0)!=0&(d|0)>-2&(d|0)<319){b[h+2>>1]=c[g+(m<<2)>>2]&65535}m=l>>>28;if(!((m|0)!=0&(d|0)>-1&(d|0)<320)){break}b[h>>1]=c[g+(m<<2)>>2]&65535}}while(0);m=i+1|0;if((m|0)>=8){break}h=h+640|0;i=m;j=k}c[2385336]=k;return}function fmc(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0;a=c[2440384]|0;d=(c[2415148]|0)+4480|0;e=7;f=c[2385336]|0;while(1){g=f+4|0;h=c[f>>2]|0;i=h&15;if((i|0)!=0){b[d>>1]=c[a+(i<<2)>>2]&65535}i=h>>>4&15;if((i|0)!=0){b[d+2>>1]=c[a+(i<<2)>>2]&65535}i=h>>>8&15;if((i|0)!=0){b[d+4>>1]=c[a+(i<<2)>>2]&65535}i=h>>>12&15;if((i|0)!=0){b[d+6>>1]=c[a+(i<<2)>>2]&65535}i=h>>>16&15;if((i|0)!=0){b[d+8>>1]=c[a+(i<<2)>>2]&65535}i=h>>>20&15;if((i|0)!=0){b[d+10>>1]=c[a+(i<<2)>>2]&65535}i=h>>>24&15;if((i|0)!=0){b[d+12>>1]=c[a+(i<<2)>>2]&65535}i=h>>>28;if((i|0)!=0){b[d+14>>1]=c[a+(i<<2)>>2]&65535}if((e|0)<=0){break}d=d-640|0;e=e-1|0;f=g}c[2385336]=g;return}function fmd(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[2385454]|0;d=c[2385466]|0;e=(d|0)>-1;f=(d|0)<320;g=c[2440384]|0;h=(c[2415148]|0)+4480|0;i=7;j=c[2385336]|0;while(1){k=j+4|0;do{if((a+i|0)>>>0<=239){l=c[j>>2]|0;m=l&15;if((m|0)!=0&e&f){b[h>>1]=c[g+(m<<2)>>2]&65535}m=l>>>4&15;if((m|0)!=0&(d|0)>-2&(d|0)<319){b[h+2>>1]=c[g+(m<<2)>>2]&65535}m=l>>>8&15;if((m|0)!=0&(d|0)>-3&(d|0)<318){b[h+4>>1]=c[g+(m<<2)>>2]&65535}m=l>>>12&15;if((m|0)!=0&(d|0)>-4&(d|0)<317){b[h+6>>1]=c[g+(m<<2)>>2]&65535}m=l>>>16&15;if((m|0)!=0&(d|0)>-5&(d|0)<316){b[h+8>>1]=c[g+(m<<2)>>2]&65535}m=l>>>20&15;if((m|0)!=0&(d|0)>-6&(d|0)<315){b[h+10>>1]=c[g+(m<<2)>>2]&65535}m=l>>>24&15;if((m|0)!=0&(d|0)>-7&(d|0)<314){b[h+12>>1]=c[g+(m<<2)>>2]&65535}m=l>>>28;if(!((m|0)!=0&(d|0)>-8&(d|0)<313)){break}b[h+14>>1]=c[g+(m<<2)>>2]&65535}}while(0);if((i|0)<=0){break}h=h-640|0;i=i-1|0;j=k}c[2385336]=k;return}function fme(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0;a=c[2440384]|0;d=(c[2415148]|0)+4480|0;e=7;f=c[2385336]|0;while(1){g=f+4|0;h=c[f>>2]|0;i=h&15;if((i|0)!=0){b[d+14>>1]=c[a+(i<<2)>>2]&65535}i=h>>>4&15;if((i|0)!=0){b[d+12>>1]=c[a+(i<<2)>>2]&65535}i=h>>>8&15;if((i|0)!=0){b[d+10>>1]=c[a+(i<<2)>>2]&65535}i=h>>>12&15;if((i|0)!=0){b[d+8>>1]=c[a+(i<<2)>>2]&65535}i=h>>>16&15;if((i|0)!=0){b[d+6>>1]=c[a+(i<<2)>>2]&65535}i=h>>>20&15;if((i|0)!=0){b[d+4>>1]=c[a+(i<<2)>>2]&65535}i=h>>>24&15;if((i|0)!=0){b[d+2>>1]=c[a+(i<<2)>>2]&65535}i=h>>>28;if((i|0)!=0){b[d>>1]=c[a+(i<<2)>>2]&65535}if((e|0)<=0){break}d=d-640|0;e=e-1|0;f=g}c[2385336]=g;return}function fmf(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[2385454]|0;d=c[2385466]|0;e=(d|0)>-8;f=(d|0)<313;g=c[2440384]|0;h=(c[2415148]|0)+4480|0;i=7;j=c[2385336]|0;while(1){k=j+4|0;do{if((a+i|0)>>>0<=239){l=c[j>>2]|0;m=l&15;if((m|0)!=0&e&f){b[h+14>>1]=c[g+(m<<2)>>2]&65535}m=l>>>4&15;if((m|0)!=0&(d|0)>-7&(d|0)<314){b[h+12>>1]=c[g+(m<<2)>>2]&65535}m=l>>>8&15;if((m|0)!=0&(d|0)>-6&(d|0)<315){b[h+10>>1]=c[g+(m<<2)>>2]&65535}m=l>>>12&15;if((m|0)!=0&(d|0)>-5&(d|0)<316){b[h+8>>1]=c[g+(m<<2)>>2]&65535}m=l>>>16&15;if((m|0)!=0&(d|0)>-4&(d|0)<317){b[h+6>>1]=c[g+(m<<2)>>2]&65535}m=l>>>20&15;if((m|0)!=0&(d|0)>-3&(d|0)<318){b[h+4>>1]=c[g+(m<<2)>>2]&65535}m=l>>>24&15;if((m|0)!=0&(d|0)>-2&(d|0)<319){b[h+2>>1]=c[g+(m<<2)>>2]&65535}m=l>>>28;if(!((m|0)!=0&(d|0)>-1&(d|0)<320)){break}b[h>>1]=c[g+(m<<2)>>2]&65535}}while(0);if((i|0)<=0){break}h=h-640|0;i=i-1|0;j=k}c[2385336]=k;return}function fmg(){var a=0,d=0,e=0,f=0,g=0,h=0;a=c[2440384]|0;d=0;e=c[2415148]|0;f=c[2385336]|0;while(1){g=f+4|0;h=c[f>>2]|0;b[e>>1]=c[a+((h&15)<<2)>>2]&65535;b[e+2>>1]=c[a+((h>>>4&15)<<2)>>2]&65535;b[e+4>>1]=c[a+((h>>>8&15)<<2)>>2]&65535;b[e+6>>1]=c[a+((h>>>12&15)<<2)>>2]&65535;b[e+8>>1]=c[a+((h>>>16&15)<<2)>>2]&65535;b[e+10>>1]=c[a+((h>>>20&15)<<2)>>2]&65535;b[e+12>>1]=c[a+((h>>>24&15)<<2)>>2]&65535;b[e+14>>1]=c[a+(h>>>28<<2)>>2]&65535;h=d+1|0;if((h|0)<8){d=h;e=e+640|0;f=g}else{break}}c[2385336]=g;return}function fmh(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[2385454]|0;d=c[2385466]|0;e=d>>>0<320;f=c[2440384]|0;g=c[2415148]|0;h=0;i=c[2385336]|0;while(1){j=i+4|0;do{if((a+h|0)>>>0<=239){k=c[i>>2]|0;if(e){b[g>>1]=c[f+((k&15)<<2)>>2]&65535}if((d+1|0)>>>0<320){b[g+2>>1]=c[f+((k>>>4&15)<<2)>>2]&65535}if((d+2|0)>>>0<320){b[g+4>>1]=c[f+((k>>>8&15)<<2)>>2]&65535}if((d+3|0)>>>0<320){b[g+6>>1]=c[f+((k>>>12&15)<<2)>>2]&65535}if((d+4|0)>>>0<320){b[g+8>>1]=c[f+((k>>>16&15)<<2)>>2]&65535}if((d+5|0)>>>0<320){b[g+10>>1]=c[f+((k>>>20&15)<<2)>>2]&65535}if((d+6|0)>>>0<320){b[g+12>>1]=c[f+((k>>>24&15)<<2)>>2]&65535}if((d+7|0)>>>0>=320){break}b[g+14>>1]=c[f+(k>>>28<<2)>>2]&65535}}while(0);k=h+1|0;if((k|0)>=8){break}g=g+640|0;h=k;i=j}c[2385336]=j;return}function fmi(){var a=0,d=0,e=0,f=0,g=0,h=0;a=c[2440384]|0;d=0;e=c[2415148]|0;f=c[2385336]|0;while(1){g=f+4|0;h=c[f>>2]|0;b[e+14>>1]=c[a+((h&15)<<2)>>2]&65535;b[e+12>>1]=c[a+((h>>>4&15)<<2)>>2]&65535;b[e+10>>1]=c[a+((h>>>8&15)<<2)>>2]&65535;b[e+8>>1]=c[a+((h>>>12&15)<<2)>>2]&65535;b[e+6>>1]=c[a+((h>>>16&15)<<2)>>2]&65535;b[e+4>>1]=c[a+((h>>>20&15)<<2)>>2]&65535;b[e+2>>1]=c[a+((h>>>24&15)<<2)>>2]&65535;b[e>>1]=c[a+(h>>>28<<2)>>2]&65535;h=d+1|0;if((h|0)<8){d=h;e=e+640|0;f=g}else{break}}c[2385336]=g;return}function fmj(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[2385454]|0;d=c[2385466]|0;e=(d+7|0)>>>0<320;f=c[2440384]|0;g=c[2415148]|0;h=0;i=c[2385336]|0;while(1){j=i+4|0;do{if((a+h|0)>>>0<=239){k=c[i>>2]|0;if(e){b[g+14>>1]=c[f+((k&15)<<2)>>2]&65535}if((d+6|0)>>>0<320){b[g+12>>1]=c[f+((k>>>4&15)<<2)>>2]&65535}if((d+5|0)>>>0<320){b[g+10>>1]=c[f+((k>>>8&15)<<2)>>2]&65535}if((d+4|0)>>>0<320){b[g+8>>1]=c[f+((k>>>12&15)<<2)>>2]&65535}if((d+3|0)>>>0<320){b[g+6>>1]=c[f+((k>>>16&15)<<2)>>2]&65535}if((d+2|0)>>>0<320){b[g+4>>1]=c[f+((k>>>20&15)<<2)>>2]&65535}if((d+1|0)>>>0<320){b[g+2>>1]=c[f+((k>>>24&15)<<2)>>2]&65535}if(d>>>0>=320){break}b[g>>1]=c[f+(k>>>28<<2)>>2]&65535}}while(0);k=h+1|0;if((k|0)>=8){break}g=g+640|0;h=k;i=j}c[2385336]=j;return}function fmk(){var a=0,d=0,e=0,f=0,g=0,h=0;a=c[2440384]|0;d=7;e=(c[2415148]|0)+4480|0;f=c[2385336]|0;while(1){g=f+4|0;h=c[f>>2]|0;b[e>>1]=c[a+((h&15)<<2)>>2]&65535;b[e+2>>1]=c[a+((h>>>4&15)<<2)>>2]&65535;b[e+4>>1]=c[a+((h>>>8&15)<<2)>>2]&65535;b[e+6>>1]=c[a+((h>>>12&15)<<2)>>2]&65535;b[e+8>>1]=c[a+((h>>>16&15)<<2)>>2]&65535;b[e+10>>1]=c[a+((h>>>20&15)<<2)>>2]&65535;b[e+12>>1]=c[a+((h>>>24&15)<<2)>>2]&65535;b[e+14>>1]=c[a+(h>>>28<<2)>>2]&65535;if((d|0)>0){d=d-1|0;e=e-640|0;f=g}else{break}}c[2385336]=g;return}function fml(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[2385454]|0;d=c[2385466]|0;e=d>>>0<320;f=c[2440384]|0;g=(c[2415148]|0)+4480|0;h=7;i=c[2385336]|0;while(1){j=i+4|0;do{if((a+h|0)>>>0<=239){k=c[i>>2]|0;if(e){b[g>>1]=c[f+((k&15)<<2)>>2]&65535}if((d+1|0)>>>0<320){b[g+2>>1]=c[f+((k>>>4&15)<<2)>>2]&65535}if((d+2|0)>>>0<320){b[g+4>>1]=c[f+((k>>>8&15)<<2)>>2]&65535}if((d+3|0)>>>0<320){b[g+6>>1]=c[f+((k>>>12&15)<<2)>>2]&65535}if((d+4|0)>>>0<320){b[g+8>>1]=c[f+((k>>>16&15)<<2)>>2]&65535}if((d+5|0)>>>0<320){b[g+10>>1]=c[f+((k>>>20&15)<<2)>>2]&65535}if((d+6|0)>>>0<320){b[g+12>>1]=c[f+((k>>>24&15)<<2)>>2]&65535}if((d+7|0)>>>0>=320){break}b[g+14>>1]=c[f+(k>>>28<<2)>>2]&65535}}while(0);if((h|0)<=0){break}g=g-640|0;h=h-1|0;i=j}c[2385336]=j;return}function fmm(){var a=0,d=0,e=0,f=0,g=0,h=0;a=c[2440384]|0;d=7;e=(c[2415148]|0)+4480|0;f=c[2385336]|0;while(1){g=f+4|0;h=c[f>>2]|0;b[e+14>>1]=c[a+((h&15)<<2)>>2]&65535;b[e+12>>1]=c[a+((h>>>4&15)<<2)>>2]&65535;b[e+10>>1]=c[a+((h>>>8&15)<<2)>>2]&65535;b[e+8>>1]=c[a+((h>>>12&15)<<2)>>2]&65535;b[e+6>>1]=c[a+((h>>>16&15)<<2)>>2]&65535;b[e+4>>1]=c[a+((h>>>20&15)<<2)>>2]&65535;b[e+2>>1]=c[a+((h>>>24&15)<<2)>>2]&65535;b[e>>1]=c[a+(h>>>28<<2)>>2]&65535;if((d|0)>0){d=d-1|0;e=e-640|0;f=g}else{break}}c[2385336]=g;return}function fmn(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[2385454]|0;d=c[2385466]|0;e=(d+7|0)>>>0<320;f=c[2440384]|0;g=(c[2415148]|0)+4480|0;h=7;i=c[2385336]|0;while(1){j=i+4|0;do{if((a+h|0)>>>0<=239){k=c[i>>2]|0;if(e){b[g+14>>1]=c[f+((k&15)<<2)>>2]&65535}if((d+6|0)>>>0<320){b[g+12>>1]=c[f+((k>>>4&15)<<2)>>2]&65535}if((d+5|0)>>>0<320){b[g+10>>1]=c[f+((k>>>8&15)<<2)>>2]&65535}if((d+4|0)>>>0<320){b[g+8>>1]=c[f+((k>>>12&15)<<2)>>2]&65535}if((d+3|0)>>>0<320){b[g+6>>1]=c[f+((k>>>16&15)<<2)>>2]&65535}if((d+2|0)>>>0<320){b[g+4>>1]=c[f+((k>>>20&15)<<2)>>2]&65535}if((d+1|0)>>>0<320){b[g+2>>1]=c[f+((k>>>24&15)<<2)>>2]&65535}if(d>>>0>=320){break}b[g>>1]=c[f+(k>>>28<<2)>>2]&65535}}while(0);if((h|0)<=0){break}g=g-640|0;h=h-1|0;i=j}c[2385336]=j;return}function fmo(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[2440384]|0;d=1;e=c[2415148]|0;f=c[2385336]|0;while(1){g=f+4|0;h=c[f>>2]|0;i=h&15;if((i|0)!=0){j=c[b+(i<<2)>>2]|0;a[e]=j&255;a[e+1|0]=j>>>8&255;a[e+2|0]=j>>>16&255}j=h>>>4&15;if((j|0)!=0){i=c[b+(j<<2)>>2]|0;a[e+3|0]=i&255;a[e+4|0]=i>>>8&255;a[e+5|0]=i>>>16&255}i=h>>>8&15;if((i|0)!=0){j=c[b+(i<<2)>>2]|0;a[e+6|0]=j&255;a[e+7|0]=j>>>8&255;a[e+8|0]=j>>>16&255}j=h>>>12&15;if((j|0)!=0){i=c[b+(j<<2)>>2]|0;a[e+9|0]=i&255;a[e+10|0]=i>>>8&255;a[e+11|0]=i>>>16&255}i=h>>>16&15;if((i|0)!=0){j=c[b+(i<<2)>>2]|0;a[e+12|0]=j&255;a[e+13|0]=j>>>8&255;a[e+14|0]=j>>>16&255}j=h>>>20&15;if((j|0)!=0){i=c[b+(j<<2)>>2]|0;a[e+15|0]=i&255;a[e+16|0]=i>>>8&255;a[e+17|0]=i>>>16&255}i=h>>>24&15;if((i|0)!=0){j=c[b+(i<<2)>>2]|0;a[e+18|0]=j&255;a[e+19|0]=j>>>8&255;a[e+20|0]=j>>>16&255}j=h>>>28;if((j|0)!=0){h=c[b+(j<<2)>>2]|0;a[e+21|0]=h&255;a[e+22|0]=h>>>8&255;a[e+23|0]=h>>>16&255}if((d|0)>=8){break}d=d+1|0;e=e+960|0;f=g}c[2385336]=g;return}function fmp(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[2385454]|0;d=c[2385466]|0;e=(d|0)>-1;f=(d|0)<320;g=c[2440384]|0;h=0;i=c[2415148]|0;j=c[2385336]|0;while(1){k=j+4|0;do{if((b+h|0)>>>0<=239){l=c[j>>2]|0;m=l&15;if((m|0)!=0&e&f){n=c[g+(m<<2)>>2]|0;a[i]=n&255;a[i+1|0]=n>>>8&255;a[i+2|0]=n>>>16&255}n=l>>>4&15;if((n|0)!=0&(d|0)>-2&(d|0)<319){m=c[g+(n<<2)>>2]|0;a[i+3|0]=m&255;a[i+4|0]=m>>>8&255;a[i+5|0]=m>>>16&255}m=l>>>8&15;if((m|0)!=0&(d|0)>-3&(d|0)<318){n=c[g+(m<<2)>>2]|0;a[i+6|0]=n&255;a[i+7|0]=n>>>8&255;a[i+8|0]=n>>>16&255}n=l>>>12&15;if((n|0)!=0&(d|0)>-4&(d|0)<317){m=c[g+(n<<2)>>2]|0;a[i+9|0]=m&255;a[i+10|0]=m>>>8&255;a[i+11|0]=m>>>16&255}m=l>>>16&15;if((m|0)!=0&(d|0)>-5&(d|0)<316){n=c[g+(m<<2)>>2]|0;a[i+12|0]=n&255;a[i+13|0]=n>>>8&255;a[i+14|0]=n>>>16&255}n=l>>>20&15;if((n|0)!=0&(d|0)>-6&(d|0)<315){m=c[g+(n<<2)>>2]|0;a[i+15|0]=m&255;a[i+16|0]=m>>>8&255;a[i+17|0]=m>>>16&255}m=l>>>24&15;if((m|0)!=0&(d|0)>-7&(d|0)<314){n=c[g+(m<<2)>>2]|0;a[i+18|0]=n&255;a[i+19|0]=n>>>8&255;a[i+20|0]=n>>>16&255}n=l>>>28;if(!((n|0)!=0&(d|0)>-8&(d|0)<313)){break}l=c[g+(n<<2)>>2]|0;a[i+21|0]=l&255;a[i+22|0]=l>>>8&255;a[i+23|0]=l>>>16&255}}while(0);l=h+1|0;if((l|0)>=8){break}h=l;i=i+960|0;j=k}c[2385336]=k;return}function fmq(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[2440384]|0;d=1;e=c[2415148]|0;f=c[2385336]|0;while(1){g=f+4|0;h=c[f>>2]|0;i=h&15;if((i|0)!=0){j=c[b+(i<<2)>>2]|0;a[e+21|0]=j&255;a[e+22|0]=j>>>8&255;a[e+23|0]=j>>>16&255}j=h>>>4&15;if((j|0)!=0){i=c[b+(j<<2)>>2]|0;a[e+18|0]=i&255;a[e+19|0]=i>>>8&255;a[e+20|0]=i>>>16&255}i=h>>>8&15;if((i|0)!=0){j=c[b+(i<<2)>>2]|0;a[e+15|0]=j&255;a[e+16|0]=j>>>8&255;a[e+17|0]=j>>>16&255}j=h>>>12&15;if((j|0)!=0){i=c[b+(j<<2)>>2]|0;a[e+12|0]=i&255;a[e+13|0]=i>>>8&255;a[e+14|0]=i>>>16&255}i=h>>>16&15;if((i|0)!=0){j=c[b+(i<<2)>>2]|0;a[e+9|0]=j&255;a[e+10|0]=j>>>8&255;a[e+11|0]=j>>>16&255}j=h>>>20&15;if((j|0)!=0){i=c[b+(j<<2)>>2]|0;a[e+6|0]=i&255;a[e+7|0]=i>>>8&255;a[e+8|0]=i>>>16&255}i=h>>>24&15;if((i|0)!=0){j=c[b+(i<<2)>>2]|0;a[e+3|0]=j&255;a[e+4|0]=j>>>8&255;a[e+5|0]=j>>>16&255}j=h>>>28;if((j|0)!=0){h=c[b+(j<<2)>>2]|0;a[e]=h&255;a[e+1|0]=h>>>8&255;a[e+2|0]=h>>>16&255}if((d|0)>=8){break}d=d+1|0;e=e+960|0;f=g}c[2385336]=g;return}function fmr(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[2385454]|0;d=c[2385466]|0;e=(d|0)>-8;f=(d|0)<313;g=c[2440384]|0;h=0;i=c[2415148]|0;j=c[2385336]|0;while(1){k=j+4|0;do{if((b+h|0)>>>0<=239){l=c[j>>2]|0;m=l&15;if((m|0)!=0&e&f){n=c[g+(m<<2)>>2]|0;a[i+21|0]=n&255;a[i+22|0]=n>>>8&255;a[i+23|0]=n>>>16&255}n=l>>>4&15;if((n|0)!=0&(d|0)>-7&(d|0)<314){m=c[g+(n<<2)>>2]|0;a[i+18|0]=m&255;a[i+19|0]=m>>>8&255;a[i+20|0]=m>>>16&255}m=l>>>8&15;if((m|0)!=0&(d|0)>-6&(d|0)<315){n=c[g+(m<<2)>>2]|0;a[i+15|0]=n&255;a[i+16|0]=n>>>8&255;a[i+17|0]=n>>>16&255}n=l>>>12&15;if((n|0)!=0&(d|0)>-5&(d|0)<316){m=c[g+(n<<2)>>2]|0;a[i+12|0]=m&255;a[i+13|0]=m>>>8&255;a[i+14|0]=m>>>16&255}m=l>>>16&15;if((m|0)!=0&(d|0)>-4&(d|0)<317){n=c[g+(m<<2)>>2]|0;a[i+9|0]=n&255;a[i+10|0]=n>>>8&255;a[i+11|0]=n>>>16&255}n=l>>>20&15;if((n|0)!=0&(d|0)>-3&(d|0)<318){m=c[g+(n<<2)>>2]|0;a[i+6|0]=m&255;a[i+7|0]=m>>>8&255;a[i+8|0]=m>>>16&255}m=l>>>24&15;if((m|0)!=0&(d|0)>-2&(d|0)<319){n=c[g+(m<<2)>>2]|0;a[i+3|0]=n&255;a[i+4|0]=n>>>8&255;a[i+5|0]=n>>>16&255}n=l>>>28;if(!((n|0)!=0&(d|0)>-1&(d|0)<320)){break}l=c[g+(n<<2)>>2]|0;a[i]=l&255;a[i+1|0]=l>>>8&255;a[i+2|0]=l>>>16&255}}while(0);l=h+1|0;if((l|0)>=8){break}h=l;i=i+960|0;j=k}c[2385336]=k;return}function fms(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[2440384]|0;d=7;e=(c[2415148]|0)+6720|0;f=c[2385336]|0;while(1){g=f+4|0;h=c[f>>2]|0;i=h&15;if((i|0)!=0){j=c[b+(i<<2)>>2]|0;a[e]=j&255;a[e+1|0]=j>>>8&255;a[e+2|0]=j>>>16&255}j=h>>>4&15;if((j|0)!=0){i=c[b+(j<<2)>>2]|0;a[e+3|0]=i&255;a[e+4|0]=i>>>8&255;a[e+5|0]=i>>>16&255}i=h>>>8&15;if((i|0)!=0){j=c[b+(i<<2)>>2]|0;a[e+6|0]=j&255;a[e+7|0]=j>>>8&255;a[e+8|0]=j>>>16&255}j=h>>>12&15;if((j|0)!=0){i=c[b+(j<<2)>>2]|0;a[e+9|0]=i&255;a[e+10|0]=i>>>8&255;a[e+11|0]=i>>>16&255}i=h>>>16&15;if((i|0)!=0){j=c[b+(i<<2)>>2]|0;a[e+12|0]=j&255;a[e+13|0]=j>>>8&255;a[e+14|0]=j>>>16&255}j=h>>>20&15;if((j|0)!=0){i=c[b+(j<<2)>>2]|0;a[e+15|0]=i&255;a[e+16|0]=i>>>8&255;a[e+17|0]=i>>>16&255}i=h>>>24&15;if((i|0)!=0){j=c[b+(i<<2)>>2]|0;a[e+18|0]=j&255;a[e+19|0]=j>>>8&255;a[e+20|0]=j>>>16&255}j=h>>>28;if((j|0)!=0){h=c[b+(j<<2)>>2]|0;a[e+21|0]=h&255;a[e+22|0]=h>>>8&255;a[e+23|0]=h>>>16&255}if((d|0)<=0){break}d=d-1|0;e=e-960|0;f=g}c[2385336]=g;return}function fmt(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[2385454]|0;d=c[2385466]|0;e=(d|0)>-1;f=(d|0)<320;g=c[2440384]|0;h=7;i=(c[2415148]|0)+6720|0;j=c[2385336]|0;while(1){k=j+4|0;do{if((b+h|0)>>>0<=239){l=c[j>>2]|0;m=l&15;if((m|0)!=0&e&f){n=c[g+(m<<2)>>2]|0;a[i]=n&255;a[i+1|0]=n>>>8&255;a[i+2|0]=n>>>16&255}n=l>>>4&15;if((n|0)!=0&(d|0)>-2&(d|0)<319){m=c[g+(n<<2)>>2]|0;a[i+3|0]=m&255;a[i+4|0]=m>>>8&255;a[i+5|0]=m>>>16&255}m=l>>>8&15;if((m|0)!=0&(d|0)>-3&(d|0)<318){n=c[g+(m<<2)>>2]|0;a[i+6|0]=n&255;a[i+7|0]=n>>>8&255;a[i+8|0]=n>>>16&255}n=l>>>12&15;if((n|0)!=0&(d|0)>-4&(d|0)<317){m=c[g+(n<<2)>>2]|0;a[i+9|0]=m&255;a[i+10|0]=m>>>8&255;a[i+11|0]=m>>>16&255}m=l>>>16&15;if((m|0)!=0&(d|0)>-5&(d|0)<316){n=c[g+(m<<2)>>2]|0;a[i+12|0]=n&255;a[i+13|0]=n>>>8&255;a[i+14|0]=n>>>16&255}n=l>>>20&15;if((n|0)!=0&(d|0)>-6&(d|0)<315){m=c[g+(n<<2)>>2]|0;a[i+15|0]=m&255;a[i+16|0]=m>>>8&255;a[i+17|0]=m>>>16&255}m=l>>>24&15;if((m|0)!=0&(d|0)>-7&(d|0)<314){n=c[g+(m<<2)>>2]|0;a[i+18|0]=n&255;a[i+19|0]=n>>>8&255;a[i+20|0]=n>>>16&255}n=l>>>28;if(!((n|0)!=0&(d|0)>-8&(d|0)<313)){break}l=c[g+(n<<2)>>2]|0;a[i+21|0]=l&255;a[i+22|0]=l>>>8&255;a[i+23|0]=l>>>16&255}}while(0);if((h|0)<=0){break}h=h-1|0;i=i-960|0;j=k}c[2385336]=k;return}function fmu(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[2440384]|0;d=7;e=(c[2415148]|0)+6720|0;f=c[2385336]|0;while(1){g=f+4|0;h=c[f>>2]|0;i=h&15;if((i|0)!=0){j=c[b+(i<<2)>>2]|0;a[e+21|0]=j&255;a[e+22|0]=j>>>8&255;a[e+23|0]=j>>>16&255}j=h>>>4&15;if((j|0)!=0){i=c[b+(j<<2)>>2]|0;a[e+18|0]=i&255;a[e+19|0]=i>>>8&255;a[e+20|0]=i>>>16&255}i=h>>>8&15;if((i|0)!=0){j=c[b+(i<<2)>>2]|0;a[e+15|0]=j&255;a[e+16|0]=j>>>8&255;a[e+17|0]=j>>>16&255}j=h>>>12&15;if((j|0)!=0){i=c[b+(j<<2)>>2]|0;a[e+12|0]=i&255;a[e+13|0]=i>>>8&255;a[e+14|0]=i>>>16&255}i=h>>>16&15;if((i|0)!=0){j=c[b+(i<<2)>>2]|0;a[e+9|0]=j&255;a[e+10|0]=j>>>8&255;a[e+11|0]=j>>>16&255}j=h>>>20&15;if((j|0)!=0){i=c[b+(j<<2)>>2]|0;a[e+6|0]=i&255;a[e+7|0]=i>>>8&255;a[e+8|0]=i>>>16&255}i=h>>>24&15;if((i|0)!=0){j=c[b+(i<<2)>>2]|0;a[e+3|0]=j&255;a[e+4|0]=j>>>8&255;a[e+5|0]=j>>>16&255}j=h>>>28;if((j|0)!=0){h=c[b+(j<<2)>>2]|0;a[e]=h&255;a[e+1|0]=h>>>8&255;a[e+2|0]=h>>>16&255}if((d|0)<=0){break}d=d-1|0;e=e-960|0;f=g}c[2385336]=g;return}function fmv(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[2385454]|0;d=c[2385466]|0;e=(d|0)>-8;f=(d|0)<313;g=c[2440384]|0;h=7;i=(c[2415148]|0)+6720|0;j=c[2385336]|0;while(1){k=j+4|0;do{if((b+h|0)>>>0<=239){l=c[j>>2]|0;m=l&15;if((m|0)!=0&e&f){n=c[g+(m<<2)>>2]|0;a[i+21|0]=n&255;a[i+22|0]=n>>>8&255;a[i+23|0]=n>>>16&255}n=l>>>4&15;if((n|0)!=0&(d|0)>-7&(d|0)<314){m=c[g+(n<<2)>>2]|0;a[i+18|0]=m&255;a[i+19|0]=m>>>8&255;a[i+20|0]=m>>>16&255}m=l>>>8&15;if((m|0)!=0&(d|0)>-6&(d|0)<315){n=c[g+(m<<2)>>2]|0;a[i+15|0]=n&255;a[i+16|0]=n>>>8&255;a[i+17|0]=n>>>16&255}n=l>>>12&15;if((n|0)!=0&(d|0)>-5&(d|0)<316){m=c[g+(n<<2)>>2]|0;a[i+12|0]=m&255;a[i+13|0]=m>>>8&255;a[i+14|0]=m>>>16&255}m=l>>>16&15;if((m|0)!=0&(d|0)>-4&(d|0)<317){n=c[g+(m<<2)>>2]|0;a[i+9|0]=n&255;a[i+10|0]=n>>>8&255;a[i+11|0]=n>>>16&255}n=l>>>20&15;if((n|0)!=0&(d|0)>-3&(d|0)<318){m=c[g+(n<<2)>>2]|0;a[i+6|0]=m&255;a[i+7|0]=m>>>8&255;a[i+8|0]=m>>>16&255}m=l>>>24&15;if((m|0)!=0&(d|0)>-2&(d|0)<319){n=c[g+(m<<2)>>2]|0;a[i+3|0]=n&255;a[i+4|0]=n>>>8&255;a[i+5|0]=n>>>16&255}n=l>>>28;if(!((n|0)!=0&(d|0)>-1&(d|0)<320)){break}l=c[g+(n<<2)>>2]|0;a[i]=l&255;a[i+1|0]=l>>>8&255;a[i+2|0]=l>>>16&255}}while(0);if((h|0)<=0){break}h=h-1|0;i=i-960|0;j=k}c[2385336]=k;return}function fmw(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=c[2440384]|0;d=0;e=c[2415148]|0;f=c[2385336]|0;while(1){g=f+4|0;h=c[f>>2]|0;i=c[b+((h&15)<<2)>>2]|0;a[e]=i&255;a[e+1|0]=i>>>8&255;a[e+2|0]=i>>>16&255;i=c[b+((h>>>4&15)<<2)>>2]|0;a[e+3|0]=i&255;a[e+4|0]=i>>>8&255;a[e+5|0]=i>>>16&255;i=c[b+((h>>>8&15)<<2)>>2]|0;a[e+6|0]=i&255;a[e+7|0]=i>>>8&255;a[e+8|0]=i>>>16&255;i=c[b+((h>>>12&15)<<2)>>2]|0;a[e+9|0]=i&255;a[e+10|0]=i>>>8&255;a[e+11|0]=i>>>16&255;i=c[b+((h>>>16&15)<<2)>>2]|0;a[e+12|0]=i&255;a[e+13|0]=i>>>8&255;a[e+14|0]=i>>>16&255;i=c[b+((h>>>20&15)<<2)>>2]|0;a[e+15|0]=i&255;a[e+16|0]=i>>>8&255;a[e+17|0]=i>>>16&255;i=c[b+((h>>>24&15)<<2)>>2]|0;a[e+18|0]=i&255;a[e+19|0]=i>>>8&255;a[e+20|0]=i>>>16&255;i=c[b+(h>>>28<<2)>>2]|0;a[e+21|0]=i&255;a[e+22|0]=i>>>8&255;a[e+23|0]=i>>>16&255;i=d+1|0;if((i|0)<8){d=i;e=e+960|0;f=g}else{break}}c[2385336]=g;return}function fmx(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=c[2385454]|0;d=c[2385466]|0;e=d>>>0<320;f=c[2440384]|0;g=0;h=c[2415148]|0;i=c[2385336]|0;while(1){j=i+4|0;do{if((b+g|0)>>>0<=239){k=c[i>>2]|0;if(e){l=c[f+((k&15)<<2)>>2]|0;a[h]=l&255;a[h+1|0]=l>>>8&255;a[h+2|0]=l>>>16&255}if((d+1|0)>>>0<320){l=c[f+((k>>>4&15)<<2)>>2]|0;a[h+3|0]=l&255;a[h+4|0]=l>>>8&255;a[h+5|0]=l>>>16&255}if((d+2|0)>>>0<320){l=c[f+((k>>>8&15)<<2)>>2]|0;a[h+6|0]=l&255;a[h+7|0]=l>>>8&255;a[h+8|0]=l>>>16&255}if((d+3|0)>>>0<320){l=c[f+((k>>>12&15)<<2)>>2]|0;a[h+9|0]=l&255;a[h+10|0]=l>>>8&255;a[h+11|0]=l>>>16&255}if((d+4|0)>>>0<320){l=c[f+((k>>>16&15)<<2)>>2]|0;a[h+12|0]=l&255;a[h+13|0]=l>>>8&255;a[h+14|0]=l>>>16&255}if((d+5|0)>>>0<320){l=c[f+((k>>>20&15)<<2)>>2]|0;a[h+15|0]=l&255;a[h+16|0]=l>>>8&255;a[h+17|0]=l>>>16&255}if((d+6|0)>>>0<320){l=c[f+((k>>>24&15)<<2)>>2]|0;a[h+18|0]=l&255;a[h+19|0]=l>>>8&255;a[h+20|0]=l>>>16&255}if((d+7|0)>>>0>=320){break}l=c[f+(k>>>28<<2)>>2]|0;a[h+21|0]=l&255;a[h+22|0]=l>>>8&255;a[h+23|0]=l>>>16&255}}while(0);l=g+1|0;if((l|0)>=8){break}g=l;h=h+960|0;i=j}c[2385336]=j;return}function fmy(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=c[2440384]|0;d=0;e=c[2415148]|0;f=c[2385336]|0;while(1){g=f+4|0;h=c[f>>2]|0;i=c[b+((h&15)<<2)>>2]|0;a[e+21|0]=i&255;a[e+22|0]=i>>>8&255;a[e+23|0]=i>>>16&255;i=c[b+((h>>>4&15)<<2)>>2]|0;a[e+18|0]=i&255;a[e+19|0]=i>>>8&255;a[e+20|0]=i>>>16&255;i=c[b+((h>>>8&15)<<2)>>2]|0;a[e+15|0]=i&255;a[e+16|0]=i>>>8&255;a[e+17|0]=i>>>16&255;i=c[b+((h>>>12&15)<<2)>>2]|0;a[e+12|0]=i&255;a[e+13|0]=i>>>8&255;a[e+14|0]=i>>>16&255;i=c[b+((h>>>16&15)<<2)>>2]|0;a[e+9|0]=i&255;a[e+10|0]=i>>>8&255;a[e+11|0]=i>>>16&255;i=c[b+((h>>>20&15)<<2)>>2]|0;a[e+6|0]=i&255;a[e+7|0]=i>>>8&255;a[e+8|0]=i>>>16&255;i=c[b+((h>>>24&15)<<2)>>2]|0;a[e+3|0]=i&255;a[e+4|0]=i>>>8&255;a[e+5|0]=i>>>16&255;i=c[b+(h>>>28<<2)>>2]|0;a[e]=i&255;a[e+1|0]=i>>>8&255;a[e+2|0]=i>>>16&255;i=d+1|0;if((i|0)<8){d=i;e=e+960|0;f=g}else{break}}c[2385336]=g;return}function fmz(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=c[2385454]|0;d=c[2385466]|0;e=(d+7|0)>>>0<320;f=c[2440384]|0;g=0;h=c[2415148]|0;i=c[2385336]|0;while(1){j=i+4|0;do{if((b+g|0)>>>0<=239){k=c[i>>2]|0;if(e){l=c[f+((k&15)<<2)>>2]|0;a[h+21|0]=l&255;a[h+22|0]=l>>>8&255;a[h+23|0]=l>>>16&255}if((d+6|0)>>>0<320){l=c[f+((k>>>4&15)<<2)>>2]|0;a[h+18|0]=l&255;a[h+19|0]=l>>>8&255;a[h+20|0]=l>>>16&255}if((d+5|0)>>>0<320){l=c[f+((k>>>8&15)<<2)>>2]|0;a[h+15|0]=l&255;a[h+16|0]=l>>>8&255;a[h+17|0]=l>>>16&255}if((d+4|0)>>>0<320){l=c[f+((k>>>12&15)<<2)>>2]|0;a[h+12|0]=l&255;a[h+13|0]=l>>>8&255;a[h+14|0]=l>>>16&255}if((d+3|0)>>>0<320){l=c[f+((k>>>16&15)<<2)>>2]|0;a[h+9|0]=l&255;a[h+10|0]=l>>>8&255;a[h+11|0]=l>>>16&255}if((d+2|0)>>>0<320){l=c[f+((k>>>20&15)<<2)>>2]|0;a[h+6|0]=l&255;a[h+7|0]=l>>>8&255;a[h+8|0]=l>>>16&255}if((d+1|0)>>>0<320){l=c[f+((k>>>24&15)<<2)>>2]|0;a[h+3|0]=l&255;a[h+4|0]=l>>>8&255;a[h+5|0]=l>>>16&255}if(d>>>0>=320){break}l=c[f+(k>>>28<<2)>>2]|0;a[h]=l&255;a[h+1|0]=l>>>8&255;a[h+2|0]=l>>>16&255}}while(0);l=g+1|0;if((l|0)>=8){break}g=l;h=h+960|0;i=j}c[2385336]=j;return}function fmA(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=c[2440384]|0;d=7;e=(c[2415148]|0)+6720|0;f=c[2385336]|0;while(1){g=f+4|0;h=c[f>>2]|0;i=c[b+((h&15)<<2)>>2]|0;a[e]=i&255;a[e+1|0]=i>>>8&255;a[e+2|0]=i>>>16&255;i=c[b+((h>>>4&15)<<2)>>2]|0;a[e+3|0]=i&255;a[e+4|0]=i>>>8&255;a[e+5|0]=i>>>16&255;i=c[b+((h>>>8&15)<<2)>>2]|0;a[e+6|0]=i&255;a[e+7|0]=i>>>8&255;a[e+8|0]=i>>>16&255;i=c[b+((h>>>12&15)<<2)>>2]|0;a[e+9|0]=i&255;a[e+10|0]=i>>>8&255;a[e+11|0]=i>>>16&255;i=c[b+((h>>>16&15)<<2)>>2]|0;a[e+12|0]=i&255;a[e+13|0]=i>>>8&255;a[e+14|0]=i>>>16&255;i=c[b+((h>>>20&15)<<2)>>2]|0;a[e+15|0]=i&255;a[e+16|0]=i>>>8&255;a[e+17|0]=i>>>16&255;i=c[b+((h>>>24&15)<<2)>>2]|0;a[e+18|0]=i&255;a[e+19|0]=i>>>8&255;a[e+20|0]=i>>>16&255;i=c[b+(h>>>28<<2)>>2]|0;a[e+21|0]=i&255;a[e+22|0]=i>>>8&255;a[e+23|0]=i>>>16&255;if((d|0)>0){d=d-1|0;e=e-960|0;f=g}else{break}}c[2385336]=g;return}function fmB(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=c[2385454]|0;d=c[2385466]|0;e=d>>>0<320;f=c[2440384]|0;g=7;h=(c[2415148]|0)+6720|0;i=c[2385336]|0;while(1){j=i+4|0;do{if((b+g|0)>>>0<=239){k=c[i>>2]|0;if(e){l=c[f+((k&15)<<2)>>2]|0;a[h]=l&255;a[h+1|0]=l>>>8&255;a[h+2|0]=l>>>16&255}if((d+1|0)>>>0<320){l=c[f+((k>>>4&15)<<2)>>2]|0;a[h+3|0]=l&255;a[h+4|0]=l>>>8&255;a[h+5|0]=l>>>16&255}if((d+2|0)>>>0<320){l=c[f+((k>>>8&15)<<2)>>2]|0;a[h+6|0]=l&255;a[h+7|0]=l>>>8&255;a[h+8|0]=l>>>16&255}if((d+3|0)>>>0<320){l=c[f+((k>>>12&15)<<2)>>2]|0;a[h+9|0]=l&255;a[h+10|0]=l>>>8&255;a[h+11|0]=l>>>16&255}if((d+4|0)>>>0<320){l=c[f+((k>>>16&15)<<2)>>2]|0;a[h+12|0]=l&255;a[h+13|0]=l>>>8&255;a[h+14|0]=l>>>16&255}if((d+5|0)>>>0<320){l=c[f+((k>>>20&15)<<2)>>2]|0;a[h+15|0]=l&255;a[h+16|0]=l>>>8&255;a[h+17|0]=l>>>16&255}if((d+6|0)>>>0<320){l=c[f+((k>>>24&15)<<2)>>2]|0;a[h+18|0]=l&255;a[h+19|0]=l>>>8&255;a[h+20|0]=l>>>16&255}if((d+7|0)>>>0>=320){break}l=c[f+(k>>>28<<2)>>2]|0;a[h+21|0]=l&255;a[h+22|0]=l>>>8&255;a[h+23|0]=l>>>16&255}}while(0);if((g|0)<=0){break}g=g-1|0;h=h-960|0;i=j}c[2385336]=j;return}function fmC(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=c[2440384]|0;d=7;e=(c[2415148]|0)+6720|0;f=c[2385336]|0;while(1){g=f+4|0;h=c[f>>2]|0;i=c[b+((h&15)<<2)>>2]|0;a[e+21|0]=i&255;a[e+22|0]=i>>>8&255;a[e+23|0]=i>>>16&255;i=c[b+((h>>>4&15)<<2)>>2]|0;a[e+18|0]=i&255;a[e+19|0]=i>>>8&255;a[e+20|0]=i>>>16&255;i=c[b+((h>>>8&15)<<2)>>2]|0;a[e+15|0]=i&255;a[e+16|0]=i>>>8&255;a[e+17|0]=i>>>16&255;i=c[b+((h>>>12&15)<<2)>>2]|0;a[e+12|0]=i&255;a[e+13|0]=i>>>8&255;a[e+14|0]=i>>>16&255;i=c[b+((h>>>16&15)<<2)>>2]|0;a[e+9|0]=i&255;a[e+10|0]=i>>>8&255;a[e+11|0]=i>>>16&255;i=c[b+((h>>>20&15)<<2)>>2]|0;a[e+6|0]=i&255;a[e+7|0]=i>>>8&255;a[e+8|0]=i>>>16&255;i=c[b+((h>>>24&15)<<2)>>2]|0;a[e+3|0]=i&255;a[e+4|0]=i>>>8&255;a[e+5|0]=i>>>16&255;i=c[b+(h>>>28<<2)>>2]|0;a[e]=i&255;a[e+1|0]=i>>>8&255;a[e+2|0]=i>>>16&255;if((d|0)>0){d=d-1|0;e=e-960|0;f=g}else{break}}c[2385336]=g;return}function fmD(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=c[2385454]|0;d=c[2385466]|0;e=(d+7|0)>>>0<320;f=c[2440384]|0;g=7;h=(c[2415148]|0)+6720|0;i=c[2385336]|0;while(1){j=i+4|0;do{if((b+g|0)>>>0<=239){k=c[i>>2]|0;if(e){l=c[f+((k&15)<<2)>>2]|0;a[h+21|0]=l&255;a[h+22|0]=l>>>8&255;a[h+23|0]=l>>>16&255}if((d+6|0)>>>0<320){l=c[f+((k>>>4&15)<<2)>>2]|0;a[h+18|0]=l&255;a[h+19|0]=l>>>8&255;a[h+20|0]=l>>>16&255}if((d+5|0)>>>0<320){l=c[f+((k>>>8&15)<<2)>>2]|0;a[h+15|0]=l&255;a[h+16|0]=l>>>8&255;a[h+17|0]=l>>>16&255}if((d+4|0)>>>0<320){l=c[f+((k>>>12&15)<<2)>>2]|0;a[h+12|0]=l&255;a[h+13|0]=l>>>8&255;a[h+14|0]=l>>>16&255}if((d+3|0)>>>0<320){l=c[f+((k>>>16&15)<<2)>>2]|0;a[h+9|0]=l&255;a[h+10|0]=l>>>8&255;a[h+11|0]=l>>>16&255}if((d+2|0)>>>0<320){l=c[f+((k>>>20&15)<<2)>>2]|0;a[h+6|0]=l&255;a[h+7|0]=l>>>8&255;a[h+8|0]=l>>>16&255}if((d+1|0)>>>0<320){l=c[f+((k>>>24&15)<<2)>>2]|0;a[h+3|0]=l&255;a[h+4|0]=l>>>8&255;a[h+5|0]=l>>>16&255}if(d>>>0>=320){break}l=c[f+(k>>>28<<2)>>2]|0;a[h]=l&255;a[h+1|0]=l>>>8&255;a[h+2|0]=l>>>16&255}}while(0);if((g|0)<=0){break}g=g-1|0;h=h-960|0;i=j}c[2385336]=j;return}function fmE(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0;a=c[2440384]|0;b=c[2415148]|0;d=1;e=c[2385336]|0;while(1){f=e+4|0;g=c[e>>2]|0;h=g&15;if((h|0)!=0){c[b>>2]=c[a+(h<<2)>>2]}h=g>>>4&15;if((h|0)!=0){c[b+4>>2]=c[a+(h<<2)>>2]}h=g>>>8&15;if((h|0)!=0){c[b+8>>2]=c[a+(h<<2)>>2]}h=g>>>12&15;if((h|0)!=0){c[b+12>>2]=c[a+(h<<2)>>2]}h=g>>>16&15;if((h|0)!=0){c[b+16>>2]=c[a+(h<<2)>>2]}h=g>>>20&15;if((h|0)!=0){c[b+20>>2]=c[a+(h<<2)>>2]}h=g>>>24&15;if((h|0)!=0){c[b+24>>2]=c[a+(h<<2)>>2]}h=g>>>28;if((h|0)!=0){c[b+28>>2]=c[a+(h<<2)>>2]}if((d|0)>=8){break}b=b+1280|0;d=d+1|0;e=f}c[2385336]=f;return}function fmF(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[2385454]|0;b=c[2385466]|0;d=(b|0)>-1;e=(b|0)<320;f=c[2440384]|0;g=c[2415148]|0;h=0;i=c[2385336]|0;while(1){j=i+4|0;do{if((a+h|0)>>>0<=239){k=c[i>>2]|0;l=k&15;if((l|0)!=0&d&e){c[g>>2]=c[f+(l<<2)>>2]}l=k>>>4&15;if((l|0)!=0&(b|0)>-2&(b|0)<319){c[g+4>>2]=c[f+(l<<2)>>2]}l=k>>>8&15;if((l|0)!=0&(b|0)>-3&(b|0)<318){c[g+8>>2]=c[f+(l<<2)>>2]}l=k>>>12&15;if((l|0)!=0&(b|0)>-4&(b|0)<317){c[g+12>>2]=c[f+(l<<2)>>2]}l=k>>>16&15;if((l|0)!=0&(b|0)>-5&(b|0)<316){c[g+16>>2]=c[f+(l<<2)>>2]}l=k>>>20&15;if((l|0)!=0&(b|0)>-6&(b|0)<315){c[g+20>>2]=c[f+(l<<2)>>2]}l=k>>>24&15;if((l|0)!=0&(b|0)>-7&(b|0)<314){c[g+24>>2]=c[f+(l<<2)>>2]}l=k>>>28;if(!((l|0)!=0&(b|0)>-8&(b|0)<313)){break}c[g+28>>2]=c[f+(l<<2)>>2]}}while(0);l=h+1|0;if((l|0)>=8){break}g=g+1280|0;h=l;i=j}c[2385336]=j;return}function fmG(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0;a=c[2440384]|0;b=c[2415148]|0;d=1;e=c[2385336]|0;while(1){f=e+4|0;g=c[e>>2]|0;h=g&15;if((h|0)!=0){c[b+28>>2]=c[a+(h<<2)>>2]}h=g>>>4&15;if((h|0)!=0){c[b+24>>2]=c[a+(h<<2)>>2]}h=g>>>8&15;if((h|0)!=0){c[b+20>>2]=c[a+(h<<2)>>2]}h=g>>>12&15;if((h|0)!=0){c[b+16>>2]=c[a+(h<<2)>>2]}h=g>>>16&15;if((h|0)!=0){c[b+12>>2]=c[a+(h<<2)>>2]}h=g>>>20&15;if((h|0)!=0){c[b+8>>2]=c[a+(h<<2)>>2]}h=g>>>24&15;if((h|0)!=0){c[b+4>>2]=c[a+(h<<2)>>2]}h=g>>>28;if((h|0)!=0){c[b>>2]=c[a+(h<<2)>>2]}if((d|0)>=8){break}b=b+1280|0;d=d+1|0;e=f}c[2385336]=f;return}function fmH(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[2385454]|0;b=c[2385466]|0;d=(b|0)>-8;e=(b|0)<313;f=c[2440384]|0;g=c[2415148]|0;h=0;i=c[2385336]|0;while(1){j=i+4|0;do{if((a+h|0)>>>0<=239){k=c[i>>2]|0;l=k&15;if((l|0)!=0&d&e){c[g+28>>2]=c[f+(l<<2)>>2]}l=k>>>4&15;if((l|0)!=0&(b|0)>-7&(b|0)<314){c[g+24>>2]=c[f+(l<<2)>>2]}l=k>>>8&15;if((l|0)!=0&(b|0)>-6&(b|0)<315){c[g+20>>2]=c[f+(l<<2)>>2]}l=k>>>12&15;if((l|0)!=0&(b|0)>-5&(b|0)<316){c[g+16>>2]=c[f+(l<<2)>>2]}l=k>>>16&15;if((l|0)!=0&(b|0)>-4&(b|0)<317){c[g+12>>2]=c[f+(l<<2)>>2]}l=k>>>20&15;if((l|0)!=0&(b|0)>-3&(b|0)<318){c[g+8>>2]=c[f+(l<<2)>>2]}l=k>>>24&15;if((l|0)!=0&(b|0)>-2&(b|0)<319){c[g+4>>2]=c[f+(l<<2)>>2]}l=k>>>28;if(!((l|0)!=0&(b|0)>-1&(b|0)<320)){break}c[g>>2]=c[f+(l<<2)>>2]}}while(0);l=h+1|0;if((l|0)>=8){break}g=g+1280|0;h=l;i=j}c[2385336]=j;return}function fmI(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0;a=c[2440384]|0;b=(c[2415148]|0)+8960|0;d=7;e=c[2385336]|0;while(1){f=e+4|0;g=c[e>>2]|0;h=g&15;if((h|0)!=0){c[b>>2]=c[a+(h<<2)>>2]}h=g>>>4&15;if((h|0)!=0){c[b+4>>2]=c[a+(h<<2)>>2]}h=g>>>8&15;if((h|0)!=0){c[b+8>>2]=c[a+(h<<2)>>2]}h=g>>>12&15;if((h|0)!=0){c[b+12>>2]=c[a+(h<<2)>>2]}h=g>>>16&15;if((h|0)!=0){c[b+16>>2]=c[a+(h<<2)>>2]}h=g>>>20&15;if((h|0)!=0){c[b+20>>2]=c[a+(h<<2)>>2]}h=g>>>24&15;if((h|0)!=0){c[b+24>>2]=c[a+(h<<2)>>2]}h=g>>>28;if((h|0)!=0){c[b+28>>2]=c[a+(h<<2)>>2]}if((d|0)<=0){break}b=b-1280|0;d=d-1|0;e=f}c[2385336]=f;return}function fmJ(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[2385454]|0;b=c[2385466]|0;d=(b|0)>-1;e=(b|0)<320;f=c[2440384]|0;g=(c[2415148]|0)+8960|0;h=7;i=c[2385336]|0;while(1){j=i+4|0;do{if((a+h|0)>>>0<=239){k=c[i>>2]|0;l=k&15;if((l|0)!=0&d&e){c[g>>2]=c[f+(l<<2)>>2]}l=k>>>4&15;if((l|0)!=0&(b|0)>-2&(b|0)<319){c[g+4>>2]=c[f+(l<<2)>>2]}l=k>>>8&15;if((l|0)!=0&(b|0)>-3&(b|0)<318){c[g+8>>2]=c[f+(l<<2)>>2]}l=k>>>12&15;if((l|0)!=0&(b|0)>-4&(b|0)<317){c[g+12>>2]=c[f+(l<<2)>>2]}l=k>>>16&15;if((l|0)!=0&(b|0)>-5&(b|0)<316){c[g+16>>2]=c[f+(l<<2)>>2]}l=k>>>20&15;if((l|0)!=0&(b|0)>-6&(b|0)<315){c[g+20>>2]=c[f+(l<<2)>>2]}l=k>>>24&15;if((l|0)!=0&(b|0)>-7&(b|0)<314){c[g+24>>2]=c[f+(l<<2)>>2]}l=k>>>28;if(!((l|0)!=0&(b|0)>-8&(b|0)<313)){break}c[g+28>>2]=c[f+(l<<2)>>2]}}while(0);if((h|0)<=0){break}g=g-1280|0;h=h-1|0;i=j}c[2385336]=j;return}function fmK(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0;a=c[2440384]|0;b=(c[2415148]|0)+8960|0;d=7;e=c[2385336]|0;while(1){f=e+4|0;g=c[e>>2]|0;h=g&15;if((h|0)!=0){c[b+28>>2]=c[a+(h<<2)>>2]}h=g>>>4&15;if((h|0)!=0){c[b+24>>2]=c[a+(h<<2)>>2]}h=g>>>8&15;if((h|0)!=0){c[b+20>>2]=c[a+(h<<2)>>2]}h=g>>>12&15;if((h|0)!=0){c[b+16>>2]=c[a+(h<<2)>>2]}h=g>>>16&15;if((h|0)!=0){c[b+12>>2]=c[a+(h<<2)>>2]}h=g>>>20&15;if((h|0)!=0){c[b+8>>2]=c[a+(h<<2)>>2]}h=g>>>24&15;if((h|0)!=0){c[b+4>>2]=c[a+(h<<2)>>2]}h=g>>>28;if((h|0)!=0){c[b>>2]=c[a+(h<<2)>>2]}if((d|0)<=0){break}b=b-1280|0;d=d-1|0;e=f}c[2385336]=f;return}function fmL(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[2385454]|0;b=c[2385466]|0;d=(b|0)>-8;e=(b|0)<313;f=c[2440384]|0;g=(c[2415148]|0)+8960|0;h=7;i=c[2385336]|0;while(1){j=i+4|0;do{if((a+h|0)>>>0<=239){k=c[i>>2]|0;l=k&15;if((l|0)!=0&d&e){c[g+28>>2]=c[f+(l<<2)>>2]}l=k>>>4&15;if((l|0)!=0&(b|0)>-7&(b|0)<314){c[g+24>>2]=c[f+(l<<2)>>2]}l=k>>>8&15;if((l|0)!=0&(b|0)>-6&(b|0)<315){c[g+20>>2]=c[f+(l<<2)>>2]}l=k>>>12&15;if((l|0)!=0&(b|0)>-5&(b|0)<316){c[g+16>>2]=c[f+(l<<2)>>2]}l=k>>>16&15;if((l|0)!=0&(b|0)>-4&(b|0)<317){c[g+12>>2]=c[f+(l<<2)>>2]}l=k>>>20&15;if((l|0)!=0&(b|0)>-3&(b|0)<318){c[g+8>>2]=c[f+(l<<2)>>2]}l=k>>>24&15;if((l|0)!=0&(b|0)>-2&(b|0)<319){c[g+4>>2]=c[f+(l<<2)>>2]}l=k>>>28;if(!((l|0)!=0&(b|0)>-1&(b|0)<320)){break}c[g>>2]=c[f+(l<<2)>>2]}}while(0);if((h|0)<=0){break}g=g-1280|0;h=h-1|0;i=j}c[2385336]=j;return}function fmM(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[2440384]|0;b=0;d=c[2415148]|0;e=c[2385336]|0;while(1){f=e+4|0;g=c[e>>2]|0;c[d>>2]=c[a+((g&15)<<2)>>2];c[d+4>>2]=c[a+((g>>>4&15)<<2)>>2];c[d+8>>2]=c[a+((g>>>8&15)<<2)>>2];c[d+12>>2]=c[a+((g>>>12&15)<<2)>>2];c[d+16>>2]=c[a+((g>>>16&15)<<2)>>2];c[d+20>>2]=c[a+((g>>>20&15)<<2)>>2];c[d+24>>2]=c[a+((g>>>24&15)<<2)>>2];c[d+28>>2]=c[a+(g>>>28<<2)>>2];g=b+1|0;if((g|0)<8){b=g;d=d+1280|0;e=f}else{break}}c[2385336]=f;return}function fmN(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a=c[2385454]|0;b=c[2385466]|0;d=b>>>0<320;e=c[2440384]|0;f=c[2415148]|0;g=0;h=c[2385336]|0;while(1){i=h+4|0;do{if((a+g|0)>>>0<=239){j=c[h>>2]|0;if(d){c[f>>2]=c[e+((j&15)<<2)>>2]}if((b+1|0)>>>0<320){c[f+4>>2]=c[e+((j>>>4&15)<<2)>>2]}if((b+2|0)>>>0<320){c[f+8>>2]=c[e+((j>>>8&15)<<2)>>2]}if((b+3|0)>>>0<320){c[f+12>>2]=c[e+((j>>>12&15)<<2)>>2]}if((b+4|0)>>>0<320){c[f+16>>2]=c[e+((j>>>16&15)<<2)>>2]}if((b+5|0)>>>0<320){c[f+20>>2]=c[e+((j>>>20&15)<<2)>>2]}if((b+6|0)>>>0<320){c[f+24>>2]=c[e+((j>>>24&15)<<2)>>2]}if((b+7|0)>>>0>=320){break}c[f+28>>2]=c[e+(j>>>28<<2)>>2]}}while(0);j=g+1|0;if((j|0)>=8){break}f=f+1280|0;g=j;h=i}c[2385336]=i;return}function fmO(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[2440384]|0;b=0;d=c[2415148]|0;e=c[2385336]|0;while(1){f=e+4|0;g=c[e>>2]|0;c[d+28>>2]=c[a+((g&15)<<2)>>2];c[d+24>>2]=c[a+((g>>>4&15)<<2)>>2];c[d+20>>2]=c[a+((g>>>8&15)<<2)>>2];c[d+16>>2]=c[a+((g>>>12&15)<<2)>>2];c[d+12>>2]=c[a+((g>>>16&15)<<2)>>2];c[d+8>>2]=c[a+((g>>>20&15)<<2)>>2];c[d+4>>2]=c[a+((g>>>24&15)<<2)>>2];c[d>>2]=c[a+(g>>>28<<2)>>2];g=b+1|0;if((g|0)<8){b=g;d=d+1280|0;e=f}else{break}}c[2385336]=f;return}function fmP(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a=c[2385454]|0;b=c[2385466]|0;d=(b+7|0)>>>0<320;e=c[2440384]|0;f=c[2415148]|0;g=0;h=c[2385336]|0;while(1){i=h+4|0;do{if((a+g|0)>>>0<=239){j=c[h>>2]|0;if(d){c[f+28>>2]=c[e+((j&15)<<2)>>2]}if((b+6|0)>>>0<320){c[f+24>>2]=c[e+((j>>>4&15)<<2)>>2]}if((b+5|0)>>>0<320){c[f+20>>2]=c[e+((j>>>8&15)<<2)>>2]}if((b+4|0)>>>0<320){c[f+16>>2]=c[e+((j>>>12&15)<<2)>>2]}if((b+3|0)>>>0<320){c[f+12>>2]=c[e+((j>>>16&15)<<2)>>2]}if((b+2|0)>>>0<320){c[f+8>>2]=c[e+((j>>>20&15)<<2)>>2]}if((b+1|0)>>>0<320){c[f+4>>2]=c[e+((j>>>24&15)<<2)>>2]}if(b>>>0>=320){break}c[f>>2]=c[e+(j>>>28<<2)>>2]}}while(0);j=g+1|0;if((j|0)>=8){break}f=f+1280|0;g=j;h=i}c[2385336]=i;return}function fmQ(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[2440384]|0;b=7;d=(c[2415148]|0)+8960|0;e=c[2385336]|0;while(1){f=e+4|0;g=c[e>>2]|0;c[d>>2]=c[a+((g&15)<<2)>>2];c[d+4>>2]=c[a+((g>>>4&15)<<2)>>2];c[d+8>>2]=c[a+((g>>>8&15)<<2)>>2];c[d+12>>2]=c[a+((g>>>12&15)<<2)>>2];c[d+16>>2]=c[a+((g>>>16&15)<<2)>>2];c[d+20>>2]=c[a+((g>>>20&15)<<2)>>2];c[d+24>>2]=c[a+((g>>>24&15)<<2)>>2];c[d+28>>2]=c[a+(g>>>28<<2)>>2];if((b|0)>0){b=b-1|0;d=d-1280|0;e=f}else{break}}c[2385336]=f;return}function fmR(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a=c[2385454]|0;b=c[2385466]|0;d=b>>>0<320;e=c[2440384]|0;f=(c[2415148]|0)+8960|0;g=7;h=c[2385336]|0;while(1){i=h+4|0;do{if((a+g|0)>>>0<=239){j=c[h>>2]|0;if(d){c[f>>2]=c[e+((j&15)<<2)>>2]}if((b+1|0)>>>0<320){c[f+4>>2]=c[e+((j>>>4&15)<<2)>>2]}if((b+2|0)>>>0<320){c[f+8>>2]=c[e+((j>>>8&15)<<2)>>2]}if((b+3|0)>>>0<320){c[f+12>>2]=c[e+((j>>>12&15)<<2)>>2]}if((b+4|0)>>>0<320){c[f+16>>2]=c[e+((j>>>16&15)<<2)>>2]}if((b+5|0)>>>0<320){c[f+20>>2]=c[e+((j>>>20&15)<<2)>>2]}if((b+6|0)>>>0<320){c[f+24>>2]=c[e+((j>>>24&15)<<2)>>2]}if((b+7|0)>>>0>=320){break}c[f+28>>2]=c[e+(j>>>28<<2)>>2]}}while(0);if((g|0)<=0){break}f=f-1280|0;g=g-1|0;h=i}c[2385336]=i;return}function fmS(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[2440384]|0;b=7;d=(c[2415148]|0)+8960|0;e=c[2385336]|0;while(1){f=e+4|0;g=c[e>>2]|0;c[d+28>>2]=c[a+((g&15)<<2)>>2];c[d+24>>2]=c[a+((g>>>4&15)<<2)>>2];c[d+20>>2]=c[a+((g>>>8&15)<<2)>>2];c[d+16>>2]=c[a+((g>>>12&15)<<2)>>2];c[d+12>>2]=c[a+((g>>>16&15)<<2)>>2];c[d+8>>2]=c[a+((g>>>20&15)<<2)>>2];c[d+4>>2]=c[a+((g>>>24&15)<<2)>>2];c[d>>2]=c[a+(g>>>28<<2)>>2];if((b|0)>0){b=b-1|0;d=d-1280|0;e=f}else{break}}c[2385336]=f;return}function fmT(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a=c[2385454]|0;b=c[2385466]|0;d=(b+7|0)>>>0<320;e=c[2440384]|0;f=(c[2415148]|0)+8960|0;g=7;h=c[2385336]|0;while(1){i=h+4|0;do{if((a+g|0)>>>0<=239){j=c[h>>2]|0;if(d){c[f+28>>2]=c[e+((j&15)<<2)>>2]}if((b+6|0)>>>0<320){c[f+24>>2]=c[e+((j>>>4&15)<<2)>>2]}if((b+5|0)>>>0<320){c[f+20>>2]=c[e+((j>>>8&15)<<2)>>2]}if((b+4|0)>>>0<320){c[f+16>>2]=c[e+((j>>>12&15)<<2)>>2]}if((b+3|0)>>>0<320){c[f+12>>2]=c[e+((j>>>16&15)<<2)>>2]}if((b+2|0)>>>0<320){c[f+8>>2]=c[e+((j>>>20&15)<<2)>>2]}if((b+1|0)>>>0<320){c[f+4>>2]=c[e+((j>>>24&15)<<2)>>2]}if(b>>>0>=320){break}c[f>>2]=c[e+(j>>>28<<2)>>2]}}while(0);if((g|0)<=0){break}f=f-1280|0;g=g-1|0;h=i}c[2385336]=i;return}function fmU(b){b=b|0;var e=0,f=0,g=0,h=0;switch(b&255|0){case 12:{e=a[9625491]|0;return e|0};case 28:{e=a[9625493]|0;return e|0};case 8:{e=a[9625490]|0;return e|0};case 0:{b=c[3540984]|0;f=(d[b+5887|0]|0|128)&(d[b+5886|0]|0);if((a[b+5884|0]&2)==0){g=f&255}else{g=(a[(c[b+5828>>2]|0)+100|0]&1|f)&255}e=g|6;return e|0};case 20:{e=a[9625488]|0;return e|0};case 16:{g=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;if((g|0)<(c[2113018]|0)){h=g>>>31<<7&255}else{h=-128}e=h|a[9625492];return e|0};case 24:{e=a[9625489]|0;return e|0};default:{e=0;return e|0}}return 0}function fmV(b,e){b=b|0;e=e|0;var f=0;f=b&255;if((f|0)==0){a[(c[3540984]|0)+5885|0]=e;return}else if((f|0)==1){f=c[3540984]|0;b=c[f+5876>>2]|0;if((b|0)!=0){gg[b&4095](c[f+5880>>2]|0,0)}lH(f,d[f+5885|0]|0,e&255);return}else{return}}function fmW(a){a=a|0;var b=0;if(!((a|0)==1048577|(a|0)==3145729)){b=0;return b|0}a=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;if((a|0)>=(c[2113018]|0)){b=1;return b|0}b=a>>>31&255;return b|0}function fmX(a){a=a|0;var d=0;if((a|0)==2097154){d=(c[3542216]|0)>>>1&16383;return d|0}else if((a|0)==2097156){d=b[(c[3542214]|0)+((c[3542216]&32767)<<1)>>1]|0;return d|0}else if((a|0)==2097158){d=b[(c[3542214]|0)+((c[3542216]&32767)+1<<1)>>1]|0;return d|0}else if((a|0)==2097168|(a|0)==2097169|(a|0)==2097170|(a|0)==2097171|(a|0)==2097172|(a|0)==2097173|(a|0)==2097174|(a|0)==2097175|(a|0)==2097176|(a|0)==2097177|(a|0)==2097178|(a|0)==2097179|(a|0)==2097180|(a|0)==2097181|(a|0)==2097182|(a|0)==2097183){d=b[14168832+((a>>>1&7)<<1)>>1]|0;return d|0}else if((a|0)==1048578){d=c[3541526]&1023;return d|0}else if((a|0)==1048582){d=b[(c[3541522]|0)+((c[3541526]&63)<<1)>>1]|0;return d|0}else if((a|0)==1048580){d=b[(c[3541524]|0)+((c[3541526]&1023)<<1)>>1]|0;return d|0}else if((a|0)==1048576|(a|0)==3145728){a=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;if((a|0)>=(c[2113018]|0)){d=1;return d|0}d=a>>>31&65535;return d|0}else{d=0;return d|0}return 0}function fmY(d,e){d=d|0;e=e|0;if((d|0)==3145731){a[9722056]=e<<24>>24!=0|0;return}else if((d|0)==1048582){d=c[3541526]|0;b[(c[3541522]|0)+((d&63)<<1)>>1]=e&255;c[3541526]=d+1;return}else{return}}function fmZ(d,e){d=d|0;e=e|0;var f=0;if((d|0)==3145730){a[9722056]=(e&255)!=0|0;return}else if((d|0)==2097156){f=c[3542216]|0;b[(c[3542214]|0)+((f&32767)<<1)>>1]=e;c[3542216]=f+1;return}else if((d|0)==3407874){c[2113312]=e&65535;return}else if((d|0)==1048580){f=c[3541526]|0;b[(c[3541524]|0)+((f&1023)<<1)>>1]=e;c[3541526]=f+1;return}else if((d|0)==1048582){f=c[3541526]|0;b[(c[3541522]|0)+((f&63)<<1)>>1]=e;c[3541526]=f+1;return}else if((d|0)==2097154){c[3542216]=(e&65535)<<1&32766;return}else if((d|0)==2097158){f=c[3542216]|0;b[(c[3542214]|0)+((f&32767)<<1)>>1]=e;c[3542216]=f+1;return}else if((d|0)==1048578){c[3541526]=e&1023;return}else if((d|0)==3407872){c[2113314]=e&65535;return}else if((d|0)==2097168|(d|0)==2097169|(d|0)==2097170|(d|0)==2097171|(d|0)==2097172|(d|0)==2097173|(d|0)==2097174|(d|0)==2097175|(d|0)==2097176|(d|0)==2097177|(d|0)==2097178|(d|0)==2097179|(d|0)==2097180|(d|0)==2097181|(d|0)==2097182|(d|0)==2097183){b[14168832+((d>>>1&7)<<1)>>1]=e;return}else{return}}function fm_(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4499900+(b*112|0)>>2];c[a+104>>2]=c[4499904+(b*112|0)>>2];c[a+108>>2]=c[4499908+(b*112|0)>>2];d=0;return d|0}function fm$(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=4499800+(b*112|0);e=0;return e|0}function fm0(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1448672+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function fm1(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>49){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4501032+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fm2(){var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;d=i;i=i+120|0;e=d|0;f=d+112|0;c[2424]=5516;c[2113316]=1048576;c[2113212]=524288;c[2426656]=0;c[2418124]=0;c[3532626]=262144;c[3542212]=294912;c[3541520]=1343488;c[2405594]=1867776;c[2418238]=1867776;c[2411406]=1884160;c[2406884]=1888256;c[3532636]=1892352;c[3542214]=1925120;c[3541524]=1990656;c[3541522]=1992704;c[2411506]=1992832;c[3531916]=1992832;c[3531914]=1996928;g=0;while(1){if((g|0)>=1024){break}j=9638528+(g<<2)|0;if((c[j>>2]|0)==0){k=62007;break}else{g=g+1|0}}do{if((k|0)==62007){g=gGq(2001024)|0;c[j>>2]=g;if((g|0)==0){break}c[2426656]=g;gGz(g|0,0,2001024);c[2418124]=g;c[3532626]=g+262144;c[3542212]=g+294912;l=(c[2113316]|0)+294912|0;c[3541520]=g+l;m=l+(c[2113212]|0)|0;l=g+m|0;c[2405594]=l;c[2418238]=l;c[2411406]=g+(m+16384);c[2406884]=g+(m+20480);c[3532636]=g+(m+24576);c[3542214]=g+(m+57344);c[3541524]=g+(m+122880);c[3541522]=g+(m+124928);l=g+(m+125056)|0;c[2411506]=l;c[3531916]=l;c[3531914]=g+(m+129152);c[2414046]=g+(m+133248);fpk(g,2)|0;fpl(c[3542212]|0,2,2,c[2113316]|0,0);fni(c[3541520]|0,4,c[2113212]|0);g=c[3532626]|0;do{if((c[3542200]|0)!=0){m=e+108|0;c[m>>2]=0;l=e+100|0;c[l>>2]=0;n=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[n&16383](e,8)|0;if((c[m>>2]|0)==0){break}m=c[l>>2]|0;c[f>>2]=9534384;l=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[l&16383](f,8,0)|0;if((m|0)<1){break}gzL(g,0,8)|0}}while(0);fxU(0,425984);if((c[2394]|0)==0){o=c[2112932]|0}else{c[2394]=0;g=c[3532596]|0;c[2112932]=g;m=c[3532592]|0;if((m|0)!=0){gGC(9104152,m|0,280)|0}c[2113054]=c[2113060];o=g}g=c[2418124]|0;m=o|0;l=0;while(1){n=g+l|0;c[m>>2]=n;c[m+131072>>2]=n;n=l+1024|0;if(n>>>0>262143){break}else{m=m+4|0;l=n}}l=c[2418238]|0;c[o+9216>>2]=l;c[o+74752>>2]=l;c[o+140288>>2]=l;m=l+1024|0;c[o+9220>>2]=m;c[o+74756>>2]=m;c[o+140292>>2]=m;m=l+2048|0;c[o+9224>>2]=m;c[o+74760>>2]=m;c[o+140296>>2]=m;m=l+3072|0;c[o+9228>>2]=m;c[o+74764>>2]=m;c[o+140300>>2]=m;m=l+4096|0;c[o+9232>>2]=m;c[o+74768>>2]=m;c[o+140304>>2]=m;m=l+5120|0;c[o+9236>>2]=m;c[o+74772>>2]=m;c[o+140308>>2]=m;m=l+6144|0;c[o+9240>>2]=m;c[o+74776>>2]=m;c[o+140312>>2]=m;m=l+7168|0;c[o+9244>>2]=m;c[o+74780>>2]=m;c[o+140316>>2]=m;m=l+8192|0;c[o+9248>>2]=m;c[o+74784>>2]=m;c[o+140320>>2]=m;m=l+9216|0;c[o+9252>>2]=m;c[o+74788>>2]=m;c[o+140324>>2]=m;m=l+10240|0;c[o+9256>>2]=m;c[o+74792>>2]=m;c[o+140328>>2]=m;m=l+11264|0;c[o+9260>>2]=m;c[o+74796>>2]=m;c[o+140332>>2]=m;m=l+12288|0;c[o+9264>>2]=m;c[o+74800>>2]=m;c[o+140336>>2]=m;m=l+13312|0;c[o+9268>>2]=m;c[o+74804>>2]=m;c[o+140340>>2]=m;m=l+14336|0;c[o+9272>>2]=m;c[o+74808>>2]=m;c[o+140344>>2]=m;m=l+15360|0;c[o+9276>>2]=m;c[o+74812>>2]=m;c[o+140348>>2]=m;m=c[2411406]|0;c[o+12352>>2]=m;c[o+77888>>2]=m;c[o+143424>>2]=m;l=m+1024|0;c[o+12356>>2]=l;c[o+77892>>2]=l;c[o+143428>>2]=l;l=c[2406884]|0;c[o+12384>>2]=l;c[o+77920>>2]=l;c[o+143456>>2]=l;m=l+1024|0;c[o+12388>>2]=m;c[o+77924>>2]=m;c[o+143460>>2]=m;c[o+196688>>2]=706;c[o+196608>>2]=1516;c[o+196728>>2]=432;c[o+196648>>2]=138;c[o+5120>>2]=1;c[o+70656>>2]=1;c[o+136192>>2]=1;c[o+5124>>2]=1;c[o+70660>>2]=1;c[o+136196>>2]=1;c[o+5128>>2]=1;c[o+70664>>2]=1;c[o+136200>>2]=1;c[o+5132>>2]=1;c[o+70668>>2]=1;c[o+136204>>2]=1;c[o+196612>>2]=594;c[o+196692>>2]=2082;c[o+196652>>2]=1774;c[o+196732>>2]=1304;m=c[3532592]|0;if((m|0)!=0){gGC(m|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fpA();fwR(0);m=c[2439330]|0;l=(m|0)==0;if(!l){g=m;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];g=c[3528484]|0;c[2076596]=g;n=c[2417276]|0;c[3541536]=n;c[1836236]=0;c[m+4172>>2]=2342;c[m+4176>>2]=2216;p=c[3532626]|0;q=0;r=0;while(1){c[m+76+(r<<2)>>2]=p+(r<<8);s=q+1&65535;if((s&65535)>127){t=0;u=0;break}else{q=s;r=s&65535}}while(1){r=p+(u<<8)|0;c[m+76+(u+512<<2)>>2]=r;c[m+76+(u+768<<2)>>2]=r;r=t+1&65535;if((r&65535)>127){break}else{t=r;u=r&65535}}p=c[3532636]|0;r=128;q=128;while(1){c[m+76+(q<<2)>>2]=p+((q<<8)-32768);s=r+1&65535;if((s&65535)>255){v=128;w=128;break}else{r=s;q=s&65535}}while(1){c[m+76+(w+256<<2)>>2]=p+((w<<8)-32768);q=v+1&65535;if((q&65535)>255){x=128;y=128;break}else{v=q;w=q&65535}}while(1){q=p+((y<<8)-32768)|0;c[m+76+(y+512<<2)>>2]=q;c[m+76+(y+768<<2)>>2]=q;q=x+1&65535;if((q&65535)>255){break}else{x=q;y=q&65535}}if(!l){p=m;gGC(p|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=g;c[2417276]=n;c[1836236]=-1;c[2113016]=1024;c[3531920]=c[2411406];c[3531918]=c[2406884];UL(35e5,1078,3456,0);c[2438224]=35e5;c[2433522]=3416;c[2406672]=1752;c[3528468]=9362;c[2443842]=584;h[745398]=1.0;a[3203264]=1;a[7072664]=1;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];p=c[3532592]|0;if((p|0)!=0){gGC(9104152,p|0,280)|0}c[2113054]=c[2113060]}RI();p=c[2394]|0;q=c[14130368+(p<<2)>>2]|0;if((q|0)!=0){gGC(q|0,9104152,280)|0}c[8452240+(p<<2)>>2]=c[2113054];c[2394]=-1;p=c[2439330]|0;q=(p|0)==0;if(!q){r=p;gGC(9706056,r|0,76)|0}r=c[2438118]|0;c[2433530]=r;s=c[3528484]|0;c[2076596]=s;z=c[2417276]|0;c[3541536]=z;c[1836236]=0;gGz(9706056,0,76);if(!q){q=p;gGC(q|0,9706056,76)|0}c[2438118]=r;c[3528484]=s;c[2417276]=z;c[1836236]=-1;c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;lw(c[3540984]|0);a[9722056]=0;A=0;i=d;return A|0}}while(0);c[2426656]=0;A=1;i=d;return A|0}function fm3(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=a[7452584]|0;if(b){d=0;e=b&1;while(1){b=14163936+(d<<2)|0;f=c[b>>2]|0;g=c[2113006]|0;if((g|0)==0){h=62051}else{i=g-1|0;c[2113006]=i;if((i|0)==0){h=62051}}if((h|0)==62051){h=0;c[2383474]=0}if((f|0)==0){j=e}else{gGr(f);j=a[7452584]&1}c[b>>2]=0;b=d+1|0;if((b|0)<(j|0)){d=b;e=j}else{break}}}a[7452584]=0;c[2438224]=0;c[2433522]=0;c[2406672]=0;c[3528468]=0;j=c[2406688]|0;if((j|0)!=0){gGr(j);c[2406688]=0}c[2432972]=0;fpB();fwZ();if((c[2392]|0)>=0){j=0;do{e=14130368+(j<<2)|0;d=c[e>>2]|0;if((d|0)!=0){gGr(d);c[e>>2]=0}e=14130384+(j<<2)|0;d=c[e>>2]|0;if((d|0)!=0){gGr(d);c[e>>2]=0}j=j+1|0;}while((j|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;j=c[2426656]|0;e=0;while(1){if((e|0)>=1024){h=62069;break}k=9638528+(e<<2)|0;if((c[k>>2]|0)==(j|0)){break}else{e=e+1|0}}if((h|0)==62069){c[2426656]=0;return 0}gGr(j);c[k>>2]=0;c[2426656]=0;return 0}function fm4(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;if((a[9623592]|0)!=0){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=i;c[1836236]=-1;c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;lw(c[3540984]|0);a[9722056]=0}a[9625488]=0;a[9625489]=0;a[9625492]=0;i=0;g=0;f=0;e=0;do{g=((a[9632624+i|0]&1)<<i|g&255)&255;f=((a[9630528+i|0]&1)<<i|f&255)&255;e=((a[9551712+i|0]&1)<<i|e&255)&255;i=i+1|0;}while((i|0)<8);a[9625488]=g;a[9625489]=f;a[9625492]=e;if((g&3)==3){e=g&-4;a[9625488]=e;j=e}else{j=g}if((j&12)==12){a[9625488]=j&-13}if((f&3)==3){j=f&-4;a[9625489]=j;k=j}else{k=f}if((k&12)==12){a[9625489]=k&-13}if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];k=c[3532592]|0;if((k|0)!=0){gGC(9104152,k|0,280)|0}c[2113054]=c[2113060]}k=c[2439330]|0;if((k|0)!=0){f=k;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;f=c[2392]|0;if((f|0)>=0){gGz(8452240,0,((f|0)>0?(f<<2)+4|0:4)|0)}c[2113054]=0;f=c[2385548]|0;if((f|0)>0){gGz(9752472,0,((f|0)>1?f<<2:4)|0)}c[2113054]=c[2113220];c[2433530]=c[2113221];f=c[2438]|0;k=gGU(f,(f|0)<0|0?-1:0,1e7,0)|0;f=~~((+(k>>>0)+ +(K|0)*4294967296.0)/14121.355397951143);c[2113218]=f;c[2113216]=63449;c[2113058]=(f|0)/262|0;k=f-((f*22|0|0)/262|0)|0;c[2113018]=k;j=0;g=f;f=k;while(1){k=j+1|0;e=(ag(k,g)|0)/4|0;do{if((e|0)>(f|0)){i=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;if((i|0)<(f|0)){d=f-i|0;c[2113056]=d;i=RG(d)|0;c[2113054]=(c[2113054]|0)+i;c[2276108]=-1;c[2113056]=-1}i=c[2112968]|0;do{if((i|0)!=0){d=c[3531916]|0;l=c[2113308]|0;do{if((c[d>>2]|0)==0){gGz(i|0,0,l*76800|0|0)}else{if((l|0)==4){m=c[d+1152>>2]|0;n=0;o=i;while(1){c[o>>2]=m;c[o+4>>2]=m;c[o+8>>2]=m;c[o+12>>2]=m;c[o+16>>2]=m;c[o+20>>2]=m;c[o+24>>2]=m;c[o+28>>2]=m;p=n+1|0;if((p|0)<9600){n=p;o=o+32|0}else{break}}}else if((l|0)==2){o=c[d+1152>>2]|0;n=o<<16|o;o=i;m=0;while(1){c[o>>2]=n;c[o+4>>2]=n;c[o+8>>2]=n;c[o+12>>2]=n;c[o+16>>2]=n;c[o+20>>2]=n;c[o+24>>2]=n;c[o+28>>2]=n;p=m+1|0;if((p|0)<4800){o=o+32|0;m=p}else{break}}}else if((l|0)==3){m=c[d+1152>>2]|0;o=m>>>8&255;n=m>>>16&255;p=m&255;m=i;q=0;while(1){a[m]=p;a[m+1|0]=o;a[m+2|0]=n;r=q+1|0;if((r|0)<76800){m=m+3|0;q=r}else{break}}}else{break}}}while(0);if(a[7072664]|0){c[2112970]=i;c[2113306]=l;c[2113298]=c[2113300];fpz();s=c[3531916]|0}else{s=d}c[2112966]=s;q=c[2113016]|0;if((q|0)>0){t=0}else{break}do{c[s+(t<<2)>>2]=65535;t=t+1|0;}while((t|0)<(q|0));d=c[3531914]|0;l=0;do{c[d+(l<<2)>>2]=65535;l=l+1|0;}while((l|0)<(q|0))}}while(0);i=c[2430400]|0;q=c[3541524]|0;gGC(i|0,q|0,2048)|0;if((a[9722056]&1)==0){break}c[8452200+(c[2394]<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0>=1024){break}RH(4)}}while(0);q=e-(c[2113054]|0)-(c[2113056]|0)+(c[2276108]|0)|0;c[2113056]=q;i=RG(q)|0;c[2113054]=(c[2113054]|0)+i;c[2276108]=-1;c[2113056]=-1;UF(ag((c[2113216]|0)/4|0,j)|0)|0;if((k|0)>=4){break}j=k;g=c[2113218]|0;f=c[2113018]|0}f=c[2113216]|0;g=gGU(f,(f|0)<0|0?-1:0,2048e6,0)|0;j=c[2438224]|0;t=gGS(g,K,j,(j|0)<0|0?-1:0)|0;j=t;UF(f)|0;f=c[2443826]|0;if((f|0)<1073676288){c[2443826]=f-j}f=c[2443827]|0;if((f|0)<1073676288){c[2443827]=f-j}f=(c[3528508]|0)-j|0;c[3528508]=(f|0)<0?0:f;f=c[2112964]|0;if((f|0)!=0){gg[c[3542112]&4095](f,a[9688]|0?534:0)}f=c[2113054]|0;c[2113220]=(c[2113056]|0)+f-(c[2276108]|0)-(c[2113218]|0);j=c[2433530]|0;t=c[2076596]|0;c[2113221]=(c[2426530]|0)+j-t-(c[2113216]|0);g=c[1836236]|0;s=c[9757320+(g<<2)>>2]|0;if((s|0)!=0){i=s;gGC(i|0,9706056,76)|0}c[9752472+(g<<2)>>2]=j;c[14113936+(g<<2)>>2]=t;c[9669104+(g<<2)>>2]=c[3541536];c[1836236]=-1;g=c[2394]|0;t=c[14130368+(g<<2)>>2]|0;if((t|0)==0){u=8452240+(g<<2)|0;c[u>>2]=f;c[2394]=-1;return 0}gGC(t|0,9104152,280)|0;u=8452240+(g<<2)|0;c[u>>2]=f;c[2394]=-1;return 0}function fm5(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=c[3531916]|0;do{if((c[b>>2]|0)==0){d=c[2113308]|0;gGz(c[2112968]|0,0,d*76800|0|0);e=d}else{d=c[2113308]|0;if((d|0)==4){f=c[b+1152>>2]|0;g=0;h=c[2112968]|0;while(1){c[h>>2]=f;c[h+4>>2]=f;c[h+8>>2]=f;c[h+12>>2]=f;c[h+16>>2]=f;c[h+20>>2]=f;c[h+24>>2]=f;c[h+28>>2]=f;i=g+1|0;if((i|0)<9600){g=i;h=h+32|0}else{e=4;break}}}else if((d|0)==3){h=c[b+1152>>2]|0;g=h>>>8&255;f=h>>>16&255;i=h&255;h=c[2112968]|0;j=0;while(1){a[h]=i;a[h+1|0]=g;a[h+2|0]=f;k=j+1|0;if((k|0)<76800){h=h+3|0;j=k}else{e=3;break}}}else if((d|0)==2){j=c[b+1152>>2]|0;h=j<<16|j;j=c[2112968]|0;f=0;while(1){c[j>>2]=h;c[j+4>>2]=h;c[j+8>>2]=h;c[j+12>>2]=h;c[j+16>>2]=h;c[j+20>>2]=h;c[j+24>>2]=h;c[j+28>>2]=h;g=f+1|0;if((g|0)<4800){j=j+32|0;f=g}else{e=2;break}}}else{e=d;break}}}while(0);if(a[7072664]|0){c[2112970]=c[2112968];c[2113306]=e;c[2113298]=c[2113300];fpz();l=c[3531916]|0}else{l=b}c[2112966]=l;b=c[2113016]|0;if((b|0)>0){m=0}else{return 0}do{c[l+(m<<2)>>2]=65535;m=m+1|0;}while((m|0)<(b|0));m=c[3531914]|0;l=0;do{c[m+(l<<2)>>2]=65535;l=l+1|0;}while((l|0)<(b|0));return 0}function fm6(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=i;i=i+96|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;l=e+80|0;if((d|0)!=0){c[d>>2]=168962}if((b&96|0)==0){i=e;return 0}gGz(l|0,0,12);m=c[2405594]|0;c[l>>2]=m;c[l+4>>2]=(c[2411506]|0)-m;c[l+12>>2]=219592;gj[c[2076592]&4095](l)|0;l=h|0;do{if((b&64|0)!=0){gGz(g|0,0,16);c[2394]=-1;if((c[2392]|0)<0){break}m=h+9|0;n=f;o=f|0;p=f+4|0;q=f+12|0;r=g|0;s=g+4|0;t=g+12|0;u=0;do{gGC(l|0,614896,11)|0;a[m]=u+48&255;v=8452256+(u<<2)|0;gGz(n|0,0,12);c[o>>2]=v;c[p>>2]=4;c[q>>2]=164976;gj[c[2076592]&4095](f)|0;if((c[v>>2]|0)!=0){c[r>>2]=c[14130368+(u<<2)>>2];c[s>>2]=c[8452184+(u<<2)>>2];c[t>>2]=l;v=c[2076592]|0;gj[v&4095](g)|0}u=u+1|0;}while((u|0)<=(c[2392]|0))}}while(0);fw$(b);UQ(b,d);gGz(k|0,0,12);c[k>>2]=9625488;c[k+4>>2]=6;c[k+12>>2]=215728;gj[c[2076592]&4095](k)|0;gGz(j|0,0,12);c[j>>2]=8452880;c[j+4>>2]=8;c[j+12>>2]=212472;gj[c[2076592]&4095](j)|0;i=e;return 0}function fm7(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2486660+(b*112|0)>>2];c[a+104>>2]=c[2486664+(b*112|0)>>2];c[a+108>>2]=c[2486668+(b*112|0)>>2];d=0;return d|0}function fm8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=2486560+(b*112|0);e=0;return e|0}function fm9(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2484836+(b*112|0)>>2];c[a+104>>2]=c[2484840+(b*112|0)>>2];c[a+108>>2]=c[2484844+(b*112|0)>>2];d=0;return d|0}function fna(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=2484736+(b*112|0);e=0;return e|0}function fnb(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>48){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=2485968+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fnc(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2483004+(b*112|0)>>2];c[a+104>>2]=c[2483008+(b*112|0)>>2];c[a+108>>2]=c[2483012+(b*112|0)>>2];d=0;return d|0}function fnd(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=2482904+(b*112|0);e=0;return e|0}function fne(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>49){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=2484136+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fnf(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2481172+(b*112|0)>>2];c[a+104>>2]=c[2481176+(b*112|0)>>2];c[a+108>>2]=c[2481180+(b*112|0)>>2];d=0;return d|0}function fng(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=2481072+(b*112|0);e=0;return e|0}function fnh(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>49){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=2482304+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fni(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+8|0;h=g|0;j=h;R6(b+3|0,e,4)|0;R6(b+1|0,e+1|0,4)|0;R6(b+2|0,e+2|0,4)|0;R6(b,e+3|0,4)|0;e=b+f|0;if((f|0)>0){k=b;l=0}else{i=g;return}while(1){f=l<<2;m=k+3|0;n=k+1|0;o=k+2|0;p=0;do{q=7-(p<<1)|0;r=d[m]|0;s=d[n]|0;t=d[o]|0;u=d[k]|0;v=q-1|0;a[j+p|0]=(r>>>(v>>>0)<<4&16|r>>>(q>>>0)&1|s>>>(q>>>0)<<1&2|s>>>(v>>>0)<<5&32|t>>>(q>>>0)<<2&4|t>>>(v>>>0)<<6&64|u>>>(v>>>0)<<7|u>>>(q>>>0)<<3&8)&255;p=p+1|0;}while((p|0)<4);p=b+f|0;C=c[h>>2]|0;a[p]=C&255;C=C>>8;a[p+1|0]=C&255;C=C>>8;a[p+2|0]=C&255;C=C>>8;a[p+3|0]=C&255;p=k+4|0;if(p>>>0<e>>>0){k=p;l=l+1|0}else{break}}i=g;return}function fnj(b,c){b=b|0;c=c|0;a[9706117]=(c|0)!=0|0;return}function fnk(a){a=a|0;var b=0,d=0;b=(c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,35e5,0)|0;return a|0}function fnl(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;e=c[2113216]|0;f=gGU(d,(d|0)<0|0?-1:0,e,(e|0)<0|0?-1:0)|0;e=c[2113218]|0;d=gGS(f,K,e,(e|0)<0|0?-1:0)|0;e=d;if((e|0)<=((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)){g=b>>>1;h=g&2047;i=c[3532636]|0;j=i+h|0;k=a[j]|0;return k|0}UF(e)|0;g=b>>>1;h=g&2047;i=c[3532636]|0;j=i+h|0;k=a[j]|0;return k|0}function fnm(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;e=c[2113216]|0;f=gGU(d,(d|0)<0|0?-1:0,e,(e|0)<0|0?-1:0)|0;e=c[2113218]|0;d=gGS(f,K,e,(e|0)<0|0?-1:0)|0;e=d;if((e|0)<=((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)){g=b>>>1;h=g&2047;i=c[3532636]|0;j=i+h|0;k=a[j]|0;l=k&255;return l|0}UF(e)|0;g=b>>>1;h=g&2047;i=c[3532636]|0;j=i+h|0;k=a[j]|0;l=k&255;return l|0}function fnn(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;f=c[2113216]|0;g=gGU(e,(e|0)<0|0?-1:0,f,(f|0)<0|0?-1:0)|0;f=c[2113218]|0;e=gGS(g,K,f,(f|0)<0|0?-1:0)|0;f=e;if((f|0)<=((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)){h=b>>>1;i=h&2047;j=c[3532636]|0;k=j+i|0;a[k]=d;return}UF(f)|0;h=b>>>1;i=h&2047;j=c[3532636]|0;k=j+i|0;a[k]=d;return}function fno(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;f=c[2113216]|0;g=gGU(e,(e|0)<0|0?-1:0,f,(f|0)<0|0?-1:0)|0;f=c[2113218]|0;e=gGS(g,K,f,(f|0)<0|0?-1:0)|0;f=e;if((f|0)<=((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)){h=d&255;i=b>>>1;j=i&2047;k=c[3532636]|0;l=k+j|0;a[l]=h;return}UF(f)|0;h=d&255;i=b>>>1;j=i&2047;k=c[3532636]|0;l=k+j|0;a[l]=h;return}function fnp(d,e){d=d|0;e=e|0;var f=0;if((d|0)==4980738){c[3542216]=(e&65535)<<1&32766;return}else if((d|0)==4980766|(d|0)==4980764|(d|0)==4980762|(d|0)==4980760|(d|0)==4980758|(d|0)==4980756|(d|0)==4980754|(d|0)==4980752){b[14168832+((d>>>1&7)<<1)>>1]=e;return}else if((d|0)==786438){f=c[3541526]|0;b[(c[3541522]|0)+((f&63)<<1)>>1]=e;c[3541526]=f+1;return}else if((d|0)==4980742|(d|0)==4980740){f=c[3542216]|0;b[(c[3542214]|0)+((f&32767)<<1)>>1]=e;c[3542216]=f+1;return}else if((d|0)==786434){c[3541526]=e&1023;return}else if((d|0)==524288){c[2113314]=e&65535;return}else if((d|0)==786436){f=c[3541526]|0;b[(c[3541524]|0)+((f&1023)<<1)>>1]=e;c[3541526]=f+1;return}else if((d|0)==524290){c[2113312]=e&65535;return}else if((d|0)==4456452){c[2437788]=e&255;return}else if((d|0)==4194306){a[9722048]=(e&255)!=0|0;return}else{return}}function fnq(a,b){a=a|0;b=b|0;return}function fnr(a){a=a|0;var d=0;if((a|0)==786436){d=b[(c[3541524]|0)+((c[3541526]&1023)<<1)>>1]|0;return d|0}else if((a|0)==4980738){d=(c[3542216]|0)>>>1&16383;return d|0}else if((a|0)==4980742){d=b[(c[3542214]|0)+((c[3542216]&32767)+1<<1)>>1]|0;return d|0}else if((a|0)==786438){d=b[(c[3541522]|0)+((c[3541526]&63)<<1)>>1]|0;return d|0}else if((a|0)==4980740){d=b[(c[3542214]|0)+((c[3542216]&32767)<<1)>>1]|0;return d|0}else if((a|0)==4980752|(a|0)==4980754|(a|0)==4980756|(a|0)==4980758|(a|0)==4980760|(a|0)==4980762|(a|0)==4980764|(a|0)==4980766){d=b[14168832+((a>>>1&7)<<1)>>1]|0;return d|0}else if((a|0)==786434){d=c[3541526]&1023;return d|0}else{d=0;return d|0}return 0}function fns(b){b=b|0;var d=0,e=0,f=0,g=0,h=0;do{if((b|0)==4456459){d=a[9550216]|0}else if((b|0)==4456455){d=a[9634744]|0}else if((b|0)==4456449){d=-1}else if((b|0)==4456465){d=a[9634746]|0}else if((b|0)==4456451){d=0}else if((b|0)==786433|(b|0)==4194305){e=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;if((e|0)>=(c[2113018]|0)){d=1;break}d=e>>>31&255}else if((b|0)==4456453){d=c[2437788]&255}else if((b|0)==4456457){e=a[9550218]|0;f=e&255;g=c[2440174]^f;c[2440174]=g;do{if((f&24&g|0)!=0){c[2437788]=(c[2437788]|0)+1;if((c[2439194]|0)<=0){break}h=c[2406652]|0;c[3528400]=h;if((a[h+14|0]&1)!=0){break}a[h+12|0]=1;c[h+8>>2]=0}}while(0);c[2440174]=f;d=e}else if((b|0)==4456461){d=a[9550217]|0}else if((b|0)==4456463){d=a[9634745]|0}else{d=0}}while(0);return d|0}function fnt(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5633396+(b*112|0)>>2];c[a+104>>2]=c[5633400+(b*112|0)>>2];c[a+108>>2]=c[5633404+(b*112|0)>>2];d=0;return d|0}function fnu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=5633296+(b*112|0);e=0;return e|0}function fnv(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?9730936:0;do{if(d){if((a|0)==0){e=0;break}c[a+100>>2]=c[b+100>>2];e=0}else{e=1}}while(0);return e|0}function fnw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?9730936:0;e=0;return e|0}function fnx(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>23){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3262720+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function fny(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>50){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6009176+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fnz(){var b=0,d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;c[2424]=5759;c[2113316]=524288;c[2113212]=1048576;c[2414872]=0;c[2388090]=0;c[3542212]=262144;c[3541520]=786432;c[2414574]=1835008;c[2388220]=1835008;c[2387118]=1867776;c[3530220]=1869824;c[3542214]=1871872;c[3541524]=1937408;c[3541522]=1939456;c[2411504]=1939584;c[3531916]=1939584;c[3531914]=1947776;b=0;while(1){if((b|0)>=1024){break}d=9638528+(b<<2)|0;if((c[d>>2]|0)==0){e=62365;break}else{b=b+1|0}}do{if((e|0)==62365){b=gGq(1955968)|0;c[d>>2]=b;if((b|0)==0){break}c[2414872]=b;gGz(b|0,0,1955968);c[2388090]=b;c[3542212]=b+262144;f=(c[2113316]|0)+262144|0;c[3541520]=b+f;g=f+(c[2113212]|0)|0;f=b+g|0;c[2414574]=f;c[2388220]=f;c[2387118]=b+(g+32768);c[3530220]=b+(g+34816);c[3542214]=b+(g+36864);c[3541524]=b+(g+102400);c[3541522]=b+(g+104448);f=b+(g+104576)|0;c[2411504]=f;c[3531916]=f;c[3531914]=b+(g+112768);c[2414044]=b+(g+120960);fpk(b,2)|0;fni(c[3542212]|0,2,c[2113316]|0);fpl(c[3541520]|0,6,3,c[2113212]|0,0);fxU(0,425984);if((c[2394]|0)==0){i=c[2112932]|0}else{c[2394]=0;b=c[3532596]|0;c[2112932]=b;g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060];i=b}b=c[2388090]|0;g=i|0;f=0;while(1){j=b+f|0;c[g>>2]=j;c[g+131072>>2]=j;j=f+1024|0;if(j>>>0>262143){break}else{g=g+4|0;f=j}}f=c[2387118]|0;c[i+16448>>2]=f;c[i+81984>>2]=f;c[i+147520>>2]=f;g=f+1024|0;c[i+16452>>2]=g;c[i+81988>>2]=g;c[i+147524>>2]=g;g=c[3530220]|0;c[i+16480>>2]=g;c[i+82016>>2]=g;c[i+147552>>2]=g;f=g+1024|0;c[i+16484>>2]=f;c[i+82020>>2]=f;c[i+147556>>2]=f;f=c[2388220]|0;g=i+18432|0;b=4718592;while(1){j=f+(b-4718592)|0;c[g>>2]=j;c[g+65536>>2]=j;c[g+131072>>2]=j;j=b+1024|0;if(j>>>0>4751359){break}else{g=g+4|0;b=j}}c[i+196688>>2]=736;c[i+196608>>2]=544;c[i+196728>>2]=3454;c[i+196648>>2]=2602;b=c[3532592]|0;if((b|0)!=0){gGC(b|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fpA();c[2113016]=2048;c[3531920]=c[2387118];c[3531918]=c[3530220];Vf(0);b=c[2439194]|0;if((b|0)>0){g=c[2406652]|0;f=0;while(1){h[g+(f*40|0)+16>>3]=.6;c[g+(f*40|0)+32>>2]=3;j=f+1|0;if((j|0)<(b|0)){f=j}else{break}}c[3528400]=g+(f*40|0);j=0;while(1){h[g+(j*40|0)+24>>3]=.6;c[g+(j*40|0)+36>>2]=3;k=j+1|0;if((k|0)<(b|0)){j=k}else{break}}c[3528400]=g+(j*40|0)}a[7072656]=1;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];b=c[3532592]|0;if((b|0)!=0){gGC(9104152,b|0,280)|0}c[2113054]=c[2113060]}RI();b=c[2394]|0;f=c[14130368+(b<<2)>>2]|0;if((f|0)!=0){gGC(f|0,9104152,280)|0}c[8452240+(b<<2)>>2]=c[2113054];c[2394]=-1;b=c[2439194]|0;if((b|0)>0){f=c[2406652]|0;k=0;do{l=f+(k*40|0)|0;m=f+(k*40|0)+12|0;a[m]=0;n=f+(k*40|0)+8|0;c[n>>2]=0;o=a[f+(k*40|0)+14|0]|0;do{if((o&2)!=0&(b|0)>(k|0)){if((o&4)==0){a[f+(k*40|0)+13|0]=1}if((o&1)!=0){break}a[m]=1;c[n>>2]=0}}while(0);k=k+1|0;}while((k|0)<(b|0));c[3528400]=l}a[9722048]=0;c[2440174]=0;c[2437788]=0;p=0;return p|0}}while(0);c[2414872]=0;p=1;return p|0}function fnA(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;fpB();if((c[2392]|0)>=0){a=0;do{b=14130368+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}b=14130384+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}a=a+1|0;}while((a|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;a=c[2439194]|0;b=c[2406652]|0;if((a|0)>0){d=0;e=b;f=a;while(1){a=e+(d*40|0)|0;c[3528400]=a;g=c[a>>2]|0;if((g|0)==0){h=f;i=e}else{gGr(g);c[c[3528400]>>2]=0;h=c[2439194]|0;i=c[2406652]|0}g=d+1|0;if((g|0)<(h|0)){d=g;e=i;f=h}else{j=i;break}}}else{j=b}if((j|0)!=0){gGr(j);c[2406652]=0}c[3528400]=0;c[2439194]=0;c[2442914]=0;j=c[2414872]|0;b=0;while(1){if((b|0)>=1024){k=62420;break}l=9638528+(b<<2)|0;if((c[l>>2]|0)==(j|0)){break}else{b=b+1|0}}if((k|0)==62420){c[2414872]=0;return 0}gGr(j);c[l>>2]=0;c[2414872]=0;return 0}function fnB(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;if((a[9623584]|0)!=0){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];b=c[3532592]|0;if((b|0)!=0){gGC(9104152,b|0,280)|0}c[2113054]=c[2113060]}RI();b=c[2394]|0;d=c[14130368+(b<<2)>>2]|0;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[8452240+(b<<2)>>2]=c[2113054];c[2394]=-1;b=c[2439194]|0;if((b|0)>0){d=c[2406652]|0;e=0;do{f=d+(e*40|0)|0;g=d+(e*40|0)+12|0;a[g]=0;h=d+(e*40|0)+8|0;c[h>>2]=0;i=a[d+(e*40|0)+14|0]|0;do{if((i&2)!=0&(b|0)>(e|0)){if((i&4)==0){a[d+(e*40|0)+13|0]=1}if((i&1)!=0){break}a[g]=1;c[h>>2]=0}}while(0);e=e+1|0;}while((e|0)<(b|0));c[3528400]=f}a[9722048]=0;c[2440174]=0;c[2437788]=0}gGz(9550216,0,3);f=0;b=0;e=0;d=0;do{b=((a[9632616+f|0]&1)<<f|b&255)&255;e=((a[9630520+f|0]&1)<<f|e&255)&255;d=((a[9629240+f|0]&1)<<f|d&255)&255;f=f+1|0;}while((f|0)<8);a[9550216]=b;a[9550217]=e;a[9550218]=d;if((b&3)==3){d=b&-4;a[9550216]=d;j=d}else{j=b}if((j&12)==12){a[9550216]=j&-13}if((e&3)==3){j=e&-4;a[9550217]=j;k=j}else{k=e}if((k&12)==12){a[9550217]=k&-13}k=c[2392]|0;if((k|0)>=0){gGz(8452240,0,((k|0)>0?(k<<2)+4|0:4)|0)}c[2113054]=0;if((c[2394]|0)==0){l=0}else{c[2394]=0;c[2112932]=c[3532596];k=c[3532592]|0;if((k|0)!=0){gGC(9104152,k|0,280)|0}k=c[2113060]|0;c[2113054]=k;l=k}k=l+(c[2113220]|0)|0;c[2113054]=k;l=c[2438]|0;e=gGU(l,(l|0)<0|0?-1:0,1e7,0)|0;l=~~((+(e>>>0)+ +(K|0)*4294967296.0)/14743.04);c[2113218]=l;c[2113058]=(l|0)/262|0;e=l-((l*22|0|0)/262|0)|0;c[2113018]=e;j=1;b=l;l=e;e=k;while(1){k=(ag(j,b)|0)/4|0;do{if((k|0)>(l|0)){d=(c[2113056]|0)+e-(c[2276108]|0)|0;if((d|0)<(l|0)){f=l-d|0;c[2113056]=f;d=RG(f)|0;c[2113054]=(c[2113054]|0)+d;c[2276108]=-1;c[2113056]=-1}d=c[2112968]|0;do{if((d|0)!=0){f=c[3531916]|0;h=c[2113308]|0;do{if((c[f>>2]|0)==0){gGz(d|0,0,h*76800|0|0)}else{if((h|0)==4){g=c[f+1152>>2]|0;i=0;m=d;while(1){c[m>>2]=g;c[m+4>>2]=g;c[m+8>>2]=g;c[m+12>>2]=g;c[m+16>>2]=g;c[m+20>>2]=g;c[m+24>>2]=g;c[m+28>>2]=g;n=i+1|0;if((n|0)<9600){i=n;m=m+32|0}else{break}}}else if((h|0)==3){m=c[f+1152>>2]|0;i=m>>>8&255;g=m>>>16&255;n=m&255;m=d;o=0;while(1){a[m]=n;a[m+1|0]=i;a[m+2|0]=g;p=o+1|0;if((p|0)<76800){m=m+3|0;o=p}else{break}}}else if((h|0)==2){o=c[f+1152>>2]|0;m=o<<16|o;o=d;g=0;while(1){c[o>>2]=m;c[o+4>>2]=m;c[o+8>>2]=m;c[o+12>>2]=m;c[o+16>>2]=m;c[o+20>>2]=m;c[o+24>>2]=m;c[o+28>>2]=m;i=g+1|0;if((i|0)<4800){o=o+32|0;g=i}else{break}}}else{break}}}while(0);if(a[7072656]|0){c[2112970]=d;c[2113306]=h;c[2113298]=c[2113300];fpz();q=c[3531916]|0}else{q=f}c[2112966]=q;g=c[2113016]|0;if((g|0)>0){r=0}else{break}do{c[q+(r<<2)>>2]=65535;r=r+1|0;}while((r|0)<(g|0));f=c[3531914]|0;h=0;do{c[f+(h<<2)>>2]=65535;h=h+1|0;}while((h|0)<(g|0))}}while(0);d=c[2430400]|0;g=c[3541524]|0;gGC(d|0,g|0,2048)|0;if((a[9722048]&1)==0){break}c[8452200+(c[2394]<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0>=1024){break}RH(4)}}while(0);g=k-(c[2113054]|0)-(c[2113056]|0)+(c[2276108]|0)|0;c[2113056]=g;d=RG(g)|0;s=(c[2113054]|0)+d|0;c[2113054]=s;c[2276108]=-1;c[2113056]=-1;if((j|0)>=4){break}j=j+1|0;b=c[2113218]|0;l=c[2113018]|0;e=s}Vg(c[2112964]|0,a[9688]|0?534:0);c[2113220]=s-(c[2113218]|0);e=c[2394]|0;l=c[14130368+(e<<2)>>2]|0;if((l|0)==0){t=8452240+(e<<2)|0;c[t>>2]=s;c[2394]=-1;return 0}gGC(l|0,9104152,280)|0;t=8452240+(e<<2)|0;c[t>>2]=s;c[2394]=-1;return 0}function fnC(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=c[3531916]|0;do{if((c[b>>2]|0)==0){d=c[2113308]|0;gGz(c[2112968]|0,0,d*76800|0|0);e=d}else{d=c[2113308]|0;if((d|0)==2){f=c[b+1152>>2]|0;g=f<<16|f;f=c[2112968]|0;h=0;while(1){c[f>>2]=g;c[f+4>>2]=g;c[f+8>>2]=g;c[f+12>>2]=g;c[f+16>>2]=g;c[f+20>>2]=g;c[f+24>>2]=g;c[f+28>>2]=g;i=h+1|0;if((i|0)<4800){f=f+32|0;h=i}else{e=2;break}}}else if((d|0)==4){h=c[b+1152>>2]|0;f=0;g=c[2112968]|0;while(1){c[g>>2]=h;c[g+4>>2]=h;c[g+8>>2]=h;c[g+12>>2]=h;c[g+16>>2]=h;c[g+20>>2]=h;c[g+24>>2]=h;c[g+28>>2]=h;i=f+1|0;if((i|0)<9600){f=i;g=g+32|0}else{e=4;break}}}else if((d|0)==3){g=c[b+1152>>2]|0;f=g>>>8&255;h=g>>>16&255;i=g&255;g=c[2112968]|0;j=0;while(1){a[g]=i;a[g+1|0]=f;a[g+2|0]=h;k=j+1|0;if((k|0)<76800){g=g+3|0;j=k}else{e=3;break}}}else{e=d;break}}}while(0);if(a[7072656]|0){c[2112970]=c[2112968];c[2113306]=e;c[2113298]=c[2113300];fpz();l=c[3531916]|0}else{l=b}c[2112966]=l;b=c[2113016]|0;if((b|0)>0){m=0}else{return 0}do{c[l+(m<<2)>>2]=65535;m=m+1|0;}while((m|0)<(b|0));m=c[3531914]|0;l=0;do{c[m+(l<<2)>>2]=65535;l=l+1|0;}while((l|0)<(b|0));return 0}function fnD(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=i;i=i+112|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;l=e+80|0;m=e+96|0;if((d|0)!=0){c[d>>2]=169735}if((b&96|0)==0){i=e;return 0}gGz(m|0,0,12);d=c[2414574]|0;c[m>>2]=d;c[m+4>>2]=(c[2411504]|0)-d;c[m+12>>2]=219592;gj[c[2076592]&4095](m)|0;m=h|0;do{if((b&64|0)!=0){gGz(g|0,0,16);c[2394]=-1;if((c[2392]|0)<0){break}d=h+9|0;n=f;o=f|0;p=f+4|0;q=f+12|0;r=g|0;s=g+4|0;t=g+12|0;u=0;do{gGC(m|0,614896,11)|0;a[d]=u+48&255;v=8452256+(u<<2)|0;gGz(n|0,0,12);c[o>>2]=v;c[p>>2]=4;c[q>>2]=164976;gj[c[2076592]&4095](f)|0;if((c[v>>2]|0)!=0){c[r>>2]=c[14130368+(u<<2)>>2];c[s>>2]=c[8452184+(u<<2)>>2];c[t>>2]=m;v=c[2076592]|0;gj[v&4095](g)|0}u=u+1|0;}while((u|0)<=(c[2392]|0))}}while(0);gGz(l|0,0,12);c[l>>2]=8452880;c[l+4>>2]=8;c[l+12>>2]=212472;gj[c[2076592]&4095](l)|0;gGz(k|0,0,12);c[k>>2]=9751152;c[k+4>>2]=4;c[k+12>>2]=231136;gj[c[2076592]&4095](k)|0;gGz(j|0,0,12);c[j>>2]=9760696;c[j+4>>2]=4;c[j+12>>2]=225176;gj[c[2076592]&4095](j)|0;i=e;return 0}function fnE(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4328724+(b*112|0)>>2];c[a+104>>2]=c[4328728+(b*112|0)>>2];c[a+108>>2]=c[4328732+(b*112|0)>>2];d=0;return d|0}function fnF(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=4328624+(b*112|0);e=0;return e|0}function fnG(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>36){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4893248+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fnH(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4329956+(b*112|0)>>2];c[a+104>>2]=c[4329960+(b*112|0)>>2];c[a+108>>2]=c[4329964+(b*112|0)>>2];d=0;return d|0}function fnI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=4329856+(b*112|0);e=0;return e|0}function fnJ(b){b=b|0;var d=0,e=0;do{if((b&16773120|0)==2097152){d=a[(c[2405160]|0)+(b>>>1&2047)|0]|0}else{if((b|0)==3145741){e=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;if((e|0)>=(c[2113018]|0)){d=1;break}d=e>>>31&255;break}else if((b|0)==2129945){d=a[9625482]|0;break}else if((b|0)==2129941){d=a[9625481]|0;break}else if((b|0)==2129937){d=a[9625480]|0;break}else{d=0;break}}}while(0);return d|0}function fnK(a){a=a|0;var e=0,f=0,g=0;if((a&16773120|0)==2097152){e=d[(c[2405160]|0)+(a>>>1&2047)|0]|0;return e|0}if((a|0)==3145740){f=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;if((f|0)>=(c[2113018]|0)){e=1;return e|0}e=f>>>31&65535;return e|0}else if((a|0)==3145734){e=b[(c[3541508]|0)+2>>1]|0;return e|0}else if((a|0)==2129936){e=d[9625480]|0;return e|0}else if((a|0)==2129940){e=d[9625481]|0;return e|0}else if((a|0)==2129944){e=d[9625482]|0;return e|0}else if((a|0)==3145732){e=b[c[3541508]>>1]|0;return e|0}else if((a|0)==7340032){a=((c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0)/(c[2113058]|0)|0;if((a|0)==(c[2384350]|0)){g=65024}else{c[2384350]=a;g=32256}e=(g|a)&65535;return e|0}else{e=0;return e|0}return 0}function fnL(b,d){b=b|0;d=d|0;if((b&16773120|0)!=2097152){return}a[(c[2405160]|0)+(b>>>1&2047)|0]=d;return}function fnM(d,e){d=d|0;e=e|0;if((d&16773120|0)==2097152){a[(c[2405160]|0)+(d>>>1&2047)|0]=e&255;return}switch(d|0){case 3145740:{b[(c[3541500]|0)+(c[3541498]<<1)>>1]=e;return};case 3145736:{c[3541498]=e&255;return};case 3145734:{b[c[3541508]>>1]=e;c[3541508]=(c[3541508]|0)+2;return};case 3145728:{c[3541508]=(c[3541506]|0)+((e&65535)<<1&16382);return};case 3145732:{b[c[3541508]>>1]=e;c[3541508]=(c[3541508]|0)+2;return};default:{return}}}function fnN(b,d){b=b|0;d=d|0;var e=0;if((b|0)==16385){e=c[2113304]|0;a[14168504+e|0]=d;mv(0,e,d&255);return}else if((b|0)==16384){c[2113304]=d&255;return}else if((b|0)==16386){Uv(0,d);return}else{return}}function fnO(a){a=a|0;var b=0;if((a|0)==16385){b=c[(c[3531464]|0)+4240>>2]&255}else if((a|0)==16386){b=c[2113156]&255}else{b=0}return b|0}function fnP(b){b=b|0;var c=0;if((b|0)==65538){c=~a[9625485]}else if((b|0)==65542){c=~a[9625483]}else if((b|0)==65536){c=~a[9625484]}else{c=0}return c|0}function fnQ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7361148+(b*112|0)>>2];c[a+104>>2]=c[7361152+(b*112|0)>>2];c[a+108>>2]=c[7361156+(b*112|0)>>2];d=0;return d|0}function fnR(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=7361048+(b*112|0);e=0;return e|0}function fnS(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4623224+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function fnT(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>62){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6549904+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fnU(){var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;b=i;i=i+360|0;d=b|0;e=b+112|0;f=b+120|0;g=b+232|0;j=b+240|0;k=b+352|0;c[2113208]=8388608;c[2426654]=0;c[2418122]=0;c[2418090]=524288;c[3541502]=557056;c[3541206]=8945664;c[2405592]=9207808;c[2418236]=9207808;c[2411404]=9224192;c[2405160]=9228288;c[3541506]=9232384;c[3541500]=9248768;c[2411502]=9249280;c[3531916]=9249280;l=0;while(1){if((l|0)>=1024){break}m=9638528+(l<<2)|0;if((c[m>>2]|0)==0){n=62648;break}else{l=l+1|0}}do{if((n|0)==62648){l=gGq(9257472)|0;c[m>>2]=l;if((l|0)==0){break}c[2426654]=l;gGz(l|0,0,9257472);c[2418122]=l;c[2418090]=l+524288;c[3541502]=l+557056;o=c[2113208]|0;c[3541206]=l+(o+557056);p=l+(o+819200)|0;c[2405592]=p;c[2418236]=p;c[2411404]=l+(o+835584);c[2405160]=l+(o+839680);c[3541506]=l+(o+843776);c[3541500]=l+(o+860160);p=l+(o+860672)|0;c[2411502]=p;c[3531916]=p;c[2414042]=l+(o+868864);do{if((c[3542200]|0)!=0){o=j+108|0;c[o>>2]=0;p=j+100|0;c[p>>2]=0;q=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[q&16383](j,0)|0;if((c[o>>2]|0)==0){break}o=c[p>>2]|0;c[k>>2]=9534384;p=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[p&16383](k,0,0)|0;if((o|0)<1){break}gzL(l,0,0)|0}}while(0);fpl(c[3541502]|0,1,4,c[2113208]|0,0);l=c[2418090]|0;do{if((c[3542200]|0)!=0){o=f+108|0;c[o>>2]=0;p=f+100|0;c[p>>2]=0;q=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[q&16383](f,5)|0;if((c[o>>2]|0)==0){break}o=c[p>>2]|0;c[g>>2]=9534384;p=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[p&16383](g,5,0)|0;if((o|0)<1){break}gzL(l,0,5)|0}}while(0);l=c[3541206]|0;do{if((c[3542200]|0)!=0){o=d+108|0;c[o>>2]=0;p=d+100|0;c[p>>2]=0;q=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[q&16383](d,6)|0;if((c[o>>2]|0)==0){break}o=c[p>>2]|0;c[e>>2]=9534384;p=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[p&16383](e,6,0)|0;if((o|0)<1){break}gzL(l,0,6)|0}}while(0);fxU(0,425984);if((c[2394]|0)==0){r=c[2112932]|0}else{c[2394]=0;l=c[3532596]|0;c[2112932]=l;o=c[3532592]|0;if((o|0)!=0){gGC(9104152,o|0,280)|0}c[2113054]=c[2113060];r=l}l=c[2418122]|0;o=r|0;p=0;while(1){q=l+p|0;c[o>>2]=q;c[o+131072>>2]=q;q=p+1024|0;if(q>>>0>524287){break}else{o=o+4|0;p=q}}p=c[2418236]|0;c[r+4096>>2]=p;c[r+69632>>2]=p;c[r+135168>>2]=p;o=p+1024|0;c[r+4100>>2]=o;c[r+69636>>2]=o;c[r+135172>>2]=o;o=p+2048|0;c[r+4104>>2]=o;c[r+69640>>2]=o;c[r+135176>>2]=o;o=p+3072|0;c[r+4108>>2]=o;c[r+69644>>2]=o;c[r+135180>>2]=o;o=p+4096|0;c[r+4112>>2]=o;c[r+69648>>2]=o;c[r+135184>>2]=o;o=p+5120|0;c[r+4116>>2]=o;c[r+69652>>2]=o;c[r+135188>>2]=o;o=p+6144|0;c[r+4120>>2]=o;c[r+69656>>2]=o;c[r+135192>>2]=o;o=p+7168|0;c[r+4124>>2]=o;c[r+69660>>2]=o;c[r+135196>>2]=o;o=p+8192|0;c[r+4128>>2]=o;c[r+69664>>2]=o;c[r+135200>>2]=o;o=p+9216|0;c[r+4132>>2]=o;c[r+69668>>2]=o;c[r+135204>>2]=o;o=p+10240|0;c[r+4136>>2]=o;c[r+69672>>2]=o;c[r+135208>>2]=o;o=p+11264|0;c[r+4140>>2]=o;c[r+69676>>2]=o;c[r+135212>>2]=o;o=p+12288|0;c[r+4144>>2]=o;c[r+69680>>2]=o;c[r+135216>>2]=o;o=p+13312|0;c[r+4148>>2]=o;c[r+69684>>2]=o;c[r+135220>>2]=o;o=p+14336|0;c[r+4152>>2]=o;c[r+69688>>2]=o;c[r+135224>>2]=o;o=p+15360|0;c[r+4156>>2]=o;c[r+69692>>2]=o;c[r+135228>>2]=o;o=c[2411404]|0;c[r+16384>>2]=o;c[r+81920>>2]=o;c[r+147456>>2]=o;p=o+1024|0;c[r+16388>>2]=p;c[r+81924>>2]=p;c[r+147460>>2]=p;p=o+2048|0;c[r+16392>>2]=p;c[r+81928>>2]=p;c[r+147464>>2]=p;p=o+3072|0;c[r+16396>>2]=p;c[r+81932>>2]=p;c[r+147468>>2]=p;c[r+196688>>2]=956;c[r+196608>>2]=2188;c[r+196728>>2]=546;c[r+196648>>2]=3290;p=c[3532592]|0;if((p|0)!=0){gGC(p|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fyz(0,65552,16e6);c[1836234]=0;p=c[2439374]|0;c[3531864]=p;gf[c[p>>2]&2047](0);p=c[2405160]|0;o=c[3531864]|0;c[o+44>>2]=p;c[o+2092>>2]=p;c[o+4140>>2]=p;c[o+6188>>2]=p;p=c[2418090]|0;l=524288;do{q=l>>11;s=(l|32767)+2047>>11;if((q|0)<(s|0)){t=p+(-l|0)|0;u=q;while(1){c[o+44+(u<<2)>>2]=t;v=u+1|0;if((v|0)<(s|0)){u=v}else{w=q;break}}while(1){c[o+2092+(w<<2)>>2]=t;u=w+1|0;if((u|0)<(s|0)){w=u}else{x=q;break}}do{c[o+4140+(x<<2)>>2]=t;c[o+6188+(x<<2)>>2]=t;x=x+1|0;}while((x|0)<(s|0))}l=l+32768|0;}while((l|0)<1048576);c[o+8236>>2]=3164;c[o+8240>>2]=1144;c[o+8244>>2]=208;l=c[o+20>>2]|0;if((l|0)==0){y=o}else{gf[l&2047](689072);y=c[3531864]|0}c[1836234]=-1;gu[c[y+4>>2]&16383]();c[3531864]=0;l=a[9680]|0;p=l?32e3:0;if(l){if(a[9624]|0){l=p*3|0;s=52734;while(1){if((s|0)>(l|0)){s=s>>1}else{z=1222;A=s;break}}}else{z=2462;A=p}c[2429380]=A;c[3542124]=z;mw(3375e3,A);s=gGq(262144)|0;c[2406684]=s;gGz(s|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(3375e3,11025)}h[745421]=.5;c[2436794]=3;h[745420]=.5;c[2436792]=3;Ux(0,7575,1);c[2407030]=128;c[2407068]=3;c[2113040]=17;c[2113182]=-470;c[2113178]=-472;c[2113174]=-474;fl6(1);c[2113016]=2048;c[3531920]=c[2411404];a[7072648]=1;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];s=c[3532592]|0;if((s|0)!=0){gGC(9104152,s|0,280)|0}c[2113054]=c[2113060]}RI();s=c[2394]|0;l=c[14130368+(s<<2)>>2]|0;if((l|0)!=0){gGC(l|0,9104152,280)|0}c[8452240+(s<<2)>>2]=c[2113054];c[2394]=-1;c[1836234]=0;s=c[2439374]|0;c[3531864]=s;gf[c[s>>2]&2047](0);gD[c[(c[3531864]|0)+8>>2]&8191]()|0;c[1836234]=-1;gu[c[(c[3531864]|0)+4>>2]&16383]();c[3531864]=0;mx(0);c[2113156]=0;a[9628264]=0;c[2407033]=0;s=c[3541206]|0;c[3541190]=s;c[3541198]=s;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=s+256;c[3541199]=s+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=s+512;c[3541200]=s+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=s+768;c[3541201]=s+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;B=0;i=b;return B|0}}while(0);c[2426654]=0;B=1;i=b;return B|0}function fnV(){var a=0,b=0,d=0,e=0,f=0;a=c[3531464]|0;c[a+44344>>2]=0;c[a+44348>>2]=0;if((a|0)!=0){gGr(a);c[3531464]=0}a=c[2406684]|0;if((a|0)!=0){gGr(a);c[2406684]=0}Uw(0);fl7();if((c[2392]|0)>=0){a=0;do{b=14130368+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}b=14130384+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}a=a+1|0;}while((a|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;fyA();a=c[2426654]|0;b=0;while(1){if((b|0)>=1024){e=62711;break}f=9638528+(b<<2)|0;if((c[f>>2]|0)==(a|0)){break}else{b=b+1|0}}if((e|0)==62711){c[2426654]=0;c[3541206]=0;return 0}gGr(a);c[f>>2]=0;c[2426654]=0;c[3541206]=0;return 0}function fnW(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((a[9623576]|0)!=0){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];b=c[3532592]|0;if((b|0)!=0){gGC(9104152,b|0,280)|0}c[2113054]=c[2113060]}RI();b=c[2394]|0;d=c[14130368+(b<<2)>>2]|0;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[8452240+(b<<2)>>2]=c[2113054];c[2394]=-1;c[1836234]=0;b=c[2439374]|0;c[3531864]=b;gf[c[b>>2]&2047](0);b=c[(c[3531864]|0)+8>>2]|0;gD[b&8191]()|0;c[1836234]=-1;gu[c[(c[3531864]|0)+4>>2]&16383]();c[3531864]=0;mx(0);c[2113156]=0;a[9628264]=0;c[2407033]=0;b=c[3541206]|0;c[3541190]=b;c[3541198]=b;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=b+256;c[3541199]=b+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=b+512;c[3541200]=b+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=b+768;c[3541201]=b+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4}a[9625480]=0;a[9625481]=0;a[9625482]=0;b=0;d=0;e=0;f=0;do{d=((a[9632608+b|0]&1)<<b|d&255)&255;e=((a[9630512+b|0]&1)<<b|e&255)&255;f=((a[9551704+b|0]&1)<<b|f&255)&255;b=b+1|0;}while((b|0)<8);a[9625480]=d;a[9625481]=e;a[9625482]=f;if((d&3)==3){f=d&-4;a[9625480]=f;g=f}else{g=d}if((g&12)==12){a[9625480]=g&-13}if((e&3)==3){g=e&-4;a[9625481]=g;h=g}else{h=e}if((h&12)==12){a[9625481]=h&-13}h=c[2392]|0;if((h|0)>=0){gGz(8452240,0,((h|0)>0?(h<<2)+4|0:4)|0)}c[2113054]=0;c[2409128]=0;c[2409245]=0;c[2409362]=0;c[2409479]=0;c[2409508]=0;c[2409537]=0;c[2409566]=0;c[2409595]=0;h=c[2438]|0;e=h;g=(h|0)<0|0?-1:0;h=gGU(e,g,16e6,0)|0;d=gGS(h,K,15360,0)|0;h=d;c[2113218]=h;d=gGU(e,g,8e6,0)|0;g=gGS(d,K,15360,0)|0;c[2113216]=g;c[2113220]=0;c[2113221]=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060]}c[2113058]=(h|0)/262|0;c[2113018]=h-((h*22|0|0)/262|0);a[670632]=0;c[1836234]=0;h=c[2439374]|0;c[3531864]=h;gf[c[h>>2]&2047](0);h=0;g=0;L81764:while(1){d=g;do{if((d|0)>=10){break L81764}d=d+1|0;e=(ag(c[2113218]|0,d)|0)/10|0;do{if(!(a[670632]|0)){f=c[2113018]|0;if((e|0)<=(f|0)){break}b=c[2113220]|0;if((b|0)<(f|0)){i=f-b|0;c[2113056]=i;b=RG(i)|0;c[2113054]=(c[2113054]|0)+b;c[2276108]=-1;c[2113056]=-1;c[2113220]=(c[2113220]|0)+b}a[670632]=1;b=c[2430398]|0;i=c[2439196]|0;f=i<<11;c[2438976]=b+f;j=(c[2440572]|0)>1;if(j){c[2438977]=(c[2430399]|0)+f}f=i^1;c[2439196]=f;i=f<<11;f=b+i|0;b=(c[3541506]|0)+12288|0;gGC(f|0,b|0,2048)|0;if(j){j=(c[2430399]|0)+i|0;i=(c[3541504]|0)+12288|0;gGC(j|0,i|0,2048)|0}c[8452200+(c[2394]<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0>=1024){break}RH(4)}}while(0);i=e-(c[2113220]|0)|0;c[2113056]=i;j=RG(i)|0;c[2113054]=(c[2113054]|0)+j;c[2276108]=-1;c[2113056]=-1;c[2113220]=(c[2113220]|0)+j;j=c[2113216]|0;if((j|0)<10){k=0}else{k=gj[c[(c[3531864]|0)+12>>2]&4095]((j|0)/10|0)|0}c[2113221]=(c[2113221]|0)+k;l=c[2112964]|0;}while((l|0)==0);j=a[9688]|0?53:0;i=l+(h<<1<<1)|0;gg[c[3542124]&4095](i,j);Uu(0,i,j);h=j+h|0;g=d}g=c[2112964]|0;do{if((g|0)!=0){l=a[9688]|0?534:0;k=l-h|0;if((l|0)==(h|0)){break}l=g+(h<<1<<1)|0;gg[c[3542124]&4095](l,k);Uu(0,l,k)}}while(0);c[1836234]=-1;gu[c[(c[3531864]|0)+4>>2]&16383]();c[3531864]=0;h=c[2394]|0;g=c[14130368+(h<<2)>>2]|0;if((g|0)!=0){gGC(g|0,9104152,280)|0}c[8452240+(h<<2)>>2]=c[2113054];c[2394]=-1;h=c[2112968]|0;if((h|0)==0){return 0}g=c[3531916]|0;k=c[2113308]|0;do{if((c[g>>2]|0)==0){gGz(h|0,0,k*76800|0|0)}else{if((k|0)==3){l=c[g+1152>>2]|0;j=l>>>8&255;i=l>>>16&255;b=l&255;l=h;f=0;while(1){a[l]=b;a[l+1|0]=j;a[l+2|0]=i;m=f+1|0;if((m|0)<76800){l=l+3|0;f=m}else{break}}}else if((k|0)==2){f=c[g+1152>>2]|0;l=f<<16|f;f=h;i=0;while(1){c[f>>2]=l;c[f+4>>2]=l;c[f+8>>2]=l;c[f+12>>2]=l;c[f+16>>2]=l;c[f+20>>2]=l;c[f+24>>2]=l;c[f+28>>2]=l;j=i+1|0;if((j|0)<4800){f=f+32|0;i=j}else{break}}}else if((k|0)==4){i=c[g+1152>>2]|0;f=0;l=h;while(1){c[l>>2]=i;c[l+4>>2]=i;c[l+8>>2]=i;c[l+12>>2]=i;c[l+16>>2]=i;c[l+20>>2]=i;c[l+24>>2]=i;c[l+28>>2]=i;j=f+1|0;if((j|0)<9600){f=j;l=l+32|0}else{break}}}else{break}}}while(0);if(a[7072648]|0){c[2112970]=h;c[2113306]=k;c[2113298]=c[2113300];fl3();n=c[3531916]|0}else{n=g}c[2112966]=n;g=c[2113016]|0;if((g|0)>0){o=0}else{return 0}do{c[n+(o<<2)>>2]=65535;o=o+1|0;}while((o|0)<(g|0));return 0}function fnX(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=c[3531916]|0;do{if((c[b>>2]|0)==0){d=c[2113308]|0;gGz(c[2112968]|0,0,d*76800|0|0);e=d}else{d=c[2113308]|0;if((d|0)==3){f=c[b+1152>>2]|0;g=f>>>8&255;h=f>>>16&255;i=f&255;f=c[2112968]|0;j=0;while(1){a[f]=i;a[f+1|0]=g;a[f+2|0]=h;k=j+1|0;if((k|0)<76800){f=f+3|0;j=k}else{e=3;break}}}else if((d|0)==4){j=c[b+1152>>2]|0;f=0;h=c[2112968]|0;while(1){c[h>>2]=j;c[h+4>>2]=j;c[h+8>>2]=j;c[h+12>>2]=j;c[h+16>>2]=j;c[h+20>>2]=j;c[h+24>>2]=j;c[h+28>>2]=j;g=f+1|0;if((g|0)<9600){f=g;h=h+32|0}else{e=4;break}}}else if((d|0)==2){h=c[b+1152>>2]|0;f=h<<16|h;h=c[2112968]|0;j=0;while(1){c[h>>2]=f;c[h+4>>2]=f;c[h+8>>2]=f;c[h+12>>2]=f;c[h+16>>2]=f;c[h+20>>2]=f;c[h+24>>2]=f;c[h+28>>2]=f;g=j+1|0;if((g|0)<4800){h=h+32|0;j=g}else{e=2;break}}}else{e=d;break}}}while(0);if(a[7072648]|0){c[2112970]=c[2112968];c[2113306]=e;c[2113298]=c[2113300];fl3();l=c[3531916]|0}else{l=b}c[2112966]=l;b=c[2113016]|0;if((b|0)>0){m=0}else{return 0}do{c[l+(m<<2)>>2]=65535;m=m+1|0;}while((m|0)<(b|0));return 0}function fnY(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;f=i;i=i+160|0;g=f|0;h=f+16|0;j=f+32|0;k=f+48|0;l=f+64|0;m=f+80|0;n=f+96|0;o=f+112|0;p=f+128|0;q=f+144|0;r=(e|0)==0;if(!r){c[e>>2]=133527}if((b&96|0)==0){i=f;return 0}gGz(q|0,0,12);s=c[2405592]|0;c[q>>2]=s;c[q+4>>2]=(c[2411502]|0)-s;c[q+12>>2]=162152;gj[c[2076592]&4095](q)|0;q=p|0;do{if((b&64|0)!=0){gGz(o|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){s=p+9|0;t=n;u=n|0;v=n+4|0;w=n+12|0;x=o|0;y=o+4|0;z=o+12|0;A=0;do{gGC(q|0,614896,11)|0;a[s]=A+48&255;B=8452256+(A<<2)|0;gGz(t|0,0,12);c[u>>2]=B;c[v>>2]=4;c[w>>2]=164976;gj[c[2076592]&4095](n)|0;if((c[B>>2]|0)!=0){c[x>>2]=c[14130368+(A<<2)>>2];c[y>>2]=c[8452184+(A<<2)>>2];c[z>>2]=q;B=c[2076592]|0;gj[B&4095](o)|0}A=A+1|0;}while((A|0)<=(c[2392]|0))}A=c[2385546]|0;if((A|0)>0){z=0;y=A;while(1){A=c[(c[9757496+(z<<2)>>2]|0)+32>>2]|0;if((A|0)==0){C=y}else{gg[A&4095](z,b);C=c[2385546]|0}A=z+1|0;if((A|0)<(C|0)){z=A;y=C}else{break}}}gGz(m|0,0,12);c[m>>2]=8453216;c[m+4>>2]=4;c[m+12>>2]=107480;y=c[2076592]|0;gj[y&4095](m)|0;gGz(l|0,0,12);c[l>>2]=14168504;c[l+4>>2]=256;c[l+12>>2]=476464;y=c[2076592]|0;gj[y&4095](l)|0;if((b&2|0)==0){break}else{D=0}do{mv(0,D,d[14168504+D|0]|0);D=D+1|0;}while((D|0)<256)}}while(0);Ut(0);if(!r){c[e>>2]=169110}gGz(k|0,0,12);c[k>>2]=9756784;c[k+4>>2]=4;c[k+12>>2]=175504;gj[c[2076592]&4095](k)|0;gGz(j|0,0,12);c[j>>2]=14166032;c[j+4>>2]=8;c[j+12>>2]=504552;gj[c[2076592]&4095](j)|0;gGz(h|0,0,12);c[h>>2]=14165992;c[h+4>>2]=8;c[h+12>>2]=388736;gj[c[2076592]&4095](h)|0;gGz(g|0,0,12);c[g>>2]=14165960;c[g+4>>2]=32;c[g+12>>2]=302352;gj[c[2076592]&4095](g)|0;i=f;return 0}function fnZ(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;d=c[2113308]|0;do{if((c[2394748]|0)!=(d|0)){c[2394748]=d;if((d|0)==4){c[3528966]=3546;c[3528964]=1606;c[3528962]=5974;c[3528960]=8374;break}else if((d|0)==3){c[3528966]=10202;c[3528964]=4844;c[3528962]=1948;c[3528960]=3696;break}else if((d|0)==2){c[3528966]=6364;c[3528964]=286;c[3528962]=5404;c[3528960]=5468;break}else{return}}}while(0);d=c[3531916]|0;f=c[2113306]<<3;g=c[2113298]<<3;h=c[2112970]|0;i=0;while(1){j=c[3541528]|0;k=c[3541530]|0;l=b[k+(i<<1)>>1]|0;m=l&65535;n=a[8306376]|0?i:e[j+(i<<1)>>1]|0;L81885:do{if((i|0)<233){o=1;while(1){if((o|0)>=8){break}p=o+i|0;if((e[j+(p<<1)>>1]|0)!=(o+n|0)){q=62832;break L81885}if((b[k+(p<<1)>>1]|0)==l<<16>>16){o=o+1|0}else{break}}if((o|0)!=8){q=62832;break}p=(c[2408]|0)+m|0;r=p>>>3;s=c[3541534]|0;t=n<<3&1984;u=p&7;c[2415146]=h+(ag(u,-(c[2113306]|0)|0)|0);p=0;do{v=b[s+((p+r&63|t)<<1)>>1]|0;w=v&65535;do{if(!((v<<16>>16|0)==32|(v<<16>>16|0)==0)){c[2385334]=(c[3541532]|0)+(w<<5&32736);c[2440382]=d+((w>>>6&1008|1024)<<2);if((p|0)==40|(p|0)==0){c[2113020]=(p<<3)-u;gu[c[3528964]&16383]();break}else{gu[c[3528966]&16383]();break}}}while(0);p=p+1|0;c[2415146]=(c[2415146]|0)+f;}while((p|0)<41);x=g;y=i+8|0}else{q=62832}}while(0);if((q|0)==62832){q=0;l=(c[2408]|0)+m|0;k=l>>>3;j=c[3541534]|0;p=n<<3&1984;u=l&7;c[2415146]=h+(ag(u,-(c[2113306]|0)|0)|0);l=n<<2&28;t=0;do{r=b[j+((t+k&63|p)<<1)>>1]|0;s=r&65535;do{if(!((r<<16>>16|0)==32|(r<<16>>16|0)==0)){c[2385334]=(c[3541532]|0)+(s<<5&32736|l);c[2440382]=d+((s>>>6&1008|1024)<<2);if((t|0)==40|(t|0)==0){c[2113020]=(t<<3)-u;gu[c[3528960]&16383]();break}else{gu[c[3528962]&16383]();break}}}while(0);t=t+1|0;c[2415146]=(c[2415146]|0)+f;}while((t|0)<41);x=c[2113298]|0;y=i+1|0}if((y|0)>=240){break}h=h+x|0;i=y}return}function fn_(){var a=0,e=0,f=0,g=0,h=0,i=0,j=0;a=c[2440382]|0;e=c[2415146]|0;f=1;g=c[2385334]|0;while(1){h=d[g]|0;i=h>>>4;if((i|0)!=0){b[e>>1]=c[a+(i<<2)>>2]&65535}i=h&15;if((i|0)!=0){b[e+2>>1]=c[a+(i<<2)>>2]&65535}i=d[g+1|0]|0;h=i>>>4;if((h|0)!=0){b[e+4>>1]=c[a+(h<<2)>>2]&65535}h=i&15;if((h|0)!=0){b[e+6>>1]=c[a+(h<<2)>>2]&65535}h=d[g+2|0]|0;i=h>>>4;if((i|0)!=0){b[e+8>>1]=c[a+(i<<2)>>2]&65535}i=h&15;if((i|0)!=0){b[e+10>>1]=c[a+(i<<2)>>2]&65535}j=g+4|0;i=d[g+3|0]|0;h=i>>>4;if((h|0)!=0){b[e+12>>1]=c[a+(h<<2)>>2]&65535}h=i&15;if((h|0)!=0){b[e+14>>1]=c[a+(h<<2)>>2]&65535}if((f|0)>=8){break}e=e+640|0;f=f+1|0;g=j}c[2385334]=j;return}function fn$(){var a=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;a=c[2113020]|0;e=a>>>0<320;f=c[2440382]|0;g=(a+7|0)>>>0<320;h=(a+6|0)>>>0<320;i=(a+5|0)>>>0<320;j=(a+4|0)>>>0<320;k=(a+3|0)>>>0<320;l=(a+2|0)>>>0<320;m=(a+1|0)>>>0<320;a=c[2415146]|0;n=1;o=c[2385334]|0;while(1){p=d[o]|0;q=p>>>4;if((q|0)!=0&e){b[a>>1]=c[f+(q<<2)>>2]&65535}q=p&15;if(!((q|0)==0|m^1)){b[a+2>>1]=c[f+(q<<2)>>2]&65535}q=d[o+1|0]|0;p=q>>>4;if(!((p|0)==0|l^1)){b[a+4>>1]=c[f+(p<<2)>>2]&65535}p=q&15;if(!((p|0)==0|k^1)){b[a+6>>1]=c[f+(p<<2)>>2]&65535}p=d[o+2|0]|0;q=p>>>4;if(!((q|0)==0|j^1)){b[a+8>>1]=c[f+(q<<2)>>2]&65535}q=p&15;if(!((q|0)==0|i^1)){b[a+10>>1]=c[f+(q<<2)>>2]&65535}r=o+4|0;q=d[o+3|0]|0;p=q>>>4;if(!((p|0)==0|h^1)){b[a+12>>1]=c[f+(p<<2)>>2]&65535}p=q&15;if(!((p|0)==0|g^1)){b[a+14>>1]=c[f+(p<<2)>>2]&65535}if((n|0)>=8){break}a=a+640|0;n=n+1|0;o=r}c[2385334]=r;return}function fn0(){var a=0,e=0,f=0,g=0,h=0;a=c[2415146]|0;e=c[2385334]|0;f=e+1|0;c[2385334]=f;g=d[e]|0;h=g>>>4;if((h|0)!=0){b[a>>1]=c[(c[2440382]|0)+(h<<2)>>2]&65535}h=g&15;if((h|0)!=0){b[a+2>>1]=c[(c[2440382]|0)+(h<<2)>>2]&65535}h=e+2|0;c[2385334]=h;g=d[f]|0;f=g>>>4;if((f|0)!=0){b[a+4>>1]=c[(c[2440382]|0)+(f<<2)>>2]&65535}f=g&15;if((f|0)!=0){b[a+6>>1]=c[(c[2440382]|0)+(f<<2)>>2]&65535}f=e+3|0;c[2385334]=f;e=d[h]|0;h=e>>>4;if((h|0)!=0){b[a+8>>1]=c[(c[2440382]|0)+(h<<2)>>2]&65535}h=e&15;if((h|0)!=0){b[a+10>>1]=c[(c[2440382]|0)+(h<<2)>>2]&65535}h=d[f]|0;f=h>>>4;if((f|0)!=0){b[a+12>>1]=c[(c[2440382]|0)+(f<<2)>>2]&65535}f=h&15;if((f|0)==0){return}b[a+14>>1]=c[(c[2440382]|0)+(f<<2)>>2]&65535;return}function fn1(){var a=0,e=0,f=0,g=0,h=0,i=0,j=0;a=c[2415146]|0;e=c[2385334]|0;f=e+1|0;c[2385334]=f;g=d[e]|0;h=g>>>4;i=c[2113020]|0;if((h|0)!=0&i>>>0<320){b[a>>1]=c[(c[2440382]|0)+(h<<2)>>2]&65535}h=a+2|0;j=g&15;do{if((j|0)!=0){if((i+1|0)>>>0>=320){break}b[h>>1]=c[(c[2440382]|0)+(j<<2)>>2]&65535}}while(0);j=a+4|0;h=e+2|0;c[2385334]=h;g=d[f]|0;f=g>>>4;do{if((f|0)!=0){if((i+2|0)>>>0>=320){break}b[j>>1]=c[(c[2440382]|0)+(f<<2)>>2]&65535}}while(0);f=a+6|0;j=g&15;do{if((j|0)!=0){if((i+3|0)>>>0>=320){break}b[f>>1]=c[(c[2440382]|0)+(j<<2)>>2]&65535}}while(0);j=a+8|0;f=e+3|0;c[2385334]=f;e=d[h]|0;h=e>>>4;do{if((h|0)!=0){if((i+4|0)>>>0>=320){break}b[j>>1]=c[(c[2440382]|0)+(h<<2)>>2]&65535}}while(0);h=a+10|0;j=e&15;do{if((j|0)!=0){if((i+5|0)>>>0>=320){break}b[h>>1]=c[(c[2440382]|0)+(j<<2)>>2]&65535}}while(0);j=a+12|0;h=d[f]|0;f=h>>>4;do{if((f|0)!=0){if((i+6|0)>>>0>=320){break}b[j>>1]=c[(c[2440382]|0)+(f<<2)>>2]&65535}}while(0);f=h&15;if((f|0)==0){return}if((i+7|0)>>>0>=320){return}b[a+14>>1]=c[(c[2440382]|0)+(f<<2)>>2]&65535;return}function fn2(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[2440382]|0;e=1;f=c[2415146]|0;g=c[2385334]|0;while(1){h=d[g]|0;i=h>>>4;if((i|0)!=0){j=c[b+(i<<2)>>2]|0;a[f]=j&255;a[f+1|0]=j>>>8&255;a[f+2|0]=j>>>16&255}j=h&15;if((j|0)!=0){h=c[b+(j<<2)>>2]|0;a[f+3|0]=h&255;a[f+4|0]=h>>>8&255;a[f+5|0]=h>>>16&255}h=d[g+1|0]|0;j=h>>>4;if((j|0)!=0){i=c[b+(j<<2)>>2]|0;a[f+6|0]=i&255;a[f+7|0]=i>>>8&255;a[f+8|0]=i>>>16&255}i=h&15;if((i|0)!=0){h=c[b+(i<<2)>>2]|0;a[f+9|0]=h&255;a[f+10|0]=h>>>8&255;a[f+11|0]=h>>>16&255}h=d[g+2|0]|0;i=h>>>4;if((i|0)!=0){j=c[b+(i<<2)>>2]|0;a[f+12|0]=j&255;a[f+13|0]=j>>>8&255;a[f+14|0]=j>>>16&255}j=h&15;if((j|0)!=0){h=c[b+(j<<2)>>2]|0;a[f+15|0]=h&255;a[f+16|0]=h>>>8&255;a[f+17|0]=h>>>16&255}k=g+4|0;h=d[g+3|0]|0;j=h>>>4;if((j|0)!=0){i=c[b+(j<<2)>>2]|0;a[f+18|0]=i&255;a[f+19|0]=i>>>8&255;a[f+20|0]=i>>>16&255}i=h&15;if((i|0)!=0){h=c[b+(i<<2)>>2]|0;a[f+21|0]=h&255;a[f+22|0]=h>>>8&255;a[f+23|0]=h>>>16&255}if((e|0)>=8){break}e=e+1|0;f=f+960|0;g=k}c[2385334]=k;return}function fn3(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=c[2113020]|0;e=b>>>0<320;f=c[2440382]|0;g=(b+7|0)>>>0<320;h=(b+6|0)>>>0<320;i=(b+5|0)>>>0<320;j=(b+4|0)>>>0<320;k=(b+3|0)>>>0<320;l=(b+2|0)>>>0<320;m=(b+1|0)>>>0<320;b=1;n=c[2415146]|0;o=c[2385334]|0;while(1){p=d[o]|0;q=p>>>4;if((q|0)!=0&e){r=c[f+(q<<2)>>2]|0;a[n]=r&255;a[n+1|0]=r>>>8&255;a[n+2|0]=r>>>16&255}r=p&15;if(!((r|0)==0|m^1)){p=c[f+(r<<2)>>2]|0;a[n+3|0]=p&255;a[n+4|0]=p>>>8&255;a[n+5|0]=p>>>16&255}p=d[o+1|0]|0;r=p>>>4;if(!((r|0)==0|l^1)){q=c[f+(r<<2)>>2]|0;a[n+6|0]=q&255;a[n+7|0]=q>>>8&255;a[n+8|0]=q>>>16&255}q=p&15;if(!((q|0)==0|k^1)){p=c[f+(q<<2)>>2]|0;a[n+9|0]=p&255;a[n+10|0]=p>>>8&255;a[n+11|0]=p>>>16&255}p=d[o+2|0]|0;q=p>>>4;if(!((q|0)==0|j^1)){r=c[f+(q<<2)>>2]|0;a[n+12|0]=r&255;a[n+13|0]=r>>>8&255;a[n+14|0]=r>>>16&255}r=p&15;if(!((r|0)==0|i^1)){p=c[f+(r<<2)>>2]|0;a[n+15|0]=p&255;a[n+16|0]=p>>>8&255;a[n+17|0]=p>>>16&255}s=o+4|0;p=d[o+3|0]|0;r=p>>>4;if(!((r|0)==0|h^1)){q=c[f+(r<<2)>>2]|0;a[n+18|0]=q&255;a[n+19|0]=q>>>8&255;a[n+20|0]=q>>>16&255}q=p&15;if(!((q|0)==0|g^1)){p=c[f+(q<<2)>>2]|0;a[n+21|0]=p&255;a[n+22|0]=p>>>8&255;a[n+23|0]=p>>>16&255}if((b|0)>=8){break}b=b+1|0;n=n+960|0;o=s}c[2385334]=s;return}function fn4(){var b=0,e=0,f=0,g=0,h=0,i=0;b=c[2415146]|0;e=c[2385334]|0;f=e+1|0;c[2385334]=f;g=d[e]|0;h=g>>>4;if((h|0)!=0){i=c[(c[2440382]|0)+(h<<2)>>2]|0;a[b]=i&255;a[b+1|0]=i>>>8&255;a[b+2|0]=i>>>16&255}i=g&15;if((i|0)!=0){g=c[(c[2440382]|0)+(i<<2)>>2]|0;a[b+3|0]=g&255;a[b+4|0]=g>>>8&255;a[b+5|0]=g>>>16&255}g=e+2|0;c[2385334]=g;i=d[f]|0;f=i>>>4;if((f|0)!=0){h=c[(c[2440382]|0)+(f<<2)>>2]|0;a[b+6|0]=h&255;a[b+7|0]=h>>>8&255;a[b+8|0]=h>>>16&255}h=i&15;if((h|0)!=0){i=c[(c[2440382]|0)+(h<<2)>>2]|0;a[b+9|0]=i&255;a[b+10|0]=i>>>8&255;a[b+11|0]=i>>>16&255}i=e+3|0;c[2385334]=i;e=d[g]|0;g=e>>>4;if((g|0)!=0){h=c[(c[2440382]|0)+(g<<2)>>2]|0;a[b+12|0]=h&255;a[b+13|0]=h>>>8&255;a[b+14|0]=h>>>16&255}h=e&15;if((h|0)!=0){e=c[(c[2440382]|0)+(h<<2)>>2]|0;a[b+15|0]=e&255;a[b+16|0]=e>>>8&255;a[b+17|0]=e>>>16&255}e=d[i]|0;i=e>>>4;if((i|0)!=0){h=c[(c[2440382]|0)+(i<<2)>>2]|0;a[b+18|0]=h&255;a[b+19|0]=h>>>8&255;a[b+20|0]=h>>>16&255}h=e&15;if((h|0)==0){return}e=c[(c[2440382]|0)+(h<<2)>>2]|0;a[b+21|0]=e&255;a[b+22|0]=e>>>8&255;a[b+23|0]=e>>>16&255;return}function fn5(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[2415146]|0;e=c[2385334]|0;f=e+1|0;c[2385334]=f;g=d[e]|0;h=g>>>4;i=c[2113020]|0;if((h|0)!=0&i>>>0<320){j=c[(c[2440382]|0)+(h<<2)>>2]|0;a[b]=j&255;a[b+1|0]=j>>>8&255;a[b+2|0]=j>>>16&255}j=b+3|0;h=g&15;do{if((h|0)!=0){if((i+1|0)>>>0>=320){break}g=c[(c[2440382]|0)+(h<<2)>>2]|0;a[j]=g&255;a[b+4|0]=g>>>8&255;a[b+5|0]=g>>>16&255}}while(0);j=b+6|0;h=e+2|0;c[2385334]=h;g=d[f]|0;f=g>>>4;do{if((f|0)!=0){if((i+2|0)>>>0>=320){break}k=c[(c[2440382]|0)+(f<<2)>>2]|0;a[j]=k&255;a[b+7|0]=k>>>8&255;a[b+8|0]=k>>>16&255}}while(0);j=b+9|0;f=g&15;do{if((f|0)!=0){if((i+3|0)>>>0>=320){break}g=c[(c[2440382]|0)+(f<<2)>>2]|0;a[j]=g&255;a[b+10|0]=g>>>8&255;a[b+11|0]=g>>>16&255}}while(0);j=b+12|0;f=e+3|0;c[2385334]=f;e=d[h]|0;h=e>>>4;do{if((h|0)!=0){if((i+4|0)>>>0>=320){break}g=c[(c[2440382]|0)+(h<<2)>>2]|0;a[j]=g&255;a[b+13|0]=g>>>8&255;a[b+14|0]=g>>>16&255}}while(0);j=b+15|0;h=e&15;do{if((h|0)!=0){if((i+5|0)>>>0>=320){break}e=c[(c[2440382]|0)+(h<<2)>>2]|0;a[j]=e&255;a[b+16|0]=e>>>8&255;a[b+17|0]=e>>>16&255}}while(0);j=b+18|0;h=d[f]|0;f=h>>>4;do{if((f|0)!=0){if((i+6|0)>>>0>=320){break}e=c[(c[2440382]|0)+(f<<2)>>2]|0;a[j]=e&255;a[b+19|0]=e>>>8&255;a[b+20|0]=e>>>16&255}}while(0);j=h&15;if((j|0)==0){return}if((i+7|0)>>>0>=320){return}i=c[(c[2440382]|0)+(j<<2)>>2]|0;a[b+21|0]=i&255;a[b+22|0]=i>>>8&255;a[b+23|0]=i>>>16&255;return}function fn6(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0;a=c[2440382]|0;b=c[2415146]|0;e=1;f=c[2385334]|0;while(1){g=d[f]|0;h=g>>>4;if((h|0)!=0){c[b>>2]=c[a+(h<<2)>>2]}h=g&15;if((h|0)!=0){c[b+4>>2]=c[a+(h<<2)>>2]}h=d[f+1|0]|0;g=h>>>4;if((g|0)!=0){c[b+8>>2]=c[a+(g<<2)>>2]}g=h&15;if((g|0)!=0){c[b+12>>2]=c[a+(g<<2)>>2]}g=d[f+2|0]|0;h=g>>>4;if((h|0)!=0){c[b+16>>2]=c[a+(h<<2)>>2]}h=g&15;if((h|0)!=0){c[b+20>>2]=c[a+(h<<2)>>2]}i=f+4|0;h=d[f+3|0]|0;g=h>>>4;if((g|0)!=0){c[b+24>>2]=c[a+(g<<2)>>2]}g=h&15;if((g|0)!=0){c[b+28>>2]=c[a+(g<<2)>>2]}if((e|0)>=8){break}b=b+1280|0;e=e+1|0;f=i}c[2385334]=i;return}function fn7(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;a=c[2113020]|0;b=a>>>0<320;e=c[2440382]|0;f=(a+7|0)>>>0<320;g=(a+6|0)>>>0<320;h=(a+5|0)>>>0<320;i=(a+4|0)>>>0<320;j=(a+3|0)>>>0<320;k=(a+2|0)>>>0<320;l=(a+1|0)>>>0<320;a=c[2415146]|0;m=1;n=c[2385334]|0;while(1){o=d[n]|0;p=o>>>4;if((p|0)!=0&b){c[a>>2]=c[e+(p<<2)>>2]}p=o&15;if(!((p|0)==0|l^1)){c[a+4>>2]=c[e+(p<<2)>>2]}p=d[n+1|0]|0;o=p>>>4;if(!((o|0)==0|k^1)){c[a+8>>2]=c[e+(o<<2)>>2]}o=p&15;if(!((o|0)==0|j^1)){c[a+12>>2]=c[e+(o<<2)>>2]}o=d[n+2|0]|0;p=o>>>4;if(!((p|0)==0|i^1)){c[a+16>>2]=c[e+(p<<2)>>2]}p=o&15;if(!((p|0)==0|h^1)){c[a+20>>2]=c[e+(p<<2)>>2]}q=n+4|0;p=d[n+3|0]|0;o=p>>>4;if(!((o|0)==0|g^1)){c[a+24>>2]=c[e+(o<<2)>>2]}o=p&15;if(!((o|0)==0|f^1)){c[a+28>>2]=c[e+(o<<2)>>2]}if((m|0)>=8){break}a=a+1280|0;m=m+1|0;n=q}c[2385334]=q;return}function fn8(){var a=0,b=0,e=0,f=0,g=0;a=c[2415146]|0;b=c[2385334]|0;e=b+1|0;c[2385334]=e;f=d[b]|0;g=f>>>4;if((g|0)!=0){c[a>>2]=c[(c[2440382]|0)+(g<<2)>>2]}g=f&15;if((g|0)!=0){c[a+4>>2]=c[(c[2440382]|0)+(g<<2)>>2]}g=b+2|0;c[2385334]=g;f=d[e]|0;e=f>>>4;if((e|0)!=0){c[a+8>>2]=c[(c[2440382]|0)+(e<<2)>>2]}e=f&15;if((e|0)!=0){c[a+12>>2]=c[(c[2440382]|0)+(e<<2)>>2]}e=b+3|0;c[2385334]=e;b=d[g]|0;g=b>>>4;if((g|0)!=0){c[a+16>>2]=c[(c[2440382]|0)+(g<<2)>>2]}g=b&15;if((g|0)!=0){c[a+20>>2]=c[(c[2440382]|0)+(g<<2)>>2]}g=d[e]|0;e=g>>>4;if((e|0)!=0){c[a+24>>2]=c[(c[2440382]|0)+(e<<2)>>2]}e=g&15;if((e|0)==0){return}c[a+28>>2]=c[(c[2440382]|0)+(e<<2)>>2];return}function fn9(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0;a=c[2415146]|0;b=c[2385334]|0;e=b+1|0;c[2385334]=e;f=d[b]|0;g=f>>>4;h=c[2113020]|0;if((g|0)!=0&h>>>0<320){c[a>>2]=c[(c[2440382]|0)+(g<<2)>>2]}g=a+4|0;i=f&15;do{if((i|0)!=0){if((h+1|0)>>>0>=320){break}c[g>>2]=c[(c[2440382]|0)+(i<<2)>>2]}}while(0);i=a+8|0;g=b+2|0;c[2385334]=g;f=d[e]|0;e=f>>>4;do{if((e|0)!=0){if((h+2|0)>>>0>=320){break}c[i>>2]=c[(c[2440382]|0)+(e<<2)>>2]}}while(0);e=a+12|0;i=f&15;do{if((i|0)!=0){if((h+3|0)>>>0>=320){break}c[e>>2]=c[(c[2440382]|0)+(i<<2)>>2]}}while(0);i=a+16|0;e=b+3|0;c[2385334]=e;b=d[g]|0;g=b>>>4;do{if((g|0)!=0){if((h+4|0)>>>0>=320){break}c[i>>2]=c[(c[2440382]|0)+(g<<2)>>2]}}while(0);g=a+20|0;i=b&15;do{if((i|0)!=0){if((h+5|0)>>>0>=320){break}c[g>>2]=c[(c[2440382]|0)+(i<<2)>>2]}}while(0);i=a+24|0;g=d[e]|0;e=g>>>4;do{if((e|0)!=0){if((h+6|0)>>>0>=320){break}c[i>>2]=c[(c[2440382]|0)+(e<<2)>>2]}}while(0);e=g&15;if((e|0)==0){return}if((h+7|0)>>>0>=320){return}c[a+28>>2]=c[(c[2440382]|0)+(e<<2)>>2];return}function foa(b){b=b|0;var d=0,e=0,f=0;do{if((b|0)==1048576|(b|0)==1048577){d=a[9647688]|0;e=a[9543088]|0;if(d<<24>>24==e<<24>>24){f=0;break}a[9543088]=d;f=d-e&255}else if((b|0)==1572881){f=a[9625474]|0}else if((b|0)==1572873){f=a[9625476]|0}else if((b|0)==1572877){f=a[9625472]|0}else if((b|0)==1572871){f=a[9625475]|0}else if((b|0)==1576973){f=a[9625477]&15}else if((b|0)==1572879){f=a[9625473]|0}else if((b|0)==1310733){e=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;if((e|0)>=(c[2113018]|0)){f=1;break}f=e>>>31&255}else if((b|0)==262144|(b|0)==262145){e=a[9647680]|0;d=a[9543080]|0;if(e<<24>>24==d<<24>>24){f=0;break}a[9543080]=e;f=e-d&255}else if((b|0)==1572864|(b|0)==1572865){f=-1}else{if((b&16773120|0)!=1572864){f=0;break}f=a[(c[2405158]|0)+(b>>>1&2047)|0]|0}}while(0);return f|0}function fob(e){e=e|0;var f=0,g=0,h=0;do{if((e|0)==1576972){f=a[9625477]&15}else if((e|0)==1572870){f=d[9625475]|0}else if((e|0)==262144){g=a[9647680]|0;h=a[9543080]|0;if(g<<24>>24==h<<24>>24){f=0;break}a[9543080]=g;f=g-h&255}else if((e|0)==1310726){f=b[(c[3541508]|0)+2>>1]|0}else if((e|0)==1572872){f=d[9625476]|0}else if((e|0)==1572880){f=d[9625474]|0}else if((e|0)==1310724){f=b[c[3541508]>>1]|0}else if((e|0)==1572878){f=d[9625473]|0}else if((e|0)==1572864|(e|0)==1572865){f=-1}else if((e|0)==1310732){h=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;if((h|0)>=(c[2113018]|0)){f=1;break}f=h>>>31&65535}else if((e|0)==1572876){f=d[9625472]|0}else if((e|0)==1048576){h=a[9647688]|0;g=a[9543088]|0;if(h<<24>>24==g<<24>>24){f=0;break}a[9543088]=h;f=h-g&255}else{if((e&16773120|0)!=1572864){f=0;break}f=d[(c[2405158]|0)+(e>>>1&2047)|0]|0}}while(0);return f|0}function foc(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;L82309:do{if((b|0)==1572865){e=d&255;do{if((e-208|0)>>>0<16){f=e<<1&30;g=c[2405158]|0;a[g+(f+668)|0]=5;a[g+(f+667)|0]=86;f=g+683|0;if(d<<24>>24!=-45){h=f;i=g;break}gGC(f|0,602928,16)|0;j=g;break L82309}else{g=c[2405158]|0;h=g+683|0;i=g}}while(0);a[h]=78;a[i+684|0]=117;k=63142}else{k=63142}}while(0);do{if((k|0)==63142){if((b&16773120|0)==1572864){j=c[2405158]|0;break}else{return}}}while(0);a[j+(b>>>1&2047)|0]=d;return}function fod(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;L82324:do{if((d|0)==1572864){f=e&65535;do{if((f-208|0)>>>0<16){g=f<<1&30;h=c[2405158]|0;a[h+(g+668)|0]=5;a[h+(g+667)|0]=86;g=h+683|0;if(e<<16>>16!=211){i=g;j=h;break}gGC(g|0,602928,16)|0;k=h;break L82324}else{h=c[2405158]|0;i=h+683|0;j=h}}while(0);a[i]=78;a[j+684|0]=117;l=63159}else if((d|0)==1310732){b[(c[3541500]|0)+(c[3541498]<<1)>>1]=e;return}else if((d|0)==1310720){c[3541508]=(c[3541506]|0)+((e&65535)<<1&16382);return}else if((d|0)==1310726){b[c[3541508]>>1]=e;c[3541508]=(c[3541508]|0)+2;return}else if((d|0)==1310728){c[3541498]=e&255;return}else if((d|0)==1310724){b[c[3541508]>>1]=e;c[3541508]=(c[3541508]|0)+2;return}else{l=63159}}while(0);do{if((l|0)==63159){if((d&16773120|0)==1572864){k=c[2405158]|0;break}else{return}}}while(0);a[k+(d>>>1&2047)|0]=e&255;return}function foe(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>4){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7051980+(b*112|0)>>2];c[a+104>>2]=c[7051984+(b*112|0)>>2];c[a+108>>2]=c[7051988+(b*112|0)>>2];d=0;return d|0}function fof(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<5&(d|0)==0)){e=1;return e|0}c[a>>2]=7051880+(b*112|0);e=0;return e|0}function fog(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?9753056:0;do{if(d){if((a|0)==0){e=0;break}c[a+100>>2]=c[b+100>>2];e=0}else{e=1}}while(0);return e|0}function foh(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?9753056:0;e=0;return e|0}function foi(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6290640+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function foj(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>67){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7215912+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fok(){var b=0,d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;c[2424]=6e3;c[2113208]=1048576;c[2426652]=0;c[2418120]=0;c[3541502]=262144;c[2405590]=1310720;c[2418234]=1310720;c[2405158]=1327104;c[2411402]=1331200;c[3541506]=1335296;c[3541500]=1368064;c[2411500]=1368576;c[3531916]=1368576;b=0;while(1){if((b|0)>=1024){break}d=9638528+(b<<2)|0;if((c[d>>2]|0)==0){e=63208;break}else{b=b+1|0}}do{if((e|0)==63208){b=gGq(1376768)|0;c[d>>2]=b;if((b|0)==0){break}c[2426652]=b;gGz(b|0,0,1376768);c[2418120]=b;c[3541502]=b+262144;f=c[2113208]|0;g=b+(f+262144)|0;c[2405590]=g;c[2418234]=g;c[2405158]=b+(f+278528);c[2411402]=b+(f+282624);c[3541506]=b+(f+286720);c[3541500]=b+(f+319488);g=b+(f+32e4)|0;c[2411500]=g;c[3531916]=g;c[2414040]=b+(f+328192);fpk(b,2)|0;fpl(c[3541502]|0,2,2,c[2113208]|0,0);fxU(0,425984);if((c[2394]|0)==0){i=c[2112932]|0}else{c[2394]=0;b=c[3532596]|0;c[2112932]=b;f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];i=b}b=c[2418120]|0;f=i|0;g=0;while(1){j=b+g|0;c[f>>2]=j;c[f+131072>>2]=j;j=g+1024|0;if(j>>>0>262143){break}else{f=f+4|0;g=j}}g=c[2418234]|0;c[i+2048>>2]=g;c[i+67584>>2]=g;c[i+133120>>2]=g;f=g+1024|0;c[i+2052>>2]=f;c[i+67588>>2]=f;c[i+133124>>2]=f;f=g+2048|0;c[i+2056>>2]=f;c[i+67592>>2]=f;c[i+133128>>2]=f;f=g+3072|0;c[i+2060>>2]=f;c[i+67596>>2]=f;c[i+133132>>2]=f;f=g+4096|0;c[i+2064>>2]=f;c[i+67600>>2]=f;c[i+133136>>2]=f;f=g+5120|0;c[i+2068>>2]=f;c[i+67604>>2]=f;c[i+133140>>2]=f;f=g+6144|0;c[i+2072>>2]=f;c[i+67608>>2]=f;c[i+133144>>2]=f;f=g+7168|0;c[i+2076>>2]=f;c[i+67612>>2]=f;c[i+133148>>2]=f;f=g+8192|0;c[i+2080>>2]=f;c[i+67616>>2]=f;c[i+133152>>2]=f;f=g+9216|0;c[i+2084>>2]=f;c[i+67620>>2]=f;c[i+133156>>2]=f;f=g+10240|0;c[i+2088>>2]=f;c[i+67624>>2]=f;c[i+133160>>2]=f;f=g+11264|0;c[i+2092>>2]=f;c[i+67628>>2]=f;c[i+133164>>2]=f;f=g+12288|0;c[i+2096>>2]=f;c[i+67632>>2]=f;c[i+133168>>2]=f;f=g+13312|0;c[i+2100>>2]=f;c[i+67636>>2]=f;c[i+133172>>2]=f;f=g+14336|0;c[i+2104>>2]=f;c[i+67640>>2]=f;c[i+133176>>2]=f;f=g+15360|0;c[i+2108>>2]=f;c[i+67644>>2]=f;c[i+133180>>2]=f;f=c[2411402]|0;c[i+3072>>2]=f;c[i+68608>>2]=f;c[i+134144>>2]=f;g=f+1024|0;c[i+3076>>2]=g;c[i+68612>>2]=g;c[i+134148>>2]=g;g=f+2048|0;c[i+3080>>2]=g;c[i+68616>>2]=g;c[i+134152>>2]=g;g=f+3072|0;c[i+3084>>2]=g;c[i+68620>>2]=g;c[i+134156>>2]=g;c[i+196688>>2]=3168;c[i+196608>>2]=1140;c[i+196728>>2]=1412;c[i+196648>>2]=868;g=c[3532592]|0;if((g|0)!=0){gGC(g|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;c[2113040]=1;c[2113182]=-470;c[2113178]=-472;c[2113174]=-474;fl6(1);c[2113016]=2048;c[3531920]=c[2411402];Vf(0);g=c[2439194]|0;if((g|0)>0){f=c[2406652]|0;b=0;while(1){h[f+(b*40|0)+16>>3]=1.0;c[f+(b*40|0)+32>>2]=3;j=b+1|0;if((j|0)<(g|0)){b=j}else{break}}c[3528400]=f+(b*40|0);j=0;while(1){h[f+(j*40|0)+24>>3]=1.0;c[f+(j*40|0)+36>>2]=3;k=j+1|0;if((k|0)<(g|0)){j=k}else{break}}c[3528400]=f+(j*40|0)}a[7072640]=1;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060]}RI();g=c[2394]|0;b=c[14130368+(g<<2)>>2]|0;if((b|0)!=0){gGC(b|0,9104152,280)|0}c[8452240+(g<<2)>>2]=c[2113054];c[2394]=-1;g=c[2439194]|0;if((g|0)>0){b=c[2406652]|0;k=0;do{l=b+(k*40|0)|0;m=b+(k*40|0)+12|0;a[m]=0;n=b+(k*40|0)+8|0;c[n>>2]=0;o=a[b+(k*40|0)+14|0]|0;do{if((o&2)!=0&(g|0)>(k|0)){if((o&4)==0){a[b+(k*40|0)+13|0]=1}if((o&1)!=0){break}a[m]=1;c[n>>2]=0}}while(0);k=k+1|0;}while((k|0)<(g|0));c[3528400]=l}a[9647688]=0;a[9543088]=0;a[9647680]=0;a[9543080]=0;p=0;return p|0}}while(0);c[2426652]=0;p=1;return p|0}function fol(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;fl7();if((c[2392]|0)>=0){a=0;do{b=14130368+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}b=14130384+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}a=a+1|0;}while((a|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;a=c[2439194]|0;b=c[2406652]|0;if((a|0)>0){d=0;e=b;f=a;while(1){a=e+(d*40|0)|0;c[3528400]=a;g=c[a>>2]|0;if((g|0)==0){h=f;i=e}else{gGr(g);c[c[3528400]>>2]=0;h=c[2439194]|0;i=c[2406652]|0}g=d+1|0;if((g|0)<(h|0)){d=g;e=i;f=h}else{j=i;break}}}else{j=b}if((j|0)!=0){gGr(j);c[2406652]=0}c[3528400]=0;c[2439194]=0;c[2442914]=0;j=c[2426652]|0;b=0;while(1){if((b|0)>=1024){k=63261;break}l=9638528+(b<<2)|0;if((c[l>>2]|0)==(j|0)){break}else{b=b+1|0}}if((k|0)==63261){c[2426652]=0;return 0}gGr(j);c[l>>2]=0;c[2426652]=0;return 0}function fom(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;if((a[9623560]|0)!=0){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];b=c[3532592]|0;if((b|0)!=0){gGC(9104152,b|0,280)|0}c[2113054]=c[2113060]}RI();b=c[2394]|0;d=c[14130368+(b<<2)>>2]|0;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[8452240+(b<<2)>>2]=c[2113054];c[2394]=-1;b=c[2439194]|0;if((b|0)>0){d=c[2406652]|0;e=0;do{f=d+(e*40|0)|0;g=d+(e*40|0)+12|0;a[g]=0;h=d+(e*40|0)+8|0;c[h>>2]=0;i=a[d+(e*40|0)+14|0]|0;do{if((i&2)!=0&(b|0)>(e|0)){if((i&4)==0){a[d+(e*40|0)+13|0]=1}if((i&1)!=0){break}a[g]=1;c[h>>2]=0}}while(0);e=e+1|0;}while((e|0)<(b|0));c[3528400]=f}a[9647688]=0;a[9543088]=0;a[9647680]=0;a[9543080]=0}gGz(9625472,0,3);f=0;b=0;e=0;d=0;do{b=((a[9632600+f|0]&1)<<f|b&255)&255;e=((a[9630504+f|0]&1)<<f|e&255)&255;d=((a[9551696+f|0]&1)<<f|d&255)&255;f=f+1|0;}while((f|0)<8);a[9625472]=b;a[9625473]=e;a[9625474]=d;if((b&3)==3){d=b&-4;a[9625472]=d;j=d}else{j=b}if((j&12)==12){a[9625472]=j&-13}if((e&3)==3){j=e&-4;a[9625473]=j;k=j}else{k=e}if((k&12)==12){a[9625473]=k&-13}if((a[9632602]|0)!=0){a[9647688]=(a[9647688]|0)-4&255}if((a[9632603]|0)!=0){a[9647688]=(a[9647688]|0)+4&255}if((a[9630506]|0)!=0){a[9647680]=(a[9647680]|0)-4&255}if((a[9630507]|0)!=0){a[9647680]=(a[9647680]|0)+4&255}k=c[2392]|0;if((k|0)>=0){gGz(8452240,0,((k|0)>0?(k<<2)+4|0:4)|0)}c[2113054]=0;if((c[2394]|0)==0){l=0}else{c[2394]=0;c[2112932]=c[3532596];k=c[3532592]|0;if((k|0)!=0){gGC(9104152,k|0,280)|0}k=c[2113060]|0;c[2113054]=k;l=k}k=l+(c[2113220]|0)|0;c[2113054]=k;l=c[2438]|0;e=gGU(l,(l|0)<0|0?-1:0,1e7,0)|0;l=gGS(e,K,15360,0)|0;e=l;c[2113218]=e;c[2113058]=(e|0)/262|0;l=e-((e*22|0|0)/262|0)|0;c[2113018]=l;j=1;b=e;e=l;l=k;while(1){k=(ag(j,b)|0)/4|0;do{if((k|0)>(e|0)){d=(c[2113056]|0)+l-(c[2276108]|0)|0;if((d|0)<(e|0)){f=e-d|0;c[2113056]=f;d=RG(f)|0;c[2113054]=(c[2113054]|0)+d;c[2276108]=-1;c[2113056]=-1}d=c[2112968]|0;do{if((d|0)!=0){f=c[3531916]|0;h=c[f>>2]|0;g=c[2113308]|0;do{if((h|0)==0){gGz(d|0,0,g*76800|0|0)}else{if((g|0)==4){i=0;m=d;while(1){c[m>>2]=h;c[m+4>>2]=h;c[m+8>>2]=h;c[m+12>>2]=h;c[m+16>>2]=h;c[m+20>>2]=h;c[m+24>>2]=h;c[m+28>>2]=h;n=i+1|0;if((n|0)<9600){i=n;m=m+32|0}else{break}}}else if((g|0)==3){m=h>>>8&255;i=h>>>16&255;n=h&255;o=d;p=0;while(1){a[o]=n;a[o+1|0]=m;a[o+2|0]=i;q=p+1|0;if((q|0)<76800){o=o+3|0;p=q}else{break}}}else if((g|0)==2){p=h<<16|h;o=d;i=0;while(1){c[o>>2]=p;c[o+4>>2]=p;c[o+8>>2]=p;c[o+12>>2]=p;c[o+16>>2]=p;c[o+20>>2]=p;c[o+24>>2]=p;c[o+28>>2]=p;m=i+1|0;if((m|0)<4800){o=o+32|0;i=m}else{break}}}else{break}}}while(0);if(a[7072640]|0){c[2112970]=d;c[2113306]=g;c[2113298]=c[2113300];fl3();r=c[3531916]|0}else{r=f}c[2112966]=r;h=c[2113016]|0;if((h|0)>0){s=0}else{break}do{c[r+(s<<2)>>2]=65535;s=s+1|0;}while((s|0)<(h|0))}}while(0);d=c[2430398]|0;h=c[2439196]|0;f=h<<11;c[2438976]=d+f;g=(c[2440572]|0)>1;if(g){c[2438977]=(c[2430399]|0)+f}f=h^1;c[2439196]=f;h=f<<11;f=d+h|0;d=(c[3541506]|0)+12288|0;gGC(f|0,d|0,2048)|0;if(g){g=(c[2430399]|0)+h|0;h=(c[3541504]|0)+12288|0;gGC(g|0,h|0,2048)|0}c[8452200+(c[2394]<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0>=1024){break}RH(4)}}while(0);h=k-(c[2113054]|0)-(c[2113056]|0)+(c[2276108]|0)|0;c[2113056]=h;g=RG(h)|0;t=(c[2113054]|0)+g|0;c[2113054]=t;c[2276108]=-1;c[2113056]=-1;u=c[2113218]|0;if((j|0)>=4){break}j=j+1|0;b=u;e=c[2113018]|0;l=t}c[2113220]=t-u;Vg(c[2112964]|0,a[9688]|0?534:0);u=c[2394]|0;l=c[14130368+(u<<2)>>2]|0;if((l|0)==0){v=8452240+(u<<2)|0;c[v>>2]=t;c[2394]=-1;return 0}gGC(l|0,9104152,280)|0;v=8452240+(u<<2)|0;c[v>>2]=t;c[2394]=-1;return 0}function fon(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[3531916]|0;d=c[b>>2]|0;do{if((d|0)==0){e=c[2113308]|0;gGz(c[2112968]|0,0,e*76800|0|0);f=e}else{e=c[2113308]|0;if((e|0)==2){g=d<<16|d;h=c[2112968]|0;i=0;while(1){c[h>>2]=g;c[h+4>>2]=g;c[h+8>>2]=g;c[h+12>>2]=g;c[h+16>>2]=g;c[h+20>>2]=g;c[h+24>>2]=g;c[h+28>>2]=g;j=i+1|0;if((j|0)<4800){h=h+32|0;i=j}else{f=2;break}}}else if((e|0)==4){i=0;h=c[2112968]|0;while(1){c[h>>2]=d;c[h+4>>2]=d;c[h+8>>2]=d;c[h+12>>2]=d;c[h+16>>2]=d;c[h+20>>2]=d;c[h+24>>2]=d;c[h+28>>2]=d;g=i+1|0;if((g|0)<9600){i=g;h=h+32|0}else{f=4;break}}}else if((e|0)==3){h=d>>>8&255;i=d>>>16&255;g=d&255;j=c[2112968]|0;k=0;while(1){a[j]=g;a[j+1|0]=h;a[j+2|0]=i;l=k+1|0;if((l|0)<76800){j=j+3|0;k=l}else{f=3;break}}}else{f=e;break}}}while(0);if(a[7072640]|0){c[2112970]=c[2112968];c[2113306]=f;c[2113298]=c[2113300];fl3();m=c[3531916]|0}else{m=b}c[2112966]=m;b=c[2113016]|0;if((b|0)>0){n=0}else{return 0}do{c[m+(n<<2)>>2]=65535;n=n+1|0;}while((n|0)<(b|0));return 0}function foo(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;e=i;i=i+128|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;l=e+80|0;m=e+96|0;n=e+112|0;o=(d|0)==0;if(!o){c[d>>2]=133527}if((b&96|0)==0){i=e;return 0}gGz(n|0,0,12);p=c[2405590]|0;c[n>>2]=p;c[n+4>>2]=(c[2411500]|0)-p;c[n+12>>2]=162152;gj[c[2076592]&4095](n)|0;n=m|0;do{if((b&64|0)!=0){gGz(l|0,0,16);c[2394]=-1;if((c[2392]|0)<0){break}p=m+9|0;q=k;r=k|0;s=k+4|0;t=k+12|0;u=l|0;v=l+4|0;w=l+12|0;x=0;do{gGC(n|0,614896,11)|0;a[p]=x+48&255;y=8452256+(x<<2)|0;gGz(q|0,0,12);c[r>>2]=y;c[s>>2]=4;c[t>>2]=164976;gj[c[2076592]&4095](k)|0;if((c[y>>2]|0)!=0){c[u>>2]=c[14130368+(x<<2)>>2];c[v>>2]=c[8452184+(x<<2)>>2];c[w>>2]=n;y=c[2076592]|0;gj[y&4095](l)|0}x=x+1|0;}while((x|0)<=(c[2392]|0))}}while(0);if(!o){c[d>>2]=169110}gGz(j|0,0,12);c[j>>2]=9756784;c[j+4>>2]=4;c[j+12>>2]=175504;gj[c[2076592]&4095](j)|0;gGz(h|0,0,12);c[h>>2]=14166032;c[h+4>>2]=8;c[h+12>>2]=504552;gj[c[2076592]&4095](h)|0;gGz(g|0,0,12);c[g>>2]=14165992;c[g+4>>2]=8;c[g+12>>2]=388736;gj[c[2076592]&4095](g)|0;gGz(f|0,0,12);c[f>>2]=14165960;c[f+4>>2]=32;c[f+12>>2]=302352;gj[c[2076592]&4095](f)|0;i=e;return 0}function fop(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>4){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6571284+(b*112|0)>>2];c[a+104>>2]=c[6571288+(b*112|0)>>2];c[a+108>>2]=c[6571292+(b*112|0)>>2];d=0;return d|0}function foq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<5&(d|0)==0)){e=1;return e|0}c[a>>2]=6571184+(b*112|0);e=0;return e|0}function fos(d,e){d=d|0;e=e|0;var f=0;if((d|0)==1835010){c[3541526]=e&1023;return}else if((d|0)==1572866){c[3542216]=(e&65535)<<1&32766;return}else if((d|0)==1048578){a[9722040]=(e&255)!=0|0;return}else if((d|0)==1835012){f=c[3541526]|0;b[(c[3541524]|0)+((f&1023)<<1)>>1]=e;c[3541526]=f+1;return}else if((d|0)==1572894|(d|0)==1572892|(d|0)==1572890|(d|0)==1572888|(d|0)==1572886|(d|0)==1572884|(d|0)==1572880|(d|0)==1572882){b[14168832+((d>>>1&7)<<1)>>1]=e;return}else if((d|0)==1572868|(d|0)==1572870){f=c[3542216]|0;b[(c[3542214]|0)+((f&32767)<<1)>>1]=e;c[3542216]=f+1;return}else if((d|0)==524290){c[2113312]=e&65535;return}else if((d|0)==524288){c[2113314]=e&65535;return}else if((d|0)==1835014){d=c[3541526]|0;b[(c[3541522]|0)+((d&63)<<1)>>1]=e;c[3541526]=d+1;return}else{return}}function fot(a,b){a=a|0;b=b|0;return}function fou(a){a=a|0;var e=0;if((a|0)==1572880|(a|0)==1572882|(a|0)==1572884|(a|0)==1572886|(a|0)==1572888|(a|0)==1572890|(a|0)==1572892|(a|0)==1572894){e=b[14168832+((a>>>1&7)<<1)>>1]|0}else if((a|0)==1310724){e=d[9634736]|0}else if((a|0)==1835010){e=c[3541526]&1023}else if((a|0)==1310726){e=d[9634737]|0}else if((a|0)==1572870){e=b[(c[3542214]|0)+((c[3542216]&32767)+1<<1)>>1]|0}else if((a|0)==1572868){e=b[(c[3542214]|0)+((c[3542216]&32767)<<1)>>1]|0}else if((a|0)==1310720){e=d[9550208]|0}else if((a|0)==1310722){e=d[9550209]|0}else if((a|0)==1310728){e=d[9550210]|0}else if((a|0)==1310730){e=d[9634738]|0|128}else if((a|0)==1572866){e=(c[3542216]|0)>>>1&16383}else if((a|0)==1835012){e=b[(c[3541524]|0)+((c[3541526]&1023)<<1)>>1]|0}else if((a|0)==1835014){e=b[(c[3541522]|0)+((c[3541526]&63)<<1)>>1]|0}else{e=0}return e|0}function fov(b){b=b|0;var d=0,e=0;do{if((b|0)==1310731){d=a[9634738]|-128}else if((b|0)==1310725){d=a[9634736]|0}else if((b|0)==1310723){d=a[9550209]|0}else if((b|0)==1310729){d=a[9550210]|0}else if((b|0)==1310727){d=a[9634737]|0}else if((b|0)==1310721){d=a[9550208]|0}else if((b|0)==1048577|(b|0)==1835009){e=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;if((e|0)>=(c[2113018]|0)){d=1;break}d=e>>>31&255}else{d=0}}while(0);return d|0}function fow(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2856684+(b*112|0)>>2];c[a+104>>2]=c[2856688+(b*112|0)>>2];c[a+108>>2]=c[2856692+(b*112|0)>>2];d=0;return d|0}function fox(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=2856584+(b*112|0);e=0;return e|0}function foy(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?9719248:0;do{if(d){if((a|0)==0){e=0;break}c[a+100>>2]=c[b+100>>2];e=0}else{e=1}}while(0);return e|0}function foz(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?9719248:0;e=0;return e|0}function foA(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1203928+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function foB(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>46){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3959320+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function foC(){var b=0,d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;c[2424]=6e3;c[2113316]=524288;c[2113212]=524288;c[2414870]=0;c[2388088]=0;c[3542212]=524288;c[3541520]=1048576;c[2414572]=1572864;c[2388218]=1572864;c[2387116]=1589248;c[3530218]=1591296;c[3542214]=1593344;c[3541524]=1658880;c[3541522]=1660928;c[2411498]=1661056;c[3531916]=1661056;c[3531914]=1669248;b=0;while(1){if((b|0)>=1024){break}d=9638528+(b<<2)|0;if((c[d>>2]|0)==0){e=63463;break}else{b=b+1|0}}do{if((e|0)==63463){b=gGq(1677440)|0;c[d>>2]=b;if((b|0)==0){break}c[2414870]=b;gGz(b|0,0,1677440);c[2388088]=b;c[3542212]=b+524288;f=(c[2113316]|0)+524288|0;c[3541520]=b+f;g=f+(c[2113212]|0)|0;f=b+g|0;c[2414572]=f;c[2388218]=f;c[2387116]=b+(g+16384);c[3530218]=b+(g+18432);c[3542214]=b+(g+20480);c[3541524]=b+(g+86016);c[3541522]=b+(g+88064);f=b+(g+88192)|0;c[2411498]=f;c[3531916]=f;c[3531914]=b+(g+96384);c[2414038]=b+(g+104576);if((R6(b+1|0,0,2)|0)!=0){i=1;return i|0}if((R6(c[2388088]|0,1,2)|0)!=0){i=1;return i|0}if((R6((c[2388088]|0)+262145|0,2,2)|0)!=0){i=1;return i|0}if((R6((c[2388088]|0)+262144|0,3,2)|0)!=0){i=1;return i|0}fni(c[3542212]|0,4,c[2113316]|0);fni(c[3541520]|0,8,c[2113212]|0);fxU(0,425984);if((c[2394]|0)==0){j=c[2112932]|0}else{c[2394]=0;b=c[3532596]|0;c[2112932]=b;g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060];j=b}b=c[2388088]|0;g=j|0;f=0;while(1){k=b+f|0;c[g>>2]=k;c[g+131072>>2]=k;k=f+1024|0;if(k>>>0>524287){break}else{g=g+4|0;f=k}}f=c[2388218]|0;c[j+3072>>2]=f;c[j+68608>>2]=f;c[j+134144>>2]=f;g=f+1024|0;c[j+3076>>2]=g;c[j+68612>>2]=g;c[j+134148>>2]=g;g=f+2048|0;c[j+3080>>2]=g;c[j+68616>>2]=g;c[j+134152>>2]=g;g=f+3072|0;c[j+3084>>2]=g;c[j+68620>>2]=g;c[j+134156>>2]=g;g=f+4096|0;c[j+3088>>2]=g;c[j+68624>>2]=g;c[j+134160>>2]=g;g=f+5120|0;c[j+3092>>2]=g;c[j+68628>>2]=g;c[j+134164>>2]=g;g=f+6144|0;c[j+3096>>2]=g;c[j+68632>>2]=g;c[j+134168>>2]=g;g=f+7168|0;c[j+3100>>2]=g;c[j+68636>>2]=g;c[j+134172>>2]=g;g=f+8192|0;c[j+3104>>2]=g;c[j+68640>>2]=g;c[j+134176>>2]=g;g=f+9216|0;c[j+3108>>2]=g;c[j+68644>>2]=g;c[j+134180>>2]=g;g=f+10240|0;c[j+3112>>2]=g;c[j+68648>>2]=g;c[j+134184>>2]=g;g=f+11264|0;c[j+3116>>2]=g;c[j+68652>>2]=g;c[j+134188>>2]=g;g=f+12288|0;c[j+3120>>2]=g;c[j+68656>>2]=g;c[j+134192>>2]=g;g=f+13312|0;c[j+3124>>2]=g;c[j+68660>>2]=g;c[j+134196>>2]=g;g=f+14336|0;c[j+3128>>2]=g;c[j+68664>>2]=g;c[j+134200>>2]=g;g=f+15360|0;c[j+3132>>2]=g;c[j+68668>>2]=g;c[j+134204>>2]=g;g=c[2387116]|0;c[j+4160>>2]=g;c[j+69696>>2]=g;c[j+135232>>2]=g;f=g+1024|0;c[j+4164>>2]=f;c[j+69700>>2]=f;c[j+135236>>2]=f;f=c[3530218]|0;c[j+4192>>2]=f;c[j+69728>>2]=f;c[j+135264>>2]=f;g=f+1024|0;c[j+4196>>2]=g;c[j+69732>>2]=g;c[j+135268>>2]=g;c[j+196688>>2]=1760;c[j+196608>>2]=2374;c[j+196728>>2]=1568;c[j+196648>>2]=2634;g=c[3532592]|0;if((g|0)!=0){gGC(g|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fpA();c[2113016]=2048;c[3531920]=c[2387116];c[3531918]=c[3530218];Vf(0);g=c[2439194]|0;if((g|0)>0){f=c[2406652]|0;b=0;while(1){h[f+(b*40|0)+16>>3]=.6;c[f+(b*40|0)+32>>2]=3;k=b+1|0;if((k|0)<(g|0)){b=k}else{break}}c[3528400]=f+(b*40|0);k=0;while(1){h[f+(k*40|0)+24>>3]=.6;c[f+(k*40|0)+36>>2]=3;l=k+1|0;if((l|0)<(g|0)){k=l}else{break}}c[3528400]=f+(k*40|0)}a[7072632]=1;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060]}RI();g=c[2394]|0;b=c[14130368+(g<<2)>>2]|0;if((b|0)!=0){gGC(b|0,9104152,280)|0}c[8452240+(g<<2)>>2]=c[2113054];c[2394]=-1;g=c[2439194]|0;if((g|0)>0){b=c[2406652]|0;l=0;do{m=b+(l*40|0)|0;n=b+(l*40|0)+12|0;a[n]=0;o=b+(l*40|0)+8|0;c[o>>2]=0;p=a[b+(l*40|0)+14|0]|0;do{if((p&2)!=0&(g|0)>(l|0)){if((p&4)==0){a[b+(l*40|0)+13|0]=1}if((p&1)!=0){break}a[n]=1;c[o>>2]=0}}while(0);l=l+1|0;}while((l|0)<(g|0));c[3528400]=m}a[9722040]=0;i=0;return i|0}}while(0);c[2414870]=0;i=1;return i|0}function foD(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;fpB();if((c[2392]|0)>=0){a=0;do{b=14130368+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}b=14130384+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}a=a+1|0;}while((a|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;a=c[2439194]|0;b=c[2406652]|0;if((a|0)>0){d=0;e=b;f=a;while(1){a=e+(d*40|0)|0;c[3528400]=a;g=c[a>>2]|0;if((g|0)==0){h=f;i=e}else{gGr(g);c[c[3528400]>>2]=0;h=c[2439194]|0;i=c[2406652]|0}g=d+1|0;if((g|0)<(h|0)){d=g;e=i;f=h}else{j=i;break}}}else{j=b}if((j|0)!=0){gGr(j);c[2406652]=0}c[3528400]=0;c[2439194]=0;c[2442914]=0;j=c[2414870]|0;b=0;while(1){if((b|0)>=1024){k=63524;break}l=9638528+(b<<2)|0;if((c[l>>2]|0)==(j|0)){break}else{b=b+1|0}}if((k|0)==63524){c[2414870]=0;return 0}gGr(j);c[l>>2]=0;c[2414870]=0;return 0}function foE(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;if((a[9623552]|0)!=0){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];b=c[3532592]|0;if((b|0)!=0){gGC(9104152,b|0,280)|0}c[2113054]=c[2113060]}RI();b=c[2394]|0;d=c[14130368+(b<<2)>>2]|0;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[8452240+(b<<2)>>2]=c[2113054];c[2394]=-1;b=c[2439194]|0;if((b|0)>0){d=c[2406652]|0;e=0;do{f=d+(e*40|0)|0;g=d+(e*40|0)+12|0;a[g]=0;h=d+(e*40|0)+8|0;c[h>>2]=0;i=a[d+(e*40|0)+14|0]|0;do{if((i&2)!=0&(b|0)>(e|0)){if((i&4)==0){a[d+(e*40|0)+13|0]=1}if((i&1)!=0){break}a[g]=1;c[h>>2]=0}}while(0);e=e+1|0;}while((e|0)<(b|0));c[3528400]=f}a[9722040]=0}gGz(9550208,0,3);f=0;b=0;e=0;d=0;do{b=((a[9632592+f|0]&1)<<f|b&255)&255;e=((a[9630496+f|0]&1)<<f|e&255)&255;d=((a[9629232+f|0]&1)<<f|d&255)&255;f=f+1|0;}while((f|0)<8);a[9550208]=b;a[9550209]=e;a[9550210]=d;if((b&3)==3){d=b&-4;a[9550208]=d;j=d}else{j=b}if((j&12)==12){a[9550208]=j&-13}if((e&3)==3){j=e&-4;a[9550209]=j;k=j}else{k=e}if((k&12)==12){a[9550209]=k&-13}k=c[2392]|0;if((k|0)>=0){gGz(8452240,0,((k|0)>0?(k<<2)+4|0:4)|0)}c[2113054]=0;if((c[2394]|0)==0){l=0}else{c[2394]=0;c[2112932]=c[3532596];k=c[3532592]|0;if((k|0)!=0){gGC(9104152,k|0,280)|0}k=c[2113060]|0;c[2113054]=k;l=k}k=l+(c[2113220]|0)|0;c[2113054]=k;l=c[2438]|0;e=gGU(l,(l|0)<0|0?-1:0,1e7,0)|0;l=gGS(e,K,15360,0)|0;e=l;c[2113218]=e;c[2113058]=(e|0)/262|0;l=e-((e*22|0|0)/262|0)|0;c[2113018]=l;j=1;b=e;e=l;l=k;while(1){k=(ag(j,b)|0)/4|0;do{if((k|0)>(e|0)){d=(c[2113056]|0)+l-(c[2276108]|0)|0;if((d|0)<(e|0)){f=e-d|0;c[2113056]=f;d=RG(f)|0;c[2113054]=(c[2113054]|0)+d;c[2276108]=-1;c[2113056]=-1}d=c[2112968]|0;do{if((d|0)!=0){f=c[3531916]|0;h=c[2113308]|0;do{if((c[f>>2]|0)==0){gGz(d|0,0,h*76800|0|0)}else{if((h|0)==3){g=c[f+1152>>2]|0;i=g>>>8&255;m=g>>>16&255;n=g&255;g=d;o=0;while(1){a[g]=n;a[g+1|0]=i;a[g+2|0]=m;p=o+1|0;if((p|0)<76800){g=g+3|0;o=p}else{break}}}else if((h|0)==2){o=c[f+1152>>2]|0;g=o<<16|o;o=d;m=0;while(1){c[o>>2]=g;c[o+4>>2]=g;c[o+8>>2]=g;c[o+12>>2]=g;c[o+16>>2]=g;c[o+20>>2]=g;c[o+24>>2]=g;c[o+28>>2]=g;i=m+1|0;if((i|0)<4800){o=o+32|0;m=i}else{break}}}else if((h|0)==4){m=c[f+1152>>2]|0;o=0;g=d;while(1){c[g>>2]=m;c[g+4>>2]=m;c[g+8>>2]=m;c[g+12>>2]=m;c[g+16>>2]=m;c[g+20>>2]=m;c[g+24>>2]=m;c[g+28>>2]=m;i=o+1|0;if((i|0)<9600){o=i;g=g+32|0}else{break}}}else{break}}}while(0);if(a[7072632]|0){c[2112970]=d;c[2113306]=h;c[2113298]=c[2113300];fpz();q=c[3531916]|0}else{q=f}c[2112966]=q;g=c[2113016]|0;if((g|0)>0){r=0}else{break}do{c[q+(r<<2)>>2]=65535;r=r+1|0;}while((r|0)<(g|0));f=c[3531914]|0;h=0;do{c[f+(h<<2)>>2]=65535;h=h+1|0;}while((h|0)<(g|0))}}while(0);d=c[2430400]|0;g=c[3541524]|0;gGC(d|0,g|0,2048)|0;if((a[9722040]&1)==0){break}c[8452200+(c[2394]<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0>=1024){break}RH(4)}}while(0);g=k-(c[2113054]|0)-(c[2113056]|0)+(c[2276108]|0)|0;c[2113056]=g;d=RG(g)|0;s=(c[2113054]|0)+d|0;c[2113054]=s;c[2276108]=-1;c[2113056]=-1;if((j|0)>=4){break}j=j+1|0;b=c[2113218]|0;e=c[2113018]|0;l=s}Vg(c[2112964]|0,a[9688]|0?534:0);c[2113220]=s-(c[2113218]|0);s=c[2430400]|0;l=c[3541524]|0;gGC(s|0,l|0,2048)|0;l=c[2394]|0;c[8452200+(l<<2)>>2]=8194;c[2276080]=512;if((c[2276079]|0)>>>0<512){RH(2);t=c[2394]|0}else{t=l}l=c[14130368+(t<<2)>>2]|0;if((l|0)==0){u=c[2113054]|0;v=8452240+(t<<2)|0;c[v>>2]=u;c[2394]=-1;return 0}gGC(l|0,9104152,280)|0;u=c[2113054]|0;v=8452240+(t<<2)|0;c[v>>2]=u;c[2394]=-1;return 0}function foF(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=c[3531916]|0;do{if((c[b>>2]|0)==0){d=c[2113308]|0;gGz(c[2112968]|0,0,d*76800|0|0);e=d}else{d=c[2113308]|0;if((d|0)==4){f=c[b+1152>>2]|0;g=0;h=c[2112968]|0;while(1){c[h>>2]=f;c[h+4>>2]=f;c[h+8>>2]=f;c[h+12>>2]=f;c[h+16>>2]=f;c[h+20>>2]=f;c[h+24>>2]=f;c[h+28>>2]=f;i=g+1|0;if((i|0)<9600){g=i;h=h+32|0}else{e=4;break}}}else if((d|0)==2){h=c[b+1152>>2]|0;g=h<<16|h;h=c[2112968]|0;f=0;while(1){c[h>>2]=g;c[h+4>>2]=g;c[h+8>>2]=g;c[h+12>>2]=g;c[h+16>>2]=g;c[h+20>>2]=g;c[h+24>>2]=g;c[h+28>>2]=g;i=f+1|0;if((i|0)<4800){h=h+32|0;f=i}else{e=2;break}}}else if((d|0)==3){f=c[b+1152>>2]|0;h=f>>>8&255;g=f>>>16&255;i=f&255;f=c[2112968]|0;j=0;while(1){a[f]=i;a[f+1|0]=h;a[f+2|0]=g;k=j+1|0;if((k|0)<76800){f=f+3|0;j=k}else{e=3;break}}}else{e=d;break}}}while(0);if(a[7072632]|0){c[2112970]=c[2112968];c[2113306]=e;c[2113298]=c[2113300];fpz();l=c[3531916]|0}else{l=b}c[2112966]=l;b=c[2113016]|0;if((b|0)>0){m=0}else{return 0}do{c[l+(m<<2)>>2]=65535;m=m+1|0;}while((m|0)<(b|0));m=c[3531914]|0;l=0;do{c[m+(l<<2)>>2]=65535;l=l+1|0;}while((l|0)<(b|0));return 0}function foG(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=i;i=i+80|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;if((d|0)!=0){c[d>>2]=169735}if((b&96|0)==0){i=e;return 0}gGz(k|0,0,12);d=c[2414572]|0;c[k>>2]=d;c[k+4>>2]=(c[2411498]|0)-d;c[k+12>>2]=219592;gj[c[2076592]&4095](k)|0;k=h|0;do{if((b&64|0)!=0){gGz(g|0,0,16);c[2394]=-1;if((c[2392]|0)<0){break}d=h+9|0;l=f;m=f|0;n=f+4|0;o=f+12|0;p=g|0;q=g+4|0;r=g+12|0;s=0;do{gGC(k|0,614896,11)|0;a[d]=s+48&255;t=8452256+(s<<2)|0;gGz(l|0,0,12);c[m>>2]=t;c[n>>2]=4;c[o>>2]=164976;gj[c[2076592]&4095](f)|0;if((c[t>>2]|0)!=0){c[p>>2]=c[14130368+(s<<2)>>2];c[q>>2]=c[8452184+(s<<2)>>2];c[r>>2]=k;t=c[2076592]|0;gj[t&4095](g)|0}s=s+1|0;}while((s|0)<=(c[2392]|0))}}while(0);gGz(j|0,0,12);c[j>>2]=8452880;c[j+4>>2]=8;c[j+12>>2]=212472;gj[c[2076592]&4095](j)|0;i=e;return 0}function foH(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1552180+(b*112|0)>>2];c[a+104>>2]=c[1552184+(b*112|0)>>2];c[a+108>>2]=c[1552188+(b*112|0)>>2];d=0;return d|0}function foI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=1552080+(b*112|0);e=0;return e|0}function foJ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>35){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3531448+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function foK(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1101060+(b*112|0)>>2];c[a+104>>2]=c[1101064+(b*112|0)>>2];c[a+108>>2]=c[1101068+(b*112|0)>>2];d=0;return d|0}function foL(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=1100960+(b*112|0);e=0;return e|0}function foM(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2347788+(b*112|0)>>2];c[a+104>>2]=c[2347792+(b*112|0)>>2];c[a+108>>2]=c[2347796+(b*112|0)>>2];d=0;return d|0}function foN(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=2347688+(b*112|0);e=0;return e|0}function foO(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>32){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3531048+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function foP(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1405540+(b*112|0)>>2];c[a+104>>2]=c[1405544+(b*112|0)>>2];c[a+108>>2]=c[1405548+(b*112|0)>>2];d=0;return d|0}function foQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=1405440+(b*112|0);e=0;return e|0}function foR(a){a=a|0;var b=0,d=0;b=a&65535;if((b|0)==57345){d=c[(c[3531464]|0)+4240>>2]&255}else if((b|0)==57372){d=c[2439198]&255}else if((b|0)==57348){d=c[2113156]&255}else{d=0}return d|0}function foS(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;switch(b&65535|0){case 57350:{b=c[3541206]|0;e=d&255;f=b+(e<<16&983040)|0;c[3541190]=f;c[3541198]=f;f=e<<12&983040;c[3541191]=b+(f|256);c[3541199]=b+f;return};case 57354:{f=d&7;if((f|0)==(c[2440568]|0)){return}b=c[3532626]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;g=(f<<14)-32768|0;h=128;i=128;while(1){c[e+76+(i<<2)>>2]=b+(g+(i<<8));j=h+1&65535;if((j&65535)>191){k=128;l=128;break}else{h=j;i=j&65535}}while(1){i=b+(g+(l<<8))|0;c[e+76+(l+512<<2)>>2]=i;c[e+76+(l+768<<2)>>2]=i;i=k+1&65535;if((i&65535)>191){break}else{k=i;l=i&65535}}c[2440568]=f;return};case 57352:{f=c[3541206]|0;l=d&255;k=l<<16&983040;c[3541192]=f+(k|512);c[3541200]=f+k;k=l<<12&983040;c[3541193]=f+(k|768);c[3541201]=f+k;return};case 57345:{k=c[2113304]|0;a[14168504+k|0]=d;mv(0,k,d&255);return};case 57344:{c[2113304]=d&255;return};case 57348:{Uv(0,d);return};default:{return}}}function foT(b){b=b|0;var d=0;if((b|0)==2211893){d=a[9625469]|0}else if((b|0)==2211873){d=a[9625464]|0}else if((b|0)==2195489){d=a[(c[3532636]|0)+16|0]|0}else if((b|0)==2195491){d=a[(c[3532636]|0)+17|0]|0}else if((b|0)==2211881){d=a[9625466]|0}else if((b|0)==2211885){d=a[9625467]|0}else if((b|0)==2211877){d=a[9625465]|0}else if((b|0)==2211889){d=a[9625468]|0}else{d=0}return d|0}function foU(a){a=a|0;var d=0,e=0;if((a|0)==3145732){d=b[c[3541508]>>1]|0;return d|0}else if((a|0)==3145734){d=b[(c[3541508]|0)+2>>1]|0;return d|0}else if((a|0)==2211900){a=((c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0)/(c[2113058]|0)|0;if((a|0)==(c[2384348]|0)){e=65024}else{c[2384348]=a;e=32256}d=(e|a)&65535;return d|0}else{d=0;return d|0}return 0}function foV(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;if((b|0)==6291457){c[2439198]=d&255;a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0;if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){e=gfc(512)|0;f=e;g=(c[2433530]|0)+e|0}else{f=512;g=(c[2433530]|0)+512|0}c[2433530]=g;c[2113221]=(c[2113221]|0)+f;return}else if((b|0)==2195489){a[(c[3532636]|0)+16|0]=d;return}else{return}}function foW(a,d){a=a|0;d=d|0;switch(a|0){case 3145740:{b[(c[3541500]|0)+(c[3541498]<<1)>>1]=d;return};case 3145736:{c[3541498]=d&255;return};case 3145732:case 3145734:{b[c[3541508]>>1]=d;c[3541508]=(c[3541508]|0)+2;return};case 3145728:{c[3541508]=(c[3541506]|0)+((d&65535)<<1&16382);return};default:{return}}}function foX(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3096468+(b*112|0)>>2];c[a+104>>2]=c[3096472+(b*112|0)>>2];c[a+108>>2]=c[3096476+(b*112|0)>>2];d=0;return d|0}function foY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=3096368+(b*112|0);e=0;return e|0}function foZ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1615848+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function fo_(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=81){if((a|0)==0){d=0;return d|0}e=a;f=3097376+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}f=b-82|0;if(f>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;a=699248+(f*12|0)|0;c[b>>2]=c[a>>2];c[b+4>>2]=c[a+4>>2];c[b+8>>2]=c[a+8>>2];d=0;return d|0}function fo$(){var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;d=i;i=i+840|0;e=d|0;f=d+112|0;g=d+120|0;j=d+232|0;k=d+240|0;l=d+352|0;m=d+360|0;n=d+472|0;o=d+480|0;p=d+592|0;q=d+600|0;r=d+712|0;s=d+720|0;t=d+832|0;c[2113208]=8388608;c[2426650]=0;c[2418118]=0;c[3532626]=1048576;c[3541502]=1179648;c[3541532]=9568256;c[3541206]=9633792;c[2405588]=10682368;c[2418232]=10682368;c[2418196]=10747904;c[3541534]=10749952;c[3541530]=10758144;c[3541528]=10762240;c[2411400]=10766336;c[3532636]=10770432;c[3541506]=10786816;c[3541500]=10803200;c[2411496]=10803712;c[3531916]=10803712;u=0;while(1){if((u|0)>=1024){break}v=9638528+(u<<2)|0;if((c[v>>2]|0)==0){w=63785;break}else{u=u+1|0}}do{if((w|0)==63785){u=gGq(10811904)|0;c[v>>2]=u;if((u|0)==0){break}c[2426650]=u;gGz(u|0,0,10811904);c[2418118]=u;c[3532626]=u+1048576;c[3541502]=u+1179648;x=c[2113208]|0;c[3541532]=u+(x+1179648);c[3541206]=u+(x+1245184);y=u+(x+2293760)|0;c[2405588]=y;c[2418232]=y;c[2418196]=u+(x+2359296);c[3541534]=u+(x+2361344);c[3541530]=u+(x+2369536);c[3541528]=u+(x+2373632);c[2411400]=u+(x+2377728);c[3532636]=u+(x+2381824);c[3541506]=u+(x+2398208);c[3541500]=u+(x+2414592);y=u+(x+2415104)|0;c[2411496]=y;c[3531916]=y;c[2414036]=u+(x+2423296);do{if(a[8306376]|0){if((c[3542200]|0)==0){z=1;i=d;return z|0}x=s+108|0;c[x>>2]=0;y=s+100|0;c[y>>2]=0;A=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[A&16383](s,0)|0;do{if((c[x>>2]|0)!=0){A=c[y>>2]|0;c[t>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](t,0,0)|0;if((A|0)<1){z=1;i=d;return z|0}if((gzL(u,0,0)|0)==0){break}else{z=1}i=d;return z|0}}while(0);fpl(c[3541502]|0,1,2,c[2113208]|0,0);y=c[3541532]|0;do{if((c[3542200]|0)!=0){x=q+108|0;c[x>>2]=0;A=q+100|0;c[A>>2]=0;B=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[B&16383](q,3)|0;if((c[x>>2]|0)==0){break}x=c[A>>2]|0;c[r>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](r,3,0)|0;if((x|0)<1){break}gzL(y,0,3)|0}}while(0);y=c[3532626]|0;do{if((c[3542200]|0)!=0){x=o+108|0;c[x>>2]=0;A=o+100|0;c[A>>2]=0;B=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[B&16383](o,4)|0;if((c[x>>2]|0)==0){break}x=c[A>>2]|0;c[p>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](p,4,0)|0;if((x|0)<1){break}gzL(y,0,4)|0}}while(0);y=c[3541206]|0;if((c[3542200]|0)==0){break}x=m+108|0;c[x>>2]=0;A=m+100|0;c[A>>2]=0;B=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[B&16383](m,5)|0;if((c[x>>2]|0)==0){break}x=c[A>>2]|0;c[n>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](n,5,0)|0;if((x|0)<1){break}gzL(y,0,5)|0}else{if((fpk(u,2)|0)!=0){z=1;i=d;return z|0}fpl(c[3541502]|0,2,4,c[2113208]|0,0);y=c[3541532]|0;do{if((c[3542200]|0)!=0){x=k+108|0;c[x>>2]=0;A=k+100|0;c[A>>2]=0;B=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[B&16383](k,6)|0;if((c[x>>2]|0)==0){break}x=c[A>>2]|0;c[l>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](l,6,0)|0;if((x|0)<1){break}gzL(y,0,6)|0}}while(0);y=c[3532626]|0;do{if((c[3542200]|0)!=0){x=g+108|0;c[x>>2]=0;A=g+100|0;c[A>>2]=0;B=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[B&16383](g,7)|0;if((c[x>>2]|0)==0){break}x=c[A>>2]|0;c[j>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](j,7,0)|0;if((x|0)<1){break}gzL(y,0,7)|0}}while(0);y=c[3541206]|0;if((c[3542200]|0)==0){break}x=e+108|0;c[x>>2]=0;A=e+100|0;c[A>>2]=0;B=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[B&16383](e,8)|0;if((c[x>>2]|0)==0){break}x=c[A>>2]|0;c[f>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](f,8,0)|0;if((x|0)<1){break}gzL(y,0,8)|0}}while(0);fxU(0,425984);if((c[2394]|0)==0){C=c[2112932]|0}else{c[2394]=0;u=c[3532596]|0;c[2112932]=u;y=c[3532592]|0;if((y|0)!=0){gGC(9104152,y|0,280)|0}c[2113054]=c[2113060];C=u}u=c[2418118]|0;y=C|0;x=0;while(1){A=u+x|0;c[y>>2]=A;c[y+131072>>2]=A;A=x+1024|0;if(A>>>0>1048575){break}else{y=y+4|0;x=A}}x=c[2418232]|0;y=C+4096|0;u=1048576;while(1){A=x+(u-1048576)|0;c[y>>2]=A;c[y+65536>>2]=A;c[y+131072>>2]=A;A=u+1024|0;if(A>>>0>1114111){break}else{y=y+4|0;u=A}}u=c[2411400]|0;c[C+16384>>2]=u;c[C+81920>>2]=u;c[C+147456>>2]=u;y=u+1024|0;c[C+16388>>2]=y;c[C+81924>>2]=y;c[C+147460>>2]=y;y=u+2048|0;c[C+16392>>2]=y;c[C+81928>>2]=y;c[C+147464>>2]=y;y=u+3072|0;c[C+16396>>2]=y;c[C+81932>>2]=y;c[C+147468>>2]=y;y=c[2418196]|0;c[C+16400>>2]=y;c[C+81936>>2]=y;c[C+147472>>2]=y;u=y+1024|0;c[C+16404>>2]=u;c[C+81940>>2]=u;c[C+147476>>2]=u;u=c[3541534]|0;c[C+20480>>2]=u;c[C+86016>>2]=u;c[C+151552>>2]=u;y=u+1024|0;c[C+20484>>2]=y;c[C+86020>>2]=y;c[C+151556>>2]=y;y=u+2048|0;c[C+20488>>2]=y;c[C+86024>>2]=y;c[C+151560>>2]=y;y=u+3072|0;c[C+20492>>2]=y;c[C+86028>>2]=y;c[C+151564>>2]=y;y=u+4096|0;c[C+20496>>2]=y;c[C+86032>>2]=y;c[C+151568>>2]=y;y=u+5120|0;c[C+20500>>2]=y;c[C+86036>>2]=y;c[C+151572>>2]=y;y=u+6144|0;c[C+20504>>2]=y;c[C+86040>>2]=y;c[C+151576>>2]=y;y=u+7168|0;c[C+20508>>2]=y;c[C+86044>>2]=y;c[C+151580>>2]=y;y=c[3541528]|0;c[C+20512>>2]=y;c[C+86048>>2]=y;c[C+151584>>2]=y;u=y+1024|0;c[C+20516>>2]=u;c[C+86052>>2]=u;c[C+151588>>2]=u;u=y+2048|0;c[C+20520>>2]=u;c[C+86056>>2]=u;c[C+151592>>2]=u;u=y+3072|0;c[C+20524>>2]=u;c[C+86060>>2]=u;c[C+151596>>2]=u;u=c[3541530]|0;c[C+20528>>2]=u;c[C+86064>>2]=u;c[C+151600>>2]=u;y=u+1024|0;c[C+20532>>2]=y;c[C+86068>>2]=y;c[C+151604>>2]=y;y=u+2048|0;c[C+20536>>2]=y;c[C+86072>>2]=y;c[C+151608>>2]=y;y=u+3072|0;c[C+20540>>2]=y;c[C+86076>>2]=y;c[C+151612>>2]=y;c[C+196688>>2]=972;c[C+196608>>2]=2754;c[C+196728>>2]=480;c[C+196648>>2]=1406;y=c[3532592]|0;if((y|0)!=0){gGC(y|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;a[9552]=1;c[2113040]=1;c[2113182]=-470;c[2113178]=-472;c[2113174]=-474;fl6(1);c[2408]=44;if(a[8306376]|0){c[2408]=0}fwR(0);y=c[2439330]|0;u=(y|0)==0;if(!u){x=y;gGC(9706056,x|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];x=c[3528484]|0;c[2076596]=x;A=c[2417276]|0;c[3541536]=A;c[1836236]=0;c[y+4180>>2]=1662;c[y+4184>>2]=1362;B=c[3532626]|0;D=0;E=0;while(1){c[y+76+(E<<2)>>2]=B+(E<<8);F=D+1&65535;if((F&65535)>127){G=0;H=0;break}else{D=F;E=F&65535}}while(1){E=B+(H<<8)|0;c[y+76+(H+512<<2)>>2]=E;c[y+76+(H+768<<2)>>2]=E;E=G+1&65535;if((E&65535)>127){I=128;J=128;break}else{G=E;H=E&65535}}while(1){c[y+76+(J<<2)>>2]=B+(J<<8);E=I+1&65535;if((E&65535)>191){K=128;L=128;break}else{I=E;J=E&65535}}while(1){E=B+(L<<8)|0;c[y+76+(L+512<<2)>>2]=E;c[y+76+(L+768<<2)>>2]=E;E=K+1&65535;if((E&65535)>191){break}else{K=E;L=E&65535}}B=c[3532636]|0;E=192;D=192;while(1){c[y+76+(D<<2)>>2]=B+((D<<8)-49152);F=E+1&65535;if((F&65535)>223){M=192;N=192;break}else{E=F;D=F&65535}}while(1){c[y+76+(N+256<<2)>>2]=B+((N<<8)-49152);D=M+1&65535;if((D&65535)>223){O=192;P=192;break}else{M=D;N=D&65535}}while(1){D=B+((P<<8)-49152)|0;c[y+76+(P+512<<2)>>2]=D;c[y+76+(P+768<<2)>>2]=D;D=O+1&65535;if((D&65535)>223){break}else{O=D;P=D&65535}}c[y+972>>2]=0;c[y+1996>>2]=0;if(!u){B=y;gGC(B|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=x;c[2417276]=A;c[1836236]=-1;c[2440568]=2;B=a[9680]|0;D=B?32e3:0;if(B){if(a[9624]|0){B=D*3|0;E=62500;while(1){if((E|0)>(B|0)){E=E>>1}else{Q=1222;R=E;break}}}else{Q=2462;R=D}c[2429380]=R;c[3542124]=Q;mw(4e6,R);E=gGq(262144)|0;c[2406684]=E;gGz(E|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(4e6,11025)}h[745421]=1.0;c[2436794]=3;h[745420]=1.0;c[2436792]=3;Ux(0,15151,1);c[2407030]=256;c[2407068]=3;c[2113016]=2048;c[3531920]=c[2411400];a[7072624]=1;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];E=c[3532592]|0;if((E|0)!=0){gGC(9104152,E|0,280)|0}c[2113054]=c[2113060]}a[9775616]=0;c[2113050]=0;c[2276080]=0;RI();E=c[2394]|0;B=c[14130368+(E<<2)>>2]|0;if((B|0)!=0){gGC(B|0,9104152,280)|0}c[8452240+(E<<2)>>2]=c[2113054];c[2394]=-1;E=c[2439330]|0;B=(E|0)==0;if(!B){A=E;gGC(9706056,A|0,76)|0}A=c[2438118]|0;c[2433530]=A;x=c[3528484]|0;c[2076596]=x;y=c[2417276]|0;c[3541536]=y;c[1836236]=0;gGz(9706056,0,76);if(!B){B=E;gGC(B|0,9706056,76)|0}c[2438118]=A;c[3528484]=x;c[2417276]=y;c[1836236]=-1;c[2113156]=0;a[9628264]=0;c[2407033]=0;y=c[3541206]|0;c[3541190]=y;c[3541198]=y;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=y+256;c[3541199]=y+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=y+512;c[3541200]=y+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=y+768;c[3541201]=y+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;mx(0);z=0;i=d;return z|0}}while(0);c[2426650]=0;z=1;i=d;return z|0}function fo0(){var b=0,d=0,e=0,f=0,g=0;Uw(0);b=c[3531464]|0;c[b+44344>>2]=0;c[b+44348>>2]=0;if((b|0)!=0){gGr(b);c[3531464]=0}b=c[2406684]|0;if((b|0)!=0){gGr(b);c[2406684]=0}fl7();c[2408]=39321;fwZ();if((c[2392]|0)>=0){b=0;do{d=14130368+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}d=14130384+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}b=b+1|0;}while((b|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;b=c[2426650]|0;d=0;while(1){if((d|0)>=1024){f=63882;break}g=9638528+(d<<2)|0;if((c[g>>2]|0)==(b|0)){break}else{d=d+1|0}}if((f|0)==63882){c[2426650]=0;a[8306376]=0;return 0}gGr(b);c[g>>2]=0;c[2426650]=0;a[8306376]=0;return 0}function fo1(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;if((a[9623544]|0)!=0){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}a[9775616]=0;c[2113050]=0;c[2276080]=0;RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;h=c[2417276]|0;c[3541536]=h;c[1836236]=0;gGz(9706056,0,76);if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=h;c[1836236]=-1;c[2113156]=0;a[9628264]=0;c[2407033]=0;h=c[3541206]|0;c[3541190]=h;c[3541198]=h;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=h+256;c[3541199]=h+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=h+512;c[3541200]=h+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=h+768;c[3541201]=h+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;mx(0)}a[9625464]=0;a[9625465]=0;a[9625466]=0;h=0;g=0;f=0;e=0;do{g=((a[9632584+h|0]&1)<<h|g&255)&255;f=((a[9630488+h|0]&1)<<h|f&255)&255;e=((a[9551688+h|0]&1)<<h|e&255)&255;h=h+1|0;}while((h|0)<8);a[9625464]=g;a[9625465]=f;a[9625466]=e;if((g&3)==3){e=g&-4;a[9625464]=e;i=e}else{i=g}if((i&12)==12){a[9625464]=i&-13}if((f&3)==3){i=f&-4;a[9625465]=i;j=i}else{j=f}if((j&12)==12){a[9625465]=j&-13}j=c[2392]|0;if((j|0)>=0){gGz(8452240,0,((j|0)>0?(j<<2)+4|0:4)|0)}c[2113054]=0;j=c[2438]|0;f=gGU(j,(j|0)<0|0?-1:0,16e6,0)|0;j=gGS(f,K,15360,0)|0;f=j;c[2113218]=f;c[2113216]=66666;c[2113221]=0;c[2113220]=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];j=c[3532592]|0;if((j|0)!=0){gGC(9104152,j|0,280)|0}c[2113054]=c[2113060]}c[2113058]=(f|0)/262|0;c[2113018]=f-((f*22|0|0)/262|0);a[670624]=0;j=c[2439330]|0;if((j|0)!=0){i=j;gGC(9706056,i|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;i=1;j=0;g=f;f=0;while(1){e=(ag(g,i)|0)/8|0;do{if(!f){h=c[2113018]|0;if((e|0)<=(h|0)){break}d=c[2113220]|0;if((d|0)<(h|0)){k=h-d|0;c[2113056]=k;d=RG(k)|0;c[2113054]=(c[2113054]|0)+d;c[2276108]=-1;c[2113056]=-1;c[2113220]=(c[2113220]|0)+d}a[9775616]=1;c[8452200+(c[2394]<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0<1024){RH(4)}d=c[2430398]|0;k=c[2439196]|0;h=k<<11;c[2438976]=d+h;l=(c[2440572]|0)>1;if(l){c[2438977]=(c[2430399]|0)+h}h=k^1;c[2439196]=h;k=h<<11;h=d+k|0;d=(c[3541506]|0)+12288|0;gGC(h|0,d|0,2048)|0;if(l){l=(c[2430399]|0)+k|0;k=(c[3541504]|0)+12288|0;gGC(l|0,k|0,2048)|0}k=c[2112968]|0;do{if((k|0)!=0){l=c[3531916]|0;d=c[l>>2]|0;h=c[2113308]|0;do{if((d|0)==0){gGz(k|0,0,h*76800|0|0)}else{if((h|0)==3){m=d>>>8&255;n=d>>>16&255;o=d&255;p=k;q=0;while(1){a[p]=o;a[p+1|0]=m;a[p+2|0]=n;r=q+1|0;if((r|0)<76800){p=p+3|0;q=r}else{break}}}else if((h|0)==2){q=d<<16|d;p=k;n=0;while(1){c[p>>2]=q;c[p+4>>2]=q;c[p+8>>2]=q;c[p+12>>2]=q;c[p+16>>2]=q;c[p+20>>2]=q;c[p+24>>2]=q;c[p+28>>2]=q;m=n+1|0;if((m|0)<4800){p=p+32|0;n=m}else{break}}}else if((h|0)==4){n=0;p=k;while(1){c[p>>2]=d;c[p+4>>2]=d;c[p+8>>2]=d;c[p+12>>2]=d;c[p+16>>2]=d;c[p+20>>2]=d;c[p+24>>2]=d;c[p+28>>2]=d;q=n+1|0;if((q|0)<9600){n=q;p=p+32|0}else{break}}}else{break}}}while(0);if(a[7072624]|0){c[2112970]=k;c[2113306]=h;c[2113298]=c[2113300];fl3();fnZ();s=c[3531916]|0}else{s=l}c[2112966]=s;d=c[2113016]|0;if((d|0)>0){t=0}else{break}do{c[s+(t<<2)>>2]=65535;t=t+1|0;}while((t|0)<(d|0))}}while(0);a[670624]=1}}while(0);k=e-(c[2113220]|0)|0;c[2113056]=k;d=RG(k)|0;c[2113054]=(c[2113054]|0)+d;c[2276108]=-1;c[2113056]=-1;c[2113220]=(c[2113220]|0)+d;a[9775616]=0;do{if((i&1|0)==0){d=(ag(c[2113216]|0,i)|0)/8|0;k=c[2113221]|0;l=d-k|0;do{if((l|0)<1){u=0;v=k}else{if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){d=gfc(l)|0;c[2433530]=(c[2433530]|0)+d;u=d;v=c[2113221]|0;break}else{c[2433530]=(c[2433530]|0)+l;u=l;v=k;break}}}while(0);c[2113221]=v+u;k=c[2112964]|0;if((k|0)==0){w=j;break}l=(ag(a[9688]|0?534:0,i)|0)/8|0;d=l-j|0;h=k+(j<<1<<1)|0;gg[c[3542124]&4095](h,d);Uu(0,h,d);w=l}else{w=j}}while(0);e=i+1|0;if((e|0)>=9){break}i=e;j=w;g=c[2113218]|0;f=a[670624]|0}f=c[2394]|0;g=c[14130368+(f<<2)>>2]|0;if((g|0)!=0){gGC(g|0,9104152,280)|0}c[8452240+(f<<2)>>2]=c[2113054];c[2394]=-1;f=c[2112964]|0;do{if((f|0)!=0){g=a[9688]|0?534:0;j=g-w|0;i=f+(w<<1<<1)|0;if((g|0)==(w|0)){break}gg[c[3542124]&4095](i,j);Uu(0,i,j)}}while(0);w=c[1836236]|0;f=c[9757320+(w<<2)>>2]|0;if((f|0)==0){x=c[2433530]|0;y=9752472+(w<<2)|0;c[y>>2]=x;z=c[2076596]|0;A=14113936+(w<<2)|0;c[A>>2]=z;B=c[3541536]|0;C=9669104+(w<<2)|0;c[C>>2]=B;c[1836236]=-1;return 0}j=f;gGC(j|0,9706056,76)|0;x=c[2433530]|0;y=9752472+(w<<2)|0;c[y>>2]=x;z=c[2076596]|0;A=14113936+(w<<2)|0;c[A>>2]=z;B=c[3541536]|0;C=9669104+(w<<2)|0;c[C>>2]=B;c[1836236]=-1;return 0}function fo2(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[3531916]|0;d=c[b>>2]|0;do{if((d|0)==0){e=c[2113308]|0;gGz(c[2112968]|0,0,e*76800|0|0);f=e}else{e=c[2113308]|0;if((e|0)==2){g=d<<16|d;h=c[2112968]|0;i=0;while(1){c[h>>2]=g;c[h+4>>2]=g;c[h+8>>2]=g;c[h+12>>2]=g;c[h+16>>2]=g;c[h+20>>2]=g;c[h+24>>2]=g;c[h+28>>2]=g;j=i+1|0;if((j|0)<4800){h=h+32|0;i=j}else{f=2;break}}}else if((e|0)==4){i=0;h=c[2112968]|0;while(1){c[h>>2]=d;c[h+4>>2]=d;c[h+8>>2]=d;c[h+12>>2]=d;c[h+16>>2]=d;c[h+20>>2]=d;c[h+24>>2]=d;c[h+28>>2]=d;g=i+1|0;if((g|0)<9600){i=g;h=h+32|0}else{f=4;break}}}else if((e|0)==3){h=d>>>8&255;i=d>>>16&255;g=d&255;j=c[2112968]|0;k=0;while(1){a[j]=g;a[j+1|0]=h;a[j+2|0]=i;l=k+1|0;if((l|0)<76800){j=j+3|0;k=l}else{f=3;break}}}else{f=e;break}}}while(0);if(a[7072624]|0){c[2112970]=c[2112968];c[2113306]=f;c[2113298]=c[2113300];fl3();fnZ();m=c[3531916]|0}else{m=b}c[2112966]=m;b=c[2113016]|0;if((b|0)>0){n=0}else{return 0}do{c[m+(n<<2)>>2]=65535;n=n+1|0;}while((n|0)<(b|0));return 0}function fo3(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;f=i;i=i+224|0;g=f|0;h=f+16|0;j=f+32|0;k=f+48|0;l=f+64|0;m=f+80|0;n=f+96|0;o=f+112|0;p=f+128|0;q=f+144|0;r=f+160|0;s=f+176|0;t=f+192|0;u=f+208|0;v=(e|0)==0;if(!v){c[e>>2]=169111}if((b&96|0)==0){i=f;return 0}gGz(u|0,0,12);w=c[2405588]|0;c[u>>2]=w;c[u+4>>2]=(c[2411496]|0)-w;c[u+12>>2]=162152;gj[c[2076592]&4095](u)|0;u=p|0;w=(b&64|0)==0;do{if(!w){gGz(o|0,0,16);c[2394]=-1;if((c[2392]|0)<0){break}x=p+9|0;y=n;z=n|0;A=n+4|0;B=n+12|0;C=o|0;D=o+4|0;E=o+12|0;F=0;do{gGC(u|0,614896,11)|0;a[x]=F+48&255;G=8452256+(F<<2)|0;gGz(y|0,0,12);c[z>>2]=G;c[A>>2]=4;c[B>>2]=164976;gj[c[2076592]&4095](n)|0;if((c[G>>2]|0)!=0){c[C>>2]=c[14130368+(F<<2)>>2];c[D>>2]=c[8452184+(F<<2)>>2];c[E>>2]=u;G=c[2076592]|0;gj[G&4095](o)|0}F=F+1|0;}while((F|0)<=(c[2392]|0))}}while(0);fw$(b);gGz(t|0,0,12);c[t>>2]=9762272;c[t+4>>2]=4;c[t+12>>2]=69312;gj[c[2076592]&4095](t)|0;Ut(0);do{if(!w){gGz(m|0,0,12);c[m>>2]=8453216;c[m+4>>2]=4;c[m+12>>2]=107480;t=c[2076592]|0;gj[t&4095](m)|0;gGz(l|0,0,12);c[l>>2]=14168504;c[l+4>>2]=256;c[l+12>>2]=476464;t=c[2076592]|0;gj[t&4095](l)|0;if((b&2|0)==0){break}else{H=0}do{mv(0,H,d[14168504+H|0]|0);H=H+1|0;}while((H|0)<256)}}while(0);if(!v){c[e>>2]=169110}gGz(k|0,0,12);c[k>>2]=9756784;c[k+4>>2]=4;c[k+12>>2]=175504;gj[c[2076592]&4095](k)|0;gGz(j|0,0,12);c[j>>2]=14166032;c[j+4>>2]=8;c[j+12>>2]=504552;gj[c[2076592]&4095](j)|0;gGz(h|0,0,12);c[h>>2]=14165992;c[h+4>>2]=8;c[h+12>>2]=388736;gj[c[2076592]&4095](h)|0;gGz(g|0,0,12);c[g>>2]=14165960;c[g+4>>2]=32;c[g+12>>2]=302352;gj[c[2076592]&4095](g)|0;gGz(s|0,0,12);c[s>>2]=9625464;c[s+4>>2]=6;c[s+12>>2]=215728;gj[c[2076592]&4095](s)|0;gGz(r|0,0,12);c[r>>2]=9756792;c[r+4>>2]=4;c[r+12>>2]=114080;gj[c[2076592]&4095](r)|0;gGz(q|0,0,12);c[q>>2]=9775616;c[q+4>>2]=1;c[q+12>>2]=68056;gj[c[2076592]&4095](q)|0;if((b&2|0)==0){i=f;return 0}b=c[2440568]|0;c[2440568]=-1;q=b&7;b=c[3532626]|0;r=c[9757320+(c[1836236]<<2)>>2]|0;s=(q<<14)-32768|0;g=128;h=128;while(1){c[r+76+(h<<2)>>2]=b+(s+(h<<8));j=g+1&65535;if((j&65535)>191){I=128;J=128;break}else{g=j;h=j&65535}}while(1){h=b+(s+(J<<8))|0;c[r+76+(J+512<<2)>>2]=h;c[r+76+(J+768<<2)>>2]=h;h=I+1&65535;if((h&65535)>191){break}else{I=h;J=h&65535}}c[2440568]=q;i=f;return 0}function fo4(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3098460+(b*112|0)>>2];c[a+104>>2]=c[3098464+(b*112|0)>>2];c[a+108>>2]=c[3098468+(b*112|0)>>2];d=0;return d|0}function fo5(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=3098360+(b*112|0);e=0;return e|0}function fo6(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=81){if((a|0)==0){d=0;return d|0}e=a;f=3097376+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}f=b-82|0;if(f>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;a=699360+(f*12|0)|0;c[b>>2]=c[a>>2];c[b+4>>2]=c[a+4>>2];c[b+8>>2]=c[a+8>>2];d=0;return d|0}function fo7(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3093444+(b*112|0)>>2];c[a+104>>2]=c[3093448+(b*112|0)>>2];c[a+108>>2]=c[3093452+(b*112|0)>>2];d=0;return d|0}function fo8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=3093344+(b*112|0);e=0;return e|0}function fo9(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3094452+(b*112|0)>>2];c[a+104>>2]=c[3094456+(b*112|0)>>2];c[a+108>>2]=c[3094460+(b*112|0)>>2];d=0;return d|0}function fpa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=3094352+(b*112|0);e=0;return e|0}function fpb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=81){if((a|0)==0){d=0;return d|0}e=a;f=3097376+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}f=b-82|0;if(f>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;a=699136+(f*12|0)|0;c[b>>2]=c[a>>2];c[b+4>>2]=c[a+4>>2];c[b+8>>2]=c[a+8>>2];d=0;return d|0}function fpc(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3095460+(b*112|0)>>2];c[a+104>>2]=c[3095464+(b*112|0)>>2];c[a+108>>2]=c[3095468+(b*112|0)>>2];d=0;return d|0}function fpd(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=3095360+(b*112|0);e=0;return e|0}function fpe(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3092436+(b*112|0)>>2];c[a+104>>2]=c[3092440+(b*112|0)>>2];c[a+108>>2]=c[3092444+(b*112|0)>>2];d=0;return d|0}function fpf(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=3092336+(b*112|0);e=0;return e|0}function fpg(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=81){if((a|0)==0){d=0;return d|0}e=a;f=3097376+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}f=b-82|0;if(f>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;a=699024+(f*12|0)|0;c[b>>2]=c[a>>2];c[b+4>>2]=c[a+4>>2];c[b+8>>2]=c[a+8>>2];d=0;return d|0}function fph(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1170156+(b*112|0)>>2];c[a+104>>2]=c[1170160+(b*112|0)>>2];c[a+108>>2]=c[1170164+(b*112|0)>>2];d=0;return d|0}function fpi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=1170056+(b*112|0);e=0;return e|0}function fpj(){a[8306376]=1;return fo$()|0}function fpk(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;i=i+112|0;e=d|0;f=b>>1;b=e+100|0;if((f|0)<=0){g=0;i=d;return g|0}h=a+1|0;j=0;while(1){if((R6(h,j,2)|0)!=0){g=1;k=64115;break}c[b>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,j)|0;l=j+1|0;if((l|0)<(f|0)){h=h+(c[b>>2]<<1)|0;j=l}else{m=a;n=0;break}}if((k|0)==64115){i=d;return g|0}while(1){a=f+n|0;if((R6(m,a,2)|0)!=0){g=1;k=64114;break}c[b>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,a)|0;a=n+1|0;if((a|0)<(f|0)){m=m+(c[b>>2]<<1)|0;n=a}else{g=0;k=64117;break}}if((k|0)==64117){i=d;return g|0}else if((k|0)==64114){i=d;return g|0}return 0}function fpl(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;j=i;i=i+8|0;k=j|0;l=k;m=f>>1;if((m|0)>0){n=g<<1;o=m+e|0;p=0;do{q=(ag(n,p)|0)/(f|0)|0;R6(b+q|0,p+e|0,2)|0;R6(b+(q+1)|0,o+p|0,2)|0;p=p+1|0;}while((p|0)<(m|0))}m=h?2:0;h=b+g|0;if((g|0)<=0){i=j;return}g=m^2;p=m|1;o=m^3;e=b;f=0;while(1){n=f<<2;q=e+m|0;r=e+g|0;s=e+p|0;t=e+o|0;u=0;do{v=7-(u<<1)|0;w=d[q]|0;x=d[r]|0;y=d[s]|0;z=d[t]|0;A=v-1|0;a[l+u|0]=(w>>>(A>>>0)<<4&16|w>>>(v>>>0)&1|x>>>(v>>>0)<<1&2|x>>>(A>>>0)<<5&32|y>>>(v>>>0)<<2&4|y>>>(A>>>0)<<6&64|z>>>(A>>>0)<<7|z>>>(v>>>0)<<3&8)&255;u=u+1|0;}while((u|0)<4);u=b+n|0;C=c[k>>2]|0;a[u]=C&255;C=C>>8;a[u+1|0]=C&255;C=C>>8;a[u+2|0]=C&255;C=C>>8;a[u+3|0]=C&255;u=e+4|0;if(u>>>0<h>>>0){e=u;f=f+1|0}else{break}}i=j;return}function fpm(b){b=b|0;var d=0,e=0;do{if((b|0)==2097177){d=a[9625458]|0}else if((b|0)==3145741){e=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;if((e|0)>=(c[2113018]|0)){d=1;break}d=e>>>31&255}else if((b|0)==2097157){d=a[9625459]|0}else if((b|0)==2097161){d=a[9625460]|0}else if((b|0)==2097169){d=a[9625456]|0}else if((b|0)==2097197){e=((c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0)/(c[2113058]|0)|0;if((e|0)!=(c[2384346]|0)){c[2384346]=e}d=e&255}else if((b|0)==2097185){d=c[2113157]&255}else if((b|0)==2097189){d=c[2113156]&255}else if((b|0)==2097165){d=a[9625461]|0}else if((b|0)==2097173){d=a[9625457]|0}else{d=0}}while(0);return d|0}function fpn(a){a=a|0;var e=0,f=0,g=0;do{if((a|0)==3145734){e=b[(c[3541508]|0)+2>>1]|0}else if((a|0)==2097176){e=d[9625458]|0}else if((a|0)==2097168){e=d[9625456]|0}else if((a|0)==3145732){e=b[c[3541508]>>1]|0}else if((a|0)==2097184){e=c[2113157]&65535}else if((a|0)==2097188){e=c[2113156]&65535}else if((a|0)==2097164){e=d[9625461]|0}else if((a|0)==2097160){e=d[9625460]|0}else if((a|0)==3145740){f=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;if((f|0)>=(c[2113018]|0)){e=1;break}e=f>>>31&65535}else if((a|0)==2097172){e=d[9625457]|0}else if((a|0)==2097196){f=((c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0)/(c[2113058]|0)|0;if((f|0)==(c[2384346]|0)){g=65024}else{c[2384346]=f;g=32256}e=(g|f)&65535}else if((a|0)==2097156){e=d[9625459]|0}else{e=0}}while(0);return e|0}function fpo(a,b){a=a|0;b=b|0;var d=0;if((a|0)==2097189){Uv(0,b);return}else if((a|0)==2097185){Uv(1,b);return}else if((a|0)==2097193){a=b&1;if((c[2432838]|0)==(a|0)){return}c[2432838]=a;b=c[2411318]|0;d=b+((a<<18)+262144)|0;gGC(b|0,d|0,262144)|0;return}else{return}}function fpp(a,d){a=a|0;d=d|0;switch(a|0){case 3145736:{c[3541498]=d&255;return};case 3145740:{b[(c[3541500]|0)+(c[3541498]<<1)>>1]=d;return};case 3145734:{b[c[3541508]>>1]=d;c[3541508]=(c[3541508]|0)+2;return};case 3145732:{b[c[3541508]>>1]=d;c[3541508]=(c[3541508]|0)+2;return};case 3145728:{c[3541508]=(c[3541506]|0)+((d&65535)<<1&16382);return};default:{return}}}function fpq(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>5){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5833580+(b*112|0)>>2];c[a+104>>2]=c[5833584+(b*112|0)>>2];c[a+108>>2]=c[5833588+(b*112|0)>>2];d=0;return d|0}function fpr(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<6&(d|0)==0)){e=1;return e|0}c[a>>2]=5833480+(b*112|0);e=0;return e|0}function fps(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>23){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3836512+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function fpt(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>60){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6268936+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fpu(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=i;i=i+360|0;d=b|0;e=b+112|0;f=b+120|0;g=b+232|0;h=b+240|0;j=b+352|0;c[2113208]=8388608;c[2426648]=0;c[2418116]=0;c[3541206]=524288;c[2411318]=524288;c[3541502]=1835008;c[2405586]=10223616;c[2418230]=10223616;c[2411398]=1024e4;c[3541506]=10244096;c[3541500]=10260480;c[2411494]=10260992;c[3531916]=10260992;k=0;while(1){if((k|0)>=1024){break}l=9638528+(k<<2)|0;if((c[l>>2]|0)==0){m=64214;break}else{k=k+1|0}}do{if((m|0)==64214){k=gGq(10269184)|0;c[l>>2]=k;if((k|0)==0){break}c[2426648]=k;gGz(k|0,0,10269184);c[2418116]=k;n=k+524288|0;c[3541206]=n;c[2411318]=n;c[3541502]=k+1835008;n=c[2113208]|0;o=k+(n+1835008)|0;c[2405586]=o;c[2418230]=o;c[2411398]=k+(n+1851392);c[3541506]=k+(n+1855488);c[3541500]=k+(n+1871872);o=k+(n+1872384)|0;c[2411494]=o;c[3531916]=o;c[2414034]=k+(n+1880576);do{if((c[3542200]|0)!=0){n=h+108|0;c[n>>2]=0;o=h+100|0;c[o>>2]=0;p=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[p&16383](h,0)|0;if((c[n>>2]|0)==0){break}n=c[o>>2]|0;c[j>>2]=9534384;o=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[o&16383](j,0,0)|0;if((n|0)<1){break}gzL(k,0,0)|0}}while(0);fpl(c[3541502]|0,1,2,c[2113208]|0,0);k=(c[2411318]|0)+262144|0;if((c[3542200]|0)==0){q=1;i=b;return q|0}n=f+108|0;c[n>>2]=0;o=f+100|0;c[o>>2]=0;p=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[p&16383](f,3)|0;do{if((c[n>>2]|0)!=0){p=c[o>>2]|0;c[g>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](g,3,0)|0;if((p|0)<1){q=1;i=b;return q|0}if((gzL(k,0,3)|0)==0){break}else{q=1}i=b;return q|0}}while(0);k=(c[2411318]|0)+1048576|0;if((c[3542200]|0)==0){q=1;i=b;return q|0}o=d+108|0;c[o>>2]=0;n=d+100|0;c[n>>2]=0;p=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[p&16383](d,4)|0;do{if((c[o>>2]|0)!=0){p=c[n>>2]|0;c[e>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](e,4,0)|0;if((p|0)<1){q=1;i=b;return q|0}if((gzL(k,0,4)|0)==0){break}else{q=1}i=b;return q|0}}while(0);fxU(0,425984);if((c[2394]|0)==0){s=c[2112932]|0}else{c[2394]=0;k=c[3532596]|0;c[2112932]=k;n=c[3532592]|0;if((n|0)!=0){gGC(9104152,n|0,280)|0}c[2113054]=c[2113060];s=k}k=c[2418116]|0;n=s|0;o=0;while(1){p=k+o|0;c[n>>2]=p;c[n+131072>>2]=p;p=o+1024|0;if(p>>>0>524287){break}else{n=n+4|0;o=p}}o=c[2418230]|0;c[s+4096>>2]=o;c[s+69632>>2]=o;c[s+135168>>2]=o;n=o+1024|0;c[s+4100>>2]=n;c[s+69636>>2]=n;c[s+135172>>2]=n;n=o+2048|0;c[s+4104>>2]=n;c[s+69640>>2]=n;c[s+135176>>2]=n;n=o+3072|0;c[s+4108>>2]=n;c[s+69644>>2]=n;c[s+135180>>2]=n;n=o+4096|0;c[s+4112>>2]=n;c[s+69648>>2]=n;c[s+135184>>2]=n;n=o+5120|0;c[s+4116>>2]=n;c[s+69652>>2]=n;c[s+135188>>2]=n;n=o+6144|0;c[s+4120>>2]=n;c[s+69656>>2]=n;c[s+135192>>2]=n;n=o+7168|0;c[s+4124>>2]=n;c[s+69660>>2]=n;c[s+135196>>2]=n;n=o+8192|0;c[s+4128>>2]=n;c[s+69664>>2]=n;c[s+135200>>2]=n;n=o+9216|0;c[s+4132>>2]=n;c[s+69668>>2]=n;c[s+135204>>2]=n;n=o+10240|0;c[s+4136>>2]=n;c[s+69672>>2]=n;c[s+135208>>2]=n;n=o+11264|0;c[s+4140>>2]=n;c[s+69676>>2]=n;c[s+135212>>2]=n;n=o+12288|0;c[s+4144>>2]=n;c[s+69680>>2]=n;c[s+135216>>2]=n;n=o+13312|0;c[s+4148>>2]=n;c[s+69684>>2]=n;c[s+135220>>2]=n;n=o+14336|0;c[s+4152>>2]=n;c[s+69688>>2]=n;c[s+135224>>2]=n;n=o+15360|0;c[s+4156>>2]=n;c[s+69692>>2]=n;c[s+135228>>2]=n;n=c[2411398]|0;c[s+16384>>2]=n;c[s+81920>>2]=n;c[s+147456>>2]=n;o=n+1024|0;c[s+16388>>2]=o;c[s+81924>>2]=o;c[s+147460>>2]=o;o=n+2048|0;c[s+16392>>2]=o;c[s+81928>>2]=o;c[s+147464>>2]=o;o=n+3072|0;c[s+16396>>2]=o;c[s+81932>>2]=o;c[s+147468>>2]=o;c[s+196688>>2]=1024;c[s+196608>>2]=660;c[s+196728>>2]=814;c[s+196648>>2]=3076;o=c[3532592]|0;if((o|0)!=0){gGC(o|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;Ux(0,7575,1);Ux(1,7575,1);c[2407030]=256;c[2407068]=3;c[2407069]=256;c[2407107]=3;c[2113040]=17;c[2113182]=-470;c[2113178]=-472;c[2113174]=-474;fl6(1);c[2113016]=2048;c[3531920]=c[2411398];a[7072616]=1;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];o=c[3532592]|0;if((o|0)!=0){gGC(9104152,o|0,280)|0}c[2113054]=c[2113060]}RI();o=c[2394]|0;n=c[14130368+(o<<2)>>2]|0;if((n|0)!=0){gGC(n|0,9104152,280)|0}c[8452240+(o<<2)>>2]=c[2113054];c[2394]=-1;c[2113156]=0;a[9628264]=0;c[2407033]=0;o=c[3541206]|0;c[3541190]=o;c[3541198]=o;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=o+256;c[3541199]=o+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=o+512;c[3541200]=o+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=o+768;c[3541201]=o+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2113157]=0;a[9628420]=0;c[2407072]=0;n=o+1048576|0;c[3541194]=n;c[3541202]=n;gGz(c[2430122]|0,0,16384);c[2407080]=4;c[3541195]=o+1048832;c[3541203]=o+1114112;gGz(c[2430123]|0,0,16384);c[2407088]=4;c[3541196]=o+1049088;c[3541204]=o+1179648;gGz(c[2430124]|0,0,16384);c[2407096]=4;c[3541197]=o+1049344;c[3541205]=o+1245184;gGz(c[2430125]|0,0,16384);c[2407104]=4;c[2432838]=0;o=c[2411318]|0;n=o+262144|0;gGC(o|0,n|0,262144)|0;q=0;i=b;return q|0}}while(0);c[2426648]=0;q=1;i=b;return q|0}function fpv(){var a=0,b=0,d=0,e=0,f=0;fl7();if((c[2392]|0)>=0){a=0;do{b=14130368+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}b=14130384+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}a=a+1|0;}while((a|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;Uw(0);Uw(1);a=c[2426648]|0;b=0;while(1){if((b|0)>=1024){e=64264;break}f=9638528+(b<<2)|0;if((c[f>>2]|0)==(a|0)){break}else{b=b+1|0}}if((e|0)==64264){c[2426648]=0;return 0}gGr(a);c[f>>2]=0;c[2426648]=0;return 0}function fpw(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if((a[9623536]|0)!=0){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];b=c[3532592]|0;if((b|0)!=0){gGC(9104152,b|0,280)|0}c[2113054]=c[2113060]}RI();b=c[2394]|0;d=c[14130368+(b<<2)>>2]|0;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[8452240+(b<<2)>>2]=c[2113054];c[2394]=-1;c[2113156]=0;a[9628264]=0;c[2407033]=0;b=c[3541206]|0;c[3541190]=b;c[3541198]=b;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=b+256;c[3541199]=b+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=b+512;c[3541200]=b+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=b+768;c[3541201]=b+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2113157]=0;a[9628420]=0;c[2407072]=0;d=b+1048576|0;c[3541194]=d;c[3541202]=d;gGz(c[2430122]|0,0,16384);c[2407080]=4;c[3541195]=b+1048832;c[3541203]=b+1114112;gGz(c[2430123]|0,0,16384);c[2407088]=4;c[3541196]=b+1049088;c[3541204]=b+1179648;gGz(c[2430124]|0,0,16384);c[2407096]=4;c[3541197]=b+1049344;c[3541205]=b+1245184;gGz(c[2430125]|0,0,16384);c[2407104]=4;c[2432838]=0;b=c[2411318]|0;d=b+262144|0;gGC(b|0,d|0,262144)|0}a[9625456]=0;a[9625457]=0;a[9625458]=0;d=0;b=0;e=0;f=0;do{b=((a[9632576+d|0]&1)<<d|b&255)&255;e=((a[9630480+d|0]&1)<<d|e&255)&255;f=((a[9551680+d|0]&1)<<d|f&255)&255;d=d+1|0;}while((d|0)<8);a[9625456]=b;a[9625457]=e;a[9625458]=f;if((b&3)==3){f=b&-4;a[9625456]=f;g=f}else{g=b}if((g&12)==12){a[9625456]=g&-13}if((e&3)==3){g=e&-4;a[9625457]=g;h=g}else{h=e}if((h&12)==12){a[9625457]=h&-13}h=c[2392]|0;if((h|0)>=0){gGz(8452240,0,((h|0)>0?(h<<2)+4|0:4)|0)}c[2113054]=0;h=c[2438]|0;e=gGU(h,(h|0)<0|0?-1:0,16e6,0)|0;h=gGS(e,K,15360,0)|0;e=h;c[2113218]=e;c[2113220]=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];h=c[3532592]|0;if((h|0)!=0){gGC(9104152,h|0,280)|0}c[2113054]=c[2113060]}c[2113058]=(e|0)/262|0;h=e-((e*22|0|0)/262|0)|0;c[2113018]=h;a[670616]=0;g=(e|0)/4|0;do{if((g|0)>(h|0)){if((h|0)>0){c[2113056]=h;e=RG(h)|0;c[2113054]=(c[2113054]|0)+e;c[2276108]=-1;c[2113056]=-1;b=(c[2113220]|0)+e|0;c[2113220]=b;i=b}else{i=0}a[670616]=1;b=c[2430398]|0;e=c[2439196]|0;f=e<<11;c[2438976]=b+f;d=(c[2440572]|0)>1;if(d){c[2438977]=(c[2430399]|0)+f}f=e^1;c[2439196]=f;e=f<<11;f=b+e|0;b=(c[3541506]|0)+12288|0;gGC(f|0,b|0,2048)|0;if(d){d=(c[2430399]|0)+e|0;e=(c[3541504]|0)+12288|0;gGC(d|0,e|0,2048)|0}c[8452200+(c[2394]<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0>=1024){j=i;break}RH(4);j=c[2113220]|0}else{j=0}}while(0);i=g-j|0;c[2113056]=i;j=RG(i)|0;c[2113054]=(c[2113054]|0)+j;c[2276108]=-1;c[2113056]=-1;i=(c[2113220]|0)+j|0;c[2113220]=i;j=(c[2113218]<<1|0)/4|0;do{if(a[670616]|0){k=i}else{g=c[2113018]|0;if((j|0)<=(g|0)){k=i;break}if((i|0)<(g|0)){h=g-i|0;c[2113056]=h;g=RG(h)|0;c[2113054]=(c[2113054]|0)+g;c[2276108]=-1;c[2113056]=-1;h=(c[2113220]|0)+g|0;c[2113220]=h;l=h}else{l=i}a[670616]=1;h=c[2430398]|0;g=c[2439196]|0;e=g<<11;c[2438976]=h+e;d=(c[2440572]|0)>1;if(d){c[2438977]=(c[2430399]|0)+e}e=g^1;c[2439196]=e;g=e<<11;e=h+g|0;h=(c[3541506]|0)+12288|0;gGC(e|0,h|0,2048)|0;if(d){d=(c[2430399]|0)+g|0;g=(c[3541504]|0)+12288|0;gGC(d|0,g|0,2048)|0}c[8452200+(c[2394]<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0>=1024){k=l;break}RH(4);k=c[2113220]|0}}while(0);l=j-k|0;c[2113056]=l;k=RG(l)|0;c[2113054]=(c[2113054]|0)+k;c[2276108]=-1;c[2113056]=-1;l=(c[2113220]|0)+k|0;c[2113220]=l;k=((c[2113218]|0)*3|0|0)/4|0;do{if(a[670616]|0){m=l}else{j=c[2113018]|0;if((k|0)<=(j|0)){m=l;break}if((l|0)<(j|0)){i=j-l|0;c[2113056]=i;j=RG(i)|0;c[2113054]=(c[2113054]|0)+j;c[2276108]=-1;c[2113056]=-1;i=(c[2113220]|0)+j|0;c[2113220]=i;n=i}else{n=l}a[670616]=1;i=c[2430398]|0;j=c[2439196]|0;g=j<<11;c[2438976]=i+g;d=(c[2440572]|0)>1;if(d){c[2438977]=(c[2430399]|0)+g}g=j^1;c[2439196]=g;j=g<<11;g=i+j|0;i=(c[3541506]|0)+12288|0;gGC(g|0,i|0,2048)|0;if(d){d=(c[2430399]|0)+j|0;j=(c[3541504]|0)+12288|0;gGC(d|0,j|0,2048)|0}c[8452200+(c[2394]<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0>=1024){m=n;break}RH(4);m=c[2113220]|0}}while(0);n=k-m|0;c[2113056]=n;m=RG(n)|0;c[2113054]=(c[2113054]|0)+m;c[2276108]=-1;c[2113056]=-1;n=(c[2113220]|0)+m|0;c[2113220]=n;m=c[2113218]|0;do{if(a[670616]|0){o=n}else{k=c[2113018]|0;if((m|0)<=(k|0)){o=n;break}if((n|0)<(k|0)){l=k-n|0;c[2113056]=l;k=RG(l)|0;c[2113054]=(c[2113054]|0)+k;c[2276108]=-1;c[2113056]=-1;l=(c[2113220]|0)+k|0;c[2113220]=l;p=l}else{p=n}a[670616]=1;l=c[2430398]|0;k=c[2439196]|0;j=k<<11;c[2438976]=l+j;d=(c[2440572]|0)>1;if(d){c[2438977]=(c[2430399]|0)+j}j=k^1;c[2439196]=j;k=j<<11;j=l+k|0;l=(c[3541506]|0)+12288|0;gGC(j|0,l|0,2048)|0;if(d){d=(c[2430399]|0)+k|0;k=(c[3541504]|0)+12288|0;gGC(d|0,k|0,2048)|0}c[8452200+(c[2394]<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0>=1024){o=p;break}RH(4);o=c[2113220]|0}}while(0);p=m-o|0;c[2113056]=p;o=RG(p)|0;p=(c[2113054]|0)+o|0;c[2113054]=p;c[2276108]=-1;c[2113056]=-1;c[2113220]=(c[2113220]|0)+o;o=c[2112964]|0;if((o|0)!=0){m=a[9688]|0;gGz(o|0,0,(m?2136:0)|0);n=m?534:0;Uu(0,o,n);Uu(1,o,n)}n=c[2394]|0;o=c[14130368+(n<<2)>>2]|0;if((o|0)!=0){gGC(o|0,9104152,280)|0}c[8452240+(n<<2)>>2]=p;c[2394]=-1;p=c[2112968]|0;if((p|0)==0){return 0}n=c[3531916]|0;o=c[n>>2]|0;m=c[2113308]|0;do{if((o|0)==0){gGz(p|0,0,m*76800|0|0)}else{if((m|0)==3){k=o>>>8&255;d=o>>>16&255;l=o&255;j=p;i=0;while(1){a[j]=l;a[j+1|0]=k;a[j+2|0]=d;g=i+1|0;if((g|0)<76800){j=j+3|0;i=g}else{break}}}else if((m|0)==2){i=o<<16|o;j=p;d=0;while(1){c[j>>2]=i;c[j+4>>2]=i;c[j+8>>2]=i;c[j+12>>2]=i;c[j+16>>2]=i;c[j+20>>2]=i;c[j+24>>2]=i;c[j+28>>2]=i;k=d+1|0;if((k|0)<4800){j=j+32|0;d=k}else{break}}}else if((m|0)==4){d=0;j=p;while(1){c[j>>2]=o;c[j+4>>2]=o;c[j+8>>2]=o;c[j+12>>2]=o;c[j+16>>2]=o;c[j+20>>2]=o;c[j+24>>2]=o;c[j+28>>2]=o;i=d+1|0;if((i|0)<9600){d=i;j=j+32|0}else{break}}}else{break}}}while(0);if(a[7072616]|0){c[2112970]=p;c[2113306]=m;c[2113298]=c[2113300];fl3();q=c[3531916]|0}else{q=n}c[2112966]=q;n=c[2113016]|0;if((n|0)>0){r=0}else{return 0}do{c[q+(r<<2)>>2]=65535;r=r+1|0;}while((r|0)<(n|0));return 0}function fpx(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[3531916]|0;d=c[b>>2]|0;do{if((d|0)==0){e=c[2113308]|0;gGz(c[2112968]|0,0,e*76800|0|0);f=e}else{e=c[2113308]|0;if((e|0)==3){g=d>>>8&255;h=d>>>16&255;i=d&255;j=c[2112968]|0;k=0;while(1){a[j]=i;a[j+1|0]=g;a[j+2|0]=h;l=k+1|0;if((l|0)<76800){j=j+3|0;k=l}else{f=3;break}}}else if((e|0)==2){k=d<<16|d;j=c[2112968]|0;h=0;while(1){c[j>>2]=k;c[j+4>>2]=k;c[j+8>>2]=k;c[j+12>>2]=k;c[j+16>>2]=k;c[j+20>>2]=k;c[j+24>>2]=k;c[j+28>>2]=k;g=h+1|0;if((g|0)<4800){j=j+32|0;h=g}else{f=2;break}}}else if((e|0)==4){h=0;j=c[2112968]|0;while(1){c[j>>2]=d;c[j+4>>2]=d;c[j+8>>2]=d;c[j+12>>2]=d;c[j+16>>2]=d;c[j+20>>2]=d;c[j+24>>2]=d;c[j+28>>2]=d;k=h+1|0;if((k|0)<9600){h=k;j=j+32|0}else{f=4;break}}}else{f=e;break}}}while(0);if(a[7072616]|0){c[2112970]=c[2112968];c[2113306]=f;c[2113298]=c[2113300];fl3();m=c[3531916]|0}else{m=b}c[2112966]=m;b=c[2113016]|0;if((b|0)>0){n=0}else{return 0}do{c[m+(n<<2)>>2]=65535;n=n+1|0;}while((n|0)<(b|0));return 0}function fpy(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;e=i;i=i+144|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;l=e+80|0;m=e+96|0;n=e+112|0;o=e+128|0;p=(d|0)==0;if(!p){c[d>>2]=133527}if((b&96|0)!=0){gGz(o|0,0,12);q=c[2405586]|0;c[o>>2]=q;c[o+4>>2]=(c[2411494]|0)-q;c[o+12>>2]=162152;q=c[2076592]|0;gj[q&4095](o)|0;o=m|0;do{if((b&64|0)!=0){gGz(l|0,0,16);c[2394]=-1;if((c[2392]|0)<0){break}q=m+9|0;r=k;s=k|0;t=k+4|0;u=k+12|0;v=l|0;w=l+4|0;x=l+12|0;y=0;do{gGC(o|0,614896,11)|0;a[q]=y+48&255;z=8452256+(y<<2)|0;gGz(r|0,0,12);c[s>>2]=z;c[t>>2]=4;c[u>>2]=164976;gj[c[2076592]&4095](k)|0;if((c[z>>2]|0)!=0){c[v>>2]=c[14130368+(y<<2)>>2];c[w>>2]=c[8452184+(y<<2)>>2];c[x>>2]=o;z=c[2076592]|0;gj[z&4095](l)|0}y=y+1|0;}while((y|0)<=(c[2392]|0))}}while(0);Ut(0);Ut(1);if(!p){c[d>>2]=169110}gGz(j|0,0,12);c[j>>2]=9756784;c[j+4>>2]=4;c[j+12>>2]=175504;d=c[2076592]|0;gj[d&4095](j)|0;gGz(h|0,0,12);c[h>>2]=14166032;c[h+4>>2]=8;c[h+12>>2]=504552;j=c[2076592]|0;gj[j&4095](h)|0;gGz(g|0,0,12);c[g>>2]=14165992;c[g+4>>2]=8;c[g+12>>2]=388736;h=c[2076592]|0;gj[h&4095](g)|0;gGz(f|0,0,12);c[f>>2]=14165960;c[f+4>>2]=32;c[f+12>>2]=302352;g=c[2076592]|0;gj[g&4095](f)|0;gGz(n|0,0,12);c[n>>2]=9731352;c[n+4>>2]=4;c[n+12>>2]=144568;f=c[2076592]|0;gj[f&4095](n)|0}if((b&2|0)==0){i=e;return 0}b=c[2411318]|0;n=b+((c[2432838]<<18)+262144)|0;gGC(b|0,n|0,262144)|0;i=e;return 0}function fpz(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;d=c[2113308]|0;if((c[2394746]|0)!=(d|0)){c[2394746]=d;c[3528968]=c[3564256+(d-2<<2)>>2]}f=c[2429848]|0;c[2438098]=f;c[2438099]=f+40960;c[2438100]=f+81920;c[2438101]=f+122880;c[2438102]=f+163840;c[2438103]=f+204800;c[2438104]=f+245760;c[2438105]=f+286720;c[2438106]=f+327680;c[2438107]=f+368640;c[2438108]=f+409600;c[2438109]=f+450560;c[2438110]=f+491520;c[2438111]=f+532480;c[2438112]=f+573440;c[2438113]=f+614400;f=c[3542214]|0;g=f+49152|0;h=c[2113314]|0;i=((e[7084422]|0)>>>7)-h+(c[2113170]|0)|0;j=c[2113312]|0;k=((e[7084423]|0)>>>7)-j+(c[2113168]|0)|0;l=a[7461832]|0;m=l?k+16|0:k;k=m>>>3;n=i>>>3;o=i&7;i=m&7;m=0;do{p=m+k<<7&8064;q=(m<<3)-i&65535;r=0;do{s=r+n<<1&126|p;t=e[g+((s|1)<<1)>>1]|0;u=e[g+(s<<1)>>1]|0;do{if((t&32768|0)==0){if((u&61440|0)==0){break}s=9752392+(u>>>12<<2)|0;v=c[s>>2]|0;c[v>>2]=u<<16|t;b[v+4>>1]=(r<<3)-o&65535;b[v+6>>1]=q;c[s>>2]=v+8}}while(0);r=r+1|0;}while((r|0)<41);m=m+1|0;}while((m|0)<31);m=f+32768|0;o=((e[7084420]|0)>>>7)-h+(c[2113174]|0)|0;g=((e[7084421]|0)>>>7)-j+(c[2113172]|0)|0;n=l?g+16|0:g;g=n>>>3;i=o>>>3;k=o&7;o=n&7;n=0;do{r=n+g<<7&8064;q=(n<<3)-o&65535;p=0;do{t=p+i<<1&126|r;u=e[m+((t|1)<<1)>>1]|0;v=e[m+(t<<1)>>1]|0;do{if((u&32768|0)==0){if((v&61440|0)==0){break}t=9752392+(v>>>12<<2)|0;s=c[t>>2]|0;c[s>>2]=v<<16|u;b[s+4>>1]=(p<<3)-k&65535;b[s+6>>1]=q;c[t>>2]=s+8}}while(0);p=p+1|0;}while((p|0)<41);n=n+1|0;}while((n|0)<31);n=f+16384|0;k=((e[7084418]|0)>>>7)-h+(c[2113178]|0)|0;m=((e[7084419]|0)>>>7)-j+(c[2113176]|0)|0;i=l?m+16|0:m;m=i>>>3;o=k>>>3;g=k&7;k=i&7;i=0;do{p=i+m<<7&8064;q=(i<<3)-k&65535;r=0;do{u=r+o<<1&126|p;v=e[n+((u|1)<<1)>>1]|0;s=e[n+(u<<1)>>1]|0;do{if((v&32768|0)==0){if((s&61440|0)==0){break}u=9752392+(s>>>12<<2)|0;t=c[u>>2]|0;c[t>>2]=s<<16|v;b[t+4>>1]=(r<<3)-g&65535;b[t+6>>1]=q;c[u>>2]=t+8}}while(0);r=r+1|0;}while((r|0)<41);i=i+1|0;}while((i|0)<31);i=f;f=((e[7084416]|0)>>>7)-h+(c[2113182]|0)|0;h=((e[7084417]|0)>>>7)-j+(c[2113180]|0)|0;j=l?h+16|0:h;h=j>>>3;l=f>>>3;g=f&7;f=j&7;j=0;do{n=j+h<<7&8064;o=(j<<3)-f&65535;k=0;do{m=k+l<<1&126|n;r=e[i+((m|1)<<1)>>1]|0;q=e[i+(m<<1)>>1]|0;do{if((r&32768|0)==0){if((q&61440|0)==0){break}m=9752392+(q>>>12<<2)|0;p=c[m>>2]|0;c[p>>2]=q<<16|r;b[p+4>>1]=(k<<3)-g&65535;b[p+6>>1]=o;c[m>>2]=p+8}}while(0);k=k+1|0;}while((k|0)<41);j=j+1|0;}while((j|0)<31);if(a[7461696]|0){w=0;x=d;y=64421}else{d=c[2429356]|0;c[2432808]=d;c[2432809]=d+1028;c[2432810]=d+2056;c[2432811]=d+3084;c[2432812]=d+4112;c[2432813]=d+5140;c[2432814]=d+6168;c[2432815]=d+7196;c[2432816]=d+8224;c[2432817]=d+9252;c[2432818]=d+10280;c[2432819]=d+11308;c[2432820]=d+12336;c[2432821]=d+13364;c[2432822]=d+14392;c[2432823]=d+15420;d=c[2430400]|0;j=0;while(1){if((b[d>>1]|0)>=0){g=9731232+((e[d+2>>1]|0)>>>12<<2)|0;i=c[g>>2]|0;c[g>>2]=i+4;c[i>>2]=d}i=j+1|0;if((i|0)<256){d=d+8|0;j=i}else{z=0;y=64438;break}}}while(1){do{if((y|0)==64421){y=0;j=w<<8;d=c[3541524]|0;i=c[3541520]|0;g=c[3531914]|0;l=c[2112968]|0;f=(x|0)>3;h=(x|0)==2;k=0;while(1){o=e[d+((k|1)<<1)>>1]|0;do{if((o&3072|0)==(j|0)){n=(e[d+((k|3)<<1)>>1]|0)>>>7;if((n|0)==256){break}r=(e[d+((k|2)<<1)>>1]|0)>>>7;q=(o&256|0)!=0;p=(q?r-15|0:r)-31|0;r=n-16|0;if((r|0)<-15|(p|0)<-15|(r|0)>239|(p|0)>319){break}n=q?15:0;q=(o&512|0)==0?n:n|240;n=e[d+(k<<1)>>1]<<8&524032;m=o<<4&1008;c[2440380]=g+(m<<2);v=r;r=0;while(1){if(v>>>0<=239){s=r<<4;t=v*320|0;u=p;A=0;while(1){do{if(u>>>0<=319){B=a[i+((A+s^q)+n)|0]|0;if(B<<24>>24==0){break}C=ag(x,u+t|0)|0;D=l+C|0;E=c[g+(m+(B&255)<<2)>>2]|0;if(f){c[D>>2]=E;break}if(h){b[D>>1]=E&65535;break}else{a[D]=E&255;a[l+(C+1)|0]=E>>>8&255;a[l+(C+2)|0]=E>>>16&255;break}}}while(0);E=A+1|0;if((E|0)<16){u=u+1|0;A=E}else{break}}}A=r+1|0;if((A|0)<16){v=v+1|0;r=A}else{break}}}}while(0);o=k+4|0;if((o|0)<2048){k=o}else{F=w;break}}}else if((y|0)==64438){y=0;k=9731232+(z<<2)|0;c[c[k>>2]>>2]=0;l=z*257|0;h=c[2429356]|0;f=h+(l+1<<2)|0;c[k>>2]=f;g=c[h+(l<<2)>>2]|0;if((g|0)==0){F=z;break}l=g;g=c[2438160]|0;h=f;while(1){f=e[l+2>>1]|0;c[2440380]=(c[3531914]|0)+((f<<4&1008)<<2);i=e[l>>1]&g;d=c[3541520]|0;j=e[(c[3541522]|0)+((f>>>6&63)<<1)>>1]|0;f=j&15;o=j>>>4&15;j=b[l+4>>1]|0;r=(j&65535)>>>7;v=(e[l+6>>1]|0)>>>7;m=a[7461832]|0?v-16|0:v;v=(j&65535)>49279?r|-512:r;r=(m|0)>384?m-512|0:m;c[2385452]=r;do{if((o|0)==0){G=g;H=h}else{if((f|0)==0){c[2385464]=v;c[2385452]=r+(o>>>0>1?o<<3:8);G=g;H=h;break}m=i;j=0;n=d+(i<<5)|0;q=g;p=r;while(1){c[2385464]=v;if(m>>>0>q>>>0){I=m;J=n;K=q;L=p}else{A=m;u=1;t=n;s=v;while(1){do{if((a[(c[2438724]|0)+A|0]|0)!=0){E=c[2385452]|0;if((s+7|0)>>>0>326|(E|0)<-7|(E|0)>239){break}c[2385332]=t;C=c[2112970]|0;D=ag(c[2113306]|0,s)|0;c[2415144]=C+((ag(c[2113298]|0,E)|0)+D);D=c[3528968]|0;if(s>>>0>312|(E|0)<0|(E|0)>232){gu[c[D+4>>2]&16383]();break}else{gu[c[D>>2]&16383]();break}}}while(0);D=(c[2385464]|0)+8|0;c[2385464]=D;M=A+1|0;N=t+32|0;O=c[2438160]|0;if((u|0)>=(f|0)|M>>>0>O>>>0){break}A=M;u=u+1|0;t=N;s=D}I=M;J=N;K=O;L=c[2385452]|0}s=j+1|0;t=L+8|0;c[2385452]=t;if((s|0)<(o|0)){m=I;j=s;n=J;q=K;p=t}else{break}}G=K;H=c[k>>2]|0}}while(0);o=H+4|0;c[k>>2]=o;f=c[H>>2]|0;if((f|0)==0){F=z;break}else{l=f;g=G;h=o}}}}while(0);h=9752392+(F<<2)|0;c[c[h>>2]>>2]=0;g=(c[2429848]|0)+((F*5120|0)<<3)|0;c[h>>2]=g;l=c[g>>2]|0;if((l|0)!=0){k=g;g=l;do{l=b[k+4>>1]|0;o=l<<16>>16;c[2385464]=o;f=b[k+6>>1]|0;v=f<<16>>16;c[2385452]=v;c[h>>2]=k+8;r=c[2440578]&g;i=c[3542212]|0;c[2440380]=(c[3531916]|0)+((g>>>12&1008)<<2);d=c[2112970]|0;p=ag(c[2113306]|0,o)|0;c[2415144]=d+((ag(c[2113298]|0,v)|0)+p);p=a[(c[2438868]|0)+r|0]|0;v=((a[7460904]|0?2:0)|0)>(F|0);do{if(p<<24>>24!=0|v){d=v?9:p;c[2385332]=i+(r<<5);if((l&65535)<312&f<<16>>16>-1&f<<16>>16<232){gu[c[(c[3528968]|0)+((d&255)-1<<2)>>2]&16383]();break}if(!((o+7|0)>>>0<327&f<<16>>16>-8&f<<16>>16<240)){break}gu[c[(c[3528968]|0)+((d&255)<<2)>>2]&16383]()}}while(0);k=c[h>>2]|0;g=c[k>>2]|0;}while((g|0)!=0)}g=F+1|0;if((g|0)>=16){break}if(!(a[7461696]|0)){z=g;y=64438;continue}w=g;x=c[2113308]|0;y=64421}return}function fpA(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;c[2394746]=0;c[2440578]=((c[2113316]|0)-1|0)>>>5;b=0;while(1){if((b|0)>=1024){d=0;break}e=9638528+(b<<2)|0;if((c[e>>2]|0)==0){f=64468;break}else{b=b+1|0}}do{if((f|0)==64468){b=gGq(655360)|0;c[e>>2]=b;if((b|0)==0){d=0;break}gGz(b|0,0,655360);d=b}}while(0);c[2429848]=d;gGz(d|0,0,655360);d=0;while(1){if((d|0)>=1024){g=0;break}h=9638528+(d<<2)|0;if((c[h>>2]|0)==0){f=64473;break}else{d=d+1|0}}do{if((f|0)==64473){d=gGq(32768)|0;c[h>>2]=d;if((d|0)==0){g=0;break}gGz(d|0,0,32768);g=d}}while(0);c[2438868]=g;gGz(g|0,0,32768);h=c[2113316]|0;if(h>>>0>31){d=h>>>5;h=c[3542212]|0;e=0;do{b=e<<5;i=b+32|0;do{if((b|0)==-32){j=g+e|0;f=64481}else{k=1;l=1;m=b;do{n=a[h+m|0]|0;o=n&255;k=n<<24>>24==0&k;l=l&((o&15|0)!=0&(o&240|0)!=0);m=m+1|0;}while(m>>>0<i>>>0);m=g+e|0;if(k){j=m;f=64481;break}if(l){a[m]=9;break}else{a[m]=1;break}}}while(0);if((f|0)==64481){f=0;a[j]=0}e=e+1|0;}while(e>>>0<d>>>0)}c[2438160]=((c[2113212]|0)-1|0)>>>5;d=0;while(1){if((d|0)>=1024){p=0;break}q=9638528+(d<<2)|0;if((c[q>>2]|0)==0){f=64489;break}else{d=d+1|0}}do{if((f|0)==64489){d=gGq(16448)|0;c[q>>2]=d;if((d|0)==0){p=0;break}gGz(d|0,0,16448);p=d}}while(0);c[2429356]=p;gGz(p|0,0,16448);p=0;while(1){if((p|0)>=1024){r=0;break}s=9638528+(p<<2)|0;if((c[s>>2]|0)==0){f=64494;break}else{p=p+1|0}}do{if((f|0)==64494){p=gGq(2048)|0;c[s>>2]=p;if((p|0)==0){r=0;break}gGz(p|0,0,2048);r=p}}while(0);c[2430400]=r;r=0;while(1){if((r|0)>=1024){t=0;break}u=9638528+(r<<2)|0;if((c[u>>2]|0)==0){f=64499;break}else{r=r+1|0}}do{if((f|0)==64499){r=gGq(32768)|0;c[u>>2]=r;if((r|0)==0){t=0;break}gGz(r|0,0,32768);t=r}}while(0);c[2438724]=t;gGz(t|0,0,32768);u=c[2113212]|0;if(u>>>0>31){r=u>>>5;u=c[3541520]|0;s=0;do{p=s<<5;q=p+32|0;do{if((p|0)==-32){v=t+s|0;f=64507}else{d=1;e=1;j=p;do{g=a[u+j|0]|0;h=g&255;d=g<<24>>24==0&d;e=e&((h&15|0)!=0&(h&240|0)!=0);j=j+1|0;}while(j>>>0<q>>>0);j=t+s|0;if(d){v=j;f=64507;break}if(e){a[j]=9;break}else{a[j]=1;break}}}while(0);if((f|0)==64507){f=0;a[v]=0}s=s+1|0;}while(s>>>0<r>>>0)}if((c[2113182]|0)==0){c[2113182]=501}if((c[2113178]|0)==0){c[2113178]=499}if((c[2113174]|0)==0){c[2113174]=497}if((c[2113170]|0)==0){c[2113170]=495}if((c[2113180]|0)==0){c[2113180]=257}if((c[2113176]|0)==0){c[2113176]=257}if((c[2113172]|0)==0){c[2113172]=257}if((c[2113168]|0)!=0){a[7460904]=0;return}c[2113168]=257;a[7460904]=0;return}function fpB(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0;c[2113182]=0;c[2113178]=0;c[2113174]=0;c[2113170]=0;c[2113180]=0;c[2113176]=0;c[2113172]=0;c[2113168]=0;a=c[2429848]|0;b=0;while(1){if((b|0)>=1024){break}d=9638528+(b<<2)|0;if((c[d>>2]|0)==(a|0)){e=64534;break}else{b=b+1|0}}if((e|0)==64534){gGr(a);c[d>>2]=0}c[2429848]=0;d=c[2438868]|0;a=0;while(1){if((a|0)>=1024){break}f=9638528+(a<<2)|0;if((c[f>>2]|0)==(d|0)){e=64538;break}else{a=a+1|0}}if((e|0)==64538){gGr(d);c[f>>2]=0}c[2438868]=0;f=c[2429356]|0;d=0;while(1){if((d|0)>=1024){break}g=9638528+(d<<2)|0;if((c[g>>2]|0)==(f|0)){e=64542;break}else{d=d+1|0}}if((e|0)==64542){gGr(f);c[g>>2]=0}c[2429356]=0;g=c[2430400]|0;f=0;while(1){if((f|0)>=1024){break}h=9638528+(f<<2)|0;if((c[h>>2]|0)==(g|0)){e=64546;break}else{f=f+1|0}}if((e|0)==64546){gGr(g);c[h>>2]=0}c[2430400]=0;h=c[2438724]|0;g=0;while(1){if((g|0)>=1024){e=64552;break}i=9638528+(g<<2)|0;if((c[i>>2]|0)==(h|0)){break}else{g=g+1|0}}if((e|0)==64552){c[2438724]=0;return}gGr(h);c[i>>2]=0;c[2438724]=0;return}function fpC(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0;a=c[2440380]|0;d=c[2415144]|0;e=1;f=c[2385332]|0;while(1){g=f+4|0;h=c[f>>2]|0;i=h&15;if((i|0)!=0){b[d>>1]=c[a+(i<<2)>>2]&65535}i=h>>>4&15;if((i|0)!=0){b[d+2>>1]=c[a+(i<<2)>>2]&65535}i=h>>>8&15;if((i|0)!=0){b[d+4>>1]=c[a+(i<<2)>>2]&65535}i=h>>>12&15;if((i|0)!=0){b[d+6>>1]=c[a+(i<<2)>>2]&65535}i=h>>>16&15;if((i|0)!=0){b[d+8>>1]=c[a+(i<<2)>>2]&65535}i=h>>>20&15;if((i|0)!=0){b[d+10>>1]=c[a+(i<<2)>>2]&65535}i=h>>>24&15;if((i|0)!=0){b[d+12>>1]=c[a+(i<<2)>>2]&65535}i=h>>>28;if((i|0)!=0){b[d+14>>1]=c[a+(i<<2)>>2]&65535}if((e|0)>=8){break}d=d+640|0;e=e+1|0;f=g}c[2385332]=g;return}function fpD(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[2385452]|0;d=c[2385464]|0;e=(d|0)>-1;f=(d|0)<320;g=c[2440380]|0;h=c[2415144]|0;i=0;j=c[2385332]|0;while(1){k=j+4|0;do{if((a+i|0)>>>0<=239){l=c[j>>2]|0;m=l&15;if((m|0)!=0&e&f){b[h>>1]=c[g+(m<<2)>>2]&65535}m=l>>>4&15;if((m|0)!=0&(d|0)>-2&(d|0)<319){b[h+2>>1]=c[g+(m<<2)>>2]&65535}m=l>>>8&15;if((m|0)!=0&(d|0)>-3&(d|0)<318){b[h+4>>1]=c[g+(m<<2)>>2]&65535}m=l>>>12&15;if((m|0)!=0&(d|0)>-4&(d|0)<317){b[h+6>>1]=c[g+(m<<2)>>2]&65535}m=l>>>16&15;if((m|0)!=0&(d|0)>-5&(d|0)<316){b[h+8>>1]=c[g+(m<<2)>>2]&65535}m=l>>>20&15;if((m|0)!=0&(d|0)>-6&(d|0)<315){b[h+10>>1]=c[g+(m<<2)>>2]&65535}m=l>>>24&15;if((m|0)!=0&(d|0)>-7&(d|0)<314){b[h+12>>1]=c[g+(m<<2)>>2]&65535}m=l>>>28;if(!((m|0)!=0&(d|0)>-8&(d|0)<313)){break}b[h+14>>1]=c[g+(m<<2)>>2]&65535}}while(0);m=i+1|0;if((m|0)>=8){break}h=h+640|0;i=m;j=k}c[2385332]=k;return}function fpE(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0;a=c[2440380]|0;d=c[2415144]|0;e=1;f=c[2385332]|0;while(1){g=f+4|0;h=c[f>>2]|0;i=h&15;if((i|0)!=0){b[d+14>>1]=c[a+(i<<2)>>2]&65535}i=h>>>4&15;if((i|0)!=0){b[d+12>>1]=c[a+(i<<2)>>2]&65535}i=h>>>8&15;if((i|0)!=0){b[d+10>>1]=c[a+(i<<2)>>2]&65535}i=h>>>12&15;if((i|0)!=0){b[d+8>>1]=c[a+(i<<2)>>2]&65535}i=h>>>16&15;if((i|0)!=0){b[d+6>>1]=c[a+(i<<2)>>2]&65535}i=h>>>20&15;if((i|0)!=0){b[d+4>>1]=c[a+(i<<2)>>2]&65535}i=h>>>24&15;if((i|0)!=0){b[d+2>>1]=c[a+(i<<2)>>2]&65535}i=h>>>28;if((i|0)!=0){b[d>>1]=c[a+(i<<2)>>2]&65535}if((e|0)>=8){break}d=d+640|0;e=e+1|0;f=g}c[2385332]=g;return}function fpF(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[2385452]|0;d=c[2385464]|0;e=(d|0)>-8;f=(d|0)<313;g=c[2440380]|0;h=c[2415144]|0;i=0;j=c[2385332]|0;while(1){k=j+4|0;do{if((a+i|0)>>>0<=239){l=c[j>>2]|0;m=l&15;if((m|0)!=0&e&f){b[h+14>>1]=c[g+(m<<2)>>2]&65535}m=l>>>4&15;if((m|0)!=0&(d|0)>-7&(d|0)<314){b[h+12>>1]=c[g+(m<<2)>>2]&65535}m=l>>>8&15;if((m|0)!=0&(d|0)>-6&(d|0)<315){b[h+10>>1]=c[g+(m<<2)>>2]&65535}m=l>>>12&15;if((m|0)!=0&(d|0)>-5&(d|0)<316){b[h+8>>1]=c[g+(m<<2)>>2]&65535}m=l>>>16&15;if((m|0)!=0&(d|0)>-4&(d|0)<317){b[h+6>>1]=c[g+(m<<2)>>2]&65535}m=l>>>20&15;if((m|0)!=0&(d|0)>-3&(d|0)<318){b[h+4>>1]=c[g+(m<<2)>>2]&65535}m=l>>>24&15;if((m|0)!=0&(d|0)>-2&(d|0)<319){b[h+2>>1]=c[g+(m<<2)>>2]&65535}m=l>>>28;if(!((m|0)!=0&(d|0)>-1&(d|0)<320)){break}b[h>>1]=c[g+(m<<2)>>2]&65535}}while(0);m=i+1|0;if((m|0)>=8){break}h=h+640|0;i=m;j=k}c[2385332]=k;return}function fpG(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0;a=c[2440380]|0;d=(c[2415144]|0)+4480|0;e=7;f=c[2385332]|0;while(1){g=f+4|0;h=c[f>>2]|0;i=h&15;if((i|0)!=0){b[d>>1]=c[a+(i<<2)>>2]&65535}i=h>>>4&15;if((i|0)!=0){b[d+2>>1]=c[a+(i<<2)>>2]&65535}i=h>>>8&15;if((i|0)!=0){b[d+4>>1]=c[a+(i<<2)>>2]&65535}i=h>>>12&15;if((i|0)!=0){b[d+6>>1]=c[a+(i<<2)>>2]&65535}i=h>>>16&15;if((i|0)!=0){b[d+8>>1]=c[a+(i<<2)>>2]&65535}i=h>>>20&15;if((i|0)!=0){b[d+10>>1]=c[a+(i<<2)>>2]&65535}i=h>>>24&15;if((i|0)!=0){b[d+12>>1]=c[a+(i<<2)>>2]&65535}i=h>>>28;if((i|0)!=0){b[d+14>>1]=c[a+(i<<2)>>2]&65535}if((e|0)<=0){break}d=d-640|0;e=e-1|0;f=g}c[2385332]=g;return}function fpH(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[2385452]|0;d=c[2385464]|0;e=(d|0)>-1;f=(d|0)<320;g=c[2440380]|0;h=(c[2415144]|0)+4480|0;i=7;j=c[2385332]|0;while(1){k=j+4|0;do{if((a+i|0)>>>0<=239){l=c[j>>2]|0;m=l&15;if((m|0)!=0&e&f){b[h>>1]=c[g+(m<<2)>>2]&65535}m=l>>>4&15;if((m|0)!=0&(d|0)>-2&(d|0)<319){b[h+2>>1]=c[g+(m<<2)>>2]&65535}m=l>>>8&15;if((m|0)!=0&(d|0)>-3&(d|0)<318){b[h+4>>1]=c[g+(m<<2)>>2]&65535}m=l>>>12&15;if((m|0)!=0&(d|0)>-4&(d|0)<317){b[h+6>>1]=c[g+(m<<2)>>2]&65535}m=l>>>16&15;if((m|0)!=0&(d|0)>-5&(d|0)<316){b[h+8>>1]=c[g+(m<<2)>>2]&65535}m=l>>>20&15;if((m|0)!=0&(d|0)>-6&(d|0)<315){b[h+10>>1]=c[g+(m<<2)>>2]&65535}m=l>>>24&15;if((m|0)!=0&(d|0)>-7&(d|0)<314){b[h+12>>1]=c[g+(m<<2)>>2]&65535}m=l>>>28;if(!((m|0)!=0&(d|0)>-8&(d|0)<313)){break}b[h+14>>1]=c[g+(m<<2)>>2]&65535}}while(0);if((i|0)<=0){break}h=h-640|0;i=i-1|0;j=k}c[2385332]=k;return}function fpI(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0;a=c[2440380]|0;d=(c[2415144]|0)+4480|0;e=7;f=c[2385332]|0;while(1){g=f+4|0;h=c[f>>2]|0;i=h&15;if((i|0)!=0){b[d+14>>1]=c[a+(i<<2)>>2]&65535}i=h>>>4&15;if((i|0)!=0){b[d+12>>1]=c[a+(i<<2)>>2]&65535}i=h>>>8&15;if((i|0)!=0){b[d+10>>1]=c[a+(i<<2)>>2]&65535}i=h>>>12&15;if((i|0)!=0){b[d+8>>1]=c[a+(i<<2)>>2]&65535}i=h>>>16&15;if((i|0)!=0){b[d+6>>1]=c[a+(i<<2)>>2]&65535}i=h>>>20&15;if((i|0)!=0){b[d+4>>1]=c[a+(i<<2)>>2]&65535}i=h>>>24&15;if((i|0)!=0){b[d+2>>1]=c[a+(i<<2)>>2]&65535}i=h>>>28;if((i|0)!=0){b[d>>1]=c[a+(i<<2)>>2]&65535}if((e|0)<=0){break}d=d-640|0;e=e-1|0;f=g}c[2385332]=g;return}function fpJ(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[2385452]|0;d=c[2385464]|0;e=(d|0)>-8;f=(d|0)<313;g=c[2440380]|0;h=(c[2415144]|0)+4480|0;i=7;j=c[2385332]|0;while(1){k=j+4|0;do{if((a+i|0)>>>0<=239){l=c[j>>2]|0;m=l&15;if((m|0)!=0&e&f){b[h+14>>1]=c[g+(m<<2)>>2]&65535}m=l>>>4&15;if((m|0)!=0&(d|0)>-7&(d|0)<314){b[h+12>>1]=c[g+(m<<2)>>2]&65535}m=l>>>8&15;if((m|0)!=0&(d|0)>-6&(d|0)<315){b[h+10>>1]=c[g+(m<<2)>>2]&65535}m=l>>>12&15;if((m|0)!=0&(d|0)>-5&(d|0)<316){b[h+8>>1]=c[g+(m<<2)>>2]&65535}m=l>>>16&15;if((m|0)!=0&(d|0)>-4&(d|0)<317){b[h+6>>1]=c[g+(m<<2)>>2]&65535}m=l>>>20&15;if((m|0)!=0&(d|0)>-3&(d|0)<318){b[h+4>>1]=c[g+(m<<2)>>2]&65535}m=l>>>24&15;if((m|0)!=0&(d|0)>-2&(d|0)<319){b[h+2>>1]=c[g+(m<<2)>>2]&65535}m=l>>>28;if(!((m|0)!=0&(d|0)>-1&(d|0)<320)){break}b[h>>1]=c[g+(m<<2)>>2]&65535}}while(0);if((i|0)<=0){break}h=h-640|0;i=i-1|0;j=k}c[2385332]=k;return}function fpK(){var a=0,d=0,e=0,f=0,g=0,h=0;a=c[2440380]|0;d=0;e=c[2415144]|0;f=c[2385332]|0;while(1){g=f+4|0;h=c[f>>2]|0;b[e>>1]=c[a+((h&15)<<2)>>2]&65535;b[e+2>>1]=c[a+((h>>>4&15)<<2)>>2]&65535;b[e+4>>1]=c[a+((h>>>8&15)<<2)>>2]&65535;b[e+6>>1]=c[a+((h>>>12&15)<<2)>>2]&65535;b[e+8>>1]=c[a+((h>>>16&15)<<2)>>2]&65535;b[e+10>>1]=c[a+((h>>>20&15)<<2)>>2]&65535;b[e+12>>1]=c[a+((h>>>24&15)<<2)>>2]&65535;b[e+14>>1]=c[a+(h>>>28<<2)>>2]&65535;h=d+1|0;if((h|0)<8){d=h;e=e+640|0;f=g}else{break}}c[2385332]=g;return}function fpL(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[2385452]|0;d=c[2385464]|0;e=d>>>0<320;f=c[2440380]|0;g=c[2415144]|0;h=0;i=c[2385332]|0;while(1){j=i+4|0;do{if((a+h|0)>>>0<=239){k=c[i>>2]|0;if(e){b[g>>1]=c[f+((k&15)<<2)>>2]&65535}if((d+1|0)>>>0<320){b[g+2>>1]=c[f+((k>>>4&15)<<2)>>2]&65535}if((d+2|0)>>>0<320){b[g+4>>1]=c[f+((k>>>8&15)<<2)>>2]&65535}if((d+3|0)>>>0<320){b[g+6>>1]=c[f+((k>>>12&15)<<2)>>2]&65535}if((d+4|0)>>>0<320){b[g+8>>1]=c[f+((k>>>16&15)<<2)>>2]&65535}if((d+5|0)>>>0<320){b[g+10>>1]=c[f+((k>>>20&15)<<2)>>2]&65535}if((d+6|0)>>>0<320){b[g+12>>1]=c[f+((k>>>24&15)<<2)>>2]&65535}if((d+7|0)>>>0>=320){break}b[g+14>>1]=c[f+(k>>>28<<2)>>2]&65535}}while(0);k=h+1|0;if((k|0)>=8){break}g=g+640|0;h=k;i=j}c[2385332]=j;return}function fpM(){var a=0,d=0,e=0,f=0,g=0,h=0;a=c[2440380]|0;d=0;e=c[2415144]|0;f=c[2385332]|0;while(1){g=f+4|0;h=c[f>>2]|0;b[e+14>>1]=c[a+((h&15)<<2)>>2]&65535;b[e+12>>1]=c[a+((h>>>4&15)<<2)>>2]&65535;b[e+10>>1]=c[a+((h>>>8&15)<<2)>>2]&65535;b[e+8>>1]=c[a+((h>>>12&15)<<2)>>2]&65535;b[e+6>>1]=c[a+((h>>>16&15)<<2)>>2]&65535;b[e+4>>1]=c[a+((h>>>20&15)<<2)>>2]&65535;b[e+2>>1]=c[a+((h>>>24&15)<<2)>>2]&65535;b[e>>1]=c[a+(h>>>28<<2)>>2]&65535;h=d+1|0;if((h|0)<8){d=h;e=e+640|0;f=g}else{break}}c[2385332]=g;return}function fpN(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[2385452]|0;d=c[2385464]|0;e=(d+7|0)>>>0<320;f=c[2440380]|0;g=c[2415144]|0;h=0;i=c[2385332]|0;while(1){j=i+4|0;do{if((a+h|0)>>>0<=239){k=c[i>>2]|0;if(e){b[g+14>>1]=c[f+((k&15)<<2)>>2]&65535}if((d+6|0)>>>0<320){b[g+12>>1]=c[f+((k>>>4&15)<<2)>>2]&65535}if((d+5|0)>>>0<320){b[g+10>>1]=c[f+((k>>>8&15)<<2)>>2]&65535}if((d+4|0)>>>0<320){b[g+8>>1]=c[f+((k>>>12&15)<<2)>>2]&65535}if((d+3|0)>>>0<320){b[g+6>>1]=c[f+((k>>>16&15)<<2)>>2]&65535}if((d+2|0)>>>0<320){b[g+4>>1]=c[f+((k>>>20&15)<<2)>>2]&65535}if((d+1|0)>>>0<320){b[g+2>>1]=c[f+((k>>>24&15)<<2)>>2]&65535}if(d>>>0>=320){break}b[g>>1]=c[f+(k>>>28<<2)>>2]&65535}}while(0);k=h+1|0;if((k|0)>=8){break}g=g+640|0;h=k;i=j}c[2385332]=j;return}function fpO(){var a=0,d=0,e=0,f=0,g=0,h=0;a=c[2440380]|0;d=7;e=(c[2415144]|0)+4480|0;f=c[2385332]|0;while(1){g=f+4|0;h=c[f>>2]|0;b[e>>1]=c[a+((h&15)<<2)>>2]&65535;b[e+2>>1]=c[a+((h>>>4&15)<<2)>>2]&65535;b[e+4>>1]=c[a+((h>>>8&15)<<2)>>2]&65535;b[e+6>>1]=c[a+((h>>>12&15)<<2)>>2]&65535;b[e+8>>1]=c[a+((h>>>16&15)<<2)>>2]&65535;b[e+10>>1]=c[a+((h>>>20&15)<<2)>>2]&65535;b[e+12>>1]=c[a+((h>>>24&15)<<2)>>2]&65535;b[e+14>>1]=c[a+(h>>>28<<2)>>2]&65535;if((d|0)>0){d=d-1|0;e=e-640|0;f=g}else{break}}c[2385332]=g;return}function fpP(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[2385452]|0;d=c[2385464]|0;e=d>>>0<320;f=c[2440380]|0;g=(c[2415144]|0)+4480|0;h=7;i=c[2385332]|0;while(1){j=i+4|0;do{if((a+h|0)>>>0<=239){k=c[i>>2]|0;if(e){b[g>>1]=c[f+((k&15)<<2)>>2]&65535}if((d+1|0)>>>0<320){b[g+2>>1]=c[f+((k>>>4&15)<<2)>>2]&65535}if((d+2|0)>>>0<320){b[g+4>>1]=c[f+((k>>>8&15)<<2)>>2]&65535}if((d+3|0)>>>0<320){b[g+6>>1]=c[f+((k>>>12&15)<<2)>>2]&65535}if((d+4|0)>>>0<320){b[g+8>>1]=c[f+((k>>>16&15)<<2)>>2]&65535}if((d+5|0)>>>0<320){b[g+10>>1]=c[f+((k>>>20&15)<<2)>>2]&65535}if((d+6|0)>>>0<320){b[g+12>>1]=c[f+((k>>>24&15)<<2)>>2]&65535}if((d+7|0)>>>0>=320){break}b[g+14>>1]=c[f+(k>>>28<<2)>>2]&65535}}while(0);if((h|0)<=0){break}g=g-640|0;h=h-1|0;i=j}c[2385332]=j;return}function fpQ(){var a=0,d=0,e=0,f=0,g=0,h=0;a=c[2440380]|0;d=7;e=(c[2415144]|0)+4480|0;f=c[2385332]|0;while(1){g=f+4|0;h=c[f>>2]|0;b[e+14>>1]=c[a+((h&15)<<2)>>2]&65535;b[e+12>>1]=c[a+((h>>>4&15)<<2)>>2]&65535;b[e+10>>1]=c[a+((h>>>8&15)<<2)>>2]&65535;b[e+8>>1]=c[a+((h>>>12&15)<<2)>>2]&65535;b[e+6>>1]=c[a+((h>>>16&15)<<2)>>2]&65535;b[e+4>>1]=c[a+((h>>>20&15)<<2)>>2]&65535;b[e+2>>1]=c[a+((h>>>24&15)<<2)>>2]&65535;b[e>>1]=c[a+(h>>>28<<2)>>2]&65535;if((d|0)>0){d=d-1|0;e=e-640|0;f=g}else{break}}c[2385332]=g;return}function fpR(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[2385452]|0;d=c[2385464]|0;e=(d+7|0)>>>0<320;f=c[2440380]|0;g=(c[2415144]|0)+4480|0;h=7;i=c[2385332]|0;while(1){j=i+4|0;do{if((a+h|0)>>>0<=239){k=c[i>>2]|0;if(e){b[g+14>>1]=c[f+((k&15)<<2)>>2]&65535}if((d+6|0)>>>0<320){b[g+12>>1]=c[f+((k>>>4&15)<<2)>>2]&65535}if((d+5|0)>>>0<320){b[g+10>>1]=c[f+((k>>>8&15)<<2)>>2]&65535}if((d+4|0)>>>0<320){b[g+8>>1]=c[f+((k>>>12&15)<<2)>>2]&65535}if((d+3|0)>>>0<320){b[g+6>>1]=c[f+((k>>>16&15)<<2)>>2]&65535}if((d+2|0)>>>0<320){b[g+4>>1]=c[f+((k>>>20&15)<<2)>>2]&65535}if((d+1|0)>>>0<320){b[g+2>>1]=c[f+((k>>>24&15)<<2)>>2]&65535}if(d>>>0>=320){break}b[g>>1]=c[f+(k>>>28<<2)>>2]&65535}}while(0);if((h|0)<=0){break}g=g-640|0;h=h-1|0;i=j}c[2385332]=j;return}function fpS(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[2440380]|0;d=1;e=c[2415144]|0;f=c[2385332]|0;while(1){g=f+4|0;h=c[f>>2]|0;i=h&15;if((i|0)!=0){j=c[b+(i<<2)>>2]|0;a[e]=j&255;a[e+1|0]=j>>>8&255;a[e+2|0]=j>>>16&255}j=h>>>4&15;if((j|0)!=0){i=c[b+(j<<2)>>2]|0;a[e+3|0]=i&255;a[e+4|0]=i>>>8&255;a[e+5|0]=i>>>16&255}i=h>>>8&15;if((i|0)!=0){j=c[b+(i<<2)>>2]|0;a[e+6|0]=j&255;a[e+7|0]=j>>>8&255;a[e+8|0]=j>>>16&255}j=h>>>12&15;if((j|0)!=0){i=c[b+(j<<2)>>2]|0;a[e+9|0]=i&255;a[e+10|0]=i>>>8&255;a[e+11|0]=i>>>16&255}i=h>>>16&15;if((i|0)!=0){j=c[b+(i<<2)>>2]|0;a[e+12|0]=j&255;a[e+13|0]=j>>>8&255;a[e+14|0]=j>>>16&255}j=h>>>20&15;if((j|0)!=0){i=c[b+(j<<2)>>2]|0;a[e+15|0]=i&255;a[e+16|0]=i>>>8&255;a[e+17|0]=i>>>16&255}i=h>>>24&15;if((i|0)!=0){j=c[b+(i<<2)>>2]|0;a[e+18|0]=j&255;a[e+19|0]=j>>>8&255;a[e+20|0]=j>>>16&255}j=h>>>28;if((j|0)!=0){h=c[b+(j<<2)>>2]|0;a[e+21|0]=h&255;a[e+22|0]=h>>>8&255;a[e+23|0]=h>>>16&255}if((d|0)>=8){break}d=d+1|0;e=e+960|0;f=g}c[2385332]=g;return}function fpT(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[2385452]|0;d=c[2385464]|0;e=(d|0)>-1;f=(d|0)<320;g=c[2440380]|0;h=0;i=c[2415144]|0;j=c[2385332]|0;while(1){k=j+4|0;do{if((b+h|0)>>>0<=239){l=c[j>>2]|0;m=l&15;if((m|0)!=0&e&f){n=c[g+(m<<2)>>2]|0;a[i]=n&255;a[i+1|0]=n>>>8&255;a[i+2|0]=n>>>16&255}n=l>>>4&15;if((n|0)!=0&(d|0)>-2&(d|0)<319){m=c[g+(n<<2)>>2]|0;a[i+3|0]=m&255;a[i+4|0]=m>>>8&255;a[i+5|0]=m>>>16&255}m=l>>>8&15;if((m|0)!=0&(d|0)>-3&(d|0)<318){n=c[g+(m<<2)>>2]|0;a[i+6|0]=n&255;a[i+7|0]=n>>>8&255;a[i+8|0]=n>>>16&255}n=l>>>12&15;if((n|0)!=0&(d|0)>-4&(d|0)<317){m=c[g+(n<<2)>>2]|0;a[i+9|0]=m&255;a[i+10|0]=m>>>8&255;a[i+11|0]=m>>>16&255}m=l>>>16&15;if((m|0)!=0&(d|0)>-5&(d|0)<316){n=c[g+(m<<2)>>2]|0;a[i+12|0]=n&255;a[i+13|0]=n>>>8&255;a[i+14|0]=n>>>16&255}n=l>>>20&15;if((n|0)!=0&(d|0)>-6&(d|0)<315){m=c[g+(n<<2)>>2]|0;a[i+15|0]=m&255;a[i+16|0]=m>>>8&255;a[i+17|0]=m>>>16&255}m=l>>>24&15;if((m|0)!=0&(d|0)>-7&(d|0)<314){n=c[g+(m<<2)>>2]|0;a[i+18|0]=n&255;a[i+19|0]=n>>>8&255;a[i+20|0]=n>>>16&255}n=l>>>28;if(!((n|0)!=0&(d|0)>-8&(d|0)<313)){break}l=c[g+(n<<2)>>2]|0;a[i+21|0]=l&255;a[i+22|0]=l>>>8&255;a[i+23|0]=l>>>16&255}}while(0);l=h+1|0;if((l|0)>=8){break}h=l;i=i+960|0;j=k}c[2385332]=k;return}function fpU(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[2440380]|0;d=1;e=c[2415144]|0;f=c[2385332]|0;while(1){g=f+4|0;h=c[f>>2]|0;i=h&15;if((i|0)!=0){j=c[b+(i<<2)>>2]|0;a[e+21|0]=j&255;a[e+22|0]=j>>>8&255;a[e+23|0]=j>>>16&255}j=h>>>4&15;if((j|0)!=0){i=c[b+(j<<2)>>2]|0;a[e+18|0]=i&255;a[e+19|0]=i>>>8&255;a[e+20|0]=i>>>16&255}i=h>>>8&15;if((i|0)!=0){j=c[b+(i<<2)>>2]|0;a[e+15|0]=j&255;a[e+16|0]=j>>>8&255;a[e+17|0]=j>>>16&255}j=h>>>12&15;if((j|0)!=0){i=c[b+(j<<2)>>2]|0;a[e+12|0]=i&255;a[e+13|0]=i>>>8&255;a[e+14|0]=i>>>16&255}i=h>>>16&15;if((i|0)!=0){j=c[b+(i<<2)>>2]|0;a[e+9|0]=j&255;a[e+10|0]=j>>>8&255;a[e+11|0]=j>>>16&255}j=h>>>20&15;if((j|0)!=0){i=c[b+(j<<2)>>2]|0;a[e+6|0]=i&255;a[e+7|0]=i>>>8&255;a[e+8|0]=i>>>16&255}i=h>>>24&15;if((i|0)!=0){j=c[b+(i<<2)>>2]|0;a[e+3|0]=j&255;a[e+4|0]=j>>>8&255;a[e+5|0]=j>>>16&255}j=h>>>28;if((j|0)!=0){h=c[b+(j<<2)>>2]|0;a[e]=h&255;a[e+1|0]=h>>>8&255;a[e+2|0]=h>>>16&255}if((d|0)>=8){break}d=d+1|0;e=e+960|0;f=g}c[2385332]=g;return}function fpV(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[2385452]|0;d=c[2385464]|0;e=(d|0)>-8;f=(d|0)<313;g=c[2440380]|0;h=0;i=c[2415144]|0;j=c[2385332]|0;while(1){k=j+4|0;do{if((b+h|0)>>>0<=239){l=c[j>>2]|0;m=l&15;if((m|0)!=0&e&f){n=c[g+(m<<2)>>2]|0;a[i+21|0]=n&255;a[i+22|0]=n>>>8&255;a[i+23|0]=n>>>16&255}n=l>>>4&15;if((n|0)!=0&(d|0)>-7&(d|0)<314){m=c[g+(n<<2)>>2]|0;a[i+18|0]=m&255;a[i+19|0]=m>>>8&255;a[i+20|0]=m>>>16&255}m=l>>>8&15;if((m|0)!=0&(d|0)>-6&(d|0)<315){n=c[g+(m<<2)>>2]|0;a[i+15|0]=n&255;a[i+16|0]=n>>>8&255;a[i+17|0]=n>>>16&255}n=l>>>12&15;if((n|0)!=0&(d|0)>-5&(d|0)<316){m=c[g+(n<<2)>>2]|0;a[i+12|0]=m&255;a[i+13|0]=m>>>8&255;a[i+14|0]=m>>>16&255}m=l>>>16&15;if((m|0)!=0&(d|0)>-4&(d|0)<317){n=c[g+(m<<2)>>2]|0;a[i+9|0]=n&255;a[i+10|0]=n>>>8&255;a[i+11|0]=n>>>16&255}n=l>>>20&15;if((n|0)!=0&(d|0)>-3&(d|0)<318){m=c[g+(n<<2)>>2]|0;a[i+6|0]=m&255;a[i+7|0]=m>>>8&255;a[i+8|0]=m>>>16&255}m=l>>>24&15;if((m|0)!=0&(d|0)>-2&(d|0)<319){n=c[g+(m<<2)>>2]|0;a[i+3|0]=n&255;a[i+4|0]=n>>>8&255;a[i+5|0]=n>>>16&255}n=l>>>28;if(!((n|0)!=0&(d|0)>-1&(d|0)<320)){break}l=c[g+(n<<2)>>2]|0;a[i]=l&255;a[i+1|0]=l>>>8&255;a[i+2|0]=l>>>16&255}}while(0);l=h+1|0;if((l|0)>=8){break}h=l;i=i+960|0;j=k}c[2385332]=k;return}function fpW(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[2440380]|0;d=7;e=(c[2415144]|0)+6720|0;f=c[2385332]|0;while(1){g=f+4|0;h=c[f>>2]|0;i=h&15;if((i|0)!=0){j=c[b+(i<<2)>>2]|0;a[e]=j&255;a[e+1|0]=j>>>8&255;a[e+2|0]=j>>>16&255}j=h>>>4&15;if((j|0)!=0){i=c[b+(j<<2)>>2]|0;a[e+3|0]=i&255;a[e+4|0]=i>>>8&255;a[e+5|0]=i>>>16&255}i=h>>>8&15;if((i|0)!=0){j=c[b+(i<<2)>>2]|0;a[e+6|0]=j&255;a[e+7|0]=j>>>8&255;a[e+8|0]=j>>>16&255}j=h>>>12&15;if((j|0)!=0){i=c[b+(j<<2)>>2]|0;a[e+9|0]=i&255;a[e+10|0]=i>>>8&255;a[e+11|0]=i>>>16&255}i=h>>>16&15;if((i|0)!=0){j=c[b+(i<<2)>>2]|0;a[e+12|0]=j&255;a[e+13|0]=j>>>8&255;a[e+14|0]=j>>>16&255}j=h>>>20&15;if((j|0)!=0){i=c[b+(j<<2)>>2]|0;a[e+15|0]=i&255;a[e+16|0]=i>>>8&255;a[e+17|0]=i>>>16&255}i=h>>>24&15;if((i|0)!=0){j=c[b+(i<<2)>>2]|0;a[e+18|0]=j&255;a[e+19|0]=j>>>8&255;a[e+20|0]=j>>>16&255}j=h>>>28;if((j|0)!=0){h=c[b+(j<<2)>>2]|0;a[e+21|0]=h&255;a[e+22|0]=h>>>8&255;a[e+23|0]=h>>>16&255}if((d|0)<=0){break}d=d-1|0;e=e-960|0;f=g}c[2385332]=g;return}function fpX(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[2385452]|0;d=c[2385464]|0;e=(d|0)>-1;f=(d|0)<320;g=c[2440380]|0;h=7;i=(c[2415144]|0)+6720|0;j=c[2385332]|0;while(1){k=j+4|0;do{if((b+h|0)>>>0<=239){l=c[j>>2]|0;m=l&15;if((m|0)!=0&e&f){n=c[g+(m<<2)>>2]|0;a[i]=n&255;a[i+1|0]=n>>>8&255;a[i+2|0]=n>>>16&255}n=l>>>4&15;if((n|0)!=0&(d|0)>-2&(d|0)<319){m=c[g+(n<<2)>>2]|0;a[i+3|0]=m&255;a[i+4|0]=m>>>8&255;a[i+5|0]=m>>>16&255}m=l>>>8&15;if((m|0)!=0&(d|0)>-3&(d|0)<318){n=c[g+(m<<2)>>2]|0;a[i+6|0]=n&255;a[i+7|0]=n>>>8&255;a[i+8|0]=n>>>16&255}n=l>>>12&15;if((n|0)!=0&(d|0)>-4&(d|0)<317){m=c[g+(n<<2)>>2]|0;a[i+9|0]=m&255;a[i+10|0]=m>>>8&255;a[i+11|0]=m>>>16&255}m=l>>>16&15;if((m|0)!=0&(d|0)>-5&(d|0)<316){n=c[g+(m<<2)>>2]|0;a[i+12|0]=n&255;a[i+13|0]=n>>>8&255;a[i+14|0]=n>>>16&255}n=l>>>20&15;if((n|0)!=0&(d|0)>-6&(d|0)<315){m=c[g+(n<<2)>>2]|0;a[i+15|0]=m&255;a[i+16|0]=m>>>8&255;a[i+17|0]=m>>>16&255}m=l>>>24&15;if((m|0)!=0&(d|0)>-7&(d|0)<314){n=c[g+(m<<2)>>2]|0;a[i+18|0]=n&255;a[i+19|0]=n>>>8&255;a[i+20|0]=n>>>16&255}n=l>>>28;if(!((n|0)!=0&(d|0)>-8&(d|0)<313)){break}l=c[g+(n<<2)>>2]|0;a[i+21|0]=l&255;a[i+22|0]=l>>>8&255;a[i+23|0]=l>>>16&255}}while(0);if((h|0)<=0){break}h=h-1|0;i=i-960|0;j=k}c[2385332]=k;return}function fpY(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[2440380]|0;d=7;e=(c[2415144]|0)+6720|0;f=c[2385332]|0;while(1){g=f+4|0;h=c[f>>2]|0;i=h&15;if((i|0)!=0){j=c[b+(i<<2)>>2]|0;a[e+21|0]=j&255;a[e+22|0]=j>>>8&255;a[e+23|0]=j>>>16&255}j=h>>>4&15;if((j|0)!=0){i=c[b+(j<<2)>>2]|0;a[e+18|0]=i&255;a[e+19|0]=i>>>8&255;a[e+20|0]=i>>>16&255}i=h>>>8&15;if((i|0)!=0){j=c[b+(i<<2)>>2]|0;a[e+15|0]=j&255;a[e+16|0]=j>>>8&255;a[e+17|0]=j>>>16&255}j=h>>>12&15;if((j|0)!=0){i=c[b+(j<<2)>>2]|0;a[e+12|0]=i&255;a[e+13|0]=i>>>8&255;a[e+14|0]=i>>>16&255}i=h>>>16&15;if((i|0)!=0){j=c[b+(i<<2)>>2]|0;a[e+9|0]=j&255;a[e+10|0]=j>>>8&255;a[e+11|0]=j>>>16&255}j=h>>>20&15;if((j|0)!=0){i=c[b+(j<<2)>>2]|0;a[e+6|0]=i&255;a[e+7|0]=i>>>8&255;a[e+8|0]=i>>>16&255}i=h>>>24&15;if((i|0)!=0){j=c[b+(i<<2)>>2]|0;a[e+3|0]=j&255;a[e+4|0]=j>>>8&255;a[e+5|0]=j>>>16&255}j=h>>>28;if((j|0)!=0){h=c[b+(j<<2)>>2]|0;a[e]=h&255;a[e+1|0]=h>>>8&255;a[e+2|0]=h>>>16&255}if((d|0)<=0){break}d=d-1|0;e=e-960|0;f=g}c[2385332]=g;return}function fpZ(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[2385452]|0;d=c[2385464]|0;e=(d|0)>-8;f=(d|0)<313;g=c[2440380]|0;h=7;i=(c[2415144]|0)+6720|0;j=c[2385332]|0;while(1){k=j+4|0;do{if((b+h|0)>>>0<=239){l=c[j>>2]|0;m=l&15;if((m|0)!=0&e&f){n=c[g+(m<<2)>>2]|0;a[i+21|0]=n&255;a[i+22|0]=n>>>8&255;a[i+23|0]=n>>>16&255}n=l>>>4&15;if((n|0)!=0&(d|0)>-7&(d|0)<314){m=c[g+(n<<2)>>2]|0;a[i+18|0]=m&255;a[i+19|0]=m>>>8&255;a[i+20|0]=m>>>16&255}m=l>>>8&15;if((m|0)!=0&(d|0)>-6&(d|0)<315){n=c[g+(m<<2)>>2]|0;a[i+15|0]=n&255;a[i+16|0]=n>>>8&255;a[i+17|0]=n>>>16&255}n=l>>>12&15;if((n|0)!=0&(d|0)>-5&(d|0)<316){m=c[g+(n<<2)>>2]|0;a[i+12|0]=m&255;a[i+13|0]=m>>>8&255;a[i+14|0]=m>>>16&255}m=l>>>16&15;if((m|0)!=0&(d|0)>-4&(d|0)<317){n=c[g+(m<<2)>>2]|0;a[i+9|0]=n&255;a[i+10|0]=n>>>8&255;a[i+11|0]=n>>>16&255}n=l>>>20&15;if((n|0)!=0&(d|0)>-3&(d|0)<318){m=c[g+(n<<2)>>2]|0;a[i+6|0]=m&255;a[i+7|0]=m>>>8&255;a[i+8|0]=m>>>16&255}m=l>>>24&15;if((m|0)!=0&(d|0)>-2&(d|0)<319){n=c[g+(m<<2)>>2]|0;a[i+3|0]=n&255;a[i+4|0]=n>>>8&255;a[i+5|0]=n>>>16&255}n=l>>>28;if(!((n|0)!=0&(d|0)>-1&(d|0)<320)){break}l=c[g+(n<<2)>>2]|0;a[i]=l&255;a[i+1|0]=l>>>8&255;a[i+2|0]=l>>>16&255}}while(0);if((h|0)<=0){break}h=h-1|0;i=i-960|0;j=k}c[2385332]=k;return}function fp_(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=c[2440380]|0;d=0;e=c[2415144]|0;f=c[2385332]|0;while(1){g=f+4|0;h=c[f>>2]|0;i=c[b+((h&15)<<2)>>2]|0;a[e]=i&255;a[e+1|0]=i>>>8&255;a[e+2|0]=i>>>16&255;i=c[b+((h>>>4&15)<<2)>>2]|0;a[e+3|0]=i&255;a[e+4|0]=i>>>8&255;a[e+5|0]=i>>>16&255;i=c[b+((h>>>8&15)<<2)>>2]|0;a[e+6|0]=i&255;a[e+7|0]=i>>>8&255;a[e+8|0]=i>>>16&255;i=c[b+((h>>>12&15)<<2)>>2]|0;a[e+9|0]=i&255;a[e+10|0]=i>>>8&255;a[e+11|0]=i>>>16&255;i=c[b+((h>>>16&15)<<2)>>2]|0;a[e+12|0]=i&255;a[e+13|0]=i>>>8&255;a[e+14|0]=i>>>16&255;i=c[b+((h>>>20&15)<<2)>>2]|0;a[e+15|0]=i&255;a[e+16|0]=i>>>8&255;a[e+17|0]=i>>>16&255;i=c[b+((h>>>24&15)<<2)>>2]|0;a[e+18|0]=i&255;a[e+19|0]=i>>>8&255;a[e+20|0]=i>>>16&255;i=c[b+(h>>>28<<2)>>2]|0;a[e+21|0]=i&255;a[e+22|0]=i>>>8&255;a[e+23|0]=i>>>16&255;i=d+1|0;if((i|0)<8){d=i;e=e+960|0;f=g}else{break}}c[2385332]=g;return}function fp$(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=c[2385452]|0;d=c[2385464]|0;e=d>>>0<320;f=c[2440380]|0;g=0;h=c[2415144]|0;i=c[2385332]|0;while(1){j=i+4|0;do{if((b+g|0)>>>0<=239){k=c[i>>2]|0;if(e){l=c[f+((k&15)<<2)>>2]|0;a[h]=l&255;a[h+1|0]=l>>>8&255;a[h+2|0]=l>>>16&255}if((d+1|0)>>>0<320){l=c[f+((k>>>4&15)<<2)>>2]|0;a[h+3|0]=l&255;a[h+4|0]=l>>>8&255;a[h+5|0]=l>>>16&255}if((d+2|0)>>>0<320){l=c[f+((k>>>8&15)<<2)>>2]|0;a[h+6|0]=l&255;a[h+7|0]=l>>>8&255;a[h+8|0]=l>>>16&255}if((d+3|0)>>>0<320){l=c[f+((k>>>12&15)<<2)>>2]|0;a[h+9|0]=l&255;a[h+10|0]=l>>>8&255;a[h+11|0]=l>>>16&255}if((d+4|0)>>>0<320){l=c[f+((k>>>16&15)<<2)>>2]|0;a[h+12|0]=l&255;a[h+13|0]=l>>>8&255;a[h+14|0]=l>>>16&255}if((d+5|0)>>>0<320){l=c[f+((k>>>20&15)<<2)>>2]|0;a[h+15|0]=l&255;a[h+16|0]=l>>>8&255;a[h+17|0]=l>>>16&255}if((d+6|0)>>>0<320){l=c[f+((k>>>24&15)<<2)>>2]|0;a[h+18|0]=l&255;a[h+19|0]=l>>>8&255;a[h+20|0]=l>>>16&255}if((d+7|0)>>>0>=320){break}l=c[f+(k>>>28<<2)>>2]|0;a[h+21|0]=l&255;a[h+22|0]=l>>>8&255;a[h+23|0]=l>>>16&255}}while(0);l=g+1|0;if((l|0)>=8){break}g=l;h=h+960|0;i=j}c[2385332]=j;return}function fp0(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=c[2440380]|0;d=0;e=c[2415144]|0;f=c[2385332]|0;while(1){g=f+4|0;h=c[f>>2]|0;i=c[b+((h&15)<<2)>>2]|0;a[e+21|0]=i&255;a[e+22|0]=i>>>8&255;a[e+23|0]=i>>>16&255;i=c[b+((h>>>4&15)<<2)>>2]|0;a[e+18|0]=i&255;a[e+19|0]=i>>>8&255;a[e+20|0]=i>>>16&255;i=c[b+((h>>>8&15)<<2)>>2]|0;a[e+15|0]=i&255;a[e+16|0]=i>>>8&255;a[e+17|0]=i>>>16&255;i=c[b+((h>>>12&15)<<2)>>2]|0;a[e+12|0]=i&255;a[e+13|0]=i>>>8&255;a[e+14|0]=i>>>16&255;i=c[b+((h>>>16&15)<<2)>>2]|0;a[e+9|0]=i&255;a[e+10|0]=i>>>8&255;a[e+11|0]=i>>>16&255;i=c[b+((h>>>20&15)<<2)>>2]|0;a[e+6|0]=i&255;a[e+7|0]=i>>>8&255;a[e+8|0]=i>>>16&255;i=c[b+((h>>>24&15)<<2)>>2]|0;a[e+3|0]=i&255;a[e+4|0]=i>>>8&255;a[e+5|0]=i>>>16&255;i=c[b+(h>>>28<<2)>>2]|0;a[e]=i&255;a[e+1|0]=i>>>8&255;a[e+2|0]=i>>>16&255;i=d+1|0;if((i|0)<8){d=i;e=e+960|0;f=g}else{break}}c[2385332]=g;return}function fp1(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=c[2385452]|0;d=c[2385464]|0;e=(d+7|0)>>>0<320;f=c[2440380]|0;g=0;h=c[2415144]|0;i=c[2385332]|0;while(1){j=i+4|0;do{if((b+g|0)>>>0<=239){k=c[i>>2]|0;if(e){l=c[f+((k&15)<<2)>>2]|0;a[h+21|0]=l&255;a[h+22|0]=l>>>8&255;a[h+23|0]=l>>>16&255}if((d+6|0)>>>0<320){l=c[f+((k>>>4&15)<<2)>>2]|0;a[h+18|0]=l&255;a[h+19|0]=l>>>8&255;a[h+20|0]=l>>>16&255}if((d+5|0)>>>0<320){l=c[f+((k>>>8&15)<<2)>>2]|0;a[h+15|0]=l&255;a[h+16|0]=l>>>8&255;a[h+17|0]=l>>>16&255}if((d+4|0)>>>0<320){l=c[f+((k>>>12&15)<<2)>>2]|0;a[h+12|0]=l&255;a[h+13|0]=l>>>8&255;a[h+14|0]=l>>>16&255}if((d+3|0)>>>0<320){l=c[f+((k>>>16&15)<<2)>>2]|0;a[h+9|0]=l&255;a[h+10|0]=l>>>8&255;a[h+11|0]=l>>>16&255}if((d+2|0)>>>0<320){l=c[f+((k>>>20&15)<<2)>>2]|0;a[h+6|0]=l&255;a[h+7|0]=l>>>8&255;a[h+8|0]=l>>>16&255}if((d+1|0)>>>0<320){l=c[f+((k>>>24&15)<<2)>>2]|0;a[h+3|0]=l&255;a[h+4|0]=l>>>8&255;a[h+5|0]=l>>>16&255}if(d>>>0>=320){break}l=c[f+(k>>>28<<2)>>2]|0;a[h]=l&255;a[h+1|0]=l>>>8&255;a[h+2|0]=l>>>16&255}}while(0);l=g+1|0;if((l|0)>=8){break}g=l;h=h+960|0;i=j}c[2385332]=j;return}function fp2(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=c[2440380]|0;d=7;e=(c[2415144]|0)+6720|0;f=c[2385332]|0;while(1){g=f+4|0;h=c[f>>2]|0;i=c[b+((h&15)<<2)>>2]|0;a[e]=i&255;a[e+1|0]=i>>>8&255;a[e+2|0]=i>>>16&255;i=c[b+((h>>>4&15)<<2)>>2]|0;a[e+3|0]=i&255;a[e+4|0]=i>>>8&255;a[e+5|0]=i>>>16&255;i=c[b+((h>>>8&15)<<2)>>2]|0;a[e+6|0]=i&255;a[e+7|0]=i>>>8&255;a[e+8|0]=i>>>16&255;i=c[b+((h>>>12&15)<<2)>>2]|0;a[e+9|0]=i&255;a[e+10|0]=i>>>8&255;a[e+11|0]=i>>>16&255;i=c[b+((h>>>16&15)<<2)>>2]|0;a[e+12|0]=i&255;a[e+13|0]=i>>>8&255;a[e+14|0]=i>>>16&255;i=c[b+((h>>>20&15)<<2)>>2]|0;a[e+15|0]=i&255;a[e+16|0]=i>>>8&255;a[e+17|0]=i>>>16&255;i=c[b+((h>>>24&15)<<2)>>2]|0;a[e+18|0]=i&255;a[e+19|0]=i>>>8&255;a[e+20|0]=i>>>16&255;i=c[b+(h>>>28<<2)>>2]|0;a[e+21|0]=i&255;a[e+22|0]=i>>>8&255;a[e+23|0]=i>>>16&255;if((d|0)>0){d=d-1|0;e=e-960|0;f=g}else{break}}c[2385332]=g;return}function fp3(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=c[2385452]|0;d=c[2385464]|0;e=d>>>0<320;f=c[2440380]|0;g=7;h=(c[2415144]|0)+6720|0;i=c[2385332]|0;while(1){j=i+4|0;do{if((b+g|0)>>>0<=239){k=c[i>>2]|0;if(e){l=c[f+((k&15)<<2)>>2]|0;a[h]=l&255;a[h+1|0]=l>>>8&255;a[h+2|0]=l>>>16&255}if((d+1|0)>>>0<320){l=c[f+((k>>>4&15)<<2)>>2]|0;a[h+3|0]=l&255;a[h+4|0]=l>>>8&255;a[h+5|0]=l>>>16&255}if((d+2|0)>>>0<320){l=c[f+((k>>>8&15)<<2)>>2]|0;a[h+6|0]=l&255;a[h+7|0]=l>>>8&255;a[h+8|0]=l>>>16&255}if((d+3|0)>>>0<320){l=c[f+((k>>>12&15)<<2)>>2]|0;a[h+9|0]=l&255;a[h+10|0]=l>>>8&255;a[h+11|0]=l>>>16&255}if((d+4|0)>>>0<320){l=c[f+((k>>>16&15)<<2)>>2]|0;a[h+12|0]=l&255;a[h+13|0]=l>>>8&255;a[h+14|0]=l>>>16&255}if((d+5|0)>>>0<320){l=c[f+((k>>>20&15)<<2)>>2]|0;a[h+15|0]=l&255;a[h+16|0]=l>>>8&255;a[h+17|0]=l>>>16&255}if((d+6|0)>>>0<320){l=c[f+((k>>>24&15)<<2)>>2]|0;a[h+18|0]=l&255;a[h+19|0]=l>>>8&255;a[h+20|0]=l>>>16&255}if((d+7|0)>>>0>=320){break}l=c[f+(k>>>28<<2)>>2]|0;a[h+21|0]=l&255;a[h+22|0]=l>>>8&255;a[h+23|0]=l>>>16&255}}while(0);if((g|0)<=0){break}g=g-1|0;h=h-960|0;i=j}c[2385332]=j;return}function fp4(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=c[2440380]|0;d=7;e=(c[2415144]|0)+6720|0;f=c[2385332]|0;while(1){g=f+4|0;h=c[f>>2]|0;i=c[b+((h&15)<<2)>>2]|0;a[e+21|0]=i&255;a[e+22|0]=i>>>8&255;a[e+23|0]=i>>>16&255;i=c[b+((h>>>4&15)<<2)>>2]|0;a[e+18|0]=i&255;a[e+19|0]=i>>>8&255;a[e+20|0]=i>>>16&255;i=c[b+((h>>>8&15)<<2)>>2]|0;a[e+15|0]=i&255;a[e+16|0]=i>>>8&255;a[e+17|0]=i>>>16&255;i=c[b+((h>>>12&15)<<2)>>2]|0;a[e+12|0]=i&255;a[e+13|0]=i>>>8&255;a[e+14|0]=i>>>16&255;i=c[b+((h>>>16&15)<<2)>>2]|0;a[e+9|0]=i&255;a[e+10|0]=i>>>8&255;a[e+11|0]=i>>>16&255;i=c[b+((h>>>20&15)<<2)>>2]|0;a[e+6|0]=i&255;a[e+7|0]=i>>>8&255;a[e+8|0]=i>>>16&255;i=c[b+((h>>>24&15)<<2)>>2]|0;a[e+3|0]=i&255;a[e+4|0]=i>>>8&255;a[e+5|0]=i>>>16&255;i=c[b+(h>>>28<<2)>>2]|0;a[e]=i&255;a[e+1|0]=i>>>8&255;a[e+2|0]=i>>>16&255;if((d|0)>0){d=d-1|0;e=e-960|0;f=g}else{break}}c[2385332]=g;return}function fp5(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=c[2385452]|0;d=c[2385464]|0;e=(d+7|0)>>>0<320;f=c[2440380]|0;g=7;h=(c[2415144]|0)+6720|0;i=c[2385332]|0;while(1){j=i+4|0;do{if((b+g|0)>>>0<=239){k=c[i>>2]|0;if(e){l=c[f+((k&15)<<2)>>2]|0;a[h+21|0]=l&255;a[h+22|0]=l>>>8&255;a[h+23|0]=l>>>16&255}if((d+6|0)>>>0<320){l=c[f+((k>>>4&15)<<2)>>2]|0;a[h+18|0]=l&255;a[h+19|0]=l>>>8&255;a[h+20|0]=l>>>16&255}if((d+5|0)>>>0<320){l=c[f+((k>>>8&15)<<2)>>2]|0;a[h+15|0]=l&255;a[h+16|0]=l>>>8&255;a[h+17|0]=l>>>16&255}if((d+4|0)>>>0<320){l=c[f+((k>>>12&15)<<2)>>2]|0;a[h+12|0]=l&255;a[h+13|0]=l>>>8&255;a[h+14|0]=l>>>16&255}if((d+3|0)>>>0<320){l=c[f+((k>>>16&15)<<2)>>2]|0;a[h+9|0]=l&255;a[h+10|0]=l>>>8&255;a[h+11|0]=l>>>16&255}if((d+2|0)>>>0<320){l=c[f+((k>>>20&15)<<2)>>2]|0;a[h+6|0]=l&255;a[h+7|0]=l>>>8&255;a[h+8|0]=l>>>16&255}if((d+1|0)>>>0<320){l=c[f+((k>>>24&15)<<2)>>2]|0;a[h+3|0]=l&255;a[h+4|0]=l>>>8&255;a[h+5|0]=l>>>16&255}if(d>>>0>=320){break}l=c[f+(k>>>28<<2)>>2]|0;a[h]=l&255;a[h+1|0]=l>>>8&255;a[h+2|0]=l>>>16&255}}while(0);if((g|0)<=0){break}g=g-1|0;h=h-960|0;i=j}c[2385332]=j;return}function fp6(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0;a=c[2440380]|0;b=c[2415144]|0;d=1;e=c[2385332]|0;while(1){f=e+4|0;g=c[e>>2]|0;h=g&15;if((h|0)!=0){c[b>>2]=c[a+(h<<2)>>2]}h=g>>>4&15;if((h|0)!=0){c[b+4>>2]=c[a+(h<<2)>>2]}h=g>>>8&15;if((h|0)!=0){c[b+8>>2]=c[a+(h<<2)>>2]}h=g>>>12&15;if((h|0)!=0){c[b+12>>2]=c[a+(h<<2)>>2]}h=g>>>16&15;if((h|0)!=0){c[b+16>>2]=c[a+(h<<2)>>2]}h=g>>>20&15;if((h|0)!=0){c[b+20>>2]=c[a+(h<<2)>>2]}h=g>>>24&15;if((h|0)!=0){c[b+24>>2]=c[a+(h<<2)>>2]}h=g>>>28;if((h|0)!=0){c[b+28>>2]=c[a+(h<<2)>>2]}if((d|0)>=8){break}b=b+1280|0;d=d+1|0;e=f}c[2385332]=f;return}function fp7(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[2385452]|0;b=c[2385464]|0;d=(b|0)>-1;e=(b|0)<320;f=c[2440380]|0;g=c[2415144]|0;h=0;i=c[2385332]|0;while(1){j=i+4|0;do{if((a+h|0)>>>0<=239){k=c[i>>2]|0;l=k&15;if((l|0)!=0&d&e){c[g>>2]=c[f+(l<<2)>>2]}l=k>>>4&15;if((l|0)!=0&(b|0)>-2&(b|0)<319){c[g+4>>2]=c[f+(l<<2)>>2]}l=k>>>8&15;if((l|0)!=0&(b|0)>-3&(b|0)<318){c[g+8>>2]=c[f+(l<<2)>>2]}l=k>>>12&15;if((l|0)!=0&(b|0)>-4&(b|0)<317){c[g+12>>2]=c[f+(l<<2)>>2]}l=k>>>16&15;if((l|0)!=0&(b|0)>-5&(b|0)<316){c[g+16>>2]=c[f+(l<<2)>>2]}l=k>>>20&15;if((l|0)!=0&(b|0)>-6&(b|0)<315){c[g+20>>2]=c[f+(l<<2)>>2]}l=k>>>24&15;if((l|0)!=0&(b|0)>-7&(b|0)<314){c[g+24>>2]=c[f+(l<<2)>>2]}l=k>>>28;if(!((l|0)!=0&(b|0)>-8&(b|0)<313)){break}c[g+28>>2]=c[f+(l<<2)>>2]}}while(0);l=h+1|0;if((l|0)>=8){break}g=g+1280|0;h=l;i=j}c[2385332]=j;return}function fp8(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0;a=c[2440380]|0;b=c[2415144]|0;d=1;e=c[2385332]|0;while(1){f=e+4|0;g=c[e>>2]|0;h=g&15;if((h|0)!=0){c[b+28>>2]=c[a+(h<<2)>>2]}h=g>>>4&15;if((h|0)!=0){c[b+24>>2]=c[a+(h<<2)>>2]}h=g>>>8&15;if((h|0)!=0){c[b+20>>2]=c[a+(h<<2)>>2]}h=g>>>12&15;if((h|0)!=0){c[b+16>>2]=c[a+(h<<2)>>2]}h=g>>>16&15;if((h|0)!=0){c[b+12>>2]=c[a+(h<<2)>>2]}h=g>>>20&15;if((h|0)!=0){c[b+8>>2]=c[a+(h<<2)>>2]}h=g>>>24&15;if((h|0)!=0){c[b+4>>2]=c[a+(h<<2)>>2]}h=g>>>28;if((h|0)!=0){c[b>>2]=c[a+(h<<2)>>2]}if((d|0)>=8){break}b=b+1280|0;d=d+1|0;e=f}c[2385332]=f;return}function fp9(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[2385452]|0;b=c[2385464]|0;d=(b|0)>-8;e=(b|0)<313;f=c[2440380]|0;g=c[2415144]|0;h=0;i=c[2385332]|0;while(1){j=i+4|0;do{if((a+h|0)>>>0<=239){k=c[i>>2]|0;l=k&15;if((l|0)!=0&d&e){c[g+28>>2]=c[f+(l<<2)>>2]}l=k>>>4&15;if((l|0)!=0&(b|0)>-7&(b|0)<314){c[g+24>>2]=c[f+(l<<2)>>2]}l=k>>>8&15;if((l|0)!=0&(b|0)>-6&(b|0)<315){c[g+20>>2]=c[f+(l<<2)>>2]}l=k>>>12&15;if((l|0)!=0&(b|0)>-5&(b|0)<316){c[g+16>>2]=c[f+(l<<2)>>2]}l=k>>>16&15;if((l|0)!=0&(b|0)>-4&(b|0)<317){c[g+12>>2]=c[f+(l<<2)>>2]}l=k>>>20&15;if((l|0)!=0&(b|0)>-3&(b|0)<318){c[g+8>>2]=c[f+(l<<2)>>2]}l=k>>>24&15;if((l|0)!=0&(b|0)>-2&(b|0)<319){c[g+4>>2]=c[f+(l<<2)>>2]}l=k>>>28;if(!((l|0)!=0&(b|0)>-1&(b|0)<320)){break}c[g>>2]=c[f+(l<<2)>>2]}}while(0);l=h+1|0;if((l|0)>=8){break}g=g+1280|0;h=l;i=j}c[2385332]=j;return}function fqa(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0;a=c[2440380]|0;b=(c[2415144]|0)+8960|0;d=7;e=c[2385332]|0;while(1){f=e+4|0;g=c[e>>2]|0;h=g&15;if((h|0)!=0){c[b>>2]=c[a+(h<<2)>>2]}h=g>>>4&15;if((h|0)!=0){c[b+4>>2]=c[a+(h<<2)>>2]}h=g>>>8&15;if((h|0)!=0){c[b+8>>2]=c[a+(h<<2)>>2]}h=g>>>12&15;if((h|0)!=0){c[b+12>>2]=c[a+(h<<2)>>2]}h=g>>>16&15;if((h|0)!=0){c[b+16>>2]=c[a+(h<<2)>>2]}h=g>>>20&15;if((h|0)!=0){c[b+20>>2]=c[a+(h<<2)>>2]}h=g>>>24&15;if((h|0)!=0){c[b+24>>2]=c[a+(h<<2)>>2]}h=g>>>28;if((h|0)!=0){c[b+28>>2]=c[a+(h<<2)>>2]}if((d|0)<=0){break}b=b-1280|0;d=d-1|0;e=f}c[2385332]=f;return}function fqb(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[2385452]|0;b=c[2385464]|0;d=(b|0)>-1;e=(b|0)<320;f=c[2440380]|0;g=(c[2415144]|0)+8960|0;h=7;i=c[2385332]|0;while(1){j=i+4|0;do{if((a+h|0)>>>0<=239){k=c[i>>2]|0;l=k&15;if((l|0)!=0&d&e){c[g>>2]=c[f+(l<<2)>>2]}l=k>>>4&15;if((l|0)!=0&(b|0)>-2&(b|0)<319){c[g+4>>2]=c[f+(l<<2)>>2]}l=k>>>8&15;if((l|0)!=0&(b|0)>-3&(b|0)<318){c[g+8>>2]=c[f+(l<<2)>>2]}l=k>>>12&15;if((l|0)!=0&(b|0)>-4&(b|0)<317){c[g+12>>2]=c[f+(l<<2)>>2]}l=k>>>16&15;if((l|0)!=0&(b|0)>-5&(b|0)<316){c[g+16>>2]=c[f+(l<<2)>>2]}l=k>>>20&15;if((l|0)!=0&(b|0)>-6&(b|0)<315){c[g+20>>2]=c[f+(l<<2)>>2]}l=k>>>24&15;if((l|0)!=0&(b|0)>-7&(b|0)<314){c[g+24>>2]=c[f+(l<<2)>>2]}l=k>>>28;if(!((l|0)!=0&(b|0)>-8&(b|0)<313)){break}c[g+28>>2]=c[f+(l<<2)>>2]}}while(0);if((h|0)<=0){break}g=g-1280|0;h=h-1|0;i=j}c[2385332]=j;return}function fqc(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0;a=c[2440380]|0;b=(c[2415144]|0)+8960|0;d=7;e=c[2385332]|0;while(1){f=e+4|0;g=c[e>>2]|0;h=g&15;if((h|0)!=0){c[b+28>>2]=c[a+(h<<2)>>2]}h=g>>>4&15;if((h|0)!=0){c[b+24>>2]=c[a+(h<<2)>>2]}h=g>>>8&15;if((h|0)!=0){c[b+20>>2]=c[a+(h<<2)>>2]}h=g>>>12&15;if((h|0)!=0){c[b+16>>2]=c[a+(h<<2)>>2]}h=g>>>16&15;if((h|0)!=0){c[b+12>>2]=c[a+(h<<2)>>2]}h=g>>>20&15;if((h|0)!=0){c[b+8>>2]=c[a+(h<<2)>>2]}h=g>>>24&15;if((h|0)!=0){c[b+4>>2]=c[a+(h<<2)>>2]}h=g>>>28;if((h|0)!=0){c[b>>2]=c[a+(h<<2)>>2]}if((d|0)<=0){break}b=b-1280|0;d=d-1|0;e=f}c[2385332]=f;return}function fqd(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[2385452]|0;b=c[2385464]|0;d=(b|0)>-8;e=(b|0)<313;f=c[2440380]|0;g=(c[2415144]|0)+8960|0;h=7;i=c[2385332]|0;while(1){j=i+4|0;do{if((a+h|0)>>>0<=239){k=c[i>>2]|0;l=k&15;if((l|0)!=0&d&e){c[g+28>>2]=c[f+(l<<2)>>2]}l=k>>>4&15;if((l|0)!=0&(b|0)>-7&(b|0)<314){c[g+24>>2]=c[f+(l<<2)>>2]}l=k>>>8&15;if((l|0)!=0&(b|0)>-6&(b|0)<315){c[g+20>>2]=c[f+(l<<2)>>2]}l=k>>>12&15;if((l|0)!=0&(b|0)>-5&(b|0)<316){c[g+16>>2]=c[f+(l<<2)>>2]}l=k>>>16&15;if((l|0)!=0&(b|0)>-4&(b|0)<317){c[g+12>>2]=c[f+(l<<2)>>2]}l=k>>>20&15;if((l|0)!=0&(b|0)>-3&(b|0)<318){c[g+8>>2]=c[f+(l<<2)>>2]}l=k>>>24&15;if((l|0)!=0&(b|0)>-2&(b|0)<319){c[g+4>>2]=c[f+(l<<2)>>2]}l=k>>>28;if(!((l|0)!=0&(b|0)>-1&(b|0)<320)){break}c[g>>2]=c[f+(l<<2)>>2]}}while(0);if((h|0)<=0){break}g=g-1280|0;h=h-1|0;i=j}c[2385332]=j;return}function fqe(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[2440380]|0;b=0;d=c[2415144]|0;e=c[2385332]|0;while(1){f=e+4|0;g=c[e>>2]|0;c[d>>2]=c[a+((g&15)<<2)>>2];c[d+4>>2]=c[a+((g>>>4&15)<<2)>>2];c[d+8>>2]=c[a+((g>>>8&15)<<2)>>2];c[d+12>>2]=c[a+((g>>>12&15)<<2)>>2];c[d+16>>2]=c[a+((g>>>16&15)<<2)>>2];c[d+20>>2]=c[a+((g>>>20&15)<<2)>>2];c[d+24>>2]=c[a+((g>>>24&15)<<2)>>2];c[d+28>>2]=c[a+(g>>>28<<2)>>2];g=b+1|0;if((g|0)<8){b=g;d=d+1280|0;e=f}else{break}}c[2385332]=f;return}function fqf(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a=c[2385452]|0;b=c[2385464]|0;d=b>>>0<320;e=c[2440380]|0;f=c[2415144]|0;g=0;h=c[2385332]|0;while(1){i=h+4|0;do{if((a+g|0)>>>0<=239){j=c[h>>2]|0;if(d){c[f>>2]=c[e+((j&15)<<2)>>2]}if((b+1|0)>>>0<320){c[f+4>>2]=c[e+((j>>>4&15)<<2)>>2]}if((b+2|0)>>>0<320){c[f+8>>2]=c[e+((j>>>8&15)<<2)>>2]}if((b+3|0)>>>0<320){c[f+12>>2]=c[e+((j>>>12&15)<<2)>>2]}if((b+4|0)>>>0<320){c[f+16>>2]=c[e+((j>>>16&15)<<2)>>2]}if((b+5|0)>>>0<320){c[f+20>>2]=c[e+((j>>>20&15)<<2)>>2]}if((b+6|0)>>>0<320){c[f+24>>2]=c[e+((j>>>24&15)<<2)>>2]}if((b+7|0)>>>0>=320){break}c[f+28>>2]=c[e+(j>>>28<<2)>>2]}}while(0);j=g+1|0;if((j|0)>=8){break}f=f+1280|0;g=j;h=i}c[2385332]=i;return}function fqg(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[2440380]|0;b=0;d=c[2415144]|0;e=c[2385332]|0;while(1){f=e+4|0;g=c[e>>2]|0;c[d+28>>2]=c[a+((g&15)<<2)>>2];c[d+24>>2]=c[a+((g>>>4&15)<<2)>>2];c[d+20>>2]=c[a+((g>>>8&15)<<2)>>2];c[d+16>>2]=c[a+((g>>>12&15)<<2)>>2];c[d+12>>2]=c[a+((g>>>16&15)<<2)>>2];c[d+8>>2]=c[a+((g>>>20&15)<<2)>>2];c[d+4>>2]=c[a+((g>>>24&15)<<2)>>2];c[d>>2]=c[a+(g>>>28<<2)>>2];g=b+1|0;if((g|0)<8){b=g;d=d+1280|0;e=f}else{break}}c[2385332]=f;return}function fqh(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a=c[2385452]|0;b=c[2385464]|0;d=(b+7|0)>>>0<320;e=c[2440380]|0;f=c[2415144]|0;g=0;h=c[2385332]|0;while(1){i=h+4|0;do{if((a+g|0)>>>0<=239){j=c[h>>2]|0;if(d){c[f+28>>2]=c[e+((j&15)<<2)>>2]}if((b+6|0)>>>0<320){c[f+24>>2]=c[e+((j>>>4&15)<<2)>>2]}if((b+5|0)>>>0<320){c[f+20>>2]=c[e+((j>>>8&15)<<2)>>2]}if((b+4|0)>>>0<320){c[f+16>>2]=c[e+((j>>>12&15)<<2)>>2]}if((b+3|0)>>>0<320){c[f+12>>2]=c[e+((j>>>16&15)<<2)>>2]}if((b+2|0)>>>0<320){c[f+8>>2]=c[e+((j>>>20&15)<<2)>>2]}if((b+1|0)>>>0<320){c[f+4>>2]=c[e+((j>>>24&15)<<2)>>2]}if(b>>>0>=320){break}c[f>>2]=c[e+(j>>>28<<2)>>2]}}while(0);j=g+1|0;if((j|0)>=8){break}f=f+1280|0;g=j;h=i}c[2385332]=i;return}function fqi(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[2440380]|0;b=7;d=(c[2415144]|0)+8960|0;e=c[2385332]|0;while(1){f=e+4|0;g=c[e>>2]|0;c[d>>2]=c[a+((g&15)<<2)>>2];c[d+4>>2]=c[a+((g>>>4&15)<<2)>>2];c[d+8>>2]=c[a+((g>>>8&15)<<2)>>2];c[d+12>>2]=c[a+((g>>>12&15)<<2)>>2];c[d+16>>2]=c[a+((g>>>16&15)<<2)>>2];c[d+20>>2]=c[a+((g>>>20&15)<<2)>>2];c[d+24>>2]=c[a+((g>>>24&15)<<2)>>2];c[d+28>>2]=c[a+(g>>>28<<2)>>2];if((b|0)>0){b=b-1|0;d=d-1280|0;e=f}else{break}}c[2385332]=f;return}function fqj(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a=c[2385452]|0;b=c[2385464]|0;d=b>>>0<320;e=c[2440380]|0;f=(c[2415144]|0)+8960|0;g=7;h=c[2385332]|0;while(1){i=h+4|0;do{if((a+g|0)>>>0<=239){j=c[h>>2]|0;if(d){c[f>>2]=c[e+((j&15)<<2)>>2]}if((b+1|0)>>>0<320){c[f+4>>2]=c[e+((j>>>4&15)<<2)>>2]}if((b+2|0)>>>0<320){c[f+8>>2]=c[e+((j>>>8&15)<<2)>>2]}if((b+3|0)>>>0<320){c[f+12>>2]=c[e+((j>>>12&15)<<2)>>2]}if((b+4|0)>>>0<320){c[f+16>>2]=c[e+((j>>>16&15)<<2)>>2]}if((b+5|0)>>>0<320){c[f+20>>2]=c[e+((j>>>20&15)<<2)>>2]}if((b+6|0)>>>0<320){c[f+24>>2]=c[e+((j>>>24&15)<<2)>>2]}if((b+7|0)>>>0>=320){break}c[f+28>>2]=c[e+(j>>>28<<2)>>2]}}while(0);if((g|0)<=0){break}f=f-1280|0;g=g-1|0;h=i}c[2385332]=i;return}function fqk(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[2440380]|0;b=7;d=(c[2415144]|0)+8960|0;e=c[2385332]|0;while(1){f=e+4|0;g=c[e>>2]|0;c[d+28>>2]=c[a+((g&15)<<2)>>2];c[d+24>>2]=c[a+((g>>>4&15)<<2)>>2];c[d+20>>2]=c[a+((g>>>8&15)<<2)>>2];c[d+16>>2]=c[a+((g>>>12&15)<<2)>>2];c[d+12>>2]=c[a+((g>>>16&15)<<2)>>2];c[d+8>>2]=c[a+((g>>>20&15)<<2)>>2];c[d+4>>2]=c[a+((g>>>24&15)<<2)>>2];c[d>>2]=c[a+(g>>>28<<2)>>2];if((b|0)>0){b=b-1|0;d=d-1280|0;e=f}else{break}}c[2385332]=f;return}function fql(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a=c[2385452]|0;b=c[2385464]|0;d=(b+7|0)>>>0<320;e=c[2440380]|0;f=(c[2415144]|0)+8960|0;g=7;h=c[2385332]|0;while(1){i=h+4|0;do{if((a+g|0)>>>0<=239){j=c[h>>2]|0;if(d){c[f+28>>2]=c[e+((j&15)<<2)>>2]}if((b+6|0)>>>0<320){c[f+24>>2]=c[e+((j>>>4&15)<<2)>>2]}if((b+5|0)>>>0<320){c[f+20>>2]=c[e+((j>>>8&15)<<2)>>2]}if((b+4|0)>>>0<320){c[f+16>>2]=c[e+((j>>>12&15)<<2)>>2]}if((b+3|0)>>>0<320){c[f+12>>2]=c[e+((j>>>16&15)<<2)>>2]}if((b+2|0)>>>0<320){c[f+8>>2]=c[e+((j>>>20&15)<<2)>>2]}if((b+1|0)>>>0<320){c[f+4>>2]=c[e+((j>>>24&15)<<2)>>2]}if(b>>>0>=320){break}c[f>>2]=c[e+(j>>>28<<2)>>2]}}while(0);if((g|0)<=0){break}f=f-1280|0;g=g-1|0;h=i}c[2385332]=i;return}function fqm(b){b=b|0;var d=0,e=0;do{if((b&16711680|0)==2162688){d=a[(c[2405156]|0)+(b>>>1&32767)|0]|0}else{if((b|0)==2097177){d=a[9625450]|0;break}else if((b|0)==3145741){e=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;if((e|0)>=(c[2113018]|0)){d=1;break}d=e>>>31&255;break}else if((b|0)==2097173){d=a[9625449]|0;break}else if((b|0)==2097169){d=a[9625448]|0;break}else{d=0;break}}}while(0);return d|0}function fqn(a){a=a|0;var e=0,f=0,g=0;do{if((a&16711680|0)==2162688){e=d[(c[2405156]|0)+(a>>>1&32767)|0]|0}else{if((a|0)==2097172){e=d[9625449]|0;break}else if((a|0)==3145734){e=b[(c[3541508]|0)+2>>1]|0;break}else if((a|0)==7340032){f=(c[2384552]|0)+1|0;c[2384552]=f;g=f&255;if((f&1|0)==0){e=(g^65535)&65535;break}e=(g^255)&65535;break}else if((a|0)==2097176){e=d[9625450]|0;break}else if((a|0)==5242886){e=b[(c[3541509]|0)+2>>1]|0;break}else if((a|0)==3145732){e=b[c[3541508]>>1]|0;break}else if((a|0)==5242884){e=b[c[3541509]>>1]|0;break}else if((a|0)==2097168){e=d[9625448]|0;break}else if((a|0)==3145740){g=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;if((g|0)>=(c[2113018]|0)){e=1;break}e=g>>>31&65535;break}else{e=0;break}}}while(0);return e|0}function fqo(b,d){b=b|0;d=d|0;if((b&16711680|0)==2162688){a[(c[2405156]|0)+(b>>>1&32767)|0]=d;return}if((b-2097180|0)>>>0>=2){return}do{if((c[2385200]|0)==0){if((d&32)!=0){break}b=c[(c[3531864]|0)+8>>2]|0;gD[b&8191]()|0}}while(0);c[2385200]=d&32^32;return}function fqp(d,e){d=d|0;e=e|0;var f=0,g=0;f=i;if((d&16711680|0)==2162688){a[(c[2405156]|0)+(d>>>1&32767)|0]=e&255;i=f;return}if((d|0)==3145728){c[3541508]=(c[3541506]|0)+((e&65535)<<1&16382);i=f;return}else if((d|0)==5242884){b[c[3541509]>>1]=e;c[3541509]=(c[3541509]|0)+2;i=f;return}else if((d|0)==3145734){b[c[3541508]>>1]=e;c[3541508]=(c[3541508]|0)+2;i=f;return}else if((d|0)==5242888){c[3541499]=e&255;i=f;return}else if((d|0)==3145736){c[3541498]=e&255;i=f;return}else if((d|0)==5242892){b[(c[3541501]|0)+(c[3541499]<<1)>>1]=e;i=f;return}else if((d|0)==5242886){b[c[3541509]>>1]=e;c[3541509]=(c[3541509]|0)+2;i=f;return}else if((d|0)==5242880){c[3541509]=(c[3541504]|0)+((e&65535)<<1&16382);i=f;return}else if((d|0)==3145732){b[c[3541508]>>1]=e;c[3541508]=(c[3541508]|0)+2;i=f;return}else if((d|0)==3145740){b[(c[3541500]|0)+(c[3541498]<<1)>>1]=e;i=f;return}else{bw(171448,(g=i,i=i+16|0,c[g>>2]=e&65535,c[g+8>>2]=d,g)|0)|0;i=g;i=f;return}}function fqq(b,d){b=b|0;d=d|0;if((b|0)==4){Uv(0,d);return}else if((b|0)==0){c[2113304]=d&255;return}else if((b|0)==1){b=c[2113304]|0;a[14168504+b|0]=d;mv(0,b,d&255);return}else{return}}function fqr(a){a=a|0;var b=0;if((a|0)==1){b=c[(c[3531464]|0)+4240>>2]&255}else if((a|0)==4){b=c[2113156]&255}else{b=0}return b|0}function fqs(b){b=b|0;var c=0;if((b|0)==65536){c=~a[9625451]}else if((b|0)==65542){c=~a[9625452]}else if((b|0)==65538){c=~a[9625453]}else{c=0}return c|0}function fqt(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>5){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4735580+(b*112|0)>>2];c[a+104>>2]=c[4735584+(b*112|0)>>2];c[a+108>>2]=c[4735588+(b*112|0)>>2];d=0;return d|0}function fqu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<6&(d|0)==0)){e=1;return e|0}c[a>>2]=4735480+(b*112|0);e=0;return e|0}function fqv(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1562904+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function fqw(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=10){if((a|0)==0){d=0;return d|0}e=a;f=716304+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}f=b-11|0;if(f>>>0>70){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;a=4736152+(f*12|0)|0;c[b>>2]=c[a>>2];c[b+4>>2]=c[a+4>>2];c[b+8>>2]=c[a+8>>2];d=0;return d|0}function fqx(){var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;b=i;i=i+240|0;d=b|0;e=b+112|0;f=b+120|0;g=b+232|0;c[2113208]=2097152;c[2113209]=4194304;c[2426646]=0;c[2418114]=0;c[3541502]=524288;c[3541503]=2621440;c[3541206]=6815744;c[2405584]=7077888;c[2418228]=7077888;c[2405156]=7094272;c[2411396]=7159808;c[3541506]=7163904;c[3541504]=7180288;c[3541500]=7196672;c[3541501]=7197184;c[2411490]=7197696;c[3531916]=7197696;j=0;while(1){if((j|0)>=1024){break}k=9638528+(j<<2)|0;if((c[k>>2]|0)==0){l=65448;break}else{j=j+1|0}}do{if((l|0)==65448){j=gGq(7205888)|0;c[k>>2]=j;if((j|0)==0){break}c[2426646]=j;gGz(j|0,0,7205888);c[2418114]=j;c[3541502]=j+524288;m=(c[2113208]|0)+524288|0;c[3541503]=j+m;n=m+(c[2113209]|0)|0;c[3541206]=j+n;m=j+(n+262144)|0;c[2405584]=m;c[2418228]=m;c[2405156]=j+(n+278528);c[2411396]=j+(n+344064);c[3541506]=j+(n+348160);c[3541504]=j+(n+364544);c[3541500]=j+(n+380928);c[3541501]=j+(n+381440);m=j+(n+381952)|0;c[2411490]=m;c[3531916]=m;c[2414030]=j+(n+390144);do{if((c[3542200]|0)!=0){n=f+108|0;c[n>>2]=0;m=f+100|0;c[m>>2]=0;o=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[o&16383](f,0)|0;if((c[n>>2]|0)==0){break}n=c[m>>2]|0;c[g>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](g,0,0)|0;if((n|0)<1){break}gzL(j,0,0)|0}}while(0);fpl(c[3541502]|0,1,2,c[2113208]|0,1);fpl(c[3541503]|0,3,2,c[2113209]|0,1);j=c[3541206]|0;do{if((c[3542200]|0)!=0){n=d+108|0;c[n>>2]=0;m=d+100|0;c[m>>2]=0;o=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[o&16383](d,5)|0;if((c[n>>2]|0)==0){break}n=c[m>>2]|0;c[e>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](e,5,0)|0;if((n|0)<1){break}gzL(j,0,5)|0}}while(0);fxU(0,425984);if((c[2394]|0)==0){p=c[2112932]|0}else{c[2394]=0;j=c[3532596]|0;c[2112932]=j;n=c[3532592]|0;if((n|0)!=0){gGC(9104152,n|0,280)|0}c[2113054]=c[2113060];p=j}j=c[2418114]|0;n=p|0;m=0;while(1){o=j+m|0;c[n>>2]=o;c[n+131072>>2]=o;o=m+1024|0;if(o>>>0>524287){break}else{n=n+4|0;m=o}}m=c[2418228]|0;c[p+4096>>2]=m;c[p+69632>>2]=m;c[p+135168>>2]=m;n=m+1024|0;c[p+4100>>2]=n;c[p+69636>>2]=n;c[p+135172>>2]=n;n=m+2048|0;c[p+4104>>2]=n;c[p+69640>>2]=n;c[p+135176>>2]=n;n=m+3072|0;c[p+4108>>2]=n;c[p+69644>>2]=n;c[p+135180>>2]=n;n=m+4096|0;c[p+4112>>2]=n;c[p+69648>>2]=n;c[p+135184>>2]=n;n=m+5120|0;c[p+4116>>2]=n;c[p+69652>>2]=n;c[p+135188>>2]=n;n=m+6144|0;c[p+4120>>2]=n;c[p+69656>>2]=n;c[p+135192>>2]=n;n=m+7168|0;c[p+4124>>2]=n;c[p+69660>>2]=n;c[p+135196>>2]=n;n=m+8192|0;c[p+4128>>2]=n;c[p+69664>>2]=n;c[p+135200>>2]=n;n=m+9216|0;c[p+4132>>2]=n;c[p+69668>>2]=n;c[p+135204>>2]=n;n=m+10240|0;c[p+4136>>2]=n;c[p+69672>>2]=n;c[p+135208>>2]=n;n=m+11264|0;c[p+4140>>2]=n;c[p+69676>>2]=n;c[p+135212>>2]=n;n=m+12288|0;c[p+4144>>2]=n;c[p+69680>>2]=n;c[p+135216>>2]=n;n=m+13312|0;c[p+4148>>2]=n;c[p+69684>>2]=n;c[p+135220>>2]=n;n=m+14336|0;c[p+4152>>2]=n;c[p+69688>>2]=n;c[p+135224>>2]=n;n=m+15360|0;c[p+4156>>2]=n;c[p+69692>>2]=n;c[p+135228>>2]=n;n=c[2411396]|0;c[p+16384>>2]=n;c[p+81920>>2]=n;c[p+147456>>2]=n;m=n+1024|0;c[p+16388>>2]=m;c[p+81924>>2]=m;c[p+147460>>2]=m;m=n+2048|0;c[p+16392>>2]=m;c[p+81928>>2]=m;c[p+147464>>2]=m;m=n+3072|0;c[p+16396>>2]=m;c[p+81932>>2]=m;c[p+147468>>2]=m;c[p+196688>>2]=690;c[p+196608>>2]=2440;c[p+196728>>2]=1618;c[p+196648>>2]=664;m=c[3532592]|0;if((m|0)!=0){gGC(m|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fyz(0,65552,125e5);c[1836234]=0;m=c[2439374]|0;c[3531864]=m;gf[c[m>>2]&2047](0);m=c[2405156]|0;n=c[3531864]|0;j=524288;do{o=j>>11;q=(j|32767)+2047>>11;if((o|0)<(q|0)){r=m+(-j|0)|0;s=o;while(1){c[n+44+(s<<2)>>2]=r;t=s+1|0;if((t|0)<(q|0)){s=t}else{u=o;break}}while(1){c[n+2092+(u<<2)>>2]=r;s=u+1|0;if((s|0)<(q|0)){u=s}else{v=o;break}}do{c[n+4140+(v<<2)>>2]=r;c[n+6188+(v<<2)>>2]=r;v=v+1|0;}while((v|0)<(q|0))}j=j+32768|0;}while((j|0)<1048576);c[n+8236>>2]=2772;c[n+8240>>2]=3006;c[n+8244>>2]=2862;j=c[n+20>>2]|0;if((j|0)==0){w=n}else{gf[j&2047](688816);w=c[3531864]|0}c[1836234]=-1;gu[c[w+4>>2]&16383]();c[3531864]=0;j=a[9680]|0;m=j?32e3:0;if(j){if(a[9624]|0){j=m*3|0;q=52734;while(1){if((q|0)>(j|0)){q=q>>1}else{x=1222;y=q;break}}}else{x=2462;y=m}c[2429380]=y;c[3542124]=x;mw(3375e3,y);q=gGq(262144)|0;c[2406684]=q;gGz(q|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(3375e3,11025)}h[745421]=.5;c[2436794]=3;h[745420]=.5;c[2436792]=3;Ux(0,7891,1);c[2407030]=128;c[2407068]=3;a[9552]=1;c[2113040]=1;c[2113182]=-470;c[2113178]=-472;c[2113174]=-474;fl6(2);c[2113016]=2048;c[3531920]=c[2411396];a[7072608]=1;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];q=c[3532592]|0;if((q|0)!=0){gGC(9104152,q|0,280)|0}c[2113054]=c[2113060]}RI();q=c[2394]|0;j=c[14130368+(q<<2)>>2]|0;if((j|0)!=0){gGC(j|0,9104152,280)|0}c[8452240+(q<<2)>>2]=c[2113054];c[2394]=-1;c[1836234]=0;q=c[2439374]|0;c[3531864]=q;gf[c[q>>2]&2047](0);gD[c[(c[3531864]|0)+8>>2]&8191]()|0;c[1836234]=-1;gu[c[(c[3531864]|0)+4>>2]&16383]();c[3531864]=0;mx(0);c[2113156]=0;a[9628264]=0;c[2407033]=0;q=c[3541206]|0;c[3541190]=q;c[3541198]=q;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=q+256;c[3541199]=q+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=q+512;c[3541200]=q+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=q+768;c[3541201]=q+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2385200]=1;z=0;i=b;return z|0}}while(0);c[2426646]=0;z=1;i=b;return z|0}function fqy(){var a=0,b=0,d=0,e=0,f=0;a=c[3531464]|0;c[a+44344>>2]=0;c[a+44348>>2]=0;if((a|0)!=0){gGr(a);c[3531464]=0}a=c[2406684]|0;if((a|0)!=0){gGr(a);c[2406684]=0}Uw(0);fl7();if((c[2392]|0)>=0){a=0;do{b=14130368+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}b=14130384+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}a=a+1|0;}while((a|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;fyA();a=c[2426646]|0;b=0;while(1){if((b|0)>=1024){e=65507;break}f=9638528+(b<<2)|0;if((c[f>>2]|0)==(a|0)){break}else{b=b+1|0}}if((e|0)==65507){c[2426646]=0;c[3541206]=0;return 0}gGr(a);c[f>>2]=0;c[2426646]=0;c[3541206]=0;return 0}function fqz(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((a[9623520]|0)!=0){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];b=c[3532592]|0;if((b|0)!=0){gGC(9104152,b|0,280)|0}c[2113054]=c[2113060]}RI();b=c[2394]|0;d=c[14130368+(b<<2)>>2]|0;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[8452240+(b<<2)>>2]=c[2113054];c[2394]=-1;c[1836234]=0;b=c[2439374]|0;c[3531864]=b;gf[c[b>>2]&2047](0);b=c[(c[3531864]|0)+8>>2]|0;gD[b&8191]()|0;c[1836234]=-1;gu[c[(c[3531864]|0)+4>>2]&16383]();c[3531864]=0;mx(0);c[2113156]=0;a[9628264]=0;c[2407033]=0;b=c[3541206]|0;c[3541190]=b;c[3541198]=b;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=b+256;c[3541199]=b+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=b+512;c[3541200]=b+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=b+768;c[3541201]=b+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2385200]=1}a[9625448]=0;a[9625449]=0;a[9625450]=0;b=0;d=0;e=0;f=0;do{d=((a[9632552+b|0]&1)<<b|d&255)&255;e=((a[9630456+b|0]&1)<<b|e&255)&255;f=((a[9551672+b|0]&1)<<b|f&255)&255;b=b+1|0;}while((b|0)<8);a[9625448]=d;a[9625449]=e;a[9625450]=f;if((d&3)==3){f=d&-4;a[9625448]=f;g=f}else{g=d}if((g&12)==12){a[9625448]=g&-13}if((e&3)==3){g=e&-4;a[9625449]=g;h=g}else{h=e}if((h&12)==12){a[9625449]=h&-13}h=c[2392]|0;if((h|0)>=0){gGz(8452240,0,((h|0)>0?(h<<2)+4|0:4)|0)}c[2113054]=0;c[2409128]=0;c[2409245]=0;c[2409362]=0;c[2409479]=0;c[2409508]=0;c[2409537]=0;c[2409566]=0;c[2409595]=0;h=c[2438]|0;e=h;g=(h|0)<0|0?-1:0;h=gGU(e,g,16e6,0)|0;d=gGS(h,K,15360,0)|0;h=d;c[2113218]=h;d=gGU(e,g,625e4,0)|0;g=gGS(d,K,15360,0)|0;c[2113216]=g;c[2113220]=0;c[2113221]=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060]}c[2113058]=(h|0)/262|0;c[2113018]=h-((h*22|0|0)/262|0);a[670608]=0;c[1836234]=0;h=c[2439374]|0;c[3531864]=h;gf[c[h>>2]&2047](0);h=0;g=0;L85536:while(1){d=g;do{if((d|0)>=10){break L85536}d=d+1|0;e=(ag(c[2113218]|0,d)|0)/10|0;do{if(!(a[670608]|0)){f=c[2113018]|0;if((e|0)<=(f|0)){break}b=c[2113220]|0;if((b|0)<(f|0)){i=f-b|0;c[2113056]=i;b=RG(i)|0;c[2113054]=(c[2113054]|0)+b;c[2276108]=-1;c[2113056]=-1;c[2113220]=(c[2113220]|0)+b}b=c[2430398]|0;i=c[2439196]|0;f=i<<11;c[2438976]=b+f;j=(c[2440572]|0)>1;if(j){c[2438977]=(c[2430399]|0)+f}f=i^1;c[2439196]=f;i=f<<11;f=b+i|0;b=(c[3541506]|0)+12288|0;gGC(f|0,b|0,2048)|0;if(j){j=(c[2430399]|0)+i|0;i=(c[3541504]|0)+12288|0;gGC(j|0,i|0,2048)|0}a[670608]=1;c[8452200+(c[2394]<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0>=1024){break}RH(4)}}while(0);i=e-(c[2113220]|0)|0;c[2113056]=i;j=RG(i)|0;c[2113054]=(c[2113054]|0)+j;c[2276108]=-1;c[2113056]=-1;c[2113220]=(c[2113220]|0)+j;j=c[2113216]|0;i=(j|0)/10|0;if((c[2385200]|0)==0){if((j|0)<10){k=0}else{k=gj[c[(c[3531864]|0)+12>>2]&4095](i)|0}l=(c[2113221]|0)+k|0}else{l=(c[2113221]|0)+i|0}c[2113221]=l;m=c[2112964]|0;}while((m|0)==0);i=a[9688]|0?53:0;j=m+(h<<1<<1)|0;gg[c[3542124]&4095](j,i);Uu(0,j,i);h=i+h|0;g=d}g=c[2112964]|0;do{if((g|0)!=0){m=a[9688]|0?534:0;l=m-h|0;if((m|0)==(h|0)){break}m=g+(h<<1<<1)|0;gg[c[3542124]&4095](m,l);Uu(0,m,l)}}while(0);c[1836234]=-1;gu[c[(c[3531864]|0)+4>>2]&16383]();c[3531864]=0;h=c[2394]|0;g=c[14130368+(h<<2)>>2]|0;if((g|0)!=0){gGC(g|0,9104152,280)|0}c[8452240+(h<<2)>>2]=c[2113054];c[2394]=-1;h=c[2112968]|0;if((h|0)==0){return 0}g=c[3531916]|0;l=c[2113308]|0;do{if((c[g>>2]|0)==0){gGz(h|0,0,l*76800|0|0)}else{if((l|0)==4){m=c[g+1152>>2]|0;k=0;i=h;while(1){c[i>>2]=m;c[i+4>>2]=m;c[i+8>>2]=m;c[i+12>>2]=m;c[i+16>>2]=m;c[i+20>>2]=m;c[i+24>>2]=m;c[i+28>>2]=m;j=k+1|0;if((j|0)<9600){k=j;i=i+32|0}else{break}}}else if((l|0)==2){i=c[g+1152>>2]|0;k=i<<16|i;i=h;m=0;while(1){c[i>>2]=k;c[i+4>>2]=k;c[i+8>>2]=k;c[i+12>>2]=k;c[i+16>>2]=k;c[i+20>>2]=k;c[i+24>>2]=k;c[i+28>>2]=k;d=m+1|0;if((d|0)<4800){i=i+32|0;m=d}else{break}}}else if((l|0)==3){m=c[g+1152>>2]|0;i=m>>>8&255;k=m>>>16&255;d=m&255;m=h;j=0;while(1){a[m]=d;a[m+1|0]=i;a[m+2|0]=k;b=j+1|0;if((b|0)<76800){m=m+3|0;j=b}else{break}}}else{break}}}while(0);if(a[7072608]|0){c[2112970]=h;c[2113306]=l;c[2113298]=c[2113300];fl3();n=c[3531916]|0}else{n=g}c[2112966]=n;g=c[2113016]|0;if((g|0)>0){o=0}else{return 0}do{c[n+(o<<2)>>2]=65535;o=o+1|0;}while((o|0)<(g|0));return 0}function fqA(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=c[3531916]|0;do{if((c[b>>2]|0)==0){d=c[2113308]|0;gGz(c[2112968]|0,0,d*76800|0|0);e=d}else{d=c[2113308]|0;if((d|0)==4){f=c[b+1152>>2]|0;g=0;h=c[2112968]|0;while(1){c[h>>2]=f;c[h+4>>2]=f;c[h+8>>2]=f;c[h+12>>2]=f;c[h+16>>2]=f;c[h+20>>2]=f;c[h+24>>2]=f;c[h+28>>2]=f;i=g+1|0;if((i|0)<9600){g=i;h=h+32|0}else{e=4;break}}}else if((d|0)==2){h=c[b+1152>>2]|0;g=h<<16|h;h=c[2112968]|0;f=0;while(1){c[h>>2]=g;c[h+4>>2]=g;c[h+8>>2]=g;c[h+12>>2]=g;c[h+16>>2]=g;c[h+20>>2]=g;c[h+24>>2]=g;c[h+28>>2]=g;i=f+1|0;if((i|0)<4800){h=h+32|0;f=i}else{e=2;break}}}else if((d|0)==3){f=c[b+1152>>2]|0;h=f>>>8&255;g=f>>>16&255;i=f&255;f=c[2112968]|0;j=0;while(1){a[f]=i;a[f+1|0]=h;a[f+2|0]=g;k=j+1|0;if((k|0)<76800){f=f+3|0;j=k}else{e=3;break}}}else{e=d;break}}}while(0);if(a[7072608]|0){c[2112970]=c[2112968];c[2113306]=e;c[2113298]=c[2113300];fl3();l=c[3531916]|0}else{l=b}c[2112966]=l;b=c[2113016]|0;if((b|0)>0){m=0}else{return 0}do{c[l+(m<<2)>>2]=65535;m=m+1|0;}while((m|0)<(b|0));return 0}function fqB(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;f=i;i=i+160|0;g=f|0;h=f+16|0;j=f+32|0;k=f+48|0;l=f+64|0;m=f+80|0;n=f+96|0;o=f+112|0;p=f+128|0;q=f+144|0;r=(e|0)==0;if(!r){c[e>>2]=133527}if((b&96|0)==0){i=f;return 0}gGz(q|0,0,12);s=c[2405584]|0;c[q>>2]=s;c[q+4>>2]=(c[2411490]|0)-s;c[q+12>>2]=162152;gj[c[2076592]&4095](q)|0;q=p|0;do{if((b&64|0)!=0){gGz(o|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){s=p+9|0;t=n;u=n|0;v=n+4|0;w=n+12|0;x=o|0;y=o+4|0;z=o+12|0;A=0;do{gGC(q|0,614896,11)|0;a[s]=A+48&255;B=8452256+(A<<2)|0;gGz(t|0,0,12);c[u>>2]=B;c[v>>2]=4;c[w>>2]=164976;gj[c[2076592]&4095](n)|0;if((c[B>>2]|0)!=0){c[x>>2]=c[14130368+(A<<2)>>2];c[y>>2]=c[8452184+(A<<2)>>2];c[z>>2]=q;B=c[2076592]|0;gj[B&4095](o)|0}A=A+1|0;}while((A|0)<=(c[2392]|0))}A=c[2385546]|0;if((A|0)>0){z=0;y=A;while(1){A=c[(c[9757496+(z<<2)>>2]|0)+32>>2]|0;if((A|0)==0){C=y}else{gg[A&4095](z,b);C=c[2385546]|0}A=z+1|0;if((A|0)<(C|0)){z=A;y=C}else{break}}}gGz(m|0,0,12);c[m>>2]=8453216;c[m+4>>2]=4;c[m+12>>2]=107480;y=c[2076592]|0;gj[y&4095](m)|0;gGz(l|0,0,12);c[l>>2]=14168504;c[l+4>>2]=256;c[l+12>>2]=476464;y=c[2076592]|0;gj[y&4095](l)|0;if((b&2|0)==0){break}else{D=0}do{mv(0,D,d[14168504+D|0]|0);D=D+1|0;}while((D|0)<256)}}while(0);Ut(0);if(!r){c[e>>2]=169110}gGz(k|0,0,12);c[k>>2]=9756784;c[k+4>>2]=4;c[k+12>>2]=175504;gj[c[2076592]&4095](k)|0;gGz(j|0,0,12);c[j>>2]=14166032;c[j+4>>2]=8;c[j+12>>2]=504552;gj[c[2076592]&4095](j)|0;gGz(h|0,0,12);c[h>>2]=14165992;c[h+4>>2]=8;c[h+12>>2]=388736;gj[c[2076592]&4095](h)|0;gGz(g|0,0,12);c[g>>2]=14165960;c[g+4>>2]=32;c[g+12>>2]=302352;gj[c[2076592]&4095](g)|0;i=f;return 0}function fqC(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>5){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2931172+(b*112|0)>>2];c[a+104>>2]=c[2931176+(b*112|0)>>2];c[a+108>>2]=c[2931180+(b*112|0)>>2];d=0;return d|0}function fqD(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<6&(d|0)==0)){e=1;return e|0}c[a>>2]=2931072+(b*112|0);e=0;return e|0}function fqE(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=10){if((a|0)==0){d=0;return d|0}e=a;f=698848+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}f=b-11|0;if(f>>>0>70){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;a=4736152+(f*12|0)|0;c[b>>2]=c[a>>2];c[b+4>>2]=c[a+4>>2];c[b+8>>2]=c[a+8>>2];d=0;return d|0}function fqF(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>5){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2930500+(b*112|0)>>2];c[a+104>>2]=c[2930504+(b*112|0)>>2];c[a+108>>2]=c[2930508+(b*112|0)>>2];d=0;return d|0}function fqG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<6&(d|0)==0)){e=1;return e|0}c[a>>2]=2930400+(b*112|0);e=0;return e|0}function fqH(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=13){if((a|0)==0){d=0;return d|0}e=a;f=698680+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}f=b-14|0;if(f>>>0>70){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;a=4736152+(f*12|0)|0;c[b>>2]=c[a>>2];c[b+4>>2]=c[a+4>>2];c[b+8>>2]=c[a+8>>2];d=0;return d|0}function fqI(b){b=b|0;var d=0,e=0;do{if((b|0)==7340057){d=a[9625447]|0}else if((b|0)==7340037){d=a[9625443]|0}else if((b|0)==7340032){d=a[9625445]|0}else if((b|0)==7340045){d=a[9625440]|0}else if((b|0)==7340053){d=a[9625446]|0}else if((b|0)==7340049){d=a[9625441]|0}else if((b|0)==7340061){d=a[9625442]|0}else if((b|0)==6291457){d=c[2113156]&255}else if((b|0)==5242883){d=c[(c[3531464]|0)+4240>>2]&255}else if((b|0)==7340041){d=a[9625444]|0}else if((b|0)==3145741){e=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;if((e|0)>=(c[2113018]|0)){d=1;break}d=e>>>31&255}else{d=0}}while(0);return d|0}function fqJ(a){a=a|0;var e=0,f=0;do{if((a|0)==3145732){e=b[c[3541508]>>1]|0}else if((a|0)==7340056){e=d[9625447]|0}else if((a|0)==7340060){e=d[9625442]|0}else if((a|0)==7340036){e=d[9625443]|0}else if((a|0)==7340040){e=d[9625444]|0}else if((a|0)==3145734){e=b[(c[3541508]|0)+2>>1]|0}else if((a|0)==3145740){f=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;if((f|0)>=(c[2113018]|0)){e=1;break}e=f>>>31&65535}else if((a|0)==5242882){e=c[(c[3531464]|0)+4240>>2]&65535}else if((a|0)==6291456){e=c[2113156]&65535}else if((a|0)==7340052){e=d[9625446]|0}else if((a|0)==7340044){e=d[9625440]|0}else if((a|0)==7340048){e=d[9625441]|0}else{e=0}}while(0);return e|0}function fqK(b,d){b=b|0;d=d|0;var e=0;if((b|0)==5242883){e=c[2113304]|0;a[14168504+e|0]=d;mv(0,e,d&255);return}else if((b|0)==5242881){c[2113304]=d&255;return}else if((b|0)==6291457){Uv(0,d);return}else{return}}function fqL(d,e){d=d|0;e=e|0;var f=0,g=0,h=0;if((d|0)==6291456){Uv(0,e&255);return}else if((d|0)==7340080){f=(e&65535)<<18&262144;g=c[3541206]|0;h=g+f|0;c[3541190]=h;c[3541198]=h;c[3541191]=g+(f|256);c[3541199]=g+(f|65536);c[3541192]=g+(f|512);c[3541200]=g+(f|131072);c[3541193]=g+(f|768);c[3541201]=g+(f|196608);return}else if((d|0)==3145732|(d|0)==3145734){b[c[3541508]>>1]=e;c[3541508]=(c[3541508]|0)+2;return}else if((d|0)==3145728){c[3541508]=(c[3541506]|0)+((e&65535)<<1&16382);return}else if((d|0)==5242880){c[2113304]=e&255;return}else if((d|0)==3145740){b[(c[3541500]|0)+(c[3541498]<<1)>>1]=e;return}else if((d|0)==5242882){f=c[2113304]|0;a[14168504+f|0]=e&255;mv(0,f,e&255);return}else if((d|0)==3145736){c[3541498]=e&255;return}else{return}}function fqM(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>5){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2256988+(b*112|0)>>2];c[a+104>>2]=c[2256992+(b*112|0)>>2];c[a+108>>2]=c[2256996+(b*112|0)>>2];d=0;return d|0}function fqN(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<6&(d|0)==0)){e=1;return e|0}c[a>>2]=2256888+(b*112|0);e=0;return e|0}function fqO(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>34){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1006608+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function fqP(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>82){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=2257560+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fqQ(){var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=i;i=i+240|0;d=b|0;e=b+112|0;f=b+120|0;g=b+232|0;c[2113208]=4194304;c[2426644]=0;c[2418112]=0;c[3541502]=524288;c[3541206]=4718592;c[2405582]=5242880;c[2418226]=5242880;c[2411394]=5308416;c[3541506]=5312512;c[3541500]=5328896;c[2411488]=5329408;c[3531916]=5329408;j=0;while(1){if((j|0)>=1024){break}k=9638528+(j<<2)|0;if((c[k>>2]|0)==0){l=65747;break}else{j=j+1|0}}do{if((l|0)==65747){j=gGq(5337600)|0;c[k>>2]=j;if((j|0)==0){break}c[2426644]=j;gGz(j|0,0,5337600);c[2418112]=j;c[3541502]=j+524288;m=c[2113208]|0;c[3541206]=j+(m+524288);n=j+(m+1048576)|0;c[2405582]=n;c[2418226]=n;c[2411394]=j+(m+1114112);c[3541506]=j+(m+1118208);c[3541500]=j+(m+1134592);n=j+(m+1135104)|0;c[2411488]=n;c[3531916]=n;c[2414028]=j+(m+1143296);do{if((c[3542200]|0)!=0){m=f+108|0;c[m>>2]=0;n=f+100|0;c[n>>2]=0;o=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[o&16383](f,0)|0;if((c[m>>2]|0)==0){break}m=c[n>>2]|0;c[g>>2]=9534384;n=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[n&16383](g,0,0)|0;if((m|0)<1){break}gzL(j,0,0)|0}}while(0);fpl(c[3541502]|0,1,4,c[2113208]|0,0);j=c[3541206]|0;do{if((c[3542200]|0)!=0){m=d+108|0;c[m>>2]=0;n=d+100|0;c[n>>2]=0;o=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[o&16383](d,5)|0;if((c[m>>2]|0)==0){break}m=c[n>>2]|0;c[e>>2]=9534384;n=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[n&16383](e,5,0)|0;if((m|0)<1){break}gzL(j,0,5)|0}}while(0);fxU(0,425984);if((c[2394]|0)==0){p=c[2112932]|0}else{c[2394]=0;j=c[3532596]|0;c[2112932]=j;m=c[3532592]|0;if((m|0)!=0){gGC(9104152,m|0,280)|0}c[2113054]=c[2113060];p=j}j=c[2418112]|0;m=p|0;n=0;while(1){o=j+n|0;c[m>>2]=o;c[m+131072>>2]=o;o=n+1024|0;if(o>>>0>524287){break}else{m=m+4|0;n=o}}n=c[2418226]|0;m=p+4096|0;j=1048576;while(1){o=n+(j-1048576)|0;c[m>>2]=o;c[m+65536>>2]=o;c[m+131072>>2]=o;o=j+1024|0;if(o>>>0>1114111){break}else{m=m+4|0;j=o}}j=c[2411394]|0;c[p+16384>>2]=j;c[p+81920>>2]=j;c[p+147456>>2]=j;m=j+1024|0;c[p+16388>>2]=m;c[p+81924>>2]=m;c[p+147460>>2]=m;m=j+2048|0;c[p+16392>>2]=m;c[p+81928>>2]=m;c[p+147464>>2]=m;m=j+3072|0;c[p+16396>>2]=m;c[p+81932>>2]=m;c[p+147468>>2]=m;c[p+196688>>2]=1112;c[p+196608>>2]=2322;c[p+196728>>2]=2252;c[p+196648>>2]=2478;m=c[3532592]|0;if((m|0)!=0){gGC(m|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;c[2113182]=-470;c[2113178]=-472;c[2113174]=-474;c[2113040]=17;fl6(1);c[2113016]=2048;c[3531920]=c[2411394];m=a[9680]|0;j=m?32e3:0;if(m){if(a[9624]|0){m=j*3|0;n=52734;while(1){if((n|0)>(m|0)){n=n>>1}else{q=1222;r=n;break}}}else{q=2462;r=j}c[2429380]=r;c[3542124]=q;mw(3375e3,r);n=gGq(262144)|0;c[2406684]=n;gGz(n|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(3375e3,11025)}h[745421]=1.0;c[2436794]=3;h[745420]=1.0;c[2436792]=3;Ux(0,20454,1);c[2407030]=256;c[2407068]=3;a[7072600]=1;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];n=c[3532592]|0;if((n|0)!=0){gGC(9104152,n|0,280)|0}c[2113054]=c[2113060]}RI();n=c[2394]|0;m=c[14130368+(n<<2)>>2]|0;if((m|0)!=0){gGC(m|0,9104152,280)|0}c[8452240+(n<<2)>>2]=c[2113054];c[2394]=-1;c[2113156]=0;a[9628264]=0;c[2407033]=0;n=c[3541206]|0;c[3541190]=n;c[3541198]=n;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=n+256;c[3541199]=n+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=n+512;c[3541200]=n+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=n+768;c[3541201]=n+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;mx(0);s=0;i=b;return s|0}}while(0);c[2426644]=0;s=1;i=b;return s|0}function fqR(){var a=0,b=0,d=0,e=0,f=0;Uw(0);a=c[3531464]|0;c[a+44344>>2]=0;c[a+44348>>2]=0;if((a|0)!=0){gGr(a);c[3531464]=0}a=c[2406684]|0;if((a|0)!=0){gGr(a);c[2406684]=0}fl7();if((c[2392]|0)>=0){a=0;do{b=14130368+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}b=14130384+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}a=a+1|0;}while((a|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;a=c[2426644]|0;b=0;while(1){if((b|0)>=1024){e=65799;break}f=9638528+(b<<2)|0;if((c[f>>2]|0)==(a|0)){break}else{b=b+1|0}}if((e|0)==65799){c[2426644]=0;return 0}gGr(a);c[f>>2]=0;c[2426644]=0;return 0}function fqS(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((a[9623512]|0)!=0){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];b=c[3532592]|0;if((b|0)!=0){gGC(9104152,b|0,280)|0}c[2113054]=c[2113060]}RI();b=c[2394]|0;d=c[14130368+(b<<2)>>2]|0;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[8452240+(b<<2)>>2]=c[2113054];c[2394]=-1;c[2113156]=0;a[9628264]=0;c[2407033]=0;b=c[3541206]|0;c[3541190]=b;c[3541198]=b;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=b+256;c[3541199]=b+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=b+512;c[3541200]=b+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=b+768;c[3541201]=b+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;mx(0)}a[9625440]=0;a[9625441]=0;a[9625442]=0;a[9625446]=0;a[9625447]=0;b=0;d=0;e=0;f=0;g=0;do{d=((a[9632544+b|0]&1)<<b|d&255)&255;e=((a[9551664+b|0]&1)<<b|e&255)&255;f=((a[9629224+b|0]&1)<<b|f&255)&255;g=((a[9628872+b|0]&1)<<b|g&255)&255;b=b+1|0;}while((b|0)<8);a[9625440]=d;a[9625442]=e;a[9625446]=f;a[9625447]=g;if((d&3)==3){e=d&-4;a[9625440]=e;h=e}else{h=d}if((h&12)==12){a[9625440]=h&-13}if((f&3)==3){h=f&-4;a[9625446]=h;i=h}else{i=f}if((i&12)==12){a[9625446]=i&-13}if((g&3)==3){i=g&-4;a[9625447]=i;j=i}else{j=g}if((j&12)==12){a[9625447]=j&-13}j=c[2392]|0;if((j|0)>=0){gGz(8452240,0,((j|0)>0?(j<<2)+4|0:4)|0)}c[2113054]=0;j=c[2438]|0;g=gGU(j,(j|0)<0|0?-1:0,16e6,0)|0;j=gGS(g,K,15360,0)|0;g=j;c[2113218]=g;c[2113220]=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];j=c[3532592]|0;if((j|0)!=0){gGC(9104152,j|0,280)|0}c[2113054]=c[2113060]}c[2113058]=(g|0)/262|0;c[2113018]=g-((g*22|0|0)/262|0);a[670600]=0;g=0;j=0;L85915:while(1){i=j;do{if((i|0)>=4){break L85915}i=i+1|0;f=(ag(c[2113218]|0,i)|0)/4|0;do{if(!(a[670600]|0)){h=c[2113018]|0;if((f|0)<=(h|0)){break}d=c[2113220]|0;if((d|0)<(h|0)){e=h-d|0;c[2113056]=e;d=RG(e)|0;c[2113054]=(c[2113054]|0)+d;c[2276108]=-1;c[2113056]=-1;c[2113220]=(c[2113220]|0)+d}a[670600]=1;d=c[2430398]|0;e=c[2439196]|0;h=e<<11;c[2438976]=d+h;b=(c[2440572]|0)>1;if(b){c[2438977]=(c[2430399]|0)+h}h=e^1;c[2439196]=h;e=h<<11;h=d+e|0;d=(c[3541506]|0)+12288|0;gGC(h|0,d|0,2048)|0;if(b){b=(c[2430399]|0)+e|0;e=(c[3541504]|0)+12288|0;gGC(b|0,e|0,2048)|0}c[8452200+(c[2394]<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0>=1024){break}RH(4)}}while(0);e=f-(c[2113220]|0)|0;c[2113056]=e;b=RG(e)|0;c[2113054]=(c[2113054]|0)+b;c[2276108]=-1;c[2113056]=-1;c[2113220]=(c[2113220]|0)+b;k=c[2112964]|0;}while((k|0)==0);b=a[9688]|0?133:0;e=k+(g<<1<<1)|0;gg[c[3542124]&4095](e,b);Uu(0,e,b);g=b+g|0;j=i}j=c[2112964]|0;do{if((j|0)!=0){k=a[9688]|0?534:0;b=k-g|0;e=j+(g<<1<<1)|0;if((k|0)==(g|0)){break}gg[c[3542124]&4095](e,b);Uu(0,e,b)}}while(0);g=c[2394]|0;j=c[14130368+(g<<2)>>2]|0;if((j|0)!=0){gGC(j|0,9104152,280)|0}c[8452240+(g<<2)>>2]=c[2113054];c[2394]=-1;g=c[2112968]|0;if((g|0)==0){return 0}j=c[3531916]|0;b=c[j>>2]|0;e=c[2113308]|0;do{if((b|0)==0){gGz(g|0,0,e*76800|0|0)}else{if((e|0)==2){k=b<<16|b;d=g;h=0;while(1){c[d>>2]=k;c[d+4>>2]=k;c[d+8>>2]=k;c[d+12>>2]=k;c[d+16>>2]=k;c[d+20>>2]=k;c[d+24>>2]=k;c[d+28>>2]=k;l=h+1|0;if((l|0)<4800){d=d+32|0;h=l}else{break}}}else if((e|0)==4){h=0;d=g;while(1){c[d>>2]=b;c[d+4>>2]=b;c[d+8>>2]=b;c[d+12>>2]=b;c[d+16>>2]=b;c[d+20>>2]=b;c[d+24>>2]=b;c[d+28>>2]=b;k=h+1|0;if((k|0)<9600){h=k;d=d+32|0}else{break}}}else if((e|0)==3){d=b>>>8&255;h=b>>>16&255;k=b&255;i=g;l=0;while(1){a[i]=k;a[i+1|0]=d;a[i+2|0]=h;m=l+1|0;if((m|0)<76800){i=i+3|0;l=m}else{break}}}else{break}}}while(0);if(a[7072600]|0){c[2112970]=g;c[2113306]=e;c[2113298]=c[2113300];fl3();n=c[3531916]|0}else{n=j}c[2112966]=n;j=c[2113016]|0;if((j|0)>0){o=0}else{return 0}do{c[n+(o<<2)>>2]=65535;o=o+1|0;}while((o|0)<(j|0));return 0}function fqT(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[3531916]|0;d=c[b>>2]|0;do{if((d|0)==0){e=c[2113308]|0;gGz(c[2112968]|0,0,e*76800|0|0);f=e}else{e=c[2113308]|0;if((e|0)==4){g=0;h=c[2112968]|0;while(1){c[h>>2]=d;c[h+4>>2]=d;c[h+8>>2]=d;c[h+12>>2]=d;c[h+16>>2]=d;c[h+20>>2]=d;c[h+24>>2]=d;c[h+28>>2]=d;i=g+1|0;if((i|0)<9600){g=i;h=h+32|0}else{f=4;break}}}else if((e|0)==3){h=d>>>8&255;g=d>>>16&255;i=d&255;j=c[2112968]|0;k=0;while(1){a[j]=i;a[j+1|0]=h;a[j+2|0]=g;l=k+1|0;if((l|0)<76800){j=j+3|0;k=l}else{f=3;break}}}else if((e|0)==2){k=d<<16|d;j=c[2112968]|0;g=0;while(1){c[j>>2]=k;c[j+4>>2]=k;c[j+8>>2]=k;c[j+12>>2]=k;c[j+16>>2]=k;c[j+20>>2]=k;c[j+24>>2]=k;c[j+28>>2]=k;h=g+1|0;if((h|0)<4800){j=j+32|0;g=h}else{f=2;break}}}else{f=e;break}}}while(0);if(a[7072600]|0){c[2112970]=c[2112968];c[2113306]=f;c[2113298]=c[2113300];fl3();m=c[3531916]|0}else{m=b}c[2112966]=m;b=c[2113016]|0;if((b|0)>0){n=0}else{return 0}do{c[m+(n<<2)>>2]=65535;n=n+1|0;}while((n|0)<(b|0));return 0}function fqU(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;f=i;i=i+176|0;g=f|0;h=f+16|0;j=f+32|0;k=f+48|0;l=f+64|0;m=f+80|0;n=f+96|0;o=f+112|0;p=f+128|0;q=f+144|0;r=f+160|0;s=(e|0)==0;if(!s){c[e>>2]=133527}if((b&96|0)==0){i=f;return 0}gGz(r|0,0,12);t=c[2405582]|0;c[r>>2]=t;c[r+4>>2]=(c[2411488]|0)-t;c[r+12>>2]=162152;gj[c[2076592]&4095](r)|0;r=p|0;do{if((b&64|0)==0){Ut(0)}else{gGz(o|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){t=p+9|0;u=n;v=n|0;w=n+4|0;x=n+12|0;y=o|0;z=o+4|0;A=o+12|0;B=0;do{gGC(r|0,614896,11)|0;a[t]=B+48&255;C=8452256+(B<<2)|0;gGz(u|0,0,12);c[v>>2]=C;c[w>>2]=4;c[x>>2]=164976;gj[c[2076592]&4095](n)|0;if((c[C>>2]|0)!=0){c[y>>2]=c[14130368+(B<<2)>>2];c[z>>2]=c[8452184+(B<<2)>>2];c[A>>2]=r;C=c[2076592]|0;gj[C&4095](o)|0}B=B+1|0;}while((B|0)<=(c[2392]|0))}Ut(0);gGz(m|0,0,12);c[m>>2]=8453216;c[m+4>>2]=4;c[m+12>>2]=107480;B=c[2076592]|0;gj[B&4095](m)|0;gGz(l|0,0,12);c[l>>2]=14168504;c[l+4>>2]=256;c[l+12>>2]=476464;B=c[2076592]|0;gj[B&4095](l)|0;if((b&2|0)==0){break}else{D=0}do{mv(0,D,d[14168504+D|0]|0);D=D+1|0;}while((D|0)<256)}}while(0);if(!s){c[e>>2]=169110}gGz(k|0,0,12);c[k>>2]=9756784;c[k+4>>2]=4;c[k+12>>2]=175504;gj[c[2076592]&4095](k)|0;gGz(j|0,0,12);c[j>>2]=14166032;c[j+4>>2]=8;c[j+12>>2]=504552;gj[c[2076592]&4095](j)|0;gGz(h|0,0,12);c[h>>2]=14165992;c[h+4>>2]=8;c[h+12>>2]=388736;gj[c[2076592]&4095](h)|0;gGz(g|0,0,12);c[g>>2]=14165960;c[g+4>>2]=32;c[g+12>>2]=302352;gj[c[2076592]&4095](g)|0;gGz(q|0,0,12);c[q>>2]=9625440;c[q+4>>2]=8;c[q+12>>2]=215728;gj[c[2076592]&4095](q)|0;i=f;return 0}function fqV(d,e){d=d|0;e=e|0;var f=0;if((d|0)==1835010){c[2113312]=e&65535;return}else if((d|0)==1048580|(d|0)==1048582){f=c[3542216]|0;b[(c[3542214]|0)+((f&32767)<<1)>>1]=e;c[3542216]=f+1;return}else if((d|0)==1048578){c[3542216]=(e&65535)<<1&32766;return}else if((d|0)==1310722){a[9722032]=(e&255)!=0|0;return}else if((d|0)==1867776){if(e<<16>>16!=0){return}gGz(9706056,0,76);return}else if((d|0)==1835008){c[2113314]=e&65535;return}else if((d|0)==1048592|(d|0)==1048594|(d|0)==1048596|(d|0)==1048598|(d|0)==1048600|(d|0)==1048602|(d|0)==1048604|(d|0)==1048606){b[14168832+((d>>>1&7)<<1)>>1]=e;return}else{return}}function fqW(a,b){a=a|0;b=b|0;return}function fqX(a){a=a|0;var d=0,e=0;switch(a|0){case 1048578:{d=(c[3542216]|0)>>>1&16383;return d|0};case 1048582:{d=b[(c[3542214]|0)+((c[3542216]&32767)+1<<1)>>1]|0;return d|0};case 1048580:{e=b[(c[3542214]|0)+((c[3542216]&32767)<<1)>>1]|0;d=e<<2&192|e|(e&65535)>>>4&3840;return d|0};case 1048592:case 1048594:case 1048596:case 1048598:case 1048600:case 1048602:case 1048604:case 1048606:{d=b[14168832+((a>>>1&7)<<1)>>1]|0;return d|0};default:{d=0;return d|0}}return 0}function fqY(a){a=a|0;var b=0;if((a|0)!=1310721){b=0;return b|0}a=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;if((a|0)>=(c[2113018]|0)){b=1;return b|0}b=a>>>31&255;return b|0}function fqZ(b,e){b=b|0;e=e|0;var f=0,g=0;f=b&255;if((f|0)==97){b=c[3540984]|0;g=c[b+5876>>2]|0;if((g|0)!=0){gg[g&4095](c[b+5880>>2]|0,0)}lH(b,d[b+5885|0]|0,e&255);return}else if((f|0)==96){a[(c[3540984]|0)+5885|0]=e;return}else{return}}function fq_(b){b=b|0;var d=0,e=0;d=b&65535;switch(d&255|0){case 16:{e=a[9550193]|0;break};case 32:{e=a[9550194]|0;break};case 64:{e=a[9634720]|0;break};case 96:case 97:{e=lx(c[3540984]|0,d&1)|0|6;break};case 0:{e=a[9550192]|0;break};case 112:{e=a[9634722]|0;break};case 80:{e=a[9634721]|0;break};default:{e=0}}return e|0}function fq$(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2397876+(b*112|0)>>2];c[a+104>>2]=c[2397880+(b*112|0)>>2];c[a+108>>2]=c[2397884+(b*112|0)>>2];d=0;return d|0}function fq0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=2397776+(b*112|0);e=0;return e|0}function fq1(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1205920+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function fq2(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>37){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3579408+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fq3(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;e=i;i=i+600|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;a[7461696]=1;c[2424]=5514;c[2113316]=524288;c[2113212]=524288;c[2414866]=0;c[2388084]=0;c[2385868]=524288;c[3542212]=589824;c[3541520]=1114112;c[2414568]=1638400;c[2388214]=1638400;c[2387112]=1654784;c[3530216]=1656832;c[3532636]=1658880;c[3527288]=1658880;c[2386392]=1691648;c[3542214]=1695744;c[2386562]=1761280;c[3541524]=1761280;c[3541522]=1765376;c[2411486]=1765504;c[3531916]=1765504;c[3531914]=1773696;r=0;while(1){if((r|0)>=1024){break}s=9638528+(r<<2)|0;if((c[s>>2]|0)==0){t=65986;break}else{r=r+1|0}}do{if((t|0)==65986){r=gGq(1781888)|0;c[s>>2]=r;if((r|0)==0){break}c[2414866]=r;gGz(r|0,0,1781888);c[2388084]=r;c[2385868]=r+524288;c[3542212]=r+589824;u=(c[2113316]|0)+589824|0;c[3541520]=r+u;v=u+(c[2113212]|0)|0;u=r+v|0;c[2414568]=u;c[2388214]=u;c[2387112]=r+(v+16384);c[3530216]=r+(v+18432);u=r+(v+20480)|0;c[3532636]=u;c[3527288]=u;c[2386392]=r+(v+53248);c[3542214]=r+(v+57344);u=r+(v+122880)|0;c[2386562]=u;c[3541524]=u;c[3541522]=r+(v+126976);u=r+(v+127104)|0;c[2411486]=u;c[3531916]=u;c[3531914]=r+(v+135296);c[2414026]=r+(v+143488);if((R6(r+1|0,0,2)|0)!=0){w=1;i=e;return w|0}if((R6(c[2388084]|0,1,2)|0)!=0){w=1;i=e;return w|0}if((R6((c[2388084]|0)+262145|0,2,2)|0)!=0){w=1;i=e;return w|0}if((R6((c[2388084]|0)+262144|0,3,2)|0)!=0){w=1;i=e;return w|0}r=c[2385868]|0;if((c[3542200]|0)==0){w=1;i=e;return w|0}v=p+108|0;c[v>>2]=0;u=p+100|0;c[u>>2]=0;x=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[x&16383](p,4)|0;do{if((c[v>>2]|0)!=0){x=c[u>>2]|0;c[q>>2]=9534384;y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[y&16383](q,4,0)|0;if((x|0)<1){w=1;i=e;return w|0}if((gzL(r,0,4)|0)==0){break}else{w=1}i=e;return w|0}}while(0);fni(c[3542212]|0,5,c[2113316]|0);r=c[3541520]|0;if((c[3542200]|0)==0){w=1;i=e;return w|0}u=n+108|0;c[u>>2]=0;v=n+100|0;c[v>>2]=0;x=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[x&16383](n,9)|0;do{if((c[u>>2]|0)!=0){x=c[v>>2]|0;c[o>>2]=9534384;y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[y&16383](o,9,0)|0;if((x|0)<1){w=1;i=e;return w|0}if((gzL(r,0,9)|0)==0){break}else{w=1}i=e;return w|0}}while(0);r=(c[3541520]|0)+65536|0;if((c[3542200]|0)==0){w=1;i=e;return w|0}v=l+108|0;c[v>>2]=0;u=l+100|0;c[u>>2]=0;x=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[x&16383](l,10)|0;do{if((c[v>>2]|0)!=0){x=c[u>>2]|0;c[m>>2]=9534384;y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[y&16383](m,10,0)|0;if((x|0)<1){w=1;i=e;return w|0}if((gzL(r,0,10)|0)==0){break}else{w=1}i=e;return w|0}}while(0);r=(c[3541520]|0)+131072|0;if((c[3542200]|0)==0){w=1;i=e;return w|0}u=j+108|0;c[u>>2]=0;v=j+100|0;c[v>>2]=0;x=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[x&16383](j,11)|0;do{if((c[u>>2]|0)!=0){x=c[v>>2]|0;c[k>>2]=9534384;y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[y&16383](k,11,0)|0;if((x|0)<1){w=1;i=e;return w|0}if((gzL(r,0,11)|0)==0){break}else{w=1}i=e;return w|0}}while(0);r=(c[3541520]|0)+196608|0;if((c[3542200]|0)==0){w=1;i=e;return w|0}v=f+108|0;c[v>>2]=0;u=f+100|0;c[u>>2]=0;x=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[x&16383](f,12)|0;do{if((c[v>>2]|0)==0){z=0}else{x=c[u>>2]|0;c[g>>2]=9534384;y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[y&16383](g,12,0)|0;if((x|0)<1){w=1;i=e;return w|0}if((gzL(r,0,12)|0)==0){z=0;break}else{w=1}i=e;return w|0}}while(0);while(1){if((z|0)>=1024){break}A=9638528+(z<<2)|0;if((c[A>>2]|0)==0){t=66014;break}else{z=z+1|0}}L86176:do{if((t|0)==66014){r=gGq(262144)|0;c[A>>2]=r;if((r|0)==0){break}gGz(r|0,0,262144);u=c[3541520]|0;gGC(r|0,u|0,262144)|0;gGz(u|0,0,524288);v=0;x=0;while(1){y=(v|0)/8|0;B=v&7^7;C=u+v|0;D=(d[r+y|0]|0)>>>(B>>>0)<<3&8|x;a[C]=D&255;E=(d[r+(y+65536)|0]|0)>>>(B>>>0)<<2&4|D;a[C]=E&255;D=(d[r+(y+131072)|0]|0)>>>(B>>>0)<<1&2|E;a[C]=D&255;a[C]=((d[r+(y+196608)|0]|0)>>>(B>>>0)&1|D)&255;D=v+1|0;if((D|0)>=524288){F=0;break}v=D;x=d[u+D|0]|0}while(1){if((F|0)>=1024){break L86176}G=9638528+(F<<2)|0;if((c[G>>2]|0)==(r|0)){break}else{F=F+1|0}}gGr(r);c[G>>2]=0}}while(0);fxU(0,425984);if((c[2394]|0)==0){H=c[2112932]|0}else{c[2394]=0;u=c[3532596]|0;c[2112932]=u;x=c[3532592]|0;if((x|0)!=0){gGC(9104152,x|0,280)|0}c[2113054]=c[2113060];H=u}u=c[2388084]|0;x=H|0;v=0;while(1){D=u+v|0;c[x>>2]=D;c[x+131072>>2]=D;D=v+1024|0;if(D>>>0>65535){break}else{x=x+4|0;v=D}}v=H+1024|0;x=262144;while(1){D=u+x|0;c[v>>2]=D;c[v+131072>>2]=D;D=x+1024|0;if(D>>>0>524287){break}else{v=v+4|0;x=D}}x=c[2388214]|0;c[H+2048>>2]=x;c[H+67584>>2]=x;c[H+133120>>2]=x;v=x+1024|0;c[H+2052>>2]=v;c[H+67588>>2]=v;c[H+133124>>2]=v;v=x+2048|0;c[H+2056>>2]=v;c[H+67592>>2]=v;c[H+133128>>2]=v;v=x+3072|0;c[H+2060>>2]=v;c[H+67596>>2]=v;c[H+133132>>2]=v;v=x+4096|0;c[H+2064>>2]=v;c[H+67600>>2]=v;c[H+133136>>2]=v;v=x+5120|0;c[H+2068>>2]=v;c[H+67604>>2]=v;c[H+133140>>2]=v;v=x+6144|0;c[H+2072>>2]=v;c[H+67608>>2]=v;c[H+133144>>2]=v;v=x+7168|0;c[H+2076>>2]=v;c[H+67612>>2]=v;c[H+133148>>2]=v;v=x+8192|0;c[H+2080>>2]=v;c[H+67616>>2]=v;c[H+133152>>2]=v;v=x+9216|0;c[H+2084>>2]=v;c[H+67620>>2]=v;c[H+133156>>2]=v;v=x+10240|0;c[H+2088>>2]=v;c[H+67624>>2]=v;c[H+133160>>2]=v;v=x+11264|0;c[H+2092>>2]=v;c[H+67628>>2]=v;c[H+133164>>2]=v;v=x+12288|0;c[H+2096>>2]=v;c[H+67632>>2]=v;c[H+133168>>2]=v;v=x+13312|0;c[H+2100>>2]=v;c[H+67636>>2]=v;c[H+133172>>2]=v;v=x+14336|0;c[H+2104>>2]=v;c[H+67640>>2]=v;c[H+133176>>2]=v;v=x+15360|0;c[H+2108>>2]=v;c[H+67644>>2]=v;c[H+133180>>2]=v;v=c[2386392]|0;c[H+3072>>2]=v;c[H+68608>>2]=v;c[H+134144>>2]=v;x=v+1024|0;c[H+3076>>2]=x;c[H+68612>>2]=x;c[H+134148>>2]=x;x=v+2048|0;c[H+3080>>2]=x;c[H+68616>>2]=x;c[H+134152>>2]=x;x=v+3072|0;c[H+3084>>2]=x;c[H+68620>>2]=x;c[H+134156>>2]=x;x=c[2387112]|0;c[H+5184>>2]=x;c[H+70720>>2]=x;c[H+136256>>2]=x;v=x+1024|0;c[H+5188>>2]=v;c[H+70724>>2]=v;c[H+136260>>2]=v;v=c[3530216]|0;c[H+5216>>2]=v;c[H+70752>>2]=v;c[H+136288>>2]=v;x=v+1024|0;c[H+5220>>2]=x;c[H+70756>>2]=x;c[H+136292>>2]=x;c[H+196688>>2]=426;c[H+196608>>2]=3518;c[H+196728>>2]=498;c[H+196648>>2]=2502;c[H+6144>>2]=1;c[H+71680>>2]=1;c[H+137216>>2]=1;c[H+6148>>2]=1;c[H+71684>>2]=1;c[H+137220>>2]=1;c[H+6152>>2]=1;c[H+71688>>2]=1;c[H+137224>>2]=1;c[H+6156>>2]=1;c[H+71692>>2]=1;c[H+137228>>2]=1;c[H+196612>>2]=594;c[H+196692>>2]=2082;c[H+196652>>2]=1774;c[H+196732>>2]=1304;x=c[3532592]|0;if((x|0)!=0){gGC(x|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);x=c[2439330]|0;v=(x|0)==0;if(!v){u=x;gGC(9706056,u|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];u=c[3528484]|0;c[2076596]=u;D=c[2417276]|0;c[3541536]=D;c[1836236]=0;B=c[2385868]|0;y=0;C=0;while(1){c[x+76+(C<<2)>>2]=B+(C<<8);E=y+1&65535;if((E&65535)>127){I=0;J=0;break}else{y=E;C=E&65535}}while(1){C=B+(J<<8)|0;c[x+76+(J+512<<2)>>2]=C;c[x+76+(J+768<<2)>>2]=C;C=I+1&65535;if((C&65535)>127){break}else{I=C;J=C&65535}}B=c[3527288]|0;C=128;y=128;while(1){c[x+76+(y<<2)>>2]=B+((y<<8)-32768);E=C+1&65535;if((E&65535)>255){K=128;L=128;break}else{C=E;y=E&65535}}while(1){c[x+76+(L+256<<2)>>2]=B+((L<<8)-32768);y=K+1&65535;if((y&65535)>255){M=128;N=128;break}else{K=y;L=y&65535}}while(1){y=B+((N<<8)-32768)|0;c[x+76+(N+512<<2)>>2]=y;c[x+76+(N+768<<2)>>2]=y;y=M+1&65535;if((y&65535)>255){break}else{M=y;N=y&65535}}c[x+4176>>2]=862;c[x+4172>>2]=2110;if(!v){B=x;gGC(B|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=u;c[2417276]=D;c[1836236]=-1;c[2113182]=19;c[2113178]=17;c[2113174]=15;c[2113170]=13;c[2113168]=273;c[2113172]=273;c[2113176]=273;c[2113180]=273;fpA();a[7460904]=0;c[2113016]=2048;c[3531920]=c[2387112];c[3531918]=c[3530216];UL(35e5,1078,3456,0);c[2438224]=35e5;c[2433522]=3416;c[2406672]=1752;c[3528468]=9362;c[2443842]=584;h[745398]=1.0;a[3203264]=1;a[7072592]=1;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];B=c[3532592]|0;if((B|0)!=0){gGC(9104152,B|0,280)|0}c[2113054]=c[2113060]}RI();B=c[2394]|0;y=c[14130368+(B<<2)>>2]|0;if((y|0)!=0){gGC(y|0,9104152,280)|0}c[8452240+(B<<2)>>2]=c[2113054];c[2394]=-1;B=c[2439330]|0;y=(B|0)==0;if(!y){C=B;gGC(9706056,C|0,76)|0}C=c[2438118]|0;c[2433530]=C;E=c[3528484]|0;c[2076596]=E;O=c[2417276]|0;c[3541536]=O;c[1836236]=0;gGz(9706056,0,76);if(!y){y=B;gGC(y|0,9706056,76)|0}c[2438118]=C;c[3528484]=E;c[2417276]=O;c[1836236]=-1;c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;lw(c[3540984]|0);a[9722032]=0;w=0;i=e;return w|0}}while(0);c[2414866]=0;w=1;i=e;return w|0}function fq4(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=a[7452584]|0;if(b){d=0;e=b&1;while(1){b=14163936+(d<<2)|0;f=c[b>>2]|0;g=c[2113006]|0;if((g|0)==0){h=66080}else{i=g-1|0;c[2113006]=i;if((i|0)==0){h=66080}}if((h|0)==66080){h=0;c[2383474]=0}if((f|0)==0){j=e}else{gGr(f);j=a[7452584]&1}c[b>>2]=0;b=d+1|0;if((b|0)<(j|0)){d=b;e=j}else{break}}}a[7452584]=0;c[2438224]=0;c[2433522]=0;c[2406672]=0;c[3528468]=0;j=c[2406688]|0;if((j|0)!=0){gGr(j);c[2406688]=0}c[2432972]=0;fpB();fwZ();if((c[2392]|0)>=0){j=0;do{e=14130368+(j<<2)|0;d=c[e>>2]|0;if((d|0)!=0){gGr(d);c[e>>2]=0}e=14130384+(j<<2)|0;d=c[e>>2]|0;if((d|0)!=0){gGr(d);c[e>>2]=0}j=j+1|0;}while((j|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;j=c[2414866]|0;e=0;while(1){if((e|0)>=1024){h=66097;break}k=9638528+(e<<2)|0;if((c[k>>2]|0)==(j|0)){break}else{e=e+1|0}}if((h|0)==66097){c[2414866]=0;a[7461696]=0;return 0}gGr(j);c[k>>2]=0;c[2414866]=0;a[7461696]=0;return 0}function fq5(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;if((a[9623504]|0)!=0){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=i;c[1836236]=-1;c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;lw(c[3540984]|0);a[9722032]=0}gGz(9550192,0,3);i=0;g=0;f=0;e=0;do{g=((a[9632536+i|0]&1)<<i|g&255)&255;f=((a[9630448+i|0]&1)<<i|f&255)&255;e=((a[9629216+i|0]&1)<<i|e&255)&255;i=i+1|0;}while((i|0)<8);a[9550192]=g;a[9550193]=f;a[9550194]=e;if((g&3)==3){e=g&-4;a[9550192]=e;j=e}else{j=g}if((j&12)==12){a[9550192]=j&-13}if((f&3)==3){j=f&-4;a[9550193]=j;k=j}else{k=f}if((k&12)==12){a[9550193]=k&-13}k=c[2392]|0;if((k|0)>=0){gGz(8452240,0,((k|0)>0?(k<<2)+4|0:4)|0)}c[2113054]=0;k=c[2385548]|0;if((k|0)>0){gGz(9752472,0,((k|0)>1?k<<2:4)|0)}c[2433530]=0;if((c[2394]|0)==0){l=0}else{c[2394]=0;c[2112932]=c[3532596];k=c[3532592]|0;if((k|0)!=0){gGC(9104152,k|0,280)|0}k=c[2113060]|0;c[2113054]=k;l=k}k=c[2439330]|0;if((k|0)!=0){f=k;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;f=c[2438118]|0;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;c[2113054]=l+(c[2113220]|0);c[2433530]=f+(c[2113221]|0);f=c[2438]|0;l=gGU(f,(f|0)<0|0?-1:0,1e7,0)|0;f=~~((+(l>>>0)+ +(K|0)*4294967296.0)/14115.84);c[2113218]=f;c[2113216]=63474;c[2113058]=(f|0)/262|0;l=f-((f*22|0|0)/262|0)|0;c[2113018]=l;k=0;j=f;f=l;while(1){l=k+1|0;g=(ag(l,j)|0)/4|0;do{if((g|0)>(f|0)){e=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;if((e|0)<(f|0)){i=f-e|0;c[2113056]=i;e=RG(i)|0;c[2113054]=(c[2113054]|0)+e;c[2276108]=-1;c[2113056]=-1}e=c[2112968]|0;do{if((e|0)!=0){i=c[3531916]|0;d=c[2113308]|0;do{if((c[i>>2]|0)==0){gGz(e|0,0,d*76800|0|0)}else{if((d|0)==4){m=c[i+1152>>2]|0;n=0;o=e;while(1){c[o>>2]=m;c[o+4>>2]=m;c[o+8>>2]=m;c[o+12>>2]=m;c[o+16>>2]=m;c[o+20>>2]=m;c[o+24>>2]=m;c[o+28>>2]=m;p=n+1|0;if((p|0)<9600){n=p;o=o+32|0}else{break}}}else if((d|0)==3){o=c[i+1152>>2]|0;n=o>>>8&255;m=o>>>16&255;p=o&255;o=e;q=0;while(1){a[o]=p;a[o+1|0]=n;a[o+2|0]=m;r=q+1|0;if((r|0)<76800){o=o+3|0;q=r}else{break}}}else if((d|0)==2){q=c[i+1152>>2]|0;o=q<<16|q;q=e;m=0;while(1){c[q>>2]=o;c[q+4>>2]=o;c[q+8>>2]=o;c[q+12>>2]=o;c[q+16>>2]=o;c[q+20>>2]=o;c[q+24>>2]=o;c[q+28>>2]=o;n=m+1|0;if((n|0)<4800){q=q+32|0;m=n}else{break}}}else{break}}}while(0);if(a[7072592]|0){c[2112970]=e;c[2113306]=d;c[2113298]=c[2113300];fpz();s=c[3531916]|0}else{s=i}c[2112966]=s;m=c[2113016]|0;if((m|0)>0){t=0}else{break}do{c[s+(t<<2)>>2]=65535;t=t+1|0;}while((t|0)<(m|0));i=c[3531914]|0;d=0;do{c[i+(d<<2)>>2]=65535;d=d+1|0;}while((d|0)<(m|0))}}while(0);e=c[2386562]|0;m=c[2386392]|0;gGC(e|0,m|0,4096)|0;if((a[9722032]&1)==0){break}c[8452200+(c[2394]<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0>=1024){break}RH(4)}}while(0);m=g-(c[2113054]|0)-(c[2113056]|0)+(c[2276108]|0)|0;c[2113056]=m;e=RG(m)|0;c[2113054]=(c[2113054]|0)+e;c[2276108]=-1;c[2113056]=-1;UF(ag((c[2113216]|0)/4|0,k)|0)|0;if((l|0)>=4){break}k=l;j=c[2113218]|0;f=c[2113018]|0}f=c[2113216]|0;j=gGU(f,(f|0)<0|0?-1:0,2048e6,0)|0;k=c[2438224]|0;t=gGS(j,K,k,(k|0)<0|0?-1:0)|0;k=t;UF(f)|0;f=c[2443826]|0;if((f|0)<1073676288){c[2443826]=f-k}f=c[2443827]|0;if((f|0)<1073676288){c[2443827]=f-k}f=(c[3528508]|0)-k|0;c[3528508]=(f|0)<0?0:f;f=c[2112964]|0;if((f|0)!=0){gg[c[3542112]&4095](f,a[9688]|0?534:0)}f=c[2113054]|0;c[2113220]=(c[2113056]|0)+f-(c[2276108]|0)-(c[2113218]|0);k=c[2394]|0;t=c[14130368+(k<<2)>>2]|0;if((t|0)!=0){gGC(t|0,9104152,280)|0}c[8452240+(k<<2)>>2]=f;c[2394]=-1;f=c[1836236]|0;k=c[9757320+(f<<2)>>2]|0;if((k|0)==0){u=c[2433530]|0;v=9752472+(f<<2)|0;c[v>>2]=u;w=c[2076596]|0;x=14113936+(f<<2)|0;c[x>>2]=w;y=c[3541536]|0;z=9669104+(f<<2)|0;c[z>>2]=y;c[1836236]=-1;return 0}t=k;gGC(t|0,9706056,76)|0;u=c[2433530]|0;v=9752472+(f<<2)|0;c[v>>2]=u;w=c[2076596]|0;x=14113936+(f<<2)|0;c[x>>2]=w;y=c[3541536]|0;z=9669104+(f<<2)|0;c[z>>2]=y;c[1836236]=-1;return 0}function fq6(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=c[3531916]|0;do{if((c[b>>2]|0)==0){d=c[2113308]|0;gGz(c[2112968]|0,0,d*76800|0|0);e=d}else{d=c[2113308]|0;if((d|0)==3){f=c[b+1152>>2]|0;g=f>>>8&255;h=f>>>16&255;i=f&255;f=c[2112968]|0;j=0;while(1){a[f]=i;a[f+1|0]=g;a[f+2|0]=h;k=j+1|0;if((k|0)<76800){f=f+3|0;j=k}else{e=3;break}}}else if((d|0)==2){j=c[b+1152>>2]|0;f=j<<16|j;j=c[2112968]|0;h=0;while(1){c[j>>2]=f;c[j+4>>2]=f;c[j+8>>2]=f;c[j+12>>2]=f;c[j+16>>2]=f;c[j+20>>2]=f;c[j+24>>2]=f;c[j+28>>2]=f;g=h+1|0;if((g|0)<4800){j=j+32|0;h=g}else{e=2;break}}}else if((d|0)==4){h=c[b+1152>>2]|0;j=0;f=c[2112968]|0;while(1){c[f>>2]=h;c[f+4>>2]=h;c[f+8>>2]=h;c[f+12>>2]=h;c[f+16>>2]=h;c[f+20>>2]=h;c[f+24>>2]=h;c[f+28>>2]=h;g=j+1|0;if((g|0)<9600){j=g;f=f+32|0}else{e=4;break}}}else{e=d;break}}}while(0);if(a[7072592]|0){c[2112970]=c[2112968];c[2113306]=e;c[2113298]=c[2113300];fpz();l=c[3531916]|0}else{l=b}c[2112966]=l;b=c[2113016]|0;if((b|0)>0){m=0}else{return 0}do{c[l+(m<<2)>>2]=65535;m=m+1|0;}while((m|0)<(b|0));m=c[3531914]|0;l=0;do{c[m+(l<<2)>>2]=65535;l=l+1|0;}while((l|0)<(b|0));return 0}function fq7(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=i;i=i+80|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;if((d|0)!=0){c[d>>2]=169735}if((b&96|0)==0){i=e;return 0}gGz(k|0,0,12);l=c[2414568]|0;c[k>>2]=l;c[k+4>>2]=(c[2411486]|0)-l;c[k+12>>2]=219592;gj[c[2076592]&4095](k)|0;k=h|0;do{if((b&64|0)!=0){gGz(g|0,0,16);c[2394]=-1;if((c[2392]|0)<0){break}l=h+9|0;m=f;n=f|0;o=f+4|0;p=f+12|0;q=g|0;r=g+4|0;s=g+12|0;t=0;do{gGC(k|0,614896,11)|0;a[l]=t+48&255;u=8452256+(t<<2)|0;gGz(m|0,0,12);c[n>>2]=u;c[o>>2]=4;c[p>>2]=164976;gj[c[2076592]&4095](f)|0;if((c[u>>2]|0)!=0){c[q>>2]=c[14130368+(t<<2)>>2];c[r>>2]=c[8452184+(t<<2)>>2];c[s>>2]=k;u=c[2076592]|0;gj[u&4095](g)|0}t=t+1|0;}while((t|0)<=(c[2392]|0))}}while(0);fw$(b);UQ(b,d);gGz(j|0,0,12);c[j>>2]=8452880;c[j+4>>2]=8;c[j+12>>2]=212472;gj[c[2076592]&4095](j)|0;i=e;return 0}function fq8(b){b=b|0;var d=0,e=0;do{if((b&16711680|0)==2162688){d=a[(c[2405154]|0)+(b>>>1&32767)|0]|0}else{if((b|0)==2097173){d=a[9625433]|0;break}else if((b|0)==2097169){d=a[9625432]|0;break}else if((b|0)==2097177){d=a[9625434]|0;break}else if((b|0)==3145741){e=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;if((e|0)>=(c[2113018]|0)){d=1;break}d=e>>>31&255;break}else{d=0;break}}}while(0);return d|0}function fq9(a){a=a|0;var e=0;do{if((a&16711680|0)==2162688){e=d[(c[2405154]|0)+(a>>>1&32767)|0]|0}else{if((a|0)==2097168){e=d[9625432]|0;break}else if((a|0)==2097172){e=d[9625433]|0;break}else if((a|0)==5242884){e=b[c[3541509]>>1]|0;break}else if((a|0)==3145732){e=b[c[3541508]>>1]|0;break}else if((a|0)==5242886){e=b[(c[3541509]|0)+2>>1]|0;break}else if((a|0)==3145734){e=b[(c[3541508]|0)+2>>1]|0;break}else if((a|0)==2097176){e=d[9625434]|0;break}else{e=0;break}}}while(0);return e|0}function fra(b,d){b=b|0;d=d|0;if((b&16711680|0)==2162688){a[(c[2405154]|0)+(b>>>1&32767)|0]=d;return}if((b-2097180|0)>>>0>=2){return}do{if((c[2385198]|0)==0){if((d&32)!=0){break}b=c[(c[3531864]|0)+8>>2]|0;gD[b&8191]()|0}}while(0);c[2385198]=d&32^32;return}function frb(d,e){d=d|0;e=e|0;if((d&16711680|0)==2162688){a[(c[2405154]|0)+(d>>>1&32767)|0]=e&255;return}if((d|0)==3145728){c[3541508]=(c[3541506]|0)+((e&65535)<<1&16382);return}else if((d|0)==3145736){c[3541498]=e&255;return}else if((d|0)==5242884|(d|0)==5242886){b[c[3541509]>>1]=e;c[3541509]=(c[3541509]|0)+2;return}else if((d|0)==5242880){c[3541509]=(c[3541504]|0)+((e&65535)<<1&16382);return}else if((d|0)==5242892){b[(c[3541501]|0)+(c[3541499]<<1)>>1]=e;return}else if((d|0)==5242888){c[3541499]=e&255;return}else if((d|0)==3145740){b[(c[3541500]|0)+(c[3541498]<<1)>>1]=e;return}else if((d|0)==3145732|(d|0)==3145734){b[c[3541508]>>1]=e;c[3541508]=(c[3541508]|0)+2;return}else{return}}function frc(b,d){b=b|0;d=d|0;var e=0;if((b|0)==0){c[2113304]=d&255;return}else if((b|0)==1){e=c[2113304]|0;a[14168504+e|0]=d;mv(0,e,d&255);return}else if((b|0)==4){Uv(0,d);return}else{return}}function frd(a){a=a|0;var b=0;if((a|0)==4){b=c[2113156]&255}else if((a|0)==1){b=c[(c[3531464]|0)+4240>>2]&255}else{b=0}return b|0}function fre(b){b=b|0;var c=0;if((b|0)==65536){c=~a[9625436]}else if((b|0)==65538){c=~a[9625437]}else if((b|0)==65542){c=~a[9625435]}else{c=0}return c|0}function frf(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3106804+(b*112|0)>>2];c[a+104>>2]=c[3106808+(b*112|0)>>2];c[a+108>>2]=c[3106812+(b*112|0)>>2];d=0;return d|0}function frg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=3106704+(b*112|0);e=0;return e|0}function frh(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1171240+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function fri(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>86){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3107600+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function frj(){var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;b=i;i=i+240|0;d=b|0;e=b+112|0;f=b+120|0;g=b+232|0;c[2113208]=4194304;c[2113209]=2097152;c[2426642]=0;c[2418110]=0;c[3541502]=524288;c[3541503]=4718592;c[3541206]=6815744;c[2405580]=7077888;c[2418224]=7077888;c[2405154]=7143424;c[2411392]=7208960;c[3541506]=7213056;c[3541504]=7229440;c[3541500]=7245824;c[3541501]=7246336;c[2411484]=7246848;c[3531916]=7246848;j=0;while(1){if((j|0)>=1024){break}k=9638528+(j<<2)|0;if((c[k>>2]|0)==0){l=66300;break}else{j=j+1|0}}do{if((l|0)==66300){j=gGq(7255040)|0;c[k>>2]=j;if((j|0)==0){break}c[2426642]=j;gGz(j|0,0,7255040);c[2418110]=j;c[3541502]=j+524288;m=(c[2113208]|0)+524288|0;c[3541503]=j+m;n=m+(c[2113209]|0)|0;c[3541206]=j+n;m=j+(n+262144)|0;c[2405580]=m;c[2418224]=m;c[2405154]=j+(n+327680);c[2411392]=j+(n+393216);c[3541506]=j+(n+397312);c[3541504]=j+(n+413696);c[3541500]=j+(n+430080);c[3541501]=j+(n+430592);m=j+(n+431104)|0;c[2411484]=m;c[3531916]=m;c[2414024]=j+(n+439296);do{if((c[3542200]|0)!=0){n=f+108|0;c[n>>2]=0;m=f+100|0;c[m>>2]=0;o=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[o&16383](f,0)|0;if((c[n>>2]|0)==0){break}n=c[m>>2]|0;c[g>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](g,0,0)|0;if((n|0)<1){break}gzL(j,0,0)|0}}while(0);fpl(c[3541502]|0,1,4,c[2113208]|0,0);fpl(c[3541503]|0,5,2,c[2113209]|0,0);j=c[3541206]|0;do{if((c[3542200]|0)!=0){n=d+108|0;c[n>>2]=0;m=d+100|0;c[m>>2]=0;o=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[o&16383](d,7)|0;if((c[n>>2]|0)==0){break}n=c[m>>2]|0;c[e>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](e,7,0)|0;if((n|0)<1){break}gzL(j,0,7)|0}}while(0);fxU(0,425984);if((c[2394]|0)==0){p=c[2112932]|0}else{c[2394]=0;j=c[3532596]|0;c[2112932]=j;n=c[3532592]|0;if((n|0)!=0){gGC(9104152,n|0,280)|0}c[2113054]=c[2113060];p=j}j=c[2418110]|0;n=p|0;m=0;while(1){o=j+m|0;c[n>>2]=o;c[n+131072>>2]=o;o=m+1024|0;if(o>>>0>524287){break}else{n=n+4|0;m=o}}m=c[2418224]|0;n=p+4096|0;j=1048576;while(1){o=m+(j-1048576)|0;c[n>>2]=o;c[n+65536>>2]=o;c[n+131072>>2]=o;o=j+1024|0;if(o>>>0>1114111){break}else{n=n+4|0;j=o}}j=c[2411392]|0;c[p+16384>>2]=j;c[p+81920>>2]=j;c[p+147456>>2]=j;n=j+1024|0;c[p+16388>>2]=n;c[p+81924>>2]=n;c[p+147460>>2]=n;n=j+2048|0;c[p+16392>>2]=n;c[p+81928>>2]=n;c[p+147464>>2]=n;n=j+3072|0;c[p+16396>>2]=n;c[p+81932>>2]=n;c[p+147468>>2]=n;c[p+196688>>2]=24;c[p+196608>>2]=488;c[p+196728>>2]=3084;c[p+196648>>2]=946;n=c[3532592]|0;if((n|0)!=0){gGC(n|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fyz(0,65552,16e6);c[1836234]=0;n=c[2439374]|0;c[3531864]=n;gf[c[n>>2]&2047](0);n=c[2405154]|0;j=c[3531864]|0;m=524288;do{o=m>>11;q=(m|32767)+2047>>11;if((o|0)<(q|0)){r=n+(-m|0)|0;s=o;while(1){c[j+44+(s<<2)>>2]=r;t=s+1|0;if((t|0)<(q|0)){s=t}else{u=o;break}}while(1){c[j+2092+(u<<2)>>2]=r;s=u+1|0;if((s|0)<(q|0)){u=s}else{v=o;break}}do{c[j+4140+(v<<2)>>2]=r;c[j+6188+(v<<2)>>2]=r;v=v+1|0;}while((v|0)<(q|0))}m=m+32768|0;}while((m|0)<1048576);c[j+8236>>2]=3402;c[j+8240>>2]=2616;c[j+8244>>2]=2552;c[1836234]=-1;gu[c[j+4>>2]&16383]();c[3531864]=0;m=a[9680]|0;n=m?32e3:0;if(m){if(a[9624]|0){m=n*3|0;q=52734;while(1){if((q|0)>(m|0)){q=q>>1}else{w=1222;x=q;break}}}else{w=2462;x=n}c[2429380]=x;c[3542124]=w;mw(3375e3,x);q=gGq(262144)|0;c[2406684]=q;gGz(q|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(3375e3,11025)}h[745421]=.5;c[2436794]=3;h[745420]=.5;c[2436792]=3;Ux(0,30303,1);c[2407030]=128;c[2407068]=3;c[2113040]=1;c[2113182]=-470;c[2113178]=-472;c[2113174]=-474;fl6(3);c[2113016]=2048;c[3531920]=c[2411392];a[7072584]=1;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];q=c[3532592]|0;if((q|0)!=0){gGC(9104152,q|0,280)|0}c[2113054]=c[2113060]}RI();q=c[2394]|0;m=c[14130368+(q<<2)>>2]|0;if((m|0)!=0){gGC(m|0,9104152,280)|0}c[8452240+(q<<2)>>2]=c[2113054];c[2394]=-1;c[1836234]=0;q=c[2439374]|0;c[3531864]=q;gf[c[q>>2]&2047](0);gD[c[(c[3531864]|0)+8>>2]&8191]()|0;c[1836234]=-1;gu[c[(c[3531864]|0)+4>>2]&16383]();c[3531864]=0;mx(0);c[2113156]=0;a[9628264]=0;c[2407033]=0;q=c[3541206]|0;c[3541190]=q;c[3541198]=q;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=q+256;c[3541199]=q+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=q+512;c[3541200]=q+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=q+768;c[3541201]=q+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2385198]=1;y=0;i=b;return y|0}}while(0);c[2426642]=0;y=1;i=b;return y|0}function frk(){var a=0,b=0,d=0,e=0,f=0;a=c[3531464]|0;c[a+44344>>2]=0;c[a+44348>>2]=0;if((a|0)!=0){gGr(a);c[3531464]=0}a=c[2406684]|0;if((a|0)!=0){gGr(a);c[2406684]=0}Uw(0);fl7();if((c[2392]|0)>=0){a=0;do{b=14130368+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}b=14130384+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}a=a+1|0;}while((a|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;fyA();a=c[2426642]|0;b=0;while(1){if((b|0)>=1024){e=66359;break}f=9638528+(b<<2)|0;if((c[f>>2]|0)==(a|0)){break}else{b=b+1|0}}if((e|0)==66359){c[2426642]=0;c[3541206]=0;return 0}gGr(a);c[f>>2]=0;c[2426642]=0;c[3541206]=0;return 0}function frl(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((a[9623496]|0)!=0){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];b=c[3532592]|0;if((b|0)!=0){gGC(9104152,b|0,280)|0}c[2113054]=c[2113060]}RI();b=c[2394]|0;d=c[14130368+(b<<2)>>2]|0;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[8452240+(b<<2)>>2]=c[2113054];c[2394]=-1;c[1836234]=0;b=c[2439374]|0;c[3531864]=b;gf[c[b>>2]&2047](0);b=c[(c[3531864]|0)+8>>2]|0;gD[b&8191]()|0;c[1836234]=-1;gu[c[(c[3531864]|0)+4>>2]&16383]();c[3531864]=0;mx(0);c[2113156]=0;a[9628264]=0;c[2407033]=0;b=c[3541206]|0;c[3541190]=b;c[3541198]=b;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=b+256;c[3541199]=b+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=b+512;c[3541200]=b+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=b+768;c[3541201]=b+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2385198]=1}a[9625432]=0;a[9625433]=0;a[9625434]=0;b=0;d=0;e=0;f=0;do{d=((a[9632528+b|0]&1)<<b|d&255)&255;e=((a[9630440+b|0]&1)<<b|e&255)&255;f=((a[9551656+b|0]&1)<<b|f&255)&255;b=b+1|0;}while((b|0)<8);a[9625432]=d;a[9625433]=e;a[9625434]=f;if((d&3)==3){f=d&-4;a[9625432]=f;g=f}else{g=d}if((g&12)==12){a[9625432]=g&-13}if((e&3)==3){g=e&-4;a[9625433]=g;h=g}else{h=e}if((h&12)==12){a[9625433]=h&-13}h=c[2392]|0;if((h|0)>=0){gGz(8452240,0,((h|0)>0?(h<<2)+4|0:4)|0)}c[2113054]=0;c[2409128]=0;c[2409245]=0;c[2409362]=0;c[2409479]=0;c[2409508]=0;c[2409537]=0;c[2409566]=0;c[2409595]=0;h=c[2438]|0;e=h;g=(h|0)<0|0?-1:0;h=gGU(e,g,16e6,0)|0;d=gGS(h,K,15360,0)|0;h=d;c[2113218]=h;d=gGU(e,g,8e6,0)|0;g=gGS(d,K,15360,0)|0;c[2113216]=g;c[2113220]=0;c[2113221]=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060]}c[2113058]=(h|0)/262|0;c[2113018]=h-((h*22|0|0)/262|0);a[670592]=0;c[1836234]=0;h=c[2439374]|0;c[3531864]=h;gf[c[h>>2]&2047](0);h=0;g=0;L86654:while(1){d=g;do{if((d|0)>=10){break L86654}d=d+1|0;e=(ag(c[2113218]|0,d)|0)/10|0;do{if(!(a[670592]|0)){f=c[2113018]|0;if((e|0)<=(f|0)){break}b=c[2113220]|0;if((b|0)<(f|0)){i=f-b|0;c[2113056]=i;b=RG(i)|0;c[2113054]=(c[2113054]|0)+b;c[2276108]=-1;c[2113056]=-1;c[2113220]=(c[2113220]|0)+b}a[670592]=1;b=c[2430398]|0;i=c[2439196]|0;f=i<<11;c[2438976]=b+f;j=(c[2440572]|0)>1;if(j){c[2438977]=(c[2430399]|0)+f}f=i^1;c[2439196]=f;i=f<<11;f=b+i|0;b=(c[3541506]|0)+12288|0;gGC(f|0,b|0,2048)|0;if(!j){break}j=(c[2430399]|0)+i|0;i=(c[3541504]|0)+12288|0;gGC(j|0,i|0,2048)|0}}while(0);i=e-(c[2113220]|0)|0;c[2113056]=i;j=RG(i)|0;c[2113054]=(c[2113054]|0)+j;c[2276108]=-1;c[2113056]=-1;c[2113220]=(c[2113220]|0)+j;j=c[2113216]|0;i=(j|0)/10|0;if((c[2385198]|0)==0){if((j|0)<10){k=0}else{k=gj[c[(c[3531864]|0)+12>>2]&4095](i)|0}l=(c[2113221]|0)+k|0}else{l=(c[2113221]|0)+i|0}c[2113221]=l;m=c[2112964]|0;}while((m|0)==0);i=a[9688]|0?53:0;j=m+(h<<1<<1)|0;gg[c[3542124]&4095](j,i);Uu(0,j,i);h=i+h|0;g=d}g=c[2112964]|0;do{if((g|0)!=0){m=a[9688]|0?534:0;l=m-h|0;if((m|0)==(h|0)){break}m=g+(h<<1<<1)|0;gg[c[3542124]&4095](m,l);Uu(0,m,l)}}while(0);c[1836234]=-1;gu[c[(c[3531864]|0)+4>>2]&16383]();c[3531864]=0;h=c[2394]|0;g=c[14130368+(h<<2)>>2]|0;if((g|0)!=0){gGC(g|0,9104152,280)|0}c[8452240+(h<<2)>>2]=c[2113054];c[2394]=-1;h=c[2112968]|0;if((h|0)==0){return 0}g=c[3531916]|0;l=c[g>>2]|0;m=c[2113308]|0;do{if((l|0)==0){gGz(h|0,0,m*76800|0|0)}else{if((m|0)==4){k=0;i=h;while(1){c[i>>2]=l;c[i+4>>2]=l;c[i+8>>2]=l;c[i+12>>2]=l;c[i+16>>2]=l;c[i+20>>2]=l;c[i+24>>2]=l;c[i+28>>2]=l;j=k+1|0;if((j|0)<9600){k=j;i=i+32|0}else{break}}}else if((m|0)==2){i=l<<16|l;k=h;d=0;while(1){c[k>>2]=i;c[k+4>>2]=i;c[k+8>>2]=i;c[k+12>>2]=i;c[k+16>>2]=i;c[k+20>>2]=i;c[k+24>>2]=i;c[k+28>>2]=i;j=d+1|0;if((j|0)<4800){k=k+32|0;d=j}else{break}}}else if((m|0)==3){d=l>>>8&255;k=l>>>16&255;i=l&255;j=h;b=0;while(1){a[j]=i;a[j+1|0]=d;a[j+2|0]=k;f=b+1|0;if((f|0)<76800){j=j+3|0;b=f}else{break}}}else{break}}}while(0);if(a[7072584]|0){c[2112970]=h;c[2113306]=m;c[2113298]=c[2113300];fl3();n=c[3531916]|0}else{n=g}c[2112966]=n;g=c[2113016]|0;if((g|0)>0){o=0}else{return 0}do{c[n+(o<<2)>>2]=65535;o=o+1|0;}while((o|0)<(g|0));return 0}function frm(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[3531916]|0;d=c[b>>2]|0;do{if((d|0)==0){e=c[2113308]|0;gGz(c[2112968]|0,0,e*76800|0|0);f=e}else{e=c[2113308]|0;if((e|0)==3){g=d>>>8&255;h=d>>>16&255;i=d&255;j=c[2112968]|0;k=0;while(1){a[j]=i;a[j+1|0]=g;a[j+2|0]=h;l=k+1|0;if((l|0)<76800){j=j+3|0;k=l}else{f=3;break}}}else if((e|0)==2){k=d<<16|d;j=c[2112968]|0;h=0;while(1){c[j>>2]=k;c[j+4>>2]=k;c[j+8>>2]=k;c[j+12>>2]=k;c[j+16>>2]=k;c[j+20>>2]=k;c[j+24>>2]=k;c[j+28>>2]=k;g=h+1|0;if((g|0)<4800){j=j+32|0;h=g}else{f=2;break}}}else if((e|0)==4){h=0;j=c[2112968]|0;while(1){c[j>>2]=d;c[j+4>>2]=d;c[j+8>>2]=d;c[j+12>>2]=d;c[j+16>>2]=d;c[j+20>>2]=d;c[j+24>>2]=d;c[j+28>>2]=d;k=h+1|0;if((k|0)<9600){h=k;j=j+32|0}else{f=4;break}}}else{f=e;break}}}while(0);if(a[7072584]|0){c[2112970]=c[2112968];c[2113306]=f;c[2113298]=c[2113300];fl3();m=c[3531916]|0}else{m=b}c[2112966]=m;b=c[2113016]|0;if((b|0)>0){n=0}else{return 0}do{c[m+(n<<2)>>2]=65535;n=n+1|0;}while((n|0)<(b|0));return 0}function frn(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;f=i;i=i+160|0;g=f|0;h=f+16|0;j=f+32|0;k=f+48|0;l=f+64|0;m=f+80|0;n=f+96|0;o=f+112|0;p=f+128|0;q=f+144|0;r=(e|0)==0;if(!r){c[e>>2]=133527}if((b&96|0)==0){i=f;return 0}gGz(q|0,0,12);s=c[2405580]|0;c[q>>2]=s;c[q+4>>2]=(c[2411484]|0)-s;c[q+12>>2]=162152;gj[c[2076592]&4095](q)|0;q=p|0;do{if((b&64|0)!=0){gGz(o|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){s=p+9|0;t=n;u=n|0;v=n+4|0;w=n+12|0;x=o|0;y=o+4|0;z=o+12|0;A=0;do{gGC(q|0,614896,11)|0;a[s]=A+48&255;B=8452256+(A<<2)|0;gGz(t|0,0,12);c[u>>2]=B;c[v>>2]=4;c[w>>2]=164976;gj[c[2076592]&4095](n)|0;if((c[B>>2]|0)!=0){c[x>>2]=c[14130368+(A<<2)>>2];c[y>>2]=c[8452184+(A<<2)>>2];c[z>>2]=q;B=c[2076592]|0;gj[B&4095](o)|0}A=A+1|0;}while((A|0)<=(c[2392]|0))}A=c[2385546]|0;if((A|0)>0){z=0;y=A;while(1){A=c[(c[9757496+(z<<2)>>2]|0)+32>>2]|0;if((A|0)==0){C=y}else{gg[A&4095](z,b);C=c[2385546]|0}A=z+1|0;if((A|0)<(C|0)){z=A;y=C}else{break}}}gGz(m|0,0,12);c[m>>2]=8453216;c[m+4>>2]=4;c[m+12>>2]=107480;y=c[2076592]|0;gj[y&4095](m)|0;gGz(l|0,0,12);c[l>>2]=14168504;c[l+4>>2]=256;c[l+12>>2]=476464;y=c[2076592]|0;gj[y&4095](l)|0;if((b&2|0)==0){break}else{D=0}do{mv(0,D,d[14168504+D|0]|0);D=D+1|0;}while((D|0)<256)}}while(0);Ut(0);if(!r){c[e>>2]=169110}gGz(k|0,0,12);c[k>>2]=9756784;c[k+4>>2]=4;c[k+12>>2]=175504;gj[c[2076592]&4095](k)|0;gGz(j|0,0,12);c[j>>2]=14166032;c[j+4>>2]=8;c[j+12>>2]=504552;gj[c[2076592]&4095](j)|0;gGz(h|0,0,12);c[h>>2]=14165992;c[h+4>>2]=8;c[h+12>>2]=388736;gj[c[2076592]&4095](h)|0;gGz(g|0,0,12);c[g>>2]=14165960;c[g+4>>2]=32;c[g+12>>2]=302352;gj[c[2076592]&4095](g)|0;i=f;return 0}function fro(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3105908+(b*112|0)>>2];c[a+104>>2]=c[3105912+(b*112|0)>>2];c[a+108>>2]=c[3105916+(b*112|0)>>2];d=0;return d|0}function frp(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=3105808+(b*112|0);e=0;return e|0}function frq(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3108748+(b*112|0)>>2];c[a+104>>2]=c[3108752+(b*112|0)>>2];c[a+108>>2]=c[3108756+(b*112|0)>>2];d=0;return d|0}function frr(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=3108648+(b*112|0);e=0;return e|0}function frs(b){b=b|0;var d=0,e=0;do{if((b|0)==1687597){d=a[9625426]|0}else if((b|0)==1687589){d=a[9625428]|0}else if((b|0)==1687593){d=a[9625429]&15}else if((b|0)==1687585){d=a[9625427]|0}else if((b|0)==1687605){d=a[9625425]|0}else if((b|0)==1310733){e=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;if((e|0)>=(c[2113018]|0)){d=1;break}d=e>>>31&255}else if((b|0)==1687601){d=a[9625424]|0}else{d=0}}while(0);return d|0}function frt(e){e=e|0;var f=0,g=0;do{if((e|0)==1687592){f=a[9625429]&15}else if((e|0)==1687584){f=d[9625427]|0}else if((e|0)==1687596){f=d[9625426]|0}else if((e|0)==1687588){f=d[9625428]|0}else if((e|0)==1310724){f=b[c[3541508]>>1]|0}else if((e|0)==1687604){f=d[9625425]|0}else if((e|0)==1687600){f=d[9625424]|0}else if((e|0)==1310732){g=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;if((g|0)>=(c[2113018]|0)){f=1;break}f=g>>>31&65535}else if((e|0)==1310726){f=b[(c[3541508]|0)+2>>1]|0}else{f=0}}while(0);return f|0}function fru(a,b){a=a|0;b=b|0;return}function frv(a,d){a=a|0;d=d|0;switch(a|0){case 1310726:{b[c[3541508]>>1]=d;c[3541508]=(c[3541508]|0)+2;return};case 1310732:{b[(c[3541500]|0)+(c[3541498]<<1)>>1]=d;return};case 1310728:{c[3541498]=d&255;return};case 1310724:{b[c[3541508]>>1]=d;c[3541508]=(c[3541508]|0)+2;return};case 1310720:{c[3541508]=(c[3541506]|0)+((d&65535)<<1&16382);return};default:{return}}}function frw(b,e){b=b|0;e=e|0;var f=0;f=b&65535;if((f|0)==57344){a[(c[3540984]|0)+5885|0]=e;return}else if((f|0)==57345){f=c[3540984]|0;b=c[f+5876>>2]|0;if((b|0)!=0){gg[b&4095](c[f+5880>>2]|0,0)}lH(f,d[f+5885|0]|0,e&255);return}else{return}}function frx(b){b=b|0;var e=0,f=0,g=0;if(((b&65535)-57344|0)>>>0>=2){e=0;return e|0}b=c[3540984]|0;f=(d[b+5887|0]|0|128)&(d[b+5886|0]|0);if((a[b+5884|0]&2)==0){g=f&255}else{g=(a[(c[b+5828>>2]|0)+100|0]&1|f)&255}e=g|6;return e|0}function fry(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>4){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2457940+(b*112|0)>>2];c[a+104>>2]=c[2457944+(b*112|0)>>2];c[a+108>>2]=c[2457948+(b*112|0)>>2];d=0;return d|0}function frz(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<5&(d|0)==0)){e=1;return e|0}c[a>>2]=2457840+(b*112|0);e=0;return e|0}function frA(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1217584+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function frB(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>58){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4314696+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function frC(){var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;d=i;i=i+240|0;e=d|0;f=d+112|0;g=d+120|0;j=d+232|0;c[2424]=6e3;c[2113208]=2097152;c[2426640]=0;c[2418108]=0;c[3532626]=262144;c[3541502]=327680;c[2405578]=2424832;c[2418222]=2424832;c[3532636]=2437120;c[2411390]=2441216;c[3541506]=2445312;c[3541500]=2478080;c[2411482]=2478592;c[3531916]=2478592;k=0;while(1){if((k|0)>=1024){break}l=9638528+(k<<2)|0;if((c[l>>2]|0)==0){m=66568;break}else{k=k+1|0}}do{if((m|0)==66568){k=gGq(2486784)|0;c[l>>2]=k;if((k|0)==0){break}c[2426640]=k;gGz(k|0,0,2486784);c[2418108]=k;c[3532626]=k+262144;c[3541502]=k+327680;n=c[2113208]|0;o=k+(n+327680)|0;c[2405578]=o;c[2418222]=o;c[3532636]=k+(n+339968);c[2411390]=k+(n+344064);c[3541506]=k+(n+348160);c[3541500]=k+(n+380928);o=k+(n+381440)|0;c[2411482]=o;c[3531916]=o;c[2414022]=k+(n+389632);n=(fa(c[c[642608+(c[2436]<<2)>>2]>>2]|0,115584)|0)==0;fpk(k,2)|0;k=c[3541502]|0;o=c[2113208]|0;do{if(n){fpl(k,2,4,o,0);p=c[3532626]|0;if((c[3542200]|0)==0){break}q=g+108|0;c[q>>2]=0;r=g+100|0;c[r>>2]=0;s=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[s&16383](g,6)|0;if((c[q>>2]|0)==0){break}q=c[r>>2]|0;c[j>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](j,6,0)|0;if((q|0)<1){break}gzL(p,0,6)|0}else{fpl(k,2,2,o,0);p=c[3532626]|0;if((c[3542200]|0)==0){break}q=e+108|0;c[q>>2]=0;r=e+100|0;c[r>>2]=0;s=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[s&16383](e,4)|0;if((c[q>>2]|0)==0){break}q=c[r>>2]|0;c[f>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](f,4,0)|0;if((q|0)<1){break}gzL(p,0,4)|0}}while(0);fxU(0,425984);if((c[2394]|0)==0){t=c[2112932]|0}else{c[2394]=0;o=c[3532596]|0;c[2112932]=o;k=c[3532592]|0;if((k|0)!=0){gGC(9104152,k|0,280)|0}c[2113054]=c[2113060];t=o}o=c[2418108]|0;k=t|0;n=0;while(1){p=o+n|0;c[k>>2]=p;c[k+131072>>2]=p;p=n+1024|0;if(p>>>0>262143){break}else{k=k+4|0;n=p}}n=c[2418222]|0;c[t+2048>>2]=n;c[t+67584>>2]=n;c[t+133120>>2]=n;k=n+1024|0;c[t+2052>>2]=k;c[t+67588>>2]=k;c[t+133124>>2]=k;k=n+2048|0;c[t+2056>>2]=k;c[t+67592>>2]=k;c[t+133128>>2]=k;k=n+3072|0;c[t+2060>>2]=k;c[t+67596>>2]=k;c[t+133132>>2]=k;k=n+4096|0;c[t+2064>>2]=k;c[t+67600>>2]=k;c[t+133136>>2]=k;k=n+5120|0;c[t+2068>>2]=k;c[t+67604>>2]=k;c[t+133140>>2]=k;k=n+6144|0;c[t+2072>>2]=k;c[t+67608>>2]=k;c[t+133144>>2]=k;k=n+7168|0;c[t+2076>>2]=k;c[t+67612>>2]=k;c[t+133148>>2]=k;k=n+8192|0;c[t+2080>>2]=k;c[t+67616>>2]=k;c[t+133152>>2]=k;k=n+9216|0;c[t+2084>>2]=k;c[t+67620>>2]=k;c[t+133156>>2]=k;k=n+10240|0;c[t+2088>>2]=k;c[t+67624>>2]=k;c[t+133160>>2]=k;k=n+11264|0;c[t+2092>>2]=k;c[t+67628>>2]=k;c[t+133164>>2]=k;k=c[2411390]|0;c[t+3072>>2]=k;c[t+68608>>2]=k;c[t+134144>>2]=k;n=k+1024|0;c[t+3076>>2]=n;c[t+68612>>2]=n;c[t+134148>>2]=n;n=k+2048|0;c[t+3080>>2]=n;c[t+68616>>2]=n;c[t+134152>>2]=n;n=k+3072|0;c[t+3084>>2]=n;c[t+68620>>2]=n;c[t+134156>>2]=n;c[t+196688>>2]=288;c[t+196608>>2]=2876;c[t+196728>>2]=3268;c[t+196648>>2]=1480;c[t+6400>>2]=1;c[t+71936>>2]=1;c[t+137472>>2]=1;c[t+6404>>2]=1;c[t+71940>>2]=1;c[t+137476>>2]=1;c[t+6408>>2]=1;c[t+71944>>2]=1;c[t+137480>>2]=1;c[t+6412>>2]=1;c[t+71948>>2]=1;c[t+137484>>2]=1;c[t+196612>>2]=594;c[t+196692>>2]=2082;c[t+196652>>2]=1774;c[t+196732>>2]=1304;n=c[3532592]|0;if((n|0)!=0){gGC(n|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);n=c[2439330]|0;k=(n|0)==0;if(!k){o=n;gGC(9706056,o|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];o=c[3528484]|0;c[2076596]=o;p=c[2417276]|0;c[3541536]=p;c[1836236]=0;q=c[3532626]|0;r=0;s=0;while(1){c[n+76+(s<<2)>>2]=q+(s<<8);u=r+1&65535;if((u&65535)>127){v=0;w=0;break}else{r=u;s=u&65535}}while(1){s=q+(w<<8)|0;c[n+76+(w+512<<2)>>2]=s;c[n+76+(w+768<<2)>>2]=s;s=v+1&65535;if((s&65535)>127){break}else{v=s;w=s&65535}}q=c[3532636]|0;c[n+588>>2]=q;s=q+256|0;c[n+592>>2]=s;r=q+512|0;c[n+596>>2]=r;u=q+768|0;c[n+600>>2]=u;x=q+1024|0;c[n+604>>2]=x;y=q+1280|0;c[n+608>>2]=y;z=q+1536|0;c[n+612>>2]=z;A=q+1792|0;c[n+616>>2]=A;c[n+1612>>2]=q;c[n+1616>>2]=s;c[n+1620>>2]=r;c[n+1624>>2]=u;c[n+1628>>2]=x;c[n+1632>>2]=y;c[n+1636>>2]=z;c[n+1640>>2]=A;c[n+2636>>2]=q;c[n+3660>>2]=q;c[n+2640>>2]=s;c[n+3664>>2]=s;c[n+2644>>2]=r;c[n+3668>>2]=r;c[n+2648>>2]=u;c[n+3672>>2]=u;c[n+2652>>2]=x;c[n+3676>>2]=x;c[n+2656>>2]=y;c[n+3680>>2]=y;c[n+2660>>2]=z;c[n+3684>>2]=z;c[n+2664>>2]=A;c[n+3688>>2]=A;c[n+4184>>2]=1450;c[n+4180>>2]=2204;if(!k){A=n;gGC(A|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=o;c[2417276]=p;c[1836236]=-1;UL(3375e3,1078,1220,0);c[2438224]=3375e3;c[2433522]=3416;c[2406672]=1752;c[3528468]=9362;c[2443842]=605;h[745398]=1.0;a[3203264]=1;c[2113040]=1;c[2113182]=-470;c[2113178]=-472;c[2113174]=-474;fl6(1);c[2113016]=2048;c[3531920]=c[2411390];a[7072576]=1;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];A=c[3532592]|0;if((A|0)!=0){gGC(9104152,A|0,280)|0}c[2113054]=c[2113060]}RI();A=c[2394]|0;z=c[14130368+(A<<2)>>2]|0;if((z|0)!=0){gGC(z|0,9104152,280)|0}c[8452240+(A<<2)>>2]=c[2113054];c[2394]=-1;A=c[2439330]|0;z=(A|0)==0;if(!z){y=A;gGC(9706056,y|0,76)|0}y=c[2438118]|0;c[2433530]=y;x=c[3528484]|0;c[2076596]=x;u=c[2417276]|0;c[3541536]=u;c[1836236]=0;gGz(9706056,0,76);if(!z){z=A;gGC(z|0,9706056,76)|0}c[2438118]=y;c[3528484]=x;c[2417276]=u;c[1836236]=-1;c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;lw(c[3540984]|0);B=0;i=d;return B|0}}while(0);c[2426640]=0;B=1;i=d;return B|0}function frD(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=a[7452584]|0;if(b){d=0;e=b&1;while(1){b=14163936+(d<<2)|0;f=c[b>>2]|0;g=c[2113006]|0;if((g|0)==0){h=66613}else{i=g-1|0;c[2113006]=i;if((i|0)==0){h=66613}}if((h|0)==66613){h=0;c[2383474]=0}if((f|0)==0){j=e}else{gGr(f);j=a[7452584]&1}c[b>>2]=0;b=d+1|0;if((b|0)<(j|0)){d=b;e=j}else{break}}}a[7452584]=0;c[2438224]=0;c[2433522]=0;c[2406672]=0;c[3528468]=0;j=c[2406688]|0;if((j|0)!=0){gGr(j);c[2406688]=0}c[2432972]=0;fl7();if((c[2392]|0)>=0){j=0;do{e=14130368+(j<<2)|0;d=c[e>>2]|0;if((d|0)!=0){gGr(d);c[e>>2]=0}e=14130384+(j<<2)|0;d=c[e>>2]|0;if((d|0)!=0){gGr(d);c[e>>2]=0}j=j+1|0;}while((j|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;fwZ();j=c[2426640]|0;e=0;while(1){if((e|0)>=1024){h=66631;break}k=9638528+(e<<2)|0;if((c[k>>2]|0)==(j|0)){break}else{e=e+1|0}}if((h|0)==66631){c[2426640]=0;return 0}gGr(j);c[k>>2]=0;c[2426640]=0;return 0}function frE(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;if((a[9623488]|0)!=0){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=i;c[1836236]=-1;c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;lw(c[3540984]|0)}gGz(9625424,0,3);i=0;g=0;f=0;e=0;do{g=((a[9632520+i|0]&1)<<i|g&255)&255;f=((a[9630432+i|0]&1)<<i|f&255)&255;e=((a[9551648+i|0]&1)<<i|e&255)&255;i=i+1|0;}while((i|0)<8);a[9625424]=g;a[9625425]=f;a[9625426]=e;if((g&3)==3){e=g&-4;a[9625424]=e;j=e}else{j=g}if((j&12)==12){a[9625424]=j&-13}if((f&3)==3){j=f&-4;a[9625425]=j;k=j}else{k=f}if((k&12)==12){a[9625425]=k&-13}k=c[2392]|0;if((k|0)>=0){gGz(8452240,0,((k|0)>0?(k<<2)+4|0:4)|0)}c[2113054]=0;k=c[2385548]|0;if((k|0)>0){gGz(9752472,0,((k|0)>1?k<<2:4)|0)}c[2433530]=0;if((c[2394]|0)==0){l=0}else{c[2394]=0;c[2112932]=c[3532596];k=c[3532592]|0;if((k|0)!=0){gGC(9104152,k|0,280)|0}k=c[2113060]|0;c[2113054]=k;l=k}k=c[2439330]|0;if((k|0)!=0){f=k;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;f=c[2438118]|0;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;c[2113054]=l+(c[2113220]|0);c[2433530]=f+(c[2113221]|0);f=c[2438]|0;l=gGU(f,(f|0)<0|0?-1:0,1e7,0)|0;f=gGS(l,K,15360,0)|0;l=f;c[2113218]=l;c[2113216]=56250;c[2113058]=(l|0)/262|0;f=l-((l*22|0|0)/262|0)|0;c[2113018]=f;k=0;j=l;l=f;while(1){f=k+1|0;g=(ag(f,j)|0)/4|0;do{if((g|0)>(l|0)){e=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;if((e|0)<(l|0)){i=l-e|0;c[2113056]=i;e=RG(i)|0;c[2113054]=(c[2113054]|0)+e;c[2276108]=-1;c[2113056]=-1}e=c[2112968]|0;do{if((e|0)!=0){i=c[3531916]|0;d=c[i>>2]|0;m=c[2113308]|0;do{if((d|0)==0){gGz(e|0,0,m*76800|0|0)}else{if((m|0)==4){n=0;o=e;while(1){c[o>>2]=d;c[o+4>>2]=d;c[o+8>>2]=d;c[o+12>>2]=d;c[o+16>>2]=d;c[o+20>>2]=d;c[o+24>>2]=d;c[o+28>>2]=d;p=n+1|0;if((p|0)<9600){n=p;o=o+32|0}else{break}}}else if((m|0)==3){o=d>>>8&255;n=d>>>16&255;p=d&255;q=e;r=0;while(1){a[q]=p;a[q+1|0]=o;a[q+2|0]=n;s=r+1|0;if((s|0)<76800){q=q+3|0;r=s}else{break}}}else if((m|0)==2){r=d<<16|d;q=e;n=0;while(1){c[q>>2]=r;c[q+4>>2]=r;c[q+8>>2]=r;c[q+12>>2]=r;c[q+16>>2]=r;c[q+20>>2]=r;c[q+24>>2]=r;c[q+28>>2]=r;o=n+1|0;if((o|0)<4800){q=q+32|0;n=o}else{break}}}else{break}}}while(0);if(a[7072576]|0){c[2112970]=e;c[2113306]=m;c[2113298]=c[2113300];fl3();t=c[3531916]|0}else{t=i}c[2112966]=t;d=c[2113016]|0;if((d|0)>0){u=0}else{break}do{c[t+(u<<2)>>2]=65535;u=u+1|0;}while((u|0)<(d|0))}}while(0);e=c[2430398]|0;d=c[2439196]|0;i=d<<11;c[2438976]=e+i;m=(c[2440572]|0)>1;if(m){c[2438977]=(c[2430399]|0)+i}i=d^1;c[2439196]=i;d=i<<11;i=e+d|0;e=(c[3541506]|0)+12288|0;gGC(i|0,e|0,2048)|0;if(m){m=(c[2430399]|0)+d|0;d=(c[3541504]|0)+12288|0;gGC(m|0,d|0,2048)|0}c[8452200+(c[2394]<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0>=1024){break}RH(4)}}while(0);d=g-(c[2113054]|0)-(c[2113056]|0)+(c[2276108]|0)|0;c[2113056]=d;m=RG(d)|0;c[2113054]=(c[2113054]|0)+m;c[2276108]=-1;c[2113056]=-1;UF(ag((c[2113216]|0)/4|0,k)|0)|0;if((f|0)>=4){break}k=f;j=c[2113218]|0;l=c[2113018]|0}l=c[2113216]|0;j=gGU(l,(l|0)<0|0?-1:0,2048e6,0)|0;k=c[2438224]|0;u=gGS(j,K,k,(k|0)<0|0?-1:0)|0;k=u;UF(l)|0;l=c[2443826]|0;if((l|0)<1073676288){c[2443826]=l-k}l=c[2443827]|0;if((l|0)<1073676288){c[2443827]=l-k}l=(c[3528508]|0)-k|0;c[3528508]=(l|0)<0?0:l;l=c[2112964]|0;if((l|0)!=0){gg[c[3542112]&4095](l,a[9688]|0?534:0)}l=c[2113054]|0;c[2113220]=(c[2113056]|0)+l-(c[2276108]|0)-(c[2113218]|0);k=c[2394]|0;u=c[14130368+(k<<2)>>2]|0;if((u|0)!=0){gGC(u|0,9104152,280)|0}c[8452240+(k<<2)>>2]=l;c[2394]=-1;l=c[1836236]|0;k=c[9757320+(l<<2)>>2]|0;if((k|0)==0){v=c[2433530]|0;w=9752472+(l<<2)|0;c[w>>2]=v;x=c[2076596]|0;y=14113936+(l<<2)|0;c[y>>2]=x;z=c[3541536]|0;A=9669104+(l<<2)|0;c[A>>2]=z;c[1836236]=-1;return 0}u=k;gGC(u|0,9706056,76)|0;v=c[2433530]|0;w=9752472+(l<<2)|0;c[w>>2]=v;x=c[2076596]|0;y=14113936+(l<<2)|0;c[y>>2]=x;z=c[3541536]|0;A=9669104+(l<<2)|0;c[A>>2]=z;c[1836236]=-1;return 0}function frF(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[3531916]|0;d=c[b>>2]|0;do{if((d|0)==0){e=c[2113308]|0;gGz(c[2112968]|0,0,e*76800|0|0);f=e}else{e=c[2113308]|0;if((e|0)==3){g=d>>>8&255;h=d>>>16&255;i=d&255;j=c[2112968]|0;k=0;while(1){a[j]=i;a[j+1|0]=g;a[j+2|0]=h;l=k+1|0;if((l|0)<76800){j=j+3|0;k=l}else{f=3;break}}}else if((e|0)==4){k=0;j=c[2112968]|0;while(1){c[j>>2]=d;c[j+4>>2]=d;c[j+8>>2]=d;c[j+12>>2]=d;c[j+16>>2]=d;c[j+20>>2]=d;c[j+24>>2]=d;c[j+28>>2]=d;h=k+1|0;if((h|0)<9600){k=h;j=j+32|0}else{f=4;break}}}else if((e|0)==2){j=d<<16|d;k=c[2112968]|0;h=0;while(1){c[k>>2]=j;c[k+4>>2]=j;c[k+8>>2]=j;c[k+12>>2]=j;c[k+16>>2]=j;c[k+20>>2]=j;c[k+24>>2]=j;c[k+28>>2]=j;g=h+1|0;if((g|0)<4800){k=k+32|0;h=g}else{f=2;break}}}else{f=e;break}}}while(0);if(a[7072576]|0){c[2112970]=c[2112968];c[2113306]=f;c[2113298]=c[2113300];fl3();m=c[3531916]|0}else{m=b}c[2112966]=m;b=c[2113016]|0;if((b|0)>0){n=0}else{return 0}do{c[m+(n<<2)>>2]=65535;n=n+1|0;}while((n|0)<(b|0));return 0}function frG(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;e=i;i=i+128|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;l=e+80|0;m=e+96|0;n=e+112|0;o=(d|0)==0;if(!o){c[d>>2]=133527}if((b&96|0)==0){i=e;return 0}gGz(n|0,0,12);p=c[2405578]|0;c[n>>2]=p;c[n+4>>2]=(c[2411482]|0)-p;c[n+12>>2]=162152;gj[c[2076592]&4095](n)|0;n=m|0;do{if((b&64|0)!=0){gGz(l|0,0,16);c[2394]=-1;if((c[2392]|0)<0){break}p=m+9|0;q=k;r=k|0;s=k+4|0;t=k+12|0;u=l|0;v=l+4|0;w=l+12|0;x=0;do{gGC(n|0,614896,11)|0;a[p]=x+48&255;y=8452256+(x<<2)|0;gGz(q|0,0,12);c[r>>2]=y;c[s>>2]=4;c[t>>2]=164976;gj[c[2076592]&4095](k)|0;if((c[y>>2]|0)!=0){c[u>>2]=c[14130368+(x<<2)>>2];c[v>>2]=c[8452184+(x<<2)>>2];c[w>>2]=n;y=c[2076592]|0;gj[y&4095](l)|0}x=x+1|0;}while((x|0)<=(c[2392]|0))}}while(0);fw$(b);UQ(b,d);if(!o){c[d>>2]=169110}gGz(j|0,0,12);c[j>>2]=9756784;c[j+4>>2]=4;c[j+12>>2]=175504;gj[c[2076592]&4095](j)|0;gGz(h|0,0,12);c[h>>2]=14166032;c[h+4>>2]=8;c[h+12>>2]=504552;gj[c[2076592]&4095](h)|0;gGz(g|0,0,12);c[g>>2]=14165992;c[g+4>>2]=8;c[g+12>>2]=388736;gj[c[2076592]&4095](g)|0;gGz(f|0,0,12);c[f>>2]=14165960;c[f+4>>2]=32;c[f+12>>2]=302352;gj[c[2076592]&4095](f)|0;i=e;return 0}function frH(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>4){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1441156+(b*112|0)>>2];c[a+104>>2]=c[1441160+(b*112|0)>>2];c[a+108>>2]=c[1441164+(b*112|0)>>2];d=0;return d|0}function frI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<5&(d|0)==0)){e=1;return e|0}c[a>>2]=1441056+(b*112|0);e=0;return e|0}function frJ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1440372+(b*112|0)>>2];c[a+104>>2]=c[1440376+(b*112|0)>>2];c[a+108>>2]=c[1440380+(b*112|0)>>2];d=0;return d|0}function frK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=1440272+(b*112|0);e=0;return e|0}function frL(a){a=a|0;var b=0,d=0;b=(c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,3375e3,0)|0;return a|0}function frM(b){b=b|0;var d=0;L87144:do{switch(b|0){case 7340043:{d=a[9625418]|0;break};case 7340049:{d=c[2113156]&255;break};case 7340055:{d=c[(c[3531464]|0)+4240>>2]&255;break};case 7340037:{d=a[9625421]|0;break};case 7340041:{d=a[9625417]|0;break};case 7340039:{d=a[9625416]|0;break};case 7340035:{d=a[9625420]|0;break};case 7340033:{d=a[9625419]|0;break};default:{if((b&16711680|0)!=5242880){d=0;break L87144}d=a[(c[3541532]|0)+(b>>>1&32767)|0]|0}}}while(0);return d|0}function frN(a){a=a|0;var e=0,f=0,g=0;if((a|0)==2097164){e=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;if((e|0)>=(c[2113018]|0)){f=1;return f|0}f=e>>>31&65535;return f|0}else if((a|0)==7340038){f=d[9625416]|0;return f|0}else if((a|0)==7340054){f=c[(c[3531464]|0)+4240>>2]&65535;return f|0}else if((a|0)==7340032){f=d[9625419]|0;return f|0}else if((a|0)==7340048){f=c[2113156]&65535;return f|0}else if((a|0)==7340040){f=d[9625417]|0;return f|0}else if((a|0)==7340042){f=d[9625418]|0;return f|0}else if((a|0)==6291456){e=((c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0)/(c[2113058]|0)|0;if((e|0)==(c[2384344]|0)){g=65024}else{c[2384344]=e;g=32256}f=(g|e)&65535;return f|0}else if((a|0)==2097156){f=b[c[3541508]>>1]|0;return f|0}else if((a|0)==7340034){f=d[9625420]|0;return f|0}else if((a|0)==7340036){f=d[9625421]|0;return f|0}else if((a|0)==2097158){f=b[(c[3541508]|0)+2>>1]|0;return f|0}else{if((a&16711680|0)!=5242880){f=0;return f|0}e=a>>>1&32767;a=c[3541532]|0;f=(d[a+(e|32768)|0]|0)<<8|(d[a+e|0]|0);return f|0}return 0}function frO(b,d){b=b|0;d=d|0;var e=0;if((b|0)==7340055){e=c[2113304]|0;a[14168504+e|0]=d;mv(0,e,d&255);return}else if((b|0)==7340053){c[2113304]=d&255;return}else if((b|0)==7340049){Uv(0,d);return}else{if((b&16711680|0)!=5242880){return}a[(c[3541532]|0)+(b>>>1&32767)|0]=d;return}}function frP(d,e){d=d|0;e=e|0;var f=0;if((d|0)==2097160){c[3541498]=e&255;return}else if((d|0)==7340054){f=c[2113304]|0;a[14168504+f|0]=e&255;mv(0,f,e&255);return}else if((d|0)==7340052){c[2113304]=e&255;return}else if((d|0)==2097164){b[(c[3541500]|0)+(c[3541498]<<1)>>1]=e;return}else if((d|0)==2097152){c[3541508]=(c[3541506]|0)+((e&65535)<<1&16382);return}else if((d|0)==7340048){Uv(0,e&255);return}else if((d|0)==2097156|(d|0)==2097158){b[c[3541508]>>1]=e;c[3541508]=(c[3541508]|0)+2;return}else{if((d&16711680|0)!=5242880){return}f=d>>>1&32767;d=c[3541532]|0;a[d+f|0]=e&255;a[d+(f|32768)|0]=0;return}}function frQ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>3){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2121972+(b*112|0)>>2];c[a+104>>2]=c[2121976+(b*112|0)>>2];c[a+108>>2]=c[2121980+(b*112|0)>>2];d=0;return d|0}function frR(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<4&(d|0)==0)){e=1;return e|0}c[a>>2]=2121872+(b*112|0);e=0;return e|0}function frS(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=999056+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function frT(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>85){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=2122320+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function frU(){var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=i;i=i+240|0;d=b|0;e=b+112|0;f=b+120|0;g=b+232|0;c[2113208]=2097152;c[2426638]=0;c[2418106]=0;c[3541502]=524288;c[3541206]=2621440;c[2405576]=3145728;c[2418220]=3145728;c[3541532]=3211264;c[3541534]=3276800;c[3541530]=3284992;c[3541528]=3289088;c[2411388]=3293184;c[3541506]=3297280;c[3541500]=3313664;c[2411480]=3314176;c[3531916]=3314176;j=0;while(1){if((j|0)>=1024){break}k=9638528+(j<<2)|0;if((c[k>>2]|0)==0){l=66866;break}else{j=j+1|0}}do{if((l|0)==66866){j=gGq(3322368)|0;c[k>>2]=j;if((j|0)==0){break}c[2426638]=j;gGz(j|0,0,3322368);c[2418106]=j;c[3541502]=j+524288;m=c[2113208]|0;c[3541206]=j+(m+524288);n=j+(m+1048576)|0;c[2405576]=n;c[2418220]=n;c[3541532]=j+(m+1114112);c[3541534]=j+(m+1179648);c[3541530]=j+(m+1187840);c[3541528]=j+(m+1191936);c[2411388]=j+(m+1196032);c[3541506]=j+(m+1200128);c[3541500]=j+(m+1216512);n=j+(m+1217024)|0;c[2411480]=n;c[3531916]=n;c[2414020]=j+(m+1225216);do{if((c[3542200]|0)!=0){m=f+108|0;c[m>>2]=0;n=f+100|0;c[n>>2]=0;o=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[o&16383](f,0)|0;if((c[m>>2]|0)==0){break}m=c[n>>2]|0;c[g>>2]=9534384;n=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[n&16383](g,0,0)|0;if((m|0)<1){break}gzL(j,0,0)|0}}while(0);j=0;m=c[2418106]|0;while(1){n=a[m]|0;o=m+1|0;a[m]=a[o]|0;a[o]=n;n=j+1|0;if((n|0)<262144){j=n;m=m+2|0}else{break}}fpl(c[3541502]|0,1,2,c[2113208]|0,0);m=c[3541206]|0;do{if((c[3542200]|0)!=0){j=d+108|0;c[j>>2]=0;n=d+100|0;c[n>>2]=0;o=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[o&16383](d,3)|0;if((c[j>>2]|0)==0){break}j=c[n>>2]|0;c[e>>2]=9534384;n=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[n&16383](e,3,0)|0;if((j|0)<1){break}gzL(m,0,3)|0}}while(0);fxU(0,425984);if((c[2394]|0)==0){p=c[2112932]|0}else{c[2394]=0;m=c[3532596]|0;c[2112932]=m;j=c[3532592]|0;if((j|0)!=0){gGC(9104152,j|0,280)|0}c[2113054]=c[2113060];p=m}m=c[2418106]|0;j=p|0;n=0;while(1){o=m+n|0;c[j>>2]=o;c[j+131072>>2]=o;o=n+1024|0;if(o>>>0>524287){break}else{j=j+4|0;n=o}}n=c[2418220]|0;j=p+4096|0;m=1048576;while(1){o=n+(m-1048576)|0;c[j>>2]=o;c[j+65536>>2]=o;c[j+131072>>2]=o;o=m+1024|0;if(o>>>0>1114111){break}else{j=j+4|0;m=o}}m=c[2411388]|0;c[p+12288>>2]=m;c[p+77824>>2]=m;c[p+143360>>2]=m;j=m+1024|0;c[p+12292>>2]=j;c[p+77828>>2]=j;c[p+143364>>2]=j;j=m+2048|0;c[p+12296>>2]=j;c[p+77832>>2]=j;c[p+143368>>2]=j;j=m+3072|0;c[p+12300>>2]=j;c[p+77836>>2]=j;c[p+143372>>2]=j;j=c[3541534]|0;c[p+16384>>2]=j;c[p+81920>>2]=j;c[p+147456>>2]=j;m=j+1024|0;c[p+16388>>2]=m;c[p+81924>>2]=m;c[p+147460>>2]=m;m=j+2048|0;c[p+16392>>2]=m;c[p+81928>>2]=m;c[p+147464>>2]=m;m=j+3072|0;c[p+16396>>2]=m;c[p+81932>>2]=m;c[p+147468>>2]=m;m=j+4096|0;c[p+16400>>2]=m;c[p+81936>>2]=m;c[p+147472>>2]=m;m=j+5120|0;c[p+16404>>2]=m;c[p+81940>>2]=m;c[p+147476>>2]=m;m=j+6144|0;c[p+16408>>2]=m;c[p+81944>>2]=m;c[p+147480>>2]=m;m=j+7168|0;c[p+16412>>2]=m;c[p+81948>>2]=m;c[p+147484>>2]=m;m=c[3541528]|0;c[p+16416>>2]=m;c[p+81952>>2]=m;c[p+147488>>2]=m;j=m+1024|0;c[p+16420>>2]=j;c[p+81956>>2]=j;c[p+147492>>2]=j;j=m+2048|0;c[p+16424>>2]=j;c[p+81960>>2]=j;c[p+147496>>2]=j;j=m+3072|0;c[p+16428>>2]=j;c[p+81964>>2]=j;c[p+147500>>2]=j;j=c[3541530]|0;c[p+16432>>2]=j;c[p+81968>>2]=j;c[p+147504>>2]=j;m=j+1024|0;c[p+16436>>2]=m;c[p+81972>>2]=m;c[p+147508>>2]=m;m=j+2048|0;c[p+16440>>2]=m;c[p+81976>>2]=m;c[p+147512>>2]=m;m=j+3072|0;c[p+16444>>2]=m;c[p+81980>>2]=m;c[p+147516>>2]=m;c[p+196688>>2]=2898;c[p+196608>>2]=546;c[p+196728>>2]=828;c[p+196648>>2]=2440;m=c[3532592]|0;if((m|0)!=0){gGC(m|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;c[2113182]=-470;c[2113178]=-472;c[2113174]=-474;c[2113040]=1;fl6(1);if((c[2408]|0)==39321){c[2408]=43}c[2113016]=2048;c[3531920]=c[2411388];m=a[9680]|0;j=m?32e3:0;if(m){if(a[9624]|0){m=j*3|0;n=52734;while(1){if((n|0)>(m|0)){n=n>>1}else{q=1222;r=n;break}}}else{q=2462;r=j}c[2429380]=r;c[3542124]=q;mw(3375e3,r);n=gGq(262144)|0;c[2406684]=n;gGz(n|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(3375e3,11025)}h[745421]=1.0;c[2436794]=1;h[745420]=1.0;c[2436792]=2;Ux(0,20454,1);c[2407030]=256;c[2407068]=3;a[7072568]=1;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];n=c[3532592]|0;if((n|0)!=0){gGC(9104152,n|0,280)|0}c[2113054]=c[2113060]}a[9775608]=0;c[2113050]=0;c[2276080]=0;RI();n=c[2394]|0;m=c[14130368+(n<<2)>>2]|0;if((m|0)!=0){gGC(m|0,9104152,280)|0}c[8452240+(n<<2)>>2]=c[2113054];c[2394]=-1;c[2113156]=0;a[9628264]=0;c[2407033]=0;n=c[3541206]|0;c[3541190]=n;c[3541198]=n;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=n+256;c[3541199]=n+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=n+512;c[3541200]=n+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=n+768;c[3541201]=n+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;mx(0);s=0;i=b;return s|0}}while(0);c[2426638]=0;s=1;i=b;return s|0}function frV(){var a=0,b=0,d=0,e=0,f=0;Uw(0);a=c[3531464]|0;c[a+44344>>2]=0;c[a+44348>>2]=0;if((a|0)!=0){gGr(a);c[3531464]=0}a=c[2406684]|0;if((a|0)!=0){gGr(a);c[2406684]=0}c[2408]=39321;fl7();if((c[2392]|0)>=0){a=0;do{b=14130368+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}b=14130384+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}a=a+1|0;}while((a|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;a=c[2426638]|0;b=0;while(1){if((b|0)>=1024){e=66922;break}f=9638528+(b<<2)|0;if((c[f>>2]|0)==(a|0)){break}else{b=b+1|0}}if((e|0)==66922){c[2426638]=0;return 0}gGr(a);c[f>>2]=0;c[2426638]=0;return 0}function frW(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;if((a[9623480]|0)!=0){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];b=c[3532592]|0;if((b|0)!=0){gGC(9104152,b|0,280)|0}c[2113054]=c[2113060]}a[9775608]=0;c[2113050]=0;c[2276080]=0;RI();b=c[2394]|0;d=c[14130368+(b<<2)>>2]|0;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[8452240+(b<<2)>>2]=c[2113054];c[2394]=-1;c[2113156]=0;a[9628264]=0;c[2407033]=0;b=c[3541206]|0;c[3541190]=b;c[3541198]=b;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=b+256;c[3541199]=b+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=b+512;c[3541200]=b+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=b+768;c[3541201]=b+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;mx(0)}a[9625416]=0;a[9625417]=0;a[9625418]=0;b=0;d=0;e=0;f=0;do{d=((a[9632512+b|0]&1)<<b|d&255)&255;e=((a[9630424+b|0]&1)<<b|e&255)&255;f=((a[9551640+b|0]&1)<<b|f&255)&255;b=b+1|0;}while((b|0)<8);a[9625416]=d;a[9625417]=e;a[9625418]=f;if((d&3)==3){f=d&-4;a[9625416]=f;g=f}else{g=d}if((g&12)==12){a[9625416]=g&-13}if((e&3)==3){g=e&-4;a[9625417]=g;h=g}else{h=e}if((h&12)==12){a[9625417]=h&-13}h=c[2392]|0;if((h|0)>=0){gGz(8452240,0,((h|0)>0?(h<<2)+4|0:4)|0)}c[2113054]=0;h=c[2438]|0;e=gGU(h,(h|0)<0|0?-1:0,16e6,0)|0;h=gGS(e,K,15360,0)|0;e=h;c[2113218]=e;c[2113220]=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];h=c[3532592]|0;if((h|0)!=0){gGC(9104152,h|0,280)|0}c[2113054]=c[2113060]}c[2113058]=(e|0)/262|0;c[2113018]=e-((e*22|0|0)/262|0);a[670584]=0;e=0;h=0;L87377:while(1){g=h;while(1){if((g|0)>=8){break L87377}i=g+1|0;d=(ag(c[2113218]|0,i)|0)/8|0;do{if(a[670584]|0){j=66962}else{f=c[2113018]|0;b=c[2113220]|0;if((d|0)<=(f|0)){k=b;break}if((b|0)<(f|0)){l=f-b|0;c[2113056]=l;b=RG(l)|0;c[2113054]=(c[2113054]|0)+b;c[2276108]=-1;c[2113056]=-1;c[2113220]=(c[2113220]|0)+b}a[9775608]=1;c[8452200+(c[2394]<<2)>>2]=8194;c[2276080]=512;if((c[2276079]|0)>>>0<512){RH(2)}b=c[2430398]|0;l=c[2439196]|0;f=l<<11;c[2438976]=b+f;m=(c[2440572]|0)>1;if(m){c[2438977]=(c[2430399]|0)+f}f=l^1;c[2439196]=f;l=f<<11;f=b+l|0;b=(c[3541506]|0)+12288|0;gGC(f|0,b|0,2048)|0;if(m){m=(c[2430399]|0)+l|0;l=(c[3541504]|0)+12288|0;gGC(m|0,l|0,2048)|0}a[670584]=1;j=66962}}while(0);if((j|0)==66962){j=0;k=c[2113220]|0}l=d-k|0;a[9775608]=0;c[2113056]=l;m=RG(l)|0;c[2113054]=(c[2113054]|0)+m;c[2276108]=-1;c[2113056]=-1;c[2113220]=(c[2113220]|0)+m;n=c[2112964]|0;if((g&1|0)==0&(n|0)!=0){break}else{g=i}}m=(ag(a[9688]|0?534:0,g)|0)/8|0;l=m-e|0;b=n+(e<<1<<1)|0;gg[c[3542124]&4095](b,l);Uu(0,b,l);e=m;h=i}i=c[2112964]|0;do{if((i|0)!=0){h=a[9688]|0?534:0;n=h-e|0;k=i+(e<<1<<1)|0;if((h|0)==(e|0)){break}gg[c[3542124]&4095](k,n);Uu(0,k,n)}}while(0);e=c[2394]|0;i=c[14130368+(e<<2)>>2]|0;if((i|0)!=0){gGC(i|0,9104152,280)|0}c[8452240+(e<<2)>>2]=c[2113054];c[2394]=-1;e=c[2112968]|0;if((e|0)==0){return 0}i=c[3531916]|0;n=c[i>>2]|0;k=c[2113308]|0;do{if((n|0)==0){gGz(e|0,0,k*76800|0|0)}else{if((k|0)==3){h=n>>>8&255;j=n>>>16&255;m=n&255;l=e;b=0;while(1){a[l]=m;a[l+1|0]=h;a[l+2|0]=j;f=b+1|0;if((f|0)<76800){l=l+3|0;b=f}else{break}}}else if((k|0)==4){b=0;l=e;while(1){c[l>>2]=n;c[l+4>>2]=n;c[l+8>>2]=n;c[l+12>>2]=n;c[l+16>>2]=n;c[l+20>>2]=n;c[l+24>>2]=n;c[l+28>>2]=n;j=b+1|0;if((j|0)<9600){b=j;l=l+32|0}else{break}}}else if((k|0)==2){l=n<<16|n;b=e;j=0;while(1){c[b>>2]=l;c[b+4>>2]=l;c[b+8>>2]=l;c[b+12>>2]=l;c[b+16>>2]=l;c[b+20>>2]=l;c[b+24>>2]=l;c[b+28>>2]=l;h=j+1|0;if((h|0)<4800){b=b+32|0;j=h}else{break}}}else{break}}}while(0);if(a[7072568]|0){c[2112970]=e;c[2113306]=k;c[2113298]=c[2113300];fl3();fnZ();o=c[3531916]|0}else{o=i}c[2112966]=o;i=c[2113016]|0;if((i|0)>0){p=0}else{return 0}do{c[o+(p<<2)>>2]=65535;p=p+1|0;}while((p|0)<(i|0));return 0}function frX(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[3531916]|0;d=c[b>>2]|0;do{if((d|0)==0){e=c[2113308]|0;gGz(c[2112968]|0,0,e*76800|0|0);f=e}else{e=c[2113308]|0;if((e|0)==3){g=d>>>8&255;h=d>>>16&255;i=d&255;j=c[2112968]|0;k=0;while(1){a[j]=i;a[j+1|0]=g;a[j+2|0]=h;l=k+1|0;if((l|0)<76800){j=j+3|0;k=l}else{f=3;break}}}else if((e|0)==4){k=0;j=c[2112968]|0;while(1){c[j>>2]=d;c[j+4>>2]=d;c[j+8>>2]=d;c[j+12>>2]=d;c[j+16>>2]=d;c[j+20>>2]=d;c[j+24>>2]=d;c[j+28>>2]=d;h=k+1|0;if((h|0)<9600){k=h;j=j+32|0}else{f=4;break}}}else if((e|0)==2){j=d<<16|d;k=c[2112968]|0;h=0;while(1){c[k>>2]=j;c[k+4>>2]=j;c[k+8>>2]=j;c[k+12>>2]=j;c[k+16>>2]=j;c[k+20>>2]=j;c[k+24>>2]=j;c[k+28>>2]=j;g=h+1|0;if((g|0)<4800){k=k+32|0;h=g}else{f=2;break}}}else{f=e;break}}}while(0);if(a[7072568]|0){c[2112970]=c[2112968];c[2113306]=f;c[2113298]=c[2113300];fl3();fnZ();m=c[3531916]|0}else{m=b}c[2112966]=m;b=c[2113016]|0;if((b|0)>0){n=0}else{return 0}do{c[m+(n<<2)>>2]=65535;n=n+1|0;}while((n|0)<(b|0));return 0}function frY(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;f=i;i=i+192|0;g=f|0;h=f+16|0;j=f+32|0;k=f+48|0;l=f+64|0;m=f+80|0;n=f+96|0;o=f+112|0;p=f+128|0;q=f+144|0;r=f+160|0;s=f+176|0;t=(e|0)==0;if(!t){c[e>>2]=169111}if((b&96|0)==0){i=f;return 0}gGz(s|0,0,12);u=c[2405576]|0;c[s>>2]=u;c[s+4>>2]=(c[2411480]|0)-u;c[s+12>>2]=219592;gj[c[2076592]&4095](s)|0;s=p|0;do{if((b&64|0)==0){Ut(0)}else{gGz(o|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){u=p+9|0;v=n;w=n|0;x=n+4|0;y=n+12|0;z=o|0;A=o+4|0;B=o+12|0;C=0;do{gGC(s|0,614896,11)|0;a[u]=C+48&255;D=8452256+(C<<2)|0;gGz(v|0,0,12);c[w>>2]=D;c[x>>2]=4;c[y>>2]=164976;gj[c[2076592]&4095](n)|0;if((c[D>>2]|0)!=0){c[z>>2]=c[14130368+(C<<2)>>2];c[A>>2]=c[8452184+(C<<2)>>2];c[B>>2]=s;D=c[2076592]|0;gj[D&4095](o)|0}C=C+1|0;}while((C|0)<=(c[2392]|0))}Ut(0);gGz(m|0,0,12);c[m>>2]=8453216;c[m+4>>2]=4;c[m+12>>2]=107480;C=c[2076592]|0;gj[C&4095](m)|0;gGz(l|0,0,12);c[l>>2]=14168504;c[l+4>>2]=256;c[l+12>>2]=476464;C=c[2076592]|0;gj[C&4095](l)|0;if((b&2|0)==0){break}else{E=0}do{mv(0,E,d[14168504+E|0]|0);E=E+1|0;}while((E|0)<256)}}while(0);if(!t){c[e>>2]=169110}gGz(k|0,0,12);c[k>>2]=9756784;c[k+4>>2]=4;c[k+12>>2]=175504;gj[c[2076592]&4095](k)|0;gGz(j|0,0,12);c[j>>2]=14166032;c[j+4>>2]=8;c[j+12>>2]=504552;gj[c[2076592]&4095](j)|0;gGz(h|0,0,12);c[h>>2]=14165992;c[h+4>>2]=8;c[h+12>>2]=388736;gj[c[2076592]&4095](h)|0;gGz(g|0,0,12);c[g>>2]=14165960;c[g+4>>2]=32;c[g+12>>2]=302352;gj[c[2076592]&4095](g)|0;gGz(r|0,0,12);c[r>>2]=9625416;c[r+4>>2]=6;c[r+12>>2]=215728;gj[c[2076592]&4095](r)|0;gGz(q|0,0,12);c[q>>2]=9775608;c[q+4>>2]=1;c[q+12>>2]=68056;gj[c[2076592]&4095](q)|0;i=f;return 0}function frZ(b){b=b|0;var d=0,e=0;do{if((b|0)==1572913){d=a[9625413]&15|16}else if((b|0)==1572897){d=a[9625410]|0}else if((b|0)==1572881){d=a[9625412]|0}else if((b|0)==1572865){d=a[9625411]|0}else if((b|0)==1572945){d=a[9625408]|0}else if((b|0)==1572961){d=a[9625409]|0}else if((b|0)==1310733){e=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;if((e|0)>=(c[2113018]|0)){d=1;break}d=e>>>31&255}else{d=0}}while(0);return d|0}function fr_(e){e=e|0;var f=0,g=0;do{if((e|0)==1572960){f=d[9625409]|0}else if((e|0)==1572880){f=d[9625412]|0}else if((e|0)==1310724){f=b[c[3541508]>>1]|0}else if((e|0)==1572896){f=d[9625410]|0}else if((e|0)==1572864){f=d[9625411]|0}else if((e|0)==1572912){f=a[9625413]&15|16}else if((e|0)==1310732){g=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;if((g|0)>=(c[2113018]|0)){f=1;break}f=g>>>31&65535}else if((e|0)==1310726){f=b[(c[3541508]|0)+2>>1]|0}else if((e|0)==1572944){f=d[9625408]|0}else{f=0}}while(0);return f|0}function fr$(a,b){a=a|0;b=b|0;return}function fr0(a,d){a=a|0;d=d|0;switch(a|0){case 1310732:{b[(c[3541500]|0)+(c[3541498]<<1)>>1]=d;return};case 1310724:{b[c[3541508]>>1]=d;c[3541508]=(c[3541508]|0)+2;return};case 1310728:{c[3541498]=d&255;return};case 1310726:{b[c[3541508]>>1]=d;c[3541508]=(c[3541508]|0)+2;return};case 1310720:{c[3541508]=(c[3541506]|0)+((d&65535)<<1&16382);return};default:{return}}}function fr1(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>4){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7360588+(b*112|0)>>2];c[a+104>>2]=c[7360592+(b*112|0)>>2];c[a+108>>2]=c[7360596+(b*112|0)>>2];d=0;return d|0}function fr2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<5&(d|0)==0)){e=1;return e|0}c[a>>2]=7360488+(b*112|0);e=0;return e|0}function fr3(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?9719144:0;do{if(d){if((a|0)==0){e=0;break}c[a+100>>2]=c[b+100>>2];e=0}else{e=1}}while(0);return e|0}function fr4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?9719144:0;e=0;return e|0}function fr5(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1002408+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function fr6(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>72){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=2172944+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fr7(){var b=0,d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;c[2113208]=8388608;c[2426636]=0;c[2418104]=0;c[3541502]=262144;c[2405574]=8650752;c[2418218]=8650752;c[2411386]=8663040;c[3541506]=8667136;c[3541500]=8699904;c[2411478]=8700416;c[3531916]=8700416;b=0;while(1){if((b|0)>=1024){break}d=9638528+(b<<2)|0;if((c[d>>2]|0)==0){e=67096;break}else{b=b+1|0}}do{if((e|0)==67096){b=gGq(8708608)|0;c[d>>2]=b;if((b|0)==0){break}c[2426636]=b;gGz(b|0,0,8708608);c[2418104]=b;c[3541502]=b+262144;f=c[2113208]|0;g=b+(f+262144)|0;c[2405574]=g;c[2418218]=g;c[2411386]=b+(f+274432);c[3541506]=b+(f+278528);c[3541500]=b+(f+311296);g=b+(f+311808)|0;c[2411478]=g;c[3531916]=g;c[2414018]=b+(f+32e4);fpk(b,2)|0;fpl(c[3541502]|0,2,2,c[2113208]|0,0);fxU(0,425984);if((c[2394]|0)==0){i=c[2112932]|0}else{c[2394]=0;b=c[3532596]|0;c[2112932]=b;f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];i=b}b=c[2418104]|0;f=i|0;g=0;while(1){j=b+g|0;c[f>>2]=j;c[f+131072>>2]=j;j=g+1024|0;if(j>>>0>262143){break}else{f=f+4|0;g=j}}g=c[2418218]|0;c[i+2048>>2]=g;c[i+67584>>2]=g;c[i+133120>>2]=g;f=g+1024|0;c[i+2052>>2]=f;c[i+67588>>2]=f;c[i+133124>>2]=f;f=g+2048|0;c[i+2056>>2]=f;c[i+67592>>2]=f;c[i+133128>>2]=f;f=g+3072|0;c[i+2060>>2]=f;c[i+67596>>2]=f;c[i+133132>>2]=f;f=g+4096|0;c[i+2064>>2]=f;c[i+67600>>2]=f;c[i+133136>>2]=f;f=g+5120|0;c[i+2068>>2]=f;c[i+67604>>2]=f;c[i+133140>>2]=f;f=g+6144|0;c[i+2072>>2]=f;c[i+67608>>2]=f;c[i+133144>>2]=f;f=g+7168|0;c[i+2076>>2]=f;c[i+67612>>2]=f;c[i+133148>>2]=f;f=g+8192|0;c[i+2080>>2]=f;c[i+67616>>2]=f;c[i+133152>>2]=f;f=g+9216|0;c[i+2084>>2]=f;c[i+67620>>2]=f;c[i+133156>>2]=f;f=g+10240|0;c[i+2088>>2]=f;c[i+67624>>2]=f;c[i+133160>>2]=f;f=g+11264|0;c[i+2092>>2]=f;c[i+67628>>2]=f;c[i+133164>>2]=f;f=c[2411386]|0;c[i+3072>>2]=f;c[i+68608>>2]=f;c[i+134144>>2]=f;g=f+1024|0;c[i+3076>>2]=g;c[i+68612>>2]=g;c[i+134148>>2]=g;g=f+2048|0;c[i+3080>>2]=g;c[i+68616>>2]=g;c[i+134152>>2]=g;g=f+3072|0;c[i+3084>>2]=g;c[i+68620>>2]=g;c[i+134156>>2]=g;c[i+196688>>2]=1494;c[i+196608>>2]=2030;c[i+196728>>2]=102;c[i+196648>>2]=1770;g=c[3532592]|0;if((g|0)!=0){gGC(g|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;c[2113040]=17;c[2113182]=-470;c[2113178]=-472;c[2113174]=-474;fl6(1);c[2113016]=2048;c[3531920]=c[2411386];Vf(0);g=c[2439194]|0;if((g|0)>0){f=c[2406652]|0;b=0;while(1){h[f+(b*40|0)+16>>3]=1.0;c[f+(b*40|0)+32>>2]=3;j=b+1|0;if((j|0)<(g|0)){b=j}else{break}}c[3528400]=f+(b*40|0);j=0;while(1){h[f+(j*40|0)+24>>3]=1.0;c[f+(j*40|0)+36>>2]=3;k=j+1|0;if((k|0)<(g|0)){j=k}else{break}}c[3528400]=f+(j*40|0)}a[7072560]=1;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060]}RI();g=c[2394]|0;b=c[14130368+(g<<2)>>2]|0;if((b|0)!=0){gGC(b|0,9104152,280)|0}c[8452240+(g<<2)>>2]=c[2113054];c[2394]=-1;g=c[2439194]|0;if((g|0)<=0){l=0;return l|0}b=c[2406652]|0;k=0;do{m=b+(k*40|0)|0;n=b+(k*40|0)+12|0;a[n]=0;o=b+(k*40|0)+8|0;c[o>>2]=0;p=a[b+(k*40|0)+14|0]|0;do{if((p&2)!=0&(g|0)>(k|0)){if((p&4)==0){a[b+(k*40|0)+13|0]=1}if((p&1)!=0){break}a[n]=1;c[o>>2]=0}}while(0);k=k+1|0;}while((k|0)<(g|0));c[3528400]=m;l=0;return l|0}}while(0);c[2426636]=0;l=1;return l|0}function fr8(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;fl7();if((c[2392]|0)>=0){a=0;do{b=14130368+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}b=14130384+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}a=a+1|0;}while((a|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;a=c[2439194]|0;b=c[2406652]|0;if((a|0)>0){d=0;e=b;f=a;while(1){a=e+(d*40|0)|0;c[3528400]=a;g=c[a>>2]|0;if((g|0)==0){h=f;i=e}else{gGr(g);c[c[3528400]>>2]=0;h=c[2439194]|0;i=c[2406652]|0}g=d+1|0;if((g|0)<(h|0)){d=g;e=i;f=h}else{j=i;break}}}else{j=b}if((j|0)!=0){gGr(j);c[2406652]=0}c[3528400]=0;c[2439194]=0;c[2442914]=0;j=c[2426636]|0;b=0;while(1){if((b|0)>=1024){k=67150;break}l=9638528+(b<<2)|0;if((c[l>>2]|0)==(j|0)){break}else{b=b+1|0}}if((k|0)==67150){c[2426636]=0;return 0}gGr(j);c[l>>2]=0;c[2426636]=0;return 0}function fr9(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;do{if((a[9623472]|0)!=0){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];b=c[3532592]|0;if((b|0)!=0){gGC(9104152,b|0,280)|0}c[2113054]=c[2113060]}RI();b=c[2394]|0;d=c[14130368+(b<<2)>>2]|0;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[8452240+(b<<2)>>2]=c[2113054];c[2394]=-1;b=c[2439194]|0;if((b|0)<=0){break}d=c[2406652]|0;e=0;do{f=d+(e*40|0)|0;g=d+(e*40|0)+12|0;a[g]=0;h=d+(e*40|0)+8|0;c[h>>2]=0;i=a[d+(e*40|0)+14|0]|0;do{if((i&2)!=0&(b|0)>(e|0)){if((i&4)==0){a[d+(e*40|0)+13|0]=1}if((i&1)!=0){break}a[g]=1;c[h>>2]=0}}while(0);e=e+1|0;}while((e|0)<(b|0));c[3528400]=f}}while(0);a[9625408]=0;a[9625409]=0;a[9625410]=0;f=0;b=0;e=0;d=0;do{b=((a[9632504+f|0]&1)<<f|b&255)&255;e=((a[9630416+f|0]&1)<<f|e&255)&255;d=((a[9551632+f|0]&1)<<f|d&255)&255;f=f+1|0;}while((f|0)<8);a[9625408]=b;a[9625409]=e;a[9625410]=d;if((b&3)==3){d=b&-4;a[9625408]=d;j=d}else{j=b}if((j&12)==12){a[9625408]=j&-13}if((e&3)==3){j=e&-4;a[9625409]=j;k=j}else{k=e}if((k&12)==12){a[9625409]=k&-13}k=c[2392]|0;if((k|0)>=0){gGz(8452240,0,((k|0)>0?(k<<2)+4|0:4)|0)}c[2113054]=0;k=c[2438]|0;e=gGU(k,(k|0)<0|0?-1:0,1e7,0)|0;k=gGS(e,K,15360,0)|0;e=k;c[2113218]=e;c[2113220]=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];k=c[3532592]|0;if((k|0)!=0){gGC(9104152,k|0,280)|0}c[2113054]=c[2113060]}c[2113058]=(e|0)/262|0;k=e-((e*22|0|0)/262|0)|0;c[2113018]=k;a[670576]=0;j=(e|0)/4|0;do{if((j|0)>(k|0)){if((k|0)>0){c[2113056]=k;e=RG(k)|0;c[2113054]=(c[2113054]|0)+e;c[2276108]=-1;c[2113056]=-1;b=(c[2113220]|0)+e|0;c[2113220]=b;l=b}else{l=0}a[670576]=1;b=c[2430398]|0;e=c[2439196]|0;d=e<<11;c[2438976]=b+d;f=(c[2440572]|0)>1;if(f){c[2438977]=(c[2430399]|0)+d}d=e^1;c[2439196]=d;e=d<<11;d=b+e|0;b=(c[3541506]|0)+12288|0;gGC(d|0,b|0,2048)|0;if(f){f=(c[2430399]|0)+e|0;e=(c[3541504]|0)+12288|0;gGC(f|0,e|0,2048)|0}c[8452200+(c[2394]<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0>=1024){m=l;break}RH(4);m=c[2113220]|0}else{m=0}}while(0);l=j-m|0;c[2113056]=l;m=RG(l)|0;c[2113054]=(c[2113054]|0)+m;c[2276108]=-1;c[2113056]=-1;l=(c[2113220]|0)+m|0;c[2113220]=l;m=(c[2113218]<<1|0)/4|0;do{if(a[670576]|0){n=l}else{j=c[2113018]|0;if((m|0)<=(j|0)){n=l;break}if((l|0)<(j|0)){k=j-l|0;c[2113056]=k;j=RG(k)|0;c[2113054]=(c[2113054]|0)+j;c[2276108]=-1;c[2113056]=-1;k=(c[2113220]|0)+j|0;c[2113220]=k;o=k}else{o=l}a[670576]=1;k=c[2430398]|0;j=c[2439196]|0;e=j<<11;c[2438976]=k+e;f=(c[2440572]|0)>1;if(f){c[2438977]=(c[2430399]|0)+e}e=j^1;c[2439196]=e;j=e<<11;e=k+j|0;k=(c[3541506]|0)+12288|0;gGC(e|0,k|0,2048)|0;if(f){f=(c[2430399]|0)+j|0;j=(c[3541504]|0)+12288|0;gGC(f|0,j|0,2048)|0}c[8452200+(c[2394]<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0>=1024){n=o;break}RH(4);n=c[2113220]|0}}while(0);o=m-n|0;c[2113056]=o;n=RG(o)|0;c[2113054]=(c[2113054]|0)+n;c[2276108]=-1;c[2113056]=-1;o=(c[2113220]|0)+n|0;c[2113220]=o;n=((c[2113218]|0)*3|0|0)/4|0;do{if(a[670576]|0){p=o}else{m=c[2113018]|0;if((n|0)<=(m|0)){p=o;break}if((o|0)<(m|0)){l=m-o|0;c[2113056]=l;m=RG(l)|0;c[2113054]=(c[2113054]|0)+m;c[2276108]=-1;c[2113056]=-1;l=(c[2113220]|0)+m|0;c[2113220]=l;q=l}else{q=o}a[670576]=1;l=c[2430398]|0;m=c[2439196]|0;j=m<<11;c[2438976]=l+j;f=(c[2440572]|0)>1;if(f){c[2438977]=(c[2430399]|0)+j}j=m^1;c[2439196]=j;m=j<<11;j=l+m|0;l=(c[3541506]|0)+12288|0;gGC(j|0,l|0,2048)|0;if(f){f=(c[2430399]|0)+m|0;m=(c[3541504]|0)+12288|0;gGC(f|0,m|0,2048)|0}c[8452200+(c[2394]<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0>=1024){p=q;break}RH(4);p=c[2113220]|0}}while(0);q=n-p|0;c[2113056]=q;p=RG(q)|0;c[2113054]=(c[2113054]|0)+p;c[2276108]=-1;c[2113056]=-1;q=(c[2113220]|0)+p|0;c[2113220]=q;p=c[2113218]|0;do{if(a[670576]|0){r=q}else{n=c[2113018]|0;if((p|0)<=(n|0)){r=q;break}if((q|0)<(n|0)){o=n-q|0;c[2113056]=o;n=RG(o)|0;c[2113054]=(c[2113054]|0)+n;c[2276108]=-1;c[2113056]=-1;o=(c[2113220]|0)+n|0;c[2113220]=o;s=o}else{s=q}a[670576]=1;o=c[2430398]|0;n=c[2439196]|0;m=n<<11;c[2438976]=o+m;f=(c[2440572]|0)>1;if(f){c[2438977]=(c[2430399]|0)+m}m=n^1;c[2439196]=m;n=m<<11;m=o+n|0;o=(c[3541506]|0)+12288|0;gGC(m|0,o|0,2048)|0;if(f){f=(c[2430399]|0)+n|0;n=(c[3541504]|0)+12288|0;gGC(f|0,n|0,2048)|0}c[8452200+(c[2394]<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0>=1024){r=s;break}RH(4);r=c[2113220]|0}}while(0);s=p-r|0;c[2113056]=s;r=RG(s)|0;s=(c[2113054]|0)+r|0;c[2113054]=s;c[2276108]=-1;c[2113056]=-1;c[2113220]=(c[2113220]|0)+r;Vg(c[2112964]|0,a[9688]|0?534:0);r=c[2394]|0;p=c[14130368+(r<<2)>>2]|0;if((p|0)!=0){gGC(p|0,9104152,280)|0}c[8452240+(r<<2)>>2]=s;c[2394]=-1;s=c[2112968]|0;if((s|0)==0){return 0}r=c[3531916]|0;p=c[2113308]|0;do{if((c[r>>2]|0)==0){gGz(s|0,0,p*76800|0|0)}else{if((p|0)==2){q=c[r+1152>>2]|0;n=q<<16|q;q=s;f=0;while(1){c[q>>2]=n;c[q+4>>2]=n;c[q+8>>2]=n;c[q+12>>2]=n;c[q+16>>2]=n;c[q+20>>2]=n;c[q+24>>2]=n;c[q+28>>2]=n;o=f+1|0;if((o|0)<4800){q=q+32|0;f=o}else{break}}}else if((p|0)==4){f=c[r+1152>>2]|0;q=0;n=s;while(1){c[n>>2]=f;c[n+4>>2]=f;c[n+8>>2]=f;c[n+12>>2]=f;c[n+16>>2]=f;c[n+20>>2]=f;c[n+24>>2]=f;c[n+28>>2]=f;o=q+1|0;if((o|0)<9600){q=o;n=n+32|0}else{break}}}else if((p|0)==3){n=c[r+1152>>2]|0;q=n>>>8&255;f=n>>>16&255;o=n&255;n=s;m=0;while(1){a[n]=o;a[n+1|0]=q;a[n+2|0]=f;l=m+1|0;if((l|0)<76800){n=n+3|0;m=l}else{break}}}else{break}}}while(0);if(a[7072560]|0){c[2112970]=s;c[2113306]=p;c[2113298]=c[2113300];fl3();t=c[3531916]|0}else{t=r}c[2112966]=t;r=c[2113016]|0;if((r|0)>0){u=0}else{return 0}do{c[t+(u<<2)>>2]=65535;u=u+1|0;}while((u|0)<(r|0));return 0}function fsa(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=c[3531916]|0;do{if((c[b>>2]|0)==0){d=c[2113308]|0;gGz(c[2112968]|0,0,d*76800|0|0);e=d}else{d=c[2113308]|0;if((d|0)==2){f=c[b+1152>>2]|0;g=f<<16|f;f=c[2112968]|0;h=0;while(1){c[f>>2]=g;c[f+4>>2]=g;c[f+8>>2]=g;c[f+12>>2]=g;c[f+16>>2]=g;c[f+20>>2]=g;c[f+24>>2]=g;c[f+28>>2]=g;i=h+1|0;if((i|0)<4800){f=f+32|0;h=i}else{e=2;break}}}else if((d|0)==3){h=c[b+1152>>2]|0;f=h>>>8&255;g=h>>>16&255;i=h&255;h=c[2112968]|0;j=0;while(1){a[h]=i;a[h+1|0]=f;a[h+2|0]=g;k=j+1|0;if((k|0)<76800){h=h+3|0;j=k}else{e=3;break}}}else if((d|0)==4){j=c[b+1152>>2]|0;h=0;g=c[2112968]|0;while(1){c[g>>2]=j;c[g+4>>2]=j;c[g+8>>2]=j;c[g+12>>2]=j;c[g+16>>2]=j;c[g+20>>2]=j;c[g+24>>2]=j;c[g+28>>2]=j;f=h+1|0;if((f|0)<9600){h=f;g=g+32|0}else{e=4;break}}}else{e=d;break}}}while(0);if(a[7072560]|0){c[2112970]=c[2112968];c[2113306]=e;c[2113298]=c[2113300];fl3();l=c[3531916]|0}else{l=b}c[2112966]=l;b=c[2113016]|0;if((b|0)>0){m=0}else{return 0}do{c[l+(m<<2)>>2]=65535;m=m+1|0;}while((m|0)<(b|0));return 0}function fsb(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;e=i;i=i+128|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;l=e+80|0;m=e+96|0;n=e+112|0;o=(d|0)==0;if(!o){c[d>>2]=133527}if((b&96|0)==0){i=e;return 0}gGz(n|0,0,12);p=c[2405574]|0;c[n>>2]=p;c[n+4>>2]=(c[2411478]|0)-p;c[n+12>>2]=162152;gj[c[2076592]&4095](n)|0;n=m|0;do{if((b&64|0)!=0){gGz(l|0,0,16);c[2394]=-1;if((c[2392]|0)<0){break}p=m+9|0;q=k;r=k|0;s=k+4|0;t=k+12|0;u=l|0;v=l+4|0;w=l+12|0;x=0;do{gGC(n|0,614896,11)|0;a[p]=x+48&255;y=8452256+(x<<2)|0;gGz(q|0,0,12);c[r>>2]=y;c[s>>2]=4;c[t>>2]=164976;gj[c[2076592]&4095](k)|0;if((c[y>>2]|0)!=0){c[u>>2]=c[14130368+(x<<2)>>2];c[v>>2]=c[8452184+(x<<2)>>2];c[w>>2]=n;y=c[2076592]|0;gj[y&4095](l)|0}x=x+1|0;}while((x|0)<=(c[2392]|0))}}while(0);if(!o){c[d>>2]=169110}gGz(j|0,0,12);c[j>>2]=9756784;c[j+4>>2]=4;c[j+12>>2]=175504;gj[c[2076592]&4095](j)|0;gGz(h|0,0,12);c[h>>2]=14166032;c[h+4>>2]=8;c[h+12>>2]=504552;gj[c[2076592]&4095](h)|0;gGz(g|0,0,12);c[g>>2]=14165992;c[g+4>>2]=8;c[g+12>>2]=388736;gj[c[2076592]&4095](g)|0;gGz(f|0,0,12);c[f>>2]=14165960;c[f+4>>2]=32;c[f+12>>2]=302352;gj[c[2076592]&4095](f)|0;i=e;return 0}function fsc(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>4){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4314236+(b*112|0)>>2];c[a+104>>2]=c[4314240+(b*112|0)>>2];c[a+108>>2]=c[4314244+(b*112|0)>>2];d=0;return d|0}function fsd(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<5&(d|0)==0)){e=1;return e|0}c[a>>2]=4314136+(b*112|0);e=0;return e|0}function fse(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1339280+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function fsf(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>58){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4314696+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fsg(e){e=e|0;var f=0,g=0,h=0,i=0;f=e&65535;if((e+14336&65535)<2048){if((b[4853030]|0)==27956){g=-1;return g|0}g=a[(c[2385746]|0)+(f-51200)|0]|0;return g|0}if(e<<16>>16!=-6141){g=0;return g|0}if(a[642568]|0){e=(((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)/2|0)-(c[2415218]|0)|0;if((e|0)>0){f4Y(e)|0}c[2161338]=0;g=a[9533344]|0;return g|0}if((c[3528494]|0)!=1){e=c[2439200]|0;f=a[618696+e|0]|0;c[2439200]=(e+1|0)%3|0;g=f;return g|0}f=d[14108680]|0;L87866:do{if((f|0)==4){e=b[4853030]|0;if(e<<16>>16==1390){g=0;return g|0}if(e<<16>>16==1392){g=1;return g|0}if(e<<16>>16==1399){g=83;return g|0}if(e<<16>>16!=27396){g=0;return g|0}g=a[602968+(d[9707344]|0)|0]|0;return g|0}else if((f|0)==1|(f|0)==2){e=a[9543264]|0;switch(e&255|0){case 184:{h=d[9707328]|0;i=(((d[9707336]|0)>>>2)+63298-(h>>>4<<8|h<<4&128)|0)>>>8&255;break L87866;break};case 35:{i=a[602960+(d[9707344]|0)|0]|0;break L87866;break};case 55:{h=(a[9707328]<<6)+(a[9707336]|0)&255;a[9543264]=e|-128;i=h;break L87866;break};case 166:{i=(((d[9707344]|0)*31&65535)-30720&65535)>>>8&255;break L87866;break};case 42:{i=a[9707344]^64;break L87866;break};case 33:{h=a[9707344]|0;i=h<<1|(h&255)>>>7;break L87866;break};case 56:{h=(-(a[9707328]<<4&-128)&255|66)+((d[9707336]|0)>>>2)&255;a[9543264]=e|-128;i=h;break L87866;break};case 32:{i=(a[9707344]&48)==48?32:-128;break L87866;break};case 183:{h=d[9707328]|0;i=(((h<<6&192)+(d[9707336]|0)&12032|h>>>2<<8&3840)>>>8|208)&255;break L87866;break};case 38:{h=(a[9707344]|0)*31&255;a[9543264]=e|-128;i=h;break L87866;break};case 34:{i=((d[9707344]|0)>>>2&3)+1&255;break L87866;break};case 36:{h=d[9707344]|0;i=a[602944+(h>>>1&12|h&3)|0]|0;break L87866;break};case 37:{h=a[9707344]|0;i=h<<4&16|(h&255)>>>3<<7|(h&255)>>>7<<3|(h&255)>>>4&1|(h&255)>>>2<<6&64|(h&255)>>>1<<5&32|(h&255)>>>5<<2&4|(h&255)>>>6<<1&2;break L87866;break};case 115:{i=118;break L87866;break};default:{i=0;break L87866}}}else if((f|0)==3){i=0}else{g=0;return g|0}}while(0);if((b[4853030]|0)!=27396){g=i;return g|0}g=a[602960+(d[9707344]|0)|0]|0;return g|0}function fsh(d){d=d|0;var e=0;if((d+14336&65535)>=2048){e=d<<16>>16==-6141?-125:0;return e|0}if((b[4853030]|0)==27956){e=-1;return e|0}e=a[(c[2385746]|0)+((d&65535)-51200)|0]|0;return e|0}function fsi(e,f){e=e|0;f=f|0;var g=0,h=0;g=e&65535;if((g|0)==59394){c[2429358]=f&255;return}else if((g|0)==59392){c[2429360]=f&255;return}else if((g|0)==59393){c[2429362]=f&255;return}else if((g|0)==59395){do{if(a[642568]|0){g=(((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)/2|0)-(c[2415218]|0)|0;if((g|0)>0){f4Y(g)|0}a[9533352]=f;c[2161344]=1;g=c[3528494]|0;if((g|0)==0){c[2161338]=0}if((c[2415208]|0)==1){h=g;break}c[2415208]=1;b[4830412]=b[4830412]|1;h=g}else{h=c[3528494]|0}}while(0);if((h|0)!=1){return}h=d[14108680]|0;if((h|0)==2){f=b[4853030]|0;if((f<<16>>16|0)==10145){a[9543264]=56;a[9707344]=b[4853036]&255;g=b[4853038]|0;a[9707336]=(g&65535)>>>8&255;a[9707328]=g&255;return}else if((f<<16>>16|0)==10158){a[9543264]=56;return}else if((f<<16>>16|0)==27362){a[9543264]=35;a[9707344]=0;a[9707336]=0;a[9707328]=0;return}else if((f<<16>>16|0)==191){a[9543264]=0;a[9707344]=0;a[9707336]=0;a[9707328]=0;return}else if((f<<16>>16|0)==4310){a[9543264]=35;a[9707344]=0;a[9707336]=0;a[9707328]=0;return}else if((f<<16>>16|0)==4323){a[9543264]=35;a[9707344]=b[4853036]&255;g=b[4853038]|0;a[9707336]=(g&65535)>>>8&255;a[9707328]=g&255;return}else if((f<<16>>16|0)==2857){a[9543264]=41;a[9707344]=b[4853036]&255;g=b[4853038]|0;a[9707336]=(g&65535)>>>8&255;a[9707328]=g&255;return}else if((f<<16>>16|0)==4415){a[9543264]=115;a[9707344]=0;a[9707336]=0;a[9707328]=0;return}else if((f<<16>>16|0)==4491){a[9543264]=36;a[9707344]=0;a[9707336]=0;a[9707328]=0;return}else if((f<<16>>16|0)==4504){a[9543264]=36;a[9707344]=b[4853036]&255;g=b[4853038]|0;a[9707336]=(g&65535)>>>8&255;a[9707328]=g&255;return}else if((f<<16>>16|0)==6648){a[9543264]=38;a[9707344]=0;a[9707336]=0;a[9707328]=0;return}else if((f<<16>>16|0)==6661){a[9543264]=38;a[9707344]=b[4853036]&255;g=b[4853038]|0;a[9707336]=(g&65535)>>>8&255;a[9707328]=g&255;return}else if((f<<16>>16|0)==2990){a[9543264]=32;a[9707344]=0;a[9707336]=0;a[9707328]=0;return}else if((f<<16>>16|0)==3003){a[9543264]=32;a[9707344]=b[4853036]&255;g=b[4853038]|0;a[9707336]=(g&65535)>>>8&255;a[9707328]=g&255;return}else if((f<<16>>16|0)==3117){a[9543264]=0;a[9707344]=0;a[9707336]=0;a[9707328]=0;return}else if((f<<16>>16|0)==3599){a[9543264]=36;a[9707344]=b[4853036]&255;g=b[4853038]|0;a[9707336]=(g&65535)>>>8&255;a[9707328]=g&255;return}else if((f<<16>>16|0)==3652){a[9543264]=35;a[9707344]=0;a[9707336]=0;a[9707328]=0;return}else if((f<<16>>16|0)==3669){a[9543264]=35;a[9707344]=b[4853036]&255;g=b[4853038]|0;a[9707336]=(g&65535)>>>8&255;a[9707328]=g&255;return}else if((f<<16>>16|0)==3724){a[9543264]=34;a[9707344]=0;a[9707336]=0;a[9707328]=0;return}else if((f<<16>>16|0)==3739){a[9543264]=34;a[9707344]=b[4853036]&255;g=b[4853038]|0;a[9707336]=(g&65535)>>>8&255;a[9707328]=g&255;return}else if((f<<16>>16|0)==27379){a[9543264]=35;a[9707344]=b[4853036]&255;g=b[4853038]|0;a[9707336]=(g&65535)>>>8&255;a[9707328]=g&255;return}else if((f<<16>>16|0)==6845){a[9543264]=55;a[9707344]=0;a[9707336]=0;a[9707328]=0;return}else if((f<<16>>16|0)==6860){a[9543264]=55;a[9707344]=b[4853036]&255;g=b[4853038]|0;a[9707336]=(g&65535)>>>8&255;a[9707328]=g&255;return}else if((f<<16>>16|0)==6873){a[9543264]=55;return}else if((f<<16>>16|0)==10130){a[9543264]=56;a[9707344]=0;a[9707336]=0;a[9707328]=0;return}else if((f<<16>>16|0)==3190){a[9543264]=42;a[9707344]=0;a[9707336]=0;a[9707328]=0;return}else if((f<<16>>16|0)==3203){a[9543264]=42;a[9707344]=b[4853036]&255;g=b[4853038]|0;a[9707336]=(g&65535)>>>8&255;a[9707328]=g&255;return}else if((f<<16>>16|0)==3586){a[9543264]=36;a[9707344]=0;a[9707336]=0;a[9707328]=0;return}else if((f<<16>>16|0)==2773){a[9543264]=33;a[9707344]=0;a[9707336]=0;a[9707328]=0;return}else if((f<<16>>16|0)==2786){a[9543264]=33;a[9707344]=b[4853036]&255;g=b[4853038]|0;a[9707336]=(g&65535)>>>8&255;a[9707328]=g&255;return}else if((f<<16>>16|0)==2844){a[9543264]=41;a[9707344]=0;a[9707336]=0;a[9707328]=0;return}else if((f<<16>>16|0)==1376){a[9543264]=37;a[9707344]=0;a[9707336]=0;a[9707328]=0;return}else if((f<<16>>16|0)==1389){a[9543264]=37;a[9707344]=b[4853036]&255;f=b[4853038]|0;a[9707336]=(f&65535)>>>8&255;a[9707328]=f&255;return}else{return}}else if((h|0)==1){f=b[4853030]|0;if((f<<16>>16|0)==4307){a[9543264]=36;a[9707344]=b[4853036]&255;g=b[4853038]|0;a[9707336]=(g&65535)>>>8&255;a[9707328]=g&255;return}else if((f<<16>>16|0)==1376){a[9543264]=37;a[9707344]=0;a[9707336]=0;a[9707328]=0;return}else if((f<<16>>16|0)==9918){a[9543264]=56;a[9707344]=b[4853036]&255;g=b[4853038]|0;a[9707336]=(g&65535)>>>8&255;a[9707328]=g&255;return}else if((f<<16>>16|0)==9931){a[9543264]=56;return}else if((f<<16>>16|0)==27175){a[9543264]=35;a[9707344]=0;a[9707336]=0;a[9707328]=0;return}else if((f<<16>>16|0)==2670){a[9543264]=41;a[9707344]=b[4853036]&255;g=b[4853038]|0;a[9707336]=(g&65535)>>>8&255;a[9707328]=g&255;return}else if((f<<16>>16|0)==2787){a[9543264]=32;a[9707344]=0;a[9707336]=0;a[9707328]=0;return}else if((f<<16>>16|0)==27192){a[9543264]=35;a[9707344]=b[4853036]&255;g=b[4853038]|0;a[9707336]=(g&65535)>>>8&255;a[9707328]=g&255;return}else if((f<<16>>16|0)==4218){a[9543264]=115;a[9707344]=0;a[9707336]=0;a[9707328]=0;return}else if((f<<16>>16|0)==2800){a[9543264]=32;a[9707344]=b[4853036]&255;g=b[4853038]|0;a[9707336]=(g&65535)>>>8&255;a[9707328]=g&255;return}else if((f<<16>>16|0)==2914){a[9543264]=0;a[9707344]=0;a[9707336]=0;a[9707328]=0;return}else if((f<<16>>16|0)==2987){a[9543264]=42;a[9707344]=0;a[9707336]=0;a[9707328]=0;return}else if((f<<16>>16|0)==2583){a[9543264]=33;a[9707344]=b[4853036]&255;g=b[4853038]|0;a[9707336]=(g&65535)>>>8&255;a[9707328]=g&255;return}else if((f<<16>>16|0)==191){a[9543264]=0;a[9707344]=0;a[9707336]=0;a[9707328]=0;return}else if((f<<16>>16|0)==4294){a[9543264]=36;a[9707344]=0;a[9707336]=0;a[9707328]=0;return}else if((f<<16>>16|0)==6416){a[9543264]=38;a[9707344]=0;a[9707336]=0;a[9707328]=0;return}else if((f<<16>>16|0)==6429){a[9543264]=38;a[9707344]=b[4853036]&255;g=b[4853038]|0;a[9707336]=(g&65535)>>>8&255;a[9707328]=g&255;return}else if((f<<16>>16|0)==6613){a[9543264]=55;a[9707344]=0;a[9707336]=0;a[9707328]=0;return}else if((f<<16>>16|0)==6628){a[9543264]=55;a[9707344]=b[4853036]&255;g=b[4853038]|0;a[9707336]=(g&65535)>>>8&255;a[9707328]=g&255;return}else if((f<<16>>16|0)==3e3){a[9543264]=42;a[9707344]=b[4853036]&255;g=b[4853038]|0;a[9707336]=(g&65535)>>>8&255;a[9707328]=g&255;return}else if((f<<16>>16|0)==3383){a[9543264]=36;a[9707344]=0;a[9707336]=0;a[9707328]=0;return}else if((f<<16>>16|0)==6641){a[9543264]=55;return}else if((f<<16>>16|0)==9903){a[9543264]=56;a[9707344]=0;a[9707336]=0;a[9707328]=0;return}else if((f<<16>>16|0)==1389){a[9543264]=37;a[9707344]=b[4853036]&255;g=b[4853038]|0;a[9707336]=(g&65535)>>>8&255;a[9707328]=g&255;return}else if((f<<16>>16|0)==2570){a[9543264]=33;a[9707344]=0;a[9707336]=0;a[9707328]=0;return}else if((f<<16>>16|0)==3396){a[9543264]=36;a[9707344]=b[4853036]&255;g=b[4853038]|0;a[9707336]=(g&65535)>>>8&255;a[9707328]=g&255;return}else if((f<<16>>16|0)==3449){a[9543264]=35;a[9707344]=0;a[9707336]=0;a[9707328]=0;return}else if((f<<16>>16|0)==4113){a[9543264]=35;a[9707344]=0;a[9707336]=0;a[9707328]=0;return}else if((f<<16>>16|0)==4126){a[9543264]=35;a[9707344]=b[4853036]&255;g=b[4853038]|0;a[9707336]=(g&65535)>>>8&255;a[9707328]=g&255;return}else if((f<<16>>16|0)==2641){a[9543264]=41;a[9707344]=0;a[9707336]=0;a[9707328]=0;return}else if((f<<16>>16|0)==3466){a[9543264]=35;a[9707344]=b[4853036]&255;g=b[4853038]|0;a[9707336]=(g&65535)>>>8&255;a[9707328]=g&255;return}else if((f<<16>>16|0)==3521){a[9543264]=34;a[9707344]=0;a[9707336]=0;a[9707328]=0;return}else if((f<<16>>16|0)==3536){a[9543264]=34;a[9707344]=b[4853036]&255;f=b[4853038]|0;a[9707336]=(f&65535)>>>8&255;a[9707328]=f&255;return}else{return}}else if((h|0)==3){f=b[4853030]|0;if((f<<16>>16|0)==27362){a[9543264]=0;a[9707344]=0;a[9707336]=0;a[9707328]=0;return}else if((f<<16>>16|0)==27379){a[9543264]=0;a[9707344]=b[4853036]&255;f=b[4853038]|0;a[9707336]=(f&65535)>>>8&255;a[9707328]=f&255;return}else{return}}else if((h|0)==4){h=b[4853030]|0;if((h<<16>>16|0)==27362){a[9543264]=0;a[9707344]=0;a[9707336]=0;a[9707328]=0;return}else if((h<<16>>16|0)==27379){a[9543264]=0;a[9707344]=b[4853036]&255;h=b[4853038]|0;a[9707336]=(h&65535)>>>8&255;a[9707328]=h&255;return}else{return}}else{return}}else{return}}function fsj(a,b){a=a|0;b=b|0;var d=0;d=a&65535;if((d|0)==59392){c[2429362]=b&255;return}else if((d|0)==59394){c[2429358]=b&255;return}else if((d|0)==59395){c[2429360]=b&255;return}else{return}}function fsk(b){b=b|0;var d=0,e=0,f=0;if((b&255)!=0){d=0;return d|0}b=c[2440440]|0;e=a[619560+b|0]|0;f=b+1|0;c[2440440]=(f|0)>2?0:f;if(!(a[642568]|0)){d=e;return d|0}d=(((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)/2|0)-(c[2415218]|0)|0;if((d|0)>0){f4Y(d)|0}d=e&-7;e=(c[2161344]|0)==0?d|2:d;return((c[2161338]|0)==0?e|4:e)|0}function fsl(a){a=a|0;var c=0,d=0;do{if((a&255)==0){c=b[4853030]|0;if(c<<16>>16==27934){d=0;break}if(c<<16>>16==27940){d=6;break}if(c<<16>>16==27948){d=2;break}d=c<<16>>16==27956?4:0}else{d=0}}while(0);return d|0}function fsm(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;switch(d&255|0){case 1:{a[9747080]=1;return};case 6:{a[9731928]=0;a[9706117]=0;return};case 7:{a[9731928]=1;return};case 8:{d=c[2418102]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=128;g=128;while(1){c[e+76+(g<<2)>>2]=d+(g<<8);h=f+1&65535;if((h&65535)>191){i=128;j=128;break}else{f=h;g=h&65535}}while(1){g=d+(j<<8)|0;c[e+76+(j+512<<2)>>2]=g;c[e+76+(j+768<<2)>>2]=g;g=i+1&65535;if((g&65535)>191){break}else{i=g;j=g&65535}}return};case 9:{j=c[2418102]|0;i=c[9757320+(c[1836236]<<2)>>2]|0;e=128;d=128;while(1){c[i+76+(d<<2)>>2]=j+((d<<8)+16384);g=e+1&65535;if((g&65535)>191){k=128;l=128;break}else{e=g;d=g&65535}}while(1){d=j+((l<<8)+16384)|0;c[i+76+(l+512<<2)>>2]=d;c[i+76+(l+768<<2)>>2]=d;d=k+1&65535;if((d&65535)>191){break}else{k=d;l=d&65535}}return};case 0:{if((a[9747080]&1)==0){return}l=c[1836236]|0;k=c[9757320+(l<<2)>>2]|0;if((k|0)!=0){i=k;gGC(i|0,9706056,76)|0}c[9752472+(l<<2)>>2]=c[2433530];c[14113936+(l<<2)>>2]=c[2076596];c[9669104+(l<<2)>>2]=c[3541536];c[1836236]=-1;l=c[2439331]|0;i=(l|0)==0;if(!i){k=l;gGC(9706056,k|0,76)|0}k=c[2438119]|0;c[2433530]=k;j=c[3528485]|0;c[2076596]=j;d=c[2417277]|0;c[3541536]=d;c[1836236]=1;gGz(9706056,0,76);if(!i){i=l;gGC(i|0,9706056,76)|0}c[2438119]=k;c[3528485]=j;c[2417277]=d;c[1836236]=-1;d=c[2439330]|0;if((d|0)!=0){j=d;gGC(9706056,j|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;a[9747080]=0;return};default:{return}}}function fsn(b){b=b|0;var d=0,e=0,f=0;d=b&65535;if((d|0)==41105){b=c[3542291]|0;if((b|0)>15){e=0;return e|0}do{if((b|0)==15){f=c[3542288]|0;if((f|0)==0){break}a[14169183]=gj[f&4095](0)|0}else if((b|0)==14){f=c[3542287]|0;if((f|0)==0){break}a[14169182]=gj[f&4095](0)|0}}while(0);e=a[14169168+b|0]|0;return e|0}else if((d|0)==41089){d=c[3542228]|0;if((d|0)>15){e=0;return e|0}do{if((d|0)==15){b=c[3542225]|0;if((b|0)==0){break}a[14168931]=gj[b&4095](0)|0}else if((d|0)==14){b=c[3542224]|0;if((b|0)==0){break}a[14168930]=gj[b&4095](0)|0}}while(0);e=a[14168916+d|0]|0;return e|0}else{e=0;return e|0}return 0}function fso(b,d){b=b|0;d=d|0;var e=0;switch(b&65535|0){case 41090:{b=d&255;e=c[3542228]|0;if((e|0)>15){return}do{if((e|0)<14){if((e|0)!=13){if((a[14168916+e|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(0,e,b);return};case 41104:{c[3542291]=d&15;return};case 41106:{b=d&255;e=c[3542291]|0;if((e|0)>15){return}do{if((e|0)<14){if((e|0)!=13){if((a[14169168+e|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(1,e,b);return};case 41088:{c[3542228]=d&15;return};case 41184:{a[9747072]=1;return};default:{return}}}function fsp(a){a=a|0;return 0}function fsq(a,b){a=a|0;b=b|0;return}function fsr(b){b=b|0;a[9533344]=a[b]|0;c[2161338]=1;return}function fss(){var b=0;a[8451512]=0;if((c[2161344]|0)==0){a[8451512]=1;b=3}else{b=2}if((c[2161338]|0)==0){return}a[8451512]=b;return}function fst(b){b=b|0;a[9533344]=a[b]|0;return}function fsu(b){b=b|0;var e=0;e=a[9533792]|0;do{if((e&2)!=0){if((a[b]&2)!=0){break}if((a[8451520]&2)==0){break}a[8451544]=a[9533352]|0;if(!((c[2161344]|0)==0|(c[2415208]|0)==0)){c[2415208]=0}c[2161344]=0}}while(0);do{if((e&4)!=0){if((a[b]&4)==0){break}if((a[8451520]&4)!=0){break}a[9533344]=a[8451536]|0;c[2161338]=1}}while(0);do{if((e&8)!=0){if((a[b]&8)!=0){break}if((a[8451520]&8)==0){break}c[2429360]=d[8451536]|0}}while(0);if((e&16)==0){return}if((a[b]&16)!=0){return}if((a[8451520]&16)==0){return}c[2429362]=d[8451536]|0;return}function fsv(){var b=0;a[8451512]=0;if((c[2161344]|0)==0){b=2}else{a[8451512]=1;b=3}if((c[2161338]|0)!=0){return}a[8451512]=b;return}function fsw(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5653364+(b*112|0)>>2];c[a+104>>2]=c[5653368+(b*112|0)>>2];c[a+108>>2]=c[5653372+(b*112|0)>>2];d=0;return d|0}function fsx(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=5653264+(b*112|0);e=0;return e|0}function fsy(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=2152392+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function fsz(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>38){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5655392+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fsA(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0.0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0;e=i;i=i+3704|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;B=e+1200|0;C=e+1312|0;D=e+1320|0;E=e+1432|0;F=e+1440|0;G=e+1552|0;H=e+1560|0;I=e+1672|0;J=e+1680|0;K=e+1792|0;L=e+1800|0;M=e+1912|0;N=e+1920|0;O=e+2032|0;P=e+2040|0;Q=e+2152|0;R=e+2160|0;S=e+2272|0;T=e+2280|0;U=e+2392|0;V=e+2400|0;W=e+2512|0;X=e+2520|0;Y=e+2632|0;Z=e+2640|0;_=e+2752|0;$=e+2760|0;aa=e+2872|0;ab=e+2880|0;ac=e+2992|0;ad=e+3e3|0;ae=e+3112|0;af=e+3120|0;ah=e+3232|0;ai=e+3240|0;aj=e+3352|0;ak=e+3360|0;al=e+3472|0;am=e+3480|0;an=e+3592|0;c[3528494]=-1;ao=c[c[642608+(c[2436]<<2)>>2]>>2]|0;do{if((fa(ao|0,168208)|0)==0){ap=67693}else{if((fa(ao|0,178920)|0)==0){ap=67693;break}if((fa(ao|0,115560)|0)==0){ap=67693;break}if((fa(ao|0,70624)|0)==0){ap=67693;break}if((fa(ao|0,562216)|0)==0){ap=67693}}}while(0);if((ap|0)==67693){c[3528494]=0}do{if((fa(ao|0,532328)|0)==0){ap=67698}else{if((fa(ao|0,481304)|0)==0){ap=67698;break}if((fa(ao|0,424992)|0)==0){ap=67698;break}if((fa(ao|0,447336)|0)==0){ap=67698}}}while(0);do{if((ap|0)==67698){c[3528494]=1;if((fa(ao|0,532328)|0)==0){a[14108680]=1}if((fa(ao|0,481304)|0)==0){a[14108680]=2}if((fa(ao|0,424992)|0)==0){a[14108680]=3}if((fa(ao|0,447336)|0)!=0){break}a[14108680]=4}}while(0);do{if((fa(ao|0,401592)|0)==0){ap=67711}else{if((fa(ao|0,368856)|0)==0){ap=67711;break}if((fa(ao|0,352984)|0)==0){ap=67711;break}if((fa(ao|0,337184)|0)==0){ap=67711;break}if((fa(ao|0,320360)|0)==0){ap=67711}}}while(0);if((ap|0)==67711){c[3528494]=2}c[2426634]=0;c[2418102]=0;c[2418088]=73728;c[2418086]=81920;c[2433270]=83968;c[2430052]=149504;c[2433266]=411648;c[2405572]=673792;c[2418216]=673792;c[2385746]=675840;c[2433272]=677888;c[2430054]=681984;c[2430056]=684032;c[2433268]=686080;c[2418190]=690176;c[2411474]=690304;c[2385356]=690304;ao=a[9688]|0?6408:0;c[2429692]=ao+690304;c[2433274]=ao+691072;aq=ao+692096|0;c[2414014]=aq;ao=aq;aq=0;while(1){if((aq|0)>=1024){break}ar=9638528+(aq<<2)|0;if((c[ar>>2]|0)==0){ap=67715;break}else{aq=aq+1|0}}do{if((ap|0)==67715){aq=gGq(ao)|0;c[ar>>2]=aq;if((aq|0)==0){break}gGz(aq|0,0,ao|0);c[2426634]=aq;gGz(aq|0,0,ao|0);c[2418102]=aq;c[2418088]=aq+73728;c[2418086]=aq+81920;c[2433270]=aq+83968;c[2430052]=aq+149504;c[2433266]=aq+411648;as=aq+673792|0;c[2405572]=as;c[2418216]=as;c[2385746]=aq+675840;c[2433272]=aq+677888;c[2430054]=aq+681984;c[2430056]=aq+684032;c[2433268]=aq+686080;c[2418190]=aq+690176;as=aq+690304|0;c[2411474]=as;c[2385356]=as;as=a[9688]|0?6408:0;c[2429692]=aq+(as+690304);c[2433274]=aq+(as+691072);c[2414014]=aq+(as+692096);as=c[642608+(c[2436]<<2)>>2]|0;at=c[as>>2]|0;au=(fa(at|0,337184)|0)==0;av=(fa(at|0,320360)|0)==0;at=av?2:au&1;aw=c[3528494]|0;do{if((aw|0)==2){do{if((c[3542200]|0)==0){ax=1}else{ay=X+108|0;c[ay>>2]=0;az=X+100|0;c[az>>2]=0;aA=c[as+76>>2]|0;gA[aA&16383](X,0)|0;if((c[ay>>2]|0)==0){ax=0;break}ay=c[az>>2]|0;c[Y>>2]=9534384;az=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[az&16383](Y,0,0)|0;if((ay|0)<1){ax=1;break}ax=(gzL(aq,0,0)|0)!=0|0}}while(0);if(au){if((ax|0)!=0){aB=1;i=e;return aB|0}ay=(c[2418102]|0)+16384|0;if((c[3542200]|0)==0){aB=1;i=e;return aB|0}az=V+108|0;c[az>>2]=0;aA=V+100|0;c[aA>>2]=0;aC=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aC&16383](V,1)|0;do{if((c[az>>2]|0)!=0){aC=c[aA>>2]|0;c[W>>2]=9534384;aD=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aD&16383](W,1,0)|0;if((aC|0)<1){aB=1;i=e;return aB|0}if((gzL(ay,0,1)|0)==0){break}else{aB=1}i=e;return aB|0}}while(0);ay=(c[2418102]|0)+32768|0;if((c[3542200]|0)==0){aB=1;i=e;return aB|0}aA=T+108|0;c[aA>>2]=0;az=T+100|0;c[az>>2]=0;aC=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aC&16383](T,2)|0;if((c[aA>>2]|0)==0){ap=67775;break}aA=c[az>>2]|0;c[U>>2]=9534384;az=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[az&16383](U,2,0)|0;if((aA|0)<1){aB=1;i=e;return aB|0}if((gzL(ay,0,2)|0)==0){ap=67775;break}else{aB=1}i=e;return aB|0}ay=(ax|0)!=0;if(!av){if(ay){aB=1;i=e;return aB|0}aA=(c[2418102]|0)+32768|0;if((c[3542200]|0)==0){aB=1;i=e;return aB|0}az=L+108|0;c[az>>2]=0;aC=L+100|0;c[aC>>2]=0;aD=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aD&16383](L,1)|0;if((c[az>>2]|0)==0){ap=67775;break}az=c[aC>>2]|0;c[M>>2]=9534384;aC=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aC&16383](M,1,0)|0;if((az|0)<1){aB=1;i=e;return aB|0}if((gzL(aA,0,1)|0)==0){ap=67775;break}else{aB=1}i=e;return aB|0}if(ay){aB=1;i=e;return aB|0}ay=(c[2418102]|0)+16384|0;if((c[3542200]|0)==0){aB=1;i=e;return aB|0}aA=R+108|0;c[aA>>2]=0;az=R+100|0;c[az>>2]=0;aC=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aC&16383](R,1)|0;do{if((c[aA>>2]|0)!=0){aC=c[az>>2]|0;c[S>>2]=9534384;aD=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aD&16383](S,1,0)|0;if((aC|0)<1){aB=1;i=e;return aB|0}if((gzL(ay,0,1)|0)==0){break}else{aB=1}i=e;return aB|0}}while(0);ay=(c[2418102]|0)+65536|0;if((c[3542200]|0)==0){aB=1;i=e;return aB|0}az=P+108|0;c[az>>2]=0;aA=P+100|0;c[aA>>2]=0;aC=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aC&16383](P,2)|0;do{if((c[az>>2]|0)!=0){aC=c[aA>>2]|0;c[Q>>2]=9534384;aD=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aD&16383](Q,2,0)|0;if((aC|0)<1){aB=1;i=e;return aB|0}if((gzL(ay,0,2)|0)==0){break}else{aB=1}i=e;return aB|0}}while(0);ay=(c[2418102]|0)+32768|0;if((c[3542200]|0)==0){aB=1;i=e;return aB|0}aA=N+108|0;c[aA>>2]=0;az=N+100|0;c[az>>2]=0;aC=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aC&16383](N,3)|0;if((c[aA>>2]|0)==0){ap=67775;break}aA=c[az>>2]|0;c[O>>2]=9534384;az=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[az&16383](O,3,0)|0;if((aA|0)<1){aB=1;i=e;return aB|0}if((gzL(ay,0,3)|0)==0){ap=67775;break}else{aB=1}i=e;return aB|0}else if((aw|0)==0){if((c[3542200]|0)==0){aB=1;i=e;return aB|0}ay=ai+108|0;c[ay>>2]=0;aA=ai+100|0;c[aA>>2]=0;gA[c[as+76>>2]&16383](ai,0)|0;do{if((c[ay>>2]|0)!=0){az=c[aA>>2]|0;c[aj>>2]=9534384;aC=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aC&16383](aj,0,0)|0;if((az|0)<1){aB=1;i=e;return aB|0}if((gzL(aq,0,0)|0)==0){break}else{aB=1}i=e;return aB|0}}while(0);aA=(c[2418102]|0)+16384|0;if((c[3542200]|0)==0){aB=1;i=e;return aB|0}ay=af+108|0;c[ay>>2]=0;az=af+100|0;c[az>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](af,1)|0;do{if((c[ay>>2]|0)!=0){aC=c[az>>2]|0;c[ah>>2]=9534384;aD=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aD&16383](ah,1,0)|0;if((aC|0)<1){aB=1;i=e;return aB|0}if((gzL(aA,0,1)|0)==0){break}else{aB=1}i=e;return aB|0}}while(0);aA=(c[2418102]|0)+32768|0;if((c[3542200]|0)==0){aB=1;i=e;return aB|0}az=ad+108|0;c[az>>2]=0;ay=ad+100|0;c[ay>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](ad,2)|0;if((c[az>>2]|0)==0){ap=67775;break}az=c[ay>>2]|0;c[ae>>2]=9534384;gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](ae,2,0)|0;if((az|0)<1){aB=1;i=e;return aB|0}if((gzL(aA,0,2)|0)==0){ap=67775;break}else{aB=1}i=e;return aB|0}else if((aw|0)==1){if((c[3542200]|0)==0){aB=1;i=e;return aB|0}aA=ab+108|0;c[aA>>2]=0;az=ab+100|0;c[az>>2]=0;gA[c[as+76>>2]&16383](ab,0)|0;do{if((c[aA>>2]|0)!=0){ay=c[az>>2]|0;c[ac>>2]=9534384;aC=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aC&16383](ac,0,0)|0;if((ay|0)<1){aB=1;i=e;return aB|0}if((gzL(aq,0,0)|0)==0){break}else{aB=1}i=e;return aB|0}}while(0);az=(c[2418102]|0)+16384|0;if((c[3542200]|0)==0){aB=1;i=e;return aB|0}aA=$+108|0;c[aA>>2]=0;ay=$+100|0;c[ay>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383]($,1)|0;do{if((c[aA>>2]|0)!=0){aC=c[ay>>2]|0;c[aa>>2]=9534384;aD=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aD&16383](aa,1,0)|0;if((aC|0)<1){aB=1;i=e;return aB|0}if((gzL(az,0,1)|0)==0){break}else{aB=1}i=e;return aB|0}}while(0);az=(c[2418102]|0)+32768|0;if((c[3542200]|0)==0){aB=1;i=e;return aB|0}ay=Z+108|0;c[ay>>2]=0;aA=Z+100|0;c[aA>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](Z,2)|0;if((c[ay>>2]|0)==0){ap=67775;break}ay=c[aA>>2]|0;c[_>>2]=9534384;gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](_,2,0)|0;if((ay|0)<1){aB=1;i=e;return aB|0}if((gzL(az,0,2)|0)==0){ap=67775;break}else{aB=1}i=e;return aB|0}else{aE=aw}}while(0);if((ap|0)==67775){aE=c[3528494]|0}if((aE|0)==0){aF=3}else if((aE|0)==1){aF=3}else if((aE|0)==2){aF=at+2|0}else{aF=0}c[am+108>>2]=0;aw=am+100|0;c[aw>>2]=0;aq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aq&16383](am,aF)|0;aq=c[aw>>2]|0;aw=aq<<2;as=0;while(1){if((as|0)>=1024){aG=0;break}aH=9638528+(as<<2)|0;if((c[aH>>2]|0)==0){ap=67783;break}else{as=as+1|0}}do{if((ap|0)==67783){as=gGq(aw)|0;c[aH>>2]=as;if((as|0)==0){aG=0;break}gGz(as|0,0,aw|0);aG=as}}while(0);do{if((c[3542200]|0)==0){aI=1}else{aw=J+108|0;c[aw>>2]=0;as=J+100|0;c[as>>2]=0;av=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[av&16383](J,aF)|0;if((c[aw>>2]|0)==0){aI=0;break}aw=c[as>>2]|0;c[K>>2]=9534384;as=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[as&16383](K,aF,0)|0;if((aw|0)<1){aI=1;break}aI=(gzL(aG,0,aF)|0)!=0|0}}while(0);aw=aG+aq|0;as=aF+1|0;do{if((c[3542200]|0)==0){aJ=1}else{av=H+108|0;c[av>>2]=0;au=H+100|0;c[au>>2]=0;az=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[az&16383](H,as)|0;if((c[av>>2]|0)==0){aJ=0;break}av=c[au>>2]|0;c[I>>2]=9534384;au=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[au&16383](I,as,0)|0;if((av|0)<1){aJ=1;break}aJ=(gzL(aw,0,as)|0)!=0|0}}while(0);as=aJ|aI;aw=aq<<1;av=aG+aw|0;au=aF+2|0;do{if((c[3542200]|0)==0){aK=1}else{az=F+108|0;c[az>>2]=0;ay=F+100|0;c[ay>>2]=0;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aA&16383](F,au)|0;if((c[az>>2]|0)==0){aK=0;break}az=c[ay>>2]|0;c[G>>2]=9534384;ay=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ay&16383](G,au,0)|0;if((az|0)<1){aK=1;break}aK=(gzL(av,0,au)|0)!=0|0}}while(0);au=as|aK;av=aq*3|0;az=aG+av|0;ay=aF+3|0;do{if((c[3542200]|0)==0){aL=1}else{aA=D+108|0;c[aA>>2]=0;aC=D+100|0;c[aC>>2]=0;aD=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aD&16383](D,ay)|0;if((c[aA>>2]|0)==0){aL=0;break}aA=c[aC>>2]|0;c[E>>2]=9534384;aC=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aC&16383](E,ay,0)|0;if((aA|0)<1){aL=1;break}aL=(gzL(az,0,ay)|0)!=0|0}}while(0);ay=au|aL;if((aq|0)>0){az=c[2430052]|0;as=0;while(1){aA=aG+as|0;aC=as<<3;aD=aG+(as+aq)|0;aM=aG+(as+aw)|0;aN=aG+(as+av)|0;aO=0;do{aP=7-aO|0;aQ=(d[aA]|0)>>>(aP>>>0)<<3&8;aR=az+(aO+aC)|0;a[aR]=aQ;aS=(d[aD]|0)>>>(aP>>>0)<<2&4|aQ&255;a[aR]=aS&255;aQ=(d[aM]|0)>>>(aP>>>0)<<1&2|aS;a[aR]=aQ&255;a[aR]=(aQ|(d[aN]|0)>>>(aP>>>0)&1)&255;aO=aO+1|0;}while((aO|0)<8);aO=as+1|0;if((aO|0)<(aq|0)){as=aO}else{aT=0;break}}}else{aT=0}while(1){if((aT|0)>=1024){break}aU=9638528+(aT<<2)|0;if((c[aU>>2]|0)==(aG|0)){ap=67808;break}else{aT=aT+1|0}}if((ap|0)==67808){gGr(aG);c[aU>>2]=0}c[2429364]=(aq>>5)-1;if((ay|0)!=0){aB=1;i=e;return aB|0}as=c[3528494]|0;if((as|0)==0){aV=7}else if((as|0)==1){aV=7}else if((as|0)==2){aV=at+6|0}else{aV=0}as=0;while(1){if((as|0)>=1024){aW=0;break}aX=9638528+(as<<2)|0;if((c[aX>>2]|0)==0){ap=67817;break}else{as=as+1|0}}do{if((ap|0)==67817){as=gGq(16384)|0;c[aX>>2]=as;if((as|0)==0){aW=0;break}gGz(as|0,0,16384);aW=as}}while(0);if((c[3542200]|0)==0){aB=1;i=e;return aB|0}as=B+108|0;c[as>>2]=0;ay=B+100|0;c[ay>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](B,aV)|0;do{if((c[as>>2]|0)!=0){aq=c[ay>>2]|0;c[C>>2]=9534384;az=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[az&16383](C,aV,0)|0;if((aq|0)<1){aB=1;i=e;return aB|0}if((gzL(aW,0,aV)|0)==0){break}else{aB=1}i=e;return aB|0}}while(0);ay=aW+8192|0;as=aV+1|0;if((c[3542200]|0)==0){aB=1;i=e;return aB|0}aq=z+108|0;c[aq>>2]=0;az=z+100|0;c[az>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,as)|0;do{if((c[aq>>2]|0)!=0){av=c[az>>2]|0;c[A>>2]=9534384;aw=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aw&16383](A,as,0)|0;if((av|0)<1){aB=1;i=e;return aB|0}if((gzL(ay,0,as)|0)==0){break}else{aB=1}i=e;return aB|0}}while(0);as=c[2433270]|0;ay=0;while(1){az=aW+ay|0;aq=ay<<3;av=aW+(ay+8192)|0;aw=0;do{au=7-aw|0;aO=(d[az]|0)>>>(au>>>0)<<1&2;aN=as+(aw+aq)|0;a[aN]=aO;a[aN]=(aO&255|(d[av]|0)>>>(au>>>0)&1)&255;aw=aw+1|0;}while((aw|0)<8);aw=ay+1|0;if((aw|0)<8192){ay=aw}else{aY=0;break}}while(1){if((aY|0)>=1024){break}aZ=9638528+(aY<<2)|0;if((c[aZ>>2]|0)==(aW|0)){ap=67833;break}else{aY=aY+1|0}}if((ap|0)==67833){gGr(aW);c[aZ>>2]=0}ay=c[3528494]|0;if((ay|0)==0){a_=9}else if((ay|0)==1){a_=9}else if((ay|0)==2){a_=at|8}else{a_=0}c[an+108>>2]=0;ay=an+100|0;c[ay>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](an,a_)|0;as=c[ay>>2]|0;ay=as<<2;aw=0;while(1){if((aw|0)>=1024){a$=0;break}a0=9638528+(aw<<2)|0;if((c[a0>>2]|0)==0){ap=67841;break}else{aw=aw+1|0}}do{if((ap|0)==67841){aw=gGq(ay)|0;c[a0>>2]=aw;if((aw|0)==0){a$=0;break}gGz(aw|0,0,ay|0);a$=aw}}while(0);do{if((c[3542200]|0)==0){a1=1}else{ay=x+108|0;c[ay>>2]=0;aw=x+100|0;c[aw>>2]=0;av=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[av&16383](x,a_)|0;if((c[ay>>2]|0)==0){a1=0;break}ay=c[aw>>2]|0;c[y>>2]=9534384;aw=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aw&16383](y,a_,0)|0;if((ay|0)<1){a1=1;break}a1=(gzL(a$,0,a_)|0)!=0|0}}while(0);ay=a$+as|0;aw=a_+1|0;do{if((c[3542200]|0)==0){a2=1}else{av=v+108|0;c[av>>2]=0;aq=v+100|0;c[aq>>2]=0;az=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[az&16383](v,aw)|0;if((c[av>>2]|0)==0){a2=0;break}av=c[aq>>2]|0;c[w>>2]=9534384;aq=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aq&16383](w,aw,0)|0;if((av|0)<1){a2=1;break}a2=(gzL(ay,0,aw)|0)!=0|0}}while(0);aw=a2|a1;ay=as<<1;av=a$+ay|0;aq=a_+2|0;do{if((c[3542200]|0)==0){a3=1}else{az=t+108|0;c[az>>2]=0;au=t+100|0;c[au>>2]=0;aO=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aO&16383](t,aq)|0;if((c[az>>2]|0)==0){a3=0;break}az=c[au>>2]|0;c[u>>2]=9534384;au=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[au&16383](u,aq,0)|0;if((az|0)<1){a3=1;break}a3=(gzL(av,0,aq)|0)!=0|0}}while(0);aq=aw|a3;av=as*3|0;az=a$+av|0;au=a_+3|0;do{if((c[3542200]|0)==0){a4=1}else{aO=r+108|0;c[aO>>2]=0;aN=r+100|0;c[aN>>2]=0;aM=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aM&16383](r,au)|0;if((c[aO>>2]|0)==0){a4=0;break}aO=c[aN>>2]|0;c[s>>2]=9534384;aN=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aN&16383](s,au,0)|0;if((aO|0)<1){a4=1;break}a4=(gzL(az,0,au)|0)!=0|0}}while(0);au=aq|a4;if((as|0)>0){az=c[2433266]|0;aw=0;while(1){aO=a$+aw|0;aN=aw<<3;aM=a$+(aw+as)|0;aD=a$+(aw+ay)|0;aC=a$+(aw+av)|0;aA=0;do{aP=7-aA|0;aQ=(d[aO]|0)>>>(aP>>>0)<<3&8;aR=az+(aA+aN)|0;a[aR]=aQ;aS=(d[aM]|0)>>>(aP>>>0)<<2&4|aQ&255;a[aR]=aS&255;aQ=(d[aD]|0)>>>(aP>>>0)<<1&2|aS;a[aR]=aQ&255;a[aR]=(aQ|(d[aC]|0)>>>(aP>>>0)&1)&255;aA=aA+1|0;}while((aA|0)<8);aA=aw+1|0;if((aA|0)<(as|0)){aw=aA}else{a5=0;break}}}else{a5=0}while(1){if((a5|0)>=1024){break}a6=9638528+(a5<<2)|0;if((c[a6>>2]|0)==(a$|0)){ap=67866;break}else{a5=a5+1|0}}if((ap|0)==67866){gGr(a$);c[a6>>2]=0}c[2429852]=(as>>3)-1;if((au|0)!=0){aB=1;i=e;return aB|0}aw=c[3528494]|0;if((aw|0)==0){a7=13}else if((aw|0)==1){a7=13}else if((aw|0)==2){a7=at|12}else{a7=0}aw=c[2429692]|0;if((c[3542200]|0)==0){aB=1;i=e;return aB|0}az=p+108|0;c[az>>2]=0;av=p+100|0;c[av>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,a7)|0;do{if((c[az>>2]|0)!=0){ay=c[av>>2]|0;c[q>>2]=9534384;aq=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aq&16383](q,a7,0)|0;if((ay|0)<1){aB=1;i=e;return aB|0}if((gzL(aw,0,a7)|0)==0){break}else{aB=1}i=e;return aB|0}}while(0);aw=(c[2429692]|0)+256|0;av=a7+1|0;if((c[3542200]|0)==0){aB=1;i=e;return aB|0}az=n+108|0;c[az>>2]=0;au=n+100|0;c[au>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,av)|0;do{if((c[az>>2]|0)!=0){as=c[au>>2]|0;c[o>>2]=9534384;ay=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ay&16383](o,av,0)|0;if((as|0)<1){aB=1;i=e;return aB|0}if((gzL(aw,0,av)|0)==0){break}else{aB=1}i=e;return aB|0}}while(0);av=(c[2429692]|0)+512|0;aw=a7+2|0;if((c[3542200]|0)==0){aB=1;i=e;return aB|0}au=l+108|0;c[au>>2]=0;az=l+100|0;c[az>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,aw)|0;do{if((c[au>>2]|0)!=0){as=c[az>>2]|0;c[m>>2]=9534384;ay=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ay&16383](m,aw,0)|0;if((as|0)<1){aB=1;i=e;return aB|0}if((gzL(av,0,aw)|0)==0){break}else{aB=1}i=e;return aB|0}}while(0);aw=c[3528494]|0;if((aw|0)==0){a8=16}else if((aw|0)==1){a8=16}else if((aw|0)==2){a8=at+15|0}else{a8=0}aw=c[2418088]|0;if((c[3542200]|0)==0){aB=1;i=e;return aB|0}av=j+108|0;c[av>>2]=0;az=j+100|0;c[az>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,a8)|0;do{if((c[av>>2]|0)!=0){au=c[az>>2]|0;c[k>>2]=9534384;as=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[as&16383](k,a8,0)|0;if((au|0)<1){aB=1;i=e;return aB|0}if((gzL(aw,0,a8)|0)==0){break}else{aB=1}i=e;return aB|0}}while(0);aw=c[642608+(c[2436]<<2)>>2]|0;az=c[aw>>2]|0;if((fa(az|0,168208)|0)==0){ap=67894}else{if((fa(az|0,178920)|0)==0){ap=67894}else{a9=aw;ba=az}}if((ap|0)==67894){az=c[2418086]|0;if((c[3542200]|0)==0){aB=1;i=e;return aB|0}av=f+108|0;c[av>>2]=0;at=f+100|0;c[at>>2]=0;au=c[aw+76>>2]|0;gA[au&16383](f,17)|0;do{if((c[av>>2]|0)!=0){au=c[at>>2]|0;c[g>>2]=9534384;aw=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aw&16383](g,17,0)|0;if((au|0)<1){aB=1;i=e;return aB|0}if((gzL(az,0,17)|0)==0){break}else{aB=1}i=e;return aB|0}}while(0);a[642568]=1;az=c[642608+(c[2436]<<2)>>2]|0;a9=az;ba=c[az>>2]|0}if((fa(ba|0,401592)|0)==0){ap=67901}else{if((fa(ba|0,368856)|0)==0){ap=67901}else{bb=a9}}if((ap|0)==67901){az=c[2418086]|0;if((c[3542200]|0)==0){aB=1;i=e;return aB|0}at=ak+108|0;c[at>>2]=0;av=ak+100|0;c[av>>2]=0;au=c[a9+76>>2]|0;gA[au&16383](ak,16)|0;do{if((c[at>>2]|0)!=0){au=c[av>>2]|0;c[al>>2]=9534384;aw=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aw&16383](al,16,0)|0;if((au|0)<1){aB=1;i=e;return aB|0}if((gzL(az,0,16)|0)==0){break}else{aB=1}i=e;return aB|0}}while(0);a[642568]=1;bb=c[642608+(c[2436]<<2)>>2]|0}if((fa(c[bb>>2]|0,424992)|0)==0){a[(c[2418102]|0)+27990|0]=-61}fwR(0);az=c[2439330]|0;av=(az|0)==0;if(!av){at=az;gGC(9706056,at|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];at=c[3528484]|0;c[2076596]=at;au=c[2417276]|0;c[3541536]=au;c[1836236]=0;aw=c[2418102]|0;as=0;ay=0;while(1){c[az+76+(ay<<2)>>2]=aw+(ay<<8);aq=as+1&65535;if((aq&65535)>127){bc=0;bd=0;break}else{as=aq;ay=aq&65535}}while(1){ay=aw+(bd<<8)|0;c[az+76+(bd+512<<2)>>2]=ay;c[az+76+(bd+768<<2)>>2]=ay;ay=bc+1&65535;if((ay&65535)>127){be=128;bf=128;break}else{bc=ay;bd=ay&65535}}while(1){c[az+76+(bf<<2)>>2]=aw+(bf<<8);ay=be+1&65535;if((ay&65535)>191){bg=128;bh=128;break}else{be=ay;bf=ay&65535}}while(1){ay=aw+(bh<<8)|0;c[az+76+(bh+512<<2)>>2]=ay;c[az+76+(bh+768<<2)>>2]=ay;ay=bg+1&65535;if((ay&65535)>191){break}else{bg=ay;bh=ay&65535}}ay=c[2418216]|0;c[az+844>>2]=ay;as=ay+256|0;c[az+848>>2]=as;aq=ay+512|0;c[az+852>>2]=aq;aA=ay+768|0;c[az+856>>2]=aA;aC=ay+1024|0;c[az+860>>2]=aC;aD=ay+1280|0;c[az+864>>2]=aD;aM=ay+1536|0;c[az+868>>2]=aM;aN=ay+1792|0;c[az+872>>2]=aN;c[az+1868>>2]=ay;c[az+1872>>2]=as;c[az+1876>>2]=aq;c[az+1880>>2]=aA;c[az+1884>>2]=aC;c[az+1888>>2]=aD;c[az+1892>>2]=aM;c[az+1896>>2]=aN;c[az+2892>>2]=ay;c[az+3916>>2]=ay;c[az+2896>>2]=as;c[az+3920>>2]=as;c[az+2900>>2]=aq;c[az+3924>>2]=aq;c[az+2904>>2]=aA;c[az+3928>>2]=aA;c[az+2908>>2]=aC;c[az+3932>>2]=aC;c[az+2912>>2]=aD;c[az+3936>>2]=aD;c[az+2916>>2]=aM;c[az+3940>>2]=aM;c[az+2920>>2]=aN;c[az+3944>>2]=aN;aN=c[642608+(c[2436]<<2)>>2]|0;if((fa(c[aN>>2]|0,424992)|0)!=0){aM=c[2385746]|0;c[az+876>>2]=aM;c[az+880>>2]=aM+256;c[az+884>>2]=aM+512;c[az+888>>2]=aM+768;c[az+892>>2]=aM+1024;c[az+896>>2]=aM+1280;c[az+900>>2]=aM+1536;c[az+904>>2]=aM+1792}aM=c[2385746]|0;c[az+1900>>2]=aM;aD=aM+256|0;c[az+1904>>2]=aD;aC=aM+512|0;c[az+1908>>2]=aC;aA=aM+768|0;c[az+1912>>2]=aA;aq=aM+1024|0;c[az+1916>>2]=aq;as=aM+1280|0;c[az+1920>>2]=as;ay=aM+1536|0;c[az+1924>>2]=ay;aO=aM+1792|0;c[az+1928>>2]=aO;c[az+2924>>2]=aM;c[az+3948>>2]=aM;c[az+2928>>2]=aD;c[az+3952>>2]=aD;c[az+2932>>2]=aC;c[az+3956>>2]=aC;c[az+2936>>2]=aA;c[az+3960>>2]=aA;c[az+2940>>2]=aq;c[az+3964>>2]=aq;c[az+2944>>2]=as;c[az+3968>>2]=as;c[az+2948>>2]=ay;c[az+3972>>2]=ay;c[az+2952>>2]=aO;c[az+3976>>2]=aO;aO=c[2433268]|0;c[az+908>>2]=aO;c[az+912>>2]=aO+256;c[az+916>>2]=aO+512;c[az+920>>2]=aO+768;c[az+924>>2]=aO+1024;c[az+928>>2]=aO+1280;c[az+932>>2]=aO+1536;c[az+936>>2]=aO+1792;c[az+940>>2]=aO+2048;c[az+944>>2]=aO+2304;c[az+948>>2]=aO+2560;c[az+952>>2]=aO+2816;c[az+956>>2]=aO+3072;c[az+960>>2]=aO+3328;c[az+964>>2]=aO+3584;c[az+968>>2]=aO+3840;ay=208;as=208;while(1){c[az+76+(as+256<<2)>>2]=aO+((as<<8)-53248);aq=ay+1&65535;if((aq&65535)>223){bi=208;bj=208;break}else{ay=aq;as=aq&65535}}while(1){as=aO+((bj<<8)-53248)|0;c[az+76+(bj+512<<2)>>2]=as;c[az+76+(bj+768<<2)>>2]=as;as=bi+1&65535;if((as&65535)>223){break}else{bi=as;bj=as&65535}}aO=c[2430054]|0;c[az+972>>2]=aO;as=aO+256|0;c[az+976>>2]=as;ay=aO+512|0;c[az+980>>2]=ay;aq=aO+768|0;c[az+984>>2]=aq;aA=aO+1024|0;c[az+988>>2]=aA;aC=aO+1280|0;c[az+992>>2]=aC;aD=aO+1536|0;c[az+996>>2]=aD;aM=aO+1792|0;c[az+1e3>>2]=aM;c[az+1996>>2]=aO;c[az+2e3>>2]=as;c[az+2004>>2]=ay;c[az+2008>>2]=aq;c[az+2012>>2]=aA;c[az+2016>>2]=aC;c[az+2020>>2]=aD;c[az+2024>>2]=aM;c[az+3020>>2]=aO;c[az+4044>>2]=aO;c[az+3024>>2]=as;c[az+4048>>2]=as;c[az+3028>>2]=ay;c[az+4052>>2]=ay;c[az+3032>>2]=aq;c[az+4056>>2]=aq;c[az+3036>>2]=aA;c[az+4060>>2]=aA;c[az+3040>>2]=aC;c[az+4064>>2]=aC;c[az+3044>>2]=aD;c[az+4068>>2]=aD;c[az+3048>>2]=aM;c[az+4072>>2]=aM;aM=c[aN>>2]|0;if((fa(aM|0,337184)|0)==0){ap=67922}else{if((fa(aM|0,320360)|0)==0){ap=67922}}if((ap|0)==67922){aM=aw+68608|0;c[az+1020>>2]=aM;aD=aw+68864|0;c[az+1024>>2]=aD;aC=aw+69120|0;c[az+1028>>2]=aC;aA=aw+69376|0;c[az+1032>>2]=aA;c[az+3068>>2]=aM;c[az+4092>>2]=aM;c[az+3072>>2]=aD;c[az+4096>>2]=aD;c[az+3076>>2]=aC;c[az+4100>>2]=aC;c[az+3080>>2]=aA;c[az+4104>>2]=aA}aA=c[2433272]|0;c[az+1036>>2]=aA;c[az+1040>>2]=aA+256;c[az+1044>>2]=aA+512;c[az+1048>>2]=aA+768;c[az+1052>>2]=aA+1024;c[az+1056>>2]=aA+1280;c[az+1060>>2]=aA+1536;c[az+1064>>2]=aA+1792;c[az+1068>>2]=aA+2048;c[az+1072>>2]=aA+2304;c[az+1076>>2]=aA+2560;c[az+1080>>2]=aA+2816;c[az+1084>>2]=aA+3072;c[az+1088>>2]=aA+3328;c[az+1092>>2]=aA+3584;c[az+1096>>2]=aA+3840;aC=240;aD=240;while(1){c[az+76+(aD+256<<2)>>2]=aA+((aD<<8)-61440);aM=aC+1&65535;if((aM&65535)>255){bk=240;bl=240;break}else{aC=aM;aD=aM&65535}}while(1){aD=aA+((bl<<8)-61440)|0;c[az+76+(bl+512<<2)>>2]=aD;c[az+76+(bl+768<<2)>>2]=aD;aD=bk+1&65535;if((aD&65535)>255){break}else{bk=aD;bl=aD&65535}}aA=(fa(c[aN>>2]|0,115560)|0)==0;c[az+4180>>2]=aA?2148:1556;aA=c[aN>>2]|0;do{if((fa(aA|0,337184)|0)==0){ap=67928}else{if((fa(aA|0,320360)|0)==0){ap=67928;break}c[az+4184>>2]=450}}while(0);if((ap|0)==67928){c[az+4184>>2]=1054}aA=(fa(c[aN>>2]|0,424992)|0)==0;c[az+4172>>2]=aA?2378:2934;c[az+4176>>2]=722;if(!av){aA=az;gGC(aA|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=at;c[2417276]=au;c[1836236]=-1;fwR(1);aA=c[2439331]|0;aD=(aA|0)==0;if(!aD){aC=aA;gGC(9706056,aC|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];aC=c[3528485]|0;c[2076596]=aC;aw=c[2417277]|0;c[3541536]=aw;c[1836236]=1;aM=c[2418088]|0;aq=0;ay=0;while(1){c[aA+76+(ay<<2)>>2]=aM+(ay<<8);as=aq+1&65535;if((as&65535)>31){bm=0;bn=0;break}else{aq=as;ay=as&65535}}while(1){ay=aM+(bn<<8)|0;c[aA+76+(bn+512<<2)>>2]=ay;c[aA+76+(bn+768<<2)>>2]=ay;ay=bm+1&65535;if((ay&65535)>31){break}else{bm=ay;bn=ay&65535}}aM=c[2385746]|0;c[aA+876>>2]=aM;ay=aM+256|0;c[aA+880>>2]=ay;aq=aM+512|0;c[aA+884>>2]=aq;au=aM+768|0;c[aA+888>>2]=au;at=aM+1024|0;c[aA+892>>2]=at;az=aM+1280|0;c[aA+896>>2]=az;av=aM+1536|0;c[aA+900>>2]=av;aN=aM+1792|0;c[aA+904>>2]=aN;c[aA+1900>>2]=aM;c[aA+1904>>2]=ay;c[aA+1908>>2]=aq;c[aA+1912>>2]=au;c[aA+1916>>2]=at;c[aA+1920>>2]=az;c[aA+1924>>2]=av;c[aA+1928>>2]=aN;c[aA+2924>>2]=aM;c[aA+3948>>2]=aM;c[aA+2928>>2]=ay;c[aA+3952>>2]=ay;c[aA+2932>>2]=aq;c[aA+3956>>2]=aq;c[aA+2936>>2]=au;c[aA+3960>>2]=au;c[aA+2940>>2]=at;c[aA+3964>>2]=at;c[aA+2944>>2]=az;c[aA+3968>>2]=az;c[aA+2948>>2]=av;c[aA+3972>>2]=av;c[aA+2952>>2]=aN;c[aA+3976>>2]=aN;c[aA+4180>>2]=1142;c[aA+4184>>2]=2096;c[aA+4172>>2]=270;c[aA+4176>>2]=1180;if(!aD){aN=aA;gGC(aN|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=aC;c[2417277]=aw;c[1836236]=-1;do{if(a[642568]|0){aN=c[3528494]|0;if((aN|0)==0){av=c[2418086]|0;az=c[2418190]|0;c[2424906]=684104;c[2443666]=2047;c[2385780]=7;c[3528996]=3;gGz(9702704,0,32);gGz(9703728,0,32);gGz(9704752,0,32);at=c[2427044]|0;c[9681616+(at<<3)>>2]=809328;c[9681620+(at<<3)>>2]=0;c[2427044]=at+1;at=2;while(1){au=az+((at<<3)-16)|0;c[9702704+(at<<2)>>2]=au;c[9703728+(at<<2)>>2]=au;c[9704752+(at<<2)>>2]=au;au=at+1|0;if((au|0)<16){at=au}else{bo=16;break}}do{at=av+(bo<<3)|0;c[9702704+(bo<<2)>>2]=at;c[9704752+(bo<<2)>>2]=at;bo=bo+1|0;}while((bo|0)<256);c[3528586]=3404;c[2385590]=1124;break}else if((aN|0)==2){av=c[2418086]|0;at=c[2418190]|0;az=c[2427044]|0;c[2424906]=682360;c[2443666]=2047;c[2385780]=7;c[3528996]=3;gGz(9702704,0,32);gGz(9703728,0,32);gGz(9704752,0,32);c[9681616+(az<<3)>>2]=809328;c[9681620+(az<<3)>>2]=0;c[2427044]=az+1;az=2;while(1){au=at+((az<<3)-16)|0;c[9702704+(az<<2)>>2]=au;c[9703728+(az<<2)>>2]=au;c[9704752+(az<<2)>>2]=au;au=az+1|0;if((au|0)<16){az=au}else{bp=16;break}}do{az=av+(bp<<3)|0;c[9702704+(bp<<2)>>2]=az;c[9704752+(bp<<2)>>2]=az;bp=bp+1|0;}while((bp|0)<256);c[3528586]=3404;c[2385590]=1124;break}else{break}}}while(0);aw=c[2385356]|0;c[2438978]=aw;aC=a[9688]|0?534:0;c[2438979]=aw+(aC<<1);c[2438980]=aw+(aC<<1<<1);c[2438981]=aw+((aC*3|0)<<1);c[2438982]=aw+(aC<<2<<1);c[2438983]=aw+((aC*5|0)<<1);aC=a[9680]|0?32e3:0;c[3542220]=11200;aw=c[2113008]|0;if((aw|0)==0){gGz(14168888,0,252);c[3542223]=aC;c[3542224]=1764;c[3542225]=416;c[3542226]=0;c[3542227]=0;c[3542234]=~~((+(aC|0)*32768.0*8.0+75.0e4)/15.0e5);aA=31;bq=32767.0;while(1){c[14169012+(aA<<2)>>2]=~~(bq+.5);aD=aA-1|0;if((aD|0)>0){aA=aD;bq=bq/1.188502227}else{break}}c[3542253]=0;h[1771269]=1.0;h[1771270]=1.0;h[1771271]=1.0;c[3542574]=3;c[3542575]=3;c[3542576]=3;mB(0);aA=(c[2113008]|0)+1|0;c[2113008]=aA;br=aA;bs=a[9680]|0?32e3:0}else{br=aw;bs=aC}c[3542220]=11200;if((br|0)==1){gGz(14169140,0,252);c[3542286]=bs;c[3542287]=2694;c[3542288]=862;c[3542289]=0;c[3542290]=0;c[3542297]=~~((+(bs|0)*32768.0*8.0+75.0e4)/15.0e5);aA=31;bq=32767.0;while(1){c[14169264+(aA<<2)>>2]=~~(bq+.5);aD=aA-1|0;if((aD|0)>0){aA=aD;bq=bq/1.188502227}else{break}}c[3542316]=0;h[1771272]=1.0;h[1771273]=1.0;h[1771274]=1.0;c[3542577]=3;c[3542578]=3;c[3542579]=3;mB(1);c[2113008]=(c[2113008]|0)+1}h[1771269]=.25;c[3542574]=3;h[1771270]=.25;c[3542575]=3;h[1771271]=.25;c[3542576]=3;h[1771272]=.25;c[3542577]=3;h[1771273]=.25;c[3542578]=3;h[1771274]=.25;c[3542579]=3;aA=0;while(1){if((aA|0)>=1024){ap=67961;break}bt=9638528+(aA<<2)|0;if((c[bt>>2]|0)==0){ap=67960;break}else{aA=aA+1|0}}do{if((ap|0)==67960){aA=gGq(1024)|0;c[bt>>2]=aA;if((aA|0)==0){ap=67961;break}gGz(aA|0,0,1024);c[2429690]=aA;aC=c[2433270]|0;aw=0;do{aD=aw<<6;av=0;while(1){if((av|0)>=64){bu=0;break}if((a[aC+(av+aD)|0]|0)==0){av=av+1|0}else{bu=1;break}}a[aA+aw|0]=bu;aw=aw+1|0;}while((aw|0)<1024)}}while(0);if((ap|0)==67961){c[2429690]=0}aw=c[2429692]|0;aA=c[2433274]|0;aC=0;do{av=d[aw+aC|0]|0;aD=d[aw+(aC+256)|0]|0;az=d[aw+(aC+512)|0]|0;c[aA+(aC<<2)>>2]=(aD<<4|aD)<<3&2016|(av<<4|av)<<8&63488|(az<<4|az)>>>3&31;aC=aC+1|0;}while((aC|0)<256);aC=c[642608+(c[2436]<<2)>>2]|0;aA=c[aC+128>>2]|0;if((c[aC+52>>2]&4|0)==0){c[2443814]=aA;aw=c[aC+132>>2]|0;c[2440436]=aw;bv=aA;bw=aw}else{c[2440436]=aA;aw=c[aC+132>>2]|0;c[2443814]=aw;bv=aw;bw=aA}aA=ag(bv<<1,bw)|0;aw=gGq(aA)|0;c[2112926]=aw;if((aw|0)!=0){gGz(aw|0,0,aA|0)}a[9731928]=0;a[9747072]=0;a[9747080]=1;c[2440440]=0;c[2439200]=0;aA=c[2439330]|0;aw=(aA|0)==0;if(!aw){aC=aA;gGC(9706056,aC|0,76)|0}aC=c[2438118]|0;c[2433530]=aC;az=c[3528484]|0;c[2076596]=az;av=c[2417276]|0;c[3541536]=av;c[1836236]=0;gGz(9706056,0,76);if(!aw){aw=aA;gGC(aw|0,9706056,76)|0}c[2438118]=aC;c[3528484]=az;c[2417276]=av;c[1836236]=-1;av=c[2439331]|0;az=(av|0)==0;if(!az){aC=av;gGC(9706056,aC|0,76)|0}aC=c[2438119]|0;c[2433530]=aC;aw=c[3528485]|0;c[2076596]=aw;aA=c[2417277]|0;c[3541536]=aA;c[1836236]=1;gGz(9706056,0,76);if(!az){az=av;gGC(az|0,9706056,76)|0}c[2438119]=aC;c[3528485]=aw;c[2417277]=aA;c[1836236]=-1;if(!(a[642568]|0)){aB=0;i=e;return aB|0}f42();a[8451544]=0;a[8451536]=0;a[9533800]=0;a[8451528]=0;a[8451520]=0;a[9533792]=0;a[8451512]=0;a[8451504]=0;a[9533784]=0;a[9533352]=0;a[9533344]=0;c[2161338]=0;c[2161344]=0;aB=0;i=e;return aB|0}}while(0);c[2426634]=0;aB=1;i=e;return aB|0}function fsB(){var b=0,d=0,e=0,f=0,g=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}b=c[2429690]|0;d=0;while(1){if((d|0)>=1024){break}e=9638528+(d<<2)|0;if((c[e>>2]|0)==(b|0)){f=68058;break}else{d=d+1|0}}if((f|0)==68058){gGr(b);c[e>>2]=0}c[2429690]=0;fwZ();c[2113008]=0;c[2076598]=0;c[2383582]=0;if(a[642568]|0){a[642568]=0;a[8451544]=0;a[8451536]=0;a[9533800]=0;a[8451528]=0;a[8451520]=0;a[9533792]=0;a[8451512]=0;a[8451504]=0;a[9533784]=0;a[9533352]=0;a[9533344]=0;c[2161338]=0;c[2161344]=0;c[2424906]=0;c[2443666]=0;c[2385780]=0;c[3528996]=0}e=c[2426634]|0;b=0;while(1){if((b|0)>=1024){f=68066;break}g=9638528+(b<<2)|0;if((c[g>>2]|0)==(e|0)){break}else{b=b+1|0}}if((f|0)==68066){c[2426634]=0;a[14108680]=0;return 0}gGr(e);c[g>>2]=0;c[2426634]=0;a[14108680]=0;return 0}function fsC(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0;do{if((a[9774760]|0)!=0){a[9731928]=0;a[9747072]=0;a[9747080]=1;c[2440440]=0;c[2439200]=0;e=c[2439330]|0;f=(e|0)==0;if(!f){g=e;gGC(9706056,g|0,76)|0}g=c[2438118]|0;c[2433530]=g;h=c[3528484]|0;c[2076596]=h;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);if(!f){f=e;gGC(f|0,9706056,76)|0}c[2438118]=g;c[3528484]=h;c[2417276]=i;c[1836236]=-1;i=c[2439331]|0;h=(i|0)==0;if(!h){g=i;gGC(9706056,g|0,76)|0}g=c[2438119]|0;c[2433530]=g;f=c[3528485]|0;c[2076596]=f;e=c[2417277]|0;c[3541536]=e;c[1836236]=1;gGz(9706056,0,76);if(!h){h=i;gGC(h|0,9706056,76)|0}c[2438119]=g;c[3528485]=f;c[2417277]=e;c[1836236]=-1;if(!(a[642568]|0)){break}f42();a[8451544]=0;a[8451536]=0;a[9533800]=0;a[8451528]=0;a[8451520]=0;a[9533792]=0;a[8451512]=0;a[8451504]=0;a[9533784]=0;a[9533352]=0;a[9533344]=0;c[2161338]=0;c[2161344]=0}}while(0);e=c[2385548]|0;if((e|0)>0){gGz(9752472,0,((e|0)>1?e<<2:4)|0)}c[2433530]=0;if(a[642568]|0){c[2415218]=0}a[9774768]=0;a[9774769]=0;e=c[3528494]|0;if((e|0)==0){f=0;g=0;h=0;while(1){i=((a[9755560+f|0]&1)<<f|g&255)&255;j=a[9755552+f|0]&1;if((f|0)<4){k=j<<(f^1)|h&255}else{k=j<<f|h&255}j=k&255;l=f+1|0;if((l|0)<8){f=l;g=i;h=j}else{m=i;n=j;break}}}else{h=0;g=0;f=0;while(1){k=((a[9755560+h|0]&1)<<h|g&255)&255;j=((a[9755552+h|0]&1)<<h|f&255)&255;i=h+1|0;if((i|0)<8){h=i;g=k;f=j}else{m=k;n=j;break}}}a[9774768]=m;a[9774769]=n;if((m&3)==3){n=m&-4;a[9774768]=n;o=n}else{o=m}if((o&12)==12){m=o&-13;a[9774768]=m;p=m}else{p=o}if((p&48)==48){o=p&-49;a[9774768]=o;q=o}else{q=p}if((q&-64)<<24>>24==-64){p=q&63;a[9774768]=p;r=p}else{r=q}if((e|0)==1){a[9774768]=r<<1&68|r&-103|(r&255)>>>1&34;s=3}else if((e|0)==0){s=1}else if((e|0)==2){s=3}else{s=0}e=0;r=0;q=0;p=0;o=0;L88878:while(1){m=r;n=q;f=p;g=o;while(1){if((n|0)>=12){break L88878}h=c[2439330]|0;if((h|0)!=0){j=h;gGC(9706056,j|0,76)|0}b[4853030]=c[2426515]&65535;j=c[2438118]|0;c[2433530]=j;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;t=n+1|0;k=t*1e5|0;i=(k|0)/12|0;do{if((k|0)<1135884|m){u=m;v=f}else{l=i-94656|0;do{if((l|0)<1){w=0}else{if((a[h+4188|0]|0)==0){x=gfc(l)|0;c[2433530]=(c[2433530]|0)+x;w=x;break}else{c[2433530]=j+l;w=l;break}}}while(0);l=w+f|0;if((c[2112968]|0)==0){y=c[2430056]|0}else{if((a[9718328]|0)!=0){a[9718328]=0;x=c[2429692]|0;z=c[2433274]|0;A=0;do{B=d[x+A|0]|0;C=d[x+(A+256)|0]|0;D=d[x+(A+512)|0]|0;c[z+(A<<2)>>2]=(C<<4|C)<<3&2016|(B<<4|B)<<8&63488|(D<<4|D)>>>3&31;A=A+1|0;}while((A|0)<256)}A=(c[2429362]<<8)+(c[2429360]|0)|0;z=c[2429358]|0;x=c[3528494]|0;if((x|0)==0){E=z-1|0}else if((x|0)==1){E=z-1|0}else if((x|0)==2){E=z+1|0}else{E=z}z=-A|0;D=-E|0;B=A&7;C=(B|0)==0?z&7:z|-8;z=E&7;F=(z|0)==0?D&7:D|-8;c[2385450]=F;D=c[2112926]|0;G=D+((z*-280|0)-B<<1)|0;c[2394720]=G;B=E>>>3;z=A>>>3&63;A=c[2433268]|0;H=c[2429852]|0;I=c[2433266]|0;J=2;K=F;F=G;do{G=J+B<<6&1984;L=G|2048;M=1;N=K;O=C;P=F;while(1){Q=M+z|0;R=d[A+(Q+L)|0]|0;S=R&240;T=I+(((R<<8|d[A+(Q+G)|0])&H)<<6)|0;L88911:do{if(O>>>0>272|(N|0)<0|(N|0)>232){if((N|0)>239){U=T;break}Q=O>>>0<280;R=0;V=P;W=N;X=T;while(1){do{if((W|0)>=0){if(Q){b[V>>1]=(d[X]|0)+S&65535}if((O+1|0)>>>0<280){b[V+2>>1]=(d[X+1|0]|0)+S&65535}if((O+2|0)>>>0<280){b[V+4>>1]=(d[X+2|0]|0)+S&65535}if((O+3|0)>>>0<280){b[V+6>>1]=(d[X+3|0]|0)+S&65535}if((O+4|0)>>>0<280){b[V+8>>1]=(d[X+4|0]|0)+S&65535}if((O+5|0)>>>0<280){b[V+10>>1]=(d[X+5|0]|0)+S&65535}if((O+6|0)>>>0<280){b[V+12>>1]=(d[X+6|0]|0)+S&65535}if((O+7|0)>>>0>=280){break}b[V+14>>1]=(d[X+7|0]|0)+S&65535}}while(0);Y=R+1|0;Z=X+8|0;if((Y|0)>=8){U=Z;break L88911}_=K+Y|0;if((_|0)>239){U=Z;break}else{R=Y;V=V+560|0;W=_;X=Z}}}else{X=P;W=0;V=T;while(1){b[X>>1]=(d[V]|0)+S&65535;b[X+2>>1]=(d[V+1|0]|0)+S&65535;b[X+4>>1]=(d[V+2|0]|0)+S&65535;b[X+6>>1]=(d[V+3|0]|0)+S&65535;b[X+8>>1]=(d[V+4|0]|0)+S&65535;b[X+10>>1]=(d[V+5|0]|0)+S&65535;b[X+12>>1]=(d[V+6|0]|0)+S&65535;b[X+14>>1]=(d[V+7|0]|0)+S&65535;R=W+1|0;Q=V+8|0;if((R|0)<8){X=X+560|0;W=R;V=Q}else{U=Q;break}}}}while(0);S=M+1|0;$=O+8|0;aa=P+16|0;if((S|0)<37){M=S;N=K;O=$;P=aa}else{break}}J=J+1|0;K=K+8|0;F=F+4480|0;}while((J|0)<33);c[2385330]=U;c[2385462]=$;c[2385450]=K;c[2415142]=aa;c[2394720]=F;J=c[2430056]|0;if((x|0)==0){ab=-16}else if((x|0)==1){ab=-16}else if((x|0)==2){ab=-17}else{ab=0}H=c[2429364]|0;A=c[2430052]|0;I=0;do{z=d[J+(I|2)|0]|0;C=z<<8&256|d[J+(I|1)|0];ac=C-21|0;ad=(d[J+(I|3)|0]|0)+ab|0;L88954:do{if((C-6|0)>>>0<295&(ad|0)>-16&(ad|0)<240){B=A+(((z<<2&768|d[J+I|0])&H)<<8)|0;P=D+((ad*280|0)+ac<<1)|0;O=z>>>1<<4&240;if(ac>>>0<265&(ad|0)>-1&(ad|0)<225){N=B;M=P;G=0;while(1){L=a[N]|0;if(L<<24>>24!=0){b[M>>1]=(L&255)+O&65535}L=a[N+1|0]|0;if(L<<24>>24!=0){b[M+2>>1]=(L&255)+O&65535}L=a[N+2|0]|0;if(L<<24>>24!=0){b[M+4>>1]=(L&255)+O&65535}L=a[N+3|0]|0;if(L<<24>>24!=0){b[M+6>>1]=(L&255)+O&65535}L=a[N+4|0]|0;if(L<<24>>24!=0){b[M+8>>1]=(L&255)+O&65535}L=a[N+5|0]|0;if(L<<24>>24!=0){b[M+10>>1]=(L&255)+O&65535}L=a[N+6|0]|0;if(L<<24>>24!=0){b[M+12>>1]=(L&255)+O&65535}L=a[N+7|0]|0;if(L<<24>>24!=0){b[M+14>>1]=(L&255)+O&65535}L=a[N+8|0]|0;if(L<<24>>24!=0){b[M+16>>1]=(L&255)+O&65535}L=a[N+9|0]|0;if(L<<24>>24!=0){b[M+18>>1]=(L&255)+O&65535}L=a[N+10|0]|0;if(L<<24>>24!=0){b[M+20>>1]=(L&255)+O&65535}L=a[N+11|0]|0;if(L<<24>>24!=0){b[M+22>>1]=(L&255)+O&65535}L=a[N+12|0]|0;if(L<<24>>24!=0){b[M+24>>1]=(L&255)+O&65535}L=a[N+13|0]|0;if(L<<24>>24!=0){b[M+26>>1]=(L&255)+O&65535}L=a[N+14|0]|0;if(L<<24>>24!=0){b[M+28>>1]=(L&255)+O&65535}L=a[N+15|0]|0;if(L<<24>>24!=0){b[M+30>>1]=(L&255)+O&65535}L=G+1|0;if((L|0)<16){N=N+16|0;M=M+560|0;G=L}else{break L88954}}}G=ac>>>0<280;M=B;N=P;L=0;while(1){do{if((L+ad|0)>>>0<=239){do{if(G){S=a[M]|0;if(S<<24>>24==0){break}b[N>>1]=(S&255)+O&65535}}while(0);do{if((C-20|0)>>>0<280){S=a[M+1|0]|0;if(S<<24>>24==0){break}b[N+2>>1]=(S&255)+O&65535}}while(0);do{if((C-19|0)>>>0<280){S=a[M+2|0]|0;if(S<<24>>24==0){break}b[N+4>>1]=(S&255)+O&65535}}while(0);do{if((C-18|0)>>>0<280){S=a[M+3|0]|0;if(S<<24>>24==0){break}b[N+6>>1]=(S&255)+O&65535}}while(0);do{if((C-17|0)>>>0<280){S=a[M+4|0]|0;if(S<<24>>24==0){break}b[N+8>>1]=(S&255)+O&65535}}while(0);do{if((C-16|0)>>>0<280){S=a[M+5|0]|0;if(S<<24>>24==0){break}b[N+10>>1]=(S&255)+O&65535}}while(0);do{if((C-15|0)>>>0<280){S=a[M+6|0]|0;if(S<<24>>24==0){break}b[N+12>>1]=(S&255)+O&65535}}while(0);do{if((C-14|0)>>>0<280){S=a[M+7|0]|0;if(S<<24>>24==0){break}b[N+14>>1]=(S&255)+O&65535}}while(0);do{if((C-13|0)>>>0<280){S=a[M+8|0]|0;if(S<<24>>24==0){break}b[N+16>>1]=(S&255)+O&65535}}while(0);do{if((C-12|0)>>>0<280){S=a[M+9|0]|0;if(S<<24>>24==0){break}b[N+18>>1]=(S&255)+O&65535}}while(0);do{if((C-11|0)>>>0<280){S=a[M+10|0]|0;if(S<<24>>24==0){break}b[N+20>>1]=(S&255)+O&65535}}while(0);do{if((C-10|0)>>>0<280){S=a[M+11|0]|0;if(S<<24>>24==0){break}b[N+22>>1]=(S&255)+O&65535}}while(0);do{if((C-9|0)>>>0<280){S=a[M+12|0]|0;if(S<<24>>24==0){break}b[N+24>>1]=(S&255)+O&65535}}while(0);do{if((C-8|0)>>>0<280){S=a[M+13|0]|0;if(S<<24>>24==0){break}b[N+26>>1]=(S&255)+O&65535}}while(0);do{if((C-7|0)>>>0<280){S=a[M+14|0]|0;if(S<<24>>24==0){break}b[N+28>>1]=(S&255)+O&65535}}while(0);if((C-6|0)>>>0>=280){break}S=a[M+15|0]|0;if(S<<24>>24==0){break}b[N+30>>1]=(S&255)+O&65535}}while(0);S=L+1|0;if((S|0)>=16){break L88954}M=M+16|0;N=N+560|0;L=S}}}while(0);I=I+4|0;}while((I|0)<2048);c[2443852]=ac;c[2443850]=ad;if((x|0)==0){c[2385450]=-15;ae=-15}else if((x|0)==1){c[2385450]=-15;ae=-15}else if((x|0)==2){c[2385450]=-16;ae=-16}else{ae=K}I=D+((ae*280|0)<<1)|0;c[2394720]=I;H=c[2433272]|0;A=c[2429690]|0;F=c[2433270]|0;C=0;z=ae;L=I;do{if((z+7|0)>>>0>246){af=z;ag=L}else{I=C<<6;c[2415142]=L;N=I+2048|0;M=1;O=L;do{G=d[H+(N+M)|0]|0;P=G<<8&768|d[H+(M+I)|0];L89089:do{if((a[A+P|0]|0)==0){ah=O}else{B=G&252;S=F+(P<<6)|0;c[2385330]=S;T=O;V=0;W=S;while(1){S=z+V|0;if((S|0)>239){ah=O;break L89089}do{if((S|0)>=0){X=a[W]|0;if(X<<24>>24!=0){b[T>>1]=(X&255)+B&65535}X=a[W+1|0]|0;if(X<<24>>24!=0){b[T+2>>1]=(X&255)+B&65535}X=a[W+2|0]|0;if(X<<24>>24!=0){b[T+4>>1]=(X&255)+B&65535}X=a[W+3|0]|0;if(X<<24>>24!=0){b[T+6>>1]=(X&255)+B&65535}X=a[W+4|0]|0;if(X<<24>>24!=0){b[T+8>>1]=(X&255)+B&65535}X=a[W+5|0]|0;if(X<<24>>24!=0){b[T+10>>1]=(X&255)+B&65535}X=a[W+6|0]|0;if(X<<24>>24!=0){b[T+12>>1]=(X&255)+B&65535}X=a[W+7|0]|0;if(X<<24>>24==0){break}b[T+14>>1]=(X&255)+B&65535}}while(0);S=V+1|0;X=W+8|0;c[2385330]=X;if((S|0)>=8){ah=O;break L89089}T=T+560|0;V=S;W=X}}}while(0);M=M+1|0;O=ah+16|0;}while((M|0)<36);c[2415142]=O;af=z;ag=L}C=C+1|0;z=af+8|0;L=ag+4480|0;}while((C|0)<32);c[2385450]=z;c[2394720]=L;R8(c[2433274]|0);y=J}C=c[2430054]|0;gGC(y|0,C|0,2048)|0;if((a[9731928]&1)==0){u=1;v=l;break}a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0;u=1;v=l}}while(0);j=i-v|0;do{if((j|0)<1){ai=0}else{if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){h=gfc(j)|0;c[2433530]=(c[2433530]|0)+h;ai=h;break}else{c[2433530]=(c[2433530]|0)+j;ai=j;break}}}while(0);aj=ai+v|0;j=c[1836236]|0;h=c[9757320+(j<<2)>>2]|0;if((h|0)!=0){k=h;gGC(k|0,9706056,76)|0}c[9752472+(j<<2)>>2]=c[2433530];c[14113936+(j<<2)>>2]=c[2076596];c[9669104+(j<<2)>>2]=c[3541536];c[1836236]=-1;do{if(a[642568]|0){j=((t*5e4|0|0)/12|0)-(c[2415218]|0)|0;if((j|0)<=0){break}f4Y(j)|0}}while(0);j=i-g|0;if((a[9747080]&1)==0){ak=i}else{k=c[2439331]|0;if((k|0)!=0){h=k;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;h=c[2438119]|0;c[2433530]=h;c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;do{if((n&s|0)==0){if((a[9747072]&1)==0){al=h;break}if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;k=(c[2433530]|0)+12|0;c[2433530]=k;al=k}else{al=h}}while(0);do{if((j|0)<1){am=0;an=al}else{if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){h=gfc(j)|0;i=(c[2433530]|0)+h|0;c[2433530]=i;am=h;an=i;break}else{i=al+j|0;c[2433530]=i;am=j;an=i;break}}}while(0);j=c[1836236]|0;i=c[9757320+(j<<2)>>2]|0;if((i|0)!=0){h=i;gGC(h|0,9706056,76)|0}c[9752472+(j<<2)>>2]=an;c[14113936+(j<<2)>>2]=c[2076596];c[9669104+(j<<2)>>2]=c[3541536];c[1836236]=-1;ak=am+g|0}ao=c[2112964]|0;if((ao|0)==0){m=u;n=t;f=aj;g=ak}else{break}}g=a[9688]|0?44:0;mF(9755912,ao+(e<<1<<1)|0,g,0);e=g+e|0;r=u;q=t;p=aj;o=ak}ak=c[2112964]|0;if((ak|0)==0){return 0}o=a[9688]|0?534:0;if((o|0)==(e|0)){return 0}mF(9755912,ak+(e<<1<<1)|0,o-e|0,0);return 0}function fsD(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;d=i;i=i+112|0;e=d|0;f=d+16|0;g=d+32|0;h=d+48|0;j=d+64|0;k=d+80|0;l=d+96|0;if((b|0)!=0){c[b>>2]=169249}if((a&96|0)==0){i=d;return 0}gGz(l|0,0,12);b=c[2405572]|0;c[l>>2]=b;c[l+4>>2]=(c[2411474]|0)-b;c[l+12>>2]=162152;gj[c[2076592]&4095](l)|0;fw$(a);gGz(k|0,0,12);c[k>>2]=9731928;c[k+4>>2]=1;c[k+12>>2]=552552;gj[c[2076592]&4095](k)|0;gGz(j|0,0,12);c[j>>2]=9747080;c[j+4>>2]=1;c[j+12>>2]=550616;gj[c[2076592]&4095](j)|0;gGz(h|0,0,12);c[h>>2]=9747072;c[h+4>>2]=1;c[h+12>>2]=548416;gj[c[2076592]&4095](h)|0;gGz(g|0,0,12);c[g>>2]=9761760;c[g+4>>2]=4;c[g+12>>2]=546480;gj[c[2076592]&4095](g)|0;gGz(f|0,0,12);c[f>>2]=9756800;c[f+4>>2]=4;c[f+12>>2]=545e3;gj[c[2076592]&4095](f)|0;gGz(e|0,0,12);c[e>>2]=9774768;c[e+4>>2]=4;c[e+12>>2]=543840;gj[c[2076592]&4095](e)|0;i=d;return 0}function fsE(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4356948+(b*112|0)>>2];c[a+104>>2]=c[4356952+(b*112|0)>>2];c[a+108>>2]=c[4356956+(b*112|0)>>2];d=0;return d|0}function fsF(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=4356848+(b*112|0);e=0;return e|0}function fsG(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2150588+(b*112|0)>>2];c[a+104>>2]=c[2150592+(b*112|0)>>2];c[a+108>>2]=c[2150596+(b*112|0)>>2];d=0;return d|0}function fsH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=2150488+(b*112|0);e=0;return e|0}function fsI(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2148684+(b*112|0)>>2];c[a+104>>2]=c[2148688+(b*112|0)>>2];c[a+108>>2]=c[2148692+(b*112|0)>>2];d=0;return d|0}function fsJ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=2148584+(b*112|0);e=0;return e|0}function fsK(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2146780+(b*112|0)>>2];c[a+104>>2]=c[2146784+(b*112|0)>>2];c[a+108>>2]=c[2146788+(b*112|0)>>2];d=0;return d|0}function fsL(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=2146680+(b*112|0);e=0;return e|0}function fsM(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4701124+(b*112|0)>>2];c[a+104>>2]=c[4701128+(b*112|0)>>2];c[a+108>>2]=c[4701132+(b*112|0)>>2];d=0;return d|0}function fsN(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=4701024+(b*112|0);e=0;return e|0}function fsO(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1546384+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function fsP(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=29){if((a|0)==0){d=0;return d|0}e=a;f=4703040+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}f=b-30|0;if(f>>>0>5){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;a=715432+(f*12|0)|0;c[b>>2]=c[a>>2];c[b+4>>2]=c[a+4>>2];c[b+8>>2]=c[a+8>>2];d=0;return d|0}function fsQ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2829404+(b*112|0)>>2];c[a+104>>2]=c[2829408+(b*112|0)>>2];c[a+108>>2]=c[2829412+(b*112|0)>>2];d=0;return d|0}function fsR(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=2829304+(b*112|0);e=0;return e|0}function fsS(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2812916+(b*112|0)>>2];c[a+104>>2]=c[2812920+(b*112|0)>>2];c[a+108>>2]=c[2812924+(b*112|0)>>2];d=0;return d|0}function fsT(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=2812816+(b*112|0);e=0;return e|0}function fsU(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=29){if((a|0)==0){d=0;return d|0}e=a;f=4703040+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}f=b-30|0;if(f>>>0>5){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;a=689344+(f*12|0)|0;c[b>>2]=c[a>>2];c[b+4>>2]=c[a+4>>2];c[b+8>>2]=c[a+8>>2];d=0;return d|0}function fsV(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2814820+(b*112|0)>>2];c[a+104>>2]=c[2814824+(b*112|0)>>2];c[a+108>>2]=c[2814828+(b*112|0)>>2];d=0;return d|0}function fsW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=2814720+(b*112|0);e=0;return e|0}function fsX(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6606500+(b*112|0)>>2];c[a+104>>2]=c[6606504+(b*112|0)>>2];c[a+108>>2]=c[6606508+(b*112|0)>>2];d=0;return d|0}function fsY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=6606400+(b*112|0);e=0;return e|0}function fsZ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>41){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=2261920+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fs_(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2260116+(b*112|0)>>2];c[a+104>>2]=c[2260120+(b*112|0)>>2];c[a+108>>2]=c[2260124+(b*112|0)>>2];d=0;return d|0}function fs$(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=2260016+(b*112|0);e=0;return e|0}function fs0(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2266444+(b*112|0)>>2];c[a+104>>2]=c[2266448+(b*112|0)>>2];c[a+108>>2]=c[2266452+(b*112|0)>>2];d=0;return d|0}function fs1(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=2266344+(b*112|0);e=0;return e|0}function fs2(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2264540+(b*112|0)>>2];c[a+104>>2]=c[2264544+(b*112|0)>>2];c[a+108>>2]=c[2264548+(b*112|0)>>2];d=0;return d|0}function fs3(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=2264440+(b*112|0);e=0;return e|0}function fs4(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2262524+(b*112|0)>>2];c[a+104>>2]=c[2262528+(b*112|0)>>2];c[a+108>>2]=c[2262532+(b*112|0)>>2];d=0;return d|0}function fs5(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=2262424+(b*112|0);e=0;return e|0}function fs6(b){b=b|0;return~a[9774768]|0}function fs7(b){b=b|0;return~a[9774769]|0}function fs8(b){b=b|0;return~a[9774770]|0}function fs9(b){b=b|0;return~a[9774771]|0}function fta(b){b=b|0;var d=0,e=0;do{if((b&16711680|0)==2162688){d=a[(c[2405152]|0)+(b>>>1&32767)|0]|0}else{if((b|0)==2097169){d=a[9625400]|0;break}else if((b|0)==2097177){d=a[9625402]|0;break}else if((b|0)==2097173){d=a[9625401]|0;break}else if((b|0)==3145741){e=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;if((e|0)>=(c[2113018]|0)){d=1;break}d=e>>>31&255;break}else{d=0;break}}}while(0);return d|0}function ftb(a){a=a|0;var e=0,f=0,g=0;if((a&16711680|0)==2162688){e=d[(c[2405152]|0)+(a>>>1&32767)|0]|0;return e|0}if((a|0)==3145740){f=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;if((f|0)>=(c[2113018]|0)){e=1;return e|0}e=f>>>31&65535;return e|0}else if((a|0)==2097176){e=d[9625402]|0;return e|0}else if((a|0)==2097168){e=d[9625400]|0;return e|0}else if((a|0)==2097172){e=d[9625401]|0;return e|0}else if((a|0)==7340032){f=((c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0)/(c[2113058]|0)|0;if((f|0)==(c[2384342]|0)){g=65024}else{c[2384342]=f;g=32256}e=(g|f)&65535;return e|0}else if((a|0)==3145732){e=b[c[3541508]>>1]|0;return e|0}else if((a|0)==3145734){e=b[(c[3541508]|0)+2>>1]|0;return e|0}else{e=0;return e|0}return 0}function ftc(b,d){b=b|0;d=d|0;if((b&16711680|0)==2162688){a[(c[2405152]|0)+(b>>>1&32767)|0]=d;return}if((b-2097180|0)>>>0>=2){return}do{if((c[2385196]|0)==0){if((d&16)!=0){break}b=c[(c[3531864]|0)+8>>2]|0;gD[b&8191]()|0}}while(0);c[2385196]=d&16^16;return}function ftd(d,e){d=d|0;e=e|0;if((d&16711680|0)==2162688){a[(c[2405152]|0)+(d>>>1&32767)|0]=e&255;return}switch(d|0){case 3145740:{b[(c[3541500]|0)+(c[3541498]<<1)>>1]=e;return};case 3145734:{b[c[3541508]>>1]=e;c[3541508]=(c[3541508]|0)+2;return};case 3145728:{c[3541508]=(c[3541506]|0)+((e&65535)<<1&16382);return};case 3145732:{b[c[3541508]>>1]=e;c[3541508]=(c[3541508]|0)+2;return};case 3145736:{c[3541498]=e&255;return};default:{return}}}function fte(b,d){b=b|0;d=d|0;if((b|0)==0){c[2113304]=d&255;return}else if((b|0)==1){b=c[2113304]|0;a[14168504+b|0]=d;mv(0,b,d&255);return}else{return}}function ftf(a){a=a|0;var b=0;if((a|0)!=1){b=0;return b|0}b=c[(c[3531464]|0)+4240>>2]&255;return b|0}function ftg(b){b=b|0;var c=0;if((b|0)==65536){c=~a[9625404]}else if((b|0)==65538){c=~a[9625405]}else if((b|0)==65542){c=~a[9625403]}else{c=0}return c|0}function fth(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>2){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6456788+(b*112|0)>>2];c[a+104>>2]=c[6456792+(b*112|0)>>2];c[a+108>>2]=c[6456796+(b*112|0)>>2];d=0;return d|0}function fti(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<3&(d|0)==0)){e=1;return e|0}c[a>>2]=6456688+(b*112|0);e=0;return e|0}function ftj(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4331088+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function ftk(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>70){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6457024+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function ftl(){var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;b=i;i=i+120|0;d=b|0;e=b+112|0;c[2113208]=2097152;c[2426632]=0;c[2418100]=0;c[3541502]=524288;c[2405570]=2621440;c[2418214]=2621440;c[2405152]=2637824;c[2411384]=2703360;c[3541506]=2707456;c[3541500]=2723840;c[2411472]=2724352;c[3531916]=2724352;f=0;while(1){if((f|0)>=1024){break}g=9638528+(f<<2)|0;if((c[g>>2]|0)==0){j=68619;break}else{f=f+1|0}}do{if((j|0)==68619){f=gGq(2732544)|0;c[g>>2]=f;if((f|0)==0){break}c[2426632]=f;gGz(f|0,0,2732544);c[2418100]=f;c[3541502]=f+524288;k=c[2113208]|0;l=f+(k+524288)|0;c[2405570]=l;c[2418214]=l;c[2405152]=f+(k+540672);c[2411384]=f+(k+606208);c[3541506]=f+(k+610304);c[3541500]=f+(k+626688);l=f+(k+627200)|0;c[2411472]=l;c[3531916]=l;c[2414012]=f+(k+635392);do{if((c[3542200]|0)!=0){k=d+108|0;c[k>>2]=0;l=d+100|0;c[l>>2]=0;m=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[m&16383](d,0)|0;if((c[k>>2]|0)==0){break}k=c[l>>2]|0;c[e>>2]=9534384;l=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[l&16383](e,0,0)|0;if((k|0)<1){break}gzL(f,0,0)|0}}while(0);fpl(c[3541502]|0,1,2,c[2113208]|0,0);fxU(0,425984);if((c[2394]|0)==0){n=c[2112932]|0}else{c[2394]=0;f=c[3532596]|0;c[2112932]=f;k=c[3532592]|0;if((k|0)!=0){gGC(9104152,k|0,280)|0}c[2113054]=c[2113060];n=f}f=c[2418100]|0;k=n|0;l=0;while(1){m=f+l|0;c[k>>2]=m;c[k+131072>>2]=m;m=l+1024|0;if(m>>>0>524287){break}else{k=k+4|0;l=m}}l=c[2418214]|0;c[n+4096>>2]=l;c[n+69632>>2]=l;c[n+135168>>2]=l;k=l+1024|0;c[n+4100>>2]=k;c[n+69636>>2]=k;c[n+135172>>2]=k;k=l+2048|0;c[n+4104>>2]=k;c[n+69640>>2]=k;c[n+135176>>2]=k;k=l+3072|0;c[n+4108>>2]=k;c[n+69644>>2]=k;c[n+135180>>2]=k;k=l+4096|0;c[n+4112>>2]=k;c[n+69648>>2]=k;c[n+135184>>2]=k;k=l+5120|0;c[n+4116>>2]=k;c[n+69652>>2]=k;c[n+135188>>2]=k;k=l+6144|0;c[n+4120>>2]=k;c[n+69656>>2]=k;c[n+135192>>2]=k;k=l+7168|0;c[n+4124>>2]=k;c[n+69660>>2]=k;c[n+135196>>2]=k;k=l+8192|0;c[n+4128>>2]=k;c[n+69664>>2]=k;c[n+135200>>2]=k;k=l+9216|0;c[n+4132>>2]=k;c[n+69668>>2]=k;c[n+135204>>2]=k;k=l+10240|0;c[n+4136>>2]=k;c[n+69672>>2]=k;c[n+135208>>2]=k;k=l+11264|0;c[n+4140>>2]=k;c[n+69676>>2]=k;c[n+135212>>2]=k;k=l+12288|0;c[n+4144>>2]=k;c[n+69680>>2]=k;c[n+135216>>2]=k;k=l+13312|0;c[n+4148>>2]=k;c[n+69684>>2]=k;c[n+135220>>2]=k;k=l+14336|0;c[n+4152>>2]=k;c[n+69688>>2]=k;c[n+135224>>2]=k;k=l+15360|0;c[n+4156>>2]=k;c[n+69692>>2]=k;c[n+135228>>2]=k;k=c[2411384]|0;c[n+16384>>2]=k;c[n+81920>>2]=k;c[n+147456>>2]=k;l=k+1024|0;c[n+16388>>2]=l;c[n+81924>>2]=l;c[n+147460>>2]=l;l=k+2048|0;c[n+16392>>2]=l;c[n+81928>>2]=l;c[n+147464>>2]=l;l=k+3072|0;c[n+16396>>2]=l;c[n+81932>>2]=l;c[n+147468>>2]=l;c[n+196688>>2]=2354;c[n+196608>>2]=2528;c[n+196728>>2]=2080;c[n+196648>>2]=3080;l=c[3532592]|0;if((l|0)!=0){gGC(l|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fyz(0,65552,1e7);c[1836234]=0;l=c[2439374]|0;c[3531864]=l;gf[c[l>>2]&2047](0);l=c[2405152]|0;k=c[3531864]|0;f=524288;do{m=f>>11;o=(f|32767)+2047>>11;if((m|0)<(o|0)){p=l+(-f|0)|0;q=m;while(1){c[k+44+(q<<2)>>2]=p;r=q+1|0;if((r|0)<(o|0)){q=r}else{s=m;break}}while(1){c[k+2092+(s<<2)>>2]=p;q=s+1|0;if((q|0)<(o|0)){s=q}else{t=m;break}}do{c[k+4140+(t<<2)>>2]=p;c[k+6188+(t<<2)>>2]=p;t=t+1|0;}while((t|0)<(o|0))}f=f+32768|0;}while((f|0)<1048576);c[k+8236>>2]=1870;c[k+8240>>2]=1854;c[k+8244>>2]=746;f=c[k+20>>2]|0;if((f|0)==0){u=k}else{gf[f&2047](688560);u=c[3531864]|0}c[1836234]=-1;gu[c[u+4>>2]&16383]();c[3531864]=0;f=a[9680]|0;l=f?32e3:0;if(f){if(a[9624]|0){f=l*3|0;o=52734;while(1){if((o|0)>(f|0)){o=o>>1}else{v=1222;w=o;break}}}else{v=2462;w=l}c[2429380]=w;c[3542124]=v;mw(3375e3,w);o=gGq(262144)|0;c[2406684]=o;gGz(o|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(3375e3,11025)}h[745421]=1.0;c[2436794]=3;h[745420]=1.0;c[2436792]=3;c[2113040]=1;c[2113182]=-470;c[2113178]=-472;c[2113174]=-474;fl6(1);c[2113016]=2048;c[3531920]=c[2411384];a[7072552]=1;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];o=c[3532592]|0;if((o|0)!=0){gGC(9104152,o|0,280)|0}c[2113054]=c[2113060]}RI();o=c[2394]|0;f=c[14130368+(o<<2)>>2]|0;if((f|0)!=0){gGC(f|0,9104152,280)|0}c[8452240+(o<<2)>>2]=c[2113054];c[2394]=-1;c[1836234]=0;o=c[2439374]|0;c[3531864]=o;gf[c[o>>2]&2047](0);gD[c[(c[3531864]|0)+8>>2]&8191]()|0;c[1836234]=-1;gu[c[(c[3531864]|0)+4>>2]&16383]();c[3531864]=0;mx(0);c[2385196]=1;x=0;i=b;return x|0}}while(0);c[2426632]=0;x=1;i=b;return x|0}function ftm(){var a=0,b=0,d=0,e=0,f=0;fl7();a=c[3531464]|0;c[a+44344>>2]=0;c[a+44348>>2]=0;if((a|0)!=0){gGr(a);c[3531464]=0}a=c[2406684]|0;if((a|0)!=0){gGr(a);c[2406684]=0}if((c[2392]|0)>=0){a=0;do{b=14130368+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}b=14130384+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}a=a+1|0;}while((a|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;fyA();a=c[2426632]|0;b=0;while(1){if((b|0)>=1024){e=68675;break}f=9638528+(b<<2)|0;if((c[f>>2]|0)==(a|0)){break}else{b=b+1|0}}if((e|0)==68675){c[2426632]=0;return 0}gGr(a);c[f>>2]=0;c[2426632]=0;return 0}function ftn(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((a[9623456]|0)!=0){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];b=c[3532592]|0;if((b|0)!=0){gGC(9104152,b|0,280)|0}c[2113054]=c[2113060]}RI();b=c[2394]|0;d=c[14130368+(b<<2)>>2]|0;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[8452240+(b<<2)>>2]=c[2113054];c[2394]=-1;c[1836234]=0;b=c[2439374]|0;c[3531864]=b;gf[c[b>>2]&2047](0);b=c[(c[3531864]|0)+8>>2]|0;gD[b&8191]()|0;c[1836234]=-1;gu[c[(c[3531864]|0)+4>>2]&16383]();c[3531864]=0;mx(0);c[2385196]=1}a[9625400]=0;a[9625401]=0;a[9625402]=0;b=0;d=0;e=0;f=0;do{d=((a[9632480+b|0]&1)<<b|d&255)&255;e=((a[9630392+b|0]&1)<<b|e&255)&255;f=((a[9551624+b|0]&1)<<b|f&255)&255;b=b+1|0;}while((b|0)<8);a[9625400]=d;a[9625401]=e;a[9625402]=f;if((d&3)==3){f=d&-4;a[9625400]=f;g=f}else{g=d}if((g&12)==12){a[9625400]=g&-13}if((e&3)==3){g=e&-4;a[9625401]=g;h=g}else{h=e}if((h&12)==12){a[9625401]=h&-13}h=c[2392]|0;if((h|0)>=0){gGz(8452240,0,((h|0)>0?(h<<2)+4|0:4)|0)}c[2113054]=0;c[2409128]=0;c[2409245]=0;c[2409362]=0;c[2409479]=0;c[2409508]=0;c[2409537]=0;c[2409566]=0;c[2409595]=0;h=c[2438]|0;e=h;g=(h|0)<0|0?-1:0;h=gGU(e,g,16e6,0)|0;d=gGS(h,K,15360,0)|0;h=d;c[2113218]=h;d=gGU(e,g,5e6,0)|0;g=gGS(d,K,15360,0)|0;c[2113216]=g;c[2113220]=0;c[2113221]=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060]}c[2113058]=(h|0)/262|0;c[2113018]=h-((h*22|0|0)/262|0);a[670568]=0;c[1836234]=0;h=c[2439374]|0;c[3531864]=h;gf[c[h>>2]&2047](0);h=0;g=0;L89635:while(1){d=g;do{if((d|0)>=10){break L89635}d=d+1|0;e=(ag(c[2113218]|0,d)|0)/10|0;do{if(!(a[670568]|0)){f=c[2113018]|0;if((e|0)<=(f|0)){break}b=c[2113220]|0;if((b|0)<(f|0)){i=f-b|0;c[2113056]=i;b=RG(i)|0;c[2113054]=(c[2113054]|0)+b;c[2276108]=-1;c[2113056]=-1;c[2113220]=(c[2113220]|0)+b}a[670568]=1;b=c[2430398]|0;i=c[2439196]|0;f=i<<11;c[2438976]=b+f;j=(c[2440572]|0)>1;if(j){c[2438977]=(c[2430399]|0)+f}f=i^1;c[2439196]=f;i=f<<11;f=b+i|0;b=(c[3541506]|0)+12288|0;gGC(f|0,b|0,2048)|0;if(j){j=(c[2430399]|0)+i|0;i=(c[3541504]|0)+12288|0;gGC(j|0,i|0,2048)|0}c[8452200+(c[2394]<<2)>>2]=8194;c[2276080]=512;if((c[2276079]|0)>>>0>=512){break}RH(2)}}while(0);i=e-(c[2113220]|0)|0;c[2113056]=i;j=RG(i)|0;c[2113054]=(c[2113054]|0)+j;c[2276108]=-1;c[2113056]=-1;c[2113220]=(c[2113220]|0)+j;j=c[2113216]|0;i=(j|0)/10|0;if((c[2385196]|0)==0){if((j|0)<10){k=0}else{k=gj[c[(c[3531864]|0)+12>>2]&4095](i)|0}l=(c[2113221]|0)+k|0}else{l=(c[2113221]|0)+i|0}c[2113221]=l;m=c[2112964]|0;}while((m|0)==0);i=a[9688]|0?53:0;gg[c[3542124]&4095](m+(h<<1<<1)|0,i);h=i+h|0;g=d}g=c[2112964]|0;do{if((g|0)!=0){m=a[9688]|0?534:0;if((m|0)==(h|0)){break}gg[c[3542124]&4095](g+(h<<1<<1)|0,m-h|0)}}while(0);c[1836234]=-1;gu[c[(c[3531864]|0)+4>>2]&16383]();c[3531864]=0;h=c[2394]|0;g=c[14130368+(h<<2)>>2]|0;if((g|0)!=0){gGC(g|0,9104152,280)|0}c[8452240+(h<<2)>>2]=c[2113054];c[2394]=-1;h=c[2112968]|0;if((h|0)==0){return 0}g=c[3531916]|0;m=c[2113308]|0;do{if((c[g>>2]|0)==0){gGz(h|0,0,m*76800|0|0)}else{if((m|0)==4){l=c[g+1152>>2]|0;k=0;i=h;while(1){c[i>>2]=l;c[i+4>>2]=l;c[i+8>>2]=l;c[i+12>>2]=l;c[i+16>>2]=l;c[i+20>>2]=l;c[i+24>>2]=l;c[i+28>>2]=l;j=k+1|0;if((j|0)<9600){k=j;i=i+32|0}else{break}}}else if((m|0)==2){i=c[g+1152>>2]|0;k=i<<16|i;i=h;l=0;while(1){c[i>>2]=k;c[i+4>>2]=k;c[i+8>>2]=k;c[i+12>>2]=k;c[i+16>>2]=k;c[i+20>>2]=k;c[i+24>>2]=k;c[i+28>>2]=k;d=l+1|0;if((d|0)<4800){i=i+32|0;l=d}else{break}}}else if((m|0)==3){l=c[g+1152>>2]|0;i=l>>>8&255;k=l>>>16&255;d=l&255;l=h;j=0;while(1){a[l]=d;a[l+1|0]=i;a[l+2|0]=k;b=j+1|0;if((b|0)<76800){l=l+3|0;j=b}else{break}}}else{break}}}while(0);if(a[7072552]|0){c[2112970]=h;c[2113306]=m;c[2113298]=c[2113300];fl3();n=c[3531916]|0}else{n=g}c[2112966]=n;g=c[2113016]|0;if((g|0)>0){o=0}else{return 0}do{c[n+(o<<2)>>2]=65535;o=o+1|0;}while((o|0)<(g|0));return 0}function fto(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=c[3531916]|0;do{if((c[b>>2]|0)==0){d=c[2113308]|0;gGz(c[2112968]|0,0,d*76800|0|0);e=d}else{d=c[2113308]|0;if((d|0)==2){f=c[b+1152>>2]|0;g=f<<16|f;f=c[2112968]|0;h=0;while(1){c[f>>2]=g;c[f+4>>2]=g;c[f+8>>2]=g;c[f+12>>2]=g;c[f+16>>2]=g;c[f+20>>2]=g;c[f+24>>2]=g;c[f+28>>2]=g;i=h+1|0;if((i|0)<4800){f=f+32|0;h=i}else{e=2;break}}}else if((d|0)==3){h=c[b+1152>>2]|0;f=h>>>8&255;g=h>>>16&255;i=h&255;h=c[2112968]|0;j=0;while(1){a[h]=i;a[h+1|0]=f;a[h+2|0]=g;k=j+1|0;if((k|0)<76800){h=h+3|0;j=k}else{e=3;break}}}else if((d|0)==4){j=c[b+1152>>2]|0;h=0;g=c[2112968]|0;while(1){c[g>>2]=j;c[g+4>>2]=j;c[g+8>>2]=j;c[g+12>>2]=j;c[g+16>>2]=j;c[g+20>>2]=j;c[g+24>>2]=j;c[g+28>>2]=j;f=h+1|0;if((f|0)<9600){h=f;g=g+32|0}else{e=4;break}}}else{e=d;break}}}while(0);if(a[7072552]|0){c[2112970]=c[2112968];c[2113306]=e;c[2113298]=c[2113300];fl3();l=c[3531916]|0}else{l=b}c[2112966]=l;b=c[2113016]|0;if((b|0)>0){m=0}else{return 0}do{c[l+(m<<2)>>2]=65535;m=m+1|0;}while((m|0)<(b|0));return 0}function ftp(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;f=i;i=i+160|0;g=f|0;h=f+16|0;j=f+32|0;k=f+48|0;l=f+64|0;m=f+80|0;n=f+96|0;o=f+112|0;p=f+128|0;q=f+144|0;r=(e|0)==0;if(!r){c[e>>2]=133527}if((b&96|0)==0){i=f;return 0}gGz(q|0,0,12);s=c[2405570]|0;c[q>>2]=s;c[q+4>>2]=(c[2411472]|0)-s;c[q+12>>2]=162152;gj[c[2076592]&4095](q)|0;q=p|0;do{if((b&64|0)!=0){gGz(o|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){s=p+9|0;t=n;u=n|0;v=n+4|0;w=n+12|0;x=o|0;y=o+4|0;z=o+12|0;A=0;do{gGC(q|0,614896,11)|0;a[s]=A+48&255;B=8452256+(A<<2)|0;gGz(t|0,0,12);c[u>>2]=B;c[v>>2]=4;c[w>>2]=164976;gj[c[2076592]&4095](n)|0;if((c[B>>2]|0)!=0){c[x>>2]=c[14130368+(A<<2)>>2];c[y>>2]=c[8452184+(A<<2)>>2];c[z>>2]=q;B=c[2076592]|0;gj[B&4095](o)|0}A=A+1|0;}while((A|0)<=(c[2392]|0))}A=c[2385546]|0;if((A|0)>0){z=0;y=A;while(1){A=c[(c[9757496+(z<<2)>>2]|0)+32>>2]|0;if((A|0)==0){C=y}else{gg[A&4095](z,b);C=c[2385546]|0}A=z+1|0;if((A|0)<(C|0)){z=A;y=C}else{break}}}gGz(m|0,0,12);c[m>>2]=8453216;c[m+4>>2]=4;c[m+12>>2]=107480;y=c[2076592]|0;gj[y&4095](m)|0;gGz(l|0,0,12);c[l>>2]=14168504;c[l+4>>2]=256;c[l+12>>2]=476464;y=c[2076592]|0;gj[y&4095](l)|0;if((b&2|0)==0){break}else{D=0}do{mv(0,D,d[14168504+D|0]|0);D=D+1|0;}while((D|0)<256)}}while(0);if(!r){c[e>>2]=169110}gGz(k|0,0,12);c[k>>2]=9756784;c[k+4>>2]=4;c[k+12>>2]=175504;gj[c[2076592]&4095](k)|0;gGz(j|0,0,12);c[j>>2]=14166032;c[j+4>>2]=8;c[j+12>>2]=504552;gj[c[2076592]&4095](j)|0;gGz(h|0,0,12);c[h>>2]=14165992;c[h+4>>2]=8;c[h+12>>2]=388736;gj[c[2076592]&4095](h)|0;gGz(g|0,0,12);c[g>>2]=14165960;c[g+4>>2]=32;c[g+12>>2]=302352;gj[c[2076592]&4095](g)|0;i=f;return 0}function ftq(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>2){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2816724+(b*112|0)>>2];c[a+104>>2]=c[2816728+(b*112|0)>>2];c[a+108>>2]=c[2816732+(b*112|0)>>2];d=0;return d|0}function ftr(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<3&(d|0)==0)){e=1;return e|0}c[a>>2]=2816624+(b*112|0);e=0;return e|0}function fts(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=70){if((a|0)==0){d=0;return d|0}e=a;f=6457024+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}f=b-71|0;if(f>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;a=698336+(f*12|0)|0;c[b>>2]=c[a>>2];c[b+4>>2]=c[a+4>>2];c[b+8>>2]=c[a+8>>2];d=0;return d|0}function ftt(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>2){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2817060+(b*112|0)>>2];c[a+104>>2]=c[2817064+(b*112|0)>>2];c[a+108>>2]=c[2817068+(b*112|0)>>2];d=0;return d|0}function ftu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<3&(d|0)==0)){e=1;return e|0}c[a>>2]=2816960+(b*112|0);e=0;return e|0}function ftv(b){b=b|0;var d=0,e=0,f=0;d=b&16711680;do{if((d|0)==2621440){e=a[(c[2405150]|0)+(b>>>1&32767)|0]|0}else if((d|0)==6291456){e=a[(c[3541532]|0)+(b>>>1&32767)|0]|0}else{if((b|0)==2097161){e=a[9625394]|0;break}else if((b|0)==2097157){e=a[9625393]|0;break}else if((b|0)==3145741){f=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;if((f|0)>=(c[2113018]|0)){e=1;break}e=f>>>31&255;break}else if((b|0)==2097153){e=a[9625392]|0;break}else if((b|0)==2097169){e=a[9625396]&4|a[9625395]&-5;break}else{e=0;break}}}while(0);return e|0}function ftw(e){e=e|0;var f=0,g=0,h=0,i=0,j=0;f=e&16711680;if((f|0)==6291456){g=e>>>1&32767;h=c[3541532]|0;i=(d[h+(g|32768)|0]|0)<<8|(d[h+g|0]|0);return i|0}else if((f|0)==2621440){i=d[(c[2405150]|0)+(e>>>1&32767)|0]|0;return i|0}else{if((e|0)==2097168){i=a[9625396]&4|a[9625395]&251;return i|0}else if((e|0)==3145740){f=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;if((f|0)>=(c[2113018]|0)){i=1;return i|0}i=f>>>31&65535;return i|0}else if((e|0)==8388608){f=((c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0)/(c[2113058]|0)|0;if((f|0)==(c[2384340]|0)){j=65024}else{c[2384340]=f;j=32256}i=(j|f)&65535;return i|0}else if((e|0)==2097156){i=d[9625393]|0;return i|0}else if((e|0)==3145732){i=b[c[3541508]>>1]|0;return i|0}else if((e|0)==2097152){i=d[9625392]|0;return i|0}else if((e|0)==2097160){i=d[9625394]|0;return i|0}else if((e|0)==3145734){i=b[(c[3541508]|0)+2>>1]|0;return i|0}else{i=0;return i|0}}return 0}function ftx(b,d){b=b|0;d=d|0;var e=0;e=b&16711680;if((e|0)==6291456){a[(c[3541532]|0)+(b>>>1&32767)|0]=d;return}else if((e|0)==2621440){a[(c[2405150]|0)+(b>>>1&32767)|0]=d;return}else{if((b-7340032|0)>>>0>=2){return}do{if((c[2385194]|0)==0){if((d&8)!=0){break}b=c[(c[3531864]|0)+8>>2]|0;gD[b&8191]()|0}}while(0);c[2385194]=d&8^8;return}}function fty(d,e){d=d|0;e=e|0;var f=0,g=0,h=0;f=d&16711680;if((f|0)==6291456){g=d>>>1&32767;h=c[3541532]|0;a[h+g|0]=e&255;a[h+(g|32768)|0]=0;return}else if((f|0)==2621440){a[(c[2405150]|0)+(d>>>1&32767)|0]=e&255;return}else{if((d|0)==7340032){do{if((c[2385194]|0)==0){if((e&8)!=0){break}f=c[(c[3531864]|0)+8>>2]|0;gD[f&8191]()|0}}while(0);c[2385194]=e&8^8;return}else if((d|0)==3145736){c[3541498]=e&255;return}else if((d|0)==3145728){c[3541508]=(c[3541506]|0)+((e&65535)<<1&16382);return}else if((d|0)==3145740){b[(c[3541500]|0)+(c[3541498]<<1)>>1]=e;return}else if((d|0)==3145732|(d|0)==3145734){b[c[3541508]>>1]=e;c[3541508]=(c[3541508]|0)+2;return}else{return}}}function ftz(b,d){b=b|0;d=d|0;if((b|0)==10){c[2113304]=d&255;return}else if((b|0)==12){Uv(0,d);return}else if((b|0)==11){b=c[2113304]|0;a[14168504+b|0]=d;mv(0,b,d&255);return}else{return}}function ftA(a){a=a|0;var b=0;if((a|0)==4){b=c[3528394]&255}else if((a|0)==11){b=c[(c[3531464]|0)+4240>>2]&255}else if((a|0)==12){b=c[2113156]&255}else{b=0}return b|0}function ftB(a){a=a|0;var b=0;if((a|0)!=65536){b=0;return b|0}if((c[2406632]|0)!=0){b=(1<<c[(c[2420380]|0)+4>>2]&c[2432962]|0)!=0?-128:0;return b|0}a=c[2443744]|0;if((a|0)<=0){b=-128;return b|0}c[2443744]=a-1;b=0;return b|0}function ftC(a,b){a=a|0;b=b|0;if((a|0)!=65536){return}a=b&255;c[2415256]=a&64;b=a>>>4&1;c[3528406]=b^1;if((b|0)==0){c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2]}Tr(a>>>5&1);return}function ftD(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>5){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2856012+(b*112|0)>>2];c[a+104>>2]=c[2856016+(b*112|0)>>2];c[a+108>>2]=c[2856020+(b*112|0)>>2];d=0;return d|0}function ftE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<6&(d|0)==0)){e=1;return e|0}c[a>>2]=2855912+(b*112|0);e=0;return e|0}function ftF(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>26){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1270936+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function ftG(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>3){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3959272+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function ftH(){return fun(0)|0}function ftI(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;i=i+128|0;d=b|0;Uw(0);e=c[3531464]|0;c[e+44344>>2]=0;c[e+44348>>2]=0;if((e|0)!=0){gGr(e);c[3531464]=0}e=c[2406684]|0;if((e|0)!=0){gGr(e);c[2406684]=0}c[2408]=39321;fl7();if((c[2392]|0)>=0){e=0;do{f=14130368+(e<<2)|0;g=c[f>>2]|0;if((g|0)!=0){gGr(g);c[f>>2]=0}f=14130384+(e<<2)|0;g=c[f>>2]|0;if((g|0)!=0){gGr(g);c[f>>2]=0}e=e+1|0;}while((e|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;fyA();e=d|0;d=c[c[642608+(c[2436]<<2)>>2]>>2]|0;be(e|0,128,179600,(f=i,i=i+24|0,c[f>>2]=9374064,c[f+8>>2]=47,c[f+16>>2]=d,f)|0)|0;i=f;a[1040128]=0;f=c[2420380]|0;d=c[f>>2]|0;g=c[f+4>>2]|0;f=fw(e|0,389440)|0;if((f|0)!=0){e=g>>3<<d&1023;cj(14100392,e|0,1,f|0)|0;aY(f|0)|0}f=c[2426630]|0;e=0;while(1){if((e|0)>=1024){h=68964;break}j=9638528+(e<<2)|0;if((c[j>>2]|0)==(f|0)){break}else{e=e+1|0}}if((h|0)==68964){c[2426630]=0;i=b;return 0}gGr(f);c[j>>2]=0;c[2426630]=0;i=b;return 0}function ftJ(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((a[9623448]|0)!=0){fuo()}c[2406348]=0;b=0;d=0;e=0;f=0;g=0;do{d=((a[9632472+b|0]&1)<<b|d&255)&255;e=((a[9630384+b|0]&1)<<b|e&255)&255;f=((a[9629208+b|0]&1)<<b|f&255)&255;g=((a[9551616+b|0]&1)<<b|g&255)&255;b=b+1|0;}while((b|0)<8);a[9625392]=d;a[9625393]=e;a[9625394]=f;a[9625395]=g;if((d&3)==3){g=d&-4;a[9625392]=g;h=g}else{h=d}if((h&12)==12){a[9625392]=h&-13}if((e&3)==3){h=e&-4;a[9625393]=h;i=h}else{i=e}if((i&12)==12){a[9625393]=i&-13}i=c[2392]|0;if((i|0)>=0){gGz(8452240,0,((i|0)>0?(i<<2)+4|0:4)|0)}c[2113054]=0;c[2409128]=0;c[2409245]=0;c[2409362]=0;c[2409479]=0;c[2409508]=0;c[2409537]=0;c[2409566]=0;c[2409595]=0;i=c[2438]|0;e=i;h=(i|0)<0|0?-1:0;i=gGU(e,h,16e6,0)|0;d=gGS(i,K,15360,0)|0;i=d;c[2113218]=i;d=gGU(e,h,8e6,0)|0;h=gGS(d,K,15360,0)|0;c[2113216]=h;c[2113220]=0;c[2113221]=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];h=c[3532592]|0;if((h|0)!=0){gGC(9104152,h|0,280)|0}c[2113054]=c[2113060]}c[2113058]=(i|0)/262|0;c[2113018]=i-((i*22|0|0)/262|0);a[670560]=0;c[1836234]=0;i=c[2439374]|0;c[3531864]=i;gf[c[i>>2]&2047](0);i=0;h=0;L89992:while(1){d=h;do{if((d|0)>=100){break L89992}d=d+1|0;e=(ag(c[2113218]|0,d)|0)/100|0;do{if(a[670560]|0){j=68998}else{g=c[2113018]|0;f=c[2113220]|0;if((e|0)<=(g|0)){k=f;break}if((f|0)<(g|0)){b=g-f|0;c[2113056]=b;f=RG(b)|0;c[2113054]=(c[2113054]|0)+f;c[2276108]=-1;c[2113056]=-1;c[2113220]=(c[2113220]|0)+f}c[8452200+(c[2394]<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0<1024){RH(4)}f=c[2430398]|0;b=c[2439196]|0;g=b<<11;c[2438976]=f+g;l=(c[2440572]|0)>1;if(l){c[2438977]=(c[2430399]|0)+g}g=b^1;c[2439196]=g;b=g<<11;g=f+b|0;f=(c[3541506]|0)+12288|0;gGC(g|0,f|0,2048)|0;if(l){l=(c[2430399]|0)+b|0;b=(c[3541504]|0)+12288|0;gGC(l|0,b|0,2048)|0}a[670560]=1;j=68998}}while(0);if((j|0)==68998){j=0;k=c[2113220]|0}b=e-k|0;c[2113056]=b;l=RG(b)|0;c[2113054]=(c[2113054]|0)+l;c[2276108]=-1;c[2113056]=-1;c[2113220]=(c[2113220]|0)+l;l=c[2113216]|0;b=(l|0)/100|0;if((c[2385194]|0)==0){if((l|0)<100){m=0}else{m=gj[c[(c[3531864]|0)+12>>2]&4095](b)|0}n=(c[2113221]|0)+m|0}else{n=(c[2113221]|0)+b|0}c[2113221]=n;o=c[2112964]|0;}while((o|0)==0);b=a[9688]|0?5:0;l=o+(i<<1<<1)|0;gg[c[3542124]&4095](l,b);Uu(0,l,b);i=b+i|0;h=d}h=c[2112964]|0;do{if((h|0)!=0){o=a[9688]|0?534:0;n=o-i|0;if((o|0)==(i|0)){break}o=h+(i<<1<<1)|0;gg[c[3542124]&4095](o,n);Uu(0,o,n)}}while(0);c[1836234]=-1;gu[c[(c[3531864]|0)+4>>2]&16383]();c[3531864]=0;i=c[2394]|0;h=c[14130368+(i<<2)>>2]|0;if((h|0)!=0){gGC(h|0,9104152,280)|0}c[8452240+(i<<2)>>2]=c[2113054];c[2394]=-1;i=c[2112968]|0;if((i|0)==0){return 0}h=c[3531916]|0;n=c[h>>2]|0;o=c[2113308]|0;do{if((n|0)==0){gGz(i|0,0,o*76800|0|0)}else{if((o|0)==4){m=0;k=i;while(1){c[k>>2]=n;c[k+4>>2]=n;c[k+8>>2]=n;c[k+12>>2]=n;c[k+16>>2]=n;c[k+20>>2]=n;c[k+24>>2]=n;c[k+28>>2]=n;j=m+1|0;if((j|0)<9600){m=j;k=k+32|0}else{break}}}else if((o|0)==3){k=n>>>8&255;m=n>>>16&255;d=n&255;j=i;b=0;while(1){a[j]=d;a[j+1|0]=k;a[j+2|0]=m;l=b+1|0;if((l|0)<76800){j=j+3|0;b=l}else{break}}}else if((o|0)==2){b=n<<16|n;j=i;m=0;while(1){c[j>>2]=b;c[j+4>>2]=b;c[j+8>>2]=b;c[j+12>>2]=b;c[j+16>>2]=b;c[j+20>>2]=b;c[j+24>>2]=b;c[j+28>>2]=b;k=m+1|0;if((k|0)<4800){j=j+32|0;m=k}else{break}}}else{break}}}while(0);if(a[7072544]|0){c[2112970]=i;c[2113306]=o;c[2113298]=c[2113300];fl3();fnZ();p=c[3531916]|0}else{p=h}c[2112966]=p;h=c[2113016]|0;if((h|0)>0){q=0}else{return 0}do{c[p+(q<<2)>>2]=65535;q=q+1|0;}while((q|0)<(h|0));return 0}function ftK(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[3531916]|0;d=c[b>>2]|0;do{if((d|0)==0){e=c[2113308]|0;gGz(c[2112968]|0,0,e*76800|0|0);f=e}else{e=c[2113308]|0;if((e|0)==2){g=d<<16|d;h=c[2112968]|0;i=0;while(1){c[h>>2]=g;c[h+4>>2]=g;c[h+8>>2]=g;c[h+12>>2]=g;c[h+16>>2]=g;c[h+20>>2]=g;c[h+24>>2]=g;c[h+28>>2]=g;j=i+1|0;if((j|0)<4800){h=h+32|0;i=j}else{f=2;break}}}else if((e|0)==3){i=d>>>8&255;h=d>>>16&255;g=d&255;j=c[2112968]|0;k=0;while(1){a[j]=g;a[j+1|0]=i;a[j+2|0]=h;l=k+1|0;if((l|0)<76800){j=j+3|0;k=l}else{f=3;break}}}else if((e|0)==4){k=0;j=c[2112968]|0;while(1){c[j>>2]=d;c[j+4>>2]=d;c[j+8>>2]=d;c[j+12>>2]=d;c[j+16>>2]=d;c[j+20>>2]=d;c[j+24>>2]=d;c[j+28>>2]=d;h=k+1|0;if((h|0)<9600){k=h;j=j+32|0}else{f=4;break}}}else{f=e;break}}}while(0);if(a[7072544]|0){c[2112970]=c[2112968];c[2113306]=f;c[2113298]=c[2113300];fl3();fnZ();m=c[3531916]|0}else{m=b}c[2112966]=m;b=c[2113016]|0;if((b|0)>0){n=0}else{return 0}do{c[m+(n<<2)>>2]=65535;n=n+1|0;}while((n|0)<(b|0));return 0}function ftL(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;f=i;i=i+160|0;g=f|0;h=f+16|0;j=f+32|0;k=f+48|0;l=f+64|0;m=f+80|0;n=f+96|0;o=f+112|0;p=f+128|0;q=f+144|0;r=(e|0)==0;if(!r){c[e>>2]=169111}if((b&96|0)==0){i=f;return 0}gGz(q|0,0,12);s=c[2405568]|0;t=q|0;c[t>>2]=s;u=q+4|0;c[u>>2]=(c[2411470]|0)-s;s=q+12|0;c[s>>2]=219592;gj[c[2076592]&4095](q)|0;c[t>>2]=c[2405150];c[u>>2]=32768;c[s>>2]=288280;gj[c[2076592]&4095](q)|0;q=p|0;do{if((b&64|0)==0){Ts(b,e);Ut(0)}else{gGz(o|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){s=p+9|0;u=n;t=n|0;v=n+4|0;w=n+12|0;x=o|0;y=o+4|0;z=o+12|0;A=0;do{gGC(q|0,614896,11)|0;a[s]=A+48&255;B=8452256+(A<<2)|0;gGz(u|0,0,12);c[t>>2]=B;c[v>>2]=4;c[w>>2]=164976;gj[c[2076592]&4095](n)|0;if((c[B>>2]|0)!=0){c[x>>2]=c[14130368+(A<<2)>>2];c[y>>2]=c[8452184+(A<<2)>>2];c[z>>2]=q;B=c[2076592]|0;gj[B&4095](o)|0}A=A+1|0;}while((A|0)<=(c[2392]|0))}A=c[2385546]|0;if((A|0)>0){z=0;y=A;while(1){A=c[(c[9757496+(z<<2)>>2]|0)+32>>2]|0;if((A|0)==0){C=y}else{gg[A&4095](z,b);C=c[2385546]|0}A=z+1|0;if((A|0)<(C|0)){z=A;y=C}else{break}}}Ts(b,e);Ut(0);gGz(m|0,0,12);c[m>>2]=8453216;c[m+4>>2]=4;c[m+12>>2]=107480;y=c[2076592]|0;gj[y&4095](m)|0;gGz(l|0,0,12);c[l>>2]=14168504;c[l+4>>2]=256;c[l+12>>2]=476464;y=c[2076592]|0;gj[y&4095](l)|0;if((b&2|0)==0){break}else{D=0}do{mv(0,D,d[14168504+D|0]|0);D=D+1|0;}while((D|0)<256)}}while(0);if(!r){c[e>>2]=169110}gGz(k|0,0,12);c[k>>2]=9756784;c[k+4>>2]=4;c[k+12>>2]=175504;gj[c[2076592]&4095](k)|0;gGz(j|0,0,12);c[j>>2]=14166032;c[j+4>>2]=8;c[j+12>>2]=504552;gj[c[2076592]&4095](j)|0;gGz(h|0,0,12);c[h>>2]=14165992;c[h+4>>2]=8;c[h+12>>2]=388736;gj[c[2076592]&4095](h)|0;gGz(g|0,0,12);c[g>>2]=14165960;c[g+4>>2]=32;c[g+12>>2]=302352;gj[c[2076592]&4095](g)|0;i=f;return 0}function ftM(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>5){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1098372+(b*112|0)>>2];c[a+104>>2]=c[1098376+(b*112|0)>>2];c[a+108>>2]=c[1098380+(b*112|0)>>2];d=0;return d|0}function ftN(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<6&(d|0)==0)){e=1;return e|0}c[a>>2]=1098272+(b*112|0);e=0;return e|0}function ftO(){return fun(0)|0}function ftP(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>5){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1549492+(b*112|0)>>2];c[a+104>>2]=c[1549496+(b*112|0)>>2];c[a+108>>2]=c[1549500+(b*112|0)>>2];d=0;return d|0}function ftQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<6&(d|0)==0)){e=1;return e|0}c[a>>2]=1549392+(b*112|0);e=0;return e|0}function ftR(){return fun(1)|0}function ftS(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>5){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1099716+(b*112|0)>>2];c[a+104>>2]=c[1099720+(b*112|0)>>2];c[a+108>>2]=c[1099724+(b*112|0)>>2];d=0;return d|0}function ftT(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<6&(d|0)==0)){e=1;return e|0}c[a>>2]=1099616+(b*112|0);e=0;return e|0}function ftU(){return fun(2)|0}function ftV(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>5){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1550836+(b*112|0)>>2];c[a+104>>2]=c[1550840+(b*112|0)>>2];c[a+108>>2]=c[1550844+(b*112|0)>>2];d=0;return d|0}function ftW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<6&(d|0)==0)){e=1;return e|0}c[a>>2]=1550736+(b*112|0);e=0;return e|0}function ftX(){return fun(3)|0}function ftY(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>5){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[942780+(b*112|0)>>2];c[a+104>>2]=c[942784+(b*112|0)>>2];c[a+108>>2]=c[942788+(b*112|0)>>2];d=0;return d|0}function ftZ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<6&(d|0)==0)){e=1;return e|0}c[a>>2]=942680+(b*112|0);e=0;return e|0}function ft_(){return fun(4)|0}function ft$(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>5){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1097700+(b*112|0)>>2];c[a+104>>2]=c[1097704+(b*112|0)>>2];c[a+108>>2]=c[1097708+(b*112|0)>>2];d=0;return d|0}function ft0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<6&(d|0)==0)){e=1;return e|0}c[a>>2]=1097600+(b*112|0);e=0;return e|0}function ft1(){return fun(5)|0}function ft2(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>5){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1100388+(b*112|0)>>2];c[a+104>>2]=c[1100392+(b*112|0)>>2];c[a+108>>2]=c[1100396+(b*112|0)>>2];d=0;return d|0}function ft3(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<6&(d|0)==0)){e=1;return e|0}c[a>>2]=1100288+(b*112|0);e=0;return e|0}function ft4(){return fun(6)|0}function ft5(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>5){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1551508+(b*112|0)>>2];c[a+104>>2]=c[1551512+(b*112|0)>>2];c[a+108>>2]=c[1551516+(b*112|0)>>2];d=0;return d|0}function ft6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<6&(d|0)==0)){e=1;return e|0}c[a>>2]=1551408+(b*112|0);e=0;return e|0}function ft7(){return fun(7)|0}function ft8(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>5){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1548820+(b*112|0)>>2];c[a+104>>2]=c[1548824+(b*112|0)>>2];c[a+108>>2]=c[1548828+(b*112|0)>>2];d=0;return d|0}function ft9(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<6&(d|0)==0)){e=1;return e|0}c[a>>2]=1548720+(b*112|0);e=0;return e|0}function fua(){return fun(8)|0}function fub(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>5){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1097028+(b*112|0)>>2];c[a+104>>2]=c[1097032+(b*112|0)>>2];c[a+108>>2]=c[1097036+(b*112|0)>>2];d=0;return d|0}function fuc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<6&(d|0)==0)){e=1;return e|0}c[a>>2]=1096928+(b*112|0);e=0;return e|0}function fud(){return fun(10)|0}function fue(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>5){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1548148+(b*112|0)>>2];c[a+104>>2]=c[1548152+(b*112|0)>>2];c[a+108>>2]=c[1548156+(b*112|0)>>2];d=0;return d|0}function fuf(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<6&(d|0)==0)){e=1;return e|0}c[a>>2]=1548048+(b*112|0);e=0;return e|0}function fug(){return fun(11)|0}function fuh(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>5){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1099044+(b*112|0)>>2];c[a+104>>2]=c[1099048+(b*112|0)>>2];c[a+108>>2]=c[1099052+(b*112|0)>>2];d=0;return d|0}function fui(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<6&(d|0)==0)){e=1;return e|0}c[a>>2]=1098944+(b*112|0);e=0;return e|0}function fuj(){return fun(14)|0}function fuk(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>5){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1550164+(b*112|0)>>2];c[a+104>>2]=c[1550168+(b*112|0)>>2];c[a+108>>2]=c[1550172+(b*112|0)>>2];d=0;return d|0}function ful(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<6&(d|0)==0)){e=1;return e|0}c[a>>2]=1550064+(b*112|0);e=0;return e|0}function fum(){return fun(15)|0}function fun(b){b=b|0;var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;d=i;i=i+480|0;e=d|0;f=d+112|0;g=d+120|0;j=d+232|0;k=d+240|0;l=d+352|0;m=d+360|0;n=d+472|0;c[2113208]=4194304;c[2426630]=0;c[2418098]=0;c[3541502]=524288;c[3541206]=4718592;c[2414456]=4980736;c[2405568]=4980864;c[2418212]=4980864;c[3541532]=4997248;c[3541534]=5062784;c[2405150]=5070976;c[3541530]=5136512;c[3541528]=5140608;c[2411382]=5144704;c[3541506]=5148800;c[3541500]=5165184;c[2411470]=5165696;c[3531916]=5165696;o=0;while(1){if((o|0)>=1024){break}p=9638528+(o<<2)|0;if((c[p>>2]|0)==0){q=69239;break}else{o=o+1|0}}do{if((q|0)==69239){o=gGq(5173888)|0;c[p>>2]=o;if((o|0)==0){break}c[2426630]=o;gGz(o|0,0,5173888);c[2418098]=o;c[3541502]=o+524288;r=c[2113208]|0;c[3541206]=o+(r+524288);c[2414456]=o+(r+786432);s=o+(r+786560)|0;c[2405568]=s;c[2418212]=s;c[3541532]=o+(r+802944);c[3541534]=o+(r+868480);c[2405150]=o+(r+876672);c[3541530]=o+(r+942208);c[3541528]=o+(r+946304);c[2411382]=o+(r+950400);c[3541506]=o+(r+954496);c[3541500]=o+(r+970880);s=o+(r+971392)|0;c[2411470]=s;c[3531916]=s;c[2414010]=o+(r+979584);do{if((c[3542200]|0)!=0){r=m+108|0;c[r>>2]=0;s=m+100|0;c[s>>2]=0;t=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[t&16383](m,0)|0;if((c[r>>2]|0)==0){break}r=c[s>>2]|0;c[n>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](n,0,0)|0;if((r|0)<1){break}gzL(o,0,0)|0}}while(0);fpl(c[3541502]|0,1,2,c[2113208]|0,0);o=c[3541206]|0;do{if((c[3542200]|0)!=0){r=k+108|0;c[r>>2]=0;s=k+100|0;c[s>>2]=0;t=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[t&16383](k,3)|0;if((c[r>>2]|0)==0){break}r=c[s>>2]|0;c[l>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](l,3,0)|0;if((r|0)<1){break}gzL(o,0,3)|0}}while(0);o=c[2414456]|0;do{if((c[3542200]|0)!=0){r=g+108|0;c[r>>2]=0;s=g+100|0;c[s>>2]=0;t=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[t&16383](g,4)|0;if((c[r>>2]|0)==0){break}r=c[s>>2]|0;c[j>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](j,4,0)|0;if((r|0)<1){break}gzL(o,0,4)|0}}while(0);o=c[2414456]|0;do{if((c[3542200]|0)!=0){r=e+108|0;c[r>>2]=0;s=e+100|0;c[s>>2]=0;t=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[t&16383](e,5)|0;if((c[r>>2]|0)==0){break}r=c[s>>2]|0;c[f>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](f,5,0)|0;if((r|0)<1){break}gzL(o,0,5)|0}}while(0);fxU(0,425984);if((c[2394]|0)==0){u=c[2112932]|0}else{c[2394]=0;o=c[3532596]|0;c[2112932]=o;r=c[3532592]|0;if((r|0)!=0){gGC(9104152,r|0,280)|0}c[2113054]=c[2113060];u=o}o=c[2418098]|0;r=u|0;s=0;while(1){t=o+s|0;c[r>>2]=t;c[r+131072>>2]=t;t=s+1024|0;if(t>>>0>524287){break}else{r=r+4|0;s=t}}s=c[2418212]|0;c[u+4096>>2]=s;c[u+69632>>2]=s;c[u+135168>>2]=s;r=s+1024|0;c[u+4100>>2]=r;c[u+69636>>2]=r;c[u+135172>>2]=r;r=s+2048|0;c[u+4104>>2]=r;c[u+69640>>2]=r;c[u+135176>>2]=r;r=s+3072|0;c[u+4108>>2]=r;c[u+69644>>2]=r;c[u+135180>>2]=r;r=s+4096|0;c[u+4112>>2]=r;c[u+69648>>2]=r;c[u+135184>>2]=r;r=s+5120|0;c[u+4116>>2]=r;c[u+69652>>2]=r;c[u+135188>>2]=r;r=s+6144|0;c[u+4120>>2]=r;c[u+69656>>2]=r;c[u+135192>>2]=r;r=s+7168|0;c[u+4124>>2]=r;c[u+69660>>2]=r;c[u+135196>>2]=r;r=s+8192|0;c[u+4128>>2]=r;c[u+69664>>2]=r;c[u+135200>>2]=r;r=s+9216|0;c[u+4132>>2]=r;c[u+69668>>2]=r;c[u+135204>>2]=r;r=s+10240|0;c[u+4136>>2]=r;c[u+69672>>2]=r;c[u+135208>>2]=r;r=s+11264|0;c[u+4140>>2]=r;c[u+69676>>2]=r;c[u+135212>>2]=r;r=s+12288|0;c[u+4144>>2]=r;c[u+69680>>2]=r;c[u+135216>>2]=r;r=s+13312|0;c[u+4148>>2]=r;c[u+69684>>2]=r;c[u+135220>>2]=r;r=s+14336|0;c[u+4152>>2]=r;c[u+69688>>2]=r;c[u+135224>>2]=r;r=s+15360|0;c[u+4156>>2]=r;c[u+69692>>2]=r;c[u+135228>>2]=r;r=c[2411382]|0;c[u+16384>>2]=r;c[u+81920>>2]=r;c[u+147456>>2]=r;s=r+1024|0;c[u+16388>>2]=s;c[u+81924>>2]=s;c[u+147460>>2]=s;s=r+2048|0;c[u+16392>>2]=s;c[u+81928>>2]=s;c[u+147464>>2]=s;s=r+3072|0;c[u+16396>>2]=s;c[u+81932>>2]=s;c[u+147468>>2]=s;s=c[3541534]|0;c[u+20480>>2]=s;c[u+86016>>2]=s;c[u+151552>>2]=s;r=s+1024|0;c[u+20484>>2]=r;c[u+86020>>2]=r;c[u+151556>>2]=r;r=s+2048|0;c[u+20488>>2]=r;c[u+86024>>2]=r;c[u+151560>>2]=r;r=s+3072|0;c[u+20492>>2]=r;c[u+86028>>2]=r;c[u+151564>>2]=r;r=s+4096|0;c[u+20496>>2]=r;c[u+86032>>2]=r;c[u+151568>>2]=r;r=s+5120|0;c[u+20500>>2]=r;c[u+86036>>2]=r;c[u+151572>>2]=r;r=s+6144|0;c[u+20504>>2]=r;c[u+86040>>2]=r;c[u+151576>>2]=r;r=s+7168|0;c[u+20508>>2]=r;c[u+86044>>2]=r;c[u+151580>>2]=r;r=c[3541528]|0;c[u+20512>>2]=r;c[u+86048>>2]=r;c[u+151584>>2]=r;s=r+1024|0;c[u+20516>>2]=s;c[u+86052>>2]=s;c[u+151588>>2]=s;s=r+2048|0;c[u+20520>>2]=s;c[u+86056>>2]=s;c[u+151592>>2]=s;s=r+3072|0;c[u+20524>>2]=s;c[u+86060>>2]=s;c[u+151596>>2]=s;s=c[3541530]|0;c[u+20528>>2]=s;c[u+86064>>2]=s;c[u+151600>>2]=s;r=s+1024|0;c[u+20532>>2]=r;c[u+86068>>2]=r;c[u+151604>>2]=r;r=s+2048|0;c[u+20536>>2]=r;c[u+86072>>2]=r;c[u+151608>>2]=r;r=s+3072|0;c[u+20540>>2]=r;c[u+86076>>2]=r;c[u+151612>>2]=r;c[u+196688>>2]=672;c[u+196608>>2]=1060;c[u+196728>>2]=1902;c[u+196648>>2]=660;r=c[3532592]|0;if((r|0)!=0){gGC(r|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fyz(0,65552,16e6);c[1836234]=0;r=c[2439374]|0;c[3531864]=r;gf[c[r>>2]&2047](0);r=c[2405150]|0;s=c[3531864]|0;o=524288;do{t=o>>11;v=(o|32767)+2047>>11;if((t|0)<(v|0)){w=r+(-o|0)|0;x=t;while(1){c[s+44+(x<<2)>>2]=w;y=x+1|0;if((y|0)<(v|0)){x=y}else{z=t;break}}while(1){c[s+2092+(z<<2)>>2]=w;x=z+1|0;if((x|0)<(v|0)){z=x}else{A=t;break}}do{c[s+4140+(A<<2)>>2]=w;c[s+6188+(A<<2)>>2]=w;A=A+1|0;}while((A|0)<(v|0))}o=o+32768|0;}while((o|0)<1048576);c[s+8236>>2]=2638;c[s+8240>>2]=640;c[s+8244>>2]=1616;c[s+8248>>2]=1416;o=c[s+20>>2]|0;if((o|0)==0){B=s}else{gf[o&2047](681368);B=c[3531864]|0}c[1836234]=-1;gu[c[B+4>>2]&16383]();c[3531864]=0;Tq(689576);c[3528394]=b;c[2113182]=-470;c[2113178]=-472;c[2113174]=-474;c[2113040]=1;fl6(1);if((c[2408]|0)==39321){c[2408]=43}c[2113016]=2048;c[3531920]=c[2411382];o=a[9680]|0;r=o?32e3:0;if(o){if(a[9624]|0){o=r*3|0;v=52734;while(1){if((v|0)>(o|0)){v=v>>1}else{C=1222;D=v;break}}}else{C=2462;D=r}c[2429380]=D;c[3542124]=C;mw(3375e3,D);v=gGq(262144)|0;c[2406684]=v;gGz(v|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(3375e3,11025)}h[745421]=.5;c[2436794]=3;h[745420]=.5;c[2436792]=3;Ux(0,7575,1);c[2407030]=128;c[2407068]=3;a[7072544]=1;fuo();E=0;i=d;return E|0}}while(0);c[2426630]=0;E=1;i=d;return E|0}function fuo(){var b=0,d=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];b=c[3532592]|0;if((b|0)!=0){gGC(9104152,b|0,280)|0}c[2113054]=c[2113060]}RI();b=c[2394]|0;d=c[14130368+(b<<2)>>2]|0;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[8452240+(b<<2)>>2]=c[2113054];c[2394]=-1;c[1836234]=0;b=c[2439374]|0;c[3531864]=b;gf[c[b>>2]&2047](0);gD[c[(c[3531864]|0)+8>>2]&8191]()|0;c[1836234]=-1;gu[c[(c[3531864]|0)+4>>2]&16383]();c[3531864]=0;c[2113156]=0;a[9628264]=0;c[2407033]=0;b=c[3541206]|0;c[3541190]=b;c[3541198]=b;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=b+256;c[3541199]=b+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=b+512;c[3541200]=b+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=b+768;c[3541201]=b+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;mx(0);c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];if(a[1040128]|0){c[2385194]=1;return}b=c[2414456]|0;gGC(14100392,b|0,128)|0;c[2385194]=1;return}function fup(b){b=b|0;var d=0;switch(b&255|0){case 132:{d=c[2113157]&255;break};case 130:{d=c[2113156]&255;break};case 129:{d=c[(c[3531464]|0)+4240>>2]&255;break};case 72:{d=a[c[3532640]|0]|0;break};case 74:{d=a[(c[3532640]|0)+1|0]|0;break};default:{d=0}}return d|0}function fuq(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;switch(b&255|0){case 194:{b=c[3541206]|0;e=d&255;f=e<<16&983040;c[3541192]=b+(f|512);c[3541200]=b+f;f=e<<12&983040;c[3541193]=b+(f|768);c[3541201]=b+f;return};case 196:{f=c[3541206]|0;b=d&255;e=f+(b<<16&983040|1048576)|0;c[3541194]=e;c[3541202]=e;e=b<<12&983040;c[3541195]=f+(e|1048832);c[3541203]=f+(e|1048576);return};case 130:{Uv(0,d);return};case 132:{Uv(1,d);return};case 136:{e=d&15;if((e|0)==(c[2440566]|0)){return}f=c[3532626]|0;b=c[9757320+(c[1836236]<<2)>>2]|0;g=(e<<14)-32768|0;h=128;i=128;while(1){c[b+76+(i<<2)>>2]=f+(g+(i<<8));j=h+1&65535;if((j&65535)>191){k=128;l=128;break}else{h=j;i=j&65535}}while(1){i=f+(g+(l<<8))|0;c[b+76+(l+512<<2)>>2]=i;c[b+76+(l+768<<2)>>2]=i;i=k+1&65535;if((i&65535)>191){break}else{k=i;l=i&65535}}c[2440566]=e;return};case 66:{a[(c[3532640]|0)+5|0]=d;return};case 64:{a[(c[3532640]|0)+4|0]=d;return};case 129:{e=c[2113304]|0;a[14168504+e|0]=d;mv(0,e,d&255);return};case 198:{e=c[3541206]|0;l=d&255;k=l<<16&983040;c[3541196]=e+(k|1049088);c[3541204]=e+(k|1048576);k=l<<12&983040;c[3541197]=e+(k|1049344);c[3541205]=e+(k|1048576);return};case 192:{k=c[3541206]|0;e=d&255;l=k+(e<<16&983040)|0;c[3541190]=l;c[3541198]=l;l=e<<12&983040;c[3541191]=k+(l|256);c[3541199]=k+l;return};case 128:{c[2113304]=d&255;return};default:{return}}}function fur(b){b=b|0;var d=0;L90419:do{switch(b|0){case 5242885:{d=a[9620475]|0;break};case 5242883:{d=a[9620474]|0;break};case 5242881:{d=a[9620472]|0;break};case 5242882:{d=a[9620477]|0;break};case 5242884:{d=a[9620476]|0;break};case 5242880:{d=a[9620473]|0;break};default:{if((b&16252928|0)!=3145728){d=0;break L90419}d=a[(c[3532626]|0)+(b>>>1&262143)|0]|0}}}while(0);return d|0}function fus(a){a=a|0;var b=0,e=0,f=0;if((a|0)==5242890){b=d[(c[3532640]|0)+5|0]|0;return b|0}else if((a|0)==5242886){e=((c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0)/(c[2113058]|0)|0;if((e|0)==(c[2384338]|0)){f=65024}else{c[2384338]=e;f=32256}b=(f|e)&65535;return b|0}else if((a|0)==5242888){b=d[(c[3532640]|0)+4|0]|0;return b|0}else if((a|0)==5242892){b=c[2415178]&65535;return b|0}else{b=0;return b|0}return 0}function fut(a,b){a=a|0;b=b|0;return}function fuu(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;switch(b|0){case 5242914:{a[(c[3532640]|0)+1|0]=d&255;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;e=c[2433530]|0;c[2433530]=e+12;if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){f=gfc(6144)|0;g=f;h=(c[2433530]|0)+f|0}else{g=6144;h=e+6156|0}c[2433530]=h;c[2113221]=(c[2113221]|0)+g;return};case 5243008:{if((c[2438130]|0)==0){return}g=c[3541534]|0;h=c[2112932]|0;c[h+8192>>2]=g;c[h+73728>>2]=g;c[h+139264>>2]=g;e=g+1024|0;c[h+8196>>2]=e;c[h+73732>>2]=e;c[h+139268>>2]=e;e=g+2048|0;c[h+8200>>2]=e;c[h+73736>>2]=e;c[h+139272>>2]=e;e=g+3072|0;c[h+8204>>2]=e;c[h+73740>>2]=e;c[h+139276>>2]=e;e=g+4096|0;c[h+8208>>2]=e;c[h+73744>>2]=e;c[h+139280>>2]=e;e=g+5120|0;c[h+8212>>2]=e;c[h+73748>>2]=e;c[h+139284>>2]=e;e=g+6144|0;c[h+8216>>2]=e;c[h+73752>>2]=e;c[h+139288>>2]=e;e=g+7168|0;c[h+8220>>2]=e;c[h+73756>>2]=e;c[h+139292>>2]=e;e=c[2411380]|0;c[h+8224>>2]=e;c[h+73760>>2]=e;c[h+139296>>2]=e;g=e+1024|0;c[h+8228>>2]=g;c[h+73764>>2]=g;c[h+139300>>2]=g;g=e+2048|0;c[h+8232>>2]=g;c[h+73768>>2]=g;c[h+139304>>2]=g;g=e+3072|0;c[h+8236>>2]=g;c[h+73772>>2]=g;c[h+139308>>2]=g;g=c[2418210]|0;e=h+8240|0;h=2109440;while(1){f=g+(h-2109440)|0;c[e>>2]=f;c[e+65536>>2]=f;c[e+131072>>2]=f;f=h+1024|0;if(f>>>0>2129919){break}else{e=e+4|0;h=f}}c[2438130]=0;return};case 5242976:{c[2415178]=d&65535;return};case 5243072:case 5243073:case 5243074:case 5243075:case 5243076:case 5243077:case 5243078:case 5243079:case 5243080:case 5243081:case 5243082:case 5243083:case 5243084:case 5243085:case 5243086:{c[14165960+((b>>>1&7)<<2)>>2]=(d&65535)<<15&491520;return};case 5242916:{a[9775600]=1;c[8452200+(c[2394]<<2)>>2]=4100;c[2276080]=1024;if((c[2276079]|0)>>>0>=1024){return}RH(4);return};case 5243010:{c[8452200+(c[2394]<<2)>>2]=0;c[2276080]=0;a[9775600]=0;return};case 5242912:{a[c[3532640]|0]=d&255;if(d<<16>>16!=85){return}if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;d=c[2433530]|0;c[2433530]=d+12;if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){b=gfc(6144)|0;i=b;j=(c[2433530]|0)+b|0}else{i=6144;j=d+6156|0}c[2433530]=j;c[2113221]=(c[2113221]|0)+i;return};default:{return}}}function fuv(a){a=a|0;var d=0;if((a|0)==4194312){d=b[c[3541508]>>1]|0}else if((a|0)==4194314){d=b[(c[3541508]|0)+2>>1]|0}else{d=0}return d|0}function fuw(a,d){a=a|0;d=d|0;switch(a|0){case 4194312:case 4194314:{b[c[3541508]>>1]=d;c[3541508]=(c[3541508]|0)+2;return};case 4194304:{b[(c[3541500]|0)+(c[3541498]<<1)>>1]=d;return};case 4194308:{c[3541498]=d&255;return};case 4194316:{c[3541508]=(c[3541506]|0)+((d&65535)<<1&16382);return};default:{return}}}function fux(b){b=b|0;return a[(c[3532626]|0)+(b>>>1&262143)|0]|0}function fuy(a){a=a|0;return d[(c[3532626]|0)+(a>>>1&262143)|0]|0|0}function fuz(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5949140+(b*112|0)>>2];c[a+104>>2]=c[5949144+(b*112|0)>>2];c[a+108>>2]=c[5949148+(b*112|0)>>2];d=0;return d|0}function fuA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=5949040+(b*112|0);e=0;return e|0}function fuB(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>24){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1171608+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function fuC(a,b){a=a|0;b=b|0;var d=0,e=0;if((b|0)==0){if((a|0)==0){d=0;return d|0}e=a;c[e>>2]=c[200404];c[e+4>>2]=c[200405];c[e+8>>2]=c[200406];d=0;return d|0}e=b-1|0;if(e>>>0>133){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;a=3112008+(e*12|0)|0;c[b>>2]=c[a>>2];c[b+4>>2]=c[a+4>>2];c[b+8>>2]=c[a+8>>2];d=0;return d|0}function fuD(){var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;d=i;i=i+360|0;e=d|0;f=d+112|0;g=d+120|0;j=d+232|0;k=d+240|0;l=d+352|0;c[2113208]=16777216;c[2426628]=0;c[2418096]=0;c[3532626]=2097152;c[3541502]=2359296;c[3541206]=19136512;c[2405566]=21233664;c[3541534]=21233664;c[2418210]=21241856;c[3541532]=21262336;c[2418194]=21295104;c[2411380]=21327872;c[3532636]=21331968;c[3541506]=21348352;c[3541500]=21364736;c[3532640]=21365248;c[2411468]=21365256;c[3531916]=21365256;c[3541528]=21241856;c[3541530]=21242368;m=0;while(1){if((m|0)>=1024){break}n=9638528+(m<<2)|0;if((c[n>>2]|0)==0){o=69445;break}else{m=m+1|0}}do{if((o|0)==69445){m=gGq(21373448)|0;c[n>>2]=m;if((m|0)==0){break}c[2426628]=m;gGz(m|0,0,21373448);c[2418096]=m;c[3532626]=m+2097152;c[3541502]=m+2359296;p=c[2113208]|0;c[3541206]=m+(p+2359296);q=m+(p+4456448)|0;c[2405566]=q;c[3541534]=q;q=m+(p+4464640)|0;c[2418210]=q;c[3541532]=m+(p+4485120);c[2418194]=m+(p+4517888);c[2411380]=m+(p+4550656);c[3532636]=m+(p+4554752);c[3541506]=m+(p+4571136);c[3541500]=m+(p+4587520);c[3532640]=m+(p+4588032);r=m+(p+4588040)|0;c[2411468]=r;c[3531916]=r;c[2414008]=m+(p+4596232);c[3541528]=q;c[3541530]=m+(p+4465152);if((fpk(m,4)|0)!=0){s=1;i=d;return s|0}fpl(c[3541502]|0,4,4,c[2113208]|0,0);m=c[3532626]|0;if((c[3542200]|0)==0){s=1;i=d;return s|0}p=k+108|0;c[p>>2]=0;q=k+100|0;c[q>>2]=0;r=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[r&16383](k,8)|0;do{if((c[p>>2]|0)!=0){r=c[q>>2]|0;c[l>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](l,8,0)|0;if((r|0)<1){s=1;i=d;return s|0}if((gzL(m,0,8)|0)==0){break}else{s=1}i=d;return s|0}}while(0);m=c[3541206]|0;do{if((c[3542200]|0)!=0){q=g+108|0;c[q>>2]=0;p=g+100|0;c[p>>2]=0;r=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[r&16383](g,9)|0;if((c[q>>2]|0)==0){break}q=c[p>>2]|0;c[j>>2]=9534384;p=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[p&16383](j,9,0)|0;if((q|0)<1){break}gzL(m,0,9)|0}}while(0);m=(c[3541206]|0)+1048576|0;do{if((c[3542200]|0)!=0){q=e+108|0;c[q>>2]=0;p=e+100|0;c[p>>2]=0;r=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[r&16383](e,10)|0;if((c[q>>2]|0)==0){break}q=c[p>>2]|0;c[f>>2]=9534384;p=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[p&16383](f,10,0)|0;if((q|0)<1){break}gzL(m,0,10)|0}}while(0);fxU(0,425984);if((c[2394]|0)==0){u=c[2112932]|0}else{c[2394]=0;m=c[3532596]|0;c[2112932]=m;q=c[3532592]|0;if((q|0)!=0){gGC(9104152,q|0,280)|0}c[2113054]=c[2113060];u=m}m=c[2418096]|0;q=u|0;p=0;while(1){r=m+p|0;c[q>>2]=r;c[q+131072>>2]=r;r=p+1024|0;if(r>>>0>2097151){break}else{q=q+4|0;p=r}}p=c[2418194]|0;q=u+8320|0;m=2129920;while(1){r=p+(m-2129920)|0;c[q>>2]=r;c[q+65536>>2]=r;c[q+131072>>2]=r;r=m+1024|0;if(r>>>0>2162687){break}else{q=q+4|0;m=r}}if((c[2438130]|0)!=1){m=c[3541532]|0;q=u+8192|0;p=2097152;while(1){r=m+(p-2097152)|0;c[q>>2]=r;c[q+65536>>2]=r;c[q+131072>>2]=r;r=p+1024|0;if(r>>>0>2129919){break}else{q=q+4|0;p=r}}c[2438130]=1}c[u+196688>>2]=66;c[u+196608>>2]=1898;c[u+196728>>2]=2544;c[u+196648>>2]=2554;c[u+16384>>2]=1;c[u+81920>>2]=1;c[u+147456>>2]=1;c[u+16388>>2]=1;c[u+81924>>2]=1;c[u+147460>>2]=1;c[u+196692>>2]=2702;c[u+196732>>2]=702;p=u+12288|0;q=3145728;while(1){c[p>>2]=2;c[p+131072>>2]=2;m=q+1024|0;if(m>>>0>3670015){break}else{p=p+4|0;q=m}}c[u+196616>>2]=1130;c[u+196696>>2]=3016;q=c[3532592]|0;if((q|0)!=0){gGC(q|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;c[2113040]=1;c[2113182]=-470;c[2113178]=-472;c[2113174]=-474;fl6(1);c[2408]=44;fwR(0);q=c[2439330]|0;p=(q|0)==0;if(!p){m=q;gGC(9706056,m|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];m=c[3528484]|0;c[2076596]=m;r=c[2417276]|0;c[3541536]=r;c[1836236]=0;c[q+4172>>2]=754;c[q+4176>>2]=2408;t=c[3532626]|0;v=0;w=0;while(1){c[q+76+(w<<2)>>2]=t+(w<<8);x=v+1&65535;if((x&65535)>127){y=0;z=0;break}else{v=x;w=x&65535}}while(1){w=t+(z<<8)|0;c[q+76+(z+512<<2)>>2]=w;c[q+76+(z+768<<2)>>2]=w;w=y+1&65535;if((w&65535)>127){A=128;B=128;break}else{y=w;z=w&65535}}while(1){c[q+76+(B<<2)>>2]=t+(B<<8);w=A+1&65535;if((w&65535)>191){C=128;D=128;break}else{A=w;B=w&65535}}while(1){w=t+(D<<8)|0;c[q+76+(D+512<<2)>>2]=w;c[q+76+(D+768<<2)>>2]=w;w=C+1&65535;if((w&65535)>191){break}else{C=w;D=w&65535}}t=c[3532636]|0;w=192;v=192;while(1){c[q+76+(v<<2)>>2]=t+((v<<8)-49152);x=w+1&65535;if((x&65535)>223){E=192;F=192;break}else{w=x;v=x&65535}}while(1){c[q+76+(F+256<<2)>>2]=t+((F<<8)-49152);v=E+1&65535;if((v&65535)>223){G=192;H=192;break}else{E=v;F=v&65535}}while(1){v=t+((H<<8)-49152)|0;c[q+76+(H+512<<2)>>2]=v;c[q+76+(H+768<<2)>>2]=v;v=G+1&65535;if((v&65535)>223){break}else{G=v;H=v&65535}}if(!p){t=q;gGC(t|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=m;c[2417276]=r;c[1836236]=-1;c[2440566]=2;t=a[9680]|0;v=t?32e3:0;if(t){if(a[9624]|0){t=v*3|0;w=62500;while(1){if((w|0)>(t|0)){w=w>>1}else{I=1222;J=w;break}}}else{I=2462;J=v}c[2429380]=J;c[3542124]=I;mw(4e6,J);w=gGq(262144)|0;c[2406684]=w;gGz(w|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(4e6,11025)}h[745421]=1.0;c[2436794]=3;h[745420]=1.0;c[2436792]=3;Ux(0,24242,1);Ux(1,19393,1);c[2407030]=256;c[2407068]=3;c[2407069]=256;c[2407107]=3;c[2113016]=2048;c[3531920]=c[2411380];c[2438130]=-1;a[7072536]=1;fuZ();s=0;i=d;return s|0}}while(0);c[2426628]=0;s=1;i=d;return s|0}function fuE(){var a=0,b=0,d=0,e=0,f=0;Uw(0);Uw(1);a=c[3531464]|0;c[a+44344>>2]=0;c[a+44348>>2]=0;if((a|0)!=0){gGr(a);c[3531464]=0}a=c[2406684]|0;if((a|0)!=0){gGr(a);c[2406684]=0}fl7();c[2408]=39321;fwZ();if((c[2392]|0)>=0){a=0;do{b=14130368+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}b=14130384+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}a=a+1|0;}while((a|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;a=c[2426628]|0;b=0;while(1){if((b|0)>=1024){e=69519;break}f=9638528+(b<<2)|0;if((c[f>>2]|0)==(a|0)){break}else{b=b+1|0}}if((e|0)==69519){c[2426628]=0;return 0}gGr(a);c[f>>2]=0;c[2426628]=0;return 0}function fuF(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;if((a[9620464]|0)!=0){fuZ()}a[9620472]=0;a[9620473]=0;a[9620474]=0;d=0;e=0;f=0;g=0;do{e=((a[9627040+d|0]&1)<<d|e&255)&255;f=((a[9627032+d|0]&1)<<d|f&255)&255;g=((a[9542504+d|0]&1)<<d|g&255)&255;d=d+1|0;}while((d|0)<8);a[9620472]=e;a[9620473]=f;a[9620474]=g;if((e&3)==3){g=e&-4;a[9620472]=g;h=g}else{h=e}if((h&12)==12){a[9620472]=h&-13}if((f&3)==3){h=f&-4;a[9620473]=h;i=h}else{i=f}if((i&12)==12){a[9620473]=i&-13}i=c[2392]|0;if((i|0)>=0){gGz(8452240,0,((i|0)>0?(i<<2)+4|0:4)|0)}c[2113054]=0;i=c[2438]|0;f=gGU(i,(i|0)<0|0?-1:0,16e6,0)|0;i=gGS(f,K,15360,0)|0;f=i;c[2113218]=f;c[2113216]=66666;c[2113221]=0;c[2113220]=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];i=c[3532592]|0;if((i|0)!=0){gGC(9104152,i|0,280)|0}c[2113054]=c[2113060]}c[2113058]=(f|0)/262|0;c[2113018]=f-((f*22|0|0)/262|0);a[670552]=0;i=c[2439330]|0;if((i|0)!=0){h=i;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;h=1;i=0;e=f;f=0;while(1){g=(ag(e,h)|0)/8|0;do{if(!f){d=c[2113018]|0;if((g|0)<=(d|0)){break}j=c[2113220]|0;if((j|0)<(d|0)){k=d-j|0;c[2113056]=k;j=RG(k)|0;c[2113054]=(c[2113054]|0)+j;c[2276108]=-1;c[2113056]=-1;c[2113220]=(c[2113220]|0)+j}j=c[2430398]|0;k=c[2439196]|0;d=k<<11;c[2438976]=j+d;l=(c[2440572]|0)>1;if(l){c[2438977]=(c[2430399]|0)+d}d=k^1;c[2439196]=d;k=d<<11;d=j+k|0;j=(c[3541506]|0)+12288|0;gGC(d|0,j|0,2048)|0;if(l){l=(c[2430399]|0)+k|0;k=(c[3541504]|0)+12288|0;gGC(l|0,k|0,2048)|0}k=c[2112968]|0;do{if((k|0)!=0){l=c[3531916]|0;j=c[l>>2]|0;d=c[2113308]|0;do{if((j|0)==0){gGz(k|0,0,d*76800|0|0)}else{if((d|0)==4){m=0;n=k;while(1){c[n>>2]=j;c[n+4>>2]=j;c[n+8>>2]=j;c[n+12>>2]=j;c[n+16>>2]=j;c[n+20>>2]=j;c[n+24>>2]=j;c[n+28>>2]=j;o=m+1|0;if((o|0)<9600){m=o;n=n+32|0}else{break}}}else if((d|0)==2){n=j<<16|j;m=k;o=0;while(1){c[m>>2]=n;c[m+4>>2]=n;c[m+8>>2]=n;c[m+12>>2]=n;c[m+16>>2]=n;c[m+20>>2]=n;c[m+24>>2]=n;c[m+28>>2]=n;p=o+1|0;if((p|0)<4800){m=m+32|0;o=p}else{break}}}else if((d|0)==3){o=j>>>8&255;m=j>>>16&255;n=j&255;p=k;q=0;while(1){a[p]=n;a[p+1|0]=o;a[p+2|0]=m;r=q+1|0;if((r|0)<76800){p=p+3|0;q=r}else{break}}}else{break}}}while(0);if(a[7072536]|0){c[2112970]=k;c[2113306]=d;c[2113298]=c[2113300];fl3();fnZ();s=c[3531916]|0}else{s=l}c[2112966]=s;j=c[2113016]|0;if((j|0)>0){t=0}else{break}do{c[s+(t<<2)>>2]=65535;t=t+1|0;}while((t|0)<(j|0))}}while(0);a[9775600]=1;c[8452200+(c[2394]<<2)>>2]=4098;c[2276080]=512;if((c[2276079]|0)>>>0<512){RH(2)}a[670552]=1}}while(0);k=g-(c[2113220]|0)|0;c[2113056]=k;j=RG(k)|0;c[2113054]=(c[2113054]|0)+j;c[2276108]=-1;c[2113056]=-1;c[2113220]=(c[2113220]|0)+j;do{if((h&1|0)==0){j=(ag(c[2113216]|0,h)|0)/8|0;k=c[2113221]|0;l=j-k|0;do{if((l|0)<1){u=0;v=k}else{if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){j=gfc(l)|0;c[2433530]=(c[2433530]|0)+j;u=j;v=c[2113221]|0;break}else{c[2433530]=(c[2433530]|0)+l;u=l;v=k;break}}}while(0);c[2113221]=v+u;k=c[2112964]|0;if((k|0)==0){w=i;break}l=(ag(a[9688]|0?534:0,h)|0)/8|0;j=l-i|0;d=k+(i<<1<<1)|0;gg[c[3542124]&4095](d,j);Uu(0,d,j);Uu(1,d,j);w=l}else{w=i}}while(0);g=h+1|0;if((g|0)>=9){break}h=g;i=w;e=c[2113218]|0;f=a[670552]|0}f=c[2394]|0;e=c[14130368+(f<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(f<<2)>>2]=c[2113054];c[2394]=-1;f=c[2112964]|0;do{if((f|0)!=0){e=a[9688]|0?534:0;i=e-w|0;h=f+(w<<1<<1)|0;if((e|0)==(w|0)){break}gg[c[3542124]&4095](h,i);Uu(0,h,i);Uu(1,h,i)}}while(0);w=c[1836236]|0;f=c[9757320+(w<<2)>>2]|0;if((f|0)==0){x=c[2433530]|0;y=9752472+(w<<2)|0;c[y>>2]=x;z=c[2076596]|0;A=14113936+(w<<2)|0;c[A>>2]=z;B=c[3541536]|0;C=9669104+(w<<2)|0;c[C>>2]=B;c[1836236]=-1;return 0}i=f;gGC(i|0,9706056,76)|0;x=c[2433530]|0;y=9752472+(w<<2)|0;c[y>>2]=x;z=c[2076596]|0;A=14113936+(w<<2)|0;c[A>>2]=z;B=c[3541536]|0;C=9669104+(w<<2)|0;c[C>>2]=B;c[1836236]=-1;return 0}function fuG(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[3531916]|0;d=c[b>>2]|0;do{if((d|0)==0){e=c[2113308]|0;gGz(c[2112968]|0,0,e*76800|0|0);f=e}else{e=c[2113308]|0;if((e|0)==3){g=d>>>8&255;h=d>>>16&255;i=d&255;j=c[2112968]|0;k=0;while(1){a[j]=i;a[j+1|0]=g;a[j+2|0]=h;l=k+1|0;if((l|0)<76800){j=j+3|0;k=l}else{f=3;break}}}else if((e|0)==4){k=0;j=c[2112968]|0;while(1){c[j>>2]=d;c[j+4>>2]=d;c[j+8>>2]=d;c[j+12>>2]=d;c[j+16>>2]=d;c[j+20>>2]=d;c[j+24>>2]=d;c[j+28>>2]=d;h=k+1|0;if((h|0)<9600){k=h;j=j+32|0}else{f=4;break}}}else if((e|0)==2){j=d<<16|d;k=c[2112968]|0;h=0;while(1){c[k>>2]=j;c[k+4>>2]=j;c[k+8>>2]=j;c[k+12>>2]=j;c[k+16>>2]=j;c[k+20>>2]=j;c[k+24>>2]=j;c[k+28>>2]=j;g=h+1|0;if((g|0)<4800){k=k+32|0;h=g}else{f=2;break}}}else{f=e;break}}}while(0);if(a[7072536]|0){c[2112970]=c[2112968];c[2113306]=f;c[2113298]=c[2113300];fl3();fnZ();m=c[3531916]|0}else{m=b}c[2112966]=m;b=c[2113016]|0;if((b|0)>0){n=0}else{return 0}do{c[m+(n<<2)>>2]=65535;n=n+1|0;}while((n|0)<(b|0));return 0}function fuH(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;g=i;i=i+224|0;h=g|0;j=g+16|0;k=g+32|0;l=g+48|0;m=g+64|0;n=g+80|0;o=g+96|0;p=g+112|0;q=g+128|0;r=g+144|0;s=g+160|0;t=g+176|0;u=g+192|0;v=g+208|0;w=(f|0)==0;if(!w){c[f>>2]=169110}if((e&96|0)==0){i=g;return 0}gGz(v|0,0,12);x=c[2405566]|0;c[v>>2]=x;c[v+4>>2]=(c[2411468]|0)-x;c[v+12>>2]=219592;gj[c[2076592]&4095](v)|0;v=q|0;x=(e&64|0)==0;do{if(!x){gGz(p|0,0,16);c[2394]=-1;if((c[2392]|0)<0){break}y=q+9|0;z=o;A=o|0;B=o+4|0;C=o+12|0;D=p|0;E=p+4|0;F=p+12|0;G=0;do{gGC(v|0,614896,11)|0;a[y]=G+48&255;H=8452256+(G<<2)|0;gGz(z|0,0,12);c[A>>2]=H;c[B>>2]=4;c[C>>2]=164976;gj[c[2076592]&4095](o)|0;if((c[H>>2]|0)!=0){c[D>>2]=c[14130368+(G<<2)>>2];c[E>>2]=c[8452184+(G<<2)>>2];c[F>>2]=v;H=c[2076592]|0;gj[H&4095](p)|0}G=G+1|0;}while((G|0)<=(c[2392]|0))}}while(0);fw$(e);gGz(u|0,0,12);c[u>>2]=9762264;c[u+4>>2]=4;c[u+12>>2]=69312;gj[c[2076592]&4095](u)|0;Ut(0);Ut(1);do{if(!x){gGz(n|0,0,12);c[n>>2]=8453216;c[n+4>>2]=4;c[n+12>>2]=107480;u=c[2076592]|0;gj[u&4095](n)|0;gGz(m|0,0,12);c[m>>2]=14168504;c[m+4>>2]=256;c[m+12>>2]=476464;u=c[2076592]|0;gj[u&4095](m)|0;if((e&2|0)==0){break}else{I=0}do{mv(0,I,d[14168504+I|0]|0);I=I+1|0;}while((I|0)<256)}}while(0);if(!w){c[f>>2]=169110}gGz(l|0,0,12);c[l>>2]=9756784;c[l+4>>2]=4;c[l+12>>2]=175504;gj[c[2076592]&4095](l)|0;gGz(k|0,0,12);c[k>>2]=14166032;c[k+4>>2]=8;c[k+12>>2]=504552;gj[c[2076592]&4095](k)|0;gGz(j|0,0,12);c[j>>2]=14165992;c[j+4>>2]=8;c[j+12>>2]=388736;gj[c[2076592]&4095](j)|0;gGz(h|0,0,12);c[h>>2]=14165960;c[h+4>>2]=32;c[h+12>>2]=302352;gj[c[2076592]&4095](h)|0;gGz(t|0,0,12);c[t>>2]=9775600;c[t+4>>2]=1;c[t+12>>2]=68056;gj[c[2076592]&4095](t)|0;gGz(s|0,0,12);c[s>>2]=9752520;c[s+4>>2]=4;c[s+12>>2]=66536;gj[c[2076592]&4095](s)|0;gGz(r|0,0,12);c[r>>2]=9620472;c[r+4>>2]=6;c[r+12>>2]=65272;gj[c[2076592]&4095](r)|0;if((e&2|0)==0){i=g;return 0}e=c[2438130]|0;c[2438130]=-1;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];r=c[3532592]|0;if((r|0)!=0){gGC(9104152,r|0,280)|0}c[2113054]=c[2113060]}if((e|0)==0){e=c[3541534]|0;r=c[2112932]|0;c[r+8192>>2]=e;c[r+73728>>2]=e;c[r+139264>>2]=e;s=e+1024|0;c[r+8196>>2]=s;c[r+73732>>2]=s;c[r+139268>>2]=s;s=e+2048|0;c[r+8200>>2]=s;c[r+73736>>2]=s;c[r+139272>>2]=s;s=e+3072|0;c[r+8204>>2]=s;c[r+73740>>2]=s;c[r+139276>>2]=s;s=e+4096|0;c[r+8208>>2]=s;c[r+73744>>2]=s;c[r+139280>>2]=s;s=e+5120|0;c[r+8212>>2]=s;c[r+73748>>2]=s;c[r+139284>>2]=s;s=e+6144|0;c[r+8216>>2]=s;c[r+73752>>2]=s;c[r+139288>>2]=s;s=e+7168|0;c[r+8220>>2]=s;c[r+73756>>2]=s;c[r+139292>>2]=s;s=c[2411380]|0;c[r+8224>>2]=s;c[r+73760>>2]=s;c[r+139296>>2]=s;e=s+1024|0;c[r+8228>>2]=e;c[r+73764>>2]=e;c[r+139300>>2]=e;e=s+2048|0;c[r+8232>>2]=e;c[r+73768>>2]=e;c[r+139304>>2]=e;e=s+3072|0;c[r+8236>>2]=e;c[r+73772>>2]=e;c[r+139308>>2]=e;e=c[2418210]|0;s=r+8240|0;r=2109440;while(1){t=e+(r-2109440)|0;c[s>>2]=t;c[s+65536>>2]=t;c[s+131072>>2]=t;t=r+1024|0;if(t>>>0>2129919){J=0;break}else{s=s+4|0;r=t}}}else{r=c[3541532]|0;s=(c[2112932]|0)+8192|0;e=2097152;while(1){t=r+(e-2097152)|0;c[s>>2]=t;c[s+65536>>2]=t;c[s+131072>>2]=t;t=e+1024|0;if(t>>>0>2129919){J=1;break}else{s=s+4|0;e=t}}}c[2438130]=J;J=c[3532592]|0;if((J|0)!=0){gGC(J|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;J=c[2440566]|0;c[2440566]=-1;e=c[2439330]|0;s=(e|0)==0;if(!s){r=e;gGC(9706056,r|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];r=c[3528484]|0;c[2076596]=r;t=c[2417276]|0;c[3541536]=t;c[1836236]=0;h=J&15;J=c[3532626]|0;j=(h<<14)-32768|0;k=128;l=128;while(1){c[e+76+(l<<2)>>2]=J+(j+(l<<8));f=k+1&65535;if((f&65535)>191){K=128;L=128;break}else{k=f;l=f&65535}}while(1){l=J+(j+(L<<8))|0;c[e+76+(L+512<<2)>>2]=l;c[e+76+(L+768<<2)>>2]=l;l=K+1&65535;if((l&65535)>191){break}else{K=l;L=l&65535}}c[2440566]=h;if(!s){s=e;gGC(s|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=r;c[2417276]=t;c[1836236]=-1;i=g;return 0}function fuI(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4817476+(b*112|0)>>2];c[a+104>>2]=c[4817480+(b*112|0)>>2];c[a+108>>2]=c[4817484+(b*112|0)>>2];d=0;return d|0}function fuJ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=4817376+(b*112|0);e=0;return e|0}function fuK(a,b){a=a|0;b=b|0;var d=0,e=0;if((b|0)==0){if((a|0)==0){d=0;return d|0}e=a;c[e>>2]=c[181242];c[e+4>>2]=c[181243];c[e+8>>2]=c[181244];d=0;return d|0}e=b-1|0;if(e>>>0>133){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;a=3112008+(e*12|0)|0;c[b>>2]=c[a>>2];c[b+4>>2]=c[a+4>>2];c[b+8>>2]=c[a+8>>2];d=0;return d|0}function fuL(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4821172+(b*112|0)>>2];c[a+104>>2]=c[4821176+(b*112|0)>>2];c[a+108>>2]=c[4821180+(b*112|0)>>2];d=0;return d|0}function fuM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=4821072+(b*112|0);e=0;return e|0}function fuN(a,b){a=a|0;b=b|0;var d=0,e=0;if((b|0)==0){if((a|0)==0){d=0;return d|0}e=a;c[e>>2]=c[181250];c[e+4>>2]=c[181251];c[e+8>>2]=c[181252];d=0;return d|0}e=b-1|0;if(e>>>0>133){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;a=3112008+(e*12|0)|0;c[b>>2]=c[a>>2];c[b+4>>2]=c[a+4>>2];c[b+8>>2]=c[a+8>>2];d=0;return d|0}function fuO(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4819940+(b*112|0)>>2];c[a+104>>2]=c[4819944+(b*112|0)>>2];c[a+108>>2]=c[4819948+(b*112|0)>>2];d=0;return d|0}function fuP(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=4819840+(b*112|0);e=0;return e|0}function fuQ(a,b){a=a|0;b=b|0;var d=0,e=0;if((b|0)==0){if((a|0)==0){d=0;return d|0}e=a;c[e>>2]=c[174956];c[e+4>>2]=c[174957];c[e+8>>2]=c[174958];d=0;return d|0}e=b-1|0;if(e>>>0>133){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;a=3112008+(e*12|0)|0;c[b>>2]=c[a>>2];c[b+4>>2]=c[a+4>>2];c[b+8>>2]=c[a+8>>2];d=0;return d|0}function fuR(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4818708+(b*112|0)>>2];c[a+104>>2]=c[4818712+(b*112|0)>>2];c[a+108>>2]=c[4818716+(b*112|0)>>2];d=0;return d|0}function fuS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=4818608+(b*112|0);e=0;return e|0}function fuT(a,b){a=a|0;b=b|0;var d=0,e=0;if((b|0)==0){if((a|0)==0){d=0;return d|0}e=a;c[e>>2]=c[181246];c[e+4>>2]=c[181247];c[e+8>>2]=c[181248];d=0;return d|0}e=b-1|0;if(e>>>0>133){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;a=3112008+(e*12|0)|0;c[b>>2]=c[a>>2];c[b+4>>2]=c[a+4>>2];c[b+8>>2]=c[a+8>>2];d=0;return d|0}function fuU(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3110876+(b*112|0)>>2];c[a+104>>2]=c[3110880+(b*112|0)>>2];c[a+108>>2]=c[3110884+(b*112|0)>>2];d=0;return d|0}function fuV(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=3110776+(b*112|0);e=0;return e|0}function fuW(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3109644+(b*112|0)>>2];c[a+104>>2]=c[3109648+(b*112|0)>>2];c[a+108>>2]=c[3109652+(b*112|0)>>2];d=0;return d|0}function fuX(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=3109544+(b*112|0);e=0;return e|0}function fuY(a,b){a=a|0;b=b|0;var d=0,e=0;if((b|0)==0){if((a|0)==0){d=0;return d|0}e=a;c[e>>2]=c[174952];c[e+4>>2]=c[174953];c[e+8>>2]=c[174954];d=0;return d|0}e=b-1|0;if(e>>>0>133){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;a=3112008+(e*12|0)|0;c[b>>2]=c[a>>2];c[b+4>>2]=c[a+4>>2];c[b+8>>2]=c[a+8>>2];d=0;return d|0}function fuZ(){var b=0,d=0,e=0,f=0,g=0;b=a[9542496]|0;if((b&30)>>>0<26){a[(c[2418096]|0)+1|0]=b&31}if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];b=c[3532592]|0;if((b|0)!=0){gGC(9104152,b|0,280)|0}c[2113054]=c[2113060]}a[9775600]=0;c[2113050]=0;c[2276080]=0;if((c[2438130]|0)!=1){b=c[3541532]|0;d=(c[2112932]|0)+8192|0;e=2097152;while(1){f=b+(e-2097152)|0;c[d>>2]=f;c[d+65536>>2]=f;c[d+131072>>2]=f;f=e+1024|0;if(f>>>0>2129919){break}else{d=d+4|0;e=f}}c[2438130]=1}RI();e=c[2394]|0;d=c[14130368+(e<<2)>>2]|0;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[8452240+(e<<2)>>2]=c[2113054];c[2394]=-1;e=c[2439330]|0;d=(e|0)==0;if(!d){b=e;gGC(9706056,b|0,76)|0}b=c[2438118]|0;c[2433530]=b;f=c[3528484]|0;c[2076596]=f;g=c[2417276]|0;c[3541536]=g;c[1836236]=0;gGz(9706056,0,76);if(!d){d=e;gGC(d|0,9706056,76)|0}c[2438118]=b;c[3528484]=f;c[2417276]=g;c[1836236]=-1;c[2113156]=0;a[9628264]=0;c[2407033]=0;g=c[3541206]|0;c[3541190]=g;c[3541198]=g;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=g+256;c[3541199]=g+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=g+512;c[3541200]=g+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=g+768;c[3541201]=g+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2113157]=0;a[9628420]=0;c[2407072]=0;f=g+1048576|0;c[3541194]=f;c[3541202]=f;gGz(c[2430122]|0,0,16384);c[2407080]=4;c[3541195]=g+1048832;c[3541203]=g+1114112;gGz(c[2430123]|0,0,16384);c[2407088]=4;c[3541196]=g+1049088;c[3541204]=g+1179648;gGz(c[2430124]|0,0,16384);c[2407096]=4;c[3541197]=g+1049344;c[3541205]=g+1245184;gGz(c[2430125]|0,0,16384);c[2407104]=4;mx(0);return}function fu_(b){b=b|0;var e=0,f=0,g=0;switch(b&255|0){case 136:{e=a[9625389]|0;return e|0};case 0:{e=a[9625384]|0;return e|0};case 8:{e=a[9625385]|0;return e|0};case 32:{e=a[9625386]|0;return e|0};case 128:{b=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;if((b|0)<(c[2113018]|0)){f=b>>>31<<7&255}else{f=-128}e=f|a[9625388];return e|0};case 40:{e=a[9625387]|0;return e|0};case 168:{f=c[3540984]|0;b=(d[f+5887|0]|0|128)&(d[f+5886|0]|0);if((a[f+5884|0]&2)==0){g=b&255}else{g=(a[(c[f+5828>>2]|0)+100|0]&1|b)&255}e=g|6;return e|0};default:{e=0;return e|0}}return 0}function fu$(b,e){b=b|0;e=e|0;var f=0;f=b&255;if((f|0)==168){a[(c[3540984]|0)+5885|0]=e;return}else if((f|0)==169){f=c[3540984]|0;b=c[f+5876>>2]|0;if((b|0)!=0){gg[b&4095](c[f+5880>>2]|0,0)}lH(f,d[f+5885|0]|0,e&255);return}else{return}}function fu0(a){a=a|0;var b=0;if(!((a|0)==4194305|(a|0)==4980737)){b=0;return b|0}a=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;if((a|0)>=(c[2113018]|0)){b=1;return b|0}b=a>>>31&255;return b|0}function fu1(a){a=a|0;var d=0,e=0;if((a|0)==4980742){d=b[(c[3541522]|0)+((c[3541526]&63)<<1)>>1]|0;return d|0}else if((a|0)==4718596){d=b[(c[3542214]|0)+((c[3542216]&32767)<<1)>>1]|0;return d|0}else if((a|0)==4980740){d=b[(c[3541524]|0)+((c[3541526]&1023)<<1)>>1]|0;return d|0}else if((a|0)==4718608|(a|0)==4718609|(a|0)==4718610|(a|0)==4718611|(a|0)==4718612|(a|0)==4718613|(a|0)==4718614|(a|0)==4718615|(a|0)==4718616|(a|0)==4718617|(a|0)==4718618|(a|0)==4718619|(a|0)==4718620|(a|0)==4718621|(a|0)==4718622|(a|0)==4718623){d=b[14168832+((a>>>1&7)<<1)>>1]|0;return d|0}else if((a|0)==4980738){d=c[3541526]&1023;return d|0}else if((a|0)==4718594){d=(c[3542216]|0)>>>1&16383;return d|0}else if((a|0)==4194304|(a|0)==4980736){e=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;if((e|0)>=(c[2113018]|0)){d=1;return d|0}d=e>>>31&65535;return d|0}else if((a|0)==4718598){d=b[(c[3542214]|0)+((c[3542216]&32767)+1<<1)>>1]|0;return d|0}else{d=0;return d|0}return 0}function fu2(d,e){d=d|0;e=e|0;var f=0;if((d|0)==4980742){f=c[3541526]|0;b[(c[3541522]|0)+((f&63)<<1)>>1]=e&255;c[3541526]=f+1;return}else if((d|0)==4194307){a[9722024]=e<<24>>24!=0|0;return}else{return}}function fu3(d,e){d=d|0;e=e|0;var f=0;if((d|0)==786432){c[2113314]=e&65535;return}else if((d|0)==786434){c[2113312]=e&65535;return}else if((d|0)==4980740){f=c[3541526]|0;b[(c[3541524]|0)+((f&1023)<<1)>>1]=e;c[3541526]=f+1;return}else if((d|0)==4718596){f=c[3542216]|0;b[(c[3542214]|0)+((f&32767)<<1)>>1]=e;c[3542216]=f+1;return}else if((d|0)==4194306){a[9722024]=(e&255)!=0|0;return}else if((d|0)==4718598){f=c[3542216]|0;b[(c[3542214]|0)+((f&32767)<<1)>>1]=e;c[3542216]=f+1;return}else if((d|0)==4980738){c[3541526]=e&1023;return}else if((d|0)==4718608|(d|0)==4718609|(d|0)==4718610|(d|0)==4718611|(d|0)==4718612|(d|0)==4718613|(d|0)==4718614|(d|0)==4718615|(d|0)==4718616|(d|0)==4718617|(d|0)==4718618|(d|0)==4718619|(d|0)==4718620|(d|0)==4718621|(d|0)==4718622|(d|0)==4718623){b[14168832+((d>>>1&7)<<1)>>1]=e;return}else if((d|0)==4980742){f=c[3541526]|0;b[(c[3541522]|0)+((f&63)<<1)>>1]=e;c[3541526]=f+1;return}else if((d|0)==4718594){c[3542216]=(e&65535)<<1&32766;return}else{return}}function fu4(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2062684+(b*112|0)>>2];c[a+104>>2]=c[2062688+(b*112|0)>>2];c[a+108>>2]=c[2062692+(b*112|0)>>2];d=0;return d|0}function fu5(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=2062584+(b*112|0);e=0;return e|0}function fu6(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=991840+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function fu7(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>48){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=2064264+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fu8(){var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;d=i;i=i+120|0;e=d|0;f=d+112|0;a[7461832]=1;c[2424]=6e3;c[2113316]=524288;c[2113212]=524288;c[2426626]=0;c[2418094]=0;c[3532626]=524288;c[3542212]=557056;c[3541520]=1081344;c[2405564]=1605632;c[2418208]=1605632;c[2411378]=1638400;c[2406882]=1642496;c[3532636]=1646592;c[3542214]=1679360;c[3541524]=1744896;c[3541522]=1746944;c[2411466]=1747072;c[3531916]=1747072;c[3531914]=1751168;g=0;while(1){if((g|0)>=1024){break}j=9638528+(g<<2)|0;if((c[j>>2]|0)==0){k=69906;break}else{g=g+1|0}}do{if((k|0)==69906){g=gGq(1755264)|0;c[j>>2]=g;if((g|0)==0){break}c[2426626]=g;gGz(g|0,0,1755264);c[2418094]=g;c[3532626]=g+524288;c[3542212]=g+557056;l=(c[2113316]|0)+557056|0;c[3541520]=g+l;m=l+(c[2113212]|0)|0;l=g+m|0;c[2405564]=l;c[2418208]=l;c[2411378]=g+(m+32768);c[2406882]=g+(m+36864);c[3532636]=g+(m+40960);c[3542214]=g+(m+73728);c[3541524]=g+(m+139264);c[3541522]=g+(m+141312);l=g+(m+141440)|0;c[2411466]=l;c[3531916]=l;c[3531914]=g+(m+145536);c[2414006]=g+(m+149632);fpk(g,2)|0;g=(c[2418094]|0)+262145|0;R6(g,2,2)|0;g=(c[2418094]|0)+262144|0;R6(g,3,2)|0;fni(c[3542212]|0,4,c[2113316]|0);fni(c[3541520]|0,8,c[2113212]|0);g=c[3532626]|0;do{if((c[3542200]|0)!=0){m=e+108|0;c[m>>2]=0;l=e+100|0;c[l>>2]=0;n=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[n&16383](e,12)|0;if((c[m>>2]|0)==0){break}m=c[l>>2]|0;c[f>>2]=9534384;l=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[l&16383](f,12,0)|0;if((m|0)<1){break}gzL(g,0,12)|0}}while(0);fxU(0,425984);if((c[2394]|0)==0){o=c[2112932]|0}else{c[2394]=0;g=c[3532596]|0;c[2112932]=g;m=c[3532592]|0;if((m|0)!=0){gGC(9104152,m|0,280)|0}c[2113054]=c[2113060];o=g}g=c[2418094]|0;m=o|0;l=0;while(1){n=g+l|0;c[m>>2]=n;c[m+131072>>2]=n;n=l+1024|0;if(n>>>0>65535){break}else{m=m+4|0;l=n}}l=o+1024|0;m=262144;while(1){n=g+m|0;c[l>>2]=n;c[l+131072>>2]=n;n=m+1024|0;if(n>>>0>524287){break}else{l=l+4|0;m=n}}m=c[2418208]|0;l=o+2048|0;g=524288;while(1){n=m+(g-524288)|0;c[l>>2]=n;c[l+65536>>2]=n;c[l+131072>>2]=n;n=g+1024|0;if(n>>>0>557055){break}else{l=l+4|0;g=n}}g=c[2411378]|0;c[o+16448>>2]=g;c[o+81984>>2]=g;c[o+147520>>2]=g;l=g+1024|0;c[o+16452>>2]=l;c[o+81988>>2]=l;c[o+147524>>2]=l;l=c[2406882]|0;c[o+16480>>2]=l;c[o+82016>>2]=l;c[o+147552>>2]=l;g=l+1024|0;c[o+16484>>2]=g;c[o+82020>>2]=g;c[o+147556>>2]=g;c[o+196688>>2]=708;c[o+196608>>2]=356;c[o+196728>>2]=2238;c[o+196648>>2]=1548;c[o+17408>>2]=1;c[o+82944>>2]=1;c[o+148480>>2]=1;c[o+17412>>2]=1;c[o+82948>>2]=1;c[o+148484>>2]=1;c[o+17416>>2]=1;c[o+82952>>2]=1;c[o+148488>>2]=1;c[o+17420>>2]=1;c[o+82956>>2]=1;c[o+148492>>2]=1;c[o+196612>>2]=594;c[o+196692>>2]=2082;c[o+196652>>2]=1774;c[o+196732>>2]=1304;g=c[3532592]|0;if((g|0)!=0){gGC(g|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fpA();fwR(0);g=c[2439330]|0;l=(g|0)==0;if(!l){m=g;gGC(9706056,m|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];m=c[3528484]|0;c[2076596]=m;n=c[2417276]|0;c[3541536]=n;c[1836236]=0;c[g+4172>>2]=3454;c[g+4176>>2]=1782;p=c[3532626]|0;q=0;r=0;while(1){c[g+76+(r<<2)>>2]=p+(r<<8);s=q+1&65535;if((s&65535)>127){t=0;u=0;break}else{q=s;r=s&65535}}while(1){r=p+(u<<8)|0;c[g+76+(u+512<<2)>>2]=r;c[g+76+(u+768<<2)>>2]=r;r=t+1&65535;if((r&65535)>127){break}else{t=r;u=r&65535}}p=c[3532636]|0;r=128;q=128;while(1){c[g+76+(q<<2)>>2]=p+((q<<8)-32768);s=r+1&65535;if((s&65535)>255){v=128;w=128;break}else{r=s;q=s&65535}}while(1){c[g+76+(w+256<<2)>>2]=p+((w<<8)-32768);q=v+1&65535;if((q&65535)>255){x=128;y=128;break}else{v=q;w=q&65535}}while(1){q=p+((y<<8)-32768)|0;c[g+76+(y+512<<2)>>2]=q;c[g+76+(y+768<<2)>>2]=q;q=x+1&65535;if((q&65535)>255){break}else{x=q;y=q&65535}}if(!l){p=g;gGC(p|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=m;c[2417276]=n;c[1836236]=-1;c[2113016]=1024;c[3531920]=c[2411378];c[3531918]=c[2406882];UL(35e5,1078,3456,0);c[2438224]=35e5;c[2433522]=3416;c[2406672]=1752;c[3528468]=9362;c[2443842]=584;h[745398]=1.0;a[3203264]=1;a[7072528]=1;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];p=c[3532592]|0;if((p|0)!=0){gGC(9104152,p|0,280)|0}c[2113054]=c[2113060]}RI();p=c[2394]|0;q=c[14130368+(p<<2)>>2]|0;if((q|0)!=0){gGC(q|0,9104152,280)|0}c[8452240+(p<<2)>>2]=c[2113054];c[2394]=-1;p=c[2439330]|0;q=(p|0)==0;if(!q){r=p;gGC(9706056,r|0,76)|0}r=c[2438118]|0;c[2433530]=r;s=c[3528484]|0;c[2076596]=s;z=c[2417276]|0;c[3541536]=z;c[1836236]=0;gGz(9706056,0,76);if(!q){q=p;gGC(q|0,9706056,76)|0}c[2438118]=r;c[3528484]=s;c[2417276]=z;c[1836236]=-1;c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;lw(c[3540984]|0);a[9722024]=0;A=0;i=d;return A|0}}while(0);c[2426626]=0;A=1;i=d;return A|0}function fu9(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=a[7452584]|0;if(b){d=0;e=b&1;while(1){b=14163936+(d<<2)|0;f=c[b>>2]|0;g=c[2113006]|0;if((g|0)==0){h=69954}else{i=g-1|0;c[2113006]=i;if((i|0)==0){h=69954}}if((h|0)==69954){h=0;c[2383474]=0}if((f|0)==0){j=e}else{gGr(f);j=a[7452584]&1}c[b>>2]=0;b=d+1|0;if((b|0)<(j|0)){d=b;e=j}else{break}}}a[7452584]=0;c[2438224]=0;c[2433522]=0;c[2406672]=0;c[3528468]=0;j=c[2406688]|0;if((j|0)!=0){gGr(j);c[2406688]=0}c[2432972]=0;fpB();fwZ();if((c[2392]|0)>=0){j=0;do{e=14130368+(j<<2)|0;d=c[e>>2]|0;if((d|0)!=0){gGr(d);c[e>>2]=0}e=14130384+(j<<2)|0;d=c[e>>2]|0;if((d|0)!=0){gGr(d);c[e>>2]=0}j=j+1|0;}while((j|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;j=c[2426626]|0;e=0;while(1){if((e|0)>=1024){h=69972;break}k=9638528+(e<<2)|0;if((c[k>>2]|0)==(j|0)){break}else{e=e+1|0}}if((h|0)==69972){c[2426626]=0;a[7461832]=0;return 0}gGr(j);c[k>>2]=0;c[2426626]=0;a[7461832]=0;return 0}function fva(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;if((a[9623440]|0)!=0){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=i;c[1836236]=-1;c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;lw(c[3540984]|0);a[9722024]=0}a[9625384]=0;a[9625385]=0;a[9625388]=0;i=0;g=0;f=0;e=0;do{g=((a[9632464+i|0]&1)<<i|g&255)&255;f=((a[9630376+i|0]&1)<<i|f&255)&255;e=((a[9551608+i|0]&1)<<i|e&255)&255;i=i+1|0;}while((i|0)<8);a[9625384]=g;a[9625385]=f;a[9625388]=e;if((g&3)==3){e=g&-4;a[9625384]=e;j=e}else{j=g}if((j&12)==12){a[9625384]=j&-13}if((f&3)==3){j=f&-4;a[9625385]=j;k=j}else{k=f}if((k&12)==12){a[9625385]=k&-13}if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];k=c[3532592]|0;if((k|0)!=0){gGC(9104152,k|0,280)|0}c[2113054]=c[2113060]}k=c[2439330]|0;if((k|0)!=0){f=k;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;f=c[2392]|0;if((f|0)>=0){gGz(8452240,0,((f|0)>0?(f<<2)+4|0:4)|0)}c[2113054]=0;f=c[2385548]|0;if((f|0)>0){gGz(9752472,0,((f|0)>1?f<<2:4)|0)}c[2113054]=c[2113220];c[2433530]=c[2113221];f=c[2438]|0;k=gGU(f,(f|0)<0|0?-1:0,1e7,0)|0;f=gGS(k,K,15360,0)|0;k=f;c[2113218]=k;c[2113216]=58333;c[2113058]=(k|0)/262|0;f=k-((k*22|0|0)/262|0)|0;c[2113018]=f;j=0;g=k;k=f;while(1){f=j+1|0;e=(ag(f,g)|0)/4|0;do{if((e|0)>(k|0)){i=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;if((i|0)<(k|0)){d=k-i|0;c[2113056]=d;i=RG(d)|0;c[2113054]=(c[2113054]|0)+i;c[2276108]=-1;c[2113056]=-1}i=c[2112968]|0;do{if((i|0)!=0){d=c[3531916]|0;l=c[2113308]|0;do{if((c[d>>2]|0)==0){gGz(i|0,0,l*76800|0|0)}else{if((l|0)==4){m=c[d+1152>>2]|0;n=0;o=i;while(1){c[o>>2]=m;c[o+4>>2]=m;c[o+8>>2]=m;c[o+12>>2]=m;c[o+16>>2]=m;c[o+20>>2]=m;c[o+24>>2]=m;c[o+28>>2]=m;p=n+1|0;if((p|0)<9600){n=p;o=o+32|0}else{break}}}else if((l|0)==3){o=c[d+1152>>2]|0;n=o>>>8&255;m=o>>>16&255;p=o&255;o=i;q=0;while(1){a[o]=p;a[o+1|0]=n;a[o+2|0]=m;r=q+1|0;if((r|0)<76800){o=o+3|0;q=r}else{break}}}else if((l|0)==2){q=c[d+1152>>2]|0;o=q<<16|q;q=i;m=0;while(1){c[q>>2]=o;c[q+4>>2]=o;c[q+8>>2]=o;c[q+12>>2]=o;c[q+16>>2]=o;c[q+20>>2]=o;c[q+24>>2]=o;c[q+28>>2]=o;n=m+1|0;if((n|0)<4800){q=q+32|0;m=n}else{break}}}else{break}}}while(0);if(a[7072528]|0){c[2112970]=i;c[2113306]=l;c[2113298]=c[2113300];fpz();s=c[3531916]|0}else{s=d}c[2112966]=s;m=c[2113016]|0;if((m|0)>0){t=0}else{break}do{c[s+(t<<2)>>2]=65535;t=t+1|0;}while((t|0)<(m|0));d=c[3531914]|0;l=0;do{c[d+(l<<2)>>2]=65535;l=l+1|0;}while((l|0)<(m|0))}}while(0);i=c[2430400]|0;m=c[3541524]|0;gGC(i|0,m|0,2048)|0;if((a[9722024]&1)==0){break}c[8452200+(c[2394]<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0>=1024){break}RH(4)}}while(0);m=e-(c[2113054]|0)-(c[2113056]|0)+(c[2276108]|0)|0;c[2113056]=m;i=RG(m)|0;c[2113054]=(c[2113054]|0)+i;c[2276108]=-1;c[2113056]=-1;UF(ag((c[2113216]|0)/4|0,j)|0)|0;if((f|0)>=4){break}j=f;g=c[2113218]|0;k=c[2113018]|0}k=c[2113216]|0;g=gGU(k,(k|0)<0|0?-1:0,2048e6,0)|0;j=c[2438224]|0;t=gGS(g,K,j,(j|0)<0|0?-1:0)|0;j=t;UF(k)|0;k=c[2443826]|0;if((k|0)<1073676288){c[2443826]=k-j}k=c[2443827]|0;if((k|0)<1073676288){c[2443827]=k-j}k=(c[3528508]|0)-j|0;c[3528508]=(k|0)<0?0:k;k=c[2112964]|0;if((k|0)!=0){gg[c[3542112]&4095](k,a[9688]|0?534:0)}k=c[2113054]|0;c[2113220]=(c[2113056]|0)+k-(c[2276108]|0)-(c[2113218]|0);j=c[2433530]|0;t=c[2076596]|0;c[2113221]=(c[2426530]|0)+j-t-(c[2113216]|0);g=c[1836236]|0;s=c[9757320+(g<<2)>>2]|0;if((s|0)!=0){i=s;gGC(i|0,9706056,76)|0}c[9752472+(g<<2)>>2]=j;c[14113936+(g<<2)>>2]=t;c[9669104+(g<<2)>>2]=c[3541536];c[1836236]=-1;g=c[2394]|0;t=c[14130368+(g<<2)>>2]|0;if((t|0)==0){u=8452240+(g<<2)|0;c[u>>2]=k;c[2394]=-1;return 0}gGC(t|0,9104152,280)|0;u=8452240+(g<<2)|0;c[u>>2]=k;c[2394]=-1;return 0}function fvb(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=c[3531916]|0;do{if((c[b>>2]|0)==0){d=c[2113308]|0;gGz(c[2112968]|0,0,d*76800|0|0);e=d}else{d=c[2113308]|0;if((d|0)==4){f=c[b+1152>>2]|0;g=0;h=c[2112968]|0;while(1){c[h>>2]=f;c[h+4>>2]=f;c[h+8>>2]=f;c[h+12>>2]=f;c[h+16>>2]=f;c[h+20>>2]=f;c[h+24>>2]=f;c[h+28>>2]=f;i=g+1|0;if((i|0)<9600){g=i;h=h+32|0}else{e=4;break}}}else if((d|0)==2){h=c[b+1152>>2]|0;g=h<<16|h;h=c[2112968]|0;f=0;while(1){c[h>>2]=g;c[h+4>>2]=g;c[h+8>>2]=g;c[h+12>>2]=g;c[h+16>>2]=g;c[h+20>>2]=g;c[h+24>>2]=g;c[h+28>>2]=g;i=f+1|0;if((i|0)<4800){h=h+32|0;f=i}else{e=2;break}}}else if((d|0)==3){f=c[b+1152>>2]|0;h=f>>>8&255;g=f>>>16&255;i=f&255;f=c[2112968]|0;j=0;while(1){a[f]=i;a[f+1|0]=h;a[f+2|0]=g;k=j+1|0;if((k|0)<76800){f=f+3|0;j=k}else{e=3;break}}}else{e=d;break}}}while(0);if(a[7072528]|0){c[2112970]=c[2112968];c[2113306]=e;c[2113298]=c[2113300];fpz();l=c[3531916]|0}else{l=b}c[2112966]=l;b=c[2113016]|0;if((b|0)>0){m=0}else{return 0}do{c[l+(m<<2)>>2]=65535;m=m+1|0;}while((m|0)<(b|0));m=c[3531914]|0;l=0;do{c[m+(l<<2)>>2]=65535;l=l+1|0;}while((l|0)<(b|0));return 0}function fvc(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=i;i=i+96|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;l=e+80|0;if((d|0)!=0){c[d>>2]=168962}if((b&96|0)==0){i=e;return 0}gGz(l|0,0,12);m=c[2405564]|0;c[l>>2]=m;c[l+4>>2]=(c[2411466]|0)-m;c[l+12>>2]=219592;gj[c[2076592]&4095](l)|0;l=h|0;do{if((b&64|0)!=0){gGz(g|0,0,16);c[2394]=-1;if((c[2392]|0)<0){break}m=h+9|0;n=f;o=f|0;p=f+4|0;q=f+12|0;r=g|0;s=g+4|0;t=g+12|0;u=0;do{gGC(l|0,614896,11)|0;a[m]=u+48&255;v=8452256+(u<<2)|0;gGz(n|0,0,12);c[o>>2]=v;c[p>>2]=4;c[q>>2]=164976;gj[c[2076592]&4095](f)|0;if((c[v>>2]|0)!=0){c[r>>2]=c[14130368+(u<<2)>>2];c[s>>2]=c[8452184+(u<<2)>>2];c[t>>2]=l;v=c[2076592]|0;gj[v&4095](g)|0}u=u+1|0;}while((u|0)<=(c[2392]|0))}}while(0);fw$(b);UQ(b,d);gGz(k|0,0,12);c[k>>2]=9625384;c[k+4>>2]=6;c[k+12>>2]=215728;gj[c[2076592]&4095](k)|0;gGz(j|0,0,12);c[j>>2]=8452880;c[j+4>>2]=8;c[j+12>>2]=212472;gj[c[2076592]&4095](j)|0;i=e;return 0}function fvd(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2060460+(b*112|0)>>2];c[a+104>>2]=c[2060464+(b*112|0)>>2];c[a+108>>2]=c[2060468+(b*112|0)>>2];d=0;return d|0}function fve(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=2060360+(b*112|0);e=0;return e|0}function fvf(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>44){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=2062040+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function fvg(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6422148+(b*112|0)>>2];c[a+104>>2]=c[6422152+(b*112|0)>>2];c[a+108>>2]=c[6422156+(b*112|0)>>2];d=0;return d|0}function fvh(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=6422048+(b*112|0);e=0;return e|0}function fvi(a,b){a=a|0;b=b|0;var d=0;if((b|0)!=0){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;c[b>>2]=c[907804];c[b+4>>2]=c[907805];c[b+8>>2]=c[907806];c[b+12>>2]=c[907807];d=0;return d|0}function fvj(){return 1}function fvk(){return 0}function fvl(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6960620+(b*112|0)>>2];c[a+104>>2]=c[6960624+(b*112|0)>>2];c[a+108>>2]=c[6960628+(b*112|0)>>2];d=0;return d|0}function fvm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=6960520+(b*112|0);e=0;return e|0}function fvn(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5454316+(b*112|0)>>2];c[a+104>>2]=c[5454320+(b*112|0)>>2];c[a+108>>2]=c[5454324+(b*112|0)>>2];d=0;return d|0}function fvo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=5454216+(b*112|0);e=0;return e|0}function fvp(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[816500+(b*112|0)>>2];c[a+104>>2]=c[816504+(b*112|0)>>2];c[a+108>>2]=c[816508+(b*112|0)>>2];d=0;return d|0}function fvq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=816400+(b*112|0);e=0;return e|0}function fvr(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7205652+(b*112|0)>>2];c[a+104>>2]=c[7205656+(b*112|0)>>2];c[a+108>>2]=c[7205660+(b*112|0)>>2];d=0;return d|0}function fvs(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=7205552+(b*112|0);e=0;return e|0}function fvt(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3858076+(b*112|0)>>2];c[a+104>>2]=c[3858080+(b*112|0)>>2];c[a+108>>2]=c[3858084+(b*112|0)>>2];d=0;return d|0}function fvu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=3857976+(b*112|0);e=0;return e|0}function fvv(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3853764+(b*112|0)>>2];c[a+104>>2]=c[3853768+(b*112|0)>>2];c[a+108>>2]=c[3853772+(b*112|0)>>2];d=0;return d|0}function fvw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=3853664+(b*112|0);e=0;return e|0}function fvx(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>5){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3766084+(b*112|0)>>2];c[a+104>>2]=c[3766088+(b*112|0)>>2];c[a+108>>2]=c[3766092+(b*112|0)>>2];d=0;return d|0}function fvy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<6&(d|0)==0)){e=1;return e|0}c[a>>2]=3765984+(b*112|0);e=0;return e|0}function fvz(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6854716+(b*112|0)>>2];c[a+104>>2]=c[6854720+(b*112|0)>>2];c[a+108>>2]=c[6854724+(b*112|0)>>2];d=0;return d|0}function fvA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=6854616+(b*112|0);e=0;return e|0}function fvB(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5144468+(b*112|0)>>2];c[a+104>>2]=c[5144472+(b*112|0)>>2];c[a+108>>2]=c[5144476+(b*112|0)>>2];d=0;return d|0}function fvC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=5144368+(b*112|0);e=0;return e|0}function fvD(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6033340+(b*112|0)>>2];c[a+104>>2]=c[6033344+(b*112|0)>>2];c[a+108>>2]=c[6033348+(b*112|0)>>2];d=0;return d|0}function fvE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=6033240+(b*112|0);e=0;return e|0}function fvF(d,e,f){d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;g=i;i=i+120|0;h=g|0;j=g+112|0;k=0;while(1){if((k|0)>=1024){l=0;break}m=9638528+(k<<2)|0;if((c[m>>2]|0)==0){n=76;break}else{k=k+1|0}}do{if((n|0)==76){k=gGq(f)|0;c[m>>2]=k;if((k|0)==0){l=0;break}gGz(k|0,0,f|0);l=k}}while(0);m=d;if((c[3542200]|0)==0){o=1;i=g;return o|0}d=h+108|0;c[d>>2]=0;k=h+100|0;c[k>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](h,e)|0;do{if((c[d>>2]|0)==0){p=0;q=0}else{h=c[k>>2]|0;c[j>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](j,e,0)|0;if((h|0)<1){o=1;i=g;return o|0}if((gzL(l,0,e)|0)==0){p=0;q=0;break}else{o=1}i=g;return o|0}}while(0);while(1){e=q&65535;L97:do{if((a[l+e|0]|0)==58){do{if((a[l+(e+1)|0]|0)==49){if((a[l+(e+2)|0]|0)!=48){s=p;t=q;break}j=q+9&65535;k=0;d=p;while(1){h=k+j|0;r=a[l+h|0]|0;u=r-48&255;v=((u&255)<10?u:r)&-33;r=(v-65&255)<26?v-55&255:v;v=a[l+(h+1)|0]|0;u=v-48&255;w=((u&255)<10?u:v)&-33;v=(w-65&255)<26?w-55&255:w;do{if(((v|r)&255)<16){w=a[l+(h+2)|0]|0;u=w-48&255;x=((u&255)<10?u:w)&-33;w=(x-65&255)<26?x-55&255:x;x=a[l+(h+3)|0]|0;u=x-48&255;y=((u&255)<10?u:x)&-33;x=(y-65&255)<26?y-55&255:y;if(((x|w)&255)>=16){z=d;break}b[m+((d&65535)<<1)>>1]=(r&255)<<4|v&255|(w&255)<<12|(x&255)<<8;z=d+1&65535}else{z=d}}while(0);v=k+4|0;if((v|0)<32){k=v;d=z}else{break}}d=q+41&65535;if((a[l+(d&65535)|0]|0)==58){s=z;t=d}else{A=d;B=z;break L97}}else{s=p;t=q}}while(0);d=t&65535;if((a[l+(d+1)|0]|0)!=48){A=t;B=s;break}if((a[l+(d+2)|0]|0)!=50){A=t;B=s;break}if((a[l+(d+3)|0]|0)!=49){A=t;B=s;break}d=t+9&65535;k=a[l+d|0]|0;j=k-48&255;v=((j&255)<10?j:k)&-33;k=a[l+(d+1)|0]|0;j=k-48&255;r=((j&255)<10?j:k)&-33;k=a[l+(d+3)|0]|0;d=k-48&255;j=(d&255)<10?d:k;b[4887388]=(((v-65&255)<26?v-55&255:v)&255)<<4|((r-65&255)<26?r-55&255:r)&255|((((j&-33)-65&255)<26?j+9&255:j)&255)<<8&3840;A=32767;B=s}else{A=q;B=p}}while(0);e=A+1&65535;if((e&65535|0)<(f|0)){p=B;q=e}else{C=0;break}}while(1){if((C|0)>=1024){o=0;n=103;break}D=9638528+(C<<2)|0;if((c[D>>2]|0)==(l|0)){break}else{C=C+1|0}}if((n|0)==103){i=g;return o|0}gGr(l);c[D>>2]=0;o=0;i=g;return o|0}function fvG(){gu[c[(c[2443776]|0)+56>>2]&16383]();return}function fvH(){var a=0;a=c[2113166]|0;if((a|0)<=0){c[2113164]=0;return}gGz(9731400,0,((a|0)>1?a<<2:4)|0);c[2113164]=0;return}function fvI(){var a=0,b=0,d=0,e=0;c[2113166]=(c[2113166]|0)+1;c[3528556]=-1;a=0;while(1){if((a|0)>=1024){b=0;break}d=9638528+(a<<2)|0;if((c[d>>2]|0)==0){e=114;break}else{a=a+1|0}}do{if((e|0)==114){a=gGq(3184)|0;c[d>>2]=a;if((a|0)==0){b=0;break}gGz(a|0,0,3184);b=a}}while(0);d=b;c[2433594]=d;c[2443776]=d;gGz(b|0,0,3184);c[b+52>>2]=2600;c[b+56>>2]=6212;e=b+60|0;c[e>>2]=8364;c[b+64>>2]=2644;c[b+3140>>2]=556;c[b+3144>>2]=1522;c[b+3148>>2]=596;c[b+3152>>2]=1224;c[b+3156>>2]=1890;c[b+3160>>2]=2274;c[b+3164>>2]=120;c[b+3168>>2]=2998;c[2432850]=0;b=0;do{c[d+68+(b<<2)>>2]=0;b=b+1|0;}while((b|0)<768);c[2113164]=0;gu[c[e>>2]&16383]();e=c[2427044]|0;c[9681616+(e<<3)>>2]=809496;c[9681620+(e<<3)>>2]=0;c[2427044]=e+1;return}function fvJ(a){a=a|0;return 0}function fvK(a,b){a=a|0;b=b|0;return}function fvL(a){a=a|0;return 0}function fvM(a,b){a=a|0;b=b|0;return}function fvN(a){a=a|0;return 0}function fvO(a,b){a=a|0;b=b|0;return}function fvP(a){a=a|0;return 0}function fvQ(a){a=a|0;return 0}function fvR(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[2433594]|0;if((a|0)!=0){b=a|0;a=0;while(1){if((a|0)>=1024){break}d=9638528+(a<<2)|0;if((c[d>>2]|0)==(b|0)){e=131;break}else{a=a+1|0}}if((e|0)==131){gGr(b);c[d>>2]=0}c[2433594]=0}d=c[2433595]|0;if((d|0)!=0){b=d|0;d=0;while(1){if((d|0)>=1024){break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==(b|0)){e=137;break}else{d=d+1|0}}if((e|0)==137){gGr(b);c[f>>2]=0}c[2433595]=0}f=c[2433596]|0;if((f|0)!=0){b=f|0;f=0;while(1){if((f|0)>=1024){break}g=9638528+(f<<2)|0;if((c[g>>2]|0)==(b|0)){e=143;break}else{f=f+1|0}}if((e|0)==143){gGr(b);c[g>>2]=0}c[2433596]=0}g=c[2433597]|0;if((g|0)!=0){b=g|0;g=0;while(1){if((g|0)>=1024){break}h=9638528+(g<<2)|0;if((c[h>>2]|0)==(b|0)){e=149;break}else{g=g+1|0}}if((e|0)==149){gGr(b);c[h>>2]=0}c[2433597]=0}h=c[2433598]|0;if((h|0)!=0){b=h|0;h=0;while(1){if((h|0)>=1024){break}i=9638528+(h<<2)|0;if((c[i>>2]|0)==(b|0)){e=155;break}else{h=h+1|0}}if((e|0)==155){gGr(b);c[i>>2]=0}c[2433598]=0}i=c[2433599]|0;if((i|0)!=0){b=i|0;i=0;while(1){if((i|0)>=1024){break}j=9638528+(i<<2)|0;if((c[j>>2]|0)==(b|0)){e=161;break}else{i=i+1|0}}if((e|0)==161){gGr(b);c[j>>2]=0}c[2433599]=0}j=c[2433600]|0;if((j|0)!=0){b=j|0;j=0;while(1){if((j|0)>=1024){break}k=9638528+(j<<2)|0;if((c[k>>2]|0)==(b|0)){e=167;break}else{j=j+1|0}}if((e|0)==167){gGr(b);c[k>>2]=0}c[2433600]=0}k=c[2433601]|0;if((k|0)==0){c[2113166]=0;return}b=k|0;k=0;while(1){if((k|0)>=1024){break}l=9638528+(k<<2)|0;if((c[l>>2]|0)==(b|0)){e=173;break}else{k=k+1|0}}if((e|0)==173){gGr(b);c[l>>2]=0}c[2433601]=0;c[2113166]=0;return}function fvS(b){b=b|0;var d=0,e=0;c[3528556]=b;d=c[9734376+(b<<2)>>2]|0;c[2443776]=d;L221:do{if((d|0)!=0){e=d|0;gGC(9660952,e|0,52)|0;switch(a[9660952]|0){case 1:{c[2309668]=634096;break L221;break};case 0:{c[2309668]=638960;break L221;break};case 5:{c[2309668]=7354992;break L221;break};case 2:{c[2309668]=638960;break L221;break};case 3:{c[2309668]=639984;break L221;break};case 4:{c[2309668]=7356016;break L221;break};default:{break L221}}}}while(0);c[2113164]=c[9731400+(b<<2)>>2];return}function fvT(){var a=0,b=0;a=c[2443776]|0;if((a|0)!=0){b=a|0;gGC(b|0,9660952,52)|0}c[9731400+(c[3528556]<<2)>>2]=c[2113164];c[2443776]=0;c[3528556]=-1;return}function fvU(){return c[3528556]|0}function fvV(a){a=a|0;var b=0;b=gj[c[(c[2443776]|0)+52>>2]&4095](a)|0;c[2113164]=(c[2113164]|0)+b;return b|0}function fvW(){return}function fvX(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=b>>>8&255;f=c[2443776]|0;g=c[f+68+(e<<2)>>2]|0;h=c[f+68+((e|256)<<2)>>2]|0;i=c[f+68+((e|512)<<2)>>2]|0;if((g|0)!=0){a[g+(b&255)|0]=d}if((h|0)!=0){a[h+(b&255)|0]=d}if((i|0)!=0){a[i+(b&255)|0]=d}i=c[f+3152>>2]|0;if((i|0)==0){return}gg[i&4095](b&65535,d);return}function fvY(b){b=b|0;var d=0,e=0,f=0;d=c[2443776]|0;e=c[d+68+((b>>>8&255)<<2)>>2]|0;if((e|0)!=0){f=a[e+(b&255)|0]|0;return f|0}e=c[d+3148>>2]|0;if((e|0)==0){f=0;return f|0}f=gj[e&4095](b&65535)|0;return f|0}function fvZ(){return c[2113164]|0}function fv_(b,d){b=b|0;d=d|0;var e=0,f=0;e=c[2443666]&b;b=e>>>((c[3528996]|0)>>>0);f=c[9702704+(b<<2)>>2]|0;if((f|0)!=0){a[f+(c[2385780]&e)|0]=d}f=c[9703728+(b<<2)>>2]|0;if((f|0)!=0){a[f+(c[2385780]&e)|0]=d}f=c[9704752+(b<<2)>>2]|0;if((f|0)!=0){a[f+(c[2385780]&e)|0]=d}f=c[3528586]|0;if((f|0)==0){return}gg[f&4095](e&65535,d);return}function fv$(){return 0}function fv0(a){a=a|0;return}function fv1(){return}function fv2(b){b=b|0;var d=0,e=0;d=b&65535&c[2443666];b=c[9702704+(d>>>((c[3528996]|0)>>>0)<<2)>>2]|0;if((b|0)!=0){e=a[b+(c[2385780]&d)|0]|0;return e|0}b=c[2385590]|0;if((b|0)==0){e=0;return e|0}e=gj[b&4095](d&65535)|0;return e|0}function fv3(){return 0}function fv4(b){b=b|0;var d=0,e=0,f=0;d=b&2147483647;e=c[(c[2406724]|0)+(d>>>12<<2)>>2]|0;if((e|0)!=0){f=a[e+(b&4095)|0]|0;return f|0}b=c[2432806]|0;if((b|0)==0){f=0;return f|0}f=gj[b&4095](d)|0;return f|0}function fv5(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;e=b&2147483647;f=e>>>12;g=c[(c[2406722]|0)+(f<<2)>>2]|0;if((g|0)!=0){a[g+(b&4095)|0]=d}g=c[(c[2406724]|0)+(f<<2)>>2]|0;if((g|0)!=0){a[g+(b&4095)|0]=d}b=c[2430392]|0;if((b|0)==0){return}gg[b&4095](e,d);return}function fv6(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=b&2097151;f=e>>>11;g=c[2388530]|0;h=c[g+16+(f<<2)>>2]|0;if((h|0)!=0){a[h+(b&2047)|0]=d}h=c[g+8208+(f<<2)>>2]|0;if((h|0)!=0){a[h+(b&2047)|0]=d}h=c[g+4112+(f<<2)>>2]|0;if((h|0)!=0){a[h+(b&2047)|0]=d}b=c[g+4>>2]|0;if((b|0)==0){return}gg[b&4095](e,d);return}function fv7(b){b=b|0;var d=0,e=0,f=0,g=0;d=b&2097151;e=c[2388530]|0;f=c[e+16+(d>>>11<<2)>>2]|0;if((f|0)!=0){g=a[f+(b&2047)|0]|0;return g|0}b=c[e>>2]|0;if((b|0)==0){g=0;return g|0}g=gj[b&4095](d)|0;return g|0}function fv8(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;c[2388530]=9554128;b=0;while(1){if((b|0)>=1024){d=0;break}e=9638528+(b<<2)|0;if((c[e>>2]|0)==0){f=275;break}else{b=b+1|0}}do{if((f|0)==275){b=gGq(68)|0;c[e>>2]=b;if((b|0)==0){d=0;break}gGz(b|0,0,68);d=b}}while(0);e=c[2388530]|0;c[e+12304>>2]=d;if(a[9520]|0){g=0}else{a[9520]=1;g=0}while(1){c[e+16+(g<<2)>>2]=0;d=g+1|0;if((d|0)<1024){g=d}else{h=0;break}}while(1){c[e+4112+(h<<2)>>2]=0;g=h+1|0;if((g|0)<1024){h=g}else{i=0;break}}do{c[e+8208+(i<<2)>>2]=0;i=i+1|0;}while((i|0)<1024);c[e+4>>2]=0;c[e>>2]=0;c[e+8>>2]=0;e=c[2427044]|0;c[9681616+(e<<3)>>2]=809624;c[9681620+(e<<3)>>2]=0;c[2427044]=e+1;return}function fv9(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;c[2388530]=9554128;c[2388533]=0;c[2388532]=0;c[2388534]=0;b=c[2391608]|0;if((b|0)!=0){d=b;b=0;while(1){if((b|0)>=1024){e=9554128;break}f=9638528+(b<<2)|0;if((c[f>>2]|0)==(d|0)){g=287;break}else{b=b+1|0}}if((g|0)==287){gGr(d);c[f>>2]=0;e=c[2388530]|0}c[e+12304>>2]=0}c[2388530]=9566436;c[2391610]=0;c[2391609]=0;c[2391611]=0;e=c[2394685]|0;if((e|0)==0){a[9520]=0;return}f=e;e=0;while(1){if((e|0)>=1024){h=9566436;break}i=9638528+(e<<2)|0;if((c[i>>2]|0)==(f|0)){g=293;break}else{e=e+1|0}}if((g|0)==293){gGr(f);c[i>>2]=0;h=c[2388530]|0}c[h+12304>>2]=0;a[9520]=0;return}function fwa(a){a=a|0;var b=0,d=0;b=(a|0)%2|0;c[2388530]=9554128+(b*12308|0);d=c[9566432+(b*12308|0)>>2]|0;if((d|0)==0){c[2382]=a;return}b=d;gGC(9661040,b|0,68)|0;c[2382]=a;return}function fwb(){var a=0,b=0;a=c[(c[2388530]|0)+12304>>2]|0;if((a|0)==0){c[2382]=-1;return}b=a;gGC(b|0,9661040,68)|0;c[2382]=-1;return}function fwc(){return c[2382]|0}function fwd(){c[(c[2391608]|0)+60>>2]=0;c[(c[2391608]|0)+60>>2]=0;return}function fwe(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a[9660900]=a[9660900]|16;e=c[2437644]|0;f=c[e+1092>>2]|0;do{if((f|0)==0){g=c[e+3144>>2]|0;if((g|0)==0){h=0;i=0;break}j=gj[g&4095](-2)|0;g=c[2437644]|0;k=c[g+1092>>2]|0;l=(j&255)<<8;if((k|0)!=0){m=k;n=l;o=314;break}k=c[g+3144>>2]|0;if((k|0)==0){h=0;i=l;break}h=gj[k&4095](-1)|0;i=l}else{m=f;n=(d[f+254|0]|0)<<8;o=314}}while(0);if((o|0)==314){h=a[m+255|0]|0;i=n}n=h&255|i;c[2415221]=n;b[4830442]=n&65535;a[9660920]=0;a[9660921]=0;a[9660928]=0;a[9660930]=0;a[9660931]=0;c[2415234]=0;gGz(9660901,0,5);c[2415235]=65535;c[2415237]=65535;a[9660932]=a[9660932]|64;return}function fwf(){c[2113162]=0;return}function fwg(a){a=a|0;return}function fwh(){return}function fwi(){return 0}function fwj(a){a=a|0;var b=0,d=0;b=gGq(3180)|0;d=b;c[2437644]=d;if((b|0)==0){return}gGz(b|0,0,3180);c[b+3144>>2]=3190;c[b+3148>>2]=1308;c[b+3152>>2]=428;c[b+3156>>2]=1374;c[b+3160>>2]=234;c[b+3164>>2]=8;c[2432848]=0;b=0;do{c[d+72+(b<<2)>>2]=0;b=b+1|0;}while((b|0)<768);c[2113162]=0;if((a|0)==3){c[2415228]=7344984;c[2415229]=7066624;b=c[2427044]|0;c[9681616+(b<<3)>>2]=809384;c[9681620+(b<<3)>>2]=0;c[2427044]=b+1;return}else if((a|0)==2){c[2415228]=6569376;c[2415229]=6595512;b=c[2427044]|0;c[9681616+(b<<3)>>2]=704144;c[9681620+(b<<3)>>2]=0;c[2427044]=b+1;return}else if((a|0)==4){c[2415228]=7344984;c[2415229]=7066624;b=c[2427044]|0;c[9681616+(b<<3)>>2]=809384;c[9681620+(b<<3)>>2]=0;c[2427044]=b+1;return}else if((a|0)==1){c[2415228]=7346008;c[2415229]=7066880;a=c[2427044]|0;c[9681616+(a<<3)>>2]=809440;c[9681620+(a<<3)>>2]=0;c[2427044]=a+1;return}else{return}}function fwk(a){a=a|0;return 0}function fwl(a,b){a=a|0;b=b|0;return}function fwm(a){a=a|0;return 0}function fwn(a){a=a|0;return 0}function fwo(a){a=a|0;return 0}function fwp(a,b){a=a|0;b=b|0;return}function fwq(a){a=a|0;var b=0;b=f02(a)|0;c[2113162]=(c[2113162]|0)+b;return b|0}function fwr(a){a=a|0;var b=0;b=f4D(a)|0;c[2113162]=(c[2113162]|0)+b;return b|0}function fws(a){a=a|0;var b=0;b=f4c(a)|0;c[2113162]=(c[2113162]|0)+b;return b|0}function fwt(){return}function fwu(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=b>>>8&255;f=c[2437644]|0;g=c[f+72+(e<<2)>>2]|0;h=c[f+72+((e|256)<<2)>>2]|0;i=c[f+72+((e|512)<<2)>>2]|0;if((g|0)!=0){a[g+(b&255)|0]=d}if((h|0)!=0){a[h+(b&255)|0]=d}if((i|0)!=0){a[i+(b&255)|0]=d}i=c[f+3148>>2]|0;if((i|0)==0){return}gg[i&4095](b&65535,d);return}function fwv(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;b=i;i=i+528|0;d=b|0;e=b+16|0;f=b+32|0;g=b+48|0;h=b+64|0;j=b+80|0;k=b+96|0;l=b+112|0;m=b+128|0;n=b+144|0;o=b+160|0;p=b+176|0;q=b+192|0;r=b+208|0;s=b+224|0;t=b+240|0;u=b+256|0;v=b+272|0;w=b+288|0;x=b+304|0;y=b+320|0;z=b+336|0;A=b+352|0;B=b+368|0;C=b+384|0;D=b+400|0;E=b+416|0;F=b+432|0;G=b+448|0;H=b+464|0;I=b+480|0;J=b+496|0;K=b+512|0;if((a&64|0)==0){i=b;return}a=c[2437644]|0;gGz(K|0,0,12);c[K>>2]=a;c[K+4>>2]=4;c[K+12>>2]=165408;gj[c[2076592]&4095](K)|0;gGz(J|0,0,12);c[J>>2]=a+4;c[J+4>>2]=4;c[J+12>>2]=501664;gj[c[2076592]&4095](J)|0;gGz(I|0,0,12);c[I>>2]=a+8;c[I+4>>2]=4;c[I+12>>2]=386136;gj[c[2076592]&4095](I)|0;gGz(H|0,0,12);c[H>>2]=a+12;c[H+4>>2]=4;c[H+12>>2]=300552;gj[c[2076592]&4095](H)|0;gGz(G|0,0,12);c[G>>2]=a+16;c[G+4>>2]=4;c[G+12>>2]=229192;gj[c[2076592]&4095](G)|0;gGz(F|0,0,12);c[F>>2]=a+20;c[F+4>>2]=1;c[F+12>>2]=178664;gj[c[2076592]&4095](F)|0;gGz(E|0,0,12);c[E>>2]=a+21;c[E+4>>2]=1;c[E+12>>2]=143760;gj[c[2076592]&4095](E)|0;gGz(D|0,0,12);c[D>>2]=a+22;c[D+4>>2]=1;c[D+12>>2]=115400;gj[c[2076592]&4095](D)|0;gGz(C|0,0,12);c[C>>2]=a+23;c[C+4>>2]=2;c[C+12>>2]=90440;gj[c[2076592]&4095](C)|0;gGz(B|0,0,12);c[B>>2]=a+25;c[B+4>>2]=1;c[B+12>>2]=70472;gj[c[2076592]&4095](B)|0;gGz(A|0,0,12);c[A>>2]=a+28;c[A+4>>2]=4;c[A+12>>2]=578480;gj[c[2076592]&4095](A)|0;gGz(z|0,0,12);c[z>>2]=a+40;c[z+4>>2]=1;c[z+12>>2]=562104;gj[c[2076592]&4095](z)|0;gGz(y|0,0,12);c[y>>2]=a+41;c[y+4>>2]=1;c[y+12>>2]=545920;gj[c[2076592]&4095](y)|0;gGz(x|0,0,12);c[x>>2]=a+42;c[x+4>>2]=1;c[x+12>>2]=532232;gj[c[2076592]&4095](x)|0;gGz(w|0,0,12);c[w>>2]=a+43;c[w+4>>2]=1;c[w+12>>2]=518616;gj[c[2076592]&4095](w)|0;gGz(v|0,0,12);c[v>>2]=a+44;c[v+4>>2]=1;c[v+12>>2]=505440;gj[c[2076592]&4095](v)|0;gGz(u|0,0,12);c[u>>2]=a+45;c[u+4>>2]=1;c[u+12>>2]=493344;gj[c[2076592]&4095](u)|0;gGz(t|0,0,12);c[t>>2]=a+46;c[t+4>>2]=1;c[t+12>>2]=481200;gj[c[2076592]&4095](t)|0;gGz(s|0,0,12);c[s>>2]=a+47;c[s+4>>2]=1;c[s+12>>2]=468688;gj[c[2076592]&4095](s)|0;gGz(r|0,0,12);c[r>>2]=a+48;c[r+4>>2]=1;c[r+12>>2]=457488;gj[c[2076592]&4095](r)|0;gGz(q|0,0,12);c[q>>2]=a+49;c[q+4>>2]=1;c[q+12>>2]=447232;gj[c[2076592]&4095](q)|0;gGz(p|0,0,12);c[p>>2]=a+50;c[p+4>>2]=1;c[p+12>>2]=435216;gj[c[2076592]&4095](p)|0;gGz(o|0,0,12);c[o>>2]=a+51;c[o+4>>2]=1;c[o+12>>2]=424832;gj[c[2076592]&4095](o)|0;gGz(n|0,0,12);c[n>>2]=a+52;c[n+4>>2]=1;c[n+12>>2]=412040;gj[c[2076592]&4095](n)|0;gGz(m|0,0,12);c[m>>2]=a+56;c[m+4>>2]=4;c[m+12>>2]=401448;gj[c[2076592]&4095](m)|0;gGz(l|0,0,12);c[l>>2]=a+60;c[l+4>>2]=4;c[l+12>>2]=389496;gj[c[2076592]&4095](l)|0;gGz(k|0,0,12);c[k>>2]=a+64;c[k+4>>2]=2;c[k+12>>2]=379280;gj[c[2076592]&4095](k)|0;gGz(j|0,0,12);c[j>>2]=a+68;c[j+4>>2]=4;c[j+12>>2]=368744;gj[c[2076592]&4095](j)|0;j=(c[2437644]|0)+3168|0;gGz(h|0,0,12);c[h>>2]=j;c[h+4>>2]=4;c[h+12>>2]=360304;gj[c[2076592]&4095](h)|0;h=(c[2437644]|0)+3172|0;gGz(g|0,0,12);c[g>>2]=h;c[g+4>>2]=4;c[g+12>>2]=352864;gj[c[2076592]&4095](g)|0;g=(c[2437644]|0)+3176|0;gGz(f|0,0,12);c[f>>2]=g;c[f+4>>2]=4;c[f+12>>2]=345016;gj[c[2076592]&4095](f)|0;gGz(e|0,0,12);c[e>>2]=9731392;c[e+4>>2]=4;c[e+12>>2]=337080;gj[c[2076592]&4095](e)|0;gGz(d|0,0,12);c[d>>2]=8452648;c[d+4>>2]=4;c[d+12>>2]=329408;gj[c[2076592]&4095](d)|0;i=b;return}function fww(b){b=b|0;var d=0,e=0,f=0;d=c[2437644]|0;e=c[d+72+((b>>>8&255)<<2)>>2]|0;if((e|0)!=0){f=a[e+(b&255)|0]|0;return f|0}e=c[d+3144>>2]|0;if((e|0)==0){f=0;return f|0}f=gj[e&4095](b&65535)|0;return f|0}function fwx(){return c[2113162]|0}function fwy(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;a[9660796]=0;a[9660797]=0;a[9660786]=0;a[9660787]=0;c[2415191]=0;a[9660784]=a[9660784]|80;e=c[3528554]|0;f=c[2433592]|0;g=c[f+(e*3148|0)+1068>>2]|0;do{if((g|0)==0){h=c[f+(e*3148|0)+3120>>2]|0;if((h|0)==0){i=0;j=0;break}k=gj[h&4095](-2)|0;h=c[3528554]|0;l=c[2433592]|0;m=c[l+(h*3148|0)+1068>>2]|0;n=(k&255)<<8;if((m|0)!=0){o=m;p=n;q=376;break}m=c[l+(h*3148|0)+3120>>2]|0;if((m|0)==0){i=0;j=n;break}i=gj[m&4095](-1)|0;j=n}else{o=g;p=(d[g+254|0]|0)<<8;q=376}}while(0);if((q|0)==376){i=a[o+255|0]|0;j=p}p=i&255|j;c[2415188]=p;b[4830376]=p&65535;return}function fwz(){var a=0;a=c[2113160]|0;if((a|0)<=0){c[2113158]=0;return}gGz(9731360,0,((a|0)>1?a<<2:4)|0);c[2113158]=0;return}function fwA(a){a=a|0;return 0}function fwB(a,b){a=a|0;b=b|0;return}function fwC(a){a=a|0;return 0}function fwD(a){a=a|0;return 0}function fwE(a){a=a|0;c[3528554]=a;f43((c[2433592]|0)+(a*3148|0)|0);c[2113158]=c[9731360+(c[3528554]<<2)>>2];return}function fwF(){var a=0,b=0,d=0;a=c[3528554]|0;b=(c[2433592]|0)+(a*3148|0)|0;if((b|0)!=0){d=b;gGC(d|0,9660752,48)|0}c[9731360+(a<<2)>>2]=c[2113158];c[3528554]=-1;return}function fwG(){return c[3528554]|0}function fwH(a){a=a|0;var b=0;b=f45(a)|0;c[2113158]=(c[2113158]|0)+b;return b|0}function fwI(){return}function fwJ(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=b>>>8&255;f=c[3528554]|0;g=c[2433592]|0;h=c[g+(f*3148|0)+48+(e<<2)>>2]|0;i=c[g+(f*3148|0)+48+((e|256)<<2)>>2]|0;j=c[g+(f*3148|0)+48+((e|512)<<2)>>2]|0;if((h|0)!=0){a[h+(b&255)|0]=d}if((i|0)!=0){a[i+(b&255)|0]=d}if((j|0)!=0){a[j+(b&255)|0]=d}j=c[g+(f*3148|0)+3124>>2]|0;if((j|0)==0){return}gg[j&4095](b&65535,d);return}function fwK(b){b=b|0;var d=0,e=0,f=0,g=0;d=c[3528554]|0;e=c[2433592]|0;f=c[e+(d*3148|0)+48+((b>>>8&255)<<2)>>2]|0;if((f|0)!=0){g=a[f+(b&255)|0]|0;return g|0}f=c[e+(d*3148|0)+3120>>2]|0;if((f|0)==0){g=0;return g|0}g=gj[f&4095](b&65535)|0;return g|0}function fwL(){return c[2113158]|0}function fwM(a){a=a|0;return 0}function fwN(a,b){a=a|0;b=b|0;return}function fwO(a){a=a|0;return 0}function fwP(a,b){a=a|0;b=b|0;return}function fwQ(){var a=0;a=c[2385548]|0;if((a|0)<=0){c[2433530]=0;return}gGz(9752472,0,((a|0)>1?a<<2:4)|0);c[2433530]=0;return}function fwR(d){d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;c[1836236]=-1;e=0;while(1){if((e|0)>=1024){f=0;break}g=9638528+(e<<2)|0;if((c[g>>2]|0)==0){h=428;break}else{e=e+1|0}}do{if((h|0)==428){e=gGq(4192)|0;c[g>>2]=e;if((e|0)==0){f=0;break}gGz(e|0,0,4192);f=e}}while(0);g=f;h=9757320+(d<<2)|0;c[h>>2]=g;gGz(f|0,0,4192);if((d|0)==0){c[2426884]=673824;c[2426882]=674592;c[2426880]=674336;c[2426878]=673568;c[2426876]=670224;c[2426874]=674080;if((c[2385740]|0)!=0&(c[2385738]|0)!=0){i=0}else{f=gGq(131072)|0;c[2385740]=f;e=gGq(131072)|0;c[2385738]=e;j=0;k=f;l=f+65536|0;f=e;m=e+65536|0;while(1){e=j&15;n=j^128;o=m+256|0;p=0;q=k;r=l;s=f;t=m;while(1){u=p-j|0;v=(p|0)!=0;w=p&128;x=p&40;y=((v?w:64)|x)&255;z=p&15;A=z>>>0<e>>>0;B=y|16;C=(p|0)<(j|0)|0;D=(A?B:y)|C;a[q]=((u^p)&128&(u^n)|0)==0?D:D|4;D=u-1|0;u=z>>>0>e>>>0;z=(p|0)>(j|0)|0;E=((u?y:B)|z)^1;a[r]=((D^p)&128&(D^n)|0)==0?E:E|4;E=j-p|0;D=((v?w|2:66)|x)&255;x=D|16;w=(u?x:D)|z;z=(p^j)&128;a[s]=(z&(E^j)|0)==0?w:w|4;w=(A?D:x)|C^1;a[t]=((E+255^j)&z|0)==0?w:w|4;w=p+1|0;if((w|0)<256){p=w;q=q+1|0;r=r+1|0;s=s+1|0;t=t+1|0}else{break}}t=j+1|0;if((t|0)<256){j=t;k=k+256|0;l=l+256|0;f=f+256|0;m=o}else{i=0;break}}}do{m=i&128;f=(i|0)!=0;l=i&40;k=(f?m:64)|l;j=k&255;a[9707544+i|0]=j;a[9644928+i|0]=((f?m:68)|l)&255;a[9706144+i|0]=(((i>>>5)+(i&1)+(i>>>6)+(i>>>3)+(i>>>4)+(i>>>1)+(i>>>2)+(m>>>7)<<2&4|k)^4)&255;k=(i|0)==128?j|4:j;m=i&15;a[9621712+i|0]=(m|0)==0?k|16:k;k=j|((i|0)==127?6:2);a[9621968+i|0]=(m|0)==15?k|16:k;i=i+1|0;}while((i|0)<256);gGz(9706056,0,76);b[4853044]=-1;b[4853042]=-1;a[9706068]=64;F=c[h>>2]|0}else{F=g}c[F+4172>>2]=338;c[F+4176>>2]=1436;c[F+4180>>2]=3516;c[F+4184>>2]=1280;a[F+4188|0]=0;if((F|0)!=0){g=F;gGC(g|0,9706056,76)|0}c[9752472+(d<<2)>>2]=0;c[14113936+(d<<2)>>2]=0;g=0;do{c[F+76+(g<<2)>>2]=0;g=g+1|0;}while((g|0)<1024);c[2433530]=0;c[2385548]=(d+1|0)%8|0;g=c[2427044]|0;c[9681616+(g<<3)>>2]=1172496;c[9681620+(g<<3)>>2]=d;c[2427044]=g+1;return}function fwS(b){b=b|0;var d=0,e=0,f=0,g=0;d=c[1836236]|0;if((d|0)<0){e=0;return e|0}f=b&65535;g=c[9757320+(d<<2)>>2]|0;d=c[g+76+(f>>>8<<2)>>2]|0;if((d|0)!=0){e=a[d+(f&255)|0]|0;return e|0}f=c[g+4180>>2]|0;if((f|0)==0){e=0;return e|0}e=gj[f&4095](b)|0;return e|0}function fwT(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;e=c[1836236]|0;if((e|0)<0){return}f=b&65535;g=c[9757320+(e<<2)>>2]|0;e=c[g+76+((f>>>8|256)<<2)>>2]|0;if((e|0)!=0){a[e+(f&255)|0]=d;return}f=c[g+4184>>2]|0;if((f|0)==0){return}gg[f&4095](b,d);return}function fwU(){var a=0,b=0,d=0;a=c[1836236]|0;b=c[9757320+(a<<2)>>2]|0;if((b|0)!=0){d=b;gGC(d|0,9706056,76)|0}c[9752472+(a<<2)>>2]=c[2433530];c[14113936+(a<<2)>>2]=c[2076596];c[9669104+(a<<2)>>2]=c[3541536];c[1836236]=-1;return}function fwV(a){a=a|0;var d=0,e=0;d=c[9757320+(a<<2)>>2]|0;if((d|0)!=0){e=d;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[9752472+(a<<2)>>2];c[2076596]=c[14113936+(a<<2)>>2];c[3541536]=c[9669104+(a<<2)>>2];c[1836236]=a;return}function fwW(){return c[1836236]|0}function fwX(b){b=b|0;var d=0,e=0;if((b|0)<1){d=0;return d|0}if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){e=gfc(b)|0;c[2433530]=(c[2433530]|0)+e;d=e;return d|0}else{c[2433530]=(c[2433530]|0)+b;d=b;return d|0}return 0}function fwY(){return}function fwZ(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[2385740]|0;if((a|0)!=0){gGr(a)}c[2385740]=0;a=c[2385738]|0;if((a|0)!=0){gGr(a)}c[2385738]=0;a=c[2439330]|0;if((a|0)!=0){b=a;a=0;while(1){if((a|0)>=1024){break}d=9638528+(a<<2)|0;if((c[d>>2]|0)==(b|0)){e=487;break}else{a=a+1|0}}if((e|0)==487){gGr(b);c[d>>2]=0}c[2439330]=0}d=c[2439331]|0;if((d|0)!=0){b=d;d=0;while(1){if((d|0)>=1024){break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==(b|0)){e=493;break}else{d=d+1|0}}if((e|0)==493){gGr(b);c[f>>2]=0}c[2439331]=0}f=c[2439332]|0;if((f|0)!=0){b=f;f=0;while(1){if((f|0)>=1024){break}g=9638528+(f<<2)|0;if((c[g>>2]|0)==(b|0)){e=499;break}else{f=f+1|0}}if((e|0)==499){gGr(b);c[g>>2]=0}c[2439332]=0}g=c[2439333]|0;if((g|0)!=0){b=g;g=0;while(1){if((g|0)>=1024){break}h=9638528+(g<<2)|0;if((c[h>>2]|0)==(b|0)){e=505;break}else{g=g+1|0}}if((e|0)==505){gGr(b);c[h>>2]=0}c[2439333]=0}h=c[2439334]|0;if((h|0)!=0){b=h;h=0;while(1){if((h|0)>=1024){break}i=9638528+(h<<2)|0;if((c[i>>2]|0)==(b|0)){e=511;break}else{h=h+1|0}}if((e|0)==511){gGr(b);c[i>>2]=0}c[2439334]=0}i=c[2439335]|0;if((i|0)!=0){b=i;i=0;while(1){if((i|0)>=1024){break}j=9638528+(i<<2)|0;if((c[j>>2]|0)==(b|0)){e=517;break}else{i=i+1|0}}if((e|0)==517){gGr(b);c[j>>2]=0}c[2439335]=0}j=c[2439336]|0;if((j|0)!=0){b=j;j=0;while(1){if((j|0)>=1024){break}k=9638528+(j<<2)|0;if((c[k>>2]|0)==(b|0)){e=523;break}else{j=j+1|0}}if((e|0)==523){gGr(b);c[k>>2]=0}c[2439336]=0}k=c[2439337]|0;if((k|0)==0){c[2385548]=0;return}b=k;k=0;while(1){if((k|0)>=1024){break}l=9638528+(k<<2)|0;if((c[l>>2]|0)==(b|0)){e=529;break}else{k=k+1|0}}if((e|0)==529){gGr(b);c[l>>2]=0}c[2439337]=0;c[2385548]=0;return}function fw_(){gGz(9706056|0,0|0,76|0);return}function fw$(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;d=i;i=i+88|0;e=d|0;f=d+16|0;g=d+32|0;h=d+48|0;j=d+64|0;k=d+80|0;if((b&64|0)==0){i=d;return}b=k|0;a[b]=a[614880]|0;a[b+1|0]=a[614881]|0;a[b+2|0]=a[614882]|0;a[b+3|0]=a[614883]|0;a[b+4|0]=a[614884]|0;a[b+5|0]=a[614885]|0;a[b+6|0]=a[614886]|0;if((c[2385548]|0)>0){l=k+5|0;k=j;m=j|0;n=j+4|0;o=j+12|0;p=h;q=h|0;r=h+4|0;s=h+12|0;t=g;u=g|0;v=g+4|0;w=g+12|0;x=f;y=f|0;z=f+4|0;A=f+12|0;B=0;do{a[l]=B+49&255;C=c[9757320+(B<<2)>>2]|0;gGz(k|0,0,12);c[m>>2]=C;c[n>>2]=76;c[o>>2]=b;gj[c[2076592]&4095](j)|0;gGz(p|0,0,12);c[q>>2]=9669104+(B<<2);c[r>>2]=4;c[s>>2]=165152;gj[c[2076592]&4095](h)|0;gGz(t|0,0,12);c[u>>2]=14113936+(B<<2);c[v>>2]=4;c[w>>2]=501560;gj[c[2076592]&4095](g)|0;gGz(x|0,0,12);c[y>>2]=9752472+(B<<2);c[z>>2]=4;c[A>>2]=386032;gj[c[2076592]&4095](f)|0;B=B+1|0;}while((B|0)<(c[2385548]|0))}gGz(e|0,0,12);c[e>>2]=9734120;c[e+4>>2]=4;c[e+12>>2]=300480;gj[c[2076592]&4095](e)|0;i=d;return}function fw0(a){a=a|0;c[2433530]=(c[2433530]|0)+a;return a|0}function fw1(){return(c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0}function fw2(b){b=b|0;var d=0,e=0,f=0;d=c[1836236]|0;if((d|0)<0){e=0;return e|0}f=c[9757320+(d<<2)>>2]|0;d=c[f+76+((b>>>8&255)<<2)>>2]|0;if((d|0)!=0){e=a[d+(b&255)|0]|0;return e|0}d=c[f+4180>>2]|0;if((d|0)==0){e=0;return e|0}e=gj[d&4095](b&65535)|0;return e|0}function fw3(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=c[1836236]|0;if((e|0)<0){return}f=b&65535;g=f>>>8;h=c[9757320+(e<<2)>>2]|0;e=c[h+76+((g|512)<<2)>>2]|0;if((e|0)!=0){a[e+f|0]=d}e=c[h+76+((g|768)<<2)>>2]|0;if((e|0)!=0){a[e+f|0]=d}f=c[h+76+((g|256)<<2)>>2]|0;if((f|0)!=0){a[f+(b&255)|0]=d;return}f=c[h+4184>>2]|0;if((f|0)==0){return}gg[f&4095](b&65535,d);return}function fw4(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=b&32767;f=e>>>8;g=c[2110940]|0;h=c[g+16+(f<<2)>>2]|0;if((h|0)!=0){a[h+(b&255)|0]=d}h=c[g+528+(f<<2)>>2]|0;if((h|0)!=0){a[h+(b&255)|0]=d}h=c[g+1040+(f<<2)>>2]|0;if((h|0)!=0){a[h+(b&255)|0]=d}b=c[g+4>>2]|0;if((b|0)==0){return}gg[b&4095](e&65535,d);return}function fw5(){return 0}function fw6(){return}function fw7(){return}function fw8(a){a=a|0;var b=0;c[2110940]=8443768+(((a|0)%4|0)*1552|0);c[2444]=a;b=9669136+(a*38|0)|0;gGC(9718136,b|0,38)|0;return}function fw9(){var a=0;a=9669136+((c[2444]|0)*38|0)|0;gGC(a|0,9718136,38)|0;c[2444]=-1;return}function fxa(){return c[2444]|0}function fxb(b){b=b|0;var d=0,e=0,f=0,g=0;d=b&32767;b=d&65535;e=c[2110940]|0;f=c[e+16+(b>>>8<<2)>>2]|0;if((f|0)!=0){g=a[f+(b&255)|0]|0;return g|0}b=c[e>>2]|0;if((b|0)==0){g=0;return g|0}g=gj[b&4095](d)|0;return g|0}function fxc(a){a=a|0;return 0}function fxd(a,b){a=a|0;b=b|0;return}function fxe(a){a=a|0;var b=0;b=((gj[c[(c[2112932]|0)+196608>>2]&4095](a)|0)&255)<<8;return(gj[c[(c[2112932]|0)+196608>>2]&4095](a+1|0)|0)&255|b|0}function fxf(a,b){a=a|0;b=b|0;gg[c[(c[2112932]|0)+196648>>2]&4095](a,(b&65535)>>>8&255);gg[c[(c[2112932]|0)+196648>>2]&4095](a+1|0,b&255);return}function fxg(a){a=a|0;var b=0;b=((gj[c[(c[2112932]|0)+196688>>2]&4095](a)|0)&65535)<<16;return(gj[c[(c[2112932]|0)+196688>>2]&4095](a+2|0)|0)&65535|b|0}function fxh(a,b){a=a|0;b=b|0;gg[c[(c[2112932]|0)+196728>>2]&4095](a,b>>>16&65535);gg[c[(c[2112932]|0)+196728>>2]&4095](a+2|0,b&65535);return}function fxi(a){a=a|0;var b=0;b=((gj[c[(c[2112932]|0)+196612>>2]&4095](a)|0)&255)<<8;return(gj[c[(c[2112932]|0)+196612>>2]&4095](a+1|0)|0)&255|b|0}function fxj(a,b){a=a|0;b=b|0;gg[c[(c[2112932]|0)+196652>>2]&4095](a,(b&65535)>>>8&255);gg[c[(c[2112932]|0)+196652>>2]&4095](a+1|0,b&255);return}function fxk(a){a=a|0;var b=0;b=((gj[c[(c[2112932]|0)+196692>>2]&4095](a)|0)&65535)<<16;return(gj[c[(c[2112932]|0)+196692>>2]&4095](a+2|0)|0)&65535|b|0}function fxl(a,b){a=a|0;b=b|0;gg[c[(c[2112932]|0)+196732>>2]&4095](a,b>>>16&65535);gg[c[(c[2112932]|0)+196732>>2]&4095](a+2|0,b&65535);return}function fxm(a){a=a|0;var b=0;b=((gj[c[(c[2112932]|0)+196616>>2]&4095](a)|0)&255)<<8;return(gj[c[(c[2112932]|0)+196616>>2]&4095](a+1|0)|0)&255|b|0}function fxn(a,b){a=a|0;b=b|0;gg[c[(c[2112932]|0)+196656>>2]&4095](a,(b&65535)>>>8&255);gg[c[(c[2112932]|0)+196656>>2]&4095](a+1|0,b&255);return}function fxo(a){a=a|0;var b=0;b=((gj[c[(c[2112932]|0)+196696>>2]&4095](a)|0)&65535)<<16;return(gj[c[(c[2112932]|0)+196696>>2]&4095](a+2|0)|0)&65535|b|0}function fxp(a,b){a=a|0;b=b|0;gg[c[(c[2112932]|0)+196736>>2]&4095](a,b>>>16&65535);gg[c[(c[2112932]|0)+196736>>2]&4095](a+2|0,b&65535);return}function fxq(a){a=a|0;var b=0;b=((gj[c[(c[2112932]|0)+196620>>2]&4095](a)|0)&255)<<8;return(gj[c[(c[2112932]|0)+196620>>2]&4095](a+1|0)|0)&255|b|0}function fxr(a,b){a=a|0;b=b|0;gg[c[(c[2112932]|0)+196660>>2]&4095](a,(b&65535)>>>8&255);gg[c[(c[2112932]|0)+196660>>2]&4095](a+1|0,b&255);return}function fxs(a){a=a|0;var b=0;b=((gj[c[(c[2112932]|0)+196700>>2]&4095](a)|0)&65535)<<16;return(gj[c[(c[2112932]|0)+196700>>2]&4095](a+2|0)|0)&65535|b|0}function fxt(a,b){a=a|0;b=b|0;gg[c[(c[2112932]|0)+196740>>2]&4095](a,b>>>16&65535);gg[c[(c[2112932]|0)+196740>>2]&4095](a+2|0,b&65535);return}function fxu(a){a=a|0;var b=0;b=((gj[c[(c[2112932]|0)+196624>>2]&4095](a)|0)&255)<<8;return(gj[c[(c[2112932]|0)+196624>>2]&4095](a+1|0)|0)&255|b|0}function fxv(a,b){a=a|0;b=b|0;gg[c[(c[2112932]|0)+196664>>2]&4095](a,(b&65535)>>>8&255);gg[c[(c[2112932]|0)+196664>>2]&4095](a+1|0,b&255);return}function fxw(a){a=a|0;var b=0;b=((gj[c[(c[2112932]|0)+196704>>2]&4095](a)|0)&65535)<<16;return(gj[c[(c[2112932]|0)+196704>>2]&4095](a+2|0)|0)&65535|b|0}function fxx(a,b){a=a|0;b=b|0;gg[c[(c[2112932]|0)+196744>>2]&4095](a,b>>>16&65535);gg[c[(c[2112932]|0)+196744>>2]&4095](a+2|0,b&65535);return}function fxy(a){a=a|0;var b=0;b=((gj[c[(c[2112932]|0)+196628>>2]&4095](a)|0)&255)<<8;return(gj[c[(c[2112932]|0)+196628>>2]&4095](a+1|0)|0)&255|b|0}function fxz(a,b){a=a|0;b=b|0;gg[c[(c[2112932]|0)+196668>>2]&4095](a,(b&65535)>>>8&255);gg[c[(c[2112932]|0)+196668>>2]&4095](a+1|0,b&255);return}function fxA(a){a=a|0;var b=0;b=((gj[c[(c[2112932]|0)+196708>>2]&4095](a)|0)&65535)<<16;return(gj[c[(c[2112932]|0)+196708>>2]&4095](a+2|0)|0)&65535|b|0}function fxB(a,b){a=a|0;b=b|0;gg[c[(c[2112932]|0)+196748>>2]&4095](a,b>>>16&65535);gg[c[(c[2112932]|0)+196748>>2]&4095](a+2|0,b&65535);return}function fxC(a){a=a|0;var b=0;b=((gj[c[(c[2112932]|0)+196632>>2]&4095](a)|0)&255)<<8;return(gj[c[(c[2112932]|0)+196632>>2]&4095](a+1|0)|0)&255|b|0}function fxD(a,b){a=a|0;b=b|0;gg[c[(c[2112932]|0)+196672>>2]&4095](a,(b&65535)>>>8&255);gg[c[(c[2112932]|0)+196672>>2]&4095](a+1|0,b&255);return}function fxE(a){a=a|0;var b=0;b=((gj[c[(c[2112932]|0)+196712>>2]&4095](a)|0)&65535)<<16;return(gj[c[(c[2112932]|0)+196712>>2]&4095](a+2|0)|0)&65535|b|0}function fxF(a,b){a=a|0;b=b|0;gg[c[(c[2112932]|0)+196752>>2]&4095](a,b>>>16&65535);gg[c[(c[2112932]|0)+196752>>2]&4095](a+2|0,b&65535);return}function fxG(a){a=a|0;var b=0;b=((gj[c[(c[2112932]|0)+196636>>2]&4095](a)|0)&255)<<8;return(gj[c[(c[2112932]|0)+196636>>2]&4095](a+1|0)|0)&255|b|0}function fxH(a,b){a=a|0;b=b|0;gg[c[(c[2112932]|0)+196676>>2]&4095](a,(b&65535)>>>8&255);gg[c[(c[2112932]|0)+196676>>2]&4095](a+1|0,b&255);return}function fxI(a){a=a|0;var b=0;b=((gj[c[(c[2112932]|0)+196716>>2]&4095](a)|0)&65535)<<16;return(gj[c[(c[2112932]|0)+196716>>2]&4095](a+2|0)|0)&65535|b|0}function fxJ(a,b){a=a|0;b=b|0;gg[c[(c[2112932]|0)+196756>>2]&4095](a,b>>>16&65535);gg[c[(c[2112932]|0)+196756>>2]&4095](a+2|0,b&65535);return}function fxK(a){a=a|0;var b=0;b=((gj[c[(c[2112932]|0)+196640>>2]&4095](a)|0)&255)<<8;return(gj[c[(c[2112932]|0)+196640>>2]&4095](a+1|0)|0)&255|b|0}function fxL(a,b){a=a|0;b=b|0;gg[c[(c[2112932]|0)+196680>>2]&4095](a,(b&65535)>>>8&255);gg[c[(c[2112932]|0)+196680>>2]&4095](a+1|0,b&255);return}function fxM(a){a=a|0;var b=0;b=((gj[c[(c[2112932]|0)+196720>>2]&4095](a)|0)&65535)<<16;return(gj[c[(c[2112932]|0)+196720>>2]&4095](a+2|0)|0)&65535|b|0}function fxN(a,b){a=a|0;b=b|0;gg[c[(c[2112932]|0)+196760>>2]&4095](a,b>>>16&65535);gg[c[(c[2112932]|0)+196760>>2]&4095](a+2|0,b&65535);return}function fxO(a){a=a|0;var b=0;b=((gj[c[(c[2112932]|0)+196644>>2]&4095](a)|0)&255)<<8;return(gj[c[(c[2112932]|0)+196644>>2]&4095](a+1|0)|0)&255|b|0}function fxP(a,b){a=a|0;b=b|0;gg[c[(c[2112932]|0)+196684>>2]&4095](a,(b&65535)>>>8&255);gg[c[(c[2112932]|0)+196684>>2]&4095](a+1|0,b&255);return}function fxQ(a){a=a|0;var b=0;b=((gj[c[(c[2112932]|0)+196724>>2]&4095](a)|0)&65535)<<16;return(gj[c[(c[2112932]|0)+196724>>2]&4095](a+2|0)|0)&65535|b|0}function fxR(a,b){a=a|0;b=b|0;gg[c[(c[2112932]|0)+196764>>2]&4095](a,b>>>16&65535);gg[c[(c[2112932]|0)+196764>>2]&4095](a+2|0,b&65535);return}function fxS(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;e=b&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){a[g+(b&1023^1)|0]=d;return}else{gg[c[f+196648+(g<<2)>>2]&4095](e,d);return}}function fxT(){var a=0;a=c[2392]|0;if((a|0)<0){c[2113054]=0;return}gGz(8452240,0,((a|0)>0?(a<<2)+4|0:4)|0);c[2113054]=0;return}function fxU(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=c[2394]|0;if((e|0)>-1){f=c[14130368+(e<<2)>>2]|0;if((f|0)!=0){gGC(f|0,9104152,280)|0}c[8452240+(e<<2)>>2]=c[2113054];c[2394]=-1}e=c[2392]|0;if((e|0)<(b|0)){c[2392]=b;g=b}else{g=e}e=gGq(196864)|0;c[14130384+(b<<2)>>2]=e;if((e|0)==0){if((g|0)>=0){g=0;do{f=14130368+(g<<2)|0;h=c[f>>2]|0;if((h|0)!=0){gGr(h);c[f>>2]=0}f=14130384+(g<<2)|0;h=c[f>>2]|0;if((h|0)!=0){gGr(h);c[f>>2]=0}g=g+1|0;}while((g|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;return}gGz(e|0,0,196864);c[e+196608>>2]=1156;c[e+196648>>2]=978;c[e+196612>>2]=1156;c[e+196652>>2]=978;c[e+196616>>2]=1156;c[e+196656>>2]=978;c[e+196620>>2]=1156;c[e+196660>>2]=978;c[e+196624>>2]=1156;c[e+196664>>2]=978;c[e+196628>>2]=1156;c[e+196668>>2]=978;c[e+196632>>2]=1156;c[e+196672>>2]=978;c[e+196636>>2]=1156;c[e+196676>>2]=978;c[e+196640>>2]=1156;c[e+196680>>2]=978;c[e+196644>>2]=1156;c[e+196684>>2]=978;c[e+196688>>2]=36;c[e+196728>>2]=974;c[e+196768>>2]=2656;c[e+196808>>2]=996;c[e+196692>>2]=2326;c[e+196732>>2]=2624;c[e+196772>>2]=1316;c[e+196812>>2]=2298;c[e+196696>>2]=2736;c[e+196736>>2]=692;c[e+196776>>2]=3572;c[e+196816>>2]=1340;c[e+196700>>2]=1404;c[e+196740>>2]=1918;c[e+196780>>2]=2530;c[e+196820>>2]=1998;c[e+196704>>2]=1946;c[e+196744>>2]=1810;c[e+196784>>2]=1758;c[e+196824>>2]=1524;c[e+196708>>2]=570;c[e+196748>>2]=2906;c[e+196788>>2]=3180;c[e+196828>>2]=1048;c[e+196712>>2]=1008;c[e+196752>>2]=1700;c[e+196792>>2]=1854;c[e+196832>>2]=1612;c[e+196716>>2]=3268;c[e+196756>>2]=604;c[e+196796>>2]=482;c[e+196836>>2]=2558;c[e+196720>>2]=1936;c[e+196760>>2]=658;c[e+196800>>2]=2520;c[e+196840>>2]=3204;c[e+196724>>2]=2180;c[e+196764>>2]=312;c[e+196804>>2]=1188;c[e+196844>>2]=898;if(!(a[43400]|0)){e=c[2276038]|0;if((e|0)==1){i=1}else{i=(e|0)==2|0}Rw(i);a[43400]=1}c[2276100]=518;c[2276101]=1202;c[2276102]=2420;c[2276103]=2516;c[2276104]=5330;c[2276105]=158;c[2276106]=1548;c[2276107]=12926;c[8452256+(b<<2)>>2]=d;if((d|0)==110018592){c[2276038]=8;c[2276085]=16777215;c[2276086]=63263;c[2276098]=9038616;c[2276099]=11672;c[2276089]=-2;c[2276090]=0;c[2276091]=0;c[2276092]=4;c[2276093]=0;c[2276094]=2;c[2276095]=2;c[2276096]=0;c[2276097]=518;Rw(0);j=669}else if((d|0)==425984){c[2276038]=1;c[2276085]=16777215;c[2276086]=42783;c[2276098]=8907544;c[2276099]=11160;c[2276089]=-2;c[2276090]=2;c[2276091]=-2;c[2276092]=2;c[2276093]=2;c[2276094]=2;c[2276095]=3;c[2276096]=1;c[2276097]=132;Rw(1);j=669}else if((d|0)==426e3){c[2276038]=4;c[2276085]=16777215;c[2276086]=42783;c[2276098]=8973080;c[2276099]=11416;c[2276089]=-4;c[2276090]=0;c[2276091]=0;c[2276092]=6;c[2276093]=0;c[2276094]=2;c[2276095]=3;c[2276096]=1;c[2276097]=130;Rw(0);j=669}do{if((j|0)==669){c[8452184+(b<<2)>>2]=280;d=gGq(280)|0;c[14130368+(b<<2)>>2]=d;if((d|0)==0){break}gGz(d|0,0,280);gGC(d|0,9104152,280)|0;c[8452240+(b<<2)>>2]=0;c[8452200+(b<<2)>>2]=0;c[2113054]=0;c[2113058]=0;d=c[2427044]|0;c[9681616+(d<<3)>>2]=1197424;c[9681620+(d<<3)>>2]=b;c[2427044]=d+1;return}}while(0);if((c[2392]|0)>=0){b=0;do{j=14130368+(b<<2)|0;d=c[j>>2]|0;if((d|0)!=0){gGr(d);c[j>>2]=0}j=14130384+(b<<2)|0;d=c[j>>2]|0;if((d|0)!=0){gGr(d);c[j>>2]=0}b=b+1|0;}while((b|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;return}function fxV(){var a=0,b=0;a=c[2394]|0;b=c[14130368+(a<<2)>>2]|0;if((b|0)!=0){gGC(b|0,9104152,280)|0}c[8452240+(a<<2)>>2]=c[2113054];c[2394]=-1;return}function fxW(){RI();return}function fxX(a){a=a|0;var b=0;if((c[2394]|0)==(a|0)){return}c[2394]=a;c[2112932]=c[14130384+(a<<2)>>2];b=c[14130368+(a<<2)>>2]|0;if((b|0)!=0){gGC(9104152,b|0,280)|0}c[2113054]=c[8452240+(a<<2)>>2];return}function fxY(){return c[2394]|0}function fxZ(){c[2226884]=(c[2226884]|0)-(c[2276108]|0);c[2276108]=0;return}function fx_(a){a=a|0;var b=0;c[2113056]=a;b=RG(a)|0;c[2113054]=(c[2113054]|0)+b;c[2276108]=-1;c[2113056]=-1;return b|0}function fx$(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=(c[2112932]|0)+(b>>>10<<2)|0;g=b&-1024;h=g>>>0>d>>>0;if((e|0)==5){if(h){return}else{i=f;j=g}while(1){k=a+(j-b)|0;c[i>>2]=k;c[i+131072>>2]=k;k=j+1024|0;if(k>>>0>d>>>0){break}else{i=i+4|0;j=k}}return}if(h){return}h=(e&2|0)==0;j=(e&4|0)==0;if((e&1|0)!=0){if(h){e=f;i=g;while(1){k=a+(i-b)|0;c[e>>2]=k;if(!j){c[e+131072>>2]=k}k=i+1024|0;if(k>>>0>d>>>0){break}else{e=e+4|0;i=k}}return}if(j){i=f;e=g;while(1){k=a+(e-b)|0;c[i>>2]=k;c[i+65536>>2]=k;k=e+1024|0;if(k>>>0>d>>>0){break}else{i=i+4|0;e=k}}return}else{e=f;i=g;while(1){k=a+(i-b)|0;c[e>>2]=k;c[e+65536>>2]=k;c[e+131072>>2]=k;k=i+1024|0;if(k>>>0>d>>>0){break}else{e=e+4|0;i=k}}return}}if(h){if(j){h=g;do{h=h+1024|0;}while(h>>>0<=d>>>0);return}else{h=f;i=g;while(1){c[h+131072>>2]=a+(i-b);e=i+1024|0;if(e>>>0>d>>>0){break}else{h=h+4|0;i=e}}return}}else{if(j){j=f;i=g;while(1){c[j+65536>>2]=a+(i-b);h=i+1024|0;if(h>>>0>d>>>0){break}else{j=j+4|0;i=h}}return}else{i=f;f=g;while(1){g=a+(f-b)|0;c[i+65536>>2]=g;c[i+131072>>2]=g;g=f+1024|0;if(g>>>0>d>>>0){break}else{i=i+4|0;f=g}}return}}}function fx0(b){b=b|0;var d=0,e=0,f=0,g=0;d=b&16777215;e=c[2112932]|0;f=c[e+(d>>>10<<2)>>2]|0;if(f>>>0>9){g=a[f+(b&1023^1)|0]|0;return g|0}else{g=gj[c[e+196608+(f<<2)>>2]&4095](d)|0;return g|0}return 0}function fx1(){return(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0}function fx2(a){a=a|0;return}function fx3(){return}function fx4(){return 0}function fx5(b){b=b|0;var d=0,e=0,f=0;d=b&67108863;e=c[(c[2406730]|0)+(d>>>12<<2)>>2]|0;if((e|0)!=0){f=a[e+(b&4095)|0]|0;return f|0}b=c[2432804]|0;if((b|0)==0){f=0;return f|0}f=gj[b&4095](d)|0;return f|0}function fx6(){var b=0,d=0,e=0,f=0;b=c[2426481]|0;d=(b&3|0)==2?0:1;a[9706036]=d;e=b+4|0;do{if((a[9706037]|0)==0){f=747}else{if((e&67108864|0)!=0){f=747;break}c[2426488]=e;c[2426481]=e&-268435456|201326621;a[9706037]=0}}while(0);do{if((f|0)==747){if(d<<24>>24==0){break}if((e&134217728|0)!=0){break}c[2426490]=e;c[2426481]=e&-201326592|134217754;a[9706036]=0}}while(0);fyL(0)|0;a[9706036]=0;e=(c[2426481]|0)+4|0;if((a[9706037]|0)==0){return}if((e&67108864|0)!=0){return}c[2426488]=e;c[2426481]=e&-268435456|201326621;a[9706037]=0;return}function fx7(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;e=b&67108863;f=e>>>12;g=c[(c[2406728]|0)+(f<<2)>>2]|0;if((g|0)!=0){a[g+(b&4095)|0]=d}g=c[(c[2406730]|0)+(f<<2)>>2]|0;if((g|0)!=0){a[g+(b&4095)|0]=d}b=c[2430390]|0;if((b|0)==0){return}gg[b&4095](e,d);return}function fx8(a){a=a|0;return 0}function fx9(b,d){b=b|0;d=d|0;var e=0,f=0;e=b>>>8&255;f=c[9699632+(e<<2)>>2]|0;if((f|0)!=0){a[f+(b&255)|0]=d}f=c[9701680+(e<<2)>>2]|0;if((f|0)!=0){a[f+(b&255)|0]=d}f=c[9700656+(e<<2)>>2]|0;if((f|0)!=0){a[f+(b&255)|0]=d}f=c[2444172]|0;if((f|0)==0){return}gg[f&4095](b&65535,d);return}function fya(){return}function fyb(a){a=a|0;c[363094]=a;return}function fyc(){c[363094]=-1;return}function fyd(){return c[363094]|0}function fye(b){b=b|0;var d=0,e=0;d=c[9699632+((b>>>8&255)<<2)>>2]|0;if((d|0)!=0){e=a[d+(b&255)|0]|0;return e|0}d=c[3528598]|0;if((d|0)==0){e=0;return e|0}e=gj[d&4095](b&65535)|0;return e|0}function fyf(){fC2();return}function fyg(){var a=0;a=c[2113196]|0;if((a|0)<=0){c[2113194]=0;return}gGz(9721800,0,((a|0)>1?a<<2:4)|0);c[2113194]=0;return}function fyh(a){a=a|0;return 0}function fyi(a,b){a=a|0;b=b|0;return}function fyj(a){a=a|0;return 0}function fyk(a){a=a|0;return 0}function fyl(d){d=d|0;var e=0;c[3528552]=d;e=(c[2433426]|0)+(d*3160|0)|0;if((e|0)!=0){d=e;gGC(9642704,d|0,60)|0}b[4821352]=c[2410676]&65535;fC1();d=(a[9642745]&1)==0;c[2430032]=d?1595912:1595656;c[2429672]=d?1114752:1114496;c[2429670]=d?1114240:1113984;c[2444186]=d?4654424:4654168;c[2113194]=c[9721800+(c[3528552]<<2)>>2];return}function fym(){var a=0,b=0,d=0;a=c[3528552]|0;b=(c[2433426]|0)+(a*3160|0)|0;if((b|0)!=0){d=b;gGC(d|0,9642704,60)|0}c[9721800+(a<<2)>>2]=c[2113194];c[3528552]=-1;return}function fyn(){return c[3528552]|0}function fyo(a){a=a|0;var b=0;b=fC4(a)|0;c[2113194]=(c[2113194]|0)+b;return b|0}function fyp(){return}function fyq(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;d=i;i=i+112|0;e=d|0;f=d+16|0;g=d+32|0;h=d+48|0;j=d+64|0;k=d+80|0;l=d+96|0;if((b&64|0)==0){i=d;return}if((c[2113196]|0)>0){b=l|0;m=l+7|0;l=k;n=k|0;o=k+4|0;p=k+12|0;q=j;r=j|0;s=j+4|0;t=j+12|0;u=h;v=h|0;w=h+4|0;x=h+12|0;y=g;z=g|0;A=g+4|0;B=g+12|0;C=f;D=f|0;E=f+4|0;F=f+12|0;G=0;do{gGC(b|0,619744,10)|0;a[m]=G+48&255;gGz(l|0,0,12);c[n>>2]=(c[2433426]|0)+(G*3160|0);c[o>>2]=60;c[p>>2]=b;gj[c[2076592]&4095](k)|0;H=(c[2433426]|0)+(G*3160|0)+3148|0;gGz(q|0,0,12);c[r>>2]=H;c[s>>2]=4;c[t>>2]=164672;gj[c[2076592]&4095](j)|0;H=(c[2433426]|0)+(G*3160|0)+3152|0;gGz(u|0,0,12);c[v>>2]=H;c[w>>2]=4;c[x>>2]=501392;gj[c[2076592]&4095](h)|0;H=(c[2433426]|0)+(G*3160|0)+3156|0;gGz(y|0,0,12);c[z>>2]=H;c[A>>2]=4;c[B>>2]=385832;gj[c[2076592]&4095](g)|0;gGz(C|0,0,12);c[D>>2]=9721800+(G<<2);c[E>>2]=4;c[F>>2]=300392;gj[c[2076592]&4095](f)|0;G=G+1|0;}while((G|0)<(c[2113196]|0))}gGz(e|0,0,12);c[e>>2]=8452776;c[e+4>>2]=4;c[e+12>>2]=228928;gj[c[2076592]&4095](e)|0;i=d;return}function fyr(b){b=b|0;var d=0,e=0,f=0,g=0;d=c[3528552]|0;e=c[2433426]|0;f=c[e+(d*3160|0)+60+((b>>>8&255)<<2)>>2]|0;if((f|0)!=0){g=a[f+(b&255)|0]|0;return g|0}f=c[e+(d*3160|0)+3132>>2]|0;if((f|0)==0){g=0;return g|0}g=gj[f&4095](b&65535)|0;return g|0}function fys(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=b>>>8&255;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+(e<<2)>>2]|0;i=c[g+(f*3160|0)+60+((e|256)<<2)>>2]|0;j=c[g+(f*3160|0)+60+((e|512)<<2)>>2]|0;if((h|0)!=0){a[h+(b&255)|0]=d}if((i|0)!=0){a[i+(b&255)|0]=d}if((j|0)!=0){a[j+(b&255)|0]=d}j=c[g+(f*3160|0)+3136>>2]|0;if((j|0)==0){return}gg[j&4095](b&65535,d);return}function fyt(){return c[2113194]|0}function fyu(a){a=a|0;return 0}function fyv(a,b){a=a|0;b=b|0;return}function fyw(a){a=a|0;return 0}function fyx(a,b){a=a|0;b=b|0;return}function fyy(b){b=b|0;var d=0,e=0,f=0;d=b&1048575;b=c[3531864]|0;e=c[b+44+(d>>>11<<2)>>2]|0;if((e|0)==0){f=gj[c[b+8236>>2]&4095](d)|0;return f|0}else{f=a[e+d|0]|0;return f|0}return 0}function fyz(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=0;while(1){if((f|0)>=1024){g=0;break}h=9638528+(f<<2)|0;if((c[h>>2]|0)==0){i=850;break}else{f=f+1|0}}do{if((i|0)==850){f=gGq(8252)|0;c[h>>2]=f;if((f|0)==0){g=0;break}gGz(f|0,0,8252);g=f}}while(0);h=g;c[9757496+(b<<2)>>2]=h;c[3531864]=h;gGz(g|0,0,8252);if((d|0)==16|(d|0)==8|(d|0)==0){h=0;while(1){if((h|0)==0){a[9761200]=1;h=1;continue}else{j=h;k=0}while(1){i=(j&1)+k|0;f=j>>>1;if((f|0)==0){break}else{j=f;k=i}}a[9761200+h|0]=(j+k&1^1)&255;i=h+1|0;if(i>>>0<256){h=i}else{l=0;break}}while(1){h=l>>>3&7;c[9652832+(l<<2)>>2]=c[614832+(h<<2)>>2];c[9654880+(l<<2)>>2]=c[614800+(h<<2)>>2];h=l+1|0;if(h>>>0<256){l=h}else{m=192;break}}do{l=m&7;c[9650784+(m<<2)>>2]=c[614800+(l<<2)>>2];c[9648736+(m<<2)>>2]=c[614832+(l<<2)>>2];m=m+1|0;}while(m>>>0<256);gGz(9637928+(b*116|0)|0,0,116);if((d|0)==16){c[9637944+(b*116|0)>>2]=0;c[9638020+(b*116|0)>>2]=16;a[9638016+(b*116|0)|0]=4;a[9638017+(b*116|0)|0]=4}else if((d|0)==8){c[9637944+(b*116|0)>>2]=0;c[9638020+(b*116|0)>>2]=8;a[9638016+(b*116|0)|0]=6;a[9638017+(b*116|0)|0]=2}else if((d|0)==0){c[9637944+(b*116|0)>>2]=0;c[9638020+(b*116|0)>>2]=0;a[9638016+(b*116|0)|0]=6;a[9638017+(b*116|0)|0]=1}c[g>>2]=1026;c[g+4>>2]=5812;c[g+8>>2]=4356;c[g+12>>2]=3066;c[g+16>>2]=16;c[g+20>>2]=0;c[g+24>>2]=1356;c[g+28>>2]=1492;c[g+32>>2]=2678;c[g+36>>2]=12870;c[g+40>>2]=294}else if((d|0)==65552|(d|0)==65544){m=d&255;d=9636056+(b*468|0)|0;c[2385308]=d;l=0;while(1){if((l|0)==0){a[9760944]=1;l=1;continue}else{n=l;o=0}while(1){h=(n&1)+o|0;k=n>>>1;if((k|0)==0){break}else{n=k;o=h}}a[9760944+l|0]=(n+o&1^1)&255;h=l+1|0;if(h>>>0<256){l=h}else{p=0;break}}while(1){l=p>>>3&7;c[9651808+(p<<2)>>2]=c[617024+(l<<2)>>2];c[9653856+(p<<2)>>2]=c[616992+(l<<2)>>2];l=p+1|0;if(l>>>0<256){p=l}else{q=192;break}}do{p=q&7;c[9649760+(q<<2)>>2]=c[616992+(p<<2)>>2];c[9647712+(q<<2)>>2]=c[617024+(p<<2)>>2];q=q+1|0;}while(q>>>0<256);gGz(d|0,0,468);c[9636476+(b*468|0)>>2]=e;if((m|0)==8){c[9636312+(b*468|0)>>2]=0;c[9636500+(b*468|0)>>2]=8;a[9636496+(b*468|0)|0]=6;a[9636497+(b*468|0)|0]=2}else if((m|0)==16){c[9636312+(b*468|0)>>2]=0;c[9636500+(b*468|0)>>2]=16;a[9636496+(b*468|0)|0]=4;a[9636497+(b*468|0)|0]=4}c[g>>2]=858;c[g+4>>2]=6754;c[g+8>>2]=1892;c[g+12>>2]=560;c[g+16>>2]=130;c[g+20>>2]=888;c[g+24>>2]=2336;c[g+28>>2]=1660;c[g+32>>2]=1512;c[g+36>>2]=8744;c[g+40>>2]=1500}c[g+8236>>2]=474;c[g+8240>>2]=2110;c[g+8244>>2]=1706;c[g+8248>>2]=1876;g=(c[2113014]|0)+1|0;c[2385546]=g;c[2113014]=g;g=c[2427044]|0;c[9681616+(g<<3)>>2]=1175616;c[9681620+(g<<3)>>2]=b;c[2427044]=g+1;return}function fyA(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0;a=c[2439374]|0;if((a|0)!=0){b=a;a=0;while(1){if((a|0)>=1024){break}d=9638528+(a<<2)|0;if((c[d>>2]|0)==(b|0)){e=880;break}else{a=a+1|0}}if((e|0)==880){gGr(b);c[d>>2]=0}c[2439374]=0}d=c[2439375]|0;if((d|0)!=0){b=d;d=0;while(1){if((d|0)>=1024){break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==(b|0)){e=886;break}else{d=d+1|0}}if((e|0)==886){gGr(b);c[f>>2]=0}c[2439375]=0}f=c[2439376]|0;if((f|0)!=0){b=f;f=0;while(1){if((f|0)>=1024){break}g=9638528+(f<<2)|0;if((c[g>>2]|0)==(b|0)){e=892;break}else{f=f+1|0}}if((e|0)==892){gGr(b);c[g>>2]=0}c[2439376]=0}g=c[2439377]|0;if((g|0)==0){c[2385546]=0;c[2113014]=0;c[1836234]=-1;return}b=g;g=0;while(1){if((g|0)>=1024){break}h=9638528+(g<<2)|0;if((c[h>>2]|0)==(b|0)){e=898;break}else{g=g+1|0}}if((e|0)==898){gGr(b);c[h>>2]=0}c[2439377]=0;c[2385546]=0;c[2113014]=0;c[1836234]=-1;return}function fyB(a){a=a|0;var b=0;b=a>>>0>3?0:a;c[1836234]=b;a=c[9757496+(b<<2)>>2]|0;c[3531864]=a;gf[c[a>>2]&2047](b);return}function fyC(){c[1836234]=-1;gu[c[(c[3531864]|0)+4>>2]&16383]();c[3531864]=0;return}function fyD(){c[2409128]=0;c[2409245]=0;c[2409362]=0;c[2409479]=0;c[2409508]=0;c[2409537]=0;c[2409566]=0;c[2409595]=0;return}function fyE(){gu[c[(c[3531864]|0)+36>>2]&16383]();return}function fyF(){return gD[c[(c[3531864]|0)+24>>2]&8191]()|0}function fyG(){return c[1836234]|0}function fyH(){gD[c[(c[3531864]|0)+8>>2]&8191]()|0;return}function fyI(a){a=a|0;var b=0;if((a|0)<1){b=0;return b|0}b=gj[c[(c[3531864]|0)+12>>2]&4095](a)|0;return b|0}function fyJ(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=b&1048575;b=e>>>11;f=c[3531864]|0;g=c[f+2092+(b<<2)>>2]|0;if((g|0)!=0){a[g+e|0]=d}g=c[f+44+(b<<2)>>2]|0;if((g|0)!=0){a[g+e|0]=d}g=c[f+4140+(b<<2)>>2]|0;if((g|0)!=0){a[g+e|0]=d}g=c[f+6188+(b<<2)>>2]|0;if((g|0)==0){h=f+8240|0;i=c[h>>2]|0;gg[i&4095](e,d);return}a[g+e|0]=d;h=f+8240|0;i=c[h>>2]|0;gg[i&4095](e,d);return}function fyK(){gGz(9705864|0,0|0,184|0);c[2426481]=201326595;return}function fyL(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0;d=i;i=i+8|0;e=d|0;c[3528846]=b;c[2426511]=b;f=c[2426481]|0;while(1){g=f&67108860;do{if((c[3542218]|0)==(g|0)){h=c[2427230]|0;if((h|0)==0){c[3528846]=0;break}else{gu[h&16383]();break}}}while(0);h=c[(c[2406726]|0)+(g>>>12<<2)>>2]|0;do{if((h|0)==0){j=c[2432800]|0;if((j|0)==0){k=0;l=937;break}m=gj[j&4095](g)|0;l=936}else{m=c[h+(f&4092)>>2]|0;l=936}}while(0);L1160:do{if((l|0)==936){l=0;switch(m>>>28|0){case 0:{k=m;l=937;break L1160;break};case 12:{if((f&1073741824|0)!=0){l=1240;break L1160}if((f>>>31|0)==(f>>>28&1|0)){n=m;l=953;break L1160}else{l=1240;break L1160}break};case 11:{if((f>>>31|0)==(f>>>28&1|0)){l=1240;break L1160}else{n=m;l=953;break L1160}break};case 8:{if((f&1610612736|0)==536870912){n=m;l=953;break L1160}else{l=1240;break L1160}break};case 9:{if((f&1610612736|0)==536870912){l=1240;break L1160}else{n=m;l=953;break L1160}break};case 13:{if((f&1073741824|0)!=0){n=m;l=953;break L1160}if((f>>>31|0)==(f>>>28&1|0)){l=1240;break L1160}else{n=m;l=953;break L1160}break};case 7:{if((f&268435456|0)==0){n=m;l=953;break L1160}else{l=1240;break L1160}break};case 1:{if((f&1073741824|0)==0){n=m;l=953;break L1160}else{l=1240;break L1160}break};case 2:{if((f&536870912|0)==0){l=1240;break L1160}else{n=m;l=953;break L1160}break};case 3:{if((f&536870912|0)==0){n=m;l=953;break L1160}else{l=1240;break L1160}break};case 5:{if((f|0)<0){l=1240;break L1160}else{n=m;l=953;break L1160}break};case 6:{if((f&268435456|0)==0){l=1240;break L1160}else{n=m;l=953;break L1160}break};case 4:{if((f|0)<0){n=m;l=953;break L1160}else{l=1240;break L1160}break};case 10:{if((f>>>31|0)==(f>>>28&1|0)){n=m;l=953;break L1160}else{l=1240;break L1160}break};case 15:{l=1240;break L1160;break};default:{n=m;l=953;break L1160}}}}while(0);if((l|0)==937){l=0;if((f&1073741824|0)==0){l=1240}else{n=k;l=953}}do{if((l|0)==953){l=0;if((n&264241392|0)==144){c[3528846]=(c[3528846]|0)-2;h=c[2426481]&3;g=ag(c[9705864+(c[4436520+(h<<6)+((n>>>8&15)<<2)>>2]<<2)>>2]|0,c[9705864+(c[4436520+(h<<6)+((n&15)<<2)>>2]<<2)>>2]|0)|0;if((n&2097152|0)==0){o=g}else{o=(c[9705864+(c[4436520+(h<<6)+((n>>>12&15)<<2)>>2]<<2)>>2]|0)+g|0}g=n>>>16&15;c[9705864+(c[4436520+(h<<6)+(g<<2)>>2]<<2)>>2]=o;h=c[2426481]|0;if((g|0)==15){g=h&-67108861|o&67108860;c[2426481]=g;p=g}else{p=h}if((n&1048576|0)==0){q=p}else{h=((o|0)==0)<<30|o&-2147483648|p&1073741823;c[2426481]=h;q=h}c[2426481]=q+4;break}h=n&201326592;if((h|0)==0){c[e>>2]=0;g=n>>>21;j=g&15;c[3528846]=(c[3528846]|0)-1;do{if((n&33554432|0)==0){r=(n&1048576|0)!=0;s=fyP(n,r?e:0)|0;if(r){t=s;break}c[e>>2]=0;t=s}else{s=n>>>8&15;if((s|0)==0){c[e>>2]=c[2426481]&536870912;t=n&4095;break}else{r=n&255;u=s<<1;s=r<<32-u|r>>>(u>>>0);c[e>>2]=s&-2147483648;t=s;break}}}while(0);do{if((g&13|0)==13){v=0}else{s=n>>>16&15;u=c[2426481]|0;if((s|0)==15){v=u+8&67108860;break}else{v=c[9705864+(c[4436520+((u&3)<<6)+(s<<2)>>2]<<2)>>2]|0;break}}}while(0);L1210:do{switch(j|0){case 10:case 2:{s=v-t|0;u=c[2426481]|0;if((n&1048576|0)==0){c[2426481]=u+4;w=s;break L1210}if((v^t|0)<0){x=(s^v)>>>31<<28}else{x=0}r=t>>>31^1;y=s>>>31^1;c[2426481]=(((v|0)==(t|0))<<30|s&-2147483648|(((y|r)&v>>>31|y&r|0)!=0?536870912:0)|u&268435455|x)+4;w=s;break};case 6:{s=v-t|0;u=c[2426481]|0;r=u>>>29&1^1;y=s-r|0;if((n&1048576|0)==0){c[2426481]=u+4;w=y;break L1210}if((v^t|0)<0){z=(y^v)>>>31<<28}else{z=0}A=t>>>31^1;B=y>>>31^1;c[2426481]=(y&-2147483648|u&268435455|((s|0)==(r|0))<<30|(((B|A)&v>>>31|B&A|0)!=0?536870912:0)|z)+4;w=y;break};case 7:{y=t-v|0;A=c[2426481]|0;B=A>>>29&1^1;r=y-B|0;if((n&1048576|0)==0){c[2426481]=A+4;w=r;break L1210}if((v^t|0)<0){C=(r^t)>>>31<<28}else{C=0}s=v>>>31^1;u=r>>>31^1;c[2426481]=(r&-2147483648|A&268435455|((y|0)==(B|0))<<30|(((u|s)&t>>>31|u&s|0)!=0?536870912:0)|C)+4;w=r;break};case 3:{r=t-v|0;s=c[2426481]|0;if((n&1048576|0)==0){c[2426481]=s+4;w=r;break L1210}if((v^t|0)<0){D=(r^t)>>>31<<28}else{D=0}u=v>>>31^1;B=r>>>31^1;c[2426481]=(((t|0)==(v|0))<<30|r&-2147483648|(((B|u)&t>>>31|B&u|0)!=0?536870912:0)|s&268435455|D)+4;w=r;break};case 5:{r=c[2426481]|0;s=v+t+(r>>>29&1)|0;if((n&1048576|0)==0){c[2426481]=r+4;w=s;break L1210}if((v^t|0)<0){E=0}else{E=(s^v)>>>31<<28}c[2426481]=(r&268435455|(t>>>0>~v>>>0)<<29|s&-2147483648|((s|0)==0)<<30|E)+4;w=s;break};case 11:case 4:{s=v+t|0;r=c[2426481]|0;if((n&1048576|0)==0){c[2426481]=r+4;w=s;break L1210}if((v^t|0)<0){F=0}else{F=(s^v)>>>31<<28}c[2426481]=((t>>>0>~v>>>0)<<29|s&-2147483648|((s|0)==0)<<30|r&268435455|F)+4;w=s;break};case 0:case 8:{s=v&t;r=c[2426481]|0;if((n&1048576|0)==0){c[2426481]=r+4;w=s;break L1210}else{c[2426481]=(((s|0)==0)<<30|s&-2147483648|r&536870911|((c[e>>2]|0)!=0)<<29)+4;w=s;break L1210}break};case 14:{s=v&~t;r=c[2426481]|0;if((n&1048576|0)==0){c[2426481]=r+4;w=s;break L1210}else{c[2426481]=(((s|0)==0)<<30|s&-2147483648|r&536870911|((c[e>>2]|0)!=0)<<29)+4;w=s;break L1210}break};case 9:case 1:{s=v^t;r=c[2426481]|0;if((n&1048576|0)==0){c[2426481]=r+4;w=s;break L1210}else{c[2426481]=(((v|0)==(t|0))<<30|s&-2147483648|r&536870911|((c[e>>2]|0)!=0)<<29)+4;w=s;break L1210}break};case 12:{s=v|t;r=c[2426481]|0;if((n&1048576|0)==0){c[2426481]=r+4;w=s;break L1210}else{c[2426481]=(((s|0)==0)<<30|s&-2147483648|r&536870911|((c[e>>2]|0)!=0)<<29)+4;w=s;break L1210}break};case 13:{s=c[2426481]|0;if((n&1048576|0)==0){c[2426481]=s+4;w=t;break L1210}else{c[2426481]=(((t|0)==0)<<30|t&-2147483648|s&536870911|((c[e>>2]|0)!=0)<<29)+4;w=t;break L1210}break};case 15:{s=~t;r=c[2426481]|0;if((n&1048576|0)==0){c[2426481]=r+4;w=s;break L1210}else{c[2426481]=(((t|0)==-1)<<30|s&-2147483648|r&536870911|((c[e>>2]|0)!=0)<<29)+4;w=s;break L1210}break};default:{w=0}}}while(0);j=n>>>12&15;s=(j|0)==15;if((g&12|0)==8){if((n&1048576|0)==0|s^1){break}r=(n|0)==-482349053?w-4|0:w;c[3528846]=(c[3528846]|0)-2;u=c[2426481]|0;B=u&3;if((B|0)==0){c[2426481]=u&201326592|r&-201326596;break}else{c[9705864+(c[4436580+(B<<6)>>2]<<2)>>2]=r;c[2426481]=c[2426481]&-67108861|r&67108860;break}}if(s&(n&1048576|0)==0){r=c[2426481]|0;c[2426481]=r&-268435456|w&67108860|r&201326592|r&3;c[3528846]=(c[3528846]|0)-2;break}r=c[2426481]|0;B=r&3;if(!s){c[9705864+(c[4436520+(B<<6)+(j<<2)>>2]<<2)>>2]=w;break}if((B|0)==0){j=r&201326592|w&-201326596;c[2426481]=j;G=j&-67108864|w&67108860}else{c[9705864+(c[4436580+(B<<6)>>2]<<2)>>2]=w;G=c[2426481]&-67108861|w&67108860}c[2426481]=G;c[3528846]=(c[3528846]|0)-2;break}else if((h|0)==67108864){if((n&33554432|0)==0){H=n&4095}else{H=fyP(n,0)|0}B=n>>>16&15;j=(n&16777216|0)!=0;do{if(j){r=9705864+(c[4436520+((c[2426481]&3)<<6)+(B<<2)>>2]<<2)|0;s=(c[r>>2]|0)+((n&8388608|0)==0?-H|0:H)|0;if((n&2097152|0)==0){if((B|0)!=15){I=s;break}I=(s&67108860)+8|0;break}else{c[r>>2]=s;if((B|0)!=15){I=s;break}c[2426481]=c[2426481]&-67108861|s&67108860;I=s;break}}else{s=c[2426481]|0;if((B|0)==15){I=(s&67108860)+8|0;break}else{I=c[9705864+(c[4436520+((s&3)<<6)+(B<<2)>>2]<<2)>>2]|0;break}}}while(0);h=n>>>12&15;g=c[3528846]|0;do{if((n&1048576|0)==0){c[3528846]=g-2;if((n&4194304|0)!=0){s=c[9705864+(c[4436520+((c[2426481]&3)<<6)+(h<<2)>>2]<<2)>>2]&255;r=I&67108863;u=c[(c[2406728]|0)+(r>>>12<<2)>>2]|0;if((u|0)!=0){a[u+(I&4095)|0]=s;break}u=c[2430390]|0;if((u|0)==0){break}gg[u&4095](r,s);break}s=c[2426481]|0;if((h|0)==15){J=s+8|0}else{J=c[9705864+(c[4436520+((s&3)<<6)+(h<<2)>>2]<<2)>>2]|0}s=I&67108860;r=c[(c[2406728]|0)+(s>>>12<<2)>>2]|0;if((r|0)!=0){c[r+(I&4092)>>2]=J;break}r=c[2430386]|0;if((r|0)==0){break}gg[r&4095](s,J)}else{c[3528846]=g-3;if((n&4194304|0)!=0){s=I&67108863;r=c[(c[2406730]|0)+(s>>>12<<2)>>2]|0;do{if((r|0)==0){u=c[2432804]|0;if((u|0)==0){K=0;break}K=gj[u&4095](s)|0}else{K=a[r+(I&4095)|0]|0}}while(0);r=K&255;c[9705864+(c[4436520+((c[2426481]&3)<<6)+(h<<2)>>2]<<2)>>2]=r;if((h|0)!=15){break}c[2426481]=c[2426481]&-67108861|r&252;break}r=(h|0)==15;s=I&67108860;u=s>>>12;y=c[(c[2406730]|0)+(u<<2)>>2]|0;do{if((y|0)==0){A=c[2432800]|0;if((A|0)==0){L=0;break}L=gj[A&4095](s)|0}else{L=c[y+(I&4092)>>2]|0}}while(0);y=I&3;if((y|0)==1){M=L<<24|L>>>8}else if((y|0)==2){M=L<<16|L>>>16}else if((y|0)==3){M=L<<8|L>>>24}else{M=L}if(!r){c[9705864+(c[4436520+((c[2426481]&3)<<6)+(h<<2)>>2]<<2)>>2]=M;break}c[2426481]=c[2426481]&-268435453|M&67108860;A=c[(c[2406730]|0)+(u<<2)>>2]|0;do{if((A|0)==0){N=c[2432800]|0;if((N|0)==0){O=0;break}O=gj[N&4095](s)|0}else{O=c[A+(I&4092)>>2]|0}}while(0);if((y|0)==1){P=O<<24|O>>>8}else if((y|0)==2){P=O<<16|O>>>16}else if((y|0)==3){P=O<<8|O>>>24}else{P=O}if((P&3|0)==0){c[2426481]=(c[2426481]|0)-4}c[3528846]=(c[3528846]|0)-2}}while(0);do{if(!j){g=(h|0)==(B|0);if((n&8388608|0)==0){if(g){if((B|0)!=15){break}A=c[2426481]|0;c[2426481]=c[9705864+(c[4436580+((A&3)<<6)>>2]<<2)>>2]&67108860|A&-67108861;break}else{A=I-H|0;c[9705864+(c[4436520+((c[2426481]&3)<<6)+(B<<2)>>2]<<2)>>2]=A;if((B|0)!=15){break}c[2426481]=c[2426481]&-67108861|A&67108860;break}}else{if(g){if((B|0)!=15){break}g=c[2426481]|0;c[2426481]=c[9705864+(c[4436580+((g&3)<<6)>>2]<<2)>>2]&67108860|g&-67108861;break}else{g=I+H|0;c[9705864+(c[4436520+((c[2426481]&3)<<6)+(B<<2)>>2]<<2)>>2]=g;if((B|0)!=15){break}c[2426481]=c[2426481]&-67108861|g&67108860;break}}}}while(0);c[2426481]=(c[2426481]|0)+4;break}else{B=n&234881024;if((B|0)==134217728){h=n>>>16&15;j=c[2426481]|0;g=c[9705864+(c[4436520+((j&3)<<6)+(h<<2)>>2]<<2)>>2]|0;if((n&1048576|0)==0){A=(n&32768|0)!=0;if(A){c[2426481]=j+12}j=(n&16777216|0)!=0;do{if((n&8388608|0)==0){s=n&65535;u=j?g:g+4|0;r=15;N=0;while(1){if((s&1<<r|0)==0){Q=N;R=u}else{S=u-4|0;T=c[9705864+(c[4436520+((c[2426481]&3)<<6)+(r<<2)>>2]<<2)>>2]|0;U=S&67108860;V=c[(c[2406728]|0)+(U>>>12<<2)>>2]|0;do{if((V|0)==0){W=c[2430386]|0;if((W|0)==0){break}gg[W&4095](U,T)}else{c[V+(S&4092)>>2]=T}}while(0);Q=N+1|0;R=S}if((r|0)>0){u=R;r=r-1|0;N=Q}else{break}}if((n&2097152|0)==0){X=Q;break}N=9705864+(c[4436520+((c[2426481]&3)<<6)+(h<<2)>>2]<<2)|0;r=(c[N>>2]|0)-(Q<<2)|0;c[N>>2]=r;if((h|0)!=15){X=Q;break}c[2426481]=c[2426481]&-67108861|r&67108860;X=Q}else{r=n&65535;N=j?g:g-4|0;u=0;s=0;while(1){if((r&1<<u|0)==0){Y=s;Z=N}else{y=N+4|0;T=c[9705864+(c[4436520+((c[2426481]&3)<<6)+(u<<2)>>2]<<2)>>2]|0;V=y&67108860;U=c[(c[2406728]|0)+(V>>>12<<2)>>2]|0;do{if((U|0)==0){W=c[2430386]|0;if((W|0)==0){break}gg[W&4095](V,T)}else{c[U+(y&4092)>>2]=T}}while(0);Y=s+1|0;Z=y}T=u+1|0;if((T|0)<16){N=Z;u=T;s=Y}else{break}}if((n&2097152|0)==0){X=Y;break}s=9705864+(c[4436520+((c[2426481]&3)<<6)+(h<<2)>>2]<<2)|0;u=(c[s>>2]|0)+(Y<<2)|0;c[s>>2]=u;if((h|0)!=15){X=Y;break}c[2426481]=c[2426481]&-67108861|u&67108860;X=Y}}while(0);if(A){c[2426481]=(c[2426481]|0)-12}_=(c[3528846]|0)+~X|0}else{j=(n&16777216|0)==0;do{if((n&8388608|0)==0){u=n&65535;s=(n&4194304|0)==0;N=j?g+4|0:g;r=15;T=0;U=0;V=0;while(1){if((u&1<<r|0)==0){$=T;aa=N;ab=U;ac=V}else{do{if((r|0)==15){if(!s){S=N-4|0;W=S&67108860;ad=c[(c[2406730]|0)+(W>>>12<<2)>>2]|0;do{if((ad|0)==0){ae=c[2432800]|0;if((ae|0)==0){af=0;break}af=gj[ae&4095](W)|0}else{af=c[ad+(S&4092)>>2]|0}}while(0);ad=S&3;if((ad|0)==1){ah=S;ai=1;aj=af<<24|af>>>8;break}else if((ad|0)==2){ah=S;ai=1;aj=af<<16|af>>>16;break}else if((ad|0)==3){ah=S;ai=1;aj=af<<8|af>>>24;break}else{ah=S;ai=1;aj=af;break}}ad=c[2426481]&-67108861;W=N-4|0;ae=W&67108860;ak=c[(c[2406730]|0)+(ae>>>12<<2)>>2]|0;do{if((ak|0)==0){al=c[2432800]|0;if((al|0)==0){am=0;break}am=gj[al&4095](ae)|0}else{am=c[ak+(W&4092)>>2]|0}}while(0);ak=W&3;if((ak|0)==1){an=am<<24|am>>>8}else if((ak|0)==2){an=am<<16|am>>>16}else if((ak|0)==3){an=am<<8|am>>>24}else{an=am}ah=W;ai=1;aj=an&67108860|ad}else{ak=N-4|0;ae=ak&67108860;S=c[(c[2406730]|0)+(ae>>>12<<2)>>2]|0;do{if((S|0)==0){al=c[2432800]|0;if((al|0)==0){ao=0;break}ao=gj[al&4095](ae)|0}else{ao=c[S+(ak&4092)>>2]|0}}while(0);S=ak&3;if((S|0)==1){ap=ao<<24|ao>>>8}else if((S|0)==2){ap=ao<<16|ao>>>16}else if((S|0)==3){ap=ao<<8|ao>>>24}else{ap=ao}c[9705864+(c[4436520+((c[2426481]&3)<<6)+(r<<2)>>2]<<2)>>2]=ap;ah=ak;ai=U;aj=V}}while(0);$=T+1|0;aa=ah;ab=ai;ac=aj}if((r|0)>0){N=aa;r=r-1|0;T=$;U=ab;V=ac}else{break}}do{if((n&2097152|0)!=0){V=9705864+(c[4436520+((c[2426481]&3)<<6)+(h<<2)>>2]<<2)|0;U=(c[V>>2]|0)-($<<2)|0;c[V>>2]=U;if((h|0)!=15){break}c[2426481]=c[2426481]&-67108861|U&67108860}}while(0);if((ab|0)!=0){c[9705864+(c[4436580+((c[2426481]&3)<<6)>>2]<<2)>>2]=ac;c[2426481]=c[2426481]&-67108861|ac&67108860}if((n&32768|0)==0){aq=$;break}c[3528846]=(c[3528846]|0)-2;c[2426481]=(c[2426481]|0)-4;aq=$}else{U=j?g-4|0:g;V=n&65535;if((n&4194304|0)==0){T=U;r=0;N=0;while(1){if((1<<r&V|0)==0){ar=N;as=T}else{if((r|0)==15){s=c[2426481]&-67108861;u=T+4|0;y=u&67108860;S=c[(c[2406730]|0)+(y>>>12<<2)>>2]|0;do{if((S|0)==0){ae=c[2432800]|0;if((ae|0)==0){at=0;break}at=gj[ae&4095](y)|0}else{at=c[S+(u&4092)>>2]|0}}while(0);S=u&3;if((S|0)==2){au=at<<16|at>>>16}else if((S|0)==1){au=at<<24|at>>>8}else if((S|0)==3){au=at<<8|at>>>24}else{au=at}S=au&67108860;c[9705864+(c[4436580+((c[2426481]&3)<<6)>>2]<<2)>>2]=S|s;c[2426481]=c[2426481]&-67108861|S;av=u}else{S=T+4|0;y=S&67108860;ae=c[(c[2406730]|0)+(y>>>12<<2)>>2]|0;do{if((ae|0)==0){ad=c[2432800]|0;if((ad|0)==0){aw=0;break}aw=gj[ad&4095](y)|0}else{aw=c[ae+(S&4092)>>2]|0}}while(0);ae=S&3;if((ae|0)==2){ax=aw<<16|aw>>>16}else if((ae|0)==1){ax=aw<<24|aw>>>8}else if((ae|0)==3){ax=aw<<8|aw>>>24}else{ax=aw}c[9705864+(c[4436520+((c[2426481]&3)<<6)+(r<<2)>>2]<<2)>>2]=ax;av=S}ar=N+1|0;as=av}ae=r+1|0;if((ae|0)<16){T=as;r=ae;N=ar}else{ay=ar;break}}}else{N=U;r=0;T=0;while(1){if((1<<r&V|0)==0){az=T;aA=N}else{ae=(r|0)==15;y=N+4|0;u=y&67108860;s=c[(c[2406730]|0)+(u>>>12<<2)>>2]|0;do{if((s|0)==0){ad=c[2432800]|0;if((ad|0)==0){aB=0;break}aB=gj[ad&4095](u)|0}else{aB=c[s+(y&4092)>>2]|0}}while(0);s=y&3;if(ae){if((s|0)==1){aC=aB<<24|aB>>>8}else if((s|0)==2){aC=aB<<16|aB>>>16}else if((s|0)==3){aC=aB<<8|aB>>>24}else{aC=aB}c[9705864+(c[4436580+((c[2426481]&3)<<6)>>2]<<2)>>2]=aC;c[2426481]=c[2426481]&-67108861|aC&67108860}else{if((s|0)==1){aD=aB<<24|aB>>>8}else if((s|0)==2){aD=aB<<16|aB>>>16}else if((s|0)==3){aD=aB<<8|aB>>>24}else{aD=aB}c[9705864+(c[4436520+((c[2426481]&3)<<6)+(r<<2)>>2]<<2)>>2]=aD}az=T+1|0;aA=y}s=r+1|0;if((s|0)<16){N=aA;r=s;T=az}else{ay=az;break}}}if((n&32768|0)!=0){c[2426481]=(c[2426481]|0)-4;c[3528846]=(c[3528846]|0)-2}if((n&2097152|0)==0){aq=ay;break}if((1<<h&n|0)!=0){aq=ay;break}T=9705864+(c[4436520+((c[2426481]&3)<<6)+(h<<2)>>2]<<2)|0;r=(c[T>>2]|0)+(ay<<2)|0;c[T>>2]=r;if((h|0)!=15){aq=ay;break}c[2426481]=c[2426481]&-67108861|r&67108860;aq=ay}}while(0);_=-2-aq+(c[3528846]|0)|0}c[3528846]=_;c[2426481]=(c[2426481]|0)+4;break}else if((B|0)==167772160){h=n<<2;g=h&67108860;if((n&16777216|0)!=0){j=c[2426481]|0;c[9705864+(c[4436576+((j&3)<<6)>>2]<<2)>>2]=j+4}if((h&33554432|0)==0){aE=g+8+(c[2426481]|0)|0}else{aE=g-67108856+(c[2426481]|0)|0}c[2426481]=aE;c[3528846]=(c[3528846]|0)-3;break}else{g=n&251658240;if((g|0)==251658240){h=(c[2426481]|0)+4|0;c[2426492]=h;c[2426481]=h|134217731;c[3528846]=(c[3528846]|0)-3;break}else if((g|0)!=234881024){l=1240;break}g=n>>>12&15;h=n>>>16&15;c[3528846]=(c[3528846]|0)-1;j=n&252706832;do{if((j|0)==235929616){A=c[9705972+(h<<2)>>2]|0;c[9705864+(c[4436520+((c[2426481]&3)<<6)+(g<<2)>>2]<<2)>>2]=A;if((g|0)!=15){break}c[2426481]=c[2426481]&-67108861|A&67108860}else if((j|0)==234881040){A=c[9705864+(c[4436520+((c[2426481]&3)<<6)+(g<<2)>>2]<<2)>>2]|0;c[9705972+(h<<2)>>2]=A;if((h|0)!=2){break}if((A|0)==0){r=c[2426493]|0;T=c[2426494]|0;N=(T&15)+(r&15)+(ag((T>>>28)+(r>>>28)|0,1e7)|0)+(((T>>>24&15)+(r>>>24&15)|0)*1e6|0)+(((T>>>20&15)+(r>>>20&15)|0)*1e5|0)+(((T>>>16&15)+(r>>>16&15)|0)*1e4|0)+(((T>>>12&15)+(r>>>12&15)|0)*1e3|0)+(((T>>>8&15)+(r>>>8&15)|0)*100|0)+(((T>>>4&15)+(r>>>4&15)|0)*10|0)|0;r=(N>>>0)%10|0;T=N-r|0;N=(T>>>0)%100|0;V=T-N|0;T=(V>>>0)%1e3|0;U=V-T|0;V=(U>>>0)%1e4|0;s=U-V|0;U=(s>>>0)%1e5|0;u=s-U|0;s=(u>>>0)%1e6|0;S=u-s|0;u=(S>>>0)%1e7|0;c[2426498]=(((U>>>0)/1e4|0)<<16)+(((N>>>0)/10|0)<<4|r|((T>>>0)/100|0)<<8|((V>>>0)/1e3|0)<<12)+(((s>>>0)/1e5|0)<<20)+(((u>>>0)/1e6|0)<<24)+((((((S-u|0)>>>0)%1e8|0)>>>0)/1e7|0)<<28);break}else if((A|0)==1){u=c[2426493]|0;S=(ag(u>>>28,1e7)|0|u&15)+((u>>>4&15)*10|0)+((u>>>8&15)*100|0)+((u>>>12&15)*1e3|0)+((u>>>16&15)*1e4|0)+((u>>>20&15)*1e5|0)+((u>>>24&15)*1e6|0)|0;u=c[2426494]|0;s=ag((ag(u>>>28,1e7)|0|u&15)+((u>>>4&15)*10|0)+((u>>>8&15)*100|0)+((u>>>12&15)*1e3|0)+((u>>>16&15)*1e4|0)+((u>>>20&15)*1e5|0)+((u>>>24&15)*1e6|0)|0,S)|0;S=(s>>>0)%10|0;u=s-S|0;s=(u>>>0)%100|0;V=u-s|0;u=(V>>>0)%1e3|0;T=V-u|0;V=(T>>>0)%1e4|0;r=T-V|0;T=(r>>>0)%1e5|0;N=r-T|0;r=(N>>>0)%1e6|0;U=N-r|0;N=(U>>>0)%1e7|0;c[2426498]=(((T>>>0)/1e4|0)<<16)+(((s>>>0)/10|0)<<4|S|((u>>>0)/100|0)<<8|((V>>>0)/1e3|0)<<12)+(((r>>>0)/1e5|0)<<20)+(((N>>>0)/1e6|0)<<24)+((((((U-N|0)>>>0)%1e8|0)>>>0)/1e7|0)<<28);break}else if((A|0)==3){A=c[2426493]|0;N=ag(A>>>28,1e7)|0;U=c[2426494]|0;r=(N|A&15)-(U&15)+(ag(U>>>28,-1e7)|0)+(((A>>>24&15)-(U>>>24&15)|0)*1e6|0)+(((A>>>20&15)-(U>>>20&15)|0)*1e5|0)+(((A>>>16&15)-(U>>>16&15)|0)*1e4|0)+(((A>>>12&15)-(U>>>12&15)|0)*1e3|0)+(((A>>>8&15)-(U>>>8&15)|0)*100|0)+(((A>>>4&15)-(U>>>4&15)|0)*10|0)|0;U=(r>>>0)%10|0;A=r-U|0;r=(A>>>0)%100|0;N=A-r|0;A=(N>>>0)%1e3|0;V=N-A|0;N=(V>>>0)%1e4|0;u=V-N|0;V=(u>>>0)%1e5|0;S=u-V|0;u=(S>>>0)%1e6|0;s=S-u|0;S=(s>>>0)%1e7|0;c[2426498]=(((V>>>0)/1e4|0)<<16)+(((r>>>0)/10|0)<<4|U|((A>>>0)/100|0)<<8|((N>>>0)/1e3|0)<<12)+(((u>>>0)/1e5|0)<<20)+(((S>>>0)/1e6|0)<<24)+((((((s-S|0)>>>0)%1e8|0)>>>0)/1e7|0)<<28);break}else{break}}else{if((n&251658256|0)!=234881024){break}S=c[2426494]|0;if((S|0)==0){c[2426496]=-1;c[2426497]=-1;break}else{s=c[2426493]|0;c[2426496]=(s>>>0)/(S>>>0)|0;c[2426497]=(s>>>0)%(S>>>0)|0;break}}}while(0);c[2426481]=(c[2426481]|0)+4;break}}}}while(0);if((l|0)==1240){l=0;c[3528846]=(c[3528846]|0)-1;c[2426481]=(c[2426481]|0)+4}h=c[2426481]|0;g=h+4|0;do{if((a[9706037]|0)==0){l=1244}else{if((g&67108864|0)!=0){l=1244;break}c[2426488]=g;j=g&-268435456|201326621;c[2426481]=j;a[9706037]=0;aF=j}}while(0);do{if((l|0)==1244){l=0;if((a[9706036]|0)==0){aF=h;break}if((g&134217728|0)!=0){aF=h;break}c[2426490]=g;j=g&-201326592|134217754;c[2426481]=j;a[9706036]=0;aF=j}}while(0);aG=c[3528846]|0;if((aG|0)>0){f=aF}else{break}}aF=b-aG|0;c[2426510]=(c[2426510]|0)+aF;i=d;return aF|0}function fyM(){return(c[2426511]|0)+(c[2426510]|0)-(c[3528846]|0)|0}function fyN(){c[3528846]=0;return}function fyO(){c[2426510]=0;c[3528846]=0;c[2426511]=0;return}function fyP(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=a>>>7&31;e=a&15;f=c[2426481]|0;g=f&3;h=c[9705864+(c[4436520+(g<<6)+(e<<2)>>2]<<2)>>2]|0;i=(e|0)==15?h+8|0:h;do{if((a&16|0)==0){j=d}else{h=c[9705864+(c[4436520+(g<<6)+(d>>>1<<2)>>2]<<2)>>2]&31;c[3528846]=(c[3528846]|0)-1;if((h|0)!=0){j=h;break}if((b|0)==0){k=i;return k|0}c[b>>2]=f&536870912;k=i;return k|0}}while(0);d=a>>>5&3;if((d|0)==1){a=(b|0)==0;if((j|0)==0){if(a){k=0;return k|0}c[b>>2]=i&-2147483648;k=0;return k|0}else{if(!a){c[b>>2]=1<<j-1&i}k=i>>>(j>>>0);return k|0}}else if((d|0)==0){if((b|0)!=0){if((j|0)==0){l=f&536870912}else{l=1<<32-j&i}c[b>>2]=l}k=i<<j;return k|0}else if((d|0)==2){l=(j|0)==0;a=l?32:j;if((b|0)!=0){c[b>>2]=1<<a-1&i}if(l){k=i>>31;return k|0}l=i>>>(a>>>0);if((i|0)>=0){k=l;return k|0}k=-1<<32-a|l;return k|0}else if((d|0)==3){if((j|0)==0){if((b|0)==0){m=f}else{c[b>>2]=i&1;m=c[2426481]|0}k=m<<2&-2147483648|i>>>1;return k|0}else{n=j}while(1){if(n>>>0>32){n=n-32|0}else{break}}if((b|0)!=0){c[b>>2]=i&-2147483648}k=i<<32-n|i>>>(n>>>0);return k|0}else{k=0;return k|0}return 0}function fyQ(a){a=a|0;return}function fyR(){return}function fyS(){return c[2440186]|0}function fyT(){c[3526974]=0;return}function fyU(){c[2440186]=0;return}function fyV(){gGz(9698808|0,0|0,156|0);c[2424718]=211;c[2424717]=0;return}function fyW(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0;f=i;i=i+8|0;g=f|0;c[3526974]=e;c[3526936]=c[2440186];h=e+3|0;j=e;do{k=c[2424718]|0;l=c[2424717]|0;L1649:do{if((k&32|0)==0){m=l&3;do{if((m|0)==0){n=l&2147483647;if((n|0)==(c[1744674]|0)){c[3526974]=0}o=c[(c[2406720]|0)+(n>>>12<<2)>>2]|0;if((o|0)!=0){p=c[o+(l&4092)>>2]|0;q=1747;break}o=c[2432802]|0;if((o|0)==0){r=0;s=k;q=1749;break}p=gj[o&4095](n)|0;q=1747}else{n=l&2147483644;if((n|0)==(c[1744674]|0)){c[3526974]=0}o=c[(c[2406720]|0)+(n>>>12<<2)>>2]|0;do{if((o|0)==0){t=c[2432802]|0;if((t|0)==0){u=0;break}u=gj[t&4095](n)|0}else{u=c[o+(l&4092)>>2]|0}}while(0);o=m<<3;p=u>>>(o>>>0)|u<<32-o;q=1747}}while(0);L2237:do{if((q|0)==1747){q=0;switch(p>>>28|0){case 0:{r=p;s=c[2424718]|0;q=1749;break L2237;break};case 1:{if((c[2424718]&1073741824|0)==0){v=p;q=1765;break L2237}else{break L2237}break};case 2:{if((c[2424718]&536870912|0)==0){break L2237}else{v=p;q=1765;break L2237}break};case 3:{if((c[2424718]&536870912|0)==0){v=p;q=1765;break L2237}else{break L2237}break};case 4:{if((c[2424718]|0)<0){v=p;q=1765;break L2237}else{break L2237}break};case 5:{if((c[2424718]|0)<0){break L2237}else{v=p;q=1765;break L2237}break};case 6:{if((c[2424718]&268435456|0)==0){break L2237}else{v=p;q=1765;break L2237}break};case 7:{if((c[2424718]&268435456|0)==0){v=p;q=1765;break L2237}else{break L2237}break};case 8:{if((c[2424718]&1610612736|0)==536870912){v=p;q=1765;break L2237}else{break L2237}break};case 9:{if((c[2424718]&1610612736|0)==536870912){break L2237}else{v=p;q=1765;break L2237}break};case 10:{m=c[2424718]|0;if((m>>>31|0)==(m>>>28&1|0)){v=p;q=1765;break L2237}else{break L2237}break};case 11:{m=c[2424718]|0;if((m>>>31|0)==(m>>>28&1|0)){break L2237}else{v=p;q=1765;break L2237}break};case 12:{m=c[2424718]|0;if((m&1073741824|0)!=0){break L2237}if((m>>>31|0)==(m>>>28&1|0)){v=p;q=1765;break L2237}else{break L2237}break};case 13:{m=c[2424718]|0;if((m&1073741824|0)!=0){v=p;q=1765;break L2237}if((m>>>31|0)==(m>>>28&1|0)){break L2237}else{v=p;q=1765;break L2237}break};case 15:{break L2237;break};default:{v=p;q=1765;break L2237}}}}while(0);if((q|0)==1749){q=0;if((s&1073741824|0)!=0){v=r;q=1765}}L2258:do{if((q|0)==1765){q=0;switch(v>>>24&15|0){case 0:case 1:case 2:case 3:{if((v&268435440|0)==19922704){m=c[2424718]|0;o=c[9698808+(c[4435368+((m&15)*72|0)+((v&15)<<2)>>2]<<2)>>2]|0;c[2424717]=o;if((o&1|0)==0){break L1649}c[2424718]=m|32;c[2424717]=o-1;break L1649}if((v&234881168|0)!=144){if((v&201326592|0)!=0){break L1649}o=v&1048576;m=(o|0)==0;if((v&26214400|0)==16777216){n=v>>>22&1|16;t=c[2424718]|0;w=t&15;x=9698808+(c[4435368+(w*72|0)+(n<<2)>>2]<<2)|0;y=c[x>>2]|0;if((v&2097152|0)==0){c[9698808+(c[4435368+(w*72|0)+((v>>>12&15)<<2)>>2]<<2)>>2]=y}else{do{if((v&33554432|0)==0){z=c[9698808+(c[4435368+(w*72|0)+((v&15)<<2)>>2]<<2)>>2]|0}else{A=v>>>8&15;B=v&255;if((A|0)==0){z=B;break}C=A<<1;z=B<<32-C|B>>>(C>>>0)}}while(0);do{if((n|0)==16){do{if((w|0)==0){D=y}else{if((v&65536|0)==0){E=y}else{E=z&255|y&-256}if((v&131072|0)==0){F=E}else{F=E&-65281|z&65280}if((v&262144|0)==0){D=F;break}D=F&-16711681|z&16711680}}while(0);if((v&524288|0)==0){G=D;break}G=D&16777215|z&-134217728}else{C=t&31;if(C>>>0<17|(C|0)==31){G=y;break}if((v&65536|0)==0){H=y}else{H=z&255|y&-256}if((v&131072|0)==0){I=H}else{I=H&-65281|z&65280}if((v&262144|0)==0){J=I}else{J=I&-16711681|z&16711680}if((v&524288|0)==0){G=J;break}G=J&16777215|z&-134217728}}while(0);c[x>>2]=G|16}c[3526974]=(c[3526974]|0)+2;c[2424717]=(c[2424717]|0)+4;break L1649}c[g>>2]=0;y=v>>>21;t=y&15;do{if((v&33554432|0)==0){w=(o|0)!=0;n=fyY(v,w?g:0)|0;if(w){L=n;break}c[g>>2]=0;L=n}else{n=v>>>8&15;if((n|0)==0){c[g>>2]=c[2424718]&536870912;L=v&4095;break}else{w=v&255;C=n<<1;n=w<<32-C|w>>>(C>>>0);c[g>>2]=n&-2147483648;L=n;break}}}while(0);do{if((y&13|0)==13){M=0}else{o=v>>>16&15;if((o|0)==15){M=(c[2424717]|0)+8|0;break}else{M=c[9698808+(c[4435368+((c[2424718]&15)*72|0)+(o<<2)>>2]<<2)>>2]|0;break}}}while(0);switch(t|0){case 6:{o=M-L|0;x=c[2424718]|0;n=x>>>29&1^1;C=o-n|0;if(!m){if((M^L|0)<0){N=(C^M)>>>31<<28}else{N=0}w=L>>>31^1;B=C>>>31^1;c[2424718]=C&-2147483648|x&268435455|((o|0)==(n|0))<<30|(((B|w)&M>>>31|B&w|0)!=0?536870912:0)|N}c[2424717]=(c[2424717]|0)+4;O=C;break};case 10:case 2:{C=M-L|0;if(!m){if((M^L|0)<0){P=(C^M)>>>31<<28}else{P=0}w=L>>>31^1;B=C>>>31^1;c[2424718]=((M|0)==(L|0))<<30|C&-2147483648|(((B|w)&M>>>31|B&w|0)!=0?536870912:0)|c[2424718]&268435455|P}c[2424717]=(c[2424717]|0)+4;O=C;break};case 7:{C=L-M|0;w=c[2424718]|0;B=w>>>29&1^1;n=C-B|0;if(!m){if((M^L|0)<0){Q=(n^L)>>>31<<28}else{Q=0}o=M>>>31^1;x=n>>>31^1;c[2424718]=n&-2147483648|w&268435455|((C|0)==(B|0))<<30|(((x|o)&L>>>31|x&o|0)!=0?536870912:0)|Q}c[2424717]=(c[2424717]|0)+4;O=n;break};case 3:{n=L-M|0;if(!m){if((M^L|0)<0){R=(n^L)>>>31<<28}else{R=0}o=M>>>31^1;x=n>>>31^1;c[2424718]=((L|0)==(M|0))<<30|n&-2147483648|(((x|o)&L>>>31|x&o|0)!=0?536870912:0)|c[2424718]&268435455|R}c[2424717]=(c[2424717]|0)+4;O=n;break};case 5:{n=c[2424718]|0;o=M+L+(n>>>29&1)|0;if(!m){if((M^L|0)<0){S=0}else{S=(o^M)>>>31<<28}c[2424718]=n&268435455|(L>>>0>~M>>>0)<<29|o&-2147483648|((o|0)==0)<<30|S}c[2424717]=(c[2424717]|0)+4;O=o;break};case 11:case 4:{o=M+L|0;if(!m){if((M^L|0)<0){T=0}else{T=(o^M)>>>31<<28}c[2424718]=(L>>>0>~M>>>0)<<29|o&-2147483648|((o|0)==0)<<30|c[2424718]&268435455|T}c[2424717]=(c[2424717]|0)+4;O=o;break};case 0:case 8:{o=M&L;if(!m){c[2424718]=((o|0)==0)<<30|o&-2147483648|c[2424718]&536870911|((c[g>>2]|0)!=0)<<29}c[2424717]=(c[2424717]|0)+4;O=o;break};case 14:{o=M&~L;if(!m){c[2424718]=((o|0)==0)<<30|o&-2147483648|c[2424718]&536870911|((c[g>>2]|0)!=0)<<29}c[2424717]=(c[2424717]|0)+4;O=o;break};case 9:case 1:{o=M^L;if(!m){c[2424718]=((M|0)==(L|0))<<30|o&-2147483648|c[2424718]&536870911|((c[g>>2]|0)!=0)<<29}c[2424717]=(c[2424717]|0)+4;O=o;break};case 12:{o=M|L;if(!m){c[2424718]=((o|0)==0)<<30|o&-2147483648|c[2424718]&536870911|((c[g>>2]|0)!=0)<<29}c[2424717]=(c[2424717]|0)+4;O=o;break};case 13:{if(!m){c[2424718]=((L|0)==0)<<30|L&-2147483648|c[2424718]&536870911|((c[g>>2]|0)!=0)<<29}c[2424717]=(c[2424717]|0)+4;O=L;break};case 15:{o=~L;if(!m){c[2424718]=((L|0)==-1)<<30|o&-2147483648|c[2424718]&536870911|((c[g>>2]|0)!=0)<<29}c[2424717]=(c[2424717]|0)+4;O=o;break};default:{O=0}}o=v>>>12&15;n=(o|0)==15;if((y&12|0)==8){if(m|n^1){break L1649}c[2424717]=O;break L1649}if(n&m){c[2424717]=O;break L1649}x=c[2424718]&15;if(n){c[2424718]=c[9698808+(c[4435436+(x*72|0)>>2]<<2)>>2];c[2424717]=O;break L1649}else{c[9698808+(c[4435368+(x*72|0)+(o<<2)>>2]<<2)>>2]=O;break L1649}}if((v&96|0)==0){if((v&16777216|0)==0){do{if((v&8388608|0)==0){o=c[2424718]&15;x=ag(c[9698808+(c[4435368+(o*72|0)+((v>>>8&15)<<2)>>2]<<2)>>2]|0,c[9698808+(c[4435368+(o*72|0)+((v&15)<<2)>>2]<<2)>>2]|0)|0;if((v&2097152|0)==0){U=x}else{U=(c[9698808+(c[4435368+(o*72|0)+((v>>>12&15)<<2)>>2]<<2)>>2]|0)+x|0}c[9698808+(c[4435368+(o*72|0)+((v>>>16&15)<<2)>>2]<<2)>>2]=U;if((v&1048576|0)==0){break}c[2424718]=((U|0)==0)<<30|U&-2147483648|c[2424718]&1073741823}else{o=c[2424718]&15;x=c[9698808+(c[4435368+(o*72|0)+((v&15)<<2)>>2]<<2)>>2]|0;n=c[9698808+(c[4435368+(o*72|0)+((v>>>8&15)<<2)>>2]<<2)>>2]|0;B=v>>>16&15;C=v>>>12&15;if((v&4194304|0)==0){w=gGU(n,0,x,0)|0;A=K;V=9698808+(c[4435368+(o*72|0)+(B<<2)>>2]<<2)|0;if((v&2097152|0)==0){W=A;X=w}else{Y=gGK(c[9698808+(c[4435368+(o*72|0)+(C<<2)>>2]<<2)>>2]|0,c[V>>2]|0,w,A)|0;W=K;X=Y}Y=W;c[V>>2]=Y;c[9698808+(c[4435368+((c[2424718]&15)*72|0)+(C<<2)>>2]<<2)>>2]=X;if((v&1048576|0)==0){break}c[2424718]=((X|0)==0&(W|0)==0&1)<<30|Y&-2147483648|c[2424718]&1073741823;break}else{Y=gGU(n,(n|0)<0|0?-1:0,x,(x|0)<0|0?-1:0)|0;x=K;n=9698808+(c[4435368+(o*72|0)+(B<<2)>>2]<<2)|0;if((v&2097152|0)==0){Z=x;_=Y}else{B=gGK(c[9698808+(c[4435368+(o*72|0)+(C<<2)>>2]<<2)>>2]|0,c[n>>2]|0,Y,x)|0;Z=K;_=B}B=Z;c[n>>2]=B;c[9698808+(c[4435368+((c[2424718]&15)*72|0)+(C<<2)>>2]<<2)>>2]=_;if((v&1048576|0)==0){break}c[2424718]=((_|0)==0&(Z|0)==0&1)<<30|B&-2147483648|c[2424718]&1073741823;break}}}while(0);c[2424717]=(c[2424717]|0)+4;break L1649}m=c[2424718]&15;y=c[9698808+(c[4435368+(m*72|0)+((v>>>16&15)<<2)>>2]<<2)>>2]|0;t=c[9698808+(c[4435368+(m*72|0)+((v&15)<<2)>>2]<<2)>>2]|0;m=v>>>12&15;if((v&4194304|0)==0){B=y&3;do{if((B|0)==0){C=y&2147483647;n=c[(c[2406724]|0)+(C>>>12<<2)>>2]|0;if((n|0)!=0){$=c[n+(y&4092)>>2]|0;break}n=c[2432802]|0;if((n|0)==0){$=0;break}$=gj[n&4095](C)|0}else{C=y&2147483644;n=c[(c[2406724]|0)+(C>>>12<<2)>>2]|0;do{if((n|0)==0){x=c[2432802]|0;if((x|0)==0){aa=0;break}aa=gj[x&4095](C)|0}else{aa=c[n+(y&4092)>>2]|0}}while(0);n=B<<3;$=aa>>>(n>>>0)|aa<<32-n}}while(0);B=y&2147483644;n=c[(c[2406722]|0)+(B>>>12<<2)>>2]|0;do{if((n|0)==0){C=c[2430388]|0;if((C|0)==0){break}gg[C&4095](B,t)}else{c[n+(y&4092)>>2]=t}}while(0);c[9698808+(c[4435368+((c[2424718]&15)*72|0)+(m<<2)>>2]<<2)>>2]=$}else{n=y&2147483647;B=n>>>12;C=c[(c[2406724]|0)+(B<<2)>>2]|0;do{if((C|0)==0){x=c[2432806]|0;if((x|0)==0){ab=0;break}ab=gj[x&4095](n)|0}else{ab=a[C+(y&4095)|0]|0}}while(0);C=ab&255;x=t&255;Y=c[(c[2406722]|0)+(B<<2)>>2]|0;do{if((Y|0)==0){o=c[2430392]|0;if((o|0)==0){break}gg[o&4095](n,x)}else{a[Y+(y&4095)|0]=x}}while(0);c[9698808+(c[4435368+((c[2424718]&15)*72|0)+(m<<2)>>2]<<2)>>2]=C}c[2424717]=(c[2424717]|0)+4;c[3526974]=(c[3526974]|0)-1;break L1649}if((v&4194304|0)==0){ac=c[9698808+(c[4435368+((c[2424718]&15)*72|0)+((v&15)<<2)>>2]<<2)>>2]|0}else{ac=v>>>8<<4&240|v&15}x=v>>>16&15;y=(v&16777216|0)!=0;do{if(y){Y=9698808+(c[4435368+((c[2424718]&15)*72|0)+(x<<2)>>2]<<2)|0;n=(c[Y>>2]|0)+((v&8388608|0)==0?-ac|0:ac)|0;if((v&2097152|0)==0){ad=(x|0)==15?n+8|0:n;break}else{c[Y>>2]=n;ad=n;break}}else{if((x|0)==15){ad=(c[2424717]|0)+8|0;break}else{ad=c[9698808+(c[4435368+((c[2424718]&15)*72|0)+(x<<2)>>2]<<2)>>2]|0;break}}}while(0);C=v>>>12&15;do{if((v&1048576|0)==0){if((C|0)==15){ae=(c[2424717]|0)+12|0}else{ae=c[9698808+(c[4435368+((c[2424718]&15)*72|0)+(C<<2)>>2]<<2)>>2]|0}m=ae&65535;n=ad&2147483646;Y=c[(c[2406722]|0)+(n>>>12<<2)>>2]|0;do{if((Y|0)==0){B=c[2430384]|0;if((B|0)==0){break}gg[B&4095](n,m)}else{b[Y+(ad&4094)>>1]=m}}while(0);if((x|0)!=15){c[2424717]=(c[2424717]|0)+4}c[3526974]=(c[3526974]|0)+1}else{if((v&64|0)==0){m=(C|0)==15;Y=ad&2147483646;n=c[(c[2406724]|0)+(Y>>>12<<2)>>2]|0;do{if((n|0)==0){if((c[2432798]|0)==0){af=0;break}if(!((Y|0)==1207959552|(Y|0)==1207959554)){af=0;break}af=d[9753376]|0}else{af=b[n+(ad&4094)>>1]|0}}while(0);if((ad&1|0)==0){ah=af}else{ah=ga(af|0)|0}n=ah&65535;if(m){c[2424717]=n+8;break}else{c[9698808+(c[4435368+((c[2424718]&15)*72|0)+(C<<2)>>2]<<2)>>2]=n;c[2424717]=(c[2424717]|0)+4;break}}if((v&32|0)==0){n=ad&2147483647;Y=c[(c[2406724]|0)+(n>>>12<<2)>>2]|0;do{if((Y|0)==0){B=c[2432806]|0;if((B|0)==0){ai=0;break}ai=gj[B&4095](n)|0}else{ai=a[Y+(ad&4095)|0]|0}}while(0);Y=ai&255;aj=((Y&128|0)!=0?-256:0)|Y}else{Y=ad&2147483646;n=c[(c[2406724]|0)+(Y>>>12<<2)>>2]|0;do{if((n|0)==0){if((c[2432798]|0)==0){ak=0;break}if(!((Y|0)==1207959552|(Y|0)==1207959554)){ak=0;break}ak=d[9753376]|0}else{ak=b[n+(ad&4094)>>1]|0}}while(0);if((ad&1|0)==0){al=ak}else{al=ga(ak|0)|0}n=al&65535;aj=n<<16>>31<<16|n}if((C|0)==15){c[2424717]=aj+8;c[3526974]=(c[3526974]|0)-2;break}else{c[9698808+(c[4435368+((c[2424718]&15)*72|0)+(C<<2)>>2]<<2)>>2]=aj;c[2424717]=(c[2424717]|0)+4;break}}}while(0);if(y){break L1649}n=v&8388608;Y=(C|0)==(x|0);if((n|0)==0){if(Y){break L1649}c[9698808+(c[4435368+((c[2424718]&15)*72|0)+(x<<2)>>2]<<2)>>2]=ad-ac;m=v&2097152;if((m|0)==0){break L1649}B=c[2424717]|0;t=m>>>21;bw(389368,(am=i,i=i+32|0,c[am>>2]=B,c[am+8>>2]=0,c[am+16>>2]=t,c[am+24>>2]=0,am)|0)|0;i=am;break L1649}if(Y){break L1649}Y=v&2097152;if((Y|0)!=0){t=c[2424717]|0;B=Y>>>21;Y=n>>>23;bw(401360,(am=i,i=i+32|0,c[am>>2]=t,c[am+8>>2]=0,c[am+16>>2]=B,c[am+24>>2]=Y,am)|0)|0;i=am}c[9698808+(c[4435368+((c[2424718]&15)*72|0)+(x<<2)>>2]<<2)>>2]=ad+ac;break L1649;break};case 4:case 5:case 6:case 7:{if((v&33554432|0)==0){an=v&4095}else{an=fyY(v,0)|0}Y=v>>>16&15;B=(v&16777216|0)!=0;do{if(B){t=9698808+(c[4435368+((c[2424718]&15)*72|0)+(Y<<2)>>2]<<2)|0;n=(c[t>>2]|0)+((v&8388608|0)==0?-an|0:an)|0;if((v&2097152|0)==0){ao=(Y|0)==15?n+8|0:n;break}else{c[t>>2]=n;ao=n;break}}else{if((Y|0)==15){ao=(c[2424717]|0)+8|0;break}else{ao=c[9698808+(c[4435368+((c[2424718]&15)*72|0)+(Y<<2)>>2]<<2)>>2]|0;break}}}while(0);x=v>>>12&15;C=(v&4194304|0)!=0;do{if((v&1048576|0)==0){do{if(C){y=c[9698808+(c[4435368+((c[2424718]&15)*72|0)+(x<<2)>>2]<<2)>>2]&255;n=ao&2147483647;t=c[(c[2406722]|0)+(n>>>12<<2)>>2]|0;if((t|0)!=0){a[t+(ao&4095)|0]=y;break}t=c[2430392]|0;if((t|0)==0){break}gg[t&4095](n,y)}else{if((x|0)==15){ap=(c[2424717]|0)+12|0}else{ap=c[9698808+(c[4435368+((c[2424718]&15)*72|0)+(x<<2)>>2]<<2)>>2]|0}y=ao&2147483644;n=c[(c[2406722]|0)+(y>>>12<<2)>>2]|0;if((n|0)!=0){c[n+(ao&4092)>>2]=ap;break}n=c[2430388]|0;if((n|0)==0){break}gg[n&4095](y,ap)}}while(0);c[3526974]=(c[3526974]|0)+1}else{if(C){y=ao&2147483647;n=c[(c[2406724]|0)+(y>>>12<<2)>>2]|0;do{if((n|0)==0){t=c[2432806]|0;if((t|0)==0){aq=0;break}aq=gj[t&4095](y)|0}else{aq=a[n+(ao&4095)|0]|0}}while(0);c[9698808+(c[4435368+((c[2424718]&15)*72|0)+(x<<2)>>2]<<2)>>2]=aq&255;break}n=(x|0)==15;y=ao&3;do{if((y|0)==0){t=ao&2147483647;m=c[(c[2406724]|0)+(t>>>12<<2)>>2]|0;if((m|0)!=0){ar=c[m+(ao&4092)>>2]|0;break}m=c[2432802]|0;if((m|0)==0){ar=0;break}ar=gj[m&4095](t)|0}else{t=ao&2147483644;m=c[(c[2406724]|0)+(t>>>12<<2)>>2]|0;do{if((m|0)==0){o=c[2432802]|0;if((o|0)==0){as=0;break}as=gj[o&4095](t)|0}else{as=c[m+(ao&4092)>>2]|0}}while(0);m=y<<3;ar=as>>>(m>>>0)|as<<32-m}}while(0);if(n){c[2424717]=ar-4;c[3526974]=(c[3526974]|0)-2;break}else{c[9698808+(c[4435368+((c[2424718]&15)*72|0)+(x<<2)>>2]<<2)>>2]=ar;break}}}while(0);do{if(!B){C=v&8388608;y=(x|0)==(Y|0);if((C|0)==0){if(y){break}c[9698808+(c[4435368+((c[2424718]&15)*72|0)+(Y<<2)>>2]<<2)>>2]=ao-an;m=v&2097152;if((m|0)==0){break}t=c[2424717]|0;o=m>>>21;bw(389368,(am=i,i=i+32|0,c[am>>2]=t,c[am+8>>2]=0,c[am+16>>2]=o,c[am+24>>2]=0,am)|0)|0;i=am;break}if(y){break}y=v&2097152;if((y|0)!=0){o=c[2424717]|0;t=y>>>21;y=C>>>23;bw(401360,(am=i,i=i+32|0,c[am>>2]=o,c[am+8>>2]=0,c[am+16>>2]=t,c[am+24>>2]=y,am)|0)|0;i=am}c[9698808+(c[4435368+((c[2424718]&15)*72|0)+(Y<<2)>>2]<<2)>>2]=ao+an}}while(0);c[2424717]=(c[2424717]|0)+4;break L1649;break};case 8:case 9:{Y=v>>>16&15;x=c[2424718]|0;B=x&15;y=c[9698808+(c[4435368+(B*72|0)+(Y<<2)>>2]<<2)>>2]|0;c[3526974]=(c[3526974]|0)+3;do{if((v&1048576|0)==0){t=(v&32768|0)!=0;if(t){c[2424717]=(c[2424717]|0)+12}o=(v&16777216|0)!=0;do{if((v&8388608|0)==0){C=o?y:y+4|0;if((v&4227072|0)==4194304){c[2424718]=x&-16;m=c[2424717]|0;bw(424648,(am=i,i=i+8|0,c[am>>2]=m,am)|0)|0;i=am;m=v&65535;V=C;A=15;w=0;while(1){if((m&1<<A|0)==0){at=w;au=V}else{av=V-4|0;aw=c[9698808+(c[4435368+((c[2424718]&15)*72|0)+(A<<2)>>2]<<2)>>2]|0;ax=av&2147483644;ay=c[(c[2406722]|0)+(ax>>>12<<2)>>2]|0;do{if((ay|0)==0){az=c[2430388]|0;if((az|0)==0){break}gg[az&4095](ax,aw)}else{c[ay+(av&4092)>>2]=aw}}while(0);at=w+1|0;au=av}if((A|0)>0){V=au;A=A-1|0;w=at}else{break}}c[2424718]=c[2424718]&-16|B;aA=at}else{w=v&65535;A=C;V=15;m=0;while(1){if((w&1<<V|0)==0){aB=m;aC=A}else{aw=A-4|0;ay=c[9698808+(c[4435368+((c[2424718]&15)*72|0)+(V<<2)>>2]<<2)>>2]|0;ax=aw&2147483644;az=c[(c[2406722]|0)+(ax>>>12<<2)>>2]|0;do{if((az|0)==0){aD=c[2430388]|0;if((aD|0)==0){break}gg[aD&4095](ax,ay)}else{c[az+(aw&4092)>>2]=ay}}while(0);aB=m+1|0;aC=aw}if((V|0)>0){A=aC;V=V-1|0;m=aB}else{aA=aB;break}}}if((v&2097152|0)==0){aE=aA;break}m=9698808+(c[4435368+((c[2424718]&15)*72|0)+(Y<<2)>>2]<<2)|0;c[m>>2]=(c[m>>2]|0)-(aA<<2);aE=aA}else{m=o?y:y-4|0;if((v&4227072|0)==4194304){c[2424718]=x&-16;V=c[2424717]|0;bw(424648,(am=i,i=i+8|0,c[am>>2]=V,am)|0)|0;i=am;V=v&65535;A=m;w=0;C=0;while(1){if((V&1<<w|0)==0){aF=C;aG=A}else{ay=A+4|0;az=c[9698808+(c[4435368+((c[2424718]&15)*72|0)+(w<<2)>>2]<<2)>>2]|0;ax=ay&2147483644;av=c[(c[2406722]|0)+(ax>>>12<<2)>>2]|0;do{if((av|0)==0){aD=c[2430388]|0;if((aD|0)==0){break}gg[aD&4095](ax,az)}else{c[av+(ay&4092)>>2]=az}}while(0);aF=C+1|0;aG=ay}az=w+1|0;if((az|0)<16){A=aG;w=az;C=aF}else{break}}c[2424718]=c[2424718]&-16|B;aH=aF}else{C=v&65535;w=m;A=0;V=0;while(1){if((C&1<<A|0)==0){aI=V;aJ=w}else{az=w+4|0;av=c[9698808+(c[4435368+((c[2424718]&15)*72|0)+(A<<2)>>2]<<2)>>2]|0;ax=az&2147483644;aw=c[(c[2406722]|0)+(ax>>>12<<2)>>2]|0;do{if((aw|0)==0){aD=c[2430388]|0;if((aD|0)==0){break}gg[aD&4095](ax,av)}else{c[aw+(az&4092)>>2]=av}}while(0);aI=V+1|0;aJ=az}av=A+1|0;if((av|0)<16){w=aJ;A=av;V=aI}else{aH=aI;break}}}if((v&2097152|0)==0){aE=aH;break}V=9698808+(c[4435368+((c[2424718]&15)*72|0)+(Y<<2)>>2]<<2)|0;c[V>>2]=(c[V>>2]|0)+(aH<<2);aE=aH}}while(0);if(t){c[2424717]=(c[2424717]|0)-12}c[3526974]=-4-aE+(c[3526974]|0)}else{o=(v&16777216|0)!=0;if((v&8388608|0)!=0){n=o?y:y-4|0;V=(v&4194304|0)==0;A=(v&32768|0)==0;if((v&4227072|0)==4194304){c[2424718]=x&-16;w=c[2424717]|0;bw(424648,(am=i,i=i+8|0,c[am>>2]=w,am)|0)|0;i=am;w=v&65535;C=n&-4;m=0;av=0;while(1){if((w&1<<m|0)==0){aK=av;aL=C}else{aw=(m|0)==15;ax=C+4|0;ay=ax&3;do{if((ay|0)==0){aD=ax&2147483647;aM=c[(c[2406724]|0)+(aD>>>12<<2)>>2]|0;if((aM|0)!=0){aN=c[aM+(ax&4092)>>2]|0;break}aM=c[2432802]|0;if((aM|0)==0){aN=0;break}aN=gj[aM&4095](aD)|0}else{aD=ax&2147483644;aM=c[(c[2406724]|0)+(aD>>>12<<2)>>2]|0;do{if((aM|0)==0){aO=c[2432802]|0;if((aO|0)==0){aP=0;break}aP=gj[aO&4095](aD)|0}else{aP=c[aM+(ax&4092)>>2]|0}}while(0);aM=ay<<3;aN=aP>>>(aM>>>0)|aP<<32-aM}}while(0);ay=c[2424718]&15;if(aw){c[9698808+(c[4435428+(ay*72|0)>>2]<<2)>>2]=aN}else{c[9698808+(c[4435368+(ay*72|0)+(m<<2)>>2]<<2)>>2]=aN}aK=av+1|0;aL=ax}ay=m+1|0;if((ay|0)<16){C=aL;m=ay;av=aK}else{break}}c[2424718]=c[2424718]&-16|B;aQ=aK}else{av=v&65535;m=n&-4;C=0;w=0;while(1){if((av&1<<C|0)==0){aR=w;aS=m}else{t=(C|0)==15;ay=m+4|0;aM=ay&3;do{if((aM|0)==0){aD=ay&2147483647;az=c[(c[2406724]|0)+(aD>>>12<<2)>>2]|0;if((az|0)!=0){aT=c[az+(ay&4092)>>2]|0;break}az=c[2432802]|0;if((az|0)==0){aT=0;break}aT=gj[az&4095](aD)|0}else{aD=ay&2147483644;az=c[(c[2406724]|0)+(aD>>>12<<2)>>2]|0;do{if((az|0)==0){aO=c[2432802]|0;if((aO|0)==0){aU=0;break}aU=gj[aO&4095](aD)|0}else{aU=c[az+(ay&4092)>>2]|0}}while(0);az=aM<<3;aT=aU>>>(az>>>0)|aU<<32-az}}while(0);aM=c[2424718]&15;if(t){c[9698808+(c[4435428+(aM*72|0)>>2]<<2)>>2]=aT}else{c[9698808+(c[4435368+(aM*72|0)+(C<<2)>>2]<<2)>>2]=aT}aR=w+1|0;aS=ay}aM=C+1|0;if((aM|0)<16){m=aS;C=aM;w=aR}else{aQ=aR;break}}}if((v&2097152|0)!=0){w=9698808+(c[4435368+((c[2424718]&15)*72|0)+(Y<<2)>>2]<<2)|0;c[w>>2]=(c[w>>2]|0)+(aQ<<2)}do{if(!A){c[2424717]=(c[2424717]|0)-4;if(V){break}c[2424718]=c[9698808+(c[4435436+((c[2424718]&15)*72|0)>>2]<<2)>>2]}}while(0);c[3526974]=(c[3526974]|0)-1;break}V=o?y:y+4|0;A=(v&4194304|0)==0;w=(v&32768|0)==0;if((v&4227072|0)==4194304){c[2424718]=x&-16;C=c[2424717]|0;bw(424648,(am=i,i=i+8|0,c[am>>2]=C,am)|0)|0;i=am;C=v&65535;m=V&-4;av=15;n=0;while(1){if((C&1<<av|0)==0){aV=n;aW=m}else{aM=(av|0)==15;ax=m-4|0;aw=ax&3;do{if((aw|0)==0){az=ax&2147483647;aD=c[(c[2406724]|0)+(az>>>12<<2)>>2]|0;if((aD|0)!=0){aX=c[aD+(ax&4092)>>2]|0;break}aD=c[2432802]|0;if((aD|0)==0){aX=0;break}aX=gj[aD&4095](az)|0}else{az=ax&2147483644;aD=c[(c[2406724]|0)+(az>>>12<<2)>>2]|0;do{if((aD|0)==0){aO=c[2432802]|0;if((aO|0)==0){aY=0;break}aY=gj[aO&4095](az)|0}else{aY=c[aD+(ax&4092)>>2]|0}}while(0);aD=aw<<3;aX=aY>>>(aD>>>0)|aY<<32-aD}}while(0);aw=c[2424718]&15;if(aM){c[9698808+(c[4435428+(aw*72|0)>>2]<<2)>>2]=aX}else{c[9698808+(c[4435368+(aw*72|0)+(av<<2)>>2]<<2)>>2]=aX}aV=n+1|0;aW=ax}if((av|0)>0){m=aW;av=av-1|0;n=aV}else{break}}c[2424718]=c[2424718]&-16|B;aZ=aV}else{n=v&65535;av=V&-4;m=15;C=0;while(1){if((n&1<<m|0)==0){a_=C;a$=av}else{o=(m|0)==15;aw=av-4|0;ay=aw&3;do{if((ay|0)==0){t=aw&2147483647;aD=c[(c[2406724]|0)+(t>>>12<<2)>>2]|0;if((aD|0)!=0){a0=c[aD+(aw&4092)>>2]|0;break}aD=c[2432802]|0;if((aD|0)==0){a0=0;break}a0=gj[aD&4095](t)|0}else{t=aw&2147483644;aD=c[(c[2406724]|0)+(t>>>12<<2)>>2]|0;do{if((aD|0)==0){az=c[2432802]|0;if((az|0)==0){a1=0;break}a1=gj[az&4095](t)|0}else{a1=c[aD+(aw&4092)>>2]|0}}while(0);aD=ay<<3;a0=a1>>>(aD>>>0)|a1<<32-aD}}while(0);ay=c[2424718]&15;if(o){c[9698808+(c[4435428+(ay*72|0)>>2]<<2)>>2]=a0}else{c[9698808+(c[4435368+(ay*72|0)+(m<<2)>>2]<<2)>>2]=a0}a_=C+1|0;a$=aw}if((m|0)>0){av=a$;m=m-1|0;C=a_}else{aZ=a_;break}}}if((v&2097152|0)!=0){if((Y|0)==15){C=c[2424717]|0;bw(411872,(am=i,i=i+8|0,c[am>>2]=C,am)|0)|0;i=am}C=9698808+(c[4435368+((c[2424718]&15)*72|0)+(Y<<2)>>2]<<2)|0;c[C>>2]=(c[C>>2]|0)-(aZ<<2)}if(w){a2=c[3526974]|0}else{c[2424717]=(c[2424717]|0)-4;if(!A){c[2424718]=c[9698808+(c[4435436+((c[2424718]&15)*72|0)>>2]<<2)>>2]}C=(c[3526974]|0)-1|0;c[3526974]=C;a2=C}c[3526974]=-2-aZ+a2}}while(0);c[2424717]=(c[2424717]|0)+4;break L1649;break};case 10:case 11:{Y=v<<2;B=Y&67108860;if((v&16777216|0)!=0){c[9698808+(c[4435424+((c[2424718]&15)*72|0)>>2]<<2)>>2]=(c[2424717]|0)+4}if((Y&33554432|0)==0){a3=B+8+(c[2424717]|0)|0}else{a3=B-67108856+(c[2424717]|0)|0}c[2424717]=a3;break L1649;break};case 12:case 13:{B=v>>>16&15;Y=c[9698808+(c[4435368+((c[2424718]&15)*72|0)+(B<<2)>>2]<<2)>>2]|0;x=c[2424717]|0;if((v&1048576|0)==0){bw(434992,(am=i,i=i+8|0,c[am>>2]=x,am)|0)|0;i=am}else{bw(447056,(am=i,i=i+8|0,c[am>>2]=x,am)|0)|0;i=am}if((v&2097152|0)==0){c[9698808+(c[4435368+((c[2424718]&15)*72|0)+(B<<2)>>2]<<2)>>2]=Y}c[2424717]=(c[2424717]|0)+4;break L1649;break};case 14:{do{if((v&16|0)==0){Y=c[2424717]|0;bw(480960,(am=i,i=i+8|0,c[am>>2]=Y,am)|0)|0;i=am}else{Y=c[2424717]|0;if((v&1048576|0)==0){bw(457312,(am=i,i=i+8|0,c[am>>2]=Y,am)|0)|0;i=am;break}else{bw(468560,(am=i,i=i+8|0,c[am>>2]=Y,am)|0)|0;i=am;break}}}while(0);c[2424717]=(c[2424717]|0)+4;break L1649;break};case 15:{a[9698961]=1;fyX();break L1649;break};default:{a[9698961]=1;fyX();c[3526974]=(c[3526974]|0)-1;bw(545832,(am=i,i=i+8|0,c[am>>2]=l-4,am)|0)|0;i=am;break L2258}}}}while(0);c[2424717]=(c[2424717]|0)+4;c[3526974]=(c[3526974]|0)+2}else{Y=l&2147483646;if((Y|0)==(c[1744674]|0)){c[3526974]=0;a4=0}else{a4=j}B=c[(c[2406720]|0)+(Y>>>12<<2)>>2]|0;do{if((B|0)==0){if((c[2432798]|0)==0){a5=0;break}if(!((Y|0)==1207959552|(Y|0)==1207959554)){a5=0;break}a5=d[9753376]|0}else{a5=b[B+(l&4094)>>1]|0}}while(0);B=a5&65535;Y=B>>>8;c[3526974]=(c[6991464+(Y<<2)>>2]|0)-3+a4;switch(B>>>12|0){case 1:{if((B&2048|0)==0){x=B&7;y=c[9698808+(c[4435368+((k&15)*72|0)+((B>>>3&7)<<2)>>2]<<2)>>2]|0;C=B>>>6&31;m=(C|0)==0;av=m?32:C;if(m){m=(y|0)<0?k|536870912:k&-536870913;c[2424718]=m;c[9698808+(c[4435368+((m&15)*72|0)+(x<<2)>>2]<<2)>>2]=y>>31}else{m=(y&1<<av-1|0)==0?k&-536870913:k|536870912;c[2424718]=m;if((y|0)<0){a6=y>>>(av>>>0)|-1<<32-av}else{a6=y>>>(av>>>0)}c[9698808+(c[4435368+((m&15)*72|0)+(x<<2)>>2]<<2)>>2]=a6}m=c[2424718]|0;av=m&1073741823;c[2424718]=av;y=c[9698808+(c[4435368+((m&15)*72|0)+(x<<2)>>2]<<2)>>2]|0;c[2424718]=y&-2147483648|av|((y|0)==0)<<30;c[2424717]=(c[2424717]|0)+2;break L1649}y=B>>>9&3;if((y|0)==0){av=k&15;x=c[9698808+(c[4435368+(av*72|0)+((B>>>6&7)<<2)>>2]<<2)>>2]|0;m=c[9698808+(c[4435368+(av*72|0)+((B>>>3&7)<<2)>>2]<<2)>>2]|0;C=B&7;c[9698808+(c[4435368+(av*72|0)+(C<<2)>>2]<<2)>>2]=m+x;av=c[2424718]|0;n=c[9698808+(c[4435368+((av&15)*72|0)+(C<<2)>>2]<<2)>>2]|0;if((m^x|0)<0){a7=0}else{a7=(n^m)>>>31<<28}c[2424718]=(x>>>0>~m>>>0)<<29|av&268435455|a7|n&-2147483648|((n|0)==0)<<30;c[2424717]=(c[2424717]|0)+2;break L1649}else if((y|0)==1){n=k&15;av=c[9698808+(c[4435368+(n*72|0)+((B>>>6&7)<<2)>>2]<<2)>>2]|0;m=c[9698808+(c[4435368+(n*72|0)+((B>>>3&7)<<2)>>2]<<2)>>2]|0;x=B&7;c[9698808+(c[4435368+(n*72|0)+(x<<2)>>2]<<2)>>2]=m-av;n=c[2424718]|0;C=c[9698808+(c[4435368+((n&15)*72|0)+(x<<2)>>2]<<2)>>2]|0;if((m^av|0)<0){a8=(C^m)>>>31<<28}else{a8=0}x=av>>>31^1;av=C>>>31^1;c[2424718]=a8|n&268435455|C&-2147483648|((C|0)==0)<<30|(((av|x)&m>>>31|av&x|0)!=0?536870912:0);c[2424717]=(c[2424717]|0)+2;break L1649}else if((y|0)==2){x=B>>>6&7;av=k&15;m=c[9698808+(c[4435368+(av*72|0)+((B>>>3&7)<<2)>>2]<<2)>>2]|0;C=B&7;c[9698808+(c[4435368+(av*72|0)+(C<<2)>>2]<<2)>>2]=m+x;av=c[2424718]|0;n=c[9698808+(c[4435368+((av&15)*72|0)+(C<<2)>>2]<<2)>>2]|0;if((m|0)<0){a9=0}else{a9=(n^m)>>>31<<28}c[2424718]=(x>>>0>~m>>>0)<<29|av&268435455|a9|n&-2147483648|((n|0)==0)<<30;c[2424717]=(c[2424717]|0)+2;break L1649}else if((y|0)==3){y=k&15;n=c[9698808+(c[4435368+(y*72|0)+((B>>>3&7)<<2)>>2]<<2)>>2]|0;av=B&7;c[9698808+(c[4435368+(y*72|0)+(av<<2)>>2]<<2)>>2]=n-(B>>>6&7);y=c[2424718]|0;m=c[9698808+(c[4435368+((y&15)*72|0)+(av<<2)>>2]<<2)>>2]|0;if((n|0)<0){ba=(m^n)>>>31<<28}else{ba=0}c[2424718]=ba|y&268435455|m&-2147483648|((m|0)==0)<<30|((m>>>31^1|n>>>31|0)!=0?536870912:0);c[2424717]=(c[2424717]|0)+2;break L1649}else{bw(164376,(am=i,i=i+16|0,c[am>>2]=l,c[am+8>>2]=B,am)|0)|0;i=am;c[2424717]=(c[2424717]|0)+2;break L1649}break};case 0:{c[2424718]=k&1073741823;n=B&7;m=k&15;y=c[9698808+(c[4435368+(m*72|0)+((B>>>3&7)<<2)>>2]<<2)>>2]|0;av=B>>>6&31;x=(av|0)!=0;if((B&2048|0)==0){do{if(x){c[9698808+(c[4435368+(m*72|0)+(n<<2)>>2]<<2)>>2]=y<<av;C=c[2424718]|0;if((y&1<<32-av|0)==0){V=C&-536870913;c[2424718]=V;bb=V;break}else{V=C|536870912;c[2424718]=V;bb=V;break}}else{c[9698808+(c[4435368+(m*72|0)+(n<<2)>>2]<<2)>>2]=y;bb=c[2424718]|0}}while(0);V=bb&1073741823;c[2424718]=V;C=c[9698808+(c[4435368+((bb&15)*72|0)+(n<<2)>>2]<<2)>>2]|0;c[2424718]=C&-2147483648|V|((C|0)==0)<<30;c[2424717]=(c[2424717]|0)+2;break L1649}do{if(x){c[9698808+(c[4435368+(m*72|0)+(n<<2)>>2]<<2)>>2]=y>>>(av>>>0);C=c[2424718]|0;if((y&1<<av-1|0)==0){V=C&-536870913;c[2424718]=V;bc=V;break}else{V=C|536870912;c[2424718]=V;bc=V;break}}else{c[9698808+(c[4435368+(m*72|0)+(n<<2)>>2]<<2)>>2]=0;V=c[2424718]|0;if((y|0)<0){C=V|536870912;c[2424718]=C;bc=C;break}else{C=V&-536870913;c[2424718]=C;bc=C;break}}}while(0);y=bc&1073741823;c[2424718]=y;m=c[9698808+(c[4435368+((bc&15)*72|0)+(n<<2)>>2]<<2)>>2]|0;c[2424718]=m&-2147483648|y|((m|0)==0)<<30;c[2424717]=(c[2424717]|0)+2;break L1649;break};case 2:{m=Y&7;if((B&2048|0)==0){c[9698808+(c[4435368+((k&15)*72|0)+(m<<2)>>2]<<2)>>2]=B&255;y=c[2424718]|0;av=y&1073741823;c[2424718]=av;x=c[9698808+(c[4435368+((y&15)*72|0)+(m<<2)>>2]<<2)>>2]|0;c[2424718]=x&-2147483648|av|((x|0)==0)<<30;c[2424717]=(c[2424717]|0)+2;break L1649}x=c[9698808+(c[4435368+((k&15)*72|0)+(m<<2)>>2]<<2)>>2]|0;m=B&255;av=x-m|0;if((x|0)<0){bd=(av^x)>>>31<<28}else{bd=0}c[2424718]=av&-2147483648|k&268435455|((x|0)==(m|0))<<30|((av>>>31^1|x>>>31|0)!=0?536870912:0)|bd;c[2424717]=l+2;break L1649;break};case 3:{x=9698808+(c[4435368+((k&15)*72|0)+((Y&7)<<2)>>2]<<2)|0;av=c[x>>2]|0;m=B&255;if((B&2048|0)==0){y=av+m|0;c[x>>2]=y;if((av|0)<0){be=0}else{be=(y^av)>>>31<<28}c[2424718]=(m>>>0>~av>>>0)<<29|y&-2147483648|((y|0)==0)<<30|c[2424718]&268435455|be;c[2424717]=(c[2424717]|0)+2;break L1649}else{y=av-m|0;c[x>>2]=y;if((av|0)<0){bf=(y^av)>>>31<<28}else{bf=0}c[2424718]=((av|0)==(m|0))<<30|y&-2147483648|((y>>>31^1|av>>>31|0)!=0?536870912:0)|c[2424718]&268435455|bf;c[2424717]=(c[2424717]|0)+2;break L1649}break};case 4:{av=B>>>10&3;if((av|0)==0){y=B>>>6&15;switch(y|0){case 0:{m=B&7;x=k&15;C=9698808+(c[4435368+(x*72|0)+(m<<2)>>2]<<2)|0;c[C>>2]=c[9698808+(c[4435368+(x*72|0)+((B>>>3&7)<<2)>>2]<<2)>>2]&c[C>>2];C=c[2424718]|0;x=C&1073741823;c[2424718]=x;V=c[9698808+(c[4435368+((C&15)*72|0)+(m<<2)>>2]<<2)>>2]|0;c[2424718]=V&-2147483648|x|((V|0)==0)<<30;c[2424717]=(c[2424717]|0)+2;break L1649;break};case 1:{V=B&7;x=k&15;m=9698808+(c[4435368+(x*72|0)+(V<<2)>>2]<<2)|0;c[m>>2]=c[9698808+(c[4435368+(x*72|0)+((B>>>3&7)<<2)>>2]<<2)>>2]^c[m>>2];m=c[2424718]|0;x=m&1073741823;c[2424718]=x;C=c[9698808+(c[4435368+((m&15)*72|0)+(V<<2)>>2]<<2)>>2]|0;c[2424718]=C&-2147483648|x|((C|0)==0)<<30;c[2424717]=(c[2424717]|0)+2;break L1649;break};case 2:{C=B&7;x=k&15;V=9698808+(c[4435368+(x*72|0)+(C<<2)>>2]<<2)|0;m=c[V>>2]|0;ay=c[9698808+(c[4435368+(x*72|0)+((B>>>3&7)<<2)>>2]<<2)>>2]&255;do{if((ay|0)==0){bg=k}else{if(ay>>>0<32){c[V>>2]=m<<ay;x=c[2424718]|0;if((1<<32-ay&m|0)==0){ax=x&-536870913;c[2424718]=ax;bg=ax;break}else{ax=x|536870912;c[2424718]=ax;bg=ax;break}}c[V>>2]=0;if((ay|0)!=32){ax=c[2424718]&-536870913;c[2424718]=ax;bg=ax;break}ax=c[2424718]|0;if((m&1|0)==0){x=ax&-536870913;c[2424718]=x;bg=x;break}else{x=ax|536870912;c[2424718]=x;bg=x;break}}}while(0);m=bg&1073741823;c[2424718]=m;ay=c[9698808+(c[4435368+((bg&15)*72|0)+(C<<2)>>2]<<2)>>2]|0;c[2424718]=ay&-2147483648|m|((ay|0)==0)<<30;c[2424717]=(c[2424717]|0)+2;break L1649;break};case 3:{ay=B&7;m=k&15;V=9698808+(c[4435368+(m*72|0)+(ay<<2)>>2]<<2)|0;n=c[V>>2]|0;x=c[9698808+(c[4435368+(m*72|0)+((B>>>3&7)<<2)>>2]<<2)>>2]&255;do{if((x|0)==0){bh=k}else{if(x>>>0<32){c[V>>2]=n>>>(x>>>0);m=c[2424718]|0;if((1<<x-1&n|0)==0){ax=m&-536870913;c[2424718]=ax;bh=ax;break}else{ax=m|536870912;c[2424718]=ax;bh=ax;break}}c[V>>2]=0;if((x|0)!=32){ax=c[2424718]&-536870913;c[2424718]=ax;bh=ax;break}ax=c[2424718]|0;if((n|0)<0){m=ax|536870912;c[2424718]=m;bh=m;break}else{m=ax&-536870913;c[2424718]=m;bh=m;break}}}while(0);n=bh&1073741823;c[2424718]=n;x=c[9698808+(c[4435368+((bh&15)*72|0)+(ay<<2)>>2]<<2)>>2]|0;c[2424718]=x&-2147483648|n|((x|0)==0)<<30;c[2424717]=(c[2424717]|0)+2;break L1649;break};case 4:{x=B&7;n=k&15;V=c[9698808+(c[4435368+(n*72|0)+((B>>>3&7)<<2)>>2]<<2)>>2]&255;C=c[9698808+(c[4435368+(n*72|0)+(x<<2)>>2]<<2)>>2]|0;do{if((V|0)!=0){if(V>>>0>31){n=(C|0)<0?k|536870912:k&-536870913;c[2424718]=n;m=9698808+(c[4435368+((n&15)*72|0)+(x<<2)>>2]<<2)|0;c[m>>2]=c[m>>2]>>31;break}m=(1<<V-1&C|0)==0?k&-536870913:k|536870912;c[2424718]=m;if((C|0)<0){bi=-1<<32-V|C>>>(V>>>0)}else{bi=C>>>(V>>>0)}c[9698808+(c[4435368+((m&15)*72|0)+(x<<2)>>2]<<2)>>2]=bi}}while(0);V=c[2424718]|0;C=V&1073741823;c[2424718]=C;ay=c[9698808+(c[4435368+((V&15)*72|0)+(x<<2)>>2]<<2)>>2]|0;c[2424718]=ay&-2147483648|C|((ay|0)==0)<<30;c[2424717]=(c[2424717]|0)+2;break L1649;break};case 5:{ay=k&15;C=9698808+(c[4435368+(ay*72|0)+((B&7)<<2)>>2]<<2)|0;V=c[C>>2]|0;m=c[9698808+(c[4435368+(ay*72|0)+((B>>>3&7)<<2)>>2]<<2)>>2]|0;ay=(k>>>29&1)+V+m|0;if((m^V|0)<0){bj=0}else{bj=(ay^V)>>>31<<28}c[2424718]=ay&-2147483648|k&268435455|(m>>>0>~V>>>0)<<29|((ay|0)==0)<<30|bj;c[2424717]=l+2;c[C>>2]=ay;break L1649;break};case 6:{ay=k>>>29&1^1;C=k&15;V=9698808+(c[4435368+(C*72|0)+((B&7)<<2)>>2]<<2)|0;m=c[V>>2]|0;n=c[9698808+(c[4435368+(C*72|0)+((B>>>3&7)<<2)>>2]<<2)>>2]|0;C=m-n|0;ax=C-ay|0;if((n^m|0)<0){bk=(ax^m)>>>31<<28}else{bk=0}aM=n>>>31^1;n=ax>>>31^1;c[2424718]=ax&-2147483648|k&268435455|((C|0)==(ay|0))<<30|(((n|aM)&m>>>31|n&aM|0)!=0?536870912:0)|bk;c[2424717]=l+2;c[V>>2]=ax;break L1649;break};case 7:{ax=B&7;V=k&15;aM=9698808+(c[4435368+(V*72|0)+(ax<<2)>>2]<<2)|0;n=c[aM>>2]|0;m=c[9698808+(c[4435368+(V*72|0)+((B>>>3&7)<<2)>>2]<<2)>>2]&31;c[aM>>2]=n<<32-m|n>>>(m>>>0);aM=c[2424718]|0;V=(1<<m-1&n|0)==0?aM&-536870913:aM|536870912;aM=V&1073741823;c[2424718]=aM;n=c[9698808+(c[4435368+((V&15)*72|0)+(ax<<2)>>2]<<2)>>2]|0;c[2424718]=((n|0)==0)<<30|n&-2147483648|aM;c[2424717]=(c[2424717]|0)+2;break L1649;break};case 8:{aM=k&1073741823;c[2424718]=aM;n=k&15;ax=c[9698808+(c[4435368+(n*72|0)+((B>>>3&7)<<2)>>2]<<2)>>2]&c[9698808+(c[4435368+(n*72|0)+((B&7)<<2)>>2]<<2)>>2];c[2424718]=ax&-2147483648|aM|((ax|0)==0)<<30;c[2424717]=l+2;break L1649;break};case 9:{ax=B&7;aM=k&15;n=c[9698808+(c[4435368+(aM*72|0)+((B>>>3&7)<<2)>>2]<<2)>>2]|0;c[9698808+(c[4435368+(aM*72|0)+(ax<<2)>>2]<<2)>>2]=-n;aM=c[2424718]|0;V=c[9698808+(c[4435368+((aM&15)*72|0)+(ax<<2)>>2]<<2)>>2]|0;ax=V>>>31;c[2424718]=((n|0)<0?ax<<28:0)|aM&268435455|V&-2147483648|((V|0)==0)<<30|(((ax^1)&(n>>>31^1)|0)!=0?536870912:0);c[2424717]=(c[2424717]|0)+2;break L1649;break};case 10:{n=k&15;ax=c[9698808+(c[4435368+(n*72|0)+((B&7)<<2)>>2]<<2)>>2]|0;V=c[9698808+(c[4435368+(n*72|0)+((B>>>3&7)<<2)>>2]<<2)>>2]|0;n=ax-V|0;if((V^ax|0)<0){bl=(n^ax)>>>31<<28}else{bl=0}aM=V>>>31^1;m=n>>>31^1;c[2424718]=n&-2147483648|k&268435455|((ax|0)==(V|0))<<30|(((m|aM)&ax>>>31|m&aM|0)!=0?536870912:0)|bl;c[2424717]=l+2;break L1649;break};case 11:{aM=k&15;m=c[9698808+(c[4435368+(aM*72|0)+((B&7)<<2)>>2]<<2)>>2]|0;ax=c[9698808+(c[4435368+(aM*72|0)+((B>>>3&7)<<2)>>2]<<2)>>2]|0;aM=ax+m|0;if((ax^m|0)<0){bm=0}else{bm=(aM^m)>>>31<<28}c[2424718]=aM&-2147483648|k&268435455|(ax>>>0>~m>>>0)<<29|((aM|0)==0)<<30|bm;c[2424717]=l+2;break L1649;break};case 12:{aM=B&7;m=k&15;ax=9698808+(c[4435368+(m*72|0)+(aM<<2)>>2]<<2)|0;c[ax>>2]=c[9698808+(c[4435368+(m*72|0)+((B>>>3&7)<<2)>>2]<<2)>>2]|c[ax>>2];ax=c[2424718]|0;m=ax&1073741823;c[2424718]=m;V=c[9698808+(c[4435368+((ax&15)*72|0)+(aM<<2)>>2]<<2)>>2]|0;c[2424718]=V&-2147483648|m|((V|0)==0)<<30;c[2424717]=(c[2424717]|0)+2;break L1649;break};case 13:{V=k&15;m=9698808+(c[4435368+(V*72|0)+((B&7)<<2)>>2]<<2)|0;aM=ag(c[9698808+(c[4435368+(V*72|0)+((B>>>3&7)<<2)>>2]<<2)>>2]|0,c[m>>2]|0)|0;c[2424718]=k&1073741823;c[m>>2]=aM;c[2424718]=aM&-2147483648|c[2424718]|((aM|0)==0)<<30;c[2424717]=(c[2424717]|0)+2;break L1649;break};case 14:{aM=B&7;m=k&15;V=9698808+(c[4435368+(m*72|0)+(aM<<2)>>2]<<2)|0;c[V>>2]=c[V>>2]&~c[9698808+(c[4435368+(m*72|0)+((B>>>3&7)<<2)>>2]<<2)>>2];m=c[2424718]|0;V=m&1073741823;c[2424718]=V;ax=c[9698808+(c[4435368+((m&15)*72|0)+(aM<<2)>>2]<<2)>>2]|0;c[2424718]=ax&-2147483648|V|((ax|0)==0)<<30;c[2424717]=(c[2424717]|0)+2;break L1649;break};case 15:{ax=B&7;V=k&15;c[9698808+(c[4435368+(V*72|0)+(ax<<2)>>2]<<2)>>2]=~c[9698808+(c[4435368+(V*72|0)+((B>>>3&7)<<2)>>2]<<2)>>2];V=c[2424718]|0;aM=V&1073741823;c[2424718]=aM;m=c[9698808+(c[4435368+((V&15)*72|0)+(ax<<2)>>2]<<2)>>2]|0;c[2424718]=m&-2147483648|aM|((m|0)==0)<<30;c[2424717]=(c[2424717]|0)+2;break L1649;break};default:{bw(501200,(am=i,i=i+24|0,c[am>>2]=l,c[am+8>>2]=B,c[am+16>>2]=y,am)|0)|0;i=am;c[2424717]=(c[2424717]|0)+2;break L1649}}}else if((av|0)==1){m=Y&3;if((m|0)==0){aM=B>>>3&7;ax=B&7;V=B>>>6&3;do{if((V|0)==1){n=k&15;ay=9698808+(c[4435368+(n*72|0)+(ax<<2)>>2]<<2)|0;c[ay>>2]=(c[9698808+(c[4435368+(n*72|0)+((aM|8)<<2)>>2]<<2)>>2]|0)+(c[ay>>2]|0);if((aM|0)!=7){break}ay=9698808+(c[4435368+((c[2424718]&15)*72|0)+(ax<<2)>>2]<<2)|0;c[ay>>2]=(c[ay>>2]|0)+4}else if((V|0)==2){ay=k&15;n=9698808+(c[4435368+(ay*72|0)+((ax|8)<<2)>>2]<<2)|0;c[n>>2]=(c[9698808+(c[4435368+(ay*72|0)+(aM<<2)>>2]<<2)>>2]|0)+(c[n>>2]|0);if((ax|0)!=7){break}c[2424717]=(c[2424717]|0)+2}else if((V|0)==3){n=ax|8;ay=k&15;C=9698808+(c[4435368+(ay*72|0)+(n<<2)>>2]<<2)|0;c[C>>2]=(c[9698808+(c[4435368+(ay*72|0)+((aM|8)<<2)>>2]<<2)>>2]|0)+(c[C>>2]|0);if((aM|0)==7){C=9698808+(c[4435368+((c[2424718]&15)*72|0)+(n<<2)>>2]<<2)|0;c[C>>2]=(c[C>>2]|0)+4}if((ax|0)!=7){break}c[2424717]=(c[2424717]|0)+2}else{bw(385256,(am=i,i=i+24|0,c[am>>2]=l,c[am+8>>2]=B,c[am+16>>2]=V,am)|0)|0;i=am}}while(0);c[2424717]=(c[2424717]|0)+2;break L1649}else if((m|0)==1){V=B>>>6&3;if((V|0)==0){ax=k&15;aM=c[9698808+(c[4435368+(ax*72|0)+((B>>>3&7)<<2)>>2]<<2)>>2]|0;y=c[9698808+(c[4435368+(ax*72|0)+((B&7)<<2)>>2]<<2)>>2]|0;ax=y-aM|0;if((y^aM|0)<0){bn=(ax^y)>>>31<<28}else{bn=0}x=aM>>>31^1;C=ax>>>31^1;c[2424718]=ax&-2147483648|k&268435455|((y|0)==(aM|0))<<30|(((C|x)&y>>>31|C&x|0)!=0?536870912:0)|bn;c[2424717]=l+2;break L1649}else if((V|0)==1){x=k&15;C=c[9698808+(c[4435368+(x*72|0)+((B>>>3&7|8)<<2)>>2]<<2)>>2]|0;y=c[9698808+(c[4435368+(x*72|0)+((B&7)<<2)>>2]<<2)>>2]|0;x=y-C|0;if((y^C|0)<0){bo=(x^y)>>>31<<28}else{bo=0}aM=C>>>31^1;ax=x>>>31^1;c[2424718]=x&-2147483648|k&268435455|((y|0)==(C|0))<<30|(((ax|aM)&y>>>31|ax&aM|0)!=0?536870912:0)|bo;c[2424717]=l+2;break L1649}else if((V|0)==2){aM=k&15;ax=c[9698808+(c[4435368+(aM*72|0)+((B>>>3&7)<<2)>>2]<<2)>>2]|0;y=c[9698808+(c[4435368+(aM*72|0)+((B&7|8)<<2)>>2]<<2)>>2]|0;aM=y-ax|0;if((y^ax|0)<0){bp=(aM^y)>>>31<<28}else{bp=0}C=ax>>>31^1;x=aM>>>31^1;c[2424718]=aM&-2147483648|k&268435455|((y|0)==(ax|0))<<30|(((x|C)&y>>>31|x&C|0)!=0?536870912:0)|bp;c[2424717]=l+2;break L1649}else if((V|0)==3){C=k&15;x=c[9698808+(c[4435368+(C*72|0)+((B>>>3&7|8)<<2)>>2]<<2)>>2]|0;y=c[9698808+(c[4435368+(C*72|0)+((B&7|8)<<2)>>2]<<2)>>2]|0;C=y-x|0;if((y^x|0)<0){bq=(C^y)>>>31<<28}else{bq=0}ax=x>>>31^1;aM=C>>>31^1;c[2424718]=C&-2147483648|k&268435455|((y|0)==(x|0))<<30|(((aM|ax)&y>>>31|aM&ax|0)!=0?536870912:0)|bq;c[2424717]=l+2;break L1649}else{bw(300240,(am=i,i=i+24|0,c[am>>2]=l,c[am+8>>2]=B,c[am+16>>2]=V,am)|0)|0;i=am;c[2424717]=(c[2424717]|0)+2;break L1649}}else if((m|0)==2){V=B>>>6&3;if((V|0)==1){ax=B>>>3&7;aM=B&7;y=k&15;x=c[9698808+(c[4435368+(y*72|0)+((ax|8)<<2)>>2]<<2)>>2]|0;if((ax|0)==7){c[9698808+(c[4435368+(y*72|0)+(aM<<2)>>2]<<2)>>2]=x+4}else{c[9698808+(c[4435368+(y*72|0)+(aM<<2)>>2]<<2)>>2]=x}c[2424717]=(c[2424717]|0)+2;break L1649}else if((V|0)==2){x=B&7;aM=k&15;c[9698808+(c[4435368+(aM*72|0)+((x|8)<<2)>>2]<<2)>>2]=c[9698808+(c[4435368+(aM*72|0)+((B>>>3&7)<<2)>>2]<<2)>>2];aM=c[2424717]|0;if((x|0)==7){c[2424717]=aM&-2;break L1649}else{c[2424717]=aM+2;break L1649}}else if((V|0)==3){aM=B>>>3&7;x=B&7;y=k&15;ax=c[9698808+(c[4435368+(y*72|0)+((aM|8)<<2)>>2]<<2)>>2]|0;if((aM|0)==7){c[9698808+(c[4435368+(y*72|0)+((x|8)<<2)>>2]<<2)>>2]=ax+4}else{c[9698808+(c[4435368+(y*72|0)+((x|8)<<2)>>2]<<2)>>2]=ax}ax=c[2424717]|0;if((x|0)==7){c[2424717]=ax&-2;break L1649}else{c[2424717]=ax+2;break L1649}}else{bw(228792,(am=i,i=i+24|0,c[am>>2]=l,c[am+8>>2]=B,c[am+16>>2]=V,am)|0)|0;i=am;c[2424717]=(c[2424717]|0)+2;break L1649}}else if((m|0)==3){V=B>>>6&3;if((V|0)==0){ax=c[9698808+(c[4435368+((k&15)*72|0)+((B>>>3&7)<<2)>>2]<<2)>>2]|0;if((ax&1|0)==0){c[2424718]=k&-33;br=(ax&2|0)==0?ax:ax+2|0}else{br=ax&-2}c[2424717]=br;break L1649}else if((V|0)==1){V=B>>>3&7|8;ax=c[9698808+(c[4435368+((k&15)*72|0)+(V<<2)>>2]<<2)>>2]|0;x=(V|0)==15?ax+2|0:ax;if((x&1|0)==0){c[2424718]=k&-33;bs=(x&2|0)==0?x:x+2|0}else{bs=x&-2}c[2424717]=bs;break L1649}else{bw(178320,(am=i,i=i+16|0,c[am>>2]=l,c[am+8>>2]=B,am)|0)|0;i=am;c[2424717]=(c[2424717]|0)+2;break L1649}}else{bw(143488,(am=i,i=i+16|0,c[am>>2]=l,c[am+8>>2]=B,am)|0)|0;i=am;c[2424717]=(c[2424717]|0)+2;break L1649}}else if((av|0)==2|(av|0)==3){x=l+4|0;ax=B<<2;V=ax&1020;y=x+ax&1;do{if((y|0)==0){ax=(x&-3)+V|0;aM=ax&2147483645;C=c[(c[2406724]|0)+(aM>>>12<<2)>>2]|0;if((C|0)!=0){bt=c[C+(ax&4092)>>2]|0;break}ax=c[2432802]|0;if((ax|0)==0){bt=0;break}bt=gj[ax&4095](aM)|0}else{aM=x+V|0;ax=aM&2147483644;C=c[(c[2406724]|0)+(ax>>>12<<2)>>2]|0;do{if((C|0)==0){n=c[2432802]|0;if((n|0)==0){bu=0;break}bu=gj[n&4095](ax)|0}else{bu=c[C+(aM&4092)>>2]|0}}while(0);aM=y<<3;bt=bu>>>(aM>>>0)|bu<<32-aM}}while(0);c[9698808+(c[4435368+((c[2424718]&15)*72|0)+((Y&7)<<2)>>2]<<2)>>2]=bt;c[2424717]=(c[2424717]|0)+2;break L1649}else{bw(115208,(am=i,i=i+16|0,c[am>>2]=l,c[am+8>>2]=B,am)|0)|0;i=am;c[2424717]=(c[2424717]|0)+2;break L1649}break};case 5:{switch(B>>>9&7|0){case 0:{y=k&15;V=(c[9698808+(c[4435368+(y*72|0)+((B>>>6&7)<<2)>>2]<<2)>>2]|0)+(c[9698808+(c[4435368+(y*72|0)+((B>>>3&7)<<2)>>2]<<2)>>2]|0)|0;x=c[9698808+(c[4435368+(y*72|0)+((B&7)<<2)>>2]<<2)>>2]|0;y=V&2147483644;av=c[(c[2406722]|0)+(y>>>12<<2)>>2]|0;do{if((av|0)==0){m=c[2430388]|0;if((m|0)==0){break}gg[m&4095](y,x)}else{c[av+(V&4092)>>2]=x}}while(0);c[2424717]=(c[2424717]|0)+2;break L1649;break};case 1:{x=k&15;V=(c[9698808+(c[4435368+(x*72|0)+((B>>>6&7)<<2)>>2]<<2)>>2]|0)+(c[9698808+(c[4435368+(x*72|0)+((B>>>3&7)<<2)>>2]<<2)>>2]|0)|0;av=c[9698808+(c[4435368+(x*72|0)+((B&7)<<2)>>2]<<2)>>2]&65535;x=V&2147483646;y=c[(c[2406722]|0)+(x>>>12<<2)>>2]|0;do{if((y|0)==0){m=c[2430384]|0;if((m|0)==0){break}gg[m&4095](x,av)}else{b[y+(V&4094)>>1]=av}}while(0);c[2424717]=(c[2424717]|0)+2;break L1649;break};case 2:{av=k&15;V=(c[9698808+(c[4435368+(av*72|0)+((B>>>6&7)<<2)>>2]<<2)>>2]|0)+(c[9698808+(c[4435368+(av*72|0)+((B>>>3&7)<<2)>>2]<<2)>>2]|0)|0;y=c[9698808+(c[4435368+(av*72|0)+((B&7)<<2)>>2]<<2)>>2]&255;av=V&2147483647;x=c[(c[2406722]|0)+(av>>>12<<2)>>2]|0;do{if((x|0)==0){m=c[2430392]|0;if((m|0)==0){break}gg[m&4095](av,y)}else{a[x+(V&4095)|0]=y}}while(0);c[2424717]=(c[2424717]|0)+2;break L1649;break};case 3:{y=B&7;V=k&15;x=(c[9698808+(c[4435368+(V*72|0)+((B>>>6&7)<<2)>>2]<<2)>>2]|0)+(c[9698808+(c[4435368+(V*72|0)+((B>>>3&7)<<2)>>2]<<2)>>2]|0)|0;V=x&2147483647;av=c[(c[2406724]|0)+(V>>>12<<2)>>2]|0;do{if((av|0)==0){m=c[2432806]|0;if((m|0)==0){bv=0;bx=k;break}aM=gj[m&4095](V)|0;bv=aM;bx=c[2424718]|0}else{bv=a[av+(x&4095)|0]|0;bx=k}}while(0);x=bv&255;c[9698808+(c[4435368+((bx&15)*72|0)+(y<<2)>>2]<<2)>>2]=(x&128|0)==0?x:x|-256;c[2424717]=(c[2424717]|0)+2;break L1649;break};case 4:{x=B&7;av=k&15;V=(c[9698808+(c[4435368+(av*72|0)+((B>>>6&7)<<2)>>2]<<2)>>2]|0)+(c[9698808+(c[4435368+(av*72|0)+((B>>>3&7)<<2)>>2]<<2)>>2]|0)|0;av=V&3;do{if((av|0)==0){aM=V&2147483647;m=c[(c[2406724]|0)+(aM>>>12<<2)>>2]|0;if((m|0)!=0){by=c[m+(V&4092)>>2]|0;break}m=c[2432802]|0;if((m|0)==0){by=0;break}by=gj[m&4095](aM)|0}else{aM=V&2147483644;m=c[(c[2406724]|0)+(aM>>>12<<2)>>2]|0;do{if((m|0)==0){C=c[2432802]|0;if((C|0)==0){bz=0;break}bz=gj[C&4095](aM)|0}else{bz=c[m+(V&4092)>>2]|0}}while(0);m=av<<3;by=bz>>>(m>>>0)|bz<<32-m}}while(0);c[9698808+(c[4435368+((c[2424718]&15)*72|0)+(x<<2)>>2]<<2)>>2]=by;c[2424717]=(c[2424717]|0)+2;break L1649;break};case 5:{av=B&7;V=k&15;y=(c[9698808+(c[4435368+(V*72|0)+((B>>>6&7)<<2)>>2]<<2)>>2]|0)+(c[9698808+(c[4435368+(V*72|0)+((B>>>3&7)<<2)>>2]<<2)>>2]|0)|0;m=y&2147483646;aM=c[(c[2406724]|0)+(m>>>12<<2)>>2]|0;do{if((aM|0)==0){if((c[2432798]|0)==0){bA=0;break}if(!((m|0)==1207959552|(m|0)==1207959554)){bA=0;break}bA=d[9753376]|0}else{bA=b[aM+(y&4094)>>1]|0}}while(0);if((y&1|0)==0){bB=bA}else{bB=ga(bA|0)|0}c[9698808+(c[4435368+(V*72|0)+(av<<2)>>2]<<2)>>2]=bB&65535;c[2424717]=(c[2424717]|0)+2;break L1649;break};case 6:{aM=B&7;m=k&15;x=(c[9698808+(c[4435368+(m*72|0)+((B>>>6&7)<<2)>>2]<<2)>>2]|0)+(c[9698808+(c[4435368+(m*72|0)+((B>>>3&7)<<2)>>2]<<2)>>2]|0)|0;m=x&2147483647;C=c[(c[2406724]|0)+(m>>>12<<2)>>2]|0;do{if((C|0)==0){ax=c[2432806]|0;if((ax|0)==0){bC=0;bD=k;break}n=gj[ax&4095](m)|0;bC=n;bD=c[2424718]|0}else{bC=a[C+(x&4095)|0]|0;bD=k}}while(0);c[9698808+(c[4435368+((bD&15)*72|0)+(aM<<2)>>2]<<2)>>2]=bC&255;c[2424717]=(c[2424717]|0)+2;break L1649;break};case 7:{x=B&7;C=k&15;m=(c[9698808+(c[4435368+(C*72|0)+((B>>>6&7)<<2)>>2]<<2)>>2]|0)+(c[9698808+(c[4435368+(C*72|0)+((B>>>3&7)<<2)>>2]<<2)>>2]|0)|0;av=m&2147483646;V=c[(c[2406724]|0)+(av>>>12<<2)>>2]|0;do{if((V|0)==0){if((c[2432798]|0)==0){bE=0;break}if(!((av|0)==1207959552|(av|0)==1207959554)){bE=0;break}bE=d[9753376]|0}else{bE=b[V+(m&4094)>>1]|0}}while(0);if((m&1|0)==0){bF=bE}else{bF=ga(bE|0)|0}V=bF&65535;c[9698808+(c[4435368+(C*72|0)+(x<<2)>>2]<<2)>>2]=(V&32768|0)==0?V:V|-65536;c[2424717]=(c[2424717]|0)+2;break L1649;break};default:{bw(90224,(am=i,i=i+16|0,c[am>>2]=l,c[am+8>>2]=B,am)|0)|0;i=am;c[2424717]=(c[2424717]|0)+2;break L1649}}break};case 6:{V=B&7;av=k&15;aM=(c[9698808+(c[4435368+(av*72|0)+((B>>>3&7)<<2)>>2]<<2)>>2]|0)+(B>>>6<<2&124)|0;if((B&2048|0)==0){y=c[9698808+(c[4435368+(av*72|0)+(V<<2)>>2]<<2)>>2]|0;av=aM&2147483644;n=c[(c[2406722]|0)+(av>>>12<<2)>>2]|0;do{if((n|0)==0){ax=c[2430388]|0;if((ax|0)==0){break}gg[ax&4095](av,y)}else{c[n+(aM&4092)>>2]=y}}while(0);c[2424717]=(c[2424717]|0)+2;break L1649}y=aM&3;do{if((y|0)==0){n=aM&2147483647;av=c[(c[2406724]|0)+(n>>>12<<2)>>2]|0;if((av|0)!=0){bG=c[av+(aM&4092)>>2]|0;break}av=c[2432802]|0;if((av|0)==0){bG=0;break}bG=gj[av&4095](n)|0}else{n=aM&2147483644;av=c[(c[2406724]|0)+(n>>>12<<2)>>2]|0;do{if((av|0)==0){x=c[2432802]|0;if((x|0)==0){bH=0;break}bH=gj[x&4095](n)|0}else{bH=c[av+(aM&4092)>>2]|0}}while(0);av=y<<3;bG=bH>>>(av>>>0)|bH<<32-av}}while(0);c[9698808+(c[4435368+((c[2424718]&15)*72|0)+(V<<2)>>2]<<2)>>2]=bG;c[2424717]=(c[2424717]|0)+2;break L1649;break};case 7:{y=B&7;aM=k&15;av=(c[9698808+(c[4435368+(aM*72|0)+((B>>>3&7)<<2)>>2]<<2)>>2]|0)+(B>>>6&31)|0;if((B&2048|0)==0){n=c[9698808+(c[4435368+(aM*72|0)+(y<<2)>>2]<<2)>>2]&255;aM=av&2147483647;x=c[(c[2406722]|0)+(aM>>>12<<2)>>2]|0;do{if((x|0)==0){C=c[2430392]|0;if((C|0)==0){break}gg[C&4095](aM,n)}else{a[x+(av&4095)|0]=n}}while(0);c[2424717]=(c[2424717]|0)+2;break L1649}else{n=av&2147483647;x=c[(c[2406724]|0)+(n>>>12<<2)>>2]|0;do{if((x|0)==0){aM=c[2432806]|0;if((aM|0)==0){bI=0;bJ=k;break}V=gj[aM&4095](n)|0;bI=V;bJ=c[2424718]|0}else{bI=a[x+(av&4095)|0]|0;bJ=k}}while(0);c[9698808+(c[4435368+((bJ&15)*72|0)+(y<<2)>>2]<<2)>>2]=bI&255;c[2424717]=(c[2424717]|0)+2;break L1649}break};case 8:{av=B&7;x=k&15;n=(c[9698808+(c[4435368+(x*72|0)+((B>>>3&7)<<2)>>2]<<2)>>2]|0)+(B>>>6<<1&62)|0;if((B&2048|0)==0){V=c[9698808+(c[4435368+(x*72|0)+(av<<2)>>2]<<2)>>2]&65535;aM=n&2147483646;C=c[(c[2406722]|0)+(aM>>>12<<2)>>2]|0;do{if((C|0)==0){m=c[2430384]|0;if((m|0)==0){break}gg[m&4095](aM,V)}else{b[C+(n&4094)>>1]=V}}while(0);c[2424717]=(c[2424717]|0)+2;break L1649}V=n&2147483646;C=c[(c[2406724]|0)+(V>>>12<<2)>>2]|0;do{if((C|0)==0){if((c[2432798]|0)==0){bK=0;break}if(!((V|0)==1207959552|(V|0)==1207959554)){bK=0;break}bK=d[9753376]|0}else{bK=b[C+(n&4094)>>1]|0}}while(0);if((n&1|0)==0){bL=bK}else{bL=ga(bK|0)|0}c[9698808+(c[4435368+(x*72|0)+(av<<2)>>2]<<2)>>2]=bL&65535;c[2424717]=(c[2424717]|0)+2;break L1649;break};case 9:{C=Y&7;V=k&15;aM=(c[9698808+(c[4435420+(V*72|0)>>2]<<2)>>2]|0)+(B<<2&1020)|0;if((B&2048|0)==0){y=c[9698808+(c[4435368+(V*72|0)+(C<<2)>>2]<<2)>>2]|0;V=aM&2147483644;m=c[(c[2406722]|0)+(V>>>12<<2)>>2]|0;do{if((m|0)==0){ax=c[2430388]|0;if((ax|0)==0){break}gg[ax&4095](V,y)}else{c[m+(aM&4092)>>2]=y}}while(0);c[2424717]=(c[2424717]|0)+2;break L1649}y=aM&3;do{if((y|0)==0){m=aM&2147483647;V=c[(c[2406724]|0)+(m>>>12<<2)>>2]|0;if((V|0)!=0){bM=c[V+(aM&4092)>>2]|0;break}V=c[2432802]|0;if((V|0)==0){bM=0;break}bM=gj[V&4095](m)|0}else{m=aM&2147483644;V=c[(c[2406724]|0)+(m>>>12<<2)>>2]|0;do{if((V|0)==0){av=c[2432802]|0;if((av|0)==0){bN=0;break}bN=gj[av&4095](m)|0}else{bN=c[V+(aM&4092)>>2]|0}}while(0);V=y<<3;bM=bN>>>(V>>>0)|bN<<32-V}}while(0);c[9698808+(c[4435368+((c[2424718]&15)*72|0)+(C<<2)>>2]<<2)>>2]=bM;c[2424717]=(c[2424717]|0)+2;break L1649;break};case 10:{y=Y&7;aM=B<<2&1020;if((B&2048|0)==0){c[9698808+(c[4435368+((k&15)*72|0)+(y<<2)>>2]<<2)>>2]=(l+4&-3)+aM;c[2424717]=(c[2424717]|0)+2;break L1649}else{V=k&15;c[9698808+(c[4435368+(V*72|0)+(y<<2)>>2]<<2)>>2]=(c[9698808+(c[4435420+(V*72|0)>>2]<<2)>>2]|0)+aM;c[2424717]=(c[2424717]|0)+2;break L1649}break};case 11:{switch(Y&15|0){case 0:{aM=9698808+(c[4435420+((k&15)*72|0)>>2]<<2)|0;V=B<<2&508;c[aM>>2]=(c[aM>>2]|0)+((B&128|0)!=0?-V|0:V);c[2424717]=(c[2424717]|0)+2;break L1649;break};case 4:{V=7;while(1){do{if((1<<V&B|0)!=0){aM=9698808+(c[4435420+((c[2424718]&15)*72|0)>>2]<<2)|0;c[aM>>2]=(c[aM>>2]|0)-4;aM=c[2424718]&15;y=c[9698808+(c[4435420+(aM*72|0)>>2]<<2)>>2]|0;m=c[9698808+(c[4435368+(aM*72|0)+(V<<2)>>2]<<2)>>2]|0;aM=y&2147483644;av=c[(c[2406722]|0)+(aM>>>12<<2)>>2]|0;if((av|0)!=0){c[av+(y&4092)>>2]=m;break}y=c[2430388]|0;if((y|0)==0){break}gg[y&4095](aM,m)}}while(0);if((V|0)>0){V=V-1|0}else{break}}c[2424717]=(c[2424717]|0)+2;break L1649;break};case 5:{V=9698808+(c[4435420+((k&15)*72|0)>>2]<<2)|0;c[V>>2]=(c[V>>2]|0)-4;V=c[2424718]&15;C=c[9698808+(c[4435420+(V*72|0)>>2]<<2)>>2]|0;m=c[9698808+(c[4435424+(V*72|0)>>2]<<2)>>2]|0;V=C&2147483644;aM=c[(c[2406722]|0)+(V>>>12<<2)>>2]|0;do{if((aM|0)==0){y=c[2430388]|0;if((y|0)==0){bO=7;break}gg[y&4095](V,m);bO=7}else{c[aM+(C&4092)>>2]=m;bO=7}}while(0);while(1){do{if((1<<bO&B|0)!=0){m=9698808+(c[4435420+((c[2424718]&15)*72|0)>>2]<<2)|0;c[m>>2]=(c[m>>2]|0)-4;m=c[2424718]&15;C=c[9698808+(c[4435420+(m*72|0)>>2]<<2)>>2]|0;aM=c[9698808+(c[4435368+(m*72|0)+(bO<<2)>>2]<<2)>>2]|0;m=C&2147483644;V=c[(c[2406722]|0)+(m>>>12<<2)>>2]|0;if((V|0)!=0){c[V+(C&4092)>>2]=aM;break}C=c[2430388]|0;if((C|0)==0){break}gg[C&4095](m,aM)}}while(0);if((bO|0)>0){bO=bO-1|0}else{break}}c[2424717]=(c[2424717]|0)+2;break L1649;break};case 12:{aM=0;do{if((1<<aM&B|0)!=0){m=c[9698808+(c[4435420+((c[2424718]&15)*72|0)>>2]<<2)>>2]|0;C=m&3;do{if((C|0)==0){V=m&2147483647;y=c[(c[2406724]|0)+(V>>>12<<2)>>2]|0;if((y|0)!=0){bP=c[y+(m&4092)>>2]|0;break}y=c[2432802]|0;if((y|0)==0){bP=0;break}bP=gj[y&4095](V)|0}else{V=m&2147483644;y=c[(c[2406724]|0)+(V>>>12<<2)>>2]|0;do{if((y|0)==0){av=c[2432802]|0;if((av|0)==0){bQ=0;break}bQ=gj[av&4095](V)|0}else{bQ=c[y+(m&4092)>>2]|0}}while(0);y=C<<3;bP=bQ>>>(y>>>0)|bQ<<32-y}}while(0);c[9698808+(c[4435368+((c[2424718]&15)*72|0)+(aM<<2)>>2]<<2)>>2]=bP;C=9698808+(c[4435420+((c[2424718]&15)*72|0)>>2]<<2)|0;c[C>>2]=(c[C>>2]|0)+4}aM=aM+1|0;}while((aM|0)<8);c[2424717]=(c[2424717]|0)+2;break L1649;break};case 13:{aM=0;do{if((1<<aM&B|0)!=0){C=c[9698808+(c[4435420+((c[2424718]&15)*72|0)>>2]<<2)>>2]|0;m=C&3;do{if((m|0)==0){y=C&2147483647;V=c[(c[2406724]|0)+(y>>>12<<2)>>2]|0;if((V|0)!=0){bR=c[V+(C&4092)>>2]|0;break}V=c[2432802]|0;if((V|0)==0){bR=0;break}bR=gj[V&4095](y)|0}else{y=C&2147483644;V=c[(c[2406724]|0)+(y>>>12<<2)>>2]|0;do{if((V|0)==0){A=c[2432802]|0;if((A|0)==0){bS=0;break}bS=gj[A&4095](y)|0}else{bS=c[V+(C&4092)>>2]|0}}while(0);V=m<<3;bR=bS>>>(V>>>0)|bS<<32-V}}while(0);c[9698808+(c[4435368+((c[2424718]&15)*72|0)+(aM<<2)>>2]<<2)>>2]=bR;m=9698808+(c[4435420+((c[2424718]&15)*72|0)>>2]<<2)|0;c[m>>2]=(c[m>>2]|0)+4}aM=aM+1|0;}while((aM|0)<8);aM=c[9698808+(c[4435420+((c[2424718]&15)*72|0)>>2]<<2)>>2]|0;m=aM&3;do{if((m|0)==0){C=aM&2147483647;V=c[(c[2406724]|0)+(C>>>12<<2)>>2]|0;if((V|0)!=0){bT=c[V+(aM&4092)>>2]|0;break}V=c[2432802]|0;if((V|0)==0){bT=0;break}bT=gj[V&4095](C)|0}else{C=aM&2147483644;V=c[(c[2406724]|0)+(C>>>12<<2)>>2]|0;do{if((V|0)==0){y=c[2432802]|0;if((y|0)==0){bU=0;break}bU=gj[y&4095](C)|0}else{bU=c[V+(aM&4092)>>2]|0}}while(0);V=m<<3;bT=bU>>>(V>>>0)|bU<<32-V}}while(0);c[2424717]=bT&-2;m=9698808+(c[4435420+((c[2424718]&15)*72|0)>>2]<<2)|0;c[m>>2]=(c[m>>2]|0)+4;break L1649;break};default:{bw(70336,(am=i,i=i+16|0,c[am>>2]=l,c[am+8>>2]=B,am)|0)|0;i=am;c[2424717]=(c[2424717]|0)+2;break L1649}}break};case 12:{m=Y&7;aM=c[9698808+(c[4435368+((k&15)*72|0)+(m<<2)>>2]<<2)>>2]&-4;if((B&2048|0)==0){V=0;C=aM;while(1){if((1<<V&B|0)==0){bV=C}else{y=c[9698808+(c[4435368+((c[2424718]&15)*72|0)+(V<<2)>>2]<<2)>>2]|0;A=C&2147483644;w=c[(c[2406722]|0)+(A>>>12<<2)>>2]|0;do{if((w|0)==0){av=c[2430388]|0;if((av|0)==0){break}gg[av&4095](A,y)}else{c[w+(C&4092)>>2]=y}}while(0);bV=C+4|0}y=V+1|0;if((y|0)<8){V=y;C=bV}else{break}}c[9698808+(c[4435368+((c[2424718]&15)*72|0)+(m<<2)>>2]<<2)>>2]=bV;c[2424717]=(c[2424717]|0)+2;break L1649}else{bW=0;bX=aM}while(1){if((1<<bW&B|0)==0){bY=bX}else{C=bX&3;do{if((C|0)==0){V=bX&2147483647;y=c[(c[2406724]|0)+(V>>>12<<2)>>2]|0;if((y|0)!=0){bZ=c[y+(bX&4092)>>2]|0;break}y=c[2432802]|0;if((y|0)==0){bZ=0;break}bZ=gj[y&4095](V)|0}else{V=bX&2147483644;y=c[(c[2406724]|0)+(V>>>12<<2)>>2]|0;do{if((y|0)==0){w=c[2432802]|0;if((w|0)==0){b_=0;break}b_=gj[w&4095](V)|0}else{b_=c[y+(bX&4092)>>2]|0}}while(0);y=C<<3;bZ=b_>>>(y>>>0)|b_<<32-y}}while(0);c[9698808+(c[4435368+((c[2424718]&15)*72|0)+(bW<<2)>>2]<<2)>>2]=bZ;bY=bX+4|0}C=bW+1|0;if((C|0)<8){bW=C;bX=bY}else{break}}if((1<<m&B|0)==0){c[9698808+(c[4435368+((c[2424718]&15)*72|0)+(m<<2)>>2]<<2)>>2]=bY}c[2424717]=(c[2424717]|0)+2;break L1649;break};case 13:{aM=B<<24;switch(Y&15|0){case 0:{if((k&1073741824|0)==0){c[2424717]=l+2;break L1649}else{c[2424717]=(aM>>23)+4+l;break L1649}break};case 1:{if((k&1073741824|0)==0){c[2424717]=(aM>>23)+4+l;break L1649}else{c[2424717]=l+2;break L1649}break};case 2:{if((k&536870912|0)==0){c[2424717]=l+2;break L1649}else{c[2424717]=(aM>>23)+4+l;break L1649}break};case 3:{if((k&536870912|0)==0){c[2424717]=(aM>>23)+4+l;break L1649}else{c[2424717]=l+2;break L1649}break};case 4:{if((k|0)<0){c[2424717]=(aM>>23)+4+l;break L1649}else{c[2424717]=l+2;break L1649}break};case 5:{if((k|0)<0){c[2424717]=l+2;break L1649}else{c[2424717]=(aM>>23)+4+l;break L1649}break};case 6:{if((k&268435456|0)==0){c[2424717]=l+2;break L1649}else{c[2424717]=(aM>>23)+4+l;break L1649}break};case 7:{if((k&268435456|0)==0){c[2424717]=(aM>>23)+4+l;break L1649}else{c[2424717]=l+2;break L1649}break};case 8:{if((k&1610612736|0)==536870912){c[2424717]=(aM>>23)+4+l;break L1649}else{c[2424717]=l+2;break L1649}break};case 9:{if((k&1610612736|0)==536870912){c[2424717]=l+2;break L1649}else{c[2424717]=(aM>>23)+4+l;break L1649}break};case 10:{if((k>>>31|0)==(k>>>28&1|0)){c[2424717]=(aM>>23)+4+l;break L1649}else{c[2424717]=l+2;break L1649}break};case 11:{if((k>>>31|0)==(k>>>28&1|0)){c[2424717]=l+2;break L1649}else{c[2424717]=(aM>>23)+4+l;break L1649}break};case 12:{do{if((k&1073741824|0)==0){if((k>>>31|0)!=(k>>>28&1|0)){break}c[2424717]=(aM>>23)+4+l;break L1649}}while(0);c[2424717]=l+2;break L1649;break};case 13:{do{if((k&1073741824|0)==0){if((k>>>31|0)!=(k>>>28&1|0)){break}c[2424717]=l+2;break L1649}}while(0);c[2424717]=(aM>>23)+4+l;break L1649;break};case 14:{bw(578320,(am=i,i=i+16|0,c[am>>2]=l,c[am+8>>2]=B,am)|0)|0;i=am;c[2424717]=(c[2424717]|0)+2;break L1649;break};case 15:{a[9698961]=1;fyX();break L1649;break};default:{break L1649}}break};case 14:{if((B&2048|0)==0){Y=B<<1;c[2424717]=((Y&2048|0)==0?Y&4094:Y|-2048)+4+l;break L1649}else{Y=9698808+(c[4435424+((k&15)*72|0)>>2]<<2)|0;m=(c[Y>>2]|0)+(B<<1&4094)&-4;c[Y>>2]=l+4|1;c[2424717]=m;break L1649}break};case 15:{if((B&2048|0)==0){m=B<<12;c[9698808+(c[4435424+((k&15)*72|0)>>2]<<2)>>2]=l+(((m&4194304|0)==0?m&8384512:m|-8388608)|4);c[2424717]=(c[2424717]|0)+2;break L1649}else{m=9698808+(c[4435424+((k&15)*72|0)>>2]<<2)|0;Y=(c[m>>2]|0)+(B<<1&4094)|0;c[m>>2]=l+2|1;c[2424717]=Y;break L1649}break};default:{bw(562e3,(am=i,i=i+16|0,c[am>>2]=l,c[am+8>>2]=B,am)|0)|0;i=am;c[2424717]=(c[2424717]|0)+2;break L1649}}}}while(0);fyX();l=c[3526974]|0;j=l-3|0;c[3526974]=j;c[2440186]=h-l+(c[3526936]|0);}while((j|0)>0);i=f;return e-j|0}function fyX(){var b=0,d=0,e=0;b=c[2424718]|0;d=c[2424717]|0;e=d+4|0;if((a[9698958]|0)!=0){c[2424734]=e;c[2424735]=b;c[2424718]=b&-176|135;c[2424717]=16;a[9698958]=0;return}do{if((a[9698957]|0)!=0){if((b&64|0)!=0){break}c[2424725]=e;c[2424726]=b;c[2424718]=b&-240|193;c[2424717]=28;return}}while(0);do{if((a[9698956]|0)!=0){if((b&128|0)!=0){break}c[2424728]=e;c[2424729]=b;c[2424718]=b&-176|130;c[2424717]=24;return}}while(0);if((a[9698959]|0)!=0){c[2424734]=e;c[2424735]=b;c[2424718]=b&-176|135;c[2424717]=12;a[9698959]=0;return}if((a[9698960]|0)!=0){c[2424737]=e;c[2424738]=b;c[2424718]=b&-176|139;c[2424717]=4;a[9698960]=0;return}if((a[9698961]|0)==0){return}c[2424731]=(b&32|0)==0?e:d+2|0;c[2424732]=b;c[2424718]=b&-176|131;c[2424717]=8;a[9698961]=0;return}function fyY(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=i;e=a>>>7&31;f=a&15;g=c[2424718]|0;h=g&15;j=c[9698808+(c[4435368+(h*72|0)+(f<<2)>>2]<<2)>>2]|0;k=(f|0)==15?j+8|0:j;do{if((a&16|0)==0){l=e;m=2206}else{j=c[9698808+(c[4435368+(h*72|0)+(e>>>1<<2)>>2]<<2)>>2]&255;if((j|0)!=0){l=j;m=2206;break}if((b|0)==0){n=k;break}c[b>>2]=g&536870912;n=k}}while(0);do{if((m|0)==2206){e=a>>>5&3;if((e|0)==0){h=(b|0)!=0;if(l>>>0>31){if(!h){n=0;break}c[b>>2]=(l|0)==32?k&1:0;n=0;break}if(h){if((l|0)==0){o=g&536870912}else{o=1<<32-l&k}c[b>>2]=o}n=k<<l;break}else if((e|0)==1){if((l|0)==32|(l|0)==0){if((b|0)==0){n=0;break}c[b>>2]=k&-2147483648;n=0;break}h=(b|0)!=0;if(l>>>0>32){if(!h){n=0;break}c[b>>2]=0;n=0;break}if(h){c[b>>2]=1<<l-1&k}n=k>>>(l>>>0);break}else if((e|0)==2){h=(l|0)==0|l>>>0>32?32:l;if((b|0)!=0){c[b>>2]=1<<h-1&k}if(h>>>0>31){n=k>>31;break}j=k>>>(h>>>0);if((k|0)>=0){n=j;break}n=-1<<32-h|j;break}else if((e|0)==3){if((l|0)==0){if((b|0)==0){p=g}else{c[b>>2]=k&1;p=c[2424718]|0}n=p<<2&-2147483648|k>>>1;break}else{q=l}while(1){if(q>>>0>32){q=q-32|0}else{break}}if((b|0)!=0){c[b>>2]=1<<q-1&k}n=k<<32-q|k>>>(q>>>0);break}else{bw(379208,(e=i,i=i+8|0,c[e>>2]=c[2424717],e)|0)|0;i=e;n=0;break}}}while(0);i=d;return n|0}function fyZ(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[2415273]|0;gGz(9661040,0,68);c[2415273]=b;a[9661063]=20;c[2415262]=511;b=c[2388530]|0;e=c[b+28>>2]|0;do{if((e|0)==0){f=c[b>>2]|0;if((f|0)==0){g=0;h=8191;i=b;break}j=gj[f&4095](8190)|0;g=j;h=(d[9661071]|0)<<13|8191;i=c[2388530]|0}else{g=a[e+2046|0]|0;h=8191;i=b}}while(0);a[9661044]=g;g=c[i+16+(h>>>11<<2)>>2]|0;do{if((g|0)==0){b=c[i>>2]|0;if((b|0)==0){k=0;break}k=gj[b&4095](h)|0}else{k=a[g+2047|0]|0}}while(0);a[9661045]=k;a[9661075]=4;a[9661073]=0;c[2415270]=131072;c[2415275]=0;gGz(9661084,0,5);return}function fy_(e){e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;c[2440610]=e;c[2415274]=e;if((a[9661088]|0)==2){a[9661088]=1}do{f=b[4830522]|0;if(((f^b[4830520])&65535)>8191){b[4830522]=f}f=c[2415261]|0;c[2415260]=f;g=d[9661064+(f>>>13&7)|0]<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;j=f&65535;do{if((i|0)==0){k=c[h>>2]|0;if((k|0)==0){l=0;m=j;break}n=gj[k&4095](g)|0;l=n;m=b[4830522]|0}else{l=a[i+(f&2047)|0]|0;m=j}}while(0);b[4830522]=m+1&65535;gu[c[633072+((l&255)<<2)>>2]&16383]();j=a[9661088]|0;L2926:do{if((j<<24>>24|0)==1){if((a[9661063]&4)!=0){break}a[9661088]=0;if((a[9661084]|0)!=0){a[9661084]=0;f=(d[9661075]|0)*-7|0;c[2440610]=f+(c[2440610]|0);c[2415269]=f+(c[2415269]|0);f=c[2415262]|0;i=a[9661045]|0;g=d[9661065]<<13|f&2097151;h=c[2388530]|0;n=c[h+4112+(g>>>11<<2)>>2]|0;do{if((n|0)==0){k=c[h+4>>2]|0;if((k|0)==0){o=h;break}gg[k&4095](g,i);o=c[2388530]|0}else{a[n+(f&2047)|0]=i;o=h}}while(0);a[9661048]=(a[9661048]|0)-1&255;h=c[2415262]|0;i=a[9661044]|0;f=d[9661065]<<13|h&2097151;n=c[o+4112+(f>>>11<<2)>>2]|0;do{if((n|0)==0){g=c[o+4>>2]|0;if((g|0)==0){p=o;break}gg[g&4095](f,i);p=c[2388530]|0}else{a[n+(h&2047)|0]=i;p=o}}while(0);a[9661048]=(a[9661048]|0)-1&255;i=a[9661063]&-17;a[9661063]=i;h=c[2415262]|0;n=d[9661065]<<13|h&2097151;f=c[p+4112+(n>>>11<<2)>>2]|0;do{if((f|0)==0){g=c[p+4>>2]|0;if((g|0)==0){q=p;break}gg[g&4095](n,i);q=c[2388530]|0}else{a[f+(h&2047)|0]=i;q=p}}while(0);a[9661048]=(a[9661048]|0)-1&255;a[9661063]=a[9661063]&-13|4;i=a[9661071]|0;h=(i&255)<<13|8188;f=c[q+16+(h>>>11<<2)>>2]|0;do{if((f|0)==0){n=c[q>>2]|0;if((n|0)==0){r=0;s=i;t=q;break}g=gj[n&4095](h)|0;r=g;s=a[9661071]|0;t=c[2388530]|0}else{r=a[f+2044|0]|0;s=i;t=q}}while(0);a[9661044]=r;i=(s&255)<<13|8189;f=c[t+16+(i>>>11<<2)>>2]|0;do{if((f|0)==0){h=c[t>>2]|0;if((h|0)==0){u=0;break}u=gj[h&4095](i)|0}else{u=a[f+2045|0]|0}}while(0);a[9661045]=u;break}do{if((a[9661087]|0)!=0){if((a[9661072]&4)!=0){break}f=(d[9661075]|0)*-7|0;c[2440610]=f+(c[2440610]|0);c[2415269]=f+(c[2415269]|0);f=c[2415262]|0;i=a[9661045]|0;h=d[9661065]<<13|f&2097151;g=c[2388530]|0;n=c[g+4112+(h>>>11<<2)>>2]|0;do{if((n|0)==0){k=c[g+4>>2]|0;if((k|0)==0){v=g;break}gg[k&4095](h,i);v=c[2388530]|0}else{a[n+(f&2047)|0]=i;v=g}}while(0);a[9661048]=(a[9661048]|0)-1&255;g=c[2415262]|0;i=a[9661044]|0;f=d[9661065]<<13|g&2097151;n=c[v+4112+(f>>>11<<2)>>2]|0;do{if((n|0)==0){h=c[v+4>>2]|0;if((h|0)==0){w=v;break}gg[h&4095](f,i);w=c[2388530]|0}else{a[n+(g&2047)|0]=i;w=v}}while(0);a[9661048]=(a[9661048]|0)-1&255;i=a[9661063]&-17;a[9661063]=i;g=c[2415262]|0;n=d[9661065]<<13|g&2097151;f=c[w+4112+(n>>>11<<2)>>2]|0;do{if((f|0)==0){h=c[w+4>>2]|0;if((h|0)==0){x=w;break}gg[h&4095](n,i);x=c[2388530]|0}else{a[f+(g&2047)|0]=i;x=w}}while(0);a[9661048]=(a[9661048]|0)-1&255;a[9661063]=a[9661063]&-13|4;i=a[9661071]|0;g=(i&255)<<13|8186;f=c[x+16+(g>>>11<<2)>>2]|0;do{if((f|0)==0){n=c[x>>2]|0;if((n|0)==0){y=0;z=i;A=x;break}h=gj[n&4095](g)|0;y=h;z=a[9661071]|0;A=c[2388530]|0}else{y=a[f+2042|0]|0;z=i;A=x}}while(0);a[9661044]=y;i=(z&255)<<13|8187;f=c[A+16+(i>>>11<<2)>>2]|0;do{if((f|0)==0){g=c[A>>2]|0;if((g|0)==0){B=0;break}B=gj[g&4095](i)|0}else{B=a[f+2043|0]|0}}while(0);a[9661045]=B;break L2926}}while(0);do{if((a[9661085]|0)!=0){if((a[9661072]&2)!=0){break}f=(d[9661075]|0)*-7|0;c[2440610]=f+(c[2440610]|0);c[2415269]=f+(c[2415269]|0);f=c[2415262]|0;i=a[9661045]|0;g=d[9661065]<<13|f&2097151;h=c[2388530]|0;n=c[h+4112+(g>>>11<<2)>>2]|0;do{if((n|0)==0){k=c[h+4>>2]|0;if((k|0)==0){C=h;break}gg[k&4095](g,i);C=c[2388530]|0}else{a[n+(f&2047)|0]=i;C=h}}while(0);a[9661048]=(a[9661048]|0)-1&255;h=c[2415262]|0;i=a[9661044]|0;f=d[9661065]<<13|h&2097151;n=c[C+4112+(f>>>11<<2)>>2]|0;do{if((n|0)==0){g=c[C+4>>2]|0;if((g|0)==0){D=C;break}gg[g&4095](f,i);D=c[2388530]|0}else{a[n+(h&2047)|0]=i;D=C}}while(0);a[9661048]=(a[9661048]|0)-1&255;i=a[9661063]&-17;a[9661063]=i;h=c[2415262]|0;n=d[9661065]<<13|h&2097151;f=c[D+4112+(n>>>11<<2)>>2]|0;do{if((f|0)==0){g=c[D+4>>2]|0;if((g|0)==0){E=D;break}gg[g&4095](n,i);E=c[2388530]|0}else{a[f+(h&2047)|0]=i;E=D}}while(0);a[9661048]=(a[9661048]|0)-1&255;a[9661063]=a[9661063]&-13|4;i=a[9661071]|0;h=(i&255)<<13|8184;f=c[E+16+(h>>>11<<2)>>2]|0;do{if((f|0)==0){n=c[E>>2]|0;if((n|0)==0){F=0;G=i;H=E;break}g=gj[n&4095](h)|0;F=g;G=a[9661071]|0;H=c[2388530]|0}else{F=a[f+2040|0]|0;G=i;H=E}}while(0);a[9661044]=F;i=(G&255)<<13|8185;f=c[H+16+(i>>>11<<2)>>2]|0;do{if((f|0)==0){h=c[H>>2]|0;if((h|0)==0){I=0;break}I=gj[h&4095](i)|0}else{I=a[f+2041|0]|0}}while(0);a[9661045]=I;f=c[2415273]|0;if((f|0)==0){break L2926}gj[f&4095](0)|0;break L2926}}while(0);if((a[9661086]|0)==0){break}if((a[9661072]&1)!=0){break}f=(d[9661075]|0)*-7|0;c[2440610]=f+(c[2440610]|0);c[2415269]=f+(c[2415269]|0);f=c[2415262]|0;i=a[9661045]|0;h=d[9661065]<<13|f&2097151;g=c[2388530]|0;n=c[g+4112+(h>>>11<<2)>>2]|0;do{if((n|0)==0){k=c[g+4>>2]|0;if((k|0)==0){J=g;break}gg[k&4095](h,i);J=c[2388530]|0}else{a[n+(f&2047)|0]=i;J=g}}while(0);a[9661048]=(a[9661048]|0)-1&255;g=c[2415262]|0;i=a[9661044]|0;f=d[9661065]<<13|g&2097151;n=c[J+4112+(f>>>11<<2)>>2]|0;do{if((n|0)==0){h=c[J+4>>2]|0;if((h|0)==0){K=J;break}gg[h&4095](f,i);K=c[2388530]|0}else{a[n+(g&2047)|0]=i;K=J}}while(0);a[9661048]=(a[9661048]|0)-1&255;i=a[9661063]&-17;a[9661063]=i;g=c[2415262]|0;n=d[9661065]<<13|g&2097151;f=c[K+4112+(n>>>11<<2)>>2]|0;do{if((f|0)==0){h=c[K+4>>2]|0;if((h|0)==0){L=K;break}gg[h&4095](n,i);L=c[2388530]|0}else{a[f+(g&2047)|0]=i;L=K}}while(0);a[9661048]=(a[9661048]|0)-1&255;a[9661063]=a[9661063]&-13|4;i=a[9661071]|0;g=(i&255)<<13|8182;f=c[L+16+(g>>>11<<2)>>2]|0;do{if((f|0)==0){n=c[L>>2]|0;if((n|0)==0){M=0;N=i;O=L;break}h=gj[n&4095](g)|0;M=h;N=a[9661071]|0;O=c[2388530]|0}else{M=a[f+2038|0]|0;N=i;O=L}}while(0);a[9661044]=M;i=(N&255)<<13|8183;f=c[O+16+(i>>>11<<2)>>2]|0;do{if((f|0)==0){g=c[O>>2]|0;if((g|0)==0){P=0;break}P=gj[g&4095](i)|0}else{P=a[f+2039|0]|0}}while(0);a[9661045]=P;f=c[2415273]|0;if((f|0)==0){break}gj[f&4095](1)|0}else if((j<<24>>24|0)!=0){a[9661088]=j-1&255}}while(0);j=c[2415269]|0;do{if((a[9661073]|0)!=0&(j|0)<1){f=a[9661088]|0;if(f<<24>>24==0){a[9661088]=1;Q=1}else{Q=f}f=c[2415270]|0;i=j;do{i=i+f|0;}while((i|0)<1);c[2415269]=i;if((a[9661087]|0)==1){break}a[9661087]=1;if(Q<<24>>24!=0){break}a[9661088]=2}}while(0);R=c[2440610]|0;}while((R|0)>0);c[2415275]=e-R+(c[2415275]|0);c[2440610]=0;c[2415274]=0;return e|0}function fy$(){return c[2415275]|0}function fy0(){c[2440610]=0;return}function fy1(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=(d[9661075]|0)<<3;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;a[9661063]=a[9661063]&-33;e=(b[4830522]|0)+1&65535;b[4830522]=e;f=c[2415262]|0;g=(e&65535)>>>8&255;e=(d[9661065]|0)<<13|f&2097151;h=c[2388530]|0;i=c[h+4112+(e>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h+4>>2]|0;if((j|0)==0){k=h;break}gg[j&4095](e,g);k=c[2388530]|0}else{a[i+(f&2047)|0]=g;k=h}}while(0);a[9661048]=(a[9661048]|0)-1&255;h=c[2415262]|0;g=a[9661044]|0;f=(d[9661065]|0)<<13|h&2097151;i=c[k+4112+(f>>>11<<2)>>2]|0;do{if((i|0)==0){e=c[k+4>>2]|0;if((e|0)==0){l=k;break}gg[e&4095](f,g);l=c[2388530]|0}else{a[i+(h&2047)|0]=g;l=k}}while(0);a[9661048]=(a[9661048]|0)-1&255;k=c[2415262]|0;g=a[9661063]|0;h=(d[9661065]|0)<<13|k&2097151;i=c[l+4112+(h>>>11<<2)>>2]|0;do{if((i|0)==0){f=c[l+4>>2]|0;if((f|0)==0){m=l;break}gg[f&4095](h,g);m=c[2388530]|0}else{a[i+(k&2047)|0]=g;m=l}}while(0);a[9661048]=(a[9661048]|0)-1&255;a[9661063]=a[9661063]&-13|4;l=a[9661071]|0;g=(l&255)<<13|8182;k=c[m+16+(g>>>11<<2)>>2]|0;do{if((k|0)==0){i=c[m>>2]|0;if((i|0)==0){n=0;o=l;p=m;break}h=gj[i&4095](g)|0;n=h;o=a[9661071]|0;p=c[2388530]|0}else{n=a[k+2038|0]|0;o=l;p=m}}while(0);a[9661044]=n;n=(o&255)<<13|8183;o=c[p+16+(n>>>11<<2)>>2]|0;if((o|0)!=0){q=a[o+2039|0]|0;a[9661045]=q;return}o=c[p>>2]|0;if((o|0)==0){q=0;a[9661045]=q;return}q=gj[o&4095](n)|0;a[9661045]=q;return}function fy2(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;e=(d[9661075]|0)*-7|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=(a[9661061]|0)+k&255;b[4830522]=l+1&65535;l=c[2415263]|0;k=(l&255|0)==255;h=a[9661065]|0;e=(h&255)<<13|l&8191;f=c[m+16+(e>>>11<<2)>>2]|0;do{if((f|0)==0){i=c[m>>2]|0;if((i|0)==0){o=0;p=h;q=l;break}g=gj[i&4095](e)|0;o=g;p=a[9661065]|0;q=c[2415263]|0}else{o=a[f+(l&2047)|0]|0;p=h;q=l}}while(0);l=o&255;o=(p&255)<<13;do{if(k){p=q+7937|0;h=p&8191|o;f=c[2388530]|0;e=c[f+16+(h>>>11<<2)>>2]|0;if((e|0)!=0){r=a[e+(p&2047)|0]|0;break}p=c[f>>2]|0;if((p|0)==0){r=0;break}r=gj[p&4095](h)|0}else{h=q+1|0;p=h&8191|o;f=c[2388530]|0;e=c[f+16+(p>>>11<<2)>>2]|0;if((e|0)!=0){r=a[e+(h&2047)|0]|0;break}h=c[f>>2]|0;if((h|0)==0){r=0;break}r=gj[h&4095](p)|0}}while(0);o=r&255;r=o<<8;q=r|l;c[2415264]=q;l=9661064+(o>>>5)|0;o=a[l]|0;if(((o&255)<<13|r&6144|0)==2088960){r=d[9661075]|0;c[2440610]=(c[2440610]|0)-r;c[2415269]=(c[2415269]|0)-r;s=a[l]|0}else{s=o}o=(s&255)<<13|q&8191;s=c[2388530]|0;l=c[s+16+(o>>>11<<2)>>2]|0;do{if((l|0)==0){r=c[s>>2]|0;if((r|0)==0){t=0;break}t=gj[r&4095](o)|0}else{t=a[l+(q&2047)|0]|0}}while(0);q=a[9661063]|0;if((q&32)==0){l=a[9661060]|t;a[9661060]=l;a[9661063]=l&-128|q&93|(l<<24>>24==0?2:0);return}a[9661063]=q&-33;a[9661052]=a[9661061]|0;q=c[2415263]|0;c[2415264]=q;l=a[9661065]|0;o=(l&255)<<13|q&8191;s=c[2388530]|0;r=c[s+16+(o>>>11<<2)>>2]|0;do{if((r|0)==0){k=c[s>>2]|0;if((k|0)==0){u=0;v=l;w=q;x=s;break}p=gj[k&4095](o)|0;u=p;v=a[9661065]|0;w=c[2415264]|0;x=c[2388530]|0}else{u=a[r+(q&2047)|0]|0;v=l;w=q;x=s}}while(0);s=u|t;t=(v&255)<<13|w&8191;v=c[x+4112+(t>>>11<<2)>>2]|0;do{if((v|0)==0){u=c[x+4>>2]|0;if((u|0)==0){break}gg[u&4095](t,s)}else{a[v+(w&2047)|0]=s}}while(0);a[9661063]=(s<<24>>24==0?2:0)|s&-128|a[9661063]&93;s=(d[9661075]|0)*-3|0;c[2440610]=s+(c[2440610]|0);c[2415269]=s+(c[2415269]|0);return}function fy3(){var b=0;b=(d[9661075]|0)*-3|0;c[2440610]=b+(c[2440610]|0);c[2415269]=b+(c[2415269]|0);a[9661063]=a[9661063]&-33;b=a[9661061]|0;a[9661061]=a[9661062]|0;a[9661062]=b;return}function fy4(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=(d[9661075]|0)*-5|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);b[4830522]=l+1&65535;a[9661063]=a[9661063]&-33;l=c[m+8>>2]|0;if((l|0)==0){return}gg[l&4095](0,k);return}function fy5(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=(d[9661075]|0)*-6|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=k;b[4830522]=l+1&65535;l=c[2415263]|0;c[2415264]=l;k=a[9661065]|0;h=(k&255)<<13|l&8191;e=c[m+16+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){o=0;p=k;q=l;r=m;break}i=gj[f&4095](h)|0;o=i;p=a[9661065]|0;q=c[2415264]|0;r=c[2388530]|0}else{o=a[e+(l&2047)|0]|0;p=k;q=l;r=m}}while(0);m=a[9661060]|o;a[9661063]=a[9661063]&29|o&-64|(m<<24>>24!=0?0:2);o=(p&255)<<13|q&8191;p=c[r+4112+(o>>>11<<2)>>2]|0;if((p|0)!=0){a[p+(q&2047)|0]=m;return}q=c[r+4>>2]|0;if((q|0)==0){return}gg[q&4095](o,m);return}function fy6(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=(d[9661075]|0)<<2;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=k;b[4830522]=l+1&65535;l=c[2415263]|0;c[2415264]=l;k=(d[9661065]|0)<<13|l&8191;h=c[m+16+(k>>>11<<2)>>2]|0;do{if((h|0)==0){e=c[m>>2]|0;if((e|0)==0){o=0;break}o=gj[e&4095](k)|0}else{o=a[h+(l&2047)|0]|0}}while(0);l=a[9661063]|0;if((l&32)==0){h=a[9661060]|o;a[9661060]=h;a[9661063]=h&-128|l&93|(h<<24>>24==0?2:0);return}a[9661063]=l&-33;a[9661052]=a[9661061]|0;l=c[2415263]|0;c[2415264]=l;h=a[9661065]|0;k=(h&255)<<13|l&8191;m=c[2388530]|0;e=c[m+16+(k>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){p=0;q=h;r=l;s=m;break}i=gj[f&4095](k)|0;p=i;q=a[9661065]|0;r=c[2415264]|0;s=c[2388530]|0}else{p=a[e+(l&2047)|0]|0;q=h;r=l;s=m}}while(0);m=p|o;o=(q&255)<<13|r&8191;q=c[s+4112+(o>>>11<<2)>>2]|0;do{if((q|0)==0){p=c[s+4>>2]|0;if((p|0)==0){break}gg[p&4095](o,m)}else{a[q+(r&2047)|0]=m}}while(0);a[9661063]=(m<<24>>24==0?2:0)|m&-128|a[9661063]&93;m=(d[9661075]|0)*-3|0;c[2440610]=m+(c[2440610]|0);c[2415269]=m+(c[2415269]|0);return}function fy7(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=(d[9661075]|0)*-6|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=k;b[4830522]=l+1&65535;l=c[2415263]|0;c[2415264]=l;k=a[9661065]|0;h=(k&255)<<13|l&8191;e=c[m+16+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){o=0;p=k;q=l;r=m;break}i=gj[f&4095](h)|0;o=i;p=a[9661065]|0;q=c[2415264]|0;r=c[2388530]|0}else{o=a[e+(l&2047)|0]|0;p=k;q=l;r=m}}while(0);m=o<<1;a[9661063]=a[9661063]&92|(o&255)>>>7|m&-128|(m<<24>>24==0?2:0);o=(p&255)<<13|q&8191;p=c[r+4112+(o>>>11<<2)>>2]|0;if((p|0)!=0){a[p+(q&2047)|0]=m;return}q=c[r+4>>2]|0;if((q|0)==0){return}gg[q&4095](o,m);return}function fy8(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=(d[9661075]|0)*-7|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=k;b[4830522]=l+1&65535;l=c[2415263]|0;c[2415264]=l;k=a[9661065]|0;h=(k&255)<<13|l&8191;e=c[m+16+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){o=0;p=k;q=l;r=m;break}i=gj[f&4095](h)|0;o=i;p=a[9661065]|0;q=c[2415264]|0;r=c[2388530]|0}else{o=a[e+(l&2047)|0]|0;p=k;q=l;r=m}}while(0);a[9661063]=a[9661063]&-33;m=o&-2;o=(p&255)<<13|q&8191;p=c[r+4112+(o>>>11<<2)>>2]|0;if((p|0)!=0){a[p+(q&2047)|0]=m;return}q=c[r+4>>2]|0;if((q|0)==0){return}gg[q&4095](o,m);return}function fy9(){var b=0,e=0,f=0,g=0,h=0,i=0;b=(d[9661075]|0)*-3|0;c[2440610]=b+(c[2440610]|0);c[2415269]=b+(c[2415269]|0);b=a[9661063]&-33;a[9661063]=b;e=c[2415262]|0;f=(d[9661065]|0)<<13|e&2097151;g=c[2388530]|0;h=c[g+4112+(f>>>11<<2)>>2]|0;do{if((h|0)==0){i=c[g+4>>2]|0;if((i|0)==0){break}gg[i&4095](f,b)}else{a[h+(e&2047)|0]=b}}while(0);a[9661048]=(a[9661048]|0)-1&255;return}function fza(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;break}m=gj[j&4095](g)|0;k=m;l=b[4830522]|0}else{k=a[i+(f&2047)|0]|0;l=e}}while(0);b[4830522]=l+1&65535;l=a[9661063]|0;if((l&32)==0){e=a[9661060]|k;a[9661060]=e;a[9661063]=e&-128|l&93|(e<<24>>24==0?2:0);return}a[9661063]=l&-33;a[9661052]=a[9661061]|0;l=c[2415263]|0;c[2415264]=l;e=a[9661065]|0;f=(e&255)<<13|l&8191;i=c[2388530]|0;g=c[i+16+(f>>>11<<2)>>2]|0;do{if((g|0)==0){h=c[i>>2]|0;if((h|0)==0){n=0;o=e;p=l;q=i;break}m=gj[h&4095](f)|0;n=m;o=a[9661065]|0;p=c[2415264]|0;q=c[2388530]|0}else{n=a[g+(l&2047)|0]|0;o=e;p=l;q=i}}while(0);i=n|k;k=(o&255)<<13|p&8191;o=c[q+4112+(k>>>11<<2)>>2]|0;do{if((o|0)==0){n=c[q+4>>2]|0;if((n|0)==0){break}gg[n&4095](k,i)}else{a[o+(p&2047)|0]=i}}while(0);a[9661063]=(i<<24>>24==0?2:0)|i&-128|a[9661063]&93;i=(d[9661075]|0)*-3|0;c[2440610]=i+(c[2440610]|0);c[2415269]=i+(c[2415269]|0);return}function fzb(){var b=0,e=0;b=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-b;c[2415269]=(c[2415269]|0)-b;b=a[9661060]|0;e=b<<1;a[9661063]=a[9661063]&92|(b&255)>>>7|e&-128|(e<<24>>24==0?2:0);a[9661060]=e;return}function fzc(){var b=0;b=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-b;c[2415269]=(c[2415269]|0)-b;a[9661063]=a[9661063]&-33;return}function fzd(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=(d[9661075]|0)*-7|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661056]=k;k=l+1&65535;b[4830522]=k;l=k&65535;h=(d[9661064+(l>>>13)|0]|0)<<13|l&8191;e=c[m+8208+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){o=0;p=k;break}i=gj[f&4095](h)|0;o=i;p=b[4830522]|0}else{o=a[e+(l&2047)|0]|0;p=k}}while(0);a[9661057]=o;b[4830522]=p+1&65535;p=c[2415264]|0;o=9661064+(p>>>13&7)|0;k=a[o]|0;if(((k&255)<<13|p&6144|0)==2088960){l=d[9661075]|0;c[2440610]=(c[2440610]|0)-l;c[2415269]=(c[2415269]|0)-l;q=a[o]|0}else{q=k}k=(q&255)<<13|p&8191;q=c[2388530]|0;o=c[q+16+(k>>>11<<2)>>2]|0;do{if((o|0)==0){l=c[q>>2]|0;if((l|0)==0){r=0;s=p;break}e=gj[l&4095](k)|0;r=e;s=c[2415264]|0}else{r=a[o+(p&2047)|0]|0;s=p}}while(0);p=a[9661060]|r;a[9661063]=a[9661063]&29|r&-64|(p<<24>>24!=0?0:2);r=9661064+(s>>>13&7)|0;o=a[r]|0;if(((o&255)<<13|s&6144|0)==2088960){k=d[9661075]|0;c[2440610]=(c[2440610]|0)-k;c[2415269]=(c[2415269]|0)-k;t=a[r]|0}else{t=o}o=(t&255)<<13|s&8191;t=c[2388530]|0;r=c[t+4112+(o>>>11<<2)>>2]|0;if((r|0)!=0){a[r+(s&2047)|0]=p;return}s=c[t+4>>2]|0;if((s|0)==0){return}gg[s&4095](o,p);return}function fze(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=(d[9661075]|0)*-5|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661056]=k;k=l+1&65535;b[4830522]=k;l=k&65535;h=(d[9661064+(l>>>13)|0]|0)<<13|l&8191;e=c[m+8208+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){o=0;p=k;break}i=gj[f&4095](h)|0;o=i;p=b[4830522]|0}else{o=a[e+(l&2047)|0]|0;p=k}}while(0);a[9661057]=o;b[4830522]=p+1&65535;p=c[2415264]|0;o=9661064+(p>>>13&7)|0;k=a[o]|0;if(((k&255)<<13|p&6144|0)==2088960){l=d[9661075]|0;c[2440610]=(c[2440610]|0)-l;c[2415269]=(c[2415269]|0)-l;q=a[o]|0}else{q=k}k=(q&255)<<13|p&8191;q=c[2388530]|0;o=c[q+16+(k>>>11<<2)>>2]|0;do{if((o|0)==0){l=c[q>>2]|0;if((l|0)==0){r=0;break}r=gj[l&4095](k)|0}else{r=a[o+(p&2047)|0]|0}}while(0);p=a[9661063]|0;if((p&32)==0){o=a[9661060]|r;a[9661060]=o;a[9661063]=o&-128|p&93|(o<<24>>24==0?2:0);return}a[9661063]=p&-33;a[9661052]=a[9661061]|0;p=c[2415263]|0;c[2415264]=p;o=a[9661065]|0;k=(o&255)<<13|p&8191;q=c[2388530]|0;l=c[q+16+(k>>>11<<2)>>2]|0;do{if((l|0)==0){e=c[q>>2]|0;if((e|0)==0){s=0;t=o;u=p;v=q;break}h=gj[e&4095](k)|0;s=h;t=a[9661065]|0;u=c[2415264]|0;v=c[2388530]|0}else{s=a[l+(p&2047)|0]|0;t=o;u=p;v=q}}while(0);q=s|r;r=(t&255)<<13|u&8191;t=c[v+4112+(r>>>11<<2)>>2]|0;do{if((t|0)==0){s=c[v+4>>2]|0;if((s|0)==0){break}gg[s&4095](r,q)}else{a[t+(u&2047)|0]=q}}while(0);a[9661063]=(q<<24>>24==0?2:0)|q&-128|a[9661063]&93;q=(d[9661075]|0)*-3|0;c[2440610]=q+(c[2440610]|0);c[2415269]=q+(c[2415269]|0);return}function fzf(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=(d[9661075]|0)*-7|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661056]=k;k=l+1&65535;b[4830522]=k;l=k&65535;h=(d[9661064+(l>>>13)|0]|0)<<13|l&8191;e=c[m+8208+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){o=0;p=k;break}i=gj[f&4095](h)|0;o=i;p=b[4830522]|0}else{o=a[e+(l&2047)|0]|0;p=k}}while(0);a[9661057]=o;b[4830522]=p+1&65535;p=c[2415264]|0;o=9661064+(p>>>13&7)|0;k=a[o]|0;if(((k&255)<<13|p&6144|0)==2088960){l=d[9661075]|0;c[2440610]=(c[2440610]|0)-l;c[2415269]=(c[2415269]|0)-l;q=a[o]|0}else{q=k}k=(q&255)<<13|p&8191;q=c[2388530]|0;o=c[q+16+(k>>>11<<2)>>2]|0;do{if((o|0)==0){l=c[q>>2]|0;if((l|0)==0){r=0;s=p;break}e=gj[l&4095](k)|0;r=e;s=c[2415264]|0}else{r=a[o+(p&2047)|0]|0;s=p}}while(0);p=r<<1;a[9661063]=a[9661063]&92|(r&255)>>>7|p&-128|(p<<24>>24==0?2:0);r=9661064+(s>>>13&7)|0;o=a[r]|0;if(((o&255)<<13|s&6144|0)==2088960){k=d[9661075]|0;c[2440610]=(c[2440610]|0)-k;c[2415269]=(c[2415269]|0)-k;t=a[r]|0}else{t=o}o=(t&255)<<13|s&8191;t=c[2388530]|0;r=c[t+4112+(o>>>11<<2)>>2]|0;if((r|0)!=0){a[r+(s&2047)|0]=p;return}s=c[t+4>>2]|0;if((s|0)==0){return}gg[s&4095](o,p);return}function fzg(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=(d[9661075]|0)<<2;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=k;k=l+1&65535;b[4830522]=k;l=c[2415263]|0;c[2415264]=l;h=(d[9661065]|0)<<13|l&8191;e=c[m+16+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){a[9661063]=a[9661063]&-33;o=k;p=m;break}else{i=gj[f&4095](h)|0;q=i;r=b[4830522]|0;s=2617;break}}else{q=a[e+(l&2047)|0]|0;r=k;s=2617}}while(0);do{if((s|0)==2617){a[9661063]=a[9661063]&-33;if((q&1)==0){o=r;p=c[2388530]|0;break}b[4830522]=r+1&65535;k=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-k;c[2415269]=(c[2415269]|0)-k;return}}while(0);r=(d[9661075]|0)<<2;c[2440610]=(c[2440610]|0)-r;c[2415269]=(c[2415269]|0)-r;r=o&65535;q=(d[9661064+(r>>>13)|0]|0)<<13|r&8191;s=c[p+8208+(q>>>11<<2)>>2]|0;do{if((s|0)==0){k=c[p>>2]|0;if((k|0)==0){t=0;u=o;break}l=gj[k&4095](q)|0;t=l;u=b[4830522]|0}else{t=a[s+(r&2047)|0]|0;u=o}}while(0);b[4830528]=(u+1&65535)+(t<<24>>24)&65535;c[2415261]=c[2415264];return}function fzh(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=a[9661063]|0;a[9661063]=e&-33;if(e<<24>>24<0){b[4830522]=(b[4830522]|0)+1&65535;e=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;return}e=(d[9661075]|0)<<2;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;break}m=gj[j&4095](g)|0;k=m;l=b[4830522]|0}else{k=a[i+(f&2047)|0]|0;l=e}}while(0);b[4830528]=(l+1&65535)+(k<<24>>24)&65535;c[2415261]=c[2415264];return}function fzi(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;e=(d[9661075]|0)*-7|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=k;b[4830522]=l+1&65535;l=c[2415263]|0;k=(l&255|0)==255;h=a[9661065]|0;e=(h&255)<<13|l&8191;f=c[m+16+(e>>>11<<2)>>2]|0;do{if((f|0)==0){i=c[m>>2]|0;if((i|0)==0){o=0;p=h;q=l;break}g=gj[i&4095](e)|0;o=g;p=a[9661065]|0;q=c[2415263]|0}else{o=a[f+(l&2047)|0]|0;p=h;q=l}}while(0);l=o&255;o=(p&255)<<13;do{if(k){p=q+7937|0;h=p&8191|o;f=c[2388530]|0;e=c[f+16+(h>>>11<<2)>>2]|0;if((e|0)!=0){r=a[e+(p&2047)|0]|0;break}p=c[f>>2]|0;if((p|0)==0){r=0;break}r=gj[p&4095](h)|0}else{h=q+1|0;p=h&8191|o;f=c[2388530]|0;e=c[f+16+(p>>>11<<2)>>2]|0;if((e|0)!=0){r=a[e+(h&2047)|0]|0;break}h=c[f>>2]|0;if((h|0)==0){r=0;break}r=gj[h&4095](p)|0}}while(0);o=(r&255)<<8|l;c[2415264]=o;b[4830528]=(o&65535)+(d[9661062]|0)&65535;o=c[2415264]|0;l=9661064+(o>>>13&7)|0;r=a[l]|0;if(((r&255)<<13|o&6144|0)==2088960){q=d[9661075]|0;c[2440610]=(c[2440610]|0)-q;c[2415269]=(c[2415269]|0)-q;s=a[l]|0}else{s=r}r=(s&255)<<13|o&8191;s=c[2388530]|0;l=c[s+16+(r>>>11<<2)>>2]|0;do{if((l|0)==0){q=c[s>>2]|0;if((q|0)==0){t=0;break}t=gj[q&4095](r)|0}else{t=a[l+(o&2047)|0]|0}}while(0);o=a[9661063]|0;if((o&32)==0){l=a[9661060]|t;a[9661060]=l;a[9661063]=l&-128|o&93|(l<<24>>24==0?2:0);return}a[9661063]=o&-33;a[9661052]=a[9661061]|0;o=c[2415263]|0;c[2415264]=o;l=a[9661065]|0;r=(l&255)<<13|o&8191;s=c[2388530]|0;q=c[s+16+(r>>>11<<2)>>2]|0;do{if((q|0)==0){k=c[s>>2]|0;if((k|0)==0){u=0;v=l;w=o;x=s;break}p=gj[k&4095](r)|0;u=p;v=a[9661065]|0;w=c[2415264]|0;x=c[2388530]|0}else{u=a[q+(o&2047)|0]|0;v=l;w=o;x=s}}while(0);s=u|t;t=(v&255)<<13|w&8191;v=c[x+4112+(t>>>11<<2)>>2]|0;do{if((v|0)==0){u=c[x+4>>2]|0;if((u|0)==0){break}gg[u&4095](t,s)}else{a[v+(w&2047)|0]=s}}while(0);a[9661063]=(s<<24>>24==0?2:0)|s&-128|a[9661063]&93;s=(d[9661075]|0)*-3|0;c[2440610]=s+(c[2440610]|0);c[2415269]=s+(c[2415269]|0);return}function fzj(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;e=(d[9661075]|0)*-7|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=k;b[4830522]=l+1&65535;l=c[2415263]|0;k=(l&255|0)==255;h=a[9661065]|0;e=(h&255)<<13|l&8191;f=c[m+16+(e>>>11<<2)>>2]|0;do{if((f|0)==0){i=c[m>>2]|0;if((i|0)==0){o=0;p=h;q=l;break}g=gj[i&4095](e)|0;o=g;p=a[9661065]|0;q=c[2415263]|0}else{o=a[f+(l&2047)|0]|0;p=h;q=l}}while(0);l=o&255;o=(p&255)<<13;do{if(k){p=q+7937|0;h=p&8191|o;f=c[2388530]|0;e=c[f+16+(h>>>11<<2)>>2]|0;if((e|0)!=0){r=a[e+(p&2047)|0]|0;break}p=c[f>>2]|0;if((p|0)==0){r=0;break}r=gj[p&4095](h)|0}else{h=q+1|0;p=h&8191|o;f=c[2388530]|0;e=c[f+16+(p>>>11<<2)>>2]|0;if((e|0)!=0){r=a[e+(h&2047)|0]|0;break}h=c[f>>2]|0;if((h|0)==0){r=0;break}r=gj[h&4095](p)|0}}while(0);o=r&255;r=o<<8;q=r|l;c[2415264]=q;l=9661064+(o>>>5)|0;o=a[l]|0;if(((o&255)<<13|r&6144|0)==2088960){r=d[9661075]|0;c[2440610]=(c[2440610]|0)-r;c[2415269]=(c[2415269]|0)-r;s=a[l]|0}else{s=o}o=(s&255)<<13|q&8191;s=c[2388530]|0;l=c[s+16+(o>>>11<<2)>>2]|0;do{if((l|0)==0){r=c[s>>2]|0;if((r|0)==0){t=0;break}t=gj[r&4095](o)|0}else{t=a[l+(q&2047)|0]|0}}while(0);q=a[9661063]|0;if((q&32)==0){l=a[9661060]|t;a[9661060]=l;a[9661063]=l&-128|q&93|(l<<24>>24==0?2:0);return}a[9661063]=q&-33;a[9661052]=a[9661061]|0;q=c[2415263]|0;c[2415264]=q;l=a[9661065]|0;o=(l&255)<<13|q&8191;s=c[2388530]|0;r=c[s+16+(o>>>11<<2)>>2]|0;do{if((r|0)==0){k=c[s>>2]|0;if((k|0)==0){u=0;v=l;w=q;x=s;break}p=gj[k&4095](o)|0;u=p;v=a[9661065]|0;w=c[2415264]|0;x=c[2388530]|0}else{u=a[r+(q&2047)|0]|0;v=l;w=q;x=s}}while(0);s=u|t;t=(v&255)<<13|w&8191;v=c[x+4112+(t>>>11<<2)>>2]|0;do{if((v|0)==0){u=c[x+4>>2]|0;if((u|0)==0){break}gg[u&4095](t,s)}else{a[v+(w&2047)|0]=s}}while(0);a[9661063]=(s<<24>>24==0?2:0)|s&-128|a[9661063]&93;s=(d[9661075]|0)*-3|0;c[2440610]=s+(c[2440610]|0);c[2415269]=s+(c[2415269]|0);return}function fzk(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=(d[9661075]|0)*-5|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);b[4830522]=l+1&65535;a[9661063]=a[9661063]&-33;l=c[m+8>>2]|0;if((l|0)==0){return}gg[l&4095](2,k);return}function fzl(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=(d[9661075]|0)*-6|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=k;b[4830522]=l+1&65535;l=c[2415263]|0;c[2415264]=l;k=a[9661065]|0;h=(k&255)<<13|l&8191;e=c[m+16+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){o=0;p=k;q=l;r=m;break}i=gj[f&4095](h)|0;o=i;p=a[9661065]|0;q=c[2415264]|0;r=c[2388530]|0}else{o=a[e+(l&2047)|0]|0;p=k;q=l;r=m}}while(0);m=a[9661060]|0;a[9661063]=a[9661063]&29|o&-64|((o&255&~(m&255)|0)!=0?0:2);l=o&~m;m=(p&255)<<13|q&8191;p=c[r+4112+(m>>>11<<2)>>2]|0;if((p|0)!=0){a[p+(q&2047)|0]=l;return}q=c[r+4>>2]|0;if((q|0)==0){return}gg[q&4095](m,l);return}function fzm(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=(d[9661075]|0)<<2;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=(a[9661061]|0)+k&255;b[4830522]=l+1&65535;l=c[2415263]|0;c[2415264]=l;k=(d[9661065]|0)<<13|l&8191;h=c[m+16+(k>>>11<<2)>>2]|0;do{if((h|0)==0){e=c[m>>2]|0;if((e|0)==0){o=0;break}o=gj[e&4095](k)|0}else{o=a[h+(l&2047)|0]|0}}while(0);l=a[9661063]|0;if((l&32)==0){h=a[9661060]|o;a[9661060]=h;a[9661063]=h&-128|l&93|(h<<24>>24==0?2:0);return}a[9661063]=l&-33;a[9661052]=a[9661061]|0;l=c[2415263]|0;c[2415264]=l;h=a[9661065]|0;k=(h&255)<<13|l&8191;m=c[2388530]|0;e=c[m+16+(k>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){p=0;q=h;r=l;s=m;break}i=gj[f&4095](k)|0;p=i;q=a[9661065]|0;r=c[2415264]|0;s=c[2388530]|0}else{p=a[e+(l&2047)|0]|0;q=h;r=l;s=m}}while(0);m=p|o;o=(q&255)<<13|r&8191;q=c[s+4112+(o>>>11<<2)>>2]|0;do{if((q|0)==0){p=c[s+4>>2]|0;if((p|0)==0){break}gg[p&4095](o,m)}else{a[q+(r&2047)|0]=m}}while(0);a[9661063]=(m<<24>>24==0?2:0)|m&-128|a[9661063]&93;m=(d[9661075]|0)*-3|0;c[2440610]=m+(c[2440610]|0);c[2415269]=m+(c[2415269]|0);return}function fzn(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=(d[9661075]|0)*-6|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=(a[9661061]|0)+k&255;b[4830522]=l+1&65535;l=c[2415263]|0;c[2415264]=l;k=a[9661065]|0;h=(k&255)<<13|l&8191;e=c[m+16+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){o=0;p=k;q=l;r=m;break}i=gj[f&4095](h)|0;o=i;p=a[9661065]|0;q=c[2415264]|0;r=c[2388530]|0}else{o=a[e+(l&2047)|0]|0;p=k;q=l;r=m}}while(0);m=o<<1;a[9661063]=a[9661063]&92|(o&255)>>>7|m&-128|(m<<24>>24==0?2:0);o=(p&255)<<13|q&8191;p=c[r+4112+(o>>>11<<2)>>2]|0;if((p|0)!=0){a[p+(q&2047)|0]=m;return}q=c[r+4>>2]|0;if((q|0)==0){return}gg[q&4095](o,m);return}function fzo(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=(d[9661075]|0)*-7|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=k;b[4830522]=l+1&65535;l=c[2415263]|0;c[2415264]=l;k=a[9661065]|0;h=(k&255)<<13|l&8191;e=c[m+16+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){o=0;p=k;q=l;r=m;break}i=gj[f&4095](h)|0;o=i;p=a[9661065]|0;q=c[2415264]|0;r=c[2388530]|0}else{o=a[e+(l&2047)|0]|0;p=k;q=l;r=m}}while(0);a[9661063]=a[9661063]&-33;m=o&-3;o=(p&255)<<13|q&8191;p=c[r+4112+(o>>>11<<2)>>2]|0;if((p|0)!=0){a[p+(q&2047)|0]=m;return}q=c[r+4>>2]|0;if((q|0)==0){return}gg[q&4095](o,m);return}function fzp(){var b=0;b=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-b;c[2415269]=(c[2415269]|0)-b;a[9661063]=a[9661063]&-34;return}function fzq(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=(d[9661075]|0)*-5|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661056]=k;k=l+1&65535;b[4830522]=k;l=k&65535;h=(d[9661064+(l>>>13)|0]|0)<<13|l&8191;e=c[m+8208+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){o=0;p=k;break}i=gj[f&4095](h)|0;o=i;p=b[4830522]|0}else{o=a[e+(l&2047)|0]|0;p=k}}while(0);a[9661057]=o;b[4830522]=p+1&65535;b[4830528]=(b[4830528]|0)+(d[9661062]|0)&65535;p=c[2415264]|0;o=9661064+(p>>>13&7)|0;k=a[o]|0;if(((k&255)<<13|p&6144|0)==2088960){l=d[9661075]|0;c[2440610]=(c[2440610]|0)-l;c[2415269]=(c[2415269]|0)-l;q=a[o]|0}else{q=k}k=(q&255)<<13|p&8191;q=c[2388530]|0;o=c[q+16+(k>>>11<<2)>>2]|0;do{if((o|0)==0){l=c[q>>2]|0;if((l|0)==0){r=0;break}r=gj[l&4095](k)|0}else{r=a[o+(p&2047)|0]|0}}while(0);p=a[9661063]|0;if((p&32)==0){o=a[9661060]|r;a[9661060]=o;a[9661063]=o&-128|p&93|(o<<24>>24==0?2:0);return}a[9661063]=p&-33;a[9661052]=a[9661061]|0;p=c[2415263]|0;c[2415264]=p;o=a[9661065]|0;k=(o&255)<<13|p&8191;q=c[2388530]|0;l=c[q+16+(k>>>11<<2)>>2]|0;do{if((l|0)==0){e=c[q>>2]|0;if((e|0)==0){s=0;t=o;u=p;v=q;break}h=gj[e&4095](k)|0;s=h;t=a[9661065]|0;u=c[2415264]|0;v=c[2388530]|0}else{s=a[l+(p&2047)|0]|0;t=o;u=p;v=q}}while(0);q=s|r;r=(t&255)<<13|u&8191;t=c[v+4112+(r>>>11<<2)>>2]|0;do{if((t|0)==0){s=c[v+4>>2]|0;if((s|0)==0){break}gg[s&4095](r,q)}else{a[t+(u&2047)|0]=q}}while(0);a[9661063]=(q<<24>>24==0?2:0)|q&-128|a[9661063]&93;q=(d[9661075]|0)*-3|0;c[2440610]=q+(c[2440610]|0);c[2415269]=q+(c[2415269]|0);return}function fzr(){var b=0,e=0;b=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-b;c[2415269]=(c[2415269]|0)-b;b=a[9661063]|0;e=(a[9661060]|0)+1&255;a[9661060]=e;a[9661063]=e&-128|b&93|(e<<24>>24==0?2:0);return}function fzs(){var b=0;b=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-b;c[2415269]=(c[2415269]|0)-b;a[9661063]=a[9661063]&-33;return}function fzt(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=(d[9661075]|0)*-7|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661056]=k;k=l+1&65535;b[4830522]=k;l=k&65535;h=(d[9661064+(l>>>13)|0]|0)<<13|l&8191;e=c[m+8208+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){o=0;p=k;break}i=gj[f&4095](h)|0;o=i;p=b[4830522]|0}else{o=a[e+(l&2047)|0]|0;p=k}}while(0);a[9661057]=o;b[4830522]=p+1&65535;p=c[2415264]|0;o=9661064+(p>>>13&7)|0;k=a[o]|0;if(((k&255)<<13|p&6144|0)==2088960){l=d[9661075]|0;c[2440610]=(c[2440610]|0)-l;c[2415269]=(c[2415269]|0)-l;q=a[o]|0}else{q=k}k=(q&255)<<13|p&8191;q=c[2388530]|0;o=c[q+16+(k>>>11<<2)>>2]|0;do{if((o|0)==0){l=c[q>>2]|0;if((l|0)==0){r=0;s=p;break}e=gj[l&4095](k)|0;r=e;s=c[2415264]|0}else{r=a[o+(p&2047)|0]|0;s=p}}while(0);p=a[9661060]|0;a[9661063]=a[9661063]&29|r&-64|((r&255&~(p&255)|0)!=0?0:2);o=r&~p;p=9661064+(s>>>13&7)|0;r=a[p]|0;if(((r&255)<<13|s&6144|0)==2088960){k=d[9661075]|0;c[2440610]=(c[2440610]|0)-k;c[2415269]=(c[2415269]|0)-k;t=a[p]|0}else{t=r}r=(t&255)<<13|s&8191;t=c[2388530]|0;p=c[t+4112+(r>>>11<<2)>>2]|0;if((p|0)!=0){a[p+(s&2047)|0]=o;return}s=c[t+4>>2]|0;if((s|0)==0){return}gg[s&4095](r,o);return}function fzu(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=(d[9661075]|0)*-5|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661056]=k;k=l+1&65535;b[4830522]=k;l=k&65535;h=(d[9661064+(l>>>13)|0]|0)<<13|l&8191;e=c[m+8208+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){o=0;p=k;break}i=gj[f&4095](h)|0;o=i;p=b[4830522]|0}else{o=a[e+(l&2047)|0]|0;p=k}}while(0);a[9661057]=o;b[4830522]=p+1&65535;b[4830528]=(b[4830528]|0)+(d[9661061]|0)&65535;p=c[2415264]|0;o=9661064+(p>>>13&7)|0;k=a[o]|0;if(((k&255)<<13|p&6144|0)==2088960){l=d[9661075]|0;c[2440610]=(c[2440610]|0)-l;c[2415269]=(c[2415269]|0)-l;q=a[o]|0}else{q=k}k=(q&255)<<13|p&8191;q=c[2388530]|0;o=c[q+16+(k>>>11<<2)>>2]|0;do{if((o|0)==0){l=c[q>>2]|0;if((l|0)==0){r=0;break}r=gj[l&4095](k)|0}else{r=a[o+(p&2047)|0]|0}}while(0);p=a[9661063]|0;if((p&32)==0){o=a[9661060]|r;a[9661060]=o;a[9661063]=o&-128|p&93|(o<<24>>24==0?2:0);return}a[9661063]=p&-33;a[9661052]=a[9661061]|0;p=c[2415263]|0;c[2415264]=p;o=a[9661065]|0;k=(o&255)<<13|p&8191;q=c[2388530]|0;l=c[q+16+(k>>>11<<2)>>2]|0;do{if((l|0)==0){e=c[q>>2]|0;if((e|0)==0){s=0;t=o;u=p;v=q;break}h=gj[e&4095](k)|0;s=h;t=a[9661065]|0;u=c[2415264]|0;v=c[2388530]|0}else{s=a[l+(p&2047)|0]|0;t=o;u=p;v=q}}while(0);q=s|r;r=(t&255)<<13|u&8191;t=c[v+4112+(r>>>11<<2)>>2]|0;do{if((t|0)==0){s=c[v+4>>2]|0;if((s|0)==0){break}gg[s&4095](r,q)}else{a[t+(u&2047)|0]=q}}while(0);a[9661063]=(q<<24>>24==0?2:0)|q&-128|a[9661063]&93;q=(d[9661075]|0)*-3|0;c[2440610]=q+(c[2440610]|0);c[2415269]=q+(c[2415269]|0);return}function fzv(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=(d[9661075]|0)*-7|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661056]=k;k=l+1&65535;b[4830522]=k;l=k&65535;h=(d[9661064+(l>>>13)|0]|0)<<13|l&8191;e=c[m+8208+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){o=0;p=k;break}i=gj[f&4095](h)|0;o=i;p=b[4830522]|0}else{o=a[e+(l&2047)|0]|0;p=k}}while(0);a[9661057]=o;b[4830522]=p+1&65535;b[4830528]=(b[4830528]|0)+(d[9661061]|0)&65535;p=c[2415264]|0;o=9661064+(p>>>13&7)|0;k=a[o]|0;if(((k&255)<<13|p&6144|0)==2088960){l=d[9661075]|0;c[2440610]=(c[2440610]|0)-l;c[2415269]=(c[2415269]|0)-l;q=a[o]|0}else{q=k}k=(q&255)<<13|p&8191;q=c[2388530]|0;o=c[q+16+(k>>>11<<2)>>2]|0;do{if((o|0)==0){l=c[q>>2]|0;if((l|0)==0){r=0;s=p;break}e=gj[l&4095](k)|0;r=e;s=c[2415264]|0}else{r=a[o+(p&2047)|0]|0;s=p}}while(0);p=r<<1;a[9661063]=a[9661063]&92|(r&255)>>>7|p&-128|(p<<24>>24==0?2:0);r=9661064+(s>>>13&7)|0;o=a[r]|0;if(((o&255)<<13|s&6144|0)==2088960){k=d[9661075]|0;c[2440610]=(c[2440610]|0)-k;c[2415269]=(c[2415269]|0)-k;t=a[r]|0}else{t=o}o=(t&255)<<13|s&8191;t=c[2388530]|0;r=c[t+4112+(o>>>11<<2)>>2]|0;if((r|0)!=0){a[r+(s&2047)|0]=p;return}s=c[t+4>>2]|0;if((s|0)==0){return}gg[s&4095](o,p);return}function fzw(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=(d[9661075]|0)<<2;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=k;k=l+1&65535;b[4830522]=k;l=c[2415263]|0;c[2415264]=l;h=(d[9661065]|0)<<13|l&8191;e=c[m+16+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){a[9661063]=a[9661063]&-33;o=k;p=m;break}else{i=gj[f&4095](h)|0;q=i;r=b[4830522]|0;s=2907;break}}else{q=a[e+(l&2047)|0]|0;r=k;s=2907}}while(0);do{if((s|0)==2907){a[9661063]=a[9661063]&-33;if((q&2)==0){o=r;p=c[2388530]|0;break}b[4830522]=r+1&65535;k=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-k;c[2415269]=(c[2415269]|0)-k;return}}while(0);r=(d[9661075]|0)<<2;c[2440610]=(c[2440610]|0)-r;c[2415269]=(c[2415269]|0)-r;r=o&65535;q=(d[9661064+(r>>>13)|0]|0)<<13|r&8191;s=c[p+8208+(q>>>11<<2)>>2]|0;do{if((s|0)==0){k=c[p>>2]|0;if((k|0)==0){t=0;u=o;break}l=gj[k&4095](q)|0;t=l;u=b[4830522]|0}else{t=a[s+(r&2047)|0]|0;u=o}}while(0);b[4830528]=(u+1&65535)+(t<<24>>24)&65535;c[2415261]=c[2415264];return}function fzx(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=(d[9661075]|0)*-7|0;c[2440610]=f+(c[2440610]|0);c[2415269]=f+(c[2415269]|0);f=b[4830522]|0;g=f&65535;h=(d[9661064+(g>>>13)|0]|0)<<13|g&8191;i=c[2388530]|0;j=c[i+8208+(h>>>11<<2)>>2]|0;do{if((j|0)==0){k=c[i>>2]|0;if((k|0)==0){l=0;m=f;n=i;break}o=gj[k&4095](h)|0;l=o;m=b[4830522]|0;n=c[2388530]|0}else{l=a[j+(g&2047)|0]|0;m=f;n=i}}while(0);a[9661056]=l;l=m+1&65535;b[4830522]=l;m=l&65535;i=(d[9661064+(m>>>13)|0]|0)<<13|m&8191;f=c[n+8208+(i>>>11<<2)>>2]|0;do{if((f|0)==0){g=c[n>>2]|0;if((g|0)==0){p=0;q=(l&65535)>>>8&255;r=n;break}j=gj[g&4095](i)|0;p=j;q=(e[4830522]|0)>>>8&255;r=c[2388530]|0}else{p=a[f+(m&2047)|0]|0;q=(l&65535)>>>8&255;r=n}}while(0);a[9661057]=p;a[9661063]=a[9661063]&-33;p=c[2415262]|0;n=(d[9661065]|0)<<13|p&2097151;l=c[r+4112+(n>>>11<<2)>>2]|0;do{if((l|0)==0){m=c[r+4>>2]|0;if((m|0)==0){s=r;break}gg[m&4095](n,q);s=c[2388530]|0}else{a[l+(p&2047)|0]=q;s=r}}while(0);a[9661048]=(a[9661048]|0)-1&255;r=c[2415262]|0;q=a[9661044]|0;p=(d[9661065]|0)<<13|r&2097151;l=c[s+4112+(p>>>11<<2)>>2]|0;if((l|0)!=0){a[l+(r&2047)|0]=q;t=a[9661048]|0;u=t-1&255;a[9661048]=u;v=c[2415264]|0;c[2415261]=v;return}r=c[s+4>>2]|0;if((r|0)==0){t=a[9661048]|0;u=t-1&255;a[9661048]=u;v=c[2415264]|0;c[2415261]=v;return}gg[r&4095](p,q);t=a[9661048]|0;u=t-1&255;a[9661048]=u;v=c[2415264]|0;c[2415261]=v;return}function fzy(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;e=(d[9661075]|0)*-7|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=(a[9661061]|0)+k&255;b[4830522]=l+1&65535;l=c[2415263]|0;k=(l&255|0)==255;h=a[9661065]|0;e=(h&255)<<13|l&8191;f=c[m+16+(e>>>11<<2)>>2]|0;do{if((f|0)==0){i=c[m>>2]|0;if((i|0)==0){o=0;p=h;q=l;break}g=gj[i&4095](e)|0;o=g;p=a[9661065]|0;q=c[2415263]|0}else{o=a[f+(l&2047)|0]|0;p=h;q=l}}while(0);l=o&255;o=(p&255)<<13;do{if(k){p=q+7937|0;h=p&8191|o;f=c[2388530]|0;e=c[f+16+(h>>>11<<2)>>2]|0;if((e|0)!=0){r=a[e+(p&2047)|0]|0;break}p=c[f>>2]|0;if((p|0)==0){r=0;break}r=gj[p&4095](h)|0}else{h=q+1|0;p=h&8191|o;f=c[2388530]|0;e=c[f+16+(p>>>11<<2)>>2]|0;if((e|0)!=0){r=a[e+(h&2047)|0]|0;break}h=c[f>>2]|0;if((h|0)==0){r=0;break}r=gj[h&4095](p)|0}}while(0);o=r&255;r=o<<8;q=r|l;c[2415264]=q;l=9661064+(o>>>5)|0;o=a[l]|0;if(((o&255)<<13|r&6144|0)==2088960){r=d[9661075]|0;c[2440610]=(c[2440610]|0)-r;c[2415269]=(c[2415269]|0)-r;s=a[l]|0}else{s=o}o=(s&255)<<13|q&8191;s=c[2388530]|0;l=c[s+16+(o>>>11<<2)>>2]|0;do{if((l|0)==0){r=c[s>>2]|0;if((r|0)==0){t=0;break}t=gj[r&4095](o)|0}else{t=a[l+(q&2047)|0]|0}}while(0);q=a[9661063]|0;if((q&32)==0){l=a[9661060]&t;a[9661060]=l;a[9661063]=l&-128|q&93|(l<<24>>24==0?2:0);return}a[9661063]=q&-33;a[9661052]=a[9661061]|0;q=c[2415263]|0;c[2415264]=q;l=a[9661065]|0;o=(l&255)<<13|q&8191;s=c[2388530]|0;r=c[s+16+(o>>>11<<2)>>2]|0;do{if((r|0)==0){k=c[s>>2]|0;if((k|0)==0){u=0;v=l;w=q;x=s;break}p=gj[k&4095](o)|0;u=p;v=a[9661065]|0;w=c[2415264]|0;x=c[2388530]|0}else{u=a[r+(q&2047)|0]|0;v=l;w=q;x=s}}while(0);s=u&t;t=(v&255)<<13|w&8191;v=c[x+4112+(t>>>11<<2)>>2]|0;do{if((v|0)==0){u=c[x+4>>2]|0;if((u|0)==0){break}gg[u&4095](t,s)}else{a[v+(w&2047)|0]=s}}while(0);a[9661063]=(s<<24>>24==0?2:0)|s&-128|a[9661063]&93;s=(d[9661075]|0)*-3|0;c[2440610]=s+(c[2440610]|0);c[2415269]=s+(c[2415269]|0);return}function fzz(){var b=0;b=(d[9661075]|0)*-3|0;c[2440610]=b+(c[2440610]|0);c[2415269]=b+(c[2415269]|0);a[9661063]=a[9661063]&-33;b=a[9661061]|0;a[9661061]=a[9661060]|0;a[9661060]=b;return}function fzA(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=(d[9661075]|0)*-5|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);b[4830522]=l+1&65535;a[9661063]=a[9661063]&-33;l=c[m+8>>2]|0;if((l|0)==0){return}gg[l&4095](3,k);return}function fzB(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=(d[9661075]|0)<<2;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=k;b[4830522]=l+1&65535;l=c[2415263]|0;c[2415264]=l;k=(d[9661065]|0)<<13|l&8191;h=c[m+16+(k>>>11<<2)>>2]|0;do{if((h|0)==0){e=c[m>>2]|0;if((e|0)==0){o=0;break}o=gj[e&4095](k)|0}else{o=a[h+(l&2047)|0]|0}}while(0);a[9661063]=a[9661063]&29|o&-64|((a[9661060]&o)<<24>>24!=0?0:2);return}function fzC(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=(d[9661075]|0)<<2;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=k;b[4830522]=l+1&65535;l=c[2415263]|0;c[2415264]=l;k=(d[9661065]|0)<<13|l&8191;h=c[m+16+(k>>>11<<2)>>2]|0;do{if((h|0)==0){e=c[m>>2]|0;if((e|0)==0){o=0;break}o=gj[e&4095](k)|0}else{o=a[h+(l&2047)|0]|0}}while(0);l=a[9661063]|0;if((l&32)==0){h=a[9661060]&o;a[9661060]=h;a[9661063]=h&-128|l&93|(h<<24>>24==0?2:0);return}a[9661063]=l&-33;a[9661052]=a[9661061]|0;l=c[2415263]|0;c[2415264]=l;h=a[9661065]|0;k=(h&255)<<13|l&8191;m=c[2388530]|0;e=c[m+16+(k>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){p=0;q=h;r=l;s=m;break}i=gj[f&4095](k)|0;p=i;q=a[9661065]|0;r=c[2415264]|0;s=c[2388530]|0}else{p=a[e+(l&2047)|0]|0;q=h;r=l;s=m}}while(0);m=p&o;o=(q&255)<<13|r&8191;q=c[s+4112+(o>>>11<<2)>>2]|0;do{if((q|0)==0){p=c[s+4>>2]|0;if((p|0)==0){break}gg[p&4095](o,m)}else{a[q+(r&2047)|0]=m}}while(0);a[9661063]=(m<<24>>24==0?2:0)|m&-128|a[9661063]&93;m=(d[9661075]|0)*-3|0;c[2440610]=m+(c[2440610]|0);c[2415269]=m+(c[2415269]|0);return}function fzD(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=(d[9661075]|0)*-6|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=k;b[4830522]=l+1&65535;l=c[2415263]|0;c[2415264]=l;k=a[9661065]|0;h=(k&255)<<13|l&8191;e=c[m+16+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){o=0;p=k;q=l;r=m;break}i=gj[f&4095](h)|0;o=i;p=a[9661065]|0;q=c[2415264]|0;r=c[2388530]|0}else{o=a[e+(l&2047)|0]|0;p=k;q=l;r=m}}while(0);m=a[9661063]|0;l=o<<1;k=m&1|l;a[9661063]=m&92|(o&255)>>>7|l&-128|(k<<24>>24==0?2:0);l=(p&255)<<13|q&8191;p=c[r+4112+(l>>>11<<2)>>2]|0;if((p|0)!=0){a[p+(q&2047)|0]=k;return}q=c[r+4>>2]|0;if((q|0)==0){return}gg[q&4095](l,k);return}function fzE(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=(d[9661075]|0)*-7|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=k;b[4830522]=l+1&65535;l=c[2415263]|0;c[2415264]=l;k=a[9661065]|0;h=(k&255)<<13|l&8191;e=c[m+16+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){o=0;p=k;q=l;r=m;break}i=gj[f&4095](h)|0;o=i;p=a[9661065]|0;q=c[2415264]|0;r=c[2388530]|0}else{o=a[e+(l&2047)|0]|0;p=k;q=l;r=m}}while(0);a[9661063]=a[9661063]&-33;m=o&-5;o=(p&255)<<13|q&8191;p=c[r+4112+(o>>>11<<2)>>2]|0;if((p|0)!=0){a[p+(q&2047)|0]=m;return}q=c[r+4>>2]|0;if((q|0)==0){return}gg[q&4095](o,m);return}function fzF(){var b=0,e=0,f=0,g=0,h=0,i=0;b=d[9661075]<<2;c[2440610]=(c[2440610]|0)-b;c[2415269]=(c[2415269]|0)-b;a[9661048]=(a[9661048]|0)+1&255;b=c[2415262]|0;e=d[9661065]<<13|b&2097151;f=c[2388530]|0;g=c[f+16+(e>>>11<<2)>>2]|0;do{if((g|0)==0){h=c[f>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](e)|0}else{i=a[g+(b&2047)|0]|0}}while(0);a[9661063]=i|16;if((a[9661088]|0)!=0){return}a[9661088]=2;return}function fzG(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;break}m=gj[j&4095](g)|0;k=m;l=b[4830522]|0}else{k=a[i+(f&2047)|0]|0;l=e}}while(0);b[4830522]=l+1&65535;l=a[9661063]|0;if((l&32)==0){e=a[9661060]&k;a[9661060]=e;a[9661063]=e&-128|l&93|(e<<24>>24==0?2:0);return}a[9661063]=l&-33;a[9661052]=a[9661061]|0;l=c[2415263]|0;c[2415264]=l;e=a[9661065]|0;f=(e&255)<<13|l&8191;i=c[2388530]|0;g=c[i+16+(f>>>11<<2)>>2]|0;do{if((g|0)==0){h=c[i>>2]|0;if((h|0)==0){n=0;o=e;p=l;q=i;break}m=gj[h&4095](f)|0;n=m;o=a[9661065]|0;p=c[2415264]|0;q=c[2388530]|0}else{n=a[g+(l&2047)|0]|0;o=e;p=l;q=i}}while(0);i=n&k;k=(o&255)<<13|p&8191;o=c[q+4112+(k>>>11<<2)>>2]|0;do{if((o|0)==0){n=c[q+4>>2]|0;if((n|0)==0){break}gg[n&4095](k,i)}else{a[o+(p&2047)|0]=i}}while(0);a[9661063]=(i<<24>>24==0?2:0)|i&-128|a[9661063]&93;i=(d[9661075]|0)*-3|0;c[2440610]=i+(c[2440610]|0);c[2415269]=i+(c[2415269]|0);return}function fzH(){var b=0,e=0,f=0,g=0;b=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-b;c[2415269]=(c[2415269]|0)-b;b=a[9661060]|0;e=a[9661063]|0;f=b<<1;g=e&1|f;a[9661063]=e&92|(b&255)>>>7|f&-128|(g<<24>>24==0?2:0);a[9661060]=g;return}function fzI(){var b=0;b=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-b;c[2415269]=(c[2415269]|0)-b;a[9661063]=a[9661063]&-33;return}function fzJ(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;e=(d[9661075]|0)*-5|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661056]=k;k=l+1&65535;b[4830522]=k;l=k&65535;h=(d[9661064+(l>>>13)|0]|0)<<13|l&8191;e=c[m+8208+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){o=0;p=k;break}i=gj[f&4095](h)|0;o=i;p=b[4830522]|0}else{o=a[e+(l&2047)|0]|0;p=k}}while(0);a[9661057]=o;b[4830522]=p+1&65535;p=c[2415264]|0;o=9661064+(p>>>13&7)|0;k=a[o]|0;if(((k&255)<<13|p&6144|0)==2088960){l=d[9661075]|0;c[2440610]=(c[2440610]|0)-l;c[2415269]=(c[2415269]|0)-l;q=a[o]|0}else{q=k}k=(q&255)<<13|p&8191;q=c[2388530]|0;o=c[q+16+(k>>>11<<2)>>2]|0;if((o|0)!=0){r=a[o+(p&2047)|0]|0;s=a[9661063]|0;t=s&29;u=a[9661060]|0;v=u&r;w=v<<24>>24!=0;x=w?0:2;y=r&-64;z=t|y;A=z|x;a[9661063]=A;return}p=c[q>>2]|0;if((p|0)==0){r=0;s=a[9661063]|0;t=s&29;u=a[9661060]|0;v=u&r;w=v<<24>>24!=0;x=w?0:2;y=r&-64;z=t|y;A=z|x;a[9661063]=A;return}r=gj[p&4095](k)|0;s=a[9661063]|0;t=s&29;u=a[9661060]|0;v=u&r;w=v<<24>>24!=0;x=w?0:2;y=r&-64;z=t|y;A=z|x;a[9661063]=A;return}function fzK(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=(d[9661075]|0)*-5|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661056]=k;k=l+1&65535;b[4830522]=k;l=k&65535;h=(d[9661064+(l>>>13)|0]|0)<<13|l&8191;e=c[m+8208+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){o=0;p=k;break}i=gj[f&4095](h)|0;o=i;p=b[4830522]|0}else{o=a[e+(l&2047)|0]|0;p=k}}while(0);a[9661057]=o;b[4830522]=p+1&65535;p=c[2415264]|0;o=9661064+(p>>>13&7)|0;k=a[o]|0;if(((k&255)<<13|p&6144|0)==2088960){l=d[9661075]|0;c[2440610]=(c[2440610]|0)-l;c[2415269]=(c[2415269]|0)-l;q=a[o]|0}else{q=k}k=(q&255)<<13|p&8191;q=c[2388530]|0;o=c[q+16+(k>>>11<<2)>>2]|0;do{if((o|0)==0){l=c[q>>2]|0;if((l|0)==0){r=0;break}r=gj[l&4095](k)|0}else{r=a[o+(p&2047)|0]|0}}while(0);p=a[9661063]|0;if((p&32)==0){o=a[9661060]&r;a[9661060]=o;a[9661063]=o&-128|p&93|(o<<24>>24==0?2:0);return}a[9661063]=p&-33;a[9661052]=a[9661061]|0;p=c[2415263]|0;c[2415264]=p;o=a[9661065]|0;k=(o&255)<<13|p&8191;q=c[2388530]|0;l=c[q+16+(k>>>11<<2)>>2]|0;do{if((l|0)==0){e=c[q>>2]|0;if((e|0)==0){s=0;t=o;u=p;v=q;break}h=gj[e&4095](k)|0;s=h;t=a[9661065]|0;u=c[2415264]|0;v=c[2388530]|0}else{s=a[l+(p&2047)|0]|0;t=o;u=p;v=q}}while(0);q=s&r;r=(t&255)<<13|u&8191;t=c[v+4112+(r>>>11<<2)>>2]|0;do{if((t|0)==0){s=c[v+4>>2]|0;if((s|0)==0){break}gg[s&4095](r,q)}else{a[t+(u&2047)|0]=q}}while(0);a[9661063]=(q<<24>>24==0?2:0)|q&-128|a[9661063]&93;q=(d[9661075]|0)*-3|0;c[2440610]=q+(c[2440610]|0);c[2415269]=q+(c[2415269]|0);return}function fzL(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=(d[9661075]|0)*-7|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661056]=k;k=l+1&65535;b[4830522]=k;l=k&65535;h=(d[9661064+(l>>>13)|0]|0)<<13|l&8191;e=c[m+8208+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){o=0;p=k;break}i=gj[f&4095](h)|0;o=i;p=b[4830522]|0}else{o=a[e+(l&2047)|0]|0;p=k}}while(0);a[9661057]=o;b[4830522]=p+1&65535;p=c[2415264]|0;o=9661064+(p>>>13&7)|0;k=a[o]|0;if(((k&255)<<13|p&6144|0)==2088960){l=d[9661075]|0;c[2440610]=(c[2440610]|0)-l;c[2415269]=(c[2415269]|0)-l;q=a[o]|0}else{q=k}k=(q&255)<<13|p&8191;q=c[2388530]|0;o=c[q+16+(k>>>11<<2)>>2]|0;do{if((o|0)==0){l=c[q>>2]|0;if((l|0)==0){r=0;s=p;break}e=gj[l&4095](k)|0;r=e;s=c[2415264]|0}else{r=a[o+(p&2047)|0]|0;s=p}}while(0);p=a[9661063]|0;o=r<<1;k=p&1|o;a[9661063]=p&92|(r&255)>>>7|o&-128|(k<<24>>24==0?2:0);o=9661064+(s>>>13&7)|0;r=a[o]|0;if(((r&255)<<13|s&6144|0)==2088960){p=d[9661075]|0;c[2440610]=(c[2440610]|0)-p;c[2415269]=(c[2415269]|0)-p;t=a[o]|0}else{t=r}r=(t&255)<<13|s&8191;t=c[2388530]|0;o=c[t+4112+(r>>>11<<2)>>2]|0;if((o|0)!=0){a[o+(s&2047)|0]=k;return}s=c[t+4>>2]|0;if((s|0)==0){return}gg[s&4095](r,k);return}function fzM(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=(d[9661075]|0)<<2;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=k;k=l+1&65535;b[4830522]=k;l=c[2415263]|0;c[2415264]=l;h=(d[9661065]|0)<<13|l&8191;e=c[m+16+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){a[9661063]=a[9661063]&-33;o=k;p=m;break}else{i=gj[f&4095](h)|0;q=i;r=b[4830522]|0;s=3156;break}}else{q=a[e+(l&2047)|0]|0;r=k;s=3156}}while(0);do{if((s|0)==3156){a[9661063]=a[9661063]&-33;if((q&4)==0){o=r;p=c[2388530]|0;break}b[4830522]=r+1&65535;k=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-k;c[2415269]=(c[2415269]|0)-k;return}}while(0);r=(d[9661075]|0)<<2;c[2440610]=(c[2440610]|0)-r;c[2415269]=(c[2415269]|0)-r;r=o&65535;q=(d[9661064+(r>>>13)|0]|0)<<13|r&8191;s=c[p+8208+(q>>>11<<2)>>2]|0;do{if((s|0)==0){k=c[p>>2]|0;if((k|0)==0){t=0;u=o;break}l=gj[k&4095](q)|0;t=l;u=b[4830522]|0}else{t=a[s+(r&2047)|0]|0;u=o}}while(0);b[4830528]=(u+1&65535)+(t<<24>>24)&65535;c[2415261]=c[2415264];return}function fzN(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=a[9661063]|0;a[9661063]=e&-33;if(e<<24>>24>=0){b[4830522]=(b[4830522]|0)+1&65535;e=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;return}e=(d[9661075]|0)<<2;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;break}m=gj[j&4095](g)|0;k=m;l=b[4830522]|0}else{k=a[i+(f&2047)|0]|0;l=e}}while(0);b[4830528]=(l+1&65535)+(k<<24>>24)&65535;c[2415261]=c[2415264];return}function fzO(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;e=(d[9661075]|0)*-7|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=k;b[4830522]=l+1&65535;l=c[2415263]|0;k=(l&255|0)==255;h=a[9661065]|0;e=(h&255)<<13|l&8191;f=c[m+16+(e>>>11<<2)>>2]|0;do{if((f|0)==0){i=c[m>>2]|0;if((i|0)==0){o=0;p=h;q=l;break}g=gj[i&4095](e)|0;o=g;p=a[9661065]|0;q=c[2415263]|0}else{o=a[f+(l&2047)|0]|0;p=h;q=l}}while(0);l=o&255;o=(p&255)<<13;do{if(k){p=q+7937|0;h=p&8191|o;f=c[2388530]|0;e=c[f+16+(h>>>11<<2)>>2]|0;if((e|0)!=0){r=a[e+(p&2047)|0]|0;break}p=c[f>>2]|0;if((p|0)==0){r=0;break}r=gj[p&4095](h)|0}else{h=q+1|0;p=h&8191|o;f=c[2388530]|0;e=c[f+16+(p>>>11<<2)>>2]|0;if((e|0)!=0){r=a[e+(h&2047)|0]|0;break}h=c[f>>2]|0;if((h|0)==0){r=0;break}r=gj[h&4095](p)|0}}while(0);o=(r&255)<<8|l;c[2415264]=o;b[4830528]=(o&65535)+(d[9661062]|0)&65535;o=c[2415264]|0;l=9661064+(o>>>13&7)|0;r=a[l]|0;if(((r&255)<<13|o&6144|0)==2088960){q=d[9661075]|0;c[2440610]=(c[2440610]|0)-q;c[2415269]=(c[2415269]|0)-q;s=a[l]|0}else{s=r}r=(s&255)<<13|o&8191;s=c[2388530]|0;l=c[s+16+(r>>>11<<2)>>2]|0;do{if((l|0)==0){q=c[s>>2]|0;if((q|0)==0){t=0;break}t=gj[q&4095](r)|0}else{t=a[l+(o&2047)|0]|0}}while(0);o=a[9661063]|0;if((o&32)==0){l=a[9661060]&t;a[9661060]=l;a[9661063]=l&-128|o&93|(l<<24>>24==0?2:0);return}a[9661063]=o&-33;a[9661052]=a[9661061]|0;o=c[2415263]|0;c[2415264]=o;l=a[9661065]|0;r=(l&255)<<13|o&8191;s=c[2388530]|0;q=c[s+16+(r>>>11<<2)>>2]|0;do{if((q|0)==0){k=c[s>>2]|0;if((k|0)==0){u=0;v=l;w=o;x=s;break}p=gj[k&4095](r)|0;u=p;v=a[9661065]|0;w=c[2415264]|0;x=c[2388530]|0}else{u=a[q+(o&2047)|0]|0;v=l;w=o;x=s}}while(0);s=u&t;t=(v&255)<<13|w&8191;v=c[x+4112+(t>>>11<<2)>>2]|0;do{if((v|0)==0){u=c[x+4>>2]|0;if((u|0)==0){break}gg[u&4095](t,s)}else{a[v+(w&2047)|0]=s}}while(0);a[9661063]=(s<<24>>24==0?2:0)|s&-128|a[9661063]&93;s=(d[9661075]|0)*-3|0;c[2440610]=s+(c[2440610]|0);c[2415269]=s+(c[2415269]|0);return}function fzP(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;e=(d[9661075]|0)*-7|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=k;b[4830522]=l+1&65535;l=c[2415263]|0;k=(l&255|0)==255;h=a[9661065]|0;e=(h&255)<<13|l&8191;f=c[m+16+(e>>>11<<2)>>2]|0;do{if((f|0)==0){i=c[m>>2]|0;if((i|0)==0){o=0;p=h;q=l;break}g=gj[i&4095](e)|0;o=g;p=a[9661065]|0;q=c[2415263]|0}else{o=a[f+(l&2047)|0]|0;p=h;q=l}}while(0);l=o&255;o=(p&255)<<13;do{if(k){p=q+7937|0;h=p&8191|o;f=c[2388530]|0;e=c[f+16+(h>>>11<<2)>>2]|0;if((e|0)!=0){r=a[e+(p&2047)|0]|0;break}p=c[f>>2]|0;if((p|0)==0){r=0;break}r=gj[p&4095](h)|0}else{h=q+1|0;p=h&8191|o;f=c[2388530]|0;e=c[f+16+(p>>>11<<2)>>2]|0;if((e|0)!=0){r=a[e+(h&2047)|0]|0;break}h=c[f>>2]|0;if((h|0)==0){r=0;break}r=gj[h&4095](p)|0}}while(0);o=r&255;r=o<<8;q=r|l;c[2415264]=q;l=9661064+(o>>>5)|0;o=a[l]|0;if(((o&255)<<13|r&6144|0)==2088960){r=d[9661075]|0;c[2440610]=(c[2440610]|0)-r;c[2415269]=(c[2415269]|0)-r;s=a[l]|0}else{s=o}o=(s&255)<<13|q&8191;s=c[2388530]|0;l=c[s+16+(o>>>11<<2)>>2]|0;do{if((l|0)==0){r=c[s>>2]|0;if((r|0)==0){t=0;break}t=gj[r&4095](o)|0}else{t=a[l+(q&2047)|0]|0}}while(0);q=a[9661063]|0;if((q&32)==0){l=a[9661060]&t;a[9661060]=l;a[9661063]=l&-128|q&93|(l<<24>>24==0?2:0);return}a[9661063]=q&-33;a[9661052]=a[9661061]|0;q=c[2415263]|0;c[2415264]=q;l=a[9661065]|0;o=(l&255)<<13|q&8191;s=c[2388530]|0;r=c[s+16+(o>>>11<<2)>>2]|0;do{if((r|0)==0){k=c[s>>2]|0;if((k|0)==0){u=0;v=l;w=q;x=s;break}p=gj[k&4095](o)|0;u=p;v=a[9661065]|0;w=c[2415264]|0;x=c[2388530]|0}else{u=a[r+(q&2047)|0]|0;v=l;w=q;x=s}}while(0);s=u&t;t=(v&255)<<13|w&8191;v=c[x+4112+(t>>>11<<2)>>2]|0;do{if((v|0)==0){u=c[x+4>>2]|0;if((u|0)==0){break}gg[u&4095](t,s)}else{a[v+(w&2047)|0]=s}}while(0);a[9661063]=(s<<24>>24==0?2:0)|s&-128|a[9661063]&93;s=(d[9661075]|0)*-3|0;c[2440610]=s+(c[2440610]|0);c[2415269]=s+(c[2415269]|0);return}function fzQ(){var b=0;b=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-b;c[2415269]=(c[2415269]|0)-b;a[9661063]=a[9661063]&-33;return}function fzR(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=(d[9661075]|0)<<2;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=(a[9661061]|0)+k&255;b[4830522]=l+1&65535;l=c[2415263]|0;c[2415264]=l;k=(d[9661065]|0)<<13|l&8191;h=c[m+16+(k>>>11<<2)>>2]|0;do{if((h|0)==0){e=c[m>>2]|0;if((e|0)==0){o=0;break}o=gj[e&4095](k)|0}else{o=a[h+(l&2047)|0]|0}}while(0);a[9661063]=a[9661063]&29|o&-64|((a[9661060]&o)<<24>>24!=0?0:2);return}function fzS(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=(d[9661075]|0)<<2;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=(a[9661061]|0)+k&255;b[4830522]=l+1&65535;l=c[2415263]|0;c[2415264]=l;k=(d[9661065]|0)<<13|l&8191;h=c[m+16+(k>>>11<<2)>>2]|0;do{if((h|0)==0){e=c[m>>2]|0;if((e|0)==0){o=0;break}o=gj[e&4095](k)|0}else{o=a[h+(l&2047)|0]|0}}while(0);l=a[9661063]|0;if((l&32)==0){h=a[9661060]&o;a[9661060]=h;a[9661063]=h&-128|l&93|(h<<24>>24==0?2:0);return}a[9661063]=l&-33;a[9661052]=a[9661061]|0;l=c[2415263]|0;c[2415264]=l;h=a[9661065]|0;k=(h&255)<<13|l&8191;m=c[2388530]|0;e=c[m+16+(k>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){p=0;q=h;r=l;s=m;break}i=gj[f&4095](k)|0;p=i;q=a[9661065]|0;r=c[2415264]|0;s=c[2388530]|0}else{p=a[e+(l&2047)|0]|0;q=h;r=l;s=m}}while(0);m=p&o;o=(q&255)<<13|r&8191;q=c[s+4112+(o>>>11<<2)>>2]|0;do{if((q|0)==0){p=c[s+4>>2]|0;if((p|0)==0){break}gg[p&4095](o,m)}else{a[q+(r&2047)|0]=m}}while(0);a[9661063]=(m<<24>>24==0?2:0)|m&-128|a[9661063]&93;m=(d[9661075]|0)*-3|0;c[2440610]=m+(c[2440610]|0);c[2415269]=m+(c[2415269]|0);return}function fzT(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=(d[9661075]|0)*-6|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=(a[9661061]|0)+k&255;b[4830522]=l+1&65535;l=c[2415263]|0;c[2415264]=l;k=a[9661065]|0;h=(k&255)<<13|l&8191;e=c[m+16+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){o=0;p=k;q=l;r=m;break}i=gj[f&4095](h)|0;o=i;p=a[9661065]|0;q=c[2415264]|0;r=c[2388530]|0}else{o=a[e+(l&2047)|0]|0;p=k;q=l;r=m}}while(0);m=a[9661063]|0;l=o<<1;k=m&1|l;a[9661063]=m&92|(o&255)>>>7|l&-128|(k<<24>>24==0?2:0);l=(p&255)<<13|q&8191;p=c[r+4112+(l>>>11<<2)>>2]|0;if((p|0)!=0){a[p+(q&2047)|0]=k;return}q=c[r+4>>2]|0;if((q|0)==0){return}gg[q&4095](l,k);return}function fzU(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=(d[9661075]|0)*-7|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=k;b[4830522]=l+1&65535;l=c[2415263]|0;c[2415264]=l;k=a[9661065]|0;h=(k&255)<<13|l&8191;e=c[m+16+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){o=0;p=k;q=l;r=m;break}i=gj[f&4095](h)|0;o=i;p=a[9661065]|0;q=c[2415264]|0;r=c[2388530]|0}else{o=a[e+(l&2047)|0]|0;p=k;q=l;r=m}}while(0);a[9661063]=a[9661063]&-33;m=o&-9;o=(p&255)<<13|q&8191;p=c[r+4112+(o>>>11<<2)>>2]|0;if((p|0)!=0){a[p+(q&2047)|0]=m;return}q=c[r+4>>2]|0;if((q|0)==0){return}gg[q&4095](o,m);return}function fzV(){var b=0;b=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-b;c[2415269]=(c[2415269]|0)-b;a[9661063]=a[9661063]&-34|1;return}function fzW(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=(d[9661075]|0)*-5|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661056]=k;k=l+1&65535;b[4830522]=k;l=k&65535;h=(d[9661064+(l>>>13)|0]|0)<<13|l&8191;e=c[m+8208+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){o=0;p=k;break}i=gj[f&4095](h)|0;o=i;p=b[4830522]|0}else{o=a[e+(l&2047)|0]|0;p=k}}while(0);a[9661057]=o;b[4830522]=p+1&65535;b[4830528]=(b[4830528]|0)+(d[9661062]|0)&65535;p=c[2415264]|0;o=9661064+(p>>>13&7)|0;k=a[o]|0;if(((k&255)<<13|p&6144|0)==2088960){l=d[9661075]|0;c[2440610]=(c[2440610]|0)-l;c[2415269]=(c[2415269]|0)-l;q=a[o]|0}else{q=k}k=(q&255)<<13|p&8191;q=c[2388530]|0;o=c[q+16+(k>>>11<<2)>>2]|0;do{if((o|0)==0){l=c[q>>2]|0;if((l|0)==0){r=0;break}r=gj[l&4095](k)|0}else{r=a[o+(p&2047)|0]|0}}while(0);p=a[9661063]|0;if((p&32)==0){o=a[9661060]&r;a[9661060]=o;a[9661063]=o&-128|p&93|(o<<24>>24==0?2:0);return}a[9661063]=p&-33;a[9661052]=a[9661061]|0;p=c[2415263]|0;c[2415264]=p;o=a[9661065]|0;k=(o&255)<<13|p&8191;q=c[2388530]|0;l=c[q+16+(k>>>11<<2)>>2]|0;do{if((l|0)==0){e=c[q>>2]|0;if((e|0)==0){s=0;t=o;u=p;v=q;break}h=gj[e&4095](k)|0;s=h;t=a[9661065]|0;u=c[2415264]|0;v=c[2388530]|0}else{s=a[l+(p&2047)|0]|0;t=o;u=p;v=q}}while(0);q=s&r;r=(t&255)<<13|u&8191;t=c[v+4112+(r>>>11<<2)>>2]|0;do{if((t|0)==0){s=c[v+4>>2]|0;if((s|0)==0){break}gg[s&4095](r,q)}else{a[t+(u&2047)|0]=q}}while(0);a[9661063]=(q<<24>>24==0?2:0)|q&-128|a[9661063]&93;q=(d[9661075]|0)*-3|0;c[2440610]=q+(c[2440610]|0);c[2415269]=q+(c[2415269]|0);return}function fzX(){var b=0,e=0;b=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-b;c[2415269]=(c[2415269]|0)-b;b=a[9661063]|0;e=(a[9661060]|0)-1&255;a[9661060]=e;a[9661063]=e&-128|b&93|(e<<24>>24==0?2:0);return}function fzY(){var b=0;b=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-b;c[2415269]=(c[2415269]|0)-b;a[9661063]=a[9661063]&-33;return}function fzZ(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;e=(d[9661075]|0)*-5|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661056]=k;k=l+1&65535;b[4830522]=k;l=k&65535;h=(d[9661064+(l>>>13)|0]|0)<<13|l&8191;e=c[m+8208+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){o=0;p=k;break}i=gj[f&4095](h)|0;o=i;p=b[4830522]|0}else{o=a[e+(l&2047)|0]|0;p=k}}while(0);a[9661057]=o;b[4830522]=p+1&65535;b[4830528]=(b[4830528]|0)+(d[9661061]|0)&65535;p=c[2415264]|0;o=9661064+(p>>>13&7)|0;k=a[o]|0;if(((k&255)<<13|p&6144|0)==2088960){l=d[9661075]|0;c[2440610]=(c[2440610]|0)-l;c[2415269]=(c[2415269]|0)-l;q=a[o]|0}else{q=k}k=(q&255)<<13|p&8191;q=c[2388530]|0;o=c[q+16+(k>>>11<<2)>>2]|0;if((o|0)!=0){r=a[o+(p&2047)|0]|0;s=a[9661063]|0;t=s&29;u=a[9661060]|0;v=u&r;w=v<<24>>24!=0;x=w?0:2;y=r&-64;z=t|y;A=z|x;a[9661063]=A;return}p=c[q>>2]|0;if((p|0)==0){r=0;s=a[9661063]|0;t=s&29;u=a[9661060]|0;v=u&r;w=v<<24>>24!=0;x=w?0:2;y=r&-64;z=t|y;A=z|x;a[9661063]=A;return}r=gj[p&4095](k)|0;s=a[9661063]|0;t=s&29;u=a[9661060]|0;v=u&r;w=v<<24>>24!=0;x=w?0:2;y=r&-64;z=t|y;A=z|x;a[9661063]=A;return}function fz_(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=(d[9661075]|0)*-5|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661056]=k;k=l+1&65535;b[4830522]=k;l=k&65535;h=(d[9661064+(l>>>13)|0]|0)<<13|l&8191;e=c[m+8208+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){o=0;p=k;break}i=gj[f&4095](h)|0;o=i;p=b[4830522]|0}else{o=a[e+(l&2047)|0]|0;p=k}}while(0);a[9661057]=o;b[4830522]=p+1&65535;b[4830528]=(b[4830528]|0)+(d[9661061]|0)&65535;p=c[2415264]|0;o=9661064+(p>>>13&7)|0;k=a[o]|0;if(((k&255)<<13|p&6144|0)==2088960){l=d[9661075]|0;c[2440610]=(c[2440610]|0)-l;c[2415269]=(c[2415269]|0)-l;q=a[o]|0}else{q=k}k=(q&255)<<13|p&8191;q=c[2388530]|0;o=c[q+16+(k>>>11<<2)>>2]|0;do{if((o|0)==0){l=c[q>>2]|0;if((l|0)==0){r=0;break}r=gj[l&4095](k)|0}else{r=a[o+(p&2047)|0]|0}}while(0);p=a[9661063]|0;if((p&32)==0){o=a[9661060]&r;a[9661060]=o;a[9661063]=o&-128|p&93|(o<<24>>24==0?2:0);return}a[9661063]=p&-33;a[9661052]=a[9661061]|0;p=c[2415263]|0;c[2415264]=p;o=a[9661065]|0;k=(o&255)<<13|p&8191;q=c[2388530]|0;l=c[q+16+(k>>>11<<2)>>2]|0;do{if((l|0)==0){e=c[q>>2]|0;if((e|0)==0){s=0;t=o;u=p;v=q;break}h=gj[e&4095](k)|0;s=h;t=a[9661065]|0;u=c[2415264]|0;v=c[2388530]|0}else{s=a[l+(p&2047)|0]|0;t=o;u=p;v=q}}while(0);q=s&r;r=(t&255)<<13|u&8191;t=c[v+4112+(r>>>11<<2)>>2]|0;do{if((t|0)==0){s=c[v+4>>2]|0;if((s|0)==0){break}gg[s&4095](r,q)}else{a[t+(u&2047)|0]=q}}while(0);a[9661063]=(q<<24>>24==0?2:0)|q&-128|a[9661063]&93;q=(d[9661075]|0)*-3|0;c[2440610]=q+(c[2440610]|0);c[2415269]=q+(c[2415269]|0);return}function fz$(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=(d[9661075]|0)*-7|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661056]=k;k=l+1&65535;b[4830522]=k;l=k&65535;h=(d[9661064+(l>>>13)|0]|0)<<13|l&8191;e=c[m+8208+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){o=0;p=k;break}i=gj[f&4095](h)|0;o=i;p=b[4830522]|0}else{o=a[e+(l&2047)|0]|0;p=k}}while(0);a[9661057]=o;b[4830522]=p+1&65535;b[4830528]=(b[4830528]|0)+(d[9661061]|0)&65535;p=c[2415264]|0;o=9661064+(p>>>13&7)|0;k=a[o]|0;if(((k&255)<<13|p&6144|0)==2088960){l=d[9661075]|0;c[2440610]=(c[2440610]|0)-l;c[2415269]=(c[2415269]|0)-l;q=a[o]|0}else{q=k}k=(q&255)<<13|p&8191;q=c[2388530]|0;o=c[q+16+(k>>>11<<2)>>2]|0;do{if((o|0)==0){l=c[q>>2]|0;if((l|0)==0){r=0;s=p;break}e=gj[l&4095](k)|0;r=e;s=c[2415264]|0}else{r=a[o+(p&2047)|0]|0;s=p}}while(0);p=a[9661063]|0;o=r<<1;k=p&1|o;a[9661063]=p&92|(r&255)>>>7|o&-128|(k<<24>>24==0?2:0);o=9661064+(s>>>13&7)|0;r=a[o]|0;if(((r&255)<<13|s&6144|0)==2088960){p=d[9661075]|0;c[2440610]=(c[2440610]|0)-p;c[2415269]=(c[2415269]|0)-p;t=a[o]|0}else{t=r}r=(t&255)<<13|s&8191;t=c[2388530]|0;o=c[t+4112+(r>>>11<<2)>>2]|0;if((o|0)!=0){a[o+(s&2047)|0]=k;return}s=c[t+4>>2]|0;if((s|0)==0){return}gg[s&4095](r,k);return}function fz0(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=(d[9661075]|0)<<2;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=k;k=l+1&65535;b[4830522]=k;l=c[2415263]|0;c[2415264]=l;h=(d[9661065]|0)<<13|l&8191;e=c[m+16+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){a[9661063]=a[9661063]&-33;o=k;p=m;break}else{i=gj[f&4095](h)|0;q=i;r=b[4830522]|0;s=3425;break}}else{q=a[e+(l&2047)|0]|0;r=k;s=3425}}while(0);do{if((s|0)==3425){a[9661063]=a[9661063]&-33;if((q&8)==0){o=r;p=c[2388530]|0;break}b[4830522]=r+1&65535;k=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-k;c[2415269]=(c[2415269]|0)-k;return}}while(0);r=(d[9661075]|0)<<2;c[2440610]=(c[2440610]|0)-r;c[2415269]=(c[2415269]|0)-r;r=o&65535;q=(d[9661064+(r>>>13)|0]|0)<<13|r&8191;s=c[p+8208+(q>>>11<<2)>>2]|0;do{if((s|0)==0){k=c[p>>2]|0;if((k|0)==0){t=0;u=o;break}l=gj[k&4095](q)|0;t=l;u=b[4830522]|0}else{t=a[s+(r&2047)|0]|0;u=o}}while(0);b[4830528]=(u+1&65535)+(t<<24>>24)&65535;c[2415261]=c[2415264];return}function fz1(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=(d[9661075]|0)*-7|0;c[2440610]=b+(c[2440610]|0);c[2415269]=b+(c[2415269]|0);a[9661048]=(a[9661048]|0)+1&255;b=a[9661065]|0;e=c[2415262]|0;f=(b&255)<<13|e&2097151;g=c[2388530]|0;h=c[g+16+(f>>>11<<2)>>2]|0;i=e&255;do{if((h|0)==0){j=c[g>>2]|0;if((j|0)==0){k=0;l=i;m=b;n=g;break}o=gj[j&4095](f)|0;k=o;l=a[9661048]|0;m=a[9661065]|0;n=c[2388530]|0}else{k=a[h+(e&2047)|0]|0;l=i;m=b;n=g}}while(0);a[9661063]=k|16;a[9661048]=l+1&255;l=c[2415262]|0;k=(m&255)<<13|l&2097151;g=c[n+16+(k>>>11<<2)>>2]|0;b=l&255;do{if((g|0)==0){i=c[n>>2]|0;if((i|0)==0){p=0;q=b;r=m;s=n;break}e=gj[i&4095](k)|0;p=e;q=a[9661048]|0;r=a[9661065]|0;s=c[2388530]|0}else{p=a[g+(l&2047)|0]|0;q=b;r=m;s=n}}while(0);a[9661044]=p;a[9661048]=q+1&255;q=c[2415262]|0;p=(r&255)<<13|q&2097151;r=c[s+16+(p>>>11<<2)>>2]|0;do{if((r|0)==0){n=c[s>>2]|0;if((n|0)==0){t=0;break}t=gj[n&4095](p)|0}else{t=a[r+(q&2047)|0]|0}}while(0);a[9661045]=t;if((a[9661088]|0)!=0){return}a[9661088]=2;return}function fz2(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;e=(d[9661075]|0)*-7|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=(a[9661061]|0)+k&255;b[4830522]=l+1&65535;l=c[2415263]|0;k=(l&255|0)==255;h=a[9661065]|0;e=(h&255)<<13|l&8191;f=c[m+16+(e>>>11<<2)>>2]|0;do{if((f|0)==0){i=c[m>>2]|0;if((i|0)==0){o=0;p=h;q=l;break}g=gj[i&4095](e)|0;o=g;p=a[9661065]|0;q=c[2415263]|0}else{o=a[f+(l&2047)|0]|0;p=h;q=l}}while(0);l=o&255;o=(p&255)<<13;do{if(k){p=q+7937|0;h=p&8191|o;f=c[2388530]|0;e=c[f+16+(h>>>11<<2)>>2]|0;if((e|0)!=0){r=a[e+(p&2047)|0]|0;break}p=c[f>>2]|0;if((p|0)==0){r=0;break}r=gj[p&4095](h)|0}else{h=q+1|0;p=h&8191|o;f=c[2388530]|0;e=c[f+16+(p>>>11<<2)>>2]|0;if((e|0)!=0){r=a[e+(h&2047)|0]|0;break}h=c[f>>2]|0;if((h|0)==0){r=0;break}r=gj[h&4095](p)|0}}while(0);o=r&255;r=o<<8;q=r|l;c[2415264]=q;l=9661064+(o>>>5)|0;o=a[l]|0;if(((o&255)<<13|r&6144|0)==2088960){r=d[9661075]|0;c[2440610]=(c[2440610]|0)-r;c[2415269]=(c[2415269]|0)-r;s=a[l]|0}else{s=o}o=(s&255)<<13|q&8191;s=c[2388530]|0;l=c[s+16+(o>>>11<<2)>>2]|0;do{if((l|0)==0){r=c[s>>2]|0;if((r|0)==0){t=0;break}t=gj[r&4095](o)|0}else{t=a[l+(q&2047)|0]|0}}while(0);q=a[9661063]|0;if((q&32)==0){l=a[9661060]|0;o=l^t;a[9661060]=o;a[9661063]=o&-128|q&93|(l<<24>>24==t<<24>>24?2:0);return}a[9661063]=q&-33;a[9661052]=a[9661061]|0;q=c[2415263]|0;c[2415264]=q;l=a[9661065]|0;o=(l&255)<<13|q&8191;s=c[2388530]|0;r=c[s+16+(o>>>11<<2)>>2]|0;do{if((r|0)==0){k=c[s>>2]|0;if((k|0)==0){u=0;v=l;w=q;x=s;break}p=gj[k&4095](o)|0;u=p;v=a[9661065]|0;w=c[2415264]|0;x=c[2388530]|0}else{u=a[r+(q&2047)|0]|0;v=l;w=q;x=s}}while(0);s=u^t;q=(v&255)<<13|w&8191;v=c[x+4112+(q>>>11<<2)>>2]|0;do{if((v|0)==0){l=c[x+4>>2]|0;if((l|0)==0){break}gg[l&4095](q,s)}else{a[v+(w&2047)|0]=s}}while(0);a[9661063]=(u<<24>>24==t<<24>>24?2:0)|s&-128|a[9661063]&93;s=(d[9661075]|0)*-3|0;c[2440610]=s+(c[2440610]|0);c[2415269]=s+(c[2415269]|0);return}function fz3(){var b=0;b=(d[9661075]|0)*-3|0;c[2440610]=b+(c[2440610]|0);c[2415269]=b+(c[2415269]|0);a[9661063]=a[9661063]&-33;b=a[9661062]|0;a[9661062]=a[9661060]|0;a[9661060]=b;return}function fz4(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=(d[9661075]|0)<<2;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;break}m=gj[j&4095](g)|0;k=m;l=b[4830522]|0}else{k=a[i+(f&2047)|0]|0;l=e}}while(0);e=k&255;b[4830522]=l+1&65535;a[9661063]=a[9661063]&-33;if((e&1|0)!=0){a[9661060]=a[9661064]|0}if((e&2|0)!=0){a[9661060]=a[9661065]|0}if((e&4|0)!=0){a[9661060]=a[9661066]|0}if((e&8|0)!=0){a[9661060]=a[9661067]|0}if((e&16|0)!=0){a[9661060]=a[9661068]|0}if((e&32|0)!=0){a[9661060]=a[9661069]|0}if((e&64|0)!=0){a[9661060]=a[9661070]|0}if((e&128|0)==0){return}a[9661060]=a[9661071]|0;return}function fz5(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=c[2415262]|0;f=a[9661045]|0;g=(d[9661065]|0)<<13|e&2097151;h=c[2388530]|0;i=c[h+4112+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h+4>>2]|0;if((j|0)==0){k=h;break}gg[j&4095](g,f);k=c[2388530]|0}else{a[i+(e&2047)|0]=f;k=h}}while(0);a[9661048]=(a[9661048]|0)-1&255;h=c[2415262]|0;f=a[9661044]|0;e=(d[9661065]|0)<<13|h&2097151;i=c[k+4112+(e>>>11<<2)>>2]|0;do{if((i|0)==0){g=c[k+4>>2]|0;if((g|0)==0){l=k;break}gg[g&4095](e,f);l=c[2388530]|0}else{a[i+(h&2047)|0]=f;l=k}}while(0);a[9661048]=(a[9661048]|0)-1&255;k=-((d[9661075]|0)<<2)|0;f=c[2440610]|0;h=c[2415269]|0;a[9661063]=a[9661063]&-33;i=k<<1;c[2440610]=i+f;c[2415269]=i+h;h=b[4830522]|0;i=h&65535;f=(d[9661064+(i>>>13)|0]|0)<<13|i&8191;k=c[l+8208+(f>>>11<<2)>>2]|0;if((k|0)!=0){m=a[k+(i&2047)|0]|0;n=h;o=n+1&65535;p=m<<24>>24;q=o+p&65535;b[4830528]=q;r=c[2415264]|0;c[2415261]=r;return}i=c[l>>2]|0;if((i|0)==0){m=0;n=h;o=n+1&65535;p=m<<24>>24;q=o+p&65535;b[4830528]=q;r=c[2415264]|0;c[2415261]=r;return}h=gj[i&4095](f)|0;m=h;n=b[4830522]|0;o=n+1&65535;p=m<<24>>24;q=o+p&65535;b[4830528]=q;r=c[2415264]|0;c[2415261]=r;return}function fz6(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=(d[9661075]|0)<<2;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=k;b[4830522]=l+1&65535;l=c[2415263]|0;c[2415264]=l;k=(d[9661065]|0)<<13|l&8191;h=c[m+16+(k>>>11<<2)>>2]|0;do{if((h|0)==0){e=c[m>>2]|0;if((e|0)==0){o=0;break}o=gj[e&4095](k)|0}else{o=a[h+(l&2047)|0]|0}}while(0);l=a[9661063]|0;if((l&32)==0){h=a[9661060]|0;k=h^o;a[9661060]=k;a[9661063]=k&-128|l&93|(h<<24>>24==o<<24>>24?2:0);return}a[9661063]=l&-33;a[9661052]=a[9661061]|0;l=c[2415263]|0;c[2415264]=l;h=a[9661065]|0;k=(h&255)<<13|l&8191;m=c[2388530]|0;e=c[m+16+(k>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){p=0;q=h;r=l;s=m;break}i=gj[f&4095](k)|0;p=i;q=a[9661065]|0;r=c[2415264]|0;s=c[2388530]|0}else{p=a[e+(l&2047)|0]|0;q=h;r=l;s=m}}while(0);m=p^o;l=(q&255)<<13|r&8191;q=c[s+4112+(l>>>11<<2)>>2]|0;do{if((q|0)==0){h=c[s+4>>2]|0;if((h|0)==0){break}gg[h&4095](l,m)}else{a[q+(r&2047)|0]=m}}while(0);a[9661063]=(p<<24>>24==o<<24>>24?2:0)|m&-128|a[9661063]&93;m=(d[9661075]|0)*-3|0;c[2440610]=m+(c[2440610]|0);c[2415269]=m+(c[2415269]|0);return}function fz7(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=(d[9661075]|0)*-6|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=k;b[4830522]=l+1&65535;l=c[2415263]|0;c[2415264]=l;k=a[9661065]|0;h=(k&255)<<13|l&8191;e=c[m+16+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){o=0;p=k;q=l;r=m;break}i=gj[f&4095](h)|0;o=i;p=a[9661065]|0;q=c[2415264]|0;r=c[2388530]|0}else{o=a[e+(l&2047)|0]|0;p=k;q=l;r=m}}while(0);m=(o&255)>>>1;a[9661063]=a[9661063]&92|o&1|((m|0)==0?2:0);o=(p&255)<<13|q&8191;p=m&255;m=c[r+4112+(o>>>11<<2)>>2]|0;if((m|0)!=0){a[m+(q&2047)|0]=p;return}q=c[r+4>>2]|0;if((q|0)==0){return}gg[q&4095](o,p);return}function fz8(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=(d[9661075]|0)*-7|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=k;b[4830522]=l+1&65535;l=c[2415263]|0;c[2415264]=l;k=a[9661065]|0;h=(k&255)<<13|l&8191;e=c[m+16+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){o=0;p=k;q=l;r=m;break}i=gj[f&4095](h)|0;o=i;p=a[9661065]|0;q=c[2415264]|0;r=c[2388530]|0}else{o=a[e+(l&2047)|0]|0;p=k;q=l;r=m}}while(0);a[9661063]=a[9661063]&-33;m=o&-17;o=(p&255)<<13|q&8191;p=c[r+4112+(o>>>11<<2)>>2]|0;if((p|0)!=0){a[p+(q&2047)|0]=m;return}q=c[r+4>>2]|0;if((q|0)==0){return}gg[q&4095](o,m);return}function fz9(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0;b=(d[9661075]|0)*-3|0;c[2440610]=b+(c[2440610]|0);c[2415269]=b+(c[2415269]|0);a[9661063]=a[9661063]&-33;b=c[2415262]|0;e=a[9661060]|0;f=(d[9661065]|0)<<13|b&2097151;g=c[2388530]|0;h=c[g+4112+(f>>>11<<2)>>2]|0;if((h|0)!=0){a[h+(b&2047)|0]=e;i=a[9661048]|0;j=i-1&255;a[9661048]=j;return}b=c[g+4>>2]|0;if((b|0)==0){i=a[9661048]|0;j=i-1&255;a[9661048]=j;return}gg[b&4095](f,e);i=a[9661048]|0;j=i-1&255;a[9661048]=j;return}function fAa(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;break}m=gj[j&4095](g)|0;k=m;l=b[4830522]|0}else{k=a[i+(f&2047)|0]|0;l=e}}while(0);b[4830522]=l+1&65535;l=a[9661063]|0;if((l&32)==0){e=a[9661060]|0;f=e^k;a[9661060]=f;a[9661063]=f&-128|l&93|(e<<24>>24==k<<24>>24?2:0);return}a[9661063]=l&-33;a[9661052]=a[9661061]|0;l=c[2415263]|0;c[2415264]=l;e=a[9661065]|0;f=(e&255)<<13|l&8191;i=c[2388530]|0;g=c[i+16+(f>>>11<<2)>>2]|0;do{if((g|0)==0){h=c[i>>2]|0;if((h|0)==0){n=0;o=e;p=l;q=i;break}m=gj[h&4095](f)|0;n=m;o=a[9661065]|0;p=c[2415264]|0;q=c[2388530]|0}else{n=a[g+(l&2047)|0]|0;o=e;p=l;q=i}}while(0);i=n^k;l=(o&255)<<13|p&8191;o=c[q+4112+(l>>>11<<2)>>2]|0;do{if((o|0)==0){e=c[q+4>>2]|0;if((e|0)==0){break}gg[e&4095](l,i)}else{a[o+(p&2047)|0]=i}}while(0);a[9661063]=(n<<24>>24==k<<24>>24?2:0)|i&-128|a[9661063]&93;i=(d[9661075]|0)*-3|0;c[2440610]=i+(c[2440610]|0);c[2415269]=i+(c[2415269]|0);return}function fAb(){var b=0,e=0;b=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-b;c[2415269]=(c[2415269]|0)-b;b=a[9661060]|0;e=(b&255)>>>1;a[9661063]=a[9661063]&92|b&1|((e|0)==0?2:0);a[9661060]=e&255;return}function fAc(){var b=0;b=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-b;c[2415269]=(c[2415269]|0)-b;a[9661063]=a[9661063]&-33;return}function fAd(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=(d[9661075]|0)<<2;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661056]=k;k=l+1&65535;b[4830522]=k;l=k&65535;k=(d[9661064+(l>>>13)|0]|0)<<13|l&8191;h=c[m+8208+(k>>>11<<2)>>2]|0;do{if((h|0)==0){e=c[m>>2]|0;if((e|0)==0){o=0;break}o=gj[e&4095](k)|0}else{o=a[h+(l&2047)|0]|0}}while(0);a[9661057]=o;a[9661063]=a[9661063]&-33;c[2415261]=c[2415264];return}function fAe(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=(d[9661075]|0)*-5|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661056]=k;k=l+1&65535;b[4830522]=k;l=k&65535;h=(d[9661064+(l>>>13)|0]|0)<<13|l&8191;e=c[m+8208+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){o=0;p=k;break}i=gj[f&4095](h)|0;o=i;p=b[4830522]|0}else{o=a[e+(l&2047)|0]|0;p=k}}while(0);a[9661057]=o;b[4830522]=p+1&65535;p=c[2415264]|0;o=9661064+(p>>>13&7)|0;k=a[o]|0;if(((k&255)<<13|p&6144|0)==2088960){l=d[9661075]|0;c[2440610]=(c[2440610]|0)-l;c[2415269]=(c[2415269]|0)-l;q=a[o]|0}else{q=k}k=(q&255)<<13|p&8191;q=c[2388530]|0;o=c[q+16+(k>>>11<<2)>>2]|0;do{if((o|0)==0){l=c[q>>2]|0;if((l|0)==0){r=0;break}r=gj[l&4095](k)|0}else{r=a[o+(p&2047)|0]|0}}while(0);p=a[9661063]|0;if((p&32)==0){o=a[9661060]|0;k=o^r;a[9661060]=k;a[9661063]=k&-128|p&93|(o<<24>>24==r<<24>>24?2:0);return}a[9661063]=p&-33;a[9661052]=a[9661061]|0;p=c[2415263]|0;c[2415264]=p;o=a[9661065]|0;k=(o&255)<<13|p&8191;q=c[2388530]|0;l=c[q+16+(k>>>11<<2)>>2]|0;do{if((l|0)==0){e=c[q>>2]|0;if((e|0)==0){s=0;t=o;u=p;v=q;break}h=gj[e&4095](k)|0;s=h;t=a[9661065]|0;u=c[2415264]|0;v=c[2388530]|0}else{s=a[l+(p&2047)|0]|0;t=o;u=p;v=q}}while(0);q=s^r;p=(t&255)<<13|u&8191;t=c[v+4112+(p>>>11<<2)>>2]|0;do{if((t|0)==0){o=c[v+4>>2]|0;if((o|0)==0){break}gg[o&4095](p,q)}else{a[t+(u&2047)|0]=q}}while(0);a[9661063]=(s<<24>>24==r<<24>>24?2:0)|q&-128|a[9661063]&93;q=(d[9661075]|0)*-3|0;c[2440610]=q+(c[2440610]|0);c[2415269]=q+(c[2415269]|0);return}function fAf(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=(d[9661075]|0)*-7|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661056]=k;k=l+1&65535;b[4830522]=k;l=k&65535;h=(d[9661064+(l>>>13)|0]|0)<<13|l&8191;e=c[m+8208+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){o=0;p=k;break}i=gj[f&4095](h)|0;o=i;p=b[4830522]|0}else{o=a[e+(l&2047)|0]|0;p=k}}while(0);a[9661057]=o;b[4830522]=p+1&65535;p=c[2415264]|0;o=9661064+(p>>>13&7)|0;k=a[o]|0;if(((k&255)<<13|p&6144|0)==2088960){l=d[9661075]|0;c[2440610]=(c[2440610]|0)-l;c[2415269]=(c[2415269]|0)-l;q=a[o]|0}else{q=k}k=(q&255)<<13|p&8191;q=c[2388530]|0;o=c[q+16+(k>>>11<<2)>>2]|0;do{if((o|0)==0){l=c[q>>2]|0;if((l|0)==0){r=0;s=p;break}e=gj[l&4095](k)|0;r=e;s=c[2415264]|0}else{r=a[o+(p&2047)|0]|0;s=p}}while(0);p=(r&255)>>>1;a[9661063]=a[9661063]&92|r&1|((p|0)==0?2:0);r=p&255;p=9661064+(s>>>13&7)|0;o=a[p]|0;if(((o&255)<<13|s&6144|0)==2088960){k=d[9661075]|0;c[2440610]=(c[2440610]|0)-k;c[2415269]=(c[2415269]|0)-k;t=a[p]|0}else{t=o}o=(t&255)<<13|s&8191;t=c[2388530]|0;p=c[t+4112+(o>>>11<<2)>>2]|0;if((p|0)!=0){a[p+(s&2047)|0]=r;return}s=c[t+4>>2]|0;if((s|0)==0){return}gg[s&4095](o,r);return}function fAg(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=(d[9661075]|0)<<2;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=k;k=l+1&65535;b[4830522]=k;l=c[2415263]|0;c[2415264]=l;h=(d[9661065]|0)<<13|l&8191;e=c[m+16+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){a[9661063]=a[9661063]&-33;o=k;p=m;break}else{i=gj[f&4095](h)|0;q=i;r=b[4830522]|0;s=3682;break}}else{q=a[e+(l&2047)|0]|0;r=k;s=3682}}while(0);do{if((s|0)==3682){a[9661063]=a[9661063]&-33;if((q&16)==0){o=r;p=c[2388530]|0;break}b[4830522]=r+1&65535;k=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-k;c[2415269]=(c[2415269]|0)-k;return}}while(0);r=(d[9661075]|0)<<2;c[2440610]=(c[2440610]|0)-r;c[2415269]=(c[2415269]|0)-r;r=o&65535;q=(d[9661064+(r>>>13)|0]|0)<<13|r&8191;s=c[p+8208+(q>>>11<<2)>>2]|0;do{if((s|0)==0){k=c[p>>2]|0;if((k|0)==0){t=0;u=o;break}l=gj[k&4095](q)|0;t=l;u=b[4830522]|0}else{t=a[s+(r&2047)|0]|0;u=o}}while(0);b[4830528]=(u+1&65535)+(t<<24>>24)&65535;c[2415261]=c[2415264];return}function fAh(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=a[9661063]|0;a[9661063]=e&-33;if((e&64)!=0){b[4830522]=(b[4830522]|0)+1&65535;e=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;return}e=(d[9661075]|0)<<2;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;break}m=gj[j&4095](g)|0;k=m;l=b[4830522]|0}else{k=a[i+(f&2047)|0]|0;l=e}}while(0);b[4830528]=(l+1&65535)+(k<<24>>24)&65535;c[2415261]=c[2415264];return}function fAi(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;e=(d[9661075]|0)*-7|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=k;b[4830522]=l+1&65535;l=c[2415263]|0;k=(l&255|0)==255;h=a[9661065]|0;e=(h&255)<<13|l&8191;f=c[m+16+(e>>>11<<2)>>2]|0;do{if((f|0)==0){i=c[m>>2]|0;if((i|0)==0){o=0;p=h;q=l;break}g=gj[i&4095](e)|0;o=g;p=a[9661065]|0;q=c[2415263]|0}else{o=a[f+(l&2047)|0]|0;p=h;q=l}}while(0);l=o&255;o=(p&255)<<13;do{if(k){p=q+7937|0;h=p&8191|o;f=c[2388530]|0;e=c[f+16+(h>>>11<<2)>>2]|0;if((e|0)!=0){r=a[e+(p&2047)|0]|0;break}p=c[f>>2]|0;if((p|0)==0){r=0;break}r=gj[p&4095](h)|0}else{h=q+1|0;p=h&8191|o;f=c[2388530]|0;e=c[f+16+(p>>>11<<2)>>2]|0;if((e|0)!=0){r=a[e+(h&2047)|0]|0;break}h=c[f>>2]|0;if((h|0)==0){r=0;break}r=gj[h&4095](p)|0}}while(0);o=(r&255)<<8|l;c[2415264]=o;b[4830528]=(o&65535)+(d[9661062]|0)&65535;o=c[2415264]|0;l=9661064+(o>>>13&7)|0;r=a[l]|0;if(((r&255)<<13|o&6144|0)==2088960){q=d[9661075]|0;c[2440610]=(c[2440610]|0)-q;c[2415269]=(c[2415269]|0)-q;s=a[l]|0}else{s=r}r=(s&255)<<13|o&8191;s=c[2388530]|0;l=c[s+16+(r>>>11<<2)>>2]|0;do{if((l|0)==0){q=c[s>>2]|0;if((q|0)==0){t=0;break}t=gj[q&4095](r)|0}else{t=a[l+(o&2047)|0]|0}}while(0);o=a[9661063]|0;if((o&32)==0){l=a[9661060]|0;r=l^t;a[9661060]=r;a[9661063]=r&-128|o&93|(l<<24>>24==t<<24>>24?2:0);return}a[9661063]=o&-33;a[9661052]=a[9661061]|0;o=c[2415263]|0;c[2415264]=o;l=a[9661065]|0;r=(l&255)<<13|o&8191;s=c[2388530]|0;q=c[s+16+(r>>>11<<2)>>2]|0;do{if((q|0)==0){k=c[s>>2]|0;if((k|0)==0){u=0;v=l;w=o;x=s;break}p=gj[k&4095](r)|0;u=p;v=a[9661065]|0;w=c[2415264]|0;x=c[2388530]|0}else{u=a[q+(o&2047)|0]|0;v=l;w=o;x=s}}while(0);s=u^t;o=(v&255)<<13|w&8191;v=c[x+4112+(o>>>11<<2)>>2]|0;do{if((v|0)==0){l=c[x+4>>2]|0;if((l|0)==0){break}gg[l&4095](o,s)}else{a[v+(w&2047)|0]=s}}while(0);a[9661063]=(u<<24>>24==t<<24>>24?2:0)|s&-128|a[9661063]&93;s=(d[9661075]|0)*-3|0;c[2440610]=s+(c[2440610]|0);c[2415269]=s+(c[2415269]|0);return}function fAj(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;e=(d[9661075]|0)*-7|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=k;b[4830522]=l+1&65535;l=c[2415263]|0;k=(l&255|0)==255;h=a[9661065]|0;e=(h&255)<<13|l&8191;f=c[m+16+(e>>>11<<2)>>2]|0;do{if((f|0)==0){i=c[m>>2]|0;if((i|0)==0){o=0;p=h;q=l;break}g=gj[i&4095](e)|0;o=g;p=a[9661065]|0;q=c[2415263]|0}else{o=a[f+(l&2047)|0]|0;p=h;q=l}}while(0);l=o&255;o=(p&255)<<13;do{if(k){p=q+7937|0;h=p&8191|o;f=c[2388530]|0;e=c[f+16+(h>>>11<<2)>>2]|0;if((e|0)!=0){r=a[e+(p&2047)|0]|0;break}p=c[f>>2]|0;if((p|0)==0){r=0;break}r=gj[p&4095](h)|0}else{h=q+1|0;p=h&8191|o;f=c[2388530]|0;e=c[f+16+(p>>>11<<2)>>2]|0;if((e|0)!=0){r=a[e+(h&2047)|0]|0;break}h=c[f>>2]|0;if((h|0)==0){r=0;break}r=gj[h&4095](p)|0}}while(0);o=r&255;r=o<<8;q=r|l;c[2415264]=q;l=9661064+(o>>>5)|0;o=a[l]|0;if(((o&255)<<13|r&6144|0)==2088960){r=d[9661075]|0;c[2440610]=(c[2440610]|0)-r;c[2415269]=(c[2415269]|0)-r;s=a[l]|0}else{s=o}o=(s&255)<<13|q&8191;s=c[2388530]|0;l=c[s+16+(o>>>11<<2)>>2]|0;do{if((l|0)==0){r=c[s>>2]|0;if((r|0)==0){t=0;break}t=gj[r&4095](o)|0}else{t=a[l+(q&2047)|0]|0}}while(0);q=a[9661063]|0;if((q&32)==0){l=a[9661060]|0;o=l^t;a[9661060]=o;a[9661063]=o&-128|q&93|(l<<24>>24==t<<24>>24?2:0);return}a[9661063]=q&-33;a[9661052]=a[9661061]|0;q=c[2415263]|0;c[2415264]=q;l=a[9661065]|0;o=(l&255)<<13|q&8191;s=c[2388530]|0;r=c[s+16+(o>>>11<<2)>>2]|0;do{if((r|0)==0){k=c[s>>2]|0;if((k|0)==0){u=0;v=l;w=q;x=s;break}p=gj[k&4095](o)|0;u=p;v=a[9661065]|0;w=c[2415264]|0;x=c[2388530]|0}else{u=a[r+(q&2047)|0]|0;v=l;w=q;x=s}}while(0);s=u^t;q=(v&255)<<13|w&8191;v=c[x+4112+(q>>>11<<2)>>2]|0;do{if((v|0)==0){l=c[x+4>>2]|0;if((l|0)==0){break}gg[l&4095](q,s)}else{a[v+(w&2047)|0]=s}}while(0);a[9661063]=(u<<24>>24==t<<24>>24?2:0)|s&-128|a[9661063]&93;s=(d[9661075]|0)*-3|0;c[2440610]=s+(c[2440610]|0);c[2415269]=s+(c[2415269]|0);return}function fAk(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=(d[9661075]|0)*-5|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;break}m=gj[j&4095](g)|0;k=m;l=b[4830522]|0}else{k=a[i+(f&2047)|0]|0;l=e}}while(0);e=k&255;b[4830522]=l+1&65535;a[9661063]=a[9661063]&-33;if((e&1|0)!=0){a[9661064]=a[9661060]|0}if((e&2|0)!=0){a[9661065]=a[9661060]|0}if((e&4|0)!=0){a[9661066]=a[9661060]|0}if((e&8|0)!=0){a[9661067]=a[9661060]|0}if((e&16|0)!=0){a[9661068]=a[9661060]|0}if((e&32|0)!=0){a[9661069]=a[9661060]|0}if((e&64|0)!=0){a[9661070]=a[9661060]|0}if((e&128|0)==0){return}a[9661071]=a[9661060]|0;return}function fAl(){var b=0;b=(d[9661075]|0)*-3|0;c[2440610]=b+(c[2440610]|0);c[2415269]=b+(c[2415269]|0);a[9661075]=4;return}function fAm(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=(d[9661075]|0)<<2;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=(a[9661061]|0)+k&255;b[4830522]=l+1&65535;l=c[2415263]|0;c[2415264]=l;k=(d[9661065]|0)<<13|l&8191;h=c[m+16+(k>>>11<<2)>>2]|0;do{if((h|0)==0){e=c[m>>2]|0;if((e|0)==0){o=0;break}o=gj[e&4095](k)|0}else{o=a[h+(l&2047)|0]|0}}while(0);l=a[9661063]|0;if((l&32)==0){h=a[9661060]|0;k=h^o;a[9661060]=k;a[9661063]=k&-128|l&93|(h<<24>>24==o<<24>>24?2:0);return}a[9661063]=l&-33;a[9661052]=a[9661061]|0;l=c[2415263]|0;c[2415264]=l;h=a[9661065]|0;k=(h&255)<<13|l&8191;m=c[2388530]|0;e=c[m+16+(k>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){p=0;q=h;r=l;s=m;break}i=gj[f&4095](k)|0;p=i;q=a[9661065]|0;r=c[2415264]|0;s=c[2388530]|0}else{p=a[e+(l&2047)|0]|0;q=h;r=l;s=m}}while(0);m=p^o;l=(q&255)<<13|r&8191;q=c[s+4112+(l>>>11<<2)>>2]|0;do{if((q|0)==0){h=c[s+4>>2]|0;if((h|0)==0){break}gg[h&4095](l,m)}else{a[q+(r&2047)|0]=m}}while(0);a[9661063]=(p<<24>>24==o<<24>>24?2:0)|m&-128|a[9661063]&93;m=(d[9661075]|0)*-3|0;c[2440610]=m+(c[2440610]|0);c[2415269]=m+(c[2415269]|0);return}function fAn(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=(d[9661075]|0)*-6|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=(a[9661061]|0)+k&255;b[4830522]=l+1&65535;l=c[2415263]|0;c[2415264]=l;k=a[9661065]|0;h=(k&255)<<13|l&8191;e=c[m+16+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){o=0;p=k;q=l;r=m;break}i=gj[f&4095](h)|0;o=i;p=a[9661065]|0;q=c[2415264]|0;r=c[2388530]|0}else{o=a[e+(l&2047)|0]|0;p=k;q=l;r=m}}while(0);m=(o&255)>>>1;a[9661063]=a[9661063]&92|o&1|((m|0)==0?2:0);o=(p&255)<<13|q&8191;p=m&255;m=c[r+4112+(o>>>11<<2)>>2]|0;if((m|0)!=0){a[m+(q&2047)|0]=p;return}q=c[r+4>>2]|0;if((q|0)==0){return}gg[q&4095](o,p);return}function fAo(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=(d[9661075]|0)*-7|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=k;b[4830522]=l+1&65535;l=c[2415263]|0;c[2415264]=l;k=a[9661065]|0;h=(k&255)<<13|l&8191;e=c[m+16+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){o=0;p=k;q=l;r=m;break}i=gj[f&4095](h)|0;o=i;p=a[9661065]|0;q=c[2415264]|0;r=c[2388530]|0}else{o=a[e+(l&2047)|0]|0;p=k;q=l;r=m}}while(0);a[9661063]=a[9661063]&-33;m=o&-33;o=(p&255)<<13|q&8191;p=c[r+4112+(o>>>11<<2)>>2]|0;if((p|0)!=0){a[p+(q&2047)|0]=m;return}q=c[r+4>>2]|0;if((q|0)==0){return}gg[q&4095](o,m);return}function fAp(){var b=0;b=d[9661075]<<1;c[2440610]=(c[2440610]|0)-b;c[2415269]=(c[2415269]|0)-b;b=a[9661063]|0;a[9661063]=b&-33;if((b&4)==0){return}a[9661063]=b&-37;if((a[9661088]|0)!=0){return}a[9661088]=2;return}function fAq(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=(d[9661075]|0)*-5|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661056]=k;k=l+1&65535;b[4830522]=k;l=k&65535;h=(d[9661064+(l>>>13)|0]|0)<<13|l&8191;e=c[m+8208+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){o=0;p=k;break}i=gj[f&4095](h)|0;o=i;p=b[4830522]|0}else{o=a[e+(l&2047)|0]|0;p=k}}while(0);a[9661057]=o;b[4830522]=p+1&65535;b[4830528]=(b[4830528]|0)+(d[9661062]|0)&65535;p=c[2415264]|0;o=9661064+(p>>>13&7)|0;k=a[o]|0;if(((k&255)<<13|p&6144|0)==2088960){l=d[9661075]|0;c[2440610]=(c[2440610]|0)-l;c[2415269]=(c[2415269]|0)-l;q=a[o]|0}else{q=k}k=(q&255)<<13|p&8191;q=c[2388530]|0;o=c[q+16+(k>>>11<<2)>>2]|0;do{if((o|0)==0){l=c[q>>2]|0;if((l|0)==0){r=0;break}r=gj[l&4095](k)|0}else{r=a[o+(p&2047)|0]|0}}while(0);p=a[9661063]|0;if((p&32)==0){o=a[9661060]|0;k=o^r;a[9661060]=k;a[9661063]=k&-128|p&93|(o<<24>>24==r<<24>>24?2:0);return}a[9661063]=p&-33;a[9661052]=a[9661061]|0;p=c[2415263]|0;c[2415264]=p;o=a[9661065]|0;k=(o&255)<<13|p&8191;q=c[2388530]|0;l=c[q+16+(k>>>11<<2)>>2]|0;do{if((l|0)==0){e=c[q>>2]|0;if((e|0)==0){s=0;t=o;u=p;v=q;break}h=gj[e&4095](k)|0;s=h;t=a[9661065]|0;u=c[2415264]|0;v=c[2388530]|0}else{s=a[l+(p&2047)|0]|0;t=o;u=p;v=q}}while(0);q=s^r;p=(t&255)<<13|u&8191;t=c[v+4112+(p>>>11<<2)>>2]|0;do{if((t|0)==0){o=c[v+4>>2]|0;if((o|0)==0){break}gg[o&4095](p,q)}else{a[t+(u&2047)|0]=q}}while(0);a[9661063]=(s<<24>>24==r<<24>>24?2:0)|q&-128|a[9661063]&93;q=(d[9661075]|0)*-3|0;c[2440610]=q+(c[2440610]|0);c[2415269]=q+(c[2415269]|0);return}function fAr(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0;b=(d[9661075]|0)*-3|0;c[2440610]=b+(c[2440610]|0);c[2415269]=b+(c[2415269]|0);a[9661063]=a[9661063]&-33;b=c[2415262]|0;e=a[9661062]|0;f=(d[9661065]|0)<<13|b&2097151;g=c[2388530]|0;h=c[g+4112+(f>>>11<<2)>>2]|0;if((h|0)!=0){a[h+(b&2047)|0]=e;i=a[9661048]|0;j=i-1&255;a[9661048]=j;return}b=c[g+4>>2]|0;if((b|0)==0){i=a[9661048]|0;j=i-1&255;a[9661048]=j;return}gg[b&4095](f,e);i=a[9661048]|0;j=i-1&255;a[9661048]=j;return}function fAs(){var b=0;b=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-b;c[2415269]=(c[2415269]|0)-b;a[9661063]=a[9661063]&-33;return}function fAt(){var b=0;b=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-b;c[2415269]=(c[2415269]|0)-b;a[9661063]=a[9661063]&-33;return}function fAu(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=(d[9661075]|0)*-5|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661056]=k;k=l+1&65535;b[4830522]=k;l=k&65535;h=(d[9661064+(l>>>13)|0]|0)<<13|l&8191;e=c[m+8208+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){o=0;p=k;break}i=gj[f&4095](h)|0;o=i;p=b[4830522]|0}else{o=a[e+(l&2047)|0]|0;p=k}}while(0);a[9661057]=o;b[4830522]=p+1&65535;b[4830528]=(b[4830528]|0)+(d[9661061]|0)&65535;p=c[2415264]|0;o=9661064+(p>>>13&7)|0;k=a[o]|0;if(((k&255)<<13|p&6144|0)==2088960){l=d[9661075]|0;c[2440610]=(c[2440610]|0)-l;c[2415269]=(c[2415269]|0)-l;q=a[o]|0}else{q=k}k=(q&255)<<13|p&8191;q=c[2388530]|0;o=c[q+16+(k>>>11<<2)>>2]|0;do{if((o|0)==0){l=c[q>>2]|0;if((l|0)==0){r=0;break}r=gj[l&4095](k)|0}else{r=a[o+(p&2047)|0]|0}}while(0);p=a[9661063]|0;if((p&32)==0){o=a[9661060]|0;k=o^r;a[9661060]=k;a[9661063]=k&-128|p&93|(o<<24>>24==r<<24>>24?2:0);return}a[9661063]=p&-33;a[9661052]=a[9661061]|0;p=c[2415263]|0;c[2415264]=p;o=a[9661065]|0;k=(o&255)<<13|p&8191;q=c[2388530]|0;l=c[q+16+(k>>>11<<2)>>2]|0;do{if((l|0)==0){e=c[q>>2]|0;if((e|0)==0){s=0;t=o;u=p;v=q;break}h=gj[e&4095](k)|0;s=h;t=a[9661065]|0;u=c[2415264]|0;v=c[2388530]|0}else{s=a[l+(p&2047)|0]|0;t=o;u=p;v=q}}while(0);q=s^r;p=(t&255)<<13|u&8191;t=c[v+4112+(p>>>11<<2)>>2]|0;do{if((t|0)==0){o=c[v+4>>2]|0;if((o|0)==0){break}gg[o&4095](p,q)}else{a[t+(u&2047)|0]=q}}while(0);a[9661063]=(s<<24>>24==r<<24>>24?2:0)|q&-128|a[9661063]&93;q=(d[9661075]|0)*-3|0;c[2440610]=q+(c[2440610]|0);c[2415269]=q+(c[2415269]|0);return}function fAv(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=(d[9661075]|0)*-7|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661056]=k;k=l+1&65535;b[4830522]=k;l=k&65535;h=(d[9661064+(l>>>13)|0]|0)<<13|l&8191;e=c[m+8208+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){o=0;p=k;break}i=gj[f&4095](h)|0;o=i;p=b[4830522]|0}else{o=a[e+(l&2047)|0]|0;p=k}}while(0);a[9661057]=o;b[4830522]=p+1&65535;b[4830528]=(b[4830528]|0)+(d[9661061]|0)&65535;p=c[2415264]|0;o=9661064+(p>>>13&7)|0;k=a[o]|0;if(((k&255)<<13|p&6144|0)==2088960){l=d[9661075]|0;c[2440610]=(c[2440610]|0)-l;c[2415269]=(c[2415269]|0)-l;q=a[o]|0}else{q=k}k=(q&255)<<13|p&8191;q=c[2388530]|0;o=c[q+16+(k>>>11<<2)>>2]|0;do{if((o|0)==0){l=c[q>>2]|0;if((l|0)==0){r=0;s=p;break}e=gj[l&4095](k)|0;r=e;s=c[2415264]|0}else{r=a[o+(p&2047)|0]|0;s=p}}while(0);p=(r&255)>>>1;a[9661063]=a[9661063]&92|r&1|((p|0)==0?2:0);r=p&255;p=9661064+(s>>>13&7)|0;o=a[p]|0;if(((o&255)<<13|s&6144|0)==2088960){k=d[9661075]|0;c[2440610]=(c[2440610]|0)-k;c[2415269]=(c[2415269]|0)-k;t=a[p]|0}else{t=o}o=(t&255)<<13|s&8191;t=c[2388530]|0;p=c[t+4112+(o>>>11<<2)>>2]|0;if((p|0)!=0){a[p+(s&2047)|0]=r;return}s=c[t+4>>2]|0;if((s|0)==0){return}gg[s&4095](o,r);return}function fAw(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=(d[9661075]|0)<<2;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=k;k=l+1&65535;b[4830522]=k;l=c[2415263]|0;c[2415264]=l;h=(d[9661065]|0)<<13|l&8191;e=c[m+16+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){a[9661063]=a[9661063]&-33;o=k;p=m;break}else{i=gj[f&4095](h)|0;q=i;r=b[4830522]|0;s=3961;break}}else{q=a[e+(l&2047)|0]|0;r=k;s=3961}}while(0);do{if((s|0)==3961){a[9661063]=a[9661063]&-33;if((q&32)==0){o=r;p=c[2388530]|0;break}b[4830522]=r+1&65535;k=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-k;c[2415269]=(c[2415269]|0)-k;return}}while(0);r=(d[9661075]|0)<<2;c[2440610]=(c[2440610]|0)-r;c[2415269]=(c[2415269]|0)-r;r=o&65535;q=(d[9661064+(r>>>13)|0]|0)<<13|r&8191;s=c[p+8208+(q>>>11<<2)>>2]|0;do{if((s|0)==0){k=c[p>>2]|0;if((k|0)==0){t=0;u=o;break}l=gj[k&4095](q)|0;t=l;u=b[4830522]|0}else{t=a[s+(r&2047)|0]|0;u=o}}while(0);b[4830528]=(u+1&65535)+(t<<24>>24)&65535;c[2415261]=c[2415264];return}function fAx(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=(d[9661075]|0)*-7|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);a[9661063]=a[9661063]&-33;a[9661048]=(a[9661048]|0)+1&255;e=a[9661065]|0;f=c[2415262]|0;g=(e&255)<<13|f&2097151;h=c[2388530]|0;i=c[h+16+(g>>>11<<2)>>2]|0;j=f&255;do{if((i|0)==0){k=c[h>>2]|0;if((k|0)==0){l=0;m=j;n=e;o=h;break}p=gj[k&4095](g)|0;l=p;m=a[9661048]|0;n=a[9661065]|0;o=c[2388530]|0}else{l=a[i+(f&2047)|0]|0;m=j;n=e;o=h}}while(0);a[9661044]=l;a[9661048]=m+1&255;m=c[2415262]|0;l=(n&255)<<13|m&2097151;n=c[o+16+(l>>>11<<2)>>2]|0;if((n|0)!=0){q=a[n+(m&2047)|0]|0;a[9661045]=q;r=b[4830522]|0;s=r+1&65535;b[4830522]=s;return}m=c[o>>2]|0;if((m|0)==0){q=0;a[9661045]=q;r=b[4830522]|0;s=r+1&65535;b[4830522]=s;return}q=gj[m&4095](l)|0;a[9661045]=q;r=b[4830522]|0;s=r+1&65535;b[4830522]=s;return}function fAy(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;e=(d[9661075]|0)*-7|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=(a[9661061]|0)+k&255;b[4830522]=l+1&65535;l=c[2415263]|0;k=(l&255|0)==255;h=a[9661065]|0;e=(h&255)<<13|l&8191;f=c[m+16+(e>>>11<<2)>>2]|0;do{if((f|0)==0){i=c[m>>2]|0;if((i|0)==0){o=0;p=h;q=l;break}g=gj[i&4095](e)|0;o=g;p=a[9661065]|0;q=c[2415263]|0}else{o=a[f+(l&2047)|0]|0;p=h;q=l}}while(0);l=o&255;o=(p&255)<<13;do{if(k){p=q+7937|0;h=p&8191|o;f=c[2388530]|0;e=c[f+16+(h>>>11<<2)>>2]|0;if((e|0)!=0){r=a[e+(p&2047)|0]|0;break}p=c[f>>2]|0;if((p|0)==0){r=0;break}r=gj[p&4095](h)|0}else{h=q+1|0;p=h&8191|o;f=c[2388530]|0;e=c[f+16+(p>>>11<<2)>>2]|0;if((e|0)!=0){r=a[e+(h&2047)|0]|0;break}h=c[f>>2]|0;if((h|0)==0){r=0;break}r=gj[h&4095](p)|0}}while(0);o=r&255;r=o<<8;q=r|l;c[2415264]=q;l=9661064+(o>>>5)|0;o=a[l]|0;if(((o&255)<<13|r&6144|0)==2088960){r=d[9661075]|0;c[2440610]=(c[2440610]|0)-r;c[2415269]=(c[2415269]|0)-r;s=a[l]|0}else{s=o}o=(s&255)<<13|q&8191;s=c[2388530]|0;l=c[s+16+(o>>>11<<2)>>2]|0;do{if((l|0)==0){r=c[s>>2]|0;if((r|0)==0){t=0;break}t=gj[r&4095](o)|0}else{t=a[l+(q&2047)|0]|0}}while(0);q=t&255;l=a[9661063]|0;o=l&255;if((o&32|0)==0){s=o&1;r=a[9661060]|0;k=r&255;if((o&8|0)==0){o=s+q+k|0;p=l&-66;h=(((o^k)&128&((r^t)&255^128)|0)==0?p:p|64)|(o&65280|0)!=0;a[9661063]=h;p=o&255;a[9661060]=p;u=h;v=p}else{p=s+(q&15)+(k&15)|0;s=(k&240)+(q&240)|0;k=l&-2;a[9661063]=k;if((p|0)>9){w=s+16|0;x=p+6|0}else{w=s;x=p}p=(w|0)>144?w+96|0:w;if((p&65280|0)==0){y=k}else{k=l|1;a[9661063]=k;y=k}k=(p&240|x&15)&255;a[9661060]=k;x=d[9661075]|0;c[2440610]=(c[2440610]|0)-x;c[2415269]=(c[2415269]|0)-x;u=y;v=k}a[9661063]=u&93|v&-128|(v<<24>>24==0?2:0);return}v=l&-33;a[9661063]=v;a[9661052]=a[9661061]|0;l=c[2415263]|0;c[2415264]=l;u=(d[9661065]|0)<<13|l&8191;k=c[2388530]|0;y=c[k+16+(u>>>11<<2)>>2]|0;do{if((y|0)==0){x=c[k>>2]|0;if((x|0)==0){z=0;A=v;break}p=gj[x&4095](u)|0;z=p;A=a[9661063]|0}else{z=a[y+(l&2047)|0]|0;A=v}}while(0);v=z&255;l=A&255;y=l&1;if((l&8|0)==0){l=v+q+y|0;u=A&-66;k=(((l^v)&((z^t)&128^128)|0)==0?u:u|64)|(l&65280|0)!=0;a[9661063]=k;B=l&255;C=k}else{k=(v&15)+(q&15)+y|0;y=(v&240)+(q&240)|0;q=A&-2;a[9661063]=q;if((k|0)>9){D=k+6|0;E=y+16|0}else{D=k;E=y}y=(E|0)>144?E+96|0:E;if((y&65280|0)==0){F=q}else{q=A|1;a[9661063]=q;F=q}q=d[9661075]|0;c[2440610]=(c[2440610]|0)-q;c[2415269]=(c[2415269]|0)-q;B=y&240|D&15;C=F}a[9661063]=(C&93|B&128|((B|0)==0?2:0))&255;C=c[2415264]|0;F=(d[9661065]|0)<<13|C&8191;D=B&255;B=c[2388530]|0;y=c[B+4112+(F>>>11<<2)>>2]|0;do{if((y|0)==0){q=c[B+4>>2]|0;if((q|0)==0){break}gg[q&4095](F,D)}else{a[y+(C&2047)|0]=D}}while(0);D=(d[9661075]|0)*-3|0;c[2440610]=D+(c[2440610]|0);c[2415269]=D+(c[2415269]|0);return}function fAz(){var b=0;b=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-b;c[2415269]=(c[2415269]|0)-b;a[9661063]=a[9661063]&-33;a[9661060]=0;return}function fAA(){var b=0;b=(d[9661075]|0)<<2;c[2440610]=(c[2440610]|0)-b;c[2415269]=(c[2415269]|0)-b;a[9661063]=a[9661063]&-33;return}function fAB(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=(d[9661075]|0)<<2;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;a[9661063]=a[9661063]&-33;e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=k;b[4830522]=l+1&65535;l=c[2415263]|0;c[2415264]=l;k=(d[9661065]|0)<<13|l&8191;h=c[m+4112+(k>>>11<<2)>>2]|0;if((h|0)!=0){a[h+(l&2047)|0]=0;return}l=c[m+4>>2]|0;if((l|0)==0){return}gg[l&4095](k,0);return}function fAC(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;e=(d[9661075]|0)<<2;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=k;b[4830522]=l+1&65535;l=c[2415263]|0;c[2415264]=l;k=(d[9661065]|0)<<13|l&8191;h=c[m+16+(k>>>11<<2)>>2]|0;do{if((h|0)==0){e=c[m>>2]|0;if((e|0)==0){o=0;break}o=gj[e&4095](k)|0}else{o=a[h+(l&2047)|0]|0}}while(0);l=o&255;h=a[9661063]|0;k=h&255;if((k&32|0)==0){m=k&1;e=a[9661060]|0;f=e&255;if((k&8|0)==0){k=m+l+f|0;i=h&-66;g=(((k^f)&128&((e^o)&255^128)|0)==0?i:i|64)|(k&65280|0)!=0;a[9661063]=g;i=k&255;a[9661060]=i;p=g;q=i}else{i=m+(l&15)+(f&15)|0;m=(f&240)+(l&240)|0;f=h&-2;a[9661063]=f;if((i|0)>9){r=m+16|0;s=i+6|0}else{r=m;s=i}i=(r|0)>144?r+96|0:r;if((i&65280|0)==0){t=f}else{f=h|1;a[9661063]=f;t=f}f=(i&240|s&15)&255;a[9661060]=f;s=d[9661075]|0;c[2440610]=(c[2440610]|0)-s;c[2415269]=(c[2415269]|0)-s;p=t;q=f}a[9661063]=p&93|q&-128|(q<<24>>24==0?2:0);return}q=h&-33;a[9661063]=q;a[9661052]=a[9661061]|0;h=c[2415263]|0;c[2415264]=h;p=(d[9661065]|0)<<13|h&8191;f=c[2388530]|0;t=c[f+16+(p>>>11<<2)>>2]|0;do{if((t|0)==0){s=c[f>>2]|0;if((s|0)==0){u=0;v=q;break}i=gj[s&4095](p)|0;u=i;v=a[9661063]|0}else{u=a[t+(h&2047)|0]|0;v=q}}while(0);q=u&255;h=v&255;t=h&1;if((h&8|0)==0){h=q+l+t|0;p=v&-66;f=(((h^q)&((u^o)&128^128)|0)==0?p:p|64)|(h&65280|0)!=0;a[9661063]=f;w=h&255;x=f}else{f=(q&15)+(l&15)+t|0;t=(q&240)+(l&240)|0;l=v&-2;a[9661063]=l;if((f|0)>9){y=f+6|0;z=t+16|0}else{y=f;z=t}t=(z|0)>144?z+96|0:z;if((t&65280|0)==0){A=l}else{l=v|1;a[9661063]=l;A=l}l=d[9661075]|0;c[2440610]=(c[2440610]|0)-l;c[2415269]=(c[2415269]|0)-l;w=t&240|y&15;x=A}a[9661063]=(x&93|w&128|((w|0)==0?2:0))&255;x=c[2415264]|0;A=(d[9661065]|0)<<13|x&8191;y=w&255;w=c[2388530]|0;t=c[w+4112+(A>>>11<<2)>>2]|0;do{if((t|0)==0){l=c[w+4>>2]|0;if((l|0)==0){break}gg[l&4095](A,y)}else{a[t+(x&2047)|0]=y}}while(0);y=(d[9661075]|0)*-3|0;c[2440610]=y+(c[2440610]|0);c[2415269]=y+(c[2415269]|0);return}function fAD(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=(d[9661075]|0)*-6|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=k;b[4830522]=l+1&65535;l=c[2415263]|0;c[2415264]=l;k=a[9661065]|0;h=(k&255)<<13|l&8191;e=c[m+16+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){o=0;p=k;q=l;r=m;break}i=gj[f&4095](h)|0;o=i;p=a[9661065]|0;q=c[2415264]|0;r=c[2388530]|0}else{o=a[e+(l&2047)|0]|0;p=k;q=l;r=m}}while(0);m=a[9661063]|0;l=((m&255)<<8|o&255)>>>1;a[9661063]=(l&128|(m&92|o&1)&93|((l&255|0)==0?2:0))&255;o=(p&255)<<13|q&8191;p=l&255;l=c[r+4112+(o>>>11<<2)>>2]|0;if((l|0)!=0){a[l+(q&2047)|0]=p;return}q=c[r+4>>2]|0;if((q|0)==0){return}gg[q&4095](o,p);return}function fAE(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=(d[9661075]|0)*-7|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=k;b[4830522]=l+1&65535;l=c[2415263]|0;c[2415264]=l;k=a[9661065]|0;h=(k&255)<<13|l&8191;e=c[m+16+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){o=0;p=k;q=l;r=m;break}i=gj[f&4095](h)|0;o=i;p=a[9661065]|0;q=c[2415264]|0;r=c[2388530]|0}else{o=a[e+(l&2047)|0]|0;p=k;q=l;r=m}}while(0);a[9661063]=a[9661063]&-33;m=o&-65;o=(p&255)<<13|q&8191;p=c[r+4112+(o>>>11<<2)>>2]|0;if((p|0)!=0){a[p+(q&2047)|0]=m;return}q=c[r+4>>2]|0;if((q|0)==0){return}gg[q&4095](o,m);return}function fAF(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=(d[9661075]|0)<<2;c[2440610]=(c[2440610]|0)-b;c[2415269]=(c[2415269]|0)-b;b=a[9661063]&-33;a[9661063]=b;a[9661048]=(a[9661048]|0)+1&255;e=c[2415262]|0;f=(d[9661065]|0)<<13|e&2097151;g=c[2388530]|0;h=c[g+16+(f>>>11<<2)>>2]|0;do{if((h|0)==0){i=c[g>>2]|0;if((i|0)==0){j=0;k=b;break}l=gj[i&4095](f)|0;j=l;k=a[9661063]|0}else{j=a[h+(e&2047)|0]|0;k=b}}while(0);a[9661060]=j;a[9661063]=k&93|j&-128|(j<<24>>24==0?2:0);return}function fAG(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;e=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;break}m=gj[j&4095](g)|0;k=m;l=b[4830522]|0}else{k=a[i+(f&2047)|0]|0;l=e}}while(0);e=k&255;b[4830522]=l+1&65535;l=a[9661063]|0;f=l&255;if((f&32|0)==0){i=f&1;g=a[9661060]|0;h=g&255;if((f&8|0)==0){f=i+e+h|0;m=l&-66;j=(((f^h)&128&((g^k)&255^128)|0)==0?m:m|64)|(f&65280|0)!=0;a[9661063]=j;m=f&255;a[9661060]=m;n=j;o=m}else{m=i+(e&15)+(h&15)|0;i=(h&240)+(e&240)|0;h=l&-2;a[9661063]=h;if((m|0)>9){p=i+16|0;q=m+6|0}else{p=i;q=m}m=(p|0)>144?p+96|0:p;if((m&65280|0)==0){r=h}else{h=l|1;a[9661063]=h;r=h}h=(m&240|q&15)&255;a[9661060]=h;q=d[9661075]|0;c[2440610]=(c[2440610]|0)-q;c[2415269]=(c[2415269]|0)-q;n=r;o=h}a[9661063]=n&93|o&-128|(o<<24>>24==0?2:0);return}o=l&-33;a[9661063]=o;a[9661052]=a[9661061]|0;l=c[2415263]|0;c[2415264]=l;n=(d[9661065]|0)<<13|l&8191;h=c[2388530]|0;r=c[h+16+(n>>>11<<2)>>2]|0;do{if((r|0)==0){q=c[h>>2]|0;if((q|0)==0){s=0;t=o;break}m=gj[q&4095](n)|0;s=m;t=a[9661063]|0}else{s=a[r+(l&2047)|0]|0;t=o}}while(0);o=s&255;l=t&255;r=l&1;if((l&8|0)==0){l=o+e+r|0;n=t&-66;h=(((l^o)&((s^k)&128^128)|0)==0?n:n|64)|(l&65280|0)!=0;a[9661063]=h;u=l&255;v=h}else{h=(o&15)+(e&15)+r|0;r=(o&240)+(e&240)|0;e=t&-2;a[9661063]=e;if((h|0)>9){w=h+6|0;x=r+16|0}else{w=h;x=r}r=(x|0)>144?x+96|0:x;if((r&65280|0)==0){y=e}else{e=t|1;a[9661063]=e;y=e}e=d[9661075]|0;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;u=r&240|w&15;v=y}a[9661063]=(v&93|u&128|((u|0)==0?2:0))&255;v=c[2415264]|0;y=(d[9661065]|0)<<13|v&8191;w=u&255;u=c[2388530]|0;r=c[u+4112+(y>>>11<<2)>>2]|0;do{if((r|0)==0){e=c[u+4>>2]|0;if((e|0)==0){break}gg[e&4095](y,w)}else{a[r+(v&2047)|0]=w}}while(0);w=(d[9661075]|0)*-3|0;c[2440610]=w+(c[2440610]|0);c[2415269]=w+(c[2415269]|0);return}function fAH(){var b=0,e=0,f=0;b=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-b;c[2415269]=(c[2415269]|0)-b;b=a[9661060]|0;e=a[9661063]|0;f=((e&255)<<8|b&255)>>>1;a[9661063]=(f&128|(e&92|b&1)&93|((f&255|0)==0?2:0))&255;a[9661060]=f&255;return}function fAI(){var b=0;b=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-b;c[2415269]=(c[2415269]|0)-b;a[9661063]=a[9661063]&-33;return}function fAJ(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;e=(d[9661075]|0)*-7|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661056]=k;k=l+1&65535;b[4830522]=k;l=k&65535;h=(d[9661064+(l>>>13)|0]|0)<<13|l&8191;e=c[m+8208+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){o=0;p=k;break}i=gj[f&4095](h)|0;o=i;p=b[4830522]|0}else{o=a[e+(l&2047)|0]|0;p=k}}while(0);a[9661057]=o;b[4830522]=p+1&65535;p=c[2415264]|0;o=9661064+(p>>>13&7)|0;k=a[o]|0;if(((k&255)<<13|p&6144|0)==2088960){l=d[9661075]|0;c[2440610]=(c[2440610]|0)-l;c[2415269]=(c[2415269]|0)-l;q=a[o]|0}else{q=k}k=(q&255)<<13|p&8191;q=c[2388530]|0;o=c[q+16+(k>>>11<<2)>>2]|0;do{if((o|0)==0){l=c[q>>2]|0;if((l|0)==0){r=0;s=p;break}e=gj[l&4095](k)|0;r=e;s=c[2415264]|0}else{r=a[o+(p&2047)|0]|0;s=p}}while(0);p=s+1|0;c[2415264]=p;s=9661064+(p>>>13&7)|0;o=a[s]|0;if(((o&255)<<13|p&6144|0)==2088960){k=d[9661075]|0;c[2440610]=(c[2440610]|0)-k;c[2415269]=(c[2415269]|0)-k;t=a[s]|0}else{t=o}o=(t&255)<<13|p&8191;t=c[2388530]|0;s=c[t+16+(o>>>11<<2)>>2]|0;if((s|0)!=0){u=a[s+(p&2047)|0]|0;a[9661057]=u;a[9661056]=r;v=a[9661063]|0;w=v&-33;a[9661063]=w;x=c[2415264]|0;c[2415261]=x;return}p=c[t>>2]|0;if((p|0)==0){u=0;a[9661057]=u;a[9661056]=r;v=a[9661063]|0;w=v&-33;a[9661063]=w;x=c[2415264]|0;c[2415261]=x;return}u=gj[p&4095](o)|0;a[9661057]=u;a[9661056]=r;v=a[9661063]|0;w=v&-33;a[9661063]=w;x=c[2415264]|0;c[2415261]=x;return}function fAK(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;e=(d[9661075]|0)*-5|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661056]=k;k=l+1&65535;b[4830522]=k;l=k&65535;h=(d[9661064+(l>>>13)|0]|0)<<13|l&8191;e=c[m+8208+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){o=0;p=k;break}i=gj[f&4095](h)|0;o=i;p=b[4830522]|0}else{o=a[e+(l&2047)|0]|0;p=k}}while(0);a[9661057]=o;b[4830522]=p+1&65535;p=c[2415264]|0;o=9661064+(p>>>13&7)|0;k=a[o]|0;if(((k&255)<<13|p&6144|0)==2088960){l=d[9661075]|0;c[2440610]=(c[2440610]|0)-l;c[2415269]=(c[2415269]|0)-l;q=a[o]|0}else{q=k}k=(q&255)<<13|p&8191;q=c[2388530]|0;o=c[q+16+(k>>>11<<2)>>2]|0;do{if((o|0)==0){l=c[q>>2]|0;if((l|0)==0){r=0;break}r=gj[l&4095](k)|0}else{r=a[o+(p&2047)|0]|0}}while(0);p=r&255;o=a[9661063]|0;k=o&255;if((k&32|0)==0){q=k&1;l=a[9661060]|0;e=l&255;if((k&8|0)==0){k=q+p+e|0;h=o&-66;m=(((k^e)&128&((l^r)&255^128)|0)==0?h:h|64)|(k&65280|0)!=0;a[9661063]=m;h=k&255;a[9661060]=h;s=m;t=h}else{h=q+(p&15)+(e&15)|0;q=(e&240)+(p&240)|0;e=o&-2;a[9661063]=e;if((h|0)>9){u=q+16|0;v=h+6|0}else{u=q;v=h}h=(u|0)>144?u+96|0:u;if((h&65280|0)==0){w=e}else{e=o|1;a[9661063]=e;w=e}e=(h&240|v&15)&255;a[9661060]=e;v=d[9661075]|0;c[2440610]=(c[2440610]|0)-v;c[2415269]=(c[2415269]|0)-v;s=w;t=e}a[9661063]=s&93|t&-128|(t<<24>>24==0?2:0);return}t=o&-33;a[9661063]=t;a[9661052]=a[9661061]|0;o=c[2415263]|0;c[2415264]=o;s=(d[9661065]|0)<<13|o&8191;e=c[2388530]|0;w=c[e+16+(s>>>11<<2)>>2]|0;do{if((w|0)==0){v=c[e>>2]|0;if((v|0)==0){x=0;y=t;break}h=gj[v&4095](s)|0;x=h;y=a[9661063]|0}else{x=a[w+(o&2047)|0]|0;y=t}}while(0);t=x&255;o=y&255;w=o&1;if((o&8|0)==0){o=t+p+w|0;s=y&-66;e=(((o^t)&((x^r)&128^128)|0)==0?s:s|64)|(o&65280|0)!=0;a[9661063]=e;z=o&255;A=e}else{e=(t&15)+(p&15)+w|0;w=(t&240)+(p&240)|0;p=y&-2;a[9661063]=p;if((e|0)>9){B=e+6|0;C=w+16|0}else{B=e;C=w}w=(C|0)>144?C+96|0:C;if((w&65280|0)==0){D=p}else{p=y|1;a[9661063]=p;D=p}p=d[9661075]|0;c[2440610]=(c[2440610]|0)-p;c[2415269]=(c[2415269]|0)-p;z=w&240|B&15;A=D}a[9661063]=(A&93|z&128|((z|0)==0?2:0))&255;A=c[2415264]|0;D=(d[9661065]|0)<<13|A&8191;B=z&255;z=c[2388530]|0;w=c[z+4112+(D>>>11<<2)>>2]|0;do{if((w|0)==0){p=c[z+4>>2]|0;if((p|0)==0){break}gg[p&4095](D,B)}else{a[w+(A&2047)|0]=B}}while(0);B=(d[9661075]|0)*-3|0;c[2440610]=B+(c[2440610]|0);c[2415269]=B+(c[2415269]|0);return}function fAL(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=(d[9661075]|0)*-7|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661056]=k;k=l+1&65535;b[4830522]=k;l=k&65535;h=(d[9661064+(l>>>13)|0]|0)<<13|l&8191;e=c[m+8208+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){o=0;p=k;break}i=gj[f&4095](h)|0;o=i;p=b[4830522]|0}else{o=a[e+(l&2047)|0]|0;p=k}}while(0);a[9661057]=o;b[4830522]=p+1&65535;p=c[2415264]|0;o=9661064+(p>>>13&7)|0;k=a[o]|0;if(((k&255)<<13|p&6144|0)==2088960){l=d[9661075]|0;c[2440610]=(c[2440610]|0)-l;c[2415269]=(c[2415269]|0)-l;q=a[o]|0}else{q=k}k=(q&255)<<13|p&8191;q=c[2388530]|0;o=c[q+16+(k>>>11<<2)>>2]|0;do{if((o|0)==0){l=c[q>>2]|0;if((l|0)==0){r=0;s=p;break}e=gj[l&4095](k)|0;r=e;s=c[2415264]|0}else{r=a[o+(p&2047)|0]|0;s=p}}while(0);p=a[9661063]|0;o=((p&255)<<8|r&255)>>>1;a[9661063]=(o&128|(p&92|r&1)&93|((o&255|0)==0?2:0))&255;r=o&255;o=9661064+(s>>>13&7)|0;p=a[o]|0;if(((p&255)<<13|s&6144|0)==2088960){k=d[9661075]|0;c[2440610]=(c[2440610]|0)-k;c[2415269]=(c[2415269]|0)-k;t=a[o]|0}else{t=p}p=(t&255)<<13|s&8191;t=c[2388530]|0;o=c[t+4112+(p>>>11<<2)>>2]|0;if((o|0)!=0){a[o+(s&2047)|0]=r;return}s=c[t+4>>2]|0;if((s|0)==0){return}gg[s&4095](p,r);return}function fAM(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=(d[9661075]|0)<<2;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=k;k=l+1&65535;b[4830522]=k;l=c[2415263]|0;c[2415264]=l;h=(d[9661065]|0)<<13|l&8191;e=c[m+16+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){a[9661063]=a[9661063]&-33;o=k;p=m;break}else{i=gj[f&4095](h)|0;q=i;r=b[4830522]|0;s=4255;break}}else{q=a[e+(l&2047)|0]|0;r=k;s=4255}}while(0);do{if((s|0)==4255){a[9661063]=a[9661063]&-33;if((q&64)==0){o=r;p=c[2388530]|0;break}b[4830522]=r+1&65535;k=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-k;c[2415269]=(c[2415269]|0)-k;return}}while(0);r=(d[9661075]|0)<<2;c[2440610]=(c[2440610]|0)-r;c[2415269]=(c[2415269]|0)-r;r=o&65535;q=(d[9661064+(r>>>13)|0]|0)<<13|r&8191;s=c[p+8208+(q>>>11<<2)>>2]|0;do{if((s|0)==0){k=c[p>>2]|0;if((k|0)==0){t=0;u=o;break}l=gj[k&4095](q)|0;t=l;u=b[4830522]|0}else{t=a[s+(r&2047)|0]|0;u=o}}while(0);b[4830528]=(u+1&65535)+(t<<24>>24)&65535;c[2415261]=c[2415264];return}function fAN(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=a[9661063]|0;a[9661063]=e&-33;if((e&64)==0){b[4830522]=(b[4830522]|0)+1&65535;e=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;return}e=(d[9661075]|0)<<2;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;break}m=gj[j&4095](g)|0;k=m;l=b[4830522]|0}else{k=a[i+(f&2047)|0]|0;l=e}}while(0);b[4830528]=(l+1&65535)+(k<<24>>24)&65535;c[2415261]=c[2415264];return}function fAO(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;e=(d[9661075]|0)*-7|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=k;b[4830522]=l+1&65535;l=c[2415263]|0;k=(l&255|0)==255;h=a[9661065]|0;e=(h&255)<<13|l&8191;f=c[m+16+(e>>>11<<2)>>2]|0;do{if((f|0)==0){i=c[m>>2]|0;if((i|0)==0){o=0;p=h;q=l;break}g=gj[i&4095](e)|0;o=g;p=a[9661065]|0;q=c[2415263]|0}else{o=a[f+(l&2047)|0]|0;p=h;q=l}}while(0);l=o&255;o=(p&255)<<13;do{if(k){p=q+7937|0;h=p&8191|o;f=c[2388530]|0;e=c[f+16+(h>>>11<<2)>>2]|0;if((e|0)!=0){r=a[e+(p&2047)|0]|0;break}p=c[f>>2]|0;if((p|0)==0){r=0;break}r=gj[p&4095](h)|0}else{h=q+1|0;p=h&8191|o;f=c[2388530]|0;e=c[f+16+(p>>>11<<2)>>2]|0;if((e|0)!=0){r=a[e+(h&2047)|0]|0;break}h=c[f>>2]|0;if((h|0)==0){r=0;break}r=gj[h&4095](p)|0}}while(0);o=(r&255)<<8|l;c[2415264]=o;b[4830528]=(o&65535)+(d[9661062]|0)&65535;o=c[2415264]|0;l=9661064+(o>>>13&7)|0;r=a[l]|0;if(((r&255)<<13|o&6144|0)==2088960){q=d[9661075]|0;c[2440610]=(c[2440610]|0)-q;c[2415269]=(c[2415269]|0)-q;s=a[l]|0}else{s=r}r=(s&255)<<13|o&8191;s=c[2388530]|0;l=c[s+16+(r>>>11<<2)>>2]|0;do{if((l|0)==0){q=c[s>>2]|0;if((q|0)==0){t=0;break}t=gj[q&4095](r)|0}else{t=a[l+(o&2047)|0]|0}}while(0);o=t&255;l=a[9661063]|0;r=l&255;if((r&32|0)==0){s=r&1;q=a[9661060]|0;k=q&255;if((r&8|0)==0){r=s+o+k|0;p=l&-66;h=(((r^k)&128&((q^t)&255^128)|0)==0?p:p|64)|(r&65280|0)!=0;a[9661063]=h;p=r&255;a[9661060]=p;u=h;v=p}else{p=s+(o&15)+(k&15)|0;s=(k&240)+(o&240)|0;k=l&-2;a[9661063]=k;if((p|0)>9){w=s+16|0;x=p+6|0}else{w=s;x=p}p=(w|0)>144?w+96|0:w;if((p&65280|0)==0){y=k}else{k=l|1;a[9661063]=k;y=k}k=(p&240|x&15)&255;a[9661060]=k;x=d[9661075]|0;c[2440610]=(c[2440610]|0)-x;c[2415269]=(c[2415269]|0)-x;u=y;v=k}a[9661063]=u&93|v&-128|(v<<24>>24==0?2:0);return}v=l&-33;a[9661063]=v;a[9661052]=a[9661061]|0;l=c[2415263]|0;c[2415264]=l;u=(d[9661065]|0)<<13|l&8191;k=c[2388530]|0;y=c[k+16+(u>>>11<<2)>>2]|0;do{if((y|0)==0){x=c[k>>2]|0;if((x|0)==0){z=0;A=v;break}p=gj[x&4095](u)|0;z=p;A=a[9661063]|0}else{z=a[y+(l&2047)|0]|0;A=v}}while(0);v=z&255;l=A&255;y=l&1;if((l&8|0)==0){l=v+o+y|0;u=A&-66;k=(((l^v)&((z^t)&128^128)|0)==0?u:u|64)|(l&65280|0)!=0;a[9661063]=k;B=l&255;C=k}else{k=(v&15)+(o&15)+y|0;y=(v&240)+(o&240)|0;o=A&-2;a[9661063]=o;if((k|0)>9){D=k+6|0;E=y+16|0}else{D=k;E=y}y=(E|0)>144?E+96|0:E;if((y&65280|0)==0){F=o}else{o=A|1;a[9661063]=o;F=o}o=d[9661075]|0;c[2440610]=(c[2440610]|0)-o;c[2415269]=(c[2415269]|0)-o;B=y&240|D&15;C=F}a[9661063]=(C&93|B&128|((B|0)==0?2:0))&255;C=c[2415264]|0;F=(d[9661065]|0)<<13|C&8191;D=B&255;B=c[2388530]|0;y=c[B+4112+(F>>>11<<2)>>2]|0;do{if((y|0)==0){o=c[B+4>>2]|0;if((o|0)==0){break}gg[o&4095](F,D)}else{a[y+(C&2047)|0]=D}}while(0);D=(d[9661075]|0)*-3|0;c[2440610]=D+(c[2440610]|0);c[2415269]=D+(c[2415269]|0);return}function fAP(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;e=(d[9661075]|0)*-7|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=k;b[4830522]=l+1&65535;l=c[2415263]|0;k=(l&255|0)==255;h=a[9661065]|0;e=(h&255)<<13|l&8191;f=c[m+16+(e>>>11<<2)>>2]|0;do{if((f|0)==0){i=c[m>>2]|0;if((i|0)==0){o=0;p=h;q=l;break}g=gj[i&4095](e)|0;o=g;p=a[9661065]|0;q=c[2415263]|0}else{o=a[f+(l&2047)|0]|0;p=h;q=l}}while(0);l=o&255;o=(p&255)<<13;do{if(k){p=q+7937|0;h=p&8191|o;f=c[2388530]|0;e=c[f+16+(h>>>11<<2)>>2]|0;if((e|0)!=0){r=a[e+(p&2047)|0]|0;break}p=c[f>>2]|0;if((p|0)==0){r=0;break}r=gj[p&4095](h)|0}else{h=q+1|0;p=h&8191|o;f=c[2388530]|0;e=c[f+16+(p>>>11<<2)>>2]|0;if((e|0)!=0){r=a[e+(h&2047)|0]|0;break}h=c[f>>2]|0;if((h|0)==0){r=0;break}r=gj[h&4095](p)|0}}while(0);o=r&255;r=o<<8;q=r|l;c[2415264]=q;l=9661064+(o>>>5)|0;o=a[l]|0;if(((o&255)<<13|r&6144|0)==2088960){r=d[9661075]|0;c[2440610]=(c[2440610]|0)-r;c[2415269]=(c[2415269]|0)-r;s=a[l]|0}else{s=o}o=(s&255)<<13|q&8191;s=c[2388530]|0;l=c[s+16+(o>>>11<<2)>>2]|0;do{if((l|0)==0){r=c[s>>2]|0;if((r|0)==0){t=0;break}t=gj[r&4095](o)|0}else{t=a[l+(q&2047)|0]|0}}while(0);q=t&255;l=a[9661063]|0;o=l&255;if((o&32|0)==0){s=o&1;r=a[9661060]|0;k=r&255;if((o&8|0)==0){o=s+q+k|0;p=l&-66;h=(((o^k)&128&((r^t)&255^128)|0)==0?p:p|64)|(o&65280|0)!=0;a[9661063]=h;p=o&255;a[9661060]=p;u=h;v=p}else{p=s+(q&15)+(k&15)|0;s=(k&240)+(q&240)|0;k=l&-2;a[9661063]=k;if((p|0)>9){w=s+16|0;x=p+6|0}else{w=s;x=p}p=(w|0)>144?w+96|0:w;if((p&65280|0)==0){y=k}else{k=l|1;a[9661063]=k;y=k}k=(p&240|x&15)&255;a[9661060]=k;x=d[9661075]|0;c[2440610]=(c[2440610]|0)-x;c[2415269]=(c[2415269]|0)-x;u=y;v=k}a[9661063]=u&93|v&-128|(v<<24>>24==0?2:0);return}v=l&-33;a[9661063]=v;a[9661052]=a[9661061]|0;l=c[2415263]|0;c[2415264]=l;u=(d[9661065]|0)<<13|l&8191;k=c[2388530]|0;y=c[k+16+(u>>>11<<2)>>2]|0;do{if((y|0)==0){x=c[k>>2]|0;if((x|0)==0){z=0;A=v;break}p=gj[x&4095](u)|0;z=p;A=a[9661063]|0}else{z=a[y+(l&2047)|0]|0;A=v}}while(0);v=z&255;l=A&255;y=l&1;if((l&8|0)==0){l=v+q+y|0;u=A&-66;k=(((l^v)&((z^t)&128^128)|0)==0?u:u|64)|(l&65280|0)!=0;a[9661063]=k;B=l&255;C=k}else{k=(v&15)+(q&15)+y|0;y=(v&240)+(q&240)|0;q=A&-2;a[9661063]=q;if((k|0)>9){D=k+6|0;E=y+16|0}else{D=k;E=y}y=(E|0)>144?E+96|0:E;if((y&65280|0)==0){F=q}else{q=A|1;a[9661063]=q;F=q}q=d[9661075]|0;c[2440610]=(c[2440610]|0)-q;c[2415269]=(c[2415269]|0)-q;B=y&240|D&15;C=F}a[9661063]=(C&93|B&128|((B|0)==0?2:0))&255;C=c[2415264]|0;F=(d[9661065]|0)<<13|C&8191;D=B&255;B=c[2388530]|0;y=c[B+4112+(F>>>11<<2)>>2]|0;do{if((y|0)==0){q=c[B+4>>2]|0;if((q|0)==0){break}gg[q&4095](F,D)}else{a[y+(C&2047)|0]=D}}while(0);D=(d[9661075]|0)*-3|0;c[2440610]=D+(c[2440610]|0);c[2415269]=D+(c[2415269]|0);return}function fAQ(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;a[9661063]=a[9661063]&-33;e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+16+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);h=k&255;k=(l&65535)+1|0;e=(d[9661064+(k>>>13&7)|0]|0)<<13|k&8191;f=c[m+16+(e>>>11<<2)>>2]|0;do{if((f|0)==0){i=c[m>>2]|0;if((i|0)==0){o=0;p=l;q=m;break}g=gj[i&4095](e)|0;o=g;p=b[4830522]|0;q=c[2388530]|0}else{o=a[f+(k&2047)|0]|0;p=l;q=m}}while(0);m=(o&255)<<8|h;h=(p&65535)+2|0;o=(d[9661064+(h>>>13&7)|0]|0)<<13|h&8191;l=c[q+16+(o>>>11<<2)>>2]|0;do{if((l|0)==0){k=c[q>>2]|0;if((k|0)==0){r=0;s=p;t=q;break}f=gj[k&4095](o)|0;r=f;s=b[4830522]|0;t=c[2388530]|0}else{r=a[l+(h&2047)|0]|0;s=p;t=q}}while(0);q=r&255;r=(s&65535)+3|0;p=(d[9661064+(r>>>13&7)|0]|0)<<13|r&8191;h=c[t+16+(p>>>11<<2)>>2]|0;do{if((h|0)==0){l=c[t>>2]|0;if((l|0)==0){u=0;v=s;w=t;break}o=gj[l&4095](p)|0;u=o;v=b[4830522]|0;w=c[2388530]|0}else{u=a[h+(r&2047)|0]|0;v=s;w=t}}while(0);t=(u&255)<<8|q;q=(v&65535)+4|0;u=(d[9661064+(q>>>13&7)|0]|0)<<13|q&8191;s=c[w+16+(u>>>11<<2)>>2]|0;do{if((s|0)==0){r=c[w>>2]|0;if((r|0)==0){x=0;y=v;z=w;break}h=gj[r&4095](u)|0;x=h;y=b[4830522]|0;z=c[2388530]|0}else{x=a[s+(q&2047)|0]|0;y=v;z=w}}while(0);w=x&255;x=(y&65535)+5|0;v=(d[9661064+(x>>>13&7)|0]|0)<<13|x&8191;q=c[z+16+(v>>>11<<2)>>2]|0;do{if((q|0)==0){s=c[z>>2]|0;if((s|0)==0){A=0;B=y;break}u=gj[s&4095](v)|0;A=u;B=b[4830522]|0}else{A=a[q+(x&2047)|0]|0;B=y}}while(0);y=(A&255)<<8|w;b[4830522]=B+6&65535;B=(y|0)==0?65536:y;y=ag((B*6|0)+17|0,d[9661075]|0)|0;c[2440610]=(c[2440610]|0)-y;c[2415269]=(c[2415269]|0)-y;y=t;t=m;m=B;while(1){B=m-1|0;w=9661064+(t>>>13&7)|0;A=a[w]|0;if(((A&255)<<13|t&6144|0)==2088960){x=d[9661075]|0;c[2440610]=(c[2440610]|0)-x;c[2415269]=(c[2415269]|0)-x;C=a[w]|0}else{C=A}A=(C&255)<<13|t&8191;w=c[2388530]|0;x=c[w+16+(A>>>11<<2)>>2]|0;do{if((x|0)==0){q=c[w>>2]|0;if((q|0)==0){D=0;break}D=gj[q&4095](A)|0}else{D=a[x+(t&2047)|0]|0}}while(0);x=9661064+(y>>>13&7)|0;A=a[x]|0;if(((A&255)<<13|y&6144|0)==2088960){w=d[9661075]|0;c[2440610]=(c[2440610]|0)-w;c[2415269]=(c[2415269]|0)-w;E=a[x]|0}else{E=A}A=(E&255)<<13|y&8191;x=c[2388530]|0;w=c[x+4112+(A>>>11<<2)>>2]|0;do{if((w|0)==0){q=c[x+4>>2]|0;if((q|0)==0){break}gg[q&4095](A,D)}else{a[w+(y&2047)|0]=D}}while(0);if((B|0)==0){break}else{y=y+1|0;t=t+1|0;m=B}}return}function fAR(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=(d[9661075]|0)<<2;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;a[9661063]=a[9661063]&-33;e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=(a[9661061]|0)+k&255;b[4830522]=l+1&65535;l=c[2415263]|0;c[2415264]=l;k=(d[9661065]|0)<<13|l&8191;h=c[m+4112+(k>>>11<<2)>>2]|0;if((h|0)!=0){a[h+(l&2047)|0]=0;return}l=c[m+4>>2]|0;if((l|0)==0){return}gg[l&4095](k,0);return}function fAS(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;e=(d[9661075]|0)<<2;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=(a[9661061]|0)+k&255;b[4830522]=l+1&65535;l=c[2415263]|0;c[2415264]=l;k=(d[9661065]|0)<<13|l&8191;h=c[m+16+(k>>>11<<2)>>2]|0;do{if((h|0)==0){e=c[m>>2]|0;if((e|0)==0){o=0;break}o=gj[e&4095](k)|0}else{o=a[h+(l&2047)|0]|0}}while(0);l=o&255;h=a[9661063]|0;k=h&255;if((k&32|0)==0){m=k&1;e=a[9661060]|0;f=e&255;if((k&8|0)==0){k=m+l+f|0;i=h&-66;g=(((k^f)&128&((e^o)&255^128)|0)==0?i:i|64)|(k&65280|0)!=0;a[9661063]=g;i=k&255;a[9661060]=i;p=g;q=i}else{i=m+(l&15)+(f&15)|0;m=(f&240)+(l&240)|0;f=h&-2;a[9661063]=f;if((i|0)>9){r=m+16|0;s=i+6|0}else{r=m;s=i}i=(r|0)>144?r+96|0:r;if((i&65280|0)==0){t=f}else{f=h|1;a[9661063]=f;t=f}f=(i&240|s&15)&255;a[9661060]=f;s=d[9661075]|0;c[2440610]=(c[2440610]|0)-s;c[2415269]=(c[2415269]|0)-s;p=t;q=f}a[9661063]=p&93|q&-128|(q<<24>>24==0?2:0);return}q=h&-33;a[9661063]=q;a[9661052]=a[9661061]|0;h=c[2415263]|0;c[2415264]=h;p=(d[9661065]|0)<<13|h&8191;f=c[2388530]|0;t=c[f+16+(p>>>11<<2)>>2]|0;do{if((t|0)==0){s=c[f>>2]|0;if((s|0)==0){u=0;v=q;break}i=gj[s&4095](p)|0;u=i;v=a[9661063]|0}else{u=a[t+(h&2047)|0]|0;v=q}}while(0);q=u&255;h=v&255;t=h&1;if((h&8|0)==0){h=q+l+t|0;p=v&-66;f=(((h^q)&((u^o)&128^128)|0)==0?p:p|64)|(h&65280|0)!=0;a[9661063]=f;w=h&255;x=f}else{f=(q&15)+(l&15)+t|0;t=(q&240)+(l&240)|0;l=v&-2;a[9661063]=l;if((f|0)>9){y=f+6|0;z=t+16|0}else{y=f;z=t}t=(z|0)>144?z+96|0:z;if((t&65280|0)==0){A=l}else{l=v|1;a[9661063]=l;A=l}l=d[9661075]|0;c[2440610]=(c[2440610]|0)-l;c[2415269]=(c[2415269]|0)-l;w=t&240|y&15;x=A}a[9661063]=(x&93|w&128|((w|0)==0?2:0))&255;x=c[2415264]|0;A=(d[9661065]|0)<<13|x&8191;y=w&255;w=c[2388530]|0;t=c[w+4112+(A>>>11<<2)>>2]|0;do{if((t|0)==0){l=c[w+4>>2]|0;if((l|0)==0){break}gg[l&4095](A,y)}else{a[t+(x&2047)|0]=y}}while(0);y=(d[9661075]|0)*-3|0;c[2440610]=y+(c[2440610]|0);c[2415269]=y+(c[2415269]|0);return}function fAT(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=(d[9661075]|0)*-6|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=(a[9661061]|0)+k&255;b[4830522]=l+1&65535;l=c[2415263]|0;c[2415264]=l;k=a[9661065]|0;h=(k&255)<<13|l&8191;e=c[m+16+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){o=0;p=k;q=l;r=m;break}i=gj[f&4095](h)|0;o=i;p=a[9661065]|0;q=c[2415264]|0;r=c[2388530]|0}else{o=a[e+(l&2047)|0]|0;p=k;q=l;r=m}}while(0);m=a[9661063]|0;l=((m&255)<<8|o&255)>>>1;a[9661063]=(l&128|(m&92|o&1)&93|((l&255|0)==0?2:0))&255;o=(p&255)<<13|q&8191;p=l&255;l=c[r+4112+(o>>>11<<2)>>2]|0;if((l|0)!=0){a[l+(q&2047)|0]=p;return}q=c[r+4>>2]|0;if((q|0)==0){return}gg[q&4095](o,p);return}function fAU(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=(d[9661075]|0)*-7|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=k;b[4830522]=l+1&65535;l=c[2415263]|0;c[2415264]=l;k=a[9661065]|0;h=(k&255)<<13|l&8191;e=c[m+16+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){o=0;p=k;q=l;r=m;break}i=gj[f&4095](h)|0;o=i;p=a[9661065]|0;q=c[2415264]|0;r=c[2388530]|0}else{o=a[e+(l&2047)|0]|0;p=k;q=l;r=m}}while(0);a[9661063]=a[9661063]&-33;m=o&127;o=(p&255)<<13|q&8191;p=c[r+4112+(o>>>11<<2)>>2]|0;if((p|0)!=0){a[p+(q&2047)|0]=m;return}q=c[r+4>>2]|0;if((q|0)==0){return}gg[q&4095](o,m);return}function fAV(){var b=0;b=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-b;c[2415269]=(c[2415269]|0)-b;a[9661063]=a[9661063]&-37|4;return}function fAW(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;e=(d[9661075]|0)*-5|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661056]=k;k=l+1&65535;b[4830522]=k;l=k&65535;h=(d[9661064+(l>>>13)|0]|0)<<13|l&8191;e=c[m+8208+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){o=0;p=k;break}i=gj[f&4095](h)|0;o=i;p=b[4830522]|0}else{o=a[e+(l&2047)|0]|0;p=k}}while(0);a[9661057]=o;b[4830522]=p+1&65535;b[4830528]=(b[4830528]|0)+(d[9661062]|0)&65535;p=c[2415264]|0;o=9661064+(p>>>13&7)|0;k=a[o]|0;if(((k&255)<<13|p&6144|0)==2088960){l=d[9661075]|0;c[2440610]=(c[2440610]|0)-l;c[2415269]=(c[2415269]|0)-l;q=a[o]|0}else{q=k}k=(q&255)<<13|p&8191;q=c[2388530]|0;o=c[q+16+(k>>>11<<2)>>2]|0;do{if((o|0)==0){l=c[q>>2]|0;if((l|0)==0){r=0;break}r=gj[l&4095](k)|0}else{r=a[o+(p&2047)|0]|0}}while(0);p=r&255;o=a[9661063]|0;k=o&255;if((k&32|0)==0){q=k&1;l=a[9661060]|0;e=l&255;if((k&8|0)==0){k=q+p+e|0;h=o&-66;m=(((k^e)&128&((l^r)&255^128)|0)==0?h:h|64)|(k&65280|0)!=0;a[9661063]=m;h=k&255;a[9661060]=h;s=m;t=h}else{h=q+(p&15)+(e&15)|0;q=(e&240)+(p&240)|0;e=o&-2;a[9661063]=e;if((h|0)>9){u=q+16|0;v=h+6|0}else{u=q;v=h}h=(u|0)>144?u+96|0:u;if((h&65280|0)==0){w=e}else{e=o|1;a[9661063]=e;w=e}e=(h&240|v&15)&255;a[9661060]=e;v=d[9661075]|0;c[2440610]=(c[2440610]|0)-v;c[2415269]=(c[2415269]|0)-v;s=w;t=e}a[9661063]=s&93|t&-128|(t<<24>>24==0?2:0);return}t=o&-33;a[9661063]=t;a[9661052]=a[9661061]|0;o=c[2415263]|0;c[2415264]=o;s=(d[9661065]|0)<<13|o&8191;e=c[2388530]|0;w=c[e+16+(s>>>11<<2)>>2]|0;do{if((w|0)==0){v=c[e>>2]|0;if((v|0)==0){x=0;y=t;break}h=gj[v&4095](s)|0;x=h;y=a[9661063]|0}else{x=a[w+(o&2047)|0]|0;y=t}}while(0);t=x&255;o=y&255;w=o&1;if((o&8|0)==0){o=t+p+w|0;s=y&-66;e=(((o^t)&((x^r)&128^128)|0)==0?s:s|64)|(o&65280|0)!=0;a[9661063]=e;z=o&255;A=e}else{e=(t&15)+(p&15)+w|0;w=(t&240)+(p&240)|0;p=y&-2;a[9661063]=p;if((e|0)>9){B=e+6|0;C=w+16|0}else{B=e;C=w}w=(C|0)>144?C+96|0:C;if((w&65280|0)==0){D=p}else{p=y|1;a[9661063]=p;D=p}p=d[9661075]|0;c[2440610]=(c[2440610]|0)-p;c[2415269]=(c[2415269]|0)-p;z=w&240|B&15;A=D}a[9661063]=(A&93|z&128|((z|0)==0?2:0))&255;A=c[2415264]|0;D=(d[9661065]|0)<<13|A&8191;B=z&255;z=c[2388530]|0;w=c[z+4112+(D>>>11<<2)>>2]|0;do{if((w|0)==0){p=c[z+4>>2]|0;if((p|0)==0){break}gg[p&4095](D,B)}else{a[w+(A&2047)|0]=B}}while(0);B=(d[9661075]|0)*-3|0;c[2440610]=B+(c[2440610]|0);c[2415269]=B+(c[2415269]|0);return}function fAX(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=(d[9661075]|0)<<2;c[2440610]=(c[2440610]|0)-b;c[2415269]=(c[2415269]|0)-b;b=a[9661063]&-33;a[9661063]=b;a[9661048]=(a[9661048]|0)+1&255;e=c[2415262]|0;f=(d[9661065]|0)<<13|e&2097151;g=c[2388530]|0;h=c[g+16+(f>>>11<<2)>>2]|0;do{if((h|0)==0){i=c[g>>2]|0;if((i|0)==0){j=0;k=b;break}l=gj[i&4095](f)|0;j=l;k=a[9661063]|0}else{j=a[h+(e&2047)|0]|0;k=b}}while(0);a[9661062]=j;a[9661063]=k&93|j&-128|(j<<24>>24==0?2:0);return}function fAY(){var b=0;b=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-b;c[2415269]=(c[2415269]|0)-b;a[9661063]=a[9661063]&-33;return}function fAZ(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;e=(d[9661075]|0)*-7|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661056]=k;k=l+1&65535;b[4830522]=k;l=k&65535;h=(d[9661064+(l>>>13)|0]|0)<<13|l&8191;e=c[m+8208+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){o=0;p=k;break}i=gj[f&4095](h)|0;o=i;p=b[4830522]|0}else{o=a[e+(l&2047)|0]|0;p=k}}while(0);a[9661057]=o;b[4830522]=p+1&65535;p=(c[2415264]|0)+(d[9661061]|0)|0;c[2415264]=p;o=9661064+(p>>>13&7)|0;k=a[o]|0;if(((k&255)<<13|p&6144|0)==2088960){l=d[9661075]|0;c[2440610]=(c[2440610]|0)-l;c[2415269]=(c[2415269]|0)-l;q=a[o]|0}else{q=k}k=(q&255)<<13|p&8191;q=c[2388530]|0;o=c[q+16+(k>>>11<<2)>>2]|0;do{if((o|0)==0){l=c[q>>2]|0;if((l|0)==0){r=0;s=p;break}e=gj[l&4095](k)|0;r=e;s=c[2415264]|0}else{r=a[o+(p&2047)|0]|0;s=p}}while(0);p=s+1|0;c[2415264]=p;s=9661064+(p>>>13&7)|0;o=a[s]|0;if(((o&255)<<13|p&6144|0)==2088960){k=d[9661075]|0;c[2440610]=(c[2440610]|0)-k;c[2415269]=(c[2415269]|0)-k;t=a[s]|0}else{t=o}o=(t&255)<<13|p&8191;t=c[2388530]|0;s=c[t+16+(o>>>11<<2)>>2]|0;if((s|0)!=0){u=a[s+(p&2047)|0]|0;a[9661057]=u;a[9661056]=r;v=a[9661063]|0;w=v&-33;a[9661063]=w;x=c[2415264]|0;c[2415261]=x;return}p=c[t>>2]|0;if((p|0)==0){u=0;a[9661057]=u;a[9661056]=r;v=a[9661063]|0;w=v&-33;a[9661063]=w;x=c[2415264]|0;c[2415261]=x;return}u=gj[p&4095](o)|0;a[9661057]=u;a[9661056]=r;v=a[9661063]|0;w=v&-33;a[9661063]=w;x=c[2415264]|0;c[2415261]=x;return}function fA_(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;e=(d[9661075]|0)*-5|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661056]=k;k=l+1&65535;b[4830522]=k;l=k&65535;h=(d[9661064+(l>>>13)|0]|0)<<13|l&8191;e=c[m+8208+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){o=0;p=k;break}i=gj[f&4095](h)|0;o=i;p=b[4830522]|0}else{o=a[e+(l&2047)|0]|0;p=k}}while(0);a[9661057]=o;b[4830522]=p+1&65535;b[4830528]=(b[4830528]|0)+(d[9661061]|0)&65535;p=c[2415264]|0;o=9661064+(p>>>13&7)|0;k=a[o]|0;if(((k&255)<<13|p&6144|0)==2088960){l=d[9661075]|0;c[2440610]=(c[2440610]|0)-l;c[2415269]=(c[2415269]|0)-l;q=a[o]|0}else{q=k}k=(q&255)<<13|p&8191;q=c[2388530]|0;o=c[q+16+(k>>>11<<2)>>2]|0;do{if((o|0)==0){l=c[q>>2]|0;if((l|0)==0){r=0;break}r=gj[l&4095](k)|0}else{r=a[o+(p&2047)|0]|0}}while(0);p=r&255;o=a[9661063]|0;k=o&255;if((k&32|0)==0){q=k&1;l=a[9661060]|0;e=l&255;if((k&8|0)==0){k=q+p+e|0;h=o&-66;m=(((k^e)&128&((l^r)&255^128)|0)==0?h:h|64)|(k&65280|0)!=0;a[9661063]=m;h=k&255;a[9661060]=h;s=m;t=h}else{h=q+(p&15)+(e&15)|0;q=(e&240)+(p&240)|0;e=o&-2;a[9661063]=e;if((h|0)>9){u=q+16|0;v=h+6|0}else{u=q;v=h}h=(u|0)>144?u+96|0:u;if((h&65280|0)==0){w=e}else{e=o|1;a[9661063]=e;w=e}e=(h&240|v&15)&255;a[9661060]=e;v=d[9661075]|0;c[2440610]=(c[2440610]|0)-v;c[2415269]=(c[2415269]|0)-v;s=w;t=e}a[9661063]=s&93|t&-128|(t<<24>>24==0?2:0);return}t=o&-33;a[9661063]=t;a[9661052]=a[9661061]|0;o=c[2415263]|0;c[2415264]=o;s=(d[9661065]|0)<<13|o&8191;e=c[2388530]|0;w=c[e+16+(s>>>11<<2)>>2]|0;do{if((w|0)==0){v=c[e>>2]|0;if((v|0)==0){x=0;y=t;break}h=gj[v&4095](s)|0;x=h;y=a[9661063]|0}else{x=a[w+(o&2047)|0]|0;y=t}}while(0);t=x&255;o=y&255;w=o&1;if((o&8|0)==0){o=t+p+w|0;s=y&-66;e=(((o^t)&((x^r)&128^128)|0)==0?s:s|64)|(o&65280|0)!=0;a[9661063]=e;z=o&255;A=e}else{e=(t&15)+(p&15)+w|0;w=(t&240)+(p&240)|0;p=y&-2;a[9661063]=p;if((e|0)>9){B=e+6|0;C=w+16|0}else{B=e;C=w}w=(C|0)>144?C+96|0:C;if((w&65280|0)==0){D=p}else{p=y|1;a[9661063]=p;D=p}p=d[9661075]|0;c[2440610]=(c[2440610]|0)-p;c[2415269]=(c[2415269]|0)-p;z=w&240|B&15;A=D}a[9661063]=(A&93|z&128|((z|0)==0?2:0))&255;A=c[2415264]|0;D=(d[9661065]|0)<<13|A&8191;B=z&255;z=c[2388530]|0;w=c[z+4112+(D>>>11<<2)>>2]|0;do{if((w|0)==0){p=c[z+4>>2]|0;if((p|0)==0){break}gg[p&4095](D,B)}else{a[w+(A&2047)|0]=B}}while(0);B=(d[9661075]|0)*-3|0;c[2440610]=B+(c[2440610]|0);c[2415269]=B+(c[2415269]|0);return}function fA$(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=(d[9661075]|0)*-7|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661056]=k;k=l+1&65535;b[4830522]=k;l=k&65535;h=(d[9661064+(l>>>13)|0]|0)<<13|l&8191;e=c[m+8208+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){o=0;p=k;break}i=gj[f&4095](h)|0;o=i;p=b[4830522]|0}else{o=a[e+(l&2047)|0]|0;p=k}}while(0);a[9661057]=o;b[4830522]=p+1&65535;b[4830528]=(b[4830528]|0)+(d[9661061]|0)&65535;p=c[2415264]|0;o=9661064+(p>>>13&7)|0;k=a[o]|0;if(((k&255)<<13|p&6144|0)==2088960){l=d[9661075]|0;c[2440610]=(c[2440610]|0)-l;c[2415269]=(c[2415269]|0)-l;q=a[o]|0}else{q=k}k=(q&255)<<13|p&8191;q=c[2388530]|0;o=c[q+16+(k>>>11<<2)>>2]|0;do{if((o|0)==0){l=c[q>>2]|0;if((l|0)==0){r=0;s=p;break}e=gj[l&4095](k)|0;r=e;s=c[2415264]|0}else{r=a[o+(p&2047)|0]|0;s=p}}while(0);p=a[9661063]|0;o=((p&255)<<8|r&255)>>>1;a[9661063]=(o&128|(p&92|r&1)&93|((o&255|0)==0?2:0))&255;r=o&255;o=9661064+(s>>>13&7)|0;p=a[o]|0;if(((p&255)<<13|s&6144|0)==2088960){k=d[9661075]|0;c[2440610]=(c[2440610]|0)-k;c[2415269]=(c[2415269]|0)-k;t=a[o]|0}else{t=p}p=(t&255)<<13|s&8191;t=c[2388530]|0;o=c[t+4112+(p>>>11<<2)>>2]|0;if((o|0)!=0){a[o+(s&2047)|0]=r;return}s=c[t+4>>2]|0;if((s|0)==0){return}gg[s&4095](p,r);return}function fA0(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=(d[9661075]|0)<<2;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=k;k=l+1&65535;b[4830522]=k;l=c[2415263]|0;c[2415264]=l;h=(d[9661065]|0)<<13|l&8191;e=c[m+16+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){a[9661063]=a[9661063]&-33;o=k;p=m;break}else{i=gj[f&4095](h)|0;q=i;r=b[4830522]|0;s=4645;break}}else{q=a[e+(l&2047)|0]|0;r=k;s=4645}}while(0);do{if((s|0)==4645){a[9661063]=a[9661063]&-33;if(q<<24>>24>=0){o=r;p=c[2388530]|0;break}b[4830522]=r+1&65535;k=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-k;c[2415269]=(c[2415269]|0)-k;return}}while(0);r=(d[9661075]|0)<<2;c[2440610]=(c[2440610]|0)-r;c[2415269]=(c[2415269]|0)-r;r=o&65535;q=(d[9661064+(r>>>13)|0]|0)<<13|r&8191;s=c[p+8208+(q>>>11<<2)>>2]|0;do{if((s|0)==0){k=c[p>>2]|0;if((k|0)==0){t=0;u=o;break}l=gj[k&4095](q)|0;t=l;u=b[4830522]|0}else{t=a[s+(r&2047)|0]|0;u=o}}while(0);b[4830528]=(u+1&65535)+(t<<24>>24)&65535;c[2415261]=c[2415264];return}function fA1(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a[9661063]=a[9661063]&-33;e=(d[9661075]|0)<<2;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;break}m=gj[j&4095](g)|0;k=m;l=b[4830522]|0}else{k=a[i+(f&2047)|0]|0;l=e}}while(0);b[4830528]=(l+1&65535)+(k<<24>>24)&65535;c[2415261]=c[2415264];return}function fA2(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=(d[9661075]|0)*-7|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);a[9661063]=a[9661063]&-33;e=a[9661060]|0;f=b[4830522]|0;g=f&65535;h=(d[9661064+(g>>>13)|0]|0)<<13|g&8191;i=c[2388530]|0;j=c[i+8208+(h>>>11<<2)>>2]|0;do{if((j|0)==0){k=c[i>>2]|0;if((k|0)==0){l=0;m=f;n=i;break}o=gj[k&4095](h)|0;l=o;m=b[4830522]|0;n=c[2388530]|0}else{l=a[j+(g&2047)|0]|0;m=f;n=i}}while(0);a[9661052]=(a[9661061]|0)+l&255;b[4830522]=m+1&65535;m=c[2415263]|0;l=(m&255|0)==255;i=a[9661065]|0;f=(i&255)<<13|m&8191;g=c[n+16+(f>>>11<<2)>>2]|0;do{if((g|0)==0){j=c[n>>2]|0;if((j|0)==0){p=0;q=i;r=m;break}h=gj[j&4095](f)|0;p=h;q=a[9661065]|0;r=c[2415263]|0}else{p=a[g+(m&2047)|0]|0;q=i;r=m}}while(0);m=p&255;p=(q&255)<<13;do{if(l){q=r+7937|0;i=q&8191|p;g=c[2388530]|0;f=c[g+16+(i>>>11<<2)>>2]|0;if((f|0)!=0){s=a[f+(q&2047)|0]|0;break}q=c[g>>2]|0;if((q|0)==0){s=0;break}s=gj[q&4095](i)|0}else{i=r+1|0;q=i&8191|p;g=c[2388530]|0;f=c[g+16+(q>>>11<<2)>>2]|0;if((f|0)!=0){s=a[f+(i&2047)|0]|0;break}i=c[g>>2]|0;if((i|0)==0){s=0;break}s=gj[i&4095](q)|0}}while(0);p=s&255;s=p<<8;r=s|m;c[2415264]=r;m=9661064+(p>>>5)|0;p=a[m]|0;if(((p&255)<<13|s&6144|0)==2088960){s=d[9661075]|0;c[2440610]=(c[2440610]|0)-s;c[2415269]=(c[2415269]|0)-s;t=a[m]|0}else{t=p}p=(t&255)<<13|r&8191;t=c[2388530]|0;m=c[t+4112+(p>>>11<<2)>>2]|0;if((m|0)!=0){a[m+(r&2047)|0]=e;return}r=c[t+4>>2]|0;if((r|0)==0){return}gg[r&4095](p,e);return}function fA3(){var b=0;b=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-b;c[2415269]=(c[2415269]|0)-b;a[9661063]=a[9661063]&-33;a[9661061]=0;return}function fA4(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;e=(d[9661075]|0)*-7|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);h=l+1&65535;b[4830522]=h;l=h&65535;e=(d[9661064+(l>>>13)|0]|0)<<13|l&8191;f=c[m+8208+(e>>>11<<2)>>2]|0;do{if((f|0)==0){i=c[m>>2]|0;if((i|0)==0){o=0;p=h;q=m;break}g=gj[i&4095](e)|0;o=g;p=b[4830522]|0;q=c[2388530]|0}else{o=a[f+(l&2047)|0]|0;p=h;q=m}}while(0);a[9661052]=o;b[4830522]=p+1&65535;p=c[2415263]|0;c[2415264]=p;o=(d[9661065]|0)<<13|p&8191;m=c[q+16+(o>>>11<<2)>>2]|0;if((m|0)!=0){r=a[m+(p&2047)|0]|0;s=a[9661063]|0;t=s&29;u=r&k;v=u<<24>>24!=0;w=v?0:2;x=r&-64;y=t|x;z=y|w;a[9661063]=z;return}p=c[q>>2]|0;if((p|0)==0){r=0;s=a[9661063]|0;t=s&29;u=r&k;v=u<<24>>24!=0;w=v?0:2;x=r&-64;y=t|x;z=y|w;a[9661063]=z;return}r=gj[p&4095](o)|0;s=a[9661063]|0;t=s&29;u=r&k;v=u<<24>>24!=0;w=v?0:2;x=r&-64;y=t|x;z=y|w;a[9661063]=z;return}function fA5(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=(d[9661075]|0)<<2;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;a[9661063]=a[9661063]&-33;e=a[9661062]|0;f=b[4830522]|0;g=f&65535;h=(d[9661064+(g>>>13)|0]|0)<<13|g&8191;i=c[2388530]|0;j=c[i+8208+(h>>>11<<2)>>2]|0;do{if((j|0)==0){k=c[i>>2]|0;if((k|0)==0){l=0;m=f;n=i;break}o=gj[k&4095](h)|0;l=o;m=b[4830522]|0;n=c[2388530]|0}else{l=a[j+(g&2047)|0]|0;m=f;n=i}}while(0);a[9661052]=l;b[4830522]=m+1&65535;m=c[2415263]|0;c[2415264]=m;l=(d[9661065]|0)<<13|m&8191;i=c[n+4112+(l>>>11<<2)>>2]|0;if((i|0)!=0){a[i+(m&2047)|0]=e;return}m=c[n+4>>2]|0;if((m|0)==0){return}gg[m&4095](l,e);return}function fA6(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=(d[9661075]|0)<<2;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;a[9661063]=a[9661063]&-33;e=a[9661060]|0;f=b[4830522]|0;g=f&65535;h=(d[9661064+(g>>>13)|0]|0)<<13|g&8191;i=c[2388530]|0;j=c[i+8208+(h>>>11<<2)>>2]|0;do{if((j|0)==0){k=c[i>>2]|0;if((k|0)==0){l=0;m=f;n=i;break}o=gj[k&4095](h)|0;l=o;m=b[4830522]|0;n=c[2388530]|0}else{l=a[j+(g&2047)|0]|0;m=f;n=i}}while(0);a[9661052]=l;b[4830522]=m+1&65535;m=c[2415263]|0;c[2415264]=m;l=(d[9661065]|0)<<13|m&8191;i=c[n+4112+(l>>>11<<2)>>2]|0;if((i|0)!=0){a[i+(m&2047)|0]=e;return}m=c[n+4>>2]|0;if((m|0)==0){return}gg[m&4095](l,e);return}function fA7(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=(d[9661075]|0)<<2;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;a[9661063]=a[9661063]&-33;e=a[9661061]|0;f=b[4830522]|0;g=f&65535;h=(d[9661064+(g>>>13)|0]|0)<<13|g&8191;i=c[2388530]|0;j=c[i+8208+(h>>>11<<2)>>2]|0;do{if((j|0)==0){k=c[i>>2]|0;if((k|0)==0){l=0;m=f;n=i;break}o=gj[k&4095](h)|0;l=o;m=b[4830522]|0;n=c[2388530]|0}else{l=a[j+(g&2047)|0]|0;m=f;n=i}}while(0);a[9661052]=l;b[4830522]=m+1&65535;m=c[2415263]|0;c[2415264]=m;l=(d[9661065]|0)<<13|m&8191;i=c[n+4112+(l>>>11<<2)>>2]|0;if((i|0)!=0){a[i+(m&2047)|0]=e;return}m=c[n+4>>2]|0;if((m|0)==0){return}gg[m&4095](l,e);return}function fA8(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=(d[9661075]|0)*-7|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=k;b[4830522]=l+1&65535;l=c[2415263]|0;c[2415264]=l;k=a[9661065]|0;h=(k&255)<<13|l&8191;e=c[m+16+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){o=0;p=k;q=l;r=m;break}i=gj[f&4095](h)|0;o=i;p=a[9661065]|0;q=c[2415264]|0;r=c[2388530]|0}else{o=a[e+(l&2047)|0]|0;p=k;q=l;r=m}}while(0);a[9661063]=a[9661063]&-33;m=o|1;o=(p&255)<<13|q&8191;p=c[r+4112+(o>>>11<<2)>>2]|0;if((p|0)!=0){a[p+(q&2047)|0]=m;return}q=c[r+4>>2]|0;if((q|0)==0){return}gg[q&4095](o,m);return}function fA9(){var b=0,e=0;b=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-b;c[2415269]=(c[2415269]|0)-b;b=a[9661063]|0;e=(a[9661062]|0)-1&255;a[9661062]=e;a[9661063]=e&-128|b&93|(e<<24>>24==0?2:0);return}function fBa(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;break}m=gj[j&4095](g)|0;k=m;l=b[4830522]|0}else{k=a[i+(f&2047)|0]|0;l=e}}while(0);b[4830522]=l+1&65535;a[9661063]=a[9661063]&29|k&-64|((a[9661060]&k)<<24>>24!=0?0:2);return}function fBb(){var b=0,e=0;b=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-b;c[2415269]=(c[2415269]|0)-b;b=a[9661063]|0;e=a[9661061]|0;a[9661060]=e;a[9661063]=e&-128|b&93|(e<<24>>24==0?2:0);return}function fBc(){var b=0;b=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-b;c[2415269]=(c[2415269]|0)-b;a[9661063]=a[9661063]&-33;return}function fBd(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=(d[9661075]|0)*-5|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);a[9661063]=a[9661063]&-33;e=a[9661062]|0;f=b[4830522]|0;g=f&65535;h=(d[9661064+(g>>>13)|0]|0)<<13|g&8191;i=c[2388530]|0;j=c[i+8208+(h>>>11<<2)>>2]|0;do{if((j|0)==0){k=c[i>>2]|0;if((k|0)==0){l=0;m=f;n=i;break}o=gj[k&4095](h)|0;l=o;m=b[4830522]|0;n=c[2388530]|0}else{l=a[j+(g&2047)|0]|0;m=f;n=i}}while(0);a[9661056]=l;l=m+1&65535;b[4830522]=l;m=l&65535;i=(d[9661064+(m>>>13)|0]|0)<<13|m&8191;f=c[n+8208+(i>>>11<<2)>>2]|0;do{if((f|0)==0){g=c[n>>2]|0;if((g|0)==0){p=0;q=l;break}j=gj[g&4095](i)|0;p=j;q=b[4830522]|0}else{p=a[f+(m&2047)|0]|0;q=l}}while(0);a[9661057]=p;b[4830522]=q+1&65535;q=c[2415264]|0;p=9661064+(q>>>13&7)|0;l=a[p]|0;if(((l&255)<<13|q&6144|0)==2088960){m=d[9661075]|0;c[2440610]=(c[2440610]|0)-m;c[2415269]=(c[2415269]|0)-m;r=a[p]|0}else{r=l}l=(r&255)<<13|q&8191;r=c[2388530]|0;p=c[r+4112+(l>>>11<<2)>>2]|0;if((p|0)!=0){a[p+(q&2047)|0]=e;return}q=c[r+4>>2]|0;if((q|0)==0){return}gg[q&4095](l,e);return}function fBe(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=(d[9661075]|0)*-5|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);a[9661063]=a[9661063]&-33;e=a[9661060]|0;f=b[4830522]|0;g=f&65535;h=(d[9661064+(g>>>13)|0]|0)<<13|g&8191;i=c[2388530]|0;j=c[i+8208+(h>>>11<<2)>>2]|0;do{if((j|0)==0){k=c[i>>2]|0;if((k|0)==0){l=0;m=f;n=i;break}o=gj[k&4095](h)|0;l=o;m=b[4830522]|0;n=c[2388530]|0}else{l=a[j+(g&2047)|0]|0;m=f;n=i}}while(0);a[9661056]=l;l=m+1&65535;b[4830522]=l;m=l&65535;i=(d[9661064+(m>>>13)|0]|0)<<13|m&8191;f=c[n+8208+(i>>>11<<2)>>2]|0;do{if((f|0)==0){g=c[n>>2]|0;if((g|0)==0){p=0;q=l;break}j=gj[g&4095](i)|0;p=j;q=b[4830522]|0}else{p=a[f+(m&2047)|0]|0;q=l}}while(0);a[9661057]=p;b[4830522]=q+1&65535;q=c[2415264]|0;p=9661064+(q>>>13&7)|0;l=a[p]|0;if(((l&255)<<13|q&6144|0)==2088960){m=d[9661075]|0;c[2440610]=(c[2440610]|0)-m;c[2415269]=(c[2415269]|0)-m;r=a[p]|0}else{r=l}l=(r&255)<<13|q&8191;r=c[2388530]|0;p=c[r+4112+(l>>>11<<2)>>2]|0;if((p|0)!=0){a[p+(q&2047)|0]=e;return}q=c[r+4>>2]|0;if((q|0)==0){return}gg[q&4095](l,e);return}function fBf(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=(d[9661075]|0)*-5|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);a[9661063]=a[9661063]&-33;e=a[9661061]|0;f=b[4830522]|0;g=f&65535;h=(d[9661064+(g>>>13)|0]|0)<<13|g&8191;i=c[2388530]|0;j=c[i+8208+(h>>>11<<2)>>2]|0;do{if((j|0)==0){k=c[i>>2]|0;if((k|0)==0){l=0;m=f;n=i;break}o=gj[k&4095](h)|0;l=o;m=b[4830522]|0;n=c[2388530]|0}else{l=a[j+(g&2047)|0]|0;m=f;n=i}}while(0);a[9661056]=l;l=m+1&65535;b[4830522]=l;m=l&65535;i=(d[9661064+(m>>>13)|0]|0)<<13|m&8191;f=c[n+8208+(i>>>11<<2)>>2]|0;do{if((f|0)==0){g=c[n>>2]|0;if((g|0)==0){p=0;q=l;break}j=gj[g&4095](i)|0;p=j;q=b[4830522]|0}else{p=a[f+(m&2047)|0]|0;q=l}}while(0);a[9661057]=p;b[4830522]=q+1&65535;q=c[2415264]|0;p=9661064+(q>>>13&7)|0;l=a[p]|0;if(((l&255)<<13|q&6144|0)==2088960){m=d[9661075]|0;c[2440610]=(c[2440610]|0)-m;c[2415269]=(c[2415269]|0)-m;r=a[p]|0}else{r=l}l=(r&255)<<13|q&8191;r=c[2388530]|0;p=c[r+4112+(l>>>11<<2)>>2]|0;if((p|0)!=0){a[p+(q&2047)|0]=e;return}q=c[r+4>>2]|0;if((q|0)==0){return}gg[q&4095](l,e);return}function fBg(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=(d[9661075]|0)<<2;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=k;k=l+1&65535;b[4830522]=k;l=c[2415263]|0;c[2415264]=l;h=(d[9661065]|0)<<13|l&8191;e=c[m+16+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){a[9661063]=a[9661063]&-33;o=k;break}else{p=gj[f&4095](h)|0;q=4828;break}}else{p=a[e+(l&2047)|0]|0;q=4828}}while(0);do{if((q|0)==4828){a[9661063]=a[9661063]&-33;if((p&1)==0){o=b[4830522]|0;break}l=(d[9661075]|0)<<2;c[2440610]=(c[2440610]|0)-l;c[2415269]=(c[2415269]|0)-l;l=b[4830522]|0;e=l&65535;h=(d[9661064+(e>>>13)|0]|0)<<13|e&8191;k=c[2388530]|0;m=c[k+8208+(h>>>11<<2)>>2]|0;do{if((m|0)==0){f=c[k>>2]|0;if((f|0)==0){r=0;s=l;break}i=gj[f&4095](h)|0;r=i;s=b[4830522]|0}else{r=a[m+(e&2047)|0]|0;s=l}}while(0);b[4830528]=(s+1&65535)+(r<<24>>24)&65535;c[2415261]=c[2415264];return}}while(0);b[4830522]=o+1&65535;o=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-o;c[2415269]=(c[2415269]|0)-o;return}function fBh(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=a[9661063]|0;a[9661063]=e&-33;if((e&1)!=0){b[4830522]=(b[4830522]|0)+1&65535;e=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;return}e=(d[9661075]|0)<<2;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;break}m=gj[j&4095](g)|0;k=m;l=b[4830522]|0}else{k=a[i+(f&2047)|0]|0;l=e}}while(0);b[4830528]=(l+1&65535)+(k<<24>>24)&65535;c[2415261]=c[2415264];return}function fBi(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=(d[9661075]|0)*-7|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);a[9661063]=a[9661063]&-33;e=a[9661060]|0;f=b[4830522]|0;g=f&65535;h=(d[9661064+(g>>>13)|0]|0)<<13|g&8191;i=c[2388530]|0;j=c[i+8208+(h>>>11<<2)>>2]|0;do{if((j|0)==0){k=c[i>>2]|0;if((k|0)==0){l=0;m=f;n=i;break}o=gj[k&4095](h)|0;l=o;m=b[4830522]|0;n=c[2388530]|0}else{l=a[j+(g&2047)|0]|0;m=f;n=i}}while(0);a[9661052]=l;b[4830522]=m+1&65535;m=c[2415263]|0;l=(m&255|0)==255;i=a[9661065]|0;f=(i&255)<<13|m&8191;g=c[n+16+(f>>>11<<2)>>2]|0;do{if((g|0)==0){j=c[n>>2]|0;if((j|0)==0){p=0;q=i;r=m;break}h=gj[j&4095](f)|0;p=h;q=a[9661065]|0;r=c[2415263]|0}else{p=a[g+(m&2047)|0]|0;q=i;r=m}}while(0);m=p&255;p=(q&255)<<13;do{if(l){q=r+7937|0;i=q&8191|p;g=c[2388530]|0;f=c[g+16+(i>>>11<<2)>>2]|0;if((f|0)!=0){s=a[f+(q&2047)|0]|0;break}q=c[g>>2]|0;if((q|0)==0){s=0;break}s=gj[q&4095](i)|0}else{i=r+1|0;q=i&8191|p;g=c[2388530]|0;f=c[g+16+(q>>>11<<2)>>2]|0;if((f|0)!=0){s=a[f+(i&2047)|0]|0;break}i=c[g>>2]|0;if((i|0)==0){s=0;break}s=gj[i&4095](q)|0}}while(0);p=(s&255)<<8|m;c[2415264]=p;b[4830528]=(p&65535)+(d[9661062]|0)&65535;p=c[2415264]|0;m=9661064+(p>>>13&7)|0;s=a[m]|0;if(((s&255)<<13|p&6144|0)==2088960){r=d[9661075]|0;c[2440610]=(c[2440610]|0)-r;c[2415269]=(c[2415269]|0)-r;t=a[m]|0}else{t=s}s=(t&255)<<13|p&8191;t=c[2388530]|0;m=c[t+4112+(s>>>11<<2)>>2]|0;if((m|0)!=0){a[m+(p&2047)|0]=e;return}p=c[t+4>>2]|0;if((p|0)==0){return}gg[p&4095](s,e);return}function fBj(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=(d[9661075]|0)*-7|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);a[9661063]=a[9661063]&-33;e=a[9661060]|0;f=b[4830522]|0;g=f&65535;h=(d[9661064+(g>>>13)|0]|0)<<13|g&8191;i=c[2388530]|0;j=c[i+8208+(h>>>11<<2)>>2]|0;do{if((j|0)==0){k=c[i>>2]|0;if((k|0)==0){l=0;m=f;n=i;break}o=gj[k&4095](h)|0;l=o;m=b[4830522]|0;n=c[2388530]|0}else{l=a[j+(g&2047)|0]|0;m=f;n=i}}while(0);a[9661052]=l;b[4830522]=m+1&65535;m=c[2415263]|0;l=(m&255|0)==255;i=a[9661065]|0;f=(i&255)<<13|m&8191;g=c[n+16+(f>>>11<<2)>>2]|0;do{if((g|0)==0){j=c[n>>2]|0;if((j|0)==0){p=0;q=i;r=m;break}h=gj[j&4095](f)|0;p=h;q=a[9661065]|0;r=c[2415263]|0}else{p=a[g+(m&2047)|0]|0;q=i;r=m}}while(0);m=p&255;p=(q&255)<<13;do{if(l){q=r+7937|0;i=q&8191|p;g=c[2388530]|0;f=c[g+16+(i>>>11<<2)>>2]|0;if((f|0)!=0){s=a[f+(q&2047)|0]|0;break}q=c[g>>2]|0;if((q|0)==0){s=0;break}s=gj[q&4095](i)|0}else{i=r+1|0;q=i&8191|p;g=c[2388530]|0;f=c[g+16+(q>>>11<<2)>>2]|0;if((f|0)!=0){s=a[f+(i&2047)|0]|0;break}i=c[g>>2]|0;if((i|0)==0){s=0;break}s=gj[i&4095](q)|0}}while(0);p=s&255;s=p<<8;r=s|m;c[2415264]=r;m=9661064+(p>>>5)|0;p=a[m]|0;if(((p&255)<<13|s&6144|0)==2088960){s=d[9661075]|0;c[2440610]=(c[2440610]|0)-s;c[2415269]=(c[2415269]|0)-s;t=a[m]|0}else{t=p}p=(t&255)<<13|r&8191;t=c[2388530]|0;m=c[t+4112+(p>>>11<<2)>>2]|0;if((m|0)!=0){a[m+(r&2047)|0]=e;return}r=c[t+4>>2]|0;if((r|0)==0){return}gg[r&4095](p,e);return}function fBk(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;e=(d[9661075]|0)<<3;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);h=l+1&65535;b[4830522]=h;l=h&65535;e=(d[9661064+(l>>>13)|0]|0)<<13|l&8191;f=c[m+8208+(e>>>11<<2)>>2]|0;do{if((f|0)==0){i=c[m>>2]|0;if((i|0)==0){o=0;p=h;q=m;break}g=gj[i&4095](e)|0;o=g;p=b[4830522]|0;q=c[2388530]|0}else{o=a[f+(l&2047)|0]|0;p=h;q=m}}while(0);a[9661056]=o;o=p+1&65535;b[4830522]=o;p=o&65535;m=(d[9661064+(p>>>13)|0]|0)<<13|p&8191;h=c[q+8208+(m>>>11<<2)>>2]|0;do{if((h|0)==0){l=c[q>>2]|0;if((l|0)==0){r=0;s=o;break}f=gj[l&4095](m)|0;r=f;s=b[4830522]|0}else{r=a[h+(p&2047)|0]|0;s=o}}while(0);a[9661057]=r;b[4830522]=s+1&65535;s=c[2415264]|0;r=9661064+(s>>>13&7)|0;o=a[r]|0;if(((o&255)<<13|s&6144|0)==2088960){p=d[9661075]|0;c[2440610]=(c[2440610]|0)-p;c[2415269]=(c[2415269]|0)-p;t=a[r]|0}else{t=o}o=(t&255)<<13|s&8191;t=c[2388530]|0;r=c[t+16+(o>>>11<<2)>>2]|0;if((r|0)!=0){u=a[r+(s&2047)|0]|0;v=a[9661063]|0;w=v&29;x=u&k;y=x<<24>>24!=0;z=y?0:2;A=u&-64;B=w|A;C=B|z;a[9661063]=C;return}s=c[t>>2]|0;if((s|0)==0){u=0;v=a[9661063]|0;w=v&29;x=u&k;y=x<<24>>24!=0;z=y?0:2;A=u&-64;B=w|A;C=B|z;a[9661063]=C;return}u=gj[s&4095](o)|0;v=a[9661063]|0;w=v&29;x=u&k;y=x<<24>>24!=0;z=y?0:2;A=u&-64;B=w|A;C=B|z;a[9661063]=C;return}function fBl(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=(d[9661075]|0)<<2;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;a[9661063]=a[9661063]&-33;e=a[9661062]|0;f=b[4830522]|0;g=f&65535;h=(d[9661064+(g>>>13)|0]|0)<<13|g&8191;i=c[2388530]|0;j=c[i+8208+(h>>>11<<2)>>2]|0;do{if((j|0)==0){k=c[i>>2]|0;if((k|0)==0){l=0;m=f;n=i;break}o=gj[k&4095](h)|0;l=o;m=b[4830522]|0;n=c[2388530]|0}else{l=a[j+(g&2047)|0]|0;m=f;n=i}}while(0);a[9661052]=(a[9661061]|0)+l&255;b[4830522]=m+1&65535;m=c[2415263]|0;c[2415264]=m;l=(d[9661065]|0)<<13|m&8191;i=c[n+4112+(l>>>11<<2)>>2]|0;if((i|0)!=0){a[i+(m&2047)|0]=e;return}m=c[n+4>>2]|0;if((m|0)==0){return}gg[m&4095](l,e);return}function fBm(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=(d[9661075]|0)<<2;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;a[9661063]=a[9661063]&-33;e=a[9661060]|0;f=b[4830522]|0;g=f&65535;h=(d[9661064+(g>>>13)|0]|0)<<13|g&8191;i=c[2388530]|0;j=c[i+8208+(h>>>11<<2)>>2]|0;do{if((j|0)==0){k=c[i>>2]|0;if((k|0)==0){l=0;m=f;n=i;break}o=gj[k&4095](h)|0;l=o;m=b[4830522]|0;n=c[2388530]|0}else{l=a[j+(g&2047)|0]|0;m=f;n=i}}while(0);a[9661052]=(a[9661061]|0)+l&255;b[4830522]=m+1&65535;m=c[2415263]|0;c[2415264]=m;l=(d[9661065]|0)<<13|m&8191;i=c[n+4112+(l>>>11<<2)>>2]|0;if((i|0)!=0){a[i+(m&2047)|0]=e;return}m=c[n+4>>2]|0;if((m|0)==0){return}gg[m&4095](l,e);return}function fBn(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=(d[9661075]|0)<<2;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;a[9661063]=a[9661063]&-33;e=a[9661061]|0;f=b[4830522]|0;g=f&65535;h=(d[9661064+(g>>>13)|0]|0)<<13|g&8191;i=c[2388530]|0;j=c[i+8208+(h>>>11<<2)>>2]|0;do{if((j|0)==0){k=c[i>>2]|0;if((k|0)==0){l=0;m=f;n=i;break}o=gj[k&4095](h)|0;l=o;m=b[4830522]|0;n=c[2388530]|0}else{l=a[j+(g&2047)|0]|0;m=f;n=i}}while(0);a[9661052]=(a[9661062]|0)+l&255;b[4830522]=m+1&65535;m=c[2415263]|0;c[2415264]=m;l=(d[9661065]|0)<<13|m&8191;i=c[n+4112+(l>>>11<<2)>>2]|0;if((i|0)!=0){a[i+(m&2047)|0]=e;return}m=c[n+4>>2]|0;if((m|0)==0){return}gg[m&4095](l,e);return}function fBo(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=(d[9661075]|0)*-7|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=k;b[4830522]=l+1&65535;l=c[2415263]|0;c[2415264]=l;k=a[9661065]|0;h=(k&255)<<13|l&8191;e=c[m+16+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){o=0;p=k;q=l;r=m;break}i=gj[f&4095](h)|0;o=i;p=a[9661065]|0;q=c[2415264]|0;r=c[2388530]|0}else{o=a[e+(l&2047)|0]|0;p=k;q=l;r=m}}while(0);a[9661063]=a[9661063]&-33;m=o|2;o=(p&255)<<13|q&8191;p=c[r+4112+(o>>>11<<2)>>2]|0;if((p|0)!=0){a[p+(q&2047)|0]=m;return}q=c[r+4>>2]|0;if((q|0)==0){return}gg[q&4095](o,m);return}function fBp(){var b=0,e=0;b=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-b;c[2415269]=(c[2415269]|0)-b;b=a[9661063]|0;e=a[9661062]|0;a[9661060]=e;a[9661063]=e&-128|b&93|(e<<24>>24==0?2:0);return}function fBq(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=(d[9661075]|0)*-5|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);a[9661063]=a[9661063]&-33;e=a[9661060]|0;f=b[4830522]|0;g=f&65535;h=(d[9661064+(g>>>13)|0]|0)<<13|g&8191;i=c[2388530]|0;j=c[i+8208+(h>>>11<<2)>>2]|0;do{if((j|0)==0){k=c[i>>2]|0;if((k|0)==0){l=0;m=f;n=i;break}o=gj[k&4095](h)|0;l=o;m=b[4830522]|0;n=c[2388530]|0}else{l=a[j+(g&2047)|0]|0;m=f;n=i}}while(0);a[9661056]=l;l=m+1&65535;b[4830522]=l;m=l&65535;i=(d[9661064+(m>>>13)|0]|0)<<13|m&8191;f=c[n+8208+(i>>>11<<2)>>2]|0;do{if((f|0)==0){g=c[n>>2]|0;if((g|0)==0){p=0;q=l;break}j=gj[g&4095](i)|0;p=j;q=b[4830522]|0}else{p=a[f+(m&2047)|0]|0;q=l}}while(0);a[9661057]=p;b[4830522]=q+1&65535;b[4830528]=(b[4830528]|0)+(d[9661062]|0)&65535;q=c[2415264]|0;p=9661064+(q>>>13&7)|0;l=a[p]|0;if(((l&255)<<13|q&6144|0)==2088960){m=d[9661075]|0;c[2440610]=(c[2440610]|0)-m;c[2415269]=(c[2415269]|0)-m;r=a[p]|0}else{r=l}l=(r&255)<<13|q&8191;r=c[2388530]|0;p=c[r+4112+(l>>>11<<2)>>2]|0;if((p|0)!=0){a[p+(q&2047)|0]=e;return}q=c[r+4>>2]|0;if((q|0)==0){return}gg[q&4095](l,e);return}function fBr(){var b=0;b=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-b;c[2415269]=(c[2415269]|0)-b;a[9661063]=a[9661063]&-33;a[9661048]=a[9661061]|0;return}function fBs(){var b=0;b=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-b;c[2415269]=(c[2415269]|0)-b;a[9661063]=a[9661063]&-33;return}function fBt(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=(d[9661075]|0)*-5|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);a[9661063]=a[9661063]&-33;e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661056]=k;k=l+1&65535;b[4830522]=k;l=k&65535;h=(d[9661064+(l>>>13)|0]|0)<<13|l&8191;e=c[m+8208+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){o=0;p=k;break}i=gj[f&4095](h)|0;o=i;p=b[4830522]|0}else{o=a[e+(l&2047)|0]|0;p=k}}while(0);a[9661057]=o;b[4830522]=p+1&65535;p=c[2415264]|0;o=9661064+(p>>>13&7)|0;k=a[o]|0;if(((k&255)<<13|p&6144|0)==2088960){l=d[9661075]|0;c[2440610]=(c[2440610]|0)-l;c[2415269]=(c[2415269]|0)-l;q=a[o]|0}else{q=k}k=(q&255)<<13|p&8191;q=c[2388530]|0;o=c[q+4112+(k>>>11<<2)>>2]|0;if((o|0)!=0){a[o+(p&2047)|0]=0;return}p=c[q+4>>2]|0;if((p|0)==0){return}gg[p&4095](k,0);return}function fBu(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=(d[9661075]|0)*-5|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);a[9661063]=a[9661063]&-33;e=a[9661060]|0;f=b[4830522]|0;g=f&65535;h=(d[9661064+(g>>>13)|0]|0)<<13|g&8191;i=c[2388530]|0;j=c[i+8208+(h>>>11<<2)>>2]|0;do{if((j|0)==0){k=c[i>>2]|0;if((k|0)==0){l=0;m=f;n=i;break}o=gj[k&4095](h)|0;l=o;m=b[4830522]|0;n=c[2388530]|0}else{l=a[j+(g&2047)|0]|0;m=f;n=i}}while(0);a[9661056]=l;l=m+1&65535;b[4830522]=l;m=l&65535;i=(d[9661064+(m>>>13)|0]|0)<<13|m&8191;f=c[n+8208+(i>>>11<<2)>>2]|0;do{if((f|0)==0){g=c[n>>2]|0;if((g|0)==0){p=0;q=l;break}j=gj[g&4095](i)|0;p=j;q=b[4830522]|0}else{p=a[f+(m&2047)|0]|0;q=l}}while(0);a[9661057]=p;b[4830522]=q+1&65535;b[4830528]=(b[4830528]|0)+(d[9661061]|0)&65535;q=c[2415264]|0;p=9661064+(q>>>13&7)|0;l=a[p]|0;if(((l&255)<<13|q&6144|0)==2088960){m=d[9661075]|0;c[2440610]=(c[2440610]|0)-m;c[2415269]=(c[2415269]|0)-m;r=a[p]|0}else{r=l}l=(r&255)<<13|q&8191;r=c[2388530]|0;p=c[r+4112+(l>>>11<<2)>>2]|0;if((p|0)!=0){a[p+(q&2047)|0]=e;return}q=c[r+4>>2]|0;if((q|0)==0){return}gg[q&4095](l,e);return}function fBv(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=(d[9661075]|0)*-5|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);a[9661063]=a[9661063]&-33;e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661056]=k;k=l+1&65535;b[4830522]=k;l=k&65535;h=(d[9661064+(l>>>13)|0]|0)<<13|l&8191;e=c[m+8208+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){o=0;p=k;break}i=gj[f&4095](h)|0;o=i;p=b[4830522]|0}else{o=a[e+(l&2047)|0]|0;p=k}}while(0);a[9661057]=o;b[4830522]=p+1&65535;b[4830528]=(b[4830528]|0)+(d[9661061]|0)&65535;p=c[2415264]|0;o=9661064+(p>>>13&7)|0;k=a[o]|0;if(((k&255)<<13|p&6144|0)==2088960){l=d[9661075]|0;c[2440610]=(c[2440610]|0)-l;c[2415269]=(c[2415269]|0)-l;q=a[o]|0}else{q=k}k=(q&255)<<13|p&8191;q=c[2388530]|0;o=c[q+4112+(k>>>11<<2)>>2]|0;if((o|0)!=0){a[o+(p&2047)|0]=0;return}p=c[q+4>>2]|0;if((p|0)==0){return}gg[p&4095](k,0);return}function fBw(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=(d[9661075]|0)<<2;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=k;k=l+1&65535;b[4830522]=k;l=c[2415263]|0;c[2415264]=l;h=(d[9661065]|0)<<13|l&8191;e=c[m+16+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){a[9661063]=a[9661063]&-33;o=k;break}else{p=gj[f&4095](h)|0;q=5061;break}}else{p=a[e+(l&2047)|0]|0;q=5061}}while(0);do{if((q|0)==5061){a[9661063]=a[9661063]&-33;if((p&2)==0){o=b[4830522]|0;break}l=(d[9661075]|0)<<2;c[2440610]=(c[2440610]|0)-l;c[2415269]=(c[2415269]|0)-l;l=b[4830522]|0;e=l&65535;h=(d[9661064+(e>>>13)|0]|0)<<13|e&8191;k=c[2388530]|0;m=c[k+8208+(h>>>11<<2)>>2]|0;do{if((m|0)==0){f=c[k>>2]|0;if((f|0)==0){r=0;s=l;break}i=gj[f&4095](h)|0;r=i;s=b[4830522]|0}else{r=a[m+(e&2047)|0]|0;s=l}}while(0);b[4830528]=(s+1&65535)+(r<<24>>24)&65535;c[2415261]=c[2415264];return}}while(0);b[4830522]=o+1&65535;o=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-o;c[2415269]=(c[2415269]|0)-o;return}function fBx(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;break}m=gj[j&4095](g)|0;k=m;l=b[4830522]|0}else{k=a[i+(f&2047)|0]|0;l=e}}while(0);b[4830522]=l+1&65535;l=a[9661063]|0;a[9661062]=k;a[9661063]=(k<<24>>24==0?2:0)|k&-128|l&93;return}function fBy(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;e=(d[9661075]|0)*-7|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=(a[9661061]|0)+k&255;b[4830522]=l+1&65535;l=c[2415263]|0;k=(l&255|0)==255;h=a[9661065]|0;e=(h&255)<<13|l&8191;f=c[m+16+(e>>>11<<2)>>2]|0;do{if((f|0)==0){i=c[m>>2]|0;if((i|0)==0){o=0;p=h;q=l;break}g=gj[i&4095](e)|0;o=g;p=a[9661065]|0;q=c[2415263]|0}else{o=a[f+(l&2047)|0]|0;p=h;q=l}}while(0);l=o&255;o=(p&255)<<13;do{if(k){p=q+7937|0;h=p&8191|o;f=c[2388530]|0;e=c[f+16+(h>>>11<<2)>>2]|0;if((e|0)!=0){r=a[e+(p&2047)|0]|0;break}p=c[f>>2]|0;if((p|0)==0){r=0;break}r=gj[p&4095](h)|0}else{h=q+1|0;p=h&8191|o;f=c[2388530]|0;e=c[f+16+(p>>>11<<2)>>2]|0;if((e|0)!=0){r=a[e+(h&2047)|0]|0;break}h=c[f>>2]|0;if((h|0)==0){r=0;break}r=gj[h&4095](p)|0}}while(0);o=r&255;r=o<<8;q=r|l;c[2415264]=q;l=9661064+(o>>>5)|0;o=a[l]|0;if(((o&255)<<13|r&6144|0)==2088960){r=d[9661075]|0;c[2440610]=(c[2440610]|0)-r;c[2415269]=(c[2415269]|0)-r;s=a[l]|0}else{s=o}o=(s&255)<<13|q&8191;s=c[2388530]|0;l=c[s+16+(o>>>11<<2)>>2]|0;if((l|0)!=0){t=a[l+(q&2047)|0]|0;u=a[9661063]|0;a[9661060]=t;v=u&93;w=t&-128;x=t<<24>>24==0;y=x?2:0;z=y|w;A=z|v;a[9661063]=A;return}q=c[s>>2]|0;if((q|0)==0){t=0;u=a[9661063]|0;a[9661060]=t;v=u&93;w=t&-128;x=t<<24>>24==0;y=x?2:0;z=y|w;A=z|v;a[9661063]=A;return}t=gj[q&4095](o)|0;u=a[9661063]|0;a[9661060]=t;v=u&93;w=t&-128;x=t<<24>>24==0;y=x?2:0;z=y|w;A=z|v;a[9661063]=A;return}function fBz(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;break}m=gj[j&4095](g)|0;k=m;l=b[4830522]|0}else{k=a[i+(f&2047)|0]|0;l=e}}while(0);b[4830522]=l+1&65535;l=a[9661063]|0;a[9661061]=k;a[9661063]=(k<<24>>24==0?2:0)|k&-128|l&93;return}function fBA(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;e=(d[9661075]|0)*-7|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);h=l+1&65535;b[4830522]=h;l=h&65535;e=(d[9661064+(l>>>13)|0]|0)<<13|l&8191;f=c[m+8208+(e>>>11<<2)>>2]|0;do{if((f|0)==0){i=c[m>>2]|0;if((i|0)==0){o=0;p=h;q=m;break}g=gj[i&4095](e)|0;o=g;p=b[4830522]|0;q=c[2388530]|0}else{o=a[f+(l&2047)|0]|0;p=h;q=m}}while(0);a[9661052]=(a[9661061]|0)+o&255;b[4830522]=p+1&65535;p=c[2415263]|0;c[2415264]=p;o=(d[9661065]|0)<<13|p&8191;m=c[q+16+(o>>>11<<2)>>2]|0;if((m|0)!=0){r=a[m+(p&2047)|0]|0;s=a[9661063]|0;t=s&29;u=r&k;v=u<<24>>24!=0;w=v?0:2;x=r&-64;y=t|x;z=y|w;a[9661063]=z;return}p=c[q>>2]|0;if((p|0)==0){r=0;s=a[9661063]|0;t=s&29;u=r&k;v=u<<24>>24!=0;w=v?0:2;x=r&-64;y=t|x;z=y|w;a[9661063]=z;return}r=gj[p&4095](o)|0;s=a[9661063]|0;t=s&29;u=r&k;v=u<<24>>24!=0;w=v?0:2;x=r&-64;y=t|x;z=y|w;a[9661063]=z;return}function fBB(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=(d[9661075]|0)<<2;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=k;b[4830522]=l+1&65535;l=c[2415263]|0;c[2415264]=l;k=(d[9661065]|0)<<13|l&8191;h=c[m+16+(k>>>11<<2)>>2]|0;do{if((h|0)==0){e=c[m>>2]|0;if((e|0)==0){o=0;break}o=gj[e&4095](k)|0}else{o=a[h+(l&2047)|0]|0}}while(0);l=a[9661063]|0;a[9661062]=o;a[9661063]=(o<<24>>24==0?2:0)|o&-128|l&93;return}function fBC(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=(d[9661075]|0)<<2;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=k;b[4830522]=l+1&65535;l=c[2415263]|0;c[2415264]=l;k=(d[9661065]|0)<<13|l&8191;h=c[m+16+(k>>>11<<2)>>2]|0;do{if((h|0)==0){e=c[m>>2]|0;if((e|0)==0){o=0;break}o=gj[e&4095](k)|0}else{o=a[h+(l&2047)|0]|0}}while(0);l=a[9661063]|0;a[9661060]=o;a[9661063]=(o<<24>>24==0?2:0)|o&-128|l&93;return}function fBD(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=(d[9661075]|0)<<2;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=k;b[4830522]=l+1&65535;l=c[2415263]|0;c[2415264]=l;k=(d[9661065]|0)<<13|l&8191;h=c[m+16+(k>>>11<<2)>>2]|0;do{if((h|0)==0){e=c[m>>2]|0;if((e|0)==0){o=0;break}o=gj[e&4095](k)|0}else{o=a[h+(l&2047)|0]|0}}while(0);l=a[9661063]|0;a[9661061]=o;a[9661063]=(o<<24>>24==0?2:0)|o&-128|l&93;return}function fBE(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=(d[9661075]|0)*-7|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=k;b[4830522]=l+1&65535;l=c[2415263]|0;c[2415264]=l;k=a[9661065]|0;h=(k&255)<<13|l&8191;e=c[m+16+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){o=0;p=k;q=l;r=m;break}i=gj[f&4095](h)|0;o=i;p=a[9661065]|0;q=c[2415264]|0;r=c[2388530]|0}else{o=a[e+(l&2047)|0]|0;p=k;q=l;r=m}}while(0);a[9661063]=a[9661063]&-33;m=o|4;o=(p&255)<<13|q&8191;p=c[r+4112+(o>>>11<<2)>>2]|0;if((p|0)!=0){a[p+(q&2047)|0]=m;return}q=c[r+4>>2]|0;if((q|0)==0){return}gg[q&4095](o,m);return}function fBF(){var b=0,e=0;b=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-b;c[2415269]=(c[2415269]|0)-b;b=a[9661063]|0;e=a[9661060]|0;a[9661062]=e;a[9661063]=e&-128|b&93|(e<<24>>24==0?2:0);return}function fBG(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;break}m=gj[j&4095](g)|0;k=m;l=b[4830522]|0}else{k=a[i+(f&2047)|0]|0;l=e}}while(0);b[4830522]=l+1&65535;l=a[9661063]|0;a[9661060]=k;a[9661063]=(k<<24>>24==0?2:0)|k&-128|l&93;return}function fBH(){var b=0,e=0;b=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-b;c[2415269]=(c[2415269]|0)-b;b=a[9661063]|0;e=a[9661060]|0;a[9661061]=e;a[9661063]=e&-128|b&93|(e<<24>>24==0?2:0);return}function fBI(){var b=0;b=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-b;c[2415269]=(c[2415269]|0)-b;a[9661063]=a[9661063]&-33;return}function fBJ(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;e=(d[9661075]|0)*-5|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661056]=k;k=l+1&65535;b[4830522]=k;l=k&65535;h=(d[9661064+(l>>>13)|0]|0)<<13|l&8191;e=c[m+8208+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){o=0;p=k;break}i=gj[f&4095](h)|0;o=i;p=b[4830522]|0}else{o=a[e+(l&2047)|0]|0;p=k}}while(0);a[9661057]=o;b[4830522]=p+1&65535;p=c[2415264]|0;o=9661064+(p>>>13&7)|0;k=a[o]|0;if(((k&255)<<13|p&6144|0)==2088960){l=d[9661075]|0;c[2440610]=(c[2440610]|0)-l;c[2415269]=(c[2415269]|0)-l;q=a[o]|0}else{q=k}k=(q&255)<<13|p&8191;q=c[2388530]|0;o=c[q+16+(k>>>11<<2)>>2]|0;if((o|0)!=0){r=a[o+(p&2047)|0]|0;s=a[9661063]|0;a[9661062]=r;t=s&93;u=r&-128;v=r<<24>>24==0;w=v?2:0;x=w|u;y=x|t;a[9661063]=y;return}p=c[q>>2]|0;if((p|0)==0){r=0;s=a[9661063]|0;a[9661062]=r;t=s&93;u=r&-128;v=r<<24>>24==0;w=v?2:0;x=w|u;y=x|t;a[9661063]=y;return}r=gj[p&4095](k)|0;s=a[9661063]|0;a[9661062]=r;t=s&93;u=r&-128;v=r<<24>>24==0;w=v?2:0;x=w|u;y=x|t;a[9661063]=y;return}function fBK(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;e=(d[9661075]|0)*-5|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661056]=k;k=l+1&65535;b[4830522]=k;l=k&65535;h=(d[9661064+(l>>>13)|0]|0)<<13|l&8191;e=c[m+8208+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){o=0;p=k;break}i=gj[f&4095](h)|0;o=i;p=b[4830522]|0}else{o=a[e+(l&2047)|0]|0;p=k}}while(0);a[9661057]=o;b[4830522]=p+1&65535;p=c[2415264]|0;o=9661064+(p>>>13&7)|0;k=a[o]|0;if(((k&255)<<13|p&6144|0)==2088960){l=d[9661075]|0;c[2440610]=(c[2440610]|0)-l;c[2415269]=(c[2415269]|0)-l;q=a[o]|0}else{q=k}k=(q&255)<<13|p&8191;q=c[2388530]|0;o=c[q+16+(k>>>11<<2)>>2]|0;if((o|0)!=0){r=a[o+(p&2047)|0]|0;s=a[9661063]|0;a[9661060]=r;t=s&93;u=r&-128;v=r<<24>>24==0;w=v?2:0;x=w|u;y=x|t;a[9661063]=y;return}p=c[q>>2]|0;if((p|0)==0){r=0;s=a[9661063]|0;a[9661060]=r;t=s&93;u=r&-128;v=r<<24>>24==0;w=v?2:0;x=w|u;y=x|t;a[9661063]=y;return}r=gj[p&4095](k)|0;s=a[9661063]|0;a[9661060]=r;t=s&93;u=r&-128;v=r<<24>>24==0;w=v?2:0;x=w|u;y=x|t;a[9661063]=y;return}function fBL(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;e=(d[9661075]|0)*-5|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661056]=k;k=l+1&65535;b[4830522]=k;l=k&65535;h=(d[9661064+(l>>>13)|0]|0)<<13|l&8191;e=c[m+8208+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){o=0;p=k;break}i=gj[f&4095](h)|0;o=i;p=b[4830522]|0}else{o=a[e+(l&2047)|0]|0;p=k}}while(0);a[9661057]=o;b[4830522]=p+1&65535;p=c[2415264]|0;o=9661064+(p>>>13&7)|0;k=a[o]|0;if(((k&255)<<13|p&6144|0)==2088960){l=d[9661075]|0;c[2440610]=(c[2440610]|0)-l;c[2415269]=(c[2415269]|0)-l;q=a[o]|0}else{q=k}k=(q&255)<<13|p&8191;q=c[2388530]|0;o=c[q+16+(k>>>11<<2)>>2]|0;if((o|0)!=0){r=a[o+(p&2047)|0]|0;s=a[9661063]|0;a[9661061]=r;t=s&93;u=r&-128;v=r<<24>>24==0;w=v?2:0;x=w|u;y=x|t;a[9661063]=y;return}p=c[q>>2]|0;if((p|0)==0){r=0;s=a[9661063]|0;a[9661061]=r;t=s&93;u=r&-128;v=r<<24>>24==0;w=v?2:0;x=w|u;y=x|t;a[9661063]=y;return}r=gj[p&4095](k)|0;s=a[9661063]|0;a[9661061]=r;t=s&93;u=r&-128;v=r<<24>>24==0;w=v?2:0;x=w|u;y=x|t;a[9661063]=y;return}function fBM(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=(d[9661075]|0)<<2;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=k;k=l+1&65535;b[4830522]=k;l=c[2415263]|0;c[2415264]=l;h=(d[9661065]|0)<<13|l&8191;e=c[m+16+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){a[9661063]=a[9661063]&-33;o=k;break}else{p=gj[f&4095](h)|0;q=5239;break}}else{p=a[e+(l&2047)|0]|0;q=5239}}while(0);do{if((q|0)==5239){a[9661063]=a[9661063]&-33;if((p&4)==0){o=b[4830522]|0;break}l=(d[9661075]|0)<<2;c[2440610]=(c[2440610]|0)-l;c[2415269]=(c[2415269]|0)-l;l=b[4830522]|0;e=l&65535;h=(d[9661064+(e>>>13)|0]|0)<<13|e&8191;k=c[2388530]|0;m=c[k+8208+(h>>>11<<2)>>2]|0;do{if((m|0)==0){f=c[k>>2]|0;if((f|0)==0){r=0;s=l;break}i=gj[f&4095](h)|0;r=i;s=b[4830522]|0}else{r=a[m+(e&2047)|0]|0;s=l}}while(0);b[4830528]=(s+1&65535)+(r<<24>>24)&65535;c[2415261]=c[2415264];return}}while(0);b[4830522]=o+1&65535;o=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-o;c[2415269]=(c[2415269]|0)-o;return}function fBN(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=a[9661063]|0;a[9661063]=e&-33;if((e&1)==0){b[4830522]=(b[4830522]|0)+1&65535;e=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;return}e=(d[9661075]|0)<<2;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;break}m=gj[j&4095](g)|0;k=m;l=b[4830522]|0}else{k=a[i+(f&2047)|0]|0;l=e}}while(0);b[4830528]=(l+1&65535)+(k<<24>>24)&65535;c[2415261]=c[2415264];return}function fBO(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;e=(d[9661075]|0)*-7|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=k;b[4830522]=l+1&65535;l=c[2415263]|0;k=(l&255|0)==255;h=a[9661065]|0;e=(h&255)<<13|l&8191;f=c[m+16+(e>>>11<<2)>>2]|0;do{if((f|0)==0){i=c[m>>2]|0;if((i|0)==0){o=0;p=h;q=l;break}g=gj[i&4095](e)|0;o=g;p=a[9661065]|0;q=c[2415263]|0}else{o=a[f+(l&2047)|0]|0;p=h;q=l}}while(0);l=o&255;o=(p&255)<<13;do{if(k){p=q+7937|0;h=p&8191|o;f=c[2388530]|0;e=c[f+16+(h>>>11<<2)>>2]|0;if((e|0)!=0){r=a[e+(p&2047)|0]|0;break}p=c[f>>2]|0;if((p|0)==0){r=0;break}r=gj[p&4095](h)|0}else{h=q+1|0;p=h&8191|o;f=c[2388530]|0;e=c[f+16+(p>>>11<<2)>>2]|0;if((e|0)!=0){r=a[e+(h&2047)|0]|0;break}h=c[f>>2]|0;if((h|0)==0){r=0;break}r=gj[h&4095](p)|0}}while(0);o=(r&255)<<8|l;c[2415264]=o;b[4830528]=(o&65535)+(d[9661062]|0)&65535;o=c[2415264]|0;l=9661064+(o>>>13&7)|0;r=a[l]|0;if(((r&255)<<13|o&6144|0)==2088960){q=d[9661075]|0;c[2440610]=(c[2440610]|0)-q;c[2415269]=(c[2415269]|0)-q;s=a[l]|0}else{s=r}r=(s&255)<<13|o&8191;s=c[2388530]|0;l=c[s+16+(r>>>11<<2)>>2]|0;if((l|0)!=0){t=a[l+(o&2047)|0]|0;u=a[9661063]|0;a[9661060]=t;v=u&93;w=t&-128;x=t<<24>>24==0;y=x?2:0;z=y|w;A=z|v;a[9661063]=A;return}o=c[s>>2]|0;if((o|0)==0){t=0;u=a[9661063]|0;a[9661060]=t;v=u&93;w=t&-128;x=t<<24>>24==0;y=x?2:0;z=y|w;A=z|v;a[9661063]=A;return}t=gj[o&4095](r)|0;u=a[9661063]|0;a[9661060]=t;v=u&93;w=t&-128;x=t<<24>>24==0;y=x?2:0;z=y|w;A=z|v;a[9661063]=A;return}function fBP(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;e=(d[9661075]|0)*-7|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=k;b[4830522]=l+1&65535;l=c[2415263]|0;k=(l&255|0)==255;h=a[9661065]|0;e=(h&255)<<13|l&8191;f=c[m+16+(e>>>11<<2)>>2]|0;do{if((f|0)==0){i=c[m>>2]|0;if((i|0)==0){o=0;p=h;q=l;break}g=gj[i&4095](e)|0;o=g;p=a[9661065]|0;q=c[2415263]|0}else{o=a[f+(l&2047)|0]|0;p=h;q=l}}while(0);l=o&255;o=(p&255)<<13;do{if(k){p=q+7937|0;h=p&8191|o;f=c[2388530]|0;e=c[f+16+(h>>>11<<2)>>2]|0;if((e|0)!=0){r=a[e+(p&2047)|0]|0;break}p=c[f>>2]|0;if((p|0)==0){r=0;break}r=gj[p&4095](h)|0}else{h=q+1|0;p=h&8191|o;f=c[2388530]|0;e=c[f+16+(p>>>11<<2)>>2]|0;if((e|0)!=0){r=a[e+(h&2047)|0]|0;break}h=c[f>>2]|0;if((h|0)==0){r=0;break}r=gj[h&4095](p)|0}}while(0);o=r&255;r=o<<8;q=r|l;c[2415264]=q;l=9661064+(o>>>5)|0;o=a[l]|0;if(((o&255)<<13|r&6144|0)==2088960){r=d[9661075]|0;c[2440610]=(c[2440610]|0)-r;c[2415269]=(c[2415269]|0)-r;s=a[l]|0}else{s=o}o=(s&255)<<13|q&8191;s=c[2388530]|0;l=c[s+16+(o>>>11<<2)>>2]|0;if((l|0)!=0){t=a[l+(q&2047)|0]|0;u=a[9661063]|0;a[9661060]=t;v=u&93;w=t&-128;x=t<<24>>24==0;y=x?2:0;z=y|w;A=z|v;a[9661063]=A;return}q=c[s>>2]|0;if((q|0)==0){t=0;u=a[9661063]|0;a[9661060]=t;v=u&93;w=t&-128;x=t<<24>>24==0;y=x?2:0;z=y|w;A=z|v;a[9661063]=A;return}t=gj[q&4095](o)|0;u=a[9661063]|0;a[9661060]=t;v=u&93;w=t&-128;x=t<<24>>24==0;y=x?2:0;z=y|w;A=z|v;a[9661063]=A;return}function fBQ(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;e=(d[9661075]|0)<<3;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);h=l+1&65535;b[4830522]=h;l=h&65535;e=(d[9661064+(l>>>13)|0]|0)<<13|l&8191;f=c[m+8208+(e>>>11<<2)>>2]|0;do{if((f|0)==0){i=c[m>>2]|0;if((i|0)==0){o=0;p=h;q=m;break}g=gj[i&4095](e)|0;o=g;p=b[4830522]|0;q=c[2388530]|0}else{o=a[f+(l&2047)|0]|0;p=h;q=m}}while(0);a[9661056]=o;o=p+1&65535;b[4830522]=o;p=o&65535;m=(d[9661064+(p>>>13)|0]|0)<<13|p&8191;h=c[q+8208+(m>>>11<<2)>>2]|0;do{if((h|0)==0){l=c[q>>2]|0;if((l|0)==0){r=0;s=o;break}f=gj[l&4095](m)|0;r=f;s=b[4830522]|0}else{r=a[h+(p&2047)|0]|0;s=o}}while(0);a[9661057]=r;b[4830522]=s+1&65535;b[4830528]=(b[4830528]|0)+(d[9661061]|0)&65535;s=c[2415264]|0;r=9661064+(s>>>13&7)|0;o=a[r]|0;if(((o&255)<<13|s&6144|0)==2088960){p=d[9661075]|0;c[2440610]=(c[2440610]|0)-p;c[2415269]=(c[2415269]|0)-p;t=a[r]|0}else{t=o}o=(t&255)<<13|s&8191;t=c[2388530]|0;r=c[t+16+(o>>>11<<2)>>2]|0;if((r|0)!=0){u=a[r+(s&2047)|0]|0;v=a[9661063]|0;w=v&29;x=u&k;y=x<<24>>24!=0;z=y?0:2;A=u&-64;B=w|A;C=B|z;a[9661063]=C;return}s=c[t>>2]|0;if((s|0)==0){u=0;v=a[9661063]|0;w=v&29;x=u&k;y=x<<24>>24!=0;z=y?0:2;A=u&-64;B=w|A;C=B|z;a[9661063]=C;return}u=gj[s&4095](o)|0;v=a[9661063]|0;w=v&29;x=u&k;y=x<<24>>24!=0;z=y?0:2;A=u&-64;B=w|A;C=B|z;a[9661063]=C;return}function fBR(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=(d[9661075]|0)<<2;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=(a[9661061]|0)+k&255;b[4830522]=l+1&65535;l=c[2415263]|0;c[2415264]=l;k=(d[9661065]|0)<<13|l&8191;h=c[m+16+(k>>>11<<2)>>2]|0;do{if((h|0)==0){e=c[m>>2]|0;if((e|0)==0){o=0;break}o=gj[e&4095](k)|0}else{o=a[h+(l&2047)|0]|0}}while(0);l=a[9661063]|0;a[9661062]=o;a[9661063]=(o<<24>>24==0?2:0)|o&-128|l&93;return}function fBS(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=(d[9661075]|0)<<2;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=(a[9661061]|0)+k&255;b[4830522]=l+1&65535;l=c[2415263]|0;c[2415264]=l;k=(d[9661065]|0)<<13|l&8191;h=c[m+16+(k>>>11<<2)>>2]|0;do{if((h|0)==0){e=c[m>>2]|0;if((e|0)==0){o=0;break}o=gj[e&4095](k)|0}else{o=a[h+(l&2047)|0]|0}}while(0);l=a[9661063]|0;a[9661060]=o;a[9661063]=(o<<24>>24==0?2:0)|o&-128|l&93;return}function fBT(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=(d[9661075]|0)<<2;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=(a[9661062]|0)+k&255;b[4830522]=l+1&65535;l=c[2415263]|0;c[2415264]=l;k=(d[9661065]|0)<<13|l&8191;h=c[m+16+(k>>>11<<2)>>2]|0;do{if((h|0)==0){e=c[m>>2]|0;if((e|0)==0){o=0;break}o=gj[e&4095](k)|0}else{o=a[h+(l&2047)|0]|0}}while(0);l=a[9661063]|0;a[9661061]=o;a[9661063]=(o<<24>>24==0?2:0)|o&-128|l&93;return}function fBU(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=(d[9661075]|0)*-7|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=k;b[4830522]=l+1&65535;l=c[2415263]|0;c[2415264]=l;k=a[9661065]|0;h=(k&255)<<13|l&8191;e=c[m+16+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){o=0;p=k;q=l;r=m;break}i=gj[f&4095](h)|0;o=i;p=a[9661065]|0;q=c[2415264]|0;r=c[2388530]|0}else{o=a[e+(l&2047)|0]|0;p=k;q=l;r=m}}while(0);a[9661063]=a[9661063]&-33;m=o|8;o=(p&255)<<13|q&8191;p=c[r+4112+(o>>>11<<2)>>2]|0;if((p|0)!=0){a[p+(q&2047)|0]=m;return}q=c[r+4>>2]|0;if((q|0)==0){return}gg[q&4095](o,m);return}function fBV(){var b=0;b=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-b;c[2415269]=(c[2415269]|0)-b;a[9661063]=a[9661063]&-97;return}function fBW(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;e=(d[9661075]|0)*-5|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661056]=k;k=l+1&65535;b[4830522]=k;l=k&65535;h=(d[9661064+(l>>>13)|0]|0)<<13|l&8191;e=c[m+8208+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){o=0;p=k;break}i=gj[f&4095](h)|0;o=i;p=b[4830522]|0}else{o=a[e+(l&2047)|0]|0;p=k}}while(0);a[9661057]=o;b[4830522]=p+1&65535;b[4830528]=(b[4830528]|0)+(d[9661062]|0)&65535;p=c[2415264]|0;o=9661064+(p>>>13&7)|0;k=a[o]|0;if(((k&255)<<13|p&6144|0)==2088960){l=d[9661075]|0;c[2440610]=(c[2440610]|0)-l;c[2415269]=(c[2415269]|0)-l;q=a[o]|0}else{q=k}k=(q&255)<<13|p&8191;q=c[2388530]|0;o=c[q+16+(k>>>11<<2)>>2]|0;if((o|0)!=0){r=a[o+(p&2047)|0]|0;s=a[9661063]|0;a[9661060]=r;t=s&93;u=r&-128;v=r<<24>>24==0;w=v?2:0;x=w|u;y=x|t;a[9661063]=y;return}p=c[q>>2]|0;if((p|0)==0){r=0;s=a[9661063]|0;a[9661060]=r;t=s&93;u=r&-128;v=r<<24>>24==0;w=v?2:0;x=w|u;y=x|t;a[9661063]=y;return}r=gj[p&4095](k)|0;s=a[9661063]|0;a[9661060]=r;t=s&93;u=r&-128;v=r<<24>>24==0;w=v?2:0;x=w|u;y=x|t;a[9661063]=y;return}function fBX(){var b=0,e=0;b=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-b;c[2415269]=(c[2415269]|0)-b;b=a[9661063]|0;e=a[9661048]|0;a[9661061]=e;a[9661063]=e&-128|b&93|(e<<24>>24==0?2:0);return}function fBY(){var b=0;b=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-b;c[2415269]=(c[2415269]|0)-b;a[9661063]=a[9661063]&-33;return}function fBZ(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;e=(d[9661075]|0)*-5|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661056]=k;k=l+1&65535;b[4830522]=k;l=k&65535;h=(d[9661064+(l>>>13)|0]|0)<<13|l&8191;e=c[m+8208+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){o=0;p=k;break}i=gj[f&4095](h)|0;o=i;p=b[4830522]|0}else{o=a[e+(l&2047)|0]|0;p=k}}while(0);a[9661057]=o;b[4830522]=p+1&65535;b[4830528]=(b[4830528]|0)+(d[9661061]|0)&65535;p=c[2415264]|0;o=9661064+(p>>>13&7)|0;k=a[o]|0;if(((k&255)<<13|p&6144|0)==2088960){l=d[9661075]|0;c[2440610]=(c[2440610]|0)-l;c[2415269]=(c[2415269]|0)-l;q=a[o]|0}else{q=k}k=(q&255)<<13|p&8191;q=c[2388530]|0;o=c[q+16+(k>>>11<<2)>>2]|0;if((o|0)!=0){r=a[o+(p&2047)|0]|0;s=a[9661063]|0;a[9661062]=r;t=s&93;u=r&-128;v=r<<24>>24==0;w=v?2:0;x=w|u;y=x|t;a[9661063]=y;return}p=c[q>>2]|0;if((p|0)==0){r=0;s=a[9661063]|0;a[9661062]=r;t=s&93;u=r&-128;v=r<<24>>24==0;w=v?2:0;x=w|u;y=x|t;a[9661063]=y;return}r=gj[p&4095](k)|0;s=a[9661063]|0;a[9661062]=r;t=s&93;u=r&-128;v=r<<24>>24==0;w=v?2:0;x=w|u;y=x|t;a[9661063]=y;return}function fB_(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;e=(d[9661075]|0)*-5|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661056]=k;k=l+1&65535;b[4830522]=k;l=k&65535;h=(d[9661064+(l>>>13)|0]|0)<<13|l&8191;e=c[m+8208+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){o=0;p=k;break}i=gj[f&4095](h)|0;o=i;p=b[4830522]|0}else{o=a[e+(l&2047)|0]|0;p=k}}while(0);a[9661057]=o;b[4830522]=p+1&65535;b[4830528]=(b[4830528]|0)+(d[9661061]|0)&65535;p=c[2415264]|0;o=9661064+(p>>>13&7)|0;k=a[o]|0;if(((k&255)<<13|p&6144|0)==2088960){l=d[9661075]|0;c[2440610]=(c[2440610]|0)-l;c[2415269]=(c[2415269]|0)-l;q=a[o]|0}else{q=k}k=(q&255)<<13|p&8191;q=c[2388530]|0;o=c[q+16+(k>>>11<<2)>>2]|0;if((o|0)!=0){r=a[o+(p&2047)|0]|0;s=a[9661063]|0;a[9661060]=r;t=s&93;u=r&-128;v=r<<24>>24==0;w=v?2:0;x=w|u;y=x|t;a[9661063]=y;return}p=c[q>>2]|0;if((p|0)==0){r=0;s=a[9661063]|0;a[9661060]=r;t=s&93;u=r&-128;v=r<<24>>24==0;w=v?2:0;x=w|u;y=x|t;a[9661063]=y;return}r=gj[p&4095](k)|0;s=a[9661063]|0;a[9661060]=r;t=s&93;u=r&-128;v=r<<24>>24==0;w=v?2:0;x=w|u;y=x|t;a[9661063]=y;return}function fB$(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;e=(d[9661075]|0)*-5|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661056]=k;k=l+1&65535;b[4830522]=k;l=k&65535;h=(d[9661064+(l>>>13)|0]|0)<<13|l&8191;e=c[m+8208+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){o=0;p=k;break}i=gj[f&4095](h)|0;o=i;p=b[4830522]|0}else{o=a[e+(l&2047)|0]|0;p=k}}while(0);a[9661057]=o;b[4830522]=p+1&65535;b[4830528]=(b[4830528]|0)+(d[9661062]|0)&65535;p=c[2415264]|0;o=9661064+(p>>>13&7)|0;k=a[o]|0;if(((k&255)<<13|p&6144|0)==2088960){l=d[9661075]|0;c[2440610]=(c[2440610]|0)-l;c[2415269]=(c[2415269]|0)-l;q=a[o]|0}else{q=k}k=(q&255)<<13|p&8191;q=c[2388530]|0;o=c[q+16+(k>>>11<<2)>>2]|0;if((o|0)!=0){r=a[o+(p&2047)|0]|0;s=a[9661063]|0;a[9661061]=r;t=s&93;u=r&-128;v=r<<24>>24==0;w=v?2:0;x=w|u;y=x|t;a[9661063]=y;return}p=c[q>>2]|0;if((p|0)==0){r=0;s=a[9661063]|0;a[9661061]=r;t=s&93;u=r&-128;v=r<<24>>24==0;w=v?2:0;x=w|u;y=x|t;a[9661063]=y;return}r=gj[p&4095](k)|0;s=a[9661063]|0;a[9661061]=r;t=s&93;u=r&-128;v=r<<24>>24==0;w=v?2:0;x=w|u;y=x|t;a[9661063]=y;return}function fB0(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=(d[9661075]|0)<<2;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=k;k=l+1&65535;b[4830522]=k;l=c[2415263]|0;c[2415264]=l;h=(d[9661065]|0)<<13|l&8191;e=c[m+16+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){a[9661063]=a[9661063]&-33;o=k;break}else{p=gj[f&4095](h)|0;q=5463;break}}else{p=a[e+(l&2047)|0]|0;q=5463}}while(0);do{if((q|0)==5463){a[9661063]=a[9661063]&-33;if((p&8)==0){o=b[4830522]|0;break}l=(d[9661075]|0)<<2;c[2440610]=(c[2440610]|0)-l;c[2415269]=(c[2415269]|0)-l;l=b[4830522]|0;e=l&65535;h=(d[9661064+(e>>>13)|0]|0)<<13|e&8191;k=c[2388530]|0;m=c[k+8208+(h>>>11<<2)>>2]|0;do{if((m|0)==0){f=c[k>>2]|0;if((f|0)==0){r=0;s=l;break}i=gj[f&4095](h)|0;r=i;s=b[4830522]|0}else{r=a[m+(e&2047)|0]|0;s=l}}while(0);b[4830528]=(s+1&65535)+(r<<24>>24)&65535;c[2415261]=c[2415264];return}}while(0);b[4830522]=o+1&65535;o=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-o;c[2415269]=(c[2415269]|0)-o;return}function fB1(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;break}m=gj[j&4095](g)|0;k=m;l=b[4830522]|0}else{k=a[i+(f&2047)|0]|0;l=e}}while(0);b[4830522]=l+1&65535;l=a[9661063]&-34;a[9661063]=l;e=a[9661062]|0;if((e&255)<(k&255)){n=l;o=n&93;p=e-k&255;q=p&-128;r=e<<24>>24==k<<24>>24;s=r?2:0;t=s|q;u=t|o;a[9661063]=u;return}f=l|1;a[9661063]=f;n=f;o=n&93;p=e-k&255;q=p&-128;r=e<<24>>24==k<<24>>24;s=r?2:0;t=s|q;u=t|o;a[9661063]=u;return}function fB2(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;e=(d[9661075]|0)*-7|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=(a[9661061]|0)+k&255;b[4830522]=l+1&65535;l=c[2415263]|0;k=(l&255|0)==255;h=a[9661065]|0;e=(h&255)<<13|l&8191;f=c[m+16+(e>>>11<<2)>>2]|0;do{if((f|0)==0){i=c[m>>2]|0;if((i|0)==0){o=0;p=h;q=l;break}g=gj[i&4095](e)|0;o=g;p=a[9661065]|0;q=c[2415263]|0}else{o=a[f+(l&2047)|0]|0;p=h;q=l}}while(0);l=o&255;o=(p&255)<<13;do{if(k){p=q+7937|0;h=p&8191|o;f=c[2388530]|0;e=c[f+16+(h>>>11<<2)>>2]|0;if((e|0)!=0){r=a[e+(p&2047)|0]|0;break}p=c[f>>2]|0;if((p|0)==0){r=0;break}r=gj[p&4095](h)|0}else{h=q+1|0;p=h&8191|o;f=c[2388530]|0;e=c[f+16+(p>>>11<<2)>>2]|0;if((e|0)!=0){r=a[e+(h&2047)|0]|0;break}h=c[f>>2]|0;if((h|0)==0){r=0;break}r=gj[h&4095](p)|0}}while(0);o=r&255;r=o<<8;q=r|l;c[2415264]=q;l=9661064+(o>>>5)|0;o=a[l]|0;if(((o&255)<<13|r&6144|0)==2088960){r=d[9661075]|0;c[2440610]=(c[2440610]|0)-r;c[2415269]=(c[2415269]|0)-r;s=a[l]|0}else{s=o}o=(s&255)<<13|q&8191;s=c[2388530]|0;l=c[s+16+(o>>>11<<2)>>2]|0;do{if((l|0)==0){r=c[s>>2]|0;if((r|0)==0){t=0;break}t=gj[r&4095](o)|0}else{t=a[l+(q&2047)|0]|0}}while(0);q=a[9661063]&-34;a[9661063]=q;l=a[9661060]|0;if((l&255)<(t&255)){u=q;v=u&93;w=l-t&255;x=w&-128;y=l<<24>>24==t<<24>>24;z=y?2:0;A=z|x;B=A|v;a[9661063]=B;return}o=q|1;a[9661063]=o;u=o;v=u&93;w=l-t&255;x=w&-128;y=l<<24>>24==t<<24>>24;z=y?2:0;A=z|x;B=A|v;a[9661063]=B;return}function fB3(){var b=0;b=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-b;c[2415269]=(c[2415269]|0)-b;a[9661063]=a[9661063]&-33;a[9661062]=0;return}function fB4(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;a[9661063]=a[9661063]&-33;e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+16+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);h=k&255;k=(l&65535)+1|0;e=(d[9661064+(k>>>13&7)|0]|0)<<13|k&8191;f=c[m+16+(e>>>11<<2)>>2]|0;do{if((f|0)==0){i=c[m>>2]|0;if((i|0)==0){o=0;p=l;q=m;break}g=gj[i&4095](e)|0;o=g;p=b[4830522]|0;q=c[2388530]|0}else{o=a[f+(k&2047)|0]|0;p=l;q=m}}while(0);m=(o&255)<<8|h;h=(p&65535)+2|0;o=(d[9661064+(h>>>13&7)|0]|0)<<13|h&8191;l=c[q+16+(o>>>11<<2)>>2]|0;do{if((l|0)==0){k=c[q>>2]|0;if((k|0)==0){r=0;s=p;t=q;break}f=gj[k&4095](o)|0;r=f;s=b[4830522]|0;t=c[2388530]|0}else{r=a[l+(h&2047)|0]|0;s=p;t=q}}while(0);q=r&255;r=(s&65535)+3|0;p=(d[9661064+(r>>>13&7)|0]|0)<<13|r&8191;h=c[t+16+(p>>>11<<2)>>2]|0;do{if((h|0)==0){l=c[t>>2]|0;if((l|0)==0){u=0;v=s;w=t;break}o=gj[l&4095](p)|0;u=o;v=b[4830522]|0;w=c[2388530]|0}else{u=a[h+(r&2047)|0]|0;v=s;w=t}}while(0);t=(u&255)<<8|q;q=(v&65535)+4|0;u=(d[9661064+(q>>>13&7)|0]|0)<<13|q&8191;s=c[w+16+(u>>>11<<2)>>2]|0;do{if((s|0)==0){r=c[w>>2]|0;if((r|0)==0){x=0;y=v;z=w;break}h=gj[r&4095](u)|0;x=h;y=b[4830522]|0;z=c[2388530]|0}else{x=a[s+(q&2047)|0]|0;y=v;z=w}}while(0);w=x&255;x=(y&65535)+5|0;v=(d[9661064+(x>>>13&7)|0]|0)<<13|x&8191;q=c[z+16+(v>>>11<<2)>>2]|0;do{if((q|0)==0){s=c[z>>2]|0;if((s|0)==0){A=0;B=y;break}u=gj[s&4095](v)|0;A=u;B=b[4830522]|0}else{A=a[q+(x&2047)|0]|0;B=y}}while(0);y=(A&255)<<8|w;b[4830522]=B+6&65535;B=(y|0)==0?65536:y;y=ag((B*6|0)+17|0,d[9661075]|0)|0;c[2440610]=(c[2440610]|0)-y;c[2415269]=(c[2415269]|0)-y;y=t;t=m;m=B;while(1){B=m-1|0;w=9661064+(t>>>13&7)|0;A=a[w]|0;if(((A&255)<<13|t&6144|0)==2088960){x=d[9661075]|0;c[2440610]=(c[2440610]|0)-x;c[2415269]=(c[2415269]|0)-x;C=a[w]|0}else{C=A}A=(C&255)<<13|t&8191;w=c[2388530]|0;x=c[w+16+(A>>>11<<2)>>2]|0;do{if((x|0)==0){q=c[w>>2]|0;if((q|0)==0){D=0;break}D=gj[q&4095](A)|0}else{D=a[x+(t&2047)|0]|0}}while(0);x=9661064+(y>>>13&7)|0;A=a[x]|0;if(((A&255)<<13|y&6144|0)==2088960){w=d[9661075]|0;c[2440610]=(c[2440610]|0)-w;c[2415269]=(c[2415269]|0)-w;E=a[x]|0}else{E=A}A=(E&255)<<13|y&8191;x=c[2388530]|0;w=c[x+4112+(A>>>11<<2)>>2]|0;do{if((w|0)==0){q=c[x+4>>2]|0;if((q|0)==0){break}gg[q&4095](A,D)}else{a[w+(y&2047)|0]=D}}while(0);if((B|0)==0){break}else{y=y-1|0;t=t-1|0;m=B}}return}function fB5(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;e=(d[9661075]|0)<<2;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=k;b[4830522]=l+1&65535;l=c[2415263]|0;c[2415264]=l;k=(d[9661065]|0)<<13|l&8191;h=c[m+16+(k>>>11<<2)>>2]|0;do{if((h|0)==0){e=c[m>>2]|0;if((e|0)==0){o=0;break}o=gj[e&4095](k)|0}else{o=a[h+(l&2047)|0]|0}}while(0);l=a[9661063]&-34;a[9661063]=l;h=a[9661062]|0;if((h&255)<(o&255)){p=l;q=p&93;r=h-o&255;s=r&-128;t=h<<24>>24==o<<24>>24;u=t?2:0;v=u|s;w=v|q;a[9661063]=w;return}k=l|1;a[9661063]=k;p=k;q=p&93;r=h-o&255;s=r&-128;t=h<<24>>24==o<<24>>24;u=t?2:0;v=u|s;w=v|q;a[9661063]=w;return}function fB6(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;e=(d[9661075]|0)<<2;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=k;b[4830522]=l+1&65535;l=c[2415263]|0;c[2415264]=l;k=(d[9661065]|0)<<13|l&8191;h=c[m+16+(k>>>11<<2)>>2]|0;do{if((h|0)==0){e=c[m>>2]|0;if((e|0)==0){o=0;break}o=gj[e&4095](k)|0}else{o=a[h+(l&2047)|0]|0}}while(0);l=a[9661063]&-34;a[9661063]=l;h=a[9661060]|0;if((h&255)<(o&255)){p=l;q=p&93;r=h-o&255;s=r&-128;t=h<<24>>24==o<<24>>24;u=t?2:0;v=u|s;w=v|q;a[9661063]=w;return}k=l|1;a[9661063]=k;p=k;q=p&93;r=h-o&255;s=r&-128;t=h<<24>>24==o<<24>>24;u=t?2:0;v=u|s;w=v|q;a[9661063]=w;return}function fB7(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=(d[9661075]|0)*-6|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=k;b[4830522]=l+1&65535;l=c[2415263]|0;c[2415264]=l;k=a[9661065]|0;h=(k&255)<<13|l&8191;e=c[m+16+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){o=0;p=k;q=l;r=m;break}i=gj[f&4095](h)|0;o=i;p=a[9661065]|0;q=c[2415264]|0;r=c[2388530]|0}else{o=a[e+(l&2047)|0]|0;p=k;q=l;r=m}}while(0);m=o-1&255;a[9661063]=a[9661063]&93|m&-128|(m<<24>>24==0?2:0);o=(p&255)<<13|q&8191;p=c[r+4112+(o>>>11<<2)>>2]|0;if((p|0)!=0){a[p+(q&2047)|0]=m;return}q=c[r+4>>2]|0;if((q|0)==0){return}gg[q&4095](o,m);return}function fB8(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=(d[9661075]|0)*-7|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=k;b[4830522]=l+1&65535;l=c[2415263]|0;c[2415264]=l;k=a[9661065]|0;h=(k&255)<<13|l&8191;e=c[m+16+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){o=0;p=k;q=l;r=m;break}i=gj[f&4095](h)|0;o=i;p=a[9661065]|0;q=c[2415264]|0;r=c[2388530]|0}else{o=a[e+(l&2047)|0]|0;p=k;q=l;r=m}}while(0);a[9661063]=a[9661063]&-33;m=o|16;o=(p&255)<<13|q&8191;p=c[r+4112+(o>>>11<<2)>>2]|0;if((p|0)!=0){a[p+(q&2047)|0]=m;return}q=c[r+4>>2]|0;if((q|0)==0){return}gg[q&4095](o,m);return}function fB9(){var b=0,e=0;b=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-b;c[2415269]=(c[2415269]|0)-b;b=a[9661063]|0;e=(a[9661062]|0)+1&255;a[9661062]=e;a[9661063]=e&-128|b&93|(e<<24>>24==0?2:0);return}function fCa(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;break}m=gj[j&4095](g)|0;k=m;l=b[4830522]|0}else{k=a[i+(f&2047)|0]|0;l=e}}while(0);b[4830522]=l+1&65535;l=a[9661063]&-34;a[9661063]=l;e=a[9661060]|0;if((e&255)<(k&255)){n=l;o=n&93;p=e-k&255;q=p&-128;r=e<<24>>24==k<<24>>24;s=r?2:0;t=s|q;u=t|o;a[9661063]=u;return}f=l|1;a[9661063]=f;n=f;o=n&93;p=e-k&255;q=p&-128;r=e<<24>>24==k<<24>>24;s=r?2:0;t=s|q;u=t|o;a[9661063]=u;return}function fCb(){var b=0,e=0;b=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-b;c[2415269]=(c[2415269]|0)-b;b=a[9661063]|0;e=(a[9661061]|0)-1&255;a[9661061]=e;a[9661063]=e&-128|b&93|(e<<24>>24==0?2:0);return}function fCc(){var b=0;b=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-b;c[2415269]=(c[2415269]|0)-b;a[9661063]=a[9661063]&-33;return}function fCd(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;e=(d[9661075]|0)*-5|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661056]=k;k=l+1&65535;b[4830522]=k;l=k&65535;h=(d[9661064+(l>>>13)|0]|0)<<13|l&8191;e=c[m+8208+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){o=0;p=k;break}i=gj[f&4095](h)|0;o=i;p=b[4830522]|0}else{o=a[e+(l&2047)|0]|0;p=k}}while(0);a[9661057]=o;b[4830522]=p+1&65535;p=c[2415264]|0;o=9661064+(p>>>13&7)|0;k=a[o]|0;if(((k&255)<<13|p&6144|0)==2088960){l=d[9661075]|0;c[2440610]=(c[2440610]|0)-l;c[2415269]=(c[2415269]|0)-l;q=a[o]|0}else{q=k}k=(q&255)<<13|p&8191;q=c[2388530]|0;o=c[q+16+(k>>>11<<2)>>2]|0;do{if((o|0)==0){l=c[q>>2]|0;if((l|0)==0){r=0;break}r=gj[l&4095](k)|0}else{r=a[o+(p&2047)|0]|0}}while(0);p=a[9661063]&-34;a[9661063]=p;o=a[9661062]|0;if((o&255)<(r&255)){s=p;t=s&93;u=o-r&255;v=u&-128;w=o<<24>>24==r<<24>>24;x=w?2:0;y=x|v;z=y|t;a[9661063]=z;return}k=p|1;a[9661063]=k;s=k;t=s&93;u=o-r&255;v=u&-128;w=o<<24>>24==r<<24>>24;x=w?2:0;y=x|v;z=y|t;a[9661063]=z;return}function fCe(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;e=(d[9661075]|0)*-5|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661056]=k;k=l+1&65535;b[4830522]=k;l=k&65535;h=(d[9661064+(l>>>13)|0]|0)<<13|l&8191;e=c[m+8208+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){o=0;p=k;break}i=gj[f&4095](h)|0;o=i;p=b[4830522]|0}else{o=a[e+(l&2047)|0]|0;p=k}}while(0);a[9661057]=o;b[4830522]=p+1&65535;p=c[2415264]|0;o=9661064+(p>>>13&7)|0;k=a[o]|0;if(((k&255)<<13|p&6144|0)==2088960){l=d[9661075]|0;c[2440610]=(c[2440610]|0)-l;c[2415269]=(c[2415269]|0)-l;q=a[o]|0}else{q=k}k=(q&255)<<13|p&8191;q=c[2388530]|0;o=c[q+16+(k>>>11<<2)>>2]|0;do{if((o|0)==0){l=c[q>>2]|0;if((l|0)==0){r=0;break}r=gj[l&4095](k)|0}else{r=a[o+(p&2047)|0]|0}}while(0);p=a[9661063]&-34;a[9661063]=p;o=a[9661060]|0;if((o&255)<(r&255)){s=p;t=s&93;u=o-r&255;v=u&-128;w=o<<24>>24==r<<24>>24;x=w?2:0;y=x|v;z=y|t;a[9661063]=z;return}k=p|1;a[9661063]=k;s=k;t=s&93;u=o-r&255;v=u&-128;w=o<<24>>24==r<<24>>24;x=w?2:0;y=x|v;z=y|t;a[9661063]=z;return}function fCf(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=(d[9661075]|0)*-7|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661056]=k;k=l+1&65535;b[4830522]=k;l=k&65535;h=(d[9661064+(l>>>13)|0]|0)<<13|l&8191;e=c[m+8208+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){o=0;p=k;break}i=gj[f&4095](h)|0;o=i;p=b[4830522]|0}else{o=a[e+(l&2047)|0]|0;p=k}}while(0);a[9661057]=o;b[4830522]=p+1&65535;p=c[2415264]|0;o=9661064+(p>>>13&7)|0;k=a[o]|0;if(((k&255)<<13|p&6144|0)==2088960){l=d[9661075]|0;c[2440610]=(c[2440610]|0)-l;c[2415269]=(c[2415269]|0)-l;q=a[o]|0}else{q=k}k=(q&255)<<13|p&8191;q=c[2388530]|0;o=c[q+16+(k>>>11<<2)>>2]|0;do{if((o|0)==0){l=c[q>>2]|0;if((l|0)==0){r=0;s=p;break}e=gj[l&4095](k)|0;r=e;s=c[2415264]|0}else{r=a[o+(p&2047)|0]|0;s=p}}while(0);p=r-1&255;a[9661063]=a[9661063]&93|p&-128|(p<<24>>24==0?2:0);r=9661064+(s>>>13&7)|0;o=a[r]|0;if(((o&255)<<13|s&6144|0)==2088960){k=d[9661075]|0;c[2440610]=(c[2440610]|0)-k;c[2415269]=(c[2415269]|0)-k;t=a[r]|0}else{t=o}o=(t&255)<<13|s&8191;t=c[2388530]|0;r=c[t+4112+(o>>>11<<2)>>2]|0;if((r|0)!=0){a[r+(s&2047)|0]=p;return}s=c[t+4>>2]|0;if((s|0)==0){return}gg[s&4095](o,p);return}function fCg(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=(d[9661075]|0)<<2;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=k;k=l+1&65535;b[4830522]=k;l=c[2415263]|0;c[2415264]=l;h=(d[9661065]|0)<<13|l&8191;e=c[m+16+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){a[9661063]=a[9661063]&-33;o=k;break}else{p=gj[f&4095](h)|0;q=5692;break}}else{p=a[e+(l&2047)|0]|0;q=5692}}while(0);do{if((q|0)==5692){a[9661063]=a[9661063]&-33;if((p&16)==0){o=b[4830522]|0;break}l=(d[9661075]|0)<<2;c[2440610]=(c[2440610]|0)-l;c[2415269]=(c[2415269]|0)-l;l=b[4830522]|0;e=l&65535;h=(d[9661064+(e>>>13)|0]|0)<<13|e&8191;k=c[2388530]|0;m=c[k+8208+(h>>>11<<2)>>2]|0;do{if((m|0)==0){f=c[k>>2]|0;if((f|0)==0){r=0;s=l;break}i=gj[f&4095](h)|0;r=i;s=b[4830522]|0}else{r=a[m+(e&2047)|0]|0;s=l}}while(0);b[4830528]=(s+1&65535)+(r<<24>>24)&65535;c[2415261]=c[2415264];return}}while(0);b[4830522]=o+1&65535;o=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-o;c[2415269]=(c[2415269]|0)-o;return}function fCh(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=a[9661063]|0;a[9661063]=e&-33;if((e&2)!=0){b[4830522]=(b[4830522]|0)+1&65535;e=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;return}e=(d[9661075]|0)<<2;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;break}m=gj[j&4095](g)|0;k=m;l=b[4830522]|0}else{k=a[i+(f&2047)|0]|0;l=e}}while(0);b[4830528]=(l+1&65535)+(k<<24>>24)&65535;c[2415261]=c[2415264];return}function fCi(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;e=(d[9661075]|0)*-7|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=k;b[4830522]=l+1&65535;l=c[2415263]|0;k=(l&255|0)==255;h=a[9661065]|0;e=(h&255)<<13|l&8191;f=c[m+16+(e>>>11<<2)>>2]|0;do{if((f|0)==0){i=c[m>>2]|0;if((i|0)==0){o=0;p=h;q=l;break}g=gj[i&4095](e)|0;o=g;p=a[9661065]|0;q=c[2415263]|0}else{o=a[f+(l&2047)|0]|0;p=h;q=l}}while(0);l=o&255;o=(p&255)<<13;do{if(k){p=q+7937|0;h=p&8191|o;f=c[2388530]|0;e=c[f+16+(h>>>11<<2)>>2]|0;if((e|0)!=0){r=a[e+(p&2047)|0]|0;break}p=c[f>>2]|0;if((p|0)==0){r=0;break}r=gj[p&4095](h)|0}else{h=q+1|0;p=h&8191|o;f=c[2388530]|0;e=c[f+16+(p>>>11<<2)>>2]|0;if((e|0)!=0){r=a[e+(h&2047)|0]|0;break}h=c[f>>2]|0;if((h|0)==0){r=0;break}r=gj[h&4095](p)|0}}while(0);o=(r&255)<<8|l;c[2415264]=o;b[4830528]=(o&65535)+(d[9661062]|0)&65535;o=c[2415264]|0;l=9661064+(o>>>13&7)|0;r=a[l]|0;if(((r&255)<<13|o&6144|0)==2088960){q=d[9661075]|0;c[2440610]=(c[2440610]|0)-q;c[2415269]=(c[2415269]|0)-q;s=a[l]|0}else{s=r}r=(s&255)<<13|o&8191;s=c[2388530]|0;l=c[s+16+(r>>>11<<2)>>2]|0;do{if((l|0)==0){q=c[s>>2]|0;if((q|0)==0){t=0;break}t=gj[q&4095](r)|0}else{t=a[l+(o&2047)|0]|0}}while(0);o=a[9661063]&-34;a[9661063]=o;l=a[9661060]|0;if((l&255)<(t&255)){u=o;v=u&93;w=l-t&255;x=w&-128;y=l<<24>>24==t<<24>>24;z=y?2:0;A=z|x;B=A|v;a[9661063]=B;return}r=o|1;a[9661063]=r;u=r;v=u&93;w=l-t&255;x=w&-128;y=l<<24>>24==t<<24>>24;z=y?2:0;A=z|x;B=A|v;a[9661063]=B;return}function fCj(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;e=(d[9661075]|0)*-7|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=k;b[4830522]=l+1&65535;l=c[2415263]|0;k=(l&255|0)==255;h=a[9661065]|0;e=(h&255)<<13|l&8191;f=c[m+16+(e>>>11<<2)>>2]|0;do{if((f|0)==0){i=c[m>>2]|0;if((i|0)==0){o=0;p=h;q=l;break}g=gj[i&4095](e)|0;o=g;p=a[9661065]|0;q=c[2415263]|0}else{o=a[f+(l&2047)|0]|0;p=h;q=l}}while(0);l=o&255;o=(p&255)<<13;do{if(k){p=q+7937|0;h=p&8191|o;f=c[2388530]|0;e=c[f+16+(h>>>11<<2)>>2]|0;if((e|0)!=0){r=a[e+(p&2047)|0]|0;break}p=c[f>>2]|0;if((p|0)==0){r=0;break}r=gj[p&4095](h)|0}else{h=q+1|0;p=h&8191|o;f=c[2388530]|0;e=c[f+16+(p>>>11<<2)>>2]|0;if((e|0)!=0){r=a[e+(h&2047)|0]|0;break}h=c[f>>2]|0;if((h|0)==0){r=0;break}r=gj[h&4095](p)|0}}while(0);o=r&255;r=o<<8;q=r|l;c[2415264]=q;l=9661064+(o>>>5)|0;o=a[l]|0;if(((o&255)<<13|r&6144|0)==2088960){r=d[9661075]|0;c[2440610]=(c[2440610]|0)-r;c[2415269]=(c[2415269]|0)-r;s=a[l]|0}else{s=o}o=(s&255)<<13|q&8191;s=c[2388530]|0;l=c[s+16+(o>>>11<<2)>>2]|0;do{if((l|0)==0){r=c[s>>2]|0;if((r|0)==0){t=0;break}t=gj[r&4095](o)|0}else{t=a[l+(q&2047)|0]|0}}while(0);q=a[9661063]&-34;a[9661063]=q;l=a[9661060]|0;if((l&255)<(t&255)){u=q;v=u&93;w=l-t&255;x=w&-128;y=l<<24>>24==t<<24>>24;z=y?2:0;A=z|x;B=A|v;a[9661063]=B;return}o=q|1;a[9661063]=o;u=o;v=u&93;w=l-t&255;x=w&-128;y=l<<24>>24==t<<24>>24;z=y?2:0;A=z|x;B=A|v;a[9661063]=B;return}function fCk(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;a[9661063]=a[9661063]&-33;e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+16+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);h=k&255;k=(l&65535)+1|0;e=(d[9661064+(k>>>13&7)|0]|0)<<13|k&8191;f=c[m+16+(e>>>11<<2)>>2]|0;do{if((f|0)==0){i=c[m>>2]|0;if((i|0)==0){o=0;p=l;q=m;break}g=gj[i&4095](e)|0;o=g;p=b[4830522]|0;q=c[2388530]|0}else{o=a[f+(k&2047)|0]|0;p=l;q=m}}while(0);m=(o&255)<<8|h;h=(p&65535)+2|0;o=(d[9661064+(h>>>13&7)|0]|0)<<13|h&8191;l=c[q+16+(o>>>11<<2)>>2]|0;do{if((l|0)==0){k=c[q>>2]|0;if((k|0)==0){r=0;s=p;t=q;break}f=gj[k&4095](o)|0;r=f;s=b[4830522]|0;t=c[2388530]|0}else{r=a[l+(h&2047)|0]|0;s=p;t=q}}while(0);q=r&255;r=(s&65535)+3|0;p=(d[9661064+(r>>>13&7)|0]|0)<<13|r&8191;h=c[t+16+(p>>>11<<2)>>2]|0;do{if((h|0)==0){l=c[t>>2]|0;if((l|0)==0){u=0;v=s;w=t;break}o=gj[l&4095](p)|0;u=o;v=b[4830522]|0;w=c[2388530]|0}else{u=a[h+(r&2047)|0]|0;v=s;w=t}}while(0);t=u&255;u=t<<8;s=(v&65535)+4|0;r=(d[9661064+(s>>>13&7)|0]|0)<<13|s&8191;h=c[w+16+(r>>>11<<2)>>2]|0;do{if((h|0)==0){p=c[w>>2]|0;if((p|0)==0){x=0;y=v;z=w;break}o=gj[p&4095](r)|0;x=o;y=b[4830522]|0;z=c[2388530]|0}else{x=a[h+(s&2047)|0]|0;y=v;z=w}}while(0);w=x&255;x=(y&65535)+5|0;v=(d[9661064+(x>>>13&7)|0]|0)<<13|x&8191;s=c[z+16+(v>>>11<<2)>>2]|0;do{if((s|0)==0){h=c[z>>2]|0;if((h|0)==0){A=0;B=y;break}r=gj[h&4095](v)|0;A=r;B=b[4830522]|0}else{A=a[s+(x&2047)|0]|0;B=y}}while(0);y=(A&255)<<8|w;b[4830522]=B+6&65535;B=(y|0)==0?65536:y;y=ag((B*6|0)+17|0,d[9661075]|0)|0;c[2440610]=(c[2440610]|0)-y;c[2415269]=(c[2415269]|0)-y;y=9661064+(t>>>5)|0;t=u&7936|q;q=u&6144;u=t&2047;w=m;m=B;while(1){B=m-1|0;A=9661064+(w>>>13&7)|0;x=a[A]|0;if(((x&255)<<13|w&6144|0)==2088960){s=d[9661075]|0;c[2440610]=(c[2440610]|0)-s;c[2415269]=(c[2415269]|0)-s;C=a[A]|0}else{C=x}x=(C&255)<<13|w&8191;A=c[2388530]|0;s=c[A+16+(x>>>11<<2)>>2]|0;do{if((s|0)==0){v=c[A>>2]|0;if((v|0)==0){D=0;break}D=gj[v&4095](x)|0}else{D=a[s+(w&2047)|0]|0}}while(0);s=a[y]|0;if(((s&255)<<13|q|0)==2088960){x=d[9661075]|0;c[2440610]=(c[2440610]|0)-x;c[2415269]=(c[2415269]|0)-x;E=a[y]|0}else{E=s}s=(E&255)<<13|t;x=c[2388530]|0;A=c[x+4112+(s>>>11<<2)>>2]|0;do{if((A|0)==0){v=c[x+4>>2]|0;if((v|0)==0){break}gg[v&4095](s,D)}else{a[A+u|0]=D}}while(0);if((B|0)==0){break}else{w=w+1|0;m=B}}return}function fCl(){var b=0;b=(d[9661075]|0)*-3|0;c[2440610]=b+(c[2440610]|0);c[2415269]=b+(c[2415269]|0);a[9661075]=1;return}function fCm(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;e=(d[9661075]|0)<<2;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=(a[9661061]|0)+k&255;b[4830522]=l+1&65535;l=c[2415263]|0;c[2415264]=l;k=(d[9661065]|0)<<13|l&8191;h=c[m+16+(k>>>11<<2)>>2]|0;do{if((h|0)==0){e=c[m>>2]|0;if((e|0)==0){o=0;break}o=gj[e&4095](k)|0}else{o=a[h+(l&2047)|0]|0}}while(0);l=a[9661063]&-34;a[9661063]=l;h=a[9661060]|0;if((h&255)<(o&255)){p=l;q=p&93;r=h-o&255;s=r&-128;t=h<<24>>24==o<<24>>24;u=t?2:0;v=u|s;w=v|q;a[9661063]=w;return}k=l|1;a[9661063]=k;p=k;q=p&93;r=h-o&255;s=r&-128;t=h<<24>>24==o<<24>>24;u=t?2:0;v=u|s;w=v|q;a[9661063]=w;return}function fCn(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=(d[9661075]|0)*-6|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=(a[9661061]|0)+k&255;b[4830522]=l+1&65535;l=c[2415263]|0;c[2415264]=l;k=a[9661065]|0;h=(k&255)<<13|l&8191;e=c[m+16+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){o=0;p=k;q=l;r=m;break}i=gj[f&4095](h)|0;o=i;p=a[9661065]|0;q=c[2415264]|0;r=c[2388530]|0}else{o=a[e+(l&2047)|0]|0;p=k;q=l;r=m}}while(0);m=o-1&255;a[9661063]=a[9661063]&93|m&-128|(m<<24>>24==0?2:0);o=(p&255)<<13|q&8191;p=c[r+4112+(o>>>11<<2)>>2]|0;if((p|0)!=0){a[p+(q&2047)|0]=m;return}q=c[r+4>>2]|0;if((q|0)==0){return}gg[q&4095](o,m);return}function fCo(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=(d[9661075]|0)*-7|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=k;b[4830522]=l+1&65535;l=c[2415263]|0;c[2415264]=l;k=a[9661065]|0;h=(k&255)<<13|l&8191;e=c[m+16+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){o=0;p=k;q=l;r=m;break}i=gj[f&4095](h)|0;o=i;p=a[9661065]|0;q=c[2415264]|0;r=c[2388530]|0}else{o=a[e+(l&2047)|0]|0;p=k;q=l;r=m}}while(0);a[9661063]=a[9661063]&-33;m=o|32;o=(p&255)<<13|q&8191;p=c[r+4112+(o>>>11<<2)>>2]|0;if((p|0)!=0){a[p+(q&2047)|0]=m;return}q=c[r+4>>2]|0;if((q|0)==0){return}gg[q&4095](o,m);return}function fCp(){var b=0;b=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-b;c[2415269]=(c[2415269]|0)-b;a[9661063]=a[9661063]&-41;return}function fCq(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;e=(d[9661075]|0)*-5|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661056]=k;k=l+1&65535;b[4830522]=k;l=k&65535;h=(d[9661064+(l>>>13)|0]|0)<<13|l&8191;e=c[m+8208+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){o=0;p=k;break}i=gj[f&4095](h)|0;o=i;p=b[4830522]|0}else{o=a[e+(l&2047)|0]|0;p=k}}while(0);a[9661057]=o;b[4830522]=p+1&65535;b[4830528]=(b[4830528]|0)+(d[9661062]|0)&65535;p=c[2415264]|0;o=9661064+(p>>>13&7)|0;k=a[o]|0;if(((k&255)<<13|p&6144|0)==2088960){l=d[9661075]|0;c[2440610]=(c[2440610]|0)-l;c[2415269]=(c[2415269]|0)-l;q=a[o]|0}else{q=k}k=(q&255)<<13|p&8191;q=c[2388530]|0;o=c[q+16+(k>>>11<<2)>>2]|0;do{if((o|0)==0){l=c[q>>2]|0;if((l|0)==0){r=0;break}r=gj[l&4095](k)|0}else{r=a[o+(p&2047)|0]|0}}while(0);p=a[9661063]&-34;a[9661063]=p;o=a[9661060]|0;if((o&255)<(r&255)){s=p;t=s&93;u=o-r&255;v=u&-128;w=o<<24>>24==r<<24>>24;x=w?2:0;y=x|v;z=y|t;a[9661063]=z;return}k=p|1;a[9661063]=k;s=k;t=s&93;u=o-r&255;v=u&-128;w=o<<24>>24==r<<24>>24;x=w?2:0;y=x|v;z=y|t;a[9661063]=z;return}function fCr(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0;b=(d[9661075]|0)*-3|0;c[2440610]=b+(c[2440610]|0);c[2415269]=b+(c[2415269]|0);a[9661063]=a[9661063]&-33;b=c[2415262]|0;e=a[9661061]|0;f=(d[9661065]|0)<<13|b&2097151;g=c[2388530]|0;h=c[g+4112+(f>>>11<<2)>>2]|0;if((h|0)!=0){a[h+(b&2047)|0]=e;i=a[9661048]|0;j=i-1&255;a[9661048]=j;return}b=c[g+4>>2]|0;if((b|0)==0){i=a[9661048]|0;j=i-1&255;a[9661048]=j;return}gg[b&4095](f,e);i=a[9661048]|0;j=i-1&255;a[9661048]=j;return}function fCs(){var b=0;b=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-b;c[2415269]=(c[2415269]|0)-b;a[9661063]=a[9661063]&-33;return}function fCt(){var b=0;b=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-b;c[2415269]=(c[2415269]|0)-b;a[9661063]=a[9661063]&-33;return}function fCu(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;e=(d[9661075]|0)*-5|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661056]=k;k=l+1&65535;b[4830522]=k;l=k&65535;h=(d[9661064+(l>>>13)|0]|0)<<13|l&8191;e=c[m+8208+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){o=0;p=k;break}i=gj[f&4095](h)|0;o=i;p=b[4830522]|0}else{o=a[e+(l&2047)|0]|0;p=k}}while(0);a[9661057]=o;b[4830522]=p+1&65535;b[4830528]=(b[4830528]|0)+(d[9661061]|0)&65535;p=c[2415264]|0;o=9661064+(p>>>13&7)|0;k=a[o]|0;if(((k&255)<<13|p&6144|0)==2088960){l=d[9661075]|0;c[2440610]=(c[2440610]|0)-l;c[2415269]=(c[2415269]|0)-l;q=a[o]|0}else{q=k}k=(q&255)<<13|p&8191;q=c[2388530]|0;o=c[q+16+(k>>>11<<2)>>2]|0;do{if((o|0)==0){l=c[q>>2]|0;if((l|0)==0){r=0;break}r=gj[l&4095](k)|0}else{r=a[o+(p&2047)|0]|0}}while(0);p=a[9661063]&-34;a[9661063]=p;o=a[9661060]|0;if((o&255)<(r&255)){s=p;t=s&93;u=o-r&255;v=u&-128;w=o<<24>>24==r<<24>>24;x=w?2:0;y=x|v;z=y|t;a[9661063]=z;return}k=p|1;a[9661063]=k;s=k;t=s&93;u=o-r&255;v=u&-128;w=o<<24>>24==r<<24>>24;x=w?2:0;y=x|v;z=y|t;a[9661063]=z;return}function fCv(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=(d[9661075]|0)*-7|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661056]=k;k=l+1&65535;b[4830522]=k;l=k&65535;h=(d[9661064+(l>>>13)|0]|0)<<13|l&8191;e=c[m+8208+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){o=0;p=k;break}i=gj[f&4095](h)|0;o=i;p=b[4830522]|0}else{o=a[e+(l&2047)|0]|0;p=k}}while(0);a[9661057]=o;b[4830522]=p+1&65535;b[4830528]=(b[4830528]|0)+(d[9661061]|0)&65535;p=c[2415264]|0;o=9661064+(p>>>13&7)|0;k=a[o]|0;if(((k&255)<<13|p&6144|0)==2088960){l=d[9661075]|0;c[2440610]=(c[2440610]|0)-l;c[2415269]=(c[2415269]|0)-l;q=a[o]|0}else{q=k}k=(q&255)<<13|p&8191;q=c[2388530]|0;o=c[q+16+(k>>>11<<2)>>2]|0;do{if((o|0)==0){l=c[q>>2]|0;if((l|0)==0){r=0;s=p;break}e=gj[l&4095](k)|0;r=e;s=c[2415264]|0}else{r=a[o+(p&2047)|0]|0;s=p}}while(0);p=r-1&255;a[9661063]=a[9661063]&93|p&-128|(p<<24>>24==0?2:0);r=9661064+(s>>>13&7)|0;o=a[r]|0;if(((o&255)<<13|s&6144|0)==2088960){k=d[9661075]|0;c[2440610]=(c[2440610]|0)-k;c[2415269]=(c[2415269]|0)-k;t=a[r]|0}else{t=o}o=(t&255)<<13|s&8191;t=c[2388530]|0;r=c[t+4112+(o>>>11<<2)>>2]|0;if((r|0)!=0){a[r+(s&2047)|0]=p;return}s=c[t+4>>2]|0;if((s|0)==0){return}gg[s&4095](o,p);return}function fCw(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=(d[9661075]|0)<<2;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=k;k=l+1&65535;b[4830522]=k;l=c[2415263]|0;c[2415264]=l;h=(d[9661065]|0)<<13|l&8191;e=c[m+16+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){a[9661063]=a[9661063]&-33;o=k;break}else{p=gj[f&4095](h)|0;q=5936;break}}else{p=a[e+(l&2047)|0]|0;q=5936}}while(0);do{if((q|0)==5936){a[9661063]=a[9661063]&-33;if((p&32)==0){o=b[4830522]|0;break}l=(d[9661075]|0)<<2;c[2440610]=(c[2440610]|0)-l;c[2415269]=(c[2415269]|0)-l;l=b[4830522]|0;e=l&65535;h=(d[9661064+(e>>>13)|0]|0)<<13|e&8191;k=c[2388530]|0;m=c[k+8208+(h>>>11<<2)>>2]|0;do{if((m|0)==0){f=c[k>>2]|0;if((f|0)==0){r=0;s=l;break}i=gj[f&4095](h)|0;r=i;s=b[4830522]|0}else{r=a[m+(e&2047)|0]|0;s=l}}while(0);b[4830528]=(s+1&65535)+(r<<24>>24)&65535;c[2415261]=c[2415264];return}}while(0);b[4830522]=o+1&65535;o=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-o;c[2415269]=(c[2415269]|0)-o;return}function fCx(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;break}m=gj[j&4095](g)|0;k=m;l=b[4830522]|0}else{k=a[i+(f&2047)|0]|0;l=e}}while(0);b[4830522]=l+1&65535;l=a[9661063]&-34;a[9661063]=l;e=a[9661061]|0;if((e&255)<(k&255)){n=l;o=n&93;p=e-k&255;q=p&-128;r=e<<24>>24==k<<24>>24;s=r?2:0;t=s|q;u=t|o;a[9661063]=u;return}f=l|1;a[9661063]=f;n=f;o=n&93;p=e-k&255;q=p&-128;r=e<<24>>24==k<<24>>24;s=r?2:0;t=s|q;u=t|o;a[9661063]=u;return}function fCy(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;e=(d[9661075]|0)*-7|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=(a[9661061]|0)+k&255;b[4830522]=l+1&65535;l=c[2415263]|0;k=(l&255|0)==255;h=a[9661065]|0;e=(h&255)<<13|l&8191;f=c[m+16+(e>>>11<<2)>>2]|0;do{if((f|0)==0){i=c[m>>2]|0;if((i|0)==0){o=0;p=h;q=l;break}g=gj[i&4095](e)|0;o=g;p=a[9661065]|0;q=c[2415263]|0}else{o=a[f+(l&2047)|0]|0;p=h;q=l}}while(0);l=o&255;o=(p&255)<<13;do{if(k){p=q+7937|0;h=p&8191|o;f=c[2388530]|0;e=c[f+16+(h>>>11<<2)>>2]|0;if((e|0)!=0){r=a[e+(p&2047)|0]|0;break}p=c[f>>2]|0;if((p|0)==0){r=0;break}r=gj[p&4095](h)|0}else{h=q+1|0;p=h&8191|o;f=c[2388530]|0;e=c[f+16+(p>>>11<<2)>>2]|0;if((e|0)!=0){r=a[e+(h&2047)|0]|0;break}h=c[f>>2]|0;if((h|0)==0){r=0;break}r=gj[h&4095](p)|0}}while(0);o=r&255;r=o<<8;q=r|l;c[2415264]=q;l=9661064+(o>>>5)|0;o=a[l]|0;if(((o&255)<<13|r&6144|0)==2088960){r=d[9661075]|0;c[2440610]=(c[2440610]|0)-r;c[2415269]=(c[2415269]|0)-r;s=a[l]|0}else{s=o}o=(s&255)<<13|q&8191;s=c[2388530]|0;l=c[s+16+(o>>>11<<2)>>2]|0;do{if((l|0)==0){r=c[s>>2]|0;if((r|0)==0){t=0;break}t=gj[r&4095](o)|0}else{t=a[l+(q&2047)|0]|0}}while(0);q=t&255;l=a[9661063]|0;o=l&255;if((o&32|0)==0){s=o&1^1;r=a[9661060]|0;k=r&255;p=k-q-s|0;if((o&8|0)==0){o=l&-66;h=(((r^t)&128&(p^k)|0)==0?o:o|64)|(p&65280|0)==0;a[9661063]=h;o=p&255;a[9661060]=o;u=h;v=o}else{o=(k&15)-(q&15)-s|0;s=(k&240)-(q&240)|0;k=(o&240|0)==0?o:o-6|0;o=(k&128|0)==0?s:s-16|0;s=(p&65280|0)==0?l|1:l&-2;a[9661063]=s;p=(((o&3840|0)==0?o:o+160|0)&240|k&15)&255;a[9661060]=p;k=d[9661075]|0;c[2440610]=(c[2440610]|0)-k;c[2415269]=(c[2415269]|0)-k;u=s;v=p}a[9661063]=u&93|v&-128|(v<<24>>24==0?2:0);return}v=l&-33;a[9661063]=v;a[9661052]=a[9661061]|0;l=c[2415263]|0;c[2415264]=l;u=(d[9661065]|0)<<13|l&8191;p=c[2388530]|0;s=c[p+16+(u>>>11<<2)>>2]|0;do{if((s|0)==0){k=c[p>>2]|0;if((k|0)==0){w=0;x=v;break}o=gj[k&4095](u)|0;w=o;x=a[9661063]|0}else{w=a[s+(l&2047)|0]|0;x=v}}while(0);v=w&255;l=x&255;s=l&1^1;u=v-q-s|0;if((l&8|0)==0){l=x&-66;p=(((w^t)&128&(u^v)|0)==0?l:l|64)|(u&65280|0)==0;a[9661063]=p;y=u&255;z=p}else{p=(v&15)-(q&15)-s|0;s=(v&240)-(q&240)|0;q=(p&240|0)==0?p:p-6|0;p=(q&128|0)==0?s:s-16|0;s=(u&65280|0)==0?x|1:x&-2;a[9661063]=s;x=d[9661075]|0;c[2440610]=(c[2440610]|0)-x;c[2415269]=(c[2415269]|0)-x;y=((p&3840|0)==0?p:p+160|0)&240|q&15;z=s}a[9661063]=(z&93|y&128|((y|0)==0?2:0))&255;z=c[2415264]|0;s=(d[9661065]|0)<<13|z&8191;q=y&255;y=c[2388530]|0;p=c[y+4112+(s>>>11<<2)>>2]|0;do{if((p|0)==0){x=c[y+4>>2]|0;if((x|0)==0){break}gg[x&4095](s,q)}else{a[p+(z&2047)|0]=q}}while(0);q=(d[9661075]|0)*-3|0;c[2440610]=q+(c[2440610]|0);c[2415269]=q+(c[2415269]|0);return}function fCz(){var b=0;b=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-b;c[2415269]=(c[2415269]|0)-b;a[9661063]=a[9661063]&-33;return}function fCA(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;a[9661063]=a[9661063]&-33;e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+16+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);h=k&255;k=(l&65535)+1|0;e=(d[9661064+(k>>>13&7)|0]|0)<<13|k&8191;f=c[m+16+(e>>>11<<2)>>2]|0;do{if((f|0)==0){i=c[m>>2]|0;if((i|0)==0){o=0;p=l;q=m;break}g=gj[i&4095](e)|0;o=g;p=b[4830522]|0;q=c[2388530]|0}else{o=a[f+(k&2047)|0]|0;p=l;q=m}}while(0);m=(o&255)<<8|h;h=(p&65535)+2|0;o=(d[9661064+(h>>>13&7)|0]|0)<<13|h&8191;l=c[q+16+(o>>>11<<2)>>2]|0;do{if((l|0)==0){k=c[q>>2]|0;if((k|0)==0){r=0;s=p;t=q;break}f=gj[k&4095](o)|0;r=f;s=b[4830522]|0;t=c[2388530]|0}else{r=a[l+(h&2047)|0]|0;s=p;t=q}}while(0);q=r&255;r=(s&65535)+3|0;p=(d[9661064+(r>>>13&7)|0]|0)<<13|r&8191;h=c[t+16+(p>>>11<<2)>>2]|0;do{if((h|0)==0){l=c[t>>2]|0;if((l|0)==0){u=0;v=s;w=t;break}o=gj[l&4095](p)|0;u=o;v=b[4830522]|0;w=c[2388530]|0}else{u=a[h+(r&2047)|0]|0;v=s;w=t}}while(0);t=(u&255)<<8|q;q=(v&65535)+4|0;u=(d[9661064+(q>>>13&7)|0]|0)<<13|q&8191;s=c[w+16+(u>>>11<<2)>>2]|0;do{if((s|0)==0){r=c[w>>2]|0;if((r|0)==0){x=0;y=v;z=w;break}h=gj[r&4095](u)|0;x=h;y=b[4830522]|0;z=c[2388530]|0}else{x=a[s+(q&2047)|0]|0;y=v;z=w}}while(0);w=x&255;x=(y&65535)+5|0;v=(d[9661064+(x>>>13&7)|0]|0)<<13|x&8191;q=c[z+16+(v>>>11<<2)>>2]|0;do{if((q|0)==0){s=c[z>>2]|0;if((s|0)==0){A=0;B=y;break}u=gj[s&4095](v)|0;A=u;B=b[4830522]|0}else{A=a[q+(x&2047)|0]|0;B=y}}while(0);y=(A&255)<<8|w;b[4830522]=B+6&65535;B=(y|0)==0?65536:y;y=ag((B*6|0)+17|0,d[9661075]|0)|0;c[2440610]=(c[2440610]|0)-y;c[2415269]=(c[2415269]|0)-y;y=m;m=B;B=0;while(1){w=m-1|0;A=B+t|0;x=9661064+(y>>>13&7)|0;q=a[x]|0;if(((q&255)<<13|y&6144|0)==2088960){v=d[9661075]|0;c[2440610]=(c[2440610]|0)-v;c[2415269]=(c[2415269]|0)-v;C=a[x]|0}else{C=q}q=(C&255)<<13|y&8191;x=c[2388530]|0;v=c[x+16+(q>>>11<<2)>>2]|0;do{if((v|0)==0){z=c[x>>2]|0;if((z|0)==0){D=0;break}D=gj[z&4095](q)|0}else{D=a[v+(y&2047)|0]|0}}while(0);v=9661064+(A>>>13&7)|0;q=a[v]|0;if(((q&255)<<13|A&6144|0)==2088960){x=d[9661075]|0;c[2440610]=(c[2440610]|0)-x;c[2415269]=(c[2415269]|0)-x;E=a[v]|0}else{E=q}q=(E&255)<<13|A&8191;v=c[2388530]|0;x=c[v+4112+(q>>>11<<2)>>2]|0;do{if((x|0)==0){z=c[v+4>>2]|0;if((z|0)==0){break}gg[z&4095](q,D)}else{a[x+(A&2047)|0]=D}}while(0);if((w|0)==0){break}else{y=y+1|0;m=w;B=B^1}}return}function fCB(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;e=(d[9661075]|0)<<2;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=k;b[4830522]=l+1&65535;l=c[2415263]|0;c[2415264]=l;k=(d[9661065]|0)<<13|l&8191;h=c[m+16+(k>>>11<<2)>>2]|0;do{if((h|0)==0){e=c[m>>2]|0;if((e|0)==0){o=0;break}o=gj[e&4095](k)|0}else{o=a[h+(l&2047)|0]|0}}while(0);l=a[9661063]&-34;a[9661063]=l;h=a[9661061]|0;if((h&255)<(o&255)){p=l;q=p&93;r=h-o&255;s=r&-128;t=h<<24>>24==o<<24>>24;u=t?2:0;v=u|s;w=v|q;a[9661063]=w;return}k=l|1;a[9661063]=k;p=k;q=p&93;r=h-o&255;s=r&-128;t=h<<24>>24==o<<24>>24;u=t?2:0;v=u|s;w=v|q;a[9661063]=w;return}function fCC(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=(d[9661075]|0)<<2;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=k;b[4830522]=l+1&65535;l=c[2415263]|0;c[2415264]=l;k=(d[9661065]|0)<<13|l&8191;h=c[m+16+(k>>>11<<2)>>2]|0;do{if((h|0)==0){e=c[m>>2]|0;if((e|0)==0){o=0;break}o=gj[e&4095](k)|0}else{o=a[h+(l&2047)|0]|0}}while(0);l=o&255;h=a[9661063]|0;k=h&255;if((k&32|0)==0){m=k&1^1;e=a[9661060]|0;f=e&255;i=f-l-m|0;if((k&8|0)==0){k=h&-66;g=(((e^o)&128&(i^f)|0)==0?k:k|64)|(i&65280|0)==0;a[9661063]=g;k=i&255;a[9661060]=k;p=g;q=k}else{k=(f&15)-(l&15)-m|0;m=(f&240)-(l&240)|0;f=(k&240|0)==0?k:k-6|0;k=(f&128|0)==0?m:m-16|0;m=(i&65280|0)==0?h|1:h&-2;a[9661063]=m;i=(((k&3840|0)==0?k:k+160|0)&240|f&15)&255;a[9661060]=i;f=d[9661075]|0;c[2440610]=(c[2440610]|0)-f;c[2415269]=(c[2415269]|0)-f;p=m;q=i}a[9661063]=p&93|q&-128|(q<<24>>24==0?2:0);return}q=h&-33;a[9661063]=q;a[9661052]=a[9661061]|0;h=c[2415263]|0;c[2415264]=h;p=(d[9661065]|0)<<13|h&8191;i=c[2388530]|0;m=c[i+16+(p>>>11<<2)>>2]|0;do{if((m|0)==0){f=c[i>>2]|0;if((f|0)==0){r=0;s=q;break}k=gj[f&4095](p)|0;r=k;s=a[9661063]|0}else{r=a[m+(h&2047)|0]|0;s=q}}while(0);q=r&255;h=s&255;m=h&1^1;p=q-l-m|0;if((h&8|0)==0){h=s&-66;i=(((r^o)&128&(p^q)|0)==0?h:h|64)|(p&65280|0)==0;a[9661063]=i;t=p&255;u=i}else{i=(q&15)-(l&15)-m|0;m=(q&240)-(l&240)|0;l=(i&240|0)==0?i:i-6|0;i=(l&128|0)==0?m:m-16|0;m=(p&65280|0)==0?s|1:s&-2;a[9661063]=m;s=d[9661075]|0;c[2440610]=(c[2440610]|0)-s;c[2415269]=(c[2415269]|0)-s;t=((i&3840|0)==0?i:i+160|0)&240|l&15;u=m}a[9661063]=(u&93|t&128|((t|0)==0?2:0))&255;u=c[2415264]|0;m=(d[9661065]|0)<<13|u&8191;l=t&255;t=c[2388530]|0;i=c[t+4112+(m>>>11<<2)>>2]|0;do{if((i|0)==0){s=c[t+4>>2]|0;if((s|0)==0){break}gg[s&4095](m,l)}else{a[i+(u&2047)|0]=l}}while(0);l=(d[9661075]|0)*-3|0;c[2440610]=l+(c[2440610]|0);c[2415269]=l+(c[2415269]|0);return}function fCD(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=(d[9661075]|0)*-6|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=k;b[4830522]=l+1&65535;l=c[2415263]|0;c[2415264]=l;k=a[9661065]|0;h=(k&255)<<13|l&8191;e=c[m+16+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){o=0;p=k;q=l;r=m;break}i=gj[f&4095](h)|0;o=i;p=a[9661065]|0;q=c[2415264]|0;r=c[2388530]|0}else{o=a[e+(l&2047)|0]|0;p=k;q=l;r=m}}while(0);m=o+1&255;a[9661063]=a[9661063]&93|m&-128|(m<<24>>24==0?2:0);o=(p&255)<<13|q&8191;p=c[r+4112+(o>>>11<<2)>>2]|0;if((p|0)!=0){a[p+(q&2047)|0]=m;return}q=c[r+4>>2]|0;if((q|0)==0){return}gg[q&4095](o,m);return}function fCE(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=(d[9661075]|0)*-7|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=k;b[4830522]=l+1&65535;l=c[2415263]|0;c[2415264]=l;k=a[9661065]|0;h=(k&255)<<13|l&8191;e=c[m+16+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){o=0;p=k;q=l;r=m;break}i=gj[f&4095](h)|0;o=i;p=a[9661065]|0;q=c[2415264]|0;r=c[2388530]|0}else{o=a[e+(l&2047)|0]|0;p=k;q=l;r=m}}while(0);a[9661063]=a[9661063]&-33;m=o|64;o=(p&255)<<13|q&8191;p=c[r+4112+(o>>>11<<2)>>2]|0;if((p|0)!=0){a[p+(q&2047)|0]=m;return}q=c[r+4>>2]|0;if((q|0)==0){return}gg[q&4095](o,m);return}function fCF(){var b=0,e=0;b=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-b;c[2415269]=(c[2415269]|0)-b;b=a[9661063]|0;e=(a[9661061]|0)+1&255;a[9661061]=e;a[9661063]=e&-128|b&93|(e<<24>>24==0?2:0);return}function fCG(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;break}m=gj[j&4095](g)|0;k=m;l=b[4830522]|0}else{k=a[i+(f&2047)|0]|0;l=e}}while(0);e=k&255;b[4830522]=l+1&65535;l=a[9661063]|0;f=l&255;if((f&32|0)==0){i=f&1^1;g=a[9661060]|0;h=g&255;m=h-e-i|0;if((f&8|0)==0){f=l&-66;j=(((g^k)&128&(m^h)|0)==0?f:f|64)|(m&65280|0)==0;a[9661063]=j;f=m&255;a[9661060]=f;n=j;o=f}else{f=(h&15)-(e&15)-i|0;i=(h&240)-(e&240)|0;h=(f&240|0)==0?f:f-6|0;f=(h&128|0)==0?i:i-16|0;i=(m&65280|0)==0?l|1:l&-2;a[9661063]=i;m=(((f&3840|0)==0?f:f+160|0)&240|h&15)&255;a[9661060]=m;h=d[9661075]|0;c[2440610]=(c[2440610]|0)-h;c[2415269]=(c[2415269]|0)-h;n=i;o=m}a[9661063]=n&93|o&-128|(o<<24>>24==0?2:0);return}o=l&-33;a[9661063]=o;a[9661052]=a[9661061]|0;l=c[2415263]|0;c[2415264]=l;n=(d[9661065]|0)<<13|l&8191;m=c[2388530]|0;i=c[m+16+(n>>>11<<2)>>2]|0;do{if((i|0)==0){h=c[m>>2]|0;if((h|0)==0){p=0;q=o;break}f=gj[h&4095](n)|0;p=f;q=a[9661063]|0}else{p=a[i+(l&2047)|0]|0;q=o}}while(0);o=p&255;l=q&255;i=l&1^1;n=o-e-i|0;if((l&8|0)==0){l=q&-66;m=(((p^k)&128&(n^o)|0)==0?l:l|64)|(n&65280|0)==0;a[9661063]=m;r=n&255;s=m}else{m=(o&15)-(e&15)-i|0;i=(o&240)-(e&240)|0;e=(m&240|0)==0?m:m-6|0;m=(e&128|0)==0?i:i-16|0;i=(n&65280|0)==0?q|1:q&-2;a[9661063]=i;q=d[9661075]|0;c[2440610]=(c[2440610]|0)-q;c[2415269]=(c[2415269]|0)-q;r=((m&3840|0)==0?m:m+160|0)&240|e&15;s=i}a[9661063]=(s&93|r&128|((r|0)==0?2:0))&255;s=c[2415264]|0;i=(d[9661065]|0)<<13|s&8191;e=r&255;r=c[2388530]|0;m=c[r+4112+(i>>>11<<2)>>2]|0;do{if((m|0)==0){q=c[r+4>>2]|0;if((q|0)==0){break}gg[q&4095](i,e)}else{a[m+(s&2047)|0]=e}}while(0);e=(d[9661075]|0)*-3|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);return}function fCH(){var b=0;b=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-b;c[2415269]=(c[2415269]|0)-b;a[9661063]=a[9661063]&-33;return}function fCI(){var b=0;b=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-b;c[2415269]=(c[2415269]|0)-b;a[9661063]=a[9661063]&-33;return}function fCJ(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;e=(d[9661075]|0)*-5|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661056]=k;k=l+1&65535;b[4830522]=k;l=k&65535;h=(d[9661064+(l>>>13)|0]|0)<<13|l&8191;e=c[m+8208+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){o=0;p=k;break}i=gj[f&4095](h)|0;o=i;p=b[4830522]|0}else{o=a[e+(l&2047)|0]|0;p=k}}while(0);a[9661057]=o;b[4830522]=p+1&65535;p=c[2415264]|0;o=9661064+(p>>>13&7)|0;k=a[o]|0;if(((k&255)<<13|p&6144|0)==2088960){l=d[9661075]|0;c[2440610]=(c[2440610]|0)-l;c[2415269]=(c[2415269]|0)-l;q=a[o]|0}else{q=k}k=(q&255)<<13|p&8191;q=c[2388530]|0;o=c[q+16+(k>>>11<<2)>>2]|0;do{if((o|0)==0){l=c[q>>2]|0;if((l|0)==0){r=0;break}r=gj[l&4095](k)|0}else{r=a[o+(p&2047)|0]|0}}while(0);p=a[9661063]&-34;a[9661063]=p;o=a[9661061]|0;if((o&255)<(r&255)){s=p;t=s&93;u=o-r&255;v=u&-128;w=o<<24>>24==r<<24>>24;x=w?2:0;y=x|v;z=y|t;a[9661063]=z;return}k=p|1;a[9661063]=k;s=k;t=s&93;u=o-r&255;v=u&-128;w=o<<24>>24==r<<24>>24;x=w?2:0;y=x|v;z=y|t;a[9661063]=z;return}function fCK(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;e=(d[9661075]|0)*-5|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661056]=k;k=l+1&65535;b[4830522]=k;l=k&65535;h=(d[9661064+(l>>>13)|0]|0)<<13|l&8191;e=c[m+8208+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){o=0;p=k;break}i=gj[f&4095](h)|0;o=i;p=b[4830522]|0}else{o=a[e+(l&2047)|0]|0;p=k}}while(0);a[9661057]=o;b[4830522]=p+1&65535;p=c[2415264]|0;o=9661064+(p>>>13&7)|0;k=a[o]|0;if(((k&255)<<13|p&6144|0)==2088960){l=d[9661075]|0;c[2440610]=(c[2440610]|0)-l;c[2415269]=(c[2415269]|0)-l;q=a[o]|0}else{q=k}k=(q&255)<<13|p&8191;q=c[2388530]|0;o=c[q+16+(k>>>11<<2)>>2]|0;do{if((o|0)==0){l=c[q>>2]|0;if((l|0)==0){r=0;break}r=gj[l&4095](k)|0}else{r=a[o+(p&2047)|0]|0}}while(0);p=r&255;o=a[9661063]|0;k=o&255;if((k&32|0)==0){q=k&1^1;l=a[9661060]|0;e=l&255;h=e-p-q|0;if((k&8|0)==0){k=o&-66;m=(((l^r)&128&(h^e)|0)==0?k:k|64)|(h&65280|0)==0;a[9661063]=m;k=h&255;a[9661060]=k;s=m;t=k}else{k=(e&15)-(p&15)-q|0;q=(e&240)-(p&240)|0;e=(k&240|0)==0?k:k-6|0;k=(e&128|0)==0?q:q-16|0;q=(h&65280|0)==0?o|1:o&-2;a[9661063]=q;h=(((k&3840|0)==0?k:k+160|0)&240|e&15)&255;a[9661060]=h;e=d[9661075]|0;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;s=q;t=h}a[9661063]=s&93|t&-128|(t<<24>>24==0?2:0);return}t=o&-33;a[9661063]=t;a[9661052]=a[9661061]|0;o=c[2415263]|0;c[2415264]=o;s=(d[9661065]|0)<<13|o&8191;h=c[2388530]|0;q=c[h+16+(s>>>11<<2)>>2]|0;do{if((q|0)==0){e=c[h>>2]|0;if((e|0)==0){u=0;v=t;break}k=gj[e&4095](s)|0;u=k;v=a[9661063]|0}else{u=a[q+(o&2047)|0]|0;v=t}}while(0);t=u&255;o=v&255;q=o&1^1;s=t-p-q|0;if((o&8|0)==0){o=v&-66;h=(((u^r)&128&(s^t)|0)==0?o:o|64)|(s&65280|0)==0;a[9661063]=h;w=s&255;x=h}else{h=(t&15)-(p&15)-q|0;q=(t&240)-(p&240)|0;p=(h&240|0)==0?h:h-6|0;h=(p&128|0)==0?q:q-16|0;q=(s&65280|0)==0?v|1:v&-2;a[9661063]=q;v=d[9661075]|0;c[2440610]=(c[2440610]|0)-v;c[2415269]=(c[2415269]|0)-v;w=((h&3840|0)==0?h:h+160|0)&240|p&15;x=q}a[9661063]=(x&93|w&128|((w|0)==0?2:0))&255;x=c[2415264]|0;q=(d[9661065]|0)<<13|x&8191;p=w&255;w=c[2388530]|0;h=c[w+4112+(q>>>11<<2)>>2]|0;do{if((h|0)==0){v=c[w+4>>2]|0;if((v|0)==0){break}gg[v&4095](q,p)}else{a[h+(x&2047)|0]=p}}while(0);p=(d[9661075]|0)*-3|0;c[2440610]=p+(c[2440610]|0);c[2415269]=p+(c[2415269]|0);return}function fCL(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=(d[9661075]|0)*-7|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661056]=k;k=l+1&65535;b[4830522]=k;l=k&65535;h=(d[9661064+(l>>>13)|0]|0)<<13|l&8191;e=c[m+8208+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){o=0;p=k;break}i=gj[f&4095](h)|0;o=i;p=b[4830522]|0}else{o=a[e+(l&2047)|0]|0;p=k}}while(0);a[9661057]=o;b[4830522]=p+1&65535;p=c[2415264]|0;o=9661064+(p>>>13&7)|0;k=a[o]|0;if(((k&255)<<13|p&6144|0)==2088960){l=d[9661075]|0;c[2440610]=(c[2440610]|0)-l;c[2415269]=(c[2415269]|0)-l;q=a[o]|0}else{q=k}k=(q&255)<<13|p&8191;q=c[2388530]|0;o=c[q+16+(k>>>11<<2)>>2]|0;do{if((o|0)==0){l=c[q>>2]|0;if((l|0)==0){r=0;s=p;break}e=gj[l&4095](k)|0;r=e;s=c[2415264]|0}else{r=a[o+(p&2047)|0]|0;s=p}}while(0);p=r+1&255;a[9661063]=a[9661063]&93|p&-128|(p<<24>>24==0?2:0);r=9661064+(s>>>13&7)|0;o=a[r]|0;if(((o&255)<<13|s&6144|0)==2088960){k=d[9661075]|0;c[2440610]=(c[2440610]|0)-k;c[2415269]=(c[2415269]|0)-k;t=a[r]|0}else{t=o}o=(t&255)<<13|s&8191;t=c[2388530]|0;r=c[t+4112+(o>>>11<<2)>>2]|0;if((r|0)!=0){a[r+(s&2047)|0]=p;return}s=c[t+4>>2]|0;if((s|0)==0){return}gg[s&4095](o,p);return}function fCM(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=(d[9661075]|0)<<2;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=k;k=l+1&65535;b[4830522]=k;l=c[2415263]|0;c[2415264]=l;h=(d[9661065]|0)<<13|l&8191;e=c[m+16+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){a[9661063]=a[9661063]&-33;o=k;break}else{p=gj[f&4095](h)|0;q=6225;break}}else{p=a[e+(l&2047)|0]|0;q=6225}}while(0);do{if((q|0)==6225){a[9661063]=a[9661063]&-33;if((p&64)==0){o=b[4830522]|0;break}l=(d[9661075]|0)<<2;c[2440610]=(c[2440610]|0)-l;c[2415269]=(c[2415269]|0)-l;l=b[4830522]|0;e=l&65535;h=(d[9661064+(e>>>13)|0]|0)<<13|e&8191;k=c[2388530]|0;m=c[k+8208+(h>>>11<<2)>>2]|0;do{if((m|0)==0){f=c[k>>2]|0;if((f|0)==0){r=0;s=l;break}i=gj[f&4095](h)|0;r=i;s=b[4830522]|0}else{r=a[m+(e&2047)|0]|0;s=l}}while(0);b[4830528]=(s+1&65535)+(r<<24>>24)&65535;c[2415261]=c[2415264];return}}while(0);b[4830522]=o+1&65535;o=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-o;c[2415269]=(c[2415269]|0)-o;return}function fCN(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=a[9661063]|0;a[9661063]=e&-33;if((e&2)==0){b[4830522]=(b[4830522]|0)+1&65535;e=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;return}e=(d[9661075]|0)<<2;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;break}m=gj[j&4095](g)|0;k=m;l=b[4830522]|0}else{k=a[i+(f&2047)|0]|0;l=e}}while(0);b[4830528]=(l+1&65535)+(k<<24>>24)&65535;c[2415261]=c[2415264];return}function fCO(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;e=(d[9661075]|0)*-7|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=k;b[4830522]=l+1&65535;l=c[2415263]|0;k=(l&255|0)==255;h=a[9661065]|0;e=(h&255)<<13|l&8191;f=c[m+16+(e>>>11<<2)>>2]|0;do{if((f|0)==0){i=c[m>>2]|0;if((i|0)==0){o=0;p=h;q=l;break}g=gj[i&4095](e)|0;o=g;p=a[9661065]|0;q=c[2415263]|0}else{o=a[f+(l&2047)|0]|0;p=h;q=l}}while(0);l=o&255;o=(p&255)<<13;do{if(k){p=q+7937|0;h=p&8191|o;f=c[2388530]|0;e=c[f+16+(h>>>11<<2)>>2]|0;if((e|0)!=0){r=a[e+(p&2047)|0]|0;break}p=c[f>>2]|0;if((p|0)==0){r=0;break}r=gj[p&4095](h)|0}else{h=q+1|0;p=h&8191|o;f=c[2388530]|0;e=c[f+16+(p>>>11<<2)>>2]|0;if((e|0)!=0){r=a[e+(h&2047)|0]|0;break}h=c[f>>2]|0;if((h|0)==0){r=0;break}r=gj[h&4095](p)|0}}while(0);o=(r&255)<<8|l;c[2415264]=o;b[4830528]=(o&65535)+(d[9661062]|0)&65535;o=c[2415264]|0;l=9661064+(o>>>13&7)|0;r=a[l]|0;if(((r&255)<<13|o&6144|0)==2088960){q=d[9661075]|0;c[2440610]=(c[2440610]|0)-q;c[2415269]=(c[2415269]|0)-q;s=a[l]|0}else{s=r}r=(s&255)<<13|o&8191;s=c[2388530]|0;l=c[s+16+(r>>>11<<2)>>2]|0;do{if((l|0)==0){q=c[s>>2]|0;if((q|0)==0){t=0;break}t=gj[q&4095](r)|0}else{t=a[l+(o&2047)|0]|0}}while(0);o=t&255;l=a[9661063]|0;r=l&255;if((r&32|0)==0){s=r&1^1;q=a[9661060]|0;k=q&255;p=k-o-s|0;if((r&8|0)==0){r=l&-66;h=(((q^t)&128&(p^k)|0)==0?r:r|64)|(p&65280|0)==0;a[9661063]=h;r=p&255;a[9661060]=r;u=h;v=r}else{r=(k&15)-(o&15)-s|0;s=(k&240)-(o&240)|0;k=(r&240|0)==0?r:r-6|0;r=(k&128|0)==0?s:s-16|0;s=(p&65280|0)==0?l|1:l&-2;a[9661063]=s;p=(((r&3840|0)==0?r:r+160|0)&240|k&15)&255;a[9661060]=p;k=d[9661075]|0;c[2440610]=(c[2440610]|0)-k;c[2415269]=(c[2415269]|0)-k;u=s;v=p}a[9661063]=u&93|v&-128|(v<<24>>24==0?2:0);return}v=l&-33;a[9661063]=v;a[9661052]=a[9661061]|0;l=c[2415263]|0;c[2415264]=l;u=(d[9661065]|0)<<13|l&8191;p=c[2388530]|0;s=c[p+16+(u>>>11<<2)>>2]|0;do{if((s|0)==0){k=c[p>>2]|0;if((k|0)==0){w=0;x=v;break}r=gj[k&4095](u)|0;w=r;x=a[9661063]|0}else{w=a[s+(l&2047)|0]|0;x=v}}while(0);v=w&255;l=x&255;s=l&1^1;u=v-o-s|0;if((l&8|0)==0){l=x&-66;p=(((w^t)&128&(u^v)|0)==0?l:l|64)|(u&65280|0)==0;a[9661063]=p;y=u&255;z=p}else{p=(v&15)-(o&15)-s|0;s=(v&240)-(o&240)|0;o=(p&240|0)==0?p:p-6|0;p=(o&128|0)==0?s:s-16|0;s=(u&65280|0)==0?x|1:x&-2;a[9661063]=s;x=d[9661075]|0;c[2440610]=(c[2440610]|0)-x;c[2415269]=(c[2415269]|0)-x;y=((p&3840|0)==0?p:p+160|0)&240|o&15;z=s}a[9661063]=(z&93|y&128|((y|0)==0?2:0))&255;z=c[2415264]|0;s=(d[9661065]|0)<<13|z&8191;o=y&255;y=c[2388530]|0;p=c[y+4112+(s>>>11<<2)>>2]|0;do{if((p|0)==0){x=c[y+4>>2]|0;if((x|0)==0){break}gg[x&4095](s,o)}else{a[p+(z&2047)|0]=o}}while(0);o=(d[9661075]|0)*-3|0;c[2440610]=o+(c[2440610]|0);c[2415269]=o+(c[2415269]|0);return}function fCP(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;e=(d[9661075]|0)*-7|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=k;b[4830522]=l+1&65535;l=c[2415263]|0;k=(l&255|0)==255;h=a[9661065]|0;e=(h&255)<<13|l&8191;f=c[m+16+(e>>>11<<2)>>2]|0;do{if((f|0)==0){i=c[m>>2]|0;if((i|0)==0){o=0;p=h;q=l;break}g=gj[i&4095](e)|0;o=g;p=a[9661065]|0;q=c[2415263]|0}else{o=a[f+(l&2047)|0]|0;p=h;q=l}}while(0);l=o&255;o=(p&255)<<13;do{if(k){p=q+7937|0;h=p&8191|o;f=c[2388530]|0;e=c[f+16+(h>>>11<<2)>>2]|0;if((e|0)!=0){r=a[e+(p&2047)|0]|0;break}p=c[f>>2]|0;if((p|0)==0){r=0;break}r=gj[p&4095](h)|0}else{h=q+1|0;p=h&8191|o;f=c[2388530]|0;e=c[f+16+(p>>>11<<2)>>2]|0;if((e|0)!=0){r=a[e+(h&2047)|0]|0;break}h=c[f>>2]|0;if((h|0)==0){r=0;break}r=gj[h&4095](p)|0}}while(0);o=r&255;r=o<<8;q=r|l;c[2415264]=q;l=9661064+(o>>>5)|0;o=a[l]|0;if(((o&255)<<13|r&6144|0)==2088960){r=d[9661075]|0;c[2440610]=(c[2440610]|0)-r;c[2415269]=(c[2415269]|0)-r;s=a[l]|0}else{s=o}o=(s&255)<<13|q&8191;s=c[2388530]|0;l=c[s+16+(o>>>11<<2)>>2]|0;do{if((l|0)==0){r=c[s>>2]|0;if((r|0)==0){t=0;break}t=gj[r&4095](o)|0}else{t=a[l+(q&2047)|0]|0}}while(0);q=t&255;l=a[9661063]|0;o=l&255;if((o&32|0)==0){s=o&1^1;r=a[9661060]|0;k=r&255;p=k-q-s|0;if((o&8|0)==0){o=l&-66;h=(((r^t)&128&(p^k)|0)==0?o:o|64)|(p&65280|0)==0;a[9661063]=h;o=p&255;a[9661060]=o;u=h;v=o}else{o=(k&15)-(q&15)-s|0;s=(k&240)-(q&240)|0;k=(o&240|0)==0?o:o-6|0;o=(k&128|0)==0?s:s-16|0;s=(p&65280|0)==0?l|1:l&-2;a[9661063]=s;p=(((o&3840|0)==0?o:o+160|0)&240|k&15)&255;a[9661060]=p;k=d[9661075]|0;c[2440610]=(c[2440610]|0)-k;c[2415269]=(c[2415269]|0)-k;u=s;v=p}a[9661063]=u&93|v&-128|(v<<24>>24==0?2:0);return}v=l&-33;a[9661063]=v;a[9661052]=a[9661061]|0;l=c[2415263]|0;c[2415264]=l;u=(d[9661065]|0)<<13|l&8191;p=c[2388530]|0;s=c[p+16+(u>>>11<<2)>>2]|0;do{if((s|0)==0){k=c[p>>2]|0;if((k|0)==0){w=0;x=v;break}o=gj[k&4095](u)|0;w=o;x=a[9661063]|0}else{w=a[s+(l&2047)|0]|0;x=v}}while(0);v=w&255;l=x&255;s=l&1^1;u=v-q-s|0;if((l&8|0)==0){l=x&-66;p=(((w^t)&128&(u^v)|0)==0?l:l|64)|(u&65280|0)==0;a[9661063]=p;y=u&255;z=p}else{p=(v&15)-(q&15)-s|0;s=(v&240)-(q&240)|0;q=(p&240|0)==0?p:p-6|0;p=(q&128|0)==0?s:s-16|0;s=(u&65280|0)==0?x|1:x&-2;a[9661063]=s;x=d[9661075]|0;c[2440610]=(c[2440610]|0)-x;c[2415269]=(c[2415269]|0)-x;y=((p&3840|0)==0?p:p+160|0)&240|q&15;z=s}a[9661063]=(z&93|y&128|((y|0)==0?2:0))&255;z=c[2415264]|0;s=(d[9661065]|0)<<13|z&8191;q=y&255;y=c[2388530]|0;p=c[y+4112+(s>>>11<<2)>>2]|0;do{if((p|0)==0){x=c[y+4>>2]|0;if((x|0)==0){break}gg[x&4095](s,q)}else{a[p+(z&2047)|0]=q}}while(0);q=(d[9661075]|0)*-3|0;c[2440610]=q+(c[2440610]|0);c[2415269]=q+(c[2415269]|0);return}function fCQ(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;a[9661063]=a[9661063]&-33;e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+16+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);h=k&255;k=(l&65535)+1|0;e=(d[9661064+(k>>>13&7)|0]|0)<<13|k&8191;f=c[m+16+(e>>>11<<2)>>2]|0;do{if((f|0)==0){i=c[m>>2]|0;if((i|0)==0){o=0;p=l;q=m;break}g=gj[i&4095](e)|0;o=g;p=b[4830522]|0;q=c[2388530]|0}else{o=a[f+(k&2047)|0]|0;p=l;q=m}}while(0);m=(o&255)<<8|h;h=(p&65535)+2|0;o=(d[9661064+(h>>>13&7)|0]|0)<<13|h&8191;l=c[q+16+(o>>>11<<2)>>2]|0;do{if((l|0)==0){k=c[q>>2]|0;if((k|0)==0){r=0;s=p;t=q;break}f=gj[k&4095](o)|0;r=f;s=b[4830522]|0;t=c[2388530]|0}else{r=a[l+(h&2047)|0]|0;s=p;t=q}}while(0);q=r&255;r=(s&65535)+3|0;p=(d[9661064+(r>>>13&7)|0]|0)<<13|r&8191;h=c[t+16+(p>>>11<<2)>>2]|0;do{if((h|0)==0){l=c[t>>2]|0;if((l|0)==0){u=0;v=s;w=t;break}o=gj[l&4095](p)|0;u=o;v=b[4830522]|0;w=c[2388530]|0}else{u=a[h+(r&2047)|0]|0;v=s;w=t}}while(0);t=(u&255)<<8|q;q=(v&65535)+4|0;u=(d[9661064+(q>>>13&7)|0]|0)<<13|q&8191;s=c[w+16+(u>>>11<<2)>>2]|0;do{if((s|0)==0){r=c[w>>2]|0;if((r|0)==0){x=0;y=v;z=w;break}h=gj[r&4095](u)|0;x=h;y=b[4830522]|0;z=c[2388530]|0}else{x=a[s+(q&2047)|0]|0;y=v;z=w}}while(0);w=x&255;x=(y&65535)+5|0;v=(d[9661064+(x>>>13&7)|0]|0)<<13|x&8191;q=c[z+16+(v>>>11<<2)>>2]|0;do{if((q|0)==0){s=c[z>>2]|0;if((s|0)==0){A=0;B=y;break}u=gj[s&4095](v)|0;A=u;B=b[4830522]|0}else{A=a[q+(x&2047)|0]|0;B=y}}while(0);y=(A&255)<<8|w;b[4830522]=B+6&65535;B=(y|0)==0?65536:y;y=ag((B*6|0)+17|0,d[9661075]|0)|0;c[2440610]=(c[2440610]|0)-y;c[2415269]=(c[2415269]|0)-y;y=t;t=B;B=0;while(1){w=t-1|0;A=B+m|0;x=9661064+(A>>>13&7)|0;q=a[x]|0;if(((q&255)<<13|A&6144|0)==2088960){v=d[9661075]|0;c[2440610]=(c[2440610]|0)-v;c[2415269]=(c[2415269]|0)-v;C=a[x]|0}else{C=q}q=(C&255)<<13|A&8191;x=c[2388530]|0;v=c[x+16+(q>>>11<<2)>>2]|0;do{if((v|0)==0){z=c[x>>2]|0;if((z|0)==0){D=0;break}D=gj[z&4095](q)|0}else{D=a[v+(A&2047)|0]|0}}while(0);A=9661064+(y>>>13&7)|0;v=a[A]|0;if(((v&255)<<13|y&6144|0)==2088960){q=d[9661075]|0;c[2440610]=(c[2440610]|0)-q;c[2415269]=(c[2415269]|0)-q;E=a[A]|0}else{E=v}v=(E&255)<<13|y&8191;A=c[2388530]|0;q=c[A+4112+(v>>>11<<2)>>2]|0;do{if((q|0)==0){x=c[A+4>>2]|0;if((x|0)==0){break}gg[x&4095](v,D)}else{a[q+(y&2047)|0]=D}}while(0);if((w|0)==0){break}else{y=y+1|0;t=w;B=B^1}}return}function fCR(){var b=0;b=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-b;c[2415269]=(c[2415269]|0)-b;a[9661063]=a[9661063]|32;return}function fCS(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=(d[9661075]|0)<<2;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=(a[9661061]|0)+k&255;b[4830522]=l+1&65535;l=c[2415263]|0;c[2415264]=l;k=(d[9661065]|0)<<13|l&8191;h=c[m+16+(k>>>11<<2)>>2]|0;do{if((h|0)==0){e=c[m>>2]|0;if((e|0)==0){o=0;break}o=gj[e&4095](k)|0}else{o=a[h+(l&2047)|0]|0}}while(0);l=o&255;h=a[9661063]|0;k=h&255;if((k&32|0)==0){m=k&1^1;e=a[9661060]|0;f=e&255;i=f-l-m|0;if((k&8|0)==0){k=h&-66;g=(((e^o)&128&(i^f)|0)==0?k:k|64)|(i&65280|0)==0;a[9661063]=g;k=i&255;a[9661060]=k;p=g;q=k}else{k=(f&15)-(l&15)-m|0;m=(f&240)-(l&240)|0;f=(k&240|0)==0?k:k-6|0;k=(f&128|0)==0?m:m-16|0;m=(i&65280|0)==0?h|1:h&-2;a[9661063]=m;i=(((k&3840|0)==0?k:k+160|0)&240|f&15)&255;a[9661060]=i;f=d[9661075]|0;c[2440610]=(c[2440610]|0)-f;c[2415269]=(c[2415269]|0)-f;p=m;q=i}a[9661063]=p&93|q&-128|(q<<24>>24==0?2:0);return}q=h&-33;a[9661063]=q;a[9661052]=a[9661061]|0;h=c[2415263]|0;c[2415264]=h;p=(d[9661065]|0)<<13|h&8191;i=c[2388530]|0;m=c[i+16+(p>>>11<<2)>>2]|0;do{if((m|0)==0){f=c[i>>2]|0;if((f|0)==0){r=0;s=q;break}k=gj[f&4095](p)|0;r=k;s=a[9661063]|0}else{r=a[m+(h&2047)|0]|0;s=q}}while(0);q=r&255;h=s&255;m=h&1^1;p=q-l-m|0;if((h&8|0)==0){h=s&-66;i=(((r^o)&128&(p^q)|0)==0?h:h|64)|(p&65280|0)==0;a[9661063]=i;t=p&255;u=i}else{i=(q&15)-(l&15)-m|0;m=(q&240)-(l&240)|0;l=(i&240|0)==0?i:i-6|0;i=(l&128|0)==0?m:m-16|0;m=(p&65280|0)==0?s|1:s&-2;a[9661063]=m;s=d[9661075]|0;c[2440610]=(c[2440610]|0)-s;c[2415269]=(c[2415269]|0)-s;t=((i&3840|0)==0?i:i+160|0)&240|l&15;u=m}a[9661063]=(u&93|t&128|((t|0)==0?2:0))&255;u=c[2415264]|0;m=(d[9661065]|0)<<13|u&8191;l=t&255;t=c[2388530]|0;i=c[t+4112+(m>>>11<<2)>>2]|0;do{if((i|0)==0){s=c[t+4>>2]|0;if((s|0)==0){break}gg[s&4095](m,l)}else{a[i+(u&2047)|0]=l}}while(0);l=(d[9661075]|0)*-3|0;c[2440610]=l+(c[2440610]|0);c[2415269]=l+(c[2415269]|0);return}function fCT(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=(d[9661075]|0)*-6|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=(a[9661061]|0)+k&255;b[4830522]=l+1&65535;l=c[2415263]|0;c[2415264]=l;k=a[9661065]|0;h=(k&255)<<13|l&8191;e=c[m+16+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){o=0;p=k;q=l;r=m;break}i=gj[f&4095](h)|0;o=i;p=a[9661065]|0;q=c[2415264]|0;r=c[2388530]|0}else{o=a[e+(l&2047)|0]|0;p=k;q=l;r=m}}while(0);m=o+1&255;a[9661063]=a[9661063]&93|m&-128|(m<<24>>24==0?2:0);o=(p&255)<<13|q&8191;p=c[r+4112+(o>>>11<<2)>>2]|0;if((p|0)!=0){a[p+(q&2047)|0]=m;return}q=c[r+4>>2]|0;if((q|0)==0){return}gg[q&4095](o,m);return}function fCU(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=(d[9661075]|0)*-7|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=k;b[4830522]=l+1&65535;l=c[2415263]|0;c[2415264]=l;k=a[9661065]|0;h=(k&255)<<13|l&8191;e=c[m+16+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){o=0;p=k;q=l;r=m;break}i=gj[f&4095](h)|0;o=i;p=a[9661065]|0;q=c[2415264]|0;r=c[2388530]|0}else{o=a[e+(l&2047)|0]|0;p=k;q=l;r=m}}while(0);a[9661063]=a[9661063]&-33;m=o|-128;o=(p&255)<<13|q&8191;p=c[r+4112+(o>>>11<<2)>>2]|0;if((p|0)!=0){a[p+(q&2047)|0]=m;return}q=c[r+4>>2]|0;if((q|0)==0){return}gg[q&4095](o,m);return}function fCV(){var b=0;b=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-b;c[2415269]=(c[2415269]|0)-b;a[9661063]=a[9661063]&-41|8;return}function fCW(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;e=(d[9661075]|0)*-5|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661056]=k;k=l+1&65535;b[4830522]=k;l=k&65535;h=(d[9661064+(l>>>13)|0]|0)<<13|l&8191;e=c[m+8208+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){o=0;p=k;break}i=gj[f&4095](h)|0;o=i;p=b[4830522]|0}else{o=a[e+(l&2047)|0]|0;p=k}}while(0);a[9661057]=o;b[4830522]=p+1&65535;b[4830528]=(b[4830528]|0)+(d[9661062]|0)&65535;p=c[2415264]|0;o=9661064+(p>>>13&7)|0;k=a[o]|0;if(((k&255)<<13|p&6144|0)==2088960){l=d[9661075]|0;c[2440610]=(c[2440610]|0)-l;c[2415269]=(c[2415269]|0)-l;q=a[o]|0}else{q=k}k=(q&255)<<13|p&8191;q=c[2388530]|0;o=c[q+16+(k>>>11<<2)>>2]|0;do{if((o|0)==0){l=c[q>>2]|0;if((l|0)==0){r=0;break}r=gj[l&4095](k)|0}else{r=a[o+(p&2047)|0]|0}}while(0);p=r&255;o=a[9661063]|0;k=o&255;if((k&32|0)==0){q=k&1^1;l=a[9661060]|0;e=l&255;h=e-p-q|0;if((k&8|0)==0){k=o&-66;m=(((l^r)&128&(h^e)|0)==0?k:k|64)|(h&65280|0)==0;a[9661063]=m;k=h&255;a[9661060]=k;s=m;t=k}else{k=(e&15)-(p&15)-q|0;q=(e&240)-(p&240)|0;e=(k&240|0)==0?k:k-6|0;k=(e&128|0)==0?q:q-16|0;q=(h&65280|0)==0?o|1:o&-2;a[9661063]=q;h=(((k&3840|0)==0?k:k+160|0)&240|e&15)&255;a[9661060]=h;e=d[9661075]|0;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;s=q;t=h}a[9661063]=s&93|t&-128|(t<<24>>24==0?2:0);return}t=o&-33;a[9661063]=t;a[9661052]=a[9661061]|0;o=c[2415263]|0;c[2415264]=o;s=(d[9661065]|0)<<13|o&8191;h=c[2388530]|0;q=c[h+16+(s>>>11<<2)>>2]|0;do{if((q|0)==0){e=c[h>>2]|0;if((e|0)==0){u=0;v=t;break}k=gj[e&4095](s)|0;u=k;v=a[9661063]|0}else{u=a[q+(o&2047)|0]|0;v=t}}while(0);t=u&255;o=v&255;q=o&1^1;s=t-p-q|0;if((o&8|0)==0){o=v&-66;h=(((u^r)&128&(s^t)|0)==0?o:o|64)|(s&65280|0)==0;a[9661063]=h;w=s&255;x=h}else{h=(t&15)-(p&15)-q|0;q=(t&240)-(p&240)|0;p=(h&240|0)==0?h:h-6|0;h=(p&128|0)==0?q:q-16|0;q=(s&65280|0)==0?v|1:v&-2;a[9661063]=q;v=d[9661075]|0;c[2440610]=(c[2440610]|0)-v;c[2415269]=(c[2415269]|0)-v;w=((h&3840|0)==0?h:h+160|0)&240|p&15;x=q}a[9661063]=(x&93|w&128|((w|0)==0?2:0))&255;x=c[2415264]|0;q=(d[9661065]|0)<<13|x&8191;p=w&255;w=c[2388530]|0;h=c[w+4112+(q>>>11<<2)>>2]|0;do{if((h|0)==0){v=c[w+4>>2]|0;if((v|0)==0){break}gg[v&4095](q,p)}else{a[h+(x&2047)|0]=p}}while(0);p=(d[9661075]|0)*-3|0;c[2440610]=p+(c[2440610]|0);c[2415269]=p+(c[2415269]|0);return}function fCX(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=(d[9661075]|0)<<2;c[2440610]=(c[2440610]|0)-b;c[2415269]=(c[2415269]|0)-b;b=a[9661063]&-33;a[9661063]=b;a[9661048]=(a[9661048]|0)+1&255;e=c[2415262]|0;f=(d[9661065]|0)<<13|e&2097151;g=c[2388530]|0;h=c[g+16+(f>>>11<<2)>>2]|0;do{if((h|0)==0){i=c[g>>2]|0;if((i|0)==0){j=0;k=b;break}l=gj[i&4095](f)|0;j=l;k=a[9661063]|0}else{j=a[h+(e&2047)|0]|0;k=b}}while(0);a[9661061]=j;a[9661063]=k&93|j&-128|(j<<24>>24==0?2:0);return}function fCY(){var b=0;b=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-b;c[2415269]=(c[2415269]|0)-b;a[9661063]=a[9661063]&-33;return}function fCZ(){var b=0;b=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-b;c[2415269]=(c[2415269]|0)-b;a[9661063]=a[9661063]&-33;return}function fC_(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;e=(d[9661075]|0)*-5|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661056]=k;k=l+1&65535;b[4830522]=k;l=k&65535;h=(d[9661064+(l>>>13)|0]|0)<<13|l&8191;e=c[m+8208+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){o=0;p=k;break}i=gj[f&4095](h)|0;o=i;p=b[4830522]|0}else{o=a[e+(l&2047)|0]|0;p=k}}while(0);a[9661057]=o;b[4830522]=p+1&65535;b[4830528]=(b[4830528]|0)+(d[9661061]|0)&65535;p=c[2415264]|0;o=9661064+(p>>>13&7)|0;k=a[o]|0;if(((k&255)<<13|p&6144|0)==2088960){l=d[9661075]|0;c[2440610]=(c[2440610]|0)-l;c[2415269]=(c[2415269]|0)-l;q=a[o]|0}else{q=k}k=(q&255)<<13|p&8191;q=c[2388530]|0;o=c[q+16+(k>>>11<<2)>>2]|0;do{if((o|0)==0){l=c[q>>2]|0;if((l|0)==0){r=0;break}r=gj[l&4095](k)|0}else{r=a[o+(p&2047)|0]|0}}while(0);p=r&255;o=a[9661063]|0;k=o&255;if((k&32|0)==0){q=k&1^1;l=a[9661060]|0;e=l&255;h=e-p-q|0;if((k&8|0)==0){k=o&-66;m=(((l^r)&128&(h^e)|0)==0?k:k|64)|(h&65280|0)==0;a[9661063]=m;k=h&255;a[9661060]=k;s=m;t=k}else{k=(e&15)-(p&15)-q|0;q=(e&240)-(p&240)|0;e=(k&240|0)==0?k:k-6|0;k=(e&128|0)==0?q:q-16|0;q=(h&65280|0)==0?o|1:o&-2;a[9661063]=q;h=(((k&3840|0)==0?k:k+160|0)&240|e&15)&255;a[9661060]=h;e=d[9661075]|0;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;s=q;t=h}a[9661063]=s&93|t&-128|(t<<24>>24==0?2:0);return}t=o&-33;a[9661063]=t;a[9661052]=a[9661061]|0;o=c[2415263]|0;c[2415264]=o;s=(d[9661065]|0)<<13|o&8191;h=c[2388530]|0;q=c[h+16+(s>>>11<<2)>>2]|0;do{if((q|0)==0){e=c[h>>2]|0;if((e|0)==0){u=0;v=t;break}k=gj[e&4095](s)|0;u=k;v=a[9661063]|0}else{u=a[q+(o&2047)|0]|0;v=t}}while(0);t=u&255;o=v&255;q=o&1^1;s=t-p-q|0;if((o&8|0)==0){o=v&-66;h=(((u^r)&128&(s^t)|0)==0?o:o|64)|(s&65280|0)==0;a[9661063]=h;w=s&255;x=h}else{h=(t&15)-(p&15)-q|0;q=(t&240)-(p&240)|0;p=(h&240|0)==0?h:h-6|0;h=(p&128|0)==0?q:q-16|0;q=(s&65280|0)==0?v|1:v&-2;a[9661063]=q;v=d[9661075]|0;c[2440610]=(c[2440610]|0)-v;c[2415269]=(c[2415269]|0)-v;w=((h&3840|0)==0?h:h+160|0)&240|p&15;x=q}a[9661063]=(x&93|w&128|((w|0)==0?2:0))&255;x=c[2415264]|0;q=(d[9661065]|0)<<13|x&8191;p=w&255;w=c[2388530]|0;h=c[w+4112+(q>>>11<<2)>>2]|0;do{if((h|0)==0){v=c[w+4>>2]|0;if((v|0)==0){break}gg[v&4095](q,p)}else{a[h+(x&2047)|0]=p}}while(0);p=(d[9661075]|0)*-3|0;c[2440610]=p+(c[2440610]|0);c[2415269]=p+(c[2415269]|0);return}function fC$(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=(d[9661075]|0)*-7|0;c[2440610]=e+(c[2440610]|0);c[2415269]=e+(c[2415269]|0);e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661056]=k;k=l+1&65535;b[4830522]=k;l=k&65535;h=(d[9661064+(l>>>13)|0]|0)<<13|l&8191;e=c[m+8208+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){o=0;p=k;break}i=gj[f&4095](h)|0;o=i;p=b[4830522]|0}else{o=a[e+(l&2047)|0]|0;p=k}}while(0);a[9661057]=o;b[4830522]=p+1&65535;b[4830528]=(b[4830528]|0)+(d[9661061]|0)&65535;p=c[2415264]|0;o=9661064+(p>>>13&7)|0;k=a[o]|0;if(((k&255)<<13|p&6144|0)==2088960){l=d[9661075]|0;c[2440610]=(c[2440610]|0)-l;c[2415269]=(c[2415269]|0)-l;q=a[o]|0}else{q=k}k=(q&255)<<13|p&8191;q=c[2388530]|0;o=c[q+16+(k>>>11<<2)>>2]|0;do{if((o|0)==0){l=c[q>>2]|0;if((l|0)==0){r=0;s=p;break}e=gj[l&4095](k)|0;r=e;s=c[2415264]|0}else{r=a[o+(p&2047)|0]|0;s=p}}while(0);p=r+1&255;a[9661063]=a[9661063]&93|p&-128|(p<<24>>24==0?2:0);r=9661064+(s>>>13&7)|0;o=a[r]|0;if(((o&255)<<13|s&6144|0)==2088960){k=d[9661075]|0;c[2440610]=(c[2440610]|0)-k;c[2415269]=(c[2415269]|0)-k;t=a[r]|0}else{t=o}o=(t&255)<<13|s&8191;t=c[2388530]|0;r=c[t+4112+(o>>>11<<2)>>2]|0;if((r|0)!=0){a[r+(s&2047)|0]=p;return}s=c[t+4>>2]|0;if((s|0)==0){return}gg[s&4095](o,p);return}function fC0(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=(d[9661075]|0)<<2;c[2440610]=(c[2440610]|0)-e;c[2415269]=(c[2415269]|0)-e;e=b[4830522]|0;f=e&65535;g=(d[9661064+(f>>>13)|0]|0)<<13|f&8191;h=c[2388530]|0;i=c[h+8208+(g>>>11<<2)>>2]|0;do{if((i|0)==0){j=c[h>>2]|0;if((j|0)==0){k=0;l=e;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830522]|0;m=c[2388530]|0}else{k=a[i+(f&2047)|0]|0;l=e;m=h}}while(0);a[9661052]=k;k=l+1&65535;b[4830522]=k;l=c[2415263]|0;c[2415264]=l;h=(d[9661065]|0)<<13|l&8191;e=c[m+16+(h>>>11<<2)>>2]|0;do{if((e|0)==0){f=c[m>>2]|0;if((f|0)==0){a[9661063]=a[9661063]&-33;o=k;break}else{p=gj[f&4095](h)|0;q=6541;break}}else{p=a[e+(l&2047)|0]|0;q=6541}}while(0);do{if((q|0)==6541){a[9661063]=a[9661063]&-33;if(p<<24>>24>=0){o=b[4830522]|0;break}l=(d[9661075]|0)<<2;c[2440610]=(c[2440610]|0)-l;c[2415269]=(c[2415269]|0)-l;l=b[4830522]|0;e=l&65535;h=(d[9661064+(e>>>13)|0]|0)<<13|e&8191;k=c[2388530]|0;m=c[k+8208+(h>>>11<<2)>>2]|0;do{if((m|0)==0){f=c[k>>2]|0;if((f|0)==0){r=0;s=l;break}i=gj[f&4095](h)|0;r=i;s=b[4830522]|0}else{r=a[m+(e&2047)|0]|0;s=l}}while(0);b[4830528]=(s+1&65535)+(r<<24>>24)&65535;c[2415261]=c[2415264];return}}while(0);b[4830522]=o+1&65535;o=(d[9661075]|0)<<1;c[2440610]=(c[2440610]|0)-o;c[2415269]=(c[2415269]|0)-o;return}function fC1(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0;e=a[9642747]|0;f=a[9642748]|0;if((f|e)<<24>>24!=0){a[9642760]=a[9642760]&-17}do{if(f<<24>>24!=0){g=a[9642744]|0;if((g&64)!=0){break}h=a[9642760]|0;do{if((h&8)==0){if((a[9642745]&2)==0){a[9642744]=g&127;b[4821364]=(b[4821364]|0)-1&65535;i=c[2410682]|0;j=i&65535;k=a[9642704]|0;l=c[3528552]|0;m=c[2433426]|0;n=c[m+(l*3160|0)+60+((i>>>8&255|256)<<2)>>2]|0;do{if((n|0)==0){o=c[m+(l*3160|0)+3136>>2]|0;if((o|0)==0){p=l;q=m;break}gg[o&4095](j,k);p=c[3528552]|0;q=c[2433426]|0}else{a[n+(i&255)|0]=k;p=l;q=m}}while(0);b[4821364]=(b[4821364]|0)-1&65535;m=c[2410682]|0;l=m&65535;k=a[9642705]|0;i=c[q+(p*3160|0)+60+((m>>>8&255|256)<<2)>>2]|0;do{if((i|0)==0){n=c[q+(p*3160|0)+3136>>2]|0;if((n|0)==0){r=p;s=q;break}gg[n&4095](l,k);r=c[3528552]|0;s=c[2433426]|0}else{a[i+(m&255)|0]=k;r=p;s=q}}while(0);b[4821364]=(b[4821364]|0)-1&65535;k=c[2410682]|0;m=k&65535;i=a[9642744]|0;l=c[s+(r*3160|0)+60+((k>>>8&255|256)<<2)>>2]|0;do{if((l|0)==0){n=c[s+(r*3160|0)+3136>>2]|0;if((n|0)==0){break}gg[n&4095](m,i)}else{a[l+(k&255)|0]=i}}while(0);c[2410688]=(c[2410688]|0)+10;break}a[9642744]=g|-128;b[4821364]=(b[4821364]|0)-1&65535;i=c[2410682]|0;k=i&65535;l=a[9642704]|0;m=c[3528552]|0;n=c[2433426]|0;j=c[n+(m*3160|0)+60+((i>>>8&255|256)<<2)>>2]|0;do{if((j|0)==0){o=c[n+(m*3160|0)+3136>>2]|0;if((o|0)==0){t=m;u=n;break}gg[o&4095](k,l);t=c[3528552]|0;u=c[2433426]|0}else{a[j+(i&255)|0]=l;t=m;u=n}}while(0);b[4821364]=(b[4821364]|0)-1&65535;n=c[2410682]|0;m=n&65535;l=a[9642705]|0;i=c[u+(t*3160|0)+60+((n>>>8&255|256)<<2)>>2]|0;do{if((i|0)==0){j=c[u+(t*3160|0)+3136>>2]|0;if((j|0)==0){v=t;w=u;break}gg[j&4095](m,l);v=c[3528552]|0;w=c[2433426]|0}else{a[i+(n&255)|0]=l;v=t;w=u}}while(0);b[4821364]=(b[4821364]|0)-1&65535;l=c[2410682]|0;n=l&65535;i=a[9642724]|0;m=c[w+(v*3160|0)+60+((l>>>8&255|256)<<2)>>2]|0;do{if((m|0)==0){j=c[w+(v*3160|0)+3136>>2]|0;if((j|0)==0){x=v;y=w;break}gg[j&4095](n,i);x=c[3528552]|0;y=c[2433426]|0}else{a[m+(l&255)|0]=i;x=v;y=w}}while(0);b[4821364]=(b[4821364]|0)-1&65535;i=c[2410682]|0;l=i&65535;m=a[9642725]|0;n=c[y+(x*3160|0)+60+((i>>>8&255|256)<<2)>>2]|0;do{if((n|0)==0){j=c[y+(x*3160|0)+3136>>2]|0;if((j|0)==0){z=x;A=y;break}gg[j&4095](l,m);z=c[3528552]|0;A=c[2433426]|0}else{a[n+(i&255)|0]=m;z=x;A=y}}while(0);b[4821364]=(b[4821364]|0)-1&65535;m=c[2410682]|0;i=m&65535;n=a[9642736]|0;l=c[A+(z*3160|0)+60+((m>>>8&255|256)<<2)>>2]|0;do{if((l|0)==0){j=c[A+(z*3160|0)+3136>>2]|0;if((j|0)==0){B=z;C=A;break}gg[j&4095](i,n);B=c[3528552]|0;C=c[2433426]|0}else{a[l+(m&255)|0]=n;B=z;C=A}}while(0);b[4821364]=(b[4821364]|0)-1&65535;n=c[2410682]|0;m=n&65535;l=a[9642737]|0;i=c[C+(B*3160|0)+60+((n>>>8&255|256)<<2)>>2]|0;do{if((i|0)==0){j=c[C+(B*3160|0)+3136>>2]|0;if((j|0)==0){D=B;E=C;break}gg[j&4095](m,l);D=c[3528552]|0;E=c[2433426]|0}else{a[i+(n&255)|0]=l;D=B;E=C}}while(0);b[4821364]=(b[4821364]|0)-1&65535;l=c[2410682]|0;n=l&65535;i=a[9642732]|0;m=c[E+(D*3160|0)+60+((l>>>8&255|256)<<2)>>2]|0;do{if((m|0)==0){j=c[E+(D*3160|0)+3136>>2]|0;if((j|0)==0){F=D;G=E;break}gg[j&4095](n,i);F=c[3528552]|0;G=c[2433426]|0}else{a[m+(l&255)|0]=i;F=D;G=E}}while(0);b[4821364]=(b[4821364]|0)-1&65535;i=c[2410682]|0;l=i&65535;m=a[9642733]|0;n=c[G+(F*3160|0)+60+((i>>>8&255|256)<<2)>>2]|0;do{if((n|0)==0){j=c[G+(F*3160|0)+3136>>2]|0;if((j|0)==0){H=F;I=G;break}gg[j&4095](l,m);H=c[3528552]|0;I=c[2433426]|0}else{a[n+(i&255)|0]=m;H=F;I=G}}while(0);b[4821364]=(b[4821364]|0)-1&65535;m=c[2410682]|0;i=m&65535;n=a[9642721]|0;l=c[I+(H*3160|0)+60+((m>>>8&255|256)<<2)>>2]|0;do{if((l|0)==0){j=c[I+(H*3160|0)+3136>>2]|0;if((j|0)==0){break}gg[j&4095](i,n)}else{a[l+(m&255)|0]=n}}while(0);if((a[9642745]&1)!=0){b[4821364]=(b[4821364]|0)-1&65535;n=c[2410682]|0;m=n&65535;l=a[9642716]|0;i=c[3528552]|0;j=c[2433426]|0;k=c[j+(i*3160|0)+60+((n>>>8&255|256)<<2)>>2]|0;do{if((k|0)==0){o=c[j+(i*3160|0)+3136>>2]|0;if((o|0)==0){J=i;K=j;break}gg[o&4095](m,l);J=c[3528552]|0;K=c[2433426]|0}else{a[k+(n&255)|0]=l;J=i;K=j}}while(0);b[4821364]=(b[4821364]|0)-1&65535;j=c[2410682]|0;i=j&65535;l=a[9642717]|0;n=c[K+(J*3160|0)+60+((j>>>8&255|256)<<2)>>2]|0;do{if((n|0)==0){k=c[K+(J*3160|0)+3136>>2]|0;if((k|0)==0){break}gg[k&4095](i,l)}else{a[n+(j&255)|0]=l}}while(0);c[2410688]=(c[2410688]|0)+2}b[4821364]=(b[4821364]|0)-1&65535;l=c[2410682]|0;j=l&65535;n=a[9642712]|0;i=c[3528552]|0;k=c[2433426]|0;m=c[k+(i*3160|0)+60+((l>>>8&255|256)<<2)>>2]|0;do{if((m|0)==0){o=c[k+(i*3160|0)+3136>>2]|0;if((o|0)==0){L=i;M=k;break}gg[o&4095](j,n);L=c[3528552]|0;M=c[2433426]|0}else{a[m+(l&255)|0]=n;L=i;M=k}}while(0);b[4821364]=(b[4821364]|0)-1&65535;k=c[2410682]|0;i=k&65535;n=a[9642713]|0;l=c[M+(L*3160|0)+60+((k>>>8&255|256)<<2)>>2]|0;do{if((l|0)==0){m=c[M+(L*3160|0)+3136>>2]|0;if((m|0)==0){N=L;O=M;break}gg[m&4095](i,n);N=c[3528552]|0;O=c[2433426]|0}else{a[l+(k&255)|0]=n;N=L;O=M}}while(0);b[4821364]=(b[4821364]|0)-1&65535;n=c[2410682]|0;k=n&65535;l=a[9642744]|0;i=c[O+(N*3160|0)+60+((n>>>8&255|256)<<2)>>2]|0;do{if((i|0)==0){m=c[O+(N*3160|0)+3136>>2]|0;if((m|0)==0){break}gg[m&4095](k,l)}else{a[i+(n&255)|0]=l}}while(0);c[2410688]=(c[2410688]|0)+19}else{a[9642760]=h&-9;c[2410688]=(c[2410688]|0)+7}}while(0);a[9642744]=a[9642744]|80;h=c[3528552]|0;g=c[2433426]|0;l=c[g+(h*3160|0)+1080>>2]|0;do{if((l|0)==0){n=c[g+(h*3160|0)+3132>>2]|0;if((n|0)==0){P=0;Q=0;break}i=gj[n&4095](-10)|0;n=c[3528552]|0;k=c[2433426]|0;m=c[k+(n*3160|0)+1080>>2]|0;j=(i&255)<<8;if((m|0)!=0){R=m;S=j;T=6635;break}m=c[k+(n*3160|0)+3132>>2]|0;if((m|0)==0){P=0;Q=j;break}P=gj[m&4095](-9)|0;Q=j}else{R=l;S=(d[l+246|0]|0)<<8;T=6635}}while(0);if((T|0)==6635){P=a[R+247|0]|0;Q=S}l=P&255|Q;c[2410676]=l;b[4821352]=l&65535;return}}while(0);if(e<<24>>24==0){return}e=a[9642744]|0;if((e&16)!=0){return}Q=a[9642760]|0;if((Q&8)==0){a[9642744]=e|-128;b[4821364]=(b[4821364]|0)-1&65535;P=c[2410682]|0;S=P&65535;R=a[9642704]|0;N=c[3528552]|0;O=c[2433426]|0;M=c[O+(N*3160|0)+60+((P>>>8&255|256)<<2)>>2]|0;do{if((M|0)==0){L=c[O+(N*3160|0)+3136>>2]|0;if((L|0)==0){U=N;V=O;break}gg[L&4095](S,R);U=c[3528552]|0;V=c[2433426]|0}else{a[M+(P&255)|0]=R;U=N;V=O}}while(0);b[4821364]=(b[4821364]|0)-1&65535;O=c[2410682]|0;N=O&65535;R=a[9642705]|0;P=c[V+(U*3160|0)+60+((O>>>8&255|256)<<2)>>2]|0;do{if((P|0)==0){M=c[V+(U*3160|0)+3136>>2]|0;if((M|0)==0){W=U;X=V;break}gg[M&4095](N,R);W=c[3528552]|0;X=c[2433426]|0}else{a[P+(O&255)|0]=R;W=U;X=V}}while(0);b[4821364]=(b[4821364]|0)-1&65535;V=c[2410682]|0;U=V&65535;R=a[9642724]|0;O=c[X+(W*3160|0)+60+((V>>>8&255|256)<<2)>>2]|0;do{if((O|0)==0){P=c[X+(W*3160|0)+3136>>2]|0;if((P|0)==0){Y=W;Z=X;break}gg[P&4095](U,R);Y=c[3528552]|0;Z=c[2433426]|0}else{a[O+(V&255)|0]=R;Y=W;Z=X}}while(0);b[4821364]=(b[4821364]|0)-1&65535;X=c[2410682]|0;W=X&65535;R=a[9642725]|0;V=c[Z+(Y*3160|0)+60+((X>>>8&255|256)<<2)>>2]|0;do{if((V|0)==0){O=c[Z+(Y*3160|0)+3136>>2]|0;if((O|0)==0){_=Y;$=Z;break}gg[O&4095](W,R);_=c[3528552]|0;$=c[2433426]|0}else{a[V+(X&255)|0]=R;_=Y;$=Z}}while(0);b[4821364]=(b[4821364]|0)-1&65535;Z=c[2410682]|0;Y=Z&65535;R=a[9642736]|0;X=c[$+(_*3160|0)+60+((Z>>>8&255|256)<<2)>>2]|0;do{if((X|0)==0){V=c[$+(_*3160|0)+3136>>2]|0;if((V|0)==0){aa=_;ab=$;break}gg[V&4095](Y,R);aa=c[3528552]|0;ab=c[2433426]|0}else{a[X+(Z&255)|0]=R;aa=_;ab=$}}while(0);b[4821364]=(b[4821364]|0)-1&65535;$=c[2410682]|0;_=$&65535;R=a[9642737]|0;Z=c[ab+(aa*3160|0)+60+(($>>>8&255|256)<<2)>>2]|0;do{if((Z|0)==0){X=c[ab+(aa*3160|0)+3136>>2]|0;if((X|0)==0){ac=aa;ad=ab;break}gg[X&4095](_,R);ac=c[3528552]|0;ad=c[2433426]|0}else{a[Z+($&255)|0]=R;ac=aa;ad=ab}}while(0);b[4821364]=(b[4821364]|0)-1&65535;ab=c[2410682]|0;aa=ab&65535;R=a[9642732]|0;$=c[ad+(ac*3160|0)+60+((ab>>>8&255|256)<<2)>>2]|0;do{if(($|0)==0){Z=c[ad+(ac*3160|0)+3136>>2]|0;if((Z|0)==0){ae=ac;af=ad;break}gg[Z&4095](aa,R);ae=c[3528552]|0;af=c[2433426]|0}else{a[$+(ab&255)|0]=R;ae=ac;af=ad}}while(0);b[4821364]=(b[4821364]|0)-1&65535;ad=c[2410682]|0;ac=ad&65535;R=a[9642733]|0;ab=c[af+(ae*3160|0)+60+((ad>>>8&255|256)<<2)>>2]|0;do{if((ab|0)==0){$=c[af+(ae*3160|0)+3136>>2]|0;if(($|0)==0){ag=ae;ah=af;break}gg[$&4095](ac,R);ag=c[3528552]|0;ah=c[2433426]|0}else{a[ab+(ad&255)|0]=R;ag=ae;ah=af}}while(0);b[4821364]=(b[4821364]|0)-1&65535;af=c[2410682]|0;ae=af&65535;R=a[9642721]|0;ad=c[ah+(ag*3160|0)+60+((af>>>8&255|256)<<2)>>2]|0;do{if((ad|0)==0){ab=c[ah+(ag*3160|0)+3136>>2]|0;if((ab|0)==0){break}gg[ab&4095](ae,R)}else{a[ad+(af&255)|0]=R}}while(0);if((a[9642745]&1)!=0){b[4821364]=(b[4821364]|0)-1&65535;R=c[2410682]|0;af=R&65535;ad=a[9642716]|0;ae=c[3528552]|0;ag=c[2433426]|0;ah=c[ag+(ae*3160|0)+60+((R>>>8&255|256)<<2)>>2]|0;do{if((ah|0)==0){ab=c[ag+(ae*3160|0)+3136>>2]|0;if((ab|0)==0){ai=ae;aj=ag;break}gg[ab&4095](af,ad);ai=c[3528552]|0;aj=c[2433426]|0}else{a[ah+(R&255)|0]=ad;ai=ae;aj=ag}}while(0);b[4821364]=(b[4821364]|0)-1&65535;ag=c[2410682]|0;ae=ag&65535;ad=a[9642717]|0;R=c[aj+(ai*3160|0)+60+((ag>>>8&255|256)<<2)>>2]|0;do{if((R|0)==0){ah=c[aj+(ai*3160|0)+3136>>2]|0;if((ah|0)==0){break}gg[ah&4095](ae,ad)}else{a[R+(ag&255)|0]=ad}}while(0);c[2410688]=(c[2410688]|0)+2}b[4821364]=(b[4821364]|0)-1&65535;ad=c[2410682]|0;ag=ad&65535;R=a[9642712]|0;ae=c[3528552]|0;ai=c[2433426]|0;aj=c[ai+(ae*3160|0)+60+((ad>>>8&255|256)<<2)>>2]|0;do{if((aj|0)==0){ah=c[ai+(ae*3160|0)+3136>>2]|0;if((ah|0)==0){ak=ae;al=ai;break}gg[ah&4095](ag,R);ak=c[3528552]|0;al=c[2433426]|0}else{a[aj+(ad&255)|0]=R;ak=ae;al=ai}}while(0);b[4821364]=(b[4821364]|0)-1&65535;ai=c[2410682]|0;ae=ai&65535;R=a[9642713]|0;ad=c[al+(ak*3160|0)+60+((ai>>>8&255|256)<<2)>>2]|0;do{if((ad|0)==0){aj=c[al+(ak*3160|0)+3136>>2]|0;if((aj|0)==0){am=ak;an=al;break}gg[aj&4095](ae,R);am=c[3528552]|0;an=c[2433426]|0}else{a[ad+(ai&255)|0]=R;am=ak;an=al}}while(0);b[4821364]=(b[4821364]|0)-1&65535;al=c[2410682]|0;ak=al&65535;R=a[9642744]|0;ai=c[an+(am*3160|0)+60+((al>>>8&255|256)<<2)>>2]|0;do{if((ai|0)==0){ad=c[an+(am*3160|0)+3136>>2]|0;if((ad|0)==0){break}gg[ad&4095](ak,R)}else{a[ai+(al&255)|0]=R}}while(0);ao=(c[2410688]|0)+19|0;ap=a[9642744]|0}else{a[9642760]=Q&-9;ao=(c[2410688]|0)+7|0;ap=e}c[2410688]=ao;a[9642744]=ap|16;ap=c[3528552]|0;ao=c[2433426]|0;e=c[ao+(ap*3160|0)+1080>>2]|0;do{if((e|0)==0){Q=c[ao+(ap*3160|0)+3132>>2]|0;if((Q|0)==0){aq=0;ar=0;break}R=gj[Q&4095](-8)|0;Q=c[3528552]|0;al=c[2433426]|0;ai=c[al+(Q*3160|0)+1080>>2]|0;ak=(R&255)<<8;if((ai|0)!=0){as=ai;at=ak;T=6706;break}ai=c[al+(Q*3160|0)+3132>>2]|0;if((ai|0)==0){aq=0;ar=ak;break}aq=gj[ai&4095](-7)|0;ar=ak}else{as=e;at=(d[e+248|0]|0)<<8;T=6706}}while(0);if((T|0)==6706){aq=a[as+249|0]|0;ar=at}at=aq&255|ar;c[2410676]=at;b[4821352]=at&65535;return}function fC2(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;a[9642760]=0;a[9642761]=0;a[9642747]=0;c[2410680]=0;a[9642745]=0;a[9642744]=a[9642744]|80;e=c[3528552]|0;f=c[2433426]|0;g=c[f+(e*3160|0)+1080>>2]|0;do{if((g|0)==0){h=c[f+(e*3160|0)+3132>>2]|0;if((h|0)==0){i=0;j=0;break}k=gj[h&4095](-2)|0;h=c[3528552]|0;l=c[2433426]|0;m=c[l+(h*3160|0)+1080>>2]|0;n=(k&255)<<8;if((m|0)!=0){o=m;p=n;q=6719;break}m=c[l+(h*3160|0)+3132>>2]|0;if((m|0)==0){i=0;j=n;break}i=gj[m&4095](-1)|0;j=n}else{o=g;p=(d[g+254|0]|0)<<8;q=6719}}while(0);if((q|0)==6719){i=a[o+255|0]|0;j=p}p=i&255|j;c[2410676]=p;b[4821352]=p&65535;p=(a[9642745]&1)==0;c[2430032]=p?1595912:1595656;c[2429672]=p?1114752:1114496;c[2429670]=p?1114240:1113984;c[2444186]=p?4654424:4654168;return}function fC3(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;if((a[9642761]|0)==1){return}a[9642761]=1;e=a[9642760]|0;if((e&32)==0){return}a[9642760]=e&-17;if((e&8)==0){a[9642744]=a[9642744]|-128;b[4821364]=(b[4821364]|0)-1&65535;f=c[2410682]|0;g=f&65535;h=a[9642704]|0;i=c[3528552]|0;j=c[2433426]|0;k=c[j+(i*3160|0)+60+((f>>>8&255|256)<<2)>>2]|0;do{if((k|0)==0){l=c[j+(i*3160|0)+3136>>2]|0;if((l|0)==0){m=i;n=j;break}gg[l&4095](g,h);m=c[3528552]|0;n=c[2433426]|0}else{a[k+(f&255)|0]=h;m=i;n=j}}while(0);b[4821364]=(b[4821364]|0)-1&65535;j=c[2410682]|0;i=j&65535;h=a[9642705]|0;f=c[n+(m*3160|0)+60+((j>>>8&255|256)<<2)>>2]|0;do{if((f|0)==0){k=c[n+(m*3160|0)+3136>>2]|0;if((k|0)==0){o=m;p=n;break}gg[k&4095](i,h);o=c[3528552]|0;p=c[2433426]|0}else{a[f+(j&255)|0]=h;o=m;p=n}}while(0);b[4821364]=(b[4821364]|0)-1&65535;n=c[2410682]|0;m=n&65535;h=a[9642724]|0;j=c[p+(o*3160|0)+60+((n>>>8&255|256)<<2)>>2]|0;do{if((j|0)==0){f=c[p+(o*3160|0)+3136>>2]|0;if((f|0)==0){q=o;r=p;break}gg[f&4095](m,h);q=c[3528552]|0;r=c[2433426]|0}else{a[j+(n&255)|0]=h;q=o;r=p}}while(0);b[4821364]=(b[4821364]|0)-1&65535;p=c[2410682]|0;o=p&65535;h=a[9642725]|0;n=c[r+(q*3160|0)+60+((p>>>8&255|256)<<2)>>2]|0;do{if((n|0)==0){j=c[r+(q*3160|0)+3136>>2]|0;if((j|0)==0){s=q;t=r;break}gg[j&4095](o,h);s=c[3528552]|0;t=c[2433426]|0}else{a[n+(p&255)|0]=h;s=q;t=r}}while(0);b[4821364]=(b[4821364]|0)-1&65535;r=c[2410682]|0;q=r&65535;h=a[9642736]|0;p=c[t+(s*3160|0)+60+((r>>>8&255|256)<<2)>>2]|0;do{if((p|0)==0){n=c[t+(s*3160|0)+3136>>2]|0;if((n|0)==0){u=s;v=t;break}gg[n&4095](q,h);u=c[3528552]|0;v=c[2433426]|0}else{a[p+(r&255)|0]=h;u=s;v=t}}while(0);b[4821364]=(b[4821364]|0)-1&65535;t=c[2410682]|0;s=t&65535;h=a[9642737]|0;r=c[v+(u*3160|0)+60+((t>>>8&255|256)<<2)>>2]|0;do{if((r|0)==0){p=c[v+(u*3160|0)+3136>>2]|0;if((p|0)==0){w=u;x=v;break}gg[p&4095](s,h);w=c[3528552]|0;x=c[2433426]|0}else{a[r+(t&255)|0]=h;w=u;x=v}}while(0);b[4821364]=(b[4821364]|0)-1&65535;v=c[2410682]|0;u=v&65535;h=a[9642732]|0;t=c[x+(w*3160|0)+60+((v>>>8&255|256)<<2)>>2]|0;do{if((t|0)==0){r=c[x+(w*3160|0)+3136>>2]|0;if((r|0)==0){y=w;z=x;break}gg[r&4095](u,h);y=c[3528552]|0;z=c[2433426]|0}else{a[t+(v&255)|0]=h;y=w;z=x}}while(0);b[4821364]=(b[4821364]|0)-1&65535;x=c[2410682]|0;w=x&65535;h=a[9642733]|0;v=c[z+(y*3160|0)+60+((x>>>8&255|256)<<2)>>2]|0;do{if((v|0)==0){t=c[z+(y*3160|0)+3136>>2]|0;if((t|0)==0){A=y;B=z;break}gg[t&4095](w,h);A=c[3528552]|0;B=c[2433426]|0}else{a[v+(x&255)|0]=h;A=y;B=z}}while(0);b[4821364]=(b[4821364]|0)-1&65535;z=c[2410682]|0;y=z&65535;h=a[9642721]|0;x=c[B+(A*3160|0)+60+((z>>>8&255|256)<<2)>>2]|0;do{if((x|0)==0){v=c[B+(A*3160|0)+3136>>2]|0;if((v|0)==0){break}gg[v&4095](y,h)}else{a[x+(z&255)|0]=h}}while(0);if((a[9642745]&1)!=0){b[4821364]=(b[4821364]|0)-1&65535;h=c[2410682]|0;z=h&65535;x=a[9642716]|0;y=c[3528552]|0;A=c[2433426]|0;B=c[A+(y*3160|0)+60+((h>>>8&255|256)<<2)>>2]|0;do{if((B|0)==0){v=c[A+(y*3160|0)+3136>>2]|0;if((v|0)==0){C=y;D=A;break}gg[v&4095](z,x);C=c[3528552]|0;D=c[2433426]|0}else{a[B+(h&255)|0]=x;C=y;D=A}}while(0);b[4821364]=(b[4821364]|0)-1&65535;A=c[2410682]|0;y=A&65535;x=a[9642717]|0;h=c[D+(C*3160|0)+60+((A>>>8&255|256)<<2)>>2]|0;do{if((h|0)==0){B=c[D+(C*3160|0)+3136>>2]|0;if((B|0)==0){break}gg[B&4095](y,x)}else{a[h+(A&255)|0]=x}}while(0);c[2410688]=(c[2410688]|0)+2}b[4821364]=(b[4821364]|0)-1&65535;x=c[2410682]|0;A=x&65535;h=a[9642712]|0;y=c[3528552]|0;C=c[2433426]|0;D=c[C+(y*3160|0)+60+((x>>>8&255|256)<<2)>>2]|0;do{if((D|0)==0){B=c[C+(y*3160|0)+3136>>2]|0;if((B|0)==0){E=y;F=C;break}gg[B&4095](A,h);E=c[3528552]|0;F=c[2433426]|0}else{a[D+(x&255)|0]=h;E=y;F=C}}while(0);b[4821364]=(b[4821364]|0)-1&65535;C=c[2410682]|0;y=C&65535;h=a[9642713]|0;x=c[F+(E*3160|0)+60+((C>>>8&255|256)<<2)>>2]|0;do{if((x|0)==0){D=c[F+(E*3160|0)+3136>>2]|0;if((D|0)==0){G=E;H=F;break}gg[D&4095](y,h);G=c[3528552]|0;H=c[2433426]|0}else{a[x+(C&255)|0]=h;G=E;H=F}}while(0);b[4821364]=(b[4821364]|0)-1&65535;F=c[2410682]|0;E=F&65535;h=a[9642744]|0;C=c[H+(G*3160|0)+60+((F>>>8&255|256)<<2)>>2]|0;do{if((C|0)==0){x=c[H+(G*3160|0)+3136>>2]|0;if((x|0)==0){break}gg[x&4095](E,h)}else{a[C+(F&255)|0]=h}}while(0);I=(c[2410688]|0)+19|0}else{a[9642760]=e&-25;I=(c[2410688]|0)+7|0}c[2410688]=I;a[9642744]=a[9642744]|80;I=c[3528552]|0;e=c[2433426]|0;h=c[e+(I*3160|0)+1080>>2]|0;do{if((h|0)==0){F=c[e+(I*3160|0)+3132>>2]|0;if((F|0)==0){J=0;K=0;break}C=gj[F&4095](-4)|0;F=c[3528552]|0;E=c[2433426]|0;G=c[E+(F*3160|0)+1080>>2]|0;H=(C&255)<<8;if((G|0)!=0){L=G;M=H;N=6790;break}G=c[E+(F*3160|0)+3132>>2]|0;if((G|0)==0){J=0;K=H;break}J=gj[G&4095](-3)|0;K=H}else{L=h;M=d[h+252|0]<<8;N=6790}}while(0);if((N|0)==6790){J=a[L+253|0]|0;K=M}M=J&255|K;c[2410676]=M;b[4821352]=M&65535;return}function fC4(e){e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;c[2439272]=e-(c[2410688]|0);c[2410688]=0;if((a[9642760]&24)!=0){c[2439272]=0;f=0;g=e-f|0;return g|0}do{h=c[2410676]|0;c[2410677]=h;i=h&65535;j=c[3528552]|0;k=c[2433426]|0;l=c[k+(j*3160|0)+60+((h>>>8&255|512)<<2)>>2]|0;do{if((l|0)==0){m=c[k+(j*3160|0)+3140>>2]|0;if((m|0)==0){n=0;o=i;break}p=gj[m&4095](i)|0;n=p;o=b[4821352]|0}else{n=a[l+(h&255)|0]|0;o=i}}while(0);a[9642746]=n;b[4821352]=o+1&65535;gu[c[7050856+((n&255)<<2)>>2]&16383]();q=(c[2439272]|0)-(d[(c[2430032]|0)+(d[9642746]|0)|0]|0)|0;c[2439272]=q;}while((q|0)>0);n=q-(c[2410688]|0)|0;c[2439272]=n;c[2410688]=0;f=n;g=e-f|0;return g|0}function fC5(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;c[2426872]=c[2410680];d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;l=f;m=g;break}n=gj[i&4095](e)|0;j=n;k=b[4821352]|0;l=c[3528552]|0;m=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=e;l=f;m=g}}while(0);a[9707488]=j;b[4821352]=k+1&65535;k=c[2426872]|0;j=k&65535;g=c[m+(l*3160|0)+60+((k>>>8&255)<<2)>>2]|0;do{if((g|0)==0){f=c[m+(l*3160|0)+3132>>2]|0;if((f|0)==0){o=0;p=k;q=l;r=m;break}e=gj[f&4095](j)|0;o=e;p=c[2426872]|0;q=c[3528552]|0;r=c[2433426]|0}else{o=a[g+(k&255)|0]|0;p=k;q=l;r=m}}while(0);m=o&255;o=-m|0;l=(a[9642744]&-16&255|o>>>4&8)&255;k=o&255;a[9642744]=((m^o^o>>>1)>>>6&2|o>>>8&1|(k<<24>>24==0?l|4:l)&255)&255;l=c[r+(q*3160|0)+60+((p>>>8&255|256)<<2)>>2]|0;if((l|0)!=0){a[l+(p&255)|0]=k;return}l=c[r+(q*3160|0)+3136>>2]|0;if((l|0)==0){return}gg[l&4095](p&65535,k);return}function fC6(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;l=f;m=g;break}n=gj[i&4095](e)|0;j=n;k=b[4821352]|0;l=c[3528552]|0;m=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=e;l=f;m=g}}while(0);b[4821352]=k+1&65535;c[2426872]=c[2410680];k=c[2410676]|0;g=k&65535;f=c[m+(l*3160|0)+60+((k>>>8&255|512)<<2)>>2]|0;do{if((f|0)==0){e=c[m+(l*3160|0)+3144>>2]|0;if((e|0)==0){o=0;p=g;q=l;r=m;break}d=gj[e&4095](g)|0;o=d;p=b[4821352]|0;q=c[3528552]|0;r=c[2433426]|0}else{o=a[f+(k&255)|0]|0;p=g;q=l;r=m}}while(0);a[9707488]=o;b[4821352]=p+1&65535;p=c[2426872]|0;o=p&65535;m=c[r+(q*3160|0)+60+((p>>>8&255)<<2)>>2]|0;do{if((m|0)==0){l=c[r+(q*3160|0)+3132>>2]|0;if((l|0)==0){s=0;t=p;u=q;v=r;break}g=gj[l&4095](o)|0;s=g;t=c[2426872]|0;u=c[3528552]|0;v=c[2433426]|0}else{s=a[m+(p&255)|0]|0;t=p;u=q;v=r}}while(0);r=s|j;j=(r&255)>>>4&8|a[9642744]&-15;a[9642744]=r<<24>>24==0?j|4:j;j=c[v+(u*3160|0)+60+((t>>>8&255|256)<<2)>>2]|0;if((j|0)!=0){a[j+(t&255)|0]=r;return}j=c[v+(u*3160|0)+3136>>2]|0;if((j|0)==0){return}gg[j&4095](t&65535,r);return}function fC7(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;l=f;m=g;break}n=gj[i&4095](e)|0;j=n;k=b[4821352]|0;l=c[3528552]|0;m=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=e;l=f;m=g}}while(0);b[4821352]=k+1&65535;c[2426872]=c[2410680];k=c[2410676]|0;g=k&65535;f=c[m+(l*3160|0)+60+((k>>>8&255|512)<<2)>>2]|0;do{if((f|0)==0){e=c[m+(l*3160|0)+3144>>2]|0;if((e|0)==0){o=0;p=g;q=l;r=m;break}d=gj[e&4095](g)|0;o=d;p=b[4821352]|0;q=c[3528552]|0;r=c[2433426]|0}else{o=a[f+(k&255)|0]|0;p=g;q=l;r=m}}while(0);a[9707488]=o;b[4821352]=p+1&65535;p=c[2426872]|0;o=p&65535;m=c[r+(q*3160|0)+60+((p>>>8&255)<<2)>>2]|0;do{if((m|0)==0){l=c[r+(q*3160|0)+3132>>2]|0;if((l|0)==0){s=0;t=p;u=q;v=r;break}g=gj[l&4095](o)|0;s=g;t=c[2426872]|0;u=c[3528552]|0;v=c[2433426]|0}else{s=a[m+(p&255)|0]|0;t=p;u=q;v=r}}while(0);r=s&j;j=(r&255)>>>4&8|a[9642744]&-15;a[9642744]=r<<24>>24==0?j|4:j;j=c[v+(u*3160|0)+60+((t>>>8&255|256)<<2)>>2]|0;if((j|0)!=0){a[j+(t&255)|0]=r;return}j=c[v+(u*3160|0)+3136>>2]|0;if((j|0)==0){return}gg[j&4095](t&65535,r);return}function fC8(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;c[2426872]=c[2410680];d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;l=f;m=g;break}n=gj[i&4095](e)|0;j=n;k=b[4821352]|0;l=c[3528552]|0;m=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=e;l=f;m=g}}while(0);a[9707488]=j;b[4821352]=k+1&65535;k=c[2426872]|0;j=k&65535;g=c[m+(l*3160|0)+60+((k>>>8&255)<<2)>>2]|0;do{if((g|0)==0){f=c[m+(l*3160|0)+3132>>2]|0;if((f|0)==0){o=0;p=k;q=l;r=m;break}e=gj[f&4095](j)|0;o=e;p=c[2426872]|0;q=c[3528552]|0;r=c[2433426]|0}else{o=a[g+(k&255)|0]|0;p=k;q=l;r=m}}while(0);m=~o;l=a[9642744]&-15|(m&255)>>>4&8;a[9642744]=(o<<24>>24==-1?l|4:l)|1;l=c[r+(q*3160|0)+60+((p>>>8&255|256)<<2)>>2]|0;if((l|0)!=0){a[l+(p&255)|0]=m;return}l=c[r+(q*3160|0)+3136>>2]|0;if((l|0)==0){return}gg[l&4095](p&65535,m);return}function fC9(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;c[2426872]=c[2410680];d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;l=f;m=g;break}n=gj[i&4095](e)|0;j=n;k=b[4821352]|0;l=c[3528552]|0;m=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=e;l=f;m=g}}while(0);a[9707488]=j;b[4821352]=k+1&65535;k=c[2426872]|0;j=k&65535;g=c[m+(l*3160|0)+60+((k>>>8&255)<<2)>>2]|0;do{if((g|0)==0){f=c[m+(l*3160|0)+3132>>2]|0;if((f|0)==0){o=0;p=k;q=l;r=m;break}e=gj[f&4095](j)|0;o=e;p=c[2426872]|0;q=c[3528552]|0;r=c[2433426]|0}else{o=a[g+(k&255)|0]|0;p=k;q=l;r=m}}while(0);m=a[9642744]&-14|o&1;l=(o&255)>>>1;a[9642744]=l<<24>>24==0?m|4:m;m=c[r+(q*3160|0)+60+((p>>>8&255|256)<<2)>>2]|0;if((m|0)!=0){a[m+(p&255)|0]=l;return}m=c[r+(q*3160|0)+3136>>2]|0;if((m|0)==0){return}gg[m&4095](p&65535,l);return}function fDa(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;l=f;m=g;break}n=gj[i&4095](e)|0;j=n;k=b[4821352]|0;l=c[3528552]|0;m=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=e;l=f;m=g}}while(0);b[4821352]=k+1&65535;c[2426872]=c[2410680];k=c[2410676]|0;g=k&65535;f=c[m+(l*3160|0)+60+((k>>>8&255|512)<<2)>>2]|0;do{if((f|0)==0){e=c[m+(l*3160|0)+3144>>2]|0;if((e|0)==0){o=0;p=g;q=l;r=m;break}d=gj[e&4095](g)|0;o=d;p=b[4821352]|0;q=c[3528552]|0;r=c[2433426]|0}else{o=a[f+(k&255)|0]|0;p=g;q=l;r=m}}while(0);a[9707488]=o;b[4821352]=p+1&65535;p=c[2426872]|0;o=p&65535;m=c[r+(q*3160|0)+60+((p>>>8&255)<<2)>>2]|0;do{if((m|0)==0){l=c[r+(q*3160|0)+3132>>2]|0;if((l|0)==0){s=0;t=p;u=q;v=r;break}g=gj[l&4095](o)|0;s=g;t=c[2426872]|0;u=c[3528552]|0;v=c[2433426]|0}else{s=a[m+(p&255)|0]|0;t=p;u=q;v=r}}while(0);r=s^j;q=(r&255)>>>4&8|a[9642744]&-15;a[9642744]=j<<24>>24==s<<24>>24?q|4:q;q=c[v+(u*3160|0)+60+((t>>>8&255|256)<<2)>>2]|0;if((q|0)!=0){a[q+(t&255)|0]=r;return}q=c[v+(u*3160|0)+3136>>2]|0;if((q|0)==0){return}gg[q&4095](t&65535,r);return}function fDb(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;c[2426872]=c[2410680];d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;l=f;m=g;break}n=gj[i&4095](e)|0;j=n;k=b[4821352]|0;l=c[3528552]|0;m=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=e;l=f;m=g}}while(0);a[9707488]=j;b[4821352]=k+1&65535;k=c[2426872]|0;j=k&65535;g=c[m+(l*3160|0)+60+((k>>>8&255)<<2)>>2]|0;do{if((g|0)==0){f=c[m+(l*3160|0)+3132>>2]|0;if((f|0)==0){o=0;p=k;q=l;r=m;break}e=gj[f&4095](j)|0;o=e;p=c[2426872]|0;q=c[3528552]|0;r=c[2433426]|0}else{o=a[g+(k&255)|0]|0;p=k;q=l;r=m}}while(0);m=a[9642744]|0;l=m<<7|(o&255)>>>1;k=m&-14|o&1|m<<3&8;a[9642744]=l<<24>>24==0?k|4:k;k=c[r+(q*3160|0)+60+((p>>>8&255|256)<<2)>>2]|0;if((k|0)!=0){a[k+(p&255)|0]=l;return}k=c[r+(q*3160|0)+3136>>2]|0;if((k|0)==0){return}gg[k&4095](p&65535,l);return}function fDc(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;c[2426872]=c[2410680];d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;l=f;m=g;break}n=gj[i&4095](e)|0;j=n;k=b[4821352]|0;l=c[3528552]|0;m=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=e;l=f;m=g}}while(0);a[9707488]=j;b[4821352]=k+1&65535;k=c[2426872]|0;j=k&65535;g=c[m+(l*3160|0)+60+((k>>>8&255)<<2)>>2]|0;do{if((g|0)==0){f=c[m+(l*3160|0)+3132>>2]|0;if((f|0)==0){o=0;p=k;q=l;r=m;break}e=gj[f&4095](j)|0;o=e;p=c[2426872]|0;q=c[3528552]|0;r=c[2433426]|0}else{o=a[g+(k&255)|0]|0;p=k;q=l;r=m}}while(0);m=o&-128|(o&255)>>>1;l=a[9642744]&-14|o&1|(o&255)>>>4&8;a[9642744]=m<<24>>24==0?l|4:l;l=c[r+(q*3160|0)+60+((p>>>8&255|256)<<2)>>2]|0;if((l|0)!=0){a[l+(p&255)|0]=m;return}l=c[r+(q*3160|0)+3136>>2]|0;if((l|0)==0){return}gg[l&4095](p&65535,m);return}function fDd(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;c[2426872]=c[2410680];d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;l=f;m=g;break}n=gj[i&4095](e)|0;j=n;k=b[4821352]|0;l=c[3528552]|0;m=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=e;l=f;m=g}}while(0);a[9707488]=j;b[4821352]=k+1&65535;k=c[2426872]|0;j=k&65535;g=c[m+(l*3160|0)+60+((k>>>8&255)<<2)>>2]|0;do{if((g|0)==0){f=c[m+(l*3160|0)+3132>>2]|0;if((f|0)==0){o=0;p=k;q=l;r=m;break}e=gj[f&4095](j)|0;o=e;p=c[2426872]|0;q=c[3528552]|0;r=c[2433426]|0}else{o=a[g+(k&255)|0]|0;p=k;q=l;r=m}}while(0);m=(o&255)<<1;o=m&65535;l=(o>>>4&8|a[9642744]&-16&255)&255;k=m&255;a[9642744]=((o>>>1^o)>>>6&2|o>>>8|(k<<24>>24==0?l|4:l)&255)&255;l=c[r+(q*3160|0)+60+((p>>>8&255|256)<<2)>>2]|0;if((l|0)!=0){a[l+(p&255)|0]=k;return}l=c[r+(q*3160|0)+3136>>2]|0;if((l|0)==0){return}gg[l&4095](p&65535,k);return}function fDe(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;c[2426872]=c[2410680];d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;l=f;m=g;break}n=gj[i&4095](e)|0;j=n;k=b[4821352]|0;l=c[3528552]|0;m=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=e;l=f;m=g}}while(0);a[9707488]=j;b[4821352]=k+1&65535;k=c[2426872]|0;j=k&65535;g=c[m+(l*3160|0)+60+((k>>>8&255)<<2)>>2]|0;do{if((g|0)==0){f=c[m+(l*3160|0)+3132>>2]|0;if((f|0)==0){o=0;p=k;q=l;r=m;break}e=gj[f&4095](j)|0;o=e;p=c[2426872]|0;q=c[3528552]|0;r=c[2433426]|0}else{o=a[g+(k&255)|0]|0;p=k;q=l;r=m}}while(0);m=a[9642744]|0;l=o&255;k=l<<1;g=m&-16|(o&255)>>>3&8;o=(m&1|k)&255;a[9642744]=((k^l)>>>6&2|l>>>7|(o<<24>>24==0?g|4:g)&255)&255;g=c[r+(q*3160|0)+60+((p>>>8&255|256)<<2)>>2]|0;if((g|0)!=0){a[g+(p&255)|0]=o;return}g=c[r+(q*3160|0)+3136>>2]|0;if((g|0)==0){return}gg[g&4095](p&65535,o);return}function fDf(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;c[2426872]=c[2410680];d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;l=f;m=g;break}n=gj[i&4095](e)|0;j=n;k=b[4821352]|0;l=c[3528552]|0;m=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=e;l=f;m=g}}while(0);a[9707488]=j;b[4821352]=k+1&65535;k=c[2426872]|0;j=k&65535;g=c[m+(l*3160|0)+60+((k>>>8&255)<<2)>>2]|0;do{if((g|0)==0){f=c[m+(l*3160|0)+3132>>2]|0;if((f|0)==0){o=0;p=k;q=l;r=m;break}e=gj[f&4095](j)|0;o=e;p=c[2426872]|0;q=c[3528552]|0;r=c[2433426]|0}else{o=a[g+(k&255)|0]|0;p=k;q=l;r=m}}while(0);m=o-1&255;a[9642744]=a[9642744]&-15|a[669184+(m&255)|0];o=c[r+(q*3160|0)+60+((p>>>8&255|256)<<2)>>2]|0;if((o|0)!=0){a[o+(p&255)|0]=m;return}o=c[r+(q*3160|0)+3136>>2]|0;if((o|0)==0){return}gg[o&4095](p&65535,m);return}function fDg(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;l=f;m=g;break}n=gj[i&4095](e)|0;j=n;k=b[4821352]|0;l=c[3528552]|0;m=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=e;l=f;m=g}}while(0);b[4821352]=k+1&65535;c[2426872]=c[2410680];k=c[2410676]|0;g=k&65535;f=c[m+(l*3160|0)+60+((k>>>8&255|512)<<2)>>2]|0;do{if((f|0)==0){e=c[m+(l*3160|0)+3144>>2]|0;if((e|0)==0){o=0;p=g;q=l;r=m;break}d=gj[e&4095](g)|0;o=d;p=b[4821352]|0;q=c[3528552]|0;r=c[2433426]|0}else{o=a[f+(k&255)|0]|0;p=g;q=l;r=m}}while(0);a[9707488]=o;b[4821352]=p+1&65535;p=c[2426872]|0;o=p&65535;m=c[r+(q*3160|0)+60+((p>>>8&255)<<2)>>2]|0;do{if((m|0)==0){l=c[r+(q*3160|0)+3132>>2]|0;if((l|0)==0){s=0;break}s=gj[l&4095](o)|0}else{s=a[m+(p&255)|0]|0}}while(0);p=s&j;j=(p&255)>>>4&8|a[9642744]&-15;a[9642744]=p<<24>>24==0?j|4:j;return}function fDh(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;c[2426872]=c[2410680];d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;l=f;m=g;break}n=gj[i&4095](e)|0;j=n;k=b[4821352]|0;l=c[3528552]|0;m=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=e;l=f;m=g}}while(0);a[9707488]=j;b[4821352]=k+1&65535;k=c[2426872]|0;j=k&65535;g=c[m+(l*3160|0)+60+((k>>>8&255)<<2)>>2]|0;do{if((g|0)==0){f=c[m+(l*3160|0)+3132>>2]|0;if((f|0)==0){o=0;p=k;q=l;r=m;break}e=gj[f&4095](j)|0;o=e;p=c[2426872]|0;q=c[3528552]|0;r=c[2433426]|0}else{o=a[g+(k&255)|0]|0;p=k;q=l;r=m}}while(0);m=o+1&255;a[9642744]=a[9642744]&-15|a[668928+(m&255)|0];o=c[r+(q*3160|0)+60+((p>>>8&255|256)<<2)>>2]|0;if((o|0)!=0){a[o+(p&255)|0]=m;return}o=c[r+(q*3160|0)+3136>>2]|0;if((o|0)==0){return}gg[o&4095](p&65535,m);return}function fDi(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c[2426872]=c[2410680];d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;l=f;m=g;break}n=gj[i&4095](e)|0;j=n;k=b[4821352]|0;l=c[3528552]|0;m=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=e;l=f;m=g}}while(0);a[9707488]=j;b[4821352]=k+1&65535;k=c[2426872]|0;j=k&65535;g=c[m+(l*3160|0)+60+((k>>>8&255)<<2)>>2]|0;do{if((g|0)==0){f=c[m+(l*3160|0)+3132>>2]|0;if((f|0)==0){o=0;break}o=gj[f&4095](j)|0}else{o=a[g+(k&255)|0]|0}}while(0);k=a[9642744]&-15|(o&255)>>>4&8;a[9642744]=o<<24>>24==0?k|4:k;return}function fDj(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;c[2426872]=c[2410680];d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;break}j=gj[i&4095](e)|0}else{j=a[h+(d&255)|0]|0}}while(0);a[9707488]=j;j=c[2426872]|0;c[2410676]=j;b[4821352]=j&65535;return}function fDk(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;c[2426872]=c[2410680];d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;l=f;m=g;break}n=gj[i&4095](e)|0;j=n;k=b[4821352]|0;l=c[3528552]|0;m=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=e;l=f;m=g}}while(0);a[9707488]=j;b[4821352]=k+1&65535;k=c[2426872]|0;j=k&65535;do{if((c[m+(l*3160|0)+60+((k>>>8&255)<<2)>>2]|0)==0){g=c[m+(l*3160|0)+3132>>2]|0;if((g|0)==0){o=k;p=l;q=m;break}gj[g&4095](j)|0;o=c[2426872]|0;p=c[3528552]|0;q=c[2433426]|0}else{o=k;p=l;q=m}}while(0);m=c[q+(p*3160|0)+60+((o>>>8&255|256)<<2)>>2]|0;if((m|0)!=0){a[m+(o&255)|0]=0;r=a[9642744]|0;s=r&-16;t=s|4;a[9642744]=t;return}m=c[q+(p*3160|0)+3136>>2]|0;if((m|0)==0){r=a[9642744]|0;s=r&-16;t=s|4;a[9642744]=t;return}gg[m&4095](o&65535,0);r=a[9642744]|0;s=r&-16;t=s|4;a[9642744]=t;return}function fDl(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=c[2410676]|0;f=e&65535;g=c[3528552]|0;h=c[2433426]|0;i=c[h+(g*3160|0)+60+((e>>>8&255|512)<<2)>>2]|0;do{if((i|0)==0){j=c[h+(g*3160|0)+3140>>2]|0;if((j|0)==0){k=0;l=f;break}m=gj[j&4095](f)|0;k=m;l=b[4821352]|0}else{k=a[i+(e&255)|0]|0;l=f}}while(0);b[4821352]=l+1&65535;l=k&255;gu[c[5872024+(l<<2)>>2]&16383]();c[2439272]=(c[2439272]|0)-(d[(c[2429672]|0)+l|0]|0);return}function fDm(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=c[2410676]|0;f=e&65535;g=c[3528552]|0;h=c[2433426]|0;i=c[h+(g*3160|0)+60+((e>>>8&255|512)<<2)>>2]|0;do{if((i|0)==0){j=c[h+(g*3160|0)+3140>>2]|0;if((j|0)==0){k=0;l=f;break}m=gj[j&4095](f)|0;k=m;l=b[4821352]|0}else{k=a[i+(e&255)|0]|0;l=f}}while(0);b[4821352]=l+1&65535;l=k&255;gu[c[5871e3+(l<<2)>>2]&16383]();c[2439272]=(c[2439272]|0)-(d[(c[2429670]|0)+l|0]|0);return}function fDn(){return}function fDo(){a[9642760]=a[9642760]|16;fC1();if(!((a[9642760]&16)!=0&(c[2439272]|0)>0)){return}c[2439272]=0;return}function fDp(){var c=0,d=0,f=0,g=0,h=0;c=e[4821358]|0;d=(c&32768|0)!=0?c|-65536:c;c=d>>>16;b[4821356]=c&65535;b[4821358]=d&65535;f=a[9642744]&-13;a[9642744]=f;g=d>>>28&8|f&255;if((c<<16|d&65535|0)!=0){h=g&255;a[9642744]=h;return}h=(g|4)&255;a[9642744]=h;return}function fDq(){a[9642745]=a[9642745]|64;fGQ();return}function fDr(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=(j&255)<<8;j=k+1|0;k=j&65535;g=c[m+(l*3160|0)+60+((j>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){f=c[m+(l*3160|0)+3144>>2]|0;if((f|0)==0){p=0;q=n;break}d=gj[f&4095](k)|0;p=d;q=b[4821352]|0}else{p=a[g+(j&255)|0]|0;q=n}}while(0);n=p&255|e;c[2426872]=n;e=n&65535;b[4821352]=(q+2&65535)+e&65535;b[4821352]=c[2410676]&65535;if(!(e<<16>>16==-3&(c[2439272]|0)>0)){return}c[2439272]=0;return}function fDs(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=(j&255)<<8;j=k+1|0;k=j&65535;g=c[m+(l*3160|0)+60+((j>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){f=c[m+(l*3160|0)+3144>>2]|0;if((f|0)==0){p=0;q=n;r=l;s=m;break}d=gj[f&4095](k)|0;p=d;q=b[4821352]|0;r=c[3528552]|0;s=c[2433426]|0}else{p=a[g+(j&255)|0]|0;q=n;r=l;s=m}}while(0);c[2426872]=p&255|e;e=q+2&65535;b[4821352]=e;b[4821364]=(b[4821364]|0)-1&65535;q=c[2410682]|0;p=q&65535;m=e&255;e=c[s+(r*3160|0)+60+((q>>>8&255|256)<<2)>>2]|0;do{if((e|0)==0){l=c[s+(r*3160|0)+3136>>2]|0;if((l|0)==0){t=r;u=s;break}gg[l&4095](p,m);t=c[3528552]|0;u=c[2433426]|0}else{a[e+(q&255)|0]=m;t=r;u=s}}while(0);b[4821364]=(b[4821364]|0)-1&65535;s=c[2410682]|0;r=a[9642705]|0;m=c[u+(t*3160|0)+60+((s>>>8&255|256)<<2)>>2]|0;if((m|0)!=0){a[m+(s&255)|0]=r;v=b[4853744]|0;w=b[4821352]|0;x=w+v&65535;b[4821352]=x;y=c[2410676]|0;z=y&65535;b[4821352]=z;return}m=c[u+(t*3160|0)+3136>>2]|0;if((m|0)==0){v=b[4853744]|0;w=b[4821352]|0;x=w+v&65535;b[4821352]=x;y=c[2410676]|0;z=y&65535;b[4821352]=z;return}gg[m&4095](s&65535,r);v=b[4853744]|0;w=b[4821352]|0;x=w+v&65535;b[4821352]=x;y=c[2410676]|0;z=y&65535;b[4821352]=z;return}function fDt(){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=a[9642713]|0;c=b&-16;d=(b&14)>9;if(d){e=7112}else{if((a[9642744]&32)==0){f=0}else{e=7112}}if((e|0)==7112){f=6}do{if((c&255)>128){g=d?f|96:f;if((c&255)<=144){h=g;e=7116;break}i=g;j=a[9642744]|0;e=7117}else{h=f;e=7116}}while(0);if((e|0)==7116){f=a[9642744]|0;if((f&1)==0){k=h;l=f}else{i=h;j=f;e=7117}}if((e|0)==7117){k=i|96;l=j}j=k+(b&255)&65535;b=j&255;k=j&65535;j=(k>>>4&8|l&-15&255)&255;a[9642744]=((b<<24>>24==0?j|4:j)&255|k>>>8&1)&255;a[9642713]=b;return}function fDu(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;break}l=gj[i&4095](e)|0;j=l;k=b[4821352]|0}else{j=a[h+(d&255)|0]|0;k=e}}while(0);b[4821352]=k+1&65535;a[9642744]=a[9642744]|j;fC1();return}function fDv(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;break}l=gj[i&4095](e)|0;j=l;k=b[4821352]|0}else{j=a[h+(d&255)|0]|0;k=e}}while(0);b[4821352]=k+1&65535;a[9642744]=a[9642744]&j;fC1();return}function fDw(){var c=0,e=0,f=0;c=d[9642712]|0;e=(c&128|0)!=0?c|65280:c;c=e&65535;b[4821356]=c;f=(e>>>12&8|a[9642744]&-13&255)&255;a[9642744]=c<<16>>16==0?f|4:f;return}function fDx(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=c[2410676]|0;f=e&65535;g=c[3528552]|0;h=c[2433426]|0;i=c[h+(g*3160|0)+60+((e>>>8&255|512)<<2)>>2]|0;do{if((i|0)==0){j=c[h+(g*3160|0)+3144>>2]|0;if((j|0)==0){k=0;l=f;break}m=gj[j&4095](f)|0;k=m;l=b[4821352]|0}else{k=a[i+(e&255)|0]|0;l=f}}while(0);f=l+1&65535;b[4821352]=f;l=k&255;k=l>>>4;e=(k^l)&8;i=(e|0)==0;g=e>>>3;L8898:do{switch(k|0){case 2:{n=b[4821368]|0;break};case 4:{n=b[4821364]|0;break};case 1:{n=b[4821366]|0;break};case 7:{n=b[4821370]|0;break};case 0:{n=b[4821356]|0;break};case 5:{n=f;break};case 6:{n=b[4821358]|0;break};case 3:{n=b[4821362]|0;break};case 9:{e=d[9642712]|0;if(i){n=e;break L8898}n=e*257&65535;break};case 11:{e=d[9642721]|0;if(i){n=e;break L8898}n=e*257&65535;break};case 8:{e=d[9642713]|0;if(i){n=e;break L8898}n=e*257&65535;break};case 10:{e=d[9642744]|0;if(i){n=e;break L8898}n=e*257&65535;break};case 14:{e=d[9642717]|0;if(i){n=e;break L8898}n=e*257&65535;break};case 12:case 13:{n=0;break};default:{e=d[9642716]|0;if(i){n=e;break L8898}n=e*257&65535}}}while(0);e=l&15;L8920:do{switch(e|0){case 0:{o=b[4821356]|0;break};case 1:{o=b[4821366]|0;break};case 2:{o=b[4821368]|0;break};case 3:{o=b[4821362]|0;break};case 4:{o=b[4821364]|0;break};case 5:{o=f;break};case 6:{o=b[4821358]|0;break};case 7:{o=b[4821370]|0;break};case 8:{l=d[9642713]|0;if(i){o=l;break L8920}o=l*257&65535;break};case 9:{l=d[9642712]|0;if(i){o=l;break L8920}o=l*257&65535;break};case 10:{l=d[9642744]|0;if(i){o=l;break L8920}o=l*257&65535;break};case 11:{l=d[9642721]|0;if(i){o=l;break L8920}o=l*257&65535;break};case 14:{l=d[9642717]|0;if(i){o=l;break L8920}o=l*257&65535;break};case 12:case 13:{o=0;break};default:{l=d[9642716]|0;if(i){o=l;break L8920}o=l*257&65535}}}while(0);switch(k|0){case 0:{b[4821356]=o;break};case 1:{b[4821366]=o;break};case 2:{b[4821368]=o;break};case 3:{b[4821362]=o;break};case 4:{b[4821364]=o;break};case 5:{b[4821352]=o;b[4821352]=c[2410676]&65535;break};case 6:{b[4821358]=o;break};case 7:{b[4821370]=o;break};case 8:{k=o&65535;a[9642713]=((g|0)!=0?k>>>8:k)&255;break};case 9:{a[9642712]=o&255;break};case 10:{a[9642744]=o&255;break};case 11:{k=o&65535;a[9642721]=((g|0)!=0?k>>>8:k)&255;break};case 14:{k=o&65535;a[9642717]=((g|0)!=0?k>>>8:k)&255;break};case 15:{a[9642716]=o&255;break};default:{}}switch(e|0){case 0:{b[4821356]=n;return};case 1:{b[4821366]=n;return};case 2:{b[4821368]=n;return};case 3:{b[4821362]=n;return};case 4:{b[4821364]=n;return};case 5:{b[4821352]=n;b[4821352]=c[2410676]&65535;return};case 6:{b[4821358]=n;return};case 7:{b[4821370]=n;return};case 8:{e=n&65535;a[9642713]=((g|0)!=0?e>>>8:e)&255;return};case 9:{a[9642712]=n&255;return};case 10:{a[9642744]=n&255;return};case 11:{e=n&65535;a[9642721]=((g|0)!=0?e>>>8:e)&255;return};case 14:{e=n&65535;a[9642717]=((g|0)!=0?e>>>8:e)&255;return};case 15:{a[9642716]=n&255;return};default:{return}}}function fDy(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=c[2410676]|0;f=e&65535;g=c[3528552]|0;h=c[2433426]|0;i=c[h+(g*3160|0)+60+((e>>>8&255|512)<<2)>>2]|0;do{if((i|0)==0){j=c[h+(g*3160|0)+3144>>2]|0;if((j|0)==0){k=0;l=f;break}m=gj[j&4095](f)|0;k=m;l=b[4821352]|0}else{k=a[i+(e&255)|0]|0;l=f}}while(0);f=l+1&65535;b[4821352]=f;l=k&255;k=l>>>4;e=(k^l)&8;i=(e|0)==0;g=e>>>3;L8994:do{switch(k|0){case 9:{e=d[9642712]|0;if(i){n=e;break L8994}n=e*257&65535;break};case 8:{e=d[9642713]|0;if(i){n=e;break L8994}n=e*257&65535;break};case 5:{n=f;break};case 3:{n=b[4821362]|0;break};case 6:{n=b[4821358]|0;break};case 0:{n=b[4821356]|0;break};case 7:{n=b[4821370]|0;break};case 2:{n=b[4821368]|0;break};case 1:{n=b[4821366]|0;break};case 4:{n=b[4821364]|0;break};case 10:{e=d[9642744]|0;if(i){n=e;break L8994}n=e*257&65535;break};case 12:case 13:{n=0;break};case 14:{e=d[9642717]|0;if(i){n=e;break L8994}n=e*257&65535;break};case 11:{e=d[9642721]|0;if(i){n=e;break L8994}n=e*257&65535;break};default:{e=d[9642716]|0;if(i){n=e;break L8994}n=e*257&65535}}}while(0);switch(l&15|0){case 10:{a[9642744]=n&255;return};case 6:{b[4821358]=n;return};case 5:{b[4821352]=n;b[4821352]=c[2410676]&65535;return};case 2:{b[4821368]=n;return};case 1:{b[4821366]=n;return};case 3:{b[4821362]=n;return};case 7:{b[4821370]=n;return};case 0:{b[4821356]=n;return};case 4:{b[4821364]=n;return};case 11:{l=n&65535;a[9642721]=((g|0)!=0?l>>>8:l)&255;return};case 15:{a[9642716]=n&255;return};case 14:{l=n&65535;a[9642717]=((g|0)!=0?l>>>8:l)&255;return};case 8:{l=n&65535;a[9642713]=((g|0)!=0?l>>>8:l)&255;return};case 9:{a[9642712]=n&255;return};default:{return}}}function fDz(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;break}l=gj[i&4095](e)|0;j=l;k=b[4821352]|0}else{j=a[h+(d&255)|0]|0;k=e}}while(0);e=j&255;b[4821352]=((e&128|0)!=0?e|65280:e)+(k+1&65535)&65535;b[4821352]=c[2410676]&65535;if(!(j<<24>>24==-2&(c[2439272]|0)>0)){return}c[2439272]=0;return}function fDA(){var a=0,d=0,e=0,f=0,g=0,h=0;a=c[2410676]|0;d=a&65535;e=c[3528552]|0;f=c[2433426]|0;do{if((c[f+(e*3160|0)+60+((a>>>8&255|512)<<2)>>2]|0)==0){g=c[f+(e*3160|0)+3144>>2]|0;if((g|0)==0){h=d;break}gj[g&4095](d)|0;h=b[4821352]|0}else{h=d}}while(0);b[4821352]=h+1&65535;return}function fDB(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;break}l=gj[i&4095](e)|0;j=l;k=b[4821352]|0}else{j=a[h+(d&255)|0]|0;k=e}}while(0);e=k+1&65535;b[4821352]=e;if((a[9642744]&5)!=0){return}k=j&255;b[4821352]=((k&128|0)!=0?k|65280:k)+(e&65535)&65535;b[4821352]=c[2410676]&65535;return}function fDC(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;break}l=gj[i&4095](e)|0;j=l;k=b[4821352]|0}else{j=a[h+(d&255)|0]|0;k=e}}while(0);e=k+1&65535;b[4821352]=e;if((a[9642744]&5)==0){return}k=j&255;b[4821352]=((k&128|0)!=0?k|65280:k)+(e&65535)&65535;b[4821352]=c[2410676]&65535;return}function fDD(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;break}l=gj[i&4095](e)|0;j=l;k=b[4821352]|0}else{j=a[h+(d&255)|0]|0;k=e}}while(0);e=k+1&65535;b[4821352]=e;if((a[9642744]&1)!=0){return}k=j&255;b[4821352]=((k&128|0)!=0?k|65280:k)+(e&65535)&65535;b[4821352]=c[2410676]&65535;return}function fDE(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;break}l=gj[i&4095](e)|0;j=l;k=b[4821352]|0}else{j=a[h+(d&255)|0]|0;k=e}}while(0);e=k+1&65535;b[4821352]=e;if((a[9642744]&1)==0){return}k=j&255;b[4821352]=((k&128|0)!=0?k|65280:k)+(e&65535)&65535;b[4821352]=c[2410676]&65535;return}function fDF(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;break}l=gj[i&4095](e)|0;j=l;k=b[4821352]|0}else{j=a[h+(d&255)|0]|0;k=e}}while(0);e=k+1&65535;b[4821352]=e;if((a[9642744]&4)!=0){return}k=j&255;b[4821352]=((k&128|0)!=0?k|65280:k)+(e&65535)&65535;b[4821352]=c[2410676]&65535;return}function fDG(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;break}l=gj[i&4095](e)|0;j=l;k=b[4821352]|0}else{j=a[h+(d&255)|0]|0;k=e}}while(0);e=k+1&65535;b[4821352]=e;if((a[9642744]&4)==0){return}k=j&255;b[4821352]=((k&128|0)!=0?k|65280:k)+(e&65535)&65535;b[4821352]=c[2410676]&65535;return}function fDH(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;break}l=gj[i&4095](e)|0;j=l;k=b[4821352]|0}else{j=a[h+(d&255)|0]|0;k=e}}while(0);e=k+1&65535;b[4821352]=e;if((a[9642744]&2)!=0){return}k=j&255;b[4821352]=((k&128|0)!=0?k|65280:k)+(e&65535)&65535;b[4821352]=c[2410676]&65535;return}function fDI(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;break}l=gj[i&4095](e)|0;j=l;k=b[4821352]|0}else{j=a[h+(d&255)|0]|0;k=e}}while(0);e=k+1&65535;b[4821352]=e;if((a[9642744]&2)==0){return}k=j&255;b[4821352]=((k&128|0)!=0?k|65280:k)+(e&65535)&65535;b[4821352]=c[2410676]&65535;return}function fDJ(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;break}l=gj[i&4095](e)|0;j=l;k=b[4821352]|0}else{j=a[h+(d&255)|0]|0;k=e}}while(0);e=k+1&65535;b[4821352]=e;if((a[9642744]&8)!=0){return}k=j&255;b[4821352]=((k&128|0)!=0?k|65280:k)+(e&65535)&65535;b[4821352]=c[2410676]&65535;return}function fDK(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;break}l=gj[i&4095](e)|0;j=l;k=b[4821352]|0}else{j=a[h+(d&255)|0]|0;k=e}}while(0);e=k+1&65535;b[4821352]=e;if((a[9642744]&8)==0){return}k=j&255;b[4821352]=((k&128|0)!=0?k|65280:k)+(e&65535)&65535;b[4821352]=c[2410676]&65535;return}function fDL(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=c[2410676]|0;f=e&65535;g=c[3528552]|0;h=c[2433426]|0;i=c[h+(g*3160|0)+60+((e>>>8&255|512)<<2)>>2]|0;do{if((i|0)==0){j=c[h+(g*3160|0)+3144>>2]|0;if((j|0)==0){k=0;l=f;break}m=gj[j&4095](f)|0;k=m;l=b[4821352]|0}else{k=a[i+(e&255)|0]|0;l=f}}while(0);f=l+1&65535;b[4821352]=f;l=d[9642744]|0;if(((l<<2^l)&8|0)!=0){return}l=k&255;b[4821352]=((l&128|0)!=0?l|65280:l)+(f&65535)&65535;b[4821352]=c[2410676]&65535;return}function fDM(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=c[2410676]|0;f=e&65535;g=c[3528552]|0;h=c[2433426]|0;i=c[h+(g*3160|0)+60+((e>>>8&255|512)<<2)>>2]|0;do{if((i|0)==0){j=c[h+(g*3160|0)+3144>>2]|0;if((j|0)==0){k=0;l=f;break}m=gj[j&4095](f)|0;k=m;l=b[4821352]|0}else{k=a[i+(e&255)|0]|0;l=f}}while(0);f=l+1&65535;b[4821352]=f;l=d[9642744]|0;if(((l<<2^l)&8|0)==0){return}l=k&255;b[4821352]=((l&128|0)!=0?l|65280:l)+(f&65535)&65535;b[4821352]=c[2410676]&65535;return}function fDN(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=c[2410676]|0;f=e&65535;g=c[3528552]|0;h=c[2433426]|0;i=c[h+(g*3160|0)+60+((e>>>8&255|512)<<2)>>2]|0;do{if((i|0)==0){j=c[h+(g*3160|0)+3144>>2]|0;if((j|0)==0){k=0;l=f;break}m=gj[j&4095](f)|0;k=m;l=b[4821352]|0}else{k=a[i+(e&255)|0]|0;l=f}}while(0);f=l+1&65535;b[4821352]=f;l=d[9642744]|0;if(((l<<2^l)&8|l&4|0)!=0){return}l=k&255;b[4821352]=((l&128|0)!=0?l|65280:l)+(f&65535)&65535;b[4821352]=c[2410676]&65535;return}function fDO(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=c[2410676]|0;f=e&65535;g=c[3528552]|0;h=c[2433426]|0;i=c[h+(g*3160|0)+60+((e>>>8&255|512)<<2)>>2]|0;do{if((i|0)==0){j=c[h+(g*3160|0)+3144>>2]|0;if((j|0)==0){k=0;l=f;break}m=gj[j&4095](f)|0;k=m;l=b[4821352]|0}else{k=a[i+(e&255)|0]|0;l=f}}while(0);f=l+1&65535;b[4821352]=f;l=d[9642744]|0;if(((l<<2^l)&8|l&4|0)==0){return}l=k&255;b[4821352]=((l&128|0)!=0?l|65280:l)+(f&65535)&65535;b[4821352]=c[2410676]&65535;return}function fDP(){var c=0,d=0;fGP();c=b[4853744]|0;b[4821366]=c;d=a[9642744]|0;a[9642744]=c<<16>>16==0?d|4:d&-5;return}function fDQ(){var c=0,d=0;fGP();c=b[4853744]|0;b[4821368]=c;d=a[9642744]|0;a[9642744]=c<<16>>16==0?d|4:d&-5;return}function fDR(){fGP();b[4821364]=b[4853744]|0;a[9642760]=a[9642760]|32;return}function fDS(){fGP();b[4821362]=b[4853744]|0;return}function fDT(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;break}l=gj[i&4095](e)|0;j=l;k=b[4821352]|0}else{j=a[h+(d&255)|0]|0;k=e}}while(0);e=k+1&65535;b[4821352]=e;k=j&255;if((k&128|0)!=0){j=e&255;b[4821364]=(b[4821364]|0)-1&65535;e=c[2410682]|0;d=e&65535;h=c[3528552]|0;f=c[2433426]|0;g=c[f+(h*3160|0)+60+((e>>>8&255|256)<<2)>>2]|0;do{if((g|0)==0){l=c[f+(h*3160|0)+3136>>2]|0;if((l|0)==0){m=h;n=f;break}gg[l&4095](d,j);m=c[3528552]|0;n=c[2433426]|0}else{a[g+(e&255)|0]=j;m=h;n=f}}while(0);b[4821364]=(b[4821364]|0)-1&65535;f=c[2410682]|0;h=f&65535;j=a[9642705]|0;e=c[n+(m*3160|0)+60+((f>>>8&255|256)<<2)>>2]|0;do{if((e|0)==0){g=c[n+(m*3160|0)+3136>>2]|0;if((g|0)==0){break}gg[g&4095](h,j)}else{a[e+(f&255)|0]=j}}while(0);c[2439272]=(c[2439272]|0)-2}if((k&64|0)!=0){b[4821364]=(b[4821364]|0)-1&65535;j=c[2410682]|0;f=j&65535;e=a[9642724]|0;h=c[3528552]|0;m=c[2433426]|0;n=c[m+(h*3160|0)+60+((j>>>8&255|256)<<2)>>2]|0;do{if((n|0)==0){g=c[m+(h*3160|0)+3136>>2]|0;if((g|0)==0){o=h;p=m;break}gg[g&4095](f,e);o=c[3528552]|0;p=c[2433426]|0}else{a[n+(j&255)|0]=e;o=h;p=m}}while(0);b[4821364]=(b[4821364]|0)-1&65535;m=c[2410682]|0;h=m&65535;e=a[9642725]|0;j=c[p+(o*3160|0)+60+((m>>>8&255|256)<<2)>>2]|0;do{if((j|0)==0){n=c[p+(o*3160|0)+3136>>2]|0;if((n|0)==0){break}gg[n&4095](h,e)}else{a[j+(m&255)|0]=e}}while(0);c[2439272]=(c[2439272]|0)-2}if((k&32|0)!=0){b[4821364]=(b[4821364]|0)-1&65535;e=c[2410682]|0;m=e&65535;j=a[9642736]|0;h=c[3528552]|0;o=c[2433426]|0;p=c[o+(h*3160|0)+60+((e>>>8&255|256)<<2)>>2]|0;do{if((p|0)==0){n=c[o+(h*3160|0)+3136>>2]|0;if((n|0)==0){q=h;r=o;break}gg[n&4095](m,j);q=c[3528552]|0;r=c[2433426]|0}else{a[p+(e&255)|0]=j;q=h;r=o}}while(0);b[4821364]=(b[4821364]|0)-1&65535;o=c[2410682]|0;h=o&65535;j=a[9642737]|0;e=c[r+(q*3160|0)+60+((o>>>8&255|256)<<2)>>2]|0;do{if((e|0)==0){p=c[r+(q*3160|0)+3136>>2]|0;if((p|0)==0){break}gg[p&4095](h,j)}else{a[e+(o&255)|0]=j}}while(0);c[2439272]=(c[2439272]|0)-2}if((k&16|0)!=0){b[4821364]=(b[4821364]|0)-1&65535;j=c[2410682]|0;o=j&65535;e=a[9642732]|0;h=c[3528552]|0;q=c[2433426]|0;r=c[q+(h*3160|0)+60+((j>>>8&255|256)<<2)>>2]|0;do{if((r|0)==0){p=c[q+(h*3160|0)+3136>>2]|0;if((p|0)==0){s=h;t=q;break}gg[p&4095](o,e);s=c[3528552]|0;t=c[2433426]|0}else{a[r+(j&255)|0]=e;s=h;t=q}}while(0);b[4821364]=(b[4821364]|0)-1&65535;q=c[2410682]|0;h=q&65535;e=a[9642733]|0;j=c[t+(s*3160|0)+60+((q>>>8&255|256)<<2)>>2]|0;do{if((j|0)==0){r=c[t+(s*3160|0)+3136>>2]|0;if((r|0)==0){break}gg[r&4095](h,e)}else{a[j+(q&255)|0]=e}}while(0);c[2439272]=(c[2439272]|0)-2}if((k&8|0)!=0){b[4821364]=(b[4821364]|0)-1&65535;e=c[2410682]|0;q=e&65535;j=a[9642721]|0;h=c[3528552]|0;s=c[2433426]|0;t=c[s+(h*3160|0)+60+((e>>>8&255|256)<<2)>>2]|0;do{if((t|0)==0){r=c[s+(h*3160|0)+3136>>2]|0;if((r|0)==0){break}gg[r&4095](q,j)}else{a[t+(e&255)|0]=j}}while(0);c[2439272]=(c[2439272]|0)-1}if((k&4|0)!=0){b[4821364]=(b[4821364]|0)-1&65535;j=c[2410682]|0;e=j&65535;t=a[9642712]|0;q=c[3528552]|0;h=c[2433426]|0;s=c[h+(q*3160|0)+60+((j>>>8&255|256)<<2)>>2]|0;do{if((s|0)==0){r=c[h+(q*3160|0)+3136>>2]|0;if((r|0)==0){break}gg[r&4095](e,t)}else{a[s+(j&255)|0]=t}}while(0);c[2439272]=(c[2439272]|0)-1}if((k&2|0)!=0){b[4821364]=(b[4821364]|0)-1&65535;t=c[2410682]|0;j=t&65535;s=a[9642713]|0;e=c[3528552]|0;q=c[2433426]|0;h=c[q+(e*3160|0)+60+((t>>>8&255|256)<<2)>>2]|0;do{if((h|0)==0){r=c[q+(e*3160|0)+3136>>2]|0;if((r|0)==0){break}gg[r&4095](j,s)}else{a[h+(t&255)|0]=s}}while(0);c[2439272]=(c[2439272]|0)-1}if((k&1|0)==0){return}b[4821364]=(b[4821364]|0)-1&65535;k=c[2410682]|0;s=k&65535;t=a[9642744]|0;h=c[3528552]|0;j=c[2433426]|0;e=c[j+(h*3160|0)+60+((k>>>8&255|256)<<2)>>2]|0;do{if((e|0)==0){q=c[j+(h*3160|0)+3136>>2]|0;if((q|0)==0){break}gg[q&4095](s,t)}else{a[e+(k&255)|0]=t}}while(0);c[2439272]=(c[2439272]|0)-1;return}function fDU(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;break}l=gj[i&4095](e)|0;j=l;k=b[4821352]|0}else{j=a[h+(d&255)|0]|0;k=e}}while(0);b[4821352]=k+1&65535;k=j&255;j=(k&1|0)!=0;if(j){e=c[2410682]|0;d=e&65535;h=c[3528552]|0;f=c[2433426]|0;g=c[f+(h*3160|0)+60+((e>>>8&255)<<2)>>2]|0;do{if((g|0)==0){l=c[f+(h*3160|0)+3132>>2]|0;if((l|0)==0){m=0;n=d;break}i=gj[l&4095](d)|0;m=i;n=b[4821364]|0}else{m=a[g+(e&255)|0]|0;n=d}}while(0);a[9642744]=m;b[4821364]=n+1&65535;c[2439272]=(c[2439272]|0)-1}if((k&2|0)!=0){n=c[2410682]|0;m=n&65535;d=c[3528552]|0;e=c[2433426]|0;g=c[e+(d*3160|0)+60+((n>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[e+(d*3160|0)+3132>>2]|0;if((h|0)==0){o=0;p=m;break}f=gj[h&4095](m)|0;o=f;p=b[4821364]|0}else{o=a[g+(n&255)|0]|0;p=m}}while(0);a[9642713]=o;b[4821364]=p+1&65535;c[2439272]=(c[2439272]|0)-1}if((k&4|0)!=0){p=c[2410682]|0;o=p&65535;m=c[3528552]|0;n=c[2433426]|0;g=c[n+(m*3160|0)+60+((p>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[n+(m*3160|0)+3132>>2]|0;if((d|0)==0){q=0;r=o;break}e=gj[d&4095](o)|0;q=e;r=b[4821364]|0}else{q=a[g+(p&255)|0]|0;r=o}}while(0);a[9642712]=q;b[4821364]=r+1&65535;c[2439272]=(c[2439272]|0)-1}if((k&8|0)!=0){r=c[2410682]|0;q=r&65535;o=c[3528552]|0;p=c[2433426]|0;g=c[p+(o*3160|0)+60+((r>>>8&255)<<2)>>2]|0;do{if((g|0)==0){m=c[p+(o*3160|0)+3132>>2]|0;if((m|0)==0){s=0;t=q;break}n=gj[m&4095](q)|0;s=n;t=b[4821364]|0}else{s=a[g+(r&255)|0]|0;t=q}}while(0);a[9642721]=s;b[4821364]=t+1&65535;c[2439272]=(c[2439272]|0)-1}if((k&16|0)!=0){t=c[2410682]|0;s=t&65535;q=c[3528552]|0;r=c[2433426]|0;g=c[r+(q*3160|0)+60+((t>>>8&255)<<2)>>2]|0;do{if((g|0)==0){o=c[r+(q*3160|0)+3132>>2]|0;if((o|0)==0){u=0;v=s;w=q;x=r;break}p=gj[o&4095](s)|0;u=p;v=b[4821364]|0;w=c[3528552]|0;x=c[2433426]|0}else{u=a[g+(t&255)|0]|0;v=s;w=q;x=r}}while(0);r=(u&255)<<8;c[2410683]=r;b[4821364]=v+1&65535;v=c[2410682]|0;u=v&65535;q=c[x+(w*3160|0)+60+((v>>>8&255)<<2)>>2]|0;do{if((q|0)==0){s=c[x+(w*3160|0)+3132>>2]|0;if((s|0)==0){y=0;z=r;A=u;break}t=gj[s&4095](u)|0;y=t;z=c[2410683]|0;A=b[4821364]|0}else{y=a[q+(v&255)|0]|0;z=r;A=u}}while(0);c[2410683]=z|y&255;b[4821364]=A+1&65535;c[2439272]=(c[2439272]|0)-2}if((k&32|0)!=0){A=c[2410682]|0;y=A&65535;z=c[3528552]|0;u=c[2433426]|0;r=c[u+(z*3160|0)+60+((A>>>8&255)<<2)>>2]|0;do{if((r|0)==0){v=c[u+(z*3160|0)+3132>>2]|0;if((v|0)==0){B=0;C=y;D=z;E=u;break}q=gj[v&4095](y)|0;B=q;C=b[4821364]|0;D=c[3528552]|0;E=c[2433426]|0}else{B=a[r+(A&255)|0]|0;C=y;D=z;E=u}}while(0);u=(B&255)<<8;c[2410684]=u;b[4821364]=C+1&65535;C=c[2410682]|0;B=C&65535;z=c[E+(D*3160|0)+60+((C>>>8&255)<<2)>>2]|0;do{if((z|0)==0){y=c[E+(D*3160|0)+3132>>2]|0;if((y|0)==0){F=0;G=u;H=B;break}A=gj[y&4095](B)|0;F=A;G=c[2410684]|0;H=b[4821364]|0}else{F=a[z+(C&255)|0]|0;G=u;H=B}}while(0);c[2410684]=G|F&255;b[4821364]=H+1&65535;c[2439272]=(c[2439272]|0)-2}if((k&64|0)!=0){H=c[2410682]|0;F=H&65535;G=c[3528552]|0;B=c[2433426]|0;u=c[B+(G*3160|0)+60+((H>>>8&255)<<2)>>2]|0;do{if((u|0)==0){C=c[B+(G*3160|0)+3132>>2]|0;if((C|0)==0){I=0;J=F;K=G;L=B;break}z=gj[C&4095](F)|0;I=z;J=b[4821364]|0;K=c[3528552]|0;L=c[2433426]|0}else{I=a[u+(H&255)|0]|0;J=F;K=G;L=B}}while(0);B=(I&255)<<8;c[2410681]=B;b[4821364]=J+1&65535;J=c[2410682]|0;I=J&65535;G=c[L+(K*3160|0)+60+((J>>>8&255)<<2)>>2]|0;do{if((G|0)==0){F=c[L+(K*3160|0)+3132>>2]|0;if((F|0)==0){M=0;N=B;O=I;break}H=gj[F&4095](I)|0;M=H;N=c[2410681]|0;O=b[4821364]|0}else{M=a[G+(J&255)|0]|0;N=B;O=I}}while(0);c[2410681]=N|M&255;b[4821364]=O+1&65535;c[2439272]=(c[2439272]|0)-2}if((k&128|0)!=0){k=c[2410682]|0;O=k&65535;M=c[3528552]|0;N=c[2433426]|0;I=c[N+(M*3160|0)+60+((k>>>8&255)<<2)>>2]|0;do{if((I|0)==0){B=c[N+(M*3160|0)+3132>>2]|0;if((B|0)==0){P=0;Q=O;R=M;S=N;break}J=gj[B&4095](O)|0;P=J;Q=b[4821364]|0;R=c[3528552]|0;S=c[2433426]|0}else{P=a[I+(k&255)|0]|0;Q=O;R=M;S=N}}while(0);N=(P&255)<<8;c[2410676]=N;b[4821364]=Q+1&65535;Q=c[2410682]|0;P=Q&65535;M=c[S+(R*3160|0)+60+((Q>>>8&255)<<2)>>2]|0;do{if((M|0)==0){O=c[S+(R*3160|0)+3132>>2]|0;if((O|0)==0){T=0;U=N;V=P;break}k=gj[O&4095](P)|0;T=k;U=c[2410676]|0;V=b[4821364]|0}else{T=a[M+(Q&255)|0]|0;U=N;V=P}}while(0);P=U|T&255;c[2410676]=P;b[4821364]=V+1&65535;b[4821352]=P&65535;c[2439272]=(c[2439272]|0)-2}if(!j){return}fC1();return}function fDV(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;break}l=gj[i&4095](e)|0;j=l;k=b[4821352]|0}else{j=a[h+(d&255)|0]|0;k=e}}while(0);e=k+1&65535;b[4821352]=e;k=j&255;if((k&128|0)!=0){j=e&255;b[4821362]=(b[4821362]|0)-1&65535;e=c[2410681]|0;d=e&65535;h=c[3528552]|0;f=c[2433426]|0;g=c[f+(h*3160|0)+60+((e>>>8&255|256)<<2)>>2]|0;do{if((g|0)==0){l=c[f+(h*3160|0)+3136>>2]|0;if((l|0)==0){m=h;n=f;break}gg[l&4095](d,j);m=c[3528552]|0;n=c[2433426]|0}else{a[g+(e&255)|0]=j;m=h;n=f}}while(0);b[4821362]=(b[4821362]|0)-1&65535;f=c[2410681]|0;h=f&65535;j=a[9642705]|0;e=c[n+(m*3160|0)+60+((f>>>8&255|256)<<2)>>2]|0;do{if((e|0)==0){g=c[n+(m*3160|0)+3136>>2]|0;if((g|0)==0){break}gg[g&4095](h,j)}else{a[e+(f&255)|0]=j}}while(0);c[2439272]=(c[2439272]|0)-2}if((k&64|0)!=0){b[4821362]=(b[4821362]|0)-1&65535;j=c[2410681]|0;f=j&65535;e=a[9642728]|0;h=c[3528552]|0;m=c[2433426]|0;n=c[m+(h*3160|0)+60+((j>>>8&255|256)<<2)>>2]|0;do{if((n|0)==0){g=c[m+(h*3160|0)+3136>>2]|0;if((g|0)==0){o=h;p=m;break}gg[g&4095](f,e);o=c[3528552]|0;p=c[2433426]|0}else{a[n+(j&255)|0]=e;o=h;p=m}}while(0);b[4821362]=(b[4821362]|0)-1&65535;m=c[2410681]|0;h=m&65535;e=a[9642729]|0;j=c[p+(o*3160|0)+60+((m>>>8&255|256)<<2)>>2]|0;do{if((j|0)==0){n=c[p+(o*3160|0)+3136>>2]|0;if((n|0)==0){break}gg[n&4095](h,e)}else{a[j+(m&255)|0]=e}}while(0);c[2439272]=(c[2439272]|0)-2}if((k&32|0)!=0){b[4821362]=(b[4821362]|0)-1&65535;e=c[2410681]|0;m=e&65535;j=a[9642736]|0;h=c[3528552]|0;o=c[2433426]|0;p=c[o+(h*3160|0)+60+((e>>>8&255|256)<<2)>>2]|0;do{if((p|0)==0){n=c[o+(h*3160|0)+3136>>2]|0;if((n|0)==0){q=h;r=o;break}gg[n&4095](m,j);q=c[3528552]|0;r=c[2433426]|0}else{a[p+(e&255)|0]=j;q=h;r=o}}while(0);b[4821362]=(b[4821362]|0)-1&65535;o=c[2410681]|0;h=o&65535;j=a[9642737]|0;e=c[r+(q*3160|0)+60+((o>>>8&255|256)<<2)>>2]|0;do{if((e|0)==0){p=c[r+(q*3160|0)+3136>>2]|0;if((p|0)==0){break}gg[p&4095](h,j)}else{a[e+(o&255)|0]=j}}while(0);c[2439272]=(c[2439272]|0)-2}if((k&16|0)!=0){b[4821362]=(b[4821362]|0)-1&65535;j=c[2410681]|0;o=j&65535;e=a[9642732]|0;h=c[3528552]|0;q=c[2433426]|0;r=c[q+(h*3160|0)+60+((j>>>8&255|256)<<2)>>2]|0;do{if((r|0)==0){p=c[q+(h*3160|0)+3136>>2]|0;if((p|0)==0){s=h;t=q;break}gg[p&4095](o,e);s=c[3528552]|0;t=c[2433426]|0}else{a[r+(j&255)|0]=e;s=h;t=q}}while(0);b[4821362]=(b[4821362]|0)-1&65535;q=c[2410681]|0;h=q&65535;e=a[9642733]|0;j=c[t+(s*3160|0)+60+((q>>>8&255|256)<<2)>>2]|0;do{if((j|0)==0){r=c[t+(s*3160|0)+3136>>2]|0;if((r|0)==0){break}gg[r&4095](h,e)}else{a[j+(q&255)|0]=e}}while(0);c[2439272]=(c[2439272]|0)-2}if((k&8|0)!=0){b[4821362]=(b[4821362]|0)-1&65535;e=c[2410681]|0;q=e&65535;j=a[9642721]|0;h=c[3528552]|0;s=c[2433426]|0;t=c[s+(h*3160|0)+60+((e>>>8&255|256)<<2)>>2]|0;do{if((t|0)==0){r=c[s+(h*3160|0)+3136>>2]|0;if((r|0)==0){break}gg[r&4095](q,j)}else{a[t+(e&255)|0]=j}}while(0);c[2439272]=(c[2439272]|0)-1}if((k&4|0)!=0){b[4821362]=(b[4821362]|0)-1&65535;j=c[2410681]|0;e=j&65535;t=a[9642712]|0;q=c[3528552]|0;h=c[2433426]|0;s=c[h+(q*3160|0)+60+((j>>>8&255|256)<<2)>>2]|0;do{if((s|0)==0){r=c[h+(q*3160|0)+3136>>2]|0;if((r|0)==0){break}gg[r&4095](e,t)}else{a[s+(j&255)|0]=t}}while(0);c[2439272]=(c[2439272]|0)-1}if((k&2|0)!=0){b[4821362]=(b[4821362]|0)-1&65535;t=c[2410681]|0;j=t&65535;s=a[9642713]|0;e=c[3528552]|0;q=c[2433426]|0;h=c[q+(e*3160|0)+60+((t>>>8&255|256)<<2)>>2]|0;do{if((h|0)==0){r=c[q+(e*3160|0)+3136>>2]|0;if((r|0)==0){break}gg[r&4095](j,s)}else{a[h+(t&255)|0]=s}}while(0);c[2439272]=(c[2439272]|0)-1}if((k&1|0)==0){return}b[4821362]=(b[4821362]|0)-1&65535;k=c[2410681]|0;s=k&65535;t=a[9642744]|0;h=c[3528552]|0;j=c[2433426]|0;e=c[j+(h*3160|0)+60+((k>>>8&255|256)<<2)>>2]|0;do{if((e|0)==0){q=c[j+(h*3160|0)+3136>>2]|0;if((q|0)==0){break}gg[q&4095](s,t)}else{a[e+(k&255)|0]=t}}while(0);c[2439272]=(c[2439272]|0)-1;return}function fDW(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;break}l=gj[i&4095](e)|0;j=l;k=b[4821352]|0}else{j=a[h+(d&255)|0]|0;k=e}}while(0);b[4821352]=k+1&65535;k=j&255;j=(k&1|0)!=0;if(j){e=c[2410681]|0;d=e&65535;h=c[3528552]|0;f=c[2433426]|0;g=c[f+(h*3160|0)+60+((e>>>8&255)<<2)>>2]|0;do{if((g|0)==0){l=c[f+(h*3160|0)+3132>>2]|0;if((l|0)==0){m=0;n=d;break}i=gj[l&4095](d)|0;m=i;n=b[4821362]|0}else{m=a[g+(e&255)|0]|0;n=d}}while(0);a[9642744]=m;b[4821362]=n+1&65535;c[2439272]=(c[2439272]|0)-1}if((k&2|0)!=0){n=c[2410681]|0;m=n&65535;d=c[3528552]|0;e=c[2433426]|0;g=c[e+(d*3160|0)+60+((n>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[e+(d*3160|0)+3132>>2]|0;if((h|0)==0){o=0;p=m;break}f=gj[h&4095](m)|0;o=f;p=b[4821362]|0}else{o=a[g+(n&255)|0]|0;p=m}}while(0);a[9642713]=o;b[4821362]=p+1&65535;c[2439272]=(c[2439272]|0)-1}if((k&4|0)!=0){p=c[2410681]|0;o=p&65535;m=c[3528552]|0;n=c[2433426]|0;g=c[n+(m*3160|0)+60+((p>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[n+(m*3160|0)+3132>>2]|0;if((d|0)==0){q=0;r=o;break}e=gj[d&4095](o)|0;q=e;r=b[4821362]|0}else{q=a[g+(p&255)|0]|0;r=o}}while(0);a[9642712]=q;b[4821362]=r+1&65535;c[2439272]=(c[2439272]|0)-1}if((k&8|0)!=0){r=c[2410681]|0;q=r&65535;o=c[3528552]|0;p=c[2433426]|0;g=c[p+(o*3160|0)+60+((r>>>8&255)<<2)>>2]|0;do{if((g|0)==0){m=c[p+(o*3160|0)+3132>>2]|0;if((m|0)==0){s=0;t=q;break}n=gj[m&4095](q)|0;s=n;t=b[4821362]|0}else{s=a[g+(r&255)|0]|0;t=q}}while(0);a[9642721]=s;b[4821362]=t+1&65535;c[2439272]=(c[2439272]|0)-1}if((k&16|0)!=0){t=c[2410681]|0;s=t&65535;q=c[3528552]|0;r=c[2433426]|0;g=c[r+(q*3160|0)+60+((t>>>8&255)<<2)>>2]|0;do{if((g|0)==0){o=c[r+(q*3160|0)+3132>>2]|0;if((o|0)==0){u=0;v=s;w=q;x=r;break}p=gj[o&4095](s)|0;u=p;v=b[4821362]|0;w=c[3528552]|0;x=c[2433426]|0}else{u=a[g+(t&255)|0]|0;v=s;w=q;x=r}}while(0);r=(u&255)<<8;c[2410683]=r;b[4821362]=v+1&65535;v=c[2410681]|0;u=v&65535;q=c[x+(w*3160|0)+60+((v>>>8&255)<<2)>>2]|0;do{if((q|0)==0){s=c[x+(w*3160|0)+3132>>2]|0;if((s|0)==0){y=0;z=r;A=u;break}t=gj[s&4095](u)|0;y=t;z=c[2410683]|0;A=b[4821362]|0}else{y=a[q+(v&255)|0]|0;z=r;A=u}}while(0);c[2410683]=z|y&255;b[4821362]=A+1&65535;c[2439272]=(c[2439272]|0)-2}if((k&32|0)!=0){A=c[2410681]|0;y=A&65535;z=c[3528552]|0;u=c[2433426]|0;r=c[u+(z*3160|0)+60+((A>>>8&255)<<2)>>2]|0;do{if((r|0)==0){v=c[u+(z*3160|0)+3132>>2]|0;if((v|0)==0){B=0;C=y;D=z;E=u;break}q=gj[v&4095](y)|0;B=q;C=b[4821362]|0;D=c[3528552]|0;E=c[2433426]|0}else{B=a[r+(A&255)|0]|0;C=y;D=z;E=u}}while(0);u=(B&255)<<8;c[2410684]=u;b[4821362]=C+1&65535;C=c[2410681]|0;B=C&65535;z=c[E+(D*3160|0)+60+((C>>>8&255)<<2)>>2]|0;do{if((z|0)==0){y=c[E+(D*3160|0)+3132>>2]|0;if((y|0)==0){F=0;G=u;H=B;break}A=gj[y&4095](B)|0;F=A;G=c[2410684]|0;H=b[4821362]|0}else{F=a[z+(C&255)|0]|0;G=u;H=B}}while(0);c[2410684]=G|F&255;b[4821362]=H+1&65535;c[2439272]=(c[2439272]|0)-2}if((k&64|0)!=0){H=c[2410681]|0;F=H&65535;G=c[3528552]|0;B=c[2433426]|0;u=c[B+(G*3160|0)+60+((H>>>8&255)<<2)>>2]|0;do{if((u|0)==0){C=c[B+(G*3160|0)+3132>>2]|0;if((C|0)==0){I=0;J=F;K=G;L=B;break}z=gj[C&4095](F)|0;I=z;J=b[4821362]|0;K=c[3528552]|0;L=c[2433426]|0}else{I=a[u+(H&255)|0]|0;J=F;K=G;L=B}}while(0);B=(I&255)<<8;c[2410682]=B;b[4821362]=J+1&65535;J=c[2410681]|0;I=J&65535;G=c[L+(K*3160|0)+60+((J>>>8&255)<<2)>>2]|0;do{if((G|0)==0){F=c[L+(K*3160|0)+3132>>2]|0;if((F|0)==0){M=0;N=B;O=I;break}H=gj[F&4095](I)|0;M=H;N=c[2410682]|0;O=b[4821362]|0}else{M=a[G+(J&255)|0]|0;N=B;O=I}}while(0);c[2410682]=N|M&255;b[4821362]=O+1&65535;c[2439272]=(c[2439272]|0)-2}if((k&128|0)!=0){k=c[2410681]|0;O=k&65535;M=c[3528552]|0;N=c[2433426]|0;I=c[N+(M*3160|0)+60+((k>>>8&255)<<2)>>2]|0;do{if((I|0)==0){B=c[N+(M*3160|0)+3132>>2]|0;if((B|0)==0){P=0;Q=O;R=M;S=N;break}J=gj[B&4095](O)|0;P=J;Q=b[4821362]|0;R=c[3528552]|0;S=c[2433426]|0}else{P=a[I+(k&255)|0]|0;Q=O;R=M;S=N}}while(0);N=(P&255)<<8;c[2410676]=N;b[4821362]=Q+1&65535;Q=c[2410681]|0;P=Q&65535;M=c[S+(R*3160|0)+60+((Q>>>8&255)<<2)>>2]|0;do{if((M|0)==0){O=c[S+(R*3160|0)+3132>>2]|0;if((O|0)==0){T=0;U=N;V=P;break}k=gj[O&4095](P)|0;T=k;U=c[2410676]|0;V=b[4821362]|0}else{T=a[M+(Q&255)|0]|0;U=N;V=P}}while(0);P=U|T&255;c[2410676]=P;b[4821362]=V+1&65535;b[4821352]=P&65535;c[2439272]=(c[2439272]|0)-2}if(!j){return}fC1();return}function fDX(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=c[2410682]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3132>>2]|0;if((i|0)==0){j=0;k=e;l=f;m=g;break}n=gj[i&4095](e)|0;j=n;k=b[4821364]|0;l=c[3528552]|0;m=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=e;l=f;m=g}}while(0);g=(j&255)<<8;c[2410676]=g;b[4821364]=k+1&65535;k=c[2410682]|0;j=k&65535;f=c[m+(l*3160|0)+60+((k>>>8&255)<<2)>>2]|0;do{if((f|0)==0){e=c[m+(l*3160|0)+3132>>2]|0;if((e|0)==0){o=0;p=g;q=j;break}d=gj[e&4095](j)|0;o=d;p=c[2410676]|0;q=b[4821364]|0}else{o=a[f+(k&255)|0]|0;p=g;q=j}}while(0);j=p|o&255;c[2410676]=j;b[4821364]=q+1&65535;b[4821352]=j&65535;return}function fDY(){b[4821366]=(b[4821366]|0)+(d[9642712]|0)&65535;return}function fDZ(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0;d=c[2410682]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3132>>2]|0;if((i|0)==0){a[9642744]=0;b[4821364]=e+1&65535;break}else{j=gj[i&4095](e)|0;k=j;l=b[4821364]|0;m=7724;break}}else{k=a[h+(d&255)|0]|0;l=e;m=7724}}while(0);do{if((m|0)==7724){a[9642744]=k;b[4821364]=l+1&65535;if(k<<24>>24>=0){break}c[2439272]=(c[2439272]|0)-9;e=c[2410682]|0;d=e&65535;h=c[3528552]|0;f=c[2433426]|0;g=c[f+(h*3160|0)+60+((e>>>8&255)<<2)>>2]|0;do{if((g|0)==0){j=c[f+(h*3160|0)+3132>>2]|0;if((j|0)==0){n=0;o=d;p=h;q=f;break}i=gj[j&4095](d)|0;n=i;o=b[4821364]|0;p=c[3528552]|0;q=c[2433426]|0}else{n=a[g+(e&255)|0]|0;o=d;p=h;q=f}}while(0);a[9642713]=n;b[4821364]=o+1&65535;f=c[2410682]|0;h=f&65535;d=c[q+(p*3160|0)+60+((f>>>8&255)<<2)>>2]|0;do{if((d|0)==0){e=c[q+(p*3160|0)+3132>>2]|0;if((e|0)==0){r=0;s=h;break}g=gj[e&4095](h)|0;r=g;s=b[4821364]|0}else{r=a[d+(f&255)|0]|0;s=h}}while(0);a[9642712]=r;b[4821364]=s+1&65535;if((a[9642745]&1)!=0){h=c[2410682]|0;f=h&65535;d=c[3528552]|0;g=c[2433426]|0;e=c[g+(d*3160|0)+60+((h>>>8&255)<<2)>>2]|0;do{if((e|0)==0){i=c[g+(d*3160|0)+3132>>2]|0;if((i|0)==0){t=0;u=f;v=d;w=g;break}j=gj[i&4095](f)|0;t=j;u=b[4821364]|0;v=c[3528552]|0;w=c[2433426]|0}else{t=a[e+(h&255)|0]|0;u=f;v=d;w=g}}while(0);a[9642717]=t;b[4821364]=u+1&65535;g=c[2410682]|0;d=g&65535;f=c[w+(v*3160|0)+60+((g>>>8&255)<<2)>>2]|0;do{if((f|0)==0){h=c[w+(v*3160|0)+3132>>2]|0;if((h|0)==0){x=0;y=d;break}e=gj[h&4095](d)|0;x=e;y=b[4821364]|0}else{x=a[f+(g&255)|0]|0;y=d}}while(0);a[9642716]=x;b[4821364]=y+1&65535;c[2439272]=(c[2439272]|0)-2}d=c[2410682]|0;g=d&65535;f=c[3528552]|0;e=c[2433426]|0;h=c[e+(f*3160|0)+60+((d>>>8&255)<<2)>>2]|0;do{if((h|0)==0){j=c[e+(f*3160|0)+3132>>2]|0;if((j|0)==0){z=0;A=g;B=f;C=e;break}i=gj[j&4095](g)|0;z=i;A=b[4821364]|0;B=c[3528552]|0;C=c[2433426]|0}else{z=a[h+(d&255)|0]|0;A=g;B=f;C=e}}while(0);a[9642721]=z;b[4821364]=A+1&65535;e=c[2410682]|0;f=e&65535;g=c[C+(B*3160|0)+60+((e>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[C+(B*3160|0)+3132>>2]|0;if((d|0)==0){D=0;E=f;F=B;G=C;break}h=gj[d&4095](f)|0;D=h;E=b[4821364]|0;F=c[3528552]|0;G=c[2433426]|0}else{D=a[g+(e&255)|0]|0;E=f;F=B;G=C}}while(0);f=(D&255)<<8;c[2410683]=f;b[4821364]=E+1&65535;e=c[2410682]|0;g=e&65535;h=c[G+(F*3160|0)+60+((e>>>8&255)<<2)>>2]|0;do{if((h|0)==0){d=c[G+(F*3160|0)+3132>>2]|0;if((d|0)==0){H=0;I=f;J=g;K=F;L=G;break}i=gj[d&4095](g)|0;H=i;I=c[2410683]|0;J=b[4821364]|0;K=c[3528552]|0;L=c[2433426]|0}else{H=a[h+(e&255)|0]|0;I=f;J=g;K=F;L=G}}while(0);c[2410683]=I|H&255;b[4821364]=J+1&65535;g=c[2410682]|0;f=g&65535;e=c[L+(K*3160|0)+60+((g>>>8&255)<<2)>>2]|0;do{if((e|0)==0){h=c[L+(K*3160|0)+3132>>2]|0;if((h|0)==0){M=0;N=f;O=K;P=L;break}i=gj[h&4095](f)|0;M=i;N=b[4821364]|0;O=c[3528552]|0;P=c[2433426]|0}else{M=a[e+(g&255)|0]|0;N=f;O=K;P=L}}while(0);f=(M&255)<<8;c[2410684]=f;b[4821364]=N+1&65535;g=c[2410682]|0;e=g&65535;i=c[P+(O*3160|0)+60+((g>>>8&255)<<2)>>2]|0;do{if((i|0)==0){h=c[P+(O*3160|0)+3132>>2]|0;if((h|0)==0){Q=0;R=f;S=e;T=O;U=P;break}d=gj[h&4095](e)|0;Q=d;R=c[2410684]|0;S=b[4821364]|0;T=c[3528552]|0;U=c[2433426]|0}else{Q=a[i+(g&255)|0]|0;R=f;S=e;T=O;U=P}}while(0);c[2410684]=R|Q&255;b[4821364]=S+1&65535;e=c[2410682]|0;f=e&65535;g=c[U+(T*3160|0)+60+((e>>>8&255)<<2)>>2]|0;do{if((g|0)==0){i=c[U+(T*3160|0)+3132>>2]|0;if((i|0)==0){V=0;W=f;X=T;Y=U;break}d=gj[i&4095](f)|0;V=d;W=b[4821364]|0;X=c[3528552]|0;Y=c[2433426]|0}else{V=a[g+(e&255)|0]|0;W=f;X=T;Y=U}}while(0);f=(V&255)<<8;c[2410681]=f;b[4821364]=W+1&65535;e=c[2410682]|0;g=e&65535;d=c[Y+(X*3160|0)+60+((e>>>8&255)<<2)>>2]|0;do{if((d|0)==0){i=c[Y+(X*3160|0)+3132>>2]|0;if((i|0)==0){Z=0;_=f;$=g;break}h=gj[i&4095](g)|0;Z=h;_=c[2410681]|0;$=b[4821364]|0}else{Z=a[d+(e&255)|0]|0;_=f;$=g}}while(0);c[2410681]=_|Z&255;b[4821364]=$+1&65535}}while(0);$=c[2410682]|0;Z=$&65535;_=c[3528552]|0;X=c[2433426]|0;Y=c[X+(_*3160|0)+60+(($>>>8&255)<<2)>>2]|0;do{if((Y|0)==0){W=c[X+(_*3160|0)+3132>>2]|0;if((W|0)==0){aa=0;ab=Z;ac=_;ad=X;break}V=gj[W&4095](Z)|0;aa=V;ab=b[4821364]|0;ac=c[3528552]|0;ad=c[2433426]|0}else{aa=a[Y+($&255)|0]|0;ab=Z;ac=_;ad=X}}while(0);X=(aa&255)<<8;c[2410676]=X;b[4821364]=ab+1&65535;ab=c[2410682]|0;aa=ab&65535;_=c[ad+(ac*3160|0)+60+((ab>>>8&255)<<2)>>2]|0;if((_|0)!=0){ae=a[_+(ab&255)|0]|0;af=X;ag=aa;ah=ae&255;ai=af|ah;c[2410676]=ai;aj=ag+1&65535;b[4821364]=aj;ak=ai&65535;b[4821352]=ak;fC1();return}ab=c[ad+(ac*3160|0)+3132>>2]|0;if((ab|0)==0){ae=0;af=X;ag=aa;ah=ae&255;ai=af|ah;c[2410676]=ai;aj=ag+1&65535;b[4821364]=aj;ak=ai&65535;b[4821352]=ak;fC1();return}X=gj[ab&4095](aa)|0;ae=X;af=c[2410676]|0;ag=b[4821364]|0;ah=ae&255;ai=af|ah;c[2410676]=ai;aj=ag+1&65535;b[4821364]=aj;ak=ai&65535;b[4821352]=ak;fC1();return}function fD_(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;l=f;m=g;break}n=gj[i&4095](e)|0;j=n;k=b[4821352]|0;l=c[3528552]|0;m=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=e;l=f;m=g}}while(0);g=k+1&65535;b[4821352]=g;a[9642744]=a[9642744]&j|-128;b[4821364]=(b[4821364]|0)-1&65535;j=c[2410682]|0;k=j&65535;f=g&255;g=c[m+(l*3160|0)+60+((j>>>8&255|256)<<2)>>2]|0;do{if((g|0)==0){e=c[m+(l*3160|0)+3136>>2]|0;if((e|0)==0){o=l;p=m;break}gg[e&4095](k,f);o=c[3528552]|0;p=c[2433426]|0}else{a[g+(j&255)|0]=f;o=l;p=m}}while(0);b[4821364]=(b[4821364]|0)-1&65535;m=c[2410682]|0;l=m&65535;f=a[9642705]|0;j=c[p+(o*3160|0)+60+((m>>>8&255|256)<<2)>>2]|0;do{if((j|0)==0){g=c[p+(o*3160|0)+3136>>2]|0;if((g|0)==0){q=o;r=p;break}gg[g&4095](l,f);q=c[3528552]|0;r=c[2433426]|0}else{a[j+(m&255)|0]=f;q=o;r=p}}while(0);b[4821364]=(b[4821364]|0)-1&65535;p=c[2410682]|0;o=p&65535;f=a[9642724]|0;m=c[r+(q*3160|0)+60+((p>>>8&255|256)<<2)>>2]|0;do{if((m|0)==0){j=c[r+(q*3160|0)+3136>>2]|0;if((j|0)==0){s=q;t=r;break}gg[j&4095](o,f);s=c[3528552]|0;t=c[2433426]|0}else{a[m+(p&255)|0]=f;s=q;t=r}}while(0);b[4821364]=(b[4821364]|0)-1&65535;r=c[2410682]|0;q=r&65535;f=a[9642725]|0;p=c[t+(s*3160|0)+60+((r>>>8&255|256)<<2)>>2]|0;do{if((p|0)==0){m=c[t+(s*3160|0)+3136>>2]|0;if((m|0)==0){u=s;v=t;break}gg[m&4095](q,f);u=c[3528552]|0;v=c[2433426]|0}else{a[p+(r&255)|0]=f;u=s;v=t}}while(0);b[4821364]=(b[4821364]|0)-1&65535;t=c[2410682]|0;s=t&65535;f=a[9642736]|0;r=c[v+(u*3160|0)+60+((t>>>8&255|256)<<2)>>2]|0;do{if((r|0)==0){p=c[v+(u*3160|0)+3136>>2]|0;if((p|0)==0){w=u;x=v;break}gg[p&4095](s,f);w=c[3528552]|0;x=c[2433426]|0}else{a[r+(t&255)|0]=f;w=u;x=v}}while(0);b[4821364]=(b[4821364]|0)-1&65535;v=c[2410682]|0;u=v&65535;f=a[9642737]|0;t=c[x+(w*3160|0)+60+((v>>>8&255|256)<<2)>>2]|0;do{if((t|0)==0){r=c[x+(w*3160|0)+3136>>2]|0;if((r|0)==0){y=w;z=x;break}gg[r&4095](u,f);y=c[3528552]|0;z=c[2433426]|0}else{a[t+(v&255)|0]=f;y=w;z=x}}while(0);b[4821364]=(b[4821364]|0)-1&65535;x=c[2410682]|0;w=x&65535;f=a[9642732]|0;v=c[z+(y*3160|0)+60+((x>>>8&255|256)<<2)>>2]|0;do{if((v|0)==0){t=c[z+(y*3160|0)+3136>>2]|0;if((t|0)==0){A=y;B=z;break}gg[t&4095](w,f);A=c[3528552]|0;B=c[2433426]|0}else{a[v+(x&255)|0]=f;A=y;B=z}}while(0);b[4821364]=(b[4821364]|0)-1&65535;z=c[2410682]|0;y=z&65535;f=a[9642733]|0;x=c[B+(A*3160|0)+60+((z>>>8&255|256)<<2)>>2]|0;do{if((x|0)==0){v=c[B+(A*3160|0)+3136>>2]|0;if((v|0)==0){C=A;D=B;break}gg[v&4095](y,f);C=c[3528552]|0;D=c[2433426]|0}else{a[x+(z&255)|0]=f;C=A;D=B}}while(0);b[4821364]=(b[4821364]|0)-1&65535;B=c[2410682]|0;A=B&65535;f=a[9642721]|0;z=c[D+(C*3160|0)+60+((B>>>8&255|256)<<2)>>2]|0;do{if((z|0)==0){x=c[D+(C*3160|0)+3136>>2]|0;if((x|0)==0){break}gg[x&4095](A,f)}else{a[z+(B&255)|0]=f}}while(0);do{if((a[9642745]&1)!=0){b[4821364]=(b[4821364]|0)-1&65535;f=c[2410682]|0;B=f&65535;z=a[9642717]|0;A=c[3528552]|0;C=c[2433426]|0;D=c[C+(A*3160|0)+60+((f>>>8&255|256)<<2)>>2]|0;do{if((D|0)==0){x=c[C+(A*3160|0)+3136>>2]|0;if((x|0)==0){E=A;F=C;break}gg[x&4095](B,z);E=c[3528552]|0;F=c[2433426]|0}else{a[D+(f&255)|0]=z;E=A;F=C}}while(0);b[4821364]=(b[4821364]|0)-1&65535;C=c[2410682]|0;A=a[9642716]|0;z=c[F+(E*3160|0)+60+((C>>>8&255|256)<<2)>>2]|0;if((z|0)!=0){a[z+(C&255)|0]=A;break}z=c[F+(E*3160|0)+3136>>2]|0;if((z|0)==0){break}gg[z&4095](C&65535,A)}}while(0);b[4821364]=(b[4821364]|0)-1&65535;E=c[2410682]|0;F=E&65535;A=a[9642712]|0;C=c[3528552]|0;z=c[2433426]|0;f=c[z+(C*3160|0)+60+((E>>>8&255|256)<<2)>>2]|0;do{if((f|0)==0){D=c[z+(C*3160|0)+3136>>2]|0;if((D|0)==0){G=C;H=z;break}gg[D&4095](F,A);G=c[3528552]|0;H=c[2433426]|0}else{a[f+(E&255)|0]=A;G=C;H=z}}while(0);b[4821364]=(b[4821364]|0)-1&65535;z=c[2410682]|0;C=z&65535;A=a[9642713]|0;E=c[H+(G*3160|0)+60+((z>>>8&255|256)<<2)>>2]|0;do{if((E|0)==0){f=c[H+(G*3160|0)+3136>>2]|0;if((f|0)==0){I=G;J=H;break}gg[f&4095](C,A);I=c[3528552]|0;J=c[2433426]|0}else{a[E+(z&255)|0]=A;I=G;J=H}}while(0);b[4821364]=(b[4821364]|0)-1&65535;H=c[2410682]|0;G=H&65535;A=a[9642744]|0;z=c[J+(I*3160|0)+60+((H>>>8&255|256)<<2)>>2]|0;do{if((z|0)==0){E=c[J+(I*3160|0)+3136>>2]|0;if((E|0)==0){break}gg[E&4095](G,A)}else{a[z+(H&255)|0]=A}}while(0);a[9642760]=a[9642760]|8;fC1();if(!((a[9642760]&8)!=0&(c[2439272]|0)>0)){return}c[2439272]=0;return}function fD$(){var c=0,e=0;c=ag(d[9642712]|0,d[9642713]|0)|0;e=a[9642744]&-6;a[9642744]=(c&65535)>>>7&1|(c<<16>>16==0?e|4:e);b[4821356]=c;return}function fD0(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;a[9642744]=a[9642744]|-128;b[4821364]=(b[4821364]|0)-1&65535;e=c[2410682]|0;f=e&65535;g=a[9642704]|0;h=c[3528552]|0;i=c[2433426]|0;j=c[i+(h*3160|0)+60+((e>>>8&255|256)<<2)>>2]|0;do{if((j|0)==0){k=c[i+(h*3160|0)+3136>>2]|0;if((k|0)==0){l=h;m=i;break}gg[k&4095](f,g);l=c[3528552]|0;m=c[2433426]|0}else{a[j+(e&255)|0]=g;l=h;m=i}}while(0);b[4821364]=(b[4821364]|0)-1&65535;i=c[2410682]|0;h=i&65535;g=a[9642705]|0;e=c[m+(l*3160|0)+60+((i>>>8&255|256)<<2)>>2]|0;do{if((e|0)==0){j=c[m+(l*3160|0)+3136>>2]|0;if((j|0)==0){n=l;o=m;break}gg[j&4095](h,g);n=c[3528552]|0;o=c[2433426]|0}else{a[e+(i&255)|0]=g;n=l;o=m}}while(0);b[4821364]=(b[4821364]|0)-1&65535;m=c[2410682]|0;l=m&65535;g=a[9642724]|0;i=c[o+(n*3160|0)+60+((m>>>8&255|256)<<2)>>2]|0;do{if((i|0)==0){e=c[o+(n*3160|0)+3136>>2]|0;if((e|0)==0){p=n;q=o;break}gg[e&4095](l,g);p=c[3528552]|0;q=c[2433426]|0}else{a[i+(m&255)|0]=g;p=n;q=o}}while(0);b[4821364]=(b[4821364]|0)-1&65535;o=c[2410682]|0;n=o&65535;g=a[9642725]|0;m=c[q+(p*3160|0)+60+((o>>>8&255|256)<<2)>>2]|0;do{if((m|0)==0){i=c[q+(p*3160|0)+3136>>2]|0;if((i|0)==0){r=p;s=q;break}gg[i&4095](n,g);r=c[3528552]|0;s=c[2433426]|0}else{a[m+(o&255)|0]=g;r=p;s=q}}while(0);b[4821364]=(b[4821364]|0)-1&65535;q=c[2410682]|0;p=q&65535;g=a[9642736]|0;o=c[s+(r*3160|0)+60+((q>>>8&255|256)<<2)>>2]|0;do{if((o|0)==0){m=c[s+(r*3160|0)+3136>>2]|0;if((m|0)==0){t=r;u=s;break}gg[m&4095](p,g);t=c[3528552]|0;u=c[2433426]|0}else{a[o+(q&255)|0]=g;t=r;u=s}}while(0);b[4821364]=(b[4821364]|0)-1&65535;s=c[2410682]|0;r=s&65535;g=a[9642737]|0;q=c[u+(t*3160|0)+60+((s>>>8&255|256)<<2)>>2]|0;do{if((q|0)==0){o=c[u+(t*3160|0)+3136>>2]|0;if((o|0)==0){v=t;w=u;break}gg[o&4095](r,g);v=c[3528552]|0;w=c[2433426]|0}else{a[q+(s&255)|0]=g;v=t;w=u}}while(0);b[4821364]=(b[4821364]|0)-1&65535;u=c[2410682]|0;t=u&65535;g=a[9642732]|0;s=c[w+(v*3160|0)+60+((u>>>8&255|256)<<2)>>2]|0;do{if((s|0)==0){q=c[w+(v*3160|0)+3136>>2]|0;if((q|0)==0){x=v;y=w;break}gg[q&4095](t,g);x=c[3528552]|0;y=c[2433426]|0}else{a[s+(u&255)|0]=g;x=v;y=w}}while(0);b[4821364]=(b[4821364]|0)-1&65535;w=c[2410682]|0;v=w&65535;g=a[9642733]|0;u=c[y+(x*3160|0)+60+((w>>>8&255|256)<<2)>>2]|0;do{if((u|0)==0){s=c[y+(x*3160|0)+3136>>2]|0;if((s|0)==0){z=x;A=y;break}gg[s&4095](v,g);z=c[3528552]|0;A=c[2433426]|0}else{a[u+(w&255)|0]=g;z=x;A=y}}while(0);b[4821364]=(b[4821364]|0)-1&65535;y=c[2410682]|0;x=y&65535;g=a[9642721]|0;w=c[A+(z*3160|0)+60+((y>>>8&255|256)<<2)>>2]|0;do{if((w|0)==0){u=c[A+(z*3160|0)+3136>>2]|0;if((u|0)==0){break}gg[u&4095](x,g)}else{a[w+(y&255)|0]=g}}while(0);do{if((a[9642745]&1)!=0){b[4821364]=(b[4821364]|0)-1&65535;g=c[2410682]|0;y=g&65535;w=a[9642716]|0;x=c[3528552]|0;z=c[2433426]|0;A=c[z+(x*3160|0)+60+((g>>>8&255|256)<<2)>>2]|0;do{if((A|0)==0){u=c[z+(x*3160|0)+3136>>2]|0;if((u|0)==0){B=x;C=z;break}gg[u&4095](y,w);B=c[3528552]|0;C=c[2433426]|0}else{a[A+(g&255)|0]=w;B=x;C=z}}while(0);b[4821364]=(b[4821364]|0)-1&65535;z=c[2410682]|0;x=a[9642717]|0;w=c[C+(B*3160|0)+60+((z>>>8&255|256)<<2)>>2]|0;if((w|0)!=0){a[w+(z&255)|0]=x;break}w=c[C+(B*3160|0)+3136>>2]|0;if((w|0)==0){break}gg[w&4095](z&65535,x)}}while(0);b[4821364]=(b[4821364]|0)-1&65535;B=c[2410682]|0;C=B&65535;x=a[9642712]|0;z=c[3528552]|0;w=c[2433426]|0;g=c[w+(z*3160|0)+60+((B>>>8&255|256)<<2)>>2]|0;do{if((g|0)==0){A=c[w+(z*3160|0)+3136>>2]|0;if((A|0)==0){D=z;E=w;break}gg[A&4095](C,x);D=c[3528552]|0;E=c[2433426]|0}else{a[g+(B&255)|0]=x;D=z;E=w}}while(0);b[4821364]=(b[4821364]|0)-1&65535;w=c[2410682]|0;z=w&65535;x=a[9642713]|0;B=c[E+(D*3160|0)+60+((w>>>8&255|256)<<2)>>2]|0;do{if((B|0)==0){g=c[E+(D*3160|0)+3136>>2]|0;if((g|0)==0){F=D;G=E;break}gg[g&4095](z,x);F=c[3528552]|0;G=c[2433426]|0}else{a[B+(w&255)|0]=x;F=D;G=E}}while(0);b[4821364]=(b[4821364]|0)-1&65535;E=c[2410682]|0;D=E&65535;x=a[9642744]|0;w=c[G+(F*3160|0)+60+((E>>>8&255|256)<<2)>>2]|0;do{if((w|0)==0){B=c[G+(F*3160|0)+3136>>2]|0;if((B|0)==0){H=F;I=G;break}gg[B&4095](D,x);H=c[3528552]|0;I=c[2433426]|0}else{a[w+(E&255)|0]=x;H=F;I=G}}while(0);a[9642744]=a[9642744]|80;G=c[I+(H*3160|0)+1080>>2]|0;do{if((G|0)==0){F=c[I+(H*3160|0)+3132>>2]|0;if((F|0)==0){J=0;K=0;L=J&255;M=L|K;c[2410676]=M;N=M&65535;b[4821352]=N;return}x=gj[F&4095](-6)|0;F=c[3528552]|0;E=c[2433426]|0;w=c[E+(F*3160|0)+1080>>2]|0;D=(x&255)<<8;if((w|0)!=0){O=w;P=D;break}w=c[E+(F*3160|0)+3132>>2]|0;if((w|0)==0){J=0;K=D;L=J&255;M=L|K;c[2410676]=M;N=M&65535;b[4821352]=N;return}J=gj[w&4095](-5)|0;K=D;L=J&255;M=L|K;c[2410676]=M;N=M&65535;b[4821352]=N;return}else{O=G;P=(d[G+250|0]|0)<<8}}while(0);J=a[O+251|0]|0;K=P;L=J&255;M=L|K;c[2410676]=M;N=M&65535;b[4821352]=N;return}function fD1(){var b=0,c=0,d=0,e=0,f=0;b=a[9642713]|0;c=-(b&255)&65535;d=c&65535;e=(d>>>4&8|a[9642744]&-16&255)&255;f=c&255;a[9642744]=((d^b&255^d>>>1)>>>6&2|d>>>8&1|(f<<24>>24==0?e|4:e)&255)&255;a[9642713]=f;return}function fD2(){var b=0,c=0,d=0;b=a[9642713]|0;c=~b;a[9642713]=c;d=(c&255)>>>4&8|a[9642744]&-15;a[9642744]=(b<<24>>24==-1?d|4:d)|1;return}function fD3(){var b=0,c=0,d=0;b=a[9642713]|0;c=b&1|a[9642744]&-14;a[9642744]=c;d=(b&255)>>>1;a[9642713]=d;if(d<<24>>24!=0){return}a[9642744]=c|4;return}function fD4(){var b=0,c=0,d=0,e=0;b=a[9642744]|0;c=a[9642713]|0;d=(c&255)>>>1|b<<7;e=c&1|b&-14|b<<3&8;a[9642744]=d<<24>>24==0?e|4:e;a[9642713]=d;return}function fD5(){var b=0,c=0,d=0,e=0;b=a[9642713]|0;c=b&1|a[9642744]&-14;d=b&-128|(b&255)>>>1;a[9642713]=d;e=(b&255)>>>4&8|c;a[9642744]=d<<24>>24==0?e|4:e;return}function fD6(){var b=0,c=0,e=0,f=0;b=(d[9642713]|0)<<1;c=b&65535;e=(c>>>4&8|a[9642744]&-16&255)&255;f=b&255;a[9642744]=((c>>>1^c)>>>6&2|c>>>8|(f<<24>>24==0?e|4:e)&255)&255;a[9642713]=f;return}function fD7(){var b=0,c=0,d=0,e=0,f=0;b=a[9642713]|0;c=a[9642744]|0;d=b&255;e=d<<1;f=c&-16|(b&255)>>>3&8;b=(c&1|e)&255;a[9642744]=((e^d)>>>6&2|d>>>7|(b<<24>>24==0?f|4:f)&255)&255;a[9642713]=b;return}function fD8(){var b=0;b=(a[9642713]|0)-1&255;a[9642713]=b;a[9642744]=a[669184+(b&255)|0]|a[9642744]&-15;return}function fD9(){var b=0;b=(a[9642713]|0)+1&255;a[9642713]=b;a[9642744]=a[668928+(b&255)|0]|a[9642744]&-15;return}function fEa(){var b=0,c=0;b=a[9642713]|0;c=(b&255)>>>4&8|a[9642744]&-15;a[9642744]=b<<24>>24==0?c|4:c;return}function fEb(){a[9642713]=0;a[9642744]=a[9642744]&-16|4;return}function fEc(){var b=0,c=0,d=0,e=0,f=0;b=a[9642712]|0;c=-(b&255)&65535;d=c&65535;e=(d>>>4&8|a[9642744]&-16&255)&255;f=c&255;a[9642744]=((d^b&255^d>>>1)>>>6&2|d>>>8&1|(f<<24>>24==0?e|4:e)&255)&255;a[9642712]=f;return}function fEd(){var b=0,c=0,d=0;b=a[9642712]|0;c=~b;a[9642712]=c;d=(c&255)>>>4&8|a[9642744]&-15;a[9642744]=(b<<24>>24==-1?d|4:d)|1;return}function fEe(){var b=0,c=0,d=0;b=a[9642712]|0;c=b&1|a[9642744]&-14;a[9642744]=c;d=(b&255)>>>1;a[9642712]=d;if(d<<24>>24!=0){return}a[9642744]=c|4;return}function fEf(){var b=0,c=0,d=0,e=0;b=a[9642744]|0;c=a[9642712]|0;d=(c&255)>>>1|b<<7;e=c&1|b&-14|b<<3&8;a[9642744]=d<<24>>24==0?e|4:e;a[9642712]=d;return}function fEg(){var b=0,c=0,d=0,e=0;b=a[9642712]|0;c=b&1|a[9642744]&-14;d=b&-128|(b&255)>>>1;a[9642712]=d;e=(b&255)>>>4&8|c;a[9642744]=d<<24>>24==0?e|4:e;return}function fEh(){var b=0,c=0,e=0,f=0;b=(d[9642712]|0)<<1;c=b&65535;e=(c>>>4&8|a[9642744]&-16&255)&255;f=b&255;a[9642744]=((c>>>1^c)>>>6&2|c>>>8|(f<<24>>24==0?e|4:e)&255)&255;a[9642712]=f;return}function fEi(){var b=0,c=0,e=0,f=0;b=a[9642744]|0;c=b&1|(d[9642712]|0)<<1;e=c&65535;f=(e>>>4&8|b&-16&255)&255;b=c&255;a[9642744]=((e>>>1^e)>>>6&2|e>>>8|(b<<24>>24==0?f|4:f)&255)&255;a[9642712]=b;return}function fEj(){var b=0;b=(a[9642712]|0)-1&255;a[9642712]=b;a[9642744]=a[669184+(b&255)|0]|a[9642744]&-15;return}function fEk(){var b=0;b=(a[9642712]|0)+1&255;a[9642712]=b;a[9642744]=a[668928+(b&255)|0]|a[9642744]&-15;return}function fEl(){var b=0,c=0;b=a[9642712]|0;c=(b&255)>>>4&8|a[9642744]&-15;a[9642744]=b<<24>>24==0?c|4:c;return}function fEm(){a[9642712]=0;a[9642744]=a[9642744]&-16|4;return}function fEn(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;fGP();b=c[2426872]|0;d=b&65535;e=c[3528552]|0;f=c[2433426]|0;g=c[f+(e*3160|0)+60+((b>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[f+(e*3160|0)+3132>>2]|0;if((h|0)==0){i=0;j=b;k=e;l=f;break}m=gj[h&4095](d)|0;i=m;j=c[2426872]|0;k=c[3528552]|0;l=c[2433426]|0}else{i=a[g+(b&255)|0]|0;j=b;k=e;l=f}}while(0);f=i&255;i=-f|0;e=(a[9642744]&-16&255|i>>>4&8)&255;b=i&255;a[9642744]=((f^i^i>>>1)>>>6&2|i>>>8&1|(b<<24>>24==0?e|4:e)&255)&255;e=c[l+(k*3160|0)+60+((j>>>8&255|256)<<2)>>2]|0;if((e|0)!=0){a[e+(j&255)|0]=b;return}e=c[l+(k*3160|0)+3136>>2]|0;if((e|0)==0){return}gg[e&4095](j&65535,b);return}function fEo(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;break}l=gj[i&4095](e)|0;j=l;k=b[4821352]|0}else{j=a[h+(d&255)|0]|0;k=e}}while(0);b[4821352]=k+1&65535;fGP();k=c[2426872]|0;e=k&65535;d=c[3528552]|0;h=c[2433426]|0;f=c[h+(d*3160|0)+60+((k>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[h+(d*3160|0)+3132>>2]|0;if((g|0)==0){m=0;n=k;o=d;p=h;break}l=gj[g&4095](e)|0;m=l;n=c[2426872]|0;o=c[3528552]|0;p=c[2433426]|0}else{m=a[f+(k&255)|0]|0;n=k;o=d;p=h}}while(0);h=m|j;j=(h&255)>>>4&8|a[9642744]&-15;a[9642744]=h<<24>>24==0?j|4:j;j=c[p+(o*3160|0)+60+((n>>>8&255|256)<<2)>>2]|0;if((j|0)!=0){a[j+(n&255)|0]=h;return}j=c[p+(o*3160|0)+3136>>2]|0;if((j|0)==0){return}gg[j&4095](n&65535,h);return}function fEp(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;break}l=gj[i&4095](e)|0;j=l;k=b[4821352]|0}else{j=a[h+(d&255)|0]|0;k=e}}while(0);b[4821352]=k+1&65535;fGP();k=c[2426872]|0;e=k&65535;d=c[3528552]|0;h=c[2433426]|0;f=c[h+(d*3160|0)+60+((k>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[h+(d*3160|0)+3132>>2]|0;if((g|0)==0){m=0;n=k;o=d;p=h;break}l=gj[g&4095](e)|0;m=l;n=c[2426872]|0;o=c[3528552]|0;p=c[2433426]|0}else{m=a[f+(k&255)|0]|0;n=k;o=d;p=h}}while(0);h=m&j;j=(h&255)>>>4&8|a[9642744]&-15;a[9642744]=h<<24>>24==0?j|4:j;j=c[p+(o*3160|0)+60+((n>>>8&255|256)<<2)>>2]|0;if((j|0)!=0){a[j+(n&255)|0]=h;return}j=c[p+(o*3160|0)+3136>>2]|0;if((j|0)==0){return}gg[j&4095](n&65535,h);return}function fEq(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;fGP();b=c[2426872]|0;d=b&65535;e=c[3528552]|0;f=c[2433426]|0;g=c[f+(e*3160|0)+60+((b>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[f+(e*3160|0)+3132>>2]|0;if((h|0)==0){i=0;j=b;k=e;l=f;break}m=gj[h&4095](d)|0;i=m;j=c[2426872]|0;k=c[3528552]|0;l=c[2433426]|0}else{i=a[g+(b&255)|0]|0;j=b;k=e;l=f}}while(0);f=~i;e=a[9642744]&-15|(f&255)>>>4&8;a[9642744]=(i<<24>>24==-1?e|4:e)|1;e=c[l+(k*3160|0)+60+((j>>>8&255|256)<<2)>>2]|0;if((e|0)!=0){a[e+(j&255)|0]=f;return}e=c[l+(k*3160|0)+3136>>2]|0;if((e|0)==0){return}gg[e&4095](j&65535,f);return}function fEr(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;fGP();b=c[2426872]|0;d=b&65535;e=c[3528552]|0;f=c[2433426]|0;g=c[f+(e*3160|0)+60+((b>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[f+(e*3160|0)+3132>>2]|0;if((h|0)==0){i=0;j=b;k=e;l=f;break}m=gj[h&4095](d)|0;i=m;j=c[2426872]|0;k=c[3528552]|0;l=c[2433426]|0}else{i=a[g+(b&255)|0]|0;j=b;k=e;l=f}}while(0);f=a[9642744]&-14|i&1;e=(i&255)>>>1;a[9642744]=e<<24>>24==0?f|4:f;f=c[l+(k*3160|0)+60+((j>>>8&255|256)<<2)>>2]|0;if((f|0)!=0){a[f+(j&255)|0]=e;return}f=c[l+(k*3160|0)+3136>>2]|0;if((f|0)==0){return}gg[f&4095](j&65535,e);return}function fEs(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;break}l=gj[i&4095](e)|0;j=l;k=b[4821352]|0}else{j=a[h+(d&255)|0]|0;k=e}}while(0);b[4821352]=k+1&65535;fGP();k=c[2426872]|0;e=k&65535;d=c[3528552]|0;h=c[2433426]|0;f=c[h+(d*3160|0)+60+((k>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[h+(d*3160|0)+3132>>2]|0;if((g|0)==0){m=0;n=k;o=d;p=h;break}l=gj[g&4095](e)|0;m=l;n=c[2426872]|0;o=c[3528552]|0;p=c[2433426]|0}else{m=a[f+(k&255)|0]|0;n=k;o=d;p=h}}while(0);h=m^j;d=(h&255)>>>4&8|a[9642744]&-15;a[9642744]=j<<24>>24==m<<24>>24?d|4:d;d=c[p+(o*3160|0)+60+((n>>>8&255|256)<<2)>>2]|0;if((d|0)!=0){a[d+(n&255)|0]=h;return}d=c[p+(o*3160|0)+3136>>2]|0;if((d|0)==0){return}gg[d&4095](n&65535,h);return}function fEt(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;fGP();b=c[2426872]|0;d=b&65535;e=c[3528552]|0;f=c[2433426]|0;g=c[f+(e*3160|0)+60+((b>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[f+(e*3160|0)+3132>>2]|0;if((h|0)==0){i=0;j=b;k=e;l=f;break}m=gj[h&4095](d)|0;i=m;j=c[2426872]|0;k=c[3528552]|0;l=c[2433426]|0}else{i=a[g+(b&255)|0]|0;j=b;k=e;l=f}}while(0);f=a[9642744]|0;e=f<<7|(i&255)>>>1;b=f&-14|i&1|f<<3&8;a[9642744]=e<<24>>24==0?b|4:b;b=c[l+(k*3160|0)+60+((j>>>8&255|256)<<2)>>2]|0;if((b|0)!=0){a[b+(j&255)|0]=e;return}b=c[l+(k*3160|0)+3136>>2]|0;if((b|0)==0){return}gg[b&4095](j&65535,e);return}function fEu(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;fGP();b=c[2426872]|0;d=b&65535;e=c[3528552]|0;f=c[2433426]|0;g=c[f+(e*3160|0)+60+((b>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[f+(e*3160|0)+3132>>2]|0;if((h|0)==0){i=0;j=b;k=e;l=f;break}m=gj[h&4095](d)|0;i=m;j=c[2426872]|0;k=c[3528552]|0;l=c[2433426]|0}else{i=a[g+(b&255)|0]|0;j=b;k=e;l=f}}while(0);f=i&-128|(i&255)>>>1;e=a[9642744]&-14|i&1|(i&255)>>>4&8;a[9642744]=f<<24>>24==0?e|4:e;e=c[l+(k*3160|0)+60+((j>>>8&255|256)<<2)>>2]|0;if((e|0)!=0){a[e+(j&255)|0]=f;return}e=c[l+(k*3160|0)+3136>>2]|0;if((e|0)==0){return}gg[e&4095](j&65535,f);return}function fEv(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;fGP();b=c[2426872]|0;d=b&65535;e=c[3528552]|0;f=c[2433426]|0;g=c[f+(e*3160|0)+60+((b>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[f+(e*3160|0)+3132>>2]|0;if((h|0)==0){i=0;j=b;k=e;l=f;break}m=gj[h&4095](d)|0;i=m;j=c[2426872]|0;k=c[3528552]|0;l=c[2433426]|0}else{i=a[g+(b&255)|0]|0;j=b;k=e;l=f}}while(0);f=(i&255)<<1;i=f&65535;e=(i>>>4&8|a[9642744]&-16&255)&255;b=f&255;a[9642744]=((i>>>1^i)>>>6&2|i>>>8|(b<<24>>24==0?e|4:e)&255)&255;e=c[l+(k*3160|0)+60+((j>>>8&255|256)<<2)>>2]|0;if((e|0)!=0){a[e+(j&255)|0]=b;return}e=c[l+(k*3160|0)+3136>>2]|0;if((e|0)==0){return}gg[e&4095](j&65535,b);return}function fEw(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;fGP();b=c[2426872]|0;d=b&65535;e=c[3528552]|0;f=c[2433426]|0;g=c[f+(e*3160|0)+60+((b>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[f+(e*3160|0)+3132>>2]|0;if((h|0)==0){i=0;j=b;k=e;l=f;break}m=gj[h&4095](d)|0;i=m;j=c[2426872]|0;k=c[3528552]|0;l=c[2433426]|0}else{i=a[g+(b&255)|0]|0;j=b;k=e;l=f}}while(0);f=a[9642744]|0;e=f&1|(i&255)<<1;i=e&65535;b=(i>>>4&8|f&-16&255)&255;f=e&255;a[9642744]=((i>>>1^i)>>>6&2|i>>>8|(f<<24>>24==0?b|4:b)&255)&255;b=c[l+(k*3160|0)+60+((j>>>8&255|256)<<2)>>2]|0;if((b|0)!=0){a[b+(j&255)|0]=f;return}b=c[l+(k*3160|0)+3136>>2]|0;if((b|0)==0){return}gg[b&4095](j&65535,f);return}function fEx(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;fGP();b=c[2426872]|0;d=b&65535;e=c[3528552]|0;f=c[2433426]|0;g=c[f+(e*3160|0)+60+((b>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[f+(e*3160|0)+3132>>2]|0;if((h|0)==0){i=0;j=b;k=e;l=f;break}m=gj[h&4095](d)|0;i=m;j=c[2426872]|0;k=c[3528552]|0;l=c[2433426]|0}else{i=a[g+(b&255)|0]|0;j=b;k=e;l=f}}while(0);f=i-1&255;a[9642744]=a[9642744]&-15|a[669184+(f&255)|0];i=c[l+(k*3160|0)+60+((j>>>8&255|256)<<2)>>2]|0;if((i|0)!=0){a[i+(j&255)|0]=f;return}i=c[l+(k*3160|0)+3136>>2]|0;if((i|0)==0){return}gg[i&4095](j&65535,f);return}function fEy(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;break}l=gj[i&4095](e)|0;j=l;k=b[4821352]|0}else{j=a[h+(d&255)|0]|0;k=e}}while(0);b[4821352]=k+1&65535;fGP();k=c[2426872]|0;e=k&65535;d=c[3528552]|0;h=c[2433426]|0;f=c[h+(d*3160|0)+60+((k>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[h+(d*3160|0)+3132>>2]|0;if((g|0)==0){m=0;break}m=gj[g&4095](e)|0}else{m=a[f+(k&255)|0]|0}}while(0);k=m&j;j=(k&255)>>>4&8|a[9642744]&-15;a[9642744]=k<<24>>24==0?j|4:j;return}function fEz(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;fGP();b=c[2426872]|0;d=b&65535;e=c[3528552]|0;f=c[2433426]|0;g=c[f+(e*3160|0)+60+((b>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[f+(e*3160|0)+3132>>2]|0;if((h|0)==0){i=0;j=b;k=e;l=f;break}m=gj[h&4095](d)|0;i=m;j=c[2426872]|0;k=c[3528552]|0;l=c[2433426]|0}else{i=a[g+(b&255)|0]|0;j=b;k=e;l=f}}while(0);f=i+1&255;a[9642744]=a[9642744]&-15|a[668928+(f&255)|0];i=c[l+(k*3160|0)+60+((j>>>8&255|256)<<2)>>2]|0;if((i|0)!=0){a[i+(j&255)|0]=f;return}i=c[l+(k*3160|0)+3136>>2]|0;if((i|0)==0){return}gg[i&4095](j&65535,f);return}function fEA(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;fGP();b=c[2426872]|0;d=b&65535;e=c[3528552]|0;f=c[2433426]|0;g=c[f+(e*3160|0)+60+((b>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[f+(e*3160|0)+3132>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(b&255)|0]|0}}while(0);b=a[9642744]&-15|(i&255)>>>4&8;a[9642744]=i<<24>>24==0?b|4:b;return}function fEB(){var a=0;fGP();a=c[2426872]|0;c[2410676]=a;b[4821352]=a&65535;return}function fEC(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;fGP();b=c[2426872]|0;d=b&65535;e=c[3528552]|0;f=c[2433426]|0;do{if((c[f+(e*3160|0)+60+((b>>>8&255)<<2)>>2]|0)==0){g=c[f+(e*3160|0)+3132>>2]|0;if((g|0)==0){h=b;i=e;j=f;break}gj[g&4095](d)|0;h=c[2426872]|0;i=c[3528552]|0;j=c[2433426]|0}else{h=b;i=e;j=f}}while(0);f=c[j+(i*3160|0)+60+((h>>>8&255|256)<<2)>>2]|0;if((f|0)!=0){a[f+(h&255)|0]=0;k=a[9642744]|0;l=k&-16;m=l|4;a[9642744]=m;return}f=c[j+(i*3160|0)+3136>>2]|0;if((f|0)==0){k=a[9642744]|0;l=k&-16;m=l|4;a[9642744]=m;return}gg[f&4095](h&65535,0);k=a[9642744]|0;l=k&-16;m=l|4;a[9642744]=m;return}function fED(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=j&255;j=e<<8;g=k+1|0;k=g&65535;f=c[m+(l*3160|0)+60+((g>>>8&255|512)<<2)>>2]|0;do{if((f|0)==0){d=c[m+(l*3160|0)+3144>>2]|0;if((d|0)==0){p=0;q=n;r=l;s=m;break}h=gj[d&4095](k)|0;p=h;q=b[4821352]|0;r=c[3528552]|0;s=c[2433426]|0}else{p=a[f+(g&255)|0]|0;q=n;r=l;s=m}}while(0);m=p&255;p=m|j;c[2426872]=p;b[4821352]=q+2&65535;q=p&65535;j=c[s+(r*3160|0)+60+(e<<2)>>2]|0;do{if((j|0)==0){e=c[s+(r*3160|0)+3132>>2]|0;if((e|0)==0){t=0;u=p;v=r;w=s;break}l=gj[e&4095](q)|0;t=l;u=c[2426872]|0;v=c[3528552]|0;w=c[2433426]|0}else{t=a[j+m|0]|0;u=p;v=r;w=s}}while(0);s=t&255;t=-s|0;r=(a[9642744]&-16&255|t>>>4&8)&255;p=t&255;a[9642744]=((s^t^t>>>1)>>>6&2|t>>>8&1|(p<<24>>24==0?r|4:r)&255)&255;r=c[w+(v*3160|0)+60+((u>>>8&255|256)<<2)>>2]|0;if((r|0)!=0){a[r+(u&255)|0]=p;return}r=c[w+(v*3160|0)+3136>>2]|0;if((r|0)==0){return}gg[r&4095](u&65535,p);return}function fEE(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;l=f;m=g;break}n=gj[i&4095](e)|0;j=n;k=b[4821352]|0;l=c[3528552]|0;m=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=e;l=f;m=g}}while(0);b[4821352]=k+1&65535;k=c[2410676]|0;g=k&65535;f=c[m+(l*3160|0)+60+((k>>>8&255|512)<<2)>>2]|0;do{if((f|0)==0){e=c[m+(l*3160|0)+3144>>2]|0;if((e|0)==0){o=0;p=k;q=l;r=m;s=g;break}d=gj[e&4095](g)|0;e=c[2410676]|0;o=d;p=e;q=c[3528552]|0;r=c[2433426]|0;s=e&65535}else{o=a[f+(k&255)|0]|0;p=k;q=l;r=m;s=g}}while(0);g=o&255;o=g<<8;m=p+1|0;p=m&65535;l=c[r+(q*3160|0)+60+((m>>>8&255|512)<<2)>>2]|0;do{if((l|0)==0){k=c[r+(q*3160|0)+3144>>2]|0;if((k|0)==0){t=0;u=s;v=q;w=r;break}f=gj[k&4095](p)|0;t=f;u=b[4821352]|0;v=c[3528552]|0;w=c[2433426]|0}else{t=a[l+(m&255)|0]|0;u=s;v=q;w=r}}while(0);r=t&255;t=r|o;c[2426872]=t;b[4821352]=u+2&65535;u=t&65535;o=c[w+(v*3160|0)+60+(g<<2)>>2]|0;do{if((o|0)==0){g=c[w+(v*3160|0)+3132>>2]|0;if((g|0)==0){x=0;y=t;z=v;A=w;break}q=gj[g&4095](u)|0;x=q;y=c[2426872]|0;z=c[3528552]|0;A=c[2433426]|0}else{x=a[o+r|0]|0;y=t;z=v;A=w}}while(0);w=x|j;j=(w&255)>>>4&8|a[9642744]&-15;a[9642744]=w<<24>>24==0?j|4:j;j=c[A+(z*3160|0)+60+((y>>>8&255|256)<<2)>>2]|0;if((j|0)!=0){a[j+(y&255)|0]=w;return}j=c[A+(z*3160|0)+3136>>2]|0;if((j|0)==0){return}gg[j&4095](y&65535,w);return}function fEF(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;l=f;m=g;break}n=gj[i&4095](e)|0;j=n;k=b[4821352]|0;l=c[3528552]|0;m=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=e;l=f;m=g}}while(0);b[4821352]=k+1&65535;k=c[2410676]|0;g=k&65535;f=c[m+(l*3160|0)+60+((k>>>8&255|512)<<2)>>2]|0;do{if((f|0)==0){e=c[m+(l*3160|0)+3144>>2]|0;if((e|0)==0){o=0;p=k;q=l;r=m;s=g;break}d=gj[e&4095](g)|0;e=c[2410676]|0;o=d;p=e;q=c[3528552]|0;r=c[2433426]|0;s=e&65535}else{o=a[f+(k&255)|0]|0;p=k;q=l;r=m;s=g}}while(0);g=o&255;o=g<<8;m=p+1|0;p=m&65535;l=c[r+(q*3160|0)+60+((m>>>8&255|512)<<2)>>2]|0;do{if((l|0)==0){k=c[r+(q*3160|0)+3144>>2]|0;if((k|0)==0){t=0;u=s;v=q;w=r;break}f=gj[k&4095](p)|0;t=f;u=b[4821352]|0;v=c[3528552]|0;w=c[2433426]|0}else{t=a[l+(m&255)|0]|0;u=s;v=q;w=r}}while(0);r=t&255;t=r|o;c[2426872]=t;b[4821352]=u+2&65535;u=t&65535;o=c[w+(v*3160|0)+60+(g<<2)>>2]|0;do{if((o|0)==0){g=c[w+(v*3160|0)+3132>>2]|0;if((g|0)==0){x=0;y=t;z=v;A=w;break}q=gj[g&4095](u)|0;x=q;y=c[2426872]|0;z=c[3528552]|0;A=c[2433426]|0}else{x=a[o+r|0]|0;y=t;z=v;A=w}}while(0);w=x&j;j=(w&255)>>>4&8|a[9642744]&-15;a[9642744]=w<<24>>24==0?j|4:j;j=c[A+(z*3160|0)+60+((y>>>8&255|256)<<2)>>2]|0;if((j|0)!=0){a[j+(y&255)|0]=w;return}j=c[A+(z*3160|0)+3136>>2]|0;if((j|0)==0){return}gg[j&4095](y&65535,w);return}function fEG(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=j&255;j=e<<8;g=k+1|0;k=g&65535;f=c[m+(l*3160|0)+60+((g>>>8&255|512)<<2)>>2]|0;do{if((f|0)==0){d=c[m+(l*3160|0)+3144>>2]|0;if((d|0)==0){p=0;q=n;r=l;s=m;break}h=gj[d&4095](k)|0;p=h;q=b[4821352]|0;r=c[3528552]|0;s=c[2433426]|0}else{p=a[f+(g&255)|0]|0;q=n;r=l;s=m}}while(0);m=p&255;p=m|j;c[2426872]=p;b[4821352]=q+2&65535;q=p&65535;j=c[s+(r*3160|0)+60+(e<<2)>>2]|0;do{if((j|0)==0){e=c[s+(r*3160|0)+3132>>2]|0;if((e|0)==0){t=0;u=p;v=r;w=s;break}l=gj[e&4095](q)|0;t=l;u=c[2426872]|0;v=c[3528552]|0;w=c[2433426]|0}else{t=a[j+m|0]|0;u=p;v=r;w=s}}while(0);s=~t;r=a[9642744]&-15|(s&255)>>>4&8;a[9642744]=(t<<24>>24==-1?r|4:r)|1;r=c[w+(v*3160|0)+60+((u>>>8&255|256)<<2)>>2]|0;if((r|0)!=0){a[r+(u&255)|0]=s;return}r=c[w+(v*3160|0)+3136>>2]|0;if((r|0)==0){return}gg[r&4095](u&65535,s);return}function fEH(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=j&255;j=e<<8;g=k+1|0;k=g&65535;f=c[m+(l*3160|0)+60+((g>>>8&255|512)<<2)>>2]|0;do{if((f|0)==0){d=c[m+(l*3160|0)+3144>>2]|0;if((d|0)==0){p=0;q=n;r=l;s=m;break}h=gj[d&4095](k)|0;p=h;q=b[4821352]|0;r=c[3528552]|0;s=c[2433426]|0}else{p=a[f+(g&255)|0]|0;q=n;r=l;s=m}}while(0);m=p&255;p=m|j;c[2426872]=p;b[4821352]=q+2&65535;q=p&65535;j=c[s+(r*3160|0)+60+(e<<2)>>2]|0;do{if((j|0)==0){e=c[s+(r*3160|0)+3132>>2]|0;if((e|0)==0){t=0;u=p;v=r;w=s;break}l=gj[e&4095](q)|0;t=l;u=c[2426872]|0;v=c[3528552]|0;w=c[2433426]|0}else{t=a[j+m|0]|0;u=p;v=r;w=s}}while(0);s=a[9642744]&-14|t&1;r=(t&255)>>>1;a[9642744]=r<<24>>24==0?s|4:s;s=c[w+(v*3160|0)+60+((u>>>8&255|256)<<2)>>2]|0;if((s|0)!=0){a[s+(u&255)|0]=r;return}s=c[w+(v*3160|0)+3136>>2]|0;if((s|0)==0){return}gg[s&4095](u&65535,r);return}function fEI(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;l=f;m=g;break}n=gj[i&4095](e)|0;j=n;k=b[4821352]|0;l=c[3528552]|0;m=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=e;l=f;m=g}}while(0);b[4821352]=k+1&65535;k=c[2410676]|0;g=k&65535;f=c[m+(l*3160|0)+60+((k>>>8&255|512)<<2)>>2]|0;do{if((f|0)==0){e=c[m+(l*3160|0)+3144>>2]|0;if((e|0)==0){o=0;p=k;q=l;r=m;s=g;break}d=gj[e&4095](g)|0;e=c[2410676]|0;o=d;p=e;q=c[3528552]|0;r=c[2433426]|0;s=e&65535}else{o=a[f+(k&255)|0]|0;p=k;q=l;r=m;s=g}}while(0);g=o&255;o=g<<8;m=p+1|0;p=m&65535;l=c[r+(q*3160|0)+60+((m>>>8&255|512)<<2)>>2]|0;do{if((l|0)==0){k=c[r+(q*3160|0)+3144>>2]|0;if((k|0)==0){t=0;u=s;v=q;w=r;break}f=gj[k&4095](p)|0;t=f;u=b[4821352]|0;v=c[3528552]|0;w=c[2433426]|0}else{t=a[l+(m&255)|0]|0;u=s;v=q;w=r}}while(0);r=t&255;t=r|o;c[2426872]=t;b[4821352]=u+2&65535;u=t&65535;o=c[w+(v*3160|0)+60+(g<<2)>>2]|0;do{if((o|0)==0){g=c[w+(v*3160|0)+3132>>2]|0;if((g|0)==0){x=0;y=t;z=v;A=w;break}q=gj[g&4095](u)|0;x=q;y=c[2426872]|0;z=c[3528552]|0;A=c[2433426]|0}else{x=a[o+r|0]|0;y=t;z=v;A=w}}while(0);w=x^j;v=(w&255)>>>4&8|a[9642744]&-15;a[9642744]=j<<24>>24==x<<24>>24?v|4:v;v=c[A+(z*3160|0)+60+((y>>>8&255|256)<<2)>>2]|0;if((v|0)!=0){a[v+(y&255)|0]=w;return}v=c[A+(z*3160|0)+3136>>2]|0;if((v|0)==0){return}gg[v&4095](y&65535,w);return}function fEJ(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=j&255;j=e<<8;g=k+1|0;k=g&65535;f=c[m+(l*3160|0)+60+((g>>>8&255|512)<<2)>>2]|0;do{if((f|0)==0){d=c[m+(l*3160|0)+3144>>2]|0;if((d|0)==0){p=0;q=n;r=l;s=m;break}h=gj[d&4095](k)|0;p=h;q=b[4821352]|0;r=c[3528552]|0;s=c[2433426]|0}else{p=a[f+(g&255)|0]|0;q=n;r=l;s=m}}while(0);m=p&255;p=m|j;c[2426872]=p;b[4821352]=q+2&65535;q=p&65535;j=c[s+(r*3160|0)+60+(e<<2)>>2]|0;do{if((j|0)==0){e=c[s+(r*3160|0)+3132>>2]|0;if((e|0)==0){t=0;u=p;v=r;w=s;break}l=gj[e&4095](q)|0;t=l;u=c[2426872]|0;v=c[3528552]|0;w=c[2433426]|0}else{t=a[j+m|0]|0;u=p;v=r;w=s}}while(0);s=a[9642744]|0;r=s<<7|(t&255)>>>1;p=s&-14|t&1|s<<3&8;a[9642744]=r<<24>>24==0?p|4:p;p=c[w+(v*3160|0)+60+((u>>>8&255|256)<<2)>>2]|0;if((p|0)!=0){a[p+(u&255)|0]=r;return}p=c[w+(v*3160|0)+3136>>2]|0;if((p|0)==0){return}gg[p&4095](u&65535,r);return}function fEK(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=j&255;j=e<<8;g=k+1|0;k=g&65535;f=c[m+(l*3160|0)+60+((g>>>8&255|512)<<2)>>2]|0;do{if((f|0)==0){d=c[m+(l*3160|0)+3144>>2]|0;if((d|0)==0){p=0;q=n;r=l;s=m;break}h=gj[d&4095](k)|0;p=h;q=b[4821352]|0;r=c[3528552]|0;s=c[2433426]|0}else{p=a[f+(g&255)|0]|0;q=n;r=l;s=m}}while(0);m=p&255;p=m|j;c[2426872]=p;b[4821352]=q+2&65535;q=p&65535;j=c[s+(r*3160|0)+60+(e<<2)>>2]|0;do{if((j|0)==0){e=c[s+(r*3160|0)+3132>>2]|0;if((e|0)==0){t=0;u=p;v=r;w=s;break}l=gj[e&4095](q)|0;t=l;u=c[2426872]|0;v=c[3528552]|0;w=c[2433426]|0}else{t=a[j+m|0]|0;u=p;v=r;w=s}}while(0);s=t&-128|(t&255)>>>1;r=a[9642744]&-14|t&1|(t&255)>>>4&8;a[9642744]=s<<24>>24==0?r|4:r;r=c[w+(v*3160|0)+60+((u>>>8&255|256)<<2)>>2]|0;if((r|0)!=0){a[r+(u&255)|0]=s;return}r=c[w+(v*3160|0)+3136>>2]|0;if((r|0)==0){return}gg[r&4095](u&65535,s);return}function fEL(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=j&255;j=e<<8;g=k+1|0;k=g&65535;f=c[m+(l*3160|0)+60+((g>>>8&255|512)<<2)>>2]|0;do{if((f|0)==0){d=c[m+(l*3160|0)+3144>>2]|0;if((d|0)==0){p=0;q=n;r=l;s=m;break}h=gj[d&4095](k)|0;p=h;q=b[4821352]|0;r=c[3528552]|0;s=c[2433426]|0}else{p=a[f+(g&255)|0]|0;q=n;r=l;s=m}}while(0);m=p&255;p=m|j;c[2426872]=p;b[4821352]=q+2&65535;q=p&65535;j=c[s+(r*3160|0)+60+(e<<2)>>2]|0;do{if((j|0)==0){e=c[s+(r*3160|0)+3132>>2]|0;if((e|0)==0){t=0;u=p;v=r;w=s;break}l=gj[e&4095](q)|0;t=l;u=c[2426872]|0;v=c[3528552]|0;w=c[2433426]|0}else{t=a[j+m|0]|0;u=p;v=r;w=s}}while(0);s=(t&255)<<1;t=s&65535;r=(t>>>4&8|a[9642744]&-16&255)&255;p=s&255;a[9642744]=((t>>>1^t)>>>6&2|t>>>8|(p<<24>>24==0?r|4:r)&255)&255;r=c[w+(v*3160|0)+60+((u>>>8&255|256)<<2)>>2]|0;if((r|0)!=0){a[r+(u&255)|0]=p;return}r=c[w+(v*3160|0)+3136>>2]|0;if((r|0)==0){return}gg[r&4095](u&65535,p);return}function fEM(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=j&255;j=e<<8;g=k+1|0;k=g&65535;f=c[m+(l*3160|0)+60+((g>>>8&255|512)<<2)>>2]|0;do{if((f|0)==0){d=c[m+(l*3160|0)+3144>>2]|0;if((d|0)==0){p=0;q=n;r=l;s=m;break}h=gj[d&4095](k)|0;p=h;q=b[4821352]|0;r=c[3528552]|0;s=c[2433426]|0}else{p=a[f+(g&255)|0]|0;q=n;r=l;s=m}}while(0);m=p&255;p=m|j;c[2426872]=p;b[4821352]=q+2&65535;q=p&65535;j=c[s+(r*3160|0)+60+(e<<2)>>2]|0;do{if((j|0)==0){e=c[s+(r*3160|0)+3132>>2]|0;if((e|0)==0){t=0;u=p;v=r;w=s;break}l=gj[e&4095](q)|0;t=l;u=c[2426872]|0;v=c[3528552]|0;w=c[2433426]|0}else{t=a[j+m|0]|0;u=p;v=r;w=s}}while(0);s=a[9642744]|0;r=t&255;p=r<<1;m=s&-16|(t&255)>>>3&8;t=(s&1|p)&255;a[9642744]=((p^r)>>>6&2|r>>>7|(t<<24>>24==0?m|4:m)&255)&255;m=c[w+(v*3160|0)+60+((u>>>8&255|256)<<2)>>2]|0;if((m|0)!=0){a[m+(u&255)|0]=t;return}m=c[w+(v*3160|0)+3136>>2]|0;if((m|0)==0){return}gg[m&4095](u&65535,t);return}function fEN(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=j&255;j=e<<8;g=k+1|0;k=g&65535;f=c[m+(l*3160|0)+60+((g>>>8&255|512)<<2)>>2]|0;do{if((f|0)==0){d=c[m+(l*3160|0)+3144>>2]|0;if((d|0)==0){p=0;q=n;r=l;s=m;break}h=gj[d&4095](k)|0;p=h;q=b[4821352]|0;r=c[3528552]|0;s=c[2433426]|0}else{p=a[f+(g&255)|0]|0;q=n;r=l;s=m}}while(0);m=p&255;p=m|j;c[2426872]=p;b[4821352]=q+2&65535;q=p&65535;j=c[s+(r*3160|0)+60+(e<<2)>>2]|0;do{if((j|0)==0){e=c[s+(r*3160|0)+3132>>2]|0;if((e|0)==0){t=0;u=p;v=r;w=s;break}l=gj[e&4095](q)|0;t=l;u=c[2426872]|0;v=c[3528552]|0;w=c[2433426]|0}else{t=a[j+m|0]|0;u=p;v=r;w=s}}while(0);s=t-1&255;a[9642744]=a[9642744]&-15|a[669184+(s&255)|0];t=c[w+(v*3160|0)+60+((u>>>8&255|256)<<2)>>2]|0;if((t|0)!=0){a[t+(u&255)|0]=s;return}t=c[w+(v*3160|0)+3136>>2]|0;if((t|0)==0){return}gg[t&4095](u&65535,s);return}function fEO(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;l=f;m=g;break}n=gj[i&4095](e)|0;j=n;k=b[4821352]|0;l=c[3528552]|0;m=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=e;l=f;m=g}}while(0);b[4821352]=k+1&65535;k=c[2410676]|0;g=k&65535;f=c[m+(l*3160|0)+60+((k>>>8&255|512)<<2)>>2]|0;do{if((f|0)==0){e=c[m+(l*3160|0)+3144>>2]|0;if((e|0)==0){o=0;p=k;q=l;r=m;s=g;break}d=gj[e&4095](g)|0;e=c[2410676]|0;o=d;p=e;q=c[3528552]|0;r=c[2433426]|0;s=e&65535}else{o=a[f+(k&255)|0]|0;p=k;q=l;r=m;s=g}}while(0);g=o&255;o=g<<8;m=p+1|0;p=m&65535;l=c[r+(q*3160|0)+60+((m>>>8&255|512)<<2)>>2]|0;do{if((l|0)==0){k=c[r+(q*3160|0)+3144>>2]|0;if((k|0)==0){t=0;u=s;v=q;w=r;break}f=gj[k&4095](p)|0;t=f;u=b[4821352]|0;v=c[3528552]|0;w=c[2433426]|0}else{t=a[l+(m&255)|0]|0;u=s;v=q;w=r}}while(0);r=t&255;t=r|o;c[2426872]=t;b[4821352]=u+2&65535;u=c[w+(v*3160|0)+60+(g<<2)>>2]|0;if((u|0)!=0){x=a[u+r|0]|0;y=x&j;z=a[9642744]|0;A=z&-15;B=(y&255)>>>4;C=B&8;D=C|A;E=y<<24>>24==0;F=D|4;G=E?F:D;a[9642744]=G;return}r=c[w+(v*3160|0)+3132>>2]|0;if((r|0)==0){x=0;y=x&j;z=a[9642744]|0;A=z&-15;B=(y&255)>>>4;C=B&8;D=C|A;E=y<<24>>24==0;F=D|4;G=E?F:D;a[9642744]=G;return}x=gj[r&4095](t&65535)|0;y=x&j;z=a[9642744]|0;A=z&-15;B=(y&255)>>>4;C=B&8;D=C|A;E=y<<24>>24==0;F=D|4;G=E?F:D;a[9642744]=G;return}function fEP(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=j&255;j=e<<8;g=k+1|0;k=g&65535;f=c[m+(l*3160|0)+60+((g>>>8&255|512)<<2)>>2]|0;do{if((f|0)==0){d=c[m+(l*3160|0)+3144>>2]|0;if((d|0)==0){p=0;q=n;r=l;s=m;break}h=gj[d&4095](k)|0;p=h;q=b[4821352]|0;r=c[3528552]|0;s=c[2433426]|0}else{p=a[f+(g&255)|0]|0;q=n;r=l;s=m}}while(0);m=p&255;p=m|j;c[2426872]=p;b[4821352]=q+2&65535;q=p&65535;j=c[s+(r*3160|0)+60+(e<<2)>>2]|0;do{if((j|0)==0){e=c[s+(r*3160|0)+3132>>2]|0;if((e|0)==0){t=0;u=p;v=r;w=s;break}l=gj[e&4095](q)|0;t=l;u=c[2426872]|0;v=c[3528552]|0;w=c[2433426]|0}else{t=a[j+m|0]|0;u=p;v=r;w=s}}while(0);s=t+1&255;a[9642744]=a[9642744]&-15|a[668928+(s&255)|0];t=c[w+(v*3160|0)+60+((u>>>8&255|256)<<2)>>2]|0;if((t|0)!=0){a[t+(u&255)|0]=s;return}t=c[w+(v*3160|0)+3136>>2]|0;if((t|0)==0){return}gg[t&4095](u&65535,s);return}function fEQ(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=j&255;j=e<<8;g=k+1|0;k=g&65535;f=c[m+(l*3160|0)+60+((g>>>8&255|512)<<2)>>2]|0;do{if((f|0)==0){d=c[m+(l*3160|0)+3144>>2]|0;if((d|0)==0){p=0;q=n;r=l;s=m;break}h=gj[d&4095](k)|0;p=h;q=b[4821352]|0;r=c[3528552]|0;s=c[2433426]|0}else{p=a[f+(g&255)|0]|0;q=n;r=l;s=m}}while(0);m=p&255;p=m|j;c[2426872]=p;b[4821352]=q+2&65535;q=p&65535;p=c[s+(r*3160|0)+60+(e<<2)>>2]|0;do{if((p|0)==0){e=c[s+(r*3160|0)+3132>>2]|0;if((e|0)==0){t=0;break}t=gj[e&4095](q)|0}else{t=a[p+m|0]|0}}while(0);m=a[9642744]&-15|(t&255)>>>4&8;a[9642744]=t<<24>>24==0?m|4:m;return}function fER(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;break}n=gj[i&4095](e)|0;j=n;k=c[2410676]|0;l=c[3528552]|0;m=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g}}while(0);g=(j&255)<<8;j=k+1|0;k=j&65535;f=c[m+(l*3160|0)+60+((j>>>8&255|512)<<2)>>2]|0;do{if((f|0)==0){d=c[m+(l*3160|0)+3144>>2]|0;if((d|0)==0){o=0;break}o=gj[d&4095](k)|0}else{o=a[f+(j&255)|0]|0}}while(0);j=o&255|g;c[2426872]=j;c[2410676]=j;b[4821352]=j&65535;return}function fES(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=j&255;j=e<<8;g=k+1|0;k=g&65535;f=c[m+(l*3160|0)+60+((g>>>8&255|512)<<2)>>2]|0;do{if((f|0)==0){d=c[m+(l*3160|0)+3144>>2]|0;if((d|0)==0){p=0;q=n;r=l;s=m;break}h=gj[d&4095](k)|0;p=h;q=b[4821352]|0;r=c[3528552]|0;s=c[2433426]|0}else{p=a[f+(g&255)|0]|0;q=n;r=l;s=m}}while(0);m=p&255|j;c[2426872]=m;b[4821352]=q+2&65535;q=m&65535;do{if((c[s+(r*3160|0)+60+(e<<2)>>2]|0)==0){j=c[s+(r*3160|0)+3132>>2]|0;if((j|0)==0){t=m;u=r;v=s;break}gj[j&4095](q)|0;t=c[2426872]|0;u=c[3528552]|0;v=c[2433426]|0}else{t=m;u=r;v=s}}while(0);s=c[v+(u*3160|0)+60+((t>>>8&255|256)<<2)>>2]|0;if((s|0)!=0){a[s+(t&255)|0]=0;w=a[9642744]|0;x=w&-16;y=x|4;a[9642744]=y;return}s=c[v+(u*3160|0)+3136>>2]|0;if((s|0)==0){w=a[9642744]|0;x=w&-16;y=x|4;a[9642744]=y;return}gg[s&4095](t&65535,0);w=a[9642744]|0;x=w&-16;y=x|4;a[9642744]=y;return}function fET(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;break}l=gj[i&4095](e)|0;j=l;k=b[4821352]|0}else{j=a[h+(d&255)|0]|0;k=e}}while(0);b[4821352]=k+1&65535;k=a[9642713]|0;e=(k&255)-(j&255)|0;d=(e>>>4&8|a[9642744]&-16&255)&255;h=e&255;a[9642744]=(((k^j)&255^e^e>>>1)>>>6&2|e>>>8&1|(h<<24>>24==0?d|4:d)&255)&255;a[9642713]=h;return}function fEU(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;break}l=gj[i&4095](e)|0;j=l;k=b[4821352]|0}else{j=a[h+(d&255)|0]|0;k=e}}while(0);b[4821352]=k+1&65535;k=a[9642713]|0;e=(k&255)-(j&255)|0;d=(e>>>4&8|a[9642744]&-16&255)&255;a[9642744]=(((k^j)&255^e^e>>>1)>>>6&2|e>>>8&1|((e&255)<<24>>24==0?d|4:d)&255)&255;return}function fEV(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;break}l=gj[i&4095](e)|0;j=l;k=b[4821352]|0}else{j=a[h+(d&255)|0]|0;k=e}}while(0);b[4821352]=k+1&65535;k=a[9642713]|0;e=a[9642744]|0;d=(k&255)-(j&255)-(e&1)|0;h=(d>>>4&8|e&-16&255)&255;e=d&255;a[9642744]=((d^(k^j)&255^d>>>1)>>>6&2|d>>>8&1|(e<<24>>24==0?h|4:h)&255)&255;a[9642713]=e;return}function fEW(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=c[2410676]|0;f=d&65535;g=c[3528552]|0;h=c[2433426]|0;i=c[h+(g*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((i|0)==0){j=c[h+(g*3160|0)+3144>>2]|0;if((j|0)==0){k=0;l=d;m=g;n=h;o=f;break}p=gj[j&4095](f)|0;j=c[2410676]|0;k=p;l=j;m=c[3528552]|0;n=c[2433426]|0;o=j&65535}else{k=a[i+(d&255)|0]|0;l=d;m=g;n=h;o=f}}while(0);f=(k&255)<<8;k=l+1|0;l=k&65535;h=c[n+(m*3160|0)+60+((k>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){g=c[n+(m*3160|0)+3144>>2]|0;if((g|0)==0){q=0;r=o;break}d=gj[g&4095](l)|0;q=d;r=b[4821352]|0}else{q=a[h+(k&255)|0]|0;r=o}}while(0);b[4821352]=r+2&65535;r=e[4821356]|0;o=r-(q&255|f)|0;q=(o>>>12&8|a[9642744]&-16&255)&255;k=o&65535;a[9642744]=((r^f^o^o>>>1)>>>14&2|o>>>16&1|(k<<16>>16==0?q|4:q)&255)&255;b[4821356]=k;return}function fEX(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;break}l=gj[i&4095](e)|0;j=l;k=b[4821352]|0}else{j=a[h+(d&255)|0]|0;k=e}}while(0);b[4821352]=k+1&65535;k=a[9642713]&j;a[9642713]=k;j=(k&255)>>>4&8|a[9642744]&-15;a[9642744]=k<<24>>24==0?j|4:j;return}function fEY(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;break}l=gj[i&4095](e)|0;j=l;k=b[4821352]|0}else{j=a[h+(d&255)|0]|0;k=e}}while(0);b[4821352]=k+1&65535;k=a[9642713]&j;j=(k&255)>>>4&8|a[9642744]&-15;a[9642744]=k<<24>>24==0?j|4:j;return}function fEZ(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;break}l=gj[i&4095](e)|0;j=l;k=b[4821352]|0}else{j=a[h+(d&255)|0]|0;k=e}}while(0);a[9642713]=j;b[4821352]=k+1&65535;k=a[9642744]&-15|(j&255)>>>4&8;a[9642744]=j<<24>>24==0?k|4:k;return}function fE_(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;break}l=gj[i&4095](e)|0;j=l;k=b[4821352]|0}else{j=a[h+(d&255)|0]|0;k=e}}while(0);b[4821352]=k+1&65535;k=a[9642713]|0;e=k^j;a[9642713]=e;d=(e&255)>>>4&8|a[9642744]&-15;a[9642744]=k<<24>>24==j<<24>>24?d|4:d;return}function fE$(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;break}l=gj[i&4095](e)|0;j=l;k=b[4821352]|0}else{j=a[h+(d&255)|0]|0;k=e}}while(0);b[4821352]=k+1&65535;k=a[9642713]|0;e=a[9642744]|0;d=(k&255)+(j&255)+(e&1)|0;h=(d>>>4&8|e&-48&255)&255;e=d&255;f=d^(k^j)&255;a[9642744]=(f<<1&32|d>>>8&1|(f^d>>>1)>>>6&2|(e<<24>>24==0?h|4:h)&255)&255;a[9642713]=e;return}function fE0(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;break}l=gj[i&4095](e)|0;j=l;k=b[4821352]|0}else{j=a[h+(d&255)|0]|0;k=e}}while(0);b[4821352]=k+1&65535;k=a[9642713]|j;a[9642713]=k;j=(k&255)>>>4&8|a[9642744]&-15;a[9642744]=k<<24>>24==0?j|4:j;return}function fE1(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;break}l=gj[i&4095](e)|0;j=l;k=b[4821352]|0}else{j=a[h+(d&255)|0]|0;k=e}}while(0);b[4821352]=k+1&65535;k=a[9642713]|0;e=(k&255)+(j&255)|0;d=(e>>>4&8|a[9642744]&-48&255)&255;h=e&255;f=(k^j)&255^e;a[9642744]=(f<<1&32|e>>>8&1|(f^e>>>1)>>>6&2|(h<<24>>24==0?d|4:d)&255)&255;a[9642713]=h;return}function fE2(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=c[2410676]|0;f=d&65535;g=c[3528552]|0;h=c[2433426]|0;i=c[h+(g*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((i|0)==0){j=c[h+(g*3160|0)+3144>>2]|0;if((j|0)==0){k=0;l=d;m=g;n=h;o=f;break}p=gj[j&4095](f)|0;j=c[2410676]|0;k=p;l=j;m=c[3528552]|0;n=c[2433426]|0;o=j&65535}else{k=a[i+(d&255)|0]|0;l=d;m=g;n=h;o=f}}while(0);f=(k&255)<<8;k=l+1|0;l=k&65535;h=c[n+(m*3160|0)+60+((k>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){g=c[n+(m*3160|0)+3144>>2]|0;if((g|0)==0){q=0;r=o;break}d=gj[g&4095](l)|0;q=d;r=b[4821352]|0}else{q=a[h+(k&255)|0]|0;r=o}}while(0);b[4821352]=r+2&65535;r=e[4821366]|0;o=r-(q&255|f)|0;q=(o>>>12&8|a[9642744]&-16&255)&255;a[9642744]=((r^f^o^o>>>1)>>>14&2|o>>>16&1|((o&65535)<<16>>16==0?q|4:q)&255)&255;return}function fE3(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=c[2410676]|0;f=d&65535;g=c[3528552]|0;h=c[2433426]|0;i=c[h+(g*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((i|0)==0){j=c[h+(g*3160|0)+3144>>2]|0;if((j|0)==0){k=0;l=f;m=g;n=h;break}o=gj[j&4095](f)|0;k=o;l=b[4821352]|0;m=c[3528552]|0;n=c[2433426]|0}else{k=a[i+(d&255)|0]|0;l=f;m=g;n=h}}while(0);h=l+1&65535;b[4821352]=h;b[4821364]=(b[4821364]|0)-1&65535;l=c[2410682]|0;g=l&65535;f=h&255;h=c[n+(m*3160|0)+60+((l>>>8&255|256)<<2)>>2]|0;do{if((h|0)==0){d=c[n+(m*3160|0)+3136>>2]|0;if((d|0)==0){p=m;q=n;break}gg[d&4095](g,f);p=c[3528552]|0;q=c[2433426]|0}else{a[h+(l&255)|0]=f;p=m;q=n}}while(0);b[4821364]=(b[4821364]|0)-1&65535;n=c[2410682]|0;m=n&65535;f=a[9642705]|0;l=c[q+(p*3160|0)+60+((n>>>8&255|256)<<2)>>2]|0;do{if((l|0)==0){h=c[q+(p*3160|0)+3136>>2]|0;if((h|0)==0){break}gg[h&4095](m,f)}else{a[l+(n&255)|0]=f}}while(0);f=k&255;b[4821352]=(e[4821352]|0)+((f&128|0)!=0?f|65280:f)&65535;b[4821352]=c[2410676]&65535;return}function fE4(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=j&255;j=e<<8;g=k+1|0;k=g&65535;f=c[m+(l*3160|0)+60+((g>>>8&255|512)<<2)>>2]|0;do{if((f|0)==0){d=c[m+(l*3160|0)+3144>>2]|0;if((d|0)==0){p=0;q=n;break}h=gj[d&4095](k)|0;p=h;q=b[4821352]|0}else{p=a[f+(g&255)|0]|0;q=n}}while(0);n=p&255|j;c[2410683]=n;b[4821352]=q+2&65535;q=a[9642744]&-15;a[9642744]=q;j=q&255|e>>>4&8;if((n|0)!=0){r=j&255;a[9642744]=r;return}r=(j|4)&255;a[9642744]=r;return}function fE5(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c[2426872]=c[2410680];d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;l=f;m=g;break}n=gj[i&4095](e)|0;j=n;k=b[4821352]|0;l=c[3528552]|0;m=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=e;l=f;m=g}}while(0);a[9707488]=j;b[4821352]=k+1&65535;k=c[2426872]|0;j=k&65535;g=c[m+(l*3160|0)+60+((k>>>8&255)<<2)>>2]|0;do{if((g|0)==0){f=c[m+(l*3160|0)+3132>>2]|0;if((f|0)==0){o=0;break}o=gj[f&4095](j)|0}else{o=a[g+(k&255)|0]|0}}while(0);k=a[9642713]|0;g=(k&255)-(o&255)|0;j=(g>>>4&8|a[9642744]&-16&255)&255;l=g&255;a[9642744]=(((k^o)&255^g^g>>>1)>>>6&2|g>>>8&1|(l<<24>>24==0?j|4:j)&255)&255;a[9642713]=l;return}function fE6(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c[2426872]=c[2410680];d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;l=f;m=g;break}n=gj[i&4095](e)|0;j=n;k=b[4821352]|0;l=c[3528552]|0;m=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=e;l=f;m=g}}while(0);a[9707488]=j;b[4821352]=k+1&65535;k=c[2426872]|0;j=k&65535;g=c[m+(l*3160|0)+60+((k>>>8&255)<<2)>>2]|0;do{if((g|0)==0){f=c[m+(l*3160|0)+3132>>2]|0;if((f|0)==0){o=0;break}o=gj[f&4095](j)|0}else{o=a[g+(k&255)|0]|0}}while(0);k=a[9642713]|0;g=(k&255)-(o&255)|0;j=(g>>>4&8|a[9642744]&-16&255)&255;a[9642744]=(((k^o)&255^g^g>>>1)>>>6&2|g>>>8&1|((g&255)<<24>>24==0?j|4:j)&255)&255;return}function fE7(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c[2426872]=c[2410680];d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;l=f;m=g;break}n=gj[i&4095](e)|0;j=n;k=b[4821352]|0;l=c[3528552]|0;m=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=e;l=f;m=g}}while(0);a[9707488]=j;b[4821352]=k+1&65535;k=c[2426872]|0;j=k&65535;g=c[m+(l*3160|0)+60+((k>>>8&255)<<2)>>2]|0;do{if((g|0)==0){f=c[m+(l*3160|0)+3132>>2]|0;if((f|0)==0){o=0;break}o=gj[f&4095](j)|0}else{o=a[g+(k&255)|0]|0}}while(0);k=a[9642713]|0;g=a[9642744]|0;j=(k&255)-(o&255)-(g&1)|0;l=(j>>>4&8|g&-16&255)&255;g=j&255;a[9642744]=((j^(k^o)&255^j>>>1)>>>6&2|j>>>8&1|(g<<24>>24==0?l|4:l)&255)&255;a[9642713]=g;return}function fE8(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;c[2426872]=c[2410680];d=c[2410676]|0;f=d&65535;g=c[3528552]|0;h=c[2433426]|0;i=c[h+(g*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((i|0)==0){j=c[h+(g*3160|0)+3144>>2]|0;if((j|0)==0){k=0;l=f;m=g;n=h;break}o=gj[j&4095](f)|0;k=o;l=b[4821352]|0;m=c[3528552]|0;n=c[2433426]|0}else{k=a[i+(d&255)|0]|0;l=f;m=g;n=h}}while(0);a[9707488]=k;b[4821352]=l+1&65535;l=c[2426872]|0;k=l&65535;h=c[n+(m*3160|0)+60+((l>>>8&255)<<2)>>2]|0;do{if((h|0)==0){g=c[n+(m*3160|0)+3132>>2]|0;if((g|0)==0){p=0;q=m;r=n;break}f=gj[g&4095](k)|0;p=f;q=c[3528552]|0;r=c[2433426]|0}else{p=a[h+(l&255)|0]|0;q=m;r=n}}while(0);n=(p&255)<<8;p=l+1|0;l=p&65535;m=c[r+(q*3160|0)+60+((p>>>8&255)<<2)>>2]|0;do{if((m|0)==0){h=c[r+(q*3160|0)+3132>>2]|0;if((h|0)==0){s=0;break}s=gj[h&4095](l)|0}else{s=a[m+(p&255)|0]|0}}while(0);p=e[4821356]|0;m=p-(s&255|n)|0;s=(m>>>12&8|a[9642744]&-16&255)&255;l=m&65535;a[9642744]=((p^n^m^m>>>1)>>>14&2|m>>>16&1|(l<<16>>16==0?s|4:s)&255)&255;b[4821356]=l;return}function fE9(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c[2426872]=c[2410680];d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;l=f;m=g;break}n=gj[i&4095](e)|0;j=n;k=b[4821352]|0;l=c[3528552]|0;m=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=e;l=f;m=g}}while(0);a[9707488]=j;b[4821352]=k+1&65535;k=c[2426872]|0;j=k&65535;g=c[m+(l*3160|0)+60+((k>>>8&255)<<2)>>2]|0;do{if((g|0)==0){f=c[m+(l*3160|0)+3132>>2]|0;if((f|0)==0){o=0;break}o=gj[f&4095](j)|0}else{o=a[g+(k&255)|0]|0}}while(0);k=a[9642713]&o;a[9642713]=k;o=(k&255)>>>4&8|a[9642744]&-15;a[9642744]=k<<24>>24==0?o|4:o;return}
function aMJ(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;e=i;i=i+480|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;c[2424]=5800;c[2414836]=0;c[2388064]=0;c[2386024]=1048576;c[2387764]=1048576;c[3530734]=1114112;c[3530498]=3211264;c[3530366]=5308416;c[3530300]=8454144;c[3530284]=18939904;c[3541206]=19988480;c[3529736]=19988480;c[3529692]=21037056;c[3529874]=21823488;c[2414538]=21831680;c[2388194]=21831680;c[2387786]=21864448;c[2386368]=21872640;c[2386546]=21874688;c[3529622]=21876736;c[3529670]=21878784;c[2387088]=21880832;c[2383414]=21889024;c[2387034]=21889024;c[2386174]=21891072;c[3528204]=21893120;c[3528638]=21893121;c[2411436]=21893122;c[3527020]=21893122;p=(a[9688]|0?21895258:21893122)|0;c[2413976]=p;q=p;p=0;while(1){if((p|0)>=1024){break}r=9638528+(p<<2)|0;if((c[r>>2]|0)==0){s=36124;break}else{p=p+1|0}}do{if((s|0)==36124){p=gGq(q)|0;c[r>>2]=p;if((p|0)==0){break}gGz(p|0,0,q|0);c[2414836]=p;gGz(p|0,0,q|0);c[2388064]=p;t=p+1048576|0;c[2386024]=t;c[2387764]=t;c[3530734]=p+1114112;c[3530498]=p+3211264;c[3530366]=p+5308416;c[3530300]=p+8454144;c[3530284]=p+18939904;t=p+19988480|0;c[3541206]=t;c[3529736]=t;c[3529692]=p+21037056;c[3529874]=p+21823488;t=p+21831680|0;c[2414538]=t;c[2388194]=t;c[2387786]=p+21864448;c[2386368]=p+21872640;c[2386546]=p+21874688;c[3529622]=p+21876736;c[3529670]=p+21878784;c[2387088]=p+21880832;t=p+21889024|0;c[2383414]=t;c[2387034]=t;c[2386174]=p+21891072;c[3528204]=p+21893120;c[3528638]=p+21893121;t=p+21893122|0;c[2411436]=t;c[3527020]=t;c[2413976]=p+(a[9688]|0?21895258:21893122);if((c[3542200]|0)==0){u=1;i=e;return u|0}t=n+108|0;c[t>>2]=0;v=n+100|0;c[v>>2]=0;w=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[w&16383](n,0)|0;do{if((c[t>>2]|0)!=0){w=c[v>>2]|0;c[o>>2]=9534384;x=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[x&16383](o,0,0)|0;if((w|0)<1){u=1;i=e;return u|0}if((gzL(p,0,0)|0)==0){break}else{u=1}i=e;return u|0}}while(0);p=(c[2388064]|0)+524288|0;if((c[3542200]|0)==0){u=1;i=e;return u|0}v=l+108|0;c[v>>2]=0;t=l+100|0;c[t>>2]=0;w=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[w&16383](l,1)|0;do{if((c[v>>2]|0)!=0){w=c[t>>2]|0;c[m>>2]=9534384;x=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[x&16383](m,1,0)|0;if((w|0)<1){u=1;i=e;return u|0}if((gzL(p,0,1)|0)==0){break}else{u=1}i=e;return u|0}}while(0);p=c[2386024]|0;if((c[3542200]|0)==0){u=1;i=e;return u|0}t=j+108|0;c[t>>2]=0;v=j+100|0;c[v>>2]=0;w=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[w&16383](j,2)|0;do{if((c[t>>2]|0)!=0){w=c[v>>2]|0;c[k>>2]=9534384;x=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[x&16383](k,2,0)|0;if((w|0)<1){u=1;i=e;return u|0}if((gzL(p,0,2)|0)==0){break}else{u=1}i=e;return u|0}}while(0);p=gGq(4194304)|0;if((R6(p,3,2)|0)!=0){u=1;i=e;return u|0}if((R6(p+1|0,4,2)|0)==0){y=0;z=p}else{u=1;i=e;return u|0}while(1){v=a[z]|0;t=z+1|0;a[z]=a[t]|0;a[t]=v;v=y+1|0;if((v|0)<2097152){y=v;z=z+2|0}else{A=0;break}}do{v=p+A|0;a[v]=~a[v];A=A+1|0;}while((A|0)<2097152);v=c[3530734]|0;gGC(v|0,p|0,131072)|0;v=c[3530498]|0;t=p+524288|0;gGC(v|0,t|0,524288)|0;t=c[3530366]|0;v=p+1572864|0;gGC(t|0,v|0,524288)|0;v=t+524288|0;t=p+1048576|0;gGC(v|0,t|0,524288)|0;t=c[3530300]|0;v=p+2097152|0;gGC(t|0,v|0,2097152)|0;gGr(p);v=c[3529736]|0;if((c[3542200]|0)==0){u=1;i=e;return u|0}t=f+108|0;c[t>>2]=0;w=f+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,5)|0;do{if((c[t>>2]|0)!=0){x=c[w>>2]|0;c[g>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](g,5,0)|0;if((x|0)<1){u=1;i=e;return u|0}if((gzL(v,0,5)|0)==0){break}else{u=1}i=e;return u|0}}while(0);v=c[3530734]|0;w=0;while(1){if((w|0)>=1024){C=0;break}D=9638528+(w<<2)|0;if((c[D>>2]|0)==0){s=36149;break}else{w=w+1|0}}do{if((s|0)==36149){w=gGq(131072)|0;c[D>>2]=w;if((w|0)==0){C=0;break}gGz(w|0,0,131072);C=w}}while(0);gGC(C|0,v|0,131072)|0;w=0;while(1){t=C+(w|3)|0;p=C+(w|1)|0;x=C+(w|2)|0;B=C+w|0;E=w<<1;F=0;do{G=F^7;a[v+(F+E)|0]=((d[p]|0)>>>(G>>>0)<<2&4|(d[t]|0)>>>(G>>>0)<<3&8|(d[x]|0)>>>(G>>>0)<<1&2|(d[B]|0)>>>(G>>>0)&1)&255;F=F+1|0;}while((F|0)<8);F=w+4|0;if((F|0)<131072){w=F}else{H=0;break}}while(1){if((H|0)>=1024){break}I=9638528+(H<<2)|0;if((c[I>>2]|0)==(C|0)){s=36157;break}else{H=H+1|0}}if((s|0)==36157){gGr(C);c[I>>2]=0}aE$(c[3530498]|0,524288);aE$(c[3530366]|0,1048576);aE$(c[3530300]|0,2097152);aE1(0,1,1);w=c[3530498]|0;v=c[3530366]|0;c[2383440]=c[3530734];c[2383441]=w;c[2383442]=v;c[2383436]=4095;c[2383437]=4095;c[2383438]=8191;a[690376]=1;c[2429434]=2;c[2429435]=0;c[2429430]=2;c[2429431]=0;c[2429668]=512;c[2429669]=1280;c[2429438]=1670;c[2429439]=1670;fxU(0,425984);if((c[2394]|0)==0){J=c[2112932]|0}else{c[2394]=0;v=c[3532596]|0;c[2112932]=v;w=c[3532592]|0;if((w|0)!=0){gGC(9104152,w|0,280)|0}c[2113054]=c[2113060];J=v}v=c[2388064]|0;w=J|0;F=0;while(1){B=v+F|0;c[w>>2]=B;c[w+131072>>2]=B;B=F+1024|0;if(B>>>0>786431){break}else{w=w+4|0;F=B}}F=c[2386368]|0;c[J+4992>>2]=F;c[J+70528>>2]=F;c[J+136064>>2]=F;w=F+1024|0;c[J+4996>>2]=w;c[J+70532>>2]=w;c[J+136068>>2]=w;w=c[2383430]|0;c[J+5184>>2]=w;c[J+70720>>2]=w;c[J+136256>>2]=w;F=w+1024|0;c[J+5188>>2]=F;c[J+70724>>2]=F;c[J+136260>>2]=F;F=w+2048|0;c[J+5192>>2]=F;c[J+70728>>2]=F;c[J+136264>>2]=F;F=w+3072|0;c[J+5196>>2]=F;c[J+70732>>2]=F;c[J+136268>>2]=F;F=c[2383431]|0;c[J+5216>>2]=F;c[J+70752>>2]=F;c[J+136288>>2]=F;w=F+1024|0;c[J+5220>>2]=w;c[J+70756>>2]=w;c[J+136292>>2]=w;w=F+2048|0;c[J+5224>>2]=w;c[J+70760>>2]=w;c[J+136296>>2]=w;w=F+3072|0;c[J+5228>>2]=w;c[J+70764>>2]=w;c[J+136300>>2]=w;w=c[2383428]|0;c[J+5312>>2]=w;c[J+70848>>2]=w;c[J+136384>>2]=w;F=w+1024|0;c[J+5316>>2]=F;c[J+70852>>2]=F;c[J+136388>>2]=F;F=c[2383426]|0;c[J+5344>>2]=F;c[J+70880>>2]=F;c[J+136416>>2]=F;w=F+1024|0;c[J+5348>>2]=w;c[J+70884>>2]=w;c[J+136420>>2]=w;w=c[2383432]|0;c[J+5440>>2]=w;c[J+70976>>2]=w;c[J+136512>>2]=w;F=w+1024|0;c[J+5444>>2]=F;c[J+70980>>2]=F;c[J+136516>>2]=F;F=w+2048|0;c[J+5448>>2]=F;c[J+70984>>2]=F;c[J+136520>>2]=F;F=w+3072|0;c[J+5452>>2]=F;c[J+70988>>2]=F;c[J+136524>>2]=F;F=c[2383433]|0;c[J+5472>>2]=F;c[J+71008>>2]=F;c[J+136544>>2]=F;w=F+1024|0;c[J+5476>>2]=w;c[J+71012>>2]=w;c[J+136548>>2]=w;w=F+2048|0;c[J+5480>>2]=w;c[J+71016>>2]=w;c[J+136552>>2]=w;w=F+3072|0;c[J+5484>>2]=w;c[J+71020>>2]=w;c[J+136556>>2]=w;w=c[2383424]|0;c[J+5568>>2]=w;c[J+71104>>2]=w;c[J+136640>>2]=w;F=w+1024|0;c[J+5572>>2]=F;c[J+71108>>2]=F;c[J+136644>>2]=F;F=c[2383422]|0;c[J+5600>>2]=F;c[J+71136>>2]=F;c[J+136672>>2]=F;w=F+1024|0;c[J+5604>>2]=w;c[J+71140>>2]=w;c[J+136676>>2]=w;w=c[2388194]|0;F=J+6144|0;v=1572864;while(1){B=w+(v-1572864)|0;c[F>>2]=B;c[F+65536>>2]=B;c[F+131072>>2]=B;B=v+1024|0;if(B>>>0>1605631){break}else{F=F+4|0;v=B}}v=c[2387088]|0;c[J+6592>>2]=v;c[J+72128>>2]=v;c[J+137664>>2]=v;F=v+1024|0;c[J+6596>>2]=F;c[J+72132>>2]=F;c[J+137668>>2]=F;F=v+2048|0;c[J+6600>>2]=F;c[J+72136>>2]=F;c[J+137672>>2]=F;F=v+3072|0;c[J+6604>>2]=F;c[J+72140>>2]=F;c[J+137676>>2]=F;F=v+4096|0;c[J+6608>>2]=F;c[J+72144>>2]=F;c[J+137680>>2]=F;F=v+5120|0;c[J+6612>>2]=F;c[J+72148>>2]=F;c[J+137684>>2]=F;F=v+6144|0;c[J+6616>>2]=F;c[J+72152>>2]=F;c[J+137688>>2]=F;F=v+7168|0;c[J+6620>>2]=F;c[J+72156>>2]=F;c[J+137692>>2]=F;c[J+196728>>2]=796;c[J+196648>>2]=562;c[J+196688>>2]=3406;c[J+196608>>2]=368;F=c[3532592]|0;if((F|0)!=0){gGC(F|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;a[668920]=1;fwR(0);F=c[2439330]|0;v=(F|0)==0;if(!v){w=F;gGC(9706056,w|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];w=c[3528484]|0;c[2076596]=w;B=c[2417276]|0;c[3541536]=B;c[1836236]=0;x=c[2386024]|0;t=0;p=0;while(1){c[F+76+(p<<2)>>2]=x+(p<<8);E=t+1&65535;if((E&65535)>127){K=0;L=0;break}else{t=E;p=E&65535}}while(1){p=x+(L<<8)|0;c[F+76+(L+512<<2)>>2]=p;c[F+76+(L+768<<2)>>2]=p;p=K+1&65535;if((p&65535)>127){break}else{K=p;L=p&65535}}x=c[2386174]|0;c[F+588>>2]=x;p=x+256|0;c[F+592>>2]=p;t=x+512|0;c[F+596>>2]=t;E=x+768|0;c[F+600>>2]=E;G=x+1024|0;c[F+604>>2]=G;M=x+1280|0;c[F+608>>2]=M;N=x+1536|0;c[F+612>>2]=N;O=x+1792|0;c[F+616>>2]=O;c[F+1612>>2]=x;c[F+1616>>2]=p;c[F+1620>>2]=t;c[F+1624>>2]=E;c[F+1628>>2]=G;c[F+1632>>2]=M;c[F+1636>>2]=N;c[F+1640>>2]=O;c[F+2636>>2]=x;c[F+3660>>2]=x;c[F+2640>>2]=p;c[F+3664>>2]=p;c[F+2644>>2]=t;c[F+3668>>2]=t;c[F+2648>>2]=E;c[F+3672>>2]=E;c[F+2652>>2]=G;c[F+3676>>2]=G;c[F+2656>>2]=M;c[F+3680>>2]=M;c[F+2660>>2]=N;c[F+3684>>2]=N;c[F+2664>>2]=O;c[F+3688>>2]=O;c[F+4184>>2]=2866;c[F+4180>>2]=2090;if(!v){O=F;gGC(O|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=w;c[2417276]=B;c[1836236]=-1;O=a[9680]|0;N=O?32e3:0;if(O){if(a[9624]|0){O=N*3|0;M=55937;while(1){if((M|0)>(O|0)){M=M>>1}else{P=1222;Q=M;break}}}else{P=2462;Q=N}c[2429380]=Q;c[3542124]=P;mw(358e4,Q);M=gGq(262144)|0;c[2406684]=M;gGz(M|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(358e4,11025)}c[(c[3531464]|0)+44344>>2]=884;h[745421]=.45;c[2436794]=3;h[745420]=.45;c[2436792]=3;Ux(0,7627,1);Ux(1,15255,1);c[2407030]=192;c[2407068]=3;c[2407069]=154;c[2407107]=3;M=c[642608+(c[2436]<<2)>>2]|0;O=c[M+128>>2]|0;if((c[M+52>>2]&4|0)==0){c[2113068]=O;B=c[M+132>>2]|0;c[2113070]=B;c[2443814]=O;c[2440436]=B;R=O;S=B}else{c[2113070]=O;B=c[M+132>>2]|0;c[2113068]=B;c[2440436]=O;c[2443814]=B;R=B;S=O}O=ag(R<<1,S)|0;B=gGq(O)|0;c[2112926]=B;if((B|0)!=0){gGz(B|0,0,O|0)}aNk();u=0;i=e;return u|0}}while(0);c[2414836]=0;u=1;i=e;return u|0}function aMK(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;d=c[3529874]|0;f=c[2387088]|0;g=(c[642608+(c[2436]<<2)>>2]|0)+124|0;if((c[g>>2]<<1|0)>0){h=0;do{i=e[f+((h|1)<<1)>>1]|0;c[d+(((h|0)/2|0)<<2)>>2]=i<<8&63488|(e[f+(h<<1)>>1]|0)>>>3&31|i>>>8<<3&2016;h=h+2|0;}while((h|0)<(c[g>>2]<<1|0))}a[9547008]=0;aE3();aE5();g=ag(c[2113070]|0,c[2113068]|0)|0;h=c[2112926]|0;if((g|0)>0){f=0;while(1){b[h+(f<<1)>>1]=512;d=f+1|0;if((d|0)<(g|0)){f=d}else{j=h;break}}}else{j=h}gGz(c[2383420]|0,0,131072);gGz(c[2383410]|0,0,131072);aE0(3,j,65537);aE0(2,j,2);aE0(1,j,2);aE0(1,j,260);h=c[2386546]|0;f=1020;g=0;do{d=(b[h+(g+1<<1)>>1]|0)==384;f=d?g:f;g=d?1024:g+4|0;}while((g|0)<1020);if((f|0)<=-1){aE0(0,j,0);k=c[3529874]|0;R8(k);return 0}g=c[3528638]|0;d=c[3530300]|0;i=(c[2113222]&1|0)==0;l=f;do{f=b[h+(l<<1)>>1]|0;m=f&65535;n=e[h+(l+1<<1)>>1]|0;do{if(f<<16>>16!=0){o=e[h+(l+2<<1)>>1]|0;p=o&49152;if((p|0)==32768){q=252}else if((p|0)==16384){q=240}else if((p|0)==49152){q=252}else{q=0}if(!((n&4096|0)==0|i)){break}p=n&8192;r=n&16384;s=1<<(n>>>9&3);t=s-1|0;u=n-(t<<4)+4|0;v=o&511;w=u&511;x=v>>>0>255?o|-512:v;v=w>>>0>255?u|-512:w;w=((r|0)!=0?0:t)+m|0;u=(r>>>13^2)-1|0;if((a[g]|0)==0){y=-16;z=r;A=p;B=240-v|0;C=240-x|0}else{y=16;z=r>>>14^1;A=p>>>13^1;B=v;C=x}if((s|0)<=0){break}s=(o>>>9<<4&496)+768|0;o=t;while(1){t=w-(ag(o,u)|0)|0;aEY(j,d,t,s,C,(ag(o,y)|0)+B|0,A,z,q,-1);if((o|0)>0){o=o-1|0}else{break}}}}while(0);l=l-4|0;}while((l|0)>-1);aE0(0,j,0);k=c[3529874]|0;R8(k);return 0}function aML(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4523948+(b*112|0)>>2];c[a+104>>2]=c[4523952+(b*112|0)>>2];c[a+108>>2]=c[4523956+(b*112|0)>>2];d=0;return d|0}function aMM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<22&(d|0)==0)){e=1;return e|0}c[a>>2]=4523848+(b*112|0);e=0;return e|0}function aMN(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>46){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5239784+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aMO(){var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;b=i;i=i+720|0;d=b|0;e=b+112|0;f=b+120|0;g=b+232|0;j=b+240|0;k=b+352|0;l=b+360|0;m=b+472|0;n=b+480|0;o=b+592|0;p=b+600|0;q=b+712|0;c[2424]=5800;c[2414836]=0;c[2388064]=0;c[2386024]=1048576;c[2387764]=1048576;c[3530734]=1114112;c[3530498]=3211264;c[3530366]=5308416;c[3530300]=8454144;c[3530284]=18939904;c[3541206]=19988480;c[3529736]=19988480;c[3529692]=21037056;c[3529874]=21823488;c[2414538]=21831680;c[2388194]=21831680;c[2387786]=21864448;c[2386368]=21872640;c[2386546]=21874688;c[3529622]=21876736;c[3529670]=21878784;c[2387088]=21880832;c[2383414]=21889024;c[2387034]=21889024;c[2386174]=21891072;c[3528204]=21893120;c[3528638]=21893121;c[2411436]=21893122;c[3527020]=21893122;r=(a[9688]|0?21895258:21893122)|0;c[2413976]=r;s=r;r=0;while(1){if((r|0)>=1024){break}t=9638528+(r<<2)|0;if((c[t>>2]|0)==0){u=36250;break}else{r=r+1|0}}do{if((u|0)==36250){r=gGq(s)|0;c[t>>2]=r;if((r|0)==0){break}gGz(r|0,0,s|0);c[2414836]=r;gGz(r|0,0,s|0);c[2388064]=r;v=r+1048576|0;c[2386024]=v;c[2387764]=v;c[3530734]=r+1114112;c[3530498]=r+3211264;c[3530366]=r+5308416;c[3530300]=r+8454144;c[3530284]=r+18939904;v=r+19988480|0;c[3541206]=v;c[3529736]=v;c[3529692]=r+21037056;c[3529874]=r+21823488;v=r+21831680|0;c[2414538]=v;c[2388194]=v;c[2387786]=r+21864448;c[2386368]=r+21872640;c[2386546]=r+21874688;c[3529622]=r+21876736;c[3529670]=r+21878784;c[2387088]=r+21880832;v=r+21889024|0;c[2383414]=v;c[2387034]=v;c[2386174]=r+21891072;c[3528204]=r+21893120;c[3528638]=r+21893121;v=r+21893122|0;c[2411436]=v;c[3527020]=v;c[2413976]=r+(a[9688]|0?21895258:21893122);if((R6(r+1|0,0,2)|0)!=0){w=1;i=b;return w|0}if((R6(c[2388064]|0,1,2)|0)!=0){w=1;i=b;return w|0}if((R6((c[2388064]|0)+262145|0,2,2)|0)!=0){w=1;i=b;return w|0}if((R6((c[2388064]|0)+262144|0,3,2)|0)!=0){w=1;i=b;return w|0}r=c[2387764]|0;if((c[3542200]|0)==0){w=1;i=b;return w|0}v=p+108|0;c[v>>2]=0;x=p+100|0;c[x>>2]=0;y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[y&16383](p,4)|0;do{if((c[v>>2]|0)!=0){y=c[x>>2]|0;c[q>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](q,4,0)|0;if((y|0)<1){w=1;i=b;return w|0}if((gzL(r,0,4)|0)==0){break}else{w=1}i=b;return w|0}}while(0);if((R6(c[3530734]|0,5,2)|0)!=0){w=1;i=b;return w|0}if((R6((c[3530734]|0)+1|0,6,2)|0)!=0){w=1;i=b;return w|0}r=c[3530498]|0;if((c[3542200]|0)==0){w=1;i=b;return w|0}x=n+108|0;c[x>>2]=0;v=n+100|0;c[v>>2]=0;y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[y&16383](n,7)|0;do{if((c[x>>2]|0)!=0){y=c[v>>2]|0;c[o>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](o,7,0)|0;if((y|0)<1){w=1;i=b;return w|0}if((gzL(r,0,7)|0)==0){break}else{w=1}i=b;return w|0}}while(0);r=c[3530734]|0;v=r+327680|0;x=r+65536|0;gGC(v|0,x|0,65536)|0;v=c[3530498]|0;gGC(x|0,v|0,262144)|0;x=r+393216|0;r=v+262144|0;gGC(x|0,r|0,262144)|0;r=c[3530366]|0;if((c[3542200]|0)==0){w=1;i=b;return w|0}x=l+108|0;c[x>>2]=0;v=l+100|0;c[v>>2]=0;y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[y&16383](l,8)|0;do{if((c[x>>2]|0)!=0){y=c[v>>2]|0;c[m>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](m,8,0)|0;if((y|0)<1){w=1;i=b;return w|0}if((gzL(r,0,8)|0)==0){break}else{w=1}i=b;return w|0}}while(0);r=(c[3530366]|0)+524288|0;if((c[3542200]|0)==0){w=1;i=b;return w|0}v=j+108|0;c[v>>2]=0;x=j+100|0;c[x>>2]=0;y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[y&16383](j,9)|0;do{if((c[v>>2]|0)!=0){y=c[x>>2]|0;c[k>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](k,9,0)|0;if((y|0)<1){w=1;i=b;return w|0}if((gzL(r,0,9)|0)==0){break}else{w=1}i=b;return w|0}}while(0);r=c[3530366]|0;x=0;do{v=r+(x+262144)|0;y=a[v]|0;z=r+(x+524288)|0;a[v]=a[z]|0;a[z]=y;x=x+1|0;}while((x|0)<262144);if((R6(c[3530300]|0,10,2)|0)!=0){w=1;i=b;return w|0}if((R6((c[3530300]|0)+1|0,13,2)|0)!=0){w=1;i=b;return w|0}if((R6((c[3530300]|0)+2097152|0,11,2)|0)!=0){w=1;i=b;return w|0}if((R6((c[3530300]|0)+2097153|0,14,2)|0)!=0){w=1;i=b;return w|0}if((R6((c[3530300]|0)+4194304|0,12,2)|0)!=0){w=1;i=b;return w|0}if((R6((c[3530300]|0)+4194305|0,15,2)|0)!=0){w=1;i=b;return w|0}if((R6((c[3530284]|0)+1|0,16,4)|0)!=0){w=1;i=b;return w|0}if((R6((c[3530284]|0)+3|0,17,4)|0)!=0){w=1;i=b;return w|0}if((R6(c[3530284]|0,18,4)|0)!=0){w=1;i=b;return w|0}if((R6((c[3530284]|0)+2|0,19,4)|0)!=0){w=1;i=b;return w|0}x=0;r=c[3530300]|0;while(1){y=a[r]|0;z=r+1|0;a[r]=a[z]|0;a[z]=y;y=x+1|0;if((y|0)<2621440){x=y;r=r+2|0}else{break}}r=0;x=c[3530284]|0;while(1){y=a[x]|0;z=x+1|0;a[x]=a[z]|0;a[z]=y;y=r+1|0;if((y|0)<131072){r=y;x=x+2|0}else{break}}x=c[3529736]|0;if((c[3542200]|0)==0){w=1;i=b;return w|0}r=f+108|0;c[r>>2]=0;y=f+100|0;c[y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,20)|0;do{if((c[r>>2]|0)!=0){z=c[y>>2]|0;c[g>>2]=9534384;v=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[v&16383](g,20,0)|0;if((z|0)<1){w=1;i=b;return w|0}if((gzL(x,0,20)|0)==0){break}else{w=1}i=b;return w|0}}while(0);x=(c[3529692]|0)+262144|0;if((c[3542200]|0)==0){w=1;i=b;return w|0}y=d+108|0;c[y>>2]=0;r=d+100|0;c[r>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](d,21)|0;do{if((c[y>>2]|0)!=0){z=c[r>>2]|0;c[e>>2]=9534384;v=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[v&16383](e,21,0)|0;if((z|0)<1){w=1;i=b;return w|0}if((gzL(x,0,21)|0)==0){break}else{w=1}i=b;return w|0}}while(0);aFg(c[3530734]|0,655360,1574056,720536,1110256);aFg(c[3530498]|0,524288,1574056,720536,1110256);x=c[3530734]|0;aE_(x,x,655360,1);x=c[3530498]|0;aE_(x,x,524288,0);x=c[3530366]|0;aE_(x,x,1048576,0);aE$(c[3530300]|0,5242880);aE$(c[3530284]|0,262144);aE1(0,0,1);x=c[3530498]|0;r=c[3530366]|0;c[2383440]=c[3530734];c[2383441]=x;c[2383442]=r;c[2383436]=32767;c[2383437]=4095;c[2383438]=8191;a[690376]=1;c[2429666]=0;c[2429667]=768;c[2429668]=512;c[2429669]=1024;c[2429436]=32;c[2429437]=2676;c[2429438]=32;c[2429439]=32;fxU(0,425984);if((c[2394]|0)==0){A=c[2112932]|0}else{c[2394]=0;r=c[3532596]|0;c[2112932]=r;x=c[3532592]|0;if((x|0)!=0){gGC(9104152,x|0,280)|0}c[2113054]=c[2113060];A=r}r=c[2388064]|0;x=A|0;y=0;while(1){z=r+y|0;c[x>>2]=z;c[x+131072>>2]=z;z=y+1024|0;if(z>>>0>524287){break}else{x=x+4|0;y=z}}y=c[2388194]|0;c[A+4096>>2]=y;c[A+69632>>2]=y;c[A+135168>>2]=y;x=y+1024|0;c[A+4100>>2]=x;c[A+69636>>2]=x;c[A+135172>>2]=x;x=y+2048|0;c[A+4104>>2]=x;c[A+69640>>2]=x;c[A+135176>>2]=x;x=y+3072|0;c[A+4108>>2]=x;c[A+69644>>2]=x;c[A+135180>>2]=x;x=y+4096|0;c[A+4112>>2]=x;c[A+69648>>2]=x;c[A+135184>>2]=x;x=y+5120|0;c[A+4116>>2]=x;c[A+69652>>2]=x;c[A+135188>>2]=x;x=y+6144|0;c[A+4120>>2]=x;c[A+69656>>2]=x;c[A+135192>>2]=x;x=y+7168|0;c[A+4124>>2]=x;c[A+69660>>2]=x;c[A+135196>>2]=x;x=y+8192|0;c[A+4128>>2]=x;c[A+69664>>2]=x;c[A+135200>>2]=x;x=y+9216|0;c[A+4132>>2]=x;c[A+69668>>2]=x;c[A+135204>>2]=x;x=y+10240|0;c[A+4136>>2]=x;c[A+69672>>2]=x;c[A+135208>>2]=x;x=y+11264|0;c[A+4140>>2]=x;c[A+69676>>2]=x;c[A+135212>>2]=x;x=y+12288|0;c[A+4144>>2]=x;c[A+69680>>2]=x;c[A+135216>>2]=x;x=y+13312|0;c[A+4148>>2]=x;c[A+69684>>2]=x;c[A+135220>>2]=x;x=y+14336|0;c[A+4152>>2]=x;c[A+69688>>2]=x;c[A+135224>>2]=x;x=y+15360|0;c[A+4156>>2]=x;c[A+69692>>2]=x;c[A+135228>>2]=x;x=c[2386368]|0;c[A+4608>>2]=x;c[A+70144>>2]=x;c[A+135680>>2]=x;y=x+1024|0;c[A+4612>>2]=y;c[A+70148>>2]=y;c[A+135684>>2]=y;y=c[3529622]|0;c[A+5120>>2]=y;c[A+70656>>2]=y;c[A+136192>>2]=y;x=y+1024|0;c[A+5124>>2]=x;c[A+70660>>2]=x;c[A+136196>>2]=x;x=c[2387088]|0;c[A+5632>>2]=x;c[A+71168>>2]=x;c[A+136704>>2]=x;y=x+1024|0;c[A+5636>>2]=y;c[A+71172>>2]=y;c[A+136708>>2]=y;y=x+2048|0;c[A+5640>>2]=y;c[A+71176>>2]=y;c[A+136712>>2]=y;y=x+3072|0;c[A+5644>>2]=y;c[A+71180>>2]=y;c[A+136716>>2]=y;y=x+4096|0;c[A+5648>>2]=y;c[A+71184>>2]=y;c[A+136720>>2]=y;y=x+5120|0;c[A+5652>>2]=y;c[A+71188>>2]=y;c[A+136724>>2]=y;y=x+6144|0;c[A+5656>>2]=y;c[A+71192>>2]=y;c[A+136728>>2]=y;y=x+7168|0;c[A+5660>>2]=y;c[A+71196>>2]=y;c[A+136732>>2]=y;y=c[2383430]|0;c[A+12352>>2]=y;c[A+77888>>2]=y;c[A+143424>>2]=y;x=y+1024|0;c[A+12356>>2]=x;c[A+77892>>2]=x;c[A+143428>>2]=x;x=y+2048|0;c[A+12360>>2]=x;c[A+77896>>2]=x;c[A+143432>>2]=x;x=y+3072|0;c[A+12364>>2]=x;c[A+77900>>2]=x;c[A+143436>>2]=x;x=y+4096|0;c[A+12368>>2]=x;c[A+77904>>2]=x;c[A+143440>>2]=x;x=y+5120|0;c[A+12372>>2]=x;c[A+77908>>2]=x;c[A+143444>>2]=x;x=y+6144|0;c[A+12376>>2]=x;c[A+77912>>2]=x;c[A+143448>>2]=x;x=y+7168|0;c[A+12380>>2]=x;c[A+77916>>2]=x;c[A+143452>>2]=x;x=c[2383431]|0;c[A+12384>>2]=x;c[A+77920>>2]=x;c[A+143456>>2]=x;y=x+1024|0;c[A+12388>>2]=y;c[A+77924>>2]=y;c[A+143460>>2]=y;y=x+2048|0;c[A+12392>>2]=y;c[A+77928>>2]=y;c[A+143464>>2]=y;y=x+3072|0;c[A+12396>>2]=y;c[A+77932>>2]=y;c[A+143468>>2]=y;y=x+4096|0;c[A+12400>>2]=y;c[A+77936>>2]=y;c[A+143472>>2]=y;y=x+5120|0;c[A+12404>>2]=y;c[A+77940>>2]=y;c[A+143476>>2]=y;y=x+6144|0;c[A+12408>>2]=y;c[A+77944>>2]=y;c[A+143480>>2]=y;y=x+7168|0;c[A+12412>>2]=y;c[A+77948>>2]=y;c[A+143484>>2]=y;y=c[2383428]|0;c[A+12416>>2]=y;c[A+77952>>2]=y;c[A+143488>>2]=y;x=y+1024|0;c[A+12420>>2]=x;c[A+77956>>2]=x;c[A+143492>>2]=x;x=c[2383426]|0;c[A+12448>>2]=x;c[A+77984>>2]=x;c[A+143520>>2]=x;y=x+1024|0;c[A+12452>>2]=y;c[A+77988>>2]=y;c[A+143524>>2]=y;y=c[2383432]|0;c[A+12608>>2]=y;c[A+78144>>2]=y;c[A+143680>>2]=y;x=y+1024|0;c[A+12612>>2]=x;c[A+78148>>2]=x;c[A+143684>>2]=x;x=y+2048|0;c[A+12616>>2]=x;c[A+78152>>2]=x;c[A+143688>>2]=x;x=y+3072|0;c[A+12620>>2]=x;c[A+78156>>2]=x;c[A+143692>>2]=x;x=y+4096|0;c[A+12624>>2]=x;c[A+78160>>2]=x;c[A+143696>>2]=x;x=y+5120|0;c[A+12628>>2]=x;c[A+78164>>2]=x;c[A+143700>>2]=x;x=y+6144|0;c[A+12632>>2]=x;c[A+78168>>2]=x;c[A+143704>>2]=x;x=y+7168|0;c[A+12636>>2]=x;c[A+78172>>2]=x;c[A+143708>>2]=x;x=c[2383433]|0;c[A+12640>>2]=x;c[A+78176>>2]=x;c[A+143712>>2]=x;y=x+1024|0;c[A+12644>>2]=y;c[A+78180>>2]=y;c[A+143716>>2]=y;y=x+2048|0;c[A+12648>>2]=y;c[A+78184>>2]=y;c[A+143720>>2]=y;y=x+3072|0;c[A+12652>>2]=y;c[A+78188>>2]=y;c[A+143724>>2]=y;y=x+4096|0;c[A+12656>>2]=y;c[A+78192>>2]=y;c[A+143728>>2]=y;y=x+5120|0;c[A+12660>>2]=y;c[A+78196>>2]=y;c[A+143732>>2]=y;y=x+6144|0;c[A+12664>>2]=y;c[A+78200>>2]=y;c[A+143736>>2]=y;y=x+7168|0;c[A+12668>>2]=y;c[A+78204>>2]=y;c[A+143740>>2]=y;y=c[2383424]|0;c[A+12672>>2]=y;c[A+78208>>2]=y;c[A+143744>>2]=y;x=y+1024|0;c[A+12676>>2]=x;c[A+78212>>2]=x;c[A+143748>>2]=x;x=c[2383422]|0;c[A+12704>>2]=x;c[A+78240>>2]=x;c[A+143776>>2]=x;y=x+1024|0;c[A+12708>>2]=y;c[A+78244>>2]=y;c[A+143780>>2]=y;c[A+196728>>2]=2246;c[A+196648>>2]=3252;c[A+196688>>2]=2666;c[A+196608>>2]=94;y=c[3532592]|0;if((y|0)!=0){gGC(y|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;aE8(c[2387764]|0,c[2387786]|0,8055e3,0,1894,.45,1006875,.75,2013750,.6);h[745421]=.45;c[2436794]=1;h[745420]=.45;c[2436792]=2;y=c[642608+(c[2436]<<2)>>2]|0;x=c[y+128>>2]|0;if((c[y+52>>2]&4|0)==0){c[2113068]=x;r=c[y+132>>2]|0;c[2113070]=r;c[2443814]=x;c[2440436]=r;B=x;C=r}else{c[2113070]=x;r=c[y+132>>2]|0;c[2113068]=r;c[2440436]=x;c[2443814]=r;B=r;C=x}x=ag(B<<1,C)|0;r=gGq(x)|0;c[2112926]=r;if((r|0)!=0){gGz(r|0,0,x|0)}aNk();w=0;i=b;return w|0}}while(0);c[2414836]=0;w=1;i=b;return w|0}function aMP(){var e=0,f=0,g=0,h=0,i=0,j=0;if((a[9623320]|0)!=0){aNk()}c[2383416]=9550096;c[2387524]=-1;e=0;f=-1;g=-1;do{f=((a[9632256+e|0]&1)<<e^f&65535)&65535;g=((a[9630168+e|0]&1)<<e^g&65535)&65535;e=e+1|0;}while((e|0)<16);b[4775048]=f;b[4775049]=g;b[4775050]=d[9634609]<<8|d[9634608];c[(c[2391608]|0)+60>>2]=0;c[(c[2391608]|0)+60>>2]=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060]}c[2388530]=9554128;g=c[2391608]|0;if((g|0)!=0){f=g;gGC(9661040,f|0,68)|0}c[2382]=0;c[2383408]=0;f=0;g=0;while(1){c[2113056]=942;e=RG(942)|0;c[2113054]=(c[2113054]|0)+e;c[2276108]=-1;c[2113056]=-1;fy_(542)|0;if((f|0)==240){c[2383408]=8}e=c[2112964]|0;if((e|0)==0){h=g}else{i=a[9688]|0?2:0;j=e+(g<<1<<1)|0;if(a[801408]|0){gg[c[3542124]&4095](j,i)}if(a[801400]|0){Uu(0,j,i)}if((c[2429658]|0)!=0){Uu(1,j,i)}h=i+g|0}i=f+1|0;if((i|0)<256){f=i;g=h}else{break}}c[8452200+(c[2394]<<2)>>2]=8198;c[2276080]=1536;if((c[2276079]|0)>>>0<1536){RH(6)}g=c[2112964]|0;do{if((g|0)!=0){f=a[9688]|0?534:0;if((f|0)==(h|0)){break}i=f-h|0;f=g+(h<<1<<1)|0;if(a[801408]|0){gg[c[3542124]&4095](f,i)}if(a[801400]|0){Uu(0,f,i)}if((c[2429658]|0)==0){break}Uu(1,f,i)}}while(0);h=c[(c[2388530]|0)+12304>>2]|0;if((h|0)!=0){g=h;gGC(g|0,9661040,68)|0}c[2382]=-1;g=c[2394]|0;h=c[14130368+(g<<2)>>2]|0;if((h|0)!=0){gGC(h|0,9104152,280)|0}c[8452240+(g<<2)>>2]=c[2113054];c[2394]=-1;if((c[2112968]|0)==0){return 0}aMQ()|0;return 0}function aMQ(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[3529874]|0;f=c[2387088]|0;g=(c[642608+(c[2436]<<2)>>2]|0)+124|0;if((c[g>>2]<<1|0)>0){h=0;do{i=e[f+((h|1)<<1)>>1]|0;c[d+(((h|0)/2|0)<<2)>>2]=i<<8&63488|(e[f+(h<<1)>>1]|0)>>>3&31|i>>>8<<3&2016;h=h+2|0;}while((h|0)<(c[g>>2]<<1|0))}a[9547008]=0;aE3();aE5();g=ag(c[2113070]|0,c[2113068]|0)|0;h=c[2112926]|0;if((g|0)>0){f=0;while(1){b[h+(f<<1)>>1]=1024;d=f+1|0;if((d|0)<(g|0)){f=d}else{j=h;break}}}else{j=h}aE0(3,j,65536);aE0(1,j,0);aE0(2,j,0);h=(b[4766836]&1)==0;f=c[2383420]|0;gGz(f|0,0,131072);g=c[2383410]|0;gGz(g|0,0,131072);if(h){aNm(c[3529670]|0,c[3530284]|0,1792,4);gGz(f|0,0,131072);gGz(g|0,0,131072);aNm(c[2386546]|0,c[3530300]|0,256,3);aE0(0,j,0);k=c[3529874]|0;R8(k);return 0}else{aNm(c[2386546]|0,c[3530300]|0,256,3);gGz(f|0,0,131072);gGz(g|0,0,131072);aNm(c[3529670]|0,c[3530284]|0,1792,4);aE0(0,j,0);k=c[3529874]|0;R8(k);return 0}return 0}function aMR(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2534412+(b*112|0)>>2];c[a+104>>2]=c[2534416+(b*112|0)>>2];c[a+108>>2]=c[2534420+(b*112|0)>>2];d=0;return d|0}function aMS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<22&(d|0)==0)){e=1;return e|0}c[a>>2]=2534312+(b*112|0);e=0;return e|0}function aMT(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2536876+(b*112|0)>>2];c[a+104>>2]=c[2536880+(b*112|0)>>2];c[a+108>>2]=c[2536884+(b*112|0)>>2];d=0;return d|0}function aMU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<22&(d|0)==0)){e=1;return e|0}c[a>>2]=2536776+(b*112|0);e=0;return e|0}function aMV(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2952340+(b*112|0)>>2];c[a+104>>2]=c[2952344+(b*112|0)>>2];c[a+108>>2]=c[2952348+(b*112|0)>>2];d=0;return d|0}function aMW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<22&(d|0)==0)){e=1;return e|0}c[a>>2]=2952240+(b*112|0);e=0;return e|0}function aMX(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>26){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4724156+(b*112|0)>>2];c[a+104>>2]=c[4724160+(b*112|0)>>2];c[a+108>>2]=c[4724164+(b*112|0)>>2];d=0;return d|0}function aMY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<27&(d|0)==0)){e=1;return e|0}c[a>>2]=4724056+(b*112|0);e=0;return e|0}function aMZ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>41){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5435568+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aM_(){var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;b=i;i=i+720|0;d=b|0;e=b+112|0;f=b+120|0;g=b+232|0;j=b+240|0;k=b+352|0;l=b+360|0;m=b+472|0;n=b+480|0;o=b+592|0;p=b+600|0;q=b+712|0;c[2424]=5800;c[2414836]=0;c[2388064]=0;c[2386024]=1048576;c[2387764]=1048576;c[3530734]=1114112;c[3530498]=3211264;c[3530366]=5308416;c[3530300]=8454144;c[3530284]=18939904;c[3541206]=19988480;c[3529736]=19988480;c[3529692]=21037056;c[3529874]=21823488;c[2414538]=21831680;c[2388194]=21831680;c[2387786]=21864448;c[2386368]=21872640;c[2386546]=21874688;c[3529622]=21876736;c[3529670]=21878784;c[2387088]=21880832;c[2383414]=21889024;c[2387034]=21889024;c[2386174]=21891072;c[3528204]=21893120;c[3528638]=21893121;c[2411436]=21893122;c[3527020]=21893122;r=(a[9688]|0?21895258:21893122)|0;c[2413976]=r;s=r;r=0;while(1){if((r|0)>=1024){break}t=9638528+(r<<2)|0;if((c[t>>2]|0)==0){u=36459;break}else{r=r+1|0}}do{if((u|0)==36459){r=gGq(s)|0;c[t>>2]=r;if((r|0)==0){break}gGz(r|0,0,s|0);c[2414836]=r;gGz(r|0,0,s|0);c[2388064]=r;v=r+1048576|0;c[2386024]=v;c[2387764]=v;c[3530734]=r+1114112;c[3530498]=r+3211264;c[3530366]=r+5308416;c[3530300]=r+8454144;c[3530284]=r+18939904;v=r+19988480|0;c[3541206]=v;c[3529736]=v;c[3529692]=r+21037056;c[3529874]=r+21823488;v=r+21831680|0;c[2414538]=v;c[2388194]=v;c[2387786]=r+21864448;c[2386368]=r+21872640;c[2386546]=r+21874688;c[3529622]=r+21876736;c[3529670]=r+21878784;c[2387088]=r+21880832;v=r+21889024|0;c[2383414]=v;c[2387034]=v;c[2386174]=r+21891072;c[3528204]=r+21893120;c[3528638]=r+21893121;v=r+21893122|0;c[2411436]=v;c[3527020]=v;c[2413976]=r+(a[9688]|0?21895258:21893122);if((R6(r+1|0,0,2)|0)!=0){w=1;i=b;return w|0}if((R6(c[2388064]|0,1,2)|0)!=0){w=1;i=b;return w|0}if((R6((c[2388064]|0)+262145|0,2,2)|0)!=0){w=1;i=b;return w|0}if((R6((c[2388064]|0)+262144|0,3,2)|0)!=0){w=1;i=b;return w|0}if((R6((c[2388064]|0)+524289|0,4,2)|0)!=0){w=1;i=b;return w|0}if((R6((c[2388064]|0)+524288|0,5,2)|0)!=0){w=1;i=b;return w|0}if((R6((c[2388064]|0)+786433|0,6,2)|0)!=0){w=1;i=b;return w|0}if((R6((c[2388064]|0)+786432|0,7,2)|0)!=0){w=1;i=b;return w|0}r=c[2387764]|0;if((c[3542200]|0)==0){w=1;i=b;return w|0}v=p+108|0;c[v>>2]=0;x=p+100|0;c[x>>2]=0;y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[y&16383](p,8)|0;do{if((c[v>>2]|0)!=0){y=c[x>>2]|0;c[q>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](q,8,0)|0;if((y|0)<1){w=1;i=b;return w|0}if((gzL(r,0,8)|0)==0){break}else{w=1}i=b;return w|0}}while(0);if((R6((c[3530734]|0)+1|0,9,2)|0)!=0){w=1;i=b;return w|0}if((R6(c[3530734]|0,10,2)|0)!=0){w=1;i=b;return w|0}r=c[3530498]|0;if((c[3542200]|0)==0){w=1;i=b;return w|0}x=n+108|0;c[x>>2]=0;v=n+100|0;c[v>>2]=0;y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[y&16383](n,11)|0;do{if((c[x>>2]|0)!=0){y=c[v>>2]|0;c[o>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](o,11,0)|0;if((y|0)<1){w=1;i=b;return w|0}if((gzL(r,0,11)|0)==0){break}else{w=1}i=b;return w|0}}while(0);r=c[3530366]|0;if((c[3542200]|0)==0){w=1;i=b;return w|0}v=l+108|0;c[v>>2]=0;x=l+100|0;c[x>>2]=0;y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[y&16383](l,12)|0;do{if((c[v>>2]|0)!=0){y=c[x>>2]|0;c[m>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](m,12,0)|0;if((y|0)<1){w=1;i=b;return w|0}if((gzL(r,0,12)|0)==0){break}else{w=1}i=b;return w|0}}while(0);r=(c[3530366]|0)+524288|0;if((c[3542200]|0)==0){w=1;i=b;return w|0}x=j+108|0;c[x>>2]=0;v=j+100|0;c[v>>2]=0;y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[y&16383](j,13)|0;do{if((c[x>>2]|0)!=0){y=c[v>>2]|0;c[k>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](k,13,0)|0;if((y|0)<1){w=1;i=b;return w|0}if((gzL(r,0,13)|0)==0){break}else{w=1}i=b;return w|0}}while(0);r=c[3530366]|0;v=0;do{x=r+(v+262144)|0;y=a[x]|0;z=r+(v+524288)|0;a[x]=a[z]|0;a[z]=y;v=v+1|0;}while((v|0)<262144);if((R6(c[3530300]|0,14,2)|0)!=0){w=1;i=b;return w|0}if((R6((c[3530300]|0)+1|0,15,2)|0)!=0){w=1;i=b;return w|0}if((R6((c[3530300]|0)+1048576|0,16,2)|0)!=0){w=1;i=b;return w|0}if((R6((c[3530300]|0)+1048577|0,17,2)|0)!=0){w=1;i=b;return w|0}if((R6((c[3530300]|0)+2097152|0,18,2)|0)!=0){w=1;i=b;return w|0}if((R6((c[3530300]|0)+2097153|0,19,2)|0)!=0){w=1;i=b;return w|0}if((R6((c[3530300]|0)+3145728|0,20,2)|0)!=0){w=1;i=b;return w|0}if((R6((c[3530300]|0)+3145729|0,21,2)|0)!=0){w=1;i=b;return w|0}if((R6((c[3530300]|0)+4194304|0,22,2)|0)!=0){w=1;i=b;return w|0}if((R6((c[3530300]|0)+4194305|0,23,2)|0)!=0){w=1;i=b;return w|0}v=0;r=c[3530300]|0;while(1){y=a[r]|0;z=r+1|0;a[r]=a[z]|0;a[z]=y;y=v+1|0;if((y|0)<2621440){v=y;r=r+2|0}else{break}}r=c[3529736]|0;if((c[3542200]|0)==0){w=1;i=b;return w|0}v=f+108|0;c[v>>2]=0;y=f+100|0;c[y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,24)|0;do{if((c[v>>2]|0)!=0){z=c[y>>2]|0;c[g>>2]=9534384;x=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[x&16383](g,24,0)|0;if((z|0)<1){w=1;i=b;return w|0}if((gzL(r,0,24)|0)==0){break}else{w=1}i=b;return w|0}}while(0);r=(c[3529692]|0)+262144|0;if((c[3542200]|0)==0){w=1;i=b;return w|0}y=d+108|0;c[y>>2]=0;v=d+100|0;c[v>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](d,25)|0;do{if((c[y>>2]|0)!=0){z=c[v>>2]|0;c[e>>2]=9534384;x=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[x&16383](e,25,0)|0;if((z|0)<1){w=1;i=b;return w|0}if((gzL(r,0,25)|0)==0){break}else{w=1}i=b;return w|0}}while(0);r=c[3530734]|0;aE_(r,r,131072,1);r=c[3530498]|0;aE_(r,r,524288,0);r=c[3530366]|0;aE_(r,r,1048576,0);aE$(c[3530300]|0,5242880);aE1(0,0,1);r=c[3530498]|0;v=c[3530366]|0;c[2383440]=c[3530734];c[2383441]=r;c[2383442]=v;c[2383436]=4095;c[2383437]=4095;c[2383438]=8191;a[690376]=1;c[2429668]=512;c[2429669]=1280;c[2429438]=1670;c[2429439]=1670;fxU(0,425984);if((c[2394]|0)==0){A=c[2112932]|0}else{c[2394]=0;v=c[3532596]|0;c[2112932]=v;r=c[3532592]|0;if((r|0)!=0){gGC(9104152,r|0,280)|0}c[2113054]=c[2113060];A=v}v=c[2388064]|0;r=A|0;y=0;while(1){z=v+y|0;c[r>>2]=z;c[r+131072>>2]=z;z=y+1024|0;if(z>>>0>1048575){break}else{r=r+4|0;y=z}}y=c[2383430]|0;c[A+5184>>2]=y;c[A+70720>>2]=y;c[A+136256>>2]=y;r=y+1024|0;c[A+5188>>2]=r;c[A+70724>>2]=r;c[A+136260>>2]=r;r=y+2048|0;c[A+5192>>2]=r;c[A+70728>>2]=r;c[A+136264>>2]=r;r=y+3072|0;c[A+5196>>2]=r;c[A+70732>>2]=r;c[A+136268>>2]=r;r=c[2383431]|0;c[A+5216>>2]=r;c[A+70752>>2]=r;c[A+136288>>2]=r;y=r+1024|0;c[A+5220>>2]=y;c[A+70756>>2]=y;c[A+136292>>2]=y;y=r+2048|0;c[A+5224>>2]=y;c[A+70760>>2]=y;c[A+136296>>2]=y;y=r+3072|0;c[A+5228>>2]=y;c[A+70764>>2]=y;c[A+136300>>2]=y;y=c[2383428]|0;c[A+5312>>2]=y;c[A+70848>>2]=y;c[A+136384>>2]=y;r=y+1024|0;c[A+5316>>2]=r;c[A+70852>>2]=r;c[A+136388>>2]=r;r=c[2383426]|0;c[A+5344>>2]=r;c[A+70880>>2]=r;c[A+136416>>2]=r;y=r+1024|0;c[A+5348>>2]=y;c[A+70884>>2]=y;c[A+136420>>2]=y;y=c[2383432]|0;c[A+5440>>2]=y;c[A+70976>>2]=y;c[A+136512>>2]=y;r=y+1024|0;c[A+5444>>2]=r;c[A+70980>>2]=r;c[A+136516>>2]=r;r=y+2048|0;c[A+5448>>2]=r;c[A+70984>>2]=r;c[A+136520>>2]=r;r=y+3072|0;c[A+5452>>2]=r;c[A+70988>>2]=r;c[A+136524>>2]=r;r=c[2383433]|0;c[A+5472>>2]=r;c[A+71008>>2]=r;c[A+136544>>2]=r;y=r+1024|0;c[A+5476>>2]=y;c[A+71012>>2]=y;c[A+136548>>2]=y;y=r+2048|0;c[A+5480>>2]=y;c[A+71016>>2]=y;c[A+136552>>2]=y;y=r+3072|0;c[A+5484>>2]=y;c[A+71020>>2]=y;c[A+136556>>2]=y;y=c[2383424]|0;c[A+5568>>2]=y;c[A+71104>>2]=y;c[A+136640>>2]=y;r=y+1024|0;c[A+5572>>2]=r;c[A+71108>>2]=r;c[A+136644>>2]=r;r=c[2383422]|0;c[A+5600>>2]=r;c[A+71136>>2]=r;c[A+136672>>2]=r;y=r+1024|0;c[A+5604>>2]=y;c[A+71140>>2]=y;c[A+136676>>2]=y;y=c[2387088]|0;c[A+6272>>2]=y;c[A+71808>>2]=y;c[A+137344>>2]=y;r=y+1024|0;c[A+6276>>2]=r;c[A+71812>>2]=r;c[A+137348>>2]=r;r=y+2048|0;c[A+6280>>2]=r;c[A+71816>>2]=r;c[A+137352>>2]=r;r=y+3072|0;c[A+6284>>2]=r;c[A+71820>>2]=r;c[A+137356>>2]=r;r=y+4096|0;c[A+6288>>2]=r;c[A+71824>>2]=r;c[A+137360>>2]=r;r=y+5120|0;c[A+6292>>2]=r;c[A+71828>>2]=r;c[A+137364>>2]=r;r=y+6144|0;c[A+6296>>2]=r;c[A+71832>>2]=r;c[A+137368>>2]=r;r=y+7168|0;c[A+6300>>2]=r;c[A+71836>>2]=r;c[A+137372>>2]=r;r=c[2388194]|0;c[A+6464>>2]=r;c[A+72e3>>2]=r;c[A+137536>>2]=r;y=r+1024|0;c[A+6468>>2]=y;c[A+72004>>2]=y;c[A+137540>>2]=y;y=r+2048|0;c[A+6472>>2]=y;c[A+72008>>2]=y;c[A+137544>>2]=y;y=r+3072|0;c[A+6476>>2]=y;c[A+72012>>2]=y;c[A+137548>>2]=y;y=r+4096|0;c[A+6480>>2]=y;c[A+72016>>2]=y;c[A+137552>>2]=y;y=r+5120|0;c[A+6484>>2]=y;c[A+72020>>2]=y;c[A+137556>>2]=y;y=r+6144|0;c[A+6488>>2]=y;c[A+72024>>2]=y;c[A+137560>>2]=y;y=r+7168|0;c[A+6492>>2]=y;c[A+72028>>2]=y;c[A+137564>>2]=y;y=r+8192|0;c[A+6496>>2]=y;c[A+72032>>2]=y;c[A+137568>>2]=y;y=r+9216|0;c[A+6500>>2]=y;c[A+72036>>2]=y;c[A+137572>>2]=y;y=r+10240|0;c[A+6504>>2]=y;c[A+72040>>2]=y;c[A+137576>>2]=y;y=r+11264|0;c[A+6508>>2]=y;c[A+72044>>2]=y;c[A+137580>>2]=y;y=r+12288|0;c[A+6512>>2]=y;c[A+72048>>2]=y;c[A+137584>>2]=y;y=r+13312|0;c[A+6516>>2]=y;c[A+72052>>2]=y;c[A+137588>>2]=y;y=r+14336|0;c[A+6520>>2]=y;c[A+72056>>2]=y;c[A+137592>>2]=y;y=r+15360|0;c[A+6524>>2]=y;c[A+72060>>2]=y;c[A+137596>>2]=y;y=c[2386368]|0;c[A+7104>>2]=y;c[A+72640>>2]=y;c[A+138176>>2]=y;r=y+1024|0;c[A+7108>>2]=r;c[A+72644>>2]=r;c[A+138180>>2]=r;c[A+196728>>2]=796;c[A+196648>>2]=562;c[A+196688>>2]=3406;c[A+196608>>2]=368;r=c[3532592]|0;if((r|0)!=0){gGC(r|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;aE8(c[2387764]|0,c[2387786]|0,8055e3,1,1894,.45,1006875,.75,2013750,.6);h[745419]=.6;a[3203368]=1;h[745418]=.6;a[3203360]=1;h[745417]=.6;a[3203352]=1;h[745416]=.6;a[3203344]=1;r=c[642608+(c[2436]<<2)>>2]|0;y=c[r+128>>2]|0;if((c[r+52>>2]&4|0)==0){c[2113068]=y;v=c[r+132>>2]|0;c[2113070]=v;c[2443814]=y;c[2440436]=v;B=y;C=v}else{c[2113070]=y;v=c[r+132>>2]|0;c[2113068]=v;c[2440436]=y;c[2443814]=v;B=v;C=y}y=ag(B<<1,C)|0;v=gGq(y)|0;c[2112926]=v;if((v|0)!=0){gGz(v|0,0,y|0)}aNk();w=0;i=b;return w|0}}while(0);c[2414836]=0;w=1;i=b;return w|0}function aM$(){var d=0,f=0,g=0,h=0,i=0,j=0;d=c[3529874]|0;f=c[2387088]|0;g=(c[642608+(c[2436]<<2)>>2]|0)+124|0;if((c[g>>2]<<1|0)>0){h=0;do{i=e[f+((h|1)<<1)>>1]|0;c[d+(((h|0)/2|0)<<2)>>2]=i<<8&63488|(e[f+(h<<1)>>1]|0)>>>3&31|i>>>8<<3&2016;h=h+2|0;}while((h|0)<(c[g>>2]<<1|0))}a[9547008]=0;aE3();aE5();g=ag(c[2113070]|0,c[2113068]|0)|0;h=c[2112926]|0;if((g|0)>0){f=0;while(1){b[h+(f<<1)>>1]=0;d=f+1|0;if((d|0)<(g|0)){f=d}else{j=h;break}}}else{j=h}gGz(c[2383420]|0,0,131072);gGz(c[2383410]|0,0,131072);aE0(3,j,65537);aE0(2,j,2);aE0(1,j,4);aNh();aE0(0,j,0);R8(c[3529874]|0);return 0}function aM0(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>26){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2889740+(b*112|0)>>2];c[a+104>>2]=c[2889744+(b*112|0)>>2];c[a+108>>2]=c[2889748+(b*112|0)>>2];d=0;return d|0}function aM1(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<27&(d|0)==0)){e=1;return e|0}c[a>>2]=2889640+(b*112|0);e=0;return e|0}function aM2(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>41){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5436072+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aM3(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>26){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2892764+(b*112|0)>>2];c[a+104>>2]=c[2892768+(b*112|0)>>2];c[a+108>>2]=c[2892772+(b*112|0)>>2];d=0;return d|0}function aM4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<27&(d|0)==0)){e=1;return e|0}c[a>>2]=2892664+(b*112|0);e=0;return e|0}function aM5(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>26){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2886716+(b*112|0)>>2];c[a+104>>2]=c[2886720+(b*112|0)>>2];c[a+108>>2]=c[2886724+(b*112|0)>>2];d=0;return d|0}function aM6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<27&(d|0)==0)){e=1;return e|0}c[a>>2]=2886616+(b*112|0);e=0;return e|0}function aM7(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>24){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2377268+(b*112|0)>>2];c[a+104>>2]=c[2377272+(b*112|0)>>2];c[a+108>>2]=c[2377276+(b*112|0)>>2];d=0;return d|0}function aM8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<25&(d|0)==0)){e=1;return e|0}c[a>>2]=2377168+(b*112|0);e=0;return e|0}function aM9(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1204552+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aNa(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>65){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3551016+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aNb(){var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;b=i;i=i+960|0;d=b|0;e=b+112|0;f=b+120|0;g=b+232|0;j=b+240|0;k=b+352|0;l=b+360|0;m=b+472|0;n=b+480|0;o=b+592|0;p=b+600|0;q=b+712|0;r=b+720|0;s=b+832|0;t=b+840|0;u=b+952|0;c[2424]=5800;c[2414836]=0;c[2388064]=0;c[2386024]=1048576;c[2387764]=1048576;c[3530734]=1114112;c[3530498]=3211264;c[3530366]=5308416;c[3530300]=8454144;c[3530284]=18939904;c[3541206]=19988480;c[3529736]=19988480;c[3529692]=21037056;c[3529874]=21823488;c[2414538]=21831680;c[2388194]=21831680;c[2387786]=21864448;c[2386368]=21872640;c[2386546]=21874688;c[3529622]=21876736;c[3529670]=21878784;c[2387088]=21880832;c[2383414]=21889024;c[2387034]=21889024;c[2386174]=21891072;c[3528204]=21893120;c[3528638]=21893121;c[2411436]=21893122;c[3527020]=21893122;v=(a[9688]|0?21895258:21893122)|0;c[2413976]=v;w=v;v=0;while(1){if((v|0)>=1024){break}x=9638528+(v<<2)|0;if((c[x>>2]|0)==0){y=36642;break}else{v=v+1|0}}do{if((y|0)==36642){v=gGq(w)|0;c[x>>2]=v;if((v|0)==0){break}gGz(v|0,0,w|0);c[2414836]=v;gGz(v|0,0,w|0);c[2388064]=v;z=v+1048576|0;c[2386024]=z;c[2387764]=z;c[3530734]=v+1114112;c[3530498]=v+3211264;c[3530366]=v+5308416;c[3530300]=v+8454144;c[3530284]=v+18939904;z=v+19988480|0;c[3541206]=z;c[3529736]=z;c[3529692]=v+21037056;c[3529874]=v+21823488;z=v+21831680|0;c[2414538]=z;c[2388194]=z;c[2387786]=v+21864448;c[2386368]=v+21872640;c[2386546]=v+21874688;c[3529622]=v+21876736;c[3529670]=v+21878784;c[2387088]=v+21880832;z=v+21889024|0;c[2383414]=z;c[2387034]=z;c[2386174]=v+21891072;c[3528204]=v+21893120;c[3528638]=v+21893121;z=v+21893122|0;c[2411436]=z;c[3527020]=z;c[2413976]=v+(a[9688]|0?21895258:21893122);if((R6(v+1|0,0,2)|0)!=0){A=1;i=b;return A|0}if((R6(c[2388064]|0,1,2)|0)!=0){A=1;i=b;return A|0}if((R6((c[2388064]|0)+262145|0,2,2)|0)!=0){A=1;i=b;return A|0}if((R6((c[2388064]|0)+262144|0,3,2)|0)!=0){A=1;i=b;return A|0}if((R6((c[2388064]|0)+524289|0,4,2)|0)!=0){A=1;i=b;return A|0}if((R6((c[2388064]|0)+524288|0,5,2)|0)!=0){A=1;i=b;return A|0}if((R6((c[2388064]|0)+786433|0,6,2)|0)!=0){A=1;i=b;return A|0}if((R6((c[2388064]|0)+786432|0,7,2)|0)!=0){A=1;i=b;return A|0}v=c[2387764]|0;if((c[3542200]|0)==0){A=1;i=b;return A|0}z=t+108|0;c[z>>2]=0;B=t+100|0;c[B>>2]=0;C=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[C&16383](t,8)|0;do{if((c[z>>2]|0)!=0){C=c[B>>2]|0;c[u>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](u,8,0)|0;if((C|0)<1){A=1;i=b;return A|0}if((gzL(v,0,8)|0)==0){break}else{A=1}i=b;return A|0}}while(0);if((R6((c[3530734]|0)+1|0,9,2)|0)!=0){A=1;i=b;return A|0}if((R6(c[3530734]|0,10,2)|0)!=0){A=1;i=b;return A|0}v=c[3530498]|0;if((c[3542200]|0)==0){A=1;i=b;return A|0}B=r+108|0;c[B>>2]=0;z=r+100|0;c[z>>2]=0;C=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[C&16383](r,11)|0;do{if((c[B>>2]|0)!=0){C=c[z>>2]|0;c[s>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](s,11,0)|0;if((C|0)<1){A=1;i=b;return A|0}if((gzL(v,0,11)|0)==0){break}else{A=1}i=b;return A|0}}while(0);v=(c[3530498]|0)+524288|0;if((c[3542200]|0)==0){A=1;i=b;return A|0}z=p+108|0;c[z>>2]=0;B=p+100|0;c[B>>2]=0;C=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[C&16383](p,12)|0;do{if((c[z>>2]|0)!=0){C=c[B>>2]|0;c[q>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](q,12,0)|0;if((C|0)<1){A=1;i=b;return A|0}if((gzL(v,0,12)|0)==0){break}else{A=1}i=b;return A|0}}while(0);v=c[3530498]|0;B=0;do{z=v+(B+262144)|0;C=a[z]|0;D=v+(B+524288)|0;a[z]=a[D]|0;a[D]=C;B=B+1|0;}while((B|0)<262144);B=c[3530300]|0;if((c[3542200]|0)==0){A=1;i=b;return A|0}v=n+108|0;c[v>>2]=0;C=n+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,13)|0;do{if((c[v>>2]|0)!=0){D=c[C>>2]|0;c[o>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](o,13,0)|0;if((D|0)<1){A=1;i=b;return A|0}if((gzL(B,0,13)|0)==0){break}else{A=1}i=b;return A|0}}while(0);B=c[3530366]|0;C=c[3530300]|0;gGC(B|0,C|0,262144)|0;v=B+786432|0;B=C+262144|0;gGC(v|0,B|0,262144)|0;if((c[3542200]|0)==0){A=1;i=b;return A|0}B=l+108|0;c[B>>2]=0;v=l+100|0;c[v>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,14)|0;do{if((c[B>>2]|0)!=0){D=c[v>>2]|0;c[m>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](m,14,0)|0;if((D|0)<1){A=1;i=b;return A|0}if((gzL(C,0,14)|0)==0){break}else{A=1}i=b;return A|0}}while(0);C=c[3530366]|0;v=C+262144|0;B=c[3530300]|0;gGC(v|0,B|0,262144)|0;v=C+1048576|0;C=B+262144|0;gGC(v|0,C|0,262144)|0;if((c[3542200]|0)==0){A=1;i=b;return A|0}C=j+108|0;c[C>>2]=0;v=j+100|0;c[v>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,15)|0;do{if((c[C>>2]|0)!=0){D=c[v>>2]|0;c[k>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](k,15,0)|0;if((D|0)<1){A=1;i=b;return A|0}if((gzL(B,0,15)|0)==0){break}else{A=1}i=b;return A|0}}while(0);B=c[3530366]|0;v=B+524288|0;C=c[3530300]|0;gGC(v|0,C|0,262144)|0;v=B+1310720|0;B=C+262144|0;gGC(v|0,B|0,262144)|0;if((R6(C,16,2)|0)!=0){A=1;i=b;return A|0}if((R6((c[3530300]|0)+1|0,17,2)|0)!=0){A=1;i=b;return A|0}if((R6((c[3530300]|0)+1048576|0,18,2)|0)!=0){A=1;i=b;return A|0}if((R6((c[3530300]|0)+1048577|0,19,2)|0)!=0){A=1;i=b;return A|0}if((R6((c[3530300]|0)+2097152|0,20,2)|0)!=0){A=1;i=b;return A|0}if((R6((c[3530300]|0)+2097153|0,21,2)|0)!=0){A=1;i=b;return A|0}C=0;B=c[3530300]|0;while(1){v=a[B]|0;D=B+1|0;a[B]=a[D]|0;a[D]=v;v=C+1|0;if((v|0)<1572864){C=v;B=B+2|0}else{break}}B=c[3529736]|0;if((c[3542200]|0)==0){A=1;i=b;return A|0}C=f+108|0;c[C>>2]=0;v=f+100|0;c[v>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,22)|0;do{if((c[C>>2]|0)!=0){D=c[v>>2]|0;c[g>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](g,22,0)|0;if((D|0)<1){A=1;i=b;return A|0}if((gzL(B,0,22)|0)==0){break}else{A=1}i=b;return A|0}}while(0);B=(c[3529692]|0)+262144|0;if((c[3542200]|0)==0){A=1;i=b;return A|0}v=d+108|0;c[v>>2]=0;C=d+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](d,23)|0;do{if((c[v>>2]|0)!=0){D=c[C>>2]|0;c[e>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](e,23,0)|0;if((D|0)<1){A=1;i=b;return A|0}if((gzL(B,0,23)|0)==0){break}else{A=1}i=b;return A|0}}while(0);B=c[3530734]|0;aE_(B,B,131072,1);B=c[3530498]|0;aE_(B,B,1048576,0);aE_(c[3530366]|0,c[3530284]|0,1572864,2);B=c[3530366]|0;aE_(B,B,1572864,0);aE$(c[3530300]|0,3145728);aE1(0,0,1);B=c[3530498]|0;C=c[3530366]|0;c[2383440]=c[3530734];c[2383441]=B;c[2383442]=C;c[2383436]=4095;c[2383437]=8191;c[2383438]=16383;a[690376]=1;c[2429668]=512;c[2429669]=1280;c[2429437]=2242;c[2429438]=2242;c[2429439]=2242;fxU(0,425984);if((c[2394]|0)==0){E=c[2112932]|0}else{c[2394]=0;C=c[3532596]|0;c[2112932]=C;B=c[3532592]|0;if((B|0)!=0){gGC(9104152,B|0,280)|0}c[2113054]=c[2113060];E=C}C=c[2388064]|0;B=E|0;v=0;while(1){D=C+v|0;c[B>>2]=D;c[B+131072>>2]=D;D=v+1024|0;if(D>>>0>1048575){break}else{B=B+4|0;v=D}}v=c[2383430]|0;c[E+5184>>2]=v;c[E+70720>>2]=v;c[E+136256>>2]=v;B=v+1024|0;c[E+5188>>2]=B;c[E+70724>>2]=B;c[E+136260>>2]=B;B=v+2048|0;c[E+5192>>2]=B;c[E+70728>>2]=B;c[E+136264>>2]=B;B=v+3072|0;c[E+5196>>2]=B;c[E+70732>>2]=B;c[E+136268>>2]=B;B=c[2383431]|0;c[E+5216>>2]=B;c[E+70752>>2]=B;c[E+136288>>2]=B;v=B+1024|0;c[E+5220>>2]=v;c[E+70756>>2]=v;c[E+136292>>2]=v;v=B+2048|0;c[E+5224>>2]=v;c[E+70760>>2]=v;c[E+136296>>2]=v;v=B+3072|0;c[E+5228>>2]=v;c[E+70764>>2]=v;c[E+136300>>2]=v;v=c[2383428]|0;c[E+5312>>2]=v;c[E+70848>>2]=v;c[E+136384>>2]=v;B=v+1024|0;c[E+5316>>2]=B;c[E+70852>>2]=B;c[E+136388>>2]=B;B=c[2383426]|0;c[E+5344>>2]=B;c[E+70880>>2]=B;c[E+136416>>2]=B;v=B+1024|0;c[E+5348>>2]=v;c[E+70884>>2]=v;c[E+136420>>2]=v;v=c[2383432]|0;c[E+5440>>2]=v;c[E+70976>>2]=v;c[E+136512>>2]=v;B=v+1024|0;c[E+5444>>2]=B;c[E+70980>>2]=B;c[E+136516>>2]=B;B=v+2048|0;c[E+5448>>2]=B;c[E+70984>>2]=B;c[E+136520>>2]=B;B=v+3072|0;c[E+5452>>2]=B;c[E+70988>>2]=B;c[E+136524>>2]=B;B=c[2383433]|0;c[E+5472>>2]=B;c[E+71008>>2]=B;c[E+136544>>2]=B;v=B+1024|0;c[E+5476>>2]=v;c[E+71012>>2]=v;c[E+136548>>2]=v;v=B+2048|0;c[E+5480>>2]=v;c[E+71016>>2]=v;c[E+136552>>2]=v;v=B+3072|0;c[E+5484>>2]=v;c[E+71020>>2]=v;c[E+136556>>2]=v;v=c[2383424]|0;c[E+5568>>2]=v;c[E+71104>>2]=v;c[E+136640>>2]=v;B=v+1024|0;c[E+5572>>2]=B;c[E+71108>>2]=B;c[E+136644>>2]=B;B=c[2383422]|0;c[E+5600>>2]=B;c[E+71136>>2]=B;c[E+136672>>2]=B;v=B+1024|0;c[E+5604>>2]=v;c[E+71140>>2]=v;c[E+136676>>2]=v;v=c[2386368]|0;c[E+6144>>2]=v;c[E+71680>>2]=v;c[E+137216>>2]=v;B=v+1024|0;c[E+6148>>2]=B;c[E+71684>>2]=B;c[E+137220>>2]=B;B=c[2387088]|0;c[E+6784>>2]=B;c[E+72320>>2]=B;c[E+137856>>2]=B;v=B+1024|0;c[E+6788>>2]=v;c[E+72324>>2]=v;c[E+137860>>2]=v;v=B+2048|0;c[E+6792>>2]=v;c[E+72328>>2]=v;c[E+137864>>2]=v;v=B+3072|0;c[E+6796>>2]=v;c[E+72332>>2]=v;c[E+137868>>2]=v;v=B+4096|0;c[E+6800>>2]=v;c[E+72336>>2]=v;c[E+137872>>2]=v;v=B+5120|0;c[E+6804>>2]=v;c[E+72340>>2]=v;c[E+137876>>2]=v;v=B+6144|0;c[E+6808>>2]=v;c[E+72344>>2]=v;c[E+137880>>2]=v;v=B+7168|0;c[E+6812>>2]=v;c[E+72348>>2]=v;c[E+137884>>2]=v;v=c[2388194]|0;c[E+7040>>2]=v;c[E+72576>>2]=v;c[E+138112>>2]=v;B=v+1024|0;c[E+7044>>2]=B;c[E+72580>>2]=B;c[E+138116>>2]=B;B=v+2048|0;c[E+7048>>2]=B;c[E+72584>>2]=B;c[E+138120>>2]=B;B=v+3072|0;c[E+7052>>2]=B;c[E+72588>>2]=B;c[E+138124>>2]=B;B=v+4096|0;c[E+7056>>2]=B;c[E+72592>>2]=B;c[E+138128>>2]=B;B=v+5120|0;c[E+7060>>2]=B;c[E+72596>>2]=B;c[E+138132>>2]=B;B=v+6144|0;c[E+7064>>2]=B;c[E+72600>>2]=B;c[E+138136>>2]=B;B=v+7168|0;c[E+7068>>2]=B;c[E+72604>>2]=B;c[E+138140>>2]=B;B=v+8192|0;c[E+7072>>2]=B;c[E+72608>>2]=B;c[E+138144>>2]=B;B=v+9216|0;c[E+7076>>2]=B;c[E+72612>>2]=B;c[E+138148>>2]=B;B=v+10240|0;c[E+7080>>2]=B;c[E+72616>>2]=B;c[E+138152>>2]=B;B=v+11264|0;c[E+7084>>2]=B;c[E+72620>>2]=B;c[E+138156>>2]=B;B=v+12288|0;c[E+7088>>2]=B;c[E+72624>>2]=B;c[E+138160>>2]=B;B=v+13312|0;c[E+7092>>2]=B;c[E+72628>>2]=B;c[E+138164>>2]=B;B=v+14336|0;c[E+7096>>2]=B;c[E+72632>>2]=B;c[E+138168>>2]=B;B=v+15360|0;c[E+7100>>2]=B;c[E+72636>>2]=B;c[E+138172>>2]=B;c[E+196728>>2]=544;c[E+196648>>2]=2742;c[E+196688>>2]=3170;c[E+196608>>2]=1686;B=c[3532592]|0;if((B|0)!=0){gGC(B|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;aE8(c[2387764]|0,c[2387786]|0,8055e3,1,1894,.45,1006875,.75,2013750,.6);h[745419]=.6;a[3203368]=1;h[745418]=.6;a[3203360]=1;h[745417]=.6;a[3203352]=1;h[745416]=.6;a[3203344]=1;h[745421]=.45;c[2436794]=1;h[745420]=.45;c[2436792]=2;B=c[642608+(c[2436]<<2)>>2]|0;v=c[B+128>>2]|0;if((c[B+52>>2]&4|0)==0){c[2113068]=v;C=c[B+132>>2]|0;c[2113070]=C;c[2443814]=v;c[2440436]=C;F=v;G=C}else{c[2113070]=v;C=c[B+132>>2]|0;c[2113068]=C;c[2440436]=v;c[2443814]=C;F=C;G=v}v=ag(F<<1,G)|0;C=gGq(v)|0;c[2112926]=C;if((C|0)!=0){gGz(C|0,0,v|0)}aNk();A=0;i=b;return A|0}}while(0);c[2414836]=0;A=1;i=b;return A|0}function aNc(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[3529874]|0;f=c[2387088]|0;g=(c[642608+(c[2436]<<2)>>2]|0)+124|0;if((c[g>>2]<<1|0)>0){h=0;do{i=e[f+((h|1)<<1)>>1]|0;c[d+(((h|0)/2|0)<<2)>>2]=i<<8&63488|(e[f+(h<<1)>>1]|0)>>>3&31|i>>>8<<3&2016;h=h+2|0;}while((h|0)<(c[g>>2]<<1|0))}a[9547008]=0;aE3();aE5();g=ag(c[2113070]|0,c[2113068]|0)|0;if((g|0)>0){h=c[2112926]|0;f=0;do{b[h+(f<<1)>>1]=512;f=f+1|0;}while((f|0)<(g|0))}gGz(c[2383420]|0,0,131072);gGz(c[2383410]|0,0,131072);g=b[4766836]|0;if((g&4)==0){c[2429664]=15;c[2429665]=15;c[2383442]=c[3530366];c[2383438]=16383;aE0(3,c[2112926]|0,65537);j=0;k=b[4766836]|0}else{c[2429664]=0;c[2429665]=0;c[2383442]=c[3530284];c[2383438]=4095;j=1048576;k=g}g=c[2112926]|0;if((k&8)==0){aE0(2,g,j|2);aE0(1,g,4);aNh();aE0(0,g,0);l=c[3529874]|0;R8(l);return 0}else{aE0(1,g,2);aE0(2,g,j|4);aNh();aE0(0,g,0);l=c[3529874]|0;R8(l);return 0}return 0}function aNd(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>24){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1420108+(b*112|0)>>2];c[a+104>>2]=c[1420112+(b*112|0)>>2];c[a+108>>2]=c[1420116+(b*112|0)>>2];d=0;return d|0}function aNe(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<25&(d|0)==0)){e=1;return e|0}c[a>>2]=1420008+(b*112|0);e=0;return e|0}function aNf(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>24){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1422908+(b*112|0)>>2];c[a+104>>2]=c[1422912+(b*112|0)>>2];c[a+108>>2]=c[1422916+(b*112|0)>>2];d=0;return d|0}function aNg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<25&(d|0)==0)){e=1;return e|0}c[a>>2]=1422808+(b*112|0);e=0;return e|0}function aNh(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;d=c[2386546]|0;f=c[3528638]|0;g=c[2112926]|0;h=c[3530300]|0;i=(c[2113222]&1|0)==0;j=1020;do{k=b[d+((j|1)<<1)>>1]|0;l=k&65535;do{if(k<<16>>16!=0){m=e[d+((j|2)<<1)>>1]|0;n=m&49152;if((n|0)==32768){o=252}else if((n|0)==49152){o=252}else if((n|0)==16384){o=240}else{o=0}n=e[d+(j<<1)>>1]|0;if(!((n&4096|0)==0|i)){break}p=n&8192;q=n&16384;r=1<<(n>>>9&3);s=r-1|0;t=m&511;u=n&511;v=c[2113068]|0;w=u>>>0>255?n|-512:u;u=240-((t|0)<(v|0)?t:m|-512)|0;t=((q|0)!=0?0:s)+(l&-r)|0;n=(q>>>13^2)-1|0;if((a[f]|0)==0){x=-16;y=q;z=p;A=u;B=240-w|0}else{x=16;y=q>>>14^1;z=p>>>13^1;A=v-16-u|0;B=w}if((r|0)<=0){break}r=(m>>>9<<4&496)+768|0;m=s;while(1){s=t-(ag(m,n)|0)|0;aEY(g,h,s,r,A,(ag(m,x)|0)+B|0,z,y,o,-1);if((m|0)>0){m=m-1|0}else{break}}}}while(0);j=j-4|0;}while((j|0)>-1);return}function aNi(a){a=a|0;return a<<8&12288|0}function aNj(a,b){a=a|0;b=b|0;var d=0;a=b&1;c[3530234]=a;b=c[3529692]|0;d=b+((a<<18)+262144)|0;gGC(b|0,d|0,262144)|0;return}function aNk(){var d=0,e=0,f=0,g=0,h=0;d=c[2414538]|0;gGz(d|0,0,(c[2411436]|0)-d|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;if(a[668920]|0){d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;h=c[2417276]|0;c[3541536]=h;c[1836236]=0;gGz(9706056,0,76);if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=h;c[1836236]=-1;c[2113156]=0;a[9628264]=0;c[2407033]=0;h=c[3541206]|0;c[3541190]=h;c[3541198]=h;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=h+256;c[3541199]=h+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=h+512;c[3541200]=h+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=h+768;c[3541201]=h+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2113157]=0;a[9628420]=0;c[2407072]=0;g=h+1048576|0;c[3541194]=g;c[3541202]=g;gGz(c[2430122]|0,0,16384);c[2407080]=4;c[3541195]=h+1048832;c[3541203]=h+1114112;gGz(c[2430123]|0,0,16384);c[2407088]=4;c[3541196]=h+1049088;c[3541204]=h+1179648;gGz(c[2430124]|0,0,16384);c[2407096]=4;c[3541197]=h+1049344;c[3541205]=h+1245184;gGz(c[2430125]|0,0,16384);c[2407104]=4;mx(0)}else{aE7()}c[3530234]=0;h=c[3529692]|0;g=h+262144|0;gGC(h|0,g|0,262144)|0;gGz(c[2383428]|0,0,4096);gGz(c[2383426]|0,0,4096);g=c[2383424]|0;if((g|0)!=0){gGz(g|0,0,4096);gGz(c[2383422]|0,0,4096)}gGz(c[2383434]|0,0,16);gGz(c[2383435]|0,0,16);gGz(c[2383430]|0,0,8192);gGz(c[2383431]|0,0,8192);g=c[2383432]|0;if((g|0)==0){b[4766836]=0;c[2426968]=0;c[3528794]=0;c[1765522]=65535;c[2429656]=0;c[2427042]=0;c[2429386]=0;c[2429384]=0;c[2429382]=0;c[2388528]=0;c[2405090]=0;c[2385602]=-1;return}gGz(g|0,0,8192);gGz(c[2383433]|0,0,8192);b[4766836]=0;c[2426968]=0;c[3528794]=0;c[1765522]=65535;c[2429656]=0;c[2427042]=0;c[2429386]=0;c[2429384]=0;c[2429382]=0;c[2388528]=0;c[2405090]=0;c[2385602]=-1;return}function aNl(a){a=a|0;return((a&240|0)==0?4096:0)|0}function aNm(d,f,g,h){d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;i=d;d=(h|0)==4;h=d?4:-4;j=d?1024:-4;k=d?15:31;l=c[3528638]|0;m=c[2112926]|0;n=(c[2113222]&1|0)==0;o=d?0:1020;do{d=b[i+((o|3)<<1)>>1]|0;p=d&65535;do{if(d<<16>>16!=0){q=e[i+((o|1)<<1)>>1]|0;r=e[i+((o|2)<<1)>>1]|0;s=r>>>12;t=r>>>8&15;u=e[i+(o<<1)>>1]|0;if(!((u&8192|0)==0|n)){break}v=r&k;r=u&16384;w=u&32768;do{if((a[l]|0)==0){x=304-((q&256|0)==0?q&511:q|-256)|0;y=240-((u&256|0)==0?u&511:u|-256)|0;z=(x|0)>431?x-512|0:x;x=(y|0)>383?y-512|0:y;if((r|0)==0){A=16;B=z-(t<<4)|0}else{A=-16;B=z+16|0}if((w|0)==0){C=16;D=A;E=x-(s<<4)|0;F=B;G=0;H=r;break}else{C=-16;D=A;E=x+16|0;F=B;G=w;H=r;break}}else{x=r>>>14;z=x^1;y=u>>>15;I=q&511;J=u&511;K=J>>>0>384?u|-512:J;J=(x|0)==1;x=J?16:-16;L=(J?-16:t<<4)+(I>>>0>384?q|-512:I)|0;if((y|0)==1){C=16;D=x;E=K-16|0;F=L;G=0;H=z;break}else{C=-16;D=x;E=K+(s<<4)|0;F=L;G=y^1;H=z;break}}}while(0);if((t|0)==0){break}q=(v<<4)+g|0;if((s|0)==0){break}else{M=0}do{u=(ag(M,s)|0)+p|0;r=(ag(t-M|0,D)|0)+F|0;w=0;do{aEY(m,f,u+w|0,q,r,(ag(s-w|0,C)|0)+E|0,H,G,0,-1);w=w+1|0;}while((w|0)<(s|0));M=M+1|0;}while((M|0)<(t|0))}}while(0);o=o+h|0;}while((o|0)!=(j|0));return}function aNn(a){a=a|0;return a>>>4<<12&12288|0}function aNo(a){a=a|0;return a>>>5<<14&16384|0}function aNp(b){b=b|0;var c=0;c=(b|0)!=0|0;if((c|0)==0){a[9706117]=0;return}else if((c|0)==1){a[9706117]=1;return}else{return}}function aNq(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=c[2113222]|0;if((d-(c[3541476]|0)|0)>45){c[3541476]=d;c[3541362]=(c[3541362]|0)+1}d=(a[14165832]|0)==0;e=(a[14165824]|0)==0;f=c[2113070]|0;g=c[2113068]|0;h=c[2112926]|0;i=0;do{j=c[9669288+(i*12|0)>>2]|0;k=j>>1;l=c[9669292+(i*12|0)>>2]|0;do{if((k|0)<128){if(((l^j>>>4)&1|0)==0){break}m=c[3541362]&3;if((m|0)==2){if((l&2|0)==0){break}}else if((m|0)==1){if((c[9669296+(i*12|0)>>2]&4|0)==0){break}}else if((m|0)==0){if((c[9669296+(i*12|0)>>2]&1|0)==0){break}}m=d?k:255-k|0;n=(e?l:255-l|0)-16|0;if(!((n|0)>-1&(f|0)>(n|0)&(m|0)>-1&(g|0)>(m|0))){break}o=(c[9669296+(i*12|0)>>2]|0)+64&65535;b[h+((ag(g,n)|0)+m<<1)>>1]=o}}while(0);i=i+1|0;}while((i|0)<252);return}function aNr(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3930492+(b*112|0)>>2];c[a+104>>2]=c[3930496+(b*112|0)>>2];c[a+108>>2]=c[3930500+(b*112|0)>>2];d=0;return d|0}function aNs(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=3930392+(b*112|0);e=0;return e|0}function aNt(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1263304+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aNu(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3931288+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aNv(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>5){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1912252+(b*112|0)>>2];c[a+104>>2]=c[1912256+(b*112|0)>>2];c[a+108>>2]=c[1912260+(b*112|0)>>2];d=0;return d|0}function aNw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<6&(d|0)==0)){e=1;return e|0}c[a>>2]=1912152+(b*112|0);e=0;return e|0}function aNx(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6040200+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aNy(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1911356+(b*112|0)>>2];c[a+104>>2]=c[1911360+(b*112|0)>>2];c[a+108>>2]=c[1911364+(b*112|0)>>2];d=0;return d|0}function aNz(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=1911256+(b*112|0);e=0;return e|0}function aNA(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1260788+(b*112|0)>>2];c[a+104>>2]=c[1260792+(b*112|0)>>2];c[a+108>>2]=c[1260796+(b*112|0)>>2];d=0;return d|0}function aNB(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=1260688+(b*112|0);e=0;return e|0}function aNC(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1910460+(b*112|0)>>2];c[a+104>>2]=c[1910464+(b*112|0)>>2];c[a+108>>2]=c[1910468+(b*112|0)>>2];d=0;return d|0}function aND(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=1910360+(b*112|0);e=0;return e|0}function aNE(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5265548+(b*112|0)>>2];c[a+104>>2]=c[5265552+(b*112|0)>>2];c[a+108>>2]=c[5265556+(b*112|0)>>2];d=0;return d|0}function aNF(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=5265448+(b*112|0);e=0;return e|0}function aNG(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6039516+(b*112|0)>>2];c[a+104>>2]=c[6039520+(b*112|0)>>2];c[a+108>>2]=c[6039524+(b*112|0)>>2];d=0;return d|0}function aNH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=6039416+(b*112|0);e=0;return e|0}function aNI(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3925764+(b*112|0)>>2];c[a+104>>2]=c[3925768+(b*112|0)>>2];c[a+108>>2]=c[3925772+(b*112|0)>>2];d=0;return d|0}function aNJ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=3925664+(b*112|0);e=0;return e|0}function aNK(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6305036+(b*112|0)>>2];c[a+104>>2]=c[6305040+(b*112|0)>>2];c[a+108>>2]=c[6305044+(b*112|0)>>2];d=0;return d|0}function aNL(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=6304936+(b*112|0);e=0;return e|0}function aNM(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6306828+(b*112|0)>>2];c[a+104>>2]=c[6306832+(b*112|0)>>2];c[a+108>>2]=c[6306836+(b*112|0)>>2];d=0;return d|0}function aNN(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=6306728+(b*112|0);e=0;return e|0}function aNO(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6305932+(b*112|0)>>2];c[a+104>>2]=c[6305936+(b*112|0)>>2];c[a+108>>2]=c[6305940+(b*112|0)>>2];d=0;return d|0}function aNP(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=6305832+(b*112|0);e=0;return e|0}function aNQ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6670060+(b*112|0)>>2];c[a+104>>2]=c[6670064+(b*112|0)>>2];c[a+108>>2]=c[6670068+(b*112|0)>>2];d=0;return d|0}function aNR(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=6669960+(b*112|0);e=0;return e|0}function aNS(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>24){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6670856+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aNT(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4262084+(b*112|0)>>2];c[a+104>>2]=c[4262088+(b*112|0)>>2];c[a+108>>2]=c[4262092+(b*112|0)>>2];d=0;return d|0}function aNU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=4261984+(b*112|0);e=0;return e|0}function aNV(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3188660+(b*112|0)>>2];c[a+104>>2]=c[3188664+(b*112|0)>>2];c[a+108>>2]=c[3188668+(b*112|0)>>2];d=0;return d|0}function aNW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=3188560+(b*112|0);e=0;return e|0}function aNX(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>24){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3189456+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aNY(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3367468+(b*112|0)>>2];c[a+104>>2]=c[3367472+(b*112|0)>>2];c[a+108>>2]=c[3367476+(b*112|0)>>2];d=0;return d|0}function aNZ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=3367368+(b*112|0);e=0;return e|0}function aN_(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3931652+(b*112|0)>>2];c[a+104>>2]=c[3931656+(b*112|0)>>2];c[a+108>>2]=c[3931660+(b*112|0)>>2];d=0;return d|0}function aN$(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=3931552+(b*112|0);e=0;return e|0}function aN0(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1261684+(b*112|0)>>2];c[a+104>>2]=c[1261688+(b*112|0)>>2];c[a+108>>2]=c[1261692+(b*112|0)>>2];d=0;return d|0}function aN1(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=1261584+(b*112|0);e=0;return e|0}function aN2(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1263040+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aN3(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1866420+(b*112|0)>>2];c[a+104>>2]=c[1866424+(b*112|0)>>2];c[a+108>>2]=c[1866428+(b*112|0)>>2];d=0;return d|0}function aN4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=1866320+(b*112|0);e=0;return e|0}function aN5(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4914788+(b*112|0)>>2];c[a+104>>2]=c[4914792+(b*112|0)>>2];c[a+108>>2]=c[4914796+(b*112|0)>>2];d=0;return d|0}function aN6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=4914688+(b*112|0);e=0;return e|0}function aN7(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5394836+(b*112|0)>>2];c[a+104>>2]=c[5394840+(b*112|0)>>2];c[a+108>>2]=c[5394844+(b*112|0)>>2];d=0;return d|0}function aN8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=5394736+(b*112|0);e=0;return e|0}function aN9(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>24){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5395632+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aOa(b){b=b|0;var c=0,d=0;c=b&65535;if((c|0)==26624){d=a[14165840]<<6&64|(a[14165873]|a[14165809])&-65;return d|0}else if((c|0)==24576){d=a[14165872]|a[14165808];return d|0}else if((c|0)==28672){d=a[14165840]<<1&4|(a[14165874]|a[14165810])&-5;return d|0}else{d=-1;return d|0}return 0}function aOb(b){b=b|0;var c=0,d=0;c=b&65535;if((c|0)==40960|(c|0)==43007){d=a[14165872]|a[14165808]}else if((c|0)==43008){d=a[14165873]|a[14165809]}else if((c|0)==45056|(c|0)==28672){d=a[14165874]|a[14165810]}else{d=-1}return d|0}function aOc(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((b+30720&65535)<256){b=e-34816|0;a[(c[3541366]|0)+b|0]=d;if(!((b|0)<64&(b&1|0)==0)){return}a[(c[3541380]|0)+(b>>1)|0]=d;return}switch(e|0){case 47104:{c[3541406]=d&255;return};case 45060:{b=d&1;c[3541360]=b;if((b|0)!=0){return}c[3541358]=-1;return};case 43008:case 43009:case 43010:case 43011:case 43012:case 43013:case 43014:case 43015:{b=e-43008|0;e=d&1;switch(b&7|0){case 3:{a[14165672]=e;if(e<<24>>24==0){return}c[3541416]=100;h[932737]=0.0;return};case 5:{do{if(e<<24>>24!=0){if((a[14165752]&1)!=0){break}a[14165512]=1;h[932735]=0.0}}while(0);a[14165752]=e;return};case 0:case 1:case 2:{c[14165720+(b<<2)>>2]=e&255;return};case 7:case 6:{e=b&1;c[3541336]=c[3541336]&~(1<<e)|(d&1)<<e;return};default:{return}}break};case 45062:{a[14165832]=d&1;return};case 45063:{a[14165824]=d&1;return};case 45057:{a[14165768]=d&1;return};default:{return}}}function aOd(c){c=c|0;var d=0,f=0;d=c&65535;do{if((d|0)==24576){f=a[14165872]|a[14165808]}else if((d|0)==26624){f=a[14165873]|a[14165809]}else if((d|0)==33282){f=(b[4853030]|0)==458?-112:-1}else if((d|0)==28672){f=a[14165874]|a[14165810]}else if((d|0)==33026){c=e[4853030]|0;if((c|0)==484){f=0;break}else if((c|0)==474){f=-128;break}else{f=-1;break}}else{f=-1}}while(0);return f|0}function aOe(b,d){b=b|0;d=d|0;var e=0,f=0,g=0.0,i=0.0,j=0.0,k=0.0,l=0.0,m=0.0,n=0.0,o=0.0;e=b&65535;if((b-20480&65535)<256){b=e-20480|0;a[(c[3541366]|0)+b|0]=d;if(!((b|0)<64&(b&1|0)==0)){return}a[(c[3541380]|0)+(b>>1)|0]=d;return}switch(e|0){case 24580:case 24581:case 24582:case 24583:{b=d&1;f=14165736+(e-24580<<2)|0;if((b|0)==(c[f>>2]|0)){return}c[f>>2]=b;b=(c[3541434]|0)==0;g=b?4030303030303031.0e-21:30303030303030305.0e-22;i=b?1.0e-12:1000001.0e-12;if((c[3541435]|0)==0){j=i;k=g+21276595744680853.0e-22}else{j=i+21276595744680853.0e-22;k=g}if((c[3541436]|0)==0){l=j;m=k+45454545454545455.0e-22}else{l=j+45454545454545455.0e-22;m=k}if((c[3541437]|0)==0){n=l;o=m+1.0e-5}else{n=l+1.0e-5;o=m}m=1.0/o;h[932738]=1.0e9/((m*2.0e6/(m+1.0/n)+1.0e5)*58788.0)*100.0;return};case 28678:{a[14165832]=d&1;return};case 30720:{c[3541406]=d&255;return};case 26624:case 26625:case 26626:case 26627:case 26628:case 26629:case 26630:case 26631:{b=e-26624|0;e=d&1;switch(b&7|0){case 5:{do{if(e<<24>>24!=0){if((a[14165752]&1)!=0){break}a[14165512]=1;h[932735]=0.0}}while(0);a[14165752]=e;return};case 0:case 1:case 2:{c[14165720+(b<<2)>>2]=e&255;return};case 3:{a[14165672]=e;if(e<<24>>24==0){return}c[3541416]=100;h[932737]=0.0;return};case 7:case 6:{e=b&1;c[3541336]=c[3541336]&~(1<<e)|(d&1)<<e;return};default:{return}}break};case 28675:{a[14165928]=d&1;return};case 28676:{e=d&1;c[3541360]=e;if((e|0)!=0){return}c[3541358]=-1;return};case 28673:{a[14165768]=d&1;return};case 28679:{a[14165824]=d&1;return};default:{return}}}function aOf(a){a=a|0;var b=0,c=0;b=a&65535;if((a-22528&65535)<2048){c=37;return c|0}switch(b|0){case 26624:case 26625:case 26626:case 26627:case 26628:case 26629:case 26630:case 26631:{c=(((d[14165809]|0)^255)-(d[14165873]|0)|0)>>>((b-26624|0)>>>0)&1;return c|0};case 24576:case 24577:case 24578:case 24579:case 24580:case 24581:case 24582:case 24583:{c=(((d[14165808]|0)^255)-(d[14165872]|0)|0)>>>((b-24576|0)>>>0)&1;return c|0};case 30727:case 30720:case 30721:case 30722:case 30723:case 30724:case 30725:case 30726:{c=(((d[14165810]|0)^255)-(d[14165874]|0)|0)>>>((b-30720|0)>>>0)&1;return c|0};default:{c=-1;return c|0}}return 0}function aOg(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((b-20480&65535)<256){b=e-20480|0;a[(c[3541366]|0)+b|0]=d;if(!((b|0)<64&(b&1|0)==0)){return}a[(c[3541380]|0)+(b>>1)|0]=d;return}switch(e|0){case 26625:{a[14165768]=d&1;return};case 26627:{a[14165928]=d&1;return};case 26631:{a[14165824]=d&1;return};case 30720:{c[3541406]=d&255;return};case 26630:{a[14165832]=d&1;return};case 26628:{e=d&1;c[3541360]=e;if((e|0)!=0){return}c[3541358]=-1;return};default:{return}}}function aOh(b){b=b|0;var c=0,d=0;c=b&65535;if((c|0)==26624){d=a[14165873]|a[14165809]}else if((c|0)==24576){d=a[14165872]|a[14165808]}else if((c|0)==28672){d=a[14165874]|a[14165810]}else{d=-1}return d|0}function aOi(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,i=0.0,j=0.0,k=0.0,l=0.0,m=0.0,n=0.0,o=0.0,p=0.0;e=b&65535;if((b-21504&65535)<1024){return}if((b-22528&65535)<256){b=e-22528|0;a[(c[3541366]|0)+b|0]=d;f=e-22656|0;if(f>>>0>=64){return}if((b&1|0)!=0){return}a[(c[3541380]|0)+(f>>1)|0]=d;return}switch(e|0){case 28676:{f=d&1;c[3541360]=f;if((f|0)!=0){return}c[3541358]=-1;return};case 28672:{a[14165768]=d&1;return};case 28675:{a[14165928]=d&1;return};case 26624:case 26625:case 26626:case 26627:case 26628:case 26629:case 26630:case 26631:{f=e-26624|0;b=d&1;switch(f&7|0){case 0:case 1:case 2:{c[14165720+(f<<2)>>2]=b&255;return};case 5:{do{if(b<<24>>24!=0){if((a[14165752]&1)!=0){break}a[14165512]=1;h[932735]=0.0}}while(0);a[14165752]=b;return};case 7:case 6:{g=f&1;c[3541336]=c[3541336]&~(1<<g)|(d&1)<<g;return};case 3:{a[14165672]=b;if(b<<24>>24==0){return}c[3541416]=100;h[932737]=0.0;return};default:{return}}break};case 24580:case 24581:case 24582:case 24583:{b=d&1;g=14165736+(e-24580<<2)|0;if((b|0)==(c[g>>2]|0)){return}c[g>>2]=b;b=(c[3541434]|0)==0;i=b?4030303030303031.0e-21:30303030303030305.0e-22;j=b?1.0e-12:1000001.0e-12;if((c[3541435]|0)==0){k=j;l=i+21276595744680853.0e-22}else{k=j+21276595744680853.0e-22;l=i}if((c[3541436]|0)==0){m=k;n=l+45454545454545455.0e-22}else{m=k+45454545454545455.0e-22;n=l}if((c[3541437]|0)==0){o=m;p=n+1.0e-5}else{o=m+1.0e-5;p=n}n=1.0/p;h[932738]=1.0e9/((n*2.0e6/(n+1.0/o)+1.0e5)*58788.0)*100.0;return};case 30720:{c[3541406]=d&255;return};case 28678:{a[14165832]=d&1;return};case 28679:{a[14165824]=d&1;return};default:{return}}}function aOj(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5569172+(b*112|0)>>2];c[a+104>>2]=c[5569176+(b*112|0)>>2];c[a+108>>2]=c[5569180+(b*112|0)>>2];d=0;return d|0}function aOk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=5569072+(b*112|0);e=0;return e|0}function aOl(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=2002736+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aOm(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5570080+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aOn(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3654420+(b*112|0)>>2];c[a+104>>2]=c[3654424+(b*112|0)>>2];c[a+108>>2]=c[3654428+(b*112|0)>>2];d=0;return d|0}function aOo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=3654320+(b*112|0);e=0;return e|0}function aOp(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1223864+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aOq(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3655216+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aOr(){c[3541404]=320;return a04()|0}function aOs(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>4){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3777292+(b*112|0)>>2];c[a+104>>2]=c[3777296+(b*112|0)>>2];c[a+108>>2]=c[3777300+(b*112|0)>>2];d=0;return d|0}function aOt(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<5&(d|0)==0)){e=1;return e|0}c[a>>2]=3777192+(b*112|0);e=0;return e|0}function aOu(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1233360+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aOv(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>2){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3777752+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aOw(){c[3541322]=6144;c[3541404]=1016;return a04()|0}function aOx(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>4){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5534532+(b*112|0)>>2];c[a+104>>2]=c[5534536+(b*112|0)>>2];c[a+108>>2]=c[5534540+(b*112|0)>>2];d=0;return d|0}function aOy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<5&(d|0)==0)){e=1;return e|0}c[a>>2]=5534432+(b*112|0);e=0;return e|0}function aOz(){c[3541322]=4096;c[3541404]=12114;return a04()|0}function aOA(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4184484+(b*112|0)>>2];c[a+104>>2]=c[4184488+(b*112|0)>>2];c[a+108>>2]=c[4184492+(b*112|0)>>2];d=0;return d|0}function aOB(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=4184384+(b*112|0);e=0;return e|0}function aOC(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5196016+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aOD(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4185168+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aOE(){c[3541322]=2048;c[3541404]=1752;return a04()|0}function aOF(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6823364+(b*112|0)>>2];c[a+104>>2]=c[6823368+(b*112|0)>>2];c[a+108>>2]=c[6823372+(b*112|0)>>2];d=0;return d|0}function aOG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=6823264+(b*112|0);e=0;return e|0}function aOH(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6824272+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aOI(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3256164+(b*112|0)>>2];c[a+104>>2]=c[3256168+(b*112|0)>>2];c[a+108>>2]=c[3256172+(b*112|0)>>2];d=0;return d|0}function aOJ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=3256064+(b*112|0);e=0;return e|0}function aOK(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1174976+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aOL(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3256960+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aOM(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1645180+(b*112|0)>>2];c[a+104>>2]=c[1645184+(b*112|0)>>2];c[a+108>>2]=c[1645188+(b*112|0)>>2];d=0;return d|0}function aON(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=1645080+(b*112|0);e=0;return e|0}function aOO(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6149308+(b*112|0)>>2];c[a+104>>2]=c[6149312+(b*112|0)>>2];c[a+108>>2]=c[6149316+(b*112|0)>>2];d=0;return d|0}function aOP(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=6149208+(b*112|0);e=0;return e|0}function aOQ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6150328+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aOR(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5104820+(b*112|0)>>2];c[a+104>>2]=c[5104824+(b*112|0)>>2];c[a+108>>2]=c[5104828+(b*112|0)>>2];d=0;return d|0}function aOS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=5104720+(b*112|0);e=0;return e|0}function aOT(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5105728+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aOU(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6320492+(b*112|0)>>2];c[a+104>>2]=c[6320496+(b*112|0)>>2];c[a+108>>2]=c[6320500+(b*112|0)>>2];d=0;return d|0}function aOV(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=6320392+(b*112|0);e=0;return e|0}function aOW(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6321512+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aOX(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6038508+(b*112|0)>>2];c[a+104>>2]=c[6038512+(b*112|0)>>2];c[a+108>>2]=c[6038516+(b*112|0)>>2];d=0;return d|0}function aOY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=6038408+(b*112|0);e=0;return e|0}function aOZ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3325160+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aO_(){c[3541404]=1900;return a04()|0}function aO$(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>5){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5585340+(b*112|0)>>2];c[a+104>>2]=c[5585344+(b*112|0)>>2];c[a+108>>2]=c[5585348+(b*112|0)>>2];d=0;return d|0}function aO0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<6&(d|0)==0)){e=1;return e|0}c[a>>2]=5585240+(b*112|0);e=0;return e|0}function aO1(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=2010432+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aO2(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5585912+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aO3(){var a=0;c[3541404]=2244;a=a04()|0;c[3541466]=60;return a|0}function aO4(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3325484+(b*112|0)>>2];c[a+104>>2]=c[3325488+(b*112|0)>>2];c[a+108>>2]=c[3325492+(b*112|0)>>2];d=0;return d|0}function aO5(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=3325384+(b*112|0);e=0;return e|0}function aO6(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1182808+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aO7(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3326392+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aO8(){c[3541404]=3248;return a04()|0}function aO9(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3518404+(b*112|0)>>2];c[a+104>>2]=c[3518408+(b*112|0)>>2];c[a+108>>2]=c[3518412+(b*112|0)>>2];d=0;return d|0}function aPa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=3518304+(b*112|0);e=0;return e|0}function aPb(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1201608+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aPc(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3519536+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aPd(){var a=0;c[3541404]=7212;a=a04()|0;c[3541392]=8638;c[3541466]=60;return a|0}function aPe(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5088476+(b*112|0)>>2];c[a+104>>2]=c[5088480+(b*112|0)>>2];c[a+108>>2]=c[5088484+(b*112|0)>>2];d=0;return d|0}function aPf(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=5088376+(b*112|0);e=0;return e|0}function aPg(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1745456+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aPh(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5089608+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aPi(){var a=0;c[3541404]=6720;a=a04()|0;c[3541392]=8638;c[3541466]=60;return a|0}function aPj(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1744132+(b*112|0)>>2];c[a+104>>2]=c[1744136+(b*112|0)>>2];c[a+108>>2]=c[1744140+(b*112|0)>>2];d=0;return d|0}function aPk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=1744032+(b*112|0);e=0;return e|0}function aPl(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=963560+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aPm(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1745264+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aPn(){var a=0;c[3541404]=5962;a=a04()|0;c[3541392]=8638;c[3541466]=60;c[3541390]=1518;return a|0}function aPo(b,d){b=b|0;d=d|0;var e=0,f=0,g=0.0,i=0.0,j=0.0,k=0.0,l=0.0,m=0.0,n=0.0,o=0.0;e=b&65535;if((b-22528&65535)<256){b=e-22528|0;a[(c[3541366]|0)+b|0]=d;if(!((b|0)<64&(b&1|0)==0)){return}a[(c[3541380]|0)+(b>>1)|0]=d;return}switch(e|0){case 26624:case 26625:case 26626:case 26627:case 26628:case 26629:case 26630:case 26631:{b=e-26624|0;f=d&1;switch(b&7|0){case 0:case 1:case 2:{c[14165720+(b<<2)>>2]=f&255;return};case 3:{a[14165672]=f;if(f<<24>>24==0){return}c[3541416]=100;h[932737]=0.0;return};case 5:{do{if(f<<24>>24!=0){if((a[14165752]&1)!=0){break}a[14165512]=1;h[932735]=0.0}}while(0);a[14165752]=f;return};case 7:case 6:{f=b&1;c[3541336]=c[3541336]&~(1<<f)|(d&1)<<f;return};default:{return}}break};case 24578:{a[c[3541454]|0]=d;return};case 24580:case 24581:case 24582:case 24583:{f=d&1;b=14165736+(e-24580<<2)|0;if((f|0)==(c[b>>2]|0)){return}c[b>>2]=f;f=(c[3541434]|0)==0;g=f?4030303030303031.0e-21:30303030303030305.0e-22;i=f?1.0e-12:1000001.0e-12;if((c[3541435]|0)==0){j=i;k=g+21276595744680853.0e-22}else{j=i+21276595744680853.0e-22;k=g}if((c[3541436]|0)==0){l=j;m=k+45454545454545455.0e-22}else{l=j+45454545454545455.0e-22;m=k}if((c[3541437]|0)==0){n=l;o=m+1.0e-5}else{n=l+1.0e-5;o=m}m=1.0/o;h[932738]=1.0e9/((m*2.0e6/(m+1.0/n)+1.0e5)*58788.0)*100.0;return};case 28678:{a[14165832]=d&1;return};case 28679:{a[14165824]=d&1;return};case 30720:{c[3541406]=d&255;return};case 28673:{a[14165768]=d&1;return};case 28676:{f=d&1;c[3541360]=f;if((f|0)!=0){return}c[3541358]=-1;return};default:{return}}}function aPp(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6168660+(b*112|0)>>2];c[a+104>>2]=c[6168664+(b*112|0)>>2];c[a+108>>2]=c[6168668+(b*112|0)>>2];d=0;return d|0}function aPq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=6168560+(b*112|0);e=0;return e|0}function aPr(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3623816+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aPs(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6169792+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aPt(){c[3541404]=12782;c[3541462]=14;c[3541464]=72;return a04()|0}function aPu(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5142972+(b*112|0)>>2];c[a+104>>2]=c[5142976+(b*112|0)>>2];c[a+108>>2]=c[5142980+(b*112|0)>>2];d=0;return d|0}function aPv(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=5142872+(b*112|0);e=0;return e|0}function aPw(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5144104+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aPx(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7162964+(b*112|0)>>2];c[a+104>>2]=c[7162968+(b*112|0)>>2];c[a+108>>2]=c[7162972+(b*112|0)>>2];d=0;return d|0}function aPy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=7162864+(b*112|0);e=0;return e|0}function aPz(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4907028+(b*112|0)>>2];c[a+104>>2]=c[4907032+(b*112|0)>>2];c[a+108>>2]=c[4907036+(b*112|0)>>2];d=0;return d|0}function aPA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=4906928+(b*112|0);e=0;return e|0}function aPB(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3885316+(b*112|0)>>2];c[a+104>>2]=c[3885320+(b*112|0)>>2];c[a+108>>2]=c[3885324+(b*112|0)>>2];d=0;return d|0}function aPC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=3885216+(b*112|0);e=0;return e|0}function aPD(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3886772+(b*112|0)>>2];c[a+104>>2]=c[3886776+(b*112|0)>>2];c[a+108>>2]=c[3886780+(b*112|0)>>2];d=0;return d|0}function aPE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=3886672+(b*112|0);e=0;return e|0}function aPF(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3888128+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aPG(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3888444+(b*112|0)>>2];c[a+104>>2]=c[3888448+(b*112|0)>>2];c[a+108>>2]=c[3888452+(b*112|0)>>2];d=0;return d|0}function aPH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=3888344+(b*112|0);e=0;return e|0}function aPI(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3889800+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aPJ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3406268+(b*112|0)>>2];c[a+104>>2]=c[3406272+(b*112|0)>>2];c[a+108>>2]=c[3406276+(b*112|0)>>2];d=0;return d|0}function aPK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=3406168+(b*112|0);e=0;return e|0}function aPL(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3407624+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aPM(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3407988+(b*112|0)>>2];c[a+104>>2]=c[3407992+(b*112|0)>>2];c[a+108>>2]=c[3407996+(b*112|0)>>2];d=0;return d|0}function aPN(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=3407888+(b*112|0);e=0;return e|0}function aPO(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3401644+(b*112|0)>>2];c[a+104>>2]=c[3401648+(b*112|0)>>2];c[a+108>>2]=c[3401652+(b*112|0)>>2];d=0;return d|0}function aPP(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=3401544+(b*112|0);e=0;return e|0}function aPQ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3438716+(b*112|0)>>2];c[a+104>>2]=c[3438720+(b*112|0)>>2];c[a+108>>2]=c[3438724+(b*112|0)>>2];d=0;return d|0}function aPR(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=3438616+(b*112|0);e=0;return e|0}function aPS(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6303580+(b*112|0)>>2];c[a+104>>2]=c[6303584+(b*112|0)>>2];c[a+108>>2]=c[6303588+(b*112|0)>>2];d=0;return d|0}function aPT(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=6303480+(b*112|0);e=0;return e|0}function aPU(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4264188+(b*112|0)>>2];c[a+104>>2]=c[4264192+(b*112|0)>>2];c[a+108>>2]=c[4264196+(b*112|0)>>2];d=0;return d|0}function aPV(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=4264088+(b*112|0);e=0;return e|0}function aPW(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4265544+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aPX(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3637052+(b*112|0)>>2];c[a+104>>2]=c[3637056+(b*112|0)>>2];c[a+108>>2]=c[3637060+(b*112|0)>>2];d=0;return d|0}function aPY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=3636952+(b*112|0);e=0;return e|0}function aPZ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5577844+(b*112|0)>>2];c[a+104>>2]=c[5577848+(b*112|0)>>2];c[a+108>>2]=c[5577852+(b*112|0)>>2];d=0;return d|0}function aP_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=5577744+(b*112|0);e=0;return e|0}function aP$(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=2009920+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aP0(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5579200+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aP1(){c[3541404]=12782;c[3541462]=122;c[3541464]=38;return a04()|0}function aP2(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3809540+(b*112|0)>>2];c[a+104>>2]=c[3809544+(b*112|0)>>2];c[a+108>>2]=c[3809548+(b*112|0)>>2];d=0;return d|0}function aP3(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=3809440+(b*112|0);e=0;return e|0}function aP4(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1236720+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aP5(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3810672+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aP6(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=i;i=i+240|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;c[3541404]=12782;c[3541462]=122;c[3541464]=38;j=a04()|0;k=0;while(1){if((k|0)>=1024){l=0;break}m=9638528+(k<<2)|0;if((c[m>>2]|0)==0){n=38073;break}else{k=k+1|0}}do{if((n|0)==38073){k=gGq(4096)|0;c[m>>2]=k;if((k|0)==0){l=0;break}gGz(k|0,0,4096);l=k}}while(0);m=c[3541348]|0;k=0;while(1){if((k|0)>=1024){o=0;break}p=9638528+(k<<2)|0;if((c[p>>2]|0)==0){n=38078;break}else{k=k+1|0}}do{if((n|0)==38078){k=gGq(m)|0;c[p>>2]=k;if((k|0)==0){o=0;break}gGz(k|0,0,m|0);o=k}}while(0);c[3541356]=o;o=(c[3541318]|0)+(c[3541326]|0)+(c[3541312]|0)|0;do{if((c[3542200]|0)!=0){m=g+108|0;c[m>>2]=0;p=g+100|0;c[p>>2]=0;k=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[k&16383](g,o)|0;if((c[m>>2]|0)==0){break}m=c[p>>2]|0;c[h>>2]=9534384;p=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[p&16383](h,o,0)|0;if((m|0)<1){break}gzL(l,0,o)|0}}while(0);o=c[3541356]|0;h=o+2048|0;gGC(h|0,l|0,2048)|0;h=l+2048|0;gGC(o|0,h|0,2048)|0;o=(c[3541326]|0)+1+(c[3541318]|0)+(c[3541312]|0)|0;do{if((c[3542200]|0)!=0){g=e+108|0;c[g>>2]=0;m=e+100|0;c[m>>2]=0;p=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[p&16383](e,o)|0;if((c[g>>2]|0)==0){break}g=c[m>>2]|0;c[f>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](f,o,0)|0;if((g|0)<1){break}gzL(l,0,o)|0}}while(0);o=c[3541356]|0;f=o+6144|0;gGC(f|0,l|0,2048)|0;f=o+4096|0;gGC(f|0,h|0,2048)|0;h=c[3541414]|0;f=c[3541472]|0;if((h|0)>0){e=c[1865546]|0;g=0;do{m=g<<6;gGz(f+m|0,0,64);p=0;do{k=m+(c[1238464+(p<<2)>>2]|0)|0;q=(p<<3)+m|0;r=0;do{s=k+(c[614800+(r<<2)>>2]|0)|0;if(((d[o+((s|0)/8|0)|0]|0)&128>>>((s&7)>>>0)|0)!=0){s=f+(q+r)|0;a[s]=a[s]|2}r=r+1|0;}while((r|0)<8);p=p+1|0;}while((p|0)<8);p=e+m|0;r=0;do{q=p+(c[1238464+(r<<2)>>2]|0)|0;k=(r<<3)+m|0;s=0;do{t=q+(c[614800+(s<<2)>>2]|0)|0;if(((d[o+((t|0)/8|0)|0]|0)&128>>>((t&7)>>>0)|0)!=0){t=f+(k+s)|0;a[t]=a[t]|1}s=s+1|0;}while((s|0)<8);r=r+1|0;}while((r|0)<8);g=g+1|0;}while((g|0)<(h|0))}h=c[3541412]|0;g=c[3541364]|0;if((h|0)>0){f=c[1865412]|0;e=0;while(1){r=e<<8;gGz(g+r|0,0,256);m=0;do{p=r+(c[611776+(m<<2)>>2]|0)|0;s=(m<<4)+r|0;k=0;do{q=p+(c[601400+(k<<2)>>2]|0)|0;if(((d[o+((q|0)/8|0)|0]|0)&128>>>((q&7)>>>0)|0)!=0){q=g+(s+k)|0;a[q]=a[q]|2}k=k+1|0;}while((k|0)<16);m=m+1|0;}while((m|0)<16);m=f+r|0;k=0;do{s=m+(c[611776+(k<<2)>>2]|0)|0;p=(k<<4)+r|0;q=0;do{t=s+(c[601400+(q<<2)>>2]|0)|0;if(((d[o+((t|0)/8|0)|0]|0)&128>>>((t&7)>>>0)|0)!=0){t=g+(p+q)|0;a[t]=a[t]|1}q=q+1|0;}while((q|0)<16);k=k+1|0;}while((k|0)<16);k=e+1|0;if((k|0)<(h|0)){e=k}else{u=0;break}}}else{u=0}while(1){if((u|0)>=1024){break}v=9638528+(u<<2)|0;if((c[v>>2]|0)==(o|0)){n=38108;break}else{u=u+1|0}}if((n|0)==38108){gGr(o);c[v>>2]=0}c[3541356]=0;v=0;while(1){if((v|0)>=1024){n=38126;break}w=9638528+(v<<2)|0;if((c[w>>2]|0)==(l|0)){break}else{v=v+1|0}}if((n|0)==38126){i=b;return j|0}gGr(l);c[w>>2]=0;i=b;return j|0}function aP7(b){b=b|0;var c=0,d=0;c=b&65535;if((c|0)==24576){d=a[14165872]|a[14165808]}else if((c|0)==26624){d=a[14165873]|a[14165809]}else if((c|0)==28672){d=a[14165874]|a[14165810]}else if((c|0)==30720){d=-1}else{d=0}return d|0}function aP8(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3358972+(b*112|0)>>2];c[a+104>>2]=c[3358976+(b*112|0)>>2];c[a+108>>2]=c[3358980+(b*112|0)>>2];d=0;return d|0}function aP9(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=3358872+(b*112|0);e=0;return e|0}function aQa(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1186984+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aQb(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3359656+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aQc(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1683124+(b*112|0)>>2];c[a+104>>2]=c[1683128+(b*112|0)>>2];c[a+108>>2]=c[1683132+(b*112|0)>>2];d=0;return d|0}function aQd(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=1683024+(b*112|0);e=0;return e|0}function aQe(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3638916+(b*112|0)>>2];c[a+104>>2]=c[3638920+(b*112|0)>>2];c[a+108>>2]=c[3638924+(b*112|0)>>2];d=0;return d|0}function aQf(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=3638816+(b*112|0);e=0;return e|0}function aQg(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1221320+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aQh(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3640160+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aQi(){var b=0;b=a04()|0;a[14165472]=7;a[14165480]=-10;return b|0}function aQj(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1789404+(b*112|0)>>2];c[a+104>>2]=c[1789408+(b*112|0)>>2];c[a+108>>2]=c[1789412+(b*112|0)>>2];d=0;return d|0}function aQk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=1789304+(b*112|0);e=0;return e|0}function aQl(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=i;i=i+240|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;c[3541404]=3032;j=a04()|0;a[14165472]=7;a[14165480]=-10;c[3541414]=256;c[3541412]=64;c[1865546]=16384;c[1865412]=16384;k=0;while(1){if((k|0)>=1024){l=0;break}m=9638528+(k<<2)|0;if((c[m>>2]|0)==0){n=38214;break}else{k=k+1|0}}do{if((n|0)==38214){k=gGq(8192)|0;c[m>>2]=k;if((k|0)==0){l=0;break}gGz(k|0,0,8192);l=k}}while(0);m=c[3541348]|0;k=0;while(1){if((k|0)>=1024){o=0;break}p=9638528+(k<<2)|0;if((c[p>>2]|0)==0){n=38219;break}else{k=k+1|0}}do{if((n|0)==38219){k=gGq(m)|0;c[p>>2]=k;if((k|0)==0){o=0;break}gGz(k|0,0,m|0);o=k}}while(0);c[3541356]=o;o=(c[3541318]|0)+(c[3541326]|0)+(c[3541312]|0)|0;do{if((c[3542200]|0)!=0){m=g+108|0;c[m>>2]=0;p=g+100|0;c[p>>2]=0;k=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[k&16383](g,o)|0;if((c[m>>2]|0)==0){break}m=c[p>>2]|0;c[h>>2]=9534384;p=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[p&16383](h,o,0)|0;if((m|0)<1){break}gzL(l,0,o)|0}}while(0);o=l+4096|0;h=(c[3541326]|0)+1+(c[3541318]|0)+(c[3541312]|0)|0;do{if((c[3542200]|0)!=0){g=e+108|0;c[g>>2]=0;m=e+100|0;c[m>>2]=0;p=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[p&16383](e,h)|0;if((c[g>>2]|0)==0){break}g=c[m>>2]|0;c[f>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](f,h,0)|0;if((g|0)<1){break}gzL(o,0,h)|0}}while(0);h=c[3541356]|0;f=l+2048|0;gGC(h|0,f|0,2048)|0;f=h+2048|0;e=l+6144|0;gGC(f|0,e|0,2048)|0;e=h+4096|0;gGC(e|0,l|0,2048)|0;e=h+6144|0;gGC(e|0,o|0,2048)|0;o=c[3541414]|0;e=c[3541472]|0;if((o|0)>0){f=c[1865546]|0;g=0;do{m=g<<6;gGz(e+m|0,0,64);p=0;do{k=m+(c[1238464+(p<<2)>>2]|0)|0;q=(p<<3)+m|0;r=0;do{s=k+(c[614800+(r<<2)>>2]|0)|0;if(((d[h+((s|0)/8|0)|0]|0)&128>>>((s&7)>>>0)|0)!=0){s=e+(q+r)|0;a[s]=a[s]|2}r=r+1|0;}while((r|0)<8);p=p+1|0;}while((p|0)<8);p=f+m|0;r=0;do{q=p+(c[1238464+(r<<2)>>2]|0)|0;k=(r<<3)+m|0;s=0;do{t=q+(c[614800+(s<<2)>>2]|0)|0;if(((d[h+((t|0)/8|0)|0]|0)&128>>>((t&7)>>>0)|0)!=0){t=e+(k+s)|0;a[t]=a[t]|1}s=s+1|0;}while((s|0)<8);r=r+1|0;}while((r|0)<8);g=g+1|0;}while((g|0)<(o|0))}o=c[3541412]|0;g=c[3541364]|0;if((o|0)>0){e=c[1865412]|0;f=0;while(1){r=f<<8;gGz(g+r|0,0,256);m=0;do{p=r+(c[611776+(m<<2)>>2]|0)|0;s=(m<<4)+r|0;k=0;do{q=p+(c[601400+(k<<2)>>2]|0)|0;if(((d[h+(((q|0)/8|0)+4096)|0]|0)&128>>>((q&7)>>>0)|0)!=0){q=g+(s+k)|0;a[q]=a[q]|2}k=k+1|0;}while((k|0)<16);m=m+1|0;}while((m|0)<16);m=e+r|0;k=0;do{s=m+(c[611776+(k<<2)>>2]|0)|0;p=(k<<4)+r|0;q=0;do{t=s+(c[601400+(q<<2)>>2]|0)|0;if(((d[h+(((t|0)/8|0)+4096)|0]|0)&128>>>((t&7)>>>0)|0)!=0){t=g+(p+q)|0;a[t]=a[t]|1}q=q+1|0;}while((q|0)<16);k=k+1|0;}while((k|0)<16);k=f+1|0;if((k|0)<(o|0)){f=k}else{u=0;break}}}else{u=0}while(1){if((u|0)>=1024){break}v=9638528+(u<<2)|0;if((c[v>>2]|0)==(h|0)){n=38249;break}else{u=u+1|0}}if((n|0)==38249){gGr(h);c[v>>2]=0}c[3541356]=0;v=0;while(1){if((v|0)>=1024){n=38267;break}w=9638528+(v<<2)|0;if((c[w>>2]|0)==(l|0)){break}else{v=v+1|0}}if((n|0)==38267){i=b;return j|0}gGr(l);c[w>>2]=0;i=b;return j|0}function aQm(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3911364+(b*112|0)>>2];c[a+104>>2]=c[3911368+(b*112|0)>>2];c[a+108>>2]=c[3911372+(b*112|0)>>2];d=0;return d|0}function aQn(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=3911264+(b*112|0);e=0;return e|0}function aQo(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3912272+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aQp(){var b=0;c[3541404]=11874;b=a04()|0;a[14165472]=7;a[14165480]=-10;return b|0}function aQq(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3624140+(b*112|0)>>2];c[a+104>>2]=c[3624144+(b*112|0)>>2];c[a+108>>2]=c[3624148+(b*112|0)>>2];d=0;return d|0}function aQr(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=3624040+(b*112|0);e=0;return e|0}function aQs(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1217936+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aQt(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3625496+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aQu(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2011284+(b*112|0)>>2];c[a+104>>2]=c[2011288+(b*112|0)>>2];c[a+108>>2]=c[2011292+(b*112|0)>>2];d=0;return d|0}function aQv(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=2011184+(b*112|0);e=0;return e|0}function aQw(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=2012192+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aQx(){c[3541322]=4096;c[3541404]=8270;return a04()|0}function aQy(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4070284+(b*112|0)>>2];c[a+104>>2]=c[4070288+(b*112|0)>>2];c[a+108>>2]=c[4070292+(b*112|0)>>2];d=0;return d|0}function aQz(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=4070184+(b*112|0);e=0;return e|0}function aQA(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1217936+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aQB(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4070968+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aQC(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;b=i;i=i+240|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;c[3541404]=3814;a04()|0;c[3541414]=256;c[3541412]=64;c[1865546]=16384;c[1865412]=16384;j=0;while(1){if((j|0)>=1024){k=0;break}l=9638528+(j<<2)|0;if((c[l>>2]|0)==0){m=38364;break}else{j=j+1|0}}do{if((m|0)==38364){j=gGq(8192)|0;c[l>>2]=j;if((j|0)==0){k=0;break}gGz(j|0,0,8192);k=j}}while(0);l=0;while(1){if((l|0)>=1024){n=0;break}o=9638528+(l<<2)|0;if((c[o>>2]|0)==0){m=38369;break}else{l=l+1|0}}do{if((m|0)==38369){l=gGq(4096)|0;c[o>>2]=l;if((l|0)==0){n=0;break}gGz(l|0,0,4096);n=l}}while(0);c[3541356]=n;n=(c[3541318]|0)+(c[3541326]|0)+(c[3541312]|0)|0;if((c[3542200]|0)==0){p=1;i=b;return p|0}o=g+108|0;c[o>>2]=0;l=g+100|0;c[l>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,n)|0;do{if((c[o>>2]|0)!=0){g=c[l>>2]|0;c[h>>2]=9534384;j=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[j&16383](h,n,0)|0;if((g|0)<1){p=1;i=b;return p|0}if((gzL(k,0,n)|0)==0){break}else{p=1}i=b;return p|0}}while(0);n=k+4096|0;h=(c[3541326]|0)+1+(c[3541318]|0)+(c[3541312]|0)|0;if((c[3542200]|0)==0){p=1;i=b;return p|0}l=e+108|0;c[l>>2]=0;o=e+100|0;c[o>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,h)|0;do{if((c[l>>2]|0)!=0){e=c[o>>2]|0;c[f>>2]=9534384;g=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[g&16383](f,h,0)|0;if((e|0)<1){p=1;i=b;return p|0}if((gzL(n,0,h)|0)==0){break}else{p=1}i=b;return p|0}}while(0);h=c[3541356]|0;f=k+2048|0;gGC(h|0,f|0,2048)|0;f=h+2048|0;o=k+6144|0;gGC(f|0,o|0,2048)|0;o=c[3541414]|0;l=c[3541472]|0;if((o|0)>0){e=c[1865546]|0;g=0;do{j=g<<6;gGz(l+j|0,0,64);q=0;do{r=j+(c[1238464+(q<<2)>>2]|0)|0;s=(q<<3)+j|0;t=0;do{u=r+(c[614800+(t<<2)>>2]|0)|0;if(((d[h+((u|0)/8|0)|0]|0)&128>>>((u&7)>>>0)|0)!=0){u=l+(s+t)|0;a[u]=a[u]|2}t=t+1|0;}while((t|0)<8);q=q+1|0;}while((q|0)<8);q=e+j|0;t=0;do{s=q+(c[1238464+(t<<2)>>2]|0)|0;r=(t<<3)+j|0;u=0;do{v=s+(c[614800+(u<<2)>>2]|0)|0;if(((d[h+((v|0)/8|0)|0]|0)&128>>>((v&7)>>>0)|0)!=0){v=l+(r+u)|0;a[v]=a[v]|1}u=u+1|0;}while((u|0)<8);t=t+1|0;}while((t|0)<8);g=g+1|0;}while((g|0)<(o|0))}gGC(h|0,k|0,2048)|0;gGC(f|0,n|0,2048)|0;n=c[3541412]|0;f=c[3541364]|0;if((n|0)>0){o=c[1865412]|0;g=0;while(1){l=g<<8;gGz(f+l|0,0,256);e=0;do{t=l+(c[611776+(e<<2)>>2]|0)|0;j=(e<<4)+l|0;q=0;do{u=t+(c[601400+(q<<2)>>2]|0)|0;if(((d[h+((u|0)/8|0)|0]|0)&128>>>((u&7)>>>0)|0)!=0){u=f+(j+q)|0;a[u]=a[u]|2}q=q+1|0;}while((q|0)<16);e=e+1|0;}while((e|0)<16);e=o+l|0;q=0;do{j=e+(c[611776+(q<<2)>>2]|0)|0;t=(q<<4)+l|0;u=0;do{r=j+(c[601400+(u<<2)>>2]|0)|0;if(((d[h+((r|0)/8|0)|0]|0)&128>>>((r&7)>>>0)|0)!=0){r=f+(t+u)|0;a[r]=a[r]|1}u=u+1|0;}while((u|0)<16);q=q+1|0;}while((q|0)<16);q=g+1|0;if((q|0)<(n|0)){g=q}else{w=0;break}}}else{w=0}while(1){if((w|0)>=1024){break}x=9638528+(w<<2)|0;if((c[x>>2]|0)==(h|0)){m=38399;break}else{w=w+1|0}}if((m|0)==38399){gGr(h);c[x>>2]=0}c[3541356]=0;x=0;while(1){if((x|0)>=1024){break}y=9638528+(x<<2)|0;if((c[y>>2]|0)==(k|0)){m=38403;break}else{x=x+1|0}}if((m|0)==38403){gGr(k);c[y>>2]=0}a[14165760]=2;p=0;i=b;return p|0}function aQD(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=b&65535;if((b-18432&65535)<2048){f=e-18432|0;g=f&768;if((g|0)==0){if((f&1|0)==0){return}h=a[14125128]|0;i=h&255;if((f&2|0)!=0){c[3542228]=i&15;return}j=c[3542228]|0;if((j|0)>15){return}do{if((j|0)<14){if((j|0)!=13){if((a[14168916+j|0]|0)==h<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(0,j,i);return}else if((g|0)==256){a[14125128]=f&255;return}else{return}}if((b-22528&65535)<256){b=e-22528|0;a[(c[3541366]|0)+b|0]=d;if(!((b|0)<64&(b&1|0)==0)){return}a[(c[3541380]|0)+(b>>1)|0]=d;return}switch(e|0){case 28673:{a[14165768]=d&1;return};case 28674:{e=c[3541328]|0;b=(d&255)<<12&4096;f=b|8192;g=c[9757320+(c[1836236]<<2)>>2]|0;i=f-8192|0;c[g+204>>2]=e+f;c[g+208>>2]=e+(b|8448);c[g+212>>2]=e+(b|8704);c[g+216>>2]=e+(b|8960);c[g+220>>2]=e+(b|9216);c[g+224>>2]=e+(b|9472);c[g+228>>2]=e+(b|9728);c[g+232>>2]=e+(b|9984);c[g+236>>2]=e+(b|10240);c[g+240>>2]=e+(b|10496);c[g+244>>2]=e+(b|10752);c[g+248>>2]=e+(b|11008);c[g+252>>2]=e+(b|11264);c[g+256>>2]=e+(b|11520);c[g+260>>2]=e+(b|11776);c[g+264>>2]=e+(b|12032);f=32;j=32;while(1){h=e+(i+(j<<8))|0;c[g+76+(j+512<<2)>>2]=h;c[g+76+(j+768<<2)>>2]=h;h=f+1&65535;if((h&65535)>47){break}else{f=h;j=h&65535}}j=b^12288;b=j-12288|0;c[g+268>>2]=e+j;c[g+272>>2]=e+(j|256);c[g+276>>2]=e+(j|512);c[g+280>>2]=e+(j|768);c[g+284>>2]=e+(j|1024);c[g+288>>2]=e+(j|1280);c[g+292>>2]=e+(j|1536);c[g+296>>2]=e+(j|1792);c[g+300>>2]=e+(j|2048);c[g+304>>2]=e+(j|2304);c[g+308>>2]=e+(j|2560);c[g+312>>2]=e+(j|2816);c[g+316>>2]=e+(j|3072);c[g+320>>2]=e+(j|3328);c[g+324>>2]=e+(j|3584);c[g+328>>2]=e+(j|3840);j=48;f=48;while(1){i=e+(b+(f<<8))|0;c[g+76+(f+512<<2)>>2]=i;c[g+76+(f+768<<2)>>2]=i;i=j+1&65535;if((i&65535)>63){break}else{j=i;f=i&65535}}return};case 28679:{a[14165824]=d&1;return};case 28676:{f=d&1;c[3541360]=f;if((f|0)!=0){return}c[3541358]=-1;return};case 28678:{a[14165832]=d&1;return};default:{return}}}function aQE(b){b=b|0;var c=0,d=0;c=b&65535;if((c|0)==33024){d=~(a[14165872]|a[14165808])}else if((c|0)==33025){d=~(a[14165873]|a[14165809])}else if((c|0)==33026){d=~(a[14165874]|a[14165810])}else{d=-1}return d|0}function aQF(b,d){b=b|0;d=d|0;var e=0;if((b-20480&65535)<256){e=(b&65535)-20480|0;a[(c[3541366]|0)+e|0]=d;if(!((e|0)<64&(e&1|0)==0)){return}a[(c[3541380]|0)+(e>>1)|0]=d;return}else{if(b<<16>>16!=26625){return}a[14165768]=d&1;return}}function aQG(b,d){b=b|0;d=d|0;var e=0,f=0;e=b&255;if((e|0)==0){b=d&255;f=c[3542228]|0;if((f|0)>15){return}do{if((f|0)<14){if((f|0)!=13){if((a[14168916+f|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(0,f,b);return}else if((e|0)==1){c[3542228]=d&15;return}else{return}}function aQH(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5961436+(b*112|0)>>2];c[a+104>>2]=c[5961440+(b*112|0)>>2];c[a+108>>2]=c[5961444+(b*112|0)>>2];d=0;return d|0}function aQI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=5961336+(b*112|0);e=0;return e|0}function aQJ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3188288+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aQK(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5962120+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aQL(){var b=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;b=i;i=i+240|0;e=b|0;f=b+112|0;g=b+120|0;j=b+232|0;a[14165488]=2;c[3541404]=258;a04()|0;c[3541414]=256;c[3541412]=64;c[1865546]=16384;c[1865412]=16384;k=0;while(1){if((k|0)>=1024){l=0;break}m=9638528+(k<<2)|0;if((c[m>>2]|0)==0){n=38523;break}else{k=k+1|0}}do{if((n|0)==38523){k=gGq(8192)|0;c[m>>2]=k;if((k|0)==0){l=0;break}gGz(k|0,0,8192);l=k}}while(0);m=0;while(1){if((m|0)>=1024){o=0;break}p=9638528+(m<<2)|0;if((c[p>>2]|0)==0){n=38528;break}else{m=m+1|0}}do{if((n|0)==38528){m=gGq(4096)|0;c[p>>2]=m;if((m|0)==0){o=0;break}gGz(m|0,0,4096);o=m}}while(0);c[3541356]=o;o=(c[3541318]|0)+(c[3541326]|0)+(c[3541312]|0)|0;if((c[3542200]|0)==0){q=1;i=b;return q|0}p=g+108|0;c[p>>2]=0;m=g+100|0;c[m>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,o)|0;do{if((c[p>>2]|0)!=0){g=c[m>>2]|0;c[j>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](j,o,0)|0;if((g|0)<1){q=1;i=b;return q|0}if((gzL(l,0,o)|0)==0){break}else{q=1}i=b;return q|0}}while(0);o=l+4096|0;j=(c[3541326]|0)+1+(c[3541318]|0)+(c[3541312]|0)|0;if((c[3542200]|0)==0){q=1;i=b;return q|0}m=e+108|0;c[m>>2]=0;p=e+100|0;c[p>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,j)|0;do{if((c[m>>2]|0)!=0){e=c[p>>2]|0;c[f>>2]=9534384;g=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[g&16383](f,j,0)|0;if((e|0)<1){q=1;i=b;return q|0}if((gzL(o,0,j)|0)==0){break}else{q=1}i=b;return q|0}}while(0);j=c[3541356]|0;gGC(j|0,l|0,2048)|0;f=j+2048|0;gGC(f|0,o|0,2048)|0;o=c[3541414]|0;p=c[3541472]|0;if((o|0)>0){m=c[1865546]|0;e=0;do{g=e<<6;gGz(p+g|0,0,64);k=0;do{r=g+(c[1238464+(k<<2)>>2]|0)|0;s=(k<<3)+g|0;t=0;do{u=r+(c[614800+(t<<2)>>2]|0)|0;if(((d[j+((u|0)/8|0)|0]|0)&128>>>((u&7)>>>0)|0)!=0){u=p+(s+t)|0;a[u]=a[u]|2}t=t+1|0;}while((t|0)<8);k=k+1|0;}while((k|0)<8);k=m+g|0;t=0;do{s=k+(c[1238464+(t<<2)>>2]|0)|0;r=(t<<3)+g|0;u=0;do{v=s+(c[614800+(u<<2)>>2]|0)|0;if(((d[j+((v|0)/8|0)|0]|0)&128>>>((v&7)>>>0)|0)!=0){v=p+(r+u)|0;a[v]=a[v]|1}u=u+1|0;}while((u|0)<8);t=t+1|0;}while((t|0)<8);e=e+1|0;}while((e|0)<(o|0))}o=l+2048|0;gGC(j|0,o|0,2048)|0;o=l+6144|0;gGC(f|0,o|0,2048)|0;o=c[3541412]|0;f=c[3541364]|0;if((o|0)>0){e=c[1865412]|0;p=0;while(1){m=p<<8;gGz(f+m|0,0,256);t=0;do{g=m+(c[611776+(t<<2)>>2]|0)|0;k=(t<<4)+m|0;u=0;do{r=g+(c[601400+(u<<2)>>2]|0)|0;if(((d[j+((r|0)/8|0)|0]|0)&128>>>((r&7)>>>0)|0)!=0){r=f+(k+u)|0;a[r]=a[r]|2}u=u+1|0;}while((u|0)<16);t=t+1|0;}while((t|0)<16);t=e+m|0;u=0;do{k=t+(c[611776+(u<<2)>>2]|0)|0;g=(u<<4)+m|0;r=0;do{s=k+(c[601400+(r<<2)>>2]|0)|0;if(((d[j+((s|0)/8|0)|0]|0)&128>>>((s&7)>>>0)|0)!=0){s=f+(g+r)|0;a[s]=a[s]|1}r=r+1|0;}while((r|0)<16);u=u+1|0;}while((u|0)<16);u=p+1|0;if((u|0)<(o|0)){p=u}else{w=0;break}}}else{w=0}while(1){if((w|0)>=1024){break}x=9638528+(w<<2)|0;if((c[x>>2]|0)==(j|0)){n=38558;break}else{w=w+1|0}}if((n|0)==38558){gGr(j);c[x>>2]=0}c[3541356]=0;x=0;while(1){if((x|0)>=1024){break}y=9638528+(x<<2)|0;if((c[y>>2]|0)==(l|0)){n=38562;break}else{x=x+1|0}}if((n|0)==38562){gGr(l);c[y>>2]=0}c[3541466]=0;h[1771269]=.2;c[3542574]=3;h[1771270]=.2;c[3542575]=3;h[1771271]=.2;c[3542576]=3;q=0;i=b;return q|0}function aQM(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4856060+(b*112|0)>>2];c[a+104>>2]=c[4856064+(b*112|0)>>2];c[a+108>>2]=c[4856068+(b*112|0)>>2];d=0;return d|0}function aQN(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=4855960+(b*112|0);e=0;return e|0}function aQO(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>5){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6821468+(b*112|0)>>2];c[a+104>>2]=c[6821472+(b*112|0)>>2];c[a+108>>2]=c[6821476+(b*112|0)>>2];d=0;return d|0}function aQP(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<6&(d|0)==0)){e=1;return e|0}c[a>>2]=6821368+(b*112|0);e=0;return e|0}function aQQ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5177312+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aQR(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6822040+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aQS(){var b=0;c[3541404]=5040;a[14165488]=2;b=a04()|0;c[3541466]=0;c[3541392]=0;return b|0}function aQT(b){b=b|0;var c=0,d=0;c=b&65535;if((c|0)==24576){d=((a[14165168]|0)!=0?a[14165875]|0:a[14165872]|0)|a[14165808];return d|0}else if((c|0)==26624){d=((a[14165168]|0)!=0?a[14165876]|0:a[14165873]|0)|a[14165809];return d|0}else if((c|0)==30720){d=-1;return d|0}else if((c|0)==28672){d=((a[14165168]|0)!=0?a[14165877]|0:a[14165874]|0)|a[14165810];return d|0}else{d=0;return d|0}return 0}function aQU(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5375876+(b*112|0)>>2];c[a+104>>2]=c[5375880+(b*112|0)>>2];c[a+108>>2]=c[5375884+(b*112|0)>>2];d=0;return d|0}function aQV(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=5375776+(b*112|0);e=0;return e|0}function aQW(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1884472+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aQX(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>46){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5377232+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aQY(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=i;i=i+480|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;l=b+360|0;m=b+472|0;c[3541404]=9104;c[3541322]=4096;a04()|0;n=0;while(1){if((n|0)>=1024){o=0;break}p=9638528+(n<<2)|0;if((c[p>>2]|0)==0){q=38663;break}else{n=n+1|0}}do{if((q|0)==38663){n=gGq(4096)|0;c[p>>2]=n;if((n|0)==0){o=0;break}gGz(n|0,0,4096);o=n}}while(0);p=0;while(1){if((p|0)>=1024){r=0;break}s=9638528+(p<<2)|0;if((c[s>>2]|0)==0){q=38668;break}else{p=p+1|0}}do{if((q|0)==38668){p=gGq(16384)|0;c[s>>2]=p;if((p|0)==0){r=0;break}gGz(p|0,0,16384);r=p}}while(0);c[3541356]=r;r=(c[3541318]|0)+(c[3541326]|0)+(c[3541312]|0)|0;if((c[3542200]|0)==0){t=1;i=b;return t|0}s=l+108|0;c[s>>2]=0;p=l+100|0;c[p>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,r)|0;do{if((c[s>>2]|0)!=0){l=c[p>>2]|0;c[m>>2]=9534384;n=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[n&16383](m,r,0)|0;if((l|0)<1){t=1;i=b;return t|0}if((gzL(o,0,r)|0)==0){break}else{t=1}i=b;return t|0}}while(0);r=c[3541356]|0;gGC(r|0,o|0,2048)|0;m=r+4096|0;r=o+2048|0;gGC(m|0,r|0,2048)|0;m=(c[3541326]|0)+1+(c[3541318]|0)+(c[3541312]|0)|0;if((c[3542200]|0)==0){t=1;i=b;return t|0}p=j+108|0;c[p>>2]=0;s=j+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,m)|0;do{if((c[p>>2]|0)!=0){j=c[s>>2]|0;c[k>>2]=9534384;l=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[l&16383](k,m,0)|0;if((j|0)<1){t=1;i=b;return t|0}if((gzL(o,0,m)|0)==0){break}else{t=1}i=b;return t|0}}while(0);m=c[3541356]|0;k=m+2048|0;gGC(k|0,o|0,2048)|0;k=m+6144|0;gGC(k|0,r|0,2048)|0;k=(c[3541326]|0)+2+(c[3541318]|0)+(c[3541312]|0)|0;if((c[3542200]|0)==0){t=1;i=b;return t|0}m=g+108|0;c[m>>2]=0;s=g+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,k)|0;do{if((c[m>>2]|0)!=0){g=c[s>>2]|0;c[h>>2]=9534384;p=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[p&16383](h,k,0)|0;if((g|0)<1){t=1;i=b;return t|0}if((gzL(o,0,k)|0)==0){break}else{t=1}i=b;return t|0}}while(0);k=c[3541356]|0;h=k+8192|0;gGC(h|0,o|0,2048)|0;h=k+12288|0;gGC(h|0,r|0,2048)|0;h=(c[3541326]|0)+3+(c[3541318]|0)+(c[3541312]|0)|0;if((c[3542200]|0)==0){t=1;i=b;return t|0}k=e+108|0;c[k>>2]=0;s=e+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,h)|0;do{if((c[k>>2]|0)!=0){e=c[s>>2]|0;c[f>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](f,h,0)|0;if((e|0)<1){t=1;i=b;return t|0}if((gzL(o,0,h)|0)==0){break}else{t=1}i=b;return t|0}}while(0);h=c[3541356]|0;f=h+10240|0;gGC(f|0,o|0,2048)|0;f=h+14336|0;gGC(f|0,r|0,2048)|0;r=c[3541414]|0;f=c[3541472]|0;if((r|0)>0){s=c[1865546]|0;k=0;do{e=k<<6;gGz(f+e|0,0,64);m=0;do{g=e+(c[1238464+(m<<2)>>2]|0)|0;p=(m<<3)+e|0;j=0;do{l=g+(c[614800+(j<<2)>>2]|0)|0;if(((d[h+((l|0)/8|0)|0]|0)&128>>>((l&7)>>>0)|0)!=0){l=f+(p+j)|0;a[l]=a[l]|2}j=j+1|0;}while((j|0)<8);m=m+1|0;}while((m|0)<8);m=s+e|0;j=0;do{p=m+(c[1238464+(j<<2)>>2]|0)|0;g=(j<<3)+e|0;l=0;do{n=p+(c[614800+(l<<2)>>2]|0)|0;if(((d[h+((n|0)/8|0)|0]|0)&128>>>((n&7)>>>0)|0)!=0){n=f+(g+l)|0;a[n]=a[n]|1}l=l+1|0;}while((l|0)<8);j=j+1|0;}while((j|0)<8);k=k+1|0;}while((k|0)<(r|0))}r=c[3541412]|0;k=c[3541364]|0;if((r|0)>0){f=c[1865412]|0;s=0;while(1){j=s<<8;gGz(k+j|0,0,256);e=0;do{m=j+(c[611776+(e<<2)>>2]|0)|0;l=(e<<4)+j|0;g=0;do{p=m+(c[601400+(g<<2)>>2]|0)|0;if(((d[h+((p|0)/8|0)|0]|0)&128>>>((p&7)>>>0)|0)!=0){p=k+(l+g)|0;a[p]=a[p]|2}g=g+1|0;}while((g|0)<16);e=e+1|0;}while((e|0)<16);e=f+j|0;g=0;do{l=e+(c[611776+(g<<2)>>2]|0)|0;m=(g<<4)+j|0;p=0;do{n=l+(c[601400+(p<<2)>>2]|0)|0;if(((d[h+((n|0)/8|0)|0]|0)&128>>>((n&7)>>>0)|0)!=0){n=k+(m+p)|0;a[n]=a[n]|1}p=p+1|0;}while((p|0)<16);g=g+1|0;}while((g|0)<16);g=s+1|0;if((g|0)<(r|0)){s=g}else{u=0;break}}}else{u=0}while(1){if((u|0)>=1024){break}v=9638528+(u<<2)|0;if((c[v>>2]|0)==(h|0)){q=38706;break}else{u=u+1|0}}if((q|0)==38706){gGr(h);c[v>>2]=0}c[3541356]=0;v=0;while(1){if((v|0)>=1024){break}w=9638528+(v<<2)|0;if((c[w>>2]|0)==(o|0)){q=38710;break}else{v=v+1|0}}if((q|0)==38710){gGr(o);c[w>>2]=0}c[3541462]=62;c[3541464]=46;a[14165472]=7;a[14165480]=-10;a[7461864]=1;t=0;i=b;return t|0}function aQZ(b){b=b|0;var c=0,e=0;c=b&65535;if((c|0)==24576){e=a[14165872]|a[14165808];return e|0}else if((c|0)==26624){e=a[(d[14166040]|0)+14165875|0]&-64|(a[14165873]|a[14165809])&63;return e|0}else if((c|0)==28672){e=a[(d[14166040]|0)+14165875|0]&59|(a[14165874]|a[14165810])&4;return e|0}else{e=-1;return e|0}return 0}function aQ_(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0.0,o=0.0,p=0.0,q=0.0,r=0.0,s=0.0,t=0.0,u=0.0;e=b&65535;if((b&65535)<16384){return}if((b-22528&65535)<256){b=e-22528|0;a[(c[3541366]|0)+b|0]=d;if(!((b|0)<64&(b&1|0)==0)){return}a[(c[3541380]|0)+(b>>1)|0]=d;return}switch(e|0){case 32768:{b=d&3;a[14166040]=b;f=c[3541328]|0;g=(b&255)<<14|8192;b=c[9757320+(c[1836236]<<2)>>2]|0;i=0;j=0;while(1){c[b+76+(j<<2)>>2]=f+((j<<8)+g);k=i+1&65535;if((k&65535)>63){l=0;m=0;break}else{i=k;j=k&65535}}while(1){j=f+((m<<8)+g)|0;c[b+76+(m+512<<2)>>2]=j;c[b+76+(m+768<<2)>>2]=j;j=l+1&65535;if((j&65535)>63){break}else{l=j;m=j&65535}}return};case 28678:{a[14165832]=d&1;return};case 28679:{a[14165824]=d&1;return};case 30720:{c[3541406]=d&255;return};case 28673:{a[14165768]=d&1;return};case 28676:{m=d&1;c[3541360]=m;if((m|0)!=0){return}c[3541358]=-1;return};case 24580:case 24581:case 24582:case 24583:{m=d&1;l=14165736+(e-24580<<2)|0;if((m|0)==(c[l>>2]|0)){return}c[l>>2]=m;m=(c[3541434]|0)==0;n=m?4030303030303031.0e-21:30303030303030305.0e-22;o=m?1.0e-12:1000001.0e-12;if((c[3541435]|0)==0){p=o;q=n+21276595744680853.0e-22}else{p=o+21276595744680853.0e-22;q=n}if((c[3541436]|0)==0){r=p;s=q+45454545454545455.0e-22}else{r=p+45454545454545455.0e-22;s=q}if((c[3541437]|0)==0){t=r;u=s+1.0e-5}else{t=r+1.0e-5;u=s}s=1.0/u;h[932738]=1.0e9/((s*2.0e6/(s+1.0/t)+1.0e5)*58788.0)*100.0;return};case 26624:case 26625:case 26626:case 26627:case 26628:case 26629:case 26630:case 26631:{m=e-26624|0;e=d&1;switch(m&7|0){case 7:case 6:{l=m&1;c[3541336]=c[3541336]&~(1<<l)|(d&1)<<l;return};case 5:{do{if(e<<24>>24!=0){if((a[14165752]&1)!=0){break}a[14165512]=1;h[932735]=0.0}}while(0);a[14165752]=e;return};case 3:{a[14165672]=e;if(e<<24>>24==0){return}c[3541416]=100;h[932737]=0.0;return};case 0:case 1:case 2:{c[14165720+(m<<2)>>2]=e&255;return};default:{return}}break};default:{return}}}function aQ$(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>24){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5401100+(b*112|0)>>2];c[a+104>>2]=c[5401104+(b*112|0)>>2];c[a+108>>2]=c[5401108+(b*112|0)>>2];d=0;return d|0}function aQ0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<25&(d|0)==0)){e=1;return e|0}c[a>>2]=5401e3+(b*112|0);e=0;return e|0}function aQ1(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1918320+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aQ2(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>46){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5403800+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aQ3(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;b=i;i=i+960|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;l=b+360|0;m=b+472|0;n=b+480|0;o=b+592|0;p=b+600|0;q=b+712|0;r=b+720|0;s=b+832|0;t=b+840|0;u=b+952|0;a[14166040]=0;c[3541404]=2804;c[3541322]=8192;c[3541348]=4096;a04()|0;c[3541414]=1024;c[3541412]=256;c[1865546]=65536;c[1865412]=65536;v=0;while(1){if((v|0)>=1024){w=0;break}x=9638528+(v<<2)|0;if((c[x>>2]|0)==0){y=38830;break}else{v=v+1|0}}do{if((y|0)==38830){v=gGq(4096)|0;c[x>>2]=v;if((v|0)==0){w=0;break}gGz(v|0,0,4096);w=v}}while(0);x=c[3541348]|0;v=0;while(1){if((v|0)>=1024){z=0;break}A=9638528+(v<<2)|0;if((c[A>>2]|0)==0){y=38835;break}else{v=v+1|0}}do{if((y|0)==38835){v=gGq(x)|0;c[A>>2]=v;if((v|0)==0){z=0;break}gGz(v|0,0,x|0);z=v}}while(0);c[3541356]=z;z=(c[3541318]|0)+(c[3541326]|0)+(c[3541312]|0)|0;if((c[3542200]|0)==0){B=1;i=b;return B|0}x=t+108|0;c[x>>2]=0;A=t+100|0;c[A>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,z)|0;do{if((c[x>>2]|0)!=0){t=c[A>>2]|0;c[u>>2]=9534384;v=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[v&16383](u,z,0)|0;if((t|0)<1){B=1;i=b;return B|0}if((gzL(w,0,z)|0)==0){break}else{B=1}i=b;return B|0}}while(0);z=c[3541356]|0;u=z+16384|0;gGC(u|0,w|0,2048)|0;u=w+2048|0;gGC(z|0,u|0,2048)|0;z=(c[3541326]|0)+1+(c[3541318]|0)+(c[3541312]|0)|0;if((c[3542200]|0)==0){B=1;i=b;return B|0}A=r+108|0;c[A>>2]=0;x=r+100|0;c[x>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,z)|0;do{if((c[A>>2]|0)!=0){r=c[x>>2]|0;c[s>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](s,z,0)|0;if((r|0)<1){B=1;i=b;return B|0}if((gzL(w,0,z)|0)==0){break}else{B=1}i=b;return B|0}}while(0);z=c[3541356]|0;s=z+24576|0;gGC(s|0,w|0,2048)|0;s=z+8192|0;gGC(s|0,u|0,2048)|0;s=(c[3541326]|0)+2+(c[3541318]|0)+(c[3541312]|0)|0;if((c[3542200]|0)==0){B=1;i=b;return B|0}z=p+108|0;c[z>>2]=0;x=p+100|0;c[x>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,s)|0;do{if((c[z>>2]|0)!=0){p=c[x>>2]|0;c[q>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](q,s,0)|0;if((p|0)<1){B=1;i=b;return B|0}if((gzL(w,0,s)|0)==0){break}else{B=1}i=b;return B|0}}while(0);s=c[3541356]|0;q=s+18432|0;gGC(q|0,w|0,2048)|0;q=s+2048|0;gGC(q|0,w|0,2048)|0;q=(c[3541326]|0)+3+(c[3541318]|0)+(c[3541312]|0)|0;if((c[3542200]|0)==0){B=1;i=b;return B|0}s=n+108|0;c[s>>2]=0;x=n+100|0;c[x>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,q)|0;do{if((c[s>>2]|0)!=0){n=c[x>>2]|0;c[o>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](o,q,0)|0;if((n|0)<1){B=1;i=b;return B|0}if((gzL(w,0,q)|0)==0){break}else{B=1}i=b;return B|0}}while(0);q=c[3541356]|0;o=q+26624|0;gGC(o|0,w|0,2048)|0;o=q+10240|0;gGC(o|0,w|0,2048)|0;o=(c[3541326]|0)+4+(c[3541318]|0)+(c[3541312]|0)|0;if((c[3542200]|0)==0){B=1;i=b;return B|0}q=l+108|0;c[q>>2]=0;x=l+100|0;c[x>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,o)|0;do{if((c[q>>2]|0)!=0){l=c[x>>2]|0;c[m>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](m,o,0)|0;if((l|0)<1){B=1;i=b;return B|0}if((gzL(w,0,o)|0)==0){break}else{B=1}i=b;return B|0}}while(0);o=c[3541356]|0;m=o+20480|0;gGC(m|0,w|0,2048)|0;m=o+4096|0;gGC(m|0,u|0,2048)|0;m=(c[3541326]|0)+5+(c[3541318]|0)+(c[3541312]|0)|0;if((c[3542200]|0)==0){B=1;i=b;return B|0}o=j+108|0;c[o>>2]=0;x=j+100|0;c[x>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,m)|0;do{if((c[o>>2]|0)!=0){j=c[x>>2]|0;c[k>>2]=9534384;q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[q&16383](k,m,0)|0;if((j|0)<1){B=1;i=b;return B|0}if((gzL(w,0,m)|0)==0){break}else{B=1}i=b;return B|0}}while(0);m=c[3541356]|0;k=m+28672|0;gGC(k|0,w|0,2048)|0;k=m+12288|0;gGC(k|0,u|0,2048)|0;k=(c[3541326]|0)+6+(c[3541318]|0)+(c[3541312]|0)|0;if((c[3542200]|0)==0){B=1;i=b;return B|0}m=g+108|0;c[m>>2]=0;x=g+100|0;c[x>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,k)|0;do{if((c[m>>2]|0)!=0){g=c[x>>2]|0;c[h>>2]=9534384;o=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[o&16383](h,k,0)|0;if((g|0)<1){B=1;i=b;return B|0}if((gzL(w,0,k)|0)==0){break}else{B=1}i=b;return B|0}}while(0);k=c[3541356]|0;h=k+22528|0;gGC(h|0,w|0,2048)|0;h=k+6144|0;gGC(h|0,u|0,2048)|0;h=(c[3541326]|0)+7+(c[3541318]|0)+(c[3541312]|0)|0;if((c[3542200]|0)==0){B=1;i=b;return B|0}k=e+108|0;c[k>>2]=0;x=e+100|0;c[x>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,h)|0;do{if((c[k>>2]|0)!=0){e=c[x>>2]|0;c[f>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](f,h,0)|0;if((e|0)<1){B=1;i=b;return B|0}if((gzL(w,0,h)|0)==0){break}else{B=1}i=b;return B|0}}while(0);h=c[3541356]|0;f=h+30720|0;gGC(f|0,w|0,2048)|0;f=h+14336|0;gGC(f|0,u|0,2048)|0;u=c[3541414]|0;f=c[3541472]|0;if((u|0)>0){x=c[1865546]|0;k=0;do{e=k<<6;gGz(f+e|0,0,64);m=0;do{g=e+(c[1238464+(m<<2)>>2]|0)|0;o=(m<<3)+e|0;j=0;do{q=g+(c[614800+(j<<2)>>2]|0)|0;if(((d[h+((q|0)/8|0)|0]|0)&128>>>((q&7)>>>0)|0)!=0){q=f+(o+j)|0;a[q]=a[q]|2}j=j+1|0;}while((j|0)<8);m=m+1|0;}while((m|0)<8);m=x+e|0;j=0;do{o=m+(c[1238464+(j<<2)>>2]|0)|0;g=(j<<3)+e|0;q=0;do{l=o+(c[614800+(q<<2)>>2]|0)|0;if(((d[h+((l|0)/8|0)|0]|0)&128>>>((l&7)>>>0)|0)!=0){l=f+(g+q)|0;a[l]=a[l]|1}q=q+1|0;}while((q|0)<8);j=j+1|0;}while((j|0)<8);k=k+1|0;}while((k|0)<(u|0))}u=c[3541412]|0;k=c[3541364]|0;if((u|0)>0){f=c[1865412]|0;x=0;while(1){j=x<<8;gGz(k+j|0,0,256);e=0;do{m=j+(c[611776+(e<<2)>>2]|0)|0;q=(e<<4)+j|0;g=0;do{o=m+(c[601400+(g<<2)>>2]|0)|0;if(((d[h+(((o|0)/8|0)+16384)|0]|0)&128>>>((o&7)>>>0)|0)!=0){o=k+(q+g)|0;a[o]=a[o]|2}g=g+1|0;}while((g|0)<16);e=e+1|0;}while((e|0)<16);e=f+j|0;g=0;do{q=e+(c[611776+(g<<2)>>2]|0)|0;m=(g<<4)+j|0;o=0;do{l=q+(c[601400+(o<<2)>>2]|0)|0;if(((d[h+(((l|0)/8|0)+16384)|0]|0)&128>>>((l&7)>>>0)|0)!=0){l=k+(m+o)|0;a[l]=a[l]|1}o=o+1|0;}while((o|0)<16);g=g+1|0;}while((g|0)<16);g=x+1|0;if((g|0)<(u|0)){x=g}else{C=0;break}}}else{C=0}while(1){if((C|0)>=1024){break}D=9638528+(C<<2)|0;if((c[D>>2]|0)==(h|0)){y=38889;break}else{C=C+1|0}}if((y|0)==38889){gGr(h);c[D>>2]=0}c[3541356]=0;D=0;while(1){if((D|0)>=1024){break}E=9638528+(D<<2)|0;if((c[E>>2]|0)==(w|0)){y=38893;break}else{D=D+1|0}}if((y|0)==38893){gGr(w);c[E>>2]=0}c[3541462]=8;c[3541464]=60;a[14165472]=7;a[14165480]=-10;B=0;i=b;return B|0}function aQ4(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3705356+(b*112|0)>>2];c[a+104>>2]=c[3705360+(b*112|0)>>2];c[a+108>>2]=c[3705364+(b*112|0)>>2];d=0;return d|0}function aQ5(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=3705256+(b*112|0);e=0;return e|0}function aQ6(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3706712+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aQ7(){var a=0;c[3541404]=7234;a=a04()|0;c[3541462]=114;c[3541464]=42;return a|0}function aQ8(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1228780+(b*112|0)>>2];c[a+104>>2]=c[1228784+(b*112|0)>>2];c[a+108>>2]=c[1228788+(b*112|0)>>2];d=0;return d|0}function aQ9(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=1228680+(b*112|0);e=0;return e|0}function aRa(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[964348+(b*112|0)>>2];c[a+104>>2]=c[964352+(b*112|0)>>2];c[a+108>>2]=c[964356+(b*112|0)>>2];d=0;return d|0}function aRb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=964248+(b*112|0);e=0;return e|0}function aRc(){var a=0;c[3541404]=2258;a=a04()|0;c[3541462]=114;c[3541464]=42;return a|0}function aRd(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1822076+(b*112|0)>>2];c[a+104>>2]=c[1822080+(b*112|0)>>2];c[a+108>>2]=c[1822084+(b*112|0)>>2];d=0;return d|0}function aRe(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=1821976+(b*112|0);e=0;return e|0}function aRf(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1823532+(b*112|0)>>2];c[a+104>>2]=c[1823536+(b*112|0)>>2];c[a+108>>2]=c[1823540+(b*112|0)>>2];d=0;return d|0}function aRg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=1823432+(b*112|0);e=0;return e|0}function aRh(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3710384+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aRi(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1824988+(b*112|0)>>2];c[a+104>>2]=c[1824992+(b*112|0)>>2];c[a+108>>2]=c[1824996+(b*112|0)>>2];d=0;return d|0}function aRj(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=1824888+(b*112|0);e=0;return e|0}function aRk(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3708696+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aRl(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,i=0.0,j=0.0,k=0.0,l=0.0,m=0.0,n=0.0,o=0.0,p=0.0;e=b&65535;if((b-22528&65535)<256){b=e-22528|0;a[(c[3541366]|0)+b|0]=d;if(!((b|0)<64&(b&1|0)==0)){return}a[(c[3541380]|0)+(b>>1)|0]=d;return}switch(e|0){case 28673:{a[14165768]=d&1;return};case 28676:{b=d&1;c[3541360]=b;if((b|0)!=0){return}c[3541358]=-1;return};case 30720:{c[3541406]=d&255;return};case 24576:case 24577:case 24578:{a[(c[3541454]|0)+(e-24576)|0]=d;return};case 28678:{a[14165832]=d&1;return};case 28679:{a[14165824]=d&1;return};case 26624:case 26625:case 26626:case 26627:case 26628:case 26629:case 26630:case 26631:{b=e-26624|0;f=d&1;switch(b&7|0){case 0:case 1:case 2:{c[14165720+(b<<2)>>2]=f&255;return};case 3:{a[14165672]=f;if(f<<24>>24==0){return}c[3541416]=100;h[932737]=0.0;return};case 7:case 6:{g=b&1;c[3541336]=c[3541336]&~(1<<g)|(d&1)<<g;return};case 5:{do{if(f<<24>>24!=0){if((a[14165752]&1)!=0){break}a[14165512]=1;h[932735]=0.0}}while(0);a[14165752]=f;return};default:{return}}break};case 24580:case 24581:case 24582:case 24583:{f=d&1;d=14165736+(e-24580<<2)|0;if((f|0)==(c[d>>2]|0)){return}c[d>>2]=f;f=(c[3541434]|0)==0;i=f?4030303030303031.0e-21:30303030303030305.0e-22;j=f?1.0e-12:1000001.0e-12;if((c[3541435]|0)==0){k=j;l=i+21276595744680853.0e-22}else{k=j+21276595744680853.0e-22;l=i}if((c[3541436]|0)==0){m=k;n=l+45454545454545455.0e-22}else{m=k+45454545454545455.0e-22;n=l}if((c[3541437]|0)==0){o=m;p=n+1.0e-5}else{o=m+1.0e-5;p=n}n=1.0/p;h[932738]=1.0e9/((n*2.0e6/(n+1.0/o)+1.0e5)*58788.0)*100.0;return};default:{return}}}function aRm(b,d){b=b|0;d=d|0;var e=0,f=0,g=0.0,i=0.0,j=0.0,k=0.0,l=0.0,m=0.0,n=0.0,o=0.0;e=b&65535;if((b+26624&65535)<256){b=e-38912|0;a[(c[3541366]|0)+b|0]=d;if(!((b|0)<64&(b&1|0)==0)){return}a[(c[3541380]|0)+(b>>1)|0]=d;return}switch(e|0){case 40964:case 40965:case 40966:case 40967:{b=d&1;f=14165736+(e-40964<<2)|0;if((b|0)==(c[f>>2]|0)){return}c[f>>2]=b;b=(c[3541434]|0)==0;g=b?4030303030303031.0e-21:30303030303030305.0e-22;i=b?1.0e-12:1000001.0e-12;if((c[3541435]|0)==0){j=i;k=g+21276595744680853.0e-22}else{j=i+21276595744680853.0e-22;k=g}if((c[3541436]|0)==0){l=j;m=k+45454545454545455.0e-22}else{l=j+45454545454545455.0e-22;m=k}if((c[3541437]|0)==0){n=l;o=m+1.0e-5}else{n=l+1.0e-5;o=m}m=1.0/o;h[932738]=1.0e9/((m*2.0e6/(m+1.0/n)+1.0e5)*58788.0)*100.0;return};case 40960:case 40961:case 40962:{a[(c[3541454]|0)+(e-40960)|0]=d;return};case 43008:case 43009:case 43010:case 43011:case 43012:case 43013:case 43014:case 43015:{b=e-43008|0;e=d&1;switch(b&7|0){case 7:case 6:{f=b&1;c[3541336]=c[3541336]&~(1<<f)|(d&1)<<f;return};case 0:case 1:case 2:{c[14165720+(b<<2)>>2]=e&255;return};case 3:{a[14165672]=e;if(e<<24>>24==0){return}c[3541416]=100;h[932737]=0.0;return};case 5:{do{if(e<<24>>24!=0){if((a[14165752]&1)!=0){break}a[14165512]=1;h[932735]=0.0}}while(0);a[14165752]=e;return};default:{return}}break};case 45062:{a[14165832]=d&1;return};case 45056:{a[14165768]=d&1;return};case 45060:{e=d&1;c[3541360]=e;if((e|0)!=0){return}c[3541358]=-1;return};case 45063:{a[14165824]=d&1;return};case 47104:{c[3541406]=d&255;return};default:{return}}}function aRn(b,d){b=b|0;d=d|0;var e=0,f=0,g=0.0,i=0.0,j=0.0,k=0.0,l=0.0,m=0.0,n=0.0,o=0.0;e=b&65535;if((b+26624&65535)<256){b=e-38912|0;a[(c[3541366]|0)+b|0]=d;if(!((b|0)<64&(b&1|0)==0)){return}a[(c[3541380]|0)+(b>>1)|0]=d;return}switch(e|0){case 40960:case 40961:case 40962:{a[(c[3541454]|0)+(e-40960)|0]=d;return};case 40964:case 40965:case 40966:case 40967:{b=d&1;f=14165736+(e-40964<<2)|0;if((b|0)==(c[f>>2]|0)){return}c[f>>2]=b;b=(c[3541434]|0)==0;g=b?4030303030303031.0e-21:30303030303030305.0e-22;i=b?1.0e-12:1000001.0e-12;if((c[3541435]|0)==0){j=i;k=g+21276595744680853.0e-22}else{j=i+21276595744680853.0e-22;k=g}if((c[3541436]|0)==0){l=j;m=k+45454545454545455.0e-22}else{l=j+45454545454545455.0e-22;m=k}if((c[3541437]|0)==0){n=l;o=m+1.0e-5}else{n=l+1.0e-5;o=m}m=1.0/o;h[932738]=1.0e9/((m*2.0e6/(m+1.0/n)+1.0e5)*58788.0)*100.0;return};case 43008:case 43009:case 43010:case 43011:case 43012:case 43013:case 43014:case 43015:{b=e-43008|0;e=d&1;switch(b&7|0){case 0:case 1:case 2:{c[14165720+(b<<2)>>2]=e&255;return};case 3:{a[14165672]=e;if(e<<24>>24==0){return}c[3541416]=100;h[932737]=0.0;return};case 5:{do{if(e<<24>>24!=0){if((a[14165752]&1)!=0){break}a[14165512]=1;h[932735]=0.0}}while(0);a[14165752]=e;return};case 7:case 6:{e=b&1;c[3541336]=c[3541336]&~(1<<e)|(d&1)<<e;return};default:{return}}break};case 45057:{a[14165768]=d&1;return};case 45062:{a[14165832]=d&1;return};case 45063:{a[14165824]=d&1;return};case 47104:{c[3541406]=d&255;return};default:{return}}}function aRo(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3709028+(b*112|0)>>2];c[a+104>>2]=c[3709032+(b*112|0)>>2];c[a+108>>2]=c[3709036+(b*112|0)>>2];d=0;return d|0}function aRp(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=3708928+(b*112|0);e=0;return e|0}function aRq(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3712484+(b*112|0)>>2];c[a+104>>2]=c[3712488+(b*112|0)>>2];c[a+108>>2]=c[3712492+(b*112|0)>>2];d=0;return d|0}function aRr(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=3712384+(b*112|0);e=0;return e|0}function aRs(){var a=0;c[3541404]=2258;a=a04()|0;a0d();c[3541462]=114;c[3541464]=42;return a|0}function aRt(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3711476+(b*112|0)>>2];c[a+104>>2]=c[3711480+(b*112|0)>>2];c[a+108>>2]=c[3711484+(b*112|0)>>2];d=0;return d|0}function aRu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=3711376+(b*112|0);e=0;return e|0}function aRv(){var a=0;c[3541404]=12928;a=a04()|0;a0d();c[3541462]=114;c[3541464]=42;return a|0}function aRw(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3710692+(b*112|0)>>2];c[a+104>>2]=c[3710696+(b*112|0)>>2];c[a+108>>2]=c[3710700+(b*112|0)>>2];d=0;return d|0}function aRx(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=3710592+(b*112|0);e=0;return e|0}function aRy(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;b=i;i=i+240|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;c[3541404]=2258;j=a04()|0;k=0;while(1){if((k|0)>=1024){l=0;break}m=9638528+(k<<2)|0;if((c[m>>2]|0)==0){n=39227;break}else{k=k+1|0}}do{if((n|0)==39227){k=gGq(4096)|0;c[m>>2]=k;if((k|0)==0){l=0;break}gGz(k|0,0,4096);l=k}}while(0);m=c[3541348]|0;k=0;while(1){if((k|0)>=1024){o=0;break}p=9638528+(k<<2)|0;if((c[p>>2]|0)==0){n=39232;break}else{k=k+1|0}}do{if((n|0)==39232){k=gGq(m)|0;c[p>>2]=k;if((k|0)==0){o=0;break}gGz(k|0,0,m|0);o=k}}while(0);c[3541356]=o;o=(c[3541318]|0)+(c[3541326]|0)+(c[3541312]|0)|0;do{if((c[3542200]|0)!=0){m=g+108|0;c[m>>2]=0;p=g+100|0;c[p>>2]=0;k=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[k&16383](g,o)|0;if((c[m>>2]|0)==0){break}m=c[p>>2]|0;c[h>>2]=9534384;p=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[p&16383](h,o,0)|0;if((m|0)<1){break}gzL(l,0,o)|0}}while(0);o=c[3541356]|0;h=o+2048|0;gGC(h|0,l|0,512)|0;h=o+3072|0;g=l+512|0;gGC(h|0,g|0,512)|0;h=o+2560|0;m=l+1024|0;gGC(h|0,m|0,512)|0;h=o+3584|0;p=l+1536|0;gGC(h|0,p|0,512)|0;h=l+2048|0;gGC(o|0,h|0,2048)|0;o=(c[3541326]|0)+1+(c[3541318]|0)+(c[3541312]|0)|0;do{if((c[3542200]|0)!=0){k=e+108|0;c[k>>2]=0;q=e+100|0;c[q>>2]=0;r=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[r&16383](e,o)|0;if((c[k>>2]|0)==0){break}k=c[q>>2]|0;c[f>>2]=9534384;q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[q&16383](f,o,0)|0;if((k|0)<1){break}gzL(l,0,o)|0}}while(0);o=c[3541356]|0;f=o+6144|0;gGC(f|0,l|0,512)|0;f=o+7168|0;gGC(f|0,g|0,512)|0;g=o+6656|0;gGC(g|0,m|0,512)|0;m=o+7680|0;gGC(m|0,p|0,512)|0;p=o+4096|0;gGC(p|0,h|0,2048)|0;h=0;while(1){if((h|0)>=1024){s=o;break}t=9638528+(h<<2)|0;if((c[t>>2]|0)==(l|0)){n=39245;break}else{h=h+1|0}}if((n|0)==39245){gGr(l);c[t>>2]=0;s=c[3541356]|0}t=c[3541414]|0;l=c[3541472]|0;if((t|0)>0){h=c[1865546]|0;o=0;do{p=o<<6;gGz(l+p|0,0,64);m=0;do{g=p+(c[1238464+(m<<2)>>2]|0)|0;f=(m<<3)+p|0;e=0;do{k=g+(c[614800+(e<<2)>>2]|0)|0;if(((d[s+((k|0)/8|0)|0]|0)&128>>>((k&7)>>>0)|0)!=0){k=l+(f+e)|0;a[k]=a[k]|2}e=e+1|0;}while((e|0)<8);m=m+1|0;}while((m|0)<8);m=h+p|0;e=0;do{f=m+(c[1238464+(e<<2)>>2]|0)|0;g=(e<<3)+p|0;k=0;do{q=f+(c[614800+(k<<2)>>2]|0)|0;if(((d[s+((q|0)/8|0)|0]|0)&128>>>((q&7)>>>0)|0)!=0){q=l+(g+k)|0;a[q]=a[q]|1}k=k+1|0;}while((k|0)<8);e=e+1|0;}while((e|0)<8);o=o+1|0;}while((o|0)<(t|0))}t=c[3541412]|0;o=c[3541364]|0;if((t|0)>0){l=c[1865412]|0;h=0;while(1){e=h<<8;gGz(o+e|0,0,256);p=0;do{m=e+(c[611776+(p<<2)>>2]|0)|0;k=(p<<4)+e|0;g=0;do{f=m+(c[601400+(g<<2)>>2]|0)|0;if(((d[s+((f|0)/8|0)|0]|0)&128>>>((f&7)>>>0)|0)!=0){f=o+(k+g)|0;a[f]=a[f]|2}g=g+1|0;}while((g|0)<16);p=p+1|0;}while((p|0)<16);p=l+e|0;g=0;do{k=p+(c[611776+(g<<2)>>2]|0)|0;m=(g<<4)+e|0;f=0;do{q=k+(c[601400+(f<<2)>>2]|0)|0;if(((d[s+((q|0)/8|0)|0]|0)&128>>>((q&7)>>>0)|0)!=0){q=o+(m+f)|0;a[q]=a[q]|1}f=f+1|0;}while((f|0)<16);g=g+1|0;}while((g|0)<16);g=h+1|0;if((g|0)<(t|0)){h=g}else{u=0;break}}}else{u=0}while(1){if((u|0)>=1024){n=39280;break}v=9638528+(u<<2)|0;if((c[v>>2]|0)==(s|0)){break}else{u=u+1|0}}if((n|0)==39280){c[3541356]=0;c[3541462]=114;c[3541464]=42;i=b;return j|0}gGr(s);c[v>>2]=0;c[3541356]=0;c[3541462]=114;c[3541464]=42;i=b;return j|0}function aRz(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3991700+(b*112|0)>>2];c[a+104>>2]=c[3991704+(b*112|0)>>2];c[a+108>>2]=c[3991708+(b*112|0)>>2];d=0;return d|0}function aRA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=3991600+(b*112|0);e=0;return e|0}function aRB(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3993056+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aRC(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6891172+(b*112|0)>>2];c[a+104>>2]=c[6891176+(b*112|0)>>2];c[a+108>>2]=c[6891180+(b*112|0)>>2];d=0;return d|0}function aRD(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=6891072+(b*112|0);e=0;return e|0}function aRE(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6326460+(b*112|0)>>2];c[a+104>>2]=c[6326464+(b*112|0)>>2];c[a+108>>2]=c[6326468+(b*112|0)>>2];d=0;return d|0}function aRF(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=6326360+(b*112|0);e=0;return e|0}function aRG(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6327816+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aRH(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6325004+(b*112|0)>>2];c[a+104>>2]=c[6325008+(b*112|0)>>2];c[a+108>>2]=c[6325012+(b*112|0)>>2];d=0;return d|0}function aRI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=6324904+(b*112|0);e=0;return e|0}function aRJ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3394884+(b*112|0)>>2];c[a+104>>2]=c[3394888+(b*112|0)>>2];c[a+108>>2]=c[3394892+(b*112|0)>>2];d=0;return d|0}function aRK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=3394784+(b*112|0);e=0;return e|0}function aRL(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3424292+(b*112|0)>>2];c[a+104>>2]=c[3424296+(b*112|0)>>2];c[a+108>>2]=c[3424300+(b*112|0)>>2];d=0;return d|0}function aRM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=3424192+(b*112|0);e=0;return e|0}function aRN(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1192280+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aRO(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3425648+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aRP(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3717348+(b*112|0)>>2];c[a+104>>2]=c[3717352+(b*112|0)>>2];c[a+108>>2]=c[3717356+(b*112|0)>>2];d=0;return d|0}function aRQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=3717248+(b*112|0);e=0;return e|0}function aRR(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3718704+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aRS(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3369252+(b*112|0)>>2];c[a+104>>2]=c[3369256+(b*112|0)>>2];c[a+108>>2]=c[3369260+(b*112|0)>>2];d=0;return d|0}function aRT(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=3369152+(b*112|0);e=0;return e|0}function aRU(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5264316+(b*112|0)>>2];c[a+104>>2]=c[5264320+(b*112|0)>>2];c[a+108>>2]=c[5264324+(b*112|0)>>2];d=0;return d|0}function aRV(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=5264216+(b*112|0);e=0;return e|0}function aRW(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3366012+(b*112|0)>>2];c[a+104>>2]=c[3366016+(b*112|0)>>2];c[a+108>>2]=c[3366020+(b*112|0)>>2];d=0;return d|0}function aRX(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=3365912+(b*112|0);e=0;return e|0}function aRY(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4972468+(b*112|0)>>2];c[a+104>>2]=c[4972472+(b*112|0)>>2];c[a+108>>2]=c[4972476+(b*112|0)>>2];d=0;return d|0}function aRZ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=4972368+(b*112|0);e=0;return e|0}function aR_(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3397052+(b*112|0)>>2];c[a+104>>2]=c[3397056+(b*112|0)>>2];c[a+108>>2]=c[3397060+(b*112|0)>>2];d=0;return d|0}function aR$(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=3396952+(b*112|0);e=0;return e|0}function aR0(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3715580+(b*112|0)>>2];c[a+104>>2]=c[3715584+(b*112|0)>>2];c[a+108>>2]=c[3715588+(b*112|0)>>2];d=0;return d|0}function aR1(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=3715480+(b*112|0);e=0;return e|0}function aR2(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>25){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3716936+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aR3(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3707076+(b*112|0)>>2];c[a+104>>2]=c[3707080+(b*112|0)>>2];c[a+108>>2]=c[3707084+(b*112|0)>>2];d=0;return d|0}function aR4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=3706976+(b*112|0);e=0;return e|0}function aR5(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3708432+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aR6(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6671916+(b*112|0)>>2];c[a+104>>2]=c[6671920+(b*112|0)>>2];c[a+108>>2]=c[6671924+(b*112|0)>>2];d=0;return d|0}function aR7(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=6671816+(b*112|0);e=0;return e|0}function aR8(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3713940+(b*112|0)>>2];c[a+104>>2]=c[3713944+(b*112|0)>>2];c[a+108>>2]=c[3713948+(b*112|0)>>2];d=0;return d|0}function aR9(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=3713840+(b*112|0);e=0;return e|0}function aSa(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3715296+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aSb(){var a=0;c[3541404]=884;a=a04()|0;c[3541462]=114;c[3541464]=42;return a|0}function aSc(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5262604+(b*112|0)>>2];c[a+104>>2]=c[5262608+(b*112|0)>>2];c[a+108>>2]=c[5262612+(b*112|0)>>2];d=0;return d|0}function aSd(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=5262504+(b*112|0);e=0;return e|0}function aSe(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5263960+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aSf(){var a=0,b=0,d=0,e=0;a=0;while(1){if((a|0)>=1024){b=0;break}d=9638528+(a<<2)|0;if((c[d>>2]|0)==0){e=39553;break}else{a=a+1|0}}do{if((e|0)==39553){a=gGq(16384)|0;c[d>>2]=a;if((a|0)==0){b=0;break}gGz(a|0,0,16384);b=a}}while(0);c[3541324]=b;c[3541404]=3598;b=a04()|0;c[3541462]=10;c[3541464]=76;return b|0}function aSg(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5266444+(b*112|0)>>2];c[a+104>>2]=c[5266448+(b*112|0)>>2];c[a+108>>2]=c[5266452+(b*112|0)>>2];d=0;return d|0}function aSh(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=5266344+(b*112|0);e=0;return e|0}function aSi(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5267912+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aSj(){c[3541404]=2258;return a04()|0}function aSk(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3719068+(b*112|0)>>2];c[a+104>>2]=c[3719072+(b*112|0)>>2];c[a+108>>2]=c[3719076+(b*112|0)>>2];d=0;return d|0}function aSl(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=3718968+(b*112|0);e=0;return e|0}function aSm(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4927900+(b*112|0)>>2];c[a+104>>2]=c[4927904+(b*112|0)>>2];c[a+108>>2]=c[4927908+(b*112|0)>>2];d=0;return d|0}function aSn(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=4927800+(b*112|0);e=0;return e|0}function aSo(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1665576+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aSp(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4929144+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aSq(){var a=0;c[3541404]=10756;a=a04()|0;c[3541462]=114;c[3541464]=42;return a|0}function aSr(b){b=b|0;var c=0,d=0;c=b&65535;if((c|0)==40960){d=a[14165872]|a[14165808]}else if((c|0)==45056){d=a[14165874]|a[14165810]}else if((c|0)==43008){d=a[14165873]|a[14165809]}else{d=-1}return d|0}function aSs(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,i=0.0,j=0.0,k=0.0,l=0.0,m=0.0,n=0.0,o=0.0,p=0.0;e=b&65535;if((b+26624&65535)<256){b=e-38912|0;a[(c[3541366]|0)+b|0]=d;if(!((b|0)<64&(b&1|0)==0)){return}a[(c[3541380]|0)+(b>>1)|0]=d;return}switch(e|0){case 43008:case 43009:case 43010:case 43011:case 43012:case 43013:case 43014:case 43015:{b=e-43008|0;f=d&1;switch(b&7|0){case 0:case 1:case 2:{c[14165720+(b<<2)>>2]=f&255;return};case 7:case 6:{g=b&1;c[3541336]=c[3541336]&~(1<<g)|(d&1)<<g;return};case 3:{a[14165672]=f;if(f<<24>>24==0){return}c[3541416]=100;h[932737]=0.0;return};case 5:{do{if(f<<24>>24!=0){if((a[14165752]&1)!=0){break}a[14165512]=1;h[932735]=0.0}}while(0);a[14165752]=f;return};default:{return}}break};case 40964:case 40965:case 40966:case 40967:{f=d&1;g=14165736+(e-40964<<2)|0;if((f|0)==(c[g>>2]|0)){return}c[g>>2]=f;f=(c[3541434]|0)==0;i=f?4030303030303031.0e-21:30303030303030305.0e-22;j=f?1.0e-12:1000001.0e-12;if((c[3541435]|0)==0){k=j;l=i+21276595744680853.0e-22}else{k=j+21276595744680853.0e-22;l=i}if((c[3541436]|0)==0){m=k;n=l+45454545454545455.0e-22}else{m=k+45454545454545455.0e-22;n=l}if((c[3541437]|0)==0){o=m;p=n+1.0e-5}else{o=m+1.0e-5;p=n}n=1.0/p;h[932738]=1.0e9/((n*2.0e6/(n+1.0/o)+1.0e5)*58788.0)*100.0;return};case 45057:{a[14165768]=d&1;return};case 45058:{a[c[3541454]|0]=d;return};case 45062:{a[14165832]=d&1;return};case 45063:{a[14165824]=d&1;return};case 47104:{c[3541406]=d&255;return};default:{return}}}function aSt(b){b=b|0;var c=0;if((b+24576&65535)<256){c=a[14165872]|a[14165808];return c|0}if((b+22528&65535)<256){c=a[14165873]|a[14165809];return c|0}if((b+20480&65535)>=256){c=-1;return c|0}c=a[14165874]|a[14165810];return c|0}function aSu(b,d){b=b|0;d=d|0;var e=0,f=0,g=0.0,i=0.0,j=0.0,k=0.0,l=0.0,m=0.0,n=0.0,o=0.0;e=b&65535;if((b+26624&65535)<256){b=e-38912|0;a[(c[3541366]|0)+b|0]=d;if(!((b|0)<64&(b&1|0)==0)){return}a[(c[3541380]|0)+(b>>1)|0]=d;return}switch(e|0){case 45056:{a[c[3541454]|0]=d;return};case 45057:{a[14165768]=d&1;return};case 45062:{a[14165832]=d&1;return};case 45063:{a[14165824]=d&1;return};case 40964:case 40965:case 40966:case 40967:{b=d&1;f=14165736+(e-40964<<2)|0;if((b|0)==(c[f>>2]|0)){return}c[f>>2]=b;b=(c[3541434]|0)==0;g=b?4030303030303031.0e-21:30303030303030305.0e-22;i=b?1.0e-12:1000001.0e-12;if((c[3541435]|0)==0){j=i;k=g+21276595744680853.0e-22}else{j=i+21276595744680853.0e-22;k=g}if((c[3541436]|0)==0){l=j;m=k+45454545454545455.0e-22}else{l=j+45454545454545455.0e-22;m=k}if((c[3541437]|0)==0){n=l;o=m+1.0e-5}else{n=l+1.0e-5;o=m}m=1.0/o;h[932738]=1.0e9/((m*2.0e6/(m+1.0/n)+1.0e5)*58788.0)*100.0;return};case 43008:case 43009:case 43010:case 43011:case 43012:case 43014:case 43015:{b=e-43008|0;e=d&1;switch(b&7|0){case 3:{a[14165672]=e;if(e<<24>>24==0){return}c[3541416]=100;h[932737]=0.0;return};case 5:{do{if(e<<24>>24!=0){if((a[14165752]&1)!=0){break}a[14165512]=1;h[932735]=0.0}}while(0);a[14165752]=e;return};case 7:case 6:{f=b&1;c[3541336]=c[3541336]&~(1<<f)|(d&1)<<f;return};case 0:case 1:case 2:{c[14165720+(b<<2)>>2]=e&255;return};default:{return}}break};case 47104:{c[3541406]=d&255;return};default:{return}}}function aSv(b){b=b|0;var c=0,d=0;c=b&65535;if((c|0)==49152){d=a[14165872]|a[14165808]}else if((c|0)==51200){d=a[14165874]|a[14165810]}else if((c|0)==50176){d=a[14165873]|a[14165809]}else{d=-1}return d|0}function aSw(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((b+26624&65535)<256){b=e-38912|0;a[(c[3541366]|0)+b|0]=d;if(!((b|0)<64&(b&1|0)==0)){return}a[(c[3541380]|0)+(b>>1)|0]=d;return}switch(e|0){case 50176:case 50177:case 50178:case 50179:case 50180:case 50181:case 50182:case 50183:{b=e-50176|0;e=d&1;switch(b&7|0){case 0:case 1:case 2:{c[14165720+(b<<2)>>2]=e&255;return};case 3:{a[14165672]=e;if(e<<24>>24==0){return}c[3541416]=100;h[932737]=0.0;return};case 5:{do{if(e<<24>>24!=0){if((a[14165752]&1)!=0){break}a[14165512]=1;h[932735]=0.0}}while(0);a[14165752]=e;return};case 7:case 6:{e=b&1;c[3541336]=c[3541336]&~(1<<e)|(d&1)<<e;return};default:{return}}break};case 51201:{a[14165768]=d&1;return};case 51206:{a[14165832]=d&1;return};case 51207:{a[14165824]=d&1;return};case 52224:{c[3541406]=d&255;return};default:{return}}}function aSx(b){b=b|0;var c=0,d=0;c=b&65535;if((c|0)==40960){d=a[14165872]|a[14165808]}else if((c|0)==45056){d=a[14165874]|a[14165810]}else if((c|0)==43008){d=a[14165873]|a[14165809]}else{d=-1}return d|0}function aSy(b,d){b=b|0;d=d|0;var e=0,f=0;e=b&65535;if((b+26624&65535)<256){b=e-38912|0;a[(c[3541366]|0)+b|0]=d;if(!((b|0)<64&(b&1|0)==0)){return}a[(c[3541380]|0)+(b>>1)|0]=d;return}switch(e|0){case 51206:{a[14165832]=d&1;return};case 51207:{a[14165824]=d&1;return};case 47104:{c[3541406]=d&255;return};case 45057:{a[14165768]=d&1;return};case 43008:case 43009:case 43010:case 43011:case 43012:case 43013:case 43014:case 43015:{b=e-43008|0;e=d&1;switch(b&7|0){case 7:case 6:{f=b&1;c[3541336]=c[3541336]&~(1<<f)|(d&1)<<f;return};case 3:{a[14165672]=e;if(e<<24>>24==0){return}c[3541416]=100;h[932737]=0.0;return};case 5:{do{if(e<<24>>24!=0){if((a[14165752]&1)!=0){break}a[14165512]=1;h[932735]=0.0}}while(0);a[14165752]=e;return};case 0:case 1:case 2:{c[14165720+(b<<2)>>2]=e&255;return};default:{return}}break};default:{return}}}function aSz(b,d){b=b|0;d=d|0;var e=0,f=0;e=b&65535;if((b+26624&65535)<256){f=e-38912|0;a[(c[3541366]|0)+f|0]=d;if(!((f|0)<64&(f&1|0)==0)){return}a[(c[3541380]|0)+(f>>1)|0]=d;return}if((b+26368&65535)<5888|(b+20479&65535)<10239){return}if((e|0)==45056){a[14165768]=d&1;return}else if((e|0)==34819){c[3542228]=d&15;return}else if((e|0)==34827){b=d&255;f=c[3542228]|0;if((f|0)>15){return}do{if((f|0)<14){if((f|0)!=13){if((a[14168916+f|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(0,f,b);return}else if((e|0)==34828){c[3542291]=d&15;return}else if((e|0)==34830){e=d&255;b=c[3542291]|0;if((b|0)>15){return}do{if((b|0)<14){if((b|0)!=13){if((a[14169168+b|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(1,b,e);return}else{return}}function aSA(b,d){b=b|0;d=d|0;var e=0,f=0;e=b&65535;if((b+26624&65535)<1024){f=e-38912|0;a[(c[3541366]|0)+f|0]=d;if(!((f|0)<64&(f&1|0)==0)){return}a[(c[3541380]|0)+(f>>1)|0]=d;return}if((b&65535)>65527){return}if((e|0)==34827){b=d&255;f=c[3542228]|0;if((f|0)>15){return}do{if((f|0)<14){if((f|0)!=13){if((a[14168916+f|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(0,f,b);return}else if((e|0)==34828){c[3542291]=d&15;return}else if((e|0)==34830){b=d&255;f=c[3542291]|0;if((f|0)>15){return}do{if((f|0)<14){if((f|0)!=13){if((a[14169168+f|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(1,f,b);return}else if((e|0)==45056){a[14165768]=d&1;return}else if((e|0)==45060){b=d&1;c[3541360]=b;if((b|0)!=0){return}c[3541358]=-1;return}else if((e|0)==34819){c[3542228]=d&15;return}else{return}}function aSB(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4986604+(b*112|0)>>2];c[a+104>>2]=c[4986608+(b*112|0)>>2];c[a+108>>2]=c[4986612+(b*112|0)>>2];d=0;return d|0}function aSC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=4986504+(b*112|0);e=0;return e|0}function aSD(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1695088+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aSE(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4987736+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aSF(){var a=0;c[3541404]=2254;a=a04()|0;c[3541462]=58;c[3541464]=56;return a|0}function aSG(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1312832+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aSH(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>24){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4253944+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aSI(){var b=0;c[3541404]=4914;a[7461872]=1;b=a04()|0;a[14165760]=2;c[3541462]=68;c[3541464]=36;return b|0}function aSJ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>5){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4254348+(b*112|0)>>2];c[a+104>>2]=c[4254352+(b*112|0)>>2];c[a+108>>2]=c[4254356+(b*112|0)>>2];d=0;return d|0}function aSK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<6&(d|0)==0)){e=1;return e|0}c[a>>2]=4254248+(b*112|0);e=0;return e|0}function aSL(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4051332+(b*112|0)>>2];c[a+104>>2]=c[4051336+(b*112|0)>>2];c[a+108>>2]=c[4051340+(b*112|0)>>2];d=0;return d|0}function aSM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=4051232+(b*112|0);e=0;return e|0}function aSN(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1281168+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aSO(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4052576+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aSP(){var a=0;c[3541404]=2180;a=a04()|0;c[3541392]=0;c[3541466]=0;c[3541462]=14;c[3541464]=80;c[3541390]=4198;return a|0}function aSQ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6654068+(b*112|0)>>2];c[a+104>>2]=c[6654072+(b*112|0)>>2];c[a+108>>2]=c[6654076+(b*112|0)>>2];d=0;return d|0}function aSR(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=6653968+(b*112|0);e=0;return e|0}function aSS(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>5){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6654752+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aST(){var b=0;c[3541404]=8086;b=a04()|0;a[14165472]=7;a[14165480]=-10;return b|0}function aSU(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6399316+(b*112|0)>>2];c[a+104>>2]=c[6399320+(b*112|0)>>2];c[a+108>>2]=c[6399324+(b*112|0)>>2];d=0;return d|0}function aSV(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=6399216+(b*112|0);e=0;return e|0}function aSW(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4158672+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aSX(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6400224+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aSY(){var b=0;c[3541404]=9646;b=a04()|0;c[3541464]=52;a[14165472]=7;a[14165480]=-10;return b|0}function aSZ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5533036+(b*112|0)>>2];c[a+104>>2]=c[5533040+(b*112|0)>>2];c[a+108>>2]=c[5533044+(b*112|0)>>2];d=0;return d|0}function aS_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=5532936+(b*112|0);e=0;return e|0}function aS$(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1981752+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aS0(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5534056+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aS1(){var b=0;c[3541404]=8220;b=a04()|0;c[3541464]=52;a[14165472]=7;a[14165480]=-10;return b|0}function aS2(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6163692+(b*112|0)>>2];c[a+104>>2]=c[6163696+(b*112|0)>>2];c[a+108>>2]=c[6163700+(b*112|0)>>2];d=0;return d|0}function aS3(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=6163592+(b*112|0);e=0;return e|0}function aS4(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3617048+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aS5(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>2){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6164600+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aS6(){var a=0;c[3541404]=9504;a=a04()|0;c[3541462]=58;c[3541464]=56;return a|0}function aS7(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7191324+(b*112|0)>>2];c[a+104>>2]=c[7191328+(b*112|0)>>2];c[a+108>>2]=c[7191332+(b*112|0)>>2];d=0;return d|0}function aS8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=7191224+(b*112|0);e=0;return e|0}function aS9(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6268280+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aTa(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7192792+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aTb(){var b=0,d=0;c[3541404]=1218;c[3541398]=32;b=a04()|0;c[3541392]=0;c[3541464]=38;d=c[3541402]|0;a[d]=0;a[d+1|0]=122;a[d+2|0]=54;a[d+3|0]=7;a[d+4|0]=0;a[d+5|0]=-16;a[d+6|0]=56;a[d+7|0]=31;a[d+8|0]=0;a[d+9|0]=-57;a[d+10|0]=-16;a[d+11|0]=63;a[d+12|0]=0;a[d+13|0]=-37;a[d+14|0]=-58;a[d+15|0]=56;a[d+16|0]=0;a[d+17|0]=54;a[d+18|0]=7;a[d+19|0]=-16;a[d+20|0]=0;a[d+21|0]=51;a[d+22|0]=63;a[d+23|0]=-37;a[d+24|0]=0;a[d+25|0]=63;a[d+26|0]=87;a[d+27|0]=-58;a[d+28|0]=0;a[d+29|0]=-58;a[d+30|0]=63;a[d+31|0]=-1;return b|0}function aTc(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3993388+(b*112|0)>>2];c[a+104>>2]=c[3993392+(b*112|0)>>2];c[a+108>>2]=c[3993396+(b*112|0)>>2];d=0;return d|0}function aTd(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=3993288+(b*112|0);e=0;return e|0}function aTe(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1271624+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aTf(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>24){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3994520+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aTg(){var b=0;a[14165488]=18;c[3541404]=6820;c[3541412]=64;b=a04()|0;c[3541390]=4614;c[3541464]=38;return b|0}function aTh(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3308660+(b*112|0)>>2];c[a+104>>2]=c[3308664+(b*112|0)>>2];c[a+108>>2]=c[3308668+(b*112|0)>>2];d=0;return d|0}function aTi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=3308560+(b*112|0);e=0;return e|0}function aTj(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1178808+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aTk(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3309792+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aTl(){var b=0,d=0;a[14165488]=18;c[3541398]=32;c[3541404]=1e4;c[3541412]=64;b=a04()|0;c[3541390]=12880;c[3541464]=38;d=c[3541402]|0;a[d]=0;a[d+1|0]=122;a[d+2|0]=54;a[d+3|0]=7;a[d+4|0]=0;a[d+5|0]=-16;a[d+6|0]=56;a[d+7|0]=31;a[d+8|0]=0;a[d+9|0]=-57;a[d+10|0]=-16;a[d+11|0]=63;a[d+12|0]=0;a[d+13|0]=-37;a[d+14|0]=-58;a[d+15|0]=56;a[d+16|0]=0;a[d+17|0]=54;a[d+18|0]=7;a[d+19|0]=-16;a[d+20|0]=0;a[d+21|0]=51;a[d+22|0]=63;a[d+23|0]=-37;a[d+24|0]=0;a[d+25|0]=63;a[d+26|0]=87;a[d+27|0]=-58;a[d+28|0]=0;a[d+29|0]=-58;a[d+30|0]=63;a[d+31|0]=-1;return b|0}function aTm(b){b=b|0;var c=0,d=0;c=b&65535;if((c|0)==34816){d=a[14165875]|a[14165811]}else if((c|0)==40960){d=a[14165872]|a[14165808]}else if((c|0)==43008){d=a[14165873]|a[14165809]}else if((c|0)==45056){d=a[14165874]|a[14165810]}else{d=-1}return d|0}function aTn(d,e){d=d|0;e=e|0;var f=0,g=0,i=0.0,j=0.0,k=0.0,l=0.0,m=0.0,n=0.0,o=0.0,p=0.0;f=d&65535;if((d+26624&65535)<256){d=f-38912|0;a[(c[3541366]|0)+d|0]=e;if(!((d|0)<64&(d&1|0)==0)){return}a[(c[3541380]|0)+(d>>1)|0]=e;return}if((f|0)==18432){b[7065264]=b[7065264]&-256|e&255;return}else if((f|0)==18433){b[7065264]=b[7065264]&255|(e&255)<<8;return}else if((f|0)==18434){b[7065260]=b[7065260]&-256|e&255;return}else if((f|0)==18435){b[7065260]=b[7065260]&255|(e&255)<<8;return}else if((f|0)==40960|(f|0)==40961|(f|0)==40962){a[(c[3541454]|0)+(f-40960)|0]=e;return}else if((f|0)==40964|(f|0)==40965|(f|0)==40966|(f|0)==40967){d=e&1;g=14165736+(f-40964<<2)|0;if((d|0)==(c[g>>2]|0)){return}c[g>>2]=d;d=(c[3541434]|0)==0;i=d?4030303030303031.0e-21:30303030303030305.0e-22;j=d?1.0e-12:1000001.0e-12;if((c[3541435]|0)==0){k=j;l=i+21276595744680853.0e-22}else{k=j+21276595744680853.0e-22;l=i}if((c[3541436]|0)==0){m=k;n=l+45454545454545455.0e-22}else{m=k+45454545454545455.0e-22;n=l}if((c[3541437]|0)==0){o=m;p=n+1.0e-5}else{o=m+1.0e-5;p=n}n=1.0/p;h[932738]=1.0e9/((n*2.0e6/(n+1.0/o)+1.0e5)*58788.0)*100.0;return}else if((f|0)==45062){a[14165832]=e&1;return}else if((f|0)==45063){a[14165824]=e&1;return}else if((f|0)==47104){c[3541406]=e&255;return}else if((f|0)==43008|(f|0)==43009|(f|0)==43010|(f|0)==43011|(f|0)==43012|(f|0)==43013|(f|0)==43014|(f|0)==43015){d=f-43008|0;g=e&1;switch(d&7|0){case 0:case 1:case 2:{c[14165720+(d<<2)>>2]=g&255;return};case 3:{a[14165672]=g;if(g<<24>>24==0){return}c[3541416]=100;h[932737]=0.0;return};case 5:{do{if(g<<24>>24!=0){if((a[14165752]&1)!=0){break}a[14165512]=1;h[932735]=0.0}}while(0);a[14165752]=g;return};case 7:case 6:{g=d&1;c[3541336]=c[3541336]&~(1<<g)|(e&1)<<g;return};default:{return}}}else if((f|0)==45056){a[14165768]=e&1;return}else if((f|0)==45060){f=e&1;c[3541360]=f;if((f|0)!=0){return}c[3541358]=-1;return}else{return}}function aTo(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3537868+(b*112|0)>>2];c[a+104>>2]=c[3537872+(b*112|0)>>2];c[a+108>>2]=c[3537876+(b*112|0)>>2];d=0;return d|0}function aTp(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=3537768+(b*112|0);e=0;return e|0}function aTq(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1204280+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aTr(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>48){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3539336+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aTs(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;b=i;i=i+240|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;c[3541404]=12480;j=0;while(1){if((j|0)>=1024){k=0;break}l=9638528+(j<<2)|0;if((c[l>>2]|0)==0){m=40219;break}else{j=j+1|0}}do{if((m|0)==40219){j=gGq(16384)|0;c[l>>2]=j;if((j|0)==0){k=0;break}gGz(j|0,0,16384);k=j}}while(0);c[3532628]=k;a04()|0;k=0;while(1){if((k|0)>=1024){n=0;break}o=9638528+(k<<2)|0;if((c[o>>2]|0)==0){m=40224;break}else{k=k+1|0}}do{if((m|0)==40224){k=gGq(8192)|0;c[o>>2]=k;if((k|0)==0){n=0;break}gGz(k|0,0,8192);n=k}}while(0);c[3541356]=n;if((c[3542200]|0)==0){p=1;i=b;return p|0}o=g+108|0;c[o>>2]=0;k=g+100|0;c[k>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,12)|0;do{if((c[o>>2]|0)!=0){g=c[k>>2]|0;c[h>>2]=9534384;l=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[l&16383](h,12,0)|0;if((g|0)<1){p=1;i=b;return p|0}if((gzL(n,0,12)|0)==0){break}else{p=1}i=b;return p|0}}while(0);n=(c[3541356]|0)+4096|0;if((c[3542200]|0)==0){p=1;i=b;return p|0}h=e+108|0;c[h>>2]=0;k=e+100|0;c[k>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,13)|0;do{if((c[h>>2]|0)!=0){e=c[k>>2]|0;c[f>>2]=9534384;o=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[o&16383](f,13,0)|0;if((e|0)<1){p=1;i=b;return p|0}if((gzL(n,0,13)|0)==0){break}else{p=1}i=b;return p|0}}while(0);n=c[3541356]|0;f=c[3532628]|0;k=0;while(1){h=k<<6;gGz(f+h|0,0,64);e=k<<7;o=0;do{g=1<<3-o;l=(c[608128+(o<<2)>>2]|0)+e|0;j=0;do{q=l+(c[6669224+(j<<2)>>2]|0)|0;r=(j<<3)+h|0;s=0;do{t=q+(c[6669320+(s<<2)>>2]|0)|0;if(((d[n+((t|0)/8|0)|0]|0)&128>>>((t&7)>>>0)|0)!=0){t=f+(r+s)|0;a[t]=(d[t]|0|g)&255}s=s+1|0;}while((s|0)<8);j=j+1|0;}while((j|0)<8);o=o+1|0;}while((o|0)<4);o=k+1|0;if((o|0)<256){k=o}else{u=0;break}}while(1){if((u|0)>=1024){break}v=9638528+(u<<2)|0;if((c[v>>2]|0)==(n|0)){m=40246;break}else{u=u+1|0}}if((m|0)==40246){gGr(n);c[v>>2]=0}c[3541356]=0;c[3541474]=3414;c[3541392]=2454;c[3541462]=114;c[3541464]=40;p=0;i=b;return p|0}function aTt(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((b+26624&65535)<256){b=e-38912|0;a[(c[3541366]|0)+b|0]=d;if(!((b|0)<64&(b&1|0)==0)){return}a[(c[3541380]|0)+(b>>1)|0]=d;return}if((e|0)==45060){b=d&1;c[3541360]=b;if((b|0)!=0){return}c[3541358]=-1;return}else if((e|0)==45063){a[14165824]=d&1;return}else if((e|0)==45062){a[14165832]=d&1;return}else if((e|0)==45057){a[14165768]=d&1;return}else{return}}function aTu(b){b=b|0;var d=0,e=0;if((b&255)!=2){d=0;return d|0}b=c[3542228]|0;if((b|0)>15){d=0;return d|0}do{if((b|0)==14){e=c[3542224]|0;if((e|0)==0){break}a[14168930]=gj[e&4095](0)|0}else if((b|0)==15){e=c[3542225]|0;if((e|0)==0){break}a[14168931]=gj[e&4095](0)|0}}while(0);d=a[14168916+b|0]|0;return d|0}function aTv(b,d){b=b|0;d=d|0;var e=0;e=b&255;if((e|0)==0){c[3542228]=d&15;return}else if((e|0)==1){e=d&255;b=c[3542228]|0;if((b|0)>15){return}do{if((b|0)<14){if((b|0)!=13){if((a[14168916+b|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(0,b,e);return}else{return}}function aTw(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5339044+(b*112|0)>>2];c[a+104>>2]=c[5339048+(b*112|0)>>2];c[a+108>>2]=c[5339052+(b*112|0)>>2];d=0;return d|0}function aTx(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=5338944+(b*112|0);e=0;return e|0}function aTy(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1867696+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aTz(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5340512+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aTA(){var b=0;c[3541404]=3834;a[14165488]=3;b=a04()|0;c[3541392]=8802;c[3541466]=60;c[3541462]=48;c[3541464]=50;h[1771269]=.2;c[3542574]=3;h[1771270]=.2;c[3542575]=3;h[1771271]=.2;c[3542576]=3;return b|0}function aTB(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3841716+(b*112|0)>>2];c[a+104>>2]=c[3841720+(b*112|0)>>2];c[a+108>>2]=c[3841724+(b*112|0)>>2];d=0;return d|0}function aTC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=3841616+(b*112|0);e=0;return e|0}function aTD(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6250636+(b*112|0)>>2];c[a+104>>2]=c[6250640+(b*112|0)>>2];c[a+108>>2]=c[6250644+(b*112|0)>>2];d=0;return d|0}function aTE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=6250536+(b*112|0);e=0;return e|0}function aTF(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3799224+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aTG(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>5){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6251768+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aTH(){var b=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=i;i=i+480|0;e=b|0;f=b+112|0;g=b+120|0;j=b+232|0;k=b+240|0;l=b+352|0;m=b+360|0;n=b+472|0;c[3541322]=4096;c[3541348]=4096;c[3541404]=3704;a[14165488]=3;a04()|0;o=c[3541348]|0;p=0;while(1){if((p|0)>=1024){q=0;break}r=9638528+(p<<2)|0;if((c[r>>2]|0)==0){s=40367;break}else{p=p+1|0}}do{if((s|0)==40367){p=gGq(o)|0;c[r>>2]=p;if((p|0)==0){q=0;break}gGz(p|0,0,o|0);q=p}}while(0);c[3541356]=q;o=(c[3541318]|0)+(c[3541326]|0)+(c[3541312]|0)|0;if((c[3542200]|0)==0){t=1;i=b;return t|0}r=m+108|0;c[r>>2]=0;p=m+100|0;c[p>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,o)|0;do{if((c[r>>2]|0)!=0){m=c[p>>2]|0;c[n>>2]=9534384;u=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[u&16383](n,o,0)|0;if((m|0)<1){t=1;i=b;return t|0}if((gzL(q,0,o)|0)==0){break}else{t=1}i=b;return t|0}}while(0);o=(c[3541356]|0)+4096|0;q=(c[3541326]|0)+1+(c[3541318]|0)+(c[3541312]|0)|0;if((c[3542200]|0)==0){t=1;i=b;return t|0}n=k+108|0;c[n>>2]=0;p=k+100|0;c[p>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,q)|0;do{if((c[n>>2]|0)!=0){k=c[p>>2]|0;c[l>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](l,q,0)|0;if((k|0)<1){t=1;i=b;return t|0}if((gzL(o,0,q)|0)==0){break}else{t=1}i=b;return t|0}}while(0);q=(c[3541356]|0)+6144|0;o=(c[3541326]|0)+2+(c[3541318]|0)+(c[3541312]|0)|0;if((c[3542200]|0)==0){t=1;i=b;return t|0}l=g+108|0;c[l>>2]=0;p=g+100|0;c[p>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,o)|0;do{if((c[l>>2]|0)!=0){g=c[p>>2]|0;c[j>>2]=9534384;n=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[n&16383](j,o,0)|0;if((g|0)<1){t=1;i=b;return t|0}if((gzL(q,0,o)|0)==0){break}else{t=1}i=b;return t|0}}while(0);o=(c[3541356]|0)+10240|0;q=(c[3541326]|0)+3+(c[3541318]|0)+(c[3541312]|0)|0;if((c[3542200]|0)==0){t=1;i=b;return t|0}j=e+108|0;c[j>>2]=0;p=e+100|0;c[p>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,q)|0;do{if((c[j>>2]|0)!=0){e=c[p>>2]|0;c[f>>2]=9534384;l=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[l&16383](f,q,0)|0;if((e|0)<1){t=1;i=b;return t|0}if((gzL(o,0,q)|0)==0){break}else{t=1}i=b;return t|0}}while(0);q=c[3541414]|0;o=c[3541356]|0;f=c[3541472]|0;if((q|0)>0){p=c[1865546]|0;j=0;do{e=j<<6;gGz(f+e|0,0,64);l=0;do{g=e+(c[1238464+(l<<2)>>2]|0)|0;n=(l<<3)+e|0;k=0;do{r=g+(c[614800+(k<<2)>>2]|0)|0;if(((d[o+((r|0)/8|0)|0]|0)&128>>>((r&7)>>>0)|0)!=0){r=f+(n+k)|0;a[r]=a[r]|2}k=k+1|0;}while((k|0)<8);l=l+1|0;}while((l|0)<8);l=p+e|0;k=0;do{n=l+(c[1238464+(k<<2)>>2]|0)|0;g=(k<<3)+e|0;r=0;do{m=n+(c[614800+(r<<2)>>2]|0)|0;if(((d[o+((m|0)/8|0)|0]|0)&128>>>((m&7)>>>0)|0)!=0){m=f+(g+r)|0;a[m]=a[m]|1}r=r+1|0;}while((r|0)<8);k=k+1|0;}while((k|0)<8);j=j+1|0;}while((j|0)<(q|0))}q=c[3541412]|0;j=c[3541364]|0;if((q|0)>0){f=c[1865412]|0;p=0;while(1){k=p<<8;gGz(j+k|0,0,256);e=0;do{l=k+(c[611776+(e<<2)>>2]|0)|0;r=(e<<4)+k|0;g=0;do{n=l+(c[601400+(g<<2)>>2]|0)|0;if(((d[o+((n|0)/8|0)|0]|0)&128>>>((n&7)>>>0)|0)!=0){n=j+(r+g)|0;a[n]=a[n]|2}g=g+1|0;}while((g|0)<16);e=e+1|0;}while((e|0)<16);e=f+k|0;g=0;do{r=e+(c[611776+(g<<2)>>2]|0)|0;l=(g<<4)+k|0;n=0;do{m=r+(c[601400+(n<<2)>>2]|0)|0;if(((d[o+((m|0)/8|0)|0]|0)&128>>>((m&7)>>>0)|0)!=0){m=j+(l+n)|0;a[m]=a[m]|1}n=n+1|0;}while((n|0)<16);g=g+1|0;}while((g|0)<16);g=p+1|0;if((g|0)<(q|0)){p=g}else{v=0;break}}}else{v=0}while(1){if((v|0)>=1024){break}w=9638528+(v<<2)|0;if((c[w>>2]|0)==(o|0)){s=40405;break}else{v=v+1|0}}if((s|0)==40405){gGr(o);c[w>>2]=0}c[3541356]=0;c[3541392]=8802;c[3541466]=60;c[3541462]=48;c[3541464]=50;h[1771269]=.2;c[3542574]=3;h[1771270]=.2;c[3542575]=3;h[1771271]=.2;c[3542576]=3;t=0;i=b;return t|0}function aTI(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6966548+(b*112|0)>>2];c[a+104>>2]=c[6966552+(b*112|0)>>2];c[a+108>>2]=c[6966556+(b*112|0)>>2];d=0;return d|0}function aTJ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=6966448+(b*112|0);e=0;return e|0}function aTK(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5564616+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aTL(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6967456+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aTM(){var b=0;c[3541404]=7524;a[14165488]=13;b=a04()|0;c[3541464]=38;return b|0}function aTN(d,e){d=d|0;e=e|0;var f=0,g=0;if((d&255)!=0){return}a[14165504]=e;e=c[1836236]|0;d=c[9757320+(e<<2)>>2]|0;if((d|0)!=0){f=d;gGC(f|0,9706056,76)|0}c[9752472+(e<<2)>>2]=c[2433530];c[14113936+(e<<2)>>2]=c[2076596];c[9669104+(e<<2)>>2]=c[3541536];c[1836236]=-1;e=c[2439331]|0;if((e|0)!=0){f=e;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;f=(c[2433530]|0)+12|0;c[2433530]=f;e=c[1836236]|0;d=c[9757320+(e<<2)>>2]|0;if((d|0)!=0){g=d;gGC(g|0,9706056,76)|0}c[9752472+(e<<2)>>2]=f;c[14113936+(e<<2)>>2]=c[2076596];c[9669104+(e<<2)>>2]=c[3541536];c[1836236]=-1;e=c[2439330]|0;if((e|0)!=0){f=e;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;return}function aTO(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((b+26624&65535)<256){b=e-38912|0;a[(c[3541366]|0)+b|0]=d;if(!((b|0)<64&(b&1|0)==0)){return}a[(c[3541380]|0)+(b>>1)|0]=d;return}switch(e|0){case 40960:case 40961:case 40962:{a[(c[3541454]|0)+(e-40960)|0]=d;return};case 45060:{e=d&1;c[3541360]=e;if((e|0)!=0){return}c[3541358]=-1;return};case 45063:{a[14165824]=d&1;return};case 45062:{a[14165832]=d&1;return};case 45057:{a[14165768]=d&1;return};default:{return}}}function aTP(b){b=b|0;var d=0,e=0;d=b&255;if((d|0)==3){e=a[14165504]|0;return e|0}else if((d|0)==6){d=c[3542228]|0;if((d|0)>15){e=0;return e|0}do{if((d|0)==14){b=c[3542224]|0;if((b|0)==0){break}a[14168930]=gj[b&4095](0)|0}else if((d|0)==15){b=c[3542225]|0;if((b|0)==0){break}a[14168931]=gj[b&4095](0)|0}}while(0);e=a[14168916+d|0]|0;return e|0}else{e=-1;return e|0}return 0}function aTQ(b,d){b=b|0;d=d|0;var e=0;e=b&255;if((e|0)==4){c[3542228]=d&15;return}else if((e|0)==5){e=d&255;b=c[3542228]|0;if((b|0)>15){return}do{if((b|0)<14){if((b|0)!=13){if((a[14168916+b|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(0,b,e);return}else{return}}function aTR(b){b=b|0;var c=0,d=0;c=b&65535;L51964:do{if((c|0)==14336){switch(e[4853030]|0|0){case 4275:{d=124;break L51964;break};case 3983:{d=124;break L51964;break};case 4337:{d=-86;break L51964;break};case 3861:{d=-11;break L51964;break};case 4320:{d=0;break L51964;break};case 5122:{d=-86;break L51964;break};default:{d=-1;break L51964}}}else if((c|0)==24576){d=a[14165872]|a[14165808]}else if((c|0)==26624){d=a[14165873]|a[14165809]}else if((c|0)==28672){d=a[14165874]|a[14165810]}else{d=-1}}while(0);return d|0}function aTS(d,e){d=d|0;e=e|0;var f=0,g=0,h=0;f=d&65535;if((d-22528&65535)<256){d=f-22528|0;a[(c[3541366]|0)+d|0]=e;if(!((d|0)<64&(d&1|0)==0)){return}a[(c[3541380]|0)+(d>>1)|0]=e;return}switch(f|0){case 28673:{a[14165768]=e&1;return};case 28678:{a[14165832]=e&1;return};case 28679:{a[14165824]=e&1;return};case 30720:{a[14165504]=e;f=c[1836236]|0;d=c[9757320+(f<<2)>>2]|0;if((d|0)!=0){g=d;gGC(g|0,9706056,76)|0}c[9752472+(f<<2)>>2]=c[2433530];c[14113936+(f<<2)>>2]=c[2076596];c[9669104+(f<<2)>>2]=c[3541536];c[1836236]=-1;f=c[2439331]|0;if((f|0)!=0){g=f;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;g=(c[2433530]|0)+12|0;c[2433530]=g;f=c[1836236]|0;d=c[9757320+(f<<2)>>2]|0;if((d|0)!=0){h=d;gGC(h|0,9706056,76)|0}c[9752472+(f<<2)>>2]=g;c[14113936+(f<<2)>>2]=c[2076596];c[9669104+(f<<2)>>2]=c[3541536];c[1836236]=-1;f=c[2439330]|0;if((f|0)!=0){g=f;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;return};case 28676:{g=e&1;c[3541360]=g;if((g|0)!=0){return}c[3541358]=-1;return};default:{return}}}function aTT(b){b=b|0;var d=0,e=0;if(b<<16>>16!=-24574){d=-1;return d|0}b=c[3542228]|0;if((b|0)>15){d=0;return d|0}do{if((b|0)==14){e=c[3542224]|0;if((e|0)==0){break}a[14168930]=gj[e&4095](0)|0}else if((b|0)==15){e=c[3542225]|0;if((e|0)==0){break}a[14168931]=gj[e&4095](0)|0}}while(0);d=a[14168916+b|0]|0;return d|0}function aTU(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((e|0)==40960){c[3542228]=d&15;return}else if((e|0)==40961){e=d&255;b=c[3542228]|0;if((b|0)>15){return}do{if((b|0)<14){if((b|0)!=13){if((a[14168916+b|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(0,b,e);return}else{return}}function aTV(b){b=b|0;var c=0,d=0;c=b&65535;if((c|0)==12341){d=-116}else if((c|0)==28672){d=a[14165874]|a[14165810]}else if((c|0)==26624){d=a[14165873]|a[14165809]}else if((c|0)==30720){d=-1}else if((c|0)==12288){d=-86}else if((c|0)==24576){d=a[14165872]|a[14165808]}else{d=-1}return d|0}function aTW(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4162628+(b*112|0)>>2];c[a+104>>2]=c[4162632+(b*112|0)>>2];c[a+108>>2]=c[4162636+(b*112|0)>>2];d=0;return d|0}function aTX(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=4162528+(b*112|0);e=0;return e|0}function aTY(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1293352+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aTZ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4163648+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aT_(){var b=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;b=i;i=i+240|0;e=b|0;f=b+112|0;g=b+120|0;j=b+232|0;c[3541404]=6242;a[14165488]=4;c[3541348]=4096;k=a04()|0;l=c[3541348]|0;m=0;while(1){if((m|0)>=1024){n=0;break}o=9638528+(m<<2)|0;if((c[o>>2]|0)==0){p=40626;break}else{m=m+1|0}}do{if((p|0)==40626){m=gGq(l)|0;c[o>>2]=m;if((m|0)==0){n=0;break}gGz(m|0,0,l|0);n=m}}while(0);c[3541356]=n;l=(c[3541318]|0)+(c[3541326]|0)+(c[3541312]|0)|0;do{if((c[3542200]|0)!=0){o=g+108|0;c[o>>2]=0;m=g+100|0;c[m>>2]=0;q=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[q&16383](g,l)|0;if((c[o>>2]|0)==0){break}o=c[m>>2]|0;c[j>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](j,l,0)|0;if((o|0)<1){break}gzL(n,0,l)|0}}while(0);l=(c[3541356]|0)+4096|0;n=(c[3541326]|0)+1+(c[3541318]|0)+(c[3541312]|0)|0;do{if((c[3542200]|0)!=0){j=e+108|0;c[j>>2]=0;g=e+100|0;c[g>>2]=0;o=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[o&16383](e,n)|0;if((c[j>>2]|0)==0){break}j=c[g>>2]|0;c[f>>2]=9534384;g=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[g&16383](f,n,0)|0;if((j|0)<1){break}gzL(l,0,n)|0}}while(0);n=c[3541356]|0;l=n+2048|0;gGC(l|0,n|0,2048)|0;l=n+6144|0;f=n+4096|0;gGC(l|0,f|0,2048)|0;f=c[3541414]|0;l=c[3541472]|0;if((f|0)>0){e=c[1865546]|0;j=0;do{g=j<<6;gGz(l+g|0,0,64);o=0;do{m=g+(c[1238464+(o<<2)>>2]|0)|0;q=(o<<3)+g|0;r=0;do{s=m+(c[614800+(r<<2)>>2]|0)|0;if(((d[n+((s|0)/8|0)|0]|0)&128>>>((s&7)>>>0)|0)!=0){s=l+(q+r)|0;a[s]=a[s]|2}r=r+1|0;}while((r|0)<8);o=o+1|0;}while((o|0)<8);o=e+g|0;r=0;do{q=o+(c[1238464+(r<<2)>>2]|0)|0;m=(r<<3)+g|0;s=0;do{t=q+(c[614800+(s<<2)>>2]|0)|0;if(((d[n+((t|0)/8|0)|0]|0)&128>>>((t&7)>>>0)|0)!=0){t=l+(m+s)|0;a[t]=a[t]|1}s=s+1|0;}while((s|0)<8);r=r+1|0;}while((r|0)<8);j=j+1|0;}while((j|0)<(f|0))}f=c[3541412]|0;j=c[3541364]|0;if((f|0)>0){l=c[1865412]|0;e=0;while(1){r=e<<8;gGz(j+r|0,0,256);g=0;do{o=r+(c[611776+(g<<2)>>2]|0)|0;s=(g<<4)+r|0;m=0;do{q=o+(c[601400+(m<<2)>>2]|0)|0;if(((d[n+((q|0)/8|0)|0]|0)&128>>>((q&7)>>>0)|0)!=0){q=j+(s+m)|0;a[q]=a[q]|2}m=m+1|0;}while((m|0)<16);g=g+1|0;}while((g|0)<16);g=l+r|0;m=0;do{s=g+(c[611776+(m<<2)>>2]|0)|0;o=(m<<4)+r|0;q=0;do{t=s+(c[601400+(q<<2)>>2]|0)|0;if(((d[n+((t|0)/8|0)|0]|0)&128>>>((t&7)>>>0)|0)!=0){t=j+(o+q)|0;a[t]=a[t]|1}q=q+1|0;}while((q|0)<16);m=m+1|0;}while((m|0)<16);m=e+1|0;if((m|0)<(f|0)){e=m}else{u=0;break}}}else{u=0}while(1){if((u|0)>=1024){p=40671;break}v=9638528+(u<<2)|0;if((c[v>>2]|0)==(n|0)){break}else{u=u+1|0}}if((p|0)==40671){c[3541356]=0;c[3541462]=114;c[3541464]=42;h[1771269]=.2;c[3542574]=3;h[1771270]=.2;c[3542575]=3;h[1771271]=.2;c[3542576]=3;i=b;return k|0}gGr(n);c[v>>2]=0;c[3541356]=0;c[3541462]=114;c[3541464]=42;h[1771269]=.2;c[3542574]=3;h[1771270]=.2;c[3542575]=3;h[1771271]=.2;c[3542576]=3;i=b;return k|0}function aT$(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1982444+(b*112|0)>>2];c[a+104>>2]=c[1982448+(b*112|0)>>2];c[a+108>>2]=c[1982452+(b*112|0)>>2];d=0;return d|0}function aT0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=1982344+(b*112|0);e=0;return e|0}function aT1(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=987064+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aT2(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1983128+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aT3(){var b=0;c[3541404]=5932;a[14165488]=5;b=a04()|0;h[1771269]=.2;c[3542574]=3;h[1771270]=.2;c[3542575]=3;h[1771271]=.2;c[3542576]=3;return b|0}function aT4(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6953324+(b*112|0)>>2];c[a+104>>2]=c[6953328+(b*112|0)>>2];c[a+108>>2]=c[6953332+(b*112|0)>>2];d=0;return d|0}function aT5(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=6953224+(b*112|0);e=0;return e|0}function aT6(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5459536+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aT7(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6954008+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aT8(){var b=0;c[3541404]=9008;a[14165488]=5;b=a04()|0;h[1771269]=1.0;c[3542574]=3;h[1771270]=1.0;c[3542575]=3;h[1771271]=1.0;c[3542576]=3;return b|0}function aT9(b){b=b|0;var d=0,e=0;if(!((b&255)==12&(a[14164624]|0)==0)){d=-1;return d|0}b=c[3542228]|0;if((b|0)>15){d=0;return d|0}do{if((b|0)==14){e=c[3542224]|0;if((e|0)==0){break}a[14168930]=gj[e&4095](0)|0}else if((b|0)==15){e=c[3542225]|0;if((e|0)==0){break}a[14168931]=gj[e&4095](0)|0}}while(0);d=a[14168916+b|0]|0;return d|0}function aUa(b,d){b=b|0;d=d|0;var e=0;e=b&255;if((e|0)==8){if((a[14164624]|0)!=0){return}c[3542228]=d&15;return}else if((e|0)==9){if((a[14164624]|0)!=0){return}e=d&255;b=c[3542228]|0;if((b|0)>15){return}do{if((b|0)<14){if((b|0)!=13){if((a[14168916+b|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(0,b,e);return}else{return}}function aUb(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((b+26624&65535)<256){b=e-38912|0;a[(c[3541366]|0)+b|0]=d;if(!((b|0)<64&(b&1|0)==0)){return}a[(c[3541380]|0)+(b>>1)|0]=d;return}if((e|0)==40960){a[14165768]=d&1;return}else if((e|0)==40961){b=d&1;c[3541360]=b;if((b|0)!=0){return}c[3541358]=-1;return}else if((e|0)==40962){b=d&1;a[14165832]=b;a[14165824]=b;return}else if((e|0)==40967){a[14164624]=d&1;return}else{return}}function aUc(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3693660+(b*112|0)>>2];c[a+104>>2]=c[3693664+(b*112|0)>>2];c[a+108>>2]=c[3693668+(b*112|0)>>2];d=0;return d|0}function aUd(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=3693560+(b*112|0);e=0;return e|0}function aUe(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1228184+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aUf(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>26){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3694904+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aUg(){var b=0;c[3541404]=7250;a[14165488]=6;c[3541348]=4096;b=a04()|0;a$R();return b|0}function aUh(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1817788+(b*112|0)>>2];c[a+104>>2]=c[1817792+(b*112|0)>>2];c[a+108>>2]=c[1817796+(b*112|0)>>2];d=0;return d|0}function aUi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=1817688+(b*112|0);e=0;return e|0}function aUj(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1816444+(b*112|0)>>2];c[a+104>>2]=c[1816448+(b*112|0)>>2];c[a+108>>2]=c[1816452+(b*112|0)>>2];d=0;return d|0}function aUk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=1816344+(b*112|0);e=0;return e|0}function aUl(){var b=0;c[3541404]=5052;a[14165488]=6;c[3541348]=4096;b=a04()|0;a$R();return b|0}function aUm(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1226940+(b*112|0)>>2];c[a+104>>2]=c[1226944+(b*112|0)>>2];c[a+108>>2]=c[1226948+(b*112|0)>>2];d=0;return d|0}function aUn(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=1226840+(b*112|0);e=0;return e|0}function aUo(b){b=b|0;var c=0,d=0,e=0;c=b&65535;if((c|0)==40960){b=a[14165872]|a[14165808];d=a[14165840]|0;if((a[14164880]|0)==0){e=d<<6&64|b;return e|0}else{e=d<<5&64|b;return e|0}}else if((c|0)==45056){e=a[14165874]|a[14165810];return e|0}else if((c|0)==43008){c=(a[14165873]|a[14165809])&223;e=(c|(cT()|0)&32)&255;return e|0}else{e=-1;return e|0}return 0}function aUp(b,d){b=b|0;d=d|0;var e=0,f=0,g=0.0,i=0.0,j=0.0,k=0.0,l=0.0,m=0.0,n=0.0,o=0.0;e=b&65535;if((b+26624&65535)<256){b=e-38912|0;a[(c[3541366]|0)+b|0]=d;if(!((b|0)<64&(b&1|0)==0)){return}a[(c[3541380]|0)+(b>>1)|0]=d;return}switch(e|0){case 40960:case 40961:case 40962:{a[(c[3541454]|0)+(e-40960)|0]=d;return};case 45058:{b=a[14164888]&-3|d<<1;a[14164888]=b;a[14165504]=b|-16;return};case 45059:{a[14164880]=d;return};case 45060:{b=d&1;c[3541360]=b;if((b|0)!=0){return}c[3541358]=-1;return};case 45062:{a[14165832]=d&1;return};case 45063:{a[14165824]=d&1;return};case 47104:{c[3541406]=d&255;return};case 45056:{a[14164888]=a[14164888]&-2|d;return};case 45057:{a[14165768]=d&1;return};case 40964:case 40965:case 40966:case 40967:{b=d&1;f=14165736+(e-40964<<2)|0;if((b|0)==(c[f>>2]|0)){return}c[f>>2]=b;b=(c[3541434]|0)==0;g=b?4030303030303031.0e-21:30303030303030305.0e-22;i=b?1.0e-12:1000001.0e-12;if((c[3541435]|0)==0){j=i;k=g+21276595744680853.0e-22}else{j=i+21276595744680853.0e-22;k=g}if((c[3541436]|0)==0){l=j;m=k+45454545454545455.0e-22}else{l=j+45454545454545455.0e-22;m=k}if((c[3541437]|0)==0){n=l;o=m+1.0e-5}else{n=l+1.0e-5;o=m}m=1.0/o;h[932738]=1.0e9/((m*2.0e6/(m+1.0/n)+1.0e5)*58788.0)*100.0;return};case 43008:case 43009:case 43010:case 43011:case 43012:case 43013:case 43014:case 43015:{b=e-43008|0;e=d&1;switch(b&7|0){case 5:{do{if(e<<24>>24!=0){if((a[14165752]&1)!=0){break}a[14165512]=1;h[932735]=0.0}}while(0);a[14165752]=e;return};case 7:case 6:{f=b&1;c[3541336]=c[3541336]&~(1<<f)|(d&1)<<f;return};case 0:case 1:case 2:{c[14165720+(b<<2)>>2]=e&255;return};case 3:{a[14165672]=e;if(e<<24>>24==0){return}c[3541416]=100;h[932737]=0.0;return};default:{return}}break};default:{return}}}function aUq(a){a=a|0;return-1|0}function aUr(a,b){a=a|0;b=b|0;return}function aUs(b){b=b|0;return((b&255)==0?a[14165504]|0:0)|0}function aUt(a,d){a=a|0;d=d|0;if((a&255)!=0){return}US(0,gD[c[2385643]&8191]()|0);b[4771272]=~~(+(b[9732544+((~d&255)<<1)>>1]|0)*+h[1192819])&65535;return}function aUu(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3829388+(b*112|0)>>2];c[a+104>>2]=c[3829392+(b*112|0)>>2];c[a+108>>2]=c[3829396+(b*112|0)>>2];d=0;return d|0}function aUv(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=3829288+(b*112|0);e=0;return e|0}function aUw(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1237152+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aUx(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>25){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3830408+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aUy(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;b=i;i=i+240|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;c[3541404]=1792;a[14165488]=7;c[3541348]=4096;j=a04()|0;k=c[3541348]|0;l=0;while(1){if((l|0)>=1024){m=0;break}n=9638528+(l<<2)|0;if((c[n>>2]|0)==0){o=40942;break}else{l=l+1|0}}do{if((o|0)==40942){l=gGq(k)|0;c[n>>2]=l;if((l|0)==0){m=0;break}gGz(l|0,0,k|0);m=l}}while(0);c[3541356]=m;k=(c[3541318]|0)+(c[3541326]|0)+(c[3541312]|0)|0;do{if((c[3542200]|0)!=0){n=g+108|0;c[n>>2]=0;l=g+100|0;c[l>>2]=0;p=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[p&16383](g,k)|0;if((c[n>>2]|0)==0){break}n=c[l>>2]|0;c[h>>2]=9534384;l=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[l&16383](h,k,0)|0;if((n|0)<1){break}gzL(m,0,k)|0}}while(0);k=(c[3541356]|0)+4096|0;m=(c[3541326]|0)+1+(c[3541318]|0)+(c[3541312]|0)|0;do{if((c[3542200]|0)!=0){h=e+108|0;c[h>>2]=0;g=e+100|0;c[g>>2]=0;n=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[n&16383](e,m)|0;if((c[h>>2]|0)==0){break}h=c[g>>2]|0;c[f>>2]=9534384;g=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[g&16383](f,m,0)|0;if((h|0)<1){break}gzL(k,0,m)|0}}while(0);m=c[3541356]|0;k=m+2048|0;gGC(k|0,m|0,2048)|0;k=m+6144|0;f=m+4096|0;gGC(k|0,f|0,2048)|0;f=c[3541414]|0;k=c[3541472]|0;if((f|0)>0){e=c[1865546]|0;h=0;do{g=h<<6;gGz(k+g|0,0,64);n=0;do{l=g+(c[1238464+(n<<2)>>2]|0)|0;p=(n<<3)+g|0;q=0;do{r=l+(c[614800+(q<<2)>>2]|0)|0;if(((d[m+((r|0)/8|0)|0]|0)&128>>>((r&7)>>>0)|0)!=0){r=k+(p+q)|0;a[r]=a[r]|2}q=q+1|0;}while((q|0)<8);n=n+1|0;}while((n|0)<8);n=e+g|0;q=0;do{p=n+(c[1238464+(q<<2)>>2]|0)|0;l=(q<<3)+g|0;r=0;do{s=p+(c[614800+(r<<2)>>2]|0)|0;if(((d[m+((s|0)/8|0)|0]|0)&128>>>((s&7)>>>0)|0)!=0){s=k+(l+r)|0;a[s]=a[s]|1}r=r+1|0;}while((r|0)<8);q=q+1|0;}while((q|0)<8);h=h+1|0;}while((h|0)<(f|0))}f=c[3541412]|0;h=c[3541364]|0;if((f|0)>0){k=c[1865412]|0;e=0;while(1){q=e<<8;gGz(h+q|0,0,256);g=0;do{n=q+(c[611776+(g<<2)>>2]|0)|0;r=(g<<4)+q|0;l=0;do{p=n+(c[601400+(l<<2)>>2]|0)|0;if(((d[m+((p|0)/8|0)|0]|0)&128>>>((p&7)>>>0)|0)!=0){p=h+(r+l)|0;a[p]=a[p]|2}l=l+1|0;}while((l|0)<16);g=g+1|0;}while((g|0)<16);g=k+q|0;l=0;do{r=g+(c[611776+(l<<2)>>2]|0)|0;n=(l<<4)+q|0;p=0;do{s=r+(c[601400+(p<<2)>>2]|0)|0;if(((d[m+((s|0)/8|0)|0]|0)&128>>>((s&7)>>>0)|0)!=0){s=h+(n+p)|0;a[s]=a[s]|1}p=p+1|0;}while((p|0)<16);l=l+1|0;}while((l|0)<16);l=e+1|0;if((l|0)<(f|0)){e=l}else{t=0;break}}}else{t=0}while(1){if((t|0)>=1024){o=40986;break}u=9638528+(t<<2)|0;if((c[u>>2]|0)==(m|0)){break}else{t=t+1|0}}if((o|0)==40986){c[3541356]=0;i=b;return j|0}gGr(m);c[u>>2]=0;c[3541356]=0;i=b;return j|0}function aUz(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1863620+(b*112|0)>>2];c[a+104>>2]=c[1863624+(b*112|0)>>2];c[a+108>>2]=c[1863628+(b*112|0)>>2];d=0;return d|0}function aUA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=1863520+(b*112|0);e=0;return e|0}function aUB(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=d&65535;if((d+26624&65535)<256){d=f-38912|0;a[(c[3541366]|0)+d|0]=e;if(!((d|0)<64&(d&1|0)==0)){return}a[(c[3541380]|0)+(d>>1)|0]=e;return}switch(f|0){case 40960:case 40961:case 40962:{a[(c[3541454]|0)+(f-40960)|0]=e;return};case 45060:{f=e&1;c[3541360]=f;if((f|0)!=0){return}c[3541358]=-1;return};case 43008:{a[14165504]=e;return};case 45056:{a[14165768]=e&1;return};case 45057:{if((e&1)!=0){return}f=c[1836236]|0;d=c[9757320+(f<<2)>>2]|0;if((d|0)!=0){g=d;gGC(g|0,9706056,76)|0}c[9752472+(f<<2)>>2]=c[2433530];c[14113936+(f<<2)>>2]=c[2076596];c[9669104+(f<<2)>>2]=c[3541536];c[1836236]=-1;f=c[2439331]|0;g=(f|0)==0;if(!g){d=f;gGC(9706056,d|0,76)|0}b[4853030]=c[2426515]&65535;d=c[2438119]|0;c[2433530]=d;h=c[3528485]|0;c[2076596]=h;i=c[2417277]|0;c[3541536]=i;c[1836236]=1;a[9706117]=1;if(!g){g=f;gGC(g|0,9706056,76)|0}c[2438119]=d;c[3528485]=h;c[2417277]=i;c[1836236]=-1;i=c[2439330]|0;if((i|0)!=0){h=i;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;return};case 45062:{a[14165832]=e&1;return};case 45063:{a[14165824]=e&1;return};default:{return}}}function aUC(a){a=a|0;var b=0,c=0,d=0;if((a&65535)<=49151){b=-1;return b|0}c=(a&65535)-49152|0;if((c&4096|0)==0){d=-1}else{d=S3(0,c>>>3&3)|0}if((c&8192|0)==0){b=d;return b|0}b=(S3(1,c>>>3&3)|0)&d;return b|0}function aUD(b,d){b=b|0;d=d|0;var e=0,f=0;e=b&65535;if((b+28672&65535)<256){f=e-36864|0;a[(c[3541366]|0)+f|0]=d;if(!((f|0)<64&(f&1|0)==0)){return}a[(c[3541380]|0)+(f>>1)|0]=d;return}if((b&65535)>49151){b=e-49152|0;if((b&4096|0)!=0){S4(0,b>>>3&3,d)}if((b&8192|0)==0){return}S4(1,b>>>3&3,d);return}if((e|0)==43010){a[14165832]=d&1;return}else if((e|0)==43012){a[14165768]=d&1;return}else if((e|0)==43014){a[14165824]=d&1;return}else{return}}function aUE(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5398620+(b*112|0)>>2];c[a+104>>2]=c[5398624+(b*112|0)>>2];c[a+108>>2]=c[5398628+(b*112|0)>>2];d=0;return d|0}function aUF(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=5398520+(b*112|0);e=0;return e|0}function aUG(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1918048+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aUH(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5399528+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aUI(){var b=0,d=0,e=0,f=0,g=0;c[3541404]=3566;a[14165488]=8;b=a04()|0;a0P();d=c[3541320]|0;e=0;do{f=d+e|0;g=a[f]|0;a[f]=g<<1&2|g&-4|(g&255)>>>1&1;e=e+1|0;}while(e>>>0<2048);a[7461920]=1;c[3541392]=8158;c[3541466]=0;c[3541462]=90;c[3541464]=4;gGz(9668984|0,0|0,27|0);S6(0,27,0);gGz(9669011|0,0|0,27|0);S6(1,27,0);c[3540906]=1550;c[3540904]=600;c[3540902]=240;c[3540890]=432;c[3540888]=1374;c[3540886]=1502;return b|0}function aUJ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1915940+(b*112|0)>>2];c[a+104>>2]=c[1915944+(b*112|0)>>2];c[a+108>>2]=c[1915948+(b*112|0)>>2];d=0;return d|0}function aUK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=1915840+(b*112|0);e=0;return e|0}function aUL(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1914820+(b*112|0)>>2];c[a+104>>2]=c[1914824+(b*112|0)>>2];c[a+108>>2]=c[1914828+(b*112|0)>>2];d=0;return d|0}function aUM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=1914720+(b*112|0);e=0;return e|0}function aUN(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1916948+(b*112|0)>>2];c[a+104>>2]=c[1916952+(b*112|0)>>2];c[a+108>>2]=c[1916956+(b*112|0)>>2];d=0;return d|0}function aUO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=1916848+(b*112|0);e=0;return e|0}function aUP(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=980168+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aUQ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1917856+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aUR(){var b=0,d=0,e=0,f=0,g=0;c[3541404]=2372;a[14165488]=8;b=a04()|0;a0P();d=c[3541320]|0;e=0;do{f=d+e|0;g=a[f]|0;a[f]=g<<1&2|g&-4|(g&255)>>>1&1;e=e+1|0;}while(e>>>0<2048);c[3541392]=8158;c[3541466]=0;c[3541462]=90;c[3541464]=4;return b|0}function aUS(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3943068+(b*112|0)>>2];c[a+104>>2]=c[3943072+(b*112|0)>>2];c[a+108>>2]=c[3943076+(b*112|0)>>2];d=0;return d|0}function aUT(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=3942968+(b*112|0);e=0;return e|0}function aUU(){var b=0,d=0,e=0,f=0,g=0;c[3541404]=6622;a[14165488]=8;b=a04()|0;a0P();d=c[3541320]|0;e=0;do{f=d+e|0;g=a[f]|0;a[f]=g<<1&2|g&-4|(g&255)>>>1&1;e=e+1|0;}while(e>>>0<2048);gGz(9668984|0,0|0,27|0);S6(0,27,0);gGz(9669011|0,0|0,27|0);S6(1,27,0);c[3540906]=1550;c[3540904]=600;c[3540902]=240;c[3540890]=432;c[3540888]=1374;c[3540886]=1502;c[3541392]=8158;c[3541466]=0;c[3541462]=90;c[3541464]=4;return b|0}function aUV(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6887356+(b*112|0)>>2];c[a+104>>2]=c[6887360+(b*112|0)>>2];c[a+108>>2]=c[6887364+(b*112|0)>>2];d=0;return d|0}function aUW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=6887256+(b*112|0);e=0;return e|0}function aUX(){var b=0,d=0,e=0,f=0,g=0;c[3541404]=2826;a[14165488]=8;b=a04()|0;a0P();d=c[3541320]|0;e=0;do{f=d+e|0;g=a[f]|0;a[f]=g<<1&2|g&-4|(g&255)>>>1&1;e=e+1|0;}while(e>>>0<2048);gGz(9668984|0,0|0,27|0);S6(0,27,0);gGz(9669011|0,0|0,27|0);S6(1,27,0);c[3540906]=1550;c[3540904]=600;c[3540902]=240;c[3540890]=432;c[3540888]=1374;c[3540886]=1502;c[3541392]=8158;c[3541466]=0;c[3541462]=90;c[3541464]=4;return b|0}function aUY(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6886068+(b*112|0)>>2];c[a+104>>2]=c[6886072+(b*112|0)>>2];c[a+108>>2]=c[6886076+(b*112|0)>>2];d=0;return d|0}function aUZ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=6885968+(b*112|0);e=0;return e|0}function aU_(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5399720+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aU$(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6887088+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aU0(){var a=0;c[3541404]=4850;a=a04()|0;c[3541392]=8158;c[3541462]=90;c[3541464]=4;return a|0}function aU1(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5397612+(b*112|0)>>2];c[a+104>>2]=c[5397616+(b*112|0)>>2];c[a+108>>2]=c[5397620+(b*112|0)>>2];d=0;return d|0}function aU2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=5397512+(b*112|0);e=0;return e|0}function aU3(){var b=0,d=0,e=0,f=0,g=0;c[3541404]=6960;a[14165488]=8;b=a04()|0;a0P();d=c[3541320]|0;e=0;do{f=d+e|0;g=a[f]|0;a[f]=g<<1&2|g&-4|(g&255)>>>1&1;e=e+1|0;}while(e>>>0<2048);gGz(9668984|0,0|0,27|0);S6(0,27,0);gGz(9669011|0,0|0,27|0);S6(1,27,0);c[3540906]=1550;c[3540904]=600;c[3540902]=240;c[3540890]=432;c[3540888]=1374;c[3540886]=1502;c[3541392]=8158;c[3541466]=0;c[3541462]=90;c[3541464]=4;return b|0}function aU4(b){b=b|0;var c=0,d=0;c=b&65535;if((c|0)==40960){d=~a[14165808]-(a[14165872]|0)&255;return d|0}else if((c|0)==40961){d=~a[14165809]-(a[14165873]|0)&255;return d|0}else if((c|0)==40962){d=~a[14165810]-(a[14165874]|0)&255;return d|0}else{d=-1;return d|0}return 0}function aU5(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((b+26624&65535)<256){b=e-38912|0;a[(c[3541366]|0)+b|0]=d;if(!((b|0)<64&(b&1|0)==0)){return}a[(c[3541380]|0)+(b>>1)|0]=d;return}switch(e|0){case 40960:{a[14165912]=d&1;return};case 40992:{a[14165920]=d&1;return};case 41e3:{a[14165936]=d&1;return};case 43009:{a[14165768]=d&1;return};case 43014:{a[14165832]=d&1;return};case 43015:{a[14165824]=d&1;return};default:{return}}}function aU6(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4910564+(b*112|0)>>2];c[a+104>>2]=c[4910568+(b*112|0)>>2];c[a+108>>2]=c[4910572+(b*112|0)>>2];d=0;return d|0}function aU7(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=4910464+(b*112|0);e=0;return e|0}function aU8(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1652384+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aU9(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4911584+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aVa(){var b=0;c[3541404]=4020;a[14165488]=9;b=a04()|0;a0U();c[3541392]=1556;c[3541466]=0;gGz(9668984|0,0|0,27|0);S6(0,27,0);gGz(9669011|0,0|0,27|0);S6(1,27,0);c[3540906]=1550;c[3540904]=600;c[3540902]=240;c[3540890]=432;c[3540888]=1374;c[3540886]=1502;return b|0}function aVb(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6023036+(b*112|0)>>2];c[a+104>>2]=c[6023040+(b*112|0)>>2];c[a+108>>2]=c[6023044+(b*112|0)>>2];d=0;return d|0}function aVc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=6022936+(b*112|0);e=0;return e|0}function aVd(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6024056+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aVe(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1193852+(b*112|0)>>2];c[a+104>>2]=c[1193856+(b*112|0)>>2];c[a+108>>2]=c[1193860+(b*112|0)>>2];d=0;return d|0}function aVf(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=1193752+(b*112|0);e=0;return e|0}function aVg(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4911876+(b*112|0)>>2];c[a+104>>2]=c[4911880+(b*112|0)>>2];c[a+108>>2]=c[4911884+(b*112|0)>>2];d=0;return d|0}function aVh(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=4911776+(b*112|0);e=0;return e|0}function aVi(){var b=0;c[3541404]=11124;a[14165488]=9;b=a04()|0;a0U();c[3541392]=1556;c[3541466]=0;return b|0}function aVj(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6438980+(b*112|0)>>2];c[a+104>>2]=c[6438984+(b*112|0)>>2];c[a+108>>2]=c[6438988+(b*112|0)>>2];d=0;return d|0}function aVk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=6438880+(b*112|0);e=0;return e|0}function aVl(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4281520+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aVm(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>48){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5610760+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aVn(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5615796+(b*112|0)>>2];c[a+104>>2]=c[5615800+(b*112|0)>>2];c[a+108>>2]=c[5615804+(b*112|0)>>2];d=0;return d|0}function aVo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=5615696+(b*112|0);e=0;return e|0}function aVp(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>48){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=644e4+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aVq(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5609740+(b*112|0)>>2];c[a+104>>2]=c[5609744+(b*112|0)>>2];c[a+108>>2]=c[5609748+(b*112|0)>>2];d=0;return d|0}function aVr(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=5609640+(b*112|0);e=0;return e|0}function aVs(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5613076+(b*112|0)>>2];c[a+104>>2]=c[5613080+(b*112|0)>>2];c[a+108>>2]=c[5613084+(b*112|0)>>2];d=0;return d|0}function aVt(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=5612976+(b*112|0);e=0;return e|0}function aVu(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>48){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5614096+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aVv(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5614788+(b*112|0)>>2];c[a+104>>2]=c[5614792+(b*112|0)>>2];c[a+108>>2]=c[5614796+(b*112|0)>>2];d=0;return d|0}function aVw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=5614688+(b*112|0);e=0;return e|0}function aVx(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6978804+(b*112|0)>>2];c[a+104>>2]=c[6978808+(b*112|0)>>2];c[a+108>>2]=c[6978812+(b*112|0)>>2];d=0;return d|0}function aVy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=6978704+(b*112|0);e=0;return e|0}function aVz(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5611452+(b*112|0)>>2];c[a+104>>2]=c[5611456+(b*112|0)>>2];c[a+108>>2]=c[5611460+(b*112|0)>>2];d=0;return d|0}function aVA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=5611352+(b*112|0);e=0;return e|0}function aVB(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5612808+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aVC(){var b=0;c[3541404]=6622;a[14165488]=9;b=a04()|0;a0U();c[3541392]=8638;c[3541466]=60;gGz(9668984|0,0|0,27|0);S6(0,27,0);gGz(9669011|0,0|0,27|0);S6(1,27,0);c[3540906]=1550;c[3540904]=600;c[3540888]=1374;c[3540886]=1502;c[3540902]=1684;c[3540890]=3316;c[3540884]=718;return b|0}function aVD(b){b=b|0;var c=0,d=0;c=b&65535;if((c|0)==32768){d=a[14165872]|a[14165808]}else if((c|0)==32769){d=a[14165873]|a[14165809]}else if((c|0)==32770){d=a[14165874]|a[14165810]}else if((c|0)==32771){d=a[14165875]|a[14165811]}else{d=-1}return d|0}function aVE(d,e){d=d|0;e=e|0;var f=0,g=0,h=0;f=d&65535;if((d-20480&65535)<256){g=f-20480|0;a[(c[3541366]|0)+g|0]=e;if(!((g|0)<64&(g&1|0)==0)){return}a[(c[3541380]|0)+(g>>1)|0]=e;return}if((d-20736&65535)<256){d=f-20736|0;a[(c[3541366]|0)+d|0]=e;if(!((d|0)<64&(d&1|0)==0)){return}a[(c[3541380]|0)+(d>>1)|0]=e;return}if((f|0)==26625){a[14165768]=e&1;return}else if((f|0)==26627){a[14165928]=e&1;return}else if((f|0)==26628){d=e&1;c[3541360]=d;if((d|0)!=0){return}c[3541358]=-1;return}else if((f|0)==26630){a[14165832]=e&1;return}else if((f|0)==26631){a[14165824]=e&1;return}else if((f|0)==32768){a[14165504]=e;return}else if((f|0)==36864){f=c[1836236]|0;e=c[9757320+(f<<2)>>2]|0;if((e|0)!=0){d=e;gGC(d|0,9706056,76)|0}c[9752472+(f<<2)>>2]=c[2433530];c[14113936+(f<<2)>>2]=c[2076596];c[9669104+(f<<2)>>2]=c[3541536];c[1836236]=-1;f=c[2439331]|0;d=(f|0)==0;if(!d){e=f;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;e=c[2438119]|0;c[2433530]=e;g=c[3528485]|0;c[2076596]=g;h=c[2417277]|0;c[3541536]=h;c[1836236]=1;a[9706117]=1;if(!d){d=f;gGC(d|0,9706056,76)|0}c[2438119]=e;c[3528485]=g;c[2417277]=h;c[1836236]=-1;h=c[2439330]|0;if((h|0)!=0){g=h;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;return}else{return}}function aVF(a){a=a|0;var b=0,c=0;b=a&65535;switch(b|0){case 28672:case 28673:case 28674:case 28675:{c=S3(0,b-28672|0)|0;break};case 30720:case 30721:case 30722:case 30723:{c=S3(1,b-30720|0)|0;break};default:{c=-1}}return c|0}function aVG(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((b+26624&65535)<256){b=e-38912|0;a[(c[3541366]|0)+b|0]=d;if(!((b|0)<64&(b&1|0)==0)){return}a[(c[3541380]|0)+(b>>1)|0]=d;return}if((e|0)==28672|(e|0)==28673|(e|0)==28674|(e|0)==28675){S4(0,e-28672|0,d);return}else if((e|0)==30720|(e|0)==30721|(e|0)==30722|(e|0)==30723){S4(1,e-30720|0,d);return}else if((e|0)==43009){a[14165768]=d&1;return}else if((e|0)==43014){a[14165832]=d&1;return}else if((e|0)==43015){a[14165824]=d&1;return}else{return}}function aVH(a){a=a|0;var b=0,c=0,d=0;b=a&65535;if((a+32512&65535)<16){c=b-33024|0;d=S3(0,c>>>2&2|c>>>1&1)|0;return d|0}if((a+32256&65535)>=16){d=-1;return d|0}a=b-33280|0;d=S3(1,a>>>2&2|a>>>1&1)|0;return d|0}function aVI(b,d){b=b|0;d=d|0;var e=0,f=0;e=b&65535;if((b-20480&65535)<256){f=e-20480|0;a[(c[3541366]|0)+f|0]=d;if(!((f|0)<64&(f&1|0)==0)){return}a[(c[3541380]|0)+(f>>1)|0]=d;return}if((b+32512&65535)<16){f=e-33024|0;S4(0,f>>>2&2|f>>>1&1,d);return}if((b+32256&65535)<16){b=e-33280|0;S4(1,b>>>2&2|b>>>1&1,d);return}if((e|0)==26625){b=d&1;c[3541360]=b;if((b|0)!=0){return}c[3541358]=-1;return}else if((e|0)==26626){a[14165768]=d&1;return}else if((e|0)==26633){a[14165832]=d&1;return}else if((e|0)==26635){a[14165824]=d&1;return}else{return}}function aVJ(a){a=a|0;var b=0,c=0,d=0;b=a&65535;if((a+32256&65535)<16){c=b-33280|0;d=S3(1,c>>>2&2|c>>>1&1)|0;return d|0}if((a+16128&65535)>=16){d=-1;return d|0}a=b-49408|0;d=S3(0,a>>>2&2|a>>>1&1)|0;return d|0}function aVK(b,d){b=b|0;d=d|0;var e=0,f=0;e=b&65535;if((b-20480&65535)<256){f=e-20480|0;a[(c[3541366]|0)+f|0]=d;if(!((f|0)<64&(f&1|0)==0)){return}a[(c[3541380]|0)+(f>>1)|0]=d;return}if((b+32256&65535)<16){f=e-33280|0;S4(1,f>>>2&2|f>>>1&1,d);return}if((b+16128&65535)<16){b=e-49408|0;S4(0,b>>>2&2|b>>>1&1,d);return}if((e|0)==26625){b=d&1;c[3541360]=b;if((b|0)!=0){return}c[3541358]=-1;return}else if((e|0)==26635){a[14165824]=d&1;return}else if((e|0)==26626){a[14165768]=d&1;return}else if((e|0)==26633){a[14165832]=d&1;return}else{return}}function aVL(b,d){b=b|0;d=d|0;var e=0,f=0;e=b&65535;if((b-20480&65535)<256){f=e-20480|0;a[(c[3541366]|0)+f|0]=d;if(!((f|0)<64&(f&1|0)==0)){return}a[(c[3541380]|0)+(f>>1)|0]=d;return}if((b+32512&65535)<16){f=e-33024|0;S4(0,f>>>2&2|f>>>1&1,d);return}if((b+32256&65535)<16){b=e-33280|0;S4(1,b>>>2&2|b>>>1&1,d);return}if((e|0)==26625){a[14165768]=d&1;return}else if((e|0)==26633){a[14165832]=d&1;return}else if((e|0)==26635){a[14165824]=d&1;return}else{return}}function aVM(b){b=b|0;var c=0,d=0;c=b&65535;if((c|0)==32768){d=a[14165872]|a[14165808]}else if((c|0)==32769){d=a[14165873]|a[14165809]}else if((c|0)==32770){d=a[14165874]|a[14165810]}else if((c|0)==32771){d=a[14165875]|a[14165811]}else{d=-1}return d|0}function aVN(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=d&65535;if((d-20480&65535)<256){d=f-20480|0;a[(c[3541366]|0)+d|0]=e;if(!((d|0)<64&(d&1|0)==0)){return}a[(c[3541380]|0)+(d>>1)|0]=e;return}if((f|0)==24582){a[c[3541454]|0]=e&1;return}else if((f|0)==26625){a[14165768]=e&1;return}else if((f|0)==32768){a[14165504]=e;return}else if((f|0)==36864){d=c[1836236]|0;g=c[9757320+(d<<2)>>2]|0;if((g|0)!=0){h=g;gGC(h|0,9706056,76)|0}c[9752472+(d<<2)>>2]=c[2433530];c[14113936+(d<<2)>>2]=c[2076596];c[9669104+(d<<2)>>2]=c[3541536];c[1836236]=-1;d=c[2439331]|0;h=(d|0)==0;if(!h){g=d;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;g=c[2438119]|0;c[2433530]=g;i=c[3528485]|0;c[2076596]=i;j=c[2417277]|0;c[3541536]=j;c[1836236]=1;a[9706117]=1;if(!h){h=d;gGC(h|0,9706056,76)|0}c[2438119]=g;c[3528485]=i;c[2417277]=j;c[1836236]=-1;j=c[2439330]|0;if((j|0)!=0){i=j;gGC(9706056,i|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;return}else if((f|0)==24580){f=e&1;a[14165832]=f;a[14165824]=f;return}else{return}}function aVO(b){b=b|0;var d=0,e=0,f=0;d=b&255;if((d|0)==32){b=c[3542228]|0;if((b|0)>15){e=0;return e|0}do{if((b|0)==14){f=c[3542224]|0;if((f|0)==0){break}a[14168930]=gj[f&4095](0)|0}else if((b|0)==15){f=c[3542225]|0;if((f|0)==0){break}a[14168931]=gj[f&4095](0)|0}}while(0);e=a[14168916+b|0]|0;return e|0}else if((d|0)==64){d=c[3542291]|0;if((d|0)>15){e=0;return e|0}do{if((d|0)==15){b=c[3542288]|0;if((b|0)==0){break}a[14169183]=gj[b&4095](0)|0}else if((d|0)==14){b=c[3542287]|0;if((b|0)==0){break}a[14169182]=gj[b&4095](0)|0}}while(0);e=a[14169168+d|0]|0;return e|0}else{e=0;return e|0}return 0}function aVP(b,d){b=b|0;d=d|0;var e=0,f=0;e=b&255;if((e|0)==16){c[3542228]=d&15;return}else if((e|0)==128){c[3542291]=d&15;return}else if((e|0)==64){b=d&255;f=c[3542291]|0;if((f|0)>15){return}do{if((f|0)<14){if((f|0)!=13){if((a[14169168+f|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(1,f,b);return}else if((e|0)==32){e=d&255;b=c[3542228]|0;if((b|0)>15){return}do{if((b|0)<14){if((b|0)!=13){if((a[14168916+b|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(0,b,e);return}else{return}}function aVQ(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if(b<<16>>16>=0){d=-1;return d|0}e=(a[14168304]|0)==0;a[14168304]=e&1;f=c[3541328]|0;g=e?16384:0;e=c[9757320+(c[1836236]<<2)>>2]|0;h=0;i=0;while(1){c[e+76+(i<<2)>>2]=f+((i<<8)+g);j=h+1&65535;if((j&65535)>31){break}else{h=j;i=j&65535}}i=b&65535;b=0;h=0;while(1){j=f+((h<<8)+g)|0;c[e+76+(h+512<<2)>>2]=j;c[e+76+(h+768<<2)>>2]=j;j=b+1&65535;if((j&65535)>31){break}else{b=j;h=j&65535}}h=i-32768|0;if((h&256|0)==0){k=-1}else{k=S3(0,h&3)|0}if((h&512|0)==0){d=k;return d|0}d=(S3(1,h&3)|0)&k;return d|0}function aVR(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=b&65535;if((b-20480&65535)<256){f=e-20480|0;a[(c[3541366]|0)+f|0]=d;if(!((f|0)<64&(f&1|0)==0)){return}a[(c[3541380]|0)+(f>>1)|0]=d;return}if(b<<16>>16<0){b=(a[14168304]|0)==0;a[14168304]=b&1;f=c[3541328]|0;g=b?16384:0;b=c[9757320+(c[1836236]<<2)>>2]|0;h=0;i=0;while(1){c[b+76+(i<<2)>>2]=f+((i<<8)+g);j=h+1&65535;if((j&65535)>31){k=0;l=0;break}else{h=j;i=j&65535}}while(1){i=f+((l<<8)+g)|0;c[b+76+(l+512<<2)>>2]=i;c[b+76+(l+768<<2)>>2]=i;i=k+1&65535;if((i&65535)>31){break}else{k=i;l=i&65535}}l=e-32768|0;if((l&256|0)!=0){S4(0,l&3,d)}if((l&512|0)==0){return}S4(1,l&3,d);return}switch(e|0){case 26627:{a[14165928]=d&1;return};case 26628:{e=d&1;c[3541360]=e;if((e|0)!=0){return}c[3541358]=-1;return};case 26630:{a[14165832]=d&1;return};case 26631:{a[14165824]=d&1;return};case 26625:{a[14165768]=d&1;return};default:{return}}}function aVS(a){a=a|0;var b=0,c=0;b=a&65535;switch(b|0){case 33024:case 33025:case 33026:case 33027:{c=S3(0,b-33024|0)|0;break};case 33283:case 33280:case 33281:case 33282:{c=S3(1,b-33280|0)|0;break};default:{c=-1}}return c|0}function aVT(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((b-20480&65535)<256){b=e-20480|0;a[(c[3541366]|0)+b|0]=d;if(!((b|0)<64&(b&1|0)==0)){return}a[(c[3541380]|0)+(b>>1)|0]=d;return}switch(e|0){case 26625:{a[14165768]=d&1;return};case 26631:{a[14165824]=d&1;return};case 33283:case 33282:case 33280:case 33281:{S4(1,e-33280|0,d);return};case 26628:{a[14165928]=d&1;return};case 26630:{a[14165832]=d&1;return};case 26624:{a[c[3541454]|0]=d&1;return};case 33024:case 33025:case 33026:case 33027:{S4(0,e-33024|0,d);return};case 26626:{a[(c[3541454]|0)+1|0]=d&1;return};default:{return}}}function aVU(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6034348+(b*112|0)>>2];c[a+104>>2]=c[6034352+(b*112|0)>>2];c[a+108>>2]=c[6034356+(b*112|0)>>2];d=0;return d|0}function aVV(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=6034248+(b*112|0);e=0;return e|0}function aVW(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3320832+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aVX(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6035480+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aVY(){var b=0;c[3541404]=6622;a[14165488]=9;b=a04()|0;a0U();c[3541392]=1636;c[3541466]=94;gGz(9668984|0,0|0,27|0);S6(0,27,0);gGz(9669011|0,0|0,27|0);S6(1,27,0);c[3540906]=1550;c[3540904]=600;c[3540902]=240;c[3540890]=432;c[3540888]=1374;c[3540886]=1502;h[1220314]=.02;h[1220324]=.02;h[1220334]=.02;h[1220344]=.02;h[1220354]=.02;h[1220364]=.02;return b|0}function aVZ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4929356+(b*112|0)>>2];c[a+104>>2]=c[4929360+(b*112|0)>>2];c[a+108>>2]=c[4929364+(b*112|0)>>2];d=0;return d|0}function aV_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=4929256+(b*112|0);e=0;return e|0}function aV$(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3516644+(b*112|0)>>2];c[a+104>>2]=c[3516648+(b*112|0)>>2];c[a+108>>2]=c[3516652+(b*112|0)>>2];d=0;return d|0}function aV0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=3516544+(b*112|0);e=0;return e|0}function aV1(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1201272+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aV2(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3518112+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aV3(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1742564+(b*112|0)>>2];c[a+104>>2]=c[1742568+(b*112|0)>>2];c[a+108>>2]=c[1742572+(b*112|0)>>2];d=0;return d|0}function aV4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=1742464+(b*112|0);e=0;return e|0}function aV5(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1198236+(b*112|0)>>2];c[a+104>>2]=c[1198240+(b*112|0)>>2];c[a+108>>2]=c[1198244+(b*112|0)>>2];d=0;return d|0}function aV6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=1198136+(b*112|0);e=0;return e|0}function aV7(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5086908+(b*112|0)>>2];c[a+104>>2]=c[5086912+(b*112|0)>>2];c[a+108>>2]=c[5086916+(b*112|0)>>2];d=0;return d|0}function aV8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=5086808+(b*112|0);e=0;return e|0}function aV9(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5085340+(b*112|0)>>2];c[a+104>>2]=c[5085344+(b*112|0)>>2];c[a+108>>2]=c[5085348+(b*112|0)>>2];d=0;return d|0}function aWa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=5085240+(b*112|0);e=0;return e|0}function aWb(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1199804+(b*112|0)>>2];c[a+104>>2]=c[1199808+(b*112|0)>>2];c[a+108>>2]=c[1199812+(b*112|0)>>2];d=0;return d|0}function aWc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=1199704+(b*112|0);e=0;return e|0}function aWd(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3356268+(b*112|0)>>2];c[a+104>>2]=c[3356272+(b*112|0)>>2];c[a+108>>2]=c[3356276+(b*112|0)>>2];d=0;return d|0}function aWe(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=3356168+(b*112|0);e=0;return e|0}function aWf(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3357736+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aWg(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3998412+(b*112|0)>>2];c[a+104>>2]=c[3998416+(b*112|0)>>2];c[a+108>>2]=c[3998420+(b*112|0)>>2];d=0;return d|0}function aWh(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=3998312+(b*112|0);e=0;return e|0}function aWi(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1272024+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aWj(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>54){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3999320+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aWk(){var b=0;c[3541404]=11232;a[14165488]=10;b=a04()|0;a0U();c[3541392]=8638;c[3541466]=60;gGz(9668984|0,0|0,27|0);S6(0,27,0);gGz(9669011|0,0|0,27|0);S6(1,27,0);c[3540906]=1550;c[3540904]=600;c[3540902]=240;c[3540890]=432;c[3540888]=1374;c[3540886]=1502;return b|0}function aWl(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6413740+(b*112|0)>>2];c[a+104>>2]=c[6413744+(b*112|0)>>2];c[a+108>>2]=c[6413748+(b*112|0)>>2];d=0;return d|0}function aWm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=6413640+(b*112|0);e=0;return e|0}function aWn(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4259756+(b*112|0)>>2];c[a+104>>2]=c[4259760+(b*112|0)>>2];c[a+108>>2]=c[4259764+(b*112|0)>>2];d=0;return d|0}function aWo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=4259656+(b*112|0);e=0;return e|0}function aWp(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1313920+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aWq(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4261e3+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aWr(){var b=0;c[3541404]=6622;a[14165488]=9;b=a04()|0;a0U();c[3541392]=8638;c[3541466]=60;gGz(9668984|0,0|0,27|0);S6(0,27,0);gGz(9669011|0,0|0,27|0);S6(1,27,0);c[3540906]=1550;c[3540904]=600;c[3540902]=240;c[3540890]=432;c[3540888]=1374;c[3540886]=1502;h[1220314]=.25;h[1220324]=.25;h[1220334]=.25;h[1220344]=.25;h[1220354]=.25;h[1220364]=.25;return b|0}function aWs(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2012508+(b*112|0)>>2];c[a+104>>2]=c[2012512+(b*112|0)>>2];c[a+108>>2]=c[2012516+(b*112|0)>>2];d=0;return d|0}function aWt(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=2012408+(b*112|0);e=0;return e|0}function aWu(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6397972+(b*112|0)>>2];c[a+104>>2]=c[6397976+(b*112|0)>>2];c[a+108>>2]=c[6397980+(b*112|0)>>2];d=0;return d|0}function aWv(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=6397872+(b*112|0);e=0;return e|0}function aWw(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4158384+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aWx(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6399104+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aWy(){var b=0;c[3541404]=9088;a[14165488]=9;b=a04()|0;a0U();gGz(9668984|0,0|0,27|0);S6(0,27,0);gGz(9669011|0,0|0,27|0);S6(1,27,0);c[3540906]=1550;c[3540904]=600;c[3540902]=240;c[3540890]=432;c[3540888]=1374;c[3540886]=1502;c[3541464]=52;a[14165472]=7;a[14165480]=-10;return b|0}function aWz(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7189524+(b*112|0)>>2];c[a+104>>2]=c[7189528+(b*112|0)>>2];c[a+108>>2]=c[7189532+(b*112|0)>>2];d=0;return d|0}function aWA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=7189424+(b*112|0);e=0;return e|0}function aWB(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>25){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6242896+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aWC(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7190768+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aWD(){var b=0;c[3541404]=12702;a[14165488]=9;b=a04()|0;a0U();c[3541392]=8638;c[3541466]=60;gGz(9668984|0,0|0,27|0);S6(0,27,0);gGz(9669011|0,0|0,27|0);S6(1,27,0);c[3540906]=1550;c[3540904]=600;c[3540902]=240;c[3540890]=432;c[3540888]=1374;c[3540886]=1502;return b|0}function aWE(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4068500+(b*112|0)>>2];c[a+104>>2]=c[4068504+(b*112|0)>>2];c[a+108>>2]=c[4068508+(b*112|0)>>2];d=0;return d|0}function aWF(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=4068400+(b*112|0);e=0;return e|0}function aWG(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1283432+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aWH(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4069968+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aWI(){var b=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;b=i;i=i+240|0;e=b|0;f=b+112|0;g=b+120|0;j=b+232|0;c[3541404]=12702;a[14165488]=9;a04()|0;a0U();c[3541414]=256;c[3541412]=64;c[1865546]=32768;c[1865412]=32768;k=c[3541348]|0;l=0;while(1){if((l|0)>=1024){m=0;break}n=9638528+(l<<2)|0;if((c[n>>2]|0)==0){o=42039;break}else{l=l+1|0}}do{if((o|0)==42039){l=gGq(k)|0;c[n>>2]=l;if((l|0)==0){m=0;break}gGz(l|0,0,k|0);m=l}}while(0);c[3541356]=m;k=(c[3541318]|0)+(c[3541326]|0)+(c[3541312]|0)|0;if((c[3542200]|0)==0){p=1;i=b;return p|0}n=g+108|0;c[n>>2]=0;l=g+100|0;c[l>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,k)|0;do{if((c[n>>2]|0)!=0){g=c[l>>2]|0;c[j>>2]=9534384;q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[q&16383](j,k,0)|0;if((g|0)<1){p=1;i=b;return p|0}if((gzL(m,0,k)|0)==0){break}else{p=1}i=b;return p|0}}while(0);k=(c[3541356]|0)+4096|0;m=(c[3541326]|0)+1+(c[3541318]|0)+(c[3541312]|0)|0;if((c[3542200]|0)==0){p=1;i=b;return p|0}j=e+108|0;c[j>>2]=0;l=e+100|0;c[l>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,m)|0;do{if((c[j>>2]|0)!=0){e=c[l>>2]|0;c[f>>2]=9534384;n=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[n&16383](f,m,0)|0;if((e|0)<1){p=1;i=b;return p|0}if((gzL(k,0,m)|0)==0){break}else{p=1}i=b;return p|0}}while(0);m=c[3541414]|0;k=c[3541356]|0;f=c[3541472]|0;if((m|0)>0){l=c[1865546]|0;j=0;do{e=j<<6;gGz(f+e|0,0,64);n=0;do{g=e+(c[1238464+(n<<2)>>2]|0)|0;q=(n<<3)+e|0;r=0;do{s=g+(c[614800+(r<<2)>>2]|0)|0;if(((d[k+((s|0)/8|0)|0]|0)&128>>>((s&7)>>>0)|0)!=0){s=f+(q+r)|0;a[s]=a[s]|2}r=r+1|0;}while((r|0)<8);n=n+1|0;}while((n|0)<8);n=l+e|0;r=0;do{q=n+(c[1238464+(r<<2)>>2]|0)|0;g=(r<<3)+e|0;s=0;do{t=q+(c[614800+(s<<2)>>2]|0)|0;if(((d[k+((t|0)/8|0)|0]|0)&128>>>((t&7)>>>0)|0)!=0){t=f+(g+s)|0;a[t]=a[t]|1}s=s+1|0;}while((s|0)<8);r=r+1|0;}while((r|0)<8);j=j+1|0;}while((j|0)<(m|0))}m=c[3541412]|0;j=c[3541364]|0;if((m|0)>0){f=c[1865412]|0;l=0;while(1){r=l<<8;gGz(j+r|0,0,256);e=0;do{n=r+(c[611776+(e<<2)>>2]|0)|0;s=(e<<4)+r|0;g=0;do{q=n+(c[601400+(g<<2)>>2]|0)|0;if(((d[k+(((q|0)/8|0)+2048)|0]|0)&128>>>((q&7)>>>0)|0)!=0){q=j+(s+g)|0;a[q]=a[q]|2}g=g+1|0;}while((g|0)<16);e=e+1|0;}while((e|0)<16);e=f+r|0;g=0;do{s=e+(c[611776+(g<<2)>>2]|0)|0;n=(g<<4)+r|0;q=0;do{t=s+(c[601400+(q<<2)>>2]|0)|0;if(((d[k+(((t|0)/8|0)+2048)|0]|0)&128>>>((t&7)>>>0)|0)!=0){t=j+(n+q)|0;a[t]=a[t]|1}q=q+1|0;}while((q|0)<16);g=g+1|0;}while((g|0)<16);g=l+1|0;if((g|0)<(m|0)){l=g}else{u=0;break}}}else{u=0}while(1){if((u|0)>=1024){break}v=9638528+(u<<2)|0;if((c[v>>2]|0)==(k|0)){o=42069;break}else{u=u+1|0}}if((o|0)==42069){gGr(k);c[v>>2]=0}c[3541356]=0;c[3541392]=8638;c[3541466]=60;gGz(9668984,0,27);S6(0,27,0);gGz(9669011,0,27);S6(1,27,0);c[3540906]=1550;c[3540904]=600;c[3540902]=240;c[3540890]=432;c[3540888]=1374;c[3540886]=1502;h[1220314]=.75;h[1220324]=.75;h[1220334]=.75;h[1220344]=.75;h[1220354]=.75;h[1220364]=.75;p=0;i=b;return p|0}function aWJ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5223188+(b*112|0)>>2];c[a+104>>2]=c[5223192+(b*112|0)>>2];c[a+108>>2]=c[5223196+(b*112|0)>>2];d=0;return d|0}function aWK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=5223088+(b*112|0);e=0;return e|0}function aWL(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5224432+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aWM(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;b=i;i=i+360|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;c[3541404]=12952;a[14165488]=9;a04()|0;a0U();c[3541414]=256;c[3541412]=64;l=c[3541348]|0;m=0;while(1){if((m|0)>=1024){n=0;break}o=9638528+(m<<2)|0;if((c[o>>2]|0)==0){p=42113;break}else{m=m+1|0}}do{if((p|0)==42113){m=gGq(l)|0;c[o>>2]=m;if((m|0)==0){n=0;break}gGz(m|0,0,l|0);n=m}}while(0);c[3541356]=n;l=(c[3541318]|0)+(c[3541326]|0)+(c[3541312]|0)|0;if((c[3542200]|0)==0){q=1;i=b;return q|0}o=j+108|0;c[o>>2]=0;m=j+100|0;c[m>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,l)|0;do{if((c[o>>2]|0)!=0){j=c[m>>2]|0;c[k>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](k,l,0)|0;if((j|0)<1){q=1;i=b;return q|0}if((gzL(n,0,l)|0)==0){break}else{q=1}i=b;return q|0}}while(0);l=(c[3541356]|0)+4096|0;n=(c[3541326]|0)+1+(c[3541318]|0)+(c[3541312]|0)|0;if((c[3542200]|0)==0){q=1;i=b;return q|0}k=g+108|0;c[k>>2]=0;m=g+100|0;c[m>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,n)|0;do{if((c[k>>2]|0)!=0){g=c[m>>2]|0;c[h>>2]=9534384;o=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[o&16383](h,n,0)|0;if((g|0)<1){q=1;i=b;return q|0}if((gzL(l,0,n)|0)==0){break}else{q=1}i=b;return q|0}}while(0);n=(c[3541356]|0)+8192|0;l=(c[3541326]|0)+2+(c[3541318]|0)+(c[3541312]|0)|0;if((c[3542200]|0)==0){q=1;i=b;return q|0}h=e+108|0;c[h>>2]=0;m=e+100|0;c[m>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,l)|0;do{if((c[h>>2]|0)!=0){e=c[m>>2]|0;c[f>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](f,l,0)|0;if((e|0)<1){q=1;i=b;return q|0}if((gzL(n,0,l)|0)==0){break}else{q=1}i=b;return q|0}}while(0);l=c[3541414]|0;n=c[3541356]|0;f=c[3541472]|0;if((l|0)>0){m=0;do{h=m<<6;gGz(f+h|0,0,64);e=h+65536|0;k=0;while(1){g=e+(c[1238464+(k<<2)>>2]|0)|0;o=(k<<3)+h|0;j=0;do{r=g+(c[614800+(j<<2)>>2]|0)|0;if(((d[n+((r|0)/8|0)|0]|0)&128>>>((r&7)>>>0)|0)!=0){r=f+(o+j)|0;a[r]=a[r]|4}j=j+1|0;}while((j|0)<8);j=k+1|0;if((j|0)<8){k=j}else{s=0;break}}do{k=h+(c[1238464+(s<<2)>>2]|0)|0;e=(s<<3)+h|0;j=0;do{o=k+(c[614800+(j<<2)>>2]|0)|0;if(((d[n+((o|0)/8|0)|0]|0)&128>>>((o&7)>>>0)|0)!=0){o=f+(e+j)|0;a[o]=a[o]|2}j=j+1|0;}while((j|0)<8);s=s+1|0;}while((s|0)<8);j=h+32768|0;e=0;do{k=j+(c[1238464+(e<<2)>>2]|0)|0;o=(e<<3)+h|0;g=0;do{r=k+(c[614800+(g<<2)>>2]|0)|0;if(((d[n+((r|0)/8|0)|0]|0)&128>>>((r&7)>>>0)|0)!=0){r=f+(o+g)|0;a[r]=a[r]|1}g=g+1|0;}while((g|0)<8);e=e+1|0;}while((e|0)<8);m=m+1|0;}while((m|0)<(l|0))}l=c[3541412]|0;m=c[3541364]|0;if((l|0)>0){f=0;while(1){s=f<<8;gGz(m+s|0,0,256);e=s+65536|0;h=0;while(1){j=e+(c[611776+(h<<2)>>2]|0)|0;g=(h<<4)+s|0;o=0;do{k=j+(c[601400+(o<<2)>>2]|0)|0;if(((d[n+(((k|0)/8|0)+2048)|0]|0)&128>>>((k&7)>>>0)|0)!=0){k=m+(g+o)|0;a[k]=a[k]|4}o=o+1|0;}while((o|0)<16);o=h+1|0;if((o|0)<16){h=o}else{t=0;break}}do{h=s+(c[611776+(t<<2)>>2]|0)|0;e=(t<<4)+s|0;o=0;do{g=h+(c[601400+(o<<2)>>2]|0)|0;if(((d[n+(((g|0)/8|0)+2048)|0]|0)&128>>>((g&7)>>>0)|0)!=0){g=m+(e+o)|0;a[g]=a[g]|2}o=o+1|0;}while((o|0)<16);t=t+1|0;}while((t|0)<16);o=s+32768|0;e=0;do{h=o+(c[611776+(e<<2)>>2]|0)|0;g=(e<<4)+s|0;j=0;do{k=h+(c[601400+(j<<2)>>2]|0)|0;if(((d[n+(((k|0)/8|0)+2048)|0]|0)&128>>>((k&7)>>>0)|0)!=0){k=m+(g+j)|0;a[k]=a[k]|1}j=j+1|0;}while((j|0)<16);e=e+1|0;}while((e|0)<16);e=f+1|0;if((e|0)<(l|0)){f=e}else{u=0;break}}}else{u=0}while(1){if((u|0)>=1024){break}v=9638528+(u<<2)|0;if((c[v>>2]|0)==(n|0)){p=42143;break}else{u=u+1|0}}if((p|0)==42143){gGr(n);c[v>>2]=0}c[3541356]=0;c[3541392]=8638;c[3541466]=60;a[14165880]=3;a[14165472]=0;a[14165480]=-10;gGz(9668984,0,27);S6(0,27,0);gGz(9669011,0,27);S6(1,27,0);c[3540906]=1550;c[3540904]=600;c[3540902]=240;c[3540890]=432;c[3540888]=1374;c[3540886]=1502;q=0;i=b;return q|0}function aWN(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3700804+(b*112|0)>>2];c[a+104>>2]=c[3700808+(b*112|0)>>2];c[a+108>>2]=c[3700812+(b*112|0)>>2];d=0;return d|0}function aWO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=3700704+(b*112|0);e=0;return e|0}function aWP(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1228440+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aWQ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3701600+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aWR(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;b=i;i=i+120|0;e=b|0;f=b+112|0;c[3541404]=1718;a[14165488]=9;a04()|0;a0U();g=c[3541348]|0;h=0;while(1){if((h|0)>=1024){j=0;break}k=9638528+(h<<2)|0;if((c[k>>2]|0)==0){l=42209;break}else{h=h+1|0}}do{if((l|0)==42209){h=gGq(g)|0;c[k>>2]=h;if((h|0)==0){j=0;break}gGz(h|0,0,g|0);j=h}}while(0);c[3541356]=j;g=(c[3541318]|0)+(c[3541326]|0)+(c[3541312]|0)|0;if((c[3542200]|0)==0){m=1;i=b;return m|0}k=e+108|0;c[k>>2]=0;h=e+100|0;c[h>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,g)|0;do{if((c[k>>2]|0)!=0){e=c[h>>2]|0;c[f>>2]=9534384;n=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[n&16383](f,g,0)|0;if((e|0)<1){m=1;i=b;return m|0}if((gzL(j,0,g)|0)==0){break}else{m=1}i=b;return m|0}}while(0);g=c[3541414]|0;j=c[3541356]|0;f=c[3541472]|0;if((g|0)>0){h=0;do{k=h<<6;gGz(f+k|0,0,64);e=h<<7;n=0;do{o=e+(c[1238464+(n<<2)>>2]|0)|0;p=(n<<3)+k|0;q=0;do{r=o+(c[610928+(q<<2)>>2]|0)|0;if(((d[j+((r|0)/8|0)|0]|0)&128>>>((r&7)>>>0)|0)!=0){r=f+(p+q)|0;a[r]=a[r]|2}q=q+1|0;}while((q|0)<8);n=n+1|0;}while((n|0)<8);n=e|4;q=0;do{p=n+(c[1238464+(q<<2)>>2]|0)|0;o=(q<<3)+k|0;r=0;do{s=p+(c[610928+(r<<2)>>2]|0)|0;if(((d[j+((s|0)/8|0)|0]|0)&128>>>((s&7)>>>0)|0)!=0){s=f+(o+r)|0;a[s]=a[s]|1}r=r+1|0;}while((r|0)<8);q=q+1|0;}while((q|0)<8);h=h+1|0;}while((h|0)<(g|0))}g=c[3541412]|0;h=c[3541364]|0;if((g|0)>0){f=0;while(1){q=f<<8;gGz(h+q|0,0,256);k=f<<9;n=0;do{e=k+(c[611712+(n<<2)>>2]|0)|0;r=(n<<4)+q|0;o=0;do{p=e+(c[608448+(o<<2)>>2]|0)|0;if(((d[j+((p|0)/8|0)|0]|0)&128>>>((p&7)>>>0)|0)!=0){p=h+(r+o)|0;a[p]=a[p]|2}o=o+1|0;}while((o|0)<16);n=n+1|0;}while((n|0)<16);n=k|4;o=0;do{r=n+(c[611712+(o<<2)>>2]|0)|0;e=(o<<4)+q|0;p=0;do{s=r+(c[608448+(p<<2)>>2]|0)|0;if(((d[j+((s|0)/8|0)|0]|0)&128>>>((s&7)>>>0)|0)!=0){s=h+(e+p)|0;a[s]=a[s]|1}p=p+1|0;}while((p|0)<16);o=o+1|0;}while((o|0)<16);o=f+1|0;if((o|0)<(g|0)){f=o}else{t=0;break}}}else{t=0}while(1){if((t|0)>=1024){break}u=9638528+(t<<2)|0;if((c[u>>2]|0)==(j|0)){l=42233;break}else{t=t+1|0}}if((l|0)==42233){gGr(j);c[u>>2]=0}c[3541356]=0;c[3541392]=8638;c[3541466]=60;gGz(9668984,0,27);S6(0,27,0);gGz(9669011,0,27);S6(1,27,0);c[3540906]=1550;c[3540904]=600;c[3540902]=240;c[3540890]=432;c[3540888]=1374;c[3540886]=1502;m=0;i=b;return m|0}function aWS(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1820924+(b*112|0)>>2];c[a+104>>2]=c[1820928+(b*112|0)>>2];c[a+108>>2]=c[1820932+(b*112|0)>>2];d=0;return d|0}function aWT(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=1820824+(b*112|0);e=0;return e|0}function aWU(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5258268+(b*112|0)>>2];c[a+104>>2]=c[5258272+(b*112|0)>>2];c[a+108>>2]=c[5258276+(b*112|0)>>2];d=0;return d|0}function aWV(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=5258168+(b*112|0);e=0;return e|0}function aWW(){var b=0;c[3541404]=7420;a[14165488]=9;b=a04()|0;a0U();c[3541392]=8638;c[3541466]=60;gGz(9668984|0,0|0,27|0);S6(0,27,0);gGz(9669011|0,0|0,27|0);S6(1,27,0);c[3540906]=1550;c[3540904]=600;c[3540902]=240;c[3540890]=432;c[3540888]=1374;c[3540886]=1502;return b|0}function aWX(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3699460+(b*112|0)>>2];c[a+104>>2]=c[3699464+(b*112|0)>>2];c[a+108>>2]=c[3699468+(b*112|0)>>2];d=0;return d|0}function aWY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=3699360+(b*112|0);e=0;return e|0}function aWZ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3861180+(b*112|0)>>2];c[a+104>>2]=c[3861184+(b*112|0)>>2];c[a+108>>2]=c[3861188+(b*112|0)>>2];d=0;return d|0}function aW_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=3861080+(b*112|0);e=0;return e|0}function aW$(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1239376+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aW0(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>53){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3862088+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aW1(){var d=0,e=0,f=0,g=0,h=0;c[3541404]=3484;a[14165488]=9;d=a04()|0;a0U();e=c[2439331]|0;f=(e|0)==0;if(!f){g=e;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];g=c[3528485]|0;c[2076596]=g;h=c[2417277]|0;c[3541536]=h;c[1836236]=1;c[e+4172>>2]=2798;c[e+4176>>2]=2538;if(!f){f=e;gGC(f|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=g;c[2417277]=h;c[1836236]=-1;c[3541462]=14;a[14165472]=7;a[14165480]=-10;return d|0}function aW2(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1869700+(b*112|0)>>2];c[a+104>>2]=c[1869704+(b*112|0)>>2];c[a+108>>2]=c[1869708+(b*112|0)>>2];d=0;return d|0}function aW3(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=1869600+(b*112|0);e=0;return e|0}function aW4(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5548428+(b*112|0)>>2];c[a+104>>2]=c[5548432+(b*112|0)>>2];c[a+108>>2]=c[5548436+(b*112|0)>>2];d=0;return d|0}function aW5(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=5548328+(b*112|0);e=0;return e|0}function aW6(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5549112+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aW7(){var b=0;c[3541404]=7622;a[14165488]=9;b=a04()|0;a0U();c[3541392]=8638;c[3541466]=60;c[3541464]=52;gGz(9668984|0,0|0,27|0);S6(0,27,0);gGz(9669011|0,0|0,27|0);S6(1,27,0);c[3540906]=1550;c[3540904]=600;c[3540902]=240;c[3540890]=432;c[3540888]=1374;c[3540886]=1502;h[1220314]=.2;h[1220324]=.2;h[1220334]=.2;h[1220344]=.2;h[1220354]=.2;h[1220364]=.2;return b|0}function aW8(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3734780+(b*112|0)>>2];c[a+104>>2]=c[3734784+(b*112|0)>>2];c[a+108>>2]=c[3734788+(b*112|0)>>2];d=0;return d|0}function aW9(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=3734680+(b*112|0);e=0;return e|0}function aXa(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3739504+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aXb(){var b=0;c[3541404]=574;a[14165488]=9;b=a04()|0;a0U();c[3541392]=8638;c[3541466]=60;c[3541462]=66;c[3541464]=32;gGz(9668984|0,0|0,27|0);S6(0,27,0);gGz(9669011|0,0|0,27|0);S6(1,27,0);c[3540906]=1550;c[3540904]=600;c[3540902]=240;c[3540890]=432;c[3540888]=1374;c[3540886]=1502;h[1220314]=.2;h[1220324]=.2;h[1220334]=.2;h[1220344]=.2;h[1220354]=.2;h[1220364]=.2;return b|0}function aXc(d){d=d|0;var e=0,f=0,g=0;e=d&255;if((e|0)==1){d=c[3542228]|0;if((d|0)>15){f=0;return f|0}do{if((d|0)==14){g=c[3542224]|0;if((g|0)==0){break}a[14168930]=gj[g&4095](0)|0}else if((d|0)==15){g=c[3542225]|0;if((g|0)==0){break}a[14168931]=gj[g&4095](0)|0}}while(0);f=a[14168916+d|0]|0;return f|0}else if((e|0)==2){d=b[4853030]|0;if(d<<16>>16==346){f=-1;return f|0}f=d<<16>>16==2182?5:0;return f|0}else if((e|0)==3){f=(b[4853030]|0)==349?4:0;return f|0}else{f=0;return f|0}return 0}function aXd(b,d){b=b|0;d=d|0;var e=0,f=0;e=b&255;if((e|0)==0){b=d&255;f=c[3542228]|0;if((f|0)>15){return}do{if((f|0)<14){if((f|0)!=13){if((a[14168916+f|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(0,f,b);return}else if((e|0)==1){c[3542228]=d&15;return}else{return}}function aXe(a){a=a|0;var b=0,c=0,d=0,e=0;b=a&65535;do{if(a<<16>>16<0){if((a<<16>>16|0)==(-19455|0)){c=7;break}else if((a<<16>>16|0)==(-28664|0)){c=3;break}d=b-32768|0;if((d&256|0)==0){e=-1}else{e=S3(0,d&3)|0}if((d&512|0)==0){c=e;break}c=(S3(1,d&3)|0)&e}else{c=-1}}while(0);return c|0}function aXf(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4916228+(b*112|0)>>2];c[a+104>>2]=c[4916232+(b*112|0)>>2];c[a+108>>2]=c[4916236+(b*112|0)>>2];d=0;return d|0}function aXg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=4916128+(b*112|0);e=0;return e|0}function aXh(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4916912+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aXi(){var b=0;c[3541404]=10886;a[14165488]=2;b=a04()|0;c[3541392]=8638;c[3541466]=60;gGz(9668984|0,0|0,27|0);S6(0,27,0);gGz(9669011|0,0|0,27|0);S6(1,27,0);c[3540906]=1550;c[3540904]=600;c[3540902]=240;c[3540890]=432;c[3540888]=0;c[3540886]=0;return b|0}function aXj(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3280804+(b*112|0)>>2];c[a+104>>2]=c[3280808+(b*112|0)>>2];c[a+108>>2]=c[3280812+(b*112|0)>>2];d=0;return d|0}function aXk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=3280704+(b*112|0);e=0;return e|0}function aXl(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3820540+(b*112|0)>>2];c[a+104>>2]=c[3820544+(b*112|0)>>2];c[a+108>>2]=c[3820548+(b*112|0)>>2];d=0;return d|0}function aXm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=3820440+(b*112|0);e=0;return e|0}function aXn(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5295156+(b*112|0)>>2];c[a+104>>2]=c[5295160+(b*112|0)>>2];c[a+108>>2]=c[5295164+(b*112|0)>>2];d=0;return d|0}function aXo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=5295056+(b*112|0);e=0;return e|0}function aXp(){var b=0;c[3541404]=11800;a[14165488]=2;b=a04()|0;c[3541474]=10914;c[3541392]=1796;c[3541466]=60;c[3541462]=92;gGz(9668984|0,0|0,27|0);S6(0,27,0);gGz(9669011|0,0|0,27|0);S6(1,27,0);c[3540906]=1550;c[3540904]=600;c[3540902]=240;c[3540890]=432;c[3540888]=0;c[3540886]=0;return b|0}function aXq(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[687412+(b*112|0)>>2];c[a+104>>2]=c[687416+(b*112|0)>>2];c[a+108>>2]=c[687420+(b*112|0)>>2];d=0;return d|0}function aXr(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=687312+(b*112|0);e=0;return e|0}function aXs(b){b=b|0;var c=0,d=0;c=b&65535;if((c|0)==40960){d=a[14165872]|a[14165808]}else if((c|0)==43008){d=a[14165873]|a[14165809]}else if((c|0)==45058){d=a[14165875]|a[14165811]}else if((c|0)==45057){d=a[14165874]|a[14165810]}else{d=-1}return d|0}function aXt(b,d){b=b|0;d=d|0;var e=0,f=0,g=0.0,i=0.0,j=0.0,k=0.0,l=0.0,m=0.0,n=0.0,o=0.0;e=b&65535;if((b+26624&65535)<256){b=e-38912|0;a[(c[3541366]|0)+b|0]=d;if(!((b|0)<64&(b&1|0)==0)){return}a[(c[3541380]|0)+(b>>1)|0]=d;return}switch(e|0){case 40964:case 40965:case 40966:case 40967:{b=d&1;f=14165736+(e-40964<<2)|0;if((b|0)==(c[f>>2]|0)){return}c[f>>2]=b;b=(c[3541434]|0)==0;g=b?4030303030303031.0e-21:30303030303030305.0e-22;i=b?1.0e-12:1000001.0e-12;if((c[3541435]|0)==0){j=i;k=g+21276595744680853.0e-22}else{j=i+21276595744680853.0e-22;k=g}if((c[3541436]|0)==0){l=j;m=k+45454545454545455.0e-22}else{l=j+45454545454545455.0e-22;m=k}if((c[3541437]|0)==0){n=l;o=m+1.0e-5}else{n=l+1.0e-5;o=m}m=1.0/o;h[932738]=1.0e9/((m*2.0e6/(m+1.0/n)+1.0e5)*58788.0)*100.0;return};case 40960:case 40961:case 40962:{a[(c[3541454]|0)+(e-40960)|0]=d;return};case 43008:case 43009:case 43010:case 43011:case 43012:case 43013:case 43014:case 43015:{b=e-43008|0;e=d&1;switch(b&7|0){case 0:case 1:case 2:{c[14165720+(b<<2)>>2]=e&255;return};case 3:{a[14165672]=e;if(e<<24>>24==0){return}c[3541416]=100;h[932737]=0.0;return};case 5:{do{if(e<<24>>24!=0){if((a[14165752]&1)!=0){break}a[14165512]=1;h[932735]=0.0}}while(0);a[14165752]=e;return};case 7:case 6:{e=b&1;c[3541336]=c[3541336]&~(1<<e)|(d&1)<<e;return};default:{return}}break};case 45060:{e=d&1;c[3541360]=e;if((e|0)!=0){return}c[3541358]=-1;return};case 45062:{a[14165832]=d&1;return};case 45063:{a[14165824]=d&1;return};case 47104:{c[3541406]=d&255;return};case 45057:{a[14165768]=d&1;return};default:{return}}}function aXu(a){a=a|0;return-1|0}function aXv(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=b&255;do{if((d&8|0)==0){e=-1}else{b=c[3542354]|0;if((b|0)>15){e=0;break}do{if((b|0)==14){f=c[3542350]|0;if((f|0)==0){break}a[14169434]=gj[f&4095](0)|0}else if((b|0)==15){f=c[3542351]|0;if((f|0)==0){break}a[14169435]=gj[f&4095](0)|0}}while(0);e=a[14169420+b|0]|0}}while(0);if((d&32|0)==0){g=e}else{f=c[3542228]|0;if((f|0)>15){h=0}else{do{if((f|0)==14){i=c[3542224]|0;if((i|0)==0){break}a[14168930]=gj[i&4095](0)|0}else if((f|0)==15){i=c[3542225]|0;if((i|0)==0){break}a[14168931]=gj[i&4095](0)|0}}while(0);h=a[14168916+f|0]|0}g=h&e}if((d&128|0)==0){j=g;return j|0}d=c[3542291]|0;if((d|0)>15){k=0}else{do{if((d|0)==14){e=c[3542287]|0;if((e|0)==0){break}a[14169182]=gj[e&4095](0)|0}else if((d|0)==15){e=c[3542288]|0;if((e|0)==0){break}a[14169183]=gj[e&4095](0)|0}}while(0);k=a[14169168+d|0]|0}j=k&g;return j|0}function aXw(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=b&255;if((e&4|0)!=0){c[3542354]=d&15}do{if((e&8|0)!=0){b=d&255;f=c[3542354]|0;if((f|0)>15){break}do{if((f|0)<14){if((f|0)!=13){if((a[14169420+f|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(2,f,b)}}while(0);if((e&16|0)!=0){c[3542228]=d&15}do{if((e&32|0)!=0){g=d&255;h=c[3542228]|0;if((h|0)>15){break}do{if((h|0)<14){if((h|0)!=13){if((a[14168916+h|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(0,h,g)}}while(0);if((e&64|0)!=0){c[3542291]=d&15}if((e&128|0)==0){return}e=d&255;b=c[3542291]|0;if((b|0)>15){return}do{if((b|0)<14){if((b|0)!=13){if((a[14169168+b|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(1,b,e);return}function aXx(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3520500+(b*112|0)>>2];c[a+104>>2]=c[3520504+(b*112|0)>>2];c[a+108>>2]=c[3520508+(b*112|0)>>2];d=0;return d|0}function aXy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=3520400+(b*112|0);e=0;return e|0}function aXz(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3521856+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aXA(){var d=0,e=0,f=0,g=0,h=0;c[3541404]=7600;a[14165488]=11;d=a04()|0;a0U();e=c[2439331]|0;f=(e|0)==0;if(!f){g=e;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];g=c[3528485]|0;c[2076596]=g;h=c[2417277]|0;c[3541536]=h;c[1836236]=1;c[e+4180>>2]=1330;c[e+4172>>2]=1478;c[e+4176>>2]=2980;if(!f){f=e;gGC(f|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=g;c[2417277]=h;c[1836236]=-1;c[3541392]=8638;c[3541466]=60;c[3541462]=122;c[3541464]=38;gGz(9668984,0,27);S6(0,27,0);gGz(9669011,0,27);S6(1,27,0);c[3540906]=1550;c[3540904]=600;c[3540902]=240;c[3540888]=1374;c[3540886]=1502;c[3540890]=3956;c[3540884]=1246;return d|0}function aXB(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1747332+(b*112|0)>>2];c[a+104>>2]=c[1747336+(b*112|0)>>2];c[a+108>>2]=c[1747340+(b*112|0)>>2];d=0;return d|0}function aXC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=1747232+(b*112|0);e=0;return e|0}function aXD(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1745876+(b*112|0)>>2];c[a+104>>2]=c[1745880+(b*112|0)>>2];c[a+108>>2]=c[1745884+(b*112|0)>>2];d=0;return d|0}function aXE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=1745776+(b*112|0);e=0;return e|0}function aXF(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1202316+(b*112|0)>>2];c[a+104>>2]=c[1202320+(b*112|0)>>2];c[a+108>>2]=c[1202324+(b*112|0)>>2];d=0;return d|0}function aXG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=1202216+(b*112|0);e=0;return e|0}function aXH(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=808504+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aXI(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1203672+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aXJ(){var a=0;c[3541404]=10842;a=a04()|0;c[3541462]=122;c[3541464]=38;return a|0}function aXK(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5608116+(b*112|0)>>2];c[a+104>>2]=c[5608120+(b*112|0)>>2];c[a+108>>2]=c[5608124+(b*112|0)>>2];d=0;return d|0}function aXL(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=5608016+(b*112|0);e=0;return e|0}function aXM(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=2015288+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aXN(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5609024+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aXO(b){b=b|0;var c=0,d=0;c=b&65535;if((c|0)==32768){d=a[14165872]|a[14165808]}else if((c|0)==32769){d=a[14165873]|a[14165809]}else if((c|0)==32770){d=a[14165874]|a[14165810]}else if((c|0)==32771){d=a[14165875]|a[14165811]}else{d=-1}return d|0}function aXP(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=d&65535;if((d-20480&65535)<256){d=f-20480|0;a[(c[3541366]|0)+d|0]=e;if(!((d|0)<64&(d&1|0)==0)){return}a[(c[3541380]|0)+(d>>1)|0]=e;return}if((f|0)==24580){d=e&1;a[14165832]=d;a[14165824]=d;return}else if((f|0)==36864){d=c[1836236]|0;g=c[9757320+(d<<2)>>2]|0;if((g|0)!=0){h=g;gGC(h|0,9706056,76)|0}c[9752472+(d<<2)>>2]=c[2433530];c[14113936+(d<<2)>>2]=c[2076596];c[9669104+(d<<2)>>2]=c[3541536];c[1836236]=-1;d=c[2439331]|0;h=(d|0)==0;if(!h){g=d;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;g=c[2438119]|0;c[2433530]=g;i=c[3528485]|0;c[2076596]=i;j=c[2417277]|0;c[3541536]=j;c[1836236]=1;a[9706117]=1;if(!h){h=d;gGC(h|0,9706056,76)|0}c[2438119]=g;c[3528485]=i;c[2417277]=j;c[1836236]=-1;j=c[2439330]|0;if((j|0)!=0){i=j;gGC(9706056,i|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;return}else if((f|0)==26625){a[14165768]=e&1;return}else if((f|0)==26627){a[14165936]=e&1;return}else if((f|0)==26630){a[14165912]=e&1;return}else if((f|0)==26631){a[14165920]=e&1;return}else if((f|0)==32768){a[14165504]=e;return}else{return}}function aXQ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6445124+(b*112|0)>>2];c[a+104>>2]=c[6445128+(b*112|0)>>2];c[a+108>>2]=c[6445132+(b*112|0)>>2];d=0;return d|0}function aXR(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=6445024+(b*112|0);e=0;return e|0}function aXS(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4300512+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aXT(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>56){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6446368+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aXU(){var d=0,e=0,f=0,g=0,h=0;c[3541404]=10394;a[14165488]=14;d=a04()|0;a0U();e=c[2439331]|0;f=(e|0)==0;if(!f){g=e;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];g=c[3528485]|0;c[2076596]=g;h=c[2417277]|0;c[3541536]=h;c[1836236]=1;c[e+4172>>2]=2798;c[e+4176>>2]=2538;if(!f){f=e;gGC(f|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=g;c[2417277]=h;c[1836236]=-1;c[3541392]=1556;c[3541466]=60;c[3541462]=50;c[3541464]=110;return d|0}function aXV(b,d){b=b|0;d=d|0;var e=0,f=0;e=b&65535;if((b-20480&65535)<256){f=e-20480|0;a[(c[3541366]|0)+f|0]=d;if(!((f|0)<64&(f&1|0)==0)){return}a[(c[3541380]|0)+(f>>1)|0]=d;return}if(b<<16>>16<0){b=e-32768|0;if((b&256|0)!=0){S4(0,b&3,d)}if((b&512|0)==0){return}S4(1,b&3,d);return}switch(e|0){case 26628:{e=d&1;c[3541360]=e;if((e|0)!=0){return}c[3541358]=-1;return};case 26629:{a[14165920]=d&1;return};case 26630:{a[14165832]=d&1;return};case 26631:{a[14165824]=d&1;return};case 26625:{a[14165768]=d&1;return};case 26624:{a[14165912]=d&1;return};case 26627:{a[14165936]=d&1;return};default:{return}}}function aXW(a){a=a|0;return 0}function aXX(a,b){a=a|0;b=b|0;return}function aXY(a){a=a|0;var b=0,c=0;b=a&255;if((b&4|0)==0){c=-1}else{c=S3(2,b&3)|0}return c|0}function aXZ(a,d){a=a|0;d=d|0;var e=0;e=a&255;if((e&4|0)!=0){S4(2,e&3,d)}if((e&16|0)==0){return}US(0,gD[c[2385643]&8191]()|0);b[4771272]=~~(+(b[9753784+((d&255)<<1)>>1]|0)*+h[1192819])&65535;return}function aX_(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7370796+(b*112|0)>>2];c[a+104>>2]=c[7370800+(b*112|0)>>2];c[a+108>>2]=c[7370804+(b*112|0)>>2];d=0;return d|0}function aX$(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=7370696+(b*112|0);e=0;return e|0}function aX0(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6725800+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aX1(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7372712+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aX2(){var b=0;c[3541404]=3290;a[14165488]=12;b=a04()|0;a0U();c[3541392]=8638;c[3541466]=60;c[3541462]=82;gGz(9668984|0,0|0,27|0);S6(0,27,0);gGz(9669011|0,0|0,27|0);S6(1,27,0);gGz(9669038|0,0|0,27|0);S6(2,27,0);c[3540906]=1550;c[3540904]=600;c[3540902]=240;c[3540890]=432;c[3540888]=1374;c[3540886]=1502;c[3540882]=2508;a[7461664]=1;a[7461888]=1;return b|0}function aX3(a){a=a|0;var b=0,c=0;b=a&65535;if((a+24576&65535)<16){c=S3(0,b-40960>>2)|0;return c|0}if((a+22528&65535)>=16){c=-1;return c|0}c=S3(1,b-43008>>2)|0;return c|0}function aX4(b,d){b=b|0;d=d|0;var e=0,f=0;e=b&65535;if((b+30720&65535)<256){f=e-34816|0;a[(c[3541366]|0)+f|0]=d;if(!((f|0)<64&(f&1|0)==0)){return}a[(c[3541380]|0)+(f>>1)|0]=d;return}if((b+24576&65535)<16){S4(0,e-40960>>2,d);return}if((b+22528&65535)<16){S4(1,e-43008>>2,d);return}switch(e|0){case 45056:{e=d&1;c[3541360]=e;if((e|0)!=0){return}c[3541358]=-1;return};case 45070:{a[14165832]=d&1;return};case 45060:{a[14165768]=d&1;return};case 45068:{a[14165824]=d&1;return};case 45058:{a[14165928]=d&1;return};default:{return}}}function aX5(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b&65535;if((d|0)==62994){b=a[9668996]|0;if(b<<24>>24==0){e=0}else{f=c[3540906]|0;if((f|0)==0){g=0;h=b}else{b=gD[f&8191]()|0;g=b;h=a[9668996]|0}a[9669002]=g;e=h&g}i=a[9668999]&a[9669005]|e;return i|0}else if((d|0)==63025){e=a[9668997]|0;if(e<<24>>24==0){j=0}else{g=c[3540904]|0;if((g|0)==0){k=0;l=e}else{e=gD[g&8191]()|0;k=e;l=a[9668997]|0}a[9669003]=k;j=l&k}i=a[9669e3]&a[9669006]|j;return i|0}else if((d|0)==63248){i=S3(0,2)|0;return i|0}else{i=-1;return i|0}return 0}function aX6(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+56|0;g=f|0;h=f+8|0;j=f+16|0;k=f+24|0;l=f+32|0;m=f+40|0;n=f+48|0;o=b&65535;if((b-8192&65535)<256){b=o-8192|0;a[(c[3541366]|0)+b|0]=e;if(!((b|0)<64&(b&1|0)==0)){i=f;return}a[(c[3541380]|0)+(b>>1)|0]=e;i=f;return}if((o|0)==9251){b=e&255;if((b&128|0)!=0){S6(1,b&127,1);i=f;return}p=1<<(b>>>1&7);if((b&1|0)==0){q=d[9669034]&(p^255)}else{q=d[9669034]|p}p=q&255;a[9669034]=p;q=a[9669028]|0;a[n]=q&p|~q;S7(9669011,n);q=a[n]|0;a[9669037]=q;n=c[3540884]|0;if((n|0)==0){i=f;return}gf[n&2047](q);i=f;return}else if((o|0)==63025){a[9669006]=e;q=a[9669e3]|0;n=q&e|~q;a[9669009]=n;q=c[3540898]|0;if((q|0)!=0){gf[q&2047](n)}if((a[9668987]|0)!=0|(a[9668985]|0)==0){i=f;return}a[9668991]=1;n=a[9669001]|0;a[j]=n&a[9669007]|~n;S7(9668984,j);n=a[j]|0;a[9669010]=n;j=c[3540896]|0;if((j|0)==0){i=f;return}gf[j&2047](n);i=f;return}else if((o|0)==63248){a[9669007]=e;n=a[9669001]|0;a[h]=n&e|~n;S7(9668984,h);n=a[h]|0;a[9669010]=n;h=c[3540896]|0;if((h|0)==0){i=f;return}gf[h&2047](n);i=f;return}else if((o|0)==9761){a[14165768]=e&1;i=f;return}else if((o|0)==9764){n=e&1;c[3541360]=n;if((n|0)!=0){i=f;return}c[3541358]=-1;i=f;return}else if((o|0)==9799){a[14165824]=e&1;i=f;return}else if((o|0)==9811){a[14165928]=e&1;i=f;return}else if((o|0)==10038){a[14165832]=e&1;i=f;return}else if((o|0)==62994){a[9669005]=e;n=a[9668999]|0;h=n&e|~n;a[9669008]=h;n=c[3540900]|0;if((n|0)!=0){gf[n&2047](h)}if((a[9668986]|0)!=0|(a[9668984]|0)==0){i=f;return}a[9668990]=1;h=a[9669001]|0;a[k]=h&a[9669007]|~h;S7(9668984,k);h=a[k]|0;a[9669010]=h;k=c[3540896]|0;if((k|0)==0){i=f;return}gf[k&2047](h);i=f;return}else if((o|0)==9296){a[9669032]=e;h=a[9669026]|0;k=h&e|~h;a[9669035]=k;h=c[3540888]|0;if((h|0)!=0){gf[h&2047](k)}if((a[9669013]|0)!=0|(a[9669011]|0)==0){i=f;return}a[9669017]=1;k=a[9669028]|0;a[m]=k&a[9669034]|~k;S7(9669011,m);k=a[m]|0;a[9669037]=k;m=c[3540884]|0;if((m|0)==0){i=f;return}gf[m&2047](k);i=f;return}else if((o|0)==9489){a[9669033]=e;k=a[9669027]|0;m=k&e|~k;a[9669036]=m;k=c[3540886]|0;if((k|0)!=0){gf[k&2047](m)}if((a[9669014]|0)!=0|(a[9669012]|0)==0){i=f;return}a[9669018]=1;m=a[9669028]|0;a[l]=m&a[9669034]|~m;S7(9669011,l);m=a[l]|0;a[9669037]=m;l=c[3540884]|0;if((l|0)==0){i=f;return}gf[l&2047](m);i=f;return}else if((o|0)==63315){o=e&255;if((o&128|0)!=0){S6(0,o&127,1);i=f;return}e=1<<(o>>>1&7);if((o&1|0)==0){r=d[9669007]&(e^255)}else{r=d[9669007]|e}e=r&255;a[9669007]=e;r=a[9669001]|0;a[g]=r&e|~r;S7(9668984,g);r=a[g]|0;a[9669010]=r;g=c[3540896]|0;if((g|0)==0){i=f;return}gf[g&2047](r);i=f;return}else{i=f;return}}function aX7(a){a=a|0;var b=0,c=0;b=a&65535;switch(b|0){case 62208:case 62209:case 62210:case 62211:{c=S3(0,b-62208|0)|0;break};case 65027:case 65024:case 65025:case 65026:{c=S3(1,b-65024|0)|0;break};default:{c=-1}}return c|0}function aX8(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((b-4608&65535)<256){b=e-4608|0;a[(c[3541366]|0)+b|0]=d;if(!((b|0)<64&(b&1|0)==0)){return}a[(c[3541380]|0)+(b>>1)|0]=d;return}if((e|0)==4465){a[14165768]=d&1;return}else if((e|0)==4467){a[14165928]=d&1;return}else if((e|0)==65027|(e|0)==65024|(e|0)==65025|(e|0)==65026){S4(1,e-65024|0,d);return}else if((e|0)==4471){a[14165824]=d&1;return}else if((e|0)==4468){b=d&1;c[3541360]=b;if((b|0)!=0){return}c[3541358]=-1;return}else if((e|0)==62208|(e|0)==62209|(e|0)==62210|(e|0)==62211){S4(0,e-62208|0,d);return}else if((e|0)==4470){a[14165832]=d&1;return}else{return}}function aX9(b,d){b=b|0;d=d|0;var e=0,f=0;e=b&65535;if((b+30720&65535)<256){f=e-34816|0;a[(c[3541366]|0)+f|0]=d;if(!((f|0)<64&(f&1|0)==0)){return}a[(c[3541380]|0)+(f>>1)|0]=d;return}if((b+24576&65535)<16){S4(0,e-40960>>2,d);return}if((b+22528&65535)<16){S4(1,e-43008>>2,d);return}switch(e|0){case 45056:{a[14165920]=d&1;return};case 45058:{a[14165936]=d&1;return};case 45060:{a[14165768]=d&1;return};case 45066:{a[14165912]=d&1;return};case 45068:{a[14165824]=d&1;return};case 45070:{a[14165832]=d&1;return};default:{return}}}function aYa(b,d){b=b|0;d=d|0;var e=0,f=0;e=b&65535;if((b+30720&65535)<256){f=e-34816|0;a[(c[3541366]|0)+f|0]=d;if(!((f|0)<64&(f&1|0)==0)){return}a[(c[3541380]|0)+(f>>1)|0]=d;return}if((b+24576&65535)<16){S4(0,e-40960>>2,d);return}if((b+22528&65535)<16){S4(1,e-43008>>2,d);return}switch(e|0){case 45056:{e=d&1;c[3541360]=e;if((e|0)!=0){return}c[3541358]=-1;return};case 45058:{a[14165928]=d&1;return};case 45060:{a[14165768]=d&1;return};case 45066:{a[14166176]=d&1;return};case 45068:{a[14165824]=d&1;return};case 45070:{a[14165832]=d&1;return};default:{return}}}function aYb(a){a=a|0;var b=0,c=0;b=a&65535;if((a+12288&65535)<32){c=S3(0,b-53248>>3)|0;return c|0}if((a+8192&65535)>=32){c=-1;return c|0}c=S3(1,b-57344>>3)|0;return c|0}function aYc(b,d){b=b|0;d=d|0;var e=0,f=0;e=b&65535;if((b+28672&65535)<256){f=e-36864|0;a[(c[3541366]|0)+f|0]=d;if(!((f|0)<64&(f&1|0)==0)){return}a[(c[3541380]|0)+(f>>1)|0]=d;return}if((b+12288&65535)<32){S4(0,e-53248>>3,d);return}if((b+8192&65535)<32){S4(1,e-57344>>3,d);return}if((e|0)==43010){a[14165832]=d&1;return}else if((e|0)==43012){a[14165768]=d&1;return}else if((e|0)==43014){a[14165824]=d&1;return}else{return}}function aYd(a){a=a|0;var b=0,c=0;b=a&65535;switch(b|0){case 49408:case 49409:case 49410:case 49411:{c=S3(0,b-49408|0)|0;break};case 49667:case 49664:case 49665:case 49666:{c=S3(1,b-49664|0)|0;break};default:{c=-1}}return c|0}function aYe(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((b+28672&65535)<256){b=e-36864|0;a[(c[3541366]|0)+b|0]=d;if(!((b|0)<64&(b&1|0)==0)){return}a[(c[3541380]|0)+(b>>1)|0]=d;return}switch(e|0){case 43009:{a[14165768]=d&1;return};case 49408:case 49409:case 49410:case 49411:{S4(0,e-49408|0,d);return};case 43015:{a[14165832]=d&1;return};case 43014:{a[14165824]=d&1;return};case 49667:case 49664:case 49665:case 49666:{S4(1,e-49664|0,d);return};default:{return}}}function aYf(b){b=b|0;var d=0,e=0;if((b&255)!=128){d=-1;return d|0}b=c[3542228]|0;if((b|0)>15){d=0;return d|0}do{if((b|0)==15){e=c[3542225]|0;if((e|0)==0){break}a[14168931]=gj[e&4095](0)|0}else if((b|0)==14){e=c[3542224]|0;if((e|0)==0){break}a[14168930]=gj[e&4095](0)|0}}while(0);d=a[14168916+b|0]|0;return d|0}function aYg(b,d){b=b|0;d=d|0;var e=0;e=b&255;if((e|0)==64){c[3542228]=d&15;return}else if((e|0)==128){e=d&255;b=c[3542228]|0;if((b|0)>15){return}do{if((b|0)<14){if((b|0)!=13){if((a[14168916+b|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(0,b,e);return}else{return}}function aYh(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((b+28672&65535)<256){b=e-36864|0;a[(c[3541366]|0)+b|0]=d;if(!((b|0)<64&(b&1|0)==0)){return}a[(c[3541380]|0)+(b>>1)|0]=d;return}switch(e|0){case 40960:case 40961:case 40962:case 40963:{S4(1,e-40960|0,d);return};case 38912:case 38913:case 38914:case 38915:{S4(0,e-38912|0,d);return};case 43008:{a[c[3541454]|0]=d&1;return};case 43015:{a[14165824]=d&1;return};case 43009:{a[14165768]=d&1;return};case 43014:{a[14165832]=d&1;return};case 43010:{a[(c[3541454]|0)+1|0]=d&1;return};case 43012:{a[14165928]=d&1;return};default:{return}}}function aYi(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6139788+(b*112|0)>>2];c[a+104>>2]=c[6139792+(b*112|0)>>2];c[a+108>>2]=c[6139796+(b*112|0)>>2];d=0;return d|0}function aYj(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=6139688+(b*112|0);e=0;return e|0}function aYk(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6141032+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aYl(){var b=0;c[3541404]=6172;a[14165488]=9;b=a04()|0;a0U();c[3541392]=8638;c[3541466]=60;gGz(9668984|0,0|0,27|0);S6(0,27,0);gGz(9669011|0,0|0,27|0);S6(1,27,0);c[3540906]=1550;c[3540904]=600;c[3540902]=240;c[3540890]=432;c[3540888]=1374;c[3540886]=1502;return b|0}function aYm(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5090620+(b*112|0)>>2];c[a+104>>2]=c[5090624+(b*112|0)>>2];c[a+108>>2]=c[5090628+(b*112|0)>>2];d=0;return d|0}function aYn(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=5090520+(b*112|0);e=0;return e|0}function aYo(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5091864+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aYp(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3522188+(b*112|0)>>2];c[a+104>>2]=c[3522192+(b*112|0)>>2];c[a+108>>2]=c[3522196+(b*112|0)>>2];d=0;return d|0}function aYq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=3522088+(b*112|0);e=0;return e|0}function aYr(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5092172+(b*112|0)>>2];c[a+104>>2]=c[5092176+(b*112|0)>>2];c[a+108>>2]=c[5092180+(b*112|0)>>2];d=0;return d|0}function aYs(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=5092072+(b*112|0);e=0;return e|0}function aYt(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3334556+(b*112|0)>>2];c[a+104>>2]=c[3334560+(b*112|0)>>2];c[a+108>>2]=c[3334564+(b*112|0)>>2];d=0;return d|0}function aYu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=3334456+(b*112|0);e=0;return e|0}function aYv(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3787964+(b*112|0)>>2];c[a+104>>2]=c[3787968+(b*112|0)>>2];c[a+108>>2]=c[3787972+(b*112|0)>>2];d=0;return d|0}function aYw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=3787864+(b*112|0);e=0;return e|0}function aYx(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1233776+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aYy(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3789208+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aYz(){var b=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;b=i;i=i+240|0;e=b|0;f=b+112|0;g=b+120|0;j=b+232|0;c[3541404]=6172;a[14165488]=9;k=a04()|0;a0U();l=c[3541348]|0;m=0;while(1){if((m|0)>=1024){n=0;break}o=9638528+(m<<2)|0;if((c[o>>2]|0)==0){p=43247;break}else{m=m+1|0}}do{if((p|0)==43247){m=gGq(l)|0;c[o>>2]=m;if((m|0)==0){n=0;break}gGz(m|0,0,l|0);n=m}}while(0);c[3541356]=n;n=c[3541348]|0;l=0;while(1){if((l|0)>=1024){q=0;break}r=9638528+(l<<2)|0;if((c[r>>2]|0)==0){p=43252;break}else{l=l+1|0}}do{if((p|0)==43252){l=gGq(n)|0;c[r>>2]=l;if((l|0)==0){q=0;break}gGz(l|0,0,n|0);q=l}}while(0);n=(c[3541318]|0)+(c[3541326]|0)+(c[3541312]|0)|0;do{if((c[3542200]|0)!=0){r=g+108|0;c[r>>2]=0;l=g+100|0;c[l>>2]=0;o=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[o&16383](g,n)|0;if((c[r>>2]|0)==0){break}r=c[l>>2]|0;c[j>>2]=9534384;l=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[l&16383](j,n,0)|0;if((r|0)<1){break}gzL(q,0,n)|0}}while(0);n=q+2048|0;j=(c[3541326]|0)+1+(c[3541318]|0)+(c[3541312]|0)|0;do{if((c[3542200]|0)!=0){g=e+108|0;c[g>>2]=0;r=e+100|0;c[r>>2]=0;l=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[l&16383](e,j)|0;if((c[g>>2]|0)==0){break}g=c[r>>2]|0;c[f>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](f,j,0)|0;if((g|0)<1){break}gzL(n,0,j)|0}}while(0);j=c[3541348]|0;if((j|0)==0){s=0}else{n=c[3541356]|0;f=0;while(1){e=f>>>1;g=f>>>8;r=e&1^1;l=f>>>10;o=f>>>7&1;a[n+f|0]=a[q+((r&l|g&1&e)<<7|f&2687|((o^l&1)&e^o)<<8|(r&g|o&e)<<10)|0]|0;e=f+1|0;if(e>>>0<j>>>0){f=e}else{s=0;break}}}while(1){if((s|0)>=1024){break}t=9638528+(s<<2)|0;if((c[t>>2]|0)==(q|0)){p=43267;break}else{s=s+1|0}}if((p|0)==43267){gGr(q);c[t>>2]=0}t=c[3541414]|0;q=c[3541356]|0;s=c[3541472]|0;if((t|0)>0){f=c[1865546]|0;j=0;do{n=j<<6;gGz(s+n|0,0,64);e=0;do{o=n+(c[1238464+(e<<2)>>2]|0)|0;g=(e<<3)+n|0;r=0;do{l=o+(c[614800+(r<<2)>>2]|0)|0;if(((d[q+((l|0)/8|0)|0]|0)&128>>>((l&7)>>>0)|0)!=0){l=s+(g+r)|0;a[l]=a[l]|2}r=r+1|0;}while((r|0)<8);e=e+1|0;}while((e|0)<8);e=f+n|0;r=0;do{g=e+(c[1238464+(r<<2)>>2]|0)|0;o=(r<<3)+n|0;l=0;do{m=g+(c[614800+(l<<2)>>2]|0)|0;if(((d[q+((m|0)/8|0)|0]|0)&128>>>((m&7)>>>0)|0)!=0){m=s+(o+l)|0;a[m]=a[m]|1}l=l+1|0;}while((l|0)<8);r=r+1|0;}while((r|0)<8);j=j+1|0;}while((j|0)<(t|0))}t=c[3541412]|0;j=c[3541364]|0;if((t|0)>0){s=c[1865412]|0;f=0;while(1){r=f<<8;gGz(j+r|0,0,256);n=0;do{e=r+(c[611776+(n<<2)>>2]|0)|0;l=(n<<4)+r|0;o=0;do{g=e+(c[601400+(o<<2)>>2]|0)|0;if(((d[q+((g|0)/8|0)|0]|0)&128>>>((g&7)>>>0)|0)!=0){g=j+(l+o)|0;a[g]=a[g]|2}o=o+1|0;}while((o|0)<16);n=n+1|0;}while((n|0)<16);n=s+r|0;o=0;do{l=n+(c[611776+(o<<2)>>2]|0)|0;e=(o<<4)+r|0;g=0;do{m=l+(c[601400+(g<<2)>>2]|0)|0;if(((d[q+((m|0)/8|0)|0]|0)&128>>>((m&7)>>>0)|0)!=0){m=j+(e+g)|0;a[m]=a[m]|1}g=g+1|0;}while((g|0)<16);o=o+1|0;}while((o|0)<16);o=f+1|0;if((o|0)<(t|0)){f=o}else{u=0;break}}}else{u=0}while(1){if((u|0)>=1024){p=43302;break}v=9638528+(u<<2)|0;if((c[v>>2]|0)==(q|0)){break}else{u=u+1|0}}if((p|0)==43302){c[3541356]=0;c[3541392]=8638;c[3541466]=60;gGz(9668984,0,27);S6(0,27,0);gGz(9669011,0,27);S6(1,27,0);c[3540906]=1550;c[3540904]=600;c[3540902]=240;c[3540890]=432;c[3540888]=1374;c[3540886]=1502;h[1220314]=.2;h[1220324]=.2;h[1220334]=.2;h[1220344]=.2;h[1220354]=.2;h[1220364]=.2;i=b;return k|0}gGr(q);c[v>>2]=0;c[3541356]=0;c[3541392]=8638;c[3541466]=60;gGz(9668984,0,27);S6(0,27,0);gGz(9669011,0,27);S6(1,27,0);c[3540906]=1550;c[3540904]=600;c[3540902]=240;c[3540890]=432;c[3540888]=1374;c[3540886]=1502;h[1220314]=.2;h[1220324]=.2;h[1220334]=.2;h[1220344]=.2;h[1220354]=.2;h[1220364]=.2;i=b;return k|0}function aYA(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1842820+(b*112|0)>>2];c[a+104>>2]=c[1842824+(b*112|0)>>2];c[a+108>>2]=c[1842828+(b*112|0)>>2];d=0;return d|0}function aYB(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=1842720+(b*112|0);e=0;return e|0}function aYC(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4273468+(b*112|0)>>2];c[a+104>>2]=c[4273472+(b*112|0)>>2];c[a+108>>2]=c[4273476+(b*112|0)>>2];d=0;return d|0}function aYD(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=4273368+(b*112|0);e=0;return e|0}function aYE(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4274488+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aYF(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2014268+(b*112|0)>>2];c[a+104>>2]=c[2014272+(b*112|0)>>2];c[a+108>>2]=c[2014276+(b*112|0)>>2];d=0;return d|0}function aYG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=2014168+(b*112|0);e=0;return e|0}function aYH(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3326628+(b*112|0)>>2];c[a+104>>2]=c[3326632+(b*112|0)>>2];c[a+108>>2]=c[3326636+(b*112|0)>>2];d=0;return d|0}function aYI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=3326528+(b*112|0);e=0;return e|0}function aYJ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1183096+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aYK(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3327748+(b*112|0)>>2];c[a+104>>2]=c[3327752+(b*112|0)>>2];c[a+108>>2]=c[3327756+(b*112|0)>>2];d=0;return d|0}function aYL(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=3327648+(b*112|0);e=0;return e|0}function aYM(){var b=0;c[3541404]=7518;a[14165488]=9;b=a04()|0;a0U();c[3541392]=8638;c[3541466]=60;gGz(9668984|0,0|0,27|0);S6(0,27,0);gGz(9669011|0,0|0,27|0);S6(1,27,0);c[3540906]=1550;c[3540904]=600;c[3540902]=240;c[3540890]=432;c[3540888]=1374;c[3540886]=1502;return b|0}function aYN(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4279852+(b*112|0)>>2];c[a+104>>2]=c[4279856+(b*112|0)>>2];c[a+108>>2]=c[4279860+(b*112|0)>>2];d=0;return d|0}function aYO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=4279752+(b*112|0);e=0;return e|0}function aYP(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1316776+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aYQ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4280760+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aYR(){var b=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;b=i;i=i+240|0;e=b|0;f=b+112|0;g=b+120|0;j=b+232|0;c[3541404]=6172;a[14165488]=9;k=a04()|0;a0U();l=c[3541348]|0;m=0;while(1){if((m|0)>=1024){n=0;break}o=9638528+(m<<2)|0;if((c[o>>2]|0)==0){p=43408;break}else{m=m+1|0}}do{if((p|0)==43408){m=gGq(l)|0;c[o>>2]=m;if((m|0)==0){n=0;break}gGz(m|0,0,l|0);n=m}}while(0);c[3541356]=n;n=c[3541348]|0;l=0;while(1){if((l|0)>=1024){q=0;break}r=9638528+(l<<2)|0;if((c[r>>2]|0)==0){p=43413;break}else{l=l+1|0}}do{if((p|0)==43413){l=gGq(n)|0;c[r>>2]=l;if((l|0)==0){q=0;break}gGz(l|0,0,n|0);q=l}}while(0);n=(c[3541318]|0)+(c[3541326]|0)+(c[3541312]|0)|0;do{if((c[3542200]|0)!=0){r=g+108|0;c[r>>2]=0;l=g+100|0;c[l>>2]=0;o=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[o&16383](g,n)|0;if((c[r>>2]|0)==0){break}r=c[l>>2]|0;c[j>>2]=9534384;l=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[l&16383](j,n,0)|0;if((r|0)<1){break}gzL(q,0,n)|0}}while(0);n=q+2048|0;j=(c[3541326]|0)+1+(c[3541318]|0)+(c[3541312]|0)|0;do{if((c[3542200]|0)!=0){g=e+108|0;c[g>>2]=0;r=e+100|0;c[r>>2]=0;l=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[l&16383](e,j)|0;if((c[g>>2]|0)==0){break}g=c[r>>2]|0;c[f>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](f,j,0)|0;if((g|0)<1){break}gzL(n,0,j)|0}}while(0);j=c[3541348]|0;if((j|0)==0){s=0}else{n=c[3541356]|0;f=0;while(1){e=f>>>2;g=f>>>10&1;a[n+f|0]=a[q+(((e&1^g)<<9|f&2495|(f>>>6^f)<<10&1024|((f>>>4^f>>>9)&1^g&e)<<6)^1024)|0]|0;e=f+1|0;if(e>>>0<j>>>0){f=e}else{s=0;break}}}while(1){if((s|0)>=1024){break}t=9638528+(s<<2)|0;if((c[t>>2]|0)==(q|0)){p=43428;break}else{s=s+1|0}}if((p|0)==43428){gGr(q);c[t>>2]=0}t=c[3541414]|0;q=c[3541356]|0;s=c[3541472]|0;if((t|0)>0){f=c[1865546]|0;j=0;do{n=j<<6;gGz(s+n|0,0,64);e=0;do{g=n+(c[1238464+(e<<2)>>2]|0)|0;r=(e<<3)+n|0;l=0;do{o=g+(c[614800+(l<<2)>>2]|0)|0;if(((d[q+((o|0)/8|0)|0]|0)&128>>>((o&7)>>>0)|0)!=0){o=s+(r+l)|0;a[o]=a[o]|2}l=l+1|0;}while((l|0)<8);e=e+1|0;}while((e|0)<8);e=f+n|0;l=0;do{r=e+(c[1238464+(l<<2)>>2]|0)|0;g=(l<<3)+n|0;o=0;do{m=r+(c[614800+(o<<2)>>2]|0)|0;if(((d[q+((m|0)/8|0)|0]|0)&128>>>((m&7)>>>0)|0)!=0){m=s+(g+o)|0;a[m]=a[m]|1}o=o+1|0;}while((o|0)<8);l=l+1|0;}while((l|0)<8);j=j+1|0;}while((j|0)<(t|0))}t=c[3541412]|0;j=c[3541364]|0;if((t|0)>0){s=c[1865412]|0;f=0;while(1){l=f<<8;gGz(j+l|0,0,256);n=0;do{e=l+(c[611776+(n<<2)>>2]|0)|0;o=(n<<4)+l|0;g=0;do{r=e+(c[601400+(g<<2)>>2]|0)|0;if(((d[q+((r|0)/8|0)|0]|0)&128>>>((r&7)>>>0)|0)!=0){r=j+(o+g)|0;a[r]=a[r]|2}g=g+1|0;}while((g|0)<16);n=n+1|0;}while((n|0)<16);n=s+l|0;g=0;do{o=n+(c[611776+(g<<2)>>2]|0)|0;e=(g<<4)+l|0;r=0;do{m=o+(c[601400+(r<<2)>>2]|0)|0;if(((d[q+((m|0)/8|0)|0]|0)&128>>>((m&7)>>>0)|0)!=0){m=j+(e+r)|0;a[m]=a[m]|1}r=r+1|0;}while((r|0)<16);g=g+1|0;}while((g|0)<16);g=f+1|0;if((g|0)<(t|0)){f=g}else{u=0;break}}}else{u=0}while(1){if((u|0)>=1024){p=43463;break}v=9638528+(u<<2)|0;if((c[v>>2]|0)==(q|0)){break}else{u=u+1|0}}if((p|0)==43463){c[3541356]=0;c[3541392]=5796;c[3541466]=60;gGz(9668984,0,27);S6(0,27,0);gGz(9669011,0,27);S6(1,27,0);c[3540906]=1550;c[3540904]=600;c[3540902]=240;c[3540890]=432;c[3540888]=1374;c[3540886]=1502;h[1220314]=.2;h[1220324]=.2;h[1220334]=.2;h[1220344]=.2;h[1220354]=.2;h[1220364]=.2;i=b;return k|0}gGr(q);c[v>>2]=0;c[3541356]=0;c[3541392]=5796;c[3541466]=60;gGz(9668984,0,27);S6(0,27,0);gGz(9669011,0,27);S6(1,27,0);c[3540906]=1550;c[3540904]=600;c[3540902]=240;c[3540890]=432;c[3540888]=1374;c[3540886]=1502;h[1220314]=.2;h[1220324]=.2;h[1220334]=.2;h[1220344]=.2;h[1220354]=.2;h[1220364]=.2;i=b;return k|0}function aYS(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2019932+(b*112|0)>>2];c[a+104>>2]=c[2019936+(b*112|0)>>2];c[a+108>>2]=c[2019940+(b*112|0)>>2];d=0;return d|0}function aYT(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=2019832+(b*112|0);e=0;return e|0}function aYU(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=990800+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aYV(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=2020616+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aYW(){var b=0;c[3541404]=316;a[14165488]=9;b=a04()|0;a0U();c[3541392]=5796;c[3541466]=60;gGz(9668984|0,0|0,27|0);S6(0,27,0);gGz(9669011|0,0|0,27|0);S6(1,27,0);c[3540906]=1550;c[3540904]=600;c[3540902]=240;c[3540890]=432;c[3540888]=1374;c[3540886]=1502;h[1220314]=.2;h[1220324]=.2;h[1220334]=.2;h[1220344]=.2;h[1220354]=.2;h[1220364]=.2;return b|0}function aYX(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1315884+(b*112|0)>>2];c[a+104>>2]=c[1315888+(b*112|0)>>2];c[a+108>>2]=c[1315892+(b*112|0)>>2];d=0;return d|0}function aYY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=1315784+(b*112|0);e=0;return e|0}function aYZ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1283432+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aY_(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1316568+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aY$(){var b=0;c[3541404]=10048;a[14165488]=9;b=a04()|0;a0U();c[3541392]=8638;c[3541466]=60;gGz(9668984|0,0|0,27|0);S6(0,27,0);gGz(9669011|0,0|0,27|0);S6(1,27,0);c[3540906]=1550;c[3540904]=600;c[3540902]=240;c[3540890]=432;c[3540888]=1374;c[3540886]=1502;h[1220314]=.2;h[1220324]=.2;h[1220334]=.2;h[1220344]=.2;h[1220354]=.2;h[1220364]=.2;return b|0}function aY0(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4971500+(b*112|0)>>2];c[a+104>>2]=c[4971504+(b*112|0)>>2];c[a+108>>2]=c[4971508+(b*112|0)>>2];d=0;return d|0}function aY1(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=4971400+(b*112|0);e=0;return e|0}function aY2(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1689952+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aY3(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4972184+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aY4(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3342516+(b*112|0)>>2];c[a+104>>2]=c[3342520+(b*112|0)>>2];c[a+108>>2]=c[3342524+(b*112|0)>>2];d=0;return d|0}function aY5(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=3342416+(b*112|0);e=0;return e|0}function aY6(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1186280+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aY7(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3343760+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aY8(){var b=0;c[3541404]=304;a[14165488]=9;b=a04()|0;a0U();c[3541392]=8638;c[3541466]=60;gGz(9668984|0,0|0,27|0);S6(0,27,0);gGz(9669011|0,0|0,27|0);S6(1,27,0);c[3540906]=1550;c[3540904]=600;c[3540902]=240;c[3540890]=432;c[3540888]=1374;c[3540886]=1502;h[1220314]=.2;h[1220324]=.2;h[1220334]=.2;h[1220344]=.2;h[1220354]=.2;h[1220364]=.2;return b|0}function aY9(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5549380+(b*112|0)>>2];c[a+104>>2]=c[5549384+(b*112|0)>>2];c[a+108>>2]=c[5549388+(b*112|0)>>2];d=0;return d|0}function aZa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=5549280+(b*112|0);e=0;return e|0}function aZb(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1992104+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aZc(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5550512+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aZd(){var b=0;c[3541404]=6172;a[14165488]=9;b=a04()|0;a0U();c[3541392]=8638;c[3541466]=60;c[3541464]=106;gGz(9668984|0,0|0,27|0);S6(0,27,0);gGz(9669011|0,0|0,27|0);S6(1,27,0);c[3540906]=1550;c[3540904]=600;c[3540902]=240;c[3540890]=432;c[3540888]=1374;c[3540886]=1502;h[1220314]=.2;h[1220324]=.2;h[1220334]=.2;h[1220344]=.2;h[1220354]=.2;h[1220364]=.2;return b|0}function aZe(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5261404+(b*112|0)>>2];c[a+104>>2]=c[5261408+(b*112|0)>>2];c[a+108>>2]=c[5261412+(b*112|0)>>2];d=0;return d|0}function aZf(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=5261304+(b*112|0);e=0;return e|0}function aZg(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1821720+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aZh(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5262312+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aZi(){var b=0;c[3541404]=6172;a[14165488]=9;b=a04()|0;a0U();c[3541392]=8638;c[3541466]=88;gGz(9668984|0,0|0,27|0);S6(0,27,0);gGz(9669011|0,0|0,27|0);S6(1,27,0);c[3540904]=600;c[3540902]=240;c[3540890]=432;c[3540888]=1374;c[3540886]=1502;c[3540906]=1200;c[3540896]=486;h[1220314]=.2;h[1220324]=.2;h[1220334]=.2;h[1220344]=.2;h[1220354]=.2;h[1220364]=.2;return b|0}function aZj(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3704156+(b*112|0)>>2];c[a+104>>2]=c[3704160+(b*112|0)>>2];c[a+108>>2]=c[3704164+(b*112|0)>>2];d=0;return d|0}function aZk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=3704056+(b*112|0);e=0;return e|0}function aZl(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3705064+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aZm(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3360012+(b*112|0)>>2];c[a+104>>2]=c[3360016+(b*112|0)>>2];c[a+108>>2]=c[3360020+(b*112|0)>>2];d=0;return d|0}function aZn(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=3359912+(b*112|0);e=0;return e|0}function aZo(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1201272+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aZp(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3361256+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aZq(){var b=0;c[3541404]=8e3;a[14165488]=9;b=a04()|0;a0U();c[3541474]=860;c[3541392]=2034;gGz(9668984|0,0|0,27|0);S6(0,27,0);gGz(9669011|0,0|0,27|0);S6(1,27,0);c[3540906]=1550;c[3540904]=600;c[3540902]=240;c[3540890]=432;c[3540888]=1374;c[3540886]=1502;return b|0}function aZr(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3361492+(b*112|0)>>2];c[a+104>>2]=c[3361496+(b*112|0)>>2];c[a+108>>2]=c[3361500+(b*112|0)>>2];d=0;return d|0}function aZs(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=3361392+(b*112|0);e=0;return e|0}function aZt(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4938116+(b*112|0)>>2];c[a+104>>2]=c[4938120+(b*112|0)>>2];c[a+108>>2]=c[4938124+(b*112|0)>>2];d=0;return d|0}function aZu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=4938016+(b*112|0);e=0;return e|0}function aZv(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4103556+(b*112|0)>>2];c[a+104>>2]=c[4103560+(b*112|0)>>2];c[a+108>>2]=c[4103564+(b*112|0)>>2];d=0;return d|0}function aZw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=4103456+(b*112|0);e=0;return e|0}function aZx(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1285752+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aZy(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4104800+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aZz(){var b=0;c[3541404]=6350;a[14165488]=9;b=a04()|0;a0U();c[3541474]=10026;c[3541466]=80;gGz(9668984|0,0|0,27|0);S6(0,27,0);gGz(9669011|0,0|0,27|0);S6(1,27,0);c[3540906]=1550;c[3540902]=240;c[3540890]=432;c[3540888]=1374;c[3540886]=1502;c[3540904]=620;h[1220314]=.2;h[1220324]=.2;h[1220334]=.2;h[1220344]=.2;h[1220354]=.2;h[1220364]=.2;return b|0}function aZA(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6147948+(b*112|0)>>2];c[a+104>>2]=c[6147952+(b*112|0)>>2];c[a+108>>2]=c[6147956+(b*112|0)>>2];d=0;return d|0}function aZB(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=6147848+(b*112|0);e=0;return e|0}function aZC(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3563968+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aZD(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6148968+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aZE(){var b=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;b=i;i=i+240|0;e=b|0;f=b+112|0;g=b+120|0;j=b+232|0;c[3541404]=6172;a[14165488]=9;a04()|0;a0U();k=c[3541348]|0;l=0;while(1){if((l|0)>=1024){m=0;break}n=9638528+(l<<2)|0;if((c[n>>2]|0)==0){o=43752;break}else{l=l+1|0}}do{if((o|0)==43752){l=gGq(k)|0;c[n>>2]=l;if((l|0)==0){m=0;break}gGz(l|0,0,k|0);m=l}}while(0);c[3541356]=m;m=c[3541348]|0;k=0;while(1){if((k|0)>=1024){p=0;break}q=9638528+(k<<2)|0;if((c[q>>2]|0)==0){o=43757;break}else{k=k+1|0}}do{if((o|0)==43757){k=gGq(m)|0;c[q>>2]=k;if((k|0)==0){p=0;break}gGz(k|0,0,m|0);p=k}}while(0);m=c[3541356]|0;q=(c[3541318]|0)+(c[3541326]|0)+(c[3541312]|0)|0;if((c[3542200]|0)==0){r=1;i=b;return r|0}k=g+108|0;c[k>>2]=0;n=g+100|0;c[n>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,q)|0;do{if((c[k>>2]|0)!=0){g=c[n>>2]|0;c[j>>2]=9534384;l=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[l&16383](j,q,0)|0;if((g|0)<1){r=1;i=b;return r|0}if((gzL(m,0,q)|0)==0){break}else{r=1}i=b;return r|0}}while(0);q=(c[3541356]|0)+2048|0;m=(c[3541326]|0)+1+(c[3541318]|0)+(c[3541312]|0)|0;if((c[3542200]|0)==0){r=1;i=b;return r|0}j=e+108|0;c[j>>2]=0;n=e+100|0;c[n>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,m)|0;do{if((c[j>>2]|0)!=0){e=c[n>>2]|0;c[f>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](f,m,0)|0;if((e|0)<1){r=1;i=b;return r|0}if((gzL(q,0,m)|0)==0){break}else{r=1}i=b;return r|0}}while(0);m=c[3541356]|0;q=c[3541348]|0;gGC(p|0,m|0,q)|0;if((q|0)!=0){f=0;do{a[m+f|0]=a[p+((f>>>3^f>>>10)<<7&128|f&2687|(f>>>1^f>>>7)<<8&256|(f>>>8^f)<<10&1024)|0]|0;f=f+1|0;}while(f>>>0<q>>>0)}q=c[3541414]|0;f=c[3541472]|0;if((q|0)>0){n=c[1865546]|0;j=0;do{e=j<<6;gGz(f+e|0,0,64);k=0;do{g=e+(c[1238464+(k<<2)>>2]|0)|0;l=(k<<3)+e|0;s=0;do{t=g+(c[614800+(s<<2)>>2]|0)|0;if(((d[m+((t|0)/8|0)|0]|0)&128>>>((t&7)>>>0)|0)!=0){t=f+(l+s)|0;a[t]=a[t]|2}s=s+1|0;}while((s|0)<8);k=k+1|0;}while((k|0)<8);k=n+e|0;s=0;do{l=k+(c[1238464+(s<<2)>>2]|0)|0;g=(s<<3)+e|0;t=0;do{u=l+(c[614800+(t<<2)>>2]|0)|0;if(((d[m+((u|0)/8|0)|0]|0)&128>>>((u&7)>>>0)|0)!=0){u=f+(g+t)|0;a[u]=a[u]|1}t=t+1|0;}while((t|0)<8);s=s+1|0;}while((s|0)<8);j=j+1|0;}while((j|0)<(q|0))}q=c[3541412]|0;j=c[3541364]|0;if((q|0)>0){f=c[1865412]|0;n=0;while(1){s=n<<8;gGz(j+s|0,0,256);e=0;do{k=s+(c[611776+(e<<2)>>2]|0)|0;t=(e<<4)+s|0;g=0;do{l=k+(c[601400+(g<<2)>>2]|0)|0;if(((d[m+((l|0)/8|0)|0]|0)&128>>>((l&7)>>>0)|0)!=0){l=j+(t+g)|0;a[l]=a[l]|2}g=g+1|0;}while((g|0)<16);e=e+1|0;}while((e|0)<16);e=f+s|0;g=0;do{t=e+(c[611776+(g<<2)>>2]|0)|0;k=(g<<4)+s|0;l=0;do{u=t+(c[601400+(l<<2)>>2]|0)|0;if(((d[m+((u|0)/8|0)|0]|0)&128>>>((u&7)>>>0)|0)!=0){u=j+(k+l)|0;a[u]=a[u]|1}l=l+1|0;}while((l|0)<16);g=g+1|0;}while((g|0)<16);g=n+1|0;if((g|0)<(q|0)){n=g}else{v=0;break}}}else{v=0}while(1){if((v|0)>=1024){w=m;break}x=9638528+(v<<2)|0;if((c[x>>2]|0)==(p|0)){o=43789;break}else{v=v+1|0}}if((o|0)==43789){gGr(p);c[x>>2]=0;w=c[3541356]|0}x=0;while(1){if((x|0)>=1024){break}y=9638528+(x<<2)|0;if((c[y>>2]|0)==(w|0)){o=43793;break}else{x=x+1|0}}if((o|0)==43793){gGr(w);c[y>>2]=0}c[3541356]=0;c[3541474]=10718;c[3541392]=5650;c[3541466]=60;gGz(9668984,0,27);S6(0,27,0);gGz(9669011,0,27);S6(1,27,0);c[3540906]=1550;c[3540904]=600;c[3540902]=240;c[3540890]=432;c[3540888]=1374;c[3540886]=1502;h[1220314]=.2;h[1220324]=.2;h[1220334]=.2;h[1220344]=.2;h[1220354]=.2;h[1220364]=.2;r=0;i=b;return r|0}function aZF(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6437860+(b*112|0)>>2];c[a+104>>2]=c[6437864+(b*112|0)>>2];c[a+108>>2]=c[6437868+(b*112|0)>>2];d=0;return d|0}function aZG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=6437760+(b*112|0);e=0;return e|0}function aZH(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5271556+(b*112|0)>>2];c[a+104>>2]=c[5271560+(b*112|0)>>2];c[a+108>>2]=c[5271564+(b*112|0)>>2];d=0;return d|0}function aZI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=5271456+(b*112|0);e=0;return e|0}function aZJ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5272688+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aZK(){var b=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;b=i;i=i+240|0;e=b|0;f=b+112|0;g=b+120|0;j=b+232|0;c[3541404]=6172;a[14165488]=9;a04()|0;a0U();k=c[3541348]|0;l=0;while(1){if((l|0)>=1024){m=0;break}n=9638528+(l<<2)|0;if((c[n>>2]|0)==0){o=43849;break}else{l=l+1|0}}do{if((o|0)==43849){l=gGq(k)|0;c[n>>2]=l;if((l|0)==0){m=0;break}gGz(l|0,0,k|0);m=l}}while(0);c[3541356]=m;m=c[3541348]|0;k=0;while(1){if((k|0)>=1024){p=0;break}q=9638528+(k<<2)|0;if((c[q>>2]|0)==0){o=43854;break}else{k=k+1|0}}do{if((o|0)==43854){k=gGq(m)|0;c[q>>2]=k;if((k|0)==0){p=0;break}gGz(k|0,0,m|0);p=k}}while(0);m=c[3541356]|0;q=(c[3541318]|0)+(c[3541326]|0)+(c[3541312]|0)|0;if((c[3542200]|0)==0){r=1;i=b;return r|0}k=g+108|0;c[k>>2]=0;n=g+100|0;c[n>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,q)|0;do{if((c[k>>2]|0)!=0){g=c[n>>2]|0;c[j>>2]=9534384;l=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[l&16383](j,q,0)|0;if((g|0)<1){r=1;i=b;return r|0}if((gzL(m,0,q)|0)==0){break}else{r=1}i=b;return r|0}}while(0);q=(c[3541356]|0)+2048|0;m=(c[3541326]|0)+1+(c[3541318]|0)+(c[3541312]|0)|0;if((c[3542200]|0)==0){r=1;i=b;return r|0}j=e+108|0;c[j>>2]=0;n=e+100|0;c[n>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,m)|0;do{if((c[j>>2]|0)!=0){e=c[n>>2]|0;c[f>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](f,m,0)|0;if((e|0)<1){r=1;i=b;return r|0}if((gzL(q,0,m)|0)==0){break}else{r=1}i=b;return r|0}}while(0);m=c[3541356]|0;q=c[3541348]|0;gGC(p|0,m|0,q)|0;if((q|0)!=0){f=0;do{n=f>>>3;j=f>>>7&1;e=f>>>5&1;k=j&n;g=e^f&1;a[m+f|0]=a[p+((n&1^j)<<5|f&3423|(g^k)<<9|((f>>>2^f>>>9)&1^e&f^k&g)<<7)|0]|0;f=f+1|0;}while(f>>>0<q>>>0)}q=c[3541414]|0;f=c[3541472]|0;if((q|0)>0){g=c[1865546]|0;k=0;do{e=k<<6;gGz(f+e|0,0,64);j=0;do{n=e+(c[1238464+(j<<2)>>2]|0)|0;l=(j<<3)+e|0;s=0;do{t=n+(c[614800+(s<<2)>>2]|0)|0;if(((d[m+((t|0)/8|0)|0]|0)&128>>>((t&7)>>>0)|0)!=0){t=f+(l+s)|0;a[t]=a[t]|2}s=s+1|0;}while((s|0)<8);j=j+1|0;}while((j|0)<8);j=g+e|0;s=0;do{l=j+(c[1238464+(s<<2)>>2]|0)|0;n=(s<<3)+e|0;t=0;do{u=l+(c[614800+(t<<2)>>2]|0)|0;if(((d[m+((u|0)/8|0)|0]|0)&128>>>((u&7)>>>0)|0)!=0){u=f+(n+t)|0;a[u]=a[u]|1}t=t+1|0;}while((t|0)<8);s=s+1|0;}while((s|0)<8);k=k+1|0;}while((k|0)<(q|0))}q=c[3541412]|0;k=c[3541364]|0;if((q|0)>0){f=c[1865412]|0;g=0;while(1){s=g<<8;gGz(k+s|0,0,256);e=0;do{j=s+(c[611776+(e<<2)>>2]|0)|0;t=(e<<4)+s|0;n=0;do{l=j+(c[601400+(n<<2)>>2]|0)|0;if(((d[m+((l|0)/8|0)|0]|0)&128>>>((l&7)>>>0)|0)!=0){l=k+(t+n)|0;a[l]=a[l]|2}n=n+1|0;}while((n|0)<16);e=e+1|0;}while((e|0)<16);e=f+s|0;n=0;do{t=e+(c[611776+(n<<2)>>2]|0)|0;j=(n<<4)+s|0;l=0;do{u=t+(c[601400+(l<<2)>>2]|0)|0;if(((d[m+((u|0)/8|0)|0]|0)&128>>>((u&7)>>>0)|0)!=0){u=k+(j+l)|0;a[u]=a[u]|1}l=l+1|0;}while((l|0)<16);n=n+1|0;}while((n|0)<16);n=g+1|0;if((n|0)<(q|0)){g=n}else{v=0;break}}}else{v=0}while(1){if((v|0)>=1024){w=m;break}x=9638528+(v<<2)|0;if((c[x>>2]|0)==(p|0)){o=43886;break}else{v=v+1|0}}if((o|0)==43886){gGr(p);c[x>>2]=0;w=c[3541356]|0}x=0;while(1){if((x|0)>=1024){break}y=9638528+(x<<2)|0;if((c[y>>2]|0)==(w|0)){o=43890;break}else{x=x+1|0}}if((o|0)==43890){gGr(w);c[y>>2]=0}c[3541356]=0;c[3541474]=10820;c[3541392]=2702;c[3541466]=60;gGz(9668984,0,27);S6(0,27,0);gGz(9669011,0,27);S6(1,27,0);c[3540906]=1550;c[3540904]=600;c[3540902]=240;c[3540890]=432;c[3540888]=1374;c[3540886]=1502;h[1220314]=.2;h[1220324]=.2;h[1220334]=.2;h[1220344]=.2;h[1220354]=.2;h[1220364]=.2;r=0;i=b;return r|0}function aZL(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5347756+(b*112|0)>>2];c[a+104>>2]=c[5347760+(b*112|0)>>2];c[a+108>>2]=c[5347764+(b*112|0)>>2];d=0;return d|0}function aZM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=5347656+(b*112|0);e=0;return e|0}function aZN(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1869296+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aZO(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5348552+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aZP(){var b=0,d=0,e=0,f=0,g=0;c[3541404]=11872;a[14165488]=8;b=a04()|0;a0P();d=c[3541320]|0;e=0;do{f=d+e|0;g=a[f]|0;a[f]=g<<1&2|g&-4|(g&255)>>>1&1;e=e+1|0;}while(e>>>0<2048);c[3541392]=8638;c[3541466]=60;gGz(9668984|0,0|0,27|0);S6(0,27,0);gGz(9669011|0,0|0,27|0);S6(1,27,0);c[3540906]=1550;c[3540904]=600;c[3540902]=240;c[3540890]=432;c[3540888]=1374;c[3540886]=1502;a[14165472]=7;a[14165480]=-10;return b|0}function aZQ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4239244+(b*112|0)>>2];c[a+104>>2]=c[4239248+(b*112|0)>>2];c[a+108>>2]=c[4239252+(b*112|0)>>2];d=0;return d|0}function aZR(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=4239144+(b*112|0);e=0;return e|0}function aZS(){var b=0,d=0,e=0,f=0,g=0;c[3541404]=7690;a[14165488]=8;b=a04()|0;a0P();d=c[3541320]|0;e=0;do{f=d+e|0;g=a[f]|0;a[f]=g<<1&2|g&-4|(g&255)>>>1&1;e=e+1|0;}while(e>>>0<2048);c[3541392]=8638;c[3541466]=60;gGz(9668984|0,0|0,27|0);S6(0,27,0);gGz(9669011|0,0|0,27|0);S6(1,27,0);c[3540906]=1550;c[3540904]=600;c[3540902]=240;c[3540890]=432;c[3540888]=1374;c[3540886]=1502;a[14165472]=7;a[14165480]=-10;return b|0}function aZT(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3852868+(b*112|0)>>2];c[a+104>>2]=c[3852872+(b*112|0)>>2];c[a+108>>2]=c[3852876+(b*112|0)>>2];d=0;return d|0}function aZU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=3852768+(b*112|0);e=0;return e|0}function aZV(){var b=0;c[3541404]=428;a[14165488]=8;b=a04()|0;c[3541392]=8638;c[3541466]=60;gGz(9668984|0,0|0,27|0);S6(0,27,0);gGz(9669011|0,0|0,27|0);S6(1,27,0);c[3540906]=1550;c[3540904]=600;c[3540902]=240;c[3540890]=432;c[3540888]=1374;c[3540886]=1502;a[14165472]=7;a[14165480]=-10;return b|0}function aZW(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3737924+(b*112|0)>>2];c[a+104>>2]=c[3737928+(b*112|0)>>2];c[a+108>>2]=c[3737932+(b*112|0)>>2];d=0;return d|0}function aZX(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=3737824+(b*112|0);e=0;return e|0}function aZY(){var b=0;c[3541404]=7866;a[14165488]=9;b=a04()|0;a0U();c[3541392]=8638;c[3541466]=60;c[3541462]=66;c[3541464]=32;gGz(9668984|0,0|0,27|0);S6(0,27,0);gGz(9669011|0,0|0,27|0);S6(1,27,0);c[3540906]=1550;c[3540904]=600;c[3540902]=240;c[3540890]=432;c[3540888]=1374;c[3540886]=1502;h[1220314]=.2;h[1220324]=.2;h[1220334]=.2;h[1220344]=.2;h[1220354]=.2;h[1220364]=.2;return b|0}function aZZ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3736236+(b*112|0)>>2];c[a+104>>2]=c[3736240+(b*112|0)>>2];c[a+108>>2]=c[3736244+(b*112|0)>>2];d=0;return d|0}function aZ_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=3736136+(b*112|0);e=0;return e|0}function aZ$(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3737592+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aZ0(){var b=0;c[3541404]=5320;a[14165488]=9;b=a04()|0;a0U();c[3541392]=8638;c[3541466]=60;c[3541462]=66;c[3541464]=32;gGz(9668984|0,0|0,27|0);S6(0,27,0);gGz(9669011|0,0|0,27|0);S6(1,27,0);c[3540906]=1550;c[3540904]=600;c[3540902]=240;c[3540890]=432;c[3540888]=1374;c[3540886]=1502;h[1220314]=.2;h[1220324]=.2;h[1220334]=.2;h[1220344]=.2;h[1220354]=.2;h[1220364]=.2;return b|0}function aZ1(b){b=b|0;var c=0,d=0;do{if((b+9984&65535)<768){c=-1}else{d=b&65535;if((d|0)==57344){c=a[14165872]|a[14165808];break}else if((d|0)==59392){c=a[14165873]|a[14165809];break}else if((d|0)==61440){c=a[14165874]|a[14165810];break}else{c=-1;break}}}while(0);return c|0}function aZ2(b,d){b=b|0;d=d|0;var e=0,f=0,g=0.0,i=0.0,j=0.0,k=0.0,l=0.0,m=0.0,n=0.0,o=0.0;e=b&65535;if((b+10240&65535)<256){f=e-55296|0;a[(c[3541366]|0)+f|0]=d;if(!((f|0)<64&(f&1|0)==0)){return}a[(c[3541380]|0)+(f>>1)|0]=d;return}if((b+9984&65535)<768){return}if((e|0)==32768){a[14166208]=d&7;a[14166200]=(d&255)>>>5<<1&2|(d&255)>>>4&1|(d&255)>>>6<<2&4;a[14166192]=(d&255)>>>3&1;a[c[3541454]|0]=(d&255)>>>7;return}else if((e|0)==32769){a[14166184]=d;return}else if((e|0)==57348|(e|0)==57349|(e|0)==57350|(e|0)==57351){b=d&1;f=14165736+(e-57348<<2)|0;if((b|0)==(c[f>>2]|0)){return}c[f>>2]=b;b=(c[3541434]|0)==0;g=b?4030303030303031.0e-21:30303030303030305.0e-22;i=b?1.0e-12:1000001.0e-12;if((c[3541435]|0)==0){j=i;k=g+21276595744680853.0e-22}else{j=i+21276595744680853.0e-22;k=g}if((c[3541436]|0)==0){l=j;m=k+45454545454545455.0e-22}else{l=j+45454545454545455.0e-22;m=k}if((c[3541437]|0)==0){n=l;o=m+1.0e-5}else{n=l+1.0e-5;o=m}m=1.0/o;h[932738]=1.0e9/((m*2.0e6/(m+1.0/n)+1.0e5)*58788.0)*100.0;return}else if((e|0)==59392|(e|0)==59393|(e|0)==59394|(e|0)==59395|(e|0)==59396|(e|0)==59397|(e|0)==59398|(e|0)==59399){b=e-59392|0;f=d&1;switch(b&7|0){case 0:case 1:case 2:{c[14165720+(b<<2)>>2]=f&255;return};case 3:{a[14165672]=f;if(f<<24>>24==0){return}c[3541416]=100;h[932737]=0.0;return};case 5:{do{if(f<<24>>24!=0){if((a[14165752]&1)!=0){break}a[14165512]=1;h[932735]=0.0}}while(0);a[14165752]=f;return};case 7:case 6:{f=b&1;c[3541336]=c[3541336]&~(1<<f)|(d&1)<<f;return};default:{return}}}else if((e|0)==61441){a[14165768]=d&1;return}else if((e|0)==61444){f=d&1;c[3541360]=f;if((f|0)!=0){return}c[3541358]=-1;return}else if((e|0)==61446){a[14165832]=d&1;return}else if((e|0)==61447){a[14165824]=d&1;return}else if((e|0)==63488){c[3541406]=d&255;return}else{return}}function aZ3(a){a=a|0;return 0}function aZ4(a,b){a=a|0;b=b|0;return}function aZ5(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4107820+(b*112|0)>>2];c[a+104>>2]=c[4107824+(b*112|0)>>2];c[a+108>>2]=c[4107828+(b*112|0)>>2];d=0;return d|0}function aZ6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=4107720+(b*112|0);e=0;return e|0}function aZ7(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1287848+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aZ8(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>25){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4109288+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aZ9(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;b=i;i=i+480|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;l=b+360|0;m=b+472|0;c[3541404]=2080;a04()|0;n=c[3541348]|0;o=0;while(1){if((o|0)>=1024){p=0;break}q=9638528+(o<<2)|0;if((c[q>>2]|0)==0){r=44093;break}else{o=o+1|0}}do{if((r|0)==44093){o=gGq(n)|0;c[q>>2]=o;if((o|0)==0){p=0;break}gGz(o|0,0,n|0);p=o}}while(0);c[3541356]=p;n=(c[3541318]|0)+(c[3541326]|0)+(c[3541312]|0)|0;if((c[3542200]|0)==0){s=1;i=b;return s|0}q=l+108|0;c[q>>2]=0;o=l+100|0;c[o>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,n)|0;do{if((c[q>>2]|0)!=0){l=c[o>>2]|0;c[m>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](m,n,0)|0;if((l|0)<1){s=1;i=b;return s|0}if((gzL(p,0,n)|0)==0){break}else{s=1}i=b;return s|0}}while(0);n=(c[3541356]|0)+4096|0;p=(c[3541326]|0)+1+(c[3541318]|0)+(c[3541312]|0)|0;if((c[3542200]|0)==0){s=1;i=b;return s|0}m=j+108|0;c[m>>2]=0;o=j+100|0;c[o>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,p)|0;do{if((c[m>>2]|0)!=0){j=c[o>>2]|0;c[k>>2]=9534384;q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[q&16383](k,p,0)|0;if((j|0)<1){s=1;i=b;return s|0}if((gzL(n,0,p)|0)==0){break}else{s=1}i=b;return s|0}}while(0);p=(c[3541356]|0)+8192|0;n=(c[3541326]|0)+2+(c[3541318]|0)+(c[3541312]|0)|0;if((c[3542200]|0)==0){s=1;i=b;return s|0}k=g+108|0;c[k>>2]=0;o=g+100|0;c[o>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,n)|0;do{if((c[k>>2]|0)!=0){g=c[o>>2]|0;c[h>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](h,n,0)|0;if((g|0)<1){s=1;i=b;return s|0}if((gzL(p,0,n)|0)==0){break}else{s=1}i=b;return s|0}}while(0);n=(c[3541356]|0)+12288|0;p=(c[3541326]|0)+3+(c[3541318]|0)+(c[3541312]|0)|0;if((c[3542200]|0)==0){s=1;i=b;return s|0}h=e+108|0;c[h>>2]=0;o=e+100|0;c[o>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,p)|0;do{if((c[h>>2]|0)!=0){e=c[o>>2]|0;c[f>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](f,p,0)|0;if((e|0)<1){s=1;i=b;return s|0}if((gzL(n,0,p)|0)==0){break}else{s=1}i=b;return s|0}}while(0);p=c[3541348]|0;n=c[3541356]|0;if((p|0)==0){u=n}else{f=0;o=0;while(1){h=o<<4;e=a[n+(h|1)|0]|0;k=a[n+(h|2)|0]|0;g=a[n+(h|3)|0]|0;m=a[n+(h|4)|0]|0;j=a[n+(h|5)|0]|0;q=a[n+(h|6)|0]|0;l=a[n+(h|7)|0]|0;t=a[n+(h|8)|0]|0;v=a[n+(h|9)|0]|0;w=a[n+(h|10)|0]|0;x=a[n+(h|11)|0]|0;y=a[n+(h|12)|0]|0;z=a[n+(h|13)|0]|0;A=a[n+(h|14)|0]|0;B=a[n+(h|15)|0]|0;a[n+f|0]=a[n+h|0]|0;a[n+(f|8)|0]=e;a[n+(f|1)|0]=k;a[n+(f|9)|0]=g;a[n+(f|2)|0]=m;a[n+(f|10)|0]=j;a[n+(f|3)|0]=q;a[n+(f|11)|0]=l;a[n+(f|4)|0]=t;a[n+(f|12)|0]=v;a[n+(f|5)|0]=w;a[n+(f|13)|0]=x;a[n+(f|6)|0]=y;a[n+(f|14)|0]=z;a[n+(f|7)|0]=A;a[n+(f|15)|0]=B;B=f+16|0;if(B>>>0<p>>>0){f=B;o=o+1|0}else{u=n;break}}}n=c[3541414]|0;o=c[3541472]|0;if((n|0)>0){f=c[1865546]|0;p=0;do{B=p<<6;gGz(o+B|0,0,64);A=0;do{z=B+(c[1238464+(A<<2)>>2]|0)|0;y=(A<<3)+B|0;x=0;do{w=z+(c[614800+(x<<2)>>2]|0)|0;if(((d[u+((w|0)/8|0)|0]|0)&128>>>((w&7)>>>0)|0)!=0){w=o+(y+x)|0;a[w]=a[w]|2}x=x+1|0;}while((x|0)<8);A=A+1|0;}while((A|0)<8);A=f+B|0;x=0;do{y=A+(c[1238464+(x<<2)>>2]|0)|0;z=(x<<3)+B|0;w=0;do{v=y+(c[614800+(w<<2)>>2]|0)|0;if(((d[u+((v|0)/8|0)|0]|0)&128>>>((v&7)>>>0)|0)!=0){v=o+(z+w)|0;a[v]=a[v]|1}w=w+1|0;}while((w|0)<8);x=x+1|0;}while((x|0)<8);p=p+1|0;}while((p|0)<(n|0))}n=c[3541412]|0;p=c[3541364]|0;if((n|0)>0){o=c[1865412]|0;f=0;while(1){x=f<<8;gGz(p+x|0,0,256);B=0;do{A=x+(c[611776+(B<<2)>>2]|0)|0;w=(B<<4)+x|0;z=0;do{y=A+(c[601400+(z<<2)>>2]|0)|0;if(((d[u+((y|0)/8|0)|0]|0)&128>>>((y&7)>>>0)|0)!=0){y=p+(w+z)|0;a[y]=a[y]|2}z=z+1|0;}while((z|0)<16);B=B+1|0;}while((B|0)<16);B=o+x|0;z=0;do{w=B+(c[611776+(z<<2)>>2]|0)|0;A=(z<<4)+x|0;y=0;do{v=w+(c[601400+(y<<2)>>2]|0)|0;if(((d[u+((v|0)/8|0)|0]|0)&128>>>((v&7)>>>0)|0)!=0){v=p+(A+y)|0;a[v]=a[v]|1}y=y+1|0;}while((y|0)<16);z=z+1|0;}while((z|0)<16);z=f+1|0;if((z|0)<(n|0)){f=z}else{C=0;break}}}else{C=0}while(1){if((C|0)>=1024){break}D=9638528+(C<<2)|0;if((c[D>>2]|0)==(u|0)){r=44133;break}else{C=C+1|0}}if((r|0)==44133){gGr(u);c[D>>2]=0}c[3541356]=0;c[3541474]=9296;c[3541392]=4214;c[3541466]=90;c[3541462]=112;c[3541464]=38;c[3541390]=3610;a[14165472]=0;a[14165480]=-1;D=0;while(1){if((D|0)>=1024){E=0;break}F=9638528+(D<<2)|0;if((c[F>>2]|0)==0){r=44137;break}else{D=D+1|0}}do{if((r|0)==44137){D=gGq(1024)|0;c[F>>2]=D;if((D|0)==0){E=0;break}gGz(D|0,0,1024);E=D}}while(0);c[3541338]=E;s=0;i=b;return s|0}function a_a(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1966772+(b*112|0)>>2];c[a+104>>2]=c[1966776+(b*112|0)>>2];c[a+108>>2]=c[1966780+(b*112|0)>>2];d=0;return d|0}function a_b(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=1966672+(b*112|0);e=0;return e|0}function a_c(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1286380+(b*112|0)>>2];c[a+104>>2]=c[1286384+(b*112|0)>>2];c[a+108>>2]=c[1286388+(b*112|0)>>2];d=0;return d|0}function a_d(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=1286280+(b*112|0);e=0;return e|0}function a_e(b){b=b|0;var c=0,d=0;c=b&65535;if((c|0)==5376|(c|0)==13568|(c|0)==21760|(c|0)==29952){d=a[14165872]|a[14165808]}else if((c|0)==5504|(c|0)==13696|(c|0)==21888|(c|0)==30080){d=a[14165873]|a[14165809]}else if((c|0)==5632|(c|0)==13824|(c|0)==22016|(c|0)==30208){d=a[14165874]|a[14165810]}else{d=0}return d|0}function a_f(b,d){b=b|0;d=d|0;var e=0,f=0,g=0.0,i=0.0,j=0.0,k=0.0,l=0.0,m=0.0,n=0.0,o=0.0,p=0.0,q=0.0,r=0.0,s=0.0,t=0.0,u=0.0,v=0.0,w=0.0,x=0.0,y=0.0,z=0.0,A=0.0,B=0.0,C=0.0,D=0.0,E=0.0,F=0.0,G=0.0;e=b&65535;if((b-5248&65535)<128|(b-13440&65535)<128|(b-21632&65535)<128|(b-29824&65535)<128){b=e&127;a[(c[3541366]|0)+b|0]=d;if(!(b>>>0<64&(e&1|0)==0)){return}a[(c[3541380]|0)+(b>>>1)|0]=d;return}if((e|0)==5504|(e|0)==5505|(e|0)==5506){b=e-5504|0;f=d&1;switch(b&7|0){case 0:case 1:case 2:{c[14165720+(b<<2)>>2]=f&255;return};case 3:{a[14165672]=f;if(f<<24>>24==0){return}c[3541416]=100;h[932737]=0.0;return};case 5:{do{if(f<<24>>24!=0){if((a[14165752]&1)!=0){break}a[14165512]=1;h[932735]=0.0}}while(0);a[14165752]=f;return};case 7:case 6:{f=b&1;c[3541336]=c[3541336]&~(1<<f)|(d&1)<<f;return};default:{return}}}else if((e|0)==13696|(e|0)==13697|(e|0)==13698){f=e-13696|0;b=d&1;switch(f&7|0){case 0:case 1:case 2:{c[14165720+(f<<2)>>2]=b&255;return};case 3:{a[14165672]=b;if(b<<24>>24==0){return}c[3541416]=100;h[932737]=0.0;return};case 5:{do{if(b<<24>>24!=0){if((a[14165752]&1)!=0){break}a[14165512]=1;h[932735]=0.0}}while(0);a[14165752]=b;return};case 7:case 6:{b=f&1;c[3541336]=c[3541336]&~(1<<b)|(d&1)<<b;return};default:{return}}}else if((e|0)==21888|(e|0)==21889|(e|0)==21890){b=e-21888|0;f=d&1;switch(b&7|0){case 0:case 1:case 2:{c[14165720+(b<<2)>>2]=f&255;return};case 3:{a[14165672]=f;if(f<<24>>24==0){return}c[3541416]=100;h[932737]=0.0;return};case 5:{do{if(f<<24>>24!=0){if((a[14165752]&1)!=0){break}a[14165512]=1;h[932735]=0.0}}while(0);a[14165752]=f;return};case 7:case 6:{f=b&1;c[3541336]=c[3541336]&~(1<<f)|(d&1)<<f;return};default:{return}}}else if((e|0)==30080|(e|0)==30081|(e|0)==30082){f=e-30080|0;b=d&1;switch(f&7|0){case 0:case 1:case 2:{c[14165720+(f<<2)>>2]=b&255;return};case 3:{a[14165672]=b;if(b<<24>>24==0){return}c[3541416]=100;h[932737]=0.0;return};case 5:{do{if(b<<24>>24!=0){if((a[14165752]&1)!=0){break}a[14165512]=1;h[932735]=0.0}}while(0);a[14165752]=b;return};case 7:case 6:{b=f&1;c[3541336]=c[3541336]&~(1<<b)|(d&1)<<b;return};default:{return}}}else if((e|0)==21892|(e|0)==21893|(e|0)==21894|(e|0)==21895){b=d&1;f=14165736+(e-21892<<2)|0;if((b|0)==(c[f>>2]|0)){return}c[f>>2]=b;b=(c[3541434]|0)==0;g=b?4030303030303031.0e-21:30303030303030305.0e-22;i=b?1.0e-12:1000001.0e-12;if((c[3541435]|0)==0){j=i;k=g+21276595744680853.0e-22}else{j=i+21276595744680853.0e-22;k=g}if((c[3541436]|0)==0){l=j;m=k+45454545454545455.0e-22}else{l=j+45454545454545455.0e-22;m=k}if((c[3541437]|0)==0){n=l;o=m+1.0e-5}else{n=l+1.0e-5;o=m}m=1.0/o;h[932738]=1.0e9/((m*2.0e6/(m+1.0/n)+1.0e5)*58788.0)*100.0;return}else if((e|0)==30084|(e|0)==30085|(e|0)==30086|(e|0)==30087){b=d&1;f=14165736+(e-30084<<2)|0;if((b|0)==(c[f>>2]|0)){return}c[f>>2]=b;b=(c[3541434]|0)==0;n=b?4030303030303031.0e-21:30303030303030305.0e-22;m=b?1.0e-12:1000001.0e-12;if((c[3541435]|0)==0){p=m;q=n+21276595744680853.0e-22}else{p=m+21276595744680853.0e-22;q=n}if((c[3541436]|0)==0){r=p;s=q+45454545454545455.0e-22}else{r=p+45454545454545455.0e-22;s=q}if((c[3541437]|0)==0){t=r;u=s+1.0e-5}else{t=r+1.0e-5;u=s}s=1.0/u;h[932738]=1.0e9/((s*2.0e6/(s+1.0/t)+1.0e5)*58788.0)*100.0;return}else if((e|0)==5508|(e|0)==5509|(e|0)==5510|(e|0)==5511){b=d&1;f=14165736+(e-5508<<2)|0;if((b|0)==(c[f>>2]|0)){return}c[f>>2]=b;b=(c[3541434]|0)==0;t=b?4030303030303031.0e-21:30303030303030305.0e-22;s=b?1.0e-12:1000001.0e-12;if((c[3541435]|0)==0){v=s;w=t+21276595744680853.0e-22}else{v=s+21276595744680853.0e-22;w=t}if((c[3541436]|0)==0){x=v;y=w+45454545454545455.0e-22}else{x=v+45454545454545455.0e-22;y=w}if((c[3541437]|0)==0){z=x;A=y+1.0e-5}else{z=x+1.0e-5;A=y}y=1.0/A;h[932738]=1.0e9/((y*2.0e6/(y+1.0/z)+1.0e5)*58788.0)*100.0;return}else if((e|0)==30214|(e|0)==22022|(e|0)==13830|(e|0)==5638){a[14165832]=d&1;return}else if((e|0)==30215|(e|0)==22023|(e|0)==13831|(e|0)==5639){a[14165824]=d&1;return}else if((e|0)==30336|(e|0)==22144|(e|0)==13952|(e|0)==5760){c[3541406]=d&255;return}else if((e|0)==13700|(e|0)==13701|(e|0)==13702|(e|0)==13703){b=d&1;d=14165736+(e-13700<<2)|0;if((b|0)==(c[d>>2]|0)){return}c[d>>2]=b;b=(c[3541434]|0)==0;z=b?4030303030303031.0e-21:30303030303030305.0e-22;y=b?1.0e-12:1000001.0e-12;if((c[3541435]|0)==0){B=y;C=z+21276595744680853.0e-22}else{B=y+21276595744680853.0e-22;C=z}if((c[3541436]|0)==0){D=B;E=C+45454545454545455.0e-22}else{D=B+45454545454545455.0e-22;E=C}if((c[3541437]|0)==0){F=D;G=E+1.0e-5}else{F=D+1.0e-5;G=E}E=1.0/G;h[932738]=1.0e9/((E*2.0e6/(E+1.0/F)+1.0e5)*58788.0)*100.0;return}else{return}}function a_g(b){b=b|0;var c=0;if(b<<16>>16!=258){c=0;return c|0}c=(a[14165368]|0)!=0?-128:0;return c|0}function a_h(a,b){a=a|0;b=b|0;return}function a_i(b){b=b|0;var c=0,d=0;c=b&65535;if((c|0)==5376|(c|0)==13568|(c|0)==21760|(c|0)==29952){d=a[14165872]|a[14165808]}else if((c|0)==5504|(c|0)==13696|(c|0)==21888|(c|0)==30080){d=a[14165873]|a[14165809]}else if((c|0)==5632|(c|0)==13824|(c|0)==22016|(c|0)==30208){d=a[14165874]|a[14165810]}else if((c|0)==5888|(c|0)==14080|(c|0)==22272|(c|0)==30464){d=a[14165875]|a[14165811]}else{d=0}return d|0}function a_j(b,d){b=b|0;d=d|0;var e=0,f=0,g=0.0,i=0.0,j=0.0,k=0.0,l=0.0,m=0.0,n=0.0,o=0.0,p=0,q=0.0,r=0.0,s=0.0,t=0.0,u=0.0,v=0.0,w=0.0,x=0.0,y=0.0,z=0.0,A=0.0,B=0.0,C=0.0,D=0.0,E=0.0,F=0.0,G=0.0,H=0.0;e=b&65535;if((b-5248&65535)<128|(b-13440&65535)<128|(b-21632&65535)<128|(b-29824&65535)<128){b=e&127;a[(c[3541366]|0)+b|0]=d;if(!(b>>>0<64&(e&1|0)==0)){return}a[(c[3541380]|0)+(b>>>1)|0]=d;return}if((e|0)==13702|(e|0)==13703){b=d&1;f=14165736+(e-13702<<2)|0;if((b|0)==(c[f>>2]|0)){return}c[f>>2]=b;b=(c[3541434]|0)==0;g=b?4030303030303031.0e-21:30303030303030305.0e-22;i=b?1.0e-12:1000001.0e-12;if((c[3541435]|0)==0){j=i;k=g+21276595744680853.0e-22}else{j=i+21276595744680853.0e-22;k=g}if((c[3541436]|0)==0){l=j;m=k+45454545454545455.0e-22}else{l=j+45454545454545455.0e-22;m=k}if((c[3541437]|0)==0){n=l;o=m+1.0e-5}else{n=l+1.0e-5;o=m}m=1.0/o;h[932738]=1.0e9/((m*2.0e6/(m+1.0/n)+1.0e5)*58788.0)*100.0;return}else if((e|0)==5632|(e|0)==13824|(e|0)==22016|(e|0)==30208){c[3541406]=d&255;return}else if((e|0)==13696|(e|0)==13697|(e|0)==13698){b=e-13696|0;f=d&1;switch(b&7|0){case 3:{a[14165672]=f;if(f<<24>>24==0){return}c[3541416]=100;h[932737]=0.0;return};case 7:case 6:{p=b&1;c[3541336]=c[3541336]&~(1<<p)|(d&1)<<p;return};case 5:{do{if(f<<24>>24!=0){if((a[14165752]&1)!=0){break}a[14165512]=1;h[932735]=0.0}}while(0);a[14165752]=f;return};case 0:case 1:case 2:{c[14165720+(b<<2)>>2]=f&255;return};default:{return}}}else if((e|0)==30471|(e|0)==30470|(e|0)==30469|(e|0)==30468|(e|0)==22279|(e|0)==22278|(e|0)==22277|(e|0)==22276|(e|0)==14087|(e|0)==14086|(e|0)==14085|(e|0)==14084|(e|0)==5895|(e|0)==5894|(e|0)==5892|(e|0)==5893){f=e&3;c[3541336]=c[3541336]&~(1<<f)|(d&1)<<f;return}else if((e|0)==30080|(e|0)==30081|(e|0)==30082){f=e-30080|0;b=d&1;switch(f&7|0){case 7:case 6:{p=f&1;c[3541336]=c[3541336]&~(1<<p)|(d&1)<<p;return};case 0:case 1:case 2:{c[14165720+(f<<2)>>2]=b&255;return};case 3:{a[14165672]=b;if(b<<24>>24==0){return}c[3541416]=100;h[932737]=0.0;return};case 5:{do{if(b<<24>>24!=0){if((a[14165752]&1)!=0){break}a[14165512]=1;h[932735]=0.0}}while(0);a[14165752]=b;return};default:{return}}}else if((e|0)==30086|(e|0)==30087){b=d&1;f=14165736+(e-30086<<2)|0;if((b|0)==(c[f>>2]|0)){return}c[f>>2]=b;b=(c[3541434]|0)==0;n=b?4030303030303031.0e-21:30303030303030305.0e-22;m=b?1.0e-12:1000001.0e-12;if((c[3541435]|0)==0){q=m;r=n+21276595744680853.0e-22}else{q=m+21276595744680853.0e-22;r=n}if((c[3541436]|0)==0){s=q;t=r+45454545454545455.0e-22}else{s=q+45454545454545455.0e-22;t=r}if((c[3541437]|0)==0){u=s;v=t+1.0e-5}else{u=s+1.0e-5;v=t}t=1.0/v;h[932738]=1.0e9/((t*2.0e6/(t+1.0/u)+1.0e5)*58788.0)*100.0;return}else if((e|0)==21888|(e|0)==21889|(e|0)==21890){b=e-21888|0;f=d&1;switch(b&7|0){case 5:{do{if(f<<24>>24!=0){if((a[14165752]&1)!=0){break}a[14165512]=1;h[932735]=0.0}}while(0);a[14165752]=f;return};case 7:case 6:{p=b&1;c[3541336]=c[3541336]&~(1<<p)|(d&1)<<p;return};case 0:case 1:case 2:{c[14165720+(b<<2)>>2]=f&255;return};case 3:{a[14165672]=f;if(f<<24>>24==0){return}c[3541416]=100;h[932737]=0.0;return};default:{return}}}else if((e|0)==5504|(e|0)==5505|(e|0)==5506){f=e-5504|0;b=d&1;switch(f&7|0){case 5:{do{if(b<<24>>24!=0){if((a[14165752]&1)!=0){break}a[14165512]=1;h[932735]=0.0}}while(0);a[14165752]=b;return};case 7:case 6:{p=f&1;c[3541336]=c[3541336]&~(1<<p)|(d&1)<<p;return};case 0:case 1:case 2:{c[14165720+(f<<2)>>2]=b&255;return};case 3:{a[14165672]=b;if(b<<24>>24==0){return}c[3541416]=100;h[932737]=0.0;return};default:{return}}}else if((e|0)==5510|(e|0)==5511){b=d&1;f=14165736+(e-5510<<2)|0;if((b|0)==(c[f>>2]|0)){return}c[f>>2]=b;b=(c[3541434]|0)==0;u=b?4030303030303031.0e-21:30303030303030305.0e-22;t=b?1.0e-12:1000001.0e-12;if((c[3541435]|0)==0){w=t;x=u+21276595744680853.0e-22}else{w=t+21276595744680853.0e-22;x=u}if((c[3541436]|0)==0){y=w;z=x+45454545454545455.0e-22}else{y=w+45454545454545455.0e-22;z=x}if((c[3541437]|0)==0){A=y;B=z+1.0e-5}else{A=y+1.0e-5;B=z}z=1.0/B;h[932738]=1.0e9/((z*2.0e6/(z+1.0/A)+1.0e5)*58788.0)*100.0;return}else if((e|0)==21894|(e|0)==21895){b=d&1;d=14165736+(e-21894<<2)|0;if((b|0)==(c[d>>2]|0)){return}c[d>>2]=b;b=(c[3541434]|0)==0;A=b?4030303030303031.0e-21:30303030303030305.0e-22;z=b?1.0e-12:1000001.0e-12;if((c[3541435]|0)==0){C=z;D=A+21276595744680853.0e-22}else{C=z+21276595744680853.0e-22;D=A}if((c[3541436]|0)==0){E=C;F=D+45454545454545455.0e-22}else{E=C+45454545454545455.0e-22;F=D}if((c[3541437]|0)==0){G=E;H=F+1.0e-5}else{G=E+1.0e-5;H=F}F=1.0/H;h[932738]=1.0e9/((F*2.0e6/(F+1.0/G)+1.0e5)*58788.0)*100.0;return}else{return}}function a_k(b){b=b|0;var c=0,d=0;c=b&65535;do{if((c|0)==0){b=(e[4859070]|0)+(e[4859069]|0)|0;if((b|0)==46|(b|0)==663){d=1;break}d=0}else if((c|0)==258){d=(a[14165368]|0)!=0?-128:0}else{d=0}}while(0);return d|0}function a_l(a,b){a=a|0;b=b|0;return}function a_m(b){b=b|0;var c=0,d=0;c=b&65535;if((c|0)==5376|(c|0)==13568|(c|0)==21760|(c|0)==29952){d=a[14165872]|a[14165808]}else if((c|0)==5504|(c|0)==13696|(c|0)==21888|(c|0)==30080){d=a[14165873]|a[14165809]}else if((c|0)==5632|(c|0)==13824|(c|0)==22016|(c|0)==30208){d=a[14165874]|a[14165810]}else{d=0}return d|0}function a_n(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((b-5120&65535)<256|(b-13312&65535)<256|(b-21504&65535)<256|(b-29696&65535)<256){b=e&255;a[(c[3541366]|0)+b|0]=d;if(!(b>>>0<64&(e&1|0)==0)){return}a[(c[3541380]|0)+(b>>>1)|0]=d;return}if((e|0)==5638|(e|0)==13830|(e|0)==22022|(e|0)==30214){a[14165832]=d&1;return}else if((e|0)==30215|(e|0)==22023|(e|0)==13831|(e|0)==5639){a[14165824]=d&1;return}else{return}}function a_o(b){b=b|0;var c=0;if(b<<16>>16!=258){c=0;return c|0}c=(a[14165368]|0)!=0?-128:0;return c|0}function a_p(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((b-32&65535)<32){a[(c[3541454]|0)+(e-32)|0]=d;return}if((e|0)==29){TR(0,d&255);return}else if((e|0)==30){TR(1,d&255);return}else if((e|0)==31){TR(2,d&255);return}else{return}}function a_q(b){b=b|0;var c=0,d=0;c=b&65535;if((c|0)==257){return((e[4859070]|0)+(e[4859069]|0)|0)==49|0}else if((c|0)==258){d=(a[14165368]|0)!=0?-128:0;return d|0}else{d=0;return d|0}return 0}function a_r(b,d){b=b|0;d=d|0;if((b-32&65535)<32){a[(c[3541454]|0)+((b&65535)-32)|0]=d;return}if(b<<16>>16!=257){return}TR(0,d&255);return}function a_s(a){a=a|0;var b=0,c=0;b=a&65535;if((b|0)==4624|(b|0)==4625|(b|0)==4626|(b|0)==4627|(b|0)==12816|(b|0)==12817|(b|0)==12818|(b|0)==12819|(b|0)==21008|(b|0)==21009|(b|0)==21010|(b|0)==21011|(b|0)==29200|(b|0)==29201|(b|0)==29202|(b|0)==29203){c=S3(0,b&3)|0}else if((b|0)==5376|(b|0)==5377|(b|0)==5378|(b|0)==5379|(b|0)==13568|(b|0)==13569|(b|0)==13570|(b|0)==13571|(b|0)==21760|(b|0)==21761|(b|0)==21762|(b|0)==21763|(b|0)==29952|(b|0)==29953|(b|0)==29954|(b|0)==29955){c=S3(0,b&3)|0}else{c=0}return c|0}function a_t(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((b-5120&65535)<256|(b-13312&65535)<256|(b-21504&65535)<256|(b-29696&65535)<256){b=e&255;a[(c[3541366]|0)+b|0]=d;if(!(b>>>0<64&(e&1|0)==0)){return}a[(c[3541380]|0)+(b>>>1)|0]=d;return}if((e|0)==4624|(e|0)==4625|(e|0)==4626|(e|0)==4627|(e|0)==12816|(e|0)==12817|(e|0)==12818|(e|0)==12819|(e|0)==21008|(e|0)==21009|(e|0)==21010|(e|0)==21011|(e|0)==29200|(e|0)==29201|(e|0)==29202|(e|0)==29203){S4(1,e&3,d);return}else if((e|0)==5376|(e|0)==5377|(e|0)==5378|(e|0)==5379|(e|0)==13568|(e|0)==13569|(e|0)==13570|(e|0)==13571|(e|0)==21760|(e|0)==21761|(e|0)==21762|(e|0)==21763|(e|0)==29952|(e|0)==29953|(e|0)==29954|(e|0)==29955){S4(0,e&3,d);return}else if((e|0)==30215|(e|0)==22023|(e|0)==13831|(e|0)==5639){a[14165824]=d&1;return}else if((e|0)==30214|(e|0)==22022|(e|0)==13830|(e|0)==5638){a[14165832]=d&1;return}else{return}}function a_u(b){b=b|0;var c=0;if(b<<16>>16!=258){c=0;return c|0}c=(a[14165368]|0)!=0?-128:0;return c|0}function a_v(a,b){a=a|0;b=b|0;return}function a_w(b){b=b|0;var c=0,d=0;c=b&65535;do{if((c|0)==0){b=(e[4859070]|0)+(e[4859069]|0)|0;if((b|0)==43|(b|0)==2599){d=1;break}d=0}else if((c|0)==258){d=(a[14165368]|0)!=0?-128:0}else{d=0}}while(0);return d|0}function a_x(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3856772+(b*112|0)>>2];c[a+104>>2]=c[3856776+(b*112|0)>>2];c[a+108>>2]=c[3856780+(b*112|0)>>2];d=0;return d|0}function a_y(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=3856672+(b*112|0);e=0;return e|0}function a_z(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1238832+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function a_A(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>5){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3857904+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function a_B(){c[3541404]=8338;return a04()|0}function a_C(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4041372+(b*112|0)>>2];c[a+104>>2]=c[4041376+(b*112|0)>>2];c[a+108>>2]=c[4041380+(b*112|0)>>2];d=0;return d|0}function a_D(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=4041272+(b*112|0);e=0;return e|0}function a_E(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1276864+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function a_F(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4042392+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function a_G(){var a=0;c[3541404]=138;a=a04()|0;c[3541474]=3414;c[3541462]=50;c[3541464]=52;return a|0}function a_H(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4040572+(b*112|0)>>2];c[a+104>>2]=c[4040576+(b*112|0)>>2];c[a+108>>2]=c[4040580+(b*112|0)>>2];d=0;return d|0}function a_I(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=4040472+(b*112|0);e=0;return e|0}function a_J(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=i;i=i+240|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;c[3541404]=138;a04()|0;j=c[3541348]|0;k=0;while(1){if((k|0)>=1024){l=0;break}m=9638528+(k<<2)|0;if((c[m>>2]|0)==0){n=44611;break}else{k=k+1|0}}do{if((n|0)==44611){k=gGq(j)|0;c[m>>2]=k;if((k|0)==0){l=0;break}gGz(k|0,0,j|0);l=k}}while(0);c[3541356]=l;l=0;while(1){if((l|0)>=1024){o=0;break}p=9638528+(l<<2)|0;if((c[p>>2]|0)==0){n=44616;break}else{l=l+1|0}}do{if((n|0)==44616){l=gGq(8192)|0;c[p>>2]=l;if((l|0)==0){o=0;break}gGz(l|0,0,8192);o=l}}while(0);p=(c[3541318]|0)+(c[3541326]|0)+(c[3541312]|0)|0;if((c[3542200]|0)==0){q=1;i=b;return q|0}l=g+108|0;c[l>>2]=0;j=g+100|0;c[j>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,p)|0;do{if((c[l>>2]|0)!=0){g=c[j>>2]|0;c[h>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](h,p,0)|0;if((g|0)<1){q=1;i=b;return q|0}if((gzL(o,0,p)|0)==0){break}else{q=1}i=b;return q|0}}while(0);p=c[3541356]|0;h=p+4096|0;gGC(h|0,o|0,4096)|0;h=o+4096|0;gGC(p|0,h|0,4096)|0;p=(c[3541326]|0)+1+(c[3541318]|0)+(c[3541312]|0)|0;if((c[3542200]|0)==0){q=1;i=b;return q|0}j=e+108|0;c[j>>2]=0;l=e+100|0;c[l>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,p)|0;do{if((c[j>>2]|0)!=0){e=c[l>>2]|0;c[f>>2]=9534384;g=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[g&16383](f,p,0)|0;if((e|0)<1){q=1;i=b;return q|0}if((gzL(o,0,p)|0)==0){break}else{q=1}i=b;return q|0}}while(0);p=c[3541356]|0;f=p+12288|0;gGC(f|0,o|0,4096)|0;f=p+8192|0;gGC(f|0,h|0,4096)|0;h=c[3541414]|0;f=c[3541472]|0;if((h|0)>0){l=c[1865546]|0;j=0;do{e=j<<6;gGz(f+e|0,0,64);g=0;do{m=e+(c[1238464+(g<<2)>>2]|0)|0;k=(g<<3)+e|0;r=0;do{s=m+(c[614800+(r<<2)>>2]|0)|0;if(((d[p+((s|0)/8|0)|0]|0)&128>>>((s&7)>>>0)|0)!=0){s=f+(k+r)|0;a[s]=a[s]|2}r=r+1|0;}while((r|0)<8);g=g+1|0;}while((g|0)<8);g=l+e|0;r=0;do{k=g+(c[1238464+(r<<2)>>2]|0)|0;m=(r<<3)+e|0;s=0;do{t=k+(c[614800+(s<<2)>>2]|0)|0;if(((d[p+((t|0)/8|0)|0]|0)&128>>>((t&7)>>>0)|0)!=0){t=f+(m+s)|0;a[t]=a[t]|1}s=s+1|0;}while((s|0)<8);r=r+1|0;}while((r|0)<8);j=j+1|0;}while((j|0)<(h|0))}h=c[3541412]|0;j=c[3541364]|0;if((h|0)>0){f=c[1865412]|0;l=0;while(1){r=l<<8;gGz(j+r|0,0,256);e=0;do{g=r+(c[611776+(e<<2)>>2]|0)|0;s=(e<<4)+r|0;m=0;do{k=g+(c[601400+(m<<2)>>2]|0)|0;if(((d[p+((k|0)/8|0)|0]|0)&128>>>((k&7)>>>0)|0)!=0){k=j+(s+m)|0;a[k]=a[k]|2}m=m+1|0;}while((m|0)<16);e=e+1|0;}while((e|0)<16);e=f+r|0;m=0;do{s=e+(c[611776+(m<<2)>>2]|0)|0;g=(m<<4)+r|0;k=0;do{t=s+(c[601400+(k<<2)>>2]|0)|0;if(((d[p+((t|0)/8|0)|0]|0)&128>>>((t&7)>>>0)|0)!=0){t=j+(g+k)|0;a[t]=a[t]|1}k=k+1|0;}while((k|0)<16);m=m+1|0;}while((m|0)<16);m=l+1|0;if((m|0)<(h|0)){l=m}else{u=0;break}}}else{u=0}while(1){if((u|0)>=1024){break}v=9638528+(u<<2)|0;if((c[v>>2]|0)==(p|0)){n=44646;break}else{u=u+1|0}}if((n|0)==44646){gGr(p);c[v>>2]=0}c[3541356]=0;v=0;while(1){if((v|0)>=1024){break}w=9638528+(v<<2)|0;if((c[w>>2]|0)==(o|0)){n=44650;break}else{v=v+1|0}}if((n|0)==44650){gGr(o);c[w>>2]=0}c[3541474]=3414;c[3541462]=50;c[3541464]=52;q=0;i=b;return q|0}function a_K(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>4){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4042580+(b*112|0)>>2];c[a+104>>2]=c[4042584+(b*112|0)>>2];c[a+108>>2]=c[4042588+(b*112|0)>>2];d=0;return d|0}function a_L(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<5&(d|0)==0)){e=1;return e|0}c[a>>2]=4042480+(b*112|0);e=0;return e|0}function a_M(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>4){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3582548+(b*112|0)>>2];c[a+104>>2]=c[3582552+(b*112|0)>>2];c[a+108>>2]=c[3582556+(b*112|0)>>2];d=0;return d|0}function a_N(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<5&(d|0)==0)){e=1;return e|0}c[a>>2]=3582448+(b*112|0);e=0;return e|0}function a_O(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1206448+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function a_P(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>2){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3583008+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function a_Q(){var b=0;c[3541404]=414;a[14165488]=15;b=a04()|0;c[3541462]=136;return b|0}function a_R(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>4){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5357188+(b*112|0)>>2];c[a+104>>2]=c[5357192+(b*112|0)>>2];c[a+108>>2]=c[5357196+(b*112|0)>>2];d=0;return d|0}function a_S(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<5&(d|0)==0)){e=1;return e|0}c[a>>2]=5357088+(b*112|0);e=0;return e|0}function a_T(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>5){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3872244+(b*112|0)>>2];c[a+104>>2]=c[3872248+(b*112|0)>>2];c[a+108>>2]=c[3872252+(b*112|0)>>2];d=0;return d|0}function a_U(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<6&(d|0)==0)){e=1;return e|0}c[a>>2]=3872144+(b*112|0);e=0;return e|0}function a_V(){var b=0;c[3541404]=7170;a[14165488]=16;b=a04()|0;c[3541462]=136;return b|0}function a_W(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3855220+(b*112|0)>>2];c[a+104>>2]=c[3855224+(b*112|0)>>2];c[a+108>>2]=c[3855228+(b*112|0)>>2];d=0;return d|0}function a_X(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=3855120+(b*112|0);e=0;return e|0}function a_Y(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1313920+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function a_Z(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3856464+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function a__(){var b=0;c[3541404]=5104;a[14165488]=17;b=a04()|0;a0V();c[3541392]=8638;c[3541466]=60;gGz(9668984|0,0|0,27|0);S6(0,27,0);gGz(9669011|0,0|0,27|0);S6(1,27,0);c[3540906]=1550;c[3540904]=600;c[3540902]=240;c[3540890]=432;c[3540888]=1374;c[3540886]=1172;return b|0}function a_$(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3866932+(b*112|0)>>2];c[a+104>>2]=c[3866936+(b*112|0)>>2];c[a+108>>2]=c[3866940+(b*112|0)>>2];d=0;return d|0}function a_0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=3866832+(b*112|0);e=0;return e|0}function a_1(){var b=0;c[3541404]=6812;a[14165488]=17;b=a04()|0;a0V();c[3541392]=8638;c[3541466]=60;c[3541462]=122;c[3541464]=38;c[2113202]=12800;gGz(9668984|0,0|0,27|0);S6(0,27,0);gGz(9669011|0,0|0,27|0);S6(1,27,0);c[3540906]=1550;c[3540904]=600;c[3540902]=240;c[3540890]=432;c[3540888]=1374;c[3540886]=1172;return b|0}function a_2(){a_3();c[2110940]=8443768;gGC(9718136,9669136,38)|0;c[2110942]=648;c[2110943]=2942;c[2110944]=1646;c[2110945]=3432;c[2444]=-1;fwR(0);return}function a_3(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;gGz(8443768,0,1552);gGz(9669136,0,38);a=c[2427044]|0;c[9681616+(a<<3)>>2]=728712;c[9681620+(a<<3)>>2]=0;c[2427044]=a+1;c[2110940]=8443768;c[2444]=0;gGC(9718136,9669136,38)|0;a=c[3541386]|0;b=0;do{d=a+(b<<8)|0;c[8443784+(b<<2)>>2]=d;c[8444808+(b<<2)>>2]=d;b=b+1|0;}while((b|0)<16);b=c[3541366]|0;c[2110966]=b;d=c[3541340]|0;c[2110970]=d;c[2111098]=d;c[2111226]=d;e=d+256|0;c[2110971]=e;c[2111099]=e;c[2111227]=e;f=d+512|0;c[2110972]=f;c[2111100]=f;c[2111228]=f;g=d+768|0;c[2110973]=g;c[2111101]=g;c[2111229]=g;h=c[3541334]|0;c[2110974]=h;c[2111102]=h;c[2111230]=h;i=h+256|0;c[2110975]=i;c[2111103]=i;c[2111231]=i;j=h+512|0;c[2110976]=j;c[2111104]=j;c[2111232]=j;k=h+768|0;c[2110977]=k;c[2111105]=k;c[2111233]=k;l=32;do{m=a+((l<<8)-4096)|0;c[8443784+(l<<2)>>2]=m;c[8444808+(l<<2)>>2]=m;l=l+1|0;}while((l|0)<48);c[2110998]=b;c[2111002]=d;c[2111130]=d;c[2111258]=d;c[2111003]=e;c[2111131]=e;c[2111259]=e;c[2111004]=f;c[2111132]=f;c[2111260]=f;c[2111005]=g;c[2111133]=g;c[2111261]=g;c[2111006]=h;c[2111134]=h;c[2111262]=h;c[2111007]=i;c[2111135]=i;c[2111263]=i;c[2111008]=j;c[2111136]=j;c[2111264]=j;c[2111009]=k;c[2111137]=k;c[2111265]=k;l=64;do{m=a+((l<<8)-8192)|0;c[8443784+(l<<2)>>2]=m;c[8444808+(l<<2)>>2]=m;l=l+1|0;}while((l|0)<80);c[2111030]=b;c[2111034]=d;c[2111162]=d;c[2111290]=d;c[2111035]=e;c[2111163]=e;c[2111291]=e;c[2111036]=f;c[2111164]=f;c[2111292]=f;c[2111037]=g;c[2111165]=g;c[2111293]=g;c[2111038]=h;c[2111166]=h;c[2111294]=h;c[2111039]=i;c[2111167]=i;c[2111295]=i;c[2111040]=j;c[2111168]=j;c[2111296]=j;c[2111041]=k;c[2111169]=k;c[2111297]=k;l=96;do{m=a+((l<<8)-12288)|0;c[8443784+(l<<2)>>2]=m;c[8444808+(l<<2)>>2]=m;l=l+1|0;}while((l|0)<112);c[2111062]=b;c[2111066]=d;c[2111194]=d;c[2111322]=d;c[2111067]=e;c[2111195]=e;c[2111323]=e;c[2111068]=f;c[2111196]=f;c[2111324]=f;c[2111069]=g;c[2111197]=g;c[2111325]=g;c[2111070]=h;c[2111198]=h;c[2111326]=h;c[2111071]=i;c[2111199]=i;c[2111327]=i;c[2111072]=j;c[2111200]=j;c[2111328]=j;c[2111073]=k;c[2111201]=k;c[2111329]=k;c[2110942]=504;c[2110943]=3234;c[2110944]=582;c[2110945]=1870;c[2112494]=324;gGC(9669136,9718136,38)|0;c[2444]=-1;return}function a_4(a){a=a|0;return 3}function a_5(){a_3();c[2110940]=8443768;gGC(9718136,9669136,38)|0;c[2110942]=648;c[2110943]=2942;c[2110944]=2598;c[2110945]=3432;c[2444]=-1;fwR(0);return}function a_6(){a_3();c[2110940]=8443768;gGC(9718136,9669136,38)|0;c[2110944]=1018;c[2110945]=1146;c[2444]=-1;return}function a_7(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[3541382]|0;b=0;while(1){if((b|0)>=1024){d=0;break}e=9638528+(b<<2)|0;if((c[e>>2]|0)==0){f=44792;break}else{b=b+1|0}}do{if((f|0)==44792){b=gGq(a)|0;c[e>>2]=b;if((b|0)==0){d=0;break}gGz(b|0,0,a|0);d=b}}while(0);c[3541356]=d;a=c[3541386]|0;e=c[3541382]|0;gGC(d|0,a|0,e)|0;e=a+6144|0;gGC(e|0,d|0,1024)|0;e=a+7168|0;b=d+1024|0;gGC(e|0,b|0,1024)|0;b=d+2048|0;gGC(a|0,b|0,1024)|0;b=a+1024|0;e=d+3072|0;gGC(b|0,e|0,1024)|0;e=a+2048|0;b=d+4096|0;gGC(e|0,b|0,1024)|0;b=a+3072|0;e=d+5120|0;gGC(b|0,e|0,1024)|0;e=a+4096|0;b=d+6144|0;gGC(e|0,b|0,1024)|0;b=a+5120|0;e=d+7168|0;gGC(b|0,e|0,1024)|0;e=a+14336|0;b=d+8192|0;gGC(e|0,b|0,1024)|0;b=a+15360|0;e=d+9216|0;gGC(b|0,e|0,1024)|0;e=a+8192|0;b=d+10240|0;gGC(e|0,b|0,1024)|0;b=a+9216|0;e=d+11264|0;gGC(b|0,e|0,1024)|0;e=a+10240|0;b=d+12288|0;gGC(e|0,b|0,1024)|0;b=a+11264|0;e=d+13312|0;gGC(b|0,e|0,1024)|0;e=a+12288|0;b=d+14336|0;gGC(e|0,b|0,1024)|0;b=a+13312|0;a=d+15360|0;gGC(b|0,a|0,1024)|0;a=0;while(1){if((a|0)>=1024){f=44799;break}g=9638528+(a<<2)|0;if((c[g>>2]|0)==(d|0)){break}else{a=a+1|0}}if((f|0)==44799){c[3541356]=0;a_8();c[2110940]=8443768;gGC(9718136,9669136,38)|0;c[2110942]=3390;c[2110943]=2288;c[2110944]=1610;c[2110945]=540;c[2444]=-1;return}gGr(d);c[g>>2]=0;c[3541356]=0;a_8();c[2110940]=8443768;gGC(9718136,9669136,38)|0;c[2110942]=3390;c[2110943]=2288;c[2110944]=1610;c[2110945]=540;c[2444]=-1;return}function a_8(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;gGz(8443768,0,1552);gGz(9669136,0,38);a=c[2427044]|0;c[9681616+(a<<3)>>2]=728712;c[9681620+(a<<3)>>2]=0;c[2427044]=a+1;c[2110940]=8443768;c[2444]=0;gGC(9718136,9669136,38)|0;a=c[3541386]|0;b=0;do{d=a+(b<<8)|0;c[8443784+(b<<2)>>2]=d;c[8444808+(b<<2)>>2]=d;b=b+1|0;}while((b|0)<16);b=(c[3541366]|0)-128|0;c[2110966]=b;d=c[3541340]|0;c[2110970]=d;c[2111098]=d;c[2111226]=d;e=d+256|0;c[2110971]=e;c[2111099]=e;c[2111227]=e;f=d+512|0;c[2110972]=f;c[2111100]=f;c[2111228]=f;g=d+768|0;c[2110973]=g;c[2111101]=g;c[2111229]=g;h=c[3541334]|0;c[2110974]=h;c[2111102]=h;c[2111230]=h;i=h+256|0;c[2110975]=i;c[2111103]=i;c[2111231]=i;j=h+512|0;c[2110976]=j;c[2111104]=j;c[2111232]=j;k=h+768|0;c[2110977]=k;c[2111105]=k;c[2111233]=k;l=32;do{m=a+((l<<8)-4096)|0;c[8443784+(l<<2)>>2]=m;c[8444808+(l<<2)>>2]=m;l=l+1|0;}while((l|0)<48);c[2110998]=b;c[2111002]=d;c[2111130]=d;c[2111258]=d;c[2111003]=e;c[2111131]=e;c[2111259]=e;c[2111004]=f;c[2111132]=f;c[2111260]=f;c[2111005]=g;c[2111133]=g;c[2111261]=g;c[2111006]=h;c[2111134]=h;c[2111262]=h;c[2111007]=i;c[2111135]=i;c[2111263]=i;c[2111008]=j;c[2111136]=j;c[2111264]=j;c[2111009]=k;c[2111137]=k;c[2111265]=k;l=64;do{m=a+((l<<8)-8192)|0;c[8443784+(l<<2)>>2]=m;c[8444808+(l<<2)>>2]=m;l=l+1|0;}while((l|0)<80);c[2111030]=b;c[2111034]=d;c[2111162]=d;c[2111290]=d;c[2111035]=e;c[2111163]=e;c[2111291]=e;c[2111036]=f;c[2111164]=f;c[2111292]=f;c[2111037]=g;c[2111165]=g;c[2111293]=g;c[2111038]=h;c[2111166]=h;c[2111294]=h;c[2111039]=i;c[2111167]=i;c[2111295]=i;c[2111040]=j;c[2111168]=j;c[2111296]=j;c[2111041]=k;c[2111169]=k;c[2111297]=k;l=96;do{m=a+((l<<8)-12288)|0;c[8443784+(l<<2)>>2]=m;c[8444808+(l<<2)>>2]=m;l=l+1|0;}while((l|0)<112);c[2111062]=b;c[2111066]=d;c[2111194]=d;c[2111322]=d;c[2111067]=e;c[2111195]=e;c[2111323]=e;c[2111068]=f;c[2111196]=f;c[2111324]=f;c[2111069]=g;c[2111197]=g;c[2111325]=g;c[2111070]=h;c[2111198]=h;c[2111326]=h;c[2111071]=i;c[2111199]=i;c[2111327]=i;c[2111072]=j;c[2111200]=j;c[2111328]=j;c[2111073]=k;c[2111201]=k;c[2111329]=k;c[2110942]=2358;c[2110943]=3354;c[2110944]=3334;c[2110945]=1262;c[2112494]=324;gGC(9669136,9718136,38)|0;c[2444]=-1;return}function a_9(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=0;while(1){if((d|0)>=1024){e=0;break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==0){g=44813;break}else{d=d+1|0}}do{if((g|0)==44813){d=gGq(16384)|0;c[f>>2]=d;if((d|0)==0){e=0;break}gGz(d|0,0,16384);e=d}}while(0);c[3541356]=e;f=c[3541328]|0;gGC(e|0,f|0,16384)|0;d=0;while(1){a[f+d|0]=a[e+(d>>>4<<11&2048|d&63463|d>>>3<<4&16|d>>>11<<3&8)|0]|0;h=d+1|0;if((h|0)<16384){d=h}else{i=0;break}}while(1){if((i|0)>=1024){j=f;break}k=9638528+(i<<2)|0;if((c[k>>2]|0)==(e|0)){g=44819;break}else{i=i+1|0}}if((g|0)==44819){gGr(e);c[k>>2]=0;j=c[3541328]|0}c[3541356]=0;k=0;while(1){e=j+(k+20480)|0;g=a[e]|0;i=j+(k+24576)|0;a[e]=a[i]|0;e=j+(k+4096)|0;a[i]=a[e]|0;a[e]=g;g=k+1|0;if((g|0)<4096){k=g}else{l=0;break}}do{k=j+(l+4096)|0;g=a[k]|0;a[k]=(g&255)>>>1<<4&16|g&-19|(g&255)>>>4<<1&2;g=j+(l+16384)|0;k=a[g]|0;a[g]=(k&255)>>>1<<4&16|k&-19|(k&255)>>>4<<1&2;k=j+(l+20480)|0;g=a[k]|0;a[k]=(g&255)>>>1<<4&16|g&-19|(g&255)>>>4<<1&2;l=l+1|0;}while((l|0)<4096);l=c[2439330]|0;g=(l|0)==0;if(!g){k=l;gGC(9706056,k|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];k=c[3528484]|0;c[2076596]=k;e=c[2417276]|0;c[3541536]=e;c[1836236]=0;gGz(l+76|0,0,2048);i=0;f=0;while(1){c[l+76+(f+512<<2)>>2]=0;c[l+76+(f+768<<2)>>2]=0;d=i+1&65535;if((d&65535)>255){break}else{i=d;f=d&65535}}c[l+4180>>2]=1850;c[l+4184>>2]=3458;c[l+4172>>2]=3586;c[l+4176>>2]=654;f=c[3541322]|0;i=f>>>0>32767?127:f-1>>8;f=(i|0)<0;do{if(!f){d=0;h=0;do{c[l+76+(h<<2)>>2]=j+(h<<8);d=d+1&65535;h=d&65535;}while((h|0)<=(i|0));if(f){break}else{m=0;n=0}do{h=j+(n<<8)|0;c[l+76+(n+512<<2)>>2]=h;c[l+76+(n+768<<2)>>2]=h;m=m+1&65535;n=m&65535;}while((n|0)<=(i|0))}}while(0);i=c[3541334]|0;c[l+844>>2]=i;n=i+256|0;c[l+848>>2]=n;m=i+512|0;c[l+852>>2]=m;j=i+768|0;c[l+856>>2]=j;f=i+1024|0;c[l+860>>2]=f;h=i+1280|0;c[l+864>>2]=h;d=i+1536|0;c[l+868>>2]=d;o=i+1792|0;c[l+872>>2]=o;c[l+1868>>2]=i;c[l+1872>>2]=n;c[l+1876>>2]=m;c[l+1880>>2]=j;c[l+1884>>2]=f;c[l+1888>>2]=h;c[l+1892>>2]=d;c[l+1896>>2]=o;c[l+2892>>2]=i;c[l+3916>>2]=i;c[l+2896>>2]=n;c[l+3920>>2]=n;c[l+2900>>2]=m;c[l+3924>>2]=m;c[l+2904>>2]=j;c[l+3928>>2]=j;c[l+2908>>2]=f;c[l+3932>>2]=f;c[l+2912>>2]=h;c[l+3936>>2]=h;c[l+2916>>2]=d;c[l+3940>>2]=d;c[l+2920>>2]=o;c[l+3944>>2]=o;o=c[3541340]|0;c[l+908>>2]=o;d=o+256|0;c[l+912>>2]=d;h=o+512|0;c[l+916>>2]=h;f=o+768|0;c[l+920>>2]=f;c[l+1932>>2]=o;c[l+1936>>2]=d;c[l+1940>>2]=h;c[l+1944>>2]=f;c[l+2956>>2]=o;c[l+3980>>2]=o;c[l+2960>>2]=d;c[l+3984>>2]=d;c[l+2964>>2]=h;c[l+3988>>2]=h;c[l+2968>>2]=f;c[l+3992>>2]=f;c[l+924>>2]=o;c[l+928>>2]=d;c[l+932>>2]=h;c[l+936>>2]=f;c[l+1948>>2]=o;c[l+1952>>2]=d;c[l+1956>>2]=h;c[l+1960>>2]=f;c[l+2972>>2]=o;c[l+3996>>2]=o;c[l+2976>>2]=d;c[l+4e3>>2]=d;c[l+2980>>2]=h;c[l+4004>>2]=h;c[l+2984>>2]=f;c[l+4008>>2]=f;f=c[3541366]|0;c[l+940>>2]=f;c[l+2988>>2]=f;c[l+4012>>2]=f;if(g){p=c[2433530]|0;c[2438118]=p;c[3528484]=k;c[2417276]=e;c[1836236]=-1;return}g=l;gGC(g|0,9706056,76)|0;p=c[2433530]|0;c[2438118]=p;c[3528484]=k;c[2417276]=e;c[1836236]=-1;return}function a$a(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a1B();a=c[2439330]|0;d=(a|0)==0;if(!d){e=a;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];e=c[3528484]|0;c[2076596]=e;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;c[a+4184>>2]=1252;gGz(a+332|0,0,256);g=64;h=64;while(1){c[a+76+(h+512<<2)>>2]=0;c[a+76+(h+768<<2)>>2]=0;i=g+1&65535;if((i&65535)>127){break}else{g=i;h=i&65535}}h=c[3541328]|0;g=192;i=192;while(1){c[a+76+(i<<2)>>2]=h+((i<<8)-32768);j=g+1&65535;if((j&65535)>255){k=192;l=192;break}else{g=j;i=j&65535}}while(1){i=h+((l<<8)-32768)|0;c[a+76+(l+512<<2)>>2]=i;c[a+76+(l+768<<2)>>2]=i;i=k+1&65535;if((i&65535)>255){break}else{k=i;l=i&65535}}if(d){m=c[2433530]|0;c[2438118]=m;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}d=a;gGC(d|0,9706056,76)|0;m=c[2433530]|0;c[2438118]=m;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}function a$b(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=c[3541328]|0;e=0;do{f=d+e|0;g=a[f]|0;h=g&255;a[f]=a[(h>>>4&8|h&7)+(600736+((e>>>6&8|e&7)<<4))|0]^g;e=e+1|0;}while((e|0)<16384);a1B();e=c[2439330]|0;g=(e|0)==0;if(!g){h=e;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];h=c[3528484]|0;c[2076596]=h;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;c[e+4184>>2]=1252;gGz(e+332|0,0,256);i=64;j=64;while(1){c[e+76+(j+512<<2)>>2]=0;c[e+76+(j+768<<2)>>2]=0;k=i+1&65535;if((k&65535)>127){l=192;m=192;break}else{i=k;j=k&65535}}while(1){c[e+76+(m<<2)>>2]=d+((m<<8)-32768);j=l+1&65535;if((j&65535)>255){n=192;o=192;break}else{l=j;m=j&65535}}while(1){m=d+((o<<8)-32768)|0;c[e+76+(o+512<<2)>>2]=m;c[e+76+(o+768<<2)>>2]=m;m=n+1&65535;if((m&65535)>255){break}else{n=m;o=m&65535}}if(g){p=c[2433530]|0;c[2438118]=p;c[3528484]=h;c[2417276]=f;c[1836236]=-1;return}g=e;gGC(g|0,9706056,76)|0;p=c[2433530]|0;c[2438118]=p;c[3528484]=h;c[2417276]=f;c[1836236]=-1;return}function a$c(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;a1B();a=c[2439330]|0;d=(a|0)==0;if(!d){e=a;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];e=c[3528484]|0;c[2076596]=e;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;c[a+4180>>2]=3594;c[a+4184>>2]=86;if(!d){d=a;gGC(d|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=e;c[2417276]=f;c[1836236]=-1;a0P();f=c[2439331]|0;e=(f|0)==0;if(!e){d=f;gGC(9706056,d|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];d=c[3528485]|0;c[2076596]=d;a=c[2417277]|0;c[3541536]=a;c[1836236]=1;c[f+4172>>2]=1948;c[f+4176>>2]=1454;g=c[3541332]|0;c[f+588>>2]=g;h=g+256|0;c[f+592>>2]=h;i=g+512|0;c[f+596>>2]=i;j=g+768|0;c[f+600>>2]=j;c[f+1612>>2]=g;c[f+1616>>2]=h;c[f+1620>>2]=i;c[f+1624>>2]=j;c[f+2636>>2]=g;c[f+3660>>2]=g;c[f+2640>>2]=h;c[f+3664>>2]=h;c[f+2644>>2]=i;c[f+3668>>2]=i;c[f+2648>>2]=j;c[f+3672>>2]=j;if(e){k=c[2433530]|0;c[2438119]=k;c[3528485]=d;c[2417277]=a;c[1836236]=-1;return}e=f;gGC(e|0,9706056,76)|0;k=c[2433530]|0;c[2438119]=k;c[3528485]=d;c[2417277]=a;c[1836236]=-1;return}function a$d(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;a1B();d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];f=c[3528484]|0;c[2076596]=f;g=c[2417276]|0;c[3541536]=g;c[1836236]=0;c[d+4180>>2]=1932;c[d+4184>>2]=1724;if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=f;c[2417276]=g;c[1836236]=-1;g=c[3541322]|0;if((g|0)==0){return}f=c[3541328]|0;e=0;do{d=e&1;h=e>>>1;i=h&1;j=e>>>2;k=j&1;l=e>>>3&1;m=e>>>4&1;n=e>>>5&1;o=e>>>6;p=o&1;q=e>>>7;r=(k|0)==(l&o|0)?85:84;o=(m|0)==(n&q|0)?r:r|2;r=(d|0)==((l^1)&q|0)?o:o&83;o=(l|0)==((d^1)&j|0)?r:r|8;r=(n|0)==((m^1)&h|0)?o:o^16;o=(p|0)==((n|k)^1|0)?r:r^32;r=(i|0)==((m|p)^1|0)?o:o^64;o=f+e|0;p=((q&1|0)==((i^1)&e|0)?r:r^-128)^a[o];a[o]=(p&255)>>>6<<7|(p&255)>>>7|p<<1&2|(p&255)>>>1<<6&64|(p&255)>>>2<<5&32|(p&255)>>>5<<4&16|(p&255)>>>4<<3&8|(p&255)>>>3<<2&4;e=e+1|0;}while(e>>>0<g>>>0);return}function a$e(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a1B();d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];f=c[3528484]|0;c[2076596]=f;g=c[2417276]|0;c[3541536]=g;c[1836236]=0;c[d+4180>>2]=1932;c[d+4184>>2]=1724;if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=f;c[2417276]=g;c[1836236]=-1;g=c[3541322]|0;if((g|0)==0){return}f=c[3541328]|0;e=0;do{d=e&1;h=e>>>1&1;i=e>>>2&1;j=e>>>3&1;k=e>>>4&1;l=e>>>5&1;m=e>>>6&1;n=(d|0)==(h|0)?-1:-2;o=(j|0)==(m|0)?n:n&-3;n=(k|0)==(l|0)?o:o&-5;o=(d|0)==(i|0)?n:n&-9;n=(i|0)==(j|0)?o:o^16;o=(h|0)==(l|0)?n:n^32;n=(d|0)==(e>>>7&1|0)?o:o^64;o=f+e|0;a[o]=((k|0)==(m|0)?n:n^-128)^a[o];e=e+1|0;}while(e>>>0<g>>>0);return}function a$f(){var a=0,d=0,e=0,f=0;a$h();a=c[2439330]|0;d=(a|0)==0;if(!d){e=a;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];e=c[3528484]|0;c[2076596]=e;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;c[a+4184>>2]=392;if(!d){d=a;gGC(d|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}function a$g(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=c[2113222]|0;if((c[2426964]|0)==(d|0)){e=b[4887256]|0}else{f=b[4887256]|0;if((a[14165776]|0)==0){g=f}else{h=f-1&65535;b[4887256]=h;g=h}if((a[14165777]|0)==0){i=g}else{h=g+1&65535;b[4887256]=h;i=h}do{if(i<<16>>16>252){b[4887256]=0;j=0}else{if(i<<16>>16>=0){j=i;break}b[4887256]=252;j=252}}while(0);c[2426964]=d;e=j}return(~a[14165809]-(a[14165873]|0)&255)-(a[598008+(e<<16>>16>>2)|0]|0)&255|0}function a$h(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=c[2439330]|0;d=(a|0)==0;if(!d){e=a;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];e=c[3528484]|0;c[2076596]=e;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;gGz(a+76|0,0,2048);g=0;h=0;while(1){c[a+76+(h+512<<2)>>2]=0;c[a+76+(h+768<<2)>>2]=0;i=g+1&65535;if((i&65535)>255){break}else{g=i;h=i&65535}}c[a+4180>>2]=2992;c[a+4184>>2]=902;h=c[3541322]|0;g=c[3541328]|0;i=h>>>0>32768?127:h-1>>8;h=(i|0)<0;do{if(!h){j=0;k=0;do{c[a+76+(k<<2)>>2]=g+(k<<8);j=j+1&65535;k=j&65535;}while((k|0)<=(i|0));if(h){break}else{l=0;m=0}do{k=g+(m<<8)|0;c[a+76+(m+512<<2)>>2]=k;c[a+76+(m+768<<2)>>2]=k;l=l+1&65535;m=l&65535;}while((m|0)<=(i|0))}}while(0);i=c[3541334]|0;c[a+588>>2]=i;m=i+256|0;c[a+592>>2]=m;l=i+512|0;c[a+596>>2]=l;g=i+768|0;c[a+600>>2]=g;h=i+1024|0;c[a+604>>2]=h;k=i+1280|0;c[a+608>>2]=k;j=i+1536|0;c[a+612>>2]=j;n=i+1792|0;c[a+616>>2]=n;c[a+1612>>2]=i;c[a+1616>>2]=m;c[a+1620>>2]=l;c[a+1624>>2]=g;c[a+1628>>2]=h;c[a+1632>>2]=k;c[a+1636>>2]=j;c[a+1640>>2]=n;c[a+2636>>2]=i;c[a+3660>>2]=i;c[a+2640>>2]=m;c[a+3664>>2]=m;c[a+2644>>2]=l;c[a+3668>>2]=l;c[a+2648>>2]=g;c[a+3672>>2]=g;c[a+2652>>2]=h;c[a+3676>>2]=h;c[a+2656>>2]=k;c[a+3680>>2]=k;c[a+2660>>2]=j;c[a+3684>>2]=j;c[a+2664>>2]=n;c[a+3688>>2]=n;n=c[3541366]|0;c[a+620>>2]=n;c[a+2668>>2]=n;c[a+3692>>2]=n;n=c[3541340]|0;c[a+652>>2]=n;j=n+256|0;c[a+656>>2]=j;k=n+512|0;c[a+660>>2]=k;h=n+768|0;c[a+664>>2]=h;c[a+1676>>2]=n;c[a+1680>>2]=j;c[a+1684>>2]=k;c[a+1688>>2]=h;c[a+2700>>2]=n;c[a+3724>>2]=n;c[a+2704>>2]=j;c[a+3728>>2]=j;c[a+2708>>2]=k;c[a+3732>>2]=k;c[a+2712>>2]=h;c[a+3736>>2]=h;if(d){o=c[2433530]|0;c[2438118]=o;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}d=a;gGC(d|0,9706056,76)|0;o=c[2433530]|0;c[2438118]=o;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}function a$i(){var a=0,d=0,e=0,f=0;a$h();a=c[2439330]|0;d=(a|0)==0;if(!d){e=a;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];e=c[3528484]|0;c[2076596]=e;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;c[a+4184>>2]=1910;if(!d){d=a;gGC(d|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}function a$j(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=(c[3541488]|0)>>>8;d=(c[3541486]|0)>>>8;e=d&255;f=~a[14165808]-(a[14165872]|0)&255;g=b&255;if(g>>>0>251){h=44929}else{if((g|0)!=0&g>>>0<5){h=44929}else{i=b&255}}if((h|0)==44929){i=0}b=(i&255)>247?-3:i;i=b<<24>>24!=0&(b&255)<8?2:b;b=d&255;if(b>>>0>251){h=44932}else{if((b|0)!=0&b>>>0<5){h=44932}else{j=e}}if((h|0)==44932){j=0}h=(j&255)>247?-3:j;j=(a[14164632]|0)!=0?i:h<<24>>24!=0&(h&255)<8?2:h;return j&15|f&-32|(j&255)>>>3&16|0}function a$k(b){b=b|0;a[14164632]=b&16;return}function a$l(){var b=0,d=0,e=0,f=0;a1B();b=c[3541328]|0;d=0;do{e=d&640;if((e|0)==0){f=b+d|0;a[f]=a[f]^-110}else if((e|0)==512){f=b+d|0;a[f]=a[f]^18}else if((e|0)==640){f=b+d|0;a[f]=a[f]^16}else if((e|0)==128){e=b+d|0;a[e]=a[e]^-126}d=d+1|0;}while(d>>>0<4096);return}function a$m(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;a=c[2439330]|0;d=(a|0)==0;if(!d){e=a;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];e=c[3528484]|0;c[2076596]=e;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;g=a+76|0;gGz(g|0,0,2048);h=0;i=0;while(1){c[a+76+(i+512<<2)>>2]=0;c[a+76+(i+768<<2)>>2]=0;j=h+1&65535;if((j&65535)>255){break}else{h=j;i=j&65535}}c[a+4180>>2]=3198;c[a+4184>>2]=3174;i=c[3541328]|0;c[g>>2]=i;g=i+256|0;c[a+80>>2]=g;h=i+512|0;c[a+84>>2]=h;j=i+768|0;c[a+88>>2]=j;c[a+2124>>2]=i;c[a+3148>>2]=i;c[a+2128>>2]=g;c[a+3152>>2]=g;c[a+2132>>2]=h;c[a+3156>>2]=h;c[a+2136>>2]=j;c[a+3160>>2]=j;j=c[3541334]|0;c[a+92>>2]=j;h=j+256|0;c[a+96>>2]=h;g=j+512|0;c[a+100>>2]=g;k=j+768|0;c[a+104>>2]=k;l=j+1024|0;c[a+108>>2]=l;m=j+1280|0;c[a+112>>2]=m;n=j+1536|0;c[a+116>>2]=n;o=j+1792|0;c[a+120>>2]=o;c[a+1116>>2]=j;c[a+1120>>2]=h;c[a+1124>>2]=g;c[a+1128>>2]=k;c[a+1132>>2]=l;c[a+1136>>2]=m;c[a+1140>>2]=n;c[a+1144>>2]=o;c[a+2140>>2]=j;c[a+3164>>2]=j;c[a+2144>>2]=h;c[a+3168>>2]=h;c[a+2148>>2]=g;c[a+3172>>2]=g;c[a+2152>>2]=k;c[a+3176>>2]=k;c[a+2156>>2]=l;c[a+3180>>2]=l;c[a+2160>>2]=m;c[a+3184>>2]=m;c[a+2164>>2]=n;c[a+3188>>2]=n;c[a+2168>>2]=o;c[a+3192>>2]=o;o=c[3541340]|0;c[a+124>>2]=o;n=o+256|0;c[a+128>>2]=n;m=o+512|0;c[a+132>>2]=m;l=o+768|0;c[a+136>>2]=l;c[a+1148>>2]=o;c[a+1152>>2]=n;c[a+1156>>2]=m;c[a+1160>>2]=l;c[a+2172>>2]=o;c[a+3196>>2]=o;c[a+2176>>2]=n;c[a+3200>>2]=n;c[a+2180>>2]=m;c[a+3204>>2]=m;c[a+2184>>2]=l;c[a+3208>>2]=l;l=c[3541366]|0;c[a+148>>2]=l;c[a+2196>>2]=l;c[a+3220>>2]=l;l=i+1024|0;c[a+356>>2]=l;m=i+1280|0;c[a+360>>2]=m;n=i+1536|0;c[a+364>>2]=n;o=i+1792|0;c[a+368>>2]=o;k=i+2048|0;c[a+372>>2]=k;g=i+2304|0;c[a+376>>2]=g;h=i+2560|0;c[a+380>>2]=h;j=i+2816|0;c[a+384>>2]=j;p=i+3072|0;c[a+388>>2]=p;q=i+3328|0;c[a+392>>2]=q;c[a+2404>>2]=l;c[a+3428>>2]=l;c[a+2408>>2]=m;c[a+3432>>2]=m;c[a+2412>>2]=n;c[a+3436>>2]=n;c[a+2416>>2]=o;c[a+3440>>2]=o;c[a+2420>>2]=k;c[a+3444>>2]=k;c[a+2424>>2]=g;c[a+3448>>2]=g;c[a+2428>>2]=h;c[a+3452>>2]=h;c[a+2432>>2]=j;c[a+3456>>2]=j;c[a+2436>>2]=p;c[a+3460>>2]=p;c[a+2440>>2]=q;c[a+3464>>2]=q;q=100;p=100;while(1){c[a+76+(p<<2)>>2]=i+((p<<8)-22016);j=q+1&65535;if((j&65535)>122){r=100;s=100;break}else{q=j;p=j&65535}}while(1){p=i+((s<<8)-22016)|0;c[a+76+(s+512<<2)>>2]=p;c[a+76+(s+768<<2)>>2]=p;p=r+1&65535;if((p&65535)>122){t=131;u=131;break}else{r=p;s=p&65535}}while(1){c[a+76+(u<<2)>>2]=i+((u<<8)-24064);s=t+1&65535;if((s&65535)>152){v=131;w=131;break}else{t=s;u=s&65535}}while(1){u=i+((w<<8)-24064)|0;c[a+76+(w+512<<2)>>2]=u;c[a+76+(w+768<<2)>>2]=u;u=v+1&65535;if((u&65535)>152){break}else{v=u;w=u&65535}}w=i+15104|0;c[a+728>>2]=w;v=i+15360|0;c[a+732>>2]=v;u=i+15616|0;c[a+736>>2]=u;t=i+15872|0;c[a+740>>2]=t;s=i+16128|0;c[a+744>>2]=s;c[a+2776>>2]=w;c[a+3800>>2]=w;c[a+2780>>2]=v;c[a+3804>>2]=v;c[a+2784>>2]=u;c[a+3808>>2]=u;c[a+2788>>2]=t;c[a+3812>>2]=t;c[a+2792>>2]=s;c[a+3816>>2]=s;if(d){x=c[2433530]|0;c[2438118]=x;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}d=a;gGC(d|0,9706056,76)|0;x=c[2433530]|0;c[2438118]=x;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}function a$n(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;a=c[2439330]|0;d=(a|0)==0;if(!d){e=a;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];e=c[3528484]|0;c[2076596]=e;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;g=a+76|0;gGz(g|0,0,2048);h=0;i=0;while(1){c[a+76+(i+512<<2)>>2]=0;c[a+76+(i+768<<2)>>2]=0;j=h+1&65535;if((j&65535)>255){break}else{h=j;i=j&65535}}c[a+4180>>2]=2272;c[a+4184>>2]=418;i=c[3541328]|0;c[g>>2]=i;g=i+256|0;c[a+80>>2]=g;h=i+512|0;c[a+84>>2]=h;j=i+768|0;c[a+88>>2]=j;c[a+2124>>2]=i;c[a+3148>>2]=i;c[a+2128>>2]=g;c[a+3152>>2]=g;c[a+2132>>2]=h;c[a+3156>>2]=h;c[a+2136>>2]=j;c[a+3160>>2]=j;j=c[3541334]|0;c[a+92>>2]=j;h=j+256|0;c[a+96>>2]=h;g=j+512|0;c[a+100>>2]=g;k=j+768|0;c[a+104>>2]=k;l=j+1024|0;c[a+108>>2]=l;m=j+1280|0;c[a+112>>2]=m;n=j+1536|0;c[a+116>>2]=n;o=j+1792|0;c[a+120>>2]=o;c[a+1116>>2]=j;c[a+1120>>2]=h;c[a+1124>>2]=g;c[a+1128>>2]=k;c[a+1132>>2]=l;c[a+1136>>2]=m;c[a+1140>>2]=n;c[a+1144>>2]=o;c[a+2140>>2]=j;c[a+3164>>2]=j;c[a+2144>>2]=h;c[a+3168>>2]=h;c[a+2148>>2]=g;c[a+3172>>2]=g;c[a+2152>>2]=k;c[a+3176>>2]=k;c[a+2156>>2]=l;c[a+3180>>2]=l;c[a+2160>>2]=m;c[a+3184>>2]=m;c[a+2164>>2]=n;c[a+3188>>2]=n;c[a+2168>>2]=o;c[a+3192>>2]=o;o=c[3541340]|0;c[a+124>>2]=o;n=o+256|0;c[a+128>>2]=n;m=o+512|0;c[a+132>>2]=m;l=o+768|0;c[a+136>>2]=l;c[a+1148>>2]=o;c[a+1152>>2]=n;c[a+1156>>2]=m;c[a+1160>>2]=l;c[a+2172>>2]=o;c[a+3196>>2]=o;c[a+2176>>2]=n;c[a+3200>>2]=n;c[a+2180>>2]=m;c[a+3204>>2]=m;c[a+2184>>2]=l;c[a+3208>>2]=l;k=c[3541366]|0;c[a+204>>2]=k;c[a+2252>>2]=k;c[a+3276>>2]=k;k=i+1024|0;c[a+356>>2]=k;g=i+1280|0;c[a+360>>2]=g;h=i+1536|0;c[a+364>>2]=h;j=i+1792|0;c[a+368>>2]=j;p=i+2048|0;c[a+372>>2]=p;q=i+2304|0;c[a+376>>2]=q;r=i+2560|0;c[a+380>>2]=r;s=i+2816|0;c[a+384>>2]=s;t=i+3072|0;c[a+388>>2]=t;u=i+3328|0;c[a+392>>2]=u;c[a+2404>>2]=k;c[a+3428>>2]=k;c[a+2408>>2]=g;c[a+3432>>2]=g;c[a+2412>>2]=h;c[a+3436>>2]=h;c[a+2416>>2]=j;c[a+3440>>2]=j;c[a+2420>>2]=p;c[a+3444>>2]=p;c[a+2424>>2]=q;c[a+3448>>2]=q;c[a+2428>>2]=r;c[a+3452>>2]=r;c[a+2432>>2]=s;c[a+3456>>2]=s;c[a+2436>>2]=t;c[a+3460>>2]=t;c[a+2440>>2]=u;c[a+3464>>2]=u;u=100;t=100;while(1){c[a+76+(t<<2)>>2]=i+((t<<8)-22016);s=u+1&65535;if((s&65535)>122){v=100;w=100;break}else{u=s;t=s&65535}}while(1){t=i+((w<<8)-22016)|0;c[a+76+(w+512<<2)>>2]=t;c[a+76+(w+768<<2)>>2]=t;t=v+1&65535;if((t&65535)>122){break}else{v=t;w=t&65535}}c[a+572>>2]=o;c[a+576>>2]=n;c[a+580>>2]=m;c[a+584>>2]=l;c[a+1596>>2]=o;c[a+1600>>2]=n;c[a+1604>>2]=m;c[a+1608>>2]=l;c[a+2620>>2]=o;c[a+3644>>2]=o;c[a+2624>>2]=n;c[a+3648>>2]=n;c[a+2628>>2]=m;c[a+3652>>2]=m;c[a+2632>>2]=l;c[a+3656>>2]=l;l=131;m=131;while(1){c[a+76+(m<<2)>>2]=i+((m<<8)-24064);n=l+1&65535;if((n&65535)>152){x=131;y=131;break}else{l=n;m=n&65535}}while(1){m=i+((y<<8)-24064)|0;c[a+76+(y+512<<2)>>2]=m;c[a+76+(y+768<<2)>>2]=m;m=x+1&65535;if((m&65535)>152){break}else{x=m;y=m&65535}}y=i+15104|0;c[a+728>>2]=y;x=i+15360|0;c[a+732>>2]=x;m=i+15616|0;c[a+736>>2]=m;l=i+15872|0;c[a+740>>2]=l;n=i+16128|0;c[a+744>>2]=n;c[a+2776>>2]=y;c[a+3800>>2]=y;c[a+2780>>2]=x;c[a+3804>>2]=x;c[a+2784>>2]=m;c[a+3808>>2]=m;c[a+2788>>2]=l;c[a+3812>>2]=l;c[a+2792>>2]=n;c[a+3816>>2]=n;if(d){z=c[2433530]|0;c[2438118]=z;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}d=a;gGC(d|0,9706056,76)|0;z=c[2433530]|0;c[2438118]=z;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}function a$o(){return a[14165496]|0}function a$p(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;a1r();d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];f=c[3528484]|0;c[2076596]=f;g=c[2417276]|0;c[3541536]=g;c[1836236]=0;c[d+4184>>2]=2986;h=c[3541328]|0;c[d+524>>2]=h+16384;c[d+528>>2]=h+16640;c[d+532>>2]=h+16896;c[d+536>>2]=h+17152;c[d+540>>2]=h+17408;c[d+544>>2]=h+17664;c[d+548>>2]=h+17920;c[d+552>>2]=h+18176;c[d+556>>2]=h+18432;c[d+560>>2]=h+18688;c[d+564>>2]=h+18944;c[d+568>>2]=h+19200;c[d+572>>2]=h+19456;c[d+576>>2]=h+19712;c[d+580>>2]=h+19968;c[d+584>>2]=h+20224;i=112;j=112;while(1){k=h+((j<<8)-12288)|0;c[d+76+(j+512<<2)>>2]=k;c[d+76+(j+768<<2)>>2]=k;k=i+1&65535;if((k&65535)>127){l=192;m=192;break}else{i=k;j=k&65535}}while(1){c[d+76+(m<<2)>>2]=h+((m<<8)-28672);j=l+1&65535;if((j&65535)>239){n=192;o=192;break}else{l=j;m=j&65535}}while(1){m=h+((o<<8)-28672)|0;c[d+76+(o+512<<2)>>2]=m;c[d+76+(o+768<<2)>>2]=m;m=n+1&65535;if((m&65535)>239){break}else{n=m;o=m&65535}}if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=f;c[2417276]=g;c[1836236]=-1;g=c[3541322]|0;f=0;while(1){if((f|0)>=1024){p=0;break}q=9638528+(f<<2)|0;if((c[q>>2]|0)==0){r=44984;break}else{f=f+1|0}}do{if((r|0)==44984){f=gGq(g)|0;c[q>>2]=f;if((f|0)==0){p=0;break}gGz(f|0,0,g|0);p=f}}while(0);c[3541356]=p;g=c[3541328]|0;q=c[3541322]|0;gGC(p|0,g|0,q)|0;gGC(g|0,p|0,4096)|0;q=g+28672|0;f=p+4096|0;gGC(q|0,f|0,4096)|0;f=g+4096|0;g=p+8192|0;gGC(f|0,g|0,24576)|0;g=0;while(1){if((g|0)>=1024){break}s=9638528+(g<<2)|0;if((c[s>>2]|0)==(p|0)){r=44989;break}else{g=g+1|0}}if((r|0)==44989){gGr(p);c[s>>2]=0}c[3541356]=0;s=c[2439332]|0;p=(s|0)==0;if(!p){r=s;gGC(9706056,r|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438120];r=c[3528486]|0;c[2076596]=r;g=c[2417278]|0;c[3541536]=g;c[1836236]=2;c[s+4180>>2]=1920;c[s+4184>>2]=2706;c[s+4172>>2]=1356;c[s+4176>>2]=1678;f=c[3541314]|0;q=(c[3541310]|0)-1>>8;e=(q|0)<0;do{if(!e){d=0;o=0;do{c[s+76+(o<<2)>>2]=f+(o<<8);d=d+1&65535;o=d&65535;}while((o|0)<=(q|0));if(e){break}else{t=0;u=0}do{o=f+(u<<8)|0;c[s+76+(u+512<<2)>>2]=o;c[s+76+(u+768<<2)>>2]=o;t=t+1&65535;u=t&65535;}while((u|0)<=(q|0))}}while(0);q=c[3541330]|0;c[s+588>>2]=q;u=q+256|0;c[s+592>>2]=u;t=q+512|0;c[s+596>>2]=t;f=q+768|0;c[s+600>>2]=f;c[s+1612>>2]=q;c[s+1616>>2]=u;c[s+1620>>2]=t;c[s+1624>>2]=f;c[s+2636>>2]=q;c[s+3660>>2]=q;c[s+2640>>2]=u;c[s+3664>>2]=u;c[s+2644>>2]=t;c[s+3668>>2]=t;c[s+2648>>2]=f;c[s+3672>>2]=f;if(p){v=c[2433530]|0;c[2438120]=v;c[3528486]=r;c[2417278]=g;c[1836236]=-1;a[9616]=1;return}p=s;gGC(p|0,9706056,76)|0;v=c[2433530]|0;c[2438120]=v;c[3528486]=r;c[2417278]=g;c[1836236]=-1;a[9616]=1;return}function a$q(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=c[3541322]|0;if((d|0)!=0){e=c[3541328]|0;f=0;do{g=e+f|0;h=a[g]^53;a[g]=(h&255)>>>6<<7|h&33|(h&255)>>>7<<3|(h&255)>>>2<<6&64|(h&255)>>>1<<4&16|(h&255)>>>3<<2&4|(h&255)>>>4<<1&2;f=f+1|0;}while(f>>>0<d>>>0)}a1r();d=c[2439330]|0;f=(d|0)==0;if(!f){e=d;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];e=c[3528484]|0;c[2076596]=e;h=c[2417276]|0;c[3541536]=h;c[1836236]=0;c[d+4180>>2]=2872;c[d+4184>>2]=2076;g=c[3541328]|0;i=160;j=160;while(1){c[d+76+(j<<2)>>2]=g+((j<<8)-24576);k=i+1&65535;if((k&65535)>223){l=160;m=160;break}else{i=k;j=k&65535}}while(1){j=g+((m<<8)-24576)|0;c[d+76+(m+512<<2)>>2]=j;c[d+76+(m+768<<2)>>2]=j;j=l+1&65535;if((j&65535)>223){break}else{l=j;m=j&65535}}m=c[3541334]|0;l=m+2048|0;c[d+1004>>2]=l;g=m+2304|0;c[d+1008>>2]=g;j=m+2560|0;c[d+1012>>2]=j;i=m+2816|0;c[d+1016>>2]=i;c[d+2028>>2]=l;c[d+2032>>2]=g;c[d+2036>>2]=j;c[d+2040>>2]=i;c[d+3052>>2]=l;c[d+4076>>2]=l;c[d+3056>>2]=g;c[d+4080>>2]=g;c[d+3060>>2]=j;c[d+4084>>2]=j;c[d+3064>>2]=i;c[d+4088>>2]=i;if(f){n=c[2433530]|0;c[2438118]=n;c[3528484]=e;c[2417276]=h;c[1836236]=-1;return}f=d;gGC(f|0,9706056,76)|0;n=c[2433530]|0;c[2438118]=n;c[3528484]=e;c[2417276]=h;c[1836236]=-1;return}function a$r(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;a1c();a=c[2439330]|0;d=(a|0)==0;if(!d){e=a;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];e=c[3528484]|0;c[2076596]=e;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;c[a+4180>>2]=2554;c[a+4184>>2]=590;g=c[3541334]|0;c[a+332>>2]=g;h=g+256|0;c[a+336>>2]=h;i=g+512|0;c[a+340>>2]=i;j=g+768|0;c[a+344>>2]=j;k=g+1024|0;c[a+348>>2]=k;l=g+1280|0;c[a+352>>2]=l;m=g+1536|0;c[a+356>>2]=m;n=g+1792|0;c[a+360>>2]=n;c[a+1356>>2]=g;c[a+1360>>2]=h;c[a+1364>>2]=i;c[a+1368>>2]=j;c[a+1372>>2]=k;c[a+1376>>2]=l;c[a+1380>>2]=m;c[a+1384>>2]=n;c[a+2380>>2]=g;c[a+3404>>2]=g;c[a+2384>>2]=h;c[a+3408>>2]=h;c[a+2388>>2]=i;c[a+3412>>2]=i;c[a+2392>>2]=j;c[a+3416>>2]=j;c[a+2396>>2]=k;c[a+3420>>2]=k;c[a+2400>>2]=l;c[a+3424>>2]=l;c[a+2404>>2]=m;c[a+3428>>2]=m;c[a+2408>>2]=n;c[a+3432>>2]=n;n=c[3541328]|0;m=80;l=80;while(1){c[a+76+(l<<2)>>2]=n+((l<<8)-4096);k=m+1&65535;if((k&65535)>103){o=80;p=80;break}else{m=k;l=k&65535}}while(1){l=n+((p<<8)-4096)|0;c[a+76+(p+512<<2)>>2]=l;c[a+76+(p+768<<2)>>2]=l;l=o+1&65535;if((l&65535)>103){break}else{o=l;p=l&65535}}p=c[3541340]|0;c[a+668>>2]=p;o=p+256|0;c[a+672>>2]=o;n=p+512|0;c[a+676>>2]=n;l=p+768|0;c[a+680>>2]=l;c[a+1692>>2]=p;c[a+1696>>2]=o;c[a+1700>>2]=n;c[a+1704>>2]=l;c[a+2716>>2]=p;c[a+3740>>2]=p;c[a+2720>>2]=o;c[a+3744>>2]=o;c[a+2724>>2]=n;c[a+3748>>2]=n;c[a+2728>>2]=l;c[a+3752>>2]=l;if(d){q=c[2433530]|0;c[2438118]=q;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}d=a;gGC(d|0,9706056,76)|0;q=c[2433530]|0;c[2438118]=q;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}function a$s(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0;a=0;while(1){if((a|0)>=1024){d=0;break}e=9638528+(a<<2)|0;if((c[e>>2]|0)==0){f=45027;break}else{a=a+1|0}}do{if((f|0)==45027){a=gGq(4096)|0;c[e>>2]=a;if((a|0)==0){d=0;break}gGz(a|0,0,4096);d=a}}while(0);c[3541356]=d;e=c[3541328]|0;a=e+16384|0;gGC(d|0,a|0,4096)|0;g=e+18432|0;gGC(g|0,a|0,2048)|0;g=d+2048|0;gGC(a|0,g|0,2048)|0;g=0;while(1){if((g|0)>=1024){break}h=9638528+(g<<2)|0;if((c[h>>2]|0)==(d|0)){f=45032;break}else{g=g+1|0}}if((f|0)==45032){gGr(d);c[h>>2]=0}c[3541356]=0;a1r();h=c[2439330]|0;if((h|0)!=0){d=h;gGC(9706056,d|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];d=c[3528484]|0;c[2076596]=d;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;g=c[3541328]|0;c[h+428>>2]=g+16384;c[h+432>>2]=g+16640;c[h+436>>2]=g+16896;c[h+440>>2]=g+17152;c[h+444>>2]=g+17408;c[h+448>>2]=g+17664;c[h+452>>2]=g+17920;c[h+456>>2]=g+18176;c[h+460>>2]=g+18432;c[h+464>>2]=g+18688;c[h+468>>2]=g+18944;c[h+472>>2]=g+19200;c[h+476>>2]=g+19456;c[h+480>>2]=g+19712;c[h+484>>2]=g+19968;c[h+488>>2]=g+20224;a=88;e=88;while(1){i=g+((e<<8)-6144)|0;c[h+76+(e+512<<2)>>2]=i;c[h+76+(e+768<<2)>>2]=i;i=a+1&65535;if((i&65535)>103){break}else{a=i;e=i&65535}}e=h;gGC(e|0,9706056,76)|0;c[2438118]=c[2433530];c[3528484]=d;c[2417276]=f;c[1836236]=-1;return}function a$t(){var a=0,c=0,d=0,e=0,f=0;a=b[7065212]&-12759;if(a<<16>>16==0){c=0;return c|0}else{d=a;e=0}while(1){a=(d&1)+e&255;f=(d&65535)>>>1;if(f<<16>>16==0){c=a;break}else{d=f;e=a}}return c|0}function a$u(a){a=a|0;var c=0,d=0,e=0;c=a&255;if((c&32|0)==0){b[7065212]=0}if((c&16|0)!=0){return}c=b[7065212]|0;a=c<<1;d=c&-12759;if(d<<16>>16==0){e=0}else{c=d;d=0;do{d=(c&1)+d&255;c=(c&65535)>>>1;}while(c<<16>>16!=0);e=d&1}b[7065212]=(e|a)^1;return}function a$v(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0;a=0;while(1){if((a|0)>=1024){d=0;break}e=9638528+(a<<2)|0;if((c[e>>2]|0)==0){f=45056;break}else{a=a+1|0}}do{if((f|0)==45056){a=gGq(4096)|0;c[e>>2]=a;if((a|0)==0){d=0;break}gGz(a|0,0,4096);d=a}}while(0);c[3541356]=d;e=c[3541328]|0;a=e+16384|0;gGC(d|0,a|0,4096)|0;g=e+18432|0;gGC(g|0,a|0,2048)|0;g=d+2048|0;gGC(a|0,g|0,2048)|0;g=0;while(1){if((g|0)>=1024){break}h=9638528+(g<<2)|0;if((c[h>>2]|0)==(d|0)){f=45061;break}else{g=g+1|0}}if((f|0)==45061){gGr(d);c[h>>2]=0}c[3541356]=0;a1r();h=c[2439330]|0;if((h|0)!=0){d=h;gGC(9706056,d|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];d=c[3528484]|0;c[2076596]=d;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;c[h+4180>>2]=272;c[h+4172>>2]=1214;c[h+4176>>2]=682;g=c[3541328]|0;c[h+428>>2]=g+16384;c[h+432>>2]=g+16640;c[h+436>>2]=g+16896;c[h+440>>2]=g+17152;c[h+444>>2]=g+17408;c[h+448>>2]=g+17664;c[h+452>>2]=g+17920;c[h+456>>2]=g+18176;c[h+460>>2]=g+18432;c[h+464>>2]=g+18688;c[h+468>>2]=g+18944;c[h+472>>2]=g+19200;c[h+476>>2]=g+19456;c[h+480>>2]=g+19712;c[h+484>>2]=g+19968;c[h+488>>2]=g+20224;a=88;e=88;while(1){i=g+((e<<8)-6144)|0;c[h+76+(e+512<<2)>>2]=i;c[h+76+(e+768<<2)>>2]=i;i=a+1&65535;if((i&65535)>103){break}else{a=i;e=i&65535}}e=h;gGC(e|0,9706056,76)|0;c[2438118]=c[2433530];c[3528484]=d;c[2417276]=f;c[1836236]=-1;return}function a$w(){var a=0,d=0,e=0,f=0;a1r();a=c[2439330]|0;d=(a|0)==0;if(!d){e=a;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];e=c[3528484]|0;c[2076596]=e;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;c[a+4172>>2]=1214;c[a+4176>>2]=682;if(!d){d=a;gGC(d|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}function a$x(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;a=c[2439330]|0;d=(a|0)==0;if(!d){e=a;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];e=c[3528484]|0;c[2076596]=e;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;gGz(a+76|0,0,2048);g=0;h=0;while(1){c[a+76+(h+512<<2)>>2]=0;c[a+76+(h+768<<2)>>2]=0;i=g+1&65535;if((i&65535)>255){break}else{g=i;h=i&65535}}c[a+4180>>2]=962;c[a+4184>>2]=764;h=c[3541322]|0;g=c[3541328]|0;i=h>>>0>16383?63:h-1>>8;h=(i|0)<0;do{if(!h){j=0;k=0;do{c[a+76+(k<<2)>>2]=g+(k<<8);j=j+1&65535;k=j&65535;}while((k|0)<=(i|0));if(h){break}else{l=0;m=0}do{k=g+(m<<8)|0;c[a+76+(m+512<<2)>>2]=k;c[a+76+(m+768<<2)>>2]=k;l=l+1&65535;m=l&65535;}while((m|0)<=(i|0))}}while(0);i=c[3541340]|0;c[a+332>>2]=i;m=i+256|0;c[a+336>>2]=m;l=i+512|0;c[a+340>>2]=l;h=i+768|0;c[a+344>>2]=h;c[a+1356>>2]=i;c[a+1360>>2]=m;c[a+1364>>2]=l;c[a+1368>>2]=h;c[a+2380>>2]=i;c[a+3404>>2]=i;c[a+2384>>2]=m;c[a+3408>>2]=m;c[a+2388>>2]=l;c[a+3412>>2]=l;c[a+2392>>2]=h;c[a+3416>>2]=h;k=c[3541334]|0;c[a+348>>2]=k;j=k+256|0;c[a+352>>2]=j;n=k+512|0;c[a+356>>2]=n;o=k+768|0;c[a+360>>2]=o;c[a+1372>>2]=k;c[a+1376>>2]=j;c[a+1380>>2]=n;c[a+1384>>2]=o;c[a+2396>>2]=k;c[a+3420>>2]=k;c[a+2400>>2]=j;c[a+3424>>2]=j;c[a+2404>>2]=n;c[a+3428>>2]=n;c[a+2408>>2]=o;c[a+3432>>2]=o;c[a+364>>2]=i;c[a+368>>2]=m;c[a+372>>2]=l;c[a+376>>2]=h;c[a+1388>>2]=i;c[a+1392>>2]=m;c[a+1396>>2]=l;c[a+1400>>2]=h;c[a+2412>>2]=i;c[a+3436>>2]=i;c[a+2416>>2]=m;c[a+3440>>2]=m;c[a+2420>>2]=l;c[a+3444>>2]=l;c[a+2424>>2]=h;c[a+3448>>2]=h;h=c[3541366]|0;c[a+396>>2]=h;c[a+2444>>2]=h;c[a+3468>>2]=h;h=192;l=192;while(1){c[a+76+(l<<2)>>2]=g+((l<<8)-32768);m=h+1&65535;if((m&65535)>255){p=192;q=192;break}else{h=m;l=m&65535}}while(1){l=g+((q<<8)-32768)|0;c[a+76+(q+512<<2)>>2]=l;c[a+76+(q+768<<2)>>2]=l;l=p+1&65535;if((l&65535)>255){break}else{p=l;q=l&65535}}if(d){r=c[2433530]|0;c[2438118]=r;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}d=a;gGC(d|0,9706056,76)|0;r=c[2433530]|0;c[2438118]=r;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}function a$y(){var a=0,d=0,e=0,f=0;a1r();a=c[2439330]|0;d=(a|0)==0;if(!d){e=a;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];e=c[3528484]|0;c[2076596]=e;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;c[a+4180>>2]=1138;c[a+4184>>2]=3264;if(!d){d=a;gGC(d|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}function a$z(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=c[2439330]|0;d=(a|0)==0;if(!d){e=a;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];e=c[3528484]|0;c[2076596]=e;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;gGz(a+76|0,0,2048);g=0;h=0;while(1){c[a+76+(h+512<<2)>>2]=0;c[a+76+(h+768<<2)>>2]=0;i=g+1&65535;if((i&65535)>255){break}else{g=i;h=i&65535}}c[a+4180>>2]=58;c[a+4184>>2]=3054;h=c[3541322]|0;g=c[3541328]|0;i=h>>>0>16383?63:h-1>>8;h=(i|0)<0;do{if(!h){j=0;k=0;do{c[a+76+(k<<2)>>2]=g+(k<<8);j=j+1&65535;k=j&65535;}while((k|0)<=(i|0));if(h){break}else{l=0;m=0}do{k=g+(m<<8)|0;c[a+76+(m+512<<2)>>2]=k;c[a+76+(m+768<<2)>>2]=k;l=l+1&65535;m=l&65535;}while((m|0)<=(i|0))}}while(0);i=c[3541334]|0;c[a+332>>2]=i;m=i+256|0;c[a+336>>2]=m;l=i+512|0;c[a+340>>2]=l;g=i+768|0;c[a+344>>2]=g;h=i+1024|0;c[a+348>>2]=h;k=i+1280|0;c[a+352>>2]=k;j=i+1536|0;c[a+356>>2]=j;n=i+1792|0;c[a+360>>2]=n;c[a+1356>>2]=i;c[a+1360>>2]=m;c[a+1364>>2]=l;c[a+1368>>2]=g;c[a+1372>>2]=h;c[a+1376>>2]=k;c[a+1380>>2]=j;c[a+1384>>2]=n;c[a+2380>>2]=i;c[a+3404>>2]=i;c[a+2384>>2]=m;c[a+3408>>2]=m;c[a+2388>>2]=l;c[a+3412>>2]=l;c[a+2392>>2]=g;c[a+3416>>2]=g;c[a+2396>>2]=h;c[a+3420>>2]=h;c[a+2400>>2]=k;c[a+3424>>2]=k;c[a+2404>>2]=j;c[a+3428>>2]=j;c[a+2408>>2]=n;c[a+3432>>2]=n;n=c[3541340]|0;c[a+364>>2]=n;j=n+256|0;c[a+368>>2]=j;k=n+512|0;c[a+372>>2]=k;h=n+768|0;c[a+376>>2]=h;c[a+1388>>2]=n;c[a+1392>>2]=j;c[a+1396>>2]=k;c[a+1400>>2]=h;c[a+2412>>2]=n;c[a+3436>>2]=n;c[a+2416>>2]=j;c[a+3440>>2]=j;c[a+2420>>2]=k;c[a+3444>>2]=k;c[a+2424>>2]=h;c[a+3448>>2]=h;c[a+380>>2]=n;c[a+384>>2]=j;c[a+388>>2]=k;c[a+392>>2]=h;c[a+1404>>2]=n;c[a+1408>>2]=j;c[a+1412>>2]=k;c[a+1416>>2]=h;c[a+2428>>2]=n;c[a+3452>>2]=n;c[a+2432>>2]=j;c[a+3456>>2]=j;c[a+2436>>2]=k;c[a+3460>>2]=k;c[a+2440>>2]=h;c[a+3464>>2]=h;h=c[3541366]|0;c[a+396>>2]=h;c[a+2444>>2]=h;c[a+3468>>2]=h;if(d){o=c[2433530]|0;c[2438118]=o;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}d=a;gGC(d|0,9706056,76)|0;o=c[2433530]|0;c[2438118]=o;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}function a$A(){var d=0,e=0,f=0,g=0;a$z();d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];f=c[3528484]|0;c[2076596]=f;g=c[2417276]|0;c[3541536]=g;c[1836236]=0;c[d+4180>>2]=102;c[d+4184>>2]=2348;if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=f;c[2417276]=g;c[1836236]=-1;a[(c[3541328]|0)+12025|0]=-55;return}function a$B(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;i=i+16|0;d=b|0;e=d|0;f=c[3541322]|0;if((f|0)==0){a$z();i=b;return}g=c[3541328]|0;h=0;do{j=0;do{a[d+j|0]=a[g+((j<<2&4|j&240|j>>>1&1|j>>>2<<3&8|j>>>3<<1&2)+h)|0]|0;j=j+1|0;}while(j>>>0<16);j=g+h|0;gGC(j|0,e|0,16)|0;h=h+16|0;}while(h>>>0<f>>>0);a$z();i=b;return}function a$C(){var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=i;i=i+16|0;e=d|0;f=e|0;g=c[3541322]|0;if((g|0)!=0){h=c[3541328]|0;j=0;do{k=0;do{a[e+k|0]=a[h+((k<<2&4|k&240|k>>>1&1|k>>>2<<3&8|k>>>3<<1&2)+j)|0]|0;k=k+1|0;}while(k>>>0<16);k=h+j|0;gGC(k|0,f|0,16)|0;j=j+16|0;}while(j>>>0<g>>>0)}j=c[2439330]|0;if((j|0)!=0){f=j;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];f=c[3528484]|0;c[2076596]=f;h=c[2417276]|0;c[3541536]=h;c[1836236]=0;gGz(j+76|0,0,2048);e=0;k=0;while(1){c[j+76+(k+512<<2)>>2]=0;c[j+76+(k+768<<2)>>2]=0;l=e+1&65535;if((l&65535)>255){break}else{e=l;k=l&65535}}c[j+4180>>2]=916;c[j+4184>>2]=2138;k=c[3541328]|0;e=g>>>0>16383?63:g-1>>8;g=(e|0)<0;do{if(!g){l=0;m=0;do{c[j+76+(m<<2)>>2]=k+(m<<8);l=l+1&65535;m=l&65535;}while((m|0)<=(e|0));if(g){break}else{n=0;o=0}do{m=k+(o<<8)|0;c[j+76+(o+512<<2)>>2]=m;c[j+76+(o+768<<2)>>2]=m;n=n+1&65535;o=n&65535;}while((o|0)<=(e|0))}}while(0);e=c[3541334]|0;c[j+332>>2]=e;o=e+256|0;c[j+336>>2]=o;n=e+512|0;c[j+340>>2]=n;g=e+768|0;c[j+344>>2]=g;m=e+1024|0;c[j+348>>2]=m;l=e+1280|0;c[j+352>>2]=l;p=e+1536|0;c[j+356>>2]=p;q=e+1792|0;c[j+360>>2]=q;c[j+1356>>2]=e;c[j+1360>>2]=o;c[j+1364>>2]=n;c[j+1368>>2]=g;c[j+1372>>2]=m;c[j+1376>>2]=l;c[j+1380>>2]=p;c[j+1384>>2]=q;c[j+2380>>2]=e;c[j+3404>>2]=e;c[j+2384>>2]=o;c[j+3408>>2]=o;c[j+2388>>2]=n;c[j+3412>>2]=n;c[j+2392>>2]=g;c[j+3416>>2]=g;c[j+2396>>2]=m;c[j+3420>>2]=m;c[j+2400>>2]=l;c[j+3424>>2]=l;c[j+2404>>2]=p;c[j+3428>>2]=p;c[j+2408>>2]=q;c[j+3432>>2]=q;q=c[3541340]|0;c[j+364>>2]=q;p=q+256|0;c[j+368>>2]=p;l=q+512|0;c[j+372>>2]=l;m=q+768|0;c[j+376>>2]=m;c[j+1388>>2]=q;c[j+1392>>2]=p;c[j+1396>>2]=l;c[j+1400>>2]=m;c[j+2412>>2]=q;c[j+3436>>2]=q;c[j+2416>>2]=p;c[j+3440>>2]=p;c[j+2420>>2]=l;c[j+3444>>2]=l;c[j+2424>>2]=m;c[j+3448>>2]=m;m=c[3541366]|0;c[j+396>>2]=m;c[j+2444>>2]=m;c[j+3468>>2]=m;c[j+716>>2]=k+16384;c[j+720>>2]=k+16640;c[j+724>>2]=k+16896;c[j+728>>2]=k+17152;c[j+732>>2]=k+17408;c[j+736>>2]=k+17664;c[j+740>>2]=k+17920;c[j+744>>2]=k+18176;c[j+748>>2]=k+18432;c[j+752>>2]=k+18688;c[j+756>>2]=k+18944;c[j+760>>2]=k+19200;c[j+764>>2]=k+19456;c[j+768>>2]=k+19712;c[j+772>>2]=k+19968;c[j+776>>2]=k+20224;m=160;l=160;while(1){p=k+((l<<8)-24576)|0;c[j+76+(l+512<<2)>>2]=p;c[j+76+(l+768<<2)>>2]=p;p=m+1&65535;if((p&65535)>175){break}else{m=p;l=p&65535}}l=j;gGC(l|0,9706056,76)|0;c[2438118]=c[2433530];c[3528484]=f;c[2417276]=h;c[1836236]=-1;i=d;return}function a$D(){var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=i;i=i+16|0;e=d|0;f=e|0;g=c[3541322]|0;if((g|0)!=0){h=c[3541328]|0;j=0;do{k=0;do{a[e+k|0]=a[h+((k<<2&4|k&240|k>>>1&1|k>>>2<<3&8|k>>>3<<1&2)+j)|0]|0;k=k+1|0;}while(k>>>0<16);k=h+j|0;gGC(k|0,f|0,16)|0;j=j+16|0;}while(j>>>0<g>>>0)}j=c[2439330]|0;f=(j|0)==0;if(!f){h=j;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];h=c[3528484]|0;c[2076596]=h;e=c[2417276]|0;c[3541536]=e;c[1836236]=0;gGz(j+76|0,0,2048);k=0;l=0;while(1){c[j+76+(l+512<<2)>>2]=0;c[j+76+(l+768<<2)>>2]=0;m=k+1&65535;if((m&65535)>255){break}else{k=m;l=m&65535}}c[j+4180>>2]=58;c[j+4184>>2]=610;l=c[3541328]|0;k=g>>>0>16383?63:g-1>>8;g=(k|0)<0;do{if(!g){m=0;n=0;do{c[j+76+(n<<2)>>2]=l+(n<<8);m=m+1&65535;n=m&65535;}while((n|0)<=(k|0));if(g){break}else{o=0;p=0}do{n=l+(p<<8)|0;c[j+76+(p+512<<2)>>2]=n;c[j+76+(p+768<<2)>>2]=n;o=o+1&65535;p=o&65535;}while((p|0)<=(k|0))}}while(0);k=c[3541334]|0;c[j+332>>2]=k;p=k+256|0;c[j+336>>2]=p;o=k+512|0;c[j+340>>2]=o;l=k+768|0;c[j+344>>2]=l;g=k+1024|0;c[j+348>>2]=g;n=k+1280|0;c[j+352>>2]=n;m=k+1536|0;c[j+356>>2]=m;q=k+1792|0;c[j+360>>2]=q;c[j+1356>>2]=k;c[j+1360>>2]=p;c[j+1364>>2]=o;c[j+1368>>2]=l;c[j+1372>>2]=g;c[j+1376>>2]=n;c[j+1380>>2]=m;c[j+1384>>2]=q;c[j+2380>>2]=k;c[j+3404>>2]=k;c[j+2384>>2]=p;c[j+3408>>2]=p;c[j+2388>>2]=o;c[j+3412>>2]=o;c[j+2392>>2]=l;c[j+3416>>2]=l;c[j+2396>>2]=g;c[j+3420>>2]=g;c[j+2400>>2]=n;c[j+3424>>2]=n;c[j+2404>>2]=m;c[j+3428>>2]=m;c[j+2408>>2]=q;c[j+3432>>2]=q;q=c[3541340]|0;c[j+364>>2]=q;m=q+256|0;c[j+368>>2]=m;n=q+512|0;c[j+372>>2]=n;g=q+768|0;c[j+376>>2]=g;c[j+1388>>2]=q;c[j+1392>>2]=m;c[j+1396>>2]=n;c[j+1400>>2]=g;c[j+2412>>2]=q;c[j+3436>>2]=q;c[j+2416>>2]=m;c[j+3440>>2]=m;c[j+2420>>2]=n;c[j+3444>>2]=n;c[j+2424>>2]=g;c[j+3448>>2]=g;g=c[3541366]|0;c[j+396>>2]=g;c[j+2444>>2]=g;c[j+3468>>2]=g;if(f){r=c[2433530]|0;c[2438118]=r;c[3528484]=h;c[2417276]=e;c[1836236]=-1;i=d;return}f=j;gGC(f|0,9706056,76)|0;r=c[2433530]|0;c[2438118]=r;c[3528484]=h;c[2417276]=e;c[1836236]=-1;i=d;return}function a$E(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=c[2439330]|0;d=(a|0)==0;if(!d){e=a;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];e=c[3528484]|0;c[2076596]=e;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;gGz(a+76|0,0,2048);g=0;h=0;while(1){c[a+76+(h+512<<2)>>2]=0;c[a+76+(h+768<<2)>>2]=0;i=g+1&65535;if((i&65535)>255){break}else{g=i;h=i&65535}}c[a+4180>>2]=224;c[a+4184>>2]=3348;h=c[3541328]|0;g=0;i=0;while(1){c[a+76+(i<<2)>>2]=h+(i<<8);j=g+1&65535;if((j&65535)>95){k=0;l=0;break}else{g=j;i=j&65535}}while(1){i=h+(l<<8)|0;c[a+76+(l+512<<2)>>2]=i;c[a+76+(l+768<<2)>>2]=i;i=k+1&65535;if((i&65535)>95){break}else{k=i;l=i&65535}}l=c[3541334]|0;c[a+460>>2]=l;c[a+464>>2]=l+256;c[a+468>>2]=l+512;c[a+472>>2]=l+768;c[a+476>>2]=l+1024;c[a+480>>2]=l+1280;c[a+484>>2]=l+1536;c[a+488>>2]=l+1792;c[a+492>>2]=l+2048;c[a+496>>2]=l+2304;c[a+500>>2]=l+2560;c[a+504>>2]=l+2816;c[a+508>>2]=l+3072;c[a+512>>2]=l+3328;c[a+516>>2]=l+3584;c[a+520>>2]=l+3840;k=96;h=96;while(1){c[a+76+(h+256<<2)>>2]=l+((h<<8)-24576);i=k+1&65535;if((i&65535)>111){m=96;n=96;break}else{k=i;h=i&65535}}while(1){h=l+((n<<8)-24576)|0;c[a+76+(n+512<<2)>>2]=h;c[a+76+(n+768<<2)>>2]=h;h=m+1&65535;if((h&65535)>111){break}else{m=h;n=h&65535}}n=c[3541340]|0;c[a+652>>2]=n;m=n+256|0;c[a+656>>2]=m;l=n+512|0;c[a+660>>2]=l;h=n+768|0;c[a+664>>2]=h;c[a+1676>>2]=n;c[a+1680>>2]=m;c[a+1684>>2]=l;c[a+1688>>2]=h;c[a+2700>>2]=n;c[a+3724>>2]=n;c[a+2704>>2]=m;c[a+3728>>2]=m;c[a+2708>>2]=l;c[a+3732>>2]=l;c[a+2712>>2]=h;c[a+3736>>2]=h;c[a+668>>2]=n;c[a+672>>2]=m;c[a+676>>2]=l;c[a+680>>2]=h;c[a+1692>>2]=n;c[a+1696>>2]=m;c[a+1700>>2]=l;c[a+1704>>2]=h;c[a+2716>>2]=n;c[a+3740>>2]=n;c[a+2720>>2]=m;c[a+3744>>2]=m;c[a+2724>>2]=l;c[a+3748>>2]=l;c[a+2728>>2]=h;c[a+3752>>2]=h;h=c[3541366]|0;c[a+684>>2]=h;c[a+2732>>2]=h;c[a+3756>>2]=h;if(d){o=c[2433530]|0;c[2438118]=o;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}d=a;gGC(d|0,9706056,76)|0;o=c[2433530]|0;c[2438118]=o;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}function a$F(){var a=0,d=0,e=0,f=0,g=0,h=0;a1r();a=c[2439330]|0;d=(a|0)==0;if(!d){e=a;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];e=c[3528484]|0;c[2076596]=e;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;c[a+4180>>2]=3112;c[a+4184>>2]=3332;g=c[3541366]|0;c[a+400>>2]=g;c[a+2448>>2]=g;c[a+3472>>2]=g;if(d){h=c[2433530]|0;c[2438118]=h;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}d=a;gGC(d|0,9706056,76)|0;h=c[2433530]|0;c[2438118]=h;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}function a$G(){var b=0,c=0;b=a[14165810]|0;if((a[14130432]|0)<0){c=(95-b&255)-(a[14165874]|0)&255;return c|0}else{c=~b-(a[14165874]|0)&255;return c|0}return 0}function a$H(){return a[14130432]|0}function a$I(c){c=c|0;var d=0;d=b[7065212]<<4|c&15;b[7065212]=d;switch(d&4095|0){case 3849:{a[14130432]=-1;return};case 2911:{a[14130432]=111;return};case 793:{a[14130432]=79;return};case 1481:{a[14130432]=111;return};case 582:{a[14130432]=a[14130432]^-128;return};case 2633:{a[14130432]=-65;return};default:{return}}}function a$J(){var a=0,d=0,e=0,f=0;a1w();a=c[2439330]|0;d=(a|0)==0;if(!d){e=a;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];e=c[3528484]|0;c[2076596]=e;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;c[a+4180>>2]=1364;c[a+4184>>2]=944;if(!d){d=a;gGC(d|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}function a$K(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=i;i=i+240|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=c[3541348]|0;k=0;while(1){if((k|0)>=1024){l=0;break}m=9638528+(k<<2)|0;if((c[m>>2]|0)==0){n=45205;break}else{k=k+1|0}}do{if((n|0)==45205){k=gGq(j)|0;c[m>>2]=k;if((k|0)==0){l=0;break}gGz(k|0,0,j|0);l=k}}while(0);c[3541356]=l;j=(c[3541318]|0)+(c[3541326]|0)+(c[3541312]|0)|0;do{if((c[3542200]|0)!=0){m=g+108|0;c[m>>2]=0;k=g+100|0;c[k>>2]=0;o=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[o&16383](g,j)|0;if((c[m>>2]|0)==0){break}m=c[k>>2]|0;c[h>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](h,j,0)|0;if((m|0)<1){break}gzL(l,0,j)|0}}while(0);j=(c[3541356]|0)+2048|0;l=(c[3541326]|0)+1+(c[3541318]|0)+(c[3541312]|0)|0;do{if((c[3542200]|0)!=0){h=e+108|0;c[h>>2]=0;g=e+100|0;c[g>>2]=0;m=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[m&16383](e,l)|0;if((c[h>>2]|0)==0){break}h=c[g>>2]|0;c[f>>2]=9534384;g=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[g&16383](f,l,0)|0;if((h|0)<1){break}gzL(j,0,l)|0}}while(0);l=c[3541356]|0;j=2048;do{f=l+j|0;e=a[f]|0;a[f]=e<<1&2|e&-4|(e&255)>>>1&1;j=j+1|0;}while(j>>>0<4096);j=c[3541414]|0;e=c[3541472]|0;if((j|0)>0){f=c[1865546]|0;h=0;do{g=h<<6;gGz(e+g|0,0,64);m=0;do{k=g+(c[1238464+(m<<2)>>2]|0)|0;o=(m<<3)+g|0;p=0;do{q=k+(c[614800+(p<<2)>>2]|0)|0;if(((d[l+((q|0)/8|0)|0]|0)&128>>>((q&7)>>>0)|0)!=0){q=e+(o+p)|0;a[q]=a[q]|2}p=p+1|0;}while((p|0)<8);m=m+1|0;}while((m|0)<8);m=f+g|0;p=0;do{o=m+(c[1238464+(p<<2)>>2]|0)|0;k=(p<<3)+g|0;q=0;do{r=o+(c[614800+(q<<2)>>2]|0)|0;if(((d[l+((r|0)/8|0)|0]|0)&128>>>((r&7)>>>0)|0)!=0){r=e+(k+q)|0;a[r]=a[r]|1}q=q+1|0;}while((q|0)<8);p=p+1|0;}while((p|0)<8);h=h+1|0;}while((h|0)<(j|0))}j=c[3541412]|0;h=c[3541364]|0;if((j|0)>0){e=c[1865412]|0;f=0;while(1){p=f<<8;gGz(h+p|0,0,256);g=0;do{m=p+(c[611776+(g<<2)>>2]|0)|0;q=(g<<4)+p|0;k=0;do{o=m+(c[601400+(k<<2)>>2]|0)|0;if(((d[l+((o|0)/8|0)|0]|0)&128>>>((o&7)>>>0)|0)!=0){o=h+(q+k)|0;a[o]=a[o]|2}k=k+1|0;}while((k|0)<16);g=g+1|0;}while((g|0)<16);g=e+p|0;k=0;do{q=g+(c[611776+(k<<2)>>2]|0)|0;m=(k<<4)+p|0;o=0;do{r=q+(c[601400+(o<<2)>>2]|0)|0;if(((d[l+((r|0)/8|0)|0]|0)&128>>>((r&7)>>>0)|0)!=0){r=h+(m+o)|0;a[r]=a[r]|1}o=o+1|0;}while((o|0)<16);k=k+1|0;}while((k|0)<16);k=f+1|0;if((k|0)<(j|0)){f=k}else{s=0;break}}}else{s=0}while(1){if((s|0)>=1024){n=45252;break}t=9638528+(s<<2)|0;if((c[t>>2]|0)==(l|0)){break}else{s=s+1|0}}if((n|0)==45252){c[3541356]=0;a1r();i=b;return}gGr(l);c[t>>2]=0;c[3541356]=0;a1r();i=b;return}function a$L(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=c[2439330]|0;d=(a|0)==0;if(!d){e=a;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];e=c[3528484]|0;c[2076596]=e;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;g=c[3541334]|0;c[a+332>>2]=g;h=g+256|0;c[a+336>>2]=h;i=g+512|0;c[a+340>>2]=i;j=g+768|0;c[a+344>>2]=j;k=g+1024|0;c[a+348>>2]=k;l=g+1280|0;c[a+352>>2]=l;m=g+1536|0;c[a+356>>2]=m;n=g+1792|0;c[a+360>>2]=n;c[a+1356>>2]=g;c[a+1360>>2]=h;c[a+1364>>2]=i;c[a+1368>>2]=j;c[a+1372>>2]=k;c[a+1376>>2]=l;c[a+1380>>2]=m;c[a+1384>>2]=n;c[a+2380>>2]=g;c[a+3404>>2]=g;c[a+2384>>2]=h;c[a+3408>>2]=h;c[a+2388>>2]=i;c[a+3412>>2]=i;c[a+2392>>2]=j;c[a+3416>>2]=j;c[a+2396>>2]=k;c[a+3420>>2]=k;c[a+2400>>2]=l;c[a+3424>>2]=l;c[a+2404>>2]=m;c[a+3428>>2]=m;c[a+2408>>2]=n;c[a+3432>>2]=n;if(d){o=c[2433530]|0;c[2438118]=o;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}d=a;gGC(d|0,9706056,76)|0;o=c[2433530]|0;c[2438118]=o;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}function a$M(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a1m();a=c[2439330]|0;if((a|0)!=0){d=a;gGC(9706056,d|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];d=c[3528484]|0;c[2076596]=d;e=c[2417276]|0;c[3541536]=e;c[1836236]=0;c[a+4180>>2]=3146;c[a+4184>>2]=3392;f=a+620|0;gGz(f|0,0,480);g=a+1644|0;gGz(g|0,0,480);h=136;i=136;while(1){c[a+76+(i+512<<2)>>2]=0;c[a+76+(i+768<<2)>>2]=0;j=h+1&65535;if((j&65535)>255){break}else{h=j;i=j&65535}}i=c[3541340]|0;c[f>>2]=i;f=i+256|0;c[a+624>>2]=f;h=i+512|0;c[a+628>>2]=h;j=i+768|0;c[a+632>>2]=j;c[g>>2]=i;c[a+1648>>2]=f;c[a+1652>>2]=h;c[a+1656>>2]=j;c[a+2668>>2]=i;c[a+3692>>2]=i;c[a+2672>>2]=f;c[a+3696>>2]=f;c[a+2676>>2]=h;c[a+3700>>2]=h;c[a+2680>>2]=j;c[a+3704>>2]=j;j=c[3541366]|0;c[a+652>>2]=j;c[a+2700>>2]=j;c[a+3724>>2]=j;j=a;gGC(j|0,9706056,76)|0;c[2438118]=c[2433530];c[3528484]=d;c[2417276]=e;c[1836236]=-1;return}function a$N(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a1c();a=c[2439330]|0;d=(a|0)==0;if(!d){e=a;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];e=c[3528484]|0;c[2076596]=e;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;c[a+4184>>2]=3018;g=c[3541334]|0;c[a+588>>2]=g;h=g+256|0;c[a+592>>2]=h;i=g+512|0;c[a+596>>2]=i;j=g+768|0;c[a+600>>2]=j;k=g+1024|0;c[a+604>>2]=k;l=g+1280|0;c[a+608>>2]=l;m=g+1536|0;c[a+612>>2]=m;n=g+1792|0;c[a+616>>2]=n;c[a+1612>>2]=g;c[a+1616>>2]=h;c[a+1620>>2]=i;c[a+1624>>2]=j;c[a+1628>>2]=k;c[a+1632>>2]=l;c[a+1636>>2]=m;c[a+1640>>2]=n;c[a+2636>>2]=g;c[a+3660>>2]=g;c[a+2640>>2]=h;c[a+3664>>2]=h;c[a+2644>>2]=i;c[a+3668>>2]=i;c[a+2648>>2]=j;c[a+3672>>2]=j;c[a+2652>>2]=k;c[a+3676>>2]=k;c[a+2656>>2]=l;c[a+3680>>2]=l;c[a+2660>>2]=m;c[a+3684>>2]=m;c[a+2664>>2]=n;c[a+3688>>2]=n;if(d){o=c[2433530]|0;c[2438118]=o;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}d=a;gGC(d|0,9706056,76)|0;o=c[2433530]|0;c[2438118]=o;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}function a$O(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=i;i=i+240|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=c[3541348]|0;k=0;while(1){if((k|0)>=1024){l=0;break}m=9638528+(k<<2)|0;if((c[m>>2]|0)==0){n=45275;break}else{k=k+1|0}}do{if((n|0)==45275){k=gGq(j)|0;c[m>>2]=k;if((k|0)==0){l=0;break}gGz(k|0,0,j|0);l=k}}while(0);c[3541356]=l;j=(c[3541318]|0)+(c[3541326]|0)+(c[3541312]|0)|0;do{if((c[3542200]|0)!=0){m=g+108|0;c[m>>2]=0;k=g+100|0;c[k>>2]=0;o=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[o&16383](g,j)|0;if((c[m>>2]|0)==0){break}m=c[k>>2]|0;c[h>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](h,j,0)|0;if((m|0)<1){break}gzL(l,0,j)|0}}while(0);j=(c[3541356]|0)+2048|0;l=(c[3541326]|0)+1+(c[3541318]|0)+(c[3541312]|0)|0;do{if((c[3542200]|0)!=0){h=e+108|0;c[h>>2]=0;g=e+100|0;c[g>>2]=0;m=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[m&16383](e,l)|0;if((c[h>>2]|0)==0){break}h=c[g>>2]|0;c[f>>2]=9534384;g=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[g&16383](f,l,0)|0;if((h|0)<1){break}gzL(j,0,l)|0}}while(0);l=c[3541356]|0;j=2048;do{f=l+j|0;e=a[f]|0;a[f]=e<<1&2|e&-4|(e&255)>>>1&1;j=j+1|0;}while(j>>>0<4096);j=c[3541414]|0;e=c[3541472]|0;if((j|0)>0){f=c[1865546]|0;h=0;do{g=h<<6;gGz(e+g|0,0,64);m=0;do{k=g+(c[1238464+(m<<2)>>2]|0)|0;o=(m<<3)+g|0;p=0;do{q=k+(c[614800+(p<<2)>>2]|0)|0;if(((d[l+((q|0)/8|0)|0]|0)&128>>>((q&7)>>>0)|0)!=0){q=e+(o+p)|0;a[q]=a[q]|2}p=p+1|0;}while((p|0)<8);m=m+1|0;}while((m|0)<8);m=f+g|0;p=0;do{o=m+(c[1238464+(p<<2)>>2]|0)|0;k=(p<<3)+g|0;q=0;do{r=o+(c[614800+(q<<2)>>2]|0)|0;if(((d[l+((r|0)/8|0)|0]|0)&128>>>((r&7)>>>0)|0)!=0){r=e+(k+q)|0;a[r]=a[r]|1}q=q+1|0;}while((q|0)<8);p=p+1|0;}while((p|0)<8);h=h+1|0;}while((h|0)<(j|0))}j=c[3541412]|0;h=c[3541364]|0;if((j|0)>0){e=c[1865412]|0;f=0;while(1){p=f<<8;gGz(h+p|0,0,256);g=0;do{m=p+(c[611776+(g<<2)>>2]|0)|0;q=(g<<4)+p|0;k=0;do{o=m+(c[601400+(k<<2)>>2]|0)|0;if(((d[l+((o|0)/8|0)|0]|0)&128>>>((o&7)>>>0)|0)!=0){o=h+(q+k)|0;a[o]=a[o]|2}k=k+1|0;}while((k|0)<16);g=g+1|0;}while((g|0)<16);g=e+p|0;k=0;do{q=g+(c[611776+(k<<2)>>2]|0)|0;m=(k<<4)+p|0;o=0;do{r=q+(c[601400+(o<<2)>>2]|0)|0;if(((d[l+((r|0)/8|0)|0]|0)&128>>>((r&7)>>>0)|0)!=0){r=h+(m+o)|0;a[r]=a[r]|1}o=o+1|0;}while((o|0)<16);k=k+1|0;}while((k|0)<16);k=f+1|0;if((k|0)<(j|0)){f=k}else{s=0;break}}}else{s=0}while(1){if((s|0)>=1024){n=45322;break}t=9638528+(s<<2)|0;if((c[t>>2]|0)==(l|0)){break}else{s=s+1|0}}if((n|0)==45322){c[3541356]=0;a1m();i=b;return}gGr(l);c[t>>2]=0;c[3541356]=0;a1m();i=b;return}function a$P(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a1c();a=c[2439330]|0;d=(a|0)==0;if(!d){e=a;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];e=c[3528484]|0;c[2076596]=e;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;c[a+4180>>2]=2424;c[a+4184>>2]=1642;if(!d){d=a;gGC(d|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=e;c[2417276]=f;c[1836236]=-1;f=c[2439331]|0;e=(f|0)==0;if(!e){d=f;gGC(9706056,d|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];d=c[3528485]|0;c[2076596]=d;a=c[2417277]|0;c[3541536]=a;c[1836236]=1;c[f+4180>>2]=3428;c[f+4184>>2]=1404;c[f+4172>>2]=2758;c[f+4176>>2]=170;g=c[3541320]|0;h=0;i=0;while(1){c[f+76+(i<<2)>>2]=g+(i<<8);j=h+1&65535;if((j&65535)>31){k=0;l=0;break}else{h=j;i=j&65535}}while(1){i=g+(l<<8)|0;c[f+76+(l+512<<2)>>2]=i;c[f+76+(l+768<<2)>>2]=i;i=k+1&65535;if((i&65535)>31){break}else{k=i;l=i&65535}}if(e){m=c[2433530]|0;c[2438119]=m;c[3528485]=d;c[2417277]=a;c[1836236]=-1;c[2113200]=41666;return}e=f;gGC(e|0,9706056,76)|0;m=c[2433530]|0;c[2438119]=m;c[3528485]=d;c[2417277]=a;c[1836236]=-1;c[2113200]=41666;return}function a$Q(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=c[3541322]|0;e=0;while(1){if((e|0)>=1024){f=0;break}g=9638528+(e<<2)|0;if((c[g>>2]|0)==0){h=45340;break}else{e=e+1|0}}do{if((h|0)==45340){e=gGq(d)|0;c[g>>2]=e;if((e|0)==0){f=0;break}gGz(e|0,0,d|0);f=e}}while(0);c[3541324]=f;d=c[3541322]|0;if((d|0)!=0){g=c[3541328]|0;h=0;do{e=a[g+h|0]|0;i=e&255;a[f+h|0]=e&-86|a[(i>>>1&2|i&1|i>>>2&4|i>>>3&8)+(600608+((i&2|h&1|i>>>5&4)<<4))|0];h=h+1|0;}while(h>>>0<d>>>0)}a1c();d=c[2439330]|0;h=(d|0)==0;if(!h){g=d;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];g=c[3528484]|0;c[2076596]=g;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;e=c[3541328]|0;j=0;k=0;while(1){c[d+76+(k<<2)>>2]=e+(k<<8);l=j+1&65535;if((l&65535)>79){m=0;n=0;break}else{j=l;k=l&65535}}while(1){k=n<<8;c[d+76+(n+512<<2)>>2]=f+k;c[d+76+(n+768<<2)>>2]=e+k;k=m+1&65535;if((k&65535)>79){break}else{m=k;n=k&65535}}c[d+4184>>2]=1260;c[d+4172>>2]=1222;c[d+4176>>2]=44;if(h){o=c[2433530]|0;c[2438118]=o;c[3528484]=g;c[2417276]=i;c[1836236]=-1;return}h=d;gGC(h|0,9706056,76)|0;o=c[2433530]|0;c[2438118]=o;c[3528484]=g;c[2417276]=i;c[1836236]=-1;return}function a$R(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;b=i;i=i+480|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;l=b+360|0;m=b+472|0;n=c[3541348]|0;o=0;while(1){if((o|0)>=1024){p=0;break}q=9638528+(o<<2)|0;if((c[q>>2]|0)==0){r=45358;break}else{o=o+1|0}}do{if((r|0)==45358){o=gGq(n)|0;c[q>>2]=o;if((o|0)==0){p=0;break}gGz(o|0,0,n|0);p=o}}while(0);c[3541356]=p;n=(c[3541318]|0)+(c[3541326]|0)+(c[3541312]|0)|0;do{if((c[3542200]|0)!=0){q=l+108|0;c[q>>2]=0;o=l+100|0;c[o>>2]=0;s=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[s&16383](l,n)|0;if((c[q>>2]|0)==0){break}q=c[o>>2]|0;c[m>>2]=9534384;o=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[o&16383](m,n,0)|0;if((q|0)<1){break}gzL(p,0,n)|0}}while(0);n=(c[3541356]|0)+4096|0;p=(c[3541326]|0)+1+(c[3541318]|0)+(c[3541312]|0)|0;do{if((c[3542200]|0)!=0){m=j+108|0;c[m>>2]=0;l=j+100|0;c[l>>2]=0;q=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[q&16383](j,p)|0;if((c[m>>2]|0)==0){break}m=c[l>>2]|0;c[k>>2]=9534384;l=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[l&16383](k,p,0)|0;if((m|0)<1){break}gzL(n,0,p)|0}}while(0);p=(c[3541356]|0)+8192|0;n=(c[3541326]|0)+2+(c[3541318]|0)+(c[3541312]|0)|0;do{if((c[3542200]|0)!=0){k=g+108|0;c[k>>2]=0;j=g+100|0;c[j>>2]=0;m=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[m&16383](g,n)|0;if((c[k>>2]|0)==0){break}k=c[j>>2]|0;c[h>>2]=9534384;j=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[j&16383](h,n,0)|0;if((k|0)<1){break}gzL(p,0,n)|0}}while(0);n=(c[3541356]|0)+12288|0;p=(c[3541326]|0)+3+(c[3541318]|0)+(c[3541312]|0)|0;do{if((c[3542200]|0)!=0){h=e+108|0;c[h>>2]=0;g=e+100|0;c[g>>2]=0;k=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[k&16383](e,p)|0;if((c[h>>2]|0)==0){break}h=c[g>>2]|0;c[f>>2]=9534384;g=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[g&16383](f,p,0)|0;if((h|0)<1){break}gzL(n,0,p)|0}}while(0);p=c[3541414]|0;n=c[3541356]|0;f=c[3541472]|0;if((p|0)>0){e=c[1865546]|0;h=0;do{g=h<<6;gGz(f+g|0,0,64);k=0;do{j=g+(c[1238464+(k<<2)>>2]|0)|0;m=(k<<3)+g|0;l=0;do{q=j+(c[614800+(l<<2)>>2]|0)|0;if(((d[n+((q|0)/8|0)|0]|0)&128>>>((q&7)>>>0)|0)!=0){q=f+(m+l)|0;a[q]=a[q]|2}l=l+1|0;}while((l|0)<8);k=k+1|0;}while((k|0)<8);k=e+g|0;l=0;do{m=k+(c[1238464+(l<<2)>>2]|0)|0;j=(l<<3)+g|0;q=0;do{o=m+(c[614800+(q<<2)>>2]|0)|0;if(((d[n+((o|0)/8|0)|0]|0)&128>>>((o&7)>>>0)|0)!=0){o=f+(j+q)|0;a[o]=a[o]|1}q=q+1|0;}while((q|0)<8);l=l+1|0;}while((l|0)<8);h=h+1|0;}while((h|0)<(p|0))}p=c[3541412]|0;h=c[3541364]|0;if((p|0)>0){f=c[1865412]|0;e=0;while(1){l=e<<8;gGz(h+l|0,0,256);g=0;do{k=l+(c[611776+(g<<2)>>2]|0)|0;q=(g<<4)+l|0;j=0;do{m=k+(c[601400+(j<<2)>>2]|0)|0;if(((d[n+((m|0)/8|0)|0]|0)&128>>>((m&7)>>>0)|0)!=0){m=h+(q+j)|0;a[m]=a[m]|2}j=j+1|0;}while((j|0)<16);g=g+1|0;}while((g|0)<16);g=f+l|0;j=0;do{q=g+(c[611776+(j<<2)>>2]|0)|0;k=(j<<4)+l|0;m=0;do{o=q+(c[601400+(m<<2)>>2]|0)|0;if(((d[n+((o|0)/8|0)|0]|0)&128>>>((o&7)>>>0)|0)!=0){o=h+(k+m)|0;a[o]=a[o]|1}m=m+1|0;}while((m|0)<16);j=j+1|0;}while((j|0)<16);j=e+1|0;if((j|0)<(p|0)){e=j}else{t=0;break}}}else{t=0}while(1){if((t|0)>=1024){r=45410;break}u=9638528+(t<<2)|0;if((c[u>>2]|0)==(n|0)){break}else{t=t+1|0}}if((r|0)==45410){c[3541356]=0;c[3541466]=72;c[3541462]=52;c[3541464]=52;a[14165760]=2;i=b;return}gGr(n);c[u>>2]=0;c[3541356]=0;c[3541466]=72;c[3541462]=52;c[3541464]=52;a[14165760]=2;i=b;return}function a$S(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=c[3541322]|0;e=0;while(1){if((e|0)>=1024){f=0;break}g=9638528+(e<<2)|0;if((c[g>>2]|0)==0){h=45415;break}else{e=e+1|0}}do{if((h|0)==45415){e=gGq(d)|0;c[g>>2]=e;if((e|0)==0){f=0;break}gGz(e|0,0,d|0);f=e}}while(0);c[3541324]=f;d=c[3541322]|0;if((d|0)!=0){g=c[3541328]|0;h=0;do{e=a[g+h|0]|0;i=e&255;a[f+h|0]=e&-86|a[(i>>>1&2|i&1|i>>>2&4|i>>>3&8)+(602416+((i&2|h&1|i>>>5&4)<<4))|0];h=h+1|0;}while(h>>>0<d>>>0)}a1c();d=c[2439330]|0;h=(d|0)==0;if(!h){g=d;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];g=c[3528484]|0;c[2076596]=g;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;e=c[3541328]|0;j=0;k=0;while(1){c[d+76+(k<<2)>>2]=e+(k<<8);l=j+1&65535;if((l&65535)>79){m=0;n=0;break}else{j=l;k=l&65535}}while(1){k=n<<8;c[d+76+(n+512<<2)>>2]=f+k;c[d+76+(n+768<<2)>>2]=e+k;k=m+1&65535;if((k&65535)>79){break}else{m=k;n=k&65535}}c[d+4184>>2]=1260;c[d+4172>>2]=1222;c[d+4176>>2]=44;if(h){o=c[2433530]|0;c[2438118]=o;c[3528484]=g;c[2417276]=i;c[1836236]=-1;return}h=d;gGC(h|0,9706056,76)|0;o=c[2433530]|0;c[2438118]=o;c[3528484]=g;c[2417276]=i;c[1836236]=-1;return}function a$T(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[2439330]|0;d=(a|0)==0;if(!d){e=a;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];e=c[3528484]|0;c[2076596]=e;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;c[a+4180>>2]=628;c[a+4184>>2]=1756;g=c[3541340]|0;c[a+412>>2]=g;h=g+256|0;c[a+416>>2]=h;i=g+512|0;c[a+420>>2]=i;j=g+768|0;c[a+424>>2]=j;c[a+1436>>2]=g;c[a+1440>>2]=h;c[a+1444>>2]=i;c[a+1448>>2]=j;c[a+2460>>2]=g;c[a+3484>>2]=g;c[a+2464>>2]=h;c[a+3488>>2]=h;c[a+2468>>2]=i;c[a+3492>>2]=i;c[a+2472>>2]=j;c[a+3496>>2]=j;if(d){k=c[2433530]|0;c[2438118]=k;c[3528484]=e;c[2417276]=f;c[1836236]=-1;a$U();return}d=a;gGC(d|0,9706056,76)|0;k=c[2433530]|0;c[2438118]=k;c[3528484]=e;c[2417276]=f;c[1836236]=-1;a$U();return}function a$U(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[2439331]|0;d=(a|0)==0;if(!d){e=a;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];e=c[3528485]|0;c[2076596]=e;f=c[2417277]|0;c[3541536]=f;c[1836236]=1;g=c[3541320]|0;h=(c[3541316]|0)-1>>8;i=(h|0)<0;do{if(!i){j=0;k=0;do{c[a+76+(k<<2)>>2]=g+(k<<8);j=j+1&65535;k=j&65535;}while((k|0)<=(h|0));if(i){break}else{l=0;m=0}do{k=g+(m<<8)|0;c[a+76+(m+512<<2)>>2]=k;c[a+76+(m+768<<2)>>2]=k;l=l+1&65535;m=l&65535;}while((m|0)<=(h|0))}}while(0);h=c[3541332]|0;c[a+588>>2]=h;m=h+256|0;c[a+592>>2]=m;l=h+512|0;c[a+596>>2]=l;g=h+768|0;c[a+600>>2]=g;c[a+1612>>2]=h;c[a+1616>>2]=m;c[a+1620>>2]=l;c[a+1624>>2]=g;c[a+2636>>2]=h;c[a+3660>>2]=h;c[a+2640>>2]=m;c[a+3664>>2]=m;c[a+2644>>2]=l;c[a+3668>>2]=l;c[a+2648>>2]=g;c[a+3672>>2]=g;c[a+4180>>2]=636;c[a+4184>>2]=3222;if(d){n=c[2433530]|0;c[2438119]=n;c[3528485]=e;c[2417277]=f;c[1836236]=-1;c[2113200]=27e3;return}d=a;gGC(d|0,9706056,76)|0;n=c[2433530]|0;c[2438119]=n;c[3528485]=e;c[2417277]=f;c[1836236]=-1;c[2113200]=27e3;return}function a$V(){var a=0,d=0,e=0,f=0;a=c[2439330]|0;d=(a|0)==0;if(!d){e=a;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];e=c[3528484]|0;c[2076596]=e;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;c[a+4180>>2]=1642;c[a+4184>>2]=1756;if(!d){d=a;gGC(d|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=e;c[2417276]=f;c[1836236]=-1;a$U();return}function a$W(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=c[3541322]|0;if((e|0)!=0){f=c[3541328]|0;g=0;do{h=f+g|0;i=g&7;j=d[h]|0;a[h]=(((j>>>((d[601370+(i<<2)|0]|0)>>>0)&1)<<(d[601371+(i<<2)|0]|0)|(j>>>((d[601368+(i<<2)|0]|0)>>>0)&1)<<(d[601369+(i<<2)|0]|0))^j)&255;g=g+1|0;}while(g>>>0<e>>>0)}a1c();e=c[2439330]|0;g=(e|0)==0;if(!g){f=e;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];f=c[3528484]|0;c[2076596]=f;j=c[2417276]|0;c[3541536]=j;c[1836236]=0;c[e+4184>>2]=3276;c[e+4176>>2]=2852;if(!g){g=e;gGC(g|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=f;c[2417276]=j;c[1836236]=-1;j=c[2439331]|0;f=(j|0)==0;if(!f){g=j;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];g=c[3528485]|0;c[2076596]=g;e=c[2417277]|0;c[3541536]=e;c[1836236]=1;i=c[3541320]|0;h=(c[3541316]|0)-1>>8;k=(h|0)<0;do{if(!k){l=0;m=0;do{c[j+76+(m<<2)>>2]=i+(m<<8);l=l+1&65535;m=l&65535;}while((m|0)<=(h|0));if(k){break}else{n=0;o=0}do{m=i+(o<<8)|0;c[j+76+(o+512<<2)>>2]=m;c[j+76+(o+768<<2)>>2]=m;n=n+1&65535;o=n&65535;}while((o|0)<=(h|0))}}while(0);h=c[3541332]|0;c[j+204>>2]=h;o=h+256|0;c[j+208>>2]=o;n=h+512|0;c[j+212>>2]=n;i=h+768|0;c[j+216>>2]=i;c[j+1228>>2]=h;c[j+1232>>2]=o;c[j+1236>>2]=n;c[j+1240>>2]=i;c[j+2252>>2]=h;c[j+3276>>2]=h;c[j+2256>>2]=o;c[j+3280>>2]=o;c[j+2260>>2]=n;c[j+3284>>2]=n;c[j+2264>>2]=i;c[j+3288>>2]=i;c[j+4172>>2]=1586;c[j+4176>>2]=2484;if(f){p=c[2433530]|0;c[2438119]=p;c[3528485]=g;c[2417277]=e;c[1836236]=-1;c[2113200]=27e3;return}f=j;gGC(f|0,9706056,76)|0;p=c[2433530]|0;c[2438119]=p;c[3528485]=g;c[2417277]=e;c[1836236]=-1;c[2113200]=27e3;return}function a$X(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a1c();a=c[2439330]|0;d=(a|0)==0;if(!d){e=a;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];e=c[3528484]|0;c[2076596]=e;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;c[a+4184>>2]=1462;c[a+4172>>2]=860;c[a+4176>>2]=1842;g=c[3541328]|0;h=0;i=0;while(1){c[a+76+(i<<2)>>2]=g+(i<<8);j=h+1&65535;if((j&65535)>95){k=0;l=0;break}else{h=j;i=j&65535}}while(1){i=g+(l<<8)|0;c[a+76+(l+512<<2)>>2]=i;c[a+76+(l+768<<2)>>2]=i;i=k+1&65535;if((i&65535)>95){break}else{k=i;l=i&65535}}l=c[3541334]|0;c[a+604>>2]=l;k=l+256|0;c[a+608>>2]=k;g=l+512|0;c[a+612>>2]=g;i=l+768|0;c[a+616>>2]=i;c[a+1628>>2]=l;c[a+1632>>2]=k;c[a+1636>>2]=g;c[a+1640>>2]=i;c[a+2652>>2]=l;c[a+3676>>2]=l;c[a+2656>>2]=k;c[a+3680>>2]=k;c[a+2660>>2]=g;c[a+3684>>2]=g;c[a+2664>>2]=i;c[a+3688>>2]=i;i=c[3541340]|0;c[a+668>>2]=i;g=i+256|0;c[a+672>>2]=g;k=i+512|0;c[a+676>>2]=k;l=i+768|0;c[a+680>>2]=l;c[a+1692>>2]=i;c[a+1696>>2]=g;c[a+1700>>2]=k;c[a+1704>>2]=l;c[a+2716>>2]=i;c[a+3740>>2]=i;c[a+2720>>2]=g;c[a+3744>>2]=g;c[a+2724>>2]=k;c[a+3748>>2]=k;c[a+2728>>2]=l;c[a+3752>>2]=l;if(d){m=c[2433530]|0;c[2438118]=m;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}d=a;gGC(d|0,9706056,76)|0;m=c[2433530]|0;c[2438118]=m;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}function a$Y(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0;a=c[3541322]|0;b=0;while(1){if((b|0)>=1024){d=0;break}e=9638528+(b<<2)|0;if((c[e>>2]|0)==0){f=45484;break}else{b=b+1|0}}do{if((f|0)==45484){b=gGq(a)|0;c[e>>2]=b;if((b|0)==0){d=0;break}gGz(b|0,0,a|0);d=b}}while(0);c[3541356]=d;a=c[3541328]|0;e=c[3541322]|0;gGC(d|0,a|0,e)|0;gGz(a|0,0,e|0);gGC(a|0,d|0,4096)|0;b=a+8192|0;a=d+4096|0;g=e-8192|0;gGC(b|0,a|0,g)|0;g=0;while(1){if((g|0)>=1024){f=45491;break}h=9638528+(g<<2)|0;if((c[h>>2]|0)==(d|0)){break}else{g=g+1|0}}if((f|0)==45491){c[3541356]=0;a1h();return}gGr(d);c[h>>2]=0;c[3541356]=0;a1h();return}function a$Z(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;a1c();a=0;while(1){if((a|0)>=1024){d=0;break}e=9638528+(a<<2)|0;if((c[e>>2]|0)==0){f=45496;break}else{a=a+1|0}}do{if((f|0)==45496){a=gGq(2048)|0;c[e>>2]=a;if((a|0)==0){d=0;break}gGz(a|0,0,2048);d=a}}while(0);c[3541338]=d;e=c[2439330]|0;f=(e|0)==0;if(!f){a=e;gGC(9706056,a|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];a=c[3528484]|0;c[2076596]=a;g=c[2417276]|0;c[3541536]=g;c[1836236]=0;c[e+4180>>2]=558;c[e+4184>>2]=674;c[e+332>>2]=d;h=d+256|0;c[e+336>>2]=h;i=d+512|0;c[e+340>>2]=i;j=d+768|0;c[e+344>>2]=j;k=d+1024|0;c[e+348>>2]=k;l=d+1280|0;c[e+352>>2]=l;m=d+1536|0;c[e+356>>2]=m;n=d+1792|0;c[e+360>>2]=n;c[e+1356>>2]=d;c[e+1360>>2]=h;c[e+1364>>2]=i;c[e+1368>>2]=j;c[e+1372>>2]=k;c[e+1376>>2]=l;c[e+1380>>2]=m;c[e+1384>>2]=n;c[e+2380>>2]=d;c[e+3404>>2]=d;c[e+2384>>2]=h;c[e+3408>>2]=h;c[e+2388>>2]=i;c[e+3412>>2]=i;c[e+2392>>2]=j;c[e+3416>>2]=j;c[e+2396>>2]=k;c[e+3420>>2]=k;c[e+2400>>2]=l;c[e+3424>>2]=l;c[e+2404>>2]=m;c[e+3428>>2]=m;c[e+2408>>2]=n;c[e+3432>>2]=n;n=c[3541334]|0;m=n+1024|0;c[e+396>>2]=m;l=n+1280|0;c[e+400>>2]=l;k=n+1536|0;c[e+404>>2]=k;j=n+1792|0;c[e+408>>2]=j;c[e+1420>>2]=m;c[e+1424>>2]=l;c[e+1428>>2]=k;c[e+1432>>2]=j;c[e+2444>>2]=m;c[e+3468>>2]=m;c[e+2448>>2]=l;c[e+3472>>2]=l;c[e+2452>>2]=k;c[e+3476>>2]=k;c[e+2456>>2]=j;c[e+3480>>2]=j;j=c[3541328]|0;k=96;l=96;while(1){c[e+76+(l<<2)>>2]=j+((l<<8)-8192);m=k+1&65535;if((m&65535)>127){o=96;p=96;break}else{k=m;l=m&65535}}while(1){l=j+((p<<8)-8192)|0;c[e+76+(p+512<<2)>>2]=l;c[e+76+(p+768<<2)>>2]=l;l=o+1&65535;if((l&65535)>127){break}else{o=l;p=l&65535}}if(f){q=c[2433530]|0;c[2438118]=q;c[3528484]=a;c[2417276]=g;c[1836236]=-1;return}f=e;gGC(f|0,9706056,76)|0;q=c[2433530]|0;c[2438118]=q;c[3528484]=a;c[2417276]=g;c[1836236]=-1;return}function a$_(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a1c();a=c[2439330]|0;d=(a|0)==0;if(!d){e=a;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];e=c[3528484]|0;c[2076596]=e;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;g=c[3541328]|0;h=0;i=0;while(1){c[a+76+(i<<2)>>2]=g+(i<<8);j=h+1&65535;if((j&65535)>127){k=0;l=0;break}else{h=j;i=j&65535}}while(1){i=g+(l<<8)|0;c[a+76+(l+512<<2)>>2]=i;c[a+76+(l+768<<2)>>2]=i;i=k+1&65535;if((i&65535)>127){break}else{k=i;l=i&65535}}l=c[3541334]|0;c[a+588>>2]=l;k=l+256|0;c[a+592>>2]=k;g=l+512|0;c[a+596>>2]=g;i=l+768|0;c[a+600>>2]=i;h=l+1024|0;c[a+604>>2]=h;j=l+1280|0;c[a+608>>2]=j;m=l+1536|0;c[a+612>>2]=m;n=l+1792|0;c[a+616>>2]=n;c[a+1612>>2]=l;c[a+1616>>2]=k;c[a+1620>>2]=g;c[a+1624>>2]=i;c[a+1628>>2]=h;c[a+1632>>2]=j;c[a+1636>>2]=m;c[a+1640>>2]=n;c[a+2636>>2]=l;c[a+3660>>2]=l;c[a+2640>>2]=k;c[a+3664>>2]=k;c[a+2644>>2]=g;c[a+3668>>2]=g;c[a+2648>>2]=i;c[a+3672>>2]=i;c[a+2652>>2]=h;c[a+3676>>2]=h;c[a+2656>>2]=j;c[a+3680>>2]=j;c[a+2660>>2]=m;c[a+3684>>2]=m;c[a+2664>>2]=n;c[a+3688>>2]=n;c[a+4184>>2]=916;if(d){o=c[2433530]|0;c[2438118]=o;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}d=a;gGC(d|0,9706056,76)|0;o=c[2433530]|0;c[2438118]=o;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}function a$$(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;a1c();a=c[2439330]|0;d=(a|0)==0;if(!d){f=a;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];f=c[3528484]|0;c[2076596]=f;g=c[2417276]|0;c[3541536]=g;c[1836236]=0;h=c[3541328]|0;i=0;j=0;while(1){c[a+76+(j<<2)>>2]=h+(j<<8);k=i+1&65535;if((k&65535)>127){l=0;m=0;break}else{i=k;j=k&65535}}while(1){j=h+(m<<8)|0;c[a+76+(m+512<<2)>>2]=j;c[a+76+(m+768<<2)>>2]=j;j=l+1&65535;if((j&65535)>127){break}else{l=j;m=j&65535}}m=c[3541334]|0;c[a+588>>2]=m;l=m+256|0;c[a+592>>2]=l;h=m+512|0;c[a+596>>2]=h;j=m+768|0;c[a+600>>2]=j;i=m+1024|0;c[a+604>>2]=i;k=m+1280|0;c[a+608>>2]=k;n=m+1536|0;c[a+612>>2]=n;o=m+1792|0;c[a+616>>2]=o;c[a+1612>>2]=m;c[a+1616>>2]=l;c[a+1620>>2]=h;c[a+1624>>2]=j;c[a+1628>>2]=i;c[a+1632>>2]=k;c[a+1636>>2]=n;c[a+1640>>2]=o;c[a+2636>>2]=m;c[a+3660>>2]=m;c[a+2640>>2]=l;c[a+3664>>2]=l;c[a+2644>>2]=h;c[a+3668>>2]=h;c[a+2648>>2]=j;c[a+3672>>2]=j;c[a+2652>>2]=i;c[a+3676>>2]=i;c[a+2656>>2]=k;c[a+3680>>2]=k;c[a+2660>>2]=n;c[a+3684>>2]=n;c[a+2664>>2]=o;c[a+3688>>2]=o;c[a+4184>>2]=262;if(!d){d=a;gGC(d|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=f;c[2417276]=g;c[1836236]=-1;g=0;while(1){if((g|0)>=1024){p=0;break}q=9638528+(g<<2)|0;if((c[q>>2]|0)==0){r=45528;break}else{g=g+1|0}}do{if((r|0)==45528){g=gGq(32768)|0;c[q>>2]=g;if((g|0)==0){p=0;break}gGz(g|0,0,32768);p=g}}while(0);q=c[3541328]|0;gGC(p|0,q|0,32768)|0;g=0;while(1){f=g<<10;d=q+f|0;a=p+((e[601024+(g<<1)>>1]|0)<<12|f&3072)|0;gGC(d|0,a|0,1024)|0;a=g+1|0;if((a|0)<32){g=a}else{s=0;break}}while(1){if((s|0)>=1024){r=45537;break}t=9638528+(s<<2)|0;if((c[t>>2]|0)==(p|0)){break}else{s=s+1|0}}if((r|0)==45537){return}gGr(p);c[t>>2]=0;return}function a$0(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a1c();a=c[2439330]|0;d=(a|0)==0;if(!d){e=a;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];e=c[3528484]|0;c[2076596]=e;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;g=c[3541328]|0;h=0;i=0;while(1){c[a+76+(i<<2)>>2]=g+(i<<8);j=h+1&65535;if((j&65535)>127){k=0;l=0;break}else{h=j;i=j&65535}}while(1){i=g+(l<<8)|0;c[a+76+(l+512<<2)>>2]=i;c[a+76+(l+768<<2)>>2]=i;i=k+1&65535;if((i&65535)>127){break}else{k=i;l=i&65535}}l=c[3541334]|0;c[a+588>>2]=l;k=l+256|0;c[a+592>>2]=k;g=l+512|0;c[a+596>>2]=g;i=l+768|0;c[a+600>>2]=i;h=l+1024|0;c[a+604>>2]=h;j=l+1280|0;c[a+608>>2]=j;m=l+1536|0;c[a+612>>2]=m;n=l+1792|0;c[a+616>>2]=n;c[a+1612>>2]=l;c[a+1616>>2]=k;c[a+1620>>2]=g;c[a+1624>>2]=i;c[a+1628>>2]=h;c[a+1632>>2]=j;c[a+1636>>2]=m;c[a+1640>>2]=n;c[a+2636>>2]=l;c[a+3660>>2]=l;c[a+2640>>2]=k;c[a+3664>>2]=k;c[a+2644>>2]=g;c[a+3668>>2]=g;c[a+2648>>2]=i;c[a+3672>>2]=i;c[a+2652>>2]=h;c[a+3676>>2]=h;c[a+2656>>2]=j;c[a+3680>>2]=j;c[a+2660>>2]=m;c[a+3684>>2]=m;c[a+2664>>2]=n;c[a+3688>>2]=n;if(d){o=c[2433530]|0;c[2438118]=o;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}d=a;gGC(d|0,9706056,76)|0;o=c[2433530]|0;c[2438118]=o;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}function a$1(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=0;while(1){if((a|0)>=1024){d=0;break}e=9638528+(a<<2)|0;if((c[e>>2]|0)==0){f=45551;break}else{a=a+1|0}}do{if((f|0)==45551){a=gGq(16384)|0;c[e>>2]=a;if((a|0)==0){d=0;break}gGz(a|0,0,16384);d=a}}while(0);c[3541356]=d;e=c[3541328]|0;gGC(d|0,e|0,16384)|0;a=e+8192|0;g=d+2048|0;gGC(a|0,g|0,2048)|0;g=e+2048|0;a=d+4096|0;gGC(g|0,a|0,2048)|0;a=e+10240|0;g=d+6144|0;gGC(a|0,g|0,2048)|0;g=e+4096|0;a=d+8192|0;gGC(g|0,a|0,2048)|0;a=e+12288|0;g=d+10240|0;gGC(a|0,g|0,2048)|0;g=e+6144|0;a=d+12288|0;gGC(g|0,a|0,2048)|0;a=e+14336|0;e=d+14336|0;gGC(a|0,e|0,2048)|0;e=0;while(1){if((e|0)>=1024){break}h=9638528+(e<<2)|0;if((c[h>>2]|0)==(d|0)){f=45556;break}else{e=e+1|0}}if((f|0)==45556){gGr(d);c[h>>2]=0}c[3541356]=0;a1c();h=c[2439330]|0;d=(h|0)==0;if(!d){f=h;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];f=c[3528484]|0;c[2076596]=f;e=c[2417276]|0;c[3541536]=e;c[1836236]=0;a=c[3541328]|0;g=0;i=0;while(1){c[h+76+(i<<2)>>2]=a+(i<<8);j=g+1&65535;if((j&65535)>95){k=0;l=0;break}else{g=j;i=j&65535}}while(1){i=a+(l<<8)|0;c[h+76+(l+512<<2)>>2]=i;c[h+76+(l+768<<2)>>2]=i;i=k+1&65535;if((i&65535)>95){break}else{k=i;l=i&65535}}l=c[3541334]|0;c[h+588>>2]=l;k=l+256|0;c[h+592>>2]=k;a=l+512|0;c[h+596>>2]=a;i=l+768|0;c[h+600>>2]=i;g=l+1024|0;c[h+604>>2]=g;j=l+1280|0;c[h+608>>2]=j;m=l+1536|0;c[h+612>>2]=m;n=l+1792|0;c[h+616>>2]=n;c[h+1612>>2]=l;c[h+1616>>2]=k;c[h+1620>>2]=a;c[h+1624>>2]=i;c[h+1628>>2]=g;c[h+1632>>2]=j;c[h+1636>>2]=m;c[h+1640>>2]=n;c[h+2636>>2]=l;c[h+3660>>2]=l;c[h+2640>>2]=k;c[h+3664>>2]=k;c[h+2644>>2]=a;c[h+3668>>2]=a;c[h+2648>>2]=i;c[h+3672>>2]=i;c[h+2652>>2]=g;c[h+3676>>2]=g;c[h+2656>>2]=j;c[h+3680>>2]=j;c[h+2660>>2]=m;c[h+3684>>2]=m;c[h+2664>>2]=n;c[h+3688>>2]=n;if(d){o=c[2433530]|0;c[2438118]=o;c[3528484]=f;c[2417276]=e;c[1836236]=-1;return}d=h;gGC(d|0,9706056,76)|0;o=c[2433530]|0;c[2438118]=o;c[3528484]=f;c[2417276]=e;c[1836236]=-1;return}function a$2(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0;a=0;while(1){if((a|0)>=1024){d=0;break}e=9638528+(a<<2)|0;if((c[e>>2]|0)==0){f=45570;break}else{a=a+1|0}}do{if((f|0)==45570){a=gGq(16384)|0;c[e>>2]=a;if((a|0)==0){d=0;break}gGz(a|0,0,16384);d=a}}while(0);c[3541356]=d;e=c[3541328]|0;gGC(d|0,e|0,16384)|0;a=e+8192|0;g=d+2048|0;gGC(a|0,g|0,2048)|0;g=e+2048|0;a=d+4096|0;gGC(g|0,a|0,2048)|0;a=e+10240|0;g=d+6144|0;gGC(a|0,g|0,2048)|0;g=e+4096|0;a=d+8192|0;gGC(g|0,a|0,2048)|0;a=e+12288|0;g=d+10240|0;gGC(a|0,g|0,2048)|0;g=e+6144|0;a=d+12288|0;gGC(g|0,a|0,2048)|0;a=e+14336|0;e=d+14336|0;gGC(a|0,e|0,2048)|0;e=0;while(1){if((e|0)>=1024){break}h=9638528+(e<<2)|0;if((c[h>>2]|0)==(d|0)){f=45575;break}else{e=e+1|0}}if((f|0)==45575){gGr(d);c[h>>2]=0}c[3541356]=0;a$3();h=c[2439330]|0;d=(h|0)==0;if(!d){f=h;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];f=c[3528484]|0;c[2076596]=f;e=c[2417276]|0;c[3541536]=e;c[1836236]=0;c[h+4180>>2]=1312;c[h+4184>>2]=2272;if(d){i=c[2433530]|0;c[2438118]=i;c[3528484]=f;c[2417276]=e;c[1836236]=-1;return}d=h;gGC(d|0,9706056,76)|0;i=c[2433530]|0;c[2438118]=i;c[3528484]=f;c[2417276]=e;c[1836236]=-1;return}function a$3(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=c[2439330]|0;d=(a|0)==0;if(!d){e=a;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];e=c[3528484]|0;c[2076596]=e;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;gGz(a+76|0,0,2048);g=0;h=0;while(1){c[a+76+(h+512<<2)>>2]=0;c[a+76+(h+768<<2)>>2]=0;i=g+1&65535;if((i&65535)>255){break}else{g=i;h=i&65535}}c[a+4180>>2]=3110;c[a+4184>>2]=3226;h=c[3541328]|0;g=0;i=0;while(1){c[a+76+(i<<2)>>2]=h+(i<<8);j=g+1&65535;if((j&65535)>87){k=0;l=0;break}else{g=j;i=j&65535}}while(1){i=h+(l<<8)|0;c[a+76+(l+512<<2)>>2]=i;c[a+76+(l+768<<2)>>2]=i;i=k+1&65535;if((i&65535)>87){break}else{k=i;l=i&65535}}l=c[3541334]|0;c[a+460>>2]=l;c[a+464>>2]=l+256;c[a+468>>2]=l+512;c[a+472>>2]=l+768;c[a+476>>2]=l+1024;c[a+480>>2]=l+1280;c[a+484>>2]=l+1536;c[a+488>>2]=l+1792;c[a+492>>2]=l+2048;c[a+496>>2]=l+2304;c[a+500>>2]=l+2560;c[a+504>>2]=l+2816;c[a+508>>2]=l+3072;c[a+512>>2]=l+3328;c[a+516>>2]=l+3584;c[a+520>>2]=l+3840;k=96;h=96;while(1){c[a+76+(h+256<<2)>>2]=l+((h<<8)-24576);i=k+1&65535;if((i&65535)>111){m=96;n=96;break}else{k=i;h=i&65535}}while(1){h=l+((n<<8)-24576)|0;c[a+76+(n+512<<2)>>2]=h;c[a+76+(n+768<<2)>>2]=h;h=m+1&65535;if((h&65535)>111){break}else{m=h;n=h&65535}}n=c[3541340]|0;c[a+652>>2]=n;m=n+256|0;c[a+656>>2]=m;l=n+512|0;c[a+660>>2]=l;h=n+768|0;c[a+664>>2]=h;c[a+1676>>2]=n;c[a+1680>>2]=m;c[a+1684>>2]=l;c[a+1688>>2]=h;c[a+2700>>2]=n;c[a+3724>>2]=n;c[a+2704>>2]=m;c[a+3728>>2]=m;c[a+2708>>2]=l;c[a+3732>>2]=l;c[a+2712>>2]=h;c[a+3736>>2]=h;h=c[3541366]|0;c[a+684>>2]=h;c[a+2732>>2]=h;c[a+3756>>2]=h;if(d){o=c[2433530]|0;c[2438118]=o;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}d=a;gGC(d|0,9706056,76)|0;o=c[2433530]|0;c[2438118]=o;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}function a$4(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[3541322]|0;b=0;while(1){if((b|0)>=1024){d=0;break}e=9638528+(b<<2)|0;if((c[e>>2]|0)==0){f=45601;break}else{b=b+1|0}}do{if((f|0)==45601){b=gGq(a)|0;c[e>>2]=b;if((b|0)==0){d=0;break}gGz(b|0,0,a|0);d=b}}while(0);c[3541356]=d;a=c[3541328]|0;e=c[3541322]|0;gGC(d|0,a|0,e)|0;e=a+9216|0;gGC(e|0,d|0,1024)|0;e=a+7168|0;b=d+1024|0;gGC(e|0,b|0,1024)|0;b=a+18432|0;e=d+2048|0;gGC(b|0,e|0,1024)|0;e=a+3072|0;b=d+3072|0;gGC(e|0,b|0,1024)|0;b=a+17408|0;e=d+4096|0;gGC(b|0,e|0,1024)|0;e=d+5120|0;gGC(a|0,e|0,1024)|0;e=a+6144|0;b=d+6144|0;gGC(e|0,b|0,1024)|0;b=a+10240|0;e=d+7168|0;gGC(b|0,e|0,1024)|0;e=a+13312|0;b=d+8192|0;gGC(e|0,b|0,1024)|0;b=a+19456|0;e=d+9216|0;gGC(b|0,e|0,1024)|0;e=a+20480|0;b=d+10240|0;gGC(e|0,b|0,1024)|0;b=a+1024|0;e=d+11264|0;gGC(b|0,e|0,1024)|0;e=a+8192|0;b=d+12288|0;gGC(e|0,b|0,1024)|0;b=a+14336|0;e=d+13312|0;gGC(b|0,e|0,1024)|0;e=a+4096|0;b=d+14336|0;gGC(e|0,b|0,1024)|0;b=a+16384|0;e=d+15360|0;gGC(b|0,e|0,1024)|0;e=a+2048|0;b=d+16384|0;gGC(e|0,b|0,1024)|0;b=a+21504|0;e=d+17408|0;gGC(b|0,e|0,1024)|0;e=a+11264|0;b=d+18432|0;gGC(e|0,b|0,1024)|0;b=a+5120|0;e=d+19456|0;gGC(b|0,e|0,1024)|0;e=a+12288|0;b=d+20480|0;gGC(e|0,b|0,1024)|0;b=a+15360|0;a=d+21504|0;gGC(b|0,a|0,1024)|0;a=0;while(1){if((a|0)>=1024){f=45609;break}g=9638528+(a<<2)|0;if((c[g>>2]|0)==(d|0)){break}else{a=a+1|0}}if((f|0)==45609){c[3541356]=0;a$3();return}gGr(d);c[g>>2]=0;c[3541356]=0;a$3();return}function a$5(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a1c();a=c[3541322]|0;d=0;while(1){if((d|0)>=1024){e=0;break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==0){g=45613;break}else{d=d+1|0}}do{if((g|0)==45613){d=gGq(a)|0;c[f>>2]=d;if((d|0)==0){e=0;break}gGz(d|0,0,a|0);e=d}}while(0);c[3541356]=e;a=c[3541328]|0;f=c[3541322]|0;gGC(e|0,a|0,f)|0;gGC(a|0,e|0,2048)|0;f=a+8192|0;d=e+2048|0;gGC(f|0,d|0,2048)|0;d=a+2048|0;f=e+4096|0;gGC(d|0,f|0,2048)|0;f=a+10240|0;d=e+6144|0;gGC(f|0,d|0,2048)|0;d=a+4096|0;f=e+8192|0;gGC(d|0,f|0,2048)|0;f=a+12288|0;d=e+10240|0;gGC(f|0,d|0,2048)|0;d=a+6144|0;f=e+12288|0;gGC(d|0,f|0,2048)|0;f=a+14336|0;a=e+14336|0;gGC(f|0,a|0,2048)|0;a=0;while(1){if((a|0)>=1024){break}h=9638528+(a<<2)|0;if((c[h>>2]|0)==(e|0)){g=45618;break}else{a=a+1|0}}if((g|0)==45618){gGr(e);c[h>>2]=0}c[3541356]=0;h=c[2439330]|0;e=(h|0)==0;if(!e){g=h;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];g=c[3528484]|0;c[2076596]=g;a=c[2417276]|0;c[3541536]=a;c[1836236]=0;f=c[3541334]|0;c[h+588>>2]=f;d=f+256|0;c[h+592>>2]=d;i=f+512|0;c[h+596>>2]=i;j=f+768|0;c[h+600>>2]=j;k=f+1024|0;c[h+604>>2]=k;l=f+1280|0;c[h+608>>2]=l;m=f+1536|0;c[h+612>>2]=m;n=f+1792|0;c[h+616>>2]=n;c[h+1612>>2]=f;c[h+1616>>2]=d;c[h+1620>>2]=i;c[h+1624>>2]=j;c[h+1628>>2]=k;c[h+1632>>2]=l;c[h+1636>>2]=m;c[h+1640>>2]=n;c[h+2636>>2]=f;c[h+3660>>2]=f;c[h+2640>>2]=d;c[h+3664>>2]=d;c[h+2644>>2]=i;c[h+3668>>2]=i;c[h+2648>>2]=j;c[h+3672>>2]=j;c[h+2652>>2]=k;c[h+3676>>2]=k;c[h+2656>>2]=l;c[h+3680>>2]=l;c[h+2660>>2]=m;c[h+3684>>2]=m;c[h+2664>>2]=n;c[h+3688>>2]=n;if(e){o=c[2433530]|0;c[2438118]=o;c[3528484]=g;c[2417276]=a;c[1836236]=-1;return}e=h;gGC(e|0,9706056,76)|0;o=c[2433530]|0;c[2438118]=o;c[3528484]=g;c[2417276]=a;c[1836236]=-1;return}function a$6(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[2439330]|0;if((a|0)!=0){d=a;gGC(9706056,d|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];d=c[3528484]|0;c[2076596]=d;e=c[2417276]|0;c[3541536]=e;c[1836236]=0;gGz(a+76|0,0,2048);f=0;g=0;while(1){c[a+76+(g+512<<2)>>2]=0;c[a+76+(g+768<<2)>>2]=0;h=f+1&65535;if((h&65535)>255){break}else{f=h;g=h&65535}}c[a+4180>>2]=1574;c[a+4184>>2]=2998;g=c[3541328]|0;f=0;h=0;while(1){c[a+76+(h<<2)>>2]=g+(h<<8);i=f+1&65535;if((i&65535)>95){j=0;k=0;break}else{f=i;h=i&65535}}while(1){h=g+(k<<8)|0;c[a+76+(k+512<<2)>>2]=h;c[a+76+(k+768<<2)>>2]=h;h=j+1&65535;if((h&65535)>95){break}else{j=h;k=h&65535}}k=c[3541334]|0;c[a+460>>2]=k;c[a+464>>2]=k+256;c[a+468>>2]=k+512;c[a+472>>2]=k+768;c[a+476>>2]=k+1024;c[a+480>>2]=k+1280;c[a+484>>2]=k+1536;c[a+488>>2]=k+1792;c[a+492>>2]=k+2048;c[a+496>>2]=k+2304;c[a+500>>2]=k+2560;c[a+504>>2]=k+2816;c[a+508>>2]=k+3072;c[a+512>>2]=k+3328;c[a+516>>2]=k+3584;c[a+520>>2]=k+3840;j=96;h=96;while(1){c[a+76+(h+256<<2)>>2]=k+((h<<8)-24576);f=j+1&65535;if((f&65535)>111){l=96;m=96;break}else{j=f;h=f&65535}}while(1){h=k+((m<<8)-24576)|0;c[a+76+(m+512<<2)>>2]=h;c[a+76+(m+768<<2)>>2]=h;h=l+1&65535;if((h&65535)>111){break}else{l=h;m=h&65535}}c[a+524>>2]=g+24576;c[a+528>>2]=g+24832;c[a+532>>2]=g+25088;c[a+536>>2]=g+25344;c[a+540>>2]=g+25600;c[a+544>>2]=g+25856;c[a+548>>2]=g+26112;c[a+552>>2]=g+26368;c[a+556>>2]=g+26624;c[a+560>>2]=g+26880;c[a+564>>2]=g+27136;c[a+568>>2]=g+27392;c[a+572>>2]=g+27648;c[a+576>>2]=g+27904;c[a+580>>2]=g+28160;c[a+584>>2]=g+28416;m=112;l=112;while(1){k=g+((l<<8)-4096)|0;c[a+76+(l+512<<2)>>2]=k;c[a+76+(l+768<<2)>>2]=k;k=m+1&65535;if((k&65535)>127){break}else{m=k;l=k&65535}}l=c[3541340]|0;c[a+652>>2]=l;m=l+256|0;c[a+656>>2]=m;g=l+512|0;c[a+660>>2]=g;k=l+768|0;c[a+664>>2]=k;c[a+1676>>2]=l;c[a+1680>>2]=m;c[a+1684>>2]=g;c[a+1688>>2]=k;c[a+2700>>2]=l;c[a+3724>>2]=l;c[a+2704>>2]=m;c[a+3728>>2]=m;c[a+2708>>2]=g;c[a+3732>>2]=g;c[a+2712>>2]=k;c[a+3736>>2]=k;k=c[3541366]|0;c[a+684>>2]=k;c[a+2732>>2]=k;c[a+3756>>2]=k;k=a;gGC(k|0,9706056,76)|0;c[2438118]=c[2433530];c[3528484]=d;c[2417276]=e;c[1836236]=-1;return}function a$7(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=c[2439330]|0;d=(a|0)==0;if(!d){e=a;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];e=c[3528484]|0;c[2076596]=e;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;gGz(a+76|0,0,2048);g=0;h=0;while(1){c[a+76+(h+512<<2)>>2]=0;c[a+76+(h+768<<2)>>2]=0;i=g+1&65535;if((i&65535)>255){break}else{g=i;h=i&65535}}c[a+4180>>2]=2972;c[a+4184>>2]=226;h=c[3541328]|0;g=(c[3541322]|0)-1>>8;i=(g|0)<0;do{if(!i){j=0;k=0;do{c[a+76+(k<<2)>>2]=h+(k<<8);j=j+1&65535;k=j&65535;}while((k|0)<=(g|0));if(i){break}else{l=0;m=0}do{k=h+(m<<8)|0;c[a+76+(m+512<<2)>>2]=k;c[a+76+(m+768<<2)>>2]=k;l=l+1&65535;m=l&65535;}while((m|0)<=(g|0))}}while(0);g=c[3541334]|0;c[a+460>>2]=g;m=g+256|0;c[a+464>>2]=m;l=g+512|0;c[a+468>>2]=l;h=g+768|0;c[a+472>>2]=h;i=g+1024|0;c[a+476>>2]=i;k=g+1280|0;c[a+480>>2]=k;j=g+1536|0;c[a+484>>2]=j;n=g+1792|0;c[a+488>>2]=n;c[a+1484>>2]=g;c[a+1488>>2]=m;c[a+1492>>2]=l;c[a+1496>>2]=h;c[a+1500>>2]=i;c[a+1504>>2]=k;c[a+1508>>2]=j;c[a+1512>>2]=n;c[a+2508>>2]=g;c[a+3532>>2]=g;c[a+2512>>2]=m;c[a+3536>>2]=m;c[a+2516>>2]=l;c[a+3540>>2]=l;c[a+2520>>2]=h;c[a+3544>>2]=h;c[a+2524>>2]=i;c[a+3548>>2]=i;c[a+2528>>2]=k;c[a+3552>>2]=k;c[a+2532>>2]=j;c[a+3556>>2]=j;c[a+2536>>2]=n;c[a+3560>>2]=n;n=c[3541340]|0;c[a+652>>2]=n;j=n+256|0;c[a+656>>2]=j;k=n+512|0;c[a+660>>2]=k;i=n+768|0;c[a+664>>2]=i;c[a+1676>>2]=n;c[a+1680>>2]=j;c[a+1684>>2]=k;c[a+1688>>2]=i;c[a+2700>>2]=n;c[a+3724>>2]=n;c[a+2704>>2]=j;c[a+3728>>2]=j;c[a+2708>>2]=k;c[a+3732>>2]=k;c[a+2712>>2]=i;c[a+3736>>2]=i;i=c[3541366]|0;c[a+684>>2]=i;c[a+2732>>2]=i;c[a+3756>>2]=i;if(d){o=c[2433530]|0;c[2438118]=o;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}d=a;gGC(d|0,9706056,76)|0;o=c[2433530]|0;c[2438118]=o;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}function a$8(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a1c();a=c[2439330]|0;d=(a|0)==0;if(!d){e=a;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];e=c[3528484]|0;c[2076596]=e;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;g=c[3541328]|0;h=0;i=0;while(1){c[a+76+(i<<2)>>2]=g+(i<<8);j=h+1&65535;if((j&65535)>95){k=0;l=0;break}else{h=j;i=j&65535}}while(1){i=g+(l<<8)|0;c[a+76+(l+512<<2)>>2]=i;c[a+76+(l+768<<2)>>2]=i;i=k+1&65535;if((i&65535)>95){break}else{k=i;l=i&65535}}l=c[3541334]|0;c[a+588>>2]=l;k=l+256|0;c[a+592>>2]=k;g=l+512|0;c[a+596>>2]=g;i=l+768|0;c[a+600>>2]=i;h=l+1024|0;c[a+604>>2]=h;j=l+1280|0;c[a+608>>2]=j;m=l+1536|0;c[a+612>>2]=m;n=l+1792|0;c[a+616>>2]=n;c[a+1612>>2]=l;c[a+1616>>2]=k;c[a+1620>>2]=g;c[a+1624>>2]=i;c[a+1628>>2]=h;c[a+1632>>2]=j;c[a+1636>>2]=m;c[a+1640>>2]=n;c[a+2636>>2]=l;c[a+3660>>2]=l;c[a+2640>>2]=k;c[a+3664>>2]=k;c[a+2644>>2]=g;c[a+3668>>2]=g;c[a+2648>>2]=i;c[a+3672>>2]=i;c[a+2652>>2]=h;c[a+3676>>2]=h;c[a+2656>>2]=j;c[a+3680>>2]=j;c[a+2660>>2]=m;c[a+3684>>2]=m;c[a+2664>>2]=n;c[a+3688>>2]=n;if(d){o=c[2433530]|0;c[2438118]=o;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}d=a;gGC(d|0,9706056,76)|0;o=c[2433530]|0;c[2438118]=o;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}function a$9(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a1c();a=c[2439330]|0;d=(a|0)==0;if(!d){e=a;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];e=c[3528484]|0;c[2076596]=e;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;g=c[3541328]|0;h=0;i=0;while(1){c[a+76+(i<<2)>>2]=g+(i<<8);j=h+1&65535;if((j&65535)>71){k=0;l=0;break}else{h=j;i=j&65535}}while(1){i=g+(l<<8)|0;c[a+76+(l+512<<2)>>2]=i;c[a+76+(l+768<<2)>>2]=i;i=k+1&65535;if((i&65535)>71){break}else{k=i;l=i&65535}}c[a+4184>>2]=2884;if(d){m=c[2433530]|0;c[2438118]=m;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}d=a;gGC(d|0,9706056,76)|0;m=c[2433530]|0;c[2438118]=m;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}function a0a(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=c[3541322]|0;if((d|0)==0){e=0}else{f=c[3541328]|0;g=c[3541324]|0;h=0;while(1){i=a[f+h|0]|0;j=i&255;k=(j&2|0)==0?i:i^64;i=(j&32|0)==0?k:k^4;if((h&1|0)==0){l=(i&255)>>>2<<6&64|i&-69|(i&255)>>>6<<2&4}else{l=i}a[g+h|0]=l;i=h+1|0;if(i>>>0<d>>>0){h=i}else{e=d;break}}}a1c();d=c[2439330]|0;h=(d|0)==0;if(!h){l=d;gGC(9706056,l|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];l=c[3528484]|0;c[2076596]=l;g=c[2417276]|0;c[3541536]=g;c[1836236]=0;c[d+4184>>2]=2748;f=c[3541324]|0;i=c[3541328]|0;k=e>>>0>16383?63:e-1>>8;if((k|0)>=0){e=0;j=0;do{m=j<<8;c[d+76+(j+512<<2)>>2]=f+m;c[d+76+(j+768<<2)>>2]=i+m;e=e+1&65535;j=e&65535;}while((j|0)<=(k|0))}if(h){n=c[2433530]|0;c[2438118]=n;c[3528484]=l;c[2417276]=g;c[1836236]=-1;return}h=d;gGC(h|0,9706056,76)|0;n=c[2433530]|0;c[2438118]=n;c[3528484]=l;c[2417276]=g;c[1836236]=-1;return}function a0b(){var a=0,d=0,e=0,f=0;a=c[2439330]|0;d=(a|0)==0;if(!d){e=a;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];e=c[3528484]|0;c[2076596]=e;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;c[a+4184>>2]=458;if(!d){d=a;gGC(d|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}function a0c(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[3541322]|0;b=0;while(1){if((b|0)>=1024){d=0;break}e=9638528+(b<<2)|0;if((c[e>>2]|0)==0){f=45694;break}else{b=b+1|0}}do{if((f|0)==45694){b=gGq(a)|0;c[e>>2]=b;if((b|0)==0){d=0;break}gGz(b|0,0,a|0);d=b}}while(0);c[3541356]=d;a=c[3541328]|0;e=c[3541322]|0;gGC(d|0,a|0,e)|0;gGC(a|0,d|0,2048)|0;e=a+8192|0;b=d+2048|0;gGC(e|0,b|0,2048)|0;b=a+2048|0;e=d+4096|0;gGC(b|0,e|0,2048)|0;e=a+10240|0;b=d+6144|0;gGC(e|0,b|0,2048)|0;b=a+4096|0;e=d+8192|0;gGC(b|0,e|0,2048)|0;e=a+12288|0;b=d+10240|0;gGC(e|0,b|0,2048)|0;b=a+6144|0;e=d+12288|0;gGC(b|0,e|0,2048)|0;e=a+14336|0;a=d+14336|0;gGC(e|0,a|0,2048)|0;a=0;while(1){if((a|0)>=1024){f=45702;break}g=9638528+(a<<2)|0;if((c[g>>2]|0)==(d|0)){break}else{a=a+1|0}}if((f|0)==45702){c[3541356]=0;a1c();return}gGr(d);c[g>>2]=0;c[3541356]=0;a1c();return}function a0d(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;b=i;i=i+480|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;l=b+360|0;m=b+472|0;n=0;while(1){if((n|0)>=1024){o=0;break}p=9638528+(n<<2)|0;if((c[p>>2]|0)==0){q=45706;break}else{n=n+1|0}}do{if((q|0)==45706){n=gGq(2048)|0;c[p>>2]=n;if((n|0)==0){o=0;break}gGz(n|0,0,2048);o=n}}while(0);p=c[3541348]|0;n=0;while(1){if((n|0)>=1024){r=0;break}s=9638528+(n<<2)|0;if((c[s>>2]|0)==0){q=45711;break}else{n=n+1|0}}do{if((q|0)==45711){n=gGq(p)|0;c[s>>2]=n;if((n|0)==0){r=0;break}gGz(n|0,0,p|0);r=n}}while(0);c[3541356]=r;p=(c[3541318]|0)+(c[3541326]|0)+(c[3541312]|0)|0;do{if((c[3542200]|0)!=0){s=l+108|0;c[s>>2]=0;n=l+100|0;c[n>>2]=0;t=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[t&16383](l,p)|0;if((c[s>>2]|0)==0){break}s=c[n>>2]|0;c[m>>2]=9534384;n=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[n&16383](m,p,0)|0;if((s|0)<1){break}gzL(r,0,p)|0}}while(0);p=(c[3541356]|0)+4096|0;r=(c[3541326]|0)+2+(c[3541318]|0)+(c[3541312]|0)|0;do{if((c[3542200]|0)!=0){m=j+108|0;c[m>>2]=0;l=j+100|0;c[l>>2]=0;s=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[s&16383](j,r)|0;if((c[m>>2]|0)==0){break}m=c[l>>2]|0;c[k>>2]=9534384;l=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[l&16383](k,r,0)|0;if((m|0)<1){break}gzL(p,0,r)|0}}while(0);r=(c[3541326]|0)+1+(c[3541318]|0)+(c[3541312]|0)|0;do{if((c[3542200]|0)!=0){p=g+108|0;c[p>>2]=0;k=g+100|0;c[k>>2]=0;j=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[j&16383](g,r)|0;if((c[p>>2]|0)==0){break}p=c[k>>2]|0;c[h>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](h,r,0)|0;if((p|0)<1){break}gzL(o,0,r)|0}}while(0);r=c[3541356]|0;h=r+2048|0;gGC(h|0,o|0,512)|0;h=r+3072|0;g=o+512|0;gGC(h|0,g|0,512)|0;h=r+2560|0;p=o+1024|0;gGC(h|0,p|0,512)|0;h=r+3584|0;r=o+1536|0;gGC(h|0,r|0,512)|0;h=(c[3541326]|0)+3+(c[3541318]|0)+(c[3541312]|0)|0;do{if((c[3542200]|0)!=0){k=e+108|0;c[k>>2]=0;j=e+100|0;c[j>>2]=0;m=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[m&16383](e,h)|0;if((c[k>>2]|0)==0){break}k=c[j>>2]|0;c[f>>2]=9534384;j=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[j&16383](f,h,0)|0;if((k|0)<1){break}gzL(o,0,h)|0}}while(0);h=c[3541356]|0;f=h+6144|0;gGC(f|0,o|0,512)|0;f=h+7168|0;gGC(f|0,g|0,512)|0;g=h+6656|0;gGC(g|0,p|0,512)|0;p=h+7680|0;gGC(p|0,r|0,512)|0;r=0;while(1){if((r|0)>=1024){u=h;break}v=9638528+(r<<2)|0;if((c[v>>2]|0)==(o|0)){q=45732;break}else{r=r+1|0}}if((q|0)==45732){gGr(o);c[v>>2]=0;u=c[3541356]|0}v=c[3541414]|0;o=c[3541472]|0;if((v|0)>0){r=c[1865546]|0;h=0;do{p=h<<6;gGz(o+p|0,0,64);g=0;do{f=p+(c[1238464+(g<<2)>>2]|0)|0;e=(g<<3)+p|0;k=0;do{j=f+(c[614800+(k<<2)>>2]|0)|0;if(((d[u+((j|0)/8|0)|0]|0)&128>>>((j&7)>>>0)|0)!=0){j=o+(e+k)|0;a[j]=a[j]|2}k=k+1|0;}while((k|0)<8);g=g+1|0;}while((g|0)<8);g=r+p|0;k=0;do{e=g+(c[1238464+(k<<2)>>2]|0)|0;f=(k<<3)+p|0;j=0;do{m=e+(c[614800+(j<<2)>>2]|0)|0;if(((d[u+((m|0)/8|0)|0]|0)&128>>>((m&7)>>>0)|0)!=0){m=o+(f+j)|0;a[m]=a[m]|1}j=j+1|0;}while((j|0)<8);k=k+1|0;}while((k|0)<8);h=h+1|0;}while((h|0)<(v|0))}v=c[3541412]|0;h=c[3541364]|0;if((v|0)>0){o=c[1865412]|0;r=0;while(1){k=r<<8;gGz(h+k|0,0,256);p=0;do{g=k+(c[611776+(p<<2)>>2]|0)|0;j=(p<<4)+k|0;f=0;do{e=g+(c[601400+(f<<2)>>2]|0)|0;if(((d[u+((e|0)/8|0)|0]|0)&128>>>((e&7)>>>0)|0)!=0){e=h+(j+f)|0;a[e]=a[e]|2}f=f+1|0;}while((f|0)<16);p=p+1|0;}while((p|0)<16);p=o+k|0;f=0;do{j=p+(c[611776+(f<<2)>>2]|0)|0;g=(f<<4)+k|0;e=0;do{m=j+(c[601400+(e<<2)>>2]|0)|0;if(((d[u+((m|0)/8|0)|0]|0)&128>>>((m&7)>>>0)|0)!=0){m=h+(g+e)|0;a[m]=a[m]|1}e=e+1|0;}while((e|0)<16);f=f+1|0;}while((f|0)<16);f=r+1|0;if((f|0)<(v|0)){r=f}else{w=0;break}}}else{w=0}while(1){if((w|0)>=1024){q=45767;break}x=9638528+(w<<2)|0;if((c[x>>2]|0)==(u|0)){break}else{w=w+1|0}}if((q|0)==45767){c[3541356]=0;i=b;return}gGr(u);c[x>>2]=0;c[3541356]=0;i=b;return}function a0e(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541322]|0;if((b|0)==0){a1c();return}d=c[3541328]|0;e=0;do{f=d+e|0;g=a[f]|0;h=g&255;i=(h&2|0)==0?g:g^64;g=(h&32|0)==0?i:i^4;if((e&1|0)==0){j=(g&255)>>>2<<6&64|g&-69|(g&255)>>>6<<2&4}else{j=g}a[f]=j;e=e+1|0;}while(e>>>0<b>>>0);a1c();return}function a0f(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=0;while(1){if((e|0)>=1024){f=0;break}g=9638528+(e<<2)|0;if((c[g>>2]|0)==0){h=45780;break}else{e=e+1|0}}do{if((h|0)==45780){e=gGq(12288)|0;c[g>>2]=e;if((e|0)==0){f=0;break}gGz(e|0,0,12288);f=e}}while(0);c[3541356]=f;g=c[3541328]|0;e=g+53248|0;gGC(f|0,e|0,12288)|0;gGz(e|0,0,4096);e=g+57344|0;gGC(e|0,f|0,12288)|0;gGz(g+69632|0,0,4096);g=0;while(1){if((g|0)>=1024){break}i=9638528+(g<<2)|0;if((c[i>>2]|0)==(f|0)){h=45785;break}else{g=g+1|0}}if((h|0)==45785){gGr(f);c[i>>2]=0}c[3541356]=0;i=c[3541322]|0;if((i|0)!=0){f=c[3541328]|0;h=0;do{g=f+h|0;a[g]=((d[g]|0)^h)&255;h=h+1|0;}while(h>>>0<i>>>0)}i=c[2439330]|0;h=(i|0)==0;if(!h){f=i;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];f=c[3528484]|0;c[2076596]=f;g=c[2417276]|0;c[3541536]=g;c[1836236]=0;gGz(i+76|0,0,2048);e=0;j=0;while(1){c[i+76+(j+512<<2)>>2]=0;c[i+76+(j+768<<2)>>2]=0;k=e+1&65535;if((k&65535)>255){break}else{e=k;j=k&65535}}c[i+4180>>2]=684;c[i+4184>>2]=1572;j=c[3541328]|0;e=0;k=0;while(1){c[i+76+(k<<2)>>2]=j+(k<<8);l=e+1&65535;if((l&65535)>63){m=0;n=0;break}else{e=l;k=l&65535}}while(1){k=j+(n<<8)|0;c[i+76+(n+512<<2)>>2]=k;c[i+76+(n+768<<2)>>2]=k;k=m+1&65535;if((k&65535)>63){break}else{m=k;n=k&65535}}n=c[3541334]|0;c[i+332>>2]=n;m=n+256|0;c[i+336>>2]=m;k=n+512|0;c[i+340>>2]=k;e=n+768|0;c[i+344>>2]=e;c[i+1356>>2]=n;c[i+1360>>2]=m;c[i+1364>>2]=k;c[i+1368>>2]=e;c[i+2380>>2]=n;c[i+3404>>2]=n;c[i+2384>>2]=m;c[i+3408>>2]=m;c[i+2388>>2]=k;c[i+3412>>2]=k;c[i+2392>>2]=e;c[i+3416>>2]=e;e=c[3541340]|0;c[i+396>>2]=e;k=e+256|0;c[i+400>>2]=k;m=e+512|0;c[i+404>>2]=m;n=e+768|0;c[i+408>>2]=n;c[i+1420>>2]=e;c[i+1424>>2]=k;c[i+1428>>2]=m;c[i+1432>>2]=n;c[i+2444>>2]=e;c[i+3468>>2]=e;c[i+2448>>2]=k;c[i+3472>>2]=k;c[i+2452>>2]=m;c[i+3476>>2]=m;c[i+2456>>2]=n;c[i+3480>>2]=n;n=c[3541366]|0;c[i+428>>2]=n;c[i+2476>>2]=n;c[i+3500>>2]=n;n=192;m=192;while(1){c[i+76+(m<<2)>>2]=j+((m<<8)-49152);k=n+1&65535;if((k&65535)>223){o=192;p=192;break}else{n=k;m=k&65535}}while(1){m=j+((p<<8)-49152)|0;c[i+76+(p+512<<2)>>2]=m;c[i+76+(p+768<<2)>>2]=m;m=o+1&65535;if((m&65535)>223){break}else{o=m;p=m&65535}}if(h){q=c[2433530]|0;c[2438118]=q;c[3528484]=f;c[2417276]=g;c[1836236]=-1;return}h=i;gGC(h|0,9706056,76)|0;q=c[2433530]|0;c[2438118]=q;c[3528484]=f;c[2417276]=g;c[1836236]=-1;return}function a0g(){var a=0,d=0,e=0,f=0;a=c[2439330]|0;d=(a|0)==0;if(!d){e=a;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];e=c[3528484]|0;c[2076596]=e;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;c[a+4180>>2]=2808;if(!d){d=a;gGC(d|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}function a0h(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[2439330]|0;d=(a|0)==0;if(!d){e=a;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];e=c[3528484]|0;c[2076596]=e;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;gGz(a+76|0,0,2048);g=0;h=0;while(1){c[a+76+(h+512<<2)>>2]=0;c[a+76+(h+768<<2)>>2]=0;i=g+1&65535;if((i&65535)>255){break}else{g=i;h=i&65535}}c[a+4180>>2]=2740;c[a+4184>>2]=1112;c[a+4176>>2]=1150;h=c[3541322]|0;g=c[3541328]|0;i=h>>>0>16383?63:h-1>>8;h=(i|0)<0;do{if(!h){j=0;k=0;do{c[a+76+(k<<2)>>2]=g+(k<<8);j=j+1&65535;k=j&65535;}while((k|0)<=(i|0));if(h){break}else{l=0;m=0}do{k=g+(m<<8)|0;c[a+76+(m+512<<2)>>2]=k;c[a+76+(m+768<<2)>>2]=k;l=l+1&65535;m=l&65535;}while((m|0)<=(i|0))}}while(0);i=c[3541334]|0;c[a+332>>2]=i;m=i+256|0;c[a+336>>2]=m;l=i+512|0;c[a+340>>2]=l;g=i+768|0;c[a+344>>2]=g;c[a+1356>>2]=i;c[a+1360>>2]=m;c[a+1364>>2]=l;c[a+1368>>2]=g;c[a+2380>>2]=i;c[a+3404>>2]=i;c[a+2384>>2]=m;c[a+3408>>2]=m;c[a+2388>>2]=l;c[a+3412>>2]=l;c[a+2392>>2]=g;c[a+3416>>2]=g;g=c[3541340]|0;c[a+364>>2]=g;l=g+256|0;c[a+368>>2]=l;m=g+512|0;c[a+372>>2]=m;i=g+768|0;c[a+376>>2]=i;c[a+1388>>2]=g;c[a+1392>>2]=l;c[a+1396>>2]=m;c[a+1400>>2]=i;c[a+2412>>2]=g;c[a+3436>>2]=g;c[a+2416>>2]=l;c[a+3440>>2]=l;c[a+2420>>2]=m;c[a+3444>>2]=m;c[a+2424>>2]=i;c[a+3448>>2]=i;c[a+380>>2]=g;c[a+384>>2]=l;c[a+388>>2]=m;c[a+392>>2]=i;c[a+1404>>2]=g;c[a+1408>>2]=l;c[a+1412>>2]=m;c[a+1416>>2]=i;c[a+2428>>2]=g;c[a+3452>>2]=g;c[a+2432>>2]=l;c[a+3456>>2]=l;c[a+2436>>2]=m;c[a+3460>>2]=m;c[a+2440>>2]=i;c[a+3464>>2]=i;i=c[3541366]|0;c[a+396>>2]=i;c[a+2444>>2]=i;c[a+3468>>2]=i;if(d){n=c[2433530]|0;c[2438118]=n;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}d=a;gGC(d|0,9706056,76)|0;n=c[2433530]|0;c[2438118]=n;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}function a0i(){var a=0,d=0,e=0,f=0;a=c[2439330]|0;d=(a|0)==0;if(!d){e=a;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];e=c[3528484]|0;c[2076596]=e;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;c[a+4184>>2]=832;if(!d){d=a;gGC(d|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}function a0j(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[3541322]|0;b=0;while(1){if((b|0)>=1024){d=0;break}e=9638528+(b<<2)|0;if((c[e>>2]|0)==0){f=45830;break}else{b=b+1|0}}do{if((f|0)==45830){b=gGq(a)|0;c[e>>2]=b;if((b|0)==0){d=0;break}gGz(b|0,0,a|0);d=b}}while(0);c[3541356]=d;a=c[3541328]|0;e=c[3541322]|0;gGC(d|0,a|0,e)|0;e=a+8192|0;gGC(e|0,d|0,2048)|0;e=d+2048|0;gGC(a|0,e|0,2048)|0;e=a+10240|0;b=d+4096|0;gGC(e|0,b|0,2048)|0;b=a+2048|0;e=d+6144|0;gGC(b|0,e|0,2048)|0;e=a+12288|0;b=d+8192|0;gGC(e|0,b|0,2048)|0;b=a+4096|0;e=d+10240|0;gGC(b|0,e|0,2048)|0;e=a+14336|0;b=d+12288|0;gGC(e|0,b|0,2048)|0;b=a+6144|0;a=d+14336|0;gGC(b|0,a|0,2048)|0;a=0;while(1){if((a|0)>=1024){f=45837;break}g=9638528+(a<<2)|0;if((c[g>>2]|0)==(d|0)){break}else{a=a+1|0}}if((f|0)==45837){c[3541356]=0;return}gGr(d);c[g>>2]=0;c[3541356]=0;return}function a0k(){var a=0,b=0,d=0,e=0,f=0;a=0;while(1){if((a|0)>=1024){b=0;break}d=9638528+(a<<2)|0;if((c[d>>2]|0)==0){e=45842;break}else{a=a+1|0}}do{if((e|0)==45842){a=gGq(12288)|0;c[d>>2]=a;if((a|0)==0){b=0;break}gGz(a|0,0,12288);b=a}}while(0);c[3541356]=b;d=c[3541328]|0;gGC(b|0,d|0,12288)|0;a=d+6144|0;d=b+4096|0;gGC(a|0,d|0,8192)|0;d=0;while(1){if((d|0)>=1024){e=45850;break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==(b|0)){break}else{d=d+1|0}}if((e|0)==45850){c[3541356]=0;return}gGr(b);c[f>>2]=0;c[3541356]=0;return}function a0l(){var a=0,d=0,e=0,f=0;a=c[2439330]|0;d=(a|0)==0;if(!d){e=a;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];e=c[3528484]|0;c[2076596]=e;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;c[a+4180>>2]=78;if(!d){d=a;gGC(d|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}function a0m(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[3541322]|0;b=0;while(1){if((b|0)>=1024){d=0;break}e=9638528+(b<<2)|0;if((c[e>>2]|0)==0){f=45859;break}else{b=b+1|0}}do{if((f|0)==45859){b=gGq(a)|0;c[e>>2]=b;if((b|0)==0){d=0;break}gGz(b|0,0,a|0);d=b}}while(0);c[3541356]=d;a=c[3541328]|0;e=c[3541322]|0;gGC(d|0,a|0,e)|0;gGC(a|0,d|0,2048)|0;e=a+8192|0;b=d+2048|0;gGC(e|0,b|0,2048)|0;b=a+2048|0;e=d+4096|0;gGC(b|0,e|0,2048)|0;e=a+10240|0;b=d+6144|0;gGC(e|0,b|0,2048)|0;b=a+4096|0;e=d+8192|0;gGC(b|0,e|0,2048)|0;e=a+12288|0;b=d+10240|0;gGC(e|0,b|0,2048)|0;b=a+6144|0;e=d+12288|0;gGC(b|0,e|0,2048)|0;e=a+14336|0;a=d+14336|0;gGC(e|0,a|0,2048)|0;a=0;while(1){if((a|0)>=1024){f=45866;break}g=9638528+(a<<2)|0;if((c[g>>2]|0)==(d|0)){break}else{a=a+1|0}}if((f|0)==45866){c[3541356]=0;return}gGr(d);c[g>>2]=0;c[3541356]=0;return}function a0n(){var a=0,d=0,e=0,f=0;a=c[2439330]|0;d=(a|0)==0;if(!d){e=a;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];e=c[3528484]|0;c[2076596]=e;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;c[a+4184>>2]=1686;if(!d){d=a;gGC(d|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}function a0o(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=c[2439330]|0;d=(a|0)==0;if(!d){e=a;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];e=c[3528484]|0;c[2076596]=e;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;gGz(a+76|0,0,2048);g=0;h=0;while(1){c[a+76+(h+512<<2)>>2]=0;c[a+76+(h+768<<2)>>2]=0;i=g+1&65535;if((i&65535)>255){break}else{g=i;h=i&65535}}c[a+4180>>2]=2918;c[a+4184>>2]=108;h=c[3541322]|0;g=c[3541328]|0;i=h>>>0>16384?63:h-1>>8;h=(i|0)<0;do{if(!h){j=0;k=0;do{c[a+76+(k<<2)>>2]=g+(k<<8);j=j+1&65535;k=j&65535;}while((k|0)<=(i|0));if(h){break}else{l=0;m=0}do{k=g+(m<<8)|0;c[a+76+(m+512<<2)>>2]=k;c[a+76+(m+768<<2)>>2]=k;l=l+1&65535;m=l&65535;}while((m|0)<=(i|0))}}while(0);i=c[3541334]|0;c[a+332>>2]=i;m=i+256|0;c[a+336>>2]=m;l=i+512|0;c[a+340>>2]=l;g=i+768|0;c[a+344>>2]=g;h=i+1024|0;c[a+348>>2]=h;k=i+1280|0;c[a+352>>2]=k;j=i+1536|0;c[a+356>>2]=j;n=i+1792|0;c[a+360>>2]=n;c[a+1356>>2]=i;c[a+1360>>2]=m;c[a+1364>>2]=l;c[a+1368>>2]=g;c[a+1372>>2]=h;c[a+1376>>2]=k;c[a+1380>>2]=j;c[a+1384>>2]=n;c[a+2380>>2]=i;c[a+3404>>2]=i;c[a+2384>>2]=m;c[a+3408>>2]=m;c[a+2388>>2]=l;c[a+3412>>2]=l;c[a+2392>>2]=g;c[a+3416>>2]=g;c[a+2396>>2]=h;c[a+3420>>2]=h;c[a+2400>>2]=k;c[a+3424>>2]=k;c[a+2404>>2]=j;c[a+3428>>2]=j;c[a+2408>>2]=n;c[a+3432>>2]=n;n=c[3541340]|0;c[a+396>>2]=n;j=n+256|0;c[a+400>>2]=j;k=n+512|0;c[a+404>>2]=k;h=n+768|0;c[a+408>>2]=h;c[a+1420>>2]=n;c[a+1424>>2]=j;c[a+1428>>2]=k;c[a+1432>>2]=h;c[a+2444>>2]=n;c[a+3468>>2]=n;c[a+2448>>2]=j;c[a+3472>>2]=j;c[a+2452>>2]=k;c[a+3476>>2]=k;c[a+2456>>2]=h;c[a+3480>>2]=h;c[a+412>>2]=n;c[a+416>>2]=j;c[a+420>>2]=k;c[a+424>>2]=h;c[a+1436>>2]=n;c[a+1440>>2]=j;c[a+1444>>2]=k;c[a+1448>>2]=h;c[a+2460>>2]=n;c[a+3484>>2]=n;c[a+2464>>2]=j;c[a+3488>>2]=j;c[a+2468>>2]=k;c[a+3492>>2]=k;c[a+2472>>2]=h;c[a+3496>>2]=h;h=c[3541366]|0;c[a+428>>2]=h;c[a+2476>>2]=h;c[a+3500>>2]=h;if(d){o=c[2433530]|0;c[2438118]=o;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}d=a;gGC(d|0,9706056,76)|0;o=c[2433530]|0;c[2438118]=o;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}function a0p(){var a=0,d=0,e=0,f=0;a0q();a=c[2439330]|0;d=(a|0)==0;if(!d){e=a;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];e=c[3528484]|0;c[2076596]=e;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;c[a+4180>>2]=1894;c[a+4184>>2]=3230;if(!d){d=a;gGC(d|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}function a0q(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=c[2439330]|0;d=(a|0)==0;if(!d){e=a;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];e=c[3528484]|0;c[2076596]=e;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;gGz(a+76|0,0,2048);g=0;h=0;while(1){c[a+76+(h+512<<2)>>2]=0;c[a+76+(h+768<<2)>>2]=0;i=g+1&65535;if((i&65535)>255){break}else{g=i;h=i&65535}}c[a+4180>>2]=2634;c[a+4184>>2]=80;h=c[3541322]|0;g=c[3541328]|0;i=h>>>0>16384?63:h-1>>8;h=(i|0)<0;do{if(!h){j=0;k=0;do{c[a+76+(k<<2)>>2]=g+(k<<8);j=j+1&65535;k=j&65535;}while((k|0)<=(i|0));if(h){break}else{l=0;m=0}do{k=g+(m<<8)|0;c[a+76+(m+512<<2)>>2]=k;c[a+76+(m+768<<2)>>2]=k;l=l+1&65535;m=l&65535;}while((m|0)<=(i|0))}}while(0);i=c[3541334]|0;c[a+332>>2]=i;m=i+256|0;c[a+336>>2]=m;l=i+512|0;c[a+340>>2]=l;g=i+768|0;c[a+344>>2]=g;h=i+1024|0;c[a+348>>2]=h;k=i+1280|0;c[a+352>>2]=k;j=i+1536|0;c[a+356>>2]=j;n=i+1792|0;c[a+360>>2]=n;c[a+1356>>2]=i;c[a+1360>>2]=m;c[a+1364>>2]=l;c[a+1368>>2]=g;c[a+1372>>2]=h;c[a+1376>>2]=k;c[a+1380>>2]=j;c[a+1384>>2]=n;c[a+2380>>2]=i;c[a+3404>>2]=i;c[a+2384>>2]=m;c[a+3408>>2]=m;c[a+2388>>2]=l;c[a+3412>>2]=l;c[a+2392>>2]=g;c[a+3416>>2]=g;c[a+2396>>2]=h;c[a+3420>>2]=h;c[a+2400>>2]=k;c[a+3424>>2]=k;c[a+2404>>2]=j;c[a+3428>>2]=j;c[a+2408>>2]=n;c[a+3432>>2]=n;n=c[3541340]|0;c[a+364>>2]=n;j=n+256|0;c[a+368>>2]=j;k=n+512|0;c[a+372>>2]=k;h=n+768|0;c[a+376>>2]=h;c[a+1388>>2]=n;c[a+1392>>2]=j;c[a+1396>>2]=k;c[a+1400>>2]=h;c[a+2412>>2]=n;c[a+3436>>2]=n;c[a+2416>>2]=j;c[a+3440>>2]=j;c[a+2420>>2]=k;c[a+3444>>2]=k;c[a+2424>>2]=h;c[a+3448>>2]=h;c[a+380>>2]=n;c[a+384>>2]=j;c[a+388>>2]=k;c[a+392>>2]=h;c[a+1404>>2]=n;c[a+1408>>2]=j;c[a+1412>>2]=k;c[a+1416>>2]=h;c[a+2428>>2]=n;c[a+3452>>2]=n;c[a+2432>>2]=j;c[a+3456>>2]=j;c[a+2436>>2]=k;c[a+3460>>2]=k;c[a+2440>>2]=h;c[a+3464>>2]=h;h=c[3541366]|0;c[a+396>>2]=h;c[a+2444>>2]=h;c[a+3468>>2]=h;if(d){o=c[2433530]|0;c[2438118]=o;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}d=a;gGC(d|0,9706056,76)|0;o=c[2433530]|0;c[2438118]=o;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}function a0r(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=c[2439330]|0;d=(a|0)==0;if(!d){e=a;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];e=c[3528484]|0;c[2076596]=e;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;gGz(a+76|0,0,2048);g=0;h=0;while(1){c[a+76+(h+512<<2)>>2]=0;c[a+76+(h+768<<2)>>2]=0;i=g+1&65535;if((i&65535)>255){break}else{g=i;h=i&65535}}c[a+4180>>2]=942;c[a+4184>>2]=948;h=c[3541328]|0;g=0;i=0;while(1){c[a+76+(i<<2)>>2]=h+(i<<8);j=g+1&65535;if((j&65535)>95){k=0;l=0;break}else{g=j;i=j&65535}}while(1){i=h+(l<<8)|0;c[a+76+(l+512<<2)>>2]=i;c[a+76+(l+768<<2)>>2]=i;i=k+1&65535;if((i&65535)>95){break}else{k=i;l=i&65535}}l=c[3541334]|0;c[a+588>>2]=l;k=l+256|0;c[a+592>>2]=k;h=l+512|0;c[a+596>>2]=h;i=l+768|0;c[a+600>>2]=i;g=l+1024|0;c[a+604>>2]=g;j=l+1280|0;c[a+608>>2]=j;m=l+1536|0;c[a+612>>2]=m;n=l+1792|0;c[a+616>>2]=n;c[a+1612>>2]=l;c[a+1616>>2]=k;c[a+1620>>2]=h;c[a+1624>>2]=i;c[a+1628>>2]=g;c[a+1632>>2]=j;c[a+1636>>2]=m;c[a+1640>>2]=n;c[a+2636>>2]=l;c[a+3660>>2]=l;c[a+2640>>2]=k;c[a+3664>>2]=k;c[a+2644>>2]=h;c[a+3668>>2]=h;c[a+2648>>2]=i;c[a+3672>>2]=i;c[a+2652>>2]=g;c[a+3676>>2]=g;c[a+2656>>2]=j;c[a+3680>>2]=j;c[a+2660>>2]=m;c[a+3684>>2]=m;c[a+2664>>2]=n;c[a+3688>>2]=n;n=c[3541366]|0;c[a+620>>2]=n;c[a+2668>>2]=n;c[a+3692>>2]=n;n=c[3541340]|0;c[a+652>>2]=n;m=n+256|0;c[a+656>>2]=m;j=n+512|0;c[a+660>>2]=j;g=n+768|0;c[a+664>>2]=g;c[a+1676>>2]=n;c[a+1680>>2]=m;c[a+1684>>2]=j;c[a+1688>>2]=g;c[a+2700>>2]=n;c[a+3724>>2]=n;c[a+2704>>2]=m;c[a+3728>>2]=m;c[a+2708>>2]=j;c[a+3732>>2]=j;c[a+2712>>2]=g;c[a+3736>>2]=g;if(d){o=c[2433530]|0;c[2438118]=o;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}d=a;gGC(d|0,9706056,76)|0;o=c[2433530]|0;c[2438118]=o;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}function a0s(){var a=0,d=0,e=0,f=0;a=c[2439330]|0;d=(a|0)==0;if(!d){e=a;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];e=c[3528484]|0;c[2076596]=e;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;c[a+4180>>2]=906;if(!d){d=a;gGC(d|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}function a0t(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[2439330]|0;d=(a|0)==0;if(!d){e=a;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];e=c[3528484]|0;c[2076596]=e;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;g=c[3541340]|0;c[a+364>>2]=g;h=g+256|0;c[a+368>>2]=h;i=g+512|0;c[a+372>>2]=i;j=g+768|0;c[a+376>>2]=j;c[a+1388>>2]=g;c[a+1392>>2]=h;c[a+1396>>2]=i;c[a+1400>>2]=j;c[a+2412>>2]=g;c[a+3436>>2]=g;c[a+2416>>2]=h;c[a+3440>>2]=h;c[a+2420>>2]=i;c[a+3444>>2]=i;c[a+2424>>2]=j;c[a+3448>>2]=j;if(d){k=c[2433530]|0;c[2438118]=k;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}d=a;gGC(d|0,9706056,76)|0;k=c[2433530]|0;c[2438118]=k;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}function a0u(){var a=0,b=0,d=0;a=c[3541328]|0;b=a+8192|0;d=a+6144|0;gGC(b|0,d|0,2048)|0;gGz(d|0,0,2048);return}function a0v(){var a=0,b=0,d=0;a=c[3541328]|0;b=a+8192|0;d=a+4096|0;gGC(b|0,d|0,2048)|0;gGz(d|0,0,2048);return}function a0w(){var a=0,b=0,d=0;a=c[3541328]|0;b=a+8192|0;d=a+2048|0;gGC(b|0,d|0,2048)|0;gGz(d|0,0,2048);return}function a0x(){var a=0,b=0,d=0,e=0,f=0,g=0;a=0;while(1){if((a|0)>=1024){b=0;break}d=9638528+(a<<2)|0;if((c[d>>2]|0)==0){e=45934;break}else{a=a+1|0}}do{if((e|0)==45934){a=gGq(8192)|0;c[d>>2]=a;if((a|0)==0){b=0;break}gGz(a|0,0,8192);b=a}}while(0);c[3541356]=b;d=c[3541328]|0;gGC(b|0,d|0,8192)|0;a=d+1536|0;gGC(a|0,d|0,512)|0;a=d+1024|0;f=b+512|0;gGC(a|0,f|0,512)|0;f=d+512|0;a=b+1024|0;gGC(f|0,a|0,512)|0;a=b+1536|0;gGC(d|0,a|0,512)|0;a=d+3584|0;f=b+2048|0;gGC(a|0,f|0,512)|0;f=d+3072|0;a=b+2560|0;gGC(f|0,a|0,512)|0;a=d+2560|0;f=b+3072|0;gGC(a|0,f|0,512)|0;f=d+2048|0;a=b+3584|0;gGC(f|0,a|0,512)|0;a=d+5632|0;f=b+4096|0;gGC(a|0,f|0,512)|0;f=d+5120|0;a=b+4608|0;gGC(f|0,a|0,512)|0;a=d+4608|0;f=b+5120|0;gGC(a|0,f|0,512)|0;f=d+4096|0;a=b+5632|0;gGC(f|0,a|0,512)|0;a=d+7680|0;f=b+6144|0;gGC(a|0,f|0,512)|0;f=d+7168|0;a=b+6656|0;gGC(f|0,a|0,512)|0;a=d+6656|0;f=b+7168|0;gGC(a|0,f|0,512)|0;f=d+6144|0;d=b+7680|0;gGC(f|0,d|0,512)|0;d=0;while(1){if((d|0)>=1024){e=45942;break}g=9638528+(d<<2)|0;if((c[g>>2]|0)==(b|0)){break}else{d=d+1|0}}if((e|0)==45942){c[3541356]=0;return}gGr(b);c[g>>2]=0;c[3541356]=0;return}function a0y(b){b=b|0;return a[14165875]|a[14165811]|0}function a0z(b){b=b|0;return a[14165504]|0}function a0A(b){b=b|0;a[9706117]=0;return a[14165504]|0}function a0B(a){a=a|0;a=a0C(0)|0;return(a&255)>>>3<<5&32|a&-41|(a&255)>>>5<<3&8|0}function a0C(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;a=c[1836236]|0;if((a|0)==1){d=(c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)<<3;e=gGW(d,(d|0)<0|0?-1:0,40960,0)|0;f=e;g=f>>>0>20479;h=f-20480|0;i=g?h:f;j=i>>>14;k=j<<6;l=k&64;m=i>>>13;n=m<<5;o=n&32;p=i>>>11;q=p<<4;r=q&16;s=g?142:14;t=l|s;u=t|o;v=u|r;w=v&255;return w|0}e=c[9757320+(a<<2)>>2]|0;d=(e|0)==0;if(!d){x=e;gGC(x|0,9706056,76)|0}x=9752472+(a<<2)|0;c[x>>2]=c[2433530];y=14113936+(a<<2)|0;c[y>>2]=c[2076596];z=9669104+(a<<2)|0;c[z>>2]=c[3541536];c[1836236]=-1;A=c[2439331]|0;B=(A|0)==0;if(!B){C=A;gGC(9706056,C|0,76)|0}b[4853030]=c[2426515]&65535;C=c[2438119]|0;c[2433530]=C;D=c[3528485]|0;c[2076596]=D;E=c[2417277]|0;c[3541536]=E;c[1836236]=1;F=C-D+(c[2426530]|0)<<3;G=gGW(F,(F|0)<0|0?-1:0,40960,0)|0;if(!B){B=A;gGC(B|0,9706056,76)|0}c[2438119]=C;c[3528485]=D;c[2417277]=E;c[1836236]=-1;if(!d){d=e;gGC(9706056,d|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[x>>2];c[2076596]=c[y>>2];c[3541536]=c[z>>2];c[1836236]=a;f=G;g=f>>>0>20479;h=f-20480|0;i=g?h:f;j=i>>>14;k=j<<6;l=k&64;m=i>>>13;n=m<<5;o=n&32;p=i>>>11;q=p<<4;r=q&16;s=g?142:14;t=l|s;u=t|o;v=u|r;w=v&255;return w|0}function a0D(b,c){b=b|0;c=c|0;a[14165496]=c&255;return}function a0E(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=a[14130360]|0;a[14130360]=e&255;if((d&1)==0){return}if((e&1|0)!=0){return}e=c[1836236]|0;if((e|0)==2){a[9706117]=1;if((a[(c[2439332]|0)+4188|0]|0)==0){d=gfc(100)|0;f=d;g=(c[2433530]|0)+d|0}else{f=100;g=(c[2433530]|0)+100|0}c[2433530]=g;c[2113206]=(c[2113206]|0)+f;a[9706117]=0;return}f=9757320+(e<<2)|0;g=c[f>>2]|0;if((g|0)!=0){d=g;gGC(d|0,9706056,76)|0}d=9752472+(e<<2)|0;c[d>>2]=c[2433530];g=14113936+(e<<2)|0;c[g>>2]=c[2076596];h=9669104+(e<<2)|0;c[h>>2]=c[3541536];c[1836236]=-1;i=c[2439332]|0;if((i|0)!=0){j=i;gGC(9706056,j|0,76)|0}b[4853030]=c[2426515]&65535;j=c[2438120]|0;c[2433530]=j;c[2076596]=c[3528486];c[3541536]=c[2417278];c[1836236]=2;a[9706117]=1;if((a[i+4188|0]|0)==0){k=gfc(100)|0;l=c[1836236]|0;m=k;n=(c[2433530]|0)+k|0;o=l;p=c[9757320+(l<<2)>>2]|0}else{m=100;n=j+100|0;o=2;p=i}c[2433530]=n;c[2113206]=(c[2113206]|0)+m;a[9706117]=0;if((p|0)!=0){m=p;gGC(m|0,9706056,76)|0}c[9752472+(o<<2)>>2]=n;c[14113936+(o<<2)>>2]=c[2076596];c[9669104+(o<<2)>>2]=c[3541536];c[1836236]=-1;o=c[f>>2]|0;if((o|0)!=0){f=o;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[d>>2];c[2076596]=c[g>>2];c[3541536]=c[h>>2];c[1836236]=e;return}function a0F(){return~~((a[9688]|0?534.0:0.0)*(+((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)/((a[9616]|0?1789740.0:0.0)/(+(c[2424]|0)/100.0))))|0}function a0G(){return~~((a[9688]|0?534.0:0.0)*(+((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)/(+(c[2113200]|0)*60.0/(+(c[2424]|0)/100.0))))|0}function a0H(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;if((c[1836236]|0)==0){a=(c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)<<3;d=gGW(a,(a|0)<0|0?-1:0,40960,0)|0;e=d}else{d=c[2439330]|0;a=(d|0)==0;if(!a){f=d;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;h=c[2417276]|0;c[3541536]=h;c[1836236]=0;i=f-g+(c[2426530]|0)<<3;j=gGW(i,(i|0)<0|0?-1:0,40960,0)|0;if(!a){a=d;gGC(a|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=h;c[1836236]=-1;e=j}j=e>>>0>20479;h=j?e-20480|0:e;return(h>>>14<<6&64|(j?142:14)|h>>>13<<5&32|h>>>11<<4&16)&255|0}function a0I(b){b=b|0;a[14165504]=b;return}function a0J(d){d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=a[14164872]|0;a[14164872]=d;if((e&8)==0){return}if((d&8)!=0){return}d=c[1836236]|0;if((d|0)==1){a[9706117]=1;return}e=c[9757320+(d<<2)>>2]|0;f=(e|0)==0;if(!f){g=e;gGC(g|0,9706056,76)|0}g=9752472+(d<<2)|0;c[g>>2]=c[2433530];h=14113936+(d<<2)|0;c[h>>2]=c[2076596];i=9669104+(d<<2)|0;c[i>>2]=c[3541536];c[1836236]=-1;j=c[2439331]|0;k=(j|0)==0;if(!k){l=j;gGC(9706056,l|0,76)|0}b[4853030]=c[2426515]&65535;l=c[2438119]|0;c[2433530]=l;m=c[3528485]|0;c[2076596]=m;n=c[2417277]|0;c[3541536]=n;c[1836236]=1;a[9706117]=1;if(!k){k=j;gGC(k|0,9706056,76)|0}c[2438119]=l;c[3528485]=m;c[2417277]=n;c[1836236]=-1;if(!f){f=e;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[g>>2];c[2076596]=c[h>>2];c[3541536]=c[i>>2];c[1836236]=d;return}function a0K(b){b=b|0;var c=0;c=a[14164872]|0;a[14164872]=b;a[7461824]=0;if((c&8)==0){return}if((b&8)!=0){return}a[7461824]=1;return}function a0L(a){a=a|0;return-1|0}function a0M(b,d){b=b|0;d=d|0;var e=0,f=0.0,g=0,h=0;if((b-24576&65535)>=4096){return}d=(b&65535)>>>6&255&3;e=(d&1|0)==0?0:22e4;f=+(((d&2|0)==0?e:e+47e3|0)|0)*1.0e-12;c[2440626]=0;if(f==0.0){g=65536}else{g=~~(65536.0- +ad(+(-1.0/(f*836.0655737704918)/(a[9680]|0?32.0e3:0.0)))*65536.0)}c[2440624]=g;g=(b&65535)>>>8&255&3;e=(g&1|0)==0?0:22e4;f=+(((g&2|0)==0?e:e+47e3|0)|0)*1.0e-12;c[2440646]=0;if(f==0.0){h=65536}else{h=~~(65536.0- +ad(+(-1.0/(f*836.0655737704918)/(a[9680]|0?32.0e3:0.0)))*65536.0)}c[2440644]=h;h=(b&65535)>>>10&255&3;b=(h&1|0)==0?0:22e4;f=+(((h&2|0)==0?b:b+47e3|0)|0)*1.0e-12;c[2440666]=0;if(f==0.0){c[2440664]=65536;return}else{c[2440664]=~~(65536.0- +ad(+(-1.0/(f*836.0655737704918)/(a[9680]|0?32.0e3:0.0)))*65536.0);return}}function a0N(b){b=b|0;var d=0,e=0;if((b&64)==0){d=-1;return d|0}b=c[3542228]|0;if((b|0)>15){d=0;return d|0}do{if((b|0)==14){e=c[3542224]|0;if((e|0)==0){break}a[14168930]=gj[e&4095](0)|0}else if((b|0)==15){e=c[3542225]|0;if((e|0)==0){break}a[14168931]=gj[e&4095](0)|0}}while(0);d=a[14168916+b|0]|0;return d|0}function a0O(b,d){b=b|0;d=d|0;var e=0;e=b&255;if((e&64|0)==0){if((e&128|0)==0){return}c[3542228]=d&15;return}e=d&255;b=c[3542228]|0;if((b|0)>15){return}do{if((b|0)<14){if((b|0)!=13){if((a[14168916+b|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(0,b,e);return}function a0P(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[2439331]|0;d=(a|0)==0;if(!d){e=a;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];e=c[3528485]|0;c[2076596]=e;f=c[2417277]|0;c[3541536]=f;c[1836236]=1;c[a+4180>>2]=3290;c[a+4184>>2]=1550;c[a+4172>>2]=1294;c[a+4176>>2]=14;g=c[3541320]|0;h=(c[3541316]|0)-1>>8;i=(h|0)<0;do{if(!i){j=0;k=0;do{c[a+76+(k<<2)>>2]=g+(k<<8);j=j+1&65535;k=j&65535;}while((k|0)<=(h|0));if(i){break}else{l=0;m=0}do{k=g+(m<<8)|0;c[a+76+(m+512<<2)>>2]=k;c[a+76+(m+768<<2)>>2]=k;l=l+1&65535;m=l&65535;}while((m|0)<=(h|0))}}while(0);h=c[3541332]|0;c[a+332>>2]=h;m=h+256|0;c[a+336>>2]=m;l=h+512|0;c[a+340>>2]=l;g=h+768|0;c[a+344>>2]=g;c[a+1356>>2]=h;c[a+1360>>2]=m;c[a+1364>>2]=l;c[a+1368>>2]=g;c[a+2380>>2]=h;c[a+3404>>2]=h;c[a+2384>>2]=m;c[a+3408>>2]=m;c[a+2388>>2]=l;c[a+3412>>2]=l;c[a+2392>>2]=g;c[a+3416>>2]=g;if(d){n=c[2433530]|0;c[2438119]=n;c[3528485]=e;c[2417277]=f;c[1836236]=-1;c[2113200]=29829;return}d=a;gGC(d|0,9706056,76)|0;n=c[2433530]|0;c[2438119]=n;c[3528485]=e;c[2417277]=f;c[1836236]=-1;c[2113200]=29829;return}function a0Q(a){a=a|0;return-1|0}function a0R(b,d){b=b|0;d=d|0;var e=0,f=0.0,g=0,h=0,i=0,j=0,k=0;d=a[14165488]|0;if(!((d<<24>>24|0)==9|(d<<24>>24|0)==8|(d<<24>>24|0)==11|(d<<24>>24|0)==12)){return}if((b+28672&65535)>=4096){return}d=b&255&3;e=(d&1|0)==0?0:22e4;f=+(((d&2|0)==0?e:e+47e3|0)|0)*1.0e-12;c[2440626]=0;if(f==0.0){g=65536}else{g=~~(65536.0- +ad(+(-1.0/(f*836.0655737704918)/(a[9680]|0?32.0e3:0.0)))*65536.0)}c[2440624]=g;g=(b&65535)>>>2&255&3;e=(g&1|0)==0?0:22e4;f=+(((g&2|0)==0?e:e+47e3|0)|0)*1.0e-12;c[2440646]=0;if(f==0.0){h=65536}else{h=~~(65536.0- +ad(+(-1.0/(f*836.0655737704918)/(a[9680]|0?32.0e3:0.0)))*65536.0)}c[2440644]=h;h=(b&65535)>>>4&255&3;e=(h&1|0)==0?0:22e4;f=+(((h&2|0)==0?e:e+47e3|0)|0)*1.0e-12;c[2440666]=0;if(f==0.0){i=65536}else{i=~~(65536.0- +ad(+(-1.0/(f*836.0655737704918)/(a[9680]|0?32.0e3:0.0)))*65536.0)}c[2440664]=i;i=(b&65535)>>>6&255&3;e=(i&1|0)==0?0:22e4;f=+(((i&2|0)==0?e:e+47e3|0)|0)*1.0e-12;c[2440686]=0;if(f==0.0){j=65536}else{j=~~(65536.0- +ad(+(-1.0/(f*836.0655737704918)/(a[9680]|0?32.0e3:0.0)))*65536.0)}c[2440684]=j;j=(b&65535)>>>8&255&3;e=(j&1|0)==0?0:22e4;f=+(((j&2|0)==0?e:e+47e3|0)|0)*1.0e-12;c[2440706]=0;if(f==0.0){k=65536}else{k=~~(65536.0- +ad(+(-1.0/(f*836.0655737704918)/(a[9680]|0?32.0e3:0.0)))*65536.0)}c[2440704]=k;k=(b&65535)>>>10&255&3;b=(k&1|0)==0?0:22e4;f=+(((k&2|0)==0?b:b+47e3|0)|0)*1.0e-12;c[2440726]=0;if(f==0.0){c[2440724]=65536;return}else{c[2440724]=~~(65536.0- +ad(+(-1.0/(f*836.0655737704918)/(a[9680]|0?32.0e3:0.0)))*65536.0);return}}function a0S(b){b=b|0;var d=0,e=0,f=0,g=0,h=0;d=b&255;do{if((d&32|0)==0){e=-1}else{b=c[3542228]|0;if((b|0)>15){e=0;break}do{if((b|0)==14){f=c[3542224]|0;if((f|0)==0){break}a[14168930]=gj[f&4095](0)|0}else if((b|0)==15){f=c[3542225]|0;if((f|0)==0){break}a[14168931]=gj[f&4095](0)|0}}while(0);e=a[14168916+b|0]|0}}while(0);if((d&128|0)==0){g=e;return g|0}d=c[3542291]|0;if((d|0)>15){h=0}else{do{if((d|0)==14){f=c[3542287]|0;if((f|0)==0){break}a[14169182]=gj[f&4095](0)|0}else if((d|0)==15){f=c[3542288]|0;if((f|0)==0){break}a[14169183]=gj[f&4095](0)|0}}while(0);h=a[14169168+d|0]|0}g=h&e;return g|0}function a0T(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;e=b&255;do{if((e&16|0)==0){if((e&32|0)==0){break}b=d&255;f=c[3542228]|0;if((f|0)>15){break}do{if((f|0)<14){if((f|0)!=13){if((a[14168916+f|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(0,f,b)}else{c[3542228]=d&15}}while(0);if((e&64|0)!=0){c[3542291]=d&15;return}if((e&128|0)==0){return}e=d&255;g=c[3542291]|0;if((g|0)>15){return}do{if((g|0)<14){if((g|0)!=13){if((a[14169168+g|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(1,g,e);return}function a0U(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[2439331]|0;d=(a|0)==0;if(!d){e=a;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];e=c[3528485]|0;c[2076596]=e;f=c[2417277]|0;c[3541536]=f;c[1836236]=1;c[a+4180>>2]=2550;c[a+4184>>2]=2626;c[a+4172>>2]=88;c[a+4176>>2]=3324;g=c[3541320]|0;h=(c[3541316]|0)-1>>8;i=(h|0)<0;do{if(!i){j=0;k=0;do{c[a+76+(k<<2)>>2]=g+(k<<8);j=j+1&65535;k=j&65535;}while((k|0)<=(h|0));if(i){break}else{l=0;m=0}do{k=g+(m<<8)|0;c[a+76+(m+512<<2)>>2]=k;c[a+76+(m+768<<2)>>2]=k;l=l+1&65535;m=l&65535;}while((m|0)<=(h|0))}}while(0);h=c[3541332]|0;c[a+588>>2]=h;m=h+256|0;c[a+592>>2]=m;l=h+512|0;c[a+596>>2]=l;g=h+768|0;c[a+600>>2]=g;c[a+1612>>2]=h;c[a+1616>>2]=m;c[a+1620>>2]=l;c[a+1624>>2]=g;c[a+2636>>2]=h;c[a+3660>>2]=h;c[a+2640>>2]=m;c[a+3664>>2]=m;c[a+2644>>2]=l;c[a+3668>>2]=l;c[a+2648>>2]=g;c[a+3672>>2]=g;if(d){n=c[2433530]|0;c[2438119]=n;c[3528485]=e;c[2417277]=f;c[1836236]=-1;c[2113200]=29829;return}d=a;gGC(d|0,9706056,76)|0;n=c[2433530]|0;c[2438119]=n;c[3528485]=e;c[2417277]=f;c[1836236]=-1;c[2113200]=29829;return}function a0V(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[2439330]|0;d=(a|0)==0;if(!d){e=a;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];e=c[3528484]|0;c[2076596]=e;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;c[a+4180>>2]=2550;c[a+4184>>2]=2626;c[a+4172>>2]=88;c[a+4176>>2]=3324;g=c[3541328]|0;h=(c[3541322]|0)-1>>8;i=(h|0)<0;do{if(!i){j=0;k=0;do{c[a+76+(k<<2)>>2]=g+(k<<8);j=j+1&65535;k=j&65535;}while((k|0)<=(h|0));if(i){break}else{l=0;m=0}do{k=g+(m<<8)|0;c[a+76+(m+512<<2)>>2]=k;c[a+76+(m+768<<2)>>2]=k;l=l+1&65535;m=l&65535;}while((m|0)<=(h|0))}}while(0);h=c[3541334]|0;m=h+1024|0;c[a+588>>2]=m;l=h+1280|0;c[a+592>>2]=l;g=h+1536|0;c[a+596>>2]=g;i=h+1792|0;c[a+600>>2]=i;c[a+1612>>2]=m;c[a+1616>>2]=l;c[a+1620>>2]=g;c[a+1624>>2]=i;c[a+2636>>2]=m;c[a+3660>>2]=m;c[a+2640>>2]=l;c[a+3664>>2]=l;c[a+2644>>2]=g;c[a+3668>>2]=g;c[a+2648>>2]=i;c[a+3672>>2]=i;c[a+604>>2]=m;c[a+608>>2]=l;c[a+612>>2]=g;c[a+616>>2]=i;c[a+1628>>2]=m;c[a+1632>>2]=l;c[a+1636>>2]=g;c[a+1640>>2]=i;c[a+2652>>2]=m;c[a+3676>>2]=m;c[a+2656>>2]=l;c[a+3680>>2]=l;c[a+2660>>2]=g;c[a+3684>>2]=g;c[a+2664>>2]=i;c[a+3688>>2]=i;c[a+620>>2]=m;c[a+624>>2]=l;c[a+628>>2]=g;c[a+632>>2]=i;c[a+1644>>2]=m;c[a+1648>>2]=l;c[a+1652>>2]=g;c[a+1656>>2]=i;c[a+2668>>2]=m;c[a+3692>>2]=m;c[a+2672>>2]=l;c[a+3696>>2]=l;c[a+2676>>2]=g;c[a+3700>>2]=g;c[a+2680>>2]=i;c[a+3704>>2]=i;c[a+636>>2]=m;c[a+640>>2]=l;c[a+644>>2]=g;c[a+648>>2]=i;c[a+1660>>2]=m;c[a+1664>>2]=l;c[a+1668>>2]=g;c[a+1672>>2]=i;c[a+2684>>2]=m;c[a+3708>>2]=m;c[a+2688>>2]=l;c[a+3712>>2]=l;c[a+2692>>2]=g;c[a+3716>>2]=g;c[a+2696>>2]=i;c[a+3720>>2]=i;if(d){n=c[2433530]|0;c[2438118]=n;c[3528484]=e;c[2417276]=f;c[1836236]=-1;c[2113200]=29829;return}d=a;gGC(d|0,9706056,76)|0;n=c[2433530]|0;c[2438118]=n;c[3528484]=e;c[2417276]=f;c[1836236]=-1;c[2113200]=29829;return}function a0W(d,f){d=d|0;f=f|0;var g=0,i=0,j=0,k=0,l=0.0,m=0,n=0,o=0,p=0.0,q=0,r=0,s=0,t=0,u=0.0,v=0.0,w=0.0,x=0,y=0.0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0.0,M=0,N=0,O=0,P=0,Q=0.0;gGz(d|0,0,f<<2|0);g=c[3541336]|0;i=c[3541406]|0;j=(f|0)>0;k=a[9680]|0;L58921:do{if((i|0)!=255&j){l=96.0e3/(k?32.0e3:0.0);m=a[6885960]|0?3:0;n=(m&1|0)==0;o=(m&2|0)==0;p=+h[83962];m=0;q=i;while(1){r=0;s=0;t=c[2443340]|0;u=+h[925090];while(1){if((t|0)>255){v=l+u;w=v>16.0?0.0:v;h[925090]=w;x=q;y=w}else{x=t;y=u}z=x+1|0;A=(b[14108688+(g<<5)+(~~y<<1)>>1]|0)+s|0;B=r+1|0;if((B|0)<16){r=B;s=A;t=z;u=y}else{break}}c[2443340]=z;t=((A|0)/16|0)<<16>>20&65535;if(n){C=0}else{C=~~(+(t<<16>>16|0)*p)}if(o){D=0}else{D=~~(+(t<<16>>16|0)*p)}if((C|0)<-32768){E=-32768}else{E=(C|0)>32767?32767:C&65535}if((D|0)<-32768){F=-32768}else{F=(D|0)>32767?32767:D&65535}b[d+(m<<1)>>1]=E;b[d+((m|1)<<1)>>1]=F;t=m+2|0;if((t|0)>=(f|0)){G=k;break L58921}m=t;q=c[3541406]|0}}else{G=k}}while(0);y=+h[932737];p=G?32.0e3:0.0;l=8.0e3/p;if(j){G=c[2443338]|0;k=a[6885960]|0?3:0;F=(k&1|0)==0;E=(k&2|0)==0;u=+h[83962];w=y;k=0;while(1){D=(ag(e[G+(~~w<<1)>>1]<<16,(c[3541416]|0)/100|0)|0)>>20&65535;if(F){H=0}else{H=~~(+(D<<16>>16|0)*u)}if(E){I=0}else{I=~~(+(D<<16>>16|0)*u)}if((H|0)<-32768){J=-32768}else{J=(H|0)>32767?32767:H}if((I|0)<-32768){K=-32768}else{K=(I|0)>32767?32767:I}D=d+(k<<1)|0;b[D>>1]=(e[D>>1]|0)+J&65535;D=d+((k|1)<<1)|0;b[D>>1]=(e[D>>1]|0)+K&65535;v=l+w;D=k+2|0;if((D|0)<(f|0)){w=v;k=D}else{L=v;break}}}else{L=y}h[932737]=L>32.0e3?0.0:L;if((a[14165512]|0)==0){a0X(0,d,f);a0X(1,d,f);a0X(2,d,f);return}L=+h[932735];y=(a[6885952]|0?22050.0:0.0)/p;if(j){j=c[2443336]|0;k=a[6885960]|0?3:0;K=(k&1|0)==0;J=(k&2|0)==0;p=+h[83962];w=L;k=0;while(1){I=~~(+(b[j+(~~w<<1)>>1]|0)*.5)<<16>>16>>>4&65535;if(K){M=0}else{M=~~(+(I<<16>>16|0)*p)}if(J){N=0}else{N=~~(+(I<<16>>16|0)*p)}if((M|0)<-32768){O=-32768}else{O=(M|0)>32767?32767:M}if((N|0)<-32768){P=-32768}else{P=(N|0)>32767?32767:N}I=d+(k<<1)|0;b[I>>1]=(e[I>>1]|0)+O&65535;I=d+((k|1)<<1)|0;b[I>>1]=(e[I>>1]|0)+P&65535;l=y+w;I=k+2|0;if((I|0)<(f|0)){w=l;k=I}else{Q=l;break}}}else{Q=L}h[932735]=Q;if(Q<=(a[5397504]|0?44100.0:0.0)){a0X(0,d,f);a0X(1,d,f);a0X(2,d,f);return}h[932735]=0.0;a[14165512]=0;a0X(0,d,f);a0X(1,d,f);a0X(2,d,f);return}function a0X(d,f,g){d=d|0;f=f|0;g=g|0;var i=0,j=0.0,k=0.0,l=0.0,m=0,n=0.0,o=0,p=0,q=0,r=0.0,s=0.0,t=0,u=0,v=0,w=0,x=0;i=14165696+(d<<3)|0;j=+h[i>>3];k=+h[932739]*64.0*1040.0/1040.0/(a[9680]|0?32.0e3:0.0);if((g|0)<=0){l=j;m=l>32.0;n=m?0.0:l;h[i>>3]=n;return}o=14165720+(d<<2)|0;d=a[6885960]|0?3:0;p=(d&1|0)==0;q=(d&2|0)==0;r=+h[83962];s=j;d=0;while(1){t=~~(+(b[1263544+(~~s<<1)>>1]|0)*((c[o>>2]|0)!=0?.05999999865889549:0.0))<<16>>16>>>4&65535;if(p){u=0}else{u=~~(+(t<<16>>16|0)*r)}if(q){v=0}else{v=~~(+(t<<16>>16|0)*r)}if((u|0)<-32768){w=-32768}else{w=(u|0)>32767?32767:u}if((v|0)<-32768){x=-32768}else{x=(v|0)>32767?32767:v}t=f+(d<<1)|0;b[t>>1]=(e[t>>1]|0)+w&65535;t=f+((d|1)<<1)|0;b[t>>1]=(e[t>>1]|0)+x&65535;j=k+s;t=d+2|0;if((t|0)<(g|0)){s=j;d=t}else{l=j;break}}m=l>32.0;n=m?0.0:l;h[i>>3]=n;return}function a0Y(){return~a[14165808]-(a[14165872]|0)&255|0}function a0Z(){return~a[14165809]-(a[14165873]|0)&255|0}function a0_(){return~a[14165810]-(a[14165874]|0)&255|0}function a0$(){return~a[14165811]-(a[14165875]|0)&255|0}function a00(b){b=b|0;var c=0,d=0;c=b&65535;if((c|0)==24576){d=a[14165872]|a[14165808]}else if((c|0)==26624){d=a[14165873]|a[14165809]}else if((c|0)==28672){d=a[14165874]|a[14165810]}else{d=-1}return d|0}function a01(b,d){b=b|0;d=d|0;var e=0,f=0,g=0.0,i=0.0,j=0.0,k=0.0,l=0.0,m=0.0,n=0.0,o=0.0;e=b&65535;if((b-22528&65535)<256){b=e-22528|0;a[(c[3541366]|0)+b|0]=d;if(!((b|0)<64&(b&1|0)==0)){return}a[(c[3541380]|0)+(b>>1)|0]=d;return}switch(e|0){case 24580:case 24581:case 24582:case 24583:{b=d&1;f=14165736+(e-24580<<2)|0;if((b|0)==(c[f>>2]|0)){return}c[f>>2]=b;b=(c[3541434]|0)==0;g=b?4030303030303031.0e-21:30303030303030305.0e-22;i=b?1.0e-12:1000001.0e-12;if((c[3541435]|0)==0){j=i;k=g+21276595744680853.0e-22}else{j=i+21276595744680853.0e-22;k=g}if((c[3541436]|0)==0){l=j;m=k+45454545454545455.0e-22}else{l=j+45454545454545455.0e-22;m=k}if((c[3541437]|0)==0){n=l;o=m+1.0e-5}else{n=l+1.0e-5;o=m}m=1.0/o;h[932738]=1.0e9/((m*2.0e6/(m+1.0/n)+1.0e5)*58788.0)*100.0;return};case 28678:{a[14165832]=d&1;return};case 28679:{a[14165824]=d&1;return};case 28673:{a[14165768]=d&1;return};case 26624:case 26625:case 26626:case 26627:case 26628:case 26629:case 26630:case 26631:{b=e-26624|0;e=d&1;switch(b&7|0){case 3:{a[14165672]=e;if(e<<24>>24==0){return}c[3541416]=100;h[932737]=0.0;return};case 0:case 1:case 2:{c[14165720+(b<<2)>>2]=e&255;return};case 7:case 6:{f=b&1;c[3541336]=c[3541336]&~(1<<f)|(d&1)<<f;return};case 5:{do{if(e<<24>>24!=0){if((a[14165752]&1)!=0){break}a[14165512]=1;h[932735]=0.0}}while(0);a[14165752]=e;return};default:{return}}break};case 30720:{c[3541406]=d&255;return};case 28676:{e=d&1;c[3541360]=e;if((e|0)!=0){return}c[3541358]=-1;return};default:{return}}}function a02(a){a=a|0;return 0}function a03(a,b){a=a|0;b=b|0;return}function a04(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0.0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0.0,ar=0.0,as=0.0,at=0.0,au=0.0,av=0.0,aw=0.0,ax=0.0,ay=0.0,az=0.0,aA=0.0,aB=0.0,aC=0.0,aD=0.0,aE=0.0,aF=0.0,aG=0.0,aH=0.0,aI=0.0,aJ=0,aK=0.0,aL=0.0,aM=0.0,aN=0.0,aO=0.0,aP=0.0,aQ=0.0,aR=0.0,aS=0,aT=0,aU=0,aV=0;a05(0)|0;if((a[14165488]|0)==0){a[14165488]=1}c[3541422]=0;a06();d=c[3541420]|0;e=0;while(1){if((e|0)>=1024){break}f=9638528+(e<<2)|0;if((c[f>>2]|0)==0){g=46281;break}else{e=e+1|0}}do{if((g|0)==46281){e=gGq(d)|0;c[f>>2]=e;if((e|0)==0){break}gGz(e|0,0,d|0);c[3541422]=e;gGz(e|0,0,d|0);a06();if((a05(1)|0)!=0){i=1;return i|0}L59088:do{if((a[14165488]|0)!=17){do{if((c[3541310]|0)==0){if((c[3541316]|0)!=0){fwR(0);fwR(1);break}if((c[3541322]|0)==0){break L59088}fwR(0)}else{fwR(0);fwR(1);fwR(2)}}while(0);e=c[3541322]|0;if((e|0)==0){break}j=c[2439330]|0;k=(j|0)==0;if(!k){l=j;gGC(9706056,l|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];l=c[3528484]|0;c[2076596]=l;m=c[2417276]|0;c[3541536]=m;c[1836236]=0;c[j+4180>>2]=2948;c[j+4184>>2]=516;c[j+4172>>2]=2142;c[j+4176>>2]=1778;n=c[3541328]|0;o=e>>>0>16384?63:e-1>>8;e=(o|0)<0;do{if(!e){p=0;q=0;do{c[j+76+(q<<2)>>2]=n+(q<<8);p=p+1&65535;q=p&65535;}while((q|0)<=(o|0));if(e){break}else{r=0;s=0}do{q=n+(s<<8)|0;c[j+76+(s+512<<2)>>2]=q;c[j+76+(s+768<<2)>>2]=q;r=r+1&65535;s=r&65535;}while((s|0)<=(o|0))}}while(0);o=c[3541334]|0;c[j+332>>2]=o;n=o+256|0;c[j+336>>2]=n;e=o+512|0;c[j+340>>2]=e;q=o+768|0;c[j+344>>2]=q;c[j+1356>>2]=o;c[j+1360>>2]=n;c[j+1364>>2]=e;c[j+1368>>2]=q;c[j+2380>>2]=o;c[j+3404>>2]=o;c[j+2384>>2]=n;c[j+3408>>2]=n;c[j+2388>>2]=e;c[j+3412>>2]=e;c[j+2392>>2]=q;c[j+3416>>2]=q;c[j+348>>2]=o;c[j+352>>2]=n;c[j+356>>2]=e;c[j+360>>2]=q;c[j+1372>>2]=o;c[j+1376>>2]=n;c[j+1380>>2]=e;c[j+1384>>2]=q;c[j+2396>>2]=o;c[j+3420>>2]=o;c[j+2400>>2]=n;c[j+3424>>2]=n;c[j+2404>>2]=e;c[j+3428>>2]=e;c[j+2408>>2]=q;c[j+3432>>2]=q;q=c[3541340]|0;c[j+396>>2]=q;e=q+256|0;c[j+400>>2]=e;n=q+512|0;c[j+404>>2]=n;o=q+768|0;c[j+408>>2]=o;c[j+1420>>2]=q;c[j+1424>>2]=e;c[j+1428>>2]=n;c[j+1432>>2]=o;c[j+2444>>2]=q;c[j+3468>>2]=q;c[j+2448>>2]=e;c[j+3472>>2]=e;c[j+2452>>2]=n;c[j+3476>>2]=n;c[j+2456>>2]=o;c[j+3480>>2]=o;o=c[3541366]|0;c[j+428>>2]=o;c[j+2476>>2]=o;c[j+3500>>2]=o;if(!k){o=j;gGC(o|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=l;c[2417276]=m;c[1836236]=-1}}while(0);c[2113202]=51200;o=c[3541404]|0;if((o|0)!=0){gu[o&16383]()}c[3541474]=11166;c[3541392]=1636;c[3541466]=68;a[14165760]=1;a[14165472]=16;a[14165480]=-1;o=a[14165488]|0;switch(o<<24>>24){case 2:case 3:case 4:case 5:case 8:case 6:case 13:{n=a[9688]|0?3204:0;e=0;while(1){if((e|0)>=1024){t=0;break}u=9638528+(e<<2)|0;if((c[u>>2]|0)==0){g=46307;break}else{e=e+1|0}}do{if((g|0)==46307){e=gGq(n)|0;c[u>>2]=e;if((e|0)==0){t=0;break}gGz(e|0,0,n|0);t=e}}while(0);c[2112958]=t;v=a[14165488]|0;break};default:{v=o}}switch(v<<24>>24){case 9:case 10:case 12:case 14:case 17:case 18:{n=a[9688]|0?6408:0;e=0;while(1){if((e|0)>=1024){w=0;break}x=9638528+(e<<2)|0;if((c[x>>2]|0)==0){g=46314;break}else{e=e+1|0}}do{if((g|0)==46314){e=gGq(n)|0;c[x>>2]=e;if((e|0)==0){w=0;break}gGz(e|0,0,n|0);w=e}}while(0);c[2112958]=w;y=a[14165488]|0;break};default:{y=v}}if(y<<24>>24==11){n=a[9688]|0?9612:0;e=0;while(1){if((e|0)>=1024){z=0;break}A=9638528+(e<<2)|0;if((c[A>>2]|0)==0){g=46321;break}else{e=e+1|0}}do{if((g|0)==46321){e=gGq(n)|0;c[A>>2]=e;if((e|0)==0){z=0;break}gGz(e|0,0,n|0);z=e}}while(0);c[2112958]=z;B=a[14165488]|0}else{B=y}L59146:do{switch(B<<24>>24){case 2:case 5:case 4:case 3:case 8:case 9:case 10:case 11:case 12:case 6:case 13:case 14:case 17:case 18:{n=c[2112958]|0;c[2112972]=n;e=a[9688]|0?534:0;c[2112973]=n+(e<<1);c[2112974]=n+(e<<1<<1);switch(B<<24>>24){case 9:case 10:case 11:case 12:case 14:case 17:case 18:{break};default:{g=46328;break L59146}}c[2112975]=n+((e*3|0)<<1);c[2112976]=n+(e<<2<<1);c[2112977]=n+((e*5|0)<<1);if(B<<24>>24!=11){g=46328;break L59146}c[2112978]=n+((e*6|0)<<1);c[2112979]=n+((e*7|0)<<1);c[2112980]=n+(e<<3<<1);g=46379;break};default:{g=46328}}}while(0);if((g|0)==46328){if((B-2&255)<3){e=a[9680]|0?32e3:0;c[3542220]=11200;if((c[2113008]|0)==0){gGz(14168888,0,252);c[3542223]=e;gGz(14168896,0,16);c[3542234]=~~((+(e|0)*32768.0*8.0+894875.0)/1789750.0);e=31;C=32767.0;while(1){c[14169012+(e<<2)>>2]=~~(C+.5);n=e-1|0;if((n|0)>0){e=n;C=C/1.188502227}else{break}}c[3542253]=0;h[1771269]=1.0;h[1771270]=1.0;h[1771271]=1.0;c[3542574]=3;c[3542575]=3;c[3542576]=3;mB(0);c[2113008]=(c[2113008]|0)+1;D=a[14165488]|0}else{D=B}h[1771269]=.5;c[3542574]=3;h[1771270]=.5;c[3542575]=3;h[1771271]=.5;c[3542576]=3;E=D}else{E=B}if(E<<24>>24==13){e=a[9680]|0?32e3:0;c[3542220]=11200;if((c[2113008]|0)==0){gGz(14168888,0,252);c[3542223]=e;c[3542224]=3296;c[3542225]=0;c[3542226]=0;c[3542227]=0;c[3542234]=~~((+(e|0)*32768.0*8.0+894875.0)/1789750.0);e=31;C=32767.0;while(1){c[14169012+(e<<2)>>2]=~~(C+.5);n=e-1|0;if((n|0)>0){e=n;C=C/1.188502227}else{break}}c[3542253]=0;h[1771269]=1.0;h[1771270]=1.0;h[1771271]=1.0;c[3542574]=3;c[3542575]=3;c[3542576]=3;mB(0);c[2113008]=(c[2113008]|0)+1;F=a[14165488]|0}else{F=13}h[1771269]=.2;c[3542574]=3;h[1771270]=.2;c[3542575]=3;h[1771271]=.2;c[3542576]=3;G=F}else{G=E}if(G<<24>>24==5){e=a[9680]|0?32e3:0;c[3542220]=11200;if((c[2113008]|0)==0){gGz(14168888,0,252);c[3542223]=e;c[3542224]=3148;c[3542225]=0;c[3542226]=0;c[3542227]=0;c[3542234]=~~((+(e|0)*32768.0*8.0+81.0e4)/162.0e4);e=31;C=32767.0;while(1){c[14169012+(e<<2)>>2]=~~(C+.5);n=e-1|0;if((n|0)>0){e=n;C=C/1.188502227}else{break}}c[3542253]=0;h[1771269]=1.0;h[1771270]=1.0;h[1771271]=1.0;c[3542574]=3;c[3542575]=3;c[3542576]=3;mB(0);c[2113008]=(c[2113008]|0)+1;H=a[14165488]|0}else{H=5}h[1771269]=.5;c[3542574]=3;h[1771270]=.5;c[3542575]=3;h[1771271]=.5;c[3542576]=3;I=H}else{I=G}if(I<<24>>24==6){e=a[9680]|0?32e3:0;c[3542220]=11200;if((c[2113008]|0)==0){gGz(14168888,0,252);c[3542223]=e;gGz(14168896,0,16);c[3542234]=~~((+(e|0)*32768.0*8.0+768.0e3)/1536.0e3);e=31;C=32767.0;while(1){c[14169012+(e<<2)>>2]=~~(C+.5);n=e-1|0;if((n|0)>0){e=n;C=C/1.188502227}else{break}}c[3542253]=0;h[1771269]=1.0;h[1771270]=1.0;h[1771271]=1.0;c[3542574]=3;c[3542575]=3;c[3542576]=3;mB(0);c[2113008]=(c[2113008]|0)+1;J=a[14165488]|0}else{J=6}h[1771269]=.2;c[3542574]=3;h[1771270]=.2;c[3542575]=3;h[1771271]=.2;c[3542576]=3;K=J}else{K=I}if(K<<24>>24==8){e=a[9680]|0?32e3:0;c[3542220]=11200;if((c[2113008]|0)==0){gGz(14168888,0,252);c[3542223]=e;c[3542224]=2266;c[3542225]=1304;c[3542226]=0;c[3542227]=0;c[3542234]=~~((+(e|0)*32768.0*8.0+894875.0)/1789750.0);e=31;C=32767.0;while(1){c[14169012+(e<<2)>>2]=~~(C+.5);n=e-1|0;if((n|0)>0){e=n;C=C/1.188502227}else{break}}c[3542253]=0;h[1771269]=1.0;h[1771270]=1.0;h[1771271]=1.0;c[3542574]=3;c[3542575]=3;c[3542576]=3;mB(0);c[2113008]=(c[2113008]|0)+1;L=a[14165488]|0}else{L=8}c[2440626]=0;c[2440624]=65536;c[2440633]=0;c[2440646]=0;c[2440644]=65536;c[2440653]=1;c[2440666]=0;c[2440664]=65536;c[2440673]=1;h[1220314]=.75;h[1220324]=.75;h[1220334]=.75;h[1220315]=1.0;c[2440632]=3;h[1220325]=1.0;c[2440652]=3;h[1220335]=1.0;c[2440672]=3;M=L}else{M=K}if(M<<24>>24==9){e=a[9680]|0?32e3:0;c[3542220]=11200;n=c[2113008]|0;if((n|0)==0){gGz(14168888,0,252);c[3542223]=e;gGz(14168896,0,16);c[3542234]=~~((+(e|0)*32768.0*8.0+894875.0)/1789750.0);o=31;C=32767.0;while(1){c[14169012+(o<<2)>>2]=~~(C+.5);q=o-1|0;if((q|0)>0){o=q;C=C/1.188502227}else{break}}c[3542253]=0;h[1771269]=1.0;h[1771270]=1.0;h[1771271]=1.0;c[3542574]=3;c[3542575]=3;c[3542576]=3;mB(0);o=(c[2113008]|0)+1|0;c[2113008]=o;N=o;O=a[9680]|0?32e3:0}else{N=n;O=e}c[3542220]=11200;if((N|0)==1){gGz(14169140,0,252);c[3542286]=O;c[3542287]=2266;c[3542288]=2348;c[3542289]=0;c[3542290]=0;c[3542297]=~~((+(O|0)*32768.0*8.0+894875.0)/1789750.0);o=31;C=32767.0;while(1){c[14169264+(o<<2)>>2]=~~(C+.5);q=o-1|0;if((q|0)>0){o=q;C=C/1.188502227}else{break}}c[3542316]=0;h[1771272]=1.0;h[1771273]=1.0;h[1771274]=1.0;c[3542577]=3;c[3542578]=3;c[3542579]=3;mB(1);c[2113008]=(c[2113008]|0)+1}c[2440626]=0;c[2440624]=65536;c[2440633]=0;c[2440646]=0;c[2440644]=65536;c[2440653]=1;c[2440666]=0;c[2440664]=65536;c[2440673]=1;c[2440686]=0;c[2440684]=65536;c[2440693]=1;c[2440706]=0;c[2440704]=65536;c[2440713]=1;c[2440726]=0;c[2440724]=65536;c[2440733]=1;h[1220314]=.5;h[1220324]=.5;h[1220334]=.5;h[1220344]=.5;h[1220354]=.5;h[1220364]=.5;h[1220315]=1.0;c[2440632]=3;h[1220325]=1.0;c[2440652]=3;h[1220335]=1.0;c[2440672]=3;h[1220345]=1.0;c[2440692]=3;h[1220355]=1.0;c[2440712]=3;h[1220365]=1.0;c[2440732]=3;P=a[14165488]|0}else{P=M}if(P<<24>>24==10){o=a[9680]|0?32e3:0;c[3542220]=11200;e=c[2113008]|0;if((e|0)==0){gGz(14168888,0,252);c[3542223]=o;c[3542224]=2348;c[3542225]=0;c[3542226]=0;c[3542227]=0;c[3542234]=~~((+(o|0)*32768.0*8.0+894875.0)/1789750.0);n=31;C=32767.0;while(1){c[14169012+(n<<2)>>2]=~~(C+.5);q=n-1|0;if((q|0)>0){n=q;C=C/1.188502227}else{break}}c[3542253]=0;h[1771269]=1.0;h[1771270]=1.0;h[1771271]=1.0;c[3542574]=3;c[3542575]=3;c[3542576]=3;mB(0);n=(c[2113008]|0)+1|0;c[2113008]=n;Q=n;R=a[9680]|0?32e3:0}else{Q=e;R=o}c[3542220]=11200;if((Q|0)==1){gGz(14169140,0,252);c[3542286]=R;c[3542287]=2266;c[3542288]=0;c[3542289]=0;c[3542290]=0;c[3542297]=~~((+(R|0)*32768.0*8.0+894875.0)/1789750.0);n=31;C=32767.0;while(1){c[14169264+(n<<2)>>2]=~~(C+.5);q=n-1|0;if((q|0)>0){n=q;C=C/1.188502227}else{break}}c[3542316]=0;h[1771272]=1.0;h[1771273]=1.0;h[1771274]=1.0;c[3542577]=3;c[3542578]=3;c[3542579]=3;mB(1);c[2113008]=(c[2113008]|0)+1}h[1771269]=.25;c[3542574]=3;h[1771270]=.25;c[3542575]=3;h[1771271]=.25;c[3542576]=3;h[1771272]=.25;c[3542577]=3;h[1771273]=.25;c[3542578]=3;h[1771274]=.25;c[3542579]=3;S=a[14165488]|0}else{S=P}if(S<<24>>24==11){g=46379}else{T=S}}if((g|0)==46379){n=a[9680]|0?32e3:0;c[3542220]=11200;o=c[2113008]|0;if((o|0)==0){gGz(14168888,0,252);c[3542223]=n;gGz(14168896,0,16);c[3542234]=~~((+(n|0)*32768.0*8.0+894875.0)/1789750.0);e=31;C=32767.0;while(1){c[14169012+(e<<2)>>2]=~~(C+.5);q=e-1|0;if((q|0)>0){e=q;C=C/1.188502227}else{break}}c[3542253]=0;h[1771269]=1.0;h[1771270]=1.0;h[1771271]=1.0;c[3542574]=3;c[3542575]=3;c[3542576]=3;mB(0);e=(c[2113008]|0)+1|0;c[2113008]=e;U=e;V=a[9680]|0?32e3:0}else{U=o;V=n}c[3542220]=11200;if((U|0)==1){gGz(14169140,0,252);c[3542286]=V;c[3542287]=2266;c[3542288]=2348;c[3542289]=0;c[3542290]=0;c[3542297]=~~((+(V|0)*32768.0*8.0+894875.0)/1789750.0);e=31;C=32767.0;while(1){c[14169264+(e<<2)>>2]=~~(C+.5);q=e-1|0;if((q|0)>0){e=q;C=C/1.188502227}else{break}}c[3542316]=0;h[1771272]=1.0;h[1771273]=1.0;h[1771274]=1.0;c[3542577]=3;c[3542578]=3;c[3542579]=3;mB(1);e=(c[2113008]|0)+1|0;c[2113008]=e;W=e;X=a[9680]|0?32e3:0}else{W=U;X=V}c[3542220]=11200;if((W|0)==2){gGz(14169392,0,252);c[3542349]=X;gGz(14169400,0,16);c[3542360]=~~((+(X|0)*32768.0*8.0+894875.0)/1789750.0);e=31;C=32767.0;while(1){c[14169516+(e<<2)>>2]=~~(C+.5);n=e-1|0;if((n|0)>0){e=n;C=C/1.188502227}else{break}}c[3542379]=0;h[1771275]=1.0;h[1771276]=1.0;h[1771277]=1.0;c[3542580]=3;c[3542581]=3;c[3542582]=3;mB(2);c[2113008]=(c[2113008]|0)+1}c[2440626]=0;c[2440624]=65536;c[2440633]=0;c[2440646]=0;c[2440644]=65536;c[2440653]=1;c[2440666]=0;c[2440664]=65536;c[2440673]=1;c[2440686]=0;c[2440684]=65536;c[2440693]=1;c[2440706]=0;c[2440704]=65536;c[2440713]=1;c[2440726]=0;c[2440724]=65536;c[2440733]=1;h[1220314]=.5;h[1220324]=.5;h[1220334]=.5;h[1220344]=.5;h[1220354]=.5;h[1220364]=.5;h[1220315]=1.0;c[2440632]=3;h[1220325]=1.0;c[2440652]=3;h[1220335]=1.0;c[2440672]=3;h[1220345]=1.0;c[2440692]=3;h[1220355]=1.0;c[2440712]=3;h[1220365]=1.0;c[2440732]=3;T=a[14165488]|0}if(T<<24>>24==14){e=a[9680]|0?32e3:0;c[3542220]=11200;n=c[2113008]|0;if((n|0)==0){gGz(14168888,0,252);c[3542223]=e;c[3542224]=2348;c[3542225]=0;c[3542226]=0;c[3542227]=0;c[3542234]=~~((+(e|0)*32768.0*8.0+894875.0)/1789750.0);o=31;C=32767.0;while(1){c[14169012+(o<<2)>>2]=~~(C+.5);q=o-1|0;if((q|0)>0){o=q;C=C/1.188502227}else{break}}c[3542253]=0;h[1771269]=1.0;h[1771270]=1.0;h[1771271]=1.0;c[3542574]=3;c[3542575]=3;c[3542576]=3;mB(0);o=(c[2113008]|0)+1|0;c[2113008]=o;Y=o;Z=a[9680]|0?32e3:0}else{Y=n;Z=e}c[3542220]=11200;if((Y|0)==1){gGz(14169140,0,252);c[3542286]=Z;c[3542287]=2266;c[3542288]=0;c[3542289]=0;c[3542290]=0;c[3542297]=~~((+(Z|0)*32768.0*8.0+894875.0)/1789750.0);o=31;C=32767.0;while(1){c[14169264+(o<<2)>>2]=~~(C+.5);q=o-1|0;if((q|0)>0){o=q;C=C/1.188502227}else{break}}c[3542316]=0;h[1771272]=1.0;h[1771273]=1.0;h[1771274]=1.0;c[3542577]=3;c[3542578]=3;c[3542579]=3;mB(1);c[2113008]=(c[2113008]|0)+1}h[1771269]=1.0;c[3542574]=3;h[1771270]=1.0;c[3542575]=3;h[1771271]=1.0;c[3542576]=3;h[1771272]=1.0;c[3542577]=3;h[1771273]=1.0;c[3542578]=3;h[1771274]=1.0;c[3542579]=3;_=a[14165488]|0}else{_=T}if(_<<24>>24==18){o=a[9680]|0?32e3:0;c[3542220]=11200;e=c[2113008]|0;if((e|0)==0){gGz(14168888,0,252);c[3542223]=o;gGz(14168896,0,16);c[3542234]=~~((+(o|0)*32768.0*8.0+894875.0)/1789750.0);n=31;C=32767.0;while(1){c[14169012+(n<<2)>>2]=~~(C+.5);q=n-1|0;if((q|0)>0){n=q;C=C/1.188502227}else{break}}c[3542253]=0;h[1771269]=1.0;h[1771270]=1.0;h[1771271]=1.0;c[3542574]=3;c[3542575]=3;c[3542576]=3;mB(0);n=(c[2113008]|0)+1|0;c[2113008]=n;$=n;aa=a[9680]|0?32e3:0}else{$=e;aa=o}c[3542220]=11200;if(($|0)==1){gGz(14169140,0,252);c[3542286]=aa;gGz(14169148,0,16);c[3542297]=~~((+(aa|0)*32768.0*8.0+894875.0)/1789750.0);n=31;C=32767.0;while(1){c[14169264+(n<<2)>>2]=~~(C+.5);q=n-1|0;if((q|0)>0){n=q;C=C/1.188502227}else{break}}c[3542316]=0;h[1771272]=1.0;h[1771273]=1.0;h[1771274]=1.0;c[3542577]=3;c[3542578]=3;c[3542579]=3;mB(1);c[2113008]=(c[2113008]|0)+1}h[1771269]=.25;c[3542574]=3;h[1771270]=.25;c[3542575]=3;h[1771271]=.25;c[3542576]=3;h[1771272]=.25;c[3542577]=3;h[1771273]=.25;c[3542578]=3;h[1771274]=.25;c[3542579]=3;ab=a[14165488]|0}else{ab=_}if(ab<<24>>24==12){n=a[9680]|0?32e3:0;c[3542220]=11200;o=c[2113008]|0;if((o|0)==0){gGz(14168888,0,252);c[3542223]=n;c[3542224]=0;c[3542225]=0;c[3542226]=2962;c[3542227]=1514;c[3542234]=~~((+(n|0)*32768.0*8.0+894875.0)/1789750.0);e=31;C=32767.0;while(1){c[14169012+(e<<2)>>2]=~~(C+.5);q=e-1|0;if((q|0)>0){e=q;C=C/1.188502227}else{break}}c[3542253]=0;h[1771269]=1.0;h[1771270]=1.0;h[1771271]=1.0;c[3542574]=3;c[3542575]=3;c[3542576]=3;mB(0);e=(c[2113008]|0)+1|0;c[2113008]=e;ac=e;ad=a[9680]|0?32e3:0}else{ac=o;ad=n}c[3542220]=11200;if((ac|0)==1){gGz(14169140,0,252);c[3542286]=ad;c[3542287]=2266;c[3542288]=2348;c[3542289]=0;c[3542290]=0;c[3542297]=~~((+(ad|0)*32768.0*8.0+894875.0)/1789750.0);e=31;C=32767.0;while(1){c[14169264+(e<<2)>>2]=~~(C+.5);q=e-1|0;if((q|0)>0){e=q;C=C/1.188502227}else{break}}c[3542316]=0;h[1771272]=1.0;h[1771273]=1.0;h[1771274]=1.0;c[3542577]=3;c[3542578]=3;c[3542579]=3;mB(1);c[2113008]=(c[2113008]|0)+1}h[1771269]=.1;c[3542574]=3;h[1771270]=.1;c[3542575]=3;h[1771271]=.1;c[3542576]=3;h[1771272]=.1;c[3542577]=3;h[1771273]=.1;c[3542578]=3;h[1771274]=.1;c[3542579]=3;c[2440626]=0;c[2440624]=65536;c[2440633]=0;c[2440646]=0;c[2440644]=65536;c[2440653]=1;c[2440666]=0;c[2440664]=65536;c[2440673]=1;c[2440686]=0;c[2440684]=65536;c[2440693]=1;c[2440706]=0;c[2440704]=65536;c[2440713]=1;c[2440726]=0;c[2440724]=65536;c[2440733]=1;h[1220314]=.5;h[1220324]=.5;h[1220334]=.5;h[1220344]=.5;h[1220354]=.5;h[1220364]=.5;h[1220315]=.1;c[2440632]=3;h[1220325]=.1;c[2440652]=3;h[1220335]=.1;c[2440672]=3;h[1220345]=.1;c[2440692]=3;h[1220355]=.1;c[2440712]=3;h[1220365]=.1;c[2440732]=3;c[2405758]=1;gGz(9542544,0,32);c[2385641]=1;h[1192819]=1.0;c[2385642]=3;c[2385643]=1926;e=0;do{n=e*257|0;b[9732544+(e<<1)>>1]=((n|0)/2|0)&65535;b[9753784+(e<<1)>>1]=n+32768&65535;e=e+1|0;}while((e|0)<256);c[3528842]=1;h[1192819]=1.0;c[2385642]=3;ae=a[14165488]|0}else{ae=ab}if((ae<<24>>24|0)==7){c[2405758]=1;gGz(9542544,0,32);c[2385641]=1;h[1192819]=1.0;c[2385642]=3;c[2385643]=2706;e=0;do{n=e*257|0;b[9732544+(e<<1)>>1]=((n|0)/2|0)&65535;b[9753784+(e<<1)>>1]=n+32768&65535;e=e+1|0;}while((e|0)<256);c[3528842]=1;h[1192819]=.75;c[2385642]=3;g=46442}else if((ae<<24>>24|0)==16){TS(0,3072e3,32768,6,0,0);e=c[2420348]|0;h[e+192>>3]=1.0;c[e+200>>2]=3;af=a[14165488]|0;g=46429}else{af=ae;g=46429}if((g|0)==46429){if(af<<24>>24==15){TS(0,3072e3,32768,6,0,0);TS(1,3072e3,32768,6,0,1);TS(2,3072e3,32768,6,0,1);e=c[2420348]|0;h[e+192>>3]=1.0;c[e+200>>2]=3;e=c[2420346]|0;h[e+192>>3]=1.0;c[e+200>>2]=3;e=c[2420344]|0;h[e+192>>3]=1.0;c[e+200>>2]=3;ah=a[14165488]|0}else{ah=af}if(ah<<24>>24==17){e=a[9680]|0?32e3:0;c[3542220]=11200;n=c[2113008]|0;if((n|0)==0){gGz(14168888,0,252);c[3542223]=e;gGz(14168896,0,16);c[3542234]=~~((+(e|0)*32768.0*8.0+894875.0)/1789750.0);o=31;C=32767.0;while(1){c[14169012+(o<<2)>>2]=~~(C+.5);q=o-1|0;if((q|0)>0){o=q;C=C/1.188502227}else{break}}c[3542253]=0;h[1771269]=1.0;h[1771270]=1.0;h[1771271]=1.0;c[3542574]=3;c[3542575]=3;c[3542576]=3;mB(0);o=(c[2113008]|0)+1|0;c[2113008]=o;ai=o;aj=a[9680]|0?32e3:0}else{ai=n;aj=e}c[3542220]=11200;if((ai|0)==1){gGz(14169140,0,252);c[3542286]=aj;c[3542287]=2266;c[3542288]=34;c[3542289]=0;c[3542290]=0;c[3542297]=~~((+(aj|0)*32768.0*8.0+894875.0)/1789750.0);o=31;C=32767.0;while(1){c[14169264+(o<<2)>>2]=~~(C+.5);q=o-1|0;if((q|0)>0){o=q;C=C/1.188502227}else{break}}c[3542316]=0;h[1771272]=1.0;h[1771273]=1.0;h[1771274]=1.0;c[3542577]=3;c[3542578]=3;c[3542579]=3;mB(1);c[2113008]=(c[2113008]|0)+1}h[1771269]=.2;c[3542574]=3;h[1771270]=.2;c[3542575]=3;h[1771271]=.2;c[3542576]=3;h[1771272]=.2;c[3542577]=3;h[1771273]=.2;c[3542578]=3;h[1771274]=.2;c[3542579]=3;ak=a[14165488]|0}else{ak=ah}if((ak<<24>>24|0)==1|(ak<<24>>24|0)==7){g=46442}}if((g|0)==46442){a[14165512]=0;h[932735]=0.0;o=0;while(1){if((o|0)>=1024){al=0;break}am=9638528+(o<<2)|0;if((c[am>>2]|0)==0){g=46445;break}else{o=o+1|0}}do{if((g|0)==46445){o=gGq(64e3)|0;c[am>>2]=o;if((o|0)==0){al=0;break}gGz(o|0,0,64e3);al=o}}while(0);c[2443338]=al;a[6885952]=1;a[5397504]=1;o=0;while(1){if((o|0)>=1024){an=0;break}ao=9638528+(o<<2)|0;if((c[ao>>2]|0)==0){g=46450;break}else{o=o+1|0}}do{if((g|0)==46450){o=gGq(88200)|0;c[ao>>2]=o;if((o|0)==0){an=0;break}gGz(o|0,0,88200);an=o}}while(0);c[2443336]=an;o=c[2443338]|0;e=0;n=0;while(1){q=n;p=-614e4;do{ap=q<<1;q=(q>>>16^1^q>>>4)&1|ap;p=p+8e3|0;}while((p|0)<0);b[o+(e<<1)>>1]=(ap&131072|0)!=0?17920:-17920;p=e+1|0;if((p|0)<32e3){e=p;n=q}else{break}}n=a[6885952]|0;C=n?.9999561407356146:0.0;aq=n?.999546588083036:0.0;ar=n?.12093726379440664:0.0;as=n?.8137166549768429:0.0;at=n?.9556615326900152:0.0;au=n?.36281179138321995:0.0;if(a[5397504]|0){av=3.8430555555555554;aw=4.1715277777777775;e=n?2205:0;ax=0.0;ay=.2;az=5.0;aA=0.0;n=0;while(1){aB=(b[o+(((~~aA|0)%32e3|0)<<1)>>1]|0)==17920?4.5:.2;aC=au+aA;aD=av*.8/3.3333333333333335;aE=ar+ax;if(aE<aD){aF=aE}else{aF=aE-aD}do{if(aF<aD*.5925925925925926){b[an+(n<<1)>>1]=~~(az/5.0*32767.0);if(ay!=4.5){aG=az;break}aG=aq*az}else{b[an+(n<<1)>>1]=0;aG=az}}while(0);aD=ay-aw;aE=aw+(aD-C*aD);aD=av-aE;aH=aE+(aD-C*aD);aD=aH-av;aE=av+(aD-as*aD);aD=aB-aE;if(ay==.2){q=e-1|0;aI=(q|0)==0?4.5:ay;aJ=q}else{aI=ay;aJ=e}q=n+1|0;if(q>>>0<44100){av=aE+(aD-at*aD);aw=aH;e=aJ;ax=aF;ay=aI;az=aG;aA=aC;n=q}else{break}}}gGz(14108688,0,128);n=0;do{e=(n&1|0)==0;aA=e?30303031303030302.0e-21:1.0e-12;az=e?1.0e-12:30303031303030302.0e-21;e=(n&4|0)!=0;if(e){aK=az+4545454545454545.0e-20;aL=aA}else{aK=az;aL=aA+4545454545454545.0e-20}aA=1.0/aL;b[14108688+(n<<1)>>1]=~~(aA*32768.0/(aA+1.0/aK)+-16384.0);if(e){aM=aK+1.0e-4;aN=aL}else{aM=aK;aN=aL+1.0e-4}aA=1.0/aN;b[14108720+(n<<1)>>1]=~~(aA*32768.0/(aA+1.0/aM)+-16384.0);if((n&8|0)==0){aO=aK;aP=aL+6666666666666667.0e-20}else{aO=aK+6666666666666667.0e-20;aP=aL}aA=1.0/aP;b[14108752+(n<<1)>>1]=~~(aA*32768.0/(aA+1.0/aO)+-16384.0);if(e){aQ=aO;aR=aP+1.0e-4}else{aQ=aO+1.0e-4;aR=aP}aA=1.0/aR;b[14108784+(n<<1)>>1]=~~(aA*32768.0/(aA+1.0/aQ)+-16384.0);n=n+1|0;}while(n>>>0<16);c[3541406]=255;c[3541336]=0;h[932739]=185.0;h[932738]=0.0;h[83962]=1.0;a[6885960]=1}c[3541360]=0;c[3541358]=-1;c[3541362]=0;n=255;e=0;o=0;while(1){q=511;p=e;m=o;while(1){l=p<<1;aS=(p>>>16^1^p>>>4)&1|l;do{if((l&65536|0)==0){if((aS&255|0)!=255){aT=m;break}j=p>>>7&63;if((j|0)==63){aT=m;break}c[9669288+(m*12|0)>>2]=q;c[9669292+(m*12|0)>>2]=n;c[9669296+(m*12|0)>>2]=j^63;aT=m+1|0}else{aT=m}}while(0);if((q|0)>0){q=q-1|0;p=aS;m=aT}else{break}}if((n|0)>0){n=n-1|0;e=aS;o=aT}else{break}}o=c[642608+(c[2436]<<2)>>2]|0;e=c[o+128>>2]|0;if((c[o+52>>2]&4|0)==0){c[2113068]=e;n=c[o+132>>2]|0;c[2113070]=n;c[2443814]=e;c[2440436]=n;aU=e;aV=n}else{c[2113070]=e;n=c[o+132>>2]|0;c[2113068]=n;c[2440436]=e;c[2443814]=n;aU=n;aV=e}e=ag(aU<<1,aV)|0;n=gGq(e)|0;c[2112926]=n;if((n|0)!=0){gGz(n|0,0,e|0)}a[14165880]=2;a07();i=0;return i|0}}while(0);c[3541422]=0;i=1;return i|0}function a05(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;e=i;i=i+1072|0;f=e|0;g=e+112|0;h=e+120|0;j=e+232|0;k=e+240|0;l=e+352|0;m=e+360|0;n=e+472|0;o=e+480|0;p=e+592|0;q=e+600|0;r=e+712|0;s=e+720|0;t=e+832|0;u=e+840|0;v=e+952|0;w=e+960|0;x=w+108|0;c[x>>2]=0;y=w+100|0;c[y>>2]=0;if(!b){b=-1;do{c[y>>2]=0;c[x>>2]=0;b=b+1|0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](w,b)|0;switch(c[x>>2]&255|0){case 2:{z=c[y>>2]|0;c[3541316]=(c[3541316]|0)+z;c[3541318]=(c[3541318]|0)+1;A=z;break};case 1:{z=c[y>>2]|0;c[3541322]=(c[3541322]|0)+z;c[3541326]=(c[3541326]|0)+1;A=z;break};case 5:{z=c[y>>2]|0;c[3541352]=(c[3541352]|0)+z;c[3541354]=(c[3541354]|0)+1;A=z;break};case 3:{z=c[y>>2]|0;c[3541310]=(c[3541310]|0)+z;c[3541312]=(c[3541312]|0)+1;A=z;break};case 8:{z=c[y>>2]|0;c[3541382]=(c[3541382]|0)+z;c[3541384]=(c[3541384]|0)+1;A=z;break};case 7:{z=c[y>>2]|0;c[3541398]=(c[3541398]|0)+z;c[3541400]=(c[3541400]|0)+1;A=z;break};case 6:{z=c[y>>2]|0;c[3541344]=(c[3541344]|0)+z;c[3541346]=(c[3541346]|0)+1;A=z;break};case 4:{z=c[y>>2]|0;c[3541348]=(c[3541348]|0)+z;c[3541350]=(c[3541350]|0)+1;A=z;break};default:{A=c[y>>2]|0}}}while((A|0)!=0);A=c[3541348]|0;if((A|0)!=0){c[3541414]=A>>>4;c[3541412]=A>>>6;x=A<<2;c[1865546]=x;c[1865412]=x}x=c[3541352]|0;if((x|0)!=0){c[3541414]=x>>>4;c[1865546]=x<<2}x=c[3541344]|0;if((x|0)==0){B=0;i=e;return B|0}c[3541412]=x>>>6;c[1865412]=x<<2;B=0;i=e;return B|0}L59428:do{if((c[3541326]|0)==0){C=0}else{x=u+108|0;A=u+100|0;b=0;z=0;while(1){D=(c[3541328]|0)+z|0;if((c[3542200]|0)==0){B=1;E=46680;break}c[x>>2]=0;c[A>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](u,b)|0;if((c[x>>2]|0)!=0){F=c[A>>2]|0;c[v>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](v,b,0)|0;if((F|0)<1){B=1;E=46672;break}if((gzL(D,0,b)|0)!=0){B=1;E=46678;break}}gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](w,b)|0;D=b+1|0;F=c[3541326]|0;if(D>>>0<F>>>0){b=D;z=(c[y>>2]|0)+z|0}else{C=F;break L59428}}if((E|0)==46672){i=e;return B|0}else if((E|0)==46678){i=e;return B|0}else if((E|0)==46680){i=e;return B|0}}}while(0);L59442:do{if((c[3541316]|0)==0){H=C}else{if(C>>>0>=((c[3541318]|0)+C|0)>>>0){H=C;break}v=s+108|0;u=s+100|0;z=C;b=0;while(1){A=(c[3541320]|0)+b|0;if((c[3542200]|0)==0){B=1;E=46679;break}c[v>>2]=0;c[u>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](s,z)|0;if((c[v>>2]|0)!=0){x=c[u>>2]|0;c[t>>2]=9534384;F=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[F&16383](t,z,0)|0;if((x|0)<1){B=1;E=46673;break}if((gzL(A,0,z)|0)!=0){B=1;E=46674;break}}gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](w,z)|0;A=z+1|0;x=c[3541326]|0;if(A>>>0<((c[3541318]|0)+x|0)>>>0){z=A;b=(c[y>>2]|0)+b|0}else{H=x;break L59442}}if((E|0)==46673){i=e;return B|0}else if((E|0)==46674){i=e;return B|0}else if((E|0)==46679){i=e;return B|0}}}while(0);L59457:do{if((c[3541310]|0)!=0){t=(c[3541318]|0)+H|0;if(t>>>0>=(t+(c[3541312]|0)|0)>>>0){break}s=q+108|0;C=q+100|0;b=t;t=0;while(1){z=(c[3541314]|0)+t|0;if((c[3542200]|0)==0){B=1;E=46681;break}c[s>>2]=0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](q,b)|0;if((c[s>>2]|0)!=0){u=c[C>>2]|0;c[r>>2]=9534384;v=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[v&16383](r,b,0)|0;if((u|0)<1){B=1;E=46682;break}if((gzL(z,0,b)|0)!=0){B=1;E=46683;break}}gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](w,b)|0;z=b+1|0;if(z>>>0<((c[3541318]|0)+(c[3541326]|0)+(c[3541312]|0)|0)>>>0){b=z;t=(c[y>>2]|0)+t|0}else{break L59457}}if((E|0)==46681){i=e;return B|0}else if((E|0)==46682){i=e;return B|0}else if((E|0)==46683){i=e;return B|0}}}while(0);r=c[3541348]|0;if((r|0)!=0){q=0;while(1){if((q|0)>=1024){I=0;break}J=9638528+(q<<2)|0;if((c[J>>2]|0)==0){E=46544;break}else{q=q+1|0}}do{if((E|0)==46544){q=gGq(r)|0;c[J>>2]=q;if((q|0)==0){I=0;break}gGz(q|0,0,r|0);I=q}}while(0);c[3541356]=I;r=(c[3541318]|0)+(c[3541326]|0)+(c[3541312]|0)|0;do{if(r>>>0<(r+(c[3541350]|0)|0)>>>0){if((c[3542200]|0)==0){B=1;i=e;return B|0}J=o+108|0;q=o+100|0;H=0;t=r;b=I;while(1){c[J>>2]=0;c[q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](o,t)|0;if((c[J>>2]|0)!=0){C=c[q>>2]|0;c[p>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](p,t,0)|0;if((C|0)<1){B=1;E=46684;break}if((gzL(b,0,t)|0)!=0){B=1;E=46685;break}}gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](w,t)|0;C=t+1|0;if(C>>>0>=((c[3541318]|0)+(c[3541326]|0)+(c[3541312]|0)+(c[3541350]|0)|0)>>>0){E=46554;break}s=(c[y>>2]|0)+H|0;if((c[3542200]|0)==0){B=1;E=46686;break}else{H=s;t=C;b=(c[3541356]|0)+s|0}}if((E|0)==46554){K=c[3541356]|0;break}else if((E|0)==46684){i=e;return B|0}else if((E|0)==46685){i=e;return B|0}else if((E|0)==46686){i=e;return B|0}}else{K=I}}while(0);I=c[3541414]|0;p=c[3541472]|0;if((I|0)>0){o=c[1865546]|0;r=0;do{b=r<<6;gGz(p+b|0,0,64);t=0;do{H=b+(c[1238464+(t<<2)>>2]|0)|0;q=(t<<3)+b|0;J=0;do{s=H+(c[614800+(J<<2)>>2]|0)|0;if(((d[K+((s|0)/8|0)|0]|0)&128>>>((s&7)>>>0)|0)!=0){s=p+(q+J)|0;a[s]=a[s]|2}J=J+1|0;}while((J|0)<8);t=t+1|0;}while((t|0)<8);t=o+b|0;J=0;do{q=t+(c[1238464+(J<<2)>>2]|0)|0;H=(J<<3)+b|0;s=0;do{C=q+(c[614800+(s<<2)>>2]|0)|0;if(((d[K+((C|0)/8|0)|0]|0)&128>>>((C&7)>>>0)|0)!=0){C=p+(H+s)|0;a[C]=a[C]|1}s=s+1|0;}while((s|0)<8);J=J+1|0;}while((J|0)<8);r=r+1|0;}while((r|0)<(I|0))}I=c[3541412]|0;r=c[3541364]|0;if((I|0)>0){p=c[1865412]|0;o=0;while(1){J=o<<8;gGz(r+J|0,0,256);b=0;do{t=J+(c[611776+(b<<2)>>2]|0)|0;s=(b<<4)+J|0;H=0;do{q=t+(c[601400+(H<<2)>>2]|0)|0;if(((d[K+((q|0)/8|0)|0]|0)&128>>>((q&7)>>>0)|0)!=0){q=r+(s+H)|0;a[q]=a[q]|2}H=H+1|0;}while((H|0)<16);b=b+1|0;}while((b|0)<16);b=p+J|0;H=0;do{s=b+(c[611776+(H<<2)>>2]|0)|0;t=(H<<4)+J|0;q=0;do{C=s+(c[601400+(q<<2)>>2]|0)|0;if(((d[K+((C|0)/8|0)|0]|0)&128>>>((C&7)>>>0)|0)!=0){C=r+(t+q)|0;a[C]=a[C]|1}q=q+1|0;}while((q|0)<16);H=H+1|0;}while((H|0)<16);H=o+1|0;if((H|0)<(I|0)){o=H}else{L=0;break}}}else{L=0}while(1){if((L|0)>=1024){break}M=9638528+(L<<2)|0;if((c[M>>2]|0)==(K|0)){E=46575;break}else{L=L+1|0}}if((E|0)==46575){gGr(K);c[M>>2]=0}c[3541356]=0}M=c[3541352]|0;if((M|0)!=0){K=0;while(1){if((K|0)>=1024){N=0;break}O=9638528+(K<<2)|0;if((c[O>>2]|0)==0){E=46580;break}else{K=K+1|0}}do{if((E|0)==46580){K=gGq(M)|0;c[O>>2]=K;if((K|0)==0){N=0;break}gGz(K|0,0,M|0);N=K}}while(0);c[3541356]=N;M=(c[3541318]|0)+(c[3541326]|0)+(c[3541312]|0)+(c[3541350]|0)|0;do{if(M>>>0<(M+(c[3541354]|0)|0)>>>0){if((c[3542200]|0)==0){B=1;i=e;return B|0}O=m+108|0;K=m+100|0;L=0;o=M;I=N;while(1){c[O>>2]=0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,o)|0;if((c[O>>2]|0)!=0){r=c[K>>2]|0;c[n>>2]=9534384;p=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[p&16383](n,o,0)|0;if((r|0)<1){B=1;E=46688;break}if((gzL(I,0,o)|0)!=0){B=1;E=46689;break}}gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](w,o)|0;r=o+1|0;if(r>>>0>=((c[3541318]|0)+(c[3541326]|0)+(c[3541312]|0)+(c[3541350]|0)+(c[3541354]|0)|0)>>>0){E=46590;break}p=(c[y>>2]|0)+L|0;if((c[3542200]|0)==0){B=1;E=46690;break}else{L=p;o=r;I=(c[3541356]|0)+p|0}}if((E|0)==46688){i=e;return B|0}else if((E|0)==46689){i=e;return B|0}else if((E|0)==46690){i=e;return B|0}else if((E|0)==46590){P=c[3541356]|0;break}}else{P=N}}while(0);N=c[3541414]|0;n=c[3541472]|0;if((N|0)>0){m=c[1865546]|0;M=0;while(1){I=M<<6;gGz(n+I|0,0,64);o=0;do{L=I+(c[1238464+(o<<2)>>2]|0)|0;K=(o<<3)+I|0;O=0;do{p=L+(c[614800+(O<<2)>>2]|0)|0;if(((d[P+((p|0)/8|0)|0]|0)&128>>>((p&7)>>>0)|0)!=0){p=n+(K+O)|0;a[p]=a[p]|2}O=O+1|0;}while((O|0)<8);o=o+1|0;}while((o|0)<8);o=m+I|0;O=0;do{K=o+(c[1238464+(O<<2)>>2]|0)|0;L=(O<<3)+I|0;p=0;do{r=K+(c[614800+(p<<2)>>2]|0)|0;if(((d[P+((r|0)/8|0)|0]|0)&128>>>((r&7)>>>0)|0)!=0){r=n+(L+p)|0;a[r]=a[r]|1}p=p+1|0;}while((p|0)<8);O=O+1|0;}while((O|0)<8);O=M+1|0;if((O|0)<(N|0)){M=O}else{Q=0;break}}}else{Q=0}while(1){if((Q|0)>=1024){break}R=9638528+(Q<<2)|0;if((c[R>>2]|0)==(P|0)){E=46602;break}else{Q=Q+1|0}}if((E|0)==46602){gGr(P);c[R>>2]=0}c[3541356]=0}R=c[3541344]|0;if((R|0)!=0){P=0;while(1){if((P|0)>=1024){S=0;break}T=9638528+(P<<2)|0;if((c[T>>2]|0)==0){E=46607;break}else{P=P+1|0}}do{if((E|0)==46607){P=gGq(R)|0;c[T>>2]=P;if((P|0)==0){S=0;break}gGz(P|0,0,R|0);S=P}}while(0);c[3541356]=S;R=(c[3541318]|0)+(c[3541326]|0)+(c[3541312]|0)+(c[3541350]|0)+(c[3541354]|0)|0;do{if(R>>>0<(R+(c[3541346]|0)|0)>>>0){if((c[3542200]|0)==0){B=1;i=e;return B|0}T=k+108|0;P=k+100|0;Q=0;M=R;N=S;while(1){c[T>>2]=0;c[P>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,M)|0;if((c[T>>2]|0)!=0){n=c[P>>2]|0;c[l>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](l,M,0)|0;if((n|0)<1){B=1;E=46692;break}if((gzL(N,0,M)|0)!=0){B=1;E=46693;break}}gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](w,M)|0;n=M+1|0;if(n>>>0>=((c[3541318]|0)+(c[3541326]|0)+(c[3541312]|0)+(c[3541350]|0)+(c[3541354]|0)+(c[3541346]|0)|0)>>>0){E=46617;break}m=(c[y>>2]|0)+Q|0;if((c[3542200]|0)==0){B=1;E=46694;break}else{Q=m;M=n;N=(c[3541356]|0)+m|0}}if((E|0)==46692){i=e;return B|0}else if((E|0)==46693){i=e;return B|0}else if((E|0)==46694){i=e;return B|0}else if((E|0)==46617){U=c[3541356]|0;break}}else{U=S}}while(0);S=c[3541412]|0;l=c[3541364]|0;if((S|0)>0){k=c[1865412]|0;R=0;while(1){N=R<<8;gGz(l+N|0,0,256);M=0;do{Q=N+(c[611776+(M<<2)>>2]|0)|0;P=(M<<4)+N|0;T=0;do{m=Q+(c[601400+(T<<2)>>2]|0)|0;if(((d[U+((m|0)/8|0)|0]|0)&128>>>((m&7)>>>0)|0)!=0){m=l+(P+T)|0;a[m]=a[m]|2}T=T+1|0;}while((T|0)<16);M=M+1|0;}while((M|0)<16);M=k+N|0;T=0;do{P=M+(c[611776+(T<<2)>>2]|0)|0;Q=(T<<4)+N|0;m=0;do{n=P+(c[601400+(m<<2)>>2]|0)|0;if(((d[U+((n|0)/8|0)|0]|0)&128>>>((n&7)>>>0)|0)!=0){n=l+(Q+m)|0;a[n]=a[n]|1}m=m+1|0;}while((m|0)<16);T=T+1|0;}while((T|0)<16);T=R+1|0;if((T|0)<(S|0)){R=T}else{V=0;break}}}else{V=0}while(1){if((V|0)>=1024){break}W=9638528+(V<<2)|0;if((c[W>>2]|0)==(U|0)){E=46629;break}else{V=V+1|0}}if((E|0)==46629){gGr(U);c[W>>2]=0}c[3541356]=0}L59660:do{if((c[3541398]|0)!=0){W=(c[3541318]|0)+(c[3541326]|0)+(c[3541312]|0)+(c[3541350]|0)+(c[3541354]|0)+(c[3541346]|0)|0;if(W>>>0>=(W+(c[3541400]|0)|0)>>>0){break}U=h+108|0;V=h+100|0;R=W;W=0;while(1){S=(c[3541402]|0)+W|0;if((c[3542200]|0)==0){B=1;E=46695;break}c[U>>2]=0;c[V>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](h,R)|0;if((c[U>>2]|0)!=0){l=c[V>>2]|0;c[j>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](j,R,0)|0;if((l|0)<1){B=1;E=46696;break}if((gzL(S,0,R)|0)!=0){B=1;E=46697;break}}gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](w,R)|0;S=R+1|0;if(S>>>0<((c[3541318]|0)+(c[3541326]|0)+(c[3541312]|0)+(c[3541350]|0)+(c[3541354]|0)+(c[3541346]|0)+(c[3541400]|0)|0)>>>0){R=S;W=(c[y>>2]|0)+W|0}else{break L59660}}if((E|0)==46695){i=e;return B|0}else if((E|0)==46696){i=e;return B|0}else if((E|0)==46697){i=e;return B|0}}}while(0);if((c[3541382]|0)==0){B=0;i=e;return B|0}j=c[3541326]|0;h=c[3541318]|0;W=c[3541312]|0;R=c[3541350]|0;V=c[3541354]|0;U=c[3541346]|0;S=c[3541400]|0;l=h+j+W+R+V+U+S|0;if(l>>>0>=(U+S+V+R+W+h+j+(c[3541384]|0)|0)>>>0){B=0;i=e;return B|0}j=f+108|0;h=f+100|0;W=l;l=0;while(1){R=(c[3541386]|0)+l|0;if((c[3542200]|0)==0){B=1;E=46700;break}c[j>>2]=0;c[h>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,W)|0;if((c[j>>2]|0)!=0){V=c[h>>2]|0;c[g>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](g,W,0)|0;if((V|0)<1){B=1;E=46701;break}if((gzL(R,0,W)|0)!=0){B=1;E=46702;break}}gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](w,W)|0;R=W+1|0;if(R>>>0<((c[3541346]|0)+(c[3541400]|0)+(c[3541354]|0)+(c[3541350]|0)+(c[3541312]|0)+(c[3541318]|0)+(c[3541326]|0)+(c[3541384]|0)|0)>>>0){W=R;l=(c[y>>2]|0)+l|0}else{B=0;E=46703;break}}if((E|0)==46700){i=e;return B|0}else if((E|0)==46701){i=e;return B|0}else if((E|0)==46702){i=e;return B|0}else if((E|0)==46703){i=e;return B|0}return 0}function a06(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0;a=c[3541422]|0;c[3541328]=a;b=c[3541322]|0;c[3541320]=a+b;d=c[3541316]|0;e=d+b|0;c[3541314]=a+e;b=c[3541310]|0;f=e+b|0;c[3541386]=a+f;e=f+(c[3541382]|0)|0;c[3541402]=a+e;f=e+(c[3541398]|0)|0;e=a+f|0;c[3541394]=e;c[3541334]=e;c[3541340]=a+(f+4096);c[3541366]=a+(f+5120);c[3541380]=a+(f+6144);c[3541454]=a+(f+6176);e=a+(f+6207)|0;if((d|0)==0){g=e}else{c[3541332]=e;g=a+(f+7231)|0}if((b|0)==0){h=g}else{c[3541330]=g;h=g+1024|0}c[3541396]=h;c[3541472]=h;g=c[3541414]<<6;c[3541364]=h+g;b=(c[3541412]<<8)+g|0;c[3541410]=h+b;c[3541420]=h+(b+1568);return}function a07(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if((c[3541382]|0)!=0){c[2110940]=8443768;gGz(9718136,0,38);a[9718144]=10;a[9718145]=0;gGC(9669136,9718136,38)|0;c[2444]=-1}if((c[3541322]|0)!=0){d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];f=c[3528484]|0;c[2076596]=f;g=c[2417276]|0;c[3541536]=g;c[1836236]=0;if((fa(c[c[642608+(c[2436]<<2)>>2]>>2]|0,279680)|0)==0){i=c[3541328]|0;j=0;k=0;while(1){c[d+76+(k<<2)>>2]=i+(k<<8);l=j+1&65535;if((l&65535)>63){m=0;n=0;break}else{j=l;k=l&65535}}while(1){k=i+(n<<8)|0;c[d+76+(n+512<<2)>>2]=k;c[d+76+(n+768<<2)>>2]=k;k=m+1&65535;if((k&65535)>63){break}else{m=k;n=k&65535}}}gGz(9706056,0,76);if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=f;c[2417276]=g;c[1836236]=-1}if((c[3541316]|0)!=0){g=c[2439331]|0;f=(g|0)==0;if(!f){e=g;gGC(9706056,e|0,76)|0}e=c[2438119]|0;c[2433530]=e;d=c[3528485]|0;c[2076596]=d;n=c[2417277]|0;c[3541536]=n;c[1836236]=1;gGz(9706056,0,76);if(!f){f=g;gGC(f|0,9706056,76)|0}c[2438119]=e;c[3528485]=d;c[2417277]=n;c[1836236]=-1}if((c[3541310]|0)!=0){n=c[2439332]|0;d=(n|0)==0;if(!d){e=n;gGC(9706056,e|0,76)|0}e=c[2438120]|0;c[2433530]=e;f=c[3528486]|0;c[2076596]=f;g=c[2417278]|0;c[3541536]=g;c[1836236]=2;gGz(9706056,0,76);if(!d){d=n;gGC(d|0,9706056,76)|0}c[2438120]=e;c[3528486]=f;c[2417278]=g;c[1836236]=-1}g=a[14165488]|0;switch(g<<24>>24){case 2:case 3:case 4:case 5:case 8:case 6:case 13:{mB(0);o=a[14165488]|0;break};default:{o=g}}switch(o<<24>>24){case 9:case 10:case 12:case 14:case 17:case 18:{mB(0);mB(1);p=a[14165488]|0;break};default:{p=o}}if(p<<24>>24==11){mB(0);mB(1);mB(2);q=a[14165488]|0}else{q=p}if((q<<24>>24|0)==7|(q<<24>>24|0)==12){p=c[2405758]|0;if((p|0)>0){o=0;do{c[9542560+(o<<5)>>2]=0;b[9542544+(o<<5)>>1]=0;o=o+1|0;}while((o|0)<(p|0))}if((q<<24>>24|0)==1|(q<<24>>24|0)==7){r=46743}}else if((q<<24>>24|0)==1){r=46743}if((r|0)==46743){a[14165752]=0;a[14165512]=0;a[14165672]=0;c[3541416]=0;h[932735]=0.0;h[932737]=0.0;gGz(14165696,0,24);c[3541406]=255;c[3541336]=0;h[925090]=0.0;c[2443340]=0;c[3541432]=0;c[3541431]=0;c[3541430]=0;h[932739]=185.0;h[932738]=0.0;gGz(14165736,0,16)}a[14165768]=0;a[14165832]=0;a[14165824]=0;a[14125128]=0;a[14165504]=0;a[14165496]=0;a[14164880]=0;a[14164888]=0;c[3541360]=0;c[3541358]=0;a[14165912]=0;a[14165920]=0;a[14165936]=0;a[14165928]=0;b[7065212]=0;a[14130432]=0;a[14164632]=0;a[14164624]=0;a[14166040]=0;a[14168304]=0;a[14165368]=0;return}function a08(b){b=b|0;var c=0,d=0;c=b&65535;if((c|0)==40960){d=a[14165872]|a[14165808]}else if((c|0)==45056){d=a[14165874]|a[14165810]}else if((c|0)==43008){d=a[14165873]|a[14165809]}else{d=-1}return d|0}function a09(b,d){b=b|0;d=d|0;var e=0,f=0,g=0.0,i=0.0,j=0.0,k=0.0,l=0.0,m=0.0,n=0.0,o=0.0;e=b&65535;if((b+26624&65535)<256){b=e-38912|0;a[(c[3541366]|0)+b|0]=d;if(!((b|0)<64&(b&1|0)==0)){return}a[(c[3541380]|0)+(b>>1)|0]=d;return}switch(e|0){case 40960:case 40961:case 40962:{a[(c[3541454]|0)+(e-40960)|0]=d;return};case 40964:case 40965:case 40966:case 40967:{b=d&1;f=14165736+(e-40964<<2)|0;if((b|0)==(c[f>>2]|0)){return}c[f>>2]=b;b=(c[3541434]|0)==0;g=b?4030303030303031.0e-21:30303030303030305.0e-22;i=b?1.0e-12:1000001.0e-12;if((c[3541435]|0)==0){j=i;k=g+21276595744680853.0e-22}else{j=i+21276595744680853.0e-22;k=g}if((c[3541436]|0)==0){l=j;m=k+45454545454545455.0e-22}else{l=j+45454545454545455.0e-22;m=k}if((c[3541437]|0)==0){n=l;o=m+1.0e-5}else{n=l+1.0e-5;o=m}m=1.0/o;h[932738]=1.0e9/((m*2.0e6/(m+1.0/n)+1.0e5)*58788.0)*100.0;return};case 43008:case 43009:case 43010:case 43011:case 43012:case 43013:case 43014:case 43015:{b=e-43008|0;e=d&1;switch(b&7|0){case 0:case 1:case 2:{c[14165720+(b<<2)>>2]=e&255;return};case 3:{a[14165672]=e;if(e<<24>>24==0){return}c[3541416]=100;h[932737]=0.0;return};case 5:{do{if(e<<24>>24!=0){if((a[14165752]&1)!=0){break}a[14165512]=1;h[932735]=0.0}}while(0);a[14165752]=e;return};case 7:case 6:{e=b&1;c[3541336]=c[3541336]&~(1<<e)|(d&1)<<e;return};default:{return}}break};case 45056:{a[14165768]=d&1;return};case 45060:{e=d&1;c[3541360]=e;if((e|0)!=0){return}c[3541358]=-1;return};case 45062:{a[14165832]=d&1;return};case 45063:{a[14165824]=d&1;return};case 47104:{c[3541406]=d&255;return};default:{return}}}function a1a(a){a=a|0;return 0}function a1b(a,b){a=a|0;b=b|0;return}function a1c(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[2439330]|0;d=(a|0)==0;if(!d){e=a;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];e=c[3528484]|0;c[2076596]=e;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;gGz(a+76|0,0,2048);g=0;h=0;while(1){c[a+76+(h+512<<2)>>2]=0;c[a+76+(h+768<<2)>>2]=0;i=g+1&65535;if((i&65535)>255){break}else{g=i;h=i&65535}}c[a+4180>>2]=2332;c[a+4184>>2]=1162;c[a+4172>>2]=3270;c[a+4176>>2]=1952;h=c[3541322]|0;g=c[3541328]|0;i=h>>>0>16383?63:h-1>>8;h=(i|0)<0;do{if(!h){j=0;k=0;do{c[a+76+(k<<2)>>2]=g+(k<<8);j=j+1&65535;k=j&65535;}while((k|0)<=(i|0));if(h){break}else{l=0;m=0}do{k=g+(m<<8)|0;c[a+76+(m+512<<2)>>2]=k;c[a+76+(m+768<<2)>>2]=k;l=l+1&65535;m=l&65535;}while((m|0)<=(i|0))}}while(0);i=c[3541334]|0;c[a+588>>2]=i;m=i+256|0;c[a+592>>2]=m;l=i+512|0;c[a+596>>2]=l;g=i+768|0;c[a+600>>2]=g;c[a+1612>>2]=i;c[a+1616>>2]=m;c[a+1620>>2]=l;c[a+1624>>2]=g;c[a+2636>>2]=i;c[a+3660>>2]=i;c[a+2640>>2]=m;c[a+3664>>2]=m;c[a+2644>>2]=l;c[a+3668>>2]=l;c[a+2648>>2]=g;c[a+3672>>2]=g;g=c[3541340]|0;c[a+652>>2]=g;l=g+256|0;c[a+656>>2]=l;m=g+512|0;c[a+660>>2]=m;i=g+768|0;c[a+664>>2]=i;c[a+1676>>2]=g;c[a+1680>>2]=l;c[a+1684>>2]=m;c[a+1688>>2]=i;c[a+2700>>2]=g;c[a+3724>>2]=g;c[a+2704>>2]=l;c[a+3728>>2]=l;c[a+2708>>2]=m;c[a+3732>>2]=m;c[a+2712>>2]=i;c[a+3736>>2]=i;i=c[3541366]|0;c[a+684>>2]=i;c[a+2732>>2]=i;c[a+3756>>2]=i;if(d){n=c[2433530]|0;c[2438118]=n;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}d=a;gGC(d|0,9706056,76)|0;n=c[2433530]|0;c[2438118]=n;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}function a1d(b){b=b|0;var c=0,d=0,e=0;c=b&65535;do{if((b+20480&65535)<4096){if((c|0)==45621){d=2;break}else if((c|0)==45841){d=-1;break}else if((c|0)==24576){e=46822;break}else if((c|0)==26624){e=46823;break}else if((c|0)==45336){d=-45;break}else if((c|0)==28672){e=46824;break}else if((c|0)==45332){d=79;break}else if((c|0)==45588){d=-49;break}else{e=46825;break}}else{if((c|0)==24576){e=46822}else if((c|0)==26624){e=46823}else if((c|0)==28672){e=46824}else{e=46825}}}while(0);if((e|0)==46822){d=a[14165872]|a[14165808]}else if((e|0)==46823){d=a[14165873]|a[14165809]}else if((e|0)==46824){d=a[14165874]|a[14165810]}else if((e|0)==46825){d=-1}return d|0}function a1e(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((b-20480&65535)<256){b=e-20480|0;a[(c[3541366]|0)+b|0]=d;if(!((b|0)<64&(b&1|0)==0)){return}a[(c[3541380]|0)+(b>>1)|0]=d;return}switch(e|0){case 24578:case 24579:case 24580:case 24581:case 24582:{a[(c[3541454]|0)+(e-24578)|0]=d;return};case 22528:{e=d&255;b=c[3542228]|0;if((b|0)>15){return}do{if((b|0)<14){if((b|0)!=13){if((a[14168916+b|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(0,b,e);return};case 22784:{c[3542228]=d&15;return};case 28673:{a[14165768]=d&1;return};case 28676:{e=d&1;c[3541360]=e;if((e|0)!=0){return}c[3541358]=-1;return};case 28678:{a[14165832]=d&1;return};case 28679:{a[14165824]=d&1;return};default:{return}}}function a1f(a){a=a|0;return 0}function a1g(a,b){a=a|0;b=b|0;return}function a1h(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;a=c[2439330]|0;d=(a|0)==0;if(!d){e=a;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];e=c[3528484]|0;c[2076596]=e;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;gGz(a+76|0,0,2048);g=0;h=0;while(1){c[a+76+(h+512<<2)>>2]=0;c[a+76+(h+768<<2)>>2]=0;i=g+1&65535;if((i&65535)>255){break}else{g=i;h=i&65535}}c[a+4180>>2]=876;c[a+4184>>2]=2280;c[a+4172>>2]=2814;c[a+4176>>2]=514;h=c[3541328]|0;g=0;i=0;while(1){c[a+76+(i<<2)>>2]=h+(i<<8);j=g+1&65535;if((j&65535)>63){k=0;l=0;break}else{g=j;i=j&65535}}while(1){i=h+(l<<8)|0;c[a+76+(l+512<<2)>>2]=i;c[a+76+(l+768<<2)>>2]=i;i=k+1&65535;if((i&65535)>63){break}else{k=i;l=i&65535}}l=c[3541334]|0;c[a+332>>2]=l;k=l+256|0;c[a+336>>2]=k;i=l+512|0;c[a+340>>2]=i;g=l+768|0;c[a+344>>2]=g;j=l+1024|0;c[a+348>>2]=j;m=l+1280|0;c[a+352>>2]=m;n=l+1536|0;c[a+356>>2]=n;o=l+1792|0;c[a+360>>2]=o;c[a+1356>>2]=l;c[a+1360>>2]=k;c[a+1364>>2]=i;c[a+1368>>2]=g;c[a+1372>>2]=j;c[a+1376>>2]=m;c[a+1380>>2]=n;c[a+1384>>2]=o;c[a+2380>>2]=l;c[a+3404>>2]=l;c[a+2384>>2]=k;c[a+3408>>2]=k;c[a+2388>>2]=i;c[a+3412>>2]=i;c[a+2392>>2]=g;c[a+3416>>2]=g;c[a+2396>>2]=j;c[a+3420>>2]=j;c[a+2400>>2]=m;c[a+3424>>2]=m;c[a+2404>>2]=n;c[a+3428>>2]=n;c[a+2408>>2]=o;c[a+3432>>2]=o;o=c[3541340]|0;c[a+364>>2]=o;n=o+256|0;c[a+368>>2]=n;m=o+512|0;c[a+372>>2]=m;j=o+768|0;c[a+376>>2]=j;c[a+1388>>2]=o;c[a+1392>>2]=n;c[a+1396>>2]=m;c[a+1400>>2]=j;c[a+2412>>2]=o;c[a+3436>>2]=o;c[a+2416>>2]=n;c[a+3440>>2]=n;c[a+2420>>2]=m;c[a+3444>>2]=m;c[a+2424>>2]=j;c[a+3448>>2]=j;c[a+380>>2]=o;c[a+384>>2]=n;c[a+388>>2]=m;c[a+392>>2]=j;c[a+1404>>2]=o;c[a+1408>>2]=n;c[a+1412>>2]=m;c[a+1416>>2]=j;c[a+2428>>2]=o;c[a+3452>>2]=o;c[a+2432>>2]=n;c[a+3456>>2]=n;c[a+2436>>2]=m;c[a+3460>>2]=m;c[a+2440>>2]=j;c[a+3464>>2]=j;j=c[3541366]|0;c[a+396>>2]=j;c[a+2444>>2]=j;c[a+3468>>2]=j;j=(c[3541322]|0)+16383>>8;m=(j|0)<128;do{if(!m){n=128;o=128;do{c[a+76+(o<<2)>>2]=h+((o<<8)-16384);n=n+1&65535;o=n&65535;}while((o|0)<=(j|0));if(m){break}else{p=128;q=128}do{o=h+((q<<8)-16384)|0;c[a+76+(q+512<<2)>>2]=o;c[a+76+(q+768<<2)>>2]=o;p=p+1&65535;q=p&65535;}while((q|0)<=(j|0))}}while(0);if(d){r=c[2433530]|0;c[2438118]=r;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}d=a;gGC(d|0,9706056,76)|0;r=c[2433530]|0;c[2438118]=r;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}function a1i(a){a=a|0;var b=0,c=0,d=0;if((a&65535)<=49151){b=-1;return b|0}c=(a&65535)-49152|0;if((c&4096|0)==0){d=-1}else{d=S3(1,c>>>1&3)|0}if((c&8192|0)==0){b=d;return b|0}b=(S3(0,c>>>1&3)|0)&d;return b|0}function a1j(b,d){b=b|0;d=d|0;var e=0,f=0;e=b&65535;if((b+20480&65535)<256){f=e-45056|0;a[(c[3541366]|0)+f|0]=d;if(!((f|0)<64&(f&1|0)==0)){return}a[(c[3541380]|0)+(f>>1)|0]=(d&255)>>>4|d<<4;return}if((b&65535)>49151){b=e-49152|0;if((b&4096|0)!=0){S4(1,b>>>1&3,d)}if((b&8192|0)==0){return}S4(0,b>>>1&3,d);return}if((e|0)==47116){a[14165824]=d&1;return}else if((e|0)==47112){a[14165768]=d&1;return}else if((e|0)==47120){a[14165832]=d&1;return}else{return}}function a1k(a){a=a|0;return 0}function a1l(a,b){a=a|0;b=b|0;return}function a1m(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=c[2439330]|0;d=(a|0)==0;if(!d){e=a;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];e=c[3528484]|0;c[2076596]=e;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;gGz(a+76|0,0,2048);g=0;h=0;while(1){c[a+76+(h+512<<2)>>2]=0;c[a+76+(h+768<<2)>>2]=0;i=g+1&65535;if((i&65535)>255){break}else{g=i;h=i&65535}}c[a+4180>>2]=1350;c[a+4184>>2]=3218;c[a+4172>>2]=1682;c[a+4176>>2]=2756;h=c[3541322]|0;g=c[3541328]|0;i=h>>>0>16384?63:h-1>>8;h=(i|0)<0;do{if(!h){j=0;k=0;do{c[a+76+(k<<2)>>2]=g+(k<<8);j=j+1&65535;k=j&65535;}while((k|0)<=(i|0));if(h){break}else{l=0;m=0}do{k=g+(m<<8)|0;c[a+76+(m+512<<2)>>2]=k;c[a+76+(m+768<<2)>>2]=k;l=l+1&65535;m=l&65535;}while((m|0)<=(i|0))}}while(0);i=c[3541334]|0;c[a+588>>2]=i;m=i+256|0;c[a+592>>2]=m;l=i+512|0;c[a+596>>2]=l;g=i+768|0;c[a+600>>2]=g;h=i+1024|0;c[a+604>>2]=h;k=i+1280|0;c[a+608>>2]=k;j=i+1536|0;c[a+612>>2]=j;n=i+1792|0;c[a+616>>2]=n;c[a+1612>>2]=i;c[a+1616>>2]=m;c[a+1620>>2]=l;c[a+1624>>2]=g;c[a+1628>>2]=h;c[a+1632>>2]=k;c[a+1636>>2]=j;c[a+1640>>2]=n;c[a+2636>>2]=i;c[a+3660>>2]=i;c[a+2640>>2]=m;c[a+3664>>2]=m;c[a+2644>>2]=l;c[a+3668>>2]=l;c[a+2648>>2]=g;c[a+3672>>2]=g;c[a+2652>>2]=h;c[a+3676>>2]=h;c[a+2656>>2]=k;c[a+3680>>2]=k;c[a+2660>>2]=j;c[a+3684>>2]=j;c[a+2664>>2]=n;c[a+3688>>2]=n;n=c[3541340]|0;c[a+748>>2]=n;j=n+256|0;c[a+752>>2]=j;k=n+512|0;c[a+756>>2]=k;h=n+768|0;c[a+760>>2]=h;c[a+1772>>2]=n;c[a+1776>>2]=j;c[a+1780>>2]=k;c[a+1784>>2]=h;c[a+2796>>2]=n;c[a+3820>>2]=n;c[a+2800>>2]=j;c[a+3824>>2]=j;c[a+2804>>2]=k;c[a+3828>>2]=k;c[a+2808>>2]=h;c[a+3832>>2]=h;h=c[3541366]|0;c[a+780>>2]=h;c[a+2828>>2]=h;c[a+3852>>2]=h;if(d){o=c[2433530]|0;c[2438118]=o;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}d=a;gGC(d|0,9706056,76)|0;o=c[2433530]|0;c[2438118]=o;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}function a1n(a){a=a|0;var b=0,c=0,d=0;if(a<<16>>16>=0){b=-1;return b|0}c=(a&65535)-32768|0;if((c&256|0)==0){d=-1}else{d=S3(0,c&3)|0}if((c&512|0)==0){b=d;return b|0}b=(S3(1,c&3)|0)&d;return b|0}function a1o(b,d){b=b|0;d=d|0;var e=0,f=0;e=b&65535;if((b-20480&65535)<256){f=e-20480|0;a[(c[3541366]|0)+f|0]=d;if(!((f|0)<64&(f&1|0)==0)){return}a[(c[3541380]|0)+(f>>1)|0]=d;return}if(b<<16>>16<0){b=e-32768|0;if((b&256|0)!=0){S4(0,b&3,d)}if((b&512|0)==0){return}S4(1,b&3,d);return}switch(e|0){case 26625:{a[14165768]=d&1;return};case 26628:{e=d&1;c[3541360]=e;if((e|0)!=0){return}c[3541358]=-1;return};case 26627:{a[14165928]=d&1;return};case 26630:{a[14165832]=d&1;return};case 26631:{a[14165824]=d&1;return};default:{return}}}function a1p(a){a=a|0;return 0}function a1q(a,b){a=a|0;b=b|0;return}function a1r(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=c[2439330]|0;d=(a|0)==0;if(!d){e=a;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];e=c[3528484]|0;c[2076596]=e;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;gGz(a+76|0,0,2048);g=0;h=0;while(1){c[a+76+(h+512<<2)>>2]=0;c[a+76+(h+768<<2)>>2]=0;i=g+1&65535;if((i&65535)>255){break}else{g=i;h=i&65535}}c[a+4180>>2]=2428;c[a+4184>>2]=472;c[a+4172>>2]=1628;c[a+4176>>2]=872;h=c[3541322]|0;g=c[3541328]|0;i=h>>>0>16384?63:h-1>>8;h=(i|0)<0;do{if(!h){j=0;k=0;do{c[a+76+(k<<2)>>2]=g+(k<<8);j=j+1&65535;k=j&65535;}while((k|0)<=(i|0));if(h){break}else{l=0;m=0}do{k=g+(m<<8)|0;c[a+76+(m+512<<2)>>2]=k;c[a+76+(m+768<<2)>>2]=k;l=l+1&65535;m=l&65535;}while((m|0)<=(i|0))}}while(0);i=c[3541334]|0;c[a+332>>2]=i;m=i+256|0;c[a+336>>2]=m;l=i+512|0;c[a+340>>2]=l;g=i+768|0;c[a+344>>2]=g;h=i+1024|0;c[a+348>>2]=h;k=i+1280|0;c[a+352>>2]=k;j=i+1536|0;c[a+356>>2]=j;n=i+1792|0;c[a+360>>2]=n;c[a+1356>>2]=i;c[a+1360>>2]=m;c[a+1364>>2]=l;c[a+1368>>2]=g;c[a+1372>>2]=h;c[a+1376>>2]=k;c[a+1380>>2]=j;c[a+1384>>2]=n;c[a+2380>>2]=i;c[a+3404>>2]=i;c[a+2384>>2]=m;c[a+3408>>2]=m;c[a+2388>>2]=l;c[a+3412>>2]=l;c[a+2392>>2]=g;c[a+3416>>2]=g;c[a+2396>>2]=h;c[a+3420>>2]=h;c[a+2400>>2]=k;c[a+3424>>2]=k;c[a+2404>>2]=j;c[a+3428>>2]=j;c[a+2408>>2]=n;c[a+3432>>2]=n;n=c[3541340]|0;c[a+364>>2]=n;j=n+256|0;c[a+368>>2]=j;k=n+512|0;c[a+372>>2]=k;h=n+768|0;c[a+376>>2]=h;c[a+1388>>2]=n;c[a+1392>>2]=j;c[a+1396>>2]=k;c[a+1400>>2]=h;c[a+2412>>2]=n;c[a+3436>>2]=n;c[a+2416>>2]=j;c[a+3440>>2]=j;c[a+2420>>2]=k;c[a+3444>>2]=k;c[a+2424>>2]=h;c[a+3448>>2]=h;c[a+380>>2]=n;c[a+384>>2]=j;c[a+388>>2]=k;c[a+392>>2]=h;c[a+1404>>2]=n;c[a+1408>>2]=j;c[a+1412>>2]=k;c[a+1416>>2]=h;c[a+2428>>2]=n;c[a+3452>>2]=n;c[a+2432>>2]=j;c[a+3456>>2]=j;c[a+2436>>2]=k;c[a+3460>>2]=k;c[a+2440>>2]=h;c[a+3464>>2]=h;h=c[3541366]|0;c[a+396>>2]=h;c[a+2444>>2]=h;c[a+3468>>2]=h;if(d){o=c[2433530]|0;c[2438118]=o;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}d=a;gGC(d|0,9706056,76)|0;o=c[2433530]|0;c[2438118]=o;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}function a1s(a){a=a|0;var b=0,c=0;b=a&65535;if((a+20480&65535)<64){c=S3(0,b>>>4&3)|0;return c|0}if((a+18432&65535)>=64){c=-1;return c|0}c=S3(1,b>>>4&3)|0;return c|0}function a1t(b,d){b=b|0;d=d|0;var e=0,f=0;e=b&65535;if((b+26624&65535)<256){f=e-38912|0;a[(c[3541366]|0)+f|0]=d;if(!((f|0)<64&(f&1|0)==0)){return}a[(c[3541380]|0)+(f>>1)|0]=d;return}if((b+20480&65535)<64){S4(0,e>>>4&3,d);return}if((b+18432&65535)<64){S4(1,e>>>4&3,d);return}switch(e|0){case 40968:{a[14165768]=d&1;return};case 40960:{a[14165912]=d&1;return};case 41e3:{a[14165936]=d&1;return};case 40984:{a[14165832]=d&1;return};case 40976:{a[14165824]=d&1;return};case 40992:{a[14165920]=d&1;return};default:{return}}}function a1u(a){a=a|0;return 0}function a1v(a,b){a=a|0;b=b|0;return}function a1w(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=c[2439330]|0;d=(a|0)==0;if(!d){e=a;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];e=c[3528484]|0;c[2076596]=e;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;gGz(a+76|0,0,2048);g=0;h=0;while(1){c[a+76+(h+512<<2)>>2]=0;c[a+76+(h+768<<2)>>2]=0;i=g+1&65535;if((i&65535)>255){break}else{g=i;h=i&65535}}c[a+4180>>2]=3300;c[a+4184>>2]=2120;c[a+4172>>2]=1770;c[a+4176>>2]=1602;h=c[3541322]|0;g=c[3541328]|0;i=h>>>0>32768?127:h-1>>8;h=(i|0)<0;do{if(!h){j=0;k=0;do{c[a+76+(k<<2)>>2]=g+(k<<8);j=j+1&65535;k=j&65535;}while((k|0)<=(i|0));if(h){break}else{l=0;m=0}do{k=g+(m<<8)|0;c[a+76+(m+512<<2)>>2]=k;c[a+76+(m+768<<2)>>2]=k;l=l+1&65535;m=l&65535;}while((m|0)<=(i|0))}}while(0);i=c[3541334]|0;c[a+588>>2]=i;m=i+256|0;c[a+592>>2]=m;l=i+512|0;c[a+596>>2]=l;g=i+768|0;c[a+600>>2]=g;h=i+1024|0;c[a+604>>2]=h;k=i+1280|0;c[a+608>>2]=k;j=i+1536|0;c[a+612>>2]=j;n=i+1792|0;c[a+616>>2]=n;c[a+1612>>2]=i;c[a+1616>>2]=m;c[a+1620>>2]=l;c[a+1624>>2]=g;c[a+1628>>2]=h;c[a+1632>>2]=k;c[a+1636>>2]=j;c[a+1640>>2]=n;c[a+2636>>2]=i;c[a+3660>>2]=i;c[a+2640>>2]=m;c[a+3664>>2]=m;c[a+2644>>2]=l;c[a+3668>>2]=l;c[a+2648>>2]=g;c[a+3672>>2]=g;c[a+2652>>2]=h;c[a+3676>>2]=h;c[a+2656>>2]=k;c[a+3680>>2]=k;c[a+2660>>2]=j;c[a+3684>>2]=j;c[a+2664>>2]=n;c[a+3688>>2]=n;n=c[3541340]|0;c[a+652>>2]=n;j=n+256|0;c[a+656>>2]=j;k=n+512|0;c[a+660>>2]=k;h=n+768|0;c[a+664>>2]=h;c[a+1676>>2]=n;c[a+1680>>2]=j;c[a+1684>>2]=k;c[a+1688>>2]=h;c[a+2700>>2]=n;c[a+3724>>2]=n;c[a+2704>>2]=j;c[a+3728>>2]=j;c[a+2708>>2]=k;c[a+3732>>2]=k;c[a+2712>>2]=h;c[a+3736>>2]=h;c[a+668>>2]=n;c[a+672>>2]=j;c[a+676>>2]=k;c[a+680>>2]=h;c[a+1692>>2]=n;c[a+1696>>2]=j;c[a+1700>>2]=k;c[a+1704>>2]=h;c[a+2716>>2]=n;c[a+3740>>2]=n;c[a+2720>>2]=j;c[a+3744>>2]=j;c[a+2724>>2]=k;c[a+3748>>2]=k;c[a+2728>>2]=h;c[a+3752>>2]=h;h=c[3541366]|0;c[a+684>>2]=h;c[a+2732>>2]=h;c[a+3756>>2]=h;if(d){o=c[2433530]|0;c[2438118]=o;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}d=a;gGC(d|0,9706056,76)|0;o=c[2433530]|0;c[2438118]=o;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}function a1x(a){a=a|0;var b=0,c=0;b=a&65535;switch(b|0){case 38912:case 38913:case 38914:case 38915:{c=S3(0,b-38912|0)|0;break};case 40960:case 40961:case 40962:case 40963:{c=S3(1,b-40960|0)|0;break};default:{c=-1}}return c|0}function a1y(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((b+28672&65535)<256){b=e-36864|0;a[(c[3541366]|0)+b|0]=d;if(!((b|0)<64&(b&1|0)==0)){return}a[(c[3541380]|0)+(b>>1)|0]=d;return}switch(e|0){case 43012:{b=d&1;c[3541360]=b;if((b|0)!=0){return}c[3541358]=-1;return};case 43011:{a[14165928]=d&1;return};case 38912:case 38913:case 38914:case 38915:{S4(0,e-38912|0,d);return};case 40960:case 40961:case 40962:case 40963:{S4(1,e-40960|0,d);return};case 43009:{a[14165768]=d&1;return};case 43015:{a[14165824]=d&1;return};case 43014:{a[14165832]=d&1;return};default:{return}}}function a1z(a){a=a|0;return-1|0}function a1A(a,b){a=a|0;b=b|0;return}function a1B(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=c[2439330]|0;d=(a|0)==0;if(!d){e=a;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];e=c[3528484]|0;c[2076596]=e;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;gGz(a+76|0,0,2048);g=0;h=0;while(1){c[a+76+(h+512<<2)>>2]=0;c[a+76+(h+768<<2)>>2]=0;i=g+1&65535;if((i&65535)>255){break}else{g=i;h=i&65535}}c[a+4180>>2]=1774;c[a+4184>>2]=678;c[a+4172>>2]=2674;c[a+4176>>2]=698;h=c[3541322]|0;g=c[3541328]|0;i=h>>>0>32768?127:h-1>>8;h=(i|0)<0;do{if(!h){j=0;k=0;do{c[a+76+(k<<2)>>2]=g+(k<<8);j=j+1&65535;k=j&65535;}while((k|0)<=(i|0));if(h){break}else{l=0;m=0}do{k=g+(m<<8)|0;c[a+76+(m+512<<2)>>2]=k;c[a+76+(m+768<<2)>>2]=k;l=l+1&65535;m=l&65535;}while((m|0)<=(i|0))}}while(0);i=c[3541334]|0;c[a+588>>2]=i;m=i+256|0;c[a+592>>2]=m;l=i+512|0;c[a+596>>2]=l;g=i+768|0;c[a+600>>2]=g;h=i+1024|0;c[a+604>>2]=h;k=i+1280|0;c[a+608>>2]=k;j=i+1536|0;c[a+612>>2]=j;n=i+1792|0;c[a+616>>2]=n;c[a+1612>>2]=i;c[a+1616>>2]=m;c[a+1620>>2]=l;c[a+1624>>2]=g;c[a+1628>>2]=h;c[a+1632>>2]=k;c[a+1636>>2]=j;c[a+1640>>2]=n;c[a+2636>>2]=i;c[a+3660>>2]=i;c[a+2640>>2]=m;c[a+3664>>2]=m;c[a+2644>>2]=l;c[a+3668>>2]=l;c[a+2648>>2]=g;c[a+3672>>2]=g;c[a+2652>>2]=h;c[a+3676>>2]=h;c[a+2656>>2]=k;c[a+3680>>2]=k;c[a+2660>>2]=j;c[a+3684>>2]=j;c[a+2664>>2]=n;c[a+3688>>2]=n;n=c[3541340]|0;c[a+620>>2]=n;j=n+256|0;c[a+624>>2]=j;k=n+512|0;c[a+628>>2]=k;h=n+768|0;c[a+632>>2]=h;c[a+1644>>2]=n;c[a+1648>>2]=j;c[a+1652>>2]=k;c[a+1656>>2]=h;c[a+2668>>2]=n;c[a+3692>>2]=n;c[a+2672>>2]=j;c[a+3696>>2]=j;c[a+2676>>2]=k;c[a+3700>>2]=k;c[a+2680>>2]=h;c[a+3704>>2]=h;c[a+636>>2]=n;c[a+640>>2]=j;c[a+644>>2]=k;c[a+648>>2]=h;c[a+1660>>2]=n;c[a+1664>>2]=j;c[a+1668>>2]=k;c[a+1672>>2]=h;c[a+2684>>2]=n;c[a+3708>>2]=n;c[a+2688>>2]=j;c[a+3712>>2]=j;c[a+2692>>2]=k;c[a+3716>>2]=k;c[a+2696>>2]=h;c[a+3720>>2]=h;h=c[3541366]|0;c[a+652>>2]=h;c[a+2700>>2]=h;c[a+3724>>2]=h;if(d){o=c[2433530]|0;c[2438118]=o;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}d=a;gGC(d|0,9706056,76)|0;o=c[2433530]|0;c[2438118]=o;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}function a1C(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;if((c[3541322]|0)!=0){fwZ()}if((c[3541382]|0)!=0){gGz(8443768,0,6208);gGz(9718136,0,38);gGz(9669136,0,152)}c[2113070]=0;c[2113068]=0;d=c[2112926]|0;if((d|0)!=0){gGr(d);c[2112926]=0}d=c[3541422]|0;e=0;while(1){if((e|0)>=1024){break}f=9638528+(e<<2)|0;if((c[f>>2]|0)==(d|0)){g=47072;break}else{e=e+1|0}}if((g|0)==47072){gGr(d);c[f>>2]=0}c[3541422]=0;f=c[3541324]|0;d=0;while(1){if((d|0)>=1024){break}i=9638528+(d<<2)|0;if((c[i>>2]|0)==(f|0)){g=47076;break}else{d=d+1|0}}if((g|0)==47076){gGr(f);c[i>>2]=0}c[3541324]=0;i=c[3541338]|0;f=0;while(1){if((f|0)>=1024){break}j=9638528+(f<<2)|0;if((c[j>>2]|0)==(i|0)){g=47080;break}else{f=f+1|0}}if((g|0)==47080){gGr(i);c[j>>2]=0}c[3541338]=0;j=c[3532628]|0;i=0;while(1){if((i|0)>=1024){break}k=9638528+(i<<2)|0;if((c[k>>2]|0)==(j|0)){g=47084;break}else{i=i+1|0}}if((g|0)==47084){gGr(j);c[k>>2]=0}c[3532628]=0;k=a[14165488]|0;switch(k<<24>>24){case 2:case 3:case 4:case 5:case 8:case 13:case 6:{c[2113008]=0;c[2076598]=0;c[2383582]=0;switch(k<<24>>24){case 9:case 10:case 12:case 14:case 17:case 18:{g=47087;break};case 11:{g=47088;break};case 7:{g=47089;break};default:{l=k;g=47090}}break};case 9:case 10:case 12:case 14:case 17:case 18:{g=47087;break};case 11:{g=47088;break};case 7:{g=47089;break};default:{l=k;g=47090}}if((g|0)==47087){c[2113008]=0;c[2076598]=0;c[2383582]=0;if((k<<24>>24|0)==11){g=47088}else if((k<<24>>24|0)==7|(k<<24>>24|0)==12){g=47089}else{l=k;g=47090}}if((g|0)==47088){c[2113008]=0;c[2076598]=0;c[2383582]=0;g=47093}else if((g|0)==47089){UT();l=a[14165488]|0;g=47090}if((g|0)==47090){if((l-15&255)<2){TT();m=a[14165488]|0}else{m=l}if((m<<24>>24|0)==9|(m<<24>>24|0)==8|(m<<24>>24|0)==11|(m<<24>>24|0)==12){g=47093}}if((g|0)==47093){gGz(9762456,0,480)}m=c[2112958]|0;l=0;while(1){if((l|0)>=1024){break}n=9638528+(l<<2)|0;if((c[n>>2]|0)==(m|0)){g=47097;break}else{l=l+1|0}}if((g|0)==47097){gGr(m);c[n>>2]=0}c[2112958]=0;gGz(8451888,0,36);n=c[2443338]|0;m=0;while(1){if((m|0)>=1024){break}o=9638528+(m<<2)|0;if((c[o>>2]|0)==(n|0)){g=47101;break}else{m=m+1|0}}if((g|0)==47101){gGr(n);c[o>>2]=0}c[2443338]=0;o=c[2443336]|0;n=0;while(1){if((n|0)>=1024){break}p=9638528+(n<<2)|0;if((c[p>>2]|0)==(o|0)){g=47105;break}else{n=n+1|0}}if((g|0)==47105){gGr(o);c[p>>2]=0}c[2443336]=0;a[7461824]=0;a[5397504]=0;a[6885952]=0;a[14165752]=0;a[14165512]=0;a[14165672]=0;c[3541416]=0;h[932735]=0.0;h[932737]=0.0;gGz(14165696,0,24);c[3541406]=0;c[3541336]=0;h[925090]=0.0;c[2443340]=0;c[3541432]=0;c[3541431]=0;c[3541430]=0;h[932739]=0.0;h[932738]=0.0;gGz(14165736,0,16);gGz(14108688,0,128);a[14165768]=0;a[14165760]=0;a[14165488]=0;a[14165832]=0;a[14165824]=0;a[14125128]=0;a[14165504]=0;a[14165496]=0;a[14164880]=0;a[14164888]=0;a[14164872]=0;a[14130360]=0;a[14165168]=0;a[14165632]=0;a[14165472]=0;a[14165480]=0;a[7461920]=0;a[14165912]=0;a[14165920]=0;a[14165936]=0;a[14165928]=0;b[7065212]=0;a[14130432]=0;c[3541322]=0;c[3541326]=0;c[3541316]=0;c[3541318]=0;c[3541310]=0;c[3541312]=0;c[3541382]=0;c[3541384]=0;c[3541348]=0;c[3541350]=0;c[3541352]=0;c[3541354]=0;c[3541414]=0;c[3541344]=0;c[3541346]=0;c[3541412]=0;c[3541398]=0;c[3541400]=0;c[3541404]=0;c[3541392]=0;c[3541474]=0;c[3541466]=0;c[3541462]=0;c[3541464]=0;c[3541390]=0;a[7461664]=0;a[7461888]=0;a[14164632]=0;a[14164624]=0;a[14166040]=0;a[7461864]=0;a[7461872]=0;a[14168304]=0;a[14166176]=0;a[14166208]=0;a[14166200]=0;a[14166192]=0;a[14166184]=0;b[7065264]=0;b[7065260]=0;a[14165368]=0;a[14165880]=0;return 0}function a1D(){gGz(9668984|0,0|0,81|0);c[3540906]=0;c[3540904]=0;c[3540902]=0;c[3540900]=0;c[3540898]=0;c[3540896]=0;c[3540894]=0;c[3540892]=0;c[3540890]=0;c[3540888]=0;c[3540886]=0;c[3540884]=0;c[3540882]=0;a1C()|0;return 0}function a1E(){var d=0,e=0,f=0,g=0.0,i=0.0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0;d=a[14165488]|0;if((d<<24>>24|0)==1|(d<<24>>24|0)==7){e=a[9688]|0?534:0;do{if(((c[2113222]|0)%3|0|0)!=0){f=c[3541416]|0;if(!((a[14165672]|0)==0&(f|0)>0)){break}c[3541416]=f-1+((f|0)/-10|0)}}while(0);g=+h[932739];if(g>93.0){i=g- +h[932738]}else{i=185.0}h[932739]=i;j=e}else{j=8}switch(d<<24>>24){case 9:case 8:case 10:case 11:case 17:{k=a[9688]|0?133:0;break};default:{k=j}}j=d<<24>>24==18?32:d<<24>>24==5?32:d<<24>>24==12?32:k;k=a[7461872]|0?0:(j|0)/4|0;if((a[14165552]|0)!=0){a07()}do{if(a[7461864]|0){d=a[14165840]|0;if((a[14165168]|0)==d<<24>>24){break}a[14165168]=d;e=d<<24>>24==1?16384:0;d=c[2439330]|0;f=(d|0)==0;if(!f){l=d;gGC(9706056,l|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];l=c[3528484]|0;c[2076596]=l;m=c[2417276]|0;c[3541536]=m;c[1836236]=0;n=c[3541328]|0;o=0;p=0;while(1){c[d+76+(p<<2)>>2]=n+((p<<8)+e);q=o+1&65535;if((q&65535)>63){r=0;s=0;break}else{o=q;p=q&65535}}while(1){p=n+((s<<8)+e)|0;c[d+76+(s+512<<2)>>2]=p;c[d+76+(s+768<<2)>>2]=p;p=r+1&65535;if((p&65535)>63){break}else{r=p;s=p&65535}}if(!f){e=d;gGC(e|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=l;c[2417276]=m;c[1836236]=-1;e=c[3541454]|0;a[e]=0;do{if((a[14165168]|0)==1){a[e]=1;n=a[14165168]|0;a[14165632]=0;if(n<<24>>24!=1){break}a[14165632]=1}else{a[14165632]=0}}while(0);a07()}}while(0);c[3541452]=0;s=0;r=0;e=0;m=0;l=0;do{r=((a[14165800+s|0]&1)<<s|r&255)&255;e=((a[14165792+s|0]&1)<<s|e&255)&255;m=((a[14165784+s|0]&1)<<s|m&255)&255;l=((a[14165776+s|0]&1)<<s|l&255)&255;s=s+1|0;}while((s|0)<8);a[14165808]=r;a[14165809]=e;a[14165810]=m;a[14165811]=l;a[14165368]=0;l=c[3541322]|0;if((l|0)!=0){m=c[2385548]|0;if((m|0)>0){gGz(9752472,0,((m|0)>1?m<<2:4)|0)}c[2433530]=0}c[2113206]=0;c[2113205]=0;c[2113204]=0;m=a[14165488]|0;L60264:do{if((j|0)>0){e=0;r=0;s=l;d=m;while(1){if((s|0)==0|d<<24>>24==17){t=d}else{f=c[2439330]|0;if((f|0)!=0){n=f;gGC(9706056,n|0,76)|0}b[4853030]=c[2426515]&65535;n=c[2438118]|0;c[2433530]=n;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;p=(ag(c[2113202]|0,e+1|0)|0)/(j|0)|0;o=c[2113204]|0;q=p-o|0;c[2430458]=q;do{if((q|0)<1){u=0;v=o}else{if((a[f+4188|0]|0)==0){p=gfc(q)|0;c[2433530]=(c[2433530]|0)+p;u=p;v=c[2113204]|0;break}else{c[2433530]=n+q;u=q;v=o;break}}}while(0);c[2113204]=v+u;if((e|0)==(k|0)&(a[14165768]|0)!=0){o=a[14165760]|0;if(o<<24>>24==1){if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12;w=a[14165760]|0}else{w=o}if(w<<24>>24==2){a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0}a[14165768]=0}o=c[1836236]|0;q=c[9757320+(o<<2)>>2]|0;if((q|0)!=0){n=q;gGC(n|0,9706056,76)|0}c[9752472+(o<<2)>>2]=c[2433530];c[14113936+(o<<2)>>2]=c[2076596];c[9669104+(o<<2)>>2]=c[3541536];c[1836236]=-1;t=a[14165488]|0}switch(t<<24>>24){case 7:case 8:case 9:case 10:case 11:case 12:case 14:case 4:{o=c[2439331]|0;if((o|0)!=0){n=o;gGC(9706056,n|0,76)|0}b[4853030]=c[2426515]&65535;n=c[2438119]|0;c[2433530]=n;c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;q=(ag(c[2113200]|0,e+1|0)|0)/(j|0)|0;f=c[2113205]|0;p=q-f|0;c[2430458]=p;do{if((p|0)<1){x=0;y=f;z=t}else{if((a[o+4188|0]|0)==0){q=gfc(p)|0;c[2433530]=(c[2433530]|0)+q;x=q;y=c[2113205]|0;z=a[14165488]|0;break}else{c[2433530]=n+p;x=p;y=f;z=t;break}}}while(0);c[2113205]=y+x;if(z<<24>>24==4){a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0}f=c[1836236]|0;p=c[9757320+(f<<2)>>2]|0;if((p|0)!=0){n=p;gGC(n|0,9706056,76)|0}c[9752472+(f<<2)>>2]=c[2433530];c[14113936+(f<<2)>>2]=c[2076596];c[9669104+(f<<2)>>2]=c[3541536];c[1836236]=-1;A=a[14165488]|0;break};default:{A=t}}if(A<<24>>24==5){f=c[2439331]|0;if((f|0)!=0){n=f;gGC(9706056,n|0,76)|0}b[4853030]=c[2426515]&65535;n=c[2438119]|0;c[2433530]=n;c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;p=(ag(c[2113200]|0,e+1|0)|0)/(j|0)|0;o=c[2113205]|0;q=p-o|0;c[2430458]=q;do{if((q|0)<1){B=0;C=o;D=1;E=f;F=n}else{if((a[f+4188|0]|0)==0){p=gfc(q)|0;G=(c[2433530]|0)+p|0;c[2433530]=G;H=c[1836236]|0;B=p;C=c[2113205]|0;D=H;E=c[9757320+(H<<2)>>2]|0;F=G;break}else{G=n+q|0;c[2433530]=G;B=q;C=o;D=1;E=f;F=G;break}}}while(0);c[2430458]=B;f=C+B|0;c[2113205]=f;a[9706117]=1;if((a[E+4188|0]|0)==0){o=gfc(300)|0;q=c[1836236]|0;I=o;J=(c[2433530]|0)+o|0;K=c[2113205]|0;L=q;M=c[9757320+(q<<2)>>2]|0}else{I=300;J=F+300|0;K=f;L=D;M=E}c[2433530]=J;f=K+I|0;c[2113205]=f;a[9706117]=0;if((a[M+4188|0]|0)==0){q=gfc(300)|0;o=c[1836236]|0;N=q;O=(c[2433530]|0)+q|0;P=c[2113205]|0;Q=o;R=c[9757320+(o<<2)>>2]|0}else{N=300;O=J+300|0;P=f;Q=L;R=M}c[2433530]=O;c[2113205]=P+N;if((R|0)!=0){f=R;gGC(f|0,9706056,76)|0}c[9752472+(Q<<2)>>2]=O;c[14113936+(Q<<2)>>2]=c[2076596];c[9669104+(Q<<2)>>2]=c[3541536];c[1836236]=-1;S=a[14165488]|0}else{S=A}if(S<<24>>24==12){f=c[2439332]|0;if((f|0)!=0){o=f;gGC(9706056,o|0,76)|0}b[4853030]=c[2426515]&65535;o=c[2438120]|0;c[2433530]=o;c[2076596]=c[3528486];c[3541536]=c[2417278];c[1836236]=2;q=(ag(a[9616]|0?29829:0,e+1|0)|0)/(j|0)|0;n=c[2113206]|0;G=q-n|0;c[2430458]=G;do{if((G|0)<1){T=0;U=n;V=2;W=f;X=o}else{if((a[f+4188|0]|0)==0){q=gfc(G)|0;H=(c[2433530]|0)+q|0;c[2433530]=H;p=c[1836236]|0;T=q;U=c[2113206]|0;V=p;W=c[9757320+(p<<2)>>2]|0;X=H;break}else{H=o+G|0;c[2433530]=H;T=G;U=n;V=2;W=f;X=H;break}}}while(0);c[2113206]=U+T;if((W|0)!=0){f=W;gGC(f|0,9706056,76)|0}c[9752472+(V<<2)>>2]=X;c[14113936+(V<<2)>>2]=c[2076596];c[9669104+(V<<2)>>2]=c[3541536];c[1836236]=-1}if((c[3541382]|0)!=0){c[2110940]=8443768;c[2444]=0;gGC(9718136,9669136,38)|0;f=(ag(c[2113202]|0,e+1|0)|0)/(j|0)|0;n=f-(c[2113204]|0)|0;c[2430458]=n;f=geH(n)|0;c[2113204]=(c[2113204]|0)+f;if((e|0)==(k|0)){a[14165368]=1;geG(0);geH(0)|0;a[9718172]=0;geH(0)|0}f=9669136+((c[2444]|0)*38|0)|0;gGC(f|0,9718136,38)|0;c[2444]=-1}f=a[14165488]|0;if(f<<24>>24==17){n=c[2439330]|0;if((n|0)!=0){G=n;gGC(9706056,G|0,76)|0}b[4853030]=c[2426515]&65535;G=c[2438118]|0;c[2433530]=G;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;o=(ag(c[2113200]|0,e+1|0)|0)/(j|0)|0;H=c[2113205]|0;p=o-H|0;c[2430458]=p;do{if((p|0)<1){Y=0;Z=H}else{if((a[n+4188|0]|0)==0){o=gfc(p)|0;c[2433530]=(c[2433530]|0)+o;Y=o;Z=c[2113205]|0;break}else{c[2433530]=G+p;Y=p;Z=H;break}}}while(0);c[2113205]=Z+Y;if(a[7461824]|0){a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0}H=c[1836236]|0;p=c[9757320+(H<<2)>>2]|0;if((p|0)!=0){G=p;gGC(G|0,9706056,76)|0}c[9752472+(H<<2)>>2]=c[2433530];c[14113936+(H<<2)>>2]=c[2076596];c[9669104+(H<<2)>>2]=c[3541536];c[1836236]=-1;_=a[14165488]|0}else{_=f}H=c[2112964]|0;G=(H|0)!=0;if(_<<24>>24==1&G){p=((a[9688]|0?534:0)|0)/(j|0)|0;a0W(H+(r<<1<<1)|0,p);$=p+r|0}else{$=r}switch(_<<24>>24){case 2:case 3:case 4:case 5:case 10:case 11:case 12:case 6:case 13:case 14:case 17:{if((H|0)==0){aa=$;ab=0}else{ac=47217}break};default:{if(_<<24>>24==18&G){ac=47217}else{aa=$;ab=H}}}if((ac|0)==47217){ac=0;G=a[9688]|0?534:0;mF(8451888,H+($<<1<<1)|0,G-$|0,0);aa=G;ab=H}H=_<<24>>24==9;if(H){if((ab|0)==0){ad=aa;ae=9}else{ac=47221}}else{if(_<<24>>24==8&(ab|0)!=0){ac=47221}else{af=aa;ac=47224}}do{if((ac|0)==47221){ac=0;G=a[9688]|0?534:0;p=G-aa|0;n=ab+(aa<<1<<1)|0;mA(0,c[2112972]|0,c[2112973]|0,c[2112974]|0,p);if(H){mA(1,c[2112975]|0,c[2112976]|0,c[2112977]|0,p);U0(0,c[2112972]|0,n,p);U0(1,c[2112973]|0,n,p);U0(2,c[2112974]|0,n,p);U0(3,c[2112975]|0,n,p);U0(4,c[2112976]|0,n,p);U0(5,c[2112977]|0,n,p);ad=G;ae=_;break}else{U0(0,c[2112972]|0,n,p);U0(1,c[2112973]|0,n,p);U0(2,c[2112974]|0,n,p);af=G;ac=47224;break}}}while(0);do{if((ac|0)==47224){ac=0;if(_<<24>>24==7&(ab|0)!=0){H=((a[9688]|0?534:0)|0)/(j|0)|0;f=ab+(af<<1<<1)|0;a0W(f,H);UR(f,H);ah=H+af|0;ai=a[14165488]|0}else{ah=af;ai=_}if((ai-15&255)>=2){ad=ah;ae=ai;break}H=((a[9688]|0?534:0)|0)/(j|0)|0;f=(c[2112964]|0)+(ah<<1<<1)|0;TQ(0,f,H);if(ai<<24>>24==15){TQ(1,f,H);TQ(2,f,H)}ad=H+ah|0;ae=ai}}while(0);H=e+1|0;if((H|0)>=(j|0)){aj=ad;ak=ae;break L60264}e=H;r=ad;s=c[3541322]|0;d=ae}}else{aj=0;ak=m}}while(0);m=c[2112964]|0;ae=(m|0)!=0;do{if(ak<<24>>24==1&ae){ad=a[9688]|0?534:0;if((ad|0)==(aj|0)){break}a0W(m+(aj<<1<<1)|0,ad-aj|0);ac=47235}else{ac=47235}}while(0);L60406:do{if((ac|0)==47235){switch(ak<<24>>24){case 2:case 3:case 4:case 5:case 10:case 11:case 12:case 6:case 13:case 14:case 17:{if((m|0)==0){al=0}else{ac=47238}break};default:{if(ak<<24>>24==18&ae){ac=47238}else{al=m}}}do{if((ac|0)==47238){ad=a[9688]|0?534:0;if((ad|0)==(aj|0)){al=m;break}mF(8451888,m+(aj<<1<<1)|0,ad-aj|0,0);al=m}}while(0);ad=ak<<24>>24==9;if(ad){if((al|0)==0){break}else{am=9;ac=47243}}else{if(ak<<24>>24==8&(al|0)!=0){am=8;ac=47243}else{ac=47247}}do{if((ac|0)==47243){j=a[9688]|0?534:0;ai=j-aj|0;ah=al+(aj<<1<<1)|0;if((j|0)==(aj|0)){an=am;ao=ak;break}mA(0,c[2112972]|0,c[2112973]|0,c[2112974]|0,ai);if(ad){mA(1,c[2112975]|0,c[2112976]|0,c[2112977]|0,ai);U0(0,c[2112972]|0,ah,ai);U0(1,c[2112973]|0,ah,ai);U0(2,c[2112974]|0,ah,ai);U0(3,c[2112975]|0,ah,ai);U0(4,c[2112976]|0,ah,ai);U0(5,c[2112977]|0,ah,ai);break L60406}else{U0(0,c[2112972]|0,ah,ai);U0(1,c[2112973]|0,ah,ai);U0(2,c[2112974]|0,ah,ai);ac=47247;break}}}while(0);do{if((ac|0)==47247){if(ak<<24>>24==7&(al|0)!=0){ad=a[9688]|0?534:0;ai=ad-aj|0;ah=al+(aj<<1<<1)|0;if((ad|0)==(aj|0)){break L60406}a0W(ah,ai);UR(ah,ai);ap=c[2112964]|0;aq=a[14165488]|0}else{ap=al;aq=ak}if(!(aq<<24>>24==12&(ap|0)!=0)){an=aq;ao=aq;break}UR(ap,a[9688]|0?534:0);ai=a[14165488]|0;an=ai;ao=ai}}while(0);if((an-15&255)>=2){break}ai=a[9688]|0?534:0;ah=ai-aj|0;ad=(c[2112964]|0)+(aj<<1<<1)|0;if((ai|0)==(aj|0)){break}TQ(0,ad,ah);if(ao<<24>>24!=15){break}TQ(1,ad,ah);TQ(2,ad,ah)}}while(0);if((c[2112968]|0)==0){return 0}ao=c[3541390]|0;if((ao|0)!=0){gu[ao&16383]();return 0}ao=c[2112926]|0;gGz(ao|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);gu[c[3541474]&16383]();ao=c[3541392]|0;if((ao|0)!=0){gu[ao&16383]()}a2D(c[3541340]|0);a2E((c[3541366]|0)+64|0);if((c[3541466]|0)!=0){a2F((c[3541366]|0)+96|0)}R8(c[3541410]|0);return 0}function a1F(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0;e=i;i=i+928|0;f=e|0;g=e+16|0;h=e+48|0;j=e+64|0;k=e+80|0;l=e+96|0;m=e+112|0;n=e+128|0;o=e+144|0;p=e+160|0;q=e+176|0;r=e+192|0;s=e+208|0;t=e+224|0;u=e+240|0;v=e+256|0;w=e+272|0;x=e+288|0;y=e+304|0;z=e+320|0;A=e+336|0;B=e+352|0;C=e+368|0;D=e+384|0;E=e+400|0;F=e+416|0;G=e+432|0;H=e+448|0;I=e+464|0;J=e+480|0;K=e+496|0;L=e+512|0;M=e+528|0;N=e+544|0;O=e+560|0;P=e+576|0;Q=e+592|0;R=e+608|0;S=e+624|0;T=e+640|0;U=e+656|0;V=e+672|0;W=e+688|0;X=e+704|0;Y=e+720|0;Z=e+736|0;_=e+752|0;$=e+768|0;aa=e+784|0;ab=e+800|0;ac=e+816|0;ad=e+832|0;ae=e+848|0;af=e+864|0;ag=e+880|0;ah=e+896|0;ai=e+912|0;aj=(d|0)==0;if(!aj){c[d>>2]=169731}if((b&32|0)!=0){gGz(ai|0,0,12);ak=c[3541394]|0;c[ai>>2]=ak;c[ai+4>>2]=(c[3541396]|0)-ak;c[ai+12>>2]=162152;ak=c[2076592]|0;gj[ak&4095](ai)|0}if((b&64|0)==0){i=e;return 0}if((c[3541322]|0)!=0){fw$(b)}gGz(y|0,0,12);c[y>>2]=9668984;c[y+4>>2]=81;c[y+12>>2]=207392;gj[c[2076592]&4095](y)|0;if((c[3541382]|0)!=0){gGz(x|0,0,12);c[x>>2]=9669136;c[x+4>>2]=152;c[x+12>>2]=162152;y=c[2076592]|0;gj[y&4095](x)|0}x=a[14165488]|0;if((x<<24>>24|0)==1|(x<<24>>24|0)==7){gGz(w|0,0,12);c[w>>2]=14165752;c[w+4>>2]=1;c[w+12>>2]=69328;y=c[2076592]|0;gj[y&4095](w)|0;gGz(v|0,0,12);c[v>>2]=14165512;c[v+4>>2]=1;c[v+12>>2]=456856;w=c[2076592]|0;gj[w&4095](v)|0;gGz(u|0,0,12);c[u>>2]=14165672;c[u+4>>2]=1;c[u+12>>2]=352464;v=c[2076592]|0;gj[v&4095](u)|0;gGz(t|0,0,12);c[t>>2]=14165664;c[t+4>>2]=4;c[t+12>>2]=274088;u=c[2076592]|0;gj[u&4095](t)|0;gGz(s|0,0,12);c[s>>2]=7461880;c[s+4>>2]=8;c[s+12>>2]=212336;t=c[2076592]|0;gj[t&4095](s)|0;gGz(r|0,0,12);c[r>>2]=7461896;c[r+4>>2]=8;c[r+12>>2]=165648;s=c[2076592]|0;gj[s&4095](r)|0;gGz(q|0,0,12);c[q>>2]=14165696;c[q+4>>2]=24;c[q+12>>2]=133744;r=c[2076592]|0;gj[r&4095](q)|0;gGz(p|0,0,12);c[p>>2]=14165624;c[p+4>>2]=4;c[p+12>>2]=108248;q=c[2076592]|0;gj[q&4095](p)|0;gGz(o|0,0,12);c[o>>2]=14165344;c[o+4>>2]=4;c[o+12>>2]=83544;p=c[2076592]|0;gj[p&4095](o)|0;gGz(n|0,0,12);c[n>>2]=7400720;c[n+4>>2]=8;c[n+12>>2]=65200;o=c[2076592]|0;gj[o&4095](n)|0;gGz(m|0,0,12);c[m>>2]=9773360;c[m+4>>2]=4;c[m+12>>2]=573680;n=c[2076592]|0;gj[n&4095](m)|0;gGz(l|0,0,12);c[l>>2]=14165720;c[l+4>>2]=12;c[l+12>>2]=556584;m=c[2076592]|0;gj[m&4095](l)|0;gGz(k|0,0,12);c[k>>2]=7461912;c[k+4>>2]=8;c[k+12>>2]=541632;l=c[2076592]|0;gj[l&4095](k)|0;gGz(j|0,0,12);c[j>>2]=7461904;c[j+4>>2]=8;c[j+12>>2]=528608;k=c[2076592]|0;gj[k&4095](j)|0;gGz(h|0,0,12);c[h>>2]=14165736;c[h+4>>2]=16;c[h+12>>2]=514712;j=c[2076592]|0;gj[j&4095](h)|0;al=a[14165488]|0}else{al=x}L60469:do{switch(al<<24>>24){case 2:case 3:case 4:case 5:case 8:case 13:case 9:case 10:case 12:case 14:case 11:case 17:case 18:{x=e+32|0;do{if(!aj){if((c[d>>2]|0)>=169110){break}c[d>>2]=169110}}while(0);if((c[2113008]|0)<=0){am=al;break L60469}h=g|0;j=g+4|0;k=g+8|0;l=g+12|0;m=0;do{cC(x|0,531144,(n=i,i=i+8|0,c[n>>2]=m,n)|0)|0;i=n;c[h>>2]=14168888+(m*252|0);c[j>>2]=252;c[k>>2]=0;c[l>>2]=x;gj[c[2076592]&4095](g)|0;m=m+1|0;}while((m|0)<(c[2113008]|0));am=a[14165488]|0;break};default:{am=al}}}while(0);do{if((am<<24>>24|0)==7|(am<<24>>24|0)==12){if(!aj){c[d>>2]=169753}if((c[2405758]|0)<=0){an=am;break}al=f;g=f|0;m=f+4|0;x=f+12|0;l=0;do{gGz(al|0,0,12);c[g>>2]=9542544+(l<<5);c[m>>2]=2;c[x>>2]=119040;gj[c[2076592]&4095](f)|0;l=l+1|0;}while((l|0)<(c[2405758]|0));an=a[14165488]|0}else{an=am}}while(0);if(an<<24>>24==15){TU(b,d)}gGz(ah|0,0,12);c[ah>>2]=14165808;c[ah+4>>2]=4;c[ah+12>>2]=455736;gj[c[2076592]&4095](ah)|0;gGz(ag|0,0,12);c[ag>>2]=14165952;c[ag+4>>2]=4;c[ag+12>>2]=351552;gj[c[2076592]&4095](ag)|0;gGz(af|0,0,12);c[af>>2]=14165944;c[af+4>>2]=4;c[af+12>>2]=273296;gj[c[2076592]&4095](af)|0;gGz(ae|0,0,12);c[ae>>2]=14165768;c[ae+4>>2]=1;c[ae+12>>2]=211888;gj[c[2076592]&4095](ae)|0;gGz(ad|0,0,12);c[ad>>2]=8452816;c[ad+4>>2]=12;c[ad+12>>2]=165392;gj[c[2076592]&4095](ad)|0;gGz(ac|0,0,12);c[ac>>2]=9721832;c[ac+4>>2]=4;c[ac+12>>2]=133656;gj[c[2076592]&4095](ac)|0;gGz(ab|0,0,12);c[ab>>2]=14125128;c[ab+4>>2]=1;c[ab+12>>2]=108144;gj[c[2076592]&4095](ab)|0;gGz(aa|0,0,12);c[aa>>2]=14165504;c[aa+4>>2]=1;c[aa+12>>2]=83448;gj[c[2076592]&4095](aa)|0;gGz($|0,0,12);c[$>>2]=14165496;c[$+4>>2]=1;c[$+12>>2]=65048;gj[c[2076592]&4095]($)|0;gGz(_|0,0,12);c[_>>2]=14164888;c[_+4>>2]=1;c[_+12>>2]=573600;gj[c[2076592]&4095](_)|0;gGz(Z|0,0,12);c[Z>>2]=14164880;c[Z+4>>2]=1;c[Z+12>>2]=556504;gj[c[2076592]&4095](Z)|0;gGz(Y|0,0,12);c[Y>>2]=14164872;c[Y+4>>2]=1;c[Y+12>>2]=541568;gj[c[2076592]&4095](Y)|0;gGz(X|0,0,12);c[X>>2]=14130360;c[X+4>>2]=1;c[X+12>>2]=528560;gj[c[2076592]&4095](X)|0;gGz(W|0,0,12);c[W>>2]=14130432;c[W+4>>2]=1;c[W+12>>2]=514640;gj[c[2076592]&4095](W)|0;gGz(V|0,0,12);c[V>>2]=14164632;c[V+4>>2]=1;c[V+12>>2]=501640;gj[c[2076592]&4095](V)|0;gGz(U|0,0,12);c[U>>2]=14164624;c[U+4>>2]=1;c[U+12>>2]=490120;gj[c[2076592]&4095](U)|0;gGz(T|0,0,12);c[T>>2]=14165168;c[T+4>>2]=1;c[T+12>>2]=477216;gj[c[2076592]&4095](T)|0;gGz(S|0,0,12);c[S>>2]=14166040;c[S+4>>2]=1;c[S+12>>2]=465472;gj[c[2076592]&4095](S)|0;gGz(R|0,0,12);c[R>>2]=14168304;c[R+4>>2]=1;c[R+12>>2]=454248;gj[c[2076592]&4095](R)|0;gGz(Q|0,0,12);c[Q>>2]=14165832;c[Q+4>>2]=1;c[Q+12>>2]=443720;gj[c[2076592]&4095](Q)|0;gGz(P|0,0,12);c[P>>2]=14165824;c[P+4>>2]=1;c[P+12>>2]=431712;gj[c[2076592]&4095](P)|0;gGz(O|0,0,12);c[O>>2]=14165632;c[O+4>>2]=1;c[O+12>>2]=421240;gj[c[2076592]&4095](O)|0;gGz(N|0,0,12);c[N>>2]=14165912;c[N+4>>2]=1;c[N+12>>2]=408304;gj[c[2076592]&4095](N)|0;gGz(M|0,0,12);c[M>>2]=14165920;c[M+4>>2]=1;c[M+12>>2]=398152;gj[c[2076592]&4095](M)|0;gGz(L|0,0,12);c[L>>2]=14165936;c[L+4>>2]=1;c[L+12>>2]=386112;gj[c[2076592]&4095](L)|0;gGz(K|0,0,12);c[K>>2]=14165928;c[K+4>>2]=1;c[K+12>>2]=375992;gj[c[2076592]&4095](K)|0;gGz(J|0,0,12);c[J>>2]=14166176;c[J+4>>2]=1;c[J+12>>2]=365624;gj[c[2076592]&4095](J)|0;gGz(I|0,0,12);c[I>>2]=14166208;c[I+4>>2]=1;c[I+12>>2]=358192;gj[c[2076592]&4095](I)|0;gGz(H|0,0,12);c[H>>2]=14166200;c[H+4>>2]=1;c[H+12>>2]=350656;gj[c[2076592]&4095](H)|0;gGz(G|0,0,12);c[G>>2]=14166192;c[G+4>>2]=1;c[G+12>>2]=342696;gj[c[2076592]&4095](G)|0;gGz(F|0,0,12);c[F>>2]=14166184;c[F+4>>2]=1;c[F+12>>2]=334688;gj[c[2076592]&4095](F)|0;gGz(E|0,0,12);c[E>>2]=14130528;c[E+4>>2]=2;c[E+12>>2]=326440;gj[c[2076592]&4095](E)|0;gGz(D|0,0,12);c[D>>2]=14130520;c[D+4>>2]=2;c[D+12>>2]=317440;gj[c[2076592]&4095](D)|0;gGz(C|0,0,12);c[C>>2]=14165440;c[C+4>>2]=4;c[C+12>>2]=308616;gj[c[2076592]&4095](C)|0;gGz(B|0,0,12);c[B>>2]=14165432;c[B+4>>2]=4;c[B+12>>2]=300528;gj[c[2076592]&4095](B)|0;gGz(A|0,0,12);c[A>>2]=14165448;c[A+4>>2]=4;c[A+12>>2]=292912;gj[c[2076592]&4095](A)|0;gGz(z|0,0,12);c[z>>2]=14165368;c[z+4>>2]=1;c[z+12>>2]=286544;gj[c[2076592]&4095](z)|0;i=e;return 0}function a1G(a,c,d,e){a=a|0;c=c|0;d=d|0;e=e|0;b[a>>1]=(b[a>>1]|0)+256&65535;return}function a1H(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;b[a>>1]=(d[c[3541454]|0]|0)<<8|b[a>>1];return}function a1I(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;g=b[a>>1]|0;if((g&128)==0){return}b[a>>1]=(d[c[3541454]|0]|0)<<8|g;return}function a1J(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;b[a>>1]=(d[c[3541454]|0]|0)<<9|b[a>>1];return}function a1K(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;h=c[3541454]|0;if((a[h+2|0]|0)==0){return}g=b[e>>1]|0;if((g&192)!=128){return}b[e>>1]=g&63|d[h]<<6|d[h+1|0]<<7|256;return}function a1L(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;b[a>>1]=(e[a>>1]|0|d<<3&256)&65535;return}function a1M(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;b[a>>1]=(d[(c[3541454]|0)+2|0]|0)<<8|b[a>>1];return}function a1N(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;h=b[e>>1]|0;if((h&192)!=128){return}g=c[3541454]|0;if((a[g+2|0]&1)==0){return}b[e>>1]=((((d[g+1|0]|0)<<7&128)+h&65535)+((d[g]|0)<<6&64|128)&65535)+((d[g+4|0]|0)<<8&256^256)&65535;return}function a1O(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;e=c[b>>2]|0;c[b>>2]=e>>>1&3|e<<2&4;return}function a1P(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;b[a>>1]=(e[a>>1]|0|d<<4&768)&65535;return}function a1Q(a,c,e,f){a=a|0;c=c|0;e=e|0;f=f|0;b[a>>1]=(d[14166040]|0)<<8|b[a>>1];return}function a1R(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;b[a>>1]=(d[(c[3541402]|0)+(g+288)|0]|0)<<8&256|b[a>>1];return}function a1S(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;g=c[3541454]|0;b[a>>1]=b[a>>1]|(d[g]|0)<<8|(d[g+1|0]|0)<<9;return}function a1T(d,e,f,g){d=d|0;e=e|0;f=f|0;g=g|0;if((a[c[3541454]|0]|0)==0){b[d>>1]=b[d>>1]|768;return}f=b[d>>1]|0;if((g|0)==28){b[d>>1]=f|768;return}else{b[d>>1]=f&255;return}}function a1U(a,d,f,g){a=a|0;d=d|0;f=f|0;g=g|0;b[a>>1]=(e[a>>1]|0|f<<4&768)&65535;c[d>>2]=c[d>>2]|f>>>3&8;return}function a1V(d,e,f,g){d=d|0;e=e|0;f=f|0;g=g|0;b[d>>1]=(a[(c[3541454]|0)+g|0]&7)<<8|b[d>>1];return}function a1W(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;b[a>>1]=(d[c[3541454]|0]|0)<<9|b[a>>1];return}function a1X(a,c,d,e,f,g,h){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;b[g>>1]=(b[g>>1]|0)+64&65535;return}function a1Y(a,e,f,g,h,i,j){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;b[i>>1]=(d[c[3541454]|0]|0)<<6|b[i>>1];return}function a1Z(a,e,f,g,h,i,j){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;b[i>>1]=b[i>>1]|(d[c[3541454]|0]|0)<<7|64;return}function a1_(e,f,g,h,i,j,k){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;k=c[3541454]|0;if((a[k+2|0]|0)==0){return}i=b[j>>1]|0;if((i&48)!=32){return}b[j>>1]=i&15|d[k]<<4|d[k+1|0]<<5|64;return}function a1$(a,c,e,f,g,h,i){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;b[h>>1]=(d[a+2|0]|0)<<1&64|b[h>>1];return}function a10(a,e,f,g,h,i,j){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;b[i>>1]=(d[(c[3541454]|0)+2|0]|0)<<6|b[i>>1];return}function a11(d,e,f,g,h,i,j){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;if((a[(c[3541454]|0)+2|0]|0)==0){return}b[i>>1]=b[i>>1]|64;return}function a12(e,f,g,h,i,j,k){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;k=b[j>>1]|0;if((k&48)!=32){return}i=c[3541454]|0;if((a[i+2|0]&1)==0){return}b[j>>1]=((((d[i+1|0]|0)<<5&32)+k&65535)+((d[i]|0)<<4&16|32)&65535)+((d[i+4|0]|0)<<6&64^64)&65535;return}function a13(b,c,d,e,f,g,h){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;g=a[h]|0;a[h]=(g&255)>>>1&3|g<<2&4;return}function a14(c,e,f,g,h,i,j){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;b[i>>1]=d[c+1|0]|0;a[g]=0;a[h]=0;return}function a15(a,c,e,f,g,h,i){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;b[h>>1]=(d[a+2|0]|0)<<2&192|b[h>>1];return}function a16(a,c,e,f,g,h,i){a=a|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;b[h>>1]=(d[14166040]|0)<<6|b[h>>1];return}function a17(c,e,f,g,h,i,j){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;b[i>>1]=d[c+1|0]|0|128;a[g]=0;return}function a18(a,e,f,g,h,i,j){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;j=c[3541454]|0;b[i>>1]=b[i>>1]|(d[j]|0)<<6|(d[j+1|0]|0)<<7;return}function a19(c,e,f,g,h,i,j){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;b[i>>1]=(d[c+2|0]|0)<<2&192|a[c+1|0]&127;a[g]=0;return}function a2a(a,e,f,g,h,i,j){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;b[i>>1]=b[i>>1]|(d[c[3541454]|0]|0)<<7|64;return}function a2b(){var b=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0.0,o=0.0,p=0.0,q=0.0,r=0.0,s=0.0,t=0.0,u=0.0,v=0;b=i;i=i+64|0;e=b|0;f=b+24|0;g=b+48|0;j=e|0;k=f|0;l=g|0;a2c(1e3,470,220,j,1e3,470,220,k,470,220,l);m=(d[14165632]|0)<<5;n=+h[j>>3];o=+h[e+8>>3];p=+h[e+16>>3];q=+h[k>>3];r=+h[f+8>>3];s=+h[f+16>>3];t=+h[l>>3];u=+h[g+8>>3];g=c[3541402]|0;l=c[3541410]|0;f=0;while(1){k=a[g+(f+m)|0]|0;c[l+(f<<2)>>2]=~~(q*+((k&255)>>>3&1|0)+ +((k&255)>>>4&1|0)*r+ +((k&255)>>>5&1|0)*s+.5)<<3&2016|~~(p*+((k&255)>>>2&1|0)+(n*+(k&1|0)+o*+((k&255)>>>1&1|0))+.5)<<8&63488|~~(+((k&255)>>>6&1|0)*t+ +((k&255)>>>7&255|0)*u+.5)>>>3&31;k=f+1|0;if((k|0)<32){f=k}else{v=0;break}}do{c[l+(v+64<<2)>>2]=c[616816+((v>>>2&3)<<2)>>2]<<3&2016|c[616816+((v&3)<<2)>>2]<<8&63488|(c[616816+((v>>>4&3)<<2)>>2]|0)>>>3&31;v=v+1|0;}while((v|0)<64);c[l+512>>2]=65535;c[l+516>>2]=65535;c[l+520>>2]=65535;c[l+524>>2]=65535;c[l+528>>2]=65535;c[l+532>>2]=65535;c[l+536>>2]=65535;c[l+540>>2]=65504;i=b;return}function a2c(a,b,d,e,f,g,j,k,l,m,n){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0.0,w=0.0,x=0.0,y=0.0,z=0.0,A=0.0,B=0.0,C=0.0,D=0.0,E=0.0,F=0.0,G=0.0,H=0.0,I=0.0,J=0.0;o=i;i=i+912|0;p=o|0;q=o+16|0;r=o+448|0;s=o+880|0;t=o+896|0;u=i;i=i+24|0;gGz(t|0,0,12);c[p>>2]=3;h[q>>3]=+(a|0);h[q+8>>3]=+(b|0);h[q+16>>3]=+(d|0);c[s>>2]=470;c[p+4>>2]=3;h[q+144>>3]=+(f|0);h[q+152>>3]=+(g|0);h[q+160>>3]=+(j|0);c[s+4>>2]=470;c[p+8>>2]=2;h[q+288>>3]=+(l|0);h[q+296>>3]=+(m|0);c[s+8>>2]=470;m=0;l=3;while(1){L60581:do{if((l|0)>0){j=c[s+(m<<2)>>2]|0;g=c[t+(m<<2)>>2]|0;f=(g|0)==0;v=1.0/+(g|0);w=1.0/+(j|0);if((j|0)==0){x=f?1.0e-12:v;j=0;while(1){g=0;y=1.0e-12;z=x;while(1){A=+h[q+(m*144|0)+(g<<3)>>3];d=A!=0.0;do{if((g|0)==(j|0)){if(!d){B=z;C=y;break}B=z+1.0/A;C=y}else{if(!d){B=z;C=y;break}B=z;C=y+1.0/A}}while(0);d=g+1|0;if((d|0)<(l|0)){g=d;y=C;z=B}else{break}}z=1.0/C;y=z*224.0/(z+1.0/B)+0.0;if(y<0.0){D=0.0}else{D=y>224.0?224.0:y}h[r+(m*144|0)+(j<<3)>>3]=D;j=j+1|0;if((j|0)>=(l|0)){break L60581}}}if(f){j=0;do{g=0;x=w;y=1.0e-12;while(1){z=+h[q+(m*144|0)+(g<<3)>>3];d=z!=0.0;do{if((g|0)==(j|0)){if(!d){E=y;F=x;break}E=y+1.0/z;F=x}else{if(!d){E=y;F=x;break}E=y;F=x+1.0/z}}while(0);d=g+1|0;if((d|0)<(l|0)){g=d;x=F;y=E}else{break}}y=1.0/F;x=y*224.0/(y+1.0/E)+0.0;if(x<0.0){G=0.0}else{G=x>224.0?224.0:x}h[r+(m*144|0)+(j<<3)>>3]=G;j=j+1|0;}while((j|0)<(l|0))}else{j=0;do{f=0;x=w;y=v;while(1){z=+h[q+(m*144|0)+(f<<3)>>3];g=z!=0.0;do{if((f|0)==(j|0)){if(!g){H=y;I=x;break}H=y+1.0/z;I=x}else{if(!g){H=y;I=x;break}H=y;I=x+1.0/z}}while(0);g=f+1|0;if((g|0)<(l|0)){f=g;x=I;y=H}else{break}}y=1.0/I;x=y*224.0/(y+1.0/H)+0.0;if(x<0.0){J=0.0}else{J=x>224.0?224.0:x}h[r+(m*144|0)+(j<<3)>>3]=J;j=j+1|0;}while((j|0)<(l|0))}}}while(0);j=m+1|0;if((j|0)>=3){break}m=j;l=c[p+(j<<2)>>2]|0}J=+h[r>>3];H=+h[r+8>>3];I=+h[r+16>>3];G=J+0.0+H+I;h[u>>3]=G;E=+h[r+144>>3];F=+h[r+152>>3];D=+h[r+160>>3];B=E+0.0+F+D;C=G>0.0?G:0.0;h[u+8>>3]=B;p=C<B;G=+h[r+288>>3];v=+h[r+296>>3];w=G+0.0+v;h[u+16>>3]=w;x=224.0/+h[u+(((p?B:C)<w?2:p&1)<<3)>>3];h[e>>3]=x*J;h[e+8>>3]=x*H;h[e+16>>3]=x*I;h[k>>3]=x*E;h[k+8>>3]=x*F;h[k+16>>3]=x*D;h[n>>3]=x*G;h[n+8>>3]=x*v;i=o;return}function a2d(){var b=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0.0,o=0.0,p=0.0,q=0.0,r=0.0,s=0.0,t=0.0,u=0.0,v=0;b=i;i=i+64|0;e=b|0;f=b+24|0;g=b+48|0;j=e|0;k=f|0;l=g|0;a2c(1e3,470,220,j,1e3,470,220,k,470,220,l);m=(d[14165632]|0)<<5;n=+h[j>>3];o=+h[e+8>>3];p=+h[e+16>>3];q=+h[k>>3];r=+h[f+8>>3];s=+h[f+16>>3];t=+h[l>>3];u=+h[g+8>>3];g=c[3541402]|0;l=c[3541410]|0;f=0;while(1){k=a[g+(f+m)|0]|0;c[l+(f<<2)>>2]=~~(q*+((k&255)>>>3&1|0)+ +((k&255)>>>4&1|0)*r+ +((k&255)>>>5&1|0)*s+.5)<<3&2016|~~(p*+((k&255)>>>2&1|0)+(n*+(k&1|0)+o*+((k&255)>>>1&1|0))+.5)<<8&63488|~~(+((k&255)>>>6&1|0)*t+ +((k&255)>>>7&255|0)*u+.5)>>>3&31;k=f+1|0;if((k|0)<64){f=k}else{v=0;break}}do{c[l+(v+64<<2)>>2]=c[616816+((v>>>2&3)<<2)>>2]<<3&2016|c[616816+((v&3)<<2)>>2]<<8&63488|(c[616816+((v>>>4&3)<<2)>>2]|0)>>>3&31;v=v+1|0;}while((v|0)<64);c[l+512>>2]=65535;c[l+516>>2]=65535;c[l+520>>2]=65535;c[l+524>>2]=65535;c[l+528>>2]=65535;c[l+532>>2]=65535;c[l+536>>2]=65535;c[l+540>>2]=65504;i=b;return}function a2e(){var a=0,b=0;a2b();a=c[3541410]|0;b=0;do{c[a+(b+136<<2)>>2]=((-(b>>>1&1)&31)+(-(b&1)&14)+(-(b>>>2&1)&67)+(-(b>>>3&1)&143)|0)>>>3&31;b=b+1|0;}while((b|0)<16);return}function a2f(){var a=0,b=0;a2b();a=c[3541410]|0;b=0;do{c[a+(b+136<<2)>>2]=-(b>>>1&1)<<3&480|-(b&1)<<8&30720|(-(b>>>2&1)|0)>>>3&8;b=b+1|0;}while((b|0)<8);return}function a2g(){var a=0,b=0;a2b();a=c[3541410]|0;b=0;do{c[a+(b+136<<2)>>2]=b>>>2&31;b=b+1|0;}while((b|0)<128);return}function a2h(){var a=0,b=0,d=0,e=0,f=0.0;a2b();a=c[3541410]|0;b=0;while(1){c[a+(b+136<<2)>>2]=b>>>2&31;d=b+1|0;if((d|0)<128){b=d}else{e=0;break}}do{f=+(e|0);c[a+(e+264<<2)>>2]=~~(f*.75)<<3&2016|((e|0)/2|0)>>>3&31|~~(f*1.5)<<8&63488;e=e+1|0;}while((e|0)<128);return}function a2i(){var b=0,e=0,f=0,g=0,j=0,k=0,l=0.0,m=0.0,n=0.0,o=0.0,p=0.0,q=0;b=i;i=i+64|0;e=b|0;f=b+48|0;g=e|0;j=f|0;a2c(1e3,470,220,g,1e3,470,220,b+24|0,470,220,j);k=(d[14165632]|0)<<5;l=+h[g>>3];m=+h[e+8>>3];n=+h[e+16>>3];o=+h[j>>3];p=+h[f+8>>3];f=c[3541402]|0;j=c[3541410]|0;e=0;while(1){g=a[f+(e+k)|0]|0;c[j+(e<<2)>>2]=~~(n*+((g&255)>>>2&1|0)+(l*+(g&1|0)+m*+((g&255)>>>1&1|0))+.5)<<8&63488|~~(o*+((g&255)>>>3&1|0)+ +((g&255)>>>4&1|0)*p+.5)>>>3&31;g=e+1|0;if((g|0)<32){e=g}else{q=0;break}}do{c[j+(q+64<<2)>>2]=c[616816+((q>>>2&3)<<2)>>2]<<3&2016|c[616816+((q&3)<<2)>>2]<<8&63488|(c[616816+((q>>>4&3)<<2)>>2]|0)>>>3&31;q=q+1|0;}while((q|0)<64);c[j+512>>2]=59392;c[j+516>>2]=29;i=b;return}function a2j(){var b=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0.0,o=0.0,p=0.0,q=0.0,r=0.0,s=0.0,t=0.0,u=0.0,v=0;b=i;i=i+64|0;e=b|0;f=b+24|0;g=b+48|0;j=e|0;k=f|0;l=g|0;a2c(1e3,470,220,j,1e3,470,220,k,470,220,l);m=(d[14165632]|0)<<5;n=+h[j>>3];o=+h[e+8>>3];p=+h[e+16>>3];q=+h[k>>3];r=+h[f+8>>3];s=+h[f+16>>3];t=+h[l>>3];u=+h[g+8>>3];g=c[3541402]|0;l=c[3541410]|0;f=0;while(1){k=a[g+(f+m)|0]|0;c[l+(f<<2)>>2]=~~(q*+((k&255)>>>3&1|0)+ +((k&255)>>>4&1|0)*r+ +((k&255)>>>5&1|0)*s+.5)<<8&63488|~~(p*+((k&255)>>>2&1|0)+(n*+(k&1|0)+o*+((k&255)>>>1&1|0))+.5)>>>3&31|~~(+((k&255)>>>6&1|0)*t+ +((k&255)>>>7&255|0)*u+.5)<<3&2016;k=f+1|0;if((k|0)<32){f=k}else{v=0;break}}do{c[l+(v+64<<2)>>2]=c[616816+((v>>>2&3)<<2)>>2]<<3&2016|c[616816+((v&3)<<2)>>2]<<8&63488|(c[616816+((v>>>4&3)<<2)>>2]|0)>>>3&31;v=v+1|0;}while((v|0)<64);c[l+512>>2]=65535;c[l+516>>2]=65535;c[l+520>>2]=65535;c[l+524>>2]=65535;c[l+528>>2]=65535;c[l+532>>2]=65535;c[l+536>>2]=65535;c[l+540>>2]=65504;v=0;do{c[l+(v+136<<2)>>2]=-(v>>>1&1)<<3&544|-(v&1)<<8&16384|(-(v>>>2&1)|0)>>>3&9;v=v+1|0;}while((v|0)<8);i=b;return}function a2k(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((c[3541360]|0)==0){return}d=(c[3541358]|0)+1|0;c[3541358]=d;e=(a[14165832]|0)==0;f=(a[14165824]|0)==0;g=c[2113070]|0;h=c[2113068]|0;i=c[2112926]|0;j=0;k=d;while(1){d=(c[9669288+(j*12|0)>>2]|0)+k|0;l=d>>>1&255;m=(d>>>9)+(c[9669292+(j*12|0)>>2]|0)|0;n=m&255;do{if(((m^d>>>4)&1|0)!=0){o=e?l:l^255;p=(f?n:n^255)-16|0;if(!((p|0)>-1&(g|0)>(p|0)&(h|0)>(o|0))){break}q=(c[9669296+(j*12|0)>>2]|0)+64&65535;b[i+((ag(h,p)|0)+o<<1)>>1]=q}}while(0);n=j+1|0;if((n|0)>=252){break}j=n;k=c[3541358]|0}return}function a2l(){var a=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;a=c[3541338]|0;e=c[2112926]|0;f=c[3532628]|0;g=0;h=0;while(1){i=g<<3;j=0;k=h;while(1){l=d[a+k|0]|0;m=(j<<3)-(b[7065264]&511)|0;n=i-(b[7065260]&255)|0;o=(m|0)<-8?m+512|0:m;m=((n|0)<-8?n+256|0:n)-16|0;do{if((o|0)>8){n=c[2113068]|0;if(!((o|0)<(n-8|0)&(m|0)>8)){p=47459;break}if((m|0)>=((c[2113070]|0)-8|0)){p=47459;break}q=f+(l<<6)|0;c[2112928]=q;r=e+((ag(n,m)|0)+o<<1)|0;s=0;t=q;while(1){b[r>>1]=d[t]|0|32;b[r+2>>1]=d[t+1|0]|0|32;b[r+4>>1]=d[t+2|0]|0|32;b[r+6>>1]=d[t+3|0]|0|32;b[r+8>>1]=d[t+4|0]|0|32;b[r+10>>1]=d[t+5|0]|0|32;b[r+12>>1]=d[t+6|0]|0|32;b[r+14>>1]=d[t+7|0]|0|32;q=s+1|0;u=t+8|0;if((q|0)<8){r=r+(n<<1)|0;s=q;t=u}else{break}}c[2112928]=u}else{p=47459}}while(0);if((p|0)==47459){p=0;Sj(e,l,o,m,0,4,32,f)}t=j+1|0;if((t|0)<64){j=t;k=k+1|0}else{break}}k=g+1|0;if((k|0)<32){g=k;h=h+64|0}else{break}}return}function a2m(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[3541360]|0)==0){return}d=c[2113222]|0;if((d-(c[3541476]|0)|0)>45){c[3541476]=d;c[3541362]=(c[3541362]|0)+1}d=(a[14165832]|0)==0;e=(a[14165824]|0)==0;f=c[2113070]|0;g=c[2113068]|0;h=c[2112926]|0;i=0;do{j=c[9669288+(i*12|0)>>2]|0;k=c[9669292+(i*12|0)>>2]|0;do{if(((k>>>1^j>>>4)&1|0)!=0){l=c[3541362]&3;if((l|0)==1){if((c[9669296+(i*12|0)>>2]&4|0)==0){break}}else if((l|0)==2){if((k&2|0)==0){break}}else if((l|0)==0){if((c[9669296+(i*12|0)>>2]&1|0)==0){break}}l=j>>1;m=k&255;if((l|0)>239){break}n=d?l:255-l|0;l=(e?m:m^255)-16|0;if(!((l|0)>-1&(f|0)>(l|0)&(n|0)>-1&(g|0)>(n|0))){break}m=(c[9669296+(i*12|0)>>2]|0)+64&65535;b[h+((ag(g,l)|0)+n<<1)>>1]=m}}while(0);i=i+1|0;}while((i|0)<252);return}function a2n(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c[(c[3541410]|0)+544>>2]=8;d=c[2113070]|0;e=(d|0)>0;if((a[14165832]|0)==0){if(!e){return}f=c[2113068]|0;g=c[2112926]|0;h=0;do{i=ag(f,h)|0;j=0;do{b[g+(i+j<<1)>>1]=136;j=j+1|0;}while((j|0)<136);h=h+1|0;}while((h|0)<(d|0));return}if(!e){return}e=c[2113068]|0;h=e-1|0;g=(h|0)>120;f=c[2112926]|0;j=e-2|0;i=(j|0)>120;k=0;do{do{if(g){l=ag(e,k)|0;b[f+(l+h<<1)>>1]=136;if(i){m=j}else{break}do{b[f+(l+m<<1)>>1]=136;m=m-1|0;}while((m|0)>120)}}while(0);k=k+1|0;}while((k|0)<(d|0));return}function a2o(){var a=0,e=0,f=0,g=0,h=0;c[(c[3541410]|0)+544>>2]=((d[14165920]|0)*568|0)&2016|((d[14165912]|0)*21760|0)&63488|((d[14165936]|0)*85|0)>>>3&31;a=c[2113070]|0;if((a|0)<=0){return}e=c[2113068]|0;f=c[2112926]|0;g=0;do{if((e|0)>0){h=0;do{b[f+((ag(e,g)|0)+h<<1)>>1]=136;h=h+1|0;}while((h|0)<(e|0))}g=g+1|0;}while((g|0)<(a|0));return}function a2p(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c[(c[3541410]|0)+544>>2]=10;do{if((a[14165928]|0)!=0){d=c[2113070]|0;if((d|0)<=0){break}e=c[2113068]|0;f=c[2112926]|0;g=0;do{if((e|0)>0){h=0;do{b[f+((ag(e,g)|0)+h<<1)>>1]=136;h=h+1|0;}while((h|0)<(e|0))}g=g+1|0;}while((g|0)<(d|0))}}while(0);if((c[3541360]|0)==0){return}d=c[2113222]|0;if((d-(c[3541476]|0)|0)>45){c[3541476]=d;c[3541362]=(c[3541362]|0)+1}d=(a[14165832]|0)==0;g=(a[14165824]|0)==0;e=c[2113070]|0;f=c[2113068]|0;h=c[2112926]|0;i=0;do{j=c[9669288+(i*12|0)>>2]|0;k=j>>1;l=c[9669292+(i*12|0)>>2]|0;do{if(((l^j>>>4)&1|0)!=0){m=c[3541362]&3;if((m|0)==2){if((l&2|0)==0){break}}else if((m|0)==1){if((c[9669296+(i*12|0)>>2]&4|0)==0){break}}else if((m|0)==0){if((c[9669296+(i*12|0)>>2]&1|0)==0){break}}m=d?k:255-k|0;n=(g?l:255-l|0)-16|0;if(!((n|0)>-1&(e|0)>(n|0)&(m|0)>-1&(f|0)>(m|0))){break}o=(c[9669296+(i*12|0)>>2]|0)+64&65535;b[h+((ag(f,n)|0)+m<<1)>>1]=o}}while(0);i=i+1|0;}while((i|0)<252);return}function a2q(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c[(c[3541410]|0)+544>>2]=10;if((a[14165928]|0)==0){return}d=c[2113070]|0;e=(d|0)>0;if((a[14165832]|0)==0){if(!e){return}f=c[2113068]|0;g=c[2112926]|0;h=0;do{i=ag(f,h)|0;j=0;do{b[g+(i+j<<1)>>1]=136;j=j+1|0;}while((j|0)<56);h=h+1|0;}while((h|0)<(d|0));return}if(!e){return}e=c[2113068]|0;h=e-1|0;g=(h|0)>200;f=c[2112926]|0;j=e-2|0;i=(j|0)>200;k=0;do{do{if(g){l=ag(e,k)|0;b[f+(l+h<<1)>>1]=136;if(i){m=j}else{break}do{b[f+(l+m<<1)>>1]=136;m=m-1|0;}while((m|0)>200)}}while(0);k=k+1|0;}while((k|0)<(d|0));return}function a2r(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=c[3541402]|0;f=(a[14165832]|0)==0;g=c[2113070]|0;h=(g|0)>0;i=c[2113068]|0;j=c[2112926]|0;if(f){k=0;while(1){if((k|0)==31){l=136}else{l=(d[e+(k+33)|0]|0)+136&65535}m=k<<3;if(h){n=m+8|0;o=0;do{p=ag(i,o)|0;q=m;do{b[j+(p+q<<1)>>1]=l;q=q+1|0;}while((q|0)<(n|0));o=o+1|0;}while((o|0)<(g|0))}o=k+1|0;if((o|0)<32){k=o}else{r=g;s=i;t=j;break}}}else{k=0;while(1){if((k|0)==0){u=136}else{u=(d[e+(k+63)|0]|0)+136&65535}l=31-k<<3;if(h){o=l+8|0;n=0;do{m=ag(i,n)|0;q=l;do{b[j+(m+q<<1)>>1]=u;q=q+1|0;}while((q|0)<(o|0));n=n+1|0;}while((n|0)<(g|0))}n=k+1|0;if((n|0)<32){k=n}else{r=g;s=i;t=j;break}}}if((c[3541360]|0)==0){return}j=(c[3541358]|0)+1|0;c[3541358]=j;i=0;g=j;while(1){j=(c[9669288+(i*12|0)>>2]|0)+g|0;k=j>>>1&255;u=(j>>>9)+(c[9669292+(i*12|0)>>2]|0)|0;h=u&255;do{if(((u^j>>>4)&1|0)!=0){n=f?k:k^255;if((a[e+((n>>>3)+1&31|288)|0]&4)==0){break}o=((a[14165824]|0)==0?h:h^255)-16|0;if(!((o|0)>-1&(r|0)>(o|0)&(s|0)>(n|0))){break}l=(c[9669296+(i*12|0)>>2]|0)+64&65535;b[t+((ag(s,o)|0)+n<<1)>>1]=l}}while(0);h=i+1|0;if((h|0)>=252){break}i=h;g=c[3541358]|0}return}function a2s(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=c[3541402]|0;e=c[2113070]|0;f=(a[14165912]|0)!=0;g=(a[14165920]|0)!=0;h=(a[14165832]|0)==0;i=c[2113068]|0;j=c[2112926]|0;k=0;do{l=a[d+(k+32)|0]|0;m=(l&2)==0;n=m&f&1;o=m&g?n|2:n;n=(h?k:31-k|0)<<3;if((e|0)>0){m=n+8|0;p=(((l&1)==0&(a[14165936]|0)!=0?o|4:o)|136)&65535;o=0;do{l=ag(i,o)|0;q=n;do{b[j+(l+q<<1)>>1]=p;q=q+1|0;}while((q|0)<(m|0));o=o+1|0;}while((o|0)<(e|0))}k=k+1|0;}while((k|0)<32);return}function a2t(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;do{if((a[14165928]|0)!=0){d=c[2113070]|0;e=c[2113068]|0;f=c[2112926]|0;g=0;while(1){if((d|0)>0){h=g+136&65535;i=0;do{b[f+((ag(e,i)|0)+g<<1)>>1]=h;i=i+1|0;}while((i|0)<(d|0))}i=g+1|0;if((i|0)<128){g=i}else{j=0;break}}do{if((d|0)>0){g=j+144&65535;i=j+128|0;h=0;do{b[f+(i+(ag(e,h)|0)<<1)>>1]=g;h=h+1|0;}while((h|0)<(d|0))}j=j+1|0;}while((j|0)<120);if((d|0)>0){k=0}else{break}do{b[f+((ag(e,k)|0)+248<<1)>>1]=136;k=k+1|0;}while((k|0)<(d|0));if((d|0)>0){l=0}else{break}while(1){b[f+((ag(e,l)|0)+249<<1)>>1]=136;h=l+1|0;if((h|0)<(d|0)){l=h}else{m=0;break}}while(1){b[f+((ag(e,m)|0)+250<<1)>>1]=136;h=m+1|0;if((h|0)<(d|0)){m=h}else{n=0;break}}while(1){b[f+((ag(e,n)|0)+251<<1)>>1]=136;h=n+1|0;if((h|0)<(d|0)){n=h}else{o=0;break}}while(1){b[f+((ag(e,o)|0)+252<<1)>>1]=136;h=o+1|0;if((h|0)<(d|0)){o=h}else{p=0;break}}while(1){b[f+((ag(e,p)|0)+253<<1)>>1]=136;h=p+1|0;if((h|0)<(d|0)){p=h}else{q=0;break}}while(1){b[f+((ag(e,q)|0)+254<<1)>>1]=136;h=q+1|0;if((h|0)<(d|0)){q=h}else{r=0;break}}do{b[f+((ag(e,r)|0)+255<<1)>>1]=136;r=r+1|0;}while((r|0)<(d|0))}}while(0);if((c[3541360]|0)==0){return}aNq();return}function a2u(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;do{if((a[14165928]|0)!=0){d=c[2113070]|0;e=c[2113068]|0;f=c[2112926]|0;g=0;while(1){if((d|0)>0){h=g+136&65535;i=0;do{b[f+((ag(e,i)|0)+g<<1)>>1]=h;i=i+1|0;}while((i|0)<(d|0))}i=g+1|0;if((i|0)<128){g=i}else{j=0;break}}do{if((d|0)>0){g=j+264&65535;i=j+128|0;h=0;do{b[f+(i+(ag(e,h)|0)<<1)>>1]=g;h=h+1|0;}while((h|0)<(d|0))}j=j+1|0;}while((j|0)<120);if((d|0)>0){k=0}else{break}do{b[f+((ag(e,k)|0)+248<<1)>>1]=136;k=k+1|0;}while((k|0)<(d|0));if((d|0)>0){l=0}else{break}while(1){b[f+((ag(e,l)|0)+249<<1)>>1]=136;h=l+1|0;if((h|0)<(d|0)){l=h}else{m=0;break}}while(1){b[f+((ag(e,m)|0)+250<<1)>>1]=136;h=m+1|0;if((h|0)<(d|0)){m=h}else{n=0;break}}while(1){b[f+((ag(e,n)|0)+251<<1)>>1]=136;h=n+1|0;if((h|0)<(d|0)){n=h}else{o=0;break}}while(1){b[f+((ag(e,o)|0)+252<<1)>>1]=136;h=o+1|0;if((h|0)<(d|0)){o=h}else{p=0;break}}while(1){b[f+((ag(e,p)|0)+253<<1)>>1]=136;h=p+1|0;if((h|0)<(d|0)){p=h}else{q=0;break}}while(1){b[f+((ag(e,q)|0)+254<<1)>>1]=136;h=q+1|0;if((h|0)<(d|0)){q=h}else{r=0;break}}do{b[f+((ag(e,r)|0)+255<<1)>>1]=136;r=r+1|0;}while((r|0)<(d|0))}}while(0);if((c[3541360]|0)==0){return}aNq();return}function a2v(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;e=a[14165832]|0;f=e<<24>>24==0;g=d[14166184]|0;h=254-g|0;i=f?0:h;j=f?h:0;h=a[14166192]|0;k=h<<24>>24==0;l=256-g|0;g=e<<24>>24!=0;e=a[14166200]|0;m=a[14166208]|0;n=((g?e:m)&255)+136&65535;o=c[2113070]|0;p=(o|0)>0;q=c[2113068]|0;r=c[2112926]|0;s=0;do{if(k){if(p){t=0;u=47637}}else{if((s|0)<=(j|0)&(s|0)>=(i|0)&p){t=0;u=47637}}if((u|0)==47637){while(1){u=0;b[r+((ag(q,t)|0)+s<<1)>>1]=n;v=t+1|0;if((v|0)<(o|0)){t=v;u=47637}else{break}}}s=s+1|0;}while((s|0)<(l|0));if(l>>>0<255){s=((g?m:e)&255)+136&65535;e=255;do{if(k){if((o|0)>0){w=0;u=47642}}else{if((e|0)<=(j|0)&(e|0)>=(i|0)&(o|0)>0){w=0;u=47642}}if((u|0)==47642){while(1){u=0;b[r+((ag(q,w)|0)+e<<1)>>1]=s;m=w+1|0;if((m|0)<(o|0)){w=m;u=47642}else{break}}}e=e-1|0;}while((e|0)>(l|0))}if((c[3541360]|0)==0|h<<24>>24!=0){return}h=(c[3541358]|0)+1|0;c[3541358]=h;l=(a[14165824]|0)==0;e=0;u=h;while(1){h=(c[9669288+(e*12|0)>>2]|0)+u|0;w=h>>>1&255;s=(h>>>9)+(c[9669292+(e*12|0)>>2]|0)|0;i=s&255;do{if(((s^h>>>4)&1|0)!=0){j=f?w:w^255;k=(l?i:i^255)-16|0;if(!((k|0)>-1&(o|0)>(k|0)&(q|0)>(j|0))){break}m=(c[9669296+(e*12|0)>>2]|0)+64&65535;b[r+((ag(q,k)|0)+j<<1)>>1]=m}}while(0);i=e+1|0;if((i|0)>=252){break}e=i;u=c[3541358]|0}return}function a2w(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=d-4|0;g=d-3|0;h=a+128|0;a=(e|0)>-1&(c[2113070]|0)>(e|0);do{if(a&(f|0)>-1){i=c[2113068]|0;if((i|0)<=(f|0)){break}j=(ag(i,e)|0)+f|0;b[(c[2112926]|0)+(j<<1)>>1]=h&65535}}while(0);f=d-2|0;do{if(a&(g|0)>-1){j=c[2113068]|0;if((j|0)<=(g|0)){break}i=(ag(j,e)|0)+g|0;b[(c[2112926]|0)+(i<<1)>>1]=h&65535}}while(0);g=d-1|0;do{if(a&(f|0)>-1){i=c[2113068]|0;if((i|0)<=(f|0)){break}j=(ag(i,e)|0)+f|0;b[(c[2112926]|0)+(j<<1)>>1]=h&65535}}while(0);if(!(a&(d|0)>0)){return}d=c[2113068]|0;if((d|0)<=(g|0)){return}a=(ag(d,e)|0)+g|0;b[(c[2112926]|0)+(a<<1)>>1]=h&65535;return}function a2x(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=d-4|0;c[(c[3541410]|0)+540>>2]=63519;g=d-3|0;h=a+128|0;a=(e|0)>-1&(c[2113070]|0)>(e|0);do{if(a&(f|0)>-1){i=c[2113068]|0;if((i|0)<=(f|0)){break}j=(ag(i,e)|0)+f|0;b[(c[2112926]|0)+(j<<1)>>1]=h&65535}}while(0);f=d-2|0;do{if(a&(g|0)>-1){j=c[2113068]|0;if((j|0)<=(g|0)){break}i=(ag(j,e)|0)+g|0;b[(c[2112926]|0)+(i<<1)>>1]=h&65535}}while(0);g=d-1|0;do{if(a&(f|0)>-1){i=c[2113068]|0;if((i|0)<=(f|0)){break}j=(ag(i,e)|0)+f|0;b[(c[2112926]|0)+(j<<1)>>1]=h&65535}}while(0);if(!(a&(d|0)>0)){return}d=c[2113068]|0;if((d|0)<=(g|0)){return}a=(ag(d,e)|0)+g|0;b[(c[2112926]|0)+(a<<1)>>1]=h&65535;return}function a2y(a,d,e){a=a|0;d=d|0;e=e|0;var f=0;a=d-6|0;if(!((e|0)>-1&(c[2113070]|0)>(e|0)&(a|0)>-1)){return}d=c[2113068]|0;if((d|0)<=(a|0)){return}f=(ag(d,e)|0)+a|0;b[(c[2112926]|0)+(f<<1)>>1]=135;return}function a2z(a,d,e){a=a|0;d=d|0;e=e|0;var f=0;a=d-6|0;c[(c[3541410]|0)+540>>2]=61298;if(!((e|0)>-1&(c[2113070]|0)>(e|0)&(a|0)>-1)){return}d=c[2113068]|0;if((d|0)<=(a|0)){return}f=(ag(d,e)|0)+a|0;b[(c[2112926]|0)+(f<<1)>>1]=135;return}function a2A(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[3541410]|0;c[a+512>>2]=65535;c[a+516>>2]=65504;c[a+520>>2]=2047;c[a+524>>2]=2016;c[a+528>>2]=63519;c[a+532>>2]=63488;c[a+536>>2]=31;c[a+540>>2]=0;a=d-1|0;if((a&64|0)==0){f=(a>>>2&7|128)&65535}else{f=132}g=(e|0)>-1&(c[2113070]|0)>(e|0);do{if(g&(d|0)>0){h=c[2113068]|0;if((h|0)<=(a|0)){break}i=(ag(h,e)|0)+a|0;b[(c[2112926]|0)+(i<<1)>>1]=f}}while(0);f=d-2|0;if((f&64|0)==0){j=(f>>>2&7|128)&65535}else{j=132}do{if(g&(f|0)>-1){a=c[2113068]|0;if((a|0)<=(f|0)){break}i=(ag(a,e)|0)+f|0;b[(c[2112926]|0)+(i<<1)>>1]=j}}while(0);j=d-3|0;if((j&64|0)==0){k=(j>>>2&7|128)&65535}else{k=132}do{if(g&(j|0)>-1){f=c[2113068]|0;if((f|0)<=(j|0)){break}i=(ag(f,e)|0)+j|0;b[(c[2112926]|0)+(i<<1)>>1]=k}}while(0);k=d-4|0;if((k&64|0)==0){l=(k>>>2&7|128)&65535}else{l=132}if(!(g&(k|0)>-1)){return}g=c[2113068]|0;if((g|0)<=(k|0)){return}d=(ag(g,e)|0)+k|0;b[(c[2112926]|0)+(d<<1)>>1]=l;return}function a2B(e,f,g){e=e|0;f=f|0;g=g|0;var h=0,i=0;e=f-6+((a[14165832]|0)!=0)|0;f=(d[14166176]|0)+128&65535;if(!((g|0)>-1&(c[2113070]|0)>(g|0)&(e|0)>-1)){return}h=c[2113068]|0;if((h|0)<=(e|0)){return}i=(ag(h,g)|0)+e|0;b[(c[2112926]|0)+(i<<1)>>1]=f;return}function a2C(d,e,f){d=d|0;e=e|0;f=f|0;var g=0,h=0;g=(d|0)<16;d=(g<<31>>31<<1)+f|0;f=e-6+((g^1)<<31>>31<<1)+((a[14165832]|0)!=0)|0;if(!((d|0)>-1&(c[2113070]|0)>(d|0)&(f|0)>-1)){return}e=c[2113068]|0;if((e|0)<=(f|0)){return}h=(ag(e,d)|0)+f|0;b[(c[2112926]|0)+(h<<1)>>1]=g?135:128;return}function a2D(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;g=i;i=i+16|0;h=g|0;j=g+8|0;k=0;l=0;m=a[14165880]|0;while(1){n=k;o=0;p=m;while(1){q=n&31;b[j>>1]=d[f+n|0]|0;r=d[(c[3541366]|0)+(q<<1|1)|0]|0;c[h>>2]=r&(p<<24>>24==3?3:7);s=c[3541462]|0;if((s|0)!=0){gL[s&255](j,h,r,q)}q=a[7461664]|0;r=(q?o:l)<<3;s=(q?l:o)<<3;t=(a[14165832]|0)==0;if(t){u=s}else{u=-8-s+(c[2113068]|0)|0}s=(a[14165824]|0)==0;v=c[2113070]|0;if(s){w=r-16|0}else{w=8-r+v|0}x=a[14165880]|0;r=c[h>>2]<<(x&255);y=c[3541472]|0;z=(c[3541380]|0)+o|0;A=a[7461888]|0;B=c[2113068]|0;C=c[2112926]|0;D=0;do{E=7-D|0;F=D+w|0;G=0;do{H=a[y+((t?G:7-G|0)+((s?D:E)<<3)+(e[j>>1]<<6))|0]|0;do{if(H<<24>>24!=0){I=G+u|0;J=d[z]|0;K=-J|0;do{if(q){L=(t?K:J)+I|0;M=(L|0)<0?L+256|0:L;if((M|0)<=255){N=F;O=M;break}N=F;O=M-256|0}else{M=(s?K:J)+F|0;L=(M|0)<0?M+256|0:M;if((L|0)<=255){N=L;O=I;break}N=L-256|0;O=I}}while(0);if(A){P=B+~O|0}else{P=O}if(!((N|0)>-1&(N|0)<(v|0))){break}if(!((P|0)>-1&(P|0)<(B|0))){break}b[C+((ag(B,N)|0)+P<<1)>>1]=(H&255|r)&65535}}while(0);G=G+1|0;}while((G|0)<8);D=D+1|0;}while((D|0)<8);D=o+1|0;if((D|0)>=32){break}n=n+1|0;o=D;p=x}p=l+1|0;if((p|0)<32){k=k+32|0;l=p;m=x}else{break}}i=g;return}function a2E(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;g=i;i=i+48|0;h=g|0;j=g+8|0;k=g+16|0;l=g+24|0;m=g+32|0;n=g+40|0;o=(a[14165832]|0)!=0?16:0;p=(d[14165472]|0)-o|0;q=(-o|1)+(d[14165480]|0)|0;o=7;while(1){r=o<<2;s=f+r|0;t=a[s]|0;if(a[7461920]|0){u=(t&255)>>>4|t<<4}else{u=t}c[h>>2]=((o|0)<3|240)-(u&255);t=a[f+(r|1)|0]|0;b[j>>1]=t&63;a[k]=t&64;a[l]=t&-128;a[m]=((a[14165880]|0)==3?3:7)&a[f+(r|2)|0];t=d[f+(r|3)|0]|0;c[n>>2]=t;r=c[3541464]|0;if((r|0)==0){v=t}else{gw[r&127](s,n,h,k,l,j,m);v=c[n>>2]|0}if((a[14165832]|0)==0){w=v}else{s=242-v|0;c[n>>2]=s;a[k]=(a[k]|0)==0|0;w=s}L61131:do{if(!((w|0)<(p|0)|(w|0)>(q|0))){s=c[h>>2]|0;if((a[14165824]|0)==0){x=s}else{r=240-s|0;c[h>>2]=r;a[l]=(a[l]|0)==0|0;x=r}r=x-16|0;c[h>>2]=r;if(a[7461888]|0){s=241-w|0;c[n>>2]=s;a[k]=(a[k]|0)==0|0;y=s}else{y=w}do{if((y|0)>16){if(!((y|0)<((c[2113068]|0)-16|0)&(r|0)>16)){break}if((r|0)>=((c[2113070]|0)-16|0)){break}s=(a[l]|0)!=0;t=c[2112926]|0;z=e[j>>1]|0;A=d[m]|0;B=d[14165880]|0;C=c[3541364]|0;if((a[k]|0)==0){if(s){SK(t,z,y,r,A,B,0,0,C);break L61131}else{SG(t,z,y,r,A,B,0,0,C);break L61131}}else{if(s){SM(t,z,y,r,A,B,0,0,C);break L61131}else{SI(t,z,y,r,A,B,0,0,C);break L61131}}}}while(0);C=(a[l]|0)!=0;B=c[2112926]|0;A=e[j>>1]|0;z=d[m]|0;t=d[14165880]|0;s=c[3541364]|0;if((a[k]|0)==0){if(C){SL(B,A,y,r,z,t,0,0,s);break}else{SH(B,A,y,r,z,t,0,0,s);break}}else{if(C){SN(B,A,y,r,z,t,0,0,s);break}else{SJ(B,A,y,r,z,t,0,0,s);break}}}}while(0);if((o|0)<=0){break}o=o-1|0}i=g;return}function a2F(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if((c[2113070]|0)<=0){return}e=b+13|0;f=b+17|0;g=b+21|0;h=b+25|0;i=b+29|0;j=b+1|0;k=b+5|0;l=b+9|0;m=0;do{n=(a[14165824]|0)!=0;o=m+15|0;p=n?o^255:o;o=m+16|0;q=n?o^255:o;if(((d[e]|0)+q&255|0)==255){r=3}else{r=((d[l]|0)+p&255|0)==255?2:((d[k]|0)+p&255|0)==255?1:(((d[j]|0)+p&255|0)!=255)<<31>>31}p=((d[h]|0)+q&255|0)==255?6:((d[g]|0)+q&255|0)==255?5:((d[f]|0)+q&255|0)==255?4:r;o=((d[i]|0)+q&255|0)==255;q=p&255;if(p<<24>>24!=-1){p=d[b+(q<<2|3)|0]|0;gG[c[3541466]&255](q,a[7461888]|0?p:p^255,m)}p=o?7:255;if(o){o=d[b+(p<<2|3)|0]|0;gG[c[3541466]&255](p,a[7461888]|0?o:o^255,m)}m=m+1|0;}while((m|0)<(c[2113070]|0));return}function a2G(){var a=0,b=0;a=c[2112926]|0;gGz(a|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);gu[c[3541474]&16383]();a=c[3541392]|0;if((a|0)!=0){gu[a&16383]()}a2D(c[3541340]|0);a2E((c[3541366]|0)+64|0);a2E((c[3541366]|0)+96|0);a2E((c[3541366]|0)+192|0);a2E((c[3541366]|0)+224|0);if((c[3541466]|0)==0){b=c[3541410]|0;R8(b);return}a2F((c[3541366]|0)+96|0);b=c[3541410]|0;R8(b);return}function a2H(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=c[2112926]|0;gGz(b|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);gu[c[3541474]&16383]();b=c[3541392]|0;if((b|0)!=0){gu[b&16383]()}a2D(c[3541340]|0);a2E((c[3541366]|0)+64|0);if((c[3541466]|0)!=0){a2F((c[3541366]|0)+96|0)}if((a[14166192]|0)==0){d=c[3541410]|0;R8(d);return}b=c[3541392]|0;if((b|0)!=0){gu[b&16383]()}b=c[3541338]|0;gGz(b|0,32,1024);e=c[3541366]|0;f=c[3541340]|0;g=0;do{if((a[e+(g<<1|1)|0]&4)>>>0>3){h=0;do{i=(h<<5)+g|0;a[b+i|0]=a[f+i|0]|0;h=h+1|0;}while((h|0)<32)}g=g+1|0;}while((g|0)<32);a2D(b);d=c[3541410]|0;R8(d);return}function a2I(){var a=0,b=0;a=c[2112926]|0;gGz(a|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);gu[c[3541474]&16383]();a=c[3541392]|0;if((a|0)!=0){gu[a&16383]()}a2D(c[3541340]|0);a2E((c[3541366]|0)+64|0);if((c[3541466]|0)==0){b=c[3541410]|0;R8(b);return}a2F((c[3541366]|0)+192|0);b=c[3541410]|0;R8(b);return}function a2J(){var a=0,b=0;a=c[2112926]|0;gGz(a|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);gu[c[3541474]&16383]();a=c[3541392]|0;if((a|0)!=0){gu[a&16383]()}a2D(c[3541340]|0);a2E((c[3541366]|0)+64|0);a2E((c[3541366]|0)+320|0);a2E((c[3541366]|0)+576|0);a2E((c[3541366]|0)+832|0);if((c[3541466]|0)==0){b=c[3541410]|0;R8(b);return}a2F((c[3541366]|0)+192|0);b=c[3541410]|0;R8(b);return}function a2K(){var a=0,b=0;a=c[2112926]|0;gGz(a|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);gu[c[3541474]&16383]();a=c[3541392]|0;if((a|0)!=0){gu[a&16383]()}a2D(c[3541340]|0);a2E((c[3541366]|0)+192|0);if((c[3541466]|0)==0){b=c[3541410]|0;R8(b);return}a2F((c[3541366]|0)+224|0);b=c[3541410]|0;R8(b);return}function a2L(b){b=b|0;var d=0,e=0,f=0;if((b&1044480|0)!=720896){d=0;return d|0}e=c[2433502]|0;f=c[3529856]|0;if((b|0)==724987&(e|0)!=0){gGC(f|0,e|0,96)|0}d=a[f+(b&4095)|0]|0;return d|0}function a2M(d,f){d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;g=d&1044480;if((g|0)==720896){h=c[3529856]|0;a[h+(d&4095)|0]=~f;if((d|0)!=724991){return}i=c[2438084]|0;if(!(f<<24>>24==0&(i|0)!=0)){return}j=h+4064|0;gGC(j|0,i|0,18)|0;return}else if((g|0)==819200){i=(d&1|0)==0;j=i?f|-32:-1;h=d&3583;k=c[2387296]|0;a[k+(h|512)|0]=j;a[k+h|0]=j;if(!i){return}i=((d|0)/2|0)&255;j=k;k=e[j+((i|512)<<1)>>1]|0;c[(c[3530212]|0)+(i<<2)>>2]=b[j+((i|1024)<<1)>>1]&31|(e[j+(i<<1)>>1]|0)<<11&63488|(k>>>2&4|k<<3)<<3&2016;return}else if((g|0)==835584){g=(d&1|0)==0;k=g?f|-32:-1;f=d&3583;i=c[2387296]|0;a[i+(f|4608)|0]=k;a[i+(f|4096)|0]=k;if(!g){return}g=((d|0)/2|0)&255;d=i+4096|0;i=e[d+((g|512)<<1)>>1]|0;c[(c[3530212]|0)+((g|256)<<2)>>2]=b[d+((g|1024)<<1)>>1]&31|(e[d+(g<<1)>>1]|0)<<11&63488|(i>>>2&4|i<<3)<<3&2016;return}else{return}}function a2N(d,f){d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;g=d&1044480;if((g|0)==819200|(g|0)==655360|(g|0)==835584){h=(d&1|0)==0;i=h?f|-32:-1;j=d&3583;k=c[2387296]|0;a[k+(j|512)|0]=i;a[k+j|0]=i;if(!h){return}h=((d|0)/2|0)&255;i=k;k=e[i+((h|512)<<1)>>1]|0;c[(c[3530212]|0)+(h<<2)>>2]=b[i+((h|1024)<<1)>>1]&31|(e[i+(h<<1)>>1]|0)<<11&63488|(k>>>2&4|k<<3)<<3&2016;return}else if((g|0)==884736|(g|0)==688128|(g|0)==671744){g=(d&1|0)==0;k=g?f|-32:-1;h=d&3583;i=c[2387296]|0;a[i+(h|4608)|0]=k;a[i+(h|4096)|0]=k;if(!g){return}g=((d|0)/2|0)&255;k=i+4096|0;i=e[k+((g|512)<<1)>>1]|0;c[(c[3530212]|0)+((g|256)<<2)>>2]=b[k+((g|1024)<<1)>>1]&31|(e[k+(g<<1)>>1]|0)<<11&63488|(i>>>2&4|i<<3)<<3&2016;return}else{if((d|0)==720897|(d|0)==917505){c[2429622]=c[2429622]&255|(f&255)<<8;return}else if((d|0)==720896|(d|0)==917504){c[2429622]=c[2429622]&65280|f&255;return}else if((d|0)==770048|(d|0)==966656){d=c[2386590]|0;f=c[2386542]|0;gGC(d|0,f|0,1024)|0;return}else{return}}}function a2O(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;switch(b|0){case 0:{a[c[3528384]|0]=d;e=a[9542400]&-33;a[9542400]=e;a[14125144]=e;a[9706117]=1;if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){e=gfc(1e3)|0;f=e;g=(c[2433530]|0)+e|0}else{f=1e3;g=(c[2433530]|0)+1e3|0}c[2433530]=g;c[2444004]=(c[2444004]|0)+f;return};case 2:{a[c[2440176]|0]=d&8;if(!(a[1558240]|0)){return}if((d&16)==0){gGz(9706056,0,76);a[9542400]=-1;a[9706117]=0;a[627120]=1;return}else{a[627120]=0;return}break};case 6:{c[2429622]=c[2429622]&65280|d&255;return};case 4:case 5:{gGC(c[2386590]|0,c[2386542]|0,1024)|0;return};case 7:{c[2429622]=c[2429622]&255|(d&255)<<8;return};case 135:case 134:case 133:case 128:case 129:case 130:case 131:case 132:{a[(c[2409012]|0)+(b&7)|0]=d;return};case 143:{c[2426972]=d<<24>>24!=0;return};case 192:{b=c[2426970]|0;if((b|0)==0){return}f=d&255;if((f|0)>=(c[b>>2]|0)){return}c[2438064]=c[b+(f+1<<2)>>2];return};default:{return}}}function a2P(b){b=b|0;var c=0,e=0,f=0,g=0;L61321:do{switch(b|0){case 0:{c=a[9551040]|0;break};case 5:{c=a[9635753]|0;break};case 3:{c=-1;break};case 1:{c=a[9551041]|0;break};case 2:{c=a[9551042]|0;break};case 4:{c=a[9635752]|0;break};default:{if((b&248|0)!=8){c=0;break L61321}e=b>>>1&3;if((e|0)==3){f=31;g=31}else if((e|0)==1){e=(d[9551040]|0|(d[9551043]|0)<<8|7967)^-7968;f=(e&65535)>>>8&255;g=e&255}else{f=-1;g=-1}c=(b&1|0)==0?g:f}}}while(0);return c|0}function a2Q(d,e){d=d|0;e=e|0;var f=0,g=0;switch(d&255|0){case 0:case 64:{c[2113304]=e&255;return};case 6:case 66:case 131:{d=a[9542400]|32;a[9542400]=d;if(d<<24>>24==-1){a[9706117]=0;return}a[14125144]=d;a[9706117]=1;if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){d=gfc(1e3)|0;f=d;g=(c[2433530]|0)+d|0}else{f=1e3;g=(c[2433530]|0)+1e3|0}c[2433530]=g;c[2444004]=(c[2444004]|0)+f;return};case 18:case 19:{c[2438064]=c[2438064]&4080|(e&255)<<12;return};case 130:{US(0,gD[c[2385643]&8191]()|0);b[4771272]=~~(+(b[9753784+((e&255)<<1)>>1]|0)*+h[1192819])&65535;c[2438064]=(c[2438064]|0)+1&262143;return};case 1:case 65:{f=c[2113304]|0;a[14168504+f|0]=e;mv(0,f,e&255);return};case 16:case 17:{c[2438064]=c[2438064]&1044480|(e&255)<<4;return};case 128:{c[2438064]=c[2438064]&2088960|(e&255)<<5;return};case 129:{c[2438064]=c[2438064]&8160|(e&255)<<13;return};default:{return}}}function a2R(b){b=b|0;var d=0;switch(b&255|0){case 0:case 1:case 64:case 65:{d=c[(c[3531464]|0)+4240>>2]&255;return d|0};case 128:case 66:case 2:{d=a[c[3528384]|0]|0;return d|0};case 132:{d=a[(c[2386708]|0)+(c[2438064]&262143)|0]|0;return d|0};default:{d=0;return d|0}}return 0}function a2S(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6490084+(b*112|0)>>2];c[a+104>>2]=c[6490088+(b*112|0)>>2];c[a+108>>2]=c[6490092+(b*112|0)>>2];d=0;return d|0}function a2T(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=6489984+(b*112|0);e=0;return e|0}function a2U(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>23){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4154960+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function a2V(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=28){if((a|0)==0){d=0;return d|0}e=a;f=4054344+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}f=b-29|0;if(f>>>0>24){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;a=6809888+(f*12|0)|0;c[b>>2]=c[a>>2];c[b+4>>2]=c[a+4>>2];c[b+8>>2]=c[a+8>>2];d=0;return d|0}function a2W(){return a4o(3164,8866,0,128,0,0)|0}function a2X(){var b=0,d=0,e=0,f=0;c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}b=c[3531464]|0;c[b+44344>>2]=0;c[b+44348>>2]=0;if((b|0)!=0){gGr(b);c[3531464]=0}b=c[2406684]|0;if((b|0)!=0){gGr(b);c[2406684]=0}UT();fwZ();fyA();b=c[2415118]|0;d=0;while(1){if((d|0)>=1024){break}e=9638528+(d<<2)|0;if((c[e>>2]|0)==(b|0)){f=48012;break}else{d=d+1|0}}if((f|0)==48012){gGr(b);c[e>>2]=0}c[2415118]=0;c[2438250]=0;a[1558240]=0;c[2437784]=0;c[2433502]=0;c[2438084]=0;c[2426970]=0;c[2438885]=0;c[2438884]=0;return 0}function a2Y(){var d=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;if((a[9625120]|0)!=0){a4u()}c[2409128]=0;c[2409245]=0;c[2409362]=0;c[2409479]=0;c[2409508]=0;c[2409537]=0;c[2409566]=0;c[2409595]=0;d=c[2385548]|0;if((d|0)>0){gGz(9752472,0,((d|0)>1?d<<2:4)|0)}c[2433530]=0;gGz(9551040,-1|0,5);d=0;f=-1;g=-1;i=-1;do{f=((a[9634472+d|0]&1)<<d^f&255)&255;g=((a[9632232+d|0]&1)<<d^g&255)&255;i=((a[9630144+d|0]&1)<<d^i&255)&255;d=d+1|0;}while((d|0)<8);a[9551040]=f;a[9551041]=g;a[9551042]=i;a[9551043]=-1;a[9551044]=-1;i=c[2438]|0;g=i;f=(i|0)<0|0?-1:0;i=gGU(g,f,145454,0)|0;d=gGS(i,K,256,0)|0;c[2440560]=d;d=gGU(g,f,65082,0)|0;f=gGS(d,K,256,0)|0;c[2440502]=f;c[2444004]=0;c[2444056]=0;c[1836234]=0;f=c[2439374]|0;c[3531864]=f;gf[c[f>>2]&2047](0);f=c[2439330]|0;if((f|0)!=0){d=f;gGC(9706056,d|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;d=0;f=0;while(1){g=c[2440560]|0;i=(g|0)/2272|0;c[2438220]=i;do{if((g|0)<2272){j=0;k=i;l=48027}else{m=gj[c[(c[3531864]|0)+12>>2]&4095](i)|0;n=c[2438220]|0;o=(c[2444056]|0)+m|0;c[2444056]=o;if((n|0)<1){c[2444056]=o;p=o;l=48031;break}else{o=gj[c[(c[3531864]|0)+12>>2]&4095](n)|0;j=o;k=c[2438220]|0;l=48027;break}}}while(0);L61443:do{if((l|0)==48027){l=0;i=(c[2444056]|0)+j|0;c[2444056]=i;do{if((k|0)<1){c[2444056]=i;q=i}else{g=gj[c[(c[3531864]|0)+12>>2]&4095](k)|0;o=c[2438220]|0;n=(c[2444056]|0)+g|0;c[2444056]=n;if((o|0)<1){p=n;l=48031;break L61443}n=gj[c[(c[3531864]|0)+12>>2]&4095](o)|0;o=c[2438220]|0;g=(c[2444056]|0)+n|0;c[2444056]=g;if((o|0)<1){q=g;break}g=gj[c[(c[3531864]|0)+12>>2]&4095](o)|0;o=c[2438220]|0;n=(c[2444056]|0)+g|0;c[2444056]=n;if((o|0)<1){r=0;s=n;break L61443}n=gj[c[(c[3531864]|0)+12>>2]&4095](o)|0;o=c[2438220]|0;g=(c[2444056]|0)+n|0;c[2444056]=g;if((o|0)<1){r=0;s=g;break L61443}g=gj[c[(c[3531864]|0)+12>>2]&4095](o)|0;r=g;s=c[2444056]|0;break L61443}}while(0);c[2444056]=q;r=0;s=q}}while(0);if((l|0)==48031){l=0;c[2444056]=p;r=0;s=p}c[2444056]=s+r;do{if(((c[2429622]|0)-128|0)==(d|0)&(d|0)<256){i=c[2439202]|0;if((i|0)<=(d|0)&(c[2113070]|0)>(d|0)){g=d+1|0;a4I(i,g);c[2439202]=g}g=((c[1631648]|0)+8|0)/4|0;gG[c[(c[3531864]|0)+16>>2]&255](0,g,1);i=c[(c[3531864]|0)+12>>2]|0;gj[i&4095](100)|0;gG[c[(c[3531864]|0)+16>>2]&255](0,g,0);g=c[(c[3531864]|0)+12>>2]|0;gj[g&4095](100)|0}else{if((d|0)!=256){break}g=c[2439202]|0;i=c[2113070]|0;if((g|0)<(i|0)){a4I(g,i);c[2439202]=0}i=(c[1631648]|0)/4|0;gG[c[(c[3531864]|0)+16>>2]&255](0,i,1);g=c[(c[3531864]|0)+12>>2]|0;gj[g&4095](100)|0;gG[c[(c[3531864]|0)+16>>2]&255](0,i,0);i=c[(c[3531864]|0)+12>>2]|0;gj[i&4095](100)|0}}while(0);if((c[2439202]|0)>=(c[2113070]|0)){c[2439202]=0}i=c[2440560]|0;g=(i|0)/2272|0;c[2438220]=g;if((i|0)<2272){t=0}else{t=gj[c[(c[3531864]|0)+12>>2]&4095](g)|0}c[2444056]=(c[2444056]|0)+t;g=c[2440502]|0;i=(g|0)/284|0;do{if(a[627120]|0){c[2433530]=(c[2433530]|0)+i}else{do{if((g|0)<284){u=0}else{if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){o=gfc(i)|0;c[2433530]=(c[2433530]|0)+o;u=o;break}else{c[2433530]=(c[2433530]|0)+i;u=i;break}}}while(0);c[2444004]=(c[2444004]|0)+u;if((d&1|0)==0){break}o=c[2437784]|0;if((o|0)==2){n=a[(c[2386708]|0)+(c[2438064]|0)|0]|0;if(n<<24>>24==0){break}US(0,gD[c[2385643]&8191]()|0);b[4771272]=~~(+(b[9753784+((n&255)<<1)>>1]|0)*+h[1192819])&65535;c[2438064]=(c[2438064]|0)+1&262143;break}else if((o|0)!=1){break}if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12}}while(0);i=c[2112964]|0;if((i|0)==0){v=f}else{g=a[9688]&1;gg[c[3542124]&4095](i+(f<<1<<1)|0,g);v=g+f|0}g=d+1|0;if((g|0)<284){d=g;f=v}else{break}}f=c[2112964]|0;if((f|0)!=0){d=a[9688]|0?534:0;if((d|0)==(v|0)){w=f;x=v}else{gg[c[3542124]&4095](f+(v<<1<<1)|0,d-v|0);w=c[2112964]|0;x=a[9688]|0?534:0}UR(w,x)}c[1836234]=-1;gu[c[(c[3531864]|0)+4>>2]&16383]();c[3531864]=0;x=c[1836236]|0;w=c[9757320+(x<<2)>>2]|0;if((w|0)!=0){v=w;gGC(v|0,9706056,76)|0}c[9752472+(x<<2)>>2]=c[2433530];c[14113936+(x<<2)>>2]=c[2076596];c[9669104+(x<<2)>>2]=c[3541536];c[1836236]=-1;if((c[2112968]|0)==0){return 0}if((a[9548080]|0)==0){y=c[3530212]|0}else{x=c[2387296]|0;v=c[3530212]|0;w=x+4096|0;d=0;do{f=d&255;u=d>>>0<256;t=u?x:w;r=e[t+((f|512)<<1)>>1]|0;c[v+((u?f:f|256)<<2)>>2]=b[t+((f|1024)<<1)>>1]&31|e[t+(f<<1)>>1]<<11&63488|(r>>>2&4|r<<3)<<3&2016;d=d+1|0;}while((d|0)<512);a[9548080]=0;y=v}R8(y);y=c[2112926]|0;gGz(y|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);return 0}function a2Z(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((a[9548080]|0)==0){d=c[3530212]|0}else{f=c[2387296]|0;g=c[3530212]|0;h=f+4096|0;i=0;do{j=i&255;k=i>>>0<256;l=k?f:h;m=e[l+((j|512)<<1)>>1]|0;c[g+((k?j:j|256)<<2)>>2]=b[l+((j|1024)<<1)>>1]&31|e[l+(j<<1)>>1]<<11&63488|(m>>>2&4|m<<3)<<3&2016;i=i+1|0;}while((i|0)<512);a[9548080]=0;d=g}R8(d);d=c[2112926]|0;gGz(d|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);return 0}function a2_(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5707620+(b*112|0)>>2];c[a+104>>2]=c[5707624+(b*112|0)>>2];c[a+108>>2]=c[5707628+(b*112|0)>>2];d=0;return d|0}function a2$(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=5707520+(b*112|0);e=0;return e|0}function a20(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4439452+(b*112|0)>>2];c[a+104>>2]=c[4439456+(b*112|0)>>2];c[a+108>>2]=c[4439460+(b*112|0)>>2];d=0;return d|0}function a21(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=4439352+(b*112|0);e=0;return e|0}function a22(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=24){if((a|0)==0){d=0;return d|0}e=a;f=6809888+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}f=b-25|0;if(f>>>0>3){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;a=6146608+(f*12|0)|0;c[b>>2]=c[a>>2];c[b+4>>2]=c[a+4>>2];c[b+8>>2]=c[a+8>>2];d=0;return d|0}function a23(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>24){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5704820+(b*112|0)>>2];c[a+104>>2]=c[5704824+(b*112|0)>>2];c[a+108>>2]=c[5704828+(b*112|0)>>2];d=0;return d|0}function a24(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<25&(d|0)==0)){e=1;return e|0}c[a>>2]=5704720+(b*112|0);e=0;return e|0}function a25(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5709860+(b*112|0)>>2];c[a+104>>2]=c[5709864+(b*112|0)>>2];c[a+108>>2]=c[5709868+(b*112|0)>>2];d=0;return d|0}function a26(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=5709760+(b*112|0);e=0;return e|0}function a27(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>23){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2068452+(b*112|0)>>2];c[a+104>>2]=c[2068456+(b*112|0)>>2];c[a+108>>2]=c[2068460+(b*112|0)>>2];d=0;return d|0}function a28(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<24&(d|0)==0)){e=1;return e|0}c[a>>2]=2068352+(b*112|0);e=0;return e|0}function a29(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=28){if((a|0)==0){d=0;return d|0}e=a;f=4054344+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}f=b-29|0;if(f>>>0>25){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;a=3216400+(f*12|0)|0;c[b>>2]=c[a>>2];c[b+4>>2]=c[a+4>>2];c[b+8>>2]=c[a+8>>2];d=0;return d|0}function a3a(){return a4o(1530,2856,0,32,1,0)|0}function a3b(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[818516+(b*112|0)>>2];c[a+104>>2]=c[818520+(b*112|0)>>2];c[a+108>>2]=c[818524+(b*112|0)>>2];d=0;return d|0}function a3c(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<22&(d|0)==0)){e=1;return e|0}c[a>>2]=818416+(b*112|0);e=0;return e|0}function a3d(){c[2433502]=1327528;c[2438084]=2068328;c[2426970]=681688;return a4o(4456,8866,0,32,1,0)|0}function a3e(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5921316+(b*112|0)>>2];c[a+104>>2]=c[5921320+(b*112|0)>>2];c[a+108>>2]=c[5921324+(b*112|0)>>2];d=0;return d|0}function a3f(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=5921216+(b*112|0);e=0;return e|0}function a3g(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=28){if((a|0)==0){d=0;return d|0}e=a;f=4054344+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}f=b-29|0;if(f>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;a=6378456+(f*12|0)|0;c[b>>2]=c[a>>2];c[b+4>>2]=c[a+4>>2];c[b+8>>2]=c[a+8>>2];d=0;return d|0}function a3h(){return a4o(7794,2856,1602,32,1,2)|0}function a3i(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1579340+(b*112|0)>>2];c[a+104>>2]=c[1579344+(b*112|0)>>2];c[a+108>>2]=c[1579348+(b*112|0)>>2];d=0;return d|0}function a3j(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=1579240+(b*112|0);e=0;return e|0}function a3k(){c[2433502]=4752352;c[2438084]=5921192;c[2426970]=683848;return a4o(4412,8866,2004,32,1,0)|0}function a3l(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>23){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3102076+(b*112|0)>>2];c[a+104>>2]=c[3102080+(b*112|0)>>2];c[a+108>>2]=c[3102084+(b*112|0)>>2];d=0;return d|0}function a3m(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<24&(d|0)==0)){e=1;return e|0}c[a>>2]=3101976+(b*112|0);e=0;return e|0}function a3n(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=28){if((a|0)==0){d=0;return d|0}e=a;f=4054344+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}f=b-29|0;if(f>>>0>24){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;a=4242888+(f*12|0)|0;c[b>>2]=c[a>>2];c[b+4>>2]=c[a+4>>2];c[b+8>>2]=c[a+8>>2];d=0;return d|0}function a3o(){c[2433502]=5945360;c[2438084]=6599816;c[2426970]=685272;return a4o(8210,8866,2004,128,2,0)|0}function a3p(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5776044+(b*112|0)>>2];c[a+104>>2]=c[5776048+(b*112|0)>>2];c[a+108>>2]=c[5776052+(b*112|0)>>2];d=0;return d|0}function a3q(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=5775944+(b*112|0);e=0;return e|0}function a3r(){c[2433502]=5945360;c[2438084]=7344960;c[2426970]=685272;return a4o(8210,8866,2004,128,2,0)|0}function a3s(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4507332+(b*112|0)>>2];c[a+104>>2]=c[4507336+(b*112|0)>>2];c[a+108>>2]=c[4507340+(b*112|0)>>2];d=0;return d|0}function a3t(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<22&(d|0)==0)){e=1;return e|0}c[a>>2]=4507232+(b*112|0);e=0;return e|0}function a3u(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=28){if((a|0)==0){d=0;return d|0}e=a;f=4054344+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}f=b-29|0;if(f>>>0>23){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;a=5199600+(f*12|0)|0;c[b>>2]=c[a>>2];c[b+4>>2]=c[a+4>>2];c[b+8>>2]=c[a+8>>2];d=0;return d|0}function a3v(){c[2433502]=6512624;c[2438084]=7020664;c[2426970]=688520;return a4o(8210,8866,0,128,2,0)|0}function a3w(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2499028+(b*112|0)>>2];c[a+104>>2]=c[2499032+(b*112|0)>>2];c[a+108>>2]=c[2499036+(b*112|0)>>2];d=0;return d|0}function a3x(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<22&(d|0)==0)){e=1;return e|0}c[a>>2]=2498928+(b*112|0);e=0;return e|0}function a3y(){c[2433502]=6512624;c[2438084]=6512600;c[2426970]=688520;return a4o(8210,8866,0,128,2,0)|0}function a3z(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2746804+(b*112|0)>>2];c[a+104>>2]=c[2746808+(b*112|0)>>2];c[a+108>>2]=c[2746812+(b*112|0)>>2];d=0;return d|0}function a3A(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=2746704+(b*112|0);e=0;return e|0}function a3B(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=28){if((a|0)==0){d=0;return d|0}e=a;f=4054344+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}f=b-29|0;if(f>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;a=3846320+(f*12|0)|0;c[b>>2]=c[a>>2];c[b+4>>2]=c[a+4>>2];c[b+8>>2]=c[a+8>>2];d=0;return d|0}function a3C(){c[2433502]=5862504;c[2438084]=6565992;c[2426970]=685120;return a4o(8210,8866,3178,128,2,0)|0}function a3D(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1528588+(b*112|0)>>2];c[a+104>>2]=c[1528592+(b*112|0)>>2];c[a+108>>2]=c[1528596+(b*112|0)>>2];d=0;return d|0}function a3E(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=1528488+(b*112|0);e=0;return e|0}function a3F(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4850052+(b*112|0)>>2];c[a+104>>2]=c[4850056+(b*112|0)>>2];c[a+108>>2]=c[4850060+(b*112|0)>>2];d=0;return d|0}function a3G(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=4849952+(b*112|0);e=0;return e|0}function a3H(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=28){if((a|0)==0){d=0;return d|0}e=a;f=4053992+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}f=b-29|0;if(f>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;a=5619104+(f*12|0)|0;c[b>>2]=c[a>>2];c[b+4>>2]=c[a+4>>2];c[b+8>>2]=c[a+8>>2];d=0;return d|0}function a3I(){c[2433502]=6609872;c[2438084]=7082456;c[2426970]=690384;return a4o(8210,8866,0,128,2,0)|0}function a3J(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5712100+(b*112|0)>>2];c[a+104>>2]=c[5712104+(b*112|0)>>2];c[a+108>>2]=c[5712108+(b*112|0)>>2];d=0;return d|0}function a3K(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=5712e3+(b*112|0);e=0;return e|0}function a3L(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=28){if((a|0)==0){d=0;return d|0}e=a;f=4054344+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}f=b-29|0;if(f>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;a=6146656+(f*12|0)|0;c[b>>2]=c[a>>2];c[b+4>>2]=c[a+4>>2];c[b+8>>2]=c[a+8>>2];d=0;return d|0}function a3M(){return a4o(10382,2856,0,128,1,1)|0}function a3N(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4441692+(b*112|0)>>2];c[a+104>>2]=c[4441696+(b*112|0)>>2];c[a+108>>2]=c[4441700+(b*112|0)>>2];d=0;return d|0}function a3O(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=4441592+(b*112|0);e=0;return e|0}function a3P(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2366508+(b*112|0)>>2];c[a+104>>2]=c[2366512+(b*112|0)>>2];c[a+108>>2]=c[2366516+(b*112|0)>>2];d=0;return d|0}function a3Q(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=2366408+(b*112|0);e=0;return e|0}function a3R(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5867180+(b*112|0)>>2];c[a+104>>2]=c[5867184+(b*112|0)>>2];c[a+108>>2]=c[5867188+(b*112|0)>>2];d=0;return d|0}function a3S(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=5867080+(b*112|0);e=0;return e|0}function a3T(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=28){if((a|0)==0){d=0;return d|0}e=a;f=4053992+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}f=b-29|0;if(f>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;a=6275720+(f*12|0)|0;c[b>>2]=c[a>>2];c[b+4>>2]=c[a+4>>2];c[b+8>>2]=c[a+8>>2];d=0;return d|0}function a3U(){return a4o(8210,2856,2004,32,1,2)|0}function a3V(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4668444+(b*112|0)>>2];c[a+104>>2]=c[4668448+(b*112|0)>>2];c[a+108>>2]=c[4668452+(b*112|0)>>2];d=0;return d|0}function a3W(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=4668344+(b*112|0);e=0;return e|0}function a3X(){return a4o(2234,2856,2004,32,1,1)|0}function a3Y(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2940468+(b*112|0)>>2];c[a+104>>2]=c[2940472+(b*112|0)>>2];c[a+108>>2]=c[2940476+(b*112|0)>>2];d=0;return d|0}function a3Z(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=2940368+(b*112|0);e=0;return e|0}function a3_(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[943452+(b*112|0)>>2];c[a+104>>2]=c[943456+(b*112|0)>>2];c[a+108>>2]=c[943460+(b*112|0)>>2];d=0;return d|0}function a3$(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=943352+(b*112|0);e=0;return e|0}function a30(){c[2433502]=5914904;c[2438084]=6589264;c[2426970]=685152;return a4o(8210,8866,2004,32,2,0)|0}function a31(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3005764+(b*112|0)>>2];c[a+104>>2]=c[3005768+(b*112|0)>>2];c[a+108>>2]=c[3005772+(b*112|0)>>2];d=0;return d|0}function a32(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=3005664+(b*112|0);e=0;return e|0}function a33(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=28){if((a|0)==0){d=0;return d|0}e=a;f=4053992+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}f=b-29|0;if(f>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;a=6301536+(f*12|0)|0;c[b>>2]=c[a>>2];c[b+4>>2]=c[a+4>>2];c[b+8>>2]=c[a+8>>2];d=0;return d|0}function a34(){return a4o(2234,2856,0,96,1,1)|0}function a35(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5893012+(b*112|0)>>2];c[a+104>>2]=c[5893016+(b*112|0)>>2];c[a+108>>2]=c[5893020+(b*112|0)>>2];d=0;return d|0}function a36(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=5892912+(b*112|0);e=0;return e|0}function a37(){c[2426970]=698552;return a4o(8210,8866,0,128,2,0)|0}function a38(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7032068+(b*112|0)>>2];c[a+104>>2]=c[7032072+(b*112|0)>>2];c[a+108>>2]=c[7032076+(b*112|0)>>2];d=0;return d|0}function a39(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=7031968+(b*112|0);e=0;return e|0}function a4a(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=28){if((a|0)==0){d=0;return d|0}e=a;f=4054344+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}f=b-29|0;if(f>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;a=7190968+(f*12|0)|0;c[b>>2]=c[a>>2];c[b+4>>2]=c[a+4>>2];c[b+8>>2]=c[a+8>>2];d=0;return d|0}function a4b(){c[2433502]=632400;c[2438084]=638672;c[2426970]=794800;return a4o(8210,8866,0,128,2,0)|0}function a4c(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6526708+(b*112|0)>>2];c[a+104>>2]=c[6526712+(b*112|0)>>2];c[a+108>>2]=c[6526716+(b*112|0)>>2];d=0;return d|0}function a4d(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=6526608+(b*112|0);e=0;return e|0}function a4e(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6528724+(b*112|0)>>2];c[a+104>>2]=c[6528728+(b*112|0)>>2];c[a+108>>2]=c[6528732+(b*112|0)>>2];d=0;return d|0}function a4f(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<21&(d|0)==0)){e=1;return e|0}c[a>>2]=6528624+(b*112|0);e=0;return e|0}function a4g(){c[2433502]=632400;c[2438084]=638672;c[2426970]=794800;return a4o(8210,8866,3994,128,2,0)|0}function a4h(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>25){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5792700+(b*112|0)>>2];c[a+104>>2]=c[5792704+(b*112|0)>>2];c[a+108>>2]=c[5792708+(b*112|0)>>2];d=0;return d|0}function a4i(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<26&(d|0)==0)){e=1;return e|0}c[a>>2]=5792600+(b*112|0);e=0;return e|0}function a4j(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2618732+(b*112|0)>>2];c[a+104>>2]=c[2618736+(b*112|0)>>2];c[a+108>>2]=c[2618740+(b*112|0)>>2];d=0;return d|0}function a4k(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=2618632+(b*112|0);e=0;return e|0}function a4l(){return a4o(12002,2856,0,128,1,3)|0}function a4m(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1502548+(b*112|0)>>2];c[a+104>>2]=c[1502552+(b*112|0)>>2];c[a+108>>2]=c[1502556+(b*112|0)>>2];d=0;return d|0}function a4n(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=1502448+(b*112|0);e=0;return e|0}function a4o(d,e,f,g,i,j){d=d|0;e=e|0;f=f|0;g=g|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;c[2424]=5500;k=c[642608+(c[2436]<<2)>>2]|0;l=c[k+128>>2]|0;if((c[k+52>>2]&4|0)==0){c[2113068]=l;m=c[k+132>>2]|0;c[2113070]=m;c[2443814]=l;c[2440436]=m;n=l;o=m}else{c[2113070]=l;m=c[k+132>>2]|0;c[2113068]=m;c[2440436]=l;c[2443814]=m;n=m;o=l}l=ag(n<<1,o)|0;o=gGq(l)|0;c[2112926]=o;if((o|0)!=0){gGz(o|0,0,l|0)}a4r(0)|0;c[2415118]=0;c[2386306]=0;c[2386022]=2097152;c[3530964]=2162688;l=(c[2433676]<<1)+2162688|0;c[3530730]=l;o=l+(c[2433674]<<1)|0;c[3530494]=o;l=o+(c[2433672]<<1)|0;c[3530362]=l;o=l+(c[2433670]<<1)|0;c[2386708]=o;l=o+262144|0;c[2439414]=l;o=l+(ag(c[2113070]|0,c[2113068]|0)|0)|0;l=o|0;c[2414826]=l;c[2386172]=l;c[2386542]=o+65536;c[3529618]=o+69632;c[2386590]=o+71680;c[3529482]=o+75776;c[3529448]=o+92160;c[2386312]=o+157696;c[2387296]=o+174080;c[3529856]=o+182272;c[2443488]=o+186368;c[3528384]=o+188416;c[2440176]=o+188417;c[2409012]=o+188418;l=o+188426|0;c[2411894]=l;c[3530212]=l;l=o+190474|0;c[2414446]=l;o=l;l=0;while(1){if((l|0)>=1024){break}p=9638528+(l<<2)|0;if((c[p>>2]|0)==0){q=48605;break}else{l=l+1|0}}do{if((q|0)==48605){l=gGq(o)|0;c[p>>2]=l;if((l|0)==0){break}gGz(l|0,0,o|0);c[2415118]=l;gGz(l|0,0,o|0);c[2386306]=l;c[2386022]=l+2097152;c[3530964]=l+2162688;n=(c[2433676]<<1)+2162688|0;c[3530730]=l+n;m=n+(c[2433674]<<1)|0;c[3530494]=l+m;n=m+(c[2433672]<<1)|0;c[3530362]=l+n;m=n+(c[2433670]<<1)|0;c[2386708]=l+m;n=m+262144|0;c[2439414]=l+n;m=n+(ag(c[2113070]|0,c[2113068]|0)|0)|0;n=l+m|0;c[2414826]=n;c[2386172]=n;c[2386542]=l+(m+65536);c[3529618]=l+(m+69632);c[2386590]=l+(m+71680);c[3529482]=l+(m+75776);c[3529448]=l+(m+92160);c[2386312]=l+(m+157696);c[2387296]=l+(m+174080);c[3529856]=l+(m+182272);c[2443488]=l+(m+186368);c[3528384]=l+(m+188416);c[2440176]=l+(m+188417);c[2409012]=l+(m+188418);n=l+(m+188426)|0;c[2411894]=n;c[3530212]=n;c[2414446]=l+(m+190474);if((a4r(1)|0)!=0){r=1;return r|0}if((d|0)!=0){gu[d&16383]()}if((e|0)!=0){gu[e&16383]()}do{if((f|0)!=0){if((gD[f&8191]()|0)==0){break}else{r=1}return r|0}}while(0);c[1631648]=g;c[2437784]=i;c[2438250]=j;switch(j|0){case 0:{c[2438885]=0;c[2438884]=0;break};case 1:case 3:{c[2438885]=-4;c[2438884]=-4;break};case 2:{c[2438884]=-4;c[2438885]=-6;break};case 4:{c[2438885]=-6;c[2438884]=-6;c[2438250]=1;break};default:{}}m=a[9680]|0;l=m?32e3:0;if(m){if(a[9624]|0){m=l*3|0;n=55930;while(1){if((n|0)>(m|0)){n=n>>1}else{s=1222;t=n;break}}}else{s=2462;t=l}c[2429380]=t;c[3542124]=s;mw(3579545,t);n=gGq(262144)|0;c[2406684]=n;gGz(n|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(3579545,11025)}c[(c[3531464]|0)+44344>>2]=278;h[745421]=1.0;c[2436794]=1;h[745420]=1.0;c[2436792]=2;c[2405758]=1;gGz(9542544,0,32);c[2385641]=1;h[1192819]=1.0;c[2385642]=3;c[2385643]=2486;n=0;do{m=n*257|0;b[9732544+(n<<1)>>1]=((m|0)/2|0)&65535;b[9753784+(n<<1)>>1]=m+32768&65535;n=n+1|0;}while((n|0)<256);c[3528842]=1;h[1192819]=.4;c[2385642]=3;a4u();r=0;return r|0}}while(0);c[2415118]=0;r=1;return r|0}function a4p(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0;fyz(0,8,0);c[1836234]=0;a=c[2439374]|0;c[3531864]=a;gf[c[a>>2]&2047](0);a=c[2386306]|0;b=c[3531864]|0;d=0;while(1){c[b+44+(d<<2)>>2]=a;e=d+1|0;if((e|0)<256){d=e}else{f=0;break}}do{c[b+4140+(f<<2)>>2]=a;c[b+6188+(f<<2)>>2]=a;f=f+1|0;}while((f|0)<256);f=(c[2443488]|0)-655360|0;c[b+1324>>2]=f;c[b+3372>>2]=f;c[b+5420>>2]=f;c[b+7468>>2]=f;f=c[2387296]|0;d=f-667648|0;c[b+1356>>2]=d;c[b+1360>>2]=d;c[b+5452>>2]=d;c[b+7500>>2]=d;c[b+5456>>2]=d;c[b+7504>>2]=d;d=(c[3529482]|0)-704512|0;c[b+1420>>2]=d;c[b+1424>>2]=d;c[b+1428>>2]=d;c[b+1432>>2]=d;c[b+1436>>2]=d;c[b+1440>>2]=d;c[b+1444>>2]=d;c[b+1448>>2]=d;c[b+3468>>2]=d;c[b+3472>>2]=d;c[b+3476>>2]=d;c[b+3480>>2]=d;c[b+3484>>2]=d;c[b+3488>>2]=d;c[b+3492>>2]=d;c[b+3496>>2]=d;c[b+5516>>2]=d;c[b+7564>>2]=d;c[b+5520>>2]=d;c[b+7568>>2]=d;c[b+5524>>2]=d;c[b+7572>>2]=d;c[b+5528>>2]=d;c[b+7576>>2]=d;c[b+5532>>2]=d;c[b+7580>>2]=d;c[b+5536>>2]=d;c[b+7584>>2]=d;c[b+5540>>2]=d;c[b+7588>>2]=d;c[b+5544>>2]=d;c[b+7592>>2]=d;d=(c[3529448]|0)-720896|0;e=352;while(1){c[b+44+(e<<2)>>2]=d;g=e+1|0;if((g|0)<384){e=g}else{h=352;break}}while(1){c[b+2092+(h<<2)>>2]=d;e=h+1|0;if((e|0)<384){h=e}else{i=352;break}}do{c[b+4140+(i<<2)>>2]=d;c[b+6188+(i<<2)>>2]=d;i=i+1|0;}while((i|0)<384);i=(c[2386542]|0)-786432|0;c[b+1580>>2]=i;c[b+3628>>2]=i;c[b+5676>>2]=i;c[b+7724>>2]=i;i=(c[3529618]|0)-819200|0;c[b+1644>>2]=i;c[b+3692>>2]=i;c[b+5740>>2]=i;c[b+7788>>2]=i;i=f-835584|0;c[b+1676>>2]=i;c[b+1680>>2]=i;c[b+5772>>2]=i;c[b+7820>>2]=i;c[b+5776>>2]=i;c[b+7824>>2]=i;i=(c[2386312]|0)-851968|0;c[b+1708>>2]=i;c[b+1712>>2]=i;c[b+1716>>2]=i;c[b+1720>>2]=i;c[b+1724>>2]=i;c[b+1728>>2]=i;c[b+1732>>2]=i;c[b+1736>>2]=i;c[b+3756>>2]=i;c[b+3760>>2]=i;c[b+3764>>2]=i;c[b+3768>>2]=i;c[b+3772>>2]=i;c[b+3776>>2]=i;c[b+3780>>2]=i;c[b+3784>>2]=i;c[b+5804>>2]=i;c[b+7852>>2]=i;c[b+5808>>2]=i;c[b+7856>>2]=i;c[b+5812>>2]=i;c[b+7860>>2]=i;c[b+5816>>2]=i;c[b+7864>>2]=i;c[b+5820>>2]=i;c[b+7868>>2]=i;c[b+5824>>2]=i;c[b+7872>>2]=i;c[b+5828>>2]=i;c[b+7876>>2]=i;c[b+5832>>2]=i;c[b+7880>>2]=i;c[b+2088>>2]=a;c[b+6184>>2]=a;c[b+8232>>2]=a;c[b+8236>>2]=1078;c[b+8240>>2]=3220;c[b+8244>>2]=2802;c[b+8248>>2]=4;c[1836234]=-1;gu[c[b+4>>2]&16383]();c[3531864]=0;return}function a4q(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;fwR(0);d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];f=c[3528484]|0;c[2076596]=f;g=c[2417276]|0;c[3541536]=g;c[1836236]=0;h=c[2386022]|0;i=0;j=0;while(1){c[d+76+(j<<2)>>2]=h+(j<<8);k=i+1&65535;if((k&65535)>239){l=0;m=0;break}else{i=k;j=k&65535}}while(1){j=h+(m<<8)|0;c[d+76+(m+512<<2)>>2]=j;c[d+76+(m+768<<2)>>2]=j;j=l+1&65535;if((j&65535)>239){break}else{l=j;m=j&65535}}m=c[2386172]|0;c[d+1036>>2]=m;c[d+1040>>2]=m+256;c[d+1044>>2]=m+512;c[d+1048>>2]=m+768;c[d+1052>>2]=m+1024;c[d+1056>>2]=m+1280;c[d+1060>>2]=m+1536;c[d+1064>>2]=m+1792;c[d+1068>>2]=m+2048;c[d+1072>>2]=m+2304;c[d+1076>>2]=m+2560;c[d+1080>>2]=m+2816;c[d+1084>>2]=m+3072;c[d+1088>>2]=m+3328;c[d+1092>>2]=m+3584;c[d+1096>>2]=m+3840;l=240;h=240;while(1){c[d+76+(h+256<<2)>>2]=m+((h<<8)-61440);j=l+1&65535;if((j&65535)>255){n=240;o=240;break}else{l=j;h=j&65535}}while(1){h=m+((o<<8)-61440)|0;c[d+76+(o+512<<2)>>2]=h;c[d+76+(o+768<<2)>>2]=h;h=n+1&65535;if((h&65535)>255){break}else{n=h;o=h&65535}}c[d+4176>>2]=1798;c[d+4172>>2]=1668;if(e){p=c[2433530]|0;c[2438118]=p;c[3528484]=f;c[2417276]=g;c[1836236]=-1;a[1558240]=0;return}e=d;gGC(e|0,9706056,76)|0;p=c[2433530]|0;c[2438118]=p;c[3528484]=f;c[2417276]=g;c[1836236]=-1;a[1558240]=0;return}function a4r(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0;e=i;i=i+1104|0;f=e|0;g=e+112|0;h=e+120|0;j=e+232|0;k=e+240|0;l=e+352|0;m=e+360|0;n=e+472|0;o=e+480|0;p=e+592|0;q=e+600|0;r=e+712|0;s=e+720|0;t=e+832|0;u=e+840|0;v=e+856|0;w=e+920|0;x=e+984|0;y=e+992|0;z=c[2386306]|0;A=c[2386022]|0;B=c[3530964]|0;C=c[3530730]|0;D=c[3530494]|0;E=c[3530362]|0;F=c[2386708]|0;L62177:do{if((gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](x,0,0)|0)==0){G=y+108|0;H=(b|0)==0;I=y+100|0;J=(b|0)!=0;K=s+108|0;L=s+100|0;M=q+108|0;N=q+100|0;O=o+108|0;P=o+100|0;Q=m+108|0;R=m+100|0;S=k+108|0;T=k+100|0;U=h+108|0;V=h+100|0;W=f+108|0;X=f+100|0;Y=z;Z=A;_=B;$=C;aa=D;ab=E;ac=F;ad=0;ae=0;L62179:while(1){gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](y,ae)|0;L62181:do{switch(c[G>>2]&15|0){case 6:{do{if(!H){if((c[3542200]|0)==0){af=1;ag=48796;break L62179}c[K>>2]=0;c[L>>2]=0;ah=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ah&16383](s,ae)|0;if((c[K>>2]|0)==0){break}ah=c[L>>2]|0;c[t>>2]=9534384;ai=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ai&16383](t,ae,0)|0;if((ah|0)<1){af=1;ag=48797;break L62179}if((gzL(Z,0,ae)|0)!=0){af=1;ag=48794;break L62179}}}while(0);aj=ae;ak=ad;al=ac;am=ab;an=aa;ao=$;ap=_;aq=Z+(c[I>>2]|0)|0;ar=Y;break};case 2:{do{if(J){if((c[3542200]|0)==0){af=1;ag=48815;break L62179}c[M>>2]=0;c[N>>2]=0;ah=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ah&16383](q,ae)|0;if((c[M>>2]|0)==0){break}ah=c[N>>2]|0;c[r>>2]=9534384;ai=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ai&16383](r,ae,0)|0;if((ah|0)<1){af=1;ag=48798;break L62179}if((gzL(_,0,ae)|0)!=0){af=1;ag=48817;break L62179}}}while(0);ah=c[I>>2]|0;ai=_+ah|0;if(!((ad|0)==65536&(ah|0)==32768)){aj=ae;ak=ah;al=ac;am=ab;an=aa;ao=$;ap=ai;aq=Z;ar=Y;break L62181}if(J){if((c[3542200]|0)==0){af=1;ag=48799;break L62179}c[O>>2]=0;c[P>>2]=0;ah=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ah&16383](o,ae)|0;if((c[O>>2]|0)!=0){ah=c[P>>2]|0;c[p>>2]=9534384;as=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[as&16383](p,ae,0)|0;if((ah|0)<1){af=1;ag=48791;break L62179}if((gzL(ai,0,ae)|0)!=0){af=1;ag=48792;break L62179}}at=c[I>>2]|0}else{at=32768}aj=ae;ak=at;al=ac;am=ab;an=aa;ao=$;ap=_+(at+32768)|0;aq=Z;ar=Y;break};case 5:{do{if(!H){if((c[3542200]|0)==0){af=1;ag=48802;break L62179}c[W>>2]=0;c[X>>2]=0;ai=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ai&16383](f,ae)|0;if((c[W>>2]|0)==0){break}ai=c[X>>2]|0;c[g>>2]=9534384;ah=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ah&16383](g,ae,0)|0;if((ai|0)<1){af=1;ag=48800;break L62179}if((gzL(ac,0,ae)|0)!=0){af=1;ag=48801;break L62179}}}while(0);aj=ae;ak=ad;al=ac+(c[I>>2]|0)|0;am=ab;an=aa;ao=$;ap=_;aq=Z;ar=Y;break};case 14:{do{if(!H){if((c[3542200]|0)==0){af=1;ag=48804;break L62179}c[U>>2]=0;c[V>>2]=0;ai=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ai&16383](h,ae)|0;if((c[U>>2]|0)==0){break}ai=c[V>>2]|0;c[j>>2]=9534384;ah=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ah&16383](j,ae,0)|0;if((ai|0)<1){af=1;ag=48805;break L62179}if((gzL(ab,0,ae)|0)!=0){af=1;ag=48806;break L62179}}}while(0);aj=ae;ak=ad;al=ac;am=ab+(c[I>>2]|0)|0;an=aa;ao=$;ap=_;aq=Z;ar=Y;break};case 3:{do{if(!H){if((c[3542200]|0)==0){af=1;ag=48812;break L62179}c[Q>>2]=0;c[R>>2]=0;ai=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ai&16383](m,ae)|0;if((c[Q>>2]|0)==0){break}ai=c[R>>2]|0;c[n>>2]=9534384;ah=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ah&16383](n,ae,0)|0;if((ai|0)<1){af=1;ag=48813;break L62179}if((gzL($,0,ae)|0)!=0){af=1;ag=48814;break L62179}}}while(0);aj=ae;ak=ad;al=ac;am=ab;an=aa;ao=$+(c[I>>2]|0)|0;ap=_;aq=Z;ar=Y;break};case 4:{do{if(!H){if((c[3542200]|0)==0){af=1;ag=48816;break L62179}c[S>>2]=0;c[T>>2]=0;ai=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ai&16383](k,ae)|0;if((c[S>>2]|0)==0){break}ai=c[T>>2]|0;c[l>>2]=9534384;ah=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ah&16383](l,ae,0)|0;if((ai|0)<1){af=1;ag=48793;break L62179}if((gzL(aa,0,ae)|0)!=0){af=1;ag=48803;break L62179}}}while(0);aj=ae;ak=ad;al=ac;am=ab;an=aa+(c[I>>2]|0)|0;ao=$;ap=_;aq=Z;ar=Y;break};case 1:{if(H){au=ae+1|0}else{if((R6(Y+1|0,ae,2)|0)!=0){af=1;ag=48819;break L62179}ai=ae+1|0;if((R6(Y,ai,2)|0)==0){au=ai}else{af=1;ag=48795;break L62179}}aj=au;ak=ad;al=ac;am=ab;an=aa;ao=$;ap=_;aq=Z;ar=Y+(c[I>>2]<<1)|0;break};default:{aj=ae;ak=ad;al=ac;am=ab;an=aa;ao=$;ap=_;aq=Z;ar=Y}}}while(0);ai=aj+1|0;if((gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](x,ai,0)|0)==0){Y=ar;Z=aq;_=ap;$=ao;aa=an;ab=am;ac=al;ad=ak;ae=ai}else{av=ar;aw=ap;ax=ao;ay=an;az=am;aA=al;break L62177}}if((ag|0)==48791){i=e;return af|0}else if((ag|0)==48792){i=e;return af|0}else if((ag|0)==48793){i=e;return af|0}else if((ag|0)==48794){i=e;return af|0}else if((ag|0)==48795){i=e;return af|0}else if((ag|0)==48796){i=e;return af|0}else if((ag|0)==48797){i=e;return af|0}else if((ag|0)==48798){i=e;return af|0}else if((ag|0)==48799){i=e;return af|0}else if((ag|0)==48800){i=e;return af|0}else if((ag|0)==48801){i=e;return af|0}else if((ag|0)==48802){i=e;return af|0}else if((ag|0)==48803){i=e;return af|0}else if((ag|0)==48804){i=e;return af|0}else if((ag|0)==48805){i=e;return af|0}else if((ag|0)==48806){i=e;return af|0}else if((ag|0)==48812){i=e;return af|0}else if((ag|0)==48813){i=e;return af|0}else if((ag|0)==48814){i=e;return af|0}else if((ag|0)==48815){i=e;return af|0}else if((ag|0)==48816){i=e;return af|0}else if((ag|0)==48817){i=e;return af|0}else if((ag|0)==48819){i=e;return af|0}}else{av=z;aw=B;ax=C;ay=D;az=E;aA=F}}while(0);if((b|0)==0){b=aw-(c[3530964]|0)|0;c[2433676]=b;aw=ax-(c[3530730]|0)|0;c[2433674]=aw;ax=ay-(c[3530494]|0)|0;c[2433672]=ax;ay=az-(c[3530362]|0)|0;c[2433670]=ay;az=1;while(1){aB=az<<1;if((az|0)<(b|0)){az=aB}else{break}}c[2433676]=az;az=1;while(1){aC=az<<1;if((az|0)<(aw|0)){az=aC}else{break}}c[2433674]=az;az=1;while(1){aD=az<<1;if((az|0)<(ax|0)){az=aD}else{break}}c[2433672]=az;az=1;while(1){aE=az<<1;if((az|0)<(ay|0)){az=aE}else{break}}c[2433670]=az;c[2385710]=(aB-1|0)/256|0;c[2385711]=(aC-1|0)/64|0;c[2385712]=(aD-1|0)/64|0;c[2385713]=(aE-1|0)/256|0;af=0;i=e;return af|0}aE=(c[2386306]|0)+1048560|0;aD=av-16|0;gGC(aE|0,aD|0,16)|0;aD=c[2386708]|0;aE=aA-aD|0;if((aE|0)<262144&(aA|0)!=(aD|0)){aA=1;do{a[aD+aA|0]=a[aD+((aA|0)%(aE|0)|0)|0]|0;aA=aA+1|0;}while((aA|0)<262144)}aA=c[3530964]|0;aE=c[2433676]|0;aD=v;av=w;aC=u|0;aB=(aE|0)/4|0;c[aC>>2]=aB*24|0;az=u+4|0;c[az>>2]=aB<<4;ay=u+8|0;c[ay>>2]=aB<<3;aB=u+12|0;c[aB>>2]=0;gGC(aD|0,597864,64)|0;gGC(av|0,609008,64)|0;ax=0;while(1){if((ax|0)>=1024){break}aF=9638528+(ax<<2)|0;if((c[aF>>2]|0)==0){ag=48712;break}else{ax=ax+1|0}}L62288:do{if((ag|0)==48712){ax=gGq(aE)|0;c[aF>>2]=ax;if((ax|0)==0){break}gGz(ax|0,0,aE|0);gGC(ax|0,aA|0,aE)|0;aw=aE<<1;b=(aw|0)/256|0;if((aw|0)>255){aw=0;while(1){F=aw<<8;gGz(aA+F|0,0,256);E=0;do{D=1<<3-E;C=(c[u+(E<<2)>>2]|0)+F|0;B=0;do{z=C+(c[w+(B<<2)>>2]|0)|0;al=(B<<4)+F|0;am=0;do{an=z+(c[v+(am<<2)>>2]|0)|0;if(((d[ax+((an|0)/8|0)|0]|0)&128>>>((an&7)>>>0)|0)!=0){an=aA+(al+am)|0;a[an]=(d[an]|0|D)&255}am=am+1|0;}while((am|0)<16);B=B+1|0;}while((B|0)<16);E=E+1|0;}while((E|0)<4);E=aw+1|0;if((E|0)<(b|0)){aw=E}else{aG=0;break}}}else{aG=0}while(1){if((aG|0)>=1024){break L62288}aH=9638528+(aG<<2)|0;if((c[aH>>2]|0)==(ax|0)){break}else{aG=aG+1|0}}gGr(ax);c[aH>>2]=0}}while(0);aH=c[3530730]|0;aG=c[2433674]|0;aA=(aG|0)/4|0;c[aC>>2]=aA*24|0;c[az>>2]=aA<<4;c[ay>>2]=aA<<3;c[aB>>2]=0;gGC(aD|0,597864,64)|0;gGC(av|0,609008,64)|0;aA=0;while(1){if((aA|0)>=1024){break}aI=9638528+(aA<<2)|0;if((c[aI>>2]|0)==0){ag=48729;break}else{aA=aA+1|0}}L62314:do{if((ag|0)==48729){aA=gGq(aG)|0;c[aI>>2]=aA;if((aA|0)==0){break}gGz(aA|0,0,aG|0);gGC(aA|0,aH|0,aG)|0;aE=aG<<1;aF=(aE|0)/64|0;if((aE|0)>63){aE=0;while(1){aw=aE<<6;gGz(aH+aw|0,0,64);b=0;do{E=1<<3-b;F=(c[u+(b<<2)>>2]|0)+aw|0;B=0;do{D=F+(c[w+(B<<2)>>2]|0)|0;C=(B<<3)+aw|0;am=0;do{al=D+(c[v+(am<<2)>>2]|0)|0;if(((d[aA+((al|0)/8|0)|0]|0)&128>>>((al&7)>>>0)|0)!=0){al=aH+(C+am)|0;a[al]=(d[al]|0|E)&255}am=am+1|0;}while((am|0)<8);B=B+1|0;}while((B|0)<8);b=b+1|0;}while((b|0)<4);b=aE+1|0;if((b|0)<(aF|0)){aE=b}else{aJ=0;break}}}else{aJ=0}while(1){if((aJ|0)>=1024){break L62314}aK=9638528+(aJ<<2)|0;if((c[aK>>2]|0)==(aA|0)){break}else{aJ=aJ+1|0}}gGr(aA);c[aK>>2]=0}}while(0);aK=c[2433672]|0;L62337:do{if((aK|0)>2){aJ=c[3530494]|0;aH=(aK|0)/4|0;c[aC>>2]=aH*24|0;c[az>>2]=aH<<4;c[ay>>2]=aH<<3;c[aB>>2]=0;gGC(aD|0,597864,64)|0;gGC(av|0,609008,64)|0;aH=0;while(1){if((aH|0)>=1024){break L62337}aL=9638528+(aH<<2)|0;if((c[aL>>2]|0)==0){break}else{aH=aH+1|0}}aH=gGq(aK)|0;c[aL>>2]=aH;if((aH|0)==0){break}gGz(aH|0,0,aK|0);gGC(aH|0,aJ|0,aK)|0;aA=aK<<1;aG=(aA|0)/64|0;if((aA|0)>63){aA=0;while(1){aI=aA<<6;gGz(aJ+aI|0,0,64);aE=0;do{aF=1<<3-aE;ax=(c[u+(aE<<2)>>2]|0)+aI|0;b=0;do{aw=ax+(c[w+(b<<2)>>2]|0)|0;B=(b<<3)+aI|0;E=0;do{F=aw+(c[v+(E<<2)>>2]|0)|0;if(((d[aH+((F|0)/8|0)|0]|0)&128>>>((F&7)>>>0)|0)!=0){F=aJ+(B+E)|0;a[F]=(d[F]|0|aF)&255}E=E+1|0;}while((E|0)<8);b=b+1|0;}while((b|0)<8);aE=aE+1|0;}while((aE|0)<4);aE=aA+1|0;if((aE|0)<(aG|0)){aA=aE}else{aM=0;break}}}else{aM=0}while(1){if((aM|0)>=1024){break L62337}aN=9638528+(aM<<2)|0;if((c[aN>>2]|0)==(aH|0)){break}else{aM=aM+1|0}}gGr(aH);c[aN>>2]=0}else{c[3530494]=c[3530730];c[2385712]=c[2385711]}}while(0);aN=c[2433670]|0;if((aN|0)<=2){c[2385713]=0;af=0;i=e;return af|0}aM=c[3530362]|0;aK=(aN|0)/4|0;c[aC>>2]=aK*24|0;c[az>>2]=aK<<4;c[ay>>2]=aK<<3;c[aB>>2]=0;gGC(aD|0,597864,64)|0;gGC(av|0,609008,64)|0;av=0;while(1){if((av|0)>=1024){af=0;ag=48807;break}aO=9638528+(av<<2)|0;if((c[aO>>2]|0)==0){break}else{av=av+1|0}}if((ag|0)==48807){i=e;return af|0}av=gGq(aN)|0;c[aO>>2]=av;if((av|0)==0){af=0;i=e;return af|0}gGz(av|0,0,aN|0);gGC(av|0,aM|0,aN)|0;aO=aN<<1;aN=(aO|0)/256|0;if((aO|0)>255){aO=0;while(1){aD=aO<<8;gGz(aM+aD|0,0,256);aB=0;do{aK=1<<3-aB;ay=(c[u+(aB<<2)>>2]|0)+aD|0;az=0;do{aC=ay+(c[w+(az<<2)>>2]|0)|0;aL=(az<<4)+aD|0;aA=0;do{aG=aC+(c[v+(aA<<2)>>2]|0)|0;if(((d[av+((aG|0)/8|0)|0]|0)&128>>>((aG&7)>>>0)|0)!=0){aG=aM+(aL+aA)|0;a[aG]=(d[aG]|0|aK)&255}aA=aA+1|0;}while((aA|0)<16);az=az+1|0;}while((az|0)<16);aB=aB+1|0;}while((aB|0)<4);aB=aO+1|0;if((aB|0)<(aN|0)){aO=aB}else{aP=0;break}}}else{aP=0}while(1){if((aP|0)>=1024){af=0;ag=48809;break}aQ=9638528+(aP<<2)|0;if((c[aQ>>2]|0)==(av|0)){break}else{aP=aP+1|0}}if((ag|0)==48809){i=e;return af|0}gGr(av);c[aQ>>2]=0;af=0;i=e;return af|0}function a4s(b){b=b|0;var d=0,e=0,f=0,g=0,h=0;d=a[9542400]|0;do{if((b|0)==0){e=d|16;a[9542400]=e;if(e<<24>>24!=-1){f=e;break}a[9706117]=0;return}else{e=d&-17;a[9542400]=e;f=e}}while(0);a[14125144]=f;a[9706117]=1;if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){f=gfc(1e3)|0;g=f;h=(c[2433530]|0)+f|0}else{g=1e3;h=(c[2433530]|0)+1e3|0}c[2433530]=h;c[2444004]=(c[2444004]|0)+g;return}function a4t(){return~~((a[9688]|0?534.0:0.0)*(+((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)/(3579545.0/(+(c[2424]|0)/100.0))))|0}function a4u(){var d=0,e=0,f=0,g=0,h=0,i=0;d=c[2414826]|0;gGz(d|0,0,(c[2411894]|0)-d|0);c[1836234]=0;d=c[2439374]|0;c[3531864]=d;gf[c[d>>2]&2047](0);gD[c[(c[3531864]|0)+8>>2]&8191]()|0;c[1836234]=-1;gu[c[(c[3531864]|0)+4>>2]&16383]();c[3531864]=0;d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;h=c[2417276]|0;c[3541536]=h;c[1836236]=0;gGz(9706056,0,76);a[9542400]=-1;a[9706117]=0;if(a[1558240]|0){a[627120]=1}if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=h;c[1836236]=-1;mx(0);h=c[2405758]|0;if((h|0)>0){i=0}else{c[2438064]=0;c[2429622]=-1;return}do{c[9542560+(i<<5)>>2]=0;b[9542544+(i<<5)>>1]=0;i=i+1|0;}while((i|0)<(h|0));c[2438064]=0;c[2429622]=-1;return}function a4v(){var a=0,b=0,d=0,e=0,f=0;fyz(0,8,0);c[1836234]=0;a=c[2439374]|0;c[3531864]=a;gf[c[a>>2]&2047](0);a=c[2386306]|0;b=c[3531864]|0;d=0;while(1){c[b+44+(d<<2)>>2]=a;e=d+1|0;if((e|0)<256){d=e}else{f=0;break}}do{c[b+4140+(f<<2)>>2]=a;c[b+6188+(f<<2)>>2]=a;f=f+1|0;}while((f|0)<256);f=(c[2386542]|0)-786432|0;c[b+1580>>2]=f;c[b+1584>>2]=f;c[b+3628>>2]=f;c[b+3632>>2]=f;c[b+5676>>2]=f;c[b+7724>>2]=f;c[b+5680>>2]=f;c[b+7728>>2]=f;f=c[2387296]|0;d=f-819200|0;c[b+1644>>2]=d;c[b+1648>>2]=d;c[b+5740>>2]=d;c[b+7788>>2]=d;c[b+5744>>2]=d;c[b+7792>>2]=d;d=(c[3529482]|0)-851968|0;c[b+1708>>2]=d;c[b+1712>>2]=d;c[b+1716>>2]=d;c[b+1720>>2]=d;c[b+1724>>2]=d;c[b+1728>>2]=d;c[b+1732>>2]=d;c[b+1736>>2]=d;c[b+3756>>2]=d;c[b+3760>>2]=d;c[b+3764>>2]=d;c[b+3768>>2]=d;c[b+3772>>2]=d;c[b+3776>>2]=d;c[b+3780>>2]=d;c[b+3784>>2]=d;c[b+5804>>2]=d;c[b+7852>>2]=d;c[b+5808>>2]=d;c[b+7856>>2]=d;c[b+5812>>2]=d;c[b+7860>>2]=d;c[b+5816>>2]=d;c[b+7864>>2]=d;c[b+5820>>2]=d;c[b+7868>>2]=d;c[b+5824>>2]=d;c[b+7872>>2]=d;c[b+5828>>2]=d;c[b+7876>>2]=d;c[b+5832>>2]=d;c[b+7880>>2]=d;d=(c[3529448]|0)-868352|0;c[b+1740>>2]=d;c[b+1744>>2]=d;c[b+1748>>2]=d;c[b+1752>>2]=d;c[b+1756>>2]=d;c[b+1760>>2]=d;c[b+1764>>2]=d;c[b+1768>>2]=d;c[b+3788>>2]=d;c[b+3792>>2]=d;c[b+3796>>2]=d;c[b+3800>>2]=d;c[b+3804>>2]=d;c[b+3808>>2]=d;c[b+3812>>2]=d;c[b+3816>>2]=d;c[b+5836>>2]=d;c[b+7884>>2]=d;c[b+5840>>2]=d;c[b+7888>>2]=d;c[b+5844>>2]=d;c[b+7892>>2]=d;c[b+5848>>2]=d;c[b+7896>>2]=d;c[b+5852>>2]=d;c[b+7900>>2]=d;c[b+5856>>2]=d;c[b+7904>>2]=d;c[b+5860>>2]=d;c[b+7908>>2]=d;c[b+5864>>2]=d;c[b+7912>>2]=d;d=f-880640|0;c[b+1772>>2]=d;c[b+1776>>2]=d;c[b+5868>>2]=d;c[b+7916>>2]=d;c[b+5872>>2]=d;c[b+7920>>2]=d;d=(c[2386312]|0)-917504|0;c[b+1836>>2]=d;c[b+1840>>2]=d;c[b+1844>>2]=d;c[b+1848>>2]=d;c[b+1852>>2]=d;c[b+1856>>2]=d;c[b+1860>>2]=d;c[b+1864>>2]=d;c[b+3884>>2]=d;c[b+3888>>2]=d;c[b+3892>>2]=d;c[b+3896>>2]=d;c[b+3900>>2]=d;c[b+3904>>2]=d;c[b+3908>>2]=d;c[b+3912>>2]=d;c[b+5932>>2]=d;c[b+7980>>2]=d;c[b+5936>>2]=d;c[b+7984>>2]=d;c[b+5940>>2]=d;c[b+7988>>2]=d;c[b+5944>>2]=d;c[b+7992>>2]=d;c[b+5948>>2]=d;c[b+7996>>2]=d;c[b+5952>>2]=d;c[b+8e3>>2]=d;c[b+5956>>2]=d;c[b+8004>>2]=d;c[b+5960>>2]=d;c[b+8008>>2]=d;c[b+2088>>2]=a;c[b+6184>>2]=a;c[b+8232>>2]=a;c[b+8236>>2]=1078;c[b+8240>>2]=3220;c[b+8244>>2]=2802;c[b+8248>>2]=4;c[1836234]=-1;gu[c[b+4>>2]&16383]();c[3531864]=0;return}function a4w(){a4z(524288,655360);return}function a4x(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;fwR(0);d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];f=c[3528484]|0;c[2076596]=f;g=c[2417276]|0;c[3541536]=g;c[1836236]=0;h=c[2386172]|0;i=0;j=0;while(1){c[d+76+(j<<2)>>2]=h+(j<<8);k=i+1&65535;if((k&65535)>255){l=0;m=0;break}else{i=k;j=k&65535}}while(1){c[d+76+(m+256<<2)>>2]=h+(m<<8);j=l+1&65535;if((j&65535)>255){n=0;o=0;break}else{l=j;m=j&65535}}while(1){m=h+(o<<8)|0;c[d+76+(o+512<<2)>>2]=m;c[d+76+(o+768<<2)>>2]=m;m=n+1&65535;if((m&65535)>255){break}else{n=m;o=m&65535}}c[d+4176>>2]=1798;c[d+4172>>2]=1668;if(e){p=c[2433530]|0;c[2438118]=p;c[3528484]=f;c[2417276]=g;c[1836236]=-1;a[1558240]=1;return}e=d;gGC(e|0,9706056,76)|0;p=c[2433530]|0;c[2438118]=p;c[3528484]=f;c[2417276]=g;c[1836236]=-1;a[1558240]=1;return}function a4y(){var b=0,d=0,e=0,f=0;b=c[2386306]|0;d=b+1024|0;gGC(d|0,595376,216)|0;a[b+1020|0]=-120;a[b+1021|0]=5;a[b+2882|0]=30;a[b+2883|0]=6;a[b+2884|0]=-72;a[b+16475|0]=5;a[b+16486|0]=5;a[b+66522|0]=-80;a[b+66525|0]=-2;a[b+66526|0]=6;a[b+66527|0]=-2;a[b+66528|0]=15;a[b+66529|0]=-27;a[b+66530|0]=2;a[b+66531|0]=-87;a[b+66532|0]=32;a[b+66533|0]=0;a[b+66534|0]=117;a[b+66535|0]=5;a[b+66536|0]=-22;a[b+66537|0]=47;a[b+66538|0]=4;a[b+66539|0]=0;a[b+66540|0]=0;a[b+66541|0]=-72;a[b+66649|0]=-25;a[b+66650|0]=4;a[b+66651|0]=-27;a[b+66652|0]=2;a[b+66653|0]=37;a[b+66654|0]=-128;a[b+66655|0]=0;a[b+66656|0]=116;a[b+66657|0]=-7;a[b+66658|0]=54;a[b+66659|0]=-95;a[b+66660|0]=-78;a[b+66661|0]=35;a[b+66662|0]=-25;a[b+66663|0]=-126;a[b+66664|0]=54;a[b+66665|0]=-95;a[b+66666|0]=-74;a[b+66667|0]=35;a[b+66668|0]=-25;a[b+66740|0]=50;a[b+66741|0]=-28;a[b+66742|0]=60;a[b+66743|0]=127;a[b+66744|0]=114;a[b+66935|0]=71;a[b+66936|0]=-36;a[b+66949|0]=97;a[b+66950|0]=7;a[b+66951|0]=31;a[b+66969|0]=0;a[b+67475|0]=-25;a[b+67476|0]=2;a[b+123328|0]=-70;a[b+125481|0]=-25;a[b+125482|0]=2;b=c[3530730]|0;d=c[3530494]|0;e=0;do{f=b+e|0;a[f]=a[f]^15;f=d+e|0;a[f]=a[f]^15;e=e+1|0;}while((e|0)<524288);return 0}function a4z(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;fyz(0,8,0);c[1836234]=0;d=c[2439374]|0;c[3531864]=d;gf[c[d>>2]&2047](0);d=c[2386306]|0;e=a+2046>>11;if((e|0)>0){a=c[3531864]|0;f=0;while(1){c[a+44+(f<<2)>>2]=d;g=f+1|0;if((g|0)<(e|0)){f=g}else{h=0;break}}do{c[a+4140+(h<<2)>>2]=d;c[a+6188+(h<<2)>>2]=d;h=h+1|0;}while((h|0)<(e|0))}e=b>>11;h=b+18430>>11;if((e|0)<(h|0)){a=(c[2386312]|0)+(-b|0)|0;b=c[3531864]|0;f=e;while(1){c[b+44+(f<<2)>>2]=a;g=f+1|0;if((g|0)<(h|0)){f=g}else{i=e;break}}while(1){c[b+2092+(i<<2)>>2]=a;f=i+1|0;if((f|0)<(h|0)){i=f}else{j=e;break}}while(1){c[b+4140+(j<<2)>>2]=a;c[b+6188+(j<<2)>>2]=a;e=j+1|0;if((e|0)<(h|0)){j=e}else{k=b;break}}}else{k=c[3531864]|0}b=(c[2386542]|0)-786432|0;c[k+1580>>2]=b;c[k+1584>>2]=b;c[k+3628>>2]=b;c[k+3632>>2]=b;c[k+5676>>2]=b;c[k+7724>>2]=b;c[k+5680>>2]=b;c[k+7728>>2]=b;b=c[2387296]|0;j=b-819200|0;c[k+1644>>2]=j;c[k+1648>>2]=j;c[k+5740>>2]=j;c[k+7788>>2]=j;c[k+5744>>2]=j;c[k+7792>>2]=j;j=b-831488|0;c[k+1676>>2]=j;c[k+1680>>2]=j;c[k+5772>>2]=j;c[k+7820>>2]=j;c[k+5776>>2]=j;c[k+7824>>2]=j;j=(c[3529482]|0)-851968|0;c[k+1708>>2]=j;c[k+1712>>2]=j;c[k+1716>>2]=j;c[k+1720>>2]=j;c[k+1724>>2]=j;c[k+1728>>2]=j;c[k+1732>>2]=j;c[k+1736>>2]=j;c[k+3756>>2]=j;c[k+3760>>2]=j;c[k+3764>>2]=j;c[k+3768>>2]=j;c[k+3772>>2]=j;c[k+3776>>2]=j;c[k+3780>>2]=j;c[k+3784>>2]=j;c[k+5804>>2]=j;c[k+7852>>2]=j;c[k+5808>>2]=j;c[k+7856>>2]=j;c[k+5812>>2]=j;c[k+7860>>2]=j;c[k+5816>>2]=j;c[k+7864>>2]=j;c[k+5820>>2]=j;c[k+7868>>2]=j;c[k+5824>>2]=j;c[k+7872>>2]=j;c[k+5828>>2]=j;c[k+7876>>2]=j;c[k+5832>>2]=j;c[k+7880>>2]=j;j=(c[3529448]|0)-884736|0;c[k+1772>>2]=j;c[k+1776>>2]=j;c[k+1780>>2]=j;c[k+1784>>2]=j;c[k+1788>>2]=j;c[k+1792>>2]=j;c[k+1796>>2]=j;c[k+1800>>2]=j;c[k+3820>>2]=j;c[k+3824>>2]=j;c[k+3828>>2]=j;c[k+3832>>2]=j;c[k+3836>>2]=j;c[k+3840>>2]=j;c[k+3844>>2]=j;c[k+3848>>2]=j;c[k+5868>>2]=j;c[k+7916>>2]=j;c[k+5872>>2]=j;c[k+7920>>2]=j;c[k+5876>>2]=j;c[k+7924>>2]=j;c[k+5880>>2]=j;c[k+7928>>2]=j;c[k+5884>>2]=j;c[k+7932>>2]=j;c[k+5888>>2]=j;c[k+7936>>2]=j;c[k+5892>>2]=j;c[k+7940>>2]=j;c[k+5896>>2]=j;c[k+7944>>2]=j;j=(c[2386172]|0)-917504|0;b=448;while(1){c[k+44+(b<<2)>>2]=j;h=b+1|0;if((h|0)<480){b=h}else{l=448;break}}while(1){c[k+2092+(l<<2)>>2]=j;b=l+1|0;if((b|0)<480){l=b}else{m=448;break}}do{c[k+4140+(m<<2)>>2]=j;c[k+6188+(m<<2)>>2]=j;m=m+1|0;}while((m|0)<480);c[k+2088>>2]=d;c[k+6184>>2]=d;c[k+8232>>2]=d;c[k+8236>>2]=1078;c[k+8240>>2]=256;c[k+8244>>2]=2802;c[k+8248>>2]=4;c[1836234]=-1;gu[c[k+4>>2]&16383]();c[3531864]=0;return}function a4A(){var a=0,b=0,d=0,e=0,f=0,g=0;fyz(0,8,0);c[1836234]=0;a=c[2439374]|0;c[3531864]=a;gf[c[a>>2]&2047](0);a=c[2386306]|0;b=c[3531864]|0;d=0;while(1){c[b+44+(d<<2)>>2]=a;e=d+1|0;if((e|0)<256){d=e}else{f=0;break}}do{c[b+4140+(f<<2)>>2]=a;c[b+6188+(f<<2)>>2]=a;f=f+1|0;}while((f|0)<256);f=c[3529482]|0;d=f-524288|0;c[b+1068>>2]=d;c[b+1072>>2]=d;c[b+1076>>2]=d;c[b+1080>>2]=d;c[b+1084>>2]=d;c[b+1088>>2]=d;c[b+1092>>2]=d;c[b+1096>>2]=d;c[b+3116>>2]=d;c[b+3120>>2]=d;c[b+3124>>2]=d;c[b+3128>>2]=d;c[b+3132>>2]=d;c[b+3136>>2]=d;c[b+3140>>2]=d;c[b+3144>>2]=d;c[b+5164>>2]=d;c[b+7212>>2]=d;c[b+5168>>2]=d;c[b+7216>>2]=d;c[b+5172>>2]=d;c[b+7220>>2]=d;c[b+5176>>2]=d;c[b+7224>>2]=d;c[b+5180>>2]=d;c[b+7228>>2]=d;c[b+5184>>2]=d;c[b+7232>>2]=d;c[b+5188>>2]=d;c[b+7236>>2]=d;c[b+5192>>2]=d;c[b+7240>>2]=d;d=c[3529448]|0;e=d-540672|0;c[b+1100>>2]=e;c[b+1104>>2]=e;c[b+1108>>2]=e;c[b+1112>>2]=e;c[b+1116>>2]=e;c[b+1120>>2]=e;c[b+1124>>2]=e;c[b+1128>>2]=e;c[b+3148>>2]=e;c[b+3152>>2]=e;c[b+3156>>2]=e;c[b+3160>>2]=e;c[b+3164>>2]=e;c[b+3168>>2]=e;c[b+3172>>2]=e;c[b+3176>>2]=e;c[b+5196>>2]=e;c[b+7244>>2]=e;c[b+5200>>2]=e;c[b+7248>>2]=e;c[b+5204>>2]=e;c[b+7252>>2]=e;c[b+5208>>2]=e;c[b+7256>>2]=e;c[b+5212>>2]=e;c[b+7260>>2]=e;c[b+5216>>2]=e;c[b+7264>>2]=e;c[b+5220>>2]=e;c[b+7268>>2]=e;c[b+5224>>2]=e;c[b+7272>>2]=e;e=c[2387296]|0;g=e-655360|0;c[b+1324>>2]=g;c[b+1328>>2]=g;c[b+5420>>2]=g;c[b+7468>>2]=g;c[b+5424>>2]=g;c[b+7472>>2]=g;g=e-684032|0;c[b+1388>>2]=g;c[b+1392>>2]=g;c[b+5484>>2]=g;c[b+7532>>2]=g;c[b+5488>>2]=g;c[b+7536>>2]=g;g=(c[2386542]|0)-786432|0;c[b+1580>>2]=g;c[b+1584>>2]=g;c[b+3628>>2]=g;c[b+3632>>2]=g;c[b+5676>>2]=g;c[b+7724>>2]=g;c[b+5680>>2]=g;c[b+7728>>2]=g;g=f-851968|0;c[b+1708>>2]=g;c[b+1712>>2]=g;c[b+1716>>2]=g;c[b+1720>>2]=g;c[b+1724>>2]=g;c[b+1728>>2]=g;c[b+1732>>2]=g;c[b+1736>>2]=g;c[b+3756>>2]=g;c[b+3760>>2]=g;c[b+3764>>2]=g;c[b+3768>>2]=g;c[b+3772>>2]=g;c[b+3776>>2]=g;c[b+3780>>2]=g;c[b+3784>>2]=g;c[b+5804>>2]=g;c[b+7852>>2]=g;c[b+5808>>2]=g;c[b+7856>>2]=g;c[b+5812>>2]=g;c[b+7860>>2]=g;c[b+5816>>2]=g;c[b+7864>>2]=g;c[b+5820>>2]=g;c[b+7868>>2]=g;c[b+5824>>2]=g;c[b+7872>>2]=g;c[b+5828>>2]=g;c[b+7876>>2]=g;c[b+5832>>2]=g;c[b+7880>>2]=g;g=d-868352|0;c[b+1740>>2]=g;c[b+1744>>2]=g;c[b+1748>>2]=g;c[b+1752>>2]=g;c[b+1756>>2]=g;c[b+1760>>2]=g;c[b+1764>>2]=g;c[b+1768>>2]=g;c[b+3788>>2]=g;c[b+3792>>2]=g;c[b+3796>>2]=g;c[b+3800>>2]=g;c[b+3804>>2]=g;c[b+3808>>2]=g;c[b+3812>>2]=g;c[b+3816>>2]=g;c[b+5836>>2]=g;c[b+7884>>2]=g;c[b+5840>>2]=g;c[b+7888>>2]=g;c[b+5844>>2]=g;c[b+7892>>2]=g;c[b+5848>>2]=g;c[b+7896>>2]=g;c[b+5852>>2]=g;c[b+7900>>2]=g;c[b+5856>>2]=g;c[b+7904>>2]=g;c[b+5860>>2]=g;c[b+7908>>2]=g;c[b+5864>>2]=g;c[b+7912>>2]=g;g=(c[2386312]|0)-917504|0;c[b+1836>>2]=g;c[b+1840>>2]=g;c[b+1844>>2]=g;c[b+1848>>2]=g;c[b+1852>>2]=g;c[b+1856>>2]=g;c[b+1860>>2]=g;c[b+1864>>2]=g;c[b+3884>>2]=g;c[b+3888>>2]=g;c[b+3892>>2]=g;c[b+3896>>2]=g;c[b+3900>>2]=g;c[b+3904>>2]=g;c[b+3908>>2]=g;c[b+3912>>2]=g;c[b+5932>>2]=g;c[b+7980>>2]=g;c[b+5936>>2]=g;c[b+7984>>2]=g;c[b+5940>>2]=g;c[b+7988>>2]=g;c[b+5944>>2]=g;c[b+7992>>2]=g;c[b+5948>>2]=g;c[b+7996>>2]=g;c[b+5952>>2]=g;c[b+8e3>>2]=g;c[b+5956>>2]=g;c[b+8004>>2]=g;c[b+5960>>2]=g;c[b+8008>>2]=g;c[b+2088>>2]=a;c[b+6184>>2]=a;c[b+8232>>2]=a;c[b+8236>>2]=1078;c[b+8240>>2]=3220;c[b+8244>>2]=2802;c[b+8248>>2]=4;c[1836234]=-1;gu[c[b+4>>2]&16383]();c[3531864]=0;return}function a4B(){var a=0,b=0,d=0;a=c[2386306]|0;b=a+393216|0;d=a+262144|0;gGC(b|0,d|0,131072)|0;return 0}function a4C(){var a=0,b=0,d=0;a=c[2386306]|0;b=a+262144|0;d=a+131072|0;gGC(b|0,d|0,262144)|0;return 0}function a4D(){a4z(524288,589824);return}function a4E(){a4z(524288,557056);return}function a4F(){var a=0,b=0,d=0;a=c[2386306]|0;b=a+393216|0;d=a+131072|0;gGC(b|0,d|0,131072)|0;return 0}function a4G(){a4z(524288,524288);return}function a4H(){a4z(524288,638976);return}function a4I(d,f){d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;if((a[c[2440176]|0]|0)!=0){return}g=c[2438250]|0;a4J(1,1,g,d,f);a4J(0,1,g,d,f);c[2102744]=d;h=c[2112926]|0;i=c[2113070]|0;j=c[2113068]|0;k=h+((ag(j,d)|0)<<1)|0;c[2112926]=k;l=f-d|0;c[2113070]=l;if((g|0)==3){m=c[3529618]|0;n=c[2385713]|0;o=c[3530362]|0;p=0;do{q=e[m+((p|1)<<1)>>1]|0;r=e[m+((p|2)<<1)>>1]|0;s=r&15;t=1<<(r>>>12&3);u=(b[m+((p|3)<<1)>>1]&1023)-320|0;v=(r&2048|0)!=0;w=(r&1024|0)!=0;r=t-1|0;x=384-d-(b[m+(p<<1)>>1]&511)-(t<<4)|0;if((t|0)>0){y=(u|0)>-16;z=0;do{A=(w?r-z|0:z)+q&n;B=x+(z<<4)|0;do{if((B|0)>-16&y&(u|0)<(j|0)&(B|0)<(l|0)){if(w){if(v){SN(k,A,u,B,s,4,0,0,o);break}else{SL(k,A,u,B,s,4,0,0,o);break}}else{if(v){SJ(k,A,u,B,s,4,0,0,o);break}else{SH(k,A,u,B,s,4,0,0,o);break}}}}while(0);z=z+1|0;}while((z|0)<(t|0))}p=p+4|0;}while((p|0)<1024)}p=c[2386590]|0;o=c[2385710]|0;n=c[3530964]|0;m=0;do{t=e[p+((m|2)<<1)>>1]|0;z=e[p+((m|1)<<1)>>1]|0;s=t&15;u=1<<(t>>>14);v=1<<(t>>>12&3);w=(b[p+((m|3)<<1)>>1]&1023)-320|0;if((u|0)>0){y=(v|0)>0;x=(t&2048|0)!=0;q=u+536870911|0;r=(t&1024|0)!=0;t=v-1|0;B=384-(v<<4)-d-(b[p+(m<<1)>>1]&511)|0;A=0;do{if(y){C=w+(A<<4)|0;D=(C|0)>-16;E=((x?q-A|0:A)<<3)+z|0;F=0;do{G=E+(r?t-F|0:F)&o;H=B+(F<<4)|0;do{if((H|0)>-16&D&(C|0)<(j|0)&(H|0)<(l|0)){if(r){if(x){SN(k,G,C,H,s,4,0,0,n);break}else{SL(k,G,C,H,s,4,0,0,n);break}}else{if(x){SJ(k,G,C,H,s,4,0,0,n);break}else{SH(k,G,C,H,s,4,0,0,n);break}}}}while(0);F=F+1|0;}while((F|0)<(v|0))}A=A+1|0;}while((A|0)<(u|0))}m=(u<<2)+m|0;}while((m|0)<512);c[2112926]=h;c[2113070]=i;a4J(1,0,g,d,f);a4J(0,0,g,d,f);return}function a4J(f,g,h,j,k){f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0;l=i;i=i+24|0;m=l|0;n=c[9542840+(f+1<<2)>>2]|0;o=(f|0)!=0;p=o?c[3529448]|0:c[3529482]|0;q=o?c[3530494]|0:c[3530730]|0;b[m>>1]=-1;b[m+2>>1]=1;b[m+4>>1]=255;b[m+6>>1]=-255;b[m+8>>1]=1;b[m+10>>1]=-1;b[m+12>>1]=-1;b[m+14>>1]=0;b[m+16>>1]=255;b[m+18>>1]=-256;o=(h|0)==0;b[m+20>>1]=o?7:1;b[m+22>>1]=o?-8:-2;o=f<<2;r=c[2409012]|0;s=((d[r+(o|1)|0]|0)<<8|(d[r+o|0]|0))+128|0;t=(c[9755536+(f<<2)>>2]|0)+64+((d[r+(o|3)|0]|0)<<8|(d[r+(o|2)|0]|0))|0;o=t&511;r=c[2443488]|0;if((j|0)>=(k|0)){i=l;return}u=(h|0)==3;v=(f|0)==1;w=u&v;x=c[2113068]|0;y=o+256|0;z=c[2112926]|0;A=c[2439414]|0;B=x+8|0;C=(c[2426972]|0)!=0&v;v=c[2438885]|0;D=j;do{j=ag(D,x)|0;E=s+D|0;F=E&511;G=E<<3&56;if((x+8|0)>0){E=r+(F<<1)|0;H=F>>>3;F=H<<8;I=G^56;J=H<<6;if(u){H=0;do{do{if(C){K=H+320+(e[E>>1]|0)+v|0;if(w){L=K;M=48932}else{N=K;M=48931}}else{K=H+o|0;if(!w){N=K;M=48931;break}L=K+256|0;M=48932}}while(0);if((M|0)==48932){M=0;K=L&1023;O=K>>>3|F;P=K}else if((M|0)==48931){M=0;K=N&511;O=K>>>3|J;P=K}K=O<<1;Q=e[p+((K|1)<<1)>>1]|0;if((Q&256|0)==0){R=Q>>>7&1}else{R=2}S=e[m+(f*12|0)+(R<<2)+(g<<1)>>1]|0;T=Q<<4&240;U=(Q&32|0)==0?0:7;V=((Q&64|0)==0?G:I)|((e[p+(K<<1)>>1]|0)&n)<<6;K=1<<R&255;Q=H-(P&7)|0;W=0;while(1){do{if((Q|0)>-1&(Q|0)<(x|0)){X=d[q+((W^U)+V)|0]|0;if((1<<X&S|0)!=0){break}Y=Q+j|0;b[z+(Y<<1)>>1]=(T|X|256)&65535;a[A+Y|0]=K}}while(0);Y=W+1|0;if((Y|0)>=8){break}Q=Q+1|0;W=Y}H=H+8|0;}while((H|0)<(B|0))}else{H=0;do{if(w){E=y+H&1023;Z=E>>>3|F;_=E}else{E=H+t&511;Z=E>>>3|J;_=E}E=Z<<1;W=e[p+(E<<1)>>1]|0;Q=e[p+((E|1)<<1)>>1]|0;do{if((h|0)==3|(h|0)==1){E=Q&64;K=Q&32;if((Q&256|0)!=0){$=2;aa=K;ab=E;break}$=Q>>>7&1;aa=K;ab=E}else{E=W&32768;K=W&16384;if((Q&128|0)!=0){$=2;aa=K;ab=E;break}$=Q>>>6&1;aa=K;ab=E}}while(0);E=e[m+(f*12|0)+($<<2)+(g<<1)>>1]|0;K=Q<<4&240;T=(aa|0)==0?0:7;S=((ab|0)==0?G:I)|(W&n)<<6;V=1<<$&255;U=H-(_&7)|0;Y=0;while(1){do{if((U|0)>-1&(U|0)<(x|0)){X=d[q+((Y^T)+S)|0]|0;if((1<<X&E|0)!=0){break}ac=U+j|0;b[z+(ac<<1)>>1]=(K|X|256)&65535;a[A+ac|0]=V}}while(0);ac=Y+1|0;if((ac|0)>=8){break}U=U+1|0;Y=ac}H=H+8|0;}while((H|0)<(B|0))}}D=D+1|0;}while((D|0)<(k|0));i=l;return}function a4K(){a4z(262144,262144);return}function a4L(b){b=b|0;var d=0;if((b&1046528|0)==1017856){d=a[(c[2387294]|0)+(b-1017856+(c[2407022]|0))|0]|0;return d|0}if((b&1032192|0)!=983040){d=0;return d|0}if((b&1|0)!=0){d=-1;return d|0}d=a[(c[2387860]|0)+(b>>>1&8191)|0]|0;return d|0}function a4M(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;if((b&1046528|0)==1017856){f=b-1017856|0;g=c[2387294]|0;a[g+((c[2407022]|0)+f)|0]=e;if((b&1|0)==0){return}h=((c[2407022]|0)+f|0)>>>1;f=h<<1;i=d[g+f|0]|0;j=d[g+(f|1)|0]|0;f=(j<<8|i)>>>2&248;c[(c[3530210]|0)+(h<<2)>>2]=j>>>2&31|i<<11&63488|(f>>>5|f)<<3&2016;return}if((b&1032193|0)==983040){a[(c[2387860]|0)+(b>>>1&8191)|0]=e;return}switch(b|0){case 1019905:{c[2438896]=c[2438896]&255|(e&255)<<8;return};case 1019908:{if(e<<24>>24==8){k=-(c[2438896]|0)<<2&1020}else{k=1024}c[2433590]=k;return};case 1019912:{a[9708288]=0;c[2427036]=1;gu[c[(c[3531864]|0)+36>>2]&16383]();return};case 1019904:{c[2438896]=c[2438896]&65280|e&255;return};case 1021952:{c[2407022]=(e&2)!=0?2048:0;return};default:{return}}}function a4N(b){b=b|0;var d=0;L62637:do{switch(b|0){case 0:{d=~a[9625904];break};case 24:{if((c[3528582]|0)!=3){d=0;break L62637}d=c[2113156]&255;break};case 2:{d=a[9625908]&127^127|a[9708288];break};case 5:{d=a[9625910]|0;break};case 6:{d=~a[9625906];break};case 4:{d=a[9625909]|0;break};case 7:{d=~a[9625907];break};case 8:{gG[c[(c[3531864]|0)+16>>2]&255](0,((c[2429908]|0)+12|0)/4|0,0);d=a[c[2440214]|0]|0;break};case 9:{gG[c[(c[3531864]|0)+16>>2]&255](0,((c[2429908]|0)+12|0)/4|0,0);d=a[(c[2440214]|0)+1|0]|0;break};case 3:{d=a[9625911]|0;break};case 1:{d=~a[9625905];break};default:{d=0}}}while(0);return d|0}function a4O(e,f){e=e|0;f=f|0;var g=0,h=0,i=0,j=0;switch(e|0){case 0:{a[c[2443734]|0]=f;c[1836234]=-1;gu[c[(c[3531864]|0)+4>>2]&16383]();c[1836234]=1;e=c[2439375]|0;c[3531864]=e;gf[c[e>>2]&2047](1);gG[c[(c[3531864]|0)+16>>2]&255](11,255,1);gj[c[(c[3531864]|0)+12>>2]&4095](10)|0;gG[c[(c[3531864]|0)+16>>2]&255](11,255,0);gj[c[(c[3531864]|0)+12>>2]&4095](10)|0;c[1836234]=-1;gu[c[(c[3531864]|0)+4>>2]&16383]();c[1836234]=0;e=c[2439374]|0;c[3531864]=e;gf[c[e>>2]&2047](0);return};case 147:{a[(c[3528416]|0)+3|0]=f;return};case 130:{a[(c[3528420]|0)+2|0]=f;return};case 32:{if((c[3528582]|0)==1){return}e=(c[2386298]|0)+(((f&255)<<16&458752|1048576)-655360)|0;g=c[3531864]|0;h=320;while(1){c[g+44+(h<<2)>>2]=e;i=h+1|0;if((i|0)<384){h=i}else{j=320;break}}do{c[g+4140+(j<<2)>>2]=e;c[g+6188+(j<<2)>>2]=e;j=j+1|0;}while((j|0)<384);return};case 24:{if((c[3528582]|0)!=3){return}Uv(0,f);return};case 158:{j=c[3528414]|0;a[j+6|0]=f;c[2427038]=((d[j+7|0]|0)<<8|f&255)-128;return};case 16:{if((c[3528582]|0)!=3){return}j=f&255;if((c[2440580]|0)==(j+1|0)){return}e=(j&3)+1|0;c[2440580]=e;j=c[2386706]|0;g=j+131072|0;h=j+((e<<17)+1048576)|0;gGC(g|0,h|0,131072)|0;return};case 137:{h=c[3528418]|0;g=h+1|0;a[g]=f;e=c[3528579]|0;b[e+12>>1]=(d[h+5|0]|0)<<8|(d[h+4|0]|0);b[e+14>>1]=(d[g]|0)<<8|(d[h]|0);return};case 156:{a[(c[3528414]|0)+4|0]=f;h=f&255;g=c[3528580]|0;e=g|0;if((h&16|0)==0){c[e>>2]=1;c[g+4>>2]=(h<<4&64)+64}else{c[e>>2]=0}c[g+8>>2]=h&64;c[g+20>>2]=(c[2386280]|0)+(h<<14&49152);return};case 133:{h=c[3528420]|0;a[h+5|0]=f;g=c[3528578]|0;b[g+12>>1]=(f&255)<<8|(d[h+4|0]|0);b[g+14>>1]=(d[h+1|0]|0)<<8|(d[h]|0);return};case 132:{h=c[3528420]|0;a[h+4|0]=f;g=c[3528578]|0;b[g+12>>1]=(d[h+5|0]|0)<<8|f&255;b[g+14>>1]=(d[h+1|0]|0)<<8|(d[h]|0);return};case 128:{h=c[3528420]|0;a[h]=f;g=c[3528578]|0;b[g+12>>1]=(d[h+5|0]|0)<<8|(d[h+4|0]|0);b[g+14>>1]=(d[h+1|0]|0)<<8|(d[h]|0);return};case 144:{h=c[3528416]|0;a[h]=f;g=c[3528580]|0;b[g+12>>1]=(d[h+5|0]|0)<<8|(d[h+4|0]|0);b[g+14>>1]=(d[h+1|0]|0)<<8|(d[h]|0);return};case 145:{h=c[3528416]|0;g=h+1|0;a[g]=f;e=c[3528580]|0;b[e+12>>1]=(d[h+5|0]|0)<<8|(d[h+4|0]|0);b[e+14>>1]=(d[g]|0)<<8|(d[h]|0);return};case 131:{a[(c[3528420]|0)+3|0]=f;return};case 146:{a[(c[3528416]|0)+2|0]=f;return};case 140:{h=c[3528418]|0;a[h+4|0]=f;g=c[3528579]|0;b[g+12>>1]=(d[h+5|0]|0)<<8|f&255;b[g+14>>1]=(d[h+1|0]|0)<<8|(d[h]|0);return};case 141:{h=c[3528418]|0;a[h+5|0]=f;g=c[3528579]|0;b[g+12>>1]=(f&255)<<8|(d[h+4|0]|0);b[g+14>>1]=(d[h+1|0]|0)<<8|(d[h]|0);return};case 135:{a[(c[3528420]|0)+7|0]=f;return};case 151:{a[(c[3528416]|0)+7|0]=f;return};case 136:{h=c[3528418]|0;a[h]=f;g=c[3528579]|0;b[g+12>>1]=(d[h+5|0]|0)<<8|(d[h+4|0]|0);b[g+14>>1]=(d[h+1|0]|0)<<8|(d[h]|0);return};case 138:{a[(c[3528418]|0)+2|0]=f;return};case 153:{a[(c[3528414]|0)+1|0]=f;return};case 142:{a[(c[3528418]|0)+6|0]=f;return};case 159:{h=c[3528414]|0;a[h+7|0]=f;c[2427038]=((f&255)<<8|(d[h+6|0]|0))-128;return};case 155:{a[(c[3528414]|0)+3|0]=f;return};case 134:{a[(c[3528420]|0)+6|0]=f;return};case 154:{a[(c[3528414]|0)+2|0]=f;h=f&255;g=c[3528579]|0;e=g|0;if((h&16|0)==0){c[e>>2]=1;c[g+4>>2]=(h<<4&64)+64}else{c[e>>2]=0}c[g+8>>2]=h&64;c[g+20>>2]=(c[2386280]|0)+(h<<14&49152);return};case 129:{h=c[3528420]|0;g=h+1|0;a[g]=f;e=c[3528578]|0;b[e+12>>1]=(d[h+5|0]|0)<<8|(d[h+4|0]|0);b[e+14>>1]=(d[g]|0)<<8|(d[h]|0);return};case 157:{a[(c[3528414]|0)+5|0]=f;return};case 143:{a[(c[3528418]|0)+7|0]=f;return};case 152:{a[c[3528414]|0]=f;h=f&255;g=c[3528578]|0;e=g|0;if((h&16|0)==0){c[e>>2]=1;c[g+4>>2]=(h<<4&64)+64}else{c[e>>2]=0}c[g+8>>2]=h&64;c[g+20>>2]=(c[2386280]|0)+(h<<14&49152);return};case 148:{h=c[3528416]|0;a[h+4|0]=f;g=c[3528580]|0;b[g+12>>1]=(d[h+5|0]|0)<<8|f&255;b[g+14>>1]=(d[h+1|0]|0)<<8|(d[h]|0);return};case 149:{h=c[3528416]|0;a[h+5|0]=f;g=c[3528580]|0;b[g+12>>1]=(f&255)<<8|(d[h+4|0]|0);b[g+14>>1]=(d[h+1|0]|0)<<8|(d[h]|0);return};case 150:{a[(c[3528416]|0)+6|0]=f;return};case 139:{a[(c[3528418]|0)+3|0]=f;return};default:{return}}}function a4P(b){b=b|0;var d=0;do{if((b&1048512|0)==688128){c[2420428]=9668600;if((b&14|0)!=14){d=0;break}d=(c[9668772+((b>>>4&3)*40|0)>>2]|0)!=0|0}else{if((b|0)==688197){d=-1;break}else if((b|0)==688196){d=a[c[2443734]|0]|0;break}else if((b|0)==688194){d=c[(c[3531464]|0)+4240>>2]&255;break}else{d=0;break}}}while(0);return d|0}function a4Q(d,e){d=d|0;e=e|0;var f=0,g=0,h=0;if((d&1048512|0)!=688128){if((d&1048320|0)==655104){return}if((d|0)==688192){c[2113304]=e&255;return}else if((d|0)==688194){f=c[2113304]|0;a[14168504+f|0]=e;mv(0,f,e&255);return}else if((d|0)==688198){a[c[2440214]|0]=e;c[1836234]=-1;gu[c[(c[3531864]|0)+4>>2]&16383]();c[1836234]=0;f=c[2439374]|0;c[3531864]=f;gf[c[f>>2]&2047](0);gG[c[(c[3531864]|0)+16>>2]&255](0,((c[2429908]|0)+12|0)/4|0,1);c[1836234]=-1;gu[c[(c[3531864]|0)+4>>2]&16383]();c[1836234]=1;f=c[2439375]|0;c[3531864]=f;gf[c[f>>2]&2047](1);return}else{return}}f=d>>>1;d=f&31;g=e&255;c[2420428]=9668600;h=d>>>3;b[9668608+(d<<1)>>1]=e&255;switch(f&7|0){case 5:{c[9668760+(h*40|0)>>2]=(g<<8>>>0)/((g+10|0)>>>0)|0;return};case 3:{f=9668756+(h*40|0)|0;c[f>>2]=c[f>>2]&4080|g<<12;return};case 0:{f=9668744+(h*40|0)|0;c[f>>2]=c[f>>2]&1044480|g<<4;return};case 1:{f=9668744+(h*40|0)|0;c[f>>2]=c[f>>2]&4080|g<<12;return};case 6:{c[9668772+(h*40|0)>>2]=g;c[9668748+(h*40|0)>>2]=c[9668744+(h*40|0)>>2];c[9668752+(h*40|0)>>2]=0;return};case 2:{f=9668756+(h*40|0)|0;c[f>>2]=c[f>>2]&1044480|g<<4;return};case 4:{c[9668736+(h*40|0)>>2]=16777216/((256-g|0)>>>0)|0;return};default:{return}}}function a4R(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7048380+(b*112|0)>>2];c[a+104>>2]=c[7048384+(b*112|0)>>2];c[a+108>>2]=c[7048388+(b*112|0)>>2];d=0;return d|0}function a4S(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=7048280+(b*112|0);e=0;return e|0}function a4T(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>36){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1036176+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function a4U(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>50){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7204656+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function a4V(){return a6q(482,48152,1,128,1048576,4194304)|0}function a4W(){var b=0,d=0,e=0,f=0;c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}b=c[3531464]|0;c[b+44344>>2]=0;c[b+44348>>2]=0;if((b|0)!=0){gGr(b);c[3531464]=0}b=c[2406684]|0;if((b|0)!=0){gGr(b);c[2406684]=0}Uw(0);fyA();b=c[2426824]|0;d=0;while(1){if((d|0)>=1024){e=49178;break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==(b|0)){break}else{d=d+1|0}}if((e|0)==49178){c[2426824]=0;c[2438148]=0;c[3528582]=0;a[4522344]=0;return 0}gGr(b);c[f>>2]=0;c[2426824]=0;c[2438148]=0;c[3528582]=0;a[4522344]=0;return 0}function a4X(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;if((a[9625112]|0)!=0){a6v()}c[2409128]=0;c[2409245]=0;c[2409362]=0;c[2409479]=0;c[2409508]=0;c[2409537]=0;c[2409566]=0;c[2409595]=0;gGz(9625904,0,5);b=0;d=0;e=0;f=0;g=0;h=0;do{d=((a[9634464+b|0]&1)<<b|d&255)&255;e=((a[9632224+b|0]&1)<<b|e&255)&255;f=((a[9630136+b|0]&1)<<b|f&255)&255;g=((a[9629128+b|0]&1)<<b|g&255)&255;h=((a[9551816+b|0]&1)<<b|h&255)&255;b=b+1|0;}while((b|0)<8);a[9625904]=d;a[9625905]=e;a[9625906]=f;a[9625907]=g;a[9625908]=h;h=c[2438]|0;g=h;f=(h|0)<0|0?-1:0;h=gGU(g,f,15e4,0)|0;e=gGS(h,K,256,0)|0;c[2440558]=e;e=gGU(g,f,119318,0)|0;f=gGS(e,K,256,0)|0;c[2440500]=f;c[2444002]=0;c[2444054]=0;f=c[2112964]|0;if((f|0)==0){i=0;j=0}else{gGz(f|0,0,(a[9688]|0?2136:0)|0);i=0;j=0}while(1){c[1836234]=0;f=c[2439374]|0;c[3531864]=f;gf[c[f>>2]&2047](0);f=c[2440558]|0;e=(f|0)/256|0;g=gD[c[(c[3531864]|0)+24>>2]&8191]()|0;if((f|0)<256){k=0}else{k=gj[c[(c[3531864]|0)+12>>2]&4095](e)|0}c[2444054]=(c[2444054]|0)+k;a6F(g,e,i);c[1836234]=-1;gu[c[(c[3531864]|0)+4>>2]&16383]();c[1836234]=1;e=c[2439375]|0;c[3531864]=e;gf[c[e>>2]&2047](1);e=(c[2440500]|0)/256|0;g=(ag(e,i)|0)+e|0;if((gD[c[(c[3531864]|0)+24>>2]&8191]()|0)<(g|0)){do{e=g-(gD[c[(c[3531864]|0)+24>>2]&8191]()|0)|0;if((e|0)<1){l=0}else{l=gj[c[(c[3531864]|0)+12>>2]&4095](e)|0}c[2444002]=(c[2444002]|0)+l;}while((gD[c[(c[3531864]|0)+24>>2]&8191]()|0)<(g|0))}g=c[2112964]|0;if((g|0)==0){m=j}else{e=a[9688]|0?2:0;f=g+(j<<1<<1)|0;gg[c[3542124]&4095](f,e);T1(f,e);m=e+j|0}c[1836234]=-1;gu[c[(c[3531864]|0)+4>>2]&16383]();c[3531864]=0;e=i+1|0;if((e|0)<256){i=e;j=m}else{break}}c[1836234]=1;j=c[2439375]|0;c[3531864]=j;gf[c[j>>2]&2047](1);j=c[2112964]|0;if((j|0)==0){c[1836234]=-1;n=c[3531864]|0;o=n+4|0;p=c[o>>2]|0;gu[p&16383]();c[3531864]=0;return 0}i=a[9688]|0?534:0;l=i-m|0;if((i|0)==(m|0)){c[1836234]=-1;n=c[3531864]|0;o=n+4|0;p=c[o>>2]|0;gu[p&16383]();c[3531864]=0;return 0}i=j+(m<<1<<1)|0;gg[c[3542124]&4095](i,l);T1(i,l);c[1836234]=-1;n=c[3531864]|0;o=n+4|0;p=c[o>>2]|0;gu[p&16383]();c[3531864]=0;return 0}function a4Y(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if((a[9753352]|0)==0){b=c[3530210]|0;e=c[2113070]|0;a6G(0,e);a6H();R8(b);return 0}f=c[2387294]|0;g=c[3530210]|0;h=0;do{i=h<<1;j=d[f+i|0]|0;k=d[f+(i|1)|0]|0;i=(k<<8|j)>>>2&248;c[g+(h<<2)>>2]=k>>>2&31|j<<11&63488|(i>>>5|i)<<3&2016;h=h+1|0;}while((h|0)<2048);a[9753352]=0;b=g;e=c[2113070]|0;a6G(0,e);a6H();R8(b);return 0}function a4Z(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;f=i;i=i+160|0;g=f|0;h=f+16|0;j=f+32|0;k=f+48|0;l=f+64|0;m=f+80|0;n=f+96|0;o=f+112|0;p=f+128|0;q=f+144|0;r=(e|0)==0;if(!r){c[e>>2]=169585}do{if((b&32|0)!=0){gGz(q|0,0,12);s=c[2405726]|0;c[q>>2]=s;c[q+4>>2]=(c[2411892]|0)-s;c[q+12>>2]=162152;s=c[2076592]|0;gj[s&4095](q)|0;if((b&2|0)==0){break}a[9753352]=1;s=c[3528578]|0;t=c[2386280]|0;c[s+16>>2]=t+62464;u=c[3528579]|0;c[u+16>>2]=t+63488;v=c[3528580]|0;c[v+16>>2]=t+64512;w=c[3528414]|0;x=d[w]|0;y=s|0;if((x&16|0)==0){c[y>>2]=1;c[s+4>>2]=(x<<4&64)+64}else{c[y>>2]=0}c[s+8>>2]=x&64;c[s+20>>2]=t+(x<<14&49152);x=d[w+2|0]|0;s=u|0;if((x&16|0)==0){c[s>>2]=1;c[u+4>>2]=(x<<4&64)+64}else{c[s>>2]=0}c[u+8>>2]=x&64;c[u+20>>2]=t+(x<<14&49152);x=d[w+4|0]|0;w=v|0;if((x&16|0)==0){c[w>>2]=1;c[v+4>>2]=(x<<4&64)+64}else{c[w>>2]=0}c[v+8>>2]=x&64;c[v+20>>2]=t+(x<<14&49152)}}while(0);if((b&64|0)==0){i=f;return 0}q=c[2385546]|0;if((q|0)>0){x=0;t=q;while(1){q=c[(c[9757496+(x<<2)>>2]|0)+32>>2]|0;if((q|0)==0){z=t}else{gg[q&4095](x,b);z=c[2385546]|0}q=x+1|0;if((q|0)<(z|0)){x=q;t=z}else{break}}A=g;B=h|0}else{A=g;B=h|0}c[2420428]=9668600;if(!r){c[e>>2]=169592}e=h|0;cC(e|0,155600,(h=i,i=i+8|0,c[h>>2]=0,h)|0)|0;i=h;c[g>>2]=9681712;c[g+4>>2]=320;c[g+8>>2]=0;c[g+12>>2]=e;gj[c[2076592]&4095](g)|0;gGz(m|0,0,12);c[m>>2]=9628088;c[m+4>>2]=4;c[m+12>>2]=399592;gj[c[2076592]&4095](m)|0;gGz(l|0,0,12);c[l>>2]=9708152;c[l+4>>2]=4;c[l+12>>2]=398848;gj[c[2076592]&4095](l)|0;gGz(k|0,0,12);c[k>>2]=9755584;c[k+4>>2]=4;c[k+12>>2]=397912;gj[c[2076592]&4095](k)|0;gGz(j|0,0,12);c[j>>2]=9734360;c[j+4>>2]=4;c[j+12>>2]=397256;gj[c[2076592]&4095](j)|0;gGz(n|0,0,12);c[n>>2]=9708288;c[n+4>>2]=1;c[n+12>>2]=395920;gj[c[2076592]&4095](n)|0;gGz(o|0,0,12);c[o>>2]=9708144;c[o+4>>2]=4;c[o+12>>2]=394136;gj[c[2076592]&4095](o)|0;if((c[3528582]|0)!=3){i=f;return 0}Ut(0);gGz(p|0,0,12);c[p>>2]=9762320;c[p+4>>2]=4;c[p+12>>2]=392808;gj[c[2076592]&4095](p)|0;p=c[2440580]|0;c[2440580]=-1;if((c[3528582]|0)!=3){i=f;return 0}o=(p&3)+1|0;c[2440580]=o;p=c[2386706]|0;n=p+131072|0;j=p+((o<<17)+1048576)|0;gGC(n|0,j|0,131072)|0;i=f;return 0}function a4_(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6566116+(b*112|0)>>2];c[a+104>>2]=c[6566120+(b*112|0)>>2];c[a+108>>2]=c[6566124+(b*112|0)>>2];d=0;return d|0}function a4$(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=6566016+(b*112|0);e=0;return e|0}function a40(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6567796+(b*112|0)>>2];c[a+104>>2]=c[6567800+(b*112|0)>>2];c[a+108>>2]=c[6567804+(b*112|0)>>2];d=0;return d|0}function a41(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=6567696+(b*112|0);e=0;return e|0}function a42(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7008476+(b*112|0)>>2];c[a+104>>2]=c[7008480+(b*112|0)>>2];c[a+108>>2]=c[7008484+(b*112|0)>>2];d=0;return d|0}function a43(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=7008376+(b*112|0);e=0;return e|0}function a44(){c[3528582]=3;a[4522344]=1;return a6q(1268,0,1,128,1048576,4194304)|0}function a45(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if((a[9625112]|0)!=0){a6v()}gGz(9625904,0,5);b=0;d=0;e=0;f=0;g=0;h=0;do{d=((a[9634464+b|0]&1)<<b|d&255)&255;e=((a[9632224+b|0]&1)<<b|e&255)&255;f=((a[9630136+b|0]&1)<<b|f&255)&255;g=((a[9629128+b|0]&1)<<b|g&255)&255;h=((a[9551816+b|0]&1)<<b|h&255)&255;b=b+1|0;}while((b|0)<8);a[9625904]=d;a[9625905]=e;a[9625906]=f;a[9625907]=g;a[9625908]=h;h=c[2438]|0;g=gGU(h,(h|0)<0|0?-1:0,15e4,0)|0;h=gGS(g,K,256,0)|0;c[2440558]=h;c[2444054]=0;c[1836234]=0;h=c[2439374]|0;c[3531864]=h;gf[c[h>>2]&2047](0);h=0;do{g=c[2440558]|0;if((g|0)<256){i=0}else{i=gj[c[(c[3531864]|0)+12>>2]&4095]((g|0)/256|0)|0}c[2444054]=(c[2444054]|0)+i;a6F(0,0,h);h=h+1|0;}while((h|0)<256);h=c[2112964]|0;if((h|0)==0){c[1836234]=-1;j=c[3531864]|0;k=j+4|0;l=c[k>>2]|0;gu[l&16383]();c[3531864]=0;return 0}Uu(0,h,a[9688]|0?534:0);c[1836234]=-1;j=c[3531864]|0;k=j+4|0;l=c[k>>2]|0;gu[l&16383]();c[3531864]=0;return 0}function a46(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4652140+(b*112|0)>>2];c[a+104>>2]=c[4652144+(b*112|0)>>2];c[a+108>>2]=c[4652148+(b*112|0)>>2];d=0;return d|0}function a47(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=4652040+(b*112|0);e=0;return e|0}function a48(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1037552+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function a49(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>47){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5341240+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function a5a(){return a6q(3244,45808,1,128,2097152,4194304)|0}function a5b(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2745124+(b*112|0)>>2];c[a+104>>2]=c[2745128+(b*112|0)>>2];c[a+108>>2]=c[2745132+(b*112|0)>>2];d=0;return d|0}function a5c(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=2745024+(b*112|0);e=0;return e|0}function a5d(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2727860+(b*112|0)>>2];c[a+104>>2]=c[2727864+(b*112|0)>>2];c[a+108>>2]=c[2727868+(b*112|0)>>2];d=0;return d|0}function a5e(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=2727760+(b*112|0);e=0;return e|0}function a5f(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2363148+(b*112|0)>>2];c[a+104>>2]=c[2363152+(b*112|0)>>2];c[a+108>>2]=c[2363156+(b*112|0)>>2];d=0;return d|0}function a5g(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=2363048+(b*112|0);e=0;return e|0}function a5h(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>47){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3532696+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function a5i(){return a6q(2760,2848,1,32,2097152,4194304)|0}function a5j(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2364828+(b*112|0)>>2];c[a+104>>2]=c[2364832+(b*112|0)>>2];c[a+108>>2]=c[2364836+(b*112|0)>>2];d=0;return d|0}function a5k(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=2364728+(b*112|0);e=0;return e|0}function a5l(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4799316+(b*112|0)>>2];c[a+104>>2]=c[4799320+(b*112|0)>>2];c[a+108>>2]=c[4799324+(b*112|0)>>2];d=0;return d|0}function a5m(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=4799216+(b*112|0);e=0;return e|0}function a5n(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>50){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5564840+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function a5o(){return a6q(1882,61864,1,128,1048576,2097152)|0}function a5p(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2996244+(b*112|0)>>2];c[a+104>>2]=c[2996248+(b*112|0)>>2];c[a+108>>2]=c[2996252+(b*112|0)>>2];d=0;return d|0}function a5q(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=2996144+(b*112|0);e=0;return e|0}function a5r(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2530844+(b*112|0)>>2];c[a+104>>2]=c[2530848+(b*112|0)>>2];c[a+108>>2]=c[2530852+(b*112|0)>>2];d=0;return d|0}function a5s(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=2530744+(b*112|0);e=0;return e|0}function a5t(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>49){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3675208+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function a5u(){return a6q(1882,9784,1,128,1048576,2097152)|0}function a5v(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2800708+(b*112|0)>>2];c[a+104>>2]=c[2800712+(b*112|0)>>2];c[a+108>>2]=c[2800716+(b*112|0)>>2];d=0;return d|0}function a5w(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=2800608+(b*112|0);e=0;return e|0}function a5x(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1452484+(b*112|0)>>2];c[a+104>>2]=c[1452488+(b*112|0)>>2];c[a+108>>2]=c[1452492+(b*112|0)>>2];d=0;return d|0}function a5y(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=1452384+(b*112|0);e=0;return e|0}function a5z(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2802388+(b*112|0)>>2];c[a+104>>2]=c[2802392+(b*112|0)>>2];c[a+108>>2]=c[2802396+(b*112|0)>>2];d=0;return d|0}function a5A(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=2802288+(b*112|0);e=0;return e|0}function a5B(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>50){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3882616+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function a5C(){return a6q(364,48664,1,128,1048576,1048576)|0}function a5D(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1532740+(b*112|0)>>2];c[a+104>>2]=c[1532744+(b*112|0)>>2];c[a+108>>2]=c[1532748+(b*112|0)>>2];d=0;return d|0}function a5E(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=1532640+(b*112|0);e=0;return e|0}function a5F(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1531060+(b*112|0)>>2];c[a+104>>2]=c[1531064+(b*112|0)>>2];c[a+108>>2]=c[1531068+(b*112|0)>>2];d=0;return d|0}function a5G(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=1530960+(b*112|0);e=0;return e|0}function a5H(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5636660+(b*112|0)>>2];c[a+104>>2]=c[5636664+(b*112|0)>>2];c[a+108>>2]=c[5636668+(b*112|0)>>2];d=0;return d|0}function a5I(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=5636560+(b*112|0);e=0;return e|0}function a5J(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>28){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1036768+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function a5K(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>49){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6022336+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function a5L(){return a6q(572,52736,1,128,2097152,4194304)|0}function a5M(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4336260+(b*112|0)>>2];c[a+104>>2]=c[4336264+(b*112|0)>>2];c[a+108>>2]=c[4336268+(b*112|0)>>2];d=0;return d|0}function a5N(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=4336160+(b*112|0);e=0;return e|0}function a5O(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2107596+(b*112|0)>>2];c[a+104>>2]=c[2107600+(b*112|0)>>2];c[a+108>>2]=c[2107604+(b*112|0)>>2];d=0;return d|0}function a5P(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=2107496+(b*112|0);e=0;return e|0}function a5Q(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4337940+(b*112|0)>>2];c[a+104>>2]=c[4337944+(b*112|0)>>2];c[a+108>>2]=c[4337948+(b*112|0)>>2];d=0;return d|0}function a5R(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=4337840+(b*112|0);e=0;return e|0}function a5S(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2804068+(b*112|0)>>2];c[a+104>>2]=c[2804072+(b*112|0)>>2];c[a+108>>2]=c[2804076+(b*112|0)>>2];d=0;return d|0}function a5T(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=2803968+(b*112|0);e=0;return e|0}function a5U(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>50){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3883232+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function a5V(){var a=0,b=0,d=0,e=0;a=a6q(3006,44528,1,128,2097152,4194304)|0;if((a|0)!=0){return a|0}b=c[2386298]|0;d=b+524288|0;e=b+1048576|0;gGC(d|0,e|0,131072)|0;return a|0}function a5W(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2831420+(b*112|0)>>2];c[a+104>>2]=c[2831424+(b*112|0)>>2];c[a+108>>2]=c[2831428+(b*112|0)>>2];d=0;return d|0}function a5X(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=2831320+(b*112|0);e=0;return e|0}function a5Y(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2641916+(b*112|0)>>2];c[a+104>>2]=c[2641920+(b*112|0)>>2];c[a+108>>2]=c[2641924+(b*112|0)>>2];d=0;return d|0}function a5Z(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=2641816+(b*112|0);e=0;return e|0}function a5_(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>55){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3799480+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function a5$(){return a6q(126,44528,0,32,1048576,1048576)|0}function a50(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2162204+(b*112|0)>>2];c[a+104>>2]=c[2162208+(b*112|0)>>2];c[a+108>>2]=c[2162212+(b*112|0)>>2];d=0;return d|0}function a51(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=2162104+(b*112|0);e=0;return e|0}function a52(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2906988+(b*112|0)>>2];c[a+104>>2]=c[2906992+(b*112|0)>>2];c[a+108>>2]=c[2906996+(b*112|0)>>2];d=0;return d|0}function a53(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=2906888+(b*112|0);e=0;return e|0}function a54(){return 1}function a55(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1558348+(b*112|0)>>2];c[a+104>>2]=c[1558352+(b*112|0)>>2];c[a+108>>2]=c[1558356+(b*112|0)>>2];d=0;return d|0}function a56(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=1558248+(b*112|0);e=0;return e|0}function a57(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>58){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1950072+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function a58(){return a6q(986,53136,1,128,4194304,4194304)|0}function a59(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2209844+(b*112|0)>>2];c[a+104>>2]=c[2209848+(b*112|0)>>2];c[a+108>>2]=c[2209852+(b*112|0)>>2];d=0;return d|0}function a6a(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=2209744+(b*112|0);e=0;return e|0}function a6b(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>28){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1213648+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function a6c(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>36){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3609408+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function a6d(){c[3528582]=1;return a6q(3754,7464,1,32,1048576,8388608)|0}function a6e(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2430212+(b*112|0)>>2];c[a+104>>2]=c[2430216+(b*112|0)>>2];c[a+108>>2]=c[2430220+(b*112|0)>>2];d=0;return d|0}function a6f(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=2430112+(b*112|0);e=0;return e|0}function a6g(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2620748+(b*112|0)>>2];c[a+104>>2]=c[2620752+(b*112|0)>>2];c[a+108>>2]=c[2620756+(b*112|0)>>2];d=0;return d|0}function a6h(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<21&(d|0)==0)){e=1;return e|0}c[a>>2]=2620648+(b*112|0);e=0;return e|0}function a6i(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>66){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3773520+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function a6j(){c[3528582]=2;return a6q(4352,10432,1,128,1048576,4194304)|0}function a6k(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1504564+(b*112|0)>>2];c[a+104>>2]=c[1504568+(b*112|0)>>2];c[a+108>>2]=c[1504572+(b*112|0)>>2];d=0;return d|0}function a6l(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<21&(d|0)==0)){e=1;return e|0}c[a>>2]=1504464+(b*112|0);e=0;return e|0}function a6m(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2271324+(b*112|0)>>2];c[a+104>>2]=c[2271328+(b*112|0)>>2];c[a+108>>2]=c[2271332+(b*112|0)>>2];d=0;return d|0}function a6n(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<21&(d|0)==0)){e=1;return e|0}c[a>>2]=2271224+(b*112|0);e=0;return e|0}function a6o(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1387732+(b*112|0)>>2];c[a+104>>2]=c[1387736+(b*112|0)>>2];c[a+108>>2]=c[1387740+(b*112|0)>>2];d=0;return d|0}function a6p(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<21&(d|0)==0)){e=1;return e|0}c[a>>2]=1387632+(b*112|0);e=0;return e|0}function a6q(d,e,f,g,i,j){d=d|0;e=e|0;f=f|0;g=g|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0;c[2426824]=0;c[2386298]=0;c[2386304]=1572864;c[3530962]=1703936;k=i<<1;i=k+1703936|0;c[3530728]=i;l=j<<1;j=i+l|0;m=j|0;c[3541206]=m;c[2386706]=m;m=j+1572864|0;c[2387860]=m;n=j+1581056|0;c[2439412]=n;o=j+1657856|0;p=o|0;c[2405726]=p;c[2386540]=p;p=j+1659904|0;c[2386588]=p;q=j+1661952|0;c[2386280]=q;r=j+1727488|0;c[2386300]=r;s=j+1793024|0;c[2386310]=s;t=j+1809408|0;c[2387294]=t;u=j+1813504|0;c[2440214]=u;v=j+1813506|0;c[2443734]=v;w=j+1813507|0;c[3528420]=w;x=j+1813515|0;c[3528418]=x;y=j+1813523|0;c[3528416]=y;z=j+1813531|0;c[3528414]=z;A=j+1813539|0;c[3528578]=A;B=j+1813563|0;c[3528579]=B;C=j+1813587|0;c[3528580]=C;D=j+1813611|0;E=D|0;c[2411892]=E;c[3530210]=E;E=j+1821803|0;F=E|0;c[2414444]=F;G=F;F=0;while(1){if((F|0)>=1024){break}H=9638528+(F<<2)|0;if((c[H>>2]|0)==0){I=49755;break}else{F=F+1|0}}do{if((I|0)==49755){F=gGq(G)|0;c[H>>2]=F;if((F|0)==0){break}gGz(F|0,0,G|0);c[2426824]=F;gGz(F|0,0,G|0);c[2386298]=F;c[2386304]=F+1572864;c[3530962]=F+1703936;c[3530728]=F+i;J=F+j|0;c[3541206]=J;c[2386706]=J;c[2387860]=F+m;c[2439412]=F+n;J=F+o|0;c[2405726]=J;c[2386540]=J;c[2386588]=F+p;c[2386280]=F+q;c[2386300]=F+r;c[2386310]=F+s;c[2387294]=F+t;c[2440214]=F+u;c[2443734]=F+v;c[3528420]=F+w;c[3528418]=F+x;c[3528416]=F+y;c[3528414]=F+z;c[3528578]=F+A;c[3528579]=F+B;c[3528580]=F+C;J=F+D|0;c[2411892]=J;c[3530210]=J;c[2414444]=F+E;do{if((d|0)!=0){if((gD[d&8191]()|0)==0){break}else{K=1}return K|0}}while(0);fyz(0,0,0);fyz(1,65544,14318180);c[1836234]=0;F=c[2439374]|0;c[3531864]=F;gf[c[F>>2]&2047](0);F=c[2386298]|0;J=c[3531864]|0;if((f|0)==0){L=0;while(1){c[J+44+(L<<2)>>2]=F;M=L+1|0;if((M|0)<256){L=M}else{N=0;break}}do{c[J+4140+(N<<2)>>2]=F;c[J+6188+(N<<2)>>2]=F;N=N+1|0;}while((N|0)<256);L=(c[2386280]|0)-524288|0;M=256;while(1){c[J+44+(M<<2)>>2]=L;O=M+1|0;if((O|0)<288){M=O}else{P=256;break}}while(1){c[J+2092+(P<<2)>>2]=L;M=P+1|0;if((M|0)<288){P=M}else{Q=256;break}}while(1){c[J+4140+(Q<<2)>>2]=L;c[J+6188+(Q<<2)>>2]=L;M=Q+1|0;if((M|0)<288){Q=M}else{R=J;break}}}else{L=0;while(1){c[J+44+(L<<2)>>2]=F;M=L+1|0;if((M|0)<320){L=M}else{S=0;break}}while(1){c[J+4140+(S<<2)>>2]=F;c[J+6188+(S<<2)>>2]=F;L=S+1|0;if((L|0)<320){S=L}else{T=320;break}}while(1){c[J+44+(T<<2)>>2]=F;L=T+1|0;if((L|0)<384){T=L}else{U=320;break}}do{c[J+4140+(U<<2)>>2]=F;c[J+6188+(U<<2)>>2]=F;U=U+1|0;}while((U|0)<384);L=F-786432|0;M=384;while(1){c[J+44+(M<<2)>>2]=L;O=M+1|0;if((O|0)<416){M=O}else{V=384;break}}do{c[J+4140+(V<<2)>>2]=L;c[J+6188+(V<<2)>>2]=L;V=V+1|0;}while((V|0)<416);L=(c[2386280]|0)-851968|0;M=416;while(1){c[J+44+(M<<2)>>2]=L;O=M+1|0;if((O|0)<448){M=O}else{W=416;break}}while(1){c[J+2092+(W<<2)>>2]=L;M=W+1|0;if((M|0)<448){W=M}else{X=416;break}}while(1){c[J+4140+(X<<2)>>2]=L;c[J+6188+(X<<2)>>2]=L;M=X+1|0;if((M|0)<448){X=M}else{R=J;break}}}J=(c[2386300]|0)-917504|0;L=448;while(1){c[R+44+(L<<2)>>2]=J;M=L+1|0;if((M|0)<480){L=M}else{Y=448;break}}while(1){c[R+2092+(Y<<2)>>2]=J;L=Y+1|0;if((L|0)<480){Y=L}else{Z=448;break}}do{c[R+4140+(Z<<2)>>2]=J;c[R+6188+(Z<<2)>>2]=J;Z=Z+1|0;}while((Z|0)<480);J=(c[2386540]|0)-1015808|0;c[R+2028>>2]=J;c[R+4076>>2]=J;J=F-524288|0;c[R+2088>>2]=J;c[R+6184>>2]=J;c[R+8232>>2]=J;c[R+8236>>2]=390;c[R+8240>>2]=2254;c[R+8244>>2]=630;c[R+8248>>2]=1518;c[1836234]=-1;gu[c[R+4>>2]&16383]();c[1836234]=1;J=c[2439375]|0;c[3531864]=J;gf[c[J>>2]&2047](1);do{if((e|0)!=0){J=c[(c[3531864]|0)+20>>2]|0;if((J|0)==0){break}gf[J&2047](e)}}while(0);F=c[2386304]|0;J=c[3531864]|0;L=0;while(1){c[J+44+(L<<2)>>2]=F;M=L+1|0;if((M|0)<64){L=M}else{_=0;break}}do{c[J+4140+(_<<2)>>2]=F;c[J+6188+(_<<2)>>2]=F;_=_+1|0;}while((_|0)<64);L=(c[2386310]|0)-655360|0;c[J+1324>>2]=L;c[J+1328>>2]=L;c[J+1332>>2]=L;c[J+1336>>2]=L;c[J+1340>>2]=L;c[J+1344>>2]=L;c[J+1348>>2]=L;c[J+1352>>2]=L;c[J+3372>>2]=L;c[J+3376>>2]=L;c[J+3380>>2]=L;c[J+3384>>2]=L;c[J+3388>>2]=L;c[J+3392>>2]=L;c[J+3396>>2]=L;c[J+3400>>2]=L;c[J+5420>>2]=L;c[J+7468>>2]=L;c[J+5424>>2]=L;c[J+7472>>2]=L;c[J+5428>>2]=L;c[J+7476>>2]=L;c[J+5432>>2]=L;c[J+7480>>2]=L;c[J+5436>>2]=L;c[J+7484>>2]=L;c[J+5440>>2]=L;c[J+7488>>2]=L;c[J+5444>>2]=L;c[J+7492>>2]=L;c[J+5448>>2]=L;c[J+7496>>2]=L;L=F-917504|0;c[J+2088>>2]=L;c[J+6184>>2]=L;c[J+8232>>2]=L;c[J+8236>>2]=1700;c[J+8240>>2]=1796;c[1836234]=-1;gu[c[J+4>>2]&16383]();c[3531864]=0;c[2439284]=(k-1|0)/64|0;c[2439282]=(l-1|0)/256|0;c[2429908]=g;L=a[9680]|0;M=L?32e3:0;if(L){if(a[9624]|0){L=M*3|0;O=55930;while(1){if((O|0)>(L|0)){O=O>>1}else{$=1222;aa=O;break}}}else{$=2462;aa=M}c[2429380]=aa;c[3542124]=$;mw(3579545,aa);O=gGq(262144)|0;c[2406684]=O;gGz(O|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(3579545,11025)}c[(c[3531464]|0)+44344>>2]=1052;h[745421]=.4;c[2436794]=3;h[745420]=.4;c[2436792]=3;c[2417150]=c[2386706];c[2417151]=1048576;c[2417224]=14914;h[1208613]=1.0;c[2417228]=3;c[2420428]=9668600;gGz(9668736,0,160);O=0;L=9668600;do{b[L+8+(O<<1)>>1]=0;O=O+1|0;L=c[2420428]|0}while((O|0)<64);c[2438316]=~~(+(c[L+296>>2]|0)/(a[9688]|0?534.0:0.0));c[2420428]=9668600;h[1208613]=1.0;c[2417228]=3;Ux(0,7575,0);c[2407030]=256;c[2407068]=3;O=c[642608+(c[2436]<<2)>>2]|0;M=c[O+128>>2]|0;if((c[O+52>>2]&4|0)==0){c[2113068]=M;J=c[O+132>>2]|0;c[2113070]=J;c[2443814]=M;c[2440436]=J;ab=M;ac=J}else{c[2113070]=M;J=c[O+132>>2]|0;c[2113068]=J;c[2440436]=M;c[2443814]=J;ab=J;ac=M}M=ag(ab<<1,ac)|0;J=gGq(M)|0;c[2112926]=J;if((J|0)!=0){gGz(J|0,0,M|0)}a6v();K=0;return K|0}}while(0);c[2426824]=0;K=1;return K|0}function a6r(){return a6s(1048576,262144,1048576,0,15)|0}function a6s(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;j=i;i=i+1200|0;k=j|0;l=j+112|0;m=j+120|0;n=j+232|0;o=j+240|0;p=j+352|0;q=j+360|0;r=j+472|0;s=j+480|0;t=j+592|0;u=j+600|0;v=j+712|0;w=j+720|0;x=j+832|0;y=j+840|0;z=j+952|0;A=j+960|0;B=j+1072|0;C=j+1080|0;D=j+1192|0;if((R6((c[2386298]|0)+1|0,0,2)|0)!=0){E=1;i=j;return E|0}if((R6(c[2386298]|0,1,2)|0)!=0){E=1;i=j;return E|0}if((R6((c[2386298]|0)+(b+1)|0,2,2)|0)!=0){E=1;i=j;return E|0}if((R6((c[2386298]|0)+b|0,3,2)|0)!=0){E=1;i=j;return E|0}if((R6((c[2386304]|0)+1|0,4,2)|0)!=0){E=1;i=j;return E|0}if((R6(c[2386304]|0,5,2)|0)==0){F=0}else{E=1;i=j;return E|0}while(1){if((F|0)>=1024){E=1;G=49894;break}H=9638528+(F<<2)|0;if((c[H>>2]|0)==0){break}else{F=F+1|0}}if((G|0)==49894){i=j;return E|0}F=gGq(2097152)|0;c[H>>2]=F;if((F|0)==0){E=1;i=j;return E|0}gGz(F|0,0,2097152);a6t(F,6,0,e);a6t(F,7,1,e);a6t(F,8,2,e);a6t(F,9,3,e);e=c[3530728]|0;do{if((g|0)==0){do{if((c[3542200]|0)!=0){H=A+108|0;c[H>>2]=0;b=A+100|0;c[b>>2]=0;I=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[I&16383](A,10)|0;if((c[H>>2]|0)==0){break}H=c[b>>2]|0;c[B>>2]=9534384;b=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[b&16383](B,10,0)|0;if((H|0)<1){break}gzL(F,0,10)|0}}while(0);H=(f|0)/32|0;do{if((f|0)>31){b=F;I=e;J=0;while(1){K=b;L=I;M=0;while(1){N=0;do{O=L+N|0;a[O]=((d[K+(N<<1&16)|0]|0)>>>((N&7^7)>>>0)&1|(d[O]|0))&255;N=N+1|0;}while((N|0)<16);N=M+1|0;if((N|0)<16){K=K+1|0;L=L+16|0;M=N}else{break}}M=J+1|0;if((M|0)<(H|0)){b=b+32|0;I=I+256|0;J=M}else{break}}J=c[3530728]|0;do{if((c[3542200]|0)==0){P=F;Q=J;R=0}else{I=y+108|0;c[I>>2]=0;b=y+100|0;c[b>>2]=0;M=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[M&16383](y,11)|0;if((c[I>>2]|0)==0){P=F;Q=J;R=0;break}I=c[b>>2]|0;c[z>>2]=9534384;b=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[b&16383](z,11,0)|0;if((I|0)<1){P=F;Q=J;R=0;break}gzL(F,0,11)|0;P=F;Q=J;R=0}}while(0);while(1){J=P;I=Q;b=0;while(1){M=0;do{L=I+M|0;a[L]=((d[J+(M<<1&16)|0]|0)>>>((M&7^7)>>>0)<<1&2|(d[L]|0))&255;M=M+1|0;}while((M|0)<16);M=b+1|0;if((M|0)<16){J=J+1|0;I=I+16|0;b=M}else{break}}b=R+1|0;if((b|0)<(H|0)){P=P+32|0;Q=Q+256|0;R=b}else{break}}b=c[3530728]|0;do{if((c[3542200]|0)==0){S=F;T=b;U=0}else{I=q+108|0;c[I>>2]=0;J=q+100|0;c[J>>2]=0;M=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[M&16383](q,12)|0;if((c[I>>2]|0)==0){S=F;T=b;U=0;break}I=c[J>>2]|0;c[r>>2]=9534384;J=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[J&16383](r,12,0)|0;if((I|0)<1){S=F;T=b;U=0;break}gzL(F,0,12)|0;S=F;T=b;U=0}}while(0);while(1){b=S;I=T;J=0;while(1){M=0;do{L=I+M|0;a[L]=((d[b+(M<<1&16)|0]|0)>>>((M&7^7)>>>0)<<2&4|(d[L]|0))&255;M=M+1|0;}while((M|0)<16);M=J+1|0;if((M|0)<16){b=b+1|0;I=I+16|0;J=M}else{break}}J=U+1|0;if((J|0)<(H|0)){S=S+32|0;T=T+256|0;U=J}else{break}}J=c[3530728]|0;do{if((c[3542200]|0)==0){V=F;W=J;X=0}else{I=o+108|0;c[I>>2]=0;b=o+100|0;c[b>>2]=0;M=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[M&16383](o,13)|0;if((c[I>>2]|0)==0){V=F;W=J;X=0;break}I=c[b>>2]|0;c[p>>2]=9534384;b=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[b&16383](p,13,0)|0;if((I|0)<1){V=F;W=J;X=0;break}gzL(F,0,13)|0;V=F;W=J;X=0}}while(0);while(1){J=V;I=W;b=0;while(1){M=0;do{L=I+M|0;a[L]=((d[J+(M<<1&16)|0]|0)>>>((M&7^7)>>>0)<<3&8|(d[L]|0))&255;M=M+1|0;}while((M|0)<16);M=b+1|0;if((M|0)<16){J=J+1|0;I=I+16|0;b=M}else{break}}b=X+1|0;if((b|0)<(H|0)){V=V+32|0;W=W+256|0;X=b}else{break}}}else{do{if((c[3542200]|0)!=0){b=w+108|0;c[b>>2]=0;I=w+100|0;c[I>>2]=0;J=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[J&16383](w,11)|0;if((c[b>>2]|0)==0){break}b=c[I>>2]|0;c[x>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](x,11,0)|0;if((b|0)<1){break}gzL(F,0,11)|0}}while(0);do{if((c[3542200]|0)!=0){b=u+108|0;c[b>>2]=0;I=u+100|0;c[I>>2]=0;J=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[J&16383](u,12)|0;if((c[b>>2]|0)==0){break}b=c[I>>2]|0;c[v>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](v,12,0)|0;if((b|0)<1){break}gzL(F,0,12)|0}}while(0);if((c[3542200]|0)==0){break}b=s+108|0;c[b>>2]=0;I=s+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](s,13)|0;if((c[b>>2]|0)==0){break}b=c[I>>2]|0;c[t>>2]=9534384;gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](t,13,0)|0;if((b|0)<1){break}gzL(F,0,13)|0}}while(0);H=c[2386706]|0;if((c[3542200]|0)==0){E=1;i=j;return E|0}b=m+108|0;c[b>>2]=0;I=m+100|0;c[I>>2]=0;J=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[J&16383](m,14)|0;if((c[b>>2]|0)==0){break}b=c[I>>2]|0;c[n>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](n,14,0)|0;if((b|0)<1){E=1;i=j;return E|0}if((gzL(H,0,14)|0)==0){break}else{E=1}i=j;return E|0}else{H=F+1|0;R6(H,10,2)|0;R6(F,11,2)|0;b=f<<3;I=(b|0)>0;if(I){J=0;do{M=e+J|0;a[M]=((d[F+((J|0)/8|0)|0]|0)>>>((J&7^7)>>>0)&1|(d[M]|0))&255;J=J+1|0;}while((J|0)<(b|0))}J=c[3530728]|0;R6(H,12,2)|0;R6(F,13,2)|0;if(I){M=0;do{L=J+M|0;a[L]=((d[F+((M|0)/8|0)|0]|0)>>>((M&7^7)>>>0)<<1&2|(d[L]|0))&255;M=M+1|0;}while((M|0)<(b|0))}M=c[3530728]|0;R6(H,14,2)|0;R6(F,15,2)|0;if(I){J=0;do{L=M+J|0;a[L]=((d[F+((J|0)/8|0)|0]|0)>>>((J&7^7)>>>0)<<2&4|(d[L]|0))&255;J=J+1|0;}while((J|0)<(b|0))}J=c[3530728]|0;R6(H,16,2)|0;R6(F,17,2)|0;if(I){M=0;do{L=J+M|0;a[L]=((d[F+((M|0)/8|0)|0]|0)>>>((M&7^7)>>>0)<<3&8|(d[L]|0))&255;M=M+1|0;}while((M|0)<(b|0))}b=c[2386706]|0;if((c[3542200]|0)==0){E=1;i=j;return E|0}M=C+108|0;c[M>>2]=0;J=C+100|0;c[J>>2]=0;I=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[I&16383](C,18)|0;if((c[M>>2]|0)==0){break}M=c[J>>2]|0;c[D>>2]=9534384;J=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[J&16383](D,18,0)|0;if((M|0)<1){E=1;i=j;return E|0}if((gzL(b,0,18)|0)==0){break}else{E=1}i=j;return E|0}}while(0);do{if((h|0)==0){Y=0}else{D=c[2387860]|0;if((c[3542200]|0)==0){E=1;i=j;return E|0}C=k+108|0;c[C>>2]=0;e=k+100|0;c[e>>2]=0;f=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[f&16383](k,h)|0;if((c[C>>2]|0)==0){Y=0;break}C=c[e>>2]|0;c[l>>2]=9534384;e=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[e&16383](l,h,0)|0;if((C|0)<1){E=1;i=j;return E|0}if((gzL(D,0,h)|0)==0){Y=0;break}else{E=1}i=j;return E|0}}while(0);while(1){if((Y|0)>=1024){E=0;G=49905;break}Z=9638528+(Y<<2)|0;if((c[Z>>2]|0)==(F|0)){break}else{Y=Y+1|0}}if((G|0)==49905){i=j;return E|0}gGr(F);c[Z>>2]=0;E=0;i=j;return E|0}function a6t(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=i;i=i+120|0;j=h|0;k=h+112|0;l=c[3530962]|0;do{if((c[3542200]|0)!=0){m=j+108|0;c[m>>2]=0;n=j+100|0;c[n>>2]=0;o=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[o&16383](j,e)|0;if((c[m>>2]|0)==0){break}m=c[n>>2]|0;c[k>>2]=9534384;n=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[n&16383](k,e,0)|0;if((m|0)<1){break}gzL(b,0,e)|0}}while(0);e=(g|0)/8|0;if((g|0)>7){p=b;q=l;r=0}else{i=h;return}while(1){l=p;b=q;g=0;while(1){a[b]=((d[l]|0)>>>7<<f|(d[b]|0))&255;k=b+1|0;a[k]=(((d[l]|0)>>>6&1)<<f|(d[k]|0))&255;k=b+2|0;a[k]=(((d[l]|0)>>>5&1)<<f|(d[k]|0))&255;k=b+3|0;a[k]=(((d[l]|0)>>>4&1)<<f|(d[k]|0))&255;k=b+4|0;a[k]=(((d[l]|0)>>>3&1)<<f|(d[k]|0))&255;k=b+5|0;a[k]=(((d[l]|0)>>>2&1)<<f|(d[k]|0))&255;k=b+6|0;a[k]=(((d[l]|0)>>>1&1)<<f|(d[k]|0))&255;k=b+7|0;a[k]=((a[l]&1)<<f|(d[k]|0))&255;k=g+1|0;if((k|0)<8){l=l+1|0;b=b+8|0;g=k}else{break}}g=r+1|0;if((g|0)<(e|0)){p=p+8|0;q=q+64|0;r=g}else{break}}i=h;return}function a6u(a){a=a|0;gG[c[(c[3531864]|0)+16>>2]&255](10,255,(a|0)!=0|0);gj[c[(c[3531864]|0)+12>>2]&4095](100)|0;return}function a6v(){var d=0,e=0,f=0,g=0;d=c[2405726]|0;gGz(d|0,0,(c[2411892]|0)-d|0);c[1836234]=0;d=c[2439374]|0;c[3531864]=d;gf[c[d>>2]&2047](0);gD[c[(c[3531864]|0)+8>>2]&8191]()|0;c[1836234]=-1;gu[c[(c[3531864]|0)+4>>2]&16383]();c[1836234]=1;d=c[2439375]|0;c[3531864]=d;gf[c[d>>2]&2047](1);gD[c[(c[3531864]|0)+8>>2]&8191]()|0;c[1836234]=-1;gu[c[(c[3531864]|0)+4>>2]&16383]();c[3531864]=0;mx(0);c[2420428]=9668600;gGz(9668736,0,160);b[4834304]=0;b[4834305]=0;d=2;e=9668600;while(1){b[e+8+(d<<1)>>1]=0;f=d+1|0;if((f|0)>=64){break}d=f;e=c[2420428]|0}e=c[3528582]|0;if((e|0)==3){c[2113156]=0;a[9628264]=0;c[2407033]=0;d=c[3541206]|0;c[3541190]=d;c[3541198]=d;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=d+256;c[3541199]=d+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=d+512;c[3541200]=d+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=d+768;c[3541201]=d+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2440580]=1;d=c[2386706]|0;f=d+131072|0;g=d+1179648|0;gGC(f|0,g|0,131072)|0}else if((e|0)==1){a[c[2440214]|0]=-128}a[9708288]=-128;c[2427036]=0;c[2407022]=0;e=c[2386280]|0;c[(c[3528578]|0)+16>>2]=e+62464;c[(c[3528579]|0)+16>>2]=e+63488;c[(c[3528580]|0)+16>>2]=e+64512;return}function a6w(){return a6s(524288,262144,2097152,1,0)|0}function a6x(){return a6s(1048576,1048576,1048576,1,0)|0}function a6y(){c[3528582]=1;return a6s(262144,262144,262144,0,0)|0}function a6z(){return a6s(1048576,524288,1048576,0,0)|0}function a6A(){return a6s(524288,524288,1048576,0,0)|0}function a6B(){return a6s(262144,262144,262144,0,0)|0}function a6C(){return a6s(524288,262144,524288,0,0)|0}function a6D(){return a6s(524288,524288,1048576,0,0)|0}function a6E(){return a6s(524288,524288,1048576,0,0)|0}function a6F(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;if((c[2427036]|0)!=0){g=c[2386588]|0;h=c[2386540]|0;gGC(g|0,h|0,2048)|0;h=gj[c[(c[3531864]|0)+12>>2]&4095](347)|0;c[2444054]=(c[2444054]|0)+h;a[9708288]=-128;gG[c[(c[3531864]|0)+16>>2]&255](0,((c[2429908]|0)+4|0)/4|0,1);h=c[(c[3531864]|0)+12>>2]|0;gj[h&4095](10)|0;gG[c[(c[3531864]|0)+16>>2]&255](0,((c[2429908]|0)+4|0)/4|0,0);h=e+b-(gD[c[(c[3531864]|0)+24>>2]&8191]()|0)|0;if((h|0)<1){i=0}else{i=gj[c[(c[3531864]|0)+12>>2]&4095](h)|0}c[2444054]=(c[2444054]|0)+i;c[2427036]=0}if((c[2427038]|0)==(f|0)){do{if((f-8|0)>>>0<240){i=c[2438148]|0;h=f-7|0;if((i|0)==(h|0)){break}if(i>>>0<240){a6G(i,h)}c[2438148]=h}}while(0);gG[c[(c[3531864]|0)+16>>2]&255](0,((c[2429908]|0)+8|0)/4|0,1);h=c[(c[3531864]|0)+12>>2]|0;gj[h&4095](10)|0;gG[c[(c[3531864]|0)+16>>2]&255](0,((c[2429908]|0)+8|0)/4|0,0);return}if((f|0)!=248){return}f=c[2438148]|0;if((f|0)!=240){a6G(f,240)}c[2438148]=0;if((c[2112968]|0)!=0){if((a[9753352]|0)==0){j=c[3530210]|0}else{f=c[2387294]|0;h=c[3530210]|0;i=0;do{b=i<<1;e=d[f+b|0]|0;g=d[f+(b|1)|0]|0;b=(g<<8|e)>>>2&248;c[h+(i<<2)>>2]=g>>>2&31|e<<11&63488|(b>>>5|b)<<3&2016;i=i+1|0;}while((i|0)<2048);a[9753352]=0;j=h}a6H();R8(j)}gG[c[(c[3531864]|0)+16>>2]&255](0,(c[2429908]|0)/4|0,1);gj[c[(c[3531864]|0)+12>>2]&4095](10)|0;gG[c[(c[3531864]|0)+16>>2]&255](0,(c[2429908]|0)/4|0,0);return}function a6G(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=c[2439412]|0;f=c[2113068]|0;g=ag(f,b)|0;h=d-b|0;gGz(e+g|0,0,ag(f,h)|0);if((a[(c[3528414]|0)+4|0]&16)==0){a6J(b,d,2,1);a6J(b,d,2,0)}else{e=(c[2112926]|0)+(g<<1)|0;gGz(e|0,0,ag(h<<1,f)|0)}a6J(b,d,1,1);a6J(b,d,1,0);a6J(b,d,0,1);a6J(b,d,0,0);return}function a6H(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;d=c[2386588]|0;f=a[4522344]|0?392:0;g=c[2112926]|0;h=c[3530728]|0;i=c[2439282]|0;j=c[2439412]|0;k=0;l=c[2433590]|0;while(1){if((l|0)>0){m=0;n=l;while(1){o=e[d+(m<<1)>>1]|0;p=(368-o+f&511)-8|0;q=(b[d+((m|3)<<1)>>1]&511)-96|0;r=e[d+((m|2)<<1)>>1]|0;s=r>>>6&2^130;t=e[d+((m|1)<<1)>>1]|0;u=r&256;v=r&512;w=1<<(o>>>9&3);x=1<<(o>>>11&3);y=(x<<2)+m|0;do{if((o>>>13|0)==(k|0)){if((u|0)==0){z=q}else{z=(x<<4)-16+q|0}if((x|0)<=0){A=n;break}B=w-1|0;C=(w|0)>0;D=r<<4&2032;E=(v>>>8)-1|0;F=(u>>>3^32)-16|0;if((v|0)==0){G=z;H=0;while(1){I=B+(H<<3)|0;J=G&511;if(C){K=G|-512;if(J>>>0>496){L=I;M=0;while(1){N=i&L+t;O=p-(M<<4)|0;a6I(g,h,N,D,J,O,u,0,j,s);a6I(g,h,N,D,K,O,u,0,j,s);O=M+1|0;if((O|0)<(w|0)){L=L+E|0;M=O}else{break}}}else{M=I;L=0;while(1){a6I(g,h,i&M+t,D,J,p-(L<<4)|0,u,0,j,s);K=L+1|0;if((K|0)<(w|0)){M=M+E|0;L=K}else{break}}}}L=H+1|0;if((L|0)<(x|0)){G=J+F|0;H=L}else{break}}}else{H=z;G=0;while(1){B=G<<3;L=H&511;if(C){M=H|-512;if(L>>>0>496){I=B;K=0;while(1){O=i&I+t;N=p-(K<<4)|0;a6I(g,h,O,D,L,N,u,v,j,s);a6I(g,h,O,D,M,N,u,v,j,s);N=K+1|0;if((N|0)<(w|0)){I=I+E|0;K=N}else{break}}}else{K=B;I=0;while(1){a6I(g,h,i&K+t,D,L,p-(I<<4)|0,u,v,j,s);M=I+1|0;if((M|0)<(w|0)){K=K+E|0;I=M}else{break}}}}I=G+1|0;if((I|0)<(x|0)){H=L+F|0;G=I}else{break}}}A=c[2433590]|0}else{A=n}}while(0);if((y|0)<(A|0)){m=y;n=A}else{P=A;break}}}else{P=l}n=k+1|0;if((n|0)<8){k=n;l=P}else{break}}return}function a6I(e,f,g,h,i,j,k,l,m,n){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;o=c[2113068]|0;p=c[2113070]|0;if(!((p|0)>(j|0)&(((o|0)<=(i|0)|(i|0)<-15|(j|0)<-15)^1))){return}q=(l|0)==0?0:240;l=(k|0)==0?q:q|15;q=g<<8;g=j;j=0;while(1){if((g|0)>-1&(g|0)<(p|0)){k=j<<4;r=ag(o,g)|0;s=i;t=0;while(1){do{if((s|0)>=0&(s|0)<(o|0)){u=a[f+((t+k^l)+q)|0]|0;if(u<<24>>24==0){break}v=r+s|0;w=m+v|0;if((1<<(d[w]|0)&n|0)!=0){break}b[e+(v<<1)>>1]=(u&255|h)&65535;a[w]=7}}while(0);w=t+1|0;if((w|0)<16){s=s+1|0;t=w}else{break}}}t=j+1|0;if((t|0)>=16){break}g=g+1|0;j=t}return}function a6J(f,g,h,i){f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;j=c[14114312+(h<<2)>>2]|0;if((c[j>>2]|0)==0){return}k=c[j+4>>2]|0;l=(e[j+14>>1]|0)+136+(a[4522344]|0?-120:0)|0;m=80-(h<<1)+(k<<1&256)+(e[j+12>>1]|0)|0;if((f|0)>=(g|0)){return}n=j+8|0;o=k-1|0;p=j+20|0;q=1<<i&255;r=j+16|0;j=c[2113068]|0;s=c[2112926]|0;t=c[2439412]|0;u=c[3530962]|0;v=c[2439284]|0;w=j+8|0;x=f;do{f=ag(x,j)|0;y=l+x|0;if((c[n>>2]|0)==0){z=m}else{z=(e[(c[r>>2]|0)+((y&511)<<1)>>1]|0)+m|0}A=y<<3&56;if((j+8|0)>0){B=ag(y>>>3&63,k)|0;y=A^56;C=z&7;D=0;do{E=(((D+z|0)/8|0)&o)+B<<1;F=c[p>>2]|0;G=e[F+((E|1)<<1)>>1]|0;H=G<<4&2032;if((G&384|0)==0){I=0}else{I=(G>>>8&1)+1|0}J=(G&512|0)==0?0:7;K=(v&(G<<1&65536|(e[F+(E<<1)>>1]|0)))<<6|((G&1024|0)==0?A:y);G=e[598088+(h*12|0)+(I<<2)+(i<<1)>>1]|0;E=D-C|0;F=0;while(1){do{if((E|0)>-1&(E|0)<(j|0)){L=d[u+((F^J)+K)|0]|0;if((1<<L&G|0)!=0){break}M=E+f|0;b[s+(M<<1)>>1]=(L|H)&65535;a[t+M|0]=q}}while(0);M=F+1|0;if((M|0)>=8){break}E=E+1|0;F=M}D=D+8|0;}while((D|0)<(w|0))}x=x+1|0;}while((x|0)<(g|0));return}function a6K(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0;b=i;i=i+1080|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;l=b+360|0;m=b+472|0;n=b+480|0;o=b+592|0;p=b+600|0;q=b+712|0;r=b+720|0;s=b+832|0;t=b+840|0;u=b+952|0;v=b+960|0;w=b+1072|0;if((R6((c[2386298]|0)+1|0,0,2)|0)!=0){x=1;i=b;return x|0}if((R6(c[2386298]|0,1,2)|0)==0){y=0}else{x=1;i=b;return x|0}while(1){if((y|0)>=1024){x=1;z=50112;break}A=9638528+(y<<2)|0;if((c[A>>2]|0)==0){break}else{y=y+1|0}}if((z|0)==50112){i=b;return x|0}y=gGq(524288)|0;c[A>>2]=y;if((y|0)==0){x=1;i=b;return x|0}gGz(y|0,0,524288);a6t(y,2,0,262144);a6t(y,3,1,262144);a6t(y,4,2,262144);a6t(y,5,3,262144);A=(c[3530728]|0)+4194304|0;c[3530728]=A;do{if((c[3542200]|0)==0){B=y;C=A;D=0}else{E=v+108|0;c[E>>2]=0;F=v+100|0;c[F>>2]=0;G=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[G&16383](v,7)|0;if((c[E>>2]|0)==0){B=y;C=A;D=0;break}E=c[F>>2]|0;c[w>>2]=9534384;F=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[F&16383](w,7,0)|0;if((E|0)<1){B=y;C=A;D=0;break}gzL(y,0,7)|0;B=y;C=A;D=0}}while(0);while(1){A=B;w=C;v=0;while(1){E=0;do{F=w+E|0;a[F]=((d[A+(E<<1&16)|0]|0)>>>((E&7^7)>>>0)&1|(d[F]|0))&255;E=E+1|0;}while((E|0)<16);E=v+1|0;if((E|0)<16){A=A+1|0;w=w+16|0;v=E}else{break}}v=D+1|0;if((v|0)<16384){B=B+32|0;C=C+256|0;D=v}else{break}}D=c[3530728]|0;do{if((c[3542200]|0)==0){H=y;I=D;J=0}else{C=t+108|0;c[C>>2]=0;B=t+100|0;c[B>>2]=0;v=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[v&16383](t,9)|0;if((c[C>>2]|0)==0){H=y;I=D;J=0;break}C=c[B>>2]|0;c[u>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](u,9,0)|0;if((C|0)<1){H=y;I=D;J=0;break}gzL(y,0,9)|0;H=y;I=D;J=0}}while(0);while(1){D=H;u=I;t=0;while(1){C=0;do{B=u+C|0;a[B]=((d[D+(C<<1&16)|0]|0)>>>((C&7^7)>>>0)<<1&2|(d[B]|0))&255;C=C+1|0;}while((C|0)<16);C=t+1|0;if((C|0)<16){D=D+1|0;u=u+16|0;t=C}else{break}}t=J+1|0;if((t|0)<16384){H=H+32|0;I=I+256|0;J=t}else{break}}J=c[3530728]|0;do{if((c[3542200]|0)==0){K=y;L=J;M=0}else{I=r+108|0;c[I>>2]=0;H=r+100|0;c[H>>2]=0;t=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[t&16383](r,11)|0;if((c[I>>2]|0)==0){K=y;L=J;M=0;break}I=c[H>>2]|0;c[s>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](s,11,0)|0;if((I|0)<1){K=y;L=J;M=0;break}gzL(y,0,11)|0;K=y;L=J;M=0}}while(0);while(1){J=K;s=L;r=0;while(1){I=0;do{H=s+I|0;a[H]=((d[J+(I<<1&16)|0]|0)>>>((I&7^7)>>>0)<<2&4|(d[H]|0))&255;I=I+1|0;}while((I|0)<16);I=r+1|0;if((I|0)<16){J=J+1|0;s=s+16|0;r=I}else{break}}r=M+1|0;if((r|0)<16384){K=K+32|0;L=L+256|0;M=r}else{break}}M=c[3530728]|0;do{if((c[3542200]|0)==0){N=y;O=M;P=0}else{L=p+108|0;c[L>>2]=0;K=p+100|0;c[K>>2]=0;r=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[r&16383](p,13)|0;if((c[L>>2]|0)==0){N=y;O=M;P=0;break}L=c[K>>2]|0;c[q>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](q,13,0)|0;if((L|0)<1){N=y;O=M;P=0;break}gzL(y,0,13)|0;N=y;O=M;P=0}}while(0);while(1){M=N;q=O;p=0;while(1){L=0;do{K=q+L|0;a[K]=((d[M+(L<<1&16)|0]|0)>>>((L&7^7)>>>0)<<3&8|(d[K]|0))&255;L=L+1|0;}while((L|0)<16);L=p+1|0;if((L|0)<16){M=M+1|0;q=q+16|0;p=L}else{break}}p=P+1|0;if((p|0)<16384){N=N+32|0;O=O+256|0;P=p}else{break}}P=(c[3530728]|0)-4194304|0;c[3530728]=P;do{if((c[3542200]|0)==0){Q=y;R=P;S=0}else{O=n+108|0;c[O>>2]=0;N=n+100|0;c[N>>2]=0;p=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[p&16383](n,6)|0;if((c[O>>2]|0)==0){Q=y;R=P;S=0;break}O=c[N>>2]|0;c[o>>2]=9534384;N=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[N&16383](o,6,0)|0;if((O|0)<1){Q=y;R=P;S=0;break}gzL(y,0,6)|0;Q=y;R=P;S=0}}while(0);while(1){P=Q;o=R;n=0;while(1){O=0;do{N=o+O|0;a[N]=((d[P+(O<<1&16)|0]|0)>>>((O&7^7)>>>0)&1|(d[N]|0))&255;O=O+1|0;}while((O|0)<16);O=n+1|0;if((O|0)<16){P=P+1|0;o=o+16|0;n=O}else{break}}n=S+1|0;if((n|0)<16384){Q=Q+32|0;R=R+256|0;S=n}else{break}}S=c[3530728]|0;do{if((c[3542200]|0)==0){T=y;U=S;V=0}else{R=l+108|0;c[R>>2]=0;Q=l+100|0;c[Q>>2]=0;n=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[n&16383](l,8)|0;if((c[R>>2]|0)==0){T=y;U=S;V=0;break}R=c[Q>>2]|0;c[m>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](m,8,0)|0;if((R|0)<1){T=y;U=S;V=0;break}gzL(y,0,8)|0;T=y;U=S;V=0}}while(0);while(1){S=T;m=U;l=0;while(1){R=0;do{Q=m+R|0;a[Q]=((d[S+(R<<1&16)|0]|0)>>>((R&7^7)>>>0)<<1&2|(d[Q]|0))&255;R=R+1|0;}while((R|0)<16);R=l+1|0;if((R|0)<16){S=S+1|0;m=m+16|0;l=R}else{break}}l=V+1|0;if((l|0)<16384){T=T+32|0;U=U+256|0;V=l}else{break}}V=c[3530728]|0;do{if((c[3542200]|0)==0){W=y;X=V;Y=0}else{U=j+108|0;c[U>>2]=0;T=j+100|0;c[T>>2]=0;l=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[l&16383](j,10)|0;if((c[U>>2]|0)==0){W=y;X=V;Y=0;break}U=c[T>>2]|0;c[k>>2]=9534384;T=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[T&16383](k,10,0)|0;if((U|0)<1){W=y;X=V;Y=0;break}gzL(y,0,10)|0;W=y;X=V;Y=0}}while(0);while(1){V=W;k=X;j=0;while(1){U=0;do{T=k+U|0;a[T]=((d[V+(U<<1&16)|0]|0)>>>((U&7^7)>>>0)<<2&4|(d[T]|0))&255;U=U+1|0;}while((U|0)<16);U=j+1|0;if((U|0)<16){V=V+1|0;k=k+16|0;j=U}else{break}}j=Y+1|0;if((j|0)<16384){W=W+32|0;X=X+256|0;Y=j}else{break}}Y=c[3530728]|0;do{if((c[3542200]|0)==0){Z=y;_=Y;$=0}else{X=g+108|0;c[X>>2]=0;W=g+100|0;c[W>>2]=0;j=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[j&16383](g,12)|0;if((c[X>>2]|0)==0){Z=y;_=Y;$=0;break}X=c[W>>2]|0;c[h>>2]=9534384;W=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[W&16383](h,12,0)|0;if((X|0)<1){Z=y;_=Y;$=0;break}gzL(y,0,12)|0;Z=y;_=Y;$=0}}while(0);while(1){Y=Z;h=_;g=0;while(1){X=0;do{W=h+X|0;a[W]=((d[Y+(X<<1&16)|0]|0)>>>((X&7^7)>>>0)<<3&8|(d[W]|0))&255;X=X+1|0;}while((X|0)<16);X=g+1|0;if((X|0)<16){Y=Y+1|0;h=h+16|0;g=X}else{break}}g=$+1|0;if((g|0)<16384){Z=Z+32|0;_=_+256|0;$=g}else{break}}$=(c[2386706]|0)+1048576|0;if((c[3542200]|0)==0){x=1;i=b;return x|0}_=e+108|0;c[_>>2]=0;Z=e+100|0;c[Z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,14)|0;do{if((c[_>>2]|0)!=0){e=c[Z>>2]|0;c[f>>2]=9534384;g=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[g&16383](f,14,0)|0;if((e|0)<1){x=1;i=b;return x|0}if((gzL($,0,14)|0)==0){break}else{x=1}i=b;return x|0}}while(0);$=c[2386706]|0;f=$+1048576|0;gGC($|0,f|0,262144)|0;f=0;while(1){if((f|0)>=1024){break}aa=9638528+(f<<2)|0;if((c[aa>>2]|0)==(y|0)){z=50107;break}else{f=f+1|0}}if((z|0)==50107){gGr(y);c[aa>>2]=0}c[2386588]=c[2386540];x=0;i=b;return x|0}function a6L(){return a6s(524288,262144,1048576,0,0)|0}function a6M(b,d){b=b|0;d=d|0;switch(b&65535|0){case 61440:{a[c[2432940]|0]=d<<24>>24!=0|0;return};case 61443:{a[c[2440370]|0]=d&1;return};case 63491:{fJ$(1);return};case 63488:{a[c[3528382]|0]=d;return};case 61442:{a[c[3528780]|0]=d&1^1;return};default:{return}}}function a6N(b){b=b|0;var d=0;switch(b&65535|0){case 61440:{d=a[c[2440212]|0]|0;break};case 63490:case 61443:{d=a[9635744]|0;break};case 63488:case 61441:{d=a[9551032]|0;break};case 63494:{d=a[9635745]|0;break};case 63489:case 61442:{d=a[9551033]|0;break};default:{d=0}}return d|0}function a6O(b,d){b=b|0;d=d|0;switch(b&65535|0){case 61440:{fJ$(1);return};case 63489:{a[c[2432940]|0]=d<<24>>24!=0|0;return};case 63495:{b=d&255;if((b&1|0)==0){return}c[1835288]=b<<8&61440;c[3528402]=0;return};case 61442:{a[c[3528382]|0]=d;return};case 63490:{a[c[3528780]|0]=d<<24>>24!=0|0;return};default:{return}}}function a6P(b){b=b|0;return a[(c[3527448]|0)+(b&4095)|0]|0}function a6Q(b,d){b=b|0;d=d|0;var e=0,f=0;if((b&65280|0)!=0){if((b|0)==257){a[9762400]=d;return}else if((b|0)==258){a[9762392]=d;if((d&-16)<<24>>24!=80){return}a[9718248]=0;return}else{return}}d=a[9762392]&240;if((d|0)==160){e=b&255;f=c[3542228]|0;if((f|0)>15){return}do{if((f|0)<14){if((f|0)!=13){if((a[14168916+f|0]|0)==(b&255)<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(0,f,e);return}else if((d|0)==224){c[3542228]=b&15;return}else{e=a[9762400]&224;f=(c[2385228]|0)!=240;if((e|0)==96&f){c[3542291]=b&15;return}if(!((e|0)==64&f)){if((d|0)!=112){return}a[c[2440212]|0]=b&255;return}d=b&255;f=c[3542291]|0;if((f|0)>15){return}do{if((f|0)<14){if((f|0)!=13){if((a[14169168+f|0]|0)==(b&255)<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(1,f,d);return}}function a6R(b){b=b|0;var e=0,f=0;if((b&65280|0)!=0){if((b|0)!=273|(a[9541200]|0)==0){e=0;return e|0}a[9541200]=0;e=1;return e|0}f=a[9762392]&240;if((f|0)==112){e=a[(c[2386704]|0)+(d[9762400]<<8&7936|b&255)|0]|0;return e|0}else if((f|0)==96){e=a[c[3528382]|0]|0;return e|0}else{e=-1;return e|0}return 0}function a6S(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2088276+(b*112|0)>>2];c[a+104>>2]=c[2088280+(b*112|0)>>2];c[a+108>>2]=c[2088284+(b*112|0)>>2];d=0;return d|0}function a6T(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=2088176+(b*112|0);e=0;return e|0}function a6U(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1173968+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function a6V(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>56){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3247248+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function a6W(){return a69(8050,4882,238,256,60)|0}function a6X(){var a=0,b=0,d=0,e=0;c[2113070]=0;c[2113068]=0;a=c[2112926]|0;if((a|0)!=0){gGr(a);c[2112926]=0}fwZ();a=c[2426620]|0;if((a|0)!=0){gGr(a);c[2426620]=0}c[2440608]=0;c[2113008]=0;c[2076598]=0;c[2383582]=0;a=c[2415116]|0;b=0;while(1){if((b|0)>=1024){d=50240;break}e=9638528+(b<<2)|0;if((c[e>>2]|0)==(a|0)){break}else{b=b+1|0}}if((d|0)==50240){c[2415116]=0;return 0}gGr(a);c[e>>2]=0;c[2415116]=0;return 0}function a6Y(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0.0,l=0.0,m=0.0,n=0,o=0.0,p=0,q=0.0,r=0.0,s=0;if((a[9625104]|0)!=0){e=c[2414824]|0;gGz(e|0,0,(c[2411890]|0)-e|0);e=c[2439330]|0;f=(e|0)==0;if(!f){g=e;gGC(9706056,g|0,76)|0}g=c[2438118]|0;c[2433530]=g;h=c[3528484]|0;c[2076596]=h;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);if(!f){f=e;gGC(f|0,9706056,76)|0}c[2438118]=g;c[3528484]=h;c[2417276]=i;c[1836236]=-1;b[4859110]=0;a[9718225]=0;a[9718224]=0;a[9718226]=8;a[9718229]=-1;a[9718230]=-1;a[9718227]=0;a[9718237]=0;a[9718236]=0;a[9718249]=0;a[9718238]=0;gGz(9718242,0,6);mB(0);mB(1);a[9762400]=0;a[9762392]=0;a[9541200]=0;c[3528402]=0;c[1835288]=-1;a[9548072]=1}b[4775516]=0;i=0;h=0;g=0;do{h=((a[9634456+i|0]&1)<<i^h&255)&255;g=((a[9632216+i|0]&1)<<i^g&255)&255;i=i+1|0;}while((i|0)<8);a[9551032]=h;a[9551033]=g;g=c[2439330]|0;if((g|0)!=0){h=g;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;h=1;i=g;while(1){if((a[i+4188|0]|0)==0){g=gfc(500)|0;j=(c[2433530]|0)+g|0}else{j=(c[2433530]|0)+500|0}c[2433530]=j;fJ_(500)|0;if((h|0)>=100){break}h=h+1|0;i=c[9757320+(c[1836236]<<2)>>2]|0}do{if((c[2427086]|0)==30){if((c[2113222]&1|0)==0){break}a[9541200]=1}else{a[9541200]=1}}while(0);if((a[c[2432940]|0]|0)!=0){if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12}i=c[1836236]|0;h=c[9757320+(i<<2)>>2]|0;if((h|0)!=0){j=h;gGC(j|0,9706056,76)|0}c[9752472+(i<<2)>>2]=c[2433530];c[14113936+(i<<2)>>2]=c[2076596];c[9669104+(i<<2)>>2]=c[3541536];c[1836236]=-1;i=c[2112964]|0;do{if((i|0)!=0){j=a[9688]|0;h=j?534:0;mF(9756744,i,h,0);g=c[1835288]|0;if((g|0)==-1){break}k=+((c[3528402]|0)+g|0);l=8.0e3/(a[9680]|0?32.0e3:0.0);L64198:do{if(j){g=c[2443482]|0;f=0;m=k;while(1){e=~~m;if(m>=40960.0){n=e;o=m;break L64198}p=d[g+e|0]<<8^-32768;e=i+(f<<1)|0;b[e>>1]=p+(b[e>>1]|0)&65535;e=i+((f|1)<<1)|0;b[e>>1]=p+(b[e>>1]|0)&65535;e=f+2|0;q=l+m;if((e|0)<(h|0)){f=e;m=q}else{r=q;s=50272;break}}}else{r=k;s=50272}}while(0);if((s|0)==50272){n=~~r;o=r}c[3528402]=n;if(o<40960.0){break}c[1835288]=-1}}while(0);if((c[2112968]|0)==0){return 0}a6Z()|0;return 0}function a6Z(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;if((a[9548072]|0)!=0){b=c[3531054]|0;e=c[3530208]|0;f=0;while(1){g=d[b+f|0]|0;h=d[b+(f+256)|0]|0;i=d[b+(f+512)|0]|0;c[e+(f<<2)>>2]=(-(h>>>1&1)&31)+(-(h&1)&14)+(-(h>>>2&1)&67)+(-(h>>>3&1)&143)<<3&2016|(-(g>>>1&1)&31)+(-(g&1)&14)+(-(g>>>2&1)&67)+(-(g>>>3&1)&143)<<8&63488|((-(i>>>1&1)&31)+(-(i&1)&14)+(-(i>>>2&1)&67)+(-(i>>>3&1)&143)|0)>>>3&31;i=f+1|0;if((i|0)<256){f=i}else{j=0;break}}do{f=d[b+(j+768)|0]|0;c[e+(j+256<<2)>>2]=(-(f>>>3&1)&33)+(-(f>>>4&1)&71)+(-(f>>>5&1)&151)<<3&2016|((-(f>>>6&1)&79)+(-(f>>>7)&168)|0)>>>3&31|(-(f>>>1&1)&71)+(-(f&1)&33)+(-(f>>>2&1)&151)<<8&63488;j=j+1|0;}while((j|0)<4);a[9548072]=0}j=c[2386742]|0;e=c[2387896]|0;b=c[3529480]|0;f=c[2440370]|0;i=c[3528780]|0;g=c[2112926]|0;h=c[3530726]|0;k=c[2113070]|0;l=0;do{m=l<<3&248;n=(l>>5<<3)-16-(d[j+m|0]|0)|0;o=(n|0)<-7?n+256|0:n;do{if((o|0)<(k|0)){n=d[e+l|0]|0;p=d[b+l|0]|n<<4&768;q=d[f]<<4|n&15;if((a[i]|0)==0){Sj(g,p,m,o,q,3,0,h);break}else{Sp(g,p,248-m|0,216-o|0,q,3,0,h);break}}}while(0);l=l+1|0;}while((l|0)<1024);l=c[2386538]|0;h=c[2385228]|0;b=0;do{e=d[l+(b|3)|0]|0;k=d[l+(b|2)|0]|0;j=k<<4&256|d[l+(b|1)|0];o=h-(d[l+b|0]|0)-16|0;m=d[f]<<4|k&15;q=k&32;if((a[i]|0)==0){r=0;s=q;t=o;u=e}else{r=1;s=q>>>5^1;t=h-o|0;u=240-e|0}a7e(j,m,u,t,s,r);if((u|0)>240){a7e(j,m,u,t,s,r)}b=b+4|0;}while((b|0)<256);b=c[3529446]|0;r=c[2430502]|0;s=c[3530960]|0;t=64;do{u=t<<3&248;h=t>>5<<3;f=d[b+t|0]|0;if((a[i]|0)==0){Sq(g,f,u,h-16|0,0,2,0,r,s)}else{Sw(g,f,248-u|0,232-h|0,0,2,0,r,s)}t=t+1|0;}while((t|0)<960);R8(c[3530208]|0);return 0}function a6_(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=i;i=i+176|0;e=d|0;f=d+16|0;g=d+32|0;h=d+48|0;j=d+80|0;k=d+96|0;l=d+112|0;m=d+128|0;n=d+144|0;o=d+160|0;p=(b|0)==0;if(!p){c[b>>2]=169730}if((a&96|0)==0){i=d;return 0}gGz(o|0,0,12);q=c[2414824]|0;c[o>>2]=q;c[o+4>>2]=(c[2411890]|0)-q;c[o+12>>2]=162152;gj[c[2076592]&4095](o)|0;fw$(a);o=d+64|0;if(!p){c[b>>2]=169753}q=(a&64|0)==0;if(!q){gGz(g|0,0,12);c[g>>2]=9718216;c[g+4>>2]=56;c[g+12>>2]=164080;a=c[2076592]|0;gj[a&4095](g)|0;gGC(o|0,501144,9)|0;gGz(h|0,0,12);c[h>>2]=c[2426620];c[h+4>>2]=128;c[h+12>>2]=o;g=c[2076592]|0;gj[g&4095](h)|0;gGz(f|0,0,12);c[f>>2]=9762432;c[f+4>>2]=4;c[f+12>>2]=385208;h=c[2076592]|0;gj[h&4095](f)|0}do{if(!q){do{if(!p){if((c[b>>2]|0)>=169110){break}c[b>>2]=169110}}while(0);if((c[2113008]|0)<=0){break}f=e|0;h=e+4|0;g=e+8|0;a=e+12|0;r=0;do{cC(o|0,531144,(s=i,i=i+8|0,c[s>>2]=r,s)|0)|0;i=s;c[f>>2]=14168888+(r*252|0);c[h>>2]=252;c[g>>2]=0;c[a>>2]=o;gj[c[2076592]&4095](e)|0;r=r+1|0;}while((r|0)<(c[2113008]|0))}}while(0);gGz(n|0,0,12);c[n>>2]=9762400;c[n+4>>2]=1;c[n+12>>2]=150832;gj[c[2076592]&4095](n)|0;gGz(m|0,0,12);c[m>>2]=9762392;c[m+4>>2]=1;c[m+12>>2]=147736;gj[c[2076592]&4095](m)|0;gGz(l|0,0,12);c[l>>2]=9541200;c[l+4>>2]=1;c[l+12>>2]=143384;gj[c[2076592]&4095](l)|0;gGz(k|0,0,12);c[k>>2]=14113608;c[k+4>>2]=4;c[k+12>>2]=140648;gj[c[2076592]&4095](k)|0;gGz(j|0,0,12);c[j>>2]=7341152;c[j+4>>2]=4;c[j+12>>2]=138088;gj[c[2076592]&4095](j)|0;i=d;return 0}function a6$(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4824244+(b*112|0)>>2];c[a+104>>2]=c[4824248+(b*112|0)>>2];c[a+108>>2]=c[4824252+(b*112|0)>>2];d=0;return d|0}function a60(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=4824144+(b*112|0);e=0;return e|0}function a61(){return a69(8050,4882,238,256,30)|0}function a62(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3129172+(b*112|0)>>2];c[a+104>>2]=c[3129176+(b*112|0)>>2];c[a+108>>2]=c[3129180+(b*112|0)>>2];d=0;return d|0}function a63(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=3129072+(b*112|0);e=0;return e|0}function a64(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>24){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2860268+(b*112|0)>>2];c[a+104>>2]=c[2860272+(b*112|0)>>2];c[a+108>>2]=c[2860276+(b*112|0)>>2];d=0;return d|0}function a65(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<25&(d|0)==0)){e=1;return e|0}c[a>>2]=2860168+(b*112|0);e=0;return e|0}function a66(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1271368+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function a67(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3962176+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function a68(){var a=0;a=a69(3014,4152,240,16,30)|0;h[1771269]=1.0;c[3542574]=3;h[1771270]=1.0;c[3542575]=3;h[1771271]=1.0;c[3542576]=3;return a|0}function a69(e,f,g,i,j){e=e|0;f=f|0;g=g|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0.0,H=0,I=0,J=0,K=0;c[2415116]=0;c[2386020]=0;c[3527448]=65536;c[3530960]=131072;c[3530726]=163840;c[3530492]=229376;c[2443482]=360448;c[2386704]=425984;c[3531054]=434176;c[3530208]=435200;c[2414824]=436240;c[3529352]=436240;c[3529308]=440336;c[3529480]=440848;c[3529446]=441872;c[2387896]=442896;c[2386538]=443920;c[2386742]=444176;c[3528382]=444432;c[2432940]=444433;c[3528780]=444434;c[2440370]=444435;c[2440212]=444436;c[2411890]=444437;k=a[9688]|0?534:0;l=k<<1;c[2439186]=444437;m=l+444437|0;c[2439187]=m;n=m+l|0;c[2439188]=n;m=n+l|0;c[2439189]=m;n=m+l|0;c[2439190]=n;c[2439191]=n+l;l=(k*12|0)+444437|0;c[2414442]=l;k=l;l=0;while(1){if((l|0)>=1024){break}o=9638528+(l<<2)|0;if((c[o>>2]|0)==0){p=50378;break}else{l=l+1|0}}do{if((p|0)==50378){l=gGq(k)|0;c[o>>2]=l;if((l|0)==0){break}gGz(l|0,0,k|0);c[2415116]=l;gGz(l|0,0,k|0);c[2386020]=l;c[3527448]=l+65536;c[3530960]=l+131072;c[3530726]=l+163840;c[3530492]=l+229376;c[2443482]=l+360448;c[2386704]=l+425984;c[3531054]=l+434176;c[3530208]=l+435200;n=l+436240|0;c[2414824]=n;c[3529352]=n;c[3529308]=l+440336;c[3529480]=l+440848;c[3529446]=l+441872;c[2387896]=l+442896;c[2386538]=l+443920;c[2386742]=l+444176;c[3528382]=l+444432;c[2432940]=l+444433;c[3528780]=l+444434;c[2440370]=l+444435;c[2440212]=l+444436;n=l+444437|0;c[2411890]=n;m=a[9688]|0?534:0;q=m<<1;c[2439186]=n;n=q+444437|0;c[2439187]=l+n;r=n+q|0;c[2439188]=l+r;n=r+q|0;c[2439189]=l+n;r=n+q|0;c[2439190]=l+r;c[2439191]=l+(r+q);c[2414442]=l+((m*12|0)+444437);if((gD[f&8191]()|0)==0){s=0}else{t=1;return t|0}while(1){if((s|0)>=1024){break}u=9638528+(s<<2)|0;if((c[u>>2]|0)==0){p=50383;break}else{s=s+1|0}}L64339:do{if((p|0)==50383){m=gGq(49152)|0;c[u>>2]=m;if((m|0)==0){break}gGz(m|0,0,49152);l=c[3530960]|0;gGC(m|0,l|0,8192)|0;q=0;do{r=q<<6;gGz(l+r|0,0,64);n=r+32768|0;v=0;while(1){w=n+(c[609008+(v<<2)>>2]|0)|0;x=(v<<3)+r|0;y=0;do{z=w+(c[612992+(y<<2)>>2]|0)|0;if(((d[m+((z|0)/8|0)|0]|0)&128>>>((z&7)>>>0)|0)!=0){z=l+(x+y)|0;a[z]=a[z]|2}y=y+1|0;}while((y|0)<8);y=v+1|0;if((y|0)<8){v=y}else{A=0;break}}do{v=r+(c[609008+(A<<2)>>2]|0)|0;n=(A<<3)+r|0;y=0;do{x=v+(c[612992+(y<<2)>>2]|0)|0;if(((d[m+((x|0)/8|0)|0]|0)&128>>>((x&7)>>>0)|0)!=0){x=l+(n+y)|0;a[x]=a[x]|1}y=y+1|0;}while((y|0)<8);A=A+1|0;}while((A|0)<8);q=q+1|0;}while((q|0)<256);q=c[3530726]|0;gGC(m|0,q|0,24576)|0;l=0;do{r=l<<6;gGz(q+r|0,0,64);y=r+131072|0;n=0;do{v=y+(c[609008+(n<<2)>>2]|0)|0;x=(n<<3)+r|0;w=0;do{z=v+(c[612992+(w<<2)>>2]|0)|0;if(((d[m+((z|0)/8|0)|0]|0)&128>>>((z&7)>>>0)|0)!=0){z=q+(x+w)|0;a[z]=a[z]|4}w=w+1|0;}while((w|0)<8);n=n+1|0;}while((n|0)<8);n=r+65536|0;y=0;while(1){w=n+(c[609008+(y<<2)>>2]|0)|0;x=(y<<3)+r|0;v=0;do{z=w+(c[612992+(v<<2)>>2]|0)|0;if(((d[m+((z|0)/8|0)|0]|0)&128>>>((z&7)>>>0)|0)!=0){z=q+(x+v)|0;a[z]=a[z]|2}v=v+1|0;}while((v|0)<8);v=y+1|0;if((v|0)<8){y=v}else{B=0;break}}do{y=r+(c[609008+(B<<2)>>2]|0)|0;n=(B<<3)+r|0;v=0;do{x=y+(c[612992+(v<<2)>>2]|0)|0;if(((d[m+((x|0)/8|0)|0]|0)&128>>>((x&7)>>>0)|0)!=0){x=q+(n+v)|0;a[x]=a[x]|1}v=v+1|0;}while((v|0)<8);B=B+1|0;}while((B|0)<8);l=l+1|0;}while((l|0)<1024);l=c[3530492]|0;gGC(m|0,l|0,49152)|0;q=0;while(1){r=q<<8;gGz(l+r|0,0,256);v=q<<7;n=v+262144|0;y=0;do{x=n+(c[609008+(y<<2)>>2]|0)|0;w=(y<<4)+r|0;z=0;do{C=x+(c[612992+(z<<2)>>2]|0)|0;if(((d[m+((C|0)/8|0)|0]|0)&128>>>((C&7)>>>0)|0)!=0){C=l+(w+z)|0;a[C]=a[C]|4}z=z+1|0;}while((z|0)<16);y=y+1|0;}while((y|0)<16);y=v+131072|0;n=0;while(1){z=y+(c[609008+(n<<2)>>2]|0)|0;w=(n<<4)+r|0;x=0;do{C=z+(c[612992+(x<<2)>>2]|0)|0;if(((d[m+((C|0)/8|0)|0]|0)&128>>>((C&7)>>>0)|0)!=0){C=l+(w+x)|0;a[C]=a[C]|2}x=x+1|0;}while((x|0)<16);x=n+1|0;if((x|0)<16){n=x}else{D=0;break}}do{n=v+(c[609008+(D<<2)>>2]|0)|0;y=(D<<4)+r|0;x=0;do{w=n+(c[612992+(x<<2)>>2]|0)|0;if(((d[m+((w|0)/8|0)|0]|0)&128>>>((w&7)>>>0)|0)!=0){w=l+(y+x)|0;a[w]=a[w]|1}x=x+1|0;}while((x|0)<16);D=D+1|0;}while((D|0)<16);r=q+1|0;if((r|0)<512){q=r}else{E=0;break}}while(1){if((E|0)>=1024){break L64339}F=9638528+(E<<2)|0;if((c[F>>2]|0)==(m|0)){break}else{E=E+1|0}}gGr(m);c[F>>2]=0}}while(0);gu[e&16383]();q=gGq(128)|0;c[2426620]=q;c[2429563]=0;a[9718232]=0;a[9718233]=127;b[4859117]=2048;gGz(q|0,0,128);a[9718241]=0;c[3541282]=662;c[3541290]=662;c[3541288]=662;c[3541286]=2184;c[3541284]=998;q=a[9680]|0?32e3:0;c[3542220]=11200;l=c[2113008]|0;if((l|0)==0){gGz(14168888,0,252);c[3542223]=q;gGz(14168896,0,16);c[3542234]=~~((+(q|0)*32768.0*8.0+75.0e4)/15.0e5);r=31;G=32767.0;while(1){c[14169012+(r<<2)>>2]=~~(G+.5);v=r-1|0;if((v|0)>0){r=v;G=G/1.188502227}else{break}}c[3542253]=0;h[1771269]=1.0;h[1771270]=1.0;h[1771271]=1.0;c[3542574]=3;c[3542575]=3;c[3542576]=3;mB(0);r=(c[2113008]|0)+1|0;c[2113008]=r;H=r;I=a[9680]|0?32e3:0}else{H=l;I=q}c[3542220]=11200;if((H|0)==1){gGz(14169140,0,252);c[3542286]=I;gGz(14169148,0,16);c[3542297]=~~((+(I|0)*32768.0*8.0+75.0e4)/15.0e5);r=31;G=32767.0;while(1){c[14169264+(r<<2)>>2]=~~(G+.5);v=r-1|0;if((v|0)>0){r=v;G=G/1.188502227}else{break}}c[3542316]=0;h[1771272]=1.0;h[1771273]=1.0;h[1771274]=1.0;c[3542577]=3;c[3542578]=3;c[3542579]=3;mB(1);c[2113008]=(c[2113008]|0)+1}h[1771269]=.25;c[3542574]=3;h[1771270]=.25;c[3542575]=3;h[1771271]=.25;c[3542576]=3;h[1771272]=1.0;c[3542577]=3;h[1771273]=1.0;c[3542578]=3;h[1771274]=1.0;c[3542579]=3;c[2385228]=g;c[2430502]=i;c[2427086]=j;r=c[642608+(c[2436]<<2)>>2]|0;q=c[r+128>>2]|0;if((c[r+52>>2]&4|0)==0){c[2113068]=q;l=c[r+132>>2]|0;c[2113070]=l;c[2443814]=q;c[2440436]=l;J=q;K=l}else{c[2113070]=q;l=c[r+132>>2]|0;c[2113068]=l;c[2440436]=q;c[2443814]=l;J=l;K=q}q=ag(J<<1,K)|0;l=gGq(q)|0;c[2112926]=l;if((l|0)!=0){gGz(l|0,0,q|0)}q=c[2414824]|0;gGz(q|0,0,(c[2411890]|0)-q|0);q=c[2439330]|0;l=(q|0)==0;if(!l){r=q;gGC(9706056,r|0,76)|0}r=c[2438118]|0;c[2433530]=r;v=c[3528484]|0;c[2076596]=v;x=c[2417276]|0;c[3541536]=x;c[1836236]=0;gGz(9706056,0,76);if(!l){l=q;gGC(l|0,9706056,76)|0}c[2438118]=r;c[3528484]=v;c[2417276]=x;c[1836236]=-1;b[4859110]=0;a[9718225]=0;a[9718224]=0;a[9718226]=8;a[9718229]=-1;a[9718230]=-1;a[9718227]=0;a[9718237]=0;a[9718236]=0;a[9718249]=0;a[9718238]=0;gGz(9718242,0,6);mB(0);mB(1);a[9762400]=0;a[9762392]=0;a[9541200]=0;c[3528402]=0;c[1835288]=-1;a[9548072]=1;t=0;return t|0}}while(0);c[2415116]=0;t=1;return t|0}function a7a(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;fwR(0);a=c[2439330]|0;d=(a|0)==0;if(!d){e=a;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];e=c[3528484]|0;c[2076596]=e;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;g=c[2386020]|0;h=0;i=0;while(1){c[a+76+(i<<2)>>2]=g+(i<<8);j=h+1&65535;if((j&65535)>191){k=0;l=0;break}else{h=j;i=j&65535}}while(1){i=g+(l<<8)|0;c[a+76+(l+512<<2)>>2]=i;c[a+76+(l+768<<2)>>2]=i;i=k+1&65535;if((i&65535)>191){break}else{k=i;l=i&65535}}l=c[3529352]|0;c[a+844>>2]=l;k=l+256|0;c[a+848>>2]=k;g=l+512|0;c[a+852>>2]=g;i=l+768|0;c[a+856>>2]=i;h=l+1024|0;c[a+860>>2]=h;j=l+1280|0;c[a+864>>2]=j;m=l+1536|0;c[a+868>>2]=m;n=l+1792|0;c[a+872>>2]=n;c[a+1868>>2]=l;c[a+1872>>2]=k;c[a+1876>>2]=g;c[a+1880>>2]=i;c[a+1884>>2]=h;c[a+1888>>2]=j;c[a+1892>>2]=m;c[a+1896>>2]=n;c[a+2892>>2]=l;c[a+3916>>2]=l;c[a+2896>>2]=k;c[a+3920>>2]=k;c[a+2900>>2]=g;c[a+3924>>2]=g;c[a+2904>>2]=i;c[a+3928>>2]=i;c[a+2908>>2]=h;c[a+3932>>2]=h;c[a+2912>>2]=j;c[a+3936>>2]=j;c[a+2916>>2]=m;c[a+3940>>2]=m;c[a+2920>>2]=n;c[a+3944>>2]=n;n=c[3529308]|0;c[a+908>>2]=n;m=n+256|0;c[a+912>>2]=m;c[a+1932>>2]=n;c[a+1936>>2]=m;c[a+2956>>2]=n;c[a+3980>>2]=n;c[a+2960>>2]=m;c[a+3984>>2]=m;m=c[2386538]|0;c[a+916>>2]=m;c[a+1940>>2]=m;c[a+2964>>2]=m;c[a+3988>>2]=m;m=c[2386742]|0;c[a+920>>2]=m;c[a+1944>>2]=m;c[a+2968>>2]=m;c[a+3992>>2]=m;m=c[3529446]|0;c[a+924>>2]=m;n=m+256|0;c[a+928>>2]=n;j=m+512|0;c[a+932>>2]=j;h=m+768|0;c[a+936>>2]=h;c[a+1948>>2]=m;c[a+1952>>2]=n;c[a+1956>>2]=j;c[a+1960>>2]=h;c[a+2972>>2]=m;c[a+3996>>2]=m;c[a+2976>>2]=n;c[a+4e3>>2]=n;c[a+2980>>2]=j;c[a+4004>>2]=j;c[a+2984>>2]=h;c[a+4008>>2]=h;h=c[3529480]|0;c[a+940>>2]=h;j=h+256|0;c[a+944>>2]=j;n=h+512|0;c[a+948>>2]=n;m=h+768|0;c[a+952>>2]=m;c[a+1964>>2]=h;c[a+1968>>2]=j;c[a+1972>>2]=n;c[a+1976>>2]=m;c[a+2988>>2]=h;c[a+4012>>2]=h;c[a+2992>>2]=j;c[a+4016>>2]=j;c[a+2996>>2]=n;c[a+4020>>2]=n;c[a+3e3>>2]=m;c[a+4024>>2]=m;m=c[2387896]|0;c[a+956>>2]=m;n=m+256|0;c[a+960>>2]=n;j=m+512|0;c[a+964>>2]=j;h=m+768|0;c[a+968>>2]=h;c[a+1980>>2]=m;c[a+1984>>2]=n;c[a+1988>>2]=j;c[a+1992>>2]=h;c[a+3004>>2]=m;c[a+4028>>2]=m;c[a+3008>>2]=n;c[a+4032>>2]=n;c[a+3012>>2]=j;c[a+4036>>2]=j;c[a+3016>>2]=h;c[a+4040>>2]=h;c[a+4184>>2]=3272;c[a+4180>>2]=2046;if(d){o=c[2433530]|0;c[2438118]=o;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}d=a;gGC(d|0,9706056,76)|0;o=c[2433530]|0;c[2438118]=o;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}function a7b(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0;a=i;i=i+3e3|0;b=a|0;d=a+112|0;e=a+120|0;f=a+232|0;g=a+240|0;h=a+352|0;j=a+360|0;k=a+472|0;l=a+480|0;m=a+592|0;n=a+600|0;o=a+712|0;p=a+720|0;q=a+832|0;r=a+840|0;s=a+952|0;t=a+960|0;u=a+1072|0;v=a+1080|0;w=a+1192|0;x=a+1200|0;y=a+1312|0;z=a+1320|0;A=a+1432|0;B=a+1440|0;C=a+1552|0;D=a+1560|0;E=a+1672|0;F=a+1680|0;G=a+1792|0;H=a+1800|0;I=a+1912|0;J=a+1920|0;K=a+2032|0;L=a+2040|0;M=a+2152|0;N=a+2160|0;O=a+2272|0;P=a+2280|0;Q=a+2392|0;R=a+2400|0;S=a+2512|0;T=a+2520|0;U=a+2632|0;V=a+2640|0;W=a+2752|0;X=a+2760|0;Y=a+2872|0;Z=a+2880|0;_=a+2992|0;$=c[2386020]|0;if((c[3542200]|0)==0){aa=1;i=a;return aa|0}ab=Z+108|0;c[ab>>2]=0;ac=Z+100|0;c[ac>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](Z,0)|0;do{if((c[ab>>2]|0)!=0){Z=c[ac>>2]|0;c[_>>2]=9534384;ad=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ad&16383](_,0,0)|0;if((Z|0)<1){aa=1;i=a;return aa|0}if((gzL($,0,0)|0)==0){break}else{aa=1}i=a;return aa|0}}while(0);$=(c[2386020]|0)+8192|0;if((c[3542200]|0)==0){aa=1;i=a;return aa|0}_=X+108|0;c[_>>2]=0;ac=X+100|0;c[ac>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](X,1)|0;do{if((c[_>>2]|0)!=0){X=c[ac>>2]|0;c[Y>>2]=9534384;ab=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ab&16383](Y,1,0)|0;if((X|0)<1){aa=1;i=a;return aa|0}if((gzL($,0,1)|0)==0){break}else{aa=1}i=a;return aa|0}}while(0);$=(c[2386020]|0)+16384|0;if((c[3542200]|0)==0){aa=1;i=a;return aa|0}Y=V+108|0;c[Y>>2]=0;ac=V+100|0;c[ac>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](V,2)|0;do{if((c[Y>>2]|0)!=0){V=c[ac>>2]|0;c[W>>2]=9534384;_=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[_&16383](W,2,0)|0;if((V|0)<1){aa=1;i=a;return aa|0}if((gzL($,0,2)|0)==0){break}else{aa=1}i=a;return aa|0}}while(0);$=(c[2386020]|0)+32768|0;if((c[3542200]|0)==0){aa=1;i=a;return aa|0}W=T+108|0;c[W>>2]=0;ac=T+100|0;c[ac>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](T,3)|0;do{if((c[W>>2]|0)!=0){T=c[ac>>2]|0;c[U>>2]=9534384;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Y&16383](U,3,0)|0;if((T|0)<1){aa=1;i=a;return aa|0}if((gzL($,0,3)|0)==0){break}else{aa=1}i=a;return aa|0}}while(0);$=(c[2386020]|0)+40960|0;if((c[3542200]|0)==0){aa=1;i=a;return aa|0}U=R+108|0;c[U>>2]=0;ac=R+100|0;c[ac>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](R,4)|0;do{if((c[U>>2]|0)!=0){R=c[ac>>2]|0;c[S>>2]=9534384;W=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[W&16383](S,4,0)|0;if((R|0)<1){aa=1;i=a;return aa|0}if((gzL($,0,4)|0)==0){break}else{aa=1}i=a;return aa|0}}while(0);$=c[3527448]|0;if((c[3542200]|0)==0){aa=1;i=a;return aa|0}S=P+108|0;c[S>>2]=0;ac=P+100|0;c[ac>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](P,5)|0;do{if((c[S>>2]|0)!=0){P=c[ac>>2]|0;c[Q>>2]=9534384;U=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[U&16383](Q,5,0)|0;if((P|0)<1){aa=1;i=a;return aa|0}if((gzL($,0,5)|0)==0){break}else{aa=1}i=a;return aa|0}}while(0);$=c[3530960]|0;if((c[3542200]|0)==0){aa=1;i=a;return aa|0}Q=N+108|0;c[Q>>2]=0;ac=N+100|0;c[ac>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](N,6)|0;do{if((c[Q>>2]|0)!=0){N=c[ac>>2]|0;c[O>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](O,6,0)|0;if((N|0)<1){aa=1;i=a;return aa|0}if((gzL($,0,6)|0)==0){break}else{aa=1}i=a;return aa|0}}while(0);$=c[3530960]|0;O=$+4096|0;ac=$+2048|0;gGC(O|0,ac|0,2048)|0;ac=c[3530726]|0;if((c[3542200]|0)==0){aa=1;i=a;return aa|0}O=L+108|0;c[O>>2]=0;$=L+100|0;c[$>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](L,7)|0;do{if((c[O>>2]|0)!=0){L=c[$>>2]|0;c[M>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](M,7,0)|0;if((L|0)<1){aa=1;i=a;return aa|0}if((gzL(ac,0,7)|0)==0){break}else{aa=1}i=a;return aa|0}}while(0);ac=(c[3530726]|0)+8192|0;if((c[3542200]|0)==0){aa=1;i=a;return aa|0}M=J+108|0;c[M>>2]=0;$=J+100|0;c[$>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](J,8)|0;do{if((c[M>>2]|0)!=0){J=c[$>>2]|0;c[K>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](K,8,0)|0;if((J|0)<1){aa=1;i=a;return aa|0}if((gzL(ac,0,8)|0)==0){break}else{aa=1}i=a;return aa|0}}while(0);ac=(c[3530726]|0)+16384|0;if((c[3542200]|0)==0){aa=1;i=a;return aa|0}K=H+108|0;c[K>>2]=0;$=H+100|0;c[$>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](H,9)|0;do{if((c[K>>2]|0)!=0){H=c[$>>2]|0;c[I>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](I,9,0)|0;if((H|0)<1){aa=1;i=a;return aa|0}if((gzL(ac,0,9)|0)==0){break}else{aa=1}i=a;return aa|0}}while(0);ac=c[3530492]|0;if((c[3542200]|0)==0){aa=1;i=a;return aa|0}I=F+108|0;c[I>>2]=0;$=F+100|0;c[$>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](F,10)|0;do{if((c[I>>2]|0)!=0){F=c[$>>2]|0;c[G>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](G,10,0)|0;if((F|0)<1){aa=1;i=a;return aa|0}if((gzL(ac,0,10)|0)==0){break}else{aa=1}i=a;return aa|0}}while(0);ac=(c[3530492]|0)+8192|0;if((c[3542200]|0)==0){aa=1;i=a;return aa|0}G=D+108|0;c[G>>2]=0;$=D+100|0;c[$>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](D,11)|0;do{if((c[G>>2]|0)!=0){D=c[$>>2]|0;c[E>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](E,11,0)|0;if((D|0)<1){aa=1;i=a;return aa|0}if((gzL(ac,0,11)|0)==0){break}else{aa=1}i=a;return aa|0}}while(0);ac=(c[3530492]|0)+16384|0;if((c[3542200]|0)==0){aa=1;i=a;return aa|0}E=B+108|0;c[E>>2]=0;$=B+100|0;c[$>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](B,12)|0;do{if((c[E>>2]|0)!=0){B=c[$>>2]|0;c[C>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](C,12,0)|0;if((B|0)<1){aa=1;i=a;return aa|0}if((gzL(ac,0,12)|0)==0){break}else{aa=1}i=a;return aa|0}}while(0);ac=(c[3530492]|0)+24576|0;if((c[3542200]|0)==0){aa=1;i=a;return aa|0}C=z+108|0;c[C>>2]=0;$=z+100|0;c[$>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,13)|0;do{if((c[C>>2]|0)!=0){z=c[$>>2]|0;c[A>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](A,13,0)|0;if((z|0)<1){aa=1;i=a;return aa|0}if((gzL(ac,0,13)|0)==0){break}else{aa=1}i=a;return aa|0}}while(0);ac=(c[3530492]|0)+32768|0;if((c[3542200]|0)==0){aa=1;i=a;return aa|0}A=x+108|0;c[A>>2]=0;$=x+100|0;c[$>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,14)|0;do{if((c[A>>2]|0)!=0){x=c[$>>2]|0;c[y>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](y,14,0)|0;if((x|0)<1){aa=1;i=a;return aa|0}if((gzL(ac,0,14)|0)==0){break}else{aa=1}i=a;return aa|0}}while(0);ac=(c[3530492]|0)+40960|0;if((c[3542200]|0)==0){aa=1;i=a;return aa|0}y=v+108|0;c[y>>2]=0;$=v+100|0;c[$>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,15)|0;do{if((c[y>>2]|0)!=0){v=c[$>>2]|0;c[w>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](w,15,0)|0;if((v|0)<1){aa=1;i=a;return aa|0}if((gzL(ac,0,15)|0)==0){break}else{aa=1}i=a;return aa|0}}while(0);ac=c[2386704]|0;if((c[3542200]|0)==0){aa=1;i=a;return aa|0}w=t+108|0;c[w>>2]=0;$=t+100|0;c[$>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,16)|0;do{if((c[w>>2]|0)!=0){t=c[$>>2]|0;c[u>>2]=9534384;y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[y&16383](u,16,0)|0;if((t|0)<1){aa=1;i=a;return aa|0}if((gzL(ac,0,16)|0)==0){break}else{aa=1}i=a;return aa|0}}while(0);ac=c[3531054]|0;if((c[3542200]|0)==0){aa=1;i=a;return aa|0}u=r+108|0;c[u>>2]=0;$=r+100|0;c[$>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,17)|0;do{if((c[u>>2]|0)!=0){r=c[$>>2]|0;c[s>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](s,17,0)|0;if((r|0)<1){aa=1;i=a;return aa|0}if((gzL(ac,0,17)|0)==0){break}else{aa=1}i=a;return aa|0}}while(0);ac=(c[3531054]|0)+256|0;if((c[3542200]|0)==0){aa=1;i=a;return aa|0}s=p+108|0;c[s>>2]=0;$=p+100|0;c[$>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,18)|0;do{if((c[s>>2]|0)!=0){p=c[$>>2]|0;c[q>>2]=9534384;u=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[u&16383](q,18,0)|0;if((p|0)<1){aa=1;i=a;return aa|0}if((gzL(ac,0,18)|0)==0){break}else{aa=1}i=a;return aa|0}}while(0);ac=(c[3531054]|0)+512|0;if((c[3542200]|0)==0){aa=1;i=a;return aa|0}q=n+108|0;c[q>>2]=0;$=n+100|0;c[$>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,19)|0;do{if((c[q>>2]|0)!=0){n=c[$>>2]|0;c[o>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](o,19,0)|0;if((n|0)<1){aa=1;i=a;return aa|0}if((gzL(ac,0,19)|0)==0){break}else{aa=1}i=a;return aa|0}}while(0);ac=c[2443482]|0;if((c[3542200]|0)==0){aa=1;i=a;return aa|0}o=l+108|0;c[o>>2]=0;$=l+100|0;c[$>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,20)|0;do{if((c[o>>2]|0)!=0){l=c[$>>2]|0;c[m>>2]=9534384;q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[q&16383](m,20,0)|0;if((l|0)<1){aa=1;i=a;return aa|0}if((gzL(ac,0,20)|0)==0){break}else{aa=1}i=a;return aa|0}}while(0);ac=(c[2443482]|0)+8192|0;if((c[3542200]|0)==0){aa=1;i=a;return aa|0}m=j+108|0;c[m>>2]=0;$=j+100|0;c[$>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,21)|0;do{if((c[m>>2]|0)!=0){j=c[$>>2]|0;c[k>>2]=9534384;o=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[o&16383](k,21,0)|0;if((j|0)<1){aa=1;i=a;return aa|0}if((gzL(ac,0,21)|0)==0){break}else{aa=1}i=a;return aa|0}}while(0);ac=(c[2443482]|0)+16384|0;if((c[3542200]|0)==0){aa=1;i=a;return aa|0}k=g+108|0;c[k>>2]=0;$=g+100|0;c[$>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,22)|0;do{if((c[k>>2]|0)!=0){g=c[$>>2]|0;c[h>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](h,22,0)|0;if((g|0)<1){aa=1;i=a;return aa|0}if((gzL(ac,0,22)|0)==0){break}else{aa=1}i=a;return aa|0}}while(0);ac=(c[2443482]|0)+24576|0;if((c[3542200]|0)==0){aa=1;i=a;return aa|0}h=e+108|0;c[h>>2]=0;$=e+100|0;c[$>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,23)|0;do{if((c[h>>2]|0)!=0){e=c[$>>2]|0;c[f>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](f,23,0)|0;if((e|0)<1){aa=1;i=a;return aa|0}if((gzL(ac,0,23)|0)==0){break}else{aa=1}i=a;return aa|0}}while(0);ac=(c[2443482]|0)+32768|0;if((c[3542200]|0)==0){aa=1;i=a;return aa|0}f=b+108|0;c[f>>2]=0;$=b+100|0;c[$>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](b,24)|0;if((c[f>>2]|0)==0){aa=0;i=a;return aa|0}f=c[$>>2]|0;c[d>>2]=9534384;gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](d,24,0)|0;if((f|0)<1){aa=1;i=a;return aa|0}aa=(gzL(ac,0,24)|0)!=0|0;i=a;return aa|0}function a7c(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;fwR(0);a=c[2439330]|0;d=(a|0)==0;if(!d){e=a;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];e=c[3528484]|0;c[2076596]=e;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;g=c[2386020]|0;h=0;i=0;while(1){c[a+76+(i<<2)>>2]=g+(i<<8);j=h+1&65535;if((j&65535)>191){k=0;l=0;break}else{h=j;i=j&65535}}while(1){i=g+(l<<8)|0;c[a+76+(l+512<<2)>>2]=i;c[a+76+(l+768<<2)>>2]=i;i=k+1&65535;if((i&65535)>191){break}else{k=i;l=i&65535}}l=c[3529352]|0;c[a+908>>2]=l;c[a+912>>2]=l+256;c[a+916>>2]=l+512;c[a+920>>2]=l+768;c[a+924>>2]=l+1024;c[a+928>>2]=l+1280;c[a+932>>2]=l+1536;c[a+936>>2]=l+1792;c[a+940>>2]=l+2048;c[a+944>>2]=l+2304;c[a+948>>2]=l+2560;c[a+952>>2]=l+2816;c[a+956>>2]=l+3072;c[a+960>>2]=l+3328;c[a+964>>2]=l+3584;c[a+968>>2]=l+3840;k=208;g=208;while(1){c[a+76+(g+256<<2)>>2]=l+((g<<8)-53248);i=k+1&65535;if((i&65535)>223){m=208;n=208;break}else{k=i;g=i&65535}}while(1){g=l+((n<<8)-53248)|0;c[a+76+(n+512<<2)>>2]=g;c[a+76+(n+768<<2)>>2]=g;g=m+1&65535;if((g&65535)>223){break}else{m=g;n=g&65535}}n=c[3529308]|0;c[a+972>>2]=n;m=n+256|0;c[a+976>>2]=m;c[a+1996>>2]=n;c[a+2e3>>2]=m;c[a+3020>>2]=n;c[a+4044>>2]=n;c[a+3024>>2]=m;c[a+4048>>2]=m;m=c[2386538]|0;c[a+980>>2]=m;c[a+2004>>2]=m;c[a+3028>>2]=m;c[a+4052>>2]=m;m=c[2386742]|0;c[a+984>>2]=m;c[a+2008>>2]=m;c[a+3032>>2]=m;c[a+4056>>2]=m;m=c[3529446]|0;c[a+988>>2]=m;n=m+256|0;c[a+992>>2]=n;l=m+512|0;c[a+996>>2]=l;g=m+768|0;c[a+1e3>>2]=g;c[a+2012>>2]=m;c[a+2016>>2]=n;c[a+2020>>2]=l;c[a+2024>>2]=g;c[a+3036>>2]=m;c[a+4060>>2]=m;c[a+3040>>2]=n;c[a+4064>>2]=n;c[a+3044>>2]=l;c[a+4068>>2]=l;c[a+3048>>2]=g;c[a+4072>>2]=g;g=c[3529480]|0;c[a+1004>>2]=g;l=g+256|0;c[a+1008>>2]=l;n=g+512|0;c[a+1012>>2]=n;m=g+768|0;c[a+1016>>2]=m;c[a+2028>>2]=g;c[a+2032>>2]=l;c[a+2036>>2]=n;c[a+2040>>2]=m;c[a+3052>>2]=g;c[a+4076>>2]=g;c[a+3056>>2]=l;c[a+4080>>2]=l;c[a+3060>>2]=n;c[a+4084>>2]=n;c[a+3064>>2]=m;c[a+4088>>2]=m;m=c[2387896]|0;c[a+1020>>2]=m;n=m+256|0;c[a+1024>>2]=n;l=m+512|0;c[a+1028>>2]=l;g=m+768|0;c[a+1032>>2]=g;c[a+2044>>2]=m;c[a+2048>>2]=n;c[a+2052>>2]=l;c[a+2056>>2]=g;c[a+3068>>2]=m;c[a+4092>>2]=m;c[a+3072>>2]=n;c[a+4096>>2]=n;c[a+3076>>2]=l;c[a+4100>>2]=l;c[a+3080>>2]=g;c[a+4104>>2]=g;c[a+4184>>2]=912;c[a+4180>>2]=2046;if(d){o=c[2433530]|0;c[2438118]=o;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}d=a;gGC(d|0,9706056,76)|0;o=c[2433530]|0;c[2438118]=o;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}function a7d(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0;a=i;i=i+2760|0;b=a|0;d=a+112|0;e=a+120|0;f=a+232|0;g=a+240|0;h=a+352|0;j=a+360|0;k=a+472|0;l=a+480|0;m=a+592|0;n=a+600|0;o=a+712|0;p=a+720|0;q=a+832|0;r=a+840|0;s=a+952|0;t=a+960|0;u=a+1072|0;v=a+1080|0;w=a+1192|0;x=a+1200|0;y=a+1312|0;z=a+1320|0;A=a+1432|0;B=a+1440|0;C=a+1552|0;D=a+1560|0;E=a+1672|0;F=a+1680|0;G=a+1792|0;H=a+1800|0;I=a+1912|0;J=a+1920|0;K=a+2032|0;L=a+2040|0;M=a+2152|0;N=a+2160|0;O=a+2272|0;P=a+2280|0;Q=a+2392|0;R=a+2400|0;S=a+2512|0;T=a+2520|0;U=a+2632|0;V=a+2640|0;W=a+2752|0;X=c[2386020]|0;if((c[3542200]|0)==0){Y=1;i=a;return Y|0}Z=V+108|0;c[Z>>2]=0;_=V+100|0;c[_>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](V,0)|0;do{if((c[Z>>2]|0)!=0){V=c[_>>2]|0;c[W>>2]=9534384;$=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[$&16383](W,0,0)|0;if((V|0)<1){Y=1;i=a;return Y|0}if((gzL(X,0,0)|0)==0){break}else{Y=1}i=a;return Y|0}}while(0);X=(c[2386020]|0)+8192|0;if((c[3542200]|0)==0){Y=1;i=a;return Y|0}W=T+108|0;c[W>>2]=0;_=T+100|0;c[_>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](T,1)|0;do{if((c[W>>2]|0)!=0){T=c[_>>2]|0;c[U>>2]=9534384;Z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Z&16383](U,1,0)|0;if((T|0)<1){Y=1;i=a;return Y|0}if((gzL(X,0,1)|0)==0){break}else{Y=1}i=a;return Y|0}}while(0);X=(c[2386020]|0)+16384|0;if((c[3542200]|0)==0){Y=1;i=a;return Y|0}U=R+108|0;c[U>>2]=0;_=R+100|0;c[_>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](R,2)|0;do{if((c[U>>2]|0)!=0){R=c[_>>2]|0;c[S>>2]=9534384;W=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[W&16383](S,2,0)|0;if((R|0)<1){Y=1;i=a;return Y|0}if((gzL(X,0,2)|0)==0){break}else{Y=1}i=a;return Y|0}}while(0);X=(c[2386020]|0)+24576|0;if((c[3542200]|0)==0){Y=1;i=a;return Y|0}S=P+108|0;c[S>>2]=0;_=P+100|0;c[_>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](P,3)|0;do{if((c[S>>2]|0)!=0){P=c[_>>2]|0;c[Q>>2]=9534384;U=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[U&16383](Q,3,0)|0;if((P|0)<1){Y=1;i=a;return Y|0}if((gzL(X,0,3)|0)==0){break}else{Y=1}i=a;return Y|0}}while(0);X=(c[2386020]|0)+32768|0;if((c[3542200]|0)==0){Y=1;i=a;return Y|0}Q=N+108|0;c[Q>>2]=0;_=N+100|0;c[_>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](N,4)|0;do{if((c[Q>>2]|0)!=0){N=c[_>>2]|0;c[O>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](O,4,0)|0;if((N|0)<1){Y=1;i=a;return Y|0}if((gzL(X,0,4)|0)==0){break}else{Y=1}i=a;return Y|0}}while(0);X=(c[2386020]|0)+40960|0;if((c[3542200]|0)==0){Y=1;i=a;return Y|0}O=L+108|0;c[O>>2]=0;_=L+100|0;c[_>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](L,5)|0;do{if((c[O>>2]|0)!=0){L=c[_>>2]|0;c[M>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](M,5,0)|0;if((L|0)<1){Y=1;i=a;return Y|0}if((gzL(X,0,5)|0)==0){break}else{Y=1}i=a;return Y|0}}while(0);X=c[3527448]|0;if((c[3542200]|0)==0){Y=1;i=a;return Y|0}M=J+108|0;c[M>>2]=0;_=J+100|0;c[_>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](J,6)|0;do{if((c[M>>2]|0)!=0){J=c[_>>2]|0;c[K>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](K,6,0)|0;if((J|0)<1){Y=1;i=a;return Y|0}if((gzL(X,0,6)|0)==0){break}else{Y=1}i=a;return Y|0}}while(0);X=c[3530960]|0;if((c[3542200]|0)==0){Y=1;i=a;return Y|0}K=H+108|0;c[K>>2]=0;_=H+100|0;c[_>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](H,7)|0;do{if((c[K>>2]|0)!=0){H=c[_>>2]|0;c[I>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](I,7,0)|0;if((H|0)<1){Y=1;i=a;return Y|0}if((gzL(X,0,7)|0)==0){break}else{Y=1}i=a;return Y|0}}while(0);X=(c[3530960]|0)+4096|0;if((c[3542200]|0)==0){Y=1;i=a;return Y|0}I=F+108|0;c[I>>2]=0;_=F+100|0;c[_>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](F,8)|0;do{if((c[I>>2]|0)!=0){F=c[_>>2]|0;c[G>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](G,8,0)|0;if((F|0)<1){Y=1;i=a;return Y|0}if((gzL(X,0,8)|0)==0){break}else{Y=1}i=a;return Y|0}}while(0);X=c[3530726]|0;if((c[3542200]|0)==0){Y=1;i=a;return Y|0}G=D+108|0;c[G>>2]=0;_=D+100|0;c[_>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](D,9)|0;do{if((c[G>>2]|0)!=0){D=c[_>>2]|0;c[E>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](E,9,0)|0;if((D|0)<1){Y=1;i=a;return Y|0}if((gzL(X,0,9)|0)==0){break}else{Y=1}i=a;return Y|0}}while(0);X=(c[3530726]|0)+8192|0;if((c[3542200]|0)==0){Y=1;i=a;return Y|0}E=B+108|0;c[E>>2]=0;_=B+100|0;c[_>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](B,10)|0;do{if((c[E>>2]|0)!=0){B=c[_>>2]|0;c[C>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](C,10,0)|0;if((B|0)<1){Y=1;i=a;return Y|0}if((gzL(X,0,10)|0)==0){break}else{Y=1}i=a;return Y|0}}while(0);X=(c[3530726]|0)+16384|0;if((c[3542200]|0)==0){Y=1;i=a;return Y|0}C=z+108|0;c[C>>2]=0;_=z+100|0;c[_>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,11)|0;do{if((c[C>>2]|0)!=0){z=c[_>>2]|0;c[A>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](A,11,0)|0;if((z|0)<1){Y=1;i=a;return Y|0}if((gzL(X,0,11)|0)==0){break}else{Y=1}i=a;return Y|0}}while(0);X=c[3530492]|0;if((c[3542200]|0)==0){Y=1;i=a;return Y|0}A=x+108|0;c[A>>2]=0;_=x+100|0;c[_>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,12)|0;do{if((c[A>>2]|0)!=0){x=c[_>>2]|0;c[y>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](y,12,0)|0;if((x|0)<1){Y=1;i=a;return Y|0}if((gzL(X,0,12)|0)==0){break}else{Y=1}i=a;return Y|0}}while(0);X=(c[3530492]|0)+8192|0;if((c[3542200]|0)==0){Y=1;i=a;return Y|0}y=v+108|0;c[y>>2]=0;_=v+100|0;c[_>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,13)|0;do{if((c[y>>2]|0)!=0){v=c[_>>2]|0;c[w>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](w,13,0)|0;if((v|0)<1){Y=1;i=a;return Y|0}if((gzL(X,0,13)|0)==0){break}else{Y=1}i=a;return Y|0}}while(0);X=(c[3530492]|0)+16384|0;if((c[3542200]|0)==0){Y=1;i=a;return Y|0}w=t+108|0;c[w>>2]=0;_=t+100|0;c[_>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,14)|0;do{if((c[w>>2]|0)!=0){t=c[_>>2]|0;c[u>>2]=9534384;y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[y&16383](u,14,0)|0;if((t|0)<1){Y=1;i=a;return Y|0}if((gzL(X,0,14)|0)==0){break}else{Y=1}i=a;return Y|0}}while(0);X=(c[3530492]|0)+24576|0;if((c[3542200]|0)==0){Y=1;i=a;return Y|0}u=r+108|0;c[u>>2]=0;_=r+100|0;c[_>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,15)|0;do{if((c[u>>2]|0)!=0){r=c[_>>2]|0;c[s>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](s,15,0)|0;if((r|0)<1){Y=1;i=a;return Y|0}if((gzL(X,0,15)|0)==0){break}else{Y=1}i=a;return Y|0}}while(0);X=(c[3530492]|0)+32768|0;if((c[3542200]|0)==0){Y=1;i=a;return Y|0}s=p+108|0;c[s>>2]=0;_=p+100|0;c[_>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,16)|0;do{if((c[s>>2]|0)!=0){p=c[_>>2]|0;c[q>>2]=9534384;u=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[u&16383](q,16,0)|0;if((p|0)<1){Y=1;i=a;return Y|0}if((gzL(X,0,16)|0)==0){break}else{Y=1}i=a;return Y|0}}while(0);X=(c[3530492]|0)+40960|0;if((c[3542200]|0)==0){Y=1;i=a;return Y|0}q=n+108|0;c[q>>2]=0;_=n+100|0;c[_>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,17)|0;do{if((c[q>>2]|0)!=0){n=c[_>>2]|0;c[o>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](o,17,0)|0;if((n|0)<1){Y=1;i=a;return Y|0}if((gzL(X,0,17)|0)==0){break}else{Y=1}i=a;return Y|0}}while(0);X=c[2386704]|0;if((c[3542200]|0)==0){Y=1;i=a;return Y|0}o=l+108|0;c[o>>2]=0;_=l+100|0;c[_>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,18)|0;do{if((c[o>>2]|0)!=0){l=c[_>>2]|0;c[m>>2]=9534384;q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[q&16383](m,18,0)|0;if((l|0)<1){Y=1;i=a;return Y|0}if((gzL(X,0,18)|0)==0){break}else{Y=1}i=a;return Y|0}}while(0);X=c[3531054]|0;if((c[3542200]|0)==0){Y=1;i=a;return Y|0}m=j+108|0;c[m>>2]=0;_=j+100|0;c[_>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,19)|0;do{if((c[m>>2]|0)!=0){j=c[_>>2]|0;c[k>>2]=9534384;o=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[o&16383](k,19,0)|0;if((j|0)<1){Y=1;i=a;return Y|0}if((gzL(X,0,19)|0)==0){break}else{Y=1}i=a;return Y|0}}while(0);X=(c[3531054]|0)+256|0;if((c[3542200]|0)==0){Y=1;i=a;return Y|0}k=g+108|0;c[k>>2]=0;_=g+100|0;c[_>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,20)|0;do{if((c[k>>2]|0)!=0){g=c[_>>2]|0;c[h>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](h,20,0)|0;if((g|0)<1){Y=1;i=a;return Y|0}if((gzL(X,0,20)|0)==0){break}else{Y=1}i=a;return Y|0}}while(0);X=(c[3531054]|0)+512|0;if((c[3542200]|0)==0){Y=1;i=a;return Y|0}h=e+108|0;c[h>>2]=0;_=e+100|0;c[_>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,21)|0;do{if((c[h>>2]|0)!=0){e=c[_>>2]|0;c[f>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](f,21,0)|0;if((e|0)<1){Y=1;i=a;return Y|0}if((gzL(X,0,21)|0)==0){break}else{Y=1}i=a;return Y|0}}while(0);X=(c[3531054]|0)+768|0;if((c[3542200]|0)==0){Y=1;i=a;return Y|0}f=b+108|0;c[f>>2]=0;_=b+100|0;c[_>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](b,22)|0;if((c[f>>2]|0)==0){Y=0;i=a;return Y|0}f=c[_>>2]|0;c[d>>2]=9534384;gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](d,22,0)|0;if((f|0)<1){Y=1;i=a;return Y|0}Y=(gzL(X,0,22)|0)!=0|0;i=a;return Y|0}function a7e(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=(f|0)!=0;f=c[2112926]|0;i=c[3530492]|0;if((g|0)==0){if(h){SJ(f,a,d,e,b,3,0,0,i);return}else{SH(f,a,d,e,b,3,0,0,i);return}}else{if(h){SN(f,a,d,e,b,3,0,0,i);return}else{SL(f,a,d,e,b,3,0,0,i);return}}}function a7f(a){a=a|0;return 0}function a7g(b,e){b=b|0;e=e|0;var f=0;f=b&65535;if((b+16352&65535)<192){a[(c[2443438]|0)+(f-49184)|0]=e;return}if((b+14336&65535)>=2048){return}b=c[2439628]|0;a[b+(f&2047)|0]=e;e=f&1279;c[(c[3530206]|0)+((f>>>2&256|f&255)<<2)>>2]=(d[b+(e|256)|0]|0)<<6&1984|(d[b+e|0]|0)<<11&63488|a[b+(e|512)|0]&31;return}function a7h(b){b=b|0;var c=0;switch(b&255|0){case 0:{c=~a[9625896];break};case 1:{c=~a[9625897];break};case 4:{c=a[9658105]|0;break};case 3:{c=a[9658104]|0;break};case 2:{c=~a[9625898];break};default:{c=0}}return c|0}function a7i(b){b=b|0;var c=0;switch(b&255|0){case 0:{c=-48-(a[9625896]|0)&255|a[9658104];break};case 1:{c=~a[9625897];break};case 2:{c=~a[9625898];break};case 3:{c=a[9658105]|0;break};case 4:{c=a[9658106]|0;break};default:{c=0}}return c|0}function a7j(b){b=b|0;var c=0;switch(b&255|0){case 0:{c=11-(a[9625896]|0)&255|a[9658104];break};case 3:{c=a[9658105]|0;break};case 1:{c=~a[9625897];break};case 2:{c=~a[9625898];break};case 4:{c=a[9658106]|0;break};default:{c=0}}return c|0}function a7k(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;switch(d&255|0){case 0:{a[9758264]=e;d=c[1836236]|0;f=c[9757320+(d<<2)>>2]|0;if((f|0)!=0){g=f;gGC(g|0,9706056,76)|0}c[9752472+(d<<2)>>2]=c[2433530];c[14113936+(d<<2)>>2]=c[2076596];c[9669104+(d<<2)>>2]=c[3541536];c[1836236]=-1;d=c[2439331]|0;if((d|0)!=0){g=d;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;g=c[2438119]|0;c[2433530]=g;c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;f=a[9774152]&-33;a[9774152]=f;a[14125144]=f;a[9706117]=1;if((a[d+4188|0]|0)==0){f=gfc(1e3)|0;h=c[1836236]|0;i=f;j=(c[2433530]|0)+f|0;k=h;l=c[9757320+(h<<2)>>2]|0}else{i=1e3;j=g+1e3|0;k=1;l=d}c[2433530]=j;c[2444123]=(c[2444123]|0)+i;if((l|0)!=0){i=l;gGC(i|0,9706056,76)|0}c[9752472+(k<<2)>>2]=j;c[14113936+(k<<2)>>2]=c[2076596];c[9669104+(k<<2)>>2]=c[3541536];c[1836236]=-1;k=c[2439330]|0;if((k|0)!=0){j=k;gGC(9706056,j|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;return};case 4:{j=e&7;a[14119368]=j;k=c[3529134]|0;i=c[9757320+(c[1836236]<<2)>>2]|0;l=((j&255)<<14)+32768|0;j=128;d=128;while(1){c[i+76+(d<<2)>>2]=k+(l+(d<<8));g=j+1&65535;if((g&65535)>191){m=128;n=128;break}else{j=g;d=g&65535}}while(1){d=k+(l+(n<<8))|0;c[i+76+(n+512<<2)>>2]=d;c[i+76+(n+768<<2)>>2]=d;d=m+1&65535;if((d&65535)>191){break}else{m=d;n=d&65535}}return};case 129:{c[2433474]=(e&255)<<8&256;return};case 130:{c[2429520]=e&255;return};case 131:{c[2429522]=(e&255)<<8&1792;return};case 132:{n=e&255;c[2439586]=n&13;c[2438758]=n&64;return};case 128:{c[2433472]=e&255;return};default:{return}}}function a7l(a){a=a|0;return 0}function a7m(b,e){b=b|0;e=e|0;var f=0;f=b&65535;if((b+14336&65535)>=768){return}b=c[2439628]|0;a[b+(f&1023)|0]=e;e=f&255;c[(c[3530206]|0)+(e<<2)>>2]=(d[b+(e|256)|0]|0)<<6&1984|(d[b+e|0]|0)<<11&63488|a[b+(e|512)|0]&31;return}function a7n(b){b=b|0;var c=0;switch(b&255|0){case 0:{c=a[9658104]|0;break};case 2:{c=~a[9625897];break};case 3:{c=~a[9625896];break};case 1:{c=a[9658105]|0;break};case 4:{c=~a[9625898];break};default:{c=0}}return c|0}function a7o(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=d&255;if((f|0)==4){d=e&7;a[14119368]=d;g=c[3529134]|0;h=c[9757320+(c[1836236]<<2)>>2]|0;i=((d&255)<<14)+32768|0;d=128;j=128;while(1){c[h+76+(j<<2)>>2]=g+(i+(j<<8));k=d+1&65535;if((k&65535)>191){l=128;m=128;break}else{d=k;j=k&65535}}while(1){j=g+(i+(m<<8))|0;c[h+76+(m+512<<2)>>2]=j;c[h+76+(m+768<<2)>>2]=j;j=l+1&65535;if((j&65535)>191){break}else{l=j;m=j&65535}}return}else if((f|0)==6){if(e<<24>>24==32){return}a[9758264]=e;e=c[1836236]|0;f=c[9757320+(e<<2)>>2]|0;if((f|0)!=0){m=f;gGC(m|0,9706056,76)|0}c[9752472+(e<<2)>>2]=c[2433530];c[14113936+(e<<2)>>2]=c[2076596];c[9669104+(e<<2)>>2]=c[3541536];c[1836236]=-1;e=c[2439331]|0;if((e|0)!=0){m=e;gGC(9706056,m|0,76)|0}b[4853030]=c[2426515]&65535;m=c[2438119]|0;c[2433530]=m;c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;f=a[9774152]&-33;a[9774152]=f;a[14125144]=f;a[9706117]=1;if((a[e+4188|0]|0)==0){f=gfc(1e3)|0;l=c[1836236]|0;n=f;o=(c[2433530]|0)+f|0;p=l;q=c[9757320+(l<<2)>>2]|0}else{n=1e3;o=m+1e3|0;p=1;q=e}c[2433530]=o;c[2444123]=(c[2444123]|0)+n;if((q|0)!=0){n=q;gGC(n|0,9706056,76)|0}c[9752472+(p<<2)>>2]=o;c[14113936+(p<<2)>>2]=c[2076596];c[9669104+(p<<2)>>2]=c[3541536];c[1836236]=-1;p=c[2439330]|0;if((p|0)!=0){o=p;gGC(9706056,o|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;return}else{return}}function a7p(a){a=a|0;return 0}function a7q(a,b){a=a|0;b=b|0;return}function a7r(b){b=b|0;var d=0,e=0;d=b&255;if((d|0)==1){e=c[(c[3531464]|0)+4240>>2]&255}else if((d|0)==128){e=a[9758264]|0}else if((d|0)==132){e=a[(c[3529826]|0)+(c[2433446]|0)|0]|0}else{e=0}return e|0}function a7s(d,e){d=d|0;e=e|0;var f=0,g=0;switch(d&255|0){case 0:{c[2113304]=e&255;return};case 131:{d=a[9774152]|32;a[9774152]=d;if(d<<24>>24==-1){a[9706117]=0;return}a[14125144]=d;a[9706117]=1;if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){d=gfc(1e3)|0;f=d;g=(c[2433530]|0)+d|0}else{f=1e3;g=(c[2433530]|0)+1e3|0}c[2433530]=g;c[2444123]=(c[2444123]|0)+f;return};case 129:{c[2433446]=c[2433446]&255|(e&255)<<8;return};case 130:{US(0,gD[c[2385643]&8191]()|0);b[4771272]=~~(+(b[9753784+((e&255)<<1)>>1]|0)*+h[1192819])&65535;c[2433446]=(c[2433446]|0)+1&65535;return};case 128:{c[2433446]=c[2433446]&65280|e&255;return};case 1:{f=c[2113304]|0;a[14168504+f|0]=e;mv(0,f,e&255);return};default:{return}}}function a7t(b){b=b|0;var d=0,e=0,f=0.0,g=0.0,i=0;d=b&255;if((d|0)==0){b=c[3541518]|0;e=b+296|0;f=+h[e>>3];do{if(f!=0.0){g=+h[6675];if(f-(g+ +gC[c[2429842]&255]())<=0.0){h[e>>3]=0.0;break}i=a[b+307|0]|-128;return i|0}}while(0);i=a[b+307|0]|0;return i|0}else if((d|0)==2){b=c[3541518]|0;e=b+19320|0;f=+h[e>>3];do{if(f!=0.0){g=+h[6675];if(f-(g+ +gC[c[2429842]&255]())<=0.0){h[e>>3]=0.0;break}i=a[b+19331|0]|-128;return i|0}}while(0);i=a[b+19331|0]|0;return i|0}else if((d|0)==132){i=a[(c[3529826]|0)+(c[2433446]|0)|0]|0;return i|0}else if((d|0)==128){i=a[9758264]|0;return i|0}else{i=0;return i|0}return 0}function a7u(d,e){d=d|0;e=e|0;var f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0;switch(d&255|0){case 0:{d=c[3541518]|0;f=d+256|0;a[d+304|0]=e;g=e&255;if((e&255)<16){c[14168912+((c[2383582]|0)*252|0)>>2]=g&15}if((e-45&255)>=3){return}if((g|0)==0){a[d+312|0]=2;i=2}else if((g|0)==45){j=d+312|0;k=a[j]|2;a[j]=k;i=k}else if((g|0)==47){a[d+312|0]=0;i=0}else if((g|0)==46){g=d+312|0;k=a[g]|1;a[g]=k;i=k}else{i=a[d+312|0]|0}d=i&3;i=c[7461744+(d<<2)>>2]|0;lI(f,i,i,c[7461728+(d<<2)>>2]|0);return};case 131:{d=a[9774152]|32;a[9774152]=d;if(d<<24>>24==-1){a[9706117]=0;return}a[14125144]=d;a[9706117]=1;if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){d=gfc(1e3)|0;l=d;m=(c[2433530]|0)+d|0}else{l=1e3;m=(c[2433530]|0)+1e3|0}c[2433530]=m;c[2444123]=(c[2444123]|0)+l;return};case 3:{lS(1,1,e);return};case 128:{c[2433446]=c[2433446]&65280|e&255;return};case 2:{l=c[3541518]|0;m=l+19280|0;a[l+19328|0]=e;d=e&255;if((e&255)<16){c[14168912+(((c[2383582]|0)+1|0)*252|0)>>2]=d&15}if((e-45&255)>=3){return}if((d|0)==47){a[l+19336|0]=0;n=0}else if((d|0)==46){i=l+19336|0;f=a[i]|1;a[i]=f;n=f}else if((d|0)==45){f=l+19336|0;i=a[f]|2;a[f]=i;n=i}else if((d|0)==0){a[l+19336|0]=2;n=2}else{n=a[l+19336|0]|0}l=n&3;n=c[7461744+(l<<2)>>2]|0;lI(m,n,n,c[7461728+(l<<2)>>2]|0);return};case 1:{lS(0,1,e);return};case 129:{c[2433446]=c[2433446]&255|(e&255)<<8;return};case 130:{US(0,gD[c[2385643]&8191]()|0);b[4771272]=~~(+(b[9753784+((e&255)<<1)>>1]|0)*+h[1192819])&65535;c[2433446]=(c[2433446]|0)+1&65535;return};default:{return}}}function a7v(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7430484+(b*112|0)>>2];c[a+104>>2]=c[7430488+(b*112|0)>>2];c[a+108>>2]=c[7430492+(b*112|0)>>2];d=0;return d|0}function a7w(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=7430384+(b*112|0);e=0;return e|0}function a7x(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6939072+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function a7y(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>50){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7450600+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function a7z(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0;e=i;i=i+2040|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;B=e+1200|0;C=e+1312|0;D=e+1320|0;E=e+1432|0;F=e+1440|0;G=e+1552|0;H=e+1560|0;I=e+1672|0;J=e+1680|0;K=e+1792|0;L=e+1800|0;M=e+1912|0;N=e+1920|0;O=e+2032|0;c[2426822]=0;c[3529134]=0;c[3529118]=163840;c[3529826]=229376;c[2405724]=294912;c[3529160]=294912;c[3529148]=303104;c[2443438]=307200;c[2439628]=307456;c[3527228]=309504;c[3530206]=313600;c[2411888]=315776;c[2406548]=315776;c[3529602]=577920;c[2443614]=1626496;P=0;while(1){if((P|0)>=1024){break}Q=9638528+(P<<2)|0;if((c[Q>>2]|0)==0){R=51053;break}else{P=P+1|0}}do{if((R|0)==51053){P=gGq(2150784)|0;c[Q>>2]=P;if((P|0)==0){break}c[2426822]=P;gGz(P|0,0,2150784);c[3529134]=P;c[3529118]=P+163840;c[3529826]=P+229376;S=P+294912|0;c[2405724]=S;c[3529160]=S;c[3529148]=P+303104;c[2443438]=P+307200;c[2439628]=P+307456;c[3527228]=P+309504;c[3530206]=P+313600;S=P+315776|0;c[2411888]=S;c[2406548]=S;c[3529602]=P+577920;c[2443614]=P+1626496;c[2414440]=P+2150784;P=0;while(1){if((P|0)>=1024){T=0;break}U=9638528+(P<<2)|0;if((c[U>>2]|0)==0){R=51058;break}else{P=P+1|0}}do{if((R|0)==51058){P=gGq(524288)|0;c[U>>2]=P;if((P|0)==0){T=0;break}gGz(P|0,0,524288);T=P}}while(0);c[3529552]=T;P=c[3529134]|0;if((c[3542200]|0)==0){V=1;i=e;return V|0}S=N+108|0;c[S>>2]=0;W=N+100|0;c[W>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](N,0)|0;do{if((c[S>>2]|0)!=0){X=c[W>>2]|0;c[O>>2]=9534384;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Y&16383](O,0,0)|0;if((X|0)<1){V=1;i=e;return V|0}if((gzL(P,0,0)|0)==0){break}else{V=1}i=e;return V|0}}while(0);P=(c[3529134]|0)+65536|0;if((c[3542200]|0)==0){V=1;i=e;return V|0}W=L+108|0;c[W>>2]=0;S=L+100|0;c[S>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](L,1)|0;do{if((c[W>>2]|0)!=0){X=c[S>>2]|0;c[M>>2]=9534384;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Y&16383](M,1,0)|0;if((X|0)<1){V=1;i=e;return V|0}if((gzL(P,0,1)|0)==0){break}else{V=1}i=e;return V|0}}while(0);P=c[3529118]|0;if((c[3542200]|0)==0){V=1;i=e;return V|0}S=J+108|0;c[S>>2]=0;W=J+100|0;c[W>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](J,2)|0;do{if((c[S>>2]|0)!=0){X=c[W>>2]|0;c[K>>2]=9534384;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Y&16383](K,2,0)|0;if((X|0)<1){V=1;i=e;return V|0}if((gzL(P,0,2)|0)==0){break}else{V=1}i=e;return V|0}}while(0);P=c[3529552]|0;if((c[3542200]|0)==0){V=1;i=e;return V|0}W=H+108|0;c[W>>2]=0;S=H+100|0;c[S>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](H,3)|0;do{if((c[W>>2]|0)!=0){X=c[S>>2]|0;c[I>>2]=9534384;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Y&16383](I,3,0)|0;if((X|0)<1){V=1;i=e;return V|0}if((gzL(P,0,3)|0)==0){break}else{V=1}i=e;return V|0}}while(0);P=(c[3529552]|0)+65536|0;if((c[3542200]|0)==0){V=1;i=e;return V|0}S=F+108|0;c[S>>2]=0;W=F+100|0;c[W>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](F,4)|0;do{if((c[S>>2]|0)!=0){X=c[W>>2]|0;c[G>>2]=9534384;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Y&16383](G,4,0)|0;if((X|0)<1){V=1;i=e;return V|0}if((gzL(P,0,4)|0)==0){break}else{V=1}i=e;return V|0}}while(0);P=c[3529552]|0;W=c[2406548]|0;S=0;do{X=S<<6;gGz(W+X|0,0,64);Y=S<<7;Z=0;do{_=1<<3-Z;$=(c[613072+(Z<<2)>>2]|0)+Y|0;aa=0;do{ab=$+(c[1238464+(aa<<2)>>2]|0)|0;ac=(aa<<3)+X|0;ad=0;do{ae=ab+(c[612768+(ad<<2)>>2]|0)|0;if(((d[P+((ae|0)/8|0)|0]|0)&128>>>((ae&7)>>>0)|0)!=0){ae=W+(ac+ad)|0;a[ae]=(d[ae]|0|_)&255}ad=ad+1|0;}while((ad|0)<8);aa=aa+1|0;}while((aa|0)<8);Z=Z+1|0;}while((Z|0)<4);S=S+1|0;}while((S|0)<4096);gGz(P|0,0,524288);if((c[3542200]|0)==0){V=1;i=e;return V|0}S=D+108|0;c[S>>2]=0;W=D+100|0;c[W>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](D,5)|0;do{if((c[S>>2]|0)!=0){Z=c[W>>2]|0;c[E>>2]=9534384;X=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[X&16383](E,5,0)|0;if((Z|0)<1){V=1;i=e;return V|0}if((gzL(P,0,5)|0)==0){break}else{V=1}i=e;return V|0}}while(0);P=(c[3529552]|0)+65536|0;if((c[3542200]|0)==0){V=1;i=e;return V|0}W=B+108|0;c[W>>2]=0;S=B+100|0;c[S>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](B,6)|0;do{if((c[W>>2]|0)!=0){Z=c[S>>2]|0;c[C>>2]=9534384;X=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[X&16383](C,6,0)|0;if((Z|0)<1){V=1;i=e;return V|0}if((gzL(P,0,6)|0)==0){break}else{V=1}i=e;return V|0}}while(0);P=(c[3529552]|0)+131072|0;if((c[3542200]|0)==0){V=1;i=e;return V|0}S=z+108|0;c[S>>2]=0;W=z+100|0;c[W>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,7)|0;do{if((c[S>>2]|0)!=0){Z=c[W>>2]|0;c[A>>2]=9534384;X=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[X&16383](A,7,0)|0;if((Z|0)<1){V=1;i=e;return V|0}if((gzL(P,0,7)|0)==0){break}else{V=1}i=e;return V|0}}while(0);P=(c[3529552]|0)+196608|0;if((c[3542200]|0)==0){V=1;i=e;return V|0}W=x+108|0;c[W>>2]=0;S=x+100|0;c[S>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,8)|0;do{if((c[W>>2]|0)!=0){Z=c[S>>2]|0;c[y>>2]=9534384;X=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[X&16383](y,8,0)|0;if((Z|0)<1){V=1;i=e;return V|0}if((gzL(P,0,8)|0)==0){break}else{V=1}i=e;return V|0}}while(0);P=(c[3529552]|0)+262144|0;if((c[3542200]|0)==0){V=1;i=e;return V|0}S=v+108|0;c[S>>2]=0;W=v+100|0;c[W>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,9)|0;do{if((c[S>>2]|0)!=0){Z=c[W>>2]|0;c[w>>2]=9534384;X=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[X&16383](w,9,0)|0;if((Z|0)<1){V=1;i=e;return V|0}if((gzL(P,0,9)|0)==0){break}else{V=1}i=e;return V|0}}while(0);P=(c[3529552]|0)+327680|0;if((c[3542200]|0)==0){V=1;i=e;return V|0}W=t+108|0;c[W>>2]=0;S=t+100|0;c[S>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,10)|0;do{if((c[W>>2]|0)!=0){Z=c[S>>2]|0;c[u>>2]=9534384;X=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[X&16383](u,10,0)|0;if((Z|0)<1){V=1;i=e;return V|0}if((gzL(P,0,10)|0)==0){break}else{V=1}i=e;return V|0}}while(0);P=(c[3529552]|0)+393216|0;if((c[3542200]|0)==0){V=1;i=e;return V|0}S=r+108|0;c[S>>2]=0;W=r+100|0;c[W>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,11)|0;do{if((c[S>>2]|0)!=0){Z=c[W>>2]|0;c[s>>2]=9534384;X=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[X&16383](s,11,0)|0;if((Z|0)<1){V=1;i=e;return V|0}if((gzL(P,0,11)|0)==0){break}else{V=1}i=e;return V|0}}while(0);P=(c[3529552]|0)+458752|0;if((c[3542200]|0)==0){V=1;i=e;return V|0}W=p+108|0;c[W>>2]=0;S=p+100|0;c[S>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,12)|0;do{if((c[W>>2]|0)!=0){Z=c[S>>2]|0;c[q>>2]=9534384;X=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[X&16383](q,12,0)|0;if((Z|0)<1){V=1;i=e;return V|0}if((gzL(P,0,12)|0)==0){break}else{V=1}i=e;return V|0}}while(0);P=c[3529552]|0;S=c[3529602]|0;W=0;do{Z=W<<8;gGz(S+Z|0,0,256);X=W<<9;Y=0;do{aa=1<<3-Y;_=(c[611168+(Y<<2)>>2]|0)+X|0;$=0;do{ad=_+(c[609008+($<<2)>>2]|0)|0;ac=($<<4)+Z|0;ab=0;do{ae=ad+(c[4969880+(ab<<2)>>2]|0)|0;if(((d[P+((ae|0)/8|0)|0]|0)&128>>>((ae&7)>>>0)|0)!=0){ae=S+(ac+ab)|0;a[ae]=(d[ae]|0|aa)&255}ab=ab+1|0;}while((ab|0)<16);$=$+1|0;}while(($|0)<16);Y=Y+1|0;}while((Y|0)<4);W=W+1|0;}while((W|0)<4096);gGz(P|0,0,524288);if((c[3542200]|0)==0){V=1;i=e;return V|0}W=n+108|0;c[W>>2]=0;S=n+100|0;c[S>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,13)|0;do{if((c[W>>2]|0)!=0){Y=c[S>>2]|0;c[o>>2]=9534384;Z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Z&16383](o,13,0)|0;if((Y|0)<1){V=1;i=e;return V|0}if((gzL(P,0,13)|0)==0){break}else{V=1}i=e;return V|0}}while(0);P=(c[3529552]|0)+65536|0;if((c[3542200]|0)==0){V=1;i=e;return V|0}S=l+108|0;c[S>>2]=0;W=l+100|0;c[W>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,14)|0;do{if((c[S>>2]|0)!=0){Y=c[W>>2]|0;c[m>>2]=9534384;Z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Z&16383](m,14,0)|0;if((Y|0)<1){V=1;i=e;return V|0}if((gzL(P,0,14)|0)==0){break}else{V=1}i=e;return V|0}}while(0);P=(c[3529552]|0)+131072|0;if((c[3542200]|0)==0){V=1;i=e;return V|0}W=j+108|0;c[W>>2]=0;S=j+100|0;c[S>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,15)|0;do{if((c[W>>2]|0)!=0){Y=c[S>>2]|0;c[k>>2]=9534384;Z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Z&16383](k,15,0)|0;if((Y|0)<1){V=1;i=e;return V|0}if((gzL(P,0,15)|0)==0){break}else{V=1}i=e;return V|0}}while(0);P=c[3529552]|0;S=c[2443614]|0;W=0;while(1){Y=W<<5;gGz(S+Y|0,0,32);Z=W<<7;X=0;do{$=Z+(c[2010304+(X<<2)>>2]|0)|0;if(((d[P+(($|0)/8|0)|0]|0)&128>>>(($&7)>>>0)|0)!=0){$=S+(Y+X)|0;a[$]=a[$]|8}X=X+1|0;}while((X|0)<32);X=Z|2;$=0;do{aa=X+(c[2010304+($<<2)>>2]|0)|0;if(((d[P+((aa|0)/8|0)|0]|0)&128>>>((aa&7)>>>0)|0)!=0){aa=S+(Y+$)|0;a[aa]=a[aa]|4}$=$+1|0;}while(($|0)<32);$=Z|4;X=0;do{aa=$+(c[2010304+(X<<2)>>2]|0)|0;if(((d[P+((aa|0)/8|0)|0]|0)&128>>>((aa&7)>>>0)|0)!=0){aa=S+(Y+X)|0;a[aa]=a[aa]|2}X=X+1|0;}while((X|0)<32);X=Z|6;$=0;do{aa=X+(c[2010304+($<<2)>>2]|0)|0;if(((d[P+((aa|0)/8|0)|0]|0)&128>>>((aa&7)>>>0)|0)!=0){aa=S+(Y+$)|0;a[aa]=a[aa]|1}$=$+1|0;}while(($|0)<32);$=W+1|0;if(($|0)<16384){W=$}else{af=0;break}}while(1){if((af|0)>=1024){break}ah=9638528+(af<<2)|0;if((c[ah>>2]|0)==(P|0)){R=51152;break}else{af=af+1|0}}if((R|0)==51152){gGr(P);c[ah>>2]=0}c[3529552]=0;W=c[3529826]|0;if((c[3542200]|0)==0){V=1;i=e;return V|0}S=f+108|0;c[S>>2]=0;$=f+100|0;c[$>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,16)|0;do{if((c[S>>2]|0)!=0){Y=c[$>>2]|0;c[g>>2]=9534384;X=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[X&16383](g,16,0)|0;if((Y|0)<1){V=1;i=e;return V|0}if((gzL(W,0,16)|0)==0){break}else{V=1}i=e;return V|0}}while(0);fwR(0);W=c[2439330]|0;$=(W|0)==0;if(!$){S=W;gGC(9706056,S|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];S=c[3528484]|0;c[2076596]=S;P=c[2417276]|0;c[3541536]=P;c[1836236]=0;c[W+4180>>2]=2338;c[W+4184>>2]=310;c[W+4172>>2]=1566;c[W+4176>>2]=2992;Y=c[3529134]|0;X=0;Z=0;while(1){c[W+76+(Z<<2)>>2]=Y+(Z<<8);aa=X+1&65535;if((aa&65535)>127){ai=0;aj=0;break}else{X=aa;Z=aa&65535}}while(1){Z=Y+(aj<<8)|0;c[W+76+(aj+512<<2)>>2]=Z;c[W+76+(aj+768<<2)>>2]=Z;Z=ai+1&65535;if((Z&65535)>127){ak=128;al=128;break}else{ai=Z;aj=Z&65535}}while(1){c[W+76+(al<<2)>>2]=Y+((al<<8)+32768);Z=ak+1&65535;if((Z&65535)>191){am=128;an=128;break}else{ak=Z;al=Z&65535}}while(1){Z=Y+((an<<8)+32768)|0;c[W+76+(an+512<<2)>>2]=Z;c[W+76+(an+768<<2)>>2]=Z;Z=am+1&65535;if((Z&65535)>191){break}else{am=Z;an=Z&65535}}Y=c[2439628]|0;c[W+876>>2]=Y;Z=Y+256|0;c[W+880>>2]=Z;X=Y+512|0;c[W+884>>2]=X;aa=Y+768|0;c[W+888>>2]=aa;_=Y+1024|0;c[W+892>>2]=_;ab=Y+1280|0;c[W+896>>2]=ab;ac=Y+1536|0;c[W+900>>2]=ac;ad=Y+1792|0;c[W+904>>2]=ad;c[W+2924>>2]=Y;c[W+3948>>2]=Y;c[W+2928>>2]=Z;c[W+3952>>2]=Z;c[W+2932>>2]=X;c[W+3956>>2]=X;c[W+2936>>2]=aa;c[W+3960>>2]=aa;c[W+2940>>2]=_;c[W+3964>>2]=_;c[W+2944>>2]=ab;c[W+3968>>2]=ab;c[W+2948>>2]=ac;c[W+3972>>2]=ac;c[W+2952>>2]=ad;c[W+3976>>2]=ad;ad=c[3527228]|0;c[W+908>>2]=ad;c[W+912>>2]=ad+256;c[W+916>>2]=ad+512;c[W+920>>2]=ad+768;c[W+924>>2]=ad+1024;c[W+928>>2]=ad+1280;c[W+932>>2]=ad+1536;c[W+936>>2]=ad+1792;c[W+940>>2]=ad+2048;c[W+944>>2]=ad+2304;c[W+948>>2]=ad+2560;c[W+952>>2]=ad+2816;c[W+956>>2]=ad+3072;c[W+960>>2]=ad+3328;c[W+964>>2]=ad+3584;c[W+968>>2]=ad+3840;ac=208;ab=208;while(1){c[W+76+(ab+256<<2)>>2]=ad+((ab<<8)-53248);_=ac+1&65535;if((_&65535)>223){ao=208;ap=208;break}else{ac=_;ab=_&65535}}while(1){ab=ad+((ap<<8)-53248)|0;c[W+76+(ap+512<<2)>>2]=ab;c[W+76+(ap+768<<2)>>2]=ab;ab=ao+1&65535;if((ab&65535)>223){break}else{ao=ab;ap=ab&65535}}ad=c[3529160]|0;c[W+972>>2]=ad;c[W+976>>2]=ad+256;c[W+980>>2]=ad+512;c[W+984>>2]=ad+768;c[W+988>>2]=ad+1024;c[W+992>>2]=ad+1280;c[W+996>>2]=ad+1536;c[W+1e3>>2]=ad+1792;c[W+1004>>2]=ad+2048;c[W+1008>>2]=ad+2304;c[W+1012>>2]=ad+2560;c[W+1016>>2]=ad+2816;c[W+1020>>2]=ad+3072;c[W+1024>>2]=ad+3328;c[W+1028>>2]=ad+3584;c[W+1032>>2]=ad+3840;ab=224;ac=224;while(1){c[W+76+(ac+256<<2)>>2]=ad+((ac<<8)-57344);_=ab+1&65535;if((_&65535)>239){aq=224;ar=224;break}else{ab=_;ac=_&65535}}while(1){ac=ad+((ar<<8)-57344)|0;c[W+76+(ar+512<<2)>>2]=ac;c[W+76+(ar+768<<2)>>2]=ac;ac=aq+1&65535;if((ac&65535)>239){break}else{aq=ac;ar=ac&65535}}if(!$){ad=W;gGC(ad|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=S;c[2417276]=P;c[1836236]=-1;fwR(1);ad=c[2439331]|0;ac=(ad|0)==0;if(!ac){ab=ad;gGC(9706056,ab|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];ab=c[3528485]|0;c[2076596]=ab;_=c[2417277]|0;c[3541536]=_;c[1836236]=1;c[ad+4180>>2]=30;c[ad+4184>>2]=1500;c[ad+4172>>2]=3476;c[ad+4176>>2]=286;aa=c[3529118]|0;X=0;Z=0;while(1){c[ad+76+(Z<<2)>>2]=aa+(Z<<8);Y=X+1&65535;if((Y&65535)>191){as=0;at=0;break}else{X=Y;Z=Y&65535}}while(1){Z=aa+(at<<8)|0;c[ad+76+(at+512<<2)>>2]=Z;c[ad+76+(at+768<<2)>>2]=Z;Z=as+1&65535;if((Z&65535)>191){break}else{as=Z;at=Z&65535}}aa=c[3529148]|0;c[ad+1036>>2]=aa;c[ad+1040>>2]=aa+256;c[ad+1044>>2]=aa+512;c[ad+1048>>2]=aa+768;c[ad+1052>>2]=aa+1024;c[ad+1056>>2]=aa+1280;c[ad+1060>>2]=aa+1536;c[ad+1064>>2]=aa+1792;c[ad+1068>>2]=aa+2048;c[ad+1072>>2]=aa+2304;c[ad+1076>>2]=aa+2560;c[ad+1080>>2]=aa+2816;c[ad+1084>>2]=aa+3072;c[ad+1088>>2]=aa+3328;c[ad+1092>>2]=aa+3584;c[ad+1096>>2]=aa+3840;Z=240;X=240;while(1){c[ad+76+(X+256<<2)>>2]=aa+((X<<8)-61440);P=Z+1&65535;if((P&65535)>255){au=240;av=240;break}else{Z=P;X=P&65535}}while(1){X=aa+((av<<8)-61440)|0;c[ad+76+(av+512<<2)>>2]=X;c[ad+76+(av+768<<2)>>2]=X;X=au+1&65535;if((X&65535)>255){break}else{au=X;av=X&65535}}if(!ac){aa=ad;gGC(aa|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=ab;c[2417277]=_;c[1836236]=-1;c[2424]=5500;c[2440556]=65084;c[2440498]=65084;aa=c[642608+(c[2436]<<2)>>2]|0;X=c[aa+128>>2]|0;if((c[aa+52>>2]&4|0)==0){c[2113068]=X;Z=c[aa+132>>2]|0;c[2113070]=Z;c[2443814]=X;c[2440436]=Z;aw=X;ax=Z}else{c[2113070]=X;Z=c[aa+132>>2]|0;c[2113068]=Z;c[2440436]=X;c[2443814]=Z;aw=Z;ax=X}X=ag(aw<<1,ax)|0;Z=gGq(X)|0;c[2112926]=Z;if((Z|0)!=0){gGz(Z|0,0,X|0)}X=a[9680]|0;Z=X?32e3:0;if(X){if(a[9624]|0){X=Z*3|0;aa=55931;while(1){if((aa|0)>(X|0)){aa=aa>>1}else{ay=1222;az=aa;break}}}else{ay=2462;az=Z}c[2429380]=az;c[3542124]=ay;mw(3579645,az);aa=gGq(262144)|0;c[2406684]=aa;gGz(aa|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(3579645,11025)}c[(c[3531464]|0)+44344>>2]=1242;h[745421]=.55;c[2436794]=1;h[745420]=.55;c[2436792]=2;c[2405758]=1;gGz(9542544,0,32);c[2385641]=1;h[1192819]=1.0;c[2385642]=3;c[2385643]=1558;aa=0;do{X=aa*257|0;b[9732544+(aa<<1)>>1]=((X|0)/2|0)&65535;b[9753784+(aa<<1)>>1]=X+32768&65535;aa=aa+1|0;}while((aa|0)<256);c[3528842]=1;h[1192819]=1.0;c[2385642]=3;a73();V=0;i=e;return V|0}}while(0);c[2426822]=0;V=1;i=e;return V|0}function a7A(){var b=0,d=0,e=0,f=0;fwZ();do{if(a[6939720]|0){b=c[3541518]|0;if((b|0)!=0){gGr(b|0);c[3541518]=0}if((c[2385508]|0)>0){c[2113008]=0;c[2076598]=0;c[2383582]=0}c[2438228]=0;c[2433526]=0;c[2406676]=0;c[3528472]=0;b=c[2406680]|0;if((b|0)!=0){gGr(b);c[2406680]=0}c[2385508]=0;c[2432978]=0;a[64240]=0}else{b=c[3531464]|0;c[b+44344>>2]=0;c[b+44348>>2]=0;if((b|0)!=0){gGr(b);c[3531464]=0}b=c[2406684]|0;if((b|0)==0){break}gGr(b);c[2406684]=0}}while(0);UT();c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}b=c[2426822]|0;d=0;while(1){if((d|0)>=1024){break}e=9638528+(d<<2)|0;if((c[e>>2]|0)==(b|0)){f=51279;break}else{d=d+1|0}}if((f|0)==51279){gGr(b);c[e>>2]=0}c[2426822]=0;a[14119368]=0;a[9758264]=0;a[9774152]=0;c[2439586]=0;c[2438758]=0;c[2433472]=0;c[2433474]=0;c[2429520]=0;c[2429522]=0;c[2433446]=0;a[6939720]=0;a[4039520]=0;return 0}function a7B(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;if((a[9625096]|0)!=0){a73()}a[9625898]=0;a[9625897]=0;a[9625896]=0;e=0;f=0;g=0;h=0;do{f=((a[9759312+e|0]&1)<<e|f&255)&255;g=((a[9759120+e|0]&1)<<e|g&255)&255;h=((a[9758928+e|0]&1)<<e|h&255)&255;e=e+1|0;}while((e|0)<8);a[9625896]=f;a[9625897]=g;a[9625898]=h;if((g&3)==3){f=g&-4;a[9625897]=f;i=f}else{i=g}if((i&12)==12){a[9625897]=i&-13}if((h&3)==3){i=h&-4;a[9625898]=i;j=i}else{j=h}if((j&12)==12){a[9625898]=j&-13}c[2444123]=0;c[2444122]=0;j=c[2385548]|0;if((j|0)>0){gGz(9752472,0,((j|0)>1?j<<2:4)|0)}c[2433530]=0;j=0;h=0;L65590:while(1){i=h;while(1){if((i|0)>=256){break L65590}g=c[2439330]|0;if((g|0)!=0){f=g;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;f=c[2438118]|0;c[2433530]=f;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;k=i+1|0;e=(ag(c[2440556]|0,k)|0)/256|0;l=c[2444122]|0;m=e-l|0;c[2438212]=m;do{if((m|0)<1){n=0;o=l}else{if((a[g+4188|0]|0)==0){e=gfc(m)|0;c[2433530]=(c[2433530]|0)+e;n=e;o=c[2444122]|0;break}else{c[2433530]=f+m;n=m;o=l;break}}}while(0);c[2444122]=o+n;if((i|0)==255){a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0}l=c[1836236]|0;m=c[9757320+(l<<2)>>2]|0;if((m|0)!=0){f=m;gGC(f|0,9706056,76)|0}c[9752472+(l<<2)>>2]=c[2433530];c[14113936+(l<<2)>>2]=c[2076596];c[9669104+(l<<2)>>2]=c[3541536];c[1836236]=-1;l=c[2439331]|0;if((l|0)!=0){f=l;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;f=c[2438119]|0;c[2433530]=f;c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;m=c[2440498]|0;if(a[6939720]|0){Sb(ag((m|0)/256|0,i)|0)}else{g=(ag(m,k)|0)/256|0;m=c[2444123]|0;e=g-m|0;c[2438212]=e;do{if((e|0)<1){p=0;q=m}else{if((a[l+4188|0]|0)==0){g=gfc(e)|0;c[2433530]=(c[2433530]|0)+g;p=g;q=c[2444123]|0;break}else{c[2433530]=f+e;p=e;q=m;break}}}while(0);c[2444123]=q+p}if((i&1|0)!=0){if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12}m=c[1836236]|0;e=c[9757320+(m<<2)>>2]|0;if((e|0)!=0){f=e;gGC(f|0,9706056,76)|0}c[9752472+(m<<2)>>2]=c[2433530];c[14113936+(m<<2)>>2]=c[2076596];c[9669104+(m<<2)>>2]=c[3541536];c[1836236]=-1;r=c[2112964]|0;if((r|0)==0|a[6939720]){i=k}else{break}}i=a[9688]|0?2:0;m=c[2439331]|0;if((m|0)!=0){f=m;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;gg[c[3542124]&4095](r+(j<<1<<1)|0,i);f=c[1836236]|0;m=c[9757320+(f<<2)>>2]|0;if((m|0)!=0){e=m;gGC(e|0,9706056,76)|0}c[9752472+(f<<2)>>2]=c[2433530];c[14113936+(f<<2)>>2]=c[2076596];c[9669104+(f<<2)>>2]=c[3541536];c[1836236]=-1;j=i+j|0;h=k}if(a[6939720]|0){k=c[2439331]|0;if((k|0)!=0){h=k;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;h=c[2440498]|0;k=gGU(h,(h|0)<0|0?-1:0,2048e6,0)|0;r=c[2438228]|0;p=gGS(k,K,r,(r|0)<0|0?-1:0)|0;r=p;Sb(h);h=c[2443830]|0;if((h|0)<1073676288){c[2443830]=h-r}h=c[2443831]|0;if((h|0)<1073676288){c[2443831]=h-r}h=(c[3528512]|0)-r|0;c[3528512]=(h|0)<0?0:h;h=c[1836236]|0;r=c[9757320+(h<<2)>>2]|0;if((r|0)!=0){p=r;gGC(p|0,9706056,76)|0}c[9752472+(h<<2)>>2]=c[2433530];c[14113936+(h<<2)>>2]=c[2076596];c[9669104+(h<<2)>>2]=c[3541536];c[1836236]=-1;s=a[6939720]|0}else{s=0}h=c[2112964]|0;if((h|0)==0|s){t=s;u=h}else{s=a[9688]|0?534:0;if((s|0)==(j|0)){v=h;w=j}else{p=c[2439331]|0;if((p|0)!=0){r=p;gGC(9706056,r|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;gg[c[3542124]&4095](h+(j<<1<<1)|0,s-j|0);j=c[1836236]|0;s=c[9757320+(j<<2)>>2]|0;if((s|0)!=0){h=s;gGC(h|0,9706056,76)|0}c[9752472+(j<<2)>>2]=c[2433530];c[14113936+(j<<2)>>2]=c[2076596];c[9669104+(j<<2)>>2]=c[3541536];c[1836236]=-1;v=c[2112964]|0;w=a[9688]|0?534:0}UR(v,w);t=a[6939720]|0;u=c[2112964]|0}if(t&(u|0)!=0){t=c[2439331]|0;if((t|0)!=0){w=t;gGC(9706056,w|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;gg[c[3542122]&4095](u,a[9688]|0?534:0);u=c[1836236]|0;w=c[9757320+(u<<2)>>2]|0;if((w|0)!=0){t=w;gGC(t|0,9706056,76)|0}c[9752472+(u<<2)>>2]=c[2433530];c[14113936+(u<<2)>>2]=c[2076596];c[9669104+(u<<2)>>2]=c[3541536];c[1836236]=-1;UR(c[2112964]|0,a[9688]|0?534:0)}if((c[2112968]|0)==0){return 0}u=a[4039520]|0;t=c[2112926]|0;gGz(t|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);if(u){u=c[3527228]|0;w=c[2406548]|0;v=0;do{j=((v|0)/128|0)<<3;h=d[u+(v|1)|0]|0;s=h>>>4;r=h<<8&3840|d[u+v|0];h=((((v|0)/2|0|0)%64|0)<<3)-64|0;do{if((h|0)>-1){if(!((h|0)<((c[2113068]|0)-8|0)&(j|0)>-1)){x=51360;break}if((j|0)>=((c[2113070]|0)-8|0)){x=51360;break}Si(t,r,h,j,s,4,0,w)}else{x=51360}}while(0);if((x|0)==51360){x=0;Sj(t,r,h,j,s,4,0,w)}v=v+2|0;}while((v|0)<4096);a76();R8(c[3530206]|0);return 0}if((c[2438758]|0)==0){v=c[2429520]|0;w=c[2429522]|0;x=c[2439628]|0;u=c[3530206]|0;p=0;do{k=c[2439586]<<4;c[u+(p+512<<2)>>2]=d[x+(p+1280+k)|0]<<6&1984|d[x+(p+1024+k)|0]<<11&63488|a[x+(p+1536+k)|0]&31;k=c[2439586]<<4;c[u+(p+528<<2)>>2]=d[x+(p+1312+k)|0]<<6&1984|d[x+(p+1056+k)|0]<<11&63488|a[x+(p+1568+k)|0]&31;p=p+1|0;}while((p|0)<16);p=378-v-w|0;w=(p|0)>0?p-2048|0:p;p=c[2443614]|0;v=c[2113070]|0;x=c[2113068]|0;k=0;q=0;while(1){n=(k<<9)+w|0;o=0;i=q;while(1){f=((o|0)>127)<<4;e=(o|0)<(v|0);m=ag(x,o)|0;l=0;g=i;while(1){y=g<<5;z=n+l|0;A=0;do{B=a[p+(A+y)|0]|0;C=z+A|0;do{if(e){if(!((C|0)>-1&(C|0)<(x|0))){break}b[t+(m+C<<1)>>1]=f|B&255|512}}while(0);A=A+1|0;}while((A|0)<32);A=l+32|0;if((A|0)<512){l=A;g=g+1|0}else{break}}g=o+1|0;if((g|0)<256){o=g;i=i+16|0}else{break}}i=k+1|0;if((i|0)<4){k=i;q=q+4096|0}else{break}}a75(0,0);a76();a75(1,0);D=u}else{a75(0,1);a76();a75(1,0);D=c[3530206]|0}R8(D);return 0}function a7C(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;g=i;i=i+288|0;h=g|0;j=g+16|0;k=g+32|0;l=g+48|0;m=g+64|0;n=g+80|0;o=g+96|0;p=g+112|0;q=g+128|0;r=g+144|0;s=g+160|0;t=g+176|0;u=g+192|0;v=g+208|0;w=g+224|0;x=g+240|0;y=g+256|0;z=g+272|0;A=(f|0)==0;if(!A){c[f>>2]=169733}if((e&32|0)!=0){gGz(z|0,0,12);B=c[2405724]|0;c[z>>2]=B;c[z+4>>2]=(c[2411888]|0)-B;c[z+12>>2]=162152;B=c[2076592]|0;gj[B&4095](z)|0}if((e&64|0)!=0){fw$(e);do{if(a[6939720]|0){Vx(e,f)}else{gGz(k|0,0,12);c[k>>2]=8453216;c[k+4>>2]=4;c[k+12>>2]=107480;z=c[2076592]|0;gj[z&4095](k)|0;gGz(j|0,0,12);c[j>>2]=14168504;c[j+4>>2]=256;c[j+12>>2]=476464;z=c[2076592]|0;gj[z&4095](j)|0;if((e&2|0)==0){break}else{C=0}do{mv(0,C,d[14168504+C|0]|0);C=C+1|0;}while((C|0)<256)}}while(0);if(!A){c[f>>2]=169753}if((c[2405758]|0)>0){f=h;A=h|0;C=h+4|0;j=h+12|0;k=0;do{gGz(f|0,0,12);c[A>>2]=9542544+(k<<5);c[C>>2]=2;c[j>>2]=119040;gj[c[2076592]&4095](h)|0;k=k+1|0;}while((k|0)<(c[2405758]|0))}gGz(y|0,0,12);c[y>>2]=9776488;c[y+4>>2]=8;c[y+12>>2]=212472;k=c[2076592]|0;gj[k&4095](y)|0;gGz(x|0,0,12);c[x>>2]=9752848;c[x+4>>2]=4;c[x+12>>2]=436576;y=c[2076592]|0;gj[y&4095](x)|0;gGz(w|0,0,12);c[w>>2]=14119368;c[w+4>>2]=1;c[w+12>>2]=511192;x=c[2076592]|0;gj[x&4095](w)|0;gGz(v|0,0,12);c[v>>2]=9758264;c[v+4>>2]=1;c[v+12>>2]=497064;w=c[2076592]|0;gj[w&4095](v)|0;gGz(u|0,0,12);c[u>>2]=9658104;c[u+4>>2]=3;c[u+12>>2]=483352;v=c[2076592]|0;gj[v&4095](u)|0;gGz(t|0,0,12);c[t>>2]=9625896;c[t+4>>2]=3;c[t+12>>2]=215728;u=c[2076592]|0;gj[u&4095](t)|0;gGz(s|0,0,12);c[s>>2]=9774152;c[s+4>>2]=1;c[s+12>>2]=560536;t=c[2076592]|0;gj[t&4095](s)|0;gGz(r|0,0,12);c[r>>2]=9758344;c[r+4>>2]=4;c[r+12>>2]=559304;s=c[2076592]|0;gj[s&4095](r)|0;gGz(q|0,0,12);c[q>>2]=9755032;c[q+4>>2]=4;c[q+12>>2]=557936;r=c[2076592]|0;gj[r&4095](q)|0;gGz(p|0,0,12);c[p>>2]=9733888;c[p+4>>2]=4;c[p+12>>2]=556336;q=c[2076592]|0;gj[q&4095](p)|0;gGz(o|0,0,12);c[o>>2]=9733896;c[o+4>>2]=4;c[o+12>>2]=555464;p=c[2076592]|0;gj[p&4095](o)|0;gGz(n|0,0,12);c[n>>2]=9718080;c[n+4>>2]=4;c[n+12>>2]=553568;o=c[2076592]|0;gj[o&4095](n)|0;gGz(m|0,0,12);c[m>>2]=9718088;c[m+4>>2]=4;c[m+12>>2]=551696;n=c[2076592]|0;gj[n&4095](m)|0;gGz(l|0,0,12);c[l>>2]=9733784;c[l+4>>2]=4;c[l+12>>2]=549848;m=c[2076592]|0;gj[m&4095](l)|0}if((e&2|0)==0){i=g;return 0}e=c[2439330]|0;l=(e|0)==0;if(!l){m=e;gGC(9706056,m|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];m=c[3528484]|0;c[2076596]=m;n=c[2417276]|0;c[3541536]=n;c[1836236]=0;o=c[3529134]|0;p=((d[14119368]|0)<<14)+32768|0;q=128;r=128;while(1){c[e+76+(r<<2)>>2]=o+(p+(r<<8));s=q+1&65535;if((s&65535)>191){D=128;E=128;break}else{q=s;r=s&65535}}while(1){r=o+(p+(E<<8))|0;c[e+76+(E+512<<2)>>2]=r;c[e+76+(E+768<<2)>>2]=r;r=D+1&65535;if((r&65535)>191){break}else{D=r;E=r&65535}}if(!l){l=e;gGC(l|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=m;c[2417276]=n;c[1836236]=-1;i=g;return 0}function a7D(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7306364+(b*112|0)>>2];c[a+104>>2]=c[7306368+(b*112|0)>>2];c[a+108>>2]=c[7306372+(b*112|0)>>2];d=0;return d|0}function a7E(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=7306264+(b*112|0);e=0;return e|0}function a7F(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7235348+(b*112|0)>>2];c[a+104>>2]=c[7235352+(b*112|0)>>2];c[a+108>>2]=c[7235356+(b*112|0)>>2];d=0;return d|0}function a7G(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=7235248+(b*112|0);e=0;return e|0}function a7H(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6902596+(b*112|0)>>2];c[a+104>>2]=c[6902600+(b*112|0)>>2];c[a+108>>2]=c[6902604+(b*112|0)>>2];d=0;return d|0}function a7I(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=6902496+(b*112|0);e=0;return e|0}function a7J(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7265588+(b*112|0)>>2];c[a+104>>2]=c[7265592+(b*112|0)>>2];c[a+108>>2]=c[7265596+(b*112|0)>>2];d=0;return d|0}function a7K(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=7265488+(b*112|0);e=0;return e|0}function a7L(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3830820+(b*112|0)>>2];c[a+104>>2]=c[3830824+(b*112|0)>>2];c[a+108>>2]=c[3830828+(b*112|0)>>2];d=0;return d|0}function a7M(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=3830720+(b*112|0);e=0;return e|0}function a7N(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1237408+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function a7O(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>48){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3832064+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function a7P(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0;e=i;i=i+2880|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;B=e+1200|0;C=e+1312|0;D=e+1320|0;E=e+1432|0;F=e+1440|0;G=e+1552|0;H=e+1560|0;I=e+1672|0;J=e+1680|0;K=e+1792|0;L=e+1800|0;M=e+1912|0;N=e+1920|0;O=e+2032|0;P=e+2040|0;Q=e+2152|0;R=e+2160|0;S=e+2272|0;T=e+2280|0;U=e+2392|0;V=e+2400|0;W=e+2512|0;X=e+2520|0;Y=e+2632|0;Z=e+2640|0;_=e+2752|0;$=e+2760|0;aa=e+2872|0;c[2426822]=0;c[3529134]=0;c[3529118]=163840;c[3529826]=229376;c[2405724]=294912;c[3529160]=294912;c[3529148]=303104;c[2443438]=307200;c[2439628]=307456;c[3527228]=309504;c[3530206]=313600;c[2411888]=315776;c[2406548]=315776;c[3529602]=577920;c[2443614]=1626496;ab=0;while(1){if((ab|0)>=1024){break}ac=9638528+(ab<<2)|0;if((c[ac>>2]|0)==0){ad=51488;break}else{ab=ab+1|0}}do{if((ad|0)==51488){ab=gGq(2150784)|0;c[ac>>2]=ab;if((ab|0)==0){break}c[2426822]=ab;gGz(ab|0,0,2150784);c[3529134]=ab;c[3529118]=ab+163840;c[3529826]=ab+229376;ae=ab+294912|0;c[2405724]=ae;c[3529160]=ae;c[3529148]=ab+303104;c[2443438]=ab+307200;c[2439628]=ab+307456;c[3527228]=ab+309504;c[3530206]=ab+313600;ae=ab+315776|0;c[2411888]=ae;c[2406548]=ae;c[3529602]=ab+577920;c[2443614]=ab+1626496;c[2414440]=ab+2150784;ab=0;while(1){if((ab|0)>=1024){af=0;break}ah=9638528+(ab<<2)|0;if((c[ah>>2]|0)==0){ad=51493;break}else{ab=ab+1|0}}do{if((ad|0)==51493){ab=gGq(524288)|0;c[ah>>2]=ab;if((ab|0)==0){af=0;break}gGz(ab|0,0,524288);af=ab}}while(0);c[3529552]=af;ab=c[642608+(c[2436]<<2)>>2]|0;ae=(fa(c[ab>>2]|0,500448)|0)==0;ai=c[3529134]|0;do{if((c[3542200]|0)==0){aj=1}else{ak=$+108|0;c[ak>>2]=0;al=$+100|0;c[al>>2]=0;am=c[ab+76>>2]|0;gA[am&16383]($,0)|0;if((c[ak>>2]|0)==0){aj=0;break}ak=c[al>>2]|0;c[aa>>2]=9534384;al=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[al&16383](aa,0,0)|0;if((ak|0)<1){aj=1;break}aj=(gzL(ai,0,0)|0)!=0}}while(0);do{if(ae){if(aj){an=1;i=e;return an|0}ai=(c[3529134]|0)+65536|0;if((c[3542200]|0)==0){an=1;i=e;return an|0}ab=Z+108|0;c[ab>>2]=0;ak=Z+100|0;c[ak>>2]=0;al=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[al&16383](Z,1)|0;do{if((c[ab>>2]|0)!=0){al=c[ak>>2]|0;c[_>>2]=9534384;am=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[am&16383](_,1,0)|0;if((al|0)<1){an=1;i=e;return an|0}if((gzL(ai,0,1)|0)==0){break}else{an=1}i=e;return an|0}}while(0);ai=(c[3529134]|0)+131072|0;if((c[3542200]|0)==0){an=1;i=e;return an|0}ak=X+108|0;c[ak>>2]=0;ab=X+100|0;c[ab>>2]=0;al=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[al&16383](X,2)|0;do{if((c[ak>>2]|0)!=0){al=c[ab>>2]|0;c[Y>>2]=9534384;am=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[am&16383](Y,2,0)|0;if((al|0)<1){an=1;i=e;return an|0}if((gzL(ai,0,2)|0)==0){break}else{an=1}i=e;return an|0}}while(0);ai=(c[3529134]|0)+163840|0;if((c[3542200]|0)==0){an=1;i=e;return an|0}ab=V+108|0;c[ab>>2]=0;ak=V+100|0;c[ak>>2]=0;al=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[al&16383](V,2)|0;do{if((c[ab>>2]|0)!=0){al=c[ak>>2]|0;c[W>>2]=9534384;am=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[am&16383](W,2,0)|0;if((al|0)<1){an=1;i=e;return an|0}if((gzL(ai,0,2)|0)==0){break}else{an=1}i=e;return an|0}}while(0);ai=c[3529118]|0;if((c[3542200]|0)==0){an=1;i=e;return an|0}ak=T+108|0;c[ak>>2]=0;ab=T+100|0;c[ab>>2]=0;al=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[al&16383](T,3)|0;do{if((c[ak>>2]|0)!=0){al=c[ab>>2]|0;c[U>>2]=9534384;am=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[am&16383](U,3,0)|0;if((al|0)<1){an=1;i=e;return an|0}if((gzL(ai,0,3)|0)==0){break}else{an=1}i=e;return an|0}}while(0);ai=c[3529552]|0;if((c[3542200]|0)==0){an=1;i=e;return an|0}ab=R+108|0;c[ab>>2]=0;ak=R+100|0;c[ak>>2]=0;al=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[al&16383](R,4)|0;do{if((c[ab>>2]|0)!=0){al=c[ak>>2]|0;c[S>>2]=9534384;am=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[am&16383](S,4,0)|0;if((al|0)<1){an=1;i=e;return an|0}if((gzL(ai,0,4)|0)==0){break}else{an=1}i=e;return an|0}}while(0);ai=(c[3529552]|0)+65536|0;if((c[3542200]|0)==0){an=1;i=e;return an|0}ak=P+108|0;c[ak>>2]=0;ab=P+100|0;c[ab>>2]=0;al=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[al&16383](P,5)|0;do{if((c[ak>>2]|0)!=0){al=c[ab>>2]|0;c[Q>>2]=9534384;am=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[am&16383](Q,5,0)|0;if((al|0)<1){an=1;i=e;return an|0}if((gzL(ai,0,5)|0)==0){break}else{an=1}i=e;return an|0}}while(0);ai=c[3529552]|0;ab=c[2406548]|0;ak=0;do{al=ak<<6;gGz(ab+al|0,0,64);am=ak<<7;ao=0;do{ap=1<<3-ao;aq=(c[613072+(ao<<2)>>2]|0)+am|0;ar=0;do{as=aq+(c[1238464+(ar<<2)>>2]|0)|0;at=(ar<<3)+al|0;au=0;do{av=as+(c[612768+(au<<2)>>2]|0)|0;if(((d[ai+((av|0)/8|0)|0]|0)&128>>>((av&7)>>>0)|0)!=0){av=ab+(at+au)|0;a[av]=(d[av]|0|ap)&255}au=au+1|0;}while((au|0)<8);ar=ar+1|0;}while((ar|0)<8);ao=ao+1|0;}while((ao|0)<4);ak=ak+1|0;}while((ak|0)<4096);gGz(ai|0,0,524288);if((c[3542200]|0)==0){an=1;i=e;return an|0}ak=N+108|0;c[ak>>2]=0;ab=N+100|0;c[ab>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](N,6)|0;do{if((c[ak>>2]|0)!=0){ao=c[ab>>2]|0;c[O>>2]=9534384;al=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[al&16383](O,6,0)|0;if((ao|0)<1){an=1;i=e;return an|0}if((gzL(ai,0,6)|0)==0){break}else{an=1}i=e;return an|0}}while(0);ai=(c[3529552]|0)+131072|0;if((c[3542200]|0)==0){an=1;i=e;return an|0}ab=L+108|0;c[ab>>2]=0;ak=L+100|0;c[ak>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](L,6)|0;do{if((c[ab>>2]|0)!=0){ao=c[ak>>2]|0;c[M>>2]=9534384;al=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[al&16383](M,6,0)|0;if((ao|0)<1){an=1;i=e;return an|0}if((gzL(ai,0,6)|0)==0){break}else{an=1}i=e;return an|0}}while(0);ai=(c[3529552]|0)+65536|0;if((c[3542200]|0)==0){an=1;i=e;return an|0}ak=J+108|0;c[ak>>2]=0;ab=J+100|0;c[ab>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](J,7)|0;do{if((c[ak>>2]|0)!=0){ao=c[ab>>2]|0;c[K>>2]=9534384;al=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[al&16383](K,7,0)|0;if((ao|0)<1){an=1;i=e;return an|0}if((gzL(ai,0,7)|0)==0){break}else{an=1}i=e;return an|0}}while(0);ai=(c[3529552]|0)+196608|0;if((c[3542200]|0)==0){an=1;i=e;return an|0}ab=H+108|0;c[ab>>2]=0;ak=H+100|0;c[ak>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](H,7)|0;do{if((c[ab>>2]|0)!=0){ao=c[ak>>2]|0;c[I>>2]=9534384;al=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[al&16383](I,7,0)|0;if((ao|0)<1){an=1;i=e;return an|0}if((gzL(ai,0,7)|0)==0){break}else{an=1}i=e;return an|0}}while(0);ai=(c[3529552]|0)+262144|0;if((c[3542200]|0)==0){an=1;i=e;return an|0}ak=F+108|0;c[ak>>2]=0;ab=F+100|0;c[ab>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](F,8)|0;do{if((c[ak>>2]|0)!=0){ao=c[ab>>2]|0;c[G>>2]=9534384;al=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[al&16383](G,8,0)|0;if((ao|0)<1){an=1;i=e;return an|0}if((gzL(ai,0,8)|0)==0){break}else{an=1}i=e;return an|0}}while(0);ai=(c[3529552]|0)+393216|0;if((c[3542200]|0)==0){an=1;i=e;return an|0}ab=D+108|0;c[ab>>2]=0;ak=D+100|0;c[ak>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](D,8)|0;do{if((c[ab>>2]|0)!=0){ao=c[ak>>2]|0;c[E>>2]=9534384;al=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[al&16383](E,8,0)|0;if((ao|0)<1){an=1;i=e;return an|0}if((gzL(ai,0,8)|0)==0){break}else{an=1}i=e;return an|0}}while(0);ai=(c[3529552]|0)+327680|0;if((c[3542200]|0)==0){an=1;i=e;return an|0}ak=B+108|0;c[ak>>2]=0;ab=B+100|0;c[ab>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](B,9)|0;do{if((c[ak>>2]|0)!=0){ao=c[ab>>2]|0;c[C>>2]=9534384;al=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[al&16383](C,9,0)|0;if((ao|0)<1){an=1;i=e;return an|0}if((gzL(ai,0,9)|0)==0){break}else{an=1}i=e;return an|0}}while(0);ai=(c[3529552]|0)+458752|0;if((c[3542200]|0)==0){an=1;i=e;return an|0}ab=z+108|0;c[ab>>2]=0;ak=z+100|0;c[ak>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,9)|0;do{if((c[ab>>2]|0)!=0){ao=c[ak>>2]|0;c[A>>2]=9534384;al=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[al&16383](A,9,0)|0;if((ao|0)<1){an=1;i=e;return an|0}if((gzL(ai,0,9)|0)==0){break}else{an=1}i=e;return an|0}}while(0);ai=c[3529552]|0;ak=c[3529602]|0;ab=0;do{ao=ab<<8;gGz(ak+ao|0,0,256);al=ab<<9;am=0;do{ar=1<<3-am;ap=(c[611168+(am<<2)>>2]|0)+al|0;aq=0;do{au=ap+(c[609008+(aq<<2)>>2]|0)|0;at=(aq<<4)+ao|0;as=0;do{av=au+(c[4969880+(as<<2)>>2]|0)|0;if(((d[ai+((av|0)/8|0)|0]|0)&128>>>((av&7)>>>0)|0)!=0){av=ak+(at+as)|0;a[av]=(d[av]|0|ar)&255}as=as+1|0;}while((as|0)<16);aq=aq+1|0;}while((aq|0)<16);am=am+1|0;}while((am|0)<4);ab=ab+1|0;}while((ab|0)<4096);ab=c[3529826]|0;if((c[3542200]|0)==0){an=1;i=e;return an|0}ak=x+108|0;c[ak>>2]=0;ai=x+100|0;c[ai>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,10)|0;if((c[ak>>2]|0)==0){break}ak=c[ai>>2]|0;c[y>>2]=9534384;gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](y,10,0)|0;if((ak|0)<1){an=1;i=e;return an|0}if((gzL(ab,0,10)|0)==0){break}else{an=1}i=e;return an|0}else{if(aj){an=1;i=e;return an|0}ab=(c[3529134]|0)+65536|0;if((c[3542200]|0)==0){an=1;i=e;return an|0}ak=v+108|0;c[ak>>2]=0;ai=v+100|0;c[ai>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,1)|0;do{if((c[ak>>2]|0)!=0){am=c[ai>>2]|0;c[w>>2]=9534384;ao=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ao&16383](w,1,0)|0;if((am|0)<1){an=1;i=e;return an|0}if((gzL(ab,0,1)|0)==0){break}else{an=1}i=e;return an|0}}while(0);ab=(c[3529134]|0)+131072|0;if((c[3542200]|0)==0){an=1;i=e;return an|0}ai=t+108|0;c[ai>>2]=0;ak=t+100|0;c[ak>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,2)|0;do{if((c[ai>>2]|0)!=0){am=c[ak>>2]|0;c[u>>2]=9534384;ao=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ao&16383](u,2,0)|0;if((am|0)<1){an=1;i=e;return an|0}if((gzL(ab,0,2)|0)==0){break}else{an=1}i=e;return an|0}}while(0);ab=c[3529118]|0;if((c[3542200]|0)==0){an=1;i=e;return an|0}ak=r+108|0;c[ak>>2]=0;ai=r+100|0;c[ai>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,3)|0;do{if((c[ak>>2]|0)!=0){am=c[ai>>2]|0;c[s>>2]=9534384;ao=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ao&16383](s,3,0)|0;if((am|0)<1){an=1;i=e;return an|0}if((gzL(ab,0,3)|0)==0){break}else{an=1}i=e;return an|0}}while(0);ab=c[3529552]|0;if((c[3542200]|0)==0){an=1;i=e;return an|0}ai=p+108|0;c[ai>>2]=0;ak=p+100|0;c[ak>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,4)|0;do{if((c[ai>>2]|0)!=0){am=c[ak>>2]|0;c[q>>2]=9534384;ao=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ao&16383](q,4,0)|0;if((am|0)<1){an=1;i=e;return an|0}if((gzL(ab,0,4)|0)==0){break}else{an=1}i=e;return an|0}}while(0);ab=(c[3529552]|0)+65536|0;if((c[3542200]|0)==0){an=1;i=e;return an|0}ak=n+108|0;c[ak>>2]=0;ai=n+100|0;c[ai>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,5)|0;do{if((c[ak>>2]|0)!=0){am=c[ai>>2]|0;c[o>>2]=9534384;ao=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ao&16383](o,5,0)|0;if((am|0)<1){an=1;i=e;return an|0}if((gzL(ab,0,5)|0)==0){break}else{an=1}i=e;return an|0}}while(0);ab=c[3529552]|0;ai=c[2406548]|0;ak=0;do{am=ak<<6;gGz(ai+am|0,0,64);ao=ak<<7;al=0;do{aq=1<<3-al;ar=(c[613072+(al<<2)>>2]|0)+ao|0;ap=0;do{as=ar+(c[1238464+(ap<<2)>>2]|0)|0;at=(ap<<3)+am|0;au=0;do{av=as+(c[612768+(au<<2)>>2]|0)|0;if(((d[ab+((av|0)/8|0)|0]|0)&128>>>((av&7)>>>0)|0)!=0){av=ai+(at+au)|0;a[av]=(d[av]|0|aq)&255}au=au+1|0;}while((au|0)<8);ap=ap+1|0;}while((ap|0)<8);al=al+1|0;}while((al|0)<4);ak=ak+1|0;}while((ak|0)<4096);gGz(ab|0,0,524288);if((c[3542200]|0)==0){an=1;i=e;return an|0}ak=l+108|0;c[ak>>2]=0;ai=l+100|0;c[ai>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,6)|0;do{if((c[ak>>2]|0)!=0){al=c[ai>>2]|0;c[m>>2]=9534384;am=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[am&16383](m,6,0)|0;if((al|0)<1){an=1;i=e;return an|0}if((gzL(ab,0,6)|0)==0){break}else{an=1}i=e;return an|0}}while(0);ab=(c[3529552]|0)+262144|0;if((c[3542200]|0)==0){an=1;i=e;return an|0}ai=j+108|0;c[ai>>2]=0;ak=j+100|0;c[ak>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,7)|0;do{if((c[ai>>2]|0)!=0){al=c[ak>>2]|0;c[k>>2]=9534384;am=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[am&16383](k,7,0)|0;if((al|0)<1){an=1;i=e;return an|0}if((gzL(ab,0,7)|0)==0){break}else{an=1}i=e;return an|0}}while(0);ab=c[3529552]|0;ak=c[3529602]|0;ai=0;do{al=ai<<8;gGz(ak+al|0,0,256);am=ai<<9;ao=0;do{ap=1<<3-ao;aq=(c[611168+(ao<<2)>>2]|0)+am|0;ar=0;do{au=aq+(c[609008+(ar<<2)>>2]|0)|0;at=(ar<<4)+al|0;as=0;do{av=au+(c[4969880+(as<<2)>>2]|0)|0;if(((d[ab+((av|0)/8|0)|0]|0)&128>>>((av&7)>>>0)|0)!=0){av=ak+(at+as)|0;a[av]=(d[av]|0|ap)&255}as=as+1|0;}while((as|0)<16);ar=ar+1|0;}while((ar|0)<16);ao=ao+1|0;}while((ao|0)<4);ai=ai+1|0;}while((ai|0)<4096);ai=c[3529826]|0;if((c[3542200]|0)==0){an=1;i=e;return an|0}ak=f+108|0;c[ak>>2]=0;ab=f+100|0;c[ab>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,8)|0;if((c[ak>>2]|0)==0){break}ak=c[ab>>2]|0;c[g>>2]=9534384;gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](g,8,0)|0;if((ak|0)<1){an=1;i=e;return an|0}if((gzL(ai,0,8)|0)==0){break}else{an=1}i=e;return an|0}}while(0);ae=c[3529552]|0;ai=0;while(1){if((ai|0)>=1024){break}aw=9638528+(ai<<2)|0;if((c[aw>>2]|0)==(ae|0)){ad=51637;break}else{ai=ai+1|0}}if((ad|0)==51637){gGr(ae);c[aw>>2]=0}c[3529552]=0;fwR(0);ai=c[2439330]|0;ak=(ai|0)==0;if(!ak){ab=ai;gGC(9706056,ab|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];ab=c[3528484]|0;c[2076596]=ab;ao=c[2417276]|0;c[3541536]=ao;c[1836236]=0;c[ai+4180>>2]=2206;c[ai+4184>>2]=3274;c[ai+4172>>2]=2474;c[ai+4176>>2]=1270;al=c[3529134]|0;am=0;ar=0;while(1){c[ai+76+(ar<<2)>>2]=al+(ar<<8);ap=am+1&65535;if((ap&65535)>127){ax=0;ay=0;break}else{am=ap;ar=ap&65535}}while(1){ar=al+(ay<<8)|0;c[ai+76+(ay+512<<2)>>2]=ar;c[ai+76+(ay+768<<2)>>2]=ar;ar=ax+1&65535;if((ar&65535)>127){az=128;aA=128;break}else{ax=ar;ay=ar&65535}}while(1){c[ai+76+(aA<<2)>>2]=al+((aA<<8)+32768);ar=az+1&65535;if((ar&65535)>191){aB=128;aC=128;break}else{az=ar;aA=ar&65535}}while(1){ar=al+((aC<<8)+32768)|0;c[ai+76+(aC+512<<2)>>2]=ar;c[ai+76+(aC+768<<2)>>2]=ar;ar=aB+1&65535;if((ar&65535)>191){break}else{aB=ar;aC=ar&65535}}al=c[2443438]|0;c[ai+844>>2]=al;c[ai+1868>>2]=al;c[ai+2892>>2]=al;c[ai+3916>>2]=al;al=c[2439628]|0;c[ai+876>>2]=al;ar=al+256|0;c[ai+880>>2]=ar;am=al+512|0;c[ai+884>>2]=am;c[ai+2924>>2]=al;c[ai+3948>>2]=al;c[ai+2928>>2]=ar;c[ai+3952>>2]=ar;c[ai+2932>>2]=am;c[ai+3956>>2]=am;am=c[3527228]|0;c[ai+908>>2]=am;c[ai+912>>2]=am+256;c[ai+916>>2]=am+512;c[ai+920>>2]=am+768;c[ai+924>>2]=am+1024;c[ai+928>>2]=am+1280;c[ai+932>>2]=am+1536;c[ai+936>>2]=am+1792;c[ai+940>>2]=am+2048;c[ai+944>>2]=am+2304;c[ai+948>>2]=am+2560;c[ai+952>>2]=am+2816;c[ai+956>>2]=am+3072;c[ai+960>>2]=am+3328;c[ai+964>>2]=am+3584;c[ai+968>>2]=am+3840;ar=208;al=208;while(1){c[ai+76+(al+256<<2)>>2]=am+((al<<8)-53248);ae=ar+1&65535;if((ae&65535)>223){aD=208;aE=208;break}else{ar=ae;al=ae&65535}}while(1){al=am+((aE<<8)-53248)|0;c[ai+76+(aE+512<<2)>>2]=al;c[ai+76+(aE+768<<2)>>2]=al;al=aD+1&65535;if((al&65535)>223){break}else{aD=al;aE=al&65535}}am=c[3529160]|0;al=224;ar=224;while(1){c[ai+76+(ar<<2)>>2]=am+((ar<<8)-57344);ae=al+1&65535;if((ae&65535)>255){aF=224;aG=224;break}else{al=ae;ar=ae&65535}}while(1){c[ai+76+(aG+256<<2)>>2]=am+((aG<<8)-57344);ar=aF+1&65535;if((ar&65535)>255){aH=224;aI=224;break}else{aF=ar;aG=ar&65535}}while(1){ar=am+((aI<<8)-57344)|0;c[ai+76+(aI+512<<2)>>2]=ar;c[ai+76+(aI+768<<2)>>2]=ar;ar=aH+1&65535;if((ar&65535)>255){break}else{aH=ar;aI=ar&65535}}if(!ak){am=ai;gGC(am|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=ab;c[2417276]=ao;c[1836236]=-1;fwR(1);am=c[2439331]|0;ar=(am|0)==0;if(!ar){al=am;gGC(9706056,al|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];al=c[3528485]|0;c[2076596]=al;ae=c[2417277]|0;c[3541536]=ae;c[1836236]=1;c[am+4180>>2]=30;c[am+4184>>2]=1500;c[am+4172>>2]=3476;c[am+4176>>2]=286;ap=c[3529118]|0;aq=0;as=0;while(1){c[am+76+(as<<2)>>2]=ap+(as<<8);at=aq+1&65535;if((at&65535)>191){aJ=0;aK=0;break}else{aq=at;as=at&65535}}while(1){as=ap+(aK<<8)|0;c[am+76+(aK+512<<2)>>2]=as;c[am+76+(aK+768<<2)>>2]=as;as=aJ+1&65535;if((as&65535)>191){break}else{aJ=as;aK=as&65535}}ap=c[3529148]|0;c[am+1036>>2]=ap;c[am+1040>>2]=ap+256;c[am+1044>>2]=ap+512;c[am+1048>>2]=ap+768;c[am+1052>>2]=ap+1024;c[am+1056>>2]=ap+1280;c[am+1060>>2]=ap+1536;c[am+1064>>2]=ap+1792;c[am+1068>>2]=ap+2048;c[am+1072>>2]=ap+2304;c[am+1076>>2]=ap+2560;c[am+1080>>2]=ap+2816;c[am+1084>>2]=ap+3072;c[am+1088>>2]=ap+3328;c[am+1092>>2]=ap+3584;c[am+1096>>2]=ap+3840;as=240;aq=240;while(1){c[am+76+(aq+256<<2)>>2]=ap+((aq<<8)-61440);ao=as+1&65535;if((ao&65535)>255){aL=240;aM=240;break}else{as=ao;aq=ao&65535}}while(1){aq=ap+((aM<<8)-61440)|0;c[am+76+(aM+512<<2)>>2]=aq;c[am+76+(aM+768<<2)>>2]=aq;aq=aL+1&65535;if((aq&65535)>255){break}else{aL=aq;aM=aq&65535}}if(!ar){ap=am;gGC(ap|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=al;c[2417277]=ae;c[1836236]=-1;c[2424]=5500;c[2440556]=65084;c[2440498]=65084;ap=c[642608+(c[2436]<<2)>>2]|0;aq=c[ap+128>>2]|0;if((c[ap+52>>2]&4|0)==0){c[2113068]=aq;as=c[ap+132>>2]|0;c[2113070]=as;c[2443814]=aq;c[2440436]=as;aN=aq;aO=as}else{c[2113070]=aq;as=c[ap+132>>2]|0;c[2113068]=as;c[2440436]=aq;c[2443814]=as;aN=as;aO=aq}aq=ag(aN<<1,aO)|0;as=gGq(aq)|0;c[2112926]=as;if((as|0)!=0){gGz(as|0,0,aq|0)}aq=a[9680]|0;as=aq?32e3:0;if(aq){if(a[9624]|0){aq=as*3|0;ap=55931;while(1){if((ap|0)>(aq|0)){ap=ap>>1}else{aP=1222;aQ=ap;break}}}else{aP=2462;aQ=as}c[2429380]=aQ;c[3542124]=aP;mw(3579645,aQ);ap=gGq(262144)|0;c[2406684]=ap;gGz(ap|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(3579645,11025)}c[(c[3531464]|0)+44344>>2]=1242;h[745421]=.55;c[2436794]=1;h[745420]=.55;c[2436792]=2;c[2405758]=1;gGz(9542544,0,32);c[2385641]=1;h[1192819]=1.0;c[2385642]=3;c[2385643]=1558;ap=0;do{aq=ap*257|0;b[9732544+(ap<<1)>>1]=((aq|0)/2|0)&65535;b[9753784+(ap<<1)>>1]=aq+32768&65535;ap=ap+1|0;}while((ap|0)<256);c[3528842]=1;h[1192819]=1.0;c[2385642]=3;a[4039520]=1;a73();an=0;i=e;return an|0}}while(0);c[2426822]=0;an=1;i=e;return an|0}function a7Q(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1864740+(b*112|0)>>2];c[a+104>>2]=c[1864744+(b*112|0)>>2];c[a+108>>2]=c[1864748+(b*112|0)>>2];d=0;return d|0}function a7R(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=1864640+(b*112|0);e=0;return e|0}function a7S(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4194684+(b*112|0)>>2];c[a+104>>2]=c[4194688+(b*112|0)>>2];c[a+108>>2]=c[4194692+(b*112|0)>>2];d=0;return d|0}function a7T(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=4194584+(b*112|0);e=0;return e|0}function a7U(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1304288+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function a7V(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>53){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4196712+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function a7W(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0;e=i;i=i+1440|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;B=e+1200|0;C=e+1312|0;D=e+1320|0;E=e+1432|0;c[2426822]=0;c[3529134]=0;c[3529118]=163840;c[3529826]=229376;c[2405724]=294912;c[3529160]=294912;c[3529148]=303104;c[2443438]=307200;c[2439628]=307456;c[3527228]=309504;c[3530206]=313600;c[2411888]=315776;c[2406548]=315776;c[3529602]=577920;c[2443614]=1626496;F=0;while(1){if((F|0)>=1024){break}G=9638528+(F<<2)|0;if((c[G>>2]|0)==0){H=51793;break}else{F=F+1|0}}do{if((H|0)==51793){F=gGq(2150784)|0;c[G>>2]=F;if((F|0)==0){break}c[2426822]=F;gGz(F|0,0,2150784);c[3529134]=F;c[3529118]=F+163840;c[3529826]=F+229376;I=F+294912|0;c[2405724]=I;c[3529160]=I;c[3529148]=F+303104;c[2443438]=F+307200;c[2439628]=F+307456;c[3527228]=F+309504;c[3530206]=F+313600;I=F+315776|0;c[2411888]=I;c[2406548]=I;c[3529602]=F+577920;c[2443614]=F+1626496;c[2414440]=F+2150784;F=0;while(1){if((F|0)>=1024){J=0;break}K=9638528+(F<<2)|0;if((c[K>>2]|0)==0){H=51798;break}else{F=F+1|0}}do{if((H|0)==51798){F=gGq(524288)|0;c[K>>2]=F;if((F|0)==0){J=0;break}gGz(F|0,0,524288);J=F}}while(0);c[3529552]=J;F=c[3529134]|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}I=D+108|0;c[I>>2]=0;M=D+100|0;c[M>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](D,0)|0;do{if((c[I>>2]|0)!=0){N=c[M>>2]|0;c[E>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](E,0,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(F,0,0)|0)==0){break}else{L=1}i=e;return L|0}}while(0);F=(c[3529134]|0)+65536|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}M=B+108|0;c[M>>2]=0;I=B+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](B,1)|0;do{if((c[M>>2]|0)!=0){N=c[I>>2]|0;c[C>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](C,1,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(F,0,1)|0)==0){break}else{L=1}i=e;return L|0}}while(0);F=c[3529118]|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}I=z+108|0;c[I>>2]=0;M=z+100|0;c[M>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,2)|0;do{if((c[I>>2]|0)!=0){N=c[M>>2]|0;c[A>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](A,2,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(F,0,2)|0)==0){break}else{L=1}i=e;return L|0}}while(0);F=c[3529552]|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}M=x+108|0;c[M>>2]=0;I=x+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,3)|0;do{if((c[M>>2]|0)!=0){N=c[I>>2]|0;c[y>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](y,3,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(F,0,3)|0)==0){break}else{L=1}i=e;return L|0}}while(0);F=(c[3529552]|0)+65536|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}I=v+108|0;c[I>>2]=0;M=v+100|0;c[M>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,4)|0;do{if((c[I>>2]|0)!=0){N=c[M>>2]|0;c[w>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](w,4,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(F,0,4)|0)==0){break}else{L=1}i=e;return L|0}}while(0);F=c[3529552]|0;M=c[2406548]|0;I=0;do{N=I<<6;gGz(M+N|0,0,64);O=I<<7;P=0;do{Q=1<<3-P;R=(c[613072+(P<<2)>>2]|0)+O|0;S=0;do{T=R+(c[1238464+(S<<2)>>2]|0)|0;U=(S<<3)+N|0;V=0;do{W=T+(c[612768+(V<<2)>>2]|0)|0;if(((d[F+((W|0)/8|0)|0]|0)&128>>>((W&7)>>>0)|0)!=0){W=M+(U+V)|0;a[W]=(d[W]|0|Q)&255}V=V+1|0;}while((V|0)<8);S=S+1|0;}while((S|0)<8);P=P+1|0;}while((P|0)<4);I=I+1|0;}while((I|0)<4096);gGz(F|0,0,524288);if((c[3542200]|0)==0){L=1;i=e;return L|0}I=t+108|0;c[I>>2]=0;M=t+100|0;c[M>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,5)|0;do{if((c[I>>2]|0)!=0){P=c[M>>2]|0;c[u>>2]=9534384;N=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[N&16383](u,5,0)|0;if((P|0)<1){L=1;i=e;return L|0}if((gzL(F,0,5)|0)==0){break}else{L=1}i=e;return L|0}}while(0);F=c[3529552]|0;M=F+131072|0;I=F+65536|0;gGC(M|0,I|0,65536)|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}M=r+108|0;c[M>>2]=0;F=r+100|0;c[F>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,6)|0;do{if((c[M>>2]|0)!=0){P=c[F>>2]|0;c[s>>2]=9534384;N=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[N&16383](s,6,0)|0;if((P|0)<1){L=1;i=e;return L|0}if((gzL(I,0,6)|0)==0){break}else{L=1}i=e;return L|0}}while(0);I=(c[3529552]|0)+262144|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}F=p+108|0;c[F>>2]=0;M=p+100|0;c[M>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,7)|0;do{if((c[F>>2]|0)!=0){P=c[M>>2]|0;c[q>>2]=9534384;N=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[N&16383](q,7,0)|0;if((P|0)<1){L=1;i=e;return L|0}if((gzL(I,0,7)|0)==0){break}else{L=1}i=e;return L|0}}while(0);I=c[3529552]|0;M=I+393216|0;F=I+327680|0;gGC(M|0,F|0,65536)|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}M=n+108|0;c[M>>2]=0;I=n+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,8)|0;do{if((c[M>>2]|0)!=0){P=c[I>>2]|0;c[o>>2]=9534384;N=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[N&16383](o,8,0)|0;if((P|0)<1){L=1;i=e;return L|0}if((gzL(F,0,8)|0)==0){break}else{L=1}i=e;return L|0}}while(0);F=c[3529552]|0;I=c[3529602]|0;M=0;do{P=M<<8;gGz(I+P|0,0,256);N=M<<9;O=0;do{S=1<<3-O;Q=(c[611168+(O<<2)>>2]|0)+N|0;R=0;do{V=Q+(c[609008+(R<<2)>>2]|0)|0;U=(R<<4)+P|0;T=0;do{W=V+(c[610128+(T<<2)>>2]|0)|0;if(((d[F+((W|0)/8|0)|0]|0)&128>>>((W&7)>>>0)|0)!=0){W=I+(U+T)|0;a[W]=(d[W]|0|S)&255}T=T+1|0;}while((T|0)<16);R=R+1|0;}while((R|0)<16);O=O+1|0;}while((O|0)<4);M=M+1|0;}while((M|0)<4096);gGz(F|0,0,524288);M=F+131072|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}I=l+108|0;c[I>>2]=0;O=l+100|0;c[O>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,9)|0;do{if((c[I>>2]|0)!=0){P=c[O>>2]|0;c[m>>2]=9534384;N=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[N&16383](m,9,0)|0;if((P|0)<1){L=1;i=e;return L|0}if((gzL(M,0,9)|0)==0){break}else{L=1}i=e;return L|0}}while(0);M=c[3529552]|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}O=j+108|0;c[O>>2]=0;I=j+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,10)|0;do{if((c[O>>2]|0)!=0){F=c[I>>2]|0;c[k>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](k,10,0)|0;if((F|0)<1){L=1;i=e;return L|0}if((gzL(M,0,10)|0)==0){break}else{L=1}i=e;return L|0}}while(0);M=c[3529552]|0;I=c[2443614]|0;O=0;while(1){F=O<<5;gGz(I+F|0,0,32);P=O<<7;N=P|6;R=0;do{S=N+(c[2010304+(R<<2)>>2]|0)|0;if(((d[M+((S|0)/8|0)|0]|0)&128>>>((S&7)>>>0)|0)!=0){S=I+(F+R)|0;a[S]=a[S]|8}R=R+1|0;}while((R|0)<32);R=P|4;N=0;do{S=R+(c[2010304+(N<<2)>>2]|0)|0;if(((d[M+((S|0)/8|0)|0]|0)&128>>>((S&7)>>>0)|0)!=0){S=I+(F+N)|0;a[S]=a[S]|4}N=N+1|0;}while((N|0)<32);N=P|2;R=0;while(1){S=N+(c[2010304+(R<<2)>>2]|0)|0;if(((d[M+((S|0)/8|0)|0]|0)&128>>>((S&7)>>>0)|0)!=0){S=I+(F+R)|0;a[S]=a[S]|2}S=R+1|0;if((S|0)<32){R=S}else{X=0;break}}do{R=P+(c[2010304+(X<<2)>>2]|0)|0;if(((d[M+((R|0)/8|0)|0]|0)&128>>>((R&7)>>>0)|0)!=0){R=I+(F+X)|0;a[R]=a[R]|1}X=X+1|0;}while((X|0)<32);F=O+1|0;if((F|0)<16384){O=F}else{Y=0;break}}while(1){if((Y|0)>=1024){break}Z=9638528+(Y<<2)|0;if((c[Z>>2]|0)==(M|0)){H=51872;break}else{Y=Y+1|0}}if((H|0)==51872){gGr(M);c[Z>>2]=0}c[3529552]=0;O=c[3529826]|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}I=f+108|0;c[I>>2]=0;F=f+100|0;c[F>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,11)|0;do{if((c[I>>2]|0)!=0){P=c[F>>2]|0;c[g>>2]=9534384;R=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[R&16383](g,11,0)|0;if((P|0)<1){L=1;i=e;return L|0}if((gzL(O,0,11)|0)==0){break}else{L=1}i=e;return L|0}}while(0);fwR(0);O=c[2439330]|0;F=(O|0)==0;if(!F){I=O;gGC(9706056,I|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];I=c[3528484]|0;c[2076596]=I;M=c[2417276]|0;c[3541536]=M;c[1836236]=0;c[O+4180>>2]=2338;c[O+4184>>2]=310;P=O+4172|0;c[P>>2]=1734;c[O+4176>>2]=2992;if((fa(c[c[642608+(c[2436]<<2)>>2]>>2]|0,419672)|0)==0){c[P>>2]=2756}P=c[3529134]|0;R=0;N=0;while(1){c[O+76+(N<<2)>>2]=P+(N<<8);S=R+1&65535;if((S&65535)>127){_=0;$=0;break}else{R=S;N=S&65535}}while(1){N=P+($<<8)|0;c[O+76+($+512<<2)>>2]=N;c[O+76+($+768<<2)>>2]=N;N=_+1&65535;if((N&65535)>127){aa=128;ab=128;break}else{_=N;$=N&65535}}while(1){c[O+76+(ab<<2)>>2]=P+((ab<<8)+32768);N=aa+1&65535;if((N&65535)>191){ac=128;ad=128;break}else{aa=N;ab=N&65535}}while(1){N=P+((ad<<8)+32768)|0;c[O+76+(ad+512<<2)>>2]=N;c[O+76+(ad+768<<2)>>2]=N;N=ac+1&65535;if((N&65535)>191){break}else{ac=N;ad=N&65535}}P=c[2439628]|0;c[O+876>>2]=P;N=P+256|0;c[O+880>>2]=N;R=P+512|0;c[O+884>>2]=R;S=P+768|0;c[O+888>>2]=S;Q=P+1024|0;c[O+892>>2]=Q;T=P+1280|0;c[O+896>>2]=T;U=P+1536|0;c[O+900>>2]=U;V=P+1792|0;c[O+904>>2]=V;c[O+2924>>2]=P;c[O+3948>>2]=P;c[O+2928>>2]=N;c[O+3952>>2]=N;c[O+2932>>2]=R;c[O+3956>>2]=R;c[O+2936>>2]=S;c[O+3960>>2]=S;c[O+2940>>2]=Q;c[O+3964>>2]=Q;c[O+2944>>2]=T;c[O+3968>>2]=T;c[O+2948>>2]=U;c[O+3972>>2]=U;c[O+2952>>2]=V;c[O+3976>>2]=V;V=c[3527228]|0;c[O+908>>2]=V;c[O+912>>2]=V+256;c[O+916>>2]=V+512;c[O+920>>2]=V+768;c[O+924>>2]=V+1024;c[O+928>>2]=V+1280;c[O+932>>2]=V+1536;c[O+936>>2]=V+1792;c[O+940>>2]=V+2048;c[O+944>>2]=V+2304;c[O+948>>2]=V+2560;c[O+952>>2]=V+2816;c[O+956>>2]=V+3072;c[O+960>>2]=V+3328;c[O+964>>2]=V+3584;c[O+968>>2]=V+3840;U=208;T=208;while(1){c[O+76+(T+256<<2)>>2]=V+((T<<8)-53248);Q=U+1&65535;if((Q&65535)>223){ae=208;af=208;break}else{U=Q;T=Q&65535}}while(1){T=V+((af<<8)-53248)|0;c[O+76+(af+512<<2)>>2]=T;c[O+76+(af+768<<2)>>2]=T;T=ae+1&65535;if((T&65535)>223){break}else{ae=T;af=T&65535}}V=c[3529160]|0;c[O+972>>2]=V;c[O+976>>2]=V+256;c[O+980>>2]=V+512;c[O+984>>2]=V+768;c[O+988>>2]=V+1024;c[O+992>>2]=V+1280;c[O+996>>2]=V+1536;c[O+1e3>>2]=V+1792;c[O+1004>>2]=V+2048;c[O+1008>>2]=V+2304;c[O+1012>>2]=V+2560;c[O+1016>>2]=V+2816;c[O+1020>>2]=V+3072;c[O+1024>>2]=V+3328;c[O+1028>>2]=V+3584;c[O+1032>>2]=V+3840;T=224;U=224;while(1){c[O+76+(U+256<<2)>>2]=V+((U<<8)-57344);Q=T+1&65535;if((Q&65535)>239){ah=224;ai=224;break}else{T=Q;U=Q&65535}}while(1){U=V+((ai<<8)-57344)|0;c[O+76+(ai+512<<2)>>2]=U;c[O+76+(ai+768<<2)>>2]=U;U=ah+1&65535;if((U&65535)>239){break}else{ah=U;ai=U&65535}}if(!F){V=O;gGC(V|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=I;c[2417276]=M;c[1836236]=-1;fwR(1);V=c[2439331]|0;U=(V|0)==0;if(!U){T=V;gGC(9706056,T|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];T=c[3528485]|0;c[2076596]=T;Q=c[2417277]|0;c[3541536]=Q;c[1836236]=1;c[V+4180>>2]=30;c[V+4184>>2]=1500;c[V+4172>>2]=2122;c[V+4176>>2]=528;S=c[3529118]|0;R=0;N=0;while(1){c[V+76+(N<<2)>>2]=S+(N<<8);P=R+1&65535;if((P&65535)>191){aj=0;ak=0;break}else{R=P;N=P&65535}}while(1){N=S+(ak<<8)|0;c[V+76+(ak+512<<2)>>2]=N;c[V+76+(ak+768<<2)>>2]=N;N=aj+1&65535;if((N&65535)>191){break}else{aj=N;ak=N&65535}}S=c[3529148]|0;c[V+1036>>2]=S;c[V+1040>>2]=S+256;c[V+1044>>2]=S+512;c[V+1048>>2]=S+768;c[V+1052>>2]=S+1024;c[V+1056>>2]=S+1280;c[V+1060>>2]=S+1536;c[V+1064>>2]=S+1792;c[V+1068>>2]=S+2048;c[V+1072>>2]=S+2304;c[V+1076>>2]=S+2560;c[V+1080>>2]=S+2816;c[V+1084>>2]=S+3072;c[V+1088>>2]=S+3328;c[V+1092>>2]=S+3584;c[V+1096>>2]=S+3840;N=240;R=240;while(1){c[V+76+(R+256<<2)>>2]=S+((R<<8)-61440);M=N+1&65535;if((M&65535)>255){al=240;am=240;break}else{N=M;R=M&65535}}while(1){R=S+((am<<8)-61440)|0;c[V+76+(am+512<<2)>>2]=R;c[V+76+(am+768<<2)>>2]=R;R=al+1&65535;if((R&65535)>255){break}else{al=R;am=R&65535}}if(!U){S=V;gGC(S|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=T;c[2417277]=Q;c[1836236]=-1;c[2424]=5500;c[2440556]=103432;c[2440498]=55854;S=c[642608+(c[2436]<<2)>>2]|0;R=c[S+128>>2]|0;if((c[S+52>>2]&4|0)==0){c[2113068]=R;N=c[S+132>>2]|0;c[2113070]=N;c[2443814]=R;c[2440436]=N;an=R;ao=N}else{c[2113070]=R;N=c[S+132>>2]|0;c[2113068]=N;c[2440436]=R;c[2443814]=N;an=N;ao=R}R=ag(an<<1,ao)|0;N=gGq(R)|0;c[2112926]=N;if((N|0)!=0){gGz(N|0,0,R|0)}a[6939720]=1;Vr(2,3072e3,2360,3058,28,0);c[2438228]=3072e3;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=665;h[745419]=.5;a[3203368]=1;h[745418]=.35;a[3203360]=1;h[745417]=.35;a[3203352]=1;h[745416]=.35;a[3203344]=1;h[745415]=.5;a[3203336]=1;h[745414]=.35;a[3203328]=1;h[745413]=.35;a[3203320]=1;h[745412]=.35;a[3203312]=1;c[2405758]=1;gGz(9542544,0,32);c[2385641]=1;h[1192819]=1.0;c[2385642]=3;c[2385643]=1558;R=0;do{N=R*257|0;b[9732544+(R<<1)>>1]=((N|0)/2|0)&65535;b[9753784+(R<<1)>>1]=N+32768&65535;R=R+1|0;}while((R|0)<256);c[3528842]=1;h[1192819]=.35;c[2385642]=3;a73();L=0;i=e;return L|0}}while(0);c[2426822]=0;L=1;i=e;return L|0}function a7X(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1992780+(b*112|0)>>2];c[a+104>>2]=c[1992784+(b*112|0)>>2];c[a+108>>2]=c[1992788+(b*112|0)>>2];d=0;return d|0}function a7Y(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=1992680+(b*112|0);e=0;return e|0}function a7Z(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=990184+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function a7_(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>53){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1994472+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function a7$(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0;b=a[9774152]|0;if((d&1|0)!=0){d=b&-17;a[9774152]=d;a[14125144]=d;a[9706117]=1;if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){d=gfc(1e3)|0;e=d;f=(c[2433530]|0)+d|0}else{e=1e3;f=(c[2433530]|0)+1e3|0}c[2433530]=f;c[2444123]=(c[2444123]|0)+e;return}e=b|16;a[9774152]=e;if(e<<24>>24==-1){a[9706117]=0;return}a[14125144]=e;a[9706117]=1;if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){e=gfc(1e3)|0;g=e;h=(c[2433530]|0)+e|0}else{g=1e3;h=(c[2433530]|0)+1e3|0}c[2433530]=h;c[2444123]=(c[2444123]|0)+g;return}function a70(a){a=a|0;var b=0,d=0;b=(c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,3072e3,0)|0;return a|0}function a71(){return+(+((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)/3072.0e3)}function a72(){return~~((a[9688]|0?534.0:0.0)*(+((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)/(+(c[2440498]|0)*55.0/(+(c[2424]|0)/100.0))))|0}function a73(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0;d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=i;c[1836236]=-1;i=c[2439331]|0;g=(i|0)==0;if(!g){f=i;gGC(9706056,f|0,76)|0}f=c[2438119]|0;c[2433530]=f;e=c[3528485]|0;c[2076596]=e;d=c[2417277]|0;c[3541536]=d;c[1836236]=1;gGz(9706056,0,76);a[9774152]=-1;a[9706117]=0;if(!g){g=i;gGC(g|0,9706056,76)|0}c[2438119]=f;c[3528485]=e;c[2417277]=d;c[1836236]=-1;do{if(a[6939720]|0){c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){j=0}else{break}do{lN(j);mB(j);j=j+1|0;}while((j|0)<(c[2385508]|0))}else{mx(0)}}while(0);j=c[2405758]|0;if((j|0)>0){k=0}else{a[14119368]=0;a[9758264]=0;c[2439586]=0;c[2438758]=0;c[2433472]=0;c[2433474]=0;c[2429520]=0;c[2429522]=0;c[2433446]=0;return}do{c[9542560+(k<<5)>>2]=0;b[9542544+(k<<5)>>1]=0;k=k+1|0;}while((k|0)<(j|0));a[14119368]=0;a[9758264]=0;c[2439586]=0;c[2438758]=0;c[2433472]=0;c[2433474]=0;c[2429520]=0;c[2429522]=0;c[2433446]=0;return}function a74(b){b=b|0;var d=0,e=0,f=0,g=0,h=0;d=a[9774152]|0;if((b|0)!=0){b=d&-17;a[9774152]=b;a[14125144]=b;a[9706117]=1;if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){b=gfc(1e3)|0;e=b;f=(c[2433530]|0)+b|0}else{e=1e3;f=(c[2433530]|0)+1e3|0}c[2433530]=f;c[2444123]=(c[2444123]|0)+e;return}e=d|16;a[9774152]=e;if(e<<24>>24==-1){a[9706117]=0;return}a[14125144]=e;a[9706117]=1;if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){e=gfc(1e3)|0;g=e;h=(c[2433530]|0)+e|0}else{g=1e3;h=(c[2433530]|0)+1e3|0}c[2433530]=h;c[2444123]=(c[2444123]|0)+g;return}function a75(a,e){a=a|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;f=(c[2433474]|0)+(c[2433472]|0)|0;g=(a|0)==0;a=(e|0)!=0;e=c[3527228]|0;h=c[2112926]|0;i=c[2406548]|0;j=0;do{k=((j|0)/128|0)<<3;l=(((j|0)/2|0|0)%64|0)<<3;m=d[e+(j|1)|0]|0;n=m&15;o=m<<4&3840|(d[e+j|0]|0);L66612:do{if(g){if((k|0)>47){p=l-f&511}else{p=l}q=p-128|0;do{if((q|0)>-1){if(!((q|0)<((c[2113068]|0)-8|0)&(k|0)>-1)){break}if((k|0)>=((c[2113070]|0)-8|0)){break}if(a|n>>>0>3){Si(h,o,q,k,n,4,256,i);break L66612}else{Sq(h,o,q,k,n,4,0,256,i);break L66612}}}while(0);if(a|n>>>0>3){Sj(h,o,q,k,n,4,256,i);break}else{Sr(h,o,q,k,n,4,0,256,i);break}}else{if(!((m&12|0)==12&(k|0)>47)){break}r=(l-f&511)-128|0;s=n<<4;t=o<<6;u=c[2113070]|0;v=c[2113068]|0;w=0;do{x=(w<<3)+t|0;y=w+k|0;z=(y|0)>-1&(y|0)<(u|0);A=ag(v,y)|0;y=0;do{B=d[i+(x+y)|0]|0;do{if((255>>>(B>>>0)&1|0)==0){C=r+y|0;if(!z){break}if(!((C|0)>-1&(C|0)<(v|0))){break}b[h+(A+C<<1)>>1]=(s|B|256)&65535}}while(0);y=y+1|0;}while((y|0)<8);w=w+1|0;}while((w|0)<8)}}while(0);j=j+2|0;}while((j|0)<4096);return}function a76(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=a[4039520]|0;e=b?256:192;f=c[2443438]|0;g=c[2112926]|0;h=c[3529602]|0;i=0;do{j=d[f+(i|5)|0]|0;k=a[f+i|0]&15;l=1<<(j>>>4&3);m=384-((d[f+(i|3)|0]|0)<<8&256|(d[f+(i|2)|0]|0))-(l<<4)|0;n=l-1|0;o=(j<<8&3840|(d[f+(i|4)|0]|0))&-l;p=((d[f+(i|7)|0]|0)<<8&256|(d[f+(i|6)|0]|0))+(b?-64:-128)|0;L66645:do{if((l|0)>0){q=(j&128|0)!=0;r=(j&64|0)==0;if((p|0)<=16){s=0;while(1){t=(q?n-s|0:s)+o|0;u=(s<<4)+m|0;do{if(r){if(q){SL(g,t,p,u,k,4,0,0,h);break}else{SH(g,t,p,u,k,4,0,0,h);break}}else{if(q){SN(g,t,p,u,k,4,0,0,h);break}else{SJ(g,t,p,u,k,4,0,0,h);break}}}while(0);s=s+1|0;if((s|0)>=(l|0)){break L66645}}}s=c[2113068]|0;u=0;do{t=(q?n-u|0:u)+o|0;v=(u<<4)+m|0;do{if((p|0)<(s-16|0)&(v|0)>16){if((v|0)>=((c[2113070]|0)-16|0)){w=52068;break}if(r){if(q){SK(g,t,p,v,k,4,0,0,h);break}else{SG(g,t,p,v,k,4,0,0,h);break}}else{if(q){SM(g,t,p,v,k,4,0,0,h);break}else{SI(g,t,p,v,k,4,0,0,h);break}}}else{w=52068}}while(0);do{if((w|0)==52068){w=0;if(r){if(q){SL(g,t,p,v,k,4,0,0,h);break}else{SH(g,t,p,v,k,4,0,0,h);break}}else{if(q){SN(g,t,p,v,k,4,0,0,h);break}else{SJ(g,t,p,v,k,4,0,0,h);break}}}}while(0);u=u+1|0;}while((u|0)<(l|0))}}while(0);i=i+8|0;}while((i|0)<(e|0));return}function a77(a){a=a|0;return 0}function a78(a,b){a=a|0;b=b|0;return}function a79(a){a=a|0;return 0}function a8a(a,b){a=a|0;b=b|0;var d=0;d=a&65535;if((d|0)==40960){c[2429502]=c[2429502]&65280|b&255;return}else if((d|0)==45056){c[2429502]=c[2429502]&255|(b&255)<<8;return}else{return}}function a8b(a){a=a|0;var b=0,c=0;b=a&65535;if((b|0)==52224){c=7}else if((b|0)==51200){c=5}else if((b|0)==53247){c=7}else{c=0}return c|0}function a8c(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;if(a<<16>>16!=-14336){return}a=c[2385798]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=((b&255)<<14&16384|32768)-32768|0;b=128;f=128;while(1){c[d+76+(f<<2)>>2]=a+(e+(f<<8));g=b+1&65535;if((g&65535)>191){h=128;i=128;break}else{b=g;f=g&65535}}while(1){f=a+(e+(i<<8))|0;c[d+76+(i+512<<2)>>2]=f;c[d+76+(i+768<<2)>>2]=f;f=h+1&65535;if((f&65535)>191){break}else{h=f;i=f&65535}}return}function a8d(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;switch(b&65535|0){case 53248:{c[2429500]=c[2429500]&65280|d&255;return};case 53249:{c[2429500]=c[2429500]&255|(d&255)<<8;return};case 53253:{a[9718824]=d&1;return};case 53251:{c[2429502]=c[2429502]&255|(d&255)<<8;return};case 53250:{c[2429502]=c[2429502]&65280|d&255;return};case 53252:{b=c[2385798]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=((d&255)<<13&24576|32768)-32768|0;d=128;g=128;while(1){c[e+76+(g<<2)>>2]=b+(f+(g<<8));h=d+1&65535;if((h&65535)>159){i=128;j=128;break}else{d=h;g=h&65535}}while(1){g=b+(f+(j<<8))|0;c[e+76+(j+512<<2)>>2]=g;c[e+76+(j+768<<2)>>2]=g;g=i+1&65535;if((g&65535)>159){break}else{i=g;j=g&65535}}return};default:{return}}}function a8e(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=b&65535;if((e|0)==53248){c[2429500]=c[2429500]&65280|d&255;return}else if((e|0)==53250){b=d&255;c[2429502]=c[2429502]&255|b>>>1<<8&256;c[2429500]=c[2429500]&255|b<<8&256;a[9718824]=(d&255)>>>2&3;return}else if((e|0)==53249){c[2429502]=c[2429502]&65280|d&255;return}else if((e|0)==53251){e=d&255;d=e>>>6<<12;b=d|98304;f=c[2385798]|0;g=c[9757320+(c[1836236]<<2)>>2]|0;h=b-32768|0;c[g+588>>2]=f+b;c[g+592>>2]=f+(d|98560);c[g+596>>2]=f+(d|98816);c[g+600>>2]=f+(d|99072);c[g+604>>2]=f+(d|99328);c[g+608>>2]=f+(d|99584);c[g+612>>2]=f+(d|99840);c[g+616>>2]=f+(d|100096);c[g+620>>2]=f+(d|100352);c[g+624>>2]=f+(d|100608);c[g+628>>2]=f+(d|100864);c[g+632>>2]=f+(d|101120);c[g+636>>2]=f+(d|101376);c[g+640>>2]=f+(d|101632);c[g+644>>2]=f+(d|101888);c[g+648>>2]=f+(d|102144);d=e>>>2<<12&61440;e=128;b=128;while(1){i=f+(h+(b<<8))|0;c[g+76+(b+512<<2)>>2]=i;c[g+76+(b+768<<2)>>2]=i;i=e+1&65535;if((i&65535)>143){break}else{e=i;b=i&65535}}b=d-4096|0;c[g+652>>2]=f+(d+32768);c[g+656>>2]=f+(d+33024);c[g+660>>2]=f+(d+33280);c[g+664>>2]=f+(d+33536);c[g+668>>2]=f+(d+33792);c[g+672>>2]=f+(d+34048);c[g+676>>2]=f+(d+34304);c[g+680>>2]=f+(d+34560);c[g+684>>2]=f+(d+34816);c[g+688>>2]=f+(d+35072);c[g+692>>2]=f+(d+35328);c[g+696>>2]=f+(d+35584);c[g+700>>2]=f+(d+35840);c[g+704>>2]=f+(d+36096);c[g+708>>2]=f+(d+36352);c[g+712>>2]=f+(d+36608);d=144;e=144;while(1){h=f+(b+(e<<8))|0;c[g+76+(e+512<<2)>>2]=h;c[g+76+(e+768<<2)>>2]=h;h=d+1&65535;if((h&65535)>159){break}else{d=h;e=h&65535}}return}else{return}}function a8f(b){b=b|0;var c=0;switch(b&255|0){case 0:{c=~a[9623104];break};case 4:{c=a[9657801]|0;break};case 2:{c=~a[9623088];break};case 3:{c=a[9657800]|0;break};case 1:{c=~a[9623096];break};default:{c=0}}return c|0}function a8g(b,d){b=b|0;d=d|0;var e=0;e=b&255;if((e|0)==0){if(d<<24>>24>-1){a[9757800]=d&127;return}else{f01();return}}else if((e|0)==1){c[2439460]=(d^1^a[9657801])&1;return}else{return}}function a8h(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=b&255;b=e&65535;if((e&65535)<2){if((b|0)==1){c[2439460]=(d^1^a[9657801])&1;return}else if((b|0)==0){if(d<<24>>24>-1){a[9757800]=d&127;return}else{f01();return}}else{return}}if((b|0)==131){e=c[2385798]|0;f=c[9757320+(c[1836236]<<2)>>2]|0;g=((d&255)<<13&122880)-8192|0;h=160;i=160;while(1){c[f+76+(i<<2)>>2]=e+(g+(i<<8));j=h+1&65535;if((j&65535)>191){k=160;l=160;break}else{h=j;i=j&65535}}while(1){i=e+(g+(l<<8))|0;c[f+76+(l+512<<2)>>2]=i;c[f+76+(l+768<<2)>>2]=i;i=k+1&65535;if((i&65535)>191){break}else{k=i;l=i&65535}}return}else if((b|0)==129){c[2429502]=c[2429502]&255|(d&255)<<8;return}else if((b|0)==128){c[2429500]=c[2429500]&65280|d&255;return}else if((b|0)==130){c[2429502]=c[2429502]&65280|d&255;return}else{return}}function a8i(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=b&255;if((d&65535)>=5){if(d<<16>>16!=128){e=0;return e|0}b=a[9754680]|0;if(b<<24>>24==0){e=0;return e|0}f=b-1&255;a[9754680]=f;if(f<<24>>24!=0){e=0;return e|0}f=c[2385798]|0;b=c[9757320+(c[1836236]<<2)>>2]|0;g=128;h=128;while(1){c[b+76+(h<<2)>>2]=f+((h<<8)+8192);i=g+1&65535;if((i&65535)>159){j=128;k=128;break}else{g=i;h=i&65535}}while(1){h=f+((k<<8)+8192)|0;c[b+76+(k+512<<2)>>2]=h;c[b+76+(k+768<<2)>>2]=h;h=j+1&65535;if((h&65535)>159){e=0;break}else{j=h;k=h&65535}}return e|0}switch(d&65535|0){case 1:{e=~a[9623096];return e|0};case 0:{e=~a[9623104];return e|0};case 3:{e=a[9657800]|0;return e|0};case 4:{e=a[9657801]|0;return e|0};case 2:{e=~a[9623088];return e|0};default:{e=0;return e|0}}return 0}function a8j(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=b&255;b=e&65535;if((e&65535)<2){if((b|0)==1){c[2439460]=(d^1^a[9657801])&1;return}else if((b|0)==0){if(d<<24>>24>-1){a[9757800]=d&127;return}else{f01();return}}else{return}}e=b-128|0;if(e>>>0>=2){return}a[9754672+e|0]=d;if((e|0)!=0){if((a[9754672]|0)==1&d<<24>>24==13){a[9754680]=2;return}else{a[9754680]=0;return}}if(!(d<<24>>24!=0&(d&255)<31)){return}e=c[616864+((d&255)-1<<2)>>2]<<13;d=c[2385798]|0;b=c[9757320+(c[1836236]<<2)>>2]|0;f=128;g=128;while(1){c[b+76+(g<<2)>>2]=d+((g<<8)+e);h=f+1&65535;if((h&65535)>159){i=128;j=128;break}else{f=h;g=h&65535}}while(1){g=d+((j<<8)+e)|0;c[b+76+(j+512<<2)>>2]=g;c[b+76+(j+768<<2)>>2]=g;g=i+1&65535;if((g&65535)>159){break}else{i=g;j=g&65535}}return}function a8k(b,d){b=b|0;d=d|0;var e=0;e=b&255;b=e&65535;if((e&65535)>=2){if((b|0)==128){c[2429500]=c[2429500]&65280|d&255;return}else if((b|0)==129){a[9718896]=d&1;return}else{return}}if((b|0)==0){if(d<<24>>24>-1){a[9757800]=d&127;return}else{f01();return}}else if((b|0)==1){c[2439460]=(d^1^a[9657801])&1;return}else{return}}function a8l(b,d){b=b|0;d=d|0;var e=0;e=b&255;b=e&65535;if((e&65535)>=2){if((b|0)==131){c[2429502]=c[2429502]&65280|d&255;return}else if((b|0)==130){c[2429502]=c[2429502]&255|(d&255)<<8;return}else{return}}if((b|0)==0){if(d<<24>>24>-1){a[9757800]=d&127;return}else{f01();return}}else if((b|0)==1){c[2439460]=(d^1^a[9657801])&1;return}else{return}}function a8m(b){b=b|0;var c=0,d=0;c=b&255;L66900:do{if((c&65535)<5){switch(c&65535|0){case 4:{d=a[9657801]|0;break L66900;break};case 0:{d=~a[9623104];break L66900;break};case 2:{d=~a[9623088];break L66900;break};case 3:{d=a[9657800]|0;break L66900;break};case 1:{d=~a[9623096];break L66900;break};default:{d=0;break L66900}}}else{d=0}}while(0);return d|0}function a8n(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=b&255;b=e&65535;if((e&65535)<2){if((b|0)==0){if(d<<24>>24>-1){a[9757800]=d&127;return}else{f01();return}}else if((b|0)==1){c[2439460]=(d^1^a[9657801])&1;return}else{return}}switch(b|0){case 130:{c[2438664]=c[2438664]&65280|d&255;return};case 131:{c[2438664]=c[2438664]&255|(d&255)<<8;return};case 133:{b=(d&255)<<13&122880;e=c[2385798]|0;f=c[9757320+(c[1836236]<<2)>>2]|0;g=128;h=128;while(1){c[f+76+(h<<2)>>2]=e+((h<<8)+b);i=g+1&65535;if((i&65535)>159){j=128;k=128;break}else{g=i;h=i&65535}}while(1){h=e+((k<<8)+b)|0;c[f+76+(k+512<<2)>>2]=h;c[f+76+(k+768<<2)>>2]=h;h=j+1&65535;if((h&65535)>159){break}else{j=h;k=h&65535}}return};case 128:{c[2429502]=c[2429502]&65280|d&255;return};case 129:{c[2429502]=c[2429502]&255|(d&255)<<8;return};case 132:{a[9717272]=d&1;return};default:{return}}}function a8o(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=b&255;b=e&65535;if((e&65535)<2){if((b|0)==1){c[2439460]=(d^1^a[9657801])&1;return}else if((b|0)==0){if(d<<24>>24>-1){a[9757800]=d&127;return}else{f01();return}}else{return}}if((b|0)==128){c[2429502]=c[2429502]&255|(d&255)<<8;return}else if((b|0)==129){c[2429502]=c[2429502]&65280|d&255;return}else if((b|0)==131){b=c[2385798]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=((d&255)<<14&16384|32768)-32768|0;d=128;g=128;while(1){c[e+76+(g<<2)>>2]=b+(f+(g<<8));h=d+1&65535;if((h&65535)>191){i=128;j=128;break}else{d=h;g=h&65535}}while(1){g=b+(f+(j<<8))|0;c[e+76+(j+512<<2)>>2]=g;c[e+76+(j+768<<2)>>2]=g;g=i+1&65535;if((g&65535)>191){break}else{i=g;j=g&65535}}return}else{return}}function a8p(b){b=b|0;var d=0;if((b&65535)<32){d=f4R(b)|0;return d|0}if((b-128&65535)>=128){d=0;return d|0}d=a[(c[3527100]|0)+((b&65535)-128)|0]|0;return d|0}function a8q(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((b&65535)<32){f4S(b,d);return}if((b-128&65535)<128){a[(c[3527100]|0)+(e-128)|0]=d;return}if((e|0)==2049){b=d&255;c[2415126]=9662152;if((c[2415542]|0)==4){c[2415538]=b&15;return}else{c[2415538]=b<<1&14;return}}else if((e|0)==2048){if((a[9660903]|0)==0){return}a[9660903]=0;return}else if((e|0)==2050){e=d&255;c[2415126]=9665376;if((c[2416348]|0)==4){c[2416344]=e&15;return}else{c[2416344]=e<<1&14;return}}else{return}}function a8r(b){b=b|0;var e=0,f=0,g=0;if(b<<16>>16!=256){e=0;return e|0}b=d[9623072]|0;if((b&8|0)!=0){f=c[3542228]|0;if((f|0)>15){e=0;return e|0}do{if((f|0)==14){g=c[3542224]|0;if((g|0)==0){break}a[14168930]=gj[g&4095](0)|0}else if((f|0)==15){g=c[3542225]|0;if((g|0)==0){break}a[14168931]=gj[g&4095](0)|0}}while(0);e=a[14168916+f|0]|0;return e|0}if((b&16|0)==0){e=-1;return e|0}b=c[3542291]|0;if((b|0)>15){e=0;return e|0}do{if((b|0)==14){f=c[3542287]|0;if((f|0)==0){break}a[14169182]=gj[f&4095](0)|0}else if((b|0)==15){f=c[3542288]|0;if((f|0)==0){break}a[14169183]=gj[f&4095](0)|0}}while(0);e=a[14169168+b|0]|0;return e|0}function a8s(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=b&65535;if((e|0)==256){a[9623080]=d;return}else if((e|0)==257){e=a[9623072]|0;b=e&255;do{if((b&1|0)!=0){if((d&1)!=0){break}f=(b&8|0)!=0;if((b&4|0)!=0){if(f){c[3542228]=a[9623080]&15}if((e&16)==0){break}c[3542291]=a[9623080]&15;break}do{if(f){g=a[9623080]|0;h=g&255;i=c[3542228]|0;if((i|0)>15){j=e;break}do{if((i|0)<14){if((i|0)!=13){if((a[14168916+i|0]|0)==g<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(0,i,h);j=a[9623072]|0}else{j=e}}while(0);if((j&16)==0){break}f=a[9623080]|0;g=f&255;k=c[3542291]|0;if((k|0)>15){break}do{if((k|0)<14){if((k|0)!=13){if((a[14169168+k|0]|0)==f<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(1,k,g)}}while(0);a[9623072]=d;return}else{return}}function a8t(b){b=b|0;return a[9757800]|0}function a8u(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>27){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5314220+(b*112|0)>>2];c[a+104>>2]=c[5314224+(b*112|0)>>2];c[a+108>>2]=c[5314228+(b*112|0)>>2];d=0;return d|0}function a8v(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<28&(d|0)==0)){e=1;return e|0}c[a>>2]=5314120+(b*112|0);e=0;return e|0}function a8w(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6856304+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function a8x(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>85){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5317256+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function a8y(){var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0;e=i;i=i+3360|0;f=e|0;g=e+112|0;h=e+120|0;j=e+232|0;k=e+240|0;l=e+352|0;m=e+360|0;n=e+472|0;o=e+480|0;p=e+592|0;q=e+600|0;r=e+712|0;s=e+720|0;t=e+832|0;u=e+840|0;v=e+952|0;w=e+960|0;x=e+1072|0;y=e+1080|0;z=e+1192|0;A=e+1200|0;B=e+1312|0;C=e+1320|0;D=e+1432|0;E=e+1440|0;F=e+1552|0;G=e+1560|0;H=e+1672|0;I=e+1680|0;J=e+1792|0;K=e+1800|0;L=e+1912|0;M=e+1920|0;N=e+2032|0;O=e+2040|0;P=e+2152|0;Q=e+2160|0;R=e+2272|0;S=e+2280|0;T=e+2392|0;U=e+2400|0;V=e+2512|0;W=e+2520|0;X=e+2632|0;Y=e+2640|0;Z=e+2752|0;_=e+2760|0;$=e+2872|0;aa=e+2880|0;ab=e+2992|0;ac=e+3e3|0;ad=e+3112|0;ae=e+3120|0;af=e+3232|0;ah=e+3240|0;ai=e+3352|0;c[2439448]=32768;c[3527090]=1824;c[3527094]=1024;c[2439452]=1024;c[2431672]=c[(c[642608+(c[2436]<<2)>>2]|0)+124>>2];c[2426820]=0;a9Q();aj=c[2414438]|0;ak=0;while(1){if((ak|0)>=1024){break}al=9638528+(ak<<2)|0;if((c[al>>2]|0)==0){am=52438;break}else{ak=ak+1|0}}do{if((am|0)==52438){ak=gGq(aj)|0;c[al>>2]=ak;if((ak|0)==0){break}gGz(ak|0,0,aj|0);c[2426820]=ak;gGz(ak|0,0,aj|0);a9Q();ak=0;while(1){if((ak|0)>=1024){an=0;break}ao=9638528+(ak<<2)|0;if((c[ao>>2]|0)==0){am=52443;break}else{ak=ak+1|0}}do{if((am|0)==52443){ak=gGq(98304)|0;c[ao>>2]=ak;if((ak|0)==0){an=0;break}gGz(ak|0,0,98304);an=ak}}while(0);c[3529012]=an;ak=c[2385798]|0;if((c[3542200]|0)==0){ap=1;i=e;return ap|0}aq=ah+108|0;c[aq>>2]=0;ar=ah+100|0;c[ar>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](ah,0)|0;do{if((c[aq>>2]|0)!=0){as=c[ar>>2]|0;c[ai>>2]=9534384;at=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[at&16383](ai,0,0)|0;if((as|0)<1){ap=1;i=e;return ap|0}if((gzL(ak,0,0)|0)==0){break}else{ap=1}i=e;return ap|0}}while(0);ak=(c[2385798]|0)+16384|0;if((c[3542200]|0)==0){ap=1;i=e;return ap|0}ar=ae+108|0;c[ar>>2]=0;aq=ae+100|0;c[aq>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](ae,1)|0;do{if((c[ar>>2]|0)!=0){as=c[aq>>2]|0;c[af>>2]=9534384;at=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[at&16383](af,1,0)|0;if((as|0)<1){ap=1;i=e;return ap|0}if((gzL(ak,0,1)|0)==0){break}else{ap=1}i=e;return ap|0}}while(0);ak=(c[3527098]|0)+24576|0;if((c[3542200]|0)==0){ap=1;i=e;return ap|0}aq=ac+108|0;c[aq>>2]=0;ar=ac+100|0;c[ar>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](ac,2)|0;do{if((c[aq>>2]|0)!=0){as=c[ar>>2]|0;c[ad>>2]=9534384;at=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[at&16383](ad,2,0)|0;if((as|0)<1){ap=1;i=e;return ap|0}if((gzL(ak,0,2)|0)==0){break}else{ap=1}i=e;return ap|0}}while(0);ak=(c[3527098]|0)+32768|0;if((c[3542200]|0)==0){ap=1;i=e;return ap|0}ar=aa+108|0;c[ar>>2]=0;aq=aa+100|0;c[aq>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](aa,3)|0;do{if((c[ar>>2]|0)!=0){as=c[aq>>2]|0;c[ab>>2]=9534384;at=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[at&16383](ab,3,0)|0;if((as|0)<1){ap=1;i=e;return ap|0}if((gzL(ak,0,3)|0)==0){break}else{ap=1}i=e;return ap|0}}while(0);ak=(c[3527098]|0)+40960|0;if((c[3542200]|0)==0){ap=1;i=e;return ap|0}aq=_+108|0;c[aq>>2]=0;ar=_+100|0;c[ar>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](_,4)|0;do{if((c[aq>>2]|0)!=0){as=c[ar>>2]|0;c[$>>2]=9534384;at=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[at&16383]($,4,0)|0;if((as|0)<1){ap=1;i=e;return ap|0}if((gzL(ak,0,4)|0)==0){break}else{ap=1}i=e;return ap|0}}while(0);ak=c[3529012]|0;gGz(ak|0,0,98304);if((c[3542200]|0)==0){ap=1;i=e;return ap|0}ar=Y+108|0;c[ar>>2]=0;aq=Y+100|0;c[aq>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](Y,5)|0;do{if((c[ar>>2]|0)!=0){as=c[aq>>2]|0;c[Z>>2]=9534384;at=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[at&16383](Z,5,0)|0;if((as|0)<1){ap=1;i=e;return ap|0}if((gzL(ak,0,5)|0)==0){break}else{ap=1}i=e;return ap|0}}while(0);ak=(c[3529012]|0)+8192|0;if((c[3542200]|0)==0){ap=1;i=e;return ap|0}aq=W+108|0;c[aq>>2]=0;ar=W+100|0;c[ar>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](W,6)|0;do{if((c[aq>>2]|0)!=0){as=c[ar>>2]|0;c[X>>2]=9534384;at=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[at&16383](X,6,0)|0;if((as|0)<1){ap=1;i=e;return ap|0}if((gzL(ak,0,6)|0)==0){break}else{ap=1}i=e;return ap|0}}while(0);ak=(c[3529012]|0)+16384|0;if((c[3542200]|0)==0){ap=1;i=e;return ap|0}ar=U+108|0;c[ar>>2]=0;aq=U+100|0;c[aq>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](U,7)|0;do{if((c[ar>>2]|0)!=0){as=c[aq>>2]|0;c[V>>2]=9534384;at=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[at&16383](V,7,0)|0;if((as|0)<1){ap=1;i=e;return ap|0}if((gzL(ak,0,7)|0)==0){break}else{ap=1}i=e;return ap|0}}while(0);ak=c[3527094]|0;aq=c[2439464]|0;ar=c[2439462]|0;as=c[3529012]|0;at=c[2405764]|0;if((ak|0)>0){au=ag(ar,aq)|0;av=(ar|0)<1|(aq|0)<1;aw=0;do{ax=ag(aw,au)|0;gGz(at+ax|0,0,au|0);ay=aw<<6;az=ay+131072|0;if(!av){aA=0;do{aB=az+(c[1238464+(aA<<2)>>2]|0)|0;aC=(ag(aA,aq)|0)+ax|0;aD=0;do{aE=aB+(c[614800+(aD<<2)>>2]|0)|0;if(((d[as+((aE|0)/8|0)|0]|0)&128>>>((aE&7)>>>0)|0)!=0){aE=at+(aC+aD)|0;a[aE]=a[aE]|4}aD=aD+1|0;}while((aD|0)<(aq|0));aA=aA+1|0;}while((aA|0)<(ar|0));aA=ay+65536|0;az=0;while(1){aD=aA+(c[1238464+(az<<2)>>2]|0)|0;aC=(ag(az,aq)|0)+ax|0;aB=0;do{aE=aD+(c[614800+(aB<<2)>>2]|0)|0;if(((d[as+((aE|0)/8|0)|0]|0)&128>>>((aE&7)>>>0)|0)!=0){aE=at+(aC+aB)|0;a[aE]=a[aE]|2}aB=aB+1|0;}while((aB|0)<(aq|0));aB=az+1|0;if((aB|0)<(ar|0)){az=aB}else{aF=0;break}}do{az=ay+(c[1238464+(aF<<2)>>2]|0)|0;aA=(ag(aF,aq)|0)+ax|0;aB=0;do{aC=az+(c[614800+(aB<<2)>>2]|0)|0;if(((d[as+((aC|0)/8|0)|0]|0)&128>>>((aC&7)>>>0)|0)!=0){aC=at+(aA+aB)|0;a[aC]=a[aC]|1}aB=aB+1|0;}while((aB|0)<(aq|0));aF=aF+1|0;}while((aF|0)<(ar|0))}aw=aw+1|0;}while((aw|0)<(ak|0))}gGz(as|0,0,98304);if((c[3542200]|0)==0){ap=1;i=e;return ap|0}ak=S+108|0;c[ak>>2]=0;aw=S+100|0;c[aw>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](S,8)|0;do{if((c[ak>>2]|0)!=0){ar=c[aw>>2]|0;c[T>>2]=9534384;aq=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aq&16383](T,8,0)|0;if((ar|0)<1){ap=1;i=e;return ap|0}if((gzL(as,0,8)|0)==0){break}else{ap=1}i=e;return ap|0}}while(0);as=(c[3529012]|0)+8192|0;if((c[3542200]|0)==0){ap=1;i=e;return ap|0}aw=Q+108|0;c[aw>>2]=0;ak=Q+100|0;c[ak>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](Q,9)|0;do{if((c[aw>>2]|0)!=0){ar=c[ak>>2]|0;c[R>>2]=9534384;aq=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aq&16383](R,9,0)|0;if((ar|0)<1){ap=1;i=e;return ap|0}if((gzL(as,0,9)|0)==0){break}else{ap=1}i=e;return ap|0}}while(0);as=(c[3529012]|0)+16384|0;if((c[3542200]|0)==0){ap=1;i=e;return ap|0}ak=O+108|0;c[ak>>2]=0;aw=O+100|0;c[aw>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](O,10)|0;do{if((c[ak>>2]|0)!=0){ar=c[aw>>2]|0;c[P>>2]=9534384;aq=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aq&16383](P,10,0)|0;if((ar|0)<1){ap=1;i=e;return ap|0}if((gzL(as,0,10)|0)==0){break}else{ap=1}i=e;return ap|0}}while(0);as=(c[3529012]|0)+24576|0;if((c[3542200]|0)==0){ap=1;i=e;return ap|0}aw=M+108|0;c[aw>>2]=0;ak=M+100|0;c[ak>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](M,11)|0;do{if((c[aw>>2]|0)!=0){ar=c[ak>>2]|0;c[N>>2]=9534384;aq=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aq&16383](N,11,0)|0;if((ar|0)<1){ap=1;i=e;return ap|0}if((gzL(as,0,11)|0)==0){break}else{ap=1}i=e;return ap|0}}while(0);as=(c[3529012]|0)+32768|0;if((c[3542200]|0)==0){ap=1;i=e;return ap|0}ak=K+108|0;c[ak>>2]=0;aw=K+100|0;c[aw>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](K,12)|0;do{if((c[ak>>2]|0)!=0){ar=c[aw>>2]|0;c[L>>2]=9534384;aq=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aq&16383](L,12,0)|0;if((ar|0)<1){ap=1;i=e;return ap|0}if((gzL(as,0,12)|0)==0){break}else{ap=1}i=e;return ap|0}}while(0);as=(c[3529012]|0)+40960|0;if((c[3542200]|0)==0){ap=1;i=e;return ap|0}aw=I+108|0;c[aw>>2]=0;ak=I+100|0;c[ak>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](I,13)|0;do{if((c[aw>>2]|0)!=0){ar=c[ak>>2]|0;c[J>>2]=9534384;aq=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aq&16383](J,13,0)|0;if((ar|0)<1){ap=1;i=e;return ap|0}if((gzL(as,0,13)|0)==0){break}else{ap=1}i=e;return ap|0}}while(0);as=(c[3529012]|0)+49152|0;if((c[3542200]|0)==0){ap=1;i=e;return ap|0}ak=G+108|0;c[ak>>2]=0;aw=G+100|0;c[aw>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](G,14)|0;do{if((c[ak>>2]|0)!=0){ar=c[aw>>2]|0;c[H>>2]=9534384;aq=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aq&16383](H,14,0)|0;if((ar|0)<1){ap=1;i=e;return ap|0}if((gzL(as,0,14)|0)==0){break}else{ap=1}i=e;return ap|0}}while(0);as=(c[3529012]|0)+57344|0;if((c[3542200]|0)==0){ap=1;i=e;return ap|0}aw=E+108|0;c[aw>>2]=0;ak=E+100|0;c[ak>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](E,15)|0;do{if((c[aw>>2]|0)!=0){ar=c[ak>>2]|0;c[F>>2]=9534384;aq=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aq&16383](F,15,0)|0;if((ar|0)<1){ap=1;i=e;return ap|0}if((gzL(as,0,15)|0)==0){break}else{ap=1}i=e;return ap|0}}while(0);as=(c[3529012]|0)+65536|0;if((c[3542200]|0)==0){ap=1;i=e;return ap|0}ak=C+108|0;c[ak>>2]=0;aw=C+100|0;c[aw>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](C,16)|0;do{if((c[ak>>2]|0)!=0){ar=c[aw>>2]|0;c[D>>2]=9534384;aq=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aq&16383](D,16,0)|0;if((ar|0)<1){ap=1;i=e;return ap|0}if((gzL(as,0,16)|0)==0){break}else{ap=1}i=e;return ap|0}}while(0);as=(c[3529012]|0)+73728|0;if((c[3542200]|0)==0){ap=1;i=e;return ap|0}aw=A+108|0;c[aw>>2]=0;ak=A+100|0;c[ak>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](A,17)|0;do{if((c[aw>>2]|0)!=0){ar=c[ak>>2]|0;c[B>>2]=9534384;aq=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aq&16383](B,17,0)|0;if((ar|0)<1){ap=1;i=e;return ap|0}if((gzL(as,0,17)|0)==0){break}else{ap=1}i=e;return ap|0}}while(0);as=(c[3529012]|0)+81920|0;if((c[3542200]|0)==0){ap=1;i=e;return ap|0}ak=y+108|0;c[ak>>2]=0;aw=y+100|0;c[aw>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](y,18)|0;do{if((c[ak>>2]|0)!=0){ar=c[aw>>2]|0;c[z>>2]=9534384;aq=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aq&16383](z,18,0)|0;if((ar|0)<1){ap=1;i=e;return ap|0}if((gzL(as,0,18)|0)==0){break}else{ap=1}i=e;return ap|0}}while(0);as=(c[3529012]|0)+90112|0;if((c[3542200]|0)==0){ap=1;i=e;return ap|0}aw=w+108|0;c[aw>>2]=0;ak=w+100|0;c[ak>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](w,19)|0;do{if((c[aw>>2]|0)!=0){ar=c[ak>>2]|0;c[x>>2]=9534384;aq=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aq&16383](x,19,0)|0;if((ar|0)<1){ap=1;i=e;return ap|0}if((gzL(as,0,19)|0)==0){break}else{ap=1}i=e;return ap|0}}while(0);as=c[2439452]|0;ak=c[3529012]|0;aw=c[3529014]|0;if((as|0)>0){ar=0;do{aq=ar<<8;gGz(aw+aq|0,0,256);at=aq+524288|0;av=0;do{au=at+(c[609008+(av<<2)>>2]|0)|0;ax=(av<<4)+aq|0;ay=0;do{aB=au+(c[597864+(ay<<2)>>2]|0)|0;if(((d[ak+((aB|0)/8|0)|0]|0)&128>>>((aB&7)>>>0)|0)!=0){aB=aw+(ax+ay)|0;a[aB]=a[aB]|4}ay=ay+1|0;}while((ay|0)<16);av=av+1|0;}while((av|0)<16);av=aq+262144|0;at=0;while(1){ay=av+(c[609008+(at<<2)>>2]|0)|0;ax=(at<<4)+aq|0;au=0;do{aB=ay+(c[597864+(au<<2)>>2]|0)|0;if(((d[ak+((aB|0)/8|0)|0]|0)&128>>>((aB&7)>>>0)|0)!=0){aB=aw+(ax+au)|0;a[aB]=a[aB]|2}au=au+1|0;}while((au|0)<16);au=at+1|0;if((au|0)<16){at=au}else{aG=0;break}}do{at=aq+(c[609008+(aG<<2)>>2]|0)|0;av=(aG<<4)+aq|0;au=0;do{ax=at+(c[597864+(au<<2)>>2]|0)|0;if(((d[ak+((ax|0)/8|0)|0]|0)&128>>>((ax&7)>>>0)|0)!=0){ax=aw+(av+au)|0;a[ax]=a[ax]|1}au=au+1|0;}while((au|0)<16);aG=aG+1|0;}while((aG|0)<16);ar=ar+1|0;}while((ar|0)<(as|0))}as=c[3527092]|0;if((c[3542200]|0)==0){ap=1;i=e;return ap|0}ar=u+108|0;c[ar>>2]=0;aw=u+100|0;c[aw>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](u,20)|0;do{if((c[ar>>2]|0)!=0){ak=c[aw>>2]|0;c[v>>2]=9534384;aq=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aq&16383](v,20,0)|0;if((ak|0)<1){ap=1;i=e;return ap|0}if((gzL(as,0,20)|0)==0){break}else{ap=1}i=e;return ap|0}}while(0);as=(c[3527092]|0)+256|0;if((c[3542200]|0)==0){ap=1;i=e;return ap|0}aw=s+108|0;c[aw>>2]=0;ar=s+100|0;c[ar>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](s,21)|0;do{if((c[aw>>2]|0)!=0){ak=c[ar>>2]|0;c[t>>2]=9534384;aq=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aq&16383](t,21,0)|0;if((ak|0)<1){ap=1;i=e;return ap|0}if((gzL(as,0,21)|0)==0){break}else{ap=1}i=e;return ap|0}}while(0);as=(c[3527092]|0)+512|0;if((c[3542200]|0)==0){ap=1;i=e;return ap|0}ar=q+108|0;c[ar>>2]=0;aw=q+100|0;c[aw>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](q,22)|0;do{if((c[ar>>2]|0)!=0){ak=c[aw>>2]|0;c[r>>2]=9534384;aq=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aq&16383](r,22,0)|0;if((ak|0)<1){ap=1;i=e;return ap|0}if((gzL(as,0,22)|0)==0){break}else{ap=1}i=e;return ap|0}}while(0);as=(c[3527092]|0)+768|0;if((c[3542200]|0)==0){ap=1;i=e;return ap|0}aw=o+108|0;c[aw>>2]=0;ar=o+100|0;c[ar>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](o,23)|0;do{if((c[aw>>2]|0)!=0){ak=c[ar>>2]|0;c[p>>2]=9534384;aq=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aq&16383](p,23,0)|0;if((ak|0)<1){ap=1;i=e;return ap|0}if((gzL(as,0,23)|0)==0){break}else{ap=1}i=e;return ap|0}}while(0);as=(c[3527092]|0)+1024|0;if((c[3542200]|0)==0){ap=1;i=e;return ap|0}ar=m+108|0;c[ar>>2]=0;aw=m+100|0;c[aw>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,24)|0;do{if((c[ar>>2]|0)!=0){ak=c[aw>>2]|0;c[n>>2]=9534384;aq=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aq&16383](n,24,0)|0;if((ak|0)<1){ap=1;i=e;return ap|0}if((gzL(as,0,24)|0)==0){break}else{ap=1}i=e;return ap|0}}while(0);as=(c[3527092]|0)+1280|0;if((c[3542200]|0)==0){ap=1;i=e;return ap|0}aw=k+108|0;c[aw>>2]=0;ar=k+100|0;c[ar>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,25)|0;do{if((c[aw>>2]|0)!=0){ak=c[ar>>2]|0;c[l>>2]=9534384;aq=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aq&16383](l,25,0)|0;if((ak|0)<1){ap=1;i=e;return ap|0}if((gzL(as,0,25)|0)==0){break}else{ap=1}i=e;return ap|0}}while(0);as=(c[3527092]|0)+1536|0;if((c[3542200]|0)==0){ap=1;i=e;return ap|0}ar=h+108|0;c[ar>>2]=0;aw=h+100|0;c[aw>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](h,26)|0;do{if((c[ar>>2]|0)!=0){ak=c[aw>>2]|0;c[j>>2]=9534384;aq=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aq&16383](j,26,0)|0;if((ak|0)<1){ap=1;i=e;return ap|0}if((gzL(as,0,26)|0)==0){break}else{ap=1}i=e;return ap|0}}while(0);as=(c[3527092]|0)+1568|0;if((c[3542200]|0)==0){ap=1;i=e;return ap|0}aw=f+108|0;c[aw>>2]=0;ar=f+100|0;c[ar>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,27)|0;do{if((c[aw>>2]|0)!=0){ak=c[ar>>2]|0;c[g>>2]=9534384;aq=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aq&16383](g,27,0)|0;if((ak|0)<1){ap=1;i=e;return ap|0}if((gzL(as,0,27)|0)==0){break}else{ap=1}i=e;return ap|0}}while(0);as=c[3529012]|0;ar=0;while(1){if((ar|0)>=1024){break}aH=9638528+(ar<<2)|0;if((c[aH>>2]|0)==(as|0)){am=52577;break}else{ar=ar+1|0}}if((am|0)==52577){gGr(as);c[aH>>2]=0}c[3529012]=0;a9H();ar=c[2439330]|0;aw=(ar|0)==0;if(!aw){ak=ar;gGC(9706056,ak|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];ak=c[3528484]|0;c[2076596]=ak;aq=c[2417276]|0;c[3541536]=aq;c[1836236]=0;c[ar+4180>>2]=960;c[ar+4184>>2]=2174;if(!aw){au=ar;gGC(au|0,9706056,76)|0}au=c[2433530]|0;c[2438118]=au;c[3528484]=ak;c[2417276]=aq;c[1836236]=-1;c[3527088]=3072e3;c[2431670]=5838;if(aw){c[2433530]=au;c[2076596]=ak;c[3541536]=aq;c[1836236]=0;gGz(9706056,0,76)}else{aw=ar;gGC(9706056,aw|0,76)|0;c[2433530]=au;c[2076596]=ak;c[3541536]=aq;c[1836236]=0;gGz(9706056,0,76);aw=ar;gGC(aw|0,9706056,76)|0}c[2438118]=au;c[3528484]=ak;c[2417276]=aq;c[1836236]=-1;a[9660900]=a[9660900]|16;aq=c[2437644]|0;ak=c[aq+1092>>2]|0;do{if((ak|0)==0){au=c[aq+3144>>2]|0;if((au|0)==0){aI=0;aJ=0;break}aw=gj[au&4095](-2)|0;au=c[2437644]|0;ar=c[au+1092>>2]|0;av=(aw&255)<<8;if((ar|0)!=0){aK=ar;aL=av;am=52589;break}ar=c[au+3144>>2]|0;if((ar|0)==0){aI=0;aJ=av;break}aI=gj[ar&4095](-1)|0;aJ=av}else{aK=ak;aL=(d[ak+254|0]|0)<<8;am=52589}}while(0);if((am|0)==52589){aI=a[aK+255|0]|0;aJ=aL}ak=aI&255|aJ;c[2415221]=ak;b[4830442]=ak&65535;a[9660920]=0;a[9660921]=0;a[9660928]=0;a[9660930]=0;a[9660931]=0;c[2415234]=0;gGz(9660901,0,5);c[2415235]=65535;c[2415237]=65535;a[9660932]=a[9660932]|64;mB(0);mB(1);UA();c[2429502]=0;c[2429500]=0;c[2438664]=0;c[2439460]=0;a[9757800]=0;a[9623080]=0;a[9623072]=0;a[683232]=0;a[9754673]=0;a[9754672]=0;a[9754680]=0;a[9718896]=0;a[9717272]=0;a[9718824]=0;ap=0;i=e;return ap|0}}while(0);c[2426820]=0;ap=1;i=e;return ap|0}function a8z(){var b=0,d=0,e=0,f=0,g=0,h=0;fwZ();b=c[2437644]|0;if((b|0)!=0){gGr(b);c[2437644]=0}c[2113008]=0;c[2076598]=0;c[2383582]=0;c[2415126]=9662152;b=c[2408988]|0;if((b|0)!=0){gGz(9662152,0,3224);d=b;b=0;while(1){if((b|0)>=1024){break}e=9638528+(b<<2)|0;if((c[e>>2]|0)==(d|0)){f=52708;break}else{b=b+1|0}}if((f|0)==52708){gGr(d);c[e>>2]=0}c[2408988]=0}c[2415126]=9665376;e=c[2408989]|0;if((e|0)!=0){gGz(9665376,0,3224);d=e;e=0;while(1){if((e|0)>=1024){break}g=9638528+(e<<2)|0;if((c[g>>2]|0)==(d|0)){f=52714;break}else{e=e+1|0}}if((f|0)==52714){gGr(d);c[g>>2]=0}c[2408989]=0}c[2113070]=0;c[2113068]=0;g=c[2112926]|0;if((g|0)!=0){gGr(g);c[2112926]=0}g=c[2426820]|0;d=0;while(1){if((d|0)>=1024){break}h=9638528+(d<<2)|0;if((c[h>>2]|0)==(g|0)){f=52721;break}else{d=d+1|0}}if((f|0)==52721){gGr(g);c[h>>2]=0}c[2426820]=0;c[2439448]=0;c[3527090]=0;c[3527094]=0;c[2439452]=0;c[3527096]=0;c[2433360]=0;c[2438666]=0;a[1840136]=0;c[2429502]=0;c[2429500]=0;c[2438664]=0;c[2439460]=0;a[9757800]=0;a[9623080]=0;a[9623072]=0;a[683232]=0;c[2431672]=0;c[3527088]=0;a[6243312]=0;c[2431670]=0;c[2426980]=0;c[2426982]=0;a[9754673]=0;a[9754672]=0;a[9754680]=0;a[9718896]=0;a[9717272]=0;a[9718824]=0;c[2439464]=0;c[2439462]=0;c[2437648]=0;c[2437646]=0;c[2426978]=0;return 0}function a8A(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;e=c[3527088]|0;c[2415126]=9662152;f=c[2415557]|0;g=f&3;if((g|0)==3){h=133}else{h=((e|0)/((e|0)/((c[2415554]|0)/(c[600992+((f>>>3&1)<<4)+(g<<2)>>2]|0)|0|0)|0|0)|0|0)/((c[2424]|0)/100|0|0)|0}if((a[9623064]|0)!=0){g=c[2439330]|0;f=(g|0)==0;if(!f){e=g;gGC(9706056,e|0,76)|0}e=c[2438118]|0;c[2433530]=e;i=c[3528484]|0;c[2076596]=i;j=c[2417276]|0;c[3541536]=j;c[1836236]=0;gGz(9706056,0,76);if(!f){f=g;gGC(f|0,9706056,76)|0}c[2438118]=e;c[3528484]=i;c[2417276]=j;c[1836236]=-1;a[9660900]=a[9660900]|16;j=c[2437644]|0;i=c[j+1092>>2]|0;do{if((i|0)==0){e=c[j+3144>>2]|0;if((e|0)==0){k=0;l=0;break}f=gj[e&4095](-2)|0;e=c[2437644]|0;g=c[e+1092>>2]|0;m=(f&255)<<8;if((g|0)!=0){n=g;o=m;p=52734;break}g=c[e+3144>>2]|0;if((g|0)==0){k=0;l=m;break}k=gj[g&4095](-1)|0;l=m}else{n=i;o=d[i+254|0]<<8;p=52734}}while(0);if((p|0)==52734){k=a[n+255|0]|0;l=o}o=k&255|l;c[2415221]=o;b[4830442]=o&65535;a[9660920]=0;a[9660921]=0;a[9660928]=0;a[9660930]=0;a[9660931]=0;c[2415234]=0;gGz(9660901,0,5);c[2415235]=65535;c[2415237]=65535;a[9660932]=a[9660932]|64;mB(0);mB(1);UA();c[2429502]=0;c[2429500]=0;c[2438664]=0;c[2439460]=0;a[9757800]=0;a[9623080]=0;a[9623072]=0;a[683232]=0;a[9754673]=0;a[9754672]=0;a[9754680]=0;a[9718896]=0;a[9717272]=0;a[9718824]=0}a[9623088]=0;a[9623096]=0;a[9623104]=0;o=0;l=0;k=0;n=0;do{l=((a[9757832+o|0]&1)<<o|l&255)&255;k=((a[9757824+o|0]&1)<<o|k&255)&255;n=((a[9757816+o|0]&1)<<o|n&255)&255;o=o+1|0;}while((o|0)<8);a[9623104]=l;a[9623096]=k;a[9623088]=n;if((l&3)==3){n=l&-4;a[9623104]=n;q=n}else{q=l}if((q&12)==12){a[9623104]=q&-13}if((k&3)==3){q=k&-4;a[9623096]=q;r=q}else{r=k}if((r&12)==12){a[9623096]=r&-13}c[2440554]=((c[3527088]|0)>>>0)/60|0;c[2440496]=a[6243312]|0?14914:0;c[2444e3]=0;c[2444052]=0;r=c[2385548]|0;if((r|0)>0){gGz(9752472,0,((r|0)>1?r<<2:4)|0)}c[2433530]=0;c[2113162]=0;if((h|0)>0){r=h-1|0;k=0;q=0;while(1){l=c[2439330]|0;if((l|0)!=0){n=l;gGC(9706056,n|0,76)|0}b[4853030]=c[2426515]&65535;n=c[2438118]|0;c[2433530]=n;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;o=k+1|0;p=(ag(c[2440554]|0,o)|0)/(h|0)|0;i=c[2444052]|0;j=p-i|0;do{if((j|0)<1){s=0;t=i}else{if((a[l+4188|0]|0)==0){p=gfc(j)|0;c[2433530]=(c[2433530]|0)+p;s=p;t=c[2444052]|0;break}else{c[2433530]=n+j;s=j;t=i;break}}}while(0);c[2444052]=t+s;if((k|0)==(r|0)){a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0}i=c[1836236]|0;j=c[9757320+(i<<2)>>2]|0;if((j|0)!=0){n=j;gGC(n|0,9706056,76)|0}c[9752472+(i<<2)>>2]=c[2433530];c[14113936+(i<<2)>>2]=c[2076596];c[9669104+(i<<2)>>2]=c[3541536];c[1836236]=-1;i=(ag(c[2440496]|0,o)|0)/(h|0)|0;n=f4c(i-(c[2444e3]|0)|0)|0;c[2113162]=(c[2113162]|0)+n;c[2444e3]=(c[2444e3]|0)+n;n=c[2112964]|0;if((n|0)==0){u=q}else{i=((a[9688]|0?534:0)|0)/(h|0)|0;mF(9756720,n+(q<<1<<1)|0,i,0);u=i+q|0}i=c[2439330]|0;if((i|0)!=0){n=i;gGC(9706056,n|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;UD();if(a[683232]|0){c[2415126]=9665376;n=(c[2416347]|0)!=0;i=c[2416345]|0;if(n|(i|0)==1){v=i}else{c[2416345]=1;v=1}c[2415126]=9665376;if(!(n|(v|0)==0)){c[2416345]=0;UC(1)}a[683232]=0}n=c[1836236]|0;i=c[9757320+(n<<2)>>2]|0;if((i|0)!=0){j=i;gGC(j|0,9706056,76)|0}c[9752472+(n<<2)>>2]=c[2433530];c[14113936+(n<<2)>>2]=c[2076596];c[9669104+(n<<2)>>2]=c[3541536];c[1836236]=-1;if((o|0)<(h|0)){k=o;q=u}else{w=u;break}}}else{w=0}u=c[2112964]|0;if((u|0)!=0){q=a[9688]|0?534:0;if((q|0)!=(w|0)){mF(9756720,u+(w<<1<<1)|0,q-w|0,0)}w=c[2439330]|0;if((w|0)!=0){k=w;gGC(9706056,k|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;Uz(0,u,q);Uz(1,c[2112964]|0,a[9688]|0?534:0);q=c[1836236]|0;u=c[9757320+(q<<2)>>2]|0;if((u|0)!=0){k=u;gGC(k|0,9706056,76)|0}c[9752472+(q<<2)>>2]=c[2433530];c[14113936+(q<<2)>>2]=c[2076596];c[9669104+(q<<2)>>2]=c[3541536];c[1836236]=-1}q=c[2431670]|0;if(!((c[2112968]|0)!=0&(q|0)!=0)){return 0}gu[q&16383]();return 0}function a8B(a,b){a=a|0;b=b|0;var d=0,e=0;d=i;i=i+16|0;e=d|0;if((b|0)!=0){c[b>>2]=169737}if((a&32|0)==0){i=d;return 0}gGz(e|0,0,12);a=c[2405722]|0;c[e>>2]=a;c[e+4>>2]=(c[2411886]|0)-a;c[e+12>>2]=162152;gj[c[2076592]&4095](e)|0;i=d;return 0}function a8C(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3812540+(b*112|0)>>2];c[a+104>>2]=c[3812544+(b*112|0)>>2];c[a+108>>2]=c[3812548+(b*112|0)>>2];d=0;return d|0}function a8D(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<21&(d|0)==0)){e=1;return e|0}c[a>>2]=3812440+(b*112|0);e=0;return e|0}function a8E(){var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0;e=i;i=i+2520|0;f=e|0;g=e+112|0;h=e+120|0;j=e+232|0;k=e+240|0;l=e+352|0;m=e+360|0;n=e+472|0;o=e+480|0;p=e+592|0;q=e+600|0;r=e+712|0;s=e+720|0;t=e+832|0;u=e+840|0;v=e+952|0;w=e+960|0;x=e+1072|0;y=e+1080|0;z=e+1192|0;A=e+1200|0;B=e+1312|0;C=e+1320|0;D=e+1432|0;E=e+1440|0;F=e+1552|0;G=e+1560|0;H=e+1672|0;I=e+1680|0;J=e+1792|0;K=e+1800|0;L=e+1912|0;M=e+1920|0;N=e+2032|0;O=e+2040|0;P=e+2152|0;Q=e+2160|0;R=e+2272|0;S=e+2280|0;T=e+2392|0;U=e+2400|0;V=e+2512|0;c[2439448]=32768;c[3527090]=1824;c[3527094]=1024;c[2439452]=1024;c[2431672]=c[(c[642608+(c[2436]<<2)>>2]|0)+124>>2];c[2426820]=0;a9Q();W=c[2414438]|0;X=0;while(1){if((X|0)>=1024){break}Y=9638528+(X<<2)|0;if((c[Y>>2]|0)==0){Z=52810;break}else{X=X+1|0}}do{if((Z|0)==52810){X=gGq(W)|0;c[Y>>2]=X;if((X|0)==0){break}gGz(X|0,0,W|0);c[2426820]=X;gGz(X|0,0,W|0);a9Q();X=0;while(1){if((X|0)>=1024){_=0;break}$=9638528+(X<<2)|0;if((c[$>>2]|0)==0){Z=52815;break}else{X=X+1|0}}do{if((Z|0)==52815){X=gGq(98304)|0;c[$>>2]=X;if((X|0)==0){_=0;break}gGz(X|0,0,98304);_=X}}while(0);c[3529012]=_;X=c[2385798]|0;if((c[3542200]|0)==0){aa=1;i=e;return aa|0}ab=U+108|0;c[ab>>2]=0;ac=U+100|0;c[ac>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](U,0)|0;do{if((c[ab>>2]|0)!=0){ad=c[ac>>2]|0;c[V>>2]=9534384;ae=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ae&16383](V,0,0)|0;if((ad|0)<1){aa=1;i=e;return aa|0}if((gzL(X,0,0)|0)==0){break}else{aa=1}i=e;return aa|0}}while(0);X=(c[2385798]|0)+16384|0;if((c[3542200]|0)==0){aa=1;i=e;return aa|0}ac=S+108|0;c[ac>>2]=0;ab=S+100|0;c[ab>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](S,1)|0;do{if((c[ac>>2]|0)!=0){ad=c[ab>>2]|0;c[T>>2]=9534384;ae=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ae&16383](T,1,0)|0;if((ad|0)<1){aa=1;i=e;return aa|0}if((gzL(X,0,1)|0)==0){break}else{aa=1}i=e;return aa|0}}while(0);X=(c[3527098]|0)+16384|0;if((c[3542200]|0)==0){aa=1;i=e;return aa|0}ab=Q+108|0;c[ab>>2]=0;ac=Q+100|0;c[ac>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](Q,2)|0;do{if((c[ab>>2]|0)!=0){ad=c[ac>>2]|0;c[R>>2]=9534384;ae=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ae&16383](R,2,0)|0;if((ad|0)<1){aa=1;i=e;return aa|0}if((gzL(X,0,2)|0)==0){break}else{aa=1}i=e;return aa|0}}while(0);X=(c[3527098]|0)+32768|0;if((c[3542200]|0)==0){aa=1;i=e;return aa|0}ac=O+108|0;c[ac>>2]=0;ab=O+100|0;c[ab>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](O,3)|0;do{if((c[ac>>2]|0)!=0){ad=c[ab>>2]|0;c[P>>2]=9534384;ae=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ae&16383](P,3,0)|0;if((ad|0)<1){aa=1;i=e;return aa|0}if((gzL(X,0,3)|0)==0){break}else{aa=1}i=e;return aa|0}}while(0);X=c[3529012]|0;gGz(X|0,0,98304);if((c[3542200]|0)==0){aa=1;i=e;return aa|0}ab=M+108|0;c[ab>>2]=0;ac=M+100|0;c[ac>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](M,4)|0;do{if((c[ab>>2]|0)!=0){ad=c[ac>>2]|0;c[N>>2]=9534384;ae=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ae&16383](N,4,0)|0;if((ad|0)<1){aa=1;i=e;return aa|0}if((gzL(X,0,4)|0)==0){break}else{aa=1}i=e;return aa|0}}while(0);X=(c[3529012]|0)+8192|0;if((c[3542200]|0)==0){aa=1;i=e;return aa|0}ac=K+108|0;c[ac>>2]=0;ab=K+100|0;c[ab>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](K,5)|0;do{if((c[ac>>2]|0)!=0){ad=c[ab>>2]|0;c[L>>2]=9534384;ae=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ae&16383](L,5,0)|0;if((ad|0)<1){aa=1;i=e;return aa|0}if((gzL(X,0,5)|0)==0){break}else{aa=1}i=e;return aa|0}}while(0);X=(c[3529012]|0)+16384|0;if((c[3542200]|0)==0){aa=1;i=e;return aa|0}ab=I+108|0;c[ab>>2]=0;ac=I+100|0;c[ac>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](I,6)|0;do{if((c[ab>>2]|0)!=0){ad=c[ac>>2]|0;c[J>>2]=9534384;ae=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ae&16383](J,6,0)|0;if((ad|0)<1){aa=1;i=e;return aa|0}if((gzL(X,0,6)|0)==0){break}else{aa=1}i=e;return aa|0}}while(0);X=c[3527094]|0;ac=c[2439464]|0;ab=c[2439462]|0;ad=c[3529012]|0;ae=c[2405764]|0;if((X|0)>0){af=ag(ab,ac)|0;ah=(ab|0)<1|(ac|0)<1;ai=0;do{aj=ag(ai,af)|0;gGz(ae+aj|0,0,af|0);ak=ai<<6;al=ak+131072|0;if(!ah){am=0;do{an=al+(c[1238464+(am<<2)>>2]|0)|0;ao=(ag(am,ac)|0)+aj|0;ap=0;do{aq=an+(c[614800+(ap<<2)>>2]|0)|0;if(((d[ad+((aq|0)/8|0)|0]|0)&128>>>((aq&7)>>>0)|0)!=0){aq=ae+(ao+ap)|0;a[aq]=a[aq]|4}ap=ap+1|0;}while((ap|0)<(ac|0));am=am+1|0;}while((am|0)<(ab|0));am=ak+65536|0;al=0;while(1){ap=am+(c[1238464+(al<<2)>>2]|0)|0;ao=(ag(al,ac)|0)+aj|0;an=0;do{aq=ap+(c[614800+(an<<2)>>2]|0)|0;if(((d[ad+((aq|0)/8|0)|0]|0)&128>>>((aq&7)>>>0)|0)!=0){aq=ae+(ao+an)|0;a[aq]=a[aq]|2}an=an+1|0;}while((an|0)<(ac|0));an=al+1|0;if((an|0)<(ab|0)){al=an}else{ar=0;break}}do{al=ak+(c[1238464+(ar<<2)>>2]|0)|0;am=(ag(ar,ac)|0)+aj|0;an=0;do{ao=al+(c[614800+(an<<2)>>2]|0)|0;if(((d[ad+((ao|0)/8|0)|0]|0)&128>>>((ao&7)>>>0)|0)!=0){ao=ae+(am+an)|0;a[ao]=a[ao]|1}an=an+1|0;}while((an|0)<(ac|0));ar=ar+1|0;}while((ar|0)<(ab|0))}ai=ai+1|0;}while((ai|0)<(X|0))}gGz(ad|0,0,98304);if((c[3542200]|0)==0){aa=1;i=e;return aa|0}X=G+108|0;c[X>>2]=0;ai=G+100|0;c[ai>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](G,7)|0;do{if((c[X>>2]|0)!=0){ab=c[ai>>2]|0;c[H>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](H,7,0)|0;if((ab|0)<1){aa=1;i=e;return aa|0}if((gzL(ad,0,7)|0)==0){break}else{aa=1}i=e;return aa|0}}while(0);ad=(c[3529012]|0)+16384|0;if((c[3542200]|0)==0){aa=1;i=e;return aa|0}ai=E+108|0;c[ai>>2]=0;X=E+100|0;c[X>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](E,8)|0;do{if((c[ai>>2]|0)!=0){ab=c[X>>2]|0;c[F>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](F,8,0)|0;if((ab|0)<1){aa=1;i=e;return aa|0}if((gzL(ad,0,8)|0)==0){break}else{aa=1}i=e;return aa|0}}while(0);ad=(c[3529012]|0)+32768|0;if((c[3542200]|0)==0){aa=1;i=e;return aa|0}X=C+108|0;c[X>>2]=0;ai=C+100|0;c[ai>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](C,9)|0;do{if((c[X>>2]|0)!=0){ab=c[ai>>2]|0;c[D>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](D,9,0)|0;if((ab|0)<1){aa=1;i=e;return aa|0}if((gzL(ad,0,9)|0)==0){break}else{aa=1}i=e;return aa|0}}while(0);ad=(c[3529012]|0)+49152|0;if((c[3542200]|0)==0){aa=1;i=e;return aa|0}ai=A+108|0;c[ai>>2]=0;X=A+100|0;c[X>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](A,10)|0;do{if((c[ai>>2]|0)!=0){ab=c[X>>2]|0;c[B>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](B,10,0)|0;if((ab|0)<1){aa=1;i=e;return aa|0}if((gzL(ad,0,10)|0)==0){break}else{aa=1}i=e;return aa|0}}while(0);ad=(c[3529012]|0)+65536|0;if((c[3542200]|0)==0){aa=1;i=e;return aa|0}X=y+108|0;c[X>>2]=0;ai=y+100|0;c[ai>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](y,11)|0;do{if((c[X>>2]|0)!=0){ab=c[ai>>2]|0;c[z>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](z,11,0)|0;if((ab|0)<1){aa=1;i=e;return aa|0}if((gzL(ad,0,11)|0)==0){break}else{aa=1}i=e;return aa|0}}while(0);ad=(c[3529012]|0)+81920|0;if((c[3542200]|0)==0){aa=1;i=e;return aa|0}ai=w+108|0;c[ai>>2]=0;X=w+100|0;c[X>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](w,12)|0;do{if((c[ai>>2]|0)!=0){ab=c[X>>2]|0;c[x>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](x,12,0)|0;if((ab|0)<1){aa=1;i=e;return aa|0}if((gzL(ad,0,12)|0)==0){break}else{aa=1}i=e;return aa|0}}while(0);ad=c[2439452]|0;X=c[3529012]|0;ai=c[3529014]|0;if((ad|0)>0){ab=0;do{ac=ab<<8;gGz(ai+ac|0,0,256);ae=ac+524288|0;ah=0;do{af=ae+(c[609008+(ah<<2)>>2]|0)|0;aj=(ah<<4)+ac|0;ak=0;do{an=af+(c[597864+(ak<<2)>>2]|0)|0;if(((d[X+((an|0)/8|0)|0]|0)&128>>>((an&7)>>>0)|0)!=0){an=ai+(aj+ak)|0;a[an]=a[an]|4}ak=ak+1|0;}while((ak|0)<16);ah=ah+1|0;}while((ah|0)<16);ah=ac+262144|0;ae=0;while(1){ak=ah+(c[609008+(ae<<2)>>2]|0)|0;aj=(ae<<4)+ac|0;af=0;do{an=ak+(c[597864+(af<<2)>>2]|0)|0;if(((d[X+((an|0)/8|0)|0]|0)&128>>>((an&7)>>>0)|0)!=0){an=ai+(aj+af)|0;a[an]=a[an]|2}af=af+1|0;}while((af|0)<16);af=ae+1|0;if((af|0)<16){ae=af}else{as=0;break}}do{ae=ac+(c[609008+(as<<2)>>2]|0)|0;ah=(as<<4)+ac|0;af=0;do{aj=ae+(c[597864+(af<<2)>>2]|0)|0;if(((d[X+((aj|0)/8|0)|0]|0)&128>>>((aj&7)>>>0)|0)!=0){aj=ai+(ah+af)|0;a[aj]=a[aj]|1}af=af+1|0;}while((af|0)<16);as=as+1|0;}while((as|0)<16);ab=ab+1|0;}while((ab|0)<(ad|0))}ad=c[3527092]|0;if((c[3542200]|0)==0){aa=1;i=e;return aa|0}ab=u+108|0;c[ab>>2]=0;ai=u+100|0;c[ai>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](u,13)|0;do{if((c[ab>>2]|0)!=0){X=c[ai>>2]|0;c[v>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](v,13,0)|0;if((X|0)<1){aa=1;i=e;return aa|0}if((gzL(ad,0,13)|0)==0){break}else{aa=1}i=e;return aa|0}}while(0);ad=(c[3527092]|0)+256|0;if((c[3542200]|0)==0){aa=1;i=e;return aa|0}ai=s+108|0;c[ai>>2]=0;ab=s+100|0;c[ab>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](s,14)|0;do{if((c[ai>>2]|0)!=0){X=c[ab>>2]|0;c[t>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](t,14,0)|0;if((X|0)<1){aa=1;i=e;return aa|0}if((gzL(ad,0,14)|0)==0){break}else{aa=1}i=e;return aa|0}}while(0);ad=(c[3527092]|0)+512|0;if((c[3542200]|0)==0){aa=1;i=e;return aa|0}ab=q+108|0;c[ab>>2]=0;ai=q+100|0;c[ai>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](q,15)|0;do{if((c[ab>>2]|0)!=0){X=c[ai>>2]|0;c[r>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](r,15,0)|0;if((X|0)<1){aa=1;i=e;return aa|0}if((gzL(ad,0,15)|0)==0){break}else{aa=1}i=e;return aa|0}}while(0);ad=(c[3527092]|0)+768|0;if((c[3542200]|0)==0){aa=1;i=e;return aa|0}ai=o+108|0;c[ai>>2]=0;ab=o+100|0;c[ab>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](o,16)|0;do{if((c[ai>>2]|0)!=0){X=c[ab>>2]|0;c[p>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](p,16,0)|0;if((X|0)<1){aa=1;i=e;return aa|0}if((gzL(ad,0,16)|0)==0){break}else{aa=1}i=e;return aa|0}}while(0);ad=(c[3527092]|0)+1024|0;if((c[3542200]|0)==0){aa=1;i=e;return aa|0}ab=m+108|0;c[ab>>2]=0;ai=m+100|0;c[ai>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,17)|0;do{if((c[ab>>2]|0)!=0){X=c[ai>>2]|0;c[n>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](n,17,0)|0;if((X|0)<1){aa=1;i=e;return aa|0}if((gzL(ad,0,17)|0)==0){break}else{aa=1}i=e;return aa|0}}while(0);ad=(c[3527092]|0)+1280|0;if((c[3542200]|0)==0){aa=1;i=e;return aa|0}ai=k+108|0;c[ai>>2]=0;ab=k+100|0;c[ab>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,18)|0;do{if((c[ai>>2]|0)!=0){X=c[ab>>2]|0;c[l>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](l,18,0)|0;if((X|0)<1){aa=1;i=e;return aa|0}if((gzL(ad,0,18)|0)==0){break}else{aa=1}i=e;return aa|0}}while(0);ad=(c[3527092]|0)+1536|0;if((c[3542200]|0)==0){aa=1;i=e;return aa|0}ab=h+108|0;c[ab>>2]=0;ai=h+100|0;c[ai>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](h,19)|0;do{if((c[ab>>2]|0)!=0){X=c[ai>>2]|0;c[j>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](j,19,0)|0;if((X|0)<1){aa=1;i=e;return aa|0}if((gzL(ad,0,19)|0)==0){break}else{aa=1}i=e;return aa|0}}while(0);ad=(c[3527092]|0)+1568|0;if((c[3542200]|0)==0){aa=1;i=e;return aa|0}ai=f+108|0;c[ai>>2]=0;ab=f+100|0;c[ab>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,20)|0;do{if((c[ai>>2]|0)!=0){X=c[ab>>2]|0;c[g>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](g,20,0)|0;if((X|0)<1){aa=1;i=e;return aa|0}if((gzL(ad,0,20)|0)==0){break}else{aa=1}i=e;return aa|0}}while(0);ad=c[3529012]|0;ab=0;while(1){if((ab|0)>=1024){break}at=9638528+(ab<<2)|0;if((c[at>>2]|0)==(ad|0)){Z=52921;break}else{ab=ab+1|0}}if((Z|0)==52921){gGr(ad);c[at>>2]=0}c[3529012]=0;a9H();ab=c[2439330]|0;ai=(ab|0)==0;if(!ai){X=ab;gGC(9706056,X|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];X=c[3528484]|0;c[2076596]=X;ac=c[2417276]|0;c[3541536]=ac;c[1836236]=0;c[ab+4180>>2]=960;c[ab+4184>>2]=2174;if(!ai){af=ab;gGC(af|0,9706056,76)|0}af=c[2433530]|0;c[2438118]=af;c[3528484]=X;c[2417276]=ac;c[1836236]=-1;c[3527088]=3072e3;c[2431670]=5838;if(ai){c[2433530]=af;c[2076596]=X;c[3541536]=ac;c[1836236]=0;gGz(9706056,0,76)}else{ai=ab;gGC(9706056,ai|0,76)|0;c[2433530]=af;c[2076596]=X;c[3541536]=ac;c[1836236]=0;gGz(9706056,0,76);ai=ab;gGC(ai|0,9706056,76)|0}c[2438118]=af;c[3528484]=X;c[2417276]=ac;c[1836236]=-1;a[9660900]=a[9660900]|16;ac=c[2437644]|0;X=c[ac+1092>>2]|0;do{if((X|0)==0){af=c[ac+3144>>2]|0;if((af|0)==0){au=0;av=0;break}ai=gj[af&4095](-2)|0;af=c[2437644]|0;ab=c[af+1092>>2]|0;ah=(ai&255)<<8;if((ab|0)!=0){aw=ab;ax=ah;Z=52933;break}ab=c[af+3144>>2]|0;if((ab|0)==0){au=0;av=ah;break}au=gj[ab&4095](-1)|0;av=ah}else{aw=X;ax=(d[X+254|0]|0)<<8;Z=52933}}while(0);if((Z|0)==52933){au=a[aw+255|0]|0;av=ax}X=au&255|av;c[2415221]=X;b[4830442]=X&65535;a[9660920]=0;a[9660921]=0;a[9660928]=0;a[9660930]=0;a[9660931]=0;c[2415234]=0;gGz(9660901,0,5);c[2415235]=65535;c[2415237]=65535;a[9660932]=a[9660932]|64;mB(0);mB(1);UA();c[2429502]=0;c[2429500]=0;c[2438664]=0;c[2439460]=0;a[9757800]=0;a[9623080]=0;a[9623072]=0;a[683232]=0;a[9754673]=0;a[9754672]=0;a[9754680]=0;a[9718896]=0;a[9717272]=0;a[9718824]=0;aa=0;i=e;return aa|0}}while(0);c[2426820]=0;aa=1;i=e;return aa|0}function a8F(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>27){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3398508+(b*112|0)>>2];c[a+104>>2]=c[3398512+(b*112|0)>>2];c[a+108>>2]=c[3398516+(b*112|0)>>2];d=0;return d|0}function a8G(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<28&(d|0)==0)){e=1;return e|0}c[a>>2]=3398408+(b*112|0);e=0;return e|0}function a8H(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>44){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5318388+(b*112|0)>>2];c[a+104>>2]=c[5318392+(b*112|0)>>2];c[a+108>>2]=c[5318396+(b*112|0)>>2];d=0;return d|0}function a8I(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<45&(d|0)==0)){e=1;return e|0}c[a>>2]=5318288+(b*112|0);e=0;return e|0}function a8J(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>27){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3817356+(b*112|0)>>2];c[a+104>>2]=c[3817360+(b*112|0)>>2];c[a+108>>2]=c[3817364+(b*112|0)>>2];d=0;return d|0}function a8K(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<28&(d|0)==0)){e=1;return e|0}c[a>>2]=3817256+(b*112|0);e=0;return e|0}function a8L(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3814892+(b*112|0)>>2];c[a+104>>2]=c[3814896+(b*112|0)>>2];c[a+108>>2]=c[3814900+(b*112|0)>>2];d=0;return d|0}function a8M(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<22&(d|0)==0)){e=1;return e|0}c[a>>2]=3814792+(b*112|0);e=0;return e|0}function a8N(){var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0;e=i;i=i+2640|0;f=e|0;g=e+112|0;h=e+120|0;j=e+232|0;k=e+240|0;l=e+352|0;m=e+360|0;n=e+472|0;o=e+480|0;p=e+592|0;q=e+600|0;r=e+712|0;s=e+720|0;t=e+832|0;u=e+840|0;v=e+952|0;w=e+960|0;x=e+1072|0;y=e+1080|0;z=e+1192|0;A=e+1200|0;B=e+1312|0;C=e+1320|0;D=e+1432|0;E=e+1440|0;F=e+1552|0;G=e+1560|0;H=e+1672|0;I=e+1680|0;J=e+1792|0;K=e+1800|0;L=e+1912|0;M=e+1920|0;N=e+2032|0;O=e+2040|0;P=e+2152|0;Q=e+2160|0;R=e+2272|0;S=e+2280|0;T=e+2392|0;U=e+2400|0;V=e+2512|0;W=e+2520|0;X=e+2632|0;c[2439448]=32768;c[3527090]=1824;c[3527094]=1024;c[2439452]=1024;c[2431672]=c[(c[642608+(c[2436]<<2)>>2]|0)+124>>2];c[2426820]=0;a9Q();Y=c[2414438]|0;Z=0;while(1){if((Z|0)>=1024){break}_=9638528+(Z<<2)|0;if((c[_>>2]|0)==0){$=53076;break}else{Z=Z+1|0}}do{if(($|0)==53076){Z=gGq(Y)|0;c[_>>2]=Z;if((Z|0)==0){break}gGz(Z|0,0,Y|0);c[2426820]=Z;gGz(Z|0,0,Y|0);a9Q();Z=0;while(1){if((Z|0)>=1024){aa=0;break}ab=9638528+(Z<<2)|0;if((c[ab>>2]|0)==0){$=53081;break}else{Z=Z+1|0}}do{if(($|0)==53081){Z=gGq(98304)|0;c[ab>>2]=Z;if((Z|0)==0){aa=0;break}gGz(Z|0,0,98304);aa=Z}}while(0);c[3529012]=aa;Z=c[2385798]|0;if((c[3542200]|0)==0){ac=1;i=e;return ac|0}ad=W+108|0;c[ad>>2]=0;ae=W+100|0;c[ae>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](W,0)|0;do{if((c[ad>>2]|0)!=0){af=c[ae>>2]|0;c[X>>2]=9534384;ah=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ah&16383](X,0,0)|0;if((af|0)<1){ac=1;i=e;return ac|0}if((gzL(Z,0,0)|0)==0){break}else{ac=1}i=e;return ac|0}}while(0);Z=(c[2385798]|0)+16384|0;if((c[3542200]|0)==0){ac=1;i=e;return ac|0}ae=U+108|0;c[ae>>2]=0;ad=U+100|0;c[ad>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](U,1)|0;do{if((c[ae>>2]|0)!=0){af=c[ad>>2]|0;c[V>>2]=9534384;ah=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ah&16383](V,1,0)|0;if((af|0)<1){ac=1;i=e;return ac|0}if((gzL(Z,0,1)|0)==0){break}else{ac=1}i=e;return ac|0}}while(0);Z=(c[3527098]|0)+24576|0;if((c[3542200]|0)==0){ac=1;i=e;return ac|0}ad=S+108|0;c[ad>>2]=0;ae=S+100|0;c[ae>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](S,2)|0;do{if((c[ad>>2]|0)!=0){af=c[ae>>2]|0;c[T>>2]=9534384;ah=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ah&16383](T,2,0)|0;if((af|0)<1){ac=1;i=e;return ac|0}if((gzL(Z,0,2)|0)==0){break}else{ac=1}i=e;return ac|0}}while(0);Z=(c[3527098]|0)+32768|0;if((c[3542200]|0)==0){ac=1;i=e;return ac|0}ae=Q+108|0;c[ae>>2]=0;ad=Q+100|0;c[ad>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](Q,3)|0;do{if((c[ae>>2]|0)!=0){af=c[ad>>2]|0;c[R>>2]=9534384;ah=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ah&16383](R,3,0)|0;if((af|0)<1){ac=1;i=e;return ac|0}if((gzL(Z,0,3)|0)==0){break}else{ac=1}i=e;return ac|0}}while(0);Z=(c[3527098]|0)+40960|0;if((c[3542200]|0)==0){ac=1;i=e;return ac|0}ad=O+108|0;c[ad>>2]=0;ae=O+100|0;c[ae>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](O,4)|0;do{if((c[ad>>2]|0)!=0){af=c[ae>>2]|0;c[P>>2]=9534384;ah=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ah&16383](P,4,0)|0;if((af|0)<1){ac=1;i=e;return ac|0}if((gzL(Z,0,4)|0)==0){break}else{ac=1}i=e;return ac|0}}while(0);Z=c[3529012]|0;gGz(Z|0,0,98304);if((c[3542200]|0)==0){ac=1;i=e;return ac|0}ae=M+108|0;c[ae>>2]=0;ad=M+100|0;c[ad>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](M,5)|0;do{if((c[ae>>2]|0)!=0){af=c[ad>>2]|0;c[N>>2]=9534384;ah=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ah&16383](N,5,0)|0;if((af|0)<1){ac=1;i=e;return ac|0}if((gzL(Z,0,5)|0)==0){break}else{ac=1}i=e;return ac|0}}while(0);Z=(c[3529012]|0)+8192|0;if((c[3542200]|0)==0){ac=1;i=e;return ac|0}ad=K+108|0;c[ad>>2]=0;ae=K+100|0;c[ae>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](K,6)|0;do{if((c[ad>>2]|0)!=0){af=c[ae>>2]|0;c[L>>2]=9534384;ah=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ah&16383](L,6,0)|0;if((af|0)<1){ac=1;i=e;return ac|0}if((gzL(Z,0,6)|0)==0){break}else{ac=1}i=e;return ac|0}}while(0);Z=(c[3529012]|0)+16384|0;if((c[3542200]|0)==0){ac=1;i=e;return ac|0}ae=I+108|0;c[ae>>2]=0;ad=I+100|0;c[ad>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](I,7)|0;do{if((c[ae>>2]|0)!=0){af=c[ad>>2]|0;c[J>>2]=9534384;ah=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ah&16383](J,7,0)|0;if((af|0)<1){ac=1;i=e;return ac|0}if((gzL(Z,0,7)|0)==0){break}else{ac=1}i=e;return ac|0}}while(0);Z=c[3527094]|0;ad=c[2439464]|0;ae=c[2439462]|0;af=c[3529012]|0;ah=c[2405764]|0;if((Z|0)>0){ai=ag(ae,ad)|0;aj=(ae|0)<1|(ad|0)<1;ak=0;do{al=ag(ak,ai)|0;gGz(ah+al|0,0,ai|0);am=ak<<6;an=am+131072|0;if(!aj){ao=0;do{ap=an+(c[1238464+(ao<<2)>>2]|0)|0;aq=(ag(ao,ad)|0)+al|0;ar=0;do{as=ap+(c[614800+(ar<<2)>>2]|0)|0;if(((d[af+((as|0)/8|0)|0]|0)&128>>>((as&7)>>>0)|0)!=0){as=ah+(aq+ar)|0;a[as]=a[as]|4}ar=ar+1|0;}while((ar|0)<(ad|0));ao=ao+1|0;}while((ao|0)<(ae|0));ao=am+65536|0;an=0;while(1){ar=ao+(c[1238464+(an<<2)>>2]|0)|0;aq=(ag(an,ad)|0)+al|0;ap=0;do{as=ar+(c[614800+(ap<<2)>>2]|0)|0;if(((d[af+((as|0)/8|0)|0]|0)&128>>>((as&7)>>>0)|0)!=0){as=ah+(aq+ap)|0;a[as]=a[as]|2}ap=ap+1|0;}while((ap|0)<(ad|0));ap=an+1|0;if((ap|0)<(ae|0)){an=ap}else{at=0;break}}do{an=am+(c[1238464+(at<<2)>>2]|0)|0;ao=(ag(at,ad)|0)+al|0;ap=0;do{aq=an+(c[614800+(ap<<2)>>2]|0)|0;if(((d[af+((aq|0)/8|0)|0]|0)&128>>>((aq&7)>>>0)|0)!=0){aq=ah+(ao+ap)|0;a[aq]=a[aq]|1}ap=ap+1|0;}while((ap|0)<(ad|0));at=at+1|0;}while((at|0)<(ae|0))}ak=ak+1|0;}while((ak|0)<(Z|0))}gGz(af|0,0,98304);if((c[3542200]|0)==0){ac=1;i=e;return ac|0}Z=G+108|0;c[Z>>2]=0;ak=G+100|0;c[ak>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](G,8)|0;do{if((c[Z>>2]|0)!=0){ae=c[ak>>2]|0;c[H>>2]=9534384;ad=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ad&16383](H,8,0)|0;if((ae|0)<1){ac=1;i=e;return ac|0}if((gzL(af,0,8)|0)==0){break}else{ac=1}i=e;return ac|0}}while(0);af=(c[3529012]|0)+16384|0;if((c[3542200]|0)==0){ac=1;i=e;return ac|0}ak=E+108|0;c[ak>>2]=0;Z=E+100|0;c[Z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](E,9)|0;do{if((c[ak>>2]|0)!=0){ae=c[Z>>2]|0;c[F>>2]=9534384;ad=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ad&16383](F,9,0)|0;if((ae|0)<1){ac=1;i=e;return ac|0}if((gzL(af,0,9)|0)==0){break}else{ac=1}i=e;return ac|0}}while(0);af=(c[3529012]|0)+32768|0;if((c[3542200]|0)==0){ac=1;i=e;return ac|0}Z=C+108|0;c[Z>>2]=0;ak=C+100|0;c[ak>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](C,10)|0;do{if((c[Z>>2]|0)!=0){ae=c[ak>>2]|0;c[D>>2]=9534384;ad=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ad&16383](D,10,0)|0;if((ae|0)<1){ac=1;i=e;return ac|0}if((gzL(af,0,10)|0)==0){break}else{ac=1}i=e;return ac|0}}while(0);af=(c[3529012]|0)+49152|0;if((c[3542200]|0)==0){ac=1;i=e;return ac|0}ak=A+108|0;c[ak>>2]=0;Z=A+100|0;c[Z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](A,11)|0;do{if((c[ak>>2]|0)!=0){ae=c[Z>>2]|0;c[B>>2]=9534384;ad=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ad&16383](B,11,0)|0;if((ae|0)<1){ac=1;i=e;return ac|0}if((gzL(af,0,11)|0)==0){break}else{ac=1}i=e;return ac|0}}while(0);af=(c[3529012]|0)+65536|0;if((c[3542200]|0)==0){ac=1;i=e;return ac|0}Z=y+108|0;c[Z>>2]=0;ak=y+100|0;c[ak>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](y,12)|0;do{if((c[Z>>2]|0)!=0){ae=c[ak>>2]|0;c[z>>2]=9534384;ad=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ad&16383](z,12,0)|0;if((ae|0)<1){ac=1;i=e;return ac|0}if((gzL(af,0,12)|0)==0){break}else{ac=1}i=e;return ac|0}}while(0);af=(c[3529012]|0)+81920|0;if((c[3542200]|0)==0){ac=1;i=e;return ac|0}ak=w+108|0;c[ak>>2]=0;Z=w+100|0;c[Z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](w,13)|0;do{if((c[ak>>2]|0)!=0){ae=c[Z>>2]|0;c[x>>2]=9534384;ad=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ad&16383](x,13,0)|0;if((ae|0)<1){ac=1;i=e;return ac|0}if((gzL(af,0,13)|0)==0){break}else{ac=1}i=e;return ac|0}}while(0);af=c[2439452]|0;Z=c[3529012]|0;ak=c[3529014]|0;if((af|0)>0){ae=0;do{ad=ae<<8;gGz(ak+ad|0,0,256);ah=ad+524288|0;aj=0;do{ai=ah+(c[609008+(aj<<2)>>2]|0)|0;al=(aj<<4)+ad|0;am=0;do{ap=ai+(c[597864+(am<<2)>>2]|0)|0;if(((d[Z+((ap|0)/8|0)|0]|0)&128>>>((ap&7)>>>0)|0)!=0){ap=ak+(al+am)|0;a[ap]=a[ap]|4}am=am+1|0;}while((am|0)<16);aj=aj+1|0;}while((aj|0)<16);aj=ad+262144|0;ah=0;while(1){am=aj+(c[609008+(ah<<2)>>2]|0)|0;al=(ah<<4)+ad|0;ai=0;do{ap=am+(c[597864+(ai<<2)>>2]|0)|0;if(((d[Z+((ap|0)/8|0)|0]|0)&128>>>((ap&7)>>>0)|0)!=0){ap=ak+(al+ai)|0;a[ap]=a[ap]|2}ai=ai+1|0;}while((ai|0)<16);ai=ah+1|0;if((ai|0)<16){ah=ai}else{au=0;break}}do{ah=ad+(c[609008+(au<<2)>>2]|0)|0;aj=(au<<4)+ad|0;ai=0;do{al=ah+(c[597864+(ai<<2)>>2]|0)|0;if(((d[Z+((al|0)/8|0)|0]|0)&128>>>((al&7)>>>0)|0)!=0){al=ak+(aj+ai)|0;a[al]=a[al]|1}ai=ai+1|0;}while((ai|0)<16);au=au+1|0;}while((au|0)<16);ae=ae+1|0;}while((ae|0)<(af|0))}af=c[3527092]|0;if((c[3542200]|0)==0){ac=1;i=e;return ac|0}ae=u+108|0;c[ae>>2]=0;ak=u+100|0;c[ak>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](u,14)|0;do{if((c[ae>>2]|0)!=0){Z=c[ak>>2]|0;c[v>>2]=9534384;ad=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ad&16383](v,14,0)|0;if((Z|0)<1){ac=1;i=e;return ac|0}if((gzL(af,0,14)|0)==0){break}else{ac=1}i=e;return ac|0}}while(0);af=(c[3527092]|0)+256|0;if((c[3542200]|0)==0){ac=1;i=e;return ac|0}ak=s+108|0;c[ak>>2]=0;ae=s+100|0;c[ae>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](s,15)|0;do{if((c[ak>>2]|0)!=0){Z=c[ae>>2]|0;c[t>>2]=9534384;ad=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ad&16383](t,15,0)|0;if((Z|0)<1){ac=1;i=e;return ac|0}if((gzL(af,0,15)|0)==0){break}else{ac=1}i=e;return ac|0}}while(0);af=(c[3527092]|0)+512|0;if((c[3542200]|0)==0){ac=1;i=e;return ac|0}ae=q+108|0;c[ae>>2]=0;ak=q+100|0;c[ak>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](q,16)|0;do{if((c[ae>>2]|0)!=0){Z=c[ak>>2]|0;c[r>>2]=9534384;ad=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ad&16383](r,16,0)|0;if((Z|0)<1){ac=1;i=e;return ac|0}if((gzL(af,0,16)|0)==0){break}else{ac=1}i=e;return ac|0}}while(0);af=(c[3527092]|0)+768|0;if((c[3542200]|0)==0){ac=1;i=e;return ac|0}ak=o+108|0;c[ak>>2]=0;ae=o+100|0;c[ae>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](o,17)|0;do{if((c[ak>>2]|0)!=0){Z=c[ae>>2]|0;c[p>>2]=9534384;ad=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ad&16383](p,17,0)|0;if((Z|0)<1){ac=1;i=e;return ac|0}if((gzL(af,0,17)|0)==0){break}else{ac=1}i=e;return ac|0}}while(0);af=(c[3527092]|0)+1024|0;if((c[3542200]|0)==0){ac=1;i=e;return ac|0}ae=m+108|0;c[ae>>2]=0;ak=m+100|0;c[ak>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,18)|0;do{if((c[ae>>2]|0)!=0){Z=c[ak>>2]|0;c[n>>2]=9534384;ad=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ad&16383](n,18,0)|0;if((Z|0)<1){ac=1;i=e;return ac|0}if((gzL(af,0,18)|0)==0){break}else{ac=1}i=e;return ac|0}}while(0);af=(c[3527092]|0)+1280|0;if((c[3542200]|0)==0){ac=1;i=e;return ac|0}ak=k+108|0;c[ak>>2]=0;ae=k+100|0;c[ae>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,19)|0;do{if((c[ak>>2]|0)!=0){Z=c[ae>>2]|0;c[l>>2]=9534384;ad=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ad&16383](l,19,0)|0;if((Z|0)<1){ac=1;i=e;return ac|0}if((gzL(af,0,19)|0)==0){break}else{ac=1}i=e;return ac|0}}while(0);af=(c[3527092]|0)+1536|0;if((c[3542200]|0)==0){ac=1;i=e;return ac|0}ae=h+108|0;c[ae>>2]=0;ak=h+100|0;c[ak>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](h,20)|0;do{if((c[ae>>2]|0)!=0){Z=c[ak>>2]|0;c[j>>2]=9534384;ad=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ad&16383](j,20,0)|0;if((Z|0)<1){ac=1;i=e;return ac|0}if((gzL(af,0,20)|0)==0){break}else{ac=1}i=e;return ac|0}}while(0);af=(c[3527092]|0)+1568|0;if((c[3542200]|0)==0){ac=1;i=e;return ac|0}ak=f+108|0;c[ak>>2]=0;ae=f+100|0;c[ae>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,21)|0;do{if((c[ak>>2]|0)!=0){Z=c[ae>>2]|0;c[g>>2]=9534384;ad=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ad&16383](g,21,0)|0;if((Z|0)<1){ac=1;i=e;return ac|0}if((gzL(af,0,21)|0)==0){break}else{ac=1}i=e;return ac|0}}while(0);af=c[3529012]|0;ae=0;while(1){if((ae|0)>=1024){break}av=9638528+(ae<<2)|0;if((c[av>>2]|0)==(af|0)){$=53191;break}else{ae=ae+1|0}}if(($|0)==53191){gGr(af);c[av>>2]=0}c[3529012]=0;a9H();ae=c[2439330]|0;ak=(ae|0)==0;if(!ak){Z=ae;gGC(9706056,Z|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];Z=c[3528484]|0;c[2076596]=Z;ad=c[2417276]|0;c[3541536]=ad;c[1836236]=0;c[ae+4180>>2]=960;c[ae+4184>>2]=2174;if(!ak){ai=ae;gGC(ai|0,9706056,76)|0}ai=c[2433530]|0;c[2438118]=ai;c[3528484]=Z;c[2417276]=ad;c[1836236]=-1;c[3527088]=3072e3;c[2431670]=5838;if(ak){c[2433530]=ai;c[2076596]=Z;c[3541536]=ad;c[1836236]=0;gGz(9706056,0,76)}else{ak=ae;gGC(9706056,ak|0,76)|0;c[2433530]=ai;c[2076596]=Z;c[3541536]=ad;c[1836236]=0;gGz(9706056,0,76);ak=ae;gGC(ak|0,9706056,76)|0}c[2438118]=ai;c[3528484]=Z;c[2417276]=ad;c[1836236]=-1;a[9660900]=a[9660900]|16;ad=c[2437644]|0;Z=c[ad+1092>>2]|0;do{if((Z|0)==0){ai=c[ad+3144>>2]|0;if((ai|0)==0){aw=0;ax=0;break}ak=gj[ai&4095](-2)|0;ai=c[2437644]|0;ae=c[ai+1092>>2]|0;aj=(ak&255)<<8;if((ae|0)!=0){ay=ae;az=aj;$=53203;break}ae=c[ai+3144>>2]|0;if((ae|0)==0){aw=0;ax=aj;break}aw=gj[ae&4095](-1)|0;ax=aj}else{ay=Z;az=(d[Z+254|0]|0)<<8;$=53203}}while(0);if(($|0)==53203){aw=a[ay+255|0]|0;ax=az}Z=aw&255|ax;c[2415221]=Z;b[4830442]=Z&65535;a[9660920]=0;a[9660921]=0;a[9660928]=0;a[9660930]=0;a[9660931]=0;c[2415234]=0;gGz(9660901,0,5);c[2415235]=65535;c[2415237]=65535;a[9660932]=a[9660932]|64;mB(0);mB(1);UA();c[2429502]=0;c[2429500]=0;c[2438664]=0;c[2439460]=0;a[9757800]=0;a[9623080]=0;a[9623072]=0;a[683232]=0;a[9754673]=0;a[9754672]=0;a[9754680]=0;a[9718896]=0;a[9717272]=0;a[9718824]=0;ac=0;i=e;return ac|0}}while(0);c[2426820]=0;ac=1;i=e;return ac|0}function a8O(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>32){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4245980+(b*112|0)>>2];c[a+104>>2]=c[4245984+(b*112|0)>>2];c[a+108>>2]=c[4245988+(b*112|0)>>2];d=0;return d|0}function a8P(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<33&(d|0)==0)){e=1;return e|0}c[a>>2]=4245880+(b*112|0);e=0;return e|0}function a8Q(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>76){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4249576+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function a8R(){var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0;e=i;i=i+3960|0;f=e|0;g=e+112|0;h=e+120|0;j=e+232|0;k=e+240|0;l=e+352|0;m=e+360|0;n=e+472|0;o=e+480|0;p=e+592|0;q=e+600|0;r=e+712|0;s=e+720|0;t=e+832|0;u=e+840|0;v=e+952|0;w=e+960|0;x=e+1072|0;y=e+1080|0;z=e+1192|0;A=e+1200|0;B=e+1312|0;C=e+1320|0;D=e+1432|0;E=e+1440|0;F=e+1552|0;G=e+1560|0;H=e+1672|0;I=e+1680|0;J=e+1792|0;K=e+1800|0;L=e+1912|0;M=e+1920|0;N=e+2032|0;O=e+2040|0;P=e+2152|0;Q=e+2160|0;R=e+2272|0;S=e+2280|0;T=e+2392|0;U=e+2400|0;V=e+2512|0;W=e+2520|0;X=e+2632|0;Y=e+2640|0;Z=e+2752|0;_=e+2760|0;$=e+2872|0;aa=e+2880|0;ab=e+2992|0;ac=e+3e3|0;ad=e+3112|0;ae=e+3120|0;af=e+3232|0;ah=e+3240|0;ai=e+3352|0;aj=e+3360|0;ak=e+3472|0;al=e+3480|0;am=e+3592|0;an=e+3600|0;ao=e+3712|0;ap=e+3720|0;aq=e+3832|0;ar=e+3840|0;as=e+3952|0;c[2439448]=90112;c[3527090]=1856;c[3527094]=1024;c[2439452]=512;c[3527096]=1024;c[2438666]=2048;c[2431672]=c[(c[642608+(c[2436]<<2)>>2]|0)+124>>2];c[2426820]=0;a9Q();at=c[2414438]|0;au=0;while(1){if((au|0)>=1024){break}av=9638528+(au<<2)|0;if((c[av>>2]|0)==0){aw=53320;break}else{au=au+1|0}}do{if((aw|0)==53320){au=gGq(at)|0;c[av>>2]=au;if((au|0)==0){break}gGz(au|0,0,at|0);c[2426820]=au;gGz(au|0,0,at|0);a9Q();au=0;while(1){if((au|0)>=1024){ax=0;break}ay=9638528+(au<<2)|0;if((c[ay>>2]|0)==0){aw=53325;break}else{au=au+1|0}}do{if((aw|0)==53325){au=gGq(49152)|0;c[ay>>2]=au;if((au|0)==0){ax=0;break}gGz(au|0,0,49152);ax=au}}while(0);c[3529012]=ax;au=c[2385798]|0;if((c[3542200]|0)==0){az=1;i=e;return az|0}aA=ar+108|0;c[aA>>2]=0;aB=ar+100|0;c[aB>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](ar,0)|0;do{if((c[aA>>2]|0)!=0){aC=c[aB>>2]|0;c[as>>2]=9534384;aD=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aD&16383](as,0,0)|0;if((aC|0)<1){az=1;i=e;return az|0}if((gzL(au,0,0)|0)==0){break}else{az=1}i=e;return az|0}}while(0);au=(c[2385798]|0)+8192|0;if((c[3542200]|0)==0){az=1;i=e;return az|0}aB=ap+108|0;c[aB>>2]=0;aA=ap+100|0;c[aA>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](ap,1)|0;do{if((c[aB>>2]|0)!=0){aC=c[aA>>2]|0;c[aq>>2]=9534384;aD=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aD&16383](aq,1,0)|0;if((aC|0)<1){az=1;i=e;return az|0}if((gzL(au,0,1)|0)==0){break}else{az=1}i=e;return az|0}}while(0);au=(c[2385798]|0)+16384|0;if((c[3542200]|0)==0){az=1;i=e;return az|0}aA=an+108|0;c[aA>>2]=0;aB=an+100|0;c[aB>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](an,2)|0;do{if((c[aA>>2]|0)!=0){aC=c[aB>>2]|0;c[ao>>2]=9534384;aD=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aD&16383](ao,2,0)|0;if((aC|0)<1){az=1;i=e;return az|0}if((gzL(au,0,2)|0)==0){break}else{az=1}i=e;return az|0}}while(0);au=(c[2385798]|0)+24576|0;if((c[3542200]|0)==0){az=1;i=e;return az|0}aB=al+108|0;c[aB>>2]=0;aA=al+100|0;c[aA>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](al,3)|0;do{if((c[aB>>2]|0)!=0){aC=c[aA>>2]|0;c[am>>2]=9534384;aD=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aD&16383](am,3,0)|0;if((aC|0)<1){az=1;i=e;return az|0}if((gzL(au,0,3)|0)==0){break}else{az=1}i=e;return az|0}}while(0);au=(c[2385798]|0)+32768|0;if((c[3542200]|0)==0){az=1;i=e;return az|0}aA=aj+108|0;c[aA>>2]=0;aB=aj+100|0;c[aB>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](aj,4)|0;do{if((c[aA>>2]|0)!=0){aC=c[aB>>2]|0;c[ak>>2]=9534384;aD=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aD&16383](ak,4,0)|0;if((aC|0)<1){az=1;i=e;return az|0}if((gzL(au,0,4)|0)==0){break}else{az=1}i=e;return az|0}}while(0);au=(c[2385798]|0)+40960|0;if((c[3542200]|0)==0){az=1;i=e;return az|0}aB=ah+108|0;c[aB>>2]=0;aA=ah+100|0;c[aA>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](ah,5)|0;do{if((c[aB>>2]|0)!=0){aC=c[aA>>2]|0;c[ai>>2]=9534384;aD=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aD&16383](ai,5,0)|0;if((aC|0)<1){az=1;i=e;return az|0}if((gzL(au,0,5)|0)==0){break}else{az=1}i=e;return az|0}}while(0);au=(c[2385798]|0)+49152|0;if((c[3542200]|0)==0){az=1;i=e;return az|0}aA=ae+108|0;c[aA>>2]=0;aB=ae+100|0;c[aB>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](ae,6)|0;do{if((c[aA>>2]|0)!=0){aC=c[aB>>2]|0;c[af>>2]=9534384;aD=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aD&16383](af,6,0)|0;if((aC|0)<1){az=1;i=e;return az|0}if((gzL(au,0,6)|0)==0){break}else{az=1}i=e;return az|0}}while(0);au=(c[2385798]|0)+57344|0;if((c[3542200]|0)==0){az=1;i=e;return az|0}aB=ac+108|0;c[aB>>2]=0;aA=ac+100|0;c[aA>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](ac,7)|0;do{if((c[aB>>2]|0)!=0){aC=c[aA>>2]|0;c[ad>>2]=9534384;aD=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aD&16383](ad,7,0)|0;if((aC|0)<1){az=1;i=e;return az|0}if((gzL(au,0,7)|0)==0){break}else{az=1}i=e;return az|0}}while(0);au=(c[2385798]|0)+65536|0;if((c[3542200]|0)==0){az=1;i=e;return az|0}aA=aa+108|0;c[aA>>2]=0;aB=aa+100|0;c[aB>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](aa,8)|0;do{if((c[aA>>2]|0)!=0){aC=c[aB>>2]|0;c[ab>>2]=9534384;aD=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aD&16383](ab,8,0)|0;if((aC|0)<1){az=1;i=e;return az|0}if((gzL(au,0,8)|0)==0){break}else{az=1}i=e;return az|0}}while(0);au=(c[2385798]|0)+81920|0;if((c[3542200]|0)==0){az=1;i=e;return az|0}aB=_+108|0;c[aB>>2]=0;aA=_+100|0;c[aA>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](_,9)|0;do{if((c[aB>>2]|0)!=0){aC=c[aA>>2]|0;c[$>>2]=9534384;aD=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aD&16383]($,9,0)|0;if((aC|0)<1){az=1;i=e;return az|0}if((gzL(au,0,9)|0)==0){break}else{az=1}i=e;return az|0}}while(0);au=(c[3527098]|0)+24576|0;if((c[3542200]|0)==0){az=1;i=e;return az|0}aA=Y+108|0;c[aA>>2]=0;aB=Y+100|0;c[aB>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](Y,10)|0;do{if((c[aA>>2]|0)!=0){aC=c[aB>>2]|0;c[Z>>2]=9534384;aD=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aD&16383](Z,10,0)|0;if((aC|0)<1){az=1;i=e;return az|0}if((gzL(au,0,10)|0)==0){break}else{az=1}i=e;return az|0}}while(0);au=(c[3527098]|0)+32768|0;if((c[3542200]|0)==0){az=1;i=e;return az|0}aB=W+108|0;c[aB>>2]=0;aA=W+100|0;c[aA>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](W,11)|0;do{if((c[aB>>2]|0)!=0){aC=c[aA>>2]|0;c[X>>2]=9534384;aD=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aD&16383](X,11,0)|0;if((aC|0)<1){az=1;i=e;return az|0}if((gzL(au,0,11)|0)==0){break}else{az=1}i=e;return az|0}}while(0);au=(c[3527098]|0)+40960|0;if((c[3542200]|0)==0){az=1;i=e;return az|0}aA=U+108|0;c[aA>>2]=0;aB=U+100|0;c[aB>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](U,12)|0;do{if((c[aA>>2]|0)!=0){aC=c[aB>>2]|0;c[V>>2]=9534384;aD=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aD&16383](V,12,0)|0;if((aC|0)<1){az=1;i=e;return az|0}if((gzL(au,0,12)|0)==0){break}else{az=1}i=e;return az|0}}while(0);au=c[3529012]|0;gGz(au|0,0,49152);if((c[3542200]|0)==0){az=1;i=e;return az|0}aB=S+108|0;c[aB>>2]=0;aA=S+100|0;c[aA>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](S,13)|0;do{if((c[aB>>2]|0)!=0){aC=c[aA>>2]|0;c[T>>2]=9534384;aD=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aD&16383](T,13,0)|0;if((aC|0)<1){az=1;i=e;return az|0}if((gzL(au,0,13)|0)==0){break}else{az=1}i=e;return az|0}}while(0);au=(c[3529012]|0)+8192|0;if((c[3542200]|0)==0){az=1;i=e;return az|0}aA=Q+108|0;c[aA>>2]=0;aB=Q+100|0;c[aB>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](Q,14)|0;do{if((c[aA>>2]|0)!=0){aC=c[aB>>2]|0;c[R>>2]=9534384;aD=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aD&16383](R,14,0)|0;if((aC|0)<1){az=1;i=e;return az|0}if((gzL(au,0,14)|0)==0){break}else{az=1}i=e;return az|0}}while(0);au=(c[3529012]|0)+16384|0;if((c[3542200]|0)==0){az=1;i=e;return az|0}aB=O+108|0;c[aB>>2]=0;aA=O+100|0;c[aA>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](O,15)|0;do{if((c[aB>>2]|0)!=0){aC=c[aA>>2]|0;c[P>>2]=9534384;aD=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aD&16383](P,15,0)|0;if((aC|0)<1){az=1;i=e;return az|0}if((gzL(au,0,15)|0)==0){break}else{az=1}i=e;return az|0}}while(0);au=c[3527094]|0;aA=c[2439464]|0;aB=c[2439462]|0;aC=c[3529012]|0;aD=c[2405764]|0;if((au|0)>0){aE=ag(aB,aA)|0;aF=(aB|0)<1|(aA|0)<1;aG=0;do{aH=ag(aG,aE)|0;gGz(aD+aH|0,0,aE|0);aI=aG<<6;aJ=aI+131072|0;if(!aF){aK=0;do{aL=aJ+(c[1238464+(aK<<2)>>2]|0)|0;aM=(ag(aK,aA)|0)+aH|0;aN=0;do{aO=aL+(c[614800+(aN<<2)>>2]|0)|0;if(((d[aC+((aO|0)/8|0)|0]|0)&128>>>((aO&7)>>>0)|0)!=0){aO=aD+(aM+aN)|0;a[aO]=a[aO]|4}aN=aN+1|0;}while((aN|0)<(aA|0));aK=aK+1|0;}while((aK|0)<(aB|0));aK=aI+65536|0;aJ=0;while(1){aN=aK+(c[1238464+(aJ<<2)>>2]|0)|0;aM=(ag(aJ,aA)|0)+aH|0;aL=0;do{aO=aN+(c[614800+(aL<<2)>>2]|0)|0;if(((d[aC+((aO|0)/8|0)|0]|0)&128>>>((aO&7)>>>0)|0)!=0){aO=aD+(aM+aL)|0;a[aO]=a[aO]|2}aL=aL+1|0;}while((aL|0)<(aA|0));aL=aJ+1|0;if((aL|0)<(aB|0)){aJ=aL}else{aP=0;break}}do{aJ=aI+(c[1238464+(aP<<2)>>2]|0)|0;aK=(ag(aP,aA)|0)+aH|0;aL=0;do{aM=aJ+(c[614800+(aL<<2)>>2]|0)|0;if(((d[aC+((aM|0)/8|0)|0]|0)&128>>>((aM&7)>>>0)|0)!=0){aM=aD+(aK+aL)|0;a[aM]=a[aM]|1}aL=aL+1|0;}while((aL|0)<(aA|0));aP=aP+1|0;}while((aP|0)<(aB|0))}aG=aG+1|0;}while((aG|0)<(au|0))}gGz(aC|0,0,49152);if((c[3542200]|0)==0){az=1;i=e;return az|0}au=M+108|0;c[au>>2]=0;aG=M+100|0;c[aG>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](M,16)|0;do{if((c[au>>2]|0)!=0){aB=c[aG>>2]|0;c[N>>2]=9534384;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aA&16383](N,16,0)|0;if((aB|0)<1){az=1;i=e;return az|0}if((gzL(aC,0,16)|0)==0){break}else{az=1}i=e;return az|0}}while(0);aC=(c[3529012]|0)+8192|0;if((c[3542200]|0)==0){az=1;i=e;return az|0}aG=K+108|0;c[aG>>2]=0;au=K+100|0;c[au>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](K,17)|0;do{if((c[aG>>2]|0)!=0){aB=c[au>>2]|0;c[L>>2]=9534384;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aA&16383](L,17,0)|0;if((aB|0)<1){az=1;i=e;return az|0}if((gzL(aC,0,17)|0)==0){break}else{az=1}i=e;return az|0}}while(0);aC=(c[3529012]|0)+16384|0;if((c[3542200]|0)==0){az=1;i=e;return az|0}au=I+108|0;c[au>>2]=0;aG=I+100|0;c[aG>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](I,18)|0;do{if((c[au>>2]|0)!=0){aB=c[aG>>2]|0;c[J>>2]=9534384;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aA&16383](J,18,0)|0;if((aB|0)<1){az=1;i=e;return az|0}if((gzL(aC,0,18)|0)==0){break}else{az=1}i=e;return az|0}}while(0);aC=(c[3529012]|0)+24576|0;if((c[3542200]|0)==0){az=1;i=e;return az|0}aG=G+108|0;c[aG>>2]=0;au=G+100|0;c[au>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](G,19)|0;do{if((c[aG>>2]|0)!=0){aB=c[au>>2]|0;c[H>>2]=9534384;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aA&16383](H,19,0)|0;if((aB|0)<1){az=1;i=e;return az|0}if((gzL(aC,0,19)|0)==0){break}else{az=1}i=e;return az|0}}while(0);aC=(c[3529012]|0)+32768|0;if((c[3542200]|0)==0){az=1;i=e;return az|0}au=E+108|0;c[au>>2]=0;aG=E+100|0;c[aG>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](E,20)|0;do{if((c[au>>2]|0)!=0){aB=c[aG>>2]|0;c[F>>2]=9534384;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aA&16383](F,20,0)|0;if((aB|0)<1){az=1;i=e;return az|0}if((gzL(aC,0,20)|0)==0){break}else{az=1}i=e;return az|0}}while(0);aC=(c[3529012]|0)+40960|0;if((c[3542200]|0)==0){az=1;i=e;return az|0}aG=C+108|0;c[aG>>2]=0;au=C+100|0;c[au>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](C,21)|0;do{if((c[aG>>2]|0)!=0){aB=c[au>>2]|0;c[D>>2]=9534384;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aA&16383](D,21,0)|0;if((aB|0)<1){az=1;i=e;return az|0}if((gzL(aC,0,21)|0)==0){break}else{az=1}i=e;return az|0}}while(0);aC=c[2439452]|0;au=c[3529012]|0;aG=c[3529014]|0;if((aC|0)>0){aB=0;do{aA=aB<<8;gGz(aG+aA|0,0,256);aD=aA+262144|0;aF=0;do{aE=aD+(c[609008+(aF<<2)>>2]|0)|0;aH=(aF<<4)+aA|0;aI=0;do{aL=aE+(c[597864+(aI<<2)>>2]|0)|0;if(((d[au+((aL|0)/8|0)|0]|0)&128>>>((aL&7)>>>0)|0)!=0){aL=aG+(aH+aI)|0;a[aL]=a[aL]|4}aI=aI+1|0;}while((aI|0)<16);aF=aF+1|0;}while((aF|0)<16);aF=aA+131072|0;aD=0;while(1){aI=aF+(c[609008+(aD<<2)>>2]|0)|0;aH=(aD<<4)+aA|0;aE=0;do{aL=aI+(c[597864+(aE<<2)>>2]|0)|0;if(((d[au+((aL|0)/8|0)|0]|0)&128>>>((aL&7)>>>0)|0)!=0){aL=aG+(aH+aE)|0;a[aL]=a[aL]|2}aE=aE+1|0;}while((aE|0)<16);aE=aD+1|0;if((aE|0)<16){aD=aE}else{aQ=0;break}}do{aD=aA+(c[609008+(aQ<<2)>>2]|0)|0;aF=(aQ<<4)+aA|0;aE=0;do{aH=aD+(c[597864+(aE<<2)>>2]|0)|0;if(((d[au+((aH|0)/8|0)|0]|0)&128>>>((aH&7)>>>0)|0)!=0){aH=aG+(aF+aE)|0;a[aH]=a[aH]|1}aE=aE+1|0;}while((aE|0)<16);aQ=aQ+1|0;}while((aQ|0)<16);aB=aB+1|0;}while((aB|0)<(aC|0))}gGz(au|0,0,49152);if((c[3542200]|0)==0){az=1;i=e;return az|0}aC=A+108|0;c[aC>>2]=0;aB=A+100|0;c[aB>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](A,22)|0;do{if((c[aC>>2]|0)!=0){aG=c[aB>>2]|0;c[B>>2]=9534384;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aA&16383](B,22,0)|0;if((aG|0)<1){az=1;i=e;return az|0}if((gzL(au,0,22)|0)==0){break}else{az=1}i=e;return az|0}}while(0);au=(c[3529012]|0)+8192|0;if((c[3542200]|0)==0){az=1;i=e;return az|0}aB=y+108|0;c[aB>>2]=0;aC=y+100|0;c[aC>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](y,23)|0;do{if((c[aB>>2]|0)!=0){aG=c[aC>>2]|0;c[z>>2]=9534384;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aA&16383](z,23,0)|0;if((aG|0)<1){az=1;i=e;return az|0}if((gzL(au,0,23)|0)==0){break}else{az=1}i=e;return az|0}}while(0);au=c[3527096]|0;aC=c[2437648]|0;aB=c[2437646]|0;aG=c[3529012]|0;aA=c[2405778]|0;if((au|0)>0){aE=ag(aB,aC)|0;aF=(aB|0)<1|(aC|0)<1;aD=0;do{aH=ag(aD,aE)|0;gGz(aA+aH|0,0,aE|0);aI=aD<<6;if(!aF){aL=0;do{aK=aI+(c[1238464+(aL<<2)>>2]|0)|0;aJ=(ag(aL,aC)|0)+aH|0;aM=0;do{aN=aK+(c[614800+(aM<<2)>>2]|0)|0;if(((d[aG+((aN|0)/8|0)|0]|0)&128>>>((aN&7)>>>0)|0)!=0){aN=aA+(aJ+aM)|0;a[aN]=a[aN]|2}aM=aM+1|0;}while((aM|0)<(aC|0));aL=aL+1|0;}while((aL|0)<(aB|0));aL=aI+65536|0;aM=0;do{aJ=aL+(c[1238464+(aM<<2)>>2]|0)|0;aK=(ag(aM,aC)|0)+aH|0;aN=0;do{aO=aJ+(c[614800+(aN<<2)>>2]|0)|0;if(((d[aG+((aO|0)/8|0)|0]|0)&128>>>((aO&7)>>>0)|0)!=0){aO=aA+(aK+aN)|0;a[aO]=a[aO]|1}aN=aN+1|0;}while((aN|0)<(aC|0));aM=aM+1|0;}while((aM|0)<(aB|0))}aD=aD+1|0;}while((aD|0)<(au|0))}au=c[3527092]|0;if((c[3542200]|0)==0){az=1;i=e;return az|0}aD=w+108|0;c[aD>>2]=0;aB=w+100|0;c[aB>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](w,24)|0;do{if((c[aD>>2]|0)!=0){aC=c[aB>>2]|0;c[x>>2]=9534384;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aA&16383](x,24,0)|0;if((aC|0)<1){az=1;i=e;return az|0}if((gzL(au,0,24)|0)==0){break}else{az=1}i=e;return az|0}}while(0);au=(c[3527092]|0)+256|0;if((c[3542200]|0)==0){az=1;i=e;return az|0}aB=u+108|0;c[aB>>2]=0;aD=u+100|0;c[aD>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](u,25)|0;do{if((c[aB>>2]|0)!=0){aC=c[aD>>2]|0;c[v>>2]=9534384;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aA&16383](v,25,0)|0;if((aC|0)<1){az=1;i=e;return az|0}if((gzL(au,0,25)|0)==0){break}else{az=1}i=e;return az|0}}while(0);au=(c[3527092]|0)+512|0;if((c[3542200]|0)==0){az=1;i=e;return az|0}aD=s+108|0;c[aD>>2]=0;aB=s+100|0;c[aB>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](s,26)|0;do{if((c[aD>>2]|0)!=0){aC=c[aB>>2]|0;c[t>>2]=9534384;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aA&16383](t,26,0)|0;if((aC|0)<1){az=1;i=e;return az|0}if((gzL(au,0,26)|0)==0){break}else{az=1}i=e;return az|0}}while(0);au=(c[3527092]|0)+768|0;if((c[3542200]|0)==0){az=1;i=e;return az|0}aB=q+108|0;c[aB>>2]=0;aD=q+100|0;c[aD>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](q,27)|0;do{if((c[aB>>2]|0)!=0){aC=c[aD>>2]|0;c[r>>2]=9534384;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aA&16383](r,27,0)|0;if((aC|0)<1){az=1;i=e;return az|0}if((gzL(au,0,27)|0)==0){break}else{az=1}i=e;return az|0}}while(0);au=(c[3527092]|0)+1024|0;if((c[3542200]|0)==0){az=1;i=e;return az|0}aD=o+108|0;c[aD>>2]=0;aB=o+100|0;c[aB>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](o,28)|0;do{if((c[aD>>2]|0)!=0){aC=c[aB>>2]|0;c[p>>2]=9534384;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aA&16383](p,28,0)|0;if((aC|0)<1){az=1;i=e;return az|0}if((gzL(au,0,28)|0)==0){break}else{az=1}i=e;return az|0}}while(0);au=(c[3527092]|0)+1280|0;if((c[3542200]|0)==0){az=1;i=e;return az|0}aB=m+108|0;c[aB>>2]=0;aD=m+100|0;c[aD>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,29)|0;do{if((c[aB>>2]|0)!=0){aC=c[aD>>2]|0;c[n>>2]=9534384;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aA&16383](n,29,0)|0;if((aC|0)<1){az=1;i=e;return az|0}if((gzL(au,0,29)|0)==0){break}else{az=1}i=e;return az|0}}while(0);au=(c[3527092]|0)+1536|0;if((c[3542200]|0)==0){az=1;i=e;return az|0}aD=k+108|0;c[aD>>2]=0;aB=k+100|0;c[aB>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,30)|0;do{if((c[aD>>2]|0)!=0){aC=c[aB>>2]|0;c[l>>2]=9534384;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aA&16383](l,30,0)|0;if((aC|0)<1){az=1;i=e;return az|0}if((gzL(au,0,30)|0)==0){break}else{az=1}i=e;return az|0}}while(0);au=(c[3527092]|0)+1568|0;if((c[3542200]|0)==0){az=1;i=e;return az|0}aB=h+108|0;c[aB>>2]=0;aD=h+100|0;c[aD>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](h,31)|0;do{if((c[aB>>2]|0)!=0){aC=c[aD>>2]|0;c[j>>2]=9534384;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aA&16383](j,31,0)|0;if((aC|0)<1){az=1;i=e;return az|0}if((gzL(au,0,31)|0)==0){break}else{az=1}i=e;return az|0}}while(0);au=(c[3527092]|0)+1824|0;if((c[3542200]|0)==0){az=1;i=e;return az|0}aD=f+108|0;c[aD>>2]=0;aB=f+100|0;c[aB>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,32)|0;do{if((c[aD>>2]|0)!=0){aC=c[aB>>2]|0;c[g>>2]=9534384;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aA&16383](g,32,0)|0;if((aC|0)<1){az=1;i=e;return az|0}if((gzL(au,0,32)|0)==0){break}else{az=1}i=e;return az|0}}while(0);au=c[3529012]|0;aB=0;while(1){if((aB|0)>=1024){break}aR=9638528+(aB<<2)|0;if((c[aR>>2]|0)==(au|0)){aw=53488;break}else{aB=aB+1|0}}if((aw|0)==53488){gGr(au);c[aR>>2]=0}c[3529012]=0;a9H();aB=c[2439330]|0;aD=(aB|0)==0;if(!aD){aC=aB;gGC(9706056,aC|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];aC=c[3528484]|0;c[2076596]=aC;aA=c[2417276]|0;c[3541536]=aA;c[1836236]=0;c[aB+4176>>2]=192;aG=c[2385798]|0;aF=160;aE=160;while(1){c[aB+76+(aE<<2)>>2]=aG+((aE<<8)-8192);aM=aF+1&65535;if((aM&65535)>191){aS=160;aT=160;break}else{aF=aM;aE=aM&65535}}while(1){aE=aG+((aT<<8)-8192)|0;c[aB+76+(aT+512<<2)>>2]=aE;c[aB+76+(aT+768<<2)>>2]=aE;aE=aS+1&65535;if((aE&65535)>191){break}else{aS=aE;aT=aE&65535}}aG=c[3529018]|0;c[aB+876>>2]=aG;aE=aG+256|0;c[aB+880>>2]=aE;aF=aG+512|0;c[aB+884>>2]=aF;au=aG+768|0;c[aB+888>>2]=au;aM=aG+1024|0;c[aB+892>>2]=aM;aH=aG+1280|0;c[aB+896>>2]=aH;aL=aG+1536|0;c[aB+900>>2]=aL;aI=aG+1792|0;c[aB+904>>2]=aI;c[aB+1900>>2]=aG;c[aB+1904>>2]=aE;c[aB+1908>>2]=aF;c[aB+1912>>2]=au;c[aB+1916>>2]=aM;c[aB+1920>>2]=aH;c[aB+1924>>2]=aL;c[aB+1928>>2]=aI;c[aB+2924>>2]=aG;c[aB+3948>>2]=aG;c[aB+2928>>2]=aE;c[aB+3952>>2]=aE;c[aB+2932>>2]=aF;c[aB+3956>>2]=aF;c[aB+2936>>2]=au;c[aB+3960>>2]=au;c[aB+2940>>2]=aM;c[aB+3964>>2]=aM;c[aB+2944>>2]=aH;c[aB+3968>>2]=aH;c[aB+2948>>2]=aL;c[aB+3972>>2]=aL;c[aB+2952>>2]=aI;c[aB+3976>>2]=aI;if(!aD){aI=aB;gGC(aI|0,9706056,76)|0}aI=c[2433530]|0;c[2438118]=aI;c[3528484]=aC;c[2417276]=aA;c[1836236]=-1;c[3527088]=3072e3;c[2431670]=468;c[2426980]=152;c[2426982]=40;if(aD){c[2433530]=aI;c[2076596]=aC;c[3541536]=aA;c[1836236]=0;gGz(9706056,0,76)}else{aL=aB;gGC(9706056,aL|0,76)|0;c[2433530]=aI;c[2076596]=aC;c[3541536]=aA;c[1836236]=0;gGz(9706056,0,76);aL=aB;gGC(aL|0,9706056,76)|0}c[2438118]=aI;c[3528484]=aC;c[2417276]=aA;c[1836236]=-1;a[9660900]=a[9660900]|16;aI=c[2437644]|0;aL=c[aI+1092>>2]|0;do{if((aL|0)==0){aH=c[aI+3144>>2]|0;if((aH|0)==0){aU=0;aV=0;break}aM=gj[aH&4095](-2)|0;aH=c[2437644]|0;au=c[aH+1092>>2]|0;aF=(aM&255)<<8;if((au|0)!=0){aW=au;aX=aF;aw=53503;break}au=c[aH+3144>>2]|0;if((au|0)==0){aU=0;aV=aF;break}aU=gj[au&4095](-1)|0;aV=aF}else{aW=aL;aX=(d[aL+254|0]|0)<<8;aw=53503}}while(0);if((aw|0)==53503){aU=a[aW+255|0]|0;aV=aX}aL=aU&255|aV;c[2415221]=aL;b[4830442]=aL&65535;a[9660920]=0;a[9660921]=0;a[9660928]=0;a[9660930]=0;a[9660931]=0;c[2415234]=0;gGz(9660901,0,5);c[2415235]=65535;c[2415237]=65535;a[9660932]=a[9660932]|64;mB(0);mB(1);UA();c[2429502]=0;c[2429500]=0;c[2438664]=0;c[2439460]=0;a[9757800]=0;a[9623080]=0;a[9623072]=0;a[683232]=0;a[9754673]=0;a[9754672]=0;a[9754680]=0;a[9718896]=0;a[9717272]=0;a[9718824]=0;az=0;i=e;return az|0}}while(0);c[2426820]=0;az=1;i=e;return az|0}function a8S(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6857676+(b*112|0)>>2];c[a+104>>2]=c[6857680+(b*112|0)>>2];c[a+108>>2]=c[6857684+(b*112|0)>>2];d=0;return d|0}function a8T(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=6857576+(b*112|0);e=0;return e|0}function a8U(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>81){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6859816+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function a8V(){var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0;e=i;i=i+2400|0;f=e|0;g=e+112|0;h=e+120|0;j=e+232|0;k=e+240|0;l=e+352|0;m=e+360|0;n=e+472|0;o=e+480|0;p=e+592|0;q=e+600|0;r=e+712|0;s=e+720|0;t=e+832|0;u=e+840|0;v=e+952|0;w=e+960|0;x=e+1072|0;y=e+1080|0;z=e+1192|0;A=e+1200|0;B=e+1312|0;C=e+1320|0;D=e+1432|0;E=e+1440|0;F=e+1552|0;G=e+1560|0;H=e+1672|0;I=e+1680|0;J=e+1792|0;K=e+1800|0;L=e+1912|0;M=e+1920|0;N=e+2032|0;O=e+2040|0;P=e+2152|0;Q=e+2160|0;R=e+2272|0;S=e+2280|0;T=e+2392|0;c[2439448]=32768;c[3527090]=1824;c[3527094]=1024;c[2439452]=256;c[2431672]=c[(c[642608+(c[2436]<<2)>>2]|0)+124>>2];c[2426820]=0;a9Q();U=c[2414438]|0;V=0;while(1){if((V|0)>=1024){break}W=9638528+(V<<2)|0;if((c[W>>2]|0)==0){X=53659;break}else{V=V+1|0}}do{if((X|0)==53659){V=gGq(U)|0;c[W>>2]=V;if((V|0)==0){break}gGz(V|0,0,U|0);c[2426820]=V;gGz(V|0,0,U|0);a9Q();V=0;while(1){if((V|0)>=1024){Y=0;break}Z=9638528+(V<<2)|0;if((c[Z>>2]|0)==0){X=53664;break}else{V=V+1|0}}do{if((X|0)==53664){V=gGq(24576)|0;c[Z>>2]=V;if((V|0)==0){Y=0;break}gGz(V|0,0,24576);Y=V}}while(0);c[3529012]=Y;V=c[2385798]|0;if((c[3542200]|0)==0){_=1;i=e;return _|0}$=S+108|0;c[$>>2]=0;aa=S+100|0;c[aa>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](S,0)|0;do{if((c[$>>2]|0)!=0){ab=c[aa>>2]|0;c[T>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](T,0,0)|0;if((ab|0)<1){_=1;i=e;return _|0}if((gzL(V,0,0)|0)==0){break}else{_=1}i=e;return _|0}}while(0);V=(c[2385798]|0)+8192|0;if((c[3542200]|0)==0){_=1;i=e;return _|0}aa=Q+108|0;c[aa>>2]=0;$=Q+100|0;c[$>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](Q,1)|0;do{if((c[aa>>2]|0)!=0){ab=c[$>>2]|0;c[R>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](R,1,0)|0;if((ab|0)<1){_=1;i=e;return _|0}if((gzL(V,0,1)|0)==0){break}else{_=1}i=e;return _|0}}while(0);V=(c[2385798]|0)+16384|0;if((c[3542200]|0)==0){_=1;i=e;return _|0}$=O+108|0;c[$>>2]=0;aa=O+100|0;c[aa>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](O,2)|0;do{if((c[$>>2]|0)!=0){ab=c[aa>>2]|0;c[P>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](P,2,0)|0;if((ab|0)<1){_=1;i=e;return _|0}if((gzL(V,0,2)|0)==0){break}else{_=1}i=e;return _|0}}while(0);V=(c[2385798]|0)+24576|0;if((c[3542200]|0)==0){_=1;i=e;return _|0}aa=M+108|0;c[aa>>2]=0;$=M+100|0;c[$>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](M,3)|0;do{if((c[aa>>2]|0)!=0){ab=c[$>>2]|0;c[N>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](N,3,0)|0;if((ab|0)<1){_=1;i=e;return _|0}if((gzL(V,0,3)|0)==0){break}else{_=1}i=e;return _|0}}while(0);V=(c[3527098]|0)+32768|0;if((c[3542200]|0)==0){_=1;i=e;return _|0}$=K+108|0;c[$>>2]=0;aa=K+100|0;c[aa>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](K,4)|0;do{if((c[$>>2]|0)!=0){ab=c[aa>>2]|0;c[L>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](L,4,0)|0;if((ab|0)<1){_=1;i=e;return _|0}if((gzL(V,0,4)|0)==0){break}else{_=1}i=e;return _|0}}while(0);V=(c[3527098]|0)+40960|0;if((c[3542200]|0)==0){_=1;i=e;return _|0}aa=I+108|0;c[aa>>2]=0;$=I+100|0;c[$>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](I,5)|0;do{if((c[aa>>2]|0)!=0){ab=c[$>>2]|0;c[J>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](J,5,0)|0;if((ab|0)<1){_=1;i=e;return _|0}if((gzL(V,0,5)|0)==0){break}else{_=1}i=e;return _|0}}while(0);V=c[3529012]|0;gGz(V|0,0,24576);if((c[3542200]|0)==0){_=1;i=e;return _|0}$=G+108|0;c[$>>2]=0;aa=G+100|0;c[aa>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](G,6)|0;do{if((c[$>>2]|0)!=0){ab=c[aa>>2]|0;c[H>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](H,6,0)|0;if((ab|0)<1){_=1;i=e;return _|0}if((gzL(V,0,6)|0)==0){break}else{_=1}i=e;return _|0}}while(0);V=(c[3529012]|0)+8192|0;if((c[3542200]|0)==0){_=1;i=e;return _|0}aa=E+108|0;c[aa>>2]=0;$=E+100|0;c[$>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](E,7)|0;do{if((c[aa>>2]|0)!=0){ab=c[$>>2]|0;c[F>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](F,7,0)|0;if((ab|0)<1){_=1;i=e;return _|0}if((gzL(V,0,7)|0)==0){break}else{_=1}i=e;return _|0}}while(0);V=(c[3529012]|0)+16384|0;if((c[3542200]|0)==0){_=1;i=e;return _|0}$=C+108|0;c[$>>2]=0;aa=C+100|0;c[aa>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](C,8)|0;do{if((c[$>>2]|0)!=0){ab=c[aa>>2]|0;c[D>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](D,8,0)|0;if((ab|0)<1){_=1;i=e;return _|0}if((gzL(V,0,8)|0)==0){break}else{_=1}i=e;return _|0}}while(0);V=c[3527094]|0;aa=c[2439464]|0;$=c[2439462]|0;ab=c[3529012]|0;ac=c[2405764]|0;if((V|0)>0){ad=ag($,aa)|0;ae=($|0)<1|(aa|0)<1;af=0;do{ah=ag(af,ad)|0;gGz(ac+ah|0,0,ad|0);ai=af<<6;aj=ai+131072|0;if(!ae){ak=0;do{al=aj+(c[1238464+(ak<<2)>>2]|0)|0;am=(ag(ak,aa)|0)+ah|0;an=0;do{ao=al+(c[614800+(an<<2)>>2]|0)|0;if(((d[ab+((ao|0)/8|0)|0]|0)&128>>>((ao&7)>>>0)|0)!=0){ao=ac+(am+an)|0;a[ao]=a[ao]|4}an=an+1|0;}while((an|0)<(aa|0));ak=ak+1|0;}while((ak|0)<($|0));ak=ai+65536|0;aj=0;while(1){an=ak+(c[1238464+(aj<<2)>>2]|0)|0;am=(ag(aj,aa)|0)+ah|0;al=0;do{ao=an+(c[614800+(al<<2)>>2]|0)|0;if(((d[ab+((ao|0)/8|0)|0]|0)&128>>>((ao&7)>>>0)|0)!=0){ao=ac+(am+al)|0;a[ao]=a[ao]|2}al=al+1|0;}while((al|0)<(aa|0));al=aj+1|0;if((al|0)<($|0)){aj=al}else{ap=0;break}}do{aj=ai+(c[1238464+(ap<<2)>>2]|0)|0;ak=(ag(ap,aa)|0)+ah|0;al=0;do{am=aj+(c[614800+(al<<2)>>2]|0)|0;if(((d[ab+((am|0)/8|0)|0]|0)&128>>>((am&7)>>>0)|0)!=0){am=ac+(ak+al)|0;a[am]=a[am]|1}al=al+1|0;}while((al|0)<(aa|0));ap=ap+1|0;}while((ap|0)<($|0))}af=af+1|0;}while((af|0)<(V|0))}gGz(ab|0,0,24576);if((c[3542200]|0)==0){_=1;i=e;return _|0}V=A+108|0;c[V>>2]=0;af=A+100|0;c[af>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](A,9)|0;do{if((c[V>>2]|0)!=0){$=c[af>>2]|0;c[B>>2]=9534384;aa=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aa&16383](B,9,0)|0;if(($|0)<1){_=1;i=e;return _|0}if((gzL(ab,0,9)|0)==0){break}else{_=1}i=e;return _|0}}while(0);ab=(c[3529012]|0)+8192|0;if((c[3542200]|0)==0){_=1;i=e;return _|0}af=y+108|0;c[af>>2]=0;V=y+100|0;c[V>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](y,10)|0;do{if((c[af>>2]|0)!=0){$=c[V>>2]|0;c[z>>2]=9534384;aa=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aa&16383](z,10,0)|0;if(($|0)<1){_=1;i=e;return _|0}if((gzL(ab,0,10)|0)==0){break}else{_=1}i=e;return _|0}}while(0);ab=(c[3529012]|0)+16384|0;if((c[3542200]|0)==0){_=1;i=e;return _|0}V=w+108|0;c[V>>2]=0;af=w+100|0;c[af>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](w,11)|0;do{if((c[V>>2]|0)!=0){$=c[af>>2]|0;c[x>>2]=9534384;aa=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aa&16383](x,11,0)|0;if(($|0)<1){_=1;i=e;return _|0}if((gzL(ab,0,11)|0)==0){break}else{_=1}i=e;return _|0}}while(0);ab=c[2439452]|0;af=c[3529012]|0;V=c[3529014]|0;if((ab|0)>0){$=0;do{aa=$<<8;gGz(V+aa|0,0,256);ac=aa+131072|0;ae=0;do{ad=ac+(c[609008+(ae<<2)>>2]|0)|0;ah=(ae<<4)+aa|0;ai=0;do{al=ad+(c[597864+(ai<<2)>>2]|0)|0;if(((d[af+((al|0)/8|0)|0]|0)&128>>>((al&7)>>>0)|0)!=0){al=V+(ah+ai)|0;a[al]=a[al]|4}ai=ai+1|0;}while((ai|0)<16);ae=ae+1|0;}while((ae|0)<16);ae=aa+65536|0;ac=0;while(1){ai=ae+(c[609008+(ac<<2)>>2]|0)|0;ah=(ac<<4)+aa|0;ad=0;do{al=ai+(c[597864+(ad<<2)>>2]|0)|0;if(((d[af+((al|0)/8|0)|0]|0)&128>>>((al&7)>>>0)|0)!=0){al=V+(ah+ad)|0;a[al]=a[al]|2}ad=ad+1|0;}while((ad|0)<16);ad=ac+1|0;if((ad|0)<16){ac=ad}else{aq=0;break}}do{ac=aa+(c[609008+(aq<<2)>>2]|0)|0;ae=(aq<<4)+aa|0;ad=0;do{ah=ac+(c[597864+(ad<<2)>>2]|0)|0;if(((d[af+((ah|0)/8|0)|0]|0)&128>>>((ah&7)>>>0)|0)!=0){ah=V+(ae+ad)|0;a[ah]=a[ah]|1}ad=ad+1|0;}while((ad|0)<16);aq=aq+1|0;}while((aq|0)<16);$=$+1|0;}while(($|0)<(ab|0))}ab=c[3527092]|0;if((c[3542200]|0)==0){_=1;i=e;return _|0}$=u+108|0;c[$>>2]=0;V=u+100|0;c[V>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](u,12)|0;do{if((c[$>>2]|0)!=0){af=c[V>>2]|0;c[v>>2]=9534384;aa=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aa&16383](v,12,0)|0;if((af|0)<1){_=1;i=e;return _|0}if((gzL(ab,0,12)|0)==0){break}else{_=1}i=e;return _|0}}while(0);ab=(c[3527092]|0)+256|0;if((c[3542200]|0)==0){_=1;i=e;return _|0}V=s+108|0;c[V>>2]=0;$=s+100|0;c[$>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](s,13)|0;do{if((c[V>>2]|0)!=0){af=c[$>>2]|0;c[t>>2]=9534384;aa=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aa&16383](t,13,0)|0;if((af|0)<1){_=1;i=e;return _|0}if((gzL(ab,0,13)|0)==0){break}else{_=1}i=e;return _|0}}while(0);ab=(c[3527092]|0)+512|0;if((c[3542200]|0)==0){_=1;i=e;return _|0}$=q+108|0;c[$>>2]=0;V=q+100|0;c[V>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](q,14)|0;do{if((c[$>>2]|0)!=0){af=c[V>>2]|0;c[r>>2]=9534384;aa=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aa&16383](r,14,0)|0;if((af|0)<1){_=1;i=e;return _|0}if((gzL(ab,0,14)|0)==0){break}else{_=1}i=e;return _|0}}while(0);ab=(c[3527092]|0)+768|0;if((c[3542200]|0)==0){_=1;i=e;return _|0}V=o+108|0;c[V>>2]=0;$=o+100|0;c[$>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](o,15)|0;do{if((c[V>>2]|0)!=0){af=c[$>>2]|0;c[p>>2]=9534384;aa=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aa&16383](p,15,0)|0;if((af|0)<1){_=1;i=e;return _|0}if((gzL(ab,0,15)|0)==0){break}else{_=1}i=e;return _|0}}while(0);ab=(c[3527092]|0)+1024|0;if((c[3542200]|0)==0){_=1;i=e;return _|0}$=m+108|0;c[$>>2]=0;V=m+100|0;c[V>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,16)|0;do{if((c[$>>2]|0)!=0){af=c[V>>2]|0;c[n>>2]=9534384;aa=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aa&16383](n,16,0)|0;if((af|0)<1){_=1;i=e;return _|0}if((gzL(ab,0,16)|0)==0){break}else{_=1}i=e;return _|0}}while(0);ab=(c[3527092]|0)+1280|0;if((c[3542200]|0)==0){_=1;i=e;return _|0}V=k+108|0;c[V>>2]=0;$=k+100|0;c[$>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,17)|0;do{if((c[V>>2]|0)!=0){af=c[$>>2]|0;c[l>>2]=9534384;aa=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aa&16383](l,17,0)|0;if((af|0)<1){_=1;i=e;return _|0}if((gzL(ab,0,17)|0)==0){break}else{_=1}i=e;return _|0}}while(0);ab=(c[3527092]|0)+1536|0;if((c[3542200]|0)==0){_=1;i=e;return _|0}$=h+108|0;c[$>>2]=0;V=h+100|0;c[V>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](h,18)|0;do{if((c[$>>2]|0)!=0){af=c[V>>2]|0;c[j>>2]=9534384;aa=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aa&16383](j,18,0)|0;if((af|0)<1){_=1;i=e;return _|0}if((gzL(ab,0,18)|0)==0){break}else{_=1}i=e;return _|0}}while(0);ab=(c[3527092]|0)+1568|0;if((c[3542200]|0)==0){_=1;i=e;return _|0}V=f+108|0;c[V>>2]=0;$=f+100|0;c[$>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,19)|0;do{if((c[V>>2]|0)!=0){af=c[$>>2]|0;c[g>>2]=9534384;aa=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aa&16383](g,19,0)|0;if((af|0)<1){_=1;i=e;return _|0}if((gzL(ab,0,19)|0)==0){break}else{_=1}i=e;return _|0}}while(0);ab=c[3529012]|0;$=0;while(1){if(($|0)>=1024){break}ar=9638528+($<<2)|0;if((c[ar>>2]|0)==(ab|0)){X=53766;break}else{$=$+1|0}}if((X|0)==53766){gGr(ab);c[ar>>2]=0}c[3529012]=0;a9H();c[2431670]=5494;c[2426980]=54;$=c[2439330]|0;V=($|0)==0;if(!V){af=$;gGC(9706056,af|0,76)|0}af=c[2438118]|0;c[2433530]=af;aa=c[3528484]|0;c[2076596]=aa;ad=c[2417276]|0;c[3541536]=ad;c[1836236]=0;gGz(9706056,0,76);if(!V){V=$;gGC(V|0,9706056,76)|0}c[2438118]=af;c[3528484]=aa;c[2417276]=ad;c[1836236]=-1;a[9660900]=a[9660900]|16;ad=c[2437644]|0;aa=c[ad+1092>>2]|0;do{if((aa|0)==0){af=c[ad+3144>>2]|0;if((af|0)==0){as=0;at=0;break}V=gj[af&4095](-2)|0;af=c[2437644]|0;$=c[af+1092>>2]|0;ae=(V&255)<<8;if(($|0)!=0){au=$;av=ae;X=53775;break}$=c[af+3144>>2]|0;if(($|0)==0){as=0;at=ae;break}as=gj[$&4095](-1)|0;at=ae}else{au=aa;av=(d[aa+254|0]|0)<<8;X=53775}}while(0);if((X|0)==53775){as=a[au+255|0]|0;at=av}aa=as&255|at;c[2415221]=aa;b[4830442]=aa&65535;a[9660920]=0;a[9660921]=0;a[9660928]=0;a[9660930]=0;a[9660931]=0;c[2415234]=0;gGz(9660901,0,5);c[2415235]=65535;c[2415237]=65535;a[9660932]=a[9660932]|64;mB(0);mB(1);UA();c[2429502]=0;c[2429500]=0;c[2438664]=0;c[2439460]=0;a[9757800]=0;a[9623080]=0;a[9623072]=0;a[683232]=0;a[9754673]=0;a[9754672]=0;a[9754680]=0;a[9718896]=0;a[9717272]=0;a[9718824]=0;_=0;i=e;return _|0}}while(0);c[2426820]=0;_=1;i=e;return _|0}function a8W(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6255604+(b*112|0)>>2];c[a+104>>2]=c[6255608+(b*112|0)>>2];c[a+108>>2]=c[6255612+(b*112|0)>>2];d=0;return d|0}function a8X(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=6255504+(b*112|0);e=0;return e|0}function a8Y(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>25){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6263996+(b*112|0)>>2];c[a+104>>2]=c[6264e3+(b*112|0)>>2];c[a+108>>2]=c[6264004+(b*112|0)>>2];d=0;return d|0}function a8Z(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<26&(d|0)==0)){e=1;return e|0}c[a>>2]=6263896+(b*112|0);e=0;return e|0}function a8_(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>82){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6266808+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function a8$(){var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0;e=i;i=i+3120|0;f=e|0;g=e+112|0;h=e+120|0;j=e+232|0;k=e+240|0;l=e+352|0;m=e+360|0;n=e+472|0;o=e+480|0;p=e+592|0;q=e+600|0;r=e+712|0;s=e+720|0;t=e+832|0;u=e+840|0;v=e+952|0;w=e+960|0;x=e+1072|0;y=e+1080|0;z=e+1192|0;A=e+1200|0;B=e+1312|0;C=e+1320|0;D=e+1432|0;E=e+1440|0;F=e+1552|0;G=e+1560|0;H=e+1672|0;I=e+1680|0;J=e+1792|0;K=e+1800|0;L=e+1912|0;M=e+1920|0;N=e+2032|0;O=e+2040|0;P=e+2152|0;Q=e+2160|0;R=e+2272|0;S=e+2280|0;T=e+2392|0;U=e+2400|0;V=e+2512|0;W=e+2520|0;X=e+2632|0;Y=e+2640|0;Z=e+2752|0;_=e+2760|0;$=e+2872|0;aa=e+2880|0;ab=e+2992|0;ac=e+3e3|0;ad=e+3112|0;c[2439448]=49152;c[3527090]=1824;c[3527094]=1024;c[2439452]=512;c[2431672]=c[(c[642608+(c[2436]<<2)>>2]|0)+124>>2];c[2426820]=0;a9Q();ae=c[2414438]|0;af=0;while(1){if((af|0)>=1024){break}ah=9638528+(af<<2)|0;if((c[ah>>2]|0)==0){ai=53898;break}else{af=af+1|0}}do{if((ai|0)==53898){af=gGq(ae)|0;c[ah>>2]=af;if((af|0)==0){break}gGz(af|0,0,ae|0);c[2426820]=af;gGz(af|0,0,ae|0);a9Q();af=0;while(1){if((af|0)>=1024){aj=0;break}ak=9638528+(af<<2)|0;if((c[ak>>2]|0)==0){ai=53903;break}else{af=af+1|0}}do{if((ai|0)==53903){af=gGq(49152)|0;c[ak>>2]=af;if((af|0)==0){aj=0;break}gGz(af|0,0,49152);aj=af}}while(0);c[3529012]=aj;af=c[2385798]|0;if((c[3542200]|0)==0){al=1;i=e;return al|0}am=ac+108|0;c[am>>2]=0;an=ac+100|0;c[an>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](ac,0)|0;do{if((c[am>>2]|0)!=0){ao=c[an>>2]|0;c[ad>>2]=9534384;ap=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ap&16383](ad,0,0)|0;if((ao|0)<1){al=1;i=e;return al|0}if((gzL(af,0,0)|0)==0){break}else{al=1}i=e;return al|0}}while(0);af=(c[2385798]|0)+8192|0;if((c[3542200]|0)==0){al=1;i=e;return al|0}an=aa+108|0;c[an>>2]=0;am=aa+100|0;c[am>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](aa,1)|0;do{if((c[an>>2]|0)!=0){ao=c[am>>2]|0;c[ab>>2]=9534384;ap=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ap&16383](ab,1,0)|0;if((ao|0)<1){al=1;i=e;return al|0}if((gzL(af,0,1)|0)==0){break}else{al=1}i=e;return al|0}}while(0);af=(c[2385798]|0)+16384|0;if((c[3542200]|0)==0){al=1;i=e;return al|0}am=_+108|0;c[am>>2]=0;an=_+100|0;c[an>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](_,2)|0;do{if((c[am>>2]|0)!=0){ao=c[an>>2]|0;c[$>>2]=9534384;ap=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ap&16383]($,2,0)|0;if((ao|0)<1){al=1;i=e;return al|0}if((gzL(af,0,2)|0)==0){break}else{al=1}i=e;return al|0}}while(0);af=(c[2385798]|0)+24576|0;if((c[3542200]|0)==0){al=1;i=e;return al|0}an=Y+108|0;c[an>>2]=0;am=Y+100|0;c[am>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](Y,3)|0;do{if((c[an>>2]|0)!=0){ao=c[am>>2]|0;c[Z>>2]=9534384;ap=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ap&16383](Z,3,0)|0;if((ao|0)<1){al=1;i=e;return al|0}if((gzL(af,0,3)|0)==0){break}else{al=1}i=e;return al|0}}while(0);af=(c[2385798]|0)+32768|0;if((c[3542200]|0)==0){al=1;i=e;return al|0}am=W+108|0;c[am>>2]=0;an=W+100|0;c[an>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](W,4)|0;do{if((c[am>>2]|0)!=0){ao=c[an>>2]|0;c[X>>2]=9534384;ap=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ap&16383](X,4,0)|0;if((ao|0)<1){al=1;i=e;return al|0}if((gzL(af,0,4)|0)==0){break}else{al=1}i=e;return al|0}}while(0);af=(c[2385798]|0)+40960|0;if((c[3542200]|0)==0){al=1;i=e;return al|0}an=U+108|0;c[an>>2]=0;am=U+100|0;c[am>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](U,5)|0;do{if((c[an>>2]|0)!=0){ao=c[am>>2]|0;c[V>>2]=9534384;ap=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ap&16383](V,5,0)|0;if((ao|0)<1){al=1;i=e;return al|0}if((gzL(af,0,5)|0)==0){break}else{al=1}i=e;return al|0}}while(0);af=(c[3527098]|0)+24576|0;if((c[3542200]|0)==0){al=1;i=e;return al|0}am=S+108|0;c[am>>2]=0;an=S+100|0;c[an>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](S,6)|0;do{if((c[am>>2]|0)!=0){ao=c[an>>2]|0;c[T>>2]=9534384;ap=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ap&16383](T,6,0)|0;if((ao|0)<1){al=1;i=e;return al|0}if((gzL(af,0,6)|0)==0){break}else{al=1}i=e;return al|0}}while(0);af=(c[3527098]|0)+32768|0;if((c[3542200]|0)==0){al=1;i=e;return al|0}an=Q+108|0;c[an>>2]=0;am=Q+100|0;c[am>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](Q,7)|0;do{if((c[an>>2]|0)!=0){ao=c[am>>2]|0;c[R>>2]=9534384;ap=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ap&16383](R,7,0)|0;if((ao|0)<1){al=1;i=e;return al|0}if((gzL(af,0,7)|0)==0){break}else{al=1}i=e;return al|0}}while(0);af=(c[3527098]|0)+40960|0;if((c[3542200]|0)==0){al=1;i=e;return al|0}am=O+108|0;c[am>>2]=0;an=O+100|0;c[an>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](O,8)|0;do{if((c[am>>2]|0)!=0){ao=c[an>>2]|0;c[P>>2]=9534384;ap=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ap&16383](P,8,0)|0;if((ao|0)<1){al=1;i=e;return al|0}if((gzL(af,0,8)|0)==0){break}else{al=1}i=e;return al|0}}while(0);af=c[3529012]|0;gGz(af|0,0,49152);if((c[3542200]|0)==0){al=1;i=e;return al|0}an=M+108|0;c[an>>2]=0;am=M+100|0;c[am>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](M,9)|0;do{if((c[an>>2]|0)!=0){ao=c[am>>2]|0;c[N>>2]=9534384;ap=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ap&16383](N,9,0)|0;if((ao|0)<1){al=1;i=e;return al|0}if((gzL(af,0,9)|0)==0){break}else{al=1}i=e;return al|0}}while(0);af=(c[3529012]|0)+8192|0;if((c[3542200]|0)==0){al=1;i=e;return al|0}am=K+108|0;c[am>>2]=0;an=K+100|0;c[an>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](K,10)|0;do{if((c[am>>2]|0)!=0){ao=c[an>>2]|0;c[L>>2]=9534384;ap=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ap&16383](L,10,0)|0;if((ao|0)<1){al=1;i=e;return al|0}if((gzL(af,0,10)|0)==0){break}else{al=1}i=e;return al|0}}while(0);af=(c[3529012]|0)+16384|0;if((c[3542200]|0)==0){al=1;i=e;return al|0}an=I+108|0;c[an>>2]=0;am=I+100|0;c[am>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](I,11)|0;do{if((c[an>>2]|0)!=0){ao=c[am>>2]|0;c[J>>2]=9534384;ap=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ap&16383](J,11,0)|0;if((ao|0)<1){al=1;i=e;return al|0}if((gzL(af,0,11)|0)==0){break}else{al=1}i=e;return al|0}}while(0);af=c[3527094]|0;am=c[2439464]|0;an=c[2439462]|0;ao=c[3529012]|0;ap=c[2405764]|0;if((af|0)>0){aq=ag(an,am)|0;ar=(an|0)<1|(am|0)<1;as=0;do{at=ag(as,aq)|0;gGz(ap+at|0,0,aq|0);au=as<<6;av=au+131072|0;if(!ar){aw=0;do{ax=av+(c[1238464+(aw<<2)>>2]|0)|0;ay=(ag(aw,am)|0)+at|0;az=0;do{aA=ax+(c[614800+(az<<2)>>2]|0)|0;if(((d[ao+((aA|0)/8|0)|0]|0)&128>>>((aA&7)>>>0)|0)!=0){aA=ap+(ay+az)|0;a[aA]=a[aA]|4}az=az+1|0;}while((az|0)<(am|0));aw=aw+1|0;}while((aw|0)<(an|0));aw=au+65536|0;av=0;while(1){az=aw+(c[1238464+(av<<2)>>2]|0)|0;ay=(ag(av,am)|0)+at|0;ax=0;do{aA=az+(c[614800+(ax<<2)>>2]|0)|0;if(((d[ao+((aA|0)/8|0)|0]|0)&128>>>((aA&7)>>>0)|0)!=0){aA=ap+(ay+ax)|0;a[aA]=a[aA]|2}ax=ax+1|0;}while((ax|0)<(am|0));ax=av+1|0;if((ax|0)<(an|0)){av=ax}else{aB=0;break}}do{av=au+(c[1238464+(aB<<2)>>2]|0)|0;aw=(ag(aB,am)|0)+at|0;ax=0;do{ay=av+(c[614800+(ax<<2)>>2]|0)|0;if(((d[ao+((ay|0)/8|0)|0]|0)&128>>>((ay&7)>>>0)|0)!=0){ay=ap+(aw+ax)|0;a[ay]=a[ay]|1}ax=ax+1|0;}while((ax|0)<(am|0));aB=aB+1|0;}while((aB|0)<(an|0))}as=as+1|0;}while((as|0)<(af|0))}gGz(ao|0,0,49152);if((c[3542200]|0)==0){al=1;i=e;return al|0}af=G+108|0;c[af>>2]=0;as=G+100|0;c[as>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](G,12)|0;do{if((c[af>>2]|0)!=0){an=c[as>>2]|0;c[H>>2]=9534384;am=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[am&16383](H,12,0)|0;if((an|0)<1){al=1;i=e;return al|0}if((gzL(ao,0,12)|0)==0){break}else{al=1}i=e;return al|0}}while(0);ao=(c[3529012]|0)+8192|0;if((c[3542200]|0)==0){al=1;i=e;return al|0}as=E+108|0;c[as>>2]=0;af=E+100|0;c[af>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](E,13)|0;do{if((c[as>>2]|0)!=0){an=c[af>>2]|0;c[F>>2]=9534384;am=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[am&16383](F,13,0)|0;if((an|0)<1){al=1;i=e;return al|0}if((gzL(ao,0,13)|0)==0){break}else{al=1}i=e;return al|0}}while(0);ao=(c[3529012]|0)+16384|0;if((c[3542200]|0)==0){al=1;i=e;return al|0}af=C+108|0;c[af>>2]=0;as=C+100|0;c[as>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](C,14)|0;do{if((c[af>>2]|0)!=0){an=c[as>>2]|0;c[D>>2]=9534384;am=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[am&16383](D,14,0)|0;if((an|0)<1){al=1;i=e;return al|0}if((gzL(ao,0,14)|0)==0){break}else{al=1}i=e;return al|0}}while(0);ao=(c[3529012]|0)+24576|0;if((c[3542200]|0)==0){al=1;i=e;return al|0}as=A+108|0;c[as>>2]=0;af=A+100|0;c[af>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](A,15)|0;do{if((c[as>>2]|0)!=0){an=c[af>>2]|0;c[B>>2]=9534384;am=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[am&16383](B,15,0)|0;if((an|0)<1){al=1;i=e;return al|0}if((gzL(ao,0,15)|0)==0){break}else{al=1}i=e;return al|0}}while(0);ao=(c[3529012]|0)+32768|0;if((c[3542200]|0)==0){al=1;i=e;return al|0}af=y+108|0;c[af>>2]=0;as=y+100|0;c[as>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](y,16)|0;do{if((c[af>>2]|0)!=0){an=c[as>>2]|0;c[z>>2]=9534384;am=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[am&16383](z,16,0)|0;if((an|0)<1){al=1;i=e;return al|0}if((gzL(ao,0,16)|0)==0){break}else{al=1}i=e;return al|0}}while(0);ao=(c[3529012]|0)+40960|0;if((c[3542200]|0)==0){al=1;i=e;return al|0}as=w+108|0;c[as>>2]=0;af=w+100|0;c[af>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](w,17)|0;do{if((c[as>>2]|0)!=0){an=c[af>>2]|0;c[x>>2]=9534384;am=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[am&16383](x,17,0)|0;if((an|0)<1){al=1;i=e;return al|0}if((gzL(ao,0,17)|0)==0){break}else{al=1}i=e;return al|0}}while(0);ao=c[2439452]|0;af=c[3529012]|0;as=c[3529014]|0;if((ao|0)>0){an=0;do{am=an<<8;gGz(as+am|0,0,256);ap=am+262144|0;ar=0;do{aq=ap+(c[609008+(ar<<2)>>2]|0)|0;at=(ar<<4)+am|0;au=0;do{ax=aq+(c[597864+(au<<2)>>2]|0)|0;if(((d[af+((ax|0)/8|0)|0]|0)&128>>>((ax&7)>>>0)|0)!=0){ax=as+(at+au)|0;a[ax]=a[ax]|4}au=au+1|0;}while((au|0)<16);ar=ar+1|0;}while((ar|0)<16);ar=am+131072|0;ap=0;while(1){au=ar+(c[609008+(ap<<2)>>2]|0)|0;at=(ap<<4)+am|0;aq=0;do{ax=au+(c[597864+(aq<<2)>>2]|0)|0;if(((d[af+((ax|0)/8|0)|0]|0)&128>>>((ax&7)>>>0)|0)!=0){ax=as+(at+aq)|0;a[ax]=a[ax]|2}aq=aq+1|0;}while((aq|0)<16);aq=ap+1|0;if((aq|0)<16){ap=aq}else{aC=0;break}}do{ap=am+(c[609008+(aC<<2)>>2]|0)|0;ar=(aC<<4)+am|0;aq=0;do{at=ap+(c[597864+(aq<<2)>>2]|0)|0;if(((d[af+((at|0)/8|0)|0]|0)&128>>>((at&7)>>>0)|0)!=0){at=as+(ar+aq)|0;a[at]=a[at]|1}aq=aq+1|0;}while((aq|0)<16);aC=aC+1|0;}while((aC|0)<16);an=an+1|0;}while((an|0)<(ao|0))}ao=c[3527092]|0;if((c[3542200]|0)==0){al=1;i=e;return al|0}an=u+108|0;c[an>>2]=0;as=u+100|0;c[as>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](u,18)|0;do{if((c[an>>2]|0)!=0){af=c[as>>2]|0;c[v>>2]=9534384;am=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[am&16383](v,18,0)|0;if((af|0)<1){al=1;i=e;return al|0}if((gzL(ao,0,18)|0)==0){break}else{al=1}i=e;return al|0}}while(0);ao=(c[3527092]|0)+256|0;if((c[3542200]|0)==0){al=1;i=e;return al|0}as=s+108|0;c[as>>2]=0;an=s+100|0;c[an>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](s,19)|0;do{if((c[as>>2]|0)!=0){af=c[an>>2]|0;c[t>>2]=9534384;am=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[am&16383](t,19,0)|0;if((af|0)<1){al=1;i=e;return al|0}if((gzL(ao,0,19)|0)==0){break}else{al=1}i=e;return al|0}}while(0);ao=(c[3527092]|0)+512|0;if((c[3542200]|0)==0){al=1;i=e;return al|0}an=q+108|0;c[an>>2]=0;as=q+100|0;c[as>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](q,20)|0;do{if((c[an>>2]|0)!=0){af=c[as>>2]|0;c[r>>2]=9534384;am=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[am&16383](r,20,0)|0;if((af|0)<1){al=1;i=e;return al|0}if((gzL(ao,0,20)|0)==0){break}else{al=1}i=e;return al|0}}while(0);ao=(c[3527092]|0)+768|0;if((c[3542200]|0)==0){al=1;i=e;return al|0}as=o+108|0;c[as>>2]=0;an=o+100|0;c[an>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](o,21)|0;do{if((c[as>>2]|0)!=0){af=c[an>>2]|0;c[p>>2]=9534384;am=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[am&16383](p,21,0)|0;if((af|0)<1){al=1;i=e;return al|0}if((gzL(ao,0,21)|0)==0){break}else{al=1}i=e;return al|0}}while(0);ao=(c[3527092]|0)+1024|0;if((c[3542200]|0)==0){al=1;i=e;return al|0}an=m+108|0;c[an>>2]=0;as=m+100|0;c[as>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,22)|0;do{if((c[an>>2]|0)!=0){af=c[as>>2]|0;c[n>>2]=9534384;am=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[am&16383](n,22,0)|0;if((af|0)<1){al=1;i=e;return al|0}if((gzL(ao,0,22)|0)==0){break}else{al=1}i=e;return al|0}}while(0);ao=(c[3527092]|0)+1280|0;if((c[3542200]|0)==0){al=1;i=e;return al|0}as=k+108|0;c[as>>2]=0;an=k+100|0;c[an>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,23)|0;do{if((c[as>>2]|0)!=0){af=c[an>>2]|0;c[l>>2]=9534384;am=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[am&16383](l,23,0)|0;if((af|0)<1){al=1;i=e;return al|0}if((gzL(ao,0,23)|0)==0){break}else{al=1}i=e;return al|0}}while(0);ao=(c[3527092]|0)+1536|0;if((c[3542200]|0)==0){al=1;i=e;return al|0}an=h+108|0;c[an>>2]=0;as=h+100|0;c[as>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](h,24)|0;do{if((c[an>>2]|0)!=0){af=c[as>>2]|0;c[j>>2]=9534384;am=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[am&16383](j,24,0)|0;if((af|0)<1){al=1;i=e;return al|0}if((gzL(ao,0,24)|0)==0){break}else{al=1}i=e;return al|0}}while(0);ao=(c[3527092]|0)+1568|0;if((c[3542200]|0)==0){al=1;i=e;return al|0}as=f+108|0;c[as>>2]=0;an=f+100|0;c[an>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,25)|0;do{if((c[as>>2]|0)!=0){af=c[an>>2]|0;c[g>>2]=9534384;am=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[am&16383](g,25,0)|0;if((af|0)<1){al=1;i=e;return al|0}if((gzL(ao,0,25)|0)==0){break}else{al=1}i=e;return al|0}}while(0);ao=c[3529012]|0;an=0;while(1){if((an|0)>=1024){break}aD=9638528+(an<<2)|0;if((c[aD>>2]|0)==(ao|0)){ai=54029;break}else{an=an+1|0}}if((ai|0)==54029){gGr(ao);c[aD>>2]=0}c[3529012]=0;a9H();an=c[2439330]|0;as=(an|0)==0;if(!as){af=an;gGC(9706056,af|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];af=c[3528484]|0;c[2076596]=af;am=c[2417276]|0;c[3541536]=am;c[1836236]=0;c[an+4172>>2]=1766;c[an+4176>>2]=858;aq=c[2385798]|0;ar=128;ap=128;while(1){c[an+76+(ap<<2)>>2]=aq+(ap<<8);at=ar+1&65535;if((at&65535)>159){aE=128;aF=128;break}else{ar=at;ap=at&65535}}while(1){ap=aq+(aF<<8)|0;c[an+76+(aF+512<<2)>>2]=ap;c[an+76+(aF+768<<2)>>2]=ap;ap=aE+1&65535;if((ap&65535)>159){break}else{aE=ap;aF=ap&65535}}if(!as){aq=an;gGC(aq|0,9706056,76)|0}aq=c[2433530]|0;c[2438118]=aq;c[3528484]=af;c[2417276]=am;c[1836236]=-1;c[2431670]=5494;c[2426980]=110;if(as){c[2433530]=aq;c[2076596]=af;c[3541536]=am;c[1836236]=0;gGz(9706056,0,76)}else{ap=an;gGC(9706056,ap|0,76)|0;c[2433530]=aq;c[2076596]=af;c[3541536]=am;c[1836236]=0;gGz(9706056,0,76);ap=an;gGC(ap|0,9706056,76)|0}c[2438118]=aq;c[3528484]=af;c[2417276]=am;c[1836236]=-1;a[9660900]=a[9660900]|16;aq=c[2437644]|0;ap=c[aq+1092>>2]|0;do{if((ap|0)==0){ar=c[aq+3144>>2]|0;if((ar|0)==0){aG=0;aH=0;break}ao=gj[ar&4095](-2)|0;ar=c[2437644]|0;at=c[ar+1092>>2]|0;au=(ao&255)<<8;if((at|0)!=0){aI=at;aJ=au;ai=54044;break}at=c[ar+3144>>2]|0;if((at|0)==0){aG=0;aH=au;break}aG=gj[at&4095](-1)|0;aH=au}else{aI=ap;aJ=(d[ap+254|0]|0)<<8;ai=54044}}while(0);if((ai|0)==54044){aG=a[aI+255|0]|0;aH=aJ}ap=aG&255|aH;c[2415221]=ap;b[4830442]=ap&65535;a[9660920]=0;a[9660921]=0;a[9660928]=0;a[9660930]=0;a[9660931]=0;c[2415234]=0;gGz(9660901,0,5);c[2415235]=65535;c[2415237]=65535;a[9660932]=a[9660932]|64;mB(0);mB(1);UA();c[2429502]=0;c[2429500]=0;c[2438664]=0;c[2439460]=0;a[9757800]=0;a[9623080]=0;a[9623072]=0;a[683232]=0;a[9754673]=0;a[9754672]=0;a[9754680]=0;a[9718896]=0;a[9717272]=0;a[9718824]=0;al=0;i=e;return al|0}}while(0);c[2426820]=0;al=1;i=e;return al|0}function a80(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6261420+(b*112|0)>>2];c[a+104>>2]=c[6261424+(b*112|0)>>2];c[a+108>>2]=c[6261428+(b*112|0)>>2];d=0;return d|0}function a81(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=6261320+(b*112|0);e=0;return e|0}function a82(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;c[2439448]=49152;c[3527090]=1824;c[3527094]=2048;c[2439452]=1024;c[2431672]=c[(c[642608+(c[2436]<<2)>>2]|0)+124>>2];c[2426820]=0;a9Q();e=c[2414438]|0;f=0;while(1){if((f|0)>=1024){break}g=9638528+(f<<2)|0;if((c[g>>2]|0)==0){h=54166;break}else{f=f+1|0}}do{if((h|0)==54166){f=gGq(e)|0;c[g>>2]=f;if((f|0)==0){break}gGz(f|0,0,e|0);c[2426820]=f;gGz(f|0,0,e|0);a9Q();if((a94()|0)!=0){i=1;return i|0}a9H();f=c[2439330]|0;j=(f|0)==0;if(!j){k=f;gGC(9706056,k|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];k=c[3528484]|0;c[2076596]=k;l=c[2417276]|0;c[3541536]=l;c[1836236]=0;c[f+4180>>2]=2126;c[f+4176>>2]=2316;m=c[2385798]|0;n=128;o=128;while(1){c[f+76+(o<<2)>>2]=m+(o<<8);p=n+1&65535;if((p&65535)>191){q=128;r=128;break}else{n=p;o=p&65535}}while(1){o=m+(r<<8)|0;c[f+76+(r+512<<2)>>2]=o;c[f+76+(r+768<<2)>>2]=o;o=q+1&65535;if((o&65535)>191){break}else{q=o;r=o&65535}}if(!j){m=f;gGC(m|0,9706056,76)|0}m=c[2433530]|0;c[2438118]=m;c[3528484]=k;c[2417276]=l;c[1836236]=-1;c[2431670]=1920;c[2426980]=110;if(j){c[2433530]=m;c[2076596]=k;c[3541536]=l;c[1836236]=0;gGz(9706056,0,76)}else{o=f;gGC(9706056,o|0,76)|0;c[2433530]=m;c[2076596]=k;c[3541536]=l;c[1836236]=0;gGz(9706056,0,76);o=f;gGC(o|0,9706056,76)|0}c[2438118]=m;c[3528484]=k;c[2417276]=l;c[1836236]=-1;a[9660900]=a[9660900]|16;m=c[2437644]|0;o=c[m+1092>>2]|0;do{if((o|0)==0){n=c[m+3144>>2]|0;if((n|0)==0){s=0;t=0;break}p=gj[n&4095](-2)|0;n=c[2437644]|0;u=c[n+1092>>2]|0;v=(p&255)<<8;if((u|0)!=0){w=u;x=v;h=54183;break}u=c[n+3144>>2]|0;if((u|0)==0){s=0;t=v;break}s=gj[u&4095](-1)|0;t=v}else{w=o;x=(d[o+254|0]|0)<<8;h=54183}}while(0);if((h|0)==54183){s=a[w+255|0]|0;t=x}o=s&255|t;c[2415221]=o;b[4830442]=o&65535;a[9660920]=0;a[9660921]=0;a[9660928]=0;a[9660930]=0;a[9660931]=0;c[2415234]=0;gGz(9660901,0,5);c[2415235]=65535;c[2415237]=65535;a[9660932]=a[9660932]|64;mB(0);mB(1);UA();c[2429502]=0;c[2429500]=0;c[2438664]=0;c[2439460]=0;a[9757800]=0;a[9623080]=0;a[9623072]=0;a[683232]=0;a[9754673]=0;a[9754672]=0;a[9754680]=0;a[9718896]=0;a[9717272]=0;a[9718824]=0;i=0;return i|0}}while(0);c[2426820]=0;i=1;return i|0}function a83(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5311092+(b*112|0)>>2];c[a+104>>2]=c[5311096+(b*112|0)>>2];c[a+108>>2]=c[5311100+(b*112|0)>>2];d=0;return d|0}function a84(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=5310992+(b*112|0);e=0;return e|0}function a85(){var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0;e=i;i=i+2280|0;f=e|0;g=e+112|0;h=e+120|0;j=e+232|0;k=e+240|0;l=e+352|0;m=e+360|0;n=e+472|0;o=e+480|0;p=e+592|0;q=e+600|0;r=e+712|0;s=e+720|0;t=e+832|0;u=e+840|0;v=e+952|0;w=e+960|0;x=e+1072|0;y=e+1080|0;z=e+1192|0;A=e+1200|0;B=e+1312|0;C=e+1320|0;D=e+1432|0;E=e+1440|0;F=e+1552|0;G=e+1560|0;H=e+1672|0;I=e+1680|0;J=e+1792|0;K=e+1800|0;L=e+1912|0;M=e+1920|0;N=e+2032|0;O=e+2040|0;P=e+2152|0;Q=e+2160|0;R=e+2272|0;c[2439448]=49152;c[3527090]=1824;c[3527094]=2048;c[2439452]=512;c[2431672]=c[(c[642608+(c[2436]<<2)>>2]|0)+124>>2];c[2426820]=0;a9Q();S=c[2414438]|0;T=0;while(1){if((T|0)>=1024){break}U=9638528+(T<<2)|0;if((c[U>>2]|0)==0){V=54206;break}else{T=T+1|0}}do{if((V|0)==54206){T=gGq(S)|0;c[U>>2]=T;if((T|0)==0){break}gGz(T|0,0,S|0);c[2426820]=T;gGz(T|0,0,S|0);a9Q();T=0;while(1){if((T|0)>=1024){W=0;break}X=9638528+(T<<2)|0;if((c[X>>2]|0)==0){V=54211;break}else{T=T+1|0}}do{if((V|0)==54211){T=gGq(49152)|0;c[X>>2]=T;if((T|0)==0){W=0;break}gGz(T|0,0,49152);W=T}}while(0);c[3529012]=W;T=c[2385798]|0;if((c[3542200]|0)==0){Y=1;i=e;return Y|0}Z=Q+108|0;c[Z>>2]=0;_=Q+100|0;c[_>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](Q,0)|0;do{if((c[Z>>2]|0)!=0){$=c[_>>2]|0;c[R>>2]=9534384;aa=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aa&16383](R,0,0)|0;if(($|0)<1){Y=1;i=e;return Y|0}if((gzL(T,0,0)|0)==0){break}else{Y=1}i=e;return Y|0}}while(0);T=(c[2385798]|0)+16384|0;if((c[3542200]|0)==0){Y=1;i=e;return Y|0}_=O+108|0;c[_>>2]=0;Z=O+100|0;c[Z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](O,1)|0;do{if((c[_>>2]|0)!=0){$=c[Z>>2]|0;c[P>>2]=9534384;aa=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aa&16383](P,1,0)|0;if(($|0)<1){Y=1;i=e;return Y|0}if((gzL(T,0,1)|0)==0){break}else{Y=1}i=e;return Y|0}}while(0);T=(c[2385798]|0)+32768|0;if((c[3542200]|0)==0){Y=1;i=e;return Y|0}Z=M+108|0;c[Z>>2]=0;_=M+100|0;c[_>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](M,2)|0;do{if((c[Z>>2]|0)!=0){$=c[_>>2]|0;c[N>>2]=9534384;aa=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aa&16383](N,2,0)|0;if(($|0)<1){Y=1;i=e;return Y|0}if((gzL(T,0,2)|0)==0){break}else{Y=1}i=e;return Y|0}}while(0);T=(c[3527098]|0)+16384|0;if((c[3542200]|0)==0){Y=1;i=e;return Y|0}_=K+108|0;c[_>>2]=0;Z=K+100|0;c[Z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](K,3)|0;do{if((c[_>>2]|0)!=0){$=c[Z>>2]|0;c[L>>2]=9534384;aa=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aa&16383](L,3,0)|0;if(($|0)<1){Y=1;i=e;return Y|0}if((gzL(T,0,3)|0)==0){break}else{Y=1}i=e;return Y|0}}while(0);T=(c[3527098]|0)+32768|0;if((c[3542200]|0)==0){Y=1;i=e;return Y|0}Z=I+108|0;c[Z>>2]=0;_=I+100|0;c[_>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](I,4)|0;do{if((c[Z>>2]|0)!=0){$=c[_>>2]|0;c[J>>2]=9534384;aa=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aa&16383](J,4,0)|0;if(($|0)<1){Y=1;i=e;return Y|0}if((gzL(T,0,4)|0)==0){break}else{Y=1}i=e;return Y|0}}while(0);T=c[3529012]|0;gGz(T|0,0,49152);if((c[3542200]|0)==0){Y=1;i=e;return Y|0}_=G+108|0;c[_>>2]=0;Z=G+100|0;c[Z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](G,5)|0;do{if((c[_>>2]|0)!=0){$=c[Z>>2]|0;c[H>>2]=9534384;aa=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aa&16383](H,5,0)|0;if(($|0)<1){Y=1;i=e;return Y|0}if((gzL(T,0,5)|0)==0){break}else{Y=1}i=e;return Y|0}}while(0);T=(c[3529012]|0)+16384|0;if((c[3542200]|0)==0){Y=1;i=e;return Y|0}Z=E+108|0;c[Z>>2]=0;_=E+100|0;c[_>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](E,6)|0;do{if((c[Z>>2]|0)!=0){$=c[_>>2]|0;c[F>>2]=9534384;aa=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aa&16383](F,6,0)|0;if(($|0)<1){Y=1;i=e;return Y|0}if((gzL(T,0,6)|0)==0){break}else{Y=1}i=e;return Y|0}}while(0);T=(c[3529012]|0)+32768|0;if((c[3542200]|0)==0){Y=1;i=e;return Y|0}_=C+108|0;c[_>>2]=0;Z=C+100|0;c[Z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](C,7)|0;do{if((c[_>>2]|0)!=0){$=c[Z>>2]|0;c[D>>2]=9534384;aa=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aa&16383](D,7,0)|0;if(($|0)<1){Y=1;i=e;return Y|0}if((gzL(T,0,7)|0)==0){break}else{Y=1}i=e;return Y|0}}while(0);T=c[3527094]|0;Z=c[2439464]|0;_=c[2439462]|0;$=c[3529012]|0;aa=c[2405764]|0;if((T|0)>0){ab=ag(_,Z)|0;ac=(_|0)<1|(Z|0)<1;ad=0;do{ae=ag(ad,ab)|0;gGz(aa+ae|0,0,ab|0);af=ad<<6;ah=af+262144|0;if(!ac){ai=0;do{aj=ah+(c[1238464+(ai<<2)>>2]|0)|0;ak=(ag(ai,Z)|0)+ae|0;al=0;do{am=aj+(c[614800+(al<<2)>>2]|0)|0;if(((d[$+((am|0)/8|0)|0]|0)&128>>>((am&7)>>>0)|0)!=0){am=aa+(ak+al)|0;a[am]=a[am]|4}al=al+1|0;}while((al|0)<(Z|0));ai=ai+1|0;}while((ai|0)<(_|0));ai=af+131072|0;ah=0;while(1){al=ai+(c[1238464+(ah<<2)>>2]|0)|0;ak=(ag(ah,Z)|0)+ae|0;aj=0;do{am=al+(c[614800+(aj<<2)>>2]|0)|0;if(((d[$+((am|0)/8|0)|0]|0)&128>>>((am&7)>>>0)|0)!=0){am=aa+(ak+aj)|0;a[am]=a[am]|2}aj=aj+1|0;}while((aj|0)<(Z|0));aj=ah+1|0;if((aj|0)<(_|0)){ah=aj}else{an=0;break}}do{ah=af+(c[1238464+(an<<2)>>2]|0)|0;ai=(ag(an,Z)|0)+ae|0;aj=0;do{ak=ah+(c[614800+(aj<<2)>>2]|0)|0;if(((d[$+((ak|0)/8|0)|0]|0)&128>>>((ak&7)>>>0)|0)!=0){ak=aa+(ai+aj)|0;a[ak]=a[ak]|1}aj=aj+1|0;}while((aj|0)<(Z|0));an=an+1|0;}while((an|0)<(_|0))}ad=ad+1|0;}while((ad|0)<(T|0))}gGz($|0,0,49152);if((c[3542200]|0)==0){Y=1;i=e;return Y|0}T=A+108|0;c[T>>2]=0;ad=A+100|0;c[ad>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](A,8)|0;do{if((c[T>>2]|0)!=0){_=c[ad>>2]|0;c[B>>2]=9534384;Z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Z&16383](B,8,0)|0;if((_|0)<1){Y=1;i=e;return Y|0}if((gzL($,0,8)|0)==0){break}else{Y=1}i=e;return Y|0}}while(0);$=(c[3529012]|0)+16384|0;if((c[3542200]|0)==0){Y=1;i=e;return Y|0}ad=y+108|0;c[ad>>2]=0;T=y+100|0;c[T>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](y,9)|0;do{if((c[ad>>2]|0)!=0){_=c[T>>2]|0;c[z>>2]=9534384;Z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Z&16383](z,9,0)|0;if((_|0)<1){Y=1;i=e;return Y|0}if((gzL($,0,9)|0)==0){break}else{Y=1}i=e;return Y|0}}while(0);$=(c[3529012]|0)+32768|0;if((c[3542200]|0)==0){Y=1;i=e;return Y|0}T=w+108|0;c[T>>2]=0;ad=w+100|0;c[ad>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](w,10)|0;do{if((c[T>>2]|0)!=0){_=c[ad>>2]|0;c[x>>2]=9534384;Z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Z&16383](x,10,0)|0;if((_|0)<1){Y=1;i=e;return Y|0}if((gzL($,0,10)|0)==0){break}else{Y=1}i=e;return Y|0}}while(0);$=c[2439452]|0;ad=c[3529012]|0;T=c[3529014]|0;if(($|0)>0){_=0;do{Z=_<<8;gGz(T+Z|0,0,256);aa=Z+262144|0;ac=0;do{ab=aa+(c[609008+(ac<<2)>>2]|0)|0;ae=(ac<<4)+Z|0;af=0;do{aj=ab+(c[597864+(af<<2)>>2]|0)|0;if(((d[ad+((aj|0)/8|0)|0]|0)&128>>>((aj&7)>>>0)|0)!=0){aj=T+(ae+af)|0;a[aj]=a[aj]|4}af=af+1|0;}while((af|0)<16);ac=ac+1|0;}while((ac|0)<16);ac=Z+131072|0;aa=0;while(1){af=ac+(c[609008+(aa<<2)>>2]|0)|0;ae=(aa<<4)+Z|0;ab=0;do{aj=af+(c[597864+(ab<<2)>>2]|0)|0;if(((d[ad+((aj|0)/8|0)|0]|0)&128>>>((aj&7)>>>0)|0)!=0){aj=T+(ae+ab)|0;a[aj]=a[aj]|2}ab=ab+1|0;}while((ab|0)<16);ab=aa+1|0;if((ab|0)<16){aa=ab}else{ao=0;break}}do{aa=Z+(c[609008+(ao<<2)>>2]|0)|0;ac=(ao<<4)+Z|0;ab=0;do{ae=aa+(c[597864+(ab<<2)>>2]|0)|0;if(((d[ad+((ae|0)/8|0)|0]|0)&128>>>((ae&7)>>>0)|0)!=0){ae=T+(ac+ab)|0;a[ae]=a[ae]|1}ab=ab+1|0;}while((ab|0)<16);ao=ao+1|0;}while((ao|0)<16);_=_+1|0;}while((_|0)<($|0))}$=c[3527092]|0;if((c[3542200]|0)==0){Y=1;i=e;return Y|0}_=u+108|0;c[_>>2]=0;T=u+100|0;c[T>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](u,11)|0;do{if((c[_>>2]|0)!=0){ad=c[T>>2]|0;c[v>>2]=9534384;Z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Z&16383](v,11,0)|0;if((ad|0)<1){Y=1;i=e;return Y|0}if((gzL($,0,11)|0)==0){break}else{Y=1}i=e;return Y|0}}while(0);$=(c[3527092]|0)+256|0;if((c[3542200]|0)==0){Y=1;i=e;return Y|0}T=s+108|0;c[T>>2]=0;_=s+100|0;c[_>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](s,12)|0;do{if((c[T>>2]|0)!=0){ad=c[_>>2]|0;c[t>>2]=9534384;Z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Z&16383](t,12,0)|0;if((ad|0)<1){Y=1;i=e;return Y|0}if((gzL($,0,12)|0)==0){break}else{Y=1}i=e;return Y|0}}while(0);$=(c[3527092]|0)+512|0;if((c[3542200]|0)==0){Y=1;i=e;return Y|0}_=q+108|0;c[_>>2]=0;T=q+100|0;c[T>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](q,13)|0;do{if((c[_>>2]|0)!=0){ad=c[T>>2]|0;c[r>>2]=9534384;Z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Z&16383](r,13,0)|0;if((ad|0)<1){Y=1;i=e;return Y|0}if((gzL($,0,13)|0)==0){break}else{Y=1}i=e;return Y|0}}while(0);$=(c[3527092]|0)+768|0;if((c[3542200]|0)==0){Y=1;i=e;return Y|0}T=o+108|0;c[T>>2]=0;_=o+100|0;c[_>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](o,14)|0;do{if((c[T>>2]|0)!=0){ad=c[_>>2]|0;c[p>>2]=9534384;Z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Z&16383](p,14,0)|0;if((ad|0)<1){Y=1;i=e;return Y|0}if((gzL($,0,14)|0)==0){break}else{Y=1}i=e;return Y|0}}while(0);$=(c[3527092]|0)+1024|0;if((c[3542200]|0)==0){Y=1;i=e;return Y|0}_=m+108|0;c[_>>2]=0;T=m+100|0;c[T>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,15)|0;do{if((c[_>>2]|0)!=0){ad=c[T>>2]|0;c[n>>2]=9534384;Z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Z&16383](n,15,0)|0;if((ad|0)<1){Y=1;i=e;return Y|0}if((gzL($,0,15)|0)==0){break}else{Y=1}i=e;return Y|0}}while(0);$=(c[3527092]|0)+1280|0;if((c[3542200]|0)==0){Y=1;i=e;return Y|0}T=k+108|0;c[T>>2]=0;_=k+100|0;c[_>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,16)|0;do{if((c[T>>2]|0)!=0){ad=c[_>>2]|0;c[l>>2]=9534384;Z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Z&16383](l,16,0)|0;if((ad|0)<1){Y=1;i=e;return Y|0}if((gzL($,0,16)|0)==0){break}else{Y=1}i=e;return Y|0}}while(0);$=(c[3527092]|0)+1536|0;if((c[3542200]|0)==0){Y=1;i=e;return Y|0}_=h+108|0;c[_>>2]=0;T=h+100|0;c[T>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](h,17)|0;do{if((c[_>>2]|0)!=0){ad=c[T>>2]|0;c[j>>2]=9534384;Z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Z&16383](j,17,0)|0;if((ad|0)<1){Y=1;i=e;return Y|0}if((gzL($,0,17)|0)==0){break}else{Y=1}i=e;return Y|0}}while(0);$=(c[3527092]|0)+1568|0;if((c[3542200]|0)==0){Y=1;i=e;return Y|0}T=f+108|0;c[T>>2]=0;_=f+100|0;c[_>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,18)|0;do{if((c[T>>2]|0)!=0){ad=c[_>>2]|0;c[g>>2]=9534384;Z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Z&16383](g,18,0)|0;if((ad|0)<1){Y=1;i=e;return Y|0}if((gzL($,0,18)|0)==0){break}else{Y=1}i=e;return Y|0}}while(0);$=c[3529012]|0;_=0;while(1){if((_|0)>=1024){break}ap=9638528+(_<<2)|0;if((c[ap>>2]|0)==($|0)){V=54309;break}else{_=_+1|0}}if((V|0)==54309){gGr($);c[ap>>2]=0}c[3529012]=0;a9H();_=c[2439330]|0;T=(_|0)==0;if(!T){ad=_;gGC(9706056,ad|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];ad=c[3528484]|0;c[2076596]=ad;Z=c[2417276]|0;c[3541536]=Z;c[1836236]=0;c[_+4180>>2]=2126;c[_+4176>>2]=2316;ab=c[2385798]|0;ac=128;aa=128;while(1){c[_+76+(aa<<2)>>2]=ab+(aa<<8);ae=ac+1&65535;if((ae&65535)>191){aq=128;ar=128;break}else{ac=ae;aa=ae&65535}}while(1){aa=ab+(ar<<8)|0;c[_+76+(ar+512<<2)>>2]=aa;c[_+76+(ar+768<<2)>>2]=aa;aa=aq+1&65535;if((aa&65535)>191){break}else{aq=aa;ar=aa&65535}}if(!T){ab=_;gGC(ab|0,9706056,76)|0}ab=c[2433530]|0;c[2438118]=ab;c[3528484]=ad;c[2417276]=Z;c[1836236]=-1;c[2431670]=1920;c[2426980]=110;if(T){c[2433530]=ab;c[2076596]=ad;c[3541536]=Z;c[1836236]=0;gGz(9706056,0,76)}else{aa=_;gGC(9706056,aa|0,76)|0;c[2433530]=ab;c[2076596]=ad;c[3541536]=Z;c[1836236]=0;gGz(9706056,0,76);aa=_;gGC(aa|0,9706056,76)|0}c[2438118]=ab;c[3528484]=ad;c[2417276]=Z;c[1836236]=-1;a[9660900]=a[9660900]|16;ab=c[2437644]|0;aa=c[ab+1092>>2]|0;do{if((aa|0)==0){ac=c[ab+3144>>2]|0;if((ac|0)==0){as=0;at=0;break}$=gj[ac&4095](-2)|0;ac=c[2437644]|0;ae=c[ac+1092>>2]|0;af=($&255)<<8;if((ae|0)!=0){au=ae;av=af;V=54324;break}ae=c[ac+3144>>2]|0;if((ae|0)==0){as=0;at=af;break}as=gj[ae&4095](-1)|0;at=af}else{au=aa;av=(d[aa+254|0]|0)<<8;V=54324}}while(0);if((V|0)==54324){as=a[au+255|0]|0;at=av}aa=as&255|at;c[2415221]=aa;b[4830442]=aa&65535;a[9660920]=0;a[9660921]=0;a[9660928]=0;a[9660930]=0;a[9660931]=0;c[2415234]=0;gGz(9660901,0,5);c[2415235]=65535;c[2415237]=65535;a[9660932]=a[9660932]|64;mB(0);mB(1);UA();c[2429502]=0;c[2429500]=0;c[2438664]=0;c[2439460]=0;a[9757800]=0;a[9623080]=0;a[9623072]=0;a[683232]=0;a[9754673]=0;a[9754672]=0;a[9754680]=0;a[9718896]=0;a[9717272]=0;a[9718824]=0;Y=0;i=e;return Y|0}}while(0);c[2426820]=0;Y=1;i=e;return Y|0}function a86(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6257844+(b*112|0)>>2];c[a+104>>2]=c[6257848+(b*112|0)>>2];c[a+108>>2]=c[6257852+(b*112|0)>>2];d=0;return d|0}function a87(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=6257744+(b*112|0);e=0;return e|0}function a88(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>82){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6260320+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function a89(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;c[2439448]=65536;c[3527090]=1824;c[3527094]=2048;c[2439452]=1024;c[2431672]=c[(c[642608+(c[2436]<<2)>>2]|0)+124>>2];c[2426820]=0;a9Q();e=c[2414438]|0;f=0;while(1){if((f|0)>=1024){break}g=9638528+(f<<2)|0;if((c[g>>2]|0)==0){h=54432;break}else{f=f+1|0}}do{if((h|0)==54432){f=gGq(e)|0;c[g>>2]=f;if((f|0)==0){break}gGz(f|0,0,e|0);c[2426820]=f;gGz(f|0,0,e|0);a9Q();if((a94()|0)!=0){i=1;return i|0}a9H();f=c[2439330]|0;j=(f|0)==0;if(!j){k=f;gGC(9706056,k|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];k=c[3528484]|0;c[2076596]=k;l=c[2417276]|0;c[3541536]=l;c[1836236]=0;c[f+4184>>2]=1122;c[f+4176>>2]=3196;m=c[2385798]|0;n=128;o=128;while(1){c[f+76+(o<<2)>>2]=m+(o<<8);p=n+1&65535;if((p&65535)>191){q=128;r=128;break}else{n=p;o=p&65535}}while(1){o=m+(r<<8)|0;c[f+76+(r+512<<2)>>2]=o;c[f+76+(r+768<<2)>>2]=o;o=q+1&65535;if((o&65535)>191){break}else{q=o;r=o&65535}}if(!j){m=f;gGC(m|0,9706056,76)|0}m=c[2433530]|0;c[2438118]=m;c[3528484]=k;c[2417276]=l;c[1836236]=-1;c[2431670]=7894;c[2426980]=24;if(j){c[2433530]=m;c[2076596]=k;c[3541536]=l;c[1836236]=0;gGz(9706056,0,76)}else{o=f;gGC(9706056,o|0,76)|0;c[2433530]=m;c[2076596]=k;c[3541536]=l;c[1836236]=0;gGz(9706056,0,76);o=f;gGC(o|0,9706056,76)|0}c[2438118]=m;c[3528484]=k;c[2417276]=l;c[1836236]=-1;a[9660900]=a[9660900]|16;m=c[2437644]|0;o=c[m+1092>>2]|0;do{if((o|0)==0){n=c[m+3144>>2]|0;if((n|0)==0){s=0;t=0;break}p=gj[n&4095](-2)|0;n=c[2437644]|0;u=c[n+1092>>2]|0;v=(p&255)<<8;if((u|0)!=0){w=u;x=v;h=54449;break}u=c[n+3144>>2]|0;if((u|0)==0){s=0;t=v;break}s=gj[u&4095](-1)|0;t=v}else{w=o;x=(d[o+254|0]|0)<<8;h=54449}}while(0);if((h|0)==54449){s=a[w+255|0]|0;t=x}o=s&255|t;c[2415221]=o;b[4830442]=o&65535;a[9660920]=0;a[9660921]=0;a[9660928]=0;a[9660930]=0;a[9660931]=0;c[2415234]=0;gGz(9660901,0,5);c[2415235]=65535;c[2415237]=65535;a[9660932]=a[9660932]|64;mB(0);mB(1);UA();c[2429502]=0;c[2429500]=0;c[2438664]=0;c[2439460]=0;a[9757800]=0;a[9623080]=0;a[9623072]=0;a[683232]=0;a[9754673]=0;a[9754672]=0;a[9754680]=0;a[9718896]=0;a[9717272]=0;a[9718824]=0;i=0;return i|0}}while(0);c[2426820]=0;i=1;return i|0}function a9a(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>24){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6243900+(b*112|0)>>2];c[a+104>>2]=c[6243904+(b*112|0)>>2];c[a+108>>2]=c[6243908+(b*112|0)>>2];d=0;return d|0}function a9b(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<25&(d|0)==0)){e=1;return e|0}c[a>>2]=6243800+(b*112|0);e=0;return e|0}function a9c(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>83){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6246600+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function a9d(){var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0;e=i;i=i+2760|0;f=e|0;g=e+112|0;h=e+120|0;j=e+232|0;k=e+240|0;l=e+352|0;m=e+360|0;n=e+472|0;o=e+480|0;p=e+592|0;q=e+600|0;r=e+712|0;s=e+720|0;t=e+832|0;u=e+840|0;v=e+952|0;w=e+960|0;x=e+1072|0;y=e+1080|0;z=e+1192|0;A=e+1200|0;B=e+1312|0;C=e+1320|0;D=e+1432|0;E=e+1440|0;F=e+1552|0;G=e+1560|0;H=e+1672|0;I=e+1680|0;J=e+1792|0;K=e+1800|0;L=e+1912|0;M=e+1920|0;N=e+2032|0;O=e+2040|0;P=e+2152|0;Q=e+2160|0;R=e+2272|0;S=e+2280|0;T=e+2392|0;U=e+2400|0;V=e+2512|0;W=e+2520|0;X=e+2632|0;Y=e+2640|0;Z=e+2752|0;c[2439448]=32768;c[3527090]=2592;c[3527094]=256;c[2439452]=256;c[3527096]=256;c[2438666]=4096;c[2439464]=12;c[2439462]=10;c[2437648]=12;c[2437646]=10;c[2431672]=c[(c[642608+(c[2436]<<2)>>2]|0)+124>>2];c[2426820]=0;a9Q();_=c[2414438]|0;$=0;while(1){if(($|0)>=1024){break}aa=9638528+($<<2)|0;if((c[aa>>2]|0)==0){ab=54479;break}else{$=$+1|0}}do{if((ab|0)==54479){$=gGq(_)|0;c[aa>>2]=$;if(($|0)==0){break}gGz($|0,0,_|0);c[2426820]=$;gGz($|0,0,_|0);a9Q();$=0;while(1){if(($|0)>=1024){ac=0;break}ad=9638528+($<<2)|0;if((c[ad>>2]|0)==0){ab=54484;break}else{$=$+1|0}}do{if((ab|0)==54484){$=gGq(24576)|0;c[ad>>2]=$;if(($|0)==0){ac=0;break}gGz($|0,0,24576);ac=$}}while(0);c[3529012]=ac;$=c[2385798]|0;if((c[3542200]|0)==0){ae=1;i=e;return ae|0}af=Y+108|0;c[af>>2]=0;ah=Y+100|0;c[ah>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](Y,0)|0;do{if((c[af>>2]|0)!=0){ai=c[ah>>2]|0;c[Z>>2]=9534384;aj=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aj&16383](Z,0,0)|0;if((ai|0)<1){ae=1;i=e;return ae|0}if((gzL($,0,0)|0)==0){break}else{ae=1}i=e;return ae|0}}while(0);$=(c[2385798]|0)+16384|0;if((c[3542200]|0)==0){ae=1;i=e;return ae|0}ah=W+108|0;c[ah>>2]=0;af=W+100|0;c[af>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](W,1)|0;do{if((c[ah>>2]|0)!=0){ai=c[af>>2]|0;c[X>>2]=9534384;aj=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aj&16383](X,1,0)|0;if((ai|0)<1){ae=1;i=e;return ae|0}if((gzL($,0,1)|0)==0){break}else{ae=1}i=e;return ae|0}}while(0);$=(c[3527098]|0)+40960|0;if((c[3542200]|0)==0){ae=1;i=e;return ae|0}af=U+108|0;c[af>>2]=0;ah=U+100|0;c[ah>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](U,2)|0;do{if((c[af>>2]|0)!=0){ai=c[ah>>2]|0;c[V>>2]=9534384;aj=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aj&16383](V,2,0)|0;if((ai|0)<1){ae=1;i=e;return ae|0}if((gzL($,0,2)|0)==0){break}else{ae=1}i=e;return ae|0}}while(0);$=c[3529012]|0;gGz($|0,0,24576);if((c[3542200]|0)==0){ae=1;i=e;return ae|0}ah=S+108|0;c[ah>>2]=0;af=S+100|0;c[af>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](S,3)|0;do{if((c[ah>>2]|0)!=0){ai=c[af>>2]|0;c[T>>2]=9534384;aj=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aj&16383](T,3,0)|0;if((ai|0)<1){ae=1;i=e;return ae|0}if((gzL($,0,3)|0)==0){break}else{ae=1}i=e;return ae|0}}while(0);$=(c[3529012]|0)+8192|0;if((c[3542200]|0)==0){ae=1;i=e;return ae|0}af=Q+108|0;c[af>>2]=0;ah=Q+100|0;c[ah>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](Q,4)|0;do{if((c[af>>2]|0)!=0){ai=c[ah>>2]|0;c[R>>2]=9534384;aj=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aj&16383](R,4,0)|0;if((ai|0)<1){ae=1;i=e;return ae|0}if((gzL($,0,4)|0)==0){break}else{ae=1}i=e;return ae|0}}while(0);$=(c[3529012]|0)+16384|0;if((c[3542200]|0)==0){ae=1;i=e;return ae|0}ah=O+108|0;c[ah>>2]=0;af=O+100|0;c[af>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](O,5)|0;do{if((c[ah>>2]|0)!=0){ai=c[af>>2]|0;c[P>>2]=9534384;aj=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aj&16383](P,5,0)|0;if((ai|0)<1){ae=1;i=e;return ae|0}if((gzL($,0,5)|0)==0){break}else{ae=1}i=e;return ae|0}}while(0);$=c[3527094]|0;af=c[2439464]|0;ah=c[2439462]|0;ai=c[3529012]|0;aj=c[2405764]|0;if(($|0)>0){ak=ag(ah,af)|0;al=(ah|0)<1|(af|0)<1;am=0;do{an=ag(am,ak)|0;gGz(aj+an|0,0,ak|0);ao=am<<8;if(!al){ap=0;do{aq=ao+(c[5299472+(ap<<2)>>2]|0)|0;ar=(ag(ap,af)|0)+an|0;as=0;do{at=aq+(c[5299512+(as<<2)>>2]|0)|0;if(((d[ai+((at|0)/8|0)|0]|0)&128>>>((at&7)>>>0)|0)!=0){at=aj+(ar+as)|0;a[at]=a[at]|4}as=as+1|0;}while((as|0)<(af|0));ap=ap+1|0;}while((ap|0)<(ah|0));ap=ao+65536|0;as=0;do{ar=ap+(c[5299472+(as<<2)>>2]|0)|0;aq=(ag(as,af)|0)+an|0;at=0;do{au=ar+(c[5299512+(at<<2)>>2]|0)|0;if(((d[ai+((au|0)/8|0)|0]|0)&128>>>((au&7)>>>0)|0)!=0){au=aj+(aq+at)|0;a[au]=a[au]|2}at=at+1|0;}while((at|0)<(af|0));as=as+1|0;}while((as|0)<(ah|0));as=ao+131072|0;ap=0;do{at=as+(c[5299472+(ap<<2)>>2]|0)|0;aq=(ag(ap,af)|0)+an|0;ar=0;do{au=at+(c[5299512+(ar<<2)>>2]|0)|0;if(((d[ai+((au|0)/8|0)|0]|0)&128>>>((au&7)>>>0)|0)!=0){au=aj+(aq+ar)|0;a[au]=a[au]|1}ar=ar+1|0;}while((ar|0)<(af|0));ap=ap+1|0;}while((ap|0)<(ah|0))}am=am+1|0;}while((am|0)<($|0))}gGz(ai|0,0,24576);if((c[3542200]|0)==0){ae=1;i=e;return ae|0}$=M+108|0;c[$>>2]=0;am=M+100|0;c[am>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](M,6)|0;do{if((c[$>>2]|0)!=0){ah=c[am>>2]|0;c[N>>2]=9534384;af=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[af&16383](N,6,0)|0;if((ah|0)<1){ae=1;i=e;return ae|0}if((gzL(ai,0,6)|0)==0){break}else{ae=1}i=e;return ae|0}}while(0);ai=(c[3529012]|0)+8192|0;if((c[3542200]|0)==0){ae=1;i=e;return ae|0}am=K+108|0;c[am>>2]=0;$=K+100|0;c[$>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](K,7)|0;do{if((c[am>>2]|0)!=0){ah=c[$>>2]|0;c[L>>2]=9534384;af=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[af&16383](L,7,0)|0;if((ah|0)<1){ae=1;i=e;return ae|0}if((gzL(ai,0,7)|0)==0){break}else{ae=1}i=e;return ae|0}}while(0);ai=(c[3529012]|0)+16384|0;if((c[3542200]|0)==0){ae=1;i=e;return ae|0}$=I+108|0;c[$>>2]=0;am=I+100|0;c[am>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](I,8)|0;do{if((c[$>>2]|0)!=0){ah=c[am>>2]|0;c[J>>2]=9534384;af=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[af&16383](J,8,0)|0;if((ah|0)<1){ae=1;i=e;return ae|0}if((gzL(ai,0,8)|0)==0){break}else{ae=1}i=e;return ae|0}}while(0);ai=c[2439452]|0;am=c[3529012]|0;$=c[3529014]|0;if((ai|0)>0){ah=0;do{af=ah<<8;gGz($+af|0,0,256);aj=af+131072|0;al=0;do{ak=aj+(c[609008+(al<<2)>>2]|0)|0;ap=(al<<4)+af|0;an=0;do{as=ak+(c[597864+(an<<2)>>2]|0)|0;if(((d[am+((as|0)/8|0)|0]|0)&128>>>((as&7)>>>0)|0)!=0){as=$+(ap+an)|0;a[as]=a[as]|4}an=an+1|0;}while((an|0)<16);al=al+1|0;}while((al|0)<16);al=af+65536|0;aj=0;while(1){an=al+(c[609008+(aj<<2)>>2]|0)|0;ap=(aj<<4)+af|0;ak=0;do{as=an+(c[597864+(ak<<2)>>2]|0)|0;if(((d[am+((as|0)/8|0)|0]|0)&128>>>((as&7)>>>0)|0)!=0){as=$+(ap+ak)|0;a[as]=a[as]|2}ak=ak+1|0;}while((ak|0)<16);ak=aj+1|0;if((ak|0)<16){aj=ak}else{av=0;break}}do{aj=af+(c[609008+(av<<2)>>2]|0)|0;al=(av<<4)+af|0;ak=0;do{ap=aj+(c[597864+(ak<<2)>>2]|0)|0;if(((d[am+((ap|0)/8|0)|0]|0)&128>>>((ap&7)>>>0)|0)!=0){ap=$+(al+ak)|0;a[ap]=a[ap]|1}ak=ak+1|0;}while((ak|0)<16);av=av+1|0;}while((av|0)<16);ah=ah+1|0;}while((ah|0)<(ai|0))}gGz(am|0,0,24576);if((c[3542200]|0)==0){ae=1;i=e;return ae|0}ai=G+108|0;c[ai>>2]=0;ah=G+100|0;c[ah>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](G,9)|0;do{if((c[ai>>2]|0)!=0){$=c[ah>>2]|0;c[H>>2]=9534384;af=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[af&16383](H,9,0)|0;if(($|0)<1){ae=1;i=e;return ae|0}if((gzL(am,0,9)|0)==0){break}else{ae=1}i=e;return ae|0}}while(0);am=(c[3529012]|0)+8192|0;if((c[3542200]|0)==0){ae=1;i=e;return ae|0}ah=E+108|0;c[ah>>2]=0;ai=E+100|0;c[ai>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](E,10)|0;do{if((c[ah>>2]|0)!=0){$=c[ai>>2]|0;c[F>>2]=9534384;af=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[af&16383](F,10,0)|0;if(($|0)<1){ae=1;i=e;return ae|0}if((gzL(am,0,10)|0)==0){break}else{ae=1}i=e;return ae|0}}while(0);am=(c[3529012]|0)+16384|0;if((c[3542200]|0)==0){ae=1;i=e;return ae|0}ai=C+108|0;c[ai>>2]=0;ah=C+100|0;c[ah>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](C,11)|0;do{if((c[ai>>2]|0)!=0){$=c[ah>>2]|0;c[D>>2]=9534384;af=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[af&16383](D,11,0)|0;if(($|0)<1){ae=1;i=e;return ae|0}if((gzL(am,0,11)|0)==0){break}else{ae=1}i=e;return ae|0}}while(0);am=c[3527096]|0;ah=c[2437648]|0;ai=c[2437646]|0;$=c[3529012]|0;af=c[2405778]|0;if((am|0)>0){ak=ag(ai,ah)|0;al=(ai|0)<1|(ah|0)<1;aj=0;do{ap=ag(aj,ak)|0;gGz(af+ap|0,0,ak|0);an=aj<<8;if(!al){as=0;do{ao=an+(c[5299472+(as<<2)>>2]|0)|0;ar=(ag(as,ah)|0)+ap|0;aq=0;do{at=ao+(c[5299512+(aq<<2)>>2]|0)|0;if(((d[$+((at|0)/8|0)|0]|0)&128>>>((at&7)>>>0)|0)!=0){at=af+(ar+aq)|0;a[at]=a[at]|4}aq=aq+1|0;}while((aq|0)<(ah|0));as=as+1|0;}while((as|0)<(ai|0));as=an+65536|0;aq=0;do{ar=as+(c[5299472+(aq<<2)>>2]|0)|0;ao=(ag(aq,ah)|0)+ap|0;at=0;do{au=ar+(c[5299512+(at<<2)>>2]|0)|0;if(((d[$+((au|0)/8|0)|0]|0)&128>>>((au&7)>>>0)|0)!=0){au=af+(ao+at)|0;a[au]=a[au]|2}at=at+1|0;}while((at|0)<(ah|0));aq=aq+1|0;}while((aq|0)<(ai|0));aq=an+131072|0;as=0;do{at=aq+(c[5299472+(as<<2)>>2]|0)|0;ao=(ag(as,ah)|0)+ap|0;ar=0;do{au=at+(c[5299512+(ar<<2)>>2]|0)|0;if(((d[$+((au|0)/8|0)|0]|0)&128>>>((au&7)>>>0)|0)!=0){au=af+(ao+ar)|0;a[au]=a[au]|1}ar=ar+1|0;}while((ar|0)<(ah|0));as=as+1|0;}while((as|0)<(ai|0))}aj=aj+1|0;}while((aj|0)<(am|0))}am=c[3527092]|0;if((c[3542200]|0)==0){ae=1;i=e;return ae|0}aj=A+108|0;c[aj>>2]=0;ai=A+100|0;c[ai>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](A,12)|0;do{if((c[aj>>2]|0)!=0){ah=c[ai>>2]|0;c[B>>2]=9534384;af=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[af&16383](B,12,0)|0;if((ah|0)<1){ae=1;i=e;return ae|0}if((gzL(am,0,12)|0)==0){break}else{ae=1}i=e;return ae|0}}while(0);am=(c[3527092]|0)+256|0;if((c[3542200]|0)==0){ae=1;i=e;return ae|0}ai=y+108|0;c[ai>>2]=0;aj=y+100|0;c[aj>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](y,13)|0;do{if((c[ai>>2]|0)!=0){ah=c[aj>>2]|0;c[z>>2]=9534384;af=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[af&16383](z,13,0)|0;if((ah|0)<1){ae=1;i=e;return ae|0}if((gzL(am,0,13)|0)==0){break}else{ae=1}i=e;return ae|0}}while(0);am=(c[3527092]|0)+512|0;if((c[3542200]|0)==0){ae=1;i=e;return ae|0}aj=w+108|0;c[aj>>2]=0;ai=w+100|0;c[ai>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](w,14)|0;do{if((c[aj>>2]|0)!=0){ah=c[ai>>2]|0;c[x>>2]=9534384;af=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[af&16383](x,14,0)|0;if((ah|0)<1){ae=1;i=e;return ae|0}if((gzL(am,0,14)|0)==0){break}else{ae=1}i=e;return ae|0}}while(0);am=(c[3527092]|0)+768|0;if((c[3542200]|0)==0){ae=1;i=e;return ae|0}ai=u+108|0;c[ai>>2]=0;aj=u+100|0;c[aj>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](u,15)|0;do{if((c[ai>>2]|0)!=0){ah=c[aj>>2]|0;c[v>>2]=9534384;af=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[af&16383](v,15,0)|0;if((ah|0)<1){ae=1;i=e;return ae|0}if((gzL(am,0,15)|0)==0){break}else{ae=1}i=e;return ae|0}}while(0);am=(c[3527092]|0)+1024|0;if((c[3542200]|0)==0){ae=1;i=e;return ae|0}aj=s+108|0;c[aj>>2]=0;ai=s+100|0;c[ai>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](s,16)|0;do{if((c[aj>>2]|0)!=0){ah=c[ai>>2]|0;c[t>>2]=9534384;af=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[af&16383](t,16,0)|0;if((ah|0)<1){ae=1;i=e;return ae|0}if((gzL(am,0,16)|0)==0){break}else{ae=1}i=e;return ae|0}}while(0);am=(c[3527092]|0)+1280|0;if((c[3542200]|0)==0){ae=1;i=e;return ae|0}ai=q+108|0;c[ai>>2]=0;aj=q+100|0;c[aj>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](q,17)|0;do{if((c[ai>>2]|0)!=0){ah=c[aj>>2]|0;c[r>>2]=9534384;af=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[af&16383](r,17,0)|0;if((ah|0)<1){ae=1;i=e;return ae|0}if((gzL(am,0,17)|0)==0){break}else{ae=1}i=e;return ae|0}}while(0);am=(c[3527092]|0)+1536|0;if((c[3542200]|0)==0){ae=1;i=e;return ae|0}aj=o+108|0;c[aj>>2]=0;ai=o+100|0;c[ai>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](o,18)|0;do{if((c[aj>>2]|0)!=0){ah=c[ai>>2]|0;c[p>>2]=9534384;af=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[af&16383](p,18,0)|0;if((ah|0)<1){ae=1;i=e;return ae|0}if((gzL(am,0,18)|0)==0){break}else{ae=1}i=e;return ae|0}}while(0);am=(c[3527092]|0)+1792|0;if((c[3542200]|0)==0){ae=1;i=e;return ae|0}ai=m+108|0;c[ai>>2]=0;aj=m+100|0;c[aj>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,19)|0;do{if((c[ai>>2]|0)!=0){ah=c[aj>>2]|0;c[n>>2]=9534384;af=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[af&16383](n,19,0)|0;if((ah|0)<1){ae=1;i=e;return ae|0}if((gzL(am,0,19)|0)==0){break}else{ae=1}i=e;return ae|0}}while(0);am=(c[3527092]|0)+2048|0;if((c[3542200]|0)==0){ae=1;i=e;return ae|0}aj=k+108|0;c[aj>>2]=0;ai=k+100|0;c[ai>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,20)|0;do{if((c[aj>>2]|0)!=0){ah=c[ai>>2]|0;c[l>>2]=9534384;af=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[af&16383](l,20,0)|0;if((ah|0)<1){ae=1;i=e;return ae|0}if((gzL(am,0,20)|0)==0){break}else{ae=1}i=e;return ae|0}}while(0);am=(c[3527092]|0)+2304|0;if((c[3542200]|0)==0){ae=1;i=e;return ae|0}ai=h+108|0;c[ai>>2]=0;aj=h+100|0;c[aj>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](h,21)|0;do{if((c[ai>>2]|0)!=0){ah=c[aj>>2]|0;c[j>>2]=9534384;af=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[af&16383](j,21,0)|0;if((ah|0)<1){ae=1;i=e;return ae|0}if((gzL(am,0,21)|0)==0){break}else{ae=1}i=e;return ae|0}}while(0);am=(c[3527092]|0)+2336|0;if((c[3542200]|0)==0){ae=1;i=e;return ae|0}aj=f+108|0;c[aj>>2]=0;ai=f+100|0;c[ai>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,22)|0;do{if((c[aj>>2]|0)!=0){ah=c[ai>>2]|0;c[g>>2]=9534384;af=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[af&16383](g,22,0)|0;if((ah|0)<1){ae=1;i=e;return ae|0}if((gzL(am,0,22)|0)==0){break}else{ae=1}i=e;return ae|0}}while(0);am=c[3529012]|0;ai=0;while(1){if((ai|0)>=1024){break}aw=9638528+(ai<<2)|0;if((c[aw>>2]|0)==(am|0)){ab=54607;break}else{ai=ai+1|0}}if((ab|0)==54607){gGr(am);c[aw>>2]=0}c[3529012]=0;a9H();ai=c[2439330]|0;aj=(ai|0)==0;if(!aj){ah=ai;gGC(9706056,ah|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];ah=c[3528484]|0;c[2076596]=ah;af=c[2417276]|0;c[3541536]=af;c[1836236]=0;$=c[3529018]|0;c[ai+716>>2]=$;c[ai+720>>2]=$+256;c[ai+724>>2]=$+512;c[ai+728>>2]=$+768;c[ai+732>>2]=$+1024;c[ai+736>>2]=$+1280;c[ai+740>>2]=$+1536;c[ai+744>>2]=$+1792;c[ai+748>>2]=$+2048;c[ai+752>>2]=$+2304;c[ai+756>>2]=$+2560;c[ai+760>>2]=$+2816;c[ai+764>>2]=$+3072;c[ai+768>>2]=$+3328;c[ai+772>>2]=$+3584;c[ai+776>>2]=$+3840;al=160;ak=160;while(1){c[ai+76+(ak+256<<2)>>2]=$+((ak<<8)-40960);as=al+1&65535;if((as&65535)>175){ax=160;ay=160;break}else{al=as;ak=as&65535}}while(1){ak=$+((ay<<8)-40960)|0;c[ai+76+(ay+512<<2)>>2]=ak;c[ai+76+(ay+768<<2)>>2]=ak;ak=ax+1&65535;if((ak&65535)>175){break}else{ax=ak;ay=ak&65535}}if(!aj){$=ai;gGC($|0,9706056,76)|0}$=c[2433530]|0;c[2438118]=$;c[3528484]=ah;c[2417276]=af;c[1836236]=-1;c[2431670]=6556;c[2426980]=2;c[2426982]=148;if(aj){c[2433530]=$;c[2076596]=ah;c[3541536]=af;c[1836236]=0;gGz(9706056,0,76)}else{ak=ai;gGC(9706056,ak|0,76)|0;c[2433530]=$;c[2076596]=ah;c[3541536]=af;c[1836236]=0;gGz(9706056,0,76);ak=ai;gGC(ak|0,9706056,76)|0}c[2438118]=$;c[3528484]=ah;c[2417276]=af;c[1836236]=-1;a[9660900]=a[9660900]|16;$=c[2437644]|0;ak=c[$+1092>>2]|0;do{if((ak|0)==0){al=c[$+3144>>2]|0;if((al|0)==0){az=0;aA=0;break}am=gj[al&4095](-2)|0;al=c[2437644]|0;as=c[al+1092>>2]|0;ap=(am&255)<<8;if((as|0)!=0){aB=as;aC=ap;ab=54622;break}as=c[al+3144>>2]|0;if((as|0)==0){az=0;aA=ap;break}az=gj[as&4095](-1)|0;aA=ap}else{aB=ak;aC=(d[ak+254|0]|0)<<8;ab=54622}}while(0);if((ab|0)==54622){az=a[aB+255|0]|0;aA=aC}ak=az&255|aA;c[2415221]=ak;b[4830442]=ak&65535;a[9660920]=0;a[9660921]=0;a[9660928]=0;a[9660930]=0;a[9660931]=0;c[2415234]=0;gGz(9660901,0,5);c[2415235]=65535;c[2415237]=65535;a[9660932]=a[9660932]|64;mB(0);mB(1);UA();c[2429502]=0;c[2429500]=0;c[2438664]=0;c[2439460]=0;a[9757800]=0;a[9623080]=0;a[9623072]=0;a[683232]=0;a[9754673]=0;a[9754672]=0;a[9754680]=0;a[9718896]=0;a[9717272]=0;a[9718824]=0;ae=0;i=e;return ae|0}}while(0);c[2426820]=0;ae=1;i=e;return ae|0}function a9e(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>33){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5328572+(b*112|0)>>2];c[a+104>>2]=c[5328576+(b*112|0)>>2];c[a+108>>2]=c[5328580+(b*112|0)>>2];d=0;return d|0}function a9f(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<34&(d|0)==0)){e=1;return e|0}c[a>>2]=5328472+(b*112|0);e=0;return e|0}function a9g(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>87){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5332280+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function a9h(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0;b=i;i=i+3960|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;l=b+360|0;m=b+472|0;n=b+480|0;o=b+592|0;p=b+600|0;q=b+712|0;r=b+720|0;s=b+832|0;t=b+840|0;u=b+952|0;v=b+960|0;w=b+1072|0;x=b+1080|0;y=b+1192|0;z=b+1200|0;A=b+1312|0;B=b+1320|0;C=b+1432|0;D=b+1440|0;E=b+1552|0;F=b+1560|0;G=b+1672|0;H=b+1680|0;I=b+1792|0;J=b+1800|0;K=b+1912|0;L=b+1920|0;M=b+2032|0;N=b+2040|0;O=b+2152|0;P=b+2160|0;Q=b+2272|0;R=b+2280|0;S=b+2392|0;T=b+2400|0;U=b+2512|0;V=b+2520|0;W=b+2632|0;X=b+2640|0;Y=b+2752|0;Z=b+2760|0;_=b+2872|0;$=b+2880|0;aa=b+2992|0;ab=b+3e3|0;ac=b+3112|0;ad=b+3120|0;ae=b+3232|0;af=b+3240|0;ah=b+3352|0;ai=b+3360|0;aj=b+3472|0;ak=b+3480|0;al=b+3592|0;am=b+3600|0;an=b+3712|0;ao=b+3720|0;ap=b+3832|0;aq=b+3840|0;ar=b+3952|0;c[2439448]=163840;c[3527090]=1824;c[3527094]=4096;c[2439452]=2048;c[3527096]=1024;c[2438666]=4096;c[2439464]=8;c[2439462]=8;c[2437648]=12;c[2437646]=8;c[2431672]=c[(c[642608+(c[2436]<<2)>>2]|0)+124>>2];c[2426820]=0;a9Q();as=c[2414438]|0;at=0;while(1){if((at|0)>=1024){break}au=9638528+(at<<2)|0;if((c[au>>2]|0)==0){av=54755;break}else{at=at+1|0}}do{if((av|0)==54755){at=gGq(as)|0;c[au>>2]=at;if((at|0)==0){break}gGz(at|0,0,as|0);c[2426820]=at;gGz(at|0,0,as|0);a9Q();at=0;while(1){if((at|0)>=1024){aw=0;break}ax=9638528+(at<<2)|0;if((c[ax>>2]|0)==0){av=54760;break}else{at=at+1|0}}do{if((av|0)==54760){at=gGq(196608)|0;c[ax>>2]=at;if((at|0)==0){aw=0;break}gGz(at|0,0,196608);aw=at}}while(0);c[3529012]=aw;at=c[2385798]|0;if((c[3542200]|0)==0){ay=1;i=b;return ay|0}az=aq+108|0;c[az>>2]=0;aA=aq+100|0;c[aA>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](aq,0)|0;do{if((c[az>>2]|0)!=0){aB=c[aA>>2]|0;c[ar>>2]=9534384;aC=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aC&16383](ar,0,0)|0;if((aB|0)<1){ay=1;i=b;return ay|0}if((gzL(at,0,0)|0)==0){break}else{ay=1}i=b;return ay|0}}while(0);at=(c[2385798]|0)+16384|0;if((c[3542200]|0)==0){ay=1;i=b;return ay|0}aA=ao+108|0;c[aA>>2]=0;az=ao+100|0;c[az>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](ao,1)|0;do{if((c[aA>>2]|0)!=0){aB=c[az>>2]|0;c[ap>>2]=9534384;aC=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aC&16383](ap,1,0)|0;if((aB|0)<1){ay=1;i=b;return ay|0}if((gzL(at,0,1)|0)==0){break}else{ay=1}i=b;return ay|0}}while(0);at=(c[2385798]|0)+32768|0;if((c[3542200]|0)==0){ay=1;i=b;return ay|0}az=am+108|0;c[az>>2]=0;aA=am+100|0;c[aA>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](am,2)|0;do{if((c[az>>2]|0)!=0){aB=c[aA>>2]|0;c[an>>2]=9534384;aC=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aC&16383](an,2,0)|0;if((aB|0)<1){ay=1;i=b;return ay|0}if((gzL(at,0,2)|0)==0){break}else{ay=1}i=b;return ay|0}}while(0);at=(c[2385798]|0)+65536|0;if((c[3542200]|0)==0){ay=1;i=b;return ay|0}aA=ak+108|0;c[aA>>2]=0;az=ak+100|0;c[az>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](ak,3)|0;do{if((c[aA>>2]|0)!=0){aB=c[az>>2]|0;c[al>>2]=9534384;aC=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aC&16383](al,3,0)|0;if((aB|0)<1){ay=1;i=b;return ay|0}if((gzL(at,0,3)|0)==0){break}else{ay=1}i=b;return ay|0}}while(0);at=c[2385798]|0;az=at+131072|0;aA=at+98304|0;gGC(az|0,aA|0,32768)|0;aA=c[3527098]|0;if((c[3542200]|0)==0){ay=1;i=b;return ay|0}az=ai+108|0;c[az>>2]=0;at=ai+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](ai,4)|0;do{if((c[az>>2]|0)!=0){aB=c[at>>2]|0;c[aj>>2]=9534384;aC=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aC&16383](aj,4,0)|0;if((aB|0)<1){ay=1;i=b;return ay|0}if((gzL(aA,0,4)|0)==0){break}else{ay=1}i=b;return ay|0}}while(0);aA=(c[3527098]|0)+16384|0;if((c[3542200]|0)==0){ay=1;i=b;return ay|0}at=af+108|0;c[at>>2]=0;az=af+100|0;c[az>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](af,5)|0;do{if((c[at>>2]|0)!=0){aB=c[az>>2]|0;c[ah>>2]=9534384;aC=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aC&16383](ah,5,0)|0;if((aB|0)<1){ay=1;i=b;return ay|0}if((gzL(aA,0,5)|0)==0){break}else{ay=1}i=b;return ay|0}}while(0);aA=(c[3527098]|0)+32768|0;if((c[3542200]|0)==0){ay=1;i=b;return ay|0}az=ad+108|0;c[az>>2]=0;at=ad+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](ad,6)|0;do{if((c[az>>2]|0)!=0){aB=c[at>>2]|0;c[ae>>2]=9534384;aC=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aC&16383](ae,6,0)|0;if((aB|0)<1){ay=1;i=b;return ay|0}if((gzL(aA,0,6)|0)==0){break}else{ay=1}i=b;return ay|0}}while(0);aA=c[3529012]|0;gGz(aA|0,0,196608);if((c[3542200]|0)==0){ay=1;i=b;return ay|0}at=ab+108|0;c[at>>2]=0;az=ab+100|0;c[az>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](ab,7)|0;do{if((c[at>>2]|0)!=0){aB=c[az>>2]|0;c[ac>>2]=9534384;aC=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aC&16383](ac,7,0)|0;if((aB|0)<1){ay=1;i=b;return ay|0}if((gzL(aA,0,7)|0)==0){break}else{ay=1}i=b;return ay|0}}while(0);aA=(c[3529012]|0)+32768|0;if((c[3542200]|0)==0){ay=1;i=b;return ay|0}az=$+108|0;c[az>>2]=0;at=$+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383]($,8)|0;do{if((c[az>>2]|0)!=0){aB=c[at>>2]|0;c[aa>>2]=9534384;aC=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aC&16383](aa,8,0)|0;if((aB|0)<1){ay=1;i=b;return ay|0}if((gzL(aA,0,8)|0)==0){break}else{ay=1}i=b;return ay|0}}while(0);aA=(c[3529012]|0)+65536|0;if((c[3542200]|0)==0){ay=1;i=b;return ay|0}at=Z+108|0;c[at>>2]=0;az=Z+100|0;c[az>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](Z,9)|0;do{if((c[at>>2]|0)!=0){aB=c[az>>2]|0;c[_>>2]=9534384;aC=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aC&16383](_,9,0)|0;if((aB|0)<1){ay=1;i=b;return ay|0}if((gzL(aA,0,9)|0)==0){break}else{ay=1}i=b;return ay|0}}while(0);aA=c[3527094]|0;az=c[2439464]|0;at=c[2439462]|0;aB=c[3529012]|0;aC=c[2405764]|0;if((aA|0)>0){aD=ag(at,az)|0;aE=(at|0)<1|(az|0)<1;aF=0;do{aG=ag(aF,aD)|0;gGz(aC+aG|0,0,aD|0);aH=aF<<6;aI=aH+524288|0;if(!aE){aJ=0;do{aK=aI+(c[1238464+(aJ<<2)>>2]|0)|0;aL=(ag(aJ,az)|0)+aG|0;aM=0;do{aN=aK+(c[614800+(aM<<2)>>2]|0)|0;if(((d[aB+((aN|0)/8|0)|0]|0)&128>>>((aN&7)>>>0)|0)!=0){aN=aC+(aL+aM)|0;a[aN]=a[aN]|4}aM=aM+1|0;}while((aM|0)<(az|0));aJ=aJ+1|0;}while((aJ|0)<(at|0));aJ=aH+262144|0;aI=0;while(1){aM=aJ+(c[1238464+(aI<<2)>>2]|0)|0;aL=(ag(aI,az)|0)+aG|0;aK=0;do{aN=aM+(c[614800+(aK<<2)>>2]|0)|0;if(((d[aB+((aN|0)/8|0)|0]|0)&128>>>((aN&7)>>>0)|0)!=0){aN=aC+(aL+aK)|0;a[aN]=a[aN]|2}aK=aK+1|0;}while((aK|0)<(az|0));aK=aI+1|0;if((aK|0)<(at|0)){aI=aK}else{aO=0;break}}do{aI=aH+(c[1238464+(aO<<2)>>2]|0)|0;aJ=(ag(aO,az)|0)+aG|0;aK=0;do{aL=aI+(c[614800+(aK<<2)>>2]|0)|0;if(((d[aB+((aL|0)/8|0)|0]|0)&128>>>((aL&7)>>>0)|0)!=0){aL=aC+(aJ+aK)|0;a[aL]=a[aL]|1}aK=aK+1|0;}while((aK|0)<(az|0));aO=aO+1|0;}while((aO|0)<(at|0))}aF=aF+1|0;}while((aF|0)<(aA|0))}gGz(aB|0,0,196608);if((c[3542200]|0)==0){ay=1;i=b;return ay|0}aA=X+108|0;c[aA>>2]=0;aF=X+100|0;c[aF>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](X,10)|0;do{if((c[aA>>2]|0)!=0){at=c[aF>>2]|0;c[Y>>2]=9534384;az=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[az&16383](Y,10,0)|0;if((at|0)<1){ay=1;i=b;return ay|0}if((gzL(aB,0,10)|0)==0){break}else{ay=1}i=b;return ay|0}}while(0);aB=(c[3529012]|0)+16384|0;if((c[3542200]|0)==0){ay=1;i=b;return ay|0}aF=V+108|0;c[aF>>2]=0;aA=V+100|0;c[aA>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](V,11)|0;do{if((c[aF>>2]|0)!=0){at=c[aA>>2]|0;c[W>>2]=9534384;az=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[az&16383](W,11,0)|0;if((at|0)<1){ay=1;i=b;return ay|0}if((gzL(aB,0,11)|0)==0){break}else{ay=1}i=b;return ay|0}}while(0);aB=(c[3529012]|0)+32768|0;if((c[3542200]|0)==0){ay=1;i=b;return ay|0}aA=T+108|0;c[aA>>2]=0;aF=T+100|0;c[aF>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](T,12)|0;do{if((c[aA>>2]|0)!=0){at=c[aF>>2]|0;c[U>>2]=9534384;az=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[az&16383](U,12,0)|0;if((at|0)<1){ay=1;i=b;return ay|0}if((gzL(aB,0,12)|0)==0){break}else{ay=1}i=b;return ay|0}}while(0);aB=(c[3529012]|0)+49152|0;if((c[3542200]|0)==0){ay=1;i=b;return ay|0}aF=R+108|0;c[aF>>2]=0;aA=R+100|0;c[aA>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](R,13)|0;do{if((c[aF>>2]|0)!=0){at=c[aA>>2]|0;c[S>>2]=9534384;az=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[az&16383](S,13,0)|0;if((at|0)<1){ay=1;i=b;return ay|0}if((gzL(aB,0,13)|0)==0){break}else{ay=1}i=b;return ay|0}}while(0);aB=(c[3529012]|0)+65536|0;if((c[3542200]|0)==0){ay=1;i=b;return ay|0}aA=P+108|0;c[aA>>2]=0;aF=P+100|0;c[aF>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](P,14)|0;do{if((c[aA>>2]|0)!=0){at=c[aF>>2]|0;c[Q>>2]=9534384;az=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[az&16383](Q,14,0)|0;if((at|0)<1){ay=1;i=b;return ay|0}if((gzL(aB,0,14)|0)==0){break}else{ay=1}i=b;return ay|0}}while(0);aB=(c[3529012]|0)+81920|0;if((c[3542200]|0)==0){ay=1;i=b;return ay|0}aF=N+108|0;c[aF>>2]=0;aA=N+100|0;c[aA>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](N,15)|0;do{if((c[aF>>2]|0)!=0){at=c[aA>>2]|0;c[O>>2]=9534384;az=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[az&16383](O,15,0)|0;if((at|0)<1){ay=1;i=b;return ay|0}if((gzL(aB,0,15)|0)==0){break}else{ay=1}i=b;return ay|0}}while(0);aB=(c[3529012]|0)+98304|0;if((c[3542200]|0)==0){ay=1;i=b;return ay|0}aA=L+108|0;c[aA>>2]=0;aF=L+100|0;c[aF>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](L,16)|0;do{if((c[aA>>2]|0)!=0){at=c[aF>>2]|0;c[M>>2]=9534384;az=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[az&16383](M,16,0)|0;if((at|0)<1){ay=1;i=b;return ay|0}if((gzL(aB,0,16)|0)==0){break}else{ay=1}i=b;return ay|0}}while(0);aB=(c[3529012]|0)+114688|0;if((c[3542200]|0)==0){ay=1;i=b;return ay|0}aF=J+108|0;c[aF>>2]=0;aA=J+100|0;c[aA>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](J,17)|0;do{if((c[aF>>2]|0)!=0){at=c[aA>>2]|0;c[K>>2]=9534384;az=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[az&16383](K,17,0)|0;if((at|0)<1){ay=1;i=b;return ay|0}if((gzL(aB,0,17)|0)==0){break}else{ay=1}i=b;return ay|0}}while(0);aB=(c[3529012]|0)+131072|0;if((c[3542200]|0)==0){ay=1;i=b;return ay|0}aA=H+108|0;c[aA>>2]=0;aF=H+100|0;c[aF>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](H,18)|0;do{if((c[aA>>2]|0)!=0){at=c[aF>>2]|0;c[I>>2]=9534384;az=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[az&16383](I,18,0)|0;if((at|0)<1){ay=1;i=b;return ay|0}if((gzL(aB,0,18)|0)==0){break}else{ay=1}i=b;return ay|0}}while(0);aB=(c[3529012]|0)+147456|0;if((c[3542200]|0)==0){ay=1;i=b;return ay|0}aF=F+108|0;c[aF>>2]=0;aA=F+100|0;c[aA>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](F,19)|0;do{if((c[aF>>2]|0)!=0){at=c[aA>>2]|0;c[G>>2]=9534384;az=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[az&16383](G,19,0)|0;if((at|0)<1){ay=1;i=b;return ay|0}if((gzL(aB,0,19)|0)==0){break}else{ay=1}i=b;return ay|0}}while(0);aB=(c[3529012]|0)+163840|0;if((c[3542200]|0)==0){ay=1;i=b;return ay|0}aA=D+108|0;c[aA>>2]=0;aF=D+100|0;c[aF>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](D,20)|0;do{if((c[aA>>2]|0)!=0){at=c[aF>>2]|0;c[E>>2]=9534384;az=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[az&16383](E,20,0)|0;if((at|0)<1){ay=1;i=b;return ay|0}if((gzL(aB,0,20)|0)==0){break}else{ay=1}i=b;return ay|0}}while(0);aB=(c[3529012]|0)+180224|0;if((c[3542200]|0)==0){ay=1;i=b;return ay|0}aF=B+108|0;c[aF>>2]=0;aA=B+100|0;c[aA>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](B,21)|0;do{if((c[aF>>2]|0)!=0){at=c[aA>>2]|0;c[C>>2]=9534384;az=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[az&16383](C,21,0)|0;if((at|0)<1){ay=1;i=b;return ay|0}if((gzL(aB,0,21)|0)==0){break}else{ay=1}i=b;return ay|0}}while(0);aB=c[2439452]|0;aA=c[3529012]|0;aF=c[3529014]|0;if((aB|0)>0){at=0;do{az=at<<8;gGz(aF+az|0,0,256);aC=az+1048576|0;aE=0;do{aD=aC+(c[609008+(aE<<2)>>2]|0)|0;aG=(aE<<4)+az|0;aH=0;do{aK=aD+(c[597864+(aH<<2)>>2]|0)|0;if(((d[aA+((aK|0)/8|0)|0]|0)&128>>>((aK&7)>>>0)|0)!=0){aK=aF+(aG+aH)|0;a[aK]=a[aK]|4}aH=aH+1|0;}while((aH|0)<16);aE=aE+1|0;}while((aE|0)<16);aE=az+524288|0;aC=0;while(1){aH=aE+(c[609008+(aC<<2)>>2]|0)|0;aG=(aC<<4)+az|0;aD=0;do{aK=aH+(c[597864+(aD<<2)>>2]|0)|0;if(((d[aA+((aK|0)/8|0)|0]|0)&128>>>((aK&7)>>>0)|0)!=0){aK=aF+(aG+aD)|0;a[aK]=a[aK]|2}aD=aD+1|0;}while((aD|0)<16);aD=aC+1|0;if((aD|0)<16){aC=aD}else{aP=0;break}}do{aC=az+(c[609008+(aP<<2)>>2]|0)|0;aE=(aP<<4)+az|0;aD=0;do{aG=aC+(c[597864+(aD<<2)>>2]|0)|0;if(((d[aA+((aG|0)/8|0)|0]|0)&128>>>((aG&7)>>>0)|0)!=0){aG=aF+(aE+aD)|0;a[aG]=a[aG]|1}aD=aD+1|0;}while((aD|0)<16);aP=aP+1|0;}while((aP|0)<16);at=at+1|0;}while((at|0)<(aB|0))}gGz(aA|0,0,196608);if((c[3542200]|0)==0){ay=1;i=b;return ay|0}aB=z+108|0;c[aB>>2]=0;at=z+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,22)|0;do{if((c[aB>>2]|0)!=0){aF=c[at>>2]|0;c[A>>2]=9534384;az=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[az&16383](A,22,0)|0;if((aF|0)<1){ay=1;i=b;return ay|0}if((gzL(aA,0,22)|0)==0){break}else{ay=1}i=b;return ay|0}}while(0);aA=(c[3529012]|0)+16384|0;if((c[3542200]|0)==0){ay=1;i=b;return ay|0}at=x+108|0;c[at>>2]=0;aB=x+100|0;c[aB>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,23)|0;do{if((c[at>>2]|0)!=0){aF=c[aB>>2]|0;c[y>>2]=9534384;az=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[az&16383](y,23,0)|0;if((aF|0)<1){ay=1;i=b;return ay|0}if((gzL(aA,0,23)|0)==0){break}else{ay=1}i=b;return ay|0}}while(0);aA=(c[3529012]|0)+32768|0;if((c[3542200]|0)==0){ay=1;i=b;return ay|0}aB=v+108|0;c[aB>>2]=0;at=v+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,24)|0;do{if((c[aB>>2]|0)!=0){aF=c[at>>2]|0;c[w>>2]=9534384;az=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[az&16383](w,24,0)|0;if((aF|0)<1){ay=1;i=b;return ay|0}if((gzL(aA,0,24)|0)==0){break}else{ay=1}i=b;return ay|0}}while(0);aA=c[3527096]|0;at=c[2437648]|0;aB=c[2437646]|0;aF=c[3529012]|0;az=c[2405778]|0;if((aA|0)>0){aD=ag(aB,at)|0;aE=(aB|0)<1|(at|0)<1;aC=0;do{aG=ag(aC,aD)|0;gGz(az+aG|0,0,aD|0);aH=aC<<7;if(!aE){aK=0;do{aJ=aH+(c[1238464+(aK<<2)>>2]|0)|0;aI=(ag(aK,at)|0)+aG|0;aL=0;do{aM=aJ+(c[3836464+(aL<<2)>>2]|0)|0;if(((d[aF+((aM|0)/8|0)|0]|0)&128>>>((aM&7)>>>0)|0)!=0){aM=az+(aI+aL)|0;a[aM]=a[aM]|4}aL=aL+1|0;}while((aL|0)<(at|0));aK=aK+1|0;}while((aK|0)<(aB|0));aK=aH+131072|0;aL=0;do{aI=aK+(c[1238464+(aL<<2)>>2]|0)|0;aJ=(ag(aL,at)|0)+aG|0;aM=0;do{aN=aI+(c[3836464+(aM<<2)>>2]|0)|0;if(((d[aF+((aN|0)/8|0)|0]|0)&128>>>((aN&7)>>>0)|0)!=0){aN=az+(aJ+aM)|0;a[aN]=a[aN]|2}aM=aM+1|0;}while((aM|0)<(at|0));aL=aL+1|0;}while((aL|0)<(aB|0));aL=aH+262144|0;aK=0;do{aM=aL+(c[1238464+(aK<<2)>>2]|0)|0;aJ=(ag(aK,at)|0)+aG|0;aI=0;do{aN=aM+(c[3836464+(aI<<2)>>2]|0)|0;if(((d[aF+((aN|0)/8|0)|0]|0)&128>>>((aN&7)>>>0)|0)!=0){aN=az+(aJ+aI)|0;a[aN]=a[aN]|1}aI=aI+1|0;}while((aI|0)<(at|0));aK=aK+1|0;}while((aK|0)<(aB|0))}aC=aC+1|0;}while((aC|0)<(aA|0))}aA=c[3527092]|0;if((c[3542200]|0)==0){ay=1;i=b;return ay|0}aC=t+108|0;c[aC>>2]=0;aB=t+100|0;c[aB>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,25)|0;do{if((c[aC>>2]|0)!=0){at=c[aB>>2]|0;c[u>>2]=9534384;az=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[az&16383](u,25,0)|0;if((at|0)<1){ay=1;i=b;return ay|0}if((gzL(aA,0,25)|0)==0){break}else{ay=1}i=b;return ay|0}}while(0);aA=(c[3527092]|0)+256|0;if((c[3542200]|0)==0){ay=1;i=b;return ay|0}aB=r+108|0;c[aB>>2]=0;aC=r+100|0;c[aC>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,26)|0;do{if((c[aB>>2]|0)!=0){at=c[aC>>2]|0;c[s>>2]=9534384;az=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[az&16383](s,26,0)|0;if((at|0)<1){ay=1;i=b;return ay|0}if((gzL(aA,0,26)|0)==0){break}else{ay=1}i=b;return ay|0}}while(0);aA=(c[3527092]|0)+512|0;if((c[3542200]|0)==0){ay=1;i=b;return ay|0}aC=p+108|0;c[aC>>2]=0;aB=p+100|0;c[aB>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,27)|0;do{if((c[aC>>2]|0)!=0){at=c[aB>>2]|0;c[q>>2]=9534384;az=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[az&16383](q,27,0)|0;if((at|0)<1){ay=1;i=b;return ay|0}if((gzL(aA,0,27)|0)==0){break}else{ay=1}i=b;return ay|0}}while(0);aA=(c[3527092]|0)+768|0;if((c[3542200]|0)==0){ay=1;i=b;return ay|0}aB=n+108|0;c[aB>>2]=0;aC=n+100|0;c[aC>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,28)|0;do{if((c[aB>>2]|0)!=0){at=c[aC>>2]|0;c[o>>2]=9534384;az=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[az&16383](o,28,0)|0;if((at|0)<1){ay=1;i=b;return ay|0}if((gzL(aA,0,28)|0)==0){break}else{ay=1}i=b;return ay|0}}while(0);aA=(c[3527092]|0)+1024|0;if((c[3542200]|0)==0){ay=1;i=b;return ay|0}aC=l+108|0;c[aC>>2]=0;aB=l+100|0;c[aB>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,29)|0;do{if((c[aC>>2]|0)!=0){at=c[aB>>2]|0;c[m>>2]=9534384;az=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[az&16383](m,29,0)|0;if((at|0)<1){ay=1;i=b;return ay|0}if((gzL(aA,0,29)|0)==0){break}else{ay=1}i=b;return ay|0}}while(0);aA=(c[3527092]|0)+1280|0;if((c[3542200]|0)==0){ay=1;i=b;return ay|0}aB=j+108|0;c[aB>>2]=0;aC=j+100|0;c[aC>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,30)|0;do{if((c[aB>>2]|0)!=0){at=c[aC>>2]|0;c[k>>2]=9534384;az=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[az&16383](k,30,0)|0;if((at|0)<1){ay=1;i=b;return ay|0}if((gzL(aA,0,30)|0)==0){break}else{ay=1}i=b;return ay|0}}while(0);aA=(c[3527092]|0)+1536|0;if((c[3542200]|0)==0){ay=1;i=b;return ay|0}aC=g+108|0;c[aC>>2]=0;aB=g+100|0;c[aB>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,31)|0;do{if((c[aC>>2]|0)!=0){at=c[aB>>2]|0;c[h>>2]=9534384;az=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[az&16383](h,31,0)|0;if((at|0)<1){ay=1;i=b;return ay|0}if((gzL(aA,0,31)|0)==0){break}else{ay=1}i=b;return ay|0}}while(0);aA=(c[3527092]|0)+1568|0;if((c[3542200]|0)==0){ay=1;i=b;return ay|0}aB=e+108|0;c[aB>>2]=0;aC=e+100|0;c[aC>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,32)|0;do{if((c[aB>>2]|0)!=0){at=c[aC>>2]|0;c[f>>2]=9534384;az=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[az&16383](f,32,0)|0;if((at|0)<1){ay=1;i=b;return ay|0}if((gzL(aA,0,32)|0)==0){break}else{ay=1}i=b;return ay|0}}while(0);aA=c[3529012]|0;aC=0;while(1){if((aC|0)>=1024){break}aQ=9638528+(aC<<2)|0;if((c[aQ>>2]|0)==(aA|0)){av=54923;break}else{aC=aC+1|0}}if((av|0)==54923){gGr(aA);c[aQ>>2]=0}c[3529012]=0;a9_();ay=0;i=b;return ay|0}}while(0);c[2426820]=0;ay=1;i=b;return ay|0}function a9i(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>33){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3832756+(b*112|0)>>2];c[a+104>>2]=c[3832760+(b*112|0)>>2];c[a+108>>2]=c[3832764+(b*112|0)>>2];d=0;return d|0}function a9j(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<34&(d|0)==0)){e=1;return e|0}c[a>>2]=3832656+(b*112|0);e=0;return e|0}function a9k(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>33){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3199556+(b*112|0)>>2];c[a+104>>2]=c[3199560+(b*112|0)>>2];c[a+108>>2]=c[3199564+(b*112|0)>>2];d=0;return d|0}function a9l(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<34&(d|0)==0)){e=1;return e|0}c[a>>2]=3199456+(b*112|0);e=0;return e|0}function a9m(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>26){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5304276+(b*112|0)>>2];c[a+104>>2]=c[5304280+(b*112|0)>>2];c[a+108>>2]=c[5304284+(b*112|0)>>2];d=0;return d|0}function a9n(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<27&(d|0)==0)){e=1;return e|0}c[a>>2]=5304176+(b*112|0);e=0;return e|0}function a9o(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0;b=i;i=i+3120|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;l=b+360|0;m=b+472|0;n=b+480|0;o=b+592|0;p=b+600|0;q=b+712|0;r=b+720|0;s=b+832|0;t=b+840|0;u=b+952|0;v=b+960|0;w=b+1072|0;x=b+1080|0;y=b+1192|0;z=b+1200|0;A=b+1312|0;B=b+1320|0;C=b+1432|0;D=b+1440|0;E=b+1552|0;F=b+1560|0;G=b+1672|0;H=b+1680|0;I=b+1792|0;J=b+1800|0;K=b+1912|0;L=b+1920|0;M=b+2032|0;N=b+2040|0;O=b+2152|0;P=b+2160|0;Q=b+2272|0;R=b+2280|0;S=b+2392|0;T=b+2400|0;U=b+2512|0;V=b+2520|0;W=b+2632|0;X=b+2640|0;Y=b+2752|0;Z=b+2760|0;_=b+2872|0;$=b+2880|0;aa=b+2992|0;ab=b+3e3|0;ac=b+3112|0;c[2439448]=163840;c[3527090]=1824;c[3527094]=4096;c[2439452]=2048;c[3527096]=1024;c[2438666]=4096;c[2439464]=8;c[2439462]=8;c[2437648]=12;c[2437646]=8;c[2431672]=c[(c[642608+(c[2436]<<2)>>2]|0)+124>>2];c[2426820]=0;a9Q();ad=c[2414438]|0;ae=0;while(1){if((ae|0)>=1024){break}af=9638528+(ae<<2)|0;if((c[af>>2]|0)==0){ah=55100;break}else{ae=ae+1|0}}do{if((ah|0)==55100){ae=gGq(ad)|0;c[af>>2]=ae;if((ae|0)==0){break}gGz(ae|0,0,ad|0);c[2426820]=ae;gGz(ae|0,0,ad|0);a9Q();ae=0;while(1){if((ae|0)>=1024){ai=0;break}aj=9638528+(ae<<2)|0;if((c[aj>>2]|0)==0){ah=55105;break}else{ae=ae+1|0}}do{if((ah|0)==55105){ae=gGq(196608)|0;c[aj>>2]=ae;if((ae|0)==0){ai=0;break}gGz(ae|0,0,196608);ai=ae}}while(0);c[3529012]=ai;ae=c[2385798]|0;if((c[3542200]|0)==0){ak=1;i=b;return ak|0}al=ab+108|0;c[al>>2]=0;am=ab+100|0;c[am>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](ab,0)|0;do{if((c[al>>2]|0)!=0){an=c[am>>2]|0;c[ac>>2]=9534384;ao=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ao&16383](ac,0,0)|0;if((an|0)<1){ak=1;i=b;return ak|0}if((gzL(ae,0,0)|0)==0){break}else{ak=1}i=b;return ak|0}}while(0);ae=(c[2385798]|0)+32768|0;if((c[3542200]|0)==0){ak=1;i=b;return ak|0}am=$+108|0;c[am>>2]=0;al=$+100|0;c[al>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383]($,1)|0;do{if((c[am>>2]|0)!=0){an=c[al>>2]|0;c[aa>>2]=9534384;ao=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ao&16383](aa,1,0)|0;if((an|0)<1){ak=1;i=b;return ak|0}if((gzL(ae,0,1)|0)==0){break}else{ak=1}i=b;return ak|0}}while(0);ae=(c[2385798]|0)+65536|0;if((c[3542200]|0)==0){ak=1;i=b;return ak|0}al=Z+108|0;c[al>>2]=0;am=Z+100|0;c[am>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](Z,2)|0;do{if((c[al>>2]|0)!=0){an=c[am>>2]|0;c[_>>2]=9534384;ao=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ao&16383](_,2,0)|0;if((an|0)<1){ak=1;i=b;return ak|0}if((gzL(ae,0,2)|0)==0){break}else{ak=1}i=b;return ak|0}}while(0);ae=c[3527098]|0;if((c[3542200]|0)==0){ak=1;i=b;return ak|0}am=X+108|0;c[am>>2]=0;al=X+100|0;c[al>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](X,3)|0;do{if((c[am>>2]|0)!=0){an=c[al>>2]|0;c[Y>>2]=9534384;ao=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ao&16383](Y,3,0)|0;if((an|0)<1){ak=1;i=b;return ak|0}if((gzL(ae,0,3)|0)==0){break}else{ak=1}i=b;return ak|0}}while(0);ae=(c[3527098]|0)+16384|0;if((c[3542200]|0)==0){ak=1;i=b;return ak|0}al=V+108|0;c[al>>2]=0;am=V+100|0;c[am>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](V,4)|0;do{if((c[al>>2]|0)!=0){an=c[am>>2]|0;c[W>>2]=9534384;ao=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ao&16383](W,4,0)|0;if((an|0)<1){ak=1;i=b;return ak|0}if((gzL(ae,0,4)|0)==0){break}else{ak=1}i=b;return ak|0}}while(0);ae=(c[3527098]|0)+32768|0;if((c[3542200]|0)==0){ak=1;i=b;return ak|0}am=T+108|0;c[am>>2]=0;al=T+100|0;c[al>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](T,5)|0;do{if((c[am>>2]|0)!=0){an=c[al>>2]|0;c[U>>2]=9534384;ao=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ao&16383](U,5,0)|0;if((an|0)<1){ak=1;i=b;return ak|0}if((gzL(ae,0,5)|0)==0){break}else{ak=1}i=b;return ak|0}}while(0);ae=c[3529012]|0;gGz(ae|0,0,196608);if((c[3542200]|0)==0){ak=1;i=b;return ak|0}al=R+108|0;c[al>>2]=0;am=R+100|0;c[am>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](R,6)|0;do{if((c[al>>2]|0)!=0){an=c[am>>2]|0;c[S>>2]=9534384;ao=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ao&16383](S,6,0)|0;if((an|0)<1){ak=1;i=b;return ak|0}if((gzL(ae,0,6)|0)==0){break}else{ak=1}i=b;return ak|0}}while(0);ae=(c[3529012]|0)+32768|0;if((c[3542200]|0)==0){ak=1;i=b;return ak|0}am=P+108|0;c[am>>2]=0;al=P+100|0;c[al>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](P,7)|0;do{if((c[am>>2]|0)!=0){an=c[al>>2]|0;c[Q>>2]=9534384;ao=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ao&16383](Q,7,0)|0;if((an|0)<1){ak=1;i=b;return ak|0}if((gzL(ae,0,7)|0)==0){break}else{ak=1}i=b;return ak|0}}while(0);ae=(c[3529012]|0)+65536|0;if((c[3542200]|0)==0){ak=1;i=b;return ak|0}al=N+108|0;c[al>>2]=0;am=N+100|0;c[am>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](N,8)|0;do{if((c[al>>2]|0)!=0){an=c[am>>2]|0;c[O>>2]=9534384;ao=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ao&16383](O,8,0)|0;if((an|0)<1){ak=1;i=b;return ak|0}if((gzL(ae,0,8)|0)==0){break}else{ak=1}i=b;return ak|0}}while(0);ae=c[3527094]|0;am=c[2439464]|0;al=c[2439462]|0;an=c[3529012]|0;ao=c[2405764]|0;if((ae|0)>0){ap=ag(al,am)|0;aq=(al|0)<1|(am|0)<1;ar=0;do{as=ag(ar,ap)|0;gGz(ao+as|0,0,ap|0);at=ar<<6;au=at+524288|0;if(!aq){av=0;do{aw=au+(c[1238464+(av<<2)>>2]|0)|0;ax=(ag(av,am)|0)+as|0;ay=0;do{az=aw+(c[614800+(ay<<2)>>2]|0)|0;if(((d[an+((az|0)/8|0)|0]|0)&128>>>((az&7)>>>0)|0)!=0){az=ao+(ax+ay)|0;a[az]=a[az]|4}ay=ay+1|0;}while((ay|0)<(am|0));av=av+1|0;}while((av|0)<(al|0));av=at+262144|0;au=0;while(1){ay=av+(c[1238464+(au<<2)>>2]|0)|0;ax=(ag(au,am)|0)+as|0;aw=0;do{az=ay+(c[614800+(aw<<2)>>2]|0)|0;if(((d[an+((az|0)/8|0)|0]|0)&128>>>((az&7)>>>0)|0)!=0){az=ao+(ax+aw)|0;a[az]=a[az]|2}aw=aw+1|0;}while((aw|0)<(am|0));aw=au+1|0;if((aw|0)<(al|0)){au=aw}else{aA=0;break}}do{au=at+(c[1238464+(aA<<2)>>2]|0)|0;av=(ag(aA,am)|0)+as|0;aw=0;do{ax=au+(c[614800+(aw<<2)>>2]|0)|0;if(((d[an+((ax|0)/8|0)|0]|0)&128>>>((ax&7)>>>0)|0)!=0){ax=ao+(av+aw)|0;a[ax]=a[ax]|1}aw=aw+1|0;}while((aw|0)<(am|0));aA=aA+1|0;}while((aA|0)<(al|0))}ar=ar+1|0;}while((ar|0)<(ae|0))}gGz(an|0,0,196608);if((c[3542200]|0)==0){ak=1;i=b;return ak|0}ae=L+108|0;c[ae>>2]=0;ar=L+100|0;c[ar>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](L,9)|0;do{if((c[ae>>2]|0)!=0){al=c[ar>>2]|0;c[M>>2]=9534384;am=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[am&16383](M,9,0)|0;if((al|0)<1){ak=1;i=b;return ak|0}if((gzL(an,0,9)|0)==0){break}else{ak=1}i=b;return ak|0}}while(0);an=(c[3529012]|0)+32768|0;if((c[3542200]|0)==0){ak=1;i=b;return ak|0}ar=J+108|0;c[ar>>2]=0;ae=J+100|0;c[ae>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](J,10)|0;do{if((c[ar>>2]|0)!=0){al=c[ae>>2]|0;c[K>>2]=9534384;am=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[am&16383](K,10,0)|0;if((al|0)<1){ak=1;i=b;return ak|0}if((gzL(an,0,10)|0)==0){break}else{ak=1}i=b;return ak|0}}while(0);an=(c[3529012]|0)+65536|0;if((c[3542200]|0)==0){ak=1;i=b;return ak|0}ae=H+108|0;c[ae>>2]=0;ar=H+100|0;c[ar>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](H,11)|0;do{if((c[ae>>2]|0)!=0){al=c[ar>>2]|0;c[I>>2]=9534384;am=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[am&16383](I,11,0)|0;if((al|0)<1){ak=1;i=b;return ak|0}if((gzL(an,0,11)|0)==0){break}else{ak=1}i=b;return ak|0}}while(0);an=(c[3529012]|0)+98304|0;if((c[3542200]|0)==0){ak=1;i=b;return ak|0}ar=F+108|0;c[ar>>2]=0;ae=F+100|0;c[ae>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](F,12)|0;do{if((c[ar>>2]|0)!=0){al=c[ae>>2]|0;c[G>>2]=9534384;am=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[am&16383](G,12,0)|0;if((al|0)<1){ak=1;i=b;return ak|0}if((gzL(an,0,12)|0)==0){break}else{ak=1}i=b;return ak|0}}while(0);an=(c[3529012]|0)+131072|0;if((c[3542200]|0)==0){ak=1;i=b;return ak|0}ae=D+108|0;c[ae>>2]=0;ar=D+100|0;c[ar>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](D,13)|0;do{if((c[ae>>2]|0)!=0){al=c[ar>>2]|0;c[E>>2]=9534384;am=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[am&16383](E,13,0)|0;if((al|0)<1){ak=1;i=b;return ak|0}if((gzL(an,0,13)|0)==0){break}else{ak=1}i=b;return ak|0}}while(0);an=(c[3529012]|0)+163840|0;if((c[3542200]|0)==0){ak=1;i=b;return ak|0}ar=B+108|0;c[ar>>2]=0;ae=B+100|0;c[ae>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](B,14)|0;do{if((c[ar>>2]|0)!=0){al=c[ae>>2]|0;c[C>>2]=9534384;am=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[am&16383](C,14,0)|0;if((al|0)<1){ak=1;i=b;return ak|0}if((gzL(an,0,14)|0)==0){break}else{ak=1}i=b;return ak|0}}while(0);an=c[2439452]|0;ae=c[3529012]|0;ar=c[3529014]|0;if((an|0)>0){al=0;do{am=al<<8;gGz(ar+am|0,0,256);ao=am+1048576|0;aq=0;do{ap=ao+(c[609008+(aq<<2)>>2]|0)|0;as=(aq<<4)+am|0;at=0;do{aw=ap+(c[597864+(at<<2)>>2]|0)|0;if(((d[ae+((aw|0)/8|0)|0]|0)&128>>>((aw&7)>>>0)|0)!=0){aw=ar+(as+at)|0;a[aw]=a[aw]|4}at=at+1|0;}while((at|0)<16);aq=aq+1|0;}while((aq|0)<16);aq=am+524288|0;ao=0;while(1){at=aq+(c[609008+(ao<<2)>>2]|0)|0;as=(ao<<4)+am|0;ap=0;do{aw=at+(c[597864+(ap<<2)>>2]|0)|0;if(((d[ae+((aw|0)/8|0)|0]|0)&128>>>((aw&7)>>>0)|0)!=0){aw=ar+(as+ap)|0;a[aw]=a[aw]|2}ap=ap+1|0;}while((ap|0)<16);ap=ao+1|0;if((ap|0)<16){ao=ap}else{aB=0;break}}do{ao=am+(c[609008+(aB<<2)>>2]|0)|0;aq=(aB<<4)+am|0;ap=0;do{as=ao+(c[597864+(ap<<2)>>2]|0)|0;if(((d[ae+((as|0)/8|0)|0]|0)&128>>>((as&7)>>>0)|0)!=0){as=ar+(aq+ap)|0;a[as]=a[as]|1}ap=ap+1|0;}while((ap|0)<16);aB=aB+1|0;}while((aB|0)<16);al=al+1|0;}while((al|0)<(an|0))}gGz(ae|0,0,196608);if((c[3542200]|0)==0){ak=1;i=b;return ak|0}an=z+108|0;c[an>>2]=0;al=z+100|0;c[al>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,15)|0;do{if((c[an>>2]|0)!=0){ar=c[al>>2]|0;c[A>>2]=9534384;am=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[am&16383](A,15,0)|0;if((ar|0)<1){ak=1;i=b;return ak|0}if((gzL(ae,0,15)|0)==0){break}else{ak=1}i=b;return ak|0}}while(0);ae=(c[3529012]|0)+16384|0;if((c[3542200]|0)==0){ak=1;i=b;return ak|0}al=x+108|0;c[al>>2]=0;an=x+100|0;c[an>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,16)|0;do{if((c[al>>2]|0)!=0){ar=c[an>>2]|0;c[y>>2]=9534384;am=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[am&16383](y,16,0)|0;if((ar|0)<1){ak=1;i=b;return ak|0}if((gzL(ae,0,16)|0)==0){break}else{ak=1}i=b;return ak|0}}while(0);ae=(c[3529012]|0)+32768|0;if((c[3542200]|0)==0){ak=1;i=b;return ak|0}an=v+108|0;c[an>>2]=0;al=v+100|0;c[al>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,17)|0;do{if((c[an>>2]|0)!=0){ar=c[al>>2]|0;c[w>>2]=9534384;am=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[am&16383](w,17,0)|0;if((ar|0)<1){ak=1;i=b;return ak|0}if((gzL(ae,0,17)|0)==0){break}else{ak=1}i=b;return ak|0}}while(0);ae=c[3527096]|0;al=c[2437648]|0;an=c[2437646]|0;ar=c[3529012]|0;am=c[2405778]|0;if((ae|0)>0){ap=ag(an,al)|0;aq=(an|0)<1|(al|0)<1;ao=0;do{as=ag(ao,ap)|0;gGz(am+as|0,0,ap|0);at=ao<<7;if(!aq){aw=0;do{av=at+(c[1238464+(aw<<2)>>2]|0)|0;au=(ag(aw,al)|0)+as|0;ax=0;do{ay=av+(c[3836464+(ax<<2)>>2]|0)|0;if(((d[ar+((ay|0)/8|0)|0]|0)&128>>>((ay&7)>>>0)|0)!=0){ay=am+(au+ax)|0;a[ay]=a[ay]|4}ax=ax+1|0;}while((ax|0)<(al|0));aw=aw+1|0;}while((aw|0)<(an|0));aw=at+131072|0;ax=0;do{au=aw+(c[1238464+(ax<<2)>>2]|0)|0;av=(ag(ax,al)|0)+as|0;ay=0;do{az=au+(c[3836464+(ay<<2)>>2]|0)|0;if(((d[ar+((az|0)/8|0)|0]|0)&128>>>((az&7)>>>0)|0)!=0){az=am+(av+ay)|0;a[az]=a[az]|2}ay=ay+1|0;}while((ay|0)<(al|0));ax=ax+1|0;}while((ax|0)<(an|0));ax=at+262144|0;aw=0;do{ay=ax+(c[1238464+(aw<<2)>>2]|0)|0;av=(ag(aw,al)|0)+as|0;au=0;do{az=ay+(c[3836464+(au<<2)>>2]|0)|0;if(((d[ar+((az|0)/8|0)|0]|0)&128>>>((az&7)>>>0)|0)!=0){az=am+(av+au)|0;a[az]=a[az]|1}au=au+1|0;}while((au|0)<(al|0));aw=aw+1|0;}while((aw|0)<(an|0))}ao=ao+1|0;}while((ao|0)<(ae|0))}ae=c[3527092]|0;if((c[3542200]|0)==0){ak=1;i=b;return ak|0}ao=t+108|0;c[ao>>2]=0;an=t+100|0;c[an>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,18)|0;do{if((c[ao>>2]|0)!=0){al=c[an>>2]|0;c[u>>2]=9534384;am=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[am&16383](u,18,0)|0;if((al|0)<1){ak=1;i=b;return ak|0}if((gzL(ae,0,18)|0)==0){break}else{ak=1}i=b;return ak|0}}while(0);ae=(c[3527092]|0)+256|0;if((c[3542200]|0)==0){ak=1;i=b;return ak|0}an=r+108|0;c[an>>2]=0;ao=r+100|0;c[ao>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,19)|0;do{if((c[an>>2]|0)!=0){al=c[ao>>2]|0;c[s>>2]=9534384;am=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[am&16383](s,19,0)|0;if((al|0)<1){ak=1;i=b;return ak|0}if((gzL(ae,0,19)|0)==0){break}else{ak=1}i=b;return ak|0}}while(0);ae=(c[3527092]|0)+512|0;if((c[3542200]|0)==0){ak=1;i=b;return ak|0}ao=p+108|0;c[ao>>2]=0;an=p+100|0;c[an>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,20)|0;do{if((c[ao>>2]|0)!=0){al=c[an>>2]|0;c[q>>2]=9534384;am=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[am&16383](q,20,0)|0;if((al|0)<1){ak=1;i=b;return ak|0}if((gzL(ae,0,20)|0)==0){break}else{ak=1}i=b;return ak|0}}while(0);ae=(c[3527092]|0)+768|0;if((c[3542200]|0)==0){ak=1;i=b;return ak|0}an=n+108|0;c[an>>2]=0;ao=n+100|0;c[ao>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,21)|0;do{if((c[an>>2]|0)!=0){al=c[ao>>2]|0;c[o>>2]=9534384;am=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[am&16383](o,21,0)|0;if((al|0)<1){ak=1;i=b;return ak|0}if((gzL(ae,0,21)|0)==0){break}else{ak=1}i=b;return ak|0}}while(0);ae=(c[3527092]|0)+1024|0;if((c[3542200]|0)==0){ak=1;i=b;return ak|0}ao=l+108|0;c[ao>>2]=0;an=l+100|0;c[an>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,22)|0;do{if((c[ao>>2]|0)!=0){al=c[an>>2]|0;c[m>>2]=9534384;am=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[am&16383](m,22,0)|0;if((al|0)<1){ak=1;i=b;return ak|0}if((gzL(ae,0,22)|0)==0){break}else{ak=1}i=b;return ak|0}}while(0);ae=(c[3527092]|0)+1280|0;if((c[3542200]|0)==0){ak=1;i=b;return ak|0}an=j+108|0;c[an>>2]=0;ao=j+100|0;c[ao>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,23)|0;do{if((c[an>>2]|0)!=0){al=c[ao>>2]|0;c[k>>2]=9534384;am=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[am&16383](k,23,0)|0;if((al|0)<1){ak=1;i=b;return ak|0}if((gzL(ae,0,23)|0)==0){break}else{ak=1}i=b;return ak|0}}while(0);ae=(c[3527092]|0)+1536|0;if((c[3542200]|0)==0){ak=1;i=b;return ak|0}ao=g+108|0;c[ao>>2]=0;an=g+100|0;c[an>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,24)|0;do{if((c[ao>>2]|0)!=0){al=c[an>>2]|0;c[h>>2]=9534384;am=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[am&16383](h,24,0)|0;if((al|0)<1){ak=1;i=b;return ak|0}if((gzL(ae,0,24)|0)==0){break}else{ak=1}i=b;return ak|0}}while(0);ae=(c[3527092]|0)+1568|0;if((c[3542200]|0)==0){ak=1;i=b;return ak|0}an=e+108|0;c[an>>2]=0;ao=e+100|0;c[ao>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,25)|0;do{if((c[an>>2]|0)!=0){al=c[ao>>2]|0;c[f>>2]=9534384;am=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[am&16383](f,25,0)|0;if((al|0)<1){ak=1;i=b;return ak|0}if((gzL(ae,0,25)|0)==0){break}else{ak=1}i=b;return ak|0}}while(0);ae=c[3529012]|0;ao=0;while(1){if((ao|0)>=1024){break}aC=9638528+(ao<<2)|0;if((c[aC>>2]|0)==(ae|0)){ah=55240;break}else{ao=ao+1|0}}if((ah|0)==55240){gGr(ae);c[aC>>2]=0}c[3529012]=0;a9_();ak=0;i=b;return ak|0}}while(0);c[2426820]=0;ak=1;i=b;return ak|0}function a9p(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>29){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3385484+(b*112|0)>>2];c[a+104>>2]=c[3385488+(b*112|0)>>2];c[a+108>>2]=c[3385492+(b*112|0)>>2];d=0;return d|0}function a9q(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<30&(d|0)==0)){e=1;return e|0}c[a>>2]=3385384+(b*112|0);e=0;return e|0}function a9r(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>86){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3388744+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function a9s(){var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0;e=i;i=i+3480|0;f=e|0;g=e+112|0;h=e+120|0;j=e+232|0;k=e+240|0;l=e+352|0;m=e+360|0;n=e+472|0;o=e+480|0;p=e+592|0;q=e+600|0;r=e+712|0;s=e+720|0;t=e+832|0;u=e+840|0;v=e+952|0;w=e+960|0;x=e+1072|0;y=e+1080|0;z=e+1192|0;A=e+1200|0;B=e+1312|0;C=e+1320|0;D=e+1432|0;E=e+1440|0;F=e+1552|0;G=e+1560|0;H=e+1672|0;I=e+1680|0;J=e+1792|0;K=e+1800|0;L=e+1912|0;M=e+1920|0;N=e+2032|0;O=e+2040|0;P=e+2152|0;Q=e+2160|0;R=e+2272|0;S=e+2280|0;T=e+2392|0;U=e+2400|0;V=e+2512|0;W=e+2520|0;X=e+2632|0;Y=e+2640|0;Z=e+2752|0;_=e+2760|0;$=e+2872|0;aa=e+2880|0;ab=e+2992|0;ac=e+3e3|0;ad=e+3112|0;ae=e+3120|0;af=e+3232|0;ah=e+3240|0;ai=e+3352|0;aj=e+3360|0;ak=e+3472|0;c[2439448]=65536;c[3527090]=1824;c[3527094]=4096;c[2439452]=1024;c[3527096]=512;c[2438666]=2048;c[2439464]=8;c[2439462]=8;c[2437648]=12;c[2437646]=8;c[2431672]=c[(c[642608+(c[2436]<<2)>>2]|0)+124>>2];c[2426820]=0;a9Q();al=c[2414438]|0;am=0;while(1){if((am|0)>=1024){break}an=9638528+(am<<2)|0;if((c[an>>2]|0)==0){ao=55379;break}else{am=am+1|0}}do{if((ao|0)==55379){am=gGq(al)|0;c[an>>2]=am;if((am|0)==0){break}gGz(am|0,0,al|0);c[2426820]=am;gGz(am|0,0,al|0);a9Q();am=0;while(1){if((am|0)>=1024){ap=0;break}aq=9638528+(am<<2)|0;if((c[aq>>2]|0)==0){ao=55384;break}else{am=am+1|0}}do{if((ao|0)==55384){am=gGq(98304)|0;c[aq>>2]=am;if((am|0)==0){ap=0;break}gGz(am|0,0,98304);ap=am}}while(0);c[3529012]=ap;am=c[2385798]|0;if((c[3542200]|0)==0){ar=1;i=e;return ar|0}as=aj+108|0;c[as>>2]=0;at=aj+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](aj,0)|0;do{if((c[as>>2]|0)!=0){au=c[at>>2]|0;c[ak>>2]=9534384;av=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[av&16383](ak,0,0)|0;if((au|0)<1){ar=1;i=e;return ar|0}if((gzL(am,0,0)|0)==0){break}else{ar=1}i=e;return ar|0}}while(0);am=(c[2385798]|0)+16384|0;if((c[3542200]|0)==0){ar=1;i=e;return ar|0}at=ah+108|0;c[at>>2]=0;as=ah+100|0;c[as>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](ah,1)|0;do{if((c[at>>2]|0)!=0){au=c[as>>2]|0;c[ai>>2]=9534384;av=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[av&16383](ai,1,0)|0;if((au|0)<1){ar=1;i=e;return ar|0}if((gzL(am,0,1)|0)==0){break}else{ar=1}i=e;return ar|0}}while(0);am=(c[2385798]|0)+32768|0;if((c[3542200]|0)==0){ar=1;i=e;return ar|0}as=ae+108|0;c[as>>2]=0;at=ae+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](ae,2)|0;do{if((c[as>>2]|0)!=0){au=c[at>>2]|0;c[af>>2]=9534384;av=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[av&16383](af,2,0)|0;if((au|0)<1){ar=1;i=e;return ar|0}if((gzL(am,0,2)|0)==0){break}else{ar=1}i=e;return ar|0}}while(0);am=(c[2385798]|0)+49152|0;if((c[3542200]|0)==0){ar=1;i=e;return ar|0}at=ac+108|0;c[at>>2]=0;as=ac+100|0;c[as>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](ac,3)|0;do{if((c[at>>2]|0)!=0){au=c[as>>2]|0;c[ad>>2]=9534384;av=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[av&16383](ad,3,0)|0;if((au|0)<1){ar=1;i=e;return ar|0}if((gzL(am,0,3)|0)==0){break}else{ar=1}i=e;return ar|0}}while(0);am=(c[3527098]|0)+16384|0;if((c[3542200]|0)==0){ar=1;i=e;return ar|0}as=aa+108|0;c[as>>2]=0;at=aa+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](aa,4)|0;do{if((c[as>>2]|0)!=0){au=c[at>>2]|0;c[ab>>2]=9534384;av=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[av&16383](ab,4,0)|0;if((au|0)<1){ar=1;i=e;return ar|0}if((gzL(am,0,4)|0)==0){break}else{ar=1}i=e;return ar|0}}while(0);am=(c[3527098]|0)+32768|0;if((c[3542200]|0)==0){ar=1;i=e;return ar|0}at=_+108|0;c[at>>2]=0;as=_+100|0;c[as>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](_,5)|0;do{if((c[at>>2]|0)!=0){au=c[as>>2]|0;c[$>>2]=9534384;av=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[av&16383]($,5,0)|0;if((au|0)<1){ar=1;i=e;return ar|0}if((gzL(am,0,5)|0)==0){break}else{ar=1}i=e;return ar|0}}while(0);am=c[3529012]|0;gGz(am|0,0,98304);if((c[3542200]|0)==0){ar=1;i=e;return ar|0}as=Y+108|0;c[as>>2]=0;at=Y+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](Y,6)|0;do{if((c[as>>2]|0)!=0){au=c[at>>2]|0;c[Z>>2]=9534384;av=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[av&16383](Z,6,0)|0;if((au|0)<1){ar=1;i=e;return ar|0}if((gzL(am,0,6)|0)==0){break}else{ar=1}i=e;return ar|0}}while(0);am=(c[3529012]|0)+16384|0;if((c[3542200]|0)==0){ar=1;i=e;return ar|0}at=W+108|0;c[at>>2]=0;as=W+100|0;c[as>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](W,7)|0;do{if((c[at>>2]|0)!=0){au=c[as>>2]|0;c[X>>2]=9534384;av=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[av&16383](X,7,0)|0;if((au|0)<1){ar=1;i=e;return ar|0}if((gzL(am,0,7)|0)==0){break}else{ar=1}i=e;return ar|0}}while(0);am=(c[3529012]|0)+32768|0;if((c[3542200]|0)==0){ar=1;i=e;return ar|0}as=U+108|0;c[as>>2]=0;at=U+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](U,8)|0;do{if((c[as>>2]|0)!=0){au=c[at>>2]|0;c[V>>2]=9534384;av=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[av&16383](V,8,0)|0;if((au|0)<1){ar=1;i=e;return ar|0}if((gzL(am,0,8)|0)==0){break}else{ar=1}i=e;return ar|0}}while(0);am=(c[3529012]|0)+49152|0;if((c[3542200]|0)==0){ar=1;i=e;return ar|0}at=S+108|0;c[at>>2]=0;as=S+100|0;c[as>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](S,9)|0;do{if((c[at>>2]|0)!=0){au=c[as>>2]|0;c[T>>2]=9534384;av=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[av&16383](T,9,0)|0;if((au|0)<1){ar=1;i=e;return ar|0}if((gzL(am,0,9)|0)==0){break}else{ar=1}i=e;return ar|0}}while(0);am=(c[3529012]|0)+65536|0;if((c[3542200]|0)==0){ar=1;i=e;return ar|0}as=Q+108|0;c[as>>2]=0;at=Q+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](Q,10)|0;do{if((c[as>>2]|0)!=0){au=c[at>>2]|0;c[R>>2]=9534384;av=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[av&16383](R,10,0)|0;if((au|0)<1){ar=1;i=e;return ar|0}if((gzL(am,0,10)|0)==0){break}else{ar=1}i=e;return ar|0}}while(0);am=(c[3529012]|0)+81920|0;if((c[3542200]|0)==0){ar=1;i=e;return ar|0}at=O+108|0;c[at>>2]=0;as=O+100|0;c[as>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](O,11)|0;do{if((c[at>>2]|0)!=0){au=c[as>>2]|0;c[P>>2]=9534384;av=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[av&16383](P,11,0)|0;if((au|0)<1){ar=1;i=e;return ar|0}if((gzL(am,0,11)|0)==0){break}else{ar=1}i=e;return ar|0}}while(0);am=c[3527094]|0;as=c[2439464]|0;at=c[2439462]|0;au=c[3529012]|0;av=c[2405764]|0;if((am|0)>0){aw=ag(at,as)|0;ax=(at|0)<1|(as|0)<1;ay=0;do{az=ag(ay,aw)|0;gGz(av+az|0,0,aw|0);aA=ay<<6;aB=aA+524288|0;if(!ax){aC=0;do{aD=aB+(c[1238464+(aC<<2)>>2]|0)|0;aE=(ag(aC,as)|0)+az|0;aF=0;do{aG=aD+(c[614800+(aF<<2)>>2]|0)|0;if(((d[au+((aG|0)/8|0)|0]|0)&128>>>((aG&7)>>>0)|0)!=0){aG=av+(aE+aF)|0;a[aG]=a[aG]|4}aF=aF+1|0;}while((aF|0)<(as|0));aC=aC+1|0;}while((aC|0)<(at|0));aC=aA+262144|0;aB=0;while(1){aF=aC+(c[1238464+(aB<<2)>>2]|0)|0;aE=(ag(aB,as)|0)+az|0;aD=0;do{aG=aF+(c[614800+(aD<<2)>>2]|0)|0;if(((d[au+((aG|0)/8|0)|0]|0)&128>>>((aG&7)>>>0)|0)!=0){aG=av+(aE+aD)|0;a[aG]=a[aG]|2}aD=aD+1|0;}while((aD|0)<(as|0));aD=aB+1|0;if((aD|0)<(at|0)){aB=aD}else{aH=0;break}}do{aB=aA+(c[1238464+(aH<<2)>>2]|0)|0;aC=(ag(aH,as)|0)+az|0;aD=0;do{aE=aB+(c[614800+(aD<<2)>>2]|0)|0;if(((d[au+((aE|0)/8|0)|0]|0)&128>>>((aE&7)>>>0)|0)!=0){aE=av+(aC+aD)|0;a[aE]=a[aE]|1}aD=aD+1|0;}while((aD|0)<(as|0));aH=aH+1|0;}while((aH|0)<(at|0))}ay=ay+1|0;}while((ay|0)<(am|0))}gGz(au|0,0,98304);if((c[3542200]|0)==0){ar=1;i=e;return ar|0}am=M+108|0;c[am>>2]=0;ay=M+100|0;c[ay>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](M,12)|0;do{if((c[am>>2]|0)!=0){at=c[ay>>2]|0;c[N>>2]=9534384;as=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[as&16383](N,12,0)|0;if((at|0)<1){ar=1;i=e;return ar|0}if((gzL(au,0,12)|0)==0){break}else{ar=1}i=e;return ar|0}}while(0);au=(c[3529012]|0)+16384|0;if((c[3542200]|0)==0){ar=1;i=e;return ar|0}ay=K+108|0;c[ay>>2]=0;am=K+100|0;c[am>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](K,13)|0;do{if((c[ay>>2]|0)!=0){at=c[am>>2]|0;c[L>>2]=9534384;as=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[as&16383](L,13,0)|0;if((at|0)<1){ar=1;i=e;return ar|0}if((gzL(au,0,13)|0)==0){break}else{ar=1}i=e;return ar|0}}while(0);au=(c[3529012]|0)+32768|0;if((c[3542200]|0)==0){ar=1;i=e;return ar|0}am=I+108|0;c[am>>2]=0;ay=I+100|0;c[ay>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](I,14)|0;do{if((c[am>>2]|0)!=0){at=c[ay>>2]|0;c[J>>2]=9534384;as=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[as&16383](J,14,0)|0;if((at|0)<1){ar=1;i=e;return ar|0}if((gzL(au,0,14)|0)==0){break}else{ar=1}i=e;return ar|0}}while(0);au=(c[3529012]|0)+49152|0;if((c[3542200]|0)==0){ar=1;i=e;return ar|0}ay=G+108|0;c[ay>>2]=0;am=G+100|0;c[am>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](G,15)|0;do{if((c[ay>>2]|0)!=0){at=c[am>>2]|0;c[H>>2]=9534384;as=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[as&16383](H,15,0)|0;if((at|0)<1){ar=1;i=e;return ar|0}if((gzL(au,0,15)|0)==0){break}else{ar=1}i=e;return ar|0}}while(0);au=(c[3529012]|0)+65536|0;if((c[3542200]|0)==0){ar=1;i=e;return ar|0}am=E+108|0;c[am>>2]=0;ay=E+100|0;c[ay>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](E,16)|0;do{if((c[am>>2]|0)!=0){at=c[ay>>2]|0;c[F>>2]=9534384;as=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[as&16383](F,16,0)|0;if((at|0)<1){ar=1;i=e;return ar|0}if((gzL(au,0,16)|0)==0){break}else{ar=1}i=e;return ar|0}}while(0);au=(c[3529012]|0)+81920|0;if((c[3542200]|0)==0){ar=1;i=e;return ar|0}ay=C+108|0;c[ay>>2]=0;am=C+100|0;c[am>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](C,17)|0;do{if((c[ay>>2]|0)!=0){at=c[am>>2]|0;c[D>>2]=9534384;as=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[as&16383](D,17,0)|0;if((at|0)<1){ar=1;i=e;return ar|0}if((gzL(au,0,17)|0)==0){break}else{ar=1}i=e;return ar|0}}while(0);au=c[2439452]|0;am=c[3529012]|0;ay=c[3529014]|0;if((au|0)>0){at=0;do{as=at<<8;gGz(ay+as|0,0,256);av=as+524288|0;ax=0;do{aw=av+(c[609008+(ax<<2)>>2]|0)|0;az=(ax<<4)+as|0;aA=0;do{aD=aw+(c[597864+(aA<<2)>>2]|0)|0;if(((d[am+((aD|0)/8|0)|0]|0)&128>>>((aD&7)>>>0)|0)!=0){aD=ay+(az+aA)|0;a[aD]=a[aD]|4}aA=aA+1|0;}while((aA|0)<16);ax=ax+1|0;}while((ax|0)<16);ax=as+262144|0;av=0;while(1){aA=ax+(c[609008+(av<<2)>>2]|0)|0;az=(av<<4)+as|0;aw=0;do{aD=aA+(c[597864+(aw<<2)>>2]|0)|0;if(((d[am+((aD|0)/8|0)|0]|0)&128>>>((aD&7)>>>0)|0)!=0){aD=ay+(az+aw)|0;a[aD]=a[aD]|2}aw=aw+1|0;}while((aw|0)<16);aw=av+1|0;if((aw|0)<16){av=aw}else{aI=0;break}}do{av=as+(c[609008+(aI<<2)>>2]|0)|0;ax=(aI<<4)+as|0;aw=0;do{az=av+(c[597864+(aw<<2)>>2]|0)|0;if(((d[am+((az|0)/8|0)|0]|0)&128>>>((az&7)>>>0)|0)!=0){az=ay+(ax+aw)|0;a[az]=a[az]|1}aw=aw+1|0;}while((aw|0)<16);aI=aI+1|0;}while((aI|0)<16);at=at+1|0;}while((at|0)<(au|0))}gGz(am|0,0,98304);au=0;while(1){if((au|0)>=1024){aJ=0;break}aK=9638528+(au<<2)|0;if((c[aK>>2]|0)==0){ao=55478;break}else{au=au+1|0}}do{if((ao|0)==55478){au=gGq(98304)|0;c[aK>>2]=au;if((au|0)==0){aJ=0;break}gGz(au|0,0,98304);aJ=au}}while(0);if((c[3542200]|0)==0){ar=1;i=e;return ar|0}au=A+108|0;c[au>>2]=0;am=A+100|0;c[am>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](A,18)|0;do{if((c[au>>2]|0)!=0){at=c[am>>2]|0;c[B>>2]=9534384;ay=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ay&16383](B,18,0)|0;if((at|0)<1){ar=1;i=e;return ar|0}if((gzL(aJ,0,18)|0)==0){break}else{ar=1}i=e;return ar|0}}while(0);am=aJ+16384|0;if((c[3542200]|0)==0){ar=1;i=e;return ar|0}au=y+108|0;c[au>>2]=0;at=y+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](y,19)|0;do{if((c[au>>2]|0)!=0){ay=c[at>>2]|0;c[z>>2]=9534384;as=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[as&16383](z,19,0)|0;if((ay|0)<1){ar=1;i=e;return ar|0}if((gzL(am,0,19)|0)==0){break}else{ar=1}i=e;return ar|0}}while(0);at=aJ+32768|0;if((c[3542200]|0)==0){ar=1;i=e;return ar|0}au=w+108|0;c[au>>2]=0;ay=w+100|0;c[ay>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](w,20)|0;do{if((c[au>>2]|0)!=0){as=c[ay>>2]|0;c[x>>2]=9534384;aw=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aw&16383](x,20,0)|0;if((as|0)<1){ar=1;i=e;return ar|0}if((gzL(at,0,20)|0)==0){break}else{ar=1}i=e;return ar|0}}while(0);ay=c[3529012]|0;gGC(ay|0,aJ|0,2048)|0;au=ay+8192|0;as=aJ+2048|0;gGC(au|0,as|0,2048)|0;as=ay+2048|0;au=aJ+4096|0;gGC(as|0,au|0,2048)|0;au=ay+10240|0;aw=aJ+6144|0;gGC(au|0,aw|0,2048)|0;aw=ay+4096|0;au=aJ+8192|0;gGC(aw|0,au|0,2048)|0;au=ay+12288|0;aw=aJ+10240|0;gGC(au|0,aw|0,2048)|0;aw=aJ+12288|0;gGC(as|0,aw|0,2048)|0;aw=ay+14336|0;as=aJ+14336|0;gGC(aw|0,as|0,2048)|0;as=ay+16384|0;gGC(as|0,am|0,2048)|0;as=ay+24576|0;aw=aJ+18432|0;gGC(as|0,aw|0,2048)|0;aw=ay+18432|0;as=aJ+20480|0;gGC(aw|0,as|0,2048)|0;as=ay+26624|0;aw=aJ+22528|0;gGC(as|0,aw|0,2048)|0;aw=ay+20480|0;as=aJ+24576|0;gGC(aw|0,as|0,2048)|0;as=ay+28672|0;aw=aJ+26624|0;gGC(as|0,aw|0,2048)|0;aw=ay+22528|0;as=aJ+28672|0;gGC(aw|0,as|0,2048)|0;as=ay+30720|0;aw=aJ+30720|0;gGC(as|0,aw|0,2048)|0;aw=ay+32768|0;gGC(aw|0,at|0,2048)|0;aw=ay+40960|0;as=aJ+34816|0;gGC(aw|0,as|0,2048)|0;as=ay+34816|0;aw=aJ+36864|0;gGC(as|0,aw|0,2048)|0;aw=ay+43008|0;as=aJ+38912|0;gGC(aw|0,as|0,2048)|0;as=ay+36864|0;aw=aJ+40960|0;gGC(as|0,aw|0,2048)|0;aw=ay+45056|0;as=aJ+43008|0;gGC(aw|0,as|0,2048)|0;as=ay+38912|0;aw=aJ+45056|0;gGC(as|0,aw|0,2048)|0;aw=ay+47104|0;as=aJ+47104|0;gGC(aw|0,as|0,2048)|0;as=0;while(1){if((as|0)>=1024){aL=ay;break}aM=9638528+(as<<2)|0;if((c[aM>>2]|0)==(aJ|0)){ao=55495;break}else{as=as+1|0}}if((ao|0)==55495){gGr(aJ);c[aM>>2]=0;aL=c[3529012]|0}as=c[3527096]|0;ay=c[2437648]|0;at=c[2437646]|0;am=c[2405778]|0;if((as|0)>0){aw=ag(at,ay)|0;au=(at|0)<1|(ay|0)<1;ax=0;do{av=ag(ax,aw)|0;gGz(am+av|0,0,aw|0);az=ax<<6;if(!au){aA=0;do{aD=az+(c[1238464+(aA<<2)>>2]|0)|0;aC=(ag(aA,ay)|0)+av|0;aB=0;do{aE=aD+(c[1689904+(aB<<2)>>2]|0)|0;if(((d[aL+((aE|0)/8|0)|0]|0)&128>>>((aE&7)>>>0)|0)!=0){aE=am+(aC+aB)|0;a[aE]=a[aE]|4}aB=aB+1|0;}while((aB|0)<(ay|0));aA=aA+1|0;}while((aA|0)<(at|0));aA=az+131072|0;aB=0;do{aC=aA+(c[1238464+(aB<<2)>>2]|0)|0;aD=(ag(aB,ay)|0)+av|0;aE=0;do{aF=aC+(c[1689904+(aE<<2)>>2]|0)|0;if(((d[aL+((aF|0)/8|0)|0]|0)&128>>>((aF&7)>>>0)|0)!=0){aF=am+(aD+aE)|0;a[aF]=a[aF]|2}aE=aE+1|0;}while((aE|0)<(ay|0));aB=aB+1|0;}while((aB|0)<(at|0));aB=az+262144|0;aA=0;do{aE=aB+(c[1238464+(aA<<2)>>2]|0)|0;aD=(ag(aA,ay)|0)+av|0;aC=0;do{aF=aE+(c[1689904+(aC<<2)>>2]|0)|0;if(((d[aL+((aF|0)/8|0)|0]|0)&128>>>((aF&7)>>>0)|0)!=0){aF=am+(aD+aC)|0;a[aF]=a[aF]|1}aC=aC+1|0;}while((aC|0)<(ay|0));aA=aA+1|0;}while((aA|0)<(at|0))}ax=ax+1|0;}while((ax|0)<(as|0))}as=c[3527092]|0;if((c[3542200]|0)==0){ar=1;i=e;return ar|0}ax=u+108|0;c[ax>>2]=0;at=u+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](u,21)|0;do{if((c[ax>>2]|0)!=0){ay=c[at>>2]|0;c[v>>2]=9534384;am=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[am&16383](v,21,0)|0;if((ay|0)<1){ar=1;i=e;return ar|0}if((gzL(as,0,21)|0)==0){break}else{ar=1}i=e;return ar|0}}while(0);as=(c[3527092]|0)+256|0;if((c[3542200]|0)==0){ar=1;i=e;return ar|0}at=s+108|0;c[at>>2]=0;ax=s+100|0;c[ax>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](s,22)|0;do{if((c[at>>2]|0)!=0){ay=c[ax>>2]|0;c[t>>2]=9534384;am=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[am&16383](t,22,0)|0;if((ay|0)<1){ar=1;i=e;return ar|0}if((gzL(as,0,22)|0)==0){break}else{ar=1}i=e;return ar|0}}while(0);as=(c[3527092]|0)+512|0;if((c[3542200]|0)==0){ar=1;i=e;return ar|0}ax=q+108|0;c[ax>>2]=0;at=q+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](q,23)|0;do{if((c[ax>>2]|0)!=0){ay=c[at>>2]|0;c[r>>2]=9534384;am=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[am&16383](r,23,0)|0;if((ay|0)<1){ar=1;i=e;return ar|0}if((gzL(as,0,23)|0)==0){break}else{ar=1}i=e;return ar|0}}while(0);as=(c[3527092]|0)+768|0;if((c[3542200]|0)==0){ar=1;i=e;return ar|0}at=o+108|0;c[at>>2]=0;ax=o+100|0;c[ax>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](o,24)|0;do{if((c[at>>2]|0)!=0){ay=c[ax>>2]|0;c[p>>2]=9534384;am=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[am&16383](p,24,0)|0;if((ay|0)<1){ar=1;i=e;return ar|0}if((gzL(as,0,24)|0)==0){break}else{ar=1}i=e;return ar|0}}while(0);as=(c[3527092]|0)+1024|0;if((c[3542200]|0)==0){ar=1;i=e;return ar|0}ax=m+108|0;c[ax>>2]=0;at=m+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,25)|0;do{if((c[ax>>2]|0)!=0){ay=c[at>>2]|0;c[n>>2]=9534384;am=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[am&16383](n,25,0)|0;if((ay|0)<1){ar=1;i=e;return ar|0}if((gzL(as,0,25)|0)==0){break}else{ar=1}i=e;return ar|0}}while(0);as=(c[3527092]|0)+1280|0;if((c[3542200]|0)==0){ar=1;i=e;return ar|0}at=k+108|0;c[at>>2]=0;ax=k+100|0;c[ax>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,26)|0;do{if((c[at>>2]|0)!=0){ay=c[ax>>2]|0;c[l>>2]=9534384;am=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[am&16383](l,26,0)|0;if((ay|0)<1){ar=1;i=e;return ar|0}if((gzL(as,0,26)|0)==0){break}else{ar=1}i=e;return ar|0}}while(0);as=(c[3527092]|0)+1536|0;if((c[3542200]|0)==0){ar=1;i=e;return ar|0}ax=h+108|0;c[ax>>2]=0;at=h+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](h,27)|0;do{if((c[ax>>2]|0)!=0){ay=c[at>>2]|0;c[j>>2]=9534384;am=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[am&16383](j,27,0)|0;if((ay|0)<1){ar=1;i=e;return ar|0}if((gzL(as,0,27)|0)==0){break}else{ar=1}i=e;return ar|0}}while(0);as=(c[3527092]|0)+1568|0;if((c[3542200]|0)==0){ar=1;i=e;return ar|0}at=f+108|0;c[at>>2]=0;ax=f+100|0;c[ax>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,28)|0;do{if((c[at>>2]|0)!=0){ay=c[ax>>2]|0;c[g>>2]=9534384;am=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[am&16383](g,28,0)|0;if((ay|0)<1){ar=1;i=e;return ar|0}if((gzL(as,0,28)|0)==0){break}else{ar=1}i=e;return ar|0}}while(0);as=c[3529012]|0;ax=0;while(1){if((ax|0)>=1024){break}aN=9638528+(ax<<2)|0;if((c[aN>>2]|0)==(as|0)){ao=55540;break}else{ax=ax+1|0}}if((ao|0)==55540){gGr(as);c[aN>>2]=0}c[3529012]=0;a9H();ax=c[2439330]|0;if((ax|0)!=0){at=ax;gGC(9706056,at|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];at=c[3528484]|0;c[2076596]=at;ay=c[2417276]|0;c[3541536]=ay;c[1836236]=0;c[ax+4184>>2]=2990;am=c[2385798]|0;au=128;aw=128;while(1){c[ax+76+(aw<<2)>>2]=am+(aw<<8);aA=au+1&65535;if((aA&65535)>159){aO=128;aP=128;break}else{au=aA;aw=aA&65535}}while(1){aw=am+(aP<<8)|0;c[ax+76+(aP+512<<2)>>2]=aw;c[ax+76+(aP+768<<2)>>2]=aw;aw=aO+1&65535;if((aw&65535)>159){break}else{aO=aw;aP=aw&65535}}am=c[3529010]|0;aw=160;au=160;while(1){c[ax+76+(au<<2)>>2]=am+((au<<8)-40960);as=aw+1&65535;if((as&65535)>191){aQ=160;aR=160;break}else{aw=as;au=as&65535}}while(1){c[ax+76+(aR+256<<2)>>2]=am+((aR<<8)-40960);au=aQ+1&65535;if((au&65535)>191){aS=160;aT=160;break}else{aQ=au;aR=au&65535}}while(1){au=am+((aT<<8)-40960)|0;c[ax+76+(aT+512<<2)>>2]=au;c[ax+76+(aT+768<<2)>>2]=au;au=aS+1&65535;if((au&65535)>191){break}else{aS=au;aT=au&65535}}am=c[3529018]|0;c[ax+876>>2]=am;au=am+256|0;c[ax+880>>2]=au;aw=am+512|0;c[ax+884>>2]=aw;as=am+768|0;c[ax+888>>2]=as;aA=am+1024|0;c[ax+892>>2]=aA;av=am+1280|0;c[ax+896>>2]=av;aB=am+1536|0;c[ax+900>>2]=aB;az=am+1792|0;c[ax+904>>2]=az;c[ax+1900>>2]=am;c[ax+1904>>2]=au;c[ax+1908>>2]=aw;c[ax+1912>>2]=as;c[ax+1916>>2]=aA;c[ax+1920>>2]=av;c[ax+1924>>2]=aB;c[ax+1928>>2]=az;c[ax+2924>>2]=am;c[ax+3948>>2]=am;c[ax+2928>>2]=au;c[ax+3952>>2]=au;c[ax+2932>>2]=aw;c[ax+3956>>2]=aw;c[ax+2936>>2]=as;c[ax+3960>>2]=as;c[ax+2940>>2]=aA;c[ax+3964>>2]=aA;c[ax+2944>>2]=av;c[ax+3968>>2]=av;c[ax+2948>>2]=aB;c[ax+3972>>2]=aB;c[ax+2952>>2]=az;c[ax+3976>>2]=az;gGz(ax+908|0,0,64);gGz(ax+1932|0,0,64);az=208;aB=208;while(1){c[ax+76+(aB+512<<2)>>2]=0;c[ax+76+(aB+768<<2)>>2]=0;av=az+1&65535;if((av&65535)>223){break}else{az=av;aB=av&65535}}aB=ax;gGC(aB|0,9706056,76)|0;aB=c[2433530]|0;c[2438118]=aB;c[3528484]=at;c[2417276]=ay;c[1836236]=-1;c[2431670]=12876;c[2426980]=144;c[2426982]=108;az=ax;gGC(9706056,az|0,76)|0;c[2433530]=aB;c[2076596]=at;c[3541536]=ay;c[1836236]=0;gGz(9706056,0,76);az=ax;gGC(az|0,9706056,76)|0;c[2438118]=aB;c[3528484]=at;c[2417276]=ay;c[1836236]=-1;a[9660900]=a[9660900]|16;aB=c[2437644]|0;az=c[aB+1092>>2]|0;do{if((az|0)==0){av=c[aB+3144>>2]|0;if((av|0)==0){aU=0;aV=0;break}aA=gj[av&4095](-2)|0;av=c[2437644]|0;as=c[av+1092>>2]|0;aw=(aA&255)<<8;if((as|0)!=0){aW=as;aX=aw;ao=55556;break}as=c[av+3144>>2]|0;if((as|0)==0){aU=0;aV=aw;break}aU=gj[as&4095](-1)|0;aV=aw}else{aW=az;aX=(d[az+254|0]|0)<<8;ao=55556}}while(0);if((ao|0)==55556){aU=a[aW+255|0]|0;aV=aX}az=aU&255|aV;c[2415221]=az;b[4830442]=az&65535;a[9660920]=0;a[9660921]=0;a[9660928]=0;a[9660930]=0;a[9660931]=0;c[2415234]=0;gGz(9660901,0,5);c[2415235]=65535;c[2415237]=65535;a[9660932]=a[9660932]|64;mB(0);mB(1);UA();c[2429502]=0;c[2429500]=0;c[2438664]=0;c[2439460]=0;a[9757800]=0;a[9623080]=0;a[9623072]=0;a[683232]=0;a[9754673]=0;a[9754672]=0;a[9754680]=0;a[9718896]=0;a[9717272]=0;a[9718824]=0;ar=0;i=e;return ar|0}}while(0);c[2426820]=0;ar=1;i=e;return ar|0}function a9t(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>29){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1686644+(b*112|0)>>2];c[a+104>>2]=c[1686648+(b*112|0)>>2];c[a+108>>2]=c[1686652+(b*112|0)>>2];d=0;return d|0}function a9u(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<30&(d|0)==0)){e=1;return e|0}c[a>>2]=1686544+(b*112|0);e=0;return e|0}function a9v(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>28){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3389892+(b*112|0)>>2];c[a+104>>2]=c[3389896+(b*112|0)>>2];c[a+108>>2]=c[3389900+(b*112|0)>>2];d=0;return d|0}function a9w(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<29&(d|0)==0)){e=1;return e|0}c[a>>2]=3389792+(b*112|0);e=0;return e|0}function a9x(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>86){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3393040+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function a9y(){var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0;e=i;i=i+3240|0;f=e|0;g=e+112|0;h=e+120|0;j=e+232|0;k=e+240|0;l=e+352|0;m=e+360|0;n=e+472|0;o=e+480|0;p=e+592|0;q=e+600|0;r=e+712|0;s=e+720|0;t=e+832|0;u=e+840|0;v=e+952|0;w=e+960|0;x=e+1072|0;y=e+1080|0;z=e+1192|0;A=e+1200|0;B=e+1312|0;C=e+1320|0;D=e+1432|0;E=e+1440|0;F=e+1552|0;G=e+1560|0;H=e+1672|0;I=e+1680|0;J=e+1792|0;K=e+1800|0;L=e+1912|0;M=e+1920|0;N=e+2032|0;O=e+2040|0;P=e+2152|0;Q=e+2160|0;R=e+2272|0;S=e+2280|0;T=e+2392|0;U=e+2400|0;V=e+2512|0;W=e+2520|0;X=e+2632|0;Y=e+2640|0;Z=e+2752|0;_=e+2760|0;$=e+2872|0;aa=e+2880|0;ab=e+2992|0;ac=e+3e3|0;ad=e+3112|0;ae=e+3120|0;af=e+3232|0;c[2439448]=114688;c[3527090]=2080;c[3527094]=4096;c[2439452]=1024;c[3527096]=512;c[2438666]=2048;c[2439464]=8;c[2439462]=8;c[2437648]=12;c[2437646]=8;c[2431672]=c[(c[642608+(c[2436]<<2)>>2]|0)+124>>2];c[2426820]=0;a9Q();ah=c[2414438]|0;ai=0;while(1){if((ai|0)>=1024){break}aj=9638528+(ai<<2)|0;if((c[aj>>2]|0)==0){ak=55718;break}else{ai=ai+1|0}}do{if((ak|0)==55718){ai=gGq(ah)|0;c[aj>>2]=ai;if((ai|0)==0){break}gGz(ai|0,0,ah|0);c[2426820]=ai;gGz(ai|0,0,ah|0);a9Q();ai=0;while(1){if((ai|0)>=1024){al=0;break}am=9638528+(ai<<2)|0;if((c[am>>2]|0)==0){ak=55723;break}else{ai=ai+1|0}}do{if((ak|0)==55723){ai=gGq(98304)|0;c[am>>2]=ai;if((ai|0)==0){al=0;break}gGz(ai|0,0,98304);al=ai}}while(0);c[3529012]=al;ai=c[2385798]|0;if((c[3542200]|0)==0){an=1;i=e;return an|0}ao=ae+108|0;c[ao>>2]=0;ap=ae+100|0;c[ap>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](ae,0)|0;do{if((c[ao>>2]|0)!=0){aq=c[ap>>2]|0;c[af>>2]=9534384;ar=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ar&16383](af,0,0)|0;if((aq|0)<1){an=1;i=e;return an|0}if((gzL(ai,0,0)|0)==0){break}else{an=1}i=e;return an|0}}while(0);ai=(c[2385798]|0)+16384|0;if((c[3542200]|0)==0){an=1;i=e;return an|0}ap=ac+108|0;c[ap>>2]=0;ao=ac+100|0;c[ao>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](ac,1)|0;do{if((c[ap>>2]|0)!=0){aq=c[ao>>2]|0;c[ad>>2]=9534384;ar=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ar&16383](ad,1,0)|0;if((aq|0)<1){an=1;i=e;return an|0}if((gzL(ai,0,1)|0)==0){break}else{an=1}i=e;return an|0}}while(0);ai=(c[2385798]|0)+32768|0;if((c[3542200]|0)==0){an=1;i=e;return an|0}ao=aa+108|0;c[ao>>2]=0;ap=aa+100|0;c[ap>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](aa,2)|0;do{if((c[ao>>2]|0)!=0){aq=c[ap>>2]|0;c[ab>>2]=9534384;ar=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ar&16383](ab,2,0)|0;if((aq|0)<1){an=1;i=e;return an|0}if((gzL(ai,0,2)|0)==0){break}else{an=1}i=e;return an|0}}while(0);ai=(c[2385798]|0)+65536|0;if((c[3542200]|0)==0){an=1;i=e;return an|0}ap=_+108|0;c[ap>>2]=0;ao=_+100|0;c[ao>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](_,3)|0;do{if((c[ap>>2]|0)!=0){aq=c[ao>>2]|0;c[$>>2]=9534384;ar=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ar&16383]($,3,0)|0;if((aq|0)<1){an=1;i=e;return an|0}if((gzL(ai,0,3)|0)==0){break}else{an=1}i=e;return an|0}}while(0);ai=(c[2385798]|0)+98304|0;if((c[3542200]|0)==0){an=1;i=e;return an|0}ao=Y+108|0;c[ao>>2]=0;ap=Y+100|0;c[ap>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](Y,4)|0;do{if((c[ao>>2]|0)!=0){aq=c[ap>>2]|0;c[Z>>2]=9534384;ar=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ar&16383](Z,4,0)|0;if((aq|0)<1){an=1;i=e;return an|0}if((gzL(ai,0,4)|0)==0){break}else{an=1}i=e;return an|0}}while(0);ai=(c[3527098]|0)+16384|0;if((c[3542200]|0)==0){an=1;i=e;return an|0}ap=W+108|0;c[ap>>2]=0;ao=W+100|0;c[ao>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](W,5)|0;do{if((c[ap>>2]|0)!=0){aq=c[ao>>2]|0;c[X>>2]=9534384;ar=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ar&16383](X,5,0)|0;if((aq|0)<1){an=1;i=e;return an|0}if((gzL(ai,0,5)|0)==0){break}else{an=1}i=e;return an|0}}while(0);ai=(c[3527098]|0)+32768|0;if((c[3542200]|0)==0){an=1;i=e;return an|0}ao=U+108|0;c[ao>>2]=0;ap=U+100|0;c[ap>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](U,6)|0;do{if((c[ao>>2]|0)!=0){aq=c[ap>>2]|0;c[V>>2]=9534384;ar=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ar&16383](V,6,0)|0;if((aq|0)<1){an=1;i=e;return an|0}if((gzL(ai,0,6)|0)==0){break}else{an=1}i=e;return an|0}}while(0);ai=c[3529012]|0;gGz(ai|0,0,98304);if((c[3542200]|0)==0){an=1;i=e;return an|0}ap=S+108|0;c[ap>>2]=0;ao=S+100|0;c[ao>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](S,7)|0;do{if((c[ap>>2]|0)!=0){aq=c[ao>>2]|0;c[T>>2]=9534384;ar=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ar&16383](T,7,0)|0;if((aq|0)<1){an=1;i=e;return an|0}if((gzL(ai,0,7)|0)==0){break}else{an=1}i=e;return an|0}}while(0);ai=(c[3529012]|0)+32768|0;if((c[3542200]|0)==0){an=1;i=e;return an|0}ao=Q+108|0;c[ao>>2]=0;ap=Q+100|0;c[ap>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](Q,8)|0;do{if((c[ao>>2]|0)!=0){aq=c[ap>>2]|0;c[R>>2]=9534384;ar=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ar&16383](R,8,0)|0;if((aq|0)<1){an=1;i=e;return an|0}if((gzL(ai,0,8)|0)==0){break}else{an=1}i=e;return an|0}}while(0);ai=(c[3529012]|0)+65536|0;if((c[3542200]|0)==0){an=1;i=e;return an|0}ap=O+108|0;c[ap>>2]=0;ao=O+100|0;c[ao>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](O,9)|0;do{if((c[ap>>2]|0)!=0){aq=c[ao>>2]|0;c[P>>2]=9534384;ar=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ar&16383](P,9,0)|0;if((aq|0)<1){an=1;i=e;return an|0}if((gzL(ai,0,9)|0)==0){break}else{an=1}i=e;return an|0}}while(0);ai=c[3527094]|0;ao=c[2439464]|0;ap=c[2439462]|0;aq=c[3529012]|0;ar=c[2405764]|0;if((ai|0)>0){as=ag(ap,ao)|0;at=(ap|0)<1|(ao|0)<1;au=0;do{av=ag(au,as)|0;gGz(ar+av|0,0,as|0);aw=au<<6;ax=aw+524288|0;if(!at){ay=0;do{az=ax+(c[1238464+(ay<<2)>>2]|0)|0;aA=(ag(ay,ao)|0)+av|0;aB=0;do{aC=az+(c[614800+(aB<<2)>>2]|0)|0;if(((d[aq+((aC|0)/8|0)|0]|0)&128>>>((aC&7)>>>0)|0)!=0){aC=ar+(aA+aB)|0;a[aC]=a[aC]|4}aB=aB+1|0;}while((aB|0)<(ao|0));ay=ay+1|0;}while((ay|0)<(ap|0));ay=aw+262144|0;ax=0;while(1){aB=ay+(c[1238464+(ax<<2)>>2]|0)|0;aA=(ag(ax,ao)|0)+av|0;az=0;do{aC=aB+(c[614800+(az<<2)>>2]|0)|0;if(((d[aq+((aC|0)/8|0)|0]|0)&128>>>((aC&7)>>>0)|0)!=0){aC=ar+(aA+az)|0;a[aC]=a[aC]|2}az=az+1|0;}while((az|0)<(ao|0));az=ax+1|0;if((az|0)<(ap|0)){ax=az}else{aD=0;break}}do{ax=aw+(c[1238464+(aD<<2)>>2]|0)|0;ay=(ag(aD,ao)|0)+av|0;az=0;do{aA=ax+(c[614800+(az<<2)>>2]|0)|0;if(((d[aq+((aA|0)/8|0)|0]|0)&128>>>((aA&7)>>>0)|0)!=0){aA=ar+(ay+az)|0;a[aA]=a[aA]|1}az=az+1|0;}while((az|0)<(ao|0));aD=aD+1|0;}while((aD|0)<(ap|0))}au=au+1|0;}while((au|0)<(ai|0))}gGz(aq|0,0,98304);if((c[3542200]|0)==0){an=1;i=e;return an|0}ai=M+108|0;c[ai>>2]=0;au=M+100|0;c[au>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](M,10)|0;do{if((c[ai>>2]|0)!=0){ap=c[au>>2]|0;c[N>>2]=9534384;ao=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ao&16383](N,10,0)|0;if((ap|0)<1){an=1;i=e;return an|0}if((gzL(aq,0,10)|0)==0){break}else{an=1}i=e;return an|0}}while(0);aq=(c[3529012]|0)+16384|0;if((c[3542200]|0)==0){an=1;i=e;return an|0}au=K+108|0;c[au>>2]=0;ai=K+100|0;c[ai>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](K,11)|0;do{if((c[au>>2]|0)!=0){ap=c[ai>>2]|0;c[L>>2]=9534384;ao=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ao&16383](L,11,0)|0;if((ap|0)<1){an=1;i=e;return an|0}if((gzL(aq,0,11)|0)==0){break}else{an=1}i=e;return an|0}}while(0);aq=(c[3529012]|0)+32768|0;if((c[3542200]|0)==0){an=1;i=e;return an|0}ai=I+108|0;c[ai>>2]=0;au=I+100|0;c[au>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](I,12)|0;do{if((c[ai>>2]|0)!=0){ap=c[au>>2]|0;c[J>>2]=9534384;ao=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ao&16383](J,12,0)|0;if((ap|0)<1){an=1;i=e;return an|0}if((gzL(aq,0,12)|0)==0){break}else{an=1}i=e;return an|0}}while(0);aq=(c[3529012]|0)+49152|0;if((c[3542200]|0)==0){an=1;i=e;return an|0}au=G+108|0;c[au>>2]=0;ai=G+100|0;c[ai>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](G,13)|0;do{if((c[au>>2]|0)!=0){ap=c[ai>>2]|0;c[H>>2]=9534384;ao=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ao&16383](H,13,0)|0;if((ap|0)<1){an=1;i=e;return an|0}if((gzL(aq,0,13)|0)==0){break}else{an=1}i=e;return an|0}}while(0);aq=(c[3529012]|0)+65536|0;if((c[3542200]|0)==0){an=1;i=e;return an|0}ai=E+108|0;c[ai>>2]=0;au=E+100|0;c[au>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](E,14)|0;do{if((c[ai>>2]|0)!=0){ap=c[au>>2]|0;c[F>>2]=9534384;ao=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ao&16383](F,14,0)|0;if((ap|0)<1){an=1;i=e;return an|0}if((gzL(aq,0,14)|0)==0){break}else{an=1}i=e;return an|0}}while(0);aq=(c[3529012]|0)+81920|0;if((c[3542200]|0)==0){an=1;i=e;return an|0}au=C+108|0;c[au>>2]=0;ai=C+100|0;c[ai>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](C,15)|0;do{if((c[au>>2]|0)!=0){ap=c[ai>>2]|0;c[D>>2]=9534384;ao=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ao&16383](D,15,0)|0;if((ap|0)<1){an=1;i=e;return an|0}if((gzL(aq,0,15)|0)==0){break}else{an=1}i=e;return an|0}}while(0);aq=c[2439452]|0;ai=c[3529012]|0;au=c[3529014]|0;if((aq|0)>0){ap=0;do{ao=ap<<8;gGz(au+ao|0,0,256);ar=ao+524288|0;at=0;do{as=ar+(c[609008+(at<<2)>>2]|0)|0;av=(at<<4)+ao|0;aw=0;do{az=as+(c[597864+(aw<<2)>>2]|0)|0;if(((d[ai+((az|0)/8|0)|0]|0)&128>>>((az&7)>>>0)|0)!=0){az=au+(av+aw)|0;a[az]=a[az]|4}aw=aw+1|0;}while((aw|0)<16);at=at+1|0;}while((at|0)<16);at=ao+262144|0;ar=0;while(1){aw=at+(c[609008+(ar<<2)>>2]|0)|0;av=(ar<<4)+ao|0;as=0;do{az=aw+(c[597864+(as<<2)>>2]|0)|0;if(((d[ai+((az|0)/8|0)|0]|0)&128>>>((az&7)>>>0)|0)!=0){az=au+(av+as)|0;a[az]=a[az]|2}as=as+1|0;}while((as|0)<16);as=ar+1|0;if((as|0)<16){ar=as}else{aE=0;break}}do{ar=ao+(c[609008+(aE<<2)>>2]|0)|0;at=(aE<<4)+ao|0;as=0;do{av=ar+(c[597864+(as<<2)>>2]|0)|0;if(((d[ai+((av|0)/8|0)|0]|0)&128>>>((av&7)>>>0)|0)!=0){av=au+(at+as)|0;a[av]=a[av]|1}as=as+1|0;}while((as|0)<16);aE=aE+1|0;}while((aE|0)<16);ap=ap+1|0;}while((ap|0)<(aq|0))}gGz(ai|0,0,98304);aq=0;while(1){if((aq|0)>=1024){aF=0;break}aG=9638528+(aq<<2)|0;if((c[aG>>2]|0)==0){ak=55809;break}else{aq=aq+1|0}}do{if((ak|0)==55809){aq=gGq(98304)|0;c[aG>>2]=aq;if((aq|0)==0){aF=0;break}gGz(aq|0,0,98304);aF=aq}}while(0);if((c[3542200]|0)==0){an=1;i=e;return an|0}aq=A+108|0;c[aq>>2]=0;ai=A+100|0;c[ai>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](A,16)|0;do{if((c[aq>>2]|0)!=0){ap=c[ai>>2]|0;c[B>>2]=9534384;au=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[au&16383](B,16,0)|0;if((ap|0)<1){an=1;i=e;return an|0}if((gzL(aF,0,16)|0)==0){break}else{an=1}i=e;return an|0}}while(0);ai=aF+16384|0;if((c[3542200]|0)==0){an=1;i=e;return an|0}aq=y+108|0;c[aq>>2]=0;ap=y+100|0;c[ap>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](y,17)|0;do{if((c[aq>>2]|0)!=0){au=c[ap>>2]|0;c[z>>2]=9534384;ao=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ao&16383](z,17,0)|0;if((au|0)<1){an=1;i=e;return an|0}if((gzL(ai,0,17)|0)==0){break}else{an=1}i=e;return an|0}}while(0);ap=aF+32768|0;if((c[3542200]|0)==0){an=1;i=e;return an|0}aq=w+108|0;c[aq>>2]=0;au=w+100|0;c[au>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](w,18)|0;do{if((c[aq>>2]|0)!=0){ao=c[au>>2]|0;c[x>>2]=9534384;as=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[as&16383](x,18,0)|0;if((ao|0)<1){an=1;i=e;return an|0}if((gzL(ap,0,18)|0)==0){break}else{an=1}i=e;return an|0}}while(0);au=c[3529012]|0;gGC(au|0,aF|0,2048)|0;aq=au+8192|0;ao=aF+2048|0;gGC(aq|0,ao|0,2048)|0;ao=au+2048|0;aq=aF+4096|0;gGC(ao|0,aq|0,2048)|0;aq=au+10240|0;as=aF+6144|0;gGC(aq|0,as|0,2048)|0;as=au+4096|0;aq=aF+8192|0;gGC(as|0,aq|0,2048)|0;aq=au+12288|0;as=aF+10240|0;gGC(aq|0,as|0,2048)|0;as=aF+12288|0;gGC(ao|0,as|0,2048)|0;as=au+14336|0;ao=aF+14336|0;gGC(as|0,ao|0,2048)|0;ao=au+16384|0;gGC(ao|0,ai|0,2048)|0;ao=au+24576|0;as=aF+18432|0;gGC(ao|0,as|0,2048)|0;as=au+18432|0;ao=aF+20480|0;gGC(as|0,ao|0,2048)|0;ao=au+26624|0;as=aF+22528|0;gGC(ao|0,as|0,2048)|0;as=au+20480|0;ao=aF+24576|0;gGC(as|0,ao|0,2048)|0;ao=au+28672|0;as=aF+26624|0;gGC(ao|0,as|0,2048)|0;as=au+22528|0;ao=aF+28672|0;gGC(as|0,ao|0,2048)|0;ao=au+30720|0;as=aF+30720|0;gGC(ao|0,as|0,2048)|0;as=au+32768|0;gGC(as|0,ap|0,2048)|0;as=au+40960|0;ao=aF+34816|0;gGC(as|0,ao|0,2048)|0;ao=au+34816|0;as=aF+36864|0;gGC(ao|0,as|0,2048)|0;as=au+43008|0;ao=aF+38912|0;gGC(as|0,ao|0,2048)|0;ao=au+36864|0;as=aF+40960|0;gGC(ao|0,as|0,2048)|0;as=au+45056|0;ao=aF+43008|0;gGC(as|0,ao|0,2048)|0;ao=au+38912|0;as=aF+45056|0;gGC(ao|0,as|0,2048)|0;as=au+47104|0;ao=aF+47104|0;gGC(as|0,ao|0,2048)|0;ao=0;while(1){if((ao|0)>=1024){aH=au;break}aI=9638528+(ao<<2)|0;if((c[aI>>2]|0)==(aF|0)){ak=55826;break}else{ao=ao+1|0}}if((ak|0)==55826){gGr(aF);c[aI>>2]=0;aH=c[3529012]|0}ao=c[3527096]|0;au=c[2437648]|0;ap=c[2437646]|0;ai=c[2405778]|0;if((ao|0)>0){as=ag(ap,au)|0;aq=(ap|0)<1|(au|0)<1;at=0;do{ar=ag(at,as)|0;gGz(ai+ar|0,0,as|0);av=at<<6;if(!aq){aw=0;do{az=av+(c[1238464+(aw<<2)>>2]|0)|0;ay=(ag(aw,au)|0)+ar|0;ax=0;do{aA=az+(c[1689904+(ax<<2)>>2]|0)|0;if(((d[aH+((aA|0)/8|0)|0]|0)&128>>>((aA&7)>>>0)|0)!=0){aA=ai+(ay+ax)|0;a[aA]=a[aA]|4}ax=ax+1|0;}while((ax|0)<(au|0));aw=aw+1|0;}while((aw|0)<(ap|0));aw=av+131072|0;ax=0;do{ay=aw+(c[1238464+(ax<<2)>>2]|0)|0;az=(ag(ax,au)|0)+ar|0;aA=0;do{aB=ay+(c[1689904+(aA<<2)>>2]|0)|0;if(((d[aH+((aB|0)/8|0)|0]|0)&128>>>((aB&7)>>>0)|0)!=0){aB=ai+(az+aA)|0;a[aB]=a[aB]|2}aA=aA+1|0;}while((aA|0)<(au|0));ax=ax+1|0;}while((ax|0)<(ap|0));ax=av+262144|0;aw=0;do{aA=ax+(c[1238464+(aw<<2)>>2]|0)|0;az=(ag(aw,au)|0)+ar|0;ay=0;do{aB=aA+(c[1689904+(ay<<2)>>2]|0)|0;if(((d[aH+((aB|0)/8|0)|0]|0)&128>>>((aB&7)>>>0)|0)!=0){aB=ai+(az+ay)|0;a[aB]=a[aB]|1}ay=ay+1|0;}while((ay|0)<(au|0));aw=aw+1|0;}while((aw|0)<(ap|0))}at=at+1|0;}while((at|0)<(ao|0))}ao=c[3527092]|0;if((c[3542200]|0)==0){an=1;i=e;return an|0}at=u+108|0;c[at>>2]=0;ap=u+100|0;c[ap>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](u,19)|0;do{if((c[at>>2]|0)!=0){au=c[ap>>2]|0;c[v>>2]=9534384;ai=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ai&16383](v,19,0)|0;if((au|0)<1){an=1;i=e;return an|0}if((gzL(ao,0,19)|0)==0){break}else{an=1}i=e;return an|0}}while(0);ao=(c[3527092]|0)+512|0;if((c[3542200]|0)==0){an=1;i=e;return an|0}ap=s+108|0;c[ap>>2]=0;at=s+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](s,20)|0;do{if((c[ap>>2]|0)!=0){au=c[at>>2]|0;c[t>>2]=9534384;ai=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ai&16383](t,20,0)|0;if((au|0)<1){an=1;i=e;return an|0}if((gzL(ao,0,20)|0)==0){break}else{an=1}i=e;return an|0}}while(0);ao=(c[3527092]|0)+768|0;if((c[3542200]|0)==0){an=1;i=e;return an|0}at=q+108|0;c[at>>2]=0;ap=q+100|0;c[ap>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](q,21)|0;do{if((c[at>>2]|0)!=0){au=c[ap>>2]|0;c[r>>2]=9534384;ai=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ai&16383](r,21,0)|0;if((au|0)<1){an=1;i=e;return an|0}if((gzL(ao,0,21)|0)==0){break}else{an=1}i=e;return an|0}}while(0);ao=(c[3527092]|0)+1024|0;if((c[3542200]|0)==0){an=1;i=e;return an|0}ap=o+108|0;c[ap>>2]=0;at=o+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](o,22)|0;do{if((c[ap>>2]|0)!=0){au=c[at>>2]|0;c[p>>2]=9534384;ai=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ai&16383](p,22,0)|0;if((au|0)<1){an=1;i=e;return an|0}if((gzL(ao,0,22)|0)==0){break}else{an=1}i=e;return an|0}}while(0);ao=(c[3527092]|0)+1280|0;if((c[3542200]|0)==0){an=1;i=e;return an|0}at=m+108|0;c[at>>2]=0;ap=m+100|0;c[ap>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,23)|0;do{if((c[at>>2]|0)!=0){au=c[ap>>2]|0;c[n>>2]=9534384;ai=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ai&16383](n,23,0)|0;if((au|0)<1){an=1;i=e;return an|0}if((gzL(ao,0,23)|0)==0){break}else{an=1}i=e;return an|0}}while(0);ao=(c[3527092]|0)+1536|0;if((c[3542200]|0)==0){an=1;i=e;return an|0}ap=k+108|0;c[ap>>2]=0;at=k+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,24)|0;do{if((c[ap>>2]|0)!=0){au=c[at>>2]|0;c[l>>2]=9534384;ai=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ai&16383](l,24,0)|0;if((au|0)<1){an=1;i=e;return an|0}if((gzL(ao,0,24)|0)==0){break}else{an=1}i=e;return an|0}}while(0);ao=(c[3527092]|0)+1792|0;if((c[3542200]|0)==0){an=1;i=e;return an|0}at=h+108|0;c[at>>2]=0;ap=h+100|0;c[ap>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](h,25)|0;do{if((c[at>>2]|0)!=0){au=c[ap>>2]|0;c[j>>2]=9534384;ai=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ai&16383](j,25,0)|0;if((au|0)<1){an=1;i=e;return an|0}if((gzL(ao,0,25)|0)==0){break}else{an=1}i=e;return an|0}}while(0);ao=(c[3527092]|0)+1824|0;if((c[3542200]|0)==0){an=1;i=e;return an|0}ap=f+108|0;c[ap>>2]=0;at=f+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,26)|0;do{if((c[ap>>2]|0)!=0){au=c[at>>2]|0;c[g>>2]=9534384;ai=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ai&16383](g,26,0)|0;if((au|0)<1){an=1;i=e;return an|0}if((gzL(ao,0,26)|0)==0){break}else{an=1}i=e;return an|0}}while(0);ao=c[3529012]|0;at=0;while(1){if((at|0)>=1024){break}aJ=9638528+(at<<2)|0;if((c[aJ>>2]|0)==(ao|0)){ak=55871;break}else{at=at+1|0}}if((ak|0)==55871){gGr(ao);c[aJ>>2]=0}c[3529012]=0;a9H();at=c[2439330]|0;if((at|0)!=0){ap=at;gGC(9706056,ap|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];ap=c[3528484]|0;c[2076596]=ap;au=c[2417276]|0;c[3541536]=au;c[1836236]=0;c[at+4184>>2]=712;ai=c[2385798]|0;c[at+588>>2]=ai+98304;c[at+592>>2]=ai+98560;c[at+596>>2]=ai+98816;c[at+600>>2]=ai+99072;c[at+604>>2]=ai+99328;c[at+608>>2]=ai+99584;c[at+612>>2]=ai+99840;c[at+616>>2]=ai+100096;c[at+620>>2]=ai+100352;c[at+624>>2]=ai+100608;c[at+628>>2]=ai+100864;c[at+632>>2]=ai+101120;c[at+636>>2]=ai+101376;c[at+640>>2]=ai+101632;c[at+644>>2]=ai+101888;c[at+648>>2]=ai+102144;aq=128;as=128;while(1){aw=ai+((as<<8)+65536)|0;c[at+76+(as+512<<2)>>2]=aw;c[at+76+(as+768<<2)>>2]=aw;aw=aq+1&65535;if((aw&65535)>143){break}else{aq=aw;as=aw&65535}}c[at+652>>2]=ai+32768;c[at+656>>2]=ai+33024;c[at+660>>2]=ai+33280;c[at+664>>2]=ai+33536;c[at+668>>2]=ai+33792;c[at+672>>2]=ai+34048;c[at+676>>2]=ai+34304;c[at+680>>2]=ai+34560;c[at+684>>2]=ai+34816;c[at+688>>2]=ai+35072;c[at+692>>2]=ai+35328;c[at+696>>2]=ai+35584;c[at+700>>2]=ai+35840;c[at+704>>2]=ai+36096;c[at+708>>2]=ai+36352;c[at+712>>2]=ai+36608;as=144;aq=144;while(1){ao=ai+((aq<<8)-4096)|0;c[at+76+(aq+512<<2)>>2]=ao;c[at+76+(aq+768<<2)>>2]=ao;ao=as+1&65535;if((ao&65535)>159){break}else{as=ao;aq=ao&65535}}aq=c[3529010]|0;as=160;ai=160;while(1){c[at+76+(ai<<2)>>2]=aq+((ai<<8)-40960);ao=as+1&65535;if((ao&65535)>191){aK=160;aL=160;break}else{as=ao;ai=ao&65535}}while(1){c[at+76+(aL+256<<2)>>2]=aq+((aL<<8)-40960);ai=aK+1&65535;if((ai&65535)>191){aM=160;aN=160;break}else{aK=ai;aL=ai&65535}}while(1){ai=aq+((aN<<8)-40960)|0;c[at+76+(aN+512<<2)>>2]=ai;c[at+76+(aN+768<<2)>>2]=ai;ai=aM+1&65535;if((ai&65535)>191){break}else{aM=ai;aN=ai&65535}}aq=c[3529018]|0;c[at+876>>2]=aq;ai=aq+256|0;c[at+880>>2]=ai;as=aq+512|0;c[at+884>>2]=as;ao=aq+768|0;c[at+888>>2]=ao;aw=aq+1024|0;c[at+892>>2]=aw;ar=aq+1280|0;c[at+896>>2]=ar;ax=aq+1536|0;c[at+900>>2]=ax;av=aq+1792|0;c[at+904>>2]=av;c[at+1900>>2]=aq;c[at+1904>>2]=ai;c[at+1908>>2]=as;c[at+1912>>2]=ao;c[at+1916>>2]=aw;c[at+1920>>2]=ar;c[at+1924>>2]=ax;c[at+1928>>2]=av;c[at+2924>>2]=aq;c[at+3948>>2]=aq;c[at+2928>>2]=ai;c[at+3952>>2]=ai;c[at+2932>>2]=as;c[at+3956>>2]=as;c[at+2936>>2]=ao;c[at+3960>>2]=ao;c[at+2940>>2]=aw;c[at+3964>>2]=aw;c[at+2944>>2]=ar;c[at+3968>>2]=ar;c[at+2948>>2]=ax;c[at+3972>>2]=ax;c[at+2952>>2]=av;c[at+3976>>2]=av;gGz(at+908|0,0,64);gGz(at+1932|0,0,64);av=208;ax=208;while(1){c[at+76+(ax+512<<2)>>2]=0;c[at+76+(ax+768<<2)>>2]=0;ar=av+1&65535;if((ar&65535)>223){break}else{av=ar;ax=ar&65535}}ax=at;gGC(ax|0,9706056,76)|0;ax=c[2433530]|0;c[2438118]=ax;c[3528484]=ap;c[2417276]=au;c[1836236]=-1;c[2431670]=2190;c[2426980]=42;c[2426982]=108;c[2426978]=1792;av=at;gGC(9706056,av|0,76)|0;c[2433530]=ax;c[2076596]=ap;c[3541536]=au;c[1836236]=0;gGz(9706056,0,76);av=at;gGC(av|0,9706056,76)|0;c[2438118]=ax;c[3528484]=ap;c[2417276]=au;c[1836236]=-1;a[9660900]=a[9660900]|16;ax=c[2437644]|0;av=c[ax+1092>>2]|0;do{if((av|0)==0){ar=c[ax+3144>>2]|0;if((ar|0)==0){aO=0;aP=0;break}aw=gj[ar&4095](-2)|0;ar=c[2437644]|0;ao=c[ar+1092>>2]|0;as=(aw&255)<<8;if((ao|0)!=0){aQ=ao;aR=as;ak=55888;break}ao=c[ar+3144>>2]|0;if((ao|0)==0){aO=0;aP=as;break}aO=gj[ao&4095](-1)|0;aP=as}else{aQ=av;aR=(d[av+254|0]|0)<<8;ak=55888}}while(0);if((ak|0)==55888){aO=a[aQ+255|0]|0;aP=aR}av=aO&255|aP;c[2415221]=av;b[4830442]=av&65535;a[9660920]=0;a[9660921]=0;a[9660928]=0;a[9660930]=0;a[9660931]=0;c[2415234]=0;gGz(9660901,0,5);c[2415235]=65535;c[2415237]=65535;a[9660932]=a[9660932]|64;mB(0);mB(1);UA();c[2429502]=0;c[2429500]=0;c[2438664]=0;c[2439460]=0;a[9757800]=0;a[9623080]=0;a[9623072]=0;a[683232]=0;a[9754673]=0;a[9754672]=0;a[9754680]=0;a[9718896]=0;a[9717272]=0;a[9718824]=0;an=0;i=e;return an|0}}while(0);c[2426820]=0;an=1;i=e;return an|0}function a9z(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>26){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3195372+(b*112|0)>>2];c[a+104>>2]=c[3195376+(b*112|0)>>2];c[a+108>>2]=c[3195380+(b*112|0)>>2];d=0;return d|0}function a9A(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<27&(d|0)==0)){e=1;return e|0}c[a>>2]=3195272+(b*112|0);e=0;return e|0}function a9B(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>81){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3198296+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function a9C(){var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0;e=i;i=i+3e3|0;f=e|0;g=e+112|0;h=e+120|0;j=e+232|0;k=e+240|0;l=e+352|0;m=e+360|0;n=e+472|0;o=e+480|0;p=e+592|0;q=e+600|0;r=e+712|0;s=e+720|0;t=e+832|0;u=e+840|0;v=e+952|0;w=e+960|0;x=e+1072|0;y=e+1080|0;z=e+1192|0;A=e+1200|0;B=e+1312|0;C=e+1320|0;D=e+1432|0;E=e+1440|0;F=e+1552|0;G=e+1560|0;H=e+1672|0;I=e+1680|0;J=e+1792|0;K=e+1800|0;L=e+1912|0;M=e+1920|0;N=e+2032|0;O=e+2040|0;P=e+2152|0;Q=e+2160|0;R=e+2272|0;S=e+2280|0;T=e+2392|0;U=e+2400|0;V=e+2512|0;W=e+2520|0;X=e+2632|0;Y=e+2640|0;Z=e+2752|0;_=e+2760|0;$=e+2872|0;aa=e+2880|0;ab=e+2992|0;c[2439448]=65536;c[3527090]=1824;c[3527094]=1024;c[2439452]=1024;c[3527096]=1024;c[2438666]=2048;c[2439464]=8;c[2439462]=16;c[2437648]=12;c[2437646]=8;c[2431672]=c[(c[642608+(c[2436]<<2)>>2]|0)+124>>2];c[2426820]=0;a9Q();ac=c[2414438]|0;ad=0;while(1){if((ad|0)>=1024){break}ae=9638528+(ad<<2)|0;if((c[ae>>2]|0)==0){af=56032;break}else{ad=ad+1|0}}do{if((af|0)==56032){ad=gGq(ac)|0;c[ae>>2]=ad;if((ad|0)==0){break}gGz(ad|0,0,ac|0);c[2426820]=ad;gGz(ad|0,0,ac|0);a9Q();ad=0;while(1){if((ad|0)>=1024){ah=0;break}ai=9638528+(ad<<2)|0;if((c[ai>>2]|0)==0){af=56037;break}else{ad=ad+1|0}}do{if((af|0)==56037){ad=gGq(98304)|0;c[ai>>2]=ad;if((ad|0)==0){ah=0;break}gGz(ad|0,0,98304);ah=ad}}while(0);c[3529012]=ah;ad=c[2385798]|0;if((c[3542200]|0)==0){aj=1;i=e;return aj|0}ak=aa+108|0;c[ak>>2]=0;al=aa+100|0;c[al>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](aa,0)|0;do{if((c[ak>>2]|0)!=0){am=c[al>>2]|0;c[ab>>2]=9534384;an=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[an&16383](ab,0,0)|0;if((am|0)<1){aj=1;i=e;return aj|0}if((gzL(ad,0,0)|0)==0){break}else{aj=1}i=e;return aj|0}}while(0);ad=(c[2385798]|0)+16384|0;if((c[3542200]|0)==0){aj=1;i=e;return aj|0}al=_+108|0;c[al>>2]=0;ak=_+100|0;c[ak>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](_,1)|0;do{if((c[al>>2]|0)!=0){am=c[ak>>2]|0;c[$>>2]=9534384;an=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[an&16383]($,1,0)|0;if((am|0)<1){aj=1;i=e;return aj|0}if((gzL(ad,0,1)|0)==0){break}else{aj=1}i=e;return aj|0}}while(0);ad=(c[2385798]|0)+32768|0;if((c[3542200]|0)==0){aj=1;i=e;return aj|0}ak=Y+108|0;c[ak>>2]=0;al=Y+100|0;c[al>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](Y,2)|0;do{if((c[ak>>2]|0)!=0){am=c[al>>2]|0;c[Z>>2]=9534384;an=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[an&16383](Z,2,0)|0;if((am|0)<1){aj=1;i=e;return aj|0}if((gzL(ad,0,2)|0)==0){break}else{aj=1}i=e;return aj|0}}while(0);ad=(c[2385798]|0)+49152|0;if((c[3542200]|0)==0){aj=1;i=e;return aj|0}al=W+108|0;c[al>>2]=0;ak=W+100|0;c[ak>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](W,3)|0;do{if((c[al>>2]|0)!=0){am=c[ak>>2]|0;c[X>>2]=9534384;an=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[an&16383](X,3,0)|0;if((am|0)<1){aj=1;i=e;return aj|0}if((gzL(ad,0,3)|0)==0){break}else{aj=1}i=e;return aj|0}}while(0);ad=(c[3527098]|0)+32768|0;if((c[3542200]|0)==0){aj=1;i=e;return aj|0}ak=U+108|0;c[ak>>2]=0;al=U+100|0;c[al>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](U,4)|0;do{if((c[ak>>2]|0)!=0){am=c[al>>2]|0;c[V>>2]=9534384;an=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[an&16383](V,4,0)|0;if((am|0)<1){aj=1;i=e;return aj|0}if((gzL(ad,0,4)|0)==0){break}else{aj=1}i=e;return aj|0}}while(0);gGz(c[3529012]|0,0,98304);ad=0;while(1){if((ad|0)>=1024){ao=0;break}ap=9638528+(ad<<2)|0;if((c[ap>>2]|0)==0){af=56062;break}else{ad=ad+1|0}}do{if((af|0)==56062){ad=gGq(98304)|0;c[ap>>2]=ad;if((ad|0)==0){ao=0;break}gGz(ad|0,0,98304);ao=ad}}while(0);if((c[3542200]|0)==0){aj=1;i=e;return aj|0}ad=S+108|0;c[ad>>2]=0;al=S+100|0;c[al>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](S,5)|0;do{if((c[ad>>2]|0)!=0){ak=c[al>>2]|0;c[T>>2]=9534384;am=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[am&16383](T,5,0)|0;if((ak|0)<1){aj=1;i=e;return aj|0}if((gzL(ao,0,5)|0)==0){break}else{aj=1}i=e;return aj|0}}while(0);al=ao+32768|0;if((c[3542200]|0)==0){aj=1;i=e;return aj|0}ad=Q+108|0;c[ad>>2]=0;ak=Q+100|0;c[ak>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](Q,6)|0;do{if((c[ad>>2]|0)!=0){am=c[ak>>2]|0;c[R>>2]=9534384;an=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[an&16383](R,6,0)|0;if((am|0)<1){aj=1;i=e;return aj|0}if((gzL(al,0,6)|0)==0){break}else{aj=1}i=e;return aj|0}}while(0);al=ao+65536|0;if((c[3542200]|0)==0){aj=1;i=e;return aj|0}ak=O+108|0;c[ak>>2]=0;ad=O+100|0;c[ad>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](O,7)|0;do{if((c[ak>>2]|0)!=0){am=c[ad>>2]|0;c[P>>2]=9534384;an=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[an&16383](P,7,0)|0;if((am|0)<1){aj=1;i=e;return aj|0}if((gzL(al,0,7)|0)==0){break}else{aj=1}i=e;return aj|0}}while(0);al=c[3529012]|0;ad=ao+16384|0;gGC(al|0,ad|0,16384)|0;ad=al+16384|0;ak=ao+49152|0;gGC(ad|0,ak|0,16384)|0;ak=al+32768|0;ad=ao+81920|0;gGC(ak|0,ad|0,16384)|0;ad=0;while(1){if((ad|0)>=1024){aq=al;break}ar=9638528+(ad<<2)|0;if((c[ar>>2]|0)==(ao|0)){af=56079;break}else{ad=ad+1|0}}if((af|0)==56079){gGr(ao);c[ar>>2]=0;aq=c[3529012]|0}ad=c[3527094]|0;al=c[2439464]|0;ak=c[2439462]|0;am=c[2405764]|0;if((ad|0)>0){an=ag(ak,al)|0;as=(ak|0)<1|(al|0)<1;at=0;do{au=ag(at,an)|0;gGz(am+au|0,0,an|0);av=at<<7;aw=av+262144|0;if(!as){ax=0;do{ay=aw+(c[609008+(ax<<2)>>2]|0)|0;az=(ag(ax,al)|0)+au|0;aA=0;do{aB=ay+(c[614800+(aA<<2)>>2]|0)|0;if(((d[aq+((aB|0)/8|0)|0]|0)&128>>>((aB&7)>>>0)|0)!=0){aB=am+(az+aA)|0;a[aB]=a[aB]|4}aA=aA+1|0;}while((aA|0)<(al|0));ax=ax+1|0;}while((ax|0)<(ak|0));ax=av+131072|0;aw=0;while(1){aA=ax+(c[609008+(aw<<2)>>2]|0)|0;az=(ag(aw,al)|0)+au|0;ay=0;do{aB=aA+(c[614800+(ay<<2)>>2]|0)|0;if(((d[aq+((aB|0)/8|0)|0]|0)&128>>>((aB&7)>>>0)|0)!=0){aB=am+(az+ay)|0;a[aB]=a[aB]|2}ay=ay+1|0;}while((ay|0)<(al|0));ay=aw+1|0;if((ay|0)<(ak|0)){aw=ay}else{aC=0;break}}do{aw=av+(c[609008+(aC<<2)>>2]|0)|0;ax=(ag(aC,al)|0)+au|0;ay=0;do{az=aw+(c[614800+(ay<<2)>>2]|0)|0;if(((d[aq+((az|0)/8|0)|0]|0)&128>>>((az&7)>>>0)|0)!=0){az=am+(ax+ay)|0;a[az]=a[az]|1}ay=ay+1|0;}while((ay|0)<(al|0));aC=aC+1|0;}while((aC|0)<(ak|0))}at=at+1|0;}while((at|0)<(ad|0))}gGz(aq|0,0,98304);if((c[3542200]|0)==0){aj=1;i=e;return aj|0}ad=M+108|0;c[ad>>2]=0;at=M+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](M,8)|0;do{if((c[ad>>2]|0)!=0){ak=c[at>>2]|0;c[N>>2]=9534384;al=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[al&16383](N,8,0)|0;if((ak|0)<1){aj=1;i=e;return aj|0}if((gzL(aq,0,8)|0)==0){break}else{aj=1}i=e;return aj|0}}while(0);at=(c[3529012]|0)+16384|0;if((c[3542200]|0)==0){aj=1;i=e;return aj|0}ad=K+108|0;c[ad>>2]=0;ak=K+100|0;c[ak>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](K,9)|0;do{if((c[ad>>2]|0)!=0){al=c[ak>>2]|0;c[L>>2]=9534384;am=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[am&16383](L,9,0)|0;if((al|0)<1){aj=1;i=e;return aj|0}if((gzL(at,0,9)|0)==0){break}else{aj=1}i=e;return aj|0}}while(0);at=(c[3529012]|0)+32768|0;if((c[3542200]|0)==0){aj=1;i=e;return aj|0}ak=I+108|0;c[ak>>2]=0;ad=I+100|0;c[ad>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](I,10)|0;do{if((c[ak>>2]|0)!=0){al=c[ad>>2]|0;c[J>>2]=9534384;am=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[am&16383](J,10,0)|0;if((al|0)<1){aj=1;i=e;return aj|0}if((gzL(at,0,10)|0)==0){break}else{aj=1}i=e;return aj|0}}while(0);at=(c[3529012]|0)+49152|0;if((c[3542200]|0)==0){aj=1;i=e;return aj|0}ad=G+108|0;c[ad>>2]=0;ak=G+100|0;c[ak>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](G,11)|0;do{if((c[ad>>2]|0)!=0){al=c[ak>>2]|0;c[H>>2]=9534384;am=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[am&16383](H,11,0)|0;if((al|0)<1){aj=1;i=e;return aj|0}if((gzL(at,0,11)|0)==0){break}else{aj=1}i=e;return aj|0}}while(0);at=(c[3529012]|0)+65536|0;if((c[3542200]|0)==0){aj=1;i=e;return aj|0}ak=E+108|0;c[ak>>2]=0;ad=E+100|0;c[ad>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](E,12)|0;do{if((c[ak>>2]|0)!=0){al=c[ad>>2]|0;c[F>>2]=9534384;am=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[am&16383](F,12,0)|0;if((al|0)<1){aj=1;i=e;return aj|0}if((gzL(at,0,12)|0)==0){break}else{aj=1}i=e;return aj|0}}while(0);at=(c[3529012]|0)+81920|0;if((c[3542200]|0)==0){aj=1;i=e;return aj|0}ad=C+108|0;c[ad>>2]=0;ak=C+100|0;c[ak>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](C,13)|0;do{if((c[ad>>2]|0)!=0){al=c[ak>>2]|0;c[D>>2]=9534384;am=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[am&16383](D,13,0)|0;if((al|0)<1){aj=1;i=e;return aj|0}if((gzL(at,0,13)|0)==0){break}else{aj=1}i=e;return aj|0}}while(0);at=c[2439452]|0;ak=c[3529012]|0;ad=c[3529014]|0;if((at|0)>0){al=0;do{am=al<<8;gGz(ad+am|0,0,256);as=am+524288|0;an=0;do{au=as+(c[609008+(an<<2)>>2]|0)|0;av=(an<<4)+am|0;ay=0;do{ax=au+(c[597864+(ay<<2)>>2]|0)|0;if(((d[ak+((ax|0)/8|0)|0]|0)&128>>>((ax&7)>>>0)|0)!=0){ax=ad+(av+ay)|0;a[ax]=a[ax]|4}ay=ay+1|0;}while((ay|0)<16);an=an+1|0;}while((an|0)<16);an=am+262144|0;as=0;while(1){ay=an+(c[609008+(as<<2)>>2]|0)|0;av=(as<<4)+am|0;au=0;do{ax=ay+(c[597864+(au<<2)>>2]|0)|0;if(((d[ak+((ax|0)/8|0)|0]|0)&128>>>((ax&7)>>>0)|0)!=0){ax=ad+(av+au)|0;a[ax]=a[ax]|2}au=au+1|0;}while((au|0)<16);au=as+1|0;if((au|0)<16){as=au}else{aD=0;break}}do{as=am+(c[609008+(aD<<2)>>2]|0)|0;an=(aD<<4)+am|0;au=0;do{av=as+(c[597864+(au<<2)>>2]|0)|0;if(((d[ak+((av|0)/8|0)|0]|0)&128>>>((av&7)>>>0)|0)!=0){av=ad+(an+au)|0;a[av]=a[av]|1}au=au+1|0;}while((au|0)<16);aD=aD+1|0;}while((aD|0)<16);al=al+1|0;}while((al|0)<(at|0))}gGz(ak|0,0,98304);if((c[3542200]|0)==0){aj=1;i=e;return aj|0}at=A+108|0;c[at>>2]=0;al=A+100|0;c[al>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](A,14)|0;do{if((c[at>>2]|0)!=0){ad=c[al>>2]|0;c[B>>2]=9534384;am=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[am&16383](B,14,0)|0;if((ad|0)<1){aj=1;i=e;return aj|0}if((gzL(ak,0,14)|0)==0){break}else{aj=1}i=e;return aj|0}}while(0);ak=(c[3529012]|0)+16384|0;if((c[3542200]|0)==0){aj=1;i=e;return aj|0}al=y+108|0;c[al>>2]=0;at=y+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](y,15)|0;do{if((c[al>>2]|0)!=0){ad=c[at>>2]|0;c[z>>2]=9534384;am=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[am&16383](z,15,0)|0;if((ad|0)<1){aj=1;i=e;return aj|0}if((gzL(ak,0,15)|0)==0){break}else{aj=1}i=e;return aj|0}}while(0);ak=(c[3529012]|0)+32768|0;if((c[3542200]|0)==0){aj=1;i=e;return aj|0}at=w+108|0;c[at>>2]=0;al=w+100|0;c[al>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](w,16)|0;do{if((c[at>>2]|0)!=0){ad=c[al>>2]|0;c[x>>2]=9534384;am=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[am&16383](x,16,0)|0;if((ad|0)<1){aj=1;i=e;return aj|0}if((gzL(ak,0,16)|0)==0){break}else{aj=1}i=e;return aj|0}}while(0);ak=c[3527096]|0;al=c[2437648]|0;at=c[2437646]|0;ad=c[3529012]|0;am=c[2405778]|0;if((ak|0)>0){au=ag(at,al)|0;an=(at|0)<1|(al|0)<1;as=0;do{av=ag(as,au)|0;gGz(am+av|0,0,au|0);ay=as<<7;if(!an){ax=0;do{aw=ay+(c[1238464+(ax<<2)>>2]|0)|0;az=(ag(ax,al)|0)+av|0;aA=0;do{aB=aw+(c[3836464+(aA<<2)>>2]|0)|0;if(((d[ad+((aB|0)/8|0)|0]|0)&128>>>((aB&7)>>>0)|0)!=0){aB=am+(az+aA)|0;a[aB]=a[aB]|4}aA=aA+1|0;}while((aA|0)<(al|0));ax=ax+1|0;}while((ax|0)<(at|0));ax=ay+131072|0;aA=0;do{az=ax+(c[1238464+(aA<<2)>>2]|0)|0;aw=(ag(aA,al)|0)+av|0;aB=0;do{aE=az+(c[3836464+(aB<<2)>>2]|0)|0;if(((d[ad+((aE|0)/8|0)|0]|0)&128>>>((aE&7)>>>0)|0)!=0){aE=am+(aw+aB)|0;a[aE]=a[aE]|2}aB=aB+1|0;}while((aB|0)<(al|0));aA=aA+1|0;}while((aA|0)<(at|0));aA=ay+262144|0;ax=0;do{aB=aA+(c[1238464+(ax<<2)>>2]|0)|0;aw=(ag(ax,al)|0)+av|0;az=0;do{aE=aB+(c[3836464+(az<<2)>>2]|0)|0;if(((d[ad+((aE|0)/8|0)|0]|0)&128>>>((aE&7)>>>0)|0)!=0){aE=am+(aw+az)|0;a[aE]=a[aE]|1}az=az+1|0;}while((az|0)<(al|0));ax=ax+1|0;}while((ax|0)<(at|0))}as=as+1|0;}while((as|0)<(ak|0))}ak=c[3527092]|0;if((c[3542200]|0)==0){aj=1;i=e;return aj|0}as=u+108|0;c[as>>2]=0;at=u+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](u,17)|0;do{if((c[as>>2]|0)!=0){al=c[at>>2]|0;c[v>>2]=9534384;am=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[am&16383](v,17,0)|0;if((al|0)<1){aj=1;i=e;return aj|0}if((gzL(ak,0,17)|0)==0){break}else{aj=1}i=e;return aj|0}}while(0);ak=(c[3527092]|0)+256|0;if((c[3542200]|0)==0){aj=1;i=e;return aj|0}at=s+108|0;c[at>>2]=0;as=s+100|0;c[as>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](s,18)|0;do{if((c[at>>2]|0)!=0){al=c[as>>2]|0;c[t>>2]=9534384;am=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[am&16383](t,18,0)|0;if((al|0)<1){aj=1;i=e;return aj|0}if((gzL(ak,0,18)|0)==0){break}else{aj=1}i=e;return aj|0}}while(0);ak=(c[3527092]|0)+512|0;if((c[3542200]|0)==0){aj=1;i=e;return aj|0}as=q+108|0;c[as>>2]=0;at=q+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](q,19)|0;do{if((c[as>>2]|0)!=0){al=c[at>>2]|0;c[r>>2]=9534384;am=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[am&16383](r,19,0)|0;if((al|0)<1){aj=1;i=e;return aj|0}if((gzL(ak,0,19)|0)==0){break}else{aj=1}i=e;return aj|0}}while(0);ak=(c[3527092]|0)+768|0;if((c[3542200]|0)==0){aj=1;i=e;return aj|0}at=o+108|0;c[at>>2]=0;as=o+100|0;c[as>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](o,20)|0;do{if((c[at>>2]|0)!=0){al=c[as>>2]|0;c[p>>2]=9534384;am=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[am&16383](p,20,0)|0;if((al|0)<1){aj=1;i=e;return aj|0}if((gzL(ak,0,20)|0)==0){break}else{aj=1}i=e;return aj|0}}while(0);ak=(c[3527092]|0)+1024|0;if((c[3542200]|0)==0){aj=1;i=e;return aj|0}as=m+108|0;c[as>>2]=0;at=m+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,21)|0;do{if((c[as>>2]|0)!=0){al=c[at>>2]|0;c[n>>2]=9534384;am=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[am&16383](n,21,0)|0;if((al|0)<1){aj=1;i=e;return aj|0}if((gzL(ak,0,21)|0)==0){break}else{aj=1}i=e;return aj|0}}while(0);ak=(c[3527092]|0)+1280|0;if((c[3542200]|0)==0){aj=1;i=e;return aj|0}at=k+108|0;c[at>>2]=0;as=k+100|0;c[as>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,22)|0;do{if((c[at>>2]|0)!=0){al=c[as>>2]|0;c[l>>2]=9534384;am=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[am&16383](l,22,0)|0;if((al|0)<1){aj=1;i=e;return aj|0}if((gzL(ak,0,22)|0)==0){break}else{aj=1}i=e;return aj|0}}while(0);ak=(c[3527092]|0)+1536|0;if((c[3542200]|0)==0){aj=1;i=e;return aj|0}as=h+108|0;c[as>>2]=0;at=h+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](h,23)|0;do{if((c[as>>2]|0)!=0){al=c[at>>2]|0;c[j>>2]=9534384;am=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[am&16383](j,23,0)|0;if((al|0)<1){aj=1;i=e;return aj|0}if((gzL(ak,0,23)|0)==0){break}else{aj=1}i=e;return aj|0}}while(0);ak=(c[3527092]|0)+1568|0;if((c[3542200]|0)==0){aj=1;i=e;return aj|0}at=f+108|0;c[at>>2]=0;as=f+100|0;c[as>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,24)|0;do{if((c[at>>2]|0)!=0){al=c[as>>2]|0;c[g>>2]=9534384;am=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[am&16383](g,24,0)|0;if((al|0)<1){aj=1;i=e;return aj|0}if((gzL(ak,0,24)|0)==0){break}else{aj=1}i=e;return aj|0}}while(0);ak=c[3529012]|0;as=0;while(1){if((as|0)>=1024){break}aF=9638528+(as<<2)|0;if((c[aF>>2]|0)==(ak|0)){af=56177;break}else{as=as+1|0}}if((af|0)==56177){gGr(ak);c[aF>>2]=0}c[3529012]=0;a9H();as=c[2439330]|0;at=(as|0)==0;if(!at){al=as;gGC(9706056,al|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];al=c[3528484]|0;c[2076596]=al;am=c[2417276]|0;c[3541536]=am;c[1836236]=0;c[as+4176>>2]=294;ad=c[2385798]|0;an=128;au=128;while(1){c[as+76+(au<<2)>>2]=ad+(au<<8);ax=an+1&65535;if((ax&65535)>191){aG=128;aH=128;break}else{an=ax;au=ax&65535}}while(1){au=ad+(aH<<8)|0;c[as+76+(aH+512<<2)>>2]=au;c[as+76+(aH+768<<2)>>2]=au;au=aG+1&65535;if((au&65535)>191){break}else{aG=au;aH=au&65535}}ad=c[3529018]|0;c[as+876>>2]=ad;au=ad+256|0;c[as+880>>2]=au;an=ad+512|0;c[as+884>>2]=an;ak=ad+768|0;c[as+888>>2]=ak;ax=ad+1024|0;c[as+892>>2]=ax;av=ad+1280|0;c[as+896>>2]=av;aA=ad+1536|0;c[as+900>>2]=aA;ay=ad+1792|0;c[as+904>>2]=ay;c[as+1900>>2]=ad;c[as+1904>>2]=au;c[as+1908>>2]=an;c[as+1912>>2]=ak;c[as+1916>>2]=ax;c[as+1920>>2]=av;c[as+1924>>2]=aA;c[as+1928>>2]=ay;c[as+2924>>2]=ad;c[as+3948>>2]=ad;c[as+2928>>2]=au;c[as+3952>>2]=au;c[as+2932>>2]=an;c[as+3956>>2]=an;c[as+2936>>2]=ak;c[as+3960>>2]=ak;c[as+2940>>2]=ax;c[as+3964>>2]=ax;c[as+2944>>2]=av;c[as+3968>>2]=av;c[as+2948>>2]=aA;c[as+3972>>2]=aA;c[as+2952>>2]=ay;c[as+3976>>2]=ay;gGz(as+940|0,0,32);gGz(as+1964|0,0,32);gGz(as+2988|0,0,32);gGz(as+4012|0,0,32);if(!at){ay=as;gGC(ay|0,9706056,76)|0}ay=c[2433530]|0;c[2438118]=ay;c[3528484]=al;c[2417276]=am;c[1836236]=-1;c[2431670]=7e3;c[2426980]=162;c[2426982]=32;c[3527088]=3072e3;if(at){c[2433530]=ay;c[2076596]=al;c[3541536]=am;c[1836236]=0;gGz(9706056,0,76)}else{aA=as;gGC(9706056,aA|0,76)|0;c[2433530]=ay;c[2076596]=al;c[3541536]=am;c[1836236]=0;gGz(9706056,0,76);aA=as;gGC(aA|0,9706056,76)|0}c[2438118]=ay;c[3528484]=al;c[2417276]=am;c[1836236]=-1;a[9660900]=a[9660900]|16;ay=c[2437644]|0;aA=c[ay+1092>>2]|0;do{if((aA|0)==0){av=c[ay+3144>>2]|0;if((av|0)==0){aI=0;aJ=0;break}ax=gj[av&4095](-2)|0;av=c[2437644]|0;ak=c[av+1092>>2]|0;an=(ax&255)<<8;if((ak|0)!=0){aK=ak;aL=an;af=56192;break}ak=c[av+3144>>2]|0;if((ak|0)==0){aI=0;aJ=an;break}aI=gj[ak&4095](-1)|0;aJ=an}else{aK=aA;aL=(d[aA+254|0]|0)<<8;af=56192}}while(0);if((af|0)==56192){aI=a[aK+255|0]|0;aJ=aL}aA=aI&255|aJ;c[2415221]=aA;b[4830442]=aA&65535;a[9660920]=0;a[9660921]=0;a[9660928]=0;a[9660930]=0;a[9660931]=0;c[2415234]=0;gGz(9660901,0,5);c[2415235]=65535;c[2415237]=65535;a[9660932]=a[9660932]|64;mB(0);mB(1);UA();c[2429502]=0;c[2429500]=0;c[2438664]=0;c[2439460]=0;a[9757800]=0;a[9623080]=0;a[9623072]=0;a[683232]=0;a[9754673]=0;a[9754672]=0;a[9754680]=0;a[9718896]=0;a[9717272]=0;a[9718824]=0;aj=0;i=e;return aj|0}}while(0);c[2426820]=0;aj=1;i=e;return aj|0}function a9D(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5350844+(b*112|0)>>2];c[a+104>>2]=c[5350848+(b*112|0)>>2];c[a+108>>2]=c[5350852+(b*112|0)>>2];d=0;return d|0}function a9E(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<21&(d|0)==0)){e=1;return e|0}c[a>>2]=5350744+(b*112|0);e=0;return e|0}function a9F(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>83){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5353096+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function a9G(){var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0;e=i;i=i+2520|0;f=e|0;g=e+112|0;h=e+120|0;j=e+232|0;k=e+240|0;l=e+352|0;m=e+360|0;n=e+472|0;o=e+480|0;p=e+592|0;q=e+600|0;r=e+712|0;s=e+720|0;t=e+832|0;u=e+840|0;v=e+952|0;w=e+960|0;x=e+1072|0;y=e+1080|0;z=e+1192|0;A=e+1200|0;B=e+1312|0;C=e+1320|0;D=e+1432|0;E=e+1440|0;F=e+1552|0;G=e+1560|0;H=e+1672|0;I=e+1680|0;J=e+1792|0;K=e+1800|0;L=e+1912|0;M=e+1920|0;N=e+2032|0;O=e+2040|0;P=e+2152|0;Q=e+2160|0;R=e+2272|0;S=e+2280|0;T=e+2392|0;U=e+2400|0;V=e+2512|0;c[2439448]=49152;c[3527090]=1824;c[3527094]=1024;c[2439452]=1024;c[2433360]=512;a[1840136]=1;c[2431672]=c[(c[642608+(c[2436]<<2)>>2]|0)+124>>2];c[2426820]=0;a9Q();W=c[2414438]|0;X=0;while(1){if((X|0)>=1024){break}Y=9638528+(X<<2)|0;if((c[Y>>2]|0)==0){Z=56330;break}else{X=X+1|0}}do{if((Z|0)==56330){X=gGq(W)|0;c[Y>>2]=X;if((X|0)==0){break}gGz(X|0,0,W|0);c[2426820]=X;gGz(X|0,0,W|0);a9Q();X=0;while(1){if((X|0)>=1024){_=0;break}$=9638528+(X<<2)|0;if((c[$>>2]|0)==0){Z=56335;break}else{X=X+1|0}}do{if((Z|0)==56335){X=gGq(98304)|0;c[$>>2]=X;if((X|0)==0){_=0;break}gGz(X|0,0,98304);_=X}}while(0);c[3529012]=_;X=c[2385798]|0;if((c[3542200]|0)==0){aa=1;i=e;return aa|0}ab=U+108|0;c[ab>>2]=0;ac=U+100|0;c[ac>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](U,0)|0;do{if((c[ab>>2]|0)!=0){ad=c[ac>>2]|0;c[V>>2]=9534384;ae=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ae&16383](V,0,0)|0;if((ad|0)<1){aa=1;i=e;return aa|0}if((gzL(X,0,0)|0)==0){break}else{aa=1}i=e;return aa|0}}while(0);X=(c[2385798]|0)+16384|0;if((c[3542200]|0)==0){aa=1;i=e;return aa|0}ac=S+108|0;c[ac>>2]=0;ab=S+100|0;c[ab>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](S,1)|0;do{if((c[ac>>2]|0)!=0){ad=c[ab>>2]|0;c[T>>2]=9534384;ae=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ae&16383](T,1,0)|0;if((ad|0)<1){aa=1;i=e;return aa|0}if((gzL(X,0,1)|0)==0){break}else{aa=1}i=e;return aa|0}}while(0);X=(c[2385798]|0)+32768|0;if((c[3542200]|0)==0){aa=1;i=e;return aa|0}ab=Q+108|0;c[ab>>2]=0;ac=Q+100|0;c[ac>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](Q,2)|0;do{if((c[ab>>2]|0)!=0){ad=c[ac>>2]|0;c[R>>2]=9534384;ae=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ae&16383](R,2,0)|0;if((ad|0)<1){aa=1;i=e;return aa|0}if((gzL(X,0,2)|0)==0){break}else{aa=1}i=e;return aa|0}}while(0);X=(c[3527098]|0)+32768|0;if((c[3542200]|0)==0){aa=1;i=e;return aa|0}ac=O+108|0;c[ac>>2]=0;ab=O+100|0;c[ab>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](O,3)|0;do{if((c[ac>>2]|0)!=0){ad=c[ab>>2]|0;c[P>>2]=9534384;ae=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ae&16383](P,3,0)|0;if((ad|0)<1){aa=1;i=e;return aa|0}if((gzL(X,0,3)|0)==0){break}else{aa=1}i=e;return aa|0}}while(0);X=c[3529012]|0;gGz(X|0,0,98304);if((c[3542200]|0)==0){aa=1;i=e;return aa|0}ab=M+108|0;c[ab>>2]=0;ac=M+100|0;c[ac>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](M,4)|0;do{if((c[ab>>2]|0)!=0){ad=c[ac>>2]|0;c[N>>2]=9534384;ae=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ae&16383](N,4,0)|0;if((ad|0)<1){aa=1;i=e;return aa|0}if((gzL(X,0,4)|0)==0){break}else{aa=1}i=e;return aa|0}}while(0);X=(c[3529012]|0)+8192|0;if((c[3542200]|0)==0){aa=1;i=e;return aa|0}ac=K+108|0;c[ac>>2]=0;ab=K+100|0;c[ab>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](K,5)|0;do{if((c[ac>>2]|0)!=0){ad=c[ab>>2]|0;c[L>>2]=9534384;ae=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ae&16383](L,5,0)|0;if((ad|0)<1){aa=1;i=e;return aa|0}if((gzL(X,0,5)|0)==0){break}else{aa=1}i=e;return aa|0}}while(0);X=(c[3529012]|0)+16384|0;if((c[3542200]|0)==0){aa=1;i=e;return aa|0}ab=I+108|0;c[ab>>2]=0;ac=I+100|0;c[ac>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](I,6)|0;do{if((c[ab>>2]|0)!=0){ad=c[ac>>2]|0;c[J>>2]=9534384;ae=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ae&16383](J,6,0)|0;if((ad|0)<1){aa=1;i=e;return aa|0}if((gzL(X,0,6)|0)==0){break}else{aa=1}i=e;return aa|0}}while(0);X=c[3527094]|0;ac=c[2439464]|0;ab=c[2439462]|0;ad=c[3529012]|0;ae=c[2405764]|0;if((X|0)>0){af=ag(ab,ac)|0;ah=(ab|0)<1|(ac|0)<1;ai=0;do{aj=ag(ai,af)|0;gGz(ae+aj|0,0,af|0);ak=ai<<6;al=ak+131072|0;if(!ah){am=0;do{an=al+(c[1238464+(am<<2)>>2]|0)|0;ao=(ag(am,ac)|0)+aj|0;ap=0;do{aq=an+(c[614800+(ap<<2)>>2]|0)|0;if(((d[ad+((aq|0)/8|0)|0]|0)&128>>>((aq&7)>>>0)|0)!=0){aq=ae+(ao+ap)|0;a[aq]=a[aq]|4}ap=ap+1|0;}while((ap|0)<(ac|0));am=am+1|0;}while((am|0)<(ab|0));am=ak+65536|0;al=0;while(1){ap=am+(c[1238464+(al<<2)>>2]|0)|0;ao=(ag(al,ac)|0)+aj|0;an=0;do{aq=ap+(c[614800+(an<<2)>>2]|0)|0;if(((d[ad+((aq|0)/8|0)|0]|0)&128>>>((aq&7)>>>0)|0)!=0){aq=ae+(ao+an)|0;a[aq]=a[aq]|2}an=an+1|0;}while((an|0)<(ac|0));an=al+1|0;if((an|0)<(ab|0)){al=an}else{ar=0;break}}do{al=ak+(c[1238464+(ar<<2)>>2]|0)|0;am=(ag(ar,ac)|0)+aj|0;an=0;do{ao=al+(c[614800+(an<<2)>>2]|0)|0;if(((d[ad+((ao|0)/8|0)|0]|0)&128>>>((ao&7)>>>0)|0)!=0){ao=ae+(am+an)|0;a[ao]=a[ao]|1}an=an+1|0;}while((an|0)<(ac|0));ar=ar+1|0;}while((ar|0)<(ab|0))}ai=ai+1|0;}while((ai|0)<(X|0))}gGz(ad|0,0,98304);if((c[3542200]|0)==0){aa=1;i=e;return aa|0}X=G+108|0;c[X>>2]=0;ai=G+100|0;c[ai>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](G,7)|0;do{if((c[X>>2]|0)!=0){ab=c[ai>>2]|0;c[H>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](H,7,0)|0;if((ab|0)<1){aa=1;i=e;return aa|0}if((gzL(ad,0,7)|0)==0){break}else{aa=1}i=e;return aa|0}}while(0);ad=(c[3529012]|0)+16384|0;if((c[3542200]|0)==0){aa=1;i=e;return aa|0}ai=E+108|0;c[ai>>2]=0;X=E+100|0;c[X>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](E,8)|0;do{if((c[ai>>2]|0)!=0){ab=c[X>>2]|0;c[F>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](F,8,0)|0;if((ab|0)<1){aa=1;i=e;return aa|0}if((gzL(ad,0,8)|0)==0){break}else{aa=1}i=e;return aa|0}}while(0);ad=(c[3529012]|0)+32768|0;if((c[3542200]|0)==0){aa=1;i=e;return aa|0}X=C+108|0;c[X>>2]=0;ai=C+100|0;c[ai>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](C,9)|0;do{if((c[X>>2]|0)!=0){ab=c[ai>>2]|0;c[D>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](D,9,0)|0;if((ab|0)<1){aa=1;i=e;return aa|0}if((gzL(ad,0,9)|0)==0){break}else{aa=1}i=e;return aa|0}}while(0);ad=(c[3529012]|0)+49152|0;if((c[3542200]|0)==0){aa=1;i=e;return aa|0}ai=A+108|0;c[ai>>2]=0;X=A+100|0;c[X>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](A,10)|0;do{if((c[ai>>2]|0)!=0){ab=c[X>>2]|0;c[B>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](B,10,0)|0;if((ab|0)<1){aa=1;i=e;return aa|0}if((gzL(ad,0,10)|0)==0){break}else{aa=1}i=e;return aa|0}}while(0);ad=(c[3529012]|0)+65536|0;if((c[3542200]|0)==0){aa=1;i=e;return aa|0}X=y+108|0;c[X>>2]=0;ai=y+100|0;c[ai>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](y,11)|0;do{if((c[X>>2]|0)!=0){ab=c[ai>>2]|0;c[z>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](z,11,0)|0;if((ab|0)<1){aa=1;i=e;return aa|0}if((gzL(ad,0,11)|0)==0){break}else{aa=1}i=e;return aa|0}}while(0);ad=(c[3529012]|0)+81920|0;if((c[3542200]|0)==0){aa=1;i=e;return aa|0}ai=w+108|0;c[ai>>2]=0;X=w+100|0;c[X>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](w,12)|0;do{if((c[ai>>2]|0)!=0){ab=c[X>>2]|0;c[x>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](x,12,0)|0;if((ab|0)<1){aa=1;i=e;return aa|0}if((gzL(ad,0,12)|0)==0){break}else{aa=1}i=e;return aa|0}}while(0);ad=c[2439452]|0;X=c[3529012]|0;ai=c[3529014]|0;if((ad|0)>0){ab=0;do{ac=ab<<8;gGz(ai+ac|0,0,256);ae=ac+524288|0;ah=0;do{af=ae+(c[609008+(ah<<2)>>2]|0)|0;aj=(ah<<4)+ac|0;ak=0;do{an=af+(c[597864+(ak<<2)>>2]|0)|0;if(((d[X+((an|0)/8|0)|0]|0)&128>>>((an&7)>>>0)|0)!=0){an=ai+(aj+ak)|0;a[an]=a[an]|4}ak=ak+1|0;}while((ak|0)<16);ah=ah+1|0;}while((ah|0)<16);ah=ac+262144|0;ae=0;while(1){ak=ah+(c[609008+(ae<<2)>>2]|0)|0;aj=(ae<<4)+ac|0;af=0;do{an=ak+(c[597864+(af<<2)>>2]|0)|0;if(((d[X+((an|0)/8|0)|0]|0)&128>>>((an&7)>>>0)|0)!=0){an=ai+(aj+af)|0;a[an]=a[an]|2}af=af+1|0;}while((af|0)<16);af=ae+1|0;if((af|0)<16){ae=af}else{as=0;break}}do{ae=ac+(c[609008+(as<<2)>>2]|0)|0;ah=(as<<4)+ac|0;af=0;do{aj=ae+(c[597864+(af<<2)>>2]|0)|0;if(((d[X+((aj|0)/8|0)|0]|0)&128>>>((aj&7)>>>0)|0)!=0){aj=ai+(ah+af)|0;a[aj]=a[aj]|1}af=af+1|0;}while((af|0)<16);as=as+1|0;}while((as|0)<16);ab=ab+1|0;}while((ab|0)<(ad|0))}ad=c[3527092]|0;if((c[3542200]|0)==0){aa=1;i=e;return aa|0}ab=u+108|0;c[ab>>2]=0;ai=u+100|0;c[ai>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](u,13)|0;do{if((c[ab>>2]|0)!=0){X=c[ai>>2]|0;c[v>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](v,13,0)|0;if((X|0)<1){aa=1;i=e;return aa|0}if((gzL(ad,0,13)|0)==0){break}else{aa=1}i=e;return aa|0}}while(0);ad=(c[3527092]|0)+256|0;if((c[3542200]|0)==0){aa=1;i=e;return aa|0}ai=s+108|0;c[ai>>2]=0;ab=s+100|0;c[ab>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](s,14)|0;do{if((c[ai>>2]|0)!=0){X=c[ab>>2]|0;c[t>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](t,14,0)|0;if((X|0)<1){aa=1;i=e;return aa|0}if((gzL(ad,0,14)|0)==0){break}else{aa=1}i=e;return aa|0}}while(0);ad=(c[3527092]|0)+512|0;if((c[3542200]|0)==0){aa=1;i=e;return aa|0}ab=q+108|0;c[ab>>2]=0;ai=q+100|0;c[ai>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](q,15)|0;do{if((c[ab>>2]|0)!=0){X=c[ai>>2]|0;c[r>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](r,15,0)|0;if((X|0)<1){aa=1;i=e;return aa|0}if((gzL(ad,0,15)|0)==0){break}else{aa=1}i=e;return aa|0}}while(0);ad=(c[3527092]|0)+768|0;if((c[3542200]|0)==0){aa=1;i=e;return aa|0}ai=o+108|0;c[ai>>2]=0;ab=o+100|0;c[ab>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](o,16)|0;do{if((c[ai>>2]|0)!=0){X=c[ab>>2]|0;c[p>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](p,16,0)|0;if((X|0)<1){aa=1;i=e;return aa|0}if((gzL(ad,0,16)|0)==0){break}else{aa=1}i=e;return aa|0}}while(0);ad=(c[3527092]|0)+1024|0;if((c[3542200]|0)==0){aa=1;i=e;return aa|0}ab=m+108|0;c[ab>>2]=0;ai=m+100|0;c[ai>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,17)|0;do{if((c[ab>>2]|0)!=0){X=c[ai>>2]|0;c[n>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](n,17,0)|0;if((X|0)<1){aa=1;i=e;return aa|0}if((gzL(ad,0,17)|0)==0){break}else{aa=1}i=e;return aa|0}}while(0);ad=(c[3527092]|0)+1280|0;if((c[3542200]|0)==0){aa=1;i=e;return aa|0}ai=k+108|0;c[ai>>2]=0;ab=k+100|0;c[ab>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,18)|0;do{if((c[ai>>2]|0)!=0){X=c[ab>>2]|0;c[l>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](l,18,0)|0;if((X|0)<1){aa=1;i=e;return aa|0}if((gzL(ad,0,18)|0)==0){break}else{aa=1}i=e;return aa|0}}while(0);ad=(c[3527092]|0)+1536|0;if((c[3542200]|0)==0){aa=1;i=e;return aa|0}ab=h+108|0;c[ab>>2]=0;ai=h+100|0;c[ai>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](h,19)|0;do{if((c[ab>>2]|0)!=0){X=c[ai>>2]|0;c[j>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](j,19,0)|0;if((X|0)<1){aa=1;i=e;return aa|0}if((gzL(ad,0,19)|0)==0){break}else{aa=1}i=e;return aa|0}}while(0);ad=(c[3527092]|0)+1568|0;if((c[3542200]|0)==0){aa=1;i=e;return aa|0}ai=f+108|0;c[ai>>2]=0;ab=f+100|0;c[ab>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,20)|0;do{if((c[ai>>2]|0)!=0){X=c[ab>>2]|0;c[g>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](g,20,0)|0;if((X|0)<1){aa=1;i=e;return aa|0}if((gzL(ad,0,20)|0)==0){break}else{aa=1}i=e;return aa|0}}while(0);ad=c[3529012]|0;ab=0;while(1){if((ab|0)>=1024){break}at=9638528+(ab<<2)|0;if((c[at>>2]|0)==(ad|0)){Z=56441;break}else{ab=ab+1|0}}if((Z|0)==56441){gGr(ad);c[at>>2]=0}c[3529012]=0;a9H();ab=c[2439330]|0;ai=(ab|0)==0;if(!ai){X=ab;gGC(9706056,X|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];X=c[3528484]|0;c[2076596]=X;ac=c[2417276]|0;c[3541536]=ac;c[1836236]=0;af=c[2385798]|0;ah=128;ae=128;while(1){c[ab+76+(ae<<2)>>2]=af+(ae<<8);aj=ah+1&65535;if((aj&65535)>191){au=128;av=128;break}else{ah=aj;ae=aj&65535}}while(1){ae=af+(av<<8)|0;c[ab+76+(av+512<<2)>>2]=ae;c[ab+76+(av+768<<2)>>2]=ae;ae=au+1&65535;if((ae&65535)>191){break}else{au=ae;av=ae&65535}}af=c[2443294]|0;c[ab+844>>2]=af;ae=af+256|0;c[ab+848>>2]=ae;c[ab+1868>>2]=af;c[ab+1872>>2]=ae;c[ab+2892>>2]=af;c[ab+3916>>2]=af;c[ab+2896>>2]=ae;c[ab+3920>>2]=ae;ae=c[2443296]|0;c[ab+876>>2]=ae;c[ab+1900>>2]=ae;c[ab+2924>>2]=ae;c[ab+3948>>2]=ae;if(!ai){ae=ab;gGC(ae|0,9706056,76)|0}ae=c[2433530]|0;c[2438118]=ae;c[3528484]=X;c[2417276]=ac;c[1836236]=-1;c[2431670]=10188;c[2426980]=124;if(ai){c[2433530]=ae;c[2076596]=X;c[3541536]=ac;c[1836236]=0;gGz(9706056,0,76)}else{af=ab;gGC(9706056,af|0,76)|0;c[2433530]=ae;c[2076596]=X;c[3541536]=ac;c[1836236]=0;gGz(9706056,0,76);af=ab;gGC(af|0,9706056,76)|0}c[2438118]=ae;c[3528484]=X;c[2417276]=ac;c[1836236]=-1;a[9660900]=a[9660900]|16;ae=c[2437644]|0;af=c[ae+1092>>2]|0;do{if((af|0)==0){ah=c[ae+3144>>2]|0;if((ah|0)==0){aw=0;ax=0;break}ad=gj[ah&4095](-2)|0;ah=c[2437644]|0;aj=c[ah+1092>>2]|0;ak=(ad&255)<<8;if((aj|0)!=0){ay=aj;az=ak;Z=56456;break}aj=c[ah+3144>>2]|0;if((aj|0)==0){aw=0;ax=ak;break}aw=gj[aj&4095](-1)|0;ax=ak}else{ay=af;az=(d[af+254|0]|0)<<8;Z=56456}}while(0);if((Z|0)==56456){aw=a[ay+255|0]|0;ax=az}af=aw&255|ax;c[2415221]=af;b[4830442]=af&65535;a[9660920]=0;a[9660921]=0;a[9660928]=0;a[9660930]=0;a[9660931]=0;c[2415234]=0;gGz(9660901,0,5);c[2415235]=65535;c[2415237]=65535;a[9660932]=a[9660932]|64;mB(0);mB(1);UA();c[2429502]=0;c[2429500]=0;c[2438664]=0;c[2439460]=0;a[9757800]=0;a[9623080]=0;a[9623072]=0;a[683232]=0;a[9754673]=0;a[9754672]=0;a[9754680]=0;a[9718896]=0;a[9717272]=0;a[9718824]=0;aa=0;i=e;return aa|0}}while(0);c[2426820]=0;aa=1;i=e;return aa|0}function a9H(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0.0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;fwR(0);d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];f=c[3528484]|0;c[2076596]=f;g=c[2417276]|0;c[3541536]=g;c[1836236]=0;c[d+4180>>2]=3542;c[d+4184>>2]=1192;c[d+4172>>2]=3374;c[d+4176>>2]=340;i=c[2385798]|0;j=0;k=0;while(1){c[d+76+(k<<2)>>2]=i+(k<<8);l=j+1&65535;if((l&65535)>127){m=0;n=0;break}else{j=l;k=l&65535}}while(1){k=i+(n<<8)|0;c[d+76+(n+512<<2)>>2]=k;c[d+76+(n+768<<2)>>2]=k;k=m+1&65535;if((k&65535)>127){break}else{m=k;n=k&65535}}n=c[2443294]|0;c[d+844>>2]=n;c[d+1868>>2]=n;c[d+2892>>2]=n;c[d+3916>>2]=n;n=c[3529010]|0;c[d+908>>2]=n;c[d+912>>2]=n+256;c[d+916>>2]=n+512;c[d+920>>2]=n+768;c[d+924>>2]=n+1024;c[d+928>>2]=n+1280;c[d+932>>2]=n+1536;c[d+936>>2]=n+1792;c[d+940>>2]=n+2048;c[d+944>>2]=n+2304;c[d+948>>2]=n+2560;c[d+952>>2]=n+2816;c[d+956>>2]=n+3072;c[d+960>>2]=n+3328;c[d+964>>2]=n+3584;c[d+968>>2]=n+3840;m=208;i=208;while(1){c[d+76+(i+256<<2)>>2]=n+((i<<8)-53248);k=m+1&65535;if((k&65535)>223){o=208;p=208;break}else{m=k;i=k&65535}}while(1){i=n+((p<<8)-53248)|0;c[d+76+(p+512<<2)>>2]=i;c[d+76+(p+768<<2)>>2]=i;i=o+1&65535;if((i&65535)>223){break}else{o=i;p=i&65535}}p=c[2385800]|0;c[d+972>>2]=p;c[d+976>>2]=p+256;c[d+980>>2]=p+512;c[d+984>>2]=p+768;c[d+988>>2]=p+1024;c[d+992>>2]=p+1280;c[d+996>>2]=p+1536;c[d+1e3>>2]=p+1792;c[d+1004>>2]=p+2048;c[d+1008>>2]=p+2304;c[d+1012>>2]=p+2560;c[d+1016>>2]=p+2816;c[d+1020>>2]=p+3072;c[d+1024>>2]=p+3328;c[d+1028>>2]=p+3584;c[d+1032>>2]=p+3840;o=224;n=224;while(1){c[d+76+(n+256<<2)>>2]=p+((n<<8)-57344);i=o+1&65535;if((i&65535)>239){q=224;r=224;break}else{o=i;n=i&65535}}while(1){n=p+((r<<8)-57344)|0;c[d+76+(r+512<<2)>>2]=n;c[d+76+(r+768<<2)>>2]=n;n=q+1&65535;if((n&65535)>239){break}else{q=n;r=n&65535}}if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=f;c[2417276]=g;c[1836236]=-1;fwj(3);g=c[3527098]|0;f=c[2437644]|0;e=64;d=64;while(1){r=g+((d<<8)-16384)|0;c[f+72+(d<<2)>>2]=r;c[f+72+(d+512<<2)>>2]=r;r=e+1&65535;if((r&65535)>255){break}else{e=r;d=r&65535}}c[f+3144>>2]=22;c[f+3148>>2]=530;c[f+3160>>2]=2288;c[f+3164>>2]=332;f=c[2385408]|0;c[2439180]=f;d=a[9688]|0?534:0;c[2439181]=f+(d<<1);c[2439182]=f+(d<<1<<1);c[2439183]=f+((d*3|0)<<1);c[2439184]=f+(d<<2<<1);c[2439185]=f+((d*5|0)<<1);UB(0,1678,384e3,11658,4);UB(1,1678,384e3,0,7);h[1207773]=.5;c[2415548]=3;c[2415126]=9665376;h[1208176]=.5;c[2416354]=3;d=a[9680]|0?32e3:0;c[3542220]=11200;f=c[2113008]|0;if((f|0)==0){gGz(14168888,0,252);c[3542223]=d;c[3542224]=2832;c[3542225]=0;c[3542226]=0;c[3542227]=806;c[3542234]=~~((+(d|0)*32768.0*8.0+447443.0)/894886.0);e=31;s=32767.0;while(1){c[14169012+(e<<2)>>2]=~~(s+.5);g=e-1|0;if((g|0)>0){e=g;s=s/1.188502227}else{break}}c[3542253]=0;h[1771269]=1.0;h[1771270]=1.0;h[1771271]=1.0;c[3542574]=3;c[3542575]=3;c[3542576]=3;mB(0);e=(c[2113008]|0)+1|0;c[2113008]=e;t=e;u=a[9680]|0?32e3:0}else{t=f;u=d}c[3542220]=11200;if((t|0)==1){gGz(14169140,0,252);c[3542286]=u;gGz(14169148,0,16);c[3542297]=~~((+(u|0)*32768.0*8.0+447443.0)/894886.0);u=31;s=32767.0;while(1){c[14169264+(u<<2)>>2]=~~(s+.5);t=u-1|0;if((t|0)>0){u=t;s=s/1.188502227}else{break}}c[3542316]=0;h[1771272]=1.0;h[1771273]=1.0;h[1771274]=1.0;c[3542577]=3;c[3542578]=3;c[3542579]=3;mB(1);c[2113008]=(c[2113008]|0)+1}h[1771269]=.5;c[3542574]=3;h[1771270]=.5;c[3542575]=3;h[1771271]=.5;c[3542576]=3;h[1771272]=.5;c[3542577]=3;h[1771273]=.5;c[3542578]=3;h[1771274]=.5;c[3542579]=3;u=c[642608+(c[2436]<<2)>>2]|0;t=c[u+128>>2]|0;if((c[u+52>>2]&4|0)==0){c[2113068]=t;d=c[u+132>>2]|0;c[2113070]=d;c[2443814]=t;c[2440436]=d;v=t;w=d}else{c[2113070]=t;d=c[u+132>>2]|0;c[2113068]=d;c[2440436]=t;c[2443814]=d;v=d;w=t}t=ag(v<<1,w)|0;w=gGq(t)|0;c[2112926]=w;if((w|0)==0){c[3527088]=4e6;a[6243312]=1;x=c[2431672]|0;y=x&3840;z=y*3|0;c[2426978]=z;return}gGz(w|0,0,t|0);c[3527088]=4e6;a[6243312]=1;x=c[2431672]|0;y=x&3840;z=y*3|0;c[2426978]=z;return}function a9I(){var a=0;a=c[2112926]|0;gGz(a|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);a9K();a9L(0,128,0,64,32,0);a9L(1,128,0,64,32,0);a9M(31,0,0,128,256);a9L(1,128,0,64,32,1);R8(c[3529016]|0);return}function a9J(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;e=c[b>>2]|0;c[a>>2]=e<<5&1024|c[a>>2]|e<<2&768;c[d>>2]=(c[b>>2]&16)>>>0>14;c[b>>2]=c[b>>2]&31;return}function a9K(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0;a=c[2431672]|0;if((a|0)==0){return}b=c[3529016]|0;e=0;f=c[3527092]|0;while(1){g=d[f]|0;h=d[f+a|0]|0;i=d[f+(a<<1)|0]|0;c[b+(e<<2)>>2]=(-(h>>>1&1)&31)+(-(h&1)&14)+(-(h>>>2&1)&67)+(-(h>>>3&1)&143)<<3&2016|(-(g>>>1&1)&31)+(-(g&1)&14)+(-(g>>>2&1)&67)+(-(g>>>3&1)&143)<<8&63488|((-(i>>>1&1)&31)+(-(i&1)&14)+(-(i>>>2&1)&67)+(-(i>>>3&1)&143)|0)>>>3&31;i=e+1|0;if(i>>>0<a>>>0){e=i;f=f+1|0}else{break}}return}function a9L(e,f,g,h,j,k){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0;l=i;i=i+32|0;m=l|0;n=l+8|0;o=l+16|0;p=l+24|0;if((j|0)<=0){i=l;return}q=(h|0)>0;r=(k|0)!=0;k=0;s=0;while(1){if(q){t=s<<1;u=t|1;v=k;w=0;while(1){x=v<<1;y=c[3529010]|0;z=d[y+x|0]|0;c[m>>2]=z;c[n>>2]=d[y+(x|1)|0]|0;c[o>>2]=0;c[p>>2]=0;x=c[2426980]|0;if((x|0)==0){A=z}else{gL[x&255](m,n,o,p);A=c[m>>2]|0}c[m>>2]=(c[3527094]|0)-1&A;x=c[2439464]|0;z=ag(x,w)|0;y=c[2439462]|0;B=ag(y,s)|0;C=(c[2439460]|0)==0;if(C){D=ag(x,h)|0;E=0;F=B;G=z;H=D;I=ag(y,j)|0}else{c[p>>2]=(c[p>>2]|0)==0;D=ag(y,j)|0;J=ag(x,h)|0;E=1;F=D-(B+y)|0;G=J-(z+x)|0;H=J;I=D}D=c[2429502]&H-1;J=(C?-D|0:D)+(G-f)|0;D=F-g-(c[2429500]&I-1)|0;C=c[n>>2]<<3;if((c[o>>2]|0)==(e|0)&(y|0)>0){z=(E|0)!=0;B=z^1;K=c[2405764]|0;L=a[1840136]|0;M=c[2443296]|0;N=M+t|0;O=M+u|0;M=c[2113070]|0;P=c[2113068]|0;Q=c[2112926]|0;R=0;S=0;while(1){L73001:do{if((x|0)>0){T=S-1|0;U=D+R|0;V=(U|0)<0;if(z){W=0;X=-1}else{Y=0;Z=-1;while(1){_=ag(c[m>>2]|0,y)|0;$=(c[p>>2]|0)==0?Y:Z+x|0;aa=a[K+($+(ag(_+R|0,x)|0))|0]|0;do{if(!(r&aa<<24>>24==0)){_=Y+J|0;if(L){$=(d[O]|0)<<8|(d[N]|0);ab=ag(x,h)|0;ac=ab-1|0;ad=_-($&ac)|0;ae=ab;af=ac}else{ac=ag(x,h)|0;ad=_;ae=ac;af=ac-1|0}ac=((ad|0)<0?ae:0)+ad|0;_=ac-((ac|0)>(af|0)?ae:0)|0;ac=ag(y,j)|0;ab=(V?ac:0)+U|0;$=ab-((ab|0)>(ac-1|0)?ac:0)|0;if(!(($|0)>-1&($|0)<(M|0))){break}if(!((_|0)>-1&(_|0)<(P|0))){break}b[Q+((ag(P,$)|0)+_<<1)>>1]=(aa&255|C)&65535}}while(0);aa=Y+1|0;if((aa|0)>=(x|0)){break L73001}_=-2-Y|0;Y=aa;Z=_}}while(1){Z=(c[p>>2]|0)==0;Y=ag(T+y+(ag(y,c[m>>2]|0)|0)|0,x)|0;if(Z|B){ah=Y+W|0}else{ah=X+x+Y|0}Y=a[K+ah|0]|0;do{if(!(r&Y<<24>>24==0)){Z=W+J|0;if(L){_=(d[O]|0)<<8|(d[N]|0);aa=ag(x,h)|0;$=aa-1|0;ai=Z-(_&$)|0;aj=aa;ak=$}else{$=ag(x,h)|0;ai=Z;aj=$;ak=$-1|0}$=((ai|0)<0?aj:0)+ai|0;Z=$-(($|0)>(ak|0)?aj:0)|0;$=ag(y,j)|0;aa=U+(V?$:0)|0;_=aa-((aa|0)>($-1|0)?$:0)|0;if(!((_|0)>-1&(_|0)<(M|0))){break}if(!((Z|0)>-1&(Z|0)<(P|0))){break}b[Q+((ag(P,_)|0)+Z<<1)>>1]=(Y&255|C)&65535}}while(0);Y=W+1|0;if((Y|0)>=(x|0)){break L73001}Z=-2-W|0;W=Y;X=Z}}}while(0);V=R+1|0;U=~R;if((V|0)<(y|0)){R=V;S=U}else{break}}}S=w+1|0;if((S|0)>=(h|0)){break}v=v+1|0;w=S}al=k+h|0}else{al=k}w=s+1|0;if((w|0)<(j|0)){k=al;s=w}else{break}}i=l;return}function a9M(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;i=c[2433360]|0;if((i|0)==0){return}j=c[2443294]|0;k=c[2426978]|0;l=c[3527092]|0;m=(c[2439460]|0)==0;n=(c[2439452]|0)-1|0;o=c[2112926]|0;p=c[3529014]|0;q=0;do{r=d[j+q|0]|0;if((r&e|0)==(f|0)){s=d[j+(q|5)|0]|0;t=s<<8&1792|(d[j+(q|4)|0]|0);u=r&b;r=(d[j+(q|7)|0]|0)<<8&256|(d[j+(q|6)|0]|0);v=369-((d[j+(q|3)|0]|0)<<8&256|(d[j+(q|2)|0]|0))|0;w=s&64;x=s&128;y=a[l+((t>>>5&31)+k)|0]|0;z=y&255;if((y<<24>>24|0)==2){A=v-48|0;B=3;C=t&2044}else if((y<<24>>24|0)==1){A=v-16|0;B=z;C=t&2046}else{A=v;B=z;C=t}if(m){D=A;E=r;F=x;G=w}else{D=242-(B<<4)-A|0;E=496-r|0;F=s>>>7^1;G=w>>>6^1}w=(F|0)!=0;s=w?-1:1;r=(w?B:0)+C|0;x=E-g|0;t=(x|0)>15;z=(G|0)==0;v=B;while(1){y=(v<<4)+D|0;H=r+(ag(v,s)|0)&n;do{if(t){if(!((x|0)<((c[2113068]|0)-16|0)&(y|0)>15)){I=56647;break}if((y|0)>=((c[2113070]|0)-16|0)){I=56647;break}if(z){if(w){SK(o,H,x,y,u,3,0,h,p);break}else{SG(o,H,x,y,u,3,0,h,p);break}}else{if(w){SM(o,H,x,y,u,3,0,h,p);break}else{SI(o,H,x,y,u,3,0,h,p);break}}}else{I=56647}}while(0);do{if((I|0)==56647){I=0;if(z){if(w){SL(o,H,x,y,u,3,0,h,p);break}else{SH(o,H,x,y,u,3,0,h,p);break}}else{if(w){SN(o,H,x,y,u,3,0,h,p);break}else{SJ(o,H,x,y,u,3,0,h,p);break}}}}while(0);if((v|0)>0){v=v-1|0}else{break}}}q=q+8|0;}while(q>>>0<i>>>0);return}function a9N(a){a=a|0;var b=0.0;b=+(a|0)*+((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)/+((c[3527088]|0)>>>0>>>0);+V(b)>=1.0?b>0.0?(al(+U(b/4294967296.0),4294967295.0)|0)>>>0:~~+af((b- +(~~b>>>0))/4294967296.0)>>>0:0;return~~b>>>0|0}function a9O(){if((a[9660902]|0)!=1){a[9660902]=1;f00(-4)}f4c(0)|0;if((a[9660902]|0)!=0){a[9660902]=0}f4c(0)|0;a[683232]=1;return}function a9P(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;c[2415126]=9662152;a=c[600992+((b>>>2&3)<<2)>>2]|0;d=(b>>>4&1)+3|0;if((c[2415541]|0)!=(a|0)){c[2415541]=a}if((c[2415542]|0)!=(d|0)){c[2415542]=d}c[2415126]=9665376;if((c[2416347]|0)!=0){c[2416347]=0}if((c[2416348]|0)==(d|0)){e=b&1;c[2415540]=e;f=b&2;c[2415126]=9665376;c[2416346]=f;return}c[2416348]=d;e=b&1;c[2415540]=e;f=b&2;c[2415126]=9665376;c[2416346]=f;return}function a9Q(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[2426820]|0;d=c[2439464]|0;if((d|0)==0){c[2439464]=8;e=8}else{e=d}d=c[2439462]|0;if((d|0)==0){c[2439462]=8;f=8}else{f=d}d=c[2437648]|0;if((d|0)==0){c[2437648]=8;g=8}else{g=d}d=c[2437646]|0;if((d|0)==0){c[2437646]=8;h=8}else{h=d}d=c[2433360]|0;if((d|0)==0){c[2433360]=256;i=256}else{i=d}c[2385798]=b;d=c[2439448]|0;c[3527098]=b+d;j=d+49152|0;d=b+j|0;c[2405722]=d;c[2443294]=d;d=j+i|0;c[3529010]=b+d;i=d+8192|0;d=c[2438666]|0;if((d|0)!=0){c[3529018]=b+i}j=i+d|0;d=a[1840136]|0;if(d){c[2443296]=b+j}i=(d?64:0)+j|0;c[2385800]=b+i;c[3527100]=b+(i+4096);j=i+4224|0;i=b+j|0;c[2411886]=i;c[2405764]=i;i=c[3527094]|0;d=(ag(ag(f,e)|0,i)|0)+j|0;c[3529014]=b+d;j=d+(c[2439452]<<8)|0;d=c[3527096]|0;if((d|0)!=0){c[2405778]=b+j}i=(ag(ag(h,g)|0,d)|0)+j|0;c[3529016]=b+i;j=(c[2431672]<<2)+i|0;c[3527092]=b+j;i=j+(c[3527090]|0)|0;c[2385408]=b+i;c[2414438]=b+(i+(a[9688]|0?6408:0));return}function a9R(){var a=0;a=c[2112926]|0;gGz(a|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);a9K();a9L(0,128,0,64,16,0);a9L(1,128,0,64,16,0);a9M(31,0,0,128,256);a9L(1,128,0,64,16,1);a9U(32,3,64,0,128);R8(c[3529016]|0);return}function a9S(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;c[a>>2]=c[b>>2]<<3&768|c[a>>2];c[d>>2]=(c[b>>2]&16)>>>0>14;c[b>>2]=c[b>>2]&31;return}function a9T(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;c[a>>2]=c[b>>2]<<2&768|c[a>>2];c[b>>2]=c[b>>2]&15;return}function a9U(e,f,g,h,j){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;k=i;i=i+16|0;l=k|0;m=k+8|0;if((e|0)>0){n=0;o=0}else{i=k;return}while(1){p=n;q=0;while(1){r=p<<1;s=c[3529018]|0;t=d[s+r|0]|0;c[l>>2]=t;c[m>>2]=d[s+(r|1)|0]|0;r=c[2426982]|0;if((r|0)==0){u=t}else{gL[r&255](l,m,0,0);u=c[l>>2]|0}c[l>>2]=(c[3527096]|0)-1&u;r=c[2437648]|0;t=ag(r,q)|0;s=c[2437646]|0;v=t-g|0;t=(ag(s,o)|0)-h|0;w=c[2438664]|0;x=t-((ag(s,e)|0)-1&w)|0;if((s|0)>0){w=c[m>>2]<<f|j;t=c[2405778]|0;y=c[2113070]|0;z=c[2113068]|0;A=c[2112926]|0;B=0;do{if((r|0)>0){C=x+B|0;D=(C|0)<0;E=0;do{F=a[t+((ag((ag(c[l>>2]|0,s)|0)+B|0,r)|0)+E)|0]|0;G=F&255;do{if(F<<24>>24!=0){H=E+v|0;I=r<<5;J=((H|0)<0?I:0)+H|0;H=J-((J|0)>(I-1|0)?I:0)|0;I=ag(s,e)|0;J=(D?I:0)+C|0;K=J-((J|0)>(I-1|0)?I:0)|0;if(!((K|0)>-1&(K|0)<(y|0))){break}if(!((H|0)>-1&(H|0)<(z|0))){break}b[A+((ag(z,K)|0)+H<<1)>>1]=(w|G)&65535}}while(0);E=E+1|0;}while((E|0)<(r|0))}B=B+1|0;}while((B|0)<(s|0))}s=q+1|0;if((s|0)>=32){break}p=p+1|0;q=s}q=o+1|0;if((q|0)<(e|0)){n=n+32|0;o=q}else{break}}i=k;return}function a9V(){var a=0,b=0,e=0,f=0,g=0,h=0;a=c[2112926]|0;gGz(a|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);a=c[3527092]|0;b=c[3529016]|0;e=0;f=a;while(1){g=d[f]|0;h=d[f+512|0]|0;c[b+(e<<2)>>2]=(-(g>>>1&1)&31)+(-(g&1)&14)+(-(g>>>2&1)&67)+(-(g>>>3&1)&143)<<8&63488|(-(g>>>5&1)&31)+(-(g>>>7)&143)+(-(g>>>4&1)&14)+(-(g>>>6&1)&67)<<3&2016|((-(h>>>1&1)&31)+(-(h&1)&14)+(-(h>>>2&1)&67)+(-(h>>>3&1)&143)|0)>>>3&31;h=e+1|0;if(h>>>0<512){e=h;f=f+1|0}else{break}}f=0;e=a+1024|0;while(1){a=d[e]|0;h=d[e+256|0]|0;g=d[e+512|0]|0;c[b+(f+512<<2)>>2]=(-(h>>>1&1)&31)+(-(h&1)&14)+(-(h>>>2&1)&67)+(-(h>>>3&1)&143)<<3&2016|(-(a>>>1&1)&31)+(-(a&1)&14)+(-(a>>>2&1)&67)+(-(a>>>3&1)&143)<<8&63488|((-(g>>>1&1)&31)+(-(g&1)&14)+(-(g>>>2&1)&67)+(-(g>>>3&1)&143)|0)>>>3&31;g=f+1|0;if(g>>>0<256){f=g;e=e+1|0}else{break}}a9L(0,63,128,64,64,0);a9M(31,0,0,64,512);a9U(32,3,-1,0,0);R8(c[3529016]|0);return}function a9W(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;c[a>>2]=c[b>>2]<<4&3840|c[a>>2];c[b>>2]=((d[9718824]|0)<<4|15)&c[b>>2];return}function a9X(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;c[a>>2]=c[b>>2]<<4&256|c[a>>2];c[b>>2]=((d[9718824]|0)<<4|15)&c[b>>2];return}function a9Y(){var a=0;a=c[2112926]|0;gGz(a|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);a9K();a9L(0,64,128,64,64,0);a9M(31,0,0,64,256);a9U(32,3,0,0,0);R8(c[3529016]|0);return}function a9Z(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;f=c[b>>2]|0;c[a>>2]=f<<6&2048|c[a>>2]|f<<4&256|f<<3&1536;c[b>>2]=((d[9718824]|0)<<4|15)&c[b>>2];return}function a9_(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;a9H();e=c[2439330]|0;f=(e|0)==0;if(!f){g=e;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];g=c[3528484]|0;c[2076596]=g;h=c[2417276]|0;c[3541536]=h;c[1836236]=0;c[e+4172>>2]=3566;c[e+4176>>2]=1330;i=c[2385798]|0;j=128;k=128;while(1){c[e+76+(k<<2)>>2]=i+(k<<8);l=j+1&65535;if((l&65535)>159){m=128;n=128;break}else{j=l;k=l&65535}}while(1){k=i+(n<<8)|0;c[e+76+(n+512<<2)>>2]=k;c[e+76+(n+768<<2)>>2]=k;k=m+1&65535;if((k&65535)>159){break}else{m=k;n=k&65535}}n=c[3529010]|0;c[e+716>>2]=n;c[e+720>>2]=n+256;c[e+724>>2]=n+512;c[e+728>>2]=n+768;c[e+732>>2]=n+1024;c[e+736>>2]=n+1280;c[e+740>>2]=n+1536;c[e+744>>2]=n+1792;c[e+748>>2]=n+2048;c[e+752>>2]=n+2304;c[e+756>>2]=n+2560;c[e+760>>2]=n+2816;c[e+764>>2]=n+3072;c[e+768>>2]=n+3328;c[e+772>>2]=n+3584;c[e+776>>2]=n+3840;m=160;i=160;while(1){c[e+76+(i+256<<2)>>2]=n+((i<<8)-40960);k=m+1&65535;if((k&65535)>175){o=160;p=160;break}else{m=k;i=k&65535}}while(1){i=n+((p<<8)-40960)|0;c[e+76+(p+512<<2)>>2]=i;c[e+76+(p+768<<2)>>2]=i;i=o+1&65535;if((i&65535)>175){break}else{o=i;p=i&65535}}p=c[3529018]|0;c[e+908>>2]=p;c[e+912>>2]=p+256;c[e+916>>2]=p+512;c[e+920>>2]=p+768;c[e+924>>2]=p+1024;c[e+928>>2]=p+1280;c[e+932>>2]=p+1536;c[e+936>>2]=p+1792;c[e+940>>2]=p+2048;c[e+944>>2]=p+2304;c[e+948>>2]=p+2560;c[e+952>>2]=p+2816;c[e+956>>2]=p+3072;c[e+960>>2]=p+3328;c[e+964>>2]=p+3584;c[e+968>>2]=p+3840;o=208;n=208;while(1){c[e+76+(n+256<<2)>>2]=p+((n<<8)-53248);i=o+1&65535;if((i&65535)>223){q=208;r=208;break}else{o=i;n=i&65535}}while(1){n=p+((r<<8)-53248)|0;c[e+76+(r+512<<2)>>2]=n;c[e+76+(r+768<<2)>>2]=n;n=q+1&65535;if((n&65535)>223){break}else{q=n;r=n&65535}}if(!f){r=e;gGC(r|0,9706056,76)|0}r=c[2433530]|0;c[2438118]=r;c[3528484]=g;c[2417276]=h;c[1836236]=-1;c[2431670]=8520;c[2426980]=130;c[2426982]=148;if(f){c[2433530]=r;c[2076596]=g;c[3541536]=h;c[1836236]=0;gGz(9706056,0,76)}else{f=e;gGC(9706056,f|0,76)|0;c[2433530]=r;c[2076596]=g;c[3541536]=h;c[1836236]=0;gGz(9706056,0,76);f=e;gGC(f|0,9706056,76)|0}c[2438118]=r;c[3528484]=g;c[2417276]=h;c[1836236]=-1;a[9660900]=a[9660900]|16;h=c[2437644]|0;g=c[h+1092>>2]|0;do{if((g|0)==0){r=c[h+3144>>2]|0;if((r|0)==0){s=0;t=0;break}f=gj[r&4095](-2)|0;r=c[2437644]|0;e=c[r+1092>>2]|0;q=(f&255)<<8;if((e|0)!=0){u=e;v=q;w=56745;break}e=c[r+3144>>2]|0;if((e|0)==0){s=0;t=q;break}s=gj[e&4095](-1)|0;t=q}else{u=g;v=(d[g+254|0]|0)<<8;w=56745}}while(0);if((w|0)==56745){s=a[u+255|0]|0;t=v}v=s&255|t;c[2415221]=v;b[4830442]=v&65535;a[9660920]=0;a[9660921]=0;a[9660928]=0;a[9660930]=0;a[9660931]=0;c[2415234]=0;gGz(9660901,0,5);c[2415235]=65535;c[2415237]=65535;a[9660932]=a[9660932]|64;mB(0);mB(1);UA();c[2429502]=0;c[2429500]=0;c[2438664]=0;c[2439460]=0;a[9757800]=0;a[9623080]=0;a[9623072]=0;a[683232]=0;a[9754673]=0;a[9754672]=0;a[9754680]=0;a[9718896]=0;a[9717272]=0;a[9718824]=0;return}function a9$(){var a=0;a=c[2112926]|0;gGz(a|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);a9K();a9L(0,64,0,64,32,0);a9L(1,64,0,64,32,0);a9M(31,0,0,64,256);a9L(1,64,0,64,32,1);a9U(64,3,0,128,0);R8(c[3529016]|0);return}function a90(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;c[a>>2]=c[a>>2]|c[b>>2]<<3&1792|(d[9717272]|0)<<11;c[e>>2]=(c[b>>2]&224|0)==224;c[b>>2]=c[b>>2]&31;return}function a91(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;c[a>>2]=c[b>>2]<<2&768|c[a>>2];c[b>>2]=c[b>>2]&31;return}function a92(){var a=0;c[2429500]=32;c[2429502]=-64;a=c[2112926]|0;gGz(a|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);a9K();a9L(0,64,0,32,64,0);a9U(64,3,0,32,512);a9M(31,0,0,64,256);R8(c[3529016]|0);return}function a93(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;c[a>>2]=c[b>>2]<<2&768|c[a>>2];c[e>>2]=c[b>>2]&32;c[b>>2]=c[b>>2]&31;return}function a94(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0;b=i;i=i+2640|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;l=b+360|0;m=b+472|0;n=b+480|0;o=b+592|0;p=b+600|0;q=b+712|0;r=b+720|0;s=b+832|0;t=b+840|0;u=b+952|0;v=b+960|0;w=b+1072|0;x=b+1080|0;y=b+1192|0;z=b+1200|0;A=b+1312|0;B=b+1320|0;C=b+1432|0;D=b+1440|0;E=b+1552|0;F=b+1560|0;G=b+1672|0;H=b+1680|0;I=b+1792|0;J=b+1800|0;K=b+1912|0;L=b+1920|0;M=b+2032|0;N=b+2040|0;O=b+2152|0;P=b+2160|0;Q=b+2272|0;R=b+2280|0;S=b+2392|0;T=b+2400|0;U=b+2512|0;V=b+2520|0;W=b+2632|0;X=0;while(1){if((X|0)>=1024){Y=0;break}Z=9638528+(X<<2)|0;if((c[Z>>2]|0)==0){_=56757;break}else{X=X+1|0}}do{if((_|0)==56757){X=gGq(98304)|0;c[Z>>2]=X;if((X|0)==0){Y=0;break}gGz(X|0,0,98304);Y=X}}while(0);c[3529012]=Y;Y=c[2385798]|0;if((c[3542200]|0)==0){$=1;i=b;return $|0}Z=V+108|0;c[Z>>2]=0;X=V+100|0;c[X>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](V,0)|0;do{if((c[Z>>2]|0)!=0){V=c[X>>2]|0;c[W>>2]=9534384;aa=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aa&16383](W,0,0)|0;if((V|0)<1){$=1;i=b;return $|0}if((gzL(Y,0,0)|0)==0){break}else{$=1}i=b;return $|0}}while(0);Y=(c[2385798]|0)+16384|0;if((c[3542200]|0)==0){$=1;i=b;return $|0}W=T+108|0;c[W>>2]=0;X=T+100|0;c[X>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](T,1)|0;do{if((c[W>>2]|0)!=0){T=c[X>>2]|0;c[U>>2]=9534384;Z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Z&16383](U,1,0)|0;if((T|0)<1){$=1;i=b;return $|0}if((gzL(Y,0,1)|0)==0){break}else{$=1}i=b;return $|0}}while(0);Y=(c[2385798]|0)+32768|0;if((c[3542200]|0)==0){$=1;i=b;return $|0}U=R+108|0;c[U>>2]=0;X=R+100|0;c[X>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](R,2)|0;do{if((c[U>>2]|0)!=0){R=c[X>>2]|0;c[S>>2]=9534384;W=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[W&16383](S,2,0)|0;if((R|0)<1){$=1;i=b;return $|0}if((gzL(Y,0,2)|0)==0){break}else{$=1}i=b;return $|0}}while(0);Y=(c[3527098]|0)+16384|0;if((c[3542200]|0)==0){$=1;i=b;return $|0}S=P+108|0;c[S>>2]=0;X=P+100|0;c[X>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](P,3)|0;do{if((c[S>>2]|0)!=0){P=c[X>>2]|0;c[Q>>2]=9534384;U=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[U&16383](Q,3,0)|0;if((P|0)<1){$=1;i=b;return $|0}if((gzL(Y,0,3)|0)==0){break}else{$=1}i=b;return $|0}}while(0);Y=(c[3527098]|0)+32768|0;if((c[3542200]|0)==0){$=1;i=b;return $|0}Q=N+108|0;c[Q>>2]=0;X=N+100|0;c[X>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](N,4)|0;do{if((c[Q>>2]|0)!=0){N=c[X>>2]|0;c[O>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](O,4,0)|0;if((N|0)<1){$=1;i=b;return $|0}if((gzL(Y,0,4)|0)==0){break}else{$=1}i=b;return $|0}}while(0);Y=c[3529012]|0;gGz(Y|0,0,98304);if((c[3542200]|0)==0){$=1;i=b;return $|0}O=L+108|0;c[O>>2]=0;X=L+100|0;c[X>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](L,5)|0;do{if((c[O>>2]|0)!=0){L=c[X>>2]|0;c[M>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](M,5,0)|0;if((L|0)<1){$=1;i=b;return $|0}if((gzL(Y,0,5)|0)==0){break}else{$=1}i=b;return $|0}}while(0);Y=(c[3529012]|0)+16384|0;if((c[3542200]|0)==0){$=1;i=b;return $|0}M=J+108|0;c[M>>2]=0;X=J+100|0;c[X>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](J,6)|0;do{if((c[M>>2]|0)!=0){J=c[X>>2]|0;c[K>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](K,6,0)|0;if((J|0)<1){$=1;i=b;return $|0}if((gzL(Y,0,6)|0)==0){break}else{$=1}i=b;return $|0}}while(0);Y=(c[3529012]|0)+32768|0;if((c[3542200]|0)==0){$=1;i=b;return $|0}K=H+108|0;c[K>>2]=0;X=H+100|0;c[X>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](H,7)|0;do{if((c[K>>2]|0)!=0){H=c[X>>2]|0;c[I>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](I,7,0)|0;if((H|0)<1){$=1;i=b;return $|0}if((gzL(Y,0,7)|0)==0){break}else{$=1}i=b;return $|0}}while(0);Y=c[3527094]|0;I=c[2439464]|0;X=c[2439462]|0;K=c[3529012]|0;H=c[2405764]|0;if((Y|0)>0){M=ag(X,I)|0;J=(X|0)<1|(I|0)<1;O=0;do{L=ag(O,M)|0;gGz(H+L|0,0,M|0);Q=O<<6;N=Q+262144|0;if(!J){S=0;do{P=N+(c[1238464+(S<<2)>>2]|0)|0;U=(ag(S,I)|0)+L|0;R=0;do{W=P+(c[614800+(R<<2)>>2]|0)|0;if(((d[K+((W|0)/8|0)|0]|0)&128>>>((W&7)>>>0)|0)!=0){W=H+(U+R)|0;a[W]=a[W]|4}R=R+1|0;}while((R|0)<(I|0));S=S+1|0;}while((S|0)<(X|0));S=Q+131072|0;N=0;while(1){R=S+(c[1238464+(N<<2)>>2]|0)|0;U=(ag(N,I)|0)+L|0;P=0;do{W=R+(c[614800+(P<<2)>>2]|0)|0;if(((d[K+((W|0)/8|0)|0]|0)&128>>>((W&7)>>>0)|0)!=0){W=H+(U+P)|0;a[W]=a[W]|2}P=P+1|0;}while((P|0)<(I|0));P=N+1|0;if((P|0)<(X|0)){N=P}else{ab=0;break}}do{N=Q+(c[1238464+(ab<<2)>>2]|0)|0;S=(ag(ab,I)|0)+L|0;P=0;do{U=N+(c[614800+(P<<2)>>2]|0)|0;if(((d[K+((U|0)/8|0)|0]|0)&128>>>((U&7)>>>0)|0)!=0){U=H+(S+P)|0;a[U]=a[U]|1}P=P+1|0;}while((P|0)<(I|0));ab=ab+1|0;}while((ab|0)<(X|0))}O=O+1|0;}while((O|0)<(Y|0))}gGz(K|0,0,98304);if((c[3542200]|0)==0){$=1;i=b;return $|0}Y=F+108|0;c[Y>>2]=0;O=F+100|0;c[O>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](F,8)|0;do{if((c[Y>>2]|0)!=0){F=c[O>>2]|0;c[G>>2]=9534384;X=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[X&16383](G,8,0)|0;if((F|0)<1){$=1;i=b;return $|0}if((gzL(K,0,8)|0)==0){break}else{$=1}i=b;return $|0}}while(0);K=(c[3529012]|0)+16384|0;if((c[3542200]|0)==0){$=1;i=b;return $|0}G=D+108|0;c[G>>2]=0;O=D+100|0;c[O>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](D,9)|0;do{if((c[G>>2]|0)!=0){D=c[O>>2]|0;c[E>>2]=9534384;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Y&16383](E,9,0)|0;if((D|0)<1){$=1;i=b;return $|0}if((gzL(K,0,9)|0)==0){break}else{$=1}i=b;return $|0}}while(0);K=(c[3529012]|0)+32768|0;if((c[3542200]|0)==0){$=1;i=b;return $|0}E=B+108|0;c[E>>2]=0;O=B+100|0;c[O>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](B,10)|0;do{if((c[E>>2]|0)!=0){B=c[O>>2]|0;c[C>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](C,10,0)|0;if((B|0)<1){$=1;i=b;return $|0}if((gzL(K,0,10)|0)==0){break}else{$=1}i=b;return $|0}}while(0);K=(c[3529012]|0)+49152|0;if((c[3542200]|0)==0){$=1;i=b;return $|0}C=z+108|0;c[C>>2]=0;O=z+100|0;c[O>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,11)|0;do{if((c[C>>2]|0)!=0){z=c[O>>2]|0;c[A>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](A,11,0)|0;if((z|0)<1){$=1;i=b;return $|0}if((gzL(K,0,11)|0)==0){break}else{$=1}i=b;return $|0}}while(0);K=(c[3529012]|0)+65536|0;if((c[3542200]|0)==0){$=1;i=b;return $|0}A=x+108|0;c[A>>2]=0;O=x+100|0;c[O>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,12)|0;do{if((c[A>>2]|0)!=0){x=c[O>>2]|0;c[y>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](y,12,0)|0;if((x|0)<1){$=1;i=b;return $|0}if((gzL(K,0,12)|0)==0){break}else{$=1}i=b;return $|0}}while(0);K=(c[3529012]|0)+81920|0;if((c[3542200]|0)==0){$=1;i=b;return $|0}y=v+108|0;c[y>>2]=0;O=v+100|0;c[O>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,13)|0;do{if((c[y>>2]|0)!=0){v=c[O>>2]|0;c[w>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](w,13,0)|0;if((v|0)<1){$=1;i=b;return $|0}if((gzL(K,0,13)|0)==0){break}else{$=1}i=b;return $|0}}while(0);K=c[2439452]|0;w=c[3529012]|0;O=c[3529014]|0;if((K|0)>0){y=0;do{v=y<<8;gGz(O+v|0,0,256);A=v+524288|0;x=0;do{C=A+(c[609008+(x<<2)>>2]|0)|0;z=(x<<4)+v|0;E=0;do{B=C+(c[597864+(E<<2)>>2]|0)|0;if(((d[w+((B|0)/8|0)|0]|0)&128>>>((B&7)>>>0)|0)!=0){B=O+(z+E)|0;a[B]=a[B]|4}E=E+1|0;}while((E|0)<16);x=x+1|0;}while((x|0)<16);x=v+262144|0;A=0;while(1){E=x+(c[609008+(A<<2)>>2]|0)|0;z=(A<<4)+v|0;C=0;do{B=E+(c[597864+(C<<2)>>2]|0)|0;if(((d[w+((B|0)/8|0)|0]|0)&128>>>((B&7)>>>0)|0)!=0){B=O+(z+C)|0;a[B]=a[B]|2}C=C+1|0;}while((C|0)<16);C=A+1|0;if((C|0)<16){A=C}else{ac=0;break}}do{A=v+(c[609008+(ac<<2)>>2]|0)|0;x=(ac<<4)+v|0;C=0;do{z=A+(c[597864+(C<<2)>>2]|0)|0;if(((d[w+((z|0)/8|0)|0]|0)&128>>>((z&7)>>>0)|0)!=0){z=O+(x+C)|0;a[z]=a[z]|1}C=C+1|0;}while((C|0)<16);ac=ac+1|0;}while((ac|0)<16);y=y+1|0;}while((y|0)<(K|0))}K=c[3527092]|0;if((c[3542200]|0)==0){$=1;i=b;return $|0}y=t+108|0;c[y>>2]=0;ac=t+100|0;c[ac>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,14)|0;do{if((c[y>>2]|0)!=0){t=c[ac>>2]|0;c[u>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](u,14,0)|0;if((t|0)<1){$=1;i=b;return $|0}if((gzL(K,0,14)|0)==0){break}else{$=1}i=b;return $|0}}while(0);K=(c[3527092]|0)+256|0;if((c[3542200]|0)==0){$=1;i=b;return $|0}u=r+108|0;c[u>>2]=0;ac=r+100|0;c[ac>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,15)|0;do{if((c[u>>2]|0)!=0){r=c[ac>>2]|0;c[s>>2]=9534384;y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[y&16383](s,15,0)|0;if((r|0)<1){$=1;i=b;return $|0}if((gzL(K,0,15)|0)==0){break}else{$=1}i=b;return $|0}}while(0);K=(c[3527092]|0)+512|0;if((c[3542200]|0)==0){$=1;i=b;return $|0}s=p+108|0;c[s>>2]=0;ac=p+100|0;c[ac>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,16)|0;do{if((c[s>>2]|0)!=0){p=c[ac>>2]|0;c[q>>2]=9534384;u=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[u&16383](q,16,0)|0;if((p|0)<1){$=1;i=b;return $|0}if((gzL(K,0,16)|0)==0){break}else{$=1}i=b;return $|0}}while(0);K=(c[3527092]|0)+768|0;if((c[3542200]|0)==0){$=1;i=b;return $|0}q=n+108|0;c[q>>2]=0;ac=n+100|0;c[ac>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,17)|0;do{if((c[q>>2]|0)!=0){n=c[ac>>2]|0;c[o>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](o,17,0)|0;if((n|0)<1){$=1;i=b;return $|0}if((gzL(K,0,17)|0)==0){break}else{$=1}i=b;return $|0}}while(0);K=(c[3527092]|0)+1024|0;if((c[3542200]|0)==0){$=1;i=b;return $|0}o=l+108|0;c[o>>2]=0;ac=l+100|0;c[ac>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,18)|0;do{if((c[o>>2]|0)!=0){l=c[ac>>2]|0;c[m>>2]=9534384;q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[q&16383](m,18,0)|0;if((l|0)<1){$=1;i=b;return $|0}if((gzL(K,0,18)|0)==0){break}else{$=1}i=b;return $|0}}while(0);K=(c[3527092]|0)+1280|0;if((c[3542200]|0)==0){$=1;i=b;return $|0}m=j+108|0;c[m>>2]=0;ac=j+100|0;c[ac>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,19)|0;do{if((c[m>>2]|0)!=0){j=c[ac>>2]|0;c[k>>2]=9534384;o=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[o&16383](k,19,0)|0;if((j|0)<1){$=1;i=b;return $|0}if((gzL(K,0,19)|0)==0){break}else{$=1}i=b;return $|0}}while(0);K=(c[3527092]|0)+1536|0;if((c[3542200]|0)==0){$=1;i=b;return $|0}k=g+108|0;c[k>>2]=0;ac=g+100|0;c[ac>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,20)|0;do{if((c[k>>2]|0)!=0){g=c[ac>>2]|0;c[h>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](h,20,0)|0;if((g|0)<1){$=1;i=b;return $|0}if((gzL(K,0,20)|0)==0){break}else{$=1}i=b;return $|0}}while(0);K=(c[3527092]|0)+1568|0;if((c[3542200]|0)==0){$=1;i=b;return $|0}h=e+108|0;c[h>>2]=0;ac=e+100|0;c[ac>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,21)|0;do{if((c[h>>2]|0)!=0){e=c[ac>>2]|0;c[f>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](f,21,0)|0;if((e|0)<1){$=1;i=b;return $|0}if((gzL(K,0,21)|0)==0){break}else{$=1}i=b;return $|0}}while(0);K=c[3529012]|0;f=0;while(1){if((f|0)>=1024){break}ad=9638528+(f<<2)|0;if((c[ad>>2]|0)==(K|0)){_=56867;break}else{f=f+1|0}}if((_|0)==56867){gGr(K);c[ad>>2]=0}c[3529012]=0;$=0;i=b;return $|0}function a95(){var a=0;a=c[2112926]|0;gGz(a|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);a9K();a9L(0,62,0,64,32,0);a9M(15,0,0,64,256);R8(c[3529016]|0);return}function a96(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;e=c[b>>2]|0;c[a>>2]=e<<5&1024|c[a>>2]|e<<2&768;c[b>>2]=c[b>>2]&31;return}function a97(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;d=c[2112926]|0;gGz(d|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);a9K();a9L(0,64,0,64,32,0);a9L(1,64,0,64,32,0);a9M(15,16,0,64,256);a9L(1,64,0,64,32,1);a9M(15,16,16,64,256);d=c[2113068]|0;if(!((a[9718896]|0)!=0&(d|0)>0)){e=c[3529016]|0;R8(e);return}f=c[2112926]|0;g=d*248|0;h=d*249|0;i=d<<1;j=d*250|0;k=d*3|0;l=d*251|0;m=d<<2;n=d*252|0;o=d*5|0;p=d*253|0;q=d*6|0;r=d*254|0;s=d*7|0;t=d*255|0;u=0;do{b[f+(u<<1)>>1]=0;b[f+(g+u<<1)>>1]=0;b[f+(d+u<<1)>>1]=0;b[f+(h+u<<1)>>1]=0;b[f+(i+u<<1)>>1]=0;b[f+(j+u<<1)>>1]=0;b[f+(k+u<<1)>>1]=0;b[f+(l+u<<1)>>1]=0;b[f+(m+u<<1)>>1]=0;b[f+(n+u<<1)>>1]=0;b[f+(o+u<<1)>>1]=0;b[f+(p+u<<1)>>1]=0;b[f+(q+u<<1)>>1]=0;b[f+(r+u<<1)>>1]=0;b[f+(s+u<<1)>>1]=0;b[f+(t+u<<1)>>1]=0;u=u+1|0;}while((u|0)<(d|0));e=c[3529016]|0;R8(e);return}function a98(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;c[a>>2]=c[b>>2]<<2&768|c[a>>2];c[e>>2]=c[b>>2]&32;c[d>>2]=(c[b>>2]&24)>>>0>6;c[b>>2]=c[b>>2]&31;return}function a99(){var a=0;a=c[2112926]|0;gGz(a|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);a9K();a9L(0,64,0,64,32,0);a9L(1,64,0,64,32,0);a9M(15,16,0,64,256);a9L(1,64,0,64,32,1);a9M(15,16,16,64,256);R8(c[3529016]|0);return}function baa(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;c[a>>2]=c[b>>2]<<2&768|c[a>>2];c[e>>2]=c[b>>2]&32;c[d>>2]=(c[b>>2]&24)>>>0>22;c[b>>2]=c[b>>2]&31;return}function bab(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0;a=c[2112926]|0;gGz(a|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);a=c[3527092]|0;b=c[3529016]|0;e=0;f=a;while(1){g=d[f]|0;h=d[f+512|0]|0;i=d[f+1024|0]|0;c[b+(e<<2)>>2]=(-(h>>>1&1)&31)+(-(h&1)&14)+(-(h>>>2&1)&67)+(-(h>>>3&1)&143)<<3&2016|(-(g>>>1&1)&31)+(-(g&1)&14)+(-(g>>>2&1)&67)+(-(g>>>3&1)&143)<<8&63488|((-(i>>>1&1)&31)+(-(i&1)&14)+(-(i>>>2&1)&67)+(-(i>>>3&1)&143)|0)>>>3&31;i=e+1|0;if(i>>>0<512){e=i;f=f+1|0}else{j=0;break}}do{f=d[a+(j+1824)|0]|0;c[b+(j+512<<2)>>2]=(-(f>>>3&1)&33)+(-(f>>>4&1)&71)+(-(f>>>5&1)&151)<<3&2016|((-(f>>>6&1)&71)+(-(f>>>7)&151)|0)>>>3&31|(-(f>>>1&1)&71)+(-(f&1)&33)+(-(f>>>2&1)&151)<<8&63488;j=j+1|0;}while(j>>>0<32);a9L(0,128,0,64,32,0);a9L(1,128,0,64,32,0);a9M(15,16,0,128,256);a9L(1,128,0,64,32,1);a9M(15,16,16,128,256);a9U(32,2,0,0,512);R8(c[3529016]|0);return}function bac(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0;f=c[b>>2]|0;c[a>>2]=f<<4&256|c[a>>2]|f<<3&512;c[e>>2]=c[b>>2]&32;c[d>>2]=(c[b>>2]&24)>>>0>6;c[b>>2]=c[b>>2]&15;return}function bad(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;e=c[b>>2]|0;c[a>>2]=e<<4&256|c[a>>2]|e<<3&512;c[b>>2]=c[b>>2]&15;return}function bae(){var a=0;a=c[2112926]|0;gGz(a|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);a9K();baf(0,0);baf(1,0);a9M(31,0,0,128,256);baf(0,1);R8(c[3529016]|0);return}function baf(e,f){e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;g=(f|0)!=0;f=c[3529010]|0;h=(c[3527094]|0)-1|0;i=c[2439464]|0;j=c[2439462]|0;k=(c[2439460]|0)==0;l=(j|0)>0;m=c[2405764]|0;n=c[2429502]|0;o=c[2113070]|0;p=c[2113068]|0;q=c[2112926]|0;r=(j<<5)+~j|0;s=(i<<6)+~i|0;t=0;u=0;while(1){v=(t|0)>5;w=ag(j,t)|0;x=r-w|0;y=u;z=0;while(1){A=d[f+(y+2048)|0]|0;B=A&32;C=(A<<2&768|(d[f+y|0]|0))&h;if((((y|0)/64|0)&67108863|0)==0){D=(A&30)>>>0>24|0}else{D=1}E=ag(i,z)|0;if(k){F=0;G=B;H=w;I=E}else{F=1;G=B>>>5^1;H=x;I=s-E|0}E=I-128|0;B=A<<3&248;if((D|0)==(e|0)&l){A=(G|0)!=0;J=(F|0)!=0;K=A&J;L=0;M=0;while(1){L73543:do{if((i|0)>0){N=M-1|0;O=L+H|0;P=(O|0)<0;Q=0;R=-1;while(1){S=ag(j,C)|0;do{if(J){T=ag(N+j+S|0,i)|0;if(!K){U=m+(T+Q)|0;break}U=m+(R+i+T)|0}else{U=m+((A?R+i|0:Q)+(ag(S+L|0,i)|0))|0}}while(0);S=a[U]|0;do{if(!(g&S<<24>>24==0)){T=E+Q|0;V=i<<6;W=V-1|0;do{if(v){X=n&W;if(k){Y=T-X|0;Z=V;_=W;break}else{Y=X+T|0;Z=V;_=W;break}}else{Y=T;Z=V;_=W}}while(0);W=((Y|0)<0?Z:0)+Y|0;V=W-((W|0)>(_|0)?Z:0)|0;W=j<<5;T=(P?W:0)+O|0;X=T-((T|0)>(W-1|0)?W:0)|0;if(!((X|0)>-1&(X|0)<(o|0))){break}if(!((V|0)>-1&(V|0)<(p|0))){break}b[q+((ag(p,X)|0)+V<<1)>>1]=(S&255|B)&65535}}while(0);S=Q+1|0;if((S|0)>=(i|0)){break L73543}V=-2-Q|0;Q=S;R=V}}}while(0);R=L+1|0;Q=~L;if((R|0)<(j|0)){L=R;M=Q}else{break}}}M=z+1|0;if((M|0)>=64){break}y=y+1|0;z=M}z=t+1|0;if((z|0)<32){t=z;u=u+64|0}else{break}}return}function bag(d,e){d=d|0;e=e|0;var f=0;if((d&1047552|0)!=917504){return}f=c[2387292]|0;a[f+(d&1023)|0]=e;e=d&1022;d=b[f+e>>1]|0;c[(c[3530204]|0)+(e>>>1<<2)>>2]=((d&65535)>>>10<<3&65535)>>>3&31|((d&255)<<3&255)<<8|(((d&65535)>>>5<<3&255|(d&65535)>>>7&4)&255)<<3&2016;return}function bah(a){a=a|0;return 0}function bai(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;if((b&-16|0)==128){a[(c[2430466]|0)+(b&15)|0]=d;return}if((b|0)==0){a[c[3528380]|0]=d;e=a[9542392]&-33;a[9542392]=e;a[14125144]=e;a[9706117]=1;return}else if((b|0)==4){b=(c[2386302]|0)+(((d&255)<<16&983040|1048576)-524288)|0;d=c[3531864]|0;e=256;while(1){c[d+44+(e<<2)>>2]=b;f=e+1|0;if((f|0)<288){e=f}else{g=256;break}}do{c[d+4140+(g<<2)>>2]=b;c[d+6188+(g<<2)>>2]=b;g=g+1|0;}while((g|0)<288);return}else{return}}function baj(b){b=b|0;var c=0;switch(b|0){case 0:{c=a[9551024]|0;break};case 4:{c=a[9635736]|0;break};case 2:{c=(a[672640]|0?-128:0)|a[9551026]&127;break};case 6:{c=a[9551027]|0;break};case 5:{c=a[9635737]|0;break};case 7:{c=a[9551028]|0;break};case 1:{c=a[9551025]|0;break};default:{c=0}}return c|0}function bak(d,e){d=d|0;e=e|0;var f=0;switch(d&255|0){case 0:case 64:{c[2113304]=e&255;return};case 66:case 131:{d=a[9542392]|32;a[9542392]=d;a[14125144]=d;f=d<<24>>24!=-1|0;if((f|0)==0){a[9706117]=0;return}else if((f|0)==1){a[9706117]=1;return}else{return}break};case 129:{c[2438062]=c[2438062]&2088960|(e&255)<<5;return};case 1:case 65:{f=c[2113304]|0;a[14168504+f|0]=e;mv(0,f,e&255);return};case 130:{US(0,gD[c[2385643]&8191]()|0);b[4771272]=~~(+(b[9753784+((e&255)<<1)>>1]|0)*+h[1192819])&65535;c[2438062]=(c[2438062]|0)+1&262143;return};case 128:{c[2438062]=c[2438062]&8160|(e&255)<<13;return};default:{return}}}function bal(b){b=b|0;var d=0;switch(b&255|0){case 0:case 1:case 64:case 65:{d=c[(c[3531464]|0)+4240>>2]&255;return d|0};case 132:{d=a[(c[2386702]|0)+(c[2438062]&16383)|0]|0;return d|0};case 66:case 128:{a[14125144]=-1;a[9706117]=0;d=a[c[3528380]|0]|0;return d|0};default:{d=0;return d|0}}return 0}function bam(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5873148+(b*112|0)>>2];c[a+104>>2]=c[5873152+(b*112|0)>>2];c[a+108>>2]=c[5873156+(b*112|0)>>2];d=0;return d|0}function ban(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=5873048+(b*112|0);e=0;return e|0}function bao(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1037232+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function bap(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>36){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6278632+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function baq(){c[2438882]=48;c[2438880]=136;return ba5(262144,524288,0,0,48664)|0}function bar(){var a=0,b=0,d=0,e=0;c[2113070]=0;c[2113068]=0;a=c[2112926]|0;if((a|0)!=0){gGr(a);c[2112926]=0}a=c[3531464]|0;c[a+44344>>2]=0;c[a+44348>>2]=0;if((a|0)!=0){gGr(a);c[3531464]=0}a=c[2406684]|0;if((a|0)!=0){gGr(a);c[2406684]=0}UT();fwZ();fyA();a=c[2415114]|0;b=0;while(1){if((b|0)>=1024){d=57100;break}e=9638528+(b<<2)|0;if((c[e>>2]|0)==(a|0)){break}else{b=b+1|0}}if((d|0)==57100){c[2415114]=0;c[2438880]=0;c[2438882]=0;return 0}gGr(a);c[e>>2]=0;c[2415114]=0;c[2438880]=0;c[2438882]=0;return 0}function bas(){var d=0,e=0,f=0,g=0,h=0,i=0;if((a[9625088]|0)!=0){d=c[2414822]|0;gGz(d|0,0,(c[2411884]|0)-d|0);c[1836234]=0;d=c[2439374]|0;c[3531864]=d;gf[c[d>>2]&2047](0);d=c[(c[3531864]|0)+8>>2]|0;gD[d&8191]()|0;c[1836234]=-1;gu[c[(c[3531864]|0)+4>>2]&16383]();c[3531864]=0;d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;h=c[2417276]|0;c[3541536]=h;c[1836236]=0;gGz(9706056,0,76);a[9542392]=-1;a[14125144]=-1;a[9706117]=0;if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=h;c[1836236]=-1;mx(0);h=c[2405758]|0;if((h|0)>0){g=0;do{c[9542560+(g<<5)>>2]=0;b[9542544+(g<<5)>>1]=0;g=g+1|0;}while((g|0)<(h|0))}c[2438062]=0}gGz(9551024,-1|0,5);h=0;g=-1;f=-1;e=-1;d=-1;i=-1;do{g=((a[9634448+h|0]&1)<<h^g&255)&255;f=((a[9632208+h|0]&1)<<h^f&255)&255;e=((a[9630128+h|0]&1)<<h^e&255)&255;d=((a[9629120+h|0]&1)<<h^d&255)&255;i=((a[9628856+h|0]&1)<<h^i&255)&255;h=h+1|0;}while((h|0)<8);a[9551024]=g;a[9551025]=f;a[9551026]=e;a[9551027]=d;a[9551028]=i;i=c[2438]|0;d=i;e=(i|0)<0|0?-1:0;i=gGU(d,e,133333,0)|0;f=gGS(i,K,256,0)|0;i=f;f=gGU(d,e,59659,0)|0;e=gGS(f,K,256,0)|0;f=e;c[2409128]=0;c[2409245]=0;c[2409362]=0;c[2409479]=0;c[2409508]=0;c[2409537]=0;c[2409566]=0;c[2409595]=0;e=c[2385548]|0;if((e|0)>0){gGz(9752472,0,((e|0)>1?e<<2:4)|0)}c[2433530]=0;c[1836234]=0;e=c[2439374]|0;c[3531864]=e;gf[c[e>>2]&2047](0);e=c[2439330]|0;if((e|0)!=0){d=e;gGC(9706056,d|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;a[672640]=0;d=(i|0)/128|0;e=(f|0)/128|0;g=(i|0)<128;i=(f|0)<128;f=0;while(1){if(!g){h=c[(c[3531864]|0)+12>>2]|0;gj[h&4095](d)|0}if((f|0)==127){gG[c[(c[3531864]|0)+16>>2]&255](10,255,1);gG[c[(c[3531864]|0)+16>>2]&255](10,255,0)}do{if(!i){if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){h=gfc(e)|0;c[2433530]=(c[2433530]|0)+h;break}else{c[2433530]=(c[2433530]|0)+e;break}}}while(0);if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12;if((f|0)==124){a[672640]=1;f=125;continue}else{h=f+1|0;if((h|0)<128){f=h;continue}else{break}}}f=c[2112964]|0;if((f|0)!=0){gg[c[3542124]&4095](f,a[9688]|0?534:0);UR(c[2112964]|0,a[9688]|0?534:0)}c[1836234]=-1;gu[c[(c[3531864]|0)+4>>2]&16383]();c[3531864]=0;f=c[1836236]|0;e=c[9757320+(f<<2)>>2]|0;if((e|0)!=0){i=e;gGC(i|0,9706056,76)|0}c[9752472+(f<<2)>>2]=c[2433530];c[14113936+(f<<2)>>2]=c[2076596];c[9669104+(f<<2)>>2]=c[3541536];c[1836236]=-1;if((c[2112968]|0)==0){return 0}bat()|0;return 0}function bat(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;if((a[9548064]|0)!=0){f=c[2387292]|0;g=c[3530204]|0;h=0;do{i=b[f+h>>1]|0;c[g+(((h|0)/2|0)<<2)>>2]=((i&65535)>>>10<<3&65535)>>>3&31|((i&255)<<3&255)<<8|(((i&65535)>>>5<<3&255|(i&65535)>>>7&4)&255)<<3&2016;h=h+2|0;}while((h|0)<1024);a[9548064]=0}h=c[2430466]|0;g=h+14|0;if((a[g]&4)!=0){f=c[2112926]|0;gGz(f|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);j=c[3530204]|0;R8(j);return 0}if((a[h+12|0]&16)==0){ba8(1);k=c[2112926]|0;l=c[2439410]|0;m=c[2113068]|0;n=c[2113070]|0}else{h=c[2439410]|0;f=c[2113068]|0;i=c[2113070]|0;gGz(h|0,0,ag(i,f)|0);o=c[2112926]|0;gGz(o|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);k=o;l=h;m=f;n=i}ba8(0);i=d[g]|0;g=(c[2386278]|0)+60928|0;f=(i&1|0)==0;h=(i&2|0)==0;i=c[2438882]|0;o=c[2438880]|0;p=c[3530724]|0;q=c[2385706]|0;r=249;do{s=e[g+(r<<1)>>1]|0;t=e[g+(r+1<<1)>>1]|0;u=e[g+(r+2<<1)>>1]|0;v=s&32768;w=u&512;x=1<<(s>>>13&3);y=s>>>9;z=(u-i&511)-16|0;u=o+s&511;A=x<<4;do{if(f){if(h){B=130;break}B=(y&12|0)==12?128:130}else{B=s>>>11&2^130}}while(0);if((x|0)>0){s=(v|0)==0;C=y<<4&240;D=512-A-u|0;E=s?0:240;F=(w|0)==0?E:E|15;E=x+16777215|0;G=(m|0)<=(z|0)|(z|0)<-15;H=0;do{I=D+(H<<4)|0;L73756:do{if((n|0)>(I|0)&((G|(I|0)<-15)^1)){J=(q&(s?H:E-H|0)+t)<<8;K=I;L=0;while(1){if((K|0)>-1&(K|0)<(n|0)){M=L<<4;N=ag(m,K)|0;O=z;P=0;while(1){do{if((O|0)>=0&(O|0)<(m|0)){Q=a[p+((P+M^F)+J)|0]|0;if(Q<<24>>24==0){break}R=N+O|0;S=l+R|0;if((1<<d[S]&B|0)!=0){break}b[k+(R<<1)>>1]=(C|Q&255|256)&65535;a[S]=7}}while(0);S=P+1|0;if((S|0)<16){O=O+1|0;P=S}else{break}}}P=L+1|0;if((P|0)>=16){break L73756}K=K+1|0;L=P}}}while(0);H=H+1|0;}while((H|0)<(x|0))}r=r-3|0;}while((r|0)>-1);j=c[3530204]|0;R8(j);return 0}function bau(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2906092+(b*112|0)>>2];c[a+104>>2]=c[2906096+(b*112|0)>>2];c[a+108>>2]=c[2906100+(b*112|0)>>2];d=0;return d|0}function bav(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=2905992+(b*112|0);e=0;return e|0}function baw(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>35){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1035600+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function bax(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>51){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4026384+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function bay(){c[2438882]=80;c[2438880]=136;return ba5(262144,1048576,131072,0,61864)|0}function baz(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3060564+(b*112|0)>>2];c[a+104>>2]=c[3060568+(b*112|0)>>2];c[a+108>>2]=c[3060572+(b*112|0)>>2];d=0;return d|0}function baA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=3060464+(b*112|0);e=0;return e|0}function baB(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>43){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4218008+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function baC(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3128276+(b*112|0)>>2];c[a+104>>2]=c[3128280+(b*112|0)>>2];c[a+108>>2]=c[3128284+(b*112|0)>>2];d=0;return d|0}function baD(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=3128176+(b*112|0);e=0;return e|0}function baE(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>51){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4259032+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function baF(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5945556+(b*112|0)>>2];c[a+104>>2]=c[5945560+(b*112|0)>>2];c[a+108>>2]=c[5945564+(b*112|0)>>2];d=0;return d|0}function baG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=5945456+(b*112|0);e=0;return e|0}function baH(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>51){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6419320+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function baI(){c[2438882]=80;c[2438880]=136;return ba5(524288,1048576,131072,0,52736)|0}function baJ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4814564+(b*112|0)>>2];c[a+104>>2]=c[4814568+(b*112|0)>>2];c[a+108>>2]=c[4814572+(b*112|0)>>2];d=0;return d|0}function baK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=4814464+(b*112|0);e=0;return e|0}function baL(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>48){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5577152+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function baM(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2509892+(b*112|0)>>2];c[a+104>>2]=c[2509896+(b*112|0)>>2];c[a+108>>2]=c[2509900+(b*112|0)>>2];d=0;return d|0}function baN(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=2509792+(b*112|0);e=0;return e|0}function baO(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5735772+(b*112|0)>>2];c[a+104>>2]=c[5735776+(b*112|0)>>2];c[a+108>>2]=c[5735780+(b*112|0)>>2];d=0;return d|0}function baP(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=5735672+(b*112|0);e=0;return e|0}function baQ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>23){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3586336+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function baR(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>38){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6160944+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function baS(){c[2438882]=48;c[2438880]=128;return ba5(524288,2097152,262144,1048576,44528)|0}function baT(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2381076+(b*112|0)>>2];c[a+104>>2]=c[2381080+(b*112|0)>>2];c[a+108>>2]=c[2381084+(b*112|0)>>2];d=0;return d|0}function baU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=2380976+(b*112|0);e=0;return e|0}function baV(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>43){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3554944+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function baW(){c[2438882]=80;c[2438880]=136;return ba5(524288,2097152,262144,0,48408)|0}function baX(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5876732+(b*112|0)>>2];c[a+104>>2]=c[5876736+(b*112|0)>>2];c[a+108>>2]=c[5876740+(b*112|0)>>2];d=0;return d|0}function baY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=5876632+(b*112|0);e=0;return e|0}function baZ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2608724+(b*112|0)>>2];c[a+104>>2]=c[2608728+(b*112|0)>>2];c[a+108>>2]=c[2608732+(b*112|0)>>2];d=0;return d|0}function ba_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=2608624+(b*112|0);e=0;return e|0}function ba$(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1232448+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function ba0(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>50){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3764824+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function ba1(){c[2438882]=48;c[2438880]=128;return ba5(524288,2097152,0,0,10176)|0}function ba2(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4397836+(b*112|0)>>2];c[a+104>>2]=c[4397840+(b*112|0)>>2];c[a+108>>2]=c[4397844+(b*112|0)>>2];d=0;return d|0}function ba3(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=4397736+(b*112|0);e=0;return e|0}function ba4(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>43){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4993984+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function ba5(e,f,g,j,k){e=e|0;f=f|0;g=g|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0;l=i;i=i+720|0;m=l|0;n=l+112|0;o=l+120|0;p=l+232|0;q=l+240|0;r=l+352|0;s=l+360|0;t=l+472|0;u=l+480|0;v=l+592|0;w=l+600|0;x=l+712|0;y=c[642608+(c[2436]<<2)>>2]|0;z=c[y+128>>2]|0;if((c[y+52>>2]&4|0)==0){c[2113068]=z;A=c[y+132>>2]|0;c[2113070]=A;c[2443814]=z;c[2440436]=A;B=z;C=A}else{c[2113070]=z;A=c[y+132>>2]|0;c[2113068]=A;c[2440436]=z;c[2443814]=A;B=A;C=z}z=ag(B<<1,C)|0;C=gGq(z)|0;c[2112926]=C;if((C|0)!=0){gGz(C|0,0,z|0)}c[2415114]=0;c[2386302]=0;c[2386018]=2097152;c[3530958]=2162688;c[3530724]=6356992;c[2386702]=10551296;c[2439410]=12124160;z=ag(c[2113070]|0,c[2113068]|0)|0;C=z+12124160|0;c[2414822]=C;c[2386536]=C;c[2386278]=z+12126208;c[2386308]=z+12191744;c[2387292]=z+12208128;c[2386170]=z+12210176;c[3528380]=z+12214272;c[2430466]=z+12214273;C=z+12214289|0;c[2411884]=C;c[3530204]=C;C=z+12216337|0;c[2414436]=C;z=C;C=0;while(1){if((C|0)>=1024){break}D=9638528+(C<<2)|0;if((c[D>>2]|0)==0){E=57399;break}else{C=C+1|0}}do{if((E|0)==57399){C=gGq(z)|0;c[D>>2]=C;if((C|0)==0){break}gGz(C|0,0,z|0);c[2415114]=C;gGz(C|0,0,z|0);c[2386302]=C;c[2386018]=C+2097152;c[3530958]=C+2162688;c[3530724]=C+6356992;c[2386702]=C+10551296;c[2439410]=C+12124160;B=ag(c[2113070]|0,c[2113068]|0)|0;A=C+(B+12124160)|0;c[2414822]=A;c[2386536]=A;c[2386278]=C+(B+12126208);c[2386308]=C+(B+12191744);c[2387292]=C+(B+12208128);c[2386170]=C+(B+12210176);c[3528380]=C+(B+12214272);c[2430466]=C+(B+12214273);A=C+(B+12214289)|0;c[2411884]=A;c[3530204]=A;c[2414436]=C+(B+12216337);if((R6(C+1|0,0,2)|0)!=0){F=1;i=l;return F|0}if((R6(c[2386302]|0,1,2)|0)!=0){F=1;i=l;return F|0}if((e|0)==262144){C=c[2386302]|0;B=C+524272|0;A=C+262128|0;gGC(B|0,A|0,16)|0}A=c[2386018]|0;if((c[3542200]|0)==0){F=1;i=l;return F|0}B=w+108|0;c[B>>2]=0;C=w+100|0;c[C>>2]=0;y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[y&16383](w,2)|0;do{if((c[B>>2]|0)!=0){y=c[C>>2]|0;c[x>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](x,2,0)|0;if((y|0)<1){F=1;i=l;return F|0}if((gzL(A,0,2)|0)==0){break}else{F=1}i=l;return F|0}}while(0);A=c[3530724]|0;if((c[3542200]|0)==0){F=1;i=l;return F|0}C=u+108|0;c[C>>2]=0;B=u+100|0;c[B>>2]=0;y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[y&16383](u,3)|0;do{if((c[C>>2]|0)!=0){y=c[B>>2]|0;c[v>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](v,3,0)|0;if((y|0)<1){F=1;i=l;return F|0}if((gzL(A,0,3)|0)==0){break}else{F=1}i=l;return F|0}}while(0);A=(c[3530724]|0)+524288|0;if((c[3542200]|0)==0){F=1;i=l;return F|0}B=s+108|0;c[B>>2]=0;C=s+100|0;c[C>>2]=0;y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[y&16383](s,4)|0;do{if((c[B>>2]|0)!=0){y=c[C>>2]|0;c[t>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](t,4,0)|0;if((y|0)<1){F=1;i=l;return F|0}if((gzL(A,0,4)|0)==0){break}else{F=1}i=l;return F|0}}while(0);A=(c[3530724]|0)+1048576|0;if((c[3542200]|0)==0){F=1;i=l;return F|0}C=q+108|0;c[C>>2]=0;B=q+100|0;c[B>>2]=0;y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[y&16383](q,5)|0;do{if((c[C>>2]|0)!=0){y=c[B>>2]|0;c[r>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](r,5,0)|0;if((y|0)<1){F=1;i=l;return F|0}if((gzL(A,0,5)|0)==0){break}else{F=1}i=l;return F|0}}while(0);A=(c[3530724]|0)+1572864|0;if((c[3542200]|0)==0){F=1;i=l;return F|0}B=o+108|0;c[B>>2]=0;C=o+100|0;c[C>>2]=0;y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[y&16383](o,6)|0;do{if((c[B>>2]|0)!=0){y=c[C>>2]|0;c[p>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](p,6,0)|0;if((y|0)<1){F=1;i=l;return F|0}if((gzL(A,0,6)|0)==0){break}else{F=1}i=l;return F|0}}while(0);do{if((g|0)!=0){A=c[2386702]|0;if((c[3542200]|0)==0){F=1;i=l;return F|0}C=m+108|0;c[C>>2]=0;B=m+100|0;c[B>>2]=0;y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[y&16383](m,7)|0;do{if((c[C>>2]|0)!=0){y=c[B>>2]|0;c[n>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](n,7,0)|0;if((y|0)<1){F=1;i=l;return F|0}if((gzL(A,0,7)|0)==0){break}else{F=1}i=l;return F|0}}while(0);if((g|0)>=262144){break}A=c[2386702]|0;B=A+131072|0;gGC(B|0,A|0,131072)|0}}while(0);do{if((j|0)==0){H=0}else{if((R6((c[2386302]|0)+1048577|0,8,2)|0)!=0){F=1;i=l;return F|0}if((R6((c[2386302]|0)+1048576|0,9,2)|0)==0){H=0;break}else{F=1}i=l;return F|0}}while(0);while(1){if((H|0)>=1024){break}I=9638528+(H<<2)|0;if((c[I>>2]|0)==0){E=57437;break}else{H=H+1|0}}L74114:do{if((E|0)==57437){A=gGq(2097152)|0;c[I>>2]=A;if((A|0)==0){break}gGz(A|0,0,2097152);B=c[3530724]|0;gGC(A|0,B|0,2097152)|0;C=c[3530958]|0;y=0;while(1){G=y<<6;gGz(C+G|0,0,64);J=0;do{K=1<<3-J;L=(c[601464+(J<<2)>>2]|0)+G|0;M=0;do{N=L+(c[609008+(M<<2)>>2]|0)|0;O=(M<<3)+G|0;P=0;do{Q=N+(c[597864+(P<<2)>>2]|0)|0;if(((d[A+((Q|0)/8|0)|0]|0)&128>>>((Q&7)>>>0)|0)!=0){Q=C+(O+P)|0;a[Q]=(d[Q]|0|K)&255}P=P+1|0;}while((P|0)<8);M=M+1|0;}while((M|0)<8);J=J+1|0;}while((J|0)<4);J=y+1|0;if((J|0)<65536){y=J}else{R=0;break}}while(1){y=R<<8;gGz(B+y|0,0,256);C=0;do{J=1<<3-C;G=(c[601464+(C<<2)>>2]|0)+y|0;M=0;do{K=G+(c[609008+(M<<2)>>2]|0)|0;L=(M<<4)+y|0;P=0;do{O=K+(c[597864+(P<<2)>>2]|0)|0;if(((d[A+((O|0)/8|0)|0]|0)&128>>>((O&7)>>>0)|0)!=0){O=B+(L+P)|0;a[O]=(d[O]|0|J)&255}P=P+1|0;}while((P|0)<16);M=M+1|0;}while((M|0)<16);C=C+1|0;}while((C|0)<4);C=R+1|0;if((C|0)<16384){R=C}else{S=0;break}}while(1){if((S|0)>=1024){break L74114}T=9638528+(S<<2)|0;if((c[T>>2]|0)==(A|0)){break}else{S=S+1|0}}gGr(A);c[T>>2]=0}}while(0);fyz(0,65544,16e6);c[1836234]=0;B=c[2439374]|0;c[3531864]=B;gf[c[B>>2]&2047](0);do{if((k|0)!=0){B=c[(c[3531864]|0)+20>>2]|0;if((B|0)==0){break}gf[B&2047](k)}}while(0);B=c[2386302]|0;C=e+2046>>11;y=c[3531864]|0;if((C|0)>0){M=0;while(1){c[y+44+(M<<2)>>2]=B;J=M+1|0;if((J|0)<(C|0)){M=J}else{U=0;break}}while(1){c[y+4140+(U<<2)>>2]=B;c[y+6188+(U<<2)>>2]=B;M=U+1|0;if((M|0)<(C|0)){U=M}else{V=y;break}}}else{V=y}C=B+524288|0;M=256;while(1){c[V+44+(M<<2)>>2]=C;J=M+1|0;if((J|0)<288){M=J}else{W=256;break}}do{c[V+4140+(W<<2)>>2]=C;c[V+6188+(W<<2)>>2]=C;W=W+1|0;}while((W|0)<288);C=(c[2386308]|0)-655360|0;c[V+1324>>2]=C;c[V+1328>>2]=C;c[V+1332>>2]=C;c[V+1336>>2]=C;c[V+1340>>2]=C;c[V+1344>>2]=C;c[V+1348>>2]=C;c[V+1352>>2]=C;c[V+3372>>2]=C;c[V+3376>>2]=C;c[V+3380>>2]=C;c[V+3384>>2]=C;c[V+3388>>2]=C;c[V+3392>>2]=C;c[V+3396>>2]=C;c[V+3400>>2]=C;c[V+5420>>2]=C;c[V+7468>>2]=C;c[V+5424>>2]=C;c[V+7472>>2]=C;c[V+5428>>2]=C;c[V+7476>>2]=C;c[V+5432>>2]=C;c[V+7480>>2]=C;c[V+5436>>2]=C;c[V+7484>>2]=C;c[V+5440>>2]=C;c[V+7488>>2]=C;c[V+5444>>2]=C;c[V+7492>>2]=C;c[V+5448>>2]=C;c[V+7496>>2]=C;C=(c[2386278]|0)-851968|0;M=416;while(1){c[V+44+(M<<2)>>2]=C;y=M+1|0;if((y|0)<448){M=y}else{X=416;break}}while(1){c[V+2092+(X<<2)>>2]=C;M=X+1|0;if((M|0)<448){X=M}else{Y=416;break}}do{c[V+4140+(Y<<2)>>2]=C;c[V+6188+(Y<<2)>>2]=C;Y=Y+1|0;}while((Y|0)<448);C=(c[2387292]|0)-917504|0;c[V+1836>>2]=C;c[V+5932>>2]=C;c[V+7980>>2]=C;C=B-524288|0;c[V+2088>>2]=C;c[V+6184>>2]=C;c[V+8232>>2]=C;c[V+8236>>2]=3526;c[V+8240>>2]=3212;c[V+8244>>2]=2614;c[V+8248>>2]=1082;c[1836234]=-1;gu[c[V+4>>2]&16383]();c[3531864]=0;fwR(0);C=c[2439330]|0;M=(C|0)==0;if(!M){y=C;gGC(9706056,y|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];y=c[3528484]|0;c[2076596]=y;J=c[2417276]|0;c[3541536]=J;c[1836236]=0;G=c[2386018]|0;P=0;L=0;while(1){c[C+76+(L<<2)>>2]=G+(L<<8);K=P+1&65535;if((K&65535)>239){Z=0;_=0;break}else{P=K;L=K&65535}}while(1){L=G+(_<<8)|0;c[C+76+(_+512<<2)>>2]=L;c[C+76+(_+768<<2)>>2]=L;L=Z+1&65535;if((L&65535)>239){break}else{Z=L;_=L&65535}}G=c[2386170]|0;c[C+1036>>2]=G;c[C+1040>>2]=G+256;c[C+1044>>2]=G+512;c[C+1048>>2]=G+768;c[C+1052>>2]=G+1024;c[C+1056>>2]=G+1280;c[C+1060>>2]=G+1536;c[C+1064>>2]=G+1792;c[C+1068>>2]=G+2048;c[C+1072>>2]=G+2304;c[C+1076>>2]=G+2560;c[C+1080>>2]=G+2816;c[C+1084>>2]=G+3072;c[C+1088>>2]=G+3328;c[C+1092>>2]=G+3584;c[C+1096>>2]=G+3840;L=240;P=240;while(1){c[C+76+(P+256<<2)>>2]=G+((P<<8)-61440);B=L+1&65535;if((B&65535)>255){$=240;aa=240;break}else{L=B;P=B&65535}}while(1){P=G+((aa<<8)-61440)|0;c[C+76+(aa+512<<2)>>2]=P;c[C+76+(aa+768<<2)>>2]=P;P=$+1&65535;if((P&65535)>255){break}else{$=P;aa=P&65535}}c[C+4176>>2]=190;c[C+4172>>2]=2132;if(!M){G=C;gGC(G|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=y;c[2417276]=J;c[1836236]=-1;G=a[9680]|0;P=G?32e3:0;if(G){if(a[9624]|0){G=P*3|0;L=55930;while(1){if((L|0)>(G|0)){L=L>>1}else{ab=1222;ac=L;break}}}else{ab=2462;ac=P}c[2429380]=ac;c[3542124]=ab;mw(3579545,ac);L=gGq(262144)|0;c[2406684]=L;gGz(L|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(3579545,11025)}c[(c[3531464]|0)+44344>>2]=202;h[745421]=.15;c[2436794]=3;h[745420]=.15;c[2436792]=3;c[2405758]=1;gGz(9542544,0,32);c[2385641]=1;h[1192819]=1.0;c[2385642]=3;c[2385643]=654;L=0;do{G=L*257|0;b[9732544+(L<<1)>>1]=((G|0)/2|0)&65535;b[9753784+(L<<1)>>1]=G+32768&65535;L=L+1|0;}while((L|0)<256);c[3528842]=1;h[1192819]=.1;c[2385642]=3;L=(f<<1)-1|0;c[2385708]=(L|0)/64|0;c[2385706]=(L|0)/256|0;L=c[2414822]|0;gGz(L|0,0,(c[2411884]|0)-L|0);c[1836234]=0;L=c[2439374]|0;c[3531864]=L;gf[c[L>>2]&2047](0);gD[c[(c[3531864]|0)+8>>2]&8191]()|0;c[1836234]=-1;gu[c[(c[3531864]|0)+4>>2]&16383]();c[3531864]=0;L=c[2439330]|0;P=(L|0)==0;if(!P){G=L;gGC(9706056,G|0,76)|0}G=c[2438118]|0;c[2433530]=G;J=c[3528484]|0;c[2076596]=J;y=c[2417276]|0;c[3541536]=y;c[1836236]=0;gGz(9706056,0,76);a[9542392]=-1;a[14125144]=-1;a[9706117]=0;if(!P){P=L;gGC(P|0,9706056,76)|0}c[2438118]=G;c[3528484]=J;c[2417276]=y;c[1836236]=-1;mx(0);y=c[2405758]|0;if((y|0)>0){J=0;do{c[9542560+(J<<5)>>2]=0;b[9542544+(J<<5)>>1]=0;J=J+1|0;}while((J|0)<(y|0))}c[2438062]=0;F=0;i=l;return F|0}}while(0);c[2415114]=0;F=1;i=l;return F|0}function ba6(b){b=b|0;var c=0,d=0;c=a[9542392]|0;d=(b|0)==0?c|16:c&-17;a[9542392]=d;a[14125144]=d;c=d<<24>>24!=-1|0;if((c|0)==0){a[9706117]=0;return}else if((c|0)==1){a[9706117]=1;return}else{return}}function ba7(){return~~((a[9688]|0?534.0:0.0)*(+((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)/(3579545.0/(+(c[2424]|0)/100.0))))|0}function ba8(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;g=c[2430466]|0;h=d[g+((f<<1)+10)|0]|0;if((h&16|0)!=0){return}i=h&4;j=(i<<4)+64|0;k=(f|0)!=0;l=k?255:0;m=c[2386278]|0;n=m+(((i>>>2^3)&h)<<14)|0;i=f<<2;o=((d[g+(i|1)|0]|0)<<8|(d[g+i|0]|0))+(c[2438880]|0)|0;p=f<<10;f=m+(p+61440)|0;q=m+(p+63488)|0;p=c[2113070]|0;if((p|0)<=0){return}m=(j<<1&256)+(k?65534:2)+(c[2438882]|0)+((d[g+(i|3)|0]|0)<<8|(d[g+(i|2)|0]|0))|0;i=m&65535;g=(h&64|0)==0;k=(j<<3)-1|0;r=(o&65535)+128|0;s=c[2113068]|0;t=c[2112926]|0;u=c[2439410]|0;v=c[2385708]|0;w=c[3530958]|0;x=s+8|0;if((h&32|0)==0){h=0;do{y=ag(h,s)|0;if(g){z=h+o|0}else{z=h+r+(e[q+(h<<1)>>1]|0)|0}A=z<<3&56;if((s+8|0)>0){B=ag(z>>>3&63,j)|0;C=A^56;D=0;do{E=((D+i&k|0)/8|0|B)<<1;F=e[n+((E|1)<<1)>>1]|0;G=F<<4&240;H=(F&64|0)==0?0:7;I=((F&128|0)==0?A:C)|((e[n+(E<<1)>>1]|0)&v)<<6;E=1<<((F&48|0)==0)&255;F=D-(D+m&7)|0;J=0;while(1){do{if((F|0)>-1&(F|0)<(s|0)){K=d[w+((J^H)+I)|0]|0;if((K|0)==(l|0)){break}L=F+y|0;b[t+(L<<1)>>1]=(K|G)&65535;a[u+L|0]=E}}while(0);L=J+1|0;if((L|0)>=8){break}F=F+1|0;J=L}D=D+8|0;}while((D|0)<(x|0))}h=h+1|0;}while((h|0)<(p|0));return}else{h=0;do{m=ag(h,s)|0;z=(e[f+(h<<1)>>1]|0)+i|0;if(g){M=h+o|0}else{M=h+r+(e[q+(h<<1)>>1]|0)|0}D=M<<3&56;if((s+8|0)>0){y=ag(M>>>3&63,j)|0;C=D^56;A=0;do{B=z+A|0;J=((B&k|0)/8|0|y)<<1;F=e[n+((J|1)<<1)>>1]|0;E=F<<4&240;G=(F&64|0)==0?0:7;I=((F&128|0)==0?D:C)|((e[n+(J<<1)>>1]|0)&v)<<6;J=1<<((F&48|0)==0)&255;F=A-(B&7)|0;B=0;while(1){do{if((F|0)>-1&(F|0)<(s|0)){H=d[w+((B^G)+I)|0]|0;if((H|0)==(l|0)){break}L=F+m|0;b[t+(L<<1)>>1]=(H|E)&65535;a[u+L|0]=J}}while(0);L=B+1|0;if((L|0)>=8){break}F=F+1|0;B=L}A=A+8|0;}while((A|0)<(x|0))}h=h+1|0;}while((h|0)<(p|0));return}}function ba9(b){b=b|0;var c=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if((b&31|0)!=24){c=0;return c|0}b=d[14116114]<<8|d[14116113]<<16|d[14116115];e=d[14116122]<<8|d[14116121]<<16|d[14116123];f=(a[14116116]|0)==-1?b+3|0:b;b=(a[14116124]|0)==-1?e+3|0:e;e=(d[14116118]|0)+1|0;g=(d[14116119]|0)+1|0;h=d[14116134]<<8|d[14116133]<<16|d[14116135];i=d[14116130]<<8|d[14116129]<<16|d[14116131];j=(d[14116126]|0)+1|0;k=(d[14116127]|0)+1|0;if((e+f|0)<(h-j|0)){c=1;return c|0}if((j+h|0)<(f-e|0)){c=1;return c|0}if((g+b|0)<(i-k|0)){c=1;return c|0}c=(k+i|0)<(b-g|0)|0;return c|0}function bba(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;e=i;i=i+112|0;f=e|0;g=e+8|0;h=e+16|0;j=e+24|0;k=e+32|0;l=e+40|0;m=e+48|0;n=e+56|0;o=e+64|0;p=e+72|0;q=e+80|0;r=e+88|0;s=e+96|0;t=e+104|0;u=b-1048576|0;if(u>>>0<32768){v=u>>>1;w=u>>>2&6144|v&2047;if((b&1|0)==0){if((c[3541230]|0)==0){x=a[(c[3529062]|0)+w|0]|0;i=e;return x|0}c[o>>2]=0;u=w>>>5;c[p>>2]=u;y=d[9730680]|0;c[q>>2]=y;z=y>>>2&3;if((c[2429638]|0)==0){gB[c[2437692]&127](0,((a[9718936+z|0]|a[9720736+z|0])&255)>>>2,p,q,o,o);A=c[p>>2]|0}else{o=y<<8|u;c[p>>2]=o;A=o}x=a[(c[3529060]|0)+((A<<5|v&31)&c[2438700])|0]|0;i=e;return x|0}else{if((c[3541230]|0)==0){x=a[(c[3529062]|0)+(w|8192)|0]|0;i=e;return x|0}c[r>>2]=0;A=w>>>5;c[s>>2]=A;w=d[9730680]|0;c[t>>2]=w;o=w>>>2&3;if((c[2429638]|0)==0){gB[c[2437692]&127](0,((a[9718936+o|0]|a[9720736+o|0])&255)>>>2,s,t,r,r);B=c[s>>2]|0}else{r=w<<8|A;c[s>>2]=r;B=r}x=a[(c[3529060]|0)+((B<<5|v&31)&c[2438700])|0]|0;i=e;return x|0}}v=b-1310720|0;if(v>>>0<8){if((v|0)==0){B=c[2384554]|0;c[2384554]=B+1;x=B&1;i=e;return x|0}if((c[3541238]|0)==0){x=0;i=e;return x|0}if((b-1310724|0)>>>0>=4){x=0;i=e;return x|0}B=d[9718033]|0;r=((d[9718032]|0)<<8)+(c[2433420]|0)+(B<<16&196608)|0;c[k>>2]=r>>>5&8191;s=(d[9718034]|0)<<6;c[l>>2]=s&192|B>>>2;c[m>>2]=0;c[n>>2]=s&128;gL[c[2437694]&255](k,l,m,n);x=a[(c[3529064]|0)+((c[k>>2]<<7|v&3|r<<2&124)&c[2438702])|0]|0;i=e;return x|0}r=b-1311744|0;if(r>>>0<1024){if((c[3541238]|0)!=0){v=r>>>2&255;c[2433420]=v;k=d[9718033]|0;c[f>>2]=((d[9718032]|0)<<8|v|k<<16)>>>5&8191;v=(d[9718034]|0)<<6;c[g>>2]=v&192|k>>>2;c[h>>2]=0;c[j>>2]=v&128;gL[c[2437694]&255](f,g,h,j)}x=a[(c[3529066]|0)+r|0]|0;i=e;return x|0}switch(b|0){case 655377:{x=a[9658096]|0;i=e;return x|0};case 655385:{x=a[9658098]|0;i=e;return x|0};case 655365:{x=~a[9625890];i=e;return x|0};case 655361:{x=~a[9625888];i=e;return x|0};case 655379:{x=a[9658097]|0;i=e;return x|0};case 655363:{x=~a[9625889];i=e;return x|0};case 655367:{x=~a[9625891];i=e;return x|0};case 655381:{x=~a[9625892];i=e;return x|0};default:{x=0;i=e;return x|0}}return 0}function bbb(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=d-1048576|0;if(f>>>0<32768){g=f>>>2&6144;h=g|f>>>1&2047;if((d&1|0)!=0){f=h|8192;a[(c[3529062]|0)+f|0]=e;if(!((g|0)==6144&(f|0)==15872)){return}a[9730680]=e;return}a[(c[3529062]|0)+h|0]=e;if((g|0)!=6144){return}switch(h|0){case 7296:{a[9729904]=e;return};case 7552:{a[9720736]=e&15;a[9720737]=(e&255)>>>4;return};case 7936:{a[9720738]=e&15;a[9720739]=(e&255)>>>4;return};case 7424:{c[3541228]=e&4;return};case 7680:{a[9730680]=e;return};case 7808:{c[2432672]=(e&255)>>>1&3;return};default:{return}}}h=d-1310720|0;if(h>>>0<8){if((h|0)==0){h=e&255;c[3541236]=h&1;c[3541234]=h&4;c[3541232]=h&8;c[3541238]=h&32;return}h=d-1310722|0;if(h>>>0>=3){return}a[9718032+h|0]=e;return}h=d-1311744|0;if(h>>>0<1024){a[(c[3529066]|0)+h|0]=e;return}if((d|0)==655361){do{if((c[2384536]|0)==8){if((e&8)!=0){break}h=c[2439330]|0;g=(h|0)==0;if(!g){f=h;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;f=c[2438118]|0;c[2433530]=f;i=c[3528484]|0;c[2076596]=i;j=c[2417276]|0;c[3541536]=j;c[1836236]=0;a[9706117]=1;if(!g){g=h;gGC(g|0,9706056,76)|0}c[2438118]=f;c[3528484]=i;c[2417276]=j;c[1836236]=-1}}while(0);j=e&255;c[2384536]=j&8;a[14115360]=(e&255)>>>5&1;c[3541230]=j&128;return}else if((d|0)==655369){a[9758256]=e;return}else if((d|0)==786433){c[2442970]=(e&255)>>>2&3;return}else{return}}function bbc(a){a=a|0;return 0}function bbd(b,d){b=b|0;d=d|0;var e=0;e=b-1311744|0;if(e>>>0>=1024){return}if((b&1|0)==0){a[(c[3529066]|0)+e|0]=(d&65535)>>>8&255;return}else{a[(c[3529066]|0)+(b-1311743)|0]=d&255;return}}function bbe(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;e=i;i=i+112|0;f=e|0;g=e+8|0;h=e+16|0;j=e+24|0;k=e+32|0;l=e+40|0;m=e+48|0;n=e+56|0;o=e+64|0;p=e+72|0;q=e+80|0;r=e+88|0;s=e+96|0;t=e+104|0;u=b-1048576|0;if(u>>>0<32768){v=u>>>1;w=u>>>2&6144|v&2047;if((b&1|0)==0){if((c[3541230]|0)==0){x=a[(c[3529062]|0)+w|0]|0;i=e;return x|0}c[o>>2]=0;u=w>>>5;c[p>>2]=u;y=d[9730680]|0;c[q>>2]=y;z=y>>>2&3;if((c[2429638]|0)==0){gB[c[2437692]&127](0,((a[9718936+z|0]|a[9720736+z|0])&255)>>>2,p,q,o,o);A=c[p>>2]|0}else{o=y<<8|u;c[p>>2]=o;A=o}x=a[(c[3529060]|0)+((A<<5|v&31)&c[2438700])|0]|0;i=e;return x|0}else{if((c[3541230]|0)==0){x=a[(c[3529062]|0)+(w|8192)|0]|0;i=e;return x|0}c[r>>2]=0;A=w>>>5;c[s>>2]=A;w=d[9730680]|0;c[t>>2]=w;o=w>>>2&3;if((c[2429638]|0)==0){gB[c[2437692]&127](0,((a[9718936+o|0]|a[9720736+o|0])&255)>>>2,s,t,r,r);B=c[s>>2]|0}else{r=w<<8|A;c[s>>2]=r;B=r}x=a[(c[3529060]|0)+((B<<5|v&31)&c[2438700])|0]|0;i=e;return x|0}}v=b-1310720|0;if(v>>>0<8){if((v|0)==0){B=c[2384566]|0;c[2384566]=B+1;x=B&1;i=e;return x|0}if((c[3541238]|0)==0){x=0;i=e;return x|0}if((b-1310724|0)>>>0>=4){x=0;i=e;return x|0}B=d[9718033]|0;r=((d[9718032]|0)<<8)+(c[2433420]|0)+(B<<16&196608)|0;c[k>>2]=r>>>5&8191;s=(d[9718034]|0)<<6;c[l>>2]=s&192|B>>>2;c[m>>2]=0;c[n>>2]=s&128;gL[c[2437694]&255](k,l,m,n);x=a[(c[3529064]|0)+((c[k>>2]<<7|v&3|r<<2&124)&c[2438702])|0]|0;i=e;return x|0}r=b-1311744|0;if(r>>>0<1024){if((c[3541238]|0)!=0){v=r>>>2&255;c[2433420]=v;k=d[9718033]|0;c[f>>2]=((d[9718032]|0)<<8|v|k<<16)>>>5&8191;v=(d[9718034]|0)<<6;c[g>>2]=v&192|k>>>2;c[h>>2]=0;c[j>>2]=v&128;gL[c[2437694]&255](f,g,h,j)}x=a[(c[3529066]|0)+r|0]|0;i=e;return x|0}switch(b|0){case 655377:{x=a[9658096]|0;i=e;return x|0};case 655385:{x=a[9658098]|0;i=e;return x|0};case 655361:{x=~a[9625888];i=e;return x|0};case 655379:{x=a[9658097]|0;i=e;return x|0};case 655363:{x=~a[9625889];i=e;return x|0};case 655365:{x=~a[9625890];i=e;return x|0};default:{x=0;i=e;return x|0}}return 0}function bbf(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=d-1048576|0;if(f>>>0<32768){g=f>>>2&6144;h=g|f>>>1&2047;if((d&1|0)!=0){f=h|8192;a[(c[3529062]|0)+f|0]=e;if(!((g|0)==6144&(f|0)==15872)){return}a[9730680]=e;return}a[(c[3529062]|0)+h|0]=e;if((g|0)!=6144){return}switch(h|0){case 7552:{a[9720736]=e&15;a[9720737]=(e&255)>>>4;return};case 7424:{c[3541228]=e&4;return};case 7936:{a[9720738]=e&15;a[9720739]=(e&255)>>>4;return};case 7808:{c[2432672]=(e&255)>>>1&3;return};case 7680:{a[9730680]=e;return};case 7296:{a[9729904]=e;return};default:{return}}}h=d-1310720|0;if(h>>>0<8){if((h|0)==0){h=e&255;c[3541236]=h&1;c[3541234]=h&4;c[3541232]=h&8;c[3541238]=h&32;return}h=d-1310722|0;if(h>>>0>=3){return}a[9718032+h|0]=e;return}h=d-1311744|0;if(h>>>0<1024){a[(c[3529066]|0)+h|0]=e;return}if((d|0)==655361){do{if((c[2384556]|0)==8){if((e&8)!=0){break}h=c[2439330]|0;g=(h|0)==0;if(!g){f=h;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;f=c[2438118]|0;c[2433530]=f;i=c[3528484]|0;c[2076596]=i;j=c[2417276]|0;c[3541536]=j;c[1836236]=0;a[9706117]=1;if(!g){g=h;gGC(g|0,9706056,76)|0}c[2438118]=f;c[3528484]=i;c[2417276]=j;c[1836236]=-1}}while(0);j=e&255;c[2384556]=j&8;a[14115360]=(e&255)>>>5&1;c[3541230]=j&128;return}else if((d|0)==655369){a[9758256]=e;return}else{return}}function bbg(a){a=a|0;return 0}function bbh(b,d){b=b|0;d=d|0;var e=0;e=b-1311744|0;if(e>>>0>=1024){return}if((b&1|0)==0){a[(c[3529066]|0)+e|0]=(d&65535)>>>8&255;return}else{a[(c[3529066]|0)+(b-1311743)|0]=d&255;return}}function bbi(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;e=i;i=i+112|0;f=e|0;g=e+8|0;h=e+16|0;j=e+24|0;k=e+32|0;l=e+40|0;m=e+48|0;n=e+56|0;o=e+64|0;p=e+72|0;q=e+80|0;r=e+88|0;s=e+96|0;t=e+104|0;u=b-1048576|0;if(u>>>0<32768){v=u>>>1;w=u>>>2&6144|v&2047;if((b&1|0)==0){if((c[3541230]|0)==0){x=a[(c[3529062]|0)+w|0]|0;i=e;return x|0}c[o>>2]=0;u=w>>>5;c[p>>2]=u;y=d[9730680]|0;c[q>>2]=y;z=y>>>2&3;if((c[2429638]|0)==0){gB[c[2437692]&127](0,((a[9718936+z|0]|a[9720736+z|0])&255)>>>2,p,q,o,o);A=c[p>>2]|0}else{o=y<<8|u;c[p>>2]=o;A=o}x=a[(c[3529060]|0)+((A<<5|v&31)&c[2438700])|0]|0;i=e;return x|0}else{if((c[3541230]|0)==0){x=a[(c[3529062]|0)+(w|8192)|0]|0;i=e;return x|0}c[r>>2]=0;A=w>>>5;c[s>>2]=A;w=d[9730680]|0;c[t>>2]=w;o=w>>>2&3;if((c[2429638]|0)==0){gB[c[2437692]&127](0,((a[9718936+o|0]|a[9720736+o|0])&255)>>>2,s,t,r,r);B=c[s>>2]|0}else{r=w<<8|A;c[s>>2]=r;B=r}x=a[(c[3529060]|0)+((B<<5|v&31)&c[2438700])|0]|0;i=e;return x|0}}v=b-1310720|0;if(v>>>0<8){if((v|0)==0){B=c[2384510]|0;c[2384510]=B+1;x=B&1;i=e;return x|0}if((c[3541238]|0)==0){x=0;i=e;return x|0}if((b-1310724|0)>>>0>=4){x=0;i=e;return x|0}B=d[9718033]|0;r=((d[9718032]|0)<<8)+(c[2433420]|0)+(B<<16&196608)|0;c[k>>2]=r>>>5&8191;s=(d[9718034]|0)<<6;c[l>>2]=s&192|B>>>2;c[m>>2]=0;c[n>>2]=s&128;gL[c[2437694]&255](k,l,m,n);x=a[(c[3529064]|0)+((c[k>>2]<<7|v&3|r<<2&124)&c[2438702])|0]|0;i=e;return x|0}r=b-1311744|0;if(r>>>0<1024){if((c[3541238]|0)!=0){v=r>>>2&255;c[2433420]=v;k=d[9718033]|0;c[f>>2]=((d[9718032]|0)<<8|v|k<<16)>>>5&8191;v=(d[9718034]|0)<<6;c[g>>2]=v&192|k>>>2;c[h>>2]=0;c[j>>2]=v&128;gL[c[2437694]&255](f,g,h,j)}x=a[(c[3529066]|0)+r|0]|0;i=e;return x|0}r=b-720896|0;if(r>>>0<1024){x=a[(c[2406292]|0)+((c[2443506]<<10)+r)|0]|0;i=e;return x|0}if((b|0)==655377){x=a[9658097]|0;i=e;return x|0}else if((b|0)==786434){x=c[(c[3531464]|0)+4240>>2]&255;i=e;return x|0}else if((b|0)==655363){x=~a[9625889];i=e;return x|0}else if((b|0)==655361){x=~a[9625888];i=e;return x|0}else if((b|0)==655379){x=a[9658096]|0;i=e;return x|0}else if((b|0)==655385){x=a[9658098]|0;i=e;return x|0}else if((b|0)==786432){x=-1;i=e;return x|0}else if((b|0)==655365){x=~a[9625890];i=e;return x|0}else{x=0;i=e;return x|0}return 0}function bbj(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;e=b-1048576|0;if(e>>>0<32768){f=e>>>2&6144;g=f|e>>>1&2047;if((b&1|0)!=0){e=g|8192;a[(c[3529062]|0)+e|0]=d;if(!((f|0)==6144&(e|0)==15872)){return}a[9730680]=d;return}a[(c[3529062]|0)+g|0]=d;if((f|0)!=6144){return}switch(g|0){case 7296:{a[9729904]=d;return};case 7424:{c[3541228]=d&4;return};case 7680:{a[9730680]=d;return};case 7808:{c[2432672]=(d&255)>>>1&3;return};case 7552:{a[9720736]=d&15;a[9720737]=(d&255)>>>4;return};case 7936:{a[9720738]=d&15;a[9720739]=(d&255)>>>4;return};default:{return}}}g=b-1310720|0;if(g>>>0<8){if((g|0)==0){g=d&255;c[3541236]=g&1;c[3541234]=g&4;c[3541232]=g&8;c[3541238]=g&32;return}g=b-1310722|0;if(g>>>0>=3){return}a[9718032+g|0]=d;return}g=b-1311744|0;if(g>>>0<1024){a[(c[3529066]|0)+g|0]=d;return}g=b-720896|0;if(g>>>0<1024){a[(c[2406292]|0)+((c[2443506]<<10)+g)|0]=d;return}if((b|0)==721920){c[2443506]=d&255;return}else if((b|0)==655361){a[14115360]=(d&255)>>>5&1;c[3541230]=d&128;return}else if((b|0)==786432){c[2113304]=d&255;return}else if((b|0)==786434){b=c[2113304]|0;a[14168504+b|0]=d;mv(0,b,d&255);return}else{return}}function bbk(a){a=a|0;var b=0,d=0;if((a-720896|0)>>>0>=1024){b=0;return b|0}d=((gj[c[(c[2112932]|0)+196608>>2]&4095](a)|0)&255)<<8;b=(gj[c[(c[2112932]|0)+196608>>2]&4095](a+1|0)|0)&255|d;return b|0}function bbl(b,d){b=b|0;d=d|0;var e=0;e=b-1311744|0;if(e>>>0>=1024){if((b-720896|0)>>>0>=1024){return}gg[c[(c[2112932]|0)+196648>>2]&4095](b,(d&65535)>>>8&255);gg[c[(c[2112932]|0)+196648>>2]&4095](b+1|0,d&255);return}if((b&1|0)==0){a[(c[3529066]|0)+e|0]=(d&65535)>>>8&255;return}else{a[(c[3529066]|0)+(b-1311743)|0]=d&255;return}}function bbm(b){b=b|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=i;i=i+48|0;g=f|0;h=f+8|0;j=f+16|0;k=f+24|0;l=f+32|0;m=f+40|0;n=b-1572864|0;if(n>>>0<16384){o=n>>>1;if((b&1|0)==0){if(n>>>0>49151){p=0;i=f;return p|0}if((c[3541230]|0)==0){p=a[(c[3529062]|0)+o|0]|0;i=f;return p|0}c[g>>2]=0;q=n>>>6&255;c[h>>2]=q;n=d[9730680]|0;c[j>>2]=n;r=n>>>2&3;if((c[2429638]|0)==0){gB[c[2437692]&127](0,((a[9718936+r|0]|a[9720736+r|0])&255)>>>2,h,j,g,g);s=c[h>>2]|0}else{g=n<<8|q;c[h>>2]=g;s=g}p=a[(c[3529060]|0)+((s<<5|o&31)&c[2438700])|0]|0;i=f;return p|0}else{s=o+8192|0;if(s>>>0>24575){p=0;i=f;return p|0}if((c[3541230]|0)==0){p=a[(c[3529062]|0)+s|0]|0;i=f;return p|0}c[k>>2]=0;o=s>>>5&255;c[l>>2]=o;g=d[9730680]|0;c[m>>2]=g;h=g>>>2&3;if((c[2429638]|0)==0){gB[c[2437692]&127](0,((a[9718936+h|0]|a[9720736+h|0])&255)>>>2,l,m,k,k);t=c[l>>2]|0}else{k=g<<8|o;c[l>>2]=k;t=k}p=a[(c[3529060]|0)+((t<<5|s&31)&c[2438700])|0]|0;i=f;return p|0}}s=b-3145728|0;if(s>>>0<16384){if((s&98|0)==0){p=(e[(c[3529054]|0)+((s>>>2&7|s>>>4&1016)<<1)>>1]|0)>>>((b<<3&8^8)>>>0)&255;i=f;return p|0}else{p=a[(c[2443436]|0)+(s^1)|0]|0;i=f;return p|0}}s=b-5242880|0;if(s>>>0<64){if((b&1|0)==0){p=0;i=f;return p|0}p=ba9(s>>>1)|0;i=f;return p|0}s=b-6815744|0;if(s>>>0<32){t=s>>>1;if((b&1|0)!=0){if((a[14108509]&16)==0){p=0;i=f;return p|0}if((t&12|0)!=12){p=0;i=f;return p|0}p=a[(c[3529056]|0)+((c[3527134]<<19|t&2|(d[14108515]|0)<<18&1835008|(d[14108512]|0)<<10|(d[14108513]|0)<<2)&c[3527124])|0]|0;i=f;return p|0}s=t&2147483646;do{if((a[14108509]&16)!=0){if((t&12|0)!=12){break}p=a[(c[3529056]|0)+((t&2|c[3527134]<<19|(d[14108515]|0)<<18&1835008|(d[14108512]|0)<<10|(d[14108513]|0)<<2|1)&c[3527124])|0]|0;i=f;return p|0}}while(0);if((s|0)!=6){p=0;i=f;return p|0}s=c[3529058]|0;t=c[3529054]|0;gGC(s|0,t|0,2048)|0;p=0;i=f;return p|0}if((b|0)==7340033){p=~a[9625889];i=f;return p|0}else if((b|0)==7340037){t=~a[9625888];s=c[2437706]|0;if((s|0)==0){u=t}else{c[2437706]=s-1;u=t&-9}t=c[2384512]^64;c[2384512]=t;p=(t^u&255)&255;i=f;return p|0}else if((b|0)==7865857|(b|0)==7865859){u=(b-7865857|0)>>>1;t=u+2|0;c[2426862]=9674384;if((u|0)==39){p=(c[2418664]<<1|c[2418653]|c[2418675]<<2|c[2418686]<<3)&255;i=f;return p|0}else if((u|0)==44){v=57953}do{if((v|0)==57953){if((c[2418596]&1|0)==0){break}u=c[2418655]|0;s=(u>>>16)+(c[2418650]|0)+(c[2418651]<<16)|0;c[2418655]=u+65536;if(s>>>0>(c[2418646]|0)>>>0){p=0;i=f;return p|0}p=a[(c[2418645]|0)+s|0]|0;i=f;return p|0}}while(0);p=c[9674388+(t<<2)>>2]&255;i=f;return p|0}else if((b|0)==7340039){if((c[2406632]|0)!=0){p=((c[2432962]|0)>>>((c[(c[2420380]|0)+4>>2]|0)>>>0)|254)&255;i=f;return p|0}t=c[2443744]|0;if((t|0)<=0){p=-1;i=f;return p|0}c[2443744]=t-1;p=-2;i=f;return p|0}else if((b|0)==7340035){p=~a[9625890];i=f;return p|0}else{p=0;i=f;return p|0}return 0}function bbn(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=d-1572864|0;if(f>>>0<16384){g=f>>>1;if((d&1|0)!=0){h=g+8192|0;if(h>>>0>24575){return}a[(c[3529062]|0)+h|0]=e;if(h>>>0>16383){c[2429638]=1}if(!((h&6144)>>>0>6143&(g|0)==7680)){return}a[9730680]=e;return}if(f>>>0>49151){return}a[(c[3529062]|0)+g|0]=e;if(f>>>0>32767){c[2429638]=1}if((g&6144)>>>0<=6143){return}if((g|0)==7424){c[3541228]=e&4;return}else if((g|0)==7936){a[9720738]=e&15;a[9720739]=(e&255)>>>4;return}else if((g|0)==7552){a[9720736]=e&15;a[9720737]=(e&255)>>>4;return}else if((g|0)==7296){a[9729904]=e;return}else if((g|0)==7680|(g|0)==15872){a[9730680]=e;return}else if((g|0)==7808){c[2432672]=(e&255)>>>1&3;return}else{return}}g=d-3145728|0;if(g>>>0<16384){a[(c[2443436]|0)+(g^1)|0]=e;if((g&98|0)!=0){return}f=(c[3529054]|0)+((g>>>2&7|g>>>4&1016)<<1)|0;g=b[f>>1]|0;if((d&1|0)==0){i=g&255|(e&255)<<8}else{i=g&-256|e&255}b[f>>1]=i;return}i=d-5242880|0;if(i>>>0<64){if((d&1|0)==0){return}a[14116112+(i>>>1&31)|0]=e;return}i=d-6815744|0;if(i>>>0<32){f=i>>>1;if((d&1|0)!=0){a[14108504+(f|1)|0]=e;return}i=f&2147483646;a[14108504+i|0]=e;if((i|0)!=6){return}i=c[3529058]|0;f=c[3529054]|0;gGC(i|0,f|0,2048)|0;return}f=d-7866112|0;if(f>>>0<32){i=e&255;g=i&63;h=f>>>1&15;a[14116144+h|0]=g&255;if((h|0)==10){c[2437685]=i<<4&112;c[2437686]=g>>>3<<4;return}else if((h|0)==9){c[2437682]=i<<5&96;c[2437683]=i>>>2<<5&96;c[2437684]=g>>>4<<5;return}else{return}}if((d|0)==7340545){g=e&255;c[2415256]=g&1;i=g>>>1&1;c[3528406]=i^1;if((i|0)==0){c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2]}Tr(g>>>2&1);return}else if((d|0)==7340801){g=e&255;c[3541230]=g&8;c[2429778]=g>>>7;return}else if((d|0)==7865857){c[2426862]=9674384;c[2418597]=e&255;return}else if((d|0)==7865861){d=c[2439330]|0;e=(d|0)==0;if(!e){g=d;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;g=c[2438118]|0;c[2433530]=g;i=c[3528484]|0;c[2076596]=i;h=c[2417276]|0;c[3541536]=h;c[1836236]=0;a[14125144]=-1;a[9706117]=1;if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=g;c[3528484]=i;c[2417276]=h;c[1836236]=-1;return}else{return}}function bbo(a){a=a|0;var d=0,e=0;d=a-3145728|0;if(d>>>0>=16384){e=0;return e|0}a=d>>>1;if((a&49|0)==0){e=b[(c[3529054]|0)+((d>>>2&7|d>>>4&1016)<<1)>>1]|0;return e|0}else{e=b[(c[2443436]|0)+(a<<1)>>1]|0;return e|0}return 0}function bbp(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=d-1572864|0;if(f>>>0>=16384){g=d-3145728|0;if(g>>>0<16384){h=g>>>1;b[(c[2443436]|0)+(h<<1)>>1]=e;if((h&49|0)!=0){return}b[(c[3529054]|0)+((g>>>2&7|g>>>4&1016)<<1)>>1]=e;return}g=d-5242880|0;if(g>>>0<64){a[14116112+(g>>>1&31)|0]=e&255;return}g=d-6815744|0;if(g>>>0>=32){return}d=g>>>1;g=d&2147483646;a[14108504+(d|1)|0]=e&255;a[14108504+g|0]=(e&65535)>>>8&255;if((g|0)!=6){return}g=c[3529058]|0;d=c[3529054]|0;gGC(g|0,d|0,2048)|0;return}d=f>>>1;g=d+8192|0;h=(e&65535)>>>8&255;do{if(g>>>0>24575){i=e&255;a[(c[3529062]|0)+d|0]=i;j=i}else{i=c[3529062]|0;a[i+g|0]=h;if(g>>>0>16383){c[2429638]=1}if((g&6144)>>>0>6143&(d|0)==7680){a[9730680]=h}k=e&255;if(f>>>0>49151){return}a[i+d|0]=k;if(f>>>0<=32767){j=k;break}c[2429638]=1;j=k}}while(0);if((d&6144)>>>0<=6143){return}if((d|0)==7552){a[9720736]=j&15;a[9720737]=(j&255)>>>4;return}else if((d|0)==7680|(d|0)==15872){a[9730680]=j;return}else if((d|0)==7296){a[9729904]=j;return}else if((d|0)==7936){a[9720738]=j&15;a[9720739]=(j&255)>>>4;return}else if((d|0)==7424){c[3541228]=e&4;return}else if((d|0)==7808){c[2432672]=(e&6)>>>1&3;return}else{return}}function bbq(a,d){a=a|0;d=d|0;b[(c[2388060]|0)+(a&30|18432)>>1]=d;return}function bbr(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;h=i;i=i+48|0;j=h|0;k=f&31;f=c[2388060]|0;a[f+(k^18433)|0]=g;if((k|0)!=24){i=h;return}k=e[f+18448>>1]|0;if((k&65280|0)!=33280){i=h;return}g=e[f+18432>>1]|0;l=(e[f+18434>>1]|0)<<16&16711680|g;m=b[f+18436>>1]|0;n=(e[f+18438>>1]|0)<<16;o=b[f+18440>>1]|0;p=(e[f+18442>>1]|0)<<16&16711680;f=c[2112932]|0;q=c[f+(l>>>10<<2)>>2]|0;if(q>>>0>9){r=g&1022;s=(d[q+(r|1)|0]|0)<<8|(d[q+r|0]|0);t=f}else{r=gj[c[f+196688+(q<<2)>>2]&4095](l&16777214)|0;s=r;t=c[2112932]|0}r=l+2|0;q=r&16777214;f=c[t+(q>>>10<<2)>>2]|0;if(f>>>0>9){g=r&1022;u=(d[f+(g|1)|0]|0)<<8|(d[f+g|0]|0);v=t}else{g=gj[c[t+196688+(f<<2)>>2]&4095](q)|0;u=g;v=c[2112932]|0}g=u&65535;u=l+4|0;q=u&16777214;f=c[v+(q>>>10<<2)>>2]|0;if(f>>>0>9){t=u&1022;w=(d[f+(t|1)|0]|0)<<8|(d[f+t|0]|0);x=v}else{t=gj[c[v+196688+(f<<2)>>2]&4095](q)|0;w=t;x=c[2112932]|0}t=l+6|0;l=t&16777214;q=c[x+(l>>>10<<2)>>2]|0;if(q>>>0>9){f=t&1022;y=(d[q+(f|1)|0]|0)<<8|(d[q+f|0]|0)}else{y=gj[c[x+196688+(q<<2)>>2]&4095](l)|0}l=p|o&65535;o=0;do{p=(o<<1)+l|0;q=p&16777214;x=c[2112932]|0;f=c[x+(q>>>10<<2)>>2]|0;if(f>>>0>9){t=p&1022;z=(d[f+(t|1)|0]|0)<<8|(d[f+t|0]|0)}else{z=gj[c[x+196688+(f<<2)>>2]&4095](q)|0}b[j+(o<<1)>>1]=z;o=o+1|0;}while((o|0)<24);o=m&65535;m=(n|o)&16777214;n=(k&255|0)==1;k=g>>>2&16128;z=g&896;l=g&31;g=b[j+42>>1]|0;if((l|0)!=15&(g&65535)<8192){A=n?l:(g&65535)>>>8}else{A=l}l=w<<16>>16;w=y<<16>>16;g=e[j>>1]|0;q=g&96;f=(g&20|0)==20;x=(g&32768|0)==0?k:k|32768;k=f?x|16384:x;if((g&16384|0)==0){B=k&65535;C=l}else{B=(k^4096)&65535;C=-l|0}l=e[j+12>>1]|0;k=e[j+14>>1]|0;x=e[j+16>>1]|0;t=b[j+28>>1]|0;p=t&65535;if(f){D=p}else{D=e[j+30>>1]|0}if((g&32|0)==0){E=58138}else{if((t<<16>>16|0)==256|(t<<16>>16|0)==0){F=w;G=C}else{E=58138}}do{if((E|0)==58138){t=p-20224|0;do{if((t|0)>0){H=~~(+(C|0)*+X(+(+(t>>8|0)),1.891292)/599.250121)+C|0}else{if((t|0)>=0){H=C;break}g=(t>>4)+p+(t>>3)+(t>>5)+(t>>6)|0;if((g|0)<=0){H=0;break}H=(ag(g,C)|0)/20224|0}}while(0);t=D-20224|0;if((t|0)>0){F=~~(+(y<<16>>16|0)*+X(+(+(t>>8|0)),1.891292)/599.250121)+w|0;G=H;break}if((t|0)>=0){F=w;G=H;break}g=(t>>4)+D+(t>>3)+(t>>5)+(t>>6)|0;if((g|0)<=0){F=0;G=H;break}F=(ag(g,w)|0)/20224|0;G=H}}while(0);H=G+l|0;l=(n?0:x)+k+F|0;F=c[2112932]|0;k=c[F+((m>>>10|16384)<<2)>>2]|0;if(k>>>0>9){x=o&1022;a[k+x|0]=B&255;a[k+(x|1)|0]=(B&65535)>>>8&255;I=F}else{gg[c[F+196728+(k<<2)>>2]&4095](m,B);I=c[2112932]|0}B=m+4|0;k=B&16777214;F=c[I+((k>>>10|16384)<<2)>>2]|0;if(F>>>0>9){x=B&1022;a[F+x|0]=s&255;a[F+(x|1)|0]=(s&65535)>>>8&255;J=I}else{gg[c[I+196728+(F<<2)>>2]&4095](k,s);J=c[2112932]|0}s=m+8|0;k=l&65535;F=s&16777214;I=c[J+((F>>>10|16384)<<2)>>2]|0;if(I>>>0>9){x=s&1022;a[I+x|0]=l&255;a[I+(x|1)|0]=(k&65535)>>>8&255;K=J}else{gg[c[J+196728+(I<<2)>>2]&4095](F,k);K=c[2112932]|0}k=m+12|0;F=H&65535;I=k&16777214;J=c[K+((I>>>10|16384)<<2)>>2]|0;if(J>>>0>9){x=k&1022;a[J+x|0]=H&255;a[J+(x|1)|0]=(F&65535)>>>8&255;L=K}else{gg[c[K+196728+(J<<2)>>2]&4095](I,F);L=c[2112932]|0}F=m+24|0;m=A|z|q;q=m&65535;z=F&16777214;A=c[L+((z>>>10|16384)<<2)>>2]|0;if(A>>>0>9){I=F&1022;a[A+I|0]=m&255;a[A+(I|1)|0]=(q&65535)>>>8&255;i=h;return}else{gg[c[L+196728+(A<<2)>>2]&4095](z,q);i=h;return}}function bbs(b){b=b|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=i;i=i+48|0;g=f|0;h=f+8|0;j=f+16|0;k=f+24|0;l=f+32|0;m=f+40|0;n=b-1572864|0;if(n>>>0<16384){if((n&98|0)==0){o=(e[(c[3529054]|0)+((n>>>2&7|n>>>4&1016)<<1)>>1]|0)>>>((b<<3&8^8)>>>0)&255;i=f;return o|0}else{o=a[(c[2443436]|0)+(n^1)|0]|0;i=f;return o|0}}if((b&16777088|0)==1836288){o=a[(c[2388060]|0)+(b&127^16385)|0]|0;i=f;return o|0}n=b-5898240|0;if(n>>>0<32){p=n>>>1;if((b&1|0)!=0){if((a[14108509]&16)==0){o=0;i=f;return o|0}if((p&12|0)!=12){o=0;i=f;return o|0}o=a[(c[3529056]|0)+((c[3527134]<<19|p&2|d[14108515]<<18&1835008|d[14108512]<<10|d[14108513]<<2)&c[3527124])|0]|0;i=f;return o|0}n=p&2147483646;do{if((a[14108509]&16)!=0){if((p&12|0)!=12){break}o=a[(c[3529056]|0)+((p&2|c[3527134]<<19|d[14108515]<<18&1835008|d[14108512]<<10|d[14108513]<<2|1)&c[3527124])|0]|0;i=f;return o|0}}while(0);if((n|0)!=6){o=0;i=f;return o|0}n=c[3529058]|0;p=c[3529054]|0;gGC(n|0,p|0,2048)|0;o=0;i=f;return o|0}p=b-6291456|0;if(p>>>0<16384){n=p>>>1;if((b&1|0)==0){if(p>>>0>49151){o=0;i=f;return o|0}if((c[3541230]|0)==0){o=a[(c[3529062]|0)+n|0]|0;i=f;return o|0}c[k>>2]=0;q=p>>>6&255;c[l>>2]=q;p=d[9730680]|0;c[m>>2]=p;r=p>>>2&3;if((c[2429638]|0)==0){gB[c[2437692]&127](0,((a[9718936+r|0]|a[9720736+r|0])&255)>>>2,l,m,k,k);s=c[l>>2]|0}else{k=p<<8|q;c[l>>2]=k;s=k}o=a[(c[3529060]|0)+((s<<5|n&31)&c[2438700])|0]|0;i=f;return o|0}else{s=n+8192|0;if(s>>>0>24575){o=0;i=f;return o|0}if((c[3541230]|0)==0){o=a[(c[3529062]|0)+s|0]|0;i=f;return o|0}c[g>>2]=0;n=s>>>5&255;c[h>>2]=n;k=d[9730680]|0;c[j>>2]=k;l=k>>>2&3;if((c[2429638]|0)==0){gB[c[2437692]&127](0,((a[9718936+l|0]|a[9720736+l|0])&255)>>>2,h,j,g,g);t=c[h>>2]|0}else{g=k<<8|n;c[h>>2]=g;t=g}o=a[(c[3529060]|0)+((t<<5|s&31)&c[2438700])|0]|0;i=f;return o|0}}if((b|0)==1835013){o=~a[9625891];i=f;return o|0}else if((b|0)==1835267){s=a[9625893]|0;t=(a[9545176]|0)==0?s:s|8;do{if((c[2406632]|0)==0){s=c[2443744]|0;if((s|0)<=0){u=1;break}c[2443744]=s-1;u=0}else{u=(c[2432962]|0)>>>((c[(c[2420380]|0)+4>>2]|0)>>>0)&1}}while(0);s=(u|t&255)&255;t=c[2437706]|0;if((t|0)==0){v=s}else{c[2437706]=t-1;v=s&127}s=c[2384440]^4;c[2384440]=s;o=(s^v&255)&255;i=f;return o|0}else if((b|0)==1835009){o=~a[9625889];i=f;return o|0}else if((b|0)==1835265){o=~a[9625888];i=f;return o|0}else if((b|0)==1835011){o=~a[9625890];i=f;return o|0}else if((b|0)==1837056|(b|0)==1837057){o=((bbt()|0)&65535)>>>((b<<3&8^8)>>>0)&255;i=f;return o|0}else if((b|0)==1835015){o=~a[9625892];i=f;return o|0}else if((b|0)==6030851|(b|0)==6030849){v=(b-6030849|0)>>>1;b=v+2|0;c[2426862]=9674384;if((v|0)==44){w=58216}else if((v|0)==39){o=(c[2418664]<<1|c[2418653]|c[2418675]<<2|c[2418686]<<3)&255;i=f;return o|0}do{if((w|0)==58216){if((c[2418596]&1|0)==0){break}v=c[2418655]|0;s=(v>>>16)+(c[2418650]|0)+(c[2418651]<<16)|0;c[2418655]=v+65536;if(s>>>0>(c[2418646]|0)>>>0){o=0;i=f;return o|0}o=a[(c[2418645]|0)+s|0]|0;i=f;return o|0}}while(0);o=c[9674388+(b<<2)>>2]&255;i=f;return o|0}else{o=0;i=f;return o|0}return 0}function bbt(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;b=i;i=i+48|0;e=b|0;f=b+8|0;g=b+16|0;h=b+24|0;j=b+32|0;k=b+40|0;l=c[2112932]|0;m=c[l+4184>>2]|0;if(m>>>0>9){n=(d[m+523|0]|0)<<8|(d[m+522|0]|0);o=l;p=m}else{q=gj[c[l+196688+(m<<2)>>2]&4095](1071626)|0;m=c[2112932]|0;n=q;o=m;p=c[m+4184>>2]|0}if(p>>>0>9){r=(d[p+253|0]|0)<<8|(d[p+252|0]|0)}else{r=gj[c[o+196688+(p<<2)>>2]&4095](1071356)|0}p=r&65535;if((p|0)==35516){r=c[2112932]|0;o=c[r+4184>>2]|0;if(o>>>0>9){s=(d[o+25|0]|0)<<8|(d[o+24|0]|0);t=r}else{m=gj[c[r+196688+(o<<2)>>2]&4095](1071128)|0;s=m;t=c[2112932]|0}m=(((-(s&65535)|0)/8|0)<<6)+1792&1984;s=c[t+4188>>2]|0;if(s>>>0>9){u=(d[s+177|0]|0)<<8|(d[s+176|0]|0)}else{u=gj[c[t+196688+(s<<2)>>2]&4095](1072304)|0}s=u&65535;u=c[3541230]|0;if((u|0)==0){v=(c[3529062]|0)+6657|0;w=0}else{c[h>>2]=0;c[j>>2]=208;t=d[9730680]|0;c[k>>2]=t;o=t>>>2&3;if((c[2429638]|0)==0){gB[c[2437692]&127](0,((a[9718936+o|0]|a[9720736+o|0])&255)>>>2,j,k,h,h);x=c[j>>2]|0;y=c[3541230]|0}else{h=t<<8|208;c[j>>2]=h;x=h;y=u}v=(c[3529060]|0)+((x<<5|1)&c[2438700])|0;w=y}y=(d[v]|0)<<8;if((w|0)==0){z=(c[3529062]|0)+6656|0}else{c[e>>2]=0;c[f>>2]=208;w=d[9730680]|0;c[g>>2]=w;v=w>>>2&3;if((c[2429638]|0)==0){gB[c[2437692]&127](0,((a[9718936+v|0]|a[9720736+v|0])&255)>>>2,f,g,e,e);A=c[f>>2]|0}else{e=w<<8|208;c[f>>2]=e;A=e}z=(c[3529060]|0)+(A<<5&c[2438700])|0}B=(((s+506+y+(d[z]|0)|0)>>>3)+12&63|m)&65535;i=b;return B|0}else if((p|0)==0){B=n&255;i=b;return B|0}else if((p|0)==24576){B=n&1;i=b;return B|0}else if((p|0)==24583){B=n&255;i=b;return B|0}else if((p|0)==4107){B=100;i=b;return B|0}else if((p|0)==24579){B=n&15;i=b;return B|0}else if((p|0)==24580){B=n&31;i=b;return B|0}else{B=-1;i=b;return B|0}return 0}function bbu(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=d-1572864|0;if(f>>>0<16384){a[(c[2443436]|0)+(f^1)|0]=e;if((f&98|0)!=0){return}g=(c[3529054]|0)+((f>>>2&7|f>>>4&1016)<<1)|0;f=b[g>>1]|0;if((d&1|0)==0){h=f&255|(e&255)<<8}else{h=f&-256|e&255}b[g>>1]=h;return}if((d&-4|0)==1837056){return}if((d&16777088|0)==1836288){a[(c[2388060]|0)+(d&127^16385)|0]=e;return}h=d-5898240|0;if(h>>>0<32){g=h>>>1;h=g&2147483646;a[14108504+(g|1)|0]=e;a[14108504+h|0]=0;if((h|0)!=6){return}h=c[3529058]|0;g=c[3529054]|0;gGC(h|0,g|0,2048)|0;return}g=d-6031104|0;if(g>>>0<32){h=e&255;f=h&63;i=g>>>1&15;a[14116144+i|0]=f&255;if((i|0)==10){c[2437685]=h<<4&112;c[2437686]=f>>>3<<4;return}else if((i|0)==9){c[2437682]=h<<5&96;c[2437683]=h>>>2<<5&96;c[2437684]=f>>>4<<5;return}else{return}}f=d-6291456|0;if(f>>>0>=16384){if((d|0)==1835777){h=e&255;c[3541230]=h&8;c[2415282]=h>>>4&7;return}else if((d|0)==6030853){h=c[2439330]|0;i=(h|0)==0;if(!i){g=h;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;g=c[2438118]|0;c[2433530]=g;j=c[3528484]|0;c[2076596]=j;k=c[2417276]|0;c[3541536]=k;c[1836236]=0;a[14125144]=-1;a[9706117]=1;if(!i){i=h;gGC(i|0,9706056,76)|0}c[2438118]=g;c[3528484]=j;c[2417276]=k;c[1836236]=-1;return}else if((d|0)==1835521){k=e&255;c[2415256]=k&1;j=k>>>1&1;c[3528406]=j^1;if((j|0)==0){c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2]}Tr(k>>>2&1);c[3527134]=k>>>5<<2&4;c[2415284]=k&24;return}else if((d|0)==6030849){c[2426862]=9674384;c[2418597]=e&255;return}else{return}}k=f>>>1;if((d&1|0)!=0){d=k+8192|0;if(d>>>0>24575){return}a[(c[3529062]|0)+d|0]=e;if(d>>>0>16383){c[2429638]=1}if(!((d&6144)>>>0>6143&(k|0)==7680)){return}a[9730680]=e;return}if(f>>>0>49151){return}a[(c[3529062]|0)+k|0]=e;if(f>>>0>32767){c[2429638]=1}if((k&6144)>>>0<=6143){return}if((k|0)==7552){a[9720736]=e&15;a[9720737]=(e&255)>>>4;return}else if((k|0)==7680|(k|0)==15872){a[9730680]=e;return}else if((k|0)==7424){c[3541228]=e&4;return}else if((k|0)==7296){a[9729904]=e;return}else if((k|0)==7936){a[9720738]=e&15;a[9720739]=(e&255)>>>4;return}else if((k|0)==7808){c[2432672]=(e&255)>>>1&3;return}else{return}}function bbv(a){a=a|0;var d=0,e=0,f=0;d=a-1572864|0;if(d>>>0<16384){e=d>>>1;if((e&49|0)==0){f=b[(c[3529054]|0)+((d>>>2&7|d>>>4&1016)<<1)>>1]|0;return f|0}else{f=b[(c[2443436]|0)+(e<<1)>>1]|0;return f|0}}if((a&16777088|0)==1836288){f=b[(c[2388060]|0)+(a&126|16384)>>1]|0;return f|0}if((a|0)!=1837056){f=0;return f|0}f=bbt()|0;return f|0}function bbw(e,f){e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=e-1572864|0;if(g>>>0<16384){h=g>>>1;b[(c[2443436]|0)+(h<<1)>>1]=f;if((h&49|0)!=0){return}b[(c[3529054]|0)+((g>>>2&7|g>>>4&1016)<<1)>>1]=f;return}g=e-5898240|0;if(g>>>0<32){h=g>>>1;g=h&2147483646;a[14108504+(h|1)|0]=f&255;a[14108504+g|0]=(f&65535)>>>8&255;if((g|0)!=6){return}g=c[3529058]|0;h=c[3529054]|0;gGC(g|0,h|0,2048)|0;return}if((e&16777088|0)==1836288){b[(c[2388060]|0)+(e&126|16384)>>1]=f;return}if((e|0)==1837058){i=1;j=1}else{return}while(1){e=i&65535;f=j;h=0;while(1){g=(h<<7)+1572870|0;k=c[2112932]|0;l=c[k+(g>>>10<<2)>>2]|0;if(l>>>0>9){m=g&902;n=(d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0)}else{n=gj[c[k+196688+(l<<2)>>2]&4095](g)|0}if(((n&65535)>>>8|0)==(e|0)){a[(c[3529054]|0)+(h<<4)|0]=f&255;o=f+1|0}else{o=f}g=h+1|0;if((g|0)<128){f=o;h=g}else{break}}h=i<<1;if((h|0)<256){i=h;j=o}else{break}}return}function bbx(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;e=i;i=i+112|0;f=e|0;g=e+8|0;h=e+16|0;j=e+24|0;k=e+32|0;l=e+40|0;m=e+48|0;n=e+56|0;o=e+64|0;p=e+72|0;q=e+80|0;r=e+88|0;s=e+96|0;t=e+104|0;u=b-6291456|0;if(u>>>0<32768){v=u>>>1;w=u>>>2&6144|v&2047;if((b&1|0)==0){if((c[3541230]|0)==0){x=a[(c[3529062]|0)+w|0]|0;i=e;return x|0}c[o>>2]=0;u=w>>>5;c[p>>2]=u;y=d[9730680]|0;c[q>>2]=y;z=y>>>2&3;if((c[2429638]|0)==0){gB[c[2437692]&127](0,((a[9718936+z|0]|a[9720736+z|0])&255)>>>2,p,q,o,o);A=c[p>>2]|0}else{o=y<<8|u;c[p>>2]=o;A=o}x=a[(c[3529060]|0)+((A<<5|v&31)&c[2438700])|0]|0;i=e;return x|0}else{if((c[3541230]|0)==0){x=a[(c[3529062]|0)+(w|8192)|0]|0;i=e;return x|0}c[r>>2]=0;A=w>>>5;c[s>>2]=A;w=d[9730680]|0;c[t>>2]=w;o=w>>>2&3;if((c[2429638]|0)==0){gB[c[2437692]&127](0,((a[9718936+o|0]|a[9720736+o|0])&255)>>>2,s,t,r,r);B=c[s>>2]|0}else{r=w<<8|A;c[s>>2]=r;B=r}x=a[(c[3529060]|0)+((B<<5|v&31)&c[2438700])|0]|0;i=e;return x|0}}v=b-7340032|0;if(v>>>0<8){if((v|0)==0){B=c[2384516]|0;c[2384516]=B+1;x=B&1;i=e;return x|0}if((c[3541238]|0)==0){x=0;i=e;return x|0}if((b-7340036|0)>>>0>=4){x=0;i=e;return x|0}B=d[9718033]|0;r=((d[9718032]|0)<<8)+(c[2433420]|0)+(B<<16&196608)|0;c[k>>2]=r>>>5&8191;s=(d[9718034]|0)<<6;c[l>>2]=s&192|B>>>2;c[m>>2]=0;c[n>>2]=s&128;gL[c[2437694]&255](k,l,m,n);x=a[(c[3529064]|0)+((c[k>>2]<<7|v&3|r<<2&124)&c[2438702])|0]|0;i=e;return x|0}if((b&268434432|0)==7341056){if((c[3541238]|0)!=0){r=b>>>2&255;c[2433420]=r;v=d[9718033]|0;c[f>>2]=((d[9718032]|0)<<8|r|v<<16)>>>5&8191;r=(d[9718034]|0)<<6;c[g>>2]=r&192|v>>>2;c[h>>2]=0;c[j>>2]=r&128;gL[c[2437694]&255](f,g,h,j)}x=a[(c[3529066]|0)+(b&1023)|0]|0;i=e;return x|0}j=b-5242880|0;if(j>>>0<64){if((b&1|0)==0){x=0;i=e;return x|0}x=ba9(j>>>1)|0;i=e;return x|0}if((b|0)==5243393){x=~a[9625888];i=e;return x|0}else if((b|0)==4194305|(b|0)==4194307){c[2426862]=9674384;x=c[9674388+((b>>>1&1|2)<<2)>>2]&255;i=e;return x|0}else if((b|0)==5243392){j=~a[9625889];h=c[2437706]|0;if((h|0)==0){x=j;i=e;return x|0}c[2437706]=h-1;x=j&-9;i=e;return x|0}else if((b|0)==5243395){x=~a[9625890];i=e;return x|0}else if((b|0)==5243394){b=c[2384518]^8;c[2384518]=b;do{if((c[2406632]|0)==0){j=c[2443744]|0;if((j|0)<=0){C=255;break}c[2443744]=j-1;C=254}else{C=(c[2432962]|0)>>>((c[(c[2420380]|0)+4>>2]|0)>>>0)&1|254}}while(0);x=(b^C)&255;i=e;return x|0}else{x=0;i=e;return x|0}return 0}function bby(b,d){b=b|0;d=d|0;var e=0;if((b&268434432|0)!=7341056){return}e=b&1022;b=c[3529066]|0;a[b+e|0]=(d&65535)>>>8&255;a[b+(e|1)|0]=d&255;return}function bbz(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=b-6291456|0;if(e>>>0<32768){f=e>>>2&6144;g=f|e>>>1&2047;if((b&1|0)!=0){e=g|8192;a[(c[3529062]|0)+e|0]=d;if(!((f|0)==6144&(e|0)==15872)){return}a[9730680]=d;return}a[(c[3529062]|0)+g|0]=d;if((f|0)!=6144){return}switch(g|0){case 7552:{a[9720736]=d&15;a[9720737]=(d&255)>>>4;return};case 7680:{a[9730680]=d;return};case 7936:{a[9720738]=d&15;a[9720739]=(d&255)>>>4;return};case 7296:{a[9729904]=d;return};case 7808:{c[2432672]=(d&255)>>>1&3;return};case 7424:{c[3541228]=d&4;return};default:{return}}}g=b-7340032|0;if(g>>>0<8){if((g|0)==0){g=d&255;c[3541236]=g&1;c[3541234]=g&4;c[3541232]=g&8;c[3541238]=g&32;return}g=b-7340034|0;if(g>>>0>=3){return}a[9718032+g|0]=d;return}if((b&268434432|0)==7341056){a[(c[3529066]|0)+(b&1023)|0]=d;return}g=b-3145728|0;if(g>>>0<32){if((b&1|0)==0){return}f=d&255;e=f&63;h=g>>>1&15;a[14116144+h|0]=e&255;if((h|0)==10){c[2437685]=f<<4&112;c[2437686]=e>>>3<<4;return}else if((h|0)==9){c[2437682]=f<<5&96;c[2437683]=f>>>2<<5&96;c[2437684]=e>>>4<<5;return}else{return}}e=b-5242880|0;if(e>>>0<64){if((b&1|0)==0){return}a[14116112+(e>>>1&31)|0]=d;return}if((b|0)==4194305){c[2426862]=9674384;c[2418597]=d&255;return}else if((b|0)==5243137){b=d&255;c[2415256]=b&1;d=b>>>1&1;c[3528406]=d^1;if((d|0)==0){c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2]}Tr(b>>>2&1);d=b&32;do{if((c[2384438]|0)==0){if((d|0)==0){i=0;break}a[14125144]=-1;a[9706117]=1;i=d}else{i=d}}while(0);c[2384438]=i;c[3541230]=b&64;return}else{return}}function bbA(a){a=a|0;var d=0,e=0;d=a-720896|0;if(d>>>0>=16384){e=0;return e|0}a=d>>>1;if((a&49|0)==0){e=b[(c[3529054]|0)+((d>>>2&7|d>>>4&1016)<<1)>>1]|0;return e|0}else{e=b[(c[2443436]|0)+(a<<1)>>1]|0;return e|0}return 0}function bbB(b){b=b|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+48|0;g=f|0;h=f+8|0;j=f+16|0;k=f+24|0;l=f+32|0;m=f+40|0;n=b-1048576|0;if(n>>>0<32768){o=n>>>1;p=n>>>2&6144|o&2047;if((b&1|0)==0){if((c[3541230]|0)==0){q=a[(c[3529062]|0)+p|0]|0;i=f;return q|0}c[g>>2]=0;n=p>>>5;c[h>>2]=n;r=d[9730680]|0;c[j>>2]=r;s=r>>>2&3;if((c[2429638]|0)==0){gB[c[2437692]&127](0,((a[9718936+s|0]|a[9720736+s|0])&255)>>>2,h,j,g,g);t=c[h>>2]|0}else{g=r<<8|n;c[h>>2]=g;t=g}q=a[(c[3529060]|0)+((t<<5|o&31)&c[2438700])|0]|0;i=f;return q|0}else{if((c[3541230]|0)==0){q=a[(c[3529062]|0)+(p|8192)|0]|0;i=f;return q|0}c[k>>2]=0;t=p>>>5;c[l>>2]=t;p=d[9730680]|0;c[m>>2]=p;g=p>>>2&3;if((c[2429638]|0)==0){gB[c[2437692]&127](0,((a[9718936+g|0]|a[9720736+g|0])&255)>>>2,l,m,k,k);u=c[l>>2]|0}else{k=p<<8|t;c[l>>2]=k;u=k}q=a[(c[3529060]|0)+((u<<5|o&31)&c[2438700])|0]|0;i=f;return q|0}}o=b-720896|0;if(o>>>0<16384){if((o&98|0)==0){q=(e[(c[3529054]|0)+((o>>>2&7|o>>>4&1016)<<1)>>1]|0)>>>((b<<3&8^8)>>>0)&255;i=f;return q|0}else{q=a[(c[2443436]|0)+(o^1)|0]|0;i=f;return q|0}}o=b-786432|0;if(o>>>0<32){u=o>>>1;if((b&1|0)!=0){if((a[14108509]&16)==0){q=0;i=f;return q|0}if((u&12|0)!=12){q=0;i=f;return q|0}q=a[(c[3529056]|0)+((c[3527134]<<19|u&2|(d[14108515]|0)<<18&1835008|(d[14108512]|0)<<10|(d[14108513]|0)<<2)&c[3527124])|0]|0;i=f;return q|0}o=u&2147483646;do{if((a[14108509]&16)!=0){if((u&12|0)!=12){break}q=a[(c[3529056]|0)+((u&2|c[3527134]<<19|(d[14108515]|0)<<18&1835008|(d[14108512]|0)<<10|(d[14108513]|0)<<2|1)&c[3527124])|0]|0;i=f;return q|0}}while(0);if((o|0)!=6){q=0;i=f;return q|0}o=c[3529058]|0;u=c[3529054]|0;gGC(o|0,u|0,2048)|0;q=0;i=f;return q|0}switch(b|0){case 655393:case 655395:{c[2426862]=9674384;q=c[9674388+((b>>>1&1|2)<<2)>>2]&255;i=f;return q|0};case 655367:{q=a[9658096]|0;i=f;return q|0};case 655363:{q=~a[9625889];i=f;return q|0};case 655365:{q=~a[9625890];i=f;return q|0};case 655377:{q=a[9658098]|0;i=f;return q|0};case 655361:{q=a[9625888]&-5^-5;i=f;return q|0};case 655369:{q=a[9658097]|0;i=f;return q|0};default:{q=0;i=f;return q|0}}return 0}function bbC(a,d){a=a|0;d=d|0;var e=0;e=a-720896|0;if(e>>>0>=16384){return}a=e>>>1;b[(c[2443436]|0)+(a<<1)>>1]=d;if((a&49|0)!=0){return}b[(c[3529054]|0)+((e>>>2&7|e>>>4&1016)<<1)>>1]=d;return}function bbD(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=d-1048576|0;if(f>>>0<32768){g=f>>>2&6144;h=g|f>>>1&2047;if((d&1|0)!=0){f=h|8192;a[(c[3529062]|0)+f|0]=e;if(!((g|0)==6144&(f|0)==15872)){return}a[9730680]=e;return}a[(c[3529062]|0)+h|0]=e;if((g|0)!=6144){return}switch(h|0){case 7296:{a[9729904]=e;return};case 7424:{c[3541228]=e&4;return};case 7936:{a[9720738]=e&15;a[9720739]=(e&255)>>>4;return};case 7680:{a[9730680]=e;return};case 7552:{a[9720736]=e&15;a[9720737]=(e&255)>>>4;return};case 7808:{c[2432672]=(e&255)>>>1&3;return};default:{return}}}h=d-917504|0;if(h>>>0<32){g=e&255;f=g&63;i=h>>>1&15;a[14116144+i|0]=f&255;if((i|0)==9){c[2437682]=g<<5&96;c[2437683]=g>>>2<<5&96;c[2437684]=f>>>4<<5;return}else if((i|0)==10){c[2437685]=g<<4&112;c[2437686]=f>>>3<<4;return}else{return}}f=d-720896|0;if(f>>>0<16384){a[(c[2443436]|0)+(f^1)|0]=e;if((f&98|0)!=0){return}g=(c[3529054]|0)+((f>>>2&7|f>>>4&1016)<<1)|0;f=b[g>>1]|0;if((d&1|0)==0){j=f&255|(e&255)<<8}else{j=f&-256|e&255}b[g>>1]=j;return}j=d-786432|0;if(j>>>0<32){g=j>>>1;j=g&2147483646;a[14108504+(g|1)|0]=e;a[14108504+j|0]=0;if((j|0)!=6){return}j=c[3529058]|0;g=c[3529054]|0;gGC(j|0,g|0,2048)|0;return}if((d|0)==655393){c[2426862]=9674384;c[2418597]=e&255;return}else if((d|0)==655385){do{if((c[2384436]|0)==0){if((e&4)==0){break}a[14125144]=-1;a[9706117]=1}}while(0);d=e&255;c[2384436]=d&4;c[3541230]=d&8;return}else{return}}function bbE(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;b=i;i=i+64|0;e=b|0;f=b+8|0;g=b+16|0;h=b+24|0;j=b+32|0;k=b+40|0;l=b+48|0;m=b+56|0;if((a&16776192|0)!=1115136){n=0;i=b;return n|0}o=a&1022;p=o|1;do{if((c[3541238]|0)==0){q=c[3529066]|0;r=d[q+p|0]|0;s=q}else{q=a>>>2&255;c[2433420]=q;t=d[9718033]|0;c[j>>2]=((d[9718032]|0)<<8|q|t<<16)>>>5&8191;u=(d[9718034]|0)<<6;c[k>>2]=u&192|t>>>2;c[l>>2]=0;c[m>>2]=u&128;gL[c[2437694]&255](j,k,l,m);u=c[3529066]|0;t=d[u+p|0]|0;if((c[3541238]|0)==0){r=t;s=u;break}c[2433420]=q;u=d[9718033]|0;c[e>>2]=((d[9718032]|0)<<8|q|u<<16)>>>5&8191;q=(d[9718034]|0)<<6;c[f>>2]=q&192|u>>>2;c[g>>2]=0;c[h>>2]=q&128;gL[c[2437694]&255](e,f,g,h);r=t;s=c[3529066]|0}}while(0);n=(d[s+o|0]|0)<<8|r;i=b;return n|0}function bbF(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;e=i;i=i+112|0;f=e|0;g=e+8|0;h=e+16|0;j=e+24|0;k=e+32|0;l=e+40|0;m=e+48|0;n=e+56|0;o=e+64|0;p=e+72|0;q=e+80|0;r=e+88|0;s=e+96|0;t=e+104|0;u=b-1048576|0;if(u>>>0<32768){v=u>>>1;w=u>>>2&6144|v&2047;if((b&1|0)==0){if((c[3541230]|0)==0){x=a[(c[3529062]|0)+w|0]|0;i=e;return x|0}c[o>>2]=0;u=w>>>5;c[p>>2]=u;y=d[9730680]|0;c[q>>2]=y;z=y>>>2&3;if((c[2429638]|0)==0){gB[c[2437692]&127](0,((a[9718936+z|0]|a[9720736+z|0])&255)>>>2,p,q,o,o);A=c[p>>2]|0}else{o=y<<8|u;c[p>>2]=o;A=o}x=a[(c[3529060]|0)+((A<<5|v&31)&c[2438700])|0]|0;i=e;return x|0}else{if((c[3541230]|0)==0){x=a[(c[3529062]|0)+(w|8192)|0]|0;i=e;return x|0}c[r>>2]=0;A=w>>>5;c[s>>2]=A;w=d[9730680]|0;c[t>>2]=w;o=w>>>2&3;if((c[2429638]|0)==0){gB[c[2437692]&127](0,((a[9718936+o|0]|a[9720736+o|0])&255)>>>2,s,t,r,r);B=c[s>>2]|0}else{r=w<<8|A;c[s>>2]=r;B=r}x=a[(c[3529060]|0)+((B<<5|v&31)&c[2438700])|0]|0;i=e;return x|0}}v=b-1114112|0;if(v>>>0<8){if((v|0)==0){B=c[2384442]|0;c[2384442]=B+1;x=B&1;i=e;return x|0}if((c[3541238]|0)==0){x=0;i=e;return x|0}if((b-1114116|0)>>>0>=4){x=0;i=e;return x|0}B=d[9718033]|0;r=((d[9718032]|0)<<8)+(c[2433420]|0)+(B<<16&196608)|0;c[k>>2]=r>>>5&8191;s=(d[9718034]|0)<<6;c[l>>2]=s&192|B>>>2;c[m>>2]=0;c[n>>2]=s&128;gL[c[2437694]&255](k,l,m,n);x=a[(c[3529064]|0)+((c[k>>2]<<7|v&3|r<<2&124)&c[2438702])|0]|0;i=e;return x|0}r=b-1115136|0;if(r>>>0<1024){if((c[3541238]|0)!=0){v=r>>>2&255;c[2433420]=v;k=d[9718033]|0;c[f>>2]=((d[9718032]|0)<<8|v|k<<16)>>>5&8191;v=(d[9718034]|0)<<6;c[g>>2]=v&192|k>>>2;c[h>>2]=0;c[j>>2]=v&128;gL[c[2437694]&255](f,g,h,j)}x=a[(c[3529066]|0)+r|0]|0;i=e;return x|0}if((b|0)==655367){x=~a[9625889];i=e;return x|0}else if((b|0)==16777212|(b|0)==16777213|(b|0)==16777214|(b|0)==16777215){x=(cT()|0)&255;i=e;return x|0}else if((b|0)==655364){x=~a[9625892];i=e;return x|0}else if((b|0)==655365){x=~a[9625891];i=e;return x|0}else if((b|0)==655363){x=~a[9625888];i=e;return x|0}else if((b|0)==655366){x=~a[9625890];i=e;return x|0}else if((b|0)==655362){x=a[9625893]&15^15|a[9658098];i=e;return x|0}else if((b|0)==655360){x=a[9658097]|0;i=e;return x|0}else if((b|0)==655361){x=a[9658096]|0;i=e;return x|0}else if((b|0)==655425|(b|0)==655427){c[2426862]=9674384;x=c[9674388+((b>>>1&1|2)<<2)>>2]&255;i=e;return x|0}else{x=0;i=e;return x|0}return 0}function bbG(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;if((b&16776192|0)==1115136){e=b&1022;f=c[3529066]|0;a[f+e|0]=(d&65535)>>>8&255;a[f+(e|1)|0]=d&255;return}if((b&16744448|0)!=1048576){return}e=b+1|0;b=d&255;d=e&16777215;f=c[2112932]|0;g=c[f+((d>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(e&1023^1)|0]=b;return}else{gg[c[f+196648+(g<<2)>>2]&4095](d,b);return}}function bbH(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=b-1048576|0;if(e>>>0<32768){f=e>>>2&6144;g=f|e>>>1&2047;if((b&1|0)!=0){e=g|8192;a[(c[3529062]|0)+e|0]=d;if(!((f|0)==6144&(e|0)==15872)){return}a[9730680]=d;return}a[(c[3529062]|0)+g|0]=d;if((f|0)!=6144){return}switch(g|0){case 7552:{a[9720736]=d&15;a[9720737]=(d&255)>>>4;return};case 7808:{c[2432672]=(d&255)>>>1&3;return};case 7296:{a[9729904]=d;return};case 7936:{a[9720738]=d&15;a[9720739]=(d&255)>>>4;return};case 7424:{c[3541228]=d&4;return};case 7680:{a[9730680]=d;return};default:{return}}}g=b-1114112|0;if(g>>>0<8){if((g|0)==0){g=d&255;c[3541236]=g&1;c[3541234]=g&4;c[3541232]=g&8;c[3541238]=g&32;return}g=b-1114114|0;if(g>>>0>=3){return}a[9718032+g|0]=d;return}g=b-1115136|0;if(g>>>0<1024){a[(c[3529066]|0)+g|0]=d;return}if((b&16777185|0)==655457){g=b>>>1&15;f=d&255;e=f&63;a[14116144+g|0]=e&255;if((g|0)==9){c[2437682]=f<<5&96;c[2437683]=f>>>2<<5&96;c[2437684]=e>>>4<<5;return}else if((g|0)==10){c[2437685]=f<<4&112;c[2437686]=e>>>3<<4;return}else{return}}if((b|0)==655392|(b|0)==655393){e=d&255;c[3541230]=e&8;f=e&4;if((c[2384434]|0)==4&(f|0)==0){a[14125144]=-1;a[9706117]=1;h=0}else{h=f}c[2384434]=h;return}else if((b|0)==655425){c[2426862]=9674384;c[2418597]=d&255;return}else{return}}function bbI(b){b=b|0;var e=0,f=0,g=0,h=0;e=b&65535;if((b+20480&65535)<14){c[2424878]=9681232;c[2426622]=9622928;if(!((e|0)==45067|(e|0)==45061)){f=0;return f|0}b=(e-45056|0)/6|0;g=b*6|0;h=d[g+9681280|0]<<16&65536|d[g+9681279|0]<<8|d[g+9681278|0]|c[9681260+(b<<2)>>2];c[9681244+(b<<2)>>2]=h;if(h>>>0>=(c[2405735]|0)>>>0){f=0;return f|0}c[9681268+(b<<2)>>2]=1;c[9681236+(b<<2)>>2]=0;f=0;return f|0}if((e|0)==49153){f=c[(c[3531464]|0)+4240>>2]&255;return f|0}else if((e|0)==40960){a[9706117]=0;f=a[9758256]|0;return f|0}else if((e|0)==36864){f=c[2436804]&255;return f|0}else if((e|0)==61440){e=c[2418506]|0;c[2424874]=e;f=(a[e+16|0]|0)==0|0;return f|0}else{f=0;return f|0}return 0}function bbJ(b,d){b=b|0;d=d|0;var e=0,f=0;e=b&65535;if((b+20480&65535)<14){TI(0,e-45056|0,d&255);return}if((e|0)==36864){b=d&255;c[2436804]=b;if((b&4|0)==0){c[2437026]=0;h[615974]=0.0}else{c[2437026]=1}b=c[2418506]|0;c[2424874]=b;f=b+9|0;b=a[f]|0;a[f]=(d&255)>>>1&1;if(b<<24>>24==0){return}if((a[(c[2424874]|0)+9|0]|0)!=0){return}Vl();return}else if((e|0)==49153){b=c[2113304]|0;a[14168504+b|0]=d;mv(0,b,d&255);return}else if((e|0)==49152){c[2113304]=d&255;return}else if((e|0)==53248){b=c[2418506]|0;c[2424874]=b;a[b+8|0]=d;return}else if((e|0)==57344){e=c[2418506]|0;c[2424874]=e;b=e+10|0;e=a[b]|0;a[b]=d<<24>>24!=0|0;d=c[2424874]|0;b=d+16|0;if((a[b]|e)<<24>>24!=0){return}if((a[d+10|0]|0)==0){return}if((a[d+9|0]|0)==0){return}a[b]=2;if(!(a[635136]|0)){return}b=a[(c[2424874]|0)+11|0]|0;Vk();d=c[2424874]|0;e=a[d+11|0]|0;if(b<<24>>24==e<<24>>24){return}b=c[d+12>>2]|0;if((b|0)==0){return}gf[b&2047](e&255);return}else{return}}function bbK(b){b=b|0;var e=0,f=0,g=0,h=0;e=b&65535;if((b+20480&65535)<14){c[2424878]=9681232;c[2426622]=9622928;if(!((e|0)==45067|(e|0)==45061)){f=0;return f|0}b=(e-45056|0)/6|0;g=b*6|0;h=(d[g+9681280|0]|0)<<16&65536|(d[g+9681279|0]|0)<<8|(d[g+9681278|0]|0)|c[9681260+(b<<2)>>2];c[9681244+(b<<2)>>2]=h;if(h>>>0>=(c[2405735]|0)>>>0){f=0;return f|0}c[9681268+(b<<2)>>2]=1;c[9681236+(b<<2)>>2]=0;f=0;return f|0}else{if((e|0)==49153){f=c[(c[3531464]|0)+4240>>2]&255;return f|0}else if((e|0)==40960){a[9706117]=0;f=a[9758256]|0;return f|0}else{f=0;return f|0}}return 0}function bbL(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((b+20480&65535)<14){TI(0,e-45056|0,d&255);return}if((e|0)==49153){b=c[2113304]|0;a[14168504+b|0]=d;mv(0,b,d&255);return}else if((e|0)==49152){c[2113304]=d&255;return}else{return}}function bbM(b){b=b|0;var d=0,e=0,f=0,g=0;d=b&65535;if((b+1536&65535)>=48){if(b<<16>>16!=-2047){e=0;return e|0}e=c[(c[3531464]|0)+4240>>2]&255;return e|0}if(b<<16>>16==-1536){a[9706117]=0}b=d-64e3|0;c[2426862]=9674384;if((d|0)==64046){f=58852}else if((d|0)==64041){e=(c[2418664]<<1|c[2418653]|c[2418675]<<2|c[2418686]<<3)&255;return e|0}do{if((f|0)==58852){if((c[2418596]&1|0)==0){break}d=c[2418655]|0;g=(d>>>16)+(c[2418650]|0)+(c[2418651]<<16)|0;c[2418655]=d+65536;if(g>>>0>(c[2418646]|0)>>>0){e=0;return e|0}e=a[(c[2418645]|0)+g|0]|0;return e|0}}while(0);e=c[9674388+(b<<2)>>2]&255;return e|0}function bbN(b,d){b=b|0;d=d|0;var e=0,f=0;e=b&65535;if((b+1536&65535)<48){TO(e-64e3|0,d);return}if((e|0)==63488){c[2113304]=d&255;return}else if((e|0)==64512){if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){b=gfc(100)|0;f=(c[2433530]|0)+b|0}else{f=(c[2433530]|0)+100|0}c[2433530]=f;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12;return}else if((e|0)==63489){e=c[2113304]|0;a[14168504+e|0]=d;mv(0,e,d&255);return}else{return}}function bbO(b,d){b=b|0;d=d|0;var e=0,f=0;e=b&65535;if((b+1024&65535)<48){TO(e-64512|0,d);return}switch(e|0){case 63489:case 63505:{e=c[2113304]|0;a[14168504+e|0]=d;mv(0,e,d&255);return};case 63488:case 63504:{c[2113304]=d&255;return};case 64e3:{if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){d=gfc(100)|0;f=(c[2433530]|0)+d|0}else{f=(c[2433530]|0)+100|0}c[2433530]=f;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12;return};default:{return}}}function bbP(b){b=b|0;var d=0,e=0,f=0,g=0;d=b&65535;if((b+1024&65535)>=48){if(!((d|0)==63489|(d|0)==63505)){e=0;return e|0}e=c[(c[3531464]|0)+4240>>2]&255;return e|0}if(b<<16>>16==-1024){a[9706117]=0}b=d-64512|0;c[2426862]=9674384;if((d|0)==64553){e=(c[2418664]<<1|c[2418653]|c[2418675]<<2|c[2418686]<<3)&255;return e|0}else if((d|0)==64558){f=58904}do{if((f|0)==58904){if((c[2418596]&1|0)==0){break}d=c[2418655]|0;g=(d>>>16)+(c[2418650]|0)+(c[2418651]<<16)|0;c[2418655]=d+65536;if(g>>>0>(c[2418646]|0)>>>0){e=0;return e|0}e=a[(c[2418645]|0)+g|0]|0;return e|0}}while(0);e=c[9674388+(b<<2)>>2]&255;return e|0}function bbQ(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((b+16384&65535)<48){TO(e-49152|0,d);return}if((e|0)==40960){c[2113304]=d&255;return}else if((e|0)==40961){e=c[2113304]|0;a[14168504+e|0]=d;mv(0,e,d&255);return}else{return}}function bbR(b){b=b|0;var d=0,e=0,f=0,g=0;d=b&65535;if((b+16384&65535)>=48){if(b<<16>>16!=-24575){e=0;return e|0}e=c[(c[3531464]|0)+4240>>2]&255;return e|0}if(b<<16>>16==-16384){a[9706117]=0}b=d-49152|0;c[2426862]=9674384;if((d|0)==49198){f=58932}else if((d|0)==49193){e=(c[2418664]<<1|c[2418653]|c[2418675]<<2|c[2418686]<<3)&255;return e|0}do{if((f|0)==58932){if((c[2418596]&1|0)==0){break}d=c[2418655]|0;g=(d>>>16)+(c[2418650]|0)+(c[2418651]<<16)|0;c[2418655]=d+65536;if(g>>>0>(c[2418646]|0)>>>0){e=0;return e|0}e=a[(c[2418645]|0)+g|0]|0;return e|0}}while(0);e=c[9674388+(b<<2)>>2]&255;return e|0}function bbS(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7112540+(b*112|0)>>2];c[a+104>>2]=c[7112544+(b*112|0)>>2];c[a+108>>2]=c[7112548+(b*112|0)>>2];d=0;return d|0}function bbT(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=7112440+(b*112|0);e=0;return e|0}function bbU(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>35){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6030208+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function bbV(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>38){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7114232+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function bbW(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0;e=i;i=i+1360|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;B=e+1200|0;C=e+1312|0;D=e+1320|0;c[2426818]=0;c[2388038]=0;c[2385848]=393216;c[3527284]=425984;c[2438732]=557056;c[3529498]=688128;c[2443400]=1736704;c[2405720]=3833856;c[2388060]=3833856;c[2385866]=3850240;c[2439626]=3852288;c[2411882]=3856384;c[2407018]=3856384;c[3530202]=3860480;c[2438740]=3864576;c[2405828]=4388864;c[3529600]=6486016;E=0;while(1){if((E|0)>=1024){break}F=9638528+(E<<2)|0;if((c[F>>2]|0)==0){G=58974;break}else{E=E+1|0}}do{if((G|0)==58974){E=gGq(10680320)|0;c[F>>2]=E;if((E|0)==0){break}c[2426818]=E;gGz(E|0,0,10680320);c[2388038]=E;c[2385848]=E+393216;c[3527284]=E+425984;c[2438732]=E+557056;H=E+688128|0;c[3529498]=H;c[2443400]=E+1736704;I=E+3833856|0;c[2405720]=I;c[2388060]=I;c[2385866]=E+3850240;c[2439626]=E+3852288;I=E+3856384|0;c[2411882]=I;c[2407018]=I;c[3530202]=E+3860480;c[2438740]=E+3864576;c[2405828]=E+4388864;c[3529600]=E+6486016;c[2414434]=E+10680320;E=0;while(1){if((E|0)>=1024){J=0;break}K=9638528+(E<<2)|0;if((c[K>>2]|0)==0){G=58979;break}else{E=E+1|0}}do{if((G|0)==58979){E=gGq(24576)|0;c[K>>2]=E;if((E|0)==0){J=0;break}gGz(E|0,0,24576);J=E}}while(0);c[3529062]=J;c[2438700]=1048575;c[3529060]=H;a[7461784]=1;gGz(9726816,0,12);gGz(9726800,0,12);c[2429638]=0;c[2437692]=6;E=c[2443400]|0;c[2438136]=0;I=0;while(1){if((I|0)>=1024){L=0;break}M=9638528+(I<<2)|0;if((c[M>>2]|0)==0){G=58984;break}else{I=I+1|0}}do{if((G|0)==58984){I=gGq(1024)|0;c[M>>2]=I;if((I|0)==0){L=0;break}gGz(I|0,0,1024);L=I}}while(0);c[3529066]=L;c[2438702]=2097151;c[3529064]=E;a[7461792]=1;c[2438136]=0;c[2437694]=16;if((R6((c[2388038]|0)+1|0,0,2)|0)!=0){N=1;i=e;return N|0}if((R6(c[2388038]|0,1,2)|0)!=0){N=1;i=e;return N|0}if((R6((c[2388038]|0)+262145|0,2,2)|0)!=0){N=1;i=e;return N|0}if((R6((c[2388038]|0)+262144|0,3,2)|0)!=0){N=1;i=e;return N|0}I=c[2385848]|0;if((c[3542200]|0)==0){N=1;i=e;return N|0}H=B+108|0;c[H>>2]=0;O=B+100|0;c[O>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](B,4)|0;do{if((c[H>>2]|0)!=0){P=c[O>>2]|0;c[C>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](C,4,0)|0;if((P|0)<1){N=1;i=e;return N|0}if((gzL(I,0,4)|0)==0){break}else{N=1}i=e;return N|0}}while(0);I=c[3529498]|0;if((c[3542200]|0)==0){N=1;i=e;return N|0}O=z+108|0;c[O>>2]=0;H=z+100|0;c[H>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,5)|0;do{if((c[O>>2]|0)!=0){E=c[H>>2]|0;c[A>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](A,5,0)|0;if((E|0)<1){N=1;i=e;return N|0}if((gzL(I,0,5)|0)==0){break}else{N=1}i=e;return N|0}}while(0);I=(c[3529498]|0)+524288|0;if((c[3542200]|0)==0){N=1;i=e;return N|0}H=x+108|0;c[H>>2]=0;O=x+100|0;c[O>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,6)|0;do{if((c[H>>2]|0)!=0){E=c[O>>2]|0;c[y>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](y,6,0)|0;if((E|0)<1){N=1;i=e;return N|0}if((gzL(I,0,6)|0)==0){break}else{N=1}i=e;return N|0}}while(0);I=c[3529498]|0;bec(I,524288);bed(I,1048576);O=c[2405828]|0;H=0;while(1){E=H<<6;gGz(O+E|0,0,64);P=H<<8;Q=0;do{R=1<<3-Q;S=(c[611632+(Q<<2)>>2]|0)+P|0;T=0;do{U=S+(c[1183816+(T<<2)>>2]|0)|0;V=(T<<3)+E|0;W=0;do{X=U+(c[614800+(W<<2)>>2]|0)|0;if((d[I+((X|0)/8|0)|0]&128>>>((X&7)>>>0)|0)!=0){X=O+(V+W)|0;a[X]=(d[X]|R)&255}W=W+1|0;}while((W|0)<8);T=T+1|0;}while((T|0)<8);Q=Q+1|0;}while((Q|0)<4);Q=H+1|0;if((Q|0)<32768){H=Q}else{Y=0;break}}while(1){if((Y|0)>=1024){Z=0;break}_=9638528+(Y<<2)|0;if((c[_>>2]|0)==0){G=59014;break}else{Y=Y+1|0}}do{if((G|0)==59014){H=gGq(2097408)|0;c[_>>2]=H;if((H|0)==0){Z=0;break}gGz(H|0,0,2097408);Z=H}}while(0);c[3529550]=Z;H=c[2443400]|0;if((c[3542200]|0)==0){N=1;i=e;return N|0}O=v+108|0;c[O>>2]=0;I=v+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,7)|0;do{if((c[O>>2]|0)!=0){Q=c[I>>2]|0;c[w>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](w,7,0)|0;if((Q|0)<1){N=1;i=e;return N|0}if((gzL(H,0,7)|0)==0){break}else{N=1}i=e;return N|0}}while(0);H=(c[2443400]|0)+524288|0;if((c[3542200]|0)==0){N=1;i=e;return N|0}I=t+108|0;c[I>>2]=0;O=t+100|0;c[O>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,8)|0;do{if((c[I>>2]|0)!=0){Q=c[O>>2]|0;c[u>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](u,8,0)|0;if((Q|0)<1){N=1;i=e;return N|0}if((gzL(H,0,8)|0)==0){break}else{N=1}i=e;return N|0}}while(0);H=(c[2443400]|0)+1048576|0;if((c[3542200]|0)==0){N=1;i=e;return N|0}O=r+108|0;c[O>>2]=0;I=r+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,9)|0;do{if((c[O>>2]|0)!=0){Q=c[I>>2]|0;c[s>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](s,9,0)|0;if((Q|0)<1){N=1;i=e;return N|0}if((gzL(H,0,9)|0)==0){break}else{N=1}i=e;return N|0}}while(0);H=(c[2443400]|0)+1572864|0;if((c[3542200]|0)==0){N=1;i=e;return N|0}I=p+108|0;c[I>>2]=0;O=p+100|0;c[O>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,10)|0;do{if((c[I>>2]|0)!=0){Q=c[O>>2]|0;c[q>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](q,10,0)|0;if((Q|0)<1){N=1;i=e;return N|0}if((gzL(H,0,10)|0)==0){break}else{N=1}i=e;return N|0}}while(0);H=c[2443400]|0;bec(H,1048576);bed(H,2097152);H=(c[3529550]|0)+2097152|0;do{if((c[3542200]|0)!=0){O=n+108|0;c[O>>2]=0;I=n+100|0;c[I>>2]=0;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Q&16383](n,11)|0;if((c[O>>2]|0)==0){break}O=c[I>>2]|0;c[o>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](o,11,0)|0;if((O|0)<1){break}gzL(H,0,11)|0}}while(0);H=c[3529550]|0;O=c[2443400]|0;gGC(H|0,O|0,2097152)|0;I=D|0;Q=D+4|0;E=D+8|0;P=D+12|0;T=D+16|0;R=D+20|0;S=D+24|0;W=D+28|0;V=D+32|0;U=D+36|0;X=0;do{$=d[H+(X>>>11&255|2097152)|0]|0;c[I>>2]=X&1;c[Q>>2]=X>>>1&1;c[E>>2]=X>>>2&1;c[P>>2]=X>>>3&1;c[T>>2]=X>>>4&1;c[R>>2]=X>>>5&1;c[S>>2]=X>>>6&1;c[W>>2]=X>>>7&1;c[V>>2]=X>>>8&1;c[U>>2]=X>>>9&1;aa=$&7;$=(c[D+(d[595272+aa|0]<<2)>>2]|X&523264|c[D+(d[595280+aa|0]<<2)>>2]<<1|c[D+(d[595288+aa|0]<<2)>>2]<<2|c[D+(d[595296+aa|0]<<2)>>2]<<3|c[D+(d[595304+aa|0]<<2)>>2]<<4|c[D+(d[595312+aa|0]<<2)>>2]<<5|c[D+(d[595320+aa|0]<<2)>>2]<<6|c[D+(d[595328+aa|0]<<2)>>2]<<7|c[D+(d[595336+aa|0]<<2)>>2]<<8|c[D+(d[595344+aa|0]<<2)>>2]<<9)<<2;aa=X<<2;a[O+aa|0]=a[H+$|0]|0;a[O+(aa|1)|0]=a[H+($|1)|0]|0;a[O+(aa|2)|0]=a[H+($|2)|0]|0;a[O+(aa|3)|0]=a[H+($|3)|0]|0;X=X+1|0;}while((X|0)<524288);X=c[3529600]|0;H=0;do{U=H<<8;gGz(X+U|0,0,256);V=H<<10;W=0;do{S=1<<3-W;R=(c[611632+(W<<2)>>2]|0)+V|0;T=0;do{P=R+(c[3946808+(T<<2)>>2]|0)|0;E=(T<<4)+U|0;Q=0;do{I=P+(c[6669416+(Q<<2)>>2]|0)|0;if((d[O+((I|0)/8|0)|0]&128>>>((I&7)>>>0)|0)!=0){I=X+(E+Q)|0;a[I]=(d[I]|S)&255}Q=Q+1|0;}while((Q|0)<16);T=T+1|0;}while((T|0)<16);W=W+1|0;}while((W|0)<4);H=H+1|0;}while((H|0)<16384);H=c[3527284]|0;if((c[3542200]|0)==0){N=1;i=e;return N|0}X=l+108|0;c[X>>2]=0;O=l+100|0;c[O>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,13)|0;do{if((c[X>>2]|0)!=0){W=c[O>>2]|0;c[m>>2]=9534384;U=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[U&16383](m,13,0)|0;if((W|0)<1){N=1;i=e;return N|0}if((gzL(H,0,13)|0)==0){break}else{N=1}i=e;return N|0}}while(0);H=c[2438732]|0;if((c[3542200]|0)==0){N=1;i=e;return N|0}O=j+108|0;c[O>>2]=0;X=j+100|0;c[X>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,14)|0;do{if((c[O>>2]|0)!=0){W=c[X>>2]|0;c[k>>2]=9534384;U=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[U&16383](k,14,0)|0;if((W|0)<1){N=1;i=e;return N|0}if((gzL(H,0,14)|0)==0){break}else{N=1}i=e;return N|0}}while(0);H=c[3529550]|0;gGz(H|0,0,524288);if((c[3542200]|0)==0){N=1;i=e;return N|0}X=f+108|0;c[X>>2]=0;O=f+100|0;c[O>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,15)|0;do{if((c[X>>2]|0)!=0){W=c[O>>2]|0;c[g>>2]=9534384;U=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[U&16383](g,15,0)|0;if((W|0)<1){N=1;i=e;return N|0}if((gzL(H,0,15)|0)==0){break}else{N=1}i=e;return N|0}}while(0);H=c[3529550]|0;O=c[2438740]|0;X=0;while(1){W=X<<1;U=d[H+(W|1)|0]|0;b[O+(X<<1)>>1]=((U<<8|d[H+W|0])>>>3&1023)-512<<(U>>>5)-3&65535;U=X+1|0;if((U|0)<262144){X=U}else{ab=0;break}}while(1){if((ab|0)>=1024){break}ac=9638528+(ab<<2)|0;if((c[ac>>2]|0)==(H|0)){G=59064;break}else{ab=ab+1|0}}if((G|0)==59064){gGr(H);c[ac>>2]=0}c[3529550]=0;fxU(0,425984);if((c[2394]|0)==0){ad=c[2112932]|0}else{c[2394]=0;X=c[3532596]|0;c[2112932]=X;O=c[3532592]|0;if((O|0)!=0){gGC(9104152,O|0,280)|0}c[2113054]=c[2113060];ad=X}X=c[2388038]|0;O=ad|0;U=0;while(1){W=X+U|0;c[O>>2]=W;c[O+131072>>2]=W;W=U+1024|0;if(W>>>0>393215){break}else{O=O+4|0;U=W}}U=c[2388060]|0;c[ad+1536>>2]=U;c[ad+67072>>2]=U;c[ad+132608>>2]=U;O=U+1024|0;c[ad+1540>>2]=O;c[ad+67076>>2]=O;c[ad+132612>>2]=O;O=U+2048|0;c[ad+1544>>2]=O;c[ad+67080>>2]=O;c[ad+132616>>2]=O;O=U+3072|0;c[ad+1548>>2]=O;c[ad+67084>>2]=O;c[ad+132620>>2]=O;O=U+4096|0;c[ad+1552>>2]=O;c[ad+67088>>2]=O;c[ad+132624>>2]=O;O=U+5120|0;c[ad+1556>>2]=O;c[ad+67092>>2]=O;c[ad+132628>>2]=O;O=U+6144|0;c[ad+1560>>2]=O;c[ad+67096>>2]=O;c[ad+132632>>2]=O;O=U+7168|0;c[ad+1564>>2]=O;c[ad+67100>>2]=O;c[ad+132636>>2]=O;O=U+8192|0;c[ad+1568>>2]=O;c[ad+67104>>2]=O;c[ad+132640>>2]=O;O=U+9216|0;c[ad+1572>>2]=O;c[ad+67108>>2]=O;c[ad+132644>>2]=O;O=U+10240|0;c[ad+1576>>2]=O;c[ad+67112>>2]=O;c[ad+132648>>2]=O;O=U+11264|0;c[ad+1580>>2]=O;c[ad+67116>>2]=O;c[ad+132652>>2]=O;O=U+12288|0;c[ad+1584>>2]=O;c[ad+67120>>2]=O;c[ad+132656>>2]=O;O=U+13312|0;c[ad+1588>>2]=O;c[ad+67124>>2]=O;c[ad+132660>>2]=O;O=U+14336|0;c[ad+1592>>2]=O;c[ad+67128>>2]=O;c[ad+132664>>2]=O;O=U+15360|0;c[ad+1596>>2]=O;c[ad+67132>>2]=O;c[ad+132668>>2]=O;O=c[2439626]|0;c[ad+2048>>2]=O;c[ad+67584>>2]=O;c[ad+133120>>2]=O;U=O+1024|0;c[ad+2052>>2]=U;c[ad+67588>>2]=U;c[ad+133124>>2]=U;U=O+2048|0;c[ad+2056>>2]=U;c[ad+67592>>2]=U;c[ad+133128>>2]=U;U=O+3072|0;c[ad+2060>>2]=U;c[ad+67596>>2]=U;c[ad+133132>>2]=U;c[ad+196688>>2]=2556;c[ad+196728>>2]=278;c[ad+196608>>2]=734;c[ad+196648>>2]=1692;U=c[3532592]|0;if((U|0)!=0){gGC(U|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);U=c[2439330]|0;O=(U|0)==0;if(!O){X=U;gGC(9706056,X|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];X=c[3528484]|0;c[2076596]=X;H=c[2417276]|0;c[3541536]=H;c[1836236]=0;c[U+4180>>2]=1094;c[U+4184>>2]=2222;W=c[2385848]|0;V=0;T=0;while(1){c[U+76+(T<<2)>>2]=W+(T<<8);S=V+1&65535;if((S&65535)>127){ae=0;af=0;break}else{V=S;T=S&65535}}while(1){T=W+(af<<8)|0;c[U+76+(af+512<<2)>>2]=T;c[U+76+(af+768<<2)>>2]=T;T=ae+1&65535;if((T&65535)>127){break}else{ae=T;af=T&65535}}W=c[2385866]|0;c[U+588>>2]=W;T=W+256|0;c[U+592>>2]=T;V=W+512|0;c[U+596>>2]=V;S=W+768|0;c[U+600>>2]=S;R=W+1024|0;c[U+604>>2]=R;Q=W+1280|0;c[U+608>>2]=Q;E=W+1536|0;c[U+612>>2]=E;P=W+1792|0;c[U+616>>2]=P;c[U+1612>>2]=W;c[U+1616>>2]=T;c[U+1620>>2]=V;c[U+1624>>2]=S;c[U+1628>>2]=R;c[U+1632>>2]=Q;c[U+1636>>2]=E;c[U+1640>>2]=P;c[U+2636>>2]=W;c[U+3660>>2]=W;c[U+2640>>2]=T;c[U+3664>>2]=T;c[U+2644>>2]=V;c[U+3668>>2]=V;c[U+2648>>2]=S;c[U+3672>>2]=S;c[U+2652>>2]=R;c[U+3676>>2]=R;c[U+2656>>2]=Q;c[U+3680>>2]=Q;c[U+2660>>2]=E;c[U+3684>>2]=E;c[U+2664>>2]=P;c[U+3688>>2]=P;if(!O){P=U;gGC(P|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=X;c[2417276]=H;c[1836236]=-1;P=a[9680]|0;E=P?32e3:0;if(P){if(a[9624]|0){P=E*3|0;Q=55930;while(1){if((Q|0)>(P|0)){Q=Q>>1}else{ah=1222;ai=Q;break}}}else{ah=2462;ai=E}c[2429380]=ai;c[3542124]=ah;mw(3579545,ai);Q=gGq(262144)|0;c[2406684]=Q;gGz(Q|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(3579545,11025)}h[745421]=1.0;c[2436794]=3;h[745420]=1.0;c[2436792]=3;TJ(0,c[3527284]|0,131072);c[2424878]=9681232;c[2405736]=152;h[1202869]=.33;c[2405742]=3;c[2426622]=9622928;h[1202870]=.33;c[2405743]=3;Q=c[2438732]|0;P=gGq(80)|0;H=P;c[2418506]=H;c[2424874]=H;gGz(P|0,0,80);a[635136]=0;c[P+4>>2]=~~(16.0e4/(a[9680]|0?32.0e3:0.0)*4194304.0);a[P+16|0]=0;if((Q|0)==0){a[635136]=1}else{c[P+52>>2]=Q}a[P+9|0]=1;a[(c[2424874]|0)+10|0]=1;Q=c[2424874]|0;h[Q+64>>3]=1.0;c[Q+72>>2]=3;Vl();c[2424874]=H;h[P+64>>3]=.6;c[P+72>>2]=3;h[413063]=1.0;a[725152]=1;P=c[642608+(c[2436]<<2)>>2]|0;H=c[P+128>>2]|0;if((c[P+52>>2]&4|0)==0){c[2113068]=H;Q=c[P+132>>2]|0;c[2113070]=Q;c[2443814]=H;c[2440436]=Q;aj=H;ak=Q}else{c[2113070]=H;Q=c[P+132>>2]|0;c[2113068]=Q;c[2440436]=H;c[2443814]=Q;aj=Q;ak=H}H=ag(aj<<1,ak)|0;Q=gGq(H)|0;c[2112926]=Q;if((Q|0)!=0){gGz(Q|0,0,H|0)}c[2437650]=0;c[2437651]=32;c[2437652]=40;c[2433324]=16;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];H=c[3532592]|0;if((H|0)!=0){gGC(9104152,H|0,280)|0}c[2113054]=c[2113060]}RI();H=c[2394]|0;Q=c[14130368+(H<<2)>>2]|0;if((Q|0)!=0){gGC(Q|0,9104152,280)|0}c[8452240+(H<<2)>>2]=c[2113054];c[2394]=-1;H=c[2439330]|0;Q=(H|0)==0;if(!Q){P=H;gGC(9706056,P|0,76)|0}P=c[2438118]|0;c[2433530]=P;X=c[3528484]|0;c[2076596]=X;U=c[2417276]|0;c[3541536]=U;c[1836236]=0;gGz(9706056,0,76);if(!Q){Q=H;gGC(Q|0,9706056,76)|0}c[2438118]=P;c[3528484]=X;c[2417276]=U;c[1836236]=-1;mx(0);blH();a[14115360]=0;a[9758256]=0;c[2436804]=0;c[2437026]=0;h[615974]=0.0;c[2442970]=0;Vl();U=c[2418506]|0;c[2424874]=U;X=U+10|0;P=a[X]|0;a[X]=0;X=c[2424874]|0;Q=X+16|0;do{if((a[Q]|P)<<24>>24==0){if((a[X+10|0]|0)==0){al=U;break}if((a[X+9|0]|0)==0){al=U;break}a[Q]=2;if(!(a[635136]|0)){al=U;break}H=a[(c[2424874]|0)+11|0]|0;Vk();O=c[2424874]|0;R=a[O+11|0]|0;if(H<<24>>24==R<<24>>24){al=U;break}H=c[O+12>>2]|0;if((H|0)==0){al=U;break}gf[H&2047](R&255);al=c[2418506]|0}else{al=U}}while(0);c[2424874]=al;U=al+9|0;Q=a[U]|0;a[U]=1;if(Q<<24>>24==0){N=0;i=e;return N|0}if((a[(c[2424874]|0)+9|0]|0)!=0){N=0;i=e;return N|0}Vl();N=0;i=e;return N|0}}while(0);c[2426818]=0;N=1;i=e;return N|0}function bbX(){var b=0,d=0,e=0,f=0,g=0;b=c[2418506]|0;if((b|0)!=0){gGr(b);c[2418506]=0}b=c[2418507]|0;if((b|0)!=0){gGr(b);c[2418507]=0}a[635136]=0;b=c[2424800]|0;if((b|0)!=0){gGr(b);c[2424800]=0}b=c[2418166]|0;if((b|0)!=0){gGr(b);c[2418166]=0}fwZ();if((c[2392]|0)>=0){b=0;do{d=14130368+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}d=14130384+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}b=b+1|0;}while((b|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;b=c[3531464]|0;c[b+44344>>2]=0;c[b+44348>>2]=0;if((b|0)!=0){gGr(b);c[3531464]=0}b=c[2406684]|0;if((b|0)!=0){gGr(b);c[2406684]=0}c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}blI();b=c[2426818]|0;d=0;while(1){if((d|0)>=1024){break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==(b|0)){g=59177;break}else{d=d+1|0}}if((g|0)==59177){gGr(b);c[f>>2]=0}c[2426818]=0;a[14115360]=0;a[9758256]=0;c[2436804]=0;c[2437026]=0;h[615974]=0.0;c[2433324]=0;gGz(9750600,0,3);gGz(9623120,0,3);c[2442970]=0;c[2443506]=0;c[2430236]=0;c[2429778]=0;a[9545176]=0;c[2437706]=0;return 0}function bbY(){var d=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0.0,z=0.0,A=0.0,B=0.0,C=0.0,D=0,E=0,F=0.0,G=0,H=0;d=a[9688]|0?534:0;do{if((a[9625080]|0)!=0){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060]}RI();f=c[2394]|0;g=c[14130368+(f<<2)>>2]|0;if((g|0)!=0){gGC(g|0,9104152,280)|0}c[8452240+(f<<2)>>2]=c[2113054];c[2394]=-1;f=c[2439330]|0;g=(f|0)==0;if(!g){i=f;gGC(9706056,i|0,76)|0}i=c[2438118]|0;c[2433530]=i;j=c[3528484]|0;c[2076596]=j;k=c[2417276]|0;c[3541536]=k;c[1836236]=0;gGz(9706056,0,76);if(!g){g=f;gGC(g|0,9706056,76)|0}c[2438118]=i;c[3528484]=j;c[2417276]=k;c[1836236]=-1;mx(0);blH();a[14115360]=0;a[9758256]=0;c[2436804]=0;c[2437026]=0;h[615974]=0.0;c[2442970]=0;Vl();k=c[2418506]|0;c[2424874]=k;j=k+10|0;i=a[j]|0;a[j]=0;j=c[2424874]|0;g=j+16|0;do{if((a[g]|i)<<24>>24==0){if((a[j+10|0]|0)==0){l=k;break}if((a[j+9|0]|0)==0){l=k;break}a[g]=2;if(!(a[635136]|0)){l=k;break}f=a[(c[2424874]|0)+11|0]|0;Vk();m=c[2424874]|0;n=a[m+11|0]|0;if(f<<24>>24==n<<24>>24){l=k;break}f=c[m+12>>2]|0;if((f|0)==0){l=k;break}gf[f&2047](n&255);l=c[2418506]|0}else{l=k}}while(0);c[2424874]=l;k=l+9|0;g=a[k]|0;a[k]=1;if(g<<24>>24==0){break}if((a[(c[2424874]|0)+9|0]|0)!=0){break}Vl()}}while(0);bdX();c[2440552]=133333;c[2440494]=59659;c[2444121]=0;c[2444120]=0;l=c[2392]|0;if((l|0)>=0){gGz(8452240,0,((l|0)>0?(l<<2)+4|0:4)|0)}c[2113054]=0;l=c[2385548]|0;if((l|0)>0){gGz(9752472,0,((l|0)>1?l<<2:4)|0)}c[2433530]=0;l=d-1|0;g=0;k=0;L76357:while(1){j=k;while(1){if((j|0)>=(d|0)){break L76357}if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];i=c[3532592]|0;if((i|0)!=0){gGC(9104152,i|0,280)|0}c[2113054]=c[2113060]}o=j+1|0;i=(ag(c[2440552]|0,o)|0)/534|0;n=i-(c[2444120]|0)|0;c[2438210]=n;c[2113056]=n;i=RG(n)|0;c[2113054]=(c[2113054]|0)+i;c[2276108]=-1;c[2113056]=-1;c[2444120]=(c[2444120]|0)+i;do{if((j|0)==(l|0)&(a[14115360]|0)!=0){c[8452200+(c[2394]<<2)>>2]=8197;c[2276080]=1280;if((c[2276079]|0)>>>0>=1280){break}RH(5)}}while(0);i=c[2394]|0;n=c[14130368+(i<<2)>>2]|0;if((n|0)!=0){gGC(n|0,9104152,280)|0}c[8452240+(i<<2)>>2]=c[2113054];c[2394]=-1;i=c[2439330]|0;if((i|0)!=0){n=i;gGC(9706056,n|0,76)|0}b[4853030]=c[2426515]&65535;n=c[2438118]|0;c[2433530]=n;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;f=(ag(c[2440494]|0,o)|0)/534|0;m=c[2444121]|0;p=f-m|0;c[2438210]=p;do{if((p|0)<1){q=0;r=m;s=0;t=i;u=n}else{if((a[i+4188|0]|0)==0){f=gfc(p)|0;v=(c[2433530]|0)+f|0;c[2433530]=v;w=c[1836236]|0;q=f;r=c[2444121]|0;s=w;t=c[9757320+(w<<2)>>2]|0;u=v;break}else{v=n+p|0;c[2433530]=v;q=p;r=m;s=0;t=i;u=v;break}}}while(0);c[2438210]=q;c[2444121]=r+q;if((t|0)!=0){i=t;gGC(i|0,9706056,76)|0}c[9752472+(s<<2)>>2]=u;c[14113936+(s<<2)>>2]=c[2076596];c[9669104+(s<<2)>>2]=c[3541536];c[1836236]=-1;x=c[2112964]|0;if((x|0)==0){j=o}else{break}}j=a[9688]|0;i=j&1;m=g<<1;p=x+(m<<1)|0;gg[c[3542124]&4095](p,i);TH(0,p,i);Vj(0,p,i);if((c[2437026]|0)!=0){y=+h[615974];z=2.0e4/(a[9680]|0?32.0e3:0.0);if(y>262143.0|j^1){A=y}else{j=a[725152]|0?3:0;p=(j&1|0)==0;n=(j&2|0)==0;j=c[2438740]|0;B=+h[413063];v=0;C=y;while(1){w=b[j+(~~C<<1)>>1]|0;if(p){D=0}else{D=~~(+(w<<16>>16|0)*B)<<16>>16}if(n){E=0}else{E=~~(+(w<<16>>16|0)*B)<<16>>16}w=x+(v+m<<1)|0;b[w>>1]=(e[w>>1]|0)+D&65535;w=x+((v|1)+m<<1)|0;b[w>>1]=(e[w>>1]|0)+E&65535;y=z+C;w=v+2|0;if((w|0)>=(i|0)|y>262143.0){A=y;break}else{v=w;C=y}}}h[615974]=A}g=i+g|0;k=o}o=c[2112964]|0;do{if((o|0)!=0){k=a[9688]|0?534:0;E=k-g|0;x=g<<1;D=o+(x<<1)|0;if((k|0)==(g|0)){break}gg[c[3542124]&4095](D,E);TH(0,D,E);Vj(0,D,E);if((c[2437026]|0)==0){break}A=+h[615974];C=2.0e4/(a[9680]|0?32.0e3:0.0);if((E|0)<1|A>262143.0){F=A}else{D=a[725152]|0?3:0;k=(D&1|0)==0;s=(D&2|0)==0;D=c[2438740]|0;z=+h[413063];u=0;B=A;while(1){t=b[D+(~~B<<1)>>1]|0;if(k){G=0}else{G=~~(+(t<<16>>16|0)*z)<<16>>16}if(s){H=0}else{H=~~(+(t<<16>>16|0)*z)<<16>>16}t=o+(u+x<<1)|0;b[t>>1]=(e[t>>1]|0)+G&65535;t=o+((u|1)+x<<1)|0;b[t>>1]=(e[t>>1]|0)+H&65535;A=C+B;t=u+2|0;if((t|0)>=(E|0)|A>262143.0){F=A;break}else{u=t;B=A}}}h[615974]=F}}while(0);if((c[2112968]|0)==0){return 0}bd5();return 0}function bbZ(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0;d=i;i=i+80|0;e=d|0;f=d+32|0;if((a&64|0)==0){bd1(a,b);i=d;return 0}fw$(a);g=d+48|0;h=(b|0)==0;if(!h){c[b>>2]=169619}cC(g|0,170224,(j=i,i=i+8|0,c[j>>2]=0,j)|0)|0;i=j;c[f>>2]=9699512;c[f+4>>2]=64;c[f+8>>2]=0;c[f+12>>2]=g;gj[c[2076592]&4095](f)|0;f=d+16|0;if(!h){c[b>>2]=169600}c[2424874]=c[2418506];cC(f|0,100600,(j=i,i=i+8|0,c[j>>2]=0,j)|0)|0;i=j;c[e>>2]=9699496;c[e+4>>2]=80;c[e+8>>2]=0;c[e+12>>2]=f;gj[c[2076592]&4095](e)|0;bd1(a,b);i=d;return 0}function bb_(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6663948+(b*112|0)>>2];c[a+104>>2]=c[6663952+(b*112|0)>>2];c[a+108>>2]=c[6663956+(b*112|0)>>2];d=0;return d|0}function bb$(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=6663848+(b*112|0);e=0;return e|0}function bb0(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6028516+(b*112|0)>>2];c[a+104>>2]=c[6028520+(b*112|0)>>2];c[a+108>>2]=c[6028524+(b*112|0)>>2];d=0;return d|0}function bb1(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=6028416+(b*112|0);e=0;return e|0}function bb2(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7114804+(b*112|0)>>2];c[a+104>>2]=c[7114808+(b*112|0)>>2];c[a+108>>2]=c[7114812+(b*112|0)>>2];d=0;return d|0}function bb3(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=7114704+(b*112|0);e=0;return e|0}function bb4(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6667532+(b*112|0)>>2];c[a+104>>2]=c[6667536+(b*112|0)>>2];c[a+108>>2]=c[6667540+(b*112|0)>>2];d=0;return d|0}function bb5(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=6667432+(b*112|0);e=0;return e|0}function bb6(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6665740+(b*112|0)>>2];c[a+104>>2]=c[6665744+(b*112|0)>>2];c[a+108>>2]=c[6665748+(b*112|0)>>2];d=0;return d|0}function bb7(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=6665640+(b*112|0);e=0;return e|0}function bb8(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6031548+(b*112|0)>>2];c[a+104>>2]=c[6031552+(b*112|0)>>2];c[a+108>>2]=c[6031556+(b*112|0)>>2];d=0;return d|0}function bb9(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=6031448+(b*112|0);e=0;return e|0}function bca(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3304152+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function bcb(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>54){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6030784+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function bcc(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4925676+(b*112|0)>>2];c[a+104>>2]=c[4925680+(b*112|0)>>2];c[a+108>>2]=c[4925684+(b*112|0)>>2];d=0;return d|0}function bcd(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=4925576+(b*112|0);e=0;return e|0}function bce(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4923884+(b*112|0)>>2];c[a+104>>2]=c[4923888+(b*112|0)>>2];c[a+108>>2]=c[4923892+(b*112|0)>>2];d=0;return d|0}function bcf(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=4923784+(b*112|0);e=0;return e|0}function bcg(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4922092+(b*112|0)>>2];c[a+104>>2]=c[4922096+(b*112|0)>>2];c[a+108>>2]=c[4922100+(b*112|0)>>2];d=0;return d|0}function bch(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=4921992+(b*112|0);e=0;return e|0}function bci(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7394940+(b*112|0)>>2];c[a+104>>2]=c[7394944+(b*112|0)>>2];c[a+108>>2]=c[7394948+(b*112|0)>>2];d=0;return d|0}function bcj(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=7394840+(b*112|0);e=0;return e|0}function bck(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6850568+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function bcl(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>62){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7396072+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function bcm(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;e=i;i=i+480|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;c[2426818]=0;c[2388038]=0;c[2385848]=262144;c[3527284]=294912;c[3529498]=425984;c[2443400]=688128;c[2405720]=1736704;c[2388060]=1736704;c[2385866]=1769472;c[2439626]=1771520;c[2411882]=1775616;c[2407018]=1775616;c[3530202]=1779712;c[2405828]=1783808;c[3529600]=2308096;p=0;while(1){if((p|0)>=1024){break}q=9638528+(p<<2)|0;if((c[q>>2]|0)==0){r=59411;break}else{p=p+1|0}}do{if((r|0)==59411){p=gGq(4405248)|0;c[q>>2]=p;if((p|0)==0){break}c[2426818]=p;gGz(p|0,0,4405248);c[2388038]=p;c[2385848]=p+262144;c[3527284]=p+294912;s=p+425984|0;c[3529498]=s;c[2443400]=p+688128;t=p+1736704|0;c[2405720]=t;c[2388060]=t;c[2385866]=p+1769472;c[2439626]=p+1771520;t=p+1775616|0;c[2411882]=t;c[2407018]=t;c[3530202]=p+1779712;c[2405828]=p+1783808;c[3529600]=p+2308096;c[2414434]=p+4405248;p=0;while(1){if((p|0)>=1024){u=0;break}v=9638528+(p<<2)|0;if((c[v>>2]|0)==0){r=59416;break}else{p=p+1|0}}do{if((r|0)==59416){p=gGq(24576)|0;c[v>>2]=p;if((p|0)==0){u=0;break}gGz(p|0,0,24576);u=p}}while(0);c[3529062]=u;c[2438700]=262143;c[3529060]=s;a[7461784]=1;gGz(9726816,0,12);gGz(9726800,0,12);c[2429638]=0;c[2437692]=4;p=c[2443400]|0;c[2438136]=0;t=0;while(1){if((t|0)>=1024){w=0;break}x=9638528+(t<<2)|0;if((c[x>>2]|0)==0){r=59421;break}else{t=t+1|0}}do{if((r|0)==59421){t=gGq(1024)|0;c[x>>2]=t;if((t|0)==0){w=0;break}gGz(t|0,0,1024);w=t}}while(0);c[3529066]=w;c[2438702]=1048575;c[3529064]=p;a[7461792]=1;c[2438136]=0;c[2437694]=26;if((R6((c[2388038]|0)+1|0,0,2)|0)!=0){y=1;i=e;return y|0}if((R6(c[2388038]|0,1,2)|0)!=0){y=1;i=e;return y|0}t=c[2385848]|0;if((c[3542200]|0)==0){y=1;i=e;return y|0}s=n+108|0;c[s>>2]=0;z=n+100|0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,2)|0;do{if((c[s>>2]|0)!=0){A=c[z>>2]|0;c[o>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](o,2,0)|0;if((A|0)<1){y=1;i=e;return y|0}if((gzL(t,0,2)|0)==0){break}else{y=1}i=e;return y|0}}while(0);if((R6(c[3529498]|0,3,2)|0)!=0){y=1;i=e;return y|0}if((R6((c[3529498]|0)+1|0,4,2)|0)!=0){y=1;i=e;return y|0}if((R6((c[3529498]|0)+131072|0,5,2)|0)!=0){y=1;i=e;return y|0}if((R6((c[3529498]|0)+131073|0,6,2)|0)!=0){y=1;i=e;return y|0}t=c[3529498]|0;bec(t,131072);bed(t,262144);z=c[2405828]|0;s=0;while(1){p=s<<6;gGz(z+p|0,0,64);A=s<<8;B=0;do{C=1<<3-B;D=(c[611632+(B<<2)>>2]|0)+A|0;E=0;do{F=D+(c[1183816+(E<<2)>>2]|0)|0;G=(E<<3)+p|0;H=0;do{I=F+(c[614800+(H<<2)>>2]|0)|0;if(((d[t+((I|0)/8|0)|0]|0)&128>>>((I&7)>>>0)|0)!=0){I=z+(G+H)|0;a[I]=(d[I]|0|C)&255}H=H+1|0;}while((H|0)<8);E=E+1|0;}while((E|0)<8);B=B+1|0;}while((B|0)<4);B=s+1|0;if((B|0)<8192){s=B}else{J=0;break}}while(1){if((J|0)>=1024){K=0;break}L=9638528+(J<<2)|0;if((c[L>>2]|0)==0){r=59445;break}else{J=J+1|0}}do{if((r|0)==59445){s=gGq(1048576)|0;c[L>>2]=s;if((s|0)==0){K=0;break}gGz(s|0,0,1048576);K=s}}while(0);c[3529550]=K;s=c[2443400]|0;if((c[3542200]|0)==0){y=1;i=e;return y|0}z=l+108|0;c[z>>2]=0;t=l+100|0;c[t>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,7)|0;do{if((c[z>>2]|0)!=0){B=c[t>>2]|0;c[m>>2]=9534384;p=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[p&16383](m,7,0)|0;if((B|0)<1){y=1;i=e;return y|0}if((gzL(s,0,7)|0)==0){break}else{y=1}i=e;return y|0}}while(0);s=(c[2443400]|0)+524288|0;if((c[3542200]|0)==0){y=1;i=e;return y|0}t=j+108|0;c[t>>2]=0;z=j+100|0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,8)|0;do{if((c[t>>2]|0)!=0){B=c[z>>2]|0;c[k>>2]=9534384;p=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[p&16383](k,8,0)|0;if((B|0)<1){y=1;i=e;return y|0}if((gzL(s,0,8)|0)==0){break}else{y=1}i=e;return y|0}}while(0);s=c[2443400]|0;bec(s,524288);bed(s,1048576);z=c[3529550]|0;gGC(z|0,s|0,1048576)|0;t=0;do{B=t&1;p=t>>>1&1;A=t>>>2&1;E=t>>>4&1;C=t>>>6&1;D=t>>>7&1;if((t&245760|0)==245760){M=p<<3|B<<2|A<<4|E<<5|C<<6|D<<7}else{M=D<<2|B<<3|p<<4|A<<5|E<<6|C<<7}C=(t>>>3&1|t&261888|t>>>5<<1&2|M)<<2;E=t<<2;a[s+E|0]=a[z+C|0]|0;a[s+(E|1)|0]=a[z+(C|1)|0]|0;a[s+(E|2)|0]=a[z+(C|2)|0]|0;a[s+(E|3)|0]=a[z+(C|3)|0]|0;t=t+1|0;}while((t|0)<262144);t=c[3529600]|0;z=0;do{C=z<<8;gGz(t+C|0,0,256);E=z<<10;A=0;do{p=1<<3-A;B=(c[611632+(A<<2)>>2]|0)+E|0;D=0;do{H=B+(c[3946808+(D<<2)>>2]|0)|0;G=(D<<4)+C|0;F=0;do{I=H+(c[6669416+(F<<2)>>2]|0)|0;if(((d[s+((I|0)/8|0)|0]|0)&128>>>((I&7)>>>0)|0)!=0){I=t+(G+F)|0;a[I]=(d[I]|0|p)&255}F=F+1|0;}while((F|0)<16);D=D+1|0;}while((D|0)<16);A=A+1|0;}while((A|0)<4);z=z+1|0;}while((z|0)<8192);z=c[3527284]|0;if((c[3542200]|0)==0){y=1;i=e;return y|0}t=f+108|0;c[t>>2]=0;s=f+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,10)|0;do{if((c[t>>2]|0)!=0){A=c[s>>2]|0;c[g>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](g,10,0)|0;if((A|0)<1){y=1;i=e;return y|0}if((gzL(z,0,10)|0)==0){break}else{y=1}i=e;return y|0}}while(0);z=c[3529550]|0;s=0;while(1){if((s|0)>=1024){break}N=9638528+(s<<2)|0;if((c[N>>2]|0)==(z|0)){r=59477;break}else{s=s+1|0}}if((r|0)==59477){gGr(z);c[N>>2]=0}c[3529550]=0;fxU(0,425984);if((c[2394]|0)==0){O=c[2112932]|0}else{c[2394]=0;s=c[3532596]|0;c[2112932]=s;t=c[3532592]|0;if((t|0)!=0){gGC(9104152,t|0,280)|0}c[2113054]=c[2113060];O=s}s=c[2388038]|0;t=O|0;A=0;while(1){C=s+A|0;c[t>>2]=C;c[t+131072>>2]=C;C=A+1024|0;if(C>>>0>262143){break}else{t=t+4|0;A=C}}A=c[2388060]|0;c[O+1024>>2]=A;c[O+66560>>2]=A;c[O+132096>>2]=A;t=A+1024|0;c[O+1028>>2]=t;c[O+66564>>2]=t;c[O+132100>>2]=t;t=A+2048|0;c[O+1032>>2]=t;c[O+66568>>2]=t;c[O+132104>>2]=t;t=A+3072|0;c[O+1036>>2]=t;c[O+66572>>2]=t;c[O+132108>>2]=t;t=A+4096|0;c[O+1040>>2]=t;c[O+66576>>2]=t;c[O+132112>>2]=t;t=A+5120|0;c[O+1044>>2]=t;c[O+66580>>2]=t;c[O+132116>>2]=t;t=A+6144|0;c[O+1048>>2]=t;c[O+66584>>2]=t;c[O+132120>>2]=t;t=A+7168|0;c[O+1052>>2]=t;c[O+66588>>2]=t;c[O+132124>>2]=t;t=A+8192|0;c[O+1056>>2]=t;c[O+66592>>2]=t;c[O+132128>>2]=t;t=A+9216|0;c[O+1060>>2]=t;c[O+66596>>2]=t;c[O+132132>>2]=t;t=A+10240|0;c[O+1064>>2]=t;c[O+66600>>2]=t;c[O+132136>>2]=t;t=A+11264|0;c[O+1068>>2]=t;c[O+66604>>2]=t;c[O+132140>>2]=t;t=A+12288|0;c[O+1072>>2]=t;c[O+66608>>2]=t;c[O+132144>>2]=t;t=A+13312|0;c[O+1076>>2]=t;c[O+66612>>2]=t;c[O+132148>>2]=t;t=A+14336|0;c[O+1080>>2]=t;c[O+66616>>2]=t;c[O+132152>>2]=t;t=A+15360|0;c[O+1084>>2]=t;c[O+66620>>2]=t;c[O+132156>>2]=t;t=A+16384|0;c[O+1536>>2]=t;c[O+67072>>2]=t;c[O+132608>>2]=t;t=A+17408|0;c[O+1540>>2]=t;c[O+67076>>2]=t;c[O+132612>>2]=t;t=A+18432|0;c[O+1544>>2]=t;c[O+67080>>2]=t;c[O+132616>>2]=t;t=A+19456|0;c[O+1548>>2]=t;c[O+67084>>2]=t;c[O+132620>>2]=t;t=A+20480|0;c[O+1552>>2]=t;c[O+67088>>2]=t;c[O+132624>>2]=t;t=A+21504|0;c[O+1556>>2]=t;c[O+67092>>2]=t;c[O+132628>>2]=t;t=A+22528|0;c[O+1560>>2]=t;c[O+67096>>2]=t;c[O+132632>>2]=t;t=A+23552|0;c[O+1564>>2]=t;c[O+67100>>2]=t;c[O+132636>>2]=t;t=A+24576|0;c[O+1568>>2]=t;c[O+67104>>2]=t;c[O+132640>>2]=t;t=A+25600|0;c[O+1572>>2]=t;c[O+67108>>2]=t;c[O+132644>>2]=t;t=A+26624|0;c[O+1576>>2]=t;c[O+67112>>2]=t;c[O+132648>>2]=t;t=A+27648|0;c[O+1580>>2]=t;c[O+67116>>2]=t;c[O+132652>>2]=t;t=A+28672|0;c[O+1584>>2]=t;c[O+67120>>2]=t;c[O+132656>>2]=t;t=A+29696|0;c[O+1588>>2]=t;c[O+67124>>2]=t;c[O+132660>>2]=t;t=A+30720|0;c[O+1592>>2]=t;c[O+67128>>2]=t;c[O+132664>>2]=t;t=A+31744|0;c[O+1596>>2]=t;c[O+67132>>2]=t;c[O+132668>>2]=t;t=c[2439626]|0;c[O+2048>>2]=t;c[O+67584>>2]=t;c[O+133120>>2]=t;A=t+1024|0;c[O+2052>>2]=A;c[O+67588>>2]=A;c[O+133124>>2]=A;A=t+2048|0;c[O+2056>>2]=A;c[O+67592>>2]=A;c[O+133128>>2]=A;A=t+3072|0;c[O+2060>>2]=A;c[O+67596>>2]=A;c[O+133132>>2]=A;c[O+196688>>2]=2472;c[O+196728>>2]=414;c[O+196608>>2]=352;c[O+196648>>2]=1564;A=c[3532592]|0;if((A|0)!=0){gGC(A|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);A=c[2439330]|0;t=(A|0)==0;if(!t){s=A;gGC(9706056,s|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];s=c[3528484]|0;c[2076596]=s;z=c[2417276]|0;c[3541536]=z;c[1836236]=0;c[A+4180>>2]=2436;c[A+4184>>2]=578;C=c[2385848]|0;E=0;D=0;while(1){c[A+76+(D<<2)>>2]=C+(D<<8);p=E+1&65535;if((p&65535)>127){P=0;Q=0;break}else{E=p;D=p&65535}}while(1){D=C+(Q<<8)|0;c[A+76+(Q+512<<2)>>2]=D;c[A+76+(Q+768<<2)>>2]=D;D=P+1&65535;if((D&65535)>127){break}else{P=D;Q=D&65535}}C=c[2385866]|0;c[A+588>>2]=C;D=C+256|0;c[A+592>>2]=D;E=C+512|0;c[A+596>>2]=E;p=C+768|0;c[A+600>>2]=p;B=C+1024|0;c[A+604>>2]=B;F=C+1280|0;c[A+608>>2]=F;G=C+1536|0;c[A+612>>2]=G;H=C+1792|0;c[A+616>>2]=H;c[A+1612>>2]=C;c[A+1616>>2]=D;c[A+1620>>2]=E;c[A+1624>>2]=p;c[A+1628>>2]=B;c[A+1632>>2]=F;c[A+1636>>2]=G;c[A+1640>>2]=H;c[A+2636>>2]=C;c[A+3660>>2]=C;c[A+2640>>2]=D;c[A+3664>>2]=D;c[A+2644>>2]=E;c[A+3668>>2]=E;c[A+2648>>2]=p;c[A+3672>>2]=p;c[A+2652>>2]=B;c[A+3676>>2]=B;c[A+2656>>2]=F;c[A+3680>>2]=F;c[A+2660>>2]=G;c[A+3684>>2]=G;c[A+2664>>2]=H;c[A+3688>>2]=H;if(!t){H=A;gGC(H|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=s;c[2417276]=z;c[1836236]=-1;H=a[9680]|0;G=H?32e3:0;if(H){if(a[9624]|0){H=G*3|0;F=55930;while(1){if((F|0)>(H|0)){F=F>>1}else{R=1222;S=F;break}}}else{R=2462;S=G}c[2429380]=S;c[3542124]=R;mw(3579545,S);F=gGq(262144)|0;c[2406684]=F;gGz(F|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(3579545,11025)}h[745421]=1.0;c[2436794]=3;h[745420]=1.0;c[2436792]=3;TJ(0,c[3527284]|0,131072);c[2424878]=9681232;c[2405736]=152;h[1202869]=.2;c[2405742]=3;c[2426622]=9622928;h[1202870]=.2;c[2405743]=3;F=c[642608+(c[2436]<<2)>>2]|0;H=c[F+128>>2]|0;if((c[F+52>>2]&4|0)==0){c[2113068]=H;z=c[F+132>>2]|0;c[2113070]=z;c[2443814]=H;c[2440436]=z;T=H;U=z}else{c[2113070]=H;z=c[F+132>>2]|0;c[2113068]=z;c[2440436]=H;c[2443814]=z;T=z;U=H}H=ag(T<<1,U)|0;z=gGq(H)|0;c[2112926]=z;if((z|0)!=0){gGz(z|0,0,H|0)}c[2437650]=0;c[2437651]=32;c[2437652]=40;c[2433324]=16;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];H=c[3532592]|0;if((H|0)!=0){gGC(9104152,H|0,280)|0}c[2113054]=c[2113060]}RI();H=c[2394]|0;z=c[14130368+(H<<2)>>2]|0;if((z|0)!=0){gGC(z|0,9104152,280)|0}c[8452240+(H<<2)>>2]=c[2113054];c[2394]=-1;H=c[2439330]|0;z=(H|0)==0;if(!z){F=H;gGC(9706056,F|0,76)|0}F=c[2438118]|0;c[2433530]=F;s=c[3528484]|0;c[2076596]=s;A=c[2417276]|0;c[3541536]=A;c[1836236]=0;gGz(9706056,0,76);if(!z){z=H;gGC(z|0,9706056,76)|0}c[2438118]=F;c[3528484]=s;c[2417276]=A;c[1836236]=-1;mx(0);blH();a[14115360]=0;a[9758256]=0;c[2436804]=0;c[2437026]=0;h[615974]=0.0;c[2442970]=0;y=0;i=e;return y|0}}while(0);c[2426818]=0;y=1;i=e;return y|0}function bcn(){var b=0,d=0,e=0,f=0,g=0;b=c[2424800]|0;if((b|0)!=0){gGr(b);c[2424800]=0}b=c[2418166]|0;if((b|0)!=0){gGr(b);c[2418166]=0}fwZ();if((c[2392]|0)>=0){b=0;do{d=14130368+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}d=14130384+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}b=b+1|0;}while((b|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;b=c[3531464]|0;c[b+44344>>2]=0;c[b+44348>>2]=0;if((b|0)!=0){gGr(b);c[3531464]=0}b=c[2406684]|0;if((b|0)!=0){gGr(b);c[2406684]=0}c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}blI();b=c[2426818]|0;d=0;while(1){if((d|0)>=1024){break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==(b|0)){g=59556;break}else{d=d+1|0}}if((g|0)==59556){gGr(b);c[f>>2]=0}c[2426818]=0;a[14115360]=0;a[9758256]=0;c[2436804]=0;c[2437026]=0;h[615974]=0.0;c[2433324]=0;gGz(9750600,0,3);gGz(9623120,0,3);c[2442970]=0;c[2443506]=0;c[2430236]=0;c[2429778]=0;a[9545176]=0;c[2437706]=0;return 0}function bco(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=a[9688]|0?534:0;if((a[9625080]|0)!=0){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060]}RI();e=c[2394]|0;f=c[14130368+(e<<2)>>2]|0;if((f|0)!=0){gGC(f|0,9104152,280)|0}c[8452240+(e<<2)>>2]=c[2113054];c[2394]=-1;e=c[2439330]|0;f=(e|0)==0;if(!f){g=e;gGC(9706056,g|0,76)|0}g=c[2438118]|0;c[2433530]=g;i=c[3528484]|0;c[2076596]=i;j=c[2417276]|0;c[3541536]=j;c[1836236]=0;gGz(9706056,0,76);if(!f){f=e;gGC(f|0,9706056,76)|0}c[2438118]=g;c[3528484]=i;c[2417276]=j;c[1836236]=-1;mx(0);blH();a[14115360]=0;a[9758256]=0;c[2436804]=0;c[2437026]=0;h[615974]=0.0;c[2442970]=0}bdX();c[2440552]=133333;c[2440494]=59659;c[2444121]=0;c[2444120]=0;j=c[2392]|0;if((j|0)>=0){gGz(8452240,0,((j|0)>0?(j<<2)+4|0:4)|0)}c[2113054]=0;j=c[2385548]|0;if((j|0)>0){gGz(9752472,0,((j|0)>1?j<<2:4)|0)}c[2433530]=0;j=d-1|0;i=0;g=0;L76839:while(1){f=g;while(1){if((f|0)>=(d|0)){break L76839}if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060]}k=f+1|0;e=(ag(c[2440552]|0,k)|0)/534|0;l=e-(c[2444120]|0)|0;c[2438210]=l;c[2113056]=l;e=RG(l)|0;c[2113054]=(c[2113054]|0)+e;c[2276108]=-1;c[2113056]=-1;c[2444120]=(c[2444120]|0)+e;do{if((f|0)==(j|0)&(a[14115360]|0)!=0){c[8452200+(c[2394]<<2)>>2]=8197;c[2276080]=1280;if((c[2276079]|0)>>>0>=1280){break}RH(5)}}while(0);e=c[2394]|0;l=c[14130368+(e<<2)>>2]|0;if((l|0)!=0){gGC(l|0,9104152,280)|0}c[8452240+(e<<2)>>2]=c[2113054];c[2394]=-1;e=c[2439330]|0;if((e|0)!=0){l=e;gGC(9706056,l|0,76)|0}b[4853030]=c[2426515]&65535;l=c[2438118]|0;c[2433530]=l;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;m=(ag(c[2440494]|0,k)|0)/534|0;n=c[2444121]|0;o=m-n|0;c[2438210]=o;do{if((o|0)<1){p=0;q=n;r=0;s=e;t=l}else{if((a[e+4188|0]|0)==0){m=gfc(o)|0;u=(c[2433530]|0)+m|0;c[2433530]=u;v=c[1836236]|0;p=m;q=c[2444121]|0;r=v;s=c[9757320+(v<<2)>>2]|0;t=u;break}else{u=l+o|0;c[2433530]=u;p=o;q=n;r=0;s=e;t=u;break}}}while(0);c[2438210]=p;c[2444121]=q+p;if((s|0)!=0){e=s;gGC(e|0,9706056,76)|0}c[9752472+(r<<2)>>2]=t;c[14113936+(r<<2)>>2]=c[2076596];c[9669104+(r<<2)>>2]=c[3541536];c[1836236]=-1;w=c[2112964]|0;if((w|0)==0){f=k}else{break}}f=a[9688]&1;e=w+(i<<1<<1)|0;gg[c[3542124]&4095](e,f);TH(0,e,f);i=f+i|0;g=k}k=c[2112964]|0;do{if((k|0)!=0){g=a[9688]|0?534:0;w=g-i|0;r=k+(i<<1<<1)|0;if((g|0)==(i|0)){break}gg[c[3542124]&4095](r,w);TH(0,r,w)}}while(0);if((c[2112968]|0)==0){return 0}bd5();return 0}function bcp(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=i;i=i+48|0;e=d|0;if((a&64|0)==0){bd1(a,b);i=d;return 0}fw$(a);f=d+16|0;if((b|0)!=0){c[b>>2]=169619}cC(f|0,170224,(g=i,i=i+8|0,c[g>>2]=0,g)|0)|0;i=g;c[e>>2]=9699512;c[e+4>>2]=64;c[e+8>>2]=0;c[e+12>>2]=f;gj[c[2076592]&4095](e)|0;bd1(a,b);i=d;return 0}function bcq(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7188292+(b*112|0)>>2];c[a+104>>2]=c[7188296+(b*112|0)>>2];c[a+108>>2]=c[7188300+(b*112|0)>>2];d=0;return d|0}function bcr(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=7188192+(b*112|0);e=0;return e|0}function bcs(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4127204+(b*112|0)>>2];c[a+104>>2]=c[4127208+(b*112|0)>>2];c[a+108>>2]=c[4127212+(b*112|0)>>2];d=0;return d|0}function bct(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=4127104+(b*112|0);e=0;return e|0}function bcu(){var b=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;c[2426818]=0;c[2388038]=0;c[3529498]=131072;c[2443400]=393216;c[2405720]=655360;c[2388060]=655360;c[2439626]=688128;c[2411882]=692224;c[2407018]=692224;c[3530202]=696320;c[2405828]=700416;c[3529600]=1224704;c[2406292]=2273280;b=0;while(1){if((b|0)>=1024){break}e=9638528+(b<<2)|0;if((c[e>>2]|0)==0){f=59638;break}else{b=b+1|0}}do{if((f|0)==59638){b=gGq(2306048)|0;c[e>>2]=b;if((b|0)==0){break}c[2426818]=b;gGz(b|0,0,2306048);c[2388038]=b;g=b+131072|0;c[3529498]=g;c[2443400]=b+393216;i=b+655360|0;c[2405720]=i;c[2388060]=i;c[2439626]=b+688128;i=b+692224|0;c[2411882]=i;c[2407018]=i;c[3530202]=b+696320;c[2405828]=b+700416;c[3529600]=b+1224704;c[2406292]=b+2273280;c[2414434]=b+2306048;b=0;while(1){if((b|0)>=1024){j=0;break}k=9638528+(b<<2)|0;if((c[k>>2]|0)==0){f=59643;break}else{b=b+1|0}}do{if((f|0)==59643){b=gGq(24576)|0;c[k>>2]=b;if((b|0)==0){j=0;break}gGz(b|0,0,24576);j=b}}while(0);c[3529062]=j;c[2438700]=262143;c[3529060]=g;a[7461784]=1;gGz(9726816,0,12);gGz(9726800,0,12);c[2429638]=0;c[2437692]=2;b=c[2443400]|0;c[2438136]=0;i=0;while(1){if((i|0)>=1024){l=0;break}m=9638528+(i<<2)|0;if((c[m>>2]|0)==0){f=59648;break}else{i=i+1|0}}do{if((f|0)==59648){i=gGq(1024)|0;c[m>>2]=i;if((i|0)==0){l=0;break}gGz(i|0,0,1024);l=i}}while(0);c[3529066]=l;c[2438702]=262143;c[3529064]=b;a[7461792]=1;c[2438136]=0;c[2437694]=128;if((R6((c[2388038]|0)+1|0,0,2)|0)!=0){n=1;return n|0}if((R6(c[2388038]|0,1,2)|0)!=0){n=1;return n|0}if((R6(c[3529498]|0,2,2)|0)!=0){n=1;return n|0}if((R6((c[3529498]|0)+1|0,3,2)|0)!=0){n=1;return n|0}if((R6((c[3529498]|0)+131072|0,4,2)|0)!=0){n=1;return n|0}if((R6((c[3529498]|0)+131073|0,5,2)|0)!=0){n=1;return n|0}i=c[3529498]|0;bd8(i,262144);g=c[2405828]|0;o=0;do{p=o<<6;gGz(g+p|0,0,64);q=o<<8;r=0;do{s=1<<3-r;t=(c[611632+(r<<2)>>2]|0)+q|0;u=0;do{v=t+(c[1183816+(u<<2)>>2]|0)|0;w=(u<<3)+p|0;x=0;do{y=v+(c[614800+(x<<2)>>2]|0)|0;if(((d[i+((y|0)/8|0)|0]|0)&128>>>((y&7)>>>0)|0)!=0){y=g+(w+x)|0;a[y]=(d[y]|0|s)&255}x=x+1|0;}while((x|0)<8);u=u+1|0;}while((u|0)<8);r=r+1|0;}while((r|0)<4);o=o+1|0;}while((o|0)<8192);if((R6(c[2443400]|0,6,2)|0)!=0){n=1;return n|0}if((R6((c[2443400]|0)+1|0,7,2)|0)!=0){n=1;return n|0}if((R6((c[2443400]|0)+131072|0,8,2)|0)!=0){n=1;return n|0}if((R6((c[2443400]|0)+131073|0,9,2)|0)!=0){n=1;return n|0}o=c[2443400]|0;bd8(o,262144);g=c[3529600]|0;i=0;do{b=i<<8;gGz(g+b|0,0,256);r=i<<10;p=0;do{q=1<<3-p;u=(c[611632+(p<<2)>>2]|0)+r|0;s=0;do{t=u+(c[3946808+(s<<2)>>2]|0)|0;x=(s<<4)+b|0;w=0;do{v=t+(c[6669416+(w<<2)>>2]|0)|0;if(((d[o+((v|0)/8|0)|0]|0)&128>>>((v&7)>>>0)|0)!=0){v=g+(x+w)|0;a[v]=(d[v]|0|q)&255}w=w+1|0;}while((w|0)<16);s=s+1|0;}while((s|0)<16);p=p+1|0;}while((p|0)<4);i=i+1|0;}while((i|0)<2048);fxU(0,425984);if((c[2394]|0)==0){z=c[2112932]|0}else{c[2394]=0;i=c[3532596]|0;c[2112932]=i;g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060];z=i}i=c[2388038]|0;g=z|0;o=0;while(1){p=i+o|0;c[g>>2]=p;c[g+131072>>2]=p;p=o+1024|0;if(p>>>0>131071){break}else{g=g+4|0;o=p}}o=c[2388060]|0;c[z+1024>>2]=o;c[z+66560>>2]=o;c[z+132096>>2]=o;g=o+1024|0;c[z+1028>>2]=g;c[z+66564>>2]=g;c[z+132100>>2]=g;g=o+2048|0;c[z+1032>>2]=g;c[z+66568>>2]=g;c[z+132104>>2]=g;g=o+3072|0;c[z+1036>>2]=g;c[z+66572>>2]=g;c[z+132108>>2]=g;g=o+4096|0;c[z+1040>>2]=g;c[z+66576>>2]=g;c[z+132112>>2]=g;g=o+5120|0;c[z+1044>>2]=g;c[z+66580>>2]=g;c[z+132116>>2]=g;g=o+6144|0;c[z+1048>>2]=g;c[z+66584>>2]=g;c[z+132120>>2]=g;g=o+7168|0;c[z+1052>>2]=g;c[z+66588>>2]=g;c[z+132124>>2]=g;g=o+8192|0;c[z+1056>>2]=g;c[z+66592>>2]=g;c[z+132128>>2]=g;g=o+9216|0;c[z+1060>>2]=g;c[z+66596>>2]=g;c[z+132132>>2]=g;g=o+10240|0;c[z+1064>>2]=g;c[z+66600>>2]=g;c[z+132136>>2]=g;g=o+11264|0;c[z+1068>>2]=g;c[z+66604>>2]=g;c[z+132140>>2]=g;g=o+12288|0;c[z+1072>>2]=g;c[z+66608>>2]=g;c[z+132144>>2]=g;g=o+13312|0;c[z+1076>>2]=g;c[z+66612>>2]=g;c[z+132148>>2]=g;g=o+14336|0;c[z+1080>>2]=g;c[z+66616>>2]=g;c[z+132152>>2]=g;g=o+15360|0;c[z+1084>>2]=g;c[z+66620>>2]=g;c[z+132156>>2]=g;g=c[2439626]|0;c[z+2048>>2]=g;c[z+67584>>2]=g;c[z+133120>>2]=g;o=g+1024|0;c[z+2052>>2]=o;c[z+67588>>2]=o;c[z+133124>>2]=o;o=g+2048|0;c[z+2056>>2]=o;c[z+67592>>2]=o;c[z+133128>>2]=o;o=g+3072|0;c[z+2060>>2]=o;c[z+67596>>2]=o;c[z+133132>>2]=o;c[z+196688>>2]=3574;c[z+196728>>2]=1890;c[z+196608>>2]=2208;c[z+196648>>2]=1236;o=c[3532592]|0;if((o|0)!=0){gGC(o|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;o=a[9680]|0;g=o?32e3:0;if(o){if(a[9624]|0){o=g*3|0;i=55930;while(1){if((i|0)>(o|0)){i=i>>1}else{A=1222;B=i;break}}}else{A=2462;B=g}c[2429380]=B;c[3542124]=A;mw(3579545,B);i=gGq(262144)|0;c[2406684]=i;gGz(i|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(3579545,11025)}c[(c[3531464]|0)+44344>>2]=1478;h[745421]=1.0;c[2436794]=3;h[745420]=1.0;c[2436792]=3;i=c[642608+(c[2436]<<2)>>2]|0;o=c[i+128>>2]|0;if((c[i+52>>2]&4|0)==0){c[2113068]=o;p=c[i+132>>2]|0;c[2113070]=p;c[2443814]=o;c[2440436]=p;C=o;D=p}else{c[2113070]=o;p=c[i+132>>2]|0;c[2113068]=p;c[2440436]=o;c[2443814]=p;C=p;D=o}o=ag(C<<1,D)|0;p=gGq(o)|0;c[2112926]=p;if((p|0)!=0){gGz(p|0,0,o|0)}c[2437650]=0;c[2437651]=32;c[2437652]=40;c[2433324]=16;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];o=c[3532592]|0;if((o|0)!=0){gGC(9104152,o|0,280)|0}c[2113054]=c[2113060]}RI();o=c[2394]|0;p=c[14130368+(o<<2)>>2]|0;if((p|0)!=0){gGC(p|0,9104152,280)|0}c[8452240+(o<<2)>>2]=c[2113054];c[2394]=-1;mx(0);blH();a[14115360]=0;c[2443506]=0;c[2442970]=0;c[2430236]=0;n=0;return n|0}}while(0);c[2426818]=0;n=1;return n|0}function bcv(){var b=0,d=0,e=0,f=0,g=0;if((c[2392]|0)>=0){b=0;do{d=14130368+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}d=14130384+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}b=b+1|0;}while((b|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;b=c[3531464]|0;c[b+44344>>2]=0;c[b+44348>>2]=0;if((b|0)!=0){gGr(b);c[3531464]=0}b=c[2406684]|0;if((b|0)!=0){gGr(b);c[2406684]=0}c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}blI();b=c[2426818]|0;d=0;while(1){if((d|0)>=1024){break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==(b|0)){g=59735;break}else{d=d+1|0}}if((g|0)==59735){gGr(b);c[f>>2]=0}c[2426818]=0;a[14115360]=0;a[9758256]=0;c[2436804]=0;c[2437026]=0;h[615974]=0.0;c[2433324]=0;gGz(9750600,0,3);gGz(9623120,0,3);c[2442970]=0;c[2443506]=0;c[2430236]=0;c[2429778]=0;a[9545176]=0;c[2437706]=0;return 0}function bcw(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;if((a[9625080]|0)!=0){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];b=c[3532592]|0;if((b|0)!=0){gGC(9104152,b|0,280)|0}c[2113054]=c[2113060]}RI();b=c[2394]|0;d=c[14130368+(b<<2)>>2]|0;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[8452240+(b<<2)>>2]=c[2113054];c[2394]=-1;mx(0);blH();a[14115360]=0;c[2443506]=0;c[2442970]=0;c[2430236]=0}bdX();c[2440552]=133333;c[2444120]=0;b=c[2392]|0;if((b|0)>=0){gGz(8452240,0,((b|0)>0?(b<<2)+4|0:4)|0)}c[2113054]=0;if((c[2394]|0)==0){e=0;f=0}else{c[2394]=0;c[2112932]=c[3532596];b=c[3532592]|0;if((b|0)!=0){gGC(9104152,b|0,280)|0}c[2113054]=c[2113060];e=0;f=0}L77082:while(1){b=f;while(1){if((b|0)>=10){break L77082}g=b+1|0;d=(ag(c[2440552]|0,g)|0)/10|0;h=d-(c[2444120]|0)|0;c[2438210]=h;c[2113056]=h;d=RG(h)|0;c[2113054]=(c[2113054]|0)+d;c[2276108]=-1;c[2113056]=-1;c[2444120]=(c[2444120]|0)+d;do{if((b|0)==9&(a[14115360]|0)!=0){c[8452200+(c[2394]<<2)>>2]=8197;c[2276080]=1280;if((c[2276079]|0)>>>0>=1280){break}RH(5)}}while(0);do{if((c[2430236]|0)!=0){c[8452200+(c[2394]<<2)>>2]=8198;c[2276080]=1536;if((c[2276079]|0)>>>0>=1536){break}RH(6)}}while(0);i=c[2112964]|0;if((i|0)==0){b=g}else{break}}b=a[9688]|0?53:0;gg[c[3542124]&4095](i+(e<<1<<1)|0,b);e=b+e|0;f=g}g=c[2112964]|0;do{if((g|0)!=0){f=a[9688]|0?534:0;if((f|0)==(e|0)){break}gg[c[3542124]&4095](g+(e<<1<<1)|0,f-e|0)}}while(0);e=c[2394]|0;g=c[14130368+(e<<2)>>2]|0;if((g|0)!=0){gGC(g|0,9104152,280)|0}c[8452240+(e<<2)>>2]=c[2113054];c[2394]=-1;if((c[2112968]|0)==0){return 0}bd5();return 0}function bcx(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=i;i=i+32|0;e=d|0;f=d+16|0;if((a&8|0)!=0){gGz(f|0,0,12);c[f>>2]=c[2406292];c[f+4>>2]=32768;c[f+12>>2]=254016;g=c[2076592]|0;gj[g&4095](f)|0}if((a&64|0)==0){bd1(a,b);i=d;return 0}blJ(a);gGz(e|0,0,12);c[e>>2]=9720944;c[e+4>>2]=4;c[e+12>>2]=357480;gj[c[2076592]&4095](e)|0;bd1(a,b);i=d;return 0}function bcy(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4228996+(b*112|0)>>2];c[a+104>>2]=c[4229e3+(b*112|0)>>2];c[a+108>>2]=c[4229004+(b*112|0)>>2];d=0;return d|0}function bcz(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=4228896+(b*112|0);e=0;return e|0}function bcA(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1309136+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function bcB(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;e=i;i=i+720|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;c[2426818]=0;c[2388038]=0;c[2385848]=524288;c[3527284]=589824;c[3529498]=1638400;c[2443400]=2686976;c[2405720]=3735552;c[2388060]=3735552;c[2385866]=3751936;c[2439626]=3753984;c[2443436]=3758080;c[2411882]=3774464;c[2405828]=3774464;c[3529600]=5871616;c[2407018]=7968768;c[3530202]=7976960;t=0;while(1){if((t|0)>=1024){break}u=9638528+(t<<2)|0;if((c[u>>2]|0)==0){v=59800;break}else{t=t+1|0}}do{if((v|0)==59800){t=gGq(7985216)|0;c[u>>2]=t;if((t|0)==0){break}c[2426818]=t;gGz(t|0,0,7985216);c[2388038]=t;c[2385848]=t+524288;c[3527284]=t+589824;w=t+1638400|0;c[3529498]=w;c[2443400]=t+2686976;x=t+3735552|0;c[2405720]=x;c[2388060]=x;c[2385866]=t+3751936;c[2439626]=t+3753984;c[2443436]=t+3758080;x=t+3774464|0;c[2411882]=x;c[2405828]=x;c[3529600]=t+5871616;c[2407018]=t+7968768;c[3530202]=t+7976960;c[2414434]=t+7985216;t=0;while(1){if((t|0)>=1024){y=0;break}z=9638528+(t<<2)|0;if((c[z>>2]|0)==0){v=59805;break}else{t=t+1|0}}do{if((v|0)==59805){t=gGq(24576)|0;c[z>>2]=t;if((t|0)==0){y=0;break}gGz(t|0,0,24576);y=t}}while(0);c[3529062]=y;c[2438700]=1048575;c[3529060]=w;a[7461784]=1;t=9726816;c[t>>2]=0;c[t+4>>2]=0;t=9726800;c[t>>2]=0;c[t+4>>2]=0;c[2429638]=0;c[2437692]=74;c[2431704]=8;c[2431700]=0;c[2431705]=8;c[2431701]=0;c[2431706]=8;c[2431702]=0;biH(c[2443400]|0,1048575,74);c[3529052]=-112;c[3529050]=16;if((R6((c[2388038]|0)+1|0,0,2)|0)!=0){A=1;i=e;return A|0}if((R6(c[2388038]|0,1,2)|0)!=0){A=1;i=e;return A|0}if((R6((c[2388038]|0)+262145|0,2,2)|0)!=0){A=1;i=e;return A|0}if((R6((c[2388038]|0)+262144|0,3,2)|0)!=0){A=1;i=e;return A|0}t=c[2385848]|0;if((c[3542200]|0)==0){A=1;i=e;return A|0}x=r+108|0;c[x>>2]=0;B=r+100|0;c[B>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,4)|0;do{if((c[x>>2]|0)!=0){C=c[B>>2]|0;c[s>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](s,4,0)|0;if((C|0)<1){A=1;i=e;return A|0}if((gzL(t,0,4)|0)==0){break}else{A=1}i=e;return A|0}}while(0);t=c[3529498]|0;if((c[3542200]|0)==0){A=1;i=e;return A|0}B=p+108|0;c[B>>2]=0;x=p+100|0;c[x>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,5)|0;do{if((c[B>>2]|0)!=0){w=c[x>>2]|0;c[q>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](q,5,0)|0;if((w|0)<1){A=1;i=e;return A|0}if((gzL(t,0,5)|0)==0){break}else{A=1}i=e;return A|0}}while(0);t=(c[3529498]|0)+524288|0;if((c[3542200]|0)==0){A=1;i=e;return A|0}x=n+108|0;c[x>>2]=0;B=n+100|0;c[B>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,6)|0;do{if((c[x>>2]|0)!=0){w=c[B>>2]|0;c[o>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](o,6,0)|0;if((w|0)<1){A=1;i=e;return A|0}if((gzL(t,0,6)|0)==0){break}else{A=1}i=e;return A|0}}while(0);t=c[3529498]|0;B=0;x=t;while(1){w=a[x]|0;C=x+1|0;a[x]=a[C]|0;a[C]=w;w=B+1|0;if((w|0)<524288){B=w;x=x+2|0}else{break}}blG(t,524288);x=c[2405828]|0;B=0;do{w=B<<6;gGz(x+w|0,0,64);C=B<<8;D=0;do{E=1<<3-D;F=(c[611632+(D<<2)>>2]|0)+C|0;G=0;do{H=F+(c[1183816+(G<<2)>>2]|0)|0;I=(G<<3)+w|0;J=0;do{K=H+(c[614800+(J<<2)>>2]|0)|0;if(((d[t+((K|0)/8|0)|0]|0)&128>>>((K&7)>>>0)|0)!=0){K=x+(I+J)|0;a[K]=(d[K]|0|E)&255}J=J+1|0;}while((J|0)<8);G=G+1|0;}while((G|0)<8);D=D+1|0;}while((D|0)<4);B=B+1|0;}while((B|0)<32768);B=c[2443400]|0;if((c[3542200]|0)==0){A=1;i=e;return A|0}x=l+108|0;c[x>>2]=0;t=l+100|0;c[t>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,7)|0;do{if((c[x>>2]|0)!=0){D=c[t>>2]|0;c[m>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](m,7,0)|0;if((D|0)<1){A=1;i=e;return A|0}if((gzL(B,0,7)|0)==0){break}else{A=1}i=e;return A|0}}while(0);B=(c[2443400]|0)+524288|0;if((c[3542200]|0)==0){A=1;i=e;return A|0}t=j+108|0;c[t>>2]=0;x=j+100|0;c[x>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,8)|0;do{if((c[t>>2]|0)!=0){D=c[x>>2]|0;c[k>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](k,8,0)|0;if((D|0)<1){A=1;i=e;return A|0}if((gzL(B,0,8)|0)==0){break}else{A=1}i=e;return A|0}}while(0);B=c[2443400]|0;x=0;t=B;while(1){D=a[t]|0;w=t+1|0;a[t]=a[w]|0;a[w]=D;D=x+1|0;if((D|0)<524288){x=D;t=t+2|0}else{break}}blG(B,524288);t=c[3529600]|0;x=0;do{D=x<<8;gGz(t+D|0,0,256);w=x<<10;C=0;do{G=1<<3-C;E=(c[611632+(C<<2)>>2]|0)+w|0;F=0;do{J=E+(c[3946808+(F<<2)>>2]|0)|0;I=(F<<4)+D|0;H=0;do{K=J+(c[6669416+(H<<2)>>2]|0)|0;if(((d[B+((K|0)/8|0)|0]|0)&128>>>((K&7)>>>0)|0)!=0){K=t+(I+H)|0;a[K]=(d[K]|0|G)&255}H=H+1|0;}while((H|0)<16);F=F+1|0;}while((F|0)<16);C=C+1|0;}while((C|0)<4);x=x+1|0;}while((x|0)<8192);x=c[3527284]|0;if((c[3542200]|0)==0){A=1;i=e;return A|0}t=f+108|0;c[t>>2]=0;B=f+100|0;c[B>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,9)|0;do{if((c[t>>2]|0)!=0){C=c[B>>2]|0;c[g>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](g,9,0)|0;if((C|0)<1){A=1;i=e;return A|0}if((gzL(x,0,9)|0)==0){break}else{A=1}i=e;return A|0}}while(0);fxU(0,425984);if((c[2394]|0)==0){L=c[2112932]|0}else{c[2394]=0;x=c[3532596]|0;c[2112932]=x;B=c[3532592]|0;if((B|0)!=0){gGC(9104152,B|0,280)|0}c[2113054]=c[2113060];L=x}x=c[2388038]|0;B=L|0;t=0;while(1){C=x+t|0;c[B>>2]=C;c[B+131072>>2]=C;C=t+1024|0;if(C>>>0>524287){break}else{B=B+4|0;t=C}}t=c[2388060]|0;c[L+8256>>2]=t;c[L+73792>>2]=t;c[L+139328>>2]=t;B=t+1024|0;c[L+8260>>2]=B;c[L+73796>>2]=B;c[L+139332>>2]=B;B=t+2048|0;c[L+8264>>2]=B;c[L+73800>>2]=B;c[L+139336>>2]=B;B=t+3072|0;c[L+8268>>2]=B;c[L+73804>>2]=B;c[L+139340>>2]=B;B=t+4096|0;c[L+8272>>2]=B;c[L+73808>>2]=B;c[L+139344>>2]=B;B=t+5120|0;c[L+8276>>2]=B;c[L+73812>>2]=B;c[L+139348>>2]=B;B=t+6144|0;c[L+8280>>2]=B;c[L+73816>>2]=B;c[L+139352>>2]=B;B=t+7168|0;c[L+8284>>2]=B;c[L+73820>>2]=B;c[L+139356>>2]=B;B=t+8192|0;c[L+8288>>2]=B;c[L+73824>>2]=B;c[L+139360>>2]=B;B=t+9216|0;c[L+8292>>2]=B;c[L+73828>>2]=B;c[L+139364>>2]=B;B=t+10240|0;c[L+8296>>2]=B;c[L+73832>>2]=B;c[L+139368>>2]=B;B=t+11264|0;c[L+8300>>2]=B;c[L+73836>>2]=B;c[L+139372>>2]=B;B=t+12288|0;c[L+8304>>2]=B;c[L+73840>>2]=B;c[L+139376>>2]=B;B=t+13312|0;c[L+8308>>2]=B;c[L+73844>>2]=B;c[L+139380>>2]=B;B=t+14336|0;c[L+8312>>2]=B;c[L+73848>>2]=B;c[L+139384>>2]=B;B=t+15360|0;c[L+8316>>2]=B;c[L+73852>>2]=B;c[L+139388>>2]=B;B=c[2439626]|0;c[L+16384>>2]=B;c[L+81920>>2]=B;c[L+147456>>2]=B;t=B+1024|0;c[L+16388>>2]=t;c[L+81924>>2]=t;c[L+147460>>2]=t;t=B+2048|0;c[L+16392>>2]=t;c[L+81928>>2]=t;c[L+147464>>2]=t;t=B+3072|0;c[L+16396>>2]=t;c[L+81932>>2]=t;c[L+147468>>2]=t;c[L+196688>>2]=3242;c[L+196728>>2]=1470;c[L+196608>>2]=806;c[L+196648>>2]=182;t=c[3532592]|0;if((t|0)!=0){gGC(t|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);t=c[2439330]|0;B=(t|0)==0;if(!B){x=t;gGC(9706056,x|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];x=c[3528484]|0;c[2076596]=x;C=c[2417276]|0;c[3541536]=C;c[1836236]=0;c[t+4180>>2]=3124;c[t+4184>>2]=2566;D=c[2385848]|0;w=0;F=0;while(1){c[t+76+(F<<2)>>2]=D+(F<<8);G=w+1&65535;if((G&65535)>239){M=0;N=0;break}else{w=G;F=G&65535}}while(1){F=D+(N<<8)|0;c[t+76+(N+512<<2)>>2]=F;c[t+76+(N+768<<2)>>2]=F;F=M+1&65535;if((F&65535)>239){break}else{M=F;N=F&65535}}D=c[2385866]|0;c[t+1036>>2]=D;F=D+256|0;c[t+1040>>2]=F;w=D+512|0;c[t+1044>>2]=w;G=D+768|0;c[t+1048>>2]=G;E=D+1024|0;c[t+1052>>2]=E;H=D+1280|0;c[t+1056>>2]=H;I=D+1536|0;c[t+1060>>2]=I;J=D+1792|0;c[t+1064>>2]=J;c[t+2060>>2]=D;c[t+2064>>2]=F;c[t+2068>>2]=w;c[t+2072>>2]=G;c[t+2076>>2]=E;c[t+2080>>2]=H;c[t+2084>>2]=I;c[t+2088>>2]=J;c[t+3084>>2]=D;c[t+4108>>2]=D;c[t+3088>>2]=F;c[t+4112>>2]=F;c[t+3092>>2]=w;c[t+4116>>2]=w;c[t+3096>>2]=G;c[t+4120>>2]=G;c[t+3100>>2]=E;c[t+4124>>2]=E;c[t+3104>>2]=H;c[t+4128>>2]=H;c[t+3108>>2]=I;c[t+4132>>2]=I;c[t+3112>>2]=J;c[t+4136>>2]=J;if(!B){J=t;gGC(J|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=x;c[2417276]=C;c[1836236]=-1;J=a[9680]|0;I=J?32e3:0;if(J){if(a[9624]|0){J=I*3|0;H=55930;while(1){if((H|0)>(J|0)){H=H>>1}else{O=1222;P=H;break}}}else{O=2462;P=I}c[2429380]=P;c[3542124]=O;mw(3579545,P);H=gGq(262144)|0;c[2406684]=H;gGz(H|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(3579545,11025)}h[745421]=.7;c[2436794]=1;h[745420]=.7;c[2436792]=2;TN(c[3527284]|0,1048576);h[1209346]=.5;c[2418696]=2;c[2426862]=9674384;h[1209347]=.5;c[2418697]=1;Tq(688456);H=c[642608+(c[2436]<<2)>>2]|0;J=c[H+128>>2]|0;if((c[H+52>>2]&4|0)==0){c[2113068]=J;C=c[H+132>>2]|0;c[2113070]=C;c[2443814]=J;c[2440436]=C;Q=J;R=C}else{c[2113070]=J;C=c[H+132>>2]|0;c[2113068]=C;c[2440436]=J;c[2443814]=C;Q=C;R=J}J=ag(Q<<1,R)|0;C=gGq(J)|0;c[2112926]=C;if((C|0)!=0){gGz(C|0,0,J|0)}if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];J=c[3532592]|0;if((J|0)!=0){gGC(9104152,J|0,280)|0}c[2113054]=c[2113060]}RI();J=c[2394]|0;C=c[14130368+(J<<2)>>2]|0;if((C|0)!=0){gGC(C|0,9104152,280)|0}c[8452240+(J<<2)>>2]=c[2113054];c[2394]=-1;J=c[2439330]|0;C=(J|0)==0;if(!C){H=J;gGC(9706056,H|0,76)|0}H=c[2438118]|0;c[2433530]=H;x=c[3528484]|0;c[2076596]=x;t=c[2417276]|0;c[3541536]=t;c[1836236]=0;gGz(9706056,0,76);if(!C){C=J;gGC(C|0,9706056,76)|0}c[2438118]=H;c[3528484]=x;c[2417276]=t;c[1836236]=-1;mx(0);c[2426862]=9674384;gGz(9674592,0,176);blH();c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];c[2437706]=a[1040128]|0?0:10;c[2429778]=0;c[3541228]=0;A=0;i=e;return A|0}}while(0);c[2426818]=0;A=1;i=e;return A|0}function bcC(){var b=0,d=0,e=0,f=0,g=0,j=0,k=0;b=i;i=i+128|0;c[2426862]=9674384;d=c[2418647]|0;if((d|0)!=0){gGr(d);c[(c[2426862]|0)+204>>2]=0}c[2426862]=9674792;d=c[2418749]|0;if((d|0)!=0){gGr(d);c[(c[2426862]|0)+204>>2]=0}c[2443782]=0;d=b|0;e=c[c[642608+(c[2436]<<2)>>2]>>2]|0;be(d|0,128,179600,(f=i,i=i+24|0,c[f>>2]=9374064,c[f+8>>2]=47,c[f+16>>2]=e,f)|0)|0;i=f;a[1040128]=0;f=c[2420380]|0;e=c[f>>2]|0;g=c[f+4>>2]|0;f=fw(d|0,389440)|0;if((f|0)!=0){d=g>>3<<e&1023;cj(14100392,d|0,1,f|0)|0;aY(f|0)|0}fwZ();if((c[2392]|0)>=0){f=0;do{d=14130368+(f<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}d=14130384+(f<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}f=f+1|0;}while((f|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;f=c[3531464]|0;c[f+44344>>2]=0;c[f+44348>>2]=0;if((f|0)!=0){gGr(f);c[3531464]=0}f=c[2406684]|0;if((f|0)!=0){gGr(f);c[2406684]=0}c[2113070]=0;c[2113068]=0;f=c[2112926]|0;if((f|0)!=0){gGr(f);c[2112926]=0}blI();f=c[2426818]|0;d=0;while(1){if((d|0)>=1024){j=59945;break}k=9638528+(d<<2)|0;if((c[k>>2]|0)==(f|0)){break}else{d=d+1|0}}if((j|0)==59945){c[2426818]=0;a[14115360]=0;a[9758256]=0;c[2436804]=0;c[2437026]=0;h[615974]=0.0;c[2433324]=0;gGz(9750600,0,3);gGz(9623120,0,3);c[2442970]=0;c[2443506]=0;c[2430236]=0;c[2429778]=0;a[9545176]=0;c[2437706]=0;i=b;return 0}gGr(f);c[k>>2]=0;c[2426818]=0;a[14115360]=0;a[9758256]=0;c[2436804]=0;c[2437026]=0;h[615974]=0.0;c[2433324]=0;gGz(9750600,0,3);gGz(9623120,0,3);c[2442970]=0;c[2443506]=0;c[2430236]=0;c[2429778]=0;a[9545176]=0;c[2437706]=0;i=b;return 0}function bcD(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;if((a[9625080]|0)!=0){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;h=c[2417276]|0;c[3541536]=h;c[1836236]=0;gGz(9706056,0,76);if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=h;c[1836236]=-1;mx(0);c[2426862]=9674384;gGz(9674592,0,176);blH();c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];c[2437706]=a[1040128]|0?0:10;c[2429778]=0;c[3541228]=0}bdX();c[2440552]=266666;c[2440494]=59659;c[2444121]=0;c[2444120]=0;h=c[2392]|0;if((h|0)>=0){gGz(8452240,0,((h|0)>0?(h<<2)+4|0:4)|0)}c[2113054]=0;h=c[2385548]|0;if((h|0)>0){gGz(9752472,0,((h|0)>1?h<<2:4)|0)}c[2433530]=0;h=0;g=0;L77378:while(1){f=g;while(1){if((f|0)>=32){break L77378}if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060]}i=f+1|0;e=(ag(c[2440552]|0,i)|0)/32|0;d=e-(c[2444120]|0)|0;c[2438210]=d;c[2113056]=d;e=RG(d)|0;c[2113054]=(c[2113054]|0)+e;c[2276108]=-1;c[2113056]=-1;c[2444120]=(c[2444120]|0)+e;do{if((f|0)==31&(c[3541228]|0)!=0){c[8452200+(c[2394]<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0>=1024){break}RH(4)}}while(0);e=c[2394]|0;d=c[14130368+(e<<2)>>2]|0;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[8452240+(e<<2)>>2]=c[2113054];c[2394]=-1;e=c[2439330]|0;if((e|0)!=0){d=e;gGC(9706056,d|0,76)|0}b[4853030]=c[2426515]&65535;d=c[2438118]|0;c[2433530]=d;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;j=(ag(c[2440494]|0,i)|0)/32|0;k=c[2444121]|0;l=j-k|0;c[2438210]=l;do{if((l|0)<1){m=0;n=k;o=0;p=e;q=d}else{if((a[e+4188|0]|0)==0){j=gfc(l)|0;r=(c[2433530]|0)+j|0;c[2433530]=r;s=c[1836236]|0;m=j;n=c[2444121]|0;o=s;p=c[9757320+(s<<2)>>2]|0;q=r;break}else{r=d+l|0;c[2433530]=r;m=l;n=k;o=0;p=e;q=r;break}}}while(0);c[2438210]=m;c[2444121]=n+m;if((p|0)!=0){e=p;gGC(e|0,9706056,76)|0}c[9752472+(o<<2)>>2]=q;c[14113936+(o<<2)>>2]=c[2076596];c[9669104+(o<<2)>>2]=c[3541536];c[1836236]=-1;t=c[2112964]|0;if((t|0)==0){f=i}else{break}}f=a[9688]|0?16:0;e=t+(h<<1<<1)|0;gg[c[3542124]&4095](e,f);TM(e,f);h=f+h|0;g=i}i=c[2112964]|0;do{if((i|0)!=0){g=a[9688]|0?534:0;t=g-h|0;o=i+(h<<1<<1)|0;if((g|0)==(h|0)){break}gg[c[3542124]&4095](o,t);TM(o,t)}}while(0);if((c[2112968]|0)!=0){bd$()}h=c[3529058]|0;i=0;do{b[h+(i<<1)>>1]=0;i=i+8|0;}while((i|0)<1024);return 0}function bcE(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=i;i=i+16|0;e=d|0;if((a&64|0)!=0){fw$(a);TP(a);gGz(e|0,0,12);c[e>>2]=9750824;c[e+4>>2]=4;c[e+12>>2]=359208;f=c[2076592]|0;gj[f&4095](e)|0}Ts(a,b);bd1(a,b);i=d;return 0}function bcF(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4071284+(b*112|0)>>2];c[a+104>>2]=c[4071288+(b*112|0)>>2];c[a+108>>2]=c[4071292+(b*112|0)>>2];d=0;return d|0}function bcG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=4071184+(b*112|0);e=0;return e|0}function bcH(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3370708+(b*112|0)>>2];c[a+104>>2]=c[3370712+(b*112|0)>>2];c[a+108>>2]=c[3370716+(b*112|0)>>2];d=0;return d|0}function bcI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=3370608+(b*112|0);e=0;return e|0}function bcJ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>33){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=807648+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function bcK(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;e=i;i=i+720|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;c[2426818]=0;c[2388038]=0;c[2385848]=786432;c[3527284]=851968;c[3529498]=1900544;c[2443400]=2949120;c[2405720]=5046272;c[2388060]=5046272;c[2385866]=5062784;c[2439626]=5064832;c[2443436]=5068928;c[2411882]=5085312;c[2407018]=5085312;c[3530202]=5093504;c[2405828]=5101760;c[3529600]=7198912;t=0;while(1){if((t|0)>=1024){break}u=9638528+(t<<2)|0;if((c[u>>2]|0)==0){v=60030;break}else{t=t+1|0}}do{if((v|0)==60030){t=gGq(11393216)|0;c[u>>2]=t;if((t|0)==0){break}c[2426818]=t;gGz(t|0,0,11393216);c[2388038]=t;c[2385848]=t+786432;c[3527284]=t+851968;w=t+1900544|0;c[3529498]=w;c[2443400]=t+2949120;x=t+5046272|0;c[2405720]=x;c[2388060]=x;c[2385866]=t+5062784;c[2439626]=t+5064832;c[2443436]=t+5068928;x=t+5085312|0;c[2411882]=x;c[2407018]=x;c[3530202]=t+5093504;c[2405828]=t+5101760;c[3529600]=t+7198912;c[2414434]=t+11393216;t=0;while(1){if((t|0)>=1024){y=0;break}z=9638528+(t<<2)|0;if((c[z>>2]|0)==0){v=60035;break}else{t=t+1|0}}do{if((v|0)==60035){t=gGq(24576)|0;c[z>>2]=t;if((t|0)==0){y=0;break}gGz(t|0,0,24576);y=t}}while(0);c[3529062]=y;c[2438700]=1048575;c[3529060]=w;a[7461784]=1;t=9726816;c[t>>2]=0;c[t+4>>2]=0;t=9726800;c[t>>2]=0;c[t+4>>2]=0;c[2429638]=0;c[2437692]=6;c[2431704]=8;c[2431700]=0;c[2431705]=8;c[2431701]=0;c[2431706]=8;c[2431702]=0;biH(c[2443400]|0,2097151,118);c[3529052]=-368;c[3529050]=528;a[7461816]=1;if((R6((c[2388038]|0)+1|0,0,2)|0)!=0){A=1;i=e;return A|0}if((R6(c[2388038]|0,1,2)|0)!=0){A=1;i=e;return A|0}if((R6((c[2388038]|0)+524289|0,2,2)|0)!=0){A=1;i=e;return A|0}if((R6((c[2388038]|0)+524288|0,3,2)|0)!=0){A=1;i=e;return A|0}t=c[2385848]|0;if((c[3542200]|0)==0){A=1;i=e;return A|0}x=r+108|0;c[x>>2]=0;B=r+100|0;c[B>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,4)|0;do{if((c[x>>2]|0)!=0){C=c[B>>2]|0;c[s>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](s,4,0)|0;if((C|0)<1){A=1;i=e;return A|0}if((gzL(t,0,4)|0)==0){break}else{A=1}i=e;return A|0}}while(0);t=c[3529498]|0;if((c[3542200]|0)==0){A=1;i=e;return A|0}B=p+108|0;c[B>>2]=0;x=p+100|0;c[x>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,5)|0;do{if((c[B>>2]|0)!=0){w=c[x>>2]|0;c[q>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](q,5,0)|0;if((w|0)<1){A=1;i=e;return A|0}if((gzL(t,0,5)|0)==0){break}else{A=1}i=e;return A|0}}while(0);t=(c[3529498]|0)+524288|0;if((c[3542200]|0)==0){A=1;i=e;return A|0}x=n+108|0;c[x>>2]=0;B=n+100|0;c[B>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,6)|0;do{if((c[x>>2]|0)!=0){w=c[B>>2]|0;c[o>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](o,6,0)|0;if((w|0)<1){A=1;i=e;return A|0}if((gzL(t,0,6)|0)==0){break}else{A=1}i=e;return A|0}}while(0);t=c[3529498]|0;blG(t,524288);B=c[2405828]|0;x=0;do{w=x<<6;gGz(B+w|0,0,64);C=x<<8;D=0;do{E=1<<3-D;F=(c[611632+(D<<2)>>2]|0)+C|0;G=0;do{H=F+(c[1183816+(G<<2)>>2]|0)|0;I=(G<<3)+w|0;J=0;do{K=H+(c[614800+(J<<2)>>2]|0)|0;if(((d[t+((K|0)/8|0)|0]|0)&128>>>((K&7)>>>0)|0)!=0){K=B+(I+J)|0;a[K]=(d[K]|0|E)&255}J=J+1|0;}while((J|0)<8);G=G+1|0;}while((G|0)<8);D=D+1|0;}while((D|0)<4);x=x+1|0;}while((x|0)<32768);x=c[2443400]|0;if((c[3542200]|0)==0){A=1;i=e;return A|0}B=l+108|0;c[B>>2]=0;t=l+100|0;c[t>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,7)|0;do{if((c[B>>2]|0)!=0){D=c[t>>2]|0;c[m>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](m,7,0)|0;if((D|0)<1){A=1;i=e;return A|0}if((gzL(x,0,7)|0)==0){break}else{A=1}i=e;return A|0}}while(0);x=(c[2443400]|0)+1048576|0;if((c[3542200]|0)==0){A=1;i=e;return A|0}t=j+108|0;c[t>>2]=0;B=j+100|0;c[B>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,8)|0;do{if((c[t>>2]|0)!=0){D=c[B>>2]|0;c[k>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](k,8,0)|0;if((D|0)<1){A=1;i=e;return A|0}if((gzL(x,0,8)|0)==0){break}else{A=1}i=e;return A|0}}while(0);x=c[2443400]|0;blG(x,1048576);B=c[3529600]|0;t=0;do{D=t<<8;gGz(B+D|0,0,256);w=t<<10;C=0;do{G=1<<3-C;E=(c[611632+(C<<2)>>2]|0)+w|0;F=0;do{J=E+(c[3946808+(F<<2)>>2]|0)|0;I=(F<<4)+D|0;H=0;do{K=J+(c[6669416+(H<<2)>>2]|0)|0;if(((d[x+((K|0)/8|0)|0]|0)&128>>>((K&7)>>>0)|0)!=0){K=B+(I+H)|0;a[K]=(d[K]|0|G)&255}H=H+1|0;}while((H|0)<16);F=F+1|0;}while((F|0)<16);C=C+1|0;}while((C|0)<4);t=t+1|0;}while((t|0)<16384);t=c[3527284]|0;if((c[3542200]|0)==0){A=1;i=e;return A|0}B=f+108|0;c[B>>2]=0;x=f+100|0;c[x>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,9)|0;do{if((c[B>>2]|0)!=0){C=c[x>>2]|0;c[g>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](g,9,0)|0;if((C|0)<1){A=1;i=e;return A|0}if((gzL(t,0,9)|0)==0){break}else{A=1}i=e;return A|0}}while(0);fxU(0,425984);if((c[2394]|0)==0){L=c[2112932]|0}else{c[2394]=0;t=c[3532596]|0;c[2112932]=t;x=c[3532592]|0;if((x|0)!=0){gGC(9104152,x|0,280)|0}c[2113054]=c[2113060];L=t}t=c[2388038]|0;x=L|0;B=0;while(1){C=t+B|0;c[x>>2]=C;c[x+131072>>2]=C;C=B+1024|0;if(C>>>0>786431){break}else{x=x+4|0;B=C}}B=c[2388060]|0;c[L+4160>>2]=B;c[L+69696>>2]=B;c[L+135232>>2]=B;x=B+1024|0;c[L+4164>>2]=x;c[L+69700>>2]=x;c[L+135236>>2]=x;x=B+2048|0;c[L+4168>>2]=x;c[L+69704>>2]=x;c[L+135240>>2]=x;x=B+3072|0;c[L+4172>>2]=x;c[L+69708>>2]=x;c[L+135244>>2]=x;x=B+4096|0;c[L+4176>>2]=x;c[L+69712>>2]=x;c[L+135248>>2]=x;x=B+5120|0;c[L+4180>>2]=x;c[L+69716>>2]=x;c[L+135252>>2]=x;x=B+6144|0;c[L+4184>>2]=x;c[L+69720>>2]=x;c[L+135256>>2]=x;x=B+7168|0;c[L+4188>>2]=x;c[L+69724>>2]=x;c[L+135260>>2]=x;x=B+8192|0;c[L+4192>>2]=x;c[L+69728>>2]=x;c[L+135264>>2]=x;x=B+9216|0;c[L+4196>>2]=x;c[L+69732>>2]=x;c[L+135268>>2]=x;x=B+10240|0;c[L+4200>>2]=x;c[L+69736>>2]=x;c[L+135272>>2]=x;x=B+11264|0;c[L+4204>>2]=x;c[L+69740>>2]=x;c[L+135276>>2]=x;x=B+12288|0;c[L+4208>>2]=x;c[L+69744>>2]=x;c[L+135280>>2]=x;x=B+13312|0;c[L+4212>>2]=x;c[L+69748>>2]=x;c[L+135284>>2]=x;x=B+14336|0;c[L+4216>>2]=x;c[L+69752>>2]=x;c[L+135288>>2]=x;x=B+15360|0;c[L+4220>>2]=x;c[L+69756>>2]=x;c[L+135292>>2]=x;x=c[2439626]|0;c[L+5120>>2]=x;c[L+70656>>2]=x;c[L+136192>>2]=x;B=x+1024|0;c[L+5124>>2]=B;c[L+70660>>2]=B;c[L+136196>>2]=B;B=x+2048|0;c[L+5128>>2]=B;c[L+70664>>2]=B;c[L+136200>>2]=B;B=x+3072|0;c[L+5132>>2]=B;c[L+70668>>2]=B;c[L+136204>>2]=B;c[L+196688>>2]=1414;c[L+196728>>2]=2564;c[L+196608>>2]=1998;c[L+196648>>2]=1050;B=c[3532592]|0;if((B|0)!=0){gGC(B|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);B=c[2439330]|0;x=(B|0)==0;if(!x){t=B;gGC(9706056,t|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];t=c[3528484]|0;c[2076596]=t;C=c[2417276]|0;c[3541536]=C;c[1836236]=0;c[B+4180>>2]=3124;c[B+4184>>2]=2566;D=c[2385848]|0;w=0;F=0;while(1){c[B+76+(F<<2)>>2]=D+(F<<8);G=w+1&65535;if((G&65535)>239){M=0;N=0;break}else{w=G;F=G&65535}}while(1){F=D+(N<<8)|0;c[B+76+(N+512<<2)>>2]=F;c[B+76+(N+768<<2)>>2]=F;F=M+1&65535;if((F&65535)>239){break}else{M=F;N=F&65535}}D=c[2385866]|0;c[B+1036>>2]=D;F=D+256|0;c[B+1040>>2]=F;w=D+512|0;c[B+1044>>2]=w;G=D+768|0;c[B+1048>>2]=G;E=D+1024|0;c[B+1052>>2]=E;H=D+1280|0;c[B+1056>>2]=H;I=D+1536|0;c[B+1060>>2]=I;J=D+1792|0;c[B+1064>>2]=J;c[B+2060>>2]=D;c[B+2064>>2]=F;c[B+2068>>2]=w;c[B+2072>>2]=G;c[B+2076>>2]=E;c[B+2080>>2]=H;c[B+2084>>2]=I;c[B+2088>>2]=J;c[B+3084>>2]=D;c[B+4108>>2]=D;c[B+3088>>2]=F;c[B+4112>>2]=F;c[B+3092>>2]=w;c[B+4116>>2]=w;c[B+3096>>2]=G;c[B+4120>>2]=G;c[B+3100>>2]=E;c[B+4124>>2]=E;c[B+3104>>2]=H;c[B+4128>>2]=H;c[B+3108>>2]=I;c[B+4132>>2]=I;c[B+3112>>2]=J;c[B+4136>>2]=J;if(!x){J=B;gGC(J|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=t;c[2417276]=C;c[1836236]=-1;J=a[9680]|0;I=J?32e3:0;if(J){if(a[9624]|0){J=I*3|0;H=55930;while(1){if((H|0)>(J|0)){H=H>>1}else{O=1222;P=H;break}}}else{O=2462;P=I}c[2429380]=P;c[3542124]=O;mw(3579545,P);H=gGq(262144)|0;c[2406684]=H;gGz(H|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(3579545,11025)}h[745421]=1.0;c[2436794]=1;h[745420]=1.0;c[2436792]=2;TN(c[3527284]|0,1048576);h[1209346]=.7;c[2418696]=1;c[2426862]=9674384;h[1209347]=.7;c[2418697]=2;Tq(688456);H=c[642608+(c[2436]<<2)>>2]|0;J=c[H+128>>2]|0;if((c[H+52>>2]&4|0)==0){c[2113068]=J;C=c[H+132>>2]|0;c[2113070]=C;c[2443814]=J;c[2440436]=C;Q=J;R=C}else{c[2113070]=J;C=c[H+132>>2]|0;c[2113068]=C;c[2440436]=J;c[2443814]=C;Q=C;R=J}J=ag(Q<<1,R)|0;C=gGq(J)|0;c[2112926]=C;if((C|0)!=0){gGz(C|0,0,J|0)}if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];J=c[3532592]|0;if((J|0)!=0){gGC(9104152,J|0,280)|0}c[2113054]=c[2113060]}RI();J=c[2394]|0;C=c[14130368+(J<<2)>>2]|0;if((C|0)!=0){gGC(C|0,9104152,280)|0}c[8452240+(J<<2)>>2]=c[2113054];c[2394]=-1;J=c[2439330]|0;C=(J|0)==0;if(!C){H=J;gGC(9706056,H|0,76)|0}H=c[2438118]|0;c[2433530]=H;t=c[3528484]|0;c[2076596]=t;B=c[2417276]|0;c[3541536]=B;c[1836236]=0;gGz(9706056,0,76);if(!C){C=J;gGC(C|0,9706056,76)|0}c[2438118]=H;c[3528484]=t;c[2417276]=B;c[1836236]=-1;mx(0);c[2426862]=9674384;gGz(9674592,0,176);blH();c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];c[2437706]=a[1040128]|0?0:10;c[3541228]=0;a[9545176]=0;c[2415284]=0;c[2415282]=0;A=0;i=e;return A|0}}while(0);c[2426818]=0;A=1;i=e;return A|0}function bcL(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;if((a[9625080]|0)!=0){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;h=c[2417276]|0;c[3541536]=h;c[1836236]=0;gGz(9706056,0,76);if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=h;c[1836236]=-1;mx(0);c[2426862]=9674384;gGz(9674592,0,176);blH();c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];c[2437706]=a[1040128]|0?0:10;c[3541228]=0;a[9545176]=0;c[2415284]=0;c[2415282]=0}bdX();a[9625893]=a[9625893]^-10;c[2440552]=266666;c[2440494]=66666;c[2444121]=0;c[2444120]=0;h=c[2392]|0;if((h|0)>=0){gGz(8452240,0,((h|0)>0?(h<<2)+4|0:4)|0)}c[2113054]=0;h=c[2385548]|0;if((h|0)>0){gGz(9752472,0,((h|0)>1?h<<2:4)|0)}c[2433530]=0;h=0;g=0;L77657:while(1){f=g;while(1){if((f|0)>=262){break L77657}if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060]}i=f+1|0;e=(ag(c[2440552]|0,i)|0)/262|0;d=e-(c[2444120]|0)|0;c[2438210]=d;c[2113056]=d;e=RG(d)|0;c[2113054]=(c[2113054]|0)+e;c[2276108]=-1;c[2113056]=-1;c[2444120]=(c[2444120]|0)+e;do{if((f|0)==19){a[9545176]=0}else if((f|0)==243){a[9545176]=1;if((c[3541228]|0)==0){break}c[8452200+(c[2394]<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0>=1024){break}RH(4)}}while(0);e=c[2394]|0;d=c[14130368+(e<<2)>>2]|0;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[8452240+(e<<2)>>2]=c[2113054];c[2394]=-1;e=c[2439330]|0;if((e|0)!=0){d=e;gGC(9706056,d|0,76)|0}b[4853030]=c[2426515]&65535;d=c[2438118]|0;c[2433530]=d;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;j=(ag(c[2440494]|0,i)|0)/262|0;k=c[2444121]|0;l=j-k|0;c[2438210]=l;do{if((l|0)<1){m=0;n=k;o=0;p=e;q=d}else{if((a[e+4188|0]|0)==0){j=gfc(l)|0;r=(c[2433530]|0)+j|0;c[2433530]=r;s=c[1836236]|0;m=j;n=c[2444121]|0;o=s;p=c[9757320+(s<<2)>>2]|0;q=r;break}else{r=d+l|0;c[2433530]=r;m=l;n=k;o=0;p=e;q=r;break}}}while(0);c[2438210]=m;c[2444121]=n+m;if((p|0)!=0){e=p;gGC(e|0,9706056,76)|0}c[9752472+(o<<2)>>2]=q;c[14113936+(o<<2)>>2]=c[2076596];c[9669104+(o<<2)>>2]=c[3541536];c[1836236]=-1;t=c[2112964]|0;if((t|0)==0){f=i}else{break}}f=a[9688]|0?2:0;e=t+(h<<1<<1)|0;gg[c[3542124]&4095](e,f);TM(e,f);h=f+h|0;g=i}i=c[2112964]|0;do{if((i|0)!=0){g=a[9688]|0?534:0;t=g-h|0;o=i+(h<<1<<1)|0;if((g|0)==(h|0)){break}gg[c[3542124]&4095](o,t);TM(o,t)}}while(0);if((c[2112968]|0)==0){return 0}bd$();return 0}function bcM(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=i;i=i+32|0;e=d|0;f=d+16|0;if((a&64|0)==0){Ts(a,b);bd1(a,b);i=d;return 0}fw$(a);TP(a);gGz(f|0,0,12);c[f>>2]=9750824;c[f+4>>2]=4;c[f+12>>2]=359208;gj[c[2076592]&4095](f)|0;gGz(e|0,0,12);c[e>>2]=9545176;c[e+4>>2]=1;c[e+12>>2]=449152;gj[c[2076592]&4095](e)|0;Ts(a,b);bd1(a,b);i=d;return 0}function bcN(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[955260+(b*112|0)>>2];c[a+104>>2]=c[955264+(b*112|0)>>2];c[a+108>>2]=c[955268+(b*112|0)>>2];d=0;return d|0}function bcO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=955160+(b*112|0);e=0;return e|0}function bcP(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1187224+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function bcQ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[956492+(b*112|0)>>2];c[a+104>>2]=c[956496+(b*112|0)>>2];c[a+108>>2]=c[956500+(b*112|0)>>2];d=0;return d|0}function bcR(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=956392+(b*112|0);e=0;return e|0}function bcS(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[947868+(b*112|0)>>2];c[a+104>>2]=c[947872+(b*112|0)>>2];c[a+108>>2]=c[947876+(b*112|0)>>2];d=0;return d|0}function bcT(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=947768+(b*112|0);e=0;return e|0}function bcU(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>37){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=725208+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function bcV(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[957724+(b*112|0)>>2];c[a+104>>2]=c[957728+(b*112|0)>>2];c[a+108>>2]=c[957732+(b*112|0)>>2];d=0;return d|0}function bcW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=957624+(b*112|0);e=0;return e|0}function bcX(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[951564+(b*112|0)>>2];c[a+104>>2]=c[951568+(b*112|0)>>2];c[a+108>>2]=c[951572+(b*112|0)>>2];d=0;return d|0}function bcY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=951464+(b*112|0);e=0;return e|0}function bcZ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[950332+(b*112|0)>>2];c[a+104>>2]=c[950336+(b*112|0)>>2];c[a+108>>2]=c[950340+(b*112|0)>>2];d=0;return d|0}function bc_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=950232+(b*112|0);e=0;return e|0}function bc$(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[949100+(b*112|0)>>2];c[a+104>>2]=c[949104+(b*112|0)>>2];c[a+108>>2]=c[949108+(b*112|0)>>2];d=0;return d|0}function bc0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=949e3+(b*112|0);e=0;return e|0}function bc1(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[960188+(b*112|0)>>2];c[a+104>>2]=c[960192+(b*112|0)>>2];c[a+108>>2]=c[960196+(b*112|0)>>2];d=0;return d|0}function bc2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=960088+(b*112|0);e=0;return e|0}function bc3(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[958956+(b*112|0)>>2];c[a+104>>2]=c[958960+(b*112|0)>>2];c[a+108>>2]=c[958964+(b*112|0)>>2];d=0;return d|0}function bc4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=958856+(b*112|0);e=0;return e|0}function bc5(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[954028+(b*112|0)>>2];c[a+104>>2]=c[954032+(b*112|0)>>2];c[a+108>>2]=c[954036+(b*112|0)>>2];d=0;return d|0}function bc6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=953928+(b*112|0);e=0;return e|0}function bc7(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[952796+(b*112|0)>>2];c[a+104>>2]=c[952800+(b*112|0)>>2];c[a+108>>2]=c[952804+(b*112|0)>>2];d=0;return d|0}function bc8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=952696+(b*112|0);e=0;return e|0}function bc9(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4358964+(b*112|0)>>2];c[a+104>>2]=c[4358968+(b*112|0)>>2];c[a+108>>2]=c[4358972+(b*112|0)>>2];d=0;return d|0}function bda(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=4358864+(b*112|0);e=0;return e|0}function bdb(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1660992+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function bdc(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;e=i;i=i+720|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;c[2426818]=0;c[2405720]=0;c[2388060]=0;c[2385866]=16384;c[2439626]=18432;c[2411882]=22528;c[2388038]=22528;c[2385848]=546816;c[3527284]=612352;c[3529498]=1136640;c[2443400]=2185216;c[2407018]=3233792;c[3530202]=3241984;c[2405828]=3250240;c[3529600]=5347392;t=0;while(1){if((t|0)>=1024){break}u=9638528+(t<<2)|0;if((c[u>>2]|0)==0){v=60369;break}else{t=t+1|0}}do{if((v|0)==60369){t=gGq(7444544)|0;c[u>>2]=t;if((t|0)==0){break}c[2426818]=t;gGz(t|0,0,7444544);c[2405720]=t;c[2388060]=t;c[2385866]=t+16384;c[2439626]=t+18432;w=t+22528|0;c[2411882]=w;c[2388038]=w;c[2385848]=t+546816;c[3527284]=t+612352;w=t+1136640|0;c[3529498]=w;c[2443400]=t+2185216;c[2407018]=t+3233792;c[3530202]=t+3241984;c[2405828]=t+3250240;c[3529600]=t+5347392;c[2414434]=t+7444544;t=0;while(1){if((t|0)>=1024){x=0;break}y=9638528+(t<<2)|0;if((c[y>>2]|0)==0){v=60374;break}else{t=t+1|0}}do{if((v|0)==60374){t=gGq(24576)|0;c[y>>2]=t;if((t|0)==0){x=0;break}gGz(t|0,0,24576);x=t}}while(0);c[3529062]=x;c[2438700]=1048575;c[3529060]=w;a[7461784]=1;t=9726816;c[t>>2]=0;c[t+4>>2]=0;t=9726800;c[t>>2]=0;c[t+4>>2]=0;c[2429638]=0;c[2437692]=6;c[2431704]=8;c[2431700]=0;c[2431705]=8;c[2431701]=0;c[2431706]=8;c[2431702]=0;t=c[2443400]|0;c[2438136]=0;z=0;while(1){if((z|0)>=1024){A=0;break}B=9638528+(z<<2)|0;if((c[B>>2]|0)==0){v=60379;break}else{z=z+1|0}}do{if((v|0)==60379){z=gGq(1024)|0;c[B>>2]=z;if((z|0)==0){A=0;break}gGz(z|0,0,1024);A=z}}while(0);c[3529066]=A;c[2438702]=1048575;c[3529064]=t;a[7461792]=1;c[2437694]=158;c[2438136]=8;if((R6((c[2388038]|0)+1|0,0,2)|0)!=0){C=1;i=e;return C|0}if((R6(c[2388038]|0,1,2)|0)!=0){C=1;i=e;return C|0}z=c[2385848]|0;if((c[3542200]|0)==0){C=1;i=e;return C|0}w=r+108|0;c[w>>2]=0;D=r+100|0;c[D>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,2)|0;do{if((c[w>>2]|0)!=0){E=c[D>>2]|0;c[s>>2]=9534384;F=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[F&16383](s,2,0)|0;if((E|0)<1){C=1;i=e;return C|0}if((gzL(z,0,2)|0)==0){break}else{C=1}i=e;return C|0}}while(0);z=c[3529498]|0;if((c[3542200]|0)==0){C=1;i=e;return C|0}D=p+108|0;c[D>>2]=0;w=p+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,3)|0;do{if((c[D>>2]|0)!=0){t=c[w>>2]|0;c[q>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](q,3,0)|0;if((t|0)<1){C=1;i=e;return C|0}if((gzL(z,0,3)|0)==0){break}else{C=1}i=e;return C|0}}while(0);z=(c[3529498]|0)+524288|0;if((c[3542200]|0)==0){C=1;i=e;return C|0}w=n+108|0;c[w>>2]=0;D=n+100|0;c[D>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,4)|0;do{if((c[w>>2]|0)!=0){t=c[D>>2]|0;c[o>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](o,4,0)|0;if((t|0)<1){C=1;i=e;return C|0}if((gzL(z,0,4)|0)==0){break}else{C=1}i=e;return C|0}}while(0);z=c[3529498]|0;blG(z,524288);D=c[2405828]|0;w=0;do{t=w<<6;gGz(D+t|0,0,64);E=w<<8;F=0;do{G=1<<3-F;H=(c[611632+(F<<2)>>2]|0)+E|0;I=0;do{J=H+(c[1183816+(I<<2)>>2]|0)|0;K=(I<<3)+t|0;L=0;do{M=J+(c[614800+(L<<2)>>2]|0)|0;if(((d[z+((M|0)/8|0)|0]|0)&128>>>((M&7)>>>0)|0)!=0){M=D+(K+L)|0;a[M]=(d[M]|0|G)&255}L=L+1|0;}while((L|0)<8);I=I+1|0;}while((I|0)<8);F=F+1|0;}while((F|0)<4);w=w+1|0;}while((w|0)<32768);w=c[2443400]|0;if((c[3542200]|0)==0){C=1;i=e;return C|0}D=l+108|0;c[D>>2]=0;z=l+100|0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,5)|0;do{if((c[D>>2]|0)!=0){F=c[z>>2]|0;c[m>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](m,5,0)|0;if((F|0)<1){C=1;i=e;return C|0}if((gzL(w,0,5)|0)==0){break}else{C=1}i=e;return C|0}}while(0);w=(c[2443400]|0)+524288|0;if((c[3542200]|0)==0){C=1;i=e;return C|0}z=j+108|0;c[z>>2]=0;D=j+100|0;c[D>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,6)|0;do{if((c[z>>2]|0)!=0){F=c[D>>2]|0;c[k>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](k,6,0)|0;if((F|0)<1){C=1;i=e;return C|0}if((gzL(w,0,6)|0)==0){break}else{C=1}i=e;return C|0}}while(0);w=c[2443400]|0;blG(w,524288);D=c[3529600]|0;z=0;do{F=z<<8;gGz(D+F|0,0,256);t=z<<10;E=0;do{I=1<<3-E;G=(c[611400+(E<<2)>>2]|0)+t|0;H=0;do{L=G+(c[3946808+(H<<2)>>2]|0)|0;K=(H<<4)+F|0;J=0;do{M=L+(c[6669416+(J<<2)>>2]|0)|0;if(((d[w+((M|0)/8|0)|0]|0)&128>>>((M&7)>>>0)|0)!=0){M=D+(K+J)|0;a[M]=(d[M]|0|I)&255}J=J+1|0;}while((J|0)<16);H=H+1|0;}while((H|0)<16);E=E+1|0;}while((E|0)<4);z=z+1|0;}while((z|0)<8192);z=c[3527284]|0;if((c[3542200]|0)==0){C=1;i=e;return C|0}D=f+108|0;c[D>>2]=0;w=f+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,7)|0;do{if((c[D>>2]|0)!=0){E=c[w>>2]|0;c[g>>2]=9534384;F=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[F&16383](g,7,0)|0;if((E|0)<1){C=1;i=e;return C|0}if((gzL(z,0,7)|0)==0){break}else{C=1}i=e;return C|0}}while(0);fxU(0,425984);if((c[2394]|0)==0){N=c[2112932]|0}else{c[2394]=0;z=c[3532596]|0;c[2112932]=z;w=c[3532592]|0;if((w|0)!=0){gGC(9104152,w|0,280)|0}c[2113054]=c[2113060];N=z}z=c[2388038]|0;w=N|0;D=0;while(1){E=z+D|0;c[w>>2]=E;c[w+131072>>2]=E;E=D+1024|0;if(E>>>0>262143){break}else{w=w+4|0;D=E}}D=c[2388060]|0;c[N+4096>>2]=D;c[N+69632>>2]=D;c[N+135168>>2]=D;w=D+1024|0;c[N+4100>>2]=w;c[N+69636>>2]=w;c[N+135172>>2]=w;w=D+2048|0;c[N+4104>>2]=w;c[N+69640>>2]=w;c[N+135176>>2]=w;w=D+3072|0;c[N+4108>>2]=w;c[N+69644>>2]=w;c[N+135180>>2]=w;w=D+4096|0;c[N+4112>>2]=w;c[N+69648>>2]=w;c[N+135184>>2]=w;w=D+5120|0;c[N+4116>>2]=w;c[N+69652>>2]=w;c[N+135188>>2]=w;w=D+6144|0;c[N+4120>>2]=w;c[N+69656>>2]=w;c[N+135192>>2]=w;w=D+7168|0;c[N+4124>>2]=w;c[N+69660>>2]=w;c[N+135196>>2]=w;w=D+8192|0;c[N+4128>>2]=w;c[N+69664>>2]=w;c[N+135200>>2]=w;w=D+9216|0;c[N+4132>>2]=w;c[N+69668>>2]=w;c[N+135204>>2]=w;w=D+10240|0;c[N+4136>>2]=w;c[N+69672>>2]=w;c[N+135208>>2]=w;w=D+11264|0;c[N+4140>>2]=w;c[N+69676>>2]=w;c[N+135212>>2]=w;w=D+12288|0;c[N+4144>>2]=w;c[N+69680>>2]=w;c[N+135216>>2]=w;w=D+13312|0;c[N+4148>>2]=w;c[N+69684>>2]=w;c[N+135220>>2]=w;w=D+14336|0;c[N+4152>>2]=w;c[N+69688>>2]=w;c[N+135224>>2]=w;w=D+15360|0;c[N+4156>>2]=w;c[N+69692>>2]=w;c[N+135228>>2]=w;w=c[2439626]|0;c[N+8192>>2]=w;c[N+73728>>2]=w;c[N+139264>>2]=w;D=w+1024|0;c[N+8196>>2]=D;c[N+73732>>2]=D;c[N+139268>>2]=D;D=w+2048|0;c[N+8200>>2]=D;c[N+73736>>2]=D;c[N+139272>>2]=D;D=w+3072|0;c[N+8204>>2]=D;c[N+73740>>2]=D;c[N+139276>>2]=D;c[N+196728>>2]=2588;c[N+196608>>2]=2364;c[N+196648>>2]=2062;D=c[3532592]|0;if((D|0)!=0){gGC(D|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);D=c[2439330]|0;w=(D|0)==0;if(!w){z=D;gGC(9706056,z|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];z=c[3528484]|0;c[2076596]=z;E=c[2417276]|0;c[3541536]=E;c[1836236]=0;c[D+4180>>2]=866;c[D+4184>>2]=1694;F=c[2385848]|0;t=0;H=0;while(1){c[D+76+(H<<2)>>2]=F+(H<<8);I=t+1&65535;if((I&65535)>239){O=0;P=0;break}else{t=I;H=I&65535}}while(1){H=F+(P<<8)|0;c[D+76+(P+512<<2)>>2]=H;c[D+76+(P+768<<2)>>2]=H;H=O+1&65535;if((H&65535)>239){break}else{O=H;P=H&65535}}F=c[2385866]|0;c[D+1036>>2]=F;H=F+256|0;c[D+1040>>2]=H;t=F+512|0;c[D+1044>>2]=t;I=F+768|0;c[D+1048>>2]=I;G=F+1024|0;c[D+1052>>2]=G;J=F+1280|0;c[D+1056>>2]=J;K=F+1536|0;c[D+1060>>2]=K;L=F+1792|0;c[D+1064>>2]=L;c[D+2060>>2]=F;c[D+2064>>2]=H;c[D+2068>>2]=t;c[D+2072>>2]=I;c[D+2076>>2]=G;c[D+2080>>2]=J;c[D+2084>>2]=K;c[D+2088>>2]=L;c[D+3084>>2]=F;c[D+4108>>2]=F;c[D+3088>>2]=H;c[D+4112>>2]=H;c[D+3092>>2]=t;c[D+4116>>2]=t;c[D+3096>>2]=I;c[D+4120>>2]=I;c[D+3100>>2]=G;c[D+4124>>2]=G;c[D+3104>>2]=J;c[D+4128>>2]=J;c[D+3108>>2]=K;c[D+4132>>2]=K;c[D+3112>>2]=L;c[D+4136>>2]=L;if(!w){L=D;gGC(L|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=z;c[2417276]=E;c[1836236]=-1;L=a[9680]|0;K=L?32e3:0;if(L){if(a[9624]|0){L=K*3|0;J=55930;while(1){if((J|0)>(L|0)){J=J>>1}else{Q=1222;R=J;break}}}else{Q=2462;R=K}c[2429380]=R;c[3542124]=Q;mw(3579545,R);J=gGq(262144)|0;c[2406684]=J;gGz(J|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(3579545,11025)}h[745421]=1.0;c[2436794]=1;h[745420]=1.0;c[2436792]=2;TN(c[3527284]|0,524288);h[1209346]=.75;c[2418696]=1;c[2426862]=9674384;h[1209347]=.75;c[2418697]=2;Tq(683288);J=c[642608+(c[2436]<<2)>>2]|0;L=c[J+128>>2]|0;if((c[J+52>>2]&4|0)==0){c[2113068]=L;E=c[J+132>>2]|0;c[2113070]=E;c[2443814]=L;c[2440436]=E;S=L;T=E}else{c[2113070]=L;E=c[J+132>>2]|0;c[2113068]=E;c[2440436]=L;c[2443814]=E;S=E;T=L}L=ag(S<<1,T)|0;E=gGq(L)|0;c[2112926]=E;if((E|0)!=0){gGz(E|0,0,L|0)}if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];L=c[3532592]|0;if((L|0)!=0){gGC(9104152,L|0,280)|0}c[2113054]=c[2113060]}RI();L=c[2394]|0;E=c[14130368+(L<<2)>>2]|0;if((E|0)!=0){gGC(E|0,9104152,280)|0}c[8452240+(L<<2)>>2]=c[2113054];c[2394]=-1;L=c[2439330]|0;E=(L|0)==0;if(!E){J=L;gGC(9706056,J|0,76)|0}J=c[2438118]|0;c[2433530]=J;z=c[3528484]|0;c[2076596]=z;D=c[2417276]|0;c[3541536]=D;c[1836236]=0;gGz(9706056,0,76);if(!E){E=L;gGC(E|0,9706056,76)|0}c[2438118]=J;c[3528484]=z;c[2417276]=D;c[1836236]=-1;mx(0);c[2426862]=9674384;gGz(9674592,0,176);blH();c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];c[2437706]=a[1040128]|0?0:10;c[3541228]=0;a[9545176]=0;c[2415284]=0;c[2415282]=0;C=0;i=e;return C|0}}while(0);c[2426818]=0;C=1;i=e;return C|0}function bdd(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;if((a[9625080]|0)!=0){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060]}RI();e=c[2394]|0;f=c[14130368+(e<<2)>>2]|0;if((f|0)!=0){gGC(f|0,9104152,280)|0}c[8452240+(e<<2)>>2]=c[2113054];c[2394]=-1;e=c[2439330]|0;f=(e|0)==0;if(!f){g=e;gGC(9706056,g|0,76)|0}g=c[2438118]|0;c[2433530]=g;h=c[3528484]|0;c[2076596]=h;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);if(!f){f=e;gGC(f|0,9706056,76)|0}c[2438118]=g;c[3528484]=h;c[2417276]=i;c[1836236]=-1;mx(0);c[2426862]=9674384;gGz(9674592,0,176);blH();c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];c[2437706]=a[1040128]|0?0:10;c[3541228]=0;a[9545176]=0;c[2415284]=0;c[2415282]=0}bdX();c[2440552]=2e5;c[2440494]=59659;c[2444121]=0;c[2444120]=0;i=c[2392]|0;if((i|0)>=0){gGz(8452240,0,((i|0)>0?(i<<2)+4|0:4)|0)}c[2113054]=0;i=c[2385548]|0;if((i|0)>0){gGz(9752472,0,((i|0)>1?i<<2:4)|0)}c[2433530]=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];i=c[3532592]|0;if((i|0)!=0){gGC(9104152,i|0,280)|0}c[2113054]=c[2113060]}i=c[2439330]|0;if((i|0)!=0){h=i;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;h=0;i=0;L78093:while(1){g=i;do{if((g|0)>=100){break L78093}g=g+1|0;f=(ag(c[2440552]|0,g)|0)/100|0;e=f-(c[2444120]|0)|0;c[2438210]=e;c[2113056]=e;f=RG(e)|0;c[2113054]=(c[2113054]|0)+f;c[2276108]=-1;c[2113056]=-1;c[2444120]=(c[2444120]|0)+f;f=(ag(c[2440494]|0,g)|0)/100|0;e=c[2444121]|0;j=f-e|0;c[2438210]=j;do{if((j|0)<1){k=0;l=e}else{if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){f=gfc(j)|0;c[2433530]=(c[2433530]|0)+f;k=f;l=c[2444121]|0;break}else{c[2433530]=(c[2433530]|0)+j;k=j;l=e;break}}}while(0);c[2438210]=k;c[2444121]=l+k;m=c[2112964]|0;}while((m|0)==0);e=a[9688]|0?5:0;j=m+(h<<1<<1)|0;gg[c[3542124]&4095](j,e);TM(j,e);h=e+h|0;i=g}do{if((c[3541228]|0)!=0){c[8452200+(c[2394]<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0>=1024){break}RH(4)}}while(0);i=c[2112964]|0;do{if((i|0)!=0){m=a[9688]|0?534:0;k=m-h|0;l=i+(h<<1<<1)|0;if((m|0)==(h|0)){break}gg[c[3542124]&4095](l,k);TM(l,k)}}while(0);h=c[1836236]|0;i=c[9757320+(h<<2)>>2]|0;if((i|0)!=0){k=i;gGC(k|0,9706056,76)|0}c[9752472+(h<<2)>>2]=c[2433530];c[14113936+(h<<2)>>2]=c[2076596];c[9669104+(h<<2)>>2]=c[3541536];c[1836236]=-1;h=c[2394]|0;k=c[14130368+(h<<2)>>2]|0;if((k|0)!=0){gGC(k|0,9104152,280)|0}c[8452240+(h<<2)>>2]=c[2113054];c[2394]=-1;if((c[2112968]|0)==0){return 0}h=c[2439626]|0;k=c[2407018]|0;i=c[3530202]|0;l=0;do{m=b[h+(l<<1)>>1]|0;e=m&255;j=((e&255)>>>2&7|e<<3)&255;e=((m&65535)>>>7&7|(m&65535)>>>5<<3&255)&255;f=((m&65535)>>>12&7|(m&65535)>>>10<<3&255)&255;c[k+(l<<2)>>2]=e<<8|f|j<<16;c[i+(l<<2)>>2]=e<<3&2016|f>>>3|j<<8&63488;l=l+1|0;}while((l|0)<2048);bpj();l=c[2437682]|0;c[2433324]=c[2437683];c[2437650]=c[2437684];c[2437651]=c[2437686];c[2437652]=c[2437685];i=d[14116146]|0;c[2405780]=i;k=d[14116148]|0;c[2405781]=k;c[2405782]=d[14116147]|0;h=ag(c[2113070]|0,c[2113068]|0)|0;if((h|0)>0){j=l<<4&65535;l=c[2112926]|0;f=0;do{b[l+(f<<1)>>1]=j;f=f+1|0;}while((f|0)<(h|0));n=c[2405780]|0;o=c[2405781]|0}else{n=i;o=k}if((n|0)<(o|0)){c[2405780]=o;c[2405781]=n;p=o;q=1;r=0;s=n}else{p=n;q=0;r=1;s=o}o=c[2405782]|0;if((p|0)<(o|0)){c[2405780]=o;c[2405782]=p;t=p;u=2;v=q}else{t=o;u=q;v=2}if((s|0)<(t|0)){c[2405781]=t;c[2405782]=s;w=v;x=r}else{w=r;x=v}bpl(c[3529600]|0,3);bpk(u,0,c[2405828]|0);bpl(c[3529600]|0,2);bpk(w,0,c[2405828]|0);bpl(c[3529600]|0,1);bpl(c[3529600]|0,0);bpk(x,0,c[2405828]|0);R8(c[3530202]|0);return 0}function bde(a,b){a=a|0;b=b|0;if((a&64|0)!=0){fw$(a);TP(a)}bd1(a,b);return 0}function bdf(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2161196+(b*112|0)>>2];c[a+104>>2]=c[2161200+(b*112|0)>>2];c[a+108>>2]=c[2161204+(b*112|0)>>2];d=0;return d|0}function bdg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=2161096+(b*112|0);e=0;return e|0}function bdh(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2160188+(b*112|0)>>2];c[a+104>>2]=c[2160192+(b*112|0)>>2];c[a+108>>2]=c[2160196+(b*112|0)>>2];d=0;return d|0}function bdi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=2160088+(b*112|0);e=0;return e|0}function bdj(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2641020+(b*112|0)>>2];c[a+104>>2]=c[2641024+(b*112|0)>>2];c[a+108>>2]=c[2641028+(b*112|0)>>2];d=0;return d|0}function bdk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=2640920+(b*112|0);e=0;return e|0}function bdl(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1234992+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function bdm(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>63){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3798104+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function bdn(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;e=i;i=i+720|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;c[2426818]=0;c[2405720]=0;c[2388060]=0;c[2385866]=16384;c[2439626]=18432;c[2443436]=22528;c[2411882]=38912;c[2388038]=38912;c[2385848]=563200;c[3527284]=628736;c[3529498]=1153024;c[2443400]=2201600;c[2407018]=3250176;c[3530202]=3258368;c[2405828]=3266624;c[3529600]=5363776;t=0;while(1){if((t|0)>=1024){break}u=9638528+(t<<2)|0;if((c[u>>2]|0)==0){v=60602;break}else{t=t+1|0}}do{if((v|0)==60602){t=gGq(7460928)|0;c[u>>2]=t;if((t|0)==0){break}c[2426818]=t;gGz(t|0,0,7460928);c[2405720]=t;c[2388060]=t;c[2385866]=t+16384;c[2439626]=t+18432;c[2443436]=t+22528;w=t+38912|0;c[2411882]=w;c[2388038]=w;c[2385848]=t+563200;c[3527284]=t+628736;w=t+1153024|0;c[3529498]=w;c[2443400]=t+2201600;c[2407018]=t+3250176;c[3530202]=t+3258368;c[2405828]=t+3266624;c[3529600]=t+5363776;c[2414434]=t+7460928;t=0;while(1){if((t|0)>=1024){x=0;break}y=9638528+(t<<2)|0;if((c[y>>2]|0)==0){v=60607;break}else{t=t+1|0}}do{if((v|0)==60607){t=gGq(24576)|0;c[y>>2]=t;if((t|0)==0){x=0;break}gGz(t|0,0,24576);x=t}}while(0);c[3529062]=x;c[2438700]=1048575;c[3529060]=w;a[7461784]=1;t=9726816;c[t>>2]=0;c[t+4>>2]=0;t=9726800;c[t>>2]=0;c[t+4>>2]=0;c[2429638]=0;c[2437692]=6;c[2431704]=8;c[2431700]=0;c[2431705]=8;c[2431701]=0;c[2431706]=8;c[2431702]=0;biH(c[2443400]|0,1048575,118);c[3529052]=-368;c[3529050]=528;a[7461816]=1;if((R6((c[2388038]|0)+1|0,0,2)|0)!=0){z=1;i=e;return z|0}if((R6(c[2388038]|0,1,2)|0)!=0){z=1;i=e;return z|0}t=c[2385848]|0;if((c[3542200]|0)==0){z=1;i=e;return z|0}A=r+108|0;c[A>>2]=0;B=r+100|0;c[B>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,2)|0;do{if((c[A>>2]|0)!=0){C=c[B>>2]|0;c[s>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](s,2,0)|0;if((C|0)<1){z=1;i=e;return z|0}if((gzL(t,0,2)|0)==0){break}else{z=1}i=e;return z|0}}while(0);t=c[3529498]|0;if((c[3542200]|0)==0){z=1;i=e;return z|0}B=p+108|0;c[B>>2]=0;A=p+100|0;c[A>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,3)|0;do{if((c[B>>2]|0)!=0){w=c[A>>2]|0;c[q>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](q,3,0)|0;if((w|0)<1){z=1;i=e;return z|0}if((gzL(t,0,3)|0)==0){break}else{z=1}i=e;return z|0}}while(0);t=(c[3529498]|0)+524288|0;if((c[3542200]|0)==0){z=1;i=e;return z|0}A=n+108|0;c[A>>2]=0;B=n+100|0;c[B>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,4)|0;do{if((c[A>>2]|0)!=0){w=c[B>>2]|0;c[o>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](o,4,0)|0;if((w|0)<1){z=1;i=e;return z|0}if((gzL(t,0,4)|0)==0){break}else{z=1}i=e;return z|0}}while(0);t=c[3529498]|0;blG(t,524288);B=c[2405828]|0;A=0;do{w=A<<6;gGz(B+w|0,0,64);C=A<<8;D=0;do{E=1<<3-D;F=(c[611632+(D<<2)>>2]|0)+C|0;G=0;do{H=F+(c[1183816+(G<<2)>>2]|0)|0;I=(G<<3)+w|0;J=0;do{K=H+(c[614800+(J<<2)>>2]|0)|0;if(((d[t+((K|0)/8|0)|0]|0)&128>>>((K&7)>>>0)|0)!=0){K=B+(I+J)|0;a[K]=(d[K]|0|E)&255}J=J+1|0;}while((J|0)<8);G=G+1|0;}while((G|0)<8);D=D+1|0;}while((D|0)<4);A=A+1|0;}while((A|0)<32768);A=c[2443400]|0;if((c[3542200]|0)==0){z=1;i=e;return z|0}B=l+108|0;c[B>>2]=0;t=l+100|0;c[t>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,5)|0;do{if((c[B>>2]|0)!=0){D=c[t>>2]|0;c[m>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](m,5,0)|0;if((D|0)<1){z=1;i=e;return z|0}if((gzL(A,0,5)|0)==0){break}else{z=1}i=e;return z|0}}while(0);A=(c[2443400]|0)+524288|0;if((c[3542200]|0)==0){z=1;i=e;return z|0}t=j+108|0;c[t>>2]=0;B=j+100|0;c[B>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,6)|0;do{if((c[t>>2]|0)!=0){D=c[B>>2]|0;c[k>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](k,6,0)|0;if((D|0)<1){z=1;i=e;return z|0}if((gzL(A,0,6)|0)==0){break}else{z=1}i=e;return z|0}}while(0);A=c[2443400]|0;blG(A,524288);B=c[3529600]|0;t=0;do{D=t<<8;gGz(B+D|0,0,256);w=t<<10;C=0;do{G=1<<3-C;E=(c[611632+(C<<2)>>2]|0)+w|0;F=0;do{J=E+(c[3946808+(F<<2)>>2]|0)|0;I=(F<<4)+D|0;H=0;do{K=J+(c[6669416+(H<<2)>>2]|0)|0;if(((d[A+((K|0)/8|0)|0]|0)&128>>>((K&7)>>>0)|0)!=0){K=B+(I+H)|0;a[K]=(d[K]|0|G)&255}H=H+1|0;}while((H|0)<16);F=F+1|0;}while((F|0)<16);C=C+1|0;}while((C|0)<4);t=t+1|0;}while((t|0)<8192);t=c[3527284]|0;if((c[3542200]|0)==0){z=1;i=e;return z|0}B=f+108|0;c[B>>2]=0;A=f+100|0;c[A>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,7)|0;do{if((c[B>>2]|0)!=0){C=c[A>>2]|0;c[g>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](g,7,0)|0;if((C|0)<1){z=1;i=e;return z|0}if((gzL(t,0,7)|0)==0){break}else{z=1}i=e;return z|0}}while(0);fxU(0,425984);if((c[2394]|0)==0){L=c[2112932]|0}else{c[2394]=0;t=c[3532596]|0;c[2112932]=t;A=c[3532592]|0;if((A|0)!=0){gGC(9104152,A|0,280)|0}c[2113054]=c[2113060];L=t}t=c[2388038]|0;A=L|0;B=0;while(1){C=t+B|0;c[A>>2]=C;c[A+131072>>2]=C;C=B+1024|0;if(C>>>0>262143){break}else{A=A+4|0;B=C}}B=c[2439626]|0;c[L+2048>>2]=B;c[L+67584>>2]=B;c[L+133120>>2]=B;A=B+1024|0;c[L+2052>>2]=A;c[L+67588>>2]=A;c[L+133124>>2]=A;A=B+2048|0;c[L+2056>>2]=A;c[L+67592>>2]=A;c[L+133128>>2]=A;A=B+3072|0;c[L+2060>>2]=A;c[L+67596>>2]=A;c[L+133132>>2]=A;A=c[2388060]|0;c[L+2304>>2]=A;c[L+67840>>2]=A;c[L+133376>>2]=A;B=A+1024|0;c[L+2308>>2]=B;c[L+67844>>2]=B;c[L+133380>>2]=B;B=A+2048|0;c[L+2312>>2]=B;c[L+67848>>2]=B;c[L+133384>>2]=B;B=A+3072|0;c[L+2316>>2]=B;c[L+67852>>2]=B;c[L+133388>>2]=B;B=A+4096|0;c[L+2320>>2]=B;c[L+67856>>2]=B;c[L+133392>>2]=B;B=A+5120|0;c[L+2324>>2]=B;c[L+67860>>2]=B;c[L+133396>>2]=B;B=A+6144|0;c[L+2328>>2]=B;c[L+67864>>2]=B;c[L+133400>>2]=B;B=A+7168|0;c[L+2332>>2]=B;c[L+67868>>2]=B;c[L+133404>>2]=B;B=A+8192|0;c[L+2336>>2]=B;c[L+67872>>2]=B;c[L+133408>>2]=B;B=A+9216|0;c[L+2340>>2]=B;c[L+67876>>2]=B;c[L+133412>>2]=B;B=A+10240|0;c[L+2344>>2]=B;c[L+67880>>2]=B;c[L+133416>>2]=B;B=A+11264|0;c[L+2348>>2]=B;c[L+67884>>2]=B;c[L+133420>>2]=B;B=A+12288|0;c[L+2352>>2]=B;c[L+67888>>2]=B;c[L+133424>>2]=B;B=A+13312|0;c[L+2356>>2]=B;c[L+67892>>2]=B;c[L+133428>>2]=B;B=A+14336|0;c[L+2360>>2]=B;c[L+67896>>2]=B;c[L+133432>>2]=B;B=A+15360|0;c[L+2364>>2]=B;c[L+67900>>2]=B;c[L+133436>>2]=B;c[L+196688>>2]=3216;c[L+196728>>2]=20;c[L+196608>>2]=2602;c[L+196648>>2]=922;B=c[3532592]|0;if((B|0)!=0){gGC(B|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);B=c[2439330]|0;A=(B|0)==0;if(!A){t=B;gGC(9706056,t|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];t=c[3528484]|0;c[2076596]=t;C=c[2417276]|0;c[3541536]=C;c[1836236]=0;c[B+4180>>2]=1886;c[B+4184>>2]=404;D=c[2385848]|0;w=0;F=0;while(1){c[B+76+(F<<2)>>2]=D+(F<<8);G=w+1&65535;if((G&65535)>127){M=0;N=0;break}else{w=G;F=G&65535}}while(1){F=D+(N<<8)|0;c[B+76+(N+512<<2)>>2]=F;c[B+76+(N+768<<2)>>2]=F;F=M+1&65535;if((F&65535)>127){break}else{M=F;N=F&65535}}D=c[2385866]|0;c[B+588>>2]=D;F=D+256|0;c[B+592>>2]=F;w=D+512|0;c[B+596>>2]=w;G=D+768|0;c[B+600>>2]=G;E=D+1024|0;c[B+604>>2]=E;H=D+1280|0;c[B+608>>2]=H;I=D+1536|0;c[B+612>>2]=I;J=D+1792|0;c[B+616>>2]=J;c[B+1612>>2]=D;c[B+1616>>2]=F;c[B+1620>>2]=w;c[B+1624>>2]=G;c[B+1628>>2]=E;c[B+1632>>2]=H;c[B+1636>>2]=I;c[B+1640>>2]=J;c[B+2636>>2]=D;c[B+3660>>2]=D;c[B+2640>>2]=F;c[B+3664>>2]=F;c[B+2644>>2]=w;c[B+3668>>2]=w;c[B+2648>>2]=G;c[B+3672>>2]=G;c[B+2652>>2]=E;c[B+3676>>2]=E;c[B+2656>>2]=H;c[B+3680>>2]=H;c[B+2660>>2]=I;c[B+3684>>2]=I;c[B+2664>>2]=J;c[B+3688>>2]=J;if(!A){J=B;gGC(J|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=t;c[2417276]=C;c[1836236]=-1;J=a[9680]|0;I=J?32e3:0;if(J){if(a[9624]|0){J=I*3|0;H=55930;while(1){if((H|0)>(J|0)){H=H>>1}else{O=1222;P=H;break}}}else{O=2462;P=I}c[2429380]=P;c[3542124]=O;mw(3579545,P);H=gGq(262144)|0;c[2406684]=H;gGz(H|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(3579545,11025)}h[745421]=1.0;c[2436794]=1;h[745420]=1.0;c[2436792]=2;TN(c[3527284]|0,524288);h[1209346]=.7;c[2418696]=1;c[2426862]=9674384;h[1209347]=.7;c[2418697]=2;Tq(683288);H=c[642608+(c[2436]<<2)>>2]|0;J=c[H+128>>2]|0;if((c[H+52>>2]&4|0)==0){c[2113068]=J;C=c[H+132>>2]|0;c[2113070]=C;c[2443814]=J;c[2440436]=C;Q=J;R=C}else{c[2113070]=J;C=c[H+132>>2]|0;c[2113068]=C;c[2440436]=J;c[2443814]=C;Q=C;R=J}J=ag(Q<<1,R)|0;C=gGq(J)|0;c[2112926]=C;if((C|0)!=0){gGz(C|0,0,J|0)}if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];J=c[3532592]|0;if((J|0)!=0){gGC(9104152,J|0,280)|0}c[2113054]=c[2113060]}RI();J=c[2394]|0;C=c[14130368+(J<<2)>>2]|0;if((C|0)!=0){gGC(C|0,9104152,280)|0}c[8452240+(J<<2)>>2]=c[2113054];c[2394]=-1;J=c[2439330]|0;C=(J|0)==0;if(!C){H=J;gGC(9706056,H|0,76)|0}H=c[2438118]|0;c[2433530]=H;t=c[3528484]|0;c[2076596]=t;B=c[2417276]|0;c[3541536]=B;c[1836236]=0;gGz(9706056,0,76);if(!C){C=J;gGC(C|0,9706056,76)|0}c[2438118]=H;c[3528484]=t;c[2417276]=B;c[1836236]=-1;mx(0);c[2426862]=9674384;gGz(9674592,0,176);blH();c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];c[2437706]=a[1040128]|0?0:10;c[3541228]=0;a[9545176]=0;c[2415284]=0;c[2415282]=0;z=0;i=e;return z|0}}while(0);c[2426818]=0;z=1;i=e;return z|0}function bdo(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if((a[9625080]|0)!=0){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;h=c[2417276]|0;c[3541536]=h;c[1836236]=0;gGz(9706056,0,76);if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=h;c[1836236]=-1;mx(0);c[2426862]=9674384;gGz(9674592,0,176);blH();c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];c[2437706]=a[1040128]|0?0:10;c[3541228]=0;a[9545176]=0;c[2415284]=0;c[2415282]=0}bdX();c[2440552]=2e5;c[2440494]=59659;c[2444121]=0;c[2444120]=0;h=c[2392]|0;if((h|0)>=0){gGz(8452240,0,((h|0)>0?(h<<2)+4|0:4)|0)}c[2113054]=0;h=c[2385548]|0;if((h|0)>0){gGz(9752472,0,((h|0)>1?h<<2:4)|0)}c[2433530]=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];h=c[3532592]|0;if((h|0)!=0){gGC(9104152,h|0,280)|0}c[2113054]=c[2113060]}h=c[2439330]|0;if((h|0)!=0){g=h;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;g=0;h=0;L78403:while(1){f=h;do{if((f|0)>=100){break L78403}f=f+1|0;e=(ag(c[2440552]|0,f)|0)/100|0;d=e-(c[2444120]|0)|0;c[2438210]=d;c[2113056]=d;e=RG(d)|0;c[2113054]=(c[2113054]|0)+e;c[2276108]=-1;c[2113056]=-1;c[2444120]=(c[2444120]|0)+e;e=(ag(c[2440494]|0,f)|0)/100|0;d=c[2444121]|0;i=e-d|0;c[2438210]=i;do{if((i|0)<1){j=0;k=d}else{if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){e=gfc(i)|0;c[2433530]=(c[2433530]|0)+e;j=e;k=c[2444121]|0;break}else{c[2433530]=(c[2433530]|0)+i;j=i;k=d;break}}}while(0);c[2438210]=j;c[2444121]=k+j;l=c[2112964]|0;}while((l|0)==0);d=a[9688]|0?5:0;i=l+(g<<1<<1)|0;gg[c[3542124]&4095](i,d);TM(i,d);g=d+g|0;h=f}do{if((c[3541228]|0)!=0){c[8452200+(c[2394]<<2)>>2]=8197;c[2276080]=1280;if((c[2276079]|0)>>>0>=1280){break}RH(5)}}while(0);h=c[2112964]|0;do{if((h|0)!=0){l=a[9688]|0?534:0;j=l-g|0;k=h+(g<<1<<1)|0;if((l|0)==(g|0)){break}gg[c[3542124]&4095](k,j);TM(k,j)}}while(0);g=c[1836236]|0;h=c[9757320+(g<<2)>>2]|0;if((h|0)!=0){j=h;gGC(j|0,9706056,76)|0}c[9752472+(g<<2)>>2]=c[2433530];c[14113936+(g<<2)>>2]=c[2076596];c[9669104+(g<<2)>>2]=c[3541536];c[1836236]=-1;g=c[2394]|0;j=c[14130368+(g<<2)>>2]|0;if((j|0)!=0){gGC(j|0,9104152,280)|0}c[8452240+(g<<2)>>2]=c[2113054];c[2394]=-1;if((c[2112968]|0)==0){return 0}bd$();return 0}function bdp(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1511100+(b*112|0)>>2];c[a+104>>2]=c[1511104+(b*112|0)>>2];c[a+108>>2]=c[1511108+(b*112|0)>>2];d=0;return d|0}function bdq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=1511e3+(b*112|0);e=0;return e|0}function bdr(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1511996+(b*112|0)>>2];c[a+104>>2]=c[1512e3+(b*112|0)>>2];c[a+108>>2]=c[1512004+(b*112|0)>>2];d=0;return d|0}function bds(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=1511896+(b*112|0);e=0;return e|0}function bdt(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5641364+(b*112|0)>>2];c[a+104>>2]=c[5641368+(b*112|0)>>2];c[a+108>>2]=c[5641372+(b*112|0)>>2];d=0;return d|0}function bdu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=5641264+(b*112|0);e=0;return e|0}function bdv(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6475020+(b*112|0)>>2];c[a+104>>2]=c[6475024+(b*112|0)>>2];c[a+108>>2]=c[6475028+(b*112|0)>>2];d=0;return d|0}function bdw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=6474920+(b*112|0);e=0;return e|0}function bdx(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;e=i;i=i+960|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;c[2426818]=0;c[2388038]=0;c[2385848]=1048576;c[3527284]=1114112;c[3529498]=3211264;c[2443400]=4259840;c[2405720]=8454144;c[2388060]=8454144;c[2385866]=8474752;c[2439626]=8476800;c[2443436]=8480896;c[2411882]=8497280;c[2407018]=8497280;c[3530202]=8505472;c[2405828]=8513728;c[3529600]=10610880;x=0;while(1){if((x|0)>=1024){break}y=9638528+(x<<2)|0;if((c[y>>2]|0)==0){z=60813;break}else{x=x+1|0}}do{if((z|0)==60813){x=gGq(18999488)|0;c[y>>2]=x;if((x|0)==0){break}c[2426818]=x;gGz(x|0,0,18999488);c[2388038]=x;c[2385848]=x+1048576;c[3527284]=x+1114112;A=x+3211264|0;c[3529498]=A;c[2443400]=x+4259840;B=x+8454144|0;c[2405720]=B;c[2388060]=B;c[2385866]=x+8474752;c[2439626]=x+8476800;c[2443436]=x+8480896;B=x+8497280|0;c[2411882]=B;c[2407018]=B;c[3530202]=x+8505472;c[2405828]=x+8513728;c[3529600]=x+10610880;c[2414434]=x+18999488;x=0;while(1){if((x|0)>=1024){C=0;break}D=9638528+(x<<2)|0;if((c[D>>2]|0)==0){z=60818;break}else{x=x+1|0}}do{if((z|0)==60818){x=gGq(24576)|0;c[D>>2]=x;if((x|0)==0){C=0;break}gGz(x|0,0,24576);C=x}}while(0);c[3529062]=C;c[2438700]=1048575;c[3529060]=A;a[7461784]=1;x=9726816;c[x>>2]=0;c[x+4>>2]=0;x=9726800;c[x>>2]=0;c[x+4>>2]=0;c[2429638]=0;c[2437692]=6;c[2431704]=8;c[2431700]=0;c[2431705]=8;c[2431701]=0;c[2431706]=8;c[2431702]=0;biH(c[2443400]|0,4194303,128);c[3529052]=-368;c[3529050]=272;a[7461816]=1;if((R6((c[2388038]|0)+1|0,0,2)|0)!=0){E=1;i=e;return E|0}if((R6(c[2388038]|0,1,2)|0)!=0){E=1;i=e;return E|0}if((R6((c[2388038]|0)+262145|0,2,2)|0)!=0){E=1;i=e;return E|0}if((R6((c[2388038]|0)+262144|0,3,2)|0)!=0){E=1;i=e;return E|0}x=c[2385848]|0;if((c[3542200]|0)==0){E=1;i=e;return E|0}B=v+108|0;c[B>>2]=0;F=v+100|0;c[F>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,4)|0;do{if((c[B>>2]|0)!=0){G=c[F>>2]|0;c[w>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](w,4,0)|0;if((G|0)<1){E=1;i=e;return E|0}if((gzL(x,0,4)|0)==0){break}else{E=1}i=e;return E|0}}while(0);x=c[3529498]|0;if((c[3542200]|0)==0){E=1;i=e;return E|0}F=t+108|0;c[F>>2]=0;B=t+100|0;c[B>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,5)|0;do{if((c[F>>2]|0)!=0){A=c[B>>2]|0;c[u>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](u,5,0)|0;if((A|0)<1){E=1;i=e;return E|0}if((gzL(x,0,5)|0)==0){break}else{E=1}i=e;return E|0}}while(0);x=(c[3529498]|0)+524288|0;if((c[3542200]|0)==0){E=1;i=e;return E|0}B=r+108|0;c[B>>2]=0;F=r+100|0;c[F>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,6)|0;do{if((c[B>>2]|0)!=0){A=c[F>>2]|0;c[s>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](s,6,0)|0;if((A|0)<1){E=1;i=e;return E|0}if((gzL(x,0,6)|0)==0){break}else{E=1}i=e;return E|0}}while(0);x=c[3529498]|0;blG(x,524288);F=c[2405828]|0;B=0;do{A=B<<6;gGz(F+A|0,0,64);G=B<<8;H=0;do{I=1<<3-H;J=(c[611632+(H<<2)>>2]|0)+G|0;K=0;do{L=J+(c[1183816+(K<<2)>>2]|0)|0;M=(K<<3)+A|0;N=0;do{O=L+(c[614800+(N<<2)>>2]|0)|0;if(((d[x+((O|0)/8|0)|0]|0)&128>>>((O&7)>>>0)|0)!=0){O=F+(M+N)|0;a[O]=(d[O]|0|I)&255}N=N+1|0;}while((N|0)<8);K=K+1|0;}while((K|0)<8);H=H+1|0;}while((H|0)<4);B=B+1|0;}while((B|0)<32768);B=c[2443400]|0;if((c[3542200]|0)==0){E=1;i=e;return E|0}F=p+108|0;c[F>>2]=0;x=p+100|0;c[x>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,7)|0;do{if((c[F>>2]|0)!=0){H=c[x>>2]|0;c[q>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](q,7,0)|0;if((H|0)<1){E=1;i=e;return E|0}if((gzL(B,0,7)|0)==0){break}else{E=1}i=e;return E|0}}while(0);B=(c[2443400]|0)+1048576|0;if((c[3542200]|0)==0){E=1;i=e;return E|0}x=n+108|0;c[x>>2]=0;F=n+100|0;c[F>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,8)|0;do{if((c[x>>2]|0)!=0){H=c[F>>2]|0;c[o>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](o,8,0)|0;if((H|0)<1){E=1;i=e;return E|0}if((gzL(B,0,8)|0)==0){break}else{E=1}i=e;return E|0}}while(0);B=(c[2443400]|0)+2097152|0;if((c[3542200]|0)==0){E=1;i=e;return E|0}F=l+108|0;c[F>>2]=0;x=l+100|0;c[x>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,9)|0;do{if((c[F>>2]|0)!=0){H=c[x>>2]|0;c[m>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](m,9,0)|0;if((H|0)<1){E=1;i=e;return E|0}if((gzL(B,0,9)|0)==0){break}else{E=1}i=e;return E|0}}while(0);B=(c[2443400]|0)+3145728|0;if((c[3542200]|0)==0){E=1;i=e;return E|0}x=j+108|0;c[x>>2]=0;F=j+100|0;c[F>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,10)|0;do{if((c[x>>2]|0)!=0){H=c[F>>2]|0;c[k>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](k,10,0)|0;if((H|0)<1){E=1;i=e;return E|0}if((gzL(B,0,10)|0)==0){break}else{E=1}i=e;return E|0}}while(0);B=c[2443400]|0;blG(B,2097152);F=c[3529600]|0;x=0;do{H=x<<8;gGz(F+H|0,0,256);A=x<<10;G=0;do{K=1<<3-G;I=(c[611632+(G<<2)>>2]|0)+A|0;J=0;do{N=I+(c[3946808+(J<<2)>>2]|0)|0;M=(J<<4)+H|0;L=0;do{O=N+(c[6669416+(L<<2)>>2]|0)|0;if(((d[B+((O|0)/8|0)|0]|0)&128>>>((O&7)>>>0)|0)!=0){O=F+(M+L)|0;a[O]=(d[O]|0|K)&255}L=L+1|0;}while((L|0)<16);J=J+1|0;}while((J|0)<16);G=G+1|0;}while((G|0)<4);x=x+1|0;}while((x|0)<32768);x=c[3527284]|0;if((c[3542200]|0)==0){E=1;i=e;return E|0}F=f+108|0;c[F>>2]=0;B=f+100|0;c[B>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,11)|0;do{if((c[F>>2]|0)!=0){G=c[B>>2]|0;c[g>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](g,11,0)|0;if((G|0)<1){E=1;i=e;return E|0}if((gzL(x,0,11)|0)==0){break}else{E=1}i=e;return E|0}}while(0);fxU(0,425984);if((c[2394]|0)==0){P=c[2112932]|0}else{c[2394]=0;x=c[3532596]|0;c[2112932]=x;B=c[3532592]|0;if((B|0)!=0){gGC(9104152,B|0,280)|0}c[2113054]=c[2113060];P=x}x=c[2388038]|0;B=P|0;F=0;while(1){G=x+F|0;c[B>>2]=G;c[B+131072>>2]=G;G=F+1024|0;if(G>>>0>1048575){break}else{B=B+4|0;F=G}}F=c[2388060]|0;c[P+4160>>2]=F;c[P+69696>>2]=F;c[P+135232>>2]=F;B=F+1024|0;c[P+4164>>2]=B;c[P+69700>>2]=B;c[P+135236>>2]=B;B=F+2048|0;c[P+4168>>2]=B;c[P+69704>>2]=B;c[P+135240>>2]=B;B=F+3072|0;c[P+4172>>2]=B;c[P+69708>>2]=B;c[P+135244>>2]=B;B=F+4096|0;c[P+4176>>2]=B;c[P+69712>>2]=B;c[P+135248>>2]=B;B=F+5120|0;c[P+4180>>2]=B;c[P+69716>>2]=B;c[P+135252>>2]=B;B=F+6144|0;c[P+4184>>2]=B;c[P+69720>>2]=B;c[P+135256>>2]=B;B=F+7168|0;c[P+4188>>2]=B;c[P+69724>>2]=B;c[P+135260>>2]=B;B=F+8192|0;c[P+4192>>2]=B;c[P+69728>>2]=B;c[P+135264>>2]=B;B=F+9216|0;c[P+4196>>2]=B;c[P+69732>>2]=B;c[P+135268>>2]=B;B=F+10240|0;c[P+4200>>2]=B;c[P+69736>>2]=B;c[P+135272>>2]=B;B=F+11264|0;c[P+4204>>2]=B;c[P+69740>>2]=B;c[P+135276>>2]=B;B=F+12288|0;c[P+4208>>2]=B;c[P+69744>>2]=B;c[P+135280>>2]=B;B=F+13312|0;c[P+4212>>2]=B;c[P+69748>>2]=B;c[P+135284>>2]=B;B=F+14336|0;c[P+4216>>2]=B;c[P+69752>>2]=B;c[P+135288>>2]=B;B=F+15360|0;c[P+4220>>2]=B;c[P+69756>>2]=B;c[P+135292>>2]=B;B=c[2439626]|0;c[P+5120>>2]=B;c[P+70656>>2]=B;c[P+136192>>2]=B;F=B+1024|0;c[P+5124>>2]=F;c[P+70660>>2]=F;c[P+136196>>2]=F;F=B+2048|0;c[P+5128>>2]=F;c[P+70664>>2]=F;c[P+136200>>2]=F;F=B+3072|0;c[P+5132>>2]=F;c[P+70668>>2]=F;c[P+136204>>2]=F;c[P+196688>>2]=1414;c[P+196728>>2]=2564;c[P+196608>>2]=1998;c[P+196648>>2]=1050;c[P+72712>>2]=1;c[P+196732>>2]=1186;c[P+196652>>2]=2916;F=c[3532592]|0;if((F|0)!=0){gGC(F|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);F=c[2439330]|0;B=(F|0)==0;if(!B){x=F;gGC(9706056,x|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];x=c[3528484]|0;c[2076596]=x;G=c[2417276]|0;c[3541536]=G;c[1836236]=0;c[F+4180>>2]=3124;c[F+4184>>2]=2566;H=c[2385848]|0;A=0;J=0;while(1){c[F+76+(J<<2)>>2]=H+(J<<8);K=A+1&65535;if((K&65535)>239){Q=0;R=0;break}else{A=K;J=K&65535}}while(1){J=H+(R<<8)|0;c[F+76+(R+512<<2)>>2]=J;c[F+76+(R+768<<2)>>2]=J;J=Q+1&65535;if((J&65535)>239){break}else{Q=J;R=J&65535}}H=c[2385866]|0;c[F+1036>>2]=H;J=H+256|0;c[F+1040>>2]=J;A=H+512|0;c[F+1044>>2]=A;K=H+768|0;c[F+1048>>2]=K;I=H+1024|0;c[F+1052>>2]=I;L=H+1280|0;c[F+1056>>2]=L;M=H+1536|0;c[F+1060>>2]=M;N=H+1792|0;c[F+1064>>2]=N;c[F+2060>>2]=H;c[F+2064>>2]=J;c[F+2068>>2]=A;c[F+2072>>2]=K;c[F+2076>>2]=I;c[F+2080>>2]=L;c[F+2084>>2]=M;c[F+2088>>2]=N;c[F+3084>>2]=H;c[F+4108>>2]=H;c[F+3088>>2]=J;c[F+4112>>2]=J;c[F+3092>>2]=A;c[F+4116>>2]=A;c[F+3096>>2]=K;c[F+4120>>2]=K;c[F+3100>>2]=I;c[F+4124>>2]=I;c[F+3104>>2]=L;c[F+4128>>2]=L;c[F+3108>>2]=M;c[F+4132>>2]=M;c[F+3112>>2]=N;c[F+4136>>2]=N;if(!B){N=F;gGC(N|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=x;c[2417276]=G;c[1836236]=-1;N=a[9680]|0;M=N?32e3:0;if(N){if(a[9624]|0){N=M*3|0;L=55930;while(1){if((L|0)>(N|0)){L=L>>1}else{S=1222;T=L;break}}}else{S=2462;T=M}c[2429380]=T;c[3542124]=S;mw(3579545,T);L=gGq(262144)|0;c[2406684]=L;gGz(L|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(3579545,11025)}h[745421]=1.0;c[2436794]=1;h[745420]=1.0;c[2436792]=2;TN(c[3527284]|0,2097152);h[1209346]=.75;c[2418696]=1;c[2426862]=9674384;h[1209347]=.75;c[2418697]=2;Tq(688456);L=c[642608+(c[2436]<<2)>>2]|0;N=c[L+128>>2]|0;if((c[L+52>>2]&4|0)==0){c[2113068]=N;G=c[L+132>>2]|0;c[2113070]=G;c[2443814]=N;c[2440436]=G;U=N;V=G}else{c[2113070]=N;G=c[L+132>>2]|0;c[2113068]=G;c[2440436]=N;c[2443814]=G;U=G;V=N}N=ag(U<<1,V)|0;G=gGq(N)|0;c[2112926]=G;if((G|0)!=0){gGz(G|0,0,N|0)}if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];N=c[3532592]|0;if((N|0)!=0){gGC(9104152,N|0,280)|0}c[2113054]=c[2113060]}RI();N=c[2394]|0;G=c[14130368+(N<<2)>>2]|0;if((G|0)!=0){gGC(G|0,9104152,280)|0}c[8452240+(N<<2)>>2]=c[2113054];c[2394]=-1;N=c[2439330]|0;G=(N|0)==0;if(!G){L=N;gGC(9706056,L|0,76)|0}L=c[2438118]|0;c[2433530]=L;x=c[3528484]|0;c[2076596]=x;F=c[2417276]|0;c[3541536]=F;c[1836236]=0;gGz(9706056,0,76);if(!G){G=N;gGC(G|0,9706056,76)|0}c[2438118]=L;c[3528484]=x;c[2417276]=F;c[1836236]=-1;mx(0);c[2426862]=9674384;gGz(9674592,0,176);blH();c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];c[2437706]=a[1040128]|0?0:10;c[3541228]=0;a[9545176]=0;c[2415284]=0;c[2415282]=0;E=0;i=e;return E|0}}while(0);c[2426818]=0;E=1;i=e;return E|0}function bdy(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;if((a[9625080]|0)!=0){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;h=c[2417276]|0;c[3541536]=h;c[1836236]=0;gGz(9706056,0,76);if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=h;c[1836236]=-1;mx(0);c[2426862]=9674384;gGz(9674592,0,176);blH();c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];c[2437706]=a[1040128]|0?0:10;c[3541228]=0;a[9545176]=0;c[2415284]=0;c[2415282]=0}bdX();a[9625893]=a[9625893]^-10;c[2440552]=266666;c[2440494]=133333;c[2444121]=0;c[2444120]=0;h=c[2392]|0;if((h|0)>=0){gGz(8452240,0,((h|0)>0?(h<<2)+4|0:4)|0)}c[2113054]=0;h=c[2385548]|0;if((h|0)>0){gGz(9752472,0,((h|0)>1?h<<2:4)|0)}c[2433530]=0;h=0;g=0;L78705:while(1){f=g;while(1){if((f|0)>=262){break L78705}if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060]}i=f+1|0;e=(ag(c[2440552]|0,i)|0)/262|0;d=e-(c[2444120]|0)|0;c[2438210]=d;c[2113056]=d;e=RG(d)|0;c[2113054]=(c[2113054]|0)+e;c[2276108]=-1;c[2113056]=-1;c[2444120]=(c[2444120]|0)+e;do{if((f|0)==19){a[9545176]=0}else if((f|0)==243){a[9545176]=1;if((c[3541228]|0)==0){break}c[8452200+(c[2394]<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0>=1024){break}RH(4)}}while(0);e=c[2394]|0;d=c[14130368+(e<<2)>>2]|0;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[8452240+(e<<2)>>2]=c[2113054];c[2394]=-1;e=c[2439330]|0;if((e|0)!=0){d=e;gGC(9706056,d|0,76)|0}b[4853030]=c[2426515]&65535;d=c[2438118]|0;c[2433530]=d;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;j=(ag(c[2440494]|0,i)|0)/262|0;k=c[2444121]|0;l=j-k|0;c[2438210]=l;do{if((l|0)<1){m=0;n=k;o=0;p=e;q=d}else{if((a[e+4188|0]|0)==0){j=gfc(l)|0;r=(c[2433530]|0)+j|0;c[2433530]=r;s=c[1836236]|0;m=j;n=c[2444121]|0;o=s;p=c[9757320+(s<<2)>>2]|0;q=r;break}else{r=d+l|0;c[2433530]=r;m=l;n=k;o=0;p=e;q=r;break}}}while(0);c[2438210]=m;c[2444121]=n+m;if((p|0)!=0){e=p;gGC(e|0,9706056,76)|0}c[9752472+(o<<2)>>2]=q;c[14113936+(o<<2)>>2]=c[2076596];c[9669104+(o<<2)>>2]=c[3541536];c[1836236]=-1;t=c[2112964]|0;if((t|0)==0){f=i}else{break}}f=a[9688]|0?2:0;e=t+(h<<1<<1)|0;gg[c[3542124]&4095](e,f);TM(e,f);h=f+h|0;g=i}i=c[2112964]|0;do{if((i|0)!=0){g=a[9688]|0?534:0;t=g-h|0;o=i+(h<<1<<1)|0;if((g|0)==(h|0)){break}gg[c[3542124]&4095](o,t);TM(o,t)}}while(0);if((c[2112968]|0)==0){return 0}bd$();return 0}function bdz(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2137116+(b*112|0)>>2];c[a+104>>2]=c[2137120+(b*112|0)>>2];c[a+108>>2]=c[2137124+(b*112|0)>>2];d=0;return d|0}function bdA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=2137016+(b*112|0);e=0;return e|0}function bdB(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2138572+(b*112|0)>>2];c[a+104>>2]=c[2138576+(b*112|0)>>2];c[a+108>>2]=c[2138580+(b*112|0)>>2];d=0;return d|0}function bdC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=2138472+(b*112|0);e=0;return e|0}function bdD(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5651892+(b*112|0)>>2];c[a+104>>2]=c[5651896+(b*112|0)>>2];c[a+108>>2]=c[5651900+(b*112|0)>>2];d=0;return d|0}function bdE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=5651792+(b*112|0);e=0;return e|0}function bdF(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2414644+(b*112|0)>>2];c[a+104>>2]=c[2414648+(b*112|0)>>2];c[a+108>>2]=c[2414652+(b*112|0)>>2];d=0;return d|0}function bdG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=2414544+(b*112|0);e=0;return e|0}function bdH(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1208272+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function bdI(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;e=i;i=i+720|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;c[2426818]=0;c[2388038]=0;c[2385848]=1048576;c[3527284]=1114112;c[3529498]=3211264;c[2443400]=4259840;c[2405720]=8454144;c[2388060]=8454144;c[2385866]=8474752;c[2439626]=8476800;c[2443436]=8480896;c[2411882]=8497280;c[2407018]=8497280;c[3530202]=8505472;c[2405828]=8513728;c[3529600]=10610880;t=0;while(1){if((t|0)>=1024){break}u=9638528+(t<<2)|0;if((c[u>>2]|0)==0){v=61051;break}else{t=t+1|0}}do{if((v|0)==61051){t=gGq(18999488)|0;c[u>>2]=t;if((t|0)==0){break}c[2426818]=t;gGz(t|0,0,18999488);c[2388038]=t;c[2385848]=t+1048576;c[3527284]=t+1114112;w=t+3211264|0;c[3529498]=w;c[2443400]=t+4259840;x=t+8454144|0;c[2405720]=x;c[2388060]=x;c[2385866]=t+8474752;c[2439626]=t+8476800;c[2443436]=t+8480896;x=t+8497280|0;c[2411882]=x;c[2407018]=x;c[3530202]=t+8505472;c[2405828]=t+8513728;c[3529600]=t+10610880;c[2414434]=t+18999488;t=0;while(1){if((t|0)>=1024){y=0;break}z=9638528+(t<<2)|0;if((c[z>>2]|0)==0){v=61056;break}else{t=t+1|0}}do{if((v|0)==61056){t=gGq(24576)|0;c[z>>2]=t;if((t|0)==0){y=0;break}gGz(t|0,0,24576);y=t}}while(0);c[3529062]=y;c[2438700]=1048575;c[3529060]=w;a[7461784]=1;t=9726816;c[t>>2]=0;c[t+4>>2]=0;t=9726800;c[t>>2]=0;c[t+4>>2]=0;c[2429638]=0;c[2437692]=6;c[2431704]=0;c[2431700]=0;c[2431705]=0;c[2431701]=0;c[2431706]=0;c[2431702]=0;biH(c[2443400]|0,4194303,128);c[3529052]=-360;c[3529050]=272;a[7461816]=1;if((R6((c[2388038]|0)+1|0,0,2)|0)!=0){A=1;i=e;return A|0}if((R6(c[2388038]|0,1,2)|0)!=0){A=1;i=e;return A|0}if((R6((c[2388038]|0)+524289|0,2,2)|0)!=0){A=1;i=e;return A|0}if((R6((c[2388038]|0)+524288|0,3,2)|0)!=0){A=1;i=e;return A|0}t=c[2385848]|0;if((c[3542200]|0)==0){A=1;i=e;return A|0}x=r+108|0;c[x>>2]=0;B=r+100|0;c[B>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,4)|0;do{if((c[x>>2]|0)!=0){C=c[B>>2]|0;c[s>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](s,4,0)|0;if((C|0)<1){A=1;i=e;return A|0}if((gzL(t,0,4)|0)==0){break}else{A=1}i=e;return A|0}}while(0);t=c[3529498]|0;if((c[3542200]|0)==0){A=1;i=e;return A|0}B=p+108|0;c[B>>2]=0;x=p+100|0;c[x>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,5)|0;do{if((c[B>>2]|0)!=0){w=c[x>>2]|0;c[q>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](q,5,0)|0;if((w|0)<1){A=1;i=e;return A|0}if((gzL(t,0,5)|0)==0){break}else{A=1}i=e;return A|0}}while(0);t=(c[3529498]|0)+524288|0;if((c[3542200]|0)==0){A=1;i=e;return A|0}x=n+108|0;c[x>>2]=0;B=n+100|0;c[B>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,6)|0;do{if((c[x>>2]|0)!=0){w=c[B>>2]|0;c[o>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](o,6,0)|0;if((w|0)<1){A=1;i=e;return A|0}if((gzL(t,0,6)|0)==0){break}else{A=1}i=e;return A|0}}while(0);t=c[3529498]|0;blG(t,524288);B=c[2405828]|0;x=0;do{w=x<<6;gGz(B+w|0,0,64);C=x<<8;D=0;do{E=1<<3-D;F=(c[611632+(D<<2)>>2]|0)+C|0;G=0;do{H=F+(c[1183816+(G<<2)>>2]|0)|0;I=(G<<3)+w|0;J=0;do{K=H+(c[614800+(J<<2)>>2]|0)|0;if(((d[t+((K|0)/8|0)|0]|0)&128>>>((K&7)>>>0)|0)!=0){K=B+(I+J)|0;a[K]=(d[K]|0|E)&255}J=J+1|0;}while((J|0)<8);G=G+1|0;}while((G|0)<8);D=D+1|0;}while((D|0)<4);x=x+1|0;}while((x|0)<32768);x=c[2443400]|0;if((c[3542200]|0)==0){A=1;i=e;return A|0}B=l+108|0;c[B>>2]=0;t=l+100|0;c[t>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,7)|0;do{if((c[B>>2]|0)!=0){D=c[t>>2]|0;c[m>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](m,7,0)|0;if((D|0)<1){A=1;i=e;return A|0}if((gzL(x,0,7)|0)==0){break}else{A=1}i=e;return A|0}}while(0);x=(c[2443400]|0)+2097152|0;if((c[3542200]|0)==0){A=1;i=e;return A|0}t=j+108|0;c[t>>2]=0;B=j+100|0;c[B>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,8)|0;do{if((c[t>>2]|0)!=0){D=c[B>>2]|0;c[k>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](k,8,0)|0;if((D|0)<1){A=1;i=e;return A|0}if((gzL(x,0,8)|0)==0){break}else{A=1}i=e;return A|0}}while(0);x=c[2443400]|0;blG(x,2097152);B=c[3529600]|0;t=0;do{D=t<<8;gGz(B+D|0,0,256);w=t<<10;C=0;do{G=1<<3-C;E=(c[611632+(C<<2)>>2]|0)+w|0;F=0;do{J=E+(c[3946808+(F<<2)>>2]|0)|0;I=(F<<4)+D|0;H=0;do{K=J+(c[6669416+(H<<2)>>2]|0)|0;if(((d[x+((K|0)/8|0)|0]|0)&128>>>((K&7)>>>0)|0)!=0){K=B+(I+H)|0;a[K]=(d[K]|0|G)&255}H=H+1|0;}while((H|0)<16);F=F+1|0;}while((F|0)<16);C=C+1|0;}while((C|0)<4);t=t+1|0;}while((t|0)<32768);t=c[3527284]|0;if((c[3542200]|0)==0){A=1;i=e;return A|0}B=f+108|0;c[B>>2]=0;x=f+100|0;c[x>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,9)|0;do{if((c[B>>2]|0)!=0){C=c[x>>2]|0;c[g>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](g,9,0)|0;if((C|0)<1){A=1;i=e;return A|0}if((gzL(t,0,9)|0)==0){break}else{A=1}i=e;return A|0}}while(0);fxU(0,425984);if((c[2394]|0)==0){L=c[2112932]|0}else{c[2394]=0;t=c[3532596]|0;c[2112932]=t;x=c[3532592]|0;if((x|0)!=0){gGC(9104152,x|0,280)|0}c[2113054]=c[2113060];L=t}t=c[2388038]|0;x=L|0;B=0;while(1){C=t+B|0;c[x>>2]=C;c[x+131072>>2]=C;C=B+1024|0;if(C>>>0>1048575){break}else{x=x+4|0;B=C}}B=c[2388060]|0;c[L+4160>>2]=B;c[L+69696>>2]=B;c[L+135232>>2]=B;x=B+1024|0;c[L+4164>>2]=x;c[L+69700>>2]=x;c[L+135236>>2]=x;x=B+2048|0;c[L+4168>>2]=x;c[L+69704>>2]=x;c[L+135240>>2]=x;x=B+3072|0;c[L+4172>>2]=x;c[L+69708>>2]=x;c[L+135244>>2]=x;x=B+4096|0;c[L+4176>>2]=x;c[L+69712>>2]=x;c[L+135248>>2]=x;x=B+5120|0;c[L+4180>>2]=x;c[L+69716>>2]=x;c[L+135252>>2]=x;x=B+6144|0;c[L+4184>>2]=x;c[L+69720>>2]=x;c[L+135256>>2]=x;x=B+7168|0;c[L+4188>>2]=x;c[L+69724>>2]=x;c[L+135260>>2]=x;x=B+8192|0;c[L+4192>>2]=x;c[L+69728>>2]=x;c[L+135264>>2]=x;x=B+9216|0;c[L+4196>>2]=x;c[L+69732>>2]=x;c[L+135268>>2]=x;x=B+10240|0;c[L+4200>>2]=x;c[L+69736>>2]=x;c[L+135272>>2]=x;x=B+11264|0;c[L+4204>>2]=x;c[L+69740>>2]=x;c[L+135276>>2]=x;x=B+12288|0;c[L+4208>>2]=x;c[L+69744>>2]=x;c[L+135280>>2]=x;x=B+13312|0;c[L+4212>>2]=x;c[L+69748>>2]=x;c[L+135284>>2]=x;x=B+14336|0;c[L+4216>>2]=x;c[L+69752>>2]=x;c[L+135288>>2]=x;x=B+15360|0;c[L+4220>>2]=x;c[L+69756>>2]=x;c[L+135292>>2]=x;x=c[2439626]|0;c[L+5120>>2]=x;c[L+70656>>2]=x;c[L+136192>>2]=x;B=x+1024|0;c[L+5124>>2]=B;c[L+70660>>2]=B;c[L+136196>>2]=B;B=x+2048|0;c[L+5128>>2]=B;c[L+70664>>2]=B;c[L+136200>>2]=B;B=x+3072|0;c[L+5132>>2]=B;c[L+70668>>2]=B;c[L+136204>>2]=B;c[L+196688>>2]=1414;c[L+196728>>2]=2564;c[L+196608>>2]=1998;c[L+196648>>2]=1050;c[L+72712>>2]=1;c[L+196732>>2]=1186;c[L+196652>>2]=2916;B=c[3532592]|0;if((B|0)!=0){gGC(B|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);B=c[2439330]|0;x=(B|0)==0;if(!x){t=B;gGC(9706056,t|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];t=c[3528484]|0;c[2076596]=t;C=c[2417276]|0;c[3541536]=C;c[1836236]=0;c[B+4180>>2]=3124;c[B+4184>>2]=2566;D=c[2385848]|0;w=0;F=0;while(1){c[B+76+(F<<2)>>2]=D+(F<<8);G=w+1&65535;if((G&65535)>239){M=0;N=0;break}else{w=G;F=G&65535}}while(1){F=D+(N<<8)|0;c[B+76+(N+512<<2)>>2]=F;c[B+76+(N+768<<2)>>2]=F;F=M+1&65535;if((F&65535)>239){break}else{M=F;N=F&65535}}D=c[2385866]|0;c[B+1036>>2]=D;F=D+256|0;c[B+1040>>2]=F;w=D+512|0;c[B+1044>>2]=w;G=D+768|0;c[B+1048>>2]=G;E=D+1024|0;c[B+1052>>2]=E;H=D+1280|0;c[B+1056>>2]=H;I=D+1536|0;c[B+1060>>2]=I;J=D+1792|0;c[B+1064>>2]=J;c[B+2060>>2]=D;c[B+2064>>2]=F;c[B+2068>>2]=w;c[B+2072>>2]=G;c[B+2076>>2]=E;c[B+2080>>2]=H;c[B+2084>>2]=I;c[B+2088>>2]=J;c[B+3084>>2]=D;c[B+4108>>2]=D;c[B+3088>>2]=F;c[B+4112>>2]=F;c[B+3092>>2]=w;c[B+4116>>2]=w;c[B+3096>>2]=G;c[B+4120>>2]=G;c[B+3100>>2]=E;c[B+4124>>2]=E;c[B+3104>>2]=H;c[B+4128>>2]=H;c[B+3108>>2]=I;c[B+4132>>2]=I;c[B+3112>>2]=J;c[B+4136>>2]=J;if(!x){J=B;gGC(J|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=t;c[2417276]=C;c[1836236]=-1;J=a[9680]|0;I=J?32e3:0;if(J){if(a[9624]|0){J=I*3|0;H=55930;while(1){if((H|0)>(J|0)){H=H>>1}else{O=1222;P=H;break}}}else{O=2462;P=I}c[2429380]=P;c[3542124]=O;mw(3579545,P);H=gGq(262144)|0;c[2406684]=H;gGz(H|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(3579545,11025)}h[745421]=1.0;c[2436794]=1;h[745420]=1.0;c[2436792]=2;TN(c[3527284]|0,2097152);h[1209346]=.75;c[2418696]=1;c[2426862]=9674384;h[1209347]=.75;c[2418697]=2;Tq(688456);H=c[642608+(c[2436]<<2)>>2]|0;J=c[H+128>>2]|0;if((c[H+52>>2]&4|0)==0){c[2113068]=J;C=c[H+132>>2]|0;c[2113070]=C;c[2443814]=J;c[2440436]=C;Q=J;R=C}else{c[2113070]=J;C=c[H+132>>2]|0;c[2113068]=C;c[2440436]=J;c[2443814]=C;Q=C;R=J}J=ag(Q<<1,R)|0;C=gGq(J)|0;c[2112926]=C;if((C|0)!=0){gGz(C|0,0,J|0)}if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];J=c[3532592]|0;if((J|0)!=0){gGC(9104152,J|0,280)|0}c[2113054]=c[2113060]}RI();J=c[2394]|0;C=c[14130368+(J<<2)>>2]|0;if((C|0)!=0){gGC(C|0,9104152,280)|0}c[8452240+(J<<2)>>2]=c[2113054];c[2394]=-1;J=c[2439330]|0;C=(J|0)==0;if(!C){H=J;gGC(9706056,H|0,76)|0}H=c[2438118]|0;c[2433530]=H;t=c[3528484]|0;c[2076596]=t;B=c[2417276]|0;c[3541536]=B;c[1836236]=0;gGz(9706056,0,76);if(!C){C=J;gGC(C|0,9706056,76)|0}c[2438118]=H;c[3528484]=t;c[2417276]=B;c[1836236]=-1;mx(0);c[2426862]=9674384;gGz(9674592,0,176);blH();c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];c[2437706]=a[1040128]|0?0:10;c[3541228]=0;a[9545176]=0;c[2415284]=0;c[2415282]=0;A=0;i=e;return A|0}}while(0);c[2426818]=0;A=1;i=e;return A|0}function bdJ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2424388+(b*112|0)>>2];c[a+104>>2]=c[2424392+(b*112|0)>>2];c[a+108>>2]=c[2424396+(b*112|0)>>2];d=0;return d|0}function bdK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=2424288+(b*112|0);e=0;return e|0}function bdL(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>35){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1210528+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function bdM(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>49){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3601744+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function bdN(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;e=i;i=i+720|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;c[2426818]=0;c[2388038]=0;c[2385848]=262144;c[3527284]=327680;c[3529498]=851968;c[2443400]=1376256;c[2405720]=3473408;c[2388060]=3473408;c[2385866]=3489792;c[2439626]=3491840;c[2411882]=3495936;c[2407018]=3495936;c[3530202]=3504128;c[2405828]=3512384;c[3529600]=4560960;t=0;while(1){if((t|0)>=1024){break}u=9638528+(t<<2)|0;if((c[u>>2]|0)==0){v=61198;break}else{t=t+1|0}}do{if((v|0)==61198){t=gGq(8755264)|0;c[u>>2]=t;if((t|0)==0){break}c[2426818]=t;gGz(t|0,0,8755264);c[2388038]=t;c[2385848]=t+262144;c[3527284]=t+327680;w=t+851968|0;c[3529498]=w;c[2443400]=t+1376256;x=t+3473408|0;c[2405720]=x;c[2388060]=x;c[2385866]=t+3489792;c[2439626]=t+3491840;x=t+3495936|0;c[2411882]=x;c[2407018]=x;c[3530202]=t+3504128;c[2405828]=t+3512384;c[3529600]=t+4560960;c[2414434]=t+8755264;t=0;while(1){if((t|0)>=1024){y=0;break}z=9638528+(t<<2)|0;if((c[z>>2]|0)==0){v=61203;break}else{t=t+1|0}}do{if((v|0)==61203){t=gGq(24576)|0;c[z>>2]=t;if((t|0)==0){y=0;break}gGz(t|0,0,24576);y=t}}while(0);c[3529062]=y;c[2438700]=524287;c[3529060]=w;a[7461784]=1;t=9726816;c[t>>2]=0;c[t+4>>2]=0;t=9726800;c[t>>2]=0;c[t+4>>2]=0;c[2429638]=0;c[2437692]=6;c[2431704]=8;c[2431700]=0;c[2431705]=8;c[2431701]=0;c[2431706]=8;c[2431702]=0;t=c[2443400]|0;c[2438136]=0;x=0;while(1){if((x|0)>=1024){A=0;break}B=9638528+(x<<2)|0;if((c[B>>2]|0)==0){v=61208;break}else{x=x+1|0}}do{if((v|0)==61208){x=gGq(1024)|0;c[B>>2]=x;if((x|0)==0){A=0;break}gGz(x|0,0,1024);A=x}}while(0);c[3529066]=A;c[2438702]=2097151;c[3529064]=t;a[7461792]=1;c[2437694]=120;c[2438136]=8;if((R6((c[2388038]|0)+1|0,0,2)|0)!=0){C=1;i=e;return C|0}if((R6(c[2388038]|0,1,2)|0)!=0){C=1;i=e;return C|0}x=c[2385848]|0;if((c[3542200]|0)==0){C=1;i=e;return C|0}w=r+108|0;c[w>>2]=0;D=r+100|0;c[D>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,2)|0;do{if((c[w>>2]|0)!=0){E=c[D>>2]|0;c[s>>2]=9534384;F=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[F&16383](s,2,0)|0;if((E|0)<1){C=1;i=e;return C|0}if((gzL(x,0,2)|0)==0){break}else{C=1}i=e;return C|0}}while(0);x=c[3529498]|0;if((c[3542200]|0)==0){C=1;i=e;return C|0}D=p+108|0;c[D>>2]=0;w=p+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,3)|0;do{if((c[D>>2]|0)!=0){t=c[w>>2]|0;c[q>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](q,3,0)|0;if((t|0)<1){C=1;i=e;return C|0}if((gzL(x,0,3)|0)==0){break}else{C=1}i=e;return C|0}}while(0);x=(c[3529498]|0)+262144|0;if((c[3542200]|0)==0){C=1;i=e;return C|0}w=n+108|0;c[w>>2]=0;D=n+100|0;c[D>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,4)|0;do{if((c[w>>2]|0)!=0){t=c[D>>2]|0;c[o>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](o,4,0)|0;if((t|0)<1){C=1;i=e;return C|0}if((gzL(x,0,4)|0)==0){break}else{C=1}i=e;return C|0}}while(0);x=c[3529498]|0;blG(x,262144);D=c[2405828]|0;w=0;do{t=w<<6;gGz(D+t|0,0,64);E=w<<8;F=0;do{G=1<<3-F;H=(c[611632+(F<<2)>>2]|0)+E|0;I=0;do{J=H+(c[1183816+(I<<2)>>2]|0)|0;K=(I<<3)+t|0;L=0;do{M=J+(c[614800+(L<<2)>>2]|0)|0;if(((d[x+((M|0)/8|0)|0]|0)&128>>>((M&7)>>>0)|0)!=0){M=D+(K+L)|0;a[M]=(d[M]|0|G)&255}L=L+1|0;}while((L|0)<8);I=I+1|0;}while((I|0)<8);F=F+1|0;}while((F|0)<4);w=w+1|0;}while((w|0)<16384);w=c[2443400]|0;if((c[3542200]|0)==0){C=1;i=e;return C|0}D=l+108|0;c[D>>2]=0;x=l+100|0;c[x>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,5)|0;do{if((c[D>>2]|0)!=0){F=c[x>>2]|0;c[m>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](m,5,0)|0;if((F|0)<1){C=1;i=e;return C|0}if((gzL(w,0,5)|0)==0){break}else{C=1}i=e;return C|0}}while(0);w=(c[2443400]|0)+1048576|0;if((c[3542200]|0)==0){C=1;i=e;return C|0}x=j+108|0;c[x>>2]=0;D=j+100|0;c[D>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,6)|0;do{if((c[x>>2]|0)!=0){F=c[D>>2]|0;c[k>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](k,6,0)|0;if((F|0)<1){C=1;i=e;return C|0}if((gzL(w,0,6)|0)==0){break}else{C=1}i=e;return C|0}}while(0);w=c[2443400]|0;blG(w,1048576);D=c[3529600]|0;x=0;do{F=x<<8;gGz(D+F|0,0,256);t=x<<10;E=0;do{I=1<<3-E;G=(c[611400+(E<<2)>>2]|0)+t|0;H=0;do{L=G+(c[3946808+(H<<2)>>2]|0)|0;K=(H<<4)+F|0;J=0;do{M=L+(c[6669416+(J<<2)>>2]|0)|0;if(((d[w+((M|0)/8|0)|0]|0)&128>>>((M&7)>>>0)|0)!=0){M=D+(K+J)|0;a[M]=(d[M]|0|I)&255}J=J+1|0;}while((J|0)<16);H=H+1|0;}while((H|0)<16);E=E+1|0;}while((E|0)<4);x=x+1|0;}while((x|0)<16384);x=c[3527284]|0;if((c[3542200]|0)==0){C=1;i=e;return C|0}D=f+108|0;c[D>>2]=0;w=f+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,7)|0;do{if((c[D>>2]|0)!=0){E=c[w>>2]|0;c[g>>2]=9534384;F=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[F&16383](g,7,0)|0;if((E|0)<1){C=1;i=e;return C|0}if((gzL(x,0,7)|0)==0){break}else{C=1}i=e;return C|0}}while(0);fxU(0,425984);if((c[2394]|0)==0){N=c[2112932]|0}else{c[2394]=0;x=c[3532596]|0;c[2112932]=x;w=c[3532592]|0;if((w|0)!=0){gGC(9104152,w|0,280)|0}c[2113054]=c[2113060];N=x}x=c[2388038]|0;w=N|0;D=0;while(1){E=x+D|0;c[w>>2]=E;c[w+131072>>2]=E;E=D+1024|0;if(E>>>0>262143){break}else{w=w+4|0;D=E}}D=c[2388060]|0;c[N+2048>>2]=D;c[N+67584>>2]=D;c[N+133120>>2]=D;w=D+1024|0;c[N+2052>>2]=w;c[N+67588>>2]=w;c[N+133124>>2]=w;w=D+2048|0;c[N+2056>>2]=w;c[N+67592>>2]=w;c[N+133128>>2]=w;w=D+3072|0;c[N+2060>>2]=w;c[N+67596>>2]=w;c[N+133132>>2]=w;w=D+4096|0;c[N+2064>>2]=w;c[N+67600>>2]=w;c[N+133136>>2]=w;w=D+5120|0;c[N+2068>>2]=w;c[N+67604>>2]=w;c[N+133140>>2]=w;w=D+6144|0;c[N+2072>>2]=w;c[N+67608>>2]=w;c[N+133144>>2]=w;w=D+7168|0;c[N+2076>>2]=w;c[N+67612>>2]=w;c[N+133148>>2]=w;w=D+8192|0;c[N+2080>>2]=w;c[N+67616>>2]=w;c[N+133152>>2]=w;w=D+9216|0;c[N+2084>>2]=w;c[N+67620>>2]=w;c[N+133156>>2]=w;w=D+10240|0;c[N+2088>>2]=w;c[N+67624>>2]=w;c[N+133160>>2]=w;w=D+11264|0;c[N+2092>>2]=w;c[N+67628>>2]=w;c[N+133164>>2]=w;w=D+12288|0;c[N+2096>>2]=w;c[N+67632>>2]=w;c[N+133168>>2]=w;w=D+13312|0;c[N+2100>>2]=w;c[N+67636>>2]=w;c[N+133172>>2]=w;w=D+14336|0;c[N+2104>>2]=w;c[N+67640>>2]=w;c[N+133176>>2]=w;w=D+15360|0;c[N+2108>>2]=w;c[N+67644>>2]=w;c[N+133180>>2]=w;w=c[2439626]|0;c[N+2304>>2]=w;c[N+67840>>2]=w;c[N+133376>>2]=w;D=w+1024|0;c[N+2308>>2]=D;c[N+67844>>2]=D;c[N+133380>>2]=D;D=w+2048|0;c[N+2312>>2]=D;c[N+67848>>2]=D;c[N+133384>>2]=D;D=w+3072|0;c[N+2316>>2]=D;c[N+67852>>2]=D;c[N+133388>>2]=D;c[N+196688>>2]=1080;c[N+196728>>2]=70;c[N+196608>>2]=2668;c[N+196648>>2]=2722;D=c[3532592]|0;if((D|0)!=0){gGC(D|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);D=c[2439330]|0;w=(D|0)==0;if(!w){x=D;gGC(9706056,x|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];x=c[3528484]|0;c[2076596]=x;E=c[2417276]|0;c[3541536]=E;c[1836236]=0;c[D+4180>>2]=866;c[D+4184>>2]=1694;F=c[2385848]|0;t=0;H=0;while(1){c[D+76+(H<<2)>>2]=F+(H<<8);I=t+1&65535;if((I&65535)>239){O=0;P=0;break}else{t=I;H=I&65535}}while(1){H=F+(P<<8)|0;c[D+76+(P+512<<2)>>2]=H;c[D+76+(P+768<<2)>>2]=H;H=O+1&65535;if((H&65535)>239){break}else{O=H;P=H&65535}}F=c[2385866]|0;c[D+1036>>2]=F;H=F+256|0;c[D+1040>>2]=H;t=F+512|0;c[D+1044>>2]=t;I=F+768|0;c[D+1048>>2]=I;G=F+1024|0;c[D+1052>>2]=G;J=F+1280|0;c[D+1056>>2]=J;K=F+1536|0;c[D+1060>>2]=K;L=F+1792|0;c[D+1064>>2]=L;c[D+2060>>2]=F;c[D+2064>>2]=H;c[D+2068>>2]=t;c[D+2072>>2]=I;c[D+2076>>2]=G;c[D+2080>>2]=J;c[D+2084>>2]=K;c[D+2088>>2]=L;c[D+3084>>2]=F;c[D+4108>>2]=F;c[D+3088>>2]=H;c[D+4112>>2]=H;c[D+3092>>2]=t;c[D+4116>>2]=t;c[D+3096>>2]=I;c[D+4120>>2]=I;c[D+3100>>2]=G;c[D+4124>>2]=G;c[D+3104>>2]=J;c[D+4128>>2]=J;c[D+3108>>2]=K;c[D+4132>>2]=K;c[D+3112>>2]=L;c[D+4136>>2]=L;if(!w){L=D;gGC(L|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=x;c[2417276]=E;c[1836236]=-1;L=a[9680]|0;K=L?32e3:0;if(L){if(a[9624]|0){L=K*3|0;J=55930;while(1){if((J|0)>(L|0)){J=J>>1}else{Q=1222;R=J;break}}}else{Q=2462;R=K}c[2429380]=R;c[3542124]=Q;mw(3579545,R);J=gGq(262144)|0;c[2406684]=J;gGz(J|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(3579545,11025)}h[745421]=1.0;c[2436794]=3;h[745420]=1.0;c[2436792]=3;TN(c[3527284]|0,524288);h[1209346]=.7;c[2418696]=3;c[2426862]=9674384;h[1209347]=.7;c[2418697]=3;J=c[642608+(c[2436]<<2)>>2]|0;L=c[J+128>>2]|0;if((c[J+52>>2]&4|0)==0){c[2113068]=L;E=c[J+132>>2]|0;c[2113070]=E;c[2443814]=L;c[2440436]=E;S=L;T=E}else{c[2113070]=L;E=c[J+132>>2]|0;c[2113068]=E;c[2440436]=L;c[2443814]=E;S=E;T=L}L=ag(S<<1,T)|0;E=gGq(L)|0;c[2112926]=E;if((E|0)!=0){gGz(E|0,0,L|0)}eC(gb(0)|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];L=c[3532592]|0;if((L|0)!=0){gGC(9104152,L|0,280)|0}c[2113054]=c[2113060]}RI();L=c[2394]|0;E=c[14130368+(L<<2)>>2]|0;if((E|0)!=0){gGC(E|0,9104152,280)|0}c[8452240+(L<<2)>>2]=c[2113054];c[2394]=-1;L=c[2439330]|0;E=(L|0)==0;if(!E){J=L;gGC(9706056,J|0,76)|0}J=c[2438118]|0;c[2433530]=J;x=c[3528484]|0;c[2076596]=x;D=c[2417276]|0;c[3541536]=D;c[1836236]=0;gGz(9706056,0,76);if(!E){E=L;gGC(E|0,9706056,76)|0}c[2438118]=J;c[3528484]=x;c[2417276]=D;c[1836236]=-1;mx(0);c[2426862]=9674384;gGz(9674592,0,176);blH();c[3541228]=0;a[9545176]=0;C=0;i=e;return C|0}}while(0);c[2426818]=0;C=1;i=e;return C|0}function bdO(){var b=0,d=0,e=0,f=0,g=0;c[2426862]=9674384;b=c[2418647]|0;if((b|0)!=0){gGr(b);c[(c[2426862]|0)+204>>2]=0}c[2426862]=9674792;b=c[2418749]|0;if((b|0)!=0){gGr(b);c[(c[2426862]|0)+204>>2]=0}c[2443782]=0;fwZ();if((c[2392]|0)>=0){b=0;do{d=14130368+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}d=14130384+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}b=b+1|0;}while((b|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;b=c[3531464]|0;c[b+44344>>2]=0;c[b+44348>>2]=0;if((b|0)!=0){gGr(b);c[3531464]=0}b=c[2406684]|0;if((b|0)!=0){gGr(b);c[2406684]=0}c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}blI();b=c[2426818]|0;d=0;while(1){if((d|0)>=1024){break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==(b|0)){g=61336;break}else{d=d+1|0}}if((g|0)==61336){gGr(b);c[f>>2]=0}c[2426818]=0;a[14115360]=0;a[9758256]=0;c[2436804]=0;c[2437026]=0;h[615974]=0.0;c[2433324]=0;gGz(9750600,0,3);gGz(9623120,0,3);c[2442970]=0;c[2443506]=0;c[2430236]=0;c[2429778]=0;a[9545176]=0;c[2437706]=0;return 0}function bdP(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;if((a[9625080]|0)!=0){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060]}RI();e=c[2394]|0;f=c[14130368+(e<<2)>>2]|0;if((f|0)!=0){gGC(f|0,9104152,280)|0}c[8452240+(e<<2)>>2]=c[2113054];c[2394]=-1;e=c[2439330]|0;f=(e|0)==0;if(!f){g=e;gGC(9706056,g|0,76)|0}g=c[2438118]|0;c[2433530]=g;h=c[3528484]|0;c[2076596]=h;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);if(!f){f=e;gGC(f|0,9706056,76)|0}c[2438118]=g;c[3528484]=h;c[2417276]=i;c[1836236]=-1;mx(0);c[2426862]=9674384;gGz(9674592,0,176);blH();c[3541228]=0;a[9545176]=0}bdX();c[2440552]=2e5;c[2440494]=59659;c[2444121]=0;c[2444120]=0;i=c[2392]|0;if((i|0)>=0){gGz(8452240,0,((i|0)>0?(i<<2)+4|0:4)|0)}c[2113054]=0;i=c[2385548]|0;if((i|0)>0){gGz(9752472,0,((i|0)>1?i<<2:4)|0)}c[2433530]=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];i=c[3532592]|0;if((i|0)!=0){gGC(9104152,i|0,280)|0}c[2113054]=c[2113060]}i=c[2439330]|0;if((i|0)!=0){h=i;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;h=0;i=0;L79251:while(1){g=i;do{if((g|0)>=256){break L79251}g=g+1|0;f=(ag(c[2440552]|0,g)|0)/256|0;e=f-(c[2444120]|0)|0;c[2438210]=e;c[2113056]=e;f=RG(e)|0;c[2113054]=(c[2113054]|0)+f;c[2276108]=-1;c[2113056]=-1;c[2444120]=(c[2444120]|0)+f;f=(ag(c[2440494]|0,g)|0)/256|0;e=c[2444121]|0;j=f-e|0;c[2438210]=j;do{if((j|0)<1){k=0;l=e}else{if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){f=gfc(j)|0;c[2433530]=(c[2433530]|0)+f;k=f;l=c[2444121]|0;break}else{c[2433530]=(c[2433530]|0)+j;k=j;l=e;break}}}while(0);c[2438210]=k;c[2444121]=l+k;m=c[2112964]|0;}while((m|0)==0);e=a[9688]|0?2:0;j=m+(h<<1<<1)|0;gg[c[3542124]&4095](j,e);TM(j,e);h=e+h|0;i=g}do{if((c[3541228]|0)!=0){c[8452200+(c[2394]<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0>=1024){break}RH(4)}}while(0);i=c[2112964]|0;do{if((i|0)!=0){m=a[9688]|0?534:0;k=m-h|0;l=i+(h<<1<<1)|0;if((m|0)==(h|0)){break}gg[c[3542124]&4095](l,k);TM(l,k)}}while(0);h=c[1836236]|0;i=c[9757320+(h<<2)>>2]|0;if((i|0)!=0){k=i;gGC(k|0,9706056,76)|0}c[9752472+(h<<2)>>2]=c[2433530];c[14113936+(h<<2)>>2]=c[2076596];c[9669104+(h<<2)>>2]=c[3541536];c[1836236]=-1;h=c[2394]|0;k=c[14130368+(h<<2)>>2]|0;if((k|0)!=0){gGC(k|0,9104152,280)|0}c[8452240+(h<<2)>>2]=c[2113054];c[2394]=-1;if((c[2112968]|0)==0){return 0}h=c[2439626]|0;k=c[2407018]|0;i=c[3530202]|0;l=0;do{m=b[h+(l<<1)>>1]|0;e=m&255;j=((e&255)>>>2&7|e<<3)&255;e=((m&65535)>>>7&7|(m&65535)>>>5<<3&255)&255;f=((m&65535)>>>12&7|(m&65535)>>>10<<3&255)&255;c[k+(l<<2)>>2]=e<<8|f|j<<16;c[i+(l<<2)>>2]=e<<3&2016|f>>>3|j<<8&63488;l=l+1|0;}while((l|0)<2048);bpj();c[2433324]=c[2437683];c[2437650]=c[2437684];c[2437651]=c[2437686];c[2437652]=c[2437685];l=a[14116146]|0;i=l&255;c[2405780]=i;k=a[14116148]|0;h=k&255;c[2405781]=h;j=d[14116147]|0;c[2405782]=j;if((l&255)<(k&255)){c[2405780]=h;c[2405781]=i;n=h;o=1;p=0;q=i}else{n=i;o=0;p=1;q=h}if(n>>>0<j>>>0){c[2405780]=j;c[2405782]=n;r=n;s=2;t=o}else{r=j;s=o;t=2}if((q|0)<(r|0)){c[2405781]=r;c[2405782]=q;u=t;v=p}else{u=p;v=t}bpk(s,1,c[2405828]|0);bpl(c[3529600]|0,2);bpk(u,0,c[2405828]|0);bpl(c[3529600]|0,1);bpk(v,0,c[2405828]|0);bpl(c[3529600]|0,0);R8(c[3530202]|0);return 0}function bdQ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1434116+(b*112|0)>>2];c[a+104>>2]=c[1434120+(b*112|0)>>2];c[a+108>>2]=c[1434124+(b*112|0)>>2];d=0;return d|0}function bdR(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=1434016+(b*112|0);e=0;return e|0}function bdS(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=963912+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function bdT(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>49){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1766616+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function bdU(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1433220+(b*112|0)>>2];c[a+104>>2]=c[1433224+(b*112|0)>>2];c[a+108>>2]=c[1433228+(b*112|0)>>2];d=0;return d|0}function bdV(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=1433120+(b*112|0);e=0;return e|0}function bdW(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>58){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1765904+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function bdX(){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;gGz(9625888,0,6);b=0;c=0;d=0;e=0;f=0;g=0;h=0;do{c=((a[9759304+b|0]&1)<<b|c&255)&255;d=((a[9759112+b|0]&1)<<b|d&255)&255;e=((a[9758920+b|0]&1)<<b|e&255)&255;f=((a[9758760+b|0]&1)<<b|f&255)&255;g=((a[9758720+b|0]&1)<<b|g&255)&255;h=((a[9758688+b|0]&1)<<b|h&255)&255;b=b+1|0;}while((b|0)<8);a[9625888]=c;a[9625889]=d;a[9625890]=e;a[9625891]=f;a[9625892]=g;a[9625893]=h;if((c&3)==3){h=c&-4;a[9625888]=h;i=h}else{i=c}if((i&12)==12){a[9625888]=i&-13}if((d&3)==3){i=d&-4;a[9625889]=i;j=i}else{j=d}if((j&12)==12){a[9625889]=j&-13}if((e&3)==3){j=e&-4;a[9625890]=j;k=j}else{k=e}if((k&12)==12){a[9625890]=k&-13}if((f&3)==3){k=f&-4;a[9625891]=k;l=k}else{l=f}if((l&12)==12){a[9625891]=l&-13}if((g&3)==3){l=g&-4;a[9625892]=l;m=l}else{m=g}if((m&12)!=12){return}a[9625892]=m&-13;return}function bdY(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;g=c[e>>2]|0;c[d>>2]=c[d>>2]|b<<13|g<<6&1024|g<<8&768|g<<9&6144;c[e>>2]=((c[e>>2]|0)>>>5&7)+(c[9750600+(a<<2)>>2]|0);return}function bdZ(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;e=(c[b>>2]|0)>>>2&24|32;do{if((e|0)>(c[2405782]|0)){if((e|0)<=(c[2405781]|0)){c[d>>2]=1;break}if((e|0)>(c[2405780]|0)){c[d>>2]=3;break}else{c[d>>2]=2;break}}else{c[d>>2]=0}}while(0);c[a>>2]=c[a>>2]&16383|c[b>>2]<<9&8192;c[b>>2]=(c[b>>2]&15)+(c[2433324]|0);return}function bd_(a,b,d){a=a|0;b=b|0;d=d|0;a=(c[b>>2]|0)>>>2&24|32;do{if((a|0)>(c[2405782]|0)){if((a|0)<=(c[2405781]|0)){c[d>>2]=1;break}if((a|0)>(c[2405780]|0)){c[d>>2]=3;break}else{c[d>>2]=2;break}}else{c[d>>2]=0}}while(0);c[b>>2]=(c[b>>2]&31)+(c[2433324]|0);return}function bd$(){var a=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;bpj();a=c[2437682]|0;c[2433324]=c[2437683];c[2437650]=c[2437684];c[2437651]=c[2437686];c[2437652]=c[2437685];e=d[14116146]|0;c[2405780]=e;f=d[14116148]|0;c[2405781]=f;c[2405782]=d[14116147]|0;g=ag(c[2113070]|0,c[2113068]|0)|0;if((g|0)>0){h=a<<4&65535;a=c[2112926]|0;i=0;do{b[a+(i<<1)>>1]=h;i=i+1|0;}while((i|0)<(g|0));j=c[2405780]|0;k=c[2405781]|0}else{j=e;k=f}if((j|0)<(k|0)){c[2405780]=k;c[2405781]=j;l=k;m=1;n=0;o=j}else{l=j;m=0;n=1;o=k}k=c[2405782]|0;if((l|0)<(k|0)){c[2405780]=k;c[2405782]=l;p=l;q=2;r=m}else{p=k;q=m;r=2}if((o|0)<(p|0)){c[2405781]=p;c[2405782]=o;s=r;t=n}else{s=n;t=r}r=d[14116149]|0;do{if((r|0)==0|(r|0)==62){u=61498}else{n=((c[2415284]|0)>>>1&8^8|c[2415282])*40|0;o=100-((n|0)/8|0)|0;if((n|0)<=7){u=61498;break}n=c[9750600+(t<<2)>>2]<<4;p=n+128|0;if((n|0)>0){m=c[2439626]|0;k=c[3530202]|0;l=0;do{j=b[m+(l<<1)>>1]|0;f=j&255;e=(ag(((f&255)>>>2&7|f<<3)&255,o)|0)/100|0;f=(ag(((j&65535)>>>7&7|(j&65535)>>>5<<3&255)&255,o)|0)/100|0;c[k+(l<<2)>>2]=f<<3&2016|e<<8&63488|((ag(((j&65535)>>>12&7|(j&65535)>>>10<<3&255)&255,o)|0)/100|0)>>>3&31;l=l+1|0;}while((l|0)<(n|0))}l=c[2439626]|0;k=c[3530202]|0;m=n;do{j=b[l+(m<<1)>>1]|0;c[k+(m<<2)>>2]=((j&65535)>>>10<<3&248)>>>3|((j&255)<<3&255)<<8|(((j&65535)>>>7&4|(j&65535)>>>5<<3&255)&255)<<3&2016;m=m+1|0;}while((m|0)<(p|0));if((p|0)<2048){v=p}else{break}do{m=b[l+(v<<1)>>1]|0;n=m&255;j=(ag(((n&255)>>>2&7|n<<3)&255,o)|0)/100|0;n=(ag(((m&65535)>>>7&7|(m&65535)>>>5<<3&255)&255,o)|0)/100|0;c[k+(v<<2)>>2]=n<<3&2016|j<<8&63488|((ag(((m&65535)>>>12&7|(m&65535)>>>10<<3&255)&255,o)|0)/100|0)>>>3&31;v=v+1|0;}while((v|0)<2048)}}while(0);if((u|0)==61498){u=c[2439626]|0;v=c[2407018]|0;r=c[3530202]|0;o=0;do{k=b[u+(o<<1)>>1]|0;l=k&255;p=((l&255)>>>2&7|l<<3)&255;l=((k&65535)>>>7&7|(k&65535)>>>5<<3&255)&255;m=((k&65535)>>>12&7|(k&65535)>>>10<<3&255)&255;c[v+(o<<2)>>2]=l<<8|m|p<<16;c[r+(o<<2)>>2]=l<<3&2016|m>>>3|p<<8&63488;o=o+1|0;}while((o|0)<2048)}biI(c[3529600]|0,3);bpk(q,0,c[2405828]|0);biI(c[3529600]|0,2);bpk(s,0,c[2405828]|0);biI(c[3529600]|0,1);biI(c[3529600]|0,0);bpk(t,0,c[2405828]|0);blK(c[2407018]|0,c[3530202]|0);return}function bd0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;e=(c[b>>2]|0)>>>2&24|32;do{if((e|0)>(c[2405782]|0)){if((e|0)<=(c[2405781]|0)){c[d>>2]=1;break}if((e|0)>(c[2405780]|0)){c[d>>2]=3;break}else{c[d>>2]=2;break}}else{c[d>>2]=0}}while(0);c[b>>2]=(c[b>>2]&31)+(c[2433324]|0);c[a>>2]=c[a>>2]&16383;return}function bd1(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;f=i;i=i+256|0;g=f|0;h=f+16|0;j=f+32|0;k=f+48|0;l=f+64|0;m=f+80|0;n=f+96|0;o=f+112|0;p=f+128|0;q=f+144|0;r=f+160|0;s=f+176|0;t=f+192|0;u=f+208|0;v=f+224|0;w=f+240|0;if((e|0)!=0){c[e>>2]=169619}if((b&32|0)!=0){gGz(w|0,0,12);e=c[2405720]|0;c[w>>2]=e;c[w+4>>2]=(c[2411882]|0)-e;c[w+12>>2]=162152;e=c[2076592]|0;gj[e&4095](w)|0}blJ(b);if((b&64|0)==0){i=f;return}w=l|0;gGz(k|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){e=l+9|0;l=j;x=j|0;y=j+4|0;z=j+12|0;A=k|0;B=k+4|0;C=k+12|0;D=0;do{gGC(w|0,614896,11)|0;a[e]=D+48&255;E=8452256+(D<<2)|0;gGz(l|0,0,12);c[x>>2]=E;c[y>>2]=4;c[z>>2]=164976;gj[c[2076592]&4095](j)|0;if((c[E>>2]|0)!=0){c[A>>2]=c[14130368+(D<<2)>>2];c[B>>2]=c[8452184+(D<<2)>>2];c[C>>2]=w;E=c[2076592]|0;gj[E&4095](k)|0}D=D+1|0;}while((D|0)<=(c[2392]|0))}gGz(h|0,0,12);c[h>>2]=8453216;c[h+4>>2]=4;c[h+12>>2]=107480;gj[c[2076592]&4095](h)|0;gGz(g|0,0,12);c[g>>2]=14168504;c[g+4>>2]=256;c[g+12>>2]=476464;gj[c[2076592]&4095](g)|0;if((b&2|0)!=0){b=0;do{mv(0,b,d[14168504+b|0]|0);b=b+1|0;}while((b|0)<256)}gGz(v|0,0,12);c[v>>2]=9776480;c[v+4>>2]=8;c[v+12>>2]=212472;gj[c[2076592]&4095](v)|0;gGz(u|0,0,12);c[u>>2]=9752840;c[u+4>>2]=4;c[u+12>>2]=436576;gj[c[2076592]&4095](u)|0;gGz(t|0,0,12);c[t>>2]=9658096;c[t+4>>2]=3;c[t+12>>2]=483352;gj[c[2076592]&4095](t)|0;gGz(s|0,0,12);c[s>>2]=9625888;c[s+4>>2]=6;c[s+12>>2]=215728;gj[c[2076592]&4095](s)|0;gGz(r|0,0,12);c[r>>2]=14115360;c[r+4>>2]=1;c[r+12>>2]=381544;gj[c[2076592]&4095](r)|0;gGz(q|0,0,12);c[q>>2]=9758256;c[q+4>>2]=1;c[q+12>>2]=497064;gj[c[2076592]&4095](q)|0;gGz(p|0,0,12);c[p>>2]=9747216;c[p+4>>2]=4;c[p+12>>2]=379152;gj[c[2076592]&4095](p)|0;gGz(o|0,0,12);c[o>>2]=9748104;c[o+4>>2]=4;c[o+12>>2]=378336;gj[c[2076592]&4095](o)|0;gGz(n|0,0,12);c[n>>2]=4927792;c[n+4>>2]=8;c[n+12>>2]=377400;gj[c[2076592]&4095](n)|0;gGz(m|0,0,12);c[m>>2]=9771880;c[m+4>>2]=4;c[m+12>>2]=376568;gj[c[2076592]&4095](m)|0;i=f;return}function bd2(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;e=(c[b>>2]|0)>>>2&24|32;do{if((e|0)>(c[2405782]|0)){if((e|0)<=(c[2405781]|0)){c[d>>2]=1;break}if((e|0)>(c[2405780]|0)){c[d>>2]=3;break}else{c[d>>2]=2;break}}else{c[d>>2]=0}}while(0);c[a>>2]=c[a>>2]&8191;c[b>>2]=(c[b>>2]&15)+(c[2433324]|0);return}function bd3(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;g=c[e>>2]|0;f=g<<8;c[d>>2]=g<<5&512|b<<12|f&256|f&3072|c[2429778]<<14|c[d>>2];c[e>>2]=((c[e>>2]|0)>>>5&7)+(c[9750600+(a<<2)>>2]|0);return}function bd4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;e=(c[b>>2]|0)>>>2&24|32;do{if((e|0)>(c[2405782]|0)){if((e|0)<=(c[2405781]|0)){c[d>>2]=1;break}if((e|0)>(c[2405780]|0)){c[d>>2]=3;break}else{c[d>>2]=2;break}}else{c[d>>2]=0}}while(0);c[a>>2]=c[a>>2]&8191;c[b>>2]=(c[b>>2]&31)+(c[2433324]|0);return}function bd5(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[2439626]|0;d=c[2407018]|0;f=c[3530202]|0;g=0;do{h=b[a+((g|1)<<1)>>1]|0;i=(e[a+(g<<1)>>1]|0)<<8|h&65535;j=h&255;h=((j&255)>>>2&7|j<<3)&255;j=(i>>>7&7|i>>>5<<3&255)&255;k=(i>>>12&7|i>>>10<<3&255)&255;i=g>>1;c[d+(i<<2)>>2]=k|h<<16|j<<8;c[f+(i<<2)>>2]=k>>>3|h<<8&63488|j<<3&2016;g=g+2|0;}while((g|0)<2048);bpj();bpk(2,1,c[2405828]|0);if((c[2442970]&1|0)!=0){bpl(c[3529600]|0,-1)}bpk(1,0,c[2405828]|0);if((c[2442970]&1|0)!=0){l=c[2405828]|0;bpk(0,0,l);m=c[3530202]|0;R8(m);return}bpl(c[3529600]|0,-1);l=c[2405828]|0;bpk(0,0,l);m=c[3530202]|0;R8(m);return}function bd6(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;g=c[e>>2]<<8;if((c[3541230]|a|0)==0){c[d>>2]=c[d>>2]|g&256;f=c[e>>2]|0;h=(f>>>5&4)+(c[9750600+(a<<2)>>2]|0)+(f>>>1&8)|0;c[e>>2]=h;return}else{c[d>>2]=c[d>>2]|g&3840;h=((c[e>>2]|0)>>>5&7)+(c[9750600+(a<<2)>>2]|0)|0;c[e>>2]=h;return}}function bd7(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;c[b>>2]=(c[b>>2]&15)+(c[2433324]|0);c[a>>2]=c[a>>2]&4095;return}function bd8(b,c){b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;if((c|0)!=2&(c&3|0)==0){d=b;e=c}else{return}while(1){c=(e|0)/2|0;b=(e|0)/4|0;if((e|0)>3){f=0;do{g=d+(f+b)|0;h=a[g]|0;i=d+(f+c)|0;a[g]=a[i]|0;a[i]=h;f=f+1|0;}while((f|0)<(b|0))}bd8(d,c);if((e-4|0)>>>0>1&(c&3|0)==0){d=d+c|0;e=c}else{break}}return}function bd9(a){a=a|0;c[2430236]=a;return}function bea(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;c[f>>2]=c[e>>2]&4;f=c[e>>2]|0;g=f<<8&256;if((a|0)==0){c[d>>2]=c[d>>2]|g;h=c[e>>2]|0;i=(h>>>5&4)+(c[2437650]|0)+(h>>>1&8)|0;c[e>>2]=i;return}else{c[d>>2]=f<<6&1536|b<<11|g|c[d>>2];i=((c[e>>2]|0)>>>5&7)+(c[9750600+(a<<2)>>2]|0)|0;c[e>>2]=i;return}}function beb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;c[b>>2]=(c[b>>2]&15)+(c[2433324]|0);return}function bec(a,c){a=a|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;if((c|0)!=2&(c&3|0)==0){d=a;e=c}else{return}while(1){c=(e|0)/2|0;a=(e|0)/4|0;if((e|0)>3){f=0;do{g=d+(f+a<<1)|0;h=b[g>>1]|0;i=d+(f+c<<1)|0;b[g>>1]=b[i>>1]|0;b[i>>1]=h;f=f+1|0;}while((f|0)<(a|0))}bec(d,c);if((e-4|0)>>>0>1&(c&3|0)==0){d=d+(c<<1)|0;e=c}else{break}}return}function bed(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+128|0;g=f|0;if((e|0)>0){h=0}else{i=f;return}do{j=0;while(1){k=d[b+(j+h)|0]|0;l=j<<3;c[g+(l<<2)>>2]=k&1;c[g+((l|1)<<2)>>2]=k>>>1&1;c[g+((l|2)<<2)>>2]=k>>>2&1;c[g+((l|3)<<2)>>2]=k>>>3&1;c[g+((l|4)<<2)>>2]=k>>>4&1;c[g+((l|5)<<2)>>2]=k>>>5&1;c[g+((l|6)<<2)>>2]=k>>>6&1;c[g+((l|7)<<2)>>2]=k>>>7;k=j+1|0;if((k|0)<4){j=k}else{m=0;break}}do{a[b+(m+h)|0]=(c[g+(m+4<<2)>>2]<<1|c[g+(m<<2)>>2]|c[g+(m+8<<2)>>2]<<2|c[g+(m+12<<2)>>2]<<3|c[g+(m+16<<2)>>2]<<4|c[g+(m+20<<2)>>2]<<5|c[g+(m+24<<2)>>2]<<6|c[g+(m+28<<2)>>2]<<7)&255;m=m+1|0;}while((m|0)<4);h=h+4|0;}while((h|0)<(e|0));i=f;return}function bee(b){b=b|0;a[9681232]=((b>>4)*17|0)&255;a[9681233]=0;c[2424878]=9681232;a[9681234]=0;a[9681235]=((b&15)*17|0)&255;return}function bef(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;c[a>>2]=c[b>>2]<<9&8192|c[a>>2];c[b>>2]=(c[b>>2]&15)+(c[2433324]|0);return}function beg(b){b=b|0;var c=0;switch(b&65535|0){case 41152:{c=a[9630121]<<1^~a[9630120]^a[9630122]<<2^a[9630123]<<3^a[9630124]<<4^a[9630125]<<5^a[9630126]<<6^a[9630127]<<7;return c|0};case 41184:{c=a[9635728]|0;return c|0};case 41088:{c=a[9634441]<<1^~a[9634440]^a[9634442]<<2^a[9634443]<<3^a[9634444]<<4^a[9634445]<<5^a[9634446]<<6^a[9634447]<<7;return c|0};case 40960:{c=a[9635729]|0;return c|0};case 41120:{c=a[9632201]<<1^~a[9632200]^a[9632202]<<2^a[9632203]<<3^a[9632204]<<4^a[9632205]<<5^a[9632206]<<6^a[9632207]<<7;return c|0};default:{c=0;return c|0}}return 0}function beh(d,e){d=d|0;e=e|0;var f=0,g=0;f=d&65535;if((f|0)==41216){a[14113512]=e;return}else if((f|0)==41351){a[14115112]=e&1^1;return}else if((f|0)==41344){d=e&1;a[14114464]=d;if(d<<24>>24!=0){return}a[9706117]=0;return}else if((f|0)==41345){if(!((a[14114424]|0)!=0|e<<24>>24==0)){f=c[1836236]|0;d=c[9757320+(f<<2)>>2]|0;if((d|0)!=0){g=d;gGC(g|0,9706056,76)|0}c[9752472+(f<<2)>>2]=c[2433530];c[14113936+(f<<2)>>2]=c[2076596];c[9669104+(f<<2)>>2]=c[3541536];c[1836236]=-1;f=c[2439331]|0;if((f|0)!=0){g=f;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0;g=c[1836236]|0;f=c[9757320+(g<<2)>>2]|0;if((f|0)!=0){d=f;gGC(d|0,9706056,76)|0}c[9752472+(g<<2)>>2]=c[2433530];c[14113936+(g<<2)>>2]=c[2076596];c[9669104+(g<<2)>>2]=c[3541536];c[1836236]=-1;g=c[2439330]|0;if((g|0)!=0){d=g;gGC(9706056,d|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0}a[14114424]=e;return}else{return}}function bei(b){b=b|0;var d=0,e=0,f=0;d=b&61440;if((d|0)==16384){b=c[3542228]|0;if((b|0)>15){e=0;return e|0}do{if((b|0)==15){f=c[3542225]|0;if((f|0)==0){break}a[14168931]=gj[f&4095](0)|0}else if((b|0)==14){f=c[3542224]|0;if((f|0)==0){break}a[14168930]=gj[f&4095](0)|0}}while(0);e=a[14168916+b|0]|0;return e|0}else if((d|0)==24576){d=c[3542291]|0;if((d|0)>15){e=0;return e|0}do{if((d|0)==15){b=c[3542288]|0;if((b|0)==0){break}a[14169183]=gj[b&4095](0)|0}else if((d|0)==14){b=c[3542287]|0;if((b|0)==0){break}a[14169182]=gj[b&4095](0)|0}}while(0);e=a[14169168+d|0]|0;return e|0}else{e=0;return e|0}return 0}function bej(b,d){b=b|0;d=d|0;var e=0,f=0;e=b&61440;if((e|0)==16384){b=d&255;f=c[3542228]|0;if((f|0)>15){return}do{if((f|0)<14){if((f|0)!=13){if((a[14168916+f|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(0,f,b);return}else if((e|0)==28672){c[3542291]=d&15;return}else if((e|0)==20480){c[3542228]=d&15;return}else if((e|0)==24576){e=d&255;b=c[3542291]|0;if((b|0)>15){return}do{if((b|0)<14){if((b|0)!=13){if((a[14169168+b|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(1,b,e);return}else{return}}function bek(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5738124+(b*112|0)>>2];c[a+104>>2]=c[5738128+(b*112|0)>>2];c[a+108>>2]=c[5738132+(b*112|0)>>2];d=0;return d|0}function bel(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=5738024+(b*112|0);e=0;return e|0}function bem(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6938848+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function ben(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>72){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7449720+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function beo(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0.0,ad=0,ae=0;e=i;i=i+968|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;c[2426816]=0;c[2424772]=0;c[2424758]=65536;c[2424868]=81920;c[2424844]=98304;c[2424796]=114688;c[2407016]=115232;c[3530200]=117280;w=(a[9688]|0?125736:119328)|0;c[2414432]=w;x=w;w=0;while(1){if((w|0)>=1024){break}y=9638528+(w<<2)|0;if((c[y>>2]|0)==0){z=61699;break}else{w=w+1|0}}do{if((z|0)==61699){w=gGq(x)|0;c[y>>2]=w;if((w|0)==0){break}gGz(w|0,0,x|0);c[2426816]=w;gGz(w|0,0,x|0);c[2424772]=w;c[2424758]=w+65536;c[2424868]=w+81920;c[2424844]=w+98304;c[2424796]=w+114688;c[2407016]=w+115232;c[3530200]=w+117280;A=w+119328|0;c[2385406]=A;B=a[9688]|0?534:0;c[2414432]=w+((B*12|0)+119328);c[2439174]=A;c[2439175]=A+(B<<1);c[2439176]=A+(B<<1<<1);c[2439177]=A+((B*3|0)<<1);c[2439178]=A+(B<<2<<1);c[2439179]=A+((B*5|0)<<1);B=t+108|0;A=t+100|0;C=0;D=w;while(1){w=D+(C<<13)|0;if((c[3542200]|0)==0){E=1;z=61820;break}c[B>>2]=0;c[A>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,C)|0;if((c[B>>2]|0)!=0){F=c[A>>2]|0;c[u>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](u,C,0)|0;if((F|0)<1){E=1;z=61825;break}if((gzL(w,0,C)|0)!=0){E=1;z=61822;break}}w=C+1|0;if((w|0)>=4){z=61702;break}C=w;D=c[2424772]|0}if((z|0)==61702){D=r+108|0;C=r+100|0;A=p+108|0;B=p+100|0;w=n+108|0;F=n+100|0;G=0;while(1){H=G<<12;I=(c[2424758]|0)+H|0;J=G+4|0;if((c[3542200]|0)==0){E=1;z=61813;break}c[D>>2]=0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,J)|0;if((c[D>>2]|0)!=0){K=c[C>>2]|0;c[s>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](s,J,0)|0;if((K|0)<1){E=1;z=61808;break}if((gzL(I,0,J)|0)!=0){E=1;z=61819;break}}J=(c[2424868]|0)+H|0;I=G+6|0;if((c[3542200]|0)==0){E=1;z=61816;break}c[A>>2]=0;c[B>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,I)|0;if((c[A>>2]|0)!=0){K=c[B>>2]|0;c[q>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](q,I,0)|0;if((K|0)<1){E=1;z=61809;break}if((gzL(J,0,I)|0)!=0){E=1;z=61801;break}}I=(c[2424844]|0)+H|0;H=G+8|0;if((c[3542200]|0)==0){E=1;z=61802;break}c[w>>2]=0;c[F>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,H)|0;if((c[w>>2]|0)!=0){J=c[F>>2]|0;c[o>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](o,H,0)|0;if((J|0)<1){E=1;z=61811;break}if((gzL(I,0,H)|0)!=0){E=1;z=61806;break}}H=G+1|0;if((H|0)<2){G=H}else{z=61722;break}}if((z|0)==61722){G=c[2424796]|0;if((c[3542200]|0)==0){E=1;i=e;return E|0}F=l+108|0;c[F>>2]=0;w=l+100|0;c[w>>2]=0;B=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[B&16383](l,10)|0;do{if((c[F>>2]|0)!=0){B=c[w>>2]|0;c[m>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](m,10,0)|0;if((B|0)<1){E=1;i=e;return E|0}if((gzL(G,0,10)|0)==0){break}else{E=1}i=e;return E|0}}while(0);G=(c[2424796]|0)+32|0;if((c[3542200]|0)==0){E=1;i=e;return E|0}w=j+108|0;c[w>>2]=0;F=j+100|0;c[F>>2]=0;B=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[B&16383](j,11)|0;do{if((c[w>>2]|0)!=0){B=c[F>>2]|0;c[k>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](k,11,0)|0;if((B|0)<1){E=1;i=e;return E|0}if((gzL(G,0,11)|0)==0){break}else{E=1}i=e;return E|0}}while(0);G=(c[2424796]|0)+288|0;if((c[3542200]|0)==0){E=1;i=e;return E|0}F=f+108|0;c[F>>2]=0;w=f+100|0;c[w>>2]=0;B=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[B&16383](f,12)|0;do{if((c[F>>2]|0)==0){M=0}else{B=c[w>>2]|0;c[g>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](g,12,0)|0;if((B|0)<1){E=1;i=e;return E|0}if((gzL(G,0,12)|0)==0){M=0;break}else{E=1}i=e;return E|0}}while(0);while(1){if((M|0)>=1024){E=1;z=61815;break}N=9638528+(M<<2)|0;if((c[N>>2]|0)==0){break}else{M=M+1|0}}if((z|0)==61815){i=e;return E|0}G=gGq(8192)|0;c[N>>2]=G;if((G|0)==0){E=1;i=e;return E|0}gGz(G|0,0,8192);w=c[2424868]|0;gGC(G|0,w|0,8192)|0;F=0;do{B=F<<6;gGz(w+B|0,0,64);A=F<<7;C=0;do{D=1<<3-C;H=(c[611104+(C<<2)>>2]|0)+A|0;I=0;do{J=H+(c[611712+(I<<2)>>2]|0)|0;K=(I<<3)+B|0;L=0;do{O=J+(c[609488+(L<<2)>>2]|0)|0;if(((d[G+((O|0)/8|0)|0]|0)&128>>>((O&7)>>>0)|0)!=0){O=w+(K+L)|0;a[O]=(d[O]|0|D)&255}L=L+1|0;}while((L|0)<8);I=I+1|0;}while((I|0)<8);C=C+1|0;}while((C|0)<4);F=F+1|0;}while((F|0)<256);F=c[2424844]|0;gGC(G|0,F|0,8192)|0;w=0;while(1){C=w<<8;gGz(F+C|0,0,256);B=w<<9;A=0;do{I=1<<3-A;D=(c[611104+(A<<2)>>2]|0)+B|0;H=0;do{L=D+(c[611712+(H<<2)>>2]|0)|0;K=(H<<4)+C|0;J=0;do{O=L+(c[609488+(J<<2)>>2]|0)|0;if(((d[G+((O|0)/8|0)|0]|0)&128>>>((O&7)>>>0)|0)!=0){O=F+(K+J)|0;a[O]=(d[O]|0|I)&255}J=J+1|0;}while((J|0)<16);H=H+1|0;}while((H|0)<16);A=A+1|0;}while((A|0)<4);A=w+1|0;if((A|0)<64){w=A}else{P=0;break}}while(1){if((P|0)>=1024){break}Q=9638528+(P<<2)|0;if((c[Q>>2]|0)==(G|0)){z=61759;break}else{P=P+1|0}}if((z|0)==61759){gGr(G);c[Q>>2]=0}w=c[2424796]|0;F=0;do{A=d[w+F|0]|0;c[v+(F<<2)>>2]=-(A>>>6&1)&80|-(A>>>7)&171|(-(A>>>3&1)&33)+(-(A>>>4&1)&71)+(-(A>>>5&1)&151)<<8|(-(A>>>1&1)&71)+(-(A&1)&33)+(-(A>>>2&1)&151)<<16;F=F+1|0;}while((F|0)<32);F=c[2407016]|0;G=0;do{c[F+(G<<2)>>2]=c[v+((a[w+(G+32)|0]&15|16)<<2)>>2];c[F+(G+256<<2)>>2]=c[v+((a[w+(G+288)|0]&15)<<2)>>2];G=G+1|0;}while((G|0)<256);fwR(0);G=c[2439330]|0;if((G|0)!=0){w=G;gGC(9706056,w|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];w=c[3528484]|0;c[2076596]=w;F=c[2417276]|0;c[3541536]=F;c[1836236]=0;A=c[2424772]|0;C=0;B=0;while(1){c[G+76+(B<<2)>>2]=A+(B<<8);H=C+1&65535;if((H&65535)>127){R=0;S=0;break}else{C=H;B=H&65535}}while(1){B=A+(S<<8)|0;c[G+76+(S+512<<2)>>2]=B;c[G+76+(S+768<<2)>>2]=B;B=R+1&65535;if((B&65535)>127){break}else{R=B;S=B&65535}}B=A+32768|0;c[G+588>>2]=B;C=A+33024|0;c[G+592>>2]=C;H=A+33280|0;c[G+596>>2]=H;I=A+33536|0;c[G+600>>2]=I;D=A+33792|0;c[G+604>>2]=D;J=A+34048|0;c[G+608>>2]=J;K=A+34304|0;c[G+612>>2]=K;L=A+34560|0;c[G+616>>2]=L;O=A+34816|0;c[G+620>>2]=O;T=A+35072|0;c[G+624>>2]=T;U=A+35328|0;c[G+628>>2]=U;V=A+35584|0;c[G+632>>2]=V;W=A+35840|0;c[G+636>>2]=W;X=A+36096|0;c[G+640>>2]=X;Y=A+36352|0;c[G+644>>2]=Y;Z=A+36608|0;c[G+648>>2]=Z;c[G+1612>>2]=B;c[G+1616>>2]=C;c[G+1620>>2]=H;c[G+1624>>2]=I;c[G+1628>>2]=D;c[G+1632>>2]=J;c[G+1636>>2]=K;c[G+1640>>2]=L;c[G+1644>>2]=O;c[G+1648>>2]=T;c[G+1652>>2]=U;c[G+1656>>2]=V;c[G+1660>>2]=W;c[G+1664>>2]=X;c[G+1668>>2]=Y;c[G+1672>>2]=Z;Z=128;Y=128;while(1){X=A+(Y<<8)|0;c[G+76+(Y+512<<2)>>2]=X;c[G+76+(Y+768<<2)>>2]=X;X=Z+1&65535;if((X&65535)>143){break}else{Z=X;Y=X&65535}}Y=A+36864|0;c[G+652>>2]=Y;c[G+1676>>2]=Y;c[G+2700>>2]=Y;c[G+3724>>2]=Y;Y=A+37888|0;c[G+668>>2]=Y;c[G+1692>>2]=Y;c[G+2716>>2]=Y;c[G+3740>>2]=Y;c[G+4184>>2]=1956;c[G+4180>>2]=2894;Y=G;gGC(Y|0,9706056,76)|0;c[2438118]=c[2433530];c[3528484]=w;c[2417276]=F;c[1836236]=-1;fwR(1);Y=c[2439331]|0;Z=(Y|0)==0;if(!Z){X=Y;gGC(9706056,X|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];X=c[3528485]|0;c[2076596]=X;W=c[2417277]|0;c[3541536]=W;c[1836236]=1;V=c[2424758]|0;U=0;T=0;while(1){c[Y+76+(T<<2)>>2]=V+(T<<8);O=U+1&65535;if((O&65535)>31){_=0;$=0;break}else{U=O;T=O&65535}}while(1){T=V+($<<8)|0;c[Y+76+($+512<<2)>>2]=T;c[Y+76+($+768<<2)>>2]=T;T=_+1&65535;if((T&65535)>31){break}else{_=T;$=T&65535}}T=V+12288|0;c[Y+268>>2]=T;U=V+12544|0;c[Y+272>>2]=U;F=V+12800|0;c[Y+276>>2]=F;w=V+13056|0;c[Y+280>>2]=w;c[Y+1292>>2]=T;c[Y+1296>>2]=U;c[Y+1300>>2]=F;c[Y+1304>>2]=w;c[Y+2316>>2]=T;c[Y+3340>>2]=T;c[Y+2320>>2]=U;c[Y+3344>>2]=U;c[Y+2324>>2]=F;c[Y+3348>>2]=F;c[Y+2328>>2]=w;c[Y+3352>>2]=w;c[Y+4184>>2]=220;c[Y+4180>>2]=360;if(!Z){w=Y;gGC(w|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=X;c[2417277]=W;c[1836236]=-1;w=c[642608+(c[2436]<<2)>>2]|0;F=c[w+128>>2]|0;if((c[w+52>>2]&4|0)==0){c[2113068]=F;U=c[w+132>>2]|0;c[2113070]=U;c[2443814]=F;c[2440436]=U;aa=F;ab=U}else{c[2113070]=F;U=c[w+132>>2]|0;c[2113068]=U;c[2440436]=F;c[2443814]=U;aa=U;ab=F}F=ag(aa<<1,ab)|0;U=gGq(F)|0;c[2112926]=U;if((U|0)!=0){gGz(U|0,0,F|0)}F=a[9680]|0?32e3:0;c[3542220]=11200;U=c[2113008]|0;if((U|0)==0){gGz(14168888,0,252);c[3542223]=F;c[3542224]=3230;c[3542225]=1912;c[3542226]=0;c[3542227]=0;c[3542234]=~~((+(F|0)*32768.0*8.0+894886.0)/1789773.0);w=31;ac=32767.0;while(1){c[14169012+(w<<2)>>2]=~~(ac+.5);T=w-1|0;if((T|0)>0){w=T;ac=ac/1.188502227}else{break}}c[3542253]=0;h[1771269]=1.0;h[1771270]=1.0;h[1771271]=1.0;c[3542574]=3;c[3542575]=3;c[3542576]=3;mB(0);w=(c[2113008]|0)+1|0;c[2113008]=w;ad=w;ae=a[9680]|0?32e3:0}else{ad=U;ae=F}c[3542220]=11200;if((ad|0)==1){gGz(14169140,0,252);c[3542286]=ae;gGz(14169148,0,16);c[3542297]=~~((+(ae|0)*32768.0*8.0+894886.0)/1789773.0);w=31;ac=32767.0;while(1){c[14169264+(w<<2)>>2]=~~(ac+.5);W=w-1|0;if((W|0)>0){w=W;ac=ac/1.188502227}else{break}}c[3542316]=0;h[1771272]=1.0;h[1771273]=1.0;h[1771274]=1.0;c[3542577]=3;c[3542578]=3;c[3542579]=3;mB(1);c[2113008]=(c[2113008]|0)+1}h[1771269]=.25;c[3542574]=3;h[1771270]=.25;c[3542575]=3;h[1771271]=.25;c[3542576]=3;h[1771272]=.25;c[3542577]=3;h[1771273]=.25;c[3542578]=3;h[1771274]=.25;c[3542579]=3;a[9625072]=0;w=c[2439330]|0;F=(w|0)==0;if(!F){U=w;gGC(9706056,U|0,76)|0}U=c[2438118]|0;c[2433530]=U;W=c[3528484]|0;c[2076596]=W;X=c[2417276]|0;c[3541536]=X;c[1836236]=0;gGz(9706056,0,76);if(!F){F=w;gGC(F|0,9706056,76)|0}c[2438118]=U;c[3528484]=W;c[2417276]=X;c[1836236]=-1;X=c[2439331]|0;W=(X|0)==0;if(!W){U=X;gGC(9706056,U|0,76)|0}U=c[2438119]|0;c[2433530]=U;F=c[3528485]|0;c[2076596]=F;w=c[2417277]|0;c[3541536]=w;c[1836236]=1;gGz(9706056,0,76);if(!W){W=X;gGC(W|0,9706056,76)|0}c[2438119]=U;c[3528485]=F;c[2417277]=w;c[1836236]=-1;mB(0);mB(1);gGz((c[2424772]|0)+32768|0,0,6144);gGz((c[2424758]|0)+12288|0,0,1024);a[14114424]=0;a[14115112]=0;a[14113512]=0;a[14114464]=0;E=0;i=e;return E|0}else if((z|0)==61801){i=e;return E|0}else if((z|0)==61802){i=e;return E|0}else if((z|0)==61806){i=e;return E|0}else if((z|0)==61808){i=e;return E|0}else if((z|0)==61809){i=e;return E|0}else if((z|0)==61811){i=e;return E|0}else if((z|0)==61813){i=e;return E|0}else if((z|0)==61816){i=e;return E|0}else if((z|0)==61819){i=e;return E|0}}else if((z|0)==61820){i=e;return E|0}else if((z|0)==61822){i=e;return E|0}else if((z|0)==61825){i=e;return E|0}}}while(0);c[2426816]=0;E=1;i=e;return E|0}function bep(){var b=0,d=0,e=0,f=0;fwZ();c[2113008]=0;c[2076598]=0;c[2383582]=0;c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}b=c[2426816]|0;d=0;while(1){if((d|0)>=1024){break}e=9638528+(d<<2)|0;if((c[e>>2]|0)==(b|0)){f=61831;break}else{d=d+1|0}}if((f|0)==61831){gGr(b);c[e>>2]=0}c[2426816]=0;c[2424796]=0;c[2424844]=0;c[2424868]=0;c[2424758]=0;c[2424772]=0;c[3530200]=0;c[2407016]=0;gGz(9756696,0,24);a[14114424]=0;a[14114464]=0;a[14115112]=0;a[14113512]=0;return 0}function beq(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;if((a[9625072]|0)==0){d=0;e=0;f=0}else{a[9625072]=0;g=c[2439330]|0;h=(g|0)==0;if(!h){i=g;gGC(9706056,i|0,76)|0}i=c[2438118]|0;c[2433530]=i;j=c[3528484]|0;c[2076596]=j;k=c[2417276]|0;c[3541536]=k;c[1836236]=0;gGz(9706056,0,76);if(!h){h=g;gGC(h|0,9706056,76)|0}c[2438118]=i;c[3528484]=j;c[2417276]=k;c[1836236]=-1;k=c[2439331]|0;j=(k|0)==0;if(!j){i=k;gGC(9706056,i|0,76)|0}i=c[2438119]|0;c[2433530]=i;h=c[3528485]|0;c[2076596]=h;g=c[2417277]|0;c[3541536]=g;c[1836236]=1;gGz(9706056,0,76);if(!j){j=k;gGC(j|0,9706056,76)|0}c[2438119]=i;c[3528485]=h;c[2417277]=g;c[1836236]=-1;mB(0);mB(1);gGz((c[2424772]|0)+32768|0,0,6144);gGz((c[2424758]|0)+12288|0,0,1024);a[14114424]=0;a[14115112]=0;a[14113512]=0;a[14114464]=0;d=0;e=0;f=0}while(1){g=c[2439330]|0;if((g|0)!=0){h=g;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;h=c[2438118]|0;c[2433530]=h;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;i=f+1|0;j=((i*51200|0|0)/10|0)-e|0;do{if((j|0)<1){l=0;m=h}else{if((a[g+4188|0]|0)==0){k=gfc(j)|0;n=(c[2433530]|0)+k|0;c[2433530]=n;l=k;m=n;break}else{n=h+j|0;c[2433530]=n;l=j;m=n;break}}}while(0);j=l+e|0;if((a[14114464]|0)!=0&(f|0)==9){if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;h=(c[2433530]|0)+12|0;c[2433530]=h;o=h}else{o=m}h=c[1836236]|0;g=c[9757320+(h<<2)>>2]|0;if((g|0)!=0){n=g;gGC(n|0,9706056,76)|0}c[9752472+(h<<2)>>2]=o;c[14113936+(h<<2)>>2]=c[2076596];c[9669104+(h<<2)>>2]=c[3541536];c[1836236]=-1;h=c[2439331]|0;if((h|0)!=0){n=h;gGC(9706056,n|0,76)|0}b[4853030]=c[2426515]&65535;n=c[2438119]|0;c[2433530]=n;c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;g=((i*29829|0|0)/10|0)-d|0;do{if((g|0)<1){p=0;q=1;r=h;s=n}else{if((a[h+4188|0]|0)==0){k=gfc(g)|0;t=(c[2433530]|0)+k|0;c[2433530]=t;u=c[1836236]|0;p=k;q=u;r=c[9757320+(u<<2)>>2]|0;s=t;break}else{t=n+g|0;c[2433530]=t;p=g;q=1;r=h;s=t;break}}}while(0);if((r|0)!=0){h=r;gGC(h|0,9706056,76)|0}c[9752472+(q<<2)>>2]=s;c[14113936+(q<<2)>>2]=c[2076596];c[9669104+(q<<2)>>2]=c[3541536];c[1836236]=-1;if((i|0)<10){d=p+d|0;e=j;f=i}else{break}}f=c[2112964]|0;if((f|0)!=0){mF(9756696,f,a[9688]|0?534:0,0)}if((c[2112968]|0)==0){return 0}ber()|0;return 0}function ber(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((a[9733800]|0)!=0){b=c[2407016]|0;e=c[3530200]|0;f=0;do{g=c[b+(f<<2)>>2]|0;c[e+(f<<2)>>2]=g>>>8<<3&2016|g>>>3&31|g>>>16<<8&63488;f=f+1|0;}while((f|0)<512)}f=c[2424772]|0;e=c[2112926]|0;b=c[2424868]|0;g=0;do{h=d[f+(g+32768)|0]|0;i=d[f+(g+33792)|0]|0;j=h&15;k=h>>>6&1;l=h>>>7;h=g<<3&248;m=g>>>2&248;if((a[14115112]|0)==0){n=k;o=l;p=h;q=m}else{n=k^1;o=l^1;p=h^248;q=m^248}m=q-16|0;do{if(m>>>0<=223){h=(n|0)!=0;if((o|0)==0){if(h){Sk(e,i,p,m,j,4,0,b);break}else{Si(e,i,p,m,j,4,0,b);break}}else{if(h){So(e,i,p,m,j,4,0,b);break}else{Sm(e,i,p,m,j,4,0,b);break}}}}while(0);g=g+1|0;}while((g|0)<1024);g=c[2424844]|0;b=16;do{p=d[f+(b+36864)|0]|0;o=a[f+(b+37889)|0]|0;n=240-(o&255)|0;q=a[f+(b+36865)|0]&63;j=d[f+(b+37888)|0]|0;m=j&15|16;do{if(!(o<<24>>24==-16|(n|0)>239)){i=n-16|0;h=(j&64|0)==0;if((j&128|0)==0){if(h){SJ(e,q,p,i,m,4,0,0,g);break}else{SH(e,q,p,i,m,4,0,0,g);break}}else{if(h){SN(e,q,p,i,m,4,0,0,g);break}else{SL(e,q,p,i,m,4,0,0,g);break}}}}while(0);b=b+2|0;}while((b|0)<64);R8(c[3530200]|0);return 0}function bes(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=i;i=i+112|0;e=d|0;f=d+32|0;g=d+48|0;h=d+64|0;j=d+80|0;k=d+96|0;l=(b|0)==0;if(!l){c[b>>2]=169249}if((a&96|0)==0){i=d;return 0}gGz(k|0,0,12);m=k|0;c[m>>2]=(c[2424772]|0)+32768;n=k+4|0;c[n>>2]=6144;o=k+12|0;c[o>>2]=571880;gj[c[2076592]&4095](k)|0;c[m>>2]=(c[2424758]|0)+12288;c[n>>2]=1024;c[o>>2]=555040;gj[c[2076592]&4095](k)|0;fw$(a);k=d+16|0;do{if((a&64|0)!=0){do{if(!l){if((c[b>>2]|0)>=169110){break}c[b>>2]=169110}}while(0);if((c[2113008]|0)<=0){break}o=e|0;n=e+4|0;m=e+8|0;p=e+12|0;q=0;do{cC(k|0,531144,(r=i,i=i+8|0,c[r>>2]=q,r)|0)|0;i=r;c[o>>2]=14168888+(q*252|0);c[n>>2]=252;c[m>>2]=0;c[p>>2]=k;gj[c[2076592]&4095](e)|0;q=q+1|0;}while((q|0)<(c[2113008]|0))}}while(0);gGz(j|0,0,12);c[j>>2]=14113512;c[j+4>>2]=1;c[j+12>>2]=191240;gj[c[2076592]&4095](j)|0;gGz(h|0,0,12);c[h>>2]=14114424;c[h+4>>2]=1;c[h+12>>2]=527176;gj[c[2076592]&4095](h)|0;gGz(g|0,0,12);c[g>>2]=14114464;c[g+4>>2]=1;c[g+12>>2]=84696;gj[c[2076592]&4095](g)|0;gGz(f|0,0,12);c[f>>2]=14115112;c[f+4>>2]=1;c[f+12>>2]=142288;gj[c[2076592]&4095](f)|0;i=d;return 0}function bet(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4475692+(b*112|0)>>2];c[a+104>>2]=c[4475696+(b*112|0)>>2];c[a+108>>2]=c[4475700+(b*112|0)>>2];d=0;return d|0}function beu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=4475592+(b*112|0);e=0;return e|0}function bev(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5739580+(b*112|0)>>2];c[a+104>>2]=c[5739584+(b*112|0)>>2];c[a+108>>2]=c[5739588+(b*112|0)>>2];d=0;return d|0}function bew(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=5739480+(b*112|0);e=0;return e|0}function bex(b){b=b|0;return a[14113512]|0}function bey(a){a=a|0;return c[606e3+((((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)>>9|0)%10|0)<<2)>>2]&255|0}function bez(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=b&65535;switch(e|0){case 8096:case 8097:case 8098:case 8099:case 8100:case 8101:case 8102:case 8103:{a[14108480+(e&7)|0]=d;return};case 8128:{c[3541230]=d&8;a[9718928]=d&32^32;return};case 8134:case 8135:{TO(e&1,d);return};case 8130:{f=d&255;if(d<<24>>24==-1){return}c[2415256]=f>>>7;g=f>>>3&1;c[3528406]=g^1;if((g|0)==0){c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2]}Tr(f>>>4&1);c[2385188]=f&3;c[2427088]=f&4;return};default:{do{if((e&61440|0)==0){if((c[2385188]&1|0)==0){break}a[(c[2387290]|0)+(e&4095)|0]=d;return}}while(0);if((e&65520|0)==8112){f=e&15;g=d&255;h=g&63;a[14116144+f|0]=h&255;if((f|0)==10){c[2437685]=g<<4&112;c[2437686]=h>>>3<<4;return}else if((f|0)==9){c[2437682]=g<<5&96;c[2437683]=g>>>2<<5&96;c[2437684]=h>>>4<<5;return}else{return}}do{if((e&57344|0)==8192){if((c[2385188]&2|0)==0){break}a[(c[2386534]|0)+((b^1)&8191)|0]=d;return}}while(0);if((e&49152|0)!=0){return}b=e&16383;a[(c[3529062]|0)+b|0]=d;if((e&6144)>>>0<=6143){return}if((b|0)==7680|(b|0)==15872){a[9730680]=d;return}else if((b|0)==7808){c[2432672]=(d&255)>>>1&3;return}else if((b|0)==7424){c[3541228]=d&4;return}else if((b|0)==7552){a[9720736]=d&15;a[9720737]=(d&255)>>>4;return}else if((b|0)==7296){a[9729904]=d;return}else if((b|0)==7936){a[9720738]=d&15;a[9720739]=(d&255)>>>4;return}else{return}}}}function beA(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;e=i;i=i+24|0;f=e|0;g=e+8|0;h=e+16|0;j=b&65535;switch(j|0){case 8065:{do{if((c[2406632]|0)==0){k=c[2443744]|0;if((k|0)<=0){l=16;break}c[2443744]=k-1;l=0}else{l=(c[2432962]|0)>>>((c[(c[2420380]|0)+4>>2]|0)>>>0)<<4&16}}while(0);k=c[2430486]|0;m=((a[9635784]&1|l)^33)&255;if((k|0)<=0){n=m;i=e;return n|0}c[2430486]=k-1;n=m&48;i=e;return n|0};case 8134:case 8135:{c[2426862]=9674384;n=c[9674388+((j&1|2)<<2)>>2]&255;i=e;return n|0};case 8080:{n=a[9551016]|0;i=e;return n|0};case 8064:{n=a[9551020]|0;i=e;return n|0};case 8138:{n=0;i=e;return n|0};case 8081:{n=a[9551017]|0;i=e;return n|0};case 8132:{a[14125144]=-1;a[9706117]=1;n=0;i=e;return n|0};case 8083:{n=a[9551019]|0;i=e;return n|0};case 8136:case 8137:{if((a[9718928]|0)==0){n=0;i=e;return n|0}n=a[(c[3529048]|0)+(((d[14108486]<<17|j&1|d[14108487]<<9|d[14108484]<<1)^1)&(a[7201808]|0?4194303:0))|0]|0;i=e;return n|0};case 8082:{n=a[9551018]|0;i=e;return n|0};default:{do{if((j&61440|0)==0){if((c[2385188]&1|0)==0){break}n=a[(c[2387290]|0)+(j&4095)|0]|0;i=e;return n|0}}while(0);do{if((j&57344|0)==8192){if((c[2385188]&2|0)==0){break}n=a[(c[2386534]|0)+((b^1)&8191)|0]|0;i=e;return n|0}}while(0);if((j&49152|0)!=0){n=0;i=e;return n|0}if((c[3541230]|0)==0){n=a[(c[3529062]|0)+(j&16383)|0]|0;i=e;return n|0}c[f>>2]=0;b=j>>>5&255;c[g>>2]=b;m=d[9730680]|0;c[h>>2]=m;k=m>>>2&3;if((c[2429638]|0)==0){gB[c[2437692]&127](0,((a[9718936+k|0]|a[9720736+k|0])&255)>>>2,g,h,f,f);o=c[g>>2]|0}else{f=m<<8|b;c[g>>2]=f;o=f}n=a[(c[3529060]|0)+((o<<5|j&31)&c[2438700])|0]|0;i=e;return n|0}}return 0}function beB(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=b&65535;if((e|0)==63488){c[2113304]=d&255;return}else if((e|0)==65024){f=d&7;if(f>>>0<2){return}a[(c[2394770]|0)+1|0]=f&255;g=c[2386016]|0;h=c[9757320+(c[1836236]<<2)>>2]|0;i=(f<<14)-32768|0;f=128;j=128;while(1){c[h+76+(j<<2)>>2]=g+(i+(j<<8));k=f+1&65535;if((k&65535)>191){l=128;m=128;break}else{f=k;j=k&65535}}while(1){j=g+(i+(m<<8))|0;c[h+76+(m+512<<2)>>2]=j;c[h+76+(m+768<<2)>>2]=j;j=l+1&65535;if((j&65535)>191){break}else{l=j;m=j&65535}}return}else if((e|0)==63489){m=c[2113304]|0;a[14168504+m|0]=d;mv(0,m,d&255);return}else if((e|0)==64e3){if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){m=gfc(100)|0;n=m;o=(c[2433530]|0)+m|0}else{n=100;o=(c[2433530]|0)+100|0}c[2433530]=o;c[2443998]=(c[2443998]|0)+n;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12;return}else{if((b+1024&65535)>=48){return}TO(e&255,d);return}}function beC(b){b=b|0;var d=0,e=0,f=0,g=0;d=b&65535;if((d|0)==63489){e=c[(c[3531464]|0)+4240>>2]&255;return e|0}else if((d|0)==63488){e=-1;return e|0}else{if((b+1024&65535)>=48){e=0;return e|0}if((d&63|0)==1){a[9706117]=0}b=d&255;c[2426862]=9674384;if((b|0)==46){f=62061}else if((b|0)==41){e=(c[2418664]<<1|c[2418653]|c[2418675]<<2|c[2418686]<<3)&255;return e|0}do{if((f|0)==62061){if((c[2418596]&1|0)==0){break}d=c[2418655]|0;g=(d>>>16)+(c[2418650]|0)+(c[2418651]<<16)|0;c[2418655]=d+65536;if(g>>>0>(c[2418646]|0)>>>0){e=0;return e|0}e=a[(c[2418645]|0)+g|0]|0;return e|0}}while(0);e=c[9674388+(b<<2)>>2]&255;return e|0}return 0}function beD(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2273676+(b*112|0)>>2];c[a+104>>2]=c[2273680+(b*112|0)>>2];c[a+108>>2]=c[2273684+(b*112|0)>>2];d=0;return d|0}function beE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=2273576+(b*112|0);e=0;return e|0}function beF(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>33){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1194872+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function beG(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0;e=i;i=i+1560|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;B=e+1200|0;C=e+1312|0;D=e+1320|0;E=e+1432|0;F=e+1440|0;G=e+1552|0;c[2415112]=0;c[2387386]=0;c[2386016]=589824;c[3530956]=720896;c[2439918]=1769472;c[3530722]=3866624;c[2439882]=8060928;c[2386700]=16449536;c[2407014]=18546688;c[3530198]=18554880;c[2414820]=18563072;c[2386168]=18563072;c[2387410]=18565120;c[2387290]=18573312;c[2386534]=18577408;c[2394770]=18585600;c[2411880]=18585602;H=0;while(1){if((H|0)>=1024){break}I=9638528+(H<<2)|0;if((c[I>>2]|0)==0){J=62095;break}else{H=H+1|0}}do{if((J|0)==62095){H=gGq(18585602)|0;c[I>>2]=H;if((H|0)==0){break}c[2415112]=H;gGz(H|0,0,18585602);c[2387386]=H;c[2386016]=H+589824;c[3530956]=H+720896;c[2439918]=H+1769472;c[3530722]=H+3866624;c[2439882]=H+8060928;c[2386700]=H+16449536;c[2407014]=H+18546688;c[3530198]=H+18554880;K=H+18563072|0;c[2414820]=K;c[2386168]=K;c[2387410]=H+18565120;c[2387290]=H+18573312;c[2386534]=H+18577408;c[2394770]=H+18585600;K=H+18585602|0;c[2411880]=K;c[2414430]=K;K=H+65536|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}H=F+108|0;c[H>>2]=0;M=F+100|0;c[M>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](F,0)|0;do{if((c[H>>2]|0)!=0){N=c[M>>2]|0;c[G>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](G,0,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(K,0,0)|0)==0){break}else{L=1}i=e;return L|0}}while(0);K=(c[2387386]|0)+196608|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}M=D+108|0;c[M>>2]=0;H=D+100|0;c[H>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](D,1)|0;do{if((c[M>>2]|0)!=0){N=c[H>>2]|0;c[E>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](E,1,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(K,0,1)|0)==0){break}else{L=1}i=e;return L|0}}while(0);K=(c[2387386]|0)+327680|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}H=B+108|0;c[H>>2]=0;M=B+100|0;c[M>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](B,2)|0;do{if((c[H>>2]|0)!=0){N=c[M>>2]|0;c[C>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](C,2,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(K,0,2)|0)==0){break}else{L=1}i=e;return L|0}}while(0);K=(c[2387386]|0)+458752|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}M=z+108|0;c[M>>2]=0;H=z+100|0;c[H>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](z,3)|0;do{if((c[M>>2]|0)!=0){N=c[H>>2]|0;c[A>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](A,3,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(K,0,3)|0)==0){break}else{L=1}i=e;return L|0}}while(0);K=c[2387386]|0;H=K+32768|0;M=K+557056|0;gGC(H|0,M|0,32768)|0;M=c[2386016]|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}H=x+108|0;c[H>>2]=0;K=x+100|0;c[K>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](x,4)|0;do{if((c[H>>2]|0)!=0){N=c[K>>2]|0;c[y>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](y,4,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(M,0,4)|0)==0){break}else{L=1}i=e;return L|0}}while(0);M=c[3530956]|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}K=v+108|0;c[K>>2]=0;H=v+100|0;c[H>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](v,5)|0;do{if((c[K>>2]|0)!=0){N=c[H>>2]|0;c[w>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](w,5,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(M,0,5)|0)==0){break}else{L=1}i=e;return L|0}}while(0);M=(c[3530956]|0)+524288|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}H=t+108|0;c[H>>2]=0;K=t+100|0;c[K>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](t,6)|0;do{if((c[H>>2]|0)!=0){N=c[K>>2]|0;c[u>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](u,6,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(M,0,6)|0)==0){break}else{L=1}i=e;return L|0}}while(0);M=c[3530722]|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}K=r+108|0;c[K>>2]=0;H=r+100|0;c[H>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](r,7)|0;do{if((c[K>>2]|0)!=0){N=c[H>>2]|0;c[s>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](s,7,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(M,0,7)|0)==0){break}else{L=1}i=e;return L|0}}while(0);M=(c[3530722]|0)+1048576|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}H=p+108|0;c[H>>2]=0;K=p+100|0;c[K>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](p,8)|0;do{if((c[H>>2]|0)!=0){N=c[K>>2]|0;c[q>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](q,8,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(M,0,8)|0)==0){break}else{L=1}i=e;return L|0}}while(0);M=(c[3530722]|0)+2097152|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}K=n+108|0;c[K>>2]=0;H=n+100|0;c[H>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](n,9)|0;do{if((c[K>>2]|0)!=0){N=c[H>>2]|0;c[o>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](o,9,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(M,0,9)|0)==0){break}else{L=1}i=e;return L|0}}while(0);M=(c[3530722]|0)+3145728|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}H=l+108|0;c[H>>2]=0;K=l+100|0;c[K>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](l,10)|0;do{if((c[H>>2]|0)!=0){N=c[K>>2]|0;c[m>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](m,10,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(M,0,10)|0)==0){break}else{L=1}i=e;return L|0}}while(0);M=c[2386700]|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}K=j+108|0;c[K>>2]=0;H=j+100|0;c[H>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](j,11)|0;do{if((c[K>>2]|0)!=0){N=c[H>>2]|0;c[k>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](k,11,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(M,0,11)|0)==0){break}else{L=1}i=e;return L|0}}while(0);M=(c[2386700]|0)+1048576|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}H=f+108|0;c[H>>2]=0;K=f+100|0;c[K>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](f,12)|0;do{if((c[H>>2]|0)!=0){N=c[K>>2]|0;c[g>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](g,12,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(M,0,12)|0)==0){break}else{L=1}i=e;return L|0}}while(0);M=c[3530956]|0;blG(M,524288);K=c[3530722]|0;H=K;blG(H,2097152);blG(H,2097152);H=c[2439918]|0;N=0;do{O=N<<6;gGz(H+O|0,0,64);P=N<<8;Q=0;do{R=1<<3-Q;S=(c[611632+(Q<<2)>>2]|0)+P|0;T=0;do{U=S+(c[1183816+(T<<2)>>2]|0)|0;V=(T<<3)+O|0;W=0;do{X=U+(c[614800+(W<<2)>>2]|0)|0;if(((d[M+((X|0)/8|0)|0]|0)&128>>>((X&7)>>>0)|0)!=0){X=H+(V+W)|0;a[X]=(d[X]|0|R)&255}W=W+1|0;}while((W|0)<8);T=T+1|0;}while((T|0)<8);Q=Q+1|0;}while((Q|0)<4);N=N+1|0;}while((N|0)<32768);N=c[2439882]|0;H=0;do{M=a[K+(H^1)|0]|0;Q=H<<1;a[N+Q|0]=(M&255)>>>4;a[N+(Q|1)|0]=M&15;H=H+1|0;}while((H|0)<4194304);c[2410674]=1748;gGz(9699632,0,3072);H=c[2427044]|0;c[9681616+(H<<3)>>2]=715288;c[9681620+(H<<3)>>2]=0;c[2427044]=H+1;c[363094]=0;H=c[2387410]|0;N=0;K=0;while(1){M=K+64|0;Q=H+(K<<8)|0;c[9699632+(M<<2)>>2]=Q;c[9700656+(M<<2)>>2]=Q;c[9701680+(M<<2)>>2]=Q;Q=N+1&65535;if((Q&65535)<32){N=Q;K=Q&65535}else{break}}K=c[2387386]|0;N=0;H=0;while(1){Q=H+96|0;M=K+((H<<8)+65536)|0;c[9699632+(Q<<2)>>2]=M;c[9701680+(Q<<2)>>2]=M;M=N+1&65535;if((M&65535)<32){N=M;H=M&65535}else{Y=0;Z=0;break}}while(1){H=Z+128|0;N=K+((Z<<8)+32768)|0;c[9699632+(H<<2)>>2]=N;c[9701680+(H<<2)>>2]=N;N=Y+1&65535;if((N&65535)<128){Y=N;Z=N&65535}else{break}}c[2444172]=2506;c[3528598]=2696;c[2410675]=940;c[363094]=-1;fwR(0);K=c[2439330]|0;N=(K|0)==0;if(!N){H=K;gGC(9706056,H|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];H=c[3528484]|0;c[2076596]=H;M=c[2417276]|0;c[3541536]=M;c[1836236]=0;Q=c[2386016]|0;O=0;P=0;while(1){c[K+76+(P<<2)>>2]=Q+(P<<8);T=O+1&65535;if((T&65535)>127){_=0;$=0;break}else{O=T;P=T&65535}}while(1){P=Q+($<<8)|0;c[K+76+($+512<<2)>>2]=P;c[K+76+($+768<<2)>>2]=P;P=_+1&65535;if((P&65535)>127){aa=128;ab=128;break}else{_=P;$=P&65535}}while(1){c[K+76+(ab<<2)>>2]=Q+(ab<<8);P=aa+1&65535;if((P&65535)>191){ac=128;ad=128;break}else{aa=P;ab=P&65535}}while(1){P=Q+(ad<<8)|0;c[K+76+(ad+512<<2)>>2]=P;c[K+76+(ad+768<<2)>>2]=P;P=ac+1&65535;if((P&65535)>191){break}else{ac=P;ad=P&65535}}Q=c[2386168]|0;c[K+1036>>2]=Q;P=Q+256|0;c[K+1040>>2]=P;O=Q+512|0;c[K+1044>>2]=O;T=Q+768|0;c[K+1048>>2]=T;R=Q+1024|0;c[K+1052>>2]=R;S=Q+1280|0;c[K+1056>>2]=S;W=Q+1536|0;c[K+1060>>2]=W;V=Q+1792|0;c[K+1064>>2]=V;c[K+2060>>2]=Q;c[K+2064>>2]=P;c[K+2068>>2]=O;c[K+2072>>2]=T;c[K+2076>>2]=R;c[K+2080>>2]=S;c[K+2084>>2]=W;c[K+2088>>2]=V;c[K+3084>>2]=Q;c[K+4108>>2]=Q;c[K+3088>>2]=P;c[K+4112>>2]=P;c[K+3092>>2]=O;c[K+4116>>2]=O;c[K+3096>>2]=T;c[K+4120>>2]=T;c[K+3100>>2]=R;c[K+4124>>2]=R;c[K+3104>>2]=S;c[K+4128>>2]=S;c[K+3108>>2]=W;c[K+4132>>2]=W;c[K+3112>>2]=V;c[K+4136>>2]=V;c[K+4184>>2]=212;c[K+4180>>2]=276;if(!N){V=K;gGC(V|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=H;c[2417276]=M;c[1836236]=-1;Tq(704824);V=c[3530956]|0;W=0;while(1){if((W|0)>=1024){ae=0;break}af=9638528+(W<<2)|0;if((c[af>>2]|0)==0){J=62178;break}else{W=W+1|0}}do{if((J|0)==62178){W=gGq(24576)|0;c[af>>2]=W;if((W|0)==0){ae=0;break}gGz(W|0,0,24576);ae=W}}while(0);c[3529062]=ae;c[2438700]=1048575;c[3529060]=V;a[7461784]=1;W=9726816;c[W>>2]=0;c[W+4>>2]=0;W=9726800;c[W>>2]=0;c[W+4>>2]=0;c[2429638]=0;c[2437692]=14;c[2431704]=8;c[2431700]=0;c[2431705]=8;c[2431701]=0;c[2431706]=8;c[2431702]=0;bhh(c[3530722]|0,76,3);c[3529042]=-59;c[3529040]=39;W=a[9680]|0;M=W?32e3:0;if(W){if(a[9624]|0){W=M*3|0;H=55930;while(1){if((H|0)>(W|0)){H=H>>1}else{ah=1222;ai=H;break}}}else{ah=2462;ai=M}c[2429380]=ai;c[3542124]=ah;mw(3579545,ai);H=gGq(262144)|0;c[2406684]=H;gGz(H|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(3579545,11025)}h[745421]=1.0;c[2436794]=3;h[745420]=0.0;c[2436792]=3;TN(c[2386700]|0,1310720);h[1209346]=.75;c[2418696]=1;c[2426862]=9674384;h[1209347]=.75;c[2418697]=2;H=c[642608+(c[2436]<<2)>>2]|0;W=c[H+128>>2]|0;if((c[H+52>>2]&4|0)==0){c[2113068]=W;V=c[H+132>>2]|0;c[2113070]=V;c[2443814]=W;c[2440436]=V;aj=W;ak=V}else{c[2113070]=W;V=c[H+132>>2]|0;c[2113068]=V;c[2440436]=W;c[2443814]=V;aj=V;ak=W}W=ag(aj<<1,ak)|0;V=gGq(W)|0;c[2112926]=V;if((V|0)!=0){gGz(V|0,0,W|0)}a[9625064]=0;W=c[2414820]|0;gGz(W|0,0,(c[2411880]|0)-W|0);c[363094]=0;c[2410673]=0;a[9642688]=0;a[9642689]=0;a[9642682]=0;a[9642683]=0;c[2410665]=0;a[9642680]=a[9642680]|80;W=c[2425163]|0;do{if((W|0)==0){V=c[3528598]|0;if((V|0)==0){al=0;am=0;break}H=gj[V&4095](-2)|0;V=c[2425163]|0;K=(H&255)<<8;if((V|0)!=0){an=V;ao=K;J=62195;break}V=c[3528598]|0;if((V|0)==0){al=0;am=K;break}al=gj[V&4095](-1)|0;am=K}else{an=W;ao=(d[W+254|0]|0)<<8;J=62195}}while(0);if((J|0)==62195){al=a[an+255|0]|0;am=ao}c[2410662]=al&255|am;c[363094]=-1;W=c[2439330]|0;M=(W|0)==0;if(!M){K=W;gGC(9706056,K|0,76)|0}K=c[2438118]|0;c[2433530]=K;V=c[3528484]|0;c[2076596]=V;H=c[2417276]|0;c[3541536]=H;c[1836236]=0;gGz(9706056,0,76);if(!M){M=W;gGC(M|0,9706056,76)|0}c[2438118]=K;c[3528484]=V;c[2417276]=H;c[1836236]=-1;mx(0);blH();c[2426862]=9674384;gGz(9674592,0,176);c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];c[2385188]=0;c[2430486]=a[1040128]|0?0:10;c[2427088]=0;c[3529046]=0;L=0;i=e;return L|0}}while(0);c[2415112]=0;L=1;i=e;return L|0}function beH(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;i=i+128|0;c[2113070]=0;c[2113068]=0;d=c[2112926]|0;if((d|0)!=0){gGr(d);c[2112926]=0}blI();c[2444172]=0;c[3528598]=0;fwZ();d=b|0;e=c[c[642608+(c[2436]<<2)>>2]>>2]|0;be(d|0,128,179600,(f=i,i=i+24|0,c[f>>2]=9374064,c[f+8>>2]=47,c[f+16>>2]=e,f)|0)|0;i=f;a[1040128]=0;f=c[2420380]|0;e=c[f>>2]|0;g=c[f+4>>2]|0;f=fw(d|0,389440)|0;if((f|0)!=0){d=g>>3<<e&1023;cj(14100392,d|0,1,f|0)|0;aY(f|0)|0}f=c[3531464]|0;c[f+44344>>2]=0;c[f+44348>>2]=0;if((f|0)!=0){gGr(f);c[3531464]=0}f=c[2406684]|0;if((f|0)!=0){gGr(f);c[2406684]=0}c[2426862]=9674384;f=c[2418647]|0;if((f|0)!=0){gGr(f);c[(c[2426862]|0)+204>>2]=0}c[2426862]=9674792;f=c[2418749]|0;if((f|0)!=0){gGr(f);c[(c[2426862]|0)+204>>2]=0}c[2443782]=0;f=c[2415112]|0;d=0;while(1){if((d|0)>=1024){h=62263;break}j=9638528+(d<<2)|0;if((c[j>>2]|0)==(f|0)){break}else{d=d+1|0}}if((h|0)==62263){c[2415112]=0;i=b;return 0}gGr(f);c[j>>2]=0;c[2415112]=0;i=b;return 0}function beI(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;if((a[9625064]|0)!=0){a[9625064]=0;f=c[2414820]|0;gGz(f|0,0,(c[2411880]|0)-f|0);c[363094]=0;c[2410673]=0;a[9642688]=0;a[9642689]=0;a[9642682]=0;a[9642683]=0;c[2410665]=0;a[9642680]=a[9642680]|80;f=c[2425163]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=0;break}j=gj[g&4095](-2)|0;g=c[2425163]|0;k=(j&255)<<8;if((g|0)!=0){l=g;m=k;n=62269;break}g=c[3528598]|0;if((g|0)==0){h=0;i=k;break}h=gj[g&4095](-1)|0;i=k}else{l=f;m=d[f+254|0]<<8;n=62269}}while(0);if((n|0)==62269){h=a[l+255|0]|0;i=m}c[2410662]=h&255|i;c[363094]=-1;i=c[2439330]|0;h=(i|0)==0;if(!h){m=i;gGC(9706056,m|0,76)|0}m=c[2438118]|0;c[2433530]=m;l=c[3528484]|0;c[2076596]=l;n=c[2417276]|0;c[3541536]=n;c[1836236]=0;gGz(9706056,0,76);if(!h){h=i;gGC(h|0,9706056,76)|0}c[2438118]=m;c[3528484]=l;c[2417276]=n;c[1836236]=-1;mx(0);blH();c[2426862]=9674384;gGz(9674592,0,176);c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];c[2385188]=0;c[2430486]=a[1040128]|0?0:10;c[2427088]=0;c[3529046]=0}n=c[2385548]|0;if((n|0)>0){gGz(9752472,0,((n|0)>1?n<<2:4)|0)}c[2433530]=0;c[2410673]=0;gGz(9551016,-1|0,5);n=0;l=-1;m=-1;h=-1;i=-1;f=-1;do{l=((a[9634432+n|0]&1)<<n^l&255)&255;m=((a[9632192+n|0]&1)<<n^m&255)&255;h=((a[9630112+n|0]&1)<<n^h&255)&255;i=((a[9629112+n|0]&1)<<n^i&255)&255;f=((a[9628848+n|0]&1)<<n^f&255)&255;n=n+1|0;}while((n|0)<8);a[9551016]=l;a[9551017]=m;a[9551018]=h;a[9551019]=i;a[9551020]=f;if((l&12)==0){f=l|12;a[9551016]=f;o=f}else{o=l}if((o&3)==0){a[9551016]=o|3}if((m&12)==0){o=m|12;a[9551017]=o;p=o}else{p=m}if((p&3)==0){a[9551017]=p|3}if((h&12)==0){p=h|12;a[9551018]=p;q=p}else{q=h}if((q&3)==0){a[9551018]=q|3}if((i&12)==0){q=i|12;a[9551019]=q;r=q}else{r=i}if((r&3)==0){a[9551019]=r|3}r=a[9688]|0?534:0;c[2443998]=0;c[2444050]=0;i=c[2439330]|0;if((i|0)!=0){q=i;gGC(9706056,q|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;c[363094]=0;q=0;i=0;L80492:while(1){h=i;while(1){if((h|0)>=(r|0)){break L80492}s=h+1|0;p=fNF(((s*5e4|0|0)/534|0)-(c[2444050]|0)|0)|0;c[2444050]=(c[2444050]|0)+p;if((h|0)==1&(c[3529046]|0)!=0&(c[2427088]|0)!=0){fNE(1,1);fNF(0)|0;a[9642683]=0;fNF(0)|0}c[3529046]=a[14108485]&16;p=c[2443998]|0;m=((s*59659|0|0)/534|0)-p|0;do{if((m|0)<1){t=0;u=p}else{if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){o=gfc(m)|0;c[2433530]=(c[2433530]|0)+o;t=o;u=c[2443998]|0;break}else{c[2433530]=(c[2433530]|0)+m;t=m;u=p;break}}}while(0);c[2443998]=u+t;v=c[2112964]|0;if((v|0)==0){h=s}else{break}}h=a[9688]&1;p=v+(q<<1<<1)|0;gg[c[3542124]&4095](p,h);TM(p,h);q=h+q|0;i=s}do{if((c[3529046]|0)!=0){s=c[3529044]|0;i=c[2386534]|0;v=256;t=256;while(1){u=e[i>>1]|0;if((u&32768|0)==0|(u&255|0)==0){w=s;x=v}else{u=s;r=i;gGC(u|0,r|0,16)|0;w=s+16|0;x=v-1|0}r=t-1|0;if((r|0)==0){break}else{s=w;i=i+16|0;v=x;t=r}}if((x|0)==0){break}else{y=w;z=x}while(1){b[y>>1]=0;t=z-1|0;if((t|0)==0){break}else{y=y+16|0;z=t}}}}while(0);if((c[3541228]|0)!=0){fNE(0,1);fNF(0)|0;a[9642682]=0;fNF(0)|0}z=c[2112964]|0;do{if((z|0)!=0){y=a[9688]|0?534:0;x=y-q|0;w=z+(q<<1<<1)|0;if((y|0)==(q|0)){break}gg[c[3542124]&4095](w,x);TM(w,x)}}while(0);c[363094]=-1;q=c[1836236]|0;z=c[9757320+(q<<2)>>2]|0;if((z|0)!=0){x=z;gGC(x|0,9706056,76)|0}c[9752472+(q<<2)>>2]=c[2433530];c[14113936+(q<<2)>>2]=c[2076596];c[9669104+(q<<2)>>2]=c[3541536];c[1836236]=-1;if((c[2112968]|0)==0){return 0}beJ()|0;return 0}function beJ(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;if((a[9548056]|0)!=0){e=c[2387290]|0;f=c[3530198]|0;g=c[2407014]|0;h=0;do{i=ga(b[e+(h<<1)>>1]|0)|0;j=i&255;k=((j&255)>>>2&7|j<<3)&255;j=((i&65535)>>>5<<3&255|(i&65535)>>>7&7)&255;l=((i&65535)>>>10<<3&255|(i&65535)>>>12&7)&255;c[f+(h<<2)>>2]=j<<3&2016|l>>>3|k<<8&63488;c[g+(h<<2)>>2]=j<<8|l|k<<16;h=h+1|0;}while((h|0)<2048)}bpj();h=c[2437682]|0;c[2442910]=h;c[2432780]=c[2437683];c[2433660]=c[2437684];c[2433661]=c[2437685];c[2433662]=c[2437686];g=a[14116146]|0;f=g&255;c[2394822]=f;e=a[14116147]|0;k=e&255;c[2394820]=k;l=d[14116148]|0;c[2394818]=l;if((g&255)<(e&255)){c[2394822]=k;c[2394820]=f;m=k;n=1;o=0;p=f}else{m=f;n=0;o=1;p=k}if(m>>>0<l>>>0){c[2394822]=l;c[2394818]=m;q=m;r=2;s=n}else{q=l;r=n;s=2}if((p|0)<(q|0)){c[2394820]=q;c[2394818]=p;t=s;u=o}else{t=o;u=s}s=ag(c[2113070]|0,c[2113068]|0)|0;if((s|0)>0){o=c[2112926]|0;p=0;do{b[o+(p<<1)>>1]=h<<4&65535;p=p+1|0;}while((p|0)<(s|0))}bhi(c[2439882]|0,3);bpk(r,0,c[2439918]|0);bhi(c[2439882]|0,2);bpk(t,0,c[2439918]|0);bhi(c[2439882]|0,1);bpk(u,0,c[2439918]|0);bhi(c[2439882]|0,0);blK(c[2407014]|0,c[3530198]|0);return 0}function beK(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;g=i;i=i+160|0;h=g|0;j=g+16|0;k=g+32|0;l=g+48|0;m=g+64|0;n=g+80|0;o=g+96|0;p=g+112|0;q=g+128|0;r=g+144|0;if((f|0)!=0){c[f>>2]=169733}if((e&96|0)!=0){gGz(r|0,0,12);s=c[2414820]|0;c[r>>2]=s;c[r+4>>2]=(c[2411880]|0)-s;c[r+12>>2]=162152;s=c[2076592]|0;gj[s&4095](r)|0;r=c[2410674]|0;s=c[2410675]|0;do{if((e&64|0)==0){c[2410674]=r;c[2410675]=s;fw$(e)}else{gGz(m|0,0,12);c[m>>2]=9642648;c[m+4>>2]=56;c[m+12>>2]=163840;t=c[2076592]|0;gj[t&4095](m)|0;gGz(l|0,0,12);c[l>>2]=9707480;c[l+4>>2]=2;c[l+12>>2]=501096;t=c[2076592]|0;gj[t&4095](l)|0;gGz(k|0,0,12);c[k>>2]=9707480;c[k+4>>2]=4;c[k+12>>2]=385184;t=c[2076592]|0;gj[t&4095](k)|0;c[2410674]=r;c[2410675]=s;fw$(e);gGz(j|0,0,12);c[j>>2]=8453216;c[j+4>>2]=4;c[j+12>>2]=107480;t=c[2076592]|0;gj[t&4095](j)|0;gGz(h|0,0,12);c[h>>2]=14168504;c[h+4>>2]=256;c[h+12>>2]=476464;t=c[2076592]|0;gj[t&4095](h)|0;if((e&2|0)==0){break}else{u=0}do{mv(0,u,d[14168504+u|0]|0);u=u+1|0;}while((u|0)<256)}}while(0);TP(e);blJ(e);Ts(e,f);gGz(q|0,0,12);c[q>>2]=9540752;c[q+4>>2]=4;c[q+12>>2]=587384;f=c[2076592]|0;gj[f&4095](q)|0;gGz(p|0,0,12);c[p>>2]=9721944;c[p+4>>2]=4;c[p+12>>2]=135288;q=c[2076592]|0;gj[q&4095](p)|0;gGz(o|0,0,12);c[o>>2]=9708352;c[o+4>>2]=4;c[o+12>>2]=188264;p=c[2076592]|0;gj[p&4095](o)|0;gGz(n|0,0,12);c[n>>2]=14116184;c[n+4>>2]=4;c[n+12>>2]=182752;o=c[2076592]|0;gj[o&4095](n)|0}if((e&2|0)==0){i=g;return 0}c[363094]=0;e=c[2394770]|0;n=c[2387386]|0;o=((d[e]|0)<<13&516096)+65536|0;p=0;q=0;while(1){f=q+96|0;u=n+(o+(q<<8))|0;c[9699632+(f<<2)>>2]=u;c[9701680+(f<<2)>>2]=u;u=p+1&65535;if((u&65535)<32){p=u;q=u&65535}else{break}}c[363094]=-1;q=c[2439330]|0;p=(q|0)==0;if(!p){o=q;gGC(9706056,o|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];o=c[3528484]|0;c[2076596]=o;n=c[2417276]|0;c[3541536]=n;c[1836236]=0;u=e+1|0;e=a[u]&7;if(e>>>0>=2){a[u]=e&255;u=c[2386016]|0;f=(e<<14)-32768|0;e=128;h=128;while(1){c[q+76+(h<<2)>>2]=u+(f+(h<<8));j=e+1&65535;if((j&65535)>191){v=128;w=128;break}else{e=j;h=j&65535}}while(1){h=u+(f+(w<<8))|0;c[q+76+(w+512<<2)>>2]=h;c[q+76+(w+768<<2)>>2]=h;h=v+1&65535;if((h&65535)>191){break}else{v=h;w=h&65535}}}if(!p){p=q;gGC(p|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=o;c[2417276]=n;c[1836236]=-1;i=g;return 0}function beL(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[830428+(b*112|0)>>2];c[a+104>>2]=c[830432+(b*112|0)>>2];c[a+108>>2]=c[830436+(b*112|0)>>2];d=0;return d|0}function beM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=830328+(b*112|0);e=0;return e|0}function beN(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1007268+(b*112|0)>>2];c[a+104>>2]=c[1007272+(b*112|0)>>2];c[a+108>>2]=c[1007276+(b*112|0)>>2];d=0;return d|0}function beO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=1007168+(b*112|0);e=0;return e|0}function beP(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=808208+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function beQ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[835132+(b*112|0)>>2];c[a+104>>2]=c[835136+(b*112|0)>>2];c[a+108>>2]=c[835140+(b*112|0)>>2];d=0;return d|0}function beR(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=835032+(b*112|0);e=0;return e|0}function beS(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[833564+(b*112|0)>>2];c[a+104>>2]=c[833568+(b*112|0)>>2];c[a+108>>2]=c[833572+(b*112|0)>>2];d=0;return d|0}function beT(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=833464+(b*112|0);e=0;return e|0}function beU(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[831996+(b*112|0)>>2];c[a+104>>2]=c[832e3+(b*112|0)>>2];c[a+108>>2]=c[832004+(b*112|0)>>2];d=0;return d|0}function beV(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=831896+(b*112|0);e=0;return e|0}function beW(b){b=b|0;var d=0,e=0,f=0,g=0,h=0;a[c[2394770]|0]=b&255;d=c[2387386]|0;e=(b<<13&516096)+65536|0;b=0;f=0;while(1){g=f+96|0;h=d+(e+(f<<8))|0;c[9699632+(g<<2)>>2]=h;c[9701680+(g<<2)>>2]=h;h=b+1&65535;if((h&65535)<32){b=h;f=h&65535}else{break}}return}function beX(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;c[d>>2]=c[d>>2]|b<<14|c[e>>2]<<8&16128;c[e>>2]=((c[e>>2]|0)>>>6&3)+(c[9734640+(a<<2)>>2]|0);c[d>>2]=c[d>>2]&32767;return}function beY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;e=(c[b>>2]|0)>>>6&62;do{if((e|0)>(c[2394818]|0)){if((e|0)<=(c[2394820]|0)){c[d>>2]=1;break}if((e|0)>(c[2394822]|0)){c[d>>2]=3;break}else{c[d>>2]=2;break}}else{c[d>>2]=0}}while(0);c[b>>2]=(c[b>>2]&31)+(c[2432780]|0);c[a>>2]=c[a>>2]&32767;return}function beZ(b,d){b=b|0;d=d|0;var e=0,f=0;e=b&65535;switch(e|0){case 8064:{a[c[2443950]|0]=d;if((d&1)==0){b=c[2387288]|0;c[2424996]=b;c[2425252]=b;c[2425508]=b;f=b+256|0;c[2424997]=f;c[2425253]=f;c[2425509]=f;f=b+512|0;c[2424998]=f;c[2425254]=f;c[2425510]=f;f=b+768|0;c[2424999]=f;c[2425255]=f;c[2425511]=f;f=b+1024|0;c[2425e3]=f;c[2425256]=f;c[2425512]=f;f=b+1280|0;c[2425001]=f;c[2425257]=f;c[2425513]=f;f=b+1536|0;c[2425002]=f;c[2425258]=f;c[2425514]=f;f=b+1792|0;c[2425003]=f;c[2425259]=f;c[2425515]=f;return}else{f=c[3531094]|0;c[2424996]=f;c[2425252]=f;c[2425508]=f;b=f+256|0;c[2424997]=b;c[2425253]=b;c[2425509]=b;b=f+512|0;c[2424998]=b;c[2425254]=b;c[2425510]=b;b=f+768|0;c[2424999]=b;c[2425255]=b;c[2425511]=b;b=f+1024|0;c[2425e3]=b;c[2425256]=b;c[2425512]=b;b=f+1280|0;c[2425001]=b;c[2425257]=b;c[2425513]=b;b=f+1536|0;c[2425002]=b;c[2425258]=b;c[2425514]=b;b=f+1792|0;c[2425003]=b;c[2425259]=b;c[2425515]=b;return}break};case 8088:{c[3541230]=d&1;return};case 8076:{return};case 8068:{a[c[3528376]|0]=d;return};case 8072:{a[14125144]=-1;a[9706117]=1;return};default:{if((e&49152|0)!=0){return}blF(e&16383,d&255);return}}}function be_(b){b=b|0;var c=0,d=0;c=b&65535;L80696:do{switch(c|0){case 8080:{d=a[9551008]|0;break};case 8083:{d=a[9635722]|0;break};case 8081:{d=a[9551009]|0;break};case 8085:{d=a[9635721]|0;break};case 8084:{d=a[9635720]|0;break};case 8082:{d=a[9551010]|0;break};default:{if((c&49152|0)!=0){d=0;break L80696}d=blE(c&16383)|0}}}while(0);return d|0}function be$(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((e&65520|0)==45056){TI(0,e&15,d&255);return}if((e|0)==49152){c[2113304]=d&255;return}else if((e|0)==61440){b=d&255;c[2424878]=9681232;c[2420315]=b<<17&131072;c[2420316]=b>>>2<<17&131072;return}else if((e|0)==49153){e=c[2113304]|0;a[14168504+e|0]=d;mv(0,e,d&255);return}else{return}}function be0(b){b=b|0;var e=0,f=0,g=0,h=0;e=b&65535;if((e&65520|0)==45056){b=e&15;c[2424878]=9681232;c[2426622]=9622928;if(!((b|0)==11|(b|0)==5)){f=0;return f|0}g=(b>>>0)/6|0;b=g*6|0;h=(d[b+9681280|0]|0)<<16&65536|(d[b+9681279|0]|0)<<8|(d[b+9681278|0]|0)|c[9681260+(g<<2)>>2];c[9681244+(g<<2)>>2]=h;if(h>>>0>=(c[2405735]|0)>>>0){f=0;return f|0}c[9681268+(g<<2)>>2]=1;c[9681236+(g<<2)>>2]=0;f=0;return f|0}else{if((e|0)==40960){a[9706117]=0;f=a[c[3528376]|0]|0;return f|0}else if((e|0)==49153){f=c[(c[3531464]|0)+4240>>2]&255;return f|0}else{f=0;return f|0}}return 0}function be1(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2833100+(b*112|0)>>2];c[a+104>>2]=c[2833104+(b*112|0)>>2];c[a+108>>2]=c[2833108+(b*112|0)>>2];d=0;return d|0}function be2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=2833e3+(b*112|0);e=0;return e|0}function be3(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1243104+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function be4(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>59){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3919440+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function be5(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;e=i;i=i+960|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;c[2387384]=0;c[2386014]=196608;c[3530954]=262144;c[3530720]=786432;c[2439916]=1310720;c[2439880]=2359296;c[2386698]=3407872;c[3530196]=3670016;c[2414818]=3674112;c[3531094]=3674112;c[2387408]=3676160;c[2387288]=3682304;c[2386166]=3684352;c[3528376]=3686400;c[2443950]=3686401;c[2438172]=3686402;c[2411878]=3686404;x=gGq(3686404)|0;c[2415110]=x;if((x|0)==0){y=1;i=e;return y|0}gGz(x|0,0,3686404);c[2387384]=x;c[2386014]=x+196608;c[3530954]=x+262144;c[3530720]=x+786432;c[2439916]=x+1310720;c[2439880]=x+2359296;c[2386698]=x+3407872;c[3530196]=x+3670016;z=x+3674112|0;c[2414818]=z;c[3531094]=z;c[2387408]=x+3676160;c[2387288]=x+3682304;c[2386166]=x+3684352;c[3528376]=x+3686400;c[2443950]=x+3686401;c[2438172]=x+3686402;z=x+3686404|0;c[2411878]=z;c[2414428]=z;if((c[3542200]|0)==0){y=1;i=e;return y|0}z=v+108|0;c[z>>2]=0;A=v+100|0;c[A>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,0)|0;do{if((c[z>>2]|0)!=0){v=c[A>>2]|0;c[w>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](w,0,0)|0;if((v|0)<1){y=1;i=e;return y|0}if((gzL(x,0,0)|0)==0){break}else{y=1}i=e;return y|0}}while(0);x=(c[2387384]|0)+131072|0;if((c[3542200]|0)==0){y=1;i=e;return y|0}w=t+108|0;c[w>>2]=0;A=t+100|0;c[A>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,1)|0;do{if((c[w>>2]|0)!=0){t=c[A>>2]|0;c[u>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](u,1,0)|0;if((t|0)<1){y=1;i=e;return y|0}if((gzL(x,0,1)|0)==0){break}else{y=1}i=e;return y|0}}while(0);x=c[2387384]|0;u=x+65536|0;gGC(u|0,x|0,32768)|0;u=x+98304|0;gGC(u|0,x|0,32768)|0;x=c[2386014]|0;if((c[3542200]|0)==0){y=1;i=e;return y|0}u=r+108|0;c[u>>2]=0;A=r+100|0;c[A>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,2)|0;do{if((c[u>>2]|0)!=0){r=c[A>>2]|0;c[s>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](s,2,0)|0;if((r|0)<1){y=1;i=e;return y|0}if((gzL(x,0,2)|0)==0){break}else{y=1}i=e;return y|0}}while(0);x=c[3530954]|0;if((c[3542200]|0)==0){y=1;i=e;return y|0}s=p+108|0;c[s>>2]=0;A=p+100|0;c[A>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,3)|0;do{if((c[s>>2]|0)!=0){p=c[A>>2]|0;c[q>>2]=9534384;u=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[u&16383](q,3,0)|0;if((p|0)<1){y=1;i=e;return y|0}if((gzL(x,0,3)|0)==0){break}else{y=1}i=e;return y|0}}while(0);x=(c[3530954]|0)+262144|0;if((c[3542200]|0)==0){y=1;i=e;return y|0}q=n+108|0;c[q>>2]=0;A=n+100|0;c[A>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,4)|0;do{if((c[q>>2]|0)!=0){n=c[A>>2]|0;c[o>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](o,4,0)|0;if((n|0)<1){y=1;i=e;return y|0}if((gzL(x,0,4)|0)==0){break}else{y=1}i=e;return y|0}}while(0);x=c[3530720]|0;if((c[3542200]|0)==0){y=1;i=e;return y|0}o=l+108|0;c[o>>2]=0;A=l+100|0;c[A>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,5)|0;do{if((c[o>>2]|0)!=0){l=c[A>>2]|0;c[m>>2]=9534384;q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[q&16383](m,5,0)|0;if((l|0)<1){y=1;i=e;return y|0}if((gzL(x,0,5)|0)==0){break}else{y=1}i=e;return y|0}}while(0);x=(c[3530720]|0)+262144|0;if((c[3542200]|0)==0){y=1;i=e;return y|0}m=j+108|0;c[m>>2]=0;A=j+100|0;c[A>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,6)|0;do{if((c[m>>2]|0)!=0){j=c[A>>2]|0;c[k>>2]=9534384;o=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[o&16383](k,6,0)|0;if((j|0)<1){y=1;i=e;return y|0}if((gzL(x,0,6)|0)==0){break}else{y=1}i=e;return y|0}}while(0);x=c[2386698]|0;if((c[3542200]|0)==0){y=1;i=e;return y|0}k=f+108|0;c[k>>2]=0;A=f+100|0;c[A>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,7)|0;do{if((c[k>>2]|0)!=0){f=c[A>>2]|0;c[g>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](g,7,0)|0;if((f|0)<1){y=1;i=e;return y|0}if((gzL(x,0,7)|0)==0){break}else{y=1}i=e;return y|0}}while(0);x=c[3530954]|0;blG(x,262144);g=c[3530720]|0;blG(g,262144);A=c[2439916]|0;k=0;do{f=k<<6;gGz(A+f|0,0,64);m=k<<8;j=0;do{o=1<<3-j;l=(c[611632+(j<<2)>>2]|0)+m|0;q=0;do{n=l+(c[3946808+(q<<2)>>2]|0)|0;s=(q<<3)+f|0;p=0;do{u=n+(c[6669416+(p<<2)>>2]|0)|0;if(((d[x+((u|0)/8|0)|0]|0)&128>>>((u&7)>>>0)|0)!=0){u=A+(s+p)|0;a[u]=(d[u]|0|o)&255}p=p+1|0;}while((p|0)<8);q=q+1|0;}while((q|0)<8);j=j+1|0;}while((j|0)<4);k=k+1|0;}while((k|0)<16384);k=c[2439880]|0;A=0;do{x=A<<8;gGz(k+x|0,0,256);j=A<<10;f=0;do{m=1<<3-f;q=(c[611400+(f<<2)>>2]|0)+j|0;o=0;do{l=q+(c[3946808+(o<<2)>>2]|0)|0;p=(o<<4)+x|0;s=0;do{n=l+(c[6669416+(s<<2)>>2]|0)|0;if(((d[g+((n|0)/8|0)|0]|0)&128>>>((n&7)>>>0)|0)!=0){n=k+(p+s)|0;a[n]=(d[n]|0|m)&255}s=s+1|0;}while((s|0)<16);o=o+1|0;}while((o|0)<16);f=f+1|0;}while((f|0)<4);A=A+1|0;}while((A|0)<4096);c[2410674]=1748;gGz(9699632,0,3072);A=c[2427044]|0;c[9681616+(A<<3)>>2]=715288;c[9681620+(A<<3)>>2]=0;c[2427044]=A+1;c[363094]=0;A=c[2387408]|0;k=0;g=0;while(1){f=g+64|0;x=A+(g<<8)|0;c[9699632+(f<<2)>>2]=x;c[9700656+(f<<2)>>2]=x;c[9701680+(f<<2)>>2]=x;x=k+1&65535;if((x&65535)<24){k=x;g=x&65535}else{break}}g=c[3531094]|0;c[2424996]=g;c[2425252]=g;c[2425508]=g;k=g+256|0;c[2424997]=k;c[2425253]=k;c[2425509]=k;k=g+512|0;c[2424998]=k;c[2425254]=k;c[2425510]=k;k=g+768|0;c[2424999]=k;c[2425255]=k;c[2425511]=k;k=g+1024|0;c[2425e3]=k;c[2425256]=k;c[2425512]=k;k=g+1280|0;c[2425001]=k;c[2425257]=k;c[2425513]=k;k=g+1536|0;c[2425002]=k;c[2425258]=k;c[2425514]=k;k=g+1792|0;c[2425003]=k;c[2425259]=k;c[2425515]=k;k=c[2387384]|0;g=0;A=0;while(1){x=A+96|0;f=k+((A<<8)+65536)|0;c[9699632+(x<<2)>>2]=f;c[9701680+(x<<2)>>2]=f;f=g+1&65535;if((f&65535)<32){g=f;A=f&65535}else{C=0;D=0;break}}while(1){A=D+128|0;g=k+((D<<8)+32768)|0;c[9699632+(A<<2)>>2]=g;c[9701680+(A<<2)>>2]=g;g=C+1&65535;if((g&65535)<128){C=g;D=g&65535}else{break}}c[2444172]=1714;c[3528598]=2790;c[2410675]=1124;c[363094]=-1;fwR(0);D=c[2439330]|0;C=(D|0)==0;if(!C){k=D;gGC(9706056,k|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];k=c[3528484]|0;c[2076596]=k;g=c[2417276]|0;c[3541536]=g;c[1836236]=0;A=c[2386014]|0;f=0;x=0;while(1){c[D+76+(x<<2)>>2]=A+(x<<8);j=f+1&65535;if((j&65535)>127){E=0;F=0;break}else{f=j;x=j&65535}}while(1){x=A+(F<<8)|0;c[D+76+(F+512<<2)>>2]=x;c[D+76+(F+768<<2)>>2]=x;x=E+1&65535;if((x&65535)>127){break}else{E=x;F=x&65535}}F=c[2386166]|0;c[D+588>>2]=F;E=F+256|0;c[D+592>>2]=E;A=F+512|0;c[D+596>>2]=A;x=F+768|0;c[D+600>>2]=x;f=F+1024|0;c[D+604>>2]=f;j=F+1280|0;c[D+608>>2]=j;o=F+1536|0;c[D+612>>2]=o;m=F+1792|0;c[D+616>>2]=m;c[D+1612>>2]=F;c[D+1616>>2]=E;c[D+1620>>2]=A;c[D+1624>>2]=x;c[D+1628>>2]=f;c[D+1632>>2]=j;c[D+1636>>2]=o;c[D+1640>>2]=m;c[D+2636>>2]=F;c[D+3660>>2]=F;c[D+2640>>2]=E;c[D+3664>>2]=E;c[D+2644>>2]=A;c[D+3668>>2]=A;c[D+2648>>2]=x;c[D+3672>>2]=x;c[D+2652>>2]=f;c[D+3676>>2]=f;c[D+2656>>2]=j;c[D+3680>>2]=j;c[D+2660>>2]=o;c[D+3684>>2]=o;c[D+2664>>2]=m;c[D+3688>>2]=m;c[D+4184>>2]=548;c[D+4180>>2]=3564;if(!C){C=D;gGC(C|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=k;c[2417276]=g;c[1836236]=-1;g=a[9680]|0;k=g?32e3:0;if(g){if(a[9624]|0){g=k*3|0;C=55930;while(1){if((C|0)>(g|0)){C=C>>1}else{G=1222;H=C;break}}}else{G=2462;H=k}c[2429380]=H;c[3542124]=G;mw(3579545,H);H=gGq(262144)|0;c[2406684]=H;gGz(H|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(3579545,11025)}h[745421]=.6;c[2436794]=3;h[745420]=.6;c[2436792]=3;TJ(0,c[2386698]|0,262144);c[2424878]=9681232;c[2405736]=558;h[1202869]=.3;c[2405742]=3;c[2426622]=9622928;h[1202870]=.3;c[2405743]=3;H=c[3530954]|0;G=0;while(1){if((G|0)>=1024){I=0;break}J=9638528+(G<<2)|0;if((c[J>>2]|0)==0){K=62598;break}else{G=G+1|0}}do{if((K|0)==62598){G=gGq(24576)|0;c[J>>2]=G;if((G|0)==0){I=0;break}gGz(G|0,0,24576);I=G}}while(0);c[3529062]=I;c[2438700]=524287;c[3529060]=H;a[7461784]=1;H=9726816;c[H>>2]=0;c[H+4>>2]=0;H=9726800;c[H>>2]=0;c[H+4>>2]=0;c[2429638]=0;c[2437692]=106;c[2431704]=8;c[2431700]=0;c[2431705]=8;c[2431701]=0;c[2431706]=8;c[2431702]=0;H=c[3530720]|0;c[2438136]=0;I=0;while(1){if((I|0)>=1024){L=0;break}M=9638528+(I<<2)|0;if((c[M>>2]|0)==0){K=62603;break}else{I=I+1|0}}do{if((K|0)==62603){I=gGq(1024)|0;c[M>>2]=I;if((I|0)==0){L=0;break}gGz(I|0,0,1024);L=I}}while(0);c[3529066]=L;c[2438702]=524287;c[3529064]=H;a[7461792]=1;c[2437694]=74;c[2438136]=8;H=c[642608+(c[2436]<<2)>>2]|0;L=c[H+128>>2]|0;if((c[H+52>>2]&4|0)==0){c[2113068]=L;M=c[H+132>>2]|0;c[2113070]=M;c[2443814]=L;c[2440436]=M;N=L;O=M}else{c[2113070]=L;M=c[H+132>>2]|0;c[2113068]=M;c[2440436]=L;c[2443814]=M;N=M;O=L}L=ag(N<<1,O)|0;O=gGq(L)|0;c[2112926]=O;if((O|0)!=0){gGz(O|0,0,L|0)}a[9625056]=0;L=c[2414818]|0;gGz(L|0,0,(c[2411878]|0)-L|0);c[363094]=0;c[2410673]=0;a[9642688]=0;a[9642689]=0;a[9642682]=0;a[9642683]=0;c[2410665]=0;a[9642680]=a[9642680]|80;L=c[2425163]|0;do{if((L|0)==0){O=c[3528598]|0;if((O|0)==0){P=0;Q=0;break}N=gj[O&4095](-2)|0;O=c[2425163]|0;M=(N&255)<<8;if((O|0)!=0){R=O;S=M;K=62614;break}O=c[3528598]|0;if((O|0)==0){P=0;Q=M;break}P=gj[O&4095](-1)|0;Q=M}else{R=L;S=(d[L+254|0]|0)<<8;K=62614}}while(0);if((K|0)==62614){P=a[R+255|0]|0;Q=S}c[2410662]=P&255|Q;c[363094]=-1;Q=c[2439330]|0;P=(Q|0)==0;if(!P){S=Q;gGC(9706056,S|0,76)|0}S=c[2438118]|0;c[2433530]=S;R=c[3528484]|0;c[2076596]=R;K=c[2417276]|0;c[3541536]=K;c[1836236]=0;gGz(9706056,0,76);if(!P){P=Q;gGC(P|0,9706056,76)|0}c[2438118]=S;c[3528484]=R;c[2417276]=K;c[1836236]=-1;mx(0);blH();y=0;i=e;return y|0}function be6(){var a=0,b=0,d=0,e=0;c[2113070]=0;c[2113068]=0;a=c[2112926]|0;if((a|0)!=0){gGr(a);c[2112926]=0}blI();c[2444172]=0;c[3528598]=0;fwZ();a=c[2424800]|0;if((a|0)!=0){gGr(a);c[2424800]=0}a=c[2418166]|0;if((a|0)!=0){gGr(a);c[2418166]=0}a=c[3531464]|0;c[a+44344>>2]=0;c[a+44348>>2]=0;if((a|0)!=0){gGr(a);c[3531464]=0}a=c[2406684]|0;if((a|0)!=0){gGr(a);c[2406684]=0}a=c[2415110]|0;b=0;while(1){if((b|0)>=1024){d=62664;break}e=9638528+(b<<2)|0;if((c[e>>2]|0)==(a|0)){break}else{b=b+1|0}}if((d|0)==62664){c[2415110]=0;return 0}gGr(a);c[e>>2]=0;c[2415110]=0;return 0}function be7(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((a[9625056]|0)!=0){a[9625056]=0;e=c[2414818]|0;gGz(e|0,0,(c[2411878]|0)-e|0);c[363094]=0;c[2410673]=0;a[9642688]=0;a[9642689]=0;a[9642682]=0;a[9642683]=0;c[2410665]=0;a[9642680]=a[9642680]|80;e=c[2425163]|0;do{if((e|0)==0){f=c[3528598]|0;if((f|0)==0){g=0;h=0;break}i=gj[f&4095](-2)|0;f=c[2425163]|0;j=(i&255)<<8;if((f|0)!=0){k=f;l=j;m=62671;break}f=c[3528598]|0;if((f|0)==0){g=0;h=j;break}g=gj[f&4095](-1)|0;h=j}else{k=e;l=d[e+254|0]<<8;m=62671}}while(0);if((m|0)==62671){g=a[k+255|0]|0;h=l}c[2410662]=g&255|h;c[363094]=-1;h=c[2439330]|0;g=(h|0)==0;if(!g){l=h;gGC(9706056,l|0,76)|0}l=c[2438118]|0;c[2433530]=l;k=c[3528484]|0;c[2076596]=k;m=c[2417276]|0;c[3541536]=m;c[1836236]=0;gGz(9706056,0,76);if(!g){g=h;gGC(g|0,9706056,76)|0}c[2438118]=l;c[3528484]=k;c[2417276]=m;c[1836236]=-1;mx(0);blH()}gGz(9551008,-1|0,3);m=0;k=-1;l=-1;g=-1;do{k=((a[9634424+m|0]&1)<<m^k&255)&255;l=((a[9632184+m|0]&1)<<m^l&255)&255;g=((a[9630104+m|0]&1)<<m^g&255)&255;m=m+1|0;}while((m|0)<8);a[9551008]=k;a[9551009]=l;a[9551010]=g;if((l&3)==0){k=l|3;a[9551009]=k;n=k}else{n=l}if((n&12)==0){a[9551009]=n|12}if((g&3)==0){n=g|3;a[9551010]=n;o=n}else{o=g}if((o&12)==0){a[9551010]=o|12}c[2410673]=0;o=c[2385548]|0;if((o|0)>0){gGz(9752472,0,((o|0)>1?o<<2:4)|0)}c[2433530]=0;o=a[9688]|0?534:0;g=c[2439330]|0;if((g|0)!=0){n=g;gGC(9706056,n|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;c[363094]=0;n=0;g=0;l=0;k=0;L81007:while(1){m=g;h=l;e=k;do{if((e|0)>=(o|0)){break L81007}e=e+1|0;h=(fNF((e*93|0)-h|0)|0)+h|0;j=(e*111|0)-m|0;do{if((j|0)<1){p=0}else{if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){f=gfc(j)|0;c[2433530]=(c[2433530]|0)+f;p=f;break}else{c[2433530]=(c[2433530]|0)+j;p=j;break}}}while(0);m=p+m|0;q=c[2112964]|0;}while((q|0)==0);j=a[9688]&1;f=q+(n<<1<<1)|0;gg[c[3542124]&4095](f,j);TH(0,f,j);n=j+n|0;g=m;l=h;k=e}if((c[3541228]|0)!=0){fNE(0,1);fNF(0)|0;a[9642682]=0;fNF(0)|0}k=c[2112964]|0;do{if((k|0)!=0){l=a[9688]|0?534:0;g=l-n|0;if((l|0)==(n|0)){break}l=k+(n<<1<<1)|0;gg[c[3542124]&4095](l,g);TH(0,l,g)}}while(0);c[363094]=-1;n=c[1836236]|0;k=c[9757320+(n<<2)>>2]|0;if((k|0)!=0){g=k;gGC(g|0,9706056,76)|0}c[9752472+(n<<2)>>2]=c[2433530];c[14113936+(n<<2)>>2]=c[2076596];c[9669104+(n<<2)>>2]=c[3541536];c[1836236]=-1;if((c[2112968]|0)==0){return 0}be8()|0;return 0}function be8(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;if((a[9548048]|0)!=0){d=c[3530196]|0;e=c[2387288]|0;f=0;do{g=ga(b[e+(f<<1)>>1]|0)|0;c[d+(f<<2)>>2]=((g&65535)>>>10<<3&65535)>>>3&31|((g&255)<<3&255)<<8|(((g&65535)>>>5<<3&255|(g&65535)>>>7&4)&255)<<3&2016;f=f+1|0;}while((f|0)<1024)}bpj();f=c[2439916]|0;if((a[c[2443950]|0]&8)==0){bpk(1,1,f);bpl(c[2439880]|0,2);bpk(2,0,c[2439916]|0);h=c[2439880]|0;bpl(h,1);i=c[2439916]|0;bpk(0,0,i);j=c[3530196]|0;R8(j);return 0}else{bpk(2,1,f);bpl(c[2439880]|0,2);bpk(1,0,c[2439916]|0);h=c[2439880]|0;bpl(h,1);i=c[2439916]|0;bpk(0,0,i);j=c[3530196]|0;R8(j);return 0}return 0}function be9(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;f=i;i=i+144|0;g=f|0;h=f+16|0;j=f+48|0;k=f+64|0;l=f+80|0;m=f+96|0;n=f+112|0;o=f+128|0;p=(e|0)==0;if(!p){c[e>>2]=169732}if((b&96|0)!=0){gGz(o|0,0,12);q=c[2414818]|0;c[o>>2]=q;c[o+4>>2]=(c[2411878]|0)-q;c[o+12>>2]=162152;q=c[2076592]|0;gj[q&4095](o)|0;o=c[2410674]|0;q=c[2410675]|0;if((b&64|0)==0){c[2410674]=o;c[2410675]=q;fw$(b);r=g;s=h|0}else{gGz(n|0,0,12);c[n>>2]=9642648;c[n+4>>2]=56;c[n+12>>2]=163840;t=c[2076592]|0;gj[t&4095](n)|0;gGz(m|0,0,12);c[m>>2]=9707480;c[m+4>>2]=2;c[m+12>>2]=501096;n=c[2076592]|0;gj[n&4095](m)|0;gGz(l|0,0,12);c[l>>2]=9707480;c[l+4>>2]=4;c[l+12>>2]=385184;m=c[2076592]|0;gj[m&4095](l)|0;c[2410674]=o;c[2410675]=q;fw$(b);gGz(k|0,0,12);c[k>>2]=8453216;c[k+4>>2]=4;c[k+12>>2]=107480;q=c[2076592]|0;gj[q&4095](k)|0;gGz(j|0,0,12);c[j>>2]=14168504;c[j+4>>2]=256;c[j+12>>2]=476464;k=c[2076592]|0;gj[k&4095](j)|0;if((b&2|0)==0){u=g;v=h|0}else{j=0;do{mv(0,j,d[14168504+j|0]|0);j=j+1|0;}while((j|0)<256);u=g;v=h|0}if(!p){c[e>>2]=169619}e=h|0;cC(e|0,170224,(h=i,i=i+8|0,c[h>>2]=0,h)|0)|0;i=h;c[g>>2]=9699512;c[g+4>>2]=64;c[g+8>>2]=0;c[g+12>>2]=e;e=c[2076592]|0;gj[e&4095](g)|0;r=u;s=v}blJ(b)}if((b&2|0)==0){i=f;return 0}c[363094]=0;if((a[c[2443950]|0]&1)==0){b=c[2387288]|0;c[2424996]=b;c[2425252]=b;c[2425508]=b;v=b+256|0;c[2424997]=v;c[2425253]=v;c[2425509]=v;v=b+512|0;c[2424998]=v;c[2425254]=v;c[2425510]=v;v=b+768|0;c[2424999]=v;c[2425255]=v;c[2425511]=v;v=b+1024|0;c[2425e3]=v;c[2425256]=v;c[2425512]=v;v=b+1280|0;c[2425001]=v;c[2425257]=v;c[2425513]=v;w=b;x=b+1536|0}else{b=c[3531094]|0;c[2424996]=b;c[2425252]=b;c[2425508]=b;v=b+256|0;c[2424997]=v;c[2425253]=v;c[2425509]=v;v=b+512|0;c[2424998]=v;c[2425254]=v;c[2425510]=v;v=b+768|0;c[2424999]=v;c[2425255]=v;c[2425511]=v;v=b+1024|0;c[2425e3]=v;c[2425256]=v;c[2425512]=v;v=b+1280|0;c[2425001]=v;c[2425257]=v;c[2425513]=v;w=b;x=b+1536|0}c[2425002]=x;c[2425258]=x;c[2425514]=x;x=w+1792|0;c[2425003]=x;c[2425259]=x;c[2425515]=x;x=((d[(c[2438172]|0)+1|0]|0)<<13&122880)+65536|0;w=c[2387384]|0;b=0;v=0;while(1){s=v+96|0;u=w+(x+(v<<8))|0;c[9699632+(s<<2)>>2]=u;c[9701680+(s<<2)>>2]=u;u=b+1&65535;if((u&65535)<32){b=u;v=u&65535}else{break}}c[363094]=-1;i=f;return 0}function bfa(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2834108+(b*112|0)>>2];c[a+104>>2]=c[2834112+(b*112|0)>>2];c[a+108>>2]=c[2834116+(b*112|0)>>2];d=0;return d|0}function bfb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=2834008+(b*112|0);e=0;return e|0}function bfc(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3004756+(b*112|0)>>2];c[a+104>>2]=c[3004760+(b*112|0)>>2];c[a+108>>2]=c[3004764+(b*112|0)>>2];d=0;return d|0}function bfd(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=3004656+(b*112|0);e=0;return e|0}function bfe(b){b=b|0;var d=0,e=0,f=0,g=0,h=0;d=(b<<13&122880)+65536|0;a[(c[2438172]|0)+1|0]=b&255;b=c[2387384]|0;e=0;f=0;while(1){g=f+96|0;h=b+(d+(f<<8))|0;c[9699632+(g<<2)>>2]=h;c[9701680+(g<<2)>>2]=h;h=e+1&65535;if((h&65535)<32){e=h;f=h&65535}else{break}}return}function bff(b){b=b|0;a[9681232]=((b>>4)*17|0)&255;a[9681233]=0;c[2424878]=9681232;a[9681234]=0;a[9681235]=((b&15)*17|0)&255;return}function bfg(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;g=c[e>>2]|0;c[d>>2]=g<<8&3328|g<<5&512|(c[d>>2]|b<<12)&16383;c[e>>2]=((c[e>>2]|0)>>>5&7)+(c[602544+(a<<2)>>2]|0);return}function bfh(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;c[d>>2]=(c[b>>2]|0)>>>4&3;c[b>>2]=c[b>>2]&15|32;c[a>>2]=c[a>>2]&4095;return}function bfi(b,d){b=b|0;d=d|0;var e=0;e=b&65535;switch(e|0){case 8259:{a[c[2405124]|0]=d&1;return};case 12288:{a[c[2406664]|0]=(d&255)>>>4&7;return};case 8260:{a[c[3528614]|0]=d&2;a[c[3528776]|0]=d&8;return};case 12544:{a[c[3528374]|0]=d;a[9706117]=1;return};case 13056:{return};default:{if((e&65504|0)!=8192){return}a[(c[2409010]|0)+(e&31)|0]=d;return}}}function bfj(b){b=b|0;var d=0,e=0;d=b&65535;L81126:do{switch(d|0){case 12544:{e=a[9635713]|0;break};case 13058:{e=a[9551002]|0;break};case 13059:{e=a[9635712]|0;break};case 13057:{e=a[9551001]|0;break};case 13056:{e=a[9551e3]|0;break};case 12800:{e=a[9635714]|0;break};default:{if((d&65504|0)!=8192){e=0;break L81126}e=a[(c[2409010]|0)+(d&31)|0]|0}}}while(0);return e|0}function bfk(b){b=b|0;var d=0;if(b<<16>>16!=-32768){d=0;return d|0}a[9706117]=0;d=a[c[3528374]|0]|0;return d|0}function bfl(a,b){a=a|0;b=b|0;var c=0;c=a&65535;if((c&254)>>>0>=2){return}lS(0,c&1,b);return}function bfm(b){b=b|0;var e=0,f=0,g=0.0,i=0.0,j=0;e=b&65535;if((e&254)>>>0>=2){f=0;return f|0}b=c[3541518]|0;if((e&1|0)==0){e=b+296|0;g=+h[e>>3];do{if(g!=0.0){i=+h[6675];if(g-(i+ +gC[c[2429842]&255]())<=0.0){h[e>>3]=0.0;break}f=a[b+307|0]|-128;return f|0}}while(0);f=a[b+307|0]|0;return f|0}if((d[b+304|0]|0)>=16){f=0;return f|0}b=c[2383582]|0;e=c[14168912+(b*252|0)>>2]|0;if((e|0)>15){f=0;return f|0}do{if((e|0)==14){j=c[14168896+(b*252|0)>>2]|0;if((j|0)==0){break}a[14168930+(b*252|0)|0]=gj[j&4095](0)|0}else if((e|0)==15){j=c[14168900+(b*252|0)>>2]|0;if((j|0)==0){break}a[14168931+(b*252|0)|0]=gj[j&4095](0)|0}}while(0);f=a[14168916+(b*252|0)+e|0]|0;return f|0}function bfn(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2320028+(b*112|0)>>2];c[a+104>>2]=c[2320032+(b*112|0)>>2];c[a+108>>2]=c[2320036+(b*112|0)>>2];d=0;return d|0}function bfo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=2319928+(b*112|0);e=0;return e|0}function bfp(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1201912+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function bfq(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>55){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3519728+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function bfr(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0;e=i;i=i+1320|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;B=e+1200|0;C=e+1312|0;c[2415108]=0;c[3527404]=0;c[2386012]=65536;c[3530952]=131072;c[3530718]=196608;c[3531052]=327680;c[3530194]=328960;c[2407012]=345344;c[2414816]=361728;c[2409010]=361728;c[2386532]=361760;c[2387894]=365856;c[2386276]=367904;c[2386164]=369952;c[3528374]=370976;c[2405124]=370977;c[3528614]=370978;c[3528776]=370979;c[2406664]=370980;c[2411876]=370981;D=0;while(1){if((D|0)>=1024){break}E=9638528+(D<<2)|0;if((c[E>>2]|0)==0){F=62862;break}else{D=D+1|0}}do{if((F|0)==62862){D=gGq(370981)|0;c[E>>2]=D;if((D|0)==0){break}c[2415108]=D;gGz(D|0,0,370981);c[3527404]=D;c[2386012]=D+65536;c[3530952]=D+131072;c[3530718]=D+196608;c[3531052]=D+327680;c[3530194]=D+328960;c[2407012]=D+345344;G=D+361728|0;c[2414816]=G;c[2409010]=G;c[2386532]=D+361760;c[2387894]=D+365856;c[2386276]=D+367904;c[2386164]=D+369952;c[3528374]=D+370976;c[2405124]=D+370977;c[3528614]=D+370978;c[3528776]=D+370979;c[2406664]=D+370980;G=D+370981|0;c[2411876]=G;c[2414426]=G;G=D+32768|0;if((c[3542200]|0)==0){H=1;i=e;return H|0}D=B+108|0;c[D>>2]=0;I=B+100|0;c[I>>2]=0;J=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[J&16383](B,0)|0;do{if((c[D>>2]|0)!=0){J=c[I>>2]|0;c[C>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](C,0,0)|0;if((J|0)<1){H=1;i=e;return H|0}if((gzL(G,0,0)|0)==0){break}else{H=1}i=e;return H|0}}while(0);G=c[3527404]|0;I=G+16384|0;D=G+49152|0;gGC(I|0,D|0,16384)|0;if((c[3542200]|0)==0){H=1;i=e;return H|0}I=z+108|0;c[I>>2]=0;G=z+100|0;c[G>>2]=0;J=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[J&16383](z,1)|0;do{if((c[I>>2]|0)!=0){J=c[G>>2]|0;c[A>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](A,1,0)|0;if((J|0)<1){H=1;i=e;return H|0}if((gzL(D,0,1)|0)==0){break}else{H=1}i=e;return H|0}}while(0);D=c[2386012]|0;if((c[3542200]|0)==0){H=1;i=e;return H|0}G=x+108|0;c[G>>2]=0;I=x+100|0;c[I>>2]=0;J=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[J&16383](x,2)|0;do{if((c[G>>2]|0)!=0){J=c[I>>2]|0;c[y>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](y,2,0)|0;if((J|0)<1){H=1;i=e;return H|0}if((gzL(D,0,2)|0)==0){break}else{H=1}i=e;return H|0}}while(0);D=c[3530952]|0;if((c[3542200]|0)==0){H=1;i=e;return H|0}I=v+108|0;c[I>>2]=0;G=v+100|0;c[G>>2]=0;J=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[J&16383](v,3)|0;do{if((c[I>>2]|0)!=0){J=c[G>>2]|0;c[w>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](w,3,0)|0;if((J|0)<1){H=1;i=e;return H|0}if((gzL(D,0,3)|0)==0){break}else{H=1}i=e;return H|0}}while(0);D=c[3530718]|0;if((c[3542200]|0)==0){H=1;i=e;return H|0}G=t+108|0;c[G>>2]=0;I=t+100|0;c[I>>2]=0;J=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[J&16383](t,4)|0;do{if((c[G>>2]|0)!=0){J=c[I>>2]|0;c[u>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](u,4,0)|0;if((J|0)<1){H=1;i=e;return H|0}if((gzL(D,0,4)|0)==0){break}else{H=1}i=e;return H|0}}while(0);D=(c[3530718]|0)+32768|0;if((c[3542200]|0)==0){H=1;i=e;return H|0}I=r+108|0;c[I>>2]=0;G=r+100|0;c[G>>2]=0;J=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[J&16383](r,5)|0;do{if((c[I>>2]|0)!=0){J=c[G>>2]|0;c[s>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](s,5,0)|0;if((J|0)<1){H=1;i=e;return H|0}if((gzL(D,0,5)|0)==0){break}else{H=1}i=e;return H|0}}while(0);D=c[3531052]|0;if((c[3542200]|0)==0){H=1;i=e;return H|0}G=p+108|0;c[G>>2]=0;I=p+100|0;c[I>>2]=0;J=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[J&16383](p,6)|0;do{if((c[G>>2]|0)!=0){J=c[I>>2]|0;c[q>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](q,6,0)|0;if((J|0)<1){H=1;i=e;return H|0}if((gzL(D,0,6)|0)==0){break}else{H=1}i=e;return H|0}}while(0);D=(c[3531052]|0)+256|0;if((c[3542200]|0)==0){H=1;i=e;return H|0}I=n+108|0;c[I>>2]=0;G=n+100|0;c[G>>2]=0;J=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[J&16383](n,7)|0;do{if((c[I>>2]|0)!=0){J=c[G>>2]|0;c[o>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](o,7,0)|0;if((J|0)<1){H=1;i=e;return H|0}if((gzL(D,0,7)|0)==0){break}else{H=1}i=e;return H|0}}while(0);D=(c[3531052]|0)+512|0;if((c[3542200]|0)==0){H=1;i=e;return H|0}G=l+108|0;c[G>>2]=0;I=l+100|0;c[I>>2]=0;J=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[J&16383](l,8)|0;do{if((c[G>>2]|0)!=0){J=c[I>>2]|0;c[m>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](m,8,0)|0;if((J|0)<1){H=1;i=e;return H|0}if((gzL(D,0,8)|0)==0){break}else{H=1}i=e;return H|0}}while(0);D=(c[3531052]|0)+768|0;if((c[3542200]|0)==0){H=1;i=e;return H|0}I=j+108|0;c[I>>2]=0;G=j+100|0;c[G>>2]=0;J=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[J&16383](j,9)|0;do{if((c[I>>2]|0)!=0){J=c[G>>2]|0;c[k>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](k,9,0)|0;if((J|0)<1){H=1;i=e;return H|0}if((gzL(D,0,9)|0)==0){break}else{H=1}i=e;return H|0}}while(0);D=(c[3531052]|0)+1024|0;if((c[3542200]|0)==0){H=1;i=e;return H|0}G=f+108|0;c[G>>2]=0;I=f+100|0;c[I>>2]=0;J=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[J&16383](f,10)|0;do{if((c[G>>2]|0)!=0){J=c[I>>2]|0;c[g>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](g,10,0)|0;if((J|0)<1){H=1;i=e;return H|0}if((gzL(D,0,10)|0)==0){break}else{H=1}i=e;return H|0}}while(0);D=c[3531052]|0;I=c[3530194]|0;G=0;do{J=a[D+G|0]&15;K=a[D+(G+256)|0]&15;L=a[D+(G+512)|0]&15;c[I+(G<<2)>>2]=J<<20|J<<16|K<<12|K<<8|L|L<<4;G=G+1|0;}while((G|0)<256);G=c[2407012]|0;L=0;while(1){K=L>>>1&128^128;J=L<<3&2048|L&255;M=D+(L+768)|0;N=0;do{c[G+((J|N<<8)<<2)>>2]=c[I+((N<<4|K|a[M]&15)<<2)>>2];N=N+1|0;}while((N|0)<8);N=L+1|0;if((N|0)<512){L=N}else{O=0;break}}while(1){if((O|0)>=1024){break}P=9638528+(O<<2)|0;if((c[P>>2]|0)==0){F=62916;break}else{O=O+1|0}}L81331:do{if((F|0)==62916){L=gGq(65536)|0;c[P>>2]=L;if((L|0)==0){break}gGz(L|0,0,65536);I=c[3530952]|0;gGC(L|0,I|0,32768)|0;G=0;do{D=G<<6;gGz(I+D|0,0,64);N=G<<8;M=0;do{K=1<<3-M;J=(c[703416+(M<<2)>>2]|0)+N|0;Q=0;do{R=J+(c[3946808+(Q<<2)>>2]|0)|0;S=(Q<<3)+D|0;T=0;do{U=R+(c[3946872+(T<<2)>>2]|0)|0;if(((d[L+((U|0)/8|0)|0]|0)&128>>>((U&7)>>>0)|0)!=0){U=I+(S+T)|0;a[U]=(d[U]|0|K)&255}T=T+1|0;}while((T|0)<8);Q=Q+1|0;}while((Q|0)<8);M=M+1|0;}while((M|0)<4);G=G+1|0;}while((G|0)<1024);G=c[3530718]|0;gGC(L|0,G|0,65536)|0;I=0;while(1){M=I<<8;gGz(G+M|0,0,256);D=I<<10;N=0;do{Q=1<<3-N;K=(c[703416+(N<<2)>>2]|0)+D|0;J=0;do{T=K+(c[3946808+(J<<2)>>2]|0)|0;S=(J<<4)+M|0;R=0;do{U=T+(c[3946872+(R<<2)>>2]|0)|0;if(((d[L+((U|0)/8|0)|0]|0)&128>>>((U&7)>>>0)|0)!=0){U=G+(S+R)|0;a[U]=(d[U]|0|Q)&255}R=R+1|0;}while((R|0)<16);J=J+1|0;}while((J|0)<16);N=N+1|0;}while((N|0)<4);N=I+1|0;if((N|0)<512){I=N}else{V=0;break}}while(1){if((V|0)>=1024){break L81331}W=9638528+(V<<2)|0;if((c[W>>2]|0)==(L|0)){break}else{V=V+1|0}}gGr(L);c[W>>2]=0}}while(0);c[3528554]=-1;c[2113160]=1;I=gGq(3148)|0;G=I;c[2433592]=G;if((I|0)!=0){gGz(I|0,0,3148);c[I+3120>>2]=3128;c[I+3124>>2]=1840;c[I+3128>>2]=136;c[I+3132>>2]=1902;c[2432840]=0;N=0;do{c[G+48+(N<<2)>>2]=0;N=N+1|0;}while((N|0)<768);c[2113158]=0;c[2415198]=0;N=c[2427044]|0;c[9681616+(N<<3)>>2]=809272;c[9681620+(N<<3)>>2]=0;c[2427044]=N+1}c[3528554]=0;f43(I);N=c[3528554]|0;G=9731360+(N<<2)|0;M=c[G>>2]|0;c[2113158]=M;D=c[2387894]|0;J=c[2433592]|0;c[J+(N*3148|0)+48>>2]=D;c[J+(N*3148|0)+1072>>2]=D;c[J+(N*3148|0)+2096>>2]=D;Q=D+256|0;c[J+(N*3148|0)+52>>2]=Q;c[J+(N*3148|0)+1076>>2]=Q;c[J+(N*3148|0)+2100>>2]=Q;Q=D+512|0;c[J+(N*3148|0)+56>>2]=Q;c[J+(N*3148|0)+1080>>2]=Q;c[J+(N*3148|0)+2104>>2]=Q;Q=D+768|0;c[J+(N*3148|0)+60>>2]=Q;c[J+(N*3148|0)+1084>>2]=Q;c[J+(N*3148|0)+2108>>2]=Q;Q=D+1024|0;c[J+(N*3148|0)+64>>2]=Q;c[J+(N*3148|0)+1088>>2]=Q;c[J+(N*3148|0)+2112>>2]=Q;Q=D+1280|0;c[J+(N*3148|0)+68>>2]=Q;c[J+(N*3148|0)+1092>>2]=Q;c[J+(N*3148|0)+2116>>2]=Q;Q=D+1536|0;c[J+(N*3148|0)+72>>2]=Q;c[J+(N*3148|0)+1096>>2]=Q;c[J+(N*3148|0)+2120>>2]=Q;Q=D+1792|0;c[J+(N*3148|0)+76>>2]=Q;c[J+(N*3148|0)+1100>>2]=Q;c[J+(N*3148|0)+2124>>2]=Q;Q=c[2386276]|0;c[J+(N*3148|0)+80>>2]=Q;c[J+(N*3148|0)+1104>>2]=Q;c[J+(N*3148|0)+2128>>2]=Q;D=Q+256|0;c[J+(N*3148|0)+84>>2]=D;c[J+(N*3148|0)+1108>>2]=D;c[J+(N*3148|0)+2132>>2]=D;D=Q+512|0;c[J+(N*3148|0)+88>>2]=D;c[J+(N*3148|0)+1112>>2]=D;c[J+(N*3148|0)+2136>>2]=D;D=Q+768|0;c[J+(N*3148|0)+92>>2]=D;c[J+(N*3148|0)+1116>>2]=D;c[J+(N*3148|0)+2140>>2]=D;D=Q+1024|0;c[J+(N*3148|0)+96>>2]=D;c[J+(N*3148|0)+1120>>2]=D;c[J+(N*3148|0)+2144>>2]=D;D=Q+1280|0;c[J+(N*3148|0)+100>>2]=D;c[J+(N*3148|0)+1124>>2]=D;c[J+(N*3148|0)+2148>>2]=D;D=Q+1536|0;c[J+(N*3148|0)+104>>2]=D;c[J+(N*3148|0)+1128>>2]=D;c[J+(N*3148|0)+2152>>2]=D;D=Q+1792|0;c[J+(N*3148|0)+108>>2]=D;c[J+(N*3148|0)+1132>>2]=D;c[J+(N*3148|0)+2156>>2]=D;D=c[2386532]|0;Q=16;K=16;while(1){R=D+((K<<8)-4096)|0;c[J+(N*3148|0)+48+(K<<2)>>2]=R;c[J+(N*3148|0)+48+(K+256<<2)>>2]=R;c[J+(N*3148|0)+48+(K+512<<2)>>2]=R;R=Q+1&65535;if((R&65535)>31){break}else{Q=R;K=R&65535}}K=c[3527404]|0;Q=64;D=64;while(1){I=K+(D<<8)|0;c[J+(N*3148|0)+48+(D<<2)>>2]=I;c[J+(N*3148|0)+48+(D+512<<2)>>2]=I;I=Q+1&65535;if((I&65535)>255){break}else{Q=I;D=I&65535}}c[J+(N*3148|0)+3124>>2]=2676;c[J+(N*3148|0)+3120>>2]=3272;D=J+(N*3148|0)|0;if((D|0)!=0){Q=D;gGC(Q|0,9660752,48)|0}c[G>>2]=M;c[3528554]=-1;fwR(0);Q=c[2439330]|0;D=(Q|0)==0;if(!D){K=Q;gGC(9706056,K|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];K=c[3528484]|0;c[2076596]=K;I=c[2417276]|0;c[3541536]=I;c[1836236]=0;R=c[2386012]|0;S=0;T=0;while(1){c[Q+76+(T<<2)>>2]=R+(T<<8);U=S+1&65535;if((U&65535)>63){X=0;Y=0;break}else{S=U;T=U&65535}}while(1){T=R+(Y<<8)|0;c[Q+76+(Y+512<<2)>>2]=T;c[Q+76+(Y+768<<2)>>2]=T;T=X+1&65535;if((T&65535)>63){break}else{X=T;Y=T&65535}}R=c[2386164]|0;c[Q+332>>2]=R;T=R+256|0;c[Q+336>>2]=T;S=R+512|0;c[Q+340>>2]=S;M=R+768|0;c[Q+344>>2]=M;c[Q+1356>>2]=R;c[Q+1360>>2]=T;c[Q+1364>>2]=S;c[Q+1368>>2]=M;c[Q+2380>>2]=R;c[Q+3404>>2]=R;c[Q+2384>>2]=T;c[Q+3408>>2]=T;c[Q+2388>>2]=S;c[Q+3412>>2]=S;c[Q+2392>>2]=M;c[Q+3416>>2]=M;c[Q+4180>>2]=1712;c[Q+4176>>2]=1732;c[Q+4172>>2]=1040;if(!D){M=Q;gGC(M|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=K;c[2417276]=I;c[1836236]=-1;Vr(1,3072e3,0,1716,118,0);c[2438228]=3072e3;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=665;h[745419]=.4;a[3203368]=1;h[745418]=.4;a[3203360]=1;h[745417]=.4;a[3203352]=1;h[745416]=.4;a[3203344]=1;a[9625048]=0;M=c[2414816]|0;gGz(M|0,0,(c[2411876]|0)-M|0);c[3528554]=0;f43(c[2433592]|0);M=c[3528554]|0;c[2113158]=c[9731360+(M<<2)>>2];a[9660796]=0;a[9660797]=0;a[9660786]=0;a[9660787]=0;c[2415191]=0;a[9660784]=a[9660784]|80;S=c[2433592]|0;T=c[S+(M*3148|0)+1068>>2]|0;do{if((T|0)==0){R=c[S+(M*3148|0)+3120>>2]|0;if((R|0)==0){Z=0;_=0;$=M;aa=S;break}G=gj[R&4095](-2)|0;R=c[3528554]|0;N=c[2433592]|0;J=c[N+(R*3148|0)+1068>>2]|0;U=(G&255)<<8;if((J|0)!=0){ab=J;ac=U;ad=R;ae=N;F=62961;break}J=c[N+(R*3148|0)+3120>>2]|0;if((J|0)==0){Z=0;_=U;$=R;aa=N;break}N=gj[J&4095](-1)|0;Z=N;_=U;$=c[3528554]|0;aa=c[2433592]|0}else{ab=T;ac=(d[T+254|0]|0)<<8;ad=M;ae=S;F=62961}}while(0);if((F|0)==62961){Z=a[ab+255|0]|0;_=ac;$=ad;aa=ae}S=Z&255|_;c[2415188]=S;b[4830376]=S&65535;S=aa+($*3148|0)|0;if((S|0)!=0){M=S;gGC(M|0,9660752,48)|0}c[9731360+($<<2)>>2]=c[2113158];c[3528554]=-1;M=c[2439330]|0;S=(M|0)==0;if(!S){T=M;gGC(9706056,T|0,76)|0}T=c[2438118]|0;c[2433530]=T;I=c[3528484]|0;c[2076596]=I;K=c[2417276]|0;c[3541536]=K;c[1836236]=0;gGz(9706056,0,76);if(!S){S=M;gGC(S|0,9706056,76)|0}c[2438118]=T;c[3528484]=I;c[2417276]=K;c[1836236]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){K=0;do{lN(K);mB(K);K=K+1|0;}while((K|0)<(c[2385508]|0))}K=c[642608+(c[2436]<<2)>>2]|0;I=c[K+128>>2]|0;if((c[K+52>>2]&4|0)==0){c[2113068]=I;T=c[K+132>>2]|0;c[2113070]=T;c[2443814]=I;c[2440436]=T;af=I;ah=T}else{c[2113070]=I;T=c[K+132>>2]|0;c[2113068]=T;c[2440436]=I;c[2443814]=T;af=T;ah=I}I=ag(af<<1,ah)|0;T=gGq(I)|0;c[2112926]=T;if((T|0)==0){H=0;i=e;return H|0}gGz(T|0,0,I|0);H=0;i=e;return H|0}}while(0);c[2415108]=0;H=1;i=e;return H|0}function bfs(){var b=0,d=0,e=0,f=0;c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}c[2113160]=0;b=c[2433592]|0;if((b|0)!=0){gGr(b);c[2433592]=0}fwZ();b=c[3541518]|0;if((b|0)!=0){gGr(b|0);c[3541518]=0}if((c[2385508]|0)>0){c[2113008]=0;c[2076598]=0;c[2383582]=0}c[2438228]=0;c[2433526]=0;c[2406676]=0;c[3528472]=0;b=c[2406680]|0;if((b|0)!=0){gGr(b);c[2406680]=0}c[2385508]=0;c[2432978]=0;a[64240]=0;b=c[2415108]|0;d=0;while(1){if((d|0)>=1024){e=63030;break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==(b|0)){break}else{d=d+1|0}}if((e|0)==63030){c[2415108]=0;return 0}gGr(b);c[f>>2]=0;c[2415108]=0;return 0}function bft(){var e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;do{if((a[9625048]|0)!=0){a[9625048]=0;e=c[2414816]|0;gGz(e|0,0,(c[2411876]|0)-e|0);c[3528554]=0;f43(c[2433592]|0);e=c[3528554]|0;c[2113158]=c[9731360+(e<<2)>>2];a[9660796]=0;a[9660797]=0;a[9660786]=0;a[9660787]=0;c[2415191]=0;a[9660784]=a[9660784]|80;f=c[2433592]|0;g=c[f+(e*3148|0)+1068>>2]|0;do{if((g|0)==0){i=c[f+(e*3148|0)+3120>>2]|0;if((i|0)==0){j=0;k=0;l=e;m=f;break}n=gj[i&4095](-2)|0;i=c[3528554]|0;o=c[2433592]|0;p=c[o+(i*3148|0)+1068>>2]|0;q=(n&255)<<8;if((p|0)!=0){r=p;s=q;t=i;u=o;v=63036;break}p=c[o+(i*3148|0)+3120>>2]|0;if((p|0)==0){j=0;k=q;l=i;m=o;break}o=gj[p&4095](-1)|0;j=o;k=q;l=c[3528554]|0;m=c[2433592]|0}else{r=g;s=d[g+254|0]<<8;t=e;u=f;v=63036}}while(0);if((v|0)==63036){j=a[r+255|0]|0;k=s;l=t;m=u}f=j&255|k;c[2415188]=f;b[4830376]=f&65535;f=m+(l*3148|0)|0;if((f|0)!=0){e=f;gGC(e|0,9660752,48)|0}c[9731360+(l<<2)>>2]=c[2113158];c[3528554]=-1;e=c[2439330]|0;f=(e|0)==0;if(!f){g=e;gGC(9706056,g|0,76)|0}g=c[2438118]|0;c[2433530]=g;q=c[3528484]|0;c[2076596]=q;o=c[2417276]|0;c[3541536]=o;c[1836236]=0;gGz(9706056,0,76);if(!f){f=e;gGC(f|0,9706056,76)|0}c[2438118]=g;c[3528484]=q;c[2417276]=o;c[1836236]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){w=0}else{break}do{lN(w);mB(w);w=w+1|0;}while((w|0)<(c[2385508]|0))}}while(0);w=c[2385548]|0;if((w|0)>0){gGz(9752472,0,((w|0)>1?w<<2:4)|0)}c[2433530]=0;gGz(9551e3,-1|0,3);w=0;l=-1;m=-1;k=-1;do{l=((a[9634416+w|0]&1)<<w^l&255)&255;m=((a[9632176+w|0]&1)<<w^m&255)&255;k=((a[9630096+w|0]&1)<<w^k&255)&255;w=w+1|0;}while((w|0)<8);a[9551e3]=l;a[9551001]=m;a[9551002]=k;if((m&3)==0){l=m|3;a[9551001]=l;x=l}else{x=m}if((x&12)==0){a[9551001]=x|12}if((k&3)==0){x=k|3;a[9551002]=x;y=x}else{y=k}if((y&12)==0){a[9551002]=y|12}c[3528554]=0;f43(c[2433592]|0);c[2113158]=c[9731360+(c[3528554]<<2)>>2];y=c[2439330]|0;if((y|0)!=0){k=y;gGC(9706056,k|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;k=0;do{y=f45(512)|0;c[2113158]=(c[2113158]|0)+y;Sb(k<<9);k=k+1|0;}while((k|0)<100);k=c[2438228]|0;y=gGS(268435456,24414,k,(k|0)<0|0?-1:0)|0;k=y;Sb(51200);y=c[2443830]|0;if((y|0)<1073676288){c[2443830]=y-k}y=c[2443831]|0;if((y|0)<1073676288){c[2443831]=y-k}y=(c[3528512]|0)-k|0;c[3528512]=(y|0)<0?0:y;if((a[c[3528614]|0]|0)!=0){f44(0);f45(0)|0;a[9660786]=0;f45(0)|0}y=c[2112964]|0;if((y|0)!=0){gg[c[3542122]&4095](y,a[9688]|0?534:0)}y=c[1836236]|0;k=c[9757320+(y<<2)>>2]|0;if((k|0)!=0){x=k;gGC(x|0,9706056,76)|0}c[9752472+(y<<2)>>2]=c[2433530];c[14113936+(y<<2)>>2]=c[2076596];c[9669104+(y<<2)>>2]=c[3541536];c[1836236]=-1;y=c[3528554]|0;x=(c[2433592]|0)+(y*3148|0)|0;if((x|0)!=0){k=x;gGC(k|0,9660752,48)|0}c[9731360+(y<<2)>>2]=c[2113158];c[3528554]=-1;if((c[2112968]|0)==0){return 0}bfu()|0;return 0}function bfu(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;if((a[9548040]|0)!=0){e=c[2407012]|0;f=c[3530194]|0;g=0;do{h=c[e+(g<<2)>>2]|0;c[f+(g<<2)>>2]=h>>8<<3&2016|h>>>3&31|h>>16<<8&63488;g=g+1|0;}while((g|0)<4096)}g=c[2112926]|0;gGz(g|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);f=c[2409010]|0;e=c[2387894]|0;h=c[2386276]|0;i=c[2405124]|0;j=c[2406664]|0;k=c[3528776]|0;l=c[3530952]|0;m=0;do{n=m<<3;o=n&504;do{if((n&256|0)==0){p=(m>>6<<3)-(d[f+(m&31)|0]|0)|0;q=(p|0)<-7?p+256|0:p;p=d[e+m|0]|0;r=p<<2&256|d[h+m|0]|d[i]<<9;s=d[j]<<4|p&15;t=p&16;u=p&32;if((a[k]|0)==0){v=u;w=t;x=o;y=q}else{v=u>>>5^1;w=t>>>4^1;x=248-o|0;y=248-q|0}q=y-16|0;t=(w|0)!=0;if((v|0)==0){if(t){Sl(g,r,x,q,s,4,0,l);break}else{Sj(g,r,x,q,s,4,0,l);break}}else{if(t){Sp(g,r,x,q,s,4,0,l);break}else{Sn(g,r,x,q,s,4,0,l);break}}}}while(0);m=m+1|0;}while((m|0)<2048);m=c[2386532]|0;l=c[3530718]|0;x=c[2113070]|0;v=c[2113068]|0;w=c[3530194]|0;y=0;do{i=d[m+(y|1)|0]|0;h=(d[m+(y|2)|0]|0)-(i<<1&256)|0;e=d[m+(y|3)|0]|0;f=i&16;o=i&32;if((a[k]|0)==0){z=h;A=e;B=o;C=f}else{z=240-h|0;A=240-e|0;B=o>>>5^1;C=f>>>4^1}f=(C|0)==0?0:15;o=(B|0)==0?f:f|240;f=(d[j]<<4|i&15)<<4;e=(i<<2&256|d[m+y|0])<<8;i=A-16|0;h=0;while(1){if((i|0)>-1&(i|0)<(x|0)){n=h<<4;s=ag(v,i)|0;q=z;r=0;while(1){do{if((q|0)>=0&(q|0)<(v|0)){t=f|d[l+(((r|n)^o)+e)|0]|2048;if((c[w+((t&4095)<<2)>>2]|0)==0){break}b[g+(s+q<<1)>>1]=t&65535}}while(0);t=r+1|0;if((t|0)<16){q=q+1|0;r=t}else{break}}}r=h+1|0;if((r|0)>=16){break}i=i+1|0;h=r}y=y+4|0;}while((y|0)<192);R8(w);return 0}function bfv(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;e=i;i=i+96|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;l=e+80|0;if((d|0)!=0){c[d>>2]=169734}if((b&96|0)!=0){gGz(l|0,0,12);m=c[2414816]|0;c[l>>2]=m;c[l+4>>2]=(c[2411876]|0)-m;c[l+12>>2]=196728;m=c[2076592]|0;gj[m&4095](l)|0}if((b&64|0)==0){i=e;return 0}l=k|0;if((c[2113160]|0)>0){m=k+7|0;k=j|0;n=j+4|0;o=j+12|0;p=h;q=h|0;r=h+4|0;s=h+12|0;t=g;u=g|0;v=g+4|0;w=g+12|0;x=f;y=f|0;z=f+4|0;A=f+12|0;B=0;do{C=c[2433592]|0;D=C+(B*3148|0)+40|0;E=c[D>>2]|0;gGC(l|0,614752,9)|0;a[m]=B+48&255;c[k>>2]=C+(B*3148|0);c[n>>2]=48;c[o>>2]=l;gj[c[2076592]&4095](j)|0;gGz(p|0,0,12);c[q>>2]=C+(B*3148|0)+3136;c[r>>2]=4;c[s>>2]=165288;gj[c[2076592]&4095](h)|0;gGz(t|0,0,12);c[u>>2]=C+(B*3148|0)+3140;c[v>>2]=4;c[w>>2]=501592;gj[c[2076592]&4095](g)|0;gGz(x|0,0,12);c[y>>2]=C+(B*3148|0)+3144;c[z>>2]=4;c[A>>2]=386080;gj[c[2076592]&4095](f)|0;c[D>>2]=E;B=B+1|0;}while((B|0)<(c[2113160]|0))}fw$(b);Vx(b,d);i=e;return 0}function bfw(a){a=a|0;var b=0,d=0;b=(c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,3072e3,0)|0;return a|0}function bfx(){return+(+((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)/3072.0e3)}function bfy(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=b&65535;switch(e|0){case 24544:{c[3541230]=d&8;a[9718928]=d&32;return};case 24550:case 24551:{TO(e&1,d);return};case 24546:{f=d&255;if(d<<24>>24==-1){return}c[2415256]=f&32;g=f>>>3&1;c[3528406]=g^1;if((g|0)==0){c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2]}Tr(f>>>4&1);c[2444176]=f>>>6&1;c[2385186]=f&1;return};case 24548:{a[14125144]=-1;a[9706117]=1;return};default:{if((e&65504|0)==24448){a[14116112+(e&31)|0]=d;return}if((e&65520|0)==24480){f=e&15;g=d&255;h=g&63;a[14116144+f|0]=h&255;if((f|0)==9){c[2437682]=g<<5&96;c[2437683]=g>>>2<<5&96;c[2437684]=h>>>4<<5;return}else if((f|0)==10){c[2437685]=g<<4&112;c[2437686]=h>>>3<<4;return}else{return}}if((e&65528|0)==24496){a[14108480+(e&7)|0]=d;return}do{if((c[2385186]|0)!=0){h=e&61440;if((h|0)==24576){a[(c[2387286]|0)+(e&4095)|0]=d;return}else if((h|0)==16384){a[(c[3529044]|0)+((b^1)&4095)|0]=d;return}else{break}}}while(0);if((e&49152|0)!=16384){return}b=e&16383;a[(c[3529062]|0)+b|0]=d;if((e&6144)>>>0<=6143){return}if((b|0)==7936){a[9720738]=d&15;a[9720739]=(d&255)>>>4;return}else if((b|0)==7424){c[3541228]=d&4;return}else if((b|0)==7552){a[9720736]=d&15;a[9720737]=(d&255)>>>4;return}else if((b|0)==7680|(b|0)==15872){a[9730680]=d;return}else if((b|0)==7808){c[2432672]=(d&255)>>>1&3;return}else if((b|0)==7296){a[9729904]=d;return}else{return}}}}function bfz(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;e=i;i=i+24|0;f=e|0;g=e+8|0;h=e+16|0;j=b&65535;switch(j|0){case 24512:{k=a[9550992]|0;i=e;return k|0};case 24513:{k=a[9550993]|0;i=e;return k|0};case 24550:case 24551:{c[2426862]=9674384;k=c[9674388+((j&1|2)<<2)>>2]&255;i=e;return k|0};case 24528:{do{if((c[2406632]|0)==0){l=c[2443744]|0;if((l|0)<=0){m=1;break}c[2443744]=l-1;m=0}else{m=(c[2432962]|0)>>>((c[(c[2420380]|0)+4>>2]|0)>>>0)&1}}while(0);l=c[2430484]|0;n=(((a[672632]|0?8:0)|m|d[9628696]<<2)^246)&255;if((l|0)<=0){k=n;i=e;return k|0}c[2430484]=l-1;k=n&-5;i=e;return k|0};case 24552:case 24553:{if((a[9718928]|0)==0){k=0;i=e;return k|0}k=a[(c[3529048]|0)+(((d[14108486]<<17|j&1|d[14108487]<<9|d[14108484]<<1)^1)&(a[7201808]|0?4194303:0))|0]|0;i=e;return k|0};case 24548:{a[14125144]=-1;a[9706117]=1;k=0;i=e;return k|0};case 24529:{k=a[9550996]|0;i=e;return k|0};case 24554:{k=0;i=e;return k|0};case 24514:{k=a[9550994]|0;i=e;return k|0};case 24515:{k=a[9550995]|0;i=e;return k|0};default:{if((j&65504|0)==24448){k=ba9(j)|0;i=e;return k|0}do{if((c[2385186]|0)!=0){n=j&61440;if((n|0)==16384){k=a[(c[3529044]|0)+((b^1)&4095)|0]|0;i=e;return k|0}else if((n|0)==24576){k=a[(c[2387286]|0)+(j&4095)|0]|0;i=e;return k|0}else{break}}}while(0);if((j&49152|0)!=16384){k=0;i=e;return k|0}if((c[3541230]|0)==0){k=a[(c[3529062]|0)+(j&16383)|0]|0;i=e;return k|0}c[f>>2]=0;b=j>>>5&255;c[g>>2]=b;n=d[9730680]|0;c[h>>2]=n;l=n>>>2&3;if((c[2429638]|0)==0){gB[c[2437692]&127](0,((a[9718936+l|0]|a[9720736+l|0])&255)>>>2,g,h,f,f);o=c[g>>2]|0}else{f=n<<8|b;c[g>>2]=f;o=f}k=a[(c[3529060]|0)+((o<<5|j&31)&c[2438700])|0]|0;i=e;return k|0}}return 0}function bfA(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=b&65535;switch(e|0){case 16336:{c[3541230]=d&8;a[9718928]=d&32;return};case 16340:{a[14125144]=-1;a[9706117]=1;return};case 16338:{f=d&255;if(d<<24>>24==-1){return}c[2415256]=f&32;g=f>>>3&1;c[3528406]=g^1;if((g|0)==0){c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2]}Tr(f>>>4&1);c[2444176]=f>>>6&1;c[2385186]=f&1;return};case 16342:case 16343:{TO(e&1,d);return};default:{if((e&65520|0)==16304){f=e&15;g=d&255;h=g&63;a[14116144+f|0]=h&255;if((f|0)==9){c[2437682]=g<<5&96;c[2437683]=g>>>2<<5&96;c[2437684]=h>>>4<<5;return}else if((f|0)==10){c[2437685]=g<<4&112;c[2437686]=h>>>3<<4;return}else{return}}if((e&65528|0)==16288){a[14108480+(e&7)|0]=d;return}do{if((c[2385186]|0)!=0){h=e&61440;if((h|0)==16384){a[(c[2387286]|0)+(e&4095)|0]=d;return}else if((h|0)==8192){a[(c[3529044]|0)+((b^1)&4095)|0]=d;return}else{break}}}while(0);if((b-8192&65535)>=16384){return}b=e-8192|0;if(b>>>0>24575){return}a[(c[3529062]|0)+b|0]=d;if(b>>>0>16383){c[2429638]=1}if((b&6144)>>>0<=6143){return}if((e|0)==15872|(e|0)==24064){a[9730680]=d;return}else if((e|0)==16e3){c[2432672]=(d&255)>>>1&3;return}else if((e|0)==15744){a[9720736]=d&15;a[9720737]=(d&255)>>>4;return}else if((e|0)==15616){c[3541228]=d&4;return}else if((e|0)==16128){a[9720738]=d&15;a[9720739]=(d&255)>>>4;return}else if((e|0)==15488){a[9729904]=d;return}else{return}}}}function bfB(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;e=i;i=i+24|0;f=e|0;g=e+8|0;h=e+16|0;j=b&65535;switch(j|0){case 16256:{k=a[9550992]|0;i=e;return k|0};case 16258:{k=a[9550994]|0;i=e;return k|0};case 16344:case 16345:{if((a[9718928]|0)==0){k=0;i=e;return k|0}k=a[(c[3529048]|0)+(((d[14108486]<<17|j&1|d[14108487]<<9|d[14108484]<<1)^1)&(a[7201808]|0?4194303:0))|0]|0;i=e;return k|0};case 16257:{k=a[9550993]|0;i=e;return k|0};case 16275:{k=a[9550996]|0;i=e;return k|0};case 16342:case 16343:{c[2426862]=9674384;k=c[9674388+((j&1|2)<<2)>>2]&255;i=e;return k|0};case 16340:{a[14125144]=-1;a[9706117]=1;k=0;i=e;return k|0};case 16259:{k=a[9550995]|0;i=e;return k|0};case 16274:{do{if((c[2406632]|0)==0){l=c[2443744]|0;if((l|0)<=0){m=1;break}c[2443744]=l-1;m=0}else{m=(c[2432962]|0)>>>((c[(c[2420380]|0)+4>>2]|0)>>>0)&1}}while(0);l=c[2430484]|0;n=(((a[672632]|0?8:0)|m|d[9628696]<<2)^246)&255;if((l|0)<=0){k=n;i=e;return k|0}c[2430484]=l-1;k=n&-5;i=e;return k|0};default:{do{if((c[2385186]|0)!=0){n=j&61440;if((n|0)==8192){k=a[(c[3529044]|0)+((b^1)&4095)|0]|0;i=e;return k|0}else if((n|0)==16384){k=a[(c[2387286]|0)+(j&4095)|0]|0;i=e;return k|0}else{break}}}while(0);if((b-8192&65535)>=16384){k=0;i=e;return k|0}b=j-8192|0;if(b>>>0>24575){k=0;i=e;return k|0}if((c[3541230]|0)==0){k=a[(c[3529062]|0)+b|0]|0;i=e;return k|0}c[f>>2]=0;j=b>>>5&255;c[g>>2]=j;n=d[9730680]|0;c[h>>2]=n;l=n>>>2&3;if((c[2429638]|0)==0){gB[c[2437692]&127](0,((a[9718936+l|0]|a[9720736+l|0])&255)>>>2,g,h,f,f);o=c[g>>2]|0}else{f=n<<8|j;c[g>>2]=f;o=f}k=a[(c[3529060]|0)+((o<<5|b&31)&c[2438700])|0]|0;i=e;return k|0}}return 0}function bfC(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=b&65535;if((e|0)==63488){c[2113304]=d&255;return}else if((e|0)==63489){f=c[2113304]|0;a[14168504+f|0]=d;mv(0,f,d&255);return}else if((e|0)==64e3){if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){f=gfc(100)|0;g=f;h=(c[2433530]|0)+f|0}else{g=100;h=(c[2433530]|0)+100|0}c[2433530]=h;c[2444119]=(c[2444119]|0)+g;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12;return}else{if((b+1024&65535)>=48){return}TO(e&255,d);return}}function bfD(b){b=b|0;var d=0,e=0,f=0,g=0;d=b&65535;if((d|0)==63489){e=c[(c[3531464]|0)+4240>>2]&255;return e|0}else if((d|0)==63488){e=-1;return e|0}else{if((b+1024&65535)>=48){e=0;return e|0}if((d&63|0)==1){a[9706117]=0}b=d&255;c[2426862]=9674384;if((b|0)==41){e=(c[2418664]<<1|c[2418653]|c[2418675]<<2|c[2418686]<<3)&255;return e|0}else if((b|0)==46){f=63344}do{if((f|0)==63344){if((c[2418596]&1|0)==0){break}d=c[2418655]|0;g=(d>>>16)+(c[2418650]|0)+(c[2418651]<<16)|0;c[2418655]=d+65536;if(g>>>0>(c[2418646]|0)>>>0){e=0;return e|0}e=a[(c[2418645]|0)+g|0]|0;return e|0}}while(0);e=c[9674388+(b<<2)>>2]&255;return e|0}return 0}function bfE(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2097900+(b*112|0)>>2];c[a+104>>2]=c[2097904+(b*112|0)>>2];c[a+108>>2]=c[2097908+(b*112|0)>>2];d=0;return d|0}function bfF(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=2097800+(b*112|0);e=0;return e|0}function bfG(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>29){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1175976+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function bfH(){return bf2(0)|0}function bfI(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;i=i+128|0;c[2113070]=0;c[2113068]=0;d=c[2112926]|0;if((d|0)!=0){gGr(d);c[2112926]=0}blI();c[2444172]=0;c[3528598]=0;fwZ();d=b|0;e=c[c[642608+(c[2436]<<2)>>2]>>2]|0;be(d|0,128,179600,(f=i,i=i+24|0,c[f>>2]=9374064,c[f+8>>2]=47,c[f+16>>2]=e,f)|0)|0;i=f;a[1040128]=0;f=c[2420380]|0;e=c[f>>2]|0;g=c[f+4>>2]|0;f=fw(d|0,389440)|0;if((f|0)!=0){d=g>>3<<e&1023;cj(14100392,d|0,1,f|0)|0;aY(f|0)|0}f=c[3531464]|0;c[f+44344>>2]=0;c[f+44348>>2]=0;if((f|0)!=0){gGr(f);c[3531464]=0}f=c[2406684]|0;if((f|0)!=0){gGr(f);c[2406684]=0}c[2426862]=9674384;f=c[2418647]|0;if((f|0)!=0){gGr(f);c[(c[2426862]|0)+204>>2]=0}c[2426862]=9674792;f=c[2418749]|0;if((f|0)!=0){gGr(f);c[(c[2426862]|0)+204>>2]=0}c[2443782]=0;f=c[2415106]|0;d=0;while(1){if((d|0)>=1024){h=63394;break}j=9638528+(d<<2)|0;if((c[j>>2]|0)==(f|0)){break}else{d=d+1|0}}if((h|0)==63394){c[2415106]=0;i=b;return 0}gGr(f);c[j>>2]=0;c[2415106]=0;i=b;return 0}function bfJ(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;if((a[9625040]|0)!=0){a[9625040]=0;e=c[2414814]|0;gGz(e|0,0,(c[2411874]|0)-e|0);c[363094]=0;c[2410673]=0;a[9642688]=0;a[9642689]=0;a[9642682]=0;a[9642683]=0;c[2410665]=0;a[9642680]=a[9642680]|80;e=c[2425163]|0;do{if((e|0)==0){f=c[3528598]|0;if((f|0)==0){g=0;h=0;break}i=gj[f&4095](-2)|0;f=c[2425163]|0;j=(i&255)<<8;if((f|0)!=0){k=f;l=j;m=63400;break}f=c[3528598]|0;if((f|0)==0){g=0;h=j;break}g=gj[f&4095](-1)|0;h=j}else{k=e;l=d[e+254|0]<<8;m=63400}}while(0);if((m|0)==63400){g=a[k+255|0]|0;h=l}c[2410662]=g&255|h;c[363094]=-1;h=c[2439330]|0;g=(h|0)==0;if(!g){l=h;gGC(9706056,l|0,76)|0}l=c[2438118]|0;c[2433530]=l;k=c[3528484]|0;c[2076596]=k;m=c[2417276]|0;c[3541536]=m;c[1836236]=0;gGz(9706056,0,76);if(!g){g=h;gGC(g|0,9706056,76)|0}c[2438118]=l;c[3528484]=k;c[2417276]=m;c[1836236]=-1;mx(0);blH();c[2426862]=9674384;gGz(9674592,0,176);c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];c[2430484]=a[1040128]|0?0:1e3;c[2444176]=0;c[2385186]=0}m=c[2385548]|0;if((m|0)>0){gGz(9752472,0,((m|0)>1?m<<2:4)|0)}c[2433530]=0;c[2410673]=0;gGz(9550992,-1|0,5);m=0;k=-1;l=-1;g=-1;h=-1;e=-1;do{k=((a[9634408+m|0]&1)<<m^k&255)&255;l=((a[9632168+m|0]&1)<<m^l&255)&255;g=((a[9630088+m|0]&1)<<m^g&255)&255;h=((a[9629104+m|0]&1)<<m^h&255)&255;e=((a[9628840+m|0]&1)<<m^e&255)&255;m=m+1|0;}while((m|0)<8);a[9550992]=k;a[9550993]=l;a[9550994]=g;a[9550995]=h;a[9550996]=e;if((k&12)==0){e=k|12;a[9550992]=e;n=e}else{n=k}if((n&3)==0){a[9550992]=n|3}if((l&12)==0){n=l|12;a[9550993]=n;o=n}else{o=l}if((o&3)==0){a[9550993]=o|3}if((g&12)==0){o=g|12;a[9550994]=o;p=o}else{p=g}if((p&3)==0){a[9550994]=p|3}if((h&12)==0){p=h|12;a[9550995]=p;q=p}else{q=h}if((q&3)==0){a[9550995]=q|3}c[2444119]=0;c[2444118]=0;q=c[2439330]|0;if((q|0)!=0){h=q;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;c[363094]=0;a[672632]=1;h=0;q=0;L81962:while(1){p=q;while(1){if((p|0)>=100){break L81962}r=p+1|0;g=fNF(((r*1e5|0|0)/100|0)-(c[2444118]|0)|0)|0;c[2444118]=(c[2444118]|0)+g;g=c[2444119]|0;o=((r*59659|0|0)/100|0)-g|0;do{if((o|0)<1){s=0;t=g}else{if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){l=gfc(o)|0;c[2433530]=(c[2433530]|0)+l;s=l;t=c[2444119]|0;break}else{c[2433530]=(c[2433530]|0)+o;s=o;t=g;break}}}while(0);c[2444119]=t+s;if((p|0)==0){a[672632]=0}u=c[2112964]|0;if((u|0)==0){p=r}else{break}}p=a[9688]|0?5:0;g=u+(h<<1<<1)|0;gg[c[3542124]&4095](g,p);TM(g,p);h=p+h|0;q=r}if((c[2444176]|0)!=0){fNE(0,1);fNF(0)|0;a[9642682]=0;fNF(0)|0}r=c[2112964]|0;do{if((r|0)!=0){q=a[9688]|0?534:0;u=q-h|0;s=r+(h<<1<<1)|0;if((q|0)==(h|0)){break}gg[c[3542124]&4095](s,u);TM(s,u)}}while(0);c[363094]=-1;h=c[1836236]|0;r=c[9757320+(h<<2)>>2]|0;if((r|0)!=0){u=r;gGC(u|0,9706056,76)|0}c[9752472+(h<<2)>>2]=c[2433530];c[14113936+(h<<2)>>2]=c[2076596];c[9669104+(h<<2)>>2]=c[3541536];c[1836236]=-1;if((c[2112968]|0)==0){return 0}bfK()|0;return 0}function bfK(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;if((a[9548032]|0)!=0){e=c[2387286]|0;f=c[2407010]|0;g=c[3530192]|0;h=0;do{i=ga(b[e+(h<<1)>>1]|0)|0;j=i&255;k=((j&255)>>>2&7|j<<3)&255;j=((i&65535)>>>5<<3&255|(i&65535)>>>7&7)&255;l=((i&65535)>>>10<<3&255|(i&65535)>>>12&7)&255;c[f+(h<<2)>>2]=j<<8|l|k<<16;c[g+(h<<2)>>2]=j<<3&2016|l>>>3|k<<8&63488;h=h+1|0;}while((h|0)<2048)}bpj();c[2432778]=c[2437683];c[2433656]=c[2437684];c[2433657]=c[2437685];c[2433658]=c[2437686];h=a[14116146]|0;g=h&255;c[2394846]=g;f=a[14116147]|0;e=f&255;c[2394844]=e;k=d[14116148]|0;c[2394842]=k;if((h&255)<(f&255)){c[2394846]=e;c[2394844]=g;m=e;n=1;o=0;p=g}else{m=g;n=0;o=1;p=e}if(m>>>0<k>>>0){c[2394846]=k;c[2394842]=m;q=m;r=2;s=n}else{q=k;r=n;s=2}if((p|0)<(q|0)){c[2394844]=q;c[2394842]=p;t=s;u=o}else{t=o;u=s}s=c[2112926]|0;gGz(s|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);bhi(c[2439878]|0,0);bpk(r,1,c[2439914]|0);bpk(t,0,c[2439914]|0);bhi(c[2439878]|0,1);bhi(c[2439878]|0,2);bpk(u,0,c[2439914]|0);bhi(c[2439878]|0,3);blK(c[2407010]|0,c[3530192]|0);return 0}function bfL(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=i;i=i+144|0;g=f|0;h=f+16|0;j=f+32|0;k=f+48|0;l=f+64|0;m=f+80|0;n=f+96|0;o=f+112|0;p=f+128|0;if((e|0)!=0){c[e>>2]=169733}if((b&96|0)!=0){gGz(p|0,0,12);q=c[2414814]|0;c[p>>2]=q;c[p+4>>2]=(c[2411874]|0)-q;c[p+12>>2]=162152;q=c[2076592]|0;gj[q&4095](p)|0;p=c[2410674]|0;q=c[2410675]|0;do{if((b&64|0)==0){c[2410674]=p;c[2410675]=q;fw$(b)}else{gGz(l|0,0,12);c[l>>2]=9642648;c[l+4>>2]=56;c[l+12>>2]=163840;r=c[2076592]|0;gj[r&4095](l)|0;gGz(k|0,0,12);c[k>>2]=9707480;c[k+4>>2]=2;c[k+12>>2]=501096;r=c[2076592]|0;gj[r&4095](k)|0;gGz(j|0,0,12);c[j>>2]=9707480;c[j+4>>2]=4;c[j+12>>2]=385184;r=c[2076592]|0;gj[r&4095](j)|0;c[2410674]=p;c[2410675]=q;fw$(b);gGz(h|0,0,12);c[h>>2]=8453216;c[h+4>>2]=4;c[h+12>>2]=107480;r=c[2076592]|0;gj[r&4095](h)|0;gGz(g|0,0,12);c[g>>2]=14168504;c[g+4>>2]=256;c[g+12>>2]=476464;r=c[2076592]|0;gj[r&4095](g)|0;if((b&2|0)==0){break}else{s=0}do{mv(0,s,d[14168504+s|0]|0);s=s+1|0;}while((s|0)<256)}}while(0);TP(b);blJ(b);Ts(b,e);gGz(o|0,0,12);c[o>>2]=9776704;c[o+4>>2]=4;c[o+12>>2]=586272;e=c[2076592]|0;gj[e&4095](o)|0;gGz(n|0,0,12);c[n>>2]=9540744;c[n+4>>2]=4;c[n+12>>2]=587384;o=c[2076592]|0;gj[o&4095](n)|0;gGz(m|0,0,12);c[m>>2]=9776476;c[m+4>>2]=4;c[m+12>>2]=321856;n=c[2076592]|0;gj[n&4095](m)|0}if((b&2|0)==0){i=f;return 0}c[363094]=0;b=a[c[2394768]|0]|0;if((b&255)<28){m=c[2387382]|0;n=((b&255)<<13)+65536|0;b=a[7362096]|0?24576:0;o=(((b|8191)-b|0)>>>8&65535)+1|0;e=b>>>8;b=0;s=0;do{g=s+e|0;h=m+(n+(s<<8))|0;c[9699632+(g<<2)>>2]=h;c[9701680+(g<<2)>>2]=h;b=b+1&65535;s=b&65535;}while(s>>>0<o>>>0)}c[363094]=-1;i=f;return 0}function bfM(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1346228+(b*112|0)>>2];c[a+104>>2]=c[1346232+(b*112|0)>>2];c[a+108>>2]=c[1346236+(b*112|0)>>2];d=0;return d|0}function bfN(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=1346128+(b*112|0);e=0;return e|0}function bfO(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[993844+(b*112|0)>>2];c[a+104>>2]=c[993848+(b*112|0)>>2];c[a+108>>2]=c[993852+(b*112|0)>>2];d=0;return d|0}function bfP(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=993744+(b*112|0);e=0;return e|0}function bfQ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1175672+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function bfR(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[820980+(b*112|0)>>2];c[a+104>>2]=c[820984+(b*112|0)>>2];c[a+108>>2]=c[820988+(b*112|0)>>2];d=0;return d|0}function bfS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=820880+(b*112|0);e=0;return e|0}function bfT(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[822100+(b*112|0)>>2];c[a+104>>2]=c[822104+(b*112|0)>>2];c[a+108>>2]=c[822108+(b*112|0)>>2];d=0;return d|0}function bfU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=822e3+(b*112|0);e=0;return e|0}function bfV(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1347348+(b*112|0)>>2];c[a+104>>2]=c[1347352+(b*112|0)>>2];c[a+108>>2]=c[1347356+(b*112|0)>>2];d=0;return d|0}function bfW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=1347248+(b*112|0);e=0;return e|0}function bfX(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4721132+(b*112|0)>>2];c[a+104>>2]=c[4721136+(b*112|0)>>2];c[a+108>>2]=c[4721140+(b*112|0)>>2];d=0;return d|0}function bfY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=4721032+(b*112|0);e=0;return e|0}function bfZ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>37){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1938816+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function bf_(){return bf2(1)|0}function bf$(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2883684+(b*112|0)>>2];c[a+104>>2]=c[2883688+(b*112|0)>>2];c[a+108>>2]=c[2883692+(b*112|0)>>2];d=0;return d|0}function bf0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=2883584+(b*112|0);e=0;return e|0}function bf1(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1273192+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function bf2(e){e=e|0;var f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0;f=i;i=i+1080|0;g=f|0;j=f+112|0;k=f+120|0;l=f+232|0;m=f+240|0;n=f+352|0;o=f+360|0;p=f+472|0;q=f+480|0;r=f+592|0;s=f+600|0;t=f+712|0;u=f+720|0;v=f+832|0;w=f+840|0;x=f+952|0;y=f+960|0;z=f+1072|0;c[2415106]=0;c[2387382]=0;c[2386010]=327680;c[3530950]=393216;c[2439914]=1441792;c[3530716]=3538944;c[2439878]=7733248;c[2386696]=16121856;c[2407010]=17170432;c[3530192]=17178624;c[2414814]=17186816;c[2386162]=17186816;c[2387406]=17188864;c[2387286]=17197056;c[2394768]=17201152;c[2411874]=17201153;A=0;while(1){if((A|0)>=1024){break}B=9638528+(A<<2)|0;if((c[B>>2]|0)==0){C=63588;break}else{A=A+1|0}}do{if((C|0)==63588){A=gGq(17201153)|0;c[B>>2]=A;if((A|0)==0){break}c[2415106]=A;gGz(A|0,0,17201153);c[2387382]=A;c[2386010]=A+327680;c[3530950]=A+393216;c[2439914]=A+1441792;c[3530716]=A+3538944;c[2439878]=A+7733248;c[2386696]=A+16121856;c[2407010]=A+17170432;c[3530192]=A+17178624;D=A+17186816|0;c[2414814]=D;c[2386162]=D;c[2387406]=A+17188864;c[2387286]=A+17197056;c[2394768]=A+17201152;D=A+17201153|0;c[2411874]=D;c[2414424]=D;D=A+65536|0;if((c[3542200]|0)==0){E=1;i=f;return E|0}A=y+108|0;c[A>>2]=0;F=y+100|0;c[F>>2]=0;G=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[G&16383](y,0)|0;do{if((c[A>>2]|0)!=0){G=c[F>>2]|0;c[z>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](z,0,0)|0;if((G|0)<1){E=1;i=f;return E|0}if((gzL(D,0,0)|0)==0){break}else{E=1}i=f;return E|0}}while(0);D=c[2386010]|0;if((c[3542200]|0)==0){E=1;i=f;return E|0}F=w+108|0;c[F>>2]=0;A=w+100|0;c[A>>2]=0;G=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[G&16383](w,1)|0;do{if((c[F>>2]|0)!=0){G=c[A>>2]|0;c[x>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](x,1,0)|0;if((G|0)<1){E=1;i=f;return E|0}if((gzL(D,0,1)|0)==0){break}else{E=1}i=f;return E|0}}while(0);D=c[3530950]|0;if((c[3542200]|0)==0){E=1;i=f;return E|0}A=u+108|0;c[A>>2]=0;F=u+100|0;c[F>>2]=0;G=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[G&16383](u,2)|0;do{if((c[A>>2]|0)!=0){G=c[F>>2]|0;c[v>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](v,2,0)|0;if((G|0)<1){E=1;i=f;return E|0}if((gzL(D,0,2)|0)==0){break}else{E=1}i=f;return E|0}}while(0);D=(c[3530950]|0)+524288|0;if((c[3542200]|0)==0){E=1;i=f;return E|0}F=s+108|0;c[F>>2]=0;A=s+100|0;c[A>>2]=0;G=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[G&16383](s,3)|0;do{if((c[F>>2]|0)!=0){G=c[A>>2]|0;c[t>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](t,3,0)|0;if((G|0)<1){E=1;i=f;return E|0}if((gzL(D,0,3)|0)==0){break}else{E=1}i=f;return E|0}}while(0);D=c[3530716]|0;if((c[3542200]|0)==0){E=1;i=f;return E|0}A=q+108|0;c[A>>2]=0;F=q+100|0;c[F>>2]=0;G=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[G&16383](q,4)|0;do{if((c[A>>2]|0)!=0){G=c[F>>2]|0;c[r>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](r,4,0)|0;if((G|0)<1){E=1;i=f;return E|0}if((gzL(D,0,4)|0)==0){break}else{E=1}i=f;return E|0}}while(0);D=(c[3530716]|0)+1048576|0;if((c[3542200]|0)==0){E=1;i=f;return E|0}F=o+108|0;c[F>>2]=0;A=o+100|0;c[A>>2]=0;G=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[G&16383](o,5)|0;do{if((c[F>>2]|0)!=0){G=c[A>>2]|0;c[p>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](p,5,0)|0;if((G|0)<1){E=1;i=f;return E|0}if((gzL(D,0,5)|0)==0){break}else{E=1}i=f;return E|0}}while(0);D=(c[3530716]|0)+2097152|0;if((c[3542200]|0)==0){E=1;i=f;return E|0}A=m+108|0;c[A>>2]=0;F=m+100|0;c[F>>2]=0;G=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[G&16383](m,6)|0;do{if((c[A>>2]|0)!=0){G=c[F>>2]|0;c[n>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](n,6,0)|0;if((G|0)<1){E=1;i=f;return E|0}if((gzL(D,0,6)|0)==0){break}else{E=1}i=f;return E|0}}while(0);D=(c[3530716]|0)+3145728|0;if((c[3542200]|0)==0){E=1;i=f;return E|0}F=k+108|0;c[F>>2]=0;A=k+100|0;c[A>>2]=0;G=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[G&16383](k,7)|0;do{if((c[F>>2]|0)!=0){G=c[A>>2]|0;c[l>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](l,7,0)|0;if((G|0)<1){E=1;i=f;return E|0}if((gzL(D,0,7)|0)==0){break}else{E=1}i=f;return E|0}}while(0);D=c[2386696]|0;if((c[3542200]|0)==0){E=1;i=f;return E|0}A=g+108|0;c[A>>2]=0;F=g+100|0;c[F>>2]=0;G=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[G&16383](g,8)|0;do{if((c[A>>2]|0)!=0){G=c[F>>2]|0;c[j>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](j,8,0)|0;if((G|0)<1){E=1;i=f;return E|0}if((gzL(D,0,8)|0)==0){break}else{E=1}i=f;return E|0}}while(0);D=c[3530950]|0;blG(D,524288);F=c[3530716]|0;A=F;blG(A,2097152);blG(A,2097152);A=c[2439914]|0;G=0;do{H=G<<6;gGz(A+H|0,0,64);I=G<<8;J=0;do{K=1<<3-J;L=(c[611632+(J<<2)>>2]|0)+I|0;M=0;do{N=L+(c[1183816+(M<<2)>>2]|0)|0;O=(M<<3)+H|0;P=0;do{Q=N+(c[614800+(P<<2)>>2]|0)|0;if(((d[D+((Q|0)/8|0)|0]|0)&128>>>((Q&7)>>>0)|0)!=0){Q=A+(O+P)|0;a[Q]=(d[Q]|0|K)&255}P=P+1|0;}while((P|0)<8);M=M+1|0;}while((M|0)<8);J=J+1|0;}while((J|0)<4);G=G+1|0;}while((G|0)<32768);G=c[2439878]|0;A=0;do{J=a[F+(A^1)|0]|0;H=A<<1;a[G+H|0]=(J&255)>>>4;a[G+(H|1)|0]=J&15;A=A+1|0;}while((A|0)<4194304);A=c[2387382]|0;G=A+32768|0;if((e|0)==0){F=A+294912|0;gGC(G|0,F|0,32768)|0;c[2410674]=1748;gGz(9699632,0,3072);F=c[2427044]|0;c[9681616+(F<<3)>>2]=715288;c[9681620+(F<<3)>>2]=0;c[2427044]=F+1;c[363094]=0;F=0;J=0;while(1){H=A+((J<<8)+65536)|0;c[9699632+(J<<2)>>2]=H;c[9701680+(J<<2)>>2]=H;H=F+1&65535;if((H&65535)<32){F=H;J=H&65535}else{break}}J=c[2387406]|0;F=0;H=0;while(1){I=H+32|0;M=J+(H<<8)|0;c[9699632+(I<<2)>>2]=M;c[9700656+(I<<2)>>2]=M;c[9701680+(I<<2)>>2]=M;M=F+1&65535;if((M&65535)<32){F=M;H=M&65535}else{R=0;S=0;break}}while(1){H=S+128|0;F=A+((S<<8)+32768)|0;c[9699632+(H<<2)>>2]=F;c[9701680+(H<<2)>>2]=F;F=R+1&65535;if((F&65535)<128){R=F;S=F&65535}else{break}}c[2444172]=488;c[3528598]=112;c[2410675]=762;c[363094]=-1;F=0;while(1){if((F|0)>=1024){T=0;break}U=9638528+(F<<2)|0;if((c[U>>2]|0)==0){C=63657;break}else{F=F+1|0}}do{if((C|0)==63657){F=gGq(24576)|0;c[U>>2]=F;if((F|0)==0){T=0;break}gGz(F|0,0,24576);T=F}}while(0);c[3529062]=T;c[2438700]=1048575;c[3529060]=D;a[7461784]=1;F=9726816;c[F>>2]=0;c[F+4>>2]=0;F=9726800;c[F>>2]=0;c[F+4>>2]=0;c[2429638]=0;c[2437692]=70;c[2431704]=0;c[2431700]=0;c[2431705]=0;c[2431701]=0;c[2431706]=0;c[2431702]=0;bhh(c[3530716]|0,48,1);V=0;W=22;X=-53}else{F=A+163840|0;gGC(G|0,F|0,32768)|0;c[2410674]=1748;gGz(9699632,0,3072);F=c[2427044]|0;c[9681616+(F<<3)>>2]=715288;c[9681620+(F<<3)>>2]=0;c[2427044]=F+1;c[363094]=0;F=c[2387406]|0;H=0;J=0;while(1){M=F+(J<<8)|0;c[9699632+(J<<2)>>2]=M;c[9700656+(J<<2)>>2]=M;c[9701680+(J<<2)>>2]=M;M=H+1&65535;if((M&65535)<32){H=M;J=M&65535}else{Y=0;Z=0;break}}while(1){J=Z+96|0;H=A+((Z<<8)+65536)|0;c[9699632+(J<<2)>>2]=H;c[9701680+(J<<2)>>2]=H;H=Y+1&65535;if((H&65535)<32){Y=H;Z=H&65535}else{_=0;$=0;break}}while(1){H=$+128|0;J=A+(($<<8)+32768)|0;c[9699632+(H<<2)>>2]=J;c[9701680+(H<<2)>>2]=J;J=_+1&65535;if((J&65535)<128){_=J;$=J&65535}else{break}}c[2444172]=1022;c[3528598]=262;c[2410675]=762;c[363094]=-1;A=0;while(1){if((A|0)>=1024){aa=0;break}ab=9638528+(A<<2)|0;if((c[ab>>2]|0)==0){C=63646;break}else{A=A+1|0}}do{if((C|0)==63646){A=gGq(24576)|0;c[ab>>2]=A;if((A|0)==0){aa=0;break}gGz(A|0,0,24576);aa=A}}while(0);c[3529062]=aa;c[2438700]=1048575;c[3529060]=D;a[7461784]=1;A=9726816;c[A>>2]=0;c[A+4>>2]=0;A=9726800;c[A>>2]=0;c[A+4>>2]=0;c[2429638]=0;c[2437692]=10;c[2431704]=8;c[2431700]=-8;c[2431705]=8;c[2431701]=-8;c[2431706]=8;c[2431702]=-8;bhh(c[3530716]|0,48,1);V=1;W=14;X=-11}c[3529042]=X;c[3529040]=W;a[7362096]=V;fwR(0);A=c[2439330]|0;J=(A|0)==0;if(!J){H=A;gGC(9706056,H|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];H=c[3528484]|0;c[2076596]=H;F=c[2417276]|0;c[3541536]=F;c[1836236]=0;G=c[2386010]|0;M=0;I=0;while(1){c[A+76+(I<<2)>>2]=G+(I<<8);K=M+1&65535;if((K&65535)>239){ac=0;ad=0;break}else{M=K;I=K&65535}}while(1){I=G+(ad<<8)|0;c[A+76+(ad+512<<2)>>2]=I;c[A+76+(ad+768<<2)>>2]=I;I=ac+1&65535;if((I&65535)>239){break}else{ac=I;ad=I&65535}}G=c[2386162]|0;c[A+1036>>2]=G;I=G+256|0;c[A+1040>>2]=I;M=G+512|0;c[A+1044>>2]=M;D=G+768|0;c[A+1048>>2]=D;K=G+1024|0;c[A+1052>>2]=K;L=G+1280|0;c[A+1056>>2]=L;P=G+1536|0;c[A+1060>>2]=P;O=G+1792|0;c[A+1064>>2]=O;c[A+2060>>2]=G;c[A+2064>>2]=I;c[A+2068>>2]=M;c[A+2072>>2]=D;c[A+2076>>2]=K;c[A+2080>>2]=L;c[A+2084>>2]=P;c[A+2088>>2]=O;c[A+3084>>2]=G;c[A+4108>>2]=G;c[A+3088>>2]=I;c[A+4112>>2]=I;c[A+3092>>2]=M;c[A+4116>>2]=M;c[A+3096>>2]=D;c[A+4120>>2]=D;c[A+3100>>2]=K;c[A+4124>>2]=K;c[A+3104>>2]=L;c[A+4128>>2]=L;c[A+3108>>2]=P;c[A+4132>>2]=P;c[A+3112>>2]=O;c[A+4136>>2]=O;c[A+4184>>2]=588;c[A+4180>>2]=920;if(!J){O=A;gGC(O|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=H;c[2417276]=F;c[1836236]=-1;Tq(704696);O=a[9680]|0;P=O?32e3:0;if(O){if(a[9624]|0){O=P*3|0;L=55930;while(1){if((L|0)>(O|0)){L=L>>1}else{ae=1222;af=L;break}}}else{ae=2462;af=P}c[2429380]=af;c[3542124]=ae;mw(3579545,af);L=gGq(262144)|0;c[2406684]=L;gGz(L|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(3579545,11025)}h[745421]=1.0;c[2436794]=1;h[745420]=1.0;c[2436792]=2;TN(c[2386696]|0,1048576>>>(e>>>0));h[1209346]=.75;c[2418696]=1;c[2426862]=9674384;h[1209347]=.75;c[2418697]=2;L=c[642608+(c[2436]<<2)>>2]|0;O=c[L+128>>2]|0;if((c[L+52>>2]&4|0)==0){c[2113068]=O;F=c[L+132>>2]|0;c[2113070]=F;c[2443814]=O;c[2440436]=F;ah=O;ai=F}else{c[2113070]=O;F=c[L+132>>2]|0;c[2113068]=F;c[2440436]=O;c[2443814]=F;ah=F;ai=O}O=ag(ah<<1,ai)|0;F=gGq(O)|0;c[2112926]=F;if((F|0)!=0){gGz(F|0,0,O|0)}a[9625040]=0;O=c[2414814]|0;gGz(O|0,0,(c[2411874]|0)-O|0);c[363094]=0;c[2410673]=0;a[9642688]=0;a[9642689]=0;a[9642682]=0;a[9642683]=0;c[2410665]=0;a[9642680]=a[9642680]|80;O=c[2425163]|0;do{if((O|0)==0){F=c[3528598]|0;if((F|0)==0){aj=0;ak=0;break}L=gj[F&4095](-2)|0;F=c[2425163]|0;H=(L&255)<<8;if((F|0)!=0){al=F;am=H;C=63682;break}F=c[3528598]|0;if((F|0)==0){aj=0;ak=H;break}aj=gj[F&4095](-1)|0;ak=H}else{al=O;am=(d[O+254|0]|0)<<8;C=63682}}while(0);if((C|0)==63682){aj=a[al+255|0]|0;ak=am}c[2410662]=aj&255|ak;c[363094]=-1;O=c[2439330]|0;P=(O|0)==0;if(!P){H=O;gGC(9706056,H|0,76)|0}H=c[2438118]|0;c[2433530]=H;F=c[3528484]|0;c[2076596]=F;L=c[2417276]|0;c[3541536]=L;c[1836236]=0;gGz(9706056,0,76);if(!P){P=O;gGC(P|0,9706056,76)|0}c[2438118]=H;c[3528484]=F;c[2417276]=L;c[1836236]=-1;mx(0);blH();c[2426862]=9674384;gGz(9674592,0,176);c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];c[2430484]=a[1040128]|0?0:1e3;c[2444176]=0;c[2385186]=0;E=0;i=f;return E|0}}while(0);c[2415106]=0;E=1;i=f;return E|0}function bf3(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;a[c[2394768]|0]=b&255;if((b|0)>=28){return}d=c[2387382]|0;e=(b<<13)+65536|0;b=a[7362096]|0?24576:0;f=(((b|8191)-b|0)>>>8&65535)+1|0;g=b>>>8;b=0;h=0;do{i=h+g|0;j=d+(e+(h<<8))|0;c[9699632+(i<<2)>>2]=j;c[9701680+(i<<2)>>2]=j;b=b+1&65535;h=b&65535;}while(h>>>0<f>>>0);return}function bf4(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;g=c[e>>2]|0;c[d>>2]=c[d>>2]|b<<13|g<<6&1024|g<<8&768|g<<9&6144;c[e>>2]=((c[e>>2]|0)>>>5&7)+(c[9734624+(a<<2)>>2]|0);return}function bf5(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;e=(c[b>>2]|0)>>>4&62;do{if((e|0)>(c[2394842]|0)){if((e|0)<=(c[2394844]|0)){c[d>>2]=1;break}if((e|0)>(c[2394846]|0)){c[d>>2]=3;break}else{c[d>>2]=2;break}}else{c[d>>2]=0}}while(0);c[a>>2]=c[a>>2]&32767;c[b>>2]=(c[b>>2]&31)+(c[2432778]|0);return}function bf6(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;g=c[e>>2]|0;c[d>>2]=c[d>>2]|b<<14|g<<6&3072|g<<8&768|g<<10&12288;c[e>>2]=((c[e>>2]|0)>>>6&3)+(c[9734624+(a<<2)>>2]|0);return}function bf7(d,e){d=d|0;e=e|0;var f=0,g=0,h=0;f=d&65535;if((f|0)==49280){d=c[1836236]|0;g=c[9757320+(d<<2)>>2]|0;if((g|0)!=0){h=g;gGC(h|0,9706056,76)|0}c[9752472+(d<<2)>>2]=c[2433530];c[14113936+(d<<2)>>2]=c[2076596];c[9669104+(d<<2)>>2]=c[3541536];c[1836236]=-1;d=c[2439331]|0;if((d|0)!=0){h=d;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0;h=c[1836236]|0;d=c[9757320+(h<<2)>>2]|0;if((d|0)!=0){g=d;gGC(g|0,9706056,76)|0}c[9752472+(h<<2)>>2]=c[2433530];c[14113936+(h<<2)>>2]=c[2076596];c[9669104+(h<<2)>>2]=c[3541536];c[1836236]=-1;h=c[2439330]|0;if((h|0)!=0){g=h;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;return}else if((f|0)==49536){a[c[2430480]|0]=e;return}else if((f|0)==49541){a[c[3528774]|0]=e&1;return}else if((f|0)==49408){a[c[3528372]|0]=e;return}else{return}}function bf8(b){b=b|0;var c=0;switch(b&65535|0){case 49152:{c=a[9635705]|0;break};case 49280:{c=a[9550984]|0;break};case 49408:{c=a[9635706]|0;break};case 49376:{c=a[9635704]|0;break};case 49312:{c=a[9550985]|0;break};case 49344:{c=a[9550986]|0;break};default:{c=0}}return c|0}function bf9(b,d){b=b|0;d=d|0;if(b<<16>>16!=8192){return}a[c[2430478]|0]=d;return}function bga(a){a=a|0;var b=0;if(a<<16>>16!=0){b=0;return b|0}b=c[2388526]&127;return b|0}function bgb(b){b=b|0;var d=0;if(b<<16>>16!=-32768){d=0;return d|0}d=a[c[3528372]|0]|0;return d|0}function bgc(b){b=b|0;var d=0,e=0;switch(b&255|0){case 1:{b=c[3542228]|0;if((b|0)>15){d=0;return d|0}do{if((b|0)==14){e=c[3542224]|0;if((e|0)==0){break}a[14168930]=gj[e&4095](0)|0}else if((b|0)==15){e=c[3542225]|0;if((e|0)==0){break}a[14168931]=gj[e&4095](0)|0}}while(0);d=a[14168916+b|0]|0;return d|0};case 13:{b=c[3542417]|0;if((b|0)>15){d=0;return d|0}do{if((b|0)==14){e=c[3542413]|0;if((e|0)==0){break}a[14169686]=gj[e&4095](0)|0}else if((b|0)==15){e=c[3542414]|0;if((e|0)==0){break}a[14169687]=gj[e&4095](0)|0}}while(0);d=a[14169672+b|0]|0;return d|0};case 5:{b=c[3542291]|0;if((b|0)>15){d=0;return d|0}do{if((b|0)==14){e=c[3542287]|0;if((e|0)==0){break}a[14169182]=gj[e&4095](0)|0}else if((b|0)==15){e=c[3542288]|0;if((e|0)==0){break}a[14169183]=gj[e&4095](0)|0}}while(0);d=a[14169168+b|0]|0;return d|0};case 17:{b=c[3542480]|0;if((b|0)>15){d=0;return d|0}do{if((b|0)==14){e=c[3542476]|0;if((e|0)==0){break}a[14169938]=gj[e&4095](0)|0}else if((b|0)==15){e=c[3542477]|0;if((e|0)==0){break}a[14169939]=gj[e&4095](0)|0}}while(0);d=a[14169924+b|0]|0;return d|0};case 9:{b=c[3542354]|0;if((b|0)>15){d=0;return d|0}do{if((b|0)==14){e=c[3542350]|0;if((e|0)==0){break}a[14169434]=gj[e&4095](0)|0}else if((b|0)==15){e=c[3542351]|0;if((e|0)==0){break}a[14169435]=gj[e&4095](0)|0}}while(0);d=a[14169420+b|0]|0;return d|0};default:{d=0;return d|0}}return 0}function bgd(b,d){b=b|0;d=d|0;var e=0;switch(b&255|0){case 0:{c[3542228]=d&15;return};case 8:{c[3542354]=d&15;return};case 2:{b=d&255;e=c[3542228]|0;if((e|0)>15){return}do{if((e|0)<14){if((e|0)!=13){if((a[14168916+e|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(0,e,b);return};case 12:{c[3542417]=d&15;return};case 16:{c[3542480]=d&15;return};case 18:{b=d&255;e=c[3542480]|0;if((e|0)>15){return}do{if((e|0)<14){if((e|0)!=13){if((a[14169924+e|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(4,e,b);return};case 6:{b=d&255;e=c[3542291]|0;if((e|0)>15){return}do{if((e|0)<14){if((e|0)!=13){if((a[14169168+e|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(1,e,b);return};case 24:{a[c[2443732]|0]=d;return};case 14:{b=d&255;e=c[3542417]|0;if((e|0)>15){return}do{if((e|0)<14){if((e|0)!=13){if((a[14169672+e|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(3,e,b);return};case 10:{b=d&255;e=c[3542354]|0;if((e|0)>15){return}do{if((e|0)<14){if((e|0)!=13){if((a[14169420+e|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(2,e,b);return};case 4:{c[3542291]=d&15;return};default:{return}}}function bge(a){a=a|0;return c[619264+((((((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)*60|0)>>10|0)%10|0)<<2)>>2]&255|0}function bgf(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5875052+(b*112|0)>>2];c[a+104>>2]=c[5875056+(b*112|0)>>2];c[a+108>>2]=c[5875060+(b*112|0)>>2];d=0;return d|0}function bgg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=5874952+(b*112|0);e=0;return e|0}function bgh(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3878e3+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function bgi(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>62){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6282840+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function bgj(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0.0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0;e=i;i=i+1800|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;B=e+1200|0;C=e+1312|0;D=e+1320|0;E=e+1432|0;F=e+1440|0;G=e+1552|0;H=e+1560|0;I=e+1672|0;J=e+1680|0;K=e+1792|0;c[2415104]=0;bgw();L=c[2414422]|0;M=0;while(1){if((M|0)>=1024){break}N=9638528+(M<<2)|0;if((c[N>>2]|0)==0){O=63911;break}else{M=M+1|0}}do{if((O|0)==63911){M=gGq(L)|0;c[N>>2]=M;if((M|0)==0){break}gGz(M|0,0,L|0);c[2415104]=M;gGz(M|0,0,L|0);bgw();M=c[3529262]|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}Q=J+108|0;c[Q>>2]=0;R=J+100|0;c[R>>2]=0;S=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[S&16383](J,0)|0;do{if((c[Q>>2]|0)!=0){S=c[R>>2]|0;c[K>>2]=9534384;T=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[T&16383](K,0,0)|0;if((S|0)<1){P=1;i=e;return P|0}if((gzL(M,0,0)|0)==0){break}else{P=1}i=e;return P|0}}while(0);M=(c[3529262]|0)+8192|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}R=H+108|0;c[R>>2]=0;Q=H+100|0;c[Q>>2]=0;S=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[S&16383](H,1)|0;do{if((c[R>>2]|0)!=0){S=c[Q>>2]|0;c[I>>2]=9534384;T=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[T&16383](I,1,0)|0;if((S|0)<1){P=1;i=e;return P|0}if((gzL(M,0,1)|0)==0){break}else{P=1}i=e;return P|0}}while(0);M=(c[3529262]|0)+16384|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}Q=F+108|0;c[Q>>2]=0;R=F+100|0;c[R>>2]=0;S=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[S&16383](F,2)|0;do{if((c[Q>>2]|0)!=0){S=c[R>>2]|0;c[G>>2]=9534384;T=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[T&16383](G,2,0)|0;if((S|0)<1){P=1;i=e;return P|0}if((gzL(M,0,2)|0)==0){break}else{P=1}i=e;return P|0}}while(0);M=(c[3527402]|0)+57344|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}R=D+108|0;c[R>>2]=0;Q=D+100|0;c[Q>>2]=0;S=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[S&16383](D,3)|0;do{if((c[R>>2]|0)!=0){S=c[Q>>2]|0;c[E>>2]=9534384;T=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[T&16383](E,3,0)|0;if((S|0)<1){P=1;i=e;return P|0}if((gzL(M,0,3)|0)==0){break}else{P=1}i=e;return P|0}}while(0);M=c[3529218]|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}Q=B+108|0;c[Q>>2]=0;R=B+100|0;c[R>>2]=0;S=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[S&16383](B,4)|0;do{if((c[Q>>2]|0)!=0){S=c[R>>2]|0;c[C>>2]=9534384;T=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[T&16383](C,4,0)|0;if((S|0)<1){P=1;i=e;return P|0}if((gzL(M,0,4)|0)==0){break}else{P=1}i=e;return P|0}}while(0);M=(c[3529218]|0)+8192|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}R=z+108|0;c[R>>2]=0;Q=z+100|0;c[Q>>2]=0;S=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[S&16383](z,5)|0;do{if((c[R>>2]|0)!=0){S=c[Q>>2]|0;c[A>>2]=9534384;T=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[T&16383](A,5,0)|0;if((S|0)<1){P=1;i=e;return P|0}if((gzL(M,0,5)|0)==0){break}else{P=1}i=e;return P|0}}while(0);M=c[3527446]|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}Q=x+108|0;c[Q>>2]=0;R=x+100|0;c[R>>2]=0;S=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[S&16383](x,6)|0;do{if((c[Q>>2]|0)!=0){S=c[R>>2]|0;c[y>>2]=9534384;T=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[T&16383](y,6,0)|0;if((S|0)<1){P=1;i=e;return P|0}if((gzL(M,0,6)|0)==0){break}else{P=1}i=e;return P|0}}while(0);M=c[3530948]|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}R=v+108|0;c[R>>2]=0;Q=v+100|0;c[Q>>2]=0;S=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[S&16383](v,7)|0;do{if((c[R>>2]|0)!=0){S=c[Q>>2]|0;c[w>>2]=9534384;T=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[T&16383](w,7,0)|0;if((S|0)<1){P=1;i=e;return P|0}if((gzL(M,0,7)|0)==0){break}else{P=1}i=e;return P|0}}while(0);M=(c[3530948]|0)+8192|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}Q=t+108|0;c[Q>>2]=0;R=t+100|0;c[R>>2]=0;S=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[S&16383](t,8)|0;do{if((c[Q>>2]|0)!=0){S=c[R>>2]|0;c[u>>2]=9534384;T=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[T&16383](u,8,0)|0;if((S|0)<1){P=1;i=e;return P|0}if((gzL(M,0,8)|0)==0){break}else{P=1}i=e;return P|0}}while(0);M=(c[3530948]|0)+16384|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}R=r+108|0;c[R>>2]=0;Q=r+100|0;c[Q>>2]=0;S=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[S&16383](r,9)|0;do{if((c[R>>2]|0)!=0){S=c[Q>>2]|0;c[s>>2]=9534384;T=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[T&16383](s,9,0)|0;if((S|0)<1){P=1;i=e;return P|0}if((gzL(M,0,9)|0)==0){break}else{P=1}i=e;return P|0}}while(0);M=(c[3530948]|0)+24576|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}Q=p+108|0;c[Q>>2]=0;R=p+100|0;c[R>>2]=0;S=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[S&16383](p,10)|0;do{if((c[Q>>2]|0)!=0){S=c[R>>2]|0;c[q>>2]=9534384;T=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[T&16383](q,10,0)|0;if((S|0)<1){P=1;i=e;return P|0}if((gzL(M,0,10)|0)==0){break}else{P=1}i=e;return P|0}}while(0);M=c[3530490]|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}R=n+108|0;c[R>>2]=0;Q=n+100|0;c[Q>>2]=0;S=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[S&16383](n,11)|0;do{if((c[R>>2]|0)!=0){S=c[Q>>2]|0;c[o>>2]=9534384;T=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[T&16383](o,11,0)|0;if((S|0)<1){P=1;i=e;return P|0}if((gzL(M,0,11)|0)==0){break}else{P=1}i=e;return P|0}}while(0);M=c[3531050]|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}Q=l+108|0;c[Q>>2]=0;R=l+100|0;c[R>>2]=0;S=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[S&16383](l,12)|0;do{if((c[Q>>2]|0)!=0){S=c[R>>2]|0;c[m>>2]=9534384;T=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[T&16383](m,12,0)|0;if((S|0)<1){P=1;i=e;return P|0}if((gzL(M,0,12)|0)==0){break}else{P=1}i=e;return P|0}}while(0);M=(c[3531050]|0)+32|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}R=j+108|0;c[R>>2]=0;Q=j+100|0;c[Q>>2]=0;S=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[S&16383](j,13)|0;do{if((c[R>>2]|0)!=0){S=c[Q>>2]|0;c[k>>2]=9534384;T=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[T&16383](k,13,0)|0;if((S|0)<1){P=1;i=e;return P|0}if((gzL(M,0,13)|0)==0){break}else{P=1}i=e;return P|0}}while(0);M=(c[3531050]|0)+288|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}Q=f+108|0;c[Q>>2]=0;R=f+100|0;c[R>>2]=0;S=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[S&16383](f,14)|0;do{if((c[Q>>2]|0)!=0){S=c[R>>2]|0;c[g>>2]=9534384;T=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[T&16383](g,14,0)|0;if((S|0)<1){P=1;i=e;return P|0}if((gzL(M,0,14)|0)==0){break}else{P=1}i=e;return P|0}}while(0);M=c[3527402]|0;R=c[2438786]|0;Q=57344;while(1){a[R+Q|0]=(((Q&2|0)==0?32:-128)|((Q&8|0)==0?2:8))^a[M+Q|0];S=Q+1|0;if((S|0)<65536){Q=S}else{U=0;break}}while(1){if((U|0)>=1024){break}V=9638528+(U<<2)|0;if((c[V>>2]|0)==0){O=63977;break}else{U=U+1|0}}L82725:do{if((O|0)==63977){Q=gGq(65536)|0;c[V>>2]=Q;if((Q|0)==0){break}gGz(Q|0,0,65536);M=c[3530948]|0;gGC(Q|0,M|0,32768)|0;R=0;do{S=R<<7;gGz(M+S|0,0,128);T=R<<9;W=0;do{X=1<<3-W;Y=(c[605936+(W<<2)>>2]|0)+T|0;Z=0;do{_=Y+(c[611712+(Z<<2)>>2]|0)|0;$=(Z<<3)+S|0;aa=0;do{ab=_+(c[612768+(aa<<2)>>2]|0)|0;if(((d[Q+((ab|0)/8|0)|0]|0)&128>>>((ab&7)>>>0)|0)!=0){ab=M+($+aa)|0;a[ab]=(d[ab]|0|X)&255}aa=aa+1|0;}while((aa|0)<8);Z=Z+1|0;}while((Z|0)<16);W=W+1|0;}while((W|0)<4);R=R+1|0;}while((R|0)<512);R=c[3530714]|0;M=0;do{W=M<<7;gGz(R+W|0,0,128);S=M<<9;T=0;do{Z=1<<3-T;X=(c[605936+(T<<2)>>2]|0)+S|0;Y=0;do{aa=X+(c[611712+(Y<<2)>>2]|0)|0;$=(Y<<3)+W|0;_=0;do{ab=aa+(c[612768+(_<<2)>>2]|0)|0;if(((d[Q+(((ab|0)/8|0)+16)|0]|0)&128>>>((ab&7)>>>0)|0)!=0){ab=R+($+_)|0;a[ab]=(d[ab]|0|Z)&255}_=_+1|0;}while((_|0)<8);Y=Y+1|0;}while((Y|0)<16);T=T+1|0;}while((T|0)<4);M=M+1|0;}while((M|0)<512);M=c[3530490]|0;gGC(Q|0,M|0,8192)|0;R=0;while(1){T=R<<6;gGz(M+T|0,0,64);W=R<<7;S=W|4;Y=0;while(1){Z=S+(c[611712+(Y<<2)>>2]|0)|0;X=(Y<<3)+T|0;_=0;do{$=Z+(c[612768+(_<<2)>>2]|0)|0;if(((d[Q+(($|0)/8|0)|0]|0)&128>>>(($&7)>>>0)|0)!=0){$=M+(X+_)|0;a[$]=a[$]|2}_=_+1|0;}while((_|0)<8);_=Y+1|0;if((_|0)<8){Y=_}else{ac=0;break}}do{Y=W+(c[611712+(ac<<2)>>2]|0)|0;S=(ac<<3)+T|0;_=0;do{X=Y+(c[612768+(_<<2)>>2]|0)|0;if(((d[Q+((X|0)/8|0)|0]|0)&128>>>((X&7)>>>0)|0)!=0){X=M+(S+_)|0;a[X]=a[X]|1}_=_+1|0;}while((_|0)<8);ac=ac+1|0;}while((ac|0)<8);T=R+1|0;if((T|0)<512){R=T}else{ad=0;break}}while(1){if((ad|0)>=1024){break L82725}ae=9638528+(ad<<2)|0;if((c[ae>>2]|0)==(Q|0)){break}else{ad=ad+1|0}}gGr(Q);c[ae>>2]=0}}while(0);R=c[3531050]|0;M=0;while(1){if((M|0)>=1024){break}af=9638528+(M<<2)|0;if((c[af>>2]|0)==0){O=64011;break}else{M=M+1|0}}L82785:do{if((O|0)==64011){M=gGq(128)|0;c[af>>2]=M;if((M|0)==0){break}gGz(M|0,0,128);T=M;W=0;do{_=d[R+W|0]|0;c[T+(W<<2)>>2]=~~(+((-(_>>>3&1)&33|-(_>>>4&1)&70)+(-(_>>>5&1)&151)|0)+.5)<<8&65280|~~(+((-(_>>>6&1)&78)+(-(_>>>7)&151)|0)+.5)&255|~~(+((-(_>>>1&1)&70|-(_&1)&33)+(-(_>>>2&1)&151)|0)+.5)<<16&16711680;W=W+1|0;}while((W|0)<32);W=c[2407008]|0;Q=0;while(1){c[W+(Q<<2)>>2]=c[T+((a[R+(Q+32)|0]&15|Q>>>4&16)<<2)>>2];_=Q+1|0;if((_|0)<320){Q=_}else{ah=0;break}}while(1){if((ah|0)>=1024){break L82785}ai=9638528+(ah<<2)|0;if((c[ai>>2]|0)==(M|0)){break}else{ah=ah+1|0}}gGr(M);c[ai>>2]=0}}while(0);fwR(0);R=c[2439330]|0;Q=(R|0)==0;if(!Q){T=R;gGC(9706056,T|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];T=c[3528484]|0;c[2076596]=T;W=c[2417276]|0;c[3541536]=W;c[1836236]=0;_=c[3529262]|0;S=0;Y=0;while(1){c[R+76+(Y<<2)>>2]=_+(Y<<8);X=S+1&65535;if((X&65535)>127){aj=0;ak=0;break}else{S=X;Y=X&65535}}while(1){Y=_+(ak<<8)|0;c[R+76+(ak+512<<2)>>2]=Y;c[R+76+(ak+768<<2)>>2]=Y;Y=aj+1&65535;if((Y&65535)>127){break}else{aj=Y;ak=Y&65535}}_=c[2387892]|0;c[R+588>>2]=_;Y=_+256|0;c[R+592>>2]=Y;S=_+512|0;c[R+596>>2]=S;X=_+768|0;c[R+600>>2]=X;c[R+1612>>2]=_;c[R+1616>>2]=Y;c[R+1620>>2]=S;c[R+1624>>2]=X;c[R+2636>>2]=_;c[R+3660>>2]=_;c[R+2640>>2]=Y;c[R+3664>>2]=Y;c[R+2644>>2]=S;c[R+3668>>2]=S;c[R+2648>>2]=X;c[R+3672>>2]=X;X=c[2386274]|0;c[R+604>>2]=X;S=X+256|0;c[R+608>>2]=S;Y=X+512|0;c[R+612>>2]=Y;_=X+768|0;c[R+616>>2]=_;c[R+1628>>2]=X;c[R+1632>>2]=S;c[R+1636>>2]=Y;c[R+1640>>2]=_;c[R+2652>>2]=X;c[R+3676>>2]=X;c[R+2656>>2]=S;c[R+3680>>2]=S;c[R+2660>>2]=Y;c[R+3684>>2]=Y;c[R+2664>>2]=_;c[R+3688>>2]=_;_=c[3529350]|0;c[R+652>>2]=_;c[R+656>>2]=_+256;c[R+660>>2]=_+512;c[R+664>>2]=_+768;c[R+668>>2]=_+1024;c[R+672>>2]=_+1280;c[R+676>>2]=_+1536;c[R+680>>2]=_+1792;c[R+684>>2]=_+2048;c[R+688>>2]=_+2304;c[R+692>>2]=_+2560;c[R+696>>2]=_+2816;c[R+700>>2]=_+3072;c[R+704>>2]=_+3328;c[R+708>>2]=_+3584;c[R+712>>2]=_+3840;Y=144;S=144;while(1){c[R+76+(S+256<<2)>>2]=_+((S<<8)-36864);X=Y+1&65535;if((X&65535)>159){al=144;am=144;break}else{Y=X;S=X&65535}}while(1){S=_+((am<<8)-36864)|0;c[R+76+(am+512<<2)>>2]=S;c[R+76+(am+768<<2)>>2]=S;S=al+1&65535;if((S&65535)>159){break}else{al=S;am=S&65535}}_=c[3527322]|0;c[R+716>>2]=_;S=_+256|0;c[R+720>>2]=S;Y=_+512|0;c[R+724>>2]=Y;X=_+768|0;c[R+728>>2]=X;Z=_+1024|0;c[R+732>>2]=Z;$=_+1280|0;c[R+736>>2]=$;aa=_+1536|0;c[R+740>>2]=aa;ab=_+1792|0;c[R+744>>2]=ab;c[R+1740>>2]=_;c[R+1744>>2]=S;c[R+1748>>2]=Y;c[R+1752>>2]=X;c[R+1756>>2]=Z;c[R+1760>>2]=$;c[R+1764>>2]=aa;c[R+1768>>2]=ab;c[R+2764>>2]=_;c[R+3788>>2]=_;c[R+2768>>2]=S;c[R+3792>>2]=S;c[R+2772>>2]=Y;c[R+3796>>2]=Y;c[R+2776>>2]=X;c[R+3800>>2]=X;c[R+2780>>2]=Z;c[R+3804>>2]=Z;c[R+2784>>2]=$;c[R+3808>>2]=$;c[R+2788>>2]=aa;c[R+3812>>2]=aa;c[R+2792>>2]=ab;c[R+3816>>2]=ab;c[R+4180>>2]=2304;c[R+4184>>2]=966;if(!Q){ab=R;gGC(ab|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=T;c[2417276]=W;c[1836236]=-1;c[3528554]=-1;c[2113160]=1;ab=gGq(3148)|0;aa=ab;c[2433592]=aa;if((ab|0)!=0){gGz(ab|0,0,3148);c[ab+3120>>2]=3128;c[ab+3124>>2]=1840;c[ab+3128>>2]=136;c[ab+3132>>2]=1902;c[2432840]=0;$=0;do{c[aa+48+($<<2)>>2]=0;$=$+1|0;}while(($|0)<768);c[2113158]=0;c[2415198]=0;$=c[2427044]|0;c[9681616+($<<3)>>2]=809272;c[9681620+($<<3)>>2]=0;c[2427044]=$+1}c[3528554]=0;f43(ab);$=c[3528554]|0;aa=9731360+($<<2)|0;W=c[aa>>2]|0;c[2113158]=W;T=c[3527416]|0;R=c[2433592]|0;c[R+($*3148|0)+304>>2]=T;c[R+($*3148|0)+1328>>2]=T;c[R+($*3148|0)+2352>>2]=T;Q=T+256|0;c[R+($*3148|0)+308>>2]=Q;c[R+($*3148|0)+1332>>2]=Q;c[R+($*3148|0)+2356>>2]=Q;Q=T+512|0;c[R+($*3148|0)+312>>2]=Q;c[R+($*3148|0)+1336>>2]=Q;c[R+($*3148|0)+2360>>2]=Q;Q=T+768|0;c[R+($*3148|0)+316>>2]=Q;c[R+($*3148|0)+1340>>2]=Q;c[R+($*3148|0)+2364>>2]=Q;Q=T+1024|0;c[R+($*3148|0)+320>>2]=Q;c[R+($*3148|0)+1344>>2]=Q;c[R+($*3148|0)+2368>>2]=Q;Q=T+1280|0;c[R+($*3148|0)+324>>2]=Q;c[R+($*3148|0)+1348>>2]=Q;c[R+($*3148|0)+2372>>2]=Q;Q=T+1536|0;c[R+($*3148|0)+328>>2]=Q;c[R+($*3148|0)+1352>>2]=Q;c[R+($*3148|0)+2376>>2]=Q;Q=T+1792|0;c[R+($*3148|0)+332>>2]=Q;c[R+($*3148|0)+1356>>2]=Q;c[R+($*3148|0)+2380>>2]=Q;Q=c[3527322]|0;c[R+($*3148|0)+432>>2]=Q;c[R+($*3148|0)+1456>>2]=Q;c[R+($*3148|0)+2480>>2]=Q;T=Q+256|0;c[R+($*3148|0)+436>>2]=T;c[R+($*3148|0)+1460>>2]=T;c[R+($*3148|0)+2484>>2]=T;T=Q+512|0;c[R+($*3148|0)+440>>2]=T;c[R+($*3148|0)+1464>>2]=T;c[R+($*3148|0)+2488>>2]=T;T=Q+768|0;c[R+($*3148|0)+444>>2]=T;c[R+($*3148|0)+1468>>2]=T;c[R+($*3148|0)+2492>>2]=T;T=Q+1024|0;c[R+($*3148|0)+448>>2]=T;c[R+($*3148|0)+1472>>2]=T;c[R+($*3148|0)+2496>>2]=T;T=Q+1280|0;c[R+($*3148|0)+452>>2]=T;c[R+($*3148|0)+1476>>2]=T;c[R+($*3148|0)+2500>>2]=T;T=Q+1536|0;c[R+($*3148|0)+456>>2]=T;c[R+($*3148|0)+1480>>2]=T;c[R+($*3148|0)+2504>>2]=T;T=Q+1792|0;c[R+($*3148|0)+460>>2]=T;c[R+($*3148|0)+1484>>2]=T;c[R+($*3148|0)+2508>>2]=T;T=c[3527402]|0;Q=224;Z=224;while(1){c[R+($*3148|0)+48+(Z<<2)>>2]=T+(Z<<8);X=Q+1&65535;if((X&65535)>255){break}else{Q=X;Z=X&65535}}Z=c[2438786]|0;Q=224;T=224;while(1){c[R+($*3148|0)+48+(T+512<<2)>>2]=Z+(T<<8);ab=Q+1&65535;if((ab&65535)>255){break}else{Q=ab;T=ab&65535}}c[R+($*3148|0)+3120>>2]=1882;c[R+($*3148|0)+3124>>2]=1108;T=R+($*3148|0)|0;if((T|0)!=0){Q=T;gGC(Q|0,9660752,48)|0}c[aa>>2]=W;c[3528554]=-1;fwR(1);Q=c[2439331]|0;T=(Q|0)==0;if(!T){Z=Q;gGC(9706056,Z|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];Z=c[3528485]|0;c[2076596]=Z;ab=c[2417277]|0;c[3541536]=ab;c[1836236]=1;X=c[3529218]|0;Y=0;S=0;while(1){c[Q+76+(S<<2)>>2]=X+(S<<8);_=Y+1&65535;if((_&65535)>95){an=0;ao=0;break}else{Y=_;S=_&65535}}while(1){S=X+(ao<<8)|0;c[Q+76+(ao+512<<2)>>2]=S;c[Q+76+(ao+768<<2)>>2]=S;S=an+1&65535;if((S&65535)>95){break}else{an=S;ao=S&65535}}X=c[3529306]|0;c[Q+460>>2]=X;S=X+256|0;c[Q+464>>2]=S;Y=X+512|0;c[Q+468>>2]=Y;W=X+768|0;c[Q+472>>2]=W;c[Q+1484>>2]=X;c[Q+1488>>2]=S;c[Q+1492>>2]=Y;c[Q+1496>>2]=W;c[Q+2508>>2]=X;c[Q+3532>>2]=X;c[Q+2512>>2]=S;c[Q+3536>>2]=S;c[Q+2516>>2]=Y;c[Q+3540>>2]=Y;c[Q+2520>>2]=W;c[Q+3544>>2]=W;c[Q+4180>>2]=1184;c[Q+4176>>2]=3342;c[Q+4172>>2]=812;if(!T){W=Q;gGC(W|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=Z;c[2417277]=ab;c[1836236]=-1;W=a[9680]|0?32e3:0;c[3542220]=11200;Y=c[2113008]|0;if((Y|0)==0){gGz(14168888,0,252);c[3542223]=W;gGz(14168896,0,16);c[3542234]=~~((+(W|0)*32768.0*8.0+894886.0)/1789773.0);S=31;ap=32767.0;while(1){c[14169012+(S<<2)>>2]=~~(ap+.5);X=S-1|0;if((X|0)>0){S=X;ap=ap/1.188502227}else{break}}c[3542253]=0;h[1771269]=1.0;h[1771270]=1.0;h[1771271]=1.0;c[3542574]=3;c[3542575]=3;c[3542576]=3;mB(0);S=(c[2113008]|0)+1|0;c[2113008]=S;aq=S;ar=a[9680]|0?32e3:0}else{aq=Y;ar=W}c[3542220]=11200;if((aq|0)==1){gGz(14169140,0,252);c[3542286]=ar;gGz(14169148,0,16);c[3542297]=~~((+(ar|0)*32768.0*8.0+894886.0)/1789773.0);S=31;ap=32767.0;while(1){c[14169264+(S<<2)>>2]=~~(ap+.5);ab=S-1|0;if((ab|0)>0){S=ab;ap=ap/1.188502227}else{break}}c[3542316]=0;h[1771272]=1.0;h[1771273]=1.0;h[1771274]=1.0;c[3542577]=3;c[3542578]=3;c[3542579]=3;mB(1);S=(c[2113008]|0)+1|0;c[2113008]=S;as=S;at=a[9680]|0?32e3:0}else{as=aq;at=ar}c[3542220]=11200;if((as|0)==2){gGz(14169392,0,252);c[3542349]=at;c[3542350]=76;c[3542351]=0;c[3542352]=0;c[3542353]=0;c[3542360]=~~((+(at|0)*32768.0*8.0+894886.0)/1789773.0);S=31;ap=32767.0;while(1){c[14169516+(S<<2)>>2]=~~(ap+.5);W=S-1|0;if((W|0)>0){S=W;ap=ap/1.188502227}else{break}}c[3542379]=0;h[1771275]=1.0;h[1771276]=1.0;h[1771277]=1.0;c[3542580]=3;c[3542581]=3;c[3542582]=3;mB(2);S=(c[2113008]|0)+1|0;c[2113008]=S;au=S;av=a[9680]|0?32e3:0}else{au=as;av=at}c[3542220]=11200;if((au|0)==3){gGz(14169644,0,252);c[3542412]=av;gGz(14169652,0,16);c[3542423]=~~((+(av|0)*32768.0*8.0+894886.0)/1789773.0);S=31;ap=32767.0;while(1){c[14169768+(S<<2)>>2]=~~(ap+.5);W=S-1|0;if((W|0)>0){S=W;ap=ap/1.188502227}else{break}}c[3542442]=0;h[1771278]=1.0;h[1771279]=1.0;h[1771280]=1.0;c[3542583]=3;c[3542584]=3;c[3542585]=3;mB(3);S=(c[2113008]|0)+1|0;c[2113008]=S;aw=S;ax=a[9680]|0?32e3:0}else{aw=au;ax=av}c[3542220]=11200;if((aw|0)==4){gGz(14169896,0,252);c[3542475]=ax;gGz(14169904,0,16);c[3542486]=~~((+(ax|0)*32768.0*8.0+894886.0)/1789773.0);S=31;ap=32767.0;while(1){c[14170020+(S<<2)>>2]=~~(ap+.5);W=S-1|0;if((W|0)>0){S=W;ap=ap/1.188502227}else{break}}c[3542505]=0;h[1771281]=1.0;h[1771282]=1.0;h[1771283]=1.0;c[3542586]=3;c[3542587]=3;c[3542588]=3;mB(4);c[2113008]=(c[2113008]|0)+1}h[1771269]=.25;c[3542574]=3;h[1771270]=.25;c[3542575]=3;h[1771271]=.25;c[3542576]=3;h[1771272]=.25;c[3542577]=3;h[1771273]=.25;c[3542578]=3;h[1771274]=.25;c[3542579]=3;h[1771275]=.25;c[3542580]=3;h[1771276]=.25;c[3542581]=3;h[1771277]=.25;c[3542582]=3;h[1771278]=.25;c[3542583]=3;h[1771279]=.25;c[3542584]=3;h[1771280]=.25;c[3542585]=3;h[1771281]=.25;c[3542586]=3;h[1771282]=.25;c[3542587]=3;h[1771283]=.25;c[3542588]=3;S=c[642608+(c[2436]<<2)>>2]|0;W=c[S+128>>2]|0;if((c[S+52>>2]&4|0)==0){c[2113068]=W;Y=c[S+132>>2]|0;c[2113070]=Y;c[2443814]=W;c[2440436]=Y;ay=W;az=Y}else{c[2113070]=W;Y=c[S+132>>2]|0;c[2113068]=Y;c[2440436]=W;c[2443814]=Y;ay=Y;az=W}W=ag(ay<<1,az)|0;Y=gGq(W)|0;c[2112926]=Y;if((Y|0)!=0){gGz(Y|0,0,W|0)}bgv();P=0;i=e;return P|0}}while(0);c[2415104]=0;P=1;i=e;return P|0}function bgk(){var a=0,b=0,d=0,e=0;c[2113070]=0;c[2113068]=0;a=c[2112926]|0;if((a|0)!=0){gGr(a);c[2112926]=0}fwZ();c[2113160]=0;a=c[2433592]|0;if((a|0)!=0){gGr(a);c[2433592]=0}c[2113008]=0;c[2076598]=0;c[2383582]=0;a=c[2415104]|0;b=0;while(1){if((b|0)>=1024){d=64135;break}e=9638528+(b<<2)|0;if((c[e>>2]|0)==(a|0)){break}else{b=b+1|0}}if((d|0)==64135){c[2415104]=0;return 0}gGr(a);c[e>>2]=0;c[2415104]=0;return 0}function bgl(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;if((a[9625032]|0)!=0){bgv()}b[4775492]=-1;e=(a[9632160]|-2)^1^a[9632161]<<1&2^a[9632162]<<2&4^a[9632163]<<3&8^a[9632164]<<4&16;f=(a[9630080]|-2)^1^a[9630081]<<1&2^a[9630082]<<2&4^a[9630083]<<3&8^a[9630084]<<4&16;a[9550984]=(a[9634400]|-2)^1^a[9634401]<<1&2^a[9634402]<<2&4^a[9634403]<<3&8^a[9634404]<<4&16;a[9550985]=e;a[9550986]=f;f=c[2385548]|0;if((f|0)>0){gGz(9752472,0,((f|0)>1?f<<2:4)|0)}c[2433530]=0;bgm()|0;f=0;e=0;g=0;h=0;while(1){c[2388526]=h;i=c[2439330]|0;if((i|0)!=0){j=i;gGC(9706056,j|0,76)|0}b[4853030]=c[2426515]&65535;j=c[2438118]|0;c[2433530]=j;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;k=h+1|0;l=((k*51200|0|0)/256|0)-g|0;do{if((l|0)<1){m=0}else{if((a[i+4188|0]|0)==0){n=gfc(l)|0;c[2433530]=(c[2433530]|0)+n;m=n;break}else{c[2433530]=j+l;m=l;break}}}while(0);l=m+g|0;j=(h|0)==255;do{if(j){if((a[c[2430480]|0]|0)==0){break}if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12}}while(0);c[3528554]=0;f43(c[2433592]|0);c[2113158]=c[9731360+(c[3528554]<<2)>>2];i=f45(((k*33333|0|0)/256|0)-e|0)|0;c[2113158]=(c[2113158]|0)+i;n=i+e|0;do{if(j){if((a[c[2430478]|0]|0)==0){break}f44(0);f45(0)|0;a[9660786]=0;f45(0)|0}}while(0);j=c[3528554]|0;i=(c[2433592]|0)+(j*3148|0)|0;if((i|0)!=0){o=i;gGC(o|0,9660752,48)|0}c[9731360+(j<<2)>>2]=c[2113158];c[3528554]=-1;j=c[1836236]|0;o=c[9757320+(j<<2)>>2]|0;if((o|0)!=0){i=o;gGC(i|0,9706056,76)|0}c[9752472+(j<<2)>>2]=c[2433530];c[14113936+(j<<2)>>2]=c[2076596];c[9669104+(j<<2)>>2]=c[3541536];c[1836236]=-1;j=c[2439331]|0;if((j|0)!=0){i=j;gGC(9706056,i|0,76)|0}b[4853030]=c[2426515]&65535;i=c[2438119]|0;c[2433530]=i;c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;o=((k*59659|0|0)/256|0)-f|0;do{if((o|0)<1){p=0;q=1;r=j;s=i}else{if((a[j+4188|0]|0)==0){t=gfc(o)|0;u=(c[2433530]|0)+t|0;c[2433530]=u;v=c[1836236]|0;p=t;q=v;r=c[9757320+(v<<2)>>2]|0;s=u;break}else{u=i+o|0;c[2433530]=u;p=o;q=1;r=j;s=u;break}}}while(0);j=p+f|0;if((r|0)!=0){o=r;gGC(o|0,9706056,76)|0}c[9752472+(q<<2)>>2]=s;c[14113936+(q<<2)>>2]=c[2076596];c[9669104+(q<<2)>>2]=c[3541536];c[1836236]=-1;o=c[2388526]|0;i=o-16|0;u=o+16|0;if((i|0)>-1){v=c[2386530]|0;t=c[3530714]|0;w=c[3530948]|0;x=(i|0)<(c[2113070]|0);y=c[2113068]|0;z=ag(y,i)|0;A=c[2112926]|0;B=188;do{C=d[v+B|0]|0;D=241-(d[v+(B|3)|0]|0)|0;L82945:do{if((D|0)>(i|0)&(D|0)<(u|0)){E=d[v+(B|1)|0]|0;F=d[v+(B|2)|0]|0;G=(E&1|0)!=0?t:w;if(!x){break}H=o-D|0;if(H>>>0>15){break}I=(((F&128|0)==0?0:120)^H<<3)+((F<<2&128|E>>>1)<<7)|0;E=F<<4&240;H=(F&64|0)!=0?0:7;F=0;J=C;while(1){K=a[G+(I+(F^H))|0]|0;if(!((J|0)>=(y|0)|K<<24>>24==0)){b[A+(z+J<<1)>>1]=(K&255|E)&65535}K=F+1|0;if((K|0)>=8){break L82945}F=K;J=J+1|0}}}while(0);B=B-4|0;}while((B|0)>-1)}if((k|0)<256){f=j;e=n;g=l;h=k}else{break}}h=c[2112964]|0;if((h|0)!=0){mF(9756632,h,a[9688]|0?534:0,0)}if((c[2112968]|0)==0){return 0}R8(c[3530190]|0);return 0}function bgm(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;if((a[9548024]|0)!=0){b=c[2407008]|0;e=c[3530190]|0;f=0;do{g=c[b+(f<<2)>>2]|0;c[e+(f<<2)>>2]=g>>8<<3&2016|g>>>3&31|g>>16<<8&63488;f=f+1|0;}while((f|0)<320)}f=c[2112926]|0;gGz(f|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);e=c[2387892]|0;b=c[2386274]|0;g=c[3528774]|0;h=c[3530490]|0;i=64;do{j=i<<3&248;k=i>>5<<3;l=d[e+i|0]|0;m=l<<3&256|d[b+i|0];n=l&15;o=l>>>6&1;p=l>>>7;if((a[g]|0)==0){q=p;r=o;s=j;t=k}else{q=p^1;r=o^1;s=j^248;t=k^248}k=t-16|0;j=(r|0)!=0;do{if((q|0)==0){if(j){Ss(f,m,s,k,n,2,0,256,h);break}else{Sq(f,m,s,k,n,2,0,256,h);break}}else{if(j){Sw(f,m,s,k,n,2,0,256,h);break}else{Su(f,m,s,k,n,2,0,256,h);break}}}while(0);i=i+1|0;}while((i|0)<960);return 0}function bgn(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;e=i;i=i+128|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;l=e+80|0;m=e+96|0;n=e+112|0;o=(d|0)==0;if(!o){c[d>>2]=169732}if((b&96|0)!=0){gGz(n|0,0,12);p=c[2414812]|0;c[n>>2]=p;c[n+4>>2]=(c[2411872]|0)-p;c[n+12>>2]=196728;p=c[2076592]|0;gj[p&4095](n)|0}if((b&64|0)==0){i=e;return 0}fw$(b);b=m|0;if((c[2113160]|0)>0){n=m+7|0;m=l|0;p=l+4|0;q=l+12|0;r=k;s=k|0;t=k+4|0;u=k+12|0;v=j;w=j|0;x=j+4|0;y=j+12|0;z=h;A=h|0;B=h+4|0;C=h+12|0;D=0;do{E=c[2433592]|0;F=E+(D*3148|0)+40|0;G=c[F>>2]|0;gGC(b|0,614752,9)|0;a[n]=D+48&255;c[m>>2]=E+(D*3148|0);c[p>>2]=48;c[q>>2]=b;gj[c[2076592]&4095](l)|0;gGz(r|0,0,12);c[s>>2]=E+(D*3148|0)+3136;c[t>>2]=4;c[u>>2]=165288;gj[c[2076592]&4095](k)|0;gGz(v|0,0,12);c[w>>2]=E+(D*3148|0)+3140;c[x>>2]=4;c[y>>2]=501592;gj[c[2076592]&4095](j)|0;gGz(z|0,0,12);c[A>>2]=E+(D*3148|0)+3144;c[B>>2]=4;c[C>>2]=386080;gj[c[2076592]&4095](h)|0;c[F>>2]=G;D=D+1|0;}while((D|0)<(c[2113160]|0))}D=g|0;do{if(!o){if((c[d>>2]|0)>=169110){break}c[d>>2]=169110}}while(0);if((c[2113008]|0)<=0){i=e;return 0}d=f|0;o=f+4|0;g=f+8|0;h=f+12|0;C=0;do{cC(D|0,531144,(B=i,i=i+8|0,c[B>>2]=C,B)|0)|0;i=B;c[d>>2]=14168888+(C*252|0);c[o>>2]=252;c[g>>2]=0;c[h>>2]=D;gj[c[2076592]&4095](f)|0;C=C+1|0;}while((C|0)<(c[2113008]|0));i=e;return 0}function bgo(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2782428+(b*112|0)>>2];c[a+104>>2]=c[2782432+(b*112|0)>>2];c[a+108>>2]=c[2782436+(b*112|0)>>2];d=0;return d|0}function bgp(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=2782328+(b*112|0);e=0;return e|0}function bgq(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>63){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3877232+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function bgr(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4678188+(b*112|0)>>2];c[a+104>>2]=c[4678192+(b*112|0)>>2];c[a+108>>2]=c[4678196+(b*112|0)>>2];d=0;return d|0}function bgs(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=4678088+(b*112|0);e=0;return e|0}function bgt(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6457980+(b*112|0)>>2];c[a+104>>2]=c[6457984+(b*112|0)>>2];c[a+108>>2]=c[6457988+(b*112|0)>>2];d=0;return d|0}function bgu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=6457880+(b*112|0);e=0;return e|0}function bgv(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;a[9625032]=0;e=c[2414812]|0;gGz(e|0,0,(c[2411872]|0)-e|0);e=c[2439330]|0;f=(e|0)==0;if(!f){g=e;gGC(9706056,g|0,76)|0}g=c[2438118]|0;c[2433530]=g;h=c[3528484]|0;c[2076596]=h;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);if(!f){f=e;gGC(f|0,9706056,76)|0}c[2438118]=g;c[3528484]=h;c[2417276]=i;c[1836236]=-1;c[3528554]=0;f43(c[2433592]|0);i=c[3528554]|0;c[2113158]=c[9731360+(i<<2)>>2];a[9660796]=0;a[9660797]=0;a[9660786]=0;a[9660787]=0;c[2415191]=0;a[9660784]=a[9660784]|80;h=c[2433592]|0;g=c[h+(i*3148|0)+1068>>2]|0;do{if((g|0)==0){f=c[h+(i*3148|0)+3120>>2]|0;if((f|0)==0){j=0;k=0;l=i;m=h;break}e=gj[f&4095](-2)|0;f=c[3528554]|0;n=c[2433592]|0;o=c[n+(f*3148|0)+1068>>2]|0;p=(e&255)<<8;if((o|0)!=0){q=o;r=p;s=f;t=n;u=64271;break}o=c[n+(f*3148|0)+3120>>2]|0;if((o|0)==0){j=0;k=p;l=f;m=n;break}n=gj[o&4095](-1)|0;j=n;k=p;l=c[3528554]|0;m=c[2433592]|0}else{q=g;r=(d[g+254|0]|0)<<8;s=i;t=h;u=64271}}while(0);if((u|0)==64271){j=a[q+255|0]|0;k=r;l=s;m=t}t=j&255|k;c[2415188]=t;b[4830376]=t&65535;t=m+(l*3148|0)|0;if((t|0)!=0){m=t;gGC(m|0,9660752,48)|0}c[9731360+(l<<2)>>2]=c[2113158];c[3528554]=-1;l=c[2439331]|0;m=(l|0)==0;if(!m){t=l;gGC(9706056,t|0,76)|0}t=c[2438119]|0;c[2433530]=t;k=c[3528485]|0;c[2076596]=k;j=c[2417277]|0;c[3541536]=j;c[1836236]=1;gGz(9706056,0,76);if(m){c[2438119]=t;c[3528485]=k;c[2417277]=j;c[1836236]=-1;mB(0);mB(1);mB(2);mB(3);mB(4);return}m=l;gGC(m|0,9706056,76)|0;c[2438119]=t;c[3528485]=k;c[2417277]=j;c[1836236]=-1;mB(0);mB(1);mB(2);mB(3);mB(4);return}function bgw(){var b=0,d=0,e=0,f=0;b=c[2415104]|0;c[3529262]=b;c[3529218]=b+65536;c[3527402]=b+131072;c[2438786]=b+196608;c[3527446]=b+262144;c[3530948]=b+266240;c[3530714]=b+331776;c[3530490]=b+397312;c[3531050]=b+430080;c[2407008]=b+430848;c[3530190]=b+432128;c[2439158]=b+433408;d=a[9688]|0?1068:0;e=d+433408|0;c[2439159]=b+e;f=e+d|0;c[2439160]=b+f;e=f+d|0;c[2439161]=b+e;f=e+d|0;c[2439162]=b+f;e=f+d|0;c[2439163]=b+e;f=e+d|0;c[2439164]=b+f;e=f+d|0;c[2439165]=b+e;f=e+d|0;c[2439166]=b+f;e=f+d|0;c[2439167]=b+e;f=e+d|0;c[2439168]=b+f;e=f+d|0;c[2439169]=b+e;f=e+d|0;c[2439170]=b+f;e=f+d|0;c[2439171]=b+e;f=e+d|0;c[2439172]=b+f;e=f+d|0;c[2415158]=b+e;d=b+(e+131072)|0;c[2414812]=d;c[3528774]=d;c[3528372]=b+(e+131073);c[2443732]=b+(e+131074);c[2430480]=b+(e+131075);c[2430478]=b+(e+131076);c[3527322]=b+(e+131077);c[2387892]=b+(e+133125);c[2386274]=b+(e+134149);c[3529350]=b+(e+135173);c[3529306]=b+(e+139269);c[3527416]=b+(e+140293);d=b+(e+142341)|0;c[2386530]=b+(e+140357);c[2411872]=d;c[2414422]=d;return}function bgx(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;f=b&65535;switch(f|0){case 16256:{g=e&255;a[c[2443944]|0]=e;h=g<<12;if((g&16|0)==0){i=h&57344|65536}else{i=h&24576|131072}h=c[3527400]|0;g=c[3528554]|0;j=c[2433592]|0;k=i-24576|0;i=96;l=96;while(1){m=h+(k+(l<<8))|0;c[j+(g*3148|0)+48+(l<<2)>>2]=m;c[j+(g*3148|0)+48+(l+512<<2)>>2]=m;m=i+1&65535;if((m&65535)>127){break}else{i=m;l=m&65535}}return};case 16320:{a[9706117]=1;return};case 16304:{a[c[3528370]|0]=e;return};case 16288:{return};case 16272:{l=e&255;c[3541230]=l&4;c[2432770]=l&8^8;c[2394734]=l&176;bgM(e&-128,e&48);do{if((l&64|0)!=0){if((c[3531218]&64|0)!=0){break}i=c[2387304]|0;g=a[i+1|0]|0;j=g&255;k=a[i+2|0]|0;h=k&255;L83110:do{if(k<<24>>24==1){m=d[i+3|0]<<8|d[i+4|0];n=d[i+5|0]<<8|d[i+6|0];o=d[i+7|0]<<8|d[i+8|0];p=d[i+9|0]<<8|d[i+10|0];q=d[i+11|0]<<8|d[i+12|0];r=d[i+13|0]<<8|d[i+14|0];if(g<<24>>24==12){s=16;while(1){t=d[i+(s+3)|0]<<8|d[i+(s+4)|0];u=d[i+(s+7)|0]<<8|d[i+(s+8)|0];v=d[i+(s+9)|0]<<8|d[i+(s+10)|0];w=d[i+(s+11)|0]<<8|d[i+(s+12)|0];x=(t|0)==88&(u|0)==4&(w|0)==16&(v|0)==48?v:w;w=m-(d[i+(s|1)|0]<<8|d[i+(s+2)|0])|0;do{if((((w|0)>-1?w:-w|0)|0)<(t+n|0)){y=o-(d[i+(s+5)|0]<<8|d[i+(s+6)|0])|0;if((((y|0)>-1?y:-y|0)|0)>=(u+p|0)){z=64297;break}y=q-v|0;if((((y|0)>-1?y:-y|0)|0)>=(x+r|0)){z=64297;break}a[i+15|0]=0;a[i+(s+13)|0]=0}else{z=64297}}while(0);if((z|0)==64297){z=0;a[i+(s+13)|0]=1}s=s+14|0;if((s|0)>=898){break L83110}}}else{A=16}do{L83124:do{if((a[i+A|0]|0)!=0){s=d[i+(A+3)|0]<<8|d[i+(A+4)|0];x=d[i+(A+7)|0]<<8|d[i+(A+8)|0];v=d[i+(A+9)|0]<<8|d[i+(A+10)|0];u=d[i+(A+11)|0]<<8|d[i+(A+12)|0];t=(s|0)==88&(x|0)==4&(u|0)==16&(v|0)==48?v:u;u=m-(d[i+(A|1)|0]<<8|d[i+(A+2)|0])|0;do{if((((u|0)>-1?u:-u|0)|0)<(s+n|0)){w=o-(d[i+(A+5)|0]<<8|d[i+(A+6)|0])|0;if((((w|0)>-1?w:-w|0)|0)>=(x+p|0)){break}w=q-v|0;if((((w|0)>-1?w:-w|0)|0)>=(t+r|0)){break}a[i+15|0]=0;a[i+(A+13)|0]=0;break L83124}}while(0);a[i+(A+13)|0]=1}}while(0);A=A+14|0;}while((A|0)<898)}else{if((k&255)<=1){break}r=d[i]<<8|j;q=d[i+3|0]|h<<8;p=(q|0)==0?25600:q;q=r>>>0>64?128:r<<1;r=q+4|0;if(r>>>0>4){o=4;do{n=i+o|0;m=i+(o|1)|0;t=((d[n]<<8|d[m])<<8>>>0)/(p>>>0)|0;a[n]=t>>>8&255;a[m]=t&255;o=o+2|0;}while((o|0)<(r|0))}gGz(i+r|0,0,2044-q|0)}}while(0);f44(1);i=f45(105)|0;c[2113158]=(c[2113158]|0)+i;a[9660787]=0}}while(0);c[3531218]=l;return};default:{if((b-8192&65535)>=16384){return}blF(f-8192|0,e&255);return}}}function bgy(b){b=b|0;var c=0,d=0;c=b&65535;L83142:do{switch(c|0){case 16336:{d=a[9635698]&-16|a[9550978]&15;break};case 16339:{d=a[9635696]|0;break};case 16352:{d=a[9635697]|0;break};case 16338:{d=a[9550977]|0;break};case 16337:{d=a[9550976]|0;break};default:{if((b-8192&65535)>=16384){d=0;break L83142}d=blE(c-8192|0)|0}}}while(0);return d|0}function bgz(b,e){b=b|0;e=e|0;var f=0;f=b&65535;b=f&65520;if((b|0)==40960){TI(0,f&15,e&255);return}else if((b|0)==45056){TI(1,f&15,e&255);return}else{if((f|0)==36864){b=e&255;c[2420315]=b<<17&393216;c[2420316]=b>>>2<<17&393216;c[2424878]=9681296;c[2420331]=b>>>4<<17&393216;c[2420332]=b>>>6<<17;return}else if((f|0)==49152|(f|0)==49153){b=c[3540984]|0;if((f&1|0)==0){a[b+5885|0]=e;return}f=c[b+5876>>2]|0;if((f|0)!=0){gg[f&4095](c[b+5880>>2]|0,0)}lH(b,d[b+5885|0]|0,e&255);return}else{return}}}function bgA(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;e=b&65535;b=e&65520;if((b|0)==40960){f=e&15;c[2424878]=9681232;c[2426622]=9622928;if(!((f|0)==11|(f|0)==5)){g=0;return g|0}h=(f>>>0)/6|0;f=h*6|0;i=(d[f+9681280|0]|0)<<16&65536|(d[f+9681279|0]|0)<<8|(d[f+9681278|0]|0)|c[9681260+(h<<2)>>2];c[9681244+(h<<2)>>2]=i;if(i>>>0>=(c[2405735]|0)>>>0){g=0;return g|0}c[9681268+(h<<2)>>2]=1;c[9681236+(h<<2)>>2]=0;g=0;return g|0}else if((b|0)==45056){b=e&15;c[2424878]=9681296;c[2426622]=9622976;if(!((b|0)==11|(b|0)==5)){g=0;return g|0}h=(b>>>0)/6|0;b=h*6|0;i=(d[b+9681344|0]|0)<<16&65536|(d[b+9681343|0]|0)<<8|(d[b+9681342|0]|0)|c[9681324+(h<<2)>>2];c[9681308+(h<<2)>>2]=i;if(i>>>0>=(c[2405747]|0)>>>0){g=0;return g|0}c[9681332+(h<<2)>>2]=1;c[9681300+(h<<2)>>2]=0;g=0;return g|0}else{if((e|0)==49152|(e|0)==49153){g=lx(c[3540984]|0,e&1)|0|6;return g|0}else if((e|0)==53248){a[9706117]=0;g=a[c[3528370]|0]|0;return g|0}else{g=0;return g|0}}return 0}function bgB(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7328372+(b*112|0)>>2];c[a+104>>2]=c[7328376+(b*112|0)>>2];c[a+108>>2]=c[7328380+(b*112|0)>>2];d=0;return d|0}function bgC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=7328272+(b*112|0);e=0;return e|0}function bgD(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6688168+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function bgE(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>62){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7369936+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function bgF(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0;e=i;i=i+1080|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;c[2415102]=0;c[3527400]=0;c[2386008]=196608;c[3530946]=262144;c[3530712]=786432;c[2439912]=1835008;c[2439876]=2883584;c[3529778]=4980736;c[3529732]=5242880;c[3530188]=5505024;c[2414810]=5509120;c[2387304]=5509120;c[3531092]=5511168;c[2387284]=5513216;c[3527414]=5515264;c[2386160]=5521408;c[3528370]=5523456;c[2443944]=5523457;c[2411870]=5523460;z=0;while(1){if((z|0)>=1024){break}A=9638528+(z<<2)|0;if((c[A>>2]|0)==0){B=64400;break}else{z=z+1|0}}do{if((B|0)==64400){z=gGq(5523460)|0;c[A>>2]=z;if((z|0)==0){break}c[2415102]=z;gGz(z|0,0,5523460);c[3527400]=z;c[2386008]=z+196608;c[3530946]=z+262144;c[3530712]=z+786432;c[2439912]=z+1835008;c[2439876]=z+2883584;c[3529778]=z+4980736;c[3529732]=z+5242880;c[3530188]=z+5505024;C=z+5509120|0;c[2414810]=C;c[2387304]=C;c[3531092]=z+5511168;c[2387284]=z+5513216;c[3527414]=z+5515264;c[2386160]=z+5521408;c[3528370]=z+5523456;c[2443944]=z+5523457;C=z+5523460|0;c[2411870]=C;c[2414420]=C;C=z+65536|0;if((c[3542200]|0)==0){D=1;i=e;return D|0}z=x+108|0;c[z>>2]=0;E=x+100|0;c[E>>2]=0;F=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[F&16383](x,0)|0;do{if((c[z>>2]|0)!=0){F=c[E>>2]|0;c[y>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](y,0,0)|0;if((F|0)<1){D=1;i=e;return D|0}if((gzL(C,0,0)|0)==0){break}else{D=1}i=e;return D|0}}while(0);C=(c[3527400]|0)+131072|0;if((c[3542200]|0)==0){D=1;i=e;return D|0}E=v+108|0;c[E>>2]=0;z=v+100|0;c[z>>2]=0;F=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[F&16383](v,1)|0;do{if((c[E>>2]|0)!=0){F=c[z>>2]|0;c[w>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](w,1,0)|0;if((F|0)<1){D=1;i=e;return D|0}if((gzL(C,0,1)|0)==0){break}else{D=1}i=e;return D|0}}while(0);C=c[3527400]|0;z=C+32768|0;E=C+163840|0;gGC(z|0,E|0,32768)|0;E=c[2386008]|0;if((c[3542200]|0)==0){D=1;i=e;return D|0}z=t+108|0;c[z>>2]=0;C=t+100|0;c[C>>2]=0;F=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[F&16383](t,2)|0;do{if((c[z>>2]|0)!=0){F=c[C>>2]|0;c[u>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](u,2,0)|0;if((F|0)<1){D=1;i=e;return D|0}if((gzL(E,0,2)|0)==0){break}else{D=1}i=e;return D|0}}while(0);E=c[3530946]|0;if((c[3542200]|0)==0){D=1;i=e;return D|0}C=r+108|0;c[C>>2]=0;z=r+100|0;c[z>>2]=0;F=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[F&16383](r,3)|0;do{if((c[C>>2]|0)!=0){F=c[z>>2]|0;c[s>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](s,3,0)|0;if((F|0)<1){D=1;i=e;return D|0}if((gzL(E,0,3)|0)==0){break}else{D=1}i=e;return D|0}}while(0);E=(c[3530946]|0)+262144|0;if((c[3542200]|0)==0){D=1;i=e;return D|0}z=p+108|0;c[z>>2]=0;C=p+100|0;c[C>>2]=0;F=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[F&16383](p,4)|0;do{if((c[z>>2]|0)!=0){F=c[C>>2]|0;c[q>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](q,4,0)|0;if((F|0)<1){D=1;i=e;return D|0}if((gzL(E,0,4)|0)==0){break}else{D=1}i=e;return D|0}}while(0);E=c[3530712]|0;if((c[3542200]|0)==0){D=1;i=e;return D|0}C=n+108|0;c[C>>2]=0;z=n+100|0;c[z>>2]=0;F=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[F&16383](n,5)|0;do{if((c[C>>2]|0)!=0){F=c[z>>2]|0;c[o>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](o,5,0)|0;if((F|0)<1){D=1;i=e;return D|0}if((gzL(E,0,5)|0)==0){break}else{D=1}i=e;return D|0}}while(0);E=(c[3530712]|0)+524288|0;if((c[3542200]|0)==0){D=1;i=e;return D|0}z=l+108|0;c[z>>2]=0;C=l+100|0;c[C>>2]=0;F=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[F&16383](l,6)|0;do{if((c[z>>2]|0)!=0){F=c[C>>2]|0;c[m>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](m,6,0)|0;if((F|0)<1){D=1;i=e;return D|0}if((gzL(E,0,6)|0)==0){break}else{D=1}i=e;return D|0}}while(0);E=c[3529778]|0;if((c[3542200]|0)==0){D=1;i=e;return D|0}C=j+108|0;c[C>>2]=0;z=j+100|0;c[z>>2]=0;F=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[F&16383](j,7)|0;do{if((c[C>>2]|0)!=0){F=c[z>>2]|0;c[k>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](k,7,0)|0;if((F|0)<1){D=1;i=e;return D|0}if((gzL(E,0,7)|0)==0){break}else{D=1}i=e;return D|0}}while(0);E=c[3529732]|0;if((c[3542200]|0)==0){D=1;i=e;return D|0}z=f+108|0;c[z>>2]=0;C=f+100|0;c[C>>2]=0;F=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[F&16383](f,8)|0;do{if((c[z>>2]|0)!=0){F=c[C>>2]|0;c[g>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](g,8,0)|0;if((F|0)<1){D=1;i=e;return D|0}if((gzL(E,0,8)|0)==0){break}else{D=1}i=e;return D|0}}while(0);E=c[3530946]|0;blG(E,262144);C=c[3530712]|0;blG(C,524288);z=c[2439912]|0;F=0;do{G=F<<6;gGz(z+G|0,0,64);H=F<<8;I=0;do{J=1<<3-I;K=(c[611632+(I<<2)>>2]|0)+H|0;L=0;do{M=K+(c[3946808+(L<<2)>>2]|0)|0;N=(L<<3)+G|0;O=0;do{P=M+(c[6669416+(O<<2)>>2]|0)|0;if(((d[E+((P|0)/8|0)|0]|0)&128>>>((P&7)>>>0)|0)!=0){P=z+(N+O)|0;a[P]=(d[P]|0|J)&255}O=O+1|0;}while((O|0)<8);L=L+1|0;}while((L|0)<8);I=I+1|0;}while((I|0)<4);F=F+1|0;}while((F|0)<16384);F=c[2439876]|0;z=0;do{E=z<<8;gGz(F+E|0,0,256);I=z<<10;G=0;do{H=1<<3-G;L=(c[611400+(G<<2)>>2]|0)+I|0;J=0;do{K=L+(c[3946808+(J<<2)>>2]|0)|0;O=(J<<4)+E|0;N=0;do{M=K+(c[6669416+(N<<2)>>2]|0)|0;if(((d[C+((M|0)/8|0)|0]|0)&128>>>((M&7)>>>0)|0)!=0){M=F+(O+N)|0;a[M]=(d[M]|0|H)&255}N=N+1|0;}while((N|0)<16);J=J+1|0;}while((J|0)<16);G=G+1|0;}while((G|0)<4);z=z+1|0;}while((z|0)<8192);c[3528554]=-1;c[2113160]=1;z=gGq(3148)|0;F=z;c[2433592]=F;if((z|0)!=0){gGz(z|0,0,3148);c[z+3120>>2]=3128;c[z+3124>>2]=1840;c[z+3128>>2]=136;c[z+3132>>2]=1902;c[2432840]=0;C=0;do{c[F+48+(C<<2)>>2]=0;C=C+1|0;}while((C|0)<768);c[2113158]=0;c[2415198]=0;C=c[2427044]|0;c[9681616+(C<<3)>>2]=809272;c[9681620+(C<<3)>>2]=0;c[2427044]=C+1}c[3528554]=0;f43(z);C=c[3528554]|0;F=9731360+(C<<2)|0;G=c[F>>2]|0;c[2113158]=G;E=c[3527414]|0;I=c[2433592]|0;J=8;H=8;while(1){L=E+((H<<8)-2048)|0;c[I+(C*3148|0)+48+(H<<2)>>2]=L;c[I+(C*3148|0)+48+(H+256<<2)>>2]=L;c[I+(C*3148|0)+48+(H+512<<2)>>2]=L;L=J+1&65535;if((L&65535)>26){break}else{J=L;H=L&65535}}H=c[3527400]|0;J=96;E=96;while(1){z=H+((E<<8)+40960)|0;c[I+(C*3148|0)+48+(E<<2)>>2]=z;c[I+(C*3148|0)+48+(E+512<<2)>>2]=z;z=J+1&65535;if((z&65535)>127){Q=128;R=128;break}else{J=z;E=z&65535}}while(1){E=H+(R<<8)|0;c[I+(C*3148|0)+48+(R<<2)>>2]=E;c[I+(C*3148|0)+48+(R+512<<2)>>2]=E;E=Q+1&65535;if((E&65535)>255){break}else{Q=E;R=E&65535}}c[I+(C*3148|0)+3124>>2]=2210;c[I+(C*3148|0)+3120>>2]=516;H=I+(C*3148|0)|0;if((H|0)!=0){E=H;gGC(E|0,9660752,48)|0}c[F>>2]=G;c[3528554]=-1;fwR(0);E=c[2439330]|0;H=(E|0)==0;if(!H){J=E;gGC(9706056,J|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];J=c[3528484]|0;c[2076596]=J;z=c[2417276]|0;c[3541536]=z;c[1836236]=0;L=c[2386008]|0;N=0;O=0;while(1){c[E+76+(O<<2)>>2]=L+(O<<8);K=N+1&65535;if((K&65535)>127){S=0;T=0;break}else{N=K;O=K&65535}}while(1){O=L+(T<<8)|0;c[E+76+(T+512<<2)>>2]=O;c[E+76+(T+768<<2)>>2]=O;O=S+1&65535;if((O&65535)>127){break}else{S=O;T=O&65535}}L=c[2386160]|0;c[E+588>>2]=L;O=L+256|0;c[E+592>>2]=O;N=L+512|0;c[E+596>>2]=N;G=L+768|0;c[E+600>>2]=G;F=L+1024|0;c[E+604>>2]=F;C=L+1280|0;c[E+608>>2]=C;I=L+1536|0;c[E+612>>2]=I;K=L+1792|0;c[E+616>>2]=K;c[E+1612>>2]=L;c[E+1616>>2]=O;c[E+1620>>2]=N;c[E+1624>>2]=G;c[E+1628>>2]=F;c[E+1632>>2]=C;c[E+1636>>2]=I;c[E+1640>>2]=K;c[E+2636>>2]=L;c[E+3660>>2]=L;c[E+2640>>2]=O;c[E+3664>>2]=O;c[E+2644>>2]=N;c[E+3668>>2]=N;c[E+2648>>2]=G;c[E+3672>>2]=G;c[E+2652>>2]=F;c[E+3676>>2]=F;c[E+2656>>2]=C;c[E+3680>>2]=C;c[E+2660>>2]=I;c[E+3684>>2]=I;c[E+2664>>2]=K;c[E+3688>>2]=K;c[E+4184>>2]=908;c[E+4180>>2]=2506;if(!H){K=E;gGC(K|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=J;c[2417276]=z;c[1836236]=-1;K=c[3530946]|0;I=0;while(1){if((I|0)>=1024){U=0;break}V=9638528+(I<<2)|0;if((c[V>>2]|0)==0){B=64479;break}else{I=I+1|0}}do{if((B|0)==64479){I=gGq(24576)|0;c[V>>2]=I;if((I|0)==0){U=0;break}gGz(I|0,0,24576);U=I}}while(0);c[3529062]=U;c[2438700]=524287;c[3529060]=K;a[7461784]=1;I=9726816;c[I>>2]=0;c[I+4>>2]=0;I=9726800;c[I>>2]=0;c[I+4>>2]=0;c[2429638]=0;c[2437692]=80;c[2431704]=-2;c[2431700]=0;c[2431705]=-2;c[2431701]=0;c[2431706]=-2;c[2431702]=0;I=c[3530712]|0;c[2438136]=0;z=0;while(1){if((z|0)>=1024){W=0;break}X=9638528+(z<<2)|0;if((c[X>>2]|0)==0){B=64484;break}else{z=z+1|0}}do{if((B|0)==64484){z=gGq(1024)|0;c[X>>2]=z;if((z|0)==0){W=0;break}gGz(z|0,0,1024);W=z}}while(0);c[3529066]=W;c[2438702]=1048575;c[3529064]=I;a[7461792]=1;c[2437694]=102;c[2438136]=0;UL(3579545,98,2738,0);c[2438224]=3579545;c[2433522]=3416;c[2406672]=1752;c[3528468]=9362;c[2443842]=571;h[745398]=1.0;a[3203264]=1;TJ(0,c[3529778]|0,262144);c[2424878]=9681232;c[2405736]=574;h[1202869]=.2;c[2405742]=3;c[2426622]=9622928;h[1202870]=.2;c[2405743]=3;TJ(1,c[3529732]|0,262144);c[2424878]=9681296;c[2405748]=1184;h[1202875]=.2;c[2405754]=3;c[2426622]=9622976;h[1202876]=.2;c[2405755]=3;z=c[642608+(c[2436]<<2)>>2]|0;K=c[z+128>>2]|0;if((c[z+52>>2]&4|0)==0){c[2113068]=K;J=c[z+132>>2]|0;c[2113070]=J;c[2443814]=K;c[2440436]=J;Y=K;Z=J}else{c[2113070]=K;J=c[z+132>>2]|0;c[2113068]=J;c[2440436]=K;c[2443814]=J;Y=J;Z=K}K=ag(Y<<1,Z)|0;J=gGq(K)|0;c[2112926]=J;if((J|0)!=0){gGz(J|0,0,K|0)}a[9625024]=0;K=c[2414810]|0;gGz(K|0,0,(c[2411870]|0)-K|0);c[3528554]=0;f43(c[2433592]|0);K=c[3528554]|0;c[2113158]=c[9731360+(K<<2)>>2];a[9660796]=0;a[9660797]=0;a[9660786]=0;a[9660787]=0;c[2415191]=0;a[9660784]=a[9660784]|80;J=c[2433592]|0;z=c[J+(K*3148|0)+1068>>2]|0;do{if((z|0)==0){E=c[J+(K*3148|0)+3120>>2]|0;if((E|0)==0){_=0;$=0;aa=K;ab=J;break}H=gj[E&4095](-2)|0;E=c[3528554]|0;C=c[2433592]|0;F=c[C+(E*3148|0)+1068>>2]|0;G=(H&255)<<8;if((F|0)!=0){ac=F;ad=G;ae=E;af=C;B=64495;break}F=c[C+(E*3148|0)+3120>>2]|0;if((F|0)==0){_=0;$=G;aa=E;ab=C;break}C=gj[F&4095](-1)|0;_=C;$=G;aa=c[3528554]|0;ab=c[2433592]|0}else{ac=z;ad=(d[z+254|0]|0)<<8;ae=K;af=J;B=64495}}while(0);if((B|0)==64495){_=a[ac+255|0]|0;$=ad;aa=ae;ab=af}J=_&255|$;c[2415188]=J;b[4830376]=J&65535;J=ab+(aa*3148|0)|0;if((J|0)!=0){K=J;gGC(K|0,9660752,48)|0}c[9731360+(aa<<2)>>2]=c[2113158];c[3528554]=-1;K=c[2439330]|0;J=(K|0)==0;if(!J){z=K;gGC(9706056,z|0,76)|0}z=c[2438118]|0;c[2433530]=z;I=c[3528484]|0;c[2076596]=I;G=c[2417276]|0;c[3541536]=G;c[1836236]=0;gGz(9706056,0,76);if(!J){J=K;gGC(J|0,9706056,76)|0}c[2438118]=z;c[3528484]=I;c[2417276]=G;c[1836236]=-1;blH();c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;lw(c[3540984]|0);c[2432770]=0;c[3531218]=0;c[2394734]=0;D=0;i=e;return D|0}}while(0);c[2415102]=0;D=1;i=e;return D|0}function bgG(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}blI();c[2113160]=0;b=c[2433592]|0;if((b|0)!=0){gGr(b);c[2433592]=0}fwZ();b=a[7452584]|0;if(b){d=0;e=b&1;while(1){b=14163936+(d<<2)|0;f=c[b>>2]|0;g=c[2113006]|0;if((g|0)==0){h=64543}else{i=g-1|0;c[2113006]=i;if((i|0)==0){h=64543}}if((h|0)==64543){h=0;c[2383474]=0}if((f|0)==0){j=e}else{gGr(f);j=a[7452584]&1}c[b>>2]=0;b=d+1|0;if((b|0)<(j|0)){d=b;e=j}else{break}}}a[7452584]=0;c[2438224]=0;c[2433522]=0;c[2406672]=0;c[3528468]=0;j=c[2406688]|0;if((j|0)!=0){gGr(j);c[2406688]=0}c[2432972]=0;j=c[2424800]|0;if((j|0)!=0){gGr(j);c[2424800]=0}j=c[2418166]|0;if((j|0)!=0){gGr(j);c[2418166]=0}j=c[2415102]|0;e=0;while(1){if((e|0)>=1024){h=64558;break}k=9638528+(e<<2)|0;if((c[k>>2]|0)==(j|0)){break}else{e=e+1|0}}if((h|0)==64558){c[2415102]=0;return 0}gGr(j);c[k>>2]=0;c[2415102]=0;return 0}function bgH(){var e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;if((a[9625024]|0)!=0){a[9625024]=0;e=c[2414810]|0;gGz(e|0,0,(c[2411870]|0)-e|0);c[3528554]=0;f43(c[2433592]|0);e=c[3528554]|0;c[2113158]=c[9731360+(e<<2)>>2];a[9660796]=0;a[9660797]=0;a[9660786]=0;a[9660787]=0;c[2415191]=0;a[9660784]=a[9660784]|80;f=c[2433592]|0;g=c[f+(e*3148|0)+1068>>2]|0;do{if((g|0)==0){i=c[f+(e*3148|0)+3120>>2]|0;if((i|0)==0){j=0;k=0;l=e;m=f;break}n=gj[i&4095](-2)|0;i=c[3528554]|0;o=c[2433592]|0;p=c[o+(i*3148|0)+1068>>2]|0;q=(n&255)<<8;if((p|0)!=0){r=p;s=q;t=i;u=o;v=64565;break}p=c[o+(i*3148|0)+3120>>2]|0;if((p|0)==0){j=0;k=q;l=i;m=o;break}o=gj[p&4095](-1)|0;j=o;k=q;l=c[3528554]|0;m=c[2433592]|0}else{r=g;s=d[g+254|0]<<8;t=e;u=f;v=64565}}while(0);if((v|0)==64565){j=a[r+255|0]|0;k=s;l=t;m=u}u=j&255|k;c[2415188]=u;b[4830376]=u&65535;u=m+(l*3148|0)|0;if((u|0)!=0){m=u;gGC(m|0,9660752,48)|0}c[9731360+(l<<2)>>2]=c[2113158];c[3528554]=-1;l=c[2439330]|0;m=(l|0)==0;if(!m){u=l;gGC(9706056,u|0,76)|0}u=c[2438118]|0;c[2433530]=u;k=c[3528484]|0;c[2076596]=k;j=c[2417276]|0;c[3541536]=j;c[1836236]=0;gGz(9706056,0,76);if(!m){m=l;gGC(m|0,9706056,76)|0}c[2438118]=u;c[3528484]=k;c[2417276]=j;c[1836236]=-1;blH();c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;lw(c[3540984]|0);c[2432770]=0;c[3531218]=0;c[2394734]=0}j=c[2385548]|0;if((j|0)>0){gGz(9752472,0,((j|0)>1?j<<2:4)|0)}c[2433530]=0;gGz(9550976,-1|0,3);j=0;k=-1;u=-1;m=-1;do{k=((a[9634392+j|0]&1)<<j^k&255)&255;u=((a[9632152+j|0]&1)<<j^u&255)&255;m=((a[9630072+j|0]&1)<<j^m&255)&255;j=j+1|0;}while((j|0)<8);a[9550976]=k;a[9550977]=u;a[9550978]=m;if((k&6)==0){m=k|6;a[9550976]=m;w=m}else{w=k}if((w&24)==0){a[9550976]=w|24}if((u&6)==0){w=u|6;a[9550977]=w;x=w}else{x=u}if((x&24)==0){a[9550977]=x|24}c[3528554]=0;f43(c[2433592]|0);c[2113158]=c[9731360+(c[3528554]<<2)>>2];x=c[2439330]|0;if((x|0)!=0){u=x;gGC(9706056,u|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;u=0;x=0;w=0;while(1){k=w+1|0;m=f45((k*665|0)-x|0)|0;c[2113158]=(c[2113158]|0)+m;j=(UF((k*596|0)-u|0)|0)+u|0;if((k|0)<100){u=j;x=m+x|0;w=k}else{break}}if((c[3541228]|0)!=0){f44(0);f45(0)|0;a[9660786]=0;f45(0)|0}w=c[2438224]|0;x=gGS(-1597636608,28447,w,(w|0)<0|0?-1:0)|0;w=x;UF(59659)|0;x=c[2443826]|0;if((x|0)<1073676288){c[2443826]=x-w}x=c[2443827]|0;if((x|0)<1073676288){c[2443827]=x-w}x=(c[3528508]|0)-w|0;c[3528508]=(x|0)<0?0:x;x=c[2112964]|0;if((x|0)!=0){gg[c[3542112]&4095](x,a[9688]|0?534:0);x=c[2112964]|0;w=a[9688]|0?534:0;TH(0,x,w);TH(1,x,w)}w=c[1836236]|0;x=c[9757320+(w<<2)>>2]|0;if((x|0)!=0){u=x;gGC(u|0,9706056,76)|0}c[9752472+(w<<2)>>2]=c[2433530];c[14113936+(w<<2)>>2]=c[2076596];c[9669104+(w<<2)>>2]=c[3541536];c[1836236]=-1;w=c[3528554]|0;u=(c[2433592]|0)+(w*3148|0)|0;if((u|0)!=0){x=u;gGC(x|0,9660752,48)|0}c[9731360+(w<<2)>>2]=c[2113158];c[3528554]=-1;if((c[2112968]|0)==0){return 0}bgI()|0;return 0}function bgI(){var d=0,e=0,f=0,g=0,h=0;if((a[9548016]|0)!=0){d=c[3530188]|0;e=c[2387284]|0;f=0;do{g=ga(b[e+(f<<1)>>1]|0)|0;c[d+(f<<2)>>2]=((g&65535)>>>10<<3&65535)>>>3&31|((g&255)<<3&255)<<8|(((g&65535)>>>5<<3&255|(g&65535)>>>7&4)&255)<<3&2016;f=f+1|0;}while((f|0)<1024)}bpj();if((c[2432770]|0)!=0){bpk(1,1,c[2439912]|0);bpl(c[2439876]|0,2);bpk(2,0,c[2439912]|0);bpl(c[2439876]|0,1);bpl(c[2439876]|0,0);bpk(0,0,c[2439912]|0);h=c[3530188]|0;R8(h);return 0}f=ag(c[2113070]|0,c[2113068]|0)|0;if((f|0)<=0){h=c[3530188]|0;R8(h);return 0}d=c[2112926]|0;e=0;do{b[d+(e<<1)>>1]=768;e=e+1|0;}while((e|0)<(f|0));h=c[3530188]|0;R8(h);return 0}function bgJ(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;f=i;i=i+192|0;g=f|0;h=f+16|0;j=f+48|0;k=f+64|0;l=f+80|0;m=f+96|0;n=f+112|0;o=f+128|0;p=f+144|0;q=f+160|0;r=f+176|0;s=(e|0)==0;if(!s){c[e>>2]=169733}if((b&96|0)==0){t=b&64}else{gGz(r|0,0,12);u=c[2414810]|0;c[r>>2]=u;c[r+4>>2]=(c[2411870]|0)-u;c[r+12>>2]=162152;u=c[2076592]|0;gj[u&4095](r)|0;r=n|0;u=b&64;v=(u|0)==0;if((c[2113160]|0)>0&(v^1)){w=n+7|0;n=m|0;x=m+4|0;y=m+12|0;z=l;A=l|0;B=l+4|0;C=l+12|0;D=k;E=k|0;F=k+4|0;G=k+12|0;H=j;I=j|0;J=j+4|0;K=j+12|0;L=0;do{M=c[2433592]|0;N=M+(L*3148|0)+40|0;O=c[N>>2]|0;gGC(r|0,614752,9)|0;a[w]=L+48&255;c[n>>2]=M+(L*3148|0);c[x>>2]=48;c[y>>2]=r;gj[c[2076592]&4095](m)|0;gGz(z|0,0,12);c[A>>2]=M+(L*3148|0)+3136;c[B>>2]=4;c[C>>2]=165288;gj[c[2076592]&4095](l)|0;gGz(D|0,0,12);c[E>>2]=M+(L*3148|0)+3140;c[F>>2]=4;c[G>>2]=501592;gj[c[2076592]&4095](k)|0;gGz(H|0,0,12);c[I>>2]=M+(L*3148|0)+3144;c[J>>2]=4;c[K>>2]=386080;gj[c[2076592]&4095](j)|0;c[N>>2]=O;L=L+1|0;}while((L|0)<(c[2113160]|0))}fw$(b);UQ(b,e);L=h|0;if(!v){if(!s){c[e>>2]=169619}cC(L|0,170224,(e=i,i=i+8|0,c[e>>2]=0,e)|0)|0;i=e;c[g>>2]=9699512;c[g+4>>2]=64;c[g+8>>2]=0;c[g+12>>2]=L;L=c[2076592]|0;gj[L&4095](g)|0}blJ(b);t=u}if((t|0)!=0){gGz(q|0,0,12);c[q>>2]=9731080;c[q+4>>2]=4;c[q+12>>2]=105304;t=c[2076592]|0;gj[t&4095](q)|0;gGz(p|0,0,12);c[p>>2]=14124872;c[p+4>>2]=4;c[p+12>>2]=81208;q=c[2076592]|0;gj[q&4095](p)|0;gGz(o|0,0,12);c[o>>2]=9578936;c[o+4>>2]=4;c[o+12>>2]=587936;p=c[2076592]|0;gj[p&4095](o)|0}if((b&2|0)==0){i=f;return 0}c[3528554]=0;f43(c[2433592]|0);b=c[3528554]|0;o=9731360+(b<<2)|0;p=c[o>>2]|0;c[2113158]=p;q=c[2443944]|0;t=d[q]|0;u=t<<12;if((t&16|0)==0){P=u&57344|65536}else{P=u&24576|131072}u=c[3527400]|0;t=c[2433592]|0;g=P-24576|0;P=96;L=96;while(1){e=u+(g+(L<<8))|0;c[t+(b*3148|0)+48+(L<<2)>>2]=e;c[t+(b*3148|0)+48+(L+512<<2)>>2]=e;e=P+1&65535;if((e&65535)>127){break}else{P=e;L=e&65535}}bgM(a[q+1|0]|0,a[q+2|0]|0);q=t+(b*3148|0)|0;if((q|0)!=0){b=q;gGC(b|0,9660752,48)|0}c[o>>2]=p;c[3528554]=-1;i=f;return 0}function bgK(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6994828+(b*112|0)>>2];c[a+104>>2]=c[6994832+(b*112|0)>>2];c[a+108>>2]=c[6994836+(b*112|0)>>2];d=0;return d|0}function bgL(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=6994728+(b*112|0);e=0;return e|0}function bgM(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=c[2443944]|0;a[e+1|0]=b;a[e+2|0]=d;e=d&255;if((e&16|0)!=0){d=c[2387284]|0;f=c[3528554]|0;g=c[2433592]|0;c[g+(f*3148|0)+48>>2]=d;c[g+(f*3148|0)+1072>>2]=d;c[g+(f*3148|0)+2096>>2]=d;h=d+256|0;c[g+(f*3148|0)+52>>2]=h;c[g+(f*3148|0)+1076>>2]=h;c[g+(f*3148|0)+2100>>2]=h;h=d+512|0;c[g+(f*3148|0)+56>>2]=h;c[g+(f*3148|0)+1080>>2]=h;c[g+(f*3148|0)+2104>>2]=h;h=d+768|0;c[g+(f*3148|0)+60>>2]=h;c[g+(f*3148|0)+1084>>2]=h;c[g+(f*3148|0)+2108>>2]=h;h=d+1024|0;c[g+(f*3148|0)+64>>2]=h;c[g+(f*3148|0)+1088>>2]=h;c[g+(f*3148|0)+2112>>2]=h;h=d+1280|0;c[g+(f*3148|0)+68>>2]=h;c[g+(f*3148|0)+1092>>2]=h;c[g+(f*3148|0)+2116>>2]=h;h=d+1536|0;c[g+(f*3148|0)+72>>2]=h;c[g+(f*3148|0)+1096>>2]=h;c[g+(f*3148|0)+2120>>2]=h;h=d+1792|0;c[g+(f*3148|0)+76>>2]=h;c[g+(f*3148|0)+1100>>2]=h;c[g+(f*3148|0)+2124>>2]=h;return}if((e&32|0)==0){e=c[3531092]|0;h=c[3528554]|0;f=c[2433592]|0;c[f+(h*3148|0)+48>>2]=e;c[f+(h*3148|0)+1072>>2]=e;c[f+(h*3148|0)+2096>>2]=e;g=e+256|0;c[f+(h*3148|0)+52>>2]=g;c[f+(h*3148|0)+1076>>2]=g;c[f+(h*3148|0)+2100>>2]=g;g=e+512|0;c[f+(h*3148|0)+56>>2]=g;c[f+(h*3148|0)+1080>>2]=g;c[f+(h*3148|0)+2104>>2]=g;g=e+768|0;c[f+(h*3148|0)+60>>2]=g;c[f+(h*3148|0)+1084>>2]=g;c[f+(h*3148|0)+2108>>2]=g;g=e+1024|0;c[f+(h*3148|0)+64>>2]=g;c[f+(h*3148|0)+1088>>2]=g;c[f+(h*3148|0)+2112>>2]=g;g=e+1280|0;c[f+(h*3148|0)+68>>2]=g;c[f+(h*3148|0)+1092>>2]=g;c[f+(h*3148|0)+2116>>2]=g;g=e+1536|0;c[f+(h*3148|0)+72>>2]=g;c[f+(h*3148|0)+1096>>2]=g;c[f+(h*3148|0)+2120>>2]=g;g=e+1792|0;c[f+(h*3148|0)+76>>2]=g;c[f+(h*3148|0)+1100>>2]=g;c[f+(h*3148|0)+2124>>2]=g;return}if(b<<24>>24<0){b=c[2387304]|0;g=c[3528554]|0;h=c[2433592]|0;c[h+(g*3148|0)+48>>2]=b;c[h+(g*3148|0)+1072>>2]=b;c[h+(g*3148|0)+2096>>2]=b;f=b+256|0;c[h+(g*3148|0)+52>>2]=f;c[h+(g*3148|0)+1076>>2]=f;c[h+(g*3148|0)+2100>>2]=f;f=b+512|0;c[h+(g*3148|0)+56>>2]=f;c[h+(g*3148|0)+1080>>2]=f;c[h+(g*3148|0)+2104>>2]=f;f=b+768|0;c[h+(g*3148|0)+60>>2]=f;c[h+(g*3148|0)+1084>>2]=f;c[h+(g*3148|0)+2108>>2]=f;f=b+1024|0;c[h+(g*3148|0)+64>>2]=f;c[h+(g*3148|0)+1088>>2]=f;c[h+(g*3148|0)+2112>>2]=f;f=b+1280|0;c[h+(g*3148|0)+68>>2]=f;c[h+(g*3148|0)+1092>>2]=f;c[h+(g*3148|0)+2116>>2]=f;f=b+1536|0;c[h+(g*3148|0)+72>>2]=f;c[h+(g*3148|0)+1096>>2]=f;c[h+(g*3148|0)+2120>>2]=f;f=b+1792|0;c[h+(g*3148|0)+76>>2]=f;c[h+(g*3148|0)+1100>>2]=f;c[h+(g*3148|0)+2124>>2]=f;return}else{f=c[3527400]|0;g=c[3528554]|0;h=c[2433592]|0;b=f+2048|0;c[h+(g*3148|0)+48>>2]=b;c[h+(g*3148|0)+2096>>2]=b;b=f+2304|0;c[h+(g*3148|0)+52>>2]=b;c[h+(g*3148|0)+2100>>2]=b;b=f+2560|0;c[h+(g*3148|0)+56>>2]=b;c[h+(g*3148|0)+2104>>2]=b;b=f+2816|0;c[h+(g*3148|0)+60>>2]=b;c[h+(g*3148|0)+2108>>2]=b;b=f+3072|0;c[h+(g*3148|0)+64>>2]=b;c[h+(g*3148|0)+2112>>2]=b;b=f+3328|0;c[h+(g*3148|0)+68>>2]=b;c[h+(g*3148|0)+2116>>2]=b;b=f+3584|0;c[h+(g*3148|0)+72>>2]=b;c[h+(g*3148|0)+2120>>2]=b;b=f+3840|0;c[h+(g*3148|0)+76>>2]=b;c[h+(g*3148|0)+2124>>2]=b;c[h+(g*3148|0)+1072>>2]=f;c[h+(g*3148|0)+1076>>2]=f+256;c[h+(g*3148|0)+1080>>2]=f+512;c[h+(g*3148|0)+1084>>2]=f+768;c[h+(g*3148|0)+1088>>2]=f+1024;c[h+(g*3148|0)+1092>>2]=f+1280;c[h+(g*3148|0)+1096>>2]=f+1536;c[h+(g*3148|0)+1100>>2]=f+1792;return}}function bgN(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;c[f>>2]=c[e>>2]&32;f=c[e>>2]|0;c[d>>2]=c[d>>2]|b<<13|f<<6&1024|f<<8&768|f<<9&6144;c[e>>2]=((c[e>>2]|0)>>>6&3)+(c[602544+(a<<2)>>2]|0);return}function bgO(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0;c[d>>2]=0;e=c[b>>2]|0;if((e&16|0)==0){f=e}else{c[d>>2]=1;f=c[b>>2]|0}if((f&32|0)==0){c[d>>2]=2;g=c[b>>2]|0}else{g=f}c[b>>2]=g&15|32;c[a>>2]=c[a>>2]&8191;return}function bgP(b,d){b=b|0;d=d|0;if((d|0)==0){return}if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12;return}function bgQ(a){a=a|0;var b=0,d=0;b=(c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,3579545,0)|0;return a|0}function bgR(b){b=b|0;a[9681232]=((b>>4)*17|0)&255;a[9681233]=0;c[2424878]=9681232;a[9681234]=0;a[9681235]=((b&15)*17|0)&255;return}function bgS(b){b=b|0;a[9681296]=((b>>4)*17|0)&255;a[9681297]=0;c[2424878]=9681296;a[9681298]=0;a[9681299]=((b&15)*17|0)&255;return}function bgT(b,d){b=b|0;d=d|0;var e=0;e=b-1359872|0;if(e>>>0>=32768){return}b=e>>>1;e=d&255;a[(c[3529062]|0)+b|0]=e;if((b&6144)>>>0<=6143){return}if((b|0)==7424){c[3541228]=d&4;return}else if((b|0)==7680|(b|0)==15872){a[9730680]=e;return}else if((b|0)==7296){a[9729904]=e;return}else if((b|0)==7552){a[9720736]=e&15;a[9720737]=(e&255)>>>4;return}else if((b|0)==7808){c[2432672]=(d&6)>>>1&3;return}else if((b|0)==7936){a[9720738]=e&15;a[9720739]=(e&255)>>>4;return}else{return}}function bgU(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;if((b|0)==786432|(b|0)==786433){do{if((c[2429402]&8|0)!=0){if((d&8)!=0){break}e=c[2113054]|0;f=c[2113056]|0;g=c[2276108]|0;h=c[2394]|0;i=c[14130368+(h<<2)>>2]|0;if((i|0)!=0){gGC(i|0,9104152,280)|0}c[8452240+(h<<2)>>2]=e;c[2394]=1;c[2112932]=c[3532597];h=c[3532593]|0;if((h|0)!=0){gGC(9104152,h|0,280)|0}h=f+e-g-f+g|0;c[2113054]=h;c[2113061]=h;c[2394]=0;c[2112932]=c[3532596];h=c[3532592]|0;if((h|0)!=0){gGC(9104152,h|0,280)|0}c[2113054]=c[2113060]}}while(0);h=d&255;c[2430488]=h&4;c[2429402]=h&8;c[2444178]=h&32;return}else if((b|0)==950272){a[c[3528368]|0]=d;return}else if((b|0)==917504|(b|0)==917505){return}else if((b|0)==983040){a[14125144]=-1;a[9706117]=1;return}else if((b|0)==884736|(b|0)==884737){c[2429632]=c[2385604]&4;return}else{h=b-1359872|0;if(h>>>0>=32768){return}b=h>>>1;a[(c[3529062]|0)+b|0]=d;if((b&6144)>>>0<=6143){return}if((b|0)==7808){c[2432672]=(d&255)>>>1&3;return}else if((b|0)==7936){a[9720738]=d&15;a[9720739]=(d&255)>>>4;return}else if((b|0)==7552){a[9720736]=d&15;a[9720737]=(d&255)>>>4;return}else if((b|0)==7296){a[9729904]=d;return}else if((b|0)==7680|(b|0)==15872){a[9730680]=d;return}else if((b|0)==7424){c[3541228]=d&4;return}else{return}}}function bgV(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;e=i;i=i+24|0;f=e|0;g=e+8|0;h=e+16|0;j=b-1359872|0;if(j>>>0>=32768){k=0;i=e;return k|0}b=j>>>1;if((c[3541230]|0)==0){l=(c[3529062]|0)+b|0}else{c[f>>2]=0;m=j>>>6&255;c[g>>2]=m;j=d[9730680]|0;c[h>>2]=j;n=j>>>2&3;if((c[2429638]|0)==0){gB[c[2437692]&127](0,((a[9718936+n|0]|a[9720736+n|0])&255)>>>2,g,h,f,f);o=c[g>>2]|0}else{f=j<<8|m;c[g>>2]=f;o=f}l=(c[3529060]|0)+((o<<5|b&31)&c[2438700])|0}k=d[l]|0;i=e;return k|0}function bgW(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+24|0;g=f|0;h=f+8|0;j=f+16|0;if((e|0)==819200|(e|0)==819201){k=b[4775484]&255;i=f;return k|0}else if((e|0)==819204|(e|0)==819205){k=b[4775486]&255;i=f;return k|0}else if((e|0)==819202|(e|0)==819203){k=b[4775485]&255;i=f;return k|0}else if((e|0)==819206|(e|0)==819207){k=a[9635690]|0;i=f;return k|0}else if((e|0)==851968|(e|0)==851969){k=a[9635688]|0;i=f;return k|0}else if((e|0)==851970|(e|0)==851971){k=a[9635689]|0;i=f;return k|0}else{l=e-1359872|0;if(l>>>0>=32768){k=0;i=f;return k|0}e=l>>>1;if((c[3541230]|0)==0){k=a[(c[3529062]|0)+e|0]|0;i=f;return k|0}c[g>>2]=0;m=l>>>6&255;c[h>>2]=m;l=d[9730680]|0;c[j>>2]=l;n=l>>>2&3;if((c[2429638]|0)==0){gB[c[2437692]&127](0,((a[9718936+n|0]|a[9720736+n|0])&255)>>>2,h,j,g,g);o=c[h>>2]|0}else{g=l<<8|m;c[h>>2]=g;o=g}k=a[(c[3529060]|0)+((o<<5|e&31)&c[2438700])|0]|0;i=f;return k|0}return 0}function bgX(b,d){b=b|0;d=d|0;var e=0,f=0;if((b&16777214|0)==1310720){c[2385604]=(d&65535)>>>8&7;return}e=b-2408448|0;if(e>>>0>=32768){if((b&268435440|0)!=2883584){if((b&268433408|0)!=2885632){return}a[(c[3529066]|0)+((b-2885632|0)>>>1)|0]=d&255;return}f=(b-2883584|0)>>>1;if((f|0)==0){b=d&255;c[3541236]=b&1;c[3541234]=b&4;c[3541232]=b&8;c[3541238]=b&32;return}b=f-2|0;if(b>>>0>=3){return}a[9718032+b|0]=d&255;return}b=e>>>1;e=d&255;a[(c[3529062]|0)+b|0]=e;if((b&6144)>>>0<=6143){return}if((b|0)==7680|(b|0)==15872){a[9730680]=e;return}else if((b|0)==7808){c[2432672]=(d&6)>>>1&3;return}else if((b|0)==7936){a[9720738]=e&15;a[9720739]=(e&255)>>>4;return}else if((b|0)==7296){a[9729904]=e;return}else if((b|0)==7424){c[3541228]=d&4;return}else if((b|0)==7552){a[9720736]=e&15;a[9720737]=(e&255)>>>4;return}else{return}}function bgY(b,d){b=b|0;d=d|0;var e=0,f=0;if((b&16777214|0)==1310720){c[2385604]=d&7;return}e=b-2408448|0;if(e>>>0>=32768){if((b&268435440|0)!=2883584){if((b&268433408|0)!=2885632){return}a[(c[3529066]|0)+((b-2885632|0)>>>1)|0]=d;return}f=(b-2883584|0)>>>1;if((f|0)==0){b=d&255;c[3541236]=b&1;c[3541234]=b&4;c[3541232]=b&8;c[3541238]=b&32;return}b=f-2|0;if(b>>>0>=3){return}a[9718032+b|0]=d;return}b=e>>>1;a[(c[3529062]|0)+b|0]=d;if((b&6144)>>>0<=6143){return}if((b|0)==7680|(b|0)==15872){a[9730680]=d;return}else if((b|0)==7552){a[9720736]=d&15;a[9720737]=(d&255)>>>4;return}else if((b|0)==7808){c[2432672]=(d&255)>>>1&3;return}else if((b|0)==7296){a[9729904]=d;return}else if((b|0)==7936){a[9720738]=d&15;a[9720739]=(d&255)>>>4;return}else if((b|0)==7424){c[3541228]=d&4;return}else{return}}function bgZ(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=i;i=i+56|0;f=e|0;g=e+8|0;h=e+16|0;j=e+24|0;k=e+32|0;l=e+40|0;m=e+48|0;n=b-2408448|0;if(n>>>0<32768){o=n>>>1;if((c[3541230]|0)==0){p=(c[3529062]|0)+o|0}else{c[k>>2]=0;q=n>>>6&255;c[l>>2]=q;n=d[9730680]|0;c[m>>2]=n;r=n>>>2&3;if((c[2429638]|0)==0){gB[c[2437692]&127](0,((a[9718936+r|0]|a[9720736+r|0])&255)>>>2,l,m,k,k);s=c[l>>2]|0}else{k=n<<8|q;c[l>>2]=k;s=k}p=(c[3529060]|0)+((s<<5|o&31)&c[2438700])|0}t=d[p]|0;i=e;return t|0}if((b&268435440|0)==2883584){t=(bpm((b-2883584|0)>>>1)|0)&255;i=e;return t|0}if((b&268433408|0)!=2885632){t=0;i=e;return t|0}p=b-2885632|0;if((c[3541238]|0)!=0){b=p>>>3&255;c[2433420]=b;o=d[9718033]|0;c[f>>2]=((d[9718032]|0)<<8|b|o<<16)>>>5&8191;b=(d[9718034]|0)<<6;c[g>>2]=b&192|o>>>2;c[h>>2]=0;c[j>>2]=b&128;gL[c[2437694]&255](f,g,h,j)}t=d[(c[3529066]|0)+(p>>>1)|0]|0;i=e;return t|0}function bg_(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=i;i=i+56|0;f=e|0;g=e+8|0;h=e+16|0;j=e+24|0;k=e+32|0;l=e+40|0;m=e+48|0;n=b-2408448|0;if(n>>>0<32768){o=n>>>1;if((c[3541230]|0)==0){p=a[(c[3529062]|0)+o|0]|0;i=e;return p|0}c[k>>2]=0;q=n>>>6&255;c[l>>2]=q;n=d[9730680]|0;c[m>>2]=n;r=n>>>2&3;if((c[2429638]|0)==0){gB[c[2437692]&127](0,((a[9718936+r|0]|a[9720736+r|0])&255)>>>2,l,m,k,k);s=c[l>>2]|0}else{k=n<<8|q;c[l>>2]=k;s=k}p=a[(c[3529060]|0)+((s<<5|o&31)&c[2438700])|0]|0;i=e;return p|0}if((b&268435440|0)==2883584){p=bpm((b-2883584|0)>>>1)|0;i=e;return p|0}if((b&268433408|0)!=2885632){p=0;i=e;return p|0}o=b-2885632|0;if((c[3541238]|0)!=0){b=o>>>3&255;c[2433420]=b;s=d[9718033]|0;c[f>>2]=((d[9718032]|0)<<8|b|s<<16)>>>5&8191;b=(d[9718034]|0)<<6;c[g>>2]=b&192|s>>>2;c[h>>2]=0;c[j>>2]=b&128;gL[c[2437694]&255](f,g,h,j)}p=a[(c[3529066]|0)+(o>>>1)|0]|0;i=e;return p|0}function bg$(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((e&65520|0)==61472){TI(0,e&15,d&255);return}if((e|0)==61489){b=c[2113304]|0;a[14168504+b|0]=d;mv(0,b,d&255);return}else if((e|0)==61440){b=d&255;c[2424878]=9681232;c[2420315]=b<<17&393216;c[2420316]=b>>>2<<17&393216;return}else if((e|0)==61488){c[2113304]=d&255;return}else{return}}function bg0(b){b=b|0;var e=0,f=0,g=0,h=0;e=b&65535;if((e&65520|0)==61472){b=e&15;c[2424878]=9681232;c[2426622]=9622928;if(!((b|0)==11|(b|0)==5)){f=0;return f|0}g=(b>>>0)/6|0;b=g*6|0;h=(d[b+9681280|0]|0)<<16&65536|(d[b+9681279|0]|0)<<8|(d[b+9681278|0]|0)|c[9681260+(g<<2)>>2];c[9681244+(g<<2)>>2]=h;if(h>>>0>=(c[2405735]|0)>>>0){f=0;return f|0}c[9681268+(g<<2)>>2]=1;c[9681236+(g<<2)>>2]=0;f=0;return f|0}else{if((e|0)==61489){f=c[(c[3531464]|0)+4240>>2]&255;return f|0}else if((e|0)==61456){a[9706117]=0;f=a[c[3528368]|0]|0;return f|0}else{f=0;return f|0}}return 0}function bg1(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>24){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4689484+(b*112|0)>>2];c[a+104>>2]=c[4689488+(b*112|0)>>2];c[a+108>>2]=c[4689492+(b*112|0)>>2];d=0;return d|0}function bg2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<25&(d|0)==0)){e=1;return e|0}c[a>>2]=4689384+(b*112|0);e=0;return e|0}function bg3(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1241088+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function bg4(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>59){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3890416+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function bg5(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;e=i;i=i+720|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;c[2415100]=0;c[3531128]=0;c[3531116]=1048576;c[2386006]=2097152;c[3530710]=2162688;c[2439910]=4259840;c[2439874]=4521984;c[2386694]=8716288;c[3530186]=9240576;c[2414808]=9248768;c[2386158]=9248768;c[3528368]=9250816;c[3531180]=9250817;c[3531158]=9267201;c[3527320]=9283585;c[2443454]=9299969;c[2387282]=9431041;c[2411868]=9435137;t=0;while(1){if((t|0)>=1024){break}u=9638528+(t<<2)|0;if((c[u>>2]|0)==0){v=64937;break}else{t=t+1|0}}do{if((v|0)==64937){t=gGq(9435137)|0;c[u>>2]=t;if((t|0)==0){break}c[2415100]=t;gGz(t|0,0,9435137);c[3531128]=t;c[3531116]=t+1048576;c[2386006]=t+2097152;c[3530710]=t+2162688;c[2439910]=t+4259840;c[2439874]=t+4521984;c[2386694]=t+8716288;c[3530186]=t+9240576;w=t+9248768|0;c[2414808]=w;c[2386158]=w;c[3528368]=t+9250816;c[3531180]=t+9250817;c[3531158]=t+9267201;c[3527320]=t+9283585;c[2443454]=t+9299969;c[2387282]=t+9431041;w=t+9435137|0;c[2411868]=w;c[2414418]=w;if((R6(t+1|0,0,2)|0)!=0){x=1;i=e;return x|0}if((R6(c[3531128]|0,1,2)|0)!=0){x=1;i=e;return x|0}if((R6((c[3531116]|0)+1|0,2,2)|0)!=0){x=1;i=e;return x|0}if((R6(c[3531116]|0,3,2)|0)!=0){x=1;i=e;return x|0}if((R6((c[3531116]|0)+262145|0,4,2)|0)!=0){x=1;i=e;return x|0}if((R6((c[3531116]|0)+262144|0,5,2)|0)!=0){x=1;i=e;return x|0}if((R6((c[3531116]|0)+524289|0,6,2)|0)!=0){x=1;i=e;return x|0}if((R6((c[3531116]|0)+524288|0,7,2)|0)!=0){x=1;i=e;return x|0}if((R6((c[3531116]|0)+786433|0,8,2)|0)!=0){x=1;i=e;return x|0}if((R6((c[3531116]|0)+786432|0,9,2)|0)!=0){x=1;i=e;return x|0}t=c[2386006]|0;if((c[3542200]|0)==0){x=1;i=e;return x|0}w=r+108|0;c[w>>2]=0;y=r+100|0;c[y>>2]=0;z=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[z&16383](r,10)|0;do{if((c[w>>2]|0)!=0){z=c[y>>2]|0;c[s>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](s,10,0)|0;if((z|0)<1){x=1;i=e;return x|0}if((gzL(t,0,10)|0)==0){break}else{x=1}i=e;return x|0}}while(0);t=c[3530710]|0;if((c[3542200]|0)==0){x=1;i=e;return x|0}y=p+108|0;c[y>>2]=0;w=p+100|0;c[w>>2]=0;z=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[z&16383](p,11)|0;do{if((c[y>>2]|0)!=0){z=c[w>>2]|0;c[q>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](q,11,0)|0;if((z|0)<1){x=1;i=e;return x|0}if((gzL(t,0,11)|0)==0){break}else{x=1}i=e;return x|0}}while(0);if((R6((c[3530710]|0)+524288|0,12,2)|0)!=0){x=1;i=e;return x|0}if((R6((c[3530710]|0)+524289|0,13,2)|0)!=0){x=1;i=e;return x|0}if((R6((c[3530710]|0)+786432|0,14,2)|0)!=0){x=1;i=e;return x|0}if((R6((c[3530710]|0)+786433|0,15,2)|0)!=0){x=1;i=e;return x|0}t=(c[3530710]|0)+1048576|0;if((c[3542200]|0)==0){x=1;i=e;return x|0}w=n+108|0;c[w>>2]=0;y=n+100|0;c[y>>2]=0;z=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[z&16383](n,16)|0;do{if((c[w>>2]|0)!=0){z=c[y>>2]|0;c[o>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](o,16,0)|0;if((z|0)<1){x=1;i=e;return x|0}if((gzL(t,0,16)|0)==0){break}else{x=1}i=e;return x|0}}while(0);if((R6((c[3530710]|0)+1572864|0,17,2)|0)!=0){x=1;i=e;return x|0}if((R6((c[3530710]|0)+1572865|0,18,2)|0)!=0){x=1;i=e;return x|0}if((R6((c[3530710]|0)+1835008|0,19,2)|0)!=0){x=1;i=e;return x|0}if((R6((c[3530710]|0)+1835009|0,20,2)|0)!=0){x=1;i=e;return x|0}t=c[2386694]|0;if((c[3542200]|0)==0){x=1;i=e;return x|0}y=l+108|0;c[y>>2]=0;w=l+100|0;c[w>>2]=0;z=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[z&16383](l,21)|0;do{if((c[y>>2]|0)!=0){z=c[w>>2]|0;c[m>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](m,21,0)|0;if((z|0)<1){x=1;i=e;return x|0}if((gzL(t,0,21)|0)==0){break}else{x=1}i=e;return x|0}}while(0);t=(c[2386694]|0)+262144|0;if((c[3542200]|0)==0){x=1;i=e;return x|0}w=j+108|0;c[w>>2]=0;y=j+100|0;c[y>>2]=0;z=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[z&16383](j,22)|0;do{if((c[w>>2]|0)!=0){z=c[y>>2]|0;c[k>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](k,22,0)|0;if((z|0)<1){x=1;i=e;return x|0}if((gzL(t,0,22)|0)==0){break}else{x=1}i=e;return x|0}}while(0);t=(c[2386694]|0)+393216|0;if((c[3542200]|0)==0){x=1;i=e;return x|0}y=f+108|0;c[y>>2]=0;w=f+100|0;c[w>>2]=0;z=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[z&16383](f,23)|0;do{if((c[y>>2]|0)!=0){z=c[w>>2]|0;c[g>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](g,23,0)|0;if((z|0)<1){x=1;i=e;return x|0}if((gzL(t,0,23)|0)==0){break}else{x=1}i=e;return x|0}}while(0);t=c[3530710]|0;blG(t,1048576);w=c[2439874]|0;y=0;do{z=y<<8;gGz(w+z|0,0,256);A=y<<10;B=0;do{C=1<<3-B;D=(c[703416+(B<<2)>>2]|0)+A|0;E=0;do{F=D+(c[3946808+(E<<2)>>2]|0)|0;G=(E<<4)+z|0;H=0;do{I=F+(c[612928+(H<<2)>>2]|0)|0;if(((d[t+((I|0)/8|0)|0]|0)&128>>>((I&7)>>>0)|0)!=0){I=w+(G+H)|0;a[I]=(d[I]|0|C)&255}H=H+1|0;}while((H|0)<16);E=E+1|0;}while((E|0)<16);B=B+1|0;}while((B|0)<4);y=y+1|0;}while((y|0)<16384);fxU(0,425984);if((c[2394]|0)==0){J=c[2112932]|0}else{c[2394]=0;y=c[3532596]|0;c[2112932]=y;w=c[3532592]|0;if((w|0)!=0){gGC(9104152,w|0,280)|0}c[2113054]=c[2113060];J=y}y=c[3531128]|0;w=J|0;t=0;while(1){B=y+t|0;c[w>>2]=B;c[w+131072>>2]=B;B=t+1024|0;if(B>>>0>262143){break}else{w=w+4|0;t=B}}t=c[3531180]|0;c[J+1024>>2]=t;c[J+66560>>2]=t;c[J+132096>>2]=t;w=t+1024|0;c[J+1028>>2]=w;c[J+66564>>2]=w;c[J+132100>>2]=w;w=t+2048|0;c[J+1032>>2]=w;c[J+66568>>2]=w;c[J+132104>>2]=w;w=t+3072|0;c[J+1036>>2]=w;c[J+66572>>2]=w;c[J+132108>>2]=w;w=t+4096|0;c[J+1040>>2]=w;c[J+66576>>2]=w;c[J+132112>>2]=w;w=t+5120|0;c[J+1044>>2]=w;c[J+66580>>2]=w;c[J+132116>>2]=w;w=t+6144|0;c[J+1048>>2]=w;c[J+66584>>2]=w;c[J+132120>>2]=w;w=t+7168|0;c[J+1052>>2]=w;c[J+66588>>2]=w;c[J+132124>>2]=w;w=t+8192|0;c[J+1056>>2]=w;c[J+66592>>2]=w;c[J+132128>>2]=w;w=t+9216|0;c[J+1060>>2]=w;c[J+66596>>2]=w;c[J+132132>>2]=w;w=t+10240|0;c[J+1064>>2]=w;c[J+66600>>2]=w;c[J+132136>>2]=w;w=t+11264|0;c[J+1068>>2]=w;c[J+66604>>2]=w;c[J+132140>>2]=w;w=t+12288|0;c[J+1072>>2]=w;c[J+66608>>2]=w;c[J+132144>>2]=w;w=t+13312|0;c[J+1076>>2]=w;c[J+66612>>2]=w;c[J+132148>>2]=w;w=t+14336|0;c[J+1080>>2]=w;c[J+66616>>2]=w;c[J+132152>>2]=w;w=t+15360|0;c[J+1084>>2]=w;c[J+66620>>2]=w;c[J+132156>>2]=w;w=c[2387282]|0;c[J+2048>>2]=w;c[J+67584>>2]=w;c[J+133120>>2]=w;t=w+1024|0;c[J+2052>>2]=t;c[J+67588>>2]=t;c[J+133124>>2]=t;t=w+2048|0;c[J+2056>>2]=t;c[J+67592>>2]=t;c[J+133128>>2]=t;t=w+3072|0;c[J+2060>>2]=t;c[J+67596>>2]=t;c[J+133132>>2]=t;t=c[3527320]|0;c[J+4096>>2]=t;c[J+69632>>2]=t;c[J+135168>>2]=t;w=t+1024|0;c[J+4100>>2]=w;c[J+69636>>2]=w;c[J+135172>>2]=w;w=t+2048|0;c[J+4104>>2]=w;c[J+69640>>2]=w;c[J+135176>>2]=w;w=t+3072|0;c[J+4108>>2]=w;c[J+69644>>2]=w;c[J+135180>>2]=w;w=t+4096|0;c[J+4112>>2]=w;c[J+69648>>2]=w;c[J+135184>>2]=w;w=t+5120|0;c[J+4116>>2]=w;c[J+69652>>2]=w;c[J+135188>>2]=w;w=t+6144|0;c[J+4120>>2]=w;c[J+69656>>2]=w;c[J+135192>>2]=w;w=t+7168|0;c[J+4124>>2]=w;c[J+69660>>2]=w;c[J+135196>>2]=w;w=t+8192|0;c[J+4128>>2]=w;c[J+69664>>2]=w;c[J+135200>>2]=w;w=t+9216|0;c[J+4132>>2]=w;c[J+69668>>2]=w;c[J+135204>>2]=w;w=t+10240|0;c[J+4136>>2]=w;c[J+69672>>2]=w;c[J+135208>>2]=w;w=t+11264|0;c[J+4140>>2]=w;c[J+69676>>2]=w;c[J+135212>>2]=w;w=t+12288|0;c[J+4144>>2]=w;c[J+69680>>2]=w;c[J+135216>>2]=w;w=t+13312|0;c[J+4148>>2]=w;c[J+69684>>2]=w;c[J+135220>>2]=w;w=t+14336|0;c[J+4152>>2]=w;c[J+69688>>2]=w;c[J+135224>>2]=w;w=t+15360|0;c[J+4156>>2]=w;c[J+69692>>2]=w;c[J+135228>>2]=w;w=c[2443454]|0;t=J+6144|0;y=1572864;while(1){B=w+(y-1572864)|0;c[t>>2]=B;c[t+65536>>2]=B;c[t+131072>>2]=B;B=y+1024|0;if(B>>>0>1703935){break}else{t=t+4|0;y=B}}c[J+196728>>2]=1614;c[J+196648>>2]=866;c[J+196688>>2]=1490;c[J+196608>>2]=3550;y=c[3532592]|0;if((y|0)!=0){gGC(y|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fxU(1,425984);if((c[2394]|0)==1){K=c[2112932]|0}else{c[2394]=1;y=c[3532597]|0;c[2112932]=y;t=c[3532593]|0;if((t|0)!=0){gGC(9104152,t|0,280)|0}c[2113054]=c[2113061];K=y}y=c[3531116]|0;t=K|0;w=0;while(1){B=y+w|0;c[t>>2]=B;c[t+131072>>2]=B;B=w+1024|0;if(B>>>0>1048575){break}else{t=t+4|0;w=B}}w=c[3531158]|0;c[K+4096>>2]=w;c[K+69632>>2]=w;c[K+135168>>2]=w;t=w+1024|0;c[K+4100>>2]=t;c[K+69636>>2]=t;c[K+135172>>2]=t;t=w+2048|0;c[K+4104>>2]=t;c[K+69640>>2]=t;c[K+135176>>2]=t;t=w+3072|0;c[K+4108>>2]=t;c[K+69644>>2]=t;c[K+135180>>2]=t;t=w+4096|0;c[K+4112>>2]=t;c[K+69648>>2]=t;c[K+135184>>2]=t;t=w+5120|0;c[K+4116>>2]=t;c[K+69652>>2]=t;c[K+135188>>2]=t;t=w+6144|0;c[K+4120>>2]=t;c[K+69656>>2]=t;c[K+135192>>2]=t;t=w+7168|0;c[K+4124>>2]=t;c[K+69660>>2]=t;c[K+135196>>2]=t;t=w+8192|0;c[K+4128>>2]=t;c[K+69664>>2]=t;c[K+135200>>2]=t;t=w+9216|0;c[K+4132>>2]=t;c[K+69668>>2]=t;c[K+135204>>2]=t;t=w+10240|0;c[K+4136>>2]=t;c[K+69672>>2]=t;c[K+135208>>2]=t;t=w+11264|0;c[K+4140>>2]=t;c[K+69676>>2]=t;c[K+135212>>2]=t;t=w+12288|0;c[K+4144>>2]=t;c[K+69680>>2]=t;c[K+135216>>2]=t;t=w+13312|0;c[K+4148>>2]=t;c[K+69684>>2]=t;c[K+135220>>2]=t;t=w+14336|0;c[K+4152>>2]=t;c[K+69688>>2]=t;c[K+135224>>2]=t;t=w+15360|0;c[K+4156>>2]=t;c[K+69692>>2]=t;c[K+135228>>2]=t;t=c[3527320]|0;c[K+8192>>2]=t;c[K+73728>>2]=t;c[K+139264>>2]=t;w=t+1024|0;c[K+8196>>2]=w;c[K+73732>>2]=w;c[K+139268>>2]=w;w=t+2048|0;c[K+8200>>2]=w;c[K+73736>>2]=w;c[K+139272>>2]=w;w=t+3072|0;c[K+8204>>2]=w;c[K+73740>>2]=w;c[K+139276>>2]=w;w=t+4096|0;c[K+8208>>2]=w;c[K+73744>>2]=w;c[K+139280>>2]=w;w=t+5120|0;c[K+8212>>2]=w;c[K+73748>>2]=w;c[K+139284>>2]=w;w=t+6144|0;c[K+8216>>2]=w;c[K+73752>>2]=w;c[K+139288>>2]=w;w=t+7168|0;c[K+8220>>2]=w;c[K+73756>>2]=w;c[K+139292>>2]=w;w=t+8192|0;c[K+8224>>2]=w;c[K+73760>>2]=w;c[K+139296>>2]=w;w=t+9216|0;c[K+8228>>2]=w;c[K+73764>>2]=w;c[K+139300>>2]=w;w=t+10240|0;c[K+8232>>2]=w;c[K+73768>>2]=w;c[K+139304>>2]=w;w=t+11264|0;c[K+8236>>2]=w;c[K+73772>>2]=w;c[K+139308>>2]=w;w=t+12288|0;c[K+8240>>2]=w;c[K+73776>>2]=w;c[K+139312>>2]=w;w=t+13312|0;c[K+8244>>2]=w;c[K+73780>>2]=w;c[K+139316>>2]=w;w=t+14336|0;c[K+8248>>2]=w;c[K+73784>>2]=w;c[K+139320>>2]=w;w=t+15360|0;c[K+8252>>2]=w;c[K+73788>>2]=w;c[K+139324>>2]=w;w=c[2443454]|0;t=K+10240|0;y=2621440;while(1){B=w+(y-2621440)|0;c[t>>2]=B;c[t+65536>>2]=B;c[t+131072>>2]=B;B=y+1024|0;if(B>>>0>2752511){break}else{t=t+4|0;y=B}}y=c[3530710]|0;t=K+16384|0;w=4194304;while(1){B=y+(w-4194304)|0;c[t>>2]=B;c[t+131072>>2]=B;B=w+1024|0;if(B>>>0>6291455){break}else{t=t+4|0;w=B}}c[K+196728>>2]=2868;c[K+196648>>2]=2170;c[K+196688>>2]=472;c[K+196608>>2]=1052;w=c[3532593]|0;if((w|0)!=0){gGC(w|0,9104152,280)|0}c[2113061]=c[2113054];c[2394]=-1;fwR(0);w=c[2439330]|0;t=(w|0)==0;if(!t){y=w;gGC(9706056,y|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];y=c[3528484]|0;c[2076596]=y;B=c[2417276]|0;c[3541536]=B;c[1836236]=0;z=c[2386006]|0;A=0;E=0;while(1){c[w+76+(E<<2)>>2]=z+(E<<8);C=A+1&65535;if((C&65535)>239){L=0;M=0;break}else{A=C;E=C&65535}}while(1){E=z+(M<<8)|0;c[w+76+(M+512<<2)>>2]=E;c[w+76+(M+768<<2)>>2]=E;E=L+1&65535;if((E&65535)>239){break}else{L=E;M=E&65535}}z=c[2386158]|0;c[w+1068>>2]=z;E=z+256|0;c[w+1072>>2]=E;A=z+512|0;c[w+1076>>2]=A;C=z+768|0;c[w+1080>>2]=C;D=z+1024|0;c[w+1084>>2]=D;H=z+1280|0;c[w+1088>>2]=H;G=z+1536|0;c[w+1092>>2]=G;F=z+1792|0;c[w+1096>>2]=F;c[w+2092>>2]=z;c[w+2096>>2]=E;c[w+2100>>2]=A;c[w+2104>>2]=C;c[w+2108>>2]=D;c[w+2112>>2]=H;c[w+2116>>2]=G;c[w+2120>>2]=F;c[w+3116>>2]=z;c[w+4140>>2]=z;c[w+3120>>2]=E;c[w+4144>>2]=E;c[w+3124>>2]=A;c[w+4148>>2]=A;c[w+3128>>2]=C;c[w+4152>>2]=C;c[w+3132>>2]=D;c[w+4156>>2]=D;c[w+3136>>2]=H;c[w+4160>>2]=H;c[w+3140>>2]=G;c[w+4164>>2]=G;c[w+3144>>2]=F;c[w+4168>>2]=F;c[w+4184>>2]=2620;c[w+4180>>2]=2248;if(!t){F=w;gGC(F|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=y;c[2417276]=B;c[1836236]=-1;F=a[9680]|0;G=F?32e3:0;if(F){if(a[9624]|0){F=G*3|0;H=55930;while(1){if((H|0)>(F|0)){H=H>>1}else{N=1222;O=H;break}}}else{N=2462;O=G}c[2429380]=O;c[3542124]=N;mw(3579545,O);H=gGq(262144)|0;c[2406684]=H;gGz(H|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(3579545,11025)}h[745421]=1.0;c[2436794]=1;h[745420]=1.0;c[2436792]=2;TJ(0,c[2386694]|0,524288);c[2424878]=9681232;c[2405736]=456;h[1202869]=.2;c[2405742]=3;c[2426622]=9622928;h[1202870]=.2;c[2405743]=3;H=c[2443454]|0;F=0;while(1){if((F|0)>=1024){P=0;break}Q=9638528+(F<<2)|0;if((c[Q>>2]|0)==0){v=65031;break}else{F=F+1|0}}do{if((v|0)==65031){F=gGq(24576)|0;c[Q>>2]=F;if((F|0)==0){P=0;break}gGz(F|0,0,24576);P=F}}while(0);c[3529062]=P;c[2438700]=131071;c[3529060]=H;a[7461784]=1;F=9726816;c[F>>2]=0;c[F+4>>2]=0;F=9726800;c[F>>2]=0;c[F+4>>2]=0;c[2429638]=0;c[2437692]=8;c[2431704]=-8;c[2431700]=0;c[2431705]=-8;c[2431701]=0;c[2431706]=-8;c[2431702]=0;F=c[3530710]|0;c[2438136]=0;G=0;while(1){if((G|0)>=1024){R=0;break}S=9638528+(G<<2)|0;if((c[S>>2]|0)==0){v=65036;break}else{G=G+1|0}}do{if((v|0)==65036){G=gGq(1024)|0;c[S>>2]=G;if((G|0)==0){R=0;break}gGz(G|0,0,1024);R=G}}while(0);c[3529066]=R;c[2438702]=2097151;c[3529064]=F;a[7461792]=1;c[2437694]=12;c[2438136]=-8;G=c[642608+(c[2436]<<2)>>2]|0;H=c[G+128>>2]|0;if((c[G+52>>2]&4|0)==0){c[2113068]=H;B=c[G+132>>2]|0;c[2113070]=B;c[2443814]=H;c[2440436]=B;T=H;U=B}else{c[2113070]=H;B=c[G+132>>2]|0;c[2113068]=B;c[2440436]=H;c[2443814]=B;T=B;U=H}H=ag(T<<1,U)|0;B=gGq(H)|0;c[2112926]=B;if((B|0)!=0){gGz(B|0,0,H|0)}a[9625016]=0;H=c[2414808]|0;gGz(H|0,0,(c[2411868]|0)-H|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];H=c[3532592]|0;if((H|0)!=0){gGC(9104152,H|0,280)|0}c[2113054]=c[2113060]}RI();H=c[2394]|0;B=c[14130368+(H<<2)>>2]|0;if((B|0)!=0){gGC(B|0,9104152,280)|0}c[8452240+(H<<2)>>2]=c[2113054];c[2394]=1;c[2112932]=c[3532597];H=c[3532593]|0;if((H|0)!=0){gGC(9104152,H|0,280)|0}c[2113054]=c[2113061];RI();H=c[2394]|0;B=c[14130368+(H<<2)>>2]|0;if((B|0)!=0){gGC(B|0,9104152,280)|0}c[8452240+(H<<2)>>2]=c[2113054];c[2394]=-1;H=c[2439330]|0;B=(H|0)==0;if(!B){G=H;gGC(9706056,G|0,76)|0}G=c[2438118]|0;c[2433530]=G;y=c[3528484]|0;c[2076596]=y;w=c[2417276]|0;c[3541536]=w;c[1836236]=0;gGz(9706056,0,76);if(!B){B=H;gGC(B|0,9706056,76)|0}c[2438118]=G;c[3528484]=y;c[2417276]=w;c[1836236]=-1;mx(0);blH();c[2430488]=0;c[2429402]=0;c[2444178]=0;c[2385604]=0;x=0;i=e;return x|0}}while(0);c[2415100]=0;x=1;i=e;return x|0}function bg6(){var a=0,b=0,d=0,e=0,f=0;c[2113070]=0;c[2113068]=0;a=c[2112926]|0;if((a|0)!=0){gGr(a);c[2112926]=0}blI();if((c[2392]|0)>=0){a=0;do{b=14130368+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}b=14130384+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}a=a+1|0;}while((a|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;fwZ();a=c[2424800]|0;if((a|0)!=0){gGr(a);c[2424800]=0}a=c[2418166]|0;if((a|0)!=0){gGr(a);c[2418166]=0}a=c[3531464]|0;c[a+44344>>2]=0;c[a+44348>>2]=0;if((a|0)!=0){gGr(a);c[3531464]=0}a=c[2406684]|0;if((a|0)!=0){gGr(a);c[2406684]=0}a=c[2415100]|0;b=0;while(1){if((b|0)>=1024){e=65119;break}f=9638528+(b<<2)|0;if((c[f>>2]|0)==(a|0)){break}else{b=b+1|0}}if((e|0)==65119){c[2415100]=0;return 0}gGr(a);c[f>>2]=0;c[2415100]=0;return 0}function bg7(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((a[9625016]|0)!=0){a[9625016]=0;d=c[2414808]|0;gGz(d|0,0,(c[2411868]|0)-d|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=1;c[2112932]=c[3532597];d=c[3532593]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113061];RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;h=c[2417276]|0;c[3541536]=h;c[1836236]=0;gGz(9706056,0,76);if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=h;c[1836236]=-1;mx(0);blH();c[2430488]=0;c[2429402]=0;c[2444178]=0;c[2385604]=0}gGz(9550968,-1|0,6);h=0;g=-1;f=-1;e=-1;do{g=((a[9634384+h|0]&1)<<h^g&65535)&65535;f=((a[9632144+h|0]&1)<<h^f&65535)&65535;e=((a[9630064+h|0]&1)<<h^e&65535)&65535;h=h+1|0;}while((h|0)<8);b[4775484]=g;b[4775485]=f;b[4775486]=e;if((f&3)==0){g=f|3;b[4775485]=g;i=g}else{i=f}if((i&12)==0){b[4775485]=i|12}if((e&3)==0){i=e|3;b[4775486]=i;j=i}else{j=e}if((j&12)==0){b[4775486]=j|12}j=c[2392]|0;if((j|0)>=0){gGz(8452240,0,((j|0)>0?(j<<2)+4|0:4)|0)}c[2113054]=0;j=c[2439330]|0;if((j|0)!=0){e=j;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;e=0;j=0;i=0;f=0;while(1){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060]}g=j+1|0;h=g*1666|0;d=h-e|0;c[2113056]=d;k=RG(d)|0;c[2113054]=(c[2113054]|0)+k;c[2276108]=-1;c[2113056]=-1;d=k+e|0;k=(j|0)==99;do{if(k&(c[2444178]|0)!=0){c[8452200+(c[2394]<<2)>>2]=8194;c[2276080]=512;if((c[2276079]|0)>>>0>=512){break}RH(2)}}while(0);l=c[2394]|0;m=c[14130368+(l<<2)>>2]|0;if((m|0)!=0){gGC(m|0,9104152,280)|0}c[8452240+(l<<2)>>2]=c[2113054];c[2394]=-1;if((c[2429402]|0)!=0){c[2394]=1;c[2112932]=c[3532597];l=c[3532593]|0;if((l|0)!=0){gGC(9104152,l|0,280)|0}l=c[2113061]|0;c[2113054]=l;m=h-l-(c[2113056]|0)+(c[2276108]|0)|0;c[2113056]=m;l=RG(m)|0;c[2113054]=(c[2113054]|0)+l;c[2276108]=-1;c[2113056]=-1;do{if((c[2429632]|0)!=0){c[8452200+(c[2394]<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0>=1024){break}RH(4)}}while(0);do{if(k){if((c[2385604]&1|0)==0){break}c[8452200+(c[2394]<<2)>>2]=8193;c[2276080]=256;if((c[2276079]|0)>>>0>=256){break}RH(1)}else{if((j|0)!=49){break}if((c[2385604]&2|0)==0){break}c[8452200+(c[2394]<<2)>>2]=8194;c[2276080]=512;if((c[2276079]|0)>>>0>=512){break}RH(2)}}while(0);k=c[2394]|0;h=c[14130368+(k<<2)>>2]|0;if((h|0)!=0){gGC(h|0,9104152,280)|0}c[8452240+(k<<2)>>2]=c[2113054];c[2394]=-1}k=(g*596|0)-i|0;do{if((k|0)<1){n=0}else{if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){h=gfc(k)|0;c[2433530]=(c[2433530]|0)+h;n=h;break}else{c[2433530]=(c[2433530]|0)+k;n=k;break}}}while(0);k=c[2112964]|0;if((k|0)==0){o=f}else{h=a[9688]|0?5:0;l=k+(f<<1<<1)|0;gg[c[3542124]&4095](l,h);TH(0,l,h);o=h+f|0}c[2429632]=0;if((g|0)<100){e=d;j=g;i=n+i|0;f=o}else{break}}f=c[2112964]|0;do{if((f|0)!=0){i=a[9688]|0?534:0;n=i-o|0;if((i|0)==(o|0)){break}i=f+(o<<1<<1)|0;gg[c[3542124]&4095](i,n);TH(0,i,n)}}while(0);o=c[1836236]|0;f=c[9757320+(o<<2)>>2]|0;if((f|0)!=0){n=f;gGC(n|0,9706056,76)|0}c[9752472+(o<<2)>>2]=c[2433530];c[14113936+(o<<2)>>2]=c[2076596];c[9669104+(o<<2)>>2]=c[3541536];c[1836236]=-1;if((c[2112968]|0)==0){return 0}bg8()|0;return 0}function bg8(){var d=0,e=0,f=0,g=0,h=0,i=0;if((a[9548008]|0)!=0){d=c[2387282]|0;e=c[3530186]|0;f=0;do{g=b[d+(f<<1)>>1]|0;c[e+(f<<2)>>2]=((g&65535)>>>10<<3&248)<<8|((g&255)<<3&255)>>>3|(((g&65535)>>>5<<3&255|(g&65535)>>>7&4)&255)<<3&2016;f=f+1|0;}while((f|0)<2048)}f=c[3529062]|0;a[f+7552|0]=16;a[9720736]=0;a[9720737]=1;a[f+7936|0]=50;a[9720738]=2;a[9720739]=3;bpj();f=c[2443454]|0;e=c[2439910]|0;d=0;do{g=a[f+(d^1)|0]|0;h=d<<1;a[e+h|0]=(g&255)>>>4;a[e+(h|1)|0]=g&15;d=d+1|0;}while((d|0)<131072);if((c[2430488]|0)==0){bpk(1,1,e);bpl(c[2439874]|0,3);bpl(c[2439874]|0,1);bpl(c[2439874]|0,0);bpk(2,0,c[2439910]|0);bpk(0,0,c[2439910]|0);bpl(c[2439874]|0,2);i=c[3530186]|0;R8(i);return 0}else{bpk(0,1,e);bpk(1,0,c[2439910]|0);bpk(2,0,c[2439910]|0);bpl(c[2439874]|0,2);bpl(c[2439874]|0,1);bpl(c[2439874]|0,3);bpl(c[2439874]|0,0);i=c[3530186]|0;R8(i);return 0}return 0}function bg9(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;f=i;i=i+208|0;g=f|0;h=f+16|0;j=f+48|0;k=f+64|0;l=f+80|0;m=f+96|0;n=f+112|0;o=f+128|0;p=f+144|0;q=f+160|0;r=f+176|0;s=f+192|0;t=(e|0)==0;if(!t){c[e>>2]=169732}if((b&96|0)!=0){gGz(s|0,0,12);u=c[2414808]|0;c[s>>2]=u;c[s+4>>2]=(c[2411868]|0)-u;c[s+12>>2]=162152;u=c[2076592]|0;gj[u&4095](s)|0;s=n|0;if((b&64|0)==0){fw$(b);v=g;w=h|0}else{gGz(m|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){u=n+9|0;n=l;x=l|0;y=l+4|0;z=l+12|0;A=m|0;B=m+4|0;C=m+12|0;D=0;do{gGC(s|0,614896,11)|0;a[u]=D+48&255;E=8452256+(D<<2)|0;gGz(n|0,0,12);c[x>>2]=E;c[y>>2]=4;c[z>>2]=164976;gj[c[2076592]&4095](l)|0;if((c[E>>2]|0)!=0){c[A>>2]=c[14130368+(D<<2)>>2];c[B>>2]=c[8452184+(D<<2)>>2];c[C>>2]=s;E=c[2076592]|0;gj[E&4095](m)|0}D=D+1|0;}while((D|0)<=(c[2392]|0))}fw$(b);gGz(k|0,0,12);c[k>>2]=8453216;c[k+4>>2]=4;c[k+12>>2]=107480;D=c[2076592]|0;gj[D&4095](k)|0;gGz(j|0,0,12);c[j>>2]=14168504;c[j+4>>2]=256;c[j+12>>2]=476464;k=c[2076592]|0;gj[k&4095](j)|0;if((b&2|0)==0){F=g;G=h|0}else{j=0;do{mv(0,j,d[14168504+j|0]|0);j=j+1|0;}while((j|0)<256);F=g;G=h|0}if(!t){c[e>>2]=169619}e=h|0;cC(e|0,170224,(h=i,i=i+8|0,c[h>>2]=0,h)|0)|0;i=h;c[g>>2]=9699512;c[g+4>>2]=64;c[g+8>>2]=0;c[g+12>>2]=e;e=c[2076592]|0;gj[e&4095](g)|0;v=F;w=G}blJ(b);gGz(r|0,0,12);c[r>>2]=9721952;c[r+4>>2]=4;c[r+12>>2]=554744;G=c[2076592]|0;gj[G&4095](r)|0;gGz(q|0,0,12);c[q>>2]=9717608;c[q+4>>2]=4;c[q+12>>2]=540008;r=c[2076592]|0;gj[r&4095](q)|0;gGz(p|0,0,12);c[p>>2]=9776712;c[p+4>>2]=4;c[p+12>>2]=526744;q=c[2076592]|0;gj[q&4095](p)|0;gGz(o|0,0,12);c[o>>2]=9542416;c[o+4>>2]=4;c[o+12>>2]=512744;p=c[2076592]|0;gj[p&4095](o)|0}if((b&2|0)==0){i=f;return 0}b=c[2443454]|0;o=c[2439910]|0;p=0;do{q=a[b+(p^1)|0]|0;r=p<<1;a[o+r|0]=(q&255)>>>4;a[o+(r|1)|0]=q&15;p=p+1|0;}while((p|0)<131072);i=f;return 0}function bha(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>24){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1538420+(b*112|0)>>2];c[a+104>>2]=c[1538424+(b*112|0)>>2];c[a+108>>2]=c[1538428+(b*112|0)>>2];d=0;return d|0}function bhb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<25&(d|0)==0)){e=1;return e|0}c[a>>2]=1538320+(b*112|0);e=0;return e|0}function bhc(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>24){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2818292+(b*112|0)>>2];c[a+104>>2]=c[2818296+(b*112|0)>>2];c[a+108>>2]=c[2818300+(b*112|0)>>2];d=0;return d|0}function bhd(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<25&(d|0)==0)){e=1;return e|0}c[a>>2]=2818192+(b*112|0);e=0;return e|0}function bhe(b){b=b|0;a[9681232]=((b>>4)*17|0)&255;a[9681233]=0;c[2424878]=9681232;a[9681234]=0;a[9681235]=((b&15)*17|0)&255;return}function bhf(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;g=c[e>>2]|0;c[d>>2]=g<<8&256|g<<7&3584|c[d>>2]&4095;c[e>>2]=((c[e>>2]|0)>>>5&7)+(c[602592+(a<<2)>>2]|0);return}function bhg(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;c[d>>2]=(c[b>>2]|0)>>>5&3;c[a>>2]=(c[a>>2]|c[b>>2]<<13)&16383;c[b>>2]=(c[b>>2]|0)>>>1&15|16;return}function bhh(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=0;while(1){if((f|0)>=1024){g=0;break}h=9638528+(f<<2)|0;if((c[h>>2]|0)==0){i=65259;break}else{f=f+1|0}}do{if((i|0)==65259){f=gGq(4096)|0;c[h>>2]=f;if((f|0)==0){g=0;break}gGz(f|0,0,4096);g=f}}while(0);c[3529044]=g;c[3529048]=b;a[7201808]=1;c[2437688]=d;c[3529042]=0;c[3529040]=0;c[2430182]=1;d=c[2308882]|0;if((d|0)!=0){j=d;c[3527110]=j;c[2443316]=e;a[7461768]=1;return}d=c[642608+(c[2436]<<2)>>2]|0;b=ag(c[d+128>>2]<<1,c[d+132>>2]|0)|0;d=0;while(1){if((d|0)>=1024){k=0;break}l=9638528+(d<<2)|0;if((c[l>>2]|0)==0){i=65265;break}else{d=d+1|0}}do{if((i|0)==65265){d=gGq(b)|0;c[l>>2]=d;if((d|0)==0){k=0;break}gGz(d|0,0,b|0);k=d}}while(0);c[2308882]=k;j=k;c[3527110]=j;c[2443316]=e;a[7461768]=1;return}function bhi(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0;h=i;i=i+1560|0;j=h|0;k=h+512|0;l=h+1536|0;m=h+1544|0;n=h+1552|0;o=j|0;gGz(o|0,1,256);a[o]=0;p=h+256|0;gGz(p|0,2,256);a[p]=0;q=d[14108485]|0;r=q&1;s=q&2;q=(d[14108480]<<8|d[14108481])<<16>>16;t=(d[14108482]<<8|d[14108483])<<16>>16;u=c[3529044]|0;v=c[2113068]|0;w=c[2443316]|0;if((w&1|0)==0){x=-1}else{x=(w&2|0)==0?0:3}w=a[7461816]|0;y=(w^1)<<31>>31;if(w){w=0;z=0;while(1){A=e[u+(z<<1)>>1]|0;if((A&32768|0)==0|(A&255|0)==(y|0)){B=w}else{c[k+(w<<2)>>2]=z;B=w+1|0}A=z+8|0;if((A|0)<2048){w=B;z=A}else{C=B;break}}}else{B=0;z=0;while(1){if((b[u+(z<<1)>>1]|0)<0){c[k+(B<<2)>>2]=z;D=B+1|0}else{D=B}w=z+8|0;if((w|0)<2048){B=D;z=w}else{C=D;break}}}D=C-1|0;z=(D|0)>0;do{if((b[7054230]&16)==0){if(z){E=0}else{break}do{B=k+(E<<2)|0;w=c[B>>2]|0;E=E+1|0;if((E|0)<(C|0)){y=E;A=b[u+(w<<1)>>1]&255;F=w;while(1){w=k+(y<<2)|0;G=c[w>>2]|0;H=b[u+(G<<1)>>1]&255;c[m>>2]=H;if((A|0)>(H|0)){I=F;J=A}else{c[w>>2]=F;c[B>>2]=G;I=G;J=H}H=y+1|0;if((H|0)<(C|0)){y=H;A=J;F=I}else{break}}}}while((E|0)<(D|0))}else{if(z){K=0}else{break}do{F=k+(K<<2)|0;A=c[F>>2]|0;K=K+1|0;if((K|0)<(C|0)){y=K;B=b[u+(A<<1)>>1]&255;H=A;while(1){A=k+(y<<2)|0;G=c[A>>2]|0;w=b[u+(G<<1)>>1]&255;c[m>>2]=w;if((B|0)<(w|0)){L=H;M=B}else{c[A>>2]=H;c[F>>2]=G;L=G;M=w}w=y+1|0;if((w|0)<(C|0)){y=w;B=M;H=L}else{break}}}}while((K|0)<(D|0))}}while(0);if((D|0)<0){i=h;return}K=(x|0)<0;L=(r|0)==0;r=(s|0)==0;s=j+15|0;j=(x|0)>-1;M=L?1:v;v=q;q=t;t=0;while(1){C=c[k+(t<<2)>>2]|0;c[m>>2]=e[u+(C+1<<1)>>1]|0;z=e[u+(C+6<<1)>>1]|0;c[l>>2]=z;c[n>>2]=0;gG[c[2437688]&255](m,l,n);L84431:do{if((c[n>>2]|0)==(g|0)){E=e[u+(C<<1)>>1]|0;I=E>>>8&3;J=1<<I;H=E>>>10&3;B=1<<H;y=c[m>>2]|0;F=y&1;w=y>>>1&1;G=(y&4|0)==0?F:F|2;F=(y&8|0)==0?w:w|2;w=(y&16|0)==0?G:G|4;G=(y&32|0)==0?F:F|4;c[m>>2]=y&-64;y=b[u+(C+2<<1)>>1]|0;F=b[u+(C+3<<1)>>1]|0;A=(c[2430182]|0)==0;if(A){N=F;O=y;P=q;Q=v}else{N=F&1023;O=y&1023;P=q&1023;Q=v&1023}y=b[u+(C+4<<1)>>1]&1023;if((y|0)==0){R=8388608}else{R=((y>>>1|4194304)>>>0)/(y>>>0)|0}do{if((E&16384|0)==0){F=b[u+(C+5<<1)>>1]&1023;if((F|0)==0){S=0;T=8388608;break}S=F;T=((F>>>1|4194304)>>>0)/(F>>>0)|0}else{S=y;T=R}}while(0);do{if((a[14108485]&8)==0){if((S|0)!=64){U=N;V=0;W=T;break}U=N;V=(y|0)==64|0;W=T}else{U=(N>>1)+M|0;V=0;W=T>>1}}while(0);y=E&8192;F=(z&16384|0)!=0;X=F?0:E&4096;Y=z&32768;Z=c[l>>2]|0;do{if((Z|0)==-1){if(K){_=P;$=Q;break L84431}c[l>>2]=0;aa=p;ab=0;ac=-1;ad=0}else{if(!j){aa=o;ab=0;ac=0;ad=Z;break}ae=((Z&536870912|0)==0?z>>>10:Z>>>20)&3;if((ae|0)==0){aa=o;ab=0;ac=0;ad=Z;break}aa=o;ab=(ae-1&x|0)==1|0;ac=ae;ad=Z}}while(0);c[l>>2]=ad&65535;do{if(L){af=U;ah=X}else{Z=-U|0;if(F){af=Z;ah=X;break}af=Z;ah=X>>>12^1}}while(0);do{if(r){ai=O;aj=y}else{X=-O|0;if((Y|0)!=0){ai=X;aj=y;break}ai=X;aj=y>>>13^1}}while(0);y=af-Q|0;if(A){ak=y;al=-(ai+P|0)|0}else{X=y&1023;Z=-(ai+P|0)|0;E=Z&1023;ak=X>>>0>767?y|-1024:X;al=E>>>0>639?Z|-1024:E}E=(ak+16+(c[3529042]|0)&1023)+(-16-(W<<I>>13))|0;Z=(al+16-(c[3529040]|0)&1023)+(-16-(R<<H>>13))|0;X=(ac|0)!=0;a[s]=X?2:1;if((B|0)<=0){_=P;$=Q;break}y=(J|0)>0;ae=(ah|0)==0;am=J+7|0;an=w+am|0;ao=(Y|0)!=0;ap=(aj|0)==0;aq=B+7|0;ar=G+aq|0;as=X|(aa|0)==(p|0);X=ao&(B|0)==1;at=ap&1;au=(V|0)==0;av=(ah|0)!=0;aw=0;ax=0;while(1){ay=((ag(aw,R)|0)+2048>>12)+Z|0;az=aw+1|0;aA=((ag(az,R)|0)+2048>>12)+Z-ay|0;L84470:do{if(y){aB=ap^(aw<<1|0)>=(B|0);aC=aA<<12;aD=aA<<16>>4;aE=ao?aB?616688+((ar+ax&7)<<2)|0:616688+((aw+G&7)<<2)|0:616688+(((ap?aw:ax+aq|0)+G&7)<<2)|0;aF=ao?aB&1:aj;aB=(aF|0)==0|0;aG=0;aH=0;while(1){aI=((ag(aG,W)|0)+2048>>12)+E|0;aJ=aG+1|0;aK=((ag(aJ,W)|0)+2048>>12)+E-aI|0;aL=c[m>>2]|0;do{if(F){if(ae^(aG<<1|0)<(J|0)){aM=1;aN=616720+((an+aH&7)<<2)|0;break}else{aM=0;aN=616720+((aG+w&7)<<2)|0;break}}else{aM=ah;aN=616720+(((ae?aG:aH+am|0)+w&7)<<2)|0}}while(0);aO=(c[aN>>2]|0)+aL+(c[aE>>2]|0)|0;L84481:do{if(as){if(X){aP=aK<<12;bhj(f,aO,c[l>>2]<<4,aa,aI,ay,ah,at,aP,aC,ab);aQ=aP}else{aQ=aK<<12}bhj(f,aO,c[l>>2]<<4,aa,aI,ay,ah,aj,aQ,aC,ab)}else{do{if(X){aP=c[2112926]|0;aR=c[l>>2]|0;if(au){aS=aK<<16>>4;S2(aP,f,aO,aR<<4,0,aI,ay,aM,aB,aS,aD);aT=aS;aU=65358;break}if(ap){if(av){SN(aP,aO,aI,ay,aR,4,0,0,f);aV=c[l>>2]|0;aW=aP;aU=65356;break}else{SL(aP,aO,aI,ay,aR,4,0,0,f);aX=c[l>>2]|0;aY=aP;aU=65357;break}}else{if(av){SJ(aP,aO,aI,ay,aR,4,0,0,f);aZ=c[l>>2]|0;a_=aP;aU=65353;break}else{SH(aP,aO,aI,ay,aR,4,0,0,f);aU=65349;break}}}else{aU=65349}}while(0);do{if((aU|0)==65349){aU=0;if(au){aT=aK<<16>>4;aU=65358;break}aR=c[2112926]|0;aP=c[l>>2]|0;if(ap){if(av){aV=aP;aW=aR;aU=65356;break}else{aX=aP;aY=aR;aU=65357;break}}if(av){aZ=aP;a_=aR;aU=65353;break}SL(aR,aO,aI,ay,aP,4,0,0,f);break L84481}}while(0);if((aU|0)==65356){aU=0;SJ(aW,aO,aI,ay,aV,4,0,0,f);break}else if((aU|0)==65357){aU=0;SH(aY,aO,aI,ay,aX,4,0,0,f);break}else if((aU|0)==65353){aU=0;SN(a_,aO,aI,ay,aZ,4,0,0,f);break}else if((aU|0)==65358){aU=0;S2(c[2112926]|0,f,aO,c[l>>2]<<4,0,aI,ay,aM,aF,aT,aD);break}}}while(0);if((aJ|0)>=(J|0)){break L84470}aI=~aG;aG=aJ;aH=aI}}}while(0);ay=~aw;if((az|0)<(B|0)){aw=az;ax=ay}else{_=P;$=Q;break}}}else{_=q;$=v}}while(0);z=t+1|0;if((z|0)>(D|0)){break}else{v=$;q=_;t=z}}i=h;return}function bhj(d,f,g,h,i,j,k,l,m,n,o){d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;p=(n<<4)+32768>>16;n=(m<<4)+32768>>16;if((p|0)==0|(n|0)==0){return}m=n+i|0;if((m|0)<0){return}q=p+j|0;r=c[2113068]|0;s=c[2113070]|0;if(!((q|0)>-1&(r|0)>(i|0)&(s|0)>(j|0))){return}t=(l|0)==0?0:240;l=(k|0)==0?t:t|15;t=65536/(p|0)|0;k=65536/(n|0)|0;u=(j|0)<0?-j|0:0;v=(i|0)<0?-i|0:0;w=(q|0)<(s|0)?p:s-j|0;s=(m|0)<(r|0)?n:r-i|0;n=f<<8;f=(ag(r,u+j|0)|0)+i|0;i=32768>>>(o>>>0);if(!((u|0)<(w|0)&(v|0)<(s|0))){return}o=(c[3527110]|0)+(f<<1)|0;j=(c[2112926]|0)+(f<<1)|0;f=u;while(1){u=(ag(f,t)|0)>>12<<4;m=v;do{p=a[d+((((ag(m,k)|0)>>12)+u^l)+n)|0]|0;q=p&255;do{if(p<<24>>24!=0){x=(q|g)&65535;if((a[h+q|0]|0)==2){b[o+(m<<1)>>1]=x;y=j+(m<<1)|0;b[y>>1]=(e[y>>1]|i)&65535;break}else{b[j+(m<<1)>>1]=x;break}}}while(0);m=m+1|0;}while((m|0)<(s|0));m=f+1|0;if((m|0)<(w|0)){o=o+(r<<1)|0;j=j+(r<<1)|0;f=m}else{break}}return}function bhk(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((e|0)==8068){a[c[3528366]|0]=d;return}else if((e|0)==8072){a[14125144]=-1;a[9706117]=1;return}else if((e|0)==8076){return}else{if((e&49152|0)!=0){return}blF(e&16383,d&255);return}}function bhl(b){b=b|0;var c=0,d=0;c=b&65535;L84559:do{switch(c|0){case 8084:{d=a[9550962]&15|a[9635682];break};case 8086:{d=a[9550961]|0;break};case 8088:{d=a[9635681]|0;break};case 8087:{d=a[9635680]|0;break};case 8085:{d=a[9550960]|0;break};default:{if((c&49152|0)!=0){d=0;break L84559}d=blE(c&16383)|0}}}while(0);return d|0}function bhm(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((e|0)==49152){c[2113304]=d&255;return}else if((e|0)==49153){e=c[2113304]|0;a[14168504+e|0]=d;mv(0,e,d&255);return}else{return}}function bhn(b){b=b|0;var d=0,e=0;d=b&65535;if((d|0)==40960){a[9706117]=0;e=a[c[3528366]|0]|0;return e|0}else if((d|0)==49153){e=c[(c[3531464]|0)+4240>>2]&255;return e|0}else{e=0;return e|0}return 0}function bho(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4800996+(b*112|0)>>2];c[a+104>>2]=c[4801e3+(b*112|0)>>2];c[a+108>>2]=c[4801004+(b*112|0)>>2];d=0;return d|0}function bhp(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=4800896+(b*112|0);e=0;return e|0}function bhq(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=2002368+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function bhr(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>49){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5566936+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function bhs(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;e=i;i=i+240|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;c[2415098]=0;c[2387380]=0;c[2386004]=65536;c[3530944]=131072;c[3530708]=262144;c[2439908]=393216;c[2439872]=655360;c[3530184]=917504;c[2414806]=921600;c[3531090]=921600;c[2387404]=923648;c[2387280]=929792;c[2386156]=931840;c[3528366]=933888;c[2438170]=933889;c[2411866]=933890;l=0;while(1){if((l|0)>=1024){break}m=9638528+(l<<2)|0;if((c[m>>2]|0)==0){n=65446;break}else{l=l+1|0}}do{if((n|0)==65446){l=gGq(933890)|0;c[m>>2]=l;if((l|0)==0){break}c[2415098]=l;gGz(l|0,0,933890);c[2387380]=l;c[2386004]=l+65536;c[3530944]=l+131072;c[3530708]=l+262144;c[2439908]=l+393216;c[2439872]=l+655360;c[3530184]=l+917504;o=l+921600|0;c[2414806]=o;c[3531090]=o;c[2387404]=l+923648;c[2387280]=l+929792;c[2386156]=l+931840;c[3528366]=l+933888;c[2438170]=l+933889;o=l+933890|0;c[2411866]=o;c[2414416]=o;if((c[3542200]|0)==0){p=1;i=e;return p|0}o=j+108|0;c[o>>2]=0;q=j+100|0;c[q>>2]=0;r=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[r&16383](j,0)|0;do{if((c[o>>2]|0)!=0){r=c[q>>2]|0;c[k>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](k,0,0)|0;if((r|0)<1){p=1;i=e;return p|0}if((gzL(l,0,0)|0)==0){break}else{p=1}i=e;return p|0}}while(0);l=c[2386004]|0;if((c[3542200]|0)==0){p=1;i=e;return p|0}q=f+108|0;c[q>>2]=0;o=f+100|0;c[o>>2]=0;r=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[r&16383](f,1)|0;do{if((c[q>>2]|0)!=0){r=c[o>>2]|0;c[g>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](g,1,0)|0;if((r|0)<1){p=1;i=e;return p|0}if((gzL(l,0,1)|0)==0){break}else{p=1}i=e;return p|0}}while(0);if((R6(c[3530944]|0,2,2)|0)!=0){p=1;i=e;return p|0}if((R6((c[3530944]|0)+1|0,3,2)|0)!=0){p=1;i=e;return p|0}if((R6((c[3530944]|0)+65536|0,4,2)|0)!=0){p=1;i=e;return p|0}if((R6((c[3530944]|0)+65537|0,5,2)|0)!=0){p=1;i=e;return p|0}if((R6(c[3530708]|0,6,2)|0)!=0){p=1;i=e;return p|0}if((R6((c[3530708]|0)+1|0,7,2)|0)!=0){p=1;i=e;return p|0}if((R6((c[3530708]|0)+65536|0,8,2)|0)!=0){p=1;i=e;return p|0}if((R6((c[3530708]|0)+65537|0,9,2)|0)!=0){p=1;i=e;return p|0}l=c[3530944]|0;blG(l,65536);o=c[3530708]|0;blG(o,65536);q=c[2439908]|0;r=0;do{s=r<<6;gGz(q+s|0,0,64);t=r<<8;u=0;do{v=1<<3-u;w=(c[611632+(u<<2)>>2]|0)+t|0;x=0;do{y=w+(c[3946808+(x<<2)>>2]|0)|0;z=(x<<3)+s|0;A=0;do{B=y+(c[6669416+(A<<2)>>2]|0)|0;if(((d[l+((B|0)/8|0)|0]|0)&128>>>((B&7)>>>0)|0)!=0){B=q+(z+A)|0;a[B]=(d[B]|0|v)&255}A=A+1|0;}while((A|0)<8);x=x+1|0;}while((x|0)<8);u=u+1|0;}while((u|0)<4);r=r+1|0;}while((r|0)<4096);r=c[2439872]|0;q=0;do{l=q<<8;gGz(r+l|0,0,256);u=q<<10;s=0;do{t=1<<3-s;x=(c[611400+(s<<2)>>2]|0)+u|0;v=0;do{w=x+(c[3946808+(v<<2)>>2]|0)|0;A=(v<<4)+l|0;z=0;do{y=w+(c[6669416+(z<<2)>>2]|0)|0;if(((d[o+((y|0)/8|0)|0]|0)&128>>>((y&7)>>>0)|0)!=0){y=r+(A+z)|0;a[y]=(d[y]|0|t)&255}z=z+1|0;}while((z|0)<16);v=v+1|0;}while((v|0)<16);s=s+1|0;}while((s|0)<4);q=q+1|0;}while((q|0)<1024);c[2410674]=1748;gGz(9699632,0,3072);q=c[2427044]|0;c[9681616+(q<<3)>>2]=715288;c[9681620+(q<<3)>>2]=0;c[2427044]=q+1;c[363094]=0;q=c[2387404]|0;r=0;o=0;while(1){s=o+64|0;l=q+(o<<8)|0;c[9699632+(s<<2)>>2]=l;c[9700656+(s<<2)>>2]=l;c[9701680+(s<<2)>>2]=l;l=r+1&65535;if((l&65535)<24){r=l;o=l&65535}else{break}}o=c[3531090]|0;c[2424996]=o;c[2425252]=o;c[2425508]=o;r=o+256|0;c[2424997]=r;c[2425253]=r;c[2425509]=r;r=o+512|0;c[2424998]=r;c[2425254]=r;c[2425510]=r;r=o+768|0;c[2424999]=r;c[2425255]=r;c[2425511]=r;r=o+1024|0;c[2425e3]=r;c[2425256]=r;c[2425512]=r;r=o+1280|0;c[2425001]=r;c[2425257]=r;c[2425513]=r;r=o+1536|0;c[2425002]=r;c[2425258]=r;c[2425514]=r;r=o+1792|0;c[2425003]=r;c[2425259]=r;c[2425515]=r;r=c[2387380]|0;o=0;q=0;while(1){l=q+96|0;s=r+(q<<8)|0;c[9699632+(l<<2)>>2]=s;c[9701680+(l<<2)>>2]=s;s=o+1&65535;if((s&65535)<32){o=s;q=s&65535}else{C=0;D=0;break}}while(1){q=D+128|0;o=r+((D<<8)+32768)|0;c[9699632+(q<<2)>>2]=o;c[9701680+(q<<2)>>2]=o;o=C+1&65535;if((o&65535)<128){C=o;D=o&65535}else{break}}c[2444172]=1068;c[3528598]=2058;c[2410675]=810;c[363094]=-1;fwR(0);r=c[2439330]|0;o=(r|0)==0;if(!o){q=r;gGC(9706056,q|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];q=c[3528484]|0;c[2076596]=q;s=c[2417276]|0;c[3541536]=s;c[1836236]=0;l=c[2386004]|0;u=0;v=0;while(1){c[r+76+(v<<2)>>2]=l+(v<<8);t=u+1&65535;if((t&65535)>127){E=0;F=0;break}else{u=t;v=t&65535}}while(1){v=l+(F<<8)|0;c[r+76+(F+512<<2)>>2]=v;c[r+76+(F+768<<2)>>2]=v;v=E+1&65535;if((v&65535)>127){break}else{E=v;F=v&65535}}l=c[2386156]|0;c[r+588>>2]=l;v=l+256|0;c[r+592>>2]=v;u=l+512|0;c[r+596>>2]=u;t=l+768|0;c[r+600>>2]=t;x=l+1024|0;c[r+604>>2]=x;z=l+1280|0;c[r+608>>2]=z;A=l+1536|0;c[r+612>>2]=A;w=l+1792|0;c[r+616>>2]=w;c[r+1612>>2]=l;c[r+1616>>2]=v;c[r+1620>>2]=u;c[r+1624>>2]=t;c[r+1628>>2]=x;c[r+1632>>2]=z;c[r+1636>>2]=A;c[r+1640>>2]=w;c[r+2636>>2]=l;c[r+3660>>2]=l;c[r+2640>>2]=v;c[r+3664>>2]=v;c[r+2644>>2]=u;c[r+3668>>2]=u;c[r+2648>>2]=t;c[r+3672>>2]=t;c[r+2652>>2]=x;c[r+3676>>2]=x;c[r+2656>>2]=z;c[r+3680>>2]=z;c[r+2660>>2]=A;c[r+3684>>2]=A;c[r+2664>>2]=w;c[r+3688>>2]=w;c[r+4184>>2]=3198;c[r+4180>>2]=1794;if(!o){w=r;gGC(w|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=q;c[2417276]=s;c[1836236]=-1;w=a[9680]|0;A=w?32e3:0;if(w){if(a[9624]|0){w=A*3|0;z=55930;while(1){if((z|0)>(w|0)){z=z>>1}else{G=1222;H=z;break}}}else{G=2462;H=A}c[2429380]=H;c[3542124]=G;mw(3579545,H);z=gGq(262144)|0;c[2406684]=z;gGz(z|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(3579545,11025)}h[745421]=.6;c[2436794]=3;h[745420]=.6;c[2436792]=3;z=c[3530944]|0;w=0;while(1){if((w|0)>=1024){I=0;break}J=9638528+(w<<2)|0;if((c[J>>2]|0)==0){n=65505;break}else{w=w+1|0}}do{if((n|0)==65505){w=gGq(24576)|0;c[J>>2]=w;if((w|0)==0){I=0;break}gGz(w|0,0,24576);I=w}}while(0);c[3529062]=I;c[2438700]=131071;c[3529060]=z;a[7461784]=1;w=9726816;c[w>>2]=0;c[w+4>>2]=0;w=9726800;c[w>>2]=0;c[w+4>>2]=0;c[2429638]=0;c[2437692]=32;c[2431704]=8;c[2431700]=0;c[2431705]=8;c[2431701]=0;c[2431706]=8;c[2431702]=0;w=c[3530708]|0;c[2438136]=0;A=0;while(1){if((A|0)>=1024){K=0;break}L=9638528+(A<<2)|0;if((c[L>>2]|0)==0){n=65510;break}else{A=A+1|0}}do{if((n|0)==65510){A=gGq(1024)|0;c[L>>2]=A;if((A|0)==0){K=0;break}gGz(A|0,0,1024);K=A}}while(0);c[3529066]=K;c[2438702]=131071;c[3529064]=w;a[7461792]=1;c[2437694]=60;c[2438136]=8;A=c[642608+(c[2436]<<2)>>2]|0;z=c[A+128>>2]|0;if((c[A+52>>2]&4|0)==0){c[2113068]=z;s=c[A+132>>2]|0;c[2113070]=s;c[2443814]=z;c[2440436]=s;M=z;N=s}else{c[2113070]=z;s=c[A+132>>2]|0;c[2113068]=s;c[2440436]=z;c[2443814]=s;M=s;N=z}z=ag(M<<1,N)|0;s=gGq(z)|0;c[2112926]=s;if((s|0)!=0){gGz(s|0,0,z|0)}a[9625008]=0;z=c[2414806]|0;gGz(z|0,0,(c[2411866]|0)-z|0);c[363094]=0;c[2410673]=0;a[9642688]=0;a[9642689]=0;a[9642682]=0;a[9642683]=0;c[2410665]=0;a[9642680]=a[9642680]|80;z=c[2425163]|0;do{if((z|0)==0){s=c[3528598]|0;if((s|0)==0){O=0;P=0;break}A=gj[s&4095](-2)|0;s=c[2425163]|0;q=(A&255)<<8;if((s|0)!=0){Q=s;R=q;n=65521;break}s=c[3528598]|0;if((s|0)==0){O=0;P=q;break}O=gj[s&4095](-1)|0;P=q}else{Q=z;R=(d[z+254|0]|0)<<8;n=65521}}while(0);if((n|0)==65521){O=a[Q+255|0]|0;P=R}c[2410662]=O&255|P;c[363094]=-1;z=c[2439330]|0;w=(z|0)==0;if(!w){q=z;gGC(9706056,q|0,76)|0}q=c[2438118]|0;c[2433530]=q;s=c[3528484]|0;c[2076596]=s;A=c[2417276]|0;c[3541536]=A;c[1836236]=0;gGz(9706056,0,76);if(!w){w=z;gGC(w|0,9706056,76)|0}c[2438118]=q;c[3528484]=s;c[2417276]=A;c[1836236]=-1;mx(0);blH();p=0;i=e;return p|0}}while(0);c[2415098]=0;p=1;i=e;return p|0}function bht(){var a=0,b=0,d=0,e=0;c[2113070]=0;c[2113068]=0;a=c[2112926]|0;if((a|0)!=0){gGr(a);c[2112926]=0}blI();c[2444172]=0;c[3528598]=0;fwZ();a=c[3531464]|0;c[a+44344>>2]=0;c[a+44348>>2]=0;if((a|0)!=0){gGr(a);c[3531464]=0}a=c[2406684]|0;if((a|0)!=0){gGr(a);c[2406684]=0}a=c[2415098]|0;b=0;while(1){if((b|0)>=1024){d=65558;break}e=9638528+(b<<2)|0;if((c[e>>2]|0)==(a|0)){break}else{b=b+1|0}}if((d|0)==65558){c[2415098]=0;return 0}gGr(a);c[e>>2]=0;c[2415098]=0;return 0}function bhu(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((a[9625008]|0)!=0){a[9625008]=0;e=c[2414806]|0;gGz(e|0,0,(c[2411866]|0)-e|0);c[363094]=0;c[2410673]=0;a[9642688]=0;a[9642689]=0;a[9642682]=0;a[9642683]=0;c[2410665]=0;a[9642680]=a[9642680]|80;e=c[2425163]|0;do{if((e|0)==0){f=c[3528598]|0;if((f|0)==0){g=0;h=0;break}i=gj[f&4095](-2)|0;f=c[2425163]|0;j=(i&255)<<8;if((f|0)!=0){k=f;l=j;m=65564;break}f=c[3528598]|0;if((f|0)==0){g=0;h=j;break}g=gj[f&4095](-1)|0;h=j}else{k=e;l=d[e+254|0]<<8;m=65564}}while(0);if((m|0)==65564){g=a[k+255|0]|0;h=l}c[2410662]=g&255|h;c[363094]=-1;h=c[2439330]|0;g=(h|0)==0;if(!g){l=h;gGC(9706056,l|0,76)|0}l=c[2438118]|0;c[2433530]=l;k=c[3528484]|0;c[2076596]=k;m=c[2417276]|0;c[3541536]=m;c[1836236]=0;gGz(9706056,0,76);if(!g){g=h;gGC(g|0,9706056,76)|0}c[2438118]=l;c[3528484]=k;c[2417276]=m;c[1836236]=-1;mx(0);blH()}gGz(9550960,-1|0,3);m=0;k=-1;l=-1;g=-1;do{k=((a[9634376+m|0]&1)<<m^k&255)&255;l=((a[9632136+m|0]&1)<<m^l&255)&255;g=((a[9630056+m|0]&1)<<m^g&255)&255;m=m+1|0;}while((m|0)<8);a[9550960]=k;a[9550961]=l;a[9550962]=g;if((k&3)==0){g=k|3;a[9550960]=g;n=g}else{n=k}if((n&12)==0){a[9550960]=n|12}if((l&3)==0){n=l|3;a[9550961]=n;o=n}else{o=l}if((o&12)==0){a[9550961]=o|12}c[2410673]=0;o=c[2385548]|0;if((o|0)>0){gGz(9752472,0,((o|0)>1?o<<2:4)|0)}c[2433530]=0;o=c[2439330]|0;if((o|0)!=0){l=o;gGC(9706056,l|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;c[363094]=0;l=0;o=0;n=0;k=0;L84816:while(1){g=o;m=n;h=k;do{if((h|0)>=100){break L84816}h=h+1|0;m=(fNF((h*665|0)-m|0)|0)+m|0;e=(h*596|0)-g|0;do{if((e|0)<1){p=0}else{if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){j=gfc(e)|0;c[2433530]=(c[2433530]|0)+j;p=j;break}else{c[2433530]=(c[2433530]|0)+e;p=e;break}}}while(0);g=p+g|0;q=c[2112964]|0;}while((q|0)==0);e=a[9688]|0?5:0;gg[c[3542124]&4095](q+(l<<1<<1)|0,e);l=e+l|0;o=g;n=m;k=h}do{if((c[3541228]|0)!=0){if((a[c[2438170]|0]&3)!=0){break}fNE(0,1);fNF(0)|0;a[9642682]=0;fNF(0)|0}}while(0);k=c[2112964]|0;do{if((k|0)!=0){n=a[9688]|0?534:0;if((n|0)==(l|0)){break}gg[c[3542124]&4095](k+(l<<1<<1)|0,n-l|0)}}while(0);c[363094]=-1;l=c[1836236]|0;k=c[9757320+(l<<2)>>2]|0;if((k|0)!=0){n=k;gGC(n|0,9706056,76)|0}c[9752472+(l<<2)>>2]=c[2433530];c[14113936+(l<<2)>>2]=c[2076596];c[9669104+(l<<2)>>2]=c[3541536];c[1836236]=-1;if((c[2112968]|0)==0){return 0}bhv()|0;return 0}function bhv(){var d=0,e=0,f=0,g=0;if((a[9548e3]|0)!=0){d=c[3530184]|0;e=c[2387280]|0;f=0;do{g=ga(b[e+(f<<1)>>1]|0)|0;c[d+(f<<2)>>2]=((g&65535)>>>10<<3&65535)>>>3&31|((g&255)<<3&255)<<8|(((g&65535)>>>5<<3&255|(g&65535)>>>7&4)&255)<<3&2016;f=f+1|0;}while((f|0)<1024)}bpj();bpk(2,1,c[2439908]|0);bpl(c[2439872]|0,0);bpk(1,0,c[2439908]|0);bpl(c[2439872]|0,1);bpk(0,0,c[2439908]|0);R8(c[3530184]|0);return 0}function bhw(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+96|0;g=f|0;h=f+16|0;j=f+32|0;k=f+48|0;l=f+64|0;m=f+80|0;if((e|0)!=0){c[e>>2]=169733}if((b&96|0)!=0){gGz(m|0,0,12);e=c[2414806]|0;c[m>>2]=e;c[m+4>>2]=(c[2411866]|0)-e;c[m+12>>2]=162152;e=c[2076592]|0;gj[e&4095](m)|0;m=c[2410674]|0;e=c[2410675]|0;do{if((b&64|0)==0){c[2410674]=m;c[2410675]=e;fw$(b)}else{gGz(l|0,0,12);c[l>>2]=9642648;c[l+4>>2]=56;c[l+12>>2]=163840;n=c[2076592]|0;gj[n&4095](l)|0;gGz(k|0,0,12);c[k>>2]=9707480;c[k+4>>2]=2;c[k+12>>2]=501096;n=c[2076592]|0;gj[n&4095](k)|0;gGz(j|0,0,12);c[j>>2]=9707480;c[j+4>>2]=4;c[j+12>>2]=385184;n=c[2076592]|0;gj[n&4095](j)|0;c[2410674]=m;c[2410675]=e;fw$(b);gGz(h|0,0,12);c[h>>2]=8453216;c[h+4>>2]=4;c[h+12>>2]=107480;n=c[2076592]|0;gj[n&4095](h)|0;gGz(g|0,0,12);c[g>>2]=14168504;c[g+4>>2]=256;c[g+12>>2]=476464;n=c[2076592]|0;gj[n&4095](g)|0;if((b&2|0)==0){break}else{o=0}do{mv(0,o,d[14168504+o|0]|0);o=o+1|0;}while((o|0)<256)}}while(0);blJ(b)}if((b&2|0)==0){i=f;return 0}c[363094]=0;b=c[2438170]|0;o=a[b]|0;g=o&255;h=g<<13&24576;e=c[2387380]|0;m=0;j=0;while(1){k=j+96|0;l=e+((j<<8)+h)|0;c[9699632+(k<<2)>>2]=l;c[9701680+(k<<2)>>2]=l;l=m+1&65535;if((l&65535)<32){m=l;j=l&65535}else{break}}if((g&32|0)==0){j=c[2387280]|0;c[2424996]=j;c[2425252]=j;c[2425508]=j;m=j+256|0;c[2424997]=m;c[2425253]=m;c[2425509]=m;m=j+512|0;c[2424998]=m;c[2425254]=m;c[2425510]=m;m=j+768|0;c[2424999]=m;c[2425255]=m;c[2425511]=m;m=j+1024|0;c[2425e3]=m;c[2425256]=m;c[2425512]=m;m=j+1280|0;c[2425001]=m;c[2425257]=m;c[2425513]=m;p=j;q=j+1536|0}else{j=c[3531090]|0;c[2424996]=j;c[2425252]=j;c[2425508]=j;m=j+256|0;c[2424997]=m;c[2425253]=m;c[2425509]=m;m=j+512|0;c[2424998]=m;c[2425254]=m;c[2425510]=m;m=j+768|0;c[2424999]=m;c[2425255]=m;c[2425511]=m;m=j+1024|0;c[2425e3]=m;c[2425256]=m;c[2425512]=m;m=j+1280|0;c[2425001]=m;c[2425257]=m;c[2425513]=m;p=j;q=j+1536|0}c[2425002]=q;c[2425258]=q;c[2425514]=q;q=p+1792|0;c[2425003]=q;c[2425259]=q;c[2425515]=q;c[3541230]=g&64;a[b]=o;c[363094]=-1;i=f;return 0}function bhx(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5736892+(b*112|0)>>2];c[a+104>>2]=c[5736896+(b*112|0)>>2];c[a+108>>2]=c[5736900+(b*112|0)>>2];d=0;return d|0}function bhy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=5736792+(b*112|0);e=0;return e|0}function bhz(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=b<<13&24576;e=c[2387380]|0;f=0;g=0;while(1){h=g+96|0;i=e+((g<<8)+d)|0;c[9699632+(h<<2)>>2]=i;c[9701680+(h<<2)>>2]=i;i=f+1&65535;if((i&65535)<32){f=i;g=i&65535}else{break}}if((b&32|0)==0){g=c[2387280]|0;c[2424996]=g;c[2425252]=g;c[2425508]=g;f=g+256|0;c[2424997]=f;c[2425253]=f;c[2425509]=f;f=g+512|0;c[2424998]=f;c[2425254]=f;c[2425510]=f;f=g+768|0;c[2424999]=f;c[2425255]=f;c[2425511]=f;f=g+1024|0;c[2425e3]=f;c[2425256]=f;c[2425512]=f;f=g+1280|0;c[2425001]=f;c[2425257]=f;c[2425513]=f;j=g;k=g+1536|0;c[2425002]=k;c[2425258]=k;c[2425514]=k;l=j+1792|0;c[2425003]=l;c[2425259]=l;c[2425515]=l;m=b&64;c[3541230]=m;n=b&255;o=c[2438170]|0;a[o]=n;return}else{g=c[3531090]|0;c[2424996]=g;c[2425252]=g;c[2425508]=g;f=g+256|0;c[2424997]=f;c[2425253]=f;c[2425509]=f;f=g+512|0;c[2424998]=f;c[2425254]=f;c[2425510]=f;f=g+768|0;c[2424999]=f;c[2425255]=f;c[2425511]=f;f=g+1024|0;c[2425e3]=f;c[2425256]=f;c[2425512]=f;f=g+1280|0;c[2425001]=f;c[2425257]=f;c[2425513]=f;j=g;k=g+1536|0;c[2425002]=k;c[2425258]=k;c[2425514]=k;l=j+1792|0;c[2425003]=l;c[2425259]=l;c[2425515]=l;m=b&64;c[3541230]=m;n=b&255;o=c[2438170]|0;a[o]=n;return}}function bhA(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;c[d>>2]=(c[d>>2]|c[e>>2]<<8)&4095;c[e>>2]=(c[e>>2]|0)>>>5&7|a<<4;return}function bhB(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;c[d>>2]=(c[b>>2]|0)>>>4&1;c[a>>2]=c[a>>2]&1023;c[b>>2]=c[b>>2]&15|48;return}function bhC(a,d){a=a|0;d=d|0;if((a|0)==786434|(a|0)==786438|(a|0)==786442){b[(c[2406650]|0)+(((a+14|0)>>>2&3)<<1)>>1]=d;return}else if((a|0)==786436|(a|0)==786440|(a|0)==786444){b[(c[2406642]|0)+(((a+12|0)>>>2&3)<<1)>>1]=d;return}else if((a|0)==917504){c[2405110]=d&65535;return}else{return}}function bhD(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;if((b|0)==655361){e=d&255;f=c[2429344]|0;if((c[2429572]|0)==1){c[2429344]=e;if((f&8|0)!=0|(f|0)==(e|0)|(e&8|0)==0){return}a[14125144]=-1;a[9706117]=1;return}if((f|0)==(e|0)){return}do{if((f&8|0)==0){if((e&8|0)==0){break}a[14125144]=-1;a[9706117]=1}}while(0);do{if((f&64|0)==0){g=f}else{if((e&64|0)!=0){g=f;break}biF();g=c[2429344]|0}}while(0);do{if((g&16|0)==0){if((e&16|0)==0){break}f=c[2394]|0;h=c[14130368+(f<<2)>>2]|0;if((h|0)!=0){gGC(h|0,9104152,280)|0}c[8452240+(f<<2)>>2]=c[2113054];c[2394]=1;c[2112932]=c[3532597];f=c[3532593]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113061];c[2113051]=8198;c[2276080]=1536;if((c[2276079]|0)>>>0<1536){RH(6);h=c[2394]|0;i=h;j=c[14130368+(h<<2)>>2]|0}else{i=1;j=f}if((j|0)!=0){gGC(j|0,9104152,280)|0}c[8452240+(i<<2)>>2]=c[2113054];c[2394]=0;c[2112932]=c[3532596];f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060]}}while(0);c[2429344]=e;return}else if((b|0)==786433){c[2437790]=d&255;return}else if((b|0)==655368|(b|0)==655369){a[c[3528364]|0]=d;a[9706117]=1;return}else if((b|0)==721920){b=d&31;a[c[2443508]|0]=b&255;d=c[2112932]|0;e=(c[2406294]|0)+((b<<10|-720896)+720896)|0;c[d+2816>>2]=e;c[d+68352>>2]=e;c[d+133888>>2]=e;return}else{return}}function bhE(a){a=a|0;var b=0,e=0;if((a|0)==786446|(a|0)==786447){b=1-(c[2384430]|0)|0;c[2384430]=b;e=b&65535}else if((a|0)==655384){e=d[9635674]|0}else if((a|0)==655378){e=d[9635672]|0}else if((a|0)==655376){e=d[9635673]|0}else if((a|0)==655360|(a|0)==655362|(a|0)==655364|(a|0)==655366){e=d[9550952+((a-655360|0)>>>1)|0]|0}else{e=0}return e|0}function bhF(b){b=b|0;var d=0,e=0;if((b|0)==786446|(b|0)==786447){d=1-(c[2384432]|0)|0;c[2384432]=d;e=d&255}else if((b|0)==655384|(b|0)==655385){e=a[9635674]|0}else if((b|0)==655378|(b|0)==655379){e=a[9635672]|0}else if((b|0)==655376|(b|0)==655377){e=a[9635673]|0}else if((b|0)==655360|(b|0)==655361|(b|0)==655362|(b|0)==655363|(b|0)==655364|(b|0)==655365|(b|0)==655366|(b|0)==655367){e=a[9550952+((b-655360|0)>>>1)|0]|0}else{e=0}return e|0}function bhG(e,f){e=e|0;f=f|0;var g=0,h=0,i=0,j=0;if((e&16515072|0)!=5242880){return}g=e&262143;e=c[3529504]|0;h=e+g|0;b[h>>1]=f;i=g<<1;j=c[2387842]|0;a[j+(i+2)|0]=(f&255)>>>4;a[j+(i+3)|0]=a[h]&15;h=e+(g+1)|0;a[j+i|0]=(d[h]|0)>>>4;a[j+(i|1)|0]=a[h]&15;return}function bhH(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;if((b|0)!=655361){if((b&16515072|0)!=5242880){return}f=c[3529504]|0;a[f+(b&262143^1)|0]=e;g=b&262142;b=f+g|0;h=g<<1;i=c[2387842]|0;a[i+(h|2)|0]=(d[b]|0)>>>4;a[i+(h|3)|0]=a[b]&15;b=f+(g|1)|0;a[i+h|0]=(d[b]|0)>>>4;a[i+(h|1)|0]=a[b]&15;return}b=e&255;e=c[2429342]|0;c[2429342]=b;if((e|0)==(b|0)){return}do{if((e&1|0)==0){if((b&1|0)==0){j=b;break}h=c[2394]|0;i=c[14130368+(h<<2)>>2]|0;if((i|0)!=0){gGC(i|0,9104152,280)|0}c[8452240+(h<<2)>>2]=c[2113054];c[2394]=0;c[2112932]=c[3532596];h=c[3532592]|0;if((h|0)!=0){gGC(9104152,h|0,280)|0}c[2113054]=c[2113060];c[2113050]=8198;c[2276080]=1536;if((c[2276079]|0)>>>0<1536){RH(6);i=c[2394]|0;k=i;l=c[14130368+(i<<2)>>2]|0}else{k=0;l=h}if((l|0)!=0){gGC(l|0,9104152,280)|0}c[8452240+(k<<2)>>2]=c[2113054];c[2394]=1;c[2112932]=c[3532597];h=c[3532593]|0;if((h|0)!=0){gGC(9104152,h|0,280)|0}c[2113054]=c[2113061];j=c[2429342]|0}else{j=b}}while(0);b=c[3530706]|0;k=(j<<17&524288|1048576)-7340032|0;j=(c[2112932]|0)+28672|0;l=7340032;while(1){e=b+(k+l)|0;c[j>>2]=e;c[j+131072>>2]=e;e=l+1024|0;if(e>>>0>7864319){break}else{j=j+4|0;l=e}}return}function bhI(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;e=b&65535;if((e|0)==36864){a[c[2443730]|0]=d;b=c[2418506]|0;c[2424874]=b;f=b+9|0;b=a[f]|0;a[f]=(d&255)>>>1&1;if(b<<24>>24==0){return}if((a[(c[2424874]|0)+9|0]|0)!=0){return}Vl();return}else if((e|0)==57344){b=c[2418506]|0;c[2424874]=b;f=b+10|0;b=a[f]|0;a[f]=d&1;f=c[2424874]|0;g=f+16|0;if((a[g]|b)<<24>>24!=0){return}if((a[f+10|0]|0)==0){return}if((a[f+9|0]|0)==0){return}a[g]=2;if(!(a[635136]|0)){return}g=a[(c[2424874]|0)+11|0]|0;Vk();f=c[2424874]|0;b=a[f+11|0]|0;if(g<<24>>24==b<<24>>24){return}g=c[f+12>>2]|0;if((g|0)==0){return}gf[g&2047](b&255);return}else if((e|0)==49152){c[2113304]=d&255;return}else if((e|0)==49153){b=c[2113304]|0;a[14168504+b|0]=d;mv(0,b,d&255);return}else if((e|0)==53248){b=c[2418506]|0;c[2424874]=b;a[b+8|0]=d;return}else{if((e&65520|0)!=45056){return}TI(0,e&15,d&255);return}}function bhJ(b){b=b|0;var e=0,f=0,g=0;e=b&65535;if((e|0)==36864){f=a[c[2443730]|0]|0;return f|0}else if((e|0)==49152|(e|0)==49153){f=c[(c[3531464]|0)+4240>>2]&255;return f|0}else if((e|0)==61440){b=c[2418506]|0;c[2424874]=b;f=(a[b+16|0]|0)==0|0;return f|0}else if((e|0)==40960){a[9706117]=0;f=a[c[3528364]|0]|0;return f|0}else{if((e&65520|0)!=45056){f=0;return f|0}b=e&15;c[2424878]=9681232;c[2426622]=9622928;if(!((b|0)==11|(b|0)==5)){f=0;return f|0}e=(b>>>0)/6|0;b=e*6|0;g=d[b+9681280|0]<<16&65536|d[b+9681279|0]<<8|d[b+9681278|0]|c[9681260+(e<<2)>>2];c[9681244+(e<<2)>>2]=g;if(g>>>0>=(c[2405735]|0)>>>0){f=0;return f|0}c[9681268+(e<<2)>>2]=1;c[9681236+(e<<2)>>2]=0;f=0;return f|0}return 0}function bhK(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5916220+(b*112|0)>>2];c[a+104>>2]=c[5916224+(b*112|0)>>2];c[a+108>>2]=c[5916228+(b*112|0)>>2];d=0;return d|0}function bhL(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=5916120+(b*112|0);e=0;return e|0}function bhM(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4068048+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function bhN(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>55){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6351640+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function bhO(){c[2429572]=0;return biv(1506)|0}function bhP(){var b=0,d=0,e=0,f=0,g=0;c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}if((c[2392]|0)>=0){b=0;do{d=14130368+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}d=14130384+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}b=b+1|0;}while((b|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;fwZ();b=c[2424800]|0;if((b|0)!=0){gGr(b);c[2424800]=0}b=c[2418166]|0;if((b|0)!=0){gGr(b);c[2418166]=0}b=c[2418506]|0;if((b|0)!=0){gGr(b);c[2418506]=0}b=c[2418507]|0;if((b|0)!=0){gGr(b);c[2418507]=0}a[635136]=0;b=c[3531464]|0;c[b+44344>>2]=0;c[b+44348>>2]=0;if((b|0)!=0){gGr(b);c[3531464]=0}b=c[2406684]|0;if((b|0)!=0){gGr(b);c[2406684]=0}b=c[2415096]|0;d=0;while(1){if((d|0)>=1024){f=65843;break}g=9638528+(d<<2)|0;if((c[g>>2]|0)==(b|0)){break}else{d=d+1|0}}if((f|0)==65843){c[2415096]=0;a[633064]=0;c[2429572]=0;return 0}gGr(b);c[g>>2]=0;c[2415096]=0;a[633064]=0;c[2429572]=0;return 0}function bhQ(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if((a[9625e3]|0)!=0){a[9625e3]=0;d=c[2414804]|0;gGz(d|0,0,(c[2411864]|0)-d|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=1;c[2112932]=c[3532597];d=c[3532593]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113061];RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;h=c[2417276]|0;c[3541536]=h;c[1836236]=0;gGz(9706056,0,76);if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=h;c[1836236]=-1;mx(0);Vl();c[2405110]=12816;c[2437790]=0;c[2429344]=0;c[2429342]=0}c[2387738]=-1;h=0;g=-1;f=-1;e=-1;d=-1;do{g=((a[9634360+h|0]&1)<<h^g&255)&255;f=((a[9632120+h|0]&1)<<h^f&255)&255;e=((a[9630040+h|0]&1)<<h^e&255)&255;d=((a[9629088+h|0]&1)<<h^d&255)&255;h=h+1|0;}while((h|0)<16);a[9550952]=g;a[9550953]=f;a[9550954]=e;a[9550955]=d;if((f&12)==0){g=f|12;a[9550953]=g;i=g}else{i=f}if((i&3)==0){a[9550953]=i|3}if((e&12)==0){i=e|12;a[9550954]=i;j=i}else{j=e}if((j&3)==0){a[9550954]=j|3}if((d&12)==0){j=d|12;a[9550955]=j;k=j}else{k=d}if((k&3)==0){a[9550955]=k|3}k=c[2429572]|0;d=(k|0)==0&(a[633064]^1)?1e3:100;j=(k|0)==1?166666:153600;k=c[2439330]|0;if((k|0)!=0){e=k;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;e=d-1|0;k=0;i=0;f=0;while(1){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060]}g=d-i|0;h=(j-k|0)/(g|0)|0;c[2113056]=h;l=RG(h)|0;c[2113054]=(c[2113054]|0)+l;c[2276108]=-1;c[2113056]=-1;m=l+k|0;l=(i|0)==(e|0);do{if((c[2429344]&32|0)!=0&l){c[8452200+(c[2394]<<2)>>2]=8197;c[2276080]=1280;if((c[2276079]|0)>>>0>=1280){break}RH(5)}}while(0);n=c[2394]|0;o=c[14130368+(n<<2)>>2]|0;if((o|0)!=0){gGC(o|0,9104152,280)|0}c[8452240+(n<<2)>>2]=c[2113054];c[2394]=-1;if((c[2429572]|0)!=1){c[2394]=1;c[2112932]=c[3532597];n=c[3532593]|0;if((n|0)!=0){gGC(9104152,n|0,280)|0}c[2113054]=c[2113061];c[2113056]=h;n=RG(h)|0;c[2113054]=(c[2113054]|0)+n;c[2276108]=-1;c[2113056]=-1;do{if((c[2429342]&2|0)!=0&l){c[8452200+(c[2394]<<2)>>2]=8197;c[2276080]=1280;if((c[2276079]|0)>>>0>=1280){break}RH(5)}}while(0);l=c[2394]|0;h=c[14130368+(l<<2)>>2]|0;if((h|0)!=0){gGC(h|0,9104152,280)|0}c[8452240+(l<<2)>>2]=c[2113054];c[2394]=-1}l=59659/(g|0)|0;do{if((l|0)>=1){if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){h=gfc(l)|0;c[2433530]=(c[2433530]|0)+h;break}else{c[2433530]=(c[2433530]|0)+l;break}}}while(0);l=c[2112964]|0;if((l|0)==0){p=f}else{g=((a[9688]|0?534:0)>>>0)/(d>>>0)|0;h=l+(f<<1<<1)|0;gg[c[3542124]&4095](h,g);Vj(0,h,g);TH(0,h,g);p=g+f|0}g=i+1|0;if((g|0)<(d|0)){k=m;i=g;f=p}else{break}}f=c[2112964]|0;do{if((f|0)!=0){i=a[9688]|0?534:0;k=i-p|0;if((i|0)==(p|0)){break}i=f+(p<<1<<1)|0;gg[c[3542124]&4095](i,k);Vj(0,i,k);TH(0,i,k)}}while(0);p=c[1836236]|0;f=c[9757320+(p<<2)>>2]|0;if((f|0)!=0){k=f;gGC(k|0,9706056,76)|0}c[9752472+(p<<2)>>2]=c[2433530];c[14113936+(p<<2)>>2]=c[2076596];c[9669104+(p<<2)>>2]=c[3541536];c[1836236]=-1;if((c[2112968]|0)!=0){bhR()|0}if(!((c[2429344]&64|0)==0&a[689328])){a[689328]=1;q=c[2386586]|0;r=c[2386528]|0;gGC(q|0,r|0,16384)|0;return 0}biF();a[689328]=1;q=c[2386586]|0;r=c[2386528]|0;gGC(q|0,r|0,16384)|0;return 0}function bhR(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((a[9547992]|0)!=0){d=c[2387278]|0;f=c[3530182]|0;g=0;do{h=b[d+(g<<1)>>1]|0;i=h&65535;j=b[d+((g|1)<<1)>>1]|0;c[f+(((g|0)/2|0)<<2)>>2]=((h&65535)>>>2<<3&65535)>>>3&31|((j&255)<<3&255)<<8|((j&224|i<<8)>>>2&248|i<<1&4)<<3&2016;g=g+2|0;}while((g|0)<2048)}biD(1);biE(1);biD(0);biE(0);g=c[2437790]|0;f=(g&2|0)!=0;d=f?504:0;i=(g&1|0)!=0?248:0;g=c[3529412]|0;j=c[2112926]|0;h=c[3530942]|0;k=c[2113068]|0;l=128;do{m=l<<3&504^d;n=f?m-192|0:m;m=(l>>6<<3^i)-16|0;L85249:do{if((n|0)<(k|0)){o=e[g+(l<<1)>>1]|0;p=o&511;q=o>>>9&15;if((p|0)==0){break}do{if((n|0)>-1){if(!((n|0)<(k-7|0)&(m|0)>-1)){break}if((m|0)>=((c[2113070]|0)-7|0)){break}if(f){Sw(j,p,n,m,q,4,0,0,h);break L85249}else{Sq(j,p,n,m,q,4,0,0,h);break L85249}}}while(0);if(f){Sx(j,p,n,m,q,4,0,0,h);break}else{Sr(j,p,n,m,q,4,0,0,h);break}}}while(0);l=l+1|0;}while((l|0)<1920);R8(c[3530182]|0);return 0}function bhS(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;f=i;i=i+192|0;g=f|0;h=f+16|0;j=f+32|0;k=f+48|0;l=f+64|0;m=f+80|0;n=f+96|0;o=f+112|0;p=f+128|0;q=f+144|0;r=f+160|0;s=f+176|0;t=(e|0)==0;if(!t){c[e>>2]=169730}if((b&32|0)!=0){u=c[2414804]|0;c[s>>2]=u;c[s+4>>2]=(c[2411864]|0)-u;c[s+8>>2]=0;c[s+12>>2]=196728;u=c[2076592]|0;gj[u&4095](s)|0}if((b&8|0)!=0){c[s>>2]=c[2406294];c[s+4>>2]=32768;c[s+8>>2]=11534336;c[s+12>>2]=471504;u=c[2076592]|0;gj[u&4095](s)|0}if((b&64|0)==0){v=b&2}else{s=n|0;gGz(m|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){u=n+9|0;n=l;w=l|0;x=l+4|0;y=l+12|0;z=m|0;A=m+4|0;B=m+12|0;C=0;do{gGC(s|0,614896,11)|0;a[u]=C+48&255;D=8452256+(C<<2)|0;gGz(n|0,0,12);c[w>>2]=D;c[x>>2]=4;c[y>>2]=164976;gj[c[2076592]&4095](l)|0;if((c[D>>2]|0)!=0){c[z>>2]=c[14130368+(C<<2)>>2];c[A>>2]=c[8452184+(C<<2)>>2];c[B>>2]=s;D=c[2076592]|0;gj[D&4095](m)|0}C=C+1|0;}while((C|0)<=(c[2392]|0))}fw$(b);C=k|0;if(!t){c[e>>2]=169600}c[2424874]=c[2418506];cC(C|0,100600,(e=i,i=i+8|0,c[e>>2]=0,e)|0)|0;i=e;c[j>>2]=9699496;c[j+4>>2]=80;c[j+8>>2]=0;c[j+12>>2]=C;C=c[2076592]|0;gj[C&4095](j)|0;gGz(h|0,0,12);c[h>>2]=8453216;c[h+4>>2]=4;c[h+12>>2]=107480;j=c[2076592]|0;gj[j&4095](h)|0;gGz(g|0,0,12);c[g>>2]=14168504;c[g+4>>2]=256;c[g+12>>2]=476464;h=c[2076592]|0;gj[h&4095](g)|0;g=b&2;if((g|0)!=0){b=0;do{mv(0,b,d[14168504+b|0]|0);b=b+1|0;}while((b|0)<256)}gGz(r|0,0,12);c[r>>2]=9620440;c[r+4>>2]=4;c[r+12>>2]=492016;b=c[2076592]|0;gj[b&4095](r)|0;gGz(q|0,0,12);c[q>>2]=9751160;c[q+4>>2]=4;c[q+12>>2]=468464;r=c[2076592]|0;gj[r&4095](q)|0;gGz(p|0,0,12);c[p>>2]=9717376;c[p+4>>2]=4;c[p+12>>2]=467688;q=c[2076592]|0;gj[q&4095](p)|0;gGz(o|0,0,12);c[o>>2]=9717368;c[o+4>>2]=4;c[o+12>>2]=466944;p=c[2076592]|0;gj[p&4095](o)|0;v=g}if((v|0)==0){i=f;return 0}if((c[2429572]|0)!=1){v=c[3529504]|0;g=c[2387842]|0;o=0;do{p=v+o|0;q=o<<1;a[g+(q|2)|0]=(d[p]|0)>>>4;a[g+(q|3)|0]=a[p]&15;p=v+(o|1)|0;a[g+q|0]=(d[p]|0)>>>4;a[g+(q|1)|0]=a[p]&15;o=o+2|0;}while((o|0)<262144)}if((c[2394]|0)==0){E=c[2112932]|0;F=c[3532592]|0}else{c[2394]=0;o=c[3532596]|0;c[2112932]=o;g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060];E=o;F=g}g=(c[2406294]|0)+((d[c[2443508]|0]|0)<<10)|0;c[E+2816>>2]=g;c[E+68352>>2]=g;c[E+133888>>2]=g;if((F|0)!=0){gGC(F|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=1;F=c[3532597]|0;c[2112932]=F;g=c[3532593]|0;E=(g|0)==0;if(!E){gGC(9104152,g|0,280)|0}o=c[2113061]|0;c[2113054]=o;v=c[3530706]|0;p=(c[2429342]<<17&524288|1048576)-7340032|0;q=F+28672|0;F=7340032;while(1){r=v+(p+F)|0;c[q>>2]=r;c[q+131072>>2]=r;r=F+1024|0;if(r>>>0>7864319){break}else{q=q+4|0;F=r}}if(!E){gGC(g|0,9104152,280)|0}c[2113061]=o;c[2394]=-1;i=f;return 0}function bhT(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6524668+(b*112|0)>>2];c[a+104>>2]=c[6524672+(b*112|0)>>2];c[a+108>>2]=c[6524676+(b*112|0)>>2];d=0;return d|0}function bhU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=6524568+(b*112|0);e=0;return e|0}function bhV(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4758820+(b*112|0)>>2];c[a+104>>2]=c[4758824+(b*112|0)>>2];c[a+108>>2]=c[4758828+(b*112|0)>>2];d=0;return d|0}function bhW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=4758720+(b*112|0);e=0;return e|0}function bhX(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>31){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1963904+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function bhY(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>38){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5490912+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function bhZ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5629748+(b*112|0)>>2];c[a+104>>2]=c[5629752+(b*112|0)>>2];c[a+108>>2]=c[5629756+(b*112|0)>>2];d=0;return d|0}function bh_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=5629648+(b*112|0);e=0;return e|0}function bh$(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6938480+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function bh0(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>66){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6006128+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function bh1(){a[633064]=1;c[2429572]=0;return biv(2864)|0}function bh2(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4325476+(b*112|0)>>2];c[a+104>>2]=c[4325480+(b*112|0)>>2];c[a+108>>2]=c[4325484+(b*112|0)>>2];d=0;return d|0}function bh3(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=4325376+(b*112|0);e=0;return e|0}function bh4(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4323684+(b*112|0)>>2];c[a+104>>2]=c[4323688+(b*112|0)>>2];c[a+108>>2]=c[4323692+(b*112|0)>>2];d=0;return d|0}function bh5(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=4323584+(b*112|0);e=0;return e|0}function bh6(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2821092+(b*112|0)>>2];c[a+104>>2]=c[2821096+(b*112|0)>>2];c[a+108>>2]=c[2821100+(b*112|0)>>2];d=0;return d|0}function bh7(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=2820992+(b*112|0);e=0;return e|0}function bh8(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>66){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3891136+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function bh9(){a[633064]=1;c[2429572]=0;return biv(1300)|0}function bia(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1543012+(b*112|0)>>2];c[a+104>>2]=c[1543016+(b*112|0)>>2];c[a+108>>2]=c[1543020+(b*112|0)>>2];d=0;return d|0}function bib(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=1542912+(b*112|0);e=0;return e|0}function bic(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1541220+(b*112|0)>>2];c[a+104>>2]=c[1541224+(b*112|0)>>2];c[a+108>>2]=c[1541228+(b*112|0)>>2];d=0;return d|0}function bid(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=1541120+(b*112|0);e=0;return e|0}function bie(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5897668+(b*112|0)>>2];c[a+104>>2]=c[5897672+(b*112|0)>>2];c[a+108>>2]=c[5897676+(b*112|0)>>2];d=0;return d|0}function bif(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=5897568+(b*112|0);e=0;return e|0}function big(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>55){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6307944+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function bih(){c[2429572]=1;return biv(4796)|0}function bii(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4715052+(b*112|0)>>2];c[a+104>>2]=c[4715056+(b*112|0)>>2];c[a+108>>2]=c[4715060+(b*112|0)>>2];d=0;return d|0}function bij(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=4714952+(b*112|0);e=0;return e|0}function bik(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2752964+(b*112|0)>>2];c[a+104>>2]=c[2752968+(b*112|0)>>2];c[a+108>>2]=c[2752972+(b*112|0)>>2];d=0;return d|0}function bil(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=2752864+(b*112|0);e=0;return e|0}function bim(){c[2429572]=2;return biv(4612)|0}function bin(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7030612+(b*112|0)>>2];c[a+104>>2]=c[7030616+(b*112|0)>>2];c[a+108>>2]=c[7030620+(b*112|0)>>2];d=0;return d|0}function bio(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=7030512+(b*112|0);e=0;return e|0}function bip(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>63){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7187424+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function biq(){c[2429572]=2;return biv(4578)|0}function bir(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2982244+(b*112|0)>>2];c[a+104>>2]=c[2982248+(b*112|0)>>2];c[a+108>>2]=c[2982252+(b*112|0)>>2];d=0;return d|0}function bis(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=2982144+(b*112|0);e=0;return e|0}function bit(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>69){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4128224+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function biu(){c[2429572]=2;return biv(4620)|0}function biv(e){e=e|0;var f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;c[2415096]=0;c[3531126]=0;c[3531114]=262144;c[2386002]=524288;c[3530942]=557056;c[3530706]=589824;c[3530488]=2686976;c[3529776]=2818048;c[3529730]=2949120;c[2387842]=3080192;c[2406294]=7274496;c[3530182]=7307264;c[2414804]=7311360;c[2386528]=7311360;c[2386586]=7327744;c[3527318]=7344128;c[3531178]=7409664;c[2387278]=7426048;c[3529412]=7430144;c[2386272]=7454720;c[3531156]=7471104;c[3529504]=7503872;c[2443442]=7766016;c[2386154]=7897088;c[2443508]=7901184;c[2406650]=7901185;c[2406642]=7901193;c[3528364]=7901201;c[2443730]=7901202;c[2411864]=7901203;f=0;while(1){if((f|0)>=1024){break}g=9638528+(f<<2)|0;if((c[g>>2]|0)==0){i=66192;break}else{f=f+1|0}}do{if((i|0)==66192){f=gGq(7901203)|0;c[g>>2]=f;if((f|0)==0){break}c[2415096]=f;gGz(f|0,0,7901203);c[3531126]=f;c[3531114]=f+262144;c[2386002]=f+524288;c[3530942]=f+557056;j=f+589824|0;c[3530706]=j;c[3530488]=f+2686976;c[3529776]=f+2818048;c[3529730]=f+2949120;c[2387842]=f+3080192;c[2406294]=f+7274496;c[3530182]=f+7307264;k=f+7311360|0;c[2414804]=k;c[2386528]=k;c[2386586]=f+7327744;c[3527318]=f+7344128;c[3531178]=f+7409664;c[2387278]=f+7426048;c[3529412]=f+7430144;c[2386272]=f+7454720;c[3531156]=f+7471104;c[2406510]=f+7487488;c[3529504]=f+7503872;c[2443442]=f+7766016;c[2386154]=f+7897088;c[2443508]=f+7901184;c[2406650]=f+7901185;c[2406642]=f+7901193;c[3528364]=f+7901201;c[2443730]=f+7901202;k=f+7901203|0;c[2411864]=k;c[2414414]=k;do{if((e|0)==0){l=j}else{if((gD[e&8191]()|0)==0){l=c[3530706]|0;break}else{m=1;return m|0}}}while(0);j=l;k=0;while(1){if((k|0)>=1024){n=0;break}o=9638528+(k<<2)|0;if((c[o>>2]|0)==0){i=66200;break}else{k=k+1|0}}do{if((i|0)==66200){k=gGq(2097152)|0;c[o>>2]=k;if((k|0)==0){n=0;break}gGz(k|0,0,2097152);n=k}}while(0);k=n;f=0;do{p=f<<1;b[k+(p<<1)>>1]=b[j+(f+524288<<1)>>1]|0;b[k+((p|1)<<1)>>1]=b[j+(f<<1)>>1]|0;f=f+1|0;}while((f|0)<524288);gGC(l|0,n|0,2097152)|0;f=0;while(1){if((f|0)>=1024){break}q=9638528+(f<<2)|0;if((c[q>>2]|0)==(n|0)){i=66207;break}else{f=f+1|0}}if((i|0)==66207){gGr(n);c[q>>2]=0}f=c[3530942]|0;j=16383;do{k=f+j|0;p=j<<1;a[f+p|0]=(d[k]|0)>>>4;a[f+(p|1)|0]=a[k]&15;j=j-1|0;}while((j|0)>0);if((c[2429572]|0)==1){j=c[3530706]|0;f=0;k=j;while(1){p=a[k]|0;r=k+1|0;a[k]=a[r]|0;a[r]=p;p=f+1|0;if((p|0)<1048576){f=p;k=k+2|0}else{break}}k=c[2387842]|0;f=2097151;while(1){p=j+f|0;r=f<<1;a[k+r|0]=(d[p]|0)>>>4;a[k+(r|1)|0]=a[p]&15;p=f-1|0;if((p|0)>0){f=p}else{s=0;t=j;break}}while(1){j=a[t]|0;f=t+1|0;a[t]=a[f]|0;a[f]=j;j=s+1|0;if((j|0)<1048576){s=j;t=t+2|0}else{break}}}fxU(0,425984);if((c[2394]|0)==0){u=c[2112932]|0}else{c[2394]=0;j=c[3532596]|0;c[2112932]=j;f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];u=j}j=c[3531126]|0;f=u|0;k=0;while(1){p=j+k|0;c[f>>2]=p;c[f+131072>>2]=p;p=k+1024|0;if(p>>>0>262143){break}else{f=f+4|0;k=p}}k=c[3527318]|0;f=u+1024|0;j=262144;while(1){p=k+(j-262144)|0;c[f>>2]=p;c[f+65536>>2]=p;c[f+131072>>2]=p;p=j+1024|0;if(p>>>0>327679){break}else{f=f+4|0;j=p}}j=c[3531178]|0;c[u+1536>>2]=j;c[u+67072>>2]=j;c[u+132608>>2]=j;f=j+1024|0;c[u+1540>>2]=f;c[u+67076>>2]=f;c[u+132612>>2]=f;f=j+2048|0;c[u+1544>>2]=f;c[u+67080>>2]=f;c[u+132616>>2]=f;f=j+3072|0;c[u+1548>>2]=f;c[u+67084>>2]=f;c[u+132620>>2]=f;f=j+4096|0;c[u+1552>>2]=f;c[u+67088>>2]=f;c[u+132624>>2]=f;f=j+5120|0;c[u+1556>>2]=f;c[u+67092>>2]=f;c[u+132628>>2]=f;f=j+6144|0;c[u+1560>>2]=f;c[u+67096>>2]=f;c[u+132632>>2]=f;f=j+7168|0;c[u+1564>>2]=f;c[u+67100>>2]=f;c[u+132636>>2]=f;f=j+8192|0;c[u+1568>>2]=f;c[u+67104>>2]=f;c[u+132640>>2]=f;f=j+9216|0;c[u+1572>>2]=f;c[u+67108>>2]=f;c[u+132644>>2]=f;f=j+10240|0;c[u+1576>>2]=f;c[u+67112>>2]=f;c[u+132648>>2]=f;f=j+11264|0;c[u+1580>>2]=f;c[u+67116>>2]=f;c[u+132652>>2]=f;f=j+12288|0;c[u+1584>>2]=f;c[u+67120>>2]=f;c[u+132656>>2]=f;f=j+13312|0;c[u+1588>>2]=f;c[u+67124>>2]=f;c[u+132660>>2]=f;f=j+14336|0;c[u+1592>>2]=f;c[u+67128>>2]=f;c[u+132664>>2]=f;f=j+15360|0;c[u+1596>>2]=f;c[u+67132>>2]=f;c[u+132668>>2]=f;f=c[2387278]|0;c[u+2048>>2]=f;c[u+67584>>2]=f;c[u+133120>>2]=f;j=f+1024|0;c[u+2052>>2]=j;c[u+67588>>2]=j;c[u+133124>>2]=j;j=f+2048|0;c[u+2056>>2]=j;c[u+67592>>2]=j;c[u+133128>>2]=j;j=f+3072|0;c[u+2060>>2]=j;c[u+67596>>2]=j;c[u+133132>>2]=j;j=c[2406294]|0;c[u+2816>>2]=j;c[u+68352>>2]=j;c[u+133888>>2]=j;j=c[3529412]|0;f=u+4096|0;k=1048576;while(1){p=j+(k-1048576)|0;c[f>>2]=p;c[f+65536>>2]=p;c[f+131072>>2]=p;p=k+1024|0;if(p>>>0>1073151){break}else{f=f+4|0;k=p}}k=c[2386272]|0;c[u+4608>>2]=k;c[u+70144>>2]=k;c[u+135680>>2]=k;f=k+1024|0;c[u+4612>>2]=f;c[u+70148>>2]=f;c[u+135684>>2]=f;f=k+2048|0;c[u+4616>>2]=f;c[u+70152>>2]=f;c[u+135688>>2]=f;f=k+3072|0;c[u+4620>>2]=f;c[u+70156>>2]=f;c[u+135692>>2]=f;f=k+4096|0;c[u+4624>>2]=f;c[u+70160>>2]=f;c[u+135696>>2]=f;f=k+5120|0;c[u+4628>>2]=f;c[u+70164>>2]=f;c[u+135700>>2]=f;f=k+6144|0;c[u+4632>>2]=f;c[u+70168>>2]=f;c[u+135704>>2]=f;f=k+7168|0;c[u+4636>>2]=f;c[u+70172>>2]=f;c[u+135708>>2]=f;f=k+8192|0;c[u+4640>>2]=f;c[u+70176>>2]=f;c[u+135712>>2]=f;f=k+9216|0;c[u+4644>>2]=f;c[u+70180>>2]=f;c[u+135716>>2]=f;f=k+10240|0;c[u+4648>>2]=f;c[u+70184>>2]=f;c[u+135720>>2]=f;f=k+11264|0;c[u+4652>>2]=f;c[u+70188>>2]=f;c[u+135724>>2]=f;f=k+12288|0;c[u+4656>>2]=f;c[u+70192>>2]=f;c[u+135728>>2]=f;f=k+13312|0;c[u+4660>>2]=f;c[u+70196>>2]=f;c[u+135732>>2]=f;f=k+14336|0;c[u+4664>>2]=f;c[u+70200>>2]=f;c[u+135736>>2]=f;f=k+15360|0;c[u+4668>>2]=f;c[u+70204>>2]=f;c[u+135740>>2]=f;f=c[2386528]|0;c[u+5120>>2]=f;c[u+70656>>2]=f;c[u+136192>>2]=f;k=f+1024|0;c[u+5124>>2]=k;c[u+70660>>2]=k;c[u+136196>>2]=k;k=f+2048|0;c[u+5128>>2]=k;c[u+70664>>2]=k;c[u+136200>>2]=k;k=f+3072|0;c[u+5132>>2]=k;c[u+70668>>2]=k;c[u+136204>>2]=k;k=f+4096|0;c[u+5136>>2]=k;c[u+70672>>2]=k;c[u+136208>>2]=k;k=f+5120|0;c[u+5140>>2]=k;c[u+70676>>2]=k;c[u+136212>>2]=k;k=f+6144|0;c[u+5144>>2]=k;c[u+70680>>2]=k;c[u+136216>>2]=k;k=f+7168|0;c[u+5148>>2]=k;c[u+70684>>2]=k;c[u+136220>>2]=k;k=f+8192|0;c[u+5152>>2]=k;c[u+70688>>2]=k;c[u+136224>>2]=k;k=f+9216|0;c[u+5156>>2]=k;c[u+70692>>2]=k;c[u+136228>>2]=k;k=f+10240|0;c[u+5160>>2]=k;c[u+70696>>2]=k;c[u+136232>>2]=k;k=f+11264|0;c[u+5164>>2]=k;c[u+70700>>2]=k;c[u+136236>>2]=k;k=f+12288|0;c[u+5168>>2]=k;c[u+70704>>2]=k;c[u+136240>>2]=k;k=f+13312|0;c[u+5172>>2]=k;c[u+70708>>2]=k;c[u+136244>>2]=k;k=f+14336|0;c[u+5176>>2]=k;c[u+70712>>2]=k;c[u+136248>>2]=k;k=f+15360|0;c[u+5180>>2]=k;c[u+70716>>2]=k;c[u+136252>>2]=k;k=c[3530706]|0;f=u+20480|0;j=5242880;while(1){p=k+(j-5242880)|0;c[f>>2]=p;c[f+131072>>2]=p;p=j+1024|0;if(p>>>0>7340031){break}else{f=f+4|0;j=p}}c[u+196728>>2]=1638;c[u+196648>>2]=3182;c[u+196688>>2]=2930;c[u+196608>>2]=2580;j=c[3532592]|0;if((j|0)!=0){gGC(j|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fxU(1,425984);if((c[2394]|0)==1){v=c[2112932]|0}else{c[2394]=1;j=c[3532597]|0;c[2112932]=j;f=c[3532593]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113061];v=j}j=c[3531114]|0;f=v|0;k=0;while(1){p=j+k|0;c[f>>2]=p;c[f+131072>>2]=p;p=k+1024|0;if(p>>>0>262143){break}else{f=f+4|0;k=p}}k=c[3527318]|0;f=v+1024|0;j=262144;while(1){p=k+(j-262144)|0;c[f>>2]=p;c[f+65536>>2]=p;c[f+131072>>2]=p;p=j+1024|0;if(p>>>0>327679){break}else{f=f+4|0;j=p}}j=c[3531156]|0;c[v+1536>>2]=j;c[v+67072>>2]=j;c[v+132608>>2]=j;f=j+1024|0;c[v+1540>>2]=f;c[v+67076>>2]=f;c[v+132612>>2]=f;f=j+2048|0;c[v+1544>>2]=f;c[v+67080>>2]=f;c[v+132616>>2]=f;f=j+3072|0;c[v+1548>>2]=f;c[v+67084>>2]=f;c[v+132620>>2]=f;f=j+4096|0;c[v+1552>>2]=f;c[v+67088>>2]=f;c[v+132624>>2]=f;f=j+5120|0;c[v+1556>>2]=f;c[v+67092>>2]=f;c[v+132628>>2]=f;f=j+6144|0;c[v+1560>>2]=f;c[v+67096>>2]=f;c[v+132632>>2]=f;f=j+7168|0;c[v+1564>>2]=f;c[v+67100>>2]=f;c[v+132636>>2]=f;f=j+8192|0;c[v+1568>>2]=f;c[v+67104>>2]=f;c[v+132640>>2]=f;f=j+9216|0;c[v+1572>>2]=f;c[v+67108>>2]=f;c[v+132644>>2]=f;f=j+10240|0;c[v+1576>>2]=f;c[v+67112>>2]=f;c[v+132648>>2]=f;f=j+11264|0;c[v+1580>>2]=f;c[v+67116>>2]=f;c[v+132652>>2]=f;f=j+12288|0;c[v+1584>>2]=f;c[v+67120>>2]=f;c[v+132656>>2]=f;f=j+13312|0;c[v+1588>>2]=f;c[v+67124>>2]=f;c[v+132660>>2]=f;f=j+14336|0;c[v+1592>>2]=f;c[v+67128>>2]=f;c[v+132664>>2]=f;f=j+15360|0;c[v+1596>>2]=f;c[v+67132>>2]=f;c[v+132668>>2]=f;f=c[3530488]|0;j=v+2048|0;k=524288;while(1){p=f+(k-524288)|0;c[j>>2]=p;c[j+131072>>2]=p;p=k+1024|0;if(p>>>0>655359){break}else{j=j+4|0;k=p}}k=c[2386528]|0;c[v+16384>>2]=k;c[v+81920>>2]=k;c[v+147456>>2]=k;j=k+1024|0;c[v+16388>>2]=j;c[v+81924>>2]=j;c[v+147460>>2]=j;j=k+2048|0;c[v+16392>>2]=j;c[v+81928>>2]=j;c[v+147464>>2]=j;j=k+3072|0;c[v+16396>>2]=j;c[v+81932>>2]=j;c[v+147468>>2]=j;j=k+4096|0;c[v+16400>>2]=j;c[v+81936>>2]=j;c[v+147472>>2]=j;j=k+5120|0;c[v+16404>>2]=j;c[v+81940>>2]=j;c[v+147476>>2]=j;j=k+6144|0;c[v+16408>>2]=j;c[v+81944>>2]=j;c[v+147480>>2]=j;j=k+7168|0;c[v+16412>>2]=j;c[v+81948>>2]=j;c[v+147484>>2]=j;j=k+8192|0;c[v+16416>>2]=j;c[v+81952>>2]=j;c[v+147488>>2]=j;j=k+9216|0;c[v+16420>>2]=j;c[v+81956>>2]=j;c[v+147492>>2]=j;j=k+10240|0;c[v+16424>>2]=j;c[v+81960>>2]=j;c[v+147496>>2]=j;j=k+11264|0;c[v+16428>>2]=j;c[v+81964>>2]=j;c[v+147500>>2]=j;j=k+12288|0;c[v+16432>>2]=j;c[v+81968>>2]=j;c[v+147504>>2]=j;j=k+13312|0;c[v+16436>>2]=j;c[v+81972>>2]=j;c[v+147508>>2]=j;j=k+14336|0;c[v+16440>>2]=j;c[v+81976>>2]=j;c[v+147512>>2]=j;j=k+15360|0;c[v+16444>>2]=j;c[v+81980>>2]=j;c[v+147516>>2]=j;j=c[2386272]|0;c[v+18432>>2]=j;c[v+83968>>2]=j;c[v+149504>>2]=j;k=j+1024|0;c[v+18436>>2]=k;c[v+83972>>2]=k;c[v+149508>>2]=k;k=j+2048|0;c[v+18440>>2]=k;c[v+83976>>2]=k;c[v+149512>>2]=k;k=j+3072|0;c[v+18444>>2]=k;c[v+83980>>2]=k;c[v+149516>>2]=k;k=j+4096|0;c[v+18448>>2]=k;c[v+83984>>2]=k;c[v+149520>>2]=k;k=j+5120|0;c[v+18452>>2]=k;c[v+83988>>2]=k;c[v+149524>>2]=k;k=j+6144|0;c[v+18456>>2]=k;c[v+83992>>2]=k;c[v+149528>>2]=k;k=j+7168|0;c[v+18460>>2]=k;c[v+83996>>2]=k;c[v+149532>>2]=k;k=j+8192|0;c[v+18464>>2]=k;c[v+84e3>>2]=k;c[v+149536>>2]=k;k=j+9216|0;c[v+18468>>2]=k;c[v+84004>>2]=k;c[v+149540>>2]=k;k=j+10240|0;c[v+18472>>2]=k;c[v+84008>>2]=k;c[v+149544>>2]=k;k=j+11264|0;c[v+18476>>2]=k;c[v+84012>>2]=k;c[v+149548>>2]=k;k=j+12288|0;c[v+18480>>2]=k;c[v+84016>>2]=k;c[v+149552>>2]=k;k=j+13312|0;c[v+18484>>2]=k;c[v+84020>>2]=k;c[v+149556>>2]=k;k=j+14336|0;c[v+18488>>2]=k;c[v+84024>>2]=k;c[v+149560>>2]=k;k=j+15360|0;c[v+18492>>2]=k;c[v+84028>>2]=k;c[v+149564>>2]=k;k=c[3529504]|0;j=v+20480|0;f=5242880;while(1){p=k+(f-5242880)|0;c[j>>2]=p;c[j+131072>>2]=p;p=f+1024|0;if(p>>>0>5505023){break}else{j=j+4|0;f=p}}f=c[3530706]|0;j=v+24576|0;k=6291456;while(1){p=f+(k-6291456)|0;c[j>>2]=p;c[j+131072>>2]=p;p=k+1024|0;if(p>>>0>7340031){break}else{j=j+4|0;k=p}}k=v+28672|0;j=7340032;while(1){p=f+(j-6291456)|0;c[k>>2]=p;c[k+131072>>2]=p;p=j+1024|0;if(p>>>0>7864319){break}else{k=k+4|0;j=p}}j=c[2443442]|0;k=v+30720|0;f=7864320;while(1){p=j+(f-7864320)|0;c[k>>2]=p;c[k+65536>>2]=p;c[k+131072>>2]=p;p=f+1024|0;if(p>>>0>7995391){break}else{k=k+4|0;f=p}}c[v+196728>>2]=1442;c[v+196648>>2]=1094;f=c[3532593]|0;if((f|0)!=0){gGC(f|0,9104152,280)|0}c[2113061]=c[2113054];c[2394]=-1;fwR(0);f=c[2439330]|0;k=(f|0)==0;if(!k){j=f;gGC(9706056,j|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];j=c[3528484]|0;c[2076596]=j;p=c[2417276]|0;c[3541536]=p;c[1836236]=0;r=c[2386002]|0;w=0;x=0;while(1){c[f+76+(x<<2)>>2]=r+(x<<8);y=w+1&65535;if((y&65535)>127){z=0;A=0;break}else{w=y;x=y&65535}}while(1){x=r+(A<<8)|0;c[f+76+(A+512<<2)>>2]=x;c[f+76+(A+768<<2)>>2]=x;x=z+1&65535;if((x&65535)>127){break}else{z=x;A=x&65535}}r=c[2386154]|0;c[f+588>>2]=r;c[f+592>>2]=r+256;c[f+596>>2]=r+512;c[f+600>>2]=r+768;c[f+604>>2]=r+1024;c[f+608>>2]=r+1280;c[f+612>>2]=r+1536;c[f+616>>2]=r+1792;c[f+620>>2]=r+2048;c[f+624>>2]=r+2304;c[f+628>>2]=r+2560;c[f+632>>2]=r+2816;c[f+636>>2]=r+3072;c[f+640>>2]=r+3328;c[f+644>>2]=r+3584;c[f+648>>2]=r+3840;x=128;w=128;while(1){c[f+76+(w+256<<2)>>2]=r+((w<<8)-32768);y=x+1&65535;if((y&65535)>143){B=128;C=128;break}else{x=y;w=y&65535}}while(1){w=r+((C<<8)-32768)|0;c[f+76+(C+512<<2)>>2]=w;c[f+76+(C+768<<2)>>2]=w;w=B+1&65535;if((w&65535)>143){break}else{B=w;C=w&65535}}c[f+4184>>2]=2718;c[f+4180>>2]=3536;if(!k){r=f;gGC(r|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=j;c[2417276]=p;c[1836236]=-1;TJ(0,c[3529776]|0,131072);c[2424878]=9681232;c[2405736]=1416;h[1202869]=.12;c[2405742]=3;c[2426622]=9622928;h[1202870]=.12;c[2405743]=3;r=a[9680]|0;w=r?32e3:0;if(r){if(a[9624]|0){r=w*3|0;x=55930;while(1){if((x|0)>(r|0)){x=x>>1}else{D=1222;E=x;break}}}else{D=2462;E=w}c[2429380]=E;c[3542124]=D;mw(3579580,E);x=gGq(262144)|0;c[2406684]=x;gGz(x|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(3579580,11025)}h[745421]=1.0;c[2436794]=1;h[745420]=1.0;c[2436792]=2;x=c[3529730]|0;r=gGq(80)|0;p=r;c[2418506]=p;c[2424874]=p;gGz(r|0,0,80);a[635136]=0;c[r+4>>2]=~~(16.0e4/(a[9680]|0?32.0e3:0.0)*4194304.0);a[r+16|0]=0;if((x|0)==0){a[635136]=1}else{c[r+52>>2]=x}a[r+9|0]=1;a[(c[2424874]|0)+10|0]=1;x=c[2424874]|0;h[x+64>>3]=1.0;c[x+72>>2]=3;Vl();c[2424874]=p;h[r+64>>3]=.2;c[r+72>>2]=3;r=c[642608+(c[2436]<<2)>>2]|0;p=c[r+128>>2]|0;if((c[r+52>>2]&4|0)==0){c[2113068]=p;x=c[r+132>>2]|0;c[2113070]=x;c[2443814]=p;c[2440436]=x;F=p;G=x}else{c[2113070]=p;x=c[r+132>>2]|0;c[2113068]=x;c[2440436]=p;c[2443814]=x;F=x;G=p}p=ag(F<<1,G)|0;x=gGq(p)|0;c[2112926]=x;if((x|0)!=0){gGz(x|0,0,p|0)}a[9625e3]=0;p=c[2414804]|0;gGz(p|0,0,(c[2411864]|0)-p|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];p=c[3532592]|0;if((p|0)!=0){gGC(9104152,p|0,280)|0}c[2113054]=c[2113060]}RI();p=c[2394]|0;x=c[14130368+(p<<2)>>2]|0;if((x|0)!=0){gGC(x|0,9104152,280)|0}c[8452240+(p<<2)>>2]=c[2113054];c[2394]=1;c[2112932]=c[3532597];p=c[3532593]|0;if((p|0)!=0){gGC(9104152,p|0,280)|0}c[2113054]=c[2113061];RI();p=c[2394]|0;x=c[14130368+(p<<2)>>2]|0;if((x|0)!=0){gGC(x|0,9104152,280)|0}c[8452240+(p<<2)>>2]=c[2113054];c[2394]=-1;p=c[2439330]|0;x=(p|0)==0;if(!x){r=p;gGC(9706056,r|0,76)|0}r=c[2438118]|0;c[2433530]=r;j=c[3528484]|0;c[2076596]=j;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;gGz(9706056,0,76);if(!x){x=p;gGC(x|0,9706056,76)|0}c[2438118]=r;c[3528484]=j;c[2417276]=f;c[1836236]=-1;mx(0);Vl();c[2405110]=12816;c[2437790]=0;c[2429344]=0;c[2429342]=0;m=0;return m|0}}while(0);c[2415096]=0;m=1;return m|0}function biw(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;a=i;i=i+240|0;b=a|0;d=a+112|0;e=a+120|0;f=a+232|0;g=c[3531126]|0;if((R6(g+1|0,0,2)|0)!=0){h=1;i=a;return h|0}if((R6(g,1,2)|0)!=0){h=1;i=a;return h|0}if((R6(g+131073|0,2,2)|0)!=0){h=1;i=a;return h|0}if((R6(g+131072|0,3,2)|0)!=0){h=1;i=a;return h|0}g=c[3531114]|0;if((R6(g+1|0,4,2)|0)!=0){h=1;i=a;return h|0}if((R6(g,5,2)|0)!=0){h=1;i=a;return h|0}if((R6(g+131073|0,6,2)|0)!=0){h=1;i=a;return h|0}if((R6(g+131072|0,7,2)|0)!=0){h=1;i=a;return h|0}g=c[2386002]|0;if((c[3542200]|0)==0){h=1;i=a;return h|0}j=e+108|0;c[j>>2]=0;k=e+100|0;c[k>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,8)|0;do{if((c[j>>2]|0)!=0){e=c[k>>2]|0;c[f>>2]=9534384;l=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[l&16383](f,8,0)|0;if((e|0)<1){h=1;i=a;return h|0}if((gzL(g,0,8)|0)==0){break}else{h=1}i=a;return h|0}}while(0);g=c[3530942]|0;if((c[3542200]|0)==0){h=1;i=a;return h|0}f=b+108|0;c[f>>2]=0;k=b+100|0;c[k>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](b,9)|0;do{if((c[f>>2]|0)!=0){b=c[k>>2]|0;c[d>>2]=9534384;j=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[j&16383](d,9,0)|0;if((b|0)<1){h=1;i=a;return h|0}if((gzL(g,0,9)|0)==0){break}else{h=1}i=a;return h|0}}while(0);if((R6((c[3530488]|0)+1|0,10,2)|0)!=0){h=1;i=a;return h|0}h=(R6(c[3530488]|0,11,2)|0)!=0|0;i=a;return h|0}function bix(b){b=b|0;a[9681232]=((b>>4)*17|0)&255;a[9681233]=0;c[2424878]=9681232;a[9681234]=0;a[9681235]=((b&15)*17|0)&255;return}function biy(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;a=i;i=i+600|0;b=a|0;d=a+112|0;e=a+120|0;f=a+232|0;g=a+240|0;h=a+352|0;j=a+360|0;k=a+472|0;l=a+480|0;m=a+592|0;n=c[3531126]|0;if((R6(n+1|0,0,2)|0)!=0){o=1;i=a;return o|0}if((R6(n,1,2)|0)!=0){o=1;i=a;return o|0}if((R6(n+131073|0,2,2)|0)!=0){o=1;i=a;return o|0}if((R6(n+131072|0,3,2)|0)!=0){o=1;i=a;return o|0}n=c[3531114]|0;if((R6(n+1|0,4,2)|0)!=0){o=1;i=a;return o|0}if((R6(n,5,2)|0)!=0){o=1;i=a;return o|0}if((R6(n+131073|0,6,2)|0)!=0){o=1;i=a;return o|0}if((R6(n+131072|0,7,2)|0)!=0){o=1;i=a;return o|0}n=c[2386002]|0;if((c[3542200]|0)==0){o=1;i=a;return o|0}p=l+108|0;c[p>>2]=0;q=l+100|0;c[q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,8)|0;do{if((c[p>>2]|0)!=0){l=c[q>>2]|0;c[m>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](m,8,0)|0;if((l|0)<1){o=1;i=a;return o|0}if((gzL(n,0,8)|0)==0){break}else{o=1}i=a;return o|0}}while(0);n=c[3530942]|0;if((c[3542200]|0)==0){o=1;i=a;return o|0}m=j+108|0;c[m>>2]=0;q=j+100|0;c[q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,9)|0;do{if((c[m>>2]|0)!=0){j=c[q>>2]|0;c[k>>2]=9534384;p=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[p&16383](k,9,0)|0;if((j|0)<1){o=1;i=a;return o|0}if((gzL(n,0,9)|0)==0){break}else{o=1}i=a;return o|0}}while(0);n=c[3530706]|0;if((c[3542200]|0)==0){o=1;i=a;return o|0}k=g+108|0;c[k>>2]=0;q=g+100|0;c[q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,10)|0;do{if((c[k>>2]|0)!=0){g=c[q>>2]|0;c[h>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](h,10,0)|0;if((g|0)<1){o=1;i=a;return o|0}if((gzL(n,0,10)|0)==0){break}else{o=1}i=a;return o|0}}while(0);n=(c[3530706]|0)+1048576|0;if((c[3542200]|0)==0){o=1;i=a;return o|0}h=e+108|0;c[h>>2]=0;q=e+100|0;c[q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,11)|0;do{if((c[h>>2]|0)!=0){e=c[q>>2]|0;c[f>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](f,11,0)|0;if((e|0)<1){o=1;i=a;return o|0}if((gzL(n,0,11)|0)==0){break}else{o=1}i=a;return o|0}}while(0);n=c[3529776]|0;if((c[3542200]|0)==0){o=1;i=a;return o|0}f=b+108|0;c[f>>2]=0;q=b+100|0;c[q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](b,12)|0;if((c[f>>2]|0)==0){o=0;i=a;return o|0}f=c[q>>2]|0;c[d>>2]=9534384;gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](d,12,0)|0;if((f|0)<1){o=1;i=a;return o|0}o=(gzL(n,0,12)|0)!=0|0;i=a;return o|0}function biz(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;a=i;i=i+960|0;b=a|0;d=a+112|0;e=a+120|0;f=a+232|0;g=a+240|0;h=a+352|0;j=a+360|0;k=a+472|0;l=a+480|0;m=a+592|0;n=a+600|0;o=a+712|0;p=a+720|0;q=a+832|0;r=a+840|0;s=a+952|0;t=c[3531126]|0;if((R6(t+1|0,0,2)|0)!=0){u=1;i=a;return u|0}if((R6(t,1,2)|0)!=0){u=1;i=a;return u|0}if((R6(t+131073|0,2,2)|0)!=0){u=1;i=a;return u|0}if((R6(t+131072|0,3,2)|0)!=0){u=1;i=a;return u|0}if((R6((c[3531114]|0)+1|0,4,2)|0)!=0){u=1;i=a;return u|0}if((R6(c[3531114]|0,5,2)|0)!=0){u=1;i=a;return u|0}t=c[2386002]|0;if((c[3542200]|0)==0){u=1;i=a;return u|0}v=r+108|0;c[v>>2]=0;w=r+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,6)|0;do{if((c[v>>2]|0)!=0){r=c[w>>2]|0;c[s>>2]=9534384;x=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[x&16383](s,6,0)|0;if((r|0)<1){u=1;i=a;return u|0}if((gzL(t,0,6)|0)==0){break}else{u=1}i=a;return u|0}}while(0);t=c[3530942]|0;if((c[3542200]|0)==0){u=1;i=a;return u|0}s=p+108|0;c[s>>2]=0;w=p+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,7)|0;do{if((c[s>>2]|0)!=0){p=c[w>>2]|0;c[q>>2]=9534384;v=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[v&16383](q,7,0)|0;if((p|0)<1){u=1;i=a;return u|0}if((gzL(t,0,7)|0)==0){break}else{u=1}i=a;return u|0}}while(0);t=c[3530706]|0;if((c[3542200]|0)==0){u=1;i=a;return u|0}q=n+108|0;c[q>>2]=0;w=n+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,8)|0;do{if((c[q>>2]|0)!=0){n=c[w>>2]|0;c[o>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](o,8,0)|0;if((n|0)<1){u=1;i=a;return u|0}if((gzL(t,0,8)|0)==0){break}else{u=1}i=a;return u|0}}while(0);t=(c[3530706]|0)+524288|0;if((c[3542200]|0)==0){u=1;i=a;return u|0}o=l+108|0;c[o>>2]=0;w=l+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,9)|0;do{if((c[o>>2]|0)!=0){l=c[w>>2]|0;c[m>>2]=9534384;q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[q&16383](m,9,0)|0;if((l|0)<1){u=1;i=a;return u|0}if((gzL(t,0,9)|0)==0){break}else{u=1}i=a;return u|0}}while(0);t=(c[3530706]|0)+1048576|0;if((c[3542200]|0)==0){u=1;i=a;return u|0}m=j+108|0;c[m>>2]=0;w=j+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,10)|0;do{if((c[m>>2]|0)!=0){j=c[w>>2]|0;c[k>>2]=9534384;o=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[o&16383](k,10,0)|0;if((j|0)<1){u=1;i=a;return u|0}if((gzL(t,0,10)|0)==0){break}else{u=1}i=a;return u|0}}while(0);t=(c[3530706]|0)+1572864|0;if((c[3542200]|0)==0){u=1;i=a;return u|0}k=g+108|0;c[k>>2]=0;w=g+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,11)|0;do{if((c[k>>2]|0)!=0){g=c[w>>2]|0;c[h>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](h,11,0)|0;if((g|0)<1){u=1;i=a;return u|0}if((gzL(t,0,11)|0)==0){break}else{u=1}i=a;return u|0}}while(0);t=c[3529776]|0;if((c[3542200]|0)==0){u=1;i=a;return u|0}h=e+108|0;c[h>>2]=0;w=e+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,12)|0;do{if((c[h>>2]|0)!=0){e=c[w>>2]|0;c[f>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](f,12,0)|0;if((e|0)<1){u=1;i=a;return u|0}if((gzL(t,0,12)|0)==0){break}else{u=1}i=a;return u|0}}while(0);t=c[3529730]|0;if((c[3542200]|0)==0){u=1;i=a;return u|0}f=b+108|0;c[f>>2]=0;w=b+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](b,13)|0;if((c[f>>2]|0)==0){u=0;i=a;return u|0}f=c[w>>2]|0;c[d>>2]=9534384;gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](d,13,0)|0;if((f|0)<1){u=1;i=a;return u|0}u=(gzL(t,0,13)|0)!=0|0;i=a;return u|0}function biA(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;a=i;i=i+960|0;b=a|0;d=a+112|0;e=a+120|0;f=a+232|0;g=a+240|0;h=a+352|0;j=a+360|0;k=a+472|0;l=a+480|0;m=a+592|0;n=a+600|0;o=a+712|0;p=a+720|0;q=a+832|0;r=a+840|0;s=a+952|0;if((R6((c[3531126]|0)+1|0,0,2)|0)!=0){t=1;i=a;return t|0}if((R6(c[3531126]|0,1,2)|0)!=0){t=1;i=a;return t|0}u=c[2386002]|0;if((c[3542200]|0)==0){t=1;i=a;return t|0}v=r+108|0;c[v>>2]=0;w=r+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,2)|0;do{if((c[v>>2]|0)!=0){r=c[w>>2]|0;c[s>>2]=9534384;x=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[x&16383](s,2,0)|0;if((r|0)<1){t=1;i=a;return t|0}if((gzL(u,0,2)|0)==0){break}else{t=1}i=a;return t|0}}while(0);u=c[3530942]|0;if((c[3542200]|0)==0){t=1;i=a;return t|0}s=p+108|0;c[s>>2]=0;w=p+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,3)|0;do{if((c[s>>2]|0)!=0){p=c[w>>2]|0;c[q>>2]=9534384;v=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[v&16383](q,3,0)|0;if((p|0)<1){t=1;i=a;return t|0}if((gzL(u,0,3)|0)==0){break}else{t=1}i=a;return t|0}}while(0);u=c[3530706]|0;if((c[3542200]|0)==0){t=1;i=a;return t|0}q=n+108|0;c[q>>2]=0;w=n+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,4)|0;do{if((c[q>>2]|0)!=0){n=c[w>>2]|0;c[o>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](o,4,0)|0;if((n|0)<1){t=1;i=a;return t|0}if((gzL(u,0,4)|0)==0){break}else{t=1}i=a;return t|0}}while(0);u=(c[3530706]|0)+524288|0;if((c[3542200]|0)==0){t=1;i=a;return t|0}o=l+108|0;c[o>>2]=0;w=l+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,5)|0;do{if((c[o>>2]|0)!=0){l=c[w>>2]|0;c[m>>2]=9534384;q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[q&16383](m,5,0)|0;if((l|0)<1){t=1;i=a;return t|0}if((gzL(u,0,5)|0)==0){break}else{t=1}i=a;return t|0}}while(0);u=(c[3530706]|0)+1048576|0;if((c[3542200]|0)==0){t=1;i=a;return t|0}m=j+108|0;c[m>>2]=0;w=j+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,6)|0;do{if((c[m>>2]|0)!=0){j=c[w>>2]|0;c[k>>2]=9534384;o=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[o&16383](k,6,0)|0;if((j|0)<1){t=1;i=a;return t|0}if((gzL(u,0,6)|0)==0){break}else{t=1}i=a;return t|0}}while(0);u=(c[3530706]|0)+1572864|0;if((c[3542200]|0)==0){t=1;i=a;return t|0}k=g+108|0;c[k>>2]=0;w=g+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,7)|0;do{if((c[k>>2]|0)!=0){g=c[w>>2]|0;c[h>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](h,7,0)|0;if((g|0)<1){t=1;i=a;return t|0}if((gzL(u,0,7)|0)==0){break}else{t=1}i=a;return t|0}}while(0);u=c[3529776]|0;if((c[3542200]|0)==0){t=1;i=a;return t|0}h=e+108|0;c[h>>2]=0;w=e+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,8)|0;do{if((c[h>>2]|0)!=0){e=c[w>>2]|0;c[f>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](f,8,0)|0;if((e|0)<1){t=1;i=a;return t|0}if((gzL(u,0,8)|0)==0){break}else{t=1}i=a;return t|0}}while(0);u=c[3529730]|0;if((c[3542200]|0)==0){t=1;i=a;return t|0}f=b+108|0;c[f>>2]=0;w=b+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](b,9)|0;if((c[f>>2]|0)==0){t=0;i=a;return t|0}f=c[w>>2]|0;c[d>>2]=9534384;gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](d,9,0)|0;if((f|0)<1){t=1;i=a;return t|0}t=(gzL(u,0,9)|0)!=0|0;i=a;return t|0}function biB(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;a=i;i=i+960|0;b=a|0;d=a+112|0;e=a+120|0;f=a+232|0;g=a+240|0;h=a+352|0;j=a+360|0;k=a+472|0;l=a+480|0;m=a+592|0;n=a+600|0;o=a+712|0;p=a+720|0;q=a+832|0;r=a+840|0;s=a+952|0;t=c[3531126]|0;if((R6(t+1|0,0,2)|0)!=0){u=1;i=a;return u|0}if((R6(t,1,2)|0)!=0){u=1;i=a;return u|0}if((R6(t+131073|0,2,2)|0)!=0){u=1;i=a;return u|0}if((R6(t+131072|0,3,2)|0)!=0){u=1;i=a;return u|0}t=c[3531114]|0;if((R6(t+1|0,4,2)|0)!=0){u=1;i=a;return u|0}if((R6(t,5,2)|0)!=0){u=1;i=a;return u|0}if((R6(t+131073|0,6,2)|0)!=0){u=1;i=a;return u|0}if((R6(t+131072|0,7,2)|0)!=0){u=1;i=a;return u|0}t=c[2386002]|0;if((c[3542200]|0)==0){u=1;i=a;return u|0}v=r+108|0;c[v>>2]=0;w=r+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,8)|0;do{if((c[v>>2]|0)!=0){r=c[w>>2]|0;c[s>>2]=9534384;x=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[x&16383](s,8,0)|0;if((r|0)<1){u=1;i=a;return u|0}if((gzL(t,0,8)|0)==0){break}else{u=1}i=a;return u|0}}while(0);t=c[3530942]|0;if((c[3542200]|0)==0){u=1;i=a;return u|0}s=p+108|0;c[s>>2]=0;w=p+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,9)|0;do{if((c[s>>2]|0)!=0){p=c[w>>2]|0;c[q>>2]=9534384;v=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[v&16383](q,9,0)|0;if((p|0)<1){u=1;i=a;return u|0}if((gzL(t,0,9)|0)==0){break}else{u=1}i=a;return u|0}}while(0);t=c[3530706]|0;if((c[3542200]|0)==0){u=1;i=a;return u|0}q=n+108|0;c[q>>2]=0;w=n+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,10)|0;do{if((c[q>>2]|0)!=0){n=c[w>>2]|0;c[o>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](o,10,0)|0;if((n|0)<1){u=1;i=a;return u|0}if((gzL(t,0,10)|0)==0){break}else{u=1}i=a;return u|0}}while(0);t=(c[3530706]|0)+524288|0;if((c[3542200]|0)==0){u=1;i=a;return u|0}o=l+108|0;c[o>>2]=0;w=l+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,11)|0;do{if((c[o>>2]|0)!=0){l=c[w>>2]|0;c[m>>2]=9534384;q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[q&16383](m,11,0)|0;if((l|0)<1){u=1;i=a;return u|0}if((gzL(t,0,11)|0)==0){break}else{u=1}i=a;return u|0}}while(0);t=(c[3530706]|0)+1048576|0;if((c[3542200]|0)==0){u=1;i=a;return u|0}m=j+108|0;c[m>>2]=0;w=j+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,12)|0;do{if((c[m>>2]|0)!=0){j=c[w>>2]|0;c[k>>2]=9534384;o=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[o&16383](k,12,0)|0;if((j|0)<1){u=1;i=a;return u|0}if((gzL(t,0,12)|0)==0){break}else{u=1}i=a;return u|0}}while(0);t=(c[3530706]|0)+1572864|0;if((c[3542200]|0)==0){u=1;i=a;return u|0}k=g+108|0;c[k>>2]=0;w=g+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,13)|0;do{if((c[k>>2]|0)!=0){g=c[w>>2]|0;c[h>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](h,13,0)|0;if((g|0)<1){u=1;i=a;return u|0}if((gzL(t,0,13)|0)==0){break}else{u=1}i=a;return u|0}}while(0);t=c[3529776]|0;if((c[3542200]|0)==0){u=1;i=a;return u|0}h=e+108|0;c[h>>2]=0;w=e+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,14)|0;do{if((c[h>>2]|0)!=0){e=c[w>>2]|0;c[f>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](f,14,0)|0;if((e|0)<1){u=1;i=a;return u|0}if((gzL(t,0,14)|0)==0){break}else{u=1}i=a;return u|0}}while(0);t=c[3529730]|0;if((c[3542200]|0)==0){u=1;i=a;return u|0}f=b+108|0;c[f>>2]=0;w=b+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](b,15)|0;if((c[f>>2]|0)==0){u=0;i=a;return u|0}f=c[w>>2]|0;c[d>>2]=9534384;gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](d,15,0)|0;if((f|0)<1){u=1;i=a;return u|0}u=(gzL(t,0,15)|0)!=0|0;i=a;return u|0}function biC(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;b=i;i=i+960|0;d=b|0;e=b+112|0;f=b+120|0;g=b+232|0;h=b+240|0;j=b+352|0;k=b+360|0;l=b+472|0;m=b+480|0;n=b+592|0;o=b+600|0;p=b+712|0;q=b+720|0;r=b+832|0;s=b+840|0;t=b+952|0;u=c[3531126]|0;if((R6(u+1|0,0,2)|0)!=0){v=1;i=b;return v|0}if((R6(u,1,2)|0)!=0){v=1;i=b;return v|0}if((R6(u+131073|0,2,2)|0)!=0){v=1;i=b;return v|0}if((R6(u+131072|0,3,2)|0)!=0){v=1;i=b;return v|0}u=c[3531114]|0;if((R6(u+1|0,4,2)|0)!=0){v=1;i=b;return v|0}if((R6(u,5,2)|0)!=0){v=1;i=b;return v|0}if((R6(u+131073|0,6,2)|0)!=0){v=1;i=b;return v|0}if((R6(u+131072|0,7,2)|0)!=0){v=1;i=b;return v|0}u=c[2386002]|0;if((c[3542200]|0)==0){v=1;i=b;return v|0}w=s+108|0;c[w>>2]=0;x=s+100|0;c[x>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](s,8)|0;do{if((c[w>>2]|0)!=0){s=c[x>>2]|0;c[t>>2]=9534384;y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[y&16383](t,8,0)|0;if((s|0)<1){v=1;i=b;return v|0}if((gzL(u,0,8)|0)==0){break}else{v=1}i=b;return v|0}}while(0);u=c[3530942]|0;if((c[3542200]|0)==0){v=1;i=b;return v|0}t=q+108|0;c[t>>2]=0;x=q+100|0;c[x>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](q,9)|0;do{if((c[t>>2]|0)!=0){q=c[x>>2]|0;c[r>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](r,9,0)|0;if((q|0)<1){v=1;i=b;return v|0}if((gzL(u,0,9)|0)==0){break}else{v=1}i=b;return v|0}}while(0);u=c[3530706]|0;if((c[3542200]|0)==0){v=1;i=b;return v|0}r=o+108|0;c[r>>2]=0;x=o+100|0;c[x>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](o,10)|0;do{if((c[r>>2]|0)!=0){o=c[x>>2]|0;c[p>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](p,10,0)|0;if((o|0)<1){v=1;i=b;return v|0}if((gzL(u,0,10)|0)==0){break}else{v=1}i=b;return v|0}}while(0);u=(c[3530706]|0)+524288|0;if((c[3542200]|0)==0){v=1;i=b;return v|0}p=m+108|0;c[p>>2]=0;x=m+100|0;c[x>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,11)|0;do{if((c[p>>2]|0)!=0){m=c[x>>2]|0;c[n>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](n,11,0)|0;if((m|0)<1){v=1;i=b;return v|0}if((gzL(u,0,11)|0)==0){break}else{v=1}i=b;return v|0}}while(0);u=(c[3530706]|0)+1048576|0;if((c[3542200]|0)==0){v=1;i=b;return v|0}n=k+108|0;c[n>>2]=0;x=k+100|0;c[x>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,12)|0;do{if((c[n>>2]|0)!=0){k=c[x>>2]|0;c[l>>2]=9534384;p=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[p&16383](l,12,0)|0;if((k|0)<1){v=1;i=b;return v|0}if((gzL(u,0,12)|0)==0){break}else{v=1}i=b;return v|0}}while(0);u=(c[3530706]|0)+1572864|0;if((c[3542200]|0)==0){v=1;i=b;return v|0}l=h+108|0;c[l>>2]=0;x=h+100|0;c[x>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](h,13)|0;do{if((c[l>>2]|0)!=0){h=c[x>>2]|0;c[j>>2]=9534384;n=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[n&16383](j,13,0)|0;if((h|0)<1){v=1;i=b;return v|0}if((gzL(u,0,13)|0)==0){break}else{v=1}i=b;return v|0}}while(0);u=0;j=c[3530706]|0;while(1){x=a[j]|0;l=j+1|0;a[j]=a[l]|0;a[l]=x;x=u+1|0;if((x|0)<1048576){u=x;j=j+2|0}else{break}}j=c[3529776]|0;if((c[3542200]|0)==0){v=1;i=b;return v|0}u=f+108|0;c[u>>2]=0;x=f+100|0;c[x>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,14)|0;do{if((c[u>>2]|0)!=0){f=c[x>>2]|0;c[g>>2]=9534384;l=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[l&16383](g,14,0)|0;if((f|0)<1){v=1;i=b;return v|0}if((gzL(j,0,14)|0)==0){break}else{v=1}i=b;return v|0}}while(0);j=c[3529730]|0;if((c[3542200]|0)==0){v=1;i=b;return v|0}g=d+108|0;c[g>>2]=0;x=d+100|0;c[x>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](d,15)|0;if((c[g>>2]|0)==0){v=0;i=b;return v|0}g=c[x>>2]|0;c[e>>2]=9534384;gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](e,15,0)|0;if((g|0)<1){v=1;i=b;return v|0}v=(gzL(j,0,15)|0)!=0|0;i=b;return v|0}function biD(b){b=b|0;var d=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=i;i=i+16|0;f=d|0;g=c[2437790]|0;h=(g>>>3&1|0)!=(b|0);j=h&1;k=(c[2386272]|0)+(j<<13)|0;l=c[2405110]|0;c[f+12>>2]=l>>12;c[f+8>>2]=l>>>8&15;c[f+4>>2]=l>>>4&15;c[f>>2]=l&15;l=h?2:1;h=e[(c[2406650]|0)+(l<<1)>>1]|0;m=e[(c[2406642]|0)+(l<<1)>>1]|0;l=(g&2|0)==0;n=l?h:192-h|0;h=g&1;o=(h|0)==0?m:256-m|0;m=j<<3;j=(b|0)==0;b=a[633064]^(h|0)!=0;h=c[2112926]|0;p=c[2387842]|0;q=c[2113068]|0;r=0;s=g;while(1){g=r<<3&504;t=r>>6<<3;u=((s&2|0)==0?g:g^504)-n|0;g=u&511;v=((s&1|0)==0?t:t^504)-o|0;t=v&511;w=g>>>0>319?u|-512:g;g=(t>>>0>255?v|-512:t)-16|0;t=e[k+(r<<1)>>1]|0;v=m|t>>>13|32;u=t&2047|c[f+((t>>>11&3)<<2)>>2]<<11;do{if((w|0)>-1){if(!((w|0)<(q-7|0)&(g|0)>-1)){x=66686;break}if((g|0)>=((c[2113070]|0)-7|0)){x=66686;break}if(!j){if(b){if(l){Sm(h,u,w,g,v,4,0,p);break}else{So(h,u,w,g,v,4,0,p);break}}else{if(l){Si(h,u,w,g,v,4,0,p);break}else{Sk(h,u,w,g,v,4,0,p);break}}}if((u|0)==0){break}if(b){if(l){Su(h,u,w,g,v,4,0,0,p);break}else{Sw(h,u,w,g,v,4,0,0,p);break}}else{if(l){Sq(h,u,w,g,v,4,0,0,p);break}else{Ss(h,u,w,g,v,4,0,0,p);break}}}else{x=66686}}while(0);do{if((x|0)==66686){x=0;if(!((g|0)>-8&(g|0)<(c[2113070]|0)&(w|0)<(q|0))){break}if(!j){if(b){if(l){Sn(h,u,w,g,v,4,0,p);break}else{Sp(h,u,w,g,v,4,0,p);break}}else{if(l){Sj(h,u,w,g,v,4,0,p);break}else{Sl(h,u,w,g,v,4,0,p);break}}}if((u|0)==0){break}if(b){if(l){Sv(h,u,w,g,v,4,0,0,p);break}else{Sx(h,u,w,g,v,4,0,0,p);break}}else{if(l){Sr(h,u,w,g,v,4,0,0,p);break}else{St(h,u,w,g,v,4,0,0,p);break}}}}while(0);v=r+1|0;if((v|0)>=4096){break}r=v;s=c[2437790]|0}i=d;return}function biE(a){a=a|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;d=c[2443442]|0;f=c[3530706]|0;g=f;h=c[2386586]|0;i=h+16376|0;j=f+1048576|0;k=f+524288|0;l=f+1572864|0;f=(c[2429572]|0)==1;m=c[2112926]|0;n=c[2113068]|0;o=h+12288|0;do{h=e[o+6>>1]|0;do{if((h>>>14&1|0)==(a|0)){p=b[o>>1]|0;q=p&65535;if(p<<16>>16==-1){break}if((h&32768|0)==0){break}p=b[o+2>>1]|0;r=p&65535;s=b[o+4>>1]|0;t=s&65535;u=h<<4&240|256;v=16<<(h>>>6&3);w=16<<(h>>>4&3);x=h&512;y=h&256;if(f){z=j;A=q}else{B=q>>>12&3;if((B|0)==3){C=d}else if((B|0)==0){C=g}else if((B|0)==2){C=(q&16384|0)==0?j:l}else if((B|0)==1){C=k}else{C=0}z=C;A=q&4095}do{if((v|0)==64&(w|0)==64){D=A&65527}else{q=(v|0)==32;B=(w|0)==32;if(q&B){D=A&65532;break}if(q&(w|0)==16){D=A&65534;break}else{D=(v|0)==16&B?A&65534:A;break}}}while(0);B=z+(D<<6<<1)|0;q=c[2437790]|0;if((q&1|0)==0){E=x;F=t}else{E=x>>>9^1;F=256-v-((s&65535)>65e3?t|-65536:t)|0}if((q&2|0)==0){G=y;H=r}else{G=y>>>8^1;H=320-w-((p&65535)>65e3?r|-65536:r)|0}q=(H|0)>319?H-65536|0:H;I=(F|0)>255?F-65536|0:F;if((v|0)<=0){break}J=(w|0)>0;K=(G|0)==0;L=w-1+q|0;M=(w|0)/4|0;if((E|0)==0){N=I-16|0;O=0;P=B;while(1){Q=N+O|0;do{if(Q>>>0<224){R=ag(n,Q)|0;if(!J){break}if(K){S=0;do{T=S+q|0;do{if(T>>>0<320){U=(e[P+(((S|0)/4|0)<<1)>>1]|0)>>>((S<<2&12^12)>>>0)&15;if((U|0)==0){break}b[m+(T+R<<1)>>1]=(U|u)&65535}}while(0);S=S+1|0;}while((S|0)<(w|0))}else{S=0;do{T=L-S|0;do{if(T>>>0<320){U=(e[P+(((S|0)/4|0)<<1)>>1]|0)>>>((S<<2&12^12)>>>0)&15;if((U|0)==0){break}b[m+(T+R<<1)>>1]=(U|u)&65535}}while(0);S=S+1|0;}while((S|0)<(w|0))}}}while(0);Q=O+1|0;if((Q|0)<(v|0)){O=Q;P=P+(M<<1)|0}else{break}}}else{P=v-17+I|0;O=0;N=B;while(1){r=P-O|0;do{if(r>>>0<224){p=ag(n,r)|0;if(!J){break}if(K){y=0;do{t=y+q|0;do{if(t>>>0<320){s=(e[N+(((y|0)/4|0)<<1)>>1]|0)>>>((y<<2&12^12)>>>0)&15;if((s|0)==0){break}b[m+(t+p<<1)>>1]=(s|u)&65535}}while(0);y=y+1|0;}while((y|0)<(w|0))}else{y=0;do{t=L-y|0;do{if(t>>>0<320){s=(e[N+(((y|0)/4|0)<<1)>>1]|0)>>>((y<<2&12^12)>>>0)&15;if((s|0)==0){break}b[m+(t+p<<1)>>1]=(s|u)&65535}}while(0);y=y+1|0;}while((y|0)<(w|0))}}}while(0);r=O+1|0;if((r|0)<(v|0)){O=r;N=N+(M<<1)|0}else{break}}}}}while(0);o=o+8|0;}while(o>>>0<i>>>0);return}function biF(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=e[c[2406650]>>1]|0;f=e[c[2406642]>>1]|0;g=c[2386528]|0;h=g;i=g+12288|0;g=i;gGz(i|0,0,2048);i=h;do{j=e[i>>1]|0;if((j&32768|0)!=0){k=j<<2&1020;l=(e[i+8>>1]|0)<<16|(e[i+10>>1]|0);m=(e[i+12>>1]|0)<<16|(e[i+14>>1]|0);n=b[i+4>>1]&1023;b[h+((k|6144)<<1)>>1]=b[i+6>>1]|0;b[h+((k|6145)<<1)>>1]=(l>>>8)-d&65535;b[h+((k|6146)<<1)>>1]=(m>>>8)-f&65535;b[h+((k|6147)<<1)>>1]=(((j&512|0)==0?n:n|16384)|32768)&65535}i=i+80|0;}while(i>>>0<g>>>0);a[689328]=0;return}function biG(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;a=i;i=i+960|0;b=a|0;d=a+112|0;e=a+120|0;f=a+232|0;g=a+240|0;h=a+352|0;j=a+360|0;k=a+472|0;l=a+480|0;m=a+592|0;n=a+600|0;o=a+712|0;p=a+720|0;q=a+832|0;r=a+840|0;s=a+952|0;t=c[3531126]|0;if((R6(t+1|0,0,2)|0)!=0){u=1;i=a;return u|0}if((R6(t,1,2)|0)!=0){u=1;i=a;return u|0}if((R6(t+131073|0,2,2)|0)!=0){u=1;i=a;return u|0}if((R6(t+131072|0,3,2)|0)!=0){u=1;i=a;return u|0}t=c[3531114]|0;if((R6(t+1|0,4,2)|0)!=0){u=1;i=a;return u|0}if((R6(t,5,2)|0)!=0){u=1;i=a;return u|0}if((R6(t+131073|0,6,2)|0)!=0){u=1;i=a;return u|0}if((R6(t+131072|0,7,2)|0)!=0){u=1;i=a;return u|0}t=c[2386002]|0;if((c[3542200]|0)==0){u=1;i=a;return u|0}v=r+108|0;c[v>>2]=0;w=r+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,8)|0;do{if((c[v>>2]|0)!=0){r=c[w>>2]|0;c[s>>2]=9534384;x=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[x&16383](s,8,0)|0;if((r|0)<1){u=1;i=a;return u|0}if((gzL(t,0,8)|0)==0){break}else{u=1}i=a;return u|0}}while(0);t=c[3530942]|0;if((c[3542200]|0)==0){u=1;i=a;return u|0}s=p+108|0;c[s>>2]=0;w=p+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,9)|0;do{if((c[s>>2]|0)!=0){p=c[w>>2]|0;c[q>>2]=9534384;v=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[v&16383](q,9,0)|0;if((p|0)<1){u=1;i=a;return u|0}if((gzL(t,0,9)|0)==0){break}else{u=1}i=a;return u|0}}while(0);t=c[3530706]|0;if((c[3542200]|0)==0){u=1;i=a;return u|0}q=n+108|0;c[q>>2]=0;w=n+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,10)|0;do{if((c[q>>2]|0)!=0){n=c[w>>2]|0;c[o>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](o,10,0)|0;if((n|0)<1){u=1;i=a;return u|0}if((gzL(t,0,10)|0)==0){break}else{u=1}i=a;return u|0}}while(0);t=(c[3530706]|0)+524288|0;if((c[3542200]|0)==0){u=1;i=a;return u|0}o=l+108|0;c[o>>2]=0;w=l+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,11)|0;do{if((c[o>>2]|0)!=0){l=c[w>>2]|0;c[m>>2]=9534384;q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[q&16383](m,11,0)|0;if((l|0)<1){u=1;i=a;return u|0}if((gzL(t,0,11)|0)==0){break}else{u=1}i=a;return u|0}}while(0);t=(c[3530706]|0)+1048576|0;if((c[3542200]|0)==0){u=1;i=a;return u|0}m=j+108|0;c[m>>2]=0;w=j+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,12)|0;do{if((c[m>>2]|0)!=0){j=c[w>>2]|0;c[k>>2]=9534384;o=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[o&16383](k,12,0)|0;if((j|0)<1){u=1;i=a;return u|0}if((gzL(t,0,12)|0)==0){break}else{u=1}i=a;return u|0}}while(0);t=(c[3530706]|0)+1572864|0;if((c[3542200]|0)==0){u=1;i=a;return u|0}k=g+108|0;c[k>>2]=0;w=g+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,13)|0;do{if((c[k>>2]|0)!=0){g=c[w>>2]|0;c[h>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](h,13,0)|0;if((g|0)<1){u=1;i=a;return u|0}if((gzL(t,0,13)|0)==0){break}else{u=1}i=a;return u|0}}while(0);if((R6((c[3530488]|0)+1|0,14,2)|0)!=0){u=1;i=a;return u|0}if((R6(c[3530488]|0,15,2)|0)!=0){u=1;i=a;return u|0}t=c[3529776]|0;if((c[3542200]|0)==0){u=1;i=a;return u|0}h=e+108|0;c[h>>2]=0;w=e+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,16)|0;do{if((c[h>>2]|0)!=0){e=c[w>>2]|0;c[f>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](f,16,0)|0;if((e|0)<1){u=1;i=a;return u|0}if((gzL(t,0,16)|0)==0){break}else{u=1}i=a;return u|0}}while(0);t=c[3529730]|0;if((c[3542200]|0)==0){u=1;i=a;return u|0}f=b+108|0;c[f>>2]=0;w=b+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](b,17)|0;if((c[f>>2]|0)==0){u=0;i=a;return u|0}f=c[w>>2]|0;c[d>>2]=9534384;gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](d,17,0)|0;if((f|0)<1){u=1;i=a;return u|0}u=(gzL(t,0,17)|0)!=0|0;i=a;return u|0}function biH(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=0;while(1){if((f|0)>=1024){g=0;break}h=9638528+(f<<2)|0;if((c[h>>2]|0)==0){i=66844;break}else{f=f+1|0}}do{if((i|0)==66844){f=gGq(2048)|0;c[h>>2]=f;if((f|0)==0){g=0;break}gGz(f|0,0,2048);g=f}}while(0);c[3529054]=g;g=0;while(1){if((g|0)>=1024){j=0;break}k=9638528+(g<<2)|0;if((c[k>>2]|0)==0){i=66849;break}else{g=g+1|0}}do{if((i|0)==66849){g=gGq(2048)|0;c[k>>2]=g;if((g|0)==0){j=0;break}gGz(g|0,0,2048);j=g}}while(0);c[3529058]=j;c[3527124]=d;c[3529056]=b;c[2437690]=e;e=(c[2439478]|0)+1|0;c[2439478]=e;a[7461776]=1;b=c[2308882]|0;if((b|0)==0){d=c[642608+(c[2436]<<2)>>2]|0;j=ag(c[d+128>>2]<<1,c[d+132>>2]|0)|0;d=0;while(1){if((d|0)>=1024){l=0;break}m=9638528+(d<<2)|0;if((c[m>>2]|0)==0){i=66855;break}else{d=d+1|0}}do{if((i|0)==66855){d=gGq(j)|0;c[m>>2]=d;if((d|0)==0){l=0;break}gGz(d|0,0,j|0);l=d}}while(0);c[2308882]=l;n=c[2439478]|0;o=l}else{n=e;o=b}c[3527122]=o;if((n|0)<=0){return}o=(n|0)>1?n:1;gGz(14108504,0,o<<4|0);gGz(14108536,0,o<<2|0);o=0;do{gGz(c[14116216+(o<<2)>>2]|0,0,2048);gGz(c[14116232+(o<<2)>>2]|0,0,2048);o=o+1|0;}while((o|0)<(n|0));return}function biI(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0;h=i;i=i+512|0;j=h|0;k=i;i=i+4|0;i=i+7&-8;l=i;i=i+4|0;i=i+7&-8;m=i;i=i+4|0;i=i+7&-8;n=d[14108509]|0;o=d[14108504]|0;p=a[14108505]|0;q=d[14108506]|0;r=a[14108507]|0;gGz(j|0,-1|0,512);s=o<<8;o=q<<8;q=c[3529058]|0;t=(a[7461816]^1)<<31>>31;u=0;do{v=e[q+(u<<1)>>1]|0;do{if((v&32768|0)!=0){w=v&127;if((u|0)!=0&(w|0)==(t|0)){break}x=j+(w<<2)|0;if((c[x>>2]|0)!=-1){break}c[x>>2]=u}}while(0);u=u+8|0;}while((u|0)<1024);u=s|p&255;p=(n&1|0)==0;s=(n&2|0)==0;n=-7-(o|r&255)|0;r=0;do{o=c[j+(r<<2)>>2]|0;L86533:do{if((o|0)!=-1){t=e[q+(o+1<<1)>>1]|0;c[l>>2]=t>>>2&4|t&65505|t<<1&16|t>>>1&2|t<<2&8;t=q+(o+6<<1)|0;c[k>>2]=b[t>>1]&255;c[m>>2]=0;gG[c[2437690]&255](l,k,m);if((c[m>>2]|0)!=(g|0)){break}v=b[q+(o<<1)>>1]|0;x=v&65535;w=x>>>8&3;y=1<<w;z=x>>>10&3;A=1<<z;B=b[q+(o+4<<1)>>1]|0;C=B&65535;if((B&65535)>8192){break}if(B<<16>>16==0){D=8388608}else{D=((C>>>1|4194304)>>>0)/(C>>>0)|0}do{if((v&16384)==0){C=b[q+(o+5<<1)>>1]|0;B=C&65535;if((C&65535)>8192){break L86533}if(C<<16>>16==0){E=8388608;break}E=((B>>>1|4194304)>>>0)/(B>>>0)|0}else{E=D}}while(0);v=(e[q+(o+3<<1)>>1]|0)+u+(c[3529052]|0)|0;B=(c[3529050]|0)+(e[q+(o+2<<1)>>1]|0)|0;C=x&8192;F=b[t>>1]|0;G=(F&256)!=0;H=G?0:x&4096;I=F&65535;F=I&512;J=I&128;do{if(p){K=v;L=H}else{I=512-v|0;if(G){K=I;L=H;break}K=I;L=H>>>12^1}}while(0);do{if(s){M=B;N=C}else{H=-B|0;if((F|0)!=0){M=H;N=C;break}M=H;N=C>>>13^1}}while(0);C=K+93|0;B=C&1023;H=n-M|0;v=H&1023;x=(B>>>0>767?C|-1024:B)-(E<<w>>13)|0;B=(v>>>0>639?H|-1024:v)-(D<<z>>13)|0;if((A|0)<=0){break}v=(y|0)>0;H=(L|0)==0;C=y-1|0;t=(F|0)==0;I=(N|0)==0;O=A-1|0;P=(J|0)==0;Q=(E|0)==65536&(D|0)==65536;R=c[2112926]|0;S=c[2308882]|0;T=0;while(1){U=((ag(T,D)|0)+2048>>12)+B|0;V=T+1|0;W=((ag(V,D)|0)+2048>>12)+B-U|0;L86556:do{if(v){X=W<<12;Y=W<<16>>16;Z=(Y|0)==0;_=Y+U|0;$=(_|0)>-1;aa=(U|0)<0?-U|0:0;ab=aa+U|0;ac=I^(T<<1|0)>=(A|0);ad=t?(I?T:O-T|0)<<3:ac?(A-T<<3)+56|0:T<<3;ae=t?N:ac&1;ac=(ae|0)==0;af=ac?0:240;ah=af|15;ai=0;aj=0;while(1){ak=((ag(ai,E)|0)+2048>>12)+x|0;al=-ak|0;am=ai+1|0;an=((ag(am,E)|0)+2048>>12)+x-ak|0;ao=c[l>>2]|0;if(G){ap=H^(ai<<1|0)<(y|0);aq=ap&1;ar=ap?aj+C|0:ai}else{aq=L;ar=H?ai:aj+C|0}ap=ar+ao+ad&63|ao&-64;do{if(P){if(!Q){S2(R,f,ap,c[k>>2]<<4,0,ak,U,aq,ae,an<<12,X);break}ao=(aq|0)!=0;as=c[k>>2]|0;if(ac){if(ao){SJ(R,ap,ak,U,as,4,0,0,f);break}else{SH(R,ap,ak,U,as,4,0,0,f);break}}else{if(ao){SN(R,ap,ak,U,as,4,0,0,f);break}else{SL(R,ap,ak,U,as,4,0,0,f);break}}}else{as=c[k>>2]<<4;ao=an<<16>>16;if(Z|(ao|0)==0){break}at=ao+ak|0;if((at|0)<0){break}au=c[2113068]|0;av=c[2113070]|0;if(!($&(au|0)>(ak|0)&(av|0)>(U|0))){break}aw=(aq|0)==0?af:ah;ax=65536/(Y|0)|0;ay=65536/(ao|0)|0;az=(ak|0)<0?al:0;aA=(_|0)<(av|0)?Y:av-U|0;av=(at|0)<(au|0)?ao:au-ak|0;ao=ap<<8;at=(ag(au,ab)|0)+ak|0;if(!((aa|0)<(aA|0)&(az|0)<(av|0))){break}aB=S+(at<<1)|0;aC=R+(at<<1)|0;at=aa;while(1){aD=(ag(at,ax)|0)>>12<<4;aE=az;do{aF=a[f+((((ag(aE,ay)|0)>>12)+aD^aw)+ao)|0]|0;do{if(aF<<24>>24!=0){aG=(aF&255|as)&65535;if(aF<<24>>24==15){b[aB+(aE<<1)>>1]=aG;aH=aC+(aE<<1)|0;b[aH>>1]=b[aH>>1]|-32768;break}else{b[aC+(aE<<1)>>1]=aG;break}}}while(0);aE=aE+1|0;}while((aE|0)<(av|0));aE=at+1|0;if((aE|0)<(aA|0)){aB=aB+(au<<1)|0;aC=aC+(au<<1)|0;at=aE}else{break}}}}while(0);if((am|0)>=(y|0)){break L86556}ak=~ai;ai=am;aj=ak}}}while(0);if((V|0)<(A|0)){T=V}else{break}}}}while(0);r=r+1|0;}while((r|0)<128);i=h;return}function biJ(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;e=i;i=i+24|0;f=e|0;g=e+8|0;h=e+16|0;j=b&65535;switch(j|0){case 24460:{k=a[9550944]|0;i=e;return k|0};case 24512:{k=0;i=e;return k|0};case 24464:{k=a[9635665]|0;i=e;return k|0};case 24463:{k=a[9635664]|0;i=e;return k|0};case 24461:{k=a[9550945]|0;i=e;return k|0};case 24462:{k=a[9635666]&-16|a[9550946]&15;i=e;return k|0};default:{if((j&63488|0)==0){b=c[2385184]|0;if((b&2|0)!=0){k=a[(c[2387276]|0)+((b<<9&2048)+j)|0]|0;i=e;return k|0}if((b&1|0)==0){k=a[(c[3531088]|0)+j|0]|0;i=e;return k|0}else{k=a[(c[3529054]|0)+(j^1)|0]|0;i=e;return k|0}}if((j&65520|0)==24480){b=j&15;do{if((a[14108509]&16)!=0){if((j&12|0)!=12){break}k=a[(c[3529056]|0)+(((c[3527134]<<19|j&3|(d[14108515]|0)<<18&1835008|(d[14108512]|0)<<10|(d[14108513]|0)<<2)^1)&c[3527124])|0]|0;i=e;return k|0}}while(0);if((b|0)!=6){k=0;i=e;return k|0}b=c[3529058]|0;l=c[3529054]|0;gGC(b|0,l|0,2048)|0;k=0;i=e;return k|0}if((j&49152|0)!=16384){k=0;i=e;return k|0}if((c[3541230]|0)==0){k=a[(c[3529062]|0)+(j&16383)|0]|0;i=e;return k|0}c[f>>2]=0;l=j>>>5&255;c[g>>2]=l;b=d[9730680]|0;c[h>>2]=b;m=b>>>2&3;if((c[2429638]|0)==0){gB[c[2437692]&127](0,((a[9718936+m|0]|a[9720736+m|0])&255)>>>2,g,h,f,f);n=c[g>>2]|0}else{f=b<<8|l;c[g>>2]=f;n=f}k=a[(c[3529060]|0)+((n<<5|j&31)&c[2438700])|0]|0;i=e;return k|0}}return 0}function biK(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=b&65535;if((e|0)==24512){c[3541230]=d&8;return}else if((e|0)==24529){b=c[2113304]|0;a[14168504+b|0]=d;mv(0,b,d&255);return}else if((e|0)==24516){c[2385184]=d&255;return}else if((e|0)==24528){c[2113304]=d&255;return}else{if((e&63488|0)==0){b=c[2385184]|0;if((b&2|0)!=0){a[(c[2387276]|0)+((b<<9&2048)+e)|0]=d;return}if((b&1|0)==0){a[(c[3531088]|0)+e|0]=d;return}else{a[(c[3529054]|0)+(e^1)|0]=d;return}}b=e&65520;if((b|0)==24496){f=e&15;g=d&255;h=g&63;a[14116144+f|0]=h&255;if((f|0)==9){c[2437682]=g<<5&96;c[2437683]=g>>>2<<5&96;c[2437684]=h>>>4<<5;return}else if((f|0)==10){c[2437685]=g<<4&112;c[2437686]=h>>>3<<4;return}else{return}}else if((b|0)==24480){b=e&15;a[14108504+b|0]=d;if((b|0)!=6){return}b=c[3529058]|0;h=c[3529054]|0;gGC(b|0,h|0,2048)|0;return}else{if((e&49152|0)!=16384){return}h=e&16383;a[(c[3529062]|0)+h|0]=d;if((e&6144)>>>0<=6143){return}if((h|0)==7808){c[2432672]=(d&255)>>>1&3;return}else if((h|0)==7552){a[9720736]=d&15;a[9720737]=(d&255)>>>4;return}else if((h|0)==7680|(h|0)==15872){a[9730680]=d;return}else if((h|0)==7936){a[9720738]=d&15;a[9720739]=(d&255)>>>4;return}else if((h|0)==7296){a[9729904]=d;return}else if((h|0)==7424){c[3541228]=d&4;return}else{return}}}}function biL(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>5){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5660532+(b*112|0)>>2];c[a+104>>2]=c[5660536+(b*112|0)>>2];c[a+108>>2]=c[5660540+(b*112|0)>>2];d=0;return d|0}function biM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<6&(d|0)==0)){e=1;return e|0}c[a>>2]=5660432+(b*112|0);e=0;return e|0}function biN(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1184584+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function biO(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=54){if((a|0)==0){d=0;return d|0}e=a;f=4937112+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}f=b-55|0;if(f>>>0>2){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;a=2000424+(f*12|0)|0;c[b>>2]=c[a>>2];c[b+4>>2]=c[a+4>>2];c[b+8>>2]=c[a+8>>2];d=0;return d|0}function biP(){var b=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;b=i;i=i+720|0;e=b|0;f=b+112|0;g=b+120|0;j=b+232|0;k=b+240|0;l=b+352|0;m=b+360|0;n=b+472|0;o=b+480|0;p=b+592|0;q=b+600|0;r=b+712|0;c[2415094]=0;c[3530940]=0;c[2439906]=524288;c[3530704]=1572864;c[2439870]=2097152;c[2387378]=3145728;c[2407006]=3473408;c[3530180]=3481600;c[2414802]=3489792;c[3531088]=3489792;c[2387402]=3491840;c[2387276]=3497984;c[2443942]=3502080;c[2411862]=3502081;s=0;while(1){if((s|0)>=1024){break}t=9638528+(s<<2)|0;if((c[t>>2]|0)==0){u=67043;break}else{s=s+1|0}}do{if((u|0)==67043){s=gGq(3502081)|0;c[t>>2]=s;if((s|0)==0){break}c[2415094]=s;gGz(s|0,0,3502081);c[3530940]=s;c[2439906]=s+524288;c[3530704]=s+1572864;c[2439870]=s+2097152;c[2387378]=s+3145728;c[2407006]=s+3473408;c[3530180]=s+3481600;v=s+3489792|0;c[2414802]=v;c[3531088]=v;c[2387402]=s+3491840;c[2387276]=s+3497984;c[2443942]=s+3502080;v=s+3502081|0;c[2411862]=v;c[2414412]=v;v=s+3211264|0;if((c[3542200]|0)==0){w=1;i=b;return w|0}s=q+108|0;c[s>>2]=0;x=q+100|0;c[x>>2]=0;y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[y&16383](q,0)|0;do{if((c[s>>2]|0)!=0){y=c[x>>2]|0;c[r>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](r,0,0)|0;if((y|0)<1){w=1;i=b;return w|0}if((gzL(v,0,0)|0)==0){break}else{w=1}i=b;return w|0}}while(0);v=(c[2387378]|0)+196608|0;if((c[3542200]|0)==0){w=1;i=b;return w|0}x=o+108|0;c[x>>2]=0;s=o+100|0;c[s>>2]=0;y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[y&16383](o,1)|0;do{if((c[x>>2]|0)!=0){y=c[s>>2]|0;c[p>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](p,1,0)|0;if((y|0)<1){w=1;i=b;return w|0}if((gzL(v,0,1)|0)==0){break}else{w=1}i=b;return w|0}}while(0);v=c[2387378]|0;s=v+32768|0;x=v+294912|0;gGC(s|0,x|0,32768)|0;x=c[3530940]|0;if((c[3542200]|0)==0){w=1;i=b;return w|0}s=m+108|0;c[s>>2]=0;v=m+100|0;c[v>>2]=0;y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[y&16383](m,2)|0;do{if((c[s>>2]|0)!=0){y=c[v>>2]|0;c[n>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](n,2,0)|0;if((y|0)<1){w=1;i=b;return w|0}if((gzL(x,0,2)|0)==0){break}else{w=1}i=b;return w|0}}while(0);x=(c[3530940]|0)+262144|0;if((c[3542200]|0)==0){w=1;i=b;return w|0}v=k+108|0;c[v>>2]=0;s=k+100|0;c[s>>2]=0;y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[y&16383](k,3)|0;do{if((c[v>>2]|0)!=0){y=c[s>>2]|0;c[l>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](l,3,0)|0;if((y|0)<1){w=1;i=b;return w|0}if((gzL(x,0,3)|0)==0){break}else{w=1}i=b;return w|0}}while(0);x=c[3530704]|0;if((c[3542200]|0)==0){w=1;i=b;return w|0}s=g+108|0;c[s>>2]=0;v=g+100|0;c[v>>2]=0;y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[y&16383](g,4)|0;do{if((c[s>>2]|0)!=0){y=c[v>>2]|0;c[j>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](j,4,0)|0;if((y|0)<1){w=1;i=b;return w|0}if((gzL(x,0,4)|0)==0){break}else{w=1}i=b;return w|0}}while(0);x=(c[3530704]|0)+262144|0;if((c[3542200]|0)==0){w=1;i=b;return w|0}v=e+108|0;c[v>>2]=0;s=e+100|0;c[s>>2]=0;y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[y&16383](e,5)|0;do{if((c[v>>2]|0)!=0){y=c[s>>2]|0;c[f>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](f,5,0)|0;if((y|0)<1){w=1;i=b;return w|0}if((gzL(x,0,5)|0)==0){break}else{w=1}i=b;return w|0}}while(0);x=c[3530940]|0;blG(x,262144);s=c[3530704]|0;blG(s,262144);v=c[2439906]|0;y=0;do{z=y<<6;gGz(v+z|0,0,64);A=y<<8;B=0;do{C=1<<3-B;D=(c[611632+(B<<2)>>2]|0)+A|0;E=0;do{F=D+(c[1183816+(E<<2)>>2]|0)|0;G=(E<<3)+z|0;H=0;do{I=F+(c[614800+(H<<2)>>2]|0)|0;if(((d[x+((I|0)/8|0)|0]|0)&128>>>((I&7)>>>0)|0)!=0){I=v+(G+H)|0;a[I]=(d[I]|0|C)&255}H=H+1|0;}while((H|0)<8);E=E+1|0;}while((E|0)<8);B=B+1|0;}while((B|0)<4);y=y+1|0;}while((y|0)<16384);y=c[2439870]|0;v=0;do{B=v<<8;gGz(y+B|0,0,256);z=v<<10;A=0;do{E=1<<3-A;C=(c[611632+(A<<2)>>2]|0)+z|0;D=0;do{H=C+(c[3946808+(D<<2)>>2]|0)|0;G=(D<<4)+B|0;F=0;do{I=H+(c[6669416+(F<<2)>>2]|0)|0;if(((d[s+((I|0)/8|0)|0]|0)&128>>>((I&7)>>>0)|0)!=0){I=y+(G+F)|0;a[I]=(d[I]|0|E)&255}F=F+1|0;}while((F|0)<16);D=D+1|0;}while((D|0)<16);A=A+1|0;}while((A|0)<4);v=v+1|0;}while((v|0)<4096);c[2410674]=1748;gGz(9699632,0,3072);v=c[2427044]|0;c[9681616+(v<<3)>>2]=715288;c[9681620+(v<<3)>>2]=0;c[2427044]=v+1;c[363094]=0;v=c[2387402]|0;y=0;s=0;while(1){A=s+8|0;B=v+(s<<8)|0;c[9699632+(A<<2)>>2]=B;c[9700656+(A<<2)>>2]=B;c[9701680+(A<<2)>>2]=B;B=y+1&65535;if((B&65535)<24){y=B;s=B&65535}else{break}}s=c[2387378]|0;y=0;v=0;while(1){B=v+32|0;A=s+((v<<8)+65536)|0;c[9699632+(B<<2)>>2]=A;c[9701680+(B<<2)>>2]=A;A=y+1&65535;if((A&65535)<32){y=A;v=A&65535}else{J=0;K=0;break}}while(1){v=K+128|0;y=s+((K<<8)+32768)|0;c[9699632+(v<<2)>>2]=y;c[9701680+(v<<2)>>2]=y;y=J+1&65535;if((y&65535)<128){J=y;K=y&65535}else{break}}c[2444172]=574;c[3528598]=1280;c[2410675]=608;c[363094]=-1;s=0;while(1){if((s|0)>=1024){L=0;break}M=9638528+(s<<2)|0;if((c[M>>2]|0)==0){u=67097;break}else{s=s+1|0}}do{if((u|0)==67097){s=gGq(24576)|0;c[M>>2]=s;if((s|0)==0){L=0;break}gGz(s|0,0,24576);L=s}}while(0);c[3529062]=L;c[2438700]=524287;c[3529060]=x;a[7461784]=1;s=9726816;c[s>>2]=0;c[s+4>>2]=0;s=9726800;c[s>>2]=0;c[s+4>>2]=0;c[2429638]=0;c[2437692]=84;c[2431704]=8;c[2431700]=0;c[2431705]=8;c[2431701]=0;c[2431706]=8;c[2431702]=0;biH(c[3530704]|0,524287,6);c[3529052]=-112;c[3529050]=16;s=a[9680]|0;y=s?32e3:0;if(s){if(a[9624]|0){s=y*3|0;v=55930;while(1){if((v|0)>(s|0)){v=v>>1}else{N=1222;O=v;break}}}else{N=2462;O=y}c[2429380]=O;c[3542124]=N;mw(3579545,O);v=gGq(262144)|0;c[2406684]=v;gGz(v|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(3579545,11025)}c[(c[3531464]|0)+44344>>2]=1348;h[745421]=1.0;c[2436794]=1;h[745420]=1.0;c[2436792]=2;v=c[642608+(c[2436]<<2)>>2]|0;s=c[v+128>>2]|0;if((c[v+52>>2]&4|0)==0){c[2113068]=s;x=c[v+132>>2]|0;c[2113070]=x;c[2443814]=s;c[2440436]=x;P=s;Q=x}else{c[2113070]=s;x=c[v+132>>2]|0;c[2113068]=x;c[2440436]=s;c[2443814]=x;P=x;Q=s}s=ag(P<<1,Q)|0;x=gGq(s)|0;c[2112926]=x;if((x|0)!=0){gGz(x|0,0,s|0)}a[9624992]=0;s=c[2414802]|0;gGz(s|0,0,(c[2411862]|0)-s|0);c[363094]=0;c[2410673]=0;a[9642688]=0;a[9642689]=0;a[9642682]=0;a[9642683]=0;c[2410665]=0;a[9642680]=a[9642680]|80;s=c[2425163]|0;do{if((s|0)==0){x=c[3528598]|0;if((x|0)==0){R=0;S=0;break}v=gj[x&4095](-2)|0;x=c[2425163]|0;A=(v&255)<<8;if((x|0)!=0){T=x;U=A;u=67114;break}x=c[3528598]|0;if((x|0)==0){R=0;S=A;break}R=gj[x&4095](-1)|0;S=A}else{T=s;U=(d[s+254|0]|0)<<8;u=67114}}while(0);if((u|0)==67114){R=a[T+255|0]|0;S=U}c[2410662]=R&255|S;c[363094]=-1;mx(0);blH();c[2385184]=0;w=0;i=b;return w|0}}while(0);c[2415094]=0;w=1;i=b;return w|0}function biQ(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c[2113070]=0;c[2113068]=0;a=c[2112926]|0;if((a|0)!=0){gGr(a);c[2112926]=0}blI();if((c[2439478]|0)>0){a=0;do{b=14116216+(a<<2)|0;d=c[b>>2]|0;e=0;while(1){if((e|0)>=1024){break}f=9638528+(e<<2)|0;if((c[f>>2]|0)==(d|0)){g=67145;break}else{e=e+1|0}}if((g|0)==67145){g=0;gGr(d);c[f>>2]=0}c[b>>2]=0;e=14116232+(a<<2)|0;h=c[e>>2]|0;i=0;while(1){if((i|0)>=1024){break}j=9638528+(i<<2)|0;if((c[j>>2]|0)==(h|0)){g=67149;break}else{i=i+1|0}}if((g|0)==67149){g=0;gGr(h);c[j>>2]=0}c[e>>2]=0;c[14116208+(a<<2)>>2]=0;c[14116200+(a<<2)>>2]=0;a=a+1|0;}while((a|0)<(c[2439478]|0))}c[2439478]=0;c[2444172]=0;c[3528598]=0;a=c[3531464]|0;c[a+44344>>2]=0;c[a+44348>>2]=0;if((a|0)!=0){gGr(a);c[3531464]=0}a=c[2406684]|0;if((a|0)!=0){gGr(a);c[2406684]=0}a=c[2415094]|0;j=0;while(1){if((j|0)>=1024){g=67161;break}k=9638528+(j<<2)|0;if((c[k>>2]|0)==(a|0)){break}else{j=j+1|0}}if((g|0)==67161){c[2415094]=0;return 0}gGr(a);c[k>>2]=0;c[2415094]=0;return 0}function biR(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((a[9624992]|0)!=0){a[9624992]=0;b=c[2414802]|0;gGz(b|0,0,(c[2411862]|0)-b|0);c[363094]=0;c[2410673]=0;a[9642688]=0;a[9642689]=0;a[9642682]=0;a[9642683]=0;c[2410665]=0;a[9642680]=a[9642680]|80;b=c[2425163]|0;do{if((b|0)==0){e=c[3528598]|0;if((e|0)==0){f=0;g=0;break}h=gj[e&4095](-2)|0;e=c[2425163]|0;i=(h&255)<<8;if((e|0)!=0){j=e;k=i;l=67167;break}e=c[3528598]|0;if((e|0)==0){f=0;g=i;break}f=gj[e&4095](-1)|0;g=i}else{j=b;k=d[b+254|0]<<8;l=67167}}while(0);if((l|0)==67167){f=a[j+255|0]|0;g=k}c[2410662]=f&255|g;c[363094]=-1;mx(0);blH();c[2385184]=0}gGz(9550944,-1|0,3);g=0;f=-1;k=-1;j=-1;do{f=((a[9634352+g|0]&1)<<g^f&255)&255;k=((a[9632112+g|0]&1)<<g^k&255)&255;j=((a[9630032+g|0]&1)<<g^j&255)&255;g=g+1|0;}while((g|0)<8);a[9550944]=f;a[9550945]=k;a[9550946]=j;if((f&24)==0){j=f|24;a[9550944]=j;m=j}else{m=f}if((m&6)==0){a[9550944]=m|6}if((k&24)==0){m=k|24;a[9550945]=m;n=m}else{n=k}if((n&6)==0){a[9550945]=n|6}c[363094]=0;n=0;k=0;m=0;L86943:while(1){f=k;j=m;do{if((j|0)>=10){break L86943}j=j+1|0;f=(fNF((j*6650|0)-f|0)|0)+f|0;o=c[2112964]|0;}while((o|0)==0);g=a[9688]|0?53:0;gg[c[3542124]&4095](o+(n<<1<<1)|0,g);n=g+n|0;k=f;m=j}if((c[3541228]|0)!=0){fNE(0,1);fNF(0)|0;a[9642682]=0;fNF(0)|0}m=c[2112964]|0;do{if((m|0)!=0){k=a[9688]|0?534:0;if((k|0)==(n|0)){break}gg[c[3542124]&4095](m+(n<<1<<1)|0,k-n|0)}}while(0);c[363094]=-1;if((c[2112968]|0)==0){return 0}biS()|0;return 0}function biS(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;if((a[9547984]|0)!=0){e=c[2387276]|0;f=c[3530180]|0;g=c[2407006]|0;h=0;do{i=ga(b[e+(h<<1)>>1]|0)|0;j=i&255;k=((j&255)>>>2&7|j<<3)&255;j=((i&65535)>>>5<<3&255|(i&65535)>>>7&7)&255;l=((i&65535)>>>10<<3&255|(i&65535)>>>12&7)&255;c[f+(h<<2)>>2]=j<<3&2016|l>>>3|k<<8&63488;c[g+(h<<2)>>2]=j<<8|l|k<<16;h=h+1|0;}while((h|0)<2048)}bpj();h=c[2437682]|0;c[2432776]=c[2437683];c[2433652]=c[2437684];c[2433653]=c[2437686];c[2433654]=c[2437685];g=a[14116146]|0;f=g&255;c[2394840]=f;e=a[14116148]|0;k=e&255;c[2394838]=k;l=d[14116147]|0;c[2394836]=l;if((g&255)<(e&255)){c[2394840]=k;c[2394838]=f;m=k;n=1;o=0;p=f}else{m=f;n=0;o=1;p=k}if(m>>>0<l>>>0){c[2394840]=l;c[2394836]=m;q=m;r=2;s=n}else{q=l;r=n;s=2}if((p|0)<(q|0)){c[2394838]=q;c[2394836]=p;t=s;u=o}else{t=o;u=s}s=ag(c[2113070]|0,c[2113068]|0)|0;if((s|0)>0){o=h<<4&65535;h=c[2112926]|0;p=0;do{b[h+(p<<1)>>1]=o;p=p+1|0;}while((p|0)<(s|0))}bpk(r,0,c[2439906]|0);biI(c[2439870]|0,2);biI(c[2439870]|0,3);bpk(t,0,c[2439906]|0);biI(c[2439870]|0,1);bpk(u,0,c[2439906]|0);biI(c[2439870]|0,0);blK(c[2407006]|0,c[3530180]|0);return 0}function biT(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=i;i=i+112|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;l=e+80|0;m=e+96|0;if((b|0)!=0){c[b>>2]=169733}if((a&96|0)==0){n=a&64}else{gGz(m|0,0,12);b=c[2414802]|0;c[m>>2]=b;c[m+4>>2]=(c[2411862]|0)-b;c[m+12>>2]=162152;b=c[2076592]|0;gj[b&4095](m)|0;m=c[2410674]|0;b=c[2410675]|0;o=a&64;do{if((o|0)==0){c[2410674]=m;c[2410675]=b}else{gGz(k|0,0,12);c[k>>2]=9642648;c[k+4>>2]=56;c[k+12>>2]=163840;p=c[2076592]|0;gj[p&4095](k)|0;gGz(j|0,0,12);c[j>>2]=9707480;c[j+4>>2]=2;c[j+12>>2]=501096;p=c[2076592]|0;gj[p&4095](j)|0;gGz(h|0,0,12);c[h>>2]=9707480;c[h+4>>2]=4;c[h+12>>2]=385184;p=c[2076592]|0;gj[p&4095](h)|0;c[2410674]=m;c[2410675]=b;gGz(g|0,0,12);c[g>>2]=8453216;c[g+4>>2]=4;c[g+12>>2]=107480;p=c[2076592]|0;gj[p&4095](g)|0;gGz(f|0,0,12);c[f>>2]=14168504;c[f+4>>2]=256;c[f+12>>2]=476464;p=c[2076592]|0;gj[p&4095](f)|0;if((a&2|0)==0){break}else{q=0}do{mv(0,q,d[14168504+q|0]|0);q=q+1|0;}while((q|0)<256)}}while(0);blJ(a);n=o}if((n|0)!=0){gGz(l|0,0,12);c[l>>2]=9540736;c[l+4>>2]=4;c[l+12>>2]=587384;n=c[2076592]|0;gj[n&4095](l)|0}if((a&2|0)==0){i=e;return 0}c[363094]=0;a=c[2387378]|0;l=((d[c[2443942]|0]|0)<<13&253952)+65536|0;n=0;o=0;while(1){q=o+32|0;f=a+(l+(o<<8))|0;c[9699632+(q<<2)>>2]=f;c[9701680+(q<<2)>>2]=f;f=n+1&65535;if((f&65535)<32){n=f;o=f&65535}else{break}}c[363094]=-1;i=e;return 0}function biU(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>5){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4377228+(b*112|0)>>2];c[a+104>>2]=c[4377232+(b*112|0)>>2];c[a+108>>2]=c[4377236+(b*112|0)>>2];d=0;return d|0}function biV(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<6&(d|0)==0)){e=1;return e|0}c[a>>2]=4377128+(b*112|0);e=0;return e|0}function biW(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>5){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4376556+(b*112|0)>>2];c[a+104>>2]=c[4376560+(b*112|0)>>2];c[a+108>>2]=c[4376564+(b*112|0)>>2];d=0;return d|0}function biX(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<6&(d|0)==0)){e=1;return e|0}c[a>>2]=4376456+(b*112|0);e=0;return e|0}function biY(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>54){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4937112+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function biZ(b){b=b|0;var d=0,e=0,f=0,g=0,h=0;a[c[2443942]|0]=b&255;d=c[2387378]|0;e=(b<<13&253952)+65536|0;b=0;f=0;while(1){g=f+32|0;h=d+(e+(f<<8))|0;c[9699632+(g<<2)>>2]=h;c[9701680+(g<<2)>>2]=h;h=b+1&65535;if((h&65535)<32){b=h;f=h&65535}else{break}}return}function bi_(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;c[f>>2]=(c[e>>2]|0)>>>7&1;f=c[e>>2]|0;c[d>>2]=c[d>>2]|b<<13|f<<6&1024|f<<8&768|f<<9&6144;c[e>>2]=((c[e>>2]|0)>>>5&3)+(c[9734608+(a<<2)>>2]|0);return}function bi$(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;e=(c[b>>2]|0)>>>2&24|32;do{if((e|0)>(c[2394836]|0)){if((e|0)<=(c[2394838]|0)){c[d>>2]=1;break}if((e|0)>(c[2394840]|0)){c[d>>2]=3;break}else{c[d>>2]=2;break}}else{c[d>>2]=0}}while(0);c[a>>2]=c[a>>2]&4095;c[b>>2]=(c[b>>2]&31)+(c[2432776]|0);return}function bi0(a){a=a|0;fNE(1,(a|0)!=0?3:0);return}function bi1(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;h=0;while(1){if((h|0)>=1024){i=0;break}j=9638528+(h<<2)|0;if((c[j>>2]|0)==0){k=67274;break}else{h=h+1|0}}do{if((k|0)==67274){h=gGq(2048)|0;c[j>>2]=h;if((h|0)==0){i=0;break}gGz(h|0,0,2048);i=h}}while(0);c[14116304+(b<<2)>>2]=i;i=0;while(1){if((i|0)>=1024){l=0;break}m=9638528+(i<<2)|0;if((c[m>>2]|0)==0){k=67279;break}else{i=i+1|0}}do{if((k|0)==67279){i=gGq(524288)|0;c[m>>2]=i;if((i|0)==0){l=0;break}gGz(i|0,0,524288);l=i}}while(0);c[9754816+(b<<2)>>2]=l;c[9750784+(b<<2)>>2]=g;c[9773272+(b<<2)>>2]=4;c[14116320+(b<<2)>>2]=d;c[9757920+(b<<2)>>2]=e;c[14108576+(b<<2)>>2]=f;g=f+1|0;if((g|0)>0){n=0}else{a[7461800]=1;o=14108556+(b<<3)|0;c[o>>2]=0;p=14108552+(b<<3)|0;c[p>>2]=0;q=9730744+(b<<2)|0;c[q>>2]=0;return}do{f=a[d+n|0]|0;l=n<<1;a[e+l|0]=(f&255)>>>4;a[e+(l|1)|0]=f&15;n=n+1|0;}while((n|0)<(g|0));a[7461800]=1;o=14108556+(b<<3)|0;c[o>>2]=0;p=14108552+(b<<3)|0;c[p>>2]=0;q=9730744+(b<<2)|0;c[q>>2]=0;return}function bi2(a,e){a=a|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+24|0;g=f|0;h=f+8|0;j=f+16|0;k=a&1023;l=a<<4&496;a=c[14116304+(e<<2)>>2]|0;c[g>>2]=d[a+k|0]|0;c[h>>2]=d[a+(k|1024)|0]|0;c[j>>2]=0;gG[c[9750784+(e<<2)>>2]&255](g,h,j);a=c[9757920+(e<<2)>>2]|0;m=c[g>>2]<<8;c[h>>2]=c[h>>2]<<c[9773272+(e<<2)>>2];g=c[j>>2]|0;j=(g&1|0)==0?0:15;n=(g&2|0)==0?0:15;g=c[9754816+(e<<2)>>2]|0;o=c[9730744+(e<<2)>>2]|0;e=0;p=k>>>5<<4;while(1){k=p<<9|l;q=(e^n)<<4;r=0;do{s=d[a+((r^j|q)+m)|0]|0;t=c[h>>2]|s;if((s|0)==(o|0)){b[g+(r+k<<1)>>1]=(t|32768)&65535}else{b[g+(r+k<<1)>>1]=t&65535}r=r+1|0;}while((r|0)<16);r=e+1|0;if((r|0)<16){e=r;p=p+1|0}else{break}}i=f;return}function bi3(e){e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;f=(d[14108594+(e<<4)|0]<<8|d[14108595+(e<<4)|0])<<16>>16;g=(d[14108596+(e<<4)|0]<<8|d[14108597+(e<<4)|0])<<16>>16;h=(d[14108600+(e<<4)|0]<<8|d[14108601+(e<<4)|0])<<16>>16;i=(d[14108602+(e<<4)|0]<<8|d[14108603+(e<<4)|0])<<16>>16;j=(c[14108556+(e<<3)>>2]|0)+16|0;k=(c[14108552+(e<<3)>>2]|0)+89|0;l=f<<5;m=h<<5;n=g<<5;o=i<<5;p=c[9754816+(e<<2)>>2]|0;q=c[2113070]|0;if((q|0)<=0){return}r=(d[14108599+(e<<4)|0]|d[14108598+(e<<4)|0]<<8)<<16>>16;s=(d[14108593+(e<<4)|0]|d[14108592+(e<<4)|0]<<8)<<16>>16;t=ag(i,j)|0;i=ag(j,g)|0;g=ag(k,h)|0;h=(s<<8)-((ag(k,f)|0)+i)|0;i=(r<<8)-(g+t)<<5;t=h<<5;h=c[2112926]|0;g=(c[9730744+(e<<2)>>2]|0)!=-1;r=c[2113068]|0;if((a[14108544+e|0]|0)==0){u=0;v=h;w=i;x=t}else{e=0;f=h;h=i;i=t;while(1){t=(r|0)>0;do{if(g){if(t){y=i;z=h;A=0;B=f}else{C=f;break}while(1){k=b[p+((z>>>16<<9&261632|y>>>16&511)<<1)>>1]|0;if(k<<16>>16>-1){b[B>>1]=k}k=A+1|0;s=B+2|0;if((k|0)<(r|0)){y=y+l|0;z=z+m|0;A=k;B=s}else{C=s;break}}}else{if(t){D=i;E=h;F=f;G=0}else{C=f;break}while(1){b[F>>1]=b[p+((E>>>16<<9&261632|D>>>16&511)<<1)>>1]&32767;s=G+1|0;k=F+2|0;if((s|0)<(r|0)){D=D+l|0;E=E+m|0;F=k;G=s}else{C=k;break}}}}while(0);t=e+1|0;if((t|0)<(q|0)){e=t;f=C;h=h+o|0;i=i+n|0}else{break}}return}while(1){i=(r|0)>0;do{if(g){if(i){H=x;I=w;J=v;K=0}else{L=v;break}while(1){do{if((H|I)>>>0<33554432){h=b[p+((I>>>16<<9&261632|H>>>16&511)<<1)>>1]|0;if(h<<16>>16<=-1){break}b[J>>1]=h}}while(0);h=K+1|0;C=J+2|0;if((h|0)<(r|0)){H=H+l|0;I=I+m|0;J=C;K=h}else{L=C;break}}}else{if(i){M=x;N=w;O=v;P=0}else{L=v;break}while(1){C=N>>>16<<9|M>>>16;if(C>>>0<=262143){b[O>>1]=b[p+(C<<1)>>1]&32767}C=P+1|0;h=O+2|0;if((C|0)<(r|0)){M=M+l|0;N=N+m|0;O=h;P=C}else{L=h;break}}}}while(0);i=u+1|0;if((i|0)<(q|0)){u=i;v=L;w=w+o|0;x=x+n|0}else{break}}return}function bi4(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0;if((b|0)==1081344){c[3541230]=d&2;a[9718928]=d&1;return}else if((b|0)==1081345){e=d&255;c[2415256]=e&4;f=e>>>4&1;c[3528406]=f^1;if((f|0)==0){c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2]}Tr(e>>>3&1);return}else if((b|0)==1089537){return}else if((b|0)==1081421){a[c[3528362]|0]=d;return}else if((b|0)==1081422|(b|0)==1081423){a[9706117]=1;return}else if((b|0)==1636865){c[2432938]=d&4;return}else{e=b-1622016|0;if(e>>>0>=49152){if((b&16773120|0)==1048576){a[(c[3529044]|0)+(b&4095^1)|0]=d;return}if((b&16777208|0)==1081376){a[14108480+(b&7^1)|0]=d;return}if((b&16777185|0)!=1081441){return}f=b>>>1&15;g=d&255;h=g&63;a[14116144+f|0]=h&255;if((f|0)==9){c[2437682]=g<<5&96;c[2437683]=g>>>2<<5&96;c[2437684]=h>>>4<<5;return}else if((f|0)==10){c[2437685]=g<<4&112;c[2437686]=h>>>3<<4;return}else{return}}if((b&1|0)==0){return}b=e>>>1;if(e>>>0>49151){return}a[(c[3529062]|0)+b|0]=d;if(e>>>0>32767){c[2429638]=1}if((b&6144)>>>0<=6143){return}if((b|0)==7808){c[2432672]=(d&255)>>>1&3;return}else if((b|0)==7424){c[3541228]=d&4;return}else if((b|0)==7680|(b|0)==15872){a[9730680]=d;return}else if((b|0)==7296){a[9729904]=d;return}else if((b|0)==7936){a[9720738]=d&15;a[9720739]=(d&255)>>>4;return}else if((b|0)==7552){a[9720736]=d&15;a[9720737]=(d&255)>>>4;return}else{return}}}function bi5(d,e){d=d|0;e=e|0;var f=0;if((d&16773120|0)==1048576){b[(c[3529044]|0)+(d&4094)>>1]=e;return}if((d&16777208|0)!=1081376){return}f=d&6;a[14108480+f|0]=e&255;a[14108480+(f|1)|0]=(e&65535)>>>8&255;return}function bi6(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=i;i=i+24|0;h=g|0;j=g+8|0;k=g+16|0;switch(f|0){case 1081428:case 1081429:{l=a[c[2443728]|0]|0;i=g;return l|0};case 1089536:case 1089537:{l=(e[4775468]|0)>>>((f<<3&8^8)>>>0)&255;i=g;return l|0};case 1089540:{m=c[2430482]|0;if((m|0)>0){c[2430482]=m-1;l=-65;i=g;return l|0}else{l=(e[4775470]|0)>>>8&255;i=g;return l|0}break};case 1089541:{c[2430482]=(c[2430482]|0)-1;m=b[4775470]&191;do{if((c[2406632]|0)==0){n=c[2443744]|0;if((n|0)<=0){o=64;break}c[2443744]=n-1;o=0}else{o=(c[2432962]|0)>>>((c[(c[2420380]|0)+4>>2]|0)>>>0)<<6&64}}while(0);l=(o|m)&255;i=g;return l|0};case 1089538:case 1089539:{l=(e[4775469]|0)>>>((f<<3&8^8)>>>0)&255;i=g;return l|0};case 1089548:case 1089549:{if((a[9718928]|0)==0){l=0;i=g;return l|0}l=a[(c[3529048]|0)+((d[14108486]<<17|f&1|d[14108487]<<9|d[14108484]<<1)&(a[7201808]|0?4194303:0))|0]|0;i=g;return l|0};default:{if((f&16773120|0)==1048576){l=a[(c[3529044]|0)+(f&4095^1)|0]|0;i=g;return l|0}m=f-1622016|0;if(m>>>0>=49152){l=0;i=g;return l|0}f=m>>>1;if((c[3541230]|0)==0){l=a[(c[3529062]|0)+f|0]|0;i=g;return l|0}c[h>>2]=0;o=m>>>6&255;c[j>>2]=o;m=d[9730680]|0;c[k>>2]=m;n=m>>>2&3;if((c[2429638]|0)==0){gB[c[2437692]&127](0,((a[9718936+n|0]|a[9720736+n|0])&255)>>>2,j,k,h,h);p=c[j>>2]|0}else{h=m<<8|o;c[j>>2]=h;p=h}l=a[(c[3529060]|0)+((p<<5|f&31)&c[2438700])|0]|0;i=g;return l|0}}return 0}function bi7(a){a=a|0;return 0}function bi8(b,e){b=b|0;e=e|0;var f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=b&65535;switch(f|0){case 59392:case 60416:{c[2113304]=e&255;return};case 61440:{a[c[2443728]|0]=e;return};case 59393:case 60417:{g=c[2113304]|0;a[14168504+g|0]=e;mv(0,g,e&255);return};case 63488:{g=e&7;i=c[2443936]|0;a[i]=g;j=c[2386e3]|0;k=c[9757320+(c[1836236]<<2)>>2]|0;l=((g&255)<<14)-32768|0;g=128;m=128;while(1){c[k+76+(m<<2)>>2]=j+(l+(m<<8));n=g+1&65535;if((n&65535)>191){break}else{g=n;m=n&65535}}m=(d[i]<<14)-32768|0;i=128;g=128;while(1){l=j+(m+(g<<8))|0;c[k+76+(g+512<<2)>>2]=l;c[k+76+(g+768<<2)>>2]=l;l=i+1&65535;if((l&65535)>191){break}else{i=l;g=l&65535}}return};default:{if((b+8192&65535)>=560){return}b=f&1023;c[2420384]=9675200;do{if((c[2419366]&4|0)==0){o=0;p=67429}else{g=(a[9678027]&1)!=0;if(!(g&b>>>0<256)){o=g;p=67429;break}g=(f&31)-12|0;if(g>>>0>=3){break}a[9677440+((b>>>5)*3|0)+g|0]=e;return}}while(0);L87264:do{if((p|0)==67429){switch(b|0){case 532:{f=e&255;if(o){g=0;while(1){i=1<<g;do{if((i&f|0)!=0){k=g<<5;a[9677468+(k|12)|0]=a[9677440+(g*3|0)|0]|0;a[9677468+(k|13)|0]=a[9677441+(g*3|0)|0]|0;a[9677468+(k|14)|0]=a[9677442+(g*3|0)|0]|0;if((a[9678027]|0)<0){break}a[9678024]=(d[9678024]|i)&255}}while(0);g=g+1|0;if((g|0)>=8){break L87264}}}if(!((f&1|0)==0|(a[9678027]|0)<0)){a[9678024]=a[9678024]|1}if(!((f&2|0)==0|(a[9678027]|0)<0)){a[9678024]=a[9678024]|2}if(!((f&4|0)==0|(a[9678027]|0)<0)){a[9678024]=a[9678024]|4}if(!((f&8|0)==0|(a[9678027]|0)<0)){a[9678024]=a[9678024]|8}if(!((f&16|0)==0|(a[9678027]|0)<0)){a[9678024]=a[9678024]|16}if(!((f&32|0)==0|(a[9678027]|0)<0)){a[9678024]=a[9678024]|32}if(!((f&64|0)==0|(a[9678027]|0)<0)){a[9678024]=a[9678024]|64}if((f&128|0)==0|(a[9678027]|0)<0){break L87264}a[9678024]=a[9678024]|-128;break L87264;break};case 558:{g=e<<24>>24==-128;if(g){q=c[2419507]|0}else{q=(c[2419512]|0)+((e&255)<<17)|0}c[2419511]=q;c[2419510]=g?16384:131072;c[2419509]=0;break L87264;break};case 319:{g=(e-17&255)<15?(e&255)-17|0:7;i=c[(c[2418800]|0)+4>>2]|0;if((i|0)==0){break L87264}gE[i&1](+h[9677256+(g<<3)>>3],+h[9677256+(14-g<<3)>>3]);break L87264;break};case 557:{if((a[9678026]|0)==-128){a[(c[2419511]|0)+(c[2419509]|0)|0]=e}g=(c[2419509]|0)+1|0;c[2419509]=g;if((g|0)!=(c[2419510]|0)){break L87264}c[2419509]=0;break L87264;break};case 533:{g=e&255;if(!((g&1|0)==0|(a[9678027]|0)<0)){a[9678024]=a[9678024]&-2}if(!((g&2|0)==0|(a[9678027]|0)<0)){a[9678024]=a[9678024]&-3}if(!((g&4|0)==0|(a[9678027]|0)<0)){a[9678024]=a[9678024]&-5}if(!((g&8|0)==0|(a[9678027]|0)<0)){a[9678024]=a[9678024]&-9}if(!((g&16|0)==0|(a[9678027]|0)<0)){a[9678024]=a[9678024]&-17}if(!((g&32|0)==0|(a[9678027]|0)<0)){a[9678024]=a[9678024]&-33}if(!((g&64|0)==0|(a[9678027]|0)<0)){a[9678024]=a[9678024]&-65}if((g&128|0)==0|(a[9678027]|0)<0){break L87264}a[9678024]=a[9678024]&127;break L87264;break};default:{break L87264}}}}while(0);a[9677468+b|0]=e;return}}}function bi9(b){b=b|0;var d=0,e=0,f=0;d=b&65535;switch(d|0){case 59392:case 59393:case 60416:case 60417:{e=c[(c[3531464]|0)+4240>>2]&255;return e|0};case 61442:{a[9706117]=0;e=a[c[3528362]|0]|0;return e|0};default:{if((b+8192&65535)>=560){e=0;return e|0}b=d&1023;c[2420384]=9675200;if((b|0)!=557){e=a[9677468+b|0]|0;return e|0}if((a[9678027]&16)==0){e=0;return e|0}b=c[2419509]|0;d=a[(c[2419511]|0)+b|0]|0;f=b+1|0;c[2419509]=f;if((f|0)!=(c[2419510]|0)){e=d;return e|0}c[2419509]=0;e=d;return e|0}}return 0}function bja(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6983948+(b*112|0)>>2];c[a+104>>2]=c[6983952+(b*112|0)>>2];c[a+108>>2]=c[6983956+(b*112|0)>>2];d=0;return d|0}function bjb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=6983848+(b*112|0);e=0;return e|0}function bjc(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>37){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5974016+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function bjd(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0;e=i;i=i+960|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;c[2415092]=0;c[2388190]=0;c[2386e3]=1048576;c[3530938]=1179648;c[2439904]=3276800;c[3530702]=7471104;c[2439868]=11665408;c[2386692]=20054016;c[2407004]=22151168;c[3530178]=22159360;c[2414800]=22167552;c[2387274]=22167552;c[2388308]=22171648;c[2386152]=22192128;c[3528362]=22200320;c[2443728]=22200321;c[2443936]=22200322;c[2411860]=22200323;x=0;while(1){if((x|0)>=1024){break}y=9638528+(x<<2)|0;if((c[y>>2]|0)==0){z=67525;break}else{x=x+1|0}}do{if((z|0)==67525){x=gGq(22200323)|0;c[y>>2]=x;if((x|0)==0){break}c[2415092]=x;gGz(x|0,0,22200323);c[2388190]=x;c[2386e3]=x+1048576;c[3530938]=x+1179648;c[2439904]=x+3276800;c[3530702]=x+7471104;c[2439868]=x+11665408;c[2386692]=x+20054016;c[2407004]=x+22151168;c[3530178]=x+22159360;A=x+22167552|0;c[2414800]=A;c[2387274]=A;c[2388308]=x+22171648;c[2386152]=x+22192128;c[3528362]=x+22200320;c[2443728]=x+22200321;c[2443936]=x+22200322;A=x+22200323|0;c[2411860]=A;c[2414410]=A;if((R6(x+1|0,0,2)|0)!=0){B=1;i=e;return B|0}if((R6(c[2388190]|0,1,2)|0)!=0){B=1;i=e;return B|0}if((R6((c[2388190]|0)+524289|0,2,2)|0)!=0){B=1;i=e;return B|0}if((R6((c[2388190]|0)+524288|0,3,2)|0)!=0){B=1;i=e;return B|0}x=c[2386e3]|0;if((c[3542200]|0)==0){B=1;i=e;return B|0}A=v+108|0;c[A>>2]=0;C=v+100|0;c[C>>2]=0;D=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[D&16383](v,4)|0;do{if((c[A>>2]|0)!=0){D=c[C>>2]|0;c[w>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](w,4,0)|0;if((D|0)<1){B=1;i=e;return B|0}if((gzL(x,0,4)|0)==0){break}else{B=1}i=e;return B|0}}while(0);x=c[3530938]|0;if((c[3542200]|0)==0){B=1;i=e;return B|0}C=t+108|0;c[C>>2]=0;A=t+100|0;c[A>>2]=0;D=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[D&16383](t,5)|0;do{if((c[C>>2]|0)!=0){D=c[A>>2]|0;c[u>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](u,5,0)|0;if((D|0)<1){B=1;i=e;return B|0}if((gzL(x,0,5)|0)==0){break}else{B=1}i=e;return B|0}}while(0);x=(c[3530938]|0)+1048576|0;if((c[3542200]|0)==0){B=1;i=e;return B|0}A=r+108|0;c[A>>2]=0;C=r+100|0;c[C>>2]=0;D=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[D&16383](r,6)|0;do{if((c[A>>2]|0)!=0){D=c[C>>2]|0;c[s>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](s,6,0)|0;if((D|0)<1){B=1;i=e;return B|0}if((gzL(x,0,6)|0)==0){break}else{B=1}i=e;return B|0}}while(0);x=c[3530702]|0;if((c[3542200]|0)==0){B=1;i=e;return B|0}C=p+108|0;c[C>>2]=0;A=p+100|0;c[A>>2]=0;D=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[D&16383](p,7)|0;do{if((c[C>>2]|0)!=0){D=c[A>>2]|0;c[q>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](q,7,0)|0;if((D|0)<1){B=1;i=e;return B|0}if((gzL(x,0,7)|0)==0){break}else{B=1}i=e;return B|0}}while(0);x=(c[3530702]|0)+1048576|0;if((c[3542200]|0)==0){B=1;i=e;return B|0}A=n+108|0;c[A>>2]=0;C=n+100|0;c[C>>2]=0;D=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[D&16383](n,8)|0;do{if((c[A>>2]|0)!=0){D=c[C>>2]|0;c[o>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](o,8,0)|0;if((D|0)<1){B=1;i=e;return B|0}if((gzL(x,0,8)|0)==0){break}else{B=1}i=e;return B|0}}while(0);x=(c[3530702]|0)+2097152|0;if((c[3542200]|0)==0){B=1;i=e;return B|0}C=l+108|0;c[C>>2]=0;A=l+100|0;c[A>>2]=0;D=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[D&16383](l,9)|0;do{if((c[C>>2]|0)!=0){D=c[A>>2]|0;c[m>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](m,9,0)|0;if((D|0)<1){B=1;i=e;return B|0}if((gzL(x,0,9)|0)==0){break}else{B=1}i=e;return B|0}}while(0);x=(c[3530702]|0)+3145728|0;if((c[3542200]|0)==0){B=1;i=e;return B|0}A=j+108|0;c[A>>2]=0;C=j+100|0;c[C>>2]=0;D=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[D&16383](j,10)|0;do{if((c[A>>2]|0)!=0){D=c[C>>2]|0;c[k>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](k,10,0)|0;if((D|0)<1){B=1;i=e;return B|0}if((gzL(x,0,10)|0)==0){break}else{B=1}i=e;return B|0}}while(0);x=c[2386692]|0;if((c[3542200]|0)==0){B=1;i=e;return B|0}C=f+108|0;c[C>>2]=0;A=f+100|0;c[A>>2]=0;D=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[D&16383](f,11)|0;do{if((c[C>>2]|0)!=0){D=c[A>>2]|0;c[g>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](g,11,0)|0;if((D|0)<1){B=1;i=e;return B|0}if((gzL(x,0,11)|0)==0){break}else{B=1}i=e;return B|0}}while(0);x=c[3530938]|0;blG(x,1048576);A=c[3530702]|0;C=A;blG(C,2097152);blG(C,2097152);C=c[2439904]|0;D=0;do{E=D<<6;gGz(C+E|0,0,64);F=D<<8;G=0;do{H=1<<3-G;I=(c[611632+(G<<2)>>2]|0)+F|0;J=0;do{K=I+(c[1183816+(J<<2)>>2]|0)|0;L=(J<<3)+E|0;M=0;do{N=K+(c[614800+(M<<2)>>2]|0)|0;if(((d[x+((N|0)/8|0)|0]|0)&128>>>((N&7)>>>0)|0)!=0){N=C+(L+M)|0;a[N]=(d[N]|0|H)&255}M=M+1|0;}while((M|0)<8);J=J+1|0;}while((J|0)<8);G=G+1|0;}while((G|0)<4);D=D+1|0;}while((D|0)<65536);D=c[2439868]|0;C=0;do{x=a[A+(C^1)|0]|0;G=C<<1;a[D+G|0]=(x&255)>>>4;a[D+(G|1)|0]=x&15;C=C+1|0;}while((C|0)<4194304);fxU(0,425984);if((c[2394]|0)==0){O=c[2112932]|0}else{c[2394]=0;C=c[3532596]|0;c[2112932]=C;D=c[3532592]|0;if((D|0)!=0){gGC(9104152,D|0,280)|0}c[2113054]=c[2113060];O=C}C=c[2388190]|0;D=O|0;A=0;while(1){x=C+A|0;c[D>>2]=x;c[D+131072>>2]=x;x=A+1024|0;if(x>>>0>1048575){break}else{D=D+4|0;A=x}}A=c[2388308]|0;c[O+4112>>2]=A;c[O+69648>>2]=A;c[O+135184>>2]=A;D=A+1024|0;c[O+4116>>2]=D;c[O+69652>>2]=D;c[O+135188>>2]=D;D=A+2048|0;c[O+4120>>2]=D;c[O+69656>>2]=D;c[O+135192>>2]=D;D=A+3072|0;c[O+4124>>2]=D;c[O+69660>>2]=D;c[O+135196>>2]=D;D=c[2387274]|0;c[O+4160>>2]=D;c[O+69696>>2]=D;c[O+135232>>2]=D;C=D+1024|0;c[O+4164>>2]=C;c[O+69700>>2]=C;c[O+135236>>2]=C;C=D+2048|0;c[O+4168>>2]=C;c[O+69704>>2]=C;c[O+135240>>2]=C;C=D+3072|0;c[O+4172>>2]=C;c[O+69708>>2]=C;c[O+135244>>2]=C;C=A+4096|0;c[O+4352>>2]=C;c[O+69888>>2]=C;c[O+135424>>2]=C;C=A+5120|0;c[O+4356>>2]=C;c[O+69892>>2]=C;c[O+135428>>2]=C;C=A+6144|0;c[O+4360>>2]=C;c[O+69896>>2]=C;c[O+135432>>2]=C;C=A+7168|0;c[O+4364>>2]=C;c[O+69900>>2]=C;c[O+135436>>2]=C;C=A+8192|0;c[O+4368>>2]=C;c[O+69904>>2]=C;c[O+135440>>2]=C;C=A+9216|0;c[O+4372>>2]=C;c[O+69908>>2]=C;c[O+135444>>2]=C;C=A+10240|0;c[O+4376>>2]=C;c[O+69912>>2]=C;c[O+135448>>2]=C;C=A+11264|0;c[O+4380>>2]=C;c[O+69916>>2]=C;c[O+135452>>2]=C;C=A+12288|0;c[O+4384>>2]=C;c[O+69920>>2]=C;c[O+135456>>2]=C;C=A+13312|0;c[O+4388>>2]=C;c[O+69924>>2]=C;c[O+135460>>2]=C;C=A+14336|0;c[O+4392>>2]=C;c[O+69928>>2]=C;c[O+135464>>2]=C;C=A+15360|0;c[O+4396>>2]=C;c[O+69932>>2]=C;c[O+135468>>2]=C;C=A+16384|0;c[O+4400>>2]=C;c[O+69936>>2]=C;c[O+135472>>2]=C;C=A+17408|0;c[O+4404>>2]=C;c[O+69940>>2]=C;c[O+135476>>2]=C;C=A+18432|0;c[O+4408>>2]=C;c[O+69944>>2]=C;c[O+135480>>2]=C;C=A+19456|0;c[O+4412>>2]=C;c[O+69948>>2]=C;c[O+135484>>2]=C;c[O+196648>>2]=2490;c[O+196728>>2]=734;c[O+196608>>2]=3400;c[O+196688>>2]=2514;C=c[3532592]|0;if((C|0)!=0){gGC(C|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);C=c[2439330]|0;A=(C|0)==0;if(!A){D=C;gGC(9706056,D|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];D=c[3528484]|0;c[2076596]=D;x=c[2417276]|0;c[3541536]=x;c[1836236]=0;G=c[2386e3]|0;E=0;F=0;while(1){c[C+76+(F<<2)>>2]=G+(F<<8);J=E+1&65535;if((J&65535)>127){P=0;Q=0;break}else{E=J;F=J&65535}}while(1){F=G+(Q<<8)|0;c[C+76+(Q+512<<2)>>2]=F;c[C+76+(Q+768<<2)>>2]=F;F=P+1&65535;if((F&65535)>127){R=128;S=128;break}else{P=F;Q=F&65535}}while(1){c[C+76+(S<<2)>>2]=G+(S<<8);F=R+1&65535;if((F&65535)>191){T=128;U=128;break}else{R=F;S=F&65535}}while(1){F=G+(U<<8)|0;c[C+76+(U+512<<2)>>2]=F;c[C+76+(U+768<<2)>>2]=F;F=T+1&65535;if((F&65535)>191){break}else{T=F;U=F&65535}}G=c[2386152]|0;F=192;E=192;while(1){c[C+76+(E<<2)>>2]=G+((E<<8)-49152);J=F+1&65535;if((J&65535)>223){V=192;W=192;break}else{F=J;E=J&65535}}while(1){c[C+76+(W+256<<2)>>2]=G+((W<<8)-49152);E=V+1&65535;if((E&65535)>223){Y=192;Z=192;break}else{V=E;W=E&65535}}while(1){E=G+((Z<<8)-49152)|0;c[C+76+(Z+512<<2)>>2]=E;c[C+76+(Z+768<<2)>>2]=E;E=Y+1&65535;if((E&65535)>223){break}else{Y=E;Z=E&65535}}c[C+4184>>2]=140;c[C+4180>>2]=2952;if(!A){G=C;gGC(G|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=D;c[2417276]=x;c[1836236]=-1;Tq(1327624);G=c[3530938]|0;E=0;while(1){if((E|0)>=1024){_=0;break}$=9638528+(E<<2)|0;if((c[$>>2]|0)==0){z=67600;break}else{E=E+1|0}}do{if((z|0)==67600){E=gGq(24576)|0;c[$>>2]=E;if((E|0)==0){_=0;break}gGz(E|0,0,24576);_=E}}while(0);c[3529062]=_;c[2438700]=2097151;c[3529060]=G;a[7461784]=1;E=9726816;c[E>>2]=0;c[E+4>>2]=0;E=9726800;c[E>>2]=0;c[E+4>>2]=0;c[2429638]=0;c[2437692]=12;c[2431704]=8;c[2431700]=0;c[2431705]=8;c[2431701]=0;c[2431706]=8;c[2431702]=0;bhh(c[3530702]|0,66,1);c[3529042]=-510;c[3529040]=158;E=a[9680]|0;x=E?32e3:0;if(E){if(a[9624]|0){E=x*3|0;D=62500;while(1){if((D|0)>(E|0)){D=D>>1}else{aa=1222;ab=D;break}}}else{aa=2462;ab=x}c[2429380]=ab;c[3542124]=aa;mw(4e6,ab);D=gGq(262144)|0;c[2406684]=D;gGz(D|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(4e6,11025)}h[745421]=.2;c[2436794]=1;h[745420]=.2;c[2436792]=2;D=c[2386692]|0;c[2420384]=9675200;c[2418800]=9539328;c[2419515]=48e3;c[2443786]=~~(48.0e3/(a[9680]|0?32.0e3:0.0)*32768.0);h[1209672]=1.0;h[1209673]=1.0;h[1209674]=1.0;h[1209675]=1.0;h[1209676]=1.0;h[1209677]=1.0;h[1209678]=1.0;h[1209679]=1.0;c[2419366]=0;E=0;do{h[9675208+(E<<3)>>3]=+X(+10.0,+(+(E|0)*-36.0*.015625/20.0))*.25;E=E+1|0;}while((E|0)<256);h[1209657]=0.0;h[1209658]=.2672612419124244;h[1209659]=.37796447300922725;h[1209660]=.4629100498862757;h[1209661]=.5345224838248488;h[1209662]=.5976143046671969;h[1209663]=.6546536707079771;h[1209664]=.7071067811865476;h[1209665]=.7559289460184545;h[1209666]=.8017837257372732;h[1209667]=.8451542547285167;h[1209668]=.8864052604279183;h[1209669]=.9258200997725514;h[1209670]=.9636241116594315;h[1209671]=1.0;gGz(9677468,0,560);gGz(9677440,0,24);c[2419366]=c[2419366]|4;E=gGq(34688)|0;c[2419507]=E;c[2419508]=0;c[2419509]=0;gGz(E|0,0,34688);c[2419512]=D;c[2419513]=2097152;c[2419514]=-1;E=0;while(1){if((E|0)>=32){break}ac=1<<E;if(ac>>>0<2097152){E=E+1|0}else{z=67613;break}}if((z|0)==67613){c[2419514]=ac-1}h[1209758]=1.0;h[1209759]=1.0;c[2419520]=3;c[2419521]=3;if((c[2388478]|0)==0){c[2388478]=gGq(a[9688]|0?2136:0)|0}if((c[2388476]|0)==0){c[2388476]=gGq(a[9688]|0?2136:0)|0}h[1209758]=1.0;c[2419520]=1;c[2420384]=9675200;h[1209759]=1.0;c[2419521]=2;E=c[642608+(c[2436]<<2)>>2]|0;D=c[E+128>>2]|0;if((c[E+52>>2]&4|0)==0){c[2113068]=D;x=c[E+132>>2]|0;c[2113070]=x;c[2443814]=D;c[2440436]=x;ad=D;ae=x}else{c[2113070]=D;x=c[E+132>>2]|0;c[2113068]=x;c[2440436]=D;c[2443814]=x;ad=x;ae=D}D=ag(ad<<1,ae)|0;x=gGq(D)|0;c[2112926]=x;if((x|0)!=0){gGz(x|0,0,D|0)}a[9624984]=0;D=c[2414800]|0;gGz(D|0,0,(c[2411860]|0)-D|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];D=c[3532592]|0;if((D|0)!=0){gGC(9104152,D|0,280)|0}c[2113054]=c[2113060]}RI();D=c[2394]|0;x=c[14130368+(D<<2)>>2]|0;if((x|0)!=0){gGC(x|0,9104152,280)|0}c[8452240+(D<<2)>>2]=c[2113054];c[2394]=-1;D=c[2439330]|0;x=(D|0)==0;if(!x){E=D;gGC(9706056,E|0,76)|0}E=c[2438118]|0;c[2433530]=E;G=c[3528484]|0;c[2076596]=G;C=c[2417276]|0;c[3541536]=C;c[1836236]=0;gGz(9706056,0,76);if(!x){x=D;gGC(x|0,9706056,76)|0}c[2438118]=E;c[3528484]=G;c[2417276]=C;c[1836236]=-1;mx(0);c[2420384]=9675200;C=a[9678026]|0;G=C<<24>>24==-128;if(G){af=c[2419507]|0}else{af=(c[2419512]|0)+((C&255)<<17)|0}c[2419511]=af;c[2419510]=G?16384:131072;blH();c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];c[2430482]=a[1040128]|0?0:10;c[2432938]=0;B=0;i=e;return B|0}}while(0);c[2415092]=0;B=1;i=e;return B|0}function bje(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;i=i+128|0;d=b|0;c[2113070]=0;c[2113068]=0;e=c[2112926]|0;if((e|0)!=0){gGr(e);c[2112926]=0}blI();if((c[2392]|0)>=0){e=0;do{f=14130368+(e<<2)|0;g=c[f>>2]|0;if((g|0)!=0){gGr(g);c[f>>2]=0}f=14130384+(e<<2)|0;g=c[f>>2]|0;if((g|0)!=0){gGr(g);c[f>>2]=0}e=e+1|0;}while((e|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;fwZ();e=c[3531464]|0;c[e+44344>>2]=0;c[e+44348>>2]=0;if((e|0)!=0){gGr(e);c[3531464]=0}e=c[2406684]|0;if((e|0)!=0){gGr(e);c[2406684]=0}e=c[2388478]|0;if((e|0)!=0){gGr(e);c[2388478]=0}e=c[2388476]|0;if((e|0)!=0){gGr(e);c[2388476]=0}c[2420384]=9675200;e=c[2419507]|0;if((e|0)!=0){gGr(e);c[(c[2420384]|0)+2828>>2]=0}c[2420384]=9678216;e=c[2420261]|0;if((e|0)!=0){gGr(e);c[(c[2420384]|0)+2828>>2]=0}e=d|0;d=c[c[642608+(c[2436]<<2)>>2]>>2]|0;be(e|0,128,179600,(f=i,i=i+24|0,c[f>>2]=9374064,c[f+8>>2]=47,c[f+16>>2]=d,f)|0)|0;i=f;a[1040128]=0;f=c[2420380]|0;d=c[f>>2]|0;g=c[f+4>>2]|0;f=fw(e|0,389440)|0;if((f|0)!=0){e=g>>3<<d&1023;cj(14100392,e|0,1,f|0)|0;aY(f|0)|0}f=c[2415092]|0;e=0;while(1){if((e|0)>=1024){h=67695;break}j=9638528+(e<<2)|0;if((c[j>>2]|0)==(f|0)){break}else{e=e+1|0}}if((h|0)==67695){c[2415092]=0;i=b;return 0}gGr(f);c[j>>2]=0;c[2415092]=0;i=b;return 0}function bjf(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;if((a[9624984]|0)!=0){a[9624984]=0;d=c[2414800]|0;gGz(d|0,0,(c[2411860]|0)-d|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;h=c[2417276]|0;c[3541536]=h;c[1836236]=0;gGz(9706056,0,76);if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=h;c[1836236]=-1;mx(0);c[2420384]=9675200;h=a[9678026]|0;g=h<<24>>24==-128;if(g){i=c[2419507]|0}else{i=(c[2419512]|0)+((h&255)<<17)|0}c[2419511]=i;c[2419510]=g?16384:131072;blH();c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];c[2430482]=a[1040128]|0?0:10;c[2432938]=0}gGz(9550936,-1|0,6);g=0;i=-1;h=-1;f=-1;do{i=((a[9634336+g|0]&1)<<g^i&65535)&65535;h=((a[9632096+g|0]&1)<<g^h&65535)&65535;f=((a[9630016+g|0]&1)<<g^f&65535)&65535;g=g+1|0;}while((g|0)<16);b[4775468]=i;b[4775469]=h;b[4775470]=f;if((h&12)==0){f=h|12;b[4775469]=f;j=f}else{j=h}if((j&3)==0){h=j|3;b[4775469]=h;k=h}else{k=j}if((i&12)==0){j=i|12;b[4775468]=j;l=j}else{l=i}if((l&3)==0){i=l|3;b[4775468]=i;m=i}else{m=l}if((k&3072)==0){l=k|3072;b[4775469]=l;n=l}else{n=k}if((n&768)==0){b[4775469]=n|768}if((m&3072)==0){n=m|3072;b[4775468]=n;o=n}else{o=m}if((o&768)==0){b[4775468]=o|768}o=a[9688]|0?534:0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];m=c[3532592]|0;if((m|0)!=0){gGC(9104152,m|0,280)|0}c[2113054]=c[2113060]}m=c[2439330]|0;if((m|0)!=0){n=m;gGC(9706056,n|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;n=o>>>1;m=0;k=0;l=0;i=0;L87690:while(1){j=k;h=l;f=i;while(1){if((f|0)>=(o|0)){break L87690}p=f+1|0;g=((p*266666|0|0)/534|0)-h|0;c[2113056]=g;e=RG(g)|0;c[2113054]=(c[2113054]|0)+e;c[2276108]=-1;c[2113056]=-1;q=e+h|0;do{if((f|0)==(n|0)&(c[2432938]|0)!=0){c[8452200+(c[2394]<<2)>>2]=8195;c[2276080]=768;if((c[2276079]|0)>>>0>=768){break}RH(3)}}while(0);e=((p*133333|0|0)/534|0)-j|0;do{if((e|0)<1){r=0}else{if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){g=gfc(e)|0;c[2433530]=(c[2433530]|0)+g;r=g;break}else{c[2433530]=(c[2433530]|0)+e;r=e;break}}}while(0);s=r+j|0;t=c[2112964]|0;if((t|0)==0){j=s;h=q;f=p}else{break}}f=a[9688]&1;h=t+(m<<1<<1)|0;gg[c[3542124]&4095](h,f);TK(h,f);m=f+m|0;k=s;l=q;i=p}do{if((c[2432938]|0)!=0){c[8452200+(c[2394]<<2)>>2]=8197;c[2276080]=1280;if((c[2276079]|0)>>>0>=1280){break}RH(5)}}while(0);p=c[2112964]|0;do{if((p|0)!=0){i=a[9688]|0?534:0;q=i-m|0;l=p+(m<<1<<1)|0;if((i|0)==(m|0)){break}gg[c[3542124]&4095](l,q);TK(l,q)}}while(0);m=c[1836236]|0;p=c[9757320+(m<<2)>>2]|0;if((p|0)!=0){q=p;gGC(q|0,9706056,76)|0}c[9752472+(m<<2)>>2]=c[2433530];c[14113936+(m<<2)>>2]=c[2076596];c[9669104+(m<<2)>>2]=c[3541536];c[1836236]=-1;m=c[2394]|0;q=c[14130368+(m<<2)>>2]|0;if((q|0)!=0){gGC(q|0,9104152,280)|0}c[8452240+(m<<2)>>2]=c[2113054];c[2394]=-1;if((c[2112968]|0)==0){return 0}bjg()|0;return 0}function bjg(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;if((a[9547976]|0)!=0){e=c[2387274]|0;f=c[2407004]|0;g=c[3530178]|0;h=0;do{i=b[e+(h<<1)>>1]|0;j=i&255;k=((j&255)>>>2&7|j<<3)&255;j=((i&65535)>>>5<<3&255|(i&65535)>>>7&7)&255;l=((i&65535)>>>10<<3&255|(i&65535)>>>12&7)&255;c[f+(h<<2)>>2]=j<<8|l|k<<16;c[g+(h<<2)>>2]=j<<3&2016|l>>>3|k<<8&63488;h=h+1|0;}while((h|0)<2048)}bpj();h=c[2437686]|0;c[2442908]=h;c[2432774]=c[2437683];c[2433648]=c[2437685];c[2433649]=c[2437682];c[2433650]=c[2437684];g=a[14116147]|0;f=g&255;c[2394834]=f;e=a[14116144]|0;k=e&255;c[2394832]=k;l=d[14116146]|0;c[2394830]=l;if((g&255)<(e&255)){c[2394834]=k;c[2394832]=f;m=k;n=1;o=0;p=f}else{m=f;n=0;o=1;p=k}if(m>>>0<l>>>0){c[2394834]=l;c[2394830]=m;q=m;r=2;s=n}else{q=l;r=n;s=2}if((p|0)<(q|0)){c[2394832]=q;c[2394830]=p;t=s;u=o}else{t=o;u=s}s=ag(c[2113070]|0,c[2113068]|0)|0;if((s|0)>0){o=c[2112926]|0;p=0;do{b[o+(p<<1)>>1]=(h<<4|1)&65535;p=p+1|0;}while((p|0)<(s|0))}bhi(c[2439868]|0,3);bpk(r,0,c[2439904]|0);bpk(t,0,c[2439904]|0);bhi(c[2439868]|0,0);bhi(c[2439868]|0,1);bhi(c[2439868]|0,2);bpk(u,0,c[2439904]|0);blK(c[2407004]|0,c[3530178]|0);return 0}function bjh(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;g=i;i=i+240|0;h=g|0;j=g+16|0;k=g+32|0;l=g+48|0;m=g+64|0;n=g+80|0;o=g+112|0;p=g+128|0;q=g+144|0;r=g+160|0;s=g+176|0;t=g+192|0;u=g+208|0;v=g+224|0;if((f|0)!=0){c[f>>2]=169733}if((e&96|0)!=0){gGz(v|0,0,12);w=c[2414800]|0;c[v>>2]=w;c[v+4>>2]=(c[2411860]|0)-w;c[v+12>>2]=162152;w=c[2076592]|0;gj[w&4095](v)|0;v=s|0;w=(e&64|0)==0;do{if(w){fw$(e);x=m;y=n|0}else{gGz(r|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){z=s+9|0;A=q;B=q|0;C=q+4|0;D=q+12|0;E=r|0;F=r+4|0;G=r+12|0;H=0;do{gGC(v|0,614896,11)|0;a[z]=H+48&255;I=8452256+(H<<2)|0;gGz(A|0,0,12);c[B>>2]=I;c[C>>2]=4;c[D>>2]=164976;gj[c[2076592]&4095](q)|0;if((c[I>>2]|0)!=0){c[E>>2]=c[14130368+(H<<2)>>2];c[F>>2]=c[8452184+(H<<2)>>2];c[G>>2]=v;I=c[2076592]|0;gj[I&4095](r)|0}H=H+1|0;}while((H|0)<=(c[2392]|0))}fw$(e);gGz(p|0,0,12);c[p>>2]=8453216;c[p+4>>2]=4;c[p+12>>2]=107480;H=c[2076592]|0;gj[H&4095](p)|0;gGz(o|0,0,12);c[o>>2]=14168504;c[o+4>>2]=256;c[o+12>>2]=476464;H=c[2076592]|0;gj[H&4095](o)|0;if((e&2|0)!=0){H=0;do{mv(0,H,d[14168504+H|0]|0);H=H+1|0;}while((H|0)<256)}H=m;G=n|0;if(w){x=H;y=G;break}F=m|0;E=m+4|0;D=m+8|0;C=m+12|0;B=l;A=l|0;z=l+4|0;I=l+12|0;J=k;K=k|0;L=k+4|0;M=k+12|0;N=j;O=j|0;P=j+4|0;Q=j+12|0;R=h;S=h|0;T=h+4|0;U=h+12|0;V=0;while(1){W=9675200+(V*3016|0)|0;c[2420384]=W;cC(G|0,169336,(X=i,i=i+8|0,c[X>>2]=0,X)|0)|0;i=X;c[F>>2]=(c[2420384]|0)+2240;c[E>>2]=24;c[D>>2]=0;c[C>>2]=G;gj[c[2076592]&4095](m)|0;cC(G|0,502752,(X=i,i=i+8|0,c[X>>2]=0,X)|0)|0;i=X;c[F>>2]=(c[2420384]|0)+2268;c[E>>2]=560;c[D>>2]=0;c[C>>2]=G;gj[c[2076592]&4095](m)|0;cC(G|0,387032,(X=i,i=i+8|0,c[X>>2]=0,X)|0)|0;i=X;X=c[2420384]|0;c[F>>2]=c[X+2828>>2];c[E>>2]=(((c[X+2860>>2]|0)/50|0)<<1)+32768;c[D>>2]=0;c[C>>2]=G;gj[c[2076592]&4095](m)|0;c[F>>2]=(c[2420384]|0)+2888;c[E>>2]=128;c[D>>2]=0;c[C>>2]=G;gj[c[2076592]&4095](m)|0;X=(c[2420384]|0)+2264|0;gGz(B|0,0,12);c[A>>2]=X;c[z>>2]=4;c[I>>2]=301112;gj[c[2076592]&4095](l)|0;X=(c[2420384]|0)+2832|0;gGz(J|0,0,12);c[K>>2]=X;c[L>>2]=4;c[M>>2]=229680;gj[c[2076592]&4095](k)|0;X=(c[2420384]|0)+2836|0;gGz(N|0,0,12);c[O>>2]=X;c[P>>2]=4;c[Q>>2]=178840;gj[c[2076592]&4095](j)|0;X=(c[2420384]|0)+2840|0;gGz(R|0,0,12);c[S>>2]=X;c[T>>2]=4;c[U>>2]=143984;gj[c[2076592]&4095](h)|0;X=a[9678026]|0;c[2420384]=W;W=X<<24>>24==-128;if(W){Y=c[9678028+(V*3016|0)>>2]|0}else{Y=(c[9678048+(V*3016|0)>>2]|0)+((X&255)<<17)|0}c[9678044+(V*3016|0)>>2]=Y;c[9678040+(V*3016|0)>>2]=W?16384:131072;c[9678036+(V*3016|0)>>2]=0;a[9678026+(V*3016|0)|0]=X;X=V+1|0;if((X|0)<2){V=X}else{x=H;y=G;break}}}}while(0);blJ(e);Ts(e,f);gGz(u|0,0,12);c[u>>2]=9731752;c[u+4>>2]=4;c[u+12>>2]=139264;y=c[2076592]|0;gj[y&4095](u)|0;gGz(t|0,0,12);c[t>>2]=9721928;c[t+4>>2]=4;c[t+12>>2]=135288;u=c[2076592]|0;gj[u&4095](t)|0}if((e&2|0)==0){Ts(e,f);i=g;return 0}t=c[2439330]|0;if((t|0)!=0){u=t;gGC(9706056,u|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];u=c[3528484]|0;c[2076596]=u;y=c[2417276]|0;c[3541536]=y;c[1836236]=0;x=c[2443936]|0;Y=a[x]&7;a[x]=Y;h=c[2386e3]|0;j=((Y&255)<<14)-32768|0;Y=128;k=128;while(1){c[t+76+(k<<2)>>2]=h+(j+(k<<8));l=Y+1&65535;if((l&65535)>191){break}else{Y=l;k=l&65535}}k=((d[x]|0)<<14)-32768|0;x=128;Y=128;while(1){j=h+(k+(Y<<8))|0;c[t+76+(Y+512<<2)>>2]=j;c[t+76+(Y+768<<2)>>2]=j;j=x+1&65535;if((j&65535)>191){break}else{x=j;Y=j&65535}}Y=t;gGC(Y|0,9706056,76)|0;c[2438118]=c[2433530];c[3528484]=u;c[2417276]=y;c[1836236]=-1;Ts(e,f);i=g;return 0}function bji(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6453540+(b*112|0)>>2];c[a+104>>2]=c[6453544+(b*112|0)>>2];c[a+108>>2]=c[6453548+(b*112|0)>>2];d=0;return d|0}function bjj(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=6453440+(b*112|0);e=0;return e|0}function bjk(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5623924+(b*112|0)>>2];c[a+104>>2]=c[5623928+(b*112|0)>>2];c[a+108>>2]=c[5623932+(b*112|0)>>2];d=0;return d|0}function bjl(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=5623824+(b*112|0);e=0;return e|0}function bjm(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6452084+(b*112|0)>>2];c[a+104>>2]=c[6452088+(b*112|0)>>2];c[a+108>>2]=c[6452092+(b*112|0)>>2];d=0;return d|0}function bjn(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=6451984+(b*112|0);e=0;return e|0}function bjo(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6450628+(b*112|0)>>2];c[a+104>>2]=c[6450632+(b*112|0)>>2];c[a+108>>2]=c[6450636+(b*112|0)>>2];d=0;return d|0}function bjp(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=6450528+(b*112|0);e=0;return e|0}function bjq(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4310252+(b*112|0)>>2];c[a+104>>2]=c[4310256+(b*112|0)>>2];c[a+108>>2]=c[4310260+(b*112|0)>>2];d=0;return d|0}function bjr(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=4310152+(b*112|0);e=0;return e|0}function bjs(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3216712+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function bjt(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4311708+(b*112|0)>>2];c[a+104>>2]=c[4311712+(b*112|0)>>2];c[a+108>>2]=c[4311716+(b*112|0)>>2];d=0;return d|0}function bju(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=4311608+(b*112|0);e=0;return e|0}function bjv(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4308796+(b*112|0)>>2];c[a+104>>2]=c[4308800+(b*112|0)>>2];c[a+108>>2]=c[4308804+(b*112|0)>>2];d=0;return d|0}function bjw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=4308696+(b*112|0);e=0;return e|0}function bjx(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;g=c[e>>2]|0;if((a|0)==0){h=g>>>4&15}else{h=g>>>2&31}c[e>>2]=h+(c[9734592+(a<<2)>>2]|0);return}function bjy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;e=(c[b>>2]|0)>>>4&14;do{if((e|0)>(c[2394830]|0)){if((e|0)<=(c[2394832]|0)){c[d>>2]=1;break}if((e|0)>(c[2394834]|0)){c[d>>2]=3;break}else{c[d>>2]=2;break}}else{c[d>>2]=0}}while(0);c[b>>2]=(c[b>>2]&31)+(c[2432774]|0);c[a>>2]=c[a>>2]&32767;return}function bjz(b){b=b|0;var c=0,d=0;c=b&65535;switch(c|0){case 16:case 17:case 18:{d=a[9550928+(c&3)|0]|0;break};case 20:case 21:case 22:{d=a[9658088+(c&3)|0]|0;break};default:{d=0}}return d|0}function bjA(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=b&65535;if((e&65280|0)==3072){b=e&255;f=c[2387272]|0;a[f+b|0]=d;g=a[f+(e&254)|0]|0;h=a[f+(b|1)|0]|0;f=(h&255)<<8|g&255;a[9547968]=1;c[(c[2407002]|0)+(b>>>1<<2)>>2]=((h&255)>>>2<<3|(h&255)>>>4&7)&255|(((g&255)>>>2&7|g<<3)&255)<<16|(((f&65535)>>>5<<3&255|(f&65535)>>>7&7)&255)<<8;return}if((e|0)==26){a[999424]=1;return}else if((e|0)==0|(e|0)==1|(e|0)==2|(e|0)==3|(e|0)==4|(e|0)==5|(e|0)==6|(e|0)==7){f=e&7;g=d&255;do{if((f|0)==3){h=c[2443774]|0;b=c[2386526]|0;if((g&8|0)==0){i=b+2048|0;gGC(h|0,i|0,2048)|0;break}else{gGC(h|0,b|0,2048)|0;break}}else if((f|0)==7){c[2430186]=g&8}}while(0);a[9750800+f|0]=d;return}else if((e|0)==96|(e|0)==97|(e|0)==98|(e|0)==99|(e|0)==100|(e|0)==101|(e|0)==102|(e|0)==103){f=e&7;g=d&255;do{if((f|0)==7){c[2430187]=g&8}else if((f|0)==3){b=c[2443772]|0;h=c[2443532]|0;if((g&8|0)==0){i=h+4096|0;gGC(b|0,i|0,2048)|0;break}else{i=h+2048|0;gGC(b|0,i|0,2048)|0;break}}}while(0);a[9750808+f|0]=d;return}else if((e|0)==28672){f=d&15;a[9542224]=f;g=(f&255)<<13;if((g+65536|0)>>>0>=163840){return}f=c[2443526]|0;i=c[3528554]|0;b=c[2433592]|0;h=g+40960|0;g=96;j=96;while(1){k=f+(h+(j<<8))|0;c[b+(i*3148|0)+48+(j<<2)>>2]=k;c[b+(i*3148|0)+48+(j+512<<2)>>2]=k;k=g+1&65535;if((k&65535)>127){break}else{g=k;j=k&65535}}return}else if((e|0)==28){a[14113440]=d;return}else{return}}function bjB(b){b=b|0;var d=0,e=0;d=b&65535;if((d|0)==0){e=a[14113440]|0}else if((d|0)==8193){e=c[(c[3531464]|0)+4240>>2]&255}else{e=0}return e|0}function bjC(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((e|0)==8192){c[2113304]=d&255;return}else if((e|0)==8193){e=c[2113304]|0;a[14168504+e|0]=d;mv(0,e,d&255);return}else{return}}function bjD(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5932580+(b*112|0)>>2];c[a+104>>2]=c[5932584+(b*112|0)>>2];c[a+108>>2]=c[5932588+(b*112|0)>>2];d=0;return d|0}function bjE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=5932480+(b*112|0);e=0;return e|0}function bjF(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6938144+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function bjG(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>62){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7448960+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function bjH(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0;e=i;i=i+920|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+856|0;x=e+888|0;c[2415090]=0;c[2443526]=0;c[2443522]=196608;c[3530936]=262144;c[3530700]=1310720;c[2406290]=2359296;c[3527462]=2360320;c[3530176]=2364416;c[2414798]=2380800;c[2443536]=2380800;c[2443532]=2384896;c[2443528]=2391040;c[2387272]=2393088;c[2387854]=2393344;c[2387848]=2394368;c[2386342]=2395392;c[2386340]=2396416;c[2387990]=2397440;c[2387966]=2398464;c[2386526]=2399488;c[2443774]=2403584;c[2443772]=2405632;c[2407002]=2407680;c[2411858]=2408192;y=0;while(1){if((y|0)>=1024){break}z=9638528+(y<<2)|0;if((c[z>>2]|0)==0){A=67982;break}else{y=y+1|0}}do{if((A|0)==67982){y=gGq(2408192)|0;c[z>>2]=y;if((y|0)==0){break}c[2415090]=y;gGz(y|0,0,2408192);c[2443526]=y;c[2443522]=y+196608;c[3530936]=y+262144;c[3530700]=y+1310720;c[2406290]=y+2359296;c[3527462]=y+2360320;c[3530176]=y+2364416;B=y+2380800|0;c[2414798]=B;c[2443536]=B;c[2443532]=y+2384896;c[2443528]=y+2391040;c[2387272]=y+2393088;c[2387854]=y+2393344;c[2387848]=y+2394368;c[2386342]=y+2395392;c[2386340]=y+2396416;c[2387990]=y+2397440;c[2387966]=y+2398464;c[2386526]=y+2399488;c[2443774]=y+2403584;c[2443772]=y+2405632;c[2407002]=y+2407680;B=y+2408192|0;c[2411858]=B;c[2414408]=B;if((c[3542200]|0)==0){C=1;i=e;return C|0}B=t+108|0;c[B>>2]=0;D=t+100|0;c[D>>2]=0;E=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[E&16383](t,0)|0;do{if((c[B>>2]|0)!=0){E=c[D>>2]|0;c[u>>2]=9534384;F=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[F&16383](u,0,0)|0;if((E|0)<1){C=1;i=e;return C|0}if((gzL(y,0,0)|0)==0){break}else{C=1}i=e;return C|0}}while(0);y=c[2443526]|0;D=y+131072|0;gGC(D|0,y|0,32768)|0;D=y+65536|0;if((c[3542200]|0)==0){C=1;i=e;return C|0}y=r+108|0;c[y>>2]=0;B=r+100|0;c[B>>2]=0;E=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[E&16383](r,1)|0;do{if((c[y>>2]|0)!=0){E=c[B>>2]|0;c[s>>2]=9534384;F=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[F&16383](s,1,0)|0;if((E|0)<1){C=1;i=e;return C|0}if((gzL(D,0,1)|0)==0){break}else{C=1}i=e;return C|0}}while(0);D=(c[2443522]|0)+32768|0;if((c[3542200]|0)==0){C=1;i=e;return C|0}B=p+108|0;c[B>>2]=0;y=p+100|0;c[y>>2]=0;E=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[E&16383](p,2)|0;do{if((c[B>>2]|0)!=0){E=c[y>>2]|0;c[q>>2]=9534384;F=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[F&16383](q,2,0)|0;if((E|0)<1){C=1;i=e;return C|0}if((gzL(D,0,2)|0)==0){break}else{C=1}i=e;return C|0}}while(0);L88022:do{if((c[(c[642608+(c[2436]<<2)>>2]|0)+52>>2]&32|0)==0){if((R6(c[3530936]|0,3,2)|0)!=0){C=1;i=e;return C|0}if((R6((c[3530936]|0)+1|0,4,2)|0)!=0){C=1;i=e;return C|0}if((R6(c[3530700]|0,5,2)|0)!=0){C=1;i=e;return C|0}if((R6((c[3530700]|0)+1|0,6,2)|0)!=0){C=1;i=e;return C|0}D=f+108|0;y=f+100|0;B=0;while(1){E=(c[2406290]|0)+(B<<8)|0;F=B+7|0;if((c[3542200]|0)==0){C=1;A=68131;break}c[D>>2]=0;c[y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,F)|0;if((c[D>>2]|0)!=0){G=c[y>>2]|0;c[g>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](g,F,0)|0;if((G|0)<1){C=1;A=68134;break}if((gzL(E,0,F)|0)!=0){C=1;A=68135;break}}B=B+1|0;if((B|0)>=4){break L88022}}if((A|0)==68131){i=e;return C|0}else if((A|0)==68134){i=e;return C|0}else if((A|0)==68135){i=e;return C|0}}else{B=n+108|0;y=n+100|0;D=l+108|0;F=l+100|0;E=0;while(1){G=E<<16;H=(c[3530936]|0)+G|0;I=E+3|0;if((c[3542200]|0)==0){C=1;A=68121;break}c[B>>2]=0;c[y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,I)|0;if((c[B>>2]|0)!=0){J=c[y>>2]|0;c[o>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](o,I,0)|0;if((J|0)<1){C=1;A=68136;break}if((gzL(H,0,I)|0)!=0){C=1;A=68127;break}}I=(c[3530700]|0)+G|0;G=E+11|0;if((c[3542200]|0)==0){C=1;A=68125;break}c[D>>2]=0;c[F>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,G)|0;if((c[D>>2]|0)!=0){H=c[F>>2]|0;c[m>>2]=9534384;J=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[J&16383](m,G,0)|0;if((H|0)<1){C=1;A=68132;break}if((gzL(I,0,G)|0)!=0){C=1;A=68142;break}}G=E+1|0;if((G|0)<8){E=G}else{A=67998;break}}if((A|0)==67998){E=j+108|0;F=j+100|0;D=0;while(1){y=(c[2406290]|0)+(D<<8)|0;B=D+18|0;if((c[3542200]|0)==0){C=1;A=68144;break}c[E>>2]=0;c[F>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,B)|0;if((c[E>>2]|0)!=0){G=c[F>>2]|0;c[k>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](k,B,0)|0;if((G|0)<1){C=1;A=68145;break}if((gzL(y,0,B)|0)!=0){C=1;A=68137;break}}D=D+1|0;if((D|0)>=4){break L88022}}if((A|0)==68137){i=e;return C|0}else if((A|0)==68144){i=e;return C|0}else if((A|0)==68145){i=e;return C|0}}else if((A|0)==68121){i=e;return C|0}else if((A|0)==68125){i=e;return C|0}else if((A|0)==68127){i=e;return C|0}else if((A|0)==68132){i=e;return C|0}else if((A|0)==68136){i=e;return C|0}else if((A|0)==68142){i=e;return C|0}}}while(0);D=c[3530936]|0;F=v;E=w;B=x;c[F>>2]=c[175854];c[F+4>>2]=c[175855];c[F+8>>2]=c[175856];c[F+12>>2]=c[175857];gGC(E|0,1934976,32)|0;gGC(B|0,1183816,32)|0;y=0;while(1){if((y|0)>=1024){break}L=9638528+(y<<2)|0;if((c[L>>2]|0)==0){A=68026;break}else{y=y+1|0}}L88083:do{if((A|0)==68026){y=gGq(524288)|0;c[L>>2]=y;if((y|0)==0){break}gGz(y|0,0,524288);gGC(y|0,D|0,524288)|0;G=0;while(1){I=G<<6;gGz(D+I|0,0,64);H=G<<8;J=0;do{K=1<<3-J;M=(c[v+(J<<2)>>2]|0)+H|0;N=0;do{O=M+(c[x+(N<<2)>>2]|0)|0;P=(N<<3)+I|0;Q=0;do{R=O+(c[w+(Q<<2)>>2]|0)|0;if(((d[y+((R|0)/8|0)|0]|0)&128>>>((R&7)>>>0)|0)!=0){R=D+(P+Q)|0;a[R]=(d[R]|0|K)&255}Q=Q+1|0;}while((Q|0)<8);N=N+1|0;}while((N|0)<8);J=J+1|0;}while((J|0)<4);J=G+1|0;if((J|0)<16384){G=J}else{S=0;break}}while(1){if((S|0)>=1024){break L88083}T=9638528+(S<<2)|0;if((c[T>>2]|0)==(y|0)){break}else{S=S+1|0}}gGr(y);c[T>>2]=0}}while(0);D=c[3530700]|0;c[F>>2]=c[175854];c[F+4>>2]=c[175855];c[F+8>>2]=c[175856];c[F+12>>2]=c[175857];gGC(E|0,1934976,32)|0;gGC(B|0,1183816,32)|0;G=0;while(1){if((G|0)>=1024){break}U=9638528+(G<<2)|0;if((c[U>>2]|0)==0){A=68043;break}else{G=G+1|0}}L88108:do{if((A|0)==68043){G=gGq(524288)|0;c[U>>2]=G;if((G|0)==0){break}gGz(G|0,0,524288);gGC(G|0,D|0,524288)|0;B=0;while(1){E=B<<6;gGz(D+E|0,0,64);F=B<<8;J=0;do{I=1<<3-J;H=(c[v+(J<<2)>>2]|0)+F|0;N=0;do{K=H+(c[x+(N<<2)>>2]|0)|0;M=(N<<3)+E|0;Q=0;do{P=K+(c[w+(Q<<2)>>2]|0)|0;if(((d[G+((P|0)/8|0)|0]|0)&128>>>((P&7)>>>0)|0)!=0){P=D+(M+Q)|0;a[P]=(d[P]|0|I)&255}Q=Q+1|0;}while((Q|0)<8);N=N+1|0;}while((N|0)<8);J=J+1|0;}while((J|0)<4);J=B+1|0;if((J|0)<16384){B=J}else{V=0;break}}while(1){if((V|0)>=1024){break L88108}W=9638528+(V<<2)|0;if((c[W>>2]|0)==(G|0)){break}else{V=V+1|0}}gGr(G);c[W>>2]=0}}while(0);D=c[2406290]|0;B=c[3527462]|0;y=0;while(1){J=y&1;E=J<<8;F=y<<8;N=y<<4;if((J|0)==0){J=0;do{I=a[D+(J|E)|0]|0;if(I<<24>>24==0){X=0}else{X=(I&15|N)&255}a[B+(J|F)|0]=X;J=J+1|0;}while((J|0)<256)}else{J=0;do{a[B+(J|F)|0]=(a[D+(J|E)|0]&15|N)&255;J=J+1|0;}while((J|0)<256)}J=y+1|0;if((J|0)<8){y=J}else{Y=0;break}}do{y=Y&1;J=y<<8|512;N=Y<<8|2048;E=Y<<4;if((y|0)==0){y=0;do{F=a[D+(y|J)|0]|0;if(F<<24>>24==0){Z=0}else{Z=(F&15|E)&255}a[B+(y|N)|0]=Z;y=y+1|0;}while((y|0)<256)}else{y=0;do{a[B+(y|N)|0]=(a[D+(y|J)|0]&15|E)&255;y=y+1|0;}while((y|0)<256)}Y=Y+1|0;}while((Y|0)<8);c[3528554]=-1;c[2113160]=2;D=gGq(6296)|0;B=D;c[2433592]=B;if((D|0)!=0){gGz(D|0,0,6296);y=0;do{c[B+(y*3148|0)+3120>>2]=3128;c[B+(y*3148|0)+3124>>2]=1840;c[B+(y*3148|0)+3128>>2]=136;c[B+(y*3148|0)+3132>>2]=1902;c[9731360+(y<<2)>>2]=0;E=0;do{c[B+(y*3148|0)+48+(E<<2)>>2]=0;E=E+1|0;}while((E|0)<768);y=y+1|0;}while((y|0)<2);c[2113158]=0;c[2415198]=0;y=c[2427044]|0;c[9681616+(y<<3)>>2]=809272;c[9681620+(y<<3)>>2]=0;B=y+1|0;c[9681616+(B<<3)>>2]=809272;c[9681620+(B<<3)>>2]=1;c[2427044]=y+2}c[3528554]=0;f43(D);y=c[3528554]|0;B=9731360+(y<<2)|0;E=c[B>>2]|0;c[2113158]=E;J=c[2387272]|0;N=c[2433592]|0;c[N+(y*3148|0)+96>>2]=J;c[N+(y*3148|0)+2144>>2]=J;J=c[2443536]|0;F=16;G=16;while(1){I=J+((G<<8)-4096)|0;c[N+(y*3148|0)+48+(G<<2)>>2]=I;c[N+(y*3148|0)+48+(G+256<<2)>>2]=I;c[N+(y*3148|0)+48+(G+512<<2)>>2]=I;I=F+1&65535;if((I&65535)>31){break}else{F=I;G=I&65535}}G=c[2387854]|0;c[N+(y*3148|0)+176>>2]=G;c[N+(y*3148|0)+1200>>2]=G;c[N+(y*3148|0)+2224>>2]=G;F=G+256|0;c[N+(y*3148|0)+180>>2]=F;c[N+(y*3148|0)+1204>>2]=F;c[N+(y*3148|0)+2228>>2]=F;F=G+512|0;c[N+(y*3148|0)+184>>2]=F;c[N+(y*3148|0)+1208>>2]=F;c[N+(y*3148|0)+2232>>2]=F;F=G+768|0;c[N+(y*3148|0)+188>>2]=F;c[N+(y*3148|0)+1212>>2]=F;c[N+(y*3148|0)+2236>>2]=F;F=c[2387848]|0;c[N+(y*3148|0)+192>>2]=F;c[N+(y*3148|0)+1216>>2]=F;c[N+(y*3148|0)+2240>>2]=F;G=F+256|0;c[N+(y*3148|0)+196>>2]=G;c[N+(y*3148|0)+1220>>2]=G;c[N+(y*3148|0)+2244>>2]=G;G=F+512|0;c[N+(y*3148|0)+200>>2]=G;c[N+(y*3148|0)+1224>>2]=G;c[N+(y*3148|0)+2248>>2]=G;G=F+768|0;c[N+(y*3148|0)+204>>2]=G;c[N+(y*3148|0)+1228>>2]=G;c[N+(y*3148|0)+2252>>2]=G;G=c[2386342]|0;c[N+(y*3148|0)+208>>2]=G;c[N+(y*3148|0)+1232>>2]=G;c[N+(y*3148|0)+2256>>2]=G;F=G+256|0;c[N+(y*3148|0)+212>>2]=F;c[N+(y*3148|0)+1236>>2]=F;c[N+(y*3148|0)+2260>>2]=F;F=G+512|0;c[N+(y*3148|0)+216>>2]=F;c[N+(y*3148|0)+1240>>2]=F;c[N+(y*3148|0)+2264>>2]=F;F=G+768|0;c[N+(y*3148|0)+220>>2]=F;c[N+(y*3148|0)+1244>>2]=F;c[N+(y*3148|0)+2268>>2]=F;F=c[2386340]|0;c[N+(y*3148|0)+224>>2]=F;c[N+(y*3148|0)+1248>>2]=F;c[N+(y*3148|0)+2272>>2]=F;G=F+256|0;c[N+(y*3148|0)+228>>2]=G;c[N+(y*3148|0)+1252>>2]=G;c[N+(y*3148|0)+2276>>2]=G;G=F+512|0;c[N+(y*3148|0)+232>>2]=G;c[N+(y*3148|0)+1256>>2]=G;c[N+(y*3148|0)+2280>>2]=G;G=F+768|0;c[N+(y*3148|0)+236>>2]=G;c[N+(y*3148|0)+1260>>2]=G;c[N+(y*3148|0)+2284>>2]=G;G=c[2386526]|0;F=48;J=48;while(1){D=G+((J<<8)-12288)|0;c[N+(y*3148|0)+48+(J<<2)>>2]=D;c[N+(y*3148|0)+48+(J+256<<2)>>2]=D;c[N+(y*3148|0)+48+(J+512<<2)>>2]=D;D=F+1&65535;if((D&65535)>63){break}else{F=D;J=D&65535}}J=c[2387990]|0;c[N+(y*3148|0)+304>>2]=J;c[N+(y*3148|0)+1328>>2]=J;c[N+(y*3148|0)+2352>>2]=J;F=J+256|0;c[N+(y*3148|0)+308>>2]=F;c[N+(y*3148|0)+1332>>2]=F;c[N+(y*3148|0)+2356>>2]=F;F=J+512|0;c[N+(y*3148|0)+312>>2]=F;c[N+(y*3148|0)+1336>>2]=F;c[N+(y*3148|0)+2360>>2]=F;F=J+768|0;c[N+(y*3148|0)+316>>2]=F;c[N+(y*3148|0)+1340>>2]=F;c[N+(y*3148|0)+2364>>2]=F;F=c[2387966]|0;c[N+(y*3148|0)+320>>2]=F;c[N+(y*3148|0)+1344>>2]=F;c[N+(y*3148|0)+2368>>2]=F;J=F+256|0;c[N+(y*3148|0)+324>>2]=J;c[N+(y*3148|0)+1348>>2]=J;c[N+(y*3148|0)+2372>>2]=J;J=F+512|0;c[N+(y*3148|0)+328>>2]=J;c[N+(y*3148|0)+1352>>2]=J;c[N+(y*3148|0)+2376>>2]=J;J=F+768|0;c[N+(y*3148|0)+332>>2]=J;c[N+(y*3148|0)+1356>>2]=J;c[N+(y*3148|0)+2380>>2]=J;J=c[2443532]|0;F=72;G=72;while(1){D=J+((G<<8)-18432)|0;c[N+(y*3148|0)+48+(G<<2)>>2]=D;c[N+(y*3148|0)+48+(G+256<<2)>>2]=D;c[N+(y*3148|0)+48+(G+512<<2)>>2]=D;D=F+1&65535;if((D&65535)>95){break}else{F=D;G=D&65535}}G=c[2443526]|0;F=128;J=128;while(1){D=G+(J<<8)|0;c[N+(y*3148|0)+48+(J<<2)>>2]=D;c[N+(y*3148|0)+48+(J+512<<2)>>2]=D;D=F+1&65535;if((D&65535)>255){break}else{F=D;J=D&65535}}c[N+(y*3148|0)+3120>>2]=2896;c[N+(y*3148|0)+3124>>2]=3350;J=N+(y*3148|0)|0;if((J|0)!=0){F=J;gGC(F|0,9660752,48)|0}c[B>>2]=E;c[3528554]=1;f43(N+3148|0);F=c[3528554]|0;J=9731360+(F<<2)|0;G=c[J>>2]|0;c[2113158]=G;D=c[2443528]|0;I=c[2433592]|0;c[I+(F*3148|0)+432>>2]=D;c[I+(F*3148|0)+1456>>2]=D;c[I+(F*3148|0)+2480>>2]=D;H=D+256|0;c[I+(F*3148|0)+436>>2]=H;c[I+(F*3148|0)+1460>>2]=H;c[I+(F*3148|0)+2484>>2]=H;H=D+512|0;c[I+(F*3148|0)+440>>2]=H;c[I+(F*3148|0)+1464>>2]=H;c[I+(F*3148|0)+2488>>2]=H;H=D+768|0;c[I+(F*3148|0)+444>>2]=H;c[I+(F*3148|0)+1468>>2]=H;c[I+(F*3148|0)+2492>>2]=H;H=D+1024|0;c[I+(F*3148|0)+448>>2]=H;c[I+(F*3148|0)+1472>>2]=H;c[I+(F*3148|0)+2496>>2]=H;H=D+1280|0;c[I+(F*3148|0)+452>>2]=H;c[I+(F*3148|0)+1476>>2]=H;c[I+(F*3148|0)+2500>>2]=H;H=D+1536|0;c[I+(F*3148|0)+456>>2]=H;c[I+(F*3148|0)+1480>>2]=H;c[I+(F*3148|0)+2504>>2]=H;H=D+1792|0;c[I+(F*3148|0)+460>>2]=H;c[I+(F*3148|0)+1484>>2]=H;c[I+(F*3148|0)+2508>>2]=H;H=c[2443522]|0;D=128;Q=128;while(1){M=H+(Q<<8)|0;c[I+(F*3148|0)+48+(Q<<2)>>2]=M;c[I+(F*3148|0)+48+(Q+512<<2)>>2]=M;M=D+1&65535;if((M&65535)>255){break}else{D=M;Q=M&65535}}c[I+(F*3148|0)+3120>>2]=3358;c[I+(F*3148|0)+3124>>2]=1170;Q=I+(F*3148|0)|0;if((Q|0)!=0){D=Q;gGC(D|0,9660752,48)|0}c[J>>2]=G;c[3528554]=-1;D=a[9680]|0;Q=D?32e3:0;if(D){if(a[9624]|0){D=Q*3|0;H=55930;while(1){if((H|0)>(D|0)){H=H>>1}else{_=1222;$=H;break}}}else{_=2462;$=Q}c[2429380]=$;c[3542124]=_;mw(3579545,$);H=gGq(262144)|0;c[2406684]=H;gGz(H|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(3579545,11025)}c[(c[3531464]|0)+44344>>2]=1534;h[745421]=.6;c[2436794]=1;h[745420]=.6;c[2436792]=2;a[9624976]=0;H=c[2414798]|0;gGz(H|0,0,(c[2411858]|0)-H|0);gGz(9750800,0,16);H=9720744;c[H>>2]=0;c[H+4>>2]=0;c[3528554]=0;f43(c[2433592]|0);H=c[3528554]|0;c[2113158]=c[9731360+(H<<2)>>2];a[9660796]=0;a[9660797]=0;a[9660786]=0;a[9660787]=0;c[2415191]=0;a[9660784]=a[9660784]|80;D=c[2433592]|0;G=c[D+(H*3148|0)+1068>>2]|0;do{if((G|0)==0){J=c[D+(H*3148|0)+3120>>2]|0;if((J|0)==0){aa=0;ab=0;ac=H;ad=D;break}F=gj[J&4095](-2)|0;J=c[3528554]|0;I=c[2433592]|0;N=c[I+(J*3148|0)+1068>>2]|0;E=(F&255)<<8;if((N|0)!=0){ae=N;af=E;ah=J;ai=I;A=68100;break}N=c[I+(J*3148|0)+3120>>2]|0;if((N|0)==0){aa=0;ab=E;ac=J;ad=I;break}I=gj[N&4095](-1)|0;aa=I;ab=E;ac=c[3528554]|0;ad=c[2433592]|0}else{ae=G;af=(d[G+254|0]|0)<<8;ah=H;ai=D;A=68100}}while(0);if((A|0)==68100){aa=a[ae+255|0]|0;ab=af;ac=ah;ad=ai}D=aa&255|ab;c[2415188]=D;b[4830376]=D&65535;D=ad+(ac*3148|0)|0;if((D|0)!=0){H=D;gGC(H|0,9660752,48)|0}c[9731360+(ac<<2)>>2]=c[2113158];c[3528554]=1;f43(ad+3148|0);H=c[3528554]|0;c[2113158]=c[9731360+(H<<2)>>2];a[9660796]=0;a[9660797]=0;a[9660786]=0;a[9660787]=0;c[2415191]=0;a[9660784]=a[9660784]|80;D=c[2433592]|0;G=c[D+(H*3148|0)+1068>>2]|0;do{if((G|0)==0){Q=c[D+(H*3148|0)+3120>>2]|0;if((Q|0)==0){aj=0;ak=0;al=H;am=D;break}E=gj[Q&4095](-2)|0;Q=c[3528554]|0;I=c[2433592]|0;N=c[I+(Q*3148|0)+1068>>2]|0;J=(E&255)<<8;if((N|0)!=0){an=N;ao=J;ap=Q;aq=I;A=68109;break}N=c[I+(Q*3148|0)+3120>>2]|0;if((N|0)==0){aj=0;ak=J;al=Q;am=I;break}I=gj[N&4095](-1)|0;aj=I;ak=J;al=c[3528554]|0;am=c[2433592]|0}else{an=G;ao=(d[G+254|0]|0)<<8;ap=H;aq=D;A=68109}}while(0);if((A|0)==68109){aj=a[an+255|0]|0;ak=ao;al=ap;am=aq}D=aj&255|ak;c[2415188]=D;b[4830376]=D&65535;D=am+(al*3148|0)|0;if((D|0)!=0){H=D;gGC(H|0,9660752,48)|0}c[9731360+(al<<2)>>2]=c[2113158];c[3528554]=-1;mx(0);a[999424]=0;a[14113440]=0;a[9542224]=0;H=c[642608+(c[2436]<<2)>>2]|0;D=c[H+128>>2]|0;if((c[H+52>>2]&4|0)==0){c[2113068]=D;G=c[H+132>>2]|0;c[2113070]=G;c[2443814]=D;c[2440436]=G;ar=D;as=G}else{c[2113070]=D;G=c[H+132>>2]|0;c[2113068]=G;c[2440436]=D;c[2443814]=G;ar=G;as=D}D=ag(ar<<1,as)|0;G=gGq(D)|0;c[2112926]=G;if((G|0)==0){C=0;i=e;return C|0}gGz(G|0,0,D|0);C=0;i=e;return C|0}}while(0);c[2415090]=0;C=1;i=e;return C|0}function bjI(){var a=0,b=0,d=0,e=0;c[2113070]=0;c[2113068]=0;a=c[2112926]|0;if((a|0)!=0){gGr(a);c[2112926]=0}c[2113160]=0;a=c[2433592]|0;if((a|0)!=0){gGr(a);c[2433592]=0}a=c[3531464]|0;c[a+44344>>2]=0;c[a+44348>>2]=0;if((a|0)!=0){gGr(a);c[3531464]=0}a=c[2406684]|0;if((a|0)!=0){gGr(a);c[2406684]=0}a=c[2415090]|0;b=0;while(1){if((b|0)>=1024){d=68162;break}e=9638528+(b<<2)|0;if((c[e>>2]|0)==(a|0)){break}else{b=b+1|0}}if((d|0)==68162){c[2415090]=0;return 0}gGr(a);c[e>>2]=0;c[2415090]=0;return 0}function bjJ(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;if((a[9624976]|0)!=0){a[9624976]=0;e=c[2414798]|0;gGz(e|0,0,(c[2411858]|0)-e|0);gGz(9750800,0,16);e=9720744;c[e>>2]=0;c[e+4>>2]=0;c[3528554]=0;f43(c[2433592]|0);e=c[3528554]|0;c[2113158]=c[9731360+(e<<2)>>2];a[9660796]=0;a[9660797]=0;a[9660786]=0;a[9660787]=0;c[2415191]=0;a[9660784]=a[9660784]|80;f=c[2433592]|0;g=c[f+(e*3148|0)+1068>>2]|0;do{if((g|0)==0){h=c[f+(e*3148|0)+3120>>2]|0;if((h|0)==0){i=0;j=0;k=e;l=f;break}m=gj[h&4095](-2)|0;h=c[3528554]|0;n=c[2433592]|0;o=c[n+(h*3148|0)+1068>>2]|0;p=(m&255)<<8;if((o|0)!=0){q=o;r=p;s=h;t=n;u=68168;break}o=c[n+(h*3148|0)+3120>>2]|0;if((o|0)==0){i=0;j=p;k=h;l=n;break}n=gj[o&4095](-1)|0;i=n;j=p;k=c[3528554]|0;l=c[2433592]|0}else{q=g;r=d[g+254|0]<<8;s=e;t=f;u=68168}}while(0);if((u|0)==68168){i=a[q+255|0]|0;j=r;k=s;l=t}t=i&255|j;c[2415188]=t;b[4830376]=t&65535;t=l+(k*3148|0)|0;if((t|0)!=0){j=t;gGC(j|0,9660752,48)|0}c[9731360+(k<<2)>>2]=c[2113158];c[3528554]=1;f43(l+3148|0);l=c[3528554]|0;c[2113158]=c[9731360+(l<<2)>>2];a[9660796]=0;a[9660797]=0;a[9660786]=0;a[9660787]=0;c[2415191]=0;a[9660784]=a[9660784]|80;k=c[2433592]|0;j=c[k+(l*3148|0)+1068>>2]|0;do{if((j|0)==0){t=c[k+(l*3148|0)+3120>>2]|0;if((t|0)==0){v=0;w=0;x=l;y=k;break}i=gj[t&4095](-2)|0;t=c[3528554]|0;s=c[2433592]|0;r=c[s+(t*3148|0)+1068>>2]|0;q=(i&255)<<8;if((r|0)!=0){z=r;A=q;B=t;C=s;u=68177;break}r=c[s+(t*3148|0)+3120>>2]|0;if((r|0)==0){v=0;w=q;x=t;y=s;break}s=gj[r&4095](-1)|0;v=s;w=q;x=c[3528554]|0;y=c[2433592]|0}else{z=j;A=d[j+254|0]<<8;B=l;C=k;u=68177}}while(0);if((u|0)==68177){v=a[z+255|0]|0;w=A;x=B;y=C}C=v&255|w;c[2415188]=C;b[4830376]=C&65535;C=y+(x*3148|0)|0;if((C|0)!=0){y=C;gGC(y|0,9660752,48)|0}c[9731360+(x<<2)>>2]=c[2113158];c[3528554]=-1;mx(0);a[999424]=0;a[14113440]=0;a[9542224]=0}a[9550930]=-1;a[9550929]=-1;a[9550928]=-1;x=0;y=-1;C=-1;w=-1;do{y=((a[9634328+x|0]&1)<<x^y&255)&255;C=((a[9632088+x|0]&1)<<x^C&255)&255;w=((a[9630008+x|0]&1)<<x^w&255)&255;x=x+1|0;}while((x|0)<8);a[9550928]=y;a[9550929]=C;a[9550930]=w;if((C&3)==0){y=C|3;a[9550929]=y;D=y}else{D=C}if((D&12)==0){a[9550929]=D|12}if((w&3)==0){D=w|3;a[9550930]=D;E=D}else{E=w}if((E&12)==0){a[9550930]=E|12}E=0;w=0;D=0;C=0;y=c[2433592]|0;while(1){c[3528554]=0;f43(y);c[2113158]=c[9731360+(c[3528554]<<2)>>2];x=D+1|0;v=f45(((x*25e3|0|0)/10|0)-w|0)|0;c[2113158]=(c[2113158]|0)+v;if((D|0)==9){f44(0);f45(0)|0;a[9660786]=0;f45(0)|0}B=c[3528554]|0;A=c[2433592]|0;z=A+(B*3148|0)|0;if((z|0)!=0){u=z;gGC(u|0,9660752,48)|0}c[9731360+(B<<2)>>2]=c[2113158];c[3528554]=1;f43(A+3148|0);c[2113158]=c[9731360+(c[3528554]<<2)>>2];if(a[999424]|0){f44(0);f45(0)|0;a[9660786]=0;f45(0)|0;a[999424]=0}A=f45(((x*33333|0|0)/10|0)-E|0)|0;c[2113158]=(c[2113158]|0)+A;B=c[2112964]|0;if((B|0)==0){F=C}else{u=a[9688]|0?53:0;gg[c[3542124]&4095](B+(C<<1<<1)|0,u);F=u+C|0}u=c[3528554]|0;G=c[2433592]|0;B=G+(u*3148|0)|0;if((B|0)!=0){z=B;gGC(z|0,9660752,48)|0}c[9731360+(u<<2)>>2]=c[2113158];c[3528554]=-1;if((x|0)<10){E=A+E|0;w=v+w|0;D=x;C=F;y=G}else{break}}y=c[2112964]|0;do{if((y|0)!=0){C=a[9688]|0?534:0;if((C|0)==(F|0)){break}c[3528554]=1;f43(G+3148|0);c[2113158]=c[9731360+(c[3528554]<<2)>>2];gg[c[3542124]&4095](y+(F<<1<<1)|0,C-F|0);C=c[3528554]|0;D=(c[2433592]|0)+(C*3148|0)|0;if((D|0)!=0){w=D;gGC(w|0,9660752,48)|0}c[9731360+(C<<2)>>2]=c[2113158];c[3528554]=-1}}while(0);if((c[2112968]|0)==0){return 0}bjK()|0;return 0}function bjK(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;if((a[9547968]|0)!=0){b=c[3527462]|0;e=c[2407002]|0;f=c[3530176]|0;g=0;do{h=c[e+(d[b+g|0]<<2)>>2]|0;c[f+(g<<2)>>2]=h>>8<<3&2016|h>>>3&31|h>>16<<8&63488;g=g+1|0;}while((g|0)<4096)}g=d[9750813]|0;f=g>>>4&3;b=(d[9750812]|0)>>>4;e=d[9750810]|0;h=40-(d[9750808]|0)|0;i=(g&3)+2|0;j=(g>>>2&3)+1|0;k=(g>>>6)-1|0;g=b<<1^16777215;l=c[2387990]|0;m=c[2387966]|0;n=c[2112926]|0;o=c[3530700]|0;if((c[2430187]|0)==0){p=0;while(1){q=(p<<3&248)+h|0;r=(p>>5<<3)-e|0;s=d[l+p|0]|0;Sj(n,((s>>>(i>>>0)&2|s>>>7|s>>>(j>>>0)&4|s>>>(f>>>0)&8|s>>>(k>>>0)&16|d[9750811]<<5&32)&g|(d[9750804]&b)<<1)<<8|d[m+p|0],(q|0)<-7?q+296|0:q,((r|0)<-7?r+256|0:r)-16|0,s&7|d[9750814]<<1&96|16,4,2048,o);s=p+1|0;if((s|0)<1024){p=s}else{t=o;u=n;break}}}else{p=0;while(1){s=(p<<3&248)+h|0;r=(p>>5<<3)-e|0;q=d[l+p|0]|0;Sp(n,((q>>>(i>>>0)&2|q>>>7|q>>>(j>>>0)&4|q>>>(f>>>0)&8|q>>>(k>>>0)&16|d[9750811]<<5&32)&g|(d[9750804]&b)<<1)<<8|d[m+p|0],272-((s|0)<-7?s+296|0:s)|0,240-((r|0)<-7?r+256|0:r)|0,q&7|d[9750814]<<1&96|16,4,2048,o);q=p+1|0;if((q|0)<1024){p=q}else{t=o;u=n;break}}}n=d[9750805]|0;o=n>>>4&3;p=a[9750804]|0;m=(p&255)>>>4;b=d[9750802]|0;g=40-(d[9750800]|0)|0;k=(n&3)+2|0;f=(n>>>2&3)+1|0;j=(n>>>6)-1|0;n=m<<1^16777215;i=c[2387854]|0;l=c[2387848]|0;e=c[3530936]|0;L88330:do{if((c[2430186]|0)==0){h=0;q=p;while(1){r=(h<<3&248)+g|0;s=(h>>5<<3)-b|0;v=d[i+h|0]|0;Sr(u,((v>>>(k>>>0)&2|v>>>7|v>>>(f>>>0)&4|v>>>(o>>>0)&8|v>>>(j>>>0)&16|d[9750803]<<5&32)&n|(q&255&m)<<1)<<8|d[l+h|0],(r|0)<-7?r+296|0:r,((s|0)<-7?s+256|0:s)-16|0,v&7|d[9750806]<<1&96|16,4,0,0,e);v=h+1|0;if((v|0)>=1024){w=e;break L88330}h=v;q=a[9750804]|0}}else{q=0;h=p;while(1){v=(q<<3&248)+g|0;s=(q>>5<<3)-b|0;r=d[i+q|0]|0;Sx(u,((r>>>(k>>>0)&2|r>>>7|r>>>(f>>>0)&4|r>>>(o>>>0)&8|r>>>(j>>>0)&16|d[9750803]<<5&32)&n|(h&255&m)<<1)<<8|d[l+q|0],272-((v|0)<-7?v+296|0:v)|0,240-((s|0)<-7?s+256|0:s)|0,r&7|d[9750806]<<1&96|16,4,0,0,e);r=q+1|0;if((r|0)>=1024){w=e;break L88330}q=r;h=a[9750804]|0}}}while(0);bjZ(0,w,0);bjZ(1,t,2048);t=d[9750805]|0;e=t>>>4&3;l=(t&3)+2|0;m=(t>>>2&3)+1|0;n=(t>>>6)-1|0;t=c[2386342]|0;j=c[2386340]|0;if((c[2430186]|0)==0){o=64;do{f=o<<3&248;if(f>>>0<=39){k=d[t+o|0]|0;Si(u,(k>>>(l>>>0)&2|k>>>7|k>>>(m>>>0)&4|k>>>(e>>>0)&8|k>>>(n>>>0)&16)<<8|d[j+o|0],f,(o>>5<<3)-16|0,k&7|d[9750806]<<1&96|16,4,0,w)}o=o+1|0;}while((o|0)<960);x=c[3530176]|0;R8(x);return 0}else{o=64;do{k=o<<3&248;if(k>>>0<=39){f=d[t+o|0]|0;Sp(u,(f>>>(l>>>0)&2|f>>>7|f>>>(m>>>0)&4|f>>>(e>>>0)&8|f>>>(n>>>0)&16)<<8|d[j+o|0],(k^248)+24|0,(o>>5<<3^248)-16|0,f&7|d[9750806]<<1&96|16,4,0,w)}o=o+1|0;}while((o|0)<960);x=c[3530176]|0;R8(x);return 0}return 0}function bjL(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;f=i;i=i+192|0;g=f|0;h=f+16|0;j=f+32|0;k=f+48|0;l=f+64|0;m=f+80|0;n=f+96|0;o=f+112|0;p=f+128|0;q=f+144|0;r=f+160|0;s=f+176|0;if((e|0)!=0){c[e>>2]=169622}if((b&96|0)!=0){e=s;gGz(e|0,0,12);t=c[2414798]|0;u=s|0;c[u>>2]=t;v=s+4|0;c[v>>2]=(c[2411858]|0)-t;t=s+12|0;c[t>>2]=196728;w=c[2076592]|0;gj[w&4095](s)|0;gGz(e|0,0,12);c[u>>2]=9750800;c[v>>2]=16;c[t>>2]=140432;t=c[2076592]|0;gj[t&4095](s)|0}if((b&64|0)==0){i=f;return 0}s=n|0;if((c[2113160]|0)>0){t=n+7|0;n=m|0;v=m+4|0;u=m+12|0;e=l;w=l|0;x=l+4|0;y=l+12|0;z=k;A=k|0;B=k+4|0;C=k+12|0;D=j;E=j|0;F=j+4|0;G=j+12|0;H=0;do{I=c[2433592]|0;J=I+(H*3148|0)+40|0;K=c[J>>2]|0;gGC(s|0,614752,9)|0;a[t]=H+48&255;c[n>>2]=I+(H*3148|0);c[v>>2]=48;c[u>>2]=s;gj[c[2076592]&4095](m)|0;gGz(e|0,0,12);c[w>>2]=I+(H*3148|0)+3136;c[x>>2]=4;c[y>>2]=165288;gj[c[2076592]&4095](l)|0;gGz(z|0,0,12);c[A>>2]=I+(H*3148|0)+3140;c[B>>2]=4;c[C>>2]=501592;gj[c[2076592]&4095](k)|0;gGz(D|0,0,12);c[E>>2]=I+(H*3148|0)+3144;c[F>>2]=4;c[G>>2]=386080;gj[c[2076592]&4095](j)|0;c[J>>2]=K;H=H+1|0;}while((H|0)<(c[2113160]|0))}gGz(h|0,0,12);c[h>>2]=8453216;c[h+4>>2]=4;c[h+12>>2]=107480;gj[c[2076592]&4095](h)|0;gGz(g|0,0,12);c[g>>2]=14168504;c[g+4>>2]=256;c[g+12>>2]=476464;gj[c[2076592]&4095](g)|0;g=(b&2|0)==0;if(!g){b=0;do{mv(0,b,d[14168504+b|0]|0);b=b+1|0;}while((b|0)<256)}gGz(r|0,0,12);c[r>>2]=9720744;c[r+4>>2]=4;c[r+12>>2]=137888;gj[c[2076592]&4095](r)|0;gGz(q|0,0,12);c[q>>2]=9720748;c[q+4>>2]=4;c[q+12>>2]=135264;gj[c[2076592]&4095](q)|0;gGz(p|0,0,12);c[p>>2]=14113440;c[p+4>>2]=1;c[p+12>>2]=191240;gj[c[2076592]&4095](p)|0;gGz(o|0,0,12);c[o>>2]=9542224;c[o+4>>2]=1;c[o+12>>2]=131088;gj[c[2076592]&4095](o)|0;if(g){i=f;return 0}c[3528554]=0;f43(c[2433592]|0);g=c[3528554]|0;o=9731360+(g<<2)|0;p=c[o>>2]|0;c[2113158]=p;q=a[9542224]&15;a[9542224]=q;r=(q&255)<<13;if((r+65536|0)>>>0<163840){q=c[2443526]|0;b=c[2433592]|0;h=r+40960|0;r=96;H=96;while(1){j=q+(h+(H<<8))|0;c[b+(g*3148|0)+48+(H<<2)>>2]=j;c[b+(g*3148|0)+48+(H+512<<2)>>2]=j;j=r+1&65535;if((j&65535)>127){L=b;break}else{r=j;H=j&65535}}}else{L=c[2433592]|0}H=L+(g*3148|0)|0;if((H|0)!=0){g=H;gGC(g|0,9660752,48)|0}c[o>>2]=p;c[3528554]=-1;i=f;return 0}function bjM(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4775956+(b*112|0)>>2];c[a+104>>2]=c[4775960+(b*112|0)>>2];c[a+108>>2]=c[4775964+(b*112|0)>>2];d=0;return d|0}function bjN(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=4775856+(b*112|0);e=0;return e|0}function bjO(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4773380+(b*112|0)>>2];c[a+104>>2]=c[4773384+(b*112|0)>>2];c[a+108>>2]=c[4773388+(b*112|0)>>2];d=0;return d|0}function bjP(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=4773280+(b*112|0);e=0;return e|0}function bjQ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4772036+(b*112|0)>>2];c[a+104>>2]=c[4772040+(b*112|0)>>2];c[a+108>>2]=c[4772044+(b*112|0)>>2];d=0;return d|0}function bjR(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=4771936+(b*112|0);e=0;return e|0}function bjS(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1589708+(b*112|0)>>2];c[a+104>>2]=c[1589712+(b*112|0)>>2];c[a+108>>2]=c[1589716+(b*112|0)>>2];d=0;return d|0}function bjT(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<22&(d|0)==0)){e=1;return e|0}c[a>>2]=1589608+(b*112|0);e=0;return e|0}function bjU(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5877628+(b*112|0)>>2];c[a+104>>2]=c[5877632+(b*112|0)>>2];c[a+108>>2]=c[5877636+(b*112|0)>>2];d=0;return d|0}function bjV(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=5877528+(b*112|0);e=0;return e|0}function bjW(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=62){if((a|0)==0){d=0;return d|0}e=a;f=7448960+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}f=b-63|0;if(f>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;a=5551640+(f*12|0)|0;c[b>>2]=c[a>>2];c[b+4>>2]=c[a+4>>2];c[b+8>>2]=c[a+8>>2];d=0;return d|0}function bjX(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4688140+(b*112|0)>>2];c[a+104>>2]=c[4688144+(b*112|0)>>2];c[a+108>>2]=c[4688148+(b*112|0)>>2];d=0;return d|0}function bjY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=4688040+(b*112|0);e=0;return e|0}function bjZ(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;g=d[9750806+(b<<3)|0]<<1&96;h=(b|0)!=0?c[2443772]|0:c[2443774]|0;i=(c[3527462]|0)==0;j=i?14:0;k=i?15:1;l=i?6:2;m=i?4:3;n=i?8:4;o=i?-32:5;p=(c[9720744+(b<<2)>>2]|0)==0;b=c[2112926]|0;q=0;r=i?h+2016|0:h;while(1){h=d[r+k|0]|0;s=d[r+m|0]|0;t=a[r+l|0]|0;u=t&255;v=d[r+n|0]|0;w=h>>>4|g;x=v&16;y=v&32;z=(v&1|0)==0?s:s|-256;s=(t&255)>239?u|-256:u;u=(h<<8&768|d[r+j|0]|v<<4&3072)<<2;t=u|h>>>2&3;if(i){if((a[r]|0)!=0){A=68345}}else{A=68345}if((A|0)==68345){A=0;h=v&14;if((h|0)==4){B=2;C=1;D=t&16381}else if((h|0)==0){B=2;C=2;D=u}else if((h|0)==2){B=1;C=2;D=t&16382}else if((h|0)==8){B=4;C=4;D=u}else{B=1;C=1;D=t}t=(x|0)!=0;x=C-1|0;u=(y|0)!=0;y=B-1|0;h=z+40|0;v=s-16|0;E=232-z|0;z=232-s|0;s=0;do{F=v+(s<<3)|0;G=(s*-8|0)+z|0;H=(c[607944+((u?y-s|0:s)<<2)>>2]|0)+D|0;I=0;do{J=H+(c[607960+((t?x-I|0:I)<<2)>>2]|0)|0;do{if(p){K=h+(I<<3)|0;if(u){if(t){Sx(b,J,K,F,w,4,0,f,e);break}else{Sv(b,J,K,F,w,4,0,f,e);break}}else{if(t){St(b,J,K,F,w,4,0,f,e);break}else{Sr(b,J,K,F,w,4,0,f,e);break}}}else{K=(I*-8|0)+E|0;if(u){if(t){Sr(b,J,K,G,w,4,0,f,e);break}else{St(b,J,K,G,w,4,0,f,e);break}}else{if(t){Sv(b,J,K,G,w,4,0,f,e);break}else{Sx(b,J,K,G,w,4,0,f,e);break}}}}while(0);I=I+1|0;}while((I|0)<(C|0));s=s+1|0;}while((s|0)<(B|0))}s=q+1|0;if((s|0)<64){q=s;r=r+o|0}else{break}}return}function bj_(b){b=b|0;if((b|0)==0){a[9660787]=0;return}else{f44(1);return}}function bj$(b,d){b=b|0;d=d|0;var e=0,f=0;e=b&65535;switch(e|0){case 16:{c[2440220]=d&4;a[14108544]=d&32;return};case 48:case 49:{TO(e&1,d);return};case 32:{return};case 64:{a[14125144]=-1;a[9706117]=1;return};default:{b=e&65520;if((b|0)==512){a[14108592+(e&15)|0]=d;return}else if((b|0)==768){b=e&15;a[14108504+b|0]=d;if((b|0)!=6){return}b=c[3529058]|0;f=c[3529054]|0;gGC(b|0,f|0,2048)|0;return}else{f=e&63488;if((f|0)==4096){a[(c[3529054]|0)+(e&2047^1)|0]=d;return}else if((f|0)==2048){a[(c[3529076]|0)+(e&2047)|0]=d;bi2(e&1023,0);return}else{return}}}}}function bj0(b){b=b|0;var e=0,f=0,g=0;e=b&65535;switch(e|0){case 48:case 49:{c[2426862]=9674384;f=c[9674388+((e&1|2)<<2)>>2]&255;return f|0};case 97:{f=127;return f|0};case 83:{f=a[9635656]|0;return f|0};case 82:{f=a[9635658]&15|a[9550922]&-16;return f|0};case 81:{f=a[9550921]|0;return f|0};case 96:{f=a[9635657]|0;return f|0};case 80:{f=a[9550920]|0;return f|0};case 32:{f=0;return f|0};default:{if((e&65520|0)==768){b=e&15;do{if((a[14108509]&16)!=0){if((e&12|0)!=12){break}f=a[(c[3529056]|0)+(((c[3527134]<<19|e&3|(d[14108515]|0)<<18&1835008|(d[14108512]|0)<<10|(d[14108513]|0)<<2)^1)&c[3527124])|0]|0;return f|0}}while(0);if((b|0)!=6){f=0;return f|0}b=c[3529058]|0;g=c[3529054]|0;gGC(b|0,g|0,2048)|0;f=0;return f|0}g=e&63488;if((g|0)==2048){b=e&2047;if((c[2440220]|0)==0){f=a[(c[3529076]|0)+b|0]|0;return f|0}if((a[14108606]&1)!=0){f=0;return f|0}f=a[(c[3529080]|0)+(((d[14108604]|0)<<11|b|(d[14108605]|0)<<19)>>>(((c[2443318]|0)<5|0)>>>0)&c[3527144])|0]|0;return f|0}else if((g|0)==4096){f=a[(c[3529054]|0)+(e&2047^1)|0]|0;return f|0}else{f=0;return f|0}}}return 0}function bj1(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0;f=b&65535;if((f|0)==49152|(f|0)==49153){g=c[3540984]|0;if((f&1|0)==0){a[g+5885|0]=e;return}h=c[g+5876>>2]|0;if((h|0)!=0){gg[h&4095](c[g+5880>>2]|0,0)}lH(g,d[g+5885|0]|0,e&255);return}else if((f|0)==64512){if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){g=gfc(100)|0;i=(c[2433530]|0)+g|0}else{i=(c[2433530]|0)+100|0}c[2433530]=i;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12;return}else{if((b+24576&65535)>=48){return}TO(f&63,e);return}}function bj2(b){b=b|0;var d=0,e=0,f=0,g=0;d=b&65535;if((d-49152|0)>>>0<2){e=lx(c[3540984]|0,d&1)|0|6;return e|0}if((b+24576&65535)>=48){e=0;return e|0}if((d&62|0)==0){a[9706117]=0}b=d&63;c[2426862]=9674384;if((b|0)==46){f=68463}else if((b|0)==41){e=(c[2418664]<<1|c[2418653]|c[2418675]<<2|c[2418686]<<3)&255;return e|0}do{if((f|0)==68463){if((c[2418596]&1|0)==0){break}d=c[2418655]|0;g=(d>>>16)+(c[2418650]|0)+(c[2418651]<<16)|0;c[2418655]=d+65536;if(g>>>0>(c[2418646]|0)>>>0){e=0;return e|0}e=a[(c[2418645]|0)+g|0]|0;return e|0}}while(0);e=c[9674388+(b<<2)>>2]&255;return e|0}function bj3(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4445052+(b*112|0)>>2];c[a+104>>2]=c[4445056+(b*112|0)>>2];c[a+108>>2]=c[4445060+(b*112|0)>>2];d=0;return d|0}function bj4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=4444952+(b*112|0);e=0;return e|0}function bj5(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1748800+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function bj6(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>57){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5095040+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function bj7(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;e=i;i=i+840|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;c[2415088]=0;c[2387376]=0;c[2385998]=196608;c[3530934]=262144;c[3530698]=2359296;c[2439902]=2883584;c[2439866]=7077888;c[2386690]=8126464;c[2407e3]=8650752;c[3530174]=8654848;c[2414796]=8658944;c[2387400]=8658944;c[2387270]=8665856;c[2386150]=8667904;c[2394766]=8669952;c[2411856]=8669953;v=0;while(1){if((v|0)>=1024){break}w=9638528+(v<<2)|0;if((c[w>>2]|0)==0){x=68503;break}else{v=v+1|0}}do{if((x|0)==68503){v=gGq(8669953)|0;c[w>>2]=v;if((v|0)==0){break}c[2415088]=v;gGz(v|0,0,8669953);c[2387376]=v;c[2385998]=v+196608;c[3530934]=v+262144;c[3530698]=v+2359296;c[2439902]=v+2883584;c[2439866]=v+7077888;c[2386690]=v+8126464;c[2407e3]=v+8650752;c[3530174]=v+8654848;y=v+8658944|0;c[2414796]=y;c[2387400]=y;c[2387270]=v+8665856;c[2386150]=v+8667904;c[2394766]=v+8669952;y=v+8669953|0;c[2411856]=y;c[2414406]=y;y=v+65536|0;if((c[3542200]|0)==0){z=1;i=e;return z|0}v=t+108|0;c[v>>2]=0;A=t+100|0;c[A>>2]=0;B=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[B&16383](t,0)|0;do{if((c[v>>2]|0)!=0){B=c[A>>2]|0;c[u>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](u,0,0)|0;if((B|0)<1){z=1;i=e;return z|0}if((gzL(y,0,0)|0)==0){break}else{z=1}i=e;return z|0}}while(0);y=c[2387376]|0;A=y+32768|0;v=y+163840|0;gGC(A|0,v|0,32768)|0;v=c[2385998]|0;if((c[3542200]|0)==0){z=1;i=e;return z|0}A=r+108|0;c[A>>2]=0;y=r+100|0;c[y>>2]=0;B=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[B&16383](r,1)|0;do{if((c[A>>2]|0)!=0){B=c[y>>2]|0;c[s>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](s,1,0)|0;if((B|0)<1){z=1;i=e;return z|0}if((gzL(v,0,1)|0)==0){break}else{z=1}i=e;return z|0}}while(0);v=c[3530934]|0;if((c[3542200]|0)==0){z=1;i=e;return z|0}y=p+108|0;c[y>>2]=0;A=p+100|0;c[A>>2]=0;B=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[B&16383](p,2)|0;do{if((c[y>>2]|0)!=0){B=c[A>>2]|0;c[q>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](q,2,0)|0;if((B|0)<1){z=1;i=e;return z|0}if((gzL(v,0,2)|0)==0){break}else{z=1}i=e;return z|0}}while(0);v=(c[3530934]|0)+1048576|0;if((c[3542200]|0)==0){z=1;i=e;return z|0}A=n+108|0;c[A>>2]=0;y=n+100|0;c[y>>2]=0;B=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[B&16383](n,3)|0;do{if((c[A>>2]|0)!=0){B=c[y>>2]|0;c[o>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](o,3,0)|0;if((B|0)<1){z=1;i=e;return z|0}if((gzL(v,0,3)|0)==0){break}else{z=1}i=e;return z|0}}while(0);v=c[3530698]|0;if((c[3542200]|0)==0){z=1;i=e;return z|0}y=l+108|0;c[y>>2]=0;A=l+100|0;c[A>>2]=0;B=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[B&16383](l,4)|0;do{if((c[y>>2]|0)!=0){B=c[A>>2]|0;c[m>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](m,4,0)|0;if((B|0)<1){z=1;i=e;return z|0}if((gzL(v,0,4)|0)==0){break}else{z=1}i=e;return z|0}}while(0);v=(c[3530698]|0)+262144|0;if((c[3542200]|0)==0){z=1;i=e;return z|0}A=j+108|0;c[A>>2]=0;y=j+100|0;c[y>>2]=0;B=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[B&16383](j,5)|0;do{if((c[A>>2]|0)!=0){B=c[y>>2]|0;c[k>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](k,5,0)|0;if((B|0)<1){z=1;i=e;return z|0}if((gzL(v,0,5)|0)==0){break}else{z=1}i=e;return z|0}}while(0);v=c[2386690]|0;if((c[3542200]|0)==0){z=1;i=e;return z|0}y=f+108|0;c[y>>2]=0;A=f+100|0;c[A>>2]=0;B=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[B&16383](f,6)|0;do{if((c[y>>2]|0)!=0){B=c[A>>2]|0;c[g>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](g,6,0)|0;if((B|0)<1){z=1;i=e;return z|0}if((gzL(v,0,6)|0)==0){break}else{z=1}i=e;return z|0}}while(0);v=c[3530934]|0;blG(v,1048576);A=c[2439902]|0;y=0;do{B=y<<8;gGz(A+B|0,0,256);C=y<<10;D=0;do{E=1<<3-D;F=(c[611632+(D<<2)>>2]|0)+C|0;G=0;do{H=F+(c[3946808+(G<<2)>>2]|0)|0;I=(G<<4)+B|0;J=0;do{K=H+(c[6669416+(J<<2)>>2]|0)|0;if(((d[v+((K|0)/8|0)|0]|0)&128>>>((K&7)>>>0)|0)!=0){K=A+(I+J)|0;a[K]=(d[K]|0|E)&255}J=J+1|0;}while((J|0)<16);G=G+1|0;}while((G|0)<16);D=D+1|0;}while((D|0)<4);y=y+1|0;}while((y|0)<16384);c[2410674]=1748;gGz(9699632,0,3072);y=c[2427044]|0;c[9681616+(y<<3)>>2]=715288;c[9681620+(y<<3)>>2]=0;c[2427044]=y+1;c[363094]=0;y=c[2387270]|0;c[2424932]=y;c[2425188]=y;c[2425444]=y;A=y+256|0;c[2424933]=A;c[2425189]=A;c[2425445]=A;A=y+512|0;c[2424934]=A;c[2425190]=A;c[2425446]=A;A=y+768|0;c[2424935]=A;c[2425191]=A;c[2425447]=A;A=y+1024|0;c[2424936]=A;c[2425192]=A;c[2425448]=A;A=y+1280|0;c[2424937]=A;c[2425193]=A;c[2425449]=A;A=y+1536|0;c[2424938]=A;c[2425194]=A;c[2425450]=A;A=y+1792|0;c[2424939]=A;c[2425195]=A;c[2425451]=A;A=c[2387400]|0;y=0;v=0;while(1){D=v+32|0;B=A+(v<<8)|0;c[9699632+(D<<2)>>2]=B;c[9700656+(D<<2)>>2]=B;c[9701680+(D<<2)>>2]=B;B=y+1&65535;if((B&65535)<27){y=B;v=B&65535}else{break}}v=c[2387376]|0;y=0;A=0;while(1){B=A+64|0;D=v+((A<<8)+16384)|0;c[9699632+(B<<2)>>2]=D;c[9701680+(B<<2)>>2]=D;D=y+1&65535;if((D&65535)<64){y=D;A=D&65535}else{L=0;M=0;break}}while(1){A=M+128|0;y=v+((M<<8)+32768)|0;c[9699632+(A<<2)>>2]=y;c[9701680+(A<<2)>>2]=y;y=L+1&65535;if((y&65535)<128){L=y;M=y&65535}else{break}}c[2444172]=1386;c[3528598]=328;c[2410675]=1188;c[363094]=-1;fwR(0);v=c[2439330]|0;y=(v|0)==0;if(!y){A=v;gGC(9706056,A|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];A=c[3528484]|0;c[2076596]=A;D=c[2417276]|0;c[3541536]=D;c[1836236]=0;B=c[2385998]|0;C=0;G=0;while(1){c[v+76+(G<<2)>>2]=B+(G<<8);E=C+1&65535;if((E&65535)>127){N=0;O=0;break}else{C=E;G=E&65535}}while(1){G=B+(O<<8)|0;c[v+76+(O+512<<2)>>2]=G;c[v+76+(O+768<<2)>>2]=G;G=N+1&65535;if((G&65535)>127){break}else{N=G;O=G&65535}}B=c[2386150]|0;c[v+588>>2]=B;G=B+256|0;c[v+592>>2]=G;C=B+512|0;c[v+596>>2]=C;E=B+768|0;c[v+600>>2]=E;F=B+1024|0;c[v+604>>2]=F;J=B+1280|0;c[v+608>>2]=J;I=B+1536|0;c[v+612>>2]=I;H=B+1792|0;c[v+616>>2]=H;c[v+1612>>2]=B;c[v+1616>>2]=G;c[v+1620>>2]=C;c[v+1624>>2]=E;c[v+1628>>2]=F;c[v+1632>>2]=J;c[v+1636>>2]=I;c[v+1640>>2]=H;c[v+2636>>2]=B;c[v+3660>>2]=B;c[v+2640>>2]=G;c[v+3664>>2]=G;c[v+2644>>2]=C;c[v+3668>>2]=C;c[v+2648>>2]=E;c[v+3672>>2]=E;c[v+2652>>2]=F;c[v+3676>>2]=F;c[v+2656>>2]=J;c[v+3680>>2]=J;c[v+2660>>2]=I;c[v+3684>>2]=I;c[v+2664>>2]=H;c[v+3688>>2]=H;c[v+4184>>2]=1728;c[v+4180>>2]=2200;if(!y){H=v;gGC(H|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=A;c[2417276]=D;c[1836236]=-1;biH(c[3530934]|0,2097151,62);c[3529052]=-112;c[3529050]=17;bi1(0,c[3530698]|0,c[2439866]|0,524287,100);c[3527138]=-90;c[3527139]=-15;UL(3579545,0,2818,0);c[2438224]=3579545;c[2433522]=3416;c[2406672]=1752;c[3528468]=9362;c[2443842]=571;h[745398]=1.0;a[3203264]=1;TN(c[2386690]|0,524288);h[1209346]=.7;c[2418696]=3;c[2426862]=9674384;h[1209347]=.7;c[2418697]=3;H=c[642608+(c[2436]<<2)>>2]|0;I=c[H+128>>2]|0;if((c[H+52>>2]&4|0)==0){c[2113068]=I;J=c[H+132>>2]|0;c[2113070]=J;c[2443814]=I;c[2440436]=J;P=I;Q=J}else{c[2113070]=I;J=c[H+132>>2]|0;c[2113068]=J;c[2440436]=I;c[2443814]=J;P=J;Q=I}I=ag(P<<1,Q)|0;J=gGq(I)|0;c[2112926]=J;if((J|0)!=0){gGz(J|0,0,I|0)}a[9624968]=0;I=c[2414796]|0;gGz(I|0,0,(c[2411856]|0)-I|0);c[363094]=0;c[2410673]=0;a[9642688]=0;a[9642689]=0;a[9642682]=0;a[9642683]=0;c[2410665]=0;a[9642680]=a[9642680]|80;I=c[2425163]|0;do{if((I|0)==0){J=c[3528598]|0;if((J|0)==0){R=0;S=0;break}H=gj[J&4095](-2)|0;J=c[2425163]|0;F=(H&255)<<8;if((J|0)!=0){T=J;U=F;x=68564;break}J=c[3528598]|0;if((J|0)==0){R=0;S=F;break}R=gj[J&4095](-1)|0;S=F}else{T=I;U=(d[I+254|0]|0)<<8;x=68564}}while(0);if((x|0)==68564){R=a[T+255|0]|0;S=U}c[2410662]=R&255|S;c[363094]=-1;I=c[2439330]|0;D=(I|0)==0;if(!D){A=I;gGC(9706056,A|0,76)|0}A=c[2438118]|0;c[2433530]=A;v=c[3528484]|0;c[2076596]=v;y=c[2417276]|0;c[3541536]=y;c[1836236]=0;gGz(9706056,0,76);if(!D){D=I;gGC(D|0,9706056,76)|0}c[2438118]=A;c[3528484]=v;c[2417276]=y;c[1836236]=-1;c[2426862]=9674384;gGz(9674592,0,176);c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;lw(c[3540984]|0);blH();c[2440220]=0;z=0;i=e;return z|0}}while(0);c[2415088]=0;z=1;i=e;return z|0}function bj8(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}blI();c[2444172]=0;c[3528598]=0;fwZ();b=a[7452584]|0;if(b){d=0;e=b&1;while(1){b=14163936+(d<<2)|0;f=c[b>>2]|0;g=c[2113006]|0;if((g|0)==0){h=68602}else{i=g-1|0;c[2113006]=i;if((i|0)==0){h=68602}}if((h|0)==68602){h=0;c[2383474]=0}if((f|0)==0){j=e}else{gGr(f);j=a[7452584]&1}c[b>>2]=0;b=d+1|0;if((b|0)<(j|0)){d=b;e=j}else{break}}}a[7452584]=0;c[2438224]=0;c[2433522]=0;c[2406672]=0;c[3528468]=0;j=c[2406688]|0;if((j|0)!=0){gGr(j);c[2406688]=0}c[2432972]=0;c[2426862]=9674384;j=c[2418647]|0;if((j|0)!=0){gGr(j);c[(c[2426862]|0)+204>>2]=0}c[2426862]=9674792;j=c[2418749]|0;if((j|0)!=0){gGr(j);c[(c[2426862]|0)+204>>2]=0}c[2443782]=0;j=c[2415088]|0;e=0;while(1){if((e|0)>=1024){h=68617;break}k=9638528+(e<<2)|0;if((c[k>>2]|0)==(j|0)){break}else{e=e+1|0}}if((h|0)==68617){c[2415088]=0;return 0}gGr(j);c[k>>2]=0;c[2415088]=0;return 0}function bj9(){var e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;if((a[9624968]|0)!=0){a[9624968]=0;e=c[2414796]|0;gGz(e|0,0,(c[2411856]|0)-e|0);c[363094]=0;c[2410673]=0;a[9642688]=0;a[9642689]=0;a[9642682]=0;a[9642683]=0;c[2410665]=0;a[9642680]=a[9642680]|80;e=c[2425163]|0;do{if((e|0)==0){f=c[3528598]|0;if((f|0)==0){g=0;i=0;break}j=gj[f&4095](-2)|0;f=c[2425163]|0;k=(j&255)<<8;if((f|0)!=0){l=f;m=k;n=68624;break}f=c[3528598]|0;if((f|0)==0){g=0;i=k;break}g=gj[f&4095](-1)|0;i=k}else{l=e;m=d[e+254|0]<<8;n=68624}}while(0);if((n|0)==68624){g=a[l+255|0]|0;i=m}c[2410662]=g&255|i;c[363094]=-1;i=c[2439330]|0;g=(i|0)==0;if(!g){m=i;gGC(9706056,m|0,76)|0}m=c[2438118]|0;c[2433530]=m;l=c[3528484]|0;c[2076596]=l;n=c[2417276]|0;c[3541536]=n;c[1836236]=0;gGz(9706056,0,76);if(!g){g=i;gGC(g|0,9706056,76)|0}c[2438118]=m;c[3528484]=l;c[2417276]=n;c[1836236]=-1;c[2426862]=9674384;gGz(9674592,0,176);c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;lw(c[3540984]|0);blH();c[2440220]=0}n=c[2385548]|0;if((n|0)>0){gGz(9752472,0,((n|0)>1?n<<2:4)|0)}c[2433530]=0;c[2410673]=0;gGz(9550920,-1|0,3);n=0;l=-1;m=-1;g=-1;do{l=((a[9634320+n|0]&1)<<n^l&255)&255;m=((a[9632080+n|0]&1)<<n^m&255)&255;g=((a[963e4+n|0]&1)<<n^g&255)&255;n=n+1|0;}while((n|0)<8);a[9550920]=l;a[9550921]=m;a[9550922]=g;if((l&24)==0){g=l|24;a[9550920]=g;o=g}else{o=l}if((o&96)==0){a[9550920]=o|96}if((m&24)==0){o=m|24;a[9550921]=o;p=o}else{p=m}if((p&96)==0){a[9550921]=p|96}p=a[9688]|0;m=p?534:0;o=c[2439330]|0;if((o|0)!=0){l=o;gGC(9706056,l|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;c[363094]=0;if(p){p=0;l=0;while(1){o=p+1|0;g=(fNF(((o*5e4|0|0)/534|0)-l|0)|0)+l|0;UF(p*111|0)|0;if((o|0)<(m|0)){p=o;l=g}else{break}}}fNE(0,1);fNF(0)|0;a[9642682]=0;fNF(0)|0;l=c[2438224]|0;p=gGS(-1597636608,28447,l,(l|0)<0|0?-1:0)|0;l=p;UF(59659)|0;p=c[2443826]|0;if((p|0)<1073676288){c[2443826]=p-l}p=c[2443827]|0;if((p|0)<1073676288){c[2443827]=p-l}p=(c[3528508]|0)-l|0;c[3528508]=(p|0)<0?0:p;p=c[2112964]|0;if((p|0)!=0){gg[c[3542112]&4095](p,a[9688]|0?534:0);TM(c[2112964]|0,a[9688]|0?534:0)}c[363094]=-1;p=c[1836236]|0;l=c[9757320+(p<<2)>>2]|0;if((l|0)!=0){m=l;gGC(m|0,9706056,76)|0}c[9752472+(p<<2)>>2]=c[2433530];c[14113936+(p<<2)>>2]=c[2076596];c[9669104+(p<<2)>>2]=c[3541536];c[1836236]=-1;if((c[2112968]|0)==0){return 0}bka()|0;return 0}function bka(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if((a[9547960]|0)!=0){d=c[2387270]|0;e=c[3530174]|0;f=c[2407e3]|0;g=0;do{h=ga(b[d+(g<<1)>>1]|0)|0;i=h&255;j=((i&255)>>>2&7|i<<3)&255;i=((h&65535)>>>5<<3&255|(h&65535)>>>7&7)&255;k=((h&65535)>>>10<<3&255|(h&65535)>>>12&7)&255;c[e+(g<<2)>>2]=i<<3&2016|k>>>3|j<<8&63488;c[f+(g<<2)>>2]=i<<8|k|j<<16;g=g+1|0;}while((g|0)<1024)}g=ag(c[2113070]|0,c[2113068]|0)|0;if((g|0)>0){f=c[2112926]|0;e=0;do{b[f+(e<<1)>>1]=256;e=e+1|0;}while((e|0)<(g|0))}biI(c[2439902]|0,0);bi3(0);biI(c[2439902]|0,16);blK(c[2407e3]|0,c[3530174]|0);return 0}function bkb(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;i=i+80|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;if((b|0)!=0){c[b>>2]=169733}if((a&96|0)!=0){gGz(k|0,0,12);l=c[2414796]|0;c[k>>2]=l;c[k+4>>2]=(c[2411856]|0)-l;c[k+12>>2]=162152;l=c[2076592]|0;gj[l&4095](k)|0;k=c[2410674]|0;l=c[2410675]|0;if((a&64|0)!=0){gGz(h|0,0,12);c[h>>2]=9642648;c[h+4>>2]=56;c[h+12>>2]=163840;m=c[2076592]|0;gj[m&4095](h)|0;gGz(g|0,0,12);c[g>>2]=9707480;c[g+4>>2]=2;c[g+12>>2]=501096;h=c[2076592]|0;gj[h&4095](g)|0;gGz(f|0,0,12);c[f>>2]=9707480;c[f+4>>2]=4;c[f+12>>2]=385184;g=c[2076592]|0;gj[g&4095](f)|0}c[2410674]=k;c[2410675]=l;fw$(a);UQ(a,b);TP(a);blJ(a);gGz(j|0,0,12);c[j>>2]=9760880;c[j+4>>2]=4;c[j+12>>2]=104912;b=c[2076592]|0;gj[b&4095](j)|0}if((a&2|0)==0){i=e;return 0}c[363094]=0;a=((d[c[2394766]|0]|0)<<14&114688)+65536|0;j=c[2387376]|0;b=0;l=0;while(1){k=l+64|0;f=j+(a+(l<<8))|0;c[9699632+(k<<2)>>2]=f;c[9701680+(k<<2)>>2]=f;f=b+1&65535;if((f&65535)<64){b=f;l=f&65535}else{break}}c[363094]=-1;i=e;return 0}function bkc(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2371212+(b*112|0)>>2];c[a+104>>2]=c[2371216+(b*112|0)>>2];c[a+108>>2]=c[2371220+(b*112|0)>>2];d=0;return d|0}function bkd(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=2371112+(b*112|0);e=0;return e|0}function bke(b){b=b|0;var d=0,e=0,f=0,g=0,h=0;a[c[2394766]|0]=b&255;d=(b<<14&114688)+65536|0;b=c[2387376]|0;e=0;f=0;while(1){g=f+64|0;h=b+(d+(f<<8))|0;c[9699632+(g<<2)>>2]=h;c[9701680+(g<<2)>>2]=h;h=e+1&65535;if((h&65535)<64){e=h;f=h&65535}else{break}}return}function bkf(a,b,d){a=a|0;b=b|0;d=d|0;c[d>>2]=c[b>>2]&16;c[b>>2]=c[b>>2]&15|16;return}function bkg(a,b,d){a=a|0;b=b|0;d=d|0;c[d>>2]=(c[b>>2]|0)>>>6&3;c[a>>2]=c[b>>2]<<8&3840|c[a>>2];c[b>>2]=(c[b>>2]|0)>>>4&3;return}function bkh(a){a=a|0;var b=0,d=0;b=(c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,3579545,0)|0;return a|0}function bki(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=b&65535;do{if((b&65535)<449){f=e>>>6&7;if((f|0)==1){a[9706117]=1;break}else if((f|0)==2){a[c[3528358]|0]=d;break}else if((f|0)==0){if(!(b<<16>>16==0&(c[3525076]|0)!=0)){break}f44(1);f45(0)|0;a[9660787]=0;f45(0)|0;break}else if((f|0)==3){f=d&255;a[c[2443956]|0]=d;g=(f<<9&65536)+65536|f<<13&57344;c[2439326]=f&8;f=c[2387374]|0;h=0;i=0;while(1){j=i+96|0;k=f+((i<<8)+g)|0;c[9699632+(j<<2)>>2]=k;c[9701680+(j<<2)>>2]=k;k=h+1&65535;if((k&65535)<32){h=k;i=k&65535}else{break}}}else{break}}}while(0);if((e&65528|0)!=2048){if((e&64512|0)!=3072){return}a[(c[3529066]|0)+(e&1023)|0]=d;return}b=e&7;if((b|0)==0){e=d&255;c[3541236]=e&1;c[3541234]=e&4;c[3541232]=e&8;c[3541238]=e&32;return}e=b-2|0;if(e>>>0>=3){return}a[9718032+e|0]=d;return}function bkj(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;e=i;i=i+32|0;f=e|0;g=e+8|0;h=e+16|0;j=e+24|0;k=b&65535;do{if((b&65535)<449){l=k>>>6&7;if((l|0)==7){m=a[9635650]|0;break}else if((l|0)==4){m=a[9550914]|0;break}else if((l|0)==0){m=c[2410673]&255;break}else if((l|0)==6){l=k&3;if((l|0)==3){m=a[9635649]|0;break}else if((l|0)==1){m=a[9550913]|0;break}else if((l|0)==0){m=a[9550912]|0;break}else if((l|0)==2){m=a[9635648]|0;break}else{m=0;break}}else{n=68730;break}}else{n=68730}}while(0);do{if((n|0)==68730){if((k&65528|0)==2048){m=bpm(k&7)|0;break}if((k&64512|0)!=3072){m=0;break}if((c[3541238]|0)!=0){b=k>>>2&255;c[2433420]=b;l=d[9718033]|0;c[f>>2]=((d[9718032]|0)<<8|b|l<<16)>>>5&8191;b=(d[9718034]|0)<<6;c[g>>2]=b&192|l>>>2;c[h>>2]=0;c[j>>2]=b&128;gL[c[2437694]&255](f,g,h,j)}m=a[(c[3529066]|0)+(k&1023)|0]|0}}while(0);i=e;return m|0}function bkk(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=b&65535;if((e&63488|0)==0){a[(c[3529076]|0)+(e&2047)|0]=d;bi2(e&1023,0);return}if((e&65520|0)==2048){a[14108592+(e&15)|0]=d;return}if(b<<16>>16==6144){a[(c[2443956]|0)+1|0]=d;b=d&255;c[3541230]=b&64;a[14108544]=d&32;c[3525076]=b&16;f=c[3527398]|0;g=c[3528554]|0;h=c[2433592]|0;i=(b<<13&122880)+32768|0;b=128;j=128;while(1){k=f+(i+(j<<8))|0;c[h+(g*3148|0)+48+(j<<2)>>2]=k;c[h+(g*3148|0)+48+(j+512<<2)>>2]=k;k=b+1&65535;if((k&65535)>159){break}else{b=k;j=k&65535}}return}if((e&49152|0)!=16384){return}j=e&16383;a[(c[3529062]|0)+j|0]=d;if((e&6144)>>>0<=6143){return}if((j|0)==7296){a[9729904]=d;return}else if((j|0)==7424){c[3541228]=d&4;return}else if((j|0)==7936){a[9720738]=d&15;a[9720739]=(d&255)>>>4;return}else if((j|0)==7552){a[9720736]=d&15;a[9720737]=(d&255)>>>4;return}else if((j|0)==7680|(j|0)==15872){a[9730680]=d;return}else if((j|0)==7808){c[2432672]=(d&255)>>>1&3;return}else{return}}function bkl(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;e=i;i=i+24|0;f=e|0;g=e+8|0;h=e+16|0;j=b&65535;b=j&63488;if((b|0)==0){k=a[(c[3529076]|0)+(j&2047)|0]|0;i=e;return k|0}else if((b|0)==4096){if((a[14108606]&1)!=0){k=0;i=e;return k|0}k=a[(c[3529080]|0)+(((d[14108604]|0)<<11|j&2047|(d[14108605]|0)<<19)>>>(((c[2443318]|0)<5|0)>>>0)&c[3527144])|0]|0;i=e;return k|0}else{if((j&49152|0)!=16384){k=0;i=e;return k|0}if((c[3541230]|0)==0){k=a[(c[3529062]|0)+(j&16383)|0]|0;i=e;return k|0}c[f>>2]=0;b=j>>>5&255;c[g>>2]=b;l=d[9730680]|0;c[h>>2]=l;m=l>>>2&3;if((c[2429638]|0)==0){gB[c[2437692]&127](0,((a[9718936+m|0]|a[9720736+m|0])&255)>>>2,g,h,f,f);n=c[g>>2]|0}else{f=l<<8|b;c[g>>2]=f;n=f}k=a[(c[3529060]|0)+((n<<5|j&31)&c[2438700])|0]|0;i=e;return k|0}return 0}function bkm(b,d){b=b|0;d=d|0;var e=0;e=b&65535;b=e&65520;if((b|0)==40960){TI(0,e&15,d&255);return}else if((b|0)==45056){TI(1,e&15,d&255);return}else{if((e|0)==49153){b=c[2113304]|0;a[14168504+b|0]=d;mv(0,b,d&255);return}else if((e|0)==36864){b=d&255;c[2420315]=b>>>1<<17&131072;c[2420316]=b<<17&131072;c[2424878]=9681296;c[2420331]=b>>>4<<17&393216;c[2420332]=b>>>2<<17&393216;return}else if((e|0)==49152){c[2113304]=d&255;return}else if((e|0)==47116){c[2424878]=9681296;e=((d&15)*17|0)>>>1&255;a[9681296]=e;a[9681297]=e;return}else{return}}}function bkn(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;e=b&65535;b=e&65520;if((b|0)==40960){f=e&15;c[2424878]=9681232;c[2426622]=9622928;if(!((f|0)==11|(f|0)==5)){g=0;return g|0}h=(f>>>0)/6|0;f=h*6|0;i=(d[f+9681280|0]|0)<<16&65536|(d[f+9681279|0]|0)<<8|(d[f+9681278|0]|0)|c[9681260+(h<<2)>>2];c[9681244+(h<<2)>>2]=i;if(i>>>0>=(c[2405735]|0)>>>0){g=0;return g|0}c[9681268+(h<<2)>>2]=1;c[9681236+(h<<2)>>2]=0;g=0;return g|0}else if((b|0)==45056){b=e&15;c[2424878]=9681296;c[2426622]=9622976;if(!((b|0)==11|(b|0)==5)){g=0;return g|0}h=(b>>>0)/6|0;b=h*6|0;i=(d[b+9681344|0]|0)<<16&65536|(d[b+9681343|0]|0)<<8|(d[b+9681342|0]|0)|c[9681324+(h<<2)>>2];c[9681308+(h<<2)>>2]=i;if(i>>>0>=(c[2405747]|0)>>>0){g=0;return g|0}c[9681332+(h<<2)>>2]=1;c[9681300+(h<<2)>>2]=0;g=0;return g|0}else{if((e|0)==49152|(e|0)==49153){g=c[(c[3531464]|0)+4240>>2]&255;return g|0}else if((e|0)==57344){a[9706117]=0;g=a[c[3528358]|0]|0;return g|0}else{g=0;return g|0}}return 0}function bko(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>43){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7077628+(b*112|0)>>2];c[a+104>>2]=c[7077632+(b*112|0)>>2];c[a+108>>2]=c[7077636+(b*112|0)>>2];d=0;return d|0}function bkp(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<44&(d|0)==0)){e=1;return e|0}c[a>>2]=7077528+(b*112|0);e=0;return e|0}function bkq(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6444400+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function bkr(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>62){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7321008+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function bks(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0;e=i;i=i+3240|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;B=e+1200|0;C=e+1312|0;D=e+1320|0;E=e+1432|0;F=e+1440|0;G=e+1552|0;H=e+1560|0;I=e+1672|0;J=e+1680|0;K=e+1792|0;L=e+1800|0;M=e+1912|0;N=e+1920|0;O=e+2032|0;P=e+2040|0;Q=e+2152|0;R=e+2160|0;S=e+2272|0;T=e+2280|0;U=e+2392|0;V=e+2400|0;W=e+2512|0;X=e+2520|0;Y=e+2632|0;Z=e+2640|0;_=e+2752|0;$=e+2760|0;aa=e+2872|0;ab=e+2880|0;ac=e+2992|0;ad=e+3e3|0;ae=e+3112|0;af=e+3120|0;ah=e+3232|0;c[2415086]=0;c[2387374]=0;c[3527398]=196608;c[2385996]=393216;c[3530932]=458752;c[3530696]=983040;c[3530486]=2031616;c[2439900]=2555904;c[2439864]=3604480;c[3529774]=5701632;c[3529728]=5963776;c[3530172]=6488064;c[2414794]=6496256;c[3527316]=6496256;c[2387398]=6504448;c[2387268]=6512640;c[2386148]=6520832;c[3528358]=6522880;c[2443956]=6522881;c[2411854]=6522883;ai=0;while(1){if((ai|0)>=1024){break}aj=9638528+(ai<<2)|0;if((c[aj>>2]|0)==0){ak=68849;break}else{ai=ai+1|0}}do{if((ak|0)==68849){ai=gGq(6522883)|0;c[aj>>2]=ai;if((ai|0)==0){break}c[2415086]=ai;gGz(ai|0,0,6522883);c[2387374]=ai;c[3527398]=ai+196608;c[2385996]=ai+393216;c[3530932]=ai+458752;c[3530696]=ai+983040;c[3530486]=ai+2031616;c[2439900]=ai+2555904;c[2439864]=ai+3604480;c[3529774]=ai+5701632;c[3529728]=ai+5963776;c[3530172]=ai+6488064;al=ai+6496256|0;c[2414794]=al;c[3527316]=al;c[2387398]=ai+6504448;c[2387268]=ai+6512640;c[2386148]=ai+6520832;c[3528358]=ai+6522880;c[2443956]=ai+6522881;al=ai+6522883|0;c[2411854]=al;c[2414404]=al;al=ai+131072|0;if((c[3542200]|0)==0){am=1;i=e;return am|0}ai=af+108|0;c[ai>>2]=0;an=af+100|0;c[an>>2]=0;ao=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ao&16383](af,0)|0;do{if((c[ai>>2]|0)!=0){ao=c[an>>2]|0;c[ah>>2]=9534384;ap=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ap&16383](ah,0,0)|0;if((ao|0)<1){am=1;i=e;return am|0}if((gzL(al,0,0)|0)==0){break}else{am=1}i=e;return am|0}}while(0);al=(c[2387374]|0)+65536|0;if((c[3542200]|0)==0){am=1;i=e;return am|0}an=ad+108|0;c[an>>2]=0;ai=ad+100|0;c[ai>>2]=0;ao=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ao&16383](ad,1)|0;do{if((c[an>>2]|0)!=0){ao=c[ai>>2]|0;c[ae>>2]=9534384;ap=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ap&16383](ae,1,0)|0;if((ao|0)<1){am=1;i=e;return am|0}if((gzL(al,0,1)|0)==0){break}else{am=1}i=e;return am|0}}while(0);al=c[2387374]|0;ai=al+32768|0;an=al+163840|0;gGC(ai|0,an|0,32768)|0;an=(c[3527398]|0)+131072|0;if((c[3542200]|0)==0){am=1;i=e;return am|0}ai=ab+108|0;c[ai>>2]=0;al=ab+100|0;c[al>>2]=0;ao=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ao&16383](ab,2)|0;do{if((c[ai>>2]|0)!=0){ao=c[al>>2]|0;c[ac>>2]=9534384;ap=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ap&16383](ac,2,0)|0;if((ao|0)<1){am=1;i=e;return am|0}if((gzL(an,0,2)|0)==0){break}else{am=1}i=e;return am|0}}while(0);an=c[3527398]|0;al=an+40960|0;ai=an+139264|0;gGC(al|0,ai|0,24576)|0;ai=an+65536|0;if((c[3542200]|0)==0){am=1;i=e;return am|0}an=$+108|0;c[an>>2]=0;al=$+100|0;c[al>>2]=0;ao=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ao&16383]($,3)|0;do{if((c[an>>2]|0)!=0){ao=c[al>>2]|0;c[aa>>2]=9534384;ap=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ap&16383](aa,3,0)|0;if((ao|0)<1){am=1;i=e;return am|0}if((gzL(ai,0,3)|0)==0){break}else{am=1}i=e;return am|0}}while(0);ai=c[2385996]|0;if((c[3542200]|0)==0){am=1;i=e;return am|0}al=Z+108|0;c[al>>2]=0;an=Z+100|0;c[an>>2]=0;ao=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ao&16383](Z,4)|0;do{if((c[al>>2]|0)!=0){ao=c[an>>2]|0;c[_>>2]=9534384;ap=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ap&16383](_,4,0)|0;if((ao|0)<1){am=1;i=e;return am|0}if((gzL(ai,0,4)|0)==0){break}else{am=1}i=e;return am|0}}while(0);ai=c[642608+(c[2436]<<2)>>2]|0;an=(fa(c[ai>>2]|0,526896)|0)==0;al=c[3530932]|0;do{if(an){if((R6(al,5,2)|0)!=0){am=1;i=e;return am|0}if((R6((c[3530932]|0)+1|0,6,2)|0)!=0){am=1;i=e;return am|0}if((R6((c[3530932]|0)+131072|0,7,2)|0)!=0){am=1;i=e;return am|0}if((R6((c[3530932]|0)+131073|0,8,2)|0)!=0){am=1;i=e;return am|0}if((R6((c[3530932]|0)+262144|0,9,2)|0)!=0){am=1;i=e;return am|0}if((R6((c[3530932]|0)+262145|0,10,2)|0)!=0){am=1;i=e;return am|0}if((R6((c[3530932]|0)+393216|0,11,2)|0)!=0){am=1;i=e;return am|0}if((R6((c[3530932]|0)+393217|0,12,2)|0)!=0){am=1;i=e;return am|0}if((R6(c[3530696]|0,13,2)|0)!=0){am=1;i=e;return am|0}if((R6((c[3530696]|0)+1|0,14,2)|0)!=0){am=1;i=e;return am|0}if((R6((c[3530696]|0)+131072|0,15,2)|0)!=0){am=1;i=e;return am|0}if((R6((c[3530696]|0)+131073|0,16,2)|0)!=0){am=1;i=e;return am|0}if((R6((c[3530696]|0)+262144|0,17,2)|0)!=0){am=1;i=e;return am|0}if((R6((c[3530696]|0)+262145|0,18,2)|0)!=0){am=1;i=e;return am|0}if((R6((c[3530696]|0)+393216|0,19,2)|0)!=0){am=1;i=e;return am|0}if((R6((c[3530696]|0)+393217|0,20,2)|0)!=0){am=1;i=e;return am|0}if((R6((c[3530696]|0)+524288|0,21,2)|0)!=0){am=1;i=e;return am|0}if((R6((c[3530696]|0)+524289|0,22,2)|0)!=0){am=1;i=e;return am|0}if((R6((c[3530696]|0)+655360|0,23,2)|0)!=0){am=1;i=e;return am|0}if((R6((c[3530696]|0)+655361|0,24,2)|0)!=0){am=1;i=e;return am|0}if((R6((c[3530696]|0)+786432|0,25,2)|0)!=0){am=1;i=e;return am|0}if((R6((c[3530696]|0)+786433|0,26,2)|0)!=0){am=1;i=e;return am|0}if((R6((c[3530696]|0)+917504|0,27,2)|0)!=0){am=1;i=e;return am|0}if((R6((c[3530696]|0)+917505|0,28,2)|0)!=0){am=1;i=e;return am|0}ao=c[3530486]|0;if((c[3542200]|0)==0){am=1;i=e;return am|0}ap=X+108|0;c[ap>>2]=0;aq=X+100|0;c[aq>>2]=0;ar=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ar&16383](X,29)|0;do{if((c[ap>>2]|0)!=0){ar=c[aq>>2]|0;c[Y>>2]=9534384;as=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[as&16383](Y,29,0)|0;if((ar|0)<1){am=1;i=e;return am|0}if((gzL(ao,0,29)|0)==0){break}else{am=1}i=e;return am|0}}while(0);ao=(c[3530486]|0)+262144|0;if((c[3542200]|0)==0){am=1;i=e;return am|0}aq=V+108|0;c[aq>>2]=0;ap=V+100|0;c[ap>>2]=0;ar=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ar&16383](V,30)|0;do{if((c[aq>>2]|0)!=0){ar=c[ap>>2]|0;c[W>>2]=9534384;as=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[as&16383](W,30,0)|0;if((ar|0)<1){am=1;i=e;return am|0}if((gzL(ao,0,30)|0)==0){break}else{am=1}i=e;return am|0}}while(0);ao=c[3529774]|0;if((c[3542200]|0)==0){am=1;i=e;return am|0}ap=T+108|0;c[ap>>2]=0;aq=T+100|0;c[aq>>2]=0;ar=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ar&16383](T,31)|0;do{if((c[ap>>2]|0)!=0){ar=c[aq>>2]|0;c[U>>2]=9534384;as=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[as&16383](U,31,0)|0;if((ar|0)<1){am=1;i=e;return am|0}if((gzL(ao,0,31)|0)==0){break}else{am=1}i=e;return am|0}}while(0);ao=(c[3529774]|0)+65536|0;if((c[3542200]|0)==0){am=1;i=e;return am|0}aq=R+108|0;c[aq>>2]=0;ap=R+100|0;c[ap>>2]=0;ar=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ar&16383](R,32)|0;do{if((c[aq>>2]|0)!=0){ar=c[ap>>2]|0;c[S>>2]=9534384;as=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[as&16383](S,32,0)|0;if((ar|0)<1){am=1;i=e;return am|0}if((gzL(ao,0,32)|0)==0){break}else{am=1}i=e;return am|0}}while(0);ao=(c[3529774]|0)+131072|0;if((c[3542200]|0)==0){am=1;i=e;return am|0}ap=P+108|0;c[ap>>2]=0;aq=P+100|0;c[aq>>2]=0;ar=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ar&16383](P,33)|0;do{if((c[ap>>2]|0)!=0){ar=c[aq>>2]|0;c[Q>>2]=9534384;as=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[as&16383](Q,33,0)|0;if((ar|0)<1){am=1;i=e;return am|0}if((gzL(ao,0,33)|0)==0){break}else{am=1}i=e;return am|0}}while(0);ao=(c[3529774]|0)+196608|0;if((c[3542200]|0)==0){am=1;i=e;return am|0}aq=N+108|0;c[aq>>2]=0;ap=N+100|0;c[ap>>2]=0;ar=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ar&16383](N,34)|0;do{if((c[aq>>2]|0)!=0){ar=c[ap>>2]|0;c[O>>2]=9534384;as=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[as&16383](O,34,0)|0;if((ar|0)<1){am=1;i=e;return am|0}if((gzL(ao,0,34)|0)==0){break}else{am=1}i=e;return am|0}}while(0);ao=c[3529728]|0;if((c[3542200]|0)==0){am=1;i=e;return am|0}ap=L+108|0;c[ap>>2]=0;aq=L+100|0;c[aq>>2]=0;ar=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ar&16383](L,35)|0;do{if((c[ap>>2]|0)!=0){ar=c[aq>>2]|0;c[M>>2]=9534384;as=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[as&16383](M,35,0)|0;if((ar|0)<1){am=1;i=e;return am|0}if((gzL(ao,0,35)|0)==0){break}else{am=1}i=e;return am|0}}while(0);ao=(c[3529728]|0)+65536|0;if((c[3542200]|0)==0){am=1;i=e;return am|0}aq=J+108|0;c[aq>>2]=0;ap=J+100|0;c[ap>>2]=0;ar=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ar&16383](J,36)|0;do{if((c[aq>>2]|0)!=0){ar=c[ap>>2]|0;c[K>>2]=9534384;as=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[as&16383](K,36,0)|0;if((ar|0)<1){am=1;i=e;return am|0}if((gzL(ao,0,36)|0)==0){break}else{am=1}i=e;return am|0}}while(0);ao=(c[3529728]|0)+131072|0;if((c[3542200]|0)==0){am=1;i=e;return am|0}ap=H+108|0;c[ap>>2]=0;aq=H+100|0;c[aq>>2]=0;ar=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ar&16383](H,37)|0;do{if((c[ap>>2]|0)!=0){ar=c[aq>>2]|0;c[I>>2]=9534384;as=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[as&16383](I,37,0)|0;if((ar|0)<1){am=1;i=e;return am|0}if((gzL(ao,0,37)|0)==0){break}else{am=1}i=e;return am|0}}while(0);ao=(c[3529728]|0)+196608|0;if((c[3542200]|0)==0){am=1;i=e;return am|0}aq=F+108|0;c[aq>>2]=0;ap=F+100|0;c[ap>>2]=0;ar=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ar&16383](F,38)|0;do{if((c[aq>>2]|0)!=0){ar=c[ap>>2]|0;c[G>>2]=9534384;as=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[as&16383](G,38,0)|0;if((ar|0)<1){am=1;i=e;return am|0}if((gzL(ao,0,38)|0)==0){break}else{am=1}i=e;return am|0}}while(0);ao=(c[3529728]|0)+262144|0;if((c[3542200]|0)==0){am=1;i=e;return am|0}ap=D+108|0;c[ap>>2]=0;aq=D+100|0;c[aq>>2]=0;ar=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ar&16383](D,39)|0;do{if((c[ap>>2]|0)!=0){ar=c[aq>>2]|0;c[E>>2]=9534384;as=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[as&16383](E,39,0)|0;if((ar|0)<1){am=1;i=e;return am|0}if((gzL(ao,0,39)|0)==0){break}else{am=1}i=e;return am|0}}while(0);ao=(c[3529728]|0)+327680|0;if((c[3542200]|0)==0){am=1;i=e;return am|0}aq=B+108|0;c[aq>>2]=0;ap=B+100|0;c[ap>>2]=0;ar=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ar&16383](B,40)|0;do{if((c[aq>>2]|0)!=0){ar=c[ap>>2]|0;c[C>>2]=9534384;as=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[as&16383](C,40,0)|0;if((ar|0)<1){am=1;i=e;return am|0}if((gzL(ao,0,40)|0)==0){break}else{am=1}i=e;return am|0}}while(0);ao=(c[3529728]|0)+393216|0;if((c[3542200]|0)==0){am=1;i=e;return am|0}ap=z+108|0;c[ap>>2]=0;aq=z+100|0;c[aq>>2]=0;ar=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ar&16383](z,41)|0;do{if((c[ap>>2]|0)!=0){ar=c[aq>>2]|0;c[A>>2]=9534384;as=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[as&16383](A,41,0)|0;if((ar|0)<1){am=1;i=e;return am|0}if((gzL(ao,0,41)|0)==0){break}else{am=1}i=e;return am|0}}while(0);ao=(c[3529728]|0)+458752|0;if((c[3542200]|0)==0){am=1;i=e;return am|0}aq=x+108|0;c[aq>>2]=0;ap=x+100|0;c[ap>>2]=0;ar=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ar&16383](x,42)|0;if((c[aq>>2]|0)==0){break}aq=c[ap>>2]|0;c[y>>2]=9534384;ap=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ap&16383](y,42,0)|0;if((aq|0)<1){am=1;i=e;return am|0}if((gzL(ao,0,42)|0)==0){break}else{am=1}i=e;return am|0}else{if((c[3542200]|0)==0){am=1;i=e;return am|0}ao=v+108|0;c[ao>>2]=0;aq=v+100|0;c[aq>>2]=0;ap=c[ai+76>>2]|0;gA[ap&16383](v,5)|0;do{if((c[ao>>2]|0)!=0){ap=c[aq>>2]|0;c[w>>2]=9534384;ar=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ar&16383](w,5,0)|0;if((ap|0)<1){am=1;i=e;return am|0}if((gzL(al,0,5)|0)==0){break}else{am=1}i=e;return am|0}}while(0);aq=(c[3530932]|0)+262144|0;if((c[3542200]|0)==0){am=1;i=e;return am|0}ao=t+108|0;c[ao>>2]=0;ap=t+100|0;c[ap>>2]=0;ar=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ar&16383](t,6)|0;do{if((c[ao>>2]|0)!=0){ar=c[ap>>2]|0;c[u>>2]=9534384;as=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[as&16383](u,6,0)|0;if((ar|0)<1){am=1;i=e;return am|0}if((gzL(aq,0,6)|0)==0){break}else{am=1}i=e;return am|0}}while(0);aq=c[3530696]|0;if((c[3542200]|0)==0){am=1;i=e;return am|0}ap=r+108|0;c[ap>>2]=0;ao=r+100|0;c[ao>>2]=0;ar=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ar&16383](r,7)|0;do{if((c[ap>>2]|0)!=0){ar=c[ao>>2]|0;c[s>>2]=9534384;as=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[as&16383](s,7,0)|0;if((ar|0)<1){am=1;i=e;return am|0}if((gzL(aq,0,7)|0)==0){break}else{am=1}i=e;return am|0}}while(0);aq=(c[3530696]|0)+524288|0;if((c[3542200]|0)==0){am=1;i=e;return am|0}ao=p+108|0;c[ao>>2]=0;ap=p+100|0;c[ap>>2]=0;ar=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ar&16383](p,8)|0;do{if((c[ao>>2]|0)!=0){ar=c[ap>>2]|0;c[q>>2]=9534384;as=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[as&16383](q,8,0)|0;if((ar|0)<1){am=1;i=e;return am|0}if((gzL(aq,0,8)|0)==0){break}else{am=1}i=e;return am|0}}while(0);aq=c[3530486]|0;if((c[3542200]|0)==0){am=1;i=e;return am|0}ap=n+108|0;c[ap>>2]=0;ao=n+100|0;c[ao>>2]=0;ar=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ar&16383](n,9)|0;do{if((c[ap>>2]|0)!=0){ar=c[ao>>2]|0;c[o>>2]=9534384;as=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[as&16383](o,9,0)|0;if((ar|0)<1){am=1;i=e;return am|0}if((gzL(aq,0,9)|0)==0){break}else{am=1}i=e;return am|0}}while(0);aq=(c[3530486]|0)+262144|0;if((c[3542200]|0)==0){am=1;i=e;return am|0}ao=l+108|0;c[ao>>2]=0;ap=l+100|0;c[ap>>2]=0;ar=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ar&16383](l,10)|0;do{if((c[ao>>2]|0)!=0){ar=c[ap>>2]|0;c[m>>2]=9534384;as=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[as&16383](m,10,0)|0;if((ar|0)<1){am=1;i=e;return am|0}if((gzL(aq,0,10)|0)==0){break}else{am=1}i=e;return am|0}}while(0);aq=c[3529774]|0;if((c[3542200]|0)==0){am=1;i=e;return am|0}ap=j+108|0;c[ap>>2]=0;ao=j+100|0;c[ao>>2]=0;ar=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ar&16383](j,11)|0;do{if((c[ap>>2]|0)!=0){ar=c[ao>>2]|0;c[k>>2]=9534384;as=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[as&16383](k,11,0)|0;if((ar|0)<1){am=1;i=e;return am|0}if((gzL(aq,0,11)|0)==0){break}else{am=1}i=e;return am|0}}while(0);aq=c[3529728]|0;if((c[3542200]|0)==0){am=1;i=e;return am|0}ao=f+108|0;c[ao>>2]=0;ap=f+100|0;c[ap>>2]=0;ar=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ar&16383](f,12)|0;if((c[ao>>2]|0)==0){break}ao=c[ap>>2]|0;c[g>>2]=9534384;ap=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ap&16383](g,12,0)|0;if((ao|0)<1){am=1;i=e;return am|0}if((gzL(aq,0,12)|0)==0){break}else{am=1}i=e;return am|0}}while(0);al=c[3530932]|0;blG(al,262144);ai=c[3530696]|0;blG(ai,524288);an=c[2439900]|0;aq=0;do{ao=aq<<6;gGz(an+ao|0,0,64);ap=aq<<8;ar=0;do{as=1<<3-ar;at=(c[611632+(ar<<2)>>2]|0)+ap|0;au=0;do{av=at+(c[3946808+(au<<2)>>2]|0)|0;aw=(au<<3)+ao|0;ax=0;do{ay=av+(c[6669416+(ax<<2)>>2]|0)|0;if(((d[al+((ay|0)/8|0)|0]|0)&128>>>((ay&7)>>>0)|0)!=0){ay=an+(aw+ax)|0;a[ay]=(d[ay]|0|as)&255}ax=ax+1|0;}while((ax|0)<8);au=au+1|0;}while((au|0)<8);ar=ar+1|0;}while((ar|0)<4);aq=aq+1|0;}while((aq|0)<16384);aq=c[2439864]|0;an=0;do{al=an<<8;gGz(aq+al|0,0,256);ar=an<<10;ao=0;do{ap=1<<3-ao;au=(c[611400+(ao<<2)>>2]|0)+ar|0;as=0;do{at=au+(c[3946808+(as<<2)>>2]|0)|0;ax=(as<<4)+al|0;aw=0;do{av=at+(c[6669416+(aw<<2)>>2]|0)|0;if(((d[ai+((av|0)/8|0)|0]|0)&128>>>((av&7)>>>0)|0)!=0){av=aq+(ax+aw)|0;a[av]=(d[av]|0|ap)&255}aw=aw+1|0;}while((aw|0)<16);as=as+1|0;}while((as|0)<16);ao=ao+1|0;}while((ao|0)<4);an=an+1|0;}while((an|0)<8192);c[2410674]=1748;gGz(9699632,0,3072);an=c[2427044]|0;c[9681616+(an<<3)>>2]=715288;c[9681620+(an<<3)>>2]=0;c[2427044]=an+1;c[363094]=0;an=c[2387268]|0;aq=0;ai=0;while(1){ao=ai+16|0;al=an+(ai<<8)|0;c[9699632+(ao<<2)>>2]=al;c[9700656+(ao<<2)>>2]=al;c[9701680+(ao<<2)>>2]=al;al=aq+1&65535;if((al&65535)<16){aq=al;ai=al&65535}else{break}}ai=c[3527316]|0;aq=0;an=0;while(1){al=an+32|0;ao=ai+(an<<8)|0;c[9699632+(al<<2)>>2]=ao;c[9700656+(al<<2)>>2]=ao;c[9701680+(al<<2)>>2]=ao;ao=aq+1&65535;if((ao&65535)<32){aq=ao;an=ao&65535}else{break}}an=c[2387398]|0;aq=0;ai=0;while(1){ao=ai+64|0;al=an+(ai<<8)|0;c[9699632+(ao<<2)>>2]=al;c[9700656+(ao<<2)>>2]=al;c[9701680+(ao<<2)>>2]=al;al=aq+1&65535;if((al&65535)<32){aq=al;ai=al&65535}else{break}}ai=c[2387374]|0;aq=0;an=0;while(1){al=an+96|0;ao=ai+((an<<8)+65536)|0;c[9699632+(al<<2)>>2]=ao;c[9701680+(al<<2)>>2]=ao;ao=aq+1&65535;if((ao&65535)<32){aq=ao;an=ao&65535}else{az=0;aA=0;break}}while(1){an=aA+128|0;aq=ai+((aA<<8)+32768)|0;c[9699632+(an<<2)>>2]=aq;c[9701680+(an<<2)>>2]=aq;aq=az+1&65535;if((aq&65535)<128){az=aq;aA=aq&65535}else{break}}c[2444172]=1126;c[3528598]=2454;c[363094]=-1;c[3528554]=-1;c[2113160]=1;ai=gGq(3148)|0;aq=ai;c[2433592]=aq;if((ai|0)!=0){gGz(ai|0,0,3148);c[ai+3120>>2]=3128;c[ai+3124>>2]=1840;c[ai+3128>>2]=136;c[ai+3132>>2]=1902;c[2432840]=0;an=0;do{c[aq+48+(an<<2)>>2]=0;an=an+1|0;}while((an|0)<768);c[2113158]=0;c[2415198]=0;an=c[2427044]|0;c[9681616+(an<<3)>>2]=809272;c[9681620+(an<<3)>>2]=0;c[2427044]=an+1}c[3528554]=0;f43(ai);an=c[3528554]|0;aq=9731360+(an<<2)|0;ao=c[aq>>2]|0;c[2113158]=ao;al=c[3527316]|0;ar=c[2433592]|0;as=32;ap=32;while(1){au=al+((ap<<8)-8192)|0;c[ar+(an*3148|0)+48+(ap<<2)>>2]=au;c[ar+(an*3148|0)+48+(ap+256<<2)>>2]=au;c[ar+(an*3148|0)+48+(ap+512<<2)>>2]=au;au=as+1&65535;if((au&65535)>63){break}else{as=au;ap=au&65535}}ap=c[3527398]|0;as=128;al=128;while(1){ai=ap+((al<<8)+32768)|0;c[ar+(an*3148|0)+48+(al<<2)>>2]=ai;c[ar+(an*3148|0)+48+(al+512<<2)>>2]=ai;ai=as+1&65535;if((ai&65535)>159){aB=160;aC=160;break}else{as=ai;al=ai&65535}}while(1){al=ap+(aC<<8)|0;c[ar+(an*3148|0)+48+(aC<<2)>>2]=al;c[ar+(an*3148|0)+48+(aC+512<<2)>>2]=al;al=aB+1&65535;if((al&65535)>255){break}else{aB=al;aC=al&65535}}c[ar+(an*3148|0)+3124>>2]=2212;c[ar+(an*3148|0)+3120>>2]=3250;ap=ar+(an*3148|0)|0;if((ap|0)!=0){al=ap;gGC(al|0,9660752,48)|0}c[aq>>2]=ao;c[3528554]=-1;fwR(0);al=c[2439330]|0;ap=(al|0)==0;if(!ap){as=al;gGC(9706056,as|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];as=c[3528484]|0;c[2076596]=as;ai=c[2417276]|0;c[3541536]=ai;c[1836236]=0;au=c[2385996]|0;aw=0;ax=0;while(1){c[al+76+(ax<<2)>>2]=au+(ax<<8);at=aw+1&65535;if((at&65535)>127){aD=0;aE=0;break}else{aw=at;ax=at&65535}}while(1){ax=au+(aE<<8)|0;c[al+76+(aE+512<<2)>>2]=ax;c[al+76+(aE+768<<2)>>2]=ax;ax=aD+1&65535;if((ax&65535)>127){break}else{aD=ax;aE=ax&65535}}au=c[2386148]|0;c[al+588>>2]=au;ax=au+256|0;c[al+592>>2]=ax;aw=au+512|0;c[al+596>>2]=aw;ao=au+768|0;c[al+600>>2]=ao;aq=au+1024|0;c[al+604>>2]=aq;an=au+1280|0;c[al+608>>2]=an;ar=au+1536|0;c[al+612>>2]=ar;at=au+1792|0;c[al+616>>2]=at;c[al+1612>>2]=au;c[al+1616>>2]=ax;c[al+1620>>2]=aw;c[al+1624>>2]=ao;c[al+1628>>2]=aq;c[al+1632>>2]=an;c[al+1636>>2]=ar;c[al+1640>>2]=at;c[al+2636>>2]=au;c[al+3660>>2]=au;c[al+2640>>2]=ax;c[al+3664>>2]=ax;c[al+2644>>2]=aw;c[al+3668>>2]=aw;c[al+2648>>2]=ao;c[al+3672>>2]=ao;c[al+2652>>2]=aq;c[al+3676>>2]=aq;c[al+2656>>2]=an;c[al+3680>>2]=an;c[al+2660>>2]=ar;c[al+3684>>2]=ar;c[al+2664>>2]=at;c[al+3688>>2]=at;c[al+4184>>2]=122;c[al+4180>>2]=1762;if(!ap){at=al;gGC(at|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=as;c[2417276]=ai;c[1836236]=-1;at=a[9680]|0;ar=at?32e3:0;if(at){if(a[9624]|0){at=ar*3|0;an=55930;while(1){if((an|0)>(at|0)){an=an>>1}else{aF=1222;aG=an;break}}}else{aF=2462;aG=ar}c[2429380]=aG;c[3542124]=aF;mw(3579545,aG);an=gGq(262144)|0;c[2406684]=an;gGz(an|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(3579545,11025)}h[745421]=1.0;c[2436794]=1;h[745420]=1.0;c[2436792]=2;TJ(0,c[3529774]|0,262144);c[2424878]=9681232;c[2405736]=952;h[1202869]=.2;c[2405742]=3;c[2426622]=9622928;h[1202870]=.2;c[2405743]=3;TJ(1,c[3529728]|0,524288);c[2424878]=9681296;c[2405748]=830;h[1202875]=.5;c[2405754]=1;c[2426622]=9622976;h[1202876]=.5;c[2405755]=2;an=c[3530932]|0;at=0;while(1){if((at|0)>=1024){aH=0;break}aI=9638528+(at<<2)|0;if((c[aI>>2]|0)==0){ak=69040;break}else{at=at+1|0}}do{if((ak|0)==69040){at=gGq(24576)|0;c[aI>>2]=at;if((at|0)==0){aH=0;break}gGz(at|0,0,24576);aH=at}}while(0);c[3529062]=aH;c[2438700]=524287;c[3529060]=an;a[7461784]=1;at=9726816;c[at>>2]=0;c[at+4>>2]=0;at=9726800;c[at>>2]=0;c[at+4>>2]=0;c[2429638]=0;c[2437692]=16;c[2431704]=8;c[2431700]=0;c[2431705]=8;c[2431701]=0;c[2431706]=8;c[2431702]=0;at=c[3530696]|0;c[2438136]=0;ar=0;while(1){if((ar|0)>=1024){aJ=0;break}aK=9638528+(ar<<2)|0;if((c[aK>>2]|0)==0){ak=69045;break}else{ar=ar+1|0}}do{if((ak|0)==69045){ar=gGq(1024)|0;c[aK>>2]=ar;if((ar|0)==0){aJ=0;break}gGz(ar|0,0,1024);aJ=ar}}while(0);c[3529066]=aJ;c[2438702]=1048575;c[3529064]=at;a[7461792]=1;c[2437694]=36;c[2438136]=8;ar=c[3530486]|0;an=0;while(1){if((an|0)>=1024){aL=0;break}aM=9638528+(an<<2)|0;if((c[aM>>2]|0)==0){ak=69050;break}else{an=an+1|0}}do{if((ak|0)==69050){an=gGq(2048)|0;c[aM>>2]=an;if((an|0)==0){aL=0;break}gGz(an|0,0,2048);aL=an}}while(0);c[3529076]=aL;an=0;while(1){if((an|0)>=1024){aN=0;break}aO=9638528+(an<<2)|0;if((c[aO>>2]|0)==0){ak=69055;break}else{an=an+1|0}}do{if((ak|0)==69055){an=gGq(524288)|0;c[aO>>2]=an;if((an|0)==0){aN=0;break}gGz(an|0,0,524288);aN=an}}while(0);c[2438704]=aN;c[2437696]=50;c[2443318]=7;c[3529080]=ar;c[2439480]=ar;c[3527144]=524287;a[7461800]=1;c[2432686]=0;c[3527138]=-112;c[3527139]=-16;an=c[642608+(c[2436]<<2)>>2]|0;at=c[an+128>>2]|0;if((c[an+52>>2]&4|0)==0){c[2113068]=at;ai=c[an+132>>2]|0;c[2113070]=ai;c[2443814]=at;c[2440436]=ai;aP=at;aQ=ai}else{c[2113070]=at;ai=c[an+132>>2]|0;c[2113068]=ai;c[2440436]=at;c[2443814]=ai;aP=ai;aQ=at}at=ag(aP<<1,aQ)|0;ai=gGq(at)|0;c[2112926]=ai;if((ai|0)!=0){gGz(ai|0,0,at|0)}a[9624960]=0;at=c[2414794]|0;gGz(at|0,0,(c[2411854]|0)-at|0);c[363094]=0;c[2410673]=0;a[9642688]=0;a[9642689]=0;a[9642682]=0;a[9642683]=0;c[2410665]=0;a[9642680]=a[9642680]|80;at=c[2425163]|0;do{if((at|0)==0){ai=c[3528598]|0;if((ai|0)==0){aR=0;aS=0;break}an=gj[ai&4095](-2)|0;ai=c[2425163]|0;as=(an&255)<<8;if((ai|0)!=0){aT=ai;aU=as;ak=69066;break}ai=c[3528598]|0;if((ai|0)==0){aR=0;aS=as;break}aR=gj[ai&4095](-1)|0;aS=as}else{aT=at;aU=(d[at+254|0]|0)<<8;ak=69066}}while(0);if((ak|0)==69066){aR=a[aT+255|0]|0;aS=aU}c[2410662]=aR&255|aS;c[363094]=-1;c[3528554]=0;f43(c[2433592]|0);at=c[3528554]|0;c[2113158]=c[9731360+(at<<2)>>2];a[9660796]=0;a[9660797]=0;a[9660786]=0;a[9660787]=0;c[2415191]=0;a[9660784]=a[9660784]|80;ar=c[2433592]|0;as=c[ar+(at*3148|0)+1068>>2]|0;do{if((as|0)==0){ai=c[ar+(at*3148|0)+3120>>2]|0;if((ai|0)==0){aV=0;aW=0;aX=at;aY=ar;break}an=gj[ai&4095](-2)|0;ai=c[3528554]|0;al=c[2433592]|0;ap=c[al+(ai*3148|0)+1068>>2]|0;aq=(an&255)<<8;if((ap|0)!=0){aZ=ap;a_=aq;a$=ai;a0=al;ak=69073;break}ap=c[al+(ai*3148|0)+3120>>2]|0;if((ap|0)==0){aV=0;aW=aq;aX=ai;aY=al;break}al=gj[ap&4095](-1)|0;aV=al;aW=aq;aX=c[3528554]|0;aY=c[2433592]|0}else{aZ=as;a_=(d[as+254|0]|0)<<8;a$=at;a0=ar;ak=69073}}while(0);if((ak|0)==69073){aV=a[aZ+255|0]|0;aW=a_;aX=a$;aY=a0}ar=aV&255|aW;c[2415188]=ar;b[4830376]=ar&65535;ar=aY+(aX*3148|0)|0;if((ar|0)!=0){at=ar;gGC(at|0,9660752,48)|0}c[9731360+(aX<<2)>>2]=c[2113158];c[3528554]=-1;at=c[2439330]|0;ar=(at|0)==0;if(!ar){as=at;gGC(9706056,as|0,76)|0}as=c[2438118]|0;c[2433530]=as;aq=c[3528484]|0;c[2076596]=aq;al=c[2417276]|0;c[3541536]=al;c[1836236]=0;gGz(9706056,0,76);if(!ar){ar=at;gGC(ar|0,9706056,76)|0}c[2438118]=as;c[3528484]=aq;c[2417276]=al;c[1836236]=-1;mx(0);blH();c[3525076]=0;c[2439326]=0;am=0;i=e;return am|0}}while(0);c[2415086]=0;am=1;i=e;return am|0}function bkt(){var a=0,b=0,d=0,e=0;c[2113070]=0;c[2113068]=0;a=c[2112926]|0;if((a|0)!=0){gGr(a);c[2112926]=0}blI();c[2113160]=0;a=c[2433592]|0;if((a|0)!=0){gGr(a);c[2433592]=0}c[2444172]=0;c[3528598]=0;fwZ();a=c[2424800]|0;if((a|0)!=0){gGr(a);c[2424800]=0}a=c[2418166]|0;if((a|0)!=0){gGr(a);c[2418166]=0}a=c[3531464]|0;c[a+44344>>2]=0;c[a+44348>>2]=0;if((a|0)!=0){gGr(a);c[3531464]=0}a=c[2406684]|0;if((a|0)!=0){gGr(a);c[2406684]=0}a=c[2415086]|0;b=0;while(1){if((b|0)>=1024){d=69208;break}e=9638528+(b<<2)|0;if((c[e>>2]|0)==(a|0)){break}else{b=b+1|0}}if((d|0)==69208){c[2415086]=0;return 0}gGr(a);c[e>>2]=0;c[2415086]=0;return 0}function bku(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;if((a[9624960]|0)!=0){a[9624960]=0;e=c[2414794]|0;gGz(e|0,0,(c[2411854]|0)-e|0);c[363094]=0;c[2410673]=0;a[9642688]=0;a[9642689]=0;a[9642682]=0;a[9642683]=0;c[2410665]=0;a[9642680]=a[9642680]|80;e=c[2425163]|0;do{if((e|0)==0){f=c[3528598]|0;if((f|0)==0){g=0;h=0;break}i=gj[f&4095](-2)|0;f=c[2425163]|0;j=(i&255)<<8;if((f|0)!=0){k=f;l=j;m=69215;break}f=c[3528598]|0;if((f|0)==0){g=0;h=j;break}g=gj[f&4095](-1)|0;h=j}else{k=e;l=d[e+254|0]<<8;m=69215}}while(0);if((m|0)==69215){g=a[k+255|0]|0;h=l}c[2410662]=g&255|h;c[363094]=-1;c[3528554]=0;f43(c[2433592]|0);h=c[3528554]|0;c[2113158]=c[9731360+(h<<2)>>2];a[9660796]=0;a[9660797]=0;a[9660786]=0;a[9660787]=0;c[2415191]=0;a[9660784]=a[9660784]|80;g=c[2433592]|0;l=c[g+(h*3148|0)+1068>>2]|0;do{if((l|0)==0){k=c[g+(h*3148|0)+3120>>2]|0;if((k|0)==0){n=0;o=0;p=h;q=g;break}e=gj[k&4095](-2)|0;k=c[3528554]|0;j=c[2433592]|0;f=c[j+(k*3148|0)+1068>>2]|0;i=(e&255)<<8;if((f|0)!=0){r=f;s=i;t=k;u=j;m=69222;break}f=c[j+(k*3148|0)+3120>>2]|0;if((f|0)==0){n=0;o=i;p=k;q=j;break}j=gj[f&4095](-1)|0;n=j;o=i;p=c[3528554]|0;q=c[2433592]|0}else{r=l;s=d[l+254|0]<<8;t=h;u=g;m=69222}}while(0);if((m|0)==69222){n=a[r+255|0]|0;o=s;p=t;q=u}u=n&255|o;c[2415188]=u;b[4830376]=u&65535;u=q+(p*3148|0)|0;if((u|0)!=0){q=u;gGC(q|0,9660752,48)|0}c[9731360+(p<<2)>>2]=c[2113158];c[3528554]=-1;p=c[2439330]|0;q=(p|0)==0;if(!q){u=p;gGC(9706056,u|0,76)|0}u=c[2438118]|0;c[2433530]=u;o=c[3528484]|0;c[2076596]=o;n=c[2417276]|0;c[3541536]=n;c[1836236]=0;gGz(9706056,0,76);if(!q){q=p;gGC(q|0,9706056,76)|0}c[2438118]=u;c[3528484]=o;c[2417276]=n;c[1836236]=-1;mx(0);blH();c[3525076]=0;c[2439326]=0}gGz(9550912,-1|0,3);n=0;o=-1;u=-1;q=-1;do{o=((a[9634312+n|0]&1)<<n^o&255)&255;u=((a[9632072+n|0]&1)<<n^u&255)&255;q=((a[9629992+n|0]&1)<<n^q&255)&255;n=n+1|0;}while((n|0)<8);a[9550912]=o;a[9550913]=u;a[9550914]=q;if((u&3)==0){o=u|3;a[9550913]=o;v=o}else{v=u}if((v&12)==0){a[9550913]=v|12}if((q&3)==0){v=q|3;a[9550914]=v;w=v}else{w=q}if((w&12)==0){a[9550914]=w|12}w=c[2439330]|0;if((w|0)!=0){q=w;gGC(9706056,q|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;c[3528554]=0;f43(c[2433592]|0);c[2113158]=c[9731360+(c[3528554]<<2)>>2];c[363094]=0;q=0;w=0;v=0;u=0;o=0;L89694:while(1){n=w;p=v;t=u;s=o;do{if((s|0)>=100){break L89694}s=s+1|0;r=s*665|0;t=(fNF(r-t|0)|0)+t|0;m=f45(r-p|0)|0;c[2113158]=(c[2113158]|0)+m;p=m+p|0;m=(s*596|0)-n|0;do{if((m|0)<1){x=0}else{if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){r=gfc(m)|0;c[2433530]=(c[2433530]|0)+r;x=r;break}else{c[2433530]=(c[2433530]|0)+m;x=m;break}}}while(0);n=x+n|0;y=c[2112964]|0;}while((y|0)==0);m=a[9688]|0?5:0;r=y+(q<<1<<1)|0;gg[c[3542124]&4095](r,m);TH(0,r,m);TH(1,r,m);q=m+q|0;w=n;v=p;u=t;o=s}if((c[3541236]|0)!=0){fNE(0,1);fNF(0)|0;a[9642682]=0;fNF(0)|0}o=c[2112964]|0;do{if((o|0)!=0){u=a[9688]|0?534:0;v=u-q|0;if((u|0)==(q|0)){break}u=o+(q<<1<<1)|0;gg[c[3542124]&4095](u,v);TH(0,u,v);TH(1,u,v)}}while(0);c[363094]=-1;q=c[3528554]|0;o=(c[2433592]|0)+(q*3148|0)|0;if((o|0)!=0){v=o;gGC(v|0,9660752,48)|0}c[9731360+(q<<2)>>2]=c[2113158];c[3528554]=-1;q=c[1836236]|0;v=c[9757320+(q<<2)>>2]|0;if((v|0)!=0){o=v;gGC(o|0,9706056,76)|0}c[9752472+(q<<2)>>2]=c[2433530];c[14113936+(q<<2)>>2]=c[2076596];c[9669104+(q<<2)>>2]=c[3541536];c[1836236]=-1;if((c[2112968]|0)==0){return 0}bkv()|0;return 0}function bkv(){var d=0,e=0,f=0,g=0;if((a[9547952]|0)!=0){d=c[3530172]|0;e=c[2387268]|0;f=0;do{g=ga(b[e+(f<<1)>>1]|0)|0;c[d+(f<<2)>>2]=((g&65535)>>>10<<3&65535)>>>3&31|((g&255)<<3&255)<<8|(((g&65535)>>>5<<3&255|(g&65535)>>>7&4)&255)<<3&2016;f=f+1|0;}while((f|0)<2048)}bpj();f=c[2112926]|0;gGz(f|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);bpk(2,0,c[2439900]|0);if((c[2439326]|0)==0){bpk(1,0,c[2439900]|0);bi3(0)}else{bi3(0);bpk(1,0,c[2439900]|0)}bpl(c[2439864]|0,3);bpl(c[2439864]|0,2);bpl(c[2439864]|0,1);bpl(c[2439864]|0,0);bpk(0,0,c[2439900]|0);R8(c[3530172]|0);return 0}function bkw(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;f=i;i=i+224|0;g=f|0;h=f+16|0;j=f+48|0;k=f+64|0;l=f+80|0;m=f+96|0;n=f+112|0;o=f+128|0;p=f+144|0;q=f+160|0;r=f+176|0;s=f+192|0;t=f+208|0;u=(e|0)==0;if(!u){c[e>>2]=169733}if((b&96|0)!=0){gGz(t|0,0,12);v=c[2414794]|0;c[t>>2]=v;c[t+4>>2]=(c[2411854]|0)-v;c[t+12>>2]=162152;v=c[2076592]|0;gj[v&4095](t)|0;t=c[2410674]|0;v=c[2410675]|0;w=(b&64|0)==0;if(!w){gGz(s|0,0,12);c[s>>2]=9642648;c[s+4>>2]=56;c[s+12>>2]=163840;x=c[2076592]|0;gj[x&4095](s)|0;gGz(r|0,0,12);c[r>>2]=9707480;c[r+4>>2]=2;c[r+12>>2]=501096;s=c[2076592]|0;gj[s&4095](r)|0;gGz(q|0,0,12);c[q>>2]=9707480;c[q+4>>2]=4;c[q+12>>2]=385184;r=c[2076592]|0;gj[r&4095](q)|0}c[2410674]=t;c[2410675]=v;v=p|0;if((c[2113160]|0)>0&(w^1)){t=p+7|0;p=o|0;q=o+4|0;r=o+12|0;s=n;x=n|0;y=n+4|0;z=n+12|0;A=m;B=m|0;C=m+4|0;D=m+12|0;E=l;F=l|0;G=l+4|0;H=l+12|0;I=0;do{J=c[2433592]|0;K=J+(I*3148|0)+40|0;L=c[K>>2]|0;gGC(v|0,614752,9)|0;a[t]=I+48&255;c[p>>2]=J+(I*3148|0);c[q>>2]=48;c[r>>2]=v;gj[c[2076592]&4095](o)|0;gGz(s|0,0,12);c[x>>2]=J+(I*3148|0)+3136;c[y>>2]=4;c[z>>2]=165288;gj[c[2076592]&4095](n)|0;gGz(A|0,0,12);c[B>>2]=J+(I*3148|0)+3140;c[C>>2]=4;c[D>>2]=501592;gj[c[2076592]&4095](m)|0;gGz(E|0,0,12);c[F>>2]=J+(I*3148|0)+3144;c[G>>2]=4;c[H>>2]=386080;gj[c[2076592]&4095](l)|0;c[K>>2]=L;I=I+1|0;}while((I|0)<(c[2113160]|0))}fw$(b);if(w){M=g;N=h|0}else{gGz(k|0,0,12);c[k>>2]=8453216;c[k+4>>2]=4;c[k+12>>2]=107480;w=c[2076592]|0;gj[w&4095](k)|0;gGz(j|0,0,12);c[j>>2]=14168504;c[j+4>>2]=256;c[j+12>>2]=476464;k=c[2076592]|0;gj[k&4095](j)|0;if((b&2|0)==0){O=g;P=h|0}else{j=0;do{mv(0,j,d[14168504+j|0]|0);j=j+1|0;}while((j|0)<256);O=g;P=h|0}if(!u){c[e>>2]=169619}e=h|0;cC(e|0,170224,(h=i,i=i+8|0,c[h>>2]=0,h)|0)|0;i=h;c[g>>2]=9699512;c[g+4>>2]=64;c[g+8>>2]=0;c[g+12>>2]=e;e=c[2076592]|0;gj[e&4095](g)|0;M=O;N=P}blJ(b)}if((b&2|0)==0){i=f;return 0}c[363094]=0;b=d[c[2443956]|0]|0;P=(b<<9&65536)+65536|b<<13&57344;c[2439326]=b&8;b=c[2387374]|0;N=0;O=0;while(1){M=O+96|0;g=b+((O<<8)+P)|0;c[9699632+(M<<2)>>2]=g;c[9701680+(M<<2)>>2]=g;g=N+1&65535;if((g&65535)<32){N=g;O=g&65535}else{break}}c[363094]=-1;c[3528554]=0;f43(c[2433592]|0);O=c[3528554]|0;N=9731360+(O<<2)|0;P=c[N>>2]|0;c[2113158]=P;b=a[(c[2443956]|0)+1|0]|0;g=b&255;c[3541230]=g&64;a[14108544]=b&32;c[3525076]=g&16;b=c[3527398]|0;M=c[2433592]|0;e=(g<<13&122880)+32768|0;g=128;h=128;while(1){u=b+(e+(h<<8))|0;c[M+(O*3148|0)+48+(h<<2)>>2]=u;c[M+(O*3148|0)+48+(h+512<<2)>>2]=u;u=g+1&65535;if((u&65535)>159){break}else{g=u;h=u&65535}}h=M+(O*3148|0)|0;if((h|0)!=0){O=h;gGC(O|0,9660752,48)|0}c[N>>2]=P;c[3528554]=-1;i=f;return 0}function bkx(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4339620+(b*112|0)>>2];c[a+104>>2]=c[4339624+(b*112|0)>>2];c[a+108>>2]=c[4339628+(b*112|0)>>2];d=0;return d|0}function bky(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=4339520+(b*112|0);e=0;return e|0}function bkz(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6608404+(b*112|0)>>2];c[a+104>>2]=c[6608408+(b*112|0)>>2];c[a+108>>2]=c[6608412+(b*112|0)>>2];d=0;return d|0}function bkA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=6608304+(b*112|0);e=0;return e|0}function bkB(b){b=b|0;a[9681232]=((b>>4)*17|0)&255;a[9681233]=0;c[2424878]=9681232;a[9681234]=0;a[9681235]=((b&15)*17|0)&255;return}function bkC(b){b=b|0;var d=0;c[2424878]=9681296;d=((b&15)*17|0)>>>1&255;a[9681296]=d;a[9681297]=d;return}function bkD(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;c[d>>2]=(c[d>>2]|b<<12)&16383|c[e>>2]<<8&3840;c[e>>2]=((c[e>>2]|0)>>>4&15)+(c[602576+(a<<2)>>2]|0);return}function bkE(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0;c[d>>2]=0;e=c[b>>2]|0;if((e&16|0)==0){f=e}else{c[d>>2]=1;f=c[b>>2]|0}if((f&64|0)==0){c[d>>2]=2;g=c[b>>2]|0}else{g=f}if((g&32|0)==0){h=g}else{c[d>>2]=3;h=c[b>>2]|0}c[b>>2]=h&15|16;c[a>>2]=c[a>>2]&8191;return}function bkF(a,b,d){a=a|0;b=b|0;d=d|0;c[a>>2]=(c[a>>2]|c[b>>2]<<8)&2047;c[b>>2]=(c[b>>2]|0)>>>3&1|6;return}function bkG(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((e|0)==24452){c[2440042]=d&4;return}else if((e|0)==24460){a[c[3528356]|0]=d;return}else if((e|0)==24464){a[14125144]=-1;a[9706117]=1;return}else if((e|0)==24456){return}else{if((e&63488|0)==14336){b=e&2047;if((c[2385182]|0)==0){a[(c[3529076]|0)+b|0]=d;bi2(e&1023,0);return}else{a[(c[3531086]|0)+b|0]=d;return}}if((e&65520|0)==24512){a[14108592+(e&15)|0]=d;return}if((e&49152|0)!=16384){return}blF(e&16383,d&255);return}}function bkH(b){b=b|0;var e=0,f=0;e=b&65535;switch(e|0){case 24468:{f=a[9635640]&-16|a[9550904]&15;return f|0};case 24470:{f=a[9550906]|0;return f|0};case 24475:{f=a[9635642]|0;return f|0};case 24469:{f=a[9550905]|0;return f|0};case 24471:{f=a[9635641]|0;return f|0};default:{if((e&63488|0)!=14336){if((e&49152|0)!=16384){f=0;return f|0}f=blE(e&16383)|0;return f|0}if((c[2385182]|0)!=0){f=a[(c[3531086]|0)+(e&2047)|0]|0;return f|0}b=e&2047;if((c[2440042]|0)==0){f=a[(c[3529076]|0)+b|0]|0;return f|0}if((a[14108606]&1)!=0){f=0;return f|0}f=a[(c[3529080]|0)+(((d[14108604]|0)<<11|b|(d[14108605]|0)<<19)>>>(((c[2443318]|0)<5|0)>>>0)&c[3527144])|0]|0;return f|0}}return 0}function bkI(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;e=b&65535;if((e|0)==36864){b=c[9674024+(c[2439378]<<2)>>2]|0;c[2424874]=b;a[b+8|0]=d;return}else if((e|0)==49152){c[2113304]=d&255;return}else if((e|0)==57344){b=(d&255)>>>2&1;c[2439378]=b;f=c[9674024+(b<<2)>>2]|0;c[2424874]=f;b=f+9|0;f=a[b]|0;a[b]=(d&255)>>>1&1;do{if(f<<24>>24!=0){if((a[(c[2424874]|0)+9|0]|0)!=0){break}Vl()}}while(0);f=c[9674024+(c[2439378]<<2)>>2]|0;c[2424874]=f;b=f+10|0;f=a[b]|0;a[b]=d&1;b=c[2424874]|0;g=b+16|0;if((a[g]|f)<<24>>24!=0){return}if((a[b+10|0]|0)==0){return}if((a[b+9|0]|0)==0){return}a[g]=2;if(!(a[635136]|0)){return}g=a[(c[2424874]|0)+11|0]|0;Vk();b=c[2424874]|0;f=a[b+11|0]|0;if(g<<24>>24==f<<24>>24){return}g=c[b+12>>2]|0;if((g|0)==0){return}gf[g&2047](f&255);return}else if((e|0)==49153){e=c[2113304]|0;a[14168504+e|0]=d;mv(0,e,d&255);return}else{return}}function bkJ(b){b=b|0;var d=0,e=0;d=b&65535;if((d|0)==40960){a[9706117]=0;e=a[c[3528356]|0]|0;return e|0}else if((d|0)==49152|(d|0)==49153){e=c[(c[3531464]|0)+4240>>2]&255;return e|0}else{e=0;return e|0}return 0}function bkK(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>35){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4708836+(b*112|0)>>2];c[a+104>>2]=c[4708840+(b*112|0)>>2];c[a+108>>2]=c[4708844+(b*112|0)>>2];d=0;return d|0}function bkL(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<36&(d|0)==0)){e=1;return e|0}c[a>>2]=4708736+(b*112|0);e=0;return e|0}function bkM(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1546896+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function bkN(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>50){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4712768+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function bkO(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0;e=i;i=i+1320|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;B=e+1200|0;C=e+1312|0;c[2415084]=0;c[2387372]=0;c[2385994]=131072;c[3530930]=196608;c[3530694]=720896;c[3530484]=1769472;c[2439898]=2031616;c[2439862]=3080192;c[2439846]=5177344;c[3529772]=5701632;c[3529726]=5832704;c[3530170]=5963776;c[2414792]=5971968;c[3531086]=5971968;c[2387396]=5974016;c[2387266]=5978112;c[2406306]=5982208;c[2386146]=5984256;c[3528356]=5986304;c[2394764]=5986305;c[2411852]=5986307;D=0;while(1){if((D|0)>=1024){break}E=9638528+(D<<2)|0;if((c[E>>2]|0)==0){F=69449;break}else{D=D+1|0}}do{if((F|0)==69449){D=gGq(5986307)|0;c[E>>2]=D;if((D|0)==0){break}c[2415084]=D;gGz(D|0,0,5986307);c[2387372]=D;c[2385994]=D+131072;c[3530930]=D+196608;c[3530694]=D+720896;c[3530484]=D+1769472;c[2439898]=D+2031616;c[2439862]=D+3080192;c[2439846]=D+5177344;c[3529772]=D+5701632;c[3529726]=D+5832704;c[3530170]=D+5963776;G=D+5971968|0;c[2414792]=G;c[3531086]=G;c[2387396]=D+5974016;c[2387266]=D+5978112;c[2406306]=D+5982208;c[2386146]=D+5984256;c[3528356]=D+5986304;c[2394764]=D+5986305;G=D+5986307|0;c[2411852]=G;c[2414402]=G;G=D+32768|0;if((c[3542200]|0)==0){H=1;i=e;return H|0}D=B+108|0;c[D>>2]=0;I=B+100|0;c[I>>2]=0;J=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[J&16383](B,0)|0;do{if((c[D>>2]|0)!=0){J=c[I>>2]|0;c[C>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](C,0,0)|0;if((J|0)<1){H=1;i=e;return H|0}if((gzL(G,0,0)|0)==0){break}else{H=1}i=e;return H|0}}while(0);G=(c[2387372]|0)+65536|0;if((c[3542200]|0)==0){H=1;i=e;return H|0}I=z+108|0;c[I>>2]=0;D=z+100|0;c[D>>2]=0;J=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[J&16383](z,1)|0;do{if((c[I>>2]|0)!=0){J=c[D>>2]|0;c[A>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](A,1,0)|0;if((J|0)<1){H=1;i=e;return H|0}if((gzL(G,0,1)|0)==0){break}else{H=1}i=e;return H|0}}while(0);G=c[2385994]|0;if((c[3542200]|0)==0){H=1;i=e;return H|0}D=x+108|0;c[D>>2]=0;I=x+100|0;c[I>>2]=0;J=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[J&16383](x,2)|0;do{if((c[D>>2]|0)!=0){J=c[I>>2]|0;c[y>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](y,2,0)|0;if((J|0)<1){H=1;i=e;return H|0}if((gzL(G,0,2)|0)==0){break}else{H=1}i=e;return H|0}}while(0);if((R6(c[3530930]|0,3,2)|0)!=0){H=1;i=e;return H|0}if((R6((c[3530930]|0)+1|0,4,2)|0)!=0){H=1;i=e;return H|0}if((R6((c[3530930]|0)+131072|0,5,2)|0)!=0){H=1;i=e;return H|0}if((R6((c[3530930]|0)+131073|0,6,2)|0)!=0){H=1;i=e;return H|0}if((R6((c[3530930]|0)+262144|0,7,2)|0)!=0){H=1;i=e;return H|0}if((R6((c[3530930]|0)+262145|0,8,2)|0)!=0){H=1;i=e;return H|0}if((R6((c[3530930]|0)+393216|0,9,2)|0)!=0){H=1;i=e;return H|0}if((R6((c[3530930]|0)+393217|0,10,2)|0)!=0){H=1;i=e;return H|0}if((R6(c[3530694]|0,11,2)|0)!=0){H=1;i=e;return H|0}if((R6((c[3530694]|0)+1|0,12,2)|0)!=0){H=1;i=e;return H|0}if((R6((c[3530694]|0)+131072|0,13,2)|0)!=0){H=1;i=e;return H|0}if((R6((c[3530694]|0)+131073|0,14,2)|0)!=0){H=1;i=e;return H|0}if((R6((c[3530694]|0)+262144|0,15,2)|0)!=0){H=1;i=e;return H|0}if((R6((c[3530694]|0)+262145|0,16,2)|0)!=0){H=1;i=e;return H|0}if((R6((c[3530694]|0)+393216|0,17,2)|0)!=0){H=1;i=e;return H|0}if((R6((c[3530694]|0)+393217|0,18,2)|0)!=0){H=1;i=e;return H|0}if((R6((c[3530694]|0)+524288|0,19,2)|0)!=0){H=1;i=e;return H|0}if((R6((c[3530694]|0)+524289|0,20,2)|0)!=0){H=1;i=e;return H|0}if((R6((c[3530694]|0)+655360|0,21,2)|0)!=0){H=1;i=e;return H|0}if((R6((c[3530694]|0)+655361|0,22,2)|0)!=0){H=1;i=e;return H|0}if((R6((c[3530694]|0)+786432|0,23,2)|0)!=0){H=1;i=e;return H|0}if((R6((c[3530694]|0)+786433|0,24,2)|0)!=0){H=1;i=e;return H|0}if((R6((c[3530694]|0)+917504|0,25,2)|0)!=0){H=1;i=e;return H|0}if((R6((c[3530694]|0)+917505|0,26,2)|0)!=0){H=1;i=e;return H|0}G=c[3530484]|0;if((c[3542200]|0)==0){H=1;i=e;return H|0}I=v+108|0;c[I>>2]=0;D=v+100|0;c[D>>2]=0;J=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[J&16383](v,27)|0;do{if((c[I>>2]|0)!=0){J=c[D>>2]|0;c[w>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](w,27,0)|0;if((J|0)<1){H=1;i=e;return H|0}if((gzL(G,0,27)|0)==0){break}else{H=1}i=e;return H|0}}while(0);G=(c[3530484]|0)+65536|0;if((c[3542200]|0)==0){H=1;i=e;return H|0}D=t+108|0;c[D>>2]=0;I=t+100|0;c[I>>2]=0;J=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[J&16383](t,28)|0;do{if((c[D>>2]|0)!=0){J=c[I>>2]|0;c[u>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](u,28,0)|0;if((J|0)<1){H=1;i=e;return H|0}if((gzL(G,0,28)|0)==0){break}else{H=1}i=e;return H|0}}while(0);G=(c[3530484]|0)+131072|0;if((c[3542200]|0)==0){H=1;i=e;return H|0}I=r+108|0;c[I>>2]=0;D=r+100|0;c[D>>2]=0;J=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[J&16383](r,29)|0;do{if((c[I>>2]|0)!=0){J=c[D>>2]|0;c[s>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](s,29,0)|0;if((J|0)<1){H=1;i=e;return H|0}if((gzL(G,0,29)|0)==0){break}else{H=1}i=e;return H|0}}while(0);G=(c[3530484]|0)+196608|0;if((c[3542200]|0)==0){H=1;i=e;return H|0}D=p+108|0;c[D>>2]=0;I=p+100|0;c[I>>2]=0;J=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[J&16383](p,30)|0;do{if((c[D>>2]|0)!=0){J=c[I>>2]|0;c[q>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](q,30,0)|0;if((J|0)<1){H=1;i=e;return H|0}if((gzL(G,0,30)|0)==0){break}else{H=1}i=e;return H|0}}while(0);G=c[3529772]|0;if((c[3542200]|0)==0){H=1;i=e;return H|0}I=n+108|0;c[I>>2]=0;D=n+100|0;c[D>>2]=0;J=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[J&16383](n,31)|0;do{if((c[I>>2]|0)!=0){J=c[D>>2]|0;c[o>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](o,31,0)|0;if((J|0)<1){H=1;i=e;return H|0}if((gzL(G,0,31)|0)==0){break}else{H=1}i=e;return H|0}}while(0);G=(c[3529772]|0)+65536|0;if((c[3542200]|0)==0){H=1;i=e;return H|0}D=l+108|0;c[D>>2]=0;I=l+100|0;c[I>>2]=0;J=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[J&16383](l,32)|0;do{if((c[D>>2]|0)!=0){J=c[I>>2]|0;c[m>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](m,32,0)|0;if((J|0)<1){H=1;i=e;return H|0}if((gzL(G,0,32)|0)==0){break}else{H=1}i=e;return H|0}}while(0);G=c[3529726]|0;if((c[3542200]|0)==0){H=1;i=e;return H|0}I=j+108|0;c[I>>2]=0;D=j+100|0;c[D>>2]=0;J=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[J&16383](j,33)|0;do{if((c[I>>2]|0)!=0){J=c[D>>2]|0;c[k>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](k,33,0)|0;if((J|0)<1){H=1;i=e;return H|0}if((gzL(G,0,33)|0)==0){break}else{H=1}i=e;return H|0}}while(0);G=(c[3529726]|0)+65536|0;if((c[3542200]|0)==0){H=1;i=e;return H|0}D=f+108|0;c[D>>2]=0;I=f+100|0;c[I>>2]=0;J=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[J&16383](f,34)|0;do{if((c[D>>2]|0)!=0){J=c[I>>2]|0;c[g>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](g,34,0)|0;if((J|0)<1){H=1;i=e;return H|0}if((gzL(G,0,34)|0)==0){break}else{H=1}i=e;return H|0}}while(0);G=c[3530930]|0;blG(G,262144);I=c[3530694]|0;blG(I,524288);D=c[2439898]|0;J=0;do{K=J<<6;gGz(D+K|0,0,64);L=J<<8;M=0;do{N=1<<3-M;O=(c[611632+(M<<2)>>2]|0)+L|0;P=0;do{Q=O+(c[3946808+(P<<2)>>2]|0)|0;R=(P<<3)+K|0;S=0;do{T=Q+(c[6669416+(S<<2)>>2]|0)|0;if(((d[G+((T|0)/8|0)|0]|0)&128>>>((T&7)>>>0)|0)!=0){T=D+(R+S)|0;a[T]=(d[T]|0|N)&255}S=S+1|0;}while((S|0)<8);P=P+1|0;}while((P|0)<8);M=M+1|0;}while((M|0)<4);J=J+1|0;}while((J|0)<16384);J=c[2439862]|0;D=0;do{G=D<<8;gGz(J+G|0,0,256);M=D<<10;K=0;do{L=1<<3-K;P=(c[611400+(K<<2)>>2]|0)+M|0;N=0;do{O=P+(c[3946808+(N<<2)>>2]|0)|0;S=(N<<4)+G|0;R=0;do{Q=O+(c[6669416+(R<<2)>>2]|0)|0;if(((d[I+((Q|0)/8|0)|0]|0)&128>>>((Q&7)>>>0)|0)!=0){Q=J+(S+R)|0;a[Q]=(d[Q]|0|L)&255}R=R+1|0;}while((R|0)<16);N=N+1|0;}while((N|0)<16);K=K+1|0;}while((K|0)<4);D=D+1|0;}while((D|0)<8192);c[2410674]=1748;gGz(9699632,0,3072);D=c[2427044]|0;c[9681616+(D<<3)>>2]=715288;c[9681620+(D<<3)>>2]=0;c[2427044]=D+1;c[363094]=0;D=c[2387266]|0;J=0;I=0;while(1){K=I+16|0;G=D+(I<<8)|0;c[9699632+(K<<2)>>2]=G;c[9700656+(K<<2)>>2]=G;c[9701680+(K<<2)>>2]=G;G=J+1&65535;if((G&65535)<16){J=G;I=G&65535}else{break}}I=c[2387396]|0;J=0;D=0;while(1){G=D+32|0;K=I+(D<<8)|0;c[9699632+(G<<2)>>2]=K;c[9700656+(G<<2)>>2]=K;c[9701680+(G<<2)>>2]=K;K=J+1&65535;if((K&65535)<16){J=K;D=K&65535}else{break}}D=c[2406306]|0;c[2424956]=D;c[2425212]=D;c[2425468]=D;J=D+256|0;c[2424957]=J;c[2425213]=J;c[2425469]=J;J=D+512|0;c[2424958]=J;c[2425214]=J;c[2425470]=J;J=D+768|0;c[2424959]=J;c[2425215]=J;c[2425471]=J;J=D+1024|0;c[2424960]=J;c[2425216]=J;c[2425472]=J;J=D+1280|0;c[2424961]=J;c[2425217]=J;c[2425473]=J;J=D+1536|0;c[2424962]=J;c[2425218]=J;c[2425474]=J;J=D+1792|0;c[2424963]=J;c[2425219]=J;c[2425475]=J;J=c[2387372]|0;D=0;I=0;while(1){K=I+128|0;G=J+((I<<8)+32768)|0;c[9699632+(K<<2)>>2]=G;c[9701680+(K<<2)>>2]=G;G=D+1&65535;if((G&65535)<128){D=G;I=G&65535}else{break}}c[2444172]=1650;c[3528598]=3366;c[2410675]=992;c[363094]=-1;fwR(0);I=c[2439330]|0;D=(I|0)==0;if(!D){J=I;gGC(9706056,J|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];J=c[3528484]|0;c[2076596]=J;G=c[2417276]|0;c[3541536]=G;c[1836236]=0;K=c[2385994]|0;M=0;N=0;while(1){c[I+76+(N<<2)>>2]=K+(N<<8);L=M+1&65535;if((L&65535)>127){U=0;V=0;break}else{M=L;N=L&65535}}while(1){N=K+(V<<8)|0;c[I+76+(V+512<<2)>>2]=N;c[I+76+(V+768<<2)>>2]=N;N=U+1&65535;if((N&65535)>127){break}else{U=N;V=N&65535}}K=c[2386146]|0;c[I+588>>2]=K;N=K+256|0;c[I+592>>2]=N;M=K+512|0;c[I+596>>2]=M;L=K+768|0;c[I+600>>2]=L;P=K+1024|0;c[I+604>>2]=P;R=K+1280|0;c[I+608>>2]=R;S=K+1536|0;c[I+612>>2]=S;O=K+1792|0;c[I+616>>2]=O;c[I+1612>>2]=K;c[I+1616>>2]=N;c[I+1620>>2]=M;c[I+1624>>2]=L;c[I+1628>>2]=P;c[I+1632>>2]=R;c[I+1636>>2]=S;c[I+1640>>2]=O;c[I+2636>>2]=K;c[I+3660>>2]=K;c[I+2640>>2]=N;c[I+3664>>2]=N;c[I+2644>>2]=M;c[I+3668>>2]=M;c[I+2648>>2]=L;c[I+3672>>2]=L;c[I+2652>>2]=P;c[I+3676>>2]=P;c[I+2656>>2]=R;c[I+3680>>2]=R;c[I+2660>>2]=S;c[I+3684>>2]=S;c[I+2664>>2]=O;c[I+3688>>2]=O;c[I+4184>>2]=1828;c[I+4180>>2]=780;if(!D){O=I;gGC(O|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=J;c[2417276]=G;c[1836236]=-1;O=a[9680]|0;S=O?32e3:0;if(O){if(a[9624]|0){O=S*3|0;R=55930;while(1){if((R|0)>(O|0)){R=R>>1}else{W=1222;X=R;break}}}else{W=2462;X=S}c[2429380]=X;c[3542124]=W;mw(3579545,X);R=gGq(262144)|0;c[2406684]=R;gGz(R|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(3579545,11025)}h[745421]=.75;c[2436794]=3;h[745420]=.75;c[2436792]=3;R=c[3529772]|0;O=gGq(80)|0;G=O;c[2418506]=G;c[2424874]=G;gGz(O|0,0,80);a[635136]=0;c[O+4>>2]=~~(16.0e4/(a[9680]|0?32.0e3:0.0)*4194304.0);a[O+16|0]=0;if((R|0)==0){a[635136]=1}else{c[O+52>>2]=R}a[O+9|0]=1;a[(c[2424874]|0)+10|0]=1;O=c[2424874]|0;h[O+64>>3]=1.0;c[O+72>>2]=3;Vl();O=c[3529726]|0;R=gGq(80)|0;G=R;c[2418507]=G;c[2424874]=G;gGz(R|0,0,80);a[635136]=0;c[R+4>>2]=~~(16.0e4/(a[9680]|0?32.0e3:0.0)*4194304.0);a[R+16|0]=0;if((O|0)==0){a[635136]=1}else{c[R+52>>2]=O}a[R+9|0]=1;a[(c[2424874]|0)+10|0]=1;O=c[2424874]|0;h[O+64>>3]=1.0;c[O+72>>2]=3;Vl();O=c[2418506]|0;h[O+64>>3]=.3;c[O+72>>2]=3;c[2424874]=G;h[R+64>>3]=.3;c[R+72>>2]=3;R=c[3530930]|0;G=0;while(1){if((G|0)>=1024){Y=0;break}Z=9638528+(G<<2)|0;if((c[Z>>2]|0)==0){F=69567;break}else{G=G+1|0}}do{if((F|0)==69567){G=gGq(24576)|0;c[Z>>2]=G;if((G|0)==0){Y=0;break}gGz(G|0,0,24576);Y=G}}while(0);c[3529062]=Y;c[2438700]=524287;c[3529060]=R;a[7461784]=1;G=9726816;c[G>>2]=0;c[G+4>>2]=0;G=9726800;c[G>>2]=0;c[G+4>>2]=0;c[2429638]=0;c[2437692]=62;c[2431704]=0;c[2431700]=0;c[2431705]=0;c[2431701]=0;c[2431706]=0;c[2431702]=0;G=c[3530694]|0;c[2438136]=0;S=0;while(1){if((S|0)>=1024){_=0;break}$=9638528+(S<<2)|0;if((c[$>>2]|0)==0){F=69572;break}else{S=S+1|0}}do{if((F|0)==69572){S=gGq(1024)|0;c[$>>2]=S;if((S|0)==0){_=0;break}gGz(S|0,0,1024);_=S}}while(0);c[3529066]=_;c[2438702]=1048575;c[3529064]=G;a[7461792]=1;c[2437694]=28;c[2438136]=0;bi1(0,c[3530484]|0,c[2439846]|0,262143,2);c[3527138]=-104;c[3527139]=-16;S=c[642608+(c[2436]<<2)>>2]|0;R=c[S+128>>2]|0;if((c[S+52>>2]&4|0)==0){c[2113068]=R;O=c[S+132>>2]|0;c[2113070]=O;c[2443814]=R;c[2440436]=O;aa=R;ab=O}else{c[2113070]=R;O=c[S+132>>2]|0;c[2113068]=O;c[2440436]=R;c[2443814]=O;aa=O;ab=R}R=ag(aa<<1,ab)|0;O=gGq(R)|0;c[2112926]=O;if((O|0)!=0){gGz(O|0,0,R|0)}a[9624952]=0;R=c[2414792]|0;gGz(R|0,0,(c[2411852]|0)-R|0);c[363094]=0;c[2410673]=0;a[9642688]=0;a[9642689]=0;a[9642682]=0;a[9642683]=0;c[2410665]=0;a[9642680]=a[9642680]|80;R=c[2425163]|0;do{if((R|0)==0){O=c[3528598]|0;if((O|0)==0){ac=0;ad=0;break}S=gj[O&4095](-2)|0;O=c[2425163]|0;J=(S&255)<<8;if((O|0)!=0){ae=O;af=J;F=69583;break}O=c[3528598]|0;if((O|0)==0){ac=0;ad=J;break}ac=gj[O&4095](-1)|0;ad=J}else{ae=R;af=(d[R+254|0]|0)<<8;F=69583}}while(0);if((F|0)==69583){ac=a[ae+255|0]|0;ad=af}c[2410662]=ac&255|ad;c[363094]=-1;R=c[2439330]|0;G=(R|0)==0;if(!G){J=R;gGC(9706056,J|0,76)|0}J=c[2438118]|0;c[2433530]=J;O=c[3528484]|0;c[2076596]=O;S=c[2417276]|0;c[3541536]=S;c[1836236]=0;gGz(9706056,0,76);if(!G){G=R;gGC(G|0,9706056,76)|0}c[2438118]=J;c[3528484]=O;c[2417276]=S;c[1836236]=-1;mx(0);blH();Vl();c[2385182]=0;c[2440042]=0;c[2430472]=0;c[2439378]=0;H=0;i=e;return H|0}}while(0);c[2415084]=0;H=1;i=e;return H|0}function bkP(){var b=0,d=0,e=0,f=0;c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}blI();c[2444172]=0;c[3528598]=0;fwZ();b=c[3531464]|0;c[b+44344>>2]=0;c[b+44348>>2]=0;if((b|0)!=0){gGr(b);c[3531464]=0}b=c[2406684]|0;if((b|0)!=0){gGr(b);c[2406684]=0}b=c[2418506]|0;if((b|0)!=0){gGr(b);c[2418506]=0}b=c[2418507]|0;if((b|0)!=0){gGr(b);c[2418507]=0}a[635136]=0;b=c[2415084]|0;d=0;while(1){if((d|0)>=1024){e=69667;break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==(b|0)){break}else{d=d+1|0}}if((e|0)==69667){c[2415084]=0;return 0}gGr(b);c[f>>2]=0;c[2415084]=0;return 0}function bkQ(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((a[9624952]|0)!=0){a[9624952]=0;e=c[2414792]|0;gGz(e|0,0,(c[2411852]|0)-e|0);c[363094]=0;c[2410673]=0;a[9642688]=0;a[9642689]=0;a[9642682]=0;a[9642683]=0;c[2410665]=0;a[9642680]=a[9642680]|80;e=c[2425163]|0;do{if((e|0)==0){f=c[3528598]|0;if((f|0)==0){g=0;h=0;break}i=gj[f&4095](-2)|0;f=c[2425163]|0;j=(i&255)<<8;if((f|0)!=0){k=f;l=j;m=69673;break}f=c[3528598]|0;if((f|0)==0){g=0;h=j;break}g=gj[f&4095](-1)|0;h=j}else{k=e;l=d[e+254|0]<<8;m=69673}}while(0);if((m|0)==69673){g=a[k+255|0]|0;h=l}c[2410662]=g&255|h;c[363094]=-1;h=c[2439330]|0;g=(h|0)==0;if(!g){l=h;gGC(9706056,l|0,76)|0}l=c[2438118]|0;c[2433530]=l;k=c[3528484]|0;c[2076596]=k;m=c[2417276]|0;c[3541536]=m;c[1836236]=0;gGz(9706056,0,76);if(!g){g=h;gGC(g|0,9706056,76)|0}c[2438118]=l;c[3528484]=k;c[2417276]=m;c[1836236]=-1;mx(0);blH();Vl();c[2385182]=0;c[2440042]=0;c[2430472]=0;c[2439378]=0}gGz(9550904,-1|0,3);m=0;k=-1;l=-1;g=-1;do{k=((a[9634304+m|0]&1)<<m^k&255)&255;l=((a[9632064+m|0]&1)<<m^l&255)&255;g=((a[9629984+m|0]&1)<<m^g&255)&255;m=m+1|0;}while((m|0)<8);a[9550904]=k;a[9550905]=l;a[9550906]=g;c[2410673]=0;g=c[2385548]|0;if((g|0)>0){gGz(9752472,0,((g|0)>1?g<<2:4)|0)}c[2433530]=0;g=c[2439330]|0;if((g|0)!=0){l=g;gGC(9706056,l|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;c[363094]=0;l=0;g=0;k=0;m=0;L90288:while(1){h=g;e=k;j=m;do{if((j|0)>=100){break L90288}j=j+1|0;e=(fNF((j*665|0)-e|0)|0)+e|0;f=(j*596|0)-h|0;do{if((f|0)<1){n=0}else{if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){i=gfc(f)|0;c[2433530]=(c[2433530]|0)+i;n=i;break}else{c[2433530]=(c[2433530]|0)+f;n=f;break}}}while(0);h=n+h|0;o=c[2112964]|0;}while((o|0)==0);f=a[9688]|0?5:0;i=o+(l<<1<<1)|0;gg[c[3542124]&4095](i,f);Vj(0,i,f);Vj(1,i,f);l=f+l|0;g=h;k=e;m=j}if((c[3541228]|0)!=0){fNE(0,1);fNF(0)|0;a[9642682]=0;fNF(0)|0}m=c[2112964]|0;do{if((m|0)!=0){k=a[9688]|0?534:0;g=k-l|0;if((k|0)==(l|0)){break}k=m+(l<<1<<1)|0;gg[c[3542124]&4095](k,g);Vj(0,k,g);Vj(1,k,g)}}while(0);c[363094]=-1;l=c[1836236]|0;m=c[9757320+(l<<2)>>2]|0;if((m|0)!=0){g=m;gGC(g|0,9706056,76)|0}c[9752472+(l<<2)>>2]=c[2433530];c[14113936+(l<<2)>>2]=c[2076596];c[9669104+(l<<2)>>2]=c[3541536];c[1836236]=-1;if((c[2112968]|0)==0){return 0}bkR()|0;return 0}function bkR(){var d=0,e=0,f=0,g=0,h=0;if((a[9547944]|0)!=0){d=c[3530170]|0;e=c[2387266]|0;f=0;do{g=ga(b[e+(f<<1)>>1]|0)|0;c[d+(f<<2)>>2]=((g&65535)>>>10<<3&65535)>>>3&31|((g&255)<<3&255)<<8|(((g&65535)>>>5<<3&255|(g&65535)>>>7&4)&255)<<3&2016;f=f+1|0;}while((f|0)<2048)}bpj();f=c[2439898]|0;if((c[2430472]|0)==0){bpk(2,1,f);bi3(0);bpl(c[2439862]|0,0);bpk(1,0,c[2439898]|0);bpl(c[2439862]|0,1);bpk(0,0,c[2439898]|0);h=c[3530170]|0;R8(h);return 0}else{bpk(0,1,f);bpl(c[2439862]|0,1);bpk(2,0,c[2439898]|0);bpk(1,0,c[2439898]|0);bpl(c[2439862]|0,0);bi3(0);h=c[3530170]|0;R8(h);return 0}return 0}function bkS(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;e=i;i=i+208|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;l=e+80|0;m=e+96|0;n=e+112|0;o=e+128|0;p=e+144|0;q=e+160|0;r=e+176|0;s=e+192|0;t=(b|0)==0;if(!t){c[b>>2]=169733}if((a&96|0)!=0){gGz(s|0,0,12);u=c[2414792]|0;c[s>>2]=u;c[s+4>>2]=(c[2411852]|0)-u;c[s+12>>2]=162152;u=c[2076592]|0;gj[u&4095](s)|0;s=c[2410674]|0;u=c[2410675]|0;v=(a&64|0)==0;if(v){c[2410674]=s;c[2410675]=u;fw$(a);w=g;x=h|0}else{gGz(n|0,0,12);c[n>>2]=9642648;c[n+4>>2]=56;c[n+12>>2]=163840;y=c[2076592]|0;gj[y&4095](n)|0;gGz(m|0,0,12);c[m>>2]=9707480;c[m+4>>2]=2;c[m+12>>2]=501096;n=c[2076592]|0;gj[n&4095](m)|0;gGz(l|0,0,12);c[l>>2]=9707480;c[l+4>>2]=4;c[l+12>>2]=385184;m=c[2076592]|0;gj[m&4095](l)|0;c[2410674]=s;c[2410675]=u;fw$(a);gGz(k|0,0,12);c[k>>2]=8453216;c[k+4>>2]=4;c[k+12>>2]=107480;u=c[2076592]|0;gj[u&4095](k)|0;gGz(j|0,0,12);c[j>>2]=14168504;c[j+4>>2]=256;c[j+12>>2]=476464;k=c[2076592]|0;gj[k&4095](j)|0;if((a&2|0)==0){z=g;A=h|0}else{j=0;do{mv(0,j,d[14168504+j|0]|0);j=j+1|0;}while((j|0)<256);z=g;A=h|0}if(!t){c[b>>2]=169600}c[2424874]=c[2418506];j=h|0;cC(j|0,100600,(B=i,i=i+8|0,c[B>>2]=0,B)|0)|0;i=B;c[g>>2]=9699496;c[g+4>>2]=80;c[g+8>>2]=0;c[g+12>>2]=j;j=c[2076592]|0;gj[j&4095](g)|0;w=z;x=A}if(!v){if(!t){c[b>>2]=169600}c[2424874]=c[2418506];b=h|0;cC(b|0,100600,(B=i,i=i+8|0,c[B>>2]=0,B)|0)|0;i=B;c[f>>2]=9699496;c[f+4>>2]=80;c[f+8>>2]=0;c[f+12>>2]=b;b=c[2076592]|0;gj[b&4095](f)|0}blJ(a);gGz(r|0,0,12);c[r>>2]=9540728;c[r+4>>2]=4;c[r+12>>2]=587384;f=c[2076592]|0;gj[f&4095](r)|0;gGz(q|0,0,12);c[q>>2]=9760168;c[q+4>>2]=4;c[q+12>>2]=206016;r=c[2076592]|0;gj[r&4095](q)|0;gGz(p|0,0,12);c[p>>2]=9721888;c[p+4>>2]=4;c[p+12>>2]=554448;q=c[2076592]|0;gj[q&4095](p)|0;gGz(o|0,0,12);c[o>>2]=9757512;c[o+4>>2]=4;c[o+12>>2]=539768;p=c[2076592]|0;gj[p&4095](o)|0}if((a&2|0)==0){i=e;return 0}bkX(d[c[2394764]|0]|0);c[363094]=-1;i=e;return 0}function bkT(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>35){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2676004+(b*112|0)>>2];c[a+104>>2]=c[2676008+(b*112|0)>>2];c[a+108>>2]=c[2676012+(b*112|0)>>2];d=0;return d|0}function bkU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<36&(d|0)==0)){e=1;return e|0}c[a>>2]=2675904+(b*112|0);e=0;return e|0}function bkV(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>35){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2748932+(b*112|0)>>2];c[a+104>>2]=c[2748936+(b*112|0)>>2];c[a+108>>2]=c[2748940+(b*112|0)>>2];d=0;return d|0}function bkW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<36&(d|0)==0)){e=1;return e|0}c[a>>2]=2748832+(b*112|0);e=0;return e|0}function bkX(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a[c[2394764]|0]=b&255;d=b<<13&57344;e=d|65536;f=c[2387372]|0;g=0;h=0;while(1){i=f+((h<<8)+e)|0;c[9699632+(h<<2)>>2]=i;c[9701680+(h<<2)>>2]=i;i=g+1&65535;if((i&65535)<16){g=i;h=i&65535}else{break}}if((b&8|0)!=0){h=c[2387266]|0;g=0;e=0;while(1){i=e+16|0;j=h+(e<<8)|0;c[9699632+(i<<2)>>2]=j;c[9700656+(i<<2)>>2]=j;c[9701680+(i<<2)>>2]=j;j=g+1&65535;if((j&65535)<16){g=j;e=j&65535}else{break}}k=b&16;c[2385182]=k;l=b&32;c[3541230]=l;m=b&128;c[2430472]=m;return}e=d|69632;d=0;g=0;while(1){h=g+16|0;j=f+((g<<8)+e)|0;c[9699632+(h<<2)>>2]=j;c[9701680+(h<<2)>>2]=j;j=d+1&65535;if((j&65535)<16){d=j;g=j&65535}else{break}}c[2425180]=f;c[2425181]=f+256;c[2425182]=f+512;c[2425183]=f+768;c[2425184]=f+1024;c[2425185]=f+1280;c[2425186]=f+1536;c[2425187]=f+1792;c[2425188]=f+2048;c[2425189]=f+2304;c[2425190]=f+2560;c[2425191]=f+2816;c[2425192]=f+3072;c[2425193]=f+3328;c[2425194]=f+3584;c[2425195]=f+3840;k=b&16;c[2385182]=k;l=b&32;c[3541230]=l;m=b&128;c[2430472]=m;return}function bkY(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;c[d>>2]=c[d>>2]|b<<12|c[e>>2]<<8&3840;c[e>>2]=((c[e>>2]|0)>>>4&15)+(c[602560+(a<<2)>>2]|0);return}function bkZ(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;c[d>>2]=(c[b>>2]|0)>>>5&1;c[b>>2]=c[b>>2]&15|32;return}function bk_(a,b,d){a=a|0;b=b|0;d=d|0;c[d>>2]=c[b>>2]&64;c[a>>2]=c[b>>2]<<8&1792|c[a>>2];a=c[b>>2]|0;c[b>>2]=a>>>3&7|a>>>4&8|48;return}function bk$(b,d){b=b|0;d=d|0;var e=0,f=0;e=b&65535;if((e&61440|0)!=57344){return}b=e&4095;a[(c[2387840]|0)+b|0]=d;e=c[2387836]|0;f=b<<2;a[e+f|0]=(d&255)>>>6;a[e+(f|1)|0]=(d&255)>>>4&3;a[e+(f|2)|0]=(d&255)>>>2&3;a[e+(f|3)|0]=d&3;return}function bk0(a,d){a=a|0;d=d|0;if((a&255)!=20){return}US(0,gD[c[2385643]&8191]()|0);b[4771272]=~~(+(b[9732544+((d&-16&255)<<1)>>1]|0)*+h[1192819])&65535;US(1,gD[c[2385651]&8191]()|0);b[4771288]=~~(+(b[9732544+((d<<4&255)<<1)>>1]|0)*+h[1192823])&65535;return}function bk1(b){b=b|0;var c=0;switch(b&255|0){case 8:{c=a[9550896]|0;break};case 12:{c=~a[9550897];break};case 15:{c=~a[9550900];break};case 16:{c=~a[9550901];break};case 13:{c=~a[9550898];break};case 14:{c=~a[9550899];break};default:{c=0}}return c|0}function bk2(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>1){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5783212+(b*112|0)>>2];c[a+104>>2]=c[5783216+(b*112|0)>>2];c[a+108>>2]=c[5783220+(b*112|0)>>2];d=0;return d|0}function bk3(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<2&(d|0)==0)){e=1;return e|0}c[a>>2]=5783112+(b*112|0);e=0;return e|0}function bk4(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>41){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3720728+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function bk5(){var a=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;a=i;i=i+240|0;d=a|0;e=a+112|0;f=a+120|0;g=a+232|0;c[2415082]=0;c[2385992]=0;c[3531048]=32768;c[3530168]=32800;c[2414790]=32928;c[2387836]=32928;c[2387840]=49312;c[2386270]=53408;c[2386144]=57504;c[2411850]=65696;j=0;while(1){if((j|0)>=1024){break}k=9638528+(j<<2)|0;if((c[k>>2]|0)==0){l=69817;break}else{j=j+1|0}}do{if((l|0)==69817){j=gGq(65696)|0;c[k>>2]=j;if((j|0)==0){break}c[2415082]=j;gGz(j|0,0,65696);c[2385992]=j;c[3531048]=j+32768;c[3530168]=j+32800;m=j+32928|0;c[2414790]=m;c[2387836]=m;c[2387840]=j+49312;c[2386270]=j+53408;c[2386144]=j+57504;m=j+65696|0;c[2411850]=m;c[2414400]=m;if((c[3542200]|0)==0){n=1;i=a;return n|0}m=f+108|0;c[m>>2]=0;o=f+100|0;c[o>>2]=0;p=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[p&16383](f,0)|0;do{if((c[m>>2]|0)!=0){p=c[o>>2]|0;c[g>>2]=9534384;q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[q&16383](g,0,0)|0;if((p|0)<1){n=1;i=a;return n|0}if((gzL(j,0,0)|0)==0){break}else{n=1}i=a;return n|0}}while(0);j=c[3531048]|0;if((c[3542200]|0)==0){n=1;i=a;return n|0}o=d+108|0;c[o>>2]=0;m=d+100|0;c[m>>2]=0;p=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[p&16383](d,1)|0;do{if((c[o>>2]|0)!=0){p=c[m>>2]|0;c[e>>2]=9534384;q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[q&16383](e,1,0)|0;if((p|0)<1){n=1;i=a;return n|0}if((gzL(j,0,1)|0)==0){break}else{n=1}i=a;return n|0}}while(0);fwR(0);j=c[2439330]|0;m=(j|0)==0;if(!m){o=j;gGC(9706056,o|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];o=c[3528484]|0;c[2076596]=o;p=c[2417276]|0;c[3541536]=p;c[1836236]=0;q=c[2385992]|0;r=0;s=0;while(1){c[j+76+(s<<2)>>2]=q+(s<<8);t=r+1&65535;if((t&65535)>127){u=0;v=0;break}else{r=t;s=t&65535}}while(1){s=q+(v<<8)|0;c[j+76+(v+512<<2)>>2]=s;c[j+76+(v+768<<2)>>2]=s;s=u+1&65535;if((s&65535)>127){break}else{u=s;v=s&65535}}q=c[2386144]|0;s=192;r=192;while(1){c[j+76+(r<<2)>>2]=q+((r<<8)-49152);t=s+1&65535;if((t&65535)>223){w=192;x=192;break}else{s=t;r=t&65535}}while(1){c[j+76+(x+256<<2)>>2]=q+((x<<8)-49152);r=w+1&65535;if((r&65535)>223){y=192;z=192;break}else{w=r;x=r&65535}}while(1){r=q+((z<<8)-49152)|0;c[j+76+(z+512<<2)>>2]=r;c[j+76+(z+768<<2)>>2]=r;r=y+1&65535;if((r&65535)>223){break}else{y=r;z=r&65535}}q=c[2387840]|0;c[j+972>>2]=q;c[j+976>>2]=q+256;c[j+980>>2]=q+512;c[j+984>>2]=q+768;c[j+988>>2]=q+1024;c[j+992>>2]=q+1280;c[j+996>>2]=q+1536;c[j+1e3>>2]=q+1792;c[j+1004>>2]=q+2048;c[j+1008>>2]=q+2304;c[j+1012>>2]=q+2560;c[j+1016>>2]=q+2816;c[j+1020>>2]=q+3072;c[j+1024>>2]=q+3328;c[j+1028>>2]=q+3584;c[j+1032>>2]=q+3840;r=224;s=224;while(1){t=q+((s<<8)-57344)|0;c[j+76+(s+512<<2)>>2]=t;c[j+76+(s+768<<2)>>2]=t;t=r+1&65535;if((t&65535)>239){break}else{r=t;s=t&65535}}s=c[2386270]|0;c[j+1036>>2]=s;c[j+1040>>2]=s+256;c[j+1044>>2]=s+512;c[j+1048>>2]=s+768;c[j+1052>>2]=s+1024;c[j+1056>>2]=s+1280;c[j+1060>>2]=s+1536;c[j+1064>>2]=s+1792;c[j+1068>>2]=s+2048;c[j+1072>>2]=s+2304;c[j+1076>>2]=s+2560;c[j+1080>>2]=s+2816;c[j+1084>>2]=s+3072;c[j+1088>>2]=s+3328;c[j+1092>>2]=s+3584;c[j+1096>>2]=s+3840;r=240;q=240;while(1){c[j+76+(q+256<<2)>>2]=s+((q<<8)-61440);t=r+1&65535;if((t&65535)>255){A=240;B=240;break}else{r=t;q=t&65535}}while(1){q=s+((B<<8)-61440)|0;c[j+76+(B+512<<2)>>2]=q;c[j+76+(B+768<<2)>>2]=q;q=A+1&65535;if((q&65535)>255){break}else{A=q;B=q&65535}}c[j+4184>>2]=1114;c[j+4176>>2]=3002;c[j+4172>>2]=840;if(!m){s=j;gGC(s|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=o;c[2417276]=p;c[1836236]=-1;c[2405758]=1;gGz(9542544,0,32);c[2385641]=1;h[1192819]=1.0;c[2385642]=3;c[2385643]=4378;s=0;do{q=s*257|0;b[9732544+(s<<1)>>1]=((q|0)/2|0)&65535;b[9753784+(s<<1)>>1]=q+32768&65535;s=s+1|0;}while((s|0)<256);c[3528842]=0;c[2405758]=2;gGz(9542576,0,32);c[2385649]=1;h[1192823]=1.0;c[2385650]=3;c[2385651]=4378;s=0;do{p=s*257|0;b[9732544+(s<<1)>>1]=((p|0)/2|0)&65535;b[9753784+(s<<1)>>1]=p+32768&65535;s=s+1|0;}while((s|0)<256);c[3528842]=0;h[1192819]=.5;c[2385642]=1;h[1192823]=.5;c[2385650]=2;s=c[642608+(c[2436]<<2)>>2]|0;p=c[s+128>>2]|0;if((c[s+52>>2]&4|0)==0){c[2113068]=p;o=c[s+132>>2]|0;c[2113070]=o;c[2443814]=p;c[2440436]=o;C=p;D=o}else{c[2113070]=p;o=c[s+132>>2]|0;c[2113068]=o;c[2440436]=p;c[2443814]=o;C=o;D=p}p=ag(C<<1,D)|0;o=gGq(p)|0;c[2112926]=o;if((o|0)!=0){gGz(o|0,0,p|0)}p=c[2414790]|0;gGz(p|0,0,(c[2411850]|0)-p|0);p=c[2439330]|0;o=(p|0)==0;if(!o){s=p;gGC(9706056,s|0,76)|0}s=c[2438118]|0;c[2433530]=s;j=c[3528484]|0;c[2076596]=j;m=c[2417276]|0;c[3541536]=m;c[1836236]=0;gGz(9706056,0,76);if(!o){o=p;gGC(o|0,9706056,76)|0}c[2438118]=s;c[3528484]=j;c[2417276]=m;c[1836236]=-1;m=c[2405758]|0;if((m|0)>0){E=0}else{n=0;i=a;return n|0}while(1){c[9542560+(E<<5)>>2]=0;b[9542544+(E<<5)>>1]=0;j=E+1|0;if((j|0)<(m|0)){E=j}else{n=0;break}}i=a;return n|0}}while(0);c[2415082]=0;n=1;i=a;return n|0}function bk6(){var a=0,b=0,d=0,e=0;c[2113070]=0;c[2113068]=0;a=c[2112926]|0;if((a|0)!=0){gGr(a);c[2112926]=0}fwZ();UT();a=c[2415082]|0;b=0;while(1){if((b|0)>=1024){d=69876;break}e=9638528+(b<<2)|0;if((c[e>>2]|0)==(a|0)){break}else{b=b+1|0}}if((d|0)==69876){c[2415082]=0;return 0}gGr(a);c[e>>2]=0;c[2415082]=0;return 0}function bk7(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;do{if((a[9624944]|0)!=0){d=c[2414790]|0;gGz(d|0,0,(c[2411850]|0)-d|0);d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;h=c[2417276]|0;c[3541536]=h;c[1836236]=0;gGz(9706056,0,76);if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=h;c[1836236]=-1;h=c[2405758]|0;if((h|0)>0){i=0}else{break}do{c[9542560+(i<<5)>>2]=0;b[9542544+(i<<5)>>1]=0;i=i+1|0;}while((i|0)<(h|0))}}while(0);i=c[2385548]|0;if((i|0)>0){gGz(9752472,0,((i|0)>1?i<<2:4)|0)}c[2433530]=0;a[9550896]=-1;C=0;a[9550897]=C&255;C=C>>8;a[9550898]=C&255;C=C>>8;a[9550899]=C&255;C=C>>8;a[9550900]=C&255;i=0;h=-1;g=0;f=0;e=0;d=0;do{h=((a[9634296+i|0]&1)<<i^h&255)&255;g=((a[9632056+i|0]&1)<<i|g&255)&255;f=((a[9629976+i|0]&1)<<i|f&255)&255;e=((a[9629080+i|0]&1)<<i|e&255)&255;d=((a[9628832+i|0]&1)<<i|d&255)&255;i=i+1|0;}while((i|0)<8);a[9550896]=h;a[9550897]=g;a[9550898]=f;a[9550899]=e;a[9550900]=d;a[9550901]=a[9635776]&1;if((g&3)==3){h=g&-4;a[9550897]=h;j=h}else{j=g}if((j&12)==12){a[9550897]=j&-13}if((f&3)==3){j=f&-4;a[9550898]=j;k=j}else{k=f}if((k&12)==12){a[9550898]=k&-13}if((e&3)==3){k=e&-4;a[9550899]=k;l=k}else{l=e}if((l&12)==12){a[9550899]=l&-13}if((d&3)==3){l=d&-4;a[9550900]=l;m=l}else{m=d}if((m&12)==12){a[9550900]=m&-13}m=c[2439330]|0;if((m|0)!=0){d=m;gGC(9706056,d|0,76)|0}b[4853030]=c[2426515]&65535;d=c[2438118]|0;c[2433530]=d;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;if((a[m+4188|0]|0)==0){m=gfc(5e4)|0;n=(c[2433530]|0)+m|0}else{n=d+5e4|0}c[2433530]=n;a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0;n=c[2112964]|0;if((n|0)!=0){UR(n,a[9688]|0?534:0)}n=c[1836236]|0;d=c[9757320+(n<<2)>>2]|0;if((d|0)!=0){m=d;gGC(m|0,9706056,76)|0}c[9752472+(n<<2)>>2]=c[2433530];c[14113936+(n<<2)>>2]=c[2076596];c[9669104+(n<<2)>>2]=c[3541536];c[1836236]=-1;if((c[2112968]|0)==0){return 0}bk8()|0;return 0}function bk8(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0;if((a[9547936]|0)!=0){b=c[3531048]|0;e=c[3530168]|0;f=0;do{g=d[b+f|0]|0;c[e+((f<<2&28|f>>>3&3)<<2)>>2]=(-(g>>>3&1)&33)+(-(g>>>4&1)&71)+(-(g>>>5&1)&151)<<3&2016|((-(g>>>6&1)&71)+(-(g>>>7)&151)|0)>>>3&31|(-(g>>>1&1)&71)+(-(g&1)&33)+(-(g>>>2&1)&151)<<8&63488;f=f+1|0;}while((f|0)<32);a[9547936]=0}f=c[2386270]|0;e=c[2112926]|0;b=c[2387836]|0;g=0;do{h=g<<3&504;i=h^256;j=i>>>0>255?h^384:i;if(j>>>0<=319){Si(e,d[f+g|0]|0,j,g>>6<<3,(d[f+(g+2048)|0]|0)>>>1&7,2,0,b)}g=g+1|0;}while((g|0)<2048);R8(c[3530168]|0);return 0}function bk9(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=i;i=i+32|0;e=d|0;f=d+16|0;g=(b|0)==0;if(!g){c[b>>2]=169624}if((a&32|0)!=0){gGz(f|0,0,12);h=c[2414790]|0;c[f>>2]=h;c[f+4>>2]=(c[2411850]|0)-h;c[f+12>>2]=162152;h=c[2076592]|0;gj[h&4095](f)|0}if((a&64|0)==0){i=d;return 0}fw$(a);if(!g){c[b>>2]=169753}if((c[2405758]|0)<=0){i=d;return 0}b=e;g=e|0;a=e+4|0;f=e+12|0;h=0;do{gGz(b|0,0,12);c[g>>2]=9542544+(h<<5);c[a>>2]=2;c[f>>2]=119040;gj[c[2076592]&4095](e)|0;h=h+1|0;}while((h|0)<(c[2405758]|0));i=d;return 0}function bla(){return~~((a[9688]|0?534.0:0.0)*(+((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)/(3.0e6/(+(c[2424]|0)/100.0))))|0}function blb(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;f=b&65535;switch(f|0){case 8064:{g=e&255;if(a[638592]|0){blc(g);return}a[c[2438168]|0]=e;if((g&16|0)==0){h=c[2387264]|0;c[2424996]=h;c[2425252]=h;c[2425508]=h;i=h+256|0;c[2424997]=i;c[2425253]=i;c[2425509]=i;i=h+512|0;c[2424998]=i;c[2425254]=i;c[2425510]=i;i=h+768|0;c[2424999]=i;c[2425255]=i;c[2425511]=i;i=h+1024|0;c[2425e3]=i;c[2425256]=i;c[2425512]=i;i=h+1280|0;c[2425001]=i;c[2425257]=i;c[2425513]=i;j=h;k=h+1536|0}else{h=c[3531084]|0;c[2424996]=h;c[2425252]=h;c[2425508]=h;i=h+256|0;c[2424997]=i;c[2425253]=i;c[2425509]=i;i=h+512|0;c[2424998]=i;c[2425254]=i;c[2425510]=i;i=h+768|0;c[2424999]=i;c[2425255]=i;c[2425511]=i;i=h+1024|0;c[2425e3]=i;c[2425256]=i;c[2425512]=i;i=h+1280|0;c[2425001]=i;c[2425257]=i;c[2425513]=i;j=h;k=h+1536|0}c[2425002]=k;c[2425258]=k;c[2425514]=k;k=j+1792|0;c[2425003]=k;c[2425259]=k;c[2425515]=k;k=(g<<13&122880)+65536|0;g=c[2387370]|0;j=0;h=0;while(1){i=h+96|0;l=g+(k+(h<<8))|0;c[9699632+(i<<2)>>2]=l;c[9701680+(i<<2)>>2]=l;l=j+1&65535;if((l&65535)<32){j=l;h=l&65535}else{break}}return};case 8068:{a[c[3528354]|0]=e;return};case 8072:{a[9706117]=1;return};case 8088:{h=e&255;c[3541230]=h&1;do{if((h&4|0)!=0){if((a[9719136]&4)!=0){break}j=c[2409604]|0;k=(((d[j]|0)<<8|(d[j+1|0]|0))-15|0)/5|0;g=((d[j+2|0]|0)-15|0)/5|0;l=a[j+5|0]|0;i=l&255;if((l&255)<16){m=d[j+6|0]|0|i<<8;n=j+7|0}else{m=i;n=j+6|0}i=(m-16|0)/5|0;l=((d[n]|0)-16|0)/5|0;o=a[j+3|0]|0;p=a[j+4|0]|0;if((i|0)<(k|0)&(l|0)<(g|0)){q=j+((l*5|0)+16)|0;r=j+((i*5|0)+16)|0;j=i;while(1){if((a[r]&o)<<24>>24!=0){i=d[r+3|0]|0;s=d[r+1|0]|0;t=i-s|0;u=s+i|0;i=d[r+4|0]|0;s=d[r+2|0]|0;v=i-s|0;w=s+i|0;i=q;s=l;while(1){x=a[i]|0;do{if((x&p)<<24>>24!=0){y=d[i+3|0]|0;z=d[i+1|0]|0;A=d[i+4|0]|0;B=d[i+2|0]|0;if(!((y-z|0)<(u|0)&(t|0)<(z+y|0)&(A-B|0)<(w|0)&(v|0)<(B+A|0))){break}a[r]=x&4|a[r]&-113|16;a[i]=a[i]&-113|16}}while(0);x=s+1|0;if((x|0)<(g|0)){i=i+5|0;s=x}else{break}}}s=j+1|0;if((s|0)<(k|0)){r=r+5|0;j=s}else{break}}}fNF(10)|0;fNE(1,1);fNF(0)|0;a[9642683]=0;fNF(0)|0}}while(0);a[9719136]=e;return};case 8076:{return};default:{if((b&65535)>=16384){return}blF(f&16383,e&255);return}}}function blc(b){b=b|0;var d=0,e=0;a[c[2438168]|0]=b&255;if((b&1|0)!=0){d=c[3531084]|0;c[2424996]=d;c[2425252]=d;c[2425508]=d;e=d+256|0;c[2424997]=e;c[2425253]=e;c[2425509]=e;e=d+512|0;c[2424998]=e;c[2425254]=e;c[2425510]=e;e=d+768|0;c[2424999]=e;c[2425255]=e;c[2425511]=e;e=d+1024|0;c[2425e3]=e;c[2425256]=e;c[2425512]=e;e=d+1280|0;c[2425001]=e;c[2425257]=e;c[2425513]=e;e=d+1536|0;c[2425002]=e;c[2425258]=e;c[2425514]=e;e=d+1792|0;c[2425003]=e;c[2425259]=e;c[2425515]=e;return}if((b&16|0)==0){b=c[2387264]|0;c[2424996]=b;c[2425252]=b;c[2425508]=b;e=b+256|0;c[2424997]=e;c[2425253]=e;c[2425509]=e;e=b+512|0;c[2424998]=e;c[2425254]=e;c[2425510]=e;e=b+768|0;c[2424999]=e;c[2425255]=e;c[2425511]=e;e=b+1024|0;c[2425e3]=e;c[2425256]=e;c[2425512]=e;e=b+1280|0;c[2425001]=e;c[2425257]=e;c[2425513]=e;e=b+1536|0;c[2425002]=e;c[2425258]=e;c[2425514]=e;e=b+1792|0;c[2425003]=e;c[2425259]=e;c[2425515]=e;return}e=c[2409604]|0;if((a[9719136]&2)==0){c[2424996]=e;c[2425252]=e;c[2425508]=e;b=e+256|0;c[2424997]=b;c[2425253]=b;c[2425509]=b;b=e+512|0;c[2424998]=b;c[2425254]=b;c[2425510]=b;b=e+768|0;c[2424999]=b;c[2425255]=b;c[2425511]=b;b=e+1024|0;c[2425e3]=b;c[2425256]=b;c[2425512]=b;b=e+1280|0;c[2425001]=b;c[2425257]=b;c[2425513]=b;b=e+1536|0;c[2425002]=b;c[2425258]=b;c[2425514]=b;b=e+1792|0;c[2425003]=b;c[2425259]=b;c[2425515]=b;return}else{b=e+2048|0;c[2424996]=b;c[2425252]=b;c[2425508]=b;b=e+2304|0;c[2424997]=b;c[2425253]=b;c[2425509]=b;b=e+2560|0;c[2424998]=b;c[2425254]=b;c[2425510]=b;b=e+2816|0;c[2424999]=b;c[2425255]=b;c[2425511]=b;b=e+3072|0;c[2425e3]=b;c[2425256]=b;c[2425512]=b;b=e+3328|0;c[2425001]=b;c[2425257]=b;c[2425513]=b;b=e+3584|0;c[2425002]=b;c[2425258]=b;c[2425514]=b;b=e+3840|0;c[2425003]=b;c[2425259]=b;c[2425515]=b;return}}function bld(b){b=b|0;var c=0,d=0;c=b&65535;L90684:do{switch(c|0){case 8080:{d=a[9550888]|0;break};case 8081:{d=a[9550889]|0;break};case 8088:{d=a[9719136]|0;break};case 8084:{d=a[9635632]|0;break};case 8085:{d=a[9635633]|0;break};case 8082:{d=a[9550890]|0;break};case 8083:{d=a[9635634]|0;break};default:{if((b&65535)>=16384){d=0;break L90684}d=blE(c&16383)|0}}}while(0);return d|0}function ble(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((e&65520|0)==45056){TI(0,e&15,d&255);return}if((e|0)==49152){c[2113304]=d&255;return}else if((e|0)==61440){b=d&255;c[2424878]=9681232;c[2420315]=b<<17&393216;c[2420316]=b>>>2<<17&393216;return}else if((e|0)==49153){e=c[2113304]|0;a[14168504+e|0]=d;mv(0,e,d&255);return}else{return}}function blf(b){b=b|0;var e=0,f=0,g=0,h=0;e=b&65535;if((e&65520|0)==45056){b=e&15;c[2424878]=9681232;c[2426622]=9622928;if(!((b|0)==11|(b|0)==5)){f=0;return f|0}g=(b>>>0)/6|0;b=g*6|0;h=(d[b+9681280|0]|0)<<16&65536|(d[b+9681279|0]|0)<<8|(d[b+9681278|0]|0)|c[9681260+(g<<2)>>2];c[9681244+(g<<2)>>2]=h;if(h>>>0>=(c[2405735]|0)>>>0){f=0;return f|0}c[9681268+(g<<2)>>2]=1;c[9681236+(g<<2)>>2]=0;f=0;return f|0}else{if((e|0)==49153){f=c[(c[3531464]|0)+4240>>2]&255;return f|0}else if((e|0)==40960){a[9706117]=0;f=a[c[3528354]|0]|0;return f|0}else{f=0;return f|0}}return 0}function blg(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>39){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4419788+(b*112|0)>>2];c[a+104>>2]=c[4419792+(b*112|0)>>2];c[a+108>>2]=c[4419796+(b*112|0)>>2];d=0;return d|0}function blh(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<40&(d|0)==0)){e=1;return e|0}c[a>>2]=4419688+(b*112|0);e=0;return e|0}function bli(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1179688+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function blj(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>59){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5089800+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function blk(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0;e=i;i=i+1560|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;B=e+1200|0;C=e+1312|0;D=e+1320|0;E=e+1432|0;F=e+1440|0;G=e+1552|0;c[2415080]=0;c[2387370]=0;c[2385990]=262144;c[3530928]=327680;c[3530692]=1376256;c[2439896]=2424832;c[2439860]=4521984;c[2386688]=6619136;c[3530166]=7143424;c[2414788]=7147520;c[3531084]=7147520;c[2387394]=7149568;c[2387264]=7155712;c[2386142]=7157760;c[3528354]=7159808;c[2438168]=7159809;c[2409604]=7159811;c[2411848]=7163907;H=0;while(1){if((H|0)>=1024){break}I=9638528+(H<<2)|0;if((c[I>>2]|0)==0){J=70057;break}else{H=H+1|0}}do{if((J|0)==70057){H=gGq(7163907)|0;c[I>>2]=H;if((H|0)==0){break}c[2415080]=H;gGz(H|0,0,7163907);c[2387370]=H;c[2385990]=H+262144;c[3530928]=H+327680;c[3530692]=H+1376256;c[2439896]=H+2424832;c[2439860]=H+4521984;c[2386688]=H+6619136;c[3530166]=H+7143424;K=H+7147520|0;c[2414788]=K;c[3531084]=K;c[2387394]=H+7149568;c[2387264]=H+7155712;c[2386142]=H+7157760;c[3528354]=H+7159808;c[2438168]=H+7159809;c[2409604]=H+7159811;K=H+7163907|0;c[2411848]=K;c[2414398]=K;K=c[642608+(c[2436]<<2)>>2]|0;L=(dW(c[K>>2]|0,519832,7)|0)==0;M=H+65536|0;do{if((c[3542200]|0)==0){N=1}else{H=F+108|0;c[H>>2]=0;O=F+100|0;c[O>>2]=0;P=c[K+76>>2]|0;gA[P&16383](F,0)|0;if((c[H>>2]|0)==0){N=0;break}H=c[O>>2]|0;c[G>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](G,0,0)|0;if((H|0)<1){N=1;break}N=(gzL(M,0,0)|0)!=0}}while(0);do{if(L){if(N){Q=1;i=e;return Q|0}M=(c[2387370]|0)+131072|0;if((c[3542200]|0)==0){Q=1;i=e;return Q|0}K=D+108|0;c[K>>2]=0;H=D+100|0;c[H>>2]=0;O=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[O&16383](D,1)|0;do{if((c[K>>2]|0)!=0){O=c[H>>2]|0;c[E>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](E,1,0)|0;if((O|0)<1){Q=1;i=e;return Q|0}if((gzL(M,0,1)|0)==0){break}else{Q=1}i=e;return Q|0}}while(0);M=c[2387370]|0;H=M+32768|0;K=M+98304|0;gGC(H|0,K|0,32768)|0;K=c[2385990]|0;if((c[3542200]|0)==0){Q=1;i=e;return Q|0}H=B+108|0;c[H>>2]=0;M=B+100|0;c[M>>2]=0;O=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[O&16383](B,2)|0;do{if((c[H>>2]|0)!=0){O=c[M>>2]|0;c[C>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](C,2,0)|0;if((O|0)<1){Q=1;i=e;return Q|0}if((gzL(K,0,2)|0)==0){break}else{Q=1}i=e;return Q|0}}while(0);if((R6(c[3530928]|0,3,2)|0)!=0){Q=1;i=e;return Q|0}if((R6((c[3530928]|0)+1|0,4,2)|0)!=0){Q=1;i=e;return Q|0}if((R6((c[3530928]|0)+262144|0,5,2)|0)!=0){Q=1;i=e;return Q|0}if((R6((c[3530928]|0)+262145|0,6,2)|0)!=0){Q=1;i=e;return Q|0}if((R6((c[3530928]|0)+393216|0,7,2)|0)!=0){Q=1;i=e;return Q|0}if((R6((c[3530928]|0)+393217|0,8,2)|0)!=0){Q=1;i=e;return Q|0}if((R6((c[3530928]|0)+524288|0,9,2)|0)!=0){Q=1;i=e;return Q|0}if((R6((c[3530928]|0)+524289|0,10,2)|0)!=0){Q=1;i=e;return Q|0}if((R6((c[3530928]|0)+786432|0,11,2)|0)!=0){Q=1;i=e;return Q|0}if((R6((c[3530928]|0)+786433|0,12,2)|0)!=0){Q=1;i=e;return Q|0}if((R6((c[3530928]|0)+917504|0,13,2)|0)!=0){Q=1;i=e;return Q|0}if((R6((c[3530928]|0)+917505|0,14,2)|0)!=0){Q=1;i=e;return Q|0}if((R6(c[3530692]|0,15,2)|0)!=0){Q=1;i=e;return Q|0}if((R6((c[3530692]|0)+1|0,16,2)|0)!=0){Q=1;i=e;return Q|0}if((R6((c[3530692]|0)+131072|0,17,2)|0)!=0){Q=1;i=e;return Q|0}if((R6((c[3530692]|0)+131073|0,18,2)|0)!=0){Q=1;i=e;return Q|0}if((R6((c[3530692]|0)+262144|0,19,2)|0)!=0){Q=1;i=e;return Q|0}if((R6((c[3530692]|0)+262145|0,20,2)|0)!=0){Q=1;i=e;return Q|0}if((R6((c[3530692]|0)+393216|0,21,2)|0)!=0){Q=1;i=e;return Q|0}if((R6((c[3530692]|0)+393217|0,22,2)|0)!=0){Q=1;i=e;return Q|0}if((R6((c[3530692]|0)+524288|0,23,2)|0)!=0){Q=1;i=e;return Q|0}if((R6((c[3530692]|0)+524289|0,24,2)|0)!=0){Q=1;i=e;return Q|0}if((R6((c[3530692]|0)+655360|0,25,2)|0)!=0){Q=1;i=e;return Q|0}if((R6((c[3530692]|0)+655361|0,26,2)|0)!=0){Q=1;i=e;return Q|0}if((R6((c[3530692]|0)+786432|0,27,2)|0)!=0){Q=1;i=e;return Q|0}if((R6((c[3530692]|0)+786433|0,28,2)|0)!=0){Q=1;i=e;return Q|0}if((R6((c[3530692]|0)+917504|0,29,2)|0)!=0){Q=1;i=e;return Q|0}if((R6((c[3530692]|0)+917505|0,30,2)|0)!=0){Q=1;i=e;return Q|0}K=c[2386688]|0;if((c[3542200]|0)==0){Q=1;i=e;return Q|0}M=z+108|0;c[M>>2]=0;H=z+100|0;c[H>>2]=0;O=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[O&16383](z,31)|0;do{if((c[M>>2]|0)!=0){O=c[H>>2]|0;c[A>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](A,31,0)|0;if((O|0)<1){Q=1;i=e;return Q|0}if((gzL(K,0,31)|0)==0){break}else{Q=1}i=e;return Q|0}}while(0);K=(c[2386688]|0)+65536|0;if((c[3542200]|0)==0){Q=1;i=e;return Q|0}H=x+108|0;c[H>>2]=0;M=x+100|0;c[M>>2]=0;O=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[O&16383](x,32)|0;do{if((c[H>>2]|0)!=0){O=c[M>>2]|0;c[y>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](y,32,0)|0;if((O|0)<1){Q=1;i=e;return Q|0}if((gzL(K,0,32)|0)==0){break}else{Q=1}i=e;return Q|0}}while(0);K=(c[2386688]|0)+131072|0;if((c[3542200]|0)==0){Q=1;i=e;return Q|0}M=v+108|0;c[M>>2]=0;H=v+100|0;c[H>>2]=0;O=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[O&16383](v,33)|0;do{if((c[M>>2]|0)!=0){O=c[H>>2]|0;c[w>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](w,33,0)|0;if((O|0)<1){Q=1;i=e;return Q|0}if((gzL(K,0,33)|0)==0){break}else{Q=1}i=e;return Q|0}}while(0);K=(c[2386688]|0)+196608|0;if((c[3542200]|0)==0){Q=1;i=e;return Q|0}H=t+108|0;c[H>>2]=0;M=t+100|0;c[M>>2]=0;O=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[O&16383](t,34)|0;do{if((c[H>>2]|0)!=0){O=c[M>>2]|0;c[u>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](u,34,0)|0;if((O|0)<1){Q=1;i=e;return Q|0}if((gzL(K,0,34)|0)==0){break}else{Q=1}i=e;return Q|0}}while(0);K=(c[2386688]|0)+262144|0;if((c[3542200]|0)==0){Q=1;i=e;return Q|0}M=r+108|0;c[M>>2]=0;H=r+100|0;c[H>>2]=0;O=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[O&16383](r,35)|0;do{if((c[M>>2]|0)!=0){O=c[H>>2]|0;c[s>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](s,35,0)|0;if((O|0)<1){Q=1;i=e;return Q|0}if((gzL(K,0,35)|0)==0){break}else{Q=1}i=e;return Q|0}}while(0);K=(c[2386688]|0)+327680|0;if((c[3542200]|0)==0){Q=1;i=e;return Q|0}H=p+108|0;c[H>>2]=0;M=p+100|0;c[M>>2]=0;O=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[O&16383](p,36)|0;do{if((c[H>>2]|0)!=0){O=c[M>>2]|0;c[q>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](q,36,0)|0;if((O|0)<1){Q=1;i=e;return Q|0}if((gzL(K,0,36)|0)==0){break}else{Q=1}i=e;return Q|0}}while(0);K=(c[2386688]|0)+393216|0;if((c[3542200]|0)==0){Q=1;i=e;return Q|0}M=n+108|0;c[M>>2]=0;H=n+100|0;c[H>>2]=0;O=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[O&16383](n,37)|0;do{if((c[M>>2]|0)!=0){O=c[H>>2]|0;c[o>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](o,37,0)|0;if((O|0)<1){Q=1;i=e;return Q|0}if((gzL(K,0,37)|0)==0){break}else{Q=1}i=e;return Q|0}}while(0);K=(c[2386688]|0)+458752|0;if((c[3542200]|0)==0){Q=1;i=e;return Q|0}H=l+108|0;c[H>>2]=0;M=l+100|0;c[M>>2]=0;O=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[O&16383](l,38)|0;do{if((c[H>>2]|0)!=0){O=c[M>>2]|0;c[m>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](m,38,0)|0;if((O|0)<1){Q=1;i=e;return Q|0}if((gzL(K,0,38)|0)==0){break}else{Q=1}i=e;return Q|0}}while(0);K=a[638592]|0;R=K&1;S=K&1}else{if(N){Q=1;i=e;return Q|0}K=(c[2387370]|0)+131072|0;if((c[3542200]|0)==0){Q=1;i=e;return Q|0}M=j+108|0;c[M>>2]=0;H=j+100|0;c[H>>2]=0;O=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[O&16383](j,1)|0;do{if((c[M>>2]|0)!=0){O=c[H>>2]|0;c[k>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](k,1,0)|0;if((O|0)<1){Q=1;i=e;return Q|0}if((gzL(K,0,1)|0)==0){break}else{Q=1}i=e;return Q|0}}while(0);K=c[2387370]|0;H=K+32768|0;M=K+163840|0;gGC(H|0,M|0,32768)|0;M=c[2385990]|0;if((c[3542200]|0)==0){Q=1;i=e;return Q|0}H=f+108|0;c[H>>2]=0;K=f+100|0;c[K>>2]=0;O=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[O&16383](f,2)|0;do{if((c[H>>2]|0)!=0){O=c[K>>2]|0;c[g>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](g,2,0)|0;if((O|0)<1){Q=1;i=e;return Q|0}if((gzL(M,0,2)|0)==0){break}else{Q=1}i=e;return Q|0}}while(0);if((R6(c[3530928]|0,3,2)|0)!=0){Q=1;i=e;return Q|0}if((R6((c[3530928]|0)+1|0,4,2)|0)!=0){Q=1;i=e;return Q|0}if((R6((c[3530928]|0)+131072|0,5,2)|0)!=0){Q=1;i=e;return Q|0}if((R6((c[3530928]|0)+131073|0,6,2)|0)!=0){Q=1;i=e;return Q|0}if((R6((c[3530928]|0)+262144|0,7,2)|0)!=0){Q=1;i=e;return Q|0}if((R6((c[3530928]|0)+262145|0,8,2)|0)!=0){Q=1;i=e;return Q|0}if((R6((c[3530928]|0)+393216|0,9,2)|0)!=0){Q=1;i=e;return Q|0}if((R6((c[3530928]|0)+393217|0,10,2)|0)!=0){Q=1;i=e;return Q|0}if((R6(c[3530692]|0,11,2)|0)!=0){Q=1;i=e;return Q|0}if((R6((c[3530692]|0)+1|0,12,2)|0)!=0){Q=1;i=e;return Q|0}if((R6((c[3530692]|0)+131072|0,13,2)|0)!=0){Q=1;i=e;return Q|0}if((R6((c[3530692]|0)+131073|0,14,2)|0)!=0){Q=1;i=e;return Q|0}if((R6((c[3530692]|0)+262144|0,15,2)|0)!=0){Q=1;i=e;return Q|0}if((R6((c[3530692]|0)+262145|0,16,2)|0)!=0){Q=1;i=e;return Q|0}if((R6((c[3530692]|0)+393216|0,17,2)|0)!=0){Q=1;i=e;return Q|0}if((R6((c[3530692]|0)+393217|0,18,2)|0)==0){a[638592]=1;R=1;S=1;break}else{Q=1;i=e;return Q|0}}}while(0);L=c[3530928]|0;blG(L,(1048576>>>(R>>>0)|0)/2|0);M=c[3530692]|0;blG(M,(1048576>>>(S>>>0)|0)/2|0);K=32768>>>(S>>>0);H=c[2439896]|0;if((K|0)>0){O=0;do{P=O<<6;gGz(H+P|0,0,64);T=O<<8;U=0;do{V=1<<3-U;W=(c[611632+(U<<2)>>2]|0)+T|0;X=0;do{Y=W+(c[3946808+(X<<2)>>2]|0)|0;Z=(X<<3)+P|0;_=0;do{$=Y+(c[6669416+(_<<2)>>2]|0)|0;if(((d[L+(($|0)/8|0)|0]|0)&128>>>(($&7)>>>0)|0)!=0){$=H+(Z+_)|0;a[$]=(d[$]|0|V)&255}_=_+1|0;}while((_|0)<8);X=X+1|0;}while((X|0)<8);U=U+1|0;}while((U|0)<4);O=O+1|0;}while((O|0)<(K|0))}K=8192>>>(S>>>0);O=c[2439860]|0;if((K|0)>0){H=0;do{L=H<<8;gGz(O+L|0,0,256);U=H<<10;P=0;do{T=1<<3-P;X=(c[611400+(P<<2)>>2]|0)+U|0;V=0;do{W=X+(c[3946808+(V<<2)>>2]|0)|0;_=(V<<4)+L|0;Z=0;do{Y=W+(c[6669416+(Z<<2)>>2]|0)|0;if(((d[M+((Y|0)/8|0)|0]|0)&128>>>((Y&7)>>>0)|0)!=0){Y=O+(_+Z)|0;a[Y]=(d[Y]|0|T)&255}Z=Z+1|0;}while((Z|0)<16);V=V+1|0;}while((V|0)<16);P=P+1|0;}while((P|0)<4);H=H+1|0;}while((H|0)<(K|0))}c[2410674]=1748;gGz(9699632,0,3072);K=c[2427044]|0;c[9681616+(K<<3)>>2]=715288;c[9681620+(K<<3)>>2]=0;c[2427044]=K+1;c[363094]=0;K=c[2387394]|0;H=0;O=0;while(1){M=O+64|0;P=K+(O<<8)|0;c[9699632+(M<<2)>>2]=P;c[9700656+(M<<2)>>2]=P;c[9701680+(M<<2)>>2]=P;P=H+1&65535;if((P&65535)<24){H=P;O=P&65535}else{break}}O=c[3531084]|0;c[2424996]=O;c[2425252]=O;c[2425508]=O;H=O+256|0;c[2424997]=H;c[2425253]=H;c[2425509]=H;H=O+512|0;c[2424998]=H;c[2425254]=H;c[2425510]=H;H=O+768|0;c[2424999]=H;c[2425255]=H;c[2425511]=H;H=O+1024|0;c[2425e3]=H;c[2425256]=H;c[2425512]=H;H=O+1280|0;c[2425001]=H;c[2425257]=H;c[2425513]=H;H=O+1536|0;c[2425002]=H;c[2425258]=H;c[2425514]=H;H=O+1792|0;c[2425003]=H;c[2425259]=H;c[2425515]=H;H=c[2387370]|0;O=0;K=0;while(1){P=K+96|0;M=H+((K<<8)+65536)|0;c[9699632+(P<<2)>>2]=M;c[9701680+(P<<2)>>2]=M;M=O+1&65535;if((M&65535)<32){O=M;K=M&65535}else{aa=0;ab=0;break}}while(1){K=ab+128|0;O=H+((ab<<8)+32768)|0;c[9699632+(K<<2)>>2]=O;c[9701680+(K<<2)>>2]=O;O=aa+1&65535;if((O&65535)<128){aa=O;ab=O&65535}else{break}}c[2444172]=2240;c[3528598]=874;c[2410675]=336;c[363094]=-1;fwR(0);H=c[2439330]|0;O=(H|0)==0;if(!O){K=H;gGC(9706056,K|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];K=c[3528484]|0;c[2076596]=K;M=c[2417276]|0;c[3541536]=M;c[1836236]=0;P=c[2385990]|0;L=0;U=0;while(1){c[H+76+(U<<2)>>2]=P+(U<<8);V=L+1&65535;if((V&65535)>127){ac=0;ad=0;break}else{L=V;U=V&65535}}while(1){U=P+(ad<<8)|0;c[H+76+(ad+512<<2)>>2]=U;c[H+76+(ad+768<<2)>>2]=U;U=ac+1&65535;if((U&65535)>127){break}else{ac=U;ad=U&65535}}P=c[2386142]|0;c[H+588>>2]=P;U=P+256|0;c[H+592>>2]=U;L=P+512|0;c[H+596>>2]=L;V=P+768|0;c[H+600>>2]=V;T=P+1024|0;c[H+604>>2]=T;X=P+1280|0;c[H+608>>2]=X;Z=P+1536|0;c[H+612>>2]=Z;_=P+1792|0;c[H+616>>2]=_;c[H+1612>>2]=P;c[H+1616>>2]=U;c[H+1620>>2]=L;c[H+1624>>2]=V;c[H+1628>>2]=T;c[H+1632>>2]=X;c[H+1636>>2]=Z;c[H+1640>>2]=_;c[H+2636>>2]=P;c[H+3660>>2]=P;c[H+2640>>2]=U;c[H+3664>>2]=U;c[H+2644>>2]=L;c[H+3668>>2]=L;c[H+2648>>2]=V;c[H+3672>>2]=V;c[H+2652>>2]=T;c[H+3676>>2]=T;c[H+2656>>2]=X;c[H+3680>>2]=X;c[H+2660>>2]=Z;c[H+3684>>2]=Z;c[H+2664>>2]=_;c[H+3688>>2]=_;c[H+4184>>2]=148;c[H+4180>>2]=1520;if(!O){_=H;gGC(_|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=K;c[2417276]=M;c[1836236]=-1;_=a[9680]|0;Z=_?32e3:0;if(_){if(a[9624]|0){_=Z*3|0;X=55930;while(1){if((X|0)>(_|0)){X=X>>1}else{ae=1222;af=X;break}}}else{ae=2462;af=Z}c[2429380]=af;c[3542124]=ae;mw(3579545,af);X=gGq(262144)|0;c[2406684]=X;gGz(X|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(3579545,11025)}h[745421]=1.0;c[2436794]=3;h[745420]=1.0;c[2436792]=3;TJ(0,c[2386688]|0,524288);c[2424878]=9681232;c[2405736]=1278;h[1202869]=.2;c[2405742]=3;c[2426622]=9622928;h[1202870]=.2;c[2405743]=3;X=c[3530928]|0;_=1048575>>>((a[638592]&1)>>>0);M=0;while(1){if((M|0)>=1024){ah=0;break}ai=9638528+(M<<2)|0;if((c[ai>>2]|0)==0){J=70201;break}else{M=M+1|0}}do{if((J|0)==70201){M=gGq(24576)|0;c[ai>>2]=M;if((M|0)==0){ah=0;break}gGz(M|0,0,24576);ah=M}}while(0);c[3529062]=ah;c[2438700]=_;c[3529060]=X;a[7461784]=1;M=9726816;c[M>>2]=0;c[M+4>>2]=0;M=9726800;c[M>>2]=0;c[M+4>>2]=0;c[2429638]=0;c[2437692]=78;c[2431704]=8;c[2431700]=0;c[2431705]=8;c[2431701]=0;c[2431706]=8;c[2431702]=0;M=c[3530692]|0;Z=1048575>>>((a[638592]&1)>>>0);c[2438136]=0;K=0;while(1){if((K|0)>=1024){aj=0;break}ak=9638528+(K<<2)|0;if((c[ak>>2]|0)==0){J=70206;break}else{K=K+1|0}}do{if((J|0)==70206){K=gGq(1024)|0;c[ak>>2]=K;if((K|0)==0){aj=0;break}gGz(K|0,0,1024);aj=K}}while(0);c[3529066]=aj;c[2438702]=Z;c[3529064]=M;a[7461792]=1;c[2437694]=138;c[2438136]=8;K=c[642608+(c[2436]<<2)>>2]|0;X=c[K+128>>2]|0;if((c[K+52>>2]&4|0)==0){c[2113068]=X;_=c[K+132>>2]|0;c[2113070]=_;c[2443814]=X;c[2440436]=_;al=X;am=_}else{c[2113070]=X;_=c[K+132>>2]|0;c[2113068]=_;c[2440436]=X;c[2443814]=_;al=_;am=X}X=ag(al<<1,am)|0;_=gGq(X)|0;c[2112926]=_;if((_|0)!=0){gGz(_|0,0,X|0)}a[9624936]=0;X=c[2414788]|0;gGz(X|0,0,(c[2411848]|0)-X|0);c[363094]=0;c[2410673]=0;a[9642688]=0;a[9642689]=0;a[9642682]=0;a[9642683]=0;c[2410665]=0;a[9642680]=a[9642680]|80;X=c[2425163]|0;do{if((X|0)==0){_=c[3528598]|0;if((_|0)==0){an=0;ao=0;break}K=gj[_&4095](-2)|0;_=c[2425163]|0;H=(K&255)<<8;if((_|0)!=0){ap=_;aq=H;J=70217;break}_=c[3528598]|0;if((_|0)==0){an=0;ao=H;break}an=gj[_&4095](-1)|0;ao=H}else{ap=X;aq=(d[X+254|0]|0)<<8;J=70217}}while(0);if((J|0)==70217){an=a[ap+255|0]|0;ao=aq}c[2410662]=an&255|ao;c[363094]=-1;X=c[2439330]|0;M=(X|0)==0;if(!M){Z=X;gGC(9706056,Z|0,76)|0}Z=c[2438118]|0;c[2433530]=Z;H=c[3528484]|0;c[2076596]=H;_=c[2417276]|0;c[3541536]=_;c[1836236]=0;gGz(9706056,0,76);if(!M){M=X;gGC(M|0,9706056,76)|0}c[2438118]=Z;c[3528484]=H;c[2417276]=_;c[1836236]=-1;mx(0);blH();Q=0;i=e;return Q|0}}while(0);c[2415080]=0;Q=1;i=e;return Q|0}function bll(){var b=0,d=0,e=0,f=0;a[638592]=0;c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}blI();c[2444172]=0;c[3528598]=0;fwZ();b=c[2424800]|0;if((b|0)!=0){gGr(b);c[2424800]=0}b=c[2418166]|0;if((b|0)!=0){gGr(b);c[2418166]=0}b=c[3531464]|0;c[b+44344>>2]=0;c[b+44348>>2]=0;if((b|0)!=0){gGr(b);c[3531464]=0}b=c[2406684]|0;if((b|0)!=0){gGr(b);c[2406684]=0}b=c[2415080]|0;d=0;while(1){if((d|0)>=1024){e=70325;break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==(b|0)){break}else{d=d+1|0}}if((e|0)==70325){c[2415080]=0;return 0}gGr(b);c[f>>2]=0;c[2415080]=0;return 0}function blm(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((a[9624936]|0)!=0){a[9624936]=0;e=c[2414788]|0;gGz(e|0,0,(c[2411848]|0)-e|0);c[363094]=0;c[2410673]=0;a[9642688]=0;a[9642689]=0;a[9642682]=0;a[9642683]=0;c[2410665]=0;a[9642680]=a[9642680]|80;e=c[2425163]|0;do{if((e|0)==0){f=c[3528598]|0;if((f|0)==0){g=0;h=0;break}i=gj[f&4095](-2)|0;f=c[2425163]|0;j=(i&255)<<8;if((f|0)!=0){k=f;l=j;m=70332;break}f=c[3528598]|0;if((f|0)==0){g=0;h=j;break}g=gj[f&4095](-1)|0;h=j}else{k=e;l=d[e+254|0]<<8;m=70332}}while(0);if((m|0)==70332){g=a[k+255|0]|0;h=l}c[2410662]=g&255|h;c[363094]=-1;h=c[2439330]|0;g=(h|0)==0;if(!g){l=h;gGC(9706056,l|0,76)|0}l=c[2438118]|0;c[2433530]=l;k=c[3528484]|0;c[2076596]=k;m=c[2417276]|0;c[3541536]=m;c[1836236]=0;gGz(9706056,0,76);if(!g){g=h;gGC(g|0,9706056,76)|0}c[2438118]=l;c[3528484]=k;c[2417276]=m;c[1836236]=-1;mx(0);blH()}gGz(9550888,-1|0,3);m=0;k=-1;l=-1;g=-1;do{k=((a[9634288+m|0]&1)<<m^k&255)&255;l=((a[9632048+m|0]&1)<<m^l&255)&255;g=((a[9629968+m|0]&1)<<m^g&255)&255;m=m+1|0;}while((m|0)<8);a[9550888]=k;a[9550889]=l;a[9550890]=g;if((l&3)==0){k=l|3;a[9550889]=k;n=k}else{n=l}if((n&12)==0){a[9550889]=n|12}if((g&3)==0){n=g|3;a[9550890]=n;o=n}else{o=g}if((o&12)==0){a[9550890]=o|12}c[2410673]=0;o=c[2385548]|0;if((o|0)>0){gGz(9752472,0,((o|0)>1?o<<2:4)|0)}c[2433530]=0;o=c[2439330]|0;if((o|0)!=0){g=o;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;c[363094]=0;g=0;o=0;n=0;l=0;L91190:while(1){k=o;m=n;h=l;do{if((h|0)>=100){break L91190}h=h+1|0;m=(fNF((h*500|0)-m|0)|0)+m|0;e=(h*596|0)-k|0;do{if((e|0)<1){p=0}else{if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){j=gfc(e)|0;c[2433530]=(c[2433530]|0)+j;p=j;break}else{c[2433530]=(c[2433530]|0)+e;p=e;break}}}while(0);k=p+k|0;q=c[2112964]|0;}while((q|0)==0);e=a[9688]|0?5:0;j=q+(g<<1<<1)|0;gg[c[3542124]&4095](j,e);TH(0,j,e);g=e+g|0;o=k;n=m;l=h}if((c[3541228]|0)!=0){fNE(0,1);fNF(0)|0;a[9642682]=0;fNF(0)|0}l=c[2112964]|0;do{if((l|0)!=0){n=a[9688]|0?534:0;o=n-g|0;if((n|0)==(g|0)){break}n=l+(g<<1<<1)|0;gg[c[3542124]&4095](n,o);TH(0,n,o)}}while(0);c[363094]=-1;g=c[1836236]|0;l=c[9757320+(g<<2)>>2]|0;if((l|0)!=0){o=l;gGC(o|0,9706056,76)|0}c[9752472+(g<<2)>>2]=c[2433530];c[14113936+(g<<2)>>2]=c[2076596];c[9669104+(g<<2)>>2]=c[3541536];c[1836236]=-1;if((c[2112968]|0)==0){return 0}bln()|0;return 0}function bln(){var d=0,e=0,f=0,g=0;if((a[9547928]|0)!=0){d=c[3530166]|0;e=c[2387264]|0;f=0;do{g=ga(b[e+(f<<1)>>1]|0)|0;c[d+(f<<2)>>2]=((g&65535)>>>10<<3&65535)>>>3&31|((g&255)<<3&255)<<8|(((g&65535)>>>5<<3&255|(g&65535)>>>7&4)&255)<<3&2016;f=f+1|0;}while((f|0)<1024)}bpj();bpk(2,1,c[2439896]|0);bpk(1,0,c[2439896]|0);bpl(c[2439860]|0,2);bpl(c[2439860]|0,1);bpl(c[2439860]|0,0);bpk(0,0,c[2439896]|0);R8(c[3530166]|0);return 0}function blo(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;f=i;i=i+160|0;g=f|0;h=f+16|0;j=f+48|0;k=f+64|0;l=f+80|0;m=f+96|0;n=f+112|0;o=f+128|0;p=f+144|0;q=(e|0)==0;if(!q){c[e>>2]=169733}if((b&96|0)==0){r=b&64}else{gGz(p|0,0,12);s=c[2414788]|0;c[p>>2]=s;c[p+4>>2]=(c[2411848]|0)-s;c[p+12>>2]=162152;s=c[2076592]|0;gj[s&4095](p)|0;p=c[2410674]|0;s=c[2410675]|0;t=b&64;if((t|0)==0){c[2410674]=p;c[2410675]=s;fw$(b);u=g;v=h|0}else{gGz(n|0,0,12);c[n>>2]=9642648;c[n+4>>2]=56;c[n+12>>2]=163840;w=c[2076592]|0;gj[w&4095](n)|0;gGz(m|0,0,12);c[m>>2]=9707480;c[m+4>>2]=2;c[m+12>>2]=501096;n=c[2076592]|0;gj[n&4095](m)|0;gGz(l|0,0,12);c[l>>2]=9707480;c[l+4>>2]=4;c[l+12>>2]=385184;m=c[2076592]|0;gj[m&4095](l)|0;c[2410674]=p;c[2410675]=s;fw$(b);gGz(k|0,0,12);c[k>>2]=8453216;c[k+4>>2]=4;c[k+12>>2]=107480;s=c[2076592]|0;gj[s&4095](k)|0;gGz(j|0,0,12);c[j>>2]=14168504;c[j+4>>2]=256;c[j+12>>2]=476464;k=c[2076592]|0;gj[k&4095](j)|0;if((b&2|0)==0){x=g;y=h|0}else{j=0;do{mv(0,j,d[14168504+j|0]|0);j=j+1|0;}while((j|0)<256);x=g;y=h|0}if(!q){c[e>>2]=169619}e=h|0;cC(e|0,170224,(h=i,i=i+8|0,c[h>>2]=0,h)|0)|0;i=h;c[g>>2]=9699512;c[g+4>>2]=64;c[g+8>>2]=0;c[g+12>>2]=e;e=c[2076592]|0;gj[e&4095](g)|0;u=x;v=y}blJ(b);r=t}if((r|0)!=0){gGz(o|0,0,12);c[o>>2]=9719136;c[o+4>>2]=1;c[o+12>>2]=167632;r=c[2076592]|0;gj[r&4095](o)|0}if((b&2|0)==0){i=f;return 0}c[363094]=0;b=c[2438168]|0;o=a[b]|0;r=o&255;if(a[638592]|0){blc(r);t=a[b+1|0]|0;y=t&255;a[b]=t;t=(y<<13&122880^65536)+65536|0;if(t>>>0>163839){z=y<<28>>15}else{z=t}t=c[2387370]|0;y=0;v=0;while(1){x=v+96|0;u=t+((v<<8)+z)|0;c[9699632+(x<<2)>>2]=u;c[9701680+(x<<2)>>2]=u;u=y+1&65535;if((u&65535)<32){y=u;v=u&65535}else{break}}}else{a[b]=o;if((r&16|0)==0){o=c[2387264]|0;c[2424996]=o;c[2425252]=o;c[2425508]=o;b=o+256|0;c[2424997]=b;c[2425253]=b;c[2425509]=b;b=o+512|0;c[2424998]=b;c[2425254]=b;c[2425510]=b;b=o+768|0;c[2424999]=b;c[2425255]=b;c[2425511]=b;b=o+1024|0;c[2425e3]=b;c[2425256]=b;c[2425512]=b;b=o+1280|0;c[2425001]=b;c[2425257]=b;c[2425513]=b;A=o;B=o+1536|0}else{o=c[3531084]|0;c[2424996]=o;c[2425252]=o;c[2425508]=o;b=o+256|0;c[2424997]=b;c[2425253]=b;c[2425509]=b;b=o+512|0;c[2424998]=b;c[2425254]=b;c[2425510]=b;b=o+768|0;c[2424999]=b;c[2425255]=b;c[2425511]=b;b=o+1024|0;c[2425e3]=b;c[2425256]=b;c[2425512]=b;b=o+1280|0;c[2425001]=b;c[2425257]=b;c[2425513]=b;A=o;B=o+1536|0}c[2425002]=B;c[2425258]=B;c[2425514]=B;B=A+1792|0;c[2425003]=B;c[2425259]=B;c[2425515]=B;B=(r<<13&122880)+65536|0;r=c[2387370]|0;A=0;o=0;while(1){b=o+96|0;v=r+(B+(o<<8))|0;c[9699632+(b<<2)>>2]=v;c[9701680+(b<<2)>>2]=v;v=A+1&65535;if((v&65535)<32){A=v;o=v&65535}else{break}}}c[363094]=-1;i=f;return 0}function blp(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>39){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2321260+(b*112|0)>>2];c[a+104>>2]=c[2321264+(b*112|0)>>2];c[a+108>>2]=c[2321268+(b*112|0)>>2];d=0;return d|0}function blq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<40&(d|0)==0)){e=1;return e|0}c[a>>2]=2321160+(b*112|0);e=0;return e|0}function blr(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2152796+(b*112|0)>>2];c[a+104>>2]=c[2152800+(b*112|0)>>2];c[a+108>>2]=c[2152804+(b*112|0)>>2];d=0;return d|0}function bls(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=2152696+(b*112|0);e=0;return e|0}function blt(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>59){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3312984+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function blu(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1361876+(b*112|0)>>2];c[a+104>>2]=c[1361880+(b*112|0)>>2];c[a+108>>2]=c[1361884+(b*112|0)>>2];d=0;return d|0}function blv(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=1361776+(b*112|0);e=0;return e|0}function blw(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1359636+(b*112|0)>>2];c[a+104>>2]=c[1359640+(b*112|0)>>2];c[a+108>>2]=c[1359644+(b*112|0)>>2];d=0;return d|0}function blx(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=1359536+(b*112|0);e=0;return e|0}function bly(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1357396+(b*112|0)>>2];c[a+104>>2]=c[1357400+(b*112|0)>>2];c[a+108>>2]=c[1357404+(b*112|0)>>2];d=0;return d|0}function blz(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=1357296+(b*112|0);e=0;return e|0}function blA(b){b=b|0;var d=0,e=0,f=0,g=0,h=0;a[c[2438168]|0]=b&255;d=(b<<13&122880^65536)+65536|0;if(d>>>0>163839){e=b<<28>>15}else{e=d}d=c[2387370]|0;b=0;f=0;while(1){g=f+96|0;h=d+((f<<8)+e)|0;c[9699632+(g<<2)>>2]=h;c[9701680+(g<<2)>>2]=h;h=b+1&65535;if((h&65535)<32){b=h;f=h&65535}else{break}}return}function blB(b){b=b|0;a[9681232]=((b>>4)*17|0)&255;a[9681233]=0;c[2424878]=9681232;a[9681234]=0;a[9681235]=((b&15)*17|0)&255;return}function blC(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;c[d>>2]=c[d>>2]|b<<13|c[e>>2]<<8&7936;c[e>>2]=((c[e>>2]|0)>>>5&7)+(c[602544+(a<<2)>>2]|0);return}function blD(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;c[d>>2]=(c[b>>2]|0)>>>4&3;c[b>>2]=c[b>>2]&15|32;c[e>>2]=0;return}function blE(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=i;i=i+56|0;f=e|0;g=e+8|0;h=e+16|0;j=e+24|0;k=e+32|0;l=e+40|0;m=e+48|0;if((c[3541230]|0)!=0){if(b>>>0>24575){n=0;i=e;return n|0}c[f>>2]=0;o=b>>>5&255;c[g>>2]=o;p=d[9730680]|0;c[h>>2]=p;q=p>>>2&3;if((c[2429638]|0)==0){gB[c[2437692]&127](0,((a[9718936+q|0]|a[9720736+q|0])&255)>>>2,g,h,f,f);r=c[g>>2]|0}else{f=p<<8|o;c[g>>2]=f;r=f}n=a[(c[3529060]|0)+((r<<5|b&31)&c[2438700])|0]|0;i=e;return n|0}r=b-14336|0;if(r>>>0<8){n=bpm(r)|0;i=e;return n|0}if((b|0)<15360){if(b>>>0>24575){n=0;i=e;return n|0}n=a[(c[3529062]|0)+b|0]|0;i=e;return n|0}else{r=b-15360|0;if((c[3541238]|0)!=0){b=r>>>2&255;c[2433420]=b;f=d[9718033]|0;c[j>>2]=((d[9718032]|0)<<8|b|f<<16)>>>5&8191;b=(d[9718034]|0)<<6;c[k>>2]=b&192|f>>>2;c[l>>2]=0;c[m>>2]=b&128;gL[c[2437694]&255](j,k,l,m)}n=a[(c[3529066]|0)+r|0]|0;i=e;return n|0}return 0}function blF(b,d){b=b|0;d=d|0;var e=0;e=b-14336|0;if(e>>>0<8){if((e|0)==0){c[3541236]=d&1;c[3541234]=d&4;c[3541232]=d&8;c[3541238]=d&32;return}e=b-14338|0;if(e>>>0>=3){return}a[9718032+e|0]=d&255;return}if((b|0)>=15360){a[(c[3529066]|0)+(b-15360)|0]=d&255;return}e=d&255;if(b>>>0>24575){return}a[(c[3529062]|0)+b|0]=e;if((b&6144)>>>0<=6143){return}switch(b|0){case 7296:{a[9729904]=e;return};case 7680:{a[9730680]=e;return};case 7424:{c[3541228]=d&4;return};case 7808:{c[2432672]=d>>>1&3;return};case 7936:{a[9720738]=e&15;a[9720739]=(e&255)>>>4;return};case 7552:{a[9720736]=e&15;a[9720737]=(e&255)>>>4;return};default:{return}}}function blG(a,c){a=a|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;if((c|0)!=2&(c&3|0)==0){d=a;e=c}else{return}while(1){c=e>>1;a=(c|0)/2|0;if((c|0)>1){f=0;do{g=d+(f+a<<1)|0;h=b[g>>1]|0;i=d+(f+c<<1)|0;b[g>>1]=b[i>>1]|0;b[i>>1]=h;f=f+1|0;}while((f|0)<(a|0))}blG(d,c);if((c|0)!=2&(c&3|0)==0){d=d+(c<<1)|0;e=c}else{break}}return}function blH(){var b=0,d=0;if(a[7461792]|0){gGz(9718032,0,3);c[3541238]=0;c[2433420]=0;c[3541236]=0;c[3541234]=0;c[3541232]=0}if(a[7461784]|0){gGz(9754784,0,12);gGz(9754768,0,12);a[9729904]=0;c[2430184]=0;c[2429734]=0;c[3541230]=0;a[9730680]=0;c[3541228]=0;gGz(c[3529062]|0,0,24576);gGz(9730696,0,12);gGz(9730712,0,12);gGz(9726832,0,3072);gGz(9730728,0,12);gGz(9729912,0,768)}do{if(a[7461800]|0){gGz(14108592,0,48);gGz(14108544,0,3);b=c[3529076]|0;if((b|0)!=0){gGz(b|0,0,2048)}b=c[2438704]|0;if((b|0)!=0){gGz(b|0,0,524288)}b=c[3529077]|0;if((b|0)!=0){gGz(b|0,0,2048)}b=c[2438705]|0;if((b|0)!=0){gGz(b|0,0,524288)}b=c[3529078]|0;if((b|0)!=0){gGz(b|0,0,2048)}b=c[2438706]|0;if((b|0)==0){break}gGz(b|0,0,524288)}}while(0);do{if(a[7461776]|0){b=c[2439478]|0;if((b|0)<=0){break}d=(b|0)>1?b:1;gGz(14108504,0,d<<4|0);gGz(14108536,0,d<<2|0);d=0;do{gGz(c[14116216+(d<<2)>>2]|0,0,2048);gGz(c[14116232+(d<<2)>>2]|0,0,2048);d=d+1|0;}while((d|0)<(b|0))}}while(0);if(!(a[7461768]|0)){gGz(14116144,0,16);gGz(9750728,0,20);gGz(14116112,0,32);gGz(14116272,0,32);return}gGz(c[3529044]|0,0,4096);gGz(14108448,0,32);b=14108480;c[b>>2]=0;c[b+4>>2]=0;a[9718928]=0;gGz(14116144,0,16);gGz(9750728,0,20);gGz(14116112,0,32);gGz(14116272,0,32);return}function blI(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=c[2308882]|0;d=0;while(1){if((d|0)>=1024){break}e=9638528+(d<<2)|0;if((c[e>>2]|0)==(b|0)){f=70572;break}else{d=d+1|0}}if((f|0)==70572){gGr(b);c[e>>2]=0}c[2308882]=0;if(a[7461792]|0){e=c[3529066]|0;b=0;while(1){if((b|0)>=1024){break}g=9638528+(b<<2)|0;if((c[g>>2]|0)==(e|0)){f=70577;break}else{b=b+1|0}}if((f|0)==70577){gGr(e);c[g>>2]=0}c[3529066]=0;c[2438702]=0;c[3529064]=0;gGz(9718032,0,3);c[3541238]=0;c[2433420]=0;c[2437694]=0}if(a[7461784]|0){g=c[3529062]|0;e=0;while(1){if((e|0)>=1024){break}h=9638528+(e<<2)|0;if((c[h>>2]|0)==(g|0)){f=70583;break}else{e=e+1|0}}if((f|0)==70583){gGr(g);c[h>>2]=0}c[3529062]=0;c[2437692]=0;c[2438700]=0;c[3529060]=0;gGz(9754784,0,3);gGz(9754768,0,3);a[9729904]=0;c[2430184]=0;c[3541230]=0;a[9730680]=0;c[2432672]=0;c[3541228]=0;c[2429638]=0}if(a[7461800]|0){h=c[3529076]|0;g=0;while(1){if((g|0)>=1024){break}i=9638528+(g<<2)|0;if((c[i>>2]|0)==(h|0)){f=70589;break}else{g=g+1|0}}if((f|0)==70589){gGr(h);c[i>>2]=0}c[3529076]=0;i=c[2438704]|0;h=0;while(1){if((h|0)>=1024){break}j=9638528+(h<<2)|0;if((c[j>>2]|0)==(i|0)){f=70593;break}else{h=h+1|0}}if((f|0)==70593){gGr(i);c[j>>2]=0}c[2438704]=0;c[2437696]=0;j=c[3529077]|0;i=0;while(1){if((i|0)>=1024){break}k=9638528+(i<<2)|0;if((c[k>>2]|0)==(j|0)){f=70597;break}else{i=i+1|0}}if((f|0)==70597){gGr(j);c[k>>2]=0}c[3529077]=0;k=c[2438705]|0;j=0;while(1){if((j|0)>=1024){break}l=9638528+(j<<2)|0;if((c[l>>2]|0)==(k|0)){f=70601;break}else{j=j+1|0}}if((f|0)==70601){gGr(k);c[l>>2]=0}c[2438705]=0;c[2437697]=0;l=c[3529078]|0;k=0;while(1){if((k|0)>=1024){break}m=9638528+(k<<2)|0;if((c[m>>2]|0)==(l|0)){f=70605;break}else{k=k+1|0}}if((f|0)==70605){gGr(l);c[m>>2]=0}c[3529078]=0;m=c[2438706]|0;l=0;while(1){if((l|0)>=1024){break}n=9638528+(l<<2)|0;if((c[n>>2]|0)==(m|0)){f=70609;break}else{l=l+1|0}}if((f|0)==70609){gGr(m);c[n>>2]=0}c[2438706]=0;c[2437698]=0}if(a[7461776]|0){if((c[2439478]|0)>0){n=0;do{m=14116216+(n<<2)|0;l=c[m>>2]|0;k=0;while(1){if((k|0)>=1024){break}o=9638528+(k<<2)|0;if((c[o>>2]|0)==(l|0)){f=70616;break}else{k=k+1|0}}if((f|0)==70616){f=0;gGr(l);c[o>>2]=0}c[m>>2]=0;k=14116232+(n<<2)|0;j=c[k>>2]|0;i=0;while(1){if((i|0)>=1024){break}p=9638528+(i<<2)|0;if((c[p>>2]|0)==(j|0)){f=70620;break}else{i=i+1|0}}if((f|0)==70620){f=0;gGr(j);c[p>>2]=0}c[k>>2]=0;c[14116208+(n<<2)>>2]=0;c[14116200+(n<<2)>>2]=0;n=n+1|0;}while((n|0)<(c[2439478]|0))}c[2439478]=0}if(!(a[7461768]|0)){a[7461792]=0;a[7461784]=0;a[7461800]=0;a[7461776]=0;a[7461768]=0;a[7461816]=0;return}c[3527110]=0;n=c[3529044]|0;p=0;while(1){if((p|0)>=1024){break}q=9638528+(p<<2)|0;if((c[q>>2]|0)==(n|0)){f=70627;break}else{p=p+1|0}}if((f|0)==70627){gGr(n);c[q>>2]=0}c[3529044]=0;c[2443316]=0;gGz(14108448,0,32);a[7461792]=0;a[7461784]=0;a[7461800]=0;a[7461776]=0;a[7461768]=0;a[7461816]=0;return}function blJ(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0;d=i;i=i+752|0;e=d|0;f=d+16|0;g=d+32|0;h=d+48|0;j=d+64|0;k=d+80|0;l=d+96|0;m=d+112|0;n=d+128|0;o=d+144|0;p=d+160|0;q=d+176|0;r=d+192|0;s=d+208|0;t=d+224|0;u=d+240|0;v=d+256|0;w=d+272|0;x=d+288|0;y=d+304|0;z=d+320|0;A=d+336|0;B=d+352|0;C=d+368|0;D=d+384|0;E=d+400|0;F=d+416|0;G=d+432|0;H=d+448|0;I=d+464|0;J=d+480|0;K=d+496|0;L=d+512|0;M=d+528|0;N=d+544|0;O=d+560|0;P=d+576|0;Q=d+592|0;R=d+608|0;S=d+624|0;T=d+640|0;U=d+656|0;V=d+672|0;W=d+688|0;X=d+704|0;Y=d+720|0;Z=d+736|0;do{if(a[7461792]|0){if((b&32|0)!=0){gGz(O|0,0,12);c[O>>2]=c[3529066];c[O+4>>2]=1024;c[O+12>>2]=499176;_=c[2076592]|0;gj[_&4095](O)|0}if((b&64|0)==0){break}gGz(N|0,0,12);c[N>>2]=9718032;c[N+4>>2]=3;c[N+12>>2]=561688;_=c[2076592]|0;gj[_&4095](N)|0;gGz(M|0,0,12);c[M>>2]=14164952;c[M+4>>2]=4;c[M+12>>2]=434864;_=c[2076592]|0;gj[_&4095](M)|0;gGz(L|0,0,12);c[L>>2]=9733680;c[L+4>>2]=4;c[L+12>>2]=336896;_=c[2076592]|0;gj[_&4095](L)|0;gGz(K|0,0,12);c[K>>2]=14164944;c[K+4>>2]=4;c[K+12>>2]=259384;_=c[2076592]|0;gj[_&4095](K)|0;gGz(J|0,0,12);c[J>>2]=14164936;c[J+4>>2]=4;c[J+12>>2]=201784;_=c[2076592]|0;gj[_&4095](J)|0;gGz(I|0,0,12);c[I>>2]=14164928;c[I+4>>2]=4;c[I+12>>2]=158832;_=c[2076592]|0;gj[_&4095](I)|0}}while(0);do{if(a[7461784]|0){if((b&32|0)!=0){gGz(H|0,0,12);c[H>>2]=c[3529062];c[H+4>>2]=24576;c[H+12>>2]=499568;I=c[2076592]|0;gj[I&4095](H)|0}if((b&64|0)==0){break}gGz(G|0,0,12);c[G>>2]=9754784;c[G+4>>2]=4;c[G+12>>2]=561800;I=c[2076592]|0;gj[I&4095](G)|0;gGz(F|0,0,12);c[F>>2]=9754788;c[F+4>>2]=4;c[F+12>>2]=434944;I=c[2076592]|0;gj[I&4095](F)|0;gGz(E|0,0,12);c[E>>2]=9754792;c[E+4>>2]=4;c[E+12>>2]=336976;I=c[2076592]|0;gj[I&4095](E)|0;gGz(D|0,0,12);c[D>>2]=9754768;c[D+4>>2]=4;c[D+12>>2]=259560;I=c[2076592]|0;gj[I&4095](D)|0;gGz(C|0,0,12);c[C>>2]=9754772;c[C+4>>2]=4;c[C+12>>2]=201824;I=c[2076592]|0;gj[I&4095](C)|0;gGz(B|0,0,12);c[B>>2]=9754776;c[B+4>>2]=4;c[B+12>>2]=158872;I=c[2076592]|0;gj[I&4095](B)|0;gGz(A|0,0,12);c[A>>2]=9729904;c[A+4>>2]=1;c[A+12>>2]=128512;I=c[2076592]|0;gj[I&4095](A)|0;gGz(z|0,0,12);c[z>>2]=9729904;c[z+4>>2]=1;c[z+12>>2]=128512;I=c[2076592]|0;gj[I&4095](z)|0;gGz(y|0,0,12);c[y>>2]=9720736;c[y+4>>2]=1;c[y+12>>2]=103784;I=c[2076592]|0;gj[I&4095](y)|0;gGz(x|0,0,12);c[x>>2]=9720737;c[x+4>>2]=1;c[x+12>>2]=80352;I=c[2076592]|0;gj[I&4095](x)|0;gGz(w|0,0,12);c[w>>2]=9720738;c[w+4>>2]=1;c[w+12>>2]=586928;I=c[2076592]|0;gj[I&4095](w)|0;gGz(v|0,0,12);c[v>>2]=9720739;c[v+4>>2]=1;c[v+12>>2]=570272;I=c[2076592]|0;gj[I&4095](v)|0;gGz(u|0,0,12);c[u>>2]=9718936;c[u+4>>2]=1;c[u+12>>2]=553968;I=c[2076592]|0;gj[I&4095](u)|0;gGz(t|0,0,12);c[t>>2]=9718937;c[t+4>>2]=1;c[t+12>>2]=539232;I=c[2076592]|0;gj[I&4095](t)|0;gGz(s|0,0,12);c[s>>2]=9718938;c[s+4>>2]=1;c[s+12>>2]=525760;I=c[2076592]|0;gj[I&4095](s)|0;gGz(r|0,0,12);c[r>>2]=9718939;c[r+4>>2]=1;c[r+12>>2]=512280;I=c[2076592]|0;gj[I&4095](r)|0;gGz(q|0,0,12);c[q>>2]=14164920;c[q+4>>2]=4;c[q+12>>2]=499376;I=c[2076592]|0;gj[I&4095](q)|0;gGz(p|0,0,12);c[p>>2]=9730680;c[p+4>>2]=1;c[p+12>>2]=487952;I=c[2076592]|0;gj[I&4095](p)|0;gGz(o|0,0,12);c[o>>2]=9730688;c[o+4>>2]=4;c[o+12>>2]=474992;I=c[2076592]|0;gj[I&4095](o)|0;gGz(n|0,0,12);c[n>>2]=14164912;c[n+4>>2]=4;c[n+12>>2]=463632;I=c[2076592]|0;gj[I&4095](n)|0;gGz(m|0,0,12);c[m>>2]=9718552;c[m+4>>2]=4;c[m+12>>2]=452432;I=c[2076592]|0;gj[I&4095](m)|0}}while(0);do{if(a[7461800]|0){m=l;if((b&32|0)!=0){n=l|0;o=l+4|0;p=l+12|0;q=c[3529076]|0;if((q|0)!=0){gGz(m|0,0,12);c[n>>2]=q;c[o>>2]=2048;c[p>>2]=499568;q=c[2076592]|0;gj[q&4095](l)|0}gGz(m|0,0,12);c[n>>2]=14108592;c[o>>2]=16;c[p>>2]=566400;q=c[2076592]|0;gj[q&4095](l)|0;q=c[3529077]|0;if((q|0)!=0){gGz(m|0,0,12);c[n>>2]=q;c[o>>2]=2048;c[p>>2]=499568;q=c[2076592]|0;gj[q&4095](l)|0}gGz(m|0,0,12);c[n>>2]=14108608;c[o>>2]=16;c[p>>2]=566400;q=c[2076592]|0;gj[q&4095](l)|0;q=c[3529078]|0;if((q|0)!=0){gGz(m|0,0,12);c[n>>2]=q;c[o>>2]=2048;c[p>>2]=499568;q=c[2076592]|0;gj[q&4095](l)|0}gGz(m|0,0,12);c[n>>2]=14108624;c[o>>2]=16;c[p>>2]=566400;p=c[2076592]|0;gj[p&4095](l)|0}if((b&64|0)!=0){gGz(k|0,0,12);c[k>>2]=14108544;c[k+4>>2]=1;c[k+12>>2]=438664;p=c[2076592]|0;gj[p&4095](k)|0;gGz(j|0,0,12);c[j>>2]=14108545;c[j+4>>2]=1;c[j+12>>2]=339400;p=c[2076592]|0;gj[p&4095](j)|0;gGz(h|0,0,12);c[h>>2]=14108546;c[h+4>>2]=1;c[h+12>>2]=262240;p=c[2076592]|0;gj[p&4095](h)|0}if((b&2|0)==0){break}if((c[3529076]|0)!=0){p=0;do{bi2(p,0);p=p+1|0;}while((p|0)<1024)}if((c[3529077]|0)!=0){p=0;do{bi2(p,1);p=p+1|0;}while((p|0)<1024)}if((c[3529078]|0)==0){break}else{$=0}do{bi2($,2);$=$+1|0;}while(($|0)<1024)}}while(0);do{if(a[7461776]|0){$=g;if((b&32|0)!=0){h=g|0;j=g+4|0;k=g+12|0;l=c[3529054]|0;if((l|0)!=0){gGz($|0,0,12);c[h>>2]=l;c[j>>2]=2048;c[k>>2]=533624;l=c[2076592]|0;gj[l&4095](g)|0;c[h>>2]=c[3529058];c[j>>2]=2048;c[k>>2]=566784;l=c[2076592]|0;gj[l&4095](g)|0}gGz($|0,0,12);c[h>>2]=14108504;c[j>>2]=16;c[k>>2]=438904;l=c[2076592]|0;gj[l&4095](g)|0;l=c[3529055]|0;if((l|0)!=0){gGz($|0,0,12);c[h>>2]=l;c[j>>2]=2048;c[k>>2]=533624;l=c[2076592]|0;gj[l&4095](g)|0;c[h>>2]=c[3529059];c[j>>2]=2048;c[k>>2]=566784;l=c[2076592]|0;gj[l&4095](g)|0}gGz($|0,0,12);c[h>>2]=14108520;c[j>>2]=16;c[k>>2]=438904;k=c[2076592]|0;gj[k&4095](g)|0}if((b&64|0)==0){break}gGz(f|0,0,12);c[f>>2]=14108536;c[f+4>>2]=4;c[f+12>>2]=339504;k=c[2076592]|0;gj[k&4095](f)|0;gGz(e|0,0,12);c[e>>2]=14108540;c[e+4>>2]=4;c[e+12>>2]=262368;k=c[2076592]|0;gj[k&4095](e)|0}}while(0);do{if(a[7461768]|0){e=b&32;if((e|0)==0){aa=W;break}else{gGz(Z|0,0,12);f=Z|0;c[f>>2]=c[3529044];g=Z+4|0;c[g>>2]=4096;k=Z+12|0;c[k>>2]=540696;j=c[2076592]|0;gj[j&4095](Z)|0;c[f>>2]=14108448;c[g>>2]=32;c[k>>2]=567968;j=c[2076592]|0;gj[j&4095](Z)|0;c[f>>2]=14108480;c[g>>2]=8;c[k>>2]=439616;k=c[2076592]|0;gj[k&4095](Z)|0;gGz(Y|0,0,12);c[Y>>2]=9718928;c[Y+4>>2]=1;c[Y+12>>2]=340200;k=c[2076592]|0;gj[k&4095](Y)|0;gGz(X|0,0,12);c[X>>2]=9720728;c[X+4>>2]=4;c[X+12>>2]=262800;k=c[2076592]|0;gj[k&4095](X)|0;ab=e;ac=70674;break}}else{ab=b&32;ac=70674}}while(0);do{if((ac|0)==70674){b=W;if((ab|0)==0){aa=b;break}gGz(b|0,0,12);c[W>>2]=14116144;c[W+4>>2]=16;c[W+12>>2]=529744;b=c[2076592]|0;gj[b&4095](W)|0;gGz(V|0,0,12);c[V>>2]=9750728;c[V+4>>2]=4;c[V+12>>2]=566128;b=c[2076592]|0;gj[b&4095](V)|0;gGz(U|0,0,12);c[U>>2]=9750732;c[U+4>>2]=4;c[U+12>>2]=438520;b=c[2076592]|0;gj[b&4095](U)|0;gGz(T|0,0,12);c[T>>2]=9750736;c[T+4>>2]=4;c[T+12>>2]=339248;b=c[2076592]|0;gj[b&4095](T)|0;gGz(S|0,0,12);c[S>>2]=9750740;c[S+4>>2]=4;c[S+12>>2]=261840;b=c[2076592]|0;gj[b&4095](S)|0;gGz(R|0,0,12);c[R>>2]=9750744;c[R+4>>2]=4;c[R+12>>2]=204344;b=c[2076592]|0;gj[b&4095](R)|0;gGz(Q|0,0,12);c[Q>>2]=14116112;c[Q+4>>2]=32;c[Q+12>>2]=561984;b=c[2076592]|0;gj[b&4095](Q)|0;b=P;gGz(b|0,0,12);c[P>>2]=14116272;c[P+4>>2]=32;c[P+12>>2]=517392;X=c[2076592]|0;gj[X&4095](P)|0;ad=b;i=d;return}}while(0);ad=P;i=d;return}function blK(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=ag(c[2113070]|0,c[2113068]|0)|0;if((f|0)<=0){return}g=c[2112926]|0;h=c[2308882]|0;i=c[2113308]|0;j=(i|0)>3;k=(i|0)==2;l=0;m=c[2112968]|0;while(1){n=b[g+(l<<1)>>1]|0;o=n&65535;do{if((n&65535)>16383){p=c[d+((o&16383)<<2)>>2]|0;q=c[d+((b[h+(l<<1)>>1]&16383)<<2)>>2]|0;r=o>>>10&16;s=r+153|0;t=103-r|0;r=ag(p&255,s)|0;u=(ag(q&255,t)|0)+r|0;r=ag(p&65280,s)|0;v=(u|(ag(q&65280,t)|0)+r)>>>16;r=ag(p&16711680,s)|0;s=(u|(ag(q&16711680,t)|0)+r)>>>24<<8&63488|v<<3&2016;v=s|u>>>11&31;if(j){c[m>>2]=v;break}if(k){b[m>>1]=v&65535;break}else{a[m]=v&255;a[m+1|0]=s>>>8&255;a[m+2|0]=0;break}}else{s=c[e+(o<<2)>>2]|0;if(j){c[m>>2]=s;break}if(k){b[m>>1]=s&65535;break}else{a[m]=s&255;a[m+1|0]=s>>>8&255;a[m+2|0]=s>>>16&255;break}}}while(0);o=l+1|0;if((o|0)<(f|0)){l=o;m=m+i|0}else{break}}return}function blL(a){a=a|0;var b=0,c=0,d=0,e=0;if((a|0)==1073741824){b=32768;return b|0}c=a>>>0<1073741824?16384:49152;d=ag(c,c)|0;if((d|0)==(a|0)){b=c;return b|0}e=(d>>>0>a>>>0?-8192:8192)+c|0;c=ag(e,e)|0;if((c|0)==(a|0)){b=e;return b|0}d=(c>>>0>a>>>0?-4096:4096)+e|0;e=ag(d,d)|0;if((e|0)==(a|0)){b=d;return b|0}c=(e>>>0>a>>>0?-2048:2048)+d|0;d=ag(c,c)|0;if((d|0)==(a|0)){b=c;return b|0}e=(d>>>0>a>>>0?-1024:1024)+c|0;c=ag(e,e)|0;if((c|0)==(a|0)){b=e;return b|0}d=(c>>>0>a>>>0?-512:512)+e|0;e=ag(d,d)|0;if((e|0)==(a|0)){b=d;return b|0}c=(e>>>0>a>>>0?-256:256)+d|0;d=ag(c,c)|0;if((d|0)==(a|0)){b=c;return b|0}e=(d>>>0>a>>>0?-128:128)+c|0;c=ag(e,e)|0;if((c|0)==(a|0)){b=e;return b|0}d=(c>>>0>a>>>0?-64:64)+e|0;e=ag(d,d)|0;if((e|0)==(a|0)){b=d;return b|0}c=(e>>>0>a>>>0?-32:32)+d|0;d=ag(c,c)|0;if((d|0)==(a|0)){b=c;return b|0}e=(d>>>0>a>>>0?-16:16)+c|0;c=ag(e,e)|0;if((c|0)==(a|0)){b=e;return b|0}d=(c>>>0>a>>>0?-8:8)+e|0;e=ag(d,d)|0;if((e|0)==(a|0)){b=d;return b|0}c=(e>>>0>a>>>0?-4:4)+d|0;d=ag(c,c)|0;if((d|0)==(a|0)){b=c;return b|0}e=(d>>>0>a>>>0?-2:2)+c|0;c=ag(e,e)|0;if((c|0)==(a|0)){b=e;return b|0}b=(c>>>0>a>>>0?-1:1)+e|0;return b|0}function blM(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=b&65535;if((f|0)==57343){c[2405130]=e&255;return}else if((f|0)==62656){a[c[3528772]|0]=e&32;return}else if((f|0)==62592){g=e&255;if((g&64|0)!=0){h=c[2386316]|0;gGz((c[2386268]|0)+((d[h]|0)<<13&8192)|0,a[h+1|0]|0,8192)}c[2406662]=g&128;h=g&15;c[2406764]=h;g=c[2385988]|0;i=c[9757320+(c[1836236]<<2)>>2]|0;j=(h<<13)-32768|0;h=128;k=128;while(1){c[i+76+(k<<2)>>2]=g+(j+(k<<8));l=h+1&65535;if((l&65535)>159){break}else{h=l;k=l&65535}}k=(c[2406764]<<13)-32768|0;h=128;j=128;while(1){l=g+(k+(j<<8))|0;c[i+76+(j+512<<2)>>2]=l;c[i+76+(j+768<<2)>>2]=l;l=h+1&65535;if((l&65535)>159){break}else{h=l;j=l&65535}}return}else if((f|0)==61952){Uv(0,e);return}else if((f|0)==62720){c[2439286]=e&255;return}else{if((f&57344|0)==49152){j=c[2405130]|0;do{if((j|0)==3&b<<16>>16==-16384){h=e&255;if((h&254|0)!=0){break}c[2406656]=h&1;return}}while(0);if((c[2406662]|0)==0){return}if((j|0)==0){a[(c[2386268]|0)+(c[2406656]<<13|f&8191)|0]=e;return}else if((j|0)==2){if((b&65535)>=51200){return}a[(c[2386316]|0)+(f&2047)|0]=e;return}else{return}}if((f&65408|0)==59392){j=f&127;c[2420382]=9674032;h=f&31;a[9674052+((j>>>5)*56|0)+h|0]=e;if(j>>>0<=95){return}a[9674276+h|0]=e;return}if((f&65520|0)!=59520){return}if((b&65535)<59530){h=f&15;c[2420382]=9674032;c[9674344+(h<<2)>>2]=e&255;c[9674040+((h>>>1)*56|0)>>2]=(c[9674344+((h|1)<<2)>>2]<<8)+(c[9674344+((f&14)<<2)>>2]|0)&4095;return}if(b<<16>>16==-6001){b=e&255;c[2420382]=9674032;c[2418512]=b&1;c[2418526]=b&2;c[2418540]=b&4;c[2418554]=b&8;c[2418568]=b&16;return}else{c[2420382]=9674032;c[9674044+((f+6&7)*56|0)>>2]=e&15;return}}}function blN(b){b=b|0;var d=0,e=0,f=0;d=b&65535;L91751:do{switch(d|0){case 62464:{e=a[9635624]|0;break};case 62467:{e=a[9550881]|0;break};case 62784:{e=0;break};case 62465:{e=a[9635625]|0;break};case 62466:{e=a[9550880]|0;break};case 62529:{e=a[9550882]&-9;break};case 62528:{e=a[9635626]|0;break};default:{if((d&57344|0)!=49152){e=0;break L91751}f=c[2439286]|0;if((f|0)!=0&(b&65535)<53248){e=a[(c[2387834]|0)+(f<<12&520192|d&4095)|0]|0;break L91751}f=c[2405130]|0;if((f|0)==0){e=a[(c[2386268]|0)+(c[2406656]<<13|d&8191)|0]|0;break L91751}else if((f|0)!=2){e=0;break L91751}if((b&65535)>=55296){e=0;break L91751}e=a[(c[2386316]|0)+(d&2047)|0]|0}}}while(0);return e|0}function blO(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5868748+(b*112|0)>>2];c[a+104>>2]=c[5868752+(b*112|0)>>2];c[a+108>>2]=c[5868756+(b*112|0)>>2];d=0;return d|0}function blP(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=5868648+(b*112|0);e=0;return e|0}function blQ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3872816+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function blR(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>54){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6275984+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function blS(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;e=i;i=i+840|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;c[2415078]=0;c[2385988]=0;c[2387834]=131072;c[2443550]=655360;c[3541206]=1703936;c[2386686]=1703936;c[3531046]=1966080;c[3530164]=1966848;c[2406998]=1967872;c[2414786]=1968896;c[2386316]=1968896;c[2386268]=1970944;c[2386140]=1995520;c[3528772]=2003712;c[2411846]=2003713;v=0;while(1){if((v|0)>=1024){break}w=9638528+(v<<2)|0;if((c[w>>2]|0)==0){x=70821;break}else{v=v+1|0}}do{if((x|0)==70821){v=gGq(2003713)|0;c[w>>2]=v;if((v|0)==0){break}c[2415078]=v;gGz(v|0,0,2003713);c[2385988]=v;c[2387834]=v+131072;c[2443550]=v+655360;y=v+1703936|0;c[3541206]=y;c[2386686]=y;c[3531046]=v+1966080;c[3530164]=v+1966848;c[2406998]=v+1967872;y=v+1968896|0;c[2414786]=y;c[2386316]=y;c[2386268]=v+1970944;c[2386140]=v+1995520;c[3528772]=v+2003712;y=v+2003713|0;c[2411846]=y;c[2414396]=y;if((c[3542200]|0)==0){z=1;i=e;return z|0}y=t+108|0;c[y>>2]=0;A=t+100|0;c[A>>2]=0;B=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[B&16383](t,0)|0;do{if((c[y>>2]|0)!=0){B=c[A>>2]|0;c[u>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](u,0,0)|0;if((B|0)<1){z=1;i=e;return z|0}if((gzL(v,0,0)|0)==0){break}else{z=1}i=e;return z|0}}while(0);v=c[2387834]|0;if((c[3542200]|0)==0){z=1;i=e;return z|0}A=r+108|0;c[A>>2]=0;y=r+100|0;c[y>>2]=0;B=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[B&16383](r,1)|0;do{if((c[A>>2]|0)!=0){B=c[y>>2]|0;c[s>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](s,1,0)|0;if((B|0)<1){z=1;i=e;return z|0}if((gzL(v,0,1)|0)==0){break}else{z=1}i=e;return z|0}}while(0);v=(c[2387834]|0)+262144|0;if((c[3542200]|0)==0){z=1;i=e;return z|0}y=p+108|0;c[y>>2]=0;A=p+100|0;c[A>>2]=0;B=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[B&16383](p,2)|0;do{if((c[y>>2]|0)!=0){B=c[A>>2]|0;c[q>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](q,2,0)|0;if((B|0)<1){z=1;i=e;return z|0}if((gzL(v,0,2)|0)==0){break}else{z=1}i=e;return z|0}}while(0);v=c[2386686]|0;if((c[3542200]|0)==0){z=1;i=e;return z|0}A=n+108|0;c[A>>2]=0;y=n+100|0;c[y>>2]=0;B=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[B&16383](n,3)|0;do{if((c[A>>2]|0)!=0){B=c[y>>2]|0;c[o>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](o,3,0)|0;if((B|0)<1){z=1;i=e;return z|0}if((gzL(v,0,3)|0)==0){break}else{z=1}i=e;return z|0}}while(0);v=c[3531046]|0;if((c[3542200]|0)==0){z=1;i=e;return z|0}y=l+108|0;c[y>>2]=0;A=l+100|0;c[A>>2]=0;B=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[B&16383](l,4)|0;do{if((c[y>>2]|0)!=0){B=c[A>>2]|0;c[m>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](m,4,0)|0;if((B|0)<1){z=1;i=e;return z|0}if((gzL(v,0,4)|0)==0){break}else{z=1}i=e;return z|0}}while(0);v=(c[3531046]|0)+256|0;if((c[3542200]|0)==0){z=1;i=e;return z|0}A=j+108|0;c[A>>2]=0;y=j+100|0;c[y>>2]=0;B=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[B&16383](j,5)|0;do{if((c[A>>2]|0)!=0){B=c[y>>2]|0;c[k>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](k,5,0)|0;if((B|0)<1){z=1;i=e;return z|0}if((gzL(v,0,5)|0)==0){break}else{z=1}i=e;return z|0}}while(0);v=(c[3531046]|0)+512|0;if((c[3542200]|0)==0){z=1;i=e;return z|0}y=f+108|0;c[y>>2]=0;A=f+100|0;c[A>>2]=0;B=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[B&16383](f,6)|0;do{if((c[y>>2]|0)==0){D=0}else{B=c[A>>2]|0;c[g>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](g,6,0)|0;if((B|0)<1){z=1;i=e;return z|0}if((gzL(v,0,6)|0)==0){D=0;break}else{z=1}i=e;return z|0}}while(0);while(1){if((D|0)>=1024){break}E=9638528+(D<<2)|0;if((c[E>>2]|0)==0){x=70853;break}else{D=D+1|0}}L91876:do{if((x|0)==70853){v=gGq(524288)|0;c[E>>2]=v;if((v|0)==0){break}gGz(v|0,0,524288);A=c[2387834]|0;gGC(v|0,A|0,524288)|0;A=c[2443550]|0;y=0;while(1){B=y<<6;gGz(A+B|0,0,64);C=y<<7;F=0;do{G=1<<3-F;H=(c[703416+(F<<2)>>2]|0)+C|0;I=0;do{J=H+(c[6669224+(I<<2)>>2]|0)|0;K=(I<<3)+B|0;L=0;do{M=J+(c[612896+(L<<2)>>2]|0)|0;if(((d[v+((M|0)/8|0)|0]|0)&128>>>((M&7)>>>0)|0)!=0){M=A+(K+L)|0;a[M]=(d[M]|0|G)&255}L=L+1|0;}while((L|0)<8);I=I+1|0;}while((I|0)<8);F=F+1|0;}while((F|0)<4);F=y+1|0;if((F|0)<16384){y=F}else{N=0;break}}while(1){if((N|0)>=1024){break L91876}O=9638528+(N<<2)|0;if((c[O>>2]|0)==(v|0)){break}else{N=N+1|0}}gGr(v);c[O>>2]=0}}while(0);y=c[3531046]|0;A=c[2406998]|0;F=0;do{B=d[y+F|0]|0;C=d[y+(F+256)|0]|0;I=d[y+(F+512)|0]|0;c[A+(F<<2)>>2]=(-(C>>>1&1)&31)+(-(C&1)&14)+(-(C>>>2&1)&67)+(-(C>>>3&1)&143)<<8|(-(B>>>1&1)&31)+(-(B&1)&14)+(-(B>>>2&1)&67)+(-(B>>>3&1)&143)<<16|(-(I>>>1&1)&31)+(-(I&1)&14)+(-(I>>>2&1)&67)+(-(I>>>3&1)&143);F=F+1|0;}while((F|0)<256);fwR(0);F=c[2439330]|0;A=(F|0)==0;if(!A){y=F;gGC(9706056,y|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];y=c[3528484]|0;c[2076596]=y;I=c[2417276]|0;c[3541536]=I;c[1836236]=0;B=c[2385988]|0;C=0;G=0;while(1){c[F+76+(G<<2)>>2]=B+(G<<8);H=C+1&65535;if((H&65535)>127){P=0;Q=0;break}else{C=H;G=H&65535}}while(1){G=B+(Q<<8)|0;c[F+76+(Q+512<<2)>>2]=G;c[F+76+(Q+768<<2)>>2]=G;G=P+1&65535;if((G&65535)>127){break}else{P=G;Q=G&65535}}B=c[2386140]|0;G=160;C=160;while(1){c[F+76+(C<<2)>>2]=B+((C<<8)-40960);H=G+1&65535;if((H&65535)>191){R=160;S=160;break}else{G=H;C=H&65535}}while(1){c[F+76+(S+256<<2)>>2]=B+((S<<8)-40960);C=R+1&65535;if((C&65535)>191){T=160;U=160;break}else{R=C;S=C&65535}}while(1){C=B+((U<<8)-40960)|0;c[F+76+(U+512<<2)>>2]=C;c[F+76+(U+768<<2)>>2]=C;C=T+1&65535;if((C&65535)>191){break}else{T=C;U=C&65535}}c[F+4184>>2]=1930;c[F+4180>>2]=354;if(!A){B=F;gGC(B|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=y;c[2417276]=I;c[1836236]=-1;Ux(0,8e3,0);c[2407030]=128;c[2407068]=3;c[2420382]=9674032;c[2418579]=93750;c[2418578]=15e5;h[1209290]=1.0;c[2418582]=3;c[2443780]=~~(93750.0/(a[9680]|0?32.0e3:0.0)*32768.0);c[2418585]=gGq(375e3)|0;B=gGq(5120)|0;c[2418583]=B;C=B+2560|0;c[2418584]=C;b[C>>1]=0;b[B+2562>>1]=25;b[(c[2418584]|0)-2>>1]=-25;B=2;do{C=(B<<7|0)/5|0;b[(c[2418584]|0)+(B<<1)>>1]=C&65535;b[(c[2418584]|0)+(-B<<1)>>1]=-C&65535;B=B+1|0;}while((B|0)<1280);c[2420382]=9674032;h[1209290]=.5;c[2418582]=3;B=c[642608+(c[2436]<<2)>>2]|0;I=c[B+128>>2]|0;if((c[B+52>>2]&4|0)==0){c[2113068]=I;y=c[B+132>>2]|0;c[2113070]=y;c[2443814]=I;c[2440436]=y;V=I;W=y}else{c[2113070]=I;y=c[B+132>>2]|0;c[2113068]=y;c[2440436]=I;c[2443814]=y;V=y;W=I}I=ag(V<<1,W)|0;y=gGq(I)|0;c[2112926]=y;if((y|0)!=0){gGz(y|0,0,I|0)}a[9624928]=0;I=c[2414786]|0;gGz(I|0,0,(c[2411846]|0)-I|0);I=c[2439330]|0;if((I|0)!=0){y=I;gGC(9706056,y|0,76)|0}c[2433530]=c[2438118];y=c[3528484]|0;c[2076596]=y;B=c[2417276]|0;c[3541536]=B;c[1836236]=0;gGz(9706056,0,76);c[2406764]=4;F=c[2385988]|0;A=128;C=128;while(1){c[I+76+(C<<2)>>2]=F+(C<<8);G=A+1&65535;if((G&65535)>159){break}else{A=G;C=G&65535}}C=(c[2406764]<<13)-32768|0;A=128;G=128;while(1){H=F+(C+(G<<8))|0;c[I+76+(G+512<<2)>>2]=H;c[I+76+(G+768<<2)>>2]=H;H=A+1&65535;if((H&65535)>159){break}else{A=H;G=H&65535}}G=I;gGC(G|0,9706056,76)|0;c[2438118]=c[2433530];c[3528484]=y;c[2417276]=B;c[1836236]=-1;c[2420382]=9674032;c[2406764]=0;c[2405130]=0;c[2406656]=0;c[2406662]=0;c[2439286]=0;z=0;i=e;return z|0}}while(0);c[2415078]=0;z=1;i=e;return z|0}function blT(){var a=0,b=0,d=0,e=0;c[2113070]=0;c[2113068]=0;a=c[2112926]|0;if((a|0)!=0){gGr(a);c[2112926]=0}Uw(0);c[2420382]=9674032;a=c[2418585]|0;if((a|0)!=0){gGr(a);c[2418585]=0}a=c[2418583]|0;if((a|0)!=0){gGr(a);c[2418583]=0}c[2443780]=0;fwZ();a=c[2415078]|0;b=0;while(1){if((b|0)>=1024){d=70930;break}e=9638528+(b<<2)|0;if((c[e>>2]|0)==(a|0)){break}else{b=b+1|0}}if((d|0)==70930){c[2415078]=0;c[3541206]=0;return 0}gGr(a);c[e>>2]=0;c[2415078]=0;c[3541206]=0;return 0}function blU(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=a[9688]|0?534:0;if((a[9624928]|0)!=0){a[9624928]=0;e=c[2414786]|0;gGz(e|0,0,(c[2411846]|0)-e|0);e=c[2439330]|0;if((e|0)!=0){f=e;gGC(9706056,f|0,76)|0}c[2433530]=c[2438118];f=c[3528484]|0;c[2076596]=f;g=c[2417276]|0;c[3541536]=g;c[1836236]=0;gGz(9706056,0,76);c[2406764]=4;h=c[2385988]|0;i=128;j=128;while(1){c[e+76+(j<<2)>>2]=h+(j<<8);k=i+1&65535;if((k&65535)>159){break}else{i=k;j=k&65535}}j=(c[2406764]<<13)-32768|0;i=128;k=128;while(1){l=h+(j+(k<<8))|0;c[e+76+(k+512<<2)>>2]=l;c[e+76+(k+768<<2)>>2]=l;l=i+1&65535;if((l&65535)>159){break}else{i=l;k=l&65535}}k=e;gGC(k|0,9706056,76)|0;c[2438118]=c[2433530];c[3528484]=f;c[2417276]=g;c[1836236]=-1;c[2420382]=9674032;c[2406764]=0;c[2405130]=0;c[2406656]=0;c[2406662]=0;c[2439286]=0}gGz(9550880,-1|0,3);g=0;f=-1;k=-1;e=-1;do{f=((a[9634280+g|0]&1)<<g^f&255)&255;k=((a[9632040+g|0]&1)<<g^k&255)&255;e=((a[9629960+g|0]&1)<<g^e&255)&255;g=g+1|0;}while((g|0)<8);a[9550880]=f;a[9550881]=k;a[9550882]=e;if((f&3)==0){e=f|3;a[9550880]=e;m=e}else{m=f}if((m&12)==0){a[9550880]=m|12}if((k&3)==0){m=k|3;a[9550881]=m;n=m}else{n=k}if((n&12)==0){a[9550881]=n|12}n=c[2385548]|0;if((n|0)>0){gGz(9752472,0,((n|0)>1?n<<2:4)|0)}c[2433530]=0;n=c[2439330]|0;if((n|0)!=0){k=n;gGC(9706056,k|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;k=(d>>>0)/3|0;n=k<<1;m=d-1|0;f=0;e=0;g=0;L91992:while(1){i=e;j=g;while(1){if((j|0)>=(d|0)){break L91992}o=j+1|0;h=((o*1e5|0|0)/534|0)-i|0;do{if((h|0)<1){p=0}else{if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){l=gfc(h)|0;c[2433530]=(c[2433530]|0)+l;p=l;break}else{c[2433530]=(c[2433530]|0)+h;p=h;break}}}while(0);if((j|0)==(k|0)){if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12}if((j|0)==(n|0)){if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12}if((j|0)==(m|0)){a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0}q=p+i|0;r=c[2112964]|0;if((r|0)==0){i=q;j=o}else{break}}j=a[9688]&1;i=r+(f<<1<<1)|0;Uu(0,i,j);Ud(i,j);f=j+f|0;e=q;g=o}o=c[1836236]|0;g=c[9757320+(o<<2)>>2]|0;if((g|0)!=0){q=g;gGC(q|0,9706056,76)|0}c[9752472+(o<<2)>>2]=c[2433530];c[14113936+(o<<2)>>2]=c[2076596];c[9669104+(o<<2)>>2]=c[3541536];c[1836236]=-1;o=c[2112964]|0;do{if((o|0)!=0){q=a[9688]|0?534:0;g=q-f|0;e=o+(f<<1<<1)|0;if((q|0)==(f|0)){break}Uu(0,e,g);Ud(e,g)}}while(0);if((c[2112968]|0)==0){return 0}if((a[9547920]|0)==0){s=c[3530164]|0}else{f=c[2406998]|0;o=c[3530164]|0;g=0;while(1){e=c[f+(g<<2)>>2]|0;c[o+(g<<2)>>2]=e>>8<<3&2016|e>>>3&31|e>>16<<8&63488;e=g+1|0;if((e|0)<256){g=e}else{s=o;break}}}blX(8192,0,4);blX(0,1,0);R8(s);return 0}function blV(){var b=0,d=0,e=0,f=0,g=0;if((a[9547920]|0)==0){b=c[3530164]|0}else{d=c[2406998]|0;e=c[3530164]|0;f=0;while(1){g=c[d+(f<<2)>>2]|0;c[e+(f<<2)>>2]=g>>8<<3&2016|g>>>3&31|g>>16<<8&63488;g=f+1|0;if((g|0)<256){f=g}else{b=e;break}}}blX(8192,0,4);blX(0,1,0);R8(b);return 0}function blW(a,d){a=a|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;e=i;i=i+112|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;l=e+80|0;m=e+96|0;n=(d|0)==0;if(!n){c[d>>2]=169733}if((a&32|0)!=0){gGz(m|0,0,12);o=c[2414786]|0;c[m>>2]=o;c[m+4>>2]=(c[2411846]|0)-o;c[m+12>>2]=162152;o=c[2076592]|0;gj[o&4095](m)|0}if((a&64|0)!=0){fw$(a);Ut(0);if(!n){c[d>>2]=169733}d=f|0;c[d>>2]=c[2420382];n=f+4|0;c[n>>2]=280;a=f+8|0;c[a>>2]=0;m=f+12|0;c[m>>2]=144416;o=c[2076592]|0;gj[o&4095](f)|0;c[d>>2]=(c[2420382]|0)+312;c[n>>2]=40;c[a>>2]=0;c[m>>2]=493520;m=c[2076592]|0;gj[m&4095](f)|0;gGz(l|0,0,12);c[l>>2]=9627056;c[l+4>>2]=4;c[l+12>>2]=129240;f=c[2076592]|0;gj[f&4095](l)|0;gGz(k|0,0,12);c[k>>2]=9620520;c[k+4>>2]=4;c[k+12>>2]=104672;l=c[2076592]|0;gj[l&4095](k)|0;gGz(j|0,0,12);c[j>>2]=9626624;c[j+4>>2]=4;c[j+12>>2]=80872;k=c[2076592]|0;gj[k&4095](j)|0;gGz(h|0,0,12);c[h>>2]=9626648;c[h+4>>2]=4;c[h+12>>2]=587368;j=c[2076592]|0;gj[j&4095](h)|0;gGz(g|0,0,12);c[g>>2]=9757144;c[g+4>>2]=4;c[g+12>>2]=571280;h=c[2076592]|0;gj[h&4095](g)|0}g=c[2439330]|0;if((g|0)!=0){h=g;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];h=c[3528484]|0;c[2076596]=h;j=c[2417276]|0;c[3541536]=j;c[1836236]=0;k=c[2406764]&15;c[2406764]=k;l=c[2385988]|0;f=(k<<13)-32768|0;k=128;m=128;while(1){c[g+76+(m<<2)>>2]=l+(f+(m<<8));a=k+1&65535;if((a&65535)>159){break}else{k=a;m=a&65535}}m=(c[2406764]<<13)-32768|0;k=128;f=128;while(1){a=l+(m+(f<<8))|0;c[g+76+(f+512<<2)>>2]=a;c[g+76+(f+768<<2)>>2]=a;a=k+1&65535;if((a&65535)>159){break}else{k=a;f=a&65535}}f=g;gGC(f|0,9706056,76)|0;c[2438118]=c[2433530];c[3528484]=h;c[2417276]=j;c[1836236]=-1;i=e;return 0}function blX(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=(c[2386268]|0)+b|0;b=(f|0)==0;h=(f|0)!=0;i=c[3528772]|0;j=c[2443550]|0;k=c[2112926]|0;if((e|0)==0){e=0;l=g;do{m=e<<3;n=m&504;o=e>>6<<3;p=d[l+1|0]<<8&16128|d[l];q=a[l+2|0]&15;l=l+4|0;do{if((a[i]|0)==0){Sj(k,p,n+f|0,o-f|0,q,4,0,j);if(b){break}if((o|0)==0){Sj(k,p,n,252,q,4,0,j)}if((n|0)!=504){break}Sj(k,p,m|-508,o,q,4,0,j)}else{r=n^504;s=o^248;Sp(k,p,r-f|0,s+f|0,q,4,0,j);if(!(h&(n|0)==504)){break}Sj(k,p,r+508|0,s,q,4,0,j)}}while(0);e=e+1|0;}while((e|0)<2048);return}else{e=0;l=g;do{g=e<<3;q=g&504;p=e>>6<<3;n=d[l+1|0]<<8&16128|d[l];o=a[l+2|0]&15;l=l+4|0;do{if((a[i]|0)==0){Sr(k,n,q+f|0,p-f|0,o,4,0,0,j);if(b){break}if((p|0)==0){Sj(k,n,q,252,o,4,0,j)}if((q|0)!=504){break}Sj(k,n,g|-508,p,o,4,0,j)}else{m=q^504;s=p^248;Sx(k,n,m-f|0,s+f|0,o,4,0,0,j);if(!(h&(q|0)==504)){break}Sj(k,n,m+508|0,s,o,4,0,j)}}while(0);e=e+1|0;}while((e|0)<2048);return}}function blY(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=b&65535;switch(e|0){case 8064:{a[c[2394762]|0]=d;b=c[3527396]|0;f=c[3528554]|0;g=c[2433592]|0;h=((d&255)<<12&122880)+40960|0;i=96;j=96;while(1){k=b+(h+(j<<8))|0;c[g+(f*3148|0)+48+(j<<2)>>2]=k;c[g+(f*3148|0)+48+(j+512<<2)>>2]=k;k=i+1&65535;if((k&65535)>127){break}else{i=k;j=k&65535}}return};case 8128:{a[14125144]=-1;a[9706117]=1;return};case 8080:{j=d&255;c[3541230]=j&4;c[2429440]=j&8^8;c[2440040]=j&16;c[2433418]=j&32;return};case 8112:{a[c[3528352]|0]=d;return};case 8096:{return};default:{if((e&65520|0)==8176){a[14108592+(e&15)|0]=d;return}do{if((c[2433418]|0)==0){j=e&63488;if((j|0)==8192){a[(c[2387262]|0)+(e&2047)|0]=d;return}else if((j|0)==0){a[(c[3529076]|0)+(e&2047)|0]=d;bi2(e&1023,0);return}else{break}}}while(0);if((e&49152|0)!=0){return}blF(e&16383,d&255);return}}}function blZ(b){b=b|0;var e=0,f=0;e=b&65535;switch(e|0){case 8144:{f=a[9635618]&-16|a[9550874]&15;return f|0};case 8145:{f=a[9550872]|0;return f|0};case 8147:{f=a[9635616]|0;return f|0};case 8160:{f=a[9635617]|0;return f|0};case 8146:{f=a[9550873]|0;return f|0};default:{do{if((c[2433418]|0)==0){b=e&63488;if((b|0)==8192){f=a[(c[2387262]|0)+(e&2047)|0]|0;return f|0}else if((b|0)!=0){break}b=e&2047;if((c[2440040]|0)==0){f=a[(c[3529076]|0)+b|0]|0;return f|0}if((a[14108606]&1)!=0){f=0;return f|0}f=a[(c[3529080]|0)+(((d[14108604]|0)<<11|b|(d[14108605]|0)<<19)>>>(((c[2443318]|0)<5|0)>>>0)&c[3527144])|0]|0;return f|0}}while(0);if((e&49152|0)!=0){f=0;return f|0}f=blE(e&16383)|0;return f|0}}return 0}function bl_(b,d){b=b|0;d=d|0;var e=0;e=b&65535;b=e&65520;if((b|0)==40960){TI(0,e&15,d&255);return}else if((b|0)==45056){TI(1,e&15,d&255);return}else{if((e|0)==36864){b=d&255;c[2420315]=b<<17&393216;c[2420316]=b>>>2<<17&393216;c[2424878]=9681296;c[2420331]=b>>>4<<17&393216;c[2420332]=b>>>6<<17;return}else if((e|0)==61440){a[c[3528480]|0]=d;return}else{return}}}function bl$(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=b&65535;f=e&65520;if((f|0)==40960){g=e&15;c[2424878]=9681232;c[2426622]=9622928;if(!((g|0)==11|(g|0)==5)){h=0;return h|0}i=(g>>>0)/6|0;g=i*6|0;j=(d[g+9681280|0]|0)<<16&65536|(d[g+9681279|0]|0)<<8|(d[g+9681278|0]|0)|c[9681260+(i<<2)>>2];c[9681244+(i<<2)>>2]=j;if(j>>>0>=(c[2405735]|0)>>>0){h=0;return h|0}c[9681268+(i<<2)>>2]=1;c[9681236+(i<<2)>>2]=0;h=0;return h|0}else if((f|0)==45056){f=e&15;c[2424878]=9681296;c[2426622]=9622976;if(!((f|0)==11|(f|0)==5)){h=0;return h|0}e=(f>>>0)/6|0;f=e*6|0;i=(d[f+9681344|0]|0)<<16&65536|(d[f+9681343|0]|0)<<8|(d[f+9681342|0]|0)|c[9681324+(e<<2)>>2];c[9681308+(e<<2)>>2]=i;if(i>>>0>=(c[2405747]|0)>>>0){h=0;return h|0}c[9681332+(e<<2)>>2]=1;c[9681300+(e<<2)>>2]=0;h=0;return h|0}else{if(b<<16>>16!=-12288){h=0;return h|0}a[9706117]=0;h=a[c[3528352]|0]|0;return h|0}return 0}function bl0(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>37){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4794932+(b*112|0)>>2];c[a+104>>2]=c[4794936+(b*112|0)>>2];c[a+108>>2]=c[4794940+(b*112|0)>>2];d=0;return d|0}function bl1(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<38&(d|0)==0)){e=1;return e|0}c[a>>2]=4794832+(b*112|0);e=0;return e|0}function bl2(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=2000088+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function bl3(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>64){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5562072+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function bl4(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0;e=i;i=i+1560|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;B=e+1200|0;C=e+1312|0;D=e+1320|0;E=e+1432|0;F=e+1440|0;G=e+1552|0;c[2415076]=0;c[3527396]=0;c[2385986]=196608;c[3530926]=262144;c[3530690]=786432;c[3530482]=1835008;c[2439894]=1966080;c[2439858]=3014656;c[2439844]=5111808;c[3529770]=5373952;c[3529724]=5636096;c[3530162]=5898240;c[2414784]=5902336;c[3527412]=5902336;c[2387262]=5910528;c[2386138]=5912576;c[3528352]=5914624;c[3528480]=5914625;c[2394762]=5914626;c[2411844]=5914627;H=0;while(1){if((H|0)>=1024){break}I=9638528+(H<<2)|0;if((c[I>>2]|0)==0){J=71139;break}else{H=H+1|0}}do{if((J|0)==71139){H=gGq(5914627)|0;c[I>>2]=H;if((H|0)==0){break}c[2415076]=H;gGz(H|0,0,5914627);c[3527396]=H;c[2385986]=H+196608;c[3530926]=H+262144;c[3530690]=H+786432;c[3530482]=H+1835008;c[2439894]=H+1966080;c[2439858]=H+3014656;c[2439844]=H+5111808;c[3529770]=H+5373952;c[3529724]=H+5636096;c[3530162]=H+5898240;K=H+5902336|0;c[2414784]=K;c[3527412]=K;c[2387262]=H+5910528;c[2386138]=H+5912576;c[3528352]=H+5914624;c[3528480]=H+5914625;c[2394762]=H+5914626;K=H+5914627|0;c[2411844]=K;c[2414394]=K;K=H+65536|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}H=F+108|0;c[H>>2]=0;M=F+100|0;c[M>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](F,0)|0;do{if((c[H>>2]|0)!=0){N=c[M>>2]|0;c[G>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](G,0,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(K,0,0)|0)==0){break}else{L=1}i=e;return L|0}}while(0);K=c[3527396]|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}M=D+108|0;c[M>>2]=0;H=D+100|0;c[H>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](D,1)|0;do{if((c[M>>2]|0)!=0){N=c[H>>2]|0;c[E>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](E,1,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(K,0,1)|0)==0){break}else{L=1}i=e;return L|0}}while(0);K=c[3527396]|0;H=K+131072|0;gGC(H|0,K|0,32768)|0;H=K+163840|0;gGC(H|0,K|0,32768)|0;K=c[2385986]|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}H=B+108|0;c[H>>2]=0;M=B+100|0;c[M>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](B,2)|0;do{if((c[H>>2]|0)!=0){N=c[M>>2]|0;c[C>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](C,2,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(K,0,2)|0)==0){break}else{L=1}i=e;return L|0}}while(0);if((R6(c[3530926]|0,3,2)|0)!=0){L=1;i=e;return L|0}if((R6((c[3530926]|0)+1|0,4,2)|0)!=0){L=1;i=e;return L|0}if((R6((c[3530926]|0)+131072|0,5,2)|0)!=0){L=1;i=e;return L|0}if((R6((c[3530926]|0)+131073|0,6,2)|0)!=0){L=1;i=e;return L|0}if((R6((c[3530926]|0)+262144|0,7,2)|0)!=0){L=1;i=e;return L|0}if((R6((c[3530926]|0)+262145|0,8,2)|0)!=0){L=1;i=e;return L|0}if((R6((c[3530926]|0)+393216|0,9,2)|0)!=0){L=1;i=e;return L|0}if((R6((c[3530926]|0)+393217|0,10,2)|0)!=0){L=1;i=e;return L|0}if((R6(c[3530690]|0,11,2)|0)!=0){L=1;i=e;return L|0}if((R6((c[3530690]|0)+1|0,12,2)|0)!=0){L=1;i=e;return L|0}if((R6((c[3530690]|0)+131072|0,13,2)|0)!=0){L=1;i=e;return L|0}if((R6((c[3530690]|0)+131073|0,14,2)|0)!=0){L=1;i=e;return L|0}if((R6((c[3530690]|0)+262144|0,15,2)|0)!=0){L=1;i=e;return L|0}if((R6((c[3530690]|0)+262145|0,16,2)|0)!=0){L=1;i=e;return L|0}if((R6((c[3530690]|0)+393216|0,17,2)|0)!=0){L=1;i=e;return L|0}if((R6((c[3530690]|0)+393217|0,18,2)|0)!=0){L=1;i=e;return L|0}if((R6((c[3530690]|0)+524288|0,19,2)|0)!=0){L=1;i=e;return L|0}if((R6((c[3530690]|0)+524289|0,20,2)|0)!=0){L=1;i=e;return L|0}if((R6((c[3530690]|0)+655360|0,21,2)|0)!=0){L=1;i=e;return L|0}if((R6((c[3530690]|0)+655361|0,22,2)|0)!=0){L=1;i=e;return L|0}if((R6((c[3530690]|0)+786432|0,23,2)|0)!=0){L=1;i=e;return L|0}if((R6((c[3530690]|0)+786433|0,24,2)|0)!=0){L=1;i=e;return L|0}if((R6((c[3530690]|0)+917504|0,25,2)|0)!=0){L=1;i=e;return L|0}if((R6((c[3530690]|0)+917505|0,26,2)|0)!=0){L=1;i=e;return L|0}K=c[3530482]|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}M=z+108|0;c[M>>2]=0;H=z+100|0;c[H>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](z,27)|0;do{if((c[M>>2]|0)!=0){N=c[H>>2]|0;c[A>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](A,27,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(K,0,27)|0)==0){break}else{L=1}i=e;return L|0}}while(0);K=(c[3530482]|0)+65536|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}H=x+108|0;c[H>>2]=0;M=x+100|0;c[M>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](x,28)|0;do{if((c[H>>2]|0)!=0){N=c[M>>2]|0;c[y>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](y,28,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(K,0,28)|0)==0){break}else{L=1}i=e;return L|0}}while(0);K=c[3529770]|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}M=v+108|0;c[M>>2]=0;H=v+100|0;c[H>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](v,29)|0;do{if((c[M>>2]|0)!=0){N=c[H>>2]|0;c[w>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](w,29,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(K,0,29)|0)==0){break}else{L=1}i=e;return L|0}}while(0);K=(c[3529770]|0)+65536|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}H=t+108|0;c[H>>2]=0;M=t+100|0;c[M>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](t,30)|0;do{if((c[H>>2]|0)!=0){N=c[M>>2]|0;c[u>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](u,30,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(K,0,30)|0)==0){break}else{L=1}i=e;return L|0}}while(0);K=(c[3529770]|0)+131072|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}M=r+108|0;c[M>>2]=0;H=r+100|0;c[H>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](r,31)|0;do{if((c[M>>2]|0)!=0){N=c[H>>2]|0;c[s>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](s,31,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(K,0,31)|0)==0){break}else{L=1}i=e;return L|0}}while(0);K=(c[3529770]|0)+196608|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}H=p+108|0;c[H>>2]=0;M=p+100|0;c[M>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](p,32)|0;do{if((c[H>>2]|0)!=0){N=c[M>>2]|0;c[q>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](q,32,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(K,0,32)|0)==0){break}else{L=1}i=e;return L|0}}while(0);K=c[3529724]|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}M=n+108|0;c[M>>2]=0;H=n+100|0;c[H>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](n,33)|0;do{if((c[M>>2]|0)!=0){N=c[H>>2]|0;c[o>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](o,33,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(K,0,33)|0)==0){break}else{L=1}i=e;return L|0}}while(0);K=(c[3529724]|0)+65536|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}H=l+108|0;c[H>>2]=0;M=l+100|0;c[M>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](l,34)|0;do{if((c[H>>2]|0)!=0){N=c[M>>2]|0;c[m>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](m,34,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(K,0,34)|0)==0){break}else{L=1}i=e;return L|0}}while(0);K=(c[3529724]|0)+131072|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}M=j+108|0;c[M>>2]=0;H=j+100|0;c[H>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](j,35)|0;do{if((c[M>>2]|0)!=0){N=c[H>>2]|0;c[k>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](k,35,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(K,0,35)|0)==0){break}else{L=1}i=e;return L|0}}while(0);K=(c[3529724]|0)+196608|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}H=f+108|0;c[H>>2]=0;M=f+100|0;c[M>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](f,36)|0;do{if((c[H>>2]|0)!=0){N=c[M>>2]|0;c[g>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](g,36,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(K,0,36)|0)==0){break}else{L=1}i=e;return L|0}}while(0);K=c[3530926]|0;blG(K,262144);M=c[3530690]|0;blG(M,524288);H=c[2439894]|0;N=0;do{O=N<<6;gGz(H+O|0,0,64);P=N<<8;Q=0;do{R=1<<3-Q;S=(c[611632+(Q<<2)>>2]|0)+P|0;T=0;do{U=S+(c[3946808+(T<<2)>>2]|0)|0;V=(T<<3)+O|0;W=0;do{X=U+(c[6669416+(W<<2)>>2]|0)|0;if(((d[K+((X|0)/8|0)|0]|0)&128>>>((X&7)>>>0)|0)!=0){X=H+(V+W)|0;a[X]=(d[X]|0|R)&255}W=W+1|0;}while((W|0)<8);T=T+1|0;}while((T|0)<8);Q=Q+1|0;}while((Q|0)<4);N=N+1|0;}while((N|0)<16384);N=c[2439858]|0;H=0;do{K=H<<8;gGz(N+K|0,0,256);Q=H<<10;O=0;do{P=1<<3-O;T=(c[611400+(O<<2)>>2]|0)+Q|0;R=0;do{S=T+(c[3946808+(R<<2)>>2]|0)|0;W=(R<<4)+K|0;V=0;do{U=S+(c[6669416+(V<<2)>>2]|0)|0;if(((d[M+((U|0)/8|0)|0]|0)&128>>>((U&7)>>>0)|0)!=0){U=N+(W+V)|0;a[U]=(d[U]|0|P)&255}V=V+1|0;}while((V|0)<16);R=R+1|0;}while((R|0)<16);O=O+1|0;}while((O|0)<4);H=H+1|0;}while((H|0)<8192);c[3528554]=-1;c[2113160]=1;H=gGq(3148)|0;N=H;c[2433592]=N;if((H|0)!=0){gGz(H|0,0,3148);c[H+3120>>2]=3128;c[H+3124>>2]=1840;c[H+3128>>2]=136;c[H+3132>>2]=1902;c[2432840]=0;M=0;do{c[N+48+(M<<2)>>2]=0;M=M+1|0;}while((M|0)<768);c[2113158]=0;c[2415198]=0;M=c[2427044]|0;c[9681616+(M<<3)>>2]=809272;c[9681620+(M<<3)>>2]=0;c[2427044]=M+1}c[3528554]=0;f43(H);M=c[3528554]|0;N=9731360+(M<<2)|0;O=c[N>>2]|0;c[2113158]=O;K=c[3527412]|0;Q=c[2433592]|0;R=64;P=64;while(1){T=K+((P<<8)-16384)|0;c[Q+(M*3148|0)+48+(P<<2)>>2]=T;c[Q+(M*3148|0)+48+(P+256<<2)>>2]=T;c[Q+(M*3148|0)+48+(P+512<<2)>>2]=T;T=R+1&65535;if((T&65535)>95){break}else{R=T;P=T&65535}}P=c[3527396]|0;R=96;K=96;while(1){H=P+((K<<8)+40960)|0;c[Q+(M*3148|0)+48+(K<<2)>>2]=H;c[Q+(M*3148|0)+48+(K+512<<2)>>2]=H;H=R+1&65535;if((H&65535)>127){Y=128;Z=128;break}else{R=H;K=H&65535}}while(1){K=P+(Z<<8)|0;c[Q+(M*3148|0)+48+(Z<<2)>>2]=K;c[Q+(M*3148|0)+48+(Z+512<<2)>>2]=K;K=Y+1&65535;if((K&65535)>255){break}else{Y=K;Z=K&65535}}c[Q+(M*3148|0)+3124>>2]=40;c[Q+(M*3148|0)+3120>>2]=3122;P=Q+(M*3148|0)|0;if((P|0)!=0){K=P;gGC(K|0,9660752,48)|0}c[N>>2]=O;c[3528554]=-1;fwR(0);K=c[2439330]|0;P=(K|0)==0;if(!P){R=K;gGC(9706056,R|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];R=c[3528484]|0;c[2076596]=R;H=c[2417276]|0;c[3541536]=H;c[1836236]=0;T=c[2385986]|0;V=0;W=0;while(1){c[K+76+(W<<2)>>2]=T+(W<<8);S=V+1&65535;if((S&65535)>127){_=0;$=0;break}else{V=S;W=S&65535}}while(1){W=T+($<<8)|0;c[K+76+($+512<<2)>>2]=W;c[K+76+($+768<<2)>>2]=W;W=_+1&65535;if((W&65535)>127){break}else{_=W;$=W&65535}}T=c[2386138]|0;c[K+588>>2]=T;W=T+256|0;c[K+592>>2]=W;V=T+512|0;c[K+596>>2]=V;O=T+768|0;c[K+600>>2]=O;N=T+1024|0;c[K+604>>2]=N;M=T+1280|0;c[K+608>>2]=M;Q=T+1536|0;c[K+612>>2]=Q;S=T+1792|0;c[K+616>>2]=S;c[K+1612>>2]=T;c[K+1616>>2]=W;c[K+1620>>2]=V;c[K+1624>>2]=O;c[K+1628>>2]=N;c[K+1632>>2]=M;c[K+1636>>2]=Q;c[K+1640>>2]=S;c[K+2636>>2]=T;c[K+3660>>2]=T;c[K+2640>>2]=W;c[K+3664>>2]=W;c[K+2644>>2]=V;c[K+3668>>2]=V;c[K+2648>>2]=O;c[K+3672>>2]=O;c[K+2652>>2]=N;c[K+3676>>2]=N;c[K+2656>>2]=M;c[K+3680>>2]=M;c[K+2660>>2]=Q;c[K+3684>>2]=Q;c[K+2664>>2]=S;c[K+3688>>2]=S;c[K+4184>>2]=3450;c[K+4180>>2]=1866;if(!P){S=K;gGC(S|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=R;c[2417276]=H;c[1836236]=-1;TJ(0,c[3529770]|0,262144);c[2424878]=9681232;c[2405736]=1104;h[1202869]=.4;c[2405742]=3;c[2426622]=9622928;h[1202870]=.4;c[2405743]=3;TJ(1,c[3529724]|0,262144);c[2424878]=9681296;c[2405748]=780;h[1202875]=.4;c[2405754]=3;c[2426622]=9622976;h[1202876]=.4;c[2405755]=3;S=c[3530926]|0;Q=0;while(1){if((Q|0)>=1024){aa=0;break}ab=9638528+(Q<<2)|0;if((c[ab>>2]|0)==0){J=71258;break}else{Q=Q+1|0}}do{if((J|0)==71258){Q=gGq(24576)|0;c[ab>>2]=Q;if((Q|0)==0){aa=0;break}gGz(Q|0,0,24576);aa=Q}}while(0);c[3529062]=aa;c[2438700]=524287;c[3529060]=S;a[7461784]=1;Q=9726816;c[Q>>2]=0;c[Q+4>>2]=0;Q=9726800;c[Q>>2]=0;c[Q+4>>2]=0;c[2429638]=0;c[2437692]=40;c[2431704]=8;c[2431700]=0;c[2431705]=8;c[2431701]=0;c[2431706]=8;c[2431702]=0;Q=c[3530690]|0;c[2438136]=0;H=0;while(1){if((H|0)>=1024){ac=0;break}ad=9638528+(H<<2)|0;if((c[ad>>2]|0)==0){J=71263;break}else{H=H+1|0}}do{if((J|0)==71263){H=gGq(1024)|0;c[ad>>2]=H;if((H|0)==0){ac=0;break}gGz(H|0,0,1024);ac=H}}while(0);c[3529066]=ac;c[2438702]=1048575;c[3529064]=Q;a[7461792]=1;c[2437694]=86;c[2438136]=8;bi1(0,c[3530482]|0,c[2439844]|0,131071,20);c[3527138]=-112;c[3527139]=-16;H=c[642608+(c[2436]<<2)>>2]|0;S=c[H+128>>2]|0;if((c[H+52>>2]&4|0)==0){c[2113068]=S;R=c[H+132>>2]|0;c[2113070]=R;c[2443814]=S;c[2440436]=R;ae=S;af=R}else{c[2113070]=S;R=c[H+132>>2]|0;c[2113068]=R;c[2440436]=S;c[2443814]=R;ae=R;af=S}S=ag(ae<<1,af)|0;R=gGq(S)|0;c[2112926]=R;if((R|0)!=0){gGz(R|0,0,S|0)}a[9624920]=0;S=c[2414784]|0;gGz(S|0,0,(c[2411844]|0)-S|0);c[3528554]=0;f43(c[2433592]|0);S=c[3528554]|0;c[2113158]=c[9731360+(S<<2)>>2];a[9660796]=0;a[9660797]=0;a[9660786]=0;a[9660787]=0;c[2415191]=0;a[9660784]=a[9660784]|80;R=c[2433592]|0;H=c[R+(S*3148|0)+1068>>2]|0;do{if((H|0)==0){K=c[R+(S*3148|0)+3120>>2]|0;if((K|0)==0){ah=0;ai=0;aj=S;ak=R;break}P=gj[K&4095](-2)|0;K=c[3528554]|0;M=c[2433592]|0;N=c[M+(K*3148|0)+1068>>2]|0;O=(P&255)<<8;if((N|0)!=0){al=N;am=O;an=K;ao=M;J=71274;break}N=c[M+(K*3148|0)+3120>>2]|0;if((N|0)==0){ah=0;ai=O;aj=K;ak=M;break}M=gj[N&4095](-1)|0;ah=M;ai=O;aj=c[3528554]|0;ak=c[2433592]|0}else{al=H;am=(d[H+254|0]|0)<<8;an=S;ao=R;J=71274}}while(0);if((J|0)==71274){ah=a[al+255|0]|0;ai=am;aj=an;ak=ao}R=ah&255|ai;c[2415188]=R;b[4830376]=R&65535;R=ak+(aj*3148|0)|0;if((R|0)!=0){S=R;gGC(S|0,9660752,48)|0}c[9731360+(aj<<2)>>2]=c[2113158];c[3528554]=-1;S=c[2439330]|0;R=(S|0)==0;if(!R){H=S;gGC(9706056,H|0,76)|0}H=c[2438118]|0;c[2433530]=H;Q=c[3528484]|0;c[2076596]=Q;O=c[2417276]|0;c[3541536]=O;c[1836236]=0;gGz(9706056,0,76);if(!R){R=S;gGC(R|0,9706056,76)|0}c[2438118]=H;c[3528484]=Q;c[2417276]=O;c[1836236]=-1;blH();c[2429440]=0;c[2440040]=0;c[2433418]=0;L=0;i=e;return L|0}}while(0);c[2415076]=0;L=1;i=e;return L|0}function bl5(){var a=0,b=0,d=0,e=0;c[2113070]=0;c[2113068]=0;a=c[2112926]|0;if((a|0)!=0){gGr(a);c[2112926]=0}blI();c[2113160]=0;a=c[2433592]|0;if((a|0)!=0){gGr(a);c[2433592]=0}fwZ();a=c[2424800]|0;if((a|0)!=0){gGr(a);c[2424800]=0}a=c[2418166]|0;if((a|0)!=0){gGr(a);c[2418166]=0}a=c[2415076]|0;b=0;while(1){if((b|0)>=1024){d=71363;break}e=9638528+(b<<2)|0;if((c[e>>2]|0)==(a|0)){break}else{b=b+1|0}}if((d|0)==71363){c[2415076]=0;return 0}gGr(a);c[e>>2]=0;c[2415076]=0;return 0}function bl6(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;if((a[9624920]|0)!=0){a[9624920]=0;e=c[2414784]|0;gGz(e|0,0,(c[2411844]|0)-e|0);c[3528554]=0;f43(c[2433592]|0);e=c[3528554]|0;c[2113158]=c[9731360+(e<<2)>>2];a[9660796]=0;a[9660797]=0;a[9660786]=0;a[9660787]=0;c[2415191]=0;a[9660784]=a[9660784]|80;f=c[2433592]|0;g=c[f+(e*3148|0)+1068>>2]|0;do{if((g|0)==0){h=c[f+(e*3148|0)+3120>>2]|0;if((h|0)==0){i=0;j=0;k=e;l=f;break}m=gj[h&4095](-2)|0;h=c[3528554]|0;n=c[2433592]|0;o=c[n+(h*3148|0)+1068>>2]|0;p=(m&255)<<8;if((o|0)!=0){q=o;r=p;s=h;t=n;u=71370;break}o=c[n+(h*3148|0)+3120>>2]|0;if((o|0)==0){i=0;j=p;k=h;l=n;break}n=gj[o&4095](-1)|0;i=n;j=p;k=c[3528554]|0;l=c[2433592]|0}else{q=g;r=d[g+254|0]<<8;s=e;t=f;u=71370}}while(0);if((u|0)==71370){i=a[q+255|0]|0;j=r;k=s;l=t}t=i&255|j;c[2415188]=t;b[4830376]=t&65535;t=l+(k*3148|0)|0;if((t|0)!=0){l=t;gGC(l|0,9660752,48)|0}c[9731360+(k<<2)>>2]=c[2113158];c[3528554]=-1;k=c[2439330]|0;l=(k|0)==0;if(!l){t=k;gGC(9706056,t|0,76)|0}t=c[2438118]|0;c[2433530]=t;j=c[3528484]|0;c[2076596]=j;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);if(!l){l=k;gGC(l|0,9706056,76)|0}c[2438118]=t;c[3528484]=j;c[2417276]=i;c[1836236]=-1;blH();c[2429440]=0;c[2440040]=0;c[2433418]=0}gGz(9550872,-1|0,3);i=0;j=-1;t=-1;l=-1;do{j=((a[9634272+i|0]&1)<<i^j&255)&255;t=((a[9632032+i|0]&1)<<i^t&255)&255;l=((a[9629952+i|0]&1)<<i^l&255)&255;i=i+1|0;}while((i|0)<8);a[9550872]=j;a[9550873]=t;a[9550874]=l;if((j&6)==0){l=j|6;a[9550872]=l;v=l}else{v=j}if((v&24)==0){a[9550872]=v|24}if((t&6)==0){v=t|6;a[9550873]=v;w=v}else{w=t}if((w&24)==0){a[9550873]=w|24}w=c[2439330]|0;if((w|0)!=0){t=w;gGC(9706056,t|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;c[3528554]=0;f43(c[2433592]|0);c[2113158]=c[9731360+(c[3528554]<<2)>>2];t=0;w=0;v=0;do{v=v+1|0;j=f45((v*4166|0)-w|0)|0;c[2113158]=(c[2113158]|0)+j;w=j+w|0;j=(v*7457|0)-t|0;do{if((j|0)<1){x=0}else{if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){l=gfc(j)|0;c[2433530]=(c[2433530]|0)+l;x=l;break}else{c[2433530]=(c[2433530]|0)+j;x=j;break}}}while(0);t=x+t|0;if((a[c[3528480]|0]|0)!=0){if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12}}while((v|0)<8);if((c[3541228]|0)!=0){f44(0);f45(0)|0;a[9660786]=0;f45(0)|0}v=c[2112964]|0;if((v|0)!=0){t=a[9688]|0;gGz(v|0,0,(t?2136:0)|0);x=t?534:0;TH(0,v,x);TH(1,v,x)}x=c[3528554]|0;v=(c[2433592]|0)+(x*3148|0)|0;if((v|0)!=0){t=v;gGC(t|0,9660752,48)|0}c[9731360+(x<<2)>>2]=c[2113158];c[3528554]=-1;x=c[1836236]|0;t=c[9757320+(x<<2)>>2]|0;if((t|0)!=0){v=t;gGC(v|0,9706056,76)|0}c[9752472+(x<<2)>>2]=c[2433530];c[14113936+(x<<2)>>2]=c[2076596];c[9669104+(x<<2)>>2]=c[3541536];c[1836236]=-1;if((c[2112968]|0)==0){return 0}bl7()|0;return 0}function bl7(){var d=0,e=0,f=0,g=0;if((a[9547912]|0)!=0){d=c[3530162]|0;e=c[2387262]|0;f=0;do{g=ga(b[e+(f<<1)>>1]|0)|0;c[d+(f<<2)>>2]=((g&65535)>>>10<<3&65535)>>>3&31|((g&255)<<3&255)<<8|(((g&65535)>>>5<<3&255|(g&65535)>>>7&4)&255)<<3&2016;f=f+1|0;}while((f|0)<1024)}bpj();f=c[2112926]|0;gGz(f|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);bpl(c[2439858]|0,1);bi3(0);bpl(c[2439858]|0,0);bpk(2,0,c[2439894]|0);bpl(c[2439858]|0,2);bpl(c[2439858]|0,3);bpk(1,0,c[2439894]|0);R8(c[3530162]|0);return 0}function bl8(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;f=i;i=i+192|0;g=f|0;h=f+16|0;j=f+48|0;k=f+64|0;l=f+80|0;m=f+96|0;n=f+112|0;o=f+128|0;p=f+144|0;q=f+160|0;r=f+176|0;s=(e|0)==0;if(!s){c[e>>2]=169733}if((b&96|0)!=0){gGz(r|0,0,12);t=c[2414784]|0;c[r>>2]=t;c[r+4>>2]=(c[2411844]|0)-t;c[r+12>>2]=162152;t=c[2076592]|0;gj[t&4095](r)|0;r=n|0;t=(b&64|0)==0;if((c[2113160]|0)>0&(t^1)){u=n+7|0;n=m|0;v=m+4|0;w=m+12|0;x=l;y=l|0;z=l+4|0;A=l+12|0;B=k;C=k|0;D=k+4|0;E=k+12|0;F=j;G=j|0;H=j+4|0;I=j+12|0;J=0;do{K=c[2433592]|0;L=K+(J*3148|0)+40|0;M=c[L>>2]|0;gGC(r|0,614752,9)|0;a[u]=J+48&255;c[n>>2]=K+(J*3148|0);c[v>>2]=48;c[w>>2]=r;gj[c[2076592]&4095](m)|0;gGz(x|0,0,12);c[y>>2]=K+(J*3148|0)+3136;c[z>>2]=4;c[A>>2]=165288;gj[c[2076592]&4095](l)|0;gGz(B|0,0,12);c[C>>2]=K+(J*3148|0)+3140;c[D>>2]=4;c[E>>2]=501592;gj[c[2076592]&4095](k)|0;gGz(F|0,0,12);c[G>>2]=K+(J*3148|0)+3144;c[H>>2]=4;c[I>>2]=386080;gj[c[2076592]&4095](j)|0;c[L>>2]=M;J=J+1|0;}while((J|0)<(c[2113160]|0))}fw$(b);J=h|0;if(!t){if(!s){c[e>>2]=169619}cC(J|0,170224,(e=i,i=i+8|0,c[e>>2]=0,e)|0)|0;i=e;c[g>>2]=9699512;c[g+4>>2]=64;c[g+8>>2]=0;c[g+12>>2]=J;J=c[2076592]|0;gj[J&4095](g)|0}blJ(b);gGz(q|0,0,12);c[q>>2]=9717760;c[q+4>>2]=4;c[q+12>>2]=210928;g=c[2076592]|0;gj[g&4095](q)|0;gGz(p|0,0,12);c[p>>2]=9760160;c[p+4>>2]=4;c[p+12>>2]=206016;q=c[2076592]|0;gj[q&4095](p)|0;gGz(o|0,0,12);c[o>>2]=9733672;c[o+4>>2]=4;c[o+12>>2]=199616;p=c[2076592]|0;gj[p&4095](o)|0}if((b&2|0)==0){i=f;return 0}c[3528554]=0;f43(c[2433592]|0);b=c[3528554]|0;o=9731360+(b<<2)|0;p=c[o>>2]|0;c[2113158]=p;q=c[3527396]|0;g=c[2433592]|0;J=((d[c[2394762]|0]|0)<<12&122880)+40960|0;e=96;s=96;while(1){t=q+(J+(s<<8))|0;c[g+(b*3148|0)+48+(s<<2)>>2]=t;c[g+(b*3148|0)+48+(s+512<<2)>>2]=t;t=e+1&65535;if((t&65535)>127){break}else{e=t;s=t&65535}}s=g+(b*3148|0)|0;if((s|0)!=0){b=s;gGC(b|0,9660752,48)|0}c[o>>2]=p;c[3528554]=-1;i=f;return 0}function bl9(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>37){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3053172+(b*112|0)>>2];c[a+104>>2]=c[3053176+(b*112|0)>>2];c[a+108>>2]=c[3053180+(b*112|0)>>2];d=0;return d|0}function bma(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<38&(d|0)==0)){e=1;return e|0}c[a>>2]=3053072+(b*112|0);e=0;return e|0}function bmb(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>37){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2546956+(b*112|0)>>2];c[a+104>>2]=c[2546960+(b*112|0)>>2];c[a+108>>2]=c[2546964+(b*112|0)>>2];d=0;return d|0}function bmc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<38&(d|0)==0)){e=1;return e|0}c[a>>2]=2546856+(b*112|0);e=0;return e|0}function bmd(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>60){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3681344+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function bme(b){b=b|0;a[9681232]=((b>>4)*17|0)&255;a[9681233]=0;c[2424878]=9681232;a[9681234]=0;a[9681235]=((b&15)*17|0)&255;return}function bmf(b){b=b|0;a[9681296]=((b>>4)*17|0)&255;a[9681297]=0;c[2424878]=9681296;a[9681298]=0;a[9681299]=((b&15)*17|0)&255;return}function bmg(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;c[d>>2]=c[e>>2]<<8&16128|c[d>>2];c[e>>2]=(c[e>>2]|0)>>>6&3|a<<3&16;return}function bmh(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;c[d>>2]=(c[b>>2]|0)>>>4&3;c[b>>2]=c[b>>2]&15|32;c[a>>2]=c[a>>2]&8191;return}function bmi(a,b,d){a=a|0;b=b|0;d=d|0;c[d>>2]=(c[b>>2]|0)>>>6&1;c[a>>2]=c[b>>2]<<8&768|c[a>>2];c[b>>2]=(c[b>>2]|0)>>>2&15|48;return}function bmj(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;if((b|0)==1835033){e=d&255;f=e>>>1&1;do{if((f|0)!=(c[2417274]|0)){c[2417274]=f;if((c[3529076]|0)==0){break}else{g=0}do{bi2(g,0);g=g+1|0;}while((g|0)<1024)}}while(0);g=e>>>3&1;do{if((g|0)!=(c[2417272]|0)){c[2417272]=g;if((c[3529077]|0)==0){break}else{h=0}do{bi2(h,1);h=h+1|0;}while((h|0)<1024)}}while(0);h=e>>>5&1;do{if((h|0)!=(c[2417270]|0)){c[2417270]=h;if((c[3529078]|0)==0){break}else{i=0}do{bi2(i,2);i=i+1|0;}while((i|0)<1024)}}while(0);a[14108544]=d&1;a[14108545]=d&4;a[14108546]=d&16;return}else if((b|0)==1835041){if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12;return}else if((b|0)==1835049){a[c[3528350]|0]=d;return}else if((b|0)==1835057){return}else{i=b&16773121;if((i|0)==2113537){h=b>>>1;a[(c[3529076]|0)+(h&2047)|0]=d;bi2(h&1023,0);return}else if((i|0)==2117633){h=b>>>1;a[(c[3529077]|0)+(h&2047)|0]=d;bi2(h&1023,1);return}else if((i|0)==2121729){i=b>>>1;a[(c[3529078]|0)+(i&2047)|0]=d;bi2(i&1023,2);return}else{i=b&16777185;if((i|0)==2129793){a[14108592+(b>>>1&15)|0]=d;return}else if((i|0)==2129825){a[14108608+(b>>>1&15)|0]=d;return}else if((i|0)==2129857){a[14108624+(b>>>1&15)|0]=d;return}else{if((b&16777201|0)!=3162113){if((b&16775169|0)!=3164161){return}a[(c[3529066]|0)+(b>>>1&1023)|0]=d;return}i=b>>>1&7;if((i|0)==0){b=d&255;c[3541236]=b&1;c[3541234]=b&4;c[3541232]=b&8;c[3541238]=b&32;return}b=i-2|0;if(b>>>0>=3){return}a[9718032+b|0]=d;return}}}}function bmk(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;i=i+32|0;f=e|0;g=e+8|0;h=e+16|0;j=e+24|0;switch(b|0){case 1835017:{k=a[9635609]|0;i=e;return k|0};case 1835011:{k=a[9550865]|0;i=e;return k|0};case 1835009:{k=a[9550864]|0;i=e;return k|0};case 1835013:{k=a[9550866]|0;i=e;return k|0};case 1835015:{k=a[9635608]|0;i=e;return k|0};default:{l=b&16773120;if((l|0)==2113536){k=a[(c[3529076]|0)+(b>>>1&2047)|0]|0;i=e;return k|0}else if((l|0)==2117632){k=a[(c[3529077]|0)+(b>>>1&2047)|0]|0;i=e;return k|0}else if((l|0)==2121728){k=a[(c[3529078]|0)+(b>>>1&2047)|0]|0;i=e;return k|0}else{if((b&16777200|0)==3162112){k=bpm(b>>>1&7)|0;i=e;return k|0}if((b&16775168|0)!=3164160){k=0;i=e;return k|0}if((c[3541238]|0)!=0){l=b>>>3&255;c[2433420]=l;m=d[9718033]|0;c[f>>2]=((d[9718032]|0)<<8|l|m<<16)>>>5&8191;l=(d[9718034]|0)<<6;c[g>>2]=l&192|m>>>2;c[h>>2]=0;c[j>>2]=l&128;gL[c[2437694]&255](f,g,h,j)}k=a[(c[3529066]|0)+(b>>>1&1023)|0]|0;i=e;return k|0}}}return 0}function bml(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((e|0)==57344){Uv(0,d);return}else if((e|0)==61441){b=c[2113304]|0;a[14168504+b|0]=d;mv(0,b,d&255);return}else if((e|0)==61440){c[2113304]=d&255;return}else{return}}function bmm(b){b=b|0;var d=0,e=0;d=b&65535;if((d|0)==49152){e=a[c[3528350]|0]|0}else if((d|0)==57344){e=c[2113156]&255}else if((d|0)==61440|(d|0)==61441){e=c[(c[3531464]|0)+4240>>2]&255}else{e=0}return e|0}function bmn(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2105468+(b*112|0)>>2];c[a+104>>2]=c[2105472+(b*112|0)>>2];c[a+108>>2]=c[2105476+(b*112|0)>>2];d=0;return d|0}function bmo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=2105368+(b*112|0);e=0;return e|0}function bmp(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1176760+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function bmq(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>49){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3273400+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function bmr(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0;e=i;i=i+1920|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;B=e+1200|0;C=e+1312|0;D=e+1320|0;E=e+1432|0;F=e+1440|0;G=e+1552|0;H=e+1560|0;I=e+1672|0;J=e+1680|0;K=e+1792|0;L=e+1800|0;M=e+1912|0;c[2415074]=0;c[2388188]=0;c[2385984]=262144;c[3530924]=327680;c[3530688]=1376256;c[3530480]=1900544;c[3530360]=2424832;c[2439892]=2949120;c[2439856]=5046272;c[2439842]=6094848;c[2439840]=7143424;c[3541206]=8192e3;c[2386684]=8192e3;c[3530160]=8454144;c[2414782]=8486912;c[2388306]=8486912;c[2387260]=8552448;c[2386136]=8568832;c[3528350]=8585216;c[2411842]=8585217;N=0;while(1){if((N|0)>=1024){break}O=9638528+(N<<2)|0;if((c[O>>2]|0)==0){P=147;break}else{N=N+1|0}}do{if((P|0)==147){N=gGq(8585217)|0;c[O>>2]=N;if((N|0)==0){break}c[2415074]=N;gGz(N|0,0,8585217);c[2388188]=N;c[2385984]=N+262144;c[3530924]=N+327680;c[3530688]=N+1376256;c[3530480]=N+1900544;c[3530360]=N+2424832;c[2439892]=N+2949120;c[2439856]=N+5046272;c[2439842]=N+6094848;c[2439840]=N+7143424;Q=N+8192e3|0;c[3541206]=Q;c[2386684]=Q;c[3530160]=N+8454144;Q=N+8486912|0;c[2414782]=Q;c[2388306]=Q;c[2387260]=N+8552448;c[2386136]=N+8568832;c[3528350]=N+8585216;Q=N+8585217|0;c[2411842]=Q;c[2414392]=Q;if((R6(N+1|0,0,2)|0)!=0){R=1;i=e;return R|0}if((R6(c[2388188]|0,1,2)|0)!=0){R=1;i=e;return R|0}N=c[2385984]|0;if((c[3542200]|0)==0){R=1;i=e;return R|0}Q=L+108|0;c[Q>>2]=0;S=L+100|0;c[S>>2]=0;T=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[T&16383](L,2)|0;do{if((c[Q>>2]|0)!=0){T=c[S>>2]|0;c[M>>2]=9534384;U=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[U&16383](M,2,0)|0;if((T|0)<1){R=1;i=e;return R|0}if((gzL(N,0,2)|0)==0){break}else{R=1}i=e;return R|0}}while(0);N=c[3530924]|0;if((c[3542200]|0)==0){R=1;i=e;return R|0}S=J+108|0;c[S>>2]=0;Q=J+100|0;c[Q>>2]=0;T=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[T&16383](J,3)|0;do{if((c[S>>2]|0)!=0){T=c[Q>>2]|0;c[K>>2]=9534384;U=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[U&16383](K,3,0)|0;if((T|0)<1){R=1;i=e;return R|0}if((gzL(N,0,3)|0)==0){break}else{R=1}i=e;return R|0}}while(0);N=(c[3530924]|0)+524288|0;if((c[3542200]|0)==0){R=1;i=e;return R|0}Q=H+108|0;c[Q>>2]=0;S=H+100|0;c[S>>2]=0;T=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[T&16383](H,4)|0;do{if((c[Q>>2]|0)!=0){T=c[S>>2]|0;c[I>>2]=9534384;U=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[U&16383](I,4,0)|0;if((T|0)<1){R=1;i=e;return R|0}if((gzL(N,0,4)|0)==0){break}else{R=1}i=e;return R|0}}while(0);N=c[3530688]|0;if((c[3542200]|0)==0){R=1;i=e;return R|0}S=F+108|0;c[S>>2]=0;Q=F+100|0;c[Q>>2]=0;T=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[T&16383](F,5)|0;do{if((c[S>>2]|0)!=0){T=c[Q>>2]|0;c[G>>2]=9534384;U=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[U&16383](G,5,0)|0;if((T|0)<1){R=1;i=e;return R|0}if((gzL(N,0,5)|0)==0){break}else{R=1}i=e;return R|0}}while(0);N=(c[3530688]|0)+131072|0;if((c[3542200]|0)==0){R=1;i=e;return R|0}Q=D+108|0;c[Q>>2]=0;S=D+100|0;c[S>>2]=0;T=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[T&16383](D,6)|0;do{if((c[Q>>2]|0)!=0){T=c[S>>2]|0;c[E>>2]=9534384;U=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[U&16383](E,6,0)|0;if((T|0)<1){R=1;i=e;return R|0}if((gzL(N,0,6)|0)==0){break}else{R=1}i=e;return R|0}}while(0);N=(c[3530688]|0)+262144|0;if((c[3542200]|0)==0){R=1;i=e;return R|0}S=B+108|0;c[S>>2]=0;Q=B+100|0;c[Q>>2]=0;T=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[T&16383](B,7)|0;do{if((c[S>>2]|0)!=0){T=c[Q>>2]|0;c[C>>2]=9534384;U=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[U&16383](C,7,0)|0;if((T|0)<1){R=1;i=e;return R|0}if((gzL(N,0,7)|0)==0){break}else{R=1}i=e;return R|0}}while(0);N=(c[3530688]|0)+393216|0;if((c[3542200]|0)==0){R=1;i=e;return R|0}Q=z+108|0;c[Q>>2]=0;S=z+100|0;c[S>>2]=0;T=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[T&16383](z,8)|0;do{if((c[Q>>2]|0)!=0){T=c[S>>2]|0;c[A>>2]=9534384;U=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[U&16383](A,8,0)|0;if((T|0)<1){R=1;i=e;return R|0}if((gzL(N,0,8)|0)==0){break}else{R=1}i=e;return R|0}}while(0);N=c[3530480]|0;if((c[3542200]|0)==0){R=1;i=e;return R|0}S=x+108|0;c[S>>2]=0;Q=x+100|0;c[Q>>2]=0;T=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[T&16383](x,9)|0;do{if((c[S>>2]|0)!=0){T=c[Q>>2]|0;c[y>>2]=9534384;U=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[U&16383](y,9,0)|0;if((T|0)<1){R=1;i=e;return R|0}if((gzL(N,0,9)|0)==0){break}else{R=1}i=e;return R|0}}while(0);N=(c[3530480]|0)+131072|0;if((c[3542200]|0)==0){R=1;i=e;return R|0}Q=v+108|0;c[Q>>2]=0;S=v+100|0;c[S>>2]=0;T=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[T&16383](v,10)|0;do{if((c[Q>>2]|0)!=0){T=c[S>>2]|0;c[w>>2]=9534384;U=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[U&16383](w,10,0)|0;if((T|0)<1){R=1;i=e;return R|0}if((gzL(N,0,10)|0)==0){break}else{R=1}i=e;return R|0}}while(0);N=(c[3530480]|0)+262144|0;if((c[3542200]|0)==0){R=1;i=e;return R|0}S=t+108|0;c[S>>2]=0;Q=t+100|0;c[Q>>2]=0;T=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[T&16383](t,11)|0;do{if((c[S>>2]|0)!=0){T=c[Q>>2]|0;c[u>>2]=9534384;U=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[U&16383](u,11,0)|0;if((T|0)<1){R=1;i=e;return R|0}if((gzL(N,0,11)|0)==0){break}else{R=1}i=e;return R|0}}while(0);N=(c[3530480]|0)+393216|0;if((c[3542200]|0)==0){R=1;i=e;return R|0}Q=r+108|0;c[Q>>2]=0;S=r+100|0;c[S>>2]=0;T=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[T&16383](r,12)|0;do{if((c[Q>>2]|0)!=0){T=c[S>>2]|0;c[s>>2]=9534384;U=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[U&16383](s,12,0)|0;if((T|0)<1){R=1;i=e;return R|0}if((gzL(N,0,12)|0)==0){break}else{R=1}i=e;return R|0}}while(0);N=c[3530360]|0;if((c[3542200]|0)==0){R=1;i=e;return R|0}S=p+108|0;c[S>>2]=0;Q=p+100|0;c[Q>>2]=0;T=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[T&16383](p,13)|0;do{if((c[S>>2]|0)!=0){T=c[Q>>2]|0;c[q>>2]=9534384;U=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[U&16383](q,13,0)|0;if((T|0)<1){R=1;i=e;return R|0}if((gzL(N,0,13)|0)==0){break}else{R=1}i=e;return R|0}}while(0);N=(c[3530360]|0)+131072|0;if((c[3542200]|0)==0){R=1;i=e;return R|0}Q=n+108|0;c[Q>>2]=0;S=n+100|0;c[S>>2]=0;T=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[T&16383](n,14)|0;do{if((c[Q>>2]|0)!=0){T=c[S>>2]|0;c[o>>2]=9534384;U=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[U&16383](o,14,0)|0;if((T|0)<1){R=1;i=e;return R|0}if((gzL(N,0,14)|0)==0){break}else{R=1}i=e;return R|0}}while(0);N=(c[3530360]|0)+262144|0;if((c[3542200]|0)==0){R=1;i=e;return R|0}S=l+108|0;c[S>>2]=0;Q=l+100|0;c[Q>>2]=0;T=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[T&16383](l,15)|0;do{if((c[S>>2]|0)!=0){T=c[Q>>2]|0;c[m>>2]=9534384;U=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[U&16383](m,15,0)|0;if((T|0)<1){R=1;i=e;return R|0}if((gzL(N,0,15)|0)==0){break}else{R=1}i=e;return R|0}}while(0);N=(c[3530360]|0)+393216|0;if((c[3542200]|0)==0){R=1;i=e;return R|0}Q=j+108|0;c[Q>>2]=0;S=j+100|0;c[S>>2]=0;T=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[T&16383](j,16)|0;do{if((c[Q>>2]|0)!=0){T=c[S>>2]|0;c[k>>2]=9534384;U=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[U&16383](k,16,0)|0;if((T|0)<1){R=1;i=e;return R|0}if((gzL(N,0,16)|0)==0){break}else{R=1}i=e;return R|0}}while(0);N=c[2386684]|0;if((c[3542200]|0)==0){R=1;i=e;return R|0}S=f+108|0;c[S>>2]=0;Q=f+100|0;c[Q>>2]=0;T=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[T&16383](f,17)|0;do{if((c[S>>2]|0)!=0){T=c[Q>>2]|0;c[g>>2]=9534384;U=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[U&16383](g,17,0)|0;if((T|0)<1){R=1;i=e;return R|0}if((gzL(N,0,17)|0)==0){break}else{R=1}i=e;return R|0}}while(0);N=c[3530924]|0;blG(N,524288);Q=c[2439892]|0;S=0;do{T=S<<8;gGz(Q+T|0,0,256);U=S<<10;V=0;do{W=1<<3-V;X=(c[611400+(V<<2)>>2]|0)+U|0;Y=0;do{Z=X+(c[3946808+(Y<<2)>>2]|0)|0;_=(Y<<4)+T|0;$=0;do{aa=Z+(c[6669416+($<<2)>>2]|0)|0;if(((d[N+((aa|0)/8|0)|0]|0)&128>>>((aa&7)>>>0)|0)!=0){aa=Q+(_+$)|0;a[aa]=(d[aa]|0|W)&255}$=$+1|0;}while(($|0)<16);Y=Y+1|0;}while((Y|0)<16);V=V+1|0;}while((V|0)<4);S=S+1|0;}while((S|0)<8192);S=c[3530688]|0;Q=c[2439856]|0;N=0;do{V=N<<8;gGz(Q+V|0,0,256);T=N<<10;U=0;do{Y=1<<3-U;W=(c[703416+(U<<2)>>2]|0)+T|0;X=0;do{$=W+(c[611904+(X<<2)>>2]|0)|0;_=(X<<4)+V|0;Z=0;do{aa=$+(c[4969688+(Z<<2)>>2]|0)|0;if(((d[S+((aa|0)/8|0)|0]|0)&128>>>((aa&7)>>>0)|0)!=0){aa=Q+(_+Z)|0;a[aa]=(d[aa]|0|Y)&255}Z=Z+1|0;}while((Z|0)<16);X=X+1|0;}while((X|0)<16);U=U+1|0;}while((U|0)<4);N=N+1|0;}while((N|0)<4096);N=c[3530480]|0;Q=c[2439842]|0;S=0;do{U=S<<8;gGz(Q+U|0,0,256);V=S<<10;T=0;do{X=1<<3-T;Y=(c[703416+(T<<2)>>2]|0)+V|0;W=0;do{Z=Y+(c[611904+(W<<2)>>2]|0)|0;_=(W<<4)+U|0;$=0;do{aa=Z+(c[4969688+($<<2)>>2]|0)|0;if(((d[N+((aa|0)/8|0)|0]|0)&128>>>((aa&7)>>>0)|0)!=0){aa=Q+(_+$)|0;a[aa]=(d[aa]|0|X)&255}$=$+1|0;}while(($|0)<16);W=W+1|0;}while((W|0)<16);T=T+1|0;}while((T|0)<4);S=S+1|0;}while((S|0)<4096);S=c[3530360]|0;Q=c[2439840]|0;N=0;do{T=N<<8;gGz(Q+T|0,0,256);U=N<<10;V=0;do{W=1<<3-V;X=(c[703416+(V<<2)>>2]|0)+U|0;Y=0;do{$=X+(c[611904+(Y<<2)>>2]|0)|0;_=(Y<<4)+T|0;Z=0;do{aa=$+(c[4969688+(Z<<2)>>2]|0)|0;if(((d[S+((aa|0)/8|0)|0]|0)&128>>>((aa&7)>>>0)|0)!=0){aa=Q+(_+Z)|0;a[aa]=(d[aa]|0|W)&255}Z=Z+1|0;}while((Z|0)<16);Y=Y+1|0;}while((Y|0)<16);V=V+1|0;}while((V|0)<4);N=N+1|0;}while((N|0)<4096);fxU(0,425984);if((c[2394]|0)==0){ab=c[2112932]|0}else{c[2394]=0;N=c[3532596]|0;c[2112932]=N;Q=c[3532592]|0;if((Q|0)!=0){gGC(9104152,Q|0,280)|0}c[2113054]=c[2113060];ab=N}N=c[2388188]|0;Q=ab|0;S=0;while(1){V=N+S|0;c[Q>>2]=V;c[Q+131072>>2]=V;V=S+1024|0;if(V>>>0>262143){break}else{Q=Q+4|0;S=V}}S=c[2388306]|0;Q=ab+2048|0;N=524288;while(1){V=S+(N-524288)|0;c[Q>>2]=V;c[Q+65536>>2]=V;c[Q+131072>>2]=V;V=N+1024|0;if(V>>>0>589823){break}else{Q=Q+4|0;N=V}}N=c[2387260]|0;c[ab+6144>>2]=N;c[ab+71680>>2]=N;c[ab+137216>>2]=N;Q=N+1024|0;c[ab+6148>>2]=Q;c[ab+71684>>2]=Q;c[ab+137220>>2]=Q;Q=N+2048|0;c[ab+6152>>2]=Q;c[ab+71688>>2]=Q;c[ab+137224>>2]=Q;Q=N+3072|0;c[ab+6156>>2]=Q;c[ab+71692>>2]=Q;c[ab+137228>>2]=Q;Q=N+4096|0;c[ab+6160>>2]=Q;c[ab+71696>>2]=Q;c[ab+137232>>2]=Q;Q=N+5120|0;c[ab+6164>>2]=Q;c[ab+71700>>2]=Q;c[ab+137236>>2]=Q;Q=N+6144|0;c[ab+6168>>2]=Q;c[ab+71704>>2]=Q;c[ab+137240>>2]=Q;Q=N+7168|0;c[ab+6172>>2]=Q;c[ab+71708>>2]=Q;c[ab+137244>>2]=Q;Q=N+8192|0;c[ab+6176>>2]=Q;c[ab+71712>>2]=Q;c[ab+137248>>2]=Q;Q=N+9216|0;c[ab+6180>>2]=Q;c[ab+71716>>2]=Q;c[ab+137252>>2]=Q;Q=N+10240|0;c[ab+6184>>2]=Q;c[ab+71720>>2]=Q;c[ab+137256>>2]=Q;Q=N+11264|0;c[ab+6188>>2]=Q;c[ab+71724>>2]=Q;c[ab+137260>>2]=Q;Q=N+12288|0;c[ab+6192>>2]=Q;c[ab+71728>>2]=Q;c[ab+137264>>2]=Q;Q=N+13312|0;c[ab+6196>>2]=Q;c[ab+71732>>2]=Q;c[ab+137268>>2]=Q;Q=N+14336|0;c[ab+6200>>2]=Q;c[ab+71736>>2]=Q;c[ab+137272>>2]=Q;Q=N+15360|0;c[ab+6204>>2]=Q;c[ab+71740>>2]=Q;c[ab+137276>>2]=Q;c[ab+196648>>2]=3134;c[ab+196608>>2]=692;Q=c[3532592]|0;if((Q|0)!=0){gGC(Q|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);Q=c[2439330]|0;N=(Q|0)==0;if(!N){S=Q;gGC(9706056,S|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];S=c[3528484]|0;c[2076596]=S;V=c[2417276]|0;c[3541536]=V;c[1836236]=0;T=c[2385984]|0;U=0;Y=0;while(1){c[Q+76+(Y<<2)>>2]=T+(Y<<8);W=U+1&65535;if((W&65535)>127){ac=0;ad=0;break}else{U=W;Y=W&65535}}while(1){Y=T+(ad<<8)|0;c[Q+76+(ad+512<<2)>>2]=Y;c[Q+76+(ad+768<<2)>>2]=Y;Y=ac+1&65535;if((Y&65535)>127){break}else{ac=Y;ad=Y&65535}}T=c[2386136]|0;Y=128;U=128;while(1){c[Q+76+(U<<2)>>2]=T+((U<<8)-32768);W=Y+1&65535;if((W&65535)>191){ae=128;af=128;break}else{Y=W;U=W&65535}}while(1){c[Q+76+(af+256<<2)>>2]=T+((af<<8)-32768);U=ae+1&65535;if((U&65535)>191){ah=128;ai=128;break}else{ae=U;af=U&65535}}while(1){U=T+((ai<<8)-32768)|0;c[Q+76+(ai+512<<2)>>2]=U;c[Q+76+(ai+768<<2)>>2]=U;U=ah+1&65535;if((U&65535)>191){break}else{ah=U;ai=U&65535}}c[Q+4184>>2]=1464;c[Q+4180>>2]=3074;if(!N){T=Q;gGC(T|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=S;c[2417276]=V;c[1836236]=-1;T=c[3530924]|0;c[2438136]=0;U=0;while(1){if((U|0)>=1024){aj=0;break}ak=9638528+(U<<2)|0;if((c[ak>>2]|0)==0){P=280;break}else{U=U+1|0}}do{if((P|0)==280){U=gGq(1024)|0;c[ak>>2]=U;if((U|0)==0){aj=0;break}gGz(U|0,0,1024);aj=U}}while(0);c[3529066]=aj;c[2438702]=1048575;c[3529064]=T;a[7461792]=1;c[2437694]=96;c[2438136]=9;bi1(0,c[3530688]|0,c[2439856]|0,524287,110);c[3527138]=-105;c[3527139]=-16;bi1(1,c[3530480]|0,c[2439842]|0,524287,108);c[3527140]=-105;c[3527141]=-16;bi1(2,c[3530360]|0,c[2439840]|0,524287,46);c[3527142]=-105;c[3527143]=-16;U=a[9680]|0;V=U?32e3:0;if(U){if(a[9624]|0){U=V*3|0;S=62500;while(1){if((S|0)>(U|0)){S=S>>1}else{al=1222;am=S;break}}}else{al=2462;am=V}c[2429380]=am;c[3542124]=al;mw(4e6,am);S=gGq(262144)|0;c[2406684]=S;gGz(S|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(4e6,11025)}h[745421]=1.0;c[2436794]=1;h[745420]=1.0;c[2436792]=2;Ux(0,8e3,1);c[2407030]=128;c[2407068]=3;S=c[642608+(c[2436]<<2)>>2]|0;U=c[S+128>>2]|0;if((c[S+52>>2]&4|0)==0){c[2113068]=U;T=c[S+132>>2]|0;c[2113070]=T;c[2443814]=U;c[2440436]=T;an=U;ao=T}else{c[2113070]=U;T=c[S+132>>2]|0;c[2113068]=T;c[2440436]=U;c[2443814]=T;an=T;ao=U}U=ag(an<<1,ao)|0;T=gGq(U)|0;c[2112926]=T;if((T|0)!=0){gGz(T|0,0,U|0)}a[9624912]=0;U=c[2414782]|0;gGz(U|0,0,(c[2411842]|0)-U|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];U=c[3532592]|0;if((U|0)!=0){gGC(9104152,U|0,280)|0}c[2113054]=c[2113060]}RI();U=c[2394]|0;T=c[14130368+(U<<2)>>2]|0;if((T|0)!=0){gGC(T|0,9104152,280)|0}c[8452240+(U<<2)>>2]=c[2113054];c[2394]=-1;U=c[2439330]|0;T=(U|0)==0;if(!T){S=U;gGC(9706056,S|0,76)|0}S=c[2438118]|0;c[2433530]=S;Q=c[3528484]|0;c[2076596]=Q;N=c[2417276]|0;c[3541536]=N;c[1836236]=0;gGz(9706056,0,76);if(!T){T=U;gGC(T|0,9706056,76)|0}c[2438118]=S;c[3528484]=Q;c[2417276]=N;c[1836236]=-1;mx(0);c[2113156]=0;a[9628264]=0;c[2407033]=0;N=c[3541206]|0;c[3541190]=N;c[3541198]=N;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=N+256;c[3541199]=N+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=N+512;c[3541200]=N+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=N+768;c[3541201]=N+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;blH();c[2417270]=0;c[2417272]=0;c[2417274]=0;R=0;i=e;return R|0}}while(0);c[2415074]=0;R=1;i=e;return R|0}function bms(){var a=0,b=0,d=0,e=0,f=0;c[2113070]=0;c[2113068]=0;a=c[2112926]|0;if((a|0)!=0){gGr(a);c[2112926]=0}blI();if((c[2392]|0)>=0){a=0;do{b=14130368+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}b=14130384+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}a=a+1|0;}while((a|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;fwZ();a=c[3531464]|0;c[a+44344>>2]=0;c[a+44348>>2]=0;if((a|0)!=0){gGr(a);c[3531464]=0}a=c[2406684]|0;if((a|0)!=0){gGr(a);c[2406684]=0}Uw(0);a=c[2415074]|0;b=0;while(1){if((b|0)>=1024){e=374;break}f=9638528+(b<<2)|0;if((c[f>>2]|0)==(a|0)){break}else{b=b+1|0}}if((e|0)==374){c[2415074]=0;return 0}gGr(a);c[f>>2]=0;c[2415074]=0;return 0}function bmt(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if((a[9624912]|0)!=0){a[9624912]=0;d=c[2414782]|0;gGz(d|0,0,(c[2411842]|0)-d|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;h=c[2417276]|0;c[3541536]=h;c[1836236]=0;gGz(9706056,0,76);if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=h;c[1836236]=-1;mx(0);c[2113156]=0;a[9628264]=0;c[2407033]=0;h=c[3541206]|0;c[3541190]=h;c[3541198]=h;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=h+256;c[3541199]=h+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=h+512;c[3541200]=h+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=h+768;c[3541201]=h+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;blH();c[2417270]=0;c[2417272]=0;c[2417274]=0}h=c[2392]|0;if((h|0)>=0){gGz(8452240,0,((h|0)>0?(h<<2)+4|0:4)|0)}c[2113054]=0;h=c[2385548]|0;if((h|0)>0){gGz(9752472,0,((h|0)>1?h<<2:4)|0)}c[2433530]=0;gGz(9550864,-1|0,3);h=0;g=-1;f=-1;e=-1;do{g=((a[9634256+h|0]&1)<<h^g&255)&255;f=((a[9632016+h|0]&1)<<h^f&255)&255;e=((a[9629936+h|0]&1)<<h^e&255)&255;h=h+1|0;}while((h|0)<8);a[9550864]=g;a[9550865]=f;a[9550866]=e;if((f&24)==0){g=f|24;a[9550865]=g;i=g}else{i=f}if((i&6)==0){a[9550865]=i|6}if((e&24)==0){i=e|24;a[9550866]=i;j=i}else{j=e}if((j&6)==0){a[9550866]=j|6}if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];j=c[3532592]|0;if((j|0)!=0){gGC(9104152,j|0,280)|0}c[2113054]=c[2113060]}j=c[2439330]|0;if((j|0)!=0){e=j;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;e=0;j=0;while(1){c[2113056]=2e3;i=RG(2e3)|0;c[2113054]=(c[2113054]|0)+i;c[2276108]=-1;c[2113056]=-1;if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){i=gfc(666)|0;k=(c[2433530]|0)+i|0}else{k=(c[2433530]|0)+666|0}c[2433530]=k;i=c[2112964]|0;if((i|0)==0){l=j}else{f=a[9688]|0?5:0;g=i+(j<<1<<1)|0;gg[c[3542124]&4095](g,f);Uu(0,g,f);l=f+j|0}f=e+1|0;if((f|0)<100){e=f;j=l}else{break}}c[8452200+(c[2394]<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0<1024){RH(4)}j=c[2112964]|0;do{if((j|0)!=0){e=a[9688]|0?534:0;k=e-l|0;if((e|0)==(l|0)){break}e=j+(l<<1<<1)|0;gg[c[3542124]&4095](e,k);Uu(0,e,k)}}while(0);l=c[1836236]|0;j=c[9757320+(l<<2)>>2]|0;if((j|0)!=0){k=j;gGC(k|0,9706056,76)|0}c[9752472+(l<<2)>>2]=c[2433530];c[14113936+(l<<2)>>2]=c[2076596];c[9669104+(l<<2)>>2]=c[3541536];c[1836236]=-1;l=c[2394]|0;k=c[14130368+(l<<2)>>2]|0;if((k|0)!=0){gGC(k|0,9104152,280)|0}c[8452240+(l<<2)>>2]=c[2113054];c[2394]=-1;if((c[2112968]|0)==0){return 0}bmu()|0;return 0}function bmu(){var d=0,e=0,f=0,g=0;if((a[9547904]|0)!=0){d=c[2387260]|0;e=c[3530160]|0;f=0;do{g=b[d+(f<<1)>>1]|0;c[e+(f<<2)>>2]=((g&65535)>>>10<<3&248)<<8|((g&255)<<3&255)>>>3|(((g&65535)>>>5<<3&255|(g&65535)>>>7&4)&255)<<3&2016;f=f+1|0;}while((f|0)<8192)}f=c[2112926]|0;gGz(f|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);bi3(2);bi3(1);bpl(c[2439892]|0,0);bi3(0);bpl(c[2439892]|0,1);R8(c[3530160]|0);return 0}function bmv(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;f=i;i=i+144|0;g=f|0;h=f+16|0;j=f+32|0;k=f+48|0;l=f+64|0;m=f+80|0;n=f+96|0;o=f+112|0;p=f+128|0;if((e|0)!=0){c[e>>2]=169733}if((b&96|0)==0){i=f;return 0}gGz(p|0,0,12);e=c[2414782]|0;c[p>>2]=e;c[p+4>>2]=(c[2411842]|0)-e;c[p+12>>2]=162152;gj[c[2076592]&4095](p)|0;p=l|0;do{if((b&64|0)==0){fw$(b)}else{gGz(k|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){e=l+9|0;q=j;r=j|0;s=j+4|0;t=j+12|0;u=k|0;v=k+4|0;w=k+12|0;x=0;do{gGC(p|0,614896,11)|0;a[e]=x+48&255;y=8452256+(x<<2)|0;gGz(q|0,0,12);c[r>>2]=y;c[s>>2]=4;c[t>>2]=164976;gj[c[2076592]&4095](j)|0;if((c[y>>2]|0)!=0){c[u>>2]=c[14130368+(x<<2)>>2];c[v>>2]=c[8452184+(x<<2)>>2];c[w>>2]=p;y=c[2076592]|0;gj[y&4095](k)|0}x=x+1|0;}while((x|0)<=(c[2392]|0))}fw$(b);gGz(h|0,0,12);c[h>>2]=8453216;c[h+4>>2]=4;c[h+12>>2]=107480;x=c[2076592]|0;gj[x&4095](h)|0;gGz(g|0,0,12);c[g>>2]=14168504;c[g+4>>2]=256;c[g+12>>2]=476464;x=c[2076592]|0;gj[x&4095](g)|0;if((b&2|0)==0){break}else{z=0}do{mv(0,z,d[14168504+z|0]|0);z=z+1|0;}while((z|0)<256)}}while(0);Ut(0);blJ(b);gGz(o|0,0,12);c[o>>2]=9669096;c[o+4>>2]=4;c[o+12>>2]=128976;gj[c[2076592]&4095](o)|0;gGz(n|0,0,12);c[n>>2]=9669088;c[n+4>>2]=4;c[n+12>>2]=104576;gj[c[2076592]&4095](n)|0;gGz(m|0,0,12);c[m>>2]=9669080;c[m+4>>2]=4;c[m+12>>2]=80656;gj[c[2076592]&4095](m)|0;i=f;return 0}function bmw(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;c[d>>2]=(c[b>>2]|0)>>>7&1;c[b>>2]=(c[b>>2]|0)>>>1&63|192;c[e>>2]=0;return}function bmx(a,b,d){a=a|0;b=b|0;d=d|0;c[a>>2]=c[b>>2]<<8&1792|c[2417274]<<11|c[a>>2];c[b>>2]=(c[b>>2]|0)>>>3&31;return}function bmy(a,b,d){a=a|0;b=b|0;d=d|0;c[a>>2]=c[b>>2]<<8&1792|c[2417272]<<11|c[a>>2];c[b>>2]=(c[b>>2]|0)>>>3&31|64;return}function bmz(a,b,d){a=a|0;b=b|0;d=d|0;c[a>>2]=c[b>>2]<<8&1792|c[2417270]<<11|c[a>>2];c[b>>2]=(c[b>>2]|0)>>>3&31|128;return}function bmA(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=b&65535;switch(f|0){case 16320:{c[3541230]=e&8;return};case 16324:{a[(c[2443940]|0)+1|0]=e;return};case 16332:case 16333:{TO(f&1,e);return};case 16328:{a[14125144]=-1;a[9706117]=1;return};default:{g=f&63488;if((g|0)==0){h=d[(c[2443940]|0)+1|0]|0;if((h&1|0)==0){a[(c[3531082]|0)+f|0]=e;return}else{a[(c[2387258]|0)+((h<<9&2048)+f)|0]=e;return}}h=f&65520;if((h|0)==16304){i=f&15;j=e&255;k=j&63;a[14116144+i|0]=k&255;if((i|0)==10){c[2437685]=j<<4&112;c[2437686]=k>>>3<<4;return}else if((i|0)==9){c[2437682]=j<<5&96;c[2437683]=j>>>2<<5&96;c[2437684]=k>>>4<<5;return}else{return}}else if((h|0)==16288){h=f&15;a[14108504+h|0]=e;if((h|0)!=6){return}h=c[3529058]|0;k=c[3529054]|0;gGC(h|0,k|0,2048)|0;return}else{do{if((g|0)==8192){if((a[(c[2443940]|0)+1|0]&2)==0){break}a[(c[3529054]|0)+(f&2047^1)|0]=e;return}}while(0);if((b-8192&65535)>=16384){return}b=f-8192|0;if(b>>>0>24575){return}a[(c[3529062]|0)+b|0]=e;if(b>>>0>16383){c[2429638]=1}if((b&6144)>>>0<=6143){return}if((f|0)==15872|(f|0)==24064){a[9730680]=e;return}else if((f|0)==15488){a[9729904]=e;return}else if((f|0)==16128){a[9720738]=e&15;a[9720739]=(e&255)>>>4;return}else if((f|0)==16e3){c[2432672]=(e&255)>>>1&3;return}else if((f|0)==15616){c[3541228]=e&4;return}else if((f|0)==15744){a[9720736]=e&15;a[9720737]=(e&255)>>>4;return}else{return}}}}}function bmB(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;e=i;i=i+24|0;f=e|0;g=e+8|0;h=e+16|0;j=b&65535;switch(j|0){case 16268:{k=a[9550856]|0;i=e;return k|0};case 16269:{k=a[9550857]|0;i=e;return k|0};case 16270:{k=a[9550858]&15|a[9635602]&-16;i=e;return k|0};case 16271:{k=a[9635600]|0;i=e;return k|0};case 16272:{k=a[9635601]|0;i=e;return k|0};case 16332:case 16333:{c[2426862]=9674384;k=c[9674388+((j&1|2)<<2)>>2]&255;i=e;return k|0};case 16320:{k=0;i=e;return k|0};default:{l=j&63488;if((l|0)==0){m=d[(c[2443940]|0)+1|0]|0;if((m&1|0)==0){k=a[(c[3531082]|0)+j|0]|0;i=e;return k|0}else{k=a[(c[2387258]|0)+((m<<9&2048)+j)|0]|0;i=e;return k|0}}if((j&65520|0)==16288){m=j&15;do{if((a[14108509]&16)!=0){if((j&12|0)!=12){break}k=a[(c[3529056]|0)+(((c[3527134]<<19|j&3|(d[14108515]|0)<<18&1835008|(d[14108512]|0)<<10|(d[14108513]|0)<<2)^1)&c[3527124])|0]|0;i=e;return k|0}}while(0);if((m|0)!=6){k=0;i=e;return k|0}m=c[3529058]|0;n=c[3529054]|0;gGC(m|0,n|0,2048)|0;k=0;i=e;return k|0}do{if((l|0)==8192){if((a[(c[2443940]|0)+1|0]&2)==0){break}k=a[(c[3529054]|0)+(j&2047^1)|0]|0;i=e;return k|0}}while(0);if((b-8192&65535)>=16384){k=0;i=e;return k|0}b=j-8192|0;if(b>>>0>24575){k=0;i=e;return k|0}if((c[3541230]|0)==0){k=a[(c[3529062]|0)+b|0]|0;i=e;return k|0}c[f>>2]=0;j=b>>>5&255;c[g>>2]=j;l=d[9730680]|0;c[h>>2]=l;n=l>>>2&3;if((c[2429638]|0)==0){gB[c[2437692]&127](0,((a[9718936+n|0]|a[9720736+n|0])&255)>>>2,g,h,f,f);o=c[g>>2]|0}else{f=l<<8|j;c[g>>2]=f;o=f}k=a[(c[3529060]|0)+((o<<5|b&31)&c[2438700])|0]|0;i=e;return k|0}}return 0}function bmC(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=b&65535;if((e|0)==63488){c[2113304]=d&255;return}else if((e|0)==63489){f=c[2113304]|0;a[14168504+f|0]=d;mv(0,f,d&255);return}else if((e|0)==64e3){if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){f=gfc(100)|0;g=f;h=(c[2433530]|0)+f|0}else{g=100;h=(c[2433530]|0)+100|0}c[2433530]=h;c[2443996]=(c[2443996]|0)+g;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12;return}else{if((b+1024&65535)>=48){return}TO(e&63,d);return}}function bmD(b){b=b|0;var d=0,e=0,f=0,g=0;d=b&65535;if((d|0)==63489){e=c[(c[3531464]|0)+4240>>2]&255;return e|0}else if((d|0)==63488){e=-1;return e|0}else{if((b+1024&65535)>=48){e=0;return e|0}if((d&62|0)==0){a[9706117]=0}b=d&63;c[2426862]=9674384;if((b|0)==46){f=576}else if((b|0)==41){e=(c[2418664]<<1|c[2418653]|c[2418675]<<2|c[2418686]<<3)&255;return e|0}do{if((f|0)==576){if((c[2418596]&1|0)==0){break}d=c[2418655]|0;g=(d>>>16)+(c[2418650]|0)+(c[2418651]<<16)|0;c[2418655]=d+65536;if(g>>>0>(c[2418646]|0)>>>0){e=0;return e|0}e=a[(c[2418645]|0)+g|0]|0;return e|0}}while(0);e=c[9674388+(b<<2)>>2]&255;return e|0}return 0}function bmE(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2466012+(b*112|0)>>2];c[a+104>>2]=c[2466016+(b*112|0)>>2];c[a+108>>2]=c[2466020+(b*112|0)>>2];d=0;return d|0}function bmF(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=2465912+(b*112|0);e=0;return e|0}function bmG(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>23){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1220936+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function bmH(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>59){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3630496+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function bmI(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0;e=i;i=i+960|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;c[2415072]=0;c[2387368]=0;c[2385982]=327680;c[3530922]=393216;c[2439890]=1441792;c[3530686]=3538944;c[2439854]=4587520;c[2386682]=6684672;c[2406996]=7208960;c[3530158]=7217152;c[2414780]=7225344;c[3531082]=7225344;c[2387392]=7227392;c[2387258]=7233536;c[2386134]=7237632;c[2443940]=7239680;c[2411840]=7239682;x=0;while(1){if((x|0)>=1024){break}y=9638528+(x<<2)|0;if((c[y>>2]|0)==0){z=617;break}else{x=x+1|0}}do{if((z|0)==617){x=gGq(7239682)|0;c[y>>2]=x;if((x|0)==0){break}c[2415072]=x;gGz(x|0,0,7239682);c[2387368]=x;c[2385982]=x+327680;c[3530922]=x+393216;c[2439890]=x+1441792;c[3530686]=x+3538944;c[2439854]=x+4587520;c[2386682]=x+6684672;c[2406996]=x+7208960;c[3530158]=x+7217152;A=x+7225344|0;c[2414780]=A;c[3531082]=A;c[2387392]=x+7227392;c[2387258]=x+7233536;c[2386134]=x+7237632;c[2443940]=x+7239680;A=x+7239682|0;c[2411840]=A;c[2414390]=A;A=x+65536|0;if((c[3542200]|0)==0){B=1;i=e;return B|0}x=v+108|0;c[x>>2]=0;C=v+100|0;c[C>>2]=0;D=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[D&16383](v,0)|0;do{if((c[x>>2]|0)!=0){D=c[C>>2]|0;c[w>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](w,0,0)|0;if((D|0)<1){B=1;i=e;return B|0}if((gzL(A,0,0)|0)==0){break}else{B=1}i=e;return B|0}}while(0);A=(c[2387368]|0)+196608|0;if((c[3542200]|0)==0){B=1;i=e;return B|0}C=t+108|0;c[C>>2]=0;x=t+100|0;c[x>>2]=0;D=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[D&16383](t,1)|0;do{if((c[C>>2]|0)!=0){D=c[x>>2]|0;c[u>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](u,1,0)|0;if((D|0)<1){B=1;i=e;return B|0}if((gzL(A,0,1)|0)==0){break}else{B=1}i=e;return B|0}}while(0);A=c[2387368]|0;x=A+32768|0;C=A+294912|0;gGC(x|0,C|0,32768)|0;C=c[2385982]|0;if((c[3542200]|0)==0){B=1;i=e;return B|0}x=r+108|0;c[x>>2]=0;A=r+100|0;c[A>>2]=0;D=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[D&16383](r,2)|0;do{if((c[x>>2]|0)!=0){D=c[A>>2]|0;c[s>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](s,2,0)|0;if((D|0)<1){B=1;i=e;return B|0}if((gzL(C,0,2)|0)==0){break}else{B=1}i=e;return B|0}}while(0);C=c[3530922]|0;if((c[3542200]|0)==0){B=1;i=e;return B|0}A=p+108|0;c[A>>2]=0;x=p+100|0;c[x>>2]=0;D=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[D&16383](p,3)|0;do{if((c[A>>2]|0)!=0){D=c[x>>2]|0;c[q>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](q,3,0)|0;if((D|0)<1){B=1;i=e;return B|0}if((gzL(C,0,3)|0)==0){break}else{B=1}i=e;return B|0}}while(0);C=(c[3530922]|0)+524288|0;if((c[3542200]|0)==0){B=1;i=e;return B|0}x=n+108|0;c[x>>2]=0;A=n+100|0;c[A>>2]=0;D=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[D&16383](n,4)|0;do{if((c[x>>2]|0)!=0){D=c[A>>2]|0;c[o>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](o,4,0)|0;if((D|0)<1){B=1;i=e;return B|0}if((gzL(C,0,4)|0)==0){break}else{B=1}i=e;return B|0}}while(0);C=c[3530686]|0;if((c[3542200]|0)==0){B=1;i=e;return B|0}A=l+108|0;c[A>>2]=0;x=l+100|0;c[x>>2]=0;D=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[D&16383](l,5)|0;do{if((c[A>>2]|0)!=0){D=c[x>>2]|0;c[m>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](m,5,0)|0;if((D|0)<1){B=1;i=e;return B|0}if((gzL(C,0,5)|0)==0){break}else{B=1}i=e;return B|0}}while(0);C=(c[3530686]|0)+524288|0;if((c[3542200]|0)==0){B=1;i=e;return B|0}x=j+108|0;c[x>>2]=0;A=j+100|0;c[A>>2]=0;D=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[D&16383](j,6)|0;do{if((c[x>>2]|0)!=0){D=c[A>>2]|0;c[k>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](k,6,0)|0;if((D|0)<1){B=1;i=e;return B|0}if((gzL(C,0,6)|0)==0){break}else{B=1}i=e;return B|0}}while(0);C=c[2386682]|0;if((c[3542200]|0)==0){B=1;i=e;return B|0}A=f+108|0;c[A>>2]=0;x=f+100|0;c[x>>2]=0;D=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[D&16383](f,7)|0;do{if((c[A>>2]|0)!=0){D=c[x>>2]|0;c[g>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](g,7,0)|0;if((D|0)<1){B=1;i=e;return B|0}if((gzL(C,0,7)|0)==0){break}else{B=1}i=e;return B|0}}while(0);C=c[3530922]|0;blG(C,524288);x=c[3530686]|0;blG(x,524288);A=c[2439890]|0;D=0;do{E=D<<6;gGz(A+E|0,0,64);F=D<<8;G=0;do{H=1<<3-G;I=(c[611632+(G<<2)>>2]|0)+F|0;J=0;do{K=I+(c[1183816+(J<<2)>>2]|0)|0;L=(J<<3)+E|0;M=0;do{N=K+(c[614800+(M<<2)>>2]|0)|0;if(((d[C+((N|0)/8|0)|0]|0)&128>>>((N&7)>>>0)|0)!=0){N=A+(L+M)|0;a[N]=(d[N]|0|H)&255}M=M+1|0;}while((M|0)<8);J=J+1|0;}while((J|0)<8);G=G+1|0;}while((G|0)<4);D=D+1|0;}while((D|0)<32768);D=c[2439854]|0;A=0;do{C=A<<8;gGz(D+C|0,0,256);G=A<<10;E=0;do{F=1<<3-E;J=(c[611632+(E<<2)>>2]|0)+G|0;H=0;do{I=J+(c[3946808+(H<<2)>>2]|0)|0;M=(H<<4)+C|0;L=0;do{K=I+(c[6669416+(L<<2)>>2]|0)|0;if(((d[x+((K|0)/8|0)|0]|0)&128>>>((K&7)>>>0)|0)!=0){K=D+(M+L)|0;a[K]=(d[K]|0|F)&255}L=L+1|0;}while((L|0)<16);H=H+1|0;}while((H|0)<16);E=E+1|0;}while((E|0)<4);A=A+1|0;}while((A|0)<8192);c[2410674]=1748;gGz(9699632,0,3072);A=c[2427044]|0;c[9681616+(A<<3)>>2]=715288;c[9681620+(A<<3)>>2]=0;c[2427044]=A+1;c[363094]=0;A=c[2387392]|0;D=0;x=0;while(1){E=x+8|0;C=A+(x<<8)|0;c[9699632+(E<<2)>>2]=C;c[9700656+(E<<2)>>2]=C;c[9701680+(E<<2)>>2]=C;C=D+1&65535;if((C&65535)<24){D=C;x=C&65535}else{break}}x=c[2387368]|0;D=0;A=0;while(1){C=A+96|0;E=x+((A<<8)+65536)|0;c[9699632+(C<<2)>>2]=E;c[9701680+(C<<2)>>2]=E;E=D+1&65535;if((E&65535)<64){D=E;A=E&65535}else{O=0;P=0;break}}while(1){A=P+160|0;D=x+((P<<8)+40960)|0;c[9699632+(A<<2)>>2]=D;c[9701680+(A<<2)>>2]=D;D=O+1&65535;if((D&65535)<96){O=D;P=D&65535}else{break}}c[2444172]=3444;c[3528598]=2788;c[2410675]=1520;c[363094]=-1;fwR(0);x=c[2439330]|0;D=(x|0)==0;if(!D){A=x;gGC(9706056,A|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];A=c[3528484]|0;c[2076596]=A;E=c[2417276]|0;c[3541536]=E;c[1836236]=0;C=c[2385982]|0;G=0;H=0;while(1){c[x+76+(H<<2)>>2]=C+(H<<8);F=G+1&65535;if((F&65535)>239){Q=0;R=0;break}else{G=F;H=F&65535}}while(1){H=C+(R<<8)|0;c[x+76+(R+512<<2)>>2]=H;c[x+76+(R+768<<2)>>2]=H;H=Q+1&65535;if((H&65535)>239){break}else{Q=H;R=H&65535}}C=c[2386134]|0;c[x+1036>>2]=C;H=C+256|0;c[x+1040>>2]=H;G=C+512|0;c[x+1044>>2]=G;F=C+768|0;c[x+1048>>2]=F;J=C+1024|0;c[x+1052>>2]=J;L=C+1280|0;c[x+1056>>2]=L;M=C+1536|0;c[x+1060>>2]=M;I=C+1792|0;c[x+1064>>2]=I;c[x+2060>>2]=C;c[x+2064>>2]=H;c[x+2068>>2]=G;c[x+2072>>2]=F;c[x+2076>>2]=J;c[x+2080>>2]=L;c[x+2084>>2]=M;c[x+2088>>2]=I;c[x+3084>>2]=C;c[x+4108>>2]=C;c[x+3088>>2]=H;c[x+4112>>2]=H;c[x+3092>>2]=G;c[x+4116>>2]=G;c[x+3096>>2]=F;c[x+4120>>2]=F;c[x+3100>>2]=J;c[x+4124>>2]=J;c[x+3104>>2]=L;c[x+4128>>2]=L;c[x+3108>>2]=M;c[x+4132>>2]=M;c[x+3112>>2]=I;c[x+4136>>2]=I;c[x+4184>>2]=2664;c[x+4180>>2]=1012;if(!D){I=x;gGC(I|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=A;c[2417276]=E;c[1836236]=-1;I=c[3530922]|0;M=0;while(1){if((M|0)>=1024){S=0;break}T=9638528+(M<<2)|0;if((c[T>>2]|0)==0){z=686;break}else{M=M+1|0}}do{if((z|0)==686){M=gGq(24576)|0;c[T>>2]=M;if((M|0)==0){S=0;break}gGz(M|0,0,24576);S=M}}while(0);c[3529062]=S;c[2438700]=1048575;c[3529060]=I;a[7461784]=1;M=9726816;c[M>>2]=0;c[M+4>>2]=0;M=9726800;c[M>>2]=0;c[M+4>>2]=0;c[2429638]=0;c[2437692]=52;c[2431704]=8;c[2431700]=0;c[2431705]=8;c[2431701]=0;c[2431706]=8;c[2431702]=0;biH(c[3530686]|0,1048575,30);c[3529052]=-112;c[3529050]=-16;M=a[9680]|0;E=M?32e3:0;if(M){if(a[9624]|0){M=E*3|0;A=55930;while(1){if((A|0)>(M|0)){A=A>>1}else{U=1222;V=A;break}}}else{U=2462;V=E}c[2429380]=V;c[3542124]=U;mw(3579545,V);A=gGq(262144)|0;c[2406684]=A;gGz(A|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(3579545,11025)}h[745421]=1.0;c[2436794]=1;h[745420]=1.0;c[2436792]=2;TN(c[2386682]|0,524288);h[1209346]=.7;c[2418696]=1;c[2426862]=9674384;h[1209347]=.7;c[2418697]=2;A=c[642608+(c[2436]<<2)>>2]|0;M=c[A+128>>2]|0;if((c[A+52>>2]&4|0)==0){c[2113068]=M;I=c[A+132>>2]|0;c[2113070]=I;c[2443814]=M;c[2440436]=I;W=M;X=I}else{c[2113070]=M;I=c[A+132>>2]|0;c[2113068]=I;c[2440436]=M;c[2443814]=I;W=I;X=M}M=ag(W<<1,X)|0;I=gGq(M)|0;c[2112926]=I;if((I|0)!=0){gGz(I|0,0,M|0)}a[9624904]=0;M=c[2414780]|0;gGz(M|0,0,(c[2411840]|0)-M|0);c[363094]=0;c[2410673]=0;a[9642688]=0;a[9642689]=0;a[9642682]=0;a[9642683]=0;c[2410665]=0;a[9642680]=a[9642680]|80;M=c[2425163]|0;do{if((M|0)==0){I=c[3528598]|0;if((I|0)==0){Y=0;Z=0;break}A=gj[I&4095](-2)|0;I=c[2425163]|0;x=(A&255)<<8;if((I|0)!=0){_=I;$=x;z=703;break}I=c[3528598]|0;if((I|0)==0){Y=0;Z=x;break}Y=gj[I&4095](-1)|0;Z=x}else{_=M;$=(d[M+254|0]|0)<<8;z=703}}while(0);if((z|0)==703){Y=a[_+255|0]|0;Z=$}c[2410662]=Y&255|Z;c[363094]=-1;M=c[2439330]|0;E=(M|0)==0;if(!E){x=M;gGC(9706056,x|0,76)|0}x=c[2438118]|0;c[2433530]=x;I=c[3528484]|0;c[2076596]=I;A=c[2417276]|0;c[3541536]=A;c[1836236]=0;gGz(9706056,0,76);if(!E){E=M;gGC(E|0,9706056,76)|0}c[2438118]=x;c[3528484]=I;c[2417276]=A;c[1836236]=-1;mx(0);blH();c[2426862]=9674384;gGz(9674592,0,176);B=0;i=e;return B|0}}while(0);c[2415072]=0;B=1;i=e;return B|0}function bmJ(){var a=0,b=0,d=0,e=0;c[2113070]=0;c[2113068]=0;a=c[2112926]|0;if((a|0)!=0){gGr(a);c[2112926]=0}blI();c[2444172]=0;c[3528598]=0;fwZ();a=c[3531464]|0;c[a+44344>>2]=0;c[a+44348>>2]=0;if((a|0)!=0){gGr(a);c[3531464]=0}a=c[2406684]|0;if((a|0)!=0){gGr(a);c[2406684]=0}c[2426862]=9674384;a=c[2418647]|0;if((a|0)!=0){gGr(a);c[(c[2426862]|0)+204>>2]=0}c[2426862]=9674792;a=c[2418749]|0;if((a|0)!=0){gGr(a);c[(c[2426862]|0)+204>>2]=0}c[2443782]=0;a=c[2415072]|0;b=0;while(1){if((b|0)>=1024){d=753;break}e=9638528+(b<<2)|0;if((c[e>>2]|0)==(a|0)){break}else{b=b+1|0}}if((d|0)==753){c[2415072]=0;return 0}gGr(a);c[e>>2]=0;c[2415072]=0;return 0}function bmK(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if((a[9624904]|0)!=0){a[9624904]=0;e=c[2414780]|0;gGz(e|0,0,(c[2411840]|0)-e|0);c[363094]=0;c[2410673]=0;a[9642688]=0;a[9642689]=0;a[9642682]=0;a[9642683]=0;c[2410665]=0;a[9642680]=a[9642680]|80;e=c[2425163]|0;do{if((e|0)==0){f=c[3528598]|0;if((f|0)==0){g=0;h=0;break}i=gj[f&4095](-2)|0;f=c[2425163]|0;j=(i&255)<<8;if((f|0)!=0){k=f;l=j;m=760;break}f=c[3528598]|0;if((f|0)==0){g=0;h=j;break}g=gj[f&4095](-1)|0;h=j}else{k=e;l=d[e+254|0]<<8;m=760}}while(0);if((m|0)==760){g=a[k+255|0]|0;h=l}c[2410662]=g&255|h;c[363094]=-1;h=c[2439330]|0;g=(h|0)==0;if(!g){l=h;gGC(9706056,l|0,76)|0}l=c[2438118]|0;c[2433530]=l;k=c[3528484]|0;c[2076596]=k;m=c[2417276]|0;c[3541536]=m;c[1836236]=0;gGz(9706056,0,76);if(!g){g=h;gGC(g|0,9706056,76)|0}c[2438118]=l;c[3528484]=k;c[2417276]=m;c[1836236]=-1;mx(0);blH();c[2426862]=9674384;gGz(9674592,0,176)}m=c[2385548]|0;if((m|0)>0){gGz(9752472,0,((m|0)>1?m<<2:4)|0)}c[2433530]=0;c[2410673]=0;gGz(9550856,-1|0,3);m=0;k=-1;l=-1;g=-1;do{k=((a[9634248+m|0]&1)<<m^k&255)&255;l=((a[9632008+m|0]&1)<<m^l&255)&255;g=((a[9629928+m|0]&1)<<m^g&255)&255;m=m+1|0;}while((m|0)<8);a[9550856]=k;a[9550857]=l;a[9550858]=g;if((k&6)==0){g=k|6;a[9550856]=g;n=g}else{n=k}if((n&24)==0){a[9550856]=n|24}if((l&6)==0){n=l|6;a[9550857]=n;o=n}else{o=l}if((o&24)==0){a[9550857]=o|24}o=a[9688]|0?534:0;c[2443996]=0;c[2444048]=0;l=c[2439330]|0;if((l|0)!=0){n=l;gGC(9706056,n|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;c[363094]=0;n=0;l=0;L1042:while(1){k=l;do{if((k|0)>=(o|0)){break L1042}k=k+1|0;g=fNF(((k*5e4|0|0)/534|0)-(c[2444048]|0)|0)|0;c[2444048]=(c[2444048]|0)+g;g=c[2443996]|0;m=((k*59659|0|0)/534|0)-g|0;do{if((m|0)<1){p=0;q=g}else{if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){h=gfc(m)|0;c[2433530]=(c[2433530]|0)+h;p=h;q=c[2443996]|0;break}else{c[2433530]=(c[2433530]|0)+m;p=m;q=g;break}}}while(0);c[2443996]=q+p;r=c[2112964]|0;}while((r|0)==0);g=a[9688]&1;m=r+(n<<1<<1)|0;gg[c[3542124]&4095](m,g);TM(m,g);n=g+n|0;l=k}if((c[3541228]|0)!=0){fNE(0,1);fNF(0)|0;a[9642682]=0;fNF(0)|0}l=c[2112964]|0;do{if((l|0)!=0){r=a[9688]|0?534:0;p=r-n|0;q=l+(n<<1<<1)|0;if((r|0)==(n|0)){break}gg[c[3542124]&4095](q,p);TM(q,p)}}while(0);c[363094]=-1;n=c[1836236]|0;l=c[9757320+(n<<2)>>2]|0;if((l|0)!=0){p=l;gGC(p|0,9706056,76)|0}c[9752472+(n<<2)>>2]=c[2433530];c[14113936+(n<<2)>>2]=c[2076596];c[9669104+(n<<2)>>2]=c[3541536];c[1836236]=-1;if((c[2112968]|0)==0){return 0}bmL()|0;return 0}function bmL(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;if((a[9547896]|0)!=0){e=c[2387258]|0;f=c[3530158]|0;g=c[2406996]|0;h=0;do{i=ga(b[e+(h<<1)>>1]|0)|0;j=i&255;k=((j&255)>>>2&7|j<<3)&255;j=((i&65535)>>>5<<3&255|(i&65535)>>>7&7)&255;l=((i&65535)>>>10<<3&255|(i&65535)>>>12&7)&255;c[f+(h<<2)>>2]=j<<3&2016|l>>>3|k<<8&63488;c[g+(h<<2)>>2]=j<<8|l|k<<16;h=h+1|0;}while((h|0)<2048)}bpj();h=c[2437682]|0;c[2432772]=c[2437683];c[2433644]=c[2437684];c[2433645]=c[2437686];c[2433646]=c[2437685];g=a[14116146]|0;f=g&255;c[2394828]=f;e=a[14116148]|0;k=e&255;c[2394826]=k;l=d[14116147]|0;c[2394824]=l;if((g&255)<(e&255)){c[2394828]=k;c[2394826]=f;m=k;n=1;o=0;p=f}else{m=f;n=0;o=1;p=k}if(m>>>0<l>>>0){c[2394828]=l;c[2394824]=m;q=m;r=2;s=n}else{q=l;r=n;s=2}if((p|0)<(q|0)){c[2394826]=q;c[2394824]=p;t=s;u=o}else{t=o;u=s}s=ag(c[2113070]|0,c[2113068]|0)|0;if((s|0)>0){o=h<<4&65535;h=c[2112926]|0;p=0;do{b[h+(p<<1)>>1]=o;p=p+1|0;}while((p|0)<(s|0))}bpk(r,0,c[2439890]|0);biI(c[2439854]|0,2);biI(c[2439854]|0,3);bpk(t,0,c[2439890]|0);biI(c[2439854]|0,1);bpk(u,0,c[2439890]|0);biI(c[2439854]|0,0);blK(c[2406996]|0,c[3530158]|0);return 0}function bmM(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;e=i;i=i+96|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;l=e+80|0;if((b|0)!=0){c[b>>2]=169733}if((a&96|0)!=0){gGz(l|0,0,12);b=c[2414780]|0;c[l>>2]=b;c[l+4>>2]=(c[2411840]|0)-b;c[l+12>>2]=162152;b=c[2076592]|0;gj[b&4095](l)|0;l=c[2410674]|0;b=c[2410675]|0;do{if((a&64|0)==0){c[2410674]=l;c[2410675]=b;fw$(a)}else{gGz(k|0,0,12);c[k>>2]=9642648;c[k+4>>2]=56;c[k+12>>2]=163840;m=c[2076592]|0;gj[m&4095](k)|0;gGz(j|0,0,12);c[j>>2]=9707480;c[j+4>>2]=2;c[j+12>>2]=501096;m=c[2076592]|0;gj[m&4095](j)|0;gGz(h|0,0,12);c[h>>2]=9707480;c[h+4>>2]=4;c[h+12>>2]=385184;m=c[2076592]|0;gj[m&4095](h)|0;c[2410674]=l;c[2410675]=b;fw$(a);gGz(g|0,0,12);c[g>>2]=8453216;c[g+4>>2]=4;c[g+12>>2]=107480;m=c[2076592]|0;gj[m&4095](g)|0;gGz(f|0,0,12);c[f>>2]=14168504;c[f+4>>2]=256;c[f+12>>2]=476464;m=c[2076592]|0;gj[m&4095](f)|0;if((a&2|0)==0){break}else{n=0}do{mv(0,n,d[14168504+n|0]|0);n=n+1|0;}while((n|0)<256)}}while(0);blJ(a)}if((a&2|0)==0){i=e;return 0}c[363094]=0;a=c[2387368]|0;n=((d[c[2443940]|0]|0)<<14&245760^245760)+65536|0;f=0;g=0;while(1){b=g+96|0;l=a+(n+(g<<8))|0;c[9699632+(b<<2)>>2]=l;c[9701680+(b<<2)>>2]=l;l=f+1&65535;if((l&65535)<64){f=l;g=l&65535}else{break}}c[363094]=-1;i=e;return 0}function bmN(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1444852+(b*112|0)>>2];c[a+104>>2]=c[1444856+(b*112|0)>>2];c[a+108>>2]=c[1444860+(b*112|0)>>2];d=0;return d|0}function bmO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=1444752+(b*112|0);e=0;return e|0}function bmP(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1443956+(b*112|0)>>2];c[a+104>>2]=c[1443960+(b*112|0)>>2];c[a+108>>2]=c[1443964+(b*112|0)>>2];d=0;return d|0}function bmQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=1443856+(b*112|0);e=0;return e|0}function bmR(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1445748+(b*112|0)>>2];c[a+104>>2]=c[1445752+(b*112|0)>>2];c[a+108>>2]=c[1445756+(b*112|0)>>2];d=0;return d|0}function bmS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=1445648+(b*112|0);e=0;return e|0}function bmT(b){b=b|0;var d=0,e=0,f=0,g=0,h=0;a[c[2443940]|0]=b&255;d=c[2387368]|0;e=(b<<14&245760^245760)+65536|0;b=0;f=0;while(1){g=f+96|0;h=d+(e+(f<<8))|0;c[9699632+(g<<2)>>2]=h;c[9701680+(g<<2)>>2]=h;h=b+1&65535;if((h&65535)<64){b=h;f=h&65535}else{break}}return}function bmU(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;c[f>>2]=(c[e>>2]|0)>>>7&1;f=c[e>>2]|0;c[d>>2]=c[d>>2]|b<<13|f<<6&1024|f<<8&768|f<<9&6144;c[e>>2]=((c[e>>2]|0)>>>5&7)+(c[9734576+(a<<2)>>2]|0);return}function bmV(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;e=(c[b>>2]|0)>>>2&24|32;do{if((e|0)>(c[2394824]|0)){if((e|0)<=(c[2394826]|0)){c[d>>2]=1;break}if((e|0)>(c[2394828]|0)){c[d>>2]=3;break}else{c[d>>2]=2;break}}else{c[d>>2]=0}}while(0);c[a>>2]=c[a>>2]&8191;c[b>>2]=(c[b>>2]&31)+(c[2432772]|0);return}function bmW(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=d&65535;switch(f|0){case 57411:{a[9721960]=e;return};case 57408:case 57409:case 57410:case 62976:{return};case 62464:{TR(0,e&255);return};case 61440:{if((c[2385616]|0)!=2){return}g=(e&255)>>>5<<11;c[2439248]=g;h=c[2426614]|0;i=c[9757320+(c[1836236]<<2)>>2]|0;c[i+1068>>2]=h+(g|65536);c[i+1072>>2]=h+(g|65792);c[i+1076>>2]=h+(g|66048);c[i+1080>>2]=h+(g|66304);c[i+1084>>2]=h+(g|66560);c[i+1088>>2]=h+(g|66816);c[i+1092>>2]=h+(g|67072);c[i+1096>>2]=h+(g|67328);g=c[2439248]|0;j=h+(g+65536)|0;c[i+3116>>2]=j;c[i+4140>>2]=j;j=h+(g+65792)|0;c[i+3120>>2]=j;c[i+4144>>2]=j;j=h+(g+66048)|0;c[i+3124>>2]=j;c[i+4148>>2]=j;j=h+(g+66304)|0;c[i+3128>>2]=j;c[i+4152>>2]=j;j=h+(g+66560)|0;c[i+3132>>2]=j;c[i+4156>>2]=j;j=h+(g+66816)|0;c[i+3136>>2]=j;c[i+4160>>2]=j;j=h+(g+67072)|0;c[i+3140>>2]=j;c[i+4164>>2]=j;j=h+(g+67328)|0;c[i+3144>>2]=j;c[i+4168>>2]=j;return};case 63744:case 63745:{b[4876580]=(d<<8&256|e&255)+56&65535;return};case 57412:{a[14113912]=e&1;a[14114448]=(c[2385616]&2^2)+2&(e&255)&255;a[14115080]=e&8;return};default:{if((d+8192&65535)<64){a[(c[2426614]|0)+f|0]=e;return}if(!((c[2385616]|0)==1&(d&65535)>59647&(d&65535)<59904)){return}a[(c[2426614]|0)+f|0]=e;return}}}function bmX(b){b=b|0;var d=0,e=0;d=b&65535;switch(d|0){case 62976:{e=a[9635592]|0;return e|0};case 62979:{e=a[9629921]<<1^~a[9629920]^a[9629922]<<2^a[9629923]<<3^a[9629924]<<4^a[9629925]<<5^a[9629926]<<6^a[9629927]<<7;return e|0};case 62978:{e=a[9634241]<<1^~a[9634240]^a[9634242]<<2^a[9634243]<<3^a[9634244]<<4^a[9634245]<<5^a[9634246]<<6^a[9634247]<<7;return e|0};case 61952:{e=a[9635593]|0;return e|0};case 62977:{if((c[2385616]&1|0)==0){e=a[9632001]<<1^~a[9632e3]^a[9632002]<<2^a[9632003]<<3^a[9632004]<<4^a[9632005]<<5^a[9632006]<<6^a[9632007]<<7;return e|0}else{e=a[9635595]|0;return e|0}break};case 62464:{e=a[9635594]|0;return e|0};default:{if((b+8192&65535)<64){e=a[(c[2426614]|0)+d|0]|0;return e|0}if((c[2385616]|0)!=1){e=0;return e|0}if((b+5888&65535)>=256){e=0;return e|0}e=a[(c[2426614]|0)+d|0]|0;return e|0}}return 0}function bmY(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5885580+(b*112|0)>>2];c[a+104>>2]=c[5885584+(b*112|0)>>2];c[a+108>>2]=c[5885588+(b*112|0)>>2];d=0;return d|0}function bmZ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=5885480+(b*112|0);e=0;return e|0}function bm_(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6937808+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function bm$(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>77){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5886712+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function bm0(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0;e=i;i=i+728|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+608|0;r=e+616|0;c[2426614]=0;c[2424866]=81920;c[2424842]=114688;c[2424794]=245760;c[2406994]=246304;c[3530156]=248352;s=0;while(1){if((s|0)>=1024){t=1;u=1077;break}v=9638528+(s<<2)|0;if((c[v>>2]|0)==0){break}else{s=s+1|0}}if((u|0)==1077){i=e;return t|0}s=gGq(250400)|0;c[v>>2]=s;if((s|0)==0){t=1;i=e;return t|0}c[2426814]=s;gGz(s|0,0,250400);c[2426614]=s;v=s+81920|0;c[2424866]=v;w=s+114688|0;c[2424842]=w;x=s+245760|0;c[2424794]=x;c[2406994]=s+246304;c[3530156]=s+248352;c[2414388]=s+250400;L1258:do{if((gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](q,0,0)|0)==0){y=r+108|0;z=r+100|0;A=n+108|0;B=n+100|0;C=l+108|0;D=l+100|0;E=j+108|0;F=j+100|0;G=f+108|0;H=f+100|0;I=s;J=v;K=w;L=x;M=0;while(1){gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,M)|0;N=c[y>>2]&7;if((N|0)==4){if((c[3542200]|0)==0){t=1;u=1073;break}c[G>>2]=0;c[H>>2]=0;O=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[O&16383](f,M)|0;if((c[G>>2]|0)!=0){O=c[H>>2]|0;c[g>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](g,M,0)|0;if((O|0)<1){t=1;u=1071;break}if((gzL(L,0,M)|0)!=0){t=1;u=1072;break}}Q=L+(c[z>>2]|0)|0;R=K;S=J;T=I}else if((N|0)==2){if((c[3542200]|0)==0){t=1;u=1074;break}c[C>>2]=0;c[D>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,M)|0;if((c[C>>2]|0)!=0){O=c[D>>2]|0;c[m>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](m,M,0)|0;if((O|0)<1){t=1;u=1081;break}if((gzL(J,0,M)|0)!=0){t=1;u=1080;break}}Q=L;R=K;S=J+(c[z>>2]|0)|0;T=I}else if((N|0)==3){if((c[3542200]|0)==0){t=1;u=1075;break}c[E>>2]=0;c[F>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,M)|0;if((c[E>>2]|0)!=0){O=c[F>>2]|0;c[k>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](k,M,0)|0;if((O|0)<1){t=1;u=1069;break}if((gzL(K,0,M)|0)!=0){t=1;u=1070;break}}Q=L;R=K+(c[z>>2]|0)|0;S=J;T=I}else if((N|0)==1){if((c[3542200]|0)==0){t=1;u=1079;break}c[A>>2]=0;c[B>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,M)|0;if((c[A>>2]|0)!=0){N=c[B>>2]|0;c[o>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](o,M,0)|0;if((N|0)<1){t=1;u=1076;break}if((gzL(I,0,M)|0)!=0){t=1;u=1066;break}}Q=L;R=K;S=J;T=I+(c[z>>2]|0)|0}else{Q=L;R=K;S=J;T=I}N=M+1|0;if((gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](q,N,0)|0)==0){I=T;J=S;K=R;L=Q;M=N}else{break L1258}}if((u|0)==1066){i=e;return t|0}else if((u|0)==1069){i=e;return t|0}else if((u|0)==1070){i=e;return t|0}else if((u|0)==1071){i=e;return t|0}else if((u|0)==1072){i=e;return t|0}else if((u|0)==1073){i=e;return t|0}else if((u|0)==1074){i=e;return t|0}else if((u|0)==1075){i=e;return t|0}else if((u|0)==1076){i=e;return t|0}else if((u|0)==1079){i=e;return t|0}else if((u|0)==1080){i=e;return t|0}else if((u|0)==1081){i=e;return t|0}}}while(0);Q=c[2385616]|0;if((Q|0)==2){R=c[2426614]|0;S=R+65536|0;T=R+49152|0;gGC(S|0,T|0,16384)|0;gGz(T|0,0,16384)}T=(Q|0)==1;Q=0;while(1){if((Q|0)>=1024){U=0;break}V=9638528+(Q<<2)|0;if((c[V>>2]|0)==0){u=986;break}else{Q=Q+1|0}}do{if((u|0)==986){Q=gGq(65536)|0;c[V>>2]=Q;if((Q|0)==0){U=0;break}gGz(Q|0,0,65536);U=Q}}while(0);V=(U|0)==0;L1312:do{if(T){if(V){break}u=c[2424866]|0;gGC(U|0,u|0,16384)|0;Q=0;do{S=Q<<6;gGz(u+S|0,0,64);R=Q<<8;q=0;do{o=1<<3-q;n=(c[703416+(q<<2)>>2]|0)+R|0;k=0;do{j=n+(c[1183816+(k<<2)>>2]|0)|0;m=(k<<3)+S|0;l=0;do{g=j+(c[606568+(l<<2)>>2]|0)|0;if(((d[U+((g|0)/8|0)|0]|0)&128>>>((g&7)>>>0)|0)!=0){g=u+(m+l)|0;a[g]=(d[g]|0|o)&255}l=l+1|0;}while((l|0)<8);k=k+1|0;}while((k|0)<8);q=q+1|0;}while((q|0)<4);Q=Q+1|0;}while((Q|0)<512);Q=c[2424842]|0;gGC(U|0,Q|0,65536)|0;u=0;while(1){q=u<<8;gGz(Q+q|0,0,256);S=0;do{R=1<<3-S;k=(c[961488+(S<<2)>>2]|0)+q|0;o=0;do{n=k+(c[609008+(o<<2)>>2]|0)|0;l=(o<<4)+q|0;m=0;do{j=n+(c[597864+(m<<2)>>2]|0)|0;if(((d[U+((j|0)/8|0)|0]|0)&128>>>((j&7)>>>0)|0)!=0){j=Q+(l+m)|0;a[j]=(d[j]|0|R)&255}m=m+1|0;}while((m|0)<16);o=o+1|0;}while((o|0)<16);S=S+1|0;}while((S|0)<4);S=u+1|0;if((S|0)<512){u=S}else{W=0;break}}while(1){if((W|0)>=1024){break L1312}X=9638528+(W<<2)|0;if((c[X>>2]|0)==(U|0)){break}else{W=W+1|0}}gGr(U);c[X>>2]=0}else{if(V){break}u=c[2424866]|0;gGC(U|0,u|0,16384)|0;Q=0;do{S=Q<<6;gGz(u+S|0,0,64);q=Q<<8;o=0;do{R=1<<3-o;k=(c[703416+(o<<2)>>2]|0)+q|0;m=0;do{l=k+(c[3946808+(m<<2)>>2]|0)|0;n=(m<<3)+S|0;j=0;do{g=l+(c[3946872+(j<<2)>>2]|0)|0;if(((d[U+((g|0)/8|0)|0]|0)&128>>>((g&7)>>>0)|0)!=0){g=u+(n+j)|0;a[g]=(d[g]|0|R)&255}j=j+1|0;}while((j|0)<8);m=m+1|0;}while((m|0)<8);o=o+1|0;}while((o|0)<4);Q=Q+1|0;}while((Q|0)<512);Q=c[2424842]|0;gGC(U|0,Q|0,65536)|0;u=0;while(1){o=u<<8;gGz(Q+o|0,0,256);S=u<<10;q=0;do{m=1<<3-q;R=(c[703416+(q<<2)>>2]|0)+S|0;k=0;do{j=R+(c[3946808+(k<<2)>>2]|0)|0;n=(k<<4)+o|0;l=0;do{g=j+(c[3946872+(l<<2)>>2]|0)|0;if(((d[U+((g|0)/8|0)|0]|0)&128>>>((g&7)>>>0)|0)!=0){g=Q+(n+l)|0;a[g]=(d[g]|0|m)&255}l=l+1|0;}while((l|0)<16);k=k+1|0;}while((k|0)<16);q=q+1|0;}while((q|0)<4);q=u+1|0;if((q|0)<512){u=q}else{Y=0;break}}while(1){if((Y|0)>=1024){break L1312}Z=9638528+(Y<<2)|0;if((c[Z>>2]|0)==(U|0)){break}else{Y=Y+1|0}}gGr(U);c[Z>>2]=0}}while(0);Z=c[2424794]|0;U=0;do{Y=d[Z+U|0]|0;c[p+(U<<2)>>2]=(-(Y>>>3&1)&33)+(-(Y>>>4&1)&71)+(-(Y>>>5&1)&151)<<8|(-(Y>>>6&1)&71)+(-(Y>>>7)&151)|(-(Y>>>1&1)&71)+(-(Y&1)&33)+(-(Y>>>2&1)&151)<<16;U=U+1|0;}while((U|0)<32);c[2424794]=Z+32;U=c[2406994]|0;Y=0;do{c[U+(Y<<2)>>2]=c[p+(((a[Z+(Y+32)|0]&15|16)&255)<<2)>>2];c[U+(Y+256<<2)>>2]=c[p+((a[Z+(Y+288)|0]&15)<<2)>>2];Y=Y+1|0;}while((Y|0)<256);fwR(0);Y=c[2439330]|0;Z=(Y|0)==0;if(!Z){p=Y;gGC(9706056,p|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];p=c[3528484]|0;c[2076596]=p;U=c[2417276]|0;c[3541536]=U;c[1836236]=0;c[Y+4180>>2]=540;c[Y+4184>>2]=2116;V=c[2426614]|0;X=0;W=0;while(1){c[Y+76+(W<<2)>>2]=V+(W<<8);T=X+1&65535;if((T&65535)>191){_=0;$=0;break}else{X=T;W=T&65535}}while(1){W=V+($<<8)|0;c[Y+76+($+512<<2)>>2]=W;c[Y+76+($+768<<2)>>2]=W;W=_+1&65535;if((W&65535)>191){break}else{_=W;$=W&65535}}$=V+49152|0;c[Y+844>>2]=$;_=V+49408|0;c[Y+848>>2]=_;W=V+49664|0;c[Y+852>>2]=W;X=V+49920|0;c[Y+856>>2]=X;T=V+50176|0;c[Y+860>>2]=T;u=V+50432|0;c[Y+864>>2]=u;Q=V+50688|0;c[Y+868>>2]=Q;q=V+50944|0;c[Y+872>>2]=q;o=V+51200|0;c[Y+876>>2]=o;S=V+51456|0;c[Y+880>>2]=S;k=V+51712|0;c[Y+884>>2]=k;m=V+51968|0;c[Y+888>>2]=m;R=V+52224|0;c[Y+892>>2]=R;l=V+52480|0;c[Y+896>>2]=l;n=V+52736|0;c[Y+900>>2]=n;j=V+52992|0;c[Y+904>>2]=j;c[Y+1868>>2]=$;c[Y+1872>>2]=_;c[Y+1876>>2]=W;c[Y+1880>>2]=X;c[Y+1884>>2]=T;c[Y+1888>>2]=u;c[Y+1892>>2]=Q;c[Y+1896>>2]=q;c[Y+1900>>2]=o;c[Y+1904>>2]=S;c[Y+1908>>2]=k;c[Y+1912>>2]=m;c[Y+1916>>2]=R;c[Y+1920>>2]=l;c[Y+1924>>2]=n;c[Y+1928>>2]=j;j=V+53248|0;c[Y+908>>2]=j;c[Y+1932>>2]=j;j=V+53504|0;c[Y+912>>2]=j;c[Y+1936>>2]=j;j=V+53760|0;c[Y+916>>2]=j;n=V+54016|0;c[Y+920>>2]=n;l=V+54272|0;c[Y+924>>2]=l;R=V+54528|0;c[Y+928>>2]=R;m=V+54784|0;c[Y+932>>2]=m;k=V+55040|0;c[Y+936>>2]=k;S=V+55296|0;c[Y+940>>2]=S;o=V+55552|0;c[Y+944>>2]=o;q=V+55808|0;c[Y+948>>2]=q;Q=V+56064|0;c[Y+952>>2]=Q;u=V+56320|0;c[Y+956>>2]=u;T=V+56576|0;c[Y+960>>2]=T;X=V+56832|0;c[Y+964>>2]=X;W=V+57088|0;c[Y+968>>2]=W;c[Y+1940>>2]=j;c[Y+1944>>2]=n;c[Y+1948>>2]=l;c[Y+1952>>2]=R;c[Y+1956>>2]=m;c[Y+1960>>2]=k;c[Y+1964>>2]=S;c[Y+1968>>2]=o;c[Y+1972>>2]=q;c[Y+1976>>2]=Q;c[Y+1980>>2]=u;c[Y+1984>>2]=T;c[Y+1988>>2]=X;c[Y+1992>>2]=W;W=210;X=210;while(1){T=V+(X<<8)|0;c[Y+76+(X+512<<2)>>2]=T;c[Y+76+(X+768<<2)>>2]=T;T=W+1&65535;if((T&65535)>223){break}else{W=T;X=T&65535}}if((c[2385616]|0)==2){X=V+59392|0;c[Y+1004>>2]=X;c[Y+2028>>2]=X;c[Y+3052>>2]=X;c[Y+4076>>2]=X}if(!Z){Z=Y;gGC(Z|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=p;c[2417276]=U;c[1836236]=-1;TS(0,1536e3,32768,6,0,0);U=c[2420348]|0;h[U+192>>3]=1.0;c[U+200>>2]=3;a[9624896]=0;a[14115080]=0;a[14113912]=0;a[14114448]=0;c[2439248]=0;b[4876580]=0;a[9721960]=0;U=c[2439330]|0;p=(U|0)==0;if(!p){Z=U;gGC(9706056,Z|0,76)|0}c[2433530]=c[2438118];Z=c[3528484]|0;c[2076596]=Z;Y=c[2417276]|0;c[3541536]=Y;c[1836236]=0;gGz(9706056,0,76);X=c[2385616]|0;if((X&2|0)!=0){c[2439248]=0;V=c[2426614]|0;c[U+1068>>2]=V+65536;c[U+1072>>2]=V+65792;c[U+1076>>2]=V+66048;c[U+1080>>2]=V+66304;c[U+1084>>2]=V+66560;c[U+1088>>2]=V+66816;c[U+1092>>2]=V+67072;c[U+1096>>2]=V+67328;W=c[2439248]|0;T=V+(W+65536)|0;c[U+3116>>2]=T;c[U+4140>>2]=T;T=V+(W+65792)|0;c[U+3120>>2]=T;c[U+4144>>2]=T;T=V+(W+66048)|0;c[U+3124>>2]=T;c[U+4148>>2]=T;T=V+(W+66304)|0;c[U+3128>>2]=T;c[U+4152>>2]=T;T=V+(W+66560)|0;c[U+3132>>2]=T;c[U+4156>>2]=T;T=V+(W+66816)|0;c[U+3136>>2]=T;c[U+4160>>2]=T;T=V+(W+67072)|0;c[U+3140>>2]=T;c[U+4164>>2]=T;T=V+(W+67328)|0;c[U+3144>>2]=T;c[U+4168>>2]=T}if(!p){p=U;gGC(p|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=Z;c[2417276]=Y;c[1836236]=-1;if((X|0)==0){c[2424]=3e3}X=c[642608+(c[2436]<<2)>>2]|0;Y=c[X+128>>2]|0;if((c[X+52>>2]&4|0)==0){c[2113068]=Y;Z=c[X+132>>2]|0;c[2113070]=Z;c[2443814]=Y;c[2440436]=Z;aa=Y;ab=Z}else{c[2113070]=Y;Z=c[X+132>>2]|0;c[2113068]=Z;c[2440436]=Y;c[2443814]=Z;aa=Z;ab=Y}Y=ag(aa<<1,ab)|0;ab=gGq(Y)|0;c[2112926]=ab;if((ab|0)==0){t=0;i=e;return t|0}gGz(ab|0,0,Y|0);t=0;i=e;return t|0}function bm1(){var a=0,b=0,d=0,e=0;c[2113070]=0;c[2113068]=0;a=c[2112926]|0;if((a|0)!=0){gGr(a);c[2112926]=0}fwZ();TT();a=c[2426614]|0;b=0;while(1){if((b|0)>=1024){d=1090;break}e=9638528+(b<<2)|0;if((c[e>>2]|0)==(a|0)){break}else{b=b+1|0}}if((d|0)==1090){c[2426614]=0;c[2385616]=0;return 0}gGr(a);c[e>>2]=0;c[2426614]=0;c[2385616]=0;return 0}function bm2(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=c[2385616]|0;e=(d|0)!=0?16:32;if((a[9624896]|0)==0){f=c[2439330]|0}else{a[9624896]=0;a[14115080]=0;a[14113912]=0;a[14114448]=0;c[2439248]=0;b[4876580]=0;a[9721960]=0;g=c[2439330]|0;h=(g|0)==0;if(!h){i=g;gGC(9706056,i|0,76)|0}c[2433530]=c[2438118];i=c[3528484]|0;c[2076596]=i;j=c[2417276]|0;c[3541536]=j;c[1836236]=0;gGz(9706056,0,76);if((d&2|0)!=0){c[2439248]=0;d=c[2426614]|0;c[g+1068>>2]=d+65536;c[g+1072>>2]=d+65792;c[g+1076>>2]=d+66048;c[g+1080>>2]=d+66304;c[g+1084>>2]=d+66560;c[g+1088>>2]=d+66816;c[g+1092>>2]=d+67072;c[g+1096>>2]=d+67328;k=c[2439248]|0;l=d+(k+65536)|0;c[g+3116>>2]=l;c[g+4140>>2]=l;l=d+(k+65792)|0;c[g+3120>>2]=l;c[g+4144>>2]=l;l=d+(k+66048)|0;c[g+3124>>2]=l;c[g+4148>>2]=l;l=d+(k+66304)|0;c[g+3128>>2]=l;c[g+4152>>2]=l;l=d+(k+66560)|0;c[g+3132>>2]=l;c[g+4156>>2]=l;l=d+(k+66816)|0;c[g+3136>>2]=l;c[g+4160>>2]=l;l=d+(k+67072)|0;c[g+3140>>2]=l;c[g+4164>>2]=l;l=d+(k+67328)|0;c[g+3144>>2]=l;c[g+4168>>2]=l}if(!h){h=g;gGC(h|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=i;c[2417276]=j;c[1836236]=-1;f=g}if((f|0)!=0){g=f;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;g=3072e3/((c[2424]|0)/256|0|0)|0;f=e-1|0;j=0;i=0;while(1){h=(g-i|0)/(e-j|0)|0;do{if((h|0)<1){m=0}else{if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){l=gfc(h)|0;c[2433530]=(c[2433530]|0)+l;m=l;break}else{c[2433530]=(c[2433530]|0)+h;m=h;break}}}while(0);if((a[14114448]|0)!=0&(j|0)==(f|0)){a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0}do{if((a[14113912]|0)!=0){if((j&1|0)==0){break}if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12}}while(0);h=j+1|0;if((h|0)<(e|0)){j=h;i=m}else{break}}m=c[1836236]|0;i=c[9757320+(m<<2)>>2]|0;if((i|0)!=0){j=i;gGC(j|0,9706056,76)|0}c[9752472+(m<<2)>>2]=c[2433530];c[14113936+(m<<2)>>2]=c[2076596];c[9669104+(m<<2)>>2]=c[3541536];c[1836236]=-1;m=c[2112964]|0;if((m|0)!=0){TQ(0,m,a[9688]|0?534:0)}if((c[2112968]|0)==0){return 0}bm3()|0;return 0}function bm3(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;if((a[9773968]|0)!=0){b=c[2406994]|0;f=c[3530156]|0;g=0;do{h=c[b+(g<<2)>>2]|0;c[f+(g<<2)>>2]=h>>>8<<3&2016|h>>>3&31|h>>>16<<8&63488;g=g+1|0;}while((g|0)<512)}g=c[2426614]|0;f=(c[2385616]&1|0)==0;b=c[2112926]|0;h=c[2424866]|0;i=64;do{j=i<<3&504;k=i>>>3&248;l=d[g+(i+49152)|0]|0;m=l<<2&256|d[g+(i+51200)|0];n=l&15;o=l&32;p=l&16;do{if(f){l=k>>>3;q=d[g+(l|57376)|0]<<8|d[g+(l|57344)|0]}else{if((k-48|0)>>>0>=184){q=0;break}q=e[4876580]|0}}while(0);l=j-q|0;r=(l>>>21&512)+l|0;if((a[14115080]|0)==0){s=p;t=o;u=r;v=k}else{s=p>>>4^1;t=o>>>5^1;u=248-r|0;v=248-k|0}r=v-16|0;l=u-8|0;do{if(!((u-1|0)>>>0>262|r>>>0>223)){w=(s|0)!=0;if((t|0)==0){if(w){Sl(b,m,l,r,n,4,0,h);break}else{Sj(b,m,l,r,n,4,0,h);break}}else{if(w){Sp(b,m,l,r,n,4,0,h);break}else{Sn(b,m,l,r,n,4,0,h);break}}}}while(0);i=i+1|0;}while((i|0)<1984);if(!f){f=252;do{i=a[g+(f+59649)|0]|0;if(i<<24>>24!=0){h=d[g+(f+59651)|0]|0;b=(d[g+(f+59650)|0]|0)-(h<<1&256)|0;t=i&255;i=h&16;s=h&32;if((a[14115080]|0)==0){x=s;y=i;z=240-t|0;A=b}else{x=s>>>5^1;y=i>>>4^1;z=t;A=240-b|0}bng(h<<2&256|d[g+(f+59648)|0],A-8|0,z-16|0,h<<4&240,y,x)}f=f-4|0;}while((f|0)>-1);B=c[3530156]|0;R8(B);return 0}f=d[9721960]<<5&256^53504;x=0;do{y=a[g+((x|3)+f)|0]|0;if(y<<24>>24!=0){z=d[g+((x|1)+f)|0]|0;A=(d[g+((x|2)+f)|0]|0)-(z<<1&256)|0;h=y&255;y=z&16;b=z&32;if((a[14115080]|0)==0){C=b;D=y;E=h;F=A}else{C=b>>>5^1;D=y>>>4^1;E=240-h|0;F=240-A|0}bng(z<<2&256|d[g+(x+f)|0],F-8|0,E-16|0,z<<4&240,D,C)}x=x+4|0;}while((x|0)<192);B=c[3530156]|0;R8(B);return 0}function bm4(a,d){a=a|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;i=i+112|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;l=e+80|0;m=e+96|0;if((d|0)!=0){c[d>>2]=169589}if((a&96|0)==0){i=e;return 0}gGz(m|0,0,12);c[m>>2]=(c[2426614]|0)+49152;c[m+4>>2]=16384;c[m+12>>2]=162152;gj[c[2076592]&4095](m)|0;fw$(a);gGz(l|0,0,12);c[l>>2]=14113912;c[l+4>>2]=1;c[l+12>>2]=86520;gj[c[2076592]&4095](l)|0;gGz(k|0,0,12);c[k>>2]=14114448;c[k+4>>2]=1;c[k+12>>2]=84696;gj[c[2076592]&4095](k)|0;gGz(j|0,0,12);c[j>>2]=14115080;c[j+4>>2]=1;c[j+12>>2]=142288;gj[c[2076592]&4095](j)|0;gGz(h|0,0,12);c[h>>2]=9756992;c[h+4>>2]=4;c[h+12>>2]=81576;gj[c[2076592]&4095](h)|0;gGz(g|0,0,12);c[g>>2]=9753160;c[g+4>>2]=2;c[g+12>>2]=79464;gj[c[2076592]&4095](g)|0;gGz(f|0,0,12);c[f>>2]=9721960;c[f+4>>2]=1;c[f+12>>2]=77256;gj[c[2076592]&4095](f)|0;f=c[2439330]|0;g=(f|0)==0;if(!g){h=f;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];h=c[3528484]|0;c[2076596]=h;j=c[2417276]|0;c[3541536]=j;c[1836236]=0;k=c[2439248]|0;l=c[2426614]|0;c[f+1068>>2]=l+(k+65536);c[f+1072>>2]=l+(k+65792);c[f+1076>>2]=l+(k+66048);c[f+1080>>2]=l+(k+66304);c[f+1084>>2]=l+(k+66560);c[f+1088>>2]=l+(k+66816);c[f+1092>>2]=l+(k+67072);c[f+1096>>2]=l+(k+67328);k=c[2439248]|0;a=l+(k+65536)|0;c[f+3116>>2]=a;c[f+4140>>2]=a;a=l+(k+65792)|0;c[f+3120>>2]=a;c[f+4144>>2]=a;a=l+(k+66048)|0;c[f+3124>>2]=a;c[f+4148>>2]=a;a=l+(k+66304)|0;c[f+3128>>2]=a;c[f+4152>>2]=a;a=l+(k+66560)|0;c[f+3132>>2]=a;c[f+4156>>2]=a;a=l+(k+66816)|0;c[f+3136>>2]=a;c[f+4160>>2]=a;a=l+(k+67072)|0;c[f+3140>>2]=a;c[f+4164>>2]=a;a=l+(k+67328)|0;c[f+3144>>2]=a;c[f+4168>>2]=a;if(!g){g=f;gGC(g|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=h;c[2417276]=j;c[1836236]=-1;i=e;return 0}function bm5(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2361916+(b*112|0)>>2];c[a+104>>2]=c[2361920+(b*112|0)>>2];c[a+108>>2]=c[2361924+(b*112|0)>>2];d=0;return d|0}function bm6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=2361816+(b*112|0);e=0;return e|0}function bm7(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4703500+(b*112|0)>>2];c[a+104>>2]=c[4703504+(b*112|0)>>2];c[a+108>>2]=c[4703508+(b*112|0)>>2];d=0;return d|0}function bm8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=4703400+(b*112|0);e=0;return e|0}function bm9(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1546688+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function bna(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>70){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4704632+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function bnb(){c[2385616]=1;return bm0()|0}function bnc(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2566436+(b*112|0)>>2];c[a+104>>2]=c[2566440+(b*112|0)>>2];c[a+108>>2]=c[2566444+(b*112|0)>>2];d=0;return d|0}function bnd(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=2566336+(b*112|0);e=0;return e|0}function bne(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>80){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=2567232+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function bnf(){c[2385616]=2;return bm0()|0}function bng(e,f,g,h,i,j){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;k=h|256;h=(c[2424842]|0)+(e<<8)|0;e=(i|0)!=0;if((j|0)==0){j=g+16|0;if(e){i=f+15|0;l=c[2113068]|0;m=c[2113070]|0;n=c[2424794]|0;o=c[2112926]|0;p=h;q=g;while(1){r=(m|0)>(q|0);s=ag(l,q)|0;t=p;u=i;do{v=d[t]|k;do{if((u|q|0)>=0){if(!((l|0)>(u|0)&r)){break}if((a[n+v|0]|0)==0){break}b[o+(s+u<<1)>>1]=v&65535}}while(0);u=u-1|0;t=t+1|0;}while((u|0)>=(f|0));u=q+1|0;if((u|0)<(j|0)){p=t;q=u}else{break}}return}else{q=f+16|0;p=f+1|0;o=((q|0)>(p|0)?q:p)-f|0;p=c[2113068]|0;n=c[2113070]|0;l=c[2424794]|0;i=c[2112926]|0;m=h;u=g;while(1){s=(n|0)>(u|0);r=ag(p,u)|0;v=m;w=f;while(1){x=d[v]|k;do{if((w|u|0)>=0){if(!((p|0)>(w|0)&s)){break}if((a[l+x|0]|0)==0){break}b[i+(r+w<<1)>>1]=x&65535}}while(0);x=w+1|0;if((x|0)<(q|0)){v=v+1|0;w=x}else{break}}w=u+1|0;if((w|0)<(j|0)){m=m+o|0;u=w}else{break}}return}}else{u=g+15|0;if(e){e=f+15|0;o=c[2113068]|0;m=c[2113070]|0;j=c[2424794]|0;q=c[2112926]|0;i=h;l=u;while(1){p=(m|0)>(l|0);n=ag(o,l)|0;w=i;v=e;do{r=d[w]|k;do{if((v|l|0)>=0){if(!((o|0)>(v|0)&p)){break}if((a[j+r|0]|0)==0){break}b[q+(n+v<<1)>>1]=r&65535}}while(0);v=v-1|0;w=w+1|0;}while((v|0)>=(f|0));v=l-1|0;if((v|0)<(g|0)){break}else{i=w;l=v}}return}else{l=f+16|0;i=f+1|0;q=((l|0)>(i|0)?l:i)-f|0;i=c[2113068]|0;j=c[2113070]|0;o=c[2424794]|0;e=c[2112926]|0;m=h;h=u;while(1){u=(j|0)>(h|0);v=ag(i,h)|0;n=m;p=f;while(1){r=d[n]|k;do{if((p|h|0)>=0){if(!((i|0)>(p|0)&u)){break}if((a[o+r|0]|0)==0){break}b[e+(v+p<<1)>>1]=r&65535}}while(0);r=p+1|0;if((r|0)<(l|0)){n=n+1|0;p=r}else{break}}p=h-1|0;if((p|0)<(g|0)){break}else{m=m+q|0;h=p}}return}}}function bnh(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=b&65535;if((e|0)==24460){a[c[3528348]|0]=d;a[14125144]=-1;a[9706117]=1;return}else if((e|0)==24456){b=d&255;f=b&32;a[c[2443948]|0]=f&255;if((f|0)==0){f=c[3531080]|0;c[2424908]=f;c[2425164]=f;c[2425420]=f;g=f+256|0;c[2424909]=g;c[2425165]=g;c[2425421]=g;h=f;i=f+512|0}else{f=c[2387256]|0;c[2424908]=f;c[2425164]=f;c[2425420]=f;g=f+256|0;c[2424909]=g;c[2425165]=g;c[2425421]=g;h=f;i=f+512|0}c[2424910]=i;c[2425166]=i;c[2425422]=i;i=h+768|0;c[2424911]=i;c[2425167]=i;c[2425423]=i;c[3541230]=b&64;return}else{if((e&49152|0)!=16384){return}blF(e&16383,d&255);return}}function bni(b){b=b|0;var c=0,d=0;c=b&65535;L1682:do{switch(c|0){case 24452:{d=a[9635584]|0;break};case 24451:{d=a[9635585]|0;break};case 24456:{d=0;break};case 24448:{d=a[9635586]|0;break};case 24450:{d=a[9550849]|0;break};case 24449:{d=a[9550848]|0;break};default:{if((c&49152|0)!=16384){d=0;break L1682}d=blE(c&16383)|0}}}while(0);return d|0}function bnj(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((e&65520|0)==57344){TI(0,e&15,d&255);return}if((e|0)==40960){c[2113304]=d&255;return}else if((e|0)==40961){e=c[2113304]|0;a[14168504+e|0]=d;mv(0,e,d&255);return}else{return}}function bnk(b){b=b|0;var e=0,f=0,g=0,h=0;e=b&65535;if((e&65520|0)==57344){b=e&15;c[2424878]=9681232;c[2426622]=9622928;if(!((b|0)==11|(b|0)==5)){f=0;return f|0}g=(b>>>0)/6|0;b=g*6|0;h=(d[b+9681280|0]|0)<<16&65536|(d[b+9681279|0]|0)<<8|(d[b+9681278|0]|0)|c[9681260+(g<<2)>>2];c[9681244+(g<<2)>>2]=h;if(h>>>0>=(c[2405735]|0)>>>0){f=0;return f|0}c[9681268+(g<<2)>>2]=1;c[9681236+(g<<2)>>2]=0;f=0;return f|0}else{if((e|0)==40960|(e|0)==40961){f=c[(c[3531464]|0)+4240>>2]&255;return f|0}else if((e|0)==49152){a[9706117]=0;f=a[c[3528348]|0]|0;return f|0}else{f=0;return f|0}}return 0}function bnl(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5954964+(b*112|0)>>2];c[a+104>>2]=c[5954968+(b*112|0)>>2];c[a+108>>2]=c[5954972+(b*112|0)>>2];d=0;return d|0}function bnm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=5954864+(b*112|0);e=0;return e|0}function bnn(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4291056+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function bno(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>52){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6443760+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function bnp(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0;e=i;i=i+1440|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;B=e+1200|0;C=e+1312|0;D=e+1320|0;E=e+1432|0;c[2415070]=0;c[2387366]=0;c[2385980]=262144;c[3530920]=327680;c[3530684]=2424832;c[2439888]=4521984;c[2439852]=8716288;c[2386680]=12910592;c[3530154]=13172736;c[2414778]=13174784;c[3531080]=13174784;c[2387390]=13175808;c[2387256]=13182976;c[2386132]=13184e3;c[3528348]=13186048;c[2443948]=13186049;c[2438166]=13186050;c[2411838]=13186051;F=0;while(1){if((F|0)>=1024){break}G=9638528+(F<<2)|0;if((c[G>>2]|0)==0){H=1343;break}else{F=F+1|0}}do{if((H|0)==1343){F=gGq(13186051)|0;c[G>>2]=F;if((F|0)==0){break}c[2415070]=F;gGz(F|0,0,13186051);c[2387366]=F;c[2385980]=F+262144;c[3530920]=F+327680;c[3530684]=F+2424832;c[2439888]=F+4521984;c[2439852]=F+8716288;c[2386680]=F+12910592;c[3530154]=F+13172736;I=F+13174784|0;c[2414778]=I;c[3531080]=I;c[2387390]=F+13175808;c[2387256]=F+13182976;c[2386132]=F+13184e3;c[3528348]=F+13186048;c[2443948]=F+13186049;c[2438166]=F+13186050;I=F+13186051|0;c[2411838]=I;c[2414386]=I;I=F+196608|0;if((c[3542200]|0)==0){J=1;i=e;return J|0}F=D+108|0;c[F>>2]=0;K=D+100|0;c[K>>2]=0;L=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[L&16383](D,0)|0;do{if((c[F>>2]|0)!=0){L=c[K>>2]|0;c[E>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](E,0,0)|0;if((L|0)<1){J=1;i=e;return J|0}if((gzL(I,0,0)|0)==0){break}else{J=1}i=e;return J|0}}while(0);I=(c[2387366]|0)+65536|0;if((c[3542200]|0)==0){J=1;i=e;return J|0}K=B+108|0;c[K>>2]=0;F=B+100|0;c[F>>2]=0;L=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[L&16383](B,1)|0;do{if((c[K>>2]|0)!=0){L=c[F>>2]|0;c[C>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](C,1,0)|0;if((L|0)<1){J=1;i=e;return J|0}if((gzL(I,0,1)|0)==0){break}else{J=1}i=e;return J|0}}while(0);I=c[2387366]|0;F=I+32768|0;K=I+229376|0;gGC(F|0,K|0,32768)|0;K=c[2385980]|0;if((c[3542200]|0)==0){J=1;i=e;return J|0}F=z+108|0;c[F>>2]=0;I=z+100|0;c[I>>2]=0;L=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[L&16383](z,2)|0;do{if((c[F>>2]|0)!=0){L=c[I>>2]|0;c[A>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](A,2,0)|0;if((L|0)<1){J=1;i=e;return J|0}if((gzL(K,0,2)|0)==0){break}else{J=1}i=e;return J|0}}while(0);K=c[3530920]|0;if((c[3542200]|0)==0){J=1;i=e;return J|0}I=x+108|0;c[I>>2]=0;F=x+100|0;c[F>>2]=0;L=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[L&16383](x,3)|0;do{if((c[I>>2]|0)!=0){L=c[F>>2]|0;c[y>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](y,3,0)|0;if((L|0)<1){J=1;i=e;return J|0}if((gzL(K,0,3)|0)==0){break}else{J=1}i=e;return J|0}}while(0);K=(c[3530920]|0)+524288|0;if((c[3542200]|0)==0){J=1;i=e;return J|0}F=v+108|0;c[F>>2]=0;I=v+100|0;c[I>>2]=0;L=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[L&16383](v,4)|0;do{if((c[F>>2]|0)!=0){L=c[I>>2]|0;c[w>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](w,4,0)|0;if((L|0)<1){J=1;i=e;return J|0}if((gzL(K,0,4)|0)==0){break}else{J=1}i=e;return J|0}}while(0);K=(c[3530920]|0)+1048576|0;if((c[3542200]|0)==0){J=1;i=e;return J|0}I=t+108|0;c[I>>2]=0;F=t+100|0;c[F>>2]=0;L=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[L&16383](t,5)|0;do{if((c[I>>2]|0)!=0){L=c[F>>2]|0;c[u>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](u,5,0)|0;if((L|0)<1){J=1;i=e;return J|0}if((gzL(K,0,5)|0)==0){break}else{J=1}i=e;return J|0}}while(0);K=(c[3530920]|0)+1572864|0;if((c[3542200]|0)==0){J=1;i=e;return J|0}F=r+108|0;c[F>>2]=0;I=r+100|0;c[I>>2]=0;L=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[L&16383](r,6)|0;do{if((c[F>>2]|0)!=0){L=c[I>>2]|0;c[s>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](s,6,0)|0;if((L|0)<1){J=1;i=e;return J|0}if((gzL(K,0,6)|0)==0){break}else{J=1}i=e;return J|0}}while(0);K=c[3530684]|0;if((c[3542200]|0)==0){J=1;i=e;return J|0}I=p+108|0;c[I>>2]=0;F=p+100|0;c[F>>2]=0;L=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[L&16383](p,7)|0;do{if((c[I>>2]|0)!=0){L=c[F>>2]|0;c[q>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](q,7,0)|0;if((L|0)<1){J=1;i=e;return J|0}if((gzL(K,0,7)|0)==0){break}else{J=1}i=e;return J|0}}while(0);K=(c[3530684]|0)+524288|0;if((c[3542200]|0)==0){J=1;i=e;return J|0}F=n+108|0;c[F>>2]=0;I=n+100|0;c[I>>2]=0;L=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[L&16383](n,8)|0;do{if((c[F>>2]|0)!=0){L=c[I>>2]|0;c[o>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](o,8,0)|0;if((L|0)<1){J=1;i=e;return J|0}if((gzL(K,0,8)|0)==0){break}else{J=1}i=e;return J|0}}while(0);K=(c[3530684]|0)+1048576|0;if((c[3542200]|0)==0){J=1;i=e;return J|0}I=l+108|0;c[I>>2]=0;F=l+100|0;c[F>>2]=0;L=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[L&16383](l,9)|0;do{if((c[I>>2]|0)!=0){L=c[F>>2]|0;c[m>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](m,9,0)|0;if((L|0)<1){J=1;i=e;return J|0}if((gzL(K,0,9)|0)==0){break}else{J=1}i=e;return J|0}}while(0);K=(c[3530684]|0)+1572864|0;if((c[3542200]|0)==0){J=1;i=e;return J|0}F=j+108|0;c[F>>2]=0;I=j+100|0;c[I>>2]=0;L=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[L&16383](j,10)|0;do{if((c[F>>2]|0)!=0){L=c[I>>2]|0;c[k>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](k,10,0)|0;if((L|0)<1){J=1;i=e;return J|0}if((gzL(K,0,10)|0)==0){break}else{J=1}i=e;return J|0}}while(0);K=c[2386680]|0;if((c[3542200]|0)==0){J=1;i=e;return J|0}I=f+108|0;c[I>>2]=0;F=f+100|0;c[F>>2]=0;L=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[L&16383](f,11)|0;do{if((c[I>>2]|0)!=0){L=c[F>>2]|0;c[g>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](g,11,0)|0;if((L|0)<1){J=1;i=e;return J|0}if((gzL(K,0,11)|0)==0){break}else{J=1}i=e;return J|0}}while(0);K=c[3530920]|0;blG(K,1048576);F=c[3530684]|0;blG(F,1048576);I=c[2439888]|0;L=0;do{M=L<<6;gGz(I+M|0,0,64);N=L<<8;O=0;do{P=1<<3-O;Q=(c[611632+(O<<2)>>2]|0)+N|0;R=0;do{S=Q+(c[3946808+(R<<2)>>2]|0)|0;T=(R<<3)+M|0;U=0;do{V=S+(c[6669416+(U<<2)>>2]|0)|0;if(((d[K+((V|0)/8|0)|0]|0)&128>>>((V&7)>>>0)|0)!=0){V=I+(T+U)|0;a[V]=(d[V]|0|P)&255}U=U+1|0;}while((U|0)<8);R=R+1|0;}while((R|0)<8);O=O+1|0;}while((O|0)<4);L=L+1|0;}while((L|0)<65536);L=c[2439852]|0;I=0;do{K=I<<8;gGz(L+K|0,0,256);O=I<<10;M=0;do{N=1<<3-M;R=(c[611400+(M<<2)>>2]|0)+O|0;P=0;do{Q=R+(c[3946808+(P<<2)>>2]|0)|0;U=(P<<4)+K|0;T=0;do{S=Q+(c[6669416+(T<<2)>>2]|0)|0;if(((d[F+((S|0)/8|0)|0]|0)&128>>>((S&7)>>>0)|0)!=0){S=L+(U+T)|0;a[S]=(d[S]|0|N)&255}T=T+1|0;}while((T|0)<16);P=P+1|0;}while((P|0)<16);M=M+1|0;}while((M|0)<4);I=I+1|0;}while((I|0)<16384);c[2410674]=1748;gGz(9699632,0,3072);I=c[2427044]|0;c[9681616+(I<<3)>>2]=715288;c[9681620+(I<<3)>>2]=0;c[2427044]=I+1;c[363094]=0;I=c[3531080]|0;c[2424908]=I;c[2425164]=I;c[2425420]=I;L=I+256|0;c[2424909]=L;c[2425165]=L;c[2425421]=L;L=I+512|0;c[2424910]=L;c[2425166]=L;c[2425422]=L;L=I+768|0;c[2424911]=L;c[2425167]=L;c[2425423]=L;L=c[2387390]|0;I=0;F=0;while(1){M=F+4|0;K=L+(F<<8)|0;c[9699632+(M<<2)>>2]=K;c[9700656+(M<<2)>>2]=K;c[9701680+(M<<2)>>2]=K;K=I+1&65535;if((K&65535)<28){I=K;F=K&65535}else{break}}F=c[2387366]|0;I=0;L=0;while(1){K=L+32|0;M=F+((L<<8)+65536)|0;c[9699632+(K<<2)>>2]=M;c[9701680+(K<<2)>>2]=M;M=I+1&65535;if((M&65535)<32){I=M;L=M&65535}else{W=0;X=0;break}}while(1){L=X+128|0;I=F+((X<<8)+32768)|0;c[9699632+(L<<2)>>2]=I;c[9701680+(L<<2)>>2]=I;I=W+1&65535;if((I&65535)<128){W=I;X=I&65535}else{break}}c[2444172]=1502;c[3528598]=52;c[2410675]=1080;c[363094]=-1;fwR(0);F=c[2439330]|0;I=(F|0)==0;if(!I){L=F;gGC(9706056,L|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];L=c[3528484]|0;c[2076596]=L;M=c[2417276]|0;c[3541536]=M;c[1836236]=0;K=c[2385980]|0;O=0;P=0;while(1){c[F+76+(P<<2)>>2]=K+(P<<8);N=O+1&65535;if((N&65535)>127){Y=0;Z=0;break}else{O=N;P=N&65535}}while(1){P=K+(Z<<8)|0;c[F+76+(Z+512<<2)>>2]=P;c[F+76+(Z+768<<2)>>2]=P;P=Y+1&65535;if((P&65535)>127){break}else{Y=P;Z=P&65535}}K=c[2386132]|0;c[F+588>>2]=K;P=K+256|0;c[F+592>>2]=P;O=K+512|0;c[F+596>>2]=O;N=K+768|0;c[F+600>>2]=N;R=K+1024|0;c[F+604>>2]=R;T=K+1280|0;c[F+608>>2]=T;U=K+1536|0;c[F+612>>2]=U;Q=K+1792|0;c[F+616>>2]=Q;c[F+1612>>2]=K;c[F+1616>>2]=P;c[F+1620>>2]=O;c[F+1624>>2]=N;c[F+1628>>2]=R;c[F+1632>>2]=T;c[F+1636>>2]=U;c[F+1640>>2]=Q;c[F+2636>>2]=K;c[F+3660>>2]=K;c[F+2640>>2]=P;c[F+3664>>2]=P;c[F+2644>>2]=O;c[F+3668>>2]=O;c[F+2648>>2]=N;c[F+3672>>2]=N;c[F+2652>>2]=R;c[F+3676>>2]=R;c[F+2656>>2]=T;c[F+3680>>2]=T;c[F+2660>>2]=U;c[F+3684>>2]=U;c[F+2664>>2]=Q;c[F+3688>>2]=Q;c[F+4184>>2]=3126;c[F+4180>>2]=1528;if(!I){Q=F;gGC(Q|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=L;c[2417276]=M;c[1836236]=-1;Q=c[3530920]|0;U=0;while(1){if((U|0)>=1024){_=0;break}$=9638528+(U<<2)|0;if((c[$>>2]|0)==0){H=1428;break}else{U=U+1|0}}do{if((H|0)==1428){U=gGq(24576)|0;c[$>>2]=U;if((U|0)==0){_=0;break}gGz(U|0,0,24576);_=U}}while(0);c[3529062]=_;c[2438700]=2097151;c[3529060]=Q;a[7461784]=1;U=9726816;c[U>>2]=0;c[U+4>>2]=0;U=9726800;c[U>>2]=0;c[U+4>>2]=0;c[2429638]=0;c[2437692]=86;c[2431704]=8;c[2431700]=0;c[2431705]=8;c[2431701]=0;c[2431706]=8;c[2431702]=0;U=c[3530684]|0;c[2438136]=0;M=0;while(1){if((M|0)>=1024){aa=0;break}ab=9638528+(M<<2)|0;if((c[ab>>2]|0)==0){H=1433;break}else{M=M+1|0}}do{if((H|0)==1433){M=gGq(1024)|0;c[ab>>2]=M;if((M|0)==0){aa=0;break}gGz(M|0,0,1024);aa=M}}while(0);c[3529066]=aa;c[2438702]=2097151;c[3529064]=U;a[7461792]=1;c[2437694]=146;c[2438136]=8;M=a[9680]|0;Q=M?32e3:0;if(M){if(a[9624]|0){M=Q*3|0;L=55930;while(1){if((L|0)>(M|0)){L=L>>1}else{ac=1222;ad=L;break}}}else{ac=2462;ad=Q}c[2429380]=ad;c[3542124]=ac;mw(3579545,ad);L=gGq(262144)|0;c[2406684]=L;gGz(L|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(3579545,11025)}c[(c[3531464]|0)+44348>>2]=1634;h[745421]=.6;c[2436794]=3;h[745420]=.6;c[2436792]=3;TJ(0,c[2386680]|0,262144);c[2424878]=9681232;c[2405736]=1056;h[1202869]=.2;c[2405742]=3;c[2426622]=9622928;h[1202870]=.2;c[2405743]=3;L=c[642608+(c[2436]<<2)>>2]|0;M=c[L+128>>2]|0;if((c[L+52>>2]&4|0)==0){c[2113068]=M;U=c[L+132>>2]|0;c[2113070]=U;c[2443814]=M;c[2440436]=U;ae=M;af=U}else{c[2113070]=M;U=c[L+132>>2]|0;c[2113068]=U;c[2440436]=M;c[2443814]=U;ae=U;af=M}M=ag(ae<<1,af)|0;U=gGq(M)|0;c[2112926]=U;if((U|0)!=0){gGz(U|0,0,M|0)}a[9624888]=0;M=c[2414778]|0;gGz(M|0,0,(c[2411838]|0)-M|0);c[363094]=0;c[2410673]=0;a[9642688]=0;a[9642689]=0;a[9642682]=0;a[9642683]=0;c[2410665]=0;a[9642680]=a[9642680]|80;M=c[2425163]|0;do{if((M|0)==0){U=c[3528598]|0;if((U|0)==0){ah=0;ai=0;break}L=gj[U&4095](-2)|0;U=c[2425163]|0;F=(L&255)<<8;if((U|0)!=0){aj=U;ak=F;H=1450;break}U=c[3528598]|0;if((U|0)==0){ah=0;ai=F;break}ah=gj[U&4095](-1)|0;ai=F}else{aj=M;ak=(d[M+254|0]|0)<<8;H=1450}}while(0);if((H|0)==1450){ah=a[aj+255|0]|0;ai=ak}c[2410662]=ah&255|ai;c[363094]=-1;M=c[2439330]|0;Q=(M|0)==0;if(!Q){F=M;gGC(9706056,F|0,76)|0}F=c[2438118]|0;c[2433530]=F;U=c[3528484]|0;c[2076596]=U;L=c[2417276]|0;c[3541536]=L;c[1836236]=0;gGz(9706056,0,76);if(!Q){Q=M;gGC(Q|0,9706056,76)|0}c[2438118]=F;c[3528484]=U;c[2417276]=L;c[1836236]=-1;mx(0);blH();J=0;i=e;return J|0}}while(0);c[2415070]=0;J=1;i=e;return J|0}function bnq(){var a=0,b=0,d=0,e=0;c[2113070]=0;c[2113068]=0;a=c[2112926]|0;if((a|0)!=0){gGr(a);c[2112926]=0}blI();c[2444172]=0;c[3528598]=0;fwZ();a=c[2424800]|0;if((a|0)!=0){gGr(a);c[2424800]=0}a=c[2418166]|0;if((a|0)!=0){gGr(a);c[2418166]=0}a=c[3531464]|0;c[a+44344>>2]=0;c[a+44348>>2]=0;if((a|0)!=0){gGr(a);c[3531464]=0}a=c[2406684]|0;if((a|0)!=0){gGr(a);c[2406684]=0}a=c[2415070]|0;b=0;while(1){if((b|0)>=1024){d=1513;break}e=9638528+(b<<2)|0;if((c[e>>2]|0)==(a|0)){break}else{b=b+1|0}}if((d|0)==1513){c[2415070]=0;return 0}gGr(a);c[e>>2]=0;c[2415070]=0;return 0}function bnr(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((a[9624888]|0)!=0){a[9624888]=0;e=c[2414778]|0;gGz(e|0,0,(c[2411838]|0)-e|0);c[363094]=0;c[2410673]=0;a[9642688]=0;a[9642689]=0;a[9642682]=0;a[9642683]=0;c[2410665]=0;a[9642680]=a[9642680]|80;e=c[2425163]|0;do{if((e|0)==0){f=c[3528598]|0;if((f|0)==0){g=0;h=0;break}i=gj[f&4095](-2)|0;f=c[2425163]|0;j=(i&255)<<8;if((f|0)!=0){k=f;l=j;m=1519;break}f=c[3528598]|0;if((f|0)==0){g=0;h=j;break}g=gj[f&4095](-1)|0;h=j}else{k=e;l=d[e+254|0]<<8;m=1519}}while(0);if((m|0)==1519){g=a[k+255|0]|0;h=l}c[2410662]=g&255|h;c[363094]=-1;h=c[2439330]|0;g=(h|0)==0;if(!g){l=h;gGC(9706056,l|0,76)|0}l=c[2438118]|0;c[2433530]=l;k=c[3528484]|0;c[2076596]=k;m=c[2417276]|0;c[3541536]=m;c[1836236]=0;gGz(9706056,0,76);if(!g){g=h;gGC(g|0,9706056,76)|0}c[2438118]=l;c[3528484]=k;c[2417276]=m;c[1836236]=-1;mx(0);blH()}b[4775424]=-1;m=0;k=-1;l=-1;g=a[9635586]|0;do{k=((a[9634232+m|0]&1)<<m^k&255)&255;l=((a[9631992+m|0]&1)<<m^l&255)&255;g=((a[9629912+m|0]&1)<<m^g&255)&255;m=m+1|0;}while((m|0)<8);a[9550848]=k;a[9550849]=l;a[9635586]=g;if((k&3)==0){g=k|3;a[9550848]=g;n=g}else{n=k}if((n&12)==0){a[9550848]=n|12}if((l&3)==0){n=l|3;a[9550849]=n;o=n}else{o=l}if((o&12)==0){a[9550849]=o|12}c[2410673]=0;o=c[2385548]|0;if((o|0)>0){gGz(9752472,0,((o|0)>1?o<<2:4)|0)}c[2433530]=0;o=a[9688]|0?534:0;l=c[2439330]|0;if((l|0)!=0){n=l;gGC(9706056,n|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;c[363094]=0;n=0;l=0;k=0;g=0;L2035:while(1){m=l;h=k;e=g;do{if((e|0)>=(o|0)){break L2035}e=e+1|0;h=(fNF((e*187|0)-h|0)|0)+h|0;j=(e*111|0)-m|0;do{if((j|0)<1){p=0}else{if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){f=gfc(j)|0;c[2433530]=(c[2433530]|0)+f;p=f;break}else{c[2433530]=(c[2433530]|0)+j;p=j;break}}}while(0);m=p+m|0;q=c[2112964]|0;}while((q|0)==0);j=a[9688]&1;f=q+(n<<1<<1)|0;gg[c[3542124]&4095](f,j);TH(0,f,j);n=j+n|0;l=m;k=h;g=e}if((c[3541236]|0)!=0){fNE(0,1);fNF(0)|0;a[9642682]=0;fNF(0)|0}g=c[2112964]|0;do{if((g|0)!=0){k=a[9688]|0?534:0;l=k-n|0;if((k|0)==(n|0)){break}k=g+(n<<1<<1)|0;gg[c[3542124]&4095](k,l);TH(0,k,l)}}while(0);c[363094]=-1;n=c[1836236]|0;g=c[9757320+(n<<2)>>2]|0;if((g|0)!=0){l=g;gGC(l|0,9706056,76)|0}c[9752472+(n<<2)>>2]=c[2433530];c[14113936+(n<<2)>>2]=c[2076596];c[9669104+(n<<2)>>2]=c[3541536];c[1836236]=-1;if((c[2112968]|0)==0){return 0}bns()|0;return 0}function bns(){var d=0,e=0,f=0,g=0;if((a[9547888]|0)!=0){d=c[3530154]|0;e=c[2387256]|0;f=0;do{g=ga(b[e+(f<<1)>>1]|0)|0;c[d+(f<<2)>>2]=((g&65535)>>>10<<3&65535)>>>3&31|((g&255)<<3&255)<<8|(((g&65535)>>>5<<3&255|(g&65535)>>>7&4)&255)<<3&2016;f=f+1|0;}while((f|0)<512)}bpj();f=ag(c[2113070]|0,c[2113068]|0)|0;if((f|0)>0){d=c[2112926]|0;e=0;do{b[d+(e<<1)>>1]=64;e=e+1|0;}while((e|0)<(f|0))}bpl(c[2439852]|0,3);bpk(1,0,c[2439888]|0);bpl(c[2439852]|0,2);bpk(2,0,c[2439888]|0);bpl(c[2439852]|0,1);bpk(0,0,c[2439888]|0);bpl(c[2439852]|0,0);bpl(c[2439852]|0,4);bpl(c[2439852]|0,5);R8(c[3530154]|0);return 0}function bnt(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;f=i;i=i+144|0;g=f|0;h=f+16|0;j=f+48|0;k=f+64|0;l=f+80|0;m=f+96|0;n=f+112|0;o=f+128|0;p=(e|0)==0;if(!p){c[e>>2]=169732}if((b&96|0)!=0){gGz(o|0,0,12);q=c[2414778]|0;c[o>>2]=q;c[o+4>>2]=(c[2411838]|0)-q;c[o+12>>2]=162152;q=c[2076592]|0;gj[q&4095](o)|0;o=c[2410674]|0;q=c[2410675]|0;if((b&64|0)==0){c[2410674]=o;c[2410675]=q;fw$(b);r=g;s=h|0}else{gGz(n|0,0,12);c[n>>2]=9642648;c[n+4>>2]=56;c[n+12>>2]=163840;t=c[2076592]|0;gj[t&4095](n)|0;gGz(m|0,0,12);c[m>>2]=9707480;c[m+4>>2]=2;c[m+12>>2]=501096;n=c[2076592]|0;gj[n&4095](m)|0;gGz(l|0,0,12);c[l>>2]=9707480;c[l+4>>2]=4;c[l+12>>2]=385184;m=c[2076592]|0;gj[m&4095](l)|0;c[2410674]=o;c[2410675]=q;fw$(b);gGz(k|0,0,12);c[k>>2]=8453216;c[k+4>>2]=4;c[k+12>>2]=107480;q=c[2076592]|0;gj[q&4095](k)|0;gGz(j|0,0,12);c[j>>2]=14168504;c[j+4>>2]=256;c[j+12>>2]=476464;k=c[2076592]|0;gj[k&4095](j)|0;if((b&2|0)==0){u=g;v=h|0}else{j=0;do{mv(0,j,d[14168504+j|0]|0);j=j+1|0;}while((j|0)<256);u=g;v=h|0}if(!p){c[e>>2]=169619}e=h|0;cC(e|0,170224,(h=i,i=i+8|0,c[h>>2]=0,h)|0)|0;i=h;c[g>>2]=9699512;c[g+4>>2]=64;c[g+8>>2]=0;c[g+12>>2]=e;e=c[2076592]|0;gj[e&4095](g)|0;r=u;s=v}blJ(b)}if((b&2|0)==0){i=f;return 0}c[363094]=0;if((a[c[2443948]|0]&32)==0){b=c[3531080]|0;c[2424908]=b;c[2425164]=b;c[2425420]=b;v=b+256|0;c[2424909]=v;c[2425165]=v;c[2425421]=v;w=b;x=b+512|0}else{b=c[2387256]|0;c[2424908]=b;c[2425164]=b;c[2425420]=b;v=b+256|0;c[2424909]=v;c[2425165]=v;c[2425421]=v;w=b;x=b+512|0}c[2424910]=x;c[2425166]=x;c[2425422]=x;x=w+768|0;c[2424911]=x;c[2425167]=x;c[2425423]=x;x=c[2387366]|0;w=((d[c[2438166]|0]|0)<<13&253952)+65536|0;b=0;v=0;while(1){s=v+32|0;u=x+(w+(v<<8))|0;c[9699632+(s<<2)>>2]=u;c[9701680+(s<<2)>>2]=u;u=b+1&65535;if((u&65535)<32){b=u;v=u&65535}else{break}}c[363094]=-1;i=f;return 0}function bnu(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4846580+(b*112|0)>>2];c[a+104>>2]=c[4846584+(b*112|0)>>2];c[a+108>>2]=c[4846588+(b*112|0)>>2];d=0;return d|0}function bnv(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=4846480+(b*112|0);e=0;return e|0}function bnw(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4845124+(b*112|0)>>2];c[a+104>>2]=c[4845128+(b*112|0)>>2];c[a+108>>2]=c[4845132+(b*112|0)>>2];d=0;return d|0}function bnx(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=4845024+(b*112|0);e=0;return e|0}function bny(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4840756+(b*112|0)>>2];c[a+104>>2]=c[4840760+(b*112|0)>>2];c[a+108>>2]=c[4840764+(b*112|0)>>2];d=0;return d|0}function bnz(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=4840656+(b*112|0);e=0;return e|0}function bnA(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4842212+(b*112|0)>>2];c[a+104>>2]=c[4842216+(b*112|0)>>2];c[a+108>>2]=c[4842220+(b*112|0)>>2];d=0;return d|0}function bnB(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=4842112+(b*112|0);e=0;return e|0}function bnC(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3164980+(b*112|0)>>2];c[a+104>>2]=c[3164984+(b*112|0)>>2];c[a+108>>2]=c[3164988+(b*112|0)>>2];d=0;return d|0}function bnD(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=3164880+(b*112|0);e=0;return e|0}function bnE(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4843668+(b*112|0)>>2];c[a+104>>2]=c[4843672+(b*112|0)>>2];c[a+108>>2]=c[4843676+(b*112|0)>>2];d=0;return d|0}function bnF(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=4843568+(b*112|0);e=0;return e|0}function bnG(b){b=b|0;var d=0,e=0,f=0,g=0,h=0;a[c[2438166]|0]=b&255;d=c[2387366]|0;e=(b<<13&253952)+65536|0;b=0;f=0;while(1){g=f+32|0;h=d+(e+(f<<8))|0;c[9699632+(g<<2)>>2]=h;c[9701680+(g<<2)>>2]=h;h=b+1&65535;if((h&65535)<32){b=h;f=h&65535}else{break}}return}function bnH(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;c[d>>2]=(c[d>>2]|b<<14)&65535|c[e>>2]<<8&16128;c[e>>2]=(c[e>>2]|0)>>>6&3|a<<2;return}function bnI(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;switch(c[b>>2]&112|0){case 32:case 96:{c[d>>2]=3;break};case 16:{c[d>>2]=0;break};case 48:case 112:{c[d>>2]=5;break};case 64:{c[d>>2]=2;break};case 0:{c[d>>2]=1;break};case 80:{c[d>>2]=4;break};default:{}}c[a>>2]=c[a>>2]&16383|c[b>>2]<<6&8192;c[b>>2]=c[b>>2]&15|16;c[e>>2]=0;return}function bnJ(a,b){a=a|0;b=b|0;c[2424878]=9681232;c[2420315]=b>>>1<<17&131072;c[2420316]=b<<17&131072;return}function bnK(b){b=b|0;a[9681232]=((b>>4)*17|0)&255;a[9681233]=0;c[2424878]=9681232;a[9681234]=0;a[9681235]=((b&15)*17|0)&255;return}function bnL(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>1){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4589948+(b*112|0)>>2];c[a+104>>2]=c[4589952+(b*112|0)>>2];c[a+108>>2]=c[4589956+(b*112|0)>>2];d=0;return d|0}function bnM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<2&(d|0)==0)){e=1;return e|0}c[a>>2]=4589848+(b*112|0);e=0;return e|0}function bnN(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6937472+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function bnO(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>3){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7448912+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function bnP(){var a=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;a=i;i=i+240|0;e=a|0;f=a+112|0;g=a+120|0;j=a+232|0;c[2415068]=0;c[2385978]=0;c[3531044]=32768;c[3530152]=32800;c[2439522]=32928;c[2414776]=49312;c[2387890]=49312;c[2386266]=51360;c[3529502]=53408;c[3528610]=57504;c[2411836]=57505;k=0;while(1){if((k|0)>=1024){break}l=9638528+(k<<2)|0;if((c[l>>2]|0)==0){m=1707;break}else{k=k+1|0}}do{if((m|0)==1707){k=gGq(57505)|0;c[l>>2]=k;if((k|0)==0){break}c[2415068]=k;gGz(k|0,0,57505);c[2385978]=k;c[3531044]=k+32768;c[3530152]=k+32800;c[2439522]=k+32928;n=k+49312|0;c[2414776]=n;c[2387890]=n;c[2386266]=k+51360;c[3529502]=k+53408;c[3528610]=k+57504;n=k+57505|0;c[2411836]=n;c[2414384]=n;if((c[3542200]|0)==0){o=1;i=a;return o|0}n=g+108|0;c[n>>2]=0;p=g+100|0;c[p>>2]=0;q=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[q&16383](g,0)|0;do{if((c[n>>2]|0)!=0){q=c[p>>2]|0;c[j>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](j,0,0)|0;if((q|0)<1){o=1;i=a;return o|0}if((gzL(k,0,0)|0)==0){break}else{o=1}i=a;return o|0}}while(0);k=c[3531044]|0;if((c[3542200]|0)==0){o=1;i=a;return o|0}p=e+108|0;c[p>>2]=0;n=e+100|0;c[n>>2]=0;q=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[q&16383](e,1)|0;do{if((c[p>>2]|0)!=0){q=c[n>>2]|0;c[f>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](f,1,0)|0;if((q|0)<1){o=1;i=a;return o|0}if((gzL(k,0,1)|0)==0){break}else{o=1}i=a;return o|0}}while(0);k=c[3531044]|0;n=c[3530152]|0;p=0;do{q=d[k+p|0]|0;c[n+(p<<2)>>2]=(-(q>>>3&1)&33)+(-(q>>>4&1)&71)+(-(q>>>5&1)&151)<<3&2016|((-(q>>>6&1)&71)+(-(q>>>7)&151)|0)>>>3&31|(-(q>>>1&1)&71)+(-(q&1)&33)+(-(q>>>2&1)&151)<<8&63488;p=p+1|0;}while((p|0)<32);fwR(0);p=c[2439330]|0;if((p|0)!=0){n=p;gGC(9706056,n|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];n=c[3528484]|0;c[2076596]=n;k=c[2417276]|0;c[3541536]=k;c[1836236]=0;q=c[2385978]|0;r=0;s=0;while(1){c[p+76+(s<<2)>>2]=q+(s<<8);t=r+1&65535;if((t&65535)>127){u=0;v=0;break}else{r=t;s=t&65535}}while(1){s=q+(v<<8)|0;c[p+76+(v+512<<2)>>2]=s;c[p+76+(v+768<<2)>>2]=s;s=u+1&65535;if((s&65535)>127){break}else{u=s;v=s&65535}}q=c[2387890]|0;c[p+972>>2]=q;s=q+256|0;c[p+976>>2]=s;r=q+512|0;c[p+980>>2]=r;t=q+768|0;c[p+984>>2]=t;w=q+1024|0;c[p+988>>2]=w;x=q+1280|0;c[p+992>>2]=x;y=q+1536|0;c[p+996>>2]=y;z=q+1792|0;c[p+1e3>>2]=z;c[p+1996>>2]=q;c[p+2e3>>2]=s;c[p+2004>>2]=r;c[p+2008>>2]=t;c[p+2012>>2]=w;c[p+2016>>2]=x;c[p+2020>>2]=y;c[p+2024>>2]=z;c[p+3020>>2]=q;c[p+4044>>2]=q;c[p+3024>>2]=s;c[p+4048>>2]=s;c[p+3028>>2]=r;c[p+4052>>2]=r;c[p+3032>>2]=t;c[p+4056>>2]=t;c[p+3036>>2]=w;c[p+4060>>2]=w;c[p+3040>>2]=x;c[p+4064>>2]=x;c[p+3044>>2]=y;c[p+4068>>2]=y;c[p+3048>>2]=z;c[p+4072>>2]=z;z=c[2386266]|0;c[p+1004>>2]=z;y=z+256|0;c[p+1008>>2]=y;x=z+512|0;c[p+1012>>2]=x;w=z+768|0;c[p+1016>>2]=w;t=z+1024|0;c[p+1020>>2]=t;r=z+1280|0;c[p+1024>>2]=r;s=z+1536|0;c[p+1028>>2]=s;q=z+1792|0;c[p+1032>>2]=q;c[p+2028>>2]=z;c[p+2032>>2]=y;c[p+2036>>2]=x;c[p+2040>>2]=w;c[p+2044>>2]=t;c[p+2048>>2]=r;c[p+2052>>2]=s;c[p+2056>>2]=q;c[p+3052>>2]=z;c[p+4076>>2]=z;c[p+3056>>2]=y;c[p+4080>>2]=y;c[p+3060>>2]=x;c[p+4084>>2]=x;c[p+3064>>2]=w;c[p+4088>>2]=w;c[p+3068>>2]=t;c[p+4092>>2]=t;c[p+3072>>2]=r;c[p+4096>>2]=r;c[p+3076>>2]=s;c[p+4100>>2]=s;c[p+3080>>2]=q;c[p+4104>>2]=q;q=c[3529502]|0;c[p+1036>>2]=q;c[p+1040>>2]=q+256;c[p+1044>>2]=q+512;c[p+1048>>2]=q+768;c[p+1052>>2]=q+1024;c[p+1056>>2]=q+1280;c[p+1060>>2]=q+1536;c[p+1064>>2]=q+1792;c[p+1068>>2]=q+2048;c[p+1072>>2]=q+2304;c[p+1076>>2]=q+2560;c[p+1080>>2]=q+2816;c[p+1084>>2]=q+3072;c[p+1088>>2]=q+3328;c[p+1092>>2]=q+3584;c[p+1096>>2]=q+3840;s=240;r=240;while(1){t=q+((r<<8)-61440)|0;c[p+76+(r+512<<2)>>2]=t;c[p+76+(r+768<<2)>>2]=t;t=s+1&65535;if((t&65535)>255){break}else{s=t;r=t&65535}}c[p+4184>>2]=2596;c[p+4176>>2]=506;c[p+4172>>2]=3534;r=p;gGC(r|0,9706056,76)|0;c[2438118]=c[2433530];c[3528484]=n;c[2417276]=k;c[1836236]=-1;TS(0,15e5,32768,6,0,0);TS(1,15e5,32768,6,0,1);r=c[2420348]|0;h[r+192>>3]=.6;c[r+200>>2]=2;r=c[2420346]|0;h[r+192>>3]=.5;c[r+200>>2]=1;r=c[642608+(c[2436]<<2)>>2]|0;s=c[r+128>>2]|0;if((c[r+52>>2]&4|0)==0){c[2113068]=s;q=c[r+132>>2]|0;c[2113070]=q;c[2443814]=s;c[2440436]=q;A=s;B=q}else{c[2113070]=s;q=c[r+132>>2]|0;c[2113068]=q;c[2440436]=s;c[2443814]=q;A=q;B=s}s=ag(A<<1,B)|0;q=gGq(s)|0;c[2112926]=q;if((q|0)!=0){gGz(q|0,0,s|0)}s=c[2414776]|0;gGz(s|0,0,(c[2411836]|0)-s|0);s=c[2439330]|0;q=(s|0)==0;if(!q){r=s;gGC(9706056,r|0,76)|0}r=c[2438118]|0;c[2433530]=r;t=c[3528484]|0;c[2076596]=t;w=c[2417276]|0;c[3541536]=w;c[1836236]=0;gGz(9706056,0,76);if(!q){q=s;gGC(q|0,9706056,76)|0}c[2438118]=r;c[3528484]=t;c[2417276]=w;c[1836236]=-1;o=0;i=a;return o|0}}while(0);c[2415068]=0;o=1;i=a;return o|0}function bnQ(){var a=0,b=0,d=0,e=0;c[2113070]=0;c[2113068]=0;a=c[2112926]|0;if((a|0)!=0){gGr(a);c[2112926]=0}fwZ();TT();a=c[2415068]|0;b=0;while(1){if((b|0)>=1024){d=1753;break}e=9638528+(b<<2)|0;if((c[e>>2]|0)==(a|0)){break}else{b=b+1|0}}if((d|0)==1753){c[2415068]=0;return 0}gGr(a);c[e>>2]=0;c[2415068]=0;return 0}function bnR(){var d=0,e=0,f=0,g=0,h=0,i=0;if((a[9624880]|0)!=0){d=c[2414776]|0;gGz(d|0,0,(c[2411836]|0)-d|0);d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;h=c[2417276]|0;c[3541536]=h;c[1836236]=0;gGz(9706056,0,76);if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=h;c[1836236]=-1}c[2387710]=-1;h=0;g=-1;f=-1;e=-1;d=-1;do{g=((a[9634224+h|0]&1)<<h^g&255)&255;f=((a[9631984+h|0]&1)<<h^f&255)&255;e=((a[9629904+h|0]&1)<<h^e&255)&255;d=((a[9629072+h|0]&1)<<h^d&255)&255;h=h+1|0;}while((h|0)<8);a[9550840]=g;a[9550841]=f;a[9550843]=d;a[9550842]=a[9635576]&-128|e&127;e=c[2439330]|0;if((e|0)!=0){d=e;gGC(9706056,d|0,76)|0}b[4853030]=c[2426515]&65535;d=c[2438118]|0;c[2433530]=d;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;if((a[e+4188|0]|0)==0){e=gfc(5e4)|0;i=(c[2433530]|0)+e|0}else{i=d+5e4|0}c[2433530]=i;if((a[c[3528610]|0]|0)!=0){a[9706117]=1}d=c[1836236]|0;e=c[9757320+(d<<2)>>2]|0;if((e|0)!=0){f=e;gGC(f|0,9706056,76)|0}c[9752472+(d<<2)>>2]=i;c[14113936+(d<<2)>>2]=c[2076596];c[9669104+(d<<2)>>2]=c[3541536];c[1836236]=-1;d=c[2112964]|0;if((d|0)!=0){i=a[9688]|0?534:0;TQ(0,d,i);TQ(1,d,i)}if((c[2112968]|0)==0){return 0}bnS()|0;return 0}function bnS(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if((a[9547880]|0)!=0){b=c[3531044]|0;e=c[3530152]|0;f=0;do{g=d[b+f|0]|0;c[e+(f<<2)>>2]=(-(g>>>3&1)&33)+(-(g>>>4&1)&71)+(-(g>>>5&1)&151)<<3&2016|((-(g>>>6&1)&71)+(-(g>>>7)&151)|0)>>>3&31|(-(g>>>1&1)&71)+(-(g&1)&33)+(-(g>>>2&1)&151)<<8&63488;f=f+1|0;}while((f|0)<32);a[9547880]=0}f=c[2386266]|0;e=c[2387890]|0;b=c[2112926]|0;g=c[2439522]|0;h=0;do{i=h&63;j=i<<3;k=d[f+h|0]|0;l=a[e+(h>>>1&960|i)|0]&7;do{if(j>>>0>=256){i=(((h|0)/64|0)<<3)-16|0;if(i>>>0>223){break}Si(b,k,j-256|0,i,l,2,0,g)}}while(0);h=h+1|0;}while((h|0)<2048);R8(c[3530152]|0);return 0}function bnT(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0;e=i;i=i+16|0;f=e|0;if((d|0)!=0){c[d>>2]=169249}if((b&96|0)!=0){gGz(f|0,0,12);g=c[2414776]|0;c[f>>2]=g;c[f+4>>2]=(c[2411836]|0)-g;c[f+12>>2]=162152;g=c[2076592]|0;gj[g&4095](f)|0;fw$(b);TU(b,d)}if((b&2|0)==0){i=e;return 0}b=c[3529502]|0;d=c[2439522]|0;f=0;do{g=a[b+f|0]|0;h=g&255;j=h>>>3;k=f<<2;a[d+k|0]=(j&1|h>>>6&2)&255;a[d+(k|1)|0]=(g&255)>>>2&1|(g&255)>>>5&2;a[d+(k|2)|0]=(g&255)>>>1&1|(g&255)>>>4&2;a[d+(k|3)|0]=(j&2|h&1)&255;f=f+1|0;}while((f|0)<4096);i=e;return 0}function bnU(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;e=b&65535;if((e&61440|0)!=61440){return}b=e&4095;a[(c[3529502]|0)+b|0]=d;e=d&255;f=e>>>3;g=b<<2;b=c[2439522]|0;a[b+g|0]=(f&1|e>>>6&2)&255;a[b+(g|1)|0]=(d&255)>>>2&1|(d&255)>>>5&2;a[b+(g|2)|0]=(d&255)>>>1&1|(d&255)>>>4&2;a[b+(g|3)|0]=(f&2|e&1)&255;return}function bnV(b,d){b=b|0;d=d|0;var e=0;e=b&255;if((e|0)==0){TR(0,d&255);return}else if((e|0)==8){a[c[3528610]|0]=d&8;a[9706117]=0;return}else if((e|0)==4){TR(1,d&255);return}else{return}}function bnW(b){b=b|0;var c=0,d=0;c=b&65535;if(((c&255)-12|0)>>>0>=4){d=0;return d|0}d=a[9550840+(c&3)|0]|0;return d|0}function bnX(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=b&65535;L2375:do{switch(e|0){case 8084:{f=a[9550832]|0;break};case 8089:{f=a[9550835]|0;break};case 8087:{f=a[9635568]|0;break};case 8086:{f=a[9550834]|0;break};case 8091:{f=a[9635569]|0;break};case 8090:{f=a[9550836]|0;break};case 8088:{f=a[9635570]|0;break};case 8085:{f=a[9550833]|0;break};default:{if(!((e&65504|0)==8096&(c[2415176]|0)!=0)){if((e&49152|0)!=0){f=0;break L2375}f=blE(e&16383)|0;break L2375}b=(d[14116272]|0)<<8|(d[14116273]|0);g=(d[14116274]|0)<<8|(d[14116275]|0);h=(d[14116276]|0)<<8|(d[14116277]|0);i=(d[14116278]|0)<<8|(d[14116279]|0);j=(d[14116280]|0)<<8|(d[14116281]|0);k=(d[14116282]|0)<<8|(d[14116283]|0);l=(d[14116284]|0)<<8|(d[14116285]|0);m=a[14116286]|0;n=a[14116287]|0;o=(m&255)<<8|n&255;p=e&31;switch(p|0){case 1:{if((g|0)==0){f=-1;break L2375}f=((b>>>0)/(g>>>0)|0)&255;break L2375;break};case 0:{if((g|0)==0){f=-1;break L2375}f=((b>>>0)/(g>>>0)|0)>>>8&255;break L2375;break};case 15:{f=~n;break L2375;break};case 5:{f=(blL(h<<16)|0)&255;break L2375;break};case 4:{f=(blL(h<<16)|0)>>>8&255;break L2375;break};case 2:{if((g|0)==0){f=-1;break L2375}f=((b>>>0)%(g>>>0)|0)>>>8&255;break L2375;break};case 14:{f=~m;break L2375;break};case 6:{f=a[14116291]|0;break L2375;break};case 7:{if((k+i|0)<(o|0)|(o+i|0)<(k|0)){f=-128;break L2375}if((j+i|0)<(l|0)){f=-128;break L2375}f=(l+i|0)<(j|0)?-128:0;break L2375;break};case 3:{if((g|0)==0){f=-1;break L2375}f=((b>>>0)%(g>>>0)|0)&255;break L2375;break};default:{f=a[14116272+p|0]|0;break L2375}}}}}while(0);return f|0}function bnY(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=b&65535;switch(e|0){case 8080:{return};case 8114:{a[c[3528476]|0]=d;return};case 8064:{b=d&3;a[c[2394760]|0]=b;f=c[2443546]|0;g=c[3528552]|0;h=c[2433426]|0;i=((b&255)<<13)+40960|0;b=96;j=96;while(1){k=f+(i+(j<<8))|0;c[h+(g*3160|0)+60+(j<<2)>>2]=k;c[h+(g*3160|0)+60+(j+512<<2)>>2]=k;k=b+1&65535;if((k&65535)>127){break}else{b=k;j=k&65535}}c[3541230]=d&64;return};case 8068:{a[c[3528346]|0]=d;return};case 8072:{a[14125144]=-1;a[9706117]=1;return};default:{if((e&65504|0)==8096&(c[2415176]|0)!=0){a[14116272+(e&31)|0]=d;return}if((e&49152|0)!=0){return}blF(e&16383,d&255);return}}}function bnZ(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=b&65535;if((e|0)==49152){c[2113304]=d&255;return}else if((e|0)==57344){b=c[2418506]|0;c[2424874]=b;f=b+9|0;g=a[f]|0;a[f]=(d&255)>>>1&1;do{if(g<<24>>24!=0){if((a[(c[2424874]|0)+9|0]|0)!=0){break}Vl()}}while(0);c[2424874]=b;g=b+10|0;b=a[g]|0;a[g]=d&1;g=c[2424874]|0;f=g+16|0;do{if((a[f]|b)<<24>>24==0){if((a[g+10|0]|0)==0){break}if((a[g+9|0]|0)==0){break}a[f]=2;if(!(a[635136]|0)){break}h=a[(c[2424874]|0)+11|0]|0;Vk();i=c[2424874]|0;j=a[i+11|0]|0;if(h<<24>>24==j<<24>>24){break}h=c[i+12>>2]|0;if((h|0)==0){break}gf[h&2047](j&255)}}while(0);a[c[3528608]|0]=d&4;return}else if((e|0)==49153){f=c[2113304]|0;a[14168504+f|0]=d;mv(0,f,d&255);return}else if((e|0)==61440){f=d&255;a[(c[2394760]|0)+1|0]=d;c[2424878]=9681232;c[2420315]=f<<17&393216;c[2420316]=f>>>2<<17&393216;g=c[3529722]|0;b=g+((f>>>4<<17&393216)+131072)|0;gGC(g|0,b|0,131072)|0;return}else if((e|0)==36864){b=c[2418506]|0;c[2424874]=b;a[b+8|0]=d;return}else{if((e&65520|0)!=45056){return}TI(0,e&15,d&255);return}}function bn_(b){b=b|0;var e=0,f=0,g=0;e=b&65535;if((e|0)==49152|(e|0)==49153){f=c[(c[3531464]|0)+4240>>2]&255;return f|0}else if((e|0)==53248){b=c[2418506]|0;c[2424874]=b;f=(a[b+16|0]|0)==0|0;return f|0}else if((e|0)==40960){a[9706117]=0;f=a[c[3528346]|0]|0;return f|0}else{if((e&65520|0)!=45056){f=0;return f|0}b=e&15;c[2424878]=9681232;c[2426622]=9622928;if(!((b|0)==11|(b|0)==5)){f=0;return f|0}e=(b>>>0)/6|0;b=e*6|0;g=d[b+9681280|0]<<16&65536|d[b+9681279|0]<<8|d[b+9681278|0]|c[9681260+(e<<2)>>2];c[9681244+(e<<2)>>2]=g;if(g>>>0>=(c[2405735]|0)>>>0){f=0;return f|0}c[9681268+(e<<2)>>2]=1;c[9681236+(e<<2)>>2]=0;f=0;return f|0}return 0}function bn$(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4562172+(b*112|0)>>2];c[a+104>>2]=c[4562176+(b*112|0)>>2];c[a+108>>2]=c[4562180+(b*112|0)>>2];d=0;return d|0}function bn0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=4562072+(b*112|0);e=0;return e|0}function bn1(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>35){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1838464+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function bn2(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>38){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5297840+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function bn3(){return bos(0)|0}function bn4(){var b=0,d=0,e=0,f=0;c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}blI();c[2113196]=0;b=c[2433426]|0;if((b|0)!=0){gGr(b);c[2433426]=0}fwZ();b=c[2424800]|0;if((b|0)!=0){gGr(b);c[2424800]=0}b=c[2418166]|0;if((b|0)!=0){gGr(b);c[2418166]=0}b=c[2418506]|0;if((b|0)!=0){gGr(b);c[2418506]=0}b=c[2418507]|0;if((b|0)!=0){gGr(b);c[2418507]=0}a[635136]=0;b=c[3531464]|0;c[b+44344>>2]=0;c[b+44348>>2]=0;if((b|0)!=0){gGr(b);c[3531464]=0}b=c[2406684]|0;if((b|0)!=0){gGr(b);c[2406684]=0}b=c[2415066]|0;d=0;while(1){if((d|0)>=1024){e=1959;break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==(b|0)){break}else{d=d+1|0}}if((e|0)==1959){c[2415066]=0;return 0}gGr(b);c[f>>2]=0;c[2415066]=0;return 0}function bn5(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;if((a[9624872]|0)!=0){a[9624872]=0;d=c[2414774]|0;gGz(d|0,0,(c[2411834]|0)-d|0);c[3528552]=0;d=c[2433426]|0;if((d|0)!=0){e=d;gGC(9642704,e|0,60)|0}b[4821352]=c[2410676]&65535;fC1();e=(a[9642745]&1)==0;c[2430032]=e?1595912:1595656;c[2429672]=e?1114752:1114496;c[2429670]=e?1114240:1113984;c[2444186]=e?4654424:4654168;c[2113194]=c[9721800+(c[3528552]<<2)>>2];fC2();e=c[3528552]|0;d=(c[2433426]|0)+(e*3160|0)|0;if((d|0)!=0){f=d;gGC(f|0,9642704,60)|0}c[9721800+(e<<2)>>2]=c[2113194];c[3528552]=-1;e=c[2439330]|0;f=(e|0)==0;if(!f){d=e;gGC(9706056,d|0,76)|0}d=c[2438118]|0;c[2433530]=d;g=c[3528484]|0;c[2076596]=g;h=c[2417276]|0;c[3541536]=h;c[1836236]=0;gGz(9706056,0,76);if(!f){f=e;gGC(f|0,9706056,76)|0}c[2438118]=d;c[3528484]=g;c[2417276]=h;c[1836236]=-1;mx(0);Vl();blH()}gGz(9550832,-1|0,5);h=0;g=-1;d=-1;f=-1;e=-1;i=-1;do{g=((a[9634216+h|0]&1)<<h^g&255)&255;d=((a[9631976+h|0]&1)<<h^d&255)&255;f=((a[9629896+h|0]&1)<<h^f&255)&255;e=((a[9629064+h|0]&1)<<h^e&255)&255;i=((a[9628824+h|0]&1)<<h^i&255)&255;h=h+1|0;}while((h|0)<8);a[9550832]=g;a[9550833]=d;a[9550834]=f;a[9550835]=e;a[9550836]=i;if((d&12)==0){g=d|12;a[9550833]=g;j=g}else{j=d}if((j&3)==0){a[9550833]=j|3}if((f&12)==0){j=f|12;a[9550834]=j;k=j}else{k=f}if((k&3)==0){a[9550834]=k|3}if((e&12)==0){k=e|12;a[9550835]=k;l=k}else{l=e}if((l&3)==0){a[9550835]=l|3}if((i&12)==0){l=i|12;a[9550836]=l;m=l}else{m=i}if((m&3)==0){a[9550836]=m|3}m=a[9688]|0?534:0;i=c[2439330]|0;if((i|0)!=0){l=i;gGC(9706056,l|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;c[3528552]=0;l=c[2433426]|0;if((l|0)!=0){i=l;gGC(9642704,i|0,60)|0}b[4821352]=c[2410676]&65535;fC1();i=(a[9642745]&1)==0;c[2430032]=i?1595912:1595656;c[2429672]=i?1114752:1114496;c[2429670]=i?1114240:1113984;c[2444186]=i?4654424:4654168;c[2113194]=c[9721800+(c[3528552]<<2)>>2];i=(m|0)/(8>>>((c[2415176]|0)>>>0)|0)|0;l=0;e=0;k=0;f=i;j=0;L2590:while(1){d=e;g=k;h=f;n=j;while(1){if((n|0)>=(m|0)){break L2590}o=n+1|0;p=fC4((o*374|0)-g|0)|0;c[2113194]=(c[2113194]|0)+p;q=p+g|0;p=(o*111|0)-d|0;do{if((p|0)<1){r=0}else{if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){s=gfc(p)|0;c[2433530]=(c[2433530]|0)+s;r=s;break}else{c[2433530]=(c[2433530]|0)+p;r=p;break}}}while(0);t=r+d|0;do{if((n|0)==(h-1|0)){p=h+i|0;if((a[c[3528608]|0]|0)==0){u=p;break}if((c[2415176]|0)!=0){a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0;u=p;break}if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12;u=p}else{u=h}}while(0);v=c[2112964]|0;if((v|0)==0){d=t;g=q;h=u;n=o}else{break}}n=a[9688]&1;h=v+(l<<1<<1)|0;gg[c[3542124]&4095](h,n);Vj(0,h,n);TH(0,h,n);l=n+l|0;e=t;k=q;f=u;j=o}do{if((c[2415176]|0)==0){if((c[3541228]|0)==0){break}a[9642747]=1;fC1();fC4(0)|0;a[9642747]=0;fC4(0)|0}else{if((a[c[3528476]|0]|0)==0){break}fC3();fC4(0)|0;if((a[9642761]|0)!=0){a[9642761]=0}fC4(0)|0}}while(0);o=c[2112964]|0;do{if((o|0)!=0){j=a[9688]|0?534:0;u=j-l|0;if((j|0)==(l|0)){break}j=o+(l<<1<<1)|0;gg[c[3542124]&4095](j,u);Vj(0,j,u);TH(0,j,u)}}while(0);l=c[3528552]|0;o=(c[2433426]|0)+(l*3160|0)|0;if((o|0)!=0){u=o;gGC(u|0,9642704,60)|0}c[9721800+(l<<2)>>2]=c[2113194];c[3528552]=-1;l=c[1836236]|0;u=c[9757320+(l<<2)>>2]|0;if((u|0)!=0){o=u;gGC(o|0,9706056,76)|0}c[9752472+(l<<2)>>2]=c[2433530];c[14113936+(l<<2)>>2]=c[2076596];c[9669104+(l<<2)>>2]=c[3541536];c[1836236]=-1;if((c[2112968]|0)==0){return 0}bn6()|0;return 0}function bn6(){var d=0,e=0,f=0,g=0,h=0;if((a[9547872]|0)!=0){d=c[3530150]|0;e=(c[2443548]|0)+7680|0;f=0;do{g=ga(b[e+(f<<1)>>1]|0)|0;c[d+(f<<2)>>2]=((g&65535)>>>10<<3&65535)>>>3&31|((g&255)<<3&255)<<8|(((g&65535)>>>5<<3&255|(g&65535)>>>7&4)&255)<<3&2016;f=f+1|0;}while((f|0)<256)}bpj();f=(c[2415176]|0)==0;bpk(1,1,c[2439886]|0);d=c[2439886]|0;if(f){bpk(18,0,d);bpl(c[2439850]|0,1);bpk(2,0,c[2439886]|0);bpl(c[2439850]|0,0);bpl(c[2439850]|0,2);bpk(0,0,c[2439886]|0);h=c[3530150]|0;R8(h);return 0}else{bpk(2,0,d);bpl(c[2439850]|0,0);bpk(0,0,c[2439886]|0);h=c[3530150]|0;R8(h);return 0}return 0}function bn7(a,b){a=a|0;b=b|0;return 1}function bn8(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2623100+(b*112|0)>>2];c[a+104>>2]=c[2623104+(b*112|0)>>2];c[a+108>>2]=c[2623108+(b*112|0)>>2];d=0;return d|0}function bn9(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=2623e3+(b*112|0);e=0;return e|0}function boa(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1506916+(b*112|0)>>2];c[a+104>>2]=c[1506920+(b*112|0)>>2];c[a+108>>2]=c[1506924+(b*112|0)>>2];d=0;return d|0}function bob(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=1506816+(b*112|0);e=0;return e|0}function boc(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>23){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=966344+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function bod(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>55){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1839040+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function boe(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2381972+(b*112|0)>>2];c[a+104>>2]=c[2381976+(b*112|0)>>2];c[a+108>>2]=c[2381980+(b*112|0)>>2];d=0;return d|0}function bof(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=2381872+(b*112|0);e=0;return e|0}function bog(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2944836+(b*112|0)>>2];c[a+104>>2]=c[2944840+(b*112|0)>>2];c[a+108>>2]=c[2944844+(b*112|0)>>2];d=0;return d|0}function boh(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=2944736+(b*112|0);e=0;return e|0}function boi(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1283096+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function boj(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>59){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4067328+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function bok(){return bos(1)|0}function bol(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1565948+(b*112|0)>>2];c[a+104>>2]=c[1565952+(b*112|0)>>2];c[a+108>>2]=c[1565956+(b*112|0)>>2];d=0;return d|0}function bom(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=1565848+(b*112|0);e=0;return e|0}function bon(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>62){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1957864+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function boo(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1564828+(b*112|0)>>2];c[a+104>>2]=c[1564832+(b*112|0)>>2];c[a+108>>2]=c[1564836+(b*112|0)>>2];d=0;return d|0}function bop(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=1564728+(b*112|0);e=0;return e|0}function boq(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5887748+(b*112|0)>>2];c[a+104>>2]=c[5887752+(b*112|0)>>2];c[a+108>>2]=c[5887756+(b*112|0)>>2];d=0;return d|0}function bor(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=5887648+(b*112|0);e=0;return e|0}function bos(e){e=e|0;var f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;f=i;i=i+720|0;g=f|0;j=f+112|0;k=f+120|0;l=f+232|0;m=f+240|0;n=f+352|0;o=f+360|0;p=f+472|0;q=f+480|0;r=f+592|0;s=f+600|0;t=f+712|0;c[2415066]=0;c[2443546]=0;c[2385976]=131072;c[3530918]=196608;c[3530682]=458752;c[2439886]=1507328;c[2439850]=2031616;c[3529768]=4128768;c[3529722]=4653056;c[3530150]=5308416;c[2414774]=5309440;c[2443548]=5309440;c[2386130]=5317632;c[3528346]=5318656;c[3528608]=5318657;c[3528476]=5318658;c[2394760]=5318659;c[2411834]=5318661;u=0;while(1){if((u|0)>=1024){break}v=9638528+(u<<2)|0;if((c[v>>2]|0)==0){w=2160;break}else{u=u+1|0}}do{if((w|0)==2160){u=gGq(5318661)|0;c[v>>2]=u;if((u|0)==0){break}c[2415066]=u;gGz(u|0,0,5318661);c[2443546]=u;c[2385976]=u+131072;c[3530918]=u+196608;c[3530682]=u+458752;c[2439886]=u+1507328;c[2439850]=u+2031616;c[3529768]=u+4128768;c[3529722]=u+4653056;c[3530150]=u+5308416;x=u+5309440|0;c[2414774]=x;c[2443548]=x;c[2386130]=u+5317632;c[3528346]=u+5318656;c[3528608]=u+5318657;c[3528476]=u+5318658;c[2394760]=u+5318659;x=u+5318661|0;c[2411834]=x;c[2414382]=x;c[2415176]=e;x=65536<<e;y=u+65536|0;if((c[3542200]|0)==0){z=1;i=f;return z|0}u=s+108|0;c[u>>2]=0;A=s+100|0;c[A>>2]=0;B=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[B&16383](s,0)|0;do{if((c[u>>2]|0)!=0){B=c[A>>2]|0;c[t>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](t,0,0)|0;if((B|0)<1){z=1;i=f;return z|0}if((gzL(y,0,0)|0)==0){break}else{z=1}i=f;return z|0}}while(0);y=c[2443546]|0;A=y+32768|0;u=y+98304|0;gGC(A|0,u|0,32768)|0;u=c[2385976]|0;if((c[3542200]|0)==0){z=1;i=f;return z|0}A=q+108|0;c[A>>2]=0;y=q+100|0;c[y>>2]=0;B=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[B&16383](q,1)|0;do{if((c[A>>2]|0)!=0){B=c[y>>2]|0;c[r>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](r,1,0)|0;if((B|0)<1){z=1;i=f;return z|0}if((gzL(u,0,1)|0)==0){break}else{z=1}i=f;return z|0}}while(0);if((R6(c[3530918]|0,2,2)|0)!=0){z=1;i=f;return z|0}if((R6((c[3530918]|0)+1|0,3,2)|0)!=0){z=1;i=f;return z|0}if((R6((c[3530918]|0)+x|0,4,2)|0)!=0){z=1;i=f;return z|0}if((R6((c[3530918]|0)+(x+1)|0,5,2)|0)!=0){z=1;i=f;return z|0}u=c[3530682]|0;if((c[3542200]|0)==0){z=1;i=f;return z|0}y=o+108|0;c[y>>2]=0;A=o+100|0;c[A>>2]=0;B=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[B&16383](o,6)|0;do{if((c[y>>2]|0)!=0){B=c[A>>2]|0;c[p>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](p,6,0)|0;if((B|0)<1){z=1;i=f;return z|0}if((gzL(u,0,6)|0)==0){break}else{z=1}i=f;return z|0}}while(0);u=(c[3530682]|0)+524288|0;if((c[3542200]|0)==0){z=1;i=f;return z|0}A=m+108|0;c[A>>2]=0;y=m+100|0;c[y>>2]=0;B=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[B&16383](m,7)|0;do{if((c[A>>2]|0)!=0){B=c[y>>2]|0;c[n>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](n,7,0)|0;if((B|0)<1){z=1;i=f;return z|0}if((gzL(u,0,7)|0)==0){break}else{z=1}i=f;return z|0}}while(0);u=c[3529768]|0;if((c[3542200]|0)==0){z=1;i=f;return z|0}y=k+108|0;c[y>>2]=0;A=k+100|0;c[A>>2]=0;B=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[B&16383](k,8)|0;do{if((c[y>>2]|0)!=0){B=c[A>>2]|0;c[l>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](l,8,0)|0;if((B|0)<1){z=1;i=f;return z|0}if((gzL(u,0,8)|0)==0){break}else{z=1}i=f;return z|0}}while(0);u=(c[3529722]|0)+131072|0;if((c[3542200]|0)==0){z=1;i=f;return z|0}A=g+108|0;c[A>>2]=0;y=g+100|0;c[y>>2]=0;B=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[B&16383](g,9)|0;do{if((c[A>>2]|0)!=0){B=c[y>>2]|0;c[j>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](j,9,0)|0;if((B|0)<1){z=1;i=f;return z|0}if((gzL(u,0,9)|0)==0){break}else{z=1}i=f;return z|0}}while(0);u=c[3529722]|0;y=u+131072|0;gGC(u|0,y|0,131072)|0;y=x<<1;u=c[3530918]|0;blG(u,(y|0)/2|0);A=c[3530682]|0;blG(A,524288);B=(y|0)/32|0;C=c[2439886]|0;if((y|0)>31){D=0;do{E=D<<6;gGz(C+E|0,0,64);F=D<<8;G=0;do{H=1<<3-G;I=(c[611632+(G<<2)>>2]|0)+F|0;J=0;do{K=I+(c[3946808+(J<<2)>>2]|0)|0;L=(J<<3)+E|0;M=0;do{N=K+(c[6669416+(M<<2)>>2]|0)|0;if(((d[u+((N|0)/8|0)|0]|0)&128>>>((N&7)>>>0)|0)!=0){N=C+(L+M)|0;a[N]=(d[N]|0|H)&255}M=M+1|0;}while((M|0)<8);J=J+1|0;}while((J|0)<8);G=G+1|0;}while((G|0)<4);D=D+1|0;}while((D|0)<(B|0))}B=c[2439850]|0;D=0;do{C=D<<8;gGz(B+C|0,0,256);u=D<<10;x=0;do{G=1<<3-x;E=(c[611400+(x<<2)>>2]|0)+u|0;F=0;do{J=E+(c[3946808+(F<<2)>>2]|0)|0;H=(F<<4)+C|0;I=0;do{M=J+(c[6669416+(I<<2)>>2]|0)|0;if(((d[A+((M|0)/8|0)|0]|0)&128>>>((M&7)>>>0)|0)!=0){M=B+(H+I)|0;a[M]=(d[M]|0|G)&255}I=I+1|0;}while((I|0)<16);F=F+1|0;}while((F|0)<16);x=x+1|0;}while((x|0)<4);D=D+1|0;}while((D|0)<8192);c[3528552]=-1;c[2113196]=1;D=gGq(3160)|0;B=D;c[2433426]=B;if((D|0)==0){c[3528552]=0}else{gGz(D|0,0,3160);c[D+3132>>2]=2102;c[D+3136>>2]=2420;c[D+3140>>2]=1856;c[D+3144>>2]=1450;c[2430450]=0;A=0;do{c[B+60+(A<<2)>>2]=0;A=A+1|0;}while((A|0)<768);c[2113194]=0;A=c[2427044]|0;c[9681616+(A<<3)>>2]=726904;c[9681620+(A<<3)>>2]=0;c[2427044]=A+1;c[3528552]=0;gGC(9642704,D|0,60)|0}b[4821352]=c[2410676]&65535;fC1();A=(a[9642745]&1)==0;c[2430032]=A?1595912:1595656;c[2429672]=A?1114752:1114496;c[2429670]=A?1114240:1113984;c[2444186]=A?4654424:4654168;A=c[3528552]|0;B=9721800+(A<<2)|0;c[2113194]=c[B>>2];x=c[2443548]|0;C=c[2433426]|0;u=64;F=64;while(1){G=x+((F<<8)-16384)|0;c[C+(A*3160|0)+60+(F<<2)>>2]=G;c[C+(A*3160|0)+60+(F+256<<2)>>2]=G;c[C+(A*3160|0)+60+(F+512<<2)>>2]=G;G=u+1&65535;if((G&65535)>95){break}else{u=G;F=G&65535}}F=c[2443546]|0;u=96;x=96;while(1){D=F+((x<<8)+40960)|0;c[C+(A*3160|0)+60+(x<<2)>>2]=D;c[C+(A*3160|0)+60+(x+512<<2)>>2]=D;D=u+1&65535;if((D&65535)>127){O=128;P=128;break}else{u=D;x=D&65535}}while(1){x=F+(P<<8)|0;c[C+(A*3160|0)+60+(P<<2)>>2]=x;c[C+(A*3160|0)+60+(P+512<<2)>>2]=x;x=O+1&65535;if((x&65535)>255){break}else{O=x;P=x&65535}}c[C+(A*3160|0)+3136>>2]=1992;c[C+(A*3160|0)+3132>>2]=1654;F=C+(A*3160|0)|0;if((F|0)!=0){x=F;gGC(x|0,9642704,60)|0}c[B>>2]=c[2113194];c[3528552]=-1;fwR(0);x=c[2439330]|0;F=(x|0)==0;if(!F){u=x;gGC(9706056,u|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];u=c[3528484]|0;c[2076596]=u;D=c[2417276]|0;c[3541536]=D;c[1836236]=0;G=c[2385976]|0;E=0;I=0;while(1){c[x+76+(I<<2)>>2]=G+(I<<8);H=E+1&65535;if((H&65535)>127){Q=0;R=0;break}else{E=H;I=H&65535}}while(1){I=G+(R<<8)|0;c[x+76+(R+512<<2)>>2]=I;c[x+76+(R+768<<2)>>2]=I;I=Q+1&65535;if((I&65535)>127){break}else{Q=I;R=I&65535}}G=c[2386130]|0;c[x+588>>2]=G;I=G+256|0;c[x+592>>2]=I;E=G+512|0;c[x+596>>2]=E;B=G+768|0;c[x+600>>2]=B;c[x+1612>>2]=G;c[x+1616>>2]=I;c[x+1620>>2]=E;c[x+1624>>2]=B;c[x+2636>>2]=G;c[x+3660>>2]=G;c[x+2640>>2]=I;c[x+3664>>2]=I;c[x+2644>>2]=E;c[x+3668>>2]=E;c[x+2648>>2]=B;c[x+3672>>2]=B;c[x+4184>>2]=1954;c[x+4180>>2]=1230;if(!F){B=x;gGC(B|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=u;c[2417276]=D;c[1836236]=-1;B=c[3530918]|0;E=y-1|0;I=0;while(1){if((I|0)>=1024){S=0;break}T=9638528+(I<<2)|0;if((c[T>>2]|0)==0){w=2232;break}else{I=I+1|0}}do{if((w|0)==2232){I=gGq(24576)|0;c[T>>2]=I;if((I|0)==0){S=0;break}gGz(I|0,0,24576);S=I}}while(0);c[3529062]=S;c[2438700]=E;c[3529060]=B;a[7461784]=1;I=9726816;c[I>>2]=0;c[I+4>>2]=0;I=9726800;c[I>>2]=0;c[I+4>>2]=0;c[2429638]=0;I=(c[2415176]|0)!=0;c[2437692]=I?24:36;y=I?0:8;c[2431704]=y;c[2431700]=0;c[2431705]=y;c[2431701]=0;c[2431706]=y;c[2431702]=0;y=c[3530682]|0;c[2438136]=0;I=0;while(1){if((I|0)>=1024){U=0;break}V=9638528+(I<<2)|0;if((c[V>>2]|0)==0){w=2237;break}else{I=I+1|0}}do{if((w|0)==2237){I=gGq(1024)|0;c[V>>2]=I;if((I|0)==0){U=0;break}gGz(I|0,0,1024);U=I}}while(0);c[3529066]=U;c[2438702]=1048575;c[3529064]=y;a[7461792]=1;I=(c[2415176]|0)!=0;c[2437694]=I?20:118;c[2438136]=I?0:8;TJ(0,c[3529768]|0,524288);c[2424878]=9681232;c[2405736]=1436;h[1202869]=.2;c[2405742]=3;c[2426622]=9622928;h[1202870]=.2;c[2405743]=3;I=a[9680]|0;B=I?32e3:0;if(I){if(a[9624]|0){I=B*3|0;E=55930;while(1){if((E|0)>(I|0)){E=E>>1}else{W=1222;X=E;break}}}else{W=2462;X=B}c[2429380]=X;c[3542124]=W;mw(3579545,X);E=gGq(262144)|0;c[2406684]=E;gGz(E|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(3579545,11025)}h[745421]=.3;c[2436794]=3;h[745420]=.3;c[2436792]=3;E=c[3529722]|0;I=gGq(80)|0;y=I;c[2418506]=y;c[2424874]=y;gGz(I|0,0,80);a[635136]=0;c[I+4>>2]=~~(16.0e4/(a[9680]|0?32.0e3:0.0)*4194304.0);a[I+16|0]=0;if((E|0)==0){a[635136]=1}else{c[I+52>>2]=E}a[I+9|0]=1;a[(c[2424874]|0)+10|0]=1;E=c[2424874]|0;h[E+64>>3]=1.0;c[E+72>>2]=3;Vl();c[2424874]=y;h[I+64>>3]=.5;c[I+72>>2]=3;I=c[642608+(c[2436]<<2)>>2]|0;y=c[I+128>>2]|0;if((c[I+52>>2]&4|0)==0){c[2113068]=y;E=c[I+132>>2]|0;c[2113070]=E;c[2443814]=y;c[2440436]=E;Y=y;Z=E}else{c[2113070]=y;E=c[I+132>>2]|0;c[2113068]=E;c[2440436]=y;c[2443814]=E;Y=E;Z=y}y=ag(Y<<1,Z)|0;E=gGq(y)|0;c[2112926]=E;if((E|0)!=0){gGz(E|0,0,y|0)}a[9624872]=0;y=c[2414774]|0;gGz(y|0,0,(c[2411834]|0)-y|0);c[3528552]=0;y=c[2433426]|0;if((y|0)!=0){E=y;gGC(9642704,E|0,60)|0}b[4821352]=c[2410676]&65535;fC1();E=(a[9642745]&1)==0;c[2430032]=E?1595912:1595656;c[2429672]=E?1114752:1114496;c[2429670]=E?1114240:1113984;c[2444186]=E?4654424:4654168;c[2113194]=c[9721800+(c[3528552]<<2)>>2];fC2();E=c[3528552]|0;y=(c[2433426]|0)+(E*3160|0)|0;if((y|0)!=0){I=y;gGC(I|0,9642704,60)|0}c[9721800+(E<<2)>>2]=c[2113194];c[3528552]=-1;E=c[2439330]|0;I=(E|0)==0;if(!I){y=E;gGC(9706056,y|0,76)|0}y=c[2438118]|0;c[2433530]=y;D=c[3528484]|0;c[2076596]=D;u=c[2417276]|0;c[3541536]=u;c[1836236]=0;gGz(9706056,0,76);if(!I){I=E;gGC(I|0,9706056,76)|0}c[2438118]=y;c[3528484]=D;c[2417276]=u;c[1836236]=-1;mx(0);Vl();blH();z=0;i=f;return z|0}}while(0);c[2415066]=0;z=1;i=f;return z|0}function bot(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;g=c[e>>2]|0;c[d>>2]=g<<7&7680|c[d>>2]|g<<8&256;c[e>>2]=(c[e>>2]|0)>>>6&3|a<<1&4;return}function bou(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;c[f>>2]=c[e>>2]&2;if((a|0)==2){c[g>>2]=(c[e>>2]|0)>>>5&1}g=c[e>>2]|0;c[d>>2]=g<<7&3584|c[d>>2]|g<<8&256;c[e>>2]=(c[e>>2]|0)>>>6&3|(a<<1&4)+(a<<2&4);return}function bov(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;c[b>>2]=c[b>>2]&7|8;return}function bow(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;e=c[b>>2]|0;do{if((e&32|0)==0){if((e&64|0)==0){c[d>>2]=2;break}else{c[d>>2]=1;break}}else{c[d>>2]=0}}while(0);c[b>>2]=c[b>>2]&3|12;return}function box(b){b=b|0;a[9681232]=((b>>4)*17|0)&255;a[9681233]=0;c[2424878]=9681232;a[9681234]=0;a[9681235]=((b&15)*17|0)&255;return}function boy(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0.0;e=b&65535;b=e&65528;if((b|0)==512){f=c[3529866]|0;g=e&7;if((g|0)==3){h=c[3529666]|0;i=(c[3529616]|0)+((d&255)<<8&2048)|0;gGC(h|0,i|0,2048)|0}a[f+g|0]=d;return}else if((b|0)==0){b=c[3529868]|0;g=e&7;if((g|0)==3){f=c[3529678]|0;i=(c[3529642]|0)+((d&255)<<8&2048)|0;gGC(f|0,i|0,2048)|0}a[b+g|0]=d;return}else{g=e&65280;if((g|0)==512){a[(c[3530272]|0)+(e&255)|0]=d;return}else if((g|0)==0){a[(c[3530274]|0)+(e&255)|0]=d;return}else{switch(e|0){case 1048:{a[c[2406756]|0]=d;return};case 1036:{c[2388392]=0;return};case 1028:{a[c[3528344]|0]=d;return};case 1032:{e=c[2433530]|0;j=+(c[2410673]|0)*1.19318167- +((c[2426530]|0)+e-(c[2076596]|0)|0);do{if(j>1.0){g=~~j;if((g|0)<1){break}if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){b=gfc(g)|0;c[2433530]=(c[2433530]|0)+b;break}else{c[2433530]=g+e;break}}}while(0);a[9706117]=1;return};case 1024:{e=d&15;a[c[2443954]|0]=e;d=c[2387364]|0;g=((e&255)<<13)+65536|0;e=0;b=0;while(1){i=b+96|0;f=d+(g+(b<<8))|0;c[9699632+(i<<2)>>2]=f;c[9701680+(i<<2)>>2]=f;f=e+1&65535;if((f&65535)<32){e=f;b=f&65535}else{break}}return};default:{return}}}}}function boz(b){b=b|0;var d=0,e=0;d=b&65535;switch(d|0){case 1048:{e=a[c[2406756]|0]|0;break};case 1043:{e=a[9635562]|0;break};case 1040:case 1041:case 1042:{e=a[9550824+(d&3)|0]|0;break};case 1045:{e=a[9635560]|0;break};case 1044:{e=a[9635561]|0;break};default:{e=0}}return e|0}function boA(b,e){b=b|0;e=e|0;var f=0,g=0,h=0;f=b&65535;if((f&65408|0)==38912){g=f&127;c[2420382]=9674032;h=f&31;a[9674052+((g>>>5)*56|0)+h|0]=e;if(g>>>0<=95){return}a[9674276+h|0]=e;return}if((f&65520|0)==39040){h=b&15;g=h&65535;if((h&65535)<10){c[2420382]=9674032;c[9674344+(g<<2)>>2]=e&255;c[9674040+((g>>>1)*56|0)>>2]=(c[9674344+((g|1)<<2)>>2]<<8)+(c[9674344+((g&14)<<2)>>2]|0)&4095;return}if(h<<16>>16==15){h=e&255;c[2420382]=9674032;c[2418512]=h&1;c[2418526]=h&2;c[2418540]=h&4;c[2418554]=h&8;c[2418568]=h&16;return}else{c[2420382]=9674032;c[9674044+((g+6&7)*56|0)>>2]=e&15;return}}if((b+20480&65535)<14){TI(0,f&15,e&255);return}if((f|0)==49152){c[2424878]=9681232;b=(e&255)>>>2<<17&393216;c[2420315]=b;c[2420316]=b;return}else if((f|0)==40960|(f|0)==40961){b=c[3540984]|0;if((f&1|0)==0){a[b+5885|0]=e;return}f=c[b+5876>>2]|0;if((f|0)!=0){gg[f&4095](c[b+5880>>2]|0,0)}lH(b,d[b+5885|0]|0,e&255);return}else{return}}function boB(b){b=b|0;var e=0,f=0,g=0,h=0;e=b&65535;if((b+20480&65535)<14){b=e&15;c[2424878]=9681232;c[2426622]=9622928;if(!((b|0)==11|(b|0)==5)){f=0;return f|0}g=(b>>>0)/6|0;b=g*6|0;h=(d[b+9681280|0]|0)<<16&65536|(d[b+9681279|0]|0)<<8|(d[b+9681278|0]|0)|c[9681260+(g<<2)>>2];c[9681244+(g<<2)>>2]=h;if(h>>>0>=(c[2405735]|0)>>>0){f=0;return f|0}c[9681268+(g<<2)>>2]=1;c[9681236+(g<<2)>>2]=0;f=0;return f|0}else{if((e|0)==40960|(e|0)==40961){f=lx(c[3540984]|0,e&1)|0|6;return f|0}else if((e|0)==53248){a[9706117]=0;f=a[c[3528344]|0]|0;return f|0}else{f=0;return f|0}}return 0}function boC(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4672700+(b*112|0)>>2];c[a+104>>2]=c[4672704+(b*112|0)>>2];c[a+108>>2]=c[4672708+(b*112|0)>>2];d=0;return d|0}function boD(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=4672600+(b*112|0);e=0;return e|0}function boE(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1871552+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function boF(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>63){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5357768+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function boG(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0;e=i;i=i+1440|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;B=e+1200|0;C=e+1312|0;D=e+1320|0;E=e+1432|0;c[2415064]=0;c[2387364]=0;c[2385974]=196608;c[3530916]=262144;c[3530680]=2359296;c[2387086]=4456448;c[2386678]=4457472;c[2406992]=4981760;c[3530148]=4985856;c[2414772]=5002240;c[3530274]=5002240;c[3530272]=5002496;c[2387254]=5002752;c[2387078]=5010944;c[2387066]=5015040;c[3529642]=5019136;c[3529616]=5023232;c[3529678]=5027328;c[3529666]=5029376;c[3529868]=5031424;c[3529866]=5031432;c[2386128]=5031440;c[2443954]=5033488;c[3528344]=5033489;c[2406756]=5033490;c[2411832]=5033491;F=0;while(1){if((F|0)>=1024){break}G=9638528+(F<<2)|0;if((c[G>>2]|0)==0){H=2411;break}else{F=F+1|0}}do{if((H|0)==2411){F=gGq(5033491)|0;c[G>>2]=F;if((F|0)==0){break}c[2415064]=F;gGz(F|0,0,5033491);c[2387364]=F;c[2385974]=F+196608;c[3530916]=F+262144;c[3530680]=F+2359296;c[2387086]=F+4456448;c[2386678]=F+4457472;c[2406992]=F+4981760;c[3530148]=F+4985856;I=F+5002240|0;c[2414772]=I;c[3530274]=I;c[3530272]=F+5002496;c[2387254]=F+5002752;c[2387078]=F+5010944;c[2387066]=F+5015040;c[3529642]=F+5019136;c[3529616]=F+5023232;c[3529678]=F+5027328;c[3529666]=F+5029376;c[3529868]=F+5031424;c[3529866]=F+5031432;c[2386128]=F+5031440;c[2443954]=F+5033488;c[3528344]=F+5033489;c[2406756]=F+5033490;I=F+5033491|0;c[2411832]=I;c[2414380]=I;if((c[3542200]|0)==0){J=1;i=e;return J|0}I=D+108|0;c[I>>2]=0;K=D+100|0;c[K>>2]=0;L=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[L&16383](D,0)|0;do{if((c[I>>2]|0)!=0){L=c[K>>2]|0;c[E>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](E,0,0)|0;if((L|0)<1){J=1;i=e;return J|0}if((gzL(F,0,0)|0)==0){break}else{J=1}i=e;return J|0}}while(0);F=(c[2387364]|0)+65536|0;if((c[3542200]|0)==0){J=1;i=e;return J|0}K=B+108|0;c[K>>2]=0;I=B+100|0;c[I>>2]=0;L=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[L&16383](B,1)|0;do{if((c[K>>2]|0)!=0){L=c[I>>2]|0;c[C>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](C,1,0)|0;if((L|0)<1){J=1;i=e;return J|0}if((gzL(F,0,1)|0)==0){break}else{J=1}i=e;return J|0}}while(0);F=c[2385974]|0;if((c[3542200]|0)==0){J=1;i=e;return J|0}I=z+108|0;c[I>>2]=0;K=z+100|0;c[K>>2]=0;L=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[L&16383](z,2)|0;do{if((c[I>>2]|0)!=0){L=c[K>>2]|0;c[A>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](A,2,0)|0;if((L|0)<1){J=1;i=e;return J|0}if((gzL(F,0,2)|0)==0){break}else{J=1}i=e;return J|0}}while(0);F=c[3530916]|0;if((c[3542200]|0)==0){J=1;i=e;return J|0}K=x+108|0;c[K>>2]=0;I=x+100|0;c[I>>2]=0;L=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[L&16383](x,3)|0;do{if((c[K>>2]|0)!=0){L=c[I>>2]|0;c[y>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](y,3,0)|0;if((L|0)<1){J=1;i=e;return J|0}if((gzL(F,0,3)|0)==0){break}else{J=1}i=e;return J|0}}while(0);F=(c[3530916]|0)+524288|0;if((c[3542200]|0)==0){J=1;i=e;return J|0}I=v+108|0;c[I>>2]=0;K=v+100|0;c[K>>2]=0;L=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[L&16383](v,4)|0;do{if((c[I>>2]|0)!=0){L=c[K>>2]|0;c[w>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](w,4,0)|0;if((L|0)<1){J=1;i=e;return J|0}if((gzL(F,0,4)|0)==0){break}else{J=1}i=e;return J|0}}while(0);F=c[3530680]|0;if((c[3542200]|0)==0){J=1;i=e;return J|0}K=t+108|0;c[K>>2]=0;I=t+100|0;c[I>>2]=0;L=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[L&16383](t,5)|0;do{if((c[K>>2]|0)!=0){L=c[I>>2]|0;c[u>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](u,5,0)|0;if((L|0)<1){J=1;i=e;return J|0}if((gzL(F,0,5)|0)==0){break}else{J=1}i=e;return J|0}}while(0);F=(c[3530680]|0)+524288|0;if((c[3542200]|0)==0){J=1;i=e;return J|0}I=r+108|0;c[I>>2]=0;K=r+100|0;c[K>>2]=0;L=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[L&16383](r,6)|0;do{if((c[I>>2]|0)!=0){L=c[K>>2]|0;c[s>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](s,6,0)|0;if((L|0)<1){J=1;i=e;return J|0}if((gzL(F,0,6)|0)==0){break}else{J=1}i=e;return J|0}}while(0);F=c[2386678]|0;if((c[3542200]|0)==0){J=1;i=e;return J|0}K=p+108|0;c[K>>2]=0;I=p+100|0;c[I>>2]=0;L=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[L&16383](p,7)|0;do{if((c[K>>2]|0)!=0){L=c[I>>2]|0;c[q>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](q,7,0)|0;if((L|0)<1){J=1;i=e;return J|0}if((gzL(F,0,7)|0)==0){break}else{J=1}i=e;return J|0}}while(0);F=c[2387086]|0;if((c[3542200]|0)==0){J=1;i=e;return J|0}I=n+108|0;c[I>>2]=0;K=n+100|0;c[K>>2]=0;L=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[L&16383](n,8)|0;do{if((c[I>>2]|0)!=0){L=c[K>>2]|0;c[o>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](o,8,0)|0;if((L|0)<1){J=1;i=e;return J|0}if((gzL(F,0,8)|0)==0){break}else{J=1}i=e;return J|0}}while(0);F=(c[2387086]|0)+256|0;if((c[3542200]|0)==0){J=1;i=e;return J|0}K=l+108|0;c[K>>2]=0;I=l+100|0;c[I>>2]=0;L=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[L&16383](l,9)|0;do{if((c[K>>2]|0)!=0){L=c[I>>2]|0;c[m>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](m,9,0)|0;if((L|0)<1){J=1;i=e;return J|0}if((gzL(F,0,9)|0)==0){break}else{J=1}i=e;return J|0}}while(0);F=(c[2387086]|0)+512|0;if((c[3542200]|0)==0){J=1;i=e;return J|0}I=j+108|0;c[I>>2]=0;K=j+100|0;c[K>>2]=0;L=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[L&16383](j,10)|0;do{if((c[I>>2]|0)!=0){L=c[K>>2]|0;c[k>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](k,10,0)|0;if((L|0)<1){J=1;i=e;return J|0}if((gzL(F,0,10)|0)==0){break}else{J=1}i=e;return J|0}}while(0);F=(c[2387086]|0)+768|0;if((c[3542200]|0)==0){J=1;i=e;return J|0}K=f+108|0;c[K>>2]=0;I=f+100|0;c[I>>2]=0;L=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[L&16383](f,11)|0;do{if((c[K>>2]|0)!=0){L=c[I>>2]|0;c[g>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](g,11,0)|0;if((L|0)<1){J=1;i=e;return J|0}if((gzL(F,0,11)|0)==0){break}else{J=1}i=e;return J|0}}while(0);F=c[2387086]|0;I=c[2406992]|0;K=0;while(1){L=K&1;M=L<<8;N=K<<8;O=K<<4;if((L|0)==0){L=0;do{P=a[F+(L|M)|0]|0;if(P<<24>>24==0){Q=0}else{Q=(P&15|O)&255}a[I+(L|N)|0]=Q;L=L+1|0;}while((L|0)<256)}else{L=0;do{a[I+(L|N)|0]=(a[F+(L|M)|0]&15|O)&255;L=L+1|0;}while((L|0)<256)}L=K+1|0;if((L|0)<8){K=L}else{R=0;break}}while(1){K=R&1;L=K<<8|512;O=R<<8|2048;M=R<<4;if((K|0)==0){K=0;do{N=a[F+(K|L)|0]|0;if(N<<24>>24==0){S=0}else{S=(N&15|M)&255}a[I+(K|O)|0]=S;K=K+1|0;}while((K|0)<256)}else{K=0;do{a[I+(K|O)|0]=(a[F+(K|L)|0]&15|M)&255;K=K+1|0;}while((K|0)<256)}K=R+1|0;if((K|0)<8){R=K}else{T=0;break}}while(1){if((T|0)>=1024){break}U=9638528+(T<<2)|0;if((c[U>>2]|0)==0){H=2476;break}else{T=T+1|0}}L3266:do{if((H|0)==2476){F=gGq(1048576)|0;c[U>>2]=F;if((F|0)==0){break}gGz(F|0,0,1048576);I=c[3530916]|0;gGC(F|0,I|0,1048576)|0;K=0;do{M=K<<6;gGz(I+M|0,0,64);L=K<<8;O=0;do{N=1<<3-O;P=(c[703416+(O<<2)>>2]|0)+L|0;V=0;do{W=P+(c[1183816+(V<<2)>>2]|0)|0;X=(V<<3)+M|0;Y=0;do{Z=W+(c[612864+(Y<<2)>>2]|0)|0;if(((d[F+((Z|0)/8|0)|0]|0)&128>>>((Z&7)>>>0)|0)!=0){Z=I+(X+Y)|0;a[Z]=(d[Z]|0|N)&255}Y=Y+1|0;}while((Y|0)<8);V=V+1|0;}while((V|0)<8);O=O+1|0;}while((O|0)<4);K=K+1|0;}while((K|0)<32768);K=c[3530680]|0;gGC(F|0,K|0,1048576)|0;I=0;while(1){O=I<<6;gGz(K+O|0,0,64);M=I<<8;L=0;do{V=1<<3-L;N=(c[703416+(L<<2)>>2]|0)+M|0;P=0;do{Y=N+(c[1183816+(P<<2)>>2]|0)|0;X=(P<<3)+O|0;W=0;do{Z=Y+(c[612864+(W<<2)>>2]|0)|0;if(((d[F+((Z|0)/8|0)|0]|0)&128>>>((Z&7)>>>0)|0)!=0){Z=K+(X+W)|0;a[Z]=(d[Z]|0|V)&255}W=W+1|0;}while((W|0)<8);P=P+1|0;}while((P|0)<8);L=L+1|0;}while((L|0)<4);L=I+1|0;if((L|0)<32768){I=L}else{_=0;break}}while(1){if((_|0)>=1024){break L3266}$=9638528+(_<<2)|0;if((c[$>>2]|0)==(F|0)){break}else{_=_+1|0}}gGr(F);c[$>>2]=0}}while(0);c[2410674]=1748;gGz(9699632,0,3072);I=c[2427044]|0;c[9681616+(I<<3)>>2]=715288;c[9681620+(I<<3)>>2]=0;c[2427044]=I+1;c[363094]=0;I=c[3530274]|0;c[2424908]=I;c[2425420]=I;I=c[3530272]|0;c[2424910]=I;c[2425422]=I;I=c[2387254]|0;K=0;L=0;while(1){O=L+6|0;M=I+(L<<8)|0;c[9699632+(O<<2)>>2]=M;c[9700656+(O<<2)>>2]=M;c[9701680+(O<<2)>>2]=M;M=K+1&65535;if((M&65535)<26){K=M;L=M&65535}else{break}}L=c[2387078]|0;K=0;I=0;while(1){M=I+32|0;O=L+(I<<8)|0;c[9699632+(M<<2)>>2]=O;c[9700656+(M<<2)>>2]=O;c[9701680+(M<<2)>>2]=O;O=K+1&65535;if((O&65535)<16){K=O;I=O&65535}else{break}}I=c[3529642]|0;K=0;L=0;while(1){O=L+48|0;M=I+(L<<8)|0;c[9699632+(O<<2)>>2]=M;c[9700656+(O<<2)>>2]=M;c[9701680+(O<<2)>>2]=M;M=K+1&65535;if((M&65535)<16){K=M;L=M&65535}else{break}}L=c[2387066]|0;K=0;I=0;while(1){M=I+64|0;O=L+(I<<8)|0;c[9699632+(M<<2)>>2]=O;c[9700656+(M<<2)>>2]=O;c[9701680+(M<<2)>>2]=O;O=K+1&65535;if((O&65535)<16){K=O;I=O&65535}else{break}}I=c[3529616]|0;K=0;L=0;while(1){O=L+80|0;M=I+(L<<8)|0;c[9699632+(O<<2)>>2]=M;c[9700656+(O<<2)>>2]=M;c[9701680+(O<<2)>>2]=M;M=K+1&65535;if((M&65535)<16){K=M;L=M&65535}else{break}}L=c[2387364]|0;K=0;I=0;while(1){M=I+96|0;O=L+((I<<8)+65536)|0;c[9699632+(M<<2)>>2]=O;c[9701680+(M<<2)>>2]=O;O=K+1&65535;if((O&65535)<32){K=O;I=O&65535}else{aa=0;ab=0;break}}while(1){I=ab+128|0;K=L+(ab<<8)|0;c[9699632+(I<<2)>>2]=K;c[9701680+(I<<2)>>2]=K;K=aa+1&65535;if((K&65535)<128){aa=K;ab=K&65535}else{break}}c[2444172]=1984;c[3528598]=1436;c[363094]=-1;fwR(0);L=c[2439330]|0;K=(L|0)==0;if(!K){I=L;gGC(9706056,I|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];I=c[3528484]|0;c[2076596]=I;O=c[2417276]|0;c[3541536]=O;c[1836236]=0;M=c[2385974]|0;P=0;V=0;while(1){c[L+76+(V<<2)>>2]=M+(V<<8);N=P+1&65535;if((N&65535)>127){ac=0;ad=0;break}else{P=N;V=N&65535}}while(1){V=M+(ad<<8)|0;c[L+76+(ad+512<<2)>>2]=V;c[L+76+(ad+768<<2)>>2]=V;V=ac+1&65535;if((V&65535)>127){break}else{ac=V;ad=V&65535}}M=c[2386128]|0;c[L+588>>2]=M;V=M+256|0;c[L+592>>2]=V;P=M+512|0;c[L+596>>2]=P;N=M+768|0;c[L+600>>2]=N;W=M+1024|0;c[L+604>>2]=W;X=M+1280|0;c[L+608>>2]=X;Y=M+1536|0;c[L+612>>2]=Y;Z=M+1792|0;c[L+616>>2]=Z;c[L+1612>>2]=M;c[L+1616>>2]=V;c[L+1620>>2]=P;c[L+1624>>2]=N;c[L+1628>>2]=W;c[L+1632>>2]=X;c[L+1636>>2]=Y;c[L+1640>>2]=Z;c[L+2636>>2]=M;c[L+3660>>2]=M;c[L+2640>>2]=V;c[L+3664>>2]=V;c[L+2644>>2]=P;c[L+3668>>2]=P;c[L+2648>>2]=N;c[L+3672>>2]=N;c[L+2652>>2]=W;c[L+3676>>2]=W;c[L+2656>>2]=X;c[L+3680>>2]=X;c[L+2660>>2]=Y;c[L+3684>>2]=Y;c[L+2664>>2]=Z;c[L+3688>>2]=Z;c[L+4184>>2]=2952;c[L+4180>>2]=1798;if(!K){Z=L;gGC(Z|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=I;c[2417276]=O;c[1836236]=-1;UL(3579545,0,446,0);c[2438224]=3579545;c[2433522]=3416;c[2406672]=1752;c[3528468]=9362;c[2443842]=571;h[745398]=.7;a[3203264]=1;TJ(0,c[2386678]|0,524288);c[2424878]=9681232;c[2405736]=326;h[1202869]=.44;c[2405742]=3;c[2426622]=9622928;h[1202870]=.5;c[2405743]=3;c[2420382]=9674032;c[2418579]=111860;c[2418578]=1789772;h[1209290]=1.0;c[2418582]=3;c[2443780]=~~(111860.0/(a[9680]|0?32.0e3:0.0)*32768.0);c[2418585]=gGq(447440)|0;Z=gGq(5120)|0;c[2418583]=Z;Y=Z+2560|0;c[2418584]=Y;b[Y>>1]=0;b[Z+2562>>1]=25;b[(c[2418584]|0)-2>>1]=-25;Z=2;do{Y=(Z<<7|0)/5|0;b[(c[2418584]|0)+(Z<<1)>>1]=Y&65535;b[(c[2418584]|0)+(-Z<<1)>>1]=-Y&65535;Z=Z+1|0;}while((Z|0)<1280);c[2420382]=9674032;h[1209290]=.45;c[2418582]=3;Z=c[642608+(c[2436]<<2)>>2]|0;O=c[Z+128>>2]|0;if((c[Z+52>>2]&4|0)==0){c[2113068]=O;I=c[Z+132>>2]|0;c[2113070]=I;c[2443814]=O;c[2440436]=I;ae=O;af=I}else{c[2113070]=O;I=c[Z+132>>2]|0;c[2113068]=I;c[2440436]=O;c[2443814]=I;ae=I;af=O}O=ag(ae<<1,af)|0;I=gGq(O)|0;c[2112926]=I;if((I|0)!=0){gGz(I|0,0,O|0)}a[9624864]=0;O=c[2414772]|0;gGz(O|0,0,(c[2411832]|0)-O|0);c[363094]=0;c[2410673]=0;a[9642688]=0;a[9642689]=0;a[9642682]=0;a[9642683]=0;c[2410665]=0;a[9642680]=a[9642680]|80;O=c[2425163]|0;do{if((O|0)==0){I=c[3528598]|0;if((I|0)==0){ah=0;ai=0;break}Z=gj[I&4095](-2)|0;I=c[2425163]|0;L=(Z&255)<<8;if((I|0)!=0){aj=I;ak=L;H=2531;break}I=c[3528598]|0;if((I|0)==0){ah=0;ai=L;break}ah=gj[I&4095](-1)|0;ai=L}else{aj=O;ak=(d[O+254|0]|0)<<8;H=2531}}while(0);if((H|0)==2531){ah=a[aj+255|0]|0;ai=ak}c[2410662]=ah&255|ai;c[363094]=-1;O=c[2439330]|0;L=(O|0)==0;if(!L){I=O;gGC(9706056,I|0,76)|0}I=c[2438118]|0;c[2433530]=I;Z=c[3528484]|0;c[2076596]=Z;K=c[2417276]|0;c[3541536]=K;c[1836236]=0;gGz(9706056,0,76);if(!L){L=O;gGC(L|0,9706056,76)|0}c[2438118]=I;c[3528484]=Z;c[2417276]=K;c[1836236]=-1;c[2420382]=9674032;c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;lw(c[3540984]|0);c[2388392]=0;J=0;i=e;return J|0}}while(0);c[2415064]=0;J=1;i=e;return J|0}function boH(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}c[2444172]=0;c[3528598]=0;fwZ();b=c[2424800]|0;if((b|0)!=0){gGr(b);c[2424800]=0}b=c[2418166]|0;if((b|0)!=0){gGr(b);c[2418166]=0}c[2420382]=9674032;b=c[2418585]|0;if((b|0)!=0){gGr(b);c[2418585]=0}b=c[2418583]|0;if((b|0)!=0){gGr(b);c[2418583]=0}c[2443780]=0;b=a[7452584]|0;if(b){d=0;e=b&1;while(1){b=14163936+(d<<2)|0;f=c[b>>2]|0;g=c[2113006]|0;if((g|0)==0){h=2592}else{i=g-1|0;c[2113006]=i;if((i|0)==0){h=2592}}if((h|0)==2592){h=0;c[2383474]=0}if((f|0)==0){j=e}else{gGr(f);j=a[7452584]&1}c[b>>2]=0;b=d+1|0;if((b|0)<(j|0)){d=b;e=j}else{break}}}a[7452584]=0;c[2438224]=0;c[2433522]=0;c[2406672]=0;c[3528468]=0;j=c[2406688]|0;if((j|0)!=0){gGr(j);c[2406688]=0}c[2432972]=0;j=c[2415064]|0;e=0;while(1){if((e|0)>=1024){h=2603;break}k=9638528+(e<<2)|0;if((c[k>>2]|0)==(j|0)){break}else{e=e+1|0}}if((h|0)==2603){c[2415064]=0;return 0}gGr(j);c[k>>2]=0;c[2415064]=0;return 0}function boI(){var e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;do{if((a[9624864]|0)==0){e=c[2388392]|0;c[2388392]=e+1;if((e|0)!=60){break}a[9624864]=0;e=c[2414772]|0;gGz(e|0,0,(c[2411832]|0)-e|0);c[363094]=0;c[2410673]=0;a[9642688]=0;a[9642689]=0;a[9642682]=0;a[9642683]=0;c[2410665]=0;a[9642680]=a[9642680]|80;e=c[2425163]|0;do{if((e|0)==0){f=c[3528598]|0;if((f|0)==0){g=0;i=0;break}j=gj[f&4095](-2)|0;f=c[2425163]|0;k=(j&255)<<8;if((f|0)!=0){l=f;m=k;n=2623;break}f=c[3528598]|0;if((f|0)==0){g=0;i=k;break}g=gj[f&4095](-1)|0;i=k}else{l=e;m=d[e+254|0]<<8;n=2623}}while(0);if((n|0)==2623){g=a[l+255|0]|0;i=m}c[2410662]=g&255|i;c[363094]=-1;e=c[2439330]|0;k=(e|0)==0;if(!k){f=e;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;j=c[3528484]|0;c[2076596]=j;o=c[2417276]|0;c[3541536]=o;c[1836236]=0;gGz(9706056,0,76);if(!k){k=e;gGC(k|0,9706056,76)|0}c[2438118]=f;c[3528484]=j;c[2417276]=o;c[1836236]=-1;c[2420382]=9674032;c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;lw(c[3540984]|0);c[2388392]=0}else{a[9624864]=0;o=c[2414772]|0;gGz(o|0,0,(c[2411832]|0)-o|0);c[363094]=0;c[2410673]=0;a[9642688]=0;a[9642689]=0;a[9642682]=0;a[9642683]=0;c[2410665]=0;a[9642680]=a[9642680]|80;o=c[2425163]|0;do{if((o|0)==0){j=c[3528598]|0;if((j|0)==0){p=0;q=0;break}f=gj[j&4095](-2)|0;j=c[2425163]|0;k=(f&255)<<8;if((j|0)!=0){r=j;s=k;n=2610;break}j=c[3528598]|0;if((j|0)==0){p=0;q=k;break}p=gj[j&4095](-1)|0;q=k}else{r=o;s=d[o+254|0]<<8;n=2610}}while(0);if((n|0)==2610){p=a[r+255|0]|0;q=s}c[2410662]=p&255|q;c[363094]=-1;o=c[2439330]|0;k=(o|0)==0;if(!k){j=o;gGC(9706056,j|0,76)|0}j=c[2438118]|0;c[2433530]=j;f=c[3528484]|0;c[2076596]=f;e=c[2417276]|0;c[3541536]=e;c[1836236]=0;gGz(9706056,0,76);if(!k){k=o;gGC(k|0,9706056,76)|0}c[2438118]=j;c[3528484]=f;c[2417276]=e;c[1836236]=-1;c[2420382]=9674032;c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;lw(c[3540984]|0);c[2388392]=1}}while(0);gGz(9550824,-1|0,3);q=0;p=-1;s=-1;r=-1;do{p=((a[9634208+q|0]&1)<<q^p&255)&255;s=((a[9631968+q|0]&1)<<q^s&255)&255;r=((a[9629888+q|0]&1)<<q^r&255)&255;q=q+1|0;}while((q|0)<8);a[9550824]=p;a[9550825]=s;a[9550826]=r;if((s&3)==0){p=s|3;a[9550825]=p;t=p}else{t=s}if((t&12)==0){a[9550825]=t|12}if((r&3)==0){t=r|3;a[9550826]=t;u=t}else{u=r}if((u&12)==0){a[9550826]=u|12}c[2410673]=0;u=c[2385548]|0;if((u|0)>0){gGz(9752472,0,((u|0)>1?u<<2:4)|0)}c[2433530]=0;u=c[2439330]|0;if((u|0)!=0){r=u;gGC(9706056,r|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;c[363094]=0;fNF(5e4)|0;fNE(0,1);fNF(0)|0;a[9642682]=0;fNF(0)|0;r=c[2438224]|0;u=gGS(-1597636608,28447,r,(r|0)<0|0?-1:0)|0;r=u;UF(59659)|0;u=c[2443826]|0;if((u|0)<1073676288){c[2443826]=u-r}u=c[2443827]|0;if((u|0)<1073676288){c[2443827]=u-r}u=(c[3528508]|0)-r|0;c[3528508]=(u|0)<0?0:u;u=c[2112964]|0;if((u|0)!=0){gg[c[3542112]&4095](u,a[9688]|0?534:0);u=c[2112964]|0;r=a[9688]|0?534:0;TH(0,u,r);Ud(u,r)}c[363094]=-1;r=c[1836236]|0;u=c[9757320+(r<<2)>>2]|0;if((u|0)!=0){t=u;gGC(t|0,9706056,76)|0}c[9752472+(r<<2)>>2]=c[2433530];c[14113936+(r<<2)>>2]=c[2076596];c[9669104+(r<<2)>>2]=c[3541536];c[1836236]=-1;if((c[2112968]|0)==0){return 0}boJ()|0;return 0}function boJ(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0;b=i;i=i+512|0;e=b|0;if((a[9547864]|0)!=0){f=c[2387254]|0;g=0;do{h=a[f+(g|1)|0]|0;j=a[f+g|0]|0;c[e+(((g|0)/2|0)<<2)>>2]=((j&255)>>>2<<3&255)>>>3|(h<<3&255)<<8|(((((j&255)<<8|h&255)&65535)>>>5<<3&255|j<<1&4)&255)<<3&2016;g=g+2|0;}while((g|0)<256);g=c[2406992]|0;f=c[3530148]|0;j=0;do{c[f+(j<<2)>>2]=c[e+(d[g+j|0]<<2)>>2];j=j+1|0;}while((j|0)<4096)}j=c[2112926]|0;gGz(j|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);j=d[c[2406756]|0]|0;g=c[3529866]|0;e=c[3530680]|0;boT(c[2387066]|0,g,e,144,j>>>1<<14&16384,0);if((j&4|0)==0){j=c[3529868]|0;f=c[3530916]|0;boU(0,c[3529678]|0,j,f,0);boU(1,c[3529666]|0,g,e,128);boT(c[2387078]|0,j,f,16,0,1);k=c[3530148]|0;R8(k);i=b;return 0}else{f=c[3529868]|0;j=c[3530916]|0;boT(c[2387078]|0,f,j,16,0,1);boU(0,c[3529678]|0,f,j,0);boU(1,c[3529666]|0,g,e,128);k=c[3530148]|0;R8(k);i=b;return 0}return 0}function boK(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=i;i=i+144|0;f=e|0;g=e+16|0;h=e+32|0;j=e+64|0;k=e+80|0;l=e+96|0;m=e+112|0;n=e+128|0;o=(d|0)==0;if(!o){c[d>>2]=169730}if((b&96|0)!=0){gGz(n|0,0,12);p=c[2414772]|0;c[n>>2]=p;c[n+4>>2]=(c[2411832]|0)-p;c[n+12>>2]=162152;p=c[2076592]|0;gj[p&4095](n)|0;n=c[2410674]|0;p=c[2410675]|0;q=(b&64|0)==0;if(!q){gGz(l|0,0,12);c[l>>2]=9642648;c[l+4>>2]=56;c[l+12>>2]=163840;r=c[2076592]|0;gj[r&4095](l)|0;gGz(k|0,0,12);c[k>>2]=9707480;c[k+4>>2]=2;c[k+12>>2]=501096;l=c[2076592]|0;gj[l&4095](k)|0;gGz(j|0,0,12);c[j>>2]=9707480;c[j+4>>2]=4;c[j+12>>2]=385184;k=c[2076592]|0;gj[k&4095](j)|0}c[2410674]=n;c[2410675]=p;fw$(b);UQ(b,d);p=h|0;if(q){s=f}else{if(!o){c[d>>2]=169619}cC(p|0,170224,(q=i,i=i+8|0,c[q>>2]=0,q)|0)|0;i=q;c[g>>2]=9699512;c[g+4>>2]=64;c[g+8>>2]=0;c[g+12>>2]=p;p=c[2076592]|0;gj[p&4095](g)|0;g=f;if(!o){c[d>>2]=169733}d=f|0;c[d>>2]=c[2420382];o=f+4|0;c[o>>2]=280;p=f+8|0;c[p>>2]=0;q=f+12|0;c[q>>2]=144416;h=c[2076592]|0;gj[h&4095](f)|0;c[d>>2]=(c[2420382]|0)+312;c[o>>2]=40;c[p>>2]=0;c[q>>2]=493520;q=c[2076592]|0;gj[q&4095](f)|0;s=g}gGz(m|0,0,12);c[m>>2]=9553568;c[m+4>>2]=4;c[m+12>>2]=102144;g=c[2076592]|0;gj[g&4095](m)|0}if((b&2|0)==0){i=e;return 0}c[363094]=0;b=c[2443954]|0;m=a[b]&15;a[b]=m;b=c[2387364]|0;g=((m&255)<<13)+65536|0;m=0;s=0;while(1){f=s+96|0;q=b+(g+(s<<8))|0;c[9699632+(f<<2)>>2]=q;c[9701680+(f<<2)>>2]=q;q=m+1&65535;if((q&65535)<32){m=q;s=q&65535}else{break}}c[363094]=-1;i=e;return 0}function boL(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2779516+(b*112|0)>>2];c[a+104>>2]=c[2779520+(b*112|0)>>2];c[a+108>>2]=c[2779524+(b*112|0)>>2];d=0;return d|0}function boM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=2779416+(b*112|0);e=0;return e|0}function boN(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2780972+(b*112|0)>>2];c[a+104>>2]=c[2780976+(b*112|0)>>2];c[a+108>>2]=c[2780980+(b*112|0)>>2];d=0;return d|0}function boO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=2780872+(b*112|0);e=0;return e|0}function boP(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3171364+(b*112|0)>>2];c[a+104>>2]=c[3171368+(b*112|0)>>2];c[a+108>>2]=c[3171372+(b*112|0)>>2];d=0;return d|0}function boQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=3171264+(b*112|0);e=0;return e|0}function boR(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1621332+(b*112|0)>>2];c[a+104>>2]=c[1621336+(b*112|0)>>2];c[a+108>>2]=c[1621340+(b*112|0)>>2];d=0;return d|0}function boS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=1621232+(b*112|0);e=0;return e|0}function boT(b,e,f,g,h,i){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;j=d[e+5|0]|0;k=(j&3)+2|0;l=(j>>>2&3)+1|0;m=j>>>4&3;n=(j>>>6)-1|0;j=(d[e+6|0]|0)<<1&96|g;g=(a[e+3|0]&1)==0?h:h+8192|0;h=(d[e+1|0]|0)<<8&256|(d[e]|0);o=d[e+2|0]|0;p=(i|0)==0;i=c[2112926]|0;if((a[e+7|0]&8)==0){e=0;do{q=(e<<3&504)-h|0;r=(q|0)<-7?q+512|0:q;q=(e>>6<<3)-o|0;s=e>>>1&992|e&31|e<<6&2048;t=d[b+s|0]|0;u=t&7|j;v=(d[b+(s|1024)|0]|0)+g+((t>>>(k>>>0)&2|t>>>7|t>>>(l>>>0)&4|t>>>(m>>>0)&8|t>>>(n>>>0)&16)<<8)|0;t=((q|0)<-7?q+256|0:q)-16|0;if(p){Sj(i,v,r,t,u,4,0,f)}else{Sr(i,v,r,t,u,4,0,0,f)}e=e+1|0;}while((e|0)<2048);return}else{if(p){p=0;do{e=(p<<3&504)-h|0;u=(p>>6<<3)-o|0;t=p>>>1&992|p&31|p<<6&2048;r=d[b+t|0]|0;Sp(i,(d[b+(t|1024)|0]|0)+g+((r>>>(k>>>0)&2|r>>>7|r>>>(l>>>0)&4|r>>>(m>>>0)&8|r>>>(n>>>0)&16)<<8)|0,248-((e|0)<-7?e+512|0:e)|0,232-((u|0)<-7?u+256|0:u)|0,r&7|j,4,0,f);p=p+1|0;}while((p|0)<2048);return}else{p=0;do{r=(p<<3&504)-h|0;u=(p>>6<<3)-o|0;e=p>>>1&992|p&31|p<<6&2048;t=d[b+e|0]|0;Sx(i,(d[b+(e|1024)|0]|0)+g+((t>>>(k>>>0)&2|t>>>7|t>>>(l>>>0)&4|t>>>(m>>>0)&8|t>>>(n>>>0)&16)<<8)|0,248-((r|0)<-7?r+512|0:r)|0,232-((u|0)<-7?u+256|0:u)|0,t&7|j,4,0,0,f);p=p+1|0;}while((p|0)<2048);return}}}function boU(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;if((b|0)==0){i=(d[c[2406756]|0]|0)<<14&16384}else{i=0}b=((d[f+6|0]|0)<<1&96)+h|0;h=(a[f+7|0]&8)==0;f=c[2112926]|0;j=0;k=e;while(1){e=d[k+1|0]|0;l=a[k+2|0]|0;m=l&255;n=d[k+3|0]|0;o=d[k+4|0]|0;p=o&16;q=o&32;r=b+(e>>>4)|0;s=(o&1|0)==0?n:n|-256;n=(l&255)>239?m|-256:m;m=e>>>2&3|i|(e<<8&768|(d[k]|0)|o<<4&3072)<<2;e=o&14;if((e|0)==8){t=m&32764;u=4;v=4}else if((e|0)==0){t=m&32764;u=2;v=2}else if((e|0)==2){t=m&32766;u=1;v=2}else if((e|0)==4){t=m&32765;u=2;v=1}else{t=m;u=1;v=1}m=(q|0)!=0;e=u-1|0;o=(p|0)!=0;l=v-1|0;w=(q|0)==0;q=(p|0)==0;p=0;do{x=(p<<3)+n|0;y=x-16|0;z=248-x-16|0;x=c[607944+((m?e-p|0:p)<<2)>>2]|0;A=0;do{B=(A<<3)+s|0;C=(c[607960+((o?l-A|0:A)<<2)>>2]|0)+t+x|0;do{if(h){if(m){if(o){Sx(f,C,B,y,r,4,0,0,g);break}else{Sv(f,C,B,y,r,4,0,0,g);break}}else{if(o){St(f,C,B,y,r,4,0,0,g);break}else{Sr(f,C,B,y,r,4,0,0,g);break}}}else{D=248-B|0;if(w){if(q){Sx(f,C,D,z,r,4,0,0,g);break}else{Sv(f,C,D,z,r,4,0,0,g);break}}else{if(q){St(f,C,D,z,r,4,0,0,g);break}else{Sr(f,C,D,z,r,4,0,0,g);break}}}}while(0);A=A+1|0;}while((A|0)<(v|0));p=p+1|0;}while((p|0)<(u|0));p=j+1|0;if((p|0)<64){j=p;k=k+5|0}else{break}}return}
function boV(a){a=a|0;var b=0,d=0;b=(c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,3579545,0)|0;return a|0}function boW(b){b=b|0;a[9681232]=((b>>4)*17|0)&255;a[9681233]=0;c[2424878]=9681232;a[9681234]=0;a[9681235]=((b&15)*17|0)&255;return}function boX(b,d){b=b|0;d=d|0;var e=0;e=b&65535;do{if(b<<16>>16==16268){a[c[3528342]|0]=d;a[14125144]=-1;a[9706117]=1}else{if((b-8192&65535)<16384){break}return}}while(0);blF(e-8192|0,d&255);return}function boY(b){b=b|0;var c=0,d=0;c=b&65535;L3635:do{switch(c|0){case 16262:{d=a[9550819]|0;break};case 16264:{d=0;break};case 16256:{d=a[9550820]|0;break};case 16261:{d=a[9550818]|0;break};case 16257:{d=a[9550816]|0;break};case 16258:{d=a[9550817]|0;break};case 16260:{d=a[9635554]|0;break};case 16263:{d=a[9635552]|0;break};case 16259:{d=a[9635553]|0;break};default:{if((b-8192&65535)>=16384){d=0;break L3635}d=blE(c-8192|0)|0}}}while(0);return d|0}function boZ(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((e&65520|0)==57344){TI(0,e&15,d&255);return}if((e|0)==40960){c[2113304]=d&255;return}else if((e|0)==40961){e=c[2113304]|0;a[14168504+e|0]=d;mv(0,e,d&255);return}else{return}}function bo_(b){b=b|0;var e=0,f=0,g=0,h=0;e=b&65535;if((e&65520|0)==57344){b=e&15;c[2424878]=9681232;c[2426622]=9622928;if(!((b|0)==11|(b|0)==5)){f=0;return f|0}g=(b>>>0)/6|0;b=g*6|0;h=(d[b+9681280|0]|0)<<16&65536|(d[b+9681279|0]|0)<<8|(d[b+9681278|0]|0)|c[9681260+(g<<2)>>2];c[9681244+(g<<2)>>2]=h;if(h>>>0>=(c[2405735]|0)>>>0){f=0;return f|0}c[9681268+(g<<2)>>2]=1;c[9681236+(g<<2)>>2]=0;f=0;return f|0}else{if((e|0)==40960|(e|0)==40961){f=c[(c[3531464]|0)+4240>>2]&255;return f|0}else if((e|0)==49152){a[9706117]=0;f=a[c[3528342]|0]|0;return f|0}else{f=0;return f|0}}return 0}function bo$(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3002628+(b*112|0)>>2];c[a+104>>2]=c[3002632+(b*112|0)>>2];c[a+108>>2]=c[3002636+(b*112|0)>>2];d=0;return d|0}function bo0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=3002528+(b*112|0);e=0;return e|0}function bo1(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>35){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1289912+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function bo2(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>30){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4141888+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function bo3(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0;e=i;i=i+840|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;c[2415062]=0;c[2387362]=0;c[2385972]=262144;c[3530914]=327680;c[3530678]=851968;c[2439884]=1900544;c[2439848]=2949120;c[2386676]=5046272;c[3530146]=5308416;c[2414770]=5310464;c[3531078]=5310464;c[2387388]=5311488;c[2387252]=5318656;c[2386126]=5319680;c[3528342]=5321728;c[2443946]=5321729;c[2438164]=5321730;c[2411830]=5321731;v=0;while(1){if((v|0)>=1024){break}w=9638528+(v<<2)|0;if((c[w>>2]|0)==0){x=2852;break}else{v=v+1|0}}do{if((x|0)==2852){v=gGq(5321731)|0;c[w>>2]=v;if((v|0)==0){break}c[2415062]=v;gGz(v|0,0,5321731);c[2387362]=v;c[2385972]=v+262144;c[3530914]=v+327680;c[3530678]=v+851968;c[2439884]=v+1900544;c[2439848]=v+2949120;c[2386676]=v+5046272;c[3530146]=v+5308416;y=v+5310464|0;c[2414770]=y;c[3531078]=y;c[2387388]=v+5311488;c[2387252]=v+5318656;c[2386126]=v+5319680;c[3528342]=v+5321728;c[2443946]=v+5321729;c[2438164]=v+5321730;y=v+5321731|0;c[2411830]=y;c[2414378]=y;y=v+65536|0;if((c[3542200]|0)==0){z=1;i=e;return z|0}v=t+108|0;c[v>>2]=0;A=t+100|0;c[A>>2]=0;B=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[B&16383](t,0)|0;do{if((c[v>>2]|0)!=0){B=c[A>>2]|0;c[u>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](u,0,0)|0;if((B|0)<1){z=1;i=e;return z|0}if((gzL(y,0,0)|0)==0){break}else{z=1}i=e;return z|0}}while(0);y=c[2387362]|0;A=y+32768|0;v=y+163840|0;gGC(A|0,v|0,32768)|0;gGz(v|0,0,32768);v=c[2385972]|0;if((c[3542200]|0)==0){z=1;i=e;return z|0}A=r+108|0;c[A>>2]=0;y=r+100|0;c[y>>2]=0;B=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[B&16383](r,1)|0;do{if((c[A>>2]|0)!=0){B=c[y>>2]|0;c[s>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](s,1,0)|0;if((B|0)<1){z=1;i=e;return z|0}if((gzL(v,0,1)|0)==0){break}else{z=1}i=e;return z|0}}while(0);v=c[3530914]|0;if((c[3542200]|0)==0){z=1;i=e;return z|0}y=p+108|0;c[y>>2]=0;A=p+100|0;c[A>>2]=0;B=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[B&16383](p,2)|0;do{if((c[y>>2]|0)!=0){B=c[A>>2]|0;c[q>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](q,2,0)|0;if((B|0)<1){z=1;i=e;return z|0}if((gzL(v,0,2)|0)==0){break}else{z=1}i=e;return z|0}}while(0);v=(c[3530914]|0)+262144|0;if((c[3542200]|0)==0){z=1;i=e;return z|0}A=n+108|0;c[A>>2]=0;y=n+100|0;c[y>>2]=0;B=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[B&16383](n,3)|0;do{if((c[A>>2]|0)!=0){B=c[y>>2]|0;c[o>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](o,3,0)|0;if((B|0)<1){z=1;i=e;return z|0}if((gzL(v,0,3)|0)==0){break}else{z=1}i=e;return z|0}}while(0);v=c[3530678]|0;if((c[3542200]|0)==0){z=1;i=e;return z|0}y=l+108|0;c[y>>2]=0;A=l+100|0;c[A>>2]=0;B=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[B&16383](l,4)|0;do{if((c[y>>2]|0)!=0){B=c[A>>2]|0;c[m>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](m,4,0)|0;if((B|0)<1){z=1;i=e;return z|0}if((gzL(v,0,4)|0)==0){break}else{z=1}i=e;return z|0}}while(0);v=(c[3530678]|0)+524288|0;if((c[3542200]|0)==0){z=1;i=e;return z|0}A=j+108|0;c[A>>2]=0;y=j+100|0;c[y>>2]=0;B=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[B&16383](j,5)|0;do{if((c[A>>2]|0)!=0){B=c[y>>2]|0;c[k>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](k,5,0)|0;if((B|0)<1){z=1;i=e;return z|0}if((gzL(v,0,5)|0)==0){break}else{z=1}i=e;return z|0}}while(0);v=c[2386676]|0;if((c[3542200]|0)==0){z=1;i=e;return z|0}y=f+108|0;c[y>>2]=0;A=f+100|0;c[A>>2]=0;B=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[B&16383](f,6)|0;do{if((c[y>>2]|0)!=0){B=c[A>>2]|0;c[g>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](g,6,0)|0;if((B|0)<1){z=1;i=e;return z|0}if((gzL(v,0,6)|0)==0){break}else{z=1}i=e;return z|0}}while(0);v=c[3530914]|0;blG(v,262144);A=c[3530678]|0;blG(A,524288);y=c[2439884]|0;B=0;do{C=B<<6;gGz(y+C|0,0,64);D=B<<8;E=0;do{F=1<<3-E;G=(c[611632+(E<<2)>>2]|0)+D|0;H=0;do{I=G+(c[3946808+(H<<2)>>2]|0)|0;J=(H<<3)+C|0;K=0;do{L=I+(c[6669416+(K<<2)>>2]|0)|0;if(((d[v+((L|0)/8|0)|0]|0)&128>>>((L&7)>>>0)|0)!=0){L=y+(J+K)|0;a[L]=(d[L]|0|F)&255}K=K+1|0;}while((K|0)<8);H=H+1|0;}while((H|0)<8);E=E+1|0;}while((E|0)<4);B=B+1|0;}while((B|0)<16384);B=c[2439848]|0;y=0;do{v=y<<8;gGz(B+v|0,0,256);E=y<<10;C=0;do{D=1<<3-C;H=(c[611400+(C<<2)>>2]|0)+E|0;F=0;do{G=H+(c[3946808+(F<<2)>>2]|0)|0;K=(F<<4)+v|0;J=0;do{I=G+(c[6669416+(J<<2)>>2]|0)|0;if(((d[A+((I|0)/8|0)|0]|0)&128>>>((I&7)>>>0)|0)!=0){I=B+(K+J)|0;a[I]=(d[I]|0|D)&255}J=J+1|0;}while((J|0)<16);F=F+1|0;}while((F|0)<16);C=C+1|0;}while((C|0)<4);y=y+1|0;}while((y|0)<8192);c[2410674]=1748;gGz(9699632,0,3072);y=c[2427044]|0;c[9681616+(y<<3)>>2]=715288;c[9681620+(y<<3)>>2]=0;c[2427044]=y+1;c[363094]=0;y=c[3531078]|0;c[2424908]=y;c[2425164]=y;c[2425420]=y;B=y+256|0;c[2424909]=B;c[2425165]=B;c[2425421]=B;B=y+512|0;c[2424910]=B;c[2425166]=B;c[2425422]=B;B=y+768|0;c[2424911]=B;c[2425167]=B;c[2425423]=B;B=c[2387388]|0;y=0;A=0;while(1){C=A+4|0;v=B+(A<<8)|0;c[9699632+(C<<2)>>2]=v;c[9700656+(C<<2)>>2]=v;c[9701680+(C<<2)>>2]=v;v=y+1&65535;if((v&65535)<28){y=v;A=v&65535}else{break}}A=c[2387362]|0;y=0;B=0;while(1){v=B+96|0;C=A+((B<<8)+65536)|0;c[9699632+(v<<2)>>2]=C;c[9701680+(v<<2)>>2]=C;C=y+1&65535;if((C&65535)<32){y=C;B=C&65535}else{M=0;N=0;break}}while(1){B=N+128|0;y=A+((N<<8)+32768)|0;c[9699632+(B<<2)>>2]=y;c[9701680+(B<<2)>>2]=y;y=M+1&65535;if((y&65535)<128){M=y;N=y&65535}else{break}}c[2444172]=1656;c[3528598]=1252;c[2410675]=208;c[363094]=-1;fwR(0);A=c[2439330]|0;y=(A|0)==0;if(!y){B=A;gGC(9706056,B|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];B=c[3528484]|0;c[2076596]=B;C=c[2417276]|0;c[3541536]=C;c[1836236]=0;v=c[2385972]|0;E=0;F=0;while(1){c[A+76+(F<<2)>>2]=v+(F<<8);D=E+1&65535;if((D&65535)>127){O=0;P=0;break}else{E=D;F=D&65535}}while(1){F=v+(P<<8)|0;c[A+76+(P+512<<2)>>2]=F;c[A+76+(P+768<<2)>>2]=F;F=O+1&65535;if((F&65535)>127){break}else{O=F;P=F&65535}}v=c[2386126]|0;c[A+588>>2]=v;F=v+256|0;c[A+592>>2]=F;E=v+512|0;c[A+596>>2]=E;D=v+768|0;c[A+600>>2]=D;H=v+1024|0;c[A+604>>2]=H;J=v+1280|0;c[A+608>>2]=J;K=v+1536|0;c[A+612>>2]=K;G=v+1792|0;c[A+616>>2]=G;c[A+1612>>2]=v;c[A+1616>>2]=F;c[A+1620>>2]=E;c[A+1624>>2]=D;c[A+1628>>2]=H;c[A+1632>>2]=J;c[A+1636>>2]=K;c[A+1640>>2]=G;c[A+2636>>2]=v;c[A+3660>>2]=v;c[A+2640>>2]=F;c[A+3664>>2]=F;c[A+2644>>2]=E;c[A+3668>>2]=E;c[A+2648>>2]=D;c[A+3672>>2]=D;c[A+2652>>2]=H;c[A+3676>>2]=H;c[A+2656>>2]=J;c[A+3680>>2]=J;c[A+2660>>2]=K;c[A+3684>>2]=K;c[A+2664>>2]=G;c[A+3688>>2]=G;c[A+4184>>2]=1944;c[A+4180>>2]=2438;if(!y){G=A;gGC(G|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=B;c[2417276]=C;c[1836236]=-1;G=a[9680]|0;K=G?32e3:0;if(G){if(a[9624]|0){G=K*3|0;J=55930;while(1){if((J|0)>(G|0)){J=J>>1}else{Q=1222;R=J;break}}}else{Q=2462;R=K}c[2429380]=R;c[3542124]=Q;mw(3579545,R);J=gGq(262144)|0;c[2406684]=J;gGz(J|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(3579545,11025)}c[(c[3531464]|0)+44348>>2]=314;h[745421]=1.0;c[2436794]=1;h[745420]=1.0;c[2436792]=2;TJ(0,c[2386676]|0,262144);c[2424878]=9681232;c[2405736]=638;h[1202869]=.2;c[2405742]=3;c[2426622]=9622928;h[1202870]=.2;c[2405743]=3;J=c[3530914]|0;G=0;while(1){if((G|0)>=1024){S=0;break}T=9638528+(G<<2)|0;if((c[T>>2]|0)==0){x=2923;break}else{G=G+1|0}}do{if((x|0)==2923){G=gGq(24576)|0;c[T>>2]=G;if((G|0)==0){S=0;break}gGz(G|0,0,24576);S=G}}while(0);c[3529062]=S;c[2438700]=524287;c[3529060]=J;a[7461784]=1;G=9726816;c[G>>2]=0;c[G+4>>2]=0;G=9726800;c[G>>2]=0;c[G+4>>2]=0;c[2429638]=0;c[2437692]=96;c[2431704]=-2;c[2431700]=0;c[2431705]=-2;c[2431701]=0;c[2431706]=-2;c[2431702]=0;G=c[3530678]|0;c[2438136]=0;K=0;while(1){if((K|0)>=1024){U=0;break}V=9638528+(K<<2)|0;if((c[V>>2]|0)==0){x=2928;break}else{K=K+1|0}}do{if((x|0)==2928){K=gGq(1024)|0;c[V>>2]=K;if((K|0)==0){U=0;break}gGz(K|0,0,1024);U=K}}while(0);c[3529066]=U;c[2438702]=1048575;c[3529064]=G;a[7461792]=1;c[2437694]=84;c[2438136]=-2;K=c[642608+(c[2436]<<2)>>2]|0;J=c[K+128>>2]|0;if((c[K+52>>2]&4|0)==0){c[2113068]=J;C=c[K+132>>2]|0;c[2113070]=C;c[2443814]=J;c[2440436]=C;W=J;X=C}else{c[2113070]=J;C=c[K+132>>2]|0;c[2113068]=C;c[2440436]=J;c[2443814]=C;W=C;X=J}J=ag(W<<1,X)|0;C=gGq(J)|0;c[2112926]=C;if((C|0)!=0){gGz(C|0,0,J|0)}a[9624856]=0;J=c[2414770]|0;gGz(J|0,0,(c[2411830]|0)-J|0);c[363094]=0;c[2410673]=0;a[9642688]=0;a[9642689]=0;a[9642682]=0;a[9642683]=0;c[2410665]=0;a[9642680]=a[9642680]|80;J=c[2425163]|0;do{if((J|0)==0){C=c[3528598]|0;if((C|0)==0){Y=0;Z=0;break}K=gj[C&4095](-2)|0;C=c[2425163]|0;B=(K&255)<<8;if((C|0)!=0){_=C;$=B;x=2939;break}C=c[3528598]|0;if((C|0)==0){Y=0;Z=B;break}Y=gj[C&4095](-1)|0;Z=B}else{_=J;$=(d[J+254|0]|0)<<8;x=2939}}while(0);if((x|0)==2939){Y=a[_+255|0]|0;Z=$}c[2410662]=Y&255|Z;c[363094]=-1;J=c[2439330]|0;G=(J|0)==0;if(!G){B=J;gGC(9706056,B|0,76)|0}B=c[2438118]|0;c[2433530]=B;C=c[3528484]|0;c[2076596]=C;K=c[2417276]|0;c[3541536]=K;c[1836236]=0;gGz(9706056,0,76);if(!G){G=J;gGC(G|0,9706056,76)|0}c[2438118]=B;c[3528484]=C;c[2417276]=K;c[1836236]=-1;mx(0);blH();z=0;i=e;return z|0}}while(0);c[2415062]=0;z=1;i=e;return z|0}function bo4(){var a=0,b=0,d=0,e=0;c[2113070]=0;c[2113068]=0;a=c[2112926]|0;if((a|0)!=0){gGr(a);c[2112926]=0}blI();c[2444172]=0;c[3528598]=0;fwZ();a=c[2424800]|0;if((a|0)!=0){gGr(a);c[2424800]=0}a=c[2418166]|0;if((a|0)!=0){gGr(a);c[2418166]=0}a=c[3531464]|0;c[a+44344>>2]=0;c[a+44348>>2]=0;if((a|0)!=0){gGr(a);c[3531464]=0}a=c[2406684]|0;if((a|0)!=0){gGr(a);c[2406684]=0}a=c[2415062]|0;b=0;while(1){if((b|0)>=1024){d=2986;break}e=9638528+(b<<2)|0;if((c[e>>2]|0)==(a|0)){break}else{b=b+1|0}}if((d|0)==2986){c[2415062]=0;return 0}gGr(a);c[e>>2]=0;c[2415062]=0;return 0}function bo5(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;if((a[9624856]|0)!=0){a[9624856]=0;e=c[2414770]|0;gGz(e|0,0,(c[2411830]|0)-e|0);c[363094]=0;c[2410673]=0;a[9642688]=0;a[9642689]=0;a[9642682]=0;a[9642683]=0;c[2410665]=0;a[9642680]=a[9642680]|80;e=c[2425163]|0;do{if((e|0)==0){f=c[3528598]|0;if((f|0)==0){g=0;h=0;break}i=gj[f&4095](-2)|0;f=c[2425163]|0;j=(i&255)<<8;if((f|0)!=0){k=f;l=j;m=2993;break}f=c[3528598]|0;if((f|0)==0){g=0;h=j;break}g=gj[f&4095](-1)|0;h=j}else{k=e;l=d[e+254|0]<<8;m=2993}}while(0);if((m|0)==2993){g=a[k+255|0]|0;h=l}c[2410662]=g&255|h;c[363094]=-1;h=c[2439330]|0;g=(h|0)==0;if(!g){l=h;gGC(9706056,l|0,76)|0}l=c[2438118]|0;c[2433530]=l;k=c[3528484]|0;c[2076596]=k;m=c[2417276]|0;c[3541536]=m;c[1836236]=0;gGz(9706056,0,76);if(!g){g=h;gGC(g|0,9706056,76)|0}c[2438118]=l;c[3528484]=k;c[2417276]=m;c[1836236]=-1;mx(0);blH()}gGz(9550816,-1|0,5);m=0;k=-1;l=-1;g=-1;h=-1;e=-1;do{k=((a[9634200+m|0]&1)<<m^k&255)&255;l=((a[9631960+m|0]&1)<<m^l&255)&255;g=((a[9629880+m|0]&1)<<m^g&255)&255;h=((a[9629056+m|0]&1)<<m^h&255)&255;e=((a[9628816+m|0]&1)<<m^e&255)&255;m=m+1|0;}while((m|0)<8);a[9550816]=k;a[9550817]=l;a[9550818]=g;a[9550819]=h;a[9550820]=e;if((k&12)==0){e=k|12;a[9550816]=e;n=e}else{n=k}if((n&3)==0){a[9550816]=n|3}if((l&12)==0){n=l|12;a[9550817]=n;o=n}else{o=l}if((o&3)==0){a[9550817]=o|3}if((g&12)==0){o=g|12;a[9550818]=o;p=o}else{p=g}if((p&3)==0){a[9550818]=p|3}if((h&12)==0){p=h|12;a[9550819]=p;q=p}else{q=h}if((q&3)==0){a[9550819]=q|3}c[2410673]=0;q=c[2385548]|0;if((q|0)>0){gGz(9752472,0,((q|0)>1?q<<2:4)|0)}c[2433530]=0;q=c[2439330]|0;if((q|0)!=0){h=q;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;c[363094]=0;h=0;q=0;p=0;g=0;L3953:while(1){o=q;l=p;n=g;do{if((n|0)>=100){break L3953}n=n+1|0;l=(fNF((n*665|0)-l|0)|0)+l|0;k=(n*596|0)-o|0;do{if((k|0)<1){r=0}else{if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){e=gfc(k)|0;c[2433530]=(c[2433530]|0)+e;r=e;break}else{c[2433530]=(c[2433530]|0)+k;r=k;break}}}while(0);o=r+o|0;s=c[2112964]|0;}while((s|0)==0);k=a[9688]|0?5:0;e=s+(h<<1<<1)|0;gg[c[3542124]&4095](e,k);TH(0,e,k);h=k+h|0;q=o;p=l;g=n}fNE(0,1);fNF(0)|0;a[9642682]=0;fNF(0)|0;g=c[2112964]|0;do{if((g|0)!=0){p=a[9688]|0?534:0;q=p-h|0;if((p|0)==(h|0)){break}p=g+(h<<1<<1)|0;gg[c[3542124]&4095](p,q);TH(0,p,q)}}while(0);c[363094]=-1;h=c[1836236]|0;g=c[9757320+(h<<2)>>2]|0;if((g|0)!=0){q=g;gGC(q|0,9706056,76)|0}c[9752472+(h<<2)>>2]=c[2433530];c[14113936+(h<<2)>>2]=c[2076596];c[9669104+(h<<2)>>2]=c[3541536];c[1836236]=-1;if((c[2112968]|0)==0){return 0}bo6()|0;return 0}function bo6(){var d=0,e=0,f=0,g=0;if((a[9547856]|0)!=0){d=c[3530146]|0;e=c[2387252]|0;f=0;do{g=ga(b[e+(f<<1)>>1]|0)|0;c[d+(f<<2)>>2]=((g&65535)>>>10<<3&65535)>>>3&31|((g&255)<<3&255)<<8|(((g&65535)>>>5<<3&255|(g&65535)>>>7&4)&255)<<3&2016;f=f+1|0;}while((f|0)<512)}bpj();bpk(1,1,c[2439884]|0);bpl(c[2439848]|0,2);bpk(2,0,c[2439884]|0);bpl(c[2439848]|0,1);bpk(0,0,c[2439884]|0);bpl(c[2439848]|0,0);R8(c[3530146]|0);return 0}function bo7(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;f=i;i=i+144|0;g=f|0;h=f+16|0;j=f+48|0;k=f+64|0;l=f+80|0;m=f+96|0;n=f+112|0;o=f+128|0;p=(e|0)==0;if(!p){c[e>>2]=169732}if((b&96|0)!=0){gGz(o|0,0,12);q=c[2414770]|0;c[o>>2]=q;c[o+4>>2]=(c[2411830]|0)-q;c[o+12>>2]=162152;q=c[2076592]|0;gj[q&4095](o)|0;o=c[2410674]|0;q=c[2410675]|0;if((b&64|0)==0){c[2410674]=o;c[2410675]=q;fw$(b);r=g;s=h|0}else{gGz(n|0,0,12);c[n>>2]=9642648;c[n+4>>2]=56;c[n+12>>2]=163840;t=c[2076592]|0;gj[t&4095](n)|0;gGz(m|0,0,12);c[m>>2]=9707480;c[m+4>>2]=2;c[m+12>>2]=501096;n=c[2076592]|0;gj[n&4095](m)|0;gGz(l|0,0,12);c[l>>2]=9707480;c[l+4>>2]=4;c[l+12>>2]=385184;m=c[2076592]|0;gj[m&4095](l)|0;c[2410674]=o;c[2410675]=q;fw$(b);gGz(k|0,0,12);c[k>>2]=8453216;c[k+4>>2]=4;c[k+12>>2]=107480;q=c[2076592]|0;gj[q&4095](k)|0;gGz(j|0,0,12);c[j>>2]=14168504;c[j+4>>2]=256;c[j+12>>2]=476464;k=c[2076592]|0;gj[k&4095](j)|0;if((b&2|0)==0){u=g;v=h|0}else{j=0;do{mv(0,j,d[14168504+j|0]|0);j=j+1|0;}while((j|0)<256);u=g;v=h|0}if(!p){c[e>>2]=169619}e=h|0;cC(e|0,170224,(h=i,i=i+8|0,c[h>>2]=0,h)|0)|0;i=h;c[g>>2]=9699512;c[g+4>>2]=64;c[g+8>>2]=0;c[g+12>>2]=e;e=c[2076592]|0;gj[e&4095](g)|0;r=u;s=v}blJ(b)}if((b&2|0)==0){i=f;return 0}c[363094]=0;b=c[2443946]|0;if((a[b]&32)==0){v=c[3531078]|0;c[2424908]=v;c[2425164]=v;c[2425420]=v;s=v+256|0;c[2424909]=s;c[2425165]=s;c[2425421]=s;w=v;x=v+512|0}else{v=c[2387252]|0;c[2424908]=v;c[2425164]=v;c[2425420]=v;s=v+256|0;c[2424909]=s;c[2425165]=s;c[2425421]=s;w=v;x=v+512|0}c[2424910]=x;c[2425166]=x;c[2425422]=x;x=w+768|0;c[2424911]=x;c[2425167]=x;c[2425423]=x;x=d[c[2438164]|0]|0;w=x&32;a[b]=w&255;if((w|0)==0){w=c[3531078]|0;c[2424908]=w;c[2425164]=w;c[2425420]=w;b=w+256|0;c[2424909]=b;c[2425165]=b;c[2425421]=b;y=w;z=w+512|0}else{w=c[2387252]|0;c[2424908]=w;c[2425164]=w;c[2425420]=w;b=w+256|0;c[2424909]=b;c[2425165]=b;c[2425421]=b;y=w;z=w+512|0}c[2424910]=z;c[2425166]=z;c[2425422]=z;z=y+768|0;c[2424911]=z;c[2425167]=z;c[2425423]=z;c[3541230]=x&64;z=(x<<13&122880)+65536|0;x=c[2387362]|0;y=0;w=0;while(1){b=w+96|0;v=x+(z+(w<<8))|0;c[9699632+(b<<2)>>2]=v;c[9701680+(b<<2)>>2]=v;v=y+1&65535;if((v&65535)<32){y=v;w=v&65535}else{break}}c[363094]=-1;i=f;return 0}function bo8(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3000836+(b*112|0)>>2];c[a+104>>2]=c[3000840+(b*112|0)>>2];c[a+108>>2]=c[3000844+(b*112|0)>>2];d=0;return d|0}function bo9(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=3000736+(b*112|0);e=0;return e|0}function bpa(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>23){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1289528+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function bpb(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>52){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4141248+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function bpc(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3001732+(b*112|0)>>2];c[a+104>>2]=c[3001736+(b*112|0)>>2];c[a+108>>2]=c[3001740+(b*112|0)>>2];d=0;return d|0}function bpd(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=3001632+(b*112|0);e=0;return e|0}function bpe(b){b=b|0;var d=0,e=0,f=0,g=0,h=0;a[c[2438164]|0]=b&255;d=b&32;a[c[2443946]|0]=d&255;if((d|0)==0){d=c[3531078]|0;c[2424908]=d;c[2425164]=d;c[2425420]=d;e=d+256|0;c[2424909]=e;c[2425165]=e;c[2425421]=e;f=d;g=d+512|0}else{d=c[2387252]|0;c[2424908]=d;c[2425164]=d;c[2425420]=d;e=d+256|0;c[2424909]=e;c[2425165]=e;c[2425421]=e;f=d;g=d+512|0}c[2424910]=g;c[2425166]=g;c[2425422]=g;g=f+768|0;c[2424911]=g;c[2425167]=g;c[2425423]=g;c[3541230]=b&64;g=(b<<13&122880)+65536|0;b=c[2387362]|0;f=0;d=0;while(1){e=d+96|0;h=b+(g+(d<<8))|0;c[9699632+(e<<2)>>2]=h;c[9701680+(e<<2)>>2]=h;h=f+1&65535;if((h&65535)<32){f=h;d=h&65535}else{break}}return}function bpf(a,b){a=a|0;b=b|0;c[2424878]=9681232;c[2420315]=b>>>1<<17&131072;c[2420316]=b<<17&131072;return}function bpg(b){b=b|0;a[9681232]=((b>>4)*17|0)&255;a[9681233]=0;c[2424878]=9681232;a[9681234]=0;a[9681235]=((b&15)*17|0)&255;return}function bph(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;c[f>>2]=c[e>>2]&32;c[d>>2]=(c[d>>2]|b<<13)&16383|c[e>>2]<<8&7936;c[e>>2]=(c[e>>2]|0)>>>6&3|a<<2;return}function bpi(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0;f=c[b>>2]&112;if((f|0)==32){c[d>>2]=3}else if((f|0)==0){c[d>>2]=1}else if((f|0)==16){c[d>>2]=0}else if((f|0)==64){c[d>>2]=2}c[a>>2]=c[a>>2]&8191;c[b>>2]=c[b>>2]&15|16;c[e>>2]=0;return}function bpj(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0;c[2432679]=0;c[2432680]=0;c[2432675]=0;c[2432676]=0;c[2432683]=0;c[2432684]=0;a=d[9729904]|0;b=a&3;do{if((b|0)==2){e=c[3529062]|0;c[2438693]=d[e+6156|0]|0;c[2432675]=1;c[2438697]=0;f=0;while(1){g=f<<4;c[9727856+(f<<2)>>2]=((d[e+((g|1)+6656)|0]|0)<<8|(d[e+(g+6656)|0]|0))+506&511;g=f+1|0;if((g|0)<32){f=g}else{h=e;break}}}else if((b|0)==3){e=c[3529062]|0;c[2438693]=d[e+6156|0]|0;c[2438697]=0;c[2432679]=1;f=0;while(1){g=f<<1;c[9727856+(f<<2)>>2]=((d[e+((g|1)+6656)|0]|0)<<8|(d[e+(g+6656)|0]|0))+506&511;g=f+1|0;if((g|0)<256){f=g}else{h=e;break}}}else{e=c[3529062]|0;f=((d[e+6657|0]|0)<<8|(d[e+6656|0]|0))+506|0;c[2438697]=f&511;if((a&4|0)==0){c[2438693]=d[e+6156|0]|0;h=e;break}c[2438693]=0;c[2432683]=1;g=0;while(1){c[9730168+(((g+f|0)>>>3&63)<<2)>>2]=d[e+(((g|0)/8|0)+6144)|0]|0;i=g+1|0;if((i|0)<512){g=i}else{h=e;break}}}}while(0);b=a&24;if((b|0)==16){c[2438694]=d[h+14348|0]|0;c[2438698]=0;c[2432676]=1;e=0;do{g=e<<4;c[9728880+(e<<2)>>2]=((d[h+((g|1)+14848)|0]|0)<<8|(d[h+(g+14848)|0]|0))+506&511;e=e+1|0;}while((e|0)<32);return}else if((b|0)==24){c[2438694]=d[h+14348|0]|0;c[2438698]=0;c[2432680]=1;b=0;do{e=b<<1;c[9728880+(b<<2)>>2]=((d[h+((e|1)+14848)|0]|0)<<8|(d[h+(e+14848)|0]|0))+506&511;b=b+1|0;}while((b|0)<256);return}else{b=((d[h+14849|0]|0)<<8|(d[h+14848|0]|0))+506|0;c[2438698]=b&511;if((a&32|0)==0){c[2438694]=d[h+14348|0]|0;return}c[2438694]=0;c[2432684]=1;a=0;do{c[9730424+(((a+b|0)>>>3&63)<<2)>>2]=d[h+(((a|0)/8|0)+14336)|0]|0;a=a+1|0;}while((a|0)<512);return}}function bpk(e,f,g){e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;h=i;i=i+64|0;j=h|0;k=h+8|0;l=h+16|0;m=h+24|0;n=h+32|0;o=h+40|0;p=h+48|0;q=h+56|0;if((c[9730712+(e<<2)>>2]|0)!=0){r=e>>4;s=e&3;t=9726800+(s<<2)|0;u=9754768+(s<<2)|0;v=9730712+(s<<2)|0;w=(f|0)==0;x=9726816+(s<<2)|0;y=0;z=c[2112926]|0;while(1){if((y+240-(c[t>>2]|0)&255|0)<(c[2113070]|0)){A=y>>>3<<6;B=9726832+(s<<10)+(y<<2)|0;C=0;do{D=C|A;E=c[3529062]|0;F=d[E+D|0]|0;c[j>>2]=F;c[k>>2]=(d[E+(D+16384)|0]|0)<<8|(d[E+(D+8192)|0]|0);if((s|0)==2){G=d[E+(D+4096)|0]|0;c[j>>2]=G;c[k>>2]=(d[E+(D+20480)|0]|0)<<8|(d[E+(D+12288)|0]|0);H=G}else if((s|0)==1){G=d[E+(D+2048)|0]|0;c[j>>2]=G;c[k>>2]=(d[E+(D+18432)|0]|0)<<8|(d[E+(D+10240)|0]|0);H=G}else{H=F}F=H>>>2&3;G=(c[2429638]|0)==0?d[9720736+F|0]|0:F;c[j>>2]=G<<2&12|H&243;F=H&2;c[l>>2]=0;c[m>>2]=0;gB[c[2437692]&127](s,G>>>2,k,j,l,m);L4123:do{if((c[m>>2]|0)==(r|0)){G=c[l>>2]|0;do{if((G|0)==0){I=0}else{if((c[2432672]&1|0)!=0){I=G;break}c[l>>2]=0;I=0}}while(0);if((F|0)==0){J=0}else{J=(c[2432672]&2|0)==0?0:F<<30>>31}G=C<<3;if((c[v>>2]|0)==0){K=G}else{K=G-((c[B>>2]|0)+104+(c[x>>2]|0)&511)|0}G=(K|0)<-8?K+512|0:K;D=c[2113068]|0;if((G|0)>=(D|0)){break}E=c[k>>2]<<6|(y-(c[u>>2]|0)-(c[t>>2]|0)^J)<<3&56;if((I|0)!=0){c[l>>2]=7}L=c[j>>2]<<4;if(w){M=G;N=0}else{O=G;G=0;while(1){if((O|0)>-1&(O|0)<(D|0)){b[z+(O<<1)>>1]=(d[g+((c[l>>2]^G)+E)|0]|0|L)&65535}P=G+1|0;if((P|0)>=8){break L4123}O=O+1|0;G=P}}while(1){do{if((M|0)>-1&(M|0)<(D|0)){G=a[g+((c[l>>2]^N)+E)|0]|0;if(G<<24>>24==0){break}b[z+(M<<1)>>1]=(G&255|L)&65535}}while(0);G=N+1|0;if((G|0)>=8){break L4123}M=M+1|0;N=G}}}while(0);C=C+1|0;}while((C|0)<64);Q=z+(c[2113068]<<1)|0}else{Q=z}C=y+1|0;if((C|0)<256){y=C;z=Q}else{break}}i=h;return}c[p>>2]=0;Q=e>>4;z=e&3;e=9754784+(z<<2)|0;y=9726816+(z<<2)|0;N=9754768+(z<<2)|0;M=9726800+(z<<2)|0;l=9730696+(z<<2)|0;w=9730728+(z<<2)|0;j=(f|0)==0;f=0;do{I=f<<6;J=f<<3;t=0;do{u=t|I;k=c[3529062]|0;K=d[k+u|0]|0;c[o>>2]=K;c[n>>2]=(d[k+(u+16384)|0]|0)<<8|(d[k+(u+8192)|0]|0);if((z|0)==1){x=d[k+(u+2048)|0]|0;c[o>>2]=x;c[n>>2]=(d[k+(u+18432)|0]|0)<<8|(d[k+(u+10240)|0]|0);R=x}else if((z|0)==2){x=d[k+(u+4096)|0]|0;c[o>>2]=x;c[n>>2]=(d[k+(u+20480)|0]|0)<<8|(d[k+(u+12288)|0]|0);R=x}else{R=K}K=R>>>2&3;x=(c[2429638]|0)==0?d[9720736+K|0]|0:K;c[o>>2]=x<<2&12|R&243;K=R&2;c[q>>2]=0;gB[c[2437692]&127](z,x>>>2,n,o,p,q);L4166:do{if((c[q>>2]|0)==(Q|0)){x=c[p>>2]|0;do{if((x|0)==0){S=0}else{if((c[2432672]&1|0)!=0){S=x;break}c[p>>2]=0;S=0}}while(0);if((K|0)==0){T=0}else{T=(c[2432672]&2|0)==0?0:K}x=(c[y>>2]|0)+(c[e>>2]|0)|0;u=(c[M>>2]|0)+(c[N>>2]|0)|0;if((c[l>>2]|0)==0){U=x}else{U=(c[9726832+(z<<10)+(((J-u|0)>>>3&31)<<2)>>2]|0)+x|0}if((c[w>>2]|0)==0){V=u}else{V=(c[9729912+(z<<8)+(t<<2)>>2]|0)+u|0}u=(t<<3)-(U+104&511)|0;x=J-(V+16&255)|0;k=(u|0)<-8?u+512|0:u;u=(x|0)<-8?x+256|0:x;x=c[2113068]|0;if((k|0)>=(x|0)){break}v=c[2113070]|0;if((u|0)>=(v|0)){break}r=(k|0)>-1;if(j){do{if(r){if(!((k|0)<=(x-8|0)&(u|0)>-1)){break}if((u|0)>(v-8|0)){break}m=(T|0)!=0;s=c[2112926]|0;H=c[n>>2]|0;C=c[o>>2]|0;if((S|0)==0){if(m){Su(s,H,k,u,C,4,0,0,g);break L4166}else{Sq(s,H,k,u,C,4,0,0,g);break L4166}}else{if(m){Sw(s,H,k,u,C,4,0,0,g);break L4166}else{Ss(s,H,k,u,C,4,0,0,g);break L4166}}}}while(0);C=(T|0)!=0;H=c[2112926]|0;s=c[n>>2]|0;m=c[o>>2]|0;if((S|0)==0){if(C){Sv(H,s,k,u,m,4,0,0,g);break}else{Sr(H,s,k,u,m,4,0,0,g);break}}else{if(C){Sx(H,s,k,u,m,4,0,0,g);break}else{St(H,s,k,u,m,4,0,0,g);break}}}else{do{if(r){if(!((k|0)<=(x-8|0)&(u|0)>-1)){break}if((u|0)>(v-8|0)){break}m=(T|0)!=0;s=c[2112926]|0;H=c[n>>2]|0;C=c[o>>2]|0;if((S|0)==0){if(m){Sm(s,H,k,u,C,4,0,g);break L4166}else{Si(s,H,k,u,C,4,0,g);break L4166}}else{if(m){So(s,H,k,u,C,4,0,g);break L4166}else{Sk(s,H,k,u,C,4,0,g);break L4166}}}}while(0);v=(T|0)!=0;x=c[2112926]|0;r=c[n>>2]|0;C=c[o>>2]|0;if((S|0)==0){if(v){Sn(x,r,k,u,C,4,0,g);break}else{Sj(x,r,k,u,C,4,0,g);break}}else{if(v){Sp(x,r,k,u,C,4,0,g);break}else{Sl(x,r,k,u,C,4,0,g);break}}}}}while(0);t=t+1|0;}while((t|0)<64);f=f+1|0;}while((f|0)<32);i=h;return}function bpl(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;f=i;i=i+512|0;g=f|0;h=i;i=i+4|0;i=i+7&-8;j=i;i=i+4|0;i=i+7&-8;k=i;i=i+4|0;i=i+7&-8;l=i;i=i+4|0;i=i+7&-8;gGz(g|0,-1|0,512);m=c[3529066]|0;n=0;do{o=d[m+n|0]|0;if((o&128|0)!=0){c[g+((o&127)<<2)>>2]=n}n=n+8|0;}while((n|0)<1024);n=(e|0)==-1;m=0;do{o=c[g+(m<<2)>>2]|0;L4244:do{if((o|0)!=-1){p=c[3529066]|0;q=o+1|0;c[h>>2]=(d[p+q|0]|0)<<8&7936|(d[p+(o+2)|0]|0);r=d[p+(o+3)|0]|0;c[j>>2]=r;c[k>>2]=0;c[l>>2]=r&128;gL[c[2437694]&255](h,j,k,l);if(!n){if((c[k>>2]|0)!=(e|0)){break}}r=c[3529066]|0;p=a[r+q|0]|0;q=(p&255)>>>5;s=c[616784+(q<<2)>>2]|0;t=c[616752+(q<<2)>>2]|0;if(!((q|0)==2|(q|0)==0)){c[h>>2]=c[h>>2]&-2}if((p&255)>63){c[h>>2]=c[h>>2]&-3}if((208>>>(q>>>0)&1|0)!=0){c[h>>2]=c[h>>2]&-5}do{if((q-5|0)>>>0<3){p=c[h>>2]|0;c[h>>2]=p&-9;if((q|0)!=7){break}c[h>>2]=p&-57}}while(0);q=d[r+(o+6)|0]|0;p=q<<8&256|(d[r+(o+7)|0]|0);u=d[r+(o+4)|0]|0;v=256-(u<<8&256|(d[r+(o+5)|0]|0))|0;w=q&2;x=u&2;y=q>>>2;q=u>>>2;u=128-y<<9;z=128-q<<9;if((q|y|0)==0){y=v-16|0;q=(w|0)!=0;A=s-1|0;B=(x|0)!=0;C=t-1|0;D=c[2438136]|0;E=c[2112926]|0;F=0;while(1){G=y+(F<<4)|0;H=c[616688+((B?C-F|0:F)<<2)>>2]|0;I=0;do{J=(c[616720+((q?A-I|0:I)<<2)>>2]|0)+(c[h>>2]|0)+H|0;K=((I<<4)+p&511)-104-D|0;L=c[j>>2]|0;do{if(q){if(B){SN(E,J,K,G,L,4,0,0,b);break}else{SJ(E,J,K,G,L,4,0,0,b);break}}else{if(B){SL(E,J,K,G,L,4,0,0,b);break}else{SH(E,J,K,G,L,4,0,0,b);break}}}while(0);I=I+1|0;}while((I|0)<(s|0));F=F+1|0;if((F|0)>=(t|0)){break L4244}}}F=(w|0)==0;E=(x|0)==0;B=t-1|0;q=s-1|0;D=-104-(c[2438136]|0)|0;A=c[2112926]|0;C=0;while(1){y=((ag(C,z)|0)+2048>>12)+v|0;r=C+1|0;I=y-16|0;G=(((ag(r,z)|0)+2048|0)>>>12)+v-y<<12;y=B-C|0;if(F){if(E){H=c[616688+(C<<2)>>2]|0;L=0;while(1){K=c[h>>2]|0;J=((ag(L,u)|0)+2048>>12)+p|0;M=L+1|0;N=(((ag(M,u)|0)+2048|0)>>>12)+p-J|0;S2(A,b,(c[616720+(L<<2)>>2]|0)+K+H|0,c[j>>2]<<4,0,D+(J&511)|0,I,0,0,N<<12,G);if((M|0)<(s|0)){L=M}else{break}}}else{L=c[616688+(y<<2)>>2]|0;H=0;while(1){M=c[h>>2]|0;N=((ag(H,u)|0)+2048>>12)+p|0;J=H+1|0;K=(((ag(J,u)|0)+2048|0)>>>12)+p-N|0;S2(A,b,(c[616720+(H<<2)>>2]|0)+M+L|0,c[j>>2]<<4,0,D+(N&511)|0,I,0,x,K<<12,G);if((J|0)<(s|0)){H=J}else{break}}}}else{if(E){H=c[616688+(C<<2)>>2]|0;L=0;while(1){J=c[h>>2]|0;K=((ag(L,u)|0)+2048>>12)+p|0;N=L+1|0;M=(((ag(N,u)|0)+2048|0)>>>12)+p-K|0;S2(A,b,(c[616720+(q-L<<2)>>2]|0)+J+H|0,c[j>>2]<<4,0,D+(K&511)|0,I,w,0,M<<12,G);if((N|0)<(s|0)){L=N}else{break}}}else{L=c[616688+(y<<2)>>2]|0;H=0;while(1){N=c[h>>2]|0;M=((ag(H,u)|0)+2048>>12)+p|0;K=H+1|0;J=(((ag(K,u)|0)+2048|0)>>>12)+p-M|0;S2(A,b,(c[616720+(q-H<<2)>>2]|0)+N+L|0,c[j>>2]<<4,0,D+(M&511)|0,I,w,x,J<<12,G);if((K|0)<(s|0)){H=K}else{break}}}}if((r|0)<(t|0)){C=r}else{break}}}}while(0);m=m+1|0;}while((m|0)<128);i=f;return}function bpm(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;e=i;i=i+32|0;f=e|0;g=e+8|0;h=e+16|0;j=e+24|0;do{if((c[3541238]|0)!=0){if((b-4|0)>>>0>=4){break}k=d[9718033]|0;l=((d[9718032]|0)<<8)+(c[2433420]|0)+(k<<16&196608)|0;c[f>>2]=l>>>5&8191;m=(d[9718034]|0)<<6;c[g>>2]=m&192|k>>>2;c[h>>2]=0;c[j>>2]=m&128;gL[c[2437694]&255](f,g,h,j);n=a[(c[3529064]|0)+((c[f>>2]<<7|b&3|l<<2&124)&c[2438702])|0]|0;i=e;return n|0}}while(0);if((b|0)!=0){n=0;i=e;return n|0}b=c[2384834]|0;c[2384834]=b+1;n=b&1;i=e;return n|0}function bpn(b){b=b|0;var c=0;if((b|0)!=10555648){c=0;return c|0}b=cT()|0;if(a[635128]|a[1232104]){c=(b|256)&65535;return c|0}else{c=b&65535&-257;return c|0}return 0}function bpo(b){b=b|0;var d=0,e=0,f=0,g=0.0,i=0.0;if((b|0)==10502144|(b|0)==10502145|(b|0)==10502146|(b|0)==10502147){if(a[635128]|a[1232104]){d=0;return d|0}e=c[3541512]|0;f=e+552|0;g=+h[f>>3];do{if(g!=0.0){i=+h[6675];if(g-(i+ +gC[c[2429842]&255]())<=0.0){h[f>>3]=0.0;break}d=a[e+563|0]|-128;return d|0}}while(0);d=a[e+563|0]|0;return d|0}else if((b|0)==10555648){b=cT()|0;if(a[635128]|a[1232104]){d=(b|1)&255;return d|0}else{d=b&255&-2;return d|0}}else{d=0;return d|0}return 0}function bpp(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,i=0;if((b-10563588|0)>>>0<60){e=b<<16&4128768;f=(c[2406836]|0)-e|0;if((f|0)<1){return}g=(f|0)>2097152?2097152:f;f=c[2406838]|0;i=f+e|0;gGC(f|0,i|0,g)|0;return}if((b|0)==10502144){if(a[635128]|a[1232104]){return}g=c[3541512]|0;a[g+560|0]=d;a[g+20408|0]=0;return}else if((b|0)==10502147){if(a[635128]|a[1232104]){return}md(0,3,d);return}else if((b|0)==10502145){if(a[635128]|a[1232104]){return}md(0,1,d);return}else if((b|0)==10555648){g=c[2406890]|0;if((d&1)==0){c[g>>2]=1;a[635128]=1;return}else{c[g>>2]=0;a[635128]=0;return}}else if((b|0)==10502146){if(a[635128]|a[1232104]){return}g=c[3541512]|0;a[g+560|0]=d;a[g+20408|0]=1;return}else if((b|0)==10555904){if((d&1)!=0){a[1232104]=0;return}d=c[2439330]|0;b=(d|0)==0;if(!b){g=d;gGC(9706056,g|0,76)|0}g=c[2438118]|0;c[2433530]=g;i=c[3528484]|0;c[2076596]=i;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;gGz(9706056,0,76);if(!b){b=d;gGC(b|0,9706056,76)|0}c[2438118]=g;c[3528484]=i;c[2417276]=f;c[1836236]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385512]|0)>0){f=0;do{mc(f);f=f+1|0;}while((f|0)<(c[2385512]|0))}a[1232104]=1;return}else{return}}function bpq(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,i=0,j=0;if((b|0)==10555904){if((d&256)!=0){a[1232104]=0;return}e=c[2439330]|0;f=(e|0)==0;if(!f){g=e;gGC(9706056,g|0,76)|0}g=c[2438118]|0;c[2433530]=g;i=c[3528484]|0;c[2076596]=i;j=c[2417276]|0;c[3541536]=j;c[1836236]=0;gGz(9706056,0,76);if(!f){f=e;gGC(f|0,9706056,76)|0}c[2438118]=g;c[3528484]=i;c[2417276]=j;c[1836236]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385512]|0)>0){j=0;do{mc(j);j=j+1|0;}while((j|0)<(c[2385512]|0))}a[1232104]=1;return}else if((b|0)==10555648){b=c[2406890]|0;if((d&256)==0){c[b>>2]=1;a[635128]=1;return}else{c[b>>2]=0;a[635128]=0;return}}else{return}}function bpr(e){e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=e&28;if((f|0)==4){e=c[2406860]|0;g=c[e+40>>2]|0;h=(c[2406890]|0)+8|0;i=a[h]|0;a[h]=i+1&255;h=(((i&8)==0?512:256)|g)&65535;g=(a[e+1|0]&64)==0?h|8:h;h=(c[2276108]|0)<88?g|4:g;a[e+36|0]=0;j=h;return j|0}else if((f|0)==0){h=c[2406860]|0;e=d[h+37|0]|0;if((e|0)==4){g=b[h+38>>1]|0;k=b[(c[2406880]|0)+(((g&65535)>>>1&63)<<1)>>1]|0;l=g}else if((e|0)==0){g=b[h+38>>1]|0;k=b[(c[2411360]|0)+((g&65535)>>>1<<1)>>1]|0;l=g}else if((e|0)==8){e=b[h+38>>1]|0;k=b[(c[2411432]|0)+(((e&65535)>>>1&63)<<1)>>1]|0;l=e}else{k=0;l=b[h+38>>1]|0}b[h+38>>1]=(d[h+15|0]|0)+l&65535;j=k;return j|0}else if((f|0)==8){f=c[3528798]|0;k=f-(c[2276108]|0)&511;l=a[(c[2406860]|0)+12|0]|0;h=((k|0)>(f-12|0))+(c[2405426]&65535)&65535;if((a[9623152]&64)==0){m=(h&65535)>234?h-6&65535:h}else{m=(h&65535)>258?h-56&65535:h}if((l&6)==6){h=m<<1;n=(h&3840)!=0|h}else{n=m}j=n<<8|(d[((l&1)==0?7357552:7357040)+k|0]|0);return j|0}else{j=0;return j|0}return 0}function bps(a){a=a|0;var b=0,c=0;b=bpr(a&-2)|0;if((a&1|0)!=0){c=b&255;return c|0}c=(b&65535)>>>8&255;return c|0}function bpt(f,g){f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;h=f&28;if((h|0)==4){f=c[2406860]|0;i=f+36|0;if((a[i]|0)!=0){j=f+32|0;c[j>>2]=c[j>>2]&-65536|g&65535;a[i]=0;bpu();return}j=g&65535;if((j&49152|0)!=32768){k=f+32|0;c[k>>2]=c[k>>2]&65535|j<<16;a[i]=1;return}i=j>>>8&31;a[f+i|0]=g&255;do{if(i>>>0<2){j=d[f+44|0]|0;if((a[f+1|0]&32&j|0)!=0){c[8452200+(c[2394]<<2)>>2]=8198;c[2276080]=1536;if((c[2276079]|0)>>>0>=1536){break}RH(6);break}k=8452200+(c[2394]<<2)|0;if((j&16&d[f|0]|0)==0){c[k>>2]=0;c[2276080]=0;break}c[k>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0>=1024){break}RH(4)}}while(0);if((i|0)==5){c[3528408]=c[3528408]|1}a[(c[2406860]|0)+37|0]=0;return}else if((h|0)==0){i=c[2406860]|0;f=i+36|0;if((a[f]|0)!=0){bpu()}a[f]=0;do{if((c[i+32>>2]&128|0)!=0){if((a[i+1|0]&16)==0){break}if((a[i+23|0]&-64)<<24>>24!=-128){break}f=i+19|0;k=i+20|0;j=d[k]<<8|d[f];l=c[2411360]|0;m=(g&65535)>>>8&255;n=i+38|0;o=b[n>>1]|0;p=a[i+15|0]|0;q=o&65535;a[l+q|0]=g&255;r=p&255;s=p<<24>>24==0?1:(j|0)==0?65535:j;j=s+65535&65535;t=r+q&65535;q=s;while(1){s=t&65535;a[l+s|0]=m;u=q-1|0;if((u|0)==0){break}else{t=s+r&65535;q=u}}b[n>>1]=(ag(j+2&65535,p&255)|0)+o&65535;a[k]=0;a[f]=0;c[3528408]=c[3528408]|16;return}}while(0);q=d[i+37|0]|0;if((q|0)==1){r=i+38|0;t=b[r>>1]|0;if((t&1)==0){v=g}else{v=ga(g|0)|0}b[(c[2411360]|0)+((t&65535)>>>1<<1)>>1]=v;c[3528408]=c[3528408]|16;w=r}else if((q|0)==3){r=i+38|0;v=(e[r>>1]|0)>>>1&63;t=g&65535;m=t<<4&240;l=t&240;u=t>>>4&240;t=m>>>4|m;s=l>>>4|l;l=u>>>4;x=l|u;b[(c[2411432]|0)+(v<<1)>>1]=g;u=c[3541184]|0;b[u+(v<<1)>>1]=(x>>>3|s<<3&2016|t<<8&63488)&65535;y=(l|m<<7|s>>>1<<3&992)&65535;b[u+((v|192)<<1)>>1]=y;b[u+((v|64)<<1)>>1]=y;y=t+128|0;t=s+128|0;s=x+128|0;b[u+((v|128)<<1)>>1]=((y>>>0>255?63488:y<<8&63488)|(t>>>0>255?2016:t<<3&2016)|(s>>>0>255?31:s>>>3&31))&65535;w=r}else if((q|0)==5){q=i+38|0;b[(c[2406880]|0)+(((e[q>>1]|0)>>>1&63)<<1)>>1]=g;w=q}else{w=i+38|0}b[w>>1]=(b[w>>1]|0)+(d[i+15|0]|0)&65535;return}else if((h|0)==16|(h|0)==20){TR(0,g&255);return}else{return}}function bpu(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;e=c[2406860]|0;f=c[e+32>>2]|0;g=f>>>2&12|f>>>30;a[e+37|0]=g&255;h=f>>>16;i=h&16383|f<<14;j=i&65535;k=e+38|0;b[k>>1]=j;if((f&128|0)==0){return}f=a[e+1|0]|0;if((f&16)==0){return}l=(d[e+20|0]|0)<<8|(d[e+19|0]|0);m=(l|0)==0?65535:l;l=d[e+23|0]|0;n=l>>>6;if((n|0)==0|(n|0)==1){o=a[e+15|0]|0;p=(d[e+22|0]|0)<<9|(d[e+21|0]|0)<<1;q=l<<17;l=p|q;do{if((q&14680064|0)==14680064){r=c[2411908]|0;s=r+65536|0;t=r+(p&65534)|0}else{r=c[2406836]|0;if(l>>>0<r>>>0){u=c[2406838]|0;s=u+r|0;t=u+l|0;break}else{return}}}while(0);l=s;s=t;t=(c[e+40>>2]&8|0)==0;do{if(t){if((f&64)==0){p=(ag((c[3528798]<<8|0)/167|0,m)|0)>>8;v=(p>>>1)+p|0;break}p=(224-(c[2405426]|0)|0)*18|0;q=c[3528798]<<8;u=(q|0)/18|0;if((p|0)<(m|0)){r=(ag(p,u)|0)>>8;v=((ag((q|0)/180|0,m-p|0)|0)>>8)+r|0;break}else{v=(ag(u,m)|0)>>8;break}}else{v=(ag((c[3528798]<<8|0)/167|0,m)|0)>>8}}while(0);f=c[2276108]|0;if((-v|0)<0&(f|0)<(v|0)){u=(c[2226884]|0)-f|0;c[2226884]=u;w=0;x=u}else{c[2113056]=(c[2113056]|0)-v;u=(c[2226884]|0)-v|0;c[2226884]=u;w=f-v|0;x=u}c[2276108]=w;if(t){c[2226884]=x-w;c[2276108]=0}if((g|0)==3){w=o&255;x=c[2411432]|0;t=c[3541184]|0;u=s;v=h&127;f=m;while(1){r=v>>>1;p=b[u>>1]|0;q=p&65535;y=q<<4&240;z=q&240;A=q>>>4&240;q=y>>>4|y;B=z>>>4|z;z=A>>>4;C=z|A;b[x+(r<<1)>>1]=p;b[t+(r<<1)>>1]=(C>>>3|B<<3&2016|q<<8&63488)&65535;p=(z|y<<7|B>>>1<<3&992)&65535;b[t+(r+192<<1)>>1]=p;b[t+(r+64<<1)>>1]=p;p=q+128|0;q=B+128|0;B=C+128|0;b[t+(r+128<<1)>>1]=((p>>>0>255?63488:p<<8&63488)|(q>>>0>255?2016:q<<3&2016)|(B>>>0>255?31:B>>>3&31))&65535;B=u+2|0;D=v+w|0;if(D>>>0>127){break}q=f-1|0;if((q|0)==0){break}else{u=B>>>0<l>>>0?B:u-65534|0;v=D;f=q}}E=(D|i&65280)&65535}else if((g|0)==5){D=c[2406880]|0;f=o&255;v=s;u=h&127;h=m;while(1){w=v+2|0;b[D+(u>>>1<<1)>>1]=b[v>>1]|0;F=u+f|0;if(F>>>0>127){break}t=h-1|0;if((t|0)==0){break}else{v=w>>>0<l>>>0?w:v-65534|0;u=F;h=t}}E=(F|i&65280)&65535}else if((g|0)==1){g=c[2411360]|0;F=o&255;o=s;s=i;h=m;while(1){u=s&65535;v=o+2|0;f=b[o>>1]|0;if((s&1|0)==0){G=f}else{G=ga(f|0)|0}b[g+(u>>>1<<1)>>1]=G;H=u+F|0;u=h-1|0;if((u|0)==0){break}else{o=v>>>0<l>>>0?v:o-65534|0;s=H;h=u}}c[3528408]=c[3528408]|16;E=H&65535}else{E=j}b[k>>1]=E;return}else if((n|0)==3){n=c[2411360]|0;E=(d[e+22|0]|0)<<8|(d[e+21|0]|0);j=n+E|0;H=(E+m|0)>65536?65536-E|0:m;do{if((H|0)!=0){a[n+(i&65535)|0]=a[j]|0;m=e+15|0;E=(b[k>>1]|0)+(d[m]|0)&65535;b[k>>1]=E;h=H-1|0;if((h|0)==0){break}else{I=j;J=h;K=E}do{I=I+1|0;a[n+(K&65535)|0]=a[I]|0;K=(b[k>>1]|0)+(d[m]|0)&65535;b[k>>1]=K;J=J-1|0;}while((J|0)!=0)}}while(0);c[3528408]=c[3528408]|16;return}else{return}}function bpv(a,b){a=a|0;b=b|0;var c=0;c=b&255;bpt(a,(c<<8|c)&65535);return}function bpw(b){b=b|0;var d=0;if(a[635128]|a[1232104]){d=0;return d|0}d=a[(c[2411356]|0)+(b&8191)|0]|0;return d|0}function bpx(a){a=a|0;return 0}function bpy(b,d){b=b|0;d=d|0;if(a[635128]|a[1232104]){return}a[(c[2411356]|0)+(b&8191)|0]=d;return}function bpz(b,d){b=b|0;d=d|0;if(a[635128]|a[1232104]){return}a[(c[2411356]|0)+(b&8191)|0]=(d&65535)>>>8&255;return}function bpA(b){b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=b>>>1&15;if((d|0)==0){f=a[9623152]|0;return f|0}else if((d|0)==1){b=c[2418172]|0;g=a[b+1|0]|0;h=g&128;i=c[2414452]|0;j=~(e[i>>1]|0);k=a[i+8|0]|0;i=(g&64)==0;do{if(k<<24>>24==2&i){l=j>>>2&48}else{m=k<<24>>24==3;if(!(i|m^1)){l=j>>>8&15|j&48;break}if(m&i){l=j>>>2&48|15;break}if(i){l=j>>>2&48|j&3;break}else{l=j&63;break}}}while(0);f=(l|h|a[b+4|0]&g&255)&255;return f|0}else if((d|0)==2){g=c[2418172]|0;b=a[g+2|0]|0;h=b&128;l=c[2414452]|0;j=~(e[l+2>>1]|0);i=a[l+9|0]|0;l=(b&64)==0;do{if(i<<24>>24==2&l){n=j>>>2&48}else{k=i<<24>>24==3;if(!(l|k^1)){n=j>>>8&15|j&48;break}if(k&l){n=j>>>2&48|15;break}if(l){n=j>>>2&48|j&3;break}else{n=j&63;break}}}while(0);f=(n|h|a[g+5|0]&b&255)&255;return f|0}else{f=a[(c[2418172]|0)+d|0]|0;return f|0}return 0}function bpB(a){a=a|0;var b=0;b=(bpA(a)|0)&255;return(b<<8|b)&65535|0}function bpC(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=b>>>1&15;do{if((e|0)==1){b=c[2414452]|0;a[b+12|0]=0;f=c[2418172]|0;if((a[f+1|0]&64)!=0){g=f;break}if((d&64)==0){g=f;break}h=b+8|0;a[h]=(a[h]|0)+1&255;g=f}else if((e|0)==2){f=c[2414452]|0;a[f+13|0]=0;h=c[2418172]|0;if((a[h+2|0]&64)!=0){g=h;break}if((d&64)==0){g=h;break}b=f+9|0;a[b]=(a[b]|0)+1&255;g=h}else{g=c[2418172]|0}}while(0);a[g+e|0]=d;return}function bpD(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=d&255;d=b>>>1&15;do{if((d|0)==1){b=c[2414452]|0;a[b+12|0]=0;f=c[2418172]|0;if((a[f+1|0]&64)!=0){g=f;break}if((e&64)==0){g=f;break}h=b+8|0;a[h]=(a[h]|0)+1&255;g=f}else if((d|0)==2){f=c[2414452]|0;a[f+13|0]=0;h=c[2418172]|0;if((a[h+2|0]&64)!=0){g=h;break}if((e&64)==0){g=h;break}b=f+9|0;a[b]=(a[b]|0)+1&255;g=h}else{g=c[2418172]|0}}while(0);a[g+d|0]=e;return}function bpE(b){b=b|0;var d=0;if((b|0)==6){d=(c[2406860]|0)+44|0;a[d]=a[d]&-33;return-1|0}else if((b|0)==4){a[(c[2406860]|0)+44|0]=0;return-1|0}else{return-1|0}return 0}function bpF(a){a=a|0;return 0}function bpG(a,b){a=a|0;b=b|0;return}function bpH(b){b=b|0;var d=0,e=0,f=0.0,g=0.0;d=b&65535;if((b-24832&65535)<7680){e=-1;return e|0}if(b<<16>>16<0){b=(c[(c[2406890]|0)+4>>2]|0)+(d&32767)|0;if(b>>>0>=4194304){e=0;return e|0}e=a[(c[2406838]|0)+(b^1)|0]|0;return e|0}if((d-16384|0)>>>0>=3){e=0;return e|0}d=c[3541512]|0;b=d+552|0;f=+h[b>>3];do{if(f!=0.0){g=+h[6675];if(f-(g+ +gC[c[2429842]&255]())<=0.0){h[b>>3]=0.0;break}e=a[d+563|0]|-128;return e|0}}while(0);e=a[d+563|0]|0;return e|0}function bpI(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=d&65535;if((d-24576&65535)<2){g=c[3531290]|(e&255)<<23&8388608;c[3531290]=g;h=(c[3531288]|0)+1|0;c[3531288]=h;if(h>>>0<9){c[3531290]=g>>>1;return}else{c[3531288]=0;c[(c[2406890]|0)+4>>2]=g;c[3531290]=0;return}}if(d<<16>>16<0){d=c[(c[2406890]|0)+4>>2]|0;g=d+(f&32767)|0;if(g>>>0<4194304){return}if((g|0)==12582929){TR(0,e&255);return}if((g-14680064|0)>>>0>=2097152){return}h=(c[2411908]|0)+((g>>>1&32767)<<1)|0;g=b[h>>1]|0;if((d+f&1|0)==0){b[h>>1]=g&255|(e&255)<<8;return}else{b[h>>1]=g&-256|e&255;return}}if((f|0)==16386){if((c[2394]|0)==0){i=c[3532592]|0}else{c[2394]=0;c[2112932]=c[3532596];g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060];i=g}g=c[3541512]|0;a[g+560|0]=e;a[g+20408|0]=1;if((i|0)!=0){gGC(i|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;return}else if((f|0)==16387){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];i=c[3532592]|0;if((i|0)!=0){gGC(9104152,i|0,280)|0}c[2113054]=c[2113060]}md(0,3,e);i=c[2394]|0;g=c[14130368+(i<<2)>>2]|0;if((g|0)!=0){gGC(g|0,9104152,280)|0}c[8452240+(i<<2)>>2]=c[2113054];c[2394]=-1;return}else if((f|0)==16385){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];i=c[3532592]|0;if((i|0)!=0){gGC(9104152,i|0,280)|0}c[2113054]=c[2113060]}md(0,1,e);i=c[2394]|0;g=c[14130368+(i<<2)>>2]|0;if((g|0)!=0){gGC(g|0,9104152,280)|0}c[8452240+(i<<2)>>2]=c[2113054];c[2394]=-1;return}else if((f|0)==32529|(f|0)==32531|(f|0)==32533|(f|0)==32535){TR(0,e&255);return}else if((f|0)==16384){if((c[2394]|0)==0){j=c[3532592]|0}else{c[2394]=0;c[2112932]=c[3532596];f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];j=f}f=c[3541512]|0;a[f+560|0]=e;a[f+20408|0]=0;if((j|0)!=0){gGC(j|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;return}else{return}}function bpJ(a){a=a|0;return 0}function bpK(a){a=a|0;var d=0,f=0,g=0,h=0;a=c[2414452]|0;d=(e[a+4>>1]|0)^255;f=(e[a+6>>1]|0)^255;a=b[(c[2406890]|0)+42>>1]&64;if((a|0)==0){g=d>>>2&48|d&3|(f>>>2&48|f&3)<<8;h=g&65535;return h|0}else{g=f<<8|d&255|a;h=g&65535;return h|0}return 0}function bpL(a,b){a=a|0;b=b|0;return}function bpM(a,d){a=a|0;d=d|0;a=d<<6&64;d=c[2406890]|0;b[d+42>>1]=a;b[d+44>>1]=a;return}function bpN(a,b){a=a|0;b=b|0;switch(a|0){case 10563835:{a=c[2406838]|0;gGC(a+2621440|0,a+(((b&255)<<19&7864320)+4194304)|0,524288)|0;return};case 10563839:{a=c[2406838]|0;gGC(a+3670016|0,a+(((b&255)<<19&7864320)+4194304)|0,524288)|0;return};case 10563831:{a=c[2406838]|0;gGC(a+1572864|0,a+(((b&255)<<19&7864320)+4194304)|0,524288)|0;return};case 10563837:{a=c[2406838]|0;gGC(a+3145728|0,a+(((b&255)<<19&7864320)+4194304)|0,524288)|0;return};case 10563825:{if(b<<24>>24!=2){return}a=c[2406838]|0;gGC(a|0,a+4194304|0,524288)|0;return};case 10563833:{a=c[2406838]|0;gGC(a+2097152|0,a+(((b&255)<<19&7864320)+4194304)|0,524288)|0;return};case 10563829:{a=c[2406838]|0;gGC(a+1048576|0,a+(((b&255)<<19&7864320)+4194304)|0,524288)|0;return};case 10563827:{a=c[2406838]|0;gGC(a+524288|0,a+(((b&255)<<19&7864320)+4194304)|0,524288)|0;return};default:{return}}}function bpO(b){b=b|0;var e=0,f=0,g=0;if((b&14|0)!=4){e=0;return e|0}b=c[2406890]|0;f=d[b+47|0]|0;if((f|0)==2){g=a[b+46|0]|0;e=(g&255)>>>4|g<<4;return e|0}else if((f|0)==1){e=(d[b+46|0]|0)>>>1;return e|0}else{f=a[b+46|0]|0;e=f<<7|(f&255)>>>7|(f&255)>>>6<<1&2|(f&255)>>>5<<2&4|(f&255)>>>4<<3&8|(f&255)>>>3<<4&16|(f&255)>>>2<<5&32|(f&255)>>>1<<6&64;return e|0}return 0}function bpP(a){a=a|0;return 0}function bpQ(b,d){b=b|0;d=d|0;var e=0;e=b>>>1&7;if((e|0)==0){a[(c[2406890]|0)+46|0]=d;return}else if((e|0)==1){a[(c[2406890]|0)+47|0]=d;return}else{return}}function bpR(a,b){a=a|0;b=b|0;return}function bpS(a,b){a=a|0;b=b|0;var d=0;if((a&14|0)!=0){return}a=c[2406838]|0;d=(c[3527058]|0)+((b&255)<<15)|0;gGC(a|0,d|0,32768)|0;return}function bpT(a,b){a=a|0;b=b|0;return}function bpU(a){a=a|0;return-86|0}function bpV(a){a=a|0;return 0}function bpW(a){a=a|0;return 85}function bpX(a){a=a|0;return 0}function bpY(a){a=a|0;return 0}function bpZ(a){a=a|0;var b=0,d=0;b=c[2406838]|0;d=b+(a>>>1<<16&4128768|4194304)|0;gGC(b|0,d|0,4194304)|0;return 0}function bp_(a){a=a|0;return 0}function bp$(a){a=a|0;var b=0;if((a|0)==10563586){b=1}else if((a|0)==10563646){b=31}else{b=0}return b|0}function bp0(a){a=a|0;var b=0;if((a|0)==4194306){b=-104}else if((a|0)==4194310){b=-16}else if((a|0)==4194308){b=-64}else{b=0}return b|0}function bp1(a){a=a|0;return 0}function bp2(a){a=a|0;return-112|0}function bp3(a){a=a|0;return 0}function bp4(a){a=a|0;return-45|0}function bp5(a){a=a|0;return 0}function bp6(a){a=a|0;return b[(c[2406890]|0)+48>>1]&255|0}function bp7(a){a=a|0;return 0}function bp8(a,d){a=a|0;d=d|0;b[(c[2406890]|0)+48>>1]=d&255;return}function bp9(a,b){a=a|0;b=b|0;return}function bqa(a){a=a|0;var b=0;if((a|0)==4194309){b=-16}else if((a|0)==4194304){b=85}else if((a|0)==4194308){b=-86}else if((a|0)==4194306){b=15}else{b=0}return b|0}function bqb(a){a=a|0;return 0}function bqc(a){a=a|0;return 0}function bqd(a){a=a|0;return 12}function bqe(a){a=a|0;return 0}function bqf(a){a=a|0;return 10}function bqg(a,b){a=a|0;b=b|0;var d=0;a=c[2406838]|0;d=a+((b&255)<<15|4194304)|0;gGC(a|0,d|0,32768)|0;return}function bqh(a,b){a=a|0;b=b|0;return}function bqi(a){a=a|0;var b=0;a=c[2276056]|0;if((a|0)==25008){b=c[2276042]&255}else if((a|0)==68688){b=(cT()|0)&255}else if((a|0)==7204){b=c[2276042]&255}else if((a|0)==68682){b=(cT()|0)&255}else if((a|0)==6018){b=c[2276042]&255}else if((a|0)==25006){b=c[2276042]&255}else if((a|0)==68690){b=c[2276043]&255}else{b=0}return b|0}function bqj(a){a=a|0;return 0}function bqk(a,b){a=a|0;b=b|0;var d=0,e=0;if((b<<24>>24|0)==0){a=c[2406838]|0;d=a+4194304|0;gGC(a|0,d|0,65536)|0;d=a+65536|0;e=a+4259840|0;gGC(d|0,e|0,65536)|0;e=a+131072|0;d=a+4325376|0;gGC(e|0,d|0,65536)|0;d=a+196608|0;e=a+4390912|0;gGC(d|0,e|0,65536)|0;e=a+262144|0;d=a+4456448|0;gGC(e|0,d|0,65536)|0;d=a+327680|0;e=a+4521984|0;gGC(d|0,e|0,65536)|0;e=a+393216|0;d=a+4587520|0;gGC(e|0,d|0,65536)|0;d=a+458752|0;e=a+4653056|0;gGC(d|0,e|0,65536)|0;e=a+524288|0;d=a+4718592|0;gGC(e|0,d|0,65536)|0;d=a+589824|0;e=a+4784128|0;gGC(d|0,e|0,65536)|0;e=a+655360|0;d=a+4849664|0;gGC(e|0,d|0,65536)|0;d=a+720896|0;e=a+4915200|0;gGC(d|0,e|0,65536)|0;e=a+786432|0;d=a+4980736|0;gGC(e|0,d|0,65536)|0;d=a+851968|0;e=a+5046272|0;gGC(d|0,e|0,65536)|0;e=a+917504|0;d=a+5111808|0;gGC(e|0,d|0,65536)|0;d=a+983040|0;e=a+5177344|0;gGC(d|0,e|0,65536)|0;return}else if((b<<24>>24|0)==(-15|0)){e=c[2406838]|0;d=e+4259840|0;gGC(e|0,d|0,65536)|0;a=e+65536|0;gGC(a|0,d|0,65536)|0;a=e+131072|0;gGC(a|0,d|0,65536)|0;a=e+196608|0;gGC(a|0,d|0,65536)|0;a=e+262144|0;gGC(a|0,d|0,65536)|0;a=e+327680|0;gGC(a|0,d|0,65536)|0;a=e+393216|0;gGC(a|0,d|0,65536)|0;a=e+458752|0;gGC(a|0,d|0,65536)|0;a=e+524288|0;gGC(a|0,d|0,65536)|0;a=e+589824|0;gGC(a|0,d|0,65536)|0;a=e+655360|0;gGC(a|0,d|0,65536)|0;a=e+720896|0;gGC(a|0,d|0,65536)|0;a=e+786432|0;gGC(a|0,d|0,65536)|0;a=e+851968|0;gGC(a|0,d|0,65536)|0;a=e+917504|0;gGC(a|0,d|0,65536)|0;a=e+983040|0;gGC(a|0,d|0,65536)|0;return}else if((b<<24>>24|0)==(-45|0)){d=c[2406838]|0;a=d+4390912|0;gGC(d|0,a|0,65536)|0;e=d+65536|0;gGC(e|0,a|0,65536)|0;e=d+131072|0;gGC(e|0,a|0,65536)|0;e=d+196608|0;gGC(e|0,a|0,65536)|0;e=d+262144|0;gGC(e|0,a|0,65536)|0;e=d+327680|0;gGC(e|0,a|0,65536)|0;e=d+393216|0;gGC(e|0,a|0,65536)|0;e=d+458752|0;gGC(e|0,a|0,65536)|0;e=d+524288|0;gGC(e|0,a|0,65536)|0;e=d+589824|0;gGC(e|0,a|0,65536)|0;e=d+655360|0;gGC(e|0,a|0,65536)|0;e=d+720896|0;gGC(e|0,a|0,65536)|0;e=d+786432|0;gGC(e|0,a|0,65536)|0;e=d+851968|0;gGC(e|0,a|0,65536)|0;e=d+917504|0;gGC(e|0,a|0,65536)|0;e=d+983040|0;gGC(e|0,a|0,65536)|0;return}else if((b<<24>>24|0)==(-41|0)){b=c[2406838]|0;a=b+4653056|0;gGC(b|0,a|0,65536)|0;e=b+65536|0;gGC(e|0,a|0,65536)|0;e=b+131072|0;gGC(e|0,a|0,65536)|0;e=b+196608|0;gGC(e|0,a|0,65536)|0;e=b+262144|0;gGC(e|0,a|0,65536)|0;e=b+327680|0;gGC(e|0,a|0,65536)|0;e=b+393216|0;gGC(e|0,a|0,65536)|0;e=b+458752|0;gGC(e|0,a|0,65536)|0;e=b+524288|0;gGC(e|0,a|0,65536)|0;e=b+589824|0;gGC(e|0,a|0,65536)|0;e=b+655360|0;gGC(e|0,a|0,65536)|0;e=b+720896|0;gGC(e|0,a|0,65536)|0;e=b+786432|0;gGC(e|0,a|0,65536)|0;e=b+851968|0;gGC(e|0,a|0,65536)|0;e=b+917504|0;gGC(e|0,a|0,65536)|0;e=b+983040|0;gGC(e|0,a|0,65536)|0;return}else{return}}function bql(a,b){a=a|0;b=b|0;return}function bqm(a){a=a|0;var d=0;if((a|0)==4194306){d=b[(c[2406890]|0)+50>>1]&255;return d|0}else if((a|0)==4194310){d=b[(c[2406890]|0)+52>>1]&255;return d|0}else{d=0;return d|0}return 0}function bqn(a){a=a|0;return 0}function bqo(a,d){a=a|0;d=d|0;if((a|0)==4194304){b[(c[2406890]|0)+50>>1]=d&255;return}else if((a|0)==4194308){b[(c[2406890]|0)+52>>1]=d&255;return}else{return}}function bqp(a,b){a=a|0;b=b|0;return}function bqq(a){a=a|0;return 0}function bqr(a){a=a|0;return 40}function bqs(a){a=a|0;var b=0;if((a|0)==4194306){b=15}else if((a|0)==4194310){b=24}else if((a|0)==4194304){b=85}else if((a|0)==4194308){b=-55}else{b=0}return b|0}function bqt(a){a=a|0;return 0}function bqu(a){a=a|0;return 0}function bqv(a){a=a|0;return 12}function bqw(a){a=a|0;var b=0;if((a|0)==4194306){b=15}else if((a|0)==4194304){b=85}else{b=0}return b|0}function bqx(a){a=a|0;return 0}function bqy(a){a=a|0;return 0}function bqz(a){a=a|0;var b=0;if((a|0)==4718592|(a|0)==4718816|(a|0)==4727968|(a|0)==4753536){b=-22016}else if((a|0)==4884512){b=2560}else if((a|0)==5212192){b=0}else{b=0}return b|0}function bqA(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;if((a|0)==4210688){d=c[2406890]|0;e=d+56|0;f=c[e>>2]&248|b&3;c[e>>2]=f;g=c[2406838]|0;h=g+((f<<17)+4194304)|0;f=d+60|0;d=c[f>>2]<<17;gGC(g|0,h|0,d)|0;d=c[f>>2]<<17;f=g+d|0;h=g+((c[e>>2]<<17)+4194304)|0;gGC(f|0,h|0,d)|0;return}else if((a|0)==4202496){d=c[2406890]|0;c[d+56>>2]=0;c[d+60>>2]=b&31;return}else if((a|0)==4194304){a=c[2406890]|0;d=a+56|0;h=c[d>>2]&7|(b&255)>>>1<<3&56;c[d>>2]=h;b=c[2406838]|0;f=b+((h<<17)+4194304)|0;h=a+60|0;a=c[h>>2]<<17;gGC(b|0,f|0,a)|0;a=c[h>>2]<<17;h=b+a|0;f=b+((c[d>>2]<<17)+4194304)|0;gGC(h|0,f|0,a)|0;return}else{return}}function bqB(a,b){a=a|0;b=b|0;return}function bqC(a,b){a=a|0;b=b|0;var d=0;b=c[2406838]|0;d=b+((a<<16)-801112064&-131072)|0;gGC(b|0,d|0,524288)|0;return}function bqD(a,b){a=a|0;b=b|0;var d=0;b=c[2406838]|0;d=b+((a<<16)-801112064&-131072)|0;gGC(b|0,d|0,524288)|0;return}function bqE(a,b){a=a|0;b=b|0;var d=0;b=c[2406838]|0;d=(c[3527058]|0)+(a>>>1<<17&8257536)|0;gGC(b|0,d|0,1048576)|0;return}function bqF(a,b){a=a|0;b=b|0;return}function bqG(a){a=a|0;var b=0,d=0;do{if((a|0)==7295813){if((c[2276056]|0)==313678){b=c[2276039]&255;break}else{d=(c[154804]|0)+1|0;c[154804]=d;b=d&255;break}}else if((a|0)==6576965){b=-97}else if((a|0)==7066261){if((c[2276056]|0)==1536418){b=80;break}d=(c[154806]|0)+1|0;c[154806]=d;b=d&255}else{b=0}}while(0);return b|0}function bqH(a){a=a|0;return 0}function bqI(a,b){a=a|0;b=b|0;var d=0,e=0;if((b<<24>>24|0)==0){a=c[2406838]|0;d=a+393216|0;e=a+4587520|0;gGC(d|0,e|0,32768)|0;e=a+131072|0;d=a+4325376|0;gGC(e|0,d|0,32768)|0;d=a+360448|0;e=a+4554752|0;gGC(d|0,e|0,32768)|0;return}else if((b<<24>>24|0)==15){e=c[2406838]|0;d=e+360448|0;a=e+4685824|0;gGC(d|0,a|0,32768)|0;return}else if((b<<24>>24|0)==42){a=c[2406838]|0;d=a+393216|0;e=a+5701632|0;gGC(d|0,e|0,32768)|0;return}else if((b<<24>>24|0)==53){b=c[2406838]|0;e=b+131072|0;d=b+5931008|0;gGC(e|0,d|0,32768)|0;return}else{return}}function bqJ(a,b){a=a|0;b=b|0;return}function bqK(b){b=b|0;var d=0,e=0,f=0;d=c[2406890]|0;if((c[d+24>>2]|0)==0){e=(c[2406838]|0)+(b^1)|0;f=a[e]|0;return f|0}else{e=(c[2424744]|0)+(b-(c[d+12>>2]|0)^1)|0;f=a[e]|0;return f|0}return 0}function bqL(a){a=a|0;var d=0,e=0,f=0;d=c[2406890]|0;if((c[d+24>>2]|0)==0){e=(c[2406838]|0)+(a>>>1<<1)|0;f=b[e>>1]|0;return f|0}else{e=(c[2424744]|0)+((a-(c[d+12>>2]|0)|0)>>>1<<1)|0;f=b[e>>1]|0;return f|0}return 0}function bqM(b,d){b=b|0;d=d|0;var e=0;e=c[2406890]|0;if((c[e+24>>2]|0)==0){return}if((c[e+32>>2]|0)!=0){return}a[(c[2424744]|0)+(b-(c[e+12>>2]|0)^1)|0]=d;return}function bqN(a,d){a=a|0;d=d|0;var e=0;e=c[2406890]|0;if((c[e+24>>2]|0)==0){return}if((c[e+32>>2]|0)!=0){return}b[(c[2424744]|0)+((a-(c[e+12>>2]|0)|0)>>>1<<1)>>1]=d;return}function bqO(a){a=a|0;var b=0;if((a&1|0)==0){b=0;return b|0}b=c[(c[2406890]|0)+24>>2]&255;return b|0}function bqP(a){a=a|0;return 0}function bqQ(a,b){a=a|0;b=b|0;if((a&1|0)==0){return}if((b<<24>>24|0)==0){c[(c[2406890]|0)+24>>2]=0;return}else if((b<<24>>24|0)==1){c[(c[2406890]|0)+24>>2]=1;return}else{return}}function bqR(a,b){a=a|0;b=b|0;return}function bqS(b){b=b|0;var d=0;if((b&1|0)==0){d=0;return d|0}d=a[(c[2406890]|0)+40|0]&1^1;return d|0}function bqT(a){a=a|0;return 0}function bqU(b,d){b=b|0;d=d|0;if((b&1|0)==0){return}b=c[2406890]|0;a[b+41|0]=(d&255)>>>1&1;a[b+40|0]=d&1;return}function bqV(a,b){a=a|0;b=b|0;return}function bqW(a){a=a|0;return 0}function bqX(b){b=b|0;return a[(c[2406890]|0)+40|0]&1|0}function bqY(a,b){a=a|0;b=b|0;return}function bqZ(b,d){b=b|0;d=d|0;b=c[2406890]|0;a[b+41|0]=(d&65535)>>>1&1;a[b+40|0]=d&1;return}function bq_(b){b=b|0;var d=0;if((b&1|0)==0){d=0;return d|0}d=a[(c[2406890]|0)+40|0]&1;return d|0}function bq$(a){a=a|0;return 0}function bq0(b,d){b=b|0;d=d|0;if((b&1|0)==0){return}a[(c[2406890]|0)+40|0]=d&1;return}function bq1(a,b){a=a|0;b=b|0;return}function bq2(a){a=a|0;return 0}function bq3(a){a=a|0;return(d[(c[2406890]|0)+40|0]|0)<<7&128|0}function bq4(a,b){a=a|0;b=b|0;return}function bq5(b,d){b=b|0;d=d|0;b=c[2406890]|0;a[b+41|0]=(d&65535)>>>6&1;a[b+40|0]=(d&65535)>>>7&1;return}function bq6(b){b=b|0;var d=0;if((b&1|0)==0){d=0;return d|0}d=a[(c[2406890]|0)+40|0]&1;return d|0}function bq7(a){a=a|0;return 0}function bq8(b,d){b=b|0;d=d|0;b=c[2406890]|0;a[b+41|0]=(d&255)>>>1&1;a[b+40|0]=d&1;return}function bq9(a,b){a=a|0;b=b|0;return}function bra(a,b){a=a|0;b=b|0;return}function brb(a,b){a=a|0;b=b|0;return}function brc(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0;e=i;i=i+584|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;c[2426812]=0;c[2406838]=0;c[2411908]=12582912;c[2411356]=12648448;c[2424744]=12656640;c[2418172]=12722176;c[2411432]=12722192;c[2406880]=12722320;c[2411360]=12722448;c[2406860]=12787984;c[2406890]=12788048;c[3541184]=12788112;c[3527168]=12788624;c[3529092]=12869264;c[3529090]=12869432;c[3529088]=12869600;c[3529086]=12869924;c[2405786]=12870568;c[2414452]=12870904;p=0;while(1){if((p|0)>=1024){break}q=9638528+(p<<2)|0;if((c[q>>2]|0)==0){r=3906;break}else{p=p+1|0}}do{if((r|0)==3906){p=gGq(12870920)|0;c[q>>2]=p;if((p|0)==0){break}c[2426812]=p;gGz(p|0,0,12870920);c[2406838]=p;s=p+12582912|0;c[2405718]=s;c[2411908]=s;c[2411356]=p+12648448;c[2424744]=p+12656640;c[2418172]=p+12722176;c[2411432]=p+12722192;c[2406880]=p+12722320;c[2411360]=p+12722448;c[2406860]=p+12787984;c[2406890]=p+12788048;s=p+12788112|0;c[2411828]=s;c[3541184]=s;c[3527168]=p+12788624;c[3529092]=p+12869264;c[3529090]=p+12869432;c[3529088]=p+12869600;c[3529086]=p+12869924;c[2405786]=p+12870568;c[2414452]=p+12870904;c[2414376]=p+12870920;p=o+108|0;s=o+100|0;c[s>>2]=0;c[p>>2]=0;t=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[t&16383](o,0)|0;t=c[s>>2]|0;if((t|0)!=0){u=0;v=t;do{c[2411322]=(c[2411322]|0)+1;c[2406836]=(c[2406836]|0)+v;u=u+1|0;c[s>>2]=0;c[p>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](o,u)|0;v=c[s>>2]|0;}while((v|0)!=0)}v=n+108|0;c[v>>2]=0;s=n+100|0;c[s>>2]=0;L5038:do{if((c[2411322]|0)!=0){u=l+108|0;p=l+100|0;t=j+108|0;w=j+100|0;x=f+108|0;y=f+100|0;z=0;A=0;do{gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,z)|0;B=c[v>>2]|0;A=(B&8|0)==0?(B&7|0)==7?2097152:(B&6|0)==6?1048577:(B&5|0)==5?1048576:(B&4|0)==0?(B&3|0)==3?131072:(B&2|0)==0?(B&1|0)==0?A:0:1:524288:3145728;C=B&240;do{if((C|0)==32){B=(c[2406838]|0)+A|0;if((c[3542200]|0)==0){break L5038}c[t>>2]=0;c[w>>2]=0;D=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[D&16383](j,z)|0;if((c[t>>2]|0)!=0){D=c[w>>2]|0;c[k>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](k,z,0)|0;if((D|0)<1){break L5038}if((gzL(B,0,z)|0)!=0){break L5038}}B=c[s>>2]>>1;if((B|0)<=0){break}D=0;E=(c[2406838]|0)+A|0;while(1){F=a[E]|0;G=E+1|0;a[E]=a[G]|0;a[G]=F;F=D+1|0;if((F|0)<(B|0)){D=F;E=E+2|0}else{break}}}else if((C|0)==48){if((R6((c[2406838]|0)+A|0,z,2)|0)!=0){break L5038}}else if((C|0)==64){E=(c[2406838]|0)+A|0;if((c[3542200]|0)==0){break L5038}c[x>>2]=0;c[y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,z)|0;if((c[x>>2]|0)!=0){D=c[y>>2]|0;c[g>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](g,z,0)|0;if((D|0)<1){break L5038}if((gzL(E,0,z)|0)!=0){break L5038}}E=c[2406838]|0;D=E+1048576|0;B=E+262144|0;gGC(D|0,B|0,262144)|0;B=0;D=E+A|0;while(1){E=a[D]|0;F=D+1|0;a[D]=a[F]|0;a[F]=E;E=B+1|0;if((E|0)<655360){B=E;D=D+2|0}else{break}}}else if((C|0)==16){D=(c[2406838]|0)+A|0;if((c[3542200]|0)==0){break L5038}c[u>>2]=0;c[p>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,z)|0;if((c[u>>2]|0)==0){break}B=c[p>>2]|0;c[m>>2]=9534384;gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](m,z,0)|0;if((B|0)<1){break L5038}if((gzL(D,0,z)|0)!=0){break L5038}}}while(0);C=c[v>>2]|0;if((C&9|0)==9){D=c[2406838]|0;B=D+2097152|0;gGC(B|0,D|0,2097152)|0}if((C&10|0)==10){C=c[2406838]|0;D=C+3145728|0;gGC(D|0,C|0,1048576)|0}z=z+1|0;}while(z>>>0<(c[2411322]|0)>>>0)}}while(0);fxU(0,425984);if((c[2394]|0)==0){H=c[2112932]|0}else{c[2394]=0;v=c[3532596]|0;c[2112932]=v;s=c[3532592]|0;if((s|0)!=0){gGC(9104152,s|0,280)|0}c[2113054]=c[2113060];H=v}v=c[2406838]|0;s=H|0;z=0;while(1){p=v+z|0;c[s>>2]=p;c[s+131072>>2]=p;p=z+1024|0;if(p>>>0>4194303){break}else{s=s+4|0;z=p}}z=c[2411908]|0;s=H+65280|0;v=16711680;while(1){p=z+(v-16711680)|0;c[s>>2]=p;c[s+65536>>2]=p;c[s+131072>>2]=p;p=v+1024|0;if(p>>>0>16777215){break}else{s=s+4|0;v=p}}c[H+49152>>2]=1;c[H+114688>>2]=1;c[H+180224>>2]=1;c[H+40960>>2]=2;c[H+106496>>2]=2;c[H+172032>>2]=2;c[H+40964>>2]=2;c[H+106500>>2]=2;c[H+172036>>2]=2;c[H+40968>>2]=2;c[H+106504>>2]=2;c[H+172040>>2]=2;c[H+40972>>2]=2;c[H+106508>>2]=2;c[H+172044>>2]=2;c[H+40976>>2]=2;c[H+106512>>2]=2;c[H+172048>>2]=2;c[H+40980>>2]=2;c[H+106516>>2]=2;c[H+172052>>2]=2;c[H+40984>>2]=2;c[H+106520>>2]=2;c[H+172056>>2]=2;c[H+40988>>2]=2;c[H+106524>>2]=2;c[H+172060>>2]=2;c[H+40992>>2]=3;c[H+106528>>2]=3;c[H+172064>>2]=3;c[H+40996>>2]=3;c[H+106532>>2]=3;c[H+172068>>2]=3;c[H+41e3>>2]=3;c[H+106536>>2]=3;c[H+172072>>2]=3;c[H+41004>>2]=3;c[H+106540>>2]=3;c[H+172076>>2]=3;c[H+41008>>2]=3;c[H+106544>>2]=3;c[H+172080>>2]=3;c[H+41012>>2]=3;c[H+106548>>2]=3;c[H+172084>>2]=3;c[H+41016>>2]=3;c[H+106552>>2]=3;c[H+172088>>2]=3;c[H+41020>>2]=3;c[H+106556>>2]=3;c[H+172092>>2]=3;c[H+41216>>2]=4;c[H+106752>>2]=4;c[H+172288>>2]=4;c[H+196608>>2]=138;c[H+196688>>2]=10;c[H+196648>>2]=1722;c[H+196728>>2]=3058;c[H+196612>>2]=326;c[H+196692>>2]=2718;c[H+196652>>2]=1608;c[H+196732>>2]=408;c[H+196616>>2]=2074;c[H+196696>>2]=280;c[H+196656>>2]=3248;c[H+196736>>2]=1704;c[H+196620>>2]=2074;c[H+196700>>2]=280;c[H+196660>>2]=3248;c[H+196740>>2]=1704;c[H+196624>>2]=1270;c[H+196704>>2]=2820;c[H+196664>>2]=1388;c[H+196744>>2]=2248;c[H+196856>>2]=2964;v=c[3532592]|0;if((v|0)!=0){gGC(v|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);v=c[2439330]|0;s=(v|0)==0;if(!s){z=v;gGC(9706056,z|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];z=c[3528484]|0;c[2076596]=z;p=c[2417276]|0;c[3541536]=p;c[1836236]=0;u=c[2411356]|0;A=0;y=0;while(1){c[v+76+(y<<2)>>2]=u+(y<<8);x=A+1&65535;if((x&65535)>31){I=0;J=0;break}else{A=x;y=x&65535}}while(1){c[v+76+(J+256<<2)>>2]=u+(J<<8);y=I+1&65535;if((y&65535)>31){K=0;L=0;break}else{I=y;J=y&65535}}while(1){y=u+(L<<8)|0;c[v+76+(L+512<<2)>>2]=y;c[v+76+(L+768<<2)>>2]=y;y=K+1&65535;if((y&65535)>31){M=32;N=32;break}else{K=y;L=y&65535}}while(1){c[v+76+(N<<2)>>2]=u+((N<<8)-8192);y=M+1&65535;if((y&65535)>63){O=32;P=32;break}else{M=y;N=y&65535}}while(1){c[v+76+(P+256<<2)>>2]=u+((P<<8)-8192);y=O+1&65535;if((y&65535)>63){Q=32;R=32;break}else{O=y;P=y&65535}}while(1){y=u+((R<<8)-8192)|0;c[v+76+(R+512<<2)>>2]=y;c[v+76+(R+768<<2)>>2]=y;y=Q+1&65535;if((y&65535)>63){break}else{Q=y;R=y&65535}}c[v+4180>>2]=2034;c[v+4184>>2]=700;c[v+4172>>2]=300;c[v+4176>>2]=1970;if(!s){u=v;gGC(u|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=z;c[2417276]=p;c[1836236]=-1;c[2424]=6e3;Uo(1,7670453,0,1196,86,0);c[2438228]=7670453;c[2433526]=3248;c[2406676]=148;c[3528472]=444;c[2443846]=265;h[745403]=.5;c[2436782]=1;h[745402]=.5;c[2436780]=2;TS(0,3579545,32768,6,0,1);u=c[2420348]|0;h[u+192>>3]=.25;c[u+200>>2]=3;u=c[2406890]|0;y=u+12|0;A=u+16|0;x=u+20|0;w=u+28|0;t=u+24|0;C=u+36|0;gGz(y|0,0,28);c[2430098]=0;u=c[2436]|0;D=(c[642608+(u<<2)>>2]|0)+60|0;do{if((c[D>>2]&7936|0)!=0){c[y>>2]=2097152;B=c[D>>2]|0;if((B&256|0)==0){S=B}else{c[A>>2]=2098175;S=c[D>>2]|0}if((S&512|0)==0){T=S}else{c[A>>2]=2099199;T=c[D>>2]|0}if((T&1024|0)==0){U=T}else{c[A>>2]=2101247;U=c[D>>2]|0}if((U&2048|0)==0){V=U}else{c[A>>2]=2113535;V=c[D>>2]|0}if((V&4096|0)!=0){c[A>>2]=2162687}c[x>>2]=1;B=(c[2406838]|0)+4194304|0;c[2430098]=B;if((c[2394]|0)==0){W=c[2112932]|0;X=c[3532592]|0}else{c[2394]=0;E=c[3532596]|0;c[2112932]=E;F=c[3532592]|0;if((F|0)!=0){gGC(9104152,F|0,280)|0}c[2113054]=c[2113060];W=E;X=F}c[W+106800>>2]=5;c[W+196668>>2]=72;c[W+196748>>2]=1858;F=(X|0)==0;if(!F){gGC(X|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;if((c[2406836]|0)>>>0>(c[y>>2]|0)>>>0){break}c[t>>2]=1;E=c[2424744]|0;gGz(E|0,-1|0,65536);G=(c[A>>2]|0)+1-(c[y>>2]|0)|0;gGC(B|0,E|0,G)|0;c[2394]=0;G=c[3532596]|0;c[2112932]=G;if(!F){gGC(9104152,X|0,280)|0}F=c[2113060]|0;c[2113054]=F;E=c[y>>2]|0;B=c[A>>2]&16777215;Y=E&16776192;if(Y>>>0<=B>>>0){Z=G+((E>>>10&16383)<<2)|0;E=Y;while(1){c[Z>>2]=6;c[Z+65536>>2]=6;Y=E+1024|0;if(Y>>>0>B>>>0){break}else{Z=Z+4|0;E=Y}}}c[G+196632>>2]=2018;c[G+196712>>2]=3144;c[G+196672>>2]=3124;c[G+196752>>2]=3132;E=c[3532592]|0;if((E|0)!=0){gGC(E|0,9104152,280)|0}c[2113060]=F;c[2394]=-1;c[w>>2]=1}}while(0);p=c[D>>2]|0;if((p&255|0)==9){c[y>>2]=4194304;c[A>>2]=4259839;c[x>>2]=1;z=(c[2406838]|0)+8388608|0;c[2430098]=z;c[t>>2]=1;v=c[2424744]|0;gGz(v|0,-1|0,65536);s=(c[A>>2]|0)+1-(c[y>>2]|0)|0;gGC(z|0,v|0,s)|0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];s=c[3532592]|0;if((s|0)!=0){gGC(9104152,s|0,280)|0}c[2113054]=c[2113060]}s=c[y>>2]|0;v=c[A>>2]&16777215;z=s&16776192;if(z>>>0>v>>>0){_=c[2112932]|0}else{E=c[2112932]|0;Z=E+((s>>>10&16383)<<2)|0;s=z;while(1){c[Z>>2]=6;c[Z+65536>>2]=6;z=s+1024|0;if(z>>>0>v>>>0){_=E;break}else{Z=Z+4|0;s=z}}}c[_+196632>>2]=2018;c[_+196712>>2]=3144;c[_+196672>>2]=3124;c[_+196752>>2]=3132;s=c[3532592]|0;if((s|0)!=0){gGC(s|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;c[w>>2]=1;$=c[D>>2]|0}else{$=p}if(($&8192|0)==0){aa=$}else{c[y>>2]=2097152;c[A>>2]=2098175;c[x>>2]=1;s=(c[2406838]|0)+4194304|0;c[2430098]=s;if((c[2394]|0)==0){ab=c[2112932]|0;ac=c[3532592]|0}else{c[2394]=0;Z=c[3532596]|0;c[2112932]=Z;E=c[3532592]|0;if((E|0)!=0){gGC(9104152,E|0,280)|0}c[2113054]=c[2113060];ab=Z;ac=E}c[ab+41264>>2]=5;c[ab+106800>>2]=5;c[ab+196628>>2]=130;c[ab+196708>>2]=1532;c[ab+196668>>2]=2474;c[ab+196748>>2]=1430;E=(ac|0)==0;if(!E){gGC(ac|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;Z=c[2424744]|0;gGz(Z|0,-1|0,65536);v=(c[A>>2]|0)+1-(c[y>>2]|0)|0;gGC(s|0,Z|0,v)|0;c[2394]=0;v=c[3532596]|0;c[2112932]=v;if(!E){gGC(9104152,ac|0,280)|0}E=c[2113060]|0;c[2113054]=E;Z=c[y>>2]|0;s=c[A>>2]&16777215;z=Z&16776192;if(z>>>0<=s>>>0){B=v+((Z>>>10&16383)<<2)|0;Z=z;while(1){c[B>>2]=6;c[B+65536>>2]=6;z=Z+1024|0;if(z>>>0>s>>>0){break}else{B=B+4|0;Z=z}}}c[v+196632>>2]=2018;c[v+196712>>2]=3144;c[v+196672>>2]=3124;c[v+196752>>2]=3132;Z=c[3532592]|0;if((Z|0)!=0){gGC(Z|0,9104152,280)|0}c[2113060]=E;c[2394]=-1;c[w>>2]=1;aa=c[D>>2]|0}if((aa&255|0)==1){c[C>>2]=1;if((c[2394]|0)==0){ad=c[2112932]|0;ae=c[3532592]|0}else{c[2394]=0;Z=c[3532596]|0;c[2112932]=Z;B=c[3532592]|0;if((B|0)!=0){gGC(9104152,B|0,280)|0}c[2113054]=c[2113060];ad=Z;ae=B}c[ad+8192>>2]=5;c[ad+73728>>2]=5;c[ad+196628>>2]=70;c[ad+196708>>2]=2914;c[ad+196668>>2]=2526;c[ad+196748>>2]=2832;if((ae|0)!=0){gGC(ae|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;af=c[D>>2]|0}else{af=aa}if((af&255|0)==10){c[C>>2]=1;if((c[2394]|0)==0){ag=c[2112932]|0;ah=c[3532592]|0}else{c[2394]=0;B=c[3532596]|0;c[2112932]=B;Z=c[3532592]|0;if((Z|0)!=0){gGC(9104152,Z|0,280)|0}c[2113054]=c[2113060];ag=B;ah=Z}c[ag+8192>>2]=5;c[ag+73728>>2]=5;c[ag+196628>>2]=2002;c[ag+196708>>2]=1428;c[ag+196668>>2]=1460;c[ag+196748>>2]=768;if((ah|0)!=0){gGC(ah|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;ai=c[D>>2]|0}else{ai=af}if(((ai&255)-11|0)>>>0<3){c[C>>2]=1;if((c[2394]|0)==0){aj=c[2112932]|0;ak=c[3532592]|0}else{c[2394]=0;Z=c[3532596]|0;c[2112932]=Z;B=c[3532592]|0;if((B|0)!=0){gGC(9104152,B|0,280)|0}c[2113054]=c[2113060];aj=Z;ak=B}c[aj+8192>>2]=5;c[aj+73728>>2]=5;c[aj+196628>>2]=68;c[aj+196708>>2]=2024;c[aj+196668>>2]=1086;c[aj+196748>>2]=1822;if((ak|0)!=0){gGC(ak|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;al=c[D>>2]|0}else{al=ai}if((al&255|0)==14){c[C>>2]=1;if((c[2394]|0)==0){am=c[2112932]|0;an=c[3532592]|0}else{c[2394]=0;B=c[3532596]|0;c[2112932]=B;Z=c[3532592]|0;if((Z|0)!=0){gGC(9104152,Z|0,280)|0}c[2113054]=c[2113060];am=B;an=Z}c[am+8192>>2]=5;c[am+73728>>2]=5;c[am+196628>>2]=170;c[am+196708>>2]=3204;c[am+196668>>2]=706;c[am+196748>>2]=3266;if((an|0)!=0){gGC(an|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;ao=c[D>>2]|0}else{ao=al}if(((ao&255)-5|0)>>>0<2){c[C>>2]=1;if((c[2394]|0)==0){ap=c[2112932]|0;aq=c[3532592]|0}else{c[2394]=0;Z=c[3532596]|0;c[2112932]=Z;B=c[3532592]|0;if((B|0)!=0){gGC(9104152,B|0,280)|0}c[2113054]=c[2113060];ap=Z;aq=B}c[ap+77824>>2]=5;c[ap+196668>>2]=938;c[ap+196748>>2]=2422;c[ap+14336>>2]=6;c[ap+196632>>2]=3472;c[ap+196712>>2]=1740;if((aq|0)!=0){gGC(aq|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1}L5255:do{if((c[x>>2]|0)==0){if((c[C>>2]|0)!=0){break}B=c[2406838]|0;do{if((a[B+433|0]|0)==82){if((a[B+432|0]|0)!=65){r=4065;break}Z=d[B+436|0]<<16|d[B+437|0]<<24|d[B+439|0]<<8|d[B+438|0];c[y>>2]=Z;s=d[B+440|0]<<16|d[B+441|0]<<24|d[B+443|0]<<8|d[B+442|0];p=Z>>>0>s>>>0|(s-Z|0)>>>0>65535?Z+65535|0:s;c[A>>2]=p;if((p-Z|0)>>>0<2){c[C>>2]=1;ar=1}else{c[x>>2]=1;ar=0}if((Z&1|0)==0){as=Z}else{s=Z-1|0;c[y>>2]=s;as=s}if((p&1|0)==0){c[A>>2]=p+1}p=B+(as&4194303)|0;c[2430098]=p;if((ar|0)==0){at=as;au=p}else{break L5255}}else{r=4065}}while(0);if((r|0)==4065){c[y>>2]=2097152;c[A>>2]=2162687;F=B+2097152|0;c[2430098]=F;at=2097152;au=F}if((c[2406836]|0)>>>0<=at>>>0){c[t>>2]=1}if((c[2394]|0)==0){av=c[2112932]|0;aw=c[3532592]|0}else{c[2394]=0;F=c[3532596]|0;c[2112932]=F;G=c[3532592]|0;if((G|0)!=0){gGC(9104152,G|0,280)|0}c[2113054]=c[2113060];av=F;aw=G}c[av+106800>>2]=5;c[av+196668>>2]=72;c[av+196748>>2]=1858;G=(aw|0)==0;if(!G){gGC(aw|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;if((c[t>>2]|0)==0){break}F=c[2424744]|0;gGz(F|0,-1|0,65536);p=(c[A>>2]|0)+1-(c[y>>2]|0)|0;gGC(au|0,F|0,p)|0;c[2394]=0;p=c[3532596]|0;c[2112932]=p;if(!G){gGC(9104152,aw|0,280)|0}G=c[2113060]|0;c[2113054]=G;F=c[y>>2]|0;s=c[A>>2]&4194303;Z=F&4193280;if(Z>>>0<=s>>>0){z=p+((F>>>10&4095)<<2)|0;F=Z;while(1){c[z>>2]=6;c[z+65536>>2]=6;Z=F+1024|0;if(Z>>>0>s>>>0){break}else{z=z+4|0;F=Z}}}c[p+196632>>2]=2018;c[p+196712>>2]=3144;c[p+196672>>2]=3124;c[p+196752>>2]=3132;F=c[3532592]|0;if((F|0)!=0){gGC(F|0,9104152,280)|0}c[2113060]=G;c[2394]=-1;c[w>>2]=1}}while(0);w=c[D>>2]|0;if(((w&255)-4|0)>>>0<2){if((c[2394]|0)==0){ax=c[2112932]|0;ay=c[3532592]|0}else{c[2394]=0;A=c[3532596]|0;c[2112932]=A;y=c[3532592]|0;if((y|0)!=0){gGC(9104152,y|0,280)|0}c[2113054]=c[2113060];ax=A;ay=y}c[ax+14588>>2]=7;c[ax+80124>>2]=7;c[ax+196636>>2]=54;c[ax+196716>>2]=2306;c[ax+196676>>2]=612;c[ax+196756>>2]=2424;if((ay|0)!=0){gGC(ay|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;az=c[D>>2]|0}else{az=w}if((az&255|0)==7){w=0;while(1){if((w|0)>=1024){aA=0;break}aB=9638528+(w<<2)|0;if((c[aB>>2]|0)==0){r=4101;break}else{w=w+1|0}}do{if((r|0)==4101){w=gGq(5242880)|0;c[aB>>2]=w;if((w|0)==0){aA=0;break}gGz(w|0,0,5242880);aA=w}}while(0);c[3527058]=aA;w=c[2406838]|0;gGC(aA|0,w|0,5242880)|0;D=w+8388608|0;y=aA+4194304|0;gGC(D|0,y|0,1048576)|0;y=w+4194304|0;gGC(y|0,aA|0,4194304)|0;gGC(w|0,aA|0,4194304)|0;if((c[2394]|0)==0){aC=c[2112932]|0;aD=c[3532592]|0}else{c[2394]=0;w=c[3532596]|0;c[2112932]=w;y=c[3532592]|0;if((y|0)!=0){gGC(9104152,y|0,280)|0}c[2113054]=c[2113060];aC=w;aD=y}c[aC+106800>>2]=7;c[aC+196676>>2]=2146;if((aD|0)!=0){gGC(aD|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;y=c[2436]|0;aE=c[(c[642608+(y<<2)>>2]|0)+60>>2]|0;aF=y}else{aE=az;aF=u}y=aE&255;if((y|0)==15|(y|0)==17){y=c[2406890]|0;a[y+46|0]=0;a[y+47|0]=0;y=0;while(1){if((y|0)>=1024){aG=0;break}aH=9638528+(y<<2)|0;if((c[aH>>2]|0)==0){r=4115;break}else{y=y+1|0}}do{if((r|0)==4115){y=gGq(2097152)|0;c[aH>>2]=y;if((y|0)==0){aG=0;break}gGz(y|0,0,2097152);aG=y}}while(0);c[3527058]=aG;y=c[2406838]|0;gGC(aG|0,y|0,2097152)|0;u=y+2097152|0;gGC(u|0,y|0,2097152)|0;if((c[2394]|0)==0){aI=c[2112932]|0}else{c[2394]=0;y=c[3532596]|0;c[2112932]=y;u=c[3532592]|0;if((u|0)!=0){gGC(9104152,u|0,280)|0}c[2113054]=c[2113060];aI=y}y=aI+24576|0;u=6291456;while(1){c[y>>2]=7;c[y+65536>>2]=7;w=u+1024|0;if(w>>>0>7340031){break}else{y=y+4|0;u=w}}c[aI+196636>>2]=832;c[aI+196716>>2]=2688;c[aI+196676>>2]=1104;c[aI+196756>>2]=3438;u=aI+28672|0;y=7340032;while(1){c[u+65536>>2]=8;w=y+1024|0;if(w>>>0>8388607){break}else{u=u+4|0;y=w}}c[aI+196680>>2]=2338;c[aI+196760>>2]=1432;y=c[3532592]|0;if((y|0)!=0){gGC(y|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;y=c[2436]|0;aJ=c[(c[642608+(y<<2)>>2]|0)+60>>2]|0;aK=y}else{aJ=aE;aK=aF}if((aJ&255|0)==16){y=c[2406890]|0;a[y+46|0]=0;a[y+47|0]=0;y=0;while(1){if((y|0)>=1024){aL=0;break}aM=9638528+(y<<2)|0;if((c[aM>>2]|0)==0){r=4133;break}else{y=y+1|0}}do{if((r|0)==4133){y=gGq(3145728)|0;c[aM>>2]=y;if((y|0)==0){aL=0;break}gGz(y|0,0,3145728);aL=y}}while(0);c[3527058]=aL;y=c[2406838]|0;gGC(aL|0,y|0,3145728)|0;u=y+3145728|0;gGC(u|0,y|0,1048576)|0;if((c[2394]|0)==0){aN=c[2112932]|0}else{c[2394]=0;y=c[3532596]|0;c[2112932]=y;u=c[3532592]|0;if((u|0)!=0){gGC(9104152,u|0,280)|0}c[2113054]=c[2113060];aN=y}y=aN+24576|0;u=6291456;while(1){c[y>>2]=7;c[y+65536>>2]=7;w=u+1024|0;if(w>>>0>7340031){break}else{y=y+4|0;u=w}}c[aN+196636>>2]=832;c[aN+196716>>2]=2688;c[aN+196676>>2]=1104;c[aN+196756>>2]=3438;u=aN+28672|0;y=7340032;while(1){c[u+65536>>2]=8;w=y+1024|0;if(w>>>0>8388607){break}else{u=u+4|0;y=w}}c[aN+196680>>2]=2338;c[aN+196760>>2]=1432;y=c[3532592]|0;if((y|0)!=0){gGC(y|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;y=c[2436]|0;aO=c[(c[642608+(y<<2)>>2]|0)+60>>2]|0;aP=y}else{aO=aJ;aP=aK}if((aO&255|0)==18){y=0;while(1){if((y|0)>=1024){aQ=0;break}aR=9638528+(y<<2)|0;if((c[aR>>2]|0)==0){r=4150;break}else{y=y+1|0}}do{if((r|0)==4150){y=gGq(2097157)|0;c[aR>>2]=y;if((y|0)==0){aQ=0;break}gGz(y|0,0,2097157);aQ=y}}while(0);c[3527058]=aQ;y=c[2406838]|0;gGC(aQ|0,y|0,2097157)|0;u=c[2406836]|0;do{if((u|0)!=0){a[aQ]=a[aQ]^64;if(u>>>0>1){aS=1}else{break}do{w=aQ+aS|0;a[w]=a[w]^64;aS=aS+1|0;}while(aS>>>0<u>>>0)}}while(0);u=aQ+4|0;gGC(y|0,u|0,2097152)|0;if((c[2394]|0)==0){aT=c[2112932]|0;aU=c[3532592]|0}else{c[2394]=0;u=c[3532596]|0;c[2112932]=u;G=c[3532592]|0;if((G|0)!=0){gGC(9104152,G|0,280)|0}c[2113054]=c[2113060];aT=u;aU=G}c[aT+196636>>2]=914;c[aT+196716>>2]=1512;c[aT+16384>>2]=8;c[aT+196640>>2]=3576;c[aT+196720>>2]=3434;if((aU|0)!=0){gGC(aU|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;G=c[2436]|0;aV=c[(c[642608+(G<<2)>>2]|0)+60>>2]|0;aW=G}else{aV=aO;aW=aP}if((aV&255|0)==19){G=c[2406836]|0;u=0;while(1){if((u|0)>=1024){aX=0;break}aY=9638528+(u<<2)|0;if((c[aY>>2]|0)==0){r=4167;break}else{u=u+1|0}}do{if((r|0)==4167){u=gGq(G)|0;c[aY>>2]=u;if((u|0)==0){aX=0;break}gGz(u|0,0,G|0);aX=u}}while(0);c[3527058]=aX;G=c[2406838]|0;u=c[2406836]|0;gGC(aX|0,G|0,u)|0;gGC(G|0,aX|0,4194304)|0;u=G+4194304|0;gGC(u|0,aX|0,4194304)|0;u=G+8388608|0;gGC(u|0,aX|0,4194304)|0;if((c[2394]|0)==0){aZ=c[2112932]|0;a_=c[3532592]|0}else{c[2394]=0;u=c[3532596]|0;c[2112932]=u;G=c[3532592]|0;if((G|0)!=0){gGC(9104152,G|0,280)|0}c[2113054]=c[2113060];aZ=u;a_=G}c[aZ+41264>>2]=7;c[aZ+196636>>2]=2522;c[aZ+196716>>2]=1416;if((a_|0)!=0){gGC(a_|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;G=c[2436]|0;a$=c[(c[642608+(G<<2)>>2]|0)+60>>2]|0;a0=G}else{a$=aV;a0=aW}if((a$&255|0)==21){if((c[2394]|0)==0){a1=c[2112932]|0;a2=c[3532592]|0}else{c[2394]=0;G=c[3532596]|0;c[2112932]=G;u=c[3532592]|0;if((u|0)!=0){gGC(9104152,u|0,280)|0}c[2113054]=c[2113060];a1=G;a2=u}c[a1+41264>>2]=7;c[a1+196636>>2]=2416;c[a1+196716>>2]=2044;if((a2|0)!=0){gGC(a2|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;a3=c[(c[642608+(a0<<2)>>2]|0)+60>>2]|0}else{a3=a$}if((a3&255|0)==22){if((c[2394]|0)==0){a4=c[2112932]|0;a5=c[3532592]|0}else{c[2394]=0;u=c[3532596]|0;c[2112932]=u;G=c[3532592]|0;if((G|0)!=0){gGC(9104152,G|0,280)|0}c[2113054]=c[2113060];a4=u;a5=G}c[a4+16384>>2]=7;c[a4+196636>>2]=2156;c[a4+196716>>2]=382;if((a5|0)!=0){gGC(a5|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;a6=c[(c[642608+(a0<<2)>>2]|0)+60>>2]|0}else{a6=a3}if((a6&255|0)==23){if((c[2394]|0)==0){a7=c[2112932]|0;a8=c[3532592]|0}else{c[2394]=0;G=c[3532596]|0;c[2112932]=G;u=c[3532592]|0;if((u|0)!=0){gGC(9104152,u|0,280)|0}c[2113054]=c[2113060];a7=G;a8=u}c[a7+16384>>2]=7;c[a7+196636>>2]=118;c[a7+196716>>2]=2004;c[a7+16400>>2]=8;c[a7+196640>>2]=364;c[a7+196720>>2]=1036;if((a8|0)!=0){gGC(a8|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;a9=c[(c[642608+(a0<<2)>>2]|0)+60>>2]|0}else{a9=a6}if((a9&255|0)==24){if((c[2394]|0)==0){ba=c[2112932]|0;bb=c[3532592]|0}else{c[2394]=0;u=c[3532596]|0;c[2112932]=u;G=c[3532592]|0;if((G|0)!=0){gGC(9104152,G|0,280)|0}c[2113054]=c[2113060];ba=u;bb=G}c[ba+16384>>2]=7;c[ba+81920>>2]=7;c[ba+196636>>2]=3412;c[ba+196716>>2]=2144;c[ba+196676>>2]=1646;c[ba+196756>>2]=3068;if((bb|0)!=0){gGC(bb|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;bc=c[(c[642608+(a0<<2)>>2]|0)+60>>2]|0}else{bc=a9}if((bc&255|0)==25){if((c[2394]|0)==0){bd=c[2112932]|0;be=c[3532592]|0}else{c[2394]=0;G=c[3532596]|0;c[2112932]=G;u=c[3532592]|0;if((u|0)!=0){gGC(9104152,u|0,280)|0}c[2113054]=c[2113060];bd=G;be=u}c[bd+16384>>2]=7;c[bd+196636>>2]=306;c[bd+196716>>2]=2194;if((be|0)!=0){gGC(be|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;bf=c[(c[642608+(a0<<2)>>2]|0)+60>>2]|0}else{bf=bc}if((bf&255|0)==26){if((c[2394]|0)==0){bg=c[2112932]|0;bh=c[3532592]|0}else{c[2394]=0;u=c[3532596]|0;c[2112932]=u;G=c[3532592]|0;if((G|0)!=0){gGC(9104152,G|0,280)|0}c[2113054]=c[2113060];bg=u;bh=G}c[bg+41264>>2]=7;c[bg+196636>>2]=2878;c[bg+196716>>2]=496;if((bh|0)!=0){gGC(bh|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;bi=c[(c[642608+(a0<<2)>>2]|0)+60>>2]|0}else{bi=bf}if((bi&255|0)==27){if((c[2394]|0)==0){bj=c[2112932]|0;bk=c[3532592]|0}else{c[2394]=0;G=c[3532596]|0;c[2112932]=G;u=c[3532592]|0;if((u|0)!=0){gGC(9104152,u|0,280)|0}c[2113054]=c[2113060];bj=G;bk=u}c[bj+41264>>2]=7;c[bj+196636>>2]=2106;c[bj+196716>>2]=1928;if((bk|0)!=0){gGC(bk|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;bl=c[(c[642608+(a0<<2)>>2]|0)+60>>2]|0}else{bl=bi}if((bl&255|0)==28){u=c[2406836]|0;G=0;while(1){if((G|0)>=1024){bm=0;break}bn=9638528+(G<<2)|0;if((c[bn>>2]|0)==0){r=4244;break}else{G=G+1|0}}do{if((r|0)==4244){G=gGq(u)|0;c[bn>>2]=G;if((G|0)==0){bm=0;break}gGz(G|0,0,u|0);bm=G}}while(0);c[3527058]=bm;u=c[2406838]|0;G=c[2406836]|0;gGC(bm|0,u|0,G)|0;G=u+4194304|0;gGC(G|0,bm|0,2097152)|0;G=u+6291456|0;gGC(G|0,bm|0,2097152)|0;gGC(u|0,bm|0,2097152)|0;if((c[2394]|0)==0){bo=c[2112932]|0}else{c[2394]=0;u=c[3532596]|0;c[2112932]=u;G=c[3532592]|0;if((G|0)!=0){gGC(9104152,G|0,280)|0}c[2113054]=c[2113060];bo=u}u=bo+28672|0;G=7340032;while(1){c[u+65536>>2]=7;y=G+1024|0;if(y>>>0>8388607){break}else{u=u+4|0;G=y}}c[bo+196676>>2]=3414;c[bo+196756>>2]=2940;G=c[3532592]|0;if((G|0)!=0){gGC(G|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;G=c[2436]|0;bp=c[(c[642608+(G<<2)>>2]|0)+60>>2]|0;bq=G}else{bp=bl;bq=a0}if((bp&255|0)==29){G=c[2406836]|0;u=0;while(1){if((u|0)>=1024){br=0;break}bs=9638528+(u<<2)|0;if((c[bs>>2]|0)==0){r=4260;break}else{u=u+1|0}}do{if((r|0)==4260){u=gGq(G)|0;c[bs>>2]=u;if((u|0)==0){br=0;break}gGz(u|0,0,G|0);br=u}}while(0);c[3527058]=br;G=c[2406838]|0;u=c[2406836]|0;gGC(br|0,G|0,u)|0;u=G+4194304|0;gGC(u|0,br|0,2097152)|0;u=G+6291456|0;gGC(u|0,br|0,2097152)|0;gGC(G|0,br|0,2097152)|0;if((c[2394]|0)==0){bt=c[2112932]|0}else{c[2394]=0;G=c[3532596]|0;c[2112932]=G;u=c[3532592]|0;if((u|0)!=0){gGC(9104152,u|0,280)|0}c[2113054]=c[2113060];bt=G}G=bt+16384|0;u=4194304;while(1){c[G>>2]=7;y=u+1024|0;if(y>>>0>5242879){break}else{G=G+4|0;u=y}}c[bt+196636>>2]=1540;c[bt+196716>>2]=1070;u=bt+24576|0;G=6291456;while(1){c[u+65536>>2]=8;y=G+1024|0;if(y>>>0>7340031){break}else{u=u+4|0;G=y}}c[bt+196680>>2]=1014;c[bt+196760>>2]=2562;G=c[3532592]|0;if((G|0)!=0){gGC(G|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;G=c[2436]|0;bu=c[(c[642608+(G<<2)>>2]|0)+60>>2]|0;bv=G}else{bu=bp;bv=bq}if((bu&255|0)==30){G=c[2406890]|0;b[G+50>>1]=0;b[G+52>>1]=0;if((c[2394]|0)==0){bw=c[2112932]|0;bx=c[3532592]|0}else{c[2394]=0;G=c[3532596]|0;c[2112932]=G;u=c[3532592]|0;if((u|0)!=0){gGC(9104152,u|0,280)|0}c[2113054]=c[2113060];bw=G;bx=u}c[bw+16384>>2]=7;c[bw+81920>>2]=7;c[bw+196636>>2]=680;c[bw+196716>>2]=686;c[bw+196676>>2]=2994;c[bw+196756>>2]=2584;if((bx|0)!=0){gGC(bx|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;by=c[(c[642608+(bv<<2)>>2]|0)+60>>2]|0}else{by=bu}if((by&255|0)==31){if((c[2394]|0)==0){bz=c[2112932]|0;bA=c[3532592]|0}else{c[2394]=0;u=c[3532596]|0;c[2112932]=u;G=c[3532592]|0;if((G|0)!=0){gGC(9104152,G|0,280)|0}c[2113054]=c[2113060];bz=u;bA=G}c[bz+41264>>2]=7;c[bz+196636>>2]=2940;c[bz+196716>>2]=1772;if((bA|0)!=0){gGC(bA|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;bB=c[(c[642608+(bv<<2)>>2]|0)+60>>2]|0}else{bB=by}if((bB&255|0)==32){if((c[2394]|0)==0){bC=c[2112932]|0;bD=c[3532592]|0}else{c[2394]=0;G=c[3532596]|0;c[2112932]=G;u=c[3532592]|0;if((u|0)!=0){gGC(9104152,u|0,280)|0}c[2113054]=c[2113060];bC=G;bD=u}c[bC+16384>>2]=7;c[bC+196636>>2]=1462;c[bC+196716>>2]=952;if((bD|0)!=0){gGC(bD|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;bE=c[(c[642608+(bv<<2)>>2]|0)+60>>2]|0}else{bE=bB}if((bE&255|0)==33){if((c[2394]|0)==0){bF=c[2112932]|0;bG=c[3532592]|0}else{c[2394]=0;u=c[3532596]|0;c[2112932]=u;G=c[3532592]|0;if((G|0)!=0){gGC(9104152,G|0,280)|0}c[2113054]=c[2113060];bF=u;bG=G}c[bF+41264>>2]=7;c[bF+196636>>2]=3318;c[bF+196716>>2]=2218;if((bG|0)!=0){gGC(bG|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;bH=c[(c[642608+(bv<<2)>>2]|0)+60>>2]|0}else{bH=bE}if((bH&255|0)==34){if((c[2394]|0)==0){bI=c[2112932]|0;bJ=c[3532592]|0}else{c[2394]=0;G=c[3532596]|0;c[2112932]=G;u=c[3532592]|0;if((u|0)!=0){gGC(9104152,u|0,280)|0}c[2113054]=c[2113060];bI=G;bJ=u}c[bI+16384>>2]=7;c[bI+196636>>2]=1336;c[bI+196716>>2]=3098;if((bJ|0)!=0){gGC(bJ|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;bK=c[(c[642608+(bv<<2)>>2]|0)+60>>2]|0}else{bK=bH}if((bK&255|0)==20){if((c[2394]|0)==0){bL=c[2112932]|0}else{c[2394]=0;u=c[3532596]|0;c[2112932]=u;G=c[3532592]|0;if((G|0)!=0){gGC(9104152,G|0,280)|0}c[2113054]=c[2113060];bL=u}u=bL+18432|0;G=4718592;while(1){c[u>>2]=7;y=G+1024|0;if(y>>>0>5242879){break}else{u=u+4|0;G=y}}c[bL+196636>>2]=2190;c[bL+196716>>2]=2278;G=c[3532592]|0;if((G|0)!=0){gGC(G|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;bM=c[(c[642608+(bv<<2)>>2]|0)+60>>2]|0}else{bM=bK}if((bM&255|0)==35){G=c[2406890]|0;c[G+56>>2]=0;c[G+60>>2]=0;G=c[2406836]|0;u=0;while(1){if((u|0)>=1024){bN=0;break}bO=9638528+(u<<2)|0;if((c[bO>>2]|0)==0){r=4334;break}else{u=u+1|0}}do{if((r|0)==4334){u=gGq(G)|0;c[bO>>2]=u;if((u|0)==0){bN=0;break}gGz(u|0,0,G|0);bN=u}}while(0);c[3527058]=bN;G=c[2406838]|0;u=c[2406836]|0;gGC(bN|0,G|0,u)|0;u=G+4194304|0;gGC(u|0,bN|0,524288)|0;u=bN+516096|0;y=0;do{p=G+y|0;gGC(p|0,u|0,8192)|0;y=y+8192|0;}while((y|0)<4194304);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];y=c[3532592]|0;if((y|0)!=0){gGC(9104152,y|0,280)|0}c[2113054]=c[2113060]}y=c[2112932]|0;c[y+81920>>2]=7;c[y+81924>>2]=7;c[y+81928>>2]=7;c[y+81932>>2]=7;c[y+81936>>2]=7;c[y+81940>>2]=7;c[y+81944>>2]=7;c[y+81948>>2]=7;c[y+81952>>2]=7;c[y+81956>>2]=7;c[y+81960>>2]=7;c[y+81964>>2]=7;c[y+81968>>2]=7;c[y+81972>>2]=7;c[y+81976>>2]=7;c[y+81980>>2]=7;c[y+81984>>2]=7;c[y+196676>>2]=1378;c[y+196756>>2]=2618;y=c[3532592]|0;if((y|0)!=0){gGC(y|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;y=c[2436]|0;bP=c[(c[642608+(y<<2)>>2]|0)+60>>2]|0;bQ=y}else{bP=bM;bQ=bv}if((bP&255|0)==36){y=c[2406836]|0;u=0;while(1){if((u|0)>=1024){bR=0;break}bS=9638528+(u<<2)|0;if((c[bS>>2]|0)==0){r=4349;break}else{u=u+1|0}}do{if((r|0)==4349){u=gGq(y)|0;c[bS>>2]=u;if((u|0)==0){bR=0;break}gGz(u|0,0,y|0);bR=u}}while(0);c[3527058]=bR;y=c[2406838]|0;u=c[2406836]|0;gGC(bR|0,y|0,u)|0;u=y+4194304|0;gGC(u|0,bR|0,4194304)|0;if((c[2394]|0)==0){bT=c[2112932]|0;bU=c[3532592]|0}else{c[2394]=0;u=c[3532596]|0;c[2112932]=u;y=c[3532592]|0;if((y|0)!=0){gGC(9104152,y|0,280)|0}c[2113054]=c[2113060];bT=u;bU=y}c[bT+106800>>2]=7;c[bT+196676>>2]=1996;c[bT+196756>>2]=2912;if((bU|0)!=0){gGC(bU|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;y=c[2436]|0;bV=c[(c[642608+(y<<2)>>2]|0)+60>>2]|0;bW=y}else{bV=bP;bW=bQ}if((bV&255|0)==37){y=c[2406836]|0;u=0;while(1){if((u|0)>=1024){bX=0;break}bY=9638528+(u<<2)|0;if((c[bY>>2]|0)==0){r=4363;break}else{u=u+1|0}}do{if((r|0)==4363){u=gGq(y)|0;c[bY>>2]=u;if((u|0)==0){bX=0;break}gGz(u|0,0,y|0);bX=u}}while(0);c[3527058]=bX;y=c[2406838]|0;u=c[2406836]|0;gGC(bX|0,y|0,u)|0;u=y+4194304|0;gGC(u|0,bX|0,2097152)|0;if((c[2394]|0)==0){bZ=c[2112932]|0;b_=c[3532592]|0}else{c[2394]=0;u=c[3532596]|0;c[2112932]=u;y=c[3532592]|0;if((y|0)!=0){gGC(9104152,y|0,280)|0}c[2113054]=c[2113060];bZ=u;b_=y}c[bZ+106800>>2]=7;c[bZ+196676>>2]=1996;c[bZ+196756>>2]=2912;if((b_|0)!=0){gGC(b_|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;y=c[2436]|0;b$=c[(c[642608+(y<<2)>>2]|0)+60>>2]|0;b0=y}else{b$=bV;b0=bW}if((b$&255|0)==38){y=c[2406836]|0;u=0;while(1){if((u|0)>=1024){b1=0;break}b2=9638528+(u<<2)|0;if((c[b2>>2]|0)==0){r=4377;break}else{u=u+1|0}}do{if((r|0)==4377){u=gGq(y)|0;c[b2>>2]=u;if((u|0)==0){b1=0;break}gGz(u|0,0,y|0);b1=u}}while(0);c[3527058]=b1;y=c[2406838]|0;u=c[2406836]|0;gGC(b1|0,y|0,u)|0;gGC(y|0,b1|0,2097152)|0;if((c[2394]|0)==0){b3=c[2112932]|0;b4=c[3532592]|0}else{c[2394]=0;y=c[3532596]|0;c[2112932]=y;u=c[3532592]|0;if((u|0)!=0){gGC(9104152,u|0,280)|0}c[2113054]=c[2113060];b3=y;b4=u}c[b3+106800>>2]=7;c[b3+196676>>2]=436;c[b3+196756>>2]=1102;if((b4|0)!=0){gGC(b4|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;u=c[2436]|0;b5=c[(c[642608+(u<<2)>>2]|0)+60>>2]|0;b6=u}else{b5=b$;b6=b0}if((b5&255|0)==39){u=c[2406836]|0;y=0;while(1){if((y|0)>=1024){b7=0;break}b8=9638528+(y<<2)|0;if((c[b8>>2]|0)==0){r=4391;break}else{y=y+1|0}}do{if((r|0)==4391){y=gGq(u)|0;c[b8>>2]=y;if((y|0)==0){b7=0;break}gGz(y|0,0,u|0);b7=y}}while(0);c[3527058]=b7;u=c[2406838]|0;y=c[2406836]|0;gGC(b7|0,u|0,y)|0;gGC(u|0,b7|0,2097152)|0;y=u+2097152|0;gGC(y|0,b7|0,2097152)|0;y=u+4194304|0;gGC(y|0,b7|0,2097152)|0;y=u+6291456|0;gGC(y|0,b7|0,2097152)|0;if((c[2394]|0)==0){b9=c[2112932]|0}else{c[2394]=0;y=c[3532596]|0;c[2112932]=y;u=c[3532592]|0;if((u|0)!=0){gGC(9104152,u|0,280)|0}c[2113054]=c[2113060];b9=y}y=b9+24576|0;u=6291456;while(1){c[y>>2]=7;G=u+1024|0;if(G>>>0>7340031){break}else{y=y+4|0;u=G}}c[b9+196636>>2]=1916;c[b9+196716>>2]=1778;u=b9+28672|0;y=7340032;while(1){c[u+65536>>2]=8;G=y+1024|0;if(G>>>0>8388607){break}else{u=u+4|0;y=G}}c[b9+196680>>2]=2402;c[b9+196760>>2]=3060;y=c[3532592]|0;if((y|0)!=0){gGC(y|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;y=c[2436]|0;ca=c[(c[642608+(y<<2)>>2]|0)+60>>2]|0;cb=y}else{ca=b5;cb=b6}if((ca&255|0)==40){y=c[2406838]|0;b[y+905630>>1]=18424;b[y+905632>>1]=-16;b[y+905634>>1]=20067;b[y+906350>>1]=20216;b[y+906352>>1]=768;b[y+906396>>1]=24578;cc=c[(c[642608+(cb<<2)>>2]|0)+60>>2]|0}else{cc=ca}if((cc&255|0)==41){y=c[2406838]|0;b[y+24630>>1]=-8192;b[y+9536>>1]=24614;b[y+7888>>1]=24614;b[y+9334>>1]=24610;b[y+516864>>1]=24830;cd=c[(c[642608+(cb<<2)>>2]|0)+60>>2]|0}else{cd=cc}if((cd&255|0)==42){b[(c[2406838]|0)+24630>>1]=-8192}c[2112966]=c[3541184];brf();ce=0;i=e;return ce|0}}while(0);c[2426812]=0;ce=1;i=e;return ce|0}function brd(a){a=a|0;var b=0,d=0;b=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,7670453,0)|0;return a|0}function bre(){return+(+((c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0)/7670453.0)}function brf(){var b=0,d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];b=c[3532592]|0;if((b|0)!=0){gGC(9104152,b|0,280)|0}c[2113054]=c[2113060]}RI();b=c[2394]|0;d=c[14130368+(b<<2)>>2]|0;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[8452240+(b<<2)>>2]=c[2113054];c[2394]=-1;b=c[2439330]|0;d=(b|0)==0;if(!d){e=b;gGC(9706056,e|0,76)|0}e=c[2438118]|0;c[2433530]=e;f=c[3528484]|0;c[2076596]=f;g=c[2417276]|0;c[3541536]=g;c[1836236]=0;gGz(9706056,0,76);if(!d){d=b;gGC(d|0,9706056,76)|0}c[2438118]=e;c[3528484]=f;c[2417276]=g;c[1836236]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385512]|0)>0){g=0;do{mc(g);g=g+1|0;}while((g|0)<(c[2385512]|0))}a[1232104]=1;a[635128]=1;g=a[14164728]|0;f=g&-32;a[9623152]=f;if((g&1)==0){i=f}else{f=c[2406838]|0;e=a[f+496|0]|0;d=e&255;L5793:do{if((e&255)<33){j=0}else{switch(d|0){case 74:{j=1;break L5793;break};case 69:{j=8;break L5793;break};case 65:case 66:case 67:case 68:case 70:{j=d-65|0;break L5793;break};case 85:{j=4;break L5793;break};case 48:case 49:case 50:case 51:case 52:case 53:case 54:case 55:case 56:case 57:{j=d-48|0;break L5793;break};case 97:case 98:case 99:case 100:case 101:case 102:{j=d-97|0;break L5793;break};default:{j=0;break L5793}}}}while(0);d=a[f+497|0]|0;e=d&255;L5803:do{if((d&255)<33){k=j}else{switch(e|0){case 69:{k=j|8;break L5803;break};case 65:case 66:case 67:case 68:case 70:{k=e-65|j;break L5803;break};case 85:{k=j|4;break L5803;break};case 74:{k=j|1;break L5803;break};case 48:case 49:case 50:case 51:case 52:case 53:case 54:case 55:case 56:case 57:{k=e-48|j;break L5803;break};case 97:case 98:case 99:case 100:case 101:case 102:{k=e-97|j;break L5803;break};default:{k=j;break L5803}}}}while(0);j=a[f+498|0]|0;e=j&255;L5813:do{if((j&255)<33){l=k}else{switch(e|0){case 48:case 49:case 50:case 51:case 52:case 53:case 54:case 55:case 56:case 57:{l=e-48|k;break L5813;break};case 65:case 66:case 67:case 68:case 70:{l=e-65|k;break L5813;break};case 74:{l=k|1;break L5813;break};case 69:{l=k|8;break L5813;break};case 85:{l=k|4;break L5813;break};case 97:case 98:case 99:case 100:case 101:case 102:{l=e-97|k;break L5813;break};default:{l=k;break L5813}}}}while(0);k=a[f+499|0]|0;f=k&255;L5823:do{if((k&255)<33){m=l}else{switch(f|0){case 97:case 98:case 99:case 100:case 101:case 102:{m=f-97|l;break L5823;break};case 85:{m=l|4;break L5823;break};case 65:case 66:case 67:case 68:case 70:{m=f-65|l;break L5823;break};case 48:case 49:case 50:case 51:case 52:case 53:case 54:case 55:case 56:case 57:{m=f-48|l;break L5823;break};case 74:{m=l|1;break L5823;break};case 69:{m=l|8;break L5823;break};default:{m=l;break L5823}}}}while(0);l=((m&4|0)==0?(m&8|0)==0?(m&1|0)==0?(m&2|0)==0?-128:64:0:-64:-128)|g&32;a[9623152]=l;i=l}if((i&64)==0){c[2424]=6e3;i=c[3541512]|0;if((i|0)!=0){gGr(i|0);c[3541512]=0}c[2438228]=0;c[2433526]=0;c[2406676]=0;c[3528472]=0;i=c[2406692]|0;if((i|0)!=0){gGr(i);c[2406692]=0}c[2385512]=0;c[2432976]=0;Uo(1,7670453,0,1196,86,0);c[2438228]=7670453;c[2433526]=3248;c[2406676]=148;c[3528472]=444;c[2443846]=265;h[745403]=.5;c[2436782]=1;h[745402]=.5;c[2436780]=2;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385512]|0)>0){i=0;do{mc(i);i=i+1|0;}while((i|0)<(c[2385512]|0))}TT();TS(0,3579545,32768,6,0,1);i=c[2420348]|0;h[i+192>>3]=.25;c[i+200>>2]=3;n=c[2414452]|0;o=n;gGz(o|0,0,16);p=c[2406860]|0;q=p|0;gGz(q|0,0,64);a[q]=4;r=p+1|0;a[r]=4;s=p+12|0;a[s]=-127;t=p+15|0;a[t]=2;u=a[14164728]|0;v=u&255;w=v>>>6;x=w&1;y=x|13320;z=p+40|0;c[z>>2]=y;return}else{c[2424]=5e3;i=c[3541512]|0;if((i|0)!=0){gGr(i|0);c[3541512]=0}c[2438228]=0;c[2433526]=0;c[2406676]=0;c[3528472]=0;i=c[2406692]|0;if((i|0)!=0){gGr(i);c[2406692]=0}c[2385512]=0;c[2432976]=0;Uo(1,7600489,0,2700,98,0);c[2438228]=7600489;c[2433526]=3248;c[2406676]=148;c[3528472]=444;c[2443846]=268;h[745403]=.5;c[2436782]=1;h[745402]=.5;c[2436780]=2;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385512]|0)>0){i=0;do{mc(i);i=i+1|0;}while((i|0)<(c[2385512]|0))}TT();TS(0,3546894,32768,6,0,1);i=c[2420348]|0;h[i+192>>3]=.25;c[i+200>>2]=3;n=c[2414452]|0;o=n;gGz(o|0,0,16);p=c[2406860]|0;q=p|0;gGz(q|0,0,64);a[q]=4;r=p+1|0;a[r]=4;s=p+12|0;a[s]=-127;t=p+15|0;a[t]=2;u=a[14164728]|0;v=u&255;w=v>>>6;x=w&1;y=x|13320;z=p+40|0;c[z>>2]=y;return}}function brg(){var b=0,d=0,e=0,f=0,g=0,h=0;if((c[2392]|0)>=0){b=0;do{d=14130368+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}d=14130384+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}b=b+1|0;}while((b|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;fwZ();b=c[3541512]|0;if((b|0)!=0){gGr(b|0);c[3541512]=0}c[2438228]=0;c[2433526]=0;c[2406676]=0;c[3528472]=0;b=c[2406692]|0;if((b|0)!=0){gGr(b);c[2406692]=0}c[2385512]=0;c[2432976]=0;TT();b=c[2426812]|0;d=0;while(1){if((d|0)>=1024){break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==(b|0)){g=4494;break}else{d=d+1|0}}if((g|0)==4494){gGr(b);c[f>>2]=0}c[2426812]=0;f=c[3527058]|0;b=0;while(1){if((b|0)>=1024){g=4500;break}h=9638528+(b<<2)|0;if((c[h>>2]|0)==(f|0)){break}else{b=b+1|0}}if((g|0)==4500){c[3527058]=0;c[3528798]=0;c[3528796]=0;a[14164656]=0;c[2406836]=0;c[2411322]=0;c[2405426]=0;a[635128]=0;a[1232104]=0;a[9623152]=0;c[2407122]=0;return 0}gGr(f);c[h>>2]=0;c[3527058]=0;c[3528798]=0;c[3528796]=0;a[14164656]=0;c[2406836]=0;c[2411322]=0;c[2405426]=0;a[635128]=0;a[1232104]=0;a[9623152]=0;c[2407122]=0;return 0}function brh(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0.0,u=0.0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,W=0,X=0,Y=0,Z=0,_=0,$=0;if((a[14164656]|0)!=0){brf();a[14164656]=0}if((a[9534312]|0)!=0){f=c[2411432]|0;g=c[3541184]|0;h=0;do{i=e[f+(h<<1)>>1]|0;j=i<<4&240;k=i&240;l=i>>>4&240;i=j>>>4|j;m=k>>>4|k;k=l>>>4;n=k|l;b[g+(h<<1)>>1]=(n>>>3|m<<3&2016|i<<8&63488)&65535;l=(k|j<<7|m>>>1<<3&992)&65535;b[g+(h+192<<1)>>1]=l;b[g+(h+64<<1)>>1]=l;l=i+128|0;i=m+128|0;m=n+128|0;b[g+(h+128<<1)>>1]=((l>>>0>255?63488:l<<8&63488)|(i>>>0>255?2016:i<<3&2016)|(m>>>0>255?31:m>>>3&31))&65535;h=h+1|0;}while((h|0)<64);a[9534312]=0}h=c[2414452]|0;g=h+6|0;f=h+4|0;m=h+2|0;i=h|0;l=h;n=l|0;C=0;b[n>>1]=C&65535;b[n+2>>1]=C>>16;n=l+4|0;C=0;b[n>>1]=C&65535;b[n+2>>1]=C>>16;n=0;l=0;j=0;k=0;o=0;do{l=(l&65535|(a[14164712+n|0]&1)<<n)&65535;b[i>>1]=l;j=(j&65535|(a[14164696+n|0]&1)<<n)&65535;b[m>>1]=j;k=(k&65535|(a[14164680+n|0]&1)<<n)&65535;b[f>>1]=k;o=(o&65535|(a[14164664+n|0]&1)<<n)&65535;b[g>>1]=o;n=n+1|0;}while((n|0)<12);n=c[2392]|0;if((n|0)>=0){gGz(8452240,0,((n|0)>0?(n<<2)+4|0:4)|0)}c[2113054]=0;n=c[2385548]|0;if((n|0)>0){gGz(9752472,0,((n|0)>1?n<<2:4)|0)}c[2433530]=0;c[2407122]=c[3527168];c[3528408]=4;n=c[2406860]|0;o=n+40|0;c[o>>2]=c[o>>2]&-33;if((a[n+12|0]&6)==6){c[3528408]=12}brp(1);g=d[n+10|0]|0;if((a[9623152]&64)==0){p=59659;q=93;r=224;s=262;t=+(c[2438]|0)*127840.89285714287}else{p=70937;q=68;r=(a[n+1|0]&8)==0?224:240;s=313;t=+(c[2438]|0)*152009.78285714285}u=t*.00390625;+V(u)>=1.0?u>0.0?(al(+U(u/4294967296.0),4294967295.0)|0)>>>0:~~+af((u- +(~~u>>>0))/4294967296.0)>>>0:0;n=~~u>>>0;c[3528798]=(n|0)/(s|0)|0;c[3528796]=(p>>>0)/(s>>>0)|0;c[o>>2]=c[o>>2]&-137;o=q+1|0;k=0;f=g;g=0;j=h;while(1){c[2405426]=g;h=j+12|0;m=a[h]|0;a[h]=m+1&255;if((m&255)>25){a[j+8|0]=0}m=j+13|0;h=a[m]|0;a[m]=h+1&255;if((h&255)>25){a[j+9|0]=0}do{if((g|0)>(r|0)){v=f}else{h=f-1|0;if((h|0)>=0){v=h;break}h=c[2406860]|0;m=d[h+10|0]|0;l=h+44|0;a[l]=a[l]|16;if((a[h|0]&16)==0){v=m;break}if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];h=c[3532592]|0;if((h|0)!=0){gGC(9104152,h|0,280)|0}c[2113054]=c[2113060]}c[2113050]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0<1024){RH(4);w=c[2394]|0}else{w=0}h=c[14130368+(w<<2)>>2]|0;if((h|0)!=0){gGC(h|0,9104152,280)|0}c[8452240+(w<<2)>>2]=c[2113054];c[2394]=-1;v=m}}while(0);do{if((g|0)==(r|0)){m=(c[2406860]|0)+40|0;c[m>>2]=c[m>>2]|136;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];m=c[3532592]|0;if((m|0)!=0){gGC(9104152,m|0,280)|0}c[2113054]=c[2113060]}m=c[3528798]|0;Sb(128-m+(ag(m,r)|0)|0);m=c[2394]|0;h=c[14130368+(m<<2)>>2]|0;if((h|0)!=0){gGC(h|0,9104152,280)|0}c[8452240+(m<<2)>>2]=c[2113054];c[2394]=-1;m=c[2406860]|0;h=m+44|0;a[h]=a[h]|32;if((a[m+1|0]&32)==0){break}c[2394]=0;c[2112932]=c[3532596];m=c[3532592]|0;if((m|0)!=0){gGC(9104152,m|0,280)|0}c[2113054]=c[2113060];c[2113050]=8198;c[2276080]=1536;if((c[2276079]|0)>>>0<1536){RH(6);x=c[2394]|0}else{x=0}m=c[14130368+(x<<2)>>2]|0;if((m|0)!=0){gGC(m|0,9104152,280)|0}c[8452240+(x<<2)>>2]=c[2113054];c[2394]=-1}}while(0);m=c[2406860]|0;h=m+1|0;l=a[h]&8;if(l<<24>>24==0&(g|0)<225){y=4553}else{if(l<<24>>24!=0&(g|0)<240){y=4553}}if((y|0)==4553){y=0;l=m+12|0;i=(d[l]|0)>>>3&1;z=c[2407122]|0;A=z+328|0;B=i<<6|a[m+7|0]&63;D=B<<8|B;B=D<<16|D;D=z+8|0;do{c[D+12>>2]=B;c[D+8>>2]=B;c[D+4>>2]=B;c[D>>2]=B;D=D+16|0;}while(D>>>0<A>>>0);A=a[h]|0;if((A&64)==0){E=A}else{A=(a[l]&1)==0;D=A?264:328;B=A?32:40;A=d[m+18|0]|0;z=A<<3&248;F=(c[2405426]|0)<(z|0)^(A&128|0)!=0;G=F&1;do{if(F){H=G;I=z;J=A;y=4563}else{L=d[m+17|0]|0;M=L&31;N=(M|0)!=0;if((L&128|0)==0){if(!N){H=G;I=0;J=L;y=4563;break}H=M>>>0<B>>>1>>>0?2:1;I=M;J=L;y=4563;break}if(N){H=M>>>0<B>>>1>>>0?2:G;I=M;J=L;y=4563;break}else{brj(1,c[3529090]|0,B,i);O=L;P=0;y=4564;break}}}while(0);do{if((y|0)==4563){y=0;brj(1,c[3529090]|0,B,i);if((H|0)==1){O=J;P=I;y=4564;break}G=c[3529092]|0;if((H|0)==2){m=(J&128|0)!=0;brj(0,G,m?I<<1:B,i);brk(m?I:0,m?B>>>1:I,0,i);Q=J;R=I;S=2;T=0;break}else{brj(0,G,B,i);Q=J;R=I;S=H;T=0;break}}}while(0);if((y|0)==4564){y=0;brk(0,B>>>1,0,i);Q=O;R=P;S=1;T=1}brl(c[3529088]|0,D,0,i);G=c[3529090]|0;if((c[G>>2]|0)!=0){brm(G,i)}do{if(T){brk(0,B>>>1,1,i)}else{G=c[3529092]|0;m=(c[G>>2]|0)!=0;if((S|0)!=2){if(!m){break}brm(G,i);break}if(m){brm(G,i)}G=(Q&128|0)!=0;brk(G?R:0,G?B>>>1:R,1,i)}}while(0);brl(c[3529088]|0,D,1,i);E=a[(c[2406860]|0)+1|0]|0}c[2407122]=(c[3527168]|0)+((((E&8)==0?9:1)+(c[2405426]|0)|0)*336|0)}if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];B=c[3532592]|0;if((B|0)!=0){gGC(9104152,B|0,280)|0}c[2113054]=c[2113060]}Sb(ag(c[3528798]|0,g)|0);B=c[2394]|0;G=c[14130368+(B<<2)>>2]|0;if((G|0)!=0){gGC(G|0,9104152,280)|0}c[8452240+(B<<2)>>2]=c[2113054];c[2394]=-1;if(a[1232104]|a[635128]^1){W=k}else{B=c[2439330]|0;if((B|0)!=0){G=B;gGC(9706056,G|0,76)|0}b[4853030]=c[2426515]&65535;G=c[2438118]|0;c[2433530]=G;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;m=c[3528796]|0;do{if((m|0)<1){X=0;Y=G}else{if((a[B+4188|0]|0)==0){A=gfc(m)|0;z=(c[2433530]|0)+A|0;c[2433530]=z;X=A;Y=z;break}else{z=G+m|0;c[2433530]=z;X=m;Y=z;break}}}while(0);if((g|0)==(q|0)){a[9706117]=1}if((g|0)==(o|0)){a[9706117]=0}m=c[1836236]|0;G=c[9757320+(m<<2)>>2]|0;if((G|0)!=0){B=G;gGC(B|0,9706056,76)|0}c[9752472+(m<<2)>>2]=Y;c[14113936+(m<<2)>>2]=c[2076596];c[9669104+(m<<2)>>2]=c[3541536];c[1836236]=-1;W=X+k|0}m=g+1|0;if((m|0)>=(s|0)){break}k=W;f=v;g=m;j=c[2414452]|0}j=c[2112968]|0;L6037:do{if((j|0)!=0){g=j;do{if((a[(c[2406860]|0)+12|0]&1)==0){v=a[14164729]&3;if((v|0)==0){break}else if((v|0)==1){v=c[3527168]|0;f=c[3541184]|0;k=0;s=j+64|0;while(1){X=(k*336|0)+3032|0;gGz(s-64|0,0,64);Y=0;do{b[s+(Y<<1)>>1]=b[f+(d[v+(X+Y)|0]<<1)>>1]|0;Y=Y+1|0;}while((Y|0)<256);gGz(s+512|0,0,64);Y=k+1|0;if((Y|0)<224){k=Y;s=s+640|0}else{break L6037}}}else{s=c[3527168]|0;k=c[3541184]|0;v=0;f=g;while(1){Y=(v*336|0)+3032|0;X=0;o=0;while(1){b[f+(o<<1)>>1]=b[k+(d[s+(Y+(X>>>16))|0]<<1)>>1]|0;q=o+1|0;if((q|0)<320){X=X+52428|0;o=q}else{break}}o=v+1|0;if((o|0)<224){v=o;f=f+640|0}else{break L6037}}}}}while(0);f=c[3527168]|0;v=c[3541184]|0;s=0;k=g;while(1){o=(s*336|0)+3032|0;X=0;do{b[k+(X<<1)>>1]=b[v+(d[f+(o+X)|0]<<1)>>1]|0;X=X+1|0;}while((X|0)<320);X=s+1|0;if((X|0)<224){s=X;k=k+640|0}else{break}}}}while(0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];j=c[3532592]|0;if((j|0)!=0){gGC(9104152,j|0,280)|0}c[2113054]=c[2113060]}j=gGU(n,(n|0)<0|0?-1:0,2048e6,0)|0;k=c[2438228]|0;s=gGS(j,K,k,(k|0)<0|0?-1:0)|0;k=s;Sb(n);n=c[2443830]|0;if((n|0)<1073676288){c[2443830]=n-k}n=c[2443831]|0;if((n|0)<1073676288){c[2443831]=n-k}n=(c[3528512]|0)-k|0;c[3528512]=(n|0)<0?0:n;n=c[2394]|0;k=c[14130368+(n<<2)>>2]|0;if((k|0)!=0){gGC(k|0,9104152,280)|0}c[8452240+(n<<2)>>2]=c[2113054];c[2394]=-1;if(a[635128]&(a[1232104]^1)&(W|0)<(p|0)){n=c[2439330]|0;if((n|0)!=0){k=n;gGC(9706056,k|0,76)|0}b[4853030]=c[2426515]&65535;k=c[2438118]|0;c[2433530]=k;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;s=p-W|0;do{if((s|0)<1){Z=0;_=n;$=k}else{if((a[n+4188|0]|0)==0){W=gfc(s)|0;p=(c[2433530]|0)+W|0;c[2433530]=p;W=c[1836236]|0;Z=W;_=c[9757320+(W<<2)>>2]|0;$=p;break}else{p=k+s|0;c[2433530]=p;Z=0;_=n;$=p;break}}}while(0);if((_|0)!=0){n=_;gGC(n|0,9706056,76)|0}c[9752472+(Z<<2)>>2]=$;c[14113936+(Z<<2)>>2]=c[2076596];c[9669104+(Z<<2)>>2]=c[3541536];c[1836236]=-1}Z=c[2112964]|0;if((Z|0)==0){return 0}if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];$=c[3532592]|0;if(($|0)!=0){gGC(9104152,$|0,280)|0}c[2113054]=c[2113060]}gg[c[3542116]&4095](Z,a[9688]|0?534:0);Z=c[2394]|0;$=c[14130368+(Z<<2)>>2]|0;if(($|0)!=0){gGC($|0,9104152,280)|0}c[8452240+(Z<<2)>>2]=c[2113054];c[2394]=-1;TQ(0,c[2112964]|0,a[9688]|0?534:0);return 0}function bri(a,b){a=a|0;b=b|0;return 1}function brj(b,f,g,h){b=b|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0;i=c[2406860]|0;j=d[i+16|0]|0;k=j&3;l=a[591224+k|0]|0;m=l<<24>>24;n=(1<<m)-1|0;o=j>>>4<<8&768|255;if((k|0)==1){p=o&511}else{p=k>>>0>1?255:o}if((b|0)==0){q=(d[i+2|0]|0)<<9}else{q=(d[i+4|0]|0)<<12}o=q&28672;q=(d[i+13|0]|0)<<9;k=a[i+11|0]|0;if((k&2)==0){r=q}else{r=(c[2405426]<<1)+q|0}q=c[2411360]|0;j=e[q+((((k&1)==0?r&32752:r)+b&32767)<<1)>>1]|0;if((a[i+12|0]&6)==6){i=(c[2405426]<<1)+(e[(c[2406880]|0)+(b<<1)>>1]|0)&(p<<1|1);r=(i>>4<<m)+o|0;s=i<<1&30;i=(j+7&7)+1|0;t=((i|0)!=8)+g|0;L6119:do{if((t|0)==0){u=f}else{v=30-s|0;w=s<<25;x=-j>>3;y=i;z=0;A=t;B=-1;C=-1;D=0;E=f;while(1){F=e[q+(r+(x&n)<<1)>>1]|0;do{if((F|0)==(C|0)){G=D;H=C;I=B;J=z;K=E}else{if((F&32768|0)!=0){L=y<<16|w|F&64512|F<<1&2046;c[E>>2]=(F&4096|0)==0?L:L^1006632960;G=D;H=C;I=B;J=z;K=E+4|0;break}if((F|0)==(B|0)){M=D;N=B;O=z}else{L=F<<5&65504;M=F>>>9&48;N=F;O=(F&4096|0)==0?L|s:v+L|0}if((F&2048|0)==0){P=bro(y,O,M)|0}else{P=brn(y,O,M)|0}G=M;H=(P|0)==0?C:F;I=N;J=O;K=E}}while(0);F=A-1|0;if((F|0)==0){u=K;break L6119}x=x+1|0;y=y+8|0;z=J;A=F;B=I;C=H;D=G;E=K}}}while(0);c[u>>2]=0;return}if((k&4)==0){k=(e[(c[2406880]|0)+(b<<1)>>1]|0)+(c[2405426]|0)&p;u=(k>>3<<m)+o|0;m=k<<1&14;k=(j+7&7)+1|0;K=((k|0)!=8)+g|0;L6142:do{if((K|0)==0){Q=f}else{G=h<<6;H=m<<25;I=-j>>3;J=k;O=0;N=K;P=-1;M=-1;s=0;r=f;while(1){t=e[q+(u+(I&n)<<1)>>1]|0;do{if((t|0)==(M|0)){R=s;S=M;T=P;U=O;V=r}else{if((t&32768|0)!=0){i=J<<16|H|t;c[r>>2]=(t&4096|0)==0?i:i^469762048;R=s;S=M;T=P;U=O;V=r+4|0;break}if((t|0)==(P|0)){W=s;X=P;Y=O}else{i=t<<4&32752|m;W=t>>>9&48|G;X=t;Y=(t&4096|0)==0?i:i^14}if((t&2048|0)==0){Z=bro(J,Y,W)|0}else{Z=brn(J,Y,W)|0}R=W;S=(Z|0)==0?M:t;T=X;U=Y;V=r}}while(0);t=N-1|0;if((t|0)==0){Q=V;break L6142}I=I+1|0;J=J+8|0;O=U;N=t;P=T;M=S;s=R;r=V}}}while(0);c[Q>>2]=0;return}Q=p|(l&255)<<24;l=c[2405426]|0;p=(j+7&7)+1|0;if((p|0)==8){_=8;$=0;aa=0;ab=0}else{V=(e[(c[2406880]|0)+(b<<1)>>1]|0)+l&Q;_=p;$=V<<1&14;aa=(V>>>3&8191)<<(Q>>24);ab=-1}if((ab|0)<(g|0)){V=Q>>24;p=c[2406880]|0;R=ab;ab=aa;aa=-1;S=-1;T=0;U=0;Y=$;$=_;_=-j>>3;j=f;while(1){if((R&1|0)==0){X=(e[p+((R&-2)+b<<1)>>1]|0)+l&Q;ac=X<<1&14;ad=(X>>>3&8191)<<V}else{ac=Y;ad=ab}X=e[q+((_&n)+o+ad<<1)>>1]|0;do{if((X|0)==(S|0)){ae=U;af=T;ag=S;ah=aa;ai=j}else{if((X&32768|0)!=0){Z=ac<<25|$<<16|X;c[j>>2]=(X&4096|0)==0?Z:Z^469762048;ae=U;af=T;ag=S;ah=aa;ai=j+4|0;break}if((X|0)==(aa|0)){aj=U;ak=T;al=aa}else{aj=((X&4096|0)==0?ac:14-ac|0)+(X<<4&32752)|0;ak=X>>>9&48;al=X}if((X&2048|0)==0){am=bro($,aj,ak)|0}else{am=brn($,aj,ak)|0}ae=aj;af=ak;ag=(am|0)==0?S:X;ah=al;ai=j}}while(0);X=R+1|0;if((X|0)<(g|0)){R=X;ab=ad;aa=ah;S=ag;T=af;U=ae;Y=ac;$=$+8|0;_=_+1|0;j=ai}else{an=ai;break}}}else{an=f}c[an>>2]=0;return}function brk(b,f,g,h){b=b|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;i=c[2406860]|0;j=c[2405426]|0;k=(j>>3<<((a[i+12|0]&1)==0?5:6))+((d[i+3|0]|0)<<9&30720)|0;i=b<<1;b=f<<1;f=j<<1&14;j=c[3528408]|0;do{if((j&2|0)==0){if(((e[(c[2411360]|0)+(k+i<<1)>>1]|0)>>>15|0)==(g|0)&(i|0)<(b|0)){break}return}else{if((i|0)<(b|0)){break}return}}while(0);l=14-f|0;m=(g|0)==0;n=c[2411360]|0;if((h|0)==0){h=i;o=-1;p=j;while(1){q=e[n+(h+k<<1)>>1]|0;do{if((q|0)==(o|0)){r=o;s=p}else{if((q>>>15|0)!=(g|0)){t=p|2;c[3528408]=t;r=o;s=t;break}t=q>>>9&48;u=q<<4&32752;v=(q&4096|0)==0?u|f:u+l|0;u=(h<<3)+8|0;if((q&2048|0)==0){w=bro(u,v,t)|0}else{w=brn(u,v,t)|0}r=(w|0)==0?o:q;s=p}}while(0);q=h+1|0;if((q|0)<(b|0)){h=q;o=r;p=s}else{break}}return}else{x=i;y=-1;z=j}while(1){j=e[n+(x+k<<1)>>1]|0;do{if((j|0)==(y|0)){A=y;B=z}else{if((j>>>15|0)!=(g|0)){i=z|2;c[3528408]=i;A=y;B=i;break}i=j>>>9&48;s=c[2407122]|0;p=x<<3;r=p+8|0;o=s+r|0;if(m){C=i|64}else{h=c[o>>2]|0;w=(h&128|0)==0?h&-193:h;h=(w&32768|0)==0?w&-49153:w;w=(h&8388608|0)==0?h&-12582913:h;h=s+(p+12)|0;c[o>>2]=(w|0)<0?w:w&1073741823;w=c[h>>2]|0;o=(w&128|0)==0?w&-193:w;w=(o&32768|0)==0?o&-49153:o;o=(w&8388608|0)==0?w&-12582913:w;c[h>>2]=(o|0)<0?o:o&1073741823;C=i}i=j<<4&32752;o=(j&4096|0)==0?i|f:i+l|0;if((j&2048|0)==0){D=bro(r,o,C)|0}else{D=brn(r,o,C)|0}A=(D|0)==0?y:j;B=z}}while(0);j=x+1|0;if((j|0)<(b|0)){x=j;y=A;z=B}else{break}}return}function brl(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0;h=i;i=i+480|0;j=h|0;k=h+320|0;l=c[3528408]|0;m=c[2405426]|0;if((l&8|0)!=0){n=m<<1;o=c[2406860]|0;p=(((a[o+12|0]&1)==0?127:126)&(d[o+5|0]|0))<<8;o=c[2411360]|0;q=0;r=0;s=0;while(1){t=q+p&32764;u=o+(t<<1)|0;v=c[u>>2]|0;w=c[o+((t|2)<<1)>>2]|0;do{if((w>>>15&1|0)==(f|0)){t=v&1023;if((n|0)<(t-256|0)){x=s;break}if((n|0)>=(t-240+(v>>>24<<4&48)|0)){x=s;break}t=(w>>>16&511)-120|0;if(!((t|0)>-24&(t|0)<(e|0))){x=s;break}c[j+(s<<2)>>2]=u;x=s+1|0}else{x=s}}while(0);u=v>>>16&127;if((u|0)==0){break}w=r+1|0;if((w|0)<80&(x|0)<21){q=u<<2;r=w;s=x}else{break}}if((x|0)>0){y=x}else{i=h;return}do{y=y-1|0;x=c[j+(y<<2)>>2]|0;s=c[x>>2]|0;r=c[x+4>>2]|0;x=s>>>24;q=s>>>26&3;e=q+1|0;o=(x&3)+1|0;p=256-(s&1023)+n|0;s=(r>>>16&511)-120|0;if((r&4096|0)==0){z=p}else{z=(16<<o)-1^p}p=(z>>4)+(r&1023)|0;w=(r&2048|0)!=0;if(w){A=(x|-4)^3;B=p+(ag(o,q)|0)|0}else{A=o;B=p}p=B<<5|z<<1&30;o=A<<5;q=r>>>9&48;L6249:do{if(w){r=p;x=s;u=e;while(1){if((x|0)<1){C=r}else{if((x|0)>327){break L6249}t=r&32767;brn(x,t,q)|0;C=t}t=u-1|0;if((t|0)==0){break}else{r=C+o|0;x=x+8|0;u=t}}}else{u=p;x=s;r=e;while(1){if((x|0)<1){D=u}else{if((x|0)>327){break L6249}t=u&32767;bro(x,t,q)|0;D=t}t=r-1|0;if((t|0)==0){break}else{u=D+o|0;x=x+8|0;r=t}}}}while(0);}while((y|0)>0);i=h;return}if((l&17|0)!=0){brp(l&16);c[3528408]=l&-18}if((c[2442950]&1<<(m>>3)|0)==0){i=h;return}y=(l&4|0)!=0;l=(g|0)==0;D=(f|0)==0;if((y|l^1)&D){gGz(c[2405786]|0,0,328)}if(!(y|D)){D=c[b>>2]|0;if((D|0)==0){i=h;return}C=(g|0)!=0;A=b;z=D;do{A=A+4|0;D=z&48;B=(z&65536|0)!=0;if(B){E=(z|-4)^3}else{E=(z&3)+1|0}n=E<<4;if(C&(D|0)==48){F=B?7072:11200}else{F=B?5936:5098}B=z>>>17<<1;j=z<<16>>22;o=(z>>>2&3)+1|0;while(1){if((j|0)<1){G=B}else{if((j|0)>327){break}q=B&32767;gp[F&16383](j,q,D)|0;G=q}q=o-1|0;if((q|0)==0){break}else{B=G+n|0;j=j+8|0;o=q}}z=c[A>>2]|0;}while((z|0)!=0);i=h;return}z=c[3529086]|0;A=c[z>>2]|0;L6297:do{if((A|0)==0){H=0}else{G=f<<15;F=g&1;C=((f<<1|g)&3|0)==1;E=z;o=0;j=0;n=0;B=0;D=A;L6299:while(1){L6301:do{if((D&4194304|0)==0){q=c[E+4>>2]|0;e=q>>16;s=D<<16>>16;p=m-s|0;w=(e|0)==-119;v=w&1|j;if((p|0)<0){I=B;J=n;K=v;L=o;break}if((p|0)>=(D>>>21&56|0)){I=B;J=n;K=v;L=o;break}p=n+1|0;r=D>>28;x=o+r|0;if((x|0)>40){H=B;break L6297}if((D&8388608|0)!=0){I=B;J=p;K=v;L=x;break}if((e|0)==-120){if((v&1|0)==0|(v|0)==3){H=B;break L6297}if(v>>>0>=256){I=B;J=p;K=v;L=x;break}I=B;J=p;K=(B<<8)+256|0;L=x;break}if(w){M=j>>8;if((M|0)!=0){break L6299}I=B;J=p;K=v|2;L=x;break}if(!y){c[k+(B<<2)>>2]=E;I=B+1|0;J=p;K=v;L=x;break}if((q&32768|0)!=(G|0)){I=B;J=p;K=v;L=x;break}w=30-n<<24>>24;u=D>>>24&7;t=(c[2405426]|0)-s|0;if((q&4096|0)==0){N=t}else{N=(u<<3)-1-t|0}t=(N>>3)+(q&2047)|0;s=q&2048;if((s|0)==0){O=u;P=t}else{O=-u|0;P=t+(ag(u,r-1|0)|0)|0}u=P<<4|N<<1&14;t=O<<4;Q=q>>>9&48;R=C?Q|64:Q;Q=((q&24576|0)==24576?F:0)|s>>>10;if((Q|0)==1){S=14}else if((Q|0)==2){S=22}else if((Q|0)==3){S=24}else{S=12}if((r|0)==0){I=B;J=p;K=v;L=x;break}else{T=r;U=u;V=e}while(1){if((V|0)<1){W=U}else{if((V|0)>327){I=B;J=p;K=v;L=x;break L6301}e=U&32767;gJ[S&31](V,e,R,w)|0;W=e}e=T-1|0;if((e|0)==0){I=B;J=p;K=v;L=x;break}else{T=e;U=W+t|0;V=V+8|0}}}else{I=B;J=n;K=j;L=o}}while(0);t=E+8|0;x=c[t>>2]|0;if((x|0)!=0&(J|0)<20){E=t;o=L;j=K;n=J;B=I;D=x}else{H=I;break L6297}}H=M-1|0}}while(0);if(y){i=h;return}L6343:do{if((H|0)>0){y=g<<6;M=b;I=H;while(1){J=I;while(1){X=J-1|0;K=c[k+(X<<2)>>2]|0;Y=c[K>>2]|0;Z=c[K+4>>2]|0;_=Z>>16;K=Y>>28;L=Y>>>24&7;V=(c[2405426]|0)-(Y<<16>>16)|0;if((Z&4096|0)==0){$=V}else{$=(L<<3)-1-V|0}V=($>>3)+(Z&2047)|0;aa=Z&2048;W=(aa|0)!=0;if(W){ab=-L|0;ac=V+(ag(L,K-1|0)|0)|0}else{ab=L;ac=V}ad=ac<<4|$<<1&14;if((Z&32768|0)!=0){break}V=ab<<4;L=Z>>>9&48|y;do{if(l){ae=4824}else{if((Z&24576|0)!=24576){ae=4824;break}af=W?7072:11200}}while(0);if((ae|0)==4824){ae=0;af=W?5936:5098}L6362:do{if((K|0)!=0){U=ad;T=_;S=K;while(1){if((T|0)<1){ah=U}else{if((T|0)>327){break L6362}O=U&32767;gp[af&16383](T,O,L)|0;ah=O}O=S-1|0;if((O|0)==0){break}else{U=ah+V|0;T=T+8|0;S=O}}}}while(0);if((X|0)>0){J=X}else{ai=M;break L6343}}J=M+4|0;c[M>>2]=aa<<5|Y>>>16&15|Z>>>9&48|_<<6&65472|ad<<16;if((X|0)>0){M=J;I=X}else{ai=J;break}}}else{ai=b}}while(0);c[ai>>2]=0;i=h;return}function brm(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=(d|0)==0;d=-1;f=b;L6374:while(1){b=d<<16>>16;g=f;while(1){h=g+4|0;i=c[g>>2]|0;if((i|0)==0){break L6374}if(!e){j=4846;break}if((i<<16>>16|0)==(b|0)){g=h}else{j=4845;break}}do{if((j|0)==4845){j=0;k=(i<<4&32752)+(i>>>25)|0;l=i>>>16&511}else if((j|0)==4846){j=0;g=(i<<4&32752)+(i>>>25)|0;b=i>>>16&511;m=c[2407122]|0;n=m+b|0;o=a[n]|0;if(o<<24>>24>-1){a[n]=o&63}o=m+(b+1)|0;n=a[o]|0;if(n<<24>>24>-1){a[o]=n&63}n=m+(b+2)|0;o=a[n]|0;if(o<<24>>24>-1){a[n]=o&63}o=m+(b+3)|0;n=a[o]|0;if(n<<24>>24>-1){a[o]=n&63}n=m+(b+4)|0;o=a[n]|0;if(o<<24>>24>-1){a[n]=o&63}o=m+(b+5)|0;n=a[o]|0;if(n<<24>>24>-1){a[o]=n&63}n=m+(b+6)|0;o=a[n]|0;if(o<<24>>24>-1){a[n]=o&63}o=m+(b+7)|0;m=a[o]|0;if(m<<24>>24<=-1){k=g;l=b;break}a[o]=m&63;k=g;l=b}}while(0);b=i>>>9&48;if((i&2048|0)==0){p=bro(l,k,b)|0}else{p=brn(l,k,b)|0}d=(p|0)==0?d:i&65535;f=h}return}function brn(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=c[2407122]|0;g=c[(c[2411360]|0)+(d<<1)>>2]|0;if((g|0)==0){h=1;return h|0}d=g&983040;if((d|0)!=0){a[f+b|0]=(d>>>16|e)&255}d=g&15728640;if((d|0)!=0){a[f+(b+1)|0]=(d>>>20|e)&255}d=g&251658240;if((d|0)!=0){a[f+(b+2)|0]=(d>>>24|e)&255}if(g>>>0>=268435456){a[f+(b+3)|0]=(g>>>28|e)&255}d=g&15;if((d|0)!=0){a[f+(b+4)|0]=(d|e)&255}d=g&240;if((d|0)!=0){a[f+(b+5)|0]=(d>>>4|e)&255}d=g&3840;if((d|0)!=0){a[f+(b+6)|0]=(d>>>8|e)&255}d=g&61440;if((d|0)==0){h=0;return h|0}a[f+(b+7)|0]=(d>>>12|e)&255;h=0;return h|0}function bro(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=c[2407122]|0;g=c[(c[2411360]|0)+(d<<1)>>2]|0;if((g|0)==0){h=1;return h|0}d=g&61440;if((d|0)!=0){a[f+b|0]=(d>>>12|e)&255}d=g&3840;if((d|0)!=0){a[f+(b+1)|0]=(d>>>8|e)&255}d=g&240;if((d|0)!=0){a[f+(b+2)|0]=(d>>>4|e)&255}d=g&15;if((d|0)!=0){a[f+(b+3)|0]=(d|e)&255}if(g>>>0>=268435456){a[f+(b+4)|0]=(g>>>28|e)&255}d=g&251658240;if((d|0)!=0){a[f+(b+5)|0]=(d>>>24|e)&255}d=g&15728640;if((d|0)!=0){a[f+(b+6)|0]=(d>>>20|e)&255}d=g&983040;if((d|0)==0){h=0;return h|0}a[f+(b+7)|0]=(d>>>16|e)&255;h=0;return h|0}function brp(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;e=c[3529086]|0;f=c[2406860]|0;g=(((a[f+12|0]&1)==0?127:126)&(d[f+5|0]|0))<<8;f=c[2411360]|0;if((b|0)==0){b=e;h=0;i=0;j=0;while(1){k=c[b>>2]|0;if((k|0)==0){l=h;break}m=i+g&32764;n=c[f+(m<<1)>>2]|0;o=(c[f+((m|2)<<1)>>2]&33554431)-7864320|0;m=o>>16;p=k>>28;do{if((m|0)<=(8-(p<<3)|0)&(m|0)>-119|(m|0)>327){q=h;r=8388608}else{s=k<<16;if((s+2097151|0)>>>0>=17825791){q=h;r=0;break}q=(2<<p)-1<<(s>>19)|h;r=0}}while(0);c[b>>2]=r|k&-8388609;c[b+4>>2]=o;p=n>>>16&127;if((p|0)==0){l=q;break}m=j+1|0;if((m|0)<80){b=b+8|0;h=q;i=p<<2;j=m}else{l=q;break}}c[2442950]=c[2442950]|l;return}else{t=e;u=0;v=0;w=0}while(1){e=v+g&32764;l=c[f+(e<<1)>>2]|0;q=(l&511)-128|0;j=l>>>24;i=j&15;h=(j&3)+1|0;if((q|0)>240){x=4919}else{if(((h<<3)+q|0)<1){x=4919}else{y=0}}if((x|0)==4919){x=0;y=4194304}j=(i>>>2)+1|0;b=c[f+((e|2)<<1)>>2]|0;e=(b>>>16&511)-120|0;r=8-(j<<3)|0;do{if((e|0)<=(r|0)&(e|0)>-119|(e|0)>327){z=y|8388608;A=u}else{if(!((e|0)>(r|0)&(y|0)==0)){z=y;A=u;break}m=q>>3;z=0;A=(2<<h)-1<<((m|0)<0?0:m)|u}}while(0);c[t>>2]=q&65535|i<<16|h<<24|j<<28|z;B=t+8|0;c[t+4>>2]=e<<16|b&65535;r=l>>>16&127;if((r|0)==0){break}n=w+1|0;if((n|0)<80){t=B;u=A;v=r<<2;w=n}else{break}}c[2442950]=A;c[B>>2]=0;return}function brq(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=c[2407122]|0;g=f+b|0;h=c[(c[2411360]|0)+(d<<1)>>2]|0;if((h|0)==0){i=1;return i|0}d=h>>>16&15;if((d|0)==15){a[g]=a[g]|-64}else if((d|0)==14){a[g]=a[g]&63|-128}else if((d|0)!=0){a[g]=(d|e)&255}d=h>>>20&15;if((d|0)==14){g=f+(b+1)|0;a[g]=a[g]&63|-128}else if((d|0)==15){g=f+(b+1)|0;a[g]=a[g]|-64}else if((d|0)!=0){a[f+(b+1)|0]=(d|e)&255}d=h>>>24&15;if((d|0)==15){g=f+(b+2)|0;a[g]=a[g]|-64}else if((d|0)==14){g=f+(b+2)|0;a[g]=a[g]&63|-128}else if((d|0)!=0){a[f+(b+2)|0]=(d|e)&255}d=h>>>28;if((d|0)==14){g=f+(b+3)|0;a[g]=a[g]&63|-128}else if((d|0)==15){g=f+(b+3)|0;a[g]=a[g]|-64}else if((d|0)!=0){a[f+(b+3)|0]=(d|e)&255}d=h&15;if((d|0)==15){g=f+(b+4)|0;a[g]=a[g]|-64}else if((d|0)==14){g=f+(b+4)|0;a[g]=a[g]&63|-128}else if((d|0)!=0){a[f+(b+4)|0]=(d|e)&255}d=h>>>4&15;if((d|0)==14){g=f+(b+5)|0;a[g]=a[g]&63|-128}else if((d|0)==15){g=f+(b+5)|0;a[g]=a[g]|-64}else if((d|0)!=0){a[f+(b+5)|0]=(d|e)&255}d=h>>>8&15;if((d|0)==15){g=f+(b+6)|0;a[g]=a[g]|-64}else if((d|0)==14){g=f+(b+6)|0;a[g]=a[g]&63|-128}else if((d|0)!=0){a[f+(b+6)|0]=(d|e)&255}d=h>>>12&15;if((d|0)==15){h=f+(b+7)|0;a[h]=a[h]|-64;i=0;return i|0}else if((d|0)==14){h=f+(b+7)|0;a[h]=a[h]&63|-128;i=0;return i|0}else if((d|0)==0){i=0;return i|0}else{a[f+(b+7)|0]=(d|e)&255;i=0;return i|0}return 0}function brr(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=c[2407122]|0;g=f+b|0;h=c[(c[2411360]|0)+(d<<1)>>2]|0;if((h|0)==0){i=1;return i|0}d=h>>>12&15;if((d|0)==15){a[g]=a[g]|-64}else if((d|0)==14){a[g]=a[g]&63|-128}else if((d|0)!=0){a[g]=(d|e)&255}d=h>>>8&15;if((d|0)==14){g=f+(b+1)|0;a[g]=a[g]&63|-128}else if((d|0)==15){g=f+(b+1)|0;a[g]=a[g]|-64}else if((d|0)!=0){a[f+(b+1)|0]=(d|e)&255}d=h>>>4&15;if((d|0)==15){g=f+(b+2)|0;a[g]=a[g]|-64}else if((d|0)==14){g=f+(b+2)|0;a[g]=a[g]&63|-128}else if((d|0)!=0){a[f+(b+2)|0]=(d|e)&255}d=h&15;if((d|0)==14){g=f+(b+3)|0;a[g]=a[g]&63|-128}else if((d|0)==15){g=f+(b+3)|0;a[g]=a[g]|-64}else if((d|0)!=0){a[f+(b+3)|0]=(d|e)&255}d=h>>>28;if((d|0)==14){g=f+(b+4)|0;a[g]=a[g]&63|-128}else if((d|0)==15){g=f+(b+4)|0;a[g]=a[g]|-64}else if((d|0)!=0){a[f+(b+4)|0]=(d|e)&255}d=h>>>24&15;if((d|0)==14){g=f+(b+5)|0;a[g]=a[g]&63|-128}else if((d|0)==15){g=f+(b+5)|0;a[g]=a[g]|-64}else if((d|0)!=0){a[f+(b+5)|0]=(d|e)&255}d=h>>>20&15;if((d|0)==14){g=f+(b+6)|0;a[g]=a[g]&63|-128}else if((d|0)==15){g=f+(b+6)|0;a[g]=a[g]|-64}else if((d|0)!=0){a[f+(b+6)|0]=(d|e)&255}d=h>>>16&15;if((d|0)==14){h=f+(b+7)|0;a[h]=a[h]&63|-128;i=0;return i|0}else if((d|0)==15){h=f+(b+7)|0;a[h]=a[h]|-64;i=0;return i|0}else if((d|0)==0){i=0;return i|0}else{a[f+(b+7)|0]=(d|e)&255;i=0;return i|0}return 0}function brs(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=c[2407122]|0;h=g+b|0;i=c[2405786]|0;j=i+b|0;k=c[(c[2411360]|0)+(d<<1)>>2]|0;if((k|0)==0){l=1;return l|0}d=k&61440;do{if((d|0)==0){m=0}else{n=a[j]|0;o=n<<24>>24!=0|0;if((n<<24>>24|0)>=(f|0)){m=o;break}a[h]=(d>>>12|e)&255;a[j]=f&255;m=o}}while(0);j=k&3840;do{if((j|0)==0){p=m}else{d=b+1|0;h=i+d|0;o=a[h]|0;n=o<<24>>24==0?m:1;if((o<<24>>24|0)>=(f|0)){p=n;break}a[g+d|0]=(j>>>8|e)&255;a[h]=f&255;p=n}}while(0);j=k&240;do{if((j|0)==0){q=p}else{m=b+2|0;n=i+m|0;h=a[n]|0;d=h<<24>>24==0?p:1;if((h<<24>>24|0)>=(f|0)){q=d;break}a[g+m|0]=(j>>>4|e)&255;a[n]=f&255;q=d}}while(0);j=k&15;do{if((j|0)==0){r=q}else{p=b+3|0;d=i+p|0;n=a[d]|0;m=n<<24>>24==0?q:1;if((n<<24>>24|0)>=(f|0)){r=m;break}a[g+p|0]=(j|e)&255;a[d]=f&255;r=m}}while(0);do{if(k>>>0<268435456){s=r}else{j=b+4|0;q=i+j|0;m=a[q]|0;d=m<<24>>24==0?r:1;if((m<<24>>24|0)>=(f|0)){s=d;break}a[g+j|0]=(k>>>28|e)&255;a[q]=f&255;s=d}}while(0);r=k&251658240;do{if((r|0)==0){t=s}else{d=b+5|0;q=i+d|0;j=a[q]|0;m=j<<24>>24==0?s:1;if((j<<24>>24|0)>=(f|0)){t=m;break}a[g+d|0]=(r>>>24|e)&255;a[q]=f&255;t=m}}while(0);r=k&15728640;do{if((r|0)==0){u=t}else{s=b+6|0;m=i+s|0;q=a[m]|0;d=q<<24>>24==0?t:1;if((q<<24>>24|0)>=(f|0)){u=d;break}a[g+s|0]=(r>>>20|e)&255;a[m]=f&255;u=d}}while(0);r=k&983040;do{if((r|0)==0){v=u}else{k=b+7|0;t=i+k|0;d=a[t]|0;m=d<<24>>24==0?u:1;if((d<<24>>24|0)>=(f|0)){v=m;break}a[g+k|0]=(r>>>16|e)&255;a[t]=f&255;v=m}}while(0);if((v|0)==0){l=0;return l|0}v=(c[2406860]|0)+40|0;c[v>>2]=c[v>>2]|32;l=0;return l|0}function brt(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=c[2407122]|0;h=g+b|0;i=c[2405786]|0;j=i+b|0;k=c[(c[2411360]|0)+(d<<1)>>2]|0;if((k|0)==0){l=1;return l|0}d=k>>>12&15;do{if((d|0)==0){m=0}else{n=a[j]|0;o=n<<24>>24!=0|0;if((n<<24>>24|0)>=(f|0)){m=o;break}if((d|0)==14){a[h]=a[h]&63|-128;m=o;break}else if((d|0)==15){a[h]=a[h]|-64;m=o;break}else{a[j]=f&255;a[h]=(d|e)&255;m=o;break}}}while(0);d=k>>>8&15;do{if((d|0)==0){p=m}else{h=b+1|0;j=i+h|0;o=a[j]|0;n=o<<24>>24==0?m:1;if((o<<24>>24|0)>=(f|0)){p=n;break}if((d|0)==15){o=g+h|0;a[o]=a[o]|-64;p=n;break}else if((d|0)==14){o=g+h|0;a[o]=a[o]&63|-128;p=n;break}else{a[j]=f&255;a[g+h|0]=(d|e)&255;p=n;break}}}while(0);d=k>>>4&15;do{if((d|0)==0){q=p}else{m=b+2|0;n=i+m|0;h=a[n]|0;j=h<<24>>24==0?p:1;if((h<<24>>24|0)>=(f|0)){q=j;break}if((d|0)==15){h=g+m|0;a[h]=a[h]|-64;q=j;break}else if((d|0)==14){h=g+m|0;a[h]=a[h]&63|-128;q=j;break}else{a[n]=f&255;a[g+m|0]=(d|e)&255;q=j;break}}}while(0);d=k&15;do{if((d|0)==0){r=q}else{p=b+3|0;j=i+p|0;m=a[j]|0;n=m<<24>>24==0?q:1;if((m<<24>>24|0)>=(f|0)){r=n;break}if((d|0)==15){m=g+p|0;a[m]=a[m]|-64;r=n;break}else if((d|0)==14){m=g+p|0;a[m]=a[m]&63|-128;r=n;break}else{a[j]=f&255;a[g+p|0]=(d|e)&255;r=n;break}}}while(0);d=k>>>28;do{if((d|0)==0){s=r}else{q=b+4|0;n=i+q|0;p=a[n]|0;j=p<<24>>24==0?r:1;if((p<<24>>24|0)>=(f|0)){s=j;break}if((d|0)==15){p=g+q|0;a[p]=a[p]|-64;s=j;break}else if((d|0)==14){p=g+q|0;a[p]=a[p]&63|-128;s=j;break}else{a[n]=f&255;a[g+q|0]=(d|e)&255;s=j;break}}}while(0);d=k>>>24&15;do{if((d|0)==0){t=s}else{r=b+5|0;j=i+r|0;q=a[j]|0;n=q<<24>>24==0?s:1;if((q<<24>>24|0)>=(f|0)){t=n;break}if((d|0)==14){q=g+r|0;a[q]=a[q]&63|-128;t=n;break}else if((d|0)==15){q=g+r|0;a[q]=a[q]|-64;t=n;break}else{a[j]=f&255;a[g+r|0]=(d|e)&255;t=n;break}}}while(0);d=k>>>20&15;do{if((d|0)==0){u=t}else{s=b+6|0;n=i+s|0;r=a[n]|0;j=r<<24>>24==0?t:1;if((r<<24>>24|0)>=(f|0)){u=j;break}if((d|0)==15){r=g+s|0;a[r]=a[r]|-64;u=j;break}else if((d|0)==14){r=g+s|0;a[r]=a[r]&63|-128;u=j;break}else{a[n]=f&255;a[g+s|0]=(d|e)&255;u=j;break}}}while(0);d=k>>>16&15;do{if((d|0)==0){v=u}else{k=b+7|0;t=i+k|0;j=a[t]|0;s=j<<24>>24==0?u:1;if((j<<24>>24|0)>=(f|0)){v=s;break}if((d|0)==15){j=g+k|0;a[j]=a[j]|-64;v=s;break}else if((d|0)==14){j=g+k|0;a[j]=a[j]&63|-128;v=s;break}else{a[t]=f&255;a[g+k|0]=(d|e)&255;v=s;break}}}while(0);if((v|0)==0){l=0;return l|0}v=(c[2406860]|0)+40|0;c[v>>2]=c[v>>2]|32;l=0;return l|0}function bru(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=c[2407122]|0;h=g+b|0;i=c[2405786]|0;j=i+b|0;k=c[(c[2411360]|0)+(d<<1)>>2]|0;if((k|0)==0){l=1;return l|0}d=k&983040;do{if((d|0)==0){m=0}else{n=a[j]&31;o=(n|0)!=0|0;if((n|0)>=(f|0)){m=o;break}a[h]=(d>>>16|e)&255;a[j]=f&255;m=o}}while(0);j=k&15728640;do{if((j|0)==0){p=m}else{d=b+1|0;h=i+d|0;o=a[h]&31;n=(o|0)==0?m:1;if((o|0)>=(f|0)){p=n;break}a[g+d|0]=(j>>>20|e)&255;a[h]=f&255;p=n}}while(0);j=k&251658240;do{if((j|0)==0){q=p}else{m=b+2|0;n=i+m|0;h=a[n]&31;d=(h|0)==0?p:1;if((h|0)>=(f|0)){q=d;break}a[g+m|0]=(j>>>24|e)&255;a[n]=f&255;q=d}}while(0);do{if(k>>>0<268435456){r=q}else{j=b+3|0;p=i+j|0;d=a[p]&31;n=(d|0)==0?q:1;if((d|0)>=(f|0)){r=n;break}a[g+j|0]=(k>>>28|e)&255;a[p]=f&255;r=n}}while(0);q=k&15;do{if((q|0)==0){s=r}else{n=b+4|0;p=i+n|0;j=a[p]&31;d=(j|0)==0?r:1;if((j|0)>=(f|0)){s=d;break}a[g+n|0]=(q|e)&255;a[p]=f&255;s=d}}while(0);q=k&240;do{if((q|0)==0){t=s}else{r=b+5|0;d=i+r|0;p=a[d]&31;n=(p|0)==0?s:1;if((p|0)>=(f|0)){t=n;break}a[g+r|0]=(q>>>4|e)&255;a[d]=f&255;t=n}}while(0);q=k&3840;do{if((q|0)==0){u=t}else{s=b+6|0;n=i+s|0;d=a[n]&31;r=(d|0)==0?t:1;if((d|0)>=(f|0)){u=r;break}a[g+s|0]=(q>>>8|e)&255;a[n]=f&255;u=r}}while(0);q=k&61440;do{if((q|0)==0){v=u}else{k=b+7|0;t=i+k|0;r=a[t]&31;n=(r|0)==0?u:1;if((r|0)>=(f|0)){v=n;break}a[g+k|0]=(q>>>12|e)&255;a[t]=f&255;v=n}}while(0);if((v|0)==0){l=0;return l|0}v=(c[2406860]|0)+40|0;c[v>>2]=c[v>>2]|32;l=0;return l|0}function brv(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=c[2407122]|0;h=g+b|0;i=c[2405786]|0;j=i+b|0;k=c[(c[2411360]|0)+(d<<1)>>2]|0;if((k|0)==0){l=1;return l|0}d=k>>>16&15;do{if((d|0)==0){m=0}else{n=a[j]|0;o=n<<24>>24!=0|0;if((n<<24>>24|0)>=(f|0)){m=o;break}if((d|0)==14){a[h]=a[h]&63|-128;m=o;break}else if((d|0)==15){a[h]=a[h]|-64;m=o;break}else{a[j]=f&255;a[h]=(d|e)&255;m=o;break}}}while(0);d=k>>>20&15;do{if((d|0)==0){p=m}else{h=b+1|0;j=i+h|0;o=a[j]|0;n=o<<24>>24==0?m:1;if((o<<24>>24|0)>=(f|0)){p=n;break}if((d|0)==15){o=g+h|0;a[o]=a[o]|-64;p=n;break}else if((d|0)==14){o=g+h|0;a[o]=a[o]&63|-128;p=n;break}else{a[j]=f&255;a[g+h|0]=(d|e)&255;p=n;break}}}while(0);d=k>>>24&15;do{if((d|0)==0){q=p}else{m=b+2|0;n=i+m|0;h=a[n]|0;j=h<<24>>24==0?p:1;if((h<<24>>24|0)>=(f|0)){q=j;break}if((d|0)==15){h=g+m|0;a[h]=a[h]|-64;q=j;break}else if((d|0)==14){h=g+m|0;a[h]=a[h]&63|-128;q=j;break}else{a[n]=f&255;a[g+m|0]=(d|e)&255;q=j;break}}}while(0);d=k>>>28;do{if((d|0)==0){r=q}else{p=b+3|0;j=i+p|0;m=a[j]|0;n=m<<24>>24==0?q:1;if((m<<24>>24|0)>=(f|0)){r=n;break}if((d|0)==15){m=g+p|0;a[m]=a[m]|-64;r=n;break}else if((d|0)==14){m=g+p|0;a[m]=a[m]&63|-128;r=n;break}else{a[j]=f&255;a[g+p|0]=(d|e)&255;r=n;break}}}while(0);d=k&15;do{if((d|0)==0){s=r}else{q=b+4|0;n=i+q|0;p=a[n]|0;j=p<<24>>24==0?r:1;if((p<<24>>24|0)>=(f|0)){s=j;break}if((d|0)==15){p=g+q|0;a[p]=a[p]|-64;s=j;break}else if((d|0)==14){p=g+q|0;a[p]=a[p]&63|-128;s=j;break}else{a[n]=f&255;a[g+q|0]=(d|e)&255;s=j;break}}}while(0);d=k>>>4&15;do{if((d|0)==0){t=s}else{r=b+5|0;j=i+r|0;q=a[j]|0;n=q<<24>>24==0?s:1;if((q<<24>>24|0)>=(f|0)){t=n;break}if((d|0)==15){q=g+r|0;a[q]=a[q]|-64;t=n;break}else if((d|0)==14){q=g+r|0;a[q]=a[q]&63|-128;t=n;break}else{a[j]=f&255;a[g+r|0]=(d|e)&255;t=n;break}}}while(0);d=k>>>8&15;do{if((d|0)==0){u=t}else{s=b+6|0;n=i+s|0;r=a[n]|0;j=r<<24>>24==0?t:1;if((r<<24>>24|0)>=(f|0)){u=j;break}if((d|0)==14){r=g+s|0;a[r]=a[r]&63|-128;u=j;break}else if((d|0)==15){r=g+s|0;a[r]=a[r]|-64;u=j;break}else{a[n]=f&255;a[g+s|0]=(d|e)&255;u=j;break}}}while(0);d=k>>>12&15;do{if((d|0)==0){v=u}else{k=b+7|0;t=i+k|0;j=a[t]|0;s=j<<24>>24==0?u:1;if((j<<24>>24|0)>=(f|0)){v=s;break}if((d|0)==14){j=g+k|0;a[j]=a[j]&63|-128;v=s;break}else if((d|0)==15){j=g+k|0;a[j]=a[j]|-64;v=s;break}else{a[t]=f&255;a[g+k|0]=(d|e)&255;v=s;break}}}while(0);if((v|0)==0){l=0;return l|0}v=(c[2406860]|0)+40|0;c[v>>2]=c[v>>2]|32;l=0;return l|0}function brw(a){a=a|0;var b=0,d=0;b=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,7600489,0)|0;return a|0}function brx(){return+(+((c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0)/7600489.0)}function bry(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;if((b|0)==0){e=1;return e|0}f=c[642608+(c[2436]<<2)>>2]|0;g=c[((d|0)==0?f|0:f+4|0)>>2]|0;if((g|0)==0){c[b>>2]=0;e=1;return e|0}if((a[g]|0)!=0){f=0;do{a[9537776+f|0]=a[g+(f+3)|0]|0;f=f+1|0;}while(f>>>0<(gGy(g|0)|0)>>>0)}c[b>>2]=9537776;e=0;return e|0}function brz(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>1){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4554452+(b*112|0)>>2];c[a+104>>2]=c[4554456+(b*112|0)>>2];c[a+108>>2]=c[4554460+(b*112|0)>>2];d=0;return d|0}function brA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<2&(d|0)==0)){e=1;return e|0}c[a>>2]=4554352+(b*112|0);e=0;return e|0}function brB(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>26){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=965744+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function brC(a,b){a=a|0;b=b|0;var d=0,e=0;if((b|0)==0){if((a|0)==0){d=0;return d|0}e=a;c[e>>2]=c[172124];c[e+4>>2]=c[172125];c[e+8>>2]=c[172126];d=0;return d|0}e=b-1|0;if(e>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;a=1833272+(e*12|0)|0;c[b>>2]=c[a>>2];c[b+4>>2]=c[a+4>>2];c[b+8>>2]=c[a+8>>2];d=0;return d|0}function brD(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1488896:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function brE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1488896:0;e=0;return e|0}function brF(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2596192:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function brG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2596192:0;e=0;return e|0}function brH(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2595632:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function brI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2595632:0;e=0;return e|0}function brJ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1058624:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function brK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1058624:0;e=0;return e|0}function brL(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1482064:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function brM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1482064:0;e=0;return e|0}function brN(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2592720:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function brO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2592720:0;e=0;return e|0}function brP(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2591488:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function brQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2591488:0;e=0;return e|0}function brR(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>1){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[880804+(b*112|0)>>2];c[a+104>>2]=c[880808+(b*112|0)>>2];c[a+108>>2]=c[880812+(b*112|0)>>2];d=0;return d|0}function brS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<2&(d|0)==0)){e=1;return e|0}c[a>>2]=880704+(b*112|0);e=0;return e|0}function brT(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?762128:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function brU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?762128:0;e=0;return e|0}function brV(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>1){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1045396+(b*112|0)>>2];c[a+104>>2]=c[1045400+(b*112|0)>>2];c[a+108>>2]=c[1045404+(b*112|0)>>2];d=0;return d|0}function brW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<2&(d|0)==0)){e=1;return e|0}c[a>>2]=1045296+(b*112|0);e=0;return e|0}function brX(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1085616:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function brY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1085616:0;e=0;return e|0}function brZ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?899072:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function br_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?899072:0;e=0;return e|0}function br$(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?936704:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function br0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?936704:0;e=0;return e|0}function br1(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1084832:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function br2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1084832:0;e=0;return e|0}function br3(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1499200:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function br4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1499200:0;e=0;return e|0}function br5(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?935696:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function br6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?935696:0;e=0;return e|0}function br7(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?935472:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function br8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?935472:0;e=0;return e|0}function br9(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?935024:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bsa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?935024:0;e=0;return e|0}function bsb(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?5784456:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bsc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?5784456:0;e=0;return e|0}function bsd(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4548304:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bse(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4548304:0;e=0;return e|0}function bsf(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1497856:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bsg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1497856:0;e=0;return e|0}function bsh(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1075760:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bsi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1075760:0;e=0;return e|0}function bsj(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1487552:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bsk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1487552:0;e=0;return e|0}function bsl(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>1){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1487204+(b*112|0)>>2];c[a+104>>2]=c[1487208+(b*112|0)>>2];c[a+108>>2]=c[1487212+(b*112|0)>>2];d=0;return d|0}function bsm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<2&(d|0)==0)){e=1;return e|0}c[a>>2]=1487104+(b*112|0);e=0;return e|0}function bsn(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>1){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1073844+(b*112|0)>>2];c[a+104>>2]=c[1073848+(b*112|0)>>2];c[a+108>>2]=c[1073852+(b*112|0)>>2];d=0;return d|0}function bso(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<2&(d|0)==0)){e=1;return e|0}c[a>>2]=1073744+(b*112|0);e=0;return e|0}function bsp(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?5786248:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bsq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?5786248:0;e=0;return e|0}function bsr(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2596864:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bss(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2596864:0;e=0;return e|0}function bst(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2596752:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bsu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2596752:0;e=0;return e|0}function bsv(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?774560:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bsw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?774560:0;e=0;return e|0}function bsx(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1465600:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bsy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1465600:0;e=0;return e|0}function bsz(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?771984:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bsA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?771984:0;e=0;return e|0}function bsB(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?901200:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bsC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?901200:0;e=0;return e|0}function bsD(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?900752:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bsE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?900752:0;e=0;return e|0}function bsF(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?899296:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bsG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?899296:0;e=0;return e|0}function bsH(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>50){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=726080+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function bsI(a,b){a=a|0;b=b|0;var d=0,e=0;if((b|0)==0){if((a|0)==0){d=0;return d|0}e=a;c[e>>2]=c[170818];c[e+4>>2]=c[170819];c[e+8>>2]=c[170820];d=0;return d|0}e=b-1|0;if(e>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;a=966176+(e*12|0)|0;c[b>>2]=c[a>>2];c[b+4>>2]=c[a+4>>2];c[b+8>>2]=c[a+8>>2];d=0;return d|0}function bsJ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?899520:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bsK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?899520:0;e=0;return e|0}function bsL(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1057392:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bsM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1057392:0;e=0;return e|0}function bsN(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>1){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1474884+(b*112|0)>>2];c[a+104>>2]=c[1474888+(b*112|0)>>2];c[a+108>>2]=c[1474892+(b*112|0)>>2];d=0;return d|0}function bsO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<2&(d|0)==0)){e=1;return e|0}c[a>>2]=1474784+(b*112|0);e=0;return e|0}function bsP(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?875664:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bsQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?875664:0;e=0;return e|0}function bsR(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1468736:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bsS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1468736:0;e=0;return e|0}function bsT(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1055264:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bsU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1055264:0;e=0;return e|0}function bsV(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1055488:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bsW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1055488:0;e=0;return e|0}function bsX(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1055376:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bsY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1055376:0;e=0;return e|0}function bsZ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1468288:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bs_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1468288:0;e=0;return e|0}function bs$(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1054592:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bs0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1054592:0;e=0;return e|0}function bs1(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>1){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[763236+(b*112|0)>>2];c[a+104>>2]=c[763240+(b*112|0)>>2];c[a+108>>2]=c[763244+(b*112|0)>>2];d=0;return d|0}function bs2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<2&(d|0)==0)){e=1;return e|0}c[a>>2]=763136+(b*112|0);e=0;return e|0}function bs3(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2587120:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bs4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2587120:0;e=0;return e|0}function bs5(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?876224:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bs6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?876224:0;e=0;return e|0}function bs7(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>1){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2586100+(b*112|0)>>2];c[a+104>>2]=c[2586104+(b*112|0)>>2];c[a+108>>2]=c[2586108+(b*112|0)>>2];d=0;return d|0}function bs8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<2&(d|0)==0)){e=1;return e|0}c[a>>2]=2586e3+(b*112|0);e=0;return e|0}function bs9(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4548640:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bta(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4548640:0;e=0;return e|0}function btb(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?868272:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function btc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?868272:0;e=0;return e|0}function btd(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1499424:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bte(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1499424:0;e=0;return e|0}function btf(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1482400:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function btg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1482400:0;e=0;return e|0}function bth(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>3){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[777684+(b*112|0)>>2];c[a+104>>2]=c[777688+(b*112|0)>>2];c[a+108>>2]=c[777692+(b*112|0)>>2];d=0;return d|0}function bti(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<4&(d|0)==0)){e=1;return e|0}c[a>>2]=777584+(b*112|0);e=0;return e|0}function btj(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>3){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[918772+(b*112|0)>>2];c[a+104>>2]=c[918776+(b*112|0)>>2];c[a+108>>2]=c[918780+(b*112|0)>>2];d=0;return d|0}function btk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<4&(d|0)==0)){e=1;return e|0}c[a>>2]=918672+(b*112|0);e=0;return e|0}function btl(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?925392:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function btm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?925392:0;e=0;return e|0}function btn(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2598320:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bto(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2598320:0;e=0;return e|0}function btp(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1076320:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function btq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1076320:0;e=0;return e|0}function btr(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?918e3:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bts(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?918e3:0;e=0;return e|0}function btt(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1074192:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function btu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1074192:0;e=0;return e|0}function btv(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1066016:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function btw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1066016:0;e=0;return e|0}function btx(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4550656:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bty(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4550656:0;e=0;return e|0}function btz(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?869392:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function btA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?869392:0;e=0;return e|0}function btB(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4545840:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function btC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4545840:0;e=0;return e|0}function btD(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?849680:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function btE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?849680:0;e=0;return e|0}function btF(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1082032:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function btG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1082032:0;e=0;return e|0}function btH(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1070608:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function btI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1070608:0;e=0;return e|0}function btJ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1075424:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function btK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1075424:0;e=0;return e|0}function btL(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?875440:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function btM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?875440:0;e=0;return e|0}function btN(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?5784232:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function btO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?5784232:0;e=0;return e|0}function btP(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?882720:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function btQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?882720:0;e=0;return e|0}function btR(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1486320:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function btS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1486320:0;e=0;return e|0}function btT(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?773328:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function btU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?773328:0;e=0;return e|0}function btV(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2587904:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function btW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2587904:0;e=0;return e|0}function btX(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2602016:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function btY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2602016:0;e=0;return e|0}function btZ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?932896:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bt_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?932896:0;e=0;return e|0}function bt$(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1466160:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bt0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1466160:0;e=0;return e|0}function bt1(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1489120:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bt2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1489120:0;e=0;return e|0}function bt3(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?874768:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bt4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?874768:0;e=0;return e|0}function bt5(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?887648:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bt6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?887648:0;e=0;return e|0}function bt7(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1071840:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bt8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1071840:0;e=0;return e|0}function bt9(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?764704:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bua(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?764704:0;e=0;return e|0}function bub(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1474448:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function buc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1474448:0;e=0;return e|0}function bud(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1060640:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bue(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1060640:0;e=0;return e|0}function buf(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?899408:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bug(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?899408:0;e=0;return e|0}function buh(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>1){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[939044+(b*112|0)>>2];c[a+104>>2]=c[939048+(b*112|0)>>2];c[a+108>>2]=c[939052+(b*112|0)>>2];d=0;return d|0}function bui(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<2&(d|0)==0)){e=1;return e|0}c[a>>2]=938944+(b*112|0);e=0;return e|0}function buj(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?939280:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function buk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?939280:0;e=0;return e|0}function bul(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2602128:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bum(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2602128:0;e=0;return e|0}function bun(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?939168:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function buo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?939168:0;e=0;return e|0}function bup(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1499872:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function buq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1499872:0;e=0;return e|0}function bur(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1499648:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bus(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1499648:0;e=0;return e|0}function but(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1086064:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function buu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1086064:0;e=0;return e|0}function buv(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1085952:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function buw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1085952:0;e=0;return e|0}function bux(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4556144:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function buy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4556144:0;e=0;return e|0}function buz(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?938832:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function buA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?938832:0;e=0;return e|0}function buB(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?935136:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function buC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?935136:0;e=0;return e|0}function buD(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?938608:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function buE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?938608:0;e=0;return e|0}function buF(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1085840:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function buG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1085840:0;e=0;return e|0}function buH(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?938720:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function buI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?938720:0;e=0;return e|0}function buJ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?938384:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function buK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?938384:0;e=0;return e|0}function buL(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?791360:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function buM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?791360:0;e=0;return e|0}function buN(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1085728:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function buO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1085728:0;e=0;return e|0}function buP(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?938272:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function buQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?938272:0;e=0;return e|0}function buR(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?938160:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function buS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?938160:0;e=0;return e|0}function buT(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?937936:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function buU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?937936:0;e=0;return e|0}function buV(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?713944:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function buW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?713944:0;e=0;return e|0}function buX(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?714056:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function buY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?714056:0;e=0;return e|0}function buZ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?714168:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bu_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?714168:0;e=0;return e|0}function bu$(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?714280:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bu0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?714280:0;e=0;return e|0}function bu1(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?714392:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bu2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?714392:0;e=0;return e|0}function bu3(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?714504:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bu4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?714504:0;e=0;return e|0}function bu5(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?714616:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bu6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?714616:0;e=0;return e|0}function bu7(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?714728:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bu8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?714728:0;e=0;return e|0}function bu9(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?714840:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bva(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?714840:0;e=0;return e|0}function bvb(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?714952:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bvc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?714952:0;e=0;return e|0}function bvd(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?715064:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bve(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?715064:0;e=0;return e|0}function bvf(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?715176:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bvg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?715176:0;e=0;return e|0}function bvh(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?938048:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bvi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?938048:0;e=0;return e|0}function bvj(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?770192:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bvk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?770192:0;e=0;return e|0}function bvl(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1058176:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bvm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1058176:0;e=0;return e|0}function bvn(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1085504:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bvo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1085504:0;e=0;return e|0}function bvp(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4556032:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bvq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4556032:0;e=0;return e|0}function bvr(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2601904:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bvs(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2601904:0;e=0;return e|0}function bvt(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2601792:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bvu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2601792:0;e=0;return e|0}function bvv(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1499312:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bvw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1499312:0;e=0;return e|0}function bvx(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1085392:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bvy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1085392:0;e=0;return e|0}function bvz(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?937264:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bvA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?937264:0;e=0;return e|0}function bvB(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?937824:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bvC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?937824:0;e=0;return e|0}function bvD(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?937152:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bvE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?937152:0;e=0;return e|0}function bvF(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?938496:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bvG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?938496:0;e=0;return e|0}function bvH(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?791472:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bvI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?791472:0;e=0;return e|0}function bvJ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?937488:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bvK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?937488:0;e=0;return e|0}function bvL(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?937712:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bvM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?937712:0;e=0;return e|0}function bvN(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?937376:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bvO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?937376:0;e=0;return e|0}function bvP(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?791248:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bvQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?791248:0;e=0;return e|0}function bvR(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1085056:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bvS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1085056:0;e=0;return e|0}function bvT(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?936928:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bvU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?936928:0;e=0;return e|0}function bvV(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?936816:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bvW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?936816:0;e=0;return e|0}function bvX(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?791136:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bvY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?791136:0;e=0;return e|0}function bvZ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?937040:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bv_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?937040:0;e=0;return e|0}function bv$(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?791024:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bv0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?791024:0;e=0;return e|0}function bv1(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?790912:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bv2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?790912:0;e=0;return e|0}function bv3(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?790800:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bv4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?790800:0;e=0;return e|0}function bv5(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?790688:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bv6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?790688:0;e=0;return e|0}function bv7(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1499088:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bv8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1499088:0;e=0;return e|0}function bv9(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1084944:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bwa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1084944:0;e=0;return e|0}function bwb(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?936592:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bwc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?936592:0;e=0;return e|0}function bwd(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?790576:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bwe(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?790576:0;e=0;return e|0}function bwf(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1498640:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bwg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1498640:0;e=0;return e|0}function bwh(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?936480:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bwi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?936480:0;e=0;return e|0}function bwj(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?936368:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bwk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?936368:0;e=0;return e|0}function bwl(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?936256:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bwm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?936256:0;e=0;return e|0}function bwn(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1070944:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bwo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1070944:0;e=0;return e|0}function bwp(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?906912:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bwq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?906912:0;e=0;return e|0}function bwr(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?936032:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bws(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?936032:0;e=0;return e|0}function bwt(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1085280:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bwu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1085280:0;e=0;return e|0}function bwv(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?937600:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bww(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?937600:0;e=0;return e|0}function bwx(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?935808:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bwy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?935808:0;e=0;return e|0}function bwz(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?790464:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bwA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?790464:0;e=0;return e|0}function bwB(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4551440:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bwC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4551440:0;e=0;return e|0}function bwD(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2591824:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bwE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2591824:0;e=0;return e|0}function bwF(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1498976:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bwG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1498976:0;e=0;return e|0}function bwH(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?935584:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bwI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?935584:0;e=0;return e|0}function bwJ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?935248:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bwK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?935248:0;e=0;return e|0}function bwL(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2601680:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bwM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2601680:0;e=0;return e|0}function bwN(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1498864:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bwO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1498864:0;e=0;return e|0}function bwP(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2601568:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bwQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2601568:0;e=0;return e|0}function bwR(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1084720:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bwS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1084720:0;e=0;return e|0}function bwT(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?873760:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bwU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?873760:0;e=0;return e|0}function bwV(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2601456:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bwW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2601456:0;e=0;return e|0}function bwX(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1498752:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bwY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1498752:0;e=0;return e|0}function bwZ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?5786808:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bw_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?5786808:0;e=0;return e|0}function bw$(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4555920:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bw0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4555920:0;e=0;return e|0}function bw1(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4555808:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bw2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4555808:0;e=0;return e|0}function bw3(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?878688:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bw4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?878688:0;e=0;return e|0}function bw5(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?934800:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bw6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?934800:0;e=0;return e|0}function bw7(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?790240:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bw8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?790240:0;e=0;return e|0}function bw9(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1084496:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bxa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1084496:0;e=0;return e|0}function bxb(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?934688:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bxc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?934688:0;e=0;return e|0}function bxd(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?934576:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bxe(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?934576:0;e=0;return e|0}function bxf(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?790128:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bxg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?790128:0;e=0;return e|0}function bxh(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1084384:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bxi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1084384:0;e=0;return e|0}function bxj(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?934464:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bxk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?934464:0;e=0;return e|0}function bxl(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1081472:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bxm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1081472:0;e=0;return e|0}function bxn(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1084272:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bxo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1084272:0;e=0;return e|0}function bxp(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?789680:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bxq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?789680:0;e=0;return e|0}function bxr(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?789792:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bxs(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?789792:0;e=0;return e|0}function bxt(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?789904:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bxu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?789904:0;e=0;return e|0}function bxv(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?789456:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bxw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?789456:0;e=0;return e|0}function bxx(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?789568:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bxy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?789568:0;e=0;return e|0}function bxz(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?789344:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bxA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?789344:0;e=0;return e|0}function bxB(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?790016:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bxC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?790016:0;e=0;return e|0}function bxD(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?934352:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bxE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?934352:0;e=0;return e|0}function bxF(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?934240:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bxG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?934240:0;e=0;return e|0}function bxH(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?934128:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bxI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?934128:0;e=0;return e|0}function bxJ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?789232:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bxK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?789232:0;e=0;return e|0}function bxL(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2601344:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bxM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2601344:0;e=0;return e|0}function bxN(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1498416:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bxO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1498416:0;e=0;return e|0}function bxP(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2588352:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bxQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2588352:0;e=0;return e|0}function bxR(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1468848:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bxS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1468848:0;e=0;return e|0}function bxT(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?5786584:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bxU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?5786584:0;e=0;return e|0}function bxV(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4555472:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bxW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4555472:0;e=0;return e|0}function bxX(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?870064:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bxY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?870064:0;e=0;return e|0}function bxZ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?934016:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bx_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?934016:0;e=0;return e|0}function bx$(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?789120:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bx0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?789120:0;e=0;return e|0}function bx1(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?789008:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bx2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?789008:0;e=0;return e|0}function bx3(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2601232:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bx4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2601232:0;e=0;return e|0}function bx5(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1498304:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bx6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1498304:0;e=0;return e|0}function bx7(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?933904:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bx8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?933904:0;e=0;return e|0}function bx9(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?788896:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bya(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?788896:0;e=0;return e|0}function byb(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?933792:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function byc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?933792:0;e=0;return e|0}function byd(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?933680:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bye(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?933680:0;e=0;return e|0}function byf(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1084048:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function byg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1084048:0;e=0;return e|0}function byh(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?933568:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function byi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?933568:0;e=0;return e|0}function byj(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1083936:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function byk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1083936:0;e=0;return e|0}function byl(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1083824:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bym(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1083824:0;e=0;return e|0}function byn(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?933456:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function byo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?933456:0;e=0;return e|0}function byp(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?788784:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function byq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?788784:0;e=0;return e|0}function byr(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1498192:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bys(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1498192:0;e=0;return e|0}function byt(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1498080:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function byu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1498080:0;e=0;return e|0}function byv(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1497968:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function byw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1497968:0;e=0;return e|0}function byx(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?933120:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function byy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?933120:0;e=0;return e|0}function byz(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1083600:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function byA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1083600:0;e=0;return e|0}function byB(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1083488:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function byC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1083488:0;e=0;return e|0}function byD(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?933008:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function byE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?933008:0;e=0;return e|0}function byF(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1083712:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function byG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1083712:0;e=0;return e|0}function byH(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?932560:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function byI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?932560:0;e=0;return e|0}function byJ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?929872:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function byK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?929872:0;e=0;return e|0}function byL(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?932672:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function byM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?932672:0;e=0;return e|0}function byN(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?932784:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function byO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?932784:0;e=0;return e|0}function byP(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2600896:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function byQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2600896:0;e=0;return e|0}function byR(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?929760:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function byS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?929760:0;e=0;return e|0}function byT(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1495952:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function byU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1495952:0;e=0;return e|0}function byV(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?932448:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function byW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?932448:0;e=0;return e|0}function byX(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1497520:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function byY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1497520:0;e=0;return e|0}function byZ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1083376:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function by_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1083376:0;e=0;return e|0}function by$(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1497408:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function by0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1497408:0;e=0;return e|0}function by1(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?932336:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function by2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?932336:0;e=0;return e|0}function by3(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1497296:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function by4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1497296:0;e=0;return e|0}function by5(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1083264:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function by6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1083264:0;e=0;return e|0}function by7(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?932224:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function by8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?932224:0;e=0;return e|0}function by9(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1497184:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bza(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1497184:0;e=0;return e|0}function bzb(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?786544:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bzc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?786544:0;e=0;return e|0}function bzd(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?786656:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bze(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?786656:0;e=0;return e|0}function bzf(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?788112:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bzg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?788112:0;e=0;return e|0}function bzh(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?788224:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bzi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?788224:0;e=0;return e|0}function bzj(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?788336:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bzk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?788336:0;e=0;return e|0}function bzl(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?788448:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bzm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?788448:0;e=0;return e|0}function bzn(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?788560:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bzo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?788560:0;e=0;return e|0}function bzp(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?787776:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bzq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?787776:0;e=0;return e|0}function bzr(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?787888:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bzs(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?787888:0;e=0;return e|0}function bzt(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?788e3:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bzu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?788e3:0;e=0;return e|0}function bzv(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?787552:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bzw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?787552:0;e=0;return e|0}function bzx(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?787664:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bzy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?787664:0;e=0;return e|0}function bzz(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?786432:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bzA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?786432:0;e=0;return e|0}function bzB(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?786768:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bzC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?786768:0;e=0;return e|0}function bzD(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?786880:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bzE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?786880:0;e=0;return e|0}function bzF(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?786992:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bzG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?786992:0;e=0;return e|0}function bzH(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?787104:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bzI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?787104:0;e=0;return e|0}function bzJ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?787216:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bzK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?787216:0;e=0;return e|0}function bzL(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?787328:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bzM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?787328:0;e=0;return e|0}function bzN(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?787440:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bzO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?787440:0;e=0;return e|0}function bzP(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1497072:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bzQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1497072:0;e=0;return e|0}function bzR(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1083152:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bzS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1083152:0;e=0;return e|0}function bzT(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1070720:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bzU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1070720:0;e=0;return e|0}function bzV(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?932e3:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bzW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?932e3:0;e=0;return e|0}function bzX(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?931888:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bzY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?931888:0;e=0;return e|0}function bzZ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?931664:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bz_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?931664:0;e=0;return e|0}function bz$(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?931776:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bz0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?931776:0;e=0;return e|0}function bz1(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1496960:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bz2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1496960:0;e=0;return e|0}function bz3(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?931552:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bz4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?931552:0;e=0;return e|0}function bz5(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?786208:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bz6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?786208:0;e=0;return e|0}function bz7(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1492928:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bz8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1492928:0;e=0;return e|0}function bz9(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?931440:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bAa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?931440:0;e=0;return e|0}function bAb(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?930992:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bAc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?930992:0;e=0;return e|0}function bAd(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?786096:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bAe(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?786096:0;e=0;return e|0}function bAf(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1496848:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bAg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1496848:0;e=0;return e|0}function bAh(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?931328:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bAi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?931328:0;e=0;return e|0}function bAj(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?931216:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bAk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?931216:0;e=0;return e|0}function bAl(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?931104:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bAm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?931104:0;e=0;return e|0}function bAn(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1496736:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bAo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1496736:0;e=0;return e|0}function bAp(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1082928:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bAq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1082928:0;e=0;return e|0}function bAr(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1082816:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bAs(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1082816:0;e=0;return e|0}function bAt(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?930544:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bAu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?930544:0;e=0;return e|0}function bAv(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?930432:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bAw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?930432:0;e=0;return e|0}function bAx(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?930656:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bAy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?930656:0;e=0;return e|0}function bAz(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?930768:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bAA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?930768:0;e=0;return e|0}function bAB(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?930880:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bAC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?930880:0;e=0;return e|0}function bAD(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?785984:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bAE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?785984:0;e=0;return e|0}function bAF(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?785872:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bAG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?785872:0;e=0;return e|0}function bAH(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1082704:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bAI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1082704:0;e=0;return e|0}function bAJ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?785312:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bAK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?785312:0;e=0;return e|0}function bAL(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?785424:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bAM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?785424:0;e=0;return e|0}function bAN(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?785536:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bAO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?785536:0;e=0;return e|0}function bAP(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?785648:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bAQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?785648:0;e=0;return e|0}function bAR(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?785760:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bAS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?785760:0;e=0;return e|0}function bAT(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1496400:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bAU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1496400:0;e=0;return e|0}function bAV(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1082592:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bAW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1082592:0;e=0;return e|0}function bAX(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?930320:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bAY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?930320:0;e=0;return e|0}function bAZ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1081584:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bA_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1081584:0;e=0;return e|0}function bA$(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1077776:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bA0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1077776:0;e=0;return e|0}function bA1(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?920688:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bA2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?920688:0;e=0;return e|0}function bA3(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1496176:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bA4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1496176:0;e=0;return e|0}function bA5(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?930096:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bA6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?930096:0;e=0;return e|0}function bA7(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?785088:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bA8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?785088:0;e=0;return e|0}function bA9(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?930208:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bBa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?930208:0;e=0;return e|0}function bBb(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?785200:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bBc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?785200:0;e=0;return e|0}function bBd(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1496064:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bBe(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1496064:0;e=0;return e|0}function bBf(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1082480:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bBg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1082480:0;e=0;return e|0}function bBh(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2600784:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bBi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2600784:0;e=0;return e|0}function bBj(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1495840:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bBk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1495840:0;e=0;return e|0}function bBl(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1495728:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bBm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1495728:0;e=0;return e|0}function bBn(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?929648:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bBo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?929648:0;e=0;return e|0}function bBp(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?784976:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bBq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?784976:0;e=0;return e|0}function bBr(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2600672:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bBs(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2600672:0;e=0;return e|0}function bBt(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1495616:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bBu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1495616:0;e=0;return e|0}function bBv(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1082256:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bBw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1082256:0;e=0;return e|0}function bBx(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1082144:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bBy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1082144:0;e=0;return e|0}function bBz(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?929536:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bBA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?929536:0;e=0;return e|0}function bBB(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?929424:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bBC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?929424:0;e=0;return e|0}function bBD(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?929200:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bBE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?929200:0;e=0;return e|0}function bBF(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?929088:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bBG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?929088:0;e=0;return e|0}function bBH(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?928976:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bBI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?928976:0;e=0;return e|0}function bBJ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?784528:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bBK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?784528:0;e=0;return e|0}function bBL(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?784416:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bBM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?784416:0;e=0;return e|0}function bBN(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1495504:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bBO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1495504:0;e=0;return e|0}function bBP(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1081808:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bBQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1081808:0;e=0;return e|0}function bBR(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?928752:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bBS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?928752:0;e=0;return e|0}function bBT(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2600560:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bBU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2600560:0;e=0;return e|0}function bBV(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?928864:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bBW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?928864:0;e=0;return e|0}function bBX(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1081696:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bBY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1081696:0;e=0;return e|0}function bBZ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?928640:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bB_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?928640:0;e=0;return e|0}function bB$(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?784304:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bB0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?784304:0;e=0;return e|0}function bB1(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?713720:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bB2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?713720:0;e=0;return e|0}function bB3(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?928528:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bB4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?928528:0;e=0;return e|0}function bB5(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?928416:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bB6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?928416:0;e=0;return e|0}function bB7(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?784192:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bB8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?784192:0;e=0;return e|0}function bB9(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?928080:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bCa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?928080:0;e=0;return e|0}function bCb(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?783856:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bCc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?783856:0;e=0;return e|0}function bCd(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1492704:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bCe(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1492704:0;e=0;return e|0}function bCf(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1079904:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bCg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1079904:0;e=0;return e|0}function bCh(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1079792:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bCi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1079792:0;e=0;return e|0}function bCj(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1085168:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bCk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1085168:0;e=0;return e|0}function bCl(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1495280:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bCm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1495280:0;e=0;return e|0}function bCn(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1495168:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bCo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1495168:0;e=0;return e|0}function bCp(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?927744:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bCq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?927744:0;e=0;return e|0}function bCr(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?927968:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bCs(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?927968:0;e=0;return e|0}function bCt(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1496288:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bCu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1496288:0;e=0;return e|0}function bCv(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?927856:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bCw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?927856:0;e=0;return e|0}function bCx(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1493264:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bCy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1493264:0;e=0;return e|0}function bCz(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?926848:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bCA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?926848:0;e=0;return e|0}function bCB(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?927520:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bCC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?927520:0;e=0;return e|0}function bCD(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?873088:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bCE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?873088:0;e=0;return e|0}function bCF(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?927632:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bCG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?927632:0;e=0;return e|0}function bCH(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?927408:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bCI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?927408:0;e=0;return e|0}function bCJ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1053248:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bCK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1053248:0;e=0;return e|0}function bCL(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1495056:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bCM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1495056:0;e=0;return e|0}function bCN(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1081360:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bCO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1081360:0;e=0;return e|0}function bCP(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?927296:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bCQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?927296:0;e=0;return e|0}function bCR(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1494608:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bCS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1494608:0;e=0;return e|0}function bCT(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1494720:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bCU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1494720:0;e=0;return e|0}function bCV(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2600224:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bCW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2600224:0;e=0;return e|0}function bCX(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1494496:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bCY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1494496:0;e=0;return e|0}function bCZ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?927184:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bC_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?927184:0;e=0;return e|0}function bC$(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?927072:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bC0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?927072:0;e=0;return e|0}function bC1(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?783744:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bC2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?783744:0;e=0;return e|0}function bC3(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?926960:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bC4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?926960:0;e=0;return e|0}function bC5(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?783632:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bC6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?783632:0;e=0;return e|0}function bC7(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?783520:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bC8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?783520:0;e=0;return e|0}function bC9(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?713608:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bDa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?713608:0;e=0;return e|0}function bDb(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?918112:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bDc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?918112:0;e=0;return e|0}function bDd(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?926736:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bDe(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?926736:0;e=0;return e|0}function bDf(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?926624:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bDg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?926624:0;e=0;return e|0}function bDh(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?783408:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bDi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?783408:0;e=0;return e|0}function bDj(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1494272:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bDk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1494272:0;e=0;return e|0}function bDl(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1081136:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bDm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1081136:0;e=0;return e|0}function bDn(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1081024:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bDo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1081024:0;e=0;return e|0}function bDp(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4555248:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bDq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4555248:0;e=0;return e|0}function bDr(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1494160:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bDs(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1494160:0;e=0;return e|0}function bDt(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?926512:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bDu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?926512:0;e=0;return e|0}function bDv(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?926400:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bDw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?926400:0;e=0;return e|0}function bDx(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1494048:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bDy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1494048:0;e=0;return e|0}function bDz(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?781280:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bDA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?781280:0;e=0;return e|0}function bDB(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?781392:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bDC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?781392:0;e=0;return e|0}function bDD(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?781504:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bDE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?781504:0;e=0;return e|0}function bDF(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?781616:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bDG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?781616:0;e=0;return e|0}function bDH(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?782512:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bDI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?782512:0;e=0;return e|0}function bDJ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?782624:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bDK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?782624:0;e=0;return e|0}function bDL(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?782736:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bDM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?782736:0;e=0;return e|0}function bDN(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?782848:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bDO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?782848:0;e=0;return e|0}function bDP(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?782960:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bDQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?782960:0;e=0;return e|0}function bDR(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?783072:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bDS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?783072:0;e=0;return e|0}function bDT(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?783184:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bDU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?783184:0;e=0;return e|0}function bDV(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?783296:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bDW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?783296:0;e=0;return e|0}function bDX(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?781728:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bDY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?781728:0;e=0;return e|0}function bDZ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?781840:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bD_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?781840:0;e=0;return e|0}function bD$(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?781952:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bD0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?781952:0;e=0;return e|0}function bD1(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?782064:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bD2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?782064:0;e=0;return e|0}function bD3(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?782176:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bD4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?782176:0;e=0;return e|0}function bD5(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?782288:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bD6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?782288:0;e=0;return e|0}function bD7(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?782400:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bD8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?782400:0;e=0;return e|0}function bD9(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1080912:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bEa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1080912:0;e=0;return e|0}function bEb(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?926288:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bEc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?926288:0;e=0;return e|0}function bEd(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1080800:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bEe(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1080800:0;e=0;return e|0}function bEf(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?926176:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bEg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?926176:0;e=0;return e|0}function bEh(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?926064:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bEi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?926064:0;e=0;return e|0}function bEj(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?781168:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bEk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?781168:0;e=0;return e|0}function bEl(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1493936:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bEm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1493936:0;e=0;return e|0}function bEn(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?925952:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bEo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?925952:0;e=0;return e|0}function bEp(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2600112:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bEq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2600112:0;e=0;return e|0}function bEr(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1493712:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bEs(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1493712:0;e=0;return e|0}function bEt(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1493824:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bEu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1493824:0;e=0;return e|0}function bEv(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?781056:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bEw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?781056:0;e=0;return e|0}function bEx(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?780272:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bEy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?780272:0;e=0;return e|0}function bEz(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?780384:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bEA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?780384:0;e=0;return e|0}function bEB(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?780496:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bEC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?780496:0;e=0;return e|0}function bED(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?780608:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bEE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?780608:0;e=0;return e|0}function bEF(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?780720:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bEG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?780720:0;e=0;return e|0}function bEH(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?780832:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bEI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?780832:0;e=0;return e|0}function bEJ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?780944:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bEK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?780944:0;e=0;return e|0}function bEL(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?780048:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bEM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?780048:0;e=0;return e|0}function bEN(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?780160:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bEO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?780160:0;e=0;return e|0}function bEP(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1080688:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bEQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1080688:0;e=0;return e|0}function bER(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1080576:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bES(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1080576:0;e=0;return e|0}function bET(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1493600:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bEU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1493600:0;e=0;return e|0}function bEV(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1080464:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bEW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1080464:0;e=0;return e|0}function bEX(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?26e5:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bEY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?26e5:0;e=0;return e|0}function bEZ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?925616:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bE_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?925616:0;e=0;return e|0}function bE$(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?779936:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bE0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?779936:0;e=0;return e|0}function bE1(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?779824:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bE2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?779824:0;e=0;return e|0}function bE3(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?713496:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bE4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?713496:0;e=0;return e|0}function bE5(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?925504:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bE6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?925504:0;e=0;return e|0}function bE7(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?924496:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bE8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?924496:0;e=0;return e|0}function bE9(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1493376:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bFa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1493376:0;e=0;return e|0}function bFb(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1080240:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bFc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1080240:0;e=0;return e|0}function bFd(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?925280:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bFe(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?925280:0;e=0;return e|0}function bFf(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?925168:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bFg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?925168:0;e=0;return e|0}function bFh(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1493152:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bFi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1493152:0;e=0;return e|0}function bFj(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2581072:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bFk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2581072:0;e=0;return e|0}function bFl(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?865696:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bFm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?865696:0;e=0;return e|0}function bFn(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?925056:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bFo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?925056:0;e=0;return e|0}function bFp(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?779600:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bFq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?779600:0;e=0;return e|0}function bFr(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?859088:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bFs(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?859088:0;e=0;return e|0}function bFt(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?924832:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bFu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?924832:0;e=0;return e|0}function bFv(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?697264:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bFw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?697264:0;e=0;return e|0}function bFx(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?697376:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bFy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?697376:0;e=0;return e|0}function bFz(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?697488:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bFA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?697488:0;e=0;return e|0}function bFB(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?697600:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bFC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?697600:0;e=0;return e|0}function bFD(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?697712:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bFE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?697712:0;e=0;return e|0}function bFF(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?697824:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bFG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?697824:0;e=0;return e|0}function bFH(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?696592:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bFI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?696592:0;e=0;return e|0}function bFJ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?696704:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bFK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?696704:0;e=0;return e|0}function bFL(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?696816:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bFM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?696816:0;e=0;return e|0}function bFN(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?696928:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bFO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?696928:0;e=0;return e|0}function bFP(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?697040:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bFQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?697040:0;e=0;return e|0}function bFR(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?697152:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bFS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?697152:0;e=0;return e|0}function bFT(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?696256:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bFU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?696256:0;e=0;return e|0}function bFV(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?696368:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bFW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?696368:0;e=0;return e|0}function bFX(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?696480:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bFY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?696480:0;e=0;return e|0}function bFZ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2599776:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bF_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2599776:0;e=0;return e|0}function bF$(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?924720:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bF0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?924720:0;e=0;return e|0}function bF1(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1492816:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bF2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1492816:0;e=0;return e|0}function bF3(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1080016:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bF4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1080016:0;e=0;return e|0}function bF5(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?924608:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bF6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?924608:0;e=0;return e|0}function bF7(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1079680:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bF8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1079680:0;e=0;return e|0}function bF9(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?924384:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bGa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?924384:0;e=0;return e|0}function bGb(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2599664:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bGc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2599664:0;e=0;return e|0}function bGd(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1492592:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bGe(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1492592:0;e=0;return e|0}function bGf(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1492480:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bGg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1492480:0;e=0;return e|0}function bGh(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1079568:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bGi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1079568:0;e=0;return e|0}function bGj(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?911280:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bGk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?911280:0;e=0;return e|0}function bGl(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?924048:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bGm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?924048:0;e=0;return e|0}function bGn(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?923936:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bGo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?923936:0;e=0;return e|0}function bGp(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1492368:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bGq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1492368:0;e=0;return e|0}function bGr(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1079232:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bGs(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1079232:0;e=0;return e|0}function bGt(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?779488:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bGu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?779488:0;e=0;return e|0}function bGv(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?779376:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bGw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?779376:0;e=0;return e|0}function bGx(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?936144:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bGy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?936144:0;e=0;return e|0}function bGz(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4555024:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bGA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4555024:0;e=0;return e|0}function bGB(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2599104:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bGC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2599104:0;e=0;return e|0}function bGD(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?923712:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bGE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?923712:0;e=0;return e|0}function bGF(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?779152:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bGG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?779152:0;e=0;return e|0}function bGH(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?923824:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bGI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?923824:0;e=0;return e|0}function bGJ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?779264:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bGK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?779264:0;e=0;return e|0}function bGL(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?923600:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bGM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?923600:0;e=0;return e|0}function bGN(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?779040:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bGO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?779040:0;e=0;return e|0}function bGP(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?923040:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bGQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?923040:0;e=0;return e|0}function bGR(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?885632:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bGS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?885632:0;e=0;return e|0}function bGT(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?922816:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bGU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?922816:0;e=0;return e|0}function bGV(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1078784:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bGW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1078784:0;e=0;return e|0}function bGX(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?922704:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bGY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?922704:0;e=0;return e|0}function bGZ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1078672:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bG_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1078672:0;e=0;return e|0}function bG$(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?922480:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bG0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?922480:0;e=0;return e|0}function bG1(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?922368:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bG2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?922368:0;e=0;return e|0}function bG3(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?712488:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bG4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?712488:0;e=0;return e|0}function bG5(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?712600:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bG6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?712600:0;e=0;return e|0}function bG7(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?712712:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bG8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?712712:0;e=0;return e|0}function bG9(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?712824:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bHa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?712824:0;e=0;return e|0}function bHb(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?712936:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bHc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?712936:0;e=0;return e|0}function bHd(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?713048:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bHe(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?713048:0;e=0;return e|0}function bHf(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?713160:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bHg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?713160:0;e=0;return e|0}function bHh(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?713272:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bHi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?713272:0;e=0;return e|0}function bHj(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?713384:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bHk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?713384:0;e=0;return e|0}function bHl(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1077440:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bHm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1077440:0;e=0;return e|0}function bHn(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?920240:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bHo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?920240:0;e=0;return e|0}function bHp(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?922256:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bHq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?922256:0;e=0;return e|0}function bHr(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1084160:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bHs(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1084160:0;e=0;return e|0}function bHt(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1492032:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bHu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1492032:0;e=0;return e|0}function bHv(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1491920:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bHw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1491920:0;e=0;return e|0}function bHx(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?922032:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bHy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?922032:0;e=0;return e|0}function bHz(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?921920:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bHA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?921920:0;e=0;return e|0}function bHB(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?921696:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bHC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?921696:0;e=0;return e|0}function bHD(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?778928:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bHE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?778928:0;e=0;return e|0}function bHF(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?921584:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bHG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?921584:0;e=0;return e|0}function bHH(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?921808:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bHI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?921808:0;e=0;return e|0}function bHJ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?712152:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bHK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?712152:0;e=0;return e|0}function bHL(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?712264:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bHM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?712264:0;e=0;return e|0}function bHN(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?712376:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bHO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?712376:0;e=0;return e|0}function bHP(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?921472:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bHQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?921472:0;e=0;return e|0}function bHR(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1491808:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bHS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1491808:0;e=0;return e|0}function bHT(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2599328:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bHU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2599328:0;e=0;return e|0}function bHV(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1491696:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bHW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1491696:0;e=0;return e|0}function bHX(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1491584:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bHY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1491584:0;e=0;return e|0}function bHZ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?921248:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bH_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?921248:0;e=0;return e|0}function bH$(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?696144:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bH0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?696144:0;e=0;return e|0}function bH1(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1077888:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bH2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1077888:0;e=0;return e|0}function bH3(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?901536:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bH4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?901536:0;e=0;return e|0}function bH5(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?771872:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bH6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?771872:0;e=0;return e|0}function bH7(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?921024:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bH8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?921024:0;e=0;return e|0}function bH9(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?920912:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bIa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?920912:0;e=0;return e|0}function bIb(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?920800:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bIc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?920800:0;e=0;return e|0}function bId(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1079008:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bIe(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1079008:0;e=0;return e|0}function bIf(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?923488:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bIg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?923488:0;e=0;return e|0}function bIh(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?923376:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bIi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?923376:0;e=0;return e|0}function bIj(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?923264:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bIk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?923264:0;e=0;return e|0}function bIl(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?920464:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bIm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?920464:0;e=0;return e|0}function bIn(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?712040:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bIo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?712040:0;e=0;return e|0}function bIp(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?778592:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bIq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?778592:0;e=0;return e|0}function bIr(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?921136:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bIs(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?921136:0;e=0;return e|0}function bIt(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1491360:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bIu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1491360:0;e=0;return e|0}function bIv(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1077664:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bIw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1077664:0;e=0;return e|0}function bIx(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?5786472:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bIy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?5786472:0;e=0;return e|0}function bIz(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4555136:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bIA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4555136:0;e=0;return e|0}function bIB(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1077552:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bIC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1077552:0;e=0;return e|0}function bID(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?920352:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bIE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?920352:0;e=0;return e|0}function bIF(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1056272:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bIG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1056272:0;e=0;return e|0}function bIH(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2599552:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bII(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2599552:0;e=0;return e|0}function bIJ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2599216:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bIK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2599216:0;e=0;return e|0}function bIL(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?922144:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bIM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?922144:0;e=0;return e|0}function bIN(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?920576:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bIO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?920576:0;e=0;return e|0}function bIP(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?778816:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bIQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?778816:0;e=0;return e|0}function bIR(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?920128:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bIS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?920128:0;e=0;return e|0}function bIT(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2598992:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bIU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2598992:0;e=0;return e|0}function bIV(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1491136:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bIW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1491136:0;e=0;return e|0}function bIX(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2598880:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bIY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2598880:0;e=0;return e|0}function bIZ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1078896:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bI_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1078896:0;e=0;return e|0}function bI$(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1491024:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bI0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1491024:0;e=0;return e|0}function bI1(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1077328:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bI2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1077328:0;e=0;return e|0}function bI3(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?778368:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bI4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?778368:0;e=0;return e|0}function bI5(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1077216:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bI6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1077216:0;e=0;return e|0}function bI7(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?920016:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bI8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?920016:0;e=0;return e|0}function bI9(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2599440:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bJa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2599440:0;e=0;return e|0}function bJb(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1492256:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bJc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1492256:0;e=0;return e|0}function bJd(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1078560:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bJe(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1078560:0;e=0;return e|0}function bJf(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1078224:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bJg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1078224:0;e=0;return e|0}function bJh(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1078336:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bJi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1078336:0;e=0;return e|0}function bJj(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1078448:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bJk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1078448:0;e=0;return e|0}function bJl(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?919792:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bJm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?919792:0;e=0;return e|0}function bJn(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?778256:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bJo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?778256:0;e=0;return e|0}function bJp(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?5785128:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bJq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?5785128:0;e=0;return e|0}function bJr(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?919568:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bJs(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?919568:0;e=0;return e|0}function bJt(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1077104:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bJu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1077104:0;e=0;return e|0}function bJv(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4554800:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bJw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4554800:0;e=0;return e|0}function bJx(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2598432:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bJy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2598432:0;e=0;return e|0}function bJz(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2598544:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bJA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2598544:0;e=0;return e|0}function bJB(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1490464:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bJC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1490464:0;e=0;return e|0}function bJD(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4554912:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bJE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4554912:0;e=0;return e|0}function bJF(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2598656:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bJG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2598656:0;e=0;return e|0}function bJH(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2598768:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bJI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2598768:0;e=0;return e|0}function bJJ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1490800:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bJK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1490800:0;e=0;return e|0}function bJL(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1076992:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bJM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1076992:0;e=0;return e|0}function bJN(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1076880:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bJO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1076880:0;e=0;return e|0}function bJP(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1490912:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bJQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1490912:0;e=0;return e|0}function bJR(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?778144:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bJS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?778144:0;e=0;return e|0}function bJT(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1490688:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bJU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1490688:0;e=0;return e|0}function bJV(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1490576:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bJW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1490576:0;e=0;return e|0}function bJX(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1076768:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bJY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1076768:0;e=0;return e|0}function bJZ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?919232:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bJ_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?919232:0;e=0;return e|0}function bJ$(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?778032:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bJ0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?778032:0;e=0;return e|0}function bJ1(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1076656:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bJ2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1076656:0;e=0;return e|0}function bJ3(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?919456:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bJ4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?919456:0;e=0;return e|0}function bJ5(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?919344:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bJ6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?919344:0;e=0;return e|0}function bJ7(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1490352:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bJ8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1490352:0;e=0;return e|0}function bJ9(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1490240:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bKa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1490240:0;e=0;return e|0}function bKb(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?919120:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bKc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?919120:0;e=0;return e|0}function bKd(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?867488:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bKe(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?867488:0;e=0;return e|0}function bKf(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?905792:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bKg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?905792:0;e=0;return e|0}function bKh(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1052688:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bKi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1052688:0;e=0;return e|0}function bKj(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?708120:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bKk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?708120:0;e=0;return e|0}function bKl(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?708568:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bKm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?708568:0;e=0;return e|0}function bKn(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?708680:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bKo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?708680:0;e=0;return e|0}function bKp(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?708792:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bKq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?708792:0;e=0;return e|0}function bKr(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?708904:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bKs(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?708904:0;e=0;return e|0}function bKt(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?709016:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bKu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?709016:0;e=0;return e|0}function bKv(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?709128:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bKw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?709128:0;e=0;return e|0}function bKx(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?708008:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bKy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?708008:0;e=0;return e|0}function bKz(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?708232:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bKA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?708232:0;e=0;return e|0}function bKB(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?708344:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bKC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?708344:0;e=0;return e|0}function bKD(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?708456:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bKE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?708456:0;e=0;return e|0}function bKF(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?863456:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bKG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?863456:0;e=0;return e|0}function bKH(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1490128:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bKI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1490128:0;e=0;return e|0}function bKJ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1490016:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bKK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1490016:0;e=0;return e|0}function bKL(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1076544:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bKM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1076544:0;e=0;return e|0}function bKN(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?918560:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bKO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?918560:0;e=0;return e|0}function bKP(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1076432:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bKQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1076432:0;e=0;return e|0}function bKR(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1489904:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bKS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1489904:0;e=0;return e|0}function bKT(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?918448:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bKU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?918448:0;e=0;return e|0}function bKV(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?777360:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bKW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?777360:0;e=0;return e|0}function bKX(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?777472:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bKY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?777472:0;e=0;return e|0}function bKZ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?711928:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bK_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?711928:0;e=0;return e|0}function bK$(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?777248:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bK0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?777248:0;e=0;return e|0}function bK1(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?918336:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bK2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?918336:0;e=0;return e|0}function bK3(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1045856:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bK4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1045856:0;e=0;return e|0}function bK5(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4553008:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bK6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4553008:0;e=0;return e|0}function bK7(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2598208:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bK8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2598208:0;e=0;return e|0}function bK9(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1489792:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bLa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1489792:0;e=0;return e|0}function bLb(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?917888:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bLc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?917888:0;e=0;return e|0}function bLd(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?777136:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bLe(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?777136:0;e=0;return e|0}function bLf(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?711816:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bLg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?711816:0;e=0;return e|0}function bLh(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1489680:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bLi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1489680:0;e=0;return e|0}function bLj(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4554688:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bLk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4554688:0;e=0;return e|0}function bLl(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2598096:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bLm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2598096:0;e=0;return e|0}function bLn(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1489568:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bLo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1489568:0;e=0;return e|0}function bLp(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1076096:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bLq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1076096:0;e=0;return e|0}function bLr(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?917664:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bLs(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?917664:0;e=0;return e|0}function bLt(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?5786360:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bLu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?5786360:0;e=0;return e|0}function bLv(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4554128:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bLw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4554128:0;e=0;return e|0}function bLx(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4554240:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bLy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4554240:0;e=0;return e|0}function bLz(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?6524344:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bLA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?6524344:0;e=0;return e|0}function bLB(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?914976:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bLC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?914976:0;e=0;return e|0}function bLD(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4554576:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bLE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4554576:0;e=0;return e|0}function bLF(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2597984:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bLG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2597984:0;e=0;return e|0}function bLH(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?917552:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bLI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?917552:0;e=0;return e|0}function bLJ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?917328:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bLK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?917328:0;e=0;return e|0}function bLL(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1075984:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bLM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1075984:0;e=0;return e|0}function bLN(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?917216:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bLO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?917216:0;e=0;return e|0}function bLP(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?777024:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bLQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?777024:0;e=0;return e|0}function bLR(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?917104:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bLS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?917104:0;e=0;return e|0}function bLT(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?776912:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bLU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?776912:0;e=0;return e|0}function bLV(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?916992:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bLW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?916992:0;e=0;return e|0}function bLX(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1075872:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bLY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1075872:0;e=0;return e|0}function bLZ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?916432:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bL_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?916432:0;e=0;return e|0}function bL$(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2597536:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bL0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2597536:0;e=0;return e|0}function bL1(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?916544:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bL2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?916544:0;e=0;return e|0}function bL3(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1487440:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bL4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1487440:0;e=0;return e|0}function bL5(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?916768:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bL6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?916768:0;e=0;return e|0}function bL7(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?905568:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bL8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?905568:0;e=0;return e|0}function bL9(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?696032:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bMa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?696032:0;e=0;return e|0}function bMb(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?916656:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bMc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?916656:0;e=0;return e|0}function bMd(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?906352:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bMe(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?906352:0;e=0;return e|0}function bMf(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?916320:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bMg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?916320:0;e=0;return e|0}function bMh(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?916208:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bMi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?916208:0;e=0;return e|0}function bMj(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?776800:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bMk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?776800:0;e=0;return e|0}function bMl(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1489344:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bMm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1489344:0;e=0;return e|0}function bMn(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?916096:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bMo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?916096:0;e=0;return e|0}function bMp(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?915984:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bMq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?915984:0;e=0;return e|0}function bMr(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?915872:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bMs(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?915872:0;e=0;return e|0}function bMt(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1486544:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bMu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1486544:0;e=0;return e|0}function bMv(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?915760:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bMw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?915760:0;e=0;return e|0}function bMx(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4554016:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bMy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4554016:0;e=0;return e|0}function bMz(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1487776:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bMA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1487776:0;e=0;return e|0}function bMB(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1489008:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bMC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1489008:0;e=0;return e|0}function bMD(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1488672:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bME(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1488672:0;e=0;return e|0}function bMF(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1489232:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bMG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1489232:0;e=0;return e|0}function bMH(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1488784:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bMI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1488784:0;e=0;return e|0}function bMJ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?915536:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bMK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?915536:0;e=0;return e|0}function bML(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?776688:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bMM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?776688:0;e=0;return e|0}function bMN(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2597648:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bMO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2597648:0;e=0;return e|0}function bMP(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?915424:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bMQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?915424:0;e=0;return e|0}function bMR(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?915312:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bMS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?915312:0;e=0;return e|0}function bMT(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?776576:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bMU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?776576:0;e=0;return e|0}function bMV(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?711704:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bMW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?711704:0;e=0;return e|0}function bMX(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?878464:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bMY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?878464:0;e=0;return e|0}function bMZ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1488448:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bM_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1488448:0;e=0;return e|0}function bM$(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1075312:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bM0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1075312:0;e=0;return e|0}function bM1(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1075200:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bM2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1075200:0;e=0;return e|0}function bM3(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?915200:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bM4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?915200:0;e=0;return e|0}function bM5(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1488336:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bM6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1488336:0;e=0;return e|0}function bM7(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1488224:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bM8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1488224:0;e=0;return e|0}function bM9(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2597872:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bNa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2597872:0;e=0;return e|0}function bNb(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2597760:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bNc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2597760:0;e=0;return e|0}function bNd(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1488112:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bNe(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1488112:0;e=0;return e|0}function bNf(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1488e3:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bNg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1488e3:0;e=0;return e|0}function bNh(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1075088:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bNi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1075088:0;e=0;return e|0}function bNj(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?915088:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bNk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?915088:0;e=0;return e|0}function bNl(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?776464:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bNm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?776464:0;e=0;return e|0}function bNn(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1074976:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bNo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1074976:0;e=0;return e|0}function bNp(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1083040:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bNq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1083040:0;e=0;return e|0}function bNr(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1074864:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bNs(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1074864:0;e=0;return e|0}function bNt(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?914864:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bNu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?914864:0;e=0;return e|0}function bNv(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?776352:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bNw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?776352:0;e=0;return e|0}function bNx(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1487888:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bNy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1487888:0;e=0;return e|0}function bNz(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4553456:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bNA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4553456:0;e=0;return e|0}function bNB(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2597424:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bNC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2597424:0;e=0;return e|0}function bND(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1487664:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bNE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1487664:0;e=0;return e|0}function bNF(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1074752:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bNG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1074752:0;e=0;return e|0}function bNH(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1073968:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bNI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1073968:0;e=0;return e|0}function bNJ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?913632:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bNK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?913632:0;e=0;return e|0}function bNL(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?913744:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bNM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?913744:0;e=0;return e|0}function bNN(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1074528:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bNO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1074528:0;e=0;return e|0}function bNP(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1074416:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bNQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1074416:0;e=0;return e|0}function bNR(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?914640:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bNS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?914640:0;e=0;return e|0}function bNT(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?914528:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bNU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?914528:0;e=0;return e|0}function bNV(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?914416:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bNW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?914416:0;e=0;return e|0}function bNX(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?776240:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bNY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?776240:0;e=0;return e|0}function bNZ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?776128:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bN_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?776128:0;e=0;return e|0}function bN$(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1074304:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bN0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1074304:0;e=0;return e|0}function bN1(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?878800:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bN2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?878800:0;e=0;return e|0}function bN3(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?914304:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bN4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?914304:0;e=0;return e|0}function bN5(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?776016:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bN6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?776016:0;e=0;return e|0}function bN7(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?914080:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bN8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?914080:0;e=0;return e|0}function bN9(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?913968:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bOa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?913968:0;e=0;return e|0}function bOb(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?914192:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bOc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?914192:0;e=0;return e|0}function bOd(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?913856:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bOe(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?913856:0;e=0;return e|0}function bOf(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?775904:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bOg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?775904:0;e=0;return e|0}function bOh(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?913520:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bOi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?913520:0;e=0;return e|0}function bOj(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?775792:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bOk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?775792:0;e=0;return e|0}function bOl(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?924160:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bOm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?924160:0;e=0;return e|0}function bOn(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?913408:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bOo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?913408:0;e=0;return e|0}function bOp(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?899632:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bOq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?899632:0;e=0;return e|0}function bOr(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?770864:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bOs(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?770864:0;e=0;return e|0}function bOt(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?711144:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bOu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?711144:0;e=0;return e|0}function bOv(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4553344:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bOw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4553344:0;e=0;return e|0}function bOx(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2597312:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bOy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2597312:0;e=0;return e|0}function bOz(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2597200:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bOA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2597200:0;e=0;return e|0}function bOB(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1486992:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bOC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1486992:0;e=0;return e|0}function bOD(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?912960:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bOE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?912960:0;e=0;return e|0}function bOF(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?775568:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bOG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?775568:0;e=0;return e|0}function bOH(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?913184:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bOI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?913184:0;e=0;return e|0}function bOJ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?775680:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bOK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?775680:0;e=0;return e|0}function bOL(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?913072:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bOM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?913072:0;e=0;return e|0}function bON(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1486880:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bOO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1486880:0;e=0;return e|0}function bOP(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2597088:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bOQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2597088:0;e=0;return e|0}function bOR(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?912848:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bOS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?912848:0;e=0;return e|0}function bOT(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1073632:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bOU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1073632:0;e=0;return e|0}function bOV(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?912736:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bOW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?912736:0;e=0;return e|0}function bOX(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1073520:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bOY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1073520:0;e=0;return e|0}function bOZ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?912624:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bO_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?912624:0;e=0;return e|0}function bO$(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?908368:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bO0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?908368:0;e=0;return e|0}function bO1(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?775456:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bO2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?775456:0;e=0;return e|0}function bO3(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?899856:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bO4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?899856:0;e=0;return e|0}function bO5(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2584096:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bO6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2584096:0;e=0;return e|0}function bO7(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4553680:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bO8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4553680:0;e=0;return e|0}function bO9(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4553568:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bPa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4553568:0;e=0;return e|0}function bPb(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?912512:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bPc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?912512:0;e=0;return e|0}function bPd(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1073408:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bPe(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1073408:0;e=0;return e|0}function bPf(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2584320:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bPg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2584320:0;e=0;return e|0}function bPh(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2596976:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bPi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2596976:0;e=0;return e|0}function bPj(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1471536:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bPk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1471536:0;e=0;return e|0}function bPl(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1073296:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bPm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1073296:0;e=0;return e|0}function bPn(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1073184:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bPo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1073184:0;e=0;return e|0}function bPp(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?912400:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bPq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?912400:0;e=0;return e|0}function bPr(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?775344:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bPs(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?775344:0;e=0;return e|0}function bPt(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?912288:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bPu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?912288:0;e=0;return e|0}function bPv(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1486768:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bPw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1486768:0;e=0;return e|0}function bPx(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1073072:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bPy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1073072:0;e=0;return e|0}function bPz(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?855728:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bPA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?855728:0;e=0;return e|0}function bPB(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?911728:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bPC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?911728:0;e=0;return e|0}function bPD(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?911952:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bPE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?911952:0;e=0;return e|0}function bPF(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?911840:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bPG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?911840:0;e=0;return e|0}function bPH(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?912176:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bPI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?912176:0;e=0;return e|0}function bPJ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?912064:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bPK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?912064:0;e=0;return e|0}function bPL(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?911616:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bPM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?911616:0;e=0;return e|0}function bPN(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1486656:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bPO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1486656:0;e=0;return e|0}function bPP(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?911504:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bPQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?911504:0;e=0;return e|0}function bPR(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1072736:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bPS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1072736:0;e=0;return e|0}function bPT(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1486432:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bPU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1486432:0;e=0;return e|0}function bPV(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?911392:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bPW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?911392:0;e=0;return e|0}function bPX(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?775232:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bPY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?775232:0;e=0;return e|0}function bPZ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?775120:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bP_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?775120:0;e=0;return e|0}function bP$(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1072960:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bP0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1072960:0;e=0;return e|0}function bP1(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1486208:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bP2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1486208:0;e=0;return e|0}function bP3(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1485872:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bP4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1485872:0;e=0;return e|0}function bP5(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1485984:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bP6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1485984:0;e=0;return e|0}function bP7(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1079120:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bP8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1079120:0;e=0;return e|0}function bP9(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4553232:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bQa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4553232:0;e=0;return e|0}function bQb(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2596640:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bQc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2596640:0;e=0;return e|0}function bQd(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1485536:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bQe(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1485536:0;e=0;return e|0}function bQf(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?910944:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bQg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?910944:0;e=0;return e|0}function bQh(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1072624:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bQi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1072624:0;e=0;return e|0}function bQj(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?910832:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bQk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?910832:0;e=0;return e|0}function bQl(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?910720:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bQm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?910720:0;e=0;return e|0}function bQn(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?910608:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bQo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?910608:0;e=0;return e|0}function bQp(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?775008:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bQq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?775008:0;e=0;return e|0}function bQr(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?711592:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bQs(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?711592:0;e=0;return e|0}function bQt(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?923152:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bQu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?923152:0;e=0;return e|0}function bQv(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1485424:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bQw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1485424:0;e=0;return e|0}function bQx(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?774896:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bQy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?774896:0;e=0;return e|0}function bQz(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1485200:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bQA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1485200:0;e=0;return e|0}function bQB(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?910496:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bQC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?910496:0;e=0;return e|0}function bQD(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?774784:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bQE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?774784:0;e=0;return e|0}function bQF(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?779712:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bQG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?779712:0;e=0;return e|0}function bQH(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4553120:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bQI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4553120:0;e=0;return e|0}function bQJ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?910272:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bQK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?910272:0;e=0;return e|0}function bQL(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?774672:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bQM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?774672:0;e=0;return e|0}function bQN(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1072176:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bQO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1072176:0;e=0;return e|0}function bQP(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?910160:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bQQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?910160:0;e=0;return e|0}function bQR(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1485088:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bQS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1485088:0;e=0;return e|0}function bQT(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?910048:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bQU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?910048:0;e=0;return e|0}function bQV(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?909936:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bQW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?909936:0;e=0;return e|0}function bQX(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?909824:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bQY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?909824:0;e=0;return e|0}function bQZ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?909264:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bQ_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?909264:0;e=0;return e|0}function bQ$(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?909376:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bQ0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?909376:0;e=0;return e|0}function bQ1(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?909488:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bQ2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?909488:0;e=0;return e|0}function bQ3(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?909600:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bQ4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?909600:0;e=0;return e|0}function bQ5(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?909712:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bQ6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?909712:0;e=0;return e|0}function bQ7(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?909152:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bQ8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?909152:0;e=0;return e|0}function bQ9(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?909040:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bRa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?909040:0;e=0;return e|0}function bRb(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2596416:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bRc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2596416:0;e=0;return e|0}function bRd(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1078112:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bRe(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1078112:0;e=0;return e|0}function bRf(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1484976:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bRg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1484976:0;e=0;return e|0}function bRh(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1484864:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bRi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1484864:0;e=0;return e|0}function bRj(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2596304:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bRk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2596304:0;e=0;return e|0}function bRl(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1071952:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bRm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1071952:0;e=0;return e|0}function bRn(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4552896:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bRo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4552896:0;e=0;return e|0}function bRp(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2595968:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bRq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2595968:0;e=0;return e|0}function bRr(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2596080:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bRs(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2596080:0;e=0;return e|0}function bRt(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?884624:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bRu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?884624:0;e=0;return e|0}function bRv(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2595856:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bRw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2595856:0;e=0;return e|0}function bRx(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?889664:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bRy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?889664:0;e=0;return e|0}function bRz(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?908816:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bRA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?908816:0;e=0;return e|0}function bRB(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1488560:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bRC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1488560:0;e=0;return e|0}function bRD(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1484304:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bRE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1484304:0;e=0;return e|0}function bRF(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1484416:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bRG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1484416:0;e=0;return e|0}function bRH(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?879808:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bRI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?879808:0;e=0;return e|0}function bRJ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1483520:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bRK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1483520:0;e=0;return e|0}function bRL(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1484752:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bRM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1484752:0;e=0;return e|0}function bRN(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1484640:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bRO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1484640:0;e=0;return e|0}function bRP(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1484528:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bRQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1484528:0;e=0;return e|0}function bRR(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?908480:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bRS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?908480:0;e=0;return e|0}function bRT(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?908032:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bRU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?908032:0;e=0;return e|0}function bRV(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?908256:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bRW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?908256:0;e=0;return e|0}function bRX(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?908144:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bRY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?908144:0;e=0;return e|0}function bRZ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?886864:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bR_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?886864:0;e=0;return e|0}function bR$(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?907920:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bR0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?907920:0;e=0;return e|0}function bR1(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?907696:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bR2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?907696:0;e=0;return e|0}function bR3(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?907808:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bR4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?907808:0;e=0;return e|0}function bR5(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1484080:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bR6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1484080:0;e=0;return e|0}function bR7(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1483968:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bR8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1483968:0;e=0;return e|0}function bR9(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1071616:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bSa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1071616:0;e=0;return e|0}function bSb(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?907584:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bSc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?907584:0;e=0;return e|0}function bSd(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?903216:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bSe(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?903216:0;e=0;return e|0}function bSf(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?903104:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bSg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?903104:0;e=0;return e|0}function bSh(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?903328:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bSi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?903328:0;e=0;return e|0}function bSj(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1481952:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bSk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1481952:0;e=0;return e|0}function bSl(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1068368:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bSm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1068368:0;e=0;return e|0}function bSn(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1071504:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bSo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1071504:0;e=0;return e|0}function bSp(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?907472:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bSq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?907472:0;e=0;return e|0}function bSr(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?907360:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bSs(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?907360:0;e=0;return e|0}function bSt(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1483856:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bSu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1483856:0;e=0;return e|0}function bSv(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1484192:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bSw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1484192:0;e=0;return e|0}function bSx(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?908592:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bSy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?908592:0;e=0;return e|0}function bSz(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?908704:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bSA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?908704:0;e=0;return e|0}function bSB(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?907024:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bSC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?907024:0;e=0;return e|0}function bSD(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1483408:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bSE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1483408:0;e=0;return e|0}function bSF(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1071056:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bSG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1071056:0;e=0;return e|0}function bSH(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1071168:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bSI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1071168:0;e=0;return e|0}function bSJ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?907136:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bSK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?907136:0;e=0;return e|0}function bSL(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?907248:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bSM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?907248:0;e=0;return e|0}function bSN(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2595744:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bSO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2595744:0;e=0;return e|0}function bSP(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1483744:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bSQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1483744:0;e=0;return e|0}function bSR(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1483632:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bSS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1483632:0;e=0;return e|0}function bST(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1071280:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bSU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1071280:0;e=0;return e|0}function bSV(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1071392:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bSW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1071392:0;e=0;return e|0}function bSX(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?773888:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bSY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?773888:0;e=0;return e|0}function bSZ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?774e3:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bS_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?774e3:0;e=0;return e|0}function bS$(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?774112:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bS0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?774112:0;e=0;return e|0}function bS1(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?774224:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bS2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?774224:0;e=0;return e|0}function bS3(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?774336:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bS4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?774336:0;e=0;return e|0}function bS5(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?774448:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bS6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?774448:0;e=0;return e|0}function bS7(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?773552:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bS8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?773552:0;e=0;return e|0}function bS9(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?773664:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bTa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?773664:0;e=0;return e|0}function bTb(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?773776:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bTc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?773776:0;e=0;return e|0}function bTd(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1071728:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bTe(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1071728:0;e=0;return e|0}function bTf(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1483184:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bTg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1483184:0;e=0;return e|0}function bTh(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1070832:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bTi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1070832:0;e=0;return e|0}function bTj(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?906800:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bTk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?906800:0;e=0;return e|0}function bTl(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?773440:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bTm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?773440:0;e=0;return e|0}function bTn(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?906576:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bTo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?906576:0;e=0;return e|0}function bTp(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?906464:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bTq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?906464:0;e=0;return e|0}function bTr(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?887424:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bTs(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?887424:0;e=0;return e|0}function bTt(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1070496:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bTu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1070496:0;e=0;return e|0}function bTv(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4552672:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bTw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4552672:0;e=0;return e|0}function bTx(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2594848:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bTy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2594848:0;e=0;return e|0}function bTz(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2594960:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bTA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2594960:0;e=0;return e|0}function bTB(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2595072:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bTC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2595072:0;e=0;return e|0}function bTD(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1070384:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bTE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1070384:0;e=0;return e|0}function bTF(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?906240:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bTG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?906240:0;e=0;return e|0}function bTH(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?906128:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bTI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?906128:0;e=0;return e|0}function bTJ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?906016:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bTK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?906016:0;e=0;return e|0}function bTL(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?905904:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bTM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?905904:0;e=0;return e|0}function bTN(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4552784:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bTO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4552784:0;e=0;return e|0}function bTP(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2595520:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bTQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2595520:0;e=0;return e|0}function bTR(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1482848:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bTS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1482848:0;e=0;return e|0}function bTT(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1070048:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bTU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1070048:0;e=0;return e|0}function bTV(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?905680:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bTW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?905680:0;e=0;return e|0}function bTX(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?905120:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bTY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?905120:0;e=0;return e|0}function bTZ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1482624:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bT_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1482624:0;e=0;return e|0}function bT$(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?905456:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bT0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?905456:0;e=0;return e|0}function bT1(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?773216:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bT2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?773216:0;e=0;return e|0}function bT3(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?773104:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bT4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?773104:0;e=0;return e|0}function bT5(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?772992:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bT6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?772992:0;e=0;return e|0}function bT7(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?711480:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bT8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?711480:0;e=0;return e|0}function bT9(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?905232:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bUa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?905232:0;e=0;return e|0}function bUb(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?905344:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bUc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?905344:0;e=0;return e|0}function bUd(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?772880:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bUe(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?772880:0;e=0;return e|0}function bUf(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?772768:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bUg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?772768:0;e=0;return e|0}function bUh(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1069376:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bUi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1069376:0;e=0;return e|0}function bUj(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?905008:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bUk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?905008:0;e=0;return e|0}function bUl(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1486096:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bUm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1486096:0;e=0;return e|0}function bUn(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?904896:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bUo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?904896:0;e=0;return e|0}function bUp(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1074640:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bUq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1074640:0;e=0;return e|0}function bUr(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?904672:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bUs(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?904672:0;e=0;return e|0}function bUt(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?711368:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bUu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?711368:0;e=0;return e|0}function bUv(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?695920:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bUw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?695920:0;e=0;return e|0}function bUx(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?904784:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bUy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?904784:0;e=0;return e|0}function bUz(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?772656:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bUA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?772656:0;e=0;return e|0}function bUB(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?904560:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bUC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?904560:0;e=0;return e|0}function bUD(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?772544:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bUE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?772544:0;e=0;return e|0}function bUF(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?772432:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bUG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?772432:0;e=0;return e|0}function bUH(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?5786024:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bUI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?5786024:0;e=0;return e|0}function bUJ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4552560:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bUK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4552560:0;e=0;return e|0}function bUL(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?5785912:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bUM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?5785912:0;e=0;return e|0}function bUN(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4552448:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bUO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4552448:0;e=0;return e|0}function bUP(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1069264:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bUQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1069264:0;e=0;return e|0}function bUR(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1069152:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bUS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1069152:0;e=0;return e|0}function bUT(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1069040:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bUU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1069040:0;e=0;return e|0}function bUV(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1068928:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bUW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1068928:0;e=0;return e|0}function bUX(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1068816:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bUY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1068816:0;e=0;return e|0}function bUZ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?904112:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bU_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?904112:0;e=0;return e|0}function bU$(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4552336:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bU0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4552336:0;e=0;return e|0}function bU1(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4552224:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bU2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4552224:0;e=0;return e|0}function bU3(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1068704:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bU4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1068704:0;e=0;return e|0}function bU5(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1068592:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bU6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1068592:0;e=0;return e|0}function bU7(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?904e3:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bU8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?904e3:0;e=0;return e|0}function bU9(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?903888:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bVa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?903888:0;e=0;return e|0}function bVb(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?903776:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bVc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?903776:0;e=0;return e|0}function bVd(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1482176:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bVe(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1482176:0;e=0;return e|0}function bVf(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1068480:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bVg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1068480:0;e=0;return e|0}function bVh(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?903664:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bVi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?903664:0;e=0;return e|0}function bVj(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1481616:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bVk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1481616:0;e=0;return e|0}function bVl(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?902992:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bVm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?902992:0;e=0;return e|0}function bVn(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?902880:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bVo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?902880:0;e=0;return e|0}function bVp(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?902768:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bVq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?902768:0;e=0;return e|0}function bVr(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?902656:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bVs(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?902656:0;e=0;return e|0}function bVt(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?902544:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bVu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?902544:0;e=0;return e|0}function bVv(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?902432:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bVw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?902432:0;e=0;return e|0}function bVx(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?5785240:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bVy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?5785240:0;e=0;return e|0}function bVz(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1478480:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bVA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1478480:0;e=0;return e|0}function bVB(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1478592:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bVC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1478592:0;e=0;return e|0}function bVD(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1478704:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bVE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1478704:0;e=0;return e|0}function bVF(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1478816:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bVG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1478816:0;e=0;return e|0}function bVH(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1477808:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bVI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1477808:0;e=0;return e|0}function bVJ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1477920:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bVK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1477920:0;e=0;return e|0}function bVL(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1477696:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bVM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1477696:0;e=0;return e|0}function bVN(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1478032:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bVO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1478032:0;e=0;return e|0}function bVP(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1478144:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bVQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1478144:0;e=0;return e|0}function bVR(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1478256:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bVS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1478256:0;e=0;return e|0}function bVT(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1478368:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bVU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1478368:0;e=0;return e|0}function bVV(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1478928:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bVW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1478928:0;e=0;return e|0}function bVX(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?902320:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bVY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?902320:0;e=0;return e|0}function bVZ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1065456:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bV_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1065456:0;e=0;return e|0}function bV$(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?902096:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bV0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?902096:0;e=0;return e|0}function bV1(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1481728:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bV2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1481728:0;e=0;return e|0}function bV3(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1068144:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bV4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1068144:0;e=0;return e|0}function bV5(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1064336:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bV6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1064336:0;e=0;return e|0}function bV7(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1481504:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bV8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1481504:0;e=0;return e|0}function bV9(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?935920:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bWa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?935920:0;e=0;return e|0}function bWb(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1067808:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bWc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1067808:0;e=0;return e|0}function bWd(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2594512:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bWe(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2594512:0;e=0;return e|0}function bWf(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1481168:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bWg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1481168:0;e=0;return e|0}function bWh(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1481056:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bWi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1481056:0;e=0;return e|0}function bWj(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1480944:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bWk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1480944:0;e=0;return e|0}function bWl(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1067696:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bWm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1067696:0;e=0;return e|0}function bWn(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1067584:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bWo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1067584:0;e=0;return e|0}function bWp(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?901760:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bWq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?901760:0;e=0;return e|0}function bWr(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1065344:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bWs(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1065344:0;e=0;return e|0}function bWt(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2594400:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bWu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2594400:0;e=0;return e|0}function bWv(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?901648:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bWw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?901648:0;e=0;return e|0}function bWx(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?901424:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bWy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?901424:0;e=0;return e|0}function bWz(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?771760:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bWA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?771760:0;e=0;return e|0}function bWB(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?771648:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bWC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?771648:0;e=0;return e|0}function bWD(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?771536:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bWE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?771536:0;e=0;return e|0}function bWF(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?901312:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bWG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?901312:0;e=0;return e|0}function bWH(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?771424:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bWI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?771424:0;e=0;return e|0}function bWJ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?711256:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bWK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?711256:0;e=0;return e|0}function bWL(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?771312:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bWM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?771312:0;e=0;return e|0}function bWN(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1480832:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bWO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1480832:0;e=0;return e|0}function bWP(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?771200:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bWQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?771200:0;e=0;return e|0}function bWR(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1067360:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bWS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1067360:0;e=0;return e|0}function bWT(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1067248:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bWU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1067248:0;e=0;return e|0}function bWV(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1067136:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bWW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1067136:0;e=0;return e|0}function bWX(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1067024:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bWY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1067024:0;e=0;return e|0}function bWZ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?900976:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bW_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?900976:0;e=0;return e|0}function bW$(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?900864:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bW0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?900864:0;e=0;return e|0}function bW1(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?901088:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bW2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?901088:0;e=0;return e|0}function bW3(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1066576:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bW4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1066576:0;e=0;return e|0}function bW5(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1058288:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bW6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1058288:0;e=0;return e|0}function bW7(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?879248:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bW8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?879248:0;e=0;return e|0}function bW9(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?900304:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bXa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?900304:0;e=0;return e|0}function bXb(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?771088:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bXc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?771088:0;e=0;return e|0}function bXd(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?900080:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bXe(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?900080:0;e=0;return e|0}function bXf(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?770976:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bXg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?770976:0;e=0;return e|0}function bXh(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1480720:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bXi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1480720:0;e=0;return e|0}function bXj(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1066912:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bXk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1066912:0;e=0;return e|0}function bXl(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1066800:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bXm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1066800:0;e=0;return e|0}function bXn(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1066688:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bXo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1066688:0;e=0;return e|0}function bXp(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1463360:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bXq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1463360:0;e=0;return e|0}function bXr(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?900640:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bXs(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?900640:0;e=0;return e|0}function bXt(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?900416:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bXu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?900416:0;e=0;return e|0}function bXv(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1066352:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bXw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1066352:0;e=0;return e|0}function bXx(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1480608:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bXy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1480608:0;e=0;return e|0}function bXz(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2594288:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bXA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2594288:0;e=0;return e|0}function bXB(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?899968:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bXC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?899968:0;e=0;return e|0}function bXD(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2593616:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bXE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2593616:0;e=0;return e|0}function bXF(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1477472:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bXG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1477472:0;e=0;return e|0}function bXH(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1480048:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bXI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1480048:0;e=0;return e|0}function bXJ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1065904:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bXK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1065904:0;e=0;return e|0}function bXL(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1065792:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bXM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1065792:0;e=0;return e|0}function bXN(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?898400:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bXO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?898400:0;e=0;return e|0}function bXP(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?899744:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bXQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?899744:0;e=0;return e|0}function bXR(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?770640:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bXS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?770640:0;e=0;return e|0}function bXT(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?770528:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bXU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?770528:0;e=0;return e|0}function bXV(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?770416:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bXW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?770416:0;e=0;return e|0}function bXX(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?770752:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bXY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?770752:0;e=0;return e|0}function bXZ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?770304:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bX_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?770304:0;e=0;return e|0}function bX$(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1066240:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bX0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1066240:0;e=0;return e|0}function bX1(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1480384:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bX2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1480384:0;e=0;return e|0}function bX3(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1066128:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bX4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1066128:0;e=0;return e|0}function bX5(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?935360:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bX6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?935360:0;e=0;return e|0}function bX7(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2594176:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bX8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2594176:0;e=0;return e|0}function bX9(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1480272:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bYa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1480272:0;e=0;return e|0}function bYb(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1480160:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bYc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1480160:0;e=0;return e|0}function bYd(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?899184:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bYe(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?899184:0;e=0;return e|0}function bYf(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?898960:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bYg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?898960:0;e=0;return e|0}function bYh(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4551776:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bYi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4551776:0;e=0;return e|0}function bYj(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2593952:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bYk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2593952:0;e=0;return e|0}function bYl(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1479488:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bYm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1479488:0;e=0;return e|0}function bYn(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1479600:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bYo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1479600:0;e=0;return e|0}function bYp(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1479712:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bYq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1479712:0;e=0;return e|0}function bYr(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1479824:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bYs(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1479824:0;e=0;return e|0}function bYt(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1479264:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bYu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1479264:0;e=0;return e|0}function bYv(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1479376:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bYw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1479376:0;e=0;return e|0}function bYx(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1479152:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bYy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1479152:0;e=0;return e|0}function bYz(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1065680:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bYA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1065680:0;e=0;return e|0}function bYB(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?897952:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bYC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?897952:0;e=0;return e|0}function bYD(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?898064:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bYE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?898064:0;e=0;return e|0}function bYF(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?898176:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bYG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?898176:0;e=0;return e|0}function bYH(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?898288:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bYI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?898288:0;e=0;return e|0}function bYJ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1078e3:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bYK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1078e3:0;e=0;return e|0}function bYL(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?921360:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bYM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?921360:0;e=0;return e|0}function bYN(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1480496:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bYO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1480496:0;e=0;return e|0}function bYP(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?898848:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bYQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?898848:0;e=0;return e|0}function bYR(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?898736:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bYS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?898736:0;e=0;return e|0}function bYT(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?5785464:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bYU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?5785464:0;e=0;return e|0}function bYV(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4551888:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bYW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4551888:0;e=0;return e|0}function bYX(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2594064:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bYY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2594064:0;e=0;return e|0}function bYZ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?897840:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bY_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?897840:0;e=0;return e|0}function bY$(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?770080:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bY0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?770080:0;e=0;return e|0}function bY1(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1065232:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bY2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1065232:0;e=0;return e|0}function bY3(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?6524232:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bY4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?6524232:0;e=0;return e|0}function bY5(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?5785352:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bY6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?5785352:0;e=0;return e|0}function bY7(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?5785688:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bY8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?5785688:0;e=0;return e|0}function bY9(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?5785576:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bZa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?5785576:0;e=0;return e|0}function bZb(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4552e3:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bZc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4552e3:0;e=0;return e|0}function bZd(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1479040:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bZe(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1479040:0;e=0;return e|0}function bZf(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1065568:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bZg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1065568:0;e=0;return e|0}function bZh(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?897616:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bZi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?897616:0;e=0;return e|0}function bZj(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?695808:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bZk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?695808:0;e=0;return e|0}function bZl(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?897504:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bZm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?897504:0;e=0;return e|0}function bZn(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?769968:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bZo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?769968:0;e=0;return e|0}function bZp(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?711032:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bZq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?711032:0;e=0;return e|0}function bZr(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2593840:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bZs(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2593840:0;e=0;return e|0}function bZt(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1477584:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bZu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1477584:0;e=0;return e|0}function bZv(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?898624:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bZw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?898624:0;e=0;return e|0}function bZx(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?898512:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bZy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?898512:0;e=0;return e|0}function bZz(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1065120:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bZA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1065120:0;e=0;return e|0}function bZB(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?897392:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bZC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?897392:0;e=0;return e|0}function bZD(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1069936:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bZE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1069936:0;e=0;return e|0}function bZF(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2591936:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bZG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2591936:0;e=0;return e|0}function bZH(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1065008:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bZI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1065008:0;e=0;return e|0}function bZJ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1067920:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bZK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1067920:0;e=0;return e|0}function bZL(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2593504:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bZM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2593504:0;e=0;return e|0}function bZN(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?896832:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bZO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?896832:0;e=0;return e|0}function bZP(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?917440:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bZQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?917440:0;e=0;return e|0}function bZR(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?896720:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bZS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?896720:0;e=0;return e|0}function bZT(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1477136:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bZU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1477136:0;e=0;return e|0}function bZV(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?896272:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bZW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?896272:0;e=0;return e|0}function bZX(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?896384:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bZY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?896384:0;e=0;return e|0}function bZZ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?896496:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bZ_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?896496:0;e=0;return e|0}function bZ$(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?896608:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bZ0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?896608:0;e=0;return e|0}function bZ1(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?693232:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bZ2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?693232:0;e=0;return e|0}function bZ3(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?693344:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bZ4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?693344:0;e=0;return e|0}function bZ5(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?693456:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bZ6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?693456:0;e=0;return e|0}function bZ7(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?693568:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function bZ8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?693568:0;e=0;return e|0}function bZ9(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?693680:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b_a(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?693680:0;e=0;return e|0}function b_b(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?693792:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b_c(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?693792:0;e=0;return e|0}function b_d(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?693904:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b_e(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?693904:0;e=0;return e|0}function b_f(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?694016:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b_g(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?694016:0;e=0;return e|0}function b_h(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?695472:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b_i(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?695472:0;e=0;return e|0}function b_j(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?695584:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b_k(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?695584:0;e=0;return e|0}function b_l(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?695696:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b_m(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?695696:0;e=0;return e|0}function b_n(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?694128:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b_o(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?694128:0;e=0;return e|0}function b_p(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?694240:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b_q(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?694240:0;e=0;return e|0}function b_r(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?694352:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b_s(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?694352:0;e=0;return e|0}function b_t(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?694464:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b_u(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?694464:0;e=0;return e|0}function b_v(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?694576:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b_w(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?694576:0;e=0;return e|0}function b_x(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?694688:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b_y(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?694688:0;e=0;return e|0}function b_z(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?694800:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b_A(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?694800:0;e=0;return e|0}function b_B(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?694912:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b_C(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?694912:0;e=0;return e|0}function b_D(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?695024:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b_E(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?695024:0;e=0;return e|0}function b_F(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?695136:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b_G(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?695136:0;e=0;return e|0}function b_H(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?695248:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b_I(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?695248:0;e=0;return e|0}function b_J(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?695360:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b_K(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?695360:0;e=0;return e|0}function b_L(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?693008:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b_M(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?693008:0;e=0;return e|0}function b_N(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?693120:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b_O(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?693120:0;e=0;return e|0}function b_P(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?896160:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b_Q(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?896160:0;e=0;return e|0}function b_R(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1064784:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b_S(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1064784:0;e=0;return e|0}function b_T(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?896048:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b_U(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?896048:0;e=0;return e|0}function b_V(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1477024:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b_W(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1477024:0;e=0;return e|0}function b_X(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1064672:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b_Y(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1064672:0;e=0;return e|0}function b_Z(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1064560:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b__(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1064560:0;e=0;return e|0}function b_$(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>3){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[895700+(b*112|0)>>2];c[a+104>>2]=c[895704+(b*112|0)>>2];c[a+108>>2]=c[895708+(b*112|0)>>2];d=0;return d|0}function b_0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<4&(d|0)==0)){e=1;return e|0}c[a>>2]=895600+(b*112|0);e=0;return e|0}function b_1(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?895488:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b_2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?895488:0;e=0;return e|0}function b_3(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?769856:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b_4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?769856:0;e=0;return e|0}function b_5(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?895376:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b_6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?895376:0;e=0;return e|0}function b_7(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?769744:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b_8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?769744:0;e=0;return e|0}function b_9(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?895264:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b$a(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?895264:0;e=0;return e|0}function b$b(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?895152:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b$c(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?895152:0;e=0;return e|0}function b$d(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?895040:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b$e(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?895040:0;e=0;return e|0}function b$f(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?784752:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b$g(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?784752:0;e=0;return e|0}function b$h(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?713832:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b$i(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?713832:0;e=0;return e|0}function b$j(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?784640:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b$k(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?784640:0;e=0;return e|0}function b$l(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?894928:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b$m(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?894928:0;e=0;return e|0}function b$n(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1064448:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b$o(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1064448:0;e=0;return e|0}function b$p(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?894816:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b$q(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?894816:0;e=0;return e|0}function b$r(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?894704:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b$s(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?894704:0;e=0;return e|0}function b$t(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?894592:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b$u(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?894592:0;e=0;return e|0}function b$v(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?894480:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b$w(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?894480:0;e=0;return e|0}function b$x(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?897168:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b$y(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?897168:0;e=0;return e|0}function b$z(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?897280:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b$A(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?897280:0;e=0;return e|0}function b$B(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?896944:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b$C(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?896944:0;e=0;return e|0}function b$D(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2593056:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b$E(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2593056:0;e=0;return e|0}function b$F(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?892016:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b$G(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?892016:0;e=0;return e|0}function b$H(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?892128:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b$I(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?892128:0;e=0;return e|0}function b$J(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?892240:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b$K(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?892240:0;e=0;return e|0}function b$L(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?892352:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b$M(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?892352:0;e=0;return e|0}function b$N(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?892464:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b$O(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?892464:0;e=0;return e|0}function b$P(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?892576:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b$Q(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?892576:0;e=0;return e|0}function b$R(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?892688:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b$S(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?892688:0;e=0;return e|0}function b$T(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?892800:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b$U(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?892800:0;e=0;return e|0}function b$V(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?892912:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b$W(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?892912:0;e=0;return e|0}function b$X(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?893024:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b$Y(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?893024:0;e=0;return e|0}function b$Z(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?893136:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b$_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?893136:0;e=0;return e|0}function b$$(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?893248:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b$0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?893248:0;e=0;return e|0}function b$1(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?893360:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b$2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?893360:0;e=0;return e|0}function b$3(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?893472:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b$4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?893472:0;e=0;return e|0}function b$5(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?893584:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b$6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?893584:0;e=0;return e|0}function b$7(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?893696:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b$8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?893696:0;e=0;return e|0}function b$9(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?893808:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b0a(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?893808:0;e=0;return e|0}function b0b(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?893920:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b0c(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?893920:0;e=0;return e|0}function b0d(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?894032:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b0e(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?894032:0;e=0;return e|0}function b0f(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?894144:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b0g(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?894144:0;e=0;return e|0}function b0h(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?894256:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b0i(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?894256:0;e=0;return e|0}function b0j(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2592944:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b0k(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2592944:0;e=0;return e|0}function b0l(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2593168:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b0m(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2593168:0;e=0;return e|0}function b0n(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1476688:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b0o(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1476688:0;e=0;return e|0}function b0p(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2592832:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b0q(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2592832:0;e=0;return e|0}function b0r(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1064224:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b0s(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1064224:0;e=0;return e|0}function b0t(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?891904:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b0u(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?891904:0;e=0;return e|0}function b0v(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?891792:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b0w(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?891792:0;e=0;return e|0}function b0x(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2592608:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b0y(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2592608:0;e=0;return e|0}function b0z(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2592496:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b0A(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2592496:0;e=0;return e|0}function b0B(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2592384:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b0C(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2592384:0;e=0;return e|0}function b0D(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2592272:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b0E(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2592272:0;e=0;return e|0}function b0F(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2592160:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b0G(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2592160:0;e=0;return e|0}function b0H(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?891456:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b0I(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?891456:0;e=0;return e|0}function b0J(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?891568:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b0K(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?891568:0;e=0;return e|0}function b0L(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?891680:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b0M(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?891680:0;e=0;return e|0}function b0N(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?890448:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b0O(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?890448:0;e=0;return e|0}function b0P(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?890560:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b0Q(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?890560:0;e=0;return e|0}function b0R(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?890672:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b0S(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?890672:0;e=0;return e|0}function b0T(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?890784:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b0U(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?890784:0;e=0;return e|0}function b0V(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?890896:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b0W(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?890896:0;e=0;return e|0}function b0X(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?891008:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b0Y(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?891008:0;e=0;return e|0}function b0Z(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?891120:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b0_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?891120:0;e=0;return e|0}function b0$(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?891232:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b00(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?891232:0;e=0;return e|0}function b01(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?891344:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b02(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?891344:0;e=0;return e|0}function b03(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?890224:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b04(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?890224:0;e=0;return e|0}function b05(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?890336:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b06(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?890336:0;e=0;return e|0}function b07(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?89e4:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b08(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?89e4:0;e=0;return e|0}function b09(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?890112:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b1a(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?890112:0;e=0;return e|0}function b1b(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1064e3:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b1c(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1064e3:0;e=0;return e|0}function b1d(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?889776:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b1e(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?889776:0;e=0;return e|0}function b1f(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1068032:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b1g(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1068032:0;e=0;return e|0}function b1h(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?901984:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b1i(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?901984:0;e=0;return e|0}function b1j(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2593280:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b1k(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2593280:0;e=0;return e|0}function b1l(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1476912:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b1m(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1476912:0;e=0;return e|0}function b1n(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1476800:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b1o(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1476800:0;e=0;return e|0}function b1p(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1476576:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b1q(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1476576:0;e=0;return e|0}function b1r(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1476464:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b1s(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1476464:0;e=0;return e|0}function b1t(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1064112:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b1u(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1064112:0;e=0;return e|0}function b1v(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?889328:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b1w(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?889328:0;e=0;return e|0}function b1x(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?889552:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b1y(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?889552:0;e=0;return e|0}function b1z(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1063776:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b1A(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1063776:0;e=0;return e|0}function b1B(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1063888:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b1C(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1063888:0;e=0;return e|0}function b1D(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?889440:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b1E(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?889440:0;e=0;return e|0}function b1F(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2592048:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b1G(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2592048:0;e=0;return e|0}function b1H(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?889216:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b1I(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?889216:0;e=0;return e|0}function b1J(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?769632:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b1K(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?769632:0;e=0;return e|0}function b1L(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?769520:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b1M(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?769520:0;e=0;return e|0}function b1N(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?710920:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b1O(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?710920:0;e=0;return e|0}function b1P(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?889104:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b1Q(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?889104:0;e=0;return e|0}function b1R(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1476352:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b1S(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1476352:0;e=0;return e|0}function b1T(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4551328:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b1U(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4551328:0;e=0;return e|0}function b1V(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1476240:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b1W(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1476240:0;e=0;return e|0}function b1X(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1063664:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b1Y(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1063664:0;e=0;return e|0}function b1Z(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1062992:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b1_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1062992:0;e=0;return e|0}function b1$(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1063104:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b10(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1063104:0;e=0;return e|0}function b11(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1063440:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b12(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1063440:0;e=0;return e|0}function b13(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1063552:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b14(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1063552:0;e=0;return e|0}function b15(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1063216:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b16(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1063216:0;e=0;return e|0}function b17(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1063328:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b18(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1063328:0;e=0;return e|0}function b19(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?888880:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b2a(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?888880:0;e=0;return e|0}function b2b(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?918224:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b2c(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?918224:0;e=0;return e|0}function b2d(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?888656:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b2e(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?888656:0;e=0;return e|0}function b2f(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?888544:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b2g(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?888544:0;e=0;return e|0}function b2h(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?769296:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b2i(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?769296:0;e=0;return e|0}function b2j(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?888432:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b2k(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?888432:0;e=0;return e|0}function b2l(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?769184:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b2m(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?769184:0;e=0;return e|0}function b2n(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1476128:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b2o(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1476128:0;e=0;return e|0}function b2p(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1062768:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b2q(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1062768:0;e=0;return e|0}function b2r(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?888320:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b2s(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?888320:0;e=0;return e|0}function b2t(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?769072:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b2u(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?769072:0;e=0;return e|0}function b2v(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?768960:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b2w(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?768960:0;e=0;return e|0}function b2x(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?710808:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b2y(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?710808:0;e=0;return e|0}function b2z(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1483296:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b2A(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1483296:0;e=0;return e|0}function b2B(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?888768:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b2C(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?888768:0;e=0;return e|0}function b2D(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?769408:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b2E(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?769408:0;e=0;return e|0}function b2F(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?888208:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b2G(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?888208:0;e=0;return e|0}function b2H(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1062656:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b2I(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1062656:0;e=0;return e|0}function b2J(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?887984:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b2K(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?887984:0;e=0;return e|0}function b2L(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?887872:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b2M(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?887872:0;e=0;return e|0}function b2N(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?888096:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b2O(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?888096:0;e=0;return e|0}function b2P(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?5784792:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b2Q(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?5784792:0;e=0;return e|0}function b2R(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?862224:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b2S(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?862224:0;e=0;return e|0}function b2T(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1476016:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b2U(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1476016:0;e=0;return e|0}function b2V(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?768848:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b2W(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?768848:0;e=0;return e|0}function b2X(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?887760:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b2Y(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?887760:0;e=0;return e|0}function b2Z(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?768736:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b2_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?768736:0;e=0;return e|0}function b2$(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?710696:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b20(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?710696:0;e=0;return e|0}function b21(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1062432:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b22(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1062432:0;e=0;return e|0}function b23(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?887536:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b24(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?887536:0;e=0;return e|0}function b25(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?768624:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b26(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?768624:0;e=0;return e|0}function b27(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1475904:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b28(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1475904:0;e=0;return e|0}function b29(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1475568:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b3a(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1475568:0;e=0;return e|0}function b3b(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1062320:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b3c(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1062320:0;e=0;return e|0}function b3d(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?897056:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b3e(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?897056:0;e=0;return e|0}function b3f(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2591600:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b3g(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2591600:0;e=0;return e|0}function b3h(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4551104:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b3i(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4551104:0;e=0;return e|0}function b3j(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1475232:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b3k(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1475232:0;e=0;return e|0}function b3l(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?878240:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b3m(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?878240:0;e=0;return e|0}function b3n(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?878128:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b3o(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?878128:0;e=0;return e|0}function b3p(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1062208:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b3q(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1062208:0;e=0;return e|0}function b3r(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2591264:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b3s(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2591264:0;e=0;return e|0}function b3t(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?5784904:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b3u(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?5784904:0;e=0;return e|0}function b3v(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4550768:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b3w(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4550768:0;e=0;return e|0}function b3x(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4550992:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b3y(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4550992:0;e=0;return e|0}function b3z(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2591376:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b3A(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2591376:0;e=0;return e|0}function b3B(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4550880:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b3C(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4550880:0;e=0;return e|0}function b3D(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1061200:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b3E(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1061200:0;e=0;return e|0}function b3F(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?884400:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b3G(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?884400:0;e=0;return e|0}function b3H(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1061088:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b3I(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1061088:0;e=0;return e|0}function b3J(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2590816:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b3K(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2590816:0;e=0;return e|0}function b3L(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2590704:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b3M(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2590704:0;e=0;return e|0}function b3N(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2590592:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b3O(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2590592:0;e=0;return e|0}function b3P(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2590480:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b3Q(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2590480:0;e=0;return e|0}function b3R(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2590368:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b3S(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2590368:0;e=0;return e|0}function b3T(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2590256:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b3U(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2590256:0;e=0;return e|0}function b3V(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2590144:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b3W(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2590144:0;e=0;return e|0}function b3X(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2590032:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b3Y(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2590032:0;e=0;return e|0}function b3Z(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1474672:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b3_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1474672:0;e=0;return e|0}function b3$(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?884288:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b30(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?884288:0;e=0;return e|0}function b31(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1060976:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b32(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1060976:0;e=0;return e|0}function b33(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1060752:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b34(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1060752:0;e=0;return e|0}function b35(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1474560:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b36(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1474560:0;e=0;return e|0}function b37(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1060864:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b38(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1060864:0;e=0;return e|0}function b39(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?883952:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b4a(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?883952:0;e=0;return e|0}function b4b(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?883840:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b4c(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?883840:0;e=0;return e|0}function b4d(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?883728:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b4e(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?883728:0;e=0;return e|0}function b4f(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?884176:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b4g(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?884176:0;e=0;return e|0}function b4h(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?884064:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b4i(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?884064:0;e=0;return e|0}function b4j(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1062096:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b4k(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1062096:0;e=0;return e|0}function b4l(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?887200:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b4m(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?887200:0;e=0;return e|0}function b4n(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1061984:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b4o(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1061984:0;e=0;return e|0}function b4p(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?887088:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b4q(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?887088:0;e=0;return e|0}function b4r(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?886976:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b4s(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?886976:0;e=0;return e|0}function b4t(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2591152:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b4u(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2591152:0;e=0;return e|0}function b4v(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2591040:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b4w(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2591040:0;e=0;return e|0}function b4x(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1475456:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b4y(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1475456:0;e=0;return e|0}function b4z(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?886752:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b4A(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?886752:0;e=0;return e|0}function b4B(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?768512:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b4C(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?768512:0;e=0;return e|0}function b4D(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1061872:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b4E(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1061872:0;e=0;return e|0}function b4F(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?886640:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b4G(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?886640:0;e=0;return e|0}function b4H(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?886416:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b4I(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?886416:0;e=0;return e|0}function b4J(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?768400:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b4K(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?768400:0;e=0;return e|0}function b4L(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1061760:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b4M(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1061760:0;e=0;return e|0}function b4N(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?886528:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b4O(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?886528:0;e=0;return e|0}function b4P(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?886192:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b4Q(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?886192:0;e=0;return e|0}function b4R(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?768288:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b4S(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?768288:0;e=0;return e|0}function b4T(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1061424:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b4U(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1061424:0;e=0;return e|0}function b4V(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?885968:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b4W(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?885968:0;e=0;return e|0}function b4X(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?886080:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b4Y(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?886080:0;e=0;return e|0}function b4Z(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1475344:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b4_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1475344:0;e=0;return e|0}function b4$(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?885744:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b40(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?885744:0;e=0;return e|0}function b41(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?768176:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b42(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?768176:0;e=0;return e|0}function b43(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?768064:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b44(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?768064:0;e=0;return e|0}function b45(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1475680:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b46(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1475680:0;e=0;return e|0}function b47(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1061648:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b48(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1061648:0;e=0;return e|0}function b49(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?886304:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b5a(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?886304:0;e=0;return e|0}function b5b(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?885520:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b5c(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?885520:0;e=0;return e|0}function b5d(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?854944:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b5e(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?854944:0;e=0;return e|0}function b5f(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?885072:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b5g(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?885072:0;e=0;return e|0}function b5h(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?884960:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b5i(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?884960:0;e=0;return e|0}function b5j(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?884848:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b5k(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?884848:0;e=0;return e|0}function b5l(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1475120:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b5m(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1475120:0;e=0;return e|0}function b5n(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?884736:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b5o(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?884736:0;e=0;return e|0}function b5p(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1061312:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b5q(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1061312:0;e=0;return e|0}function b5r(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?885296:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b5s(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?885296:0;e=0;return e|0}function b5t(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?767952:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b5u(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?767952:0;e=0;return e|0}function b5v(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?885184:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b5w(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?885184:0;e=0;return e|0}function b5x(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?885408:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b5y(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?885408:0;e=0;return e|0}function b5z(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2590928:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b5A(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2590928:0;e=0;return e|0}function b5B(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?884512:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b5C(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?884512:0;e=0;return e|0}function b5D(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1475008:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b5E(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1475008:0;e=0;return e|0}function b5F(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1493488:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b5G(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1493488:0;e=0;return e|0}function b5H(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1080352:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b5I(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1080352:0;e=0;return e|0}function b5J(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?883616:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b5K(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?883616:0;e=0;return e|0}function b5L(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1474336:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b5M(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1474336:0;e=0;return e|0}function b5N(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1060528:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b5O(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1060528:0;e=0;return e|0}function b5P(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1060416:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b5Q(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1060416:0;e=0;return e|0}function b5R(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?883504:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b5S(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?883504:0;e=0;return e|0}function b5T(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?883392:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b5U(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?883392:0;e=0;return e|0}function b5V(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?767840:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b5W(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?767840:0;e=0;return e|0}function b5X(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1474224:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b5Y(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1474224:0;e=0;return e|0}function b5Z(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?767728:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b5_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?767728:0;e=0;return e|0}function b5$(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?883168:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b50(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?883168:0;e=0;return e|0}function b51(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?883280:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b52(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?883280:0;e=0;return e|0}function b53(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?767616:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b54(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?767616:0;e=0;return e|0}function b55(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2596528:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b56(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2596528:0;e=0;return e|0}function b57(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2586448:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b58(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2586448:0;e=0;return e|0}function b59(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1060304:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b6a(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1060304:0;e=0;return e|0}function b6b(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?710584:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b6c(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?710584:0;e=0;return e|0}function b6d(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?883056:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b6e(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?883056:0;e=0;return e|0}function b6f(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?882944:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b6g(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?882944:0;e=0;return e|0}function b6h(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?882832:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b6i(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?882832:0;e=0;return e|0}function b6j(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?767504:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b6k(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?767504:0;e=0;return e|0}function b6l(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?882608:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b6m(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?882608:0;e=0;return e|0}function b6n(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?900192:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b6o(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?900192:0;e=0;return e|0}function b6p(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1474112:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b6q(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1474112:0;e=0;return e|0}function b6r(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1059408:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b6s(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1059408:0;e=0;return e|0}function b6t(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1059296:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b6u(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1059296:0;e=0;return e|0}function b6v(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1473552:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b6w(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1473552:0;e=0;return e|0}function b6x(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1473440:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b6y(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1473440:0;e=0;return e|0}function b6z(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1059520:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b6A(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1059520:0;e=0;return e|0}function b6B(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1059632:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b6C(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1059632:0;e=0;return e|0}function b6D(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?882496:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b6E(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?882496:0;e=0;return e|0}function b6F(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1474e3:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b6G(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1474e3:0;e=0;return e|0}function b6H(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1060192:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b6I(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1060192:0;e=0;return e|0}function b6J(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1473888:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b6K(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1473888:0;e=0;return e|0}function b6L(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?881712:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b6M(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?881712:0;e=0;return e|0}function b6N(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1473776:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b6O(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1473776:0;e=0;return e|0}function b6P(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1060080:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b6Q(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1060080:0;e=0;return e|0}function b6R(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1059968:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b6S(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1059968:0;e=0;return e|0}function b6T(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?882048:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b6U(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?882048:0;e=0;return e|0}function b6V(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1059856:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b6W(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1059856:0;e=0;return e|0}function b6X(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?881936:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b6Y(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?881936:0;e=0;return e|0}function b6Z(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1076208:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b6_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1076208:0;e=0;return e|0}function b6$(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?917776:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b60(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?917776:0;e=0;return e|0}function b61(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1473664:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b62(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1473664:0;e=0;return e|0}function b63(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1059744:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b64(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1059744:0;e=0;return e|0}function b65(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?881824:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b66(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?881824:0;e=0;return e|0}function b67(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1059184:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b68(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1059184:0;e=0;return e|0}function b69(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1059072:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b7a(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1059072:0;e=0;return e|0}function b7b(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?881488:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b7c(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?881488:0;e=0;return e|0}function b7d(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?767056:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b7e(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?767056:0;e=0;return e|0}function b7f(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?881376:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b7g(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?881376:0;e=0;return e|0}function b7h(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4550544:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b7i(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4550544:0;e=0;return e|0}function b7j(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1058960:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b7k(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1058960:0;e=0;return e|0}function b7l(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?881264:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b7m(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?881264:0;e=0;return e|0}function b7n(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?881152:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b7o(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?881152:0;e=0;return e|0}function b7p(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1053024:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b7q(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1053024:0;e=0;return e|0}function b7r(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4550432:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b7s(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4550432:0;e=0;return e|0}function b7t(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4550096:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b7u(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4550096:0;e=0;return e|0}function b7v(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1471984:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b7w(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1471984:0;e=0;return e|0}function b7x(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1472096:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b7y(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1472096:0;e=0;return e|0}function b7z(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1472208:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b7A(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1472208:0;e=0;return e|0}function b7B(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1472320:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b7C(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1472320:0;e=0;return e|0}function b7D(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1472432:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b7E(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1472432:0;e=0;return e|0}function b7F(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1472544:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b7G(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1472544:0;e=0;return e|0}function b7H(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1471872:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b7I(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1471872:0;e=0;return e|0}function b7J(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1473216:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b7K(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1473216:0;e=0;return e|0}function b7L(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?880928:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b7M(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?880928:0;e=0;return e|0}function b7N(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4550320:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b7O(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4550320:0;e=0;return e|0}function b7P(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1473104:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b7Q(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1473104:0;e=0;return e|0}function b7R(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1491248:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b7S(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1491248:0;e=0;return e|0}function b7T(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1472992:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b7U(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1472992:0;e=0;return e|0}function b7V(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1058848:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b7W(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1058848:0;e=0;return e|0}function b7X(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1058736:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b7Y(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1058736:0;e=0;return e|0}function b7Z(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?880480:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b7_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?880480:0;e=0;return e|0}function b7$(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?880592:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b70(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?880592:0;e=0;return e|0}function b71(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?880256:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b72(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?880256:0;e=0;return e|0}function b73(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?880368:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b74(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?880368:0;e=0;return e|0}function b75(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?879920:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b76(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?879920:0;e=0;return e|0}function b77(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1472768:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b78(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1472768:0;e=0;return e|0}function b79(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1058064:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b8a(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1058064:0;e=0;return e|0}function b8b(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1057952:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b8c(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1057952:0;e=0;return e|0}function b8d(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1472656:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b8e(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1472656:0;e=0;return e|0}function b8f(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1057840:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b8g(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1057840:0;e=0;return e|0}function b8h(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?880032:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b8i(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?880032:0;e=0;return e|0}function b8j(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?766832:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b8k(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?766832:0;e=0;return e|0}function b8l(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?879696:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b8m(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?879696:0;e=0;return e|0}function b8n(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?879472:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b8o(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?879472:0;e=0;return e|0}function b8p(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?766720:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b8q(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?766720:0;e=0;return e|0}function b8r(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?766608:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b8s(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?766608:0;e=0;return e|0}function b8t(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?710472:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b8u(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?710472:0;e=0;return e|0}function b8v(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?766496:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b8w(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?766496:0;e=0;return e|0}function b8x(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?879584:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b8y(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?879584:0;e=0;return e|0}function b8z(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?879360:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b8A(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?879360:0;e=0;return e|0}function b8B(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?880144:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b8C(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?880144:0;e=0;return e|0}function b8D(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?766944:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b8E(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?766944:0;e=0;return e|0}function b8F(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1472880:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b8G(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1472880:0;e=0;return e|0}function b8H(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1058512:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b8I(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1058512:0;e=0;return e|0}function b8J(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1058400:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b8K(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1058400:0;e=0;return e|0}function b8L(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2593728:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b8M(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2593728:0;e=0;return e|0}function b8N(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1471760:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b8O(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1471760:0;e=0;return e|0}function b8P(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1057728:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b8Q(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1057728:0;e=0;return e|0}function b8R(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1057616:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b8S(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1057616:0;e=0;return e|0}function b8T(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1471648:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b8U(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1471648:0;e=0;return e|0}function b8V(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4550208:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b8W(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4550208:0;e=0;return e|0}function b8X(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1458656:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b8Y(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1458656:0;e=0;return e|0}function b8Z(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?879024:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b8_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?879024:0;e=0;return e|0}function b8$(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?878016:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b80(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?878016:0;e=0;return e|0}function b81(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?878912:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b82(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?878912:0;e=0;return e|0}function b83(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?877904:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b84(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?877904:0;e=0;return e|0}function b85(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1057504:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b86(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1057504:0;e=0;return e|0}function b87(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1471200:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b88(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1471200:0;e=0;return e|0}function b89(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1079344:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b9a(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1079344:0;e=0;return e|0}function b9b(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?878576:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b9c(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?878576:0;e=0;return e|0}function b9d(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1466384:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b9e(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1466384:0;e=0;return e|0}function b9f(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1053920:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b9g(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1053920:0;e=0;return e|0}function b9h(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?878352:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b9i(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?878352:0;e=0;return e|0}function b9j(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1471088:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b9k(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1471088:0;e=0;return e|0}function b9l(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1057280:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b9m(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1057280:0;e=0;return e|0}function b9n(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1057168:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b9o(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1057168:0;e=0;return e|0}function b9p(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1470976:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b9q(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1470976:0;e=0;return e|0}function b9r(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1057056:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b9s(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1057056:0;e=0;return e|0}function b9t(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1470864:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b9u(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1470864:0;e=0;return e|0}function b9v(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?877792:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b9w(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?877792:0;e=0;return e|0}function b9x(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?874432:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b9y(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?874432:0;e=0;return e|0}function b9z(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?764480:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b9A(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?764480:0;e=0;return e|0}function b9B(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1470528:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b9C(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1470528:0;e=0;return e|0}function b9D(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?877680:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b9E(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?877680:0;e=0;return e|0}function b9F(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?877232:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b9G(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?877232:0;e=0;return e|0}function b9H(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?766160:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b9I(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?766160:0;e=0;return e|0}function b9J(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1056832:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b9K(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1056832:0;e=0;return e|0}function b9L(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?877008:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b9M(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?877008:0;e=0;return e|0}function b9N(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1056608:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b9O(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1056608:0;e=0;return e|0}function b9P(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?876784:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b9Q(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?876784:0;e=0;return e|0}function b9R(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?765936:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b9S(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?765936:0;e=0;return e|0}function b9T(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?876896:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b9U(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?876896:0;e=0;return e|0}function b9V(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1470304:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b9W(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1470304:0;e=0;return e|0}function b9X(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1469968:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b9Y(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1469968:0;e=0;return e|0}function b9Z(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1469632:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b9_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1469632:0;e=0;return e|0}function b9$(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?876112:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b90(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?876112:0;e=0;return e|0}function b91(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2601120:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b92(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2601120:0;e=0;return e|0}function b93(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1497632:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b94(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1497632:0;e=0;return e|0}function b95(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1497744:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b96(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1497744:0;e=0;return e|0}function b97(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?876672:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function b98(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?876672:0;e=0;return e|0}function b99(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?765824:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function caa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?765824:0;e=0;return e|0}function cab(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?710024:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cac(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?710024:0;e=0;return e|0}function cad(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?710136:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cae(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?710136:0;e=0;return e|0}function caf(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?710248:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cag(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?710248:0;e=0;return e|0}function cah(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?710360:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cai(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?710360:0;e=0;return e|0}function caj(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?876560:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cak(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?876560:0;e=0;return e|0}function cal(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1056384:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cam(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1056384:0;e=0;return e|0}function can(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?876448:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cao(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?876448:0;e=0;return e|0}function cap(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?765712:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function caq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?765712:0;e=0;return e|0}function car(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1469856:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cas(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1469856:0;e=0;return e|0}function cat(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1469744:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cau(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1469744:0;e=0;return e|0}function cav(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?876e3:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function caw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?876e3:0;e=0;return e|0}function cax(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?875552:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cay(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?875552:0;e=0;return e|0}function caz(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?765040:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function caA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?765040:0;e=0;return e|0}function caB(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?765152:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function caC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?765152:0;e=0;return e|0}function caD(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?765376:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function caE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?765376:0;e=0;return e|0}function caF(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?709688:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function caG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?709688:0;e=0;return e|0}function caH(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?709800:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function caI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?709800:0;e=0;return e|0}function caJ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?765264:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function caK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?765264:0;e=0;return e|0}function caL(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?875776:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function caM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?875776:0;e=0;return e|0}function caN(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?709912:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function caO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?709912:0;e=0;return e|0}function caP(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?765488:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function caQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?765488:0;e=0;return e|0}function caR(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?764928:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function caS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?764928:0;e=0;return e|0}function caT(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?864800:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function caU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?864800:0;e=0;return e|0}function caV(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?709352:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function caW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?709352:0;e=0;return e|0}function caX(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?709240:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function caY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?709240:0;e=0;return e|0}function caZ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4549760:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ca_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4549760:0;e=0;return e|0}function ca$(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1469520:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ca0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1469520:0;e=0;return e|0}function ca1(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1056048:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ca2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1056048:0;e=0;return e|0}function ca3(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1055600:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ca4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1055600:0;e=0;return e|0}function ca5(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?877344:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ca6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?877344:0;e=0;return e|0}function ca7(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?877456:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ca8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?877456:0;e=0;return e|0}function ca9(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?766272:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cba(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?766272:0;e=0;return e|0}function cbb(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1469296:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cbc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1469296:0;e=0;return e|0}function cbd(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?875328:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cbe(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?875328:0;e=0;return e|0}function cbf(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?875216:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cbg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?875216:0;e=0;return e|0}function cbh(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?875104:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cbi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?875104:0;e=0;return e|0}function cbj(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?764816:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cbk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?764816:0;e=0;return e|0}function cbl(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?933232:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cbm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?933232:0;e=0;return e|0}function cbn(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?788672:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cbo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?788672:0;e=0;return e|0}function cbp(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?933344:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cbq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?933344:0;e=0;return e|0}function cbr(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?874992:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cbs(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?874992:0;e=0;return e|0}function cbt(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?764592:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cbu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?764592:0;e=0;return e|0}function cbv(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?874544:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cbw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?874544:0;e=0;return e|0}function cbx(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?874320:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cby(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?874320:0;e=0;return e|0}function cbz(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?874208:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cbA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?874208:0;e=0;return e|0}function cbB(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?874096:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cbC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?874096:0;e=0;return e|0}function cbD(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1489456:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cbE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1489456:0;e=0;return e|0}function cbF(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?873648:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cbG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?873648:0;e=0;return e|0}function cbH(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?873536:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cbI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?873536:0;e=0;return e|0}function cbJ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?873312:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cbK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?873312:0;e=0;return e|0}function cbL(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1468624:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cbM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1468624:0;e=0;return e|0}function cbN(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1052016:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cbO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1052016:0;e=0;return e|0}function cbP(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?873200:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cbQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?873200:0;e=0;return e|0}function cbR(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1468512:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cbS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1468512:0;e=0;return e|0}function cbT(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?924944:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cbU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?924944:0;e=0;return e|0}function cbV(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?882160:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cbW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?882160:0;e=0;return e|0}function cbX(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?767280:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cbY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?767280:0;e=0;return e|0}function cbZ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?767392:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cb_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?767392:0;e=0;return e|0}function cb$(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>1){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6524108+(b*112|0)>>2];c[a+104>>2]=c[6524112+(b*112|0)>>2];c[a+108>>2]=c[6524116+(b*112|0)>>2];d=0;return d|0}function cb0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<2&(d|0)==0)){e=1;return e|0}c[a>>2]=6524008+(b*112|0);e=0;return e|0}function cb1(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2588800:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cb2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2588800:0;e=0;return e|0}function cb3(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2589024:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cb4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2589024:0;e=0;return e|0}function cb5(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2589248:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cb6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2589248:0;e=0;return e|0}function cb7(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2589472:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cb8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2589472:0;e=0;return e|0}function cb9(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2589696:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cca(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2589696:0;e=0;return e|0}function ccb(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2589808:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ccc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2589808:0;e=0;return e|0}function ccd(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2588688:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cce(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2588688:0;e=0;return e|0}function ccf(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2588912:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ccg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2588912:0;e=0;return e|0}function cch(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2589136:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cci(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2589136:0;e=0;return e|0}function ccj(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2589360:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cck(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2589360:0;e=0;return e|0}function ccl(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2589584:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ccm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2589584:0;e=0;return e|0}function ccn(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1070272:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cco(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1070272:0;e=0;return e|0}function ccp(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2588576:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ccq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2588576:0;e=0;return e|0}function ccr(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1054816:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ccs(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1054816:0;e=0;return e|0}function cct(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?872080:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ccu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?872080:0;e=0;return e|0}function ccv(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1054704:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ccw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1054704:0;e=0;return e|0}function ccx(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?763472:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ccy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?763472:0;e=0;return e|0}function ccz(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?763584:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ccA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?763584:0;e=0;return e|0}function ccB(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?763696:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ccC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?763696:0;e=0;return e|0}function ccD(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?763808:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ccE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?763808:0;e=0;return e|0}function ccF(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?763920:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ccG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?763920:0;e=0;return e|0}function ccH(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?764032:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ccI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?764032:0;e=0;return e|0}function ccJ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?764144:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ccK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?764144:0;e=0;return e|0}function ccL(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?764256:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ccM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?764256:0;e=0;return e|0}function ccN(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?871968:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ccO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?871968:0;e=0;return e|0}function ccP(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1470416:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ccQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1470416:0;e=0;return e|0}function ccR(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1054368:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ccS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1054368:0;e=0;return e|0}function ccT(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?871856:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ccU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?871856:0;e=0;return e|0}function ccV(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?763024:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ccW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?763024:0;e=0;return e|0}function ccX(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1466608:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ccY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1466608:0;e=0;return e|0}function ccZ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1466720:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cc_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1466720:0;e=0;return e|0}function cc$(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1466496:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cc0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1466496:0;e=0;return e|0}function cc1(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1054032:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cc2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1054032:0;e=0;return e|0}function cc3(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1468176:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cc4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1468176:0;e=0;return e|0}function cc5(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?871744:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cc6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?871744:0;e=0;return e|0}function cc7(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1468400:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cc8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1468400:0;e=0;return e|0}function cc9(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1055152:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cda(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1055152:0;e=0;return e|0}function cdb(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?872192:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cdc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?872192:0;e=0;return e|0}function cdd(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?872304:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cde(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?872304:0;e=0;return e|0}function cdf(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?872416:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cdg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?872416:0;e=0;return e|0}function cdh(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?872528:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cdi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?872528:0;e=0;return e|0}function cdj(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?872640:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cdk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?872640:0;e=0;return e|0}function cdl(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?872752:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cdm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?872752:0;e=0;return e|0}function cdn(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?872864:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cdo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?872864:0;e=0;return e|0}function cdp(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1055040:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cdq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1055040:0;e=0;return e|0}function cdr(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1054928:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cds(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1054928:0;e=0;return e|0}function cdt(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?872976:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cdu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?872976:0;e=0;return e|0}function cdv(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?763360:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cdw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?763360:0;e=0;return e|0}function cdx(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1054480:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cdy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1054480:0;e=0;return e|0}function cdz(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1054256:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cdA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1054256:0;e=0;return e|0}function cdB(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?870512:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cdC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?870512:0;e=0;return e|0}function cdD(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?870400:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cdE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?870400:0;e=0;return e|0}function cdF(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1467504:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cdG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1467504:0;e=0;return e|0}function cdH(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?765600:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cdI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?765600:0;e=0;return e|0}function cdJ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1469072:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cdK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1469072:0;e=0;return e|0}function cdL(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1469184:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cdM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1469184:0;e=0;return e|0}function cdN(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?869952:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cdO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?869952:0;e=0;return e|0}function cdP(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?762464:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cdQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?762464:0;e=0;return e|0}function cdR(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?762576:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cdS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?762576:0;e=0;return e|0}function cdT(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?869840:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cdU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?869840:0;e=0;return e|0}function cdV(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?762352:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cdW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?762352:0;e=0;return e|0}function cdX(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?762240:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cdY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?762240:0;e=0;return e|0}function cdZ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?869728:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cd_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?869728:0;e=0;return e|0}function cd$(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?709576:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cd0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?709576:0;e=0;return e|0}function cd1(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?709464:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cd2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?709464:0;e=0;return e|0}function cd3(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?869616:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cd4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?869616:0;e=0;return e|0}function cd5(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?869504:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cd6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?869504:0;e=0;return e|0}function cd7(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2584992:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cd8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2584992:0;e=0;return e|0}function cd9(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?869280:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cea(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?869280:0;e=0;return e|0}function ceb(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1467392:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cec(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1467392:0;e=0;return e|0}function ced(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?869168:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cee(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?869168:0;e=0;return e|0}function cef(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?762016:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ceg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?762016:0;e=0;return e|0}function ceh(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?869056:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cei(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?869056:0;e=0;return e|0}function cej(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?761904:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cek(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?761904:0;e=0;return e|0}function cel(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1467280:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cem(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1467280:0;e=0;return e|0}function cen(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?868832:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ceo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?868832:0;e=0;return e|0}function cep(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1467168:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ceq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1467168:0;e=0;return e|0}function cer(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1054144:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ces(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1054144:0;e=0;return e|0}function cet(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?867936:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ceu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?867936:0;e=0;return e|0}function cev(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?868048:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cew(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?868048:0;e=0;return e|0}function cex(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2587008:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cey(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2587008:0;e=0;return e|0}function cez(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1466048:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ceA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1466048:0;e=0;return e|0}function ceB(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2586896:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ceC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2586896:0;e=0;return e|0}function ceD(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1465936:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ceE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1465936:0;e=0;return e|0}function ceF(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?866144:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ceG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?866144:0;e=0;return e|0}function ceH(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?866256:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ceI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?866256:0;e=0;return e|0}function ceJ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?866368:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ceK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?866368:0;e=0;return e|0}function ceL(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?866480:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ceM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?866480:0;e=0;return e|0}function ceN(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?866592:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ceO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?866592:0;e=0;return e|0}function ceP(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?866704:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ceQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?866704:0;e=0;return e|0}function ceR(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1466272:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ceS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1466272:0;e=0;return e|0}function ceT(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1053808:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ceU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1053808:0;e=0;return e|0}function ceV(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?867824:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ceW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?867824:0;e=0;return e|0}function ceX(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?761568:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ceY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?761568:0;e=0;return e|0}function ceZ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?867376:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ce_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?867376:0;e=0;return e|0}function ce$(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?761456:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ce0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?761456:0;e=0;return e|0}function ce1(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?761344:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ce2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?761344:0;e=0;return e|0}function ce3(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?867264:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ce4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?867264:0;e=0;return e|0}function ce5(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?866816:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ce6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?866816:0;e=0;return e|0}function ce7(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?761120:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ce8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?761120:0;e=0;return e|0}function ce9(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4547520:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cfa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4547520:0;e=0;return e|0}function cfb(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2585888:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cfc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2585888:0;e=0;return e|0}function cfd(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2585776:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cfe(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2585776:0;e=0;return e|0}function cff(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1465040:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cfg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1465040:0;e=0;return e|0}function cfh(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2585664:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cfi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2585664:0;e=0;return e|0}function cfj(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1464816:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cfk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1464816:0;e=0;return e|0}function cfl(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1464928:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cfm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1464928:0;e=0;return e|0}function cfn(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?786320:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cfo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?786320:0;e=0;return e|0}function cfp(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2585552:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cfq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2585552:0;e=0;return e|0}function cfr(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?932112:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cfs(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?932112:0;e=0;return e|0}function cft(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?5784680:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cfu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?5784680:0;e=0;return e|0}function cfv(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4549984:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cfw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4549984:0;e=0;return e|0}function cfx(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1470192:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cfy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1470192:0;e=0;return e|0}function cfz(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4549872:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cfA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4549872:0;e=0;return e|0}function cfB(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1467056:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cfC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1467056:0;e=0;return e|0}function cfD(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1466832:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cfE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1466832:0;e=0;return e|0}function cfF(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4548528:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cfG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4548528:0;e=0;return e|0}function cfH(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2587792:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cfI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2587792:0;e=0;return e|0}function cfJ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4555696:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cfK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4555696:0;e=0;return e|0}function cfL(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4548416:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cfM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4548416:0;e=0;return e|0}function cfN(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2587680:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cfO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2587680:0;e=0;return e|0}function cfP(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1467616:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cfQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1467616:0;e=0;return e|0}function cfR(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1467728:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cfS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1467728:0;e=0;return e|0}function cfT(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1467840:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cfU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1467840:0;e=0;return e|0}function cfV(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1467952:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cfW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1467952:0;e=0;return e|0}function cfX(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1468064:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cfY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1468064:0;e=0;return e|0}function cfZ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?871072:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cf_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?871072:0;e=0;return e|0}function cf$(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?871184:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cf0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?871184:0;e=0;return e|0}function cf1(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?871296:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cf2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?871296:0;e=0;return e|0}function cf3(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?871408:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cf4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?871408:0;e=0;return e|0}function cf5(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?871520:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cf6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?871520:0;e=0;return e|0}function cf7(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?871632:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cf8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?871632:0;e=0;return e|0}function cf9(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?870624:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cga(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?870624:0;e=0;return e|0}function cgb(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?870736:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cgc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?870736:0;e=0;return e|0}function cgd(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?870848:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cge(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?870848:0;e=0;return e|0}function cgf(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?870960:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cgg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?870960:0;e=0;return e|0}function cgh(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2587568:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cgi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2587568:0;e=0;return e|0}function cgj(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?5786696:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cgk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?5786696:0;e=0;return e|0}function cgl(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4555584:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cgm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4555584:0;e=0;return e|0}function cgn(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1053584:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cgo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1053584:0;e=0;return e|0}function cgp(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?867040:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cgq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?867040:0;e=0;return e|0}function cgr(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?867152:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cgs(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?867152:0;e=0;return e|0}function cgt(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?761232:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cgu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?761232:0;e=0;return e|0}function cgv(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1053472:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cgw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1053472:0;e=0;return e|0}function cgx(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?866928:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cgy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?866928:0;e=0;return e|0}function cgz(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1053360:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cgA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1053360:0;e=0;return e|0}function cgB(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?761008:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cgC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?761008:0;e=0;return e|0}function cgD(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?760896:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cgE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?760896:0;e=0;return e|0}function cgF(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?866032:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cgG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?866032:0;e=0;return e|0}function cgH(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?760784:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cgI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?760784:0;e=0;return e|0}function cgJ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?865920:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cgK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?865920:0;e=0;return e|0}function cgL(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1465824:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cgM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1465824:0;e=0;return e|0}function cgN(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?868160:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cgO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?868160:0;e=0;return e|0}function cgP(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?761680:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cgQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?761680:0;e=0;return e|0}function cgR(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1499760:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cgS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1499760:0;e=0;return e|0}function cgT(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1086176:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cgU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1086176:0;e=0;return e|0}function cgV(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1470752:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cgW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1470752:0;e=0;return e|0}function cgX(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1470640:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cgY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1470640:0;e=0;return e|0}function cgZ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?865808:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cg_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?865808:0;e=0;return e|0}function cg$(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?760672:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cg0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?760672:0;e=0;return e|0}function cg1(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1470080:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cg2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1470080:0;e=0;return e|0}function cg3(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1056496:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cg4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1056496:0;e=0;return e|0}function cg5(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1056160:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cg6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1056160:0;e=0;return e|0}function cg7(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?876336:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cg8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?876336:0;e=0;return e|0}function cg9(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?875888:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cha(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?875888:0;e=0;return e|0}function chb(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1053136:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function chc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1053136:0;e=0;return e|0}function chd(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?865360:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function che(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?865360:0;e=0;return e|0}function chf(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?865248:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function chg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?865248:0;e=0;return e|0}function chh(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?874880:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function chi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?874880:0;e=0;return e|0}function chj(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?864912:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function chk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?864912:0;e=0;return e|0}function chl(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?760336:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function chm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?760336:0;e=0;return e|0}function chn(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1069488:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cho(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1069488:0;e=0;return e|0}function chp(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4548864:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function chq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4548864:0;e=0;return e|0}function chr(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4548752:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function chs(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4548752:0;e=0;return e|0}function cht(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2588240:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function chu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2588240:0;e=0;return e|0}function chv(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2588128:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function chw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2588128:0;e=0;return e|0}function chx(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2588016:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function chy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2588016:0;e=0;return e|0}function chz(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?865472:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function chA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?865472:0;e=0;return e|0}function chB(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?868496:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function chC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?868496:0;e=0;return e|0}function chD(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?761792:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function chE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?761792:0;e=0;return e|0}function chF(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?887312:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function chG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?887312:0;e=0;return e|0}function chH(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2587232:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function chI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2587232:0;e=0;return e|0}function chJ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1466944:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function chK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1466944:0;e=0;return e|0}function chL(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4548192:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function chM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4548192:0;e=0;return e|0}function chN(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2587456:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function chO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2587456:0;e=0;return e|0}function chP(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2587344:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function chQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2587344:0;e=0;return e|0}function chR(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1053696:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function chS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1053696:0;e=0;return e|0}function chT(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1052800:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function chU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1052800:0;e=0;return e|0}function chV(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?864688:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function chW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?864688:0;e=0;return e|0}function chX(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?864576:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function chY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?864576:0;e=0;return e|0}function chZ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?865584:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ch_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?865584:0;e=0;return e|0}function ch$(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?760560:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ch0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?760560:0;e=0;return e|0}function ch1(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?760448:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ch2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?760448:0;e=0;return e|0}function ch3(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1052912:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ch4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1052912:0;e=0;return e|0}function ch5(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2586784:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ch6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2586784:0;e=0;return e|0}function ch7(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?864464:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ch8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?864464:0;e=0;return e|0}function ch9(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?760224:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cia(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?760224:0;e=0;return e|0}function cib(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?864352:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cic(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?864352:0;e=0;return e|0}function cid(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1056944:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cie(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1056944:0;e=0;return e|0}function cif(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1462576:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cig(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1462576:0;e=0;return e|0}function cih(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1049440:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cii(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1049440:0;e=0;return e|0}function cij(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?864240:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cik(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?864240:0;e=0;return e|0}function cil(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?760112:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cim(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?760112:0;e=0;return e|0}function cin(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?864128:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cio(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?864128:0;e=0;return e|0}function cip(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2586336:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ciq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2586336:0;e=0;return e|0}function cir(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4548080:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cis(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4548080:0;e=0;return e|0}function cit(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2586560:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ciu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2586560:0;e=0;return e|0}function civ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2586672:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ciw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2586672:0;e=0;return e|0}function cix(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?864016:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ciy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?864016:0;e=0;return e|0}function ciz(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1465712:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ciA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1465712:0;e=0;return e|0}function ciB(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?863904:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ciC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?863904:0;e=0;return e|0}function ciD(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?901872:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ciE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?901872:0;e=0;return e|0}function ciF(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?860096:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ciG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?860096:0;e=0;return e|0}function ciH(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1482512:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ciI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1482512:0;e=0;return e|0}function ciJ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?863680:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ciK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?863680:0;e=0;return e|0}function ciL(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?76e4:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ciM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?76e4:0;e=0;return e|0}function ciN(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1050224:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ciO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1050224:0;e=0;return e|0}function ciP(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?863568:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ciQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?863568:0;e=0;return e|0}function ciR(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1052576:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ciS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1052576:0;e=0;return e|0}function ciT(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?778704:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ciU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?778704:0;e=0;return e|0}function ciV(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?863344:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ciW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?863344:0;e=0;return e|0}function ciX(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?862448:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ciY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?862448:0;e=0;return e|0}function ciZ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1082368:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ci_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1082368:0;e=0;return e|0}function ci$(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?863232:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ci0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?863232:0;e=0;return e|0}function ci1(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1052464:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ci2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1052464:0;e=0;return e|0}function ci3(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?862672:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ci4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?862672:0;e=0;return e|0}function ci5(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?759664:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ci6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?759664:0;e=0;return e|0}function ci7(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?759552:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ci8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?759552:0;e=0;return e|0}function ci9(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?862896:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cja(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?862896:0;e=0;return e|0}function cjb(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?759776:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cjc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?759776:0;e=0;return e|0}function cjd(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?862784:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cje(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?862784:0;e=0;return e|0}function cjf(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?863120:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cjg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?863120:0;e=0;return e|0}function cjh(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?863008:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cji(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?863008:0;e=0;return e|0}function cjj(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?759888:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cjk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?759888:0;e=0;return e|0}function cjl(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?862560:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cjm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?862560:0;e=0;return e|0}function cjn(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1052352:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cjo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1052352:0;e=0;return e|0}function cjp(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?862336:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cjq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?862336:0;e=0;return e|0}function cjr(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1464592:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cjs(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1464592:0;e=0;return e|0}function cjt(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1051792:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cju(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1051792:0;e=0;return e|0}function cjv(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1464368:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cjw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1464368:0;e=0;return e|0}function cjx(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1464480:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cjy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1464480:0;e=0;return e|0}function cjz(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1051680:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cjA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1051680:0;e=0;return e|0}function cjB(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1051568:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cjC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1051568:0;e=0;return e|0}function cjD(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?862112:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cjE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?862112:0;e=0;return e|0}function cjF(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1465376:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cjG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1465376:0;e=0;return e|0}function cjH(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1052240:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cjI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1052240:0;e=0;return e|0}function cjJ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?862e3:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cjK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?862e3:0;e=0;return e|0}function cjL(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?861888:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cjM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?861888:0;e=0;return e|0}function cjN(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?759440:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cjO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?759440:0;e=0;return e|0}function cjP(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?5784344:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cjQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?5784344:0;e=0;return e|0}function cjR(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1465264:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cjS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1465264:0;e=0;return e|0}function cjT(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?861776:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cjU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?861776:0;e=0;return e|0}function cjV(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4547296:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cjW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4547296:0;e=0;return e|0}function cjX(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1465152:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cjY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1465152:0;e=0;return e|0}function cjZ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4547856:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cj_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4547856:0;e=0;return e|0}function cj$(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?5784120:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cj0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?5784120:0;e=0;return e|0}function cj1(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?5784008:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cj2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?5784008:0;e=0;return e|0}function cj3(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4547744:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cj4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4547744:0;e=0;return e|0}function cj5(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?904448:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cj6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?904448:0;e=0;return e|0}function cj7(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4547632:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cj8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4547632:0;e=0;return e|0}function cj9(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2586224:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cka(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2586224:0;e=0;return e|0}function ckb(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1463808:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ckc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1463808:0;e=0;return e|0}function ckd(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4547408:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cke(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4547408:0;e=0;return e|0}function ckf(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?861664:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ckg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?861664:0;e=0;return e|0}function ckh(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?759328:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cki(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?759328:0;e=0;return e|0}function ckj(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1051904:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ckk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1051904:0;e=0;return e|0}function ckl(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1464704:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ckm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1464704:0;e=0;return e|0}function ckn(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1463696:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cko(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1463696:0;e=0;return e|0}function ckp(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1050112:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ckq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1050112:0;e=0;return e|0}function ckr(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?859760:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cks(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?859760:0;e=0;return e|0}function ckt(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?758880:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cku(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?758880:0;e=0;return e|0}function ckv(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?758768:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ckw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?758768:0;e=0;return e|0}function ckx(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1051456:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cky(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1051456:0;e=0;return e|0}function ckz(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1464144:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ckA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1464144:0;e=0;return e|0}function ckB(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1468960:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ckC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1468960:0;e=0;return e|0}function ckD(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1055936:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ckE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1055936:0;e=0;return e|0}function ckF(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1464032:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ckG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1464032:0;e=0;return e|0}function ckH(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1051232:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ckI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1051232:0;e=0;return e|0}function ckJ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1051344:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ckK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1051344:0;e=0;return e|0}function ckL(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?861552:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ckM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?861552:0;e=0;return e|0}function ckN(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?861440:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ckO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?861440:0;e=0;return e|0}function ckP(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?861328:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ckQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?861328:0;e=0;return e|0}function ckR(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4547184:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ckS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4547184:0;e=0;return e|0}function ckT(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2585440:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ckU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2585440:0;e=0;return e|0}function ckV(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?861216:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ckW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?861216:0;e=0;return e|0}function ckX(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?759216:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ckY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?759216:0;e=0;return e|0}function ckZ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1069600:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ck_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1069600:0;e=0;return e|0}function ck$(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?860992:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ck0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?860992:0;e=0;return e|0}function ck1(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1051008:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ck2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1051008:0;e=0;return e|0}function ck3(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?860880:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ck4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?860880:0;e=0;return e|0}function ck5(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?860768:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ck6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?860768:0;e=0;return e|0}function ck7(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?860656:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ck8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?860656:0;e=0;return e|0}function ck9(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1463920:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cla(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1463920:0;e=0;return e|0}function clb(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?860544:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function clc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?860544:0;e=0;return e|0}function cld(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?759104:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cle(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?759104:0;e=0;return e|0}function clf(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4547072:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function clg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4547072:0;e=0;return e|0}function clh(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?860320:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cli(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?860320:0;e=0;return e|0}function clj(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1050560:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function clk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1050560:0;e=0;return e|0}function cll(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?860208:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function clm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?860208:0;e=0;return e|0}function cln(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1050784:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function clo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1050784:0;e=0;return e|0}function clp(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?860432:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function clq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?860432:0;e=0;return e|0}function clr(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?758992:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cls(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?758992:0;e=0;return e|0}function clt(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?859984:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function clu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?859984:0;e=0;return e|0}function clv(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?929984:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function clw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?929984:0;e=0;return e|0}function clx(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1050448:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cly(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1050448:0;e=0;return e|0}function clz(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?859872:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function clA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?859872:0;e=0;return e|0}function clB(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1463472:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function clC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1463472:0;e=0;return e|0}function clD(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?105e4:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function clE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?105e4:0;e=0;return e|0}function clF(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1050896:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function clG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1050896:0;e=0;return e|0}function clH(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?859536:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function clI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?859536:0;e=0;return e|0}function clJ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?859424:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function clK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?859424:0;e=0;return e|0}function clL(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1482736:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function clM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1482736:0;e=0;return e|0}function clN(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?859200:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function clO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?859200:0;e=0;return e|0}function clP(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?859312:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function clQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?859312:0;e=0;return e|0}function clR(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?858976:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function clS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?858976:0;e=0;return e|0}function clT(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?758656:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function clU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?758656:0;e=0;return e|0}function clV(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1493040:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function clW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1493040:0;e=0;return e|0}function clX(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?858864:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function clY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?858864:0;e=0;return e|0}function clZ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4546960:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cl_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4546960:0;e=0;return e|0}function cl$(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2585328:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cl0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2585328:0;e=0;return e|0}function cl1(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1463248:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cl2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1463248:0;e=0;return e|0}function cl3(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1049216:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cl4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1049216:0;e=0;return e|0}function cl5(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?858640:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cl6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?858640:0;e=0;return e|0}function cl7(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?858752:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cl8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?858752:0;e=0;return e|0}function cl9(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?858528:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cma(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?858528:0;e=0;return e|0}function cmb(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?924272:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cmc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?924272:0;e=0;return e|0}function cmd(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?894368:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cme(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?894368:0;e=0;return e|0}function cmf(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1079456:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cmg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1079456:0;e=0;return e|0}function cmh(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1463136:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cmi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1463136:0;e=0;return e|0}function cmj(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?858416:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cmk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?858416:0;e=0;return e|0}function cml(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?858192:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cmm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?858192:0;e=0;return e|0}function cmn(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1049888:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cmo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1049888:0;e=0;return e|0}function cmp(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1463024:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cmq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1463024:0;e=0;return e|0}function cmr(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2585216:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cms(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2585216:0;e=0;return e|0}function cmt(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1462800:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cmu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1462800:0;e=0;return e|0}function cmv(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1462912:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cmw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1462912:0;e=0;return e|0}function cmx(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1049776:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cmy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1049776:0;e=0;return e|0}function cmz(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1049664:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cmA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1049664:0;e=0;return e|0}function cmB(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2594736:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cmC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2594736:0;e=0;return e|0}function cmD(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1462688:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cmE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1462688:0;e=0;return e|0}function cmF(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?858080:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cmG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?858080:0;e=0;return e|0}function cmH(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?857968:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cmI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?857968:0;e=0;return e|0}function cmJ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?857856:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cmK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?857856:0;e=0;return e|0}function cmL(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1049552:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cmM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1049552:0;e=0;return e|0}function cmN(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?758432:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cmO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?758432:0;e=0;return e|0}function cmP(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?757872:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cmQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?757872:0;e=0;return e|0}function cmR(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?757984:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cmS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?757984:0;e=0;return e|0}function cmT(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?758096:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cmU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?758096:0;e=0;return e|0}function cmV(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?758208:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cmW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?758208:0;e=0;return e|0}function cmX(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?758320:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cmY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?758320:0;e=0;return e|0}function cmZ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1049328:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cm_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1049328:0;e=0;return e|0}function cm$(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?857744:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cm0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?857744:0;e=0;return e|0}function cm1(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?757760:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cm2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?757760:0;e=0;return e|0}function cm3(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?5783896:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cm4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?5783896:0;e=0;return e|0}function cm5(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4546848:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cm6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4546848:0;e=0;return e|0}function cm7(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2584432:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cm8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2584432:0;e=0;return e|0}function cm9(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2584544:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cna(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2584544:0;e=0;return e|0}function cnb(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2584656:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cnc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2584656:0;e=0;return e|0}function cnd(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2584768:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cne(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2584768:0;e=0;return e|0}function cnf(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2584880:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cng(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2584880:0;e=0;return e|0}function cnh(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1462464:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cni(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1462464:0;e=0;return e|0}function cnj(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2585104:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cnk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2585104:0;e=0;return e|0}function cnl(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?857520:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cnm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?857520:0;e=0;return e|0}function cnn(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?857632:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cno(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?857632:0;e=0;return e|0}function cnp(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1049104:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cnq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1049104:0;e=0;return e|0}function cnr(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?857408:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cns(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?857408:0;e=0;return e|0}function cnt(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1045744:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cnu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1045744:0;e=0;return e|0}function cnv(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?756640:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cnw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?756640:0;e=0;return e|0}function cnx(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?756752:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cny(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?756752:0;e=0;return e|0}function cnz(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?756864:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cnA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?756864:0;e=0;return e|0}function cnB(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?857296:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cnC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?857296:0;e=0;return e|0}function cnD(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1048992:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cnE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1048992:0;e=0;return e|0}function cnF(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?857184:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cnG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?857184:0;e=0;return e|0}function cnH(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1048880:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cnI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1048880:0;e=0;return e|0}function cnJ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?857072:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cnK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?857072:0;e=0;return e|0}function cnL(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?856960:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cnM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?856960:0;e=0;return e|0}function cnN(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1048768:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cnO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1048768:0;e=0;return e|0}function cnP(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1495392:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cnQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1495392:0;e=0;return e|0}function cnR(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?856848:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cnS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?856848:0;e=0;return e|0}function cnT(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1081920:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cnU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1081920:0;e=0;return e|0}function cnV(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1048656:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cnW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1048656:0;e=0;return e|0}function cnX(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?856736:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cnY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?856736:0;e=0;return e|0}function cnZ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1462240:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cn_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1462240:0;e=0;return e|0}function cn$(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?856624:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cn0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?856624:0;e=0;return e|0}function cn1(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?856512:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cn2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?856512:0;e=0;return e|0}function cn3(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?856288:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cn4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?856288:0;e=0;return e|0}function cn5(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?928192:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cn6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?928192:0;e=0;return e|0}function cn7(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?783968:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cn8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?783968:0;e=0;return e|0}function cn9(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?928304:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function coa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?928304:0;e=0;return e|0}function cob(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?784080:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function coc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?784080:0;e=0;return e|0}function cod(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?856176:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function coe(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?856176:0;e=0;return e|0}function cof(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?757648:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cog(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?757648:0;e=0;return e|0}function coh(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?856064:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function coi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?856064:0;e=0;return e|0}function coj(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?790352:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cok(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?790352:0;e=0;return e|0}function col(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1046416:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function com(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1046416:0;e=0;return e|0}function con(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?855952:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function coo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?855952:0;e=0;return e|0}function cop(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?855840:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function coq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?855840:0;e=0;return e|0}function cor(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?757536:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cos(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?757536:0;e=0;return e|0}function cot(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?855616:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cou(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?855616:0;e=0;return e|0}function cov(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?757424:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cow(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?757424:0;e=0;return e|0}function cox(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?757312:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function coy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?757312:0;e=0;return e|0}function coz(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1461568:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function coA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1461568:0;e=0;return e|0}function coB(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1046304:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function coC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1046304:0;e=0;return e|0}function coD(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1046192:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function coE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1046192:0;e=0;return e|0}function coF(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1046080:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function coG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1046080:0;e=0;return e|0}function coH(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?855504:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function coI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?855504:0;e=0;return e|0}function coJ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?855392:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function coK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?855392:0;e=0;return e|0}function coL(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?855280:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function coM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?855280:0;e=0;return e|0}function coN(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2583984:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function coO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2583984:0;e=0;return e|0}function coP(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1462128:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function coQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1462128:0;e=0;return e|0}function coR(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2583872:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function coS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2583872:0;e=0;return e|0}function coT(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?859648:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function coU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?859648:0;e=0;return e|0}function coV(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1045968:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function coW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1045968:0;e=0;return e|0}function coX(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4546736:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function coY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4546736:0;e=0;return e|0}function coZ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2583760:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function co_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2583760:0;e=0;return e|0}function co$(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1046640:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function co0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1046640:0;e=0;return e|0}function co1(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1047200:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function co2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1047200:0;e=0;return e|0}function co3(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1047648:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function co4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1047648:0;e=0;return e|0}function co5(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1047760:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function co6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1047760:0;e=0;return e|0}function co7(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1047872:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function co8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1047872:0;e=0;return e|0}function co9(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1047984:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cpa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1047984:0;e=0;return e|0}function cpb(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1048096:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cpc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1048096:0;e=0;return e|0}function cpd(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1048208:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cpe(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1048208:0;e=0;return e|0}function cpf(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1048320:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cpg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1048320:0;e=0;return e|0}function cph(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1048432:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cpi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1048432:0;e=0;return e|0}function cpj(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1046528:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cpk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1046528:0;e=0;return e|0}function cpl(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1046752:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cpm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1046752:0;e=0;return e|0}function cpn(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1046864:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cpo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1046864:0;e=0;return e|0}function cpp(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1046976:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cpq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1046976:0;e=0;return e|0}function cpr(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1047088:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cps(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1047088:0;e=0;return e|0}function cpt(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1047312:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cpu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1047312:0;e=0;return e|0}function cpv(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1047424:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cpw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1047424:0;e=0;return e|0}function cpx(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1047536:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cpy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1047536:0;e=0;return e|0}function cpz(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1461904:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cpA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1461904:0;e=0;return e|0}function cpB(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1462016:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cpC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1462016:0;e=0;return e|0}function cpD(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1048544:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cpE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1048544:0;e=0;return e|0}function cpF(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1461792:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cpG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1461792:0;e=0;return e|0}function cpH(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?5783784:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cpI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?5783784:0;e=0;return e|0}function cpJ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4546624:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cpK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4546624:0;e=0;return e|0}function cpL(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4546512:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cpM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4546512:0;e=0;return e|0}function cpN(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1461680:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cpO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1461680:0;e=0;return e|0}function cpP(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?6523896:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cpQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?6523896:0;e=0;return e|0}function cpR(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?5783672:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cpS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?5783672:0;e=0;return e|0}function cpT(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2582976:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cpU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2582976:0;e=0;return e|0}function cpV(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2583088:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cpW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2583088:0;e=0;return e|0}function cpX(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2583312:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cpY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2583312:0;e=0;return e|0}function cpZ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2583424:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cp_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2583424:0;e=0;return e|0}function cp$(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2583536:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cp0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2583536:0;e=0;return e|0}function cp1(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2583648:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cp2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2583648:0;e=0;return e|0}function cp3(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2583200:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cp4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2583200:0;e=0;return e|0}function cp5(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2581744:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cp6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2581744:0;e=0;return e|0}function cp7(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2581856:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cp8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2581856:0;e=0;return e|0}function cp9(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2581968:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cqa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2581968:0;e=0;return e|0}function cqb(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2582080:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cqc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2582080:0;e=0;return e|0}function cqd(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2582192:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cqe(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2582192:0;e=0;return e|0}function cqf(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2582304:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cqg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2582304:0;e=0;return e|0}function cqh(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2582416:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cqi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2582416:0;e=0;return e|0}function cqj(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2582528:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cqk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2582528:0;e=0;return e|0}function cql(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2582640:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cqm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2582640:0;e=0;return e|0}function cqn(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2582752:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cqo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2582752:0;e=0;return e|0}function cqp(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2582864:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cqq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2582864:0;e=0;return e|0}function cqr(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?855168:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cqs(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?855168:0;e=0;return e|0}function cqt(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?757200:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cqu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?757200:0;e=0;return e|0}function cqv(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?707896:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cqw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?707896:0;e=0;return e|0}function cqx(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?757088:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cqy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?757088:0;e=0;return e|0}function cqz(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2581520:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cqA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2581520:0;e=0;return e|0}function cqB(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?852368:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cqC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?852368:0;e=0;return e|0}function cqD(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?852480:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cqE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?852480:0;e=0;return e|0}function cqF(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?852592:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cqG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?852592:0;e=0;return e|0}function cqH(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?853936:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cqI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?853936:0;e=0;return e|0}function cqJ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?854048:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cqK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?854048:0;e=0;return e|0}function cqL(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?854160:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cqM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?854160:0;e=0;return e|0}function cqN(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?854272:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cqO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?854272:0;e=0;return e|0}function cqP(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?854384:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cqQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?854384:0;e=0;return e|0}function cqR(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?854496:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cqS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?854496:0;e=0;return e|0}function cqT(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?854608:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cqU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?854608:0;e=0;return e|0}function cqV(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?854720:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cqW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?854720:0;e=0;return e|0}function cqX(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?854832:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cqY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?854832:0;e=0;return e|0}function cqZ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?852704:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cq_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?852704:0;e=0;return e|0}function cq$(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?852816:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cq0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?852816:0;e=0;return e|0}function cq1(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?852928:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cq2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?852928:0;e=0;return e|0}function cq3(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?853040:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cq4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?853040:0;e=0;return e|0}function cq5(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?853152:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cq6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?853152:0;e=0;return e|0}function cq7(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?853264:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cq8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?853264:0;e=0;return e|0}function cq9(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?853376:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cra(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?853376:0;e=0;return e|0}function crb(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?853488:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function crc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?853488:0;e=0;return e|0}function crd(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?853600:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cre(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?853600:0;e=0;return e|0}function crf(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?853712:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function crg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?853712:0;e=0;return e|0}function crh(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?853824:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cri(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?853824:0;e=0;return e|0}function crj(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2581408:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function crk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2581408:0;e=0;return e|0}function crl(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2581296:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function crm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2581296:0;e=0;return e|0}function crn(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?5783560:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cro(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?5783560:0;e=0;return e|0}function crp(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1460336:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function crq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1460336:0;e=0;return e|0}function crr(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1460448:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function crs(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1460448:0;e=0;return e|0}function crt(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1460560:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cru(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1460560:0;e=0;return e|0}function crv(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1461008:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function crw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1461008:0;e=0;return e|0}function crx(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1460672:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cry(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1460672:0;e=0;return e|0}function crz(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1460784:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function crA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1460784:0;e=0;return e|0}function crB(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1460896:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function crC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1460896:0;e=0;return e|0}function crD(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1461120:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function crE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1461120:0;e=0;return e|0}function crF(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1461232:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function crG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1461232:0;e=0;return e|0}function crH(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1460224:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function crI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1460224:0;e=0;return e|0}function crJ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2581632:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function crK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2581632:0;e=0;return e|0}function crL(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1461344:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function crM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1461344:0;e=0;return e|0}function crN(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?855056:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function crO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?855056:0;e=0;return e|0}function crP(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?756976:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function crQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?756976:0;e=0;return e|0}function crR(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1460112:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function crS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1460112:0;e=0;return e|0}function crT(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1459888:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function crU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1459888:0;e=0;return e|0}function crV(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?852256:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function crW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?852256:0;e=0;return e|0}function crX(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1459776:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function crY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1459776:0;e=0;return e|0}function crZ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2581184:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cr_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2581184:0;e=0;return e|0}function cr$(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?146e4:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cr0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?146e4:0;e=0;return e|0}function cr1(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4546288:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cr2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4546288:0;e=0;return e|0}function cr3(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2580848:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cr4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2580848:0;e=0;return e|0}function cr5(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2580960:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cr6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2580960:0;e=0;return e|0}function cr7(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?850912:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cr8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?850912:0;e=0;return e|0}function cr9(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?851024:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function csa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?851024:0;e=0;return e|0}function csb(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?851136:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function csc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?851136:0;e=0;return e|0}function csd(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?851248:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cse(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?851248:0;e=0;return e|0}function csf(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?851360:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function csg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?851360:0;e=0;return e|0}function csh(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?851472:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function csi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?851472:0;e=0;return e|0}function csj(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?851584:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function csk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?851584:0;e=0;return e|0}function csl(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?851696:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function csm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?851696:0;e=0;return e|0}function csn(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?851808:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cso(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?851808:0;e=0;return e|0}function csp(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?851920:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function csq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?851920:0;e=0;return e|0}function csr(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?852032:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function css(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?852032:0;e=0;return e|0}function cst(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?852144:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function csu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?852144:0;e=0;return e|0}function csv(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?850128:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function csw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?850128:0;e=0;return e|0}function csx(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?850240:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function csy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?850240:0;e=0;return e|0}function csz(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?850464:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function csA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?850464:0;e=0;return e|0}function csB(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?850576:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function csC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?850576:0;e=0;return e|0}function csD(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?850688:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function csE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?850688:0;e=0;return e|0}function csF(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?850800:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function csG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?850800:0;e=0;return e|0}function csH(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?850352:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function csI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?850352:0;e=0;return e|0}function csJ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1459328:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function csK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1459328:0;e=0;return e|0}function csL(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1045520:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function csM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1045520:0;e=0;return e|0}function csN(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?5783448:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function csO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?5783448:0;e=0;return e|0}function csP(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1459664:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function csQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1459664:0;e=0;return e|0}function csR(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1459552:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function csS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1459552:0;e=0;return e|0}function csT(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1045632:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function csU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1045632:0;e=0;return e|0}function csV(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1459440:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function csW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1459440:0;e=0;return e|0}function csX(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1459104:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function csY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1459104:0;e=0;return e|0}function csZ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1459216:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cs_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1459216:0;e=0;return e|0}function cs$(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?850016:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cs0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?850016:0;e=0;return e|0}function cs1(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?849904:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cs2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?849904:0;e=0;return e|0}function cs3(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?5783336:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cs4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?5783336:0;e=0;return e|0}function cs5(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4546176:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cs6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4546176:0;e=0;return e|0}function cs7(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1458992:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cs8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1458992:0;e=0;return e|0}function cs9(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1458880:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cta(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1458880:0;e=0;return e|0}function ctb(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2580736:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ctc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2580736:0;e=0;return e|0}function ctd(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?849792:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cte(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?849792:0;e=0;return e|0}function ctf(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?756528:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ctg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?756528:0;e=0;return e|0}function cth(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4546064:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cti(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4546064:0;e=0;return e|0}function ctj(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2580624:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ctk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2580624:0;e=0;return e|0}function ctl(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?849568:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ctm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?849568:0;e=0;return e|0}function ctn(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?756416:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cto(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?756416:0;e=0;return e|0}function ctp(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1458768:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ctq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1458768:0;e=0;return e|0}function ctr(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?849456:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cts(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?849456:0;e=0;return e|0}function ctt(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1045184:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ctu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1045184:0;e=0;return e|0}function ctv(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?849344:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ctw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?849344:0;e=0;return e|0}function ctx(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4545952:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cty(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4545952:0;e=0;return e|0}function ctz(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2580512:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ctA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2580512:0;e=0;return e|0}function ctB(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4545728:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ctC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4545728:0;e=0;return e|0}function ctD(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2580400:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ctE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2580400:0;e=0;return e|0}function ctF(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4553904:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ctG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4553904:0;e=0;return e|0}function ctH(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?900528:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ctI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?900528:0;e=0;return e|0}function ctJ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1066464:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ctK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1066464:0;e=0;return e|0}function ctL(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?877120:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ctM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?877120:0;e=0;return e|0}function ctN(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?766048:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ctO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?766048:0;e=0;return e|0}function ctP(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1056720:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ctQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1056720:0;e=0;return e|0}function ctR(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2602240:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ctS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2602240:0;e=0;return e|0}function ctT(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1499536:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ctU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1499536:0;e=0;return e|0}function ctV(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?929312:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ctW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?929312:0;e=0;return e|0}function ctX(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?784864:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ctY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?784864:0;e=0;return e|0}function ctZ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1494384:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ct_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1494384:0;e=0;return e|0}function ct$(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?919680:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ct0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?919680:0;e=0;return e|0}function ct1(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?914752:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ct2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?914752:0;e=0;return e|0}function ct3(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?913296:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ct4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?913296:0;e=0;return e|0}function ct5(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1485760:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ct6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1485760:0;e=0;return e|0}function ct7(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1485648:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function ct8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1485648:0;e=0;return e|0}function ct9(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2595296:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cua(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2595296:0;e=0;return e|0}function cub(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2595184:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cuc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2595184:0;e=0;return e|0}function cud(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1482960:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cue(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1482960:0;e=0;return e|0}function cuf(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?865136:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cug(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?865136:0;e=0;return e|0}function cuh(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?904336:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cui(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?904336:0;e=0;return e|0}function cuj(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?904224:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cuk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?904224:0;e=0;return e|0}function cul(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1481840:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cum(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1481840:0;e=0;return e|0}function cun(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1068256:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cuo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1068256:0;e=0;return e|0}function cup(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?885856:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cuq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?885856:0;e=0;return e|0}function cur(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?879136:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cus(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?879136:0;e=0;return e|0}function cut(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?870288:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cuu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?870288:0;e=0;return e|0}function cuv(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?762800:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cuw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?762800:0;e=0;return e|0}function cux(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?868608:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cuy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?868608:0;e=0;return e|0}function cuz(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1471424:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cuA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1471424:0;e=0;return e|0}function cuB(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1471312:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cuC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1471312:0;e=0;return e|0}function cuD(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?865024:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cuE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?865024:0;e=0;return e|0}function cuF(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?877568:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cuG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?877568:0;e=0;return e|0}function cuH(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?874656:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cuI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?874656:0;e=0;return e|0}function cuJ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1055824:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cuK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1055824:0;e=0;return e|0}function cuL(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?5784568:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cuM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?5784568:0;e=0;return e|0}function cuN(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?881600:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cuO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?881600:0;e=0;return e|0}function cuP(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?767168:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cuQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?767168:0;e=0;return e|0}function cuR(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?861104:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cuS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?861104:0;e=0;return e|0}function cuT(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1051120:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cuU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1051120:0;e=0;return e|0}function cuV(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?856400:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cuW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?856400:0;e=0;return e|0}function cuX(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?882272:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cuY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?882272:0;e=0;return e|0}function cuZ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?882384:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cu_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?882384:0;e=0;return e|0}function cu$(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1081248:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cu0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1081248:0;e=0;return e|0}function cu1(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1483072:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cu2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1483072:0;e=0;return e|0}function cu3(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?772320:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cu4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?772320:0;e=0;return e|0}function cu5(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?766384:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cu6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?766384:0;e=0;return e|0}function cu7(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1496512:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cu8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1496512:0;e=0;return e|0}function cu9(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1050336:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cva(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1050336:0;e=0;return e|0}function cvb(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1465488:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cvc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1465488:0;e=0;return e|0}function cvd(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?858304:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cve(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?858304:0;e=0;return e|0}function cvf(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?758544:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cvg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?758544:0;e=0;return e|0}function cvh(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?778480:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cvi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?778480:0;e=0;return e|0}function cvj(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2595408:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cvk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2595408:0;e=0;return e|0}function cvl(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?772208:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cvm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?772208:0;e=0;return e|0}function cvn(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?772096:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cvo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?772096:0;e=0;return e|0}function cvp(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1067472:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cvq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1067472:0;e=0;return e|0}function cvr(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?902208:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cvs(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?902208:0;e=0;return e|0}function cvt(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?762912:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cvu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?762912:0;e=0;return e|0}function cvv(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?870176:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cvw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?870176:0;e=0;return e|0}function cvx(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?762688:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cvy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?762688:0;e=0;return e|0}function cvz(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?873984:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cvA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?873984:0;e=0;return e|0}function cvB(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1052128:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cvC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1052128:0;e=0;return e|0}function cvD(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2584208:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cvE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2584208:0;e=0;return e|0}function cvF(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?919904:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cvG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?919904:0;e=0;return e|0}function cvH(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?934912:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cvI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?934912:0;e=0;return e|0}function cvJ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1498528:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cvK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1498528:0;e=0;return e|0}function cvL(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2601008:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cvM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2601008:0;e=0;return e|0}function cvN(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1496624:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cvO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1496624:0;e=0;return e|0}function cvP(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2600336:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cvQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2600336:0;e=0;return e|0}function cvR(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1494944:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cvS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1494944:0;e=0;return e|0}function cvT(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1494832:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cvU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1494832:0;e=0;return e|0}function cvV(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?925728:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cvW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?925728:0;e=0;return e|0}function cvX(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?925840:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cvY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?925840:0;e=0;return e|0}function cvZ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1080128:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cv_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1080128:0;e=0;return e|0}function cv$(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2599888:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cv0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2599888:0;e=0;return e|0}function cv1(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?922928:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cv2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?922928:0;e=0;return e|0}function cv3(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?922592:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cv4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?922592:0;e=0;return e|0}function cv5(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1492144:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cv6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1492144:0;e=0;return e|0}function cv7(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1491472:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cv8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1491472:0;e=0;return e|0}function cv9(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1075648:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cwa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1075648:0;e=0;return e|0}function cwb(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1075536:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cwc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1075536:0;e=0;return e|0}function cwd(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?915648:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cwe(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?915648:0;e=0;return e|0}function cwf(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4551664:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cwg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4551664:0;e=0;return e|0}function cwh(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?916880:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cwi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?916880:0;e=0;return e|0}function cwj(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?5786136:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cwk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?5786136:0;e=0;return e|0}function cwl(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1072848:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cwm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1072848:0;e=0;return e|0}function cwn(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?911056:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cwo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?911056:0;e=0;return e|0}function cwp(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?911168:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cwq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?911168:0;e=0;return e|0}function cwr(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1485312:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cws(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1485312:0;e=0;return e|0}function cwt(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1072512:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cwu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1072512:0;e=0;return e|0}function cwv(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1072400:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cww(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1072400:0;e=0;return e|0}function cwx(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?910384:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cwy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?910384:0;e=0;return e|0}function cwz(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1072288:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cwA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1072288:0;e=0;return e|0}function cwB(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1072064:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cwC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1072064:0;e=0;return e|0}function cwD(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?908928:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cwE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?908928:0;e=0;return e|0}function cwF(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1070160:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cwG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1070160:0;e=0;return e|0}function cwH(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?906688:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cwI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?906688:0;e=0;return e|0}function cwJ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1069712:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cwK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1069712:0;e=0;return e|0}function cwL(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1069824:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cwM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1069824:0;e=0;return e|0}function cwN(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4552112:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cwO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4552112:0;e=0;return e|0}function cwP(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1482288:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cwQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1482288:0;e=0;return e|0}function cwR(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?903552:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cwS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?903552:0;e=0;return e|0}function cwT(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?903440:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cwU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?903440:0;e=0;return e|0}function cwV(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2594624:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cwW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2594624:0;e=0;return e|0}function cwX(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1481392:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cwY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1481392:0;e=0;return e|0}function cwZ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1481280:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cw_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1481280:0;e=0;return e|0}function cw$(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?873872:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cw0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?873872:0;e=0;return e|0}function cw1(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?764368:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cw2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?764368:0;e=0;return e|0}function cw3(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?5785800:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cw4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?5785800:0;e=0;return e|0}function cw5(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1479936:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cw6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1479936:0;e=0;return e|0}function cw7(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?897728:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cw8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?897728:0;e=0;return e|0}function cw9(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1064896:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cxa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1064896:0;e=0;return e|0}function cxb(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1477360:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cxc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1477360:0;e=0;return e|0}function cxd(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2593392:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cxe(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2593392:0;e=0;return e|0}function cxf(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1477248:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cxg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1477248:0;e=0;return e|0}function cxh(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4551552:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cxi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4551552:0;e=0;return e|0}function cxj(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?889888:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cxk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?889888:0;e=0;return e|0}function cxl(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1475792:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cxm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1475792:0;e=0;return e|0}function cxn(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1062544:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cxo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1062544:0;e=0;return e|0}function cxp(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1061536:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cxq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1061536:0;e=0;return e|0}function cxr(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1473328:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cxs(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1473328:0;e=0;return e|0}function cxt(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?881040:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cxu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?881040:0;e=0;return e|0}function cxv(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2589920:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cxw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2589920:0;e=0;return e|0}function cxx(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1469408:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cxy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1469408:0;e=0;return e|0}function cxz(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1062880:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cxA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1062880:0;e=0;return e|0}function cxB(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?888992:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cxC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?888992:0;e=0;return e|0}function cxD(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?873424:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cxE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?873424:0;e=0;return e|0}function cxF(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?868944:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cxG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?868944:0;e=0;return e|0}function cxH(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?868720:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cxI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?868720:0;e=0;return e|0}function cxJ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?867600:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cxK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?867600:0;e=0;return e|0}function cxL(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?867712:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cxM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?867712:0;e=0;return e|0}function cxN(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2588464:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cxO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2588464:0;e=0;return e|0}function cxP(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?868384:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cxQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?868384:0;e=0;return e|0}function cxR(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4547968:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cxS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4547968:0;e=0;return e|0}function cxT(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4555360:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cxU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4555360:0;e=0;return e|0}function cxV(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2600448:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cxW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2600448:0;e=0;return e|0}function cxX(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?863792:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cxY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?863792:0;e=0;return e|0}function cxZ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1463584:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cx_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1463584:0;e=0;return e|0}function cx$(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1464256:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cx0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1464256:0;e=0;return e|0}function cx1(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1050672:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cx2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1050672:0;e=0;return e|0}function cx3(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1462352:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cx4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1462352:0;e=0;return e|0}function cx5(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4546400:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cx6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4546400:0;e=0;return e|0}function cx7(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1461456:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cx8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1461456:0;e=0;return e|0}function cx9(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?6524456:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cya(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?6524456:0;e=0;return e|0}function cyb(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1487328:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cyc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1487328:0;e=0;return e|0}function cyd(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1074080:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cye(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1074080:0;e=0;return e|0}function cyf(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?5785016:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cyg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?5785016:0;e=0;return e|0}function cyh(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4551216:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cyi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4551216:0;e=0;return e|0}function cyj(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2591712:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cyk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2591712:0;e=0;return e|0}function cyl(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4553792:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cym(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4553792:0;e=0;return e|0}function cyn(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1055712:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cyo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1055712:0;e=0;return e|0}function cyp(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1084608:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cyq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1084608:0;e=0;return e|0}function cyr(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>1){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4549636+(b*112|0)>>2];c[a+104>>2]=c[4549640+(b*112|0)>>2];c[a+108>>2]=c[4549644+(b*112|0)>>2];d=0;return d|0}function cys(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<2&(d|0)==0)){e=1;return e|0}c[a>>2]=4549536+(b*112|0);e=0;return e|0}function cyt(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>2){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4549300+(b*112|0)>>2];c[a+104>>2]=c[4549304+(b*112|0)>>2];c[a+108>>2]=c[4549308+(b*112|0)>>2];d=0;return d|0}function cyu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<3&(d|0)==0)){e=1;return e|0}c[a>>2]=4549200+(b*112|0);e=0;return e|0}function cyv(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>1){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4549076+(b*112|0)>>2];c[a+104>>2]=c[4549080+(b*112|0)>>2];c[a+108>>2]=c[4549084+(b*112|0)>>2];d=0;return d|0}function cyw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<2&(d|0)==0)){e=1;return e|0}c[a>>2]=4548976+(b*112|0);e=0;return e|0}function cyx(){var a=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=c[2113308]|0;if((c[159660]|0)!=(a|0)){c[159660]=a;c[3528976]=c[1755632+(a-2<<2)>>2]}if((c[2430092]|0)==0){return}a=c[2113130]|0;c[2430428]=a&3;c[2430426]=a&7;a=c[2112932]|0;e=c[a>>2]|0;if(e>>>0>9){f=(d[e+265|0]|0)<<8|(d[e+264|0]|0)}else{f=gj[c[a+196688+(e<<2)>>2]&4095](264)|0}do{if(f<<16>>16==133){e=c[3541066]|0;a=e;if((b[e+66564>>1]&64)!=0){g=0;break}if((b[e+66566>>1]&64)==0){g=0;break}else{h=3}while(1){if((b[a+(h+33280<<1)>>1]&64)==0){break}else{h=h+1|0}}g=(h|0)==3?0:h}else{g=0}}while(0);h=0;do{f=(h+g|0)%381|0;a=c[3541066]|0;e=f<<1;i=b[a+(e+65536)>>1]|0;j=b[a+(e+66560)>>1]|0;k=b[a+(e+67584)>>1]|0;c[2415160]=a+(f<<7);f=j&65535;if((f&64|0)==0){c[2385550]=-(f>>>7)&511;j=(k&65535)>>>7;c[2385552]=j;if((c[2113132]|0)==304){k=j-8|0;c[2385552]=k;l=k}else{l=j}c[3528548]=i&255;j=f&63;c[2385554]=j;m=j;n=l}else{j=(c[3528550]|0)+1+(c[2385552]|0)|0;c[2385552]=j;m=c[2385554]|0;n=j}L36399:do{if((m|0)!=0){j=(i&65535)>>>8;f=j&15;k=-f|0;c[3528550]=f;if((n|0)>479){a=n-512|0;c[2385552]=a;o=a}else{o=n}a=c[2113132]|0;do{if((o|0)>-1){if((o|0)>=(((j|-16)^15)+a|0)){break}gu[c[(c[3528976]|0)+(f<<2)>>2]&16383]();break L36399}}while(0);if(!((o|0)>=(k|0)&(o|0)<(a|0))){break}gu[c[(c[3528976]|0)+((f|16)<<2)>>2]&16383]()}}while(0);h=h+1|0;}while((h|0)<381);return}function cyy(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0;f=c[3540994]|0;g=c[3528548]|0;h=g<<8;i=c[2385554]|0;do{if((i|0)>31){j=511}else{k=(i<<4)-1|0;if((k|0)>=0){j=k;break}return}}while(0);k=(j|0)>255;l=j&255;m=c[2385550]|0;n=c[2113042]|0;o=c[2113044]|0;p=n+512|0;q=c[2113132]|0;r=c[2385552]<<1;s=c[2112968]|0;t=q<<1;u=c[2415160]|0;v=c[2429858]|0;w=c[2430428]|0;x=c[2429718]|0;y=c[2430092]|0;z=c[3541046]|0;A=c[2430426]|0;B=0;C=0;D=0;L36416:while(1){E=(i|0)<33;F=511-g|0;G=g+1|0;L36418:do{if((i|0)>16&(g|0)!=255){H=g-255|0;I=~g;J=D;L36420:while(1){K=J+m&511;do{if((K|0)<(n|0)){L=J+n-K|0}else{if((K|0)>=(o|0)){L=p+J-K|0;break}M=(J|0)>255;N=M?16:0;O=J&255;if(E){if(!M){P=32505;break L36420}if((J|0)<(F|0)){L=F;break}else{P=32520;break L36420}}if(M){Q=H+O|0;if((Q|0)>=0){P=32502;break L36420}M=G+Q|0;if((M|0)<0){L=512;break}else{R=g;S=M;T=0;U=J;V=K;P=32523;break L36418}}else{if((O|0)<=(g|0)){R=g;S=O;T=N;U=J;V=K;P=32523;break L36418}M=O+I|0;if((M|0)>(g|0)){L=256;break}else{R=g;S=M;T=16;U=J;V=K;P=32523;break L36418}}}}while(0);if((L|0)>(j|0)){P=32546;break L36416}else{J=L}}if((P|0)==32520){P=0;I=255-g|0;R=((J|0)<256&k?255:l)-I|0;S=O-I|0;T=N;U=J;V=K;P=32523;break}else if((P|0)==32502){P=0;W=g;X=-K|0;Y=K;Z=N;_=Q;$=G+J-Q|0;break}else if((P|0)==32505){P=0;I=(J|0)<256&k?255:l;aa=-K|0;ab=K;ac=N;ad=O;ae=I;af=J+1-O+I|0;P=32524;break}}else{if(k){I=D;while(1){ah=I+m&511;if((ah|0)<(n|0)){ai=I+n|0}else{if((ah|0)<(o|0)){break}ai=p+I|0}H=ai-ah|0;if((H|0)>(j|0)){P=32547;break L36416}else{I=H}}aj=ah;ak=(I|0)>255?16:0;al=I;am=(I|0)<256?255:l}else{J=D;while(1){an=J+m&511;if((an|0)<(n|0)){ao=J+n|0}else{if((an|0)<(o|0)){break}ao=p+J|0}H=ao-an|0;if((H|0)>(j|0)){P=32548;break L36416}else{J=H}}aj=an;ak=(J|0)>255?16:0;al=J;am=l}R=am;S=al&255;T=ak;U=al;V=aj;P=32523}}while(0);if((P|0)==32523){P=0;G=-V|0;F=U+1-S+R|0;if(E){aa=G;ab=V;ac=T;ad=S;ae=R;af=F;P=32524}else{W=R;X=G;Y=V;Z=T;_=S;$=F}}if((P|0)==32524){P=0;W=(ae|0)>(g|0)?g:ae;X=aa;Y=ab;Z=ac;_=ad;$=af}F=X-1|0;if((W-_|0)>(F+o|0)){ap=_+o+F|0}else{ap=W}if((_|0)>(ap|0)){aq=B;ar=C}else{F=B;G=C;I=-1;H=s+((ag(q,(Y<<1)-32|0)|0)+r)|0;M=_;while(1){as=d[f+(M+h)|0]|0;at=(as>>>4)+Z|0;do{if((at|0)==(I|0)){au=I;av=G;aw=F}else{ax=at<<1;ay=e[u+((ax|1)<<1)>>1]|0;az=(ay<<12&983040|(e[u+(ax<<1)>>1]|0))&v;do{if((ay&8|0)==0){if((ay&4|0)==0){aA=az;break}aA=w|az&1048572}else{aA=A|az&1048568}}while(0);az=a[x+aA|0]|0;ax=az&255;if(az<<24>>24!=0){au=at;av=ax;aw=ay;break}c[2385344]=y+(aA<<7);c[2440392]=z+((ay>>>4&4080)<<2);au=at;av=ax;aw=ay}}while(0);do{if((av|0)==0){at=as<<1&30;J=c[(c[2385344]|0)+((((aw&2|0)==0?at:at^30)|1)<<2)>>2]&15;at=(J|0)==0;if((aw&1|0)==0){if(at){break}b[H>>1]=c[(c[2440392]|0)+(J<<2)>>2]&65535;break}else{if(at){break}b[H>>1]=c[(c[2440392]|0)+(J<<2)>>2]&65535;break}}}while(0);as=M+1|0;if((as|0)>(ap|0)){aq=aw;ar=av;break}else{F=aw;G=av;I=au;H=H+t|0;M=as}}}if(($|0)>(j|0)){P=32544;break}else{B=aq;C=ar;D=$}}if((P|0)==32544){return}else if((P|0)==32546){return}else if((P|0)==32547){return}else if((P|0)==32548){return}}function cyz(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0;f=c[3540994]|0;g=c[3528548]|0;h=g<<8;i=c[2385554]|0;do{if((i|0)>31){j=511}else{k=(i<<4)-1|0;if((k|0)>=0){j=k;break}return}}while(0);k=(j|0)>255;l=j&255;m=c[2385550]|0;n=c[2113042]|0;o=c[2113044]|0;p=n+512|0;q=c[2113132]|0;r=c[2385552]<<1;s=c[2112968]|0;t=q<<1;u=c[2415160]|0;v=c[2429858]|0;w=c[2430428]|0;x=c[2429718]|0;y=c[2430092]|0;z=c[3541046]|0;A=c[2430426]|0;B=0;C=0;D=0;L36501:while(1){E=(i|0)>16&(g|0)!=255;F=(i|0)<33;G=511-g|0;H=g+1|0;I=g-255|0;J=~g;K=D;L36503:while(1){L=K+m|0;M=L&511;do{if((M|0)<(n|0)){N=K+n-M|0}else{if((M|0)>=(o|0)){N=p+K-M|0;break}O=(K|0)>255;P=O?16:0;Q=K&255;R=(K|0)<256&k?255:l;if(!E){S=R;T=Q;U=P;V=32572;break L36503}if(F){if(!O){V=32562;break L36503}if((K|0)<(G|0)){N=G;break}else{V=32564;break L36503}}if(O){W=I+Q|0;if((W|0)>=0){V=32567;break L36503}O=H+W|0;if((O|0)<0){N=512;break}else{S=g;T=O;U=0;V=32572;break L36503}}else{if((Q|0)<=(g|0)){V=32570;break L36503}O=Q+J|0;if((O|0)>(g|0)){N=256;break}else{S=g;T=O;U=16;V=32572;break L36503}}}}while(0);if((N|0)>(j|0)){V=32597;break L36501}else{K=N}}if((V|0)==32570){V=0;X=g;Y=P;Z=Q;_=H+K-Q|0}else if((V|0)==32562){V=0;$=P;aa=Q;ab=R;ac=K+1-Q+R|0;V=32573}else if((V|0)==32564){V=0;J=255-g|0;S=R-J|0;T=Q-J|0;U=P;V=32572}else if((V|0)==32567){V=0;X=g;Y=P;Z=W;_=H+K-W|0}if((V|0)==32572){V=0;J=K+1-T+S|0;if(F){$=U;aa=T;ab=S;ac=J;V=32573}else{X=S;Y=U;Z=T;_=J}}if((V|0)==32573){V=0;X=(ab|0)>(g|0)?g:ab;Y=$;Z=aa;_=ac}J=((L|-512)^511)+o|0;I=(X-Z|0)>(J|0)?J+Z|0:X;if((Z|0)>(I|0)){ad=B;ae=C}else{J=B;G=C;E=-1;O=s+((ag(q,(M<<1)-32|0)|0)+r)|0;af=Z;while(1){ah=d[f+(af+h)|0]|0;ai=(ah>>>4)+Y|0;do{if((ai|0)==(E|0)){aj=E;ak=G;al=J}else{am=ai<<1;an=e[u+((am|1)<<1)>>1]|0;ao=(an<<12&983040|(e[u+(am<<1)>>1]|0))&v;do{if((an&8|0)==0){if((an&4|0)==0){ap=ao;break}ap=w|ao&1048572}else{ap=A|ao&1048568}}while(0);ao=a[x+ap|0]|0;am=ao&255;if(ao<<24>>24!=0){aj=ai;ak=am;al=an;break}c[2385344]=y+(ap<<7);c[2440392]=z+((an>>>4&4080)<<2);aj=ai;ak=am;al=an}}while(0);do{if((ak|0)==0){ai=ah<<1&30;am=(al&2|0)==0?ai:ai^30;ai=c[2385344]|0;ao=(c[ai+(am<<2)>>2]|0)>>>16&15;aq=(ao|0)==0;if((al&1|0)==0){if(!aq){b[O>>1]=c[(c[2440392]|0)+(ao<<2)>>2]&65535}ar=c[ai+((am|1)<<2)>>2]&15;if((ar|0)==0){break}b[O+2>>1]=c[(c[2440392]|0)+(ar<<2)>>2]&65535;break}else{if(!aq){b[O+2>>1]=c[(c[2440392]|0)+(ao<<2)>>2]&65535}ao=c[ai+((am|1)<<2)>>2]&15;if((ao|0)==0){break}b[O>>1]=c[(c[2440392]|0)+(ao<<2)>>2]&65535;break}}}while(0);ah=af+1|0;if((ah|0)>(I|0)){ad=al;ae=ak;break}else{J=al;G=ak;E=aj;O=O+t|0;af=ah}}}if((_|0)>(j|0)){V=32595;break}else{B=ad;C=ae;D=_}}if((V|0)==32595){return}else if((V|0)==32597){return}}function cyA(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0;f=c[3540994]|0;g=c[3528548]|0;h=g<<8;i=c[2385554]|0;do{if((i|0)>31){j=511}else{k=(i<<4)-1|0;if((k|0)>=0){j=k;break}return}}while(0);k=(j|0)>255;l=j&255;m=c[2385550]|0;n=c[2113042]|0;o=c[2113044]|0;p=n+512|0;q=c[2113132]|0;r=c[2385552]<<1;s=c[2112968]|0;t=q<<1;u=c[2415160]|0;v=c[2429858]|0;w=c[2430428]|0;x=c[2429718]|0;y=c[2430092]|0;z=c[3541046]|0;A=c[2430426]|0;B=0;C=0;D=0;L36568:while(1){E=(i|0)>16&(g|0)!=255;F=(i|0)<33;G=511-g|0;H=g+1|0;I=g-255|0;J=~g;K=D;L36570:while(1){L=K+m|0;M=L&511;do{if((M|0)<(n|0)){N=K+n-M|0}else{if((M|0)>=(o|0)){N=p+K-M|0;break}O=(K|0)>255;P=O?16:0;Q=K&255;R=(K|0)<256&k?255:l;if(!E){S=R;T=Q;U=P;V=32621;break L36570}if(F){if(!O){V=32611;break L36570}if((K|0)<(G|0)){N=G;break}else{V=32613;break L36570}}if(O){W=I+Q|0;if((W|0)>=0){V=32616;break L36570}O=H+W|0;if((O|0)<0){N=512;break}else{S=g;T=O;U=0;V=32621;break L36570}}else{if((Q|0)<=(g|0)){V=32619;break L36570}O=Q+J|0;if((O|0)>(g|0)){N=256;break}else{S=g;T=O;U=16;V=32621;break L36570}}}}while(0);if((N|0)>(j|0)){V=32650;break L36568}else{K=N}}if((V|0)==32613){V=0;J=255-g|0;S=R-J|0;T=Q-J|0;U=P;V=32621}else if((V|0)==32616){V=0;X=g;Y=P;Z=W;_=H+K-W|0}else if((V|0)==32619){V=0;X=g;Y=P;Z=Q;_=H+K-Q|0}else if((V|0)==32611){V=0;$=P;aa=Q;ab=R;ac=K+1-Q+R|0;V=32622}if((V|0)==32621){V=0;J=K+1-T+S|0;if(F){$=U;aa=T;ab=S;ac=J;V=32622}else{X=S;Y=U;Z=T;_=J}}if((V|0)==32622){V=0;X=(ab|0)>(g|0)?g:ab;Y=$;Z=aa;_=ac}J=((L|-512)^511)+o|0;I=(X-Z|0)>(J|0)?J+Z|0:X;if((Z|0)>(I|0)){ad=B;ae=C}else{J=B;G=C;E=-1;O=s+((ag(q,(M<<1)-32|0)|0)+r)|0;af=Z;while(1){ah=d[f+(af+h)|0]|0;ai=(ah>>>4)+Y|0;do{if((ai|0)==(E|0)){aj=E;ak=G;al=J}else{am=ai<<1;an=e[u+((am|1)<<1)>>1]|0;ao=(an<<12&983040|(e[u+(am<<1)>>1]|0))&v;do{if((an&8|0)==0){if((an&4|0)==0){ap=ao;break}ap=w|ao&1048572}else{ap=A|ao&1048568}}while(0);ao=a[x+ap|0]|0;am=ao&255;if(ao<<24>>24!=0){aj=ai;ak=am;al=an;break}c[2385344]=y+(ap<<7);c[2440392]=z+((an>>>4&4080)<<2);aj=ai;ak=am;al=an}}while(0);do{if((ak|0)==0){ai=ah<<1&30;am=(al&2|0)==0?ai:ai^30;ai=c[2385344]|0;ao=(c[ai+(am<<2)>>2]|0)>>>16&15;aq=(ao|0)==0;if((al&1|0)==0){if(!aq){b[O>>1]=c[(c[2440392]|0)+(ao<<2)>>2]&65535}ar=c[ai+((am|1)<<2)>>2]|0;as=ar&15;if((as|0)!=0){b[O+2>>1]=c[(c[2440392]|0)+(as<<2)>>2]&65535}as=ar>>>16&15;if((as|0)==0){break}b[O+4>>1]=c[(c[2440392]|0)+(as<<2)>>2]&65535;break}else{if(!aq){b[O+4>>1]=c[(c[2440392]|0)+(ao<<2)>>2]&65535}ao=c[ai+((am|1)<<2)>>2]|0;am=ao&15;if((am|0)!=0){b[O+2>>1]=c[(c[2440392]|0)+(am<<2)>>2]&65535}am=ao>>>16&15;if((am|0)==0){break}b[O>>1]=c[(c[2440392]|0)+(am<<2)>>2]&65535;break}}}while(0);ah=af+1|0;if((ah|0)>(I|0)){ad=al;ae=ak;break}else{J=al;G=ak;E=aj;O=O+t|0;af=ah}}}if((_|0)>(j|0)){V=32648;break}else{B=ad;C=ae;D=_}}if((V|0)==32648){return}else if((V|0)==32650){return}}function cyB(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0;f=c[3540994]|0;g=c[3528548]|0;h=g<<8;i=c[2385554]|0;do{if((i|0)>31){j=511}else{k=(i<<4)-1|0;if((k|0)>=0){j=k;break}return}}while(0);k=(j|0)>255;l=j&255;m=c[2385550]|0;n=c[2113042]|0;o=c[2113044]|0;p=n+512|0;q=c[2113132]|0;r=c[2385552]<<1;s=c[2112968]|0;t=q<<1;u=c[2415160]|0;v=c[2429858]|0;w=c[2430428]|0;x=c[2429718]|0;y=c[2430092]|0;z=c[3541046]|0;A=c[2430426]|0;B=0;C=0;D=0;L36641:while(1){E=(i|0)>16&(g|0)!=255;F=(i|0)<33;G=511-g|0;H=g+1|0;I=g-255|0;J=~g;K=D;L36643:while(1){L=K+m|0;M=L&511;do{if((M|0)<(n|0)){N=K+n-M|0}else{if((M|0)>=(o|0)){N=p+K-M|0;break}O=(K|0)>255;P=O?16:0;Q=K&255;R=(K|0)<256&k?255:l;if(!E){S=R;T=Q;U=P;V=32674;break L36643}if(F){if(!O){V=32664;break L36643}if((K|0)<(G|0)){N=G;break}else{V=32666;break L36643}}if(O){W=I+Q|0;if((W|0)>=0){V=32669;break L36643}O=H+W|0;if((O|0)<0){N=512;break}else{S=g;T=O;U=0;V=32674;break L36643}}else{if((Q|0)<=(g|0)){V=32672;break L36643}O=Q+J|0;if((O|0)>(g|0)){N=256;break}else{S=g;T=O;U=16;V=32674;break L36643}}}}while(0);if((N|0)>(j|0)){V=32707;break L36641}else{K=N}}if((V|0)==32672){V=0;X=g;Y=P;Z=Q;_=H+K-Q|0}else if((V|0)==32666){V=0;J=255-g|0;S=R-J|0;T=Q-J|0;U=P;V=32674}else if((V|0)==32669){V=0;X=g;Y=P;Z=W;_=H+K-W|0}else if((V|0)==32664){V=0;$=P;aa=Q;ab=R;ac=K+1-Q+R|0;V=32675}if((V|0)==32674){V=0;J=K+1-T+S|0;if(F){$=U;aa=T;ab=S;ac=J;V=32675}else{X=S;Y=U;Z=T;_=J}}if((V|0)==32675){V=0;X=(ab|0)>(g|0)?g:ab;Y=$;Z=aa;_=ac}J=((L|-512)^511)+o|0;I=(X-Z|0)>(J|0)?J+Z|0:X;if((Z|0)>(I|0)){ad=B;ae=C}else{J=B;G=C;E=-1;O=s+((ag(q,(M<<1)-32|0)|0)+r)|0;af=Z;while(1){ah=d[f+(af+h)|0]|0;ai=(ah>>>4)+Y|0;do{if((ai|0)==(E|0)){aj=E;ak=G;al=J}else{am=ai<<1;an=e[u+((am|1)<<1)>>1]|0;ao=(an<<12&983040|(e[u+(am<<1)>>1]|0))&v;do{if((an&8|0)==0){if((an&4|0)==0){ap=ao;break}ap=w|ao&1048572}else{ap=A|ao&1048568}}while(0);ao=a[x+ap|0]|0;am=ao&255;if(ao<<24>>24!=0){aj=ai;ak=am;al=an;break}c[2385344]=y+(ap<<7);c[2440392]=z+((an>>>4&4080)<<2);aj=ai;ak=am;al=an}}while(0);do{if((ak|0)==0){ai=ah<<1&30;am=(al&2|0)==0?ai:ai^30;ai=c[2385344]|0;ao=c[ai+(am<<2)>>2]|0;aq=ao>>>8&15;ar=(aq|0)==0;if((al&1|0)==0){if(!ar){b[O>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}as=ao>>>16&15;if((as|0)!=0){b[O+2>>1]=c[(c[2440392]|0)+(as<<2)>>2]&65535}as=c[ai+((am|1)<<2)>>2]|0;at=as&15;if((at|0)!=0){b[O+4>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535}at=as>>>16&15;if((at|0)==0){break}b[O+6>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535;break}else{if(!ar){b[O+6>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}aq=ao>>>16&15;if((aq|0)!=0){b[O+4>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}aq=c[ai+((am|1)<<2)>>2]|0;am=aq&15;if((am|0)!=0){b[O+2>>1]=c[(c[2440392]|0)+(am<<2)>>2]&65535}am=aq>>>16&15;if((am|0)==0){break}b[O>>1]=c[(c[2440392]|0)+(am<<2)>>2]&65535;break}}}while(0);ah=af+1|0;if((ah|0)>(I|0)){ad=al;ae=ak;break}else{J=al;G=ak;E=aj;O=O+t|0;af=ah}}}if((_|0)>(j|0)){V=32705;break}else{B=ad;C=ae;D=_}}if((V|0)==32705){return}else if((V|0)==32707){return}}function cyC(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0;f=c[3540994]|0;g=c[3528548]|0;h=g<<8;i=c[2385554]|0;do{if((i|0)>31){j=511}else{k=(i<<4)-1|0;if((k|0)>=0){j=k;break}return}}while(0);k=(j|0)>255;l=j&255;m=c[2385550]|0;n=c[2113042]|0;o=c[2113044]|0;p=n+512|0;q=c[2113132]|0;r=c[2385552]<<1;s=c[2112968]|0;t=q<<1;u=c[2415160]|0;v=c[2429858]|0;w=c[2430428]|0;x=c[2429718]|0;y=c[2430092]|0;z=c[3541046]|0;A=c[2430426]|0;B=0;C=0;D=0;L36720:while(1){E=(i|0)>16&(g|0)!=255;F=(i|0)<33;G=511-g|0;H=g+1|0;I=g-255|0;J=~g;K=D;L36722:while(1){L=K+m|0;M=L&511;do{if((M|0)<(n|0)){N=K+n-M|0}else{if((M|0)>=(o|0)){N=p+K-M|0;break}O=(K|0)>255;P=O?16:0;Q=K&255;R=(K|0)<256&k?255:l;if(!E){S=R;T=Q;U=P;V=32731;break L36722}if(F){if(!O){V=32721;break L36722}if((K|0)<(G|0)){N=G;break}else{V=32723;break L36722}}if(O){W=I+Q|0;if((W|0)>=0){V=32726;break L36722}O=H+W|0;if((O|0)<0){N=512;break}else{S=g;T=O;U=0;V=32731;break L36722}}else{if((Q|0)<=(g|0)){V=32729;break L36722}O=Q+J|0;if((O|0)>(g|0)){N=256;break}else{S=g;T=O;U=16;V=32731;break L36722}}}}while(0);if((N|0)>(j|0)){V=32768;break L36720}else{K=N}}if((V|0)==32721){V=0;X=P;Y=Q;Z=R;_=K+1-Q+R|0;V=32732}else if((V|0)==32726){V=0;$=g;aa=P;ab=W;ac=H+K-W|0}else if((V|0)==32729){V=0;$=g;aa=P;ab=Q;ac=H+K-Q|0}else if((V|0)==32723){V=0;J=255-g|0;S=R-J|0;T=Q-J|0;U=P;V=32731}if((V|0)==32731){V=0;J=K+1-T+S|0;if(F){X=U;Y=T;Z=S;_=J;V=32732}else{$=S;aa=U;ab=T;ac=J}}if((V|0)==32732){V=0;$=(Z|0)>(g|0)?g:Z;aa=X;ab=Y;ac=_}J=((L|-512)^511)+o|0;I=($-ab|0)>(J|0)?J+ab|0:$;if((ab|0)>(I|0)){ad=B;ae=C}else{J=B;G=C;E=-1;O=s+((ag(q,(M<<1)-32|0)|0)+r)|0;af=ab;while(1){ah=d[f+(af+h)|0]|0;ai=(ah>>>4)+aa|0;do{if((ai|0)==(E|0)){aj=E;ak=G;al=J}else{am=ai<<1;an=e[u+((am|1)<<1)>>1]|0;ao=(an<<12&983040|(e[u+(am<<1)>>1]|0))&v;do{if((an&8|0)==0){if((an&4|0)==0){ap=ao;break}ap=w|ao&1048572}else{ap=A|ao&1048568}}while(0);ao=a[x+ap|0]|0;am=ao&255;if(ao<<24>>24!=0){aj=ai;ak=am;al=an;break}c[2385344]=y+(ap<<7);c[2440392]=z+((an>>>4&4080)<<2);aj=ai;ak=am;al=an}}while(0);do{if((ak|0)==0){ai=ah<<1&30;am=(al&2|0)==0?ai:ai^30;ai=c[2385344]|0;ao=c[ai+(am<<2)>>2]|0;aq=ao>>>8&15;ar=(aq|0)==0;if((al&1|0)==0){if(!ar){b[O>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}as=ao>>>16&15;if((as|0)!=0){b[O+2>>1]=c[(c[2440392]|0)+(as<<2)>>2]&65535}as=c[ai+((am|1)<<2)>>2]|0;at=as&15;if((at|0)!=0){b[O+4>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535}at=as>>>16&15;if((at|0)!=0){b[O+6>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535}at=as>>>24&15;if((at|0)==0){break}b[O+8>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535;break}else{if(!ar){b[O+8>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}aq=ao>>>16&15;if((aq|0)!=0){b[O+6>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}aq=c[ai+((am|1)<<2)>>2]|0;am=aq&15;if((am|0)!=0){b[O+4>>1]=c[(c[2440392]|0)+(am<<2)>>2]&65535}am=aq>>>16&15;if((am|0)!=0){b[O+2>>1]=c[(c[2440392]|0)+(am<<2)>>2]&65535}am=aq>>>24&15;if((am|0)==0){break}b[O>>1]=c[(c[2440392]|0)+(am<<2)>>2]&65535;break}}}while(0);ah=af+1|0;if((ah|0)>(I|0)){ad=al;ae=ak;break}else{J=al;G=ak;E=aj;O=O+t|0;af=ah}}}if((ac|0)>(j|0)){V=32766;break}else{B=ad;C=ae;D=ac}}if((V|0)==32766){return}else if((V|0)==32768){return}}function cyD(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0;f=c[3540994]|0;g=c[3528548]|0;h=g<<8;i=c[2385554]|0;do{if((i|0)>31){j=511}else{k=(i<<4)-1|0;if((k|0)>=0){j=k;break}return}}while(0);k=(j|0)>255;l=j&255;m=c[2385550]|0;n=c[2113042]|0;o=c[2113044]|0;p=n+512|0;q=c[2113132]|0;r=c[2385552]<<1;s=c[2112968]|0;t=q<<1;u=c[2415160]|0;v=c[2429858]|0;w=c[2430428]|0;x=c[2429718]|0;y=c[2430092]|0;z=c[3541046]|0;A=c[2430426]|0;B=0;C=0;D=0;L36805:while(1){E=(i|0)>16&(g|0)!=255;F=(i|0)<33;G=511-g|0;H=g+1|0;I=g-255|0;J=~g;K=D;L36807:while(1){L=K+m|0;M=L&511;do{if((M|0)<(n|0)){N=K+n-M|0}else{if((M|0)>=(o|0)){N=p+K-M|0;break}O=(K|0)>255;P=O?16:0;Q=K&255;R=(K|0)<256&k?255:l;if(!E){S=R;T=Q;U=P;V=32792;break L36807}if(F){if(!O){V=32782;break L36807}if((K|0)<(G|0)){N=G;break}else{V=32784;break L36807}}if(O){W=I+Q|0;if((W|0)>=0){V=32787;break L36807}O=H+W|0;if((O|0)<0){N=512;break}else{S=g;T=O;U=0;V=32792;break L36807}}else{if((Q|0)<=(g|0)){V=32790;break L36807}O=Q+J|0;if((O|0)>(g|0)){N=256;break}else{S=g;T=O;U=16;V=32792;break L36807}}}}while(0);if((N|0)>(j|0)){V=32833;break L36805}else{K=N}}if((V|0)==32782){V=0;X=P;Y=Q;Z=R;_=K+1-Q+R|0;V=32793}else if((V|0)==32784){V=0;J=255-g|0;S=R-J|0;T=Q-J|0;U=P;V=32792}else if((V|0)==32790){V=0;$=g;aa=P;ab=Q;ac=H+K-Q|0}else if((V|0)==32787){V=0;$=g;aa=P;ab=W;ac=H+K-W|0}if((V|0)==32792){V=0;J=K+1-T+S|0;if(F){X=U;Y=T;Z=S;_=J;V=32793}else{$=S;aa=U;ab=T;ac=J}}if((V|0)==32793){V=0;$=(Z|0)>(g|0)?g:Z;aa=X;ab=Y;ac=_}J=((L|-512)^511)+o|0;I=($-ab|0)>(J|0)?J+ab|0:$;if((ab|0)>(I|0)){ad=B;ae=C}else{J=B;G=C;E=-1;O=s+((ag(q,(M<<1)-32|0)|0)+r)|0;af=ab;while(1){ah=d[f+(af+h)|0]|0;ai=(ah>>>4)+aa|0;do{if((ai|0)==(E|0)){aj=E;ak=G;al=J}else{am=ai<<1;an=e[u+((am|1)<<1)>>1]|0;ao=(an<<12&983040|(e[u+(am<<1)>>1]|0))&v;do{if((an&8|0)==0){if((an&4|0)==0){ap=ao;break}ap=w|ao&1048572}else{ap=A|ao&1048568}}while(0);ao=a[x+ap|0]|0;am=ao&255;if(ao<<24>>24!=0){aj=ai;ak=am;al=an;break}c[2385344]=y+(ap<<7);c[2440392]=z+((an>>>4&4080)<<2);aj=ai;ak=am;al=an}}while(0);do{if((ak|0)==0){ai=ah<<1&30;am=(al&2|0)==0?ai:ai^30;ai=c[2385344]|0;ao=c[ai+(am<<2)>>2]|0;aq=ao>>>8&15;ar=(aq|0)==0;if((al&1|0)==0){if(!ar){b[O>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}as=ao>>>16&15;if((as|0)!=0){b[O+2>>1]=c[(c[2440392]|0)+(as<<2)>>2]&65535}as=ao>>>24&15;if((as|0)!=0){b[O+4>>1]=c[(c[2440392]|0)+(as<<2)>>2]&65535}as=c[ai+((am|1)<<2)>>2]|0;at=as&15;if((at|0)!=0){b[O+6>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535}at=as>>>16&15;if((at|0)!=0){b[O+8>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535}at=as>>>24&15;if((at|0)==0){break}b[O+10>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535;break}else{if(!ar){b[O+10>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}aq=ao>>>16&15;if((aq|0)!=0){b[O+8>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}aq=ao>>>24&15;if((aq|0)!=0){b[O+6>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}aq=c[ai+((am|1)<<2)>>2]|0;am=aq&15;if((am|0)!=0){b[O+4>>1]=c[(c[2440392]|0)+(am<<2)>>2]&65535}am=aq>>>16&15;if((am|0)!=0){b[O+2>>1]=c[(c[2440392]|0)+(am<<2)>>2]&65535}am=aq>>>24&15;if((am|0)==0){break}b[O>>1]=c[(c[2440392]|0)+(am<<2)>>2]&65535;break}}}while(0);ah=af+1|0;if((ah|0)>(I|0)){ad=al;ae=ak;break}else{J=al;G=ak;E=aj;O=O+t|0;af=ah}}}if((ac|0)>(j|0)){V=32831;break}else{B=ad;C=ae;D=ac}}if((V|0)==32831){return}else if((V|0)==32833){return}}function cyE(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0;f=c[3540994]|0;g=c[3528548]|0;h=g<<8;i=c[2385554]|0;do{if((i|0)>31){j=511}else{k=(i<<4)-1|0;if((k|0)>=0){j=k;break}return}}while(0);k=(j|0)>255;l=j&255;m=c[2385550]|0;n=c[2113042]|0;o=c[2113044]|0;p=n+512|0;q=c[2113132]|0;r=c[2385552]<<1;s=c[2112968]|0;t=q<<1;u=c[2415160]|0;v=c[2429858]|0;w=c[2430428]|0;x=c[2429718]|0;y=c[2430092]|0;z=c[3541046]|0;A=c[2430426]|0;B=0;C=0;D=0;L36896:while(1){E=(i|0)>16&(g|0)!=255;F=(i|0)<33;G=511-g|0;H=g+1|0;I=g-255|0;J=~g;K=D;L36898:while(1){L=K+m|0;M=L&511;do{if((M|0)<(n|0)){N=K+n-M|0}else{if((M|0)>=(o|0)){N=p+K-M|0;break}O=(K|0)>255;P=O?16:0;Q=K&255;R=(K|0)<256&k?255:l;if(!E){S=R;T=Q;U=P;V=32857;break L36898}if(F){if(!O){V=32847;break L36898}if((K|0)<(G|0)){N=G;break}else{V=32849;break L36898}}if(O){W=I+Q|0;if((W|0)>=0){V=32852;break L36898}O=H+W|0;if((O|0)<0){N=512;break}else{S=g;T=O;U=0;V=32857;break L36898}}else{if((Q|0)<=(g|0)){V=32855;break L36898}O=Q+J|0;if((O|0)>(g|0)){N=256;break}else{S=g;T=O;U=16;V=32857;break L36898}}}}while(0);if((N|0)>(j|0)){V=32902;break L36896}else{K=N}}if((V|0)==32852){V=0;X=g;Y=P;Z=W;_=H+K-W|0}else if((V|0)==32855){V=0;X=g;Y=P;Z=Q;_=H+K-Q|0}else if((V|0)==32849){V=0;J=255-g|0;S=R-J|0;T=Q-J|0;U=P;V=32857}else if((V|0)==32847){V=0;$=P;aa=Q;ab=R;ac=K+1-Q+R|0;V=32858}if((V|0)==32857){V=0;J=K+1-T+S|0;if(F){$=U;aa=T;ab=S;ac=J;V=32858}else{X=S;Y=U;Z=T;_=J}}if((V|0)==32858){V=0;X=(ab|0)>(g|0)?g:ab;Y=$;Z=aa;_=ac}J=((L|-512)^511)+o|0;I=(X-Z|0)>(J|0)?J+Z|0:X;if((Z|0)>(I|0)){ad=B;ae=C}else{J=B;G=C;E=-1;O=s+((ag(q,(M<<1)-32|0)|0)+r)|0;af=Z;while(1){ah=d[f+(af+h)|0]|0;ai=(ah>>>4)+Y|0;do{if((ai|0)==(E|0)){aj=E;ak=G;al=J}else{am=ai<<1;an=e[u+((am|1)<<1)>>1]|0;ao=(an<<12&983040|(e[u+(am<<1)>>1]|0))&v;do{if((an&8|0)==0){if((an&4|0)==0){ap=ao;break}ap=w|ao&1048572}else{ap=A|ao&1048568}}while(0);ao=a[x+ap|0]|0;am=ao&255;if(ao<<24>>24!=0){aj=ai;ak=am;al=an;break}c[2385344]=y+(ap<<7);c[2440392]=z+((an>>>4&4080)<<2);aj=ai;ak=am;al=an}}while(0);do{if((ak|0)==0){ai=ah<<1&30;am=(al&2|0)==0?ai:ai^30;ai=c[2385344]|0;ao=c[ai+(am<<2)>>2]|0;aq=ao>>>8&15;ar=(aq|0)==0;if((al&1|0)==0){if(!ar){b[O>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}as=ao>>>16&15;if((as|0)!=0){b[O+2>>1]=c[(c[2440392]|0)+(as<<2)>>2]&65535}as=ao>>>24&15;if((as|0)!=0){b[O+4>>1]=c[(c[2440392]|0)+(as<<2)>>2]&65535}as=c[ai+((am|1)<<2)>>2]|0;at=as&15;if((at|0)!=0){b[O+6>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535}at=as>>>8&15;if((at|0)!=0){b[O+8>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535}at=as>>>16&15;if((at|0)!=0){b[O+10>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535}at=as>>>24&15;if((at|0)==0){break}b[O+12>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535;break}else{if(!ar){b[O+12>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}aq=ao>>>16&15;if((aq|0)!=0){b[O+10>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}aq=ao>>>24&15;if((aq|0)!=0){b[O+8>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}aq=c[ai+((am|1)<<2)>>2]|0;am=aq&15;if((am|0)!=0){b[O+6>>1]=c[(c[2440392]|0)+(am<<2)>>2]&65535}am=aq>>>8&15;if((am|0)!=0){b[O+4>>1]=c[(c[2440392]|0)+(am<<2)>>2]&65535}am=aq>>>16&15;if((am|0)!=0){b[O+2>>1]=c[(c[2440392]|0)+(am<<2)>>2]&65535}am=aq>>>24&15;if((am|0)==0){break}b[O>>1]=c[(c[2440392]|0)+(am<<2)>>2]&65535;break}}}while(0);ah=af+1|0;if((ah|0)>(I|0)){ad=al;ae=ak;break}else{J=al;G=ak;E=aj;O=O+t|0;af=ah}}}if((_|0)>(j|0)){V=32900;break}else{B=ad;C=ae;D=_}}if((V|0)==32900){return}else if((V|0)==32902){return}}function cyF(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0;f=c[3540994]|0;g=c[3528548]|0;h=g<<8;i=c[2385554]|0;do{if((i|0)>31){j=511}else{k=(i<<4)-1|0;if((k|0)>=0){j=k;break}return}}while(0);k=(j|0)>255;l=j&255;m=c[2385550]|0;n=c[2113042]|0;o=c[2113044]|0;p=n+512|0;q=c[2113132]|0;r=c[2385552]<<1;s=c[2112968]|0;t=q<<1;u=c[2415160]|0;v=c[2429858]|0;w=c[2430428]|0;x=c[2429718]|0;y=c[2430092]|0;z=c[3541046]|0;A=c[2430426]|0;B=0;C=0;D=0;L36993:while(1){E=(i|0)>16&(g|0)!=255;F=(i|0)<33;G=511-g|0;H=g+1|0;I=g-255|0;J=~g;K=D;L36995:while(1){L=K+m|0;M=L&511;do{if((M|0)<(n|0)){N=K+n-M|0}else{if((M|0)>=(o|0)){N=p+K-M|0;break}O=(K|0)>255;P=O?16:0;Q=K&255;R=(K|0)<256&k?255:l;if(!E){S=R;T=Q;U=P;V=32926;break L36995}if(F){if(!O){V=32916;break L36995}if((K|0)<(G|0)){N=G;break}else{V=32918;break L36995}}if(O){W=I+Q|0;if((W|0)>=0){V=32921;break L36995}O=H+W|0;if((O|0)<0){N=512;break}else{S=g;T=O;U=0;V=32926;break L36995}}else{if((Q|0)<=(g|0)){V=32924;break L36995}O=Q+J|0;if((O|0)>(g|0)){N=256;break}else{S=g;T=O;U=16;V=32926;break L36995}}}}while(0);if((N|0)>(j|0)){V=32975;break L36993}else{K=N}}if((V|0)==32916){V=0;X=P;Y=Q;Z=R;_=K+1-Q+R|0;V=32927}else if((V|0)==32924){V=0;$=g;aa=P;ab=Q;ac=H+K-Q|0}else if((V|0)==32918){V=0;J=255-g|0;S=R-J|0;T=Q-J|0;U=P;V=32926}else if((V|0)==32921){V=0;$=g;aa=P;ab=W;ac=H+K-W|0}if((V|0)==32926){V=0;J=K+1-T+S|0;if(F){X=U;Y=T;Z=S;_=J;V=32927}else{$=S;aa=U;ab=T;ac=J}}if((V|0)==32927){V=0;$=(Z|0)>(g|0)?g:Z;aa=X;ab=Y;ac=_}J=((L|-512)^511)+o|0;I=($-ab|0)>(J|0)?J+ab|0:$;if((ab|0)>(I|0)){ad=B;ae=C}else{J=B;G=C;E=-1;O=s+((ag(q,(M<<1)-32|0)|0)+r)|0;af=ab;while(1){ah=d[f+(af+h)|0]|0;ai=(ah>>>4)+aa|0;do{if((ai|0)==(E|0)){aj=E;ak=G;al=J}else{am=ai<<1;an=e[u+((am|1)<<1)>>1]|0;ao=(an<<12&983040|(e[u+(am<<1)>>1]|0))&v;do{if((an&8|0)==0){if((an&4|0)==0){ap=ao;break}ap=w|ao&1048572}else{ap=A|ao&1048568}}while(0);ao=a[x+ap|0]|0;am=ao&255;if(ao<<24>>24!=0){aj=ai;ak=am;al=an;break}c[2385344]=y+(ap<<7);c[2440392]=z+((an>>>4&4080)<<2);aj=ai;ak=am;al=an}}while(0);do{if((ak|0)==0){ai=ah<<1&30;am=(al&2|0)==0?ai:ai^30;ai=c[2385344]|0;ao=c[ai+(am<<2)>>2]|0;aq=ao&15;ar=(aq|0)==0;if((al&1|0)==0){if(!ar){b[O>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}as=ao>>>8&15;if((as|0)!=0){b[O+2>>1]=c[(c[2440392]|0)+(as<<2)>>2]&65535}as=ao>>>16&15;if((as|0)!=0){b[O+4>>1]=c[(c[2440392]|0)+(as<<2)>>2]&65535}as=ao>>>24&15;if((as|0)!=0){b[O+6>>1]=c[(c[2440392]|0)+(as<<2)>>2]&65535}as=c[ai+((am|1)<<2)>>2]|0;at=as&15;if((at|0)!=0){b[O+8>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535}at=as>>>8&15;if((at|0)!=0){b[O+10>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535}at=as>>>16&15;if((at|0)!=0){b[O+12>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535}at=as>>>24&15;if((at|0)==0){break}b[O+14>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535;break}else{if(!ar){b[O+14>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}aq=ao>>>8&15;if((aq|0)!=0){b[O+12>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}aq=ao>>>16&15;if((aq|0)!=0){b[O+10>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}aq=ao>>>24&15;if((aq|0)!=0){b[O+8>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}aq=c[ai+((am|1)<<2)>>2]|0;am=aq&15;if((am|0)!=0){b[O+6>>1]=c[(c[2440392]|0)+(am<<2)>>2]&65535}am=aq>>>8&15;if((am|0)!=0){b[O+4>>1]=c[(c[2440392]|0)+(am<<2)>>2]&65535}am=aq>>>16&15;if((am|0)!=0){b[O+2>>1]=c[(c[2440392]|0)+(am<<2)>>2]&65535}am=aq>>>24&15;if((am|0)==0){break}b[O>>1]=c[(c[2440392]|0)+(am<<2)>>2]&65535;break}}}while(0);ah=af+1|0;if((ah|0)>(I|0)){ad=al;ae=ak;break}else{J=al;G=ak;E=aj;O=O+t|0;af=ah}}}if((ac|0)>(j|0)){V=32973;break}else{B=ad;C=ae;D=ac}}if((V|0)==32973){return}else if((V|0)==32975){return}}function cyG(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0;f=c[3540994]|0;g=c[3528548]|0;h=g<<8;i=c[2385554]|0;do{if((i|0)>31){j=511}else{k=(i<<4)-1|0;if((k|0)>=0){j=k;break}return}}while(0);k=(j|0)>255;l=j&255;m=c[2385550]|0;n=c[2113042]|0;o=c[2113044]|0;p=n+512|0;q=c[2113132]|0;r=c[2385552]<<1;s=c[2112968]|0;t=q<<1;u=c[2415160]|0;v=c[2429858]|0;w=c[2430428]|0;x=c[2429718]|0;y=c[2430092]|0;z=c[3541046]|0;A=c[2430426]|0;B=0;C=0;D=0;L37096:while(1){E=(i|0)>16&(g|0)!=255;F=(i|0)<33;G=511-g|0;H=g+1|0;I=g-255|0;J=~g;K=D;L37098:while(1){L=K+m|0;M=L&511;do{if((M|0)<(n|0)){N=K+n-M|0}else{if((M|0)>=(o|0)){N=p+K-M|0;break}O=(K|0)>255;P=O?16:0;Q=K&255;R=(K|0)<256&k?255:l;if(!E){S=R;T=Q;U=P;V=32999;break L37098}if(F){if(!O){V=32989;break L37098}if((K|0)<(G|0)){N=G;break}else{V=32991;break L37098}}if(O){W=I+Q|0;if((W|0)>=0){V=32994;break L37098}O=H+W|0;if((O|0)<0){N=512;break}else{S=g;T=O;U=0;V=32999;break L37098}}else{if((Q|0)<=(g|0)){V=32997;break L37098}O=Q+J|0;if((O|0)>(g|0)){N=256;break}else{S=g;T=O;U=16;V=32999;break L37098}}}}while(0);if((N|0)>(j|0)){V=33052;break L37096}else{K=N}}if((V|0)==32991){V=0;J=255-g|0;S=R-J|0;T=Q-J|0;U=P;V=32999}else if((V|0)==32989){V=0;X=P;Y=Q;Z=R;_=K+1-Q+R|0;V=33e3}else if((V|0)==32994){V=0;$=g;aa=P;ab=W;ac=H+K-W|0}else if((V|0)==32997){V=0;$=g;aa=P;ab=Q;ac=H+K-Q|0}if((V|0)==32999){V=0;J=K+1-T+S|0;if(F){X=U;Y=T;Z=S;_=J;V=33e3}else{$=S;aa=U;ab=T;ac=J}}if((V|0)==33e3){V=0;$=(Z|0)>(g|0)?g:Z;aa=X;ab=Y;ac=_}J=((L|-512)^511)+o|0;I=($-ab|0)>(J|0)?J+ab|0:$;if((ab|0)>(I|0)){ad=B;ae=C}else{J=B;G=C;E=-1;O=s+((ag(q,(M<<1)-32|0)|0)+r)|0;af=ab;while(1){ah=d[f+(af+h)|0]|0;ai=(ah>>>4)+aa|0;do{if((ai|0)==(E|0)){aj=E;ak=G;al=J}else{am=ai<<1;an=e[u+((am|1)<<1)>>1]|0;ao=(an<<12&983040|(e[u+(am<<1)>>1]|0))&v;do{if((an&8|0)==0){if((an&4|0)==0){ap=ao;break}ap=w|ao&1048572}else{ap=A|ao&1048568}}while(0);ao=a[x+ap|0]|0;am=ao&255;if(ao<<24>>24!=0){aj=ai;ak=am;al=an;break}c[2385344]=y+(ap<<7);c[2440392]=z+((an>>>4&4080)<<2);aj=ai;ak=am;al=an}}while(0);do{if((ak|0)==0){ai=ah<<1&30;am=(al&2|0)==0?ai:ai^30;ai=c[2385344]|0;ao=c[ai+(am<<2)>>2]|0;aq=ao&15;ar=(aq|0)==0;if((al&1|0)==0){if(!ar){b[O>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}as=ao>>>8&15;if((as|0)!=0){b[O+2>>1]=c[(c[2440392]|0)+(as<<2)>>2]&65535}as=ao>>>16&15;if((as|0)!=0){b[O+4>>1]=c[(c[2440392]|0)+(as<<2)>>2]&65535}as=ao>>>24&15;if((as|0)!=0){b[O+6>>1]=c[(c[2440392]|0)+(as<<2)>>2]&65535}as=c[ai+((am|1)<<2)>>2]|0;at=as&15;if((at|0)!=0){b[O+8>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535}at=as>>>4&15;if((at|0)!=0){b[O+10>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535}at=as>>>8&15;if((at|0)!=0){b[O+12>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535}at=as>>>16&15;if((at|0)!=0){b[O+14>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535}at=as>>>24&15;if((at|0)==0){break}b[O+16>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535;break}else{if(!ar){b[O+16>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}aq=ao>>>8&15;if((aq|0)!=0){b[O+14>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}aq=ao>>>16&15;if((aq|0)!=0){b[O+12>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}aq=ao>>>24&15;if((aq|0)!=0){b[O+10>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}aq=c[ai+((am|1)<<2)>>2]|0;am=aq&15;if((am|0)!=0){b[O+8>>1]=c[(c[2440392]|0)+(am<<2)>>2]&65535}am=aq>>>4&15;if((am|0)!=0){b[O+6>>1]=c[(c[2440392]|0)+(am<<2)>>2]&65535}am=aq>>>8&15;if((am|0)!=0){b[O+4>>1]=c[(c[2440392]|0)+(am<<2)>>2]&65535}am=aq>>>16&15;if((am|0)!=0){b[O+2>>1]=c[(c[2440392]|0)+(am<<2)>>2]&65535}am=aq>>>24&15;if((am|0)==0){break}b[O>>1]=c[(c[2440392]|0)+(am<<2)>>2]&65535;break}}}while(0);ah=af+1|0;if((ah|0)>(I|0)){ad=al;ae=ak;break}else{J=al;G=ak;E=aj;O=O+t|0;af=ah}}}if((ac|0)>(j|0)){V=33051;break}else{B=ad;C=ae;D=ac}}if((V|0)==33051){return}else if((V|0)==33052){return}}function cyH(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0;f=c[3540994]|0;g=c[3528548]|0;h=g<<8;i=c[2385554]|0;do{if((i|0)>31){j=511}else{k=(i<<4)-1|0;if((k|0)>=0){j=k;break}return}}while(0);k=(j|0)>255;l=j&255;m=c[2385550]|0;n=c[2113042]|0;o=c[2113044]|0;p=n+512|0;q=c[2113132]|0;r=c[2385552]<<1;s=c[2112968]|0;t=q<<1;u=c[2415160]|0;v=c[2429858]|0;w=c[2430428]|0;x=c[2429718]|0;y=c[2430092]|0;z=c[3541046]|0;A=c[2430426]|0;B=0;C=0;D=0;L37205:while(1){E=(i|0)>16&(g|0)!=255;F=(i|0)<33;G=511-g|0;H=g+1|0;I=g-255|0;J=~g;K=D;L37207:while(1){L=K+m|0;M=L&511;do{if((M|0)<(n|0)){N=K+n-M|0}else{if((M|0)>=(o|0)){N=p+K-M|0;break}O=(K|0)>255;P=O?16:0;Q=K&255;R=(K|0)<256&k?255:l;if(!E){S=R;T=Q;U=P;V=33076;break L37207}if(F){if(!O){V=33066;break L37207}if((K|0)<(G|0)){N=G;break}else{V=33068;break L37207}}if(O){W=I+Q|0;if((W|0)>=0){V=33071;break L37207}O=H+W|0;if((O|0)<0){N=512;break}else{S=g;T=O;U=0;V=33076;break L37207}}else{if((Q|0)<=(g|0)){V=33074;break L37207}O=Q+J|0;if((O|0)>(g|0)){N=256;break}else{S=g;T=O;U=16;V=33076;break L37207}}}}while(0);if((N|0)>(j|0)){V=33133;break L37205}else{K=N}}if((V|0)==33068){V=0;J=255-g|0;S=R-J|0;T=Q-J|0;U=P;V=33076}else if((V|0)==33066){V=0;X=P;Y=Q;Z=R;_=K+1-Q+R|0;V=33077}else if((V|0)==33071){V=0;$=g;aa=P;ab=W;ac=H+K-W|0}else if((V|0)==33074){V=0;$=g;aa=P;ab=Q;ac=H+K-Q|0}if((V|0)==33076){V=0;J=K+1-T+S|0;if(F){X=U;Y=T;Z=S;_=J;V=33077}else{$=S;aa=U;ab=T;ac=J}}if((V|0)==33077){V=0;$=(Z|0)>(g|0)?g:Z;aa=X;ab=Y;ac=_}J=((L|-512)^511)+o|0;I=($-ab|0)>(J|0)?J+ab|0:$;if((ab|0)>(I|0)){ad=B;ae=C}else{J=B;G=C;E=-1;O=s+((ag(q,(M<<1)-32|0)|0)+r)|0;af=ab;while(1){ah=d[f+(af+h)|0]|0;ai=(ah>>>4)+aa|0;do{if((ai|0)==(E|0)){aj=E;ak=G;al=J}else{am=ai<<1;an=e[u+((am|1)<<1)>>1]|0;ao=(an<<12&983040|(e[u+(am<<1)>>1]|0))&v;do{if((an&8|0)==0){if((an&4|0)==0){ap=ao;break}ap=w|ao&1048572}else{ap=A|ao&1048568}}while(0);ao=a[x+ap|0]|0;am=ao&255;if(ao<<24>>24!=0){aj=ai;ak=am;al=an;break}c[2385344]=y+(ap<<7);c[2440392]=z+((an>>>4&4080)<<2);aj=ai;ak=am;al=an}}while(0);do{if((ak|0)==0){ai=ah<<1&30;am=(al&2|0)==0?ai:ai^30;ai=c[2385344]|0;ao=c[ai+(am<<2)>>2]|0;aq=ao&15;ar=(aq|0)==0;if((al&1|0)==0){if(!ar){b[O>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}as=ao>>>8&15;if((as|0)!=0){b[O+2>>1]=c[(c[2440392]|0)+(as<<2)>>2]&65535}as=ao>>>12&15;if((as|0)!=0){b[O+4>>1]=c[(c[2440392]|0)+(as<<2)>>2]&65535}as=ao>>>16&15;if((as|0)!=0){b[O+6>>1]=c[(c[2440392]|0)+(as<<2)>>2]&65535}as=ao>>>24&15;if((as|0)!=0){b[O+8>>1]=c[(c[2440392]|0)+(as<<2)>>2]&65535}as=c[ai+((am|1)<<2)>>2]|0;at=as&15;if((at|0)!=0){b[O+10>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535}at=as>>>4&15;if((at|0)!=0){b[O+12>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535}at=as>>>8&15;if((at|0)!=0){b[O+14>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535}at=as>>>16&15;if((at|0)!=0){b[O+16>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535}at=as>>>24&15;if((at|0)==0){break}b[O+18>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535;break}else{if(!ar){b[O+18>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}aq=ao>>>8&15;if((aq|0)!=0){b[O+16>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}aq=ao>>>12&15;if((aq|0)!=0){b[O+14>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}aq=ao>>>16&15;if((aq|0)!=0){b[O+12>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}aq=ao>>>24&15;if((aq|0)!=0){b[O+10>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}aq=c[ai+((am|1)<<2)>>2]|0;am=aq&15;if((am|0)!=0){b[O+8>>1]=c[(c[2440392]|0)+(am<<2)>>2]&65535}am=aq>>>4&15;if((am|0)!=0){b[O+6>>1]=c[(c[2440392]|0)+(am<<2)>>2]&65535}am=aq>>>8&15;if((am|0)!=0){b[O+4>>1]=c[(c[2440392]|0)+(am<<2)>>2]&65535}am=aq>>>16&15;if((am|0)!=0){b[O+2>>1]=c[(c[2440392]|0)+(am<<2)>>2]&65535}am=aq>>>24&15;if((am|0)==0){break}b[O>>1]=c[(c[2440392]|0)+(am<<2)>>2]&65535;break}}}while(0);ah=af+1|0;if((ah|0)>(I|0)){ad=al;ae=ak;break}else{J=al;G=ak;E=aj;O=O+t|0;af=ah}}}if((ac|0)>(j|0)){V=33131;break}else{B=ad;C=ae;D=ac}}if((V|0)==33131){return}else if((V|0)==33133){return}}function cyI(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0;f=c[3540994]|0;g=c[3528548]|0;h=g<<8;i=c[2385554]|0;do{if((i|0)>31){j=511}else{k=(i<<4)-1|0;if((k|0)>=0){j=k;break}return}}while(0);k=(j|0)>255;l=j&255;m=c[2385550]|0;n=c[2113042]|0;o=c[2113044]|0;p=n+512|0;q=c[2113132]|0;r=c[2385552]<<1;s=c[2112968]|0;t=q<<1;u=c[2415160]|0;v=c[2429858]|0;w=c[2430428]|0;x=c[2429718]|0;y=c[2430092]|0;z=c[3541046]|0;A=c[2430426]|0;B=0;C=0;D=0;L37320:while(1){E=(i|0)>16&(g|0)!=255;F=(i|0)<33;G=511-g|0;H=g+1|0;I=g-255|0;J=~g;K=D;L37322:while(1){L=K+m|0;M=L&511;do{if((M|0)<(n|0)){N=K+n-M|0}else{if((M|0)>=(o|0)){N=p+K-M|0;break}O=(K|0)>255;P=O?16:0;Q=K&255;R=(K|0)<256&k?255:l;if(!E){S=R;T=Q;U=P;V=33157;break L37322}if(F){if(!O){V=33147;break L37322}if((K|0)<(G|0)){N=G;break}else{V=33149;break L37322}}if(O){W=I+Q|0;if((W|0)>=0){V=33152;break L37322}O=H+W|0;if((O|0)<0){N=512;break}else{S=g;T=O;U=0;V=33157;break L37322}}else{if((Q|0)<=(g|0)){V=33155;break L37322}O=Q+J|0;if((O|0)>(g|0)){N=256;break}else{S=g;T=O;U=16;V=33157;break L37322}}}}while(0);if((N|0)>(j|0)){V=33218;break L37320}else{K=N}}if((V|0)==33152){V=0;X=g;Y=P;Z=W;_=H+K-W|0}else if((V|0)==33147){V=0;$=P;aa=Q;ab=R;ac=K+1-Q+R|0;V=33158}else if((V|0)==33149){V=0;J=255-g|0;S=R-J|0;T=Q-J|0;U=P;V=33157}else if((V|0)==33155){V=0;X=g;Y=P;Z=Q;_=H+K-Q|0}if((V|0)==33157){V=0;J=K+1-T+S|0;if(F){$=U;aa=T;ab=S;ac=J;V=33158}else{X=S;Y=U;Z=T;_=J}}if((V|0)==33158){V=0;X=(ab|0)>(g|0)?g:ab;Y=$;Z=aa;_=ac}J=((L|-512)^511)+o|0;I=(X-Z|0)>(J|0)?J+Z|0:X;if((Z|0)>(I|0)){ad=B;ae=C}else{J=B;G=C;E=-1;O=s+((ag(q,(M<<1)-32|0)|0)+r)|0;af=Z;while(1){ah=d[f+(af+h)|0]|0;ai=(ah>>>4)+Y|0;do{if((ai|0)==(E|0)){aj=E;ak=G;al=J}else{am=ai<<1;an=e[u+((am|1)<<1)>>1]|0;ao=(an<<12&983040|(e[u+(am<<1)>>1]|0))&v;do{if((an&8|0)==0){if((an&4|0)==0){ap=ao;break}ap=w|ao&1048572}else{ap=A|ao&1048568}}while(0);ao=a[x+ap|0]|0;am=ao&255;if(ao<<24>>24!=0){aj=ai;ak=am;al=an;break}c[2385344]=y+(ap<<7);c[2440392]=z+((an>>>4&4080)<<2);aj=ai;ak=am;al=an}}while(0);do{if((ak|0)==0){ai=ah<<1&30;am=(al&2|0)==0?ai:ai^30;ai=c[2385344]|0;ao=c[ai+(am<<2)>>2]|0;aq=ao&15;ar=(aq|0)==0;if((al&1|0)==0){if(!ar){b[O>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}as=ao>>>8&15;if((as|0)!=0){b[O+2>>1]=c[(c[2440392]|0)+(as<<2)>>2]&65535}as=ao>>>12&15;if((as|0)!=0){b[O+4>>1]=c[(c[2440392]|0)+(as<<2)>>2]&65535}as=ao>>>16&15;if((as|0)!=0){b[O+6>>1]=c[(c[2440392]|0)+(as<<2)>>2]&65535}as=ao>>>24&15;if((as|0)!=0){b[O+8>>1]=c[(c[2440392]|0)+(as<<2)>>2]&65535}as=c[ai+((am|1)<<2)>>2]|0;at=as&15;if((at|0)!=0){b[O+10>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535}at=as>>>4&15;if((at|0)!=0){b[O+12>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535}at=as>>>8&15;if((at|0)!=0){b[O+14>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535}at=as>>>16&15;if((at|0)!=0){b[O+16>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535}at=as>>>24&15;if((at|0)!=0){b[O+18>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535}at=as>>>28;if((at|0)==0){break}b[O+20>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535;break}else{if(!ar){b[O+20>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}aq=ao>>>8&15;if((aq|0)!=0){b[O+18>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}aq=ao>>>12&15;if((aq|0)!=0){b[O+16>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}aq=ao>>>16&15;if((aq|0)!=0){b[O+14>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}aq=ao>>>24&15;if((aq|0)!=0){b[O+12>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}aq=c[ai+((am|1)<<2)>>2]|0;am=aq&15;if((am|0)!=0){b[O+10>>1]=c[(c[2440392]|0)+(am<<2)>>2]&65535}am=aq>>>4&15;if((am|0)!=0){b[O+8>>1]=c[(c[2440392]|0)+(am<<2)>>2]&65535}am=aq>>>8&15;if((am|0)!=0){b[O+6>>1]=c[(c[2440392]|0)+(am<<2)>>2]&65535}am=aq>>>16&15;if((am|0)!=0){b[O+4>>1]=c[(c[2440392]|0)+(am<<2)>>2]&65535}am=aq>>>24&15;if((am|0)!=0){b[O+2>>1]=c[(c[2440392]|0)+(am<<2)>>2]&65535}am=aq>>>28;if((am|0)==0){break}b[O>>1]=c[(c[2440392]|0)+(am<<2)>>2]&65535;break}}}while(0);ah=af+1|0;if((ah|0)>(I|0)){ad=al;ae=ak;break}else{J=al;G=ak;E=aj;O=O+t|0;af=ah}}}if((_|0)>(j|0)){V=33217;break}else{B=ad;C=ae;D=_}}if((V|0)==33217){return}else if((V|0)==33218){return}}function cyJ(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0;f=c[3540994]|0;g=c[3528548]|0;h=g<<8;i=c[2385554]|0;do{if((i|0)>31){j=511}else{k=(i<<4)-1|0;if((k|0)>=0){j=k;break}return}}while(0);k=(j|0)>255;l=j&255;m=c[2385550]|0;n=c[2113042]|0;o=c[2113044]|0;p=n+512|0;q=c[2113132]|0;r=c[2385552]<<1;s=c[2112968]|0;t=q<<1;u=c[2415160]|0;v=c[2429858]|0;w=c[2430428]|0;x=c[2429718]|0;y=c[2430092]|0;z=c[3541046]|0;A=c[2430426]|0;B=0;C=0;D=0;L37441:while(1){E=(i|0)>16&(g|0)!=255;F=(i|0)<33;G=511-g|0;H=g+1|0;I=g-255|0;J=~g;K=D;L37443:while(1){L=K+m|0;M=L&511;do{if((M|0)<(n|0)){N=K+n-M|0}else{if((M|0)>=(o|0)){N=p+K-M|0;break}O=(K|0)>255;P=O?16:0;Q=K&255;R=(K|0)<256&k?255:l;if(!E){S=R;T=Q;U=P;V=33242;break L37443}if(F){if(!O){V=33232;break L37443}if((K|0)<(G|0)){N=G;break}else{V=33234;break L37443}}if(O){W=I+Q|0;if((W|0)>=0){V=33237;break L37443}O=H+W|0;if((O|0)<0){N=512;break}else{S=g;T=O;U=0;V=33242;break L37443}}else{if((Q|0)<=(g|0)){V=33240;break L37443}O=Q+J|0;if((O|0)>(g|0)){N=256;break}else{S=g;T=O;U=16;V=33242;break L37443}}}}while(0);if((N|0)>(j|0)){V=33307;break L37441}else{K=N}}if((V|0)==33237){V=0;X=g;Y=P;Z=W;_=H+K-W|0}else if((V|0)==33234){V=0;J=255-g|0;S=R-J|0;T=Q-J|0;U=P;V=33242}else if((V|0)==33232){V=0;$=P;aa=Q;ab=R;ac=K+1-Q+R|0;V=33243}else if((V|0)==33240){V=0;X=g;Y=P;Z=Q;_=H+K-Q|0}if((V|0)==33242){V=0;J=K+1-T+S|0;if(F){$=U;aa=T;ab=S;ac=J;V=33243}else{X=S;Y=U;Z=T;_=J}}if((V|0)==33243){V=0;X=(ab|0)>(g|0)?g:ab;Y=$;Z=aa;_=ac}J=((L|-512)^511)+o|0;I=(X-Z|0)>(J|0)?J+Z|0:X;if((Z|0)>(I|0)){ad=B;ae=C}else{J=B;G=C;E=-1;O=s+((ag(q,(M<<1)-32|0)|0)+r)|0;af=Z;while(1){ah=d[f+(af+h)|0]|0;ai=(ah>>>4)+Y|0;do{if((ai|0)==(E|0)){aj=E;ak=G;al=J}else{am=ai<<1;an=e[u+((am|1)<<1)>>1]|0;ao=(an<<12&983040|(e[u+(am<<1)>>1]|0))&v;do{if((an&8|0)==0){if((an&4|0)==0){ap=ao;break}ap=w|ao&1048572}else{ap=A|ao&1048568}}while(0);ao=a[x+ap|0]|0;am=ao&255;if(ao<<24>>24!=0){aj=ai;ak=am;al=an;break}c[2385344]=y+(ap<<7);c[2440392]=z+((an>>>4&4080)<<2);aj=ai;ak=am;al=an}}while(0);do{if((ak|0)==0){ai=ah<<1&30;am=(al&2|0)==0?ai:ai^30;ai=c[2385344]|0;ao=c[ai+(am<<2)>>2]|0;aq=ao&15;ar=(aq|0)==0;if((al&1|0)==0){if(!ar){b[O>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}as=ao>>>8&15;if((as|0)!=0){b[O+2>>1]=c[(c[2440392]|0)+(as<<2)>>2]&65535}as=ao>>>12&15;if((as|0)!=0){b[O+4>>1]=c[(c[2440392]|0)+(as<<2)>>2]&65535}as=ao>>>16&15;if((as|0)!=0){b[O+6>>1]=c[(c[2440392]|0)+(as<<2)>>2]&65535}as=ao>>>24&15;if((as|0)!=0){b[O+8>>1]=c[(c[2440392]|0)+(as<<2)>>2]&65535}as=ao>>>28;if((as|0)!=0){b[O+10>>1]=c[(c[2440392]|0)+(as<<2)>>2]&65535}as=c[ai+((am|1)<<2)>>2]|0;at=as&15;if((at|0)!=0){b[O+12>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535}at=as>>>4&15;if((at|0)!=0){b[O+14>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535}at=as>>>8&15;if((at|0)!=0){b[O+16>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535}at=as>>>16&15;if((at|0)!=0){b[O+18>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535}at=as>>>24&15;if((at|0)!=0){b[O+20>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535}at=as>>>28;if((at|0)==0){break}b[O+22>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535;break}else{if(!ar){b[O+22>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}aq=ao>>>8&15;if((aq|0)!=0){b[O+20>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}aq=ao>>>12&15;if((aq|0)!=0){b[O+18>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}aq=ao>>>16&15;if((aq|0)!=0){b[O+16>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}aq=ao>>>24&15;if((aq|0)!=0){b[O+14>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}aq=ao>>>28;if((aq|0)!=0){b[O+12>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}aq=c[ai+((am|1)<<2)>>2]|0;am=aq&15;if((am|0)!=0){b[O+10>>1]=c[(c[2440392]|0)+(am<<2)>>2]&65535}am=aq>>>4&15;if((am|0)!=0){b[O+8>>1]=c[(c[2440392]|0)+(am<<2)>>2]&65535}am=aq>>>8&15;if((am|0)!=0){b[O+6>>1]=c[(c[2440392]|0)+(am<<2)>>2]&65535}am=aq>>>16&15;if((am|0)!=0){b[O+4>>1]=c[(c[2440392]|0)+(am<<2)>>2]&65535}am=aq>>>24&15;if((am|0)!=0){b[O+2>>1]=c[(c[2440392]|0)+(am<<2)>>2]&65535}am=aq>>>28;if((am|0)==0){break}b[O>>1]=c[(c[2440392]|0)+(am<<2)>>2]&65535;break}}}while(0);ah=af+1|0;if((ah|0)>(I|0)){ad=al;ae=ak;break}else{J=al;G=ak;E=aj;O=O+t|0;af=ah}}}if((_|0)>(j|0)){V=33305;break}else{B=ad;C=ae;D=_}}if((V|0)==33305){return}else if((V|0)==33307){return}}function cyK(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0;f=c[3540994]|0;g=c[3528548]|0;h=g<<8;i=c[2385554]|0;do{if((i|0)>31){j=511}else{k=(i<<4)-1|0;if((k|0)>=0){j=k;break}return}}while(0);k=(j|0)>255;l=j&255;m=c[2385550]|0;n=c[2113042]|0;o=c[2113044]|0;p=n+512|0;q=c[2113132]|0;r=c[2385552]<<1;s=c[2112968]|0;t=q<<1;u=c[2415160]|0;v=c[2429858]|0;w=c[2430428]|0;x=c[2429718]|0;y=c[2430092]|0;z=c[3541046]|0;A=c[2430426]|0;B=0;C=0;D=0;L37568:while(1){E=(i|0)>16&(g|0)!=255;F=(i|0)<33;G=511-g|0;H=g+1|0;I=g-255|0;J=~g;K=D;L37570:while(1){L=K+m|0;M=L&511;do{if((M|0)<(n|0)){N=K+n-M|0}else{if((M|0)>=(o|0)){N=p+K-M|0;break}O=(K|0)>255;P=O?16:0;Q=K&255;R=(K|0)<256&k?255:l;if(!E){S=R;T=Q;U=P;V=33331;break L37570}if(F){if(!O){V=33321;break L37570}if((K|0)<(G|0)){N=G;break}else{V=33323;break L37570}}if(O){W=I+Q|0;if((W|0)>=0){V=33326;break L37570}O=H+W|0;if((O|0)<0){N=512;break}else{S=g;T=O;U=0;V=33331;break L37570}}else{if((Q|0)<=(g|0)){V=33329;break L37570}O=Q+J|0;if((O|0)>(g|0)){N=256;break}else{S=g;T=O;U=16;V=33331;break L37570}}}}while(0);if((N|0)>(j|0)){V=33400;break L37568}else{K=N}}if((V|0)==33326){V=0;X=g;Y=P;Z=W;_=H+K-W|0}else if((V|0)==33321){V=0;$=P;aa=Q;ab=R;ac=K+1-Q+R|0;V=33332}else if((V|0)==33329){V=0;X=g;Y=P;Z=Q;_=H+K-Q|0}else if((V|0)==33323){V=0;J=255-g|0;S=R-J|0;T=Q-J|0;U=P;V=33331}if((V|0)==33331){V=0;J=K+1-T+S|0;if(F){$=U;aa=T;ab=S;ac=J;V=33332}else{X=S;Y=U;Z=T;_=J}}if((V|0)==33332){V=0;X=(ab|0)>(g|0)?g:ab;Y=$;Z=aa;_=ac}J=((L|-512)^511)+o|0;I=(X-Z|0)>(J|0)?J+Z|0:X;if((Z|0)>(I|0)){ad=B;ae=C}else{J=B;G=C;E=-1;O=s+((ag(q,(M<<1)-32|0)|0)+r)|0;af=Z;while(1){ah=d[f+(af+h)|0]|0;ai=(ah>>>4)+Y|0;do{if((ai|0)==(E|0)){aj=E;ak=G;al=J}else{am=ai<<1;an=e[u+((am|1)<<1)>>1]|0;ao=(an<<12&983040|(e[u+(am<<1)>>1]|0))&v;do{if((an&8|0)==0){if((an&4|0)==0){ap=ao;break}ap=w|ao&1048572}else{ap=A|ao&1048568}}while(0);ao=a[x+ap|0]|0;am=ao&255;if(ao<<24>>24!=0){aj=ai;ak=am;al=an;break}c[2385344]=y+(ap<<7);c[2440392]=z+((an>>>4&4080)<<2);aj=ai;ak=am;al=an}}while(0);do{if((ak|0)==0){ai=ah<<1&30;am=(al&2|0)==0?ai:ai^30;ai=c[2385344]|0;ao=c[ai+(am<<2)>>2]|0;aq=ao&15;ar=(aq|0)==0;if((al&1|0)==0){if(!ar){b[O>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}as=ao>>>8&15;if((as|0)!=0){b[O+2>>1]=c[(c[2440392]|0)+(as<<2)>>2]&65535}as=ao>>>12&15;if((as|0)!=0){b[O+4>>1]=c[(c[2440392]|0)+(as<<2)>>2]&65535}as=ao>>>16&15;if((as|0)!=0){b[O+6>>1]=c[(c[2440392]|0)+(as<<2)>>2]&65535}as=ao>>>24&15;if((as|0)!=0){b[O+8>>1]=c[(c[2440392]|0)+(as<<2)>>2]&65535}as=ao>>>28;if((as|0)!=0){b[O+10>>1]=c[(c[2440392]|0)+(as<<2)>>2]&65535}as=c[ai+((am|1)<<2)>>2]|0;at=as&15;if((at|0)!=0){b[O+12>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535}at=as>>>4&15;if((at|0)!=0){b[O+14>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535}at=as>>>8&15;if((at|0)!=0){b[O+16>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535}at=as>>>16&15;if((at|0)!=0){b[O+18>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535}at=as>>>20&15;if((at|0)!=0){b[O+20>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535}at=as>>>24&15;if((at|0)!=0){b[O+22>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535}at=as>>>28;if((at|0)==0){break}b[O+24>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535;break}else{if(!ar){b[O+24>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}aq=ao>>>8&15;if((aq|0)!=0){b[O+22>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}aq=ao>>>12&15;if((aq|0)!=0){b[O+20>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}aq=ao>>>16&15;if((aq|0)!=0){b[O+18>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}aq=ao>>>24&15;if((aq|0)!=0){b[O+16>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}aq=ao>>>28;if((aq|0)!=0){b[O+14>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}aq=c[ai+((am|1)<<2)>>2]|0;am=aq&15;if((am|0)!=0){b[O+12>>1]=c[(c[2440392]|0)+(am<<2)>>2]&65535}am=aq>>>4&15;if((am|0)!=0){b[O+10>>1]=c[(c[2440392]|0)+(am<<2)>>2]&65535}am=aq>>>8&15;if((am|0)!=0){b[O+8>>1]=c[(c[2440392]|0)+(am<<2)>>2]&65535}am=aq>>>16&15;if((am|0)!=0){b[O+6>>1]=c[(c[2440392]|0)+(am<<2)>>2]&65535}am=aq>>>20&15;if((am|0)!=0){b[O+4>>1]=c[(c[2440392]|0)+(am<<2)>>2]&65535}am=aq>>>24&15;if((am|0)!=0){b[O+2>>1]=c[(c[2440392]|0)+(am<<2)>>2]&65535}am=aq>>>28;if((am|0)==0){break}b[O>>1]=c[(c[2440392]|0)+(am<<2)>>2]&65535;break}}}while(0);ah=af+1|0;if((ah|0)>(I|0)){ad=al;ae=ak;break}else{J=al;G=ak;E=aj;O=O+t|0;af=ah}}}if((_|0)>(j|0)){V=33399;break}else{B=ad;C=ae;D=_}}if((V|0)==33399){return}else if((V|0)==33400){return}}function cyL(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0;f=c[3540994]|0;g=c[3528548]|0;h=g<<8;i=c[2385554]|0;do{if((i|0)>31){j=511}else{k=(i<<4)-1|0;if((k|0)>=0){j=k;break}return}}while(0);k=(j|0)>255;l=j&255;m=c[2385550]|0;n=c[2113042]|0;o=c[2113044]|0;p=n+512|0;q=c[2113132]|0;r=c[2385552]<<1;s=c[2112968]|0;t=q<<1;u=c[2415160]|0;v=c[2429858]|0;w=c[2430428]|0;x=c[2429718]|0;y=c[2430092]|0;z=c[3541046]|0;A=c[2430426]|0;B=0;C=0;D=0;L37701:while(1){E=(i|0)>16&(g|0)!=255;F=(i|0)<33;G=511-g|0;H=g+1|0;I=g-255|0;J=~g;K=D;L37703:while(1){L=K+m|0;M=L&511;do{if((M|0)<(n|0)){N=K+n-M|0}else{if((M|0)>=(o|0)){N=p+K-M|0;break}O=(K|0)>255;P=O?16:0;Q=K&255;R=(K|0)<256&k?255:l;if(!E){S=R;T=Q;U=P;V=33424;break L37703}if(F){if(!O){V=33414;break L37703}if((K|0)<(G|0)){N=G;break}else{V=33416;break L37703}}if(O){W=I+Q|0;if((W|0)>=0){V=33419;break L37703}O=H+W|0;if((O|0)<0){N=512;break}else{S=g;T=O;U=0;V=33424;break L37703}}else{if((Q|0)<=(g|0)){V=33422;break L37703}O=Q+J|0;if((O|0)>(g|0)){N=256;break}else{S=g;T=O;U=16;V=33424;break L37703}}}}while(0);if((N|0)>(j|0)){V=33497;break L37701}else{K=N}}if((V|0)==33416){V=0;J=255-g|0;S=R-J|0;T=Q-J|0;U=P;V=33424}else if((V|0)==33414){V=0;X=P;Y=Q;Z=R;_=K+1-Q+R|0;V=33425}else if((V|0)==33419){V=0;$=g;aa=P;ab=W;ac=H+K-W|0}else if((V|0)==33422){V=0;$=g;aa=P;ab=Q;ac=H+K-Q|0}if((V|0)==33424){V=0;J=K+1-T+S|0;if(F){X=U;Y=T;Z=S;_=J;V=33425}else{$=S;aa=U;ab=T;ac=J}}if((V|0)==33425){V=0;$=(Z|0)>(g|0)?g:Z;aa=X;ab=Y;ac=_}J=((L|-512)^511)+o|0;I=($-ab|0)>(J|0)?J+ab|0:$;if((ab|0)>(I|0)){ad=B;ae=C}else{J=B;G=C;E=-1;O=s+((ag(q,(M<<1)-32|0)|0)+r)|0;af=ab;while(1){ah=d[f+(af+h)|0]|0;ai=(ah>>>4)+aa|0;do{if((ai|0)==(E|0)){aj=E;ak=G;al=J}else{am=ai<<1;an=e[u+((am|1)<<1)>>1]|0;ao=(an<<12&983040|(e[u+(am<<1)>>1]|0))&v;do{if((an&8|0)==0){if((an&4|0)==0){ap=ao;break}ap=w|ao&1048572}else{ap=A|ao&1048568}}while(0);ao=a[x+ap|0]|0;am=ao&255;if(ao<<24>>24!=0){aj=ai;ak=am;al=an;break}c[2385344]=y+(ap<<7);c[2440392]=z+((an>>>4&4080)<<2);aj=ai;ak=am;al=an}}while(0);do{if((ak|0)==0){ai=ah<<1&30;am=(al&2|0)==0?ai:ai^30;ai=c[2385344]|0;ao=c[ai+(am<<2)>>2]|0;aq=ao&15;ar=(aq|0)==0;if((al&1|0)==0){if(!ar){b[O>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}as=ao>>>4&15;if((as|0)!=0){b[O+2>>1]=c[(c[2440392]|0)+(as<<2)>>2]&65535}as=ao>>>8&15;if((as|0)!=0){b[O+4>>1]=c[(c[2440392]|0)+(as<<2)>>2]&65535}as=ao>>>12&15;if((as|0)!=0){b[O+6>>1]=c[(c[2440392]|0)+(as<<2)>>2]&65535}as=ao>>>16&15;if((as|0)!=0){b[O+8>>1]=c[(c[2440392]|0)+(as<<2)>>2]&65535}as=ao>>>24&15;if((as|0)!=0){b[O+10>>1]=c[(c[2440392]|0)+(as<<2)>>2]&65535}as=ao>>>28;if((as|0)!=0){b[O+12>>1]=c[(c[2440392]|0)+(as<<2)>>2]&65535}as=c[ai+((am|1)<<2)>>2]|0;at=as&15;if((at|0)!=0){b[O+14>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535}at=as>>>4&15;if((at|0)!=0){b[O+16>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535}at=as>>>8&15;if((at|0)!=0){b[O+18>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535}at=as>>>16&15;if((at|0)!=0){b[O+20>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535}at=as>>>20&15;if((at|0)!=0){b[O+22>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535}at=as>>>24&15;if((at|0)!=0){b[O+24>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535}at=as>>>28;if((at|0)==0){break}b[O+26>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535;break}else{if(!ar){b[O+26>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}aq=ao>>>4&15;if((aq|0)!=0){b[O+24>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}aq=ao>>>8&15;if((aq|0)!=0){b[O+22>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}aq=ao>>>12&15;if((aq|0)!=0){b[O+20>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}aq=ao>>>16&15;if((aq|0)!=0){b[O+18>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}aq=ao>>>24&15;if((aq|0)!=0){b[O+16>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}aq=ao>>>28;if((aq|0)!=0){b[O+14>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}aq=c[ai+((am|1)<<2)>>2]|0;am=aq&15;if((am|0)!=0){b[O+12>>1]=c[(c[2440392]|0)+(am<<2)>>2]&65535}am=aq>>>4&15;if((am|0)!=0){b[O+10>>1]=c[(c[2440392]|0)+(am<<2)>>2]&65535}am=aq>>>8&15;if((am|0)!=0){b[O+8>>1]=c[(c[2440392]|0)+(am<<2)>>2]&65535}am=aq>>>16&15;if((am|0)!=0){b[O+6>>1]=c[(c[2440392]|0)+(am<<2)>>2]&65535}am=aq>>>20&15;if((am|0)!=0){b[O+4>>1]=c[(c[2440392]|0)+(am<<2)>>2]&65535}am=aq>>>24&15;if((am|0)!=0){b[O+2>>1]=c[(c[2440392]|0)+(am<<2)>>2]&65535}am=aq>>>28;if((am|0)==0){break}b[O>>1]=c[(c[2440392]|0)+(am<<2)>>2]&65535;break}}}while(0);ah=af+1|0;if((ah|0)>(I|0)){ad=al;ae=ak;break}else{J=al;G=ak;E=aj;O=O+t|0;af=ah}}}if((ac|0)>(j|0)){V=33495;break}else{B=ad;C=ae;D=ac}}if((V|0)==33495){return}else if((V|0)==33497){return}}function cyM(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0;f=c[3540994]|0;g=c[3528548]|0;h=g<<8;i=c[2385554]|0;do{if((i|0)>31){j=511}else{k=(i<<4)-1|0;if((k|0)>=0){j=k;break}return}}while(0);k=(j|0)>255;l=j&255;m=c[2385550]|0;n=c[2113042]|0;o=c[2113044]|0;p=n+512|0;q=c[2113132]|0;r=c[2385552]<<1;s=c[2112968]|0;t=q<<1;u=c[2415160]|0;v=c[2429858]|0;w=c[2430428]|0;x=c[2429718]|0;y=c[2430092]|0;z=c[3541046]|0;A=c[2430426]|0;B=0;C=0;D=0;L37840:while(1){E=(i|0)>16&(g|0)!=255;F=(i|0)<33;G=511-g|0;H=g+1|0;I=g-255|0;J=~g;K=D;L37842:while(1){L=K+m|0;M=L&511;do{if((M|0)<(n|0)){N=K+n-M|0}else{if((M|0)>=(o|0)){N=p+K-M|0;break}O=(K|0)>255;P=O?16:0;Q=K&255;R=(K|0)<256&k?255:l;if(!E){S=R;T=Q;U=P;V=33521;break L37842}if(F){if(!O){V=33511;break L37842}if((K|0)<(G|0)){N=G;break}else{V=33513;break L37842}}if(O){W=I+Q|0;if((W|0)>=0){V=33516;break L37842}O=H+W|0;if((O|0)<0){N=512;break}else{S=g;T=O;U=0;V=33521;break L37842}}else{if((Q|0)<=(g|0)){V=33519;break L37842}O=Q+J|0;if((O|0)>(g|0)){N=256;break}else{S=g;T=O;U=16;V=33521;break L37842}}}}while(0);if((N|0)>(j|0)){V=33598;break L37840}else{K=N}}if((V|0)==33519){V=0;X=g;Y=P;Z=Q;_=H+K-Q|0}else if((V|0)==33516){V=0;X=g;Y=P;Z=W;_=H+K-W|0}else if((V|0)==33511){V=0;$=P;aa=Q;ab=R;ac=K+1-Q+R|0;V=33522}else if((V|0)==33513){V=0;J=255-g|0;S=R-J|0;T=Q-J|0;U=P;V=33521}if((V|0)==33521){V=0;J=K+1-T+S|0;if(F){$=U;aa=T;ab=S;ac=J;V=33522}else{X=S;Y=U;Z=T;_=J}}if((V|0)==33522){V=0;X=(ab|0)>(g|0)?g:ab;Y=$;Z=aa;_=ac}J=((L|-512)^511)+o|0;I=(X-Z|0)>(J|0)?J+Z|0:X;if((Z|0)>(I|0)){ad=B;ae=C}else{J=B;G=C;E=-1;O=s+((ag(q,(M<<1)-32|0)|0)+r)|0;af=Z;while(1){ah=d[f+(af+h)|0]|0;ai=(ah>>>4)+Y|0;do{if((ai|0)==(E|0)){aj=E;ak=G;al=J}else{am=ai<<1;an=e[u+((am|1)<<1)>>1]|0;ao=(an<<12&983040|(e[u+(am<<1)>>1]|0))&v;do{if((an&8|0)==0){if((an&4|0)==0){ap=ao;break}ap=w|ao&1048572}else{ap=A|ao&1048568}}while(0);ao=a[x+ap|0]|0;am=ao&255;if(ao<<24>>24!=0){aj=ai;ak=am;al=an;break}c[2385344]=y+(ap<<7);c[2440392]=z+((an>>>4&4080)<<2);aj=ai;ak=am;al=an}}while(0);do{if((ak|0)==0){ai=ah<<1&30;am=(al&2|0)==0?ai:ai^30;ai=c[2385344]|0;ao=c[ai+(am<<2)>>2]|0;aq=ao&15;ar=(aq|0)==0;if((al&1|0)==0){if(!ar){b[O>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}as=ao>>>4&15;if((as|0)!=0){b[O+2>>1]=c[(c[2440392]|0)+(as<<2)>>2]&65535}as=ao>>>8&15;if((as|0)!=0){b[O+4>>1]=c[(c[2440392]|0)+(as<<2)>>2]&65535}as=ao>>>12&15;if((as|0)!=0){b[O+6>>1]=c[(c[2440392]|0)+(as<<2)>>2]&65535}as=ao>>>16&15;if((as|0)!=0){b[O+8>>1]=c[(c[2440392]|0)+(as<<2)>>2]&65535}as=ao>>>24&15;if((as|0)!=0){b[O+10>>1]=c[(c[2440392]|0)+(as<<2)>>2]&65535}as=ao>>>28;if((as|0)!=0){b[O+12>>1]=c[(c[2440392]|0)+(as<<2)>>2]&65535}as=c[ai+((am|1)<<2)>>2]|0;at=as&15;if((at|0)!=0){b[O+14>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535}at=as>>>4&15;if((at|0)!=0){b[O+16>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535}at=as>>>8&15;if((at|0)!=0){b[O+18>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535}at=as>>>12&15;if((at|0)!=0){b[O+20>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535}at=as>>>16&15;if((at|0)!=0){b[O+22>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535}at=as>>>20&15;if((at|0)!=0){b[O+24>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535}at=as>>>24&15;if((at|0)!=0){b[O+26>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535}at=as>>>28;if((at|0)==0){break}b[O+28>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535;break}else{if(!ar){b[O+28>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}aq=ao>>>4&15;if((aq|0)!=0){b[O+26>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}aq=ao>>>8&15;if((aq|0)!=0){b[O+24>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}aq=ao>>>12&15;if((aq|0)!=0){b[O+22>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}aq=ao>>>16&15;if((aq|0)!=0){b[O+20>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}aq=ao>>>24&15;if((aq|0)!=0){b[O+18>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}aq=ao>>>28;if((aq|0)!=0){b[O+16>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}aq=c[ai+((am|1)<<2)>>2]|0;am=aq&15;if((am|0)!=0){b[O+14>>1]=c[(c[2440392]|0)+(am<<2)>>2]&65535}am=aq>>>4&15;if((am|0)!=0){b[O+12>>1]=c[(c[2440392]|0)+(am<<2)>>2]&65535}am=aq>>>8&15;if((am|0)!=0){b[O+10>>1]=c[(c[2440392]|0)+(am<<2)>>2]&65535}am=aq>>>12&15;if((am|0)!=0){b[O+8>>1]=c[(c[2440392]|0)+(am<<2)>>2]&65535}am=aq>>>16&15;if((am|0)!=0){b[O+6>>1]=c[(c[2440392]|0)+(am<<2)>>2]&65535}am=aq>>>20&15;if((am|0)!=0){b[O+4>>1]=c[(c[2440392]|0)+(am<<2)>>2]&65535}am=aq>>>24&15;if((am|0)!=0){b[O+2>>1]=c[(c[2440392]|0)+(am<<2)>>2]&65535}am=aq>>>28;if((am|0)==0){break}b[O>>1]=c[(c[2440392]|0)+(am<<2)>>2]&65535;break}}}while(0);ah=af+1|0;if((ah|0)>(I|0)){ad=al;ae=ak;break}else{J=al;G=ak;E=aj;O=O+t|0;af=ah}}}if((_|0)>(j|0)){V=33597;break}else{B=ad;C=ae;D=_}}if((V|0)==33597){return}else if((V|0)==33598){return}}function cyN(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0;f=c[3540994]|0;g=c[3528548]|0;h=g<<8;i=c[2385554]|0;do{if((i|0)>31){j=511}else{k=(i<<4)-1|0;if((k|0)>=0){j=k;break}return}}while(0);k=(j|0)>255;l=j&255;m=c[2385550]|0;n=c[2113042]|0;o=c[2113044]|0;p=n+512|0;q=c[2113132]|0;r=c[2385552]<<1;s=c[2112968]|0;t=q<<1;u=c[2415160]|0;v=c[2429858]|0;w=c[2430428]|0;x=c[2429718]|0;y=c[2430092]|0;z=c[3541046]|0;A=c[2430426]|0;B=0;C=0;D=0;L37985:while(1){E=(i|0)>16&(g|0)!=255;F=(i|0)<33;G=511-g|0;H=g+1|0;I=g-255|0;J=~g;K=D;L37987:while(1){L=K+m|0;M=L&511;do{if((M|0)<(n|0)){N=K+n-M|0}else{if((M|0)>=(o|0)){N=p+K-M|0;break}O=(K|0)>255;P=O?16:0;Q=K&255;R=(K|0)<256&k?255:l;if(!E){S=R;T=Q;U=P;V=33622;break L37987}if(F){if(!O){V=33612;break L37987}if((K|0)<(G|0)){N=G;break}else{V=33614;break L37987}}if(O){W=I+Q|0;if((W|0)>=0){V=33617;break L37987}O=H+W|0;if((O|0)<0){N=512;break}else{S=g;T=O;U=0;V=33622;break L37987}}else{if((Q|0)<=(g|0)){V=33620;break L37987}O=Q+J|0;if((O|0)>(g|0)){N=256;break}else{S=g;T=O;U=16;V=33622;break L37987}}}}while(0);if((N|0)>(j|0)){V=33703;break L37985}else{K=N}}if((V|0)==33612){V=0;X=P;Y=Q;Z=R;_=K+1-Q+R|0;V=33623}else if((V|0)==33614){V=0;J=255-g|0;S=R-J|0;T=Q-J|0;U=P;V=33622}else if((V|0)==33617){V=0;$=g;aa=P;ab=W;ac=H+K-W|0}else if((V|0)==33620){V=0;$=g;aa=P;ab=Q;ac=H+K-Q|0}if((V|0)==33622){V=0;J=K+1-T+S|0;if(F){X=U;Y=T;Z=S;_=J;V=33623}else{$=S;aa=U;ab=T;ac=J}}if((V|0)==33623){V=0;$=(Z|0)>(g|0)?g:Z;aa=X;ab=Y;ac=_}J=((L|-512)^511)+o|0;I=($-ab|0)>(J|0)?J+ab|0:$;if((ab|0)>(I|0)){ad=B;ae=C}else{J=B;G=C;E=-1;O=s+((ag(q,(M<<1)-32|0)|0)+r)|0;af=ab;while(1){ah=d[f+(af+h)|0]|0;ai=(ah>>>4)+aa|0;do{if((ai|0)==(E|0)){aj=E;ak=G;al=J}else{am=ai<<1;an=e[u+((am|1)<<1)>>1]|0;ao=(an<<12&983040|(e[u+(am<<1)>>1]|0))&v;do{if((an&8|0)==0){if((an&4|0)==0){ap=ao;break}ap=w|ao&1048572}else{ap=A|ao&1048568}}while(0);ao=a[x+ap|0]|0;am=ao&255;if(ao<<24>>24!=0){aj=ai;ak=am;al=an;break}c[2385344]=y+(ap<<7);c[2440392]=z+((an>>>4&4080)<<2);aj=ai;ak=am;al=an}}while(0);do{if((ak|0)==0){ai=ah<<1&30;am=(al&2|0)==0?ai:ai^30;ai=c[2385344]|0;ao=c[ai+(am<<2)>>2]|0;aq=ao&15;ar=(aq|0)==0;if((al&1|0)==0){if(!ar){b[O>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}as=ao>>>4&15;if((as|0)!=0){b[O+2>>1]=c[(c[2440392]|0)+(as<<2)>>2]&65535}as=ao>>>8&15;if((as|0)!=0){b[O+4>>1]=c[(c[2440392]|0)+(as<<2)>>2]&65535}as=ao>>>12&15;if((as|0)!=0){b[O+6>>1]=c[(c[2440392]|0)+(as<<2)>>2]&65535}as=ao>>>16&15;if((as|0)!=0){b[O+8>>1]=c[(c[2440392]|0)+(as<<2)>>2]&65535}as=ao>>>20&15;if((as|0)!=0){b[O+10>>1]=c[(c[2440392]|0)+(as<<2)>>2]&65535}as=ao>>>24&15;if((as|0)!=0){b[O+12>>1]=c[(c[2440392]|0)+(as<<2)>>2]&65535}as=ao>>>28;if((as|0)!=0){b[O+14>>1]=c[(c[2440392]|0)+(as<<2)>>2]&65535}as=c[ai+((am|1)<<2)>>2]|0;at=as&15;if((at|0)!=0){b[O+16>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535}at=as>>>4&15;if((at|0)!=0){b[O+18>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535}at=as>>>8&15;if((at|0)!=0){b[O+20>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535}at=as>>>12&15;if((at|0)!=0){b[O+22>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535}at=as>>>16&15;if((at|0)!=0){b[O+24>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535}at=as>>>20&15;if((at|0)!=0){b[O+26>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535}at=as>>>24&15;if((at|0)!=0){b[O+28>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535}at=as>>>28;if((at|0)==0){break}b[O+30>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535;break}else{if(!ar){b[O+30>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}aq=ao>>>4&15;if((aq|0)!=0){b[O+28>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}aq=ao>>>8&15;if((aq|0)!=0){b[O+26>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}aq=ao>>>12&15;if((aq|0)!=0){b[O+24>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}aq=ao>>>16&15;if((aq|0)!=0){b[O+22>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}aq=ao>>>20&15;if((aq|0)!=0){b[O+20>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}aq=ao>>>24&15;if((aq|0)!=0){b[O+18>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}aq=ao>>>28;if((aq|0)!=0){b[O+16>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}aq=c[ai+((am|1)<<2)>>2]|0;am=aq&15;if((am|0)!=0){b[O+14>>1]=c[(c[2440392]|0)+(am<<2)>>2]&65535}am=aq>>>4&15;if((am|0)!=0){b[O+12>>1]=c[(c[2440392]|0)+(am<<2)>>2]&65535}am=aq>>>8&15;if((am|0)!=0){b[O+10>>1]=c[(c[2440392]|0)+(am<<2)>>2]&65535}am=aq>>>12&15;if((am|0)!=0){b[O+8>>1]=c[(c[2440392]|0)+(am<<2)>>2]&65535}am=aq>>>16&15;if((am|0)!=0){b[O+6>>1]=c[(c[2440392]|0)+(am<<2)>>2]&65535}am=aq>>>20&15;if((am|0)!=0){b[O+4>>1]=c[(c[2440392]|0)+(am<<2)>>2]&65535}am=aq>>>24&15;if((am|0)!=0){b[O+2>>1]=c[(c[2440392]|0)+(am<<2)>>2]&65535}am=aq>>>28;if((am|0)==0){break}b[O>>1]=c[(c[2440392]|0)+(am<<2)>>2]&65535;break}}}while(0);ah=af+1|0;if((ah|0)>(I|0)){ad=al;ae=ak;break}else{J=al;G=ak;E=aj;O=O+t|0;af=ah}}}if((ac|0)>(j|0)){V=33701;break}else{B=ad;C=ae;D=ac}}if((V|0)==33701){return}else if((V|0)==33703){return}}function cyO(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0;f=c[3540994]|0;g=c[3528548]|0;h=g<<8;i=c[2385554]|0;do{if((i|0)>31){j=511}else{k=(i<<4)-1|0;if((k|0)>=0){j=k;break}return}}while(0);k=(j|0)>255;l=j&255;m=c[2385550]|0;n=c[2113042]|0;o=c[2113044]|0;p=n+512|0;q=c[2385552]|0;r=c[2113132]|0;s=q<<1;t=c[2112968]|0;u=(q|0)>-1;v=r<<1;w=c[2415160]|0;x=c[2429858]|0;y=c[2430428]|0;z=c[2429718]|0;A=c[2430092]|0;B=c[3541046]|0;C=c[2430426]|0;D=0;E=0;F=0;L38136:while(1){G=(i|0)>16&(g|0)!=255;H=(i|0)<33;I=511-g|0;J=g+1|0;K=g-255|0;L=~g;M=F;L38138:while(1){N=M+m|0;O=N&511;do{if((O|0)<(n|0)){P=M+n-O|0}else{if((O|0)>=(o|0)){P=p+M-O|0;break}Q=(M|0)>255;R=Q?16:0;S=M&255;T=(M|0)<256&k?255:l;if(!G){U=T;V=S;W=R;X=33727;break L38138}if(H){if(!Q){X=33717;break L38138}if((M|0)<(I|0)){P=I;break}else{X=33719;break L38138}}if(Q){Y=K+S|0;if((Y|0)>=0){X=33722;break L38138}Q=J+Y|0;if((Q|0)<0){P=512;break}else{U=g;V=Q;W=0;X=33727;break L38138}}else{if((S|0)<=(g|0)){X=33725;break L38138}Q=S+L|0;if((Q|0)>(g|0)){P=256;break}else{U=g;V=Q;W=16;X=33727;break L38138}}}}while(0);if((P|0)>(j|0)){X=33750;break L38136}else{M=P}}if((X|0)==33725){X=0;Z=g;_=R;$=S;aa=J+M-S|0}else if((X|0)==33722){X=0;Z=g;_=R;$=Y;aa=J+M-Y|0}else if((X|0)==33717){X=0;ab=R;ac=S;ad=T;ae=M+1-S+T|0;X=33728}else if((X|0)==33719){X=0;L=255-g|0;U=T-L|0;V=S-L|0;W=R;X=33727}if((X|0)==33727){X=0;L=M+1-V+U|0;if(H){ab=W;ac=V;ad=U;ae=L;X=33728}else{Z=U;_=W;$=V;aa=L}}if((X|0)==33728){X=0;Z=(ad|0)>(g|0)?g:ad;_=ab;$=ac;aa=ae}L=((N|-512)^511)+o|0;K=(Z-$|0)>(L|0)?L+$|0:Z;if(($|0)>(K|0)){af=D;ah=E}else{L=D;I=E;G=-1;Q=t+((ag(r,(O<<1)-32|0)|0)+s)|0;ai=$;while(1){aj=d[f+(ai+h)|0]|0;ak=(aj>>>4)+_|0;do{if((ak|0)==(G|0)){al=G;am=I;an=L}else{ao=ak<<1;ap=e[w+((ao|1)<<1)>>1]|0;aq=(ap<<12&983040|(e[w+(ao<<1)>>1]|0))&x;do{if((ap&8|0)==0){if((ap&4|0)==0){ar=aq;break}ar=y|aq&1048572}else{ar=C|aq&1048568}}while(0);aq=a[z+ar|0]|0;ao=aq&255;if(aq<<24>>24!=0){al=ak;am=ao;an=ap;break}c[2385344]=A+(ar<<7);c[2440392]=B+((ap>>>4&4080)<<2);al=ak;am=ao;an=ap}}while(0);do{if((am|0)==0){ak=aj<<1&30;ao=c[(c[2385344]|0)+((((an&2|0)==0?ak:ak^30)|1)<<2)>>2]&15;ak=(ao|0)==0;if((an&1|0)==0){if(ak){break}if(!(u&(q|0)<(r|0))){break}b[Q>>1]=c[(c[2440392]|0)+(ao<<2)>>2]&65535;break}else{if(ak){break}if(!(u&(q|0)<(r|0))){break}b[Q>>1]=c[(c[2440392]|0)+(ao<<2)>>2]&65535;break}}}while(0);aj=ai+1|0;if((aj|0)>(K|0)){af=an;ah=am;break}else{L=an;I=am;G=al;Q=Q+v|0;ai=aj}}}if((aa|0)>(j|0)){X=33749;break}else{D=af;E=ah;F=aa}}if((X|0)==33749){return}else if((X|0)==33750){return}}function cyP(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0;f=c[3540994]|0;g=c[3528548]|0;h=g<<8;i=c[2385554]|0;do{if((i|0)>31){j=511}else{k=(i<<4)-1|0;if((k|0)>=0){j=k;break}return}}while(0);k=(j|0)>255;l=j&255;m=c[2385550]|0;n=c[2113042]|0;o=c[2113044]|0;p=n+512|0;q=c[2385552]|0;r=c[2113132]|0;s=q<<1;t=c[2112968]|0;u=q+1|0;v=(u|0)>-1&(u|0)<(r|0);u=(q|0)>-1&(q|0)<(r|0);q=r<<1;w=c[2415160]|0;x=c[2429858]|0;y=c[2430428]|0;z=c[2429718]|0;A=c[2430092]|0;B=c[3541046]|0;C=c[2430426]|0;D=0;E=0;F=0;L38199:while(1){G=(i|0)>16&(g|0)!=255;H=(i|0)<33;I=511-g|0;J=g+1|0;K=g-255|0;L=~g;M=F;L38201:while(1){N=M+m|0;O=N&511;do{if((O|0)<(n|0)){P=M+n-O|0}else{if((O|0)>=(o|0)){P=p+M-O|0;break}Q=(M|0)>255;R=Q?16:0;S=M&255;T=(M|0)<256&k?255:l;if(!G){U=T;V=S;W=R;X=33774;break L38201}if(H){if(!Q){X=33764;break L38201}if((M|0)<(I|0)){P=I;break}else{X=33766;break L38201}}if(Q){Y=K+S|0;if((Y|0)>=0){X=33769;break L38201}Q=J+Y|0;if((Q|0)<0){P=512;break}else{U=g;V=Q;W=0;X=33774;break L38201}}else{if((S|0)<=(g|0)){X=33772;break L38201}Q=S+L|0;if((Q|0)>(g|0)){P=256;break}else{U=g;V=Q;W=16;X=33774;break L38201}}}}while(0);if((P|0)>(j|0)){X=33799;break L38199}else{M=P}}if((X|0)==33764){X=0;Z=R;_=S;$=T;aa=M+1-S+T|0;X=33775}else if((X|0)==33766){X=0;L=255-g|0;U=T-L|0;V=S-L|0;W=R;X=33774}else if((X|0)==33769){X=0;ab=g;ac=R;ad=Y;ae=J+M-Y|0}else if((X|0)==33772){X=0;ab=g;ac=R;ad=S;ae=J+M-S|0}if((X|0)==33774){X=0;L=M+1-V+U|0;if(H){Z=W;_=V;$=U;aa=L;X=33775}else{ab=U;ac=W;ad=V;ae=L}}if((X|0)==33775){X=0;ab=($|0)>(g|0)?g:$;ac=Z;ad=_;ae=aa}L=((N|-512)^511)+o|0;K=(ab-ad|0)>(L|0)?L+ad|0:ab;if((ad|0)>(K|0)){af=D;ah=E}else{L=D;I=E;G=-1;Q=t+((ag(r,(O<<1)-32|0)|0)+s)|0;ai=ad;while(1){aj=d[f+(ai+h)|0]|0;ak=(aj>>>4)+ac|0;do{if((ak|0)==(G|0)){al=G;am=I;an=L}else{ao=ak<<1;ap=e[w+((ao|1)<<1)>>1]|0;aq=(ap<<12&983040|(e[w+(ao<<1)>>1]|0))&x;do{if((ap&8|0)==0){if((ap&4|0)==0){ar=aq;break}ar=y|aq&1048572}else{ar=C|aq&1048568}}while(0);aq=a[z+ar|0]|0;ao=aq&255;if(aq<<24>>24!=0){al=ak;am=ao;an=ap;break}c[2385344]=A+(ar<<7);c[2440392]=B+((ap>>>4&4080)<<2);al=ak;am=ao;an=ap}}while(0);do{if((am|0)==0){ak=aj<<1&30;ao=(an&2|0)==0?ak:ak^30;if((an&1|0)==0){ak=c[2385344]|0;aq=(c[ak+(ao<<2)>>2]|0)>>>16&15;if(!((aq|0)==0|u^1)){b[Q>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}aq=c[ak+((ao|1)<<2)>>2]&15;if((aq|0)==0|v^1){break}b[Q+2>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535;break}else{aq=c[2385344]|0;ak=(c[aq+(ao<<2)>>2]|0)>>>16&15;if(!((ak|0)==0|v^1)){b[Q+2>>1]=c[(c[2440392]|0)+(ak<<2)>>2]&65535}ak=c[aq+((ao|1)<<2)>>2]&15;if((ak|0)==0|u^1){break}b[Q>>1]=c[(c[2440392]|0)+(ak<<2)>>2]&65535;break}}}while(0);aj=ai+1|0;if((aj|0)>(K|0)){af=an;ah=am;break}else{L=an;I=am;G=al;Q=Q+q|0;ai=aj}}}if((ae|0)>(j|0)){X=33797;break}else{D=af;E=ah;F=ae}}if((X|0)==33797){return}else if((X|0)==33799){return}}function cyQ(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0;f=c[3540994]|0;g=c[3528548]|0;h=g<<8;i=c[2385554]|0;do{if((i|0)>31){j=511}else{k=(i<<4)-1|0;if((k|0)>=0){j=k;break}return}}while(0);k=(j|0)>255;l=j&255;m=c[2385550]|0;n=c[2113042]|0;o=c[2113044]|0;p=n+512|0;q=c[2385552]|0;r=c[2113132]|0;s=q<<1;t=c[2112968]|0;u=q+2|0;v=(u|0)>-1&(u|0)<(r|0);u=q+1|0;w=(u|0)>-1&(u|0)<(r|0);u=(q|0)>-1&(q|0)<(r|0);q=r<<1;x=c[2415160]|0;y=c[2429858]|0;z=c[2430428]|0;A=c[2429718]|0;B=c[2430092]|0;C=c[3541046]|0;D=c[2430426]|0;E=0;F=0;G=0;L38266:while(1){H=(i|0)>16&(g|0)!=255;I=(i|0)<33;J=511-g|0;K=g+1|0;L=g-255|0;M=~g;N=G;L38268:while(1){O=N+m|0;P=O&511;do{if((P|0)<(n|0)){Q=N+n-P|0}else{if((P|0)>=(o|0)){Q=p+N-P|0;break}R=(N|0)>255;S=R?16:0;T=N&255;U=(N|0)<256&k?255:l;if(!H){V=U;W=T;X=S;Y=33823;break L38268}if(I){if(!R){Y=33813;break L38268}if((N|0)<(J|0)){Q=J;break}else{Y=33815;break L38268}}if(R){Z=L+T|0;if((Z|0)>=0){Y=33818;break L38268}R=K+Z|0;if((R|0)<0){Q=512;break}else{V=g;W=R;X=0;Y=33823;break L38268}}else{if((T|0)<=(g|0)){Y=33821;break L38268}R=T+M|0;if((R|0)>(g|0)){Q=256;break}else{V=g;W=R;X=16;Y=33823;break L38268}}}}while(0);if((Q|0)>(j|0)){Y=33852;break L38266}else{N=Q}}if((Y|0)==33813){Y=0;_=S;$=T;aa=U;ab=N+1-T+U|0;Y=33824}else if((Y|0)==33815){Y=0;M=255-g|0;V=U-M|0;W=T-M|0;X=S;Y=33823}else if((Y|0)==33818){Y=0;ac=g;ad=S;ae=Z;af=K+N-Z|0}else if((Y|0)==33821){Y=0;ac=g;ad=S;ae=T;af=K+N-T|0}if((Y|0)==33823){Y=0;M=N+1-W+V|0;if(I){_=X;$=W;aa=V;ab=M;Y=33824}else{ac=V;ad=X;ae=W;af=M}}if((Y|0)==33824){Y=0;ac=(aa|0)>(g|0)?g:aa;ad=_;ae=$;af=ab}M=((O|-512)^511)+o|0;L=(ac-ae|0)>(M|0)?M+ae|0:ac;if((ae|0)>(L|0)){ah=E;ai=F}else{M=E;J=F;H=-1;R=t+((ag(r,(P<<1)-32|0)|0)+s)|0;aj=ae;while(1){ak=d[f+(aj+h)|0]|0;al=(ak>>>4)+ad|0;do{if((al|0)==(H|0)){am=H;an=J;ao=M}else{ap=al<<1;aq=e[x+((ap|1)<<1)>>1]|0;ar=(aq<<12&983040|(e[x+(ap<<1)>>1]|0))&y;do{if((aq&8|0)==0){if((aq&4|0)==0){as=ar;break}as=z|ar&1048572}else{as=D|ar&1048568}}while(0);ar=a[A+as|0]|0;ap=ar&255;if(ar<<24>>24!=0){am=al;an=ap;ao=aq;break}c[2385344]=B+(as<<7);c[2440392]=C+((aq>>>4&4080)<<2);am=al;an=ap;ao=aq}}while(0);do{if((an|0)==0){al=ak<<1&30;ap=(ao&2|0)==0?al:al^30;if((ao&1|0)==0){al=c[2385344]|0;ar=(c[al+(ap<<2)>>2]|0)>>>16&15;if(!((ar|0)==0|u^1)){b[R>>1]=c[(c[2440392]|0)+(ar<<2)>>2]&65535}ar=c[al+((ap|1)<<2)>>2]|0;al=ar&15;if(!((al|0)==0|w^1)){b[R+2>>1]=c[(c[2440392]|0)+(al<<2)>>2]&65535}al=ar>>>16&15;if((al|0)==0|v^1){break}b[R+4>>1]=c[(c[2440392]|0)+(al<<2)>>2]&65535;break}else{al=c[2385344]|0;ar=(c[al+(ap<<2)>>2]|0)>>>16&15;if(!((ar|0)==0|v^1)){b[R+4>>1]=c[(c[2440392]|0)+(ar<<2)>>2]&65535}ar=c[al+((ap|1)<<2)>>2]|0;ap=ar&15;if(!((ap|0)==0|w^1)){b[R+2>>1]=c[(c[2440392]|0)+(ap<<2)>>2]&65535}ap=ar>>>16&15;if((ap|0)==0|u^1){break}b[R>>1]=c[(c[2440392]|0)+(ap<<2)>>2]&65535;break}}}while(0);ak=aj+1|0;if((ak|0)>(L|0)){ah=ao;ai=an;break}else{M=ao;J=an;H=am;R=R+q|0;aj=ak}}}if((af|0)>(j|0)){Y=33851;break}else{E=ah;F=ai;G=af}}if((Y|0)==33851){return}else if((Y|0)==33852){return}}function cyR(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0;f=c[3540994]|0;g=c[3528548]|0;h=g<<8;i=c[2385554]|0;do{if((i|0)>31){j=511}else{k=(i<<4)-1|0;if((k|0)>=0){j=k;break}return}}while(0);k=(j|0)>255;l=j&255;m=c[2385550]|0;n=c[2113042]|0;o=c[2113044]|0;p=n+512|0;q=c[2385552]|0;r=c[2113132]|0;s=q<<1;t=c[2112968]|0;u=q+3|0;v=(u|0)>-1&(u|0)<(r|0);u=q+2|0;w=(u|0)>-1&(u|0)<(r|0);u=q+1|0;x=(u|0)>-1&(u|0)<(r|0);u=(q|0)>-1&(q|0)<(r|0);q=r<<1;y=c[2415160]|0;z=c[2429858]|0;A=c[2430428]|0;B=c[2429718]|0;C=c[2430092]|0;D=c[3541046]|0;E=c[2430426]|0;F=0;G=0;H=0;L38339:while(1){I=(i|0)>16&(g|0)!=255;J=(i|0)<33;K=511-g|0;L=g+1|0;M=g-255|0;N=~g;O=H;L38341:while(1){P=O+m|0;Q=P&511;do{if((Q|0)<(n|0)){R=O+n-Q|0}else{if((Q|0)>=(o|0)){R=p+O-Q|0;break}S=(O|0)>255;T=S?16:0;U=O&255;V=(O|0)<256&k?255:l;if(!I){W=V;X=U;Y=T;Z=33876;break L38341}if(J){if(!S){Z=33866;break L38341}if((O|0)<(K|0)){R=K;break}else{Z=33868;break L38341}}if(S){_=M+U|0;if((_|0)>=0){Z=33871;break L38341}S=L+_|0;if((S|0)<0){R=512;break}else{W=g;X=S;Y=0;Z=33876;break L38341}}else{if((U|0)<=(g|0)){Z=33874;break L38341}S=U+N|0;if((S|0)>(g|0)){R=256;break}else{W=g;X=S;Y=16;Z=33876;break L38341}}}}while(0);if((R|0)>(j|0)){Z=33909;break L38339}else{O=R}}if((Z|0)==33874){Z=0;$=g;aa=T;ab=U;ac=L+O-U|0}else if((Z|0)==33871){Z=0;$=g;aa=T;ab=_;ac=L+O-_|0}else if((Z|0)==33868){Z=0;N=255-g|0;W=V-N|0;X=U-N|0;Y=T;Z=33876}else if((Z|0)==33866){Z=0;ad=T;ae=U;af=V;ah=O+1-U+V|0;Z=33877}if((Z|0)==33876){Z=0;N=O+1-X+W|0;if(J){ad=Y;ae=X;af=W;ah=N;Z=33877}else{$=W;aa=Y;ab=X;ac=N}}if((Z|0)==33877){Z=0;$=(af|0)>(g|0)?g:af;aa=ad;ab=ae;ac=ah}N=((P|-512)^511)+o|0;M=($-ab|0)>(N|0)?N+ab|0:$;if((ab|0)>(M|0)){ai=F;aj=G}else{N=F;K=G;I=-1;S=t+((ag(r,(Q<<1)-32|0)|0)+s)|0;ak=ab;while(1){al=d[f+(ak+h)|0]|0;am=(al>>>4)+aa|0;do{if((am|0)==(I|0)){an=I;ao=K;ap=N}else{aq=am<<1;ar=e[y+((aq|1)<<1)>>1]|0;as=(ar<<12&983040|(e[y+(aq<<1)>>1]|0))&z;do{if((ar&8|0)==0){if((ar&4|0)==0){at=as;break}at=A|as&1048572}else{at=E|as&1048568}}while(0);as=a[B+at|0]|0;aq=as&255;if(as<<24>>24!=0){an=am;ao=aq;ap=ar;break}c[2385344]=C+(at<<7);c[2440392]=D+((ar>>>4&4080)<<2);an=am;ao=aq;ap=ar}}while(0);do{if((ao|0)==0){am=al<<1&30;aq=(ap&2|0)==0?am:am^30;if((ap&1|0)==0){am=c[2385344]|0;as=c[am+(aq<<2)>>2]|0;au=as>>>8&15;if(!((au|0)==0|u^1)){b[S>>1]=c[(c[2440392]|0)+(au<<2)>>2]&65535}au=as>>>16&15;if(!((au|0)==0|x^1)){b[S+2>>1]=c[(c[2440392]|0)+(au<<2)>>2]&65535}au=c[am+((aq|1)<<2)>>2]|0;am=au&15;if(!((am|0)==0|w^1)){b[S+4>>1]=c[(c[2440392]|0)+(am<<2)>>2]&65535}am=au>>>16&15;if((am|0)==0|v^1){break}b[S+6>>1]=c[(c[2440392]|0)+(am<<2)>>2]&65535;break}else{am=c[2385344]|0;au=c[am+(aq<<2)>>2]|0;as=au>>>8&15;if(!((as|0)==0|v^1)){b[S+6>>1]=c[(c[2440392]|0)+(as<<2)>>2]&65535}as=au>>>16&15;if(!((as|0)==0|w^1)){b[S+4>>1]=c[(c[2440392]|0)+(as<<2)>>2]&65535}as=c[am+((aq|1)<<2)>>2]|0;aq=as&15;if(!((aq|0)==0|x^1)){b[S+2>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}aq=as>>>16&15;if((aq|0)==0|u^1){break}b[S>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535;break}}}while(0);al=ak+1|0;if((al|0)>(M|0)){ai=ap;aj=ao;break}else{N=ap;K=ao;I=an;S=S+q|0;ak=al}}}if((ac|0)>(j|0)){Z=33907;break}else{F=ai;G=aj;H=ac}}if((Z|0)==33907){return}else if((Z|0)==33909){return}}function cyS(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0;f=c[3540994]|0;g=c[3528548]|0;h=g<<8;i=c[2385554]|0;do{if((i|0)>31){j=511}else{k=(i<<4)-1|0;if((k|0)>=0){j=k;break}return}}while(0);k=(j|0)>255;l=j&255;m=c[2385550]|0;n=c[2113042]|0;o=c[2113044]|0;p=n+512|0;q=c[2385552]|0;r=c[2113132]|0;s=q<<1;t=c[2112968]|0;u=q+4|0;v=(u|0)>-1&(u|0)<(r|0);u=q+3|0;w=(u|0)>-1&(u|0)<(r|0);u=q+2|0;x=(u|0)>-1&(u|0)<(r|0);u=q+1|0;y=(u|0)>-1&(u|0)<(r|0);u=(q|0)>-1&(q|0)<(r|0);q=r<<1;z=c[2415160]|0;A=c[2429858]|0;B=c[2430428]|0;C=c[2429718]|0;D=c[2430092]|0;E=c[3541046]|0;F=c[2430426]|0;G=0;H=0;I=0;L38418:while(1){J=(i|0)>16&(g|0)!=255;K=(i|0)<33;L=511-g|0;M=g+1|0;N=g-255|0;O=~g;P=I;L38420:while(1){Q=P+m|0;R=Q&511;do{if((R|0)<(n|0)){S=P+n-R|0}else{if((R|0)>=(o|0)){S=p+P-R|0;break}T=(P|0)>255;U=T?16:0;V=P&255;W=(P|0)<256&k?255:l;if(!J){X=W;Y=V;Z=U;_=33933;break L38420}if(K){if(!T){_=33923;break L38420}if((P|0)<(L|0)){S=L;break}else{_=33925;break L38420}}if(T){$=N+V|0;if(($|0)>=0){_=33928;break L38420}T=M+$|0;if((T|0)<0){S=512;break}else{X=g;Y=T;Z=0;_=33933;break L38420}}else{if((V|0)<=(g|0)){_=33931;break L38420}T=V+O|0;if((T|0)>(g|0)){S=256;break}else{X=g;Y=T;Z=16;_=33933;break L38420}}}}while(0);if((S|0)>(j|0)){_=33970;break L38418}else{P=S}}if((_|0)==33928){_=0;aa=g;ab=U;ac=$;ad=M+P-$|0}else if((_|0)==33925){_=0;O=255-g|0;X=W-O|0;Y=V-O|0;Z=U;_=33933}else if((_|0)==33923){_=0;ae=U;af=V;ah=W;ai=P+1-V+W|0;_=33934}else if((_|0)==33931){_=0;aa=g;ab=U;ac=V;ad=M+P-V|0}if((_|0)==33933){_=0;O=P+1-Y+X|0;if(K){ae=Z;af=Y;ah=X;ai=O;_=33934}else{aa=X;ab=Z;ac=Y;ad=O}}if((_|0)==33934){_=0;aa=(ah|0)>(g|0)?g:ah;ab=ae;ac=af;ad=ai}O=((Q|-512)^511)+o|0;N=(aa-ac|0)>(O|0)?O+ac|0:aa;if((ac|0)>(N|0)){aj=G;ak=H}else{O=G;L=H;J=-1;T=t+((ag(r,(R<<1)-32|0)|0)+s)|0;al=ac;while(1){am=d[f+(al+h)|0]|0;an=(am>>>4)+ab|0;do{if((an|0)==(J|0)){ao=J;ap=L;aq=O}else{ar=an<<1;as=e[z+((ar|1)<<1)>>1]|0;at=(as<<12&983040|(e[z+(ar<<1)>>1]|0))&A;do{if((as&8|0)==0){if((as&4|0)==0){au=at;break}au=B|at&1048572}else{au=F|at&1048568}}while(0);at=a[C+au|0]|0;ar=at&255;if(at<<24>>24!=0){ao=an;ap=ar;aq=as;break}c[2385344]=D+(au<<7);c[2440392]=E+((as>>>4&4080)<<2);ao=an;ap=ar;aq=as}}while(0);do{if((ap|0)==0){an=am<<1&30;ar=(aq&2|0)==0?an:an^30;if((aq&1|0)==0){an=c[2385344]|0;at=c[an+(ar<<2)>>2]|0;av=at>>>8&15;if(!((av|0)==0|u^1)){b[T>>1]=c[(c[2440392]|0)+(av<<2)>>2]&65535}av=at>>>16&15;if(!((av|0)==0|y^1)){b[T+2>>1]=c[(c[2440392]|0)+(av<<2)>>2]&65535}av=c[an+((ar|1)<<2)>>2]|0;an=av&15;if(!((an|0)==0|x^1)){b[T+4>>1]=c[(c[2440392]|0)+(an<<2)>>2]&65535}an=av>>>16&15;if(!((an|0)==0|w^1)){b[T+6>>1]=c[(c[2440392]|0)+(an<<2)>>2]&65535}an=av>>>24&15;if((an|0)==0|v^1){break}b[T+8>>1]=c[(c[2440392]|0)+(an<<2)>>2]&65535;break}else{an=c[2385344]|0;av=c[an+(ar<<2)>>2]|0;at=av>>>8&15;if(!((at|0)==0|v^1)){b[T+8>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535}at=av>>>16&15;if(!((at|0)==0|w^1)){b[T+6>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535}at=c[an+((ar|1)<<2)>>2]|0;ar=at&15;if(!((ar|0)==0|x^1)){b[T+4>>1]=c[(c[2440392]|0)+(ar<<2)>>2]&65535}ar=at>>>16&15;if(!((ar|0)==0|y^1)){b[T+2>>1]=c[(c[2440392]|0)+(ar<<2)>>2]&65535}ar=at>>>24&15;if((ar|0)==0|u^1){break}b[T>>1]=c[(c[2440392]|0)+(ar<<2)>>2]&65535;break}}}while(0);am=al+1|0;if((am|0)>(N|0)){aj=aq;ak=ap;break}else{O=aq;L=ap;J=ao;T=T+q|0;al=am}}}if((ad|0)>(j|0)){_=33969;break}else{G=aj;H=ak;I=ad}}if((_|0)==33969){return}else if((_|0)==33970){return}}function cyT(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0;f=c[3540994]|0;g=c[3528548]|0;h=g<<8;i=c[2385554]|0;do{if((i|0)>31){j=511}else{k=(i<<4)-1|0;if((k|0)>=0){j=k;break}return}}while(0);k=(j|0)>255;l=j&255;m=c[2385550]|0;n=c[2113042]|0;o=c[2113044]|0;p=n+512|0;q=c[2385552]|0;r=c[2113132]|0;s=q<<1;t=c[2112968]|0;u=q+5|0;v=(u|0)>-1&(u|0)<(r|0);u=q+4|0;w=(u|0)>-1&(u|0)<(r|0);u=q+3|0;x=(u|0)>-1&(u|0)<(r|0);u=q+2|0;y=(u|0)>-1&(u|0)<(r|0);u=q+1|0;z=(u|0)>-1&(u|0)<(r|0);u=(q|0)>-1&(q|0)<(r|0);q=r<<1;A=c[2415160]|0;B=c[2429858]|0;C=c[2430428]|0;D=c[2429718]|0;E=c[2430092]|0;F=c[3541046]|0;G=c[2430426]|0;H=0;I=0;J=0;L38503:while(1){K=(i|0)>16&(g|0)!=255;L=(i|0)<33;M=511-g|0;N=g+1|0;O=g-255|0;P=~g;Q=J;L38505:while(1){R=Q+m|0;S=R&511;do{if((S|0)<(n|0)){T=Q+n-S|0}else{if((S|0)>=(o|0)){T=p+Q-S|0;break}U=(Q|0)>255;V=U?16:0;W=Q&255;X=(Q|0)<256&k?255:l;if(!K){Y=X;Z=W;_=V;$=33994;break L38505}if(L){if(!U){$=33984;break L38505}if((Q|0)<(M|0)){T=M;break}else{$=33986;break L38505}}if(U){aa=O+W|0;if((aa|0)>=0){$=33989;break L38505}U=N+aa|0;if((U|0)<0){T=512;break}else{Y=g;Z=U;_=0;$=33994;break L38505}}else{if((W|0)<=(g|0)){$=33992;break L38505}U=W+P|0;if((U|0)>(g|0)){T=256;break}else{Y=g;Z=U;_=16;$=33994;break L38505}}}}while(0);if((T|0)>(j|0)){$=34035;break L38503}else{Q=T}}if(($|0)==33984){$=0;ab=V;ac=W;ad=X;ae=Q+1-W+X|0;$=33995}else if(($|0)==33986){$=0;P=255-g|0;Y=X-P|0;Z=W-P|0;_=V;$=33994}else if(($|0)==33992){$=0;af=g;ah=V;ai=W;aj=N+Q-W|0}else if(($|0)==33989){$=0;af=g;ah=V;ai=aa;aj=N+Q-aa|0}if(($|0)==33994){$=0;P=Q+1-Z+Y|0;if(L){ab=_;ac=Z;ad=Y;ae=P;$=33995}else{af=Y;ah=_;ai=Z;aj=P}}if(($|0)==33995){$=0;af=(ad|0)>(g|0)?g:ad;ah=ab;ai=ac;aj=ae}P=((R|-512)^511)+o|0;O=(af-ai|0)>(P|0)?P+ai|0:af;if((ai|0)>(O|0)){ak=H;al=I}else{P=H;M=I;K=-1;U=t+((ag(r,(S<<1)-32|0)|0)+s)|0;am=ai;while(1){an=d[f+(am+h)|0]|0;ao=(an>>>4)+ah|0;do{if((ao|0)==(K|0)){ap=K;aq=M;ar=P}else{as=ao<<1;at=e[A+((as|1)<<1)>>1]|0;au=(at<<12&983040|(e[A+(as<<1)>>1]|0))&B;do{if((at&8|0)==0){if((at&4|0)==0){av=au;break}av=C|au&1048572}else{av=G|au&1048568}}while(0);au=a[D+av|0]|0;as=au&255;if(au<<24>>24!=0){ap=ao;aq=as;ar=at;break}c[2385344]=E+(av<<7);c[2440392]=F+((at>>>4&4080)<<2);ap=ao;aq=as;ar=at}}while(0);do{if((aq|0)==0){ao=an<<1&30;as=(ar&2|0)==0?ao:ao^30;if((ar&1|0)==0){ao=c[2385344]|0;au=c[ao+(as<<2)>>2]|0;aw=au>>>8&15;if(!((aw|0)==0|u^1)){b[U>>1]=c[(c[2440392]|0)+(aw<<2)>>2]&65535}aw=au>>>16&15;if(!((aw|0)==0|z^1)){b[U+2>>1]=c[(c[2440392]|0)+(aw<<2)>>2]&65535}aw=au>>>24&15;if(!((aw|0)==0|y^1)){b[U+4>>1]=c[(c[2440392]|0)+(aw<<2)>>2]&65535}aw=c[ao+((as|1)<<2)>>2]|0;ao=aw&15;if(!((ao|0)==0|x^1)){b[U+6>>1]=c[(c[2440392]|0)+(ao<<2)>>2]&65535}ao=aw>>>16&15;if(!((ao|0)==0|w^1)){b[U+8>>1]=c[(c[2440392]|0)+(ao<<2)>>2]&65535}ao=aw>>>24&15;if((ao|0)==0|v^1){break}b[U+10>>1]=c[(c[2440392]|0)+(ao<<2)>>2]&65535;break}else{ao=c[2385344]|0;aw=c[ao+(as<<2)>>2]|0;au=aw>>>8&15;if(!((au|0)==0|v^1)){b[U+10>>1]=c[(c[2440392]|0)+(au<<2)>>2]&65535}au=aw>>>16&15;if(!((au|0)==0|w^1)){b[U+8>>1]=c[(c[2440392]|0)+(au<<2)>>2]&65535}au=aw>>>24&15;if(!((au|0)==0|x^1)){b[U+6>>1]=c[(c[2440392]|0)+(au<<2)>>2]&65535}au=c[ao+((as|1)<<2)>>2]|0;as=au&15;if(!((as|0)==0|y^1)){b[U+4>>1]=c[(c[2440392]|0)+(as<<2)>>2]&65535}as=au>>>16&15;if(!((as|0)==0|z^1)){b[U+2>>1]=c[(c[2440392]|0)+(as<<2)>>2]&65535}as=au>>>24&15;if((as|0)==0|u^1){break}b[U>>1]=c[(c[2440392]|0)+(as<<2)>>2]&65535;break}}}while(0);an=am+1|0;if((an|0)>(O|0)){ak=ar;al=aq;break}else{P=ar;M=aq;K=ap;U=U+q|0;am=an}}}if((aj|0)>(j|0)){$=34033;break}else{H=ak;I=al;J=aj}}if(($|0)==34033){return}else if(($|0)==34035){return}}function cyU(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0;f=c[3540994]|0;g=c[3528548]|0;h=g<<8;i=c[2385554]|0;do{if((i|0)>31){j=511}else{k=(i<<4)-1|0;if((k|0)>=0){j=k;break}return}}while(0);k=(j|0)>255;l=j&255;m=c[2385550]|0;n=c[2113042]|0;o=c[2113044]|0;p=n+512|0;q=c[2385552]|0;r=c[2113132]|0;s=q<<1;t=c[2112968]|0;u=q+6|0;v=(u|0)>-1&(u|0)<(r|0);u=q+5|0;w=(u|0)>-1&(u|0)<(r|0);u=q+4|0;x=(u|0)>-1&(u|0)<(r|0);u=q+3|0;y=(u|0)>-1&(u|0)<(r|0);u=q+2|0;z=(u|0)>-1&(u|0)<(r|0);u=q+1|0;A=(u|0)>-1&(u|0)<(r|0);u=(q|0)>-1&(q|0)<(r|0);q=r<<1;B=c[2415160]|0;C=c[2429858]|0;D=c[2430428]|0;E=c[2429718]|0;F=c[2430092]|0;G=c[3541046]|0;H=c[2430426]|0;I=0;J=0;K=0;L38594:while(1){L=(i|0)>16&(g|0)!=255;M=(i|0)<33;N=511-g|0;O=g+1|0;P=g-255|0;Q=~g;R=K;L38596:while(1){S=R+m|0;T=S&511;do{if((T|0)<(n|0)){U=R+n-T|0}else{if((T|0)>=(o|0)){U=p+R-T|0;break}V=(R|0)>255;W=V?16:0;X=R&255;Y=(R|0)<256&k?255:l;if(!L){Z=Y;_=X;$=W;aa=34059;break L38596}if(M){if(!V){aa=34049;break L38596}if((R|0)<(N|0)){U=N;break}else{aa=34051;break L38596}}if(V){ab=P+X|0;if((ab|0)>=0){aa=34054;break L38596}V=O+ab|0;if((V|0)<0){U=512;break}else{Z=g;_=V;$=0;aa=34059;break L38596}}else{if((X|0)<=(g|0)){aa=34057;break L38596}V=X+Q|0;if((V|0)>(g|0)){U=256;break}else{Z=g;_=V;$=16;aa=34059;break L38596}}}}while(0);if((U|0)>(j|0)){aa=34104;break L38594}else{R=U}}if((aa|0)==34049){aa=0;ac=W;ad=X;ae=Y;af=R+1-X+Y|0;aa=34060}else if((aa|0)==34054){aa=0;ah=g;ai=W;aj=ab;ak=O+R-ab|0}else if((aa|0)==34057){aa=0;ah=g;ai=W;aj=X;ak=O+R-X|0}else if((aa|0)==34051){aa=0;Q=255-g|0;Z=Y-Q|0;_=X-Q|0;$=W;aa=34059}if((aa|0)==34059){aa=0;Q=R+1-_+Z|0;if(M){ac=$;ad=_;ae=Z;af=Q;aa=34060}else{ah=Z;ai=$;aj=_;ak=Q}}if((aa|0)==34060){aa=0;ah=(ae|0)>(g|0)?g:ae;ai=ac;aj=ad;ak=af}Q=((S|-512)^511)+o|0;P=(ah-aj|0)>(Q|0)?Q+aj|0:ah;if((aj|0)>(P|0)){al=I;am=J}else{Q=I;N=J;L=-1;V=t+((ag(r,(T<<1)-32|0)|0)+s)|0;an=aj;while(1){ao=d[f+(an+h)|0]|0;ap=(ao>>>4)+ai|0;do{if((ap|0)==(L|0)){aq=L;ar=N;as=Q}else{at=ap<<1;au=e[B+((at|1)<<1)>>1]|0;av=(au<<12&983040|(e[B+(at<<1)>>1]|0))&C;do{if((au&8|0)==0){if((au&4|0)==0){aw=av;break}aw=D|av&1048572}else{aw=H|av&1048568}}while(0);av=a[E+aw|0]|0;at=av&255;if(av<<24>>24!=0){aq=ap;ar=at;as=au;break}c[2385344]=F+(aw<<7);c[2440392]=G+((au>>>4&4080)<<2);aq=ap;ar=at;as=au}}while(0);do{if((ar|0)==0){ap=ao<<1&30;at=(as&2|0)==0?ap:ap^30;if((as&1|0)==0){ap=c[2385344]|0;av=c[ap+(at<<2)>>2]|0;ax=av>>>8&15;if(!((ax|0)==0|u^1)){b[V>>1]=c[(c[2440392]|0)+(ax<<2)>>2]&65535}ax=av>>>16&15;if(!((ax|0)==0|A^1)){b[V+2>>1]=c[(c[2440392]|0)+(ax<<2)>>2]&65535}ax=av>>>24&15;if(!((ax|0)==0|z^1)){b[V+4>>1]=c[(c[2440392]|0)+(ax<<2)>>2]&65535}ax=c[ap+((at|1)<<2)>>2]|0;ap=ax&15;if(!((ap|0)==0|y^1)){b[V+6>>1]=c[(c[2440392]|0)+(ap<<2)>>2]&65535}ap=ax>>>8&15;if(!((ap|0)==0|x^1)){b[V+8>>1]=c[(c[2440392]|0)+(ap<<2)>>2]&65535}ap=ax>>>16&15;if(!((ap|0)==0|w^1)){b[V+10>>1]=c[(c[2440392]|0)+(ap<<2)>>2]&65535}ap=ax>>>24&15;if((ap|0)==0|v^1){break}b[V+12>>1]=c[(c[2440392]|0)+(ap<<2)>>2]&65535;break}else{ap=c[2385344]|0;ax=c[ap+(at<<2)>>2]|0;av=ax>>>8&15;if(!((av|0)==0|v^1)){b[V+12>>1]=c[(c[2440392]|0)+(av<<2)>>2]&65535}av=ax>>>16&15;if(!((av|0)==0|w^1)){b[V+10>>1]=c[(c[2440392]|0)+(av<<2)>>2]&65535}av=ax>>>24&15;if(!((av|0)==0|x^1)){b[V+8>>1]=c[(c[2440392]|0)+(av<<2)>>2]&65535}av=c[ap+((at|1)<<2)>>2]|0;at=av&15;if(!((at|0)==0|y^1)){b[V+6>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535}at=av>>>8&15;if(!((at|0)==0|z^1)){b[V+4>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535}at=av>>>16&15;if(!((at|0)==0|A^1)){b[V+2>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535}at=av>>>24&15;if((at|0)==0|u^1){break}b[V>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535;break}}}while(0);ao=an+1|0;if((ao|0)>(P|0)){al=as;am=ar;break}else{Q=as;N=ar;L=aq;V=V+q|0;an=ao}}}if((ak|0)>(j|0)){aa=34103;break}else{I=al;J=am;K=ak}}if((aa|0)==34103){return}else if((aa|0)==34104){return}}function cyV(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0;f=c[3540994]|0;g=c[3528548]|0;h=g<<8;i=c[2385554]|0;do{if((i|0)>31){j=511}else{k=(i<<4)-1|0;if((k|0)>=0){j=k;break}return}}while(0);k=(j|0)>255;l=j&255;m=c[2385550]|0;n=c[2113042]|0;o=c[2113044]|0;p=n+512|0;q=c[2385552]|0;r=c[2113132]|0;s=q<<1;t=c[2112968]|0;u=q+7|0;v=(u|0)>-1&(u|0)<(r|0);u=q+6|0;w=(u|0)>-1&(u|0)<(r|0);u=q+5|0;x=(u|0)>-1&(u|0)<(r|0);u=q+4|0;y=(u|0)>-1&(u|0)<(r|0);u=q+3|0;z=(u|0)>-1&(u|0)<(r|0);u=q+2|0;A=(u|0)>-1&(u|0)<(r|0);u=q+1|0;B=(u|0)>-1&(u|0)<(r|0);u=(q|0)>-1&(q|0)<(r|0);q=r<<1;C=c[2415160]|0;D=c[2429858]|0;E=c[2430428]|0;F=c[2429718]|0;G=c[2430092]|0;H=c[3541046]|0;I=c[2430426]|0;J=0;K=0;L=0;L38691:while(1){M=(i|0)>16&(g|0)!=255;N=(i|0)<33;O=511-g|0;P=g+1|0;Q=g-255|0;R=~g;S=L;L38693:while(1){T=S+m|0;U=T&511;do{if((U|0)<(n|0)){V=S+n-U|0}else{if((U|0)>=(o|0)){V=p+S-U|0;break}W=(S|0)>255;X=W?16:0;Y=S&255;Z=(S|0)<256&k?255:l;if(!M){_=Z;$=Y;aa=X;ab=34128;break L38693}if(N){if(!W){ab=34118;break L38693}if((S|0)<(O|0)){V=O;break}else{ab=34120;break L38693}}if(W){ac=Q+Y|0;if((ac|0)>=0){ab=34123;break L38693}W=P+ac|0;if((W|0)<0){V=512;break}else{_=g;$=W;aa=0;ab=34128;break L38693}}else{if((Y|0)<=(g|0)){ab=34126;break L38693}W=Y+R|0;if((W|0)>(g|0)){V=256;break}else{_=g;$=W;aa=16;ab=34128;break L38693}}}}while(0);if((V|0)>(j|0)){ab=34177;break L38691}else{S=V}}if((ab|0)==34123){ab=0;ad=g;ae=X;af=ac;ah=P+S-ac|0}else if((ab|0)==34118){ab=0;ai=X;aj=Y;ak=Z;al=S+1-Y+Z|0;ab=34129}else if((ab|0)==34120){ab=0;R=255-g|0;_=Z-R|0;$=Y-R|0;aa=X;ab=34128}else if((ab|0)==34126){ab=0;ad=g;ae=X;af=Y;ah=P+S-Y|0}if((ab|0)==34128){ab=0;R=S+1-$+_|0;if(N){ai=aa;aj=$;ak=_;al=R;ab=34129}else{ad=_;ae=aa;af=$;ah=R}}if((ab|0)==34129){ab=0;ad=(ak|0)>(g|0)?g:ak;ae=ai;af=aj;ah=al}R=((T|-512)^511)+o|0;Q=(ad-af|0)>(R|0)?R+af|0:ad;if((af|0)>(Q|0)){am=J;an=K}else{R=J;O=K;M=-1;W=t+((ag(r,(U<<1)-32|0)|0)+s)|0;ao=af;while(1){ap=d[f+(ao+h)|0]|0;aq=(ap>>>4)+ae|0;do{if((aq|0)==(M|0)){ar=M;as=O;at=R}else{au=aq<<1;av=e[C+((au|1)<<1)>>1]|0;aw=(av<<12&983040|(e[C+(au<<1)>>1]|0))&D;do{if((av&8|0)==0){if((av&4|0)==0){ax=aw;break}ax=E|aw&1048572}else{ax=I|aw&1048568}}while(0);aw=a[F+ax|0]|0;au=aw&255;if(aw<<24>>24!=0){ar=aq;as=au;at=av;break}c[2385344]=G+(ax<<7);c[2440392]=H+((av>>>4&4080)<<2);ar=aq;as=au;at=av}}while(0);do{if((as|0)==0){aq=ap<<1&30;au=(at&2|0)==0?aq:aq^30;if((at&1|0)==0){aq=c[2385344]|0;aw=c[aq+(au<<2)>>2]|0;ay=aw&15;if(!((ay|0)==0|u^1)){b[W>>1]=c[(c[2440392]|0)+(ay<<2)>>2]&65535}ay=aw>>>8&15;if(!((ay|0)==0|B^1)){b[W+2>>1]=c[(c[2440392]|0)+(ay<<2)>>2]&65535}ay=aw>>>16&15;if(!((ay|0)==0|A^1)){b[W+4>>1]=c[(c[2440392]|0)+(ay<<2)>>2]&65535}ay=aw>>>24&15;if(!((ay|0)==0|z^1)){b[W+6>>1]=c[(c[2440392]|0)+(ay<<2)>>2]&65535}ay=c[aq+((au|1)<<2)>>2]|0;aq=ay&15;if(!((aq|0)==0|y^1)){b[W+8>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}aq=ay>>>8&15;if(!((aq|0)==0|x^1)){b[W+10>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}aq=ay>>>16&15;if(!((aq|0)==0|w^1)){b[W+12>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535}aq=ay>>>24&15;if((aq|0)==0|v^1){break}b[W+14>>1]=c[(c[2440392]|0)+(aq<<2)>>2]&65535;break}else{aq=c[2385344]|0;ay=c[aq+(au<<2)>>2]|0;aw=ay&15;if(!((aw|0)==0|v^1)){b[W+14>>1]=c[(c[2440392]|0)+(aw<<2)>>2]&65535}aw=ay>>>8&15;if(!((aw|0)==0|w^1)){b[W+12>>1]=c[(c[2440392]|0)+(aw<<2)>>2]&65535}aw=ay>>>16&15;if(!((aw|0)==0|x^1)){b[W+10>>1]=c[(c[2440392]|0)+(aw<<2)>>2]&65535}aw=ay>>>24&15;if(!((aw|0)==0|y^1)){b[W+8>>1]=c[(c[2440392]|0)+(aw<<2)>>2]&65535}aw=c[aq+((au|1)<<2)>>2]|0;au=aw&15;if(!((au|0)==0|z^1)){b[W+6>>1]=c[(c[2440392]|0)+(au<<2)>>2]&65535}au=aw>>>8&15;if(!((au|0)==0|A^1)){b[W+4>>1]=c[(c[2440392]|0)+(au<<2)>>2]&65535}au=aw>>>16&15;if(!((au|0)==0|B^1)){b[W+2>>1]=c[(c[2440392]|0)+(au<<2)>>2]&65535}au=aw>>>24&15;if((au|0)==0|u^1){break}b[W>>1]=c[(c[2440392]|0)+(au<<2)>>2]&65535;break}}}while(0);ap=ao+1|0;if((ap|0)>(Q|0)){am=at;an=as;break}else{R=at;O=as;M=ar;W=W+q|0;ao=ap}}}if((ah|0)>(j|0)){ab=34175;break}else{J=am;K=an;L=ah}}if((ab|0)==34175){return}else if((ab|0)==34177){return}}function cyW(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0;f=c[3540994]|0;g=c[3528548]|0;h=g<<8;i=c[2385554]|0;do{if((i|0)>31){j=511}else{k=(i<<4)-1|0;if((k|0)>=0){j=k;break}return}}while(0);k=(j|0)>255;l=j&255;m=c[2385550]|0;n=c[2113042]|0;o=c[2113044]|0;p=n+512|0;q=c[2385552]|0;r=c[2113132]|0;s=q<<1;t=c[2112968]|0;u=q+8|0;v=(u|0)>-1&(u|0)<(r|0);u=q+7|0;w=(u|0)>-1&(u|0)<(r|0);u=q+6|0;x=(u|0)>-1&(u|0)<(r|0);u=q+5|0;y=(u|0)>-1&(u|0)<(r|0);u=q+4|0;z=(u|0)>-1&(u|0)<(r|0);u=q+3|0;A=(u|0)>-1&(u|0)<(r|0);u=q+2|0;B=(u|0)>-1&(u|0)<(r|0);u=q+1|0;C=(u|0)>-1&(u|0)<(r|0);u=(q|0)>-1&(q|0)<(r|0);q=r<<1;D=c[2415160]|0;E=c[2429858]|0;F=c[2430428]|0;G=c[2429718]|0;H=c[2430092]|0;I=c[3541046]|0;J=c[2430426]|0;K=0;L=0;M=0;L38794:while(1){N=(i|0)>16&(g|0)!=255;O=(i|0)<33;P=511-g|0;Q=g+1|0;R=g-255|0;S=~g;T=M;L38796:while(1){U=T+m|0;V=U&511;do{if((V|0)<(n|0)){W=T+n-V|0}else{if((V|0)>=(o|0)){W=p+T-V|0;break}X=(T|0)>255;Y=X?16:0;Z=T&255;_=(T|0)<256&k?255:l;if(!N){$=_;aa=Z;ab=Y;ac=34201;break L38796}if(O){if(!X){ac=34191;break L38796}if((T|0)<(P|0)){W=P;break}else{ac=34193;break L38796}}if(X){ad=R+Z|0;if((ad|0)>=0){ac=34196;break L38796}X=Q+ad|0;if((X|0)<0){W=512;break}else{$=g;aa=X;ab=0;ac=34201;break L38796}}else{if((Z|0)<=(g|0)){ac=34199;break L38796}X=Z+S|0;if((X|0)>(g|0)){W=256;break}else{$=g;aa=X;ab=16;ac=34201;break L38796}}}}while(0);if((W|0)>(j|0)){ac=34254;break L38794}else{T=W}}if((ac|0)==34191){ac=0;ae=Y;af=Z;ah=_;ai=T+1-Z+_|0;ac=34202}else if((ac|0)==34196){ac=0;aj=g;ak=Y;al=ad;am=Q+T-ad|0}else if((ac|0)==34193){ac=0;S=255-g|0;$=_-S|0;aa=Z-S|0;ab=Y;ac=34201}else if((ac|0)==34199){ac=0;aj=g;ak=Y;al=Z;am=Q+T-Z|0}if((ac|0)==34201){ac=0;S=T+1-aa+$|0;if(O){ae=ab;af=aa;ah=$;ai=S;ac=34202}else{aj=$;ak=ab;al=aa;am=S}}if((ac|0)==34202){ac=0;aj=(ah|0)>(g|0)?g:ah;ak=ae;al=af;am=ai}S=((U|-512)^511)+o|0;R=(aj-al|0)>(S|0)?S+al|0:aj;if((al|0)>(R|0)){an=K;ao=L}else{S=K;P=L;N=-1;X=t+((ag(r,(V<<1)-32|0)|0)+s)|0;ap=al;while(1){aq=d[f+(ap+h)|0]|0;ar=(aq>>>4)+ak|0;do{if((ar|0)==(N|0)){as=N;at=P;au=S}else{av=ar<<1;aw=e[D+((av|1)<<1)>>1]|0;ax=(aw<<12&983040|(e[D+(av<<1)>>1]|0))&E;do{if((aw&8|0)==0){if((aw&4|0)==0){ay=ax;break}ay=F|ax&1048572}else{ay=J|ax&1048568}}while(0);ax=a[G+ay|0]|0;av=ax&255;if(ax<<24>>24!=0){as=ar;at=av;au=aw;break}c[2385344]=H+(ay<<7);c[2440392]=I+((aw>>>4&4080)<<2);as=ar;at=av;au=aw}}while(0);do{if((at|0)==0){ar=aq<<1&30;av=(au&2|0)==0?ar:ar^30;if((au&1|0)==0){ar=c[2385344]|0;ax=c[ar+(av<<2)>>2]|0;az=ax&15;if(!((az|0)==0|u^1)){b[X>>1]=c[(c[2440392]|0)+(az<<2)>>2]&65535}az=ax>>>8&15;if(!((az|0)==0|C^1)){b[X+2>>1]=c[(c[2440392]|0)+(az<<2)>>2]&65535}az=ax>>>16&15;if(!((az|0)==0|B^1)){b[X+4>>1]=c[(c[2440392]|0)+(az<<2)>>2]&65535}az=ax>>>24&15;if(!((az|0)==0|A^1)){b[X+6>>1]=c[(c[2440392]|0)+(az<<2)>>2]&65535}az=c[ar+((av|1)<<2)>>2]|0;ar=az&15;if(!((ar|0)==0|z^1)){b[X+8>>1]=c[(c[2440392]|0)+(ar<<2)>>2]&65535}ar=az>>>4&15;if(!((ar|0)==0|y^1)){b[X+10>>1]=c[(c[2440392]|0)+(ar<<2)>>2]&65535}ar=az>>>8&15;if(!((ar|0)==0|x^1)){b[X+12>>1]=c[(c[2440392]|0)+(ar<<2)>>2]&65535}ar=az>>>16&15;if(!((ar|0)==0|w^1)){b[X+14>>1]=c[(c[2440392]|0)+(ar<<2)>>2]&65535}ar=az>>>24&15;if((ar|0)==0|v^1){break}b[X+16>>1]=c[(c[2440392]|0)+(ar<<2)>>2]&65535;break}else{ar=c[2385344]|0;az=c[ar+(av<<2)>>2]|0;ax=az&15;if(!((ax|0)==0|v^1)){b[X+16>>1]=c[(c[2440392]|0)+(ax<<2)>>2]&65535}ax=az>>>8&15;if(!((ax|0)==0|w^1)){b[X+14>>1]=c[(c[2440392]|0)+(ax<<2)>>2]&65535}ax=az>>>16&15;if(!((ax|0)==0|x^1)){b[X+12>>1]=c[(c[2440392]|0)+(ax<<2)>>2]&65535}ax=az>>>24&15;if(!((ax|0)==0|y^1)){b[X+10>>1]=c[(c[2440392]|0)+(ax<<2)>>2]&65535}ax=c[ar+((av|1)<<2)>>2]|0;av=ax&15;if(!((av|0)==0|z^1)){b[X+8>>1]=c[(c[2440392]|0)+(av<<2)>>2]&65535}av=ax>>>4&15;if(!((av|0)==0|A^1)){b[X+6>>1]=c[(c[2440392]|0)+(av<<2)>>2]&65535}av=ax>>>8&15;if(!((av|0)==0|B^1)){b[X+4>>1]=c[(c[2440392]|0)+(av<<2)>>2]&65535}av=ax>>>16&15;if(!((av|0)==0|C^1)){b[X+2>>1]=c[(c[2440392]|0)+(av<<2)>>2]&65535}av=ax>>>24&15;if((av|0)==0|u^1){break}b[X>>1]=c[(c[2440392]|0)+(av<<2)>>2]&65535;break}}}while(0);aq=ap+1|0;if((aq|0)>(R|0)){an=au;ao=at;break}else{S=au;P=at;N=as;X=X+q|0;ap=aq}}}if((am|0)>(j|0)){ac=34253;break}else{K=an;L=ao;M=am}}if((ac|0)==34253){return}else if((ac|0)==34254){return}}function cyX(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0;f=c[3540994]|0;g=c[3528548]|0;h=g<<8;i=c[2385554]|0;do{if((i|0)>31){j=511}else{k=(i<<4)-1|0;if((k|0)>=0){j=k;break}return}}while(0);k=(j|0)>255;l=j&255;m=c[2385550]|0;n=c[2113042]|0;o=c[2113044]|0;p=n+512|0;q=c[2385552]|0;r=c[2113132]|0;s=q<<1;t=c[2112968]|0;u=q+9|0;v=(u|0)>-1&(u|0)<(r|0);u=q+8|0;w=(u|0)>-1&(u|0)<(r|0);u=q+7|0;x=(u|0)>-1&(u|0)<(r|0);u=q+6|0;y=(u|0)>-1&(u|0)<(r|0);u=q+5|0;z=(u|0)>-1&(u|0)<(r|0);u=q+4|0;A=(u|0)>-1&(u|0)<(r|0);u=q+3|0;B=(u|0)>-1&(u|0)<(r|0);u=q+2|0;C=(u|0)>-1&(u|0)<(r|0);u=q+1|0;D=(u|0)>-1&(u|0)<(r|0);u=(q|0)>-1&(q|0)<(r|0);q=r<<1;E=c[2415160]|0;F=c[2429858]|0;G=c[2430428]|0;H=c[2429718]|0;I=c[2430092]|0;J=c[3541046]|0;K=c[2430426]|0;L=0;M=0;N=0;L38903:while(1){O=(i|0)>16&(g|0)!=255;P=(i|0)<33;Q=511-g|0;R=g+1|0;S=g-255|0;T=~g;U=N;L38905:while(1){V=U+m|0;W=V&511;do{if((W|0)<(n|0)){X=U+n-W|0}else{if((W|0)>=(o|0)){X=p+U-W|0;break}Y=(U|0)>255;Z=Y?16:0;_=U&255;$=(U|0)<256&k?255:l;if(!O){aa=$;ab=_;ac=Z;ad=34278;break L38905}if(P){if(!Y){ad=34268;break L38905}if((U|0)<(Q|0)){X=Q;break}else{ad=34270;break L38905}}if(Y){ae=S+_|0;if((ae|0)>=0){ad=34273;break L38905}Y=R+ae|0;if((Y|0)<0){X=512;break}else{aa=g;ab=Y;ac=0;ad=34278;break L38905}}else{if((_|0)<=(g|0)){ad=34276;break L38905}Y=_+T|0;if((Y|0)>(g|0)){X=256;break}else{aa=g;ab=Y;ac=16;ad=34278;break L38905}}}}while(0);if((X|0)>(j|0)){ad=34335;break L38903}else{U=X}}if((ad|0)==34276){ad=0;af=g;ah=Z;ai=_;aj=R+U-_|0}else if((ad|0)==34268){ad=0;ak=Z;al=_;am=$;an=U+1-_+$|0;ad=34279}else if((ad|0)==34273){ad=0;af=g;ah=Z;ai=ae;aj=R+U-ae|0}else if((ad|0)==34270){ad=0;T=255-g|0;aa=$-T|0;ab=_-T|0;ac=Z;ad=34278}if((ad|0)==34278){ad=0;T=U+1-ab+aa|0;if(P){ak=ac;al=ab;am=aa;an=T;ad=34279}else{af=aa;ah=ac;ai=ab;aj=T}}if((ad|0)==34279){ad=0;af=(am|0)>(g|0)?g:am;ah=ak;ai=al;aj=an}T=((V|-512)^511)+o|0;S=(af-ai|0)>(T|0)?T+ai|0:af;if((ai|0)>(S|0)){ao=L;ap=M}else{T=L;Q=M;O=-1;Y=t+((ag(r,(W<<1)-32|0)|0)+s)|0;aq=ai;while(1){ar=d[f+(aq+h)|0]|0;as=(ar>>>4)+ah|0;do{if((as|0)==(O|0)){at=O;au=Q;av=T}else{aw=as<<1;ax=e[E+((aw|1)<<1)>>1]|0;ay=(ax<<12&983040|(e[E+(aw<<1)>>1]|0))&F;do{if((ax&8|0)==0){if((ax&4|0)==0){az=ay;break}az=G|ay&1048572}else{az=K|ay&1048568}}while(0);ay=a[H+az|0]|0;aw=ay&255;if(ay<<24>>24!=0){at=as;au=aw;av=ax;break}c[2385344]=I+(az<<7);c[2440392]=J+((ax>>>4&4080)<<2);at=as;au=aw;av=ax}}while(0);do{if((au|0)==0){as=ar<<1&30;aw=(av&2|0)==0?as:as^30;if((av&1|0)==0){as=c[2385344]|0;ay=c[as+(aw<<2)>>2]|0;aA=ay&15;if(!((aA|0)==0|u^1)){b[Y>>1]=c[(c[2440392]|0)+(aA<<2)>>2]&65535}aA=ay>>>8&15;if(!((aA|0)==0|D^1)){b[Y+2>>1]=c[(c[2440392]|0)+(aA<<2)>>2]&65535}aA=ay>>>12&15;if(!((aA|0)==0|C^1)){b[Y+4>>1]=c[(c[2440392]|0)+(aA<<2)>>2]&65535}aA=ay>>>16&15;if(!((aA|0)==0|B^1)){b[Y+6>>1]=c[(c[2440392]|0)+(aA<<2)>>2]&65535}aA=ay>>>24&15;if(!((aA|0)==0|A^1)){b[Y+8>>1]=c[(c[2440392]|0)+(aA<<2)>>2]&65535}aA=c[as+((aw|1)<<2)>>2]|0;as=aA&15;if(!((as|0)==0|z^1)){b[Y+10>>1]=c[(c[2440392]|0)+(as<<2)>>2]&65535}as=aA>>>4&15;if(!((as|0)==0|y^1)){b[Y+12>>1]=c[(c[2440392]|0)+(as<<2)>>2]&65535}as=aA>>>8&15;if(!((as|0)==0|x^1)){b[Y+14>>1]=c[(c[2440392]|0)+(as<<2)>>2]&65535}as=aA>>>16&15;if(!((as|0)==0|w^1)){b[Y+16>>1]=c[(c[2440392]|0)+(as<<2)>>2]&65535}as=aA>>>24&15;if((as|0)==0|v^1){break}b[Y+18>>1]=c[(c[2440392]|0)+(as<<2)>>2]&65535;break}else{as=c[2385344]|0;aA=c[as+(aw<<2)>>2]|0;ay=aA&15;if(!((ay|0)==0|v^1)){b[Y+18>>1]=c[(c[2440392]|0)+(ay<<2)>>2]&65535}ay=aA>>>8&15;if(!((ay|0)==0|w^1)){b[Y+16>>1]=c[(c[2440392]|0)+(ay<<2)>>2]&65535}ay=aA>>>12&15;if(!((ay|0)==0|x^1)){b[Y+14>>1]=c[(c[2440392]|0)+(ay<<2)>>2]&65535}ay=aA>>>16&15;if(!((ay|0)==0|y^1)){b[Y+12>>1]=c[(c[2440392]|0)+(ay<<2)>>2]&65535}ay=aA>>>24&15;if(!((ay|0)==0|z^1)){b[Y+10>>1]=c[(c[2440392]|0)+(ay<<2)>>2]&65535}ay=c[as+((aw|1)<<2)>>2]|0;aw=ay&15;if(!((aw|0)==0|A^1)){b[Y+8>>1]=c[(c[2440392]|0)+(aw<<2)>>2]&65535}aw=ay>>>4&15;if(!((aw|0)==0|B^1)){b[Y+6>>1]=c[(c[2440392]|0)+(aw<<2)>>2]&65535}aw=ay>>>8&15;if(!((aw|0)==0|C^1)){b[Y+4>>1]=c[(c[2440392]|0)+(aw<<2)>>2]&65535}aw=ay>>>16&15;if(!((aw|0)==0|D^1)){b[Y+2>>1]=c[(c[2440392]|0)+(aw<<2)>>2]&65535}aw=ay>>>24&15;if((aw|0)==0|u^1){break}b[Y>>1]=c[(c[2440392]|0)+(aw<<2)>>2]&65535;break}}}while(0);ar=aq+1|0;if((ar|0)>(S|0)){ao=av;ap=au;break}else{T=av;Q=au;O=at;Y=Y+q|0;aq=ar}}}if((aj|0)>(j|0)){ad=34333;break}else{L=ao;M=ap;N=aj}}if((ad|0)==34333){return}else if((ad|0)==34335){return}}function cyY(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0;f=c[3540994]|0;g=c[3528548]|0;h=g<<8;i=c[2385554]|0;do{if((i|0)>31){j=511}else{k=(i<<4)-1|0;if((k|0)>=0){j=k;break}return}}while(0);k=(j|0)>255;l=j&255;m=c[2385550]|0;n=c[2113042]|0;o=c[2113044]|0;p=n+512|0;q=c[2385552]|0;r=c[2113132]|0;s=q<<1;t=c[2112968]|0;u=q+10|0;v=(u|0)>-1&(u|0)<(r|0);u=q+9|0;w=(u|0)>-1&(u|0)<(r|0);u=q+8|0;x=(u|0)>-1&(u|0)<(r|0);u=q+7|0;y=(u|0)>-1&(u|0)<(r|0);u=q+6|0;z=(u|0)>-1&(u|0)<(r|0);u=q+5|0;A=(u|0)>-1&(u|0)<(r|0);u=q+4|0;B=(u|0)>-1&(u|0)<(r|0);u=q+3|0;C=(u|0)>-1&(u|0)<(r|0);u=q+2|0;D=(u|0)>-1&(u|0)<(r|0);u=q+1|0;E=(u|0)>-1&(u|0)<(r|0);u=(q|0)>-1&(q|0)<(r|0);q=r<<1;F=c[2415160]|0;G=c[2429858]|0;H=c[2430428]|0;I=c[2429718]|0;J=c[2430092]|0;K=c[3541046]|0;L=c[2430426]|0;M=0;N=0;O=0;L39018:while(1){P=(i|0)>16&(g|0)!=255;Q=(i|0)<33;R=511-g|0;S=g+1|0;T=g-255|0;U=~g;V=O;L39020:while(1){W=V+m|0;X=W&511;do{if((X|0)<(n|0)){Y=V+n-X|0}else{if((X|0)>=(o|0)){Y=p+V-X|0;break}Z=(V|0)>255;_=Z?16:0;$=V&255;aa=(V|0)<256&k?255:l;if(!P){ab=aa;ac=$;ad=_;ae=34359;break L39020}if(Q){if(!Z){ae=34349;break L39020}if((V|0)<(R|0)){Y=R;break}else{ae=34351;break L39020}}if(Z){af=T+$|0;if((af|0)>=0){ae=34354;break L39020}Z=S+af|0;if((Z|0)<0){Y=512;break}else{ab=g;ac=Z;ad=0;ae=34359;break L39020}}else{if(($|0)<=(g|0)){ae=34357;break L39020}Z=$+U|0;if((Z|0)>(g|0)){Y=256;break}else{ab=g;ac=Z;ad=16;ae=34359;break L39020}}}}while(0);if((Y|0)>(j|0)){ae=34420;break L39018}else{V=Y}}if((ae|0)==34349){ae=0;ah=_;ai=$;aj=aa;ak=V+1-$+aa|0;ae=34360}else if((ae|0)==34354){ae=0;al=g;am=_;an=af;ao=S+V-af|0}else if((ae|0)==34351){ae=0;U=255-g|0;ab=aa-U|0;ac=$-U|0;ad=_;ae=34359}else if((ae|0)==34357){ae=0;al=g;am=_;an=$;ao=S+V-$|0}if((ae|0)==34359){ae=0;U=V+1-ac+ab|0;if(Q){ah=ad;ai=ac;aj=ab;ak=U;ae=34360}else{al=ab;am=ad;an=ac;ao=U}}if((ae|0)==34360){ae=0;al=(aj|0)>(g|0)?g:aj;am=ah;an=ai;ao=ak}U=((W|-512)^511)+o|0;T=(al-an|0)>(U|0)?U+an|0:al;if((an|0)>(T|0)){ap=M;aq=N}else{U=M;R=N;P=-1;Z=t+((ag(r,(X<<1)-32|0)|0)+s)|0;ar=an;while(1){as=d[f+(ar+h)|0]|0;at=(as>>>4)+am|0;do{if((at|0)==(P|0)){au=P;av=R;aw=U}else{ax=at<<1;ay=e[F+((ax|1)<<1)>>1]|0;az=(ay<<12&983040|(e[F+(ax<<1)>>1]|0))&G;do{if((ay&8|0)==0){if((ay&4|0)==0){aA=az;break}aA=H|az&1048572}else{aA=L|az&1048568}}while(0);az=a[I+aA|0]|0;ax=az&255;if(az<<24>>24!=0){au=at;av=ax;aw=ay;break}c[2385344]=J+(aA<<7);c[2440392]=K+((ay>>>4&4080)<<2);au=at;av=ax;aw=ay}}while(0);do{if((av|0)==0){at=as<<1&30;ax=(aw&2|0)==0?at:at^30;if((aw&1|0)==0){at=c[2385344]|0;az=c[at+(ax<<2)>>2]|0;aB=az&15;if(!((aB|0)==0|u^1)){b[Z>>1]=c[(c[2440392]|0)+(aB<<2)>>2]&65535}aB=az>>>8&15;if(!((aB|0)==0|E^1)){b[Z+2>>1]=c[(c[2440392]|0)+(aB<<2)>>2]&65535}aB=az>>>12&15;if(!((aB|0)==0|D^1)){b[Z+4>>1]=c[(c[2440392]|0)+(aB<<2)>>2]&65535}aB=az>>>16&15;if(!((aB|0)==0|C^1)){b[Z+6>>1]=c[(c[2440392]|0)+(aB<<2)>>2]&65535}aB=az>>>24&15;if(!((aB|0)==0|B^1)){b[Z+8>>1]=c[(c[2440392]|0)+(aB<<2)>>2]&65535}aB=c[at+((ax|1)<<2)>>2]|0;at=aB&15;if(!((at|0)==0|A^1)){b[Z+10>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535}at=aB>>>4&15;if(!((at|0)==0|z^1)){b[Z+12>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535}at=aB>>>8&15;if(!((at|0)==0|y^1)){b[Z+14>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535}at=aB>>>16&15;if(!((at|0)==0|x^1)){b[Z+16>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535}at=aB>>>24&15;if(!((at|0)==0|w^1)){b[Z+18>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535}at=aB>>>28;if((at|0)==0|v^1){break}b[Z+20>>1]=c[(c[2440392]|0)+(at<<2)>>2]&65535;break}else{at=c[2385344]|0;aB=c[at+(ax<<2)>>2]|0;az=aB&15;if(!((az|0)==0|v^1)){b[Z+20>>1]=c[(c[2440392]|0)+(az<<2)>>2]&65535}az=aB>>>8&15;if(!((az|0)==0|w^1)){b[Z+18>>1]=c[(c[2440392]|0)+(az<<2)>>2]&65535}az=aB>>>12&15;if(!((az|0)==0|x^1)){b[Z+16>>1]=c[(c[2440392]|0)+(az<<2)>>2]&65535}az=aB>>>16&15;if(!((az|0)==0|y^1)){b[Z+14>>1]=c[(c[2440392]|0)+(az<<2)>>2]&65535}az=aB>>>24&15;if(!((az|0)==0|z^1)){b[Z+12>>1]=c[(c[2440392]|0)+(az<<2)>>2]&65535}az=c[at+((ax|1)<<2)>>2]|0;ax=az&15;if(!((ax|0)==0|A^1)){b[Z+10>>1]=c[(c[2440392]|0)+(ax<<2)>>2]&65535}ax=az>>>4&15;if(!((ax|0)==0|B^1)){b[Z+8>>1]=c[(c[2440392]|0)+(ax<<2)>>2]&65535}ax=az>>>8&15;if(!((ax|0)==0|C^1)){b[Z+6>>1]=c[(c[2440392]|0)+(ax<<2)>>2]&65535}ax=az>>>16&15;if(!((ax|0)==0|D^1)){b[Z+4>>1]=c[(c[2440392]|0)+(ax<<2)>>2]&65535}ax=az>>>24&15;if(!((ax|0)==0|E^1)){b[Z+2>>1]=c[(c[2440392]|0)+(ax<<2)>>2]&65535}ax=az>>>28;if((ax|0)==0|u^1){break}b[Z>>1]=c[(c[2440392]|0)+(ax<<2)>>2]&65535;break}}}while(0);as=ar+1|0;if((as|0)>(T|0)){ap=aw;aq=av;break}else{U=aw;R=av;P=au;Z=Z+q|0;ar=as}}}if((ao|0)>(j|0)){ae=34419;break}else{M=ap;N=aq;O=ao}}if((ae|0)==34419){return}else if((ae|0)==34420){return}}function cyZ(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0;f=c[3540994]|0;g=c[3528548]|0;h=g<<8;i=c[2385554]|0;do{if((i|0)>31){j=511}else{k=(i<<4)-1|0;if((k|0)>=0){j=k;break}return}}while(0);k=(j|0)>255;l=j&255;m=c[2385550]|0;n=c[2113042]|0;o=c[2113044]|0;p=n+512|0;q=c[2385552]|0;r=c[2113132]|0;s=q<<1;t=c[2112968]|0;u=q+11|0;v=(u|0)>-1&(u|0)<(r|0);u=q+10|0;w=(u|0)>-1&(u|0)<(r|0);u=q+9|0;x=(u|0)>-1&(u|0)<(r|0);u=q+8|0;y=(u|0)>-1&(u|0)<(r|0);u=q+7|0;z=(u|0)>-1&(u|0)<(r|0);u=q+6|0;A=(u|0)>-1&(u|0)<(r|0);u=q+5|0;B=(u|0)>-1&(u|0)<(r|0);u=q+4|0;C=(u|0)>-1&(u|0)<(r|0);u=q+3|0;D=(u|0)>-1&(u|0)<(r|0);u=q+2|0;E=(u|0)>-1&(u|0)<(r|0);u=q+1|0;F=(u|0)>-1&(u|0)<(r|0);u=(q|0)>-1&(q|0)<(r|0);q=r<<1;G=c[2415160]|0;H=c[2429858]|0;I=c[2430428]|0;J=c[2429718]|0;K=c[2430092]|0;L=c[3541046]|0;M=c[2430426]|0;N=0;O=0;P=0;L39139:while(1){Q=(i|0)>16&(g|0)!=255;R=(i|0)<33;S=511-g|0;T=g+1|0;U=g-255|0;V=~g;W=P;L39141:while(1){X=W+m|0;Y=X&511;do{if((Y|0)<(n|0)){Z=W+n-Y|0}else{if((Y|0)>=(o|0)){Z=p+W-Y|0;break}_=(W|0)>255;$=_?16:0;aa=W&255;ab=(W|0)<256&k?255:l;if(!Q){ac=ab;ad=aa;ae=$;af=34444;break L39141}if(R){if(!_){af=34434;break L39141}if((W|0)<(S|0)){Z=S;break}else{af=34436;break L39141}}if(_){ah=U+aa|0;if((ah|0)>=0){af=34439;break L39141}_=T+ah|0;if((_|0)<0){Z=512;break}else{ac=g;ad=_;ae=0;af=34444;break L39141}}else{if((aa|0)<=(g|0)){af=34442;break L39141}_=aa+V|0;if((_|0)>(g|0)){Z=256;break}else{ac=g;ad=_;ae=16;af=34444;break L39141}}}}while(0);if((Z|0)>(j|0)){af=34509;break L39139}else{W=Z}}if((af|0)==34434){af=0;ai=$;aj=aa;ak=ab;al=W+1-aa+ab|0;af=34445}else if((af|0)==34436){af=0;V=255-g|0;ac=ab-V|0;ad=aa-V|0;ae=$;af=34444}else if((af|0)==34442){af=0;am=g;an=$;ao=aa;ap=T+W-aa|0}else if((af|0)==34439){af=0;am=g;an=$;ao=ah;ap=T+W-ah|0}if((af|0)==34444){af=0;V=W+1-ad+ac|0;if(R){ai=ae;aj=ad;ak=ac;al=V;af=34445}else{am=ac;an=ae;ao=ad;ap=V}}if((af|0)==34445){af=0;am=(ak|0)>(g|0)?g:ak;an=ai;ao=aj;ap=al}V=((X|-512)^511)+o|0;U=(am-ao|0)>(V|0)?V+ao|0:am;if((ao|0)>(U|0)){aq=N;ar=O}else{V=N;S=O;Q=-1;_=t+((ag(r,(Y<<1)-32|0)|0)+s)|0;as=ao;while(1){at=d[f+(as+h)|0]|0;au=(at>>>4)+an|0;do{if((au|0)==(Q|0)){av=Q;aw=S;ax=V}else{ay=au<<1;az=e[G+((ay|1)<<1)>>1]|0;aA=(az<<12&983040|(e[G+(ay<<1)>>1]|0))&H;do{if((az&8|0)==0){if((az&4|0)==0){aB=aA;break}aB=I|aA&1048572}else{aB=M|aA&1048568}}while(0);aA=a[J+aB|0]|0;ay=aA&255;if(aA<<24>>24!=0){av=au;aw=ay;ax=az;break}c[2385344]=K+(aB<<7);c[2440392]=L+((az>>>4&4080)<<2);av=au;aw=ay;ax=az}}while(0);do{if((aw|0)==0){au=at<<1&30;ay=(ax&2|0)==0?au:au^30;if((ax&1|0)==0){au=c[2385344]|0;aA=c[au+(ay<<2)>>2]|0;aC=aA&15;if(!((aC|0)==0|u^1)){b[_>>1]=c[(c[2440392]|0)+(aC<<2)>>2]&65535}aC=aA>>>8&15;if(!((aC|0)==0|F^1)){b[_+2>>1]=c[(c[2440392]|0)+(aC<<2)>>2]&65535}aC=aA>>>12&15;if(!((aC|0)==0|E^1)){b[_+4>>1]=c[(c[2440392]|0)+(aC<<2)>>2]&65535}aC=aA>>>16&15;if(!((aC|0)==0|D^1)){b[_+6>>1]=c[(c[2440392]|0)+(aC<<2)>>2]&65535}aC=aA>>>24&15;if(!((aC|0)==0|C^1)){b[_+8>>1]=c[(c[2440392]|0)+(aC<<2)>>2]&65535}aC=aA>>>28;if(!((aC|0)==0|B^1)){b[_+10>>1]=c[(c[2440392]|0)+(aC<<2)>>2]&65535}aC=c[au+((ay|1)<<2)>>2]|0;au=aC&15;if(!((au|0)==0|A^1)){b[_+12>>1]=c[(c[2440392]|0)+(au<<2)>>2]&65535}au=aC>>>4&15;if(!((au|0)==0|z^1)){b[_+14>>1]=c[(c[2440392]|0)+(au<<2)>>2]&65535}au=aC>>>8&15;if(!((au|0)==0|y^1)){b[_+16>>1]=c[(c[2440392]|0)+(au<<2)>>2]&65535}au=aC>>>16&15;if(!((au|0)==0|x^1)){b[_+18>>1]=c[(c[2440392]|0)+(au<<2)>>2]&65535}au=aC>>>24&15;if(!((au|0)==0|w^1)){b[_+20>>1]=c[(c[2440392]|0)+(au<<2)>>2]&65535}au=aC>>>28;if((au|0)==0|v^1){break}b[_+22>>1]=c[(c[2440392]|0)+(au<<2)>>2]&65535;break}else{au=c[2385344]|0;aC=c[au+(ay<<2)>>2]|0;aA=aC&15;if(!((aA|0)==0|v^1)){b[_+22>>1]=c[(c[2440392]|0)+(aA<<2)>>2]&65535}aA=aC>>>8&15;if(!((aA|0)==0|w^1)){b[_+20>>1]=c[(c[2440392]|0)+(aA<<2)>>2]&65535}aA=aC>>>12&15;if(!((aA|0)==0|x^1)){b[_+18>>1]=c[(c[2440392]|0)+(aA<<2)>>2]&65535}aA=aC>>>16&15;if(!((aA|0)==0|y^1)){b[_+16>>1]=c[(c[2440392]|0)+(aA<<2)>>2]&65535}aA=aC>>>24&15;if(!((aA|0)==0|z^1)){b[_+14>>1]=c[(c[2440392]|0)+(aA<<2)>>2]&65535}aA=aC>>>28;if(!((aA|0)==0|A^1)){b[_+12>>1]=c[(c[2440392]|0)+(aA<<2)>>2]&65535}aA=c[au+((ay|1)<<2)>>2]|0;ay=aA&15;if(!((ay|0)==0|B^1)){b[_+10>>1]=c[(c[2440392]|0)+(ay<<2)>>2]&65535}ay=aA>>>4&15;if(!((ay|0)==0|C^1)){b[_+8>>1]=c[(c[2440392]|0)+(ay<<2)>>2]&65535}ay=aA>>>8&15;if(!((ay|0)==0|D^1)){b[_+6>>1]=c[(c[2440392]|0)+(ay<<2)>>2]&65535}ay=aA>>>16&15;if(!((ay|0)==0|E^1)){b[_+4>>1]=c[(c[2440392]|0)+(ay<<2)>>2]&65535}ay=aA>>>24&15;if(!((ay|0)==0|F^1)){b[_+2>>1]=c[(c[2440392]|0)+(ay<<2)>>2]&65535}ay=aA>>>28;if((ay|0)==0|u^1){break}b[_>>1]=c[(c[2440392]|0)+(ay<<2)>>2]&65535;break}}}while(0);at=as+1|0;if((at|0)>(U|0)){aq=ax;ar=aw;break}else{V=ax;S=aw;Q=av;_=_+q|0;as=at}}}if((ap|0)>(j|0)){af=34507;break}else{N=aq;O=ar;P=ap}}if((af|0)==34507){return}else if((af|0)==34509){return}}function cy_(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0;f=c[3540994]|0;g=c[3528548]|0;h=g<<8;i=c[2385554]|0;do{if((i|0)>31){j=511}else{k=(i<<4)-1|0;if((k|0)>=0){j=k;break}return}}while(0);k=(j|0)>255;l=j&255;m=c[2385550]|0;n=c[2113042]|0;o=c[2113044]|0;p=n+512|0;q=c[2385552]|0;r=c[2113132]|0;s=q<<1;t=c[2112968]|0;u=q+12|0;v=(u|0)>-1&(u|0)<(r|0);u=q+11|0;w=(u|0)>-1&(u|0)<(r|0);u=q+10|0;x=(u|0)>-1&(u|0)<(r|0);u=q+9|0;y=(u|0)>-1&(u|0)<(r|0);u=q+8|0;z=(u|0)>-1&(u|0)<(r|0);u=q+7|0;A=(u|0)>-1&(u|0)<(r|0);u=q+6|0;B=(u|0)>-1&(u|0)<(r|0);u=q+5|0;C=(u|0)>-1&(u|0)<(r|0);u=q+4|0;D=(u|0)>-1&(u|0)<(r|0);u=q+3|0;E=(u|0)>-1&(u|0)<(r|0);u=q+2|0;F=(u|0)>-1&(u|0)<(r|0);u=q+1|0;G=(u|0)>-1&(u|0)<(r|0);u=(q|0)>-1&(q|0)<(r|0);q=r<<1;H=c[2415160]|0;I=c[2429858]|0;J=c[2430428]|0;K=c[2429718]|0;L=c[2430092]|0;M=c[3541046]|0;N=c[2430426]|0;O=0;P=0;Q=0;L39266:while(1){R=(i|0)>16&(g|0)!=255;S=(i|0)<33;T=511-g|0;U=g+1|0;V=g-255|0;W=~g;X=Q;L39268:while(1){Y=X+m|0;Z=Y&511;do{if((Z|0)<(n|0)){_=X+n-Z|0}else{if((Z|0)>=(o|0)){_=p+X-Z|0;break}$=(X|0)>255;aa=$?16:0;ab=X&255;ac=(X|0)<256&k?255:l;if(!R){ad=ac;ae=ab;af=aa;ah=34533;break L39268}if(S){if(!$){ah=34523;break L39268}if((X|0)<(T|0)){_=T;break}else{ah=34525;break L39268}}if($){ai=V+ab|0;if((ai|0)>=0){ah=34528;break L39268}$=U+ai|0;if(($|0)<0){_=512;break}else{ad=g;ae=$;af=0;ah=34533;break L39268}}else{if((ab|0)<=(g|0)){ah=34531;break L39268}$=ab+W|0;if(($|0)>(g|0)){_=256;break}else{ad=g;ae=$;af=16;ah=34533;break L39268}}}}while(0);if((_|0)>(j|0)){ah=34602;break L39266}else{X=_}}if((ah|0)==34528){ah=0;aj=g;ak=aa;al=ai;am=U+X-ai|0}else if((ah|0)==34531){ah=0;aj=g;ak=aa;al=ab;am=U+X-ab|0}else if((ah|0)==34523){ah=0;an=aa;ao=ab;ap=ac;aq=X+1-ab+ac|0;ah=34534}else if((ah|0)==34525){ah=0;W=255-g|0;ad=ac-W|0;ae=ab-W|0;af=aa;ah=34533}if((ah|0)==34533){ah=0;W=X+1-ae+ad|0;if(S){an=af;ao=ae;ap=ad;aq=W;ah=34534}else{aj=ad;ak=af;al=ae;am=W}}if((ah|0)==34534){ah=0;aj=(ap|0)>(g|0)?g:ap;ak=an;al=ao;am=aq}W=((Y|-512)^511)+o|0;V=(aj-al|0)>(W|0)?W+al|0:aj;if((al|0)>(V|0)){ar=O;as=P}else{W=O;T=P;R=-1;$=t+((ag(r,(Z<<1)-32|0)|0)+s)|0;at=al;while(1){au=d[f+(at+h)|0]|0;av=(au>>>4)+ak|0;do{if((av|0)==(R|0)){aw=R;ax=T;ay=W}else{az=av<<1;aA=e[H+((az|1)<<1)>>1]|0;aB=(aA<<12&983040|(e[H+(az<<1)>>1]|0))&I;do{if((aA&8|0)==0){if((aA&4|0)==0){aC=aB;break}aC=J|aB&1048572}else{aC=N|aB&1048568}}while(0);aB=a[K+aC|0]|0;az=aB&255;if(aB<<24>>24!=0){aw=av;ax=az;ay=aA;break}c[2385344]=L+(aC<<7);c[2440392]=M+((aA>>>4&4080)<<2);aw=av;ax=az;ay=aA}}while(0);do{if((ax|0)==0){av=au<<1&30;az=(ay&2|0)==0?av:av^30;if((ay&1|0)==0){av=c[2385344]|0;aB=c[av+(az<<2)>>2]|0;aD=aB&15;if(!((aD|0)==0|u^1)){b[$>>1]=c[(c[2440392]|0)+(aD<<2)>>2]&65535}aD=aB>>>8&15;if(!((aD|0)==0|G^1)){b[$+2>>1]=c[(c[2440392]|0)+(aD<<2)>>2]&65535}aD=aB>>>12&15;if(!((aD|0)==0|F^1)){b[$+4>>1]=c[(c[2440392]|0)+(aD<<2)>>2]&65535}aD=aB>>>16&15;if(!((aD|0)==0|E^1)){b[$+6>>1]=c[(c[2440392]|0)+(aD<<2)>>2]&65535}aD=aB>>>24&15;if(!((aD|0)==0|D^1)){b[$+8>>1]=c[(c[2440392]|0)+(aD<<2)>>2]&65535}aD=aB>>>28;if(!((aD|0)==0|C^1)){b[$+10>>1]=c[(c[2440392]|0)+(aD<<2)>>2]&65535}aD=c[av+((az|1)<<2)>>2]|0;av=aD&15;if(!((av|0)==0|B^1)){b[$+12>>1]=c[(c[2440392]|0)+(av<<2)>>2]&65535}av=aD>>>4&15;if(!((av|0)==0|A^1)){b[$+14>>1]=c[(c[2440392]|0)+(av<<2)>>2]&65535}av=aD>>>8&15;if(!((av|0)==0|z^1)){b[$+16>>1]=c[(c[2440392]|0)+(av<<2)>>2]&65535}av=aD>>>16&15;if(!((av|0)==0|y^1)){b[$+18>>1]=c[(c[2440392]|0)+(av<<2)>>2]&65535}av=aD>>>20&15;if(!((av|0)==0|x^1)){b[$+20>>1]=c[(c[2440392]|0)+(av<<2)>>2]&65535}av=aD>>>24&15;if(!((av|0)==0|w^1)){b[$+22>>1]=c[(c[2440392]|0)+(av<<2)>>2]&65535}av=aD>>>28;if((av|0)==0|v^1){break}b[$+24>>1]=c[(c[2440392]|0)+(av<<2)>>2]&65535;break}else{av=c[2385344]|0;aD=c[av+(az<<2)>>2]|0;aB=aD&15;if(!((aB|0)==0|v^1)){b[$+24>>1]=c[(c[2440392]|0)+(aB<<2)>>2]&65535}aB=aD>>>8&15;if(!((aB|0)==0|w^1)){b[$+22>>1]=c[(c[2440392]|0)+(aB<<2)>>2]&65535}aB=aD>>>12&15;if(!((aB|0)==0|x^1)){b[$+20>>1]=c[(c[2440392]|0)+(aB<<2)>>2]&65535}aB=aD>>>16&15;if(!((aB|0)==0|y^1)){b[$+18>>1]=c[(c[2440392]|0)+(aB<<2)>>2]&65535}aB=aD>>>24&15;if(!((aB|0)==0|z^1)){b[$+16>>1]=c[(c[2440392]|0)+(aB<<2)>>2]&65535}aB=aD>>>28;if(!((aB|0)==0|A^1)){b[$+14>>1]=c[(c[2440392]|0)+(aB<<2)>>2]&65535}aB=c[av+((az|1)<<2)>>2]|0;az=aB&15;if(!((az|0)==0|B^1)){b[$+12>>1]=c[(c[2440392]|0)+(az<<2)>>2]&65535}az=aB>>>4&15;if(!((az|0)==0|C^1)){b[$+10>>1]=c[(c[2440392]|0)+(az<<2)>>2]&65535}az=aB>>>8&15;if(!((az|0)==0|D^1)){b[$+8>>1]=c[(c[2440392]|0)+(az<<2)>>2]&65535}az=aB>>>16&15;if(!((az|0)==0|E^1)){b[$+6>>1]=c[(c[2440392]|0)+(az<<2)>>2]&65535}az=aB>>>20&15;if(!((az|0)==0|F^1)){b[$+4>>1]=c[(c[2440392]|0)+(az<<2)>>2]&65535}az=aB>>>24&15;if(!((az|0)==0|G^1)){b[$+2>>1]=c[(c[2440392]|0)+(az<<2)>>2]&65535}az=aB>>>28;if((az|0)==0|u^1){break}b[$>>1]=c[(c[2440392]|0)+(az<<2)>>2]&65535;break}}}while(0);au=at+1|0;if((au|0)>(V|0)){ar=ay;as=ax;break}else{W=ay;T=ax;R=aw;$=$+q|0;at=au}}}if((am|0)>(j|0)){ah=34601;break}else{O=ar;P=as;Q=am}}if((ah|0)==34601){return}else if((ah|0)==34602){return}}function cy$(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0;f=c[3540994]|0;g=c[3528548]|0;h=g<<8;i=c[2385554]|0;do{if((i|0)>31){j=511}else{k=(i<<4)-1|0;if((k|0)>=0){j=k;break}return}}while(0);k=(j|0)>255;l=j&255;m=c[2385550]|0;n=c[2113042]|0;o=c[2113044]|0;p=n+512|0;q=c[2385552]|0;r=c[2113132]|0;s=q<<1;t=c[2112968]|0;u=q+13|0;v=(u|0)>-1&(u|0)<(r|0);u=q+12|0;w=(u|0)>-1&(u|0)<(r|0);u=q+11|0;x=(u|0)>-1&(u|0)<(r|0);u=q+10|0;y=(u|0)>-1&(u|0)<(r|0);u=q+9|0;z=(u|0)>-1&(u|0)<(r|0);u=q+8|0;A=(u|0)>-1&(u|0)<(r|0);u=q+7|0;B=(u|0)>-1&(u|0)<(r|0);u=q+6|0;C=(u|0)>-1&(u|0)<(r|0);u=q+5|0;D=(u|0)>-1&(u|0)<(r|0);u=q+4|0;E=(u|0)>-1&(u|0)<(r|0);u=q+3|0;F=(u|0)>-1&(u|0)<(r|0);u=q+2|0;G=(u|0)>-1&(u|0)<(r|0);u=q+1|0;H=(u|0)>-1&(u|0)<(r|0);u=(q|0)>-1&(q|0)<(r|0);q=r<<1;I=c[2415160]|0;J=c[2429858]|0;K=c[2430428]|0;L=c[2429718]|0;M=c[2430092]|0;N=c[3541046]|0;O=c[2430426]|0;P=0;Q=0;R=0;L39399:while(1){S=(i|0)>16&(g|0)!=255;T=(i|0)<33;U=511-g|0;V=g+1|0;W=g-255|0;X=~g;Y=R;L39401:while(1){Z=Y+m|0;_=Z&511;do{if((_|0)<(n|0)){$=Y+n-_|0}else{if((_|0)>=(o|0)){$=p+Y-_|0;break}aa=(Y|0)>255;ab=aa?16:0;ac=Y&255;ad=(Y|0)<256&k?255:l;if(!S){ae=ad;af=ac;ah=ab;ai=34626;break L39401}if(T){if(!aa){ai=34616;break L39401}if((Y|0)<(U|0)){$=U;break}else{ai=34618;break L39401}}if(aa){aj=W+ac|0;if((aj|0)>=0){ai=34621;break L39401}aa=V+aj|0;if((aa|0)<0){$=512;break}else{ae=g;af=aa;ah=0;ai=34626;break L39401}}else{if((ac|0)<=(g|0)){ai=34624;break L39401}aa=ac+X|0;if((aa|0)>(g|0)){$=256;break}else{ae=g;af=aa;ah=16;ai=34626;break L39401}}}}while(0);if(($|0)>(j|0)){ai=34699;break L39399}else{Y=$}}if((ai|0)==34621){ai=0;ak=g;al=ab;am=aj;an=V+Y-aj|0}else if((ai|0)==34624){ai=0;ak=g;al=ab;am=ac;an=V+Y-ac|0}else if((ai|0)==34616){ai=0;ao=ab;ap=ac;aq=ad;ar=Y+1-ac+ad|0;ai=34627}else if((ai|0)==34618){ai=0;X=255-g|0;ae=ad-X|0;af=ac-X|0;ah=ab;ai=34626}if((ai|0)==34626){ai=0;X=Y+1-af+ae|0;if(T){ao=ah;ap=af;aq=ae;ar=X;ai=34627}else{ak=ae;al=ah;am=af;an=X}}if((ai|0)==34627){ai=0;ak=(aq|0)>(g|0)?g:aq;al=ao;am=ap;an=ar}X=((Z|-512)^511)+o|0;W=(ak-am|0)>(X|0)?X+am|0:ak;if((am|0)>(W|0)){as=P;at=Q}else{X=P;U=Q;S=-1;aa=t+((ag(r,(_<<1)-32|0)|0)+s)|0;au=am;while(1){av=d[f+(au+h)|0]|0;aw=(av>>>4)+al|0;do{if((aw|0)==(S|0)){ax=S;ay=U;az=X}else{aA=aw<<1;aB=e[I+((aA|1)<<1)>>1]|0;aC=(aB<<12&983040|(e[I+(aA<<1)>>1]|0))&J;do{if((aB&8|0)==0){if((aB&4|0)==0){aD=aC;break}aD=K|aC&1048572}else{aD=O|aC&1048568}}while(0);aC=a[L+aD|0]|0;aA=aC&255;if(aC<<24>>24!=0){ax=aw;ay=aA;az=aB;break}c[2385344]=M+(aD<<7);c[2440392]=N+((aB>>>4&4080)<<2);ax=aw;ay=aA;az=aB}}while(0);do{if((ay|0)==0){aw=av<<1&30;aA=(az&2|0)==0?aw:aw^30;if((az&1|0)==0){aw=c[2385344]|0;aC=c[aw+(aA<<2)>>2]|0;aE=aC&15;if(!((aE|0)==0|u^1)){b[aa>>1]=c[(c[2440392]|0)+(aE<<2)>>2]&65535}aE=aC>>>4&15;if(!((aE|0)==0|H^1)){b[aa+2>>1]=c[(c[2440392]|0)+(aE<<2)>>2]&65535}aE=aC>>>8&15;if(!((aE|0)==0|G^1)){b[aa+4>>1]=c[(c[2440392]|0)+(aE<<2)>>2]&65535}aE=aC>>>12&15;if(!((aE|0)==0|F^1)){b[aa+6>>1]=c[(c[2440392]|0)+(aE<<2)>>2]&65535}aE=aC>>>16&15;if(!((aE|0)==0|E^1)){b[aa+8>>1]=c[(c[2440392]|0)+(aE<<2)>>2]&65535}aE=aC>>>24&15;if(!((aE|0)==0|D^1)){b[aa+10>>1]=c[(c[2440392]|0)+(aE<<2)>>2]&65535}aE=aC>>>28;if(!((aE|0)==0|C^1)){b[aa+12>>1]=c[(c[2440392]|0)+(aE<<2)>>2]&65535}aE=c[aw+((aA|1)<<2)>>2]|0;aw=aE&15;if(!((aw|0)==0|B^1)){b[aa+14>>1]=c[(c[2440392]|0)+(aw<<2)>>2]&65535}aw=aE>>>4&15;if(!((aw|0)==0|A^1)){b[aa+16>>1]=c[(c[2440392]|0)+(aw<<2)>>2]&65535}aw=aE>>>8&15;if(!((aw|0)==0|z^1)){b[aa+18>>1]=c[(c[2440392]|0)+(aw<<2)>>2]&65535}aw=aE>>>16&15;if(!((aw|0)==0|y^1)){b[aa+20>>1]=c[(c[2440392]|0)+(aw<<2)>>2]&65535}aw=aE>>>20&15;if(!((aw|0)==0|x^1)){b[aa+22>>1]=c[(c[2440392]|0)+(aw<<2)>>2]&65535}aw=aE>>>24&15;if(!((aw|0)==0|w^1)){b[aa+24>>1]=c[(c[2440392]|0)+(aw<<2)>>2]&65535}aw=aE>>>28;if((aw|0)==0|v^1){break}b[aa+26>>1]=c[(c[2440392]|0)+(aw<<2)>>2]&65535;break}else{aw=c[2385344]|0;aE=c[aw+(aA<<2)>>2]|0;aC=aE&15;if(!((aC|0)==0|v^1)){b[aa+26>>1]=c[(c[2440392]|0)+(aC<<2)>>2]&65535}aC=aE>>>4&15;if(!((aC|0)==0|w^1)){b[aa+24>>1]=c[(c[2440392]|0)+(aC<<2)>>2]&65535}aC=aE>>>8&15;if(!((aC|0)==0|x^1)){b[aa+22>>1]=c[(c[2440392]|0)+(aC<<2)>>2]&65535}aC=aE>>>12&15;if(!((aC|0)==0|y^1)){b[aa+20>>1]=c[(c[2440392]|0)+(aC<<2)>>2]&65535}aC=aE>>>16&15;if(!((aC|0)==0|z^1)){b[aa+18>>1]=c[(c[2440392]|0)+(aC<<2)>>2]&65535}aC=aE>>>24&15;if(!((aC|0)==0|A^1)){b[aa+16>>1]=c[(c[2440392]|0)+(aC<<2)>>2]&65535}aC=aE>>>28;if(!((aC|0)==0|B^1)){b[aa+14>>1]=c[(c[2440392]|0)+(aC<<2)>>2]&65535}aC=c[aw+((aA|1)<<2)>>2]|0;aA=aC&15;if(!((aA|0)==0|C^1)){b[aa+12>>1]=c[(c[2440392]|0)+(aA<<2)>>2]&65535}aA=aC>>>4&15;if(!((aA|0)==0|D^1)){b[aa+10>>1]=c[(c[2440392]|0)+(aA<<2)>>2]&65535}aA=aC>>>8&15;if(!((aA|0)==0|E^1)){b[aa+8>>1]=c[(c[2440392]|0)+(aA<<2)>>2]&65535}aA=aC>>>16&15;if(!((aA|0)==0|F^1)){b[aa+6>>1]=c[(c[2440392]|0)+(aA<<2)>>2]&65535}aA=aC>>>20&15;if(!((aA|0)==0|G^1)){b[aa+4>>1]=c[(c[2440392]|0)+(aA<<2)>>2]&65535}aA=aC>>>24&15;if(!((aA|0)==0|H^1)){b[aa+2>>1]=c[(c[2440392]|0)+(aA<<2)>>2]&65535}aA=aC>>>28;if((aA|0)==0|u^1){break}b[aa>>1]=c[(c[2440392]|0)+(aA<<2)>>2]&65535;break}}}while(0);av=au+1|0;if((av|0)>(W|0)){as=az;at=ay;break}else{X=az;U=ay;S=ax;aa=aa+q|0;au=av}}}if((an|0)>(j|0)){ai=34697;break}else{P=as;Q=at;R=an}}if((ai|0)==34697){return}else if((ai|0)==34699){return}}function cy0(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0;f=c[3540994]|0;g=c[3528548]|0;h=g<<8;i=c[2385554]|0;do{if((i|0)>31){j=511}else{k=(i<<4)-1|0;if((k|0)>=0){j=k;break}return}}while(0);k=(j|0)>255;l=j&255;m=c[2385550]|0;n=c[2113042]|0;o=c[2113044]|0;p=n+512|0;q=c[2385552]|0;r=c[2113132]|0;s=q<<1;t=c[2112968]|0;u=q+14|0;v=(u|0)>-1&(u|0)<(r|0);u=q+13|0;w=(u|0)>-1&(u|0)<(r|0);u=q+12|0;x=(u|0)>-1&(u|0)<(r|0);u=q+11|0;y=(u|0)>-1&(u|0)<(r|0);u=q+10|0;z=(u|0)>-1&(u|0)<(r|0);u=q+9|0;A=(u|0)>-1&(u|0)<(r|0);u=q+8|0;B=(u|0)>-1&(u|0)<(r|0);u=q+7|0;C=(u|0)>-1&(u|0)<(r|0);u=q+6|0;D=(u|0)>-1&(u|0)<(r|0);u=q+5|0;E=(u|0)>-1&(u|0)<(r|0);u=q+4|0;F=(u|0)>-1&(u|0)<(r|0);u=q+3|0;G=(u|0)>-1&(u|0)<(r|0);u=q+2|0;H=(u|0)>-1&(u|0)<(r|0);u=q+1|0;I=(u|0)>-1&(u|0)<(r|0);u=(q|0)>-1&(q|0)<(r|0);q=r<<1;J=c[2415160]|0;K=c[2429858]|0;L=c[2430428]|0;M=c[2429718]|0;N=c[2430092]|0;O=c[3541046]|0;P=c[2430426]|0;Q=0;R=0;S=0;L39538:while(1){T=(i|0)>16&(g|0)!=255;U=(i|0)<33;V=511-g|0;W=g+1|0;X=g-255|0;Y=~g;Z=S;L39540:while(1){_=Z+m|0;$=_&511;do{if(($|0)<(n|0)){aa=Z+n-$|0}else{if(($|0)>=(o|0)){aa=p+Z-$|0;break}ab=(Z|0)>255;ac=ab?16:0;ad=Z&255;ae=(Z|0)<256&k?255:l;if(!T){af=ae;ah=ad;ai=ac;aj=34723;break L39540}if(U){if(!ab){aj=34713;break L39540}if((Z|0)<(V|0)){aa=V;break}else{aj=34715;break L39540}}if(ab){ak=X+ad|0;if((ak|0)>=0){aj=34718;break L39540}ab=W+ak|0;if((ab|0)<0){aa=512;break}else{af=g;ah=ab;ai=0;aj=34723;break L39540}}else{if((ad|0)<=(g|0)){aj=34721;break L39540}ab=ad+Y|0;if((ab|0)>(g|0)){aa=256;break}else{af=g;ah=ab;ai=16;aj=34723;break L39540}}}}while(0);if((aa|0)>(j|0)){aj=34800;break L39538}else{Z=aa}}if((aj|0)==34715){aj=0;Y=255-g|0;af=ae-Y|0;ah=ad-Y|0;ai=ac;aj=34723}else if((aj|0)==34718){aj=0;al=g;am=ac;an=ak;ao=W+Z-ak|0}else if((aj|0)==34713){aj=0;ap=ac;aq=ad;ar=ae;as=Z+1-ad+ae|0;aj=34724}else if((aj|0)==34721){aj=0;al=g;am=ac;an=ad;ao=W+Z-ad|0}if((aj|0)==34723){aj=0;Y=Z+1-ah+af|0;if(U){ap=ai;aq=ah;ar=af;as=Y;aj=34724}else{al=af;am=ai;an=ah;ao=Y}}if((aj|0)==34724){aj=0;al=(ar|0)>(g|0)?g:ar;am=ap;an=aq;ao=as}Y=((_|-512)^511)+o|0;X=(al-an|0)>(Y|0)?Y+an|0:al;if((an|0)>(X|0)){at=Q;au=R}else{Y=Q;V=R;T=-1;ab=t+((ag(r,($<<1)-32|0)|0)+s)|0;av=an;while(1){aw=d[f+(av+h)|0]|0;ax=(aw>>>4)+am|0;do{if((ax|0)==(T|0)){ay=T;az=V;aA=Y}else{aB=ax<<1;aC=e[J+((aB|1)<<1)>>1]|0;aD=(aC<<12&983040|(e[J+(aB<<1)>>1]|0))&K;do{if((aC&8|0)==0){if((aC&4|0)==0){aE=aD;break}aE=L|aD&1048572}else{aE=P|aD&1048568}}while(0);aD=a[M+aE|0]|0;aB=aD&255;if(aD<<24>>24!=0){ay=ax;az=aB;aA=aC;break}c[2385344]=N+(aE<<7);c[2440392]=O+((aC>>>4&4080)<<2);ay=ax;az=aB;aA=aC}}while(0);do{if((az|0)==0){ax=aw<<1&30;aB=(aA&2|0)==0?ax:ax^30;if((aA&1|0)==0){ax=c[2385344]|0;aD=c[ax+(aB<<2)>>2]|0;aF=aD&15;if(!((aF|0)==0|u^1)){b[ab>>1]=c[(c[2440392]|0)+(aF<<2)>>2]&65535}aF=aD>>>4&15;if(!((aF|0)==0|I^1)){b[ab+2>>1]=c[(c[2440392]|0)+(aF<<2)>>2]&65535}aF=aD>>>8&15;if(!((aF|0)==0|H^1)){b[ab+4>>1]=c[(c[2440392]|0)+(aF<<2)>>2]&65535}aF=aD>>>12&15;if(!((aF|0)==0|G^1)){b[ab+6>>1]=c[(c[2440392]|0)+(aF<<2)>>2]&65535}aF=aD>>>16&15;if(!((aF|0)==0|F^1)){b[ab+8>>1]=c[(c[2440392]|0)+(aF<<2)>>2]&65535}aF=aD>>>24&15;if(!((aF|0)==0|E^1)){b[ab+10>>1]=c[(c[2440392]|0)+(aF<<2)>>2]&65535}aF=aD>>>28;if(!((aF|0)==0|D^1)){b[ab+12>>1]=c[(c[2440392]|0)+(aF<<2)>>2]&65535}aF=c[ax+((aB|1)<<2)>>2]|0;ax=aF&15;if(!((ax|0)==0|C^1)){b[ab+14>>1]=c[(c[2440392]|0)+(ax<<2)>>2]&65535}ax=aF>>>4&15;if(!((ax|0)==0|B^1)){b[ab+16>>1]=c[(c[2440392]|0)+(ax<<2)>>2]&65535}ax=aF>>>8&15;if(!((ax|0)==0|A^1)){b[ab+18>>1]=c[(c[2440392]|0)+(ax<<2)>>2]&65535}ax=aF>>>12&15;if(!((ax|0)==0|z^1)){b[ab+20>>1]=c[(c[2440392]|0)+(ax<<2)>>2]&65535}ax=aF>>>16&15;if(!((ax|0)==0|y^1)){b[ab+22>>1]=c[(c[2440392]|0)+(ax<<2)>>2]&65535}ax=aF>>>20&15;if(!((ax|0)==0|x^1)){b[ab+24>>1]=c[(c[2440392]|0)+(ax<<2)>>2]&65535}ax=aF>>>24&15;if(!((ax|0)==0|w^1)){b[ab+26>>1]=c[(c[2440392]|0)+(ax<<2)>>2]&65535}ax=aF>>>28;if((ax|0)==0|v^1){break}b[ab+28>>1]=c[(c[2440392]|0)+(ax<<2)>>2]&65535;break}else{ax=c[2385344]|0;aF=c[ax+(aB<<2)>>2]|0;aD=aF&15;if(!((aD|0)==0|v^1)){b[ab+28>>1]=c[(c[2440392]|0)+(aD<<2)>>2]&65535}aD=aF>>>4&15;if(!((aD|0)==0|w^1)){b[ab+26>>1]=c[(c[2440392]|0)+(aD<<2)>>2]&65535}aD=aF>>>8&15;if(!((aD|0)==0|x^1)){b[ab+24>>1]=c[(c[2440392]|0)+(aD<<2)>>2]&65535}aD=aF>>>12&15;if(!((aD|0)==0|y^1)){b[ab+22>>1]=c[(c[2440392]|0)+(aD<<2)>>2]&65535}aD=aF>>>16&15;if(!((aD|0)==0|z^1)){b[ab+20>>1]=c[(c[2440392]|0)+(aD<<2)>>2]&65535}aD=aF>>>24&15;if(!((aD|0)==0|A^1)){b[ab+18>>1]=c[(c[2440392]|0)+(aD<<2)>>2]&65535}aD=aF>>>28;if(!((aD|0)==0|B^1)){b[ab+16>>1]=c[(c[2440392]|0)+(aD<<2)>>2]&65535}aD=c[ax+((aB|1)<<2)>>2]|0;aB=aD&15;if(!((aB|0)==0|C^1)){b[ab+14>>1]=c[(c[2440392]|0)+(aB<<2)>>2]&65535}aB=aD>>>4&15;if(!((aB|0)==0|D^1)){b[ab+12>>1]=c[(c[2440392]|0)+(aB<<2)>>2]&65535}aB=aD>>>8&15;if(!((aB|0)==0|E^1)){b[ab+10>>1]=c[(c[2440392]|0)+(aB<<2)>>2]&65535}aB=aD>>>12&15;if(!((aB|0)==0|F^1)){b[ab+8>>1]=c[(c[2440392]|0)+(aB<<2)>>2]&65535}aB=aD>>>16&15;if(!((aB|0)==0|G^1)){b[ab+6>>1]=c[(c[2440392]|0)+(aB<<2)>>2]&65535}aB=aD>>>20&15;if(!((aB|0)==0|H^1)){b[ab+4>>1]=c[(c[2440392]|0)+(aB<<2)>>2]&65535}aB=aD>>>24&15;if(!((aB|0)==0|I^1)){b[ab+2>>1]=c[(c[2440392]|0)+(aB<<2)>>2]&65535}aB=aD>>>28;if((aB|0)==0|u^1){break}b[ab>>1]=c[(c[2440392]|0)+(aB<<2)>>2]&65535;break}}}while(0);aw=av+1|0;if((aw|0)>(X|0)){at=aA;au=az;break}else{Y=aA;V=az;T=ay;ab=ab+q|0;av=aw}}}if((ao|0)>(j|0)){aj=34799;break}else{Q=at;R=au;S=ao}}if((aj|0)==34799){return}else if((aj|0)==34800){return}}function cy1(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0;f=c[3540994]|0;g=c[3528548]|0;h=g<<8;i=c[2385554]|0;do{if((i|0)>31){j=511}else{k=(i<<4)-1|0;if((k|0)>=0){j=k;break}return}}while(0);k=(j|0)>255;l=j&255;m=c[2385550]|0;n=c[2113042]|0;o=c[2113044]|0;p=n+512|0;q=c[2385552]|0;r=c[2113132]|0;s=q<<1;t=c[2112968]|0;u=q+15|0;v=(u|0)>-1&(u|0)<(r|0);u=q+14|0;w=(u|0)>-1&(u|0)<(r|0);u=q+13|0;x=(u|0)>-1&(u|0)<(r|0);u=q+12|0;y=(u|0)>-1&(u|0)<(r|0);u=q+11|0;z=(u|0)>-1&(u|0)<(r|0);u=q+10|0;A=(u|0)>-1&(u|0)<(r|0);u=q+9|0;B=(u|0)>-1&(u|0)<(r|0);u=q+8|0;C=(u|0)>-1&(u|0)<(r|0);u=q+7|0;D=(u|0)>-1&(u|0)<(r|0);u=q+6|0;E=(u|0)>-1&(u|0)<(r|0);u=q+5|0;F=(u|0)>-1&(u|0)<(r|0);u=q+4|0;G=(u|0)>-1&(u|0)<(r|0);u=q+3|0;H=(u|0)>-1&(u|0)<(r|0);u=q+2|0;I=(u|0)>-1&(u|0)<(r|0);u=q+1|0;J=(u|0)>-1&(u|0)<(r|0);u=(q|0)>-1&(q|0)<(r|0);q=r<<1;K=c[2415160]|0;L=c[2429858]|0;M=c[2430428]|0;N=c[2429718]|0;O=c[2430092]|0;P=c[3541046]|0;Q=c[2430426]|0;R=0;S=0;T=0;L39683:while(1){U=(i|0)>16&(g|0)!=255;V=(i|0)<33;W=511-g|0;X=g+1|0;Y=g-255|0;Z=~g;_=T;L39685:while(1){$=_+m|0;aa=$&511;do{if((aa|0)<(n|0)){ab=_+n-aa|0}else{if((aa|0)>=(o|0)){ab=p+_-aa|0;break}ac=(_|0)>255;ad=ac?16:0;ae=_&255;af=(_|0)<256&k?255:l;if(!U){ah=af;ai=ae;aj=ad;ak=34824;break L39685}if(V){if(!ac){ak=34814;break L39685}if((_|0)<(W|0)){ab=W;break}else{ak=34816;break L39685}}if(ac){al=Y+ae|0;if((al|0)>=0){ak=34819;break L39685}ac=X+al|0;if((ac|0)<0){ab=512;break}else{ah=g;ai=ac;aj=0;ak=34824;break L39685}}else{if((ae|0)<=(g|0)){ak=34822;break L39685}ac=ae+Z|0;if((ac|0)>(g|0)){ab=256;break}else{ah=g;ai=ac;aj=16;ak=34824;break L39685}}}}while(0);if((ab|0)>(j|0)){ak=34905;break L39683}else{_=ab}}if((ak|0)==34816){ak=0;Z=255-g|0;ah=af-Z|0;ai=ae-Z|0;aj=ad;ak=34824}else if((ak|0)==34822){ak=0;am=g;an=ad;ao=ae;ap=X+_-ae|0}else if((ak|0)==34819){ak=0;am=g;an=ad;ao=al;ap=X+_-al|0}else if((ak|0)==34814){ak=0;aq=ad;ar=ae;as=af;at=_+1-ae+af|0;ak=34825}if((ak|0)==34824){ak=0;Z=_+1-ai+ah|0;if(V){aq=aj;ar=ai;as=ah;at=Z;ak=34825}else{am=ah;an=aj;ao=ai;ap=Z}}if((ak|0)==34825){ak=0;am=(as|0)>(g|0)?g:as;an=aq;ao=ar;ap=at}Z=(($|-512)^511)+o|0;Y=(am-ao|0)>(Z|0)?Z+ao|0:am;if((ao|0)>(Y|0)){au=R;av=S}else{Z=R;W=S;U=-1;ac=t+((ag(r,(aa<<1)-32|0)|0)+s)|0;aw=ao;while(1){ax=d[f+(aw+h)|0]|0;ay=(ax>>>4)+an|0;do{if((ay|0)==(U|0)){az=U;aA=W;aB=Z}else{aC=ay<<1;aD=e[K+((aC|1)<<1)>>1]|0;aE=(aD<<12&983040|(e[K+(aC<<1)>>1]|0))&L;do{if((aD&8|0)==0){if((aD&4|0)==0){aF=aE;break}aF=M|aE&1048572}else{aF=Q|aE&1048568}}while(0);aE=a[N+aF|0]|0;aC=aE&255;if(aE<<24>>24!=0){az=ay;aA=aC;aB=aD;break}c[2385344]=O+(aF<<7);c[2440392]=P+((aD>>>4&4080)<<2);az=ay;aA=aC;aB=aD}}while(0);do{if((aA|0)==0){ay=ax<<1&30;aC=(aB&2|0)==0?ay:ay^30;if((aB&1|0)==0){ay=c[2385344]|0;aE=c[ay+(aC<<2)>>2]|0;aG=aE&15;if(!((aG|0)==0|u^1)){b[ac>>1]=c[(c[2440392]|0)+(aG<<2)>>2]&65535}aG=aE>>>4&15;if(!((aG|0)==0|J^1)){b[ac+2>>1]=c[(c[2440392]|0)+(aG<<2)>>2]&65535}aG=aE>>>8&15;if(!((aG|0)==0|I^1)){b[ac+4>>1]=c[(c[2440392]|0)+(aG<<2)>>2]&65535}aG=aE>>>12&15;if(!((aG|0)==0|H^1)){b[ac+6>>1]=c[(c[2440392]|0)+(aG<<2)>>2]&65535}aG=aE>>>16&15;if(!((aG|0)==0|G^1)){b[ac+8>>1]=c[(c[2440392]|0)+(aG<<2)>>2]&65535}aG=aE>>>20&15;if(!((aG|0)==0|F^1)){b[ac+10>>1]=c[(c[2440392]|0)+(aG<<2)>>2]&65535}aG=aE>>>24&15;if(!((aG|0)==0|E^1)){b[ac+12>>1]=c[(c[2440392]|0)+(aG<<2)>>2]&65535}aG=aE>>>28;if(!((aG|0)==0|D^1)){b[ac+14>>1]=c[(c[2440392]|0)+(aG<<2)>>2]&65535}aG=c[ay+((aC|1)<<2)>>2]|0;ay=aG&15;if(!((ay|0)==0|C^1)){b[ac+16>>1]=c[(c[2440392]|0)+(ay<<2)>>2]&65535}ay=aG>>>4&15;if(!((ay|0)==0|B^1)){b[ac+18>>1]=c[(c[2440392]|0)+(ay<<2)>>2]&65535}ay=aG>>>8&15;if(!((ay|0)==0|A^1)){b[ac+20>>1]=c[(c[2440392]|0)+(ay<<2)>>2]&65535}ay=aG>>>12&15;if(!((ay|0)==0|z^1)){b[ac+22>>1]=c[(c[2440392]|0)+(ay<<2)>>2]&65535}ay=aG>>>16&15;if(!((ay|0)==0|y^1)){b[ac+24>>1]=c[(c[2440392]|0)+(ay<<2)>>2]&65535}ay=aG>>>20&15;if(!((ay|0)==0|x^1)){b[ac+26>>1]=c[(c[2440392]|0)+(ay<<2)>>2]&65535}ay=aG>>>24&15;if(!((ay|0)==0|w^1)){b[ac+28>>1]=c[(c[2440392]|0)+(ay<<2)>>2]&65535}ay=aG>>>28;if((ay|0)==0|v^1){break}b[ac+30>>1]=c[(c[2440392]|0)+(ay<<2)>>2]&65535;break}else{ay=c[2385344]|0;aG=c[ay+(aC<<2)>>2]|0;aE=aG&15;if(!((aE|0)==0|v^1)){b[ac+30>>1]=c[(c[2440392]|0)+(aE<<2)>>2]&65535}aE=aG>>>4&15;if(!((aE|0)==0|w^1)){b[ac+28>>1]=c[(c[2440392]|0)+(aE<<2)>>2]&65535}aE=aG>>>8&15;if(!((aE|0)==0|x^1)){b[ac+26>>1]=c[(c[2440392]|0)+(aE<<2)>>2]&65535}aE=aG>>>12&15;if(!((aE|0)==0|y^1)){b[ac+24>>1]=c[(c[2440392]|0)+(aE<<2)>>2]&65535}aE=aG>>>16&15;if(!((aE|0)==0|z^1)){b[ac+22>>1]=c[(c[2440392]|0)+(aE<<2)>>2]&65535}aE=aG>>>20&15;if(!((aE|0)==0|A^1)){b[ac+20>>1]=c[(c[2440392]|0)+(aE<<2)>>2]&65535}aE=aG>>>24&15;if(!((aE|0)==0|B^1)){b[ac+18>>1]=c[(c[2440392]|0)+(aE<<2)>>2]&65535}aE=aG>>>28;if(!((aE|0)==0|C^1)){b[ac+16>>1]=c[(c[2440392]|0)+(aE<<2)>>2]&65535}aE=c[ay+((aC|1)<<2)>>2]|0;aC=aE&15;if(!((aC|0)==0|D^1)){b[ac+14>>1]=c[(c[2440392]|0)+(aC<<2)>>2]&65535}aC=aE>>>4&15;if(!((aC|0)==0|E^1)){b[ac+12>>1]=c[(c[2440392]|0)+(aC<<2)>>2]&65535}aC=aE>>>8&15;if(!((aC|0)==0|F^1)){b[ac+10>>1]=c[(c[2440392]|0)+(aC<<2)>>2]&65535}aC=aE>>>12&15;if(!((aC|0)==0|G^1)){b[ac+8>>1]=c[(c[2440392]|0)+(aC<<2)>>2]&65535}aC=aE>>>16&15;if(!((aC|0)==0|H^1)){b[ac+6>>1]=c[(c[2440392]|0)+(aC<<2)>>2]&65535}aC=aE>>>20&15;if(!((aC|0)==0|I^1)){b[ac+4>>1]=c[(c[2440392]|0)+(aC<<2)>>2]&65535}aC=aE>>>24&15;if(!((aC|0)==0|J^1)){b[ac+2>>1]=c[(c[2440392]|0)+(aC<<2)>>2]&65535}aC=aE>>>28;if((aC|0)==0|u^1){break}b[ac>>1]=c[(c[2440392]|0)+(aC<<2)>>2]&65535;break}}}while(0);ax=aw+1|0;if((ax|0)>(Y|0)){au=aB;av=aA;break}else{Z=aB;W=aA;U=az;ac=ac+q|0;aw=ax}}}if((ap|0)>(j|0)){ak=34903;break}else{R=au;S=av;T=ap}}if((ak|0)==34903){return}else if((ak|0)==34905){return}}function cy2(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0;b=c[3540994]|0;f=c[3528548]|0;g=f<<8;h=c[2385554]|0;do{if((h|0)>31){i=511}else{j=(h<<4)-1|0;if((j|0)>=0){i=j;break}return}}while(0);j=(i|0)>255;k=i&255;l=c[2385550]|0;m=c[2113042]|0;n=c[2113044]|0;o=m+512|0;p=c[2113132]|0;q=(c[2385552]|0)*3|0;r=c[2112968]|0;s=p*3|0;t=c[2415160]|0;u=c[2429858]|0;v=c[2430428]|0;w=c[2429718]|0;x=c[2430092]|0;y=c[3541046]|0;z=c[2430426]|0;A=0;B=0;C=0;L39834:while(1){D=(h|0)>16&(f|0)!=255;E=(h|0)<33;F=511-f|0;G=f+1|0;H=f-255|0;I=~f;J=C;L39836:while(1){K=J+l|0;L=K&511;do{if((L|0)<(m|0)){M=J+m-L|0}else{if((L|0)>=(n|0)){M=o+J-L|0;break}N=(J|0)>255;O=N?16:0;P=J&255;Q=(J|0)<256&j?255:k;if(!D){R=Q;S=P;T=O;U=34929;break L39836}if(E){if(!N){U=34919;break L39836}if((J|0)<(F|0)){M=F;break}else{U=34921;break L39836}}if(N){V=H+P|0;if((V|0)>=0){U=34924;break L39836}N=G+V|0;if((N|0)<0){M=512;break}else{R=f;S=N;T=0;U=34929;break L39836}}else{if((P|0)<=(f|0)){U=34927;break L39836}N=P+I|0;if((N|0)>(f|0)){M=256;break}else{R=f;S=N;T=16;U=34929;break L39836}}}}while(0);if((M|0)>(i|0)){U=34950;break L39834}else{J=M}}if((U|0)==34924){U=0;W=f;X=O;Y=V;Z=G+J-V|0}else if((U|0)==34919){U=0;_=O;$=P;aa=Q;ab=J+1-P+Q|0;U=34930}else if((U|0)==34927){U=0;W=f;X=O;Y=P;Z=G+J-P|0}else if((U|0)==34921){U=0;I=255-f|0;R=Q-I|0;S=P-I|0;T=O;U=34929}if((U|0)==34929){U=0;I=J+1-S+R|0;if(E){_=T;$=S;aa=R;ab=I;U=34930}else{W=R;X=T;Y=S;Z=I}}if((U|0)==34930){U=0;W=(aa|0)>(f|0)?f:aa;X=_;Y=$;Z=ab}I=((K|-512)^511)+n|0;H=(W-Y|0)>(I|0)?I+Y|0:W;if((Y|0)>(H|0)){ac=A;ad=B}else{I=A;F=-1;D=B;N=Y;ae=r+((ag(p,(L*3|0)-48|0)|0)+q)|0;while(1){af=d[b+(N+g)|0]|0;ah=(af>>>4)+X|0;do{if((ah|0)==(F|0)){ai=D;aj=F;ak=I}else{al=ah<<1;am=e[t+((al|1)<<1)>>1]|0;an=(am<<12&983040|(e[t+(al<<1)>>1]|0))&u;do{if((am&8|0)==0){if((am&4|0)==0){ao=an;break}ao=v|an&1048572}else{ao=z|an&1048568}}while(0);an=a[w+ao|0]|0;al=an&255;if(an<<24>>24!=0){ai=al;aj=ah;ak=am;break}c[2385344]=x+(ao<<7);c[2440392]=y+((am>>>4&4080)<<2);ai=al;aj=ah;ak=am}}while(0);do{if((ai|0)==0){ah=af<<1&30;al=c[(c[2385344]|0)+((((ak&2|0)==0?ah:ah^30)|1)<<2)>>2]&15;ah=(al|0)==0;if((ak&1|0)==0){if(ah){break}an=c[(c[2440392]|0)+(al<<2)>>2]|0;a[ae]=an&255;a[ae+1|0]=an>>>8&255;a[ae+2|0]=an>>>16&255;break}else{if(ah){break}ah=c[(c[2440392]|0)+(al<<2)>>2]|0;a[ae]=ah&255;a[ae+1|0]=ah>>>8&255;a[ae+2|0]=ah>>>16&255;break}}}while(0);af=N+1|0;if((af|0)>(H|0)){ac=ak;ad=ai;break}else{I=ak;F=aj;D=ai;N=af;ae=ae+s|0}}}if((Z|0)>(i|0)){U=34949;break}else{A=ac;B=ad;C=Z}}if((U|0)==34949){return}else if((U|0)==34950){return}}function cy3(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0;b=c[3540994]|0;f=c[3528548]|0;g=f<<8;h=c[2385554]|0;do{if((h|0)>31){i=511}else{j=(h<<4)-1|0;if((j|0)>=0){i=j;break}return}}while(0);j=(i|0)>255;k=i&255;l=c[2385550]|0;m=c[2113042]|0;n=c[2113044]|0;o=m+512|0;p=c[2113132]|0;q=(c[2385552]|0)*3|0;r=c[2112968]|0;s=p*3|0;t=c[2415160]|0;u=c[2429858]|0;v=c[2430428]|0;w=c[2429718]|0;x=c[2430092]|0;y=c[3541046]|0;z=c[2430426]|0;A=0;B=0;C=0;L39895:while(1){D=(h|0)>16&(f|0)!=255;E=(h|0)<33;F=511-f|0;G=f+1|0;H=f-255|0;I=~f;J=B;L39897:while(1){K=J+l|0;L=K&511;do{if((L|0)<(m|0)){M=J+m-L|0}else{if((L|0)>=(n|0)){M=o+J-L|0;break}N=(J|0)>255;O=N?16:0;P=J&255;Q=(J|0)<256&j?255:k;if(!D){R=Q;S=P;T=O;U=34974;break L39897}if(E){if(!N){U=34964;break L39897}if((J|0)<(F|0)){M=F;break}else{U=34966;break L39897}}if(N){V=H+P|0;if((V|0)>=0){U=34969;break L39897}N=G+V|0;if((N|0)<0){M=512;break}else{R=f;S=N;T=0;U=34974;break L39897}}else{if((P|0)<=(f|0)){U=34972;break L39897}N=P+I|0;if((N|0)>(f|0)){M=256;break}else{R=f;S=N;T=16;U=34974;break L39897}}}}while(0);if((M|0)>(i|0)){U=34999;break L39895}else{J=M}}if((U|0)==34964){U=0;W=O;X=P;Y=Q;Z=J+1-P+Q|0;U=34975}else if((U|0)==34966){U=0;I=255-f|0;R=Q-I|0;S=P-I|0;T=O;U=34974}else if((U|0)==34969){U=0;_=f;$=O;aa=V;ab=G+J-V|0}else if((U|0)==34972){U=0;_=f;$=O;aa=P;ab=G+J-P|0}if((U|0)==34974){U=0;I=J+1-S+R|0;if(E){W=T;X=S;Y=R;Z=I;U=34975}else{_=R;$=T;aa=S;ab=I}}if((U|0)==34975){U=0;_=(Y|0)>(f|0)?f:Y;$=W;aa=X;ab=Z}I=((K|-512)^511)+n|0;H=(_-aa|0)>(I|0)?I+aa|0:_;if((aa|0)>(H|0)){ac=A;ad=C}else{I=-1;F=A;D=aa;N=C;ae=r+((ag(p,(L*3|0)-48|0)|0)+q)|0;while(1){af=d[b+(D+g)|0]|0;ah=(af>>>4)+$|0;do{if((ah|0)==(I|0)){ai=N;aj=F;ak=I}else{al=ah<<1;am=e[t+((al|1)<<1)>>1]|0;an=(am<<12&983040|(e[t+(al<<1)>>1]|0))&u;do{if((am&8|0)==0){if((am&4|0)==0){ao=an;break}ao=v|an&1048572}else{ao=z|an&1048568}}while(0);an=a[w+ao|0]|0;al=an&255;if(an<<24>>24!=0){ai=al;aj=am;ak=ah;break}c[2385344]=x+(ao<<7);c[2440392]=y+((am>>>4&4080)<<2);ai=al;aj=am;ak=ah}}while(0);do{if((ai|0)==0){ah=af<<1&30;al=(aj&2|0)==0?ah:ah^30;ah=c[2385344]|0;an=(c[ah+(al<<2)>>2]|0)>>>16&15;ap=(an|0)==0;if((aj&1|0)==0){if(!ap){aq=c[(c[2440392]|0)+(an<<2)>>2]|0;a[ae]=aq&255;a[ae+1|0]=aq>>>8&255;a[ae+2|0]=aq>>>16&255}aq=c[ah+((al|1)<<2)>>2]&15;if((aq|0)==0){break}ar=c[(c[2440392]|0)+(aq<<2)>>2]|0;a[ae+3|0]=ar&255;a[ae+4|0]=ar>>>8&255;a[ae+5|0]=ar>>>16&255;break}else{if(!ap){ap=c[(c[2440392]|0)+(an<<2)>>2]|0;a[ae+3|0]=ap&255;a[ae+4|0]=ap>>>8&255;a[ae+5|0]=ap>>>16&255}ap=c[ah+((al|1)<<2)>>2]&15;if((ap|0)==0){break}al=c[(c[2440392]|0)+(ap<<2)>>2]|0;a[ae]=al&255;a[ae+1|0]=al>>>8&255;a[ae+2|0]=al>>>16&255;break}}}while(0);af=D+1|0;if((af|0)>(H|0)){ac=aj;ad=ai;break}else{I=ak;F=aj;D=af;N=ai;ae=ae+s|0}}}if((ab|0)>(i|0)){U=34997;break}else{A=ac;B=ab;C=ad}}if((U|0)==34997){return}else if((U|0)==34999){return}}function cy4(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0;b=c[3540994]|0;f=c[3528548]|0;g=f<<8;h=c[2385554]|0;do{if((h|0)>31){i=511}else{j=(h<<4)-1|0;if((j|0)>=0){i=j;break}return}}while(0);j=(i|0)>255;k=i&255;l=c[2385550]|0;m=c[2113042]|0;n=c[2113044]|0;o=m+512|0;p=c[2113132]|0;q=(c[2385552]|0)*3|0;r=c[2112968]|0;s=p*3|0;t=c[2415160]|0;u=c[2429858]|0;v=c[2430428]|0;w=c[2429718]|0;x=c[2430092]|0;y=c[3541046]|0;z=c[2430426]|0;A=0;B=0;C=0;L39962:while(1){D=(h|0)>16&(f|0)!=255;E=(h|0)<33;F=511-f|0;G=f+1|0;H=f-255|0;I=~f;J=A;L39964:while(1){K=J+l|0;L=K&511;do{if((L|0)<(m|0)){M=J+m-L|0}else{if((L|0)>=(n|0)){M=o+J-L|0;break}N=(J|0)>255;O=N?16:0;P=J&255;Q=(J|0)<256&j?255:k;if(!D){R=Q;S=P;T=O;U=35023;break L39964}if(E){if(!N){U=35013;break L39964}if((J|0)<(F|0)){M=F;break}else{U=35015;break L39964}}if(N){V=H+P|0;if((V|0)>=0){U=35018;break L39964}N=G+V|0;if((N|0)<0){M=512;break}else{R=f;S=N;T=0;U=35023;break L39964}}else{if((P|0)<=(f|0)){U=35021;break L39964}N=P+I|0;if((N|0)>(f|0)){M=256;break}else{R=f;S=N;T=16;U=35023;break L39964}}}}while(0);if((M|0)>(i|0)){U=35052;break L39962}else{J=M}}if((U|0)==35013){U=0;W=O;X=P;Y=Q;Z=J+1-P+Q|0;U=35024}else if((U|0)==35015){U=0;I=255-f|0;R=Q-I|0;S=P-I|0;T=O;U=35023}else if((U|0)==35018){U=0;_=f;$=O;aa=V;ab=G+J-V|0}else if((U|0)==35021){U=0;_=f;$=O;aa=P;ab=G+J-P|0}if((U|0)==35023){U=0;I=J+1-S+R|0;if(E){W=T;X=S;Y=R;Z=I;U=35024}else{_=R;$=T;aa=S;ab=I}}if((U|0)==35024){U=0;_=(Y|0)>(f|0)?f:Y;$=W;aa=X;ab=Z}I=((K|-512)^511)+n|0;H=(_-aa|0)>(I|0)?I+aa|0:_;if((aa|0)>(H|0)){ac=B;ad=C}else{I=-1;F=aa;D=B;N=C;ae=r+((ag(p,(L*3|0)-48|0)|0)+q)|0;while(1){af=d[b+(F+g)|0]|0;ah=(af>>>4)+$|0;do{if((ah|0)==(I|0)){ai=N;aj=D;ak=I}else{al=ah<<1;am=e[t+((al|1)<<1)>>1]|0;an=(am<<12&983040|(e[t+(al<<1)>>1]|0))&u;do{if((am&8|0)==0){if((am&4|0)==0){ao=an;break}ao=v|an&1048572}else{ao=z|an&1048568}}while(0);an=a[w+ao|0]|0;al=an&255;if(an<<24>>24!=0){ai=al;aj=am;ak=ah;break}c[2385344]=x+(ao<<7);c[2440392]=y+((am>>>4&4080)<<2);ai=al;aj=am;ak=ah}}while(0);do{if((ai|0)==0){ah=af<<1&30;al=(aj&2|0)==0?ah:ah^30;ah=c[2385344]|0;an=(c[ah+(al<<2)>>2]|0)>>>16&15;ap=(an|0)==0;if((aj&1|0)==0){if(!ap){aq=c[(c[2440392]|0)+(an<<2)>>2]|0;a[ae]=aq&255;a[ae+1|0]=aq>>>8&255;a[ae+2|0]=aq>>>16&255}aq=c[ah+((al|1)<<2)>>2]|0;ar=aq&15;if((ar|0)!=0){as=c[(c[2440392]|0)+(ar<<2)>>2]|0;a[ae+3|0]=as&255;a[ae+4|0]=as>>>8&255;a[ae+5|0]=as>>>16&255}as=aq>>>16&15;if((as|0)==0){break}aq=c[(c[2440392]|0)+(as<<2)>>2]|0;a[ae+6|0]=aq&255;a[ae+7|0]=aq>>>8&255;a[ae+8|0]=aq>>>16&255;break}else{if(!ap){ap=c[(c[2440392]|0)+(an<<2)>>2]|0;a[ae+6|0]=ap&255;a[ae+7|0]=ap>>>8&255;a[ae+8|0]=ap>>>16&255}ap=c[ah+((al|1)<<2)>>2]|0;al=ap&15;if((al|0)!=0){ah=c[(c[2440392]|0)+(al<<2)>>2]|0;a[ae+3|0]=ah&255;a[ae+4|0]=ah>>>8&255;a[ae+5|0]=ah>>>16&255}ah=ap>>>16&15;if((ah|0)==0){break}ap=c[(c[2440392]|0)+(ah<<2)>>2]|0;a[ae]=ap&255;a[ae+1|0]=ap>>>8&255;a[ae+2|0]=ap>>>16&255;break}}}while(0);af=F+1|0;if((af|0)>(H|0)){ac=aj;ad=ai;break}else{I=ak;F=af;D=aj;N=ai;ae=ae+s|0}}}if((ab|0)>(i|0)){U=35051;break}else{A=ab;B=ac;C=ad}}if((U|0)==35051){return}else if((U|0)==35052){return}}function cy5(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0;b=c[3540994]|0;f=c[3528548]|0;g=f<<8;h=c[2385554]|0;do{if((h|0)>31){i=511}else{j=(h<<4)-1|0;if((j|0)>=0){i=j;break}return}}while(0);j=(i|0)>255;k=i&255;l=c[2385550]|0;m=c[2113042]|0;n=c[2113044]|0;o=m+512|0;p=c[2113132]|0;q=(c[2385552]|0)*3|0;r=c[2112968]|0;s=p*3|0;t=c[2415160]|0;u=c[2429858]|0;v=c[2430428]|0;w=c[2429718]|0;x=c[2430092]|0;y=c[3541046]|0;z=c[2430426]|0;A=0;B=0;C=0;L40035:while(1){D=(h|0)>16&(f|0)!=255;E=(h|0)<33;F=511-f|0;G=f+1|0;H=f-255|0;I=~f;J=A;L40037:while(1){K=J+l|0;L=K&511;do{if((L|0)<(m|0)){M=J+m-L|0}else{if((L|0)>=(n|0)){M=o+J-L|0;break}N=(J|0)>255;O=N?16:0;P=J&255;Q=(J|0)<256&j?255:k;if(!D){R=Q;S=P;T=O;U=35076;break L40037}if(E){if(!N){U=35066;break L40037}if((J|0)<(F|0)){M=F;break}else{U=35068;break L40037}}if(N){V=H+P|0;if((V|0)>=0){U=35071;break L40037}N=G+V|0;if((N|0)<0){M=512;break}else{R=f;S=N;T=0;U=35076;break L40037}}else{if((P|0)<=(f|0)){U=35074;break L40037}N=P+I|0;if((N|0)>(f|0)){M=256;break}else{R=f;S=N;T=16;U=35076;break L40037}}}}while(0);if((M|0)>(i|0)){U=35109;break L40035}else{J=M}}if((U|0)==35066){U=0;W=O;X=P;Y=Q;Z=J+1-P+Q|0;U=35077}else if((U|0)==35068){U=0;I=255-f|0;R=Q-I|0;S=P-I|0;T=O;U=35076}else if((U|0)==35071){U=0;_=f;$=O;aa=V;ab=G+J-V|0}else if((U|0)==35074){U=0;_=f;$=O;aa=P;ab=G+J-P|0}if((U|0)==35076){U=0;I=J+1-S+R|0;if(E){W=T;X=S;Y=R;Z=I;U=35077}else{_=R;$=T;aa=S;ab=I}}if((U|0)==35077){U=0;_=(Y|0)>(f|0)?f:Y;$=W;aa=X;ab=Z}I=((K|-512)^511)+n|0;H=(_-aa|0)>(I|0)?I+aa|0:_;if((aa|0)>(H|0)){ac=B;ad=C}else{I=aa;F=-1;D=B;N=C;ae=r+((ag(p,(L*3|0)-48|0)|0)+q)|0;while(1){af=d[b+(I+g)|0]|0;ah=(af>>>4)+$|0;do{if((ah|0)==(F|0)){ai=N;aj=D;ak=F}else{al=ah<<1;am=e[t+((al|1)<<1)>>1]|0;an=(am<<12&983040|(e[t+(al<<1)>>1]|0))&u;do{if((am&8|0)==0){if((am&4|0)==0){ao=an;break}ao=v|an&1048572}else{ao=z|an&1048568}}while(0);an=a[w+ao|0]|0;al=an&255;if(an<<24>>24!=0){ai=al;aj=am;ak=ah;break}c[2385344]=x+(ao<<7);c[2440392]=y+((am>>>4&4080)<<2);ai=al;aj=am;ak=ah}}while(0);do{if((ai|0)==0){ah=af<<1&30;al=(aj&2|0)==0?ah:ah^30;ah=c[2385344]|0;an=c[ah+(al<<2)>>2]|0;ap=an>>>8&15;aq=(ap|0)==0;if((aj&1|0)==0){if(!aq){ar=c[(c[2440392]|0)+(ap<<2)>>2]|0;a[ae]=ar&255;a[ae+1|0]=ar>>>8&255;a[ae+2|0]=ar>>>16&255}ar=an>>>16&15;if((ar|0)!=0){as=c[(c[2440392]|0)+(ar<<2)>>2]|0;a[ae+3|0]=as&255;a[ae+4|0]=as>>>8&255;a[ae+5|0]=as>>>16&255}as=c[ah+((al|1)<<2)>>2]|0;ar=as&15;if((ar|0)!=0){at=c[(c[2440392]|0)+(ar<<2)>>2]|0;a[ae+6|0]=at&255;a[ae+7|0]=at>>>8&255;a[ae+8|0]=at>>>16&255}at=as>>>16&15;if((at|0)==0){break}as=c[(c[2440392]|0)+(at<<2)>>2]|0;a[ae+9|0]=as&255;a[ae+10|0]=as>>>8&255;a[ae+11|0]=as>>>16&255;break}else{if(!aq){aq=c[(c[2440392]|0)+(ap<<2)>>2]|0;a[ae+9|0]=aq&255;a[ae+10|0]=aq>>>8&255;a[ae+11|0]=aq>>>16&255}aq=an>>>16&15;if((aq|0)!=0){an=c[(c[2440392]|0)+(aq<<2)>>2]|0;a[ae+6|0]=an&255;a[ae+7|0]=an>>>8&255;a[ae+8|0]=an>>>16&255}an=c[ah+((al|1)<<2)>>2]|0;al=an&15;if((al|0)!=0){ah=c[(c[2440392]|0)+(al<<2)>>2]|0;a[ae+3|0]=ah&255;a[ae+4|0]=ah>>>8&255;a[ae+5|0]=ah>>>16&255}ah=an>>>16&15;if((ah|0)==0){break}an=c[(c[2440392]|0)+(ah<<2)>>2]|0;a[ae]=an&255;a[ae+1|0]=an>>>8&255;a[ae+2|0]=an>>>16&255;break}}}while(0);af=I+1|0;if((af|0)>(H|0)){ac=aj;ad=ai;break}else{I=af;F=ak;D=aj;N=ai;ae=ae+s|0}}}if((ab|0)>(i|0)){U=35107;break}else{A=ab;B=ac;C=ad}}if((U|0)==35107){return}else if((U|0)==35109){return}}function cy6(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0;b=c[3540994]|0;f=c[3528548]|0;g=f<<8;h=c[2385554]|0;do{if((h|0)>31){i=511}else{j=(h<<4)-1|0;if((j|0)>=0){i=j;break}return}}while(0);j=(i|0)>255;k=i&255;l=c[2385550]|0;m=c[2113042]|0;n=c[2113044]|0;o=m+512|0;p=c[2113132]|0;q=(c[2385552]|0)*3|0;r=c[2112968]|0;s=p*3|0;t=c[2415160]|0;u=c[2429858]|0;v=c[2430428]|0;w=c[2429718]|0;x=c[2430092]|0;y=c[3541046]|0;z=c[2430426]|0;A=0;B=0;C=0;L40114:while(1){D=(h|0)>16&(f|0)!=255;E=(h|0)<33;F=511-f|0;G=f+1|0;H=f-255|0;I=~f;J=A;L40116:while(1){K=J+l|0;L=K&511;do{if((L|0)<(m|0)){M=J+m-L|0}else{if((L|0)>=(n|0)){M=o+J-L|0;break}N=(J|0)>255;O=N?16:0;P=J&255;Q=(J|0)<256&j?255:k;if(!D){R=O;S=Q;T=P;U=35133;break L40116}if(E){if(!N){U=35123;break L40116}if((J|0)<(F|0)){M=F;break}else{U=35125;break L40116}}if(N){V=H+P|0;if((V|0)>=0){U=35128;break L40116}N=G+V|0;if((N|0)<0){M=512;break}else{R=0;S=f;T=N;U=35133;break L40116}}else{if((P|0)<=(f|0)){U=35131;break L40116}N=P+I|0;if((N|0)>(f|0)){M=256;break}else{R=16;S=f;T=N;U=35133;break L40116}}}}while(0);if((M|0)>(i|0)){U=35170;break L40114}else{J=M}}if((U|0)==35123){U=0;W=P;X=Q;Y=O;Z=J+1-P+Q|0;U=35134}else if((U|0)==35131){U=0;_=f;$=P;aa=O;ab=G+J-P|0}else if((U|0)==35128){U=0;_=f;$=V;aa=O;ab=G+J-V|0}else if((U|0)==35125){U=0;I=255-f|0;R=O;S=Q-I|0;T=P-I|0;U=35133}if((U|0)==35133){U=0;I=J+1-T+S|0;if(E){W=T;X=S;Y=R;Z=I;U=35134}else{_=S;$=T;aa=R;ab=I}}if((U|0)==35134){U=0;_=(X|0)>(f|0)?f:X;$=W;aa=Y;ab=Z}I=((K|-512)^511)+n|0;H=(_-$|0)>(I|0)?I+$|0:_;if(($|0)>(H|0)){ac=B;ad=C}else{I=$;F=-1;D=B;N=C;ae=r+((ag(p,(L*3|0)-48|0)|0)+q)|0;while(1){af=d[b+(I+g)|0]|0;ah=(af>>>4)+aa|0;do{if((ah|0)==(F|0)){ai=N;aj=D;ak=F}else{al=ah<<1;am=e[t+((al|1)<<1)>>1]|0;an=(am<<12&983040|(e[t+(al<<1)>>1]|0))&u;do{if((am&8|0)==0){if((am&4|0)==0){ao=an;break}ao=v|an&1048572}else{ao=z|an&1048568}}while(0);an=a[w+ao|0]|0;al=an&255;if(an<<24>>24!=0){ai=al;aj=am;ak=ah;break}c[2385344]=x+(ao<<7);c[2440392]=y+((am>>>4&4080)<<2);ai=al;aj=am;ak=ah}}while(0);do{if((ai|0)==0){ah=af<<1&30;al=(aj&2|0)==0?ah:ah^30;ah=c[2385344]|0;an=c[ah+(al<<2)>>2]|0;ap=an>>>8&15;aq=(ap|0)==0;if((aj&1|0)==0){if(!aq){ar=c[(c[2440392]|0)+(ap<<2)>>2]|0;a[ae]=ar&255;a[ae+1|0]=ar>>>8&255;a[ae+2|0]=ar>>>16&255}ar=an>>>16&15;if((ar|0)!=0){as=c[(c[2440392]|0)+(ar<<2)>>2]|0;a[ae+3|0]=as&255;a[ae+4|0]=as>>>8&255;a[ae+5|0]=as>>>16&255}as=c[ah+((al|1)<<2)>>2]|0;ar=as&15;if((ar|0)!=0){at=c[(c[2440392]|0)+(ar<<2)>>2]|0;a[ae+6|0]=at&255;a[ae+7|0]=at>>>8&255;a[ae+8|0]=at>>>16&255}at=as>>>16&15;if((at|0)!=0){ar=c[(c[2440392]|0)+(at<<2)>>2]|0;a[ae+9|0]=ar&255;a[ae+10|0]=ar>>>8&255;a[ae+11|0]=ar>>>16&255}ar=as>>>24&15;if((ar|0)==0){break}as=c[(c[2440392]|0)+(ar<<2)>>2]|0;a[ae+12|0]=as&255;a[ae+13|0]=as>>>8&255;a[ae+14|0]=as>>>16&255;break}else{if(!aq){aq=c[(c[2440392]|0)+(ap<<2)>>2]|0;a[ae+12|0]=aq&255;a[ae+13|0]=aq>>>8&255;a[ae+14|0]=aq>>>16&255}aq=an>>>16&15;if((aq|0)!=0){an=c[(c[2440392]|0)+(aq<<2)>>2]|0;a[ae+9|0]=an&255;a[ae+10|0]=an>>>8&255;a[ae+11|0]=an>>>16&255}an=c[ah+((al|1)<<2)>>2]|0;al=an&15;if((al|0)!=0){ah=c[(c[2440392]|0)+(al<<2)>>2]|0;a[ae+6|0]=ah&255;a[ae+7|0]=ah>>>8&255;a[ae+8|0]=ah>>>16&255}ah=an>>>16&15;if((ah|0)!=0){al=c[(c[2440392]|0)+(ah<<2)>>2]|0;a[ae+3|0]=al&255;a[ae+4|0]=al>>>8&255;a[ae+5|0]=al>>>16&255}al=an>>>24&15;if((al|0)==0){break}an=c[(c[2440392]|0)+(al<<2)>>2]|0;a[ae]=an&255;a[ae+1|0]=an>>>8&255;a[ae+2|0]=an>>>16&255;break}}}while(0);af=I+1|0;if((af|0)>(H|0)){ac=aj;ad=ai;break}else{I=af;F=ak;D=aj;N=ai;ae=ae+s|0}}}if((ab|0)>(i|0)){U=35169;break}else{A=ab;B=ac;C=ad}}if((U|0)==35169){return}else if((U|0)==35170){return}}function cy7(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0;b=c[3540994]|0;f=c[3528548]|0;g=f<<8;h=c[2385554]|0;do{if((h|0)>31){i=511}else{j=(h<<4)-1|0;if((j|0)>=0){i=j;break}return}}while(0);j=(i|0)>255;k=i&255;l=c[2385550]|0;m=c[2113042]|0;n=c[2113044]|0;o=m+512|0;p=c[2113132]|0;q=(c[2385552]|0)*3|0;r=c[2112968]|0;s=p*3|0;t=c[2415160]|0;u=c[2429858]|0;v=c[2430428]|0;w=c[2429718]|0;x=c[2430092]|0;y=c[3541046]|0;z=c[2430426]|0;A=0;B=0;C=0;L40199:while(1){D=(h|0)>16&(f|0)!=255;E=(h|0)<33;F=511-f|0;G=f+1|0;H=f-255|0;I=~f;J=A;L40201:while(1){K=J+l|0;L=K&511;do{if((L|0)<(m|0)){M=J+m-L|0}else{if((L|0)>=(n|0)){M=o+J-L|0;break}N=(J|0)>255;O=N?16:0;P=J&255;Q=(J|0)<256&j?255:k;if(!D){R=O;S=P;T=Q;U=35194;break L40201}if(E){if(!N){U=35184;break L40201}if((J|0)<(F|0)){M=F;break}else{U=35186;break L40201}}if(N){V=H+P|0;if((V|0)>=0){U=35189;break L40201}N=G+V|0;if((N|0)<0){M=512;break}else{R=0;S=N;T=f;U=35194;break L40201}}else{if((P|0)<=(f|0)){U=35192;break L40201}N=P+I|0;if((N|0)>(f|0)){M=256;break}else{R=16;S=N;T=f;U=35194;break L40201}}}}while(0);if((M|0)>(i|0)){U=35235;break L40199}else{J=M}}if((U|0)==35186){U=0;I=255-f|0;R=O;S=P-I|0;T=Q-I|0;U=35194}else if((U|0)==35192){U=0;W=f;X=P;Y=O;Z=G+J-P|0}else if((U|0)==35184){U=0;_=Q;$=P;aa=O;ab=J+1-P+Q|0;U=35195}else if((U|0)==35189){U=0;W=f;X=V;Y=O;Z=G+J-V|0}if((U|0)==35194){U=0;I=J+1+T-S|0;if(E){_=T;$=S;aa=R;ab=I;U=35195}else{W=T;X=S;Y=R;Z=I}}if((U|0)==35195){U=0;W=(_|0)>(f|0)?f:_;X=$;Y=aa;Z=ab}I=((K|-512)^511)+n|0;H=(W-X|0)>(I|0)?I+X|0:W;if((X|0)>(H|0)){ac=B;ad=C}else{I=X;F=-1;D=B;N=C;ae=r+((ag(p,(L*3|0)-48|0)|0)+q)|0;while(1){af=d[b+(I+g)|0]|0;ah=(af>>>4)+Y|0;do{if((ah|0)==(F|0)){ai=N;aj=D;ak=F}else{al=ah<<1;am=e[t+((al|1)<<1)>>1]|0;an=(am<<12&983040|(e[t+(al<<1)>>1]|0))&u;do{if((am&8|0)==0){if((am&4|0)==0){ao=an;break}ao=v|an&1048572}else{ao=z|an&1048568}}while(0);an=a[w+ao|0]|0;al=an&255;if(an<<24>>24!=0){ai=al;aj=am;ak=ah;break}c[2385344]=x+(ao<<7);c[2440392]=y+((am>>>4&4080)<<2);ai=al;aj=am;ak=ah}}while(0);do{if((ai|0)==0){ah=af<<1&30;al=(aj&2|0)==0?ah:ah^30;ah=c[2385344]|0;an=c[ah+(al<<2)>>2]|0;ap=an>>>8&15;aq=(ap|0)==0;if((aj&1|0)==0){if(!aq){ar=c[(c[2440392]|0)+(ap<<2)>>2]|0;a[ae]=ar&255;a[ae+1|0]=ar>>>8&255;a[ae+2|0]=ar>>>16&255}ar=an>>>16&15;if((ar|0)!=0){as=c[(c[2440392]|0)+(ar<<2)>>2]|0;a[ae+3|0]=as&255;a[ae+4|0]=as>>>8&255;a[ae+5|0]=as>>>16&255}as=an>>>24&15;if((as|0)!=0){ar=c[(c[2440392]|0)+(as<<2)>>2]|0;a[ae+6|0]=ar&255;a[ae+7|0]=ar>>>8&255;a[ae+8|0]=ar>>>16&255}ar=c[ah+((al|1)<<2)>>2]|0;as=ar&15;if((as|0)!=0){at=c[(c[2440392]|0)+(as<<2)>>2]|0;a[ae+9|0]=at&255;a[ae+10|0]=at>>>8&255;a[ae+11|0]=at>>>16&255}at=ar>>>16&15;if((at|0)!=0){as=c[(c[2440392]|0)+(at<<2)>>2]|0;a[ae+12|0]=as&255;a[ae+13|0]=as>>>8&255;a[ae+14|0]=as>>>16&255}as=ar>>>24&15;if((as|0)==0){break}ar=c[(c[2440392]|0)+(as<<2)>>2]|0;a[ae+15|0]=ar&255;a[ae+16|0]=ar>>>8&255;a[ae+17|0]=ar>>>16&255;break}else{if(!aq){aq=c[(c[2440392]|0)+(ap<<2)>>2]|0;a[ae+15|0]=aq&255;a[ae+16|0]=aq>>>8&255;a[ae+17|0]=aq>>>16&255}aq=an>>>16&15;if((aq|0)!=0){ap=c[(c[2440392]|0)+(aq<<2)>>2]|0;a[ae+12|0]=ap&255;a[ae+13|0]=ap>>>8&255;a[ae+14|0]=ap>>>16&255}ap=an>>>24&15;if((ap|0)!=0){an=c[(c[2440392]|0)+(ap<<2)>>2]|0;a[ae+9|0]=an&255;a[ae+10|0]=an>>>8&255;a[ae+11|0]=an>>>16&255}an=c[ah+((al|1)<<2)>>2]|0;al=an&15;if((al|0)!=0){ah=c[(c[2440392]|0)+(al<<2)>>2]|0;a[ae+6|0]=ah&255;a[ae+7|0]=ah>>>8&255;a[ae+8|0]=ah>>>16&255}ah=an>>>16&15;if((ah|0)!=0){al=c[(c[2440392]|0)+(ah<<2)>>2]|0;a[ae+3|0]=al&255;a[ae+4|0]=al>>>8&255;a[ae+5|0]=al>>>16&255}al=an>>>24&15;if((al|0)==0){break}an=c[(c[2440392]|0)+(al<<2)>>2]|0;a[ae]=an&255;a[ae+1|0]=an>>>8&255;a[ae+2|0]=an>>>16&255;break}}}while(0);af=I+1|0;if((af|0)>(H|0)){ac=aj;ad=ai;break}else{I=af;F=ak;D=aj;N=ai;ae=ae+s|0}}}if((Z|0)>(i|0)){U=35233;break}else{A=Z;B=ac;C=ad}}if((U|0)==35233){return}else if((U|0)==35235){return}}function cy8(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0;b=c[3540994]|0;f=c[3528548]|0;g=f<<8;h=c[2385554]|0;do{if((h|0)>31){i=511}else{j=(h<<4)-1|0;if((j|0)>=0){i=j;break}return}}while(0);j=(i|0)>255;k=i&255;l=c[2385550]|0;m=c[2113042]|0;n=c[2113044]|0;o=m+512|0;p=c[2113132]|0;q=(c[2385552]|0)*3|0;r=c[2112968]|0;s=p*3|0;t=c[2415160]|0;u=c[2429858]|0;v=c[2430428]|0;w=c[2429718]|0;x=c[2430092]|0;y=c[3541046]|0;z=c[2430426]|0;A=0;B=0;C=0;L40290:while(1){D=(h|0)>16&(f|0)!=255;E=(h|0)<33;F=511-f|0;G=f+1|0;H=f-255|0;I=~f;J=A;L40292:while(1){K=J+l|0;L=K&511;do{if((L|0)<(m|0)){M=J+m-L|0}else{if((L|0)>=(n|0)){M=o+J-L|0;break}N=(J|0)>255;O=N?16:0;P=J&255;Q=(J|0)<256&j?255:k;if(!D){R=O;S=P;T=Q;U=35259;break L40292}if(E){if(!N){U=35249;break L40292}if((J|0)<(F|0)){M=F;break}else{U=35251;break L40292}}if(N){V=H+P|0;if((V|0)>=0){U=35254;break L40292}N=G+V|0;if((N|0)<0){M=512;break}else{R=0;S=N;T=f;U=35259;break L40292}}else{if((P|0)<=(f|0)){U=35257;break L40292}N=P+I|0;if((N|0)>(f|0)){M=256;break}else{R=16;S=N;T=f;U=35259;break L40292}}}}while(0);if((M|0)>(i|0)){U=35304;break L40290}else{J=M}}if((U|0)==35254){U=0;W=f;X=V;Y=O;Z=G+J-V|0}else if((U|0)==35251){U=0;I=255-f|0;R=O;S=P-I|0;T=Q-I|0;U=35259}else if((U|0)==35257){U=0;W=f;X=P;Y=O;Z=G+J-P|0}else if((U|0)==35249){U=0;_=Q;$=P;aa=O;ab=J+1-P+Q|0;U=35260}if((U|0)==35259){U=0;I=J+1+T-S|0;if(E){_=T;$=S;aa=R;ab=I;U=35260}else{W=T;X=S;Y=R;Z=I}}if((U|0)==35260){U=0;W=(_|0)>(f|0)?f:_;X=$;Y=aa;Z=ab}I=((K|-512)^511)+n|0;H=(W-X|0)>(I|0)?I+X|0:W;if((X|0)>(H|0)){ac=B;ad=C}else{I=X;F=-1;D=B;N=C;ae=r+((ag(p,(L*3|0)-48|0)|0)+q)|0;while(1){af=d[b+(I+g)|0]|0;ah=(af>>>4)+Y|0;do{if((ah|0)==(F|0)){ai=N;aj=D;ak=F}else{al=ah<<1;am=e[t+((al|1)<<1)>>1]|0;an=(am<<12&983040|(e[t+(al<<1)>>1]|0))&u;do{if((am&8|0)==0){if((am&4|0)==0){ao=an;break}ao=v|an&1048572}else{ao=z|an&1048568}}while(0);an=a[w+ao|0]|0;al=an&255;if(an<<24>>24!=0){ai=al;aj=am;ak=ah;break}c[2385344]=x+(ao<<7);c[2440392]=y+((am>>>4&4080)<<2);ai=al;aj=am;ak=ah}}while(0);do{if((ai|0)==0){ah=af<<1&30;al=(aj&2|0)==0?ah:ah^30;ah=c[2385344]|0;an=c[ah+(al<<2)>>2]|0;ap=an>>>8&15;aq=(ap|0)==0;if((aj&1|0)==0){if(!aq){ar=c[(c[2440392]|0)+(ap<<2)>>2]|0;a[ae]=ar&255;a[ae+1|0]=ar>>>8&255;a[ae+2|0]=ar>>>16&255}ar=an>>>16&15;if((ar|0)!=0){as=c[(c[2440392]|0)+(ar<<2)>>2]|0;a[ae+3|0]=as&255;a[ae+4|0]=as>>>8&255;a[ae+5|0]=as>>>16&255}as=an>>>24&15;if((as|0)!=0){ar=c[(c[2440392]|0)+(as<<2)>>2]|0;a[ae+6|0]=ar&255;a[ae+7|0]=ar>>>8&255;a[ae+8|0]=ar>>>16&255}ar=c[ah+((al|1)<<2)>>2]|0;as=ar&15;if((as|0)!=0){at=c[(c[2440392]|0)+(as<<2)>>2]|0;a[ae+9|0]=at&255;a[ae+10|0]=at>>>8&255;a[ae+11|0]=at>>>16&255}at=ar>>>8&15;if((at|0)!=0){as=c[(c[2440392]|0)+(at<<2)>>2]|0;a[ae+12|0]=as&255;a[ae+13|0]=as>>>8&255;a[ae+14|0]=as>>>16&255}as=ar>>>16&15;if((as|0)!=0){at=c[(c[2440392]|0)+(as<<2)>>2]|0;a[ae+15|0]=at&255;a[ae+16|0]=at>>>8&255;a[ae+17|0]=at>>>16&255}at=ar>>>24&15;if((at|0)==0){break}ar=c[(c[2440392]|0)+(at<<2)>>2]|0;a[ae+18|0]=ar&255;a[ae+19|0]=ar>>>8&255;a[ae+20|0]=ar>>>16&255;break}else{if(!aq){aq=c[(c[2440392]|0)+(ap<<2)>>2]|0;a[ae+18|0]=aq&255;a[ae+19|0]=aq>>>8&255;a[ae+20|0]=aq>>>16&255}aq=an>>>16&15;if((aq|0)!=0){ap=c[(c[2440392]|0)+(aq<<2)>>2]|0;a[ae+15|0]=ap&255;a[ae+16|0]=ap>>>8&255;a[ae+17|0]=ap>>>16&255}ap=an>>>24&15;if((ap|0)!=0){an=c[(c[2440392]|0)+(ap<<2)>>2]|0;a[ae+12|0]=an&255;a[ae+13|0]=an>>>8&255;a[ae+14|0]=an>>>16&255}an=c[ah+((al|1)<<2)>>2]|0;al=an&15;if((al|0)!=0){ah=c[(c[2440392]|0)+(al<<2)>>2]|0;a[ae+9|0]=ah&255;a[ae+10|0]=ah>>>8&255;a[ae+11|0]=ah>>>16&255}ah=an>>>8&15;if((ah|0)!=0){al=c[(c[2440392]|0)+(ah<<2)>>2]|0;a[ae+6|0]=al&255;a[ae+7|0]=al>>>8&255;a[ae+8|0]=al>>>16&255}al=an>>>16&15;if((al|0)!=0){ah=c[(c[2440392]|0)+(al<<2)>>2]|0;a[ae+3|0]=ah&255;a[ae+4|0]=ah>>>8&255;a[ae+5|0]=ah>>>16&255}ah=an>>>24&15;if((ah|0)==0){break}an=c[(c[2440392]|0)+(ah<<2)>>2]|0;a[ae]=an&255;a[ae+1|0]=an>>>8&255;a[ae+2|0]=an>>>16&255;break}}}while(0);af=I+1|0;if((af|0)>(H|0)){ac=aj;ad=ai;break}else{I=af;F=ak;D=aj;N=ai;ae=ae+s|0}}}if((Z|0)>(i|0)){U=35303;break}else{A=Z;B=ac;C=ad}}if((U|0)==35303){return}else if((U|0)==35304){return}}function cy9(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0;b=c[3540994]|0;f=c[3528548]|0;g=f<<8;h=c[2385554]|0;do{if((h|0)>31){i=511}else{j=(h<<4)-1|0;if((j|0)>=0){i=j;break}return}}while(0);j=(i|0)>255;k=i&255;l=c[2385550]|0;m=c[2113042]|0;n=c[2113044]|0;o=m+512|0;p=c[2113132]|0;q=(c[2385552]|0)*3|0;r=c[2112968]|0;s=p*3|0;t=c[2415160]|0;u=c[2429858]|0;v=c[2430428]|0;w=c[2429718]|0;x=c[2430092]|0;y=c[3541046]|0;z=c[2430426]|0;A=0;B=0;C=0;L40387:while(1){D=(h|0)>16&(f|0)!=255;E=(h|0)<33;F=511-f|0;G=f+1|0;H=f-255|0;I=~f;J=A;L40389:while(1){K=J+l|0;L=K&511;do{if((L|0)<(m|0)){M=J+m-L|0}else{if((L|0)>=(n|0)){M=o+J-L|0;break}N=(J|0)>255;O=N?16:0;P=J&255;Q=(J|0)<256&j?255:k;if(!D){R=O;S=P;T=Q;U=35328;break L40389}if(E){if(!N){U=35318;break L40389}if((J|0)<(F|0)){M=F;break}else{U=35320;break L40389}}if(N){V=H+P|0;if((V|0)>=0){U=35323;break L40389}N=G+V|0;if((N|0)<0){M=512;break}else{R=0;S=N;T=f;U=35328;break L40389}}else{if((P|0)<=(f|0)){U=35326;break L40389}N=P+I|0;if((N|0)>(f|0)){M=256;break}else{R=16;S=N;T=f;U=35328;break L40389}}}}while(0);if((M|0)>(i|0)){U=35377;break L40387}else{J=M}}if((U|0)==35320){U=0;I=255-f|0;R=O;S=P-I|0;T=Q-I|0;U=35328}else if((U|0)==35323){U=0;W=f;X=V;Y=O;Z=G+J-V|0}else if((U|0)==35326){U=0;W=f;X=P;Y=O;Z=G+J-P|0}else if((U|0)==35318){U=0;_=Q;$=P;aa=O;ab=J+1-P+Q|0;U=35329}if((U|0)==35328){U=0;I=J+1+T-S|0;if(E){_=T;$=S;aa=R;ab=I;U=35329}else{W=T;X=S;Y=R;Z=I}}if((U|0)==35329){U=0;W=(_|0)>(f|0)?f:_;X=$;Y=aa;Z=ab}I=((K|-512)^511)+n|0;H=(W-X|0)>(I|0)?I+X|0:W;if((X|0)>(H|0)){ac=B;ad=C}else{I=X;F=-1;D=B;N=C;ae=r+((ag(p,(L*3|0)-48|0)|0)+q)|0;while(1){af=d[b+(I+g)|0]|0;ah=(af>>>4)+Y|0;do{if((ah|0)==(F|0)){ai=N;aj=D;ak=F}else{al=ah<<1;am=e[t+((al|1)<<1)>>1]|0;an=(am<<12&983040|(e[t+(al<<1)>>1]|0))&u;do{if((am&8|0)==0){if((am&4|0)==0){ao=an;break}ao=v|an&1048572}else{ao=z|an&1048568}}while(0);an=a[w+ao|0]|0;al=an&255;if(an<<24>>24!=0){ai=al;aj=am;ak=ah;break}c[2385344]=x+(ao<<7);c[2440392]=y+((am>>>4&4080)<<2);ai=al;aj=am;ak=ah}}while(0);do{if((ai|0)==0){ah=af<<1&30;al=(aj&2|0)==0?ah:ah^30;ah=c[2385344]|0;an=c[ah+(al<<2)>>2]|0;ap=an&15;aq=(ap|0)==0;if((aj&1|0)==0){if(!aq){ar=c[(c[2440392]|0)+(ap<<2)>>2]|0;a[ae]=ar&255;a[ae+1|0]=ar>>>8&255;a[ae+2|0]=ar>>>16&255}ar=an>>>8&15;if((ar|0)!=0){as=c[(c[2440392]|0)+(ar<<2)>>2]|0;a[ae+3|0]=as&255;a[ae+4|0]=as>>>8&255;a[ae+5|0]=as>>>16&255}as=an>>>16&15;if((as|0)!=0){ar=c[(c[2440392]|0)+(as<<2)>>2]|0;a[ae+6|0]=ar&255;a[ae+7|0]=ar>>>8&255;a[ae+8|0]=ar>>>16&255}ar=an>>>24&15;if((ar|0)!=0){as=c[(c[2440392]|0)+(ar<<2)>>2]|0;a[ae+9|0]=as&255;a[ae+10|0]=as>>>8&255;a[ae+11|0]=as>>>16&255}as=c[ah+((al|1)<<2)>>2]|0;ar=as&15;if((ar|0)!=0){at=c[(c[2440392]|0)+(ar<<2)>>2]|0;a[ae+12|0]=at&255;a[ae+13|0]=at>>>8&255;a[ae+14|0]=at>>>16&255}at=as>>>8&15;if((at|0)!=0){ar=c[(c[2440392]|0)+(at<<2)>>2]|0;a[ae+15|0]=ar&255;a[ae+16|0]=ar>>>8&255;a[ae+17|0]=ar>>>16&255}ar=as>>>16&15;if((ar|0)!=0){at=c[(c[2440392]|0)+(ar<<2)>>2]|0;a[ae+18|0]=at&255;a[ae+19|0]=at>>>8&255;a[ae+20|0]=at>>>16&255}at=as>>>24&15;if((at|0)==0){break}as=c[(c[2440392]|0)+(at<<2)>>2]|0;a[ae+21|0]=as&255;a[ae+22|0]=as>>>8&255;a[ae+23|0]=as>>>16&255;break}else{if(!aq){aq=c[(c[2440392]|0)+(ap<<2)>>2]|0;a[ae+21|0]=aq&255;a[ae+22|0]=aq>>>8&255;a[ae+23|0]=aq>>>16&255}aq=an>>>8&15;if((aq|0)!=0){ap=c[(c[2440392]|0)+(aq<<2)>>2]|0;a[ae+18|0]=ap&255;a[ae+19|0]=ap>>>8&255;a[ae+20|0]=ap>>>16&255}ap=an>>>16&15;if((ap|0)!=0){aq=c[(c[2440392]|0)+(ap<<2)>>2]|0;a[ae+15|0]=aq&255;a[ae+16|0]=aq>>>8&255;a[ae+17|0]=aq>>>16&255}aq=an>>>24&15;if((aq|0)!=0){an=c[(c[2440392]|0)+(aq<<2)>>2]|0;a[ae+12|0]=an&255;a[ae+13|0]=an>>>8&255;a[ae+14|0]=an>>>16&255}an=c[ah+((al|1)<<2)>>2]|0;al=an&15;if((al|0)!=0){ah=c[(c[2440392]|0)+(al<<2)>>2]|0;a[ae+9|0]=ah&255;a[ae+10|0]=ah>>>8&255;a[ae+11|0]=ah>>>16&255}ah=an>>>8&15;if((ah|0)!=0){al=c[(c[2440392]|0)+(ah<<2)>>2]|0;a[ae+6|0]=al&255;a[ae+7|0]=al>>>8&255;a[ae+8|0]=al>>>16&255}al=an>>>16&15;if((al|0)!=0){ah=c[(c[2440392]|0)+(al<<2)>>2]|0;a[ae+3|0]=ah&255;a[ae+4|0]=ah>>>8&255;a[ae+5|0]=ah>>>16&255}ah=an>>>24&15;if((ah|0)==0){break}an=c[(c[2440392]|0)+(ah<<2)>>2]|0;a[ae]=an&255;a[ae+1|0]=an>>>8&255;a[ae+2|0]=an>>>16&255;break}}}while(0);af=I+1|0;if((af|0)>(H|0)){ac=aj;ad=ai;break}else{I=af;F=ak;D=aj;N=ai;ae=ae+s|0}}}if((Z|0)>(i|0)){U=35375;break}else{A=Z;B=ac;C=ad}}if((U|0)==35375){return}else if((U|0)==35377){return}}function cza(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0;b=c[3540994]|0;f=c[3528548]|0;g=f<<8;h=c[2385554]|0;do{if((h|0)>31){i=511}else{j=(h<<4)-1|0;if((j|0)>=0){i=j;break}return}}while(0);j=(i|0)>255;k=i&255;l=c[2385550]|0;m=c[2113042]|0;n=c[2113044]|0;o=m+512|0;p=c[2113132]|0;q=(c[2385552]|0)*3|0;r=c[2112968]|0;s=p*3|0;t=c[2415160]|0;u=c[2429858]|0;v=c[2430428]|0;w=c[2429718]|0;x=c[2430092]|0;y=c[3541046]|0;z=c[2430426]|0;A=0;B=0;C=0;L40490:while(1){D=(h|0)>16&(f|0)!=255;E=(h|0)<33;F=511-f|0;G=f+1|0;H=f-255|0;I=~f;J=A;L40492:while(1){K=J+l|0;L=K&511;do{if((L|0)<(m|0)){M=J+m-L|0}else{if((L|0)>=(n|0)){M=o+J-L|0;break}N=(J|0)>255;O=N?16:0;P=J&255;Q=(J|0)<256&j?255:k;if(!D){R=O;S=P;T=Q;U=35401;break L40492}if(E){if(!N){U=35391;break L40492}if((J|0)<(F|0)){M=F;break}else{U=35393;break L40492}}if(N){V=H+P|0;if((V|0)>=0){U=35396;break L40492}N=G+V|0;if((N|0)<0){M=512;break}else{R=0;S=N;T=f;U=35401;break L40492}}else{if((P|0)<=(f|0)){U=35399;break L40492}N=P+I|0;if((N|0)>(f|0)){M=256;break}else{R=16;S=N;T=f;U=35401;break L40492}}}}while(0);if((M|0)>(i|0)){U=35454;break L40490}else{J=M}}if((U|0)==35396){U=0;W=f;X=V;Y=O;Z=G+J-V|0}else if((U|0)==35393){U=0;I=255-f|0;R=O;S=P-I|0;T=Q-I|0;U=35401}else if((U|0)==35399){U=0;W=f;X=P;Y=O;Z=G+J-P|0}else if((U|0)==35391){U=0;_=Q;$=P;aa=O;ab=J+1-P+Q|0;U=35402}if((U|0)==35401){U=0;I=J+1+T-S|0;if(E){_=T;$=S;aa=R;ab=I;U=35402}else{W=T;X=S;Y=R;Z=I}}if((U|0)==35402){U=0;W=(_|0)>(f|0)?f:_;X=$;Y=aa;Z=ab}I=((K|-512)^511)+n|0;H=(W-X|0)>(I|0)?I+X|0:W;if((X|0)>(H|0)){ac=B;ad=C}else{I=X;F=-1;D=B;N=C;ae=r+((ag(p,(L*3|0)-48|0)|0)+q)|0;while(1){af=d[b+(I+g)|0]|0;ah=(af>>>4)+Y|0;do{if((ah|0)==(F|0)){ai=N;aj=D;ak=F}else{al=ah<<1;am=e[t+((al|1)<<1)>>1]|0;an=(am<<12&983040|(e[t+(al<<1)>>1]|0))&u;do{if((am&8|0)==0){if((am&4|0)==0){ao=an;break}ao=v|an&1048572}else{ao=z|an&1048568}}while(0);an=a[w+ao|0]|0;al=an&255;if(an<<24>>24!=0){ai=al;aj=am;ak=ah;break}c[2385344]=x+(ao<<7);c[2440392]=y+((am>>>4&4080)<<2);ai=al;aj=am;ak=ah}}while(0);do{if((ai|0)==0){ah=af<<1&30;al=(aj&2|0)==0?ah:ah^30;ah=c[2385344]|0;an=c[ah+(al<<2)>>2]|0;ap=an&15;aq=(ap|0)==0;if((aj&1|0)==0){if(!aq){ar=c[(c[2440392]|0)+(ap<<2)>>2]|0;a[ae]=ar&255;a[ae+1|0]=ar>>>8&255;a[ae+2|0]=ar>>>16&255}ar=an>>>8&15;if((ar|0)!=0){as=c[(c[2440392]|0)+(ar<<2)>>2]|0;a[ae+3|0]=as&255;a[ae+4|0]=as>>>8&255;a[ae+5|0]=as>>>16&255}as=an>>>16&15;if((as|0)!=0){ar=c[(c[2440392]|0)+(as<<2)>>2]|0;a[ae+6|0]=ar&255;a[ae+7|0]=ar>>>8&255;a[ae+8|0]=ar>>>16&255}ar=an>>>24&15;if((ar|0)!=0){as=c[(c[2440392]|0)+(ar<<2)>>2]|0;a[ae+9|0]=as&255;a[ae+10|0]=as>>>8&255;a[ae+11|0]=as>>>16&255}as=c[ah+((al|1)<<2)>>2]|0;ar=as&15;if((ar|0)!=0){at=c[(c[2440392]|0)+(ar<<2)>>2]|0;a[ae+12|0]=at&255;a[ae+13|0]=at>>>8&255;a[ae+14|0]=at>>>16&255}at=as>>>4&15;if((at|0)!=0){ar=c[(c[2440392]|0)+(at<<2)>>2]|0;a[ae+15|0]=ar&255;a[ae+16|0]=ar>>>8&255;a[ae+17|0]=ar>>>16&255}ar=as>>>8&15;if((ar|0)!=0){at=c[(c[2440392]|0)+(ar<<2)>>2]|0;a[ae+18|0]=at&255;a[ae+19|0]=at>>>8&255;a[ae+20|0]=at>>>16&255}at=as>>>16&15;if((at|0)!=0){ar=c[(c[2440392]|0)+(at<<2)>>2]|0;a[ae+21|0]=ar&255;a[ae+22|0]=ar>>>8&255;a[ae+23|0]=ar>>>16&255}ar=as>>>24&15;if((ar|0)==0){break}as=c[(c[2440392]|0)+(ar<<2)>>2]|0;a[ae+24|0]=as&255;a[ae+25|0]=as>>>8&255;a[ae+26|0]=as>>>16&255;break}else{if(!aq){aq=c[(c[2440392]|0)+(ap<<2)>>2]|0;a[ae+24|0]=aq&255;a[ae+25|0]=aq>>>8&255;a[ae+26|0]=aq>>>16&255}aq=an>>>8&15;if((aq|0)!=0){ap=c[(c[2440392]|0)+(aq<<2)>>2]|0;a[ae+21|0]=ap&255;a[ae+22|0]=ap>>>8&255;a[ae+23|0]=ap>>>16&255}ap=an>>>16&15;if((ap|0)!=0){aq=c[(c[2440392]|0)+(ap<<2)>>2]|0;a[ae+18|0]=aq&255;a[ae+19|0]=aq>>>8&255;a[ae+20|0]=aq>>>16&255}aq=an>>>24&15;if((aq|0)!=0){an=c[(c[2440392]|0)+(aq<<2)>>2]|0;a[ae+15|0]=an&255;a[ae+16|0]=an>>>8&255;a[ae+17|0]=an>>>16&255}an=c[ah+((al|1)<<2)>>2]|0;al=an&15;if((al|0)!=0){ah=c[(c[2440392]|0)+(al<<2)>>2]|0;a[ae+12|0]=ah&255;a[ae+13|0]=ah>>>8&255;a[ae+14|0]=ah>>>16&255}ah=an>>>4&15;if((ah|0)!=0){al=c[(c[2440392]|0)+(ah<<2)>>2]|0;a[ae+9|0]=al&255;a[ae+10|0]=al>>>8&255;a[ae+11|0]=al>>>16&255}al=an>>>8&15;if((al|0)!=0){ah=c[(c[2440392]|0)+(al<<2)>>2]|0;a[ae+6|0]=ah&255;a[ae+7|0]=ah>>>8&255;a[ae+8|0]=ah>>>16&255}ah=an>>>16&15;if((ah|0)!=0){al=c[(c[2440392]|0)+(ah<<2)>>2]|0;a[ae+3|0]=al&255;a[ae+4|0]=al>>>8&255;a[ae+5|0]=al>>>16&255}al=an>>>24&15;if((al|0)==0){break}an=c[(c[2440392]|0)+(al<<2)>>2]|0;a[ae]=an&255;a[ae+1|0]=an>>>8&255;a[ae+2|0]=an>>>16&255;break}}}while(0);af=I+1|0;if((af|0)>(H|0)){ac=aj;ad=ai;break}else{I=af;F=ak;D=aj;N=ai;ae=ae+s|0}}}if((Z|0)>(i|0)){U=35453;break}else{A=Z;B=ac;C=ad}}if((U|0)==35453){return}else if((U|0)==35454){return}}function czb(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0;b=c[3540994]|0;f=c[3528548]|0;g=f<<8;h=c[2385554]|0;do{if((h|0)>31){i=511}else{j=(h<<4)-1|0;if((j|0)>=0){i=j;break}return}}while(0);j=(i|0)>255;k=i&255;l=c[2385550]|0;m=c[2113042]|0;n=c[2113044]|0;o=m+512|0;p=c[2113132]|0;q=(c[2385552]|0)*3|0;r=c[2112968]|0;s=p*3|0;t=c[2415160]|0;u=c[2429858]|0;v=c[2430428]|0;w=c[2429718]|0;x=c[2430092]|0;y=c[3541046]|0;z=c[2430426]|0;A=0;B=0;C=0;L40599:while(1){D=(h|0)>16&(f|0)!=255;E=(h|0)<33;F=511-f|0;G=f+1|0;H=f-255|0;I=~f;J=A;L40601:while(1){K=J+l|0;L=K&511;do{if((L|0)<(m|0)){M=J+m-L|0}else{if((L|0)>=(n|0)){M=o+J-L|0;break}N=(J|0)>255;O=N?16:0;P=J&255;Q=(J|0)<256&j?255:k;if(!D){R=O;S=P;T=Q;U=35478;break L40601}if(E){if(!N){U=35468;break L40601}if((J|0)<(F|0)){M=F;break}else{U=35470;break L40601}}if(N){V=H+P|0;if((V|0)>=0){U=35473;break L40601}N=G+V|0;if((N|0)<0){M=512;break}else{R=0;S=N;T=f;U=35478;break L40601}}else{if((P|0)<=(f|0)){U=35476;break L40601}N=P+I|0;if((N|0)>(f|0)){M=256;break}else{R=16;S=N;T=f;U=35478;break L40601}}}}while(0);if((M|0)>(i|0)){U=35535;break L40599}else{J=M}}if((U|0)==35470){U=0;I=255-f|0;R=O;S=P-I|0;T=Q-I|0;U=35478}else if((U|0)==35476){U=0;W=f;X=P;Y=O;Z=G+J-P|0}else if((U|0)==35473){U=0;W=f;X=V;Y=O;Z=G+J-V|0}else if((U|0)==35468){U=0;_=Q;$=P;aa=O;ab=J+1-P+Q|0;U=35479}if((U|0)==35478){U=0;I=J+1+T-S|0;if(E){_=T;$=S;aa=R;ab=I;U=35479}else{W=T;X=S;Y=R;Z=I}}if((U|0)==35479){U=0;W=(_|0)>(f|0)?f:_;X=$;Y=aa;Z=ab}I=((K|-512)^511)+n|0;H=(W-X|0)>(I|0)?I+X|0:W;if((X|0)>(H|0)){ac=B;ad=C}else{I=X;F=-1;D=B;N=C;ae=r+((ag(p,(L*3|0)-48|0)|0)+q)|0;while(1){af=d[b+(I+g)|0]|0;ah=(af>>>4)+Y|0;do{if((ah|0)==(F|0)){ai=N;aj=D;ak=F}else{al=ah<<1;am=e[t+((al|1)<<1)>>1]|0;an=(am<<12&983040|(e[t+(al<<1)>>1]|0))&u;do{if((am&8|0)==0){if((am&4|0)==0){ao=an;break}ao=v|an&1048572}else{ao=z|an&1048568}}while(0);an=a[w+ao|0]|0;al=an&255;if(an<<24>>24!=0){ai=al;aj=am;ak=ah;break}c[2385344]=x+(ao<<7);c[2440392]=y+((am>>>4&4080)<<2);ai=al;aj=am;ak=ah}}while(0);do{if((ai|0)==0){ah=af<<1&30;al=(aj&2|0)==0?ah:ah^30;ah=c[2385344]|0;an=c[ah+(al<<2)>>2]|0;ap=an&15;aq=(ap|0)==0;if((aj&1|0)==0){if(!aq){ar=c[(c[2440392]|0)+(ap<<2)>>2]|0;a[ae]=ar&255;a[ae+1|0]=ar>>>8&255;a[ae+2|0]=ar>>>16&255}ar=an>>>8&15;if((ar|0)!=0){as=c[(c[2440392]|0)+(ar<<2)>>2]|0;a[ae+3|0]=as&255;a[ae+4|0]=as>>>8&255;a[ae+5|0]=as>>>16&255}as=an>>>12&15;if((as|0)!=0){ar=c[(c[2440392]|0)+(as<<2)>>2]|0;a[ae+6|0]=ar&255;a[ae+7|0]=ar>>>8&255;a[ae+8|0]=ar>>>16&255}ar=an>>>16&15;if((ar|0)!=0){as=c[(c[2440392]|0)+(ar<<2)>>2]|0;a[ae+9|0]=as&255;a[ae+10|0]=as>>>8&255;a[ae+11|0]=as>>>16&255}as=an>>>24&15;if((as|0)!=0){ar=c[(c[2440392]|0)+(as<<2)>>2]|0;a[ae+12|0]=ar&255;a[ae+13|0]=ar>>>8&255;a[ae+14|0]=ar>>>16&255}ar=c[ah+((al|1)<<2)>>2]|0;as=ar&15;if((as|0)!=0){at=c[(c[2440392]|0)+(as<<2)>>2]|0;a[ae+15|0]=at&255;a[ae+16|0]=at>>>8&255;a[ae+17|0]=at>>>16&255}at=ar>>>4&15;if((at|0)!=0){as=c[(c[2440392]|0)+(at<<2)>>2]|0;a[ae+18|0]=as&255;a[ae+19|0]=as>>>8&255;a[ae+20|0]=as>>>16&255}as=ar>>>8&15;if((as|0)!=0){at=c[(c[2440392]|0)+(as<<2)>>2]|0;a[ae+21|0]=at&255;a[ae+22|0]=at>>>8&255;a[ae+23|0]=at>>>16&255}at=ar>>>16&15;if((at|0)!=0){as=c[(c[2440392]|0)+(at<<2)>>2]|0;a[ae+24|0]=as&255;a[ae+25|0]=as>>>8&255;a[ae+26|0]=as>>>16&255}as=ar>>>24&15;if((as|0)==0){break}ar=c[(c[2440392]|0)+(as<<2)>>2]|0;a[ae+27|0]=ar&255;a[ae+28|0]=ar>>>8&255;a[ae+29|0]=ar>>>16&255;break}else{if(!aq){aq=c[(c[2440392]|0)+(ap<<2)>>2]|0;a[ae+27|0]=aq&255;a[ae+28|0]=aq>>>8&255;a[ae+29|0]=aq>>>16&255}aq=an>>>8&15;if((aq|0)!=0){ap=c[(c[2440392]|0)+(aq<<2)>>2]|0;a[ae+24|0]=ap&255;a[ae+25|0]=ap>>>8&255;a[ae+26|0]=ap>>>16&255}ap=an>>>12&15;if((ap|0)!=0){aq=c[(c[2440392]|0)+(ap<<2)>>2]|0;a[ae+21|0]=aq&255;a[ae+22|0]=aq>>>8&255;a[ae+23|0]=aq>>>16&255}aq=an>>>16&15;if((aq|0)!=0){ap=c[(c[2440392]|0)+(aq<<2)>>2]|0;a[ae+18|0]=ap&255;a[ae+19|0]=ap>>>8&255;a[ae+20|0]=ap>>>16&255}ap=an>>>24&15;if((ap|0)!=0){an=c[(c[2440392]|0)+(ap<<2)>>2]|0;a[ae+15|0]=an&255;a[ae+16|0]=an>>>8&255;a[ae+17|0]=an>>>16&255}an=c[ah+((al|1)<<2)>>2]|0;al=an&15;if((al|0)!=0){ah=c[(c[2440392]|0)+(al<<2)>>2]|0;a[ae+12|0]=ah&255;a[ae+13|0]=ah>>>8&255;a[ae+14|0]=ah>>>16&255}ah=an>>>4&15;if((ah|0)!=0){al=c[(c[2440392]|0)+(ah<<2)>>2]|0;a[ae+9|0]=al&255;a[ae+10|0]=al>>>8&255;a[ae+11|0]=al>>>16&255}al=an>>>8&15;if((al|0)!=0){ah=c[(c[2440392]|0)+(al<<2)>>2]|0;a[ae+6|0]=ah&255;a[ae+7|0]=ah>>>8&255;a[ae+8|0]=ah>>>16&255}ah=an>>>16&15;if((ah|0)!=0){al=c[(c[2440392]|0)+(ah<<2)>>2]|0;a[ae+3|0]=al&255;a[ae+4|0]=al>>>8&255;a[ae+5|0]=al>>>16&255}al=an>>>24&15;if((al|0)==0){break}an=c[(c[2440392]|0)+(al<<2)>>2]|0;a[ae]=an&255;a[ae+1|0]=an>>>8&255;a[ae+2|0]=an>>>16&255;break}}}while(0);af=I+1|0;if((af|0)>(H|0)){ac=aj;ad=ai;break}else{I=af;F=ak;D=aj;N=ai;ae=ae+s|0}}}if((Z|0)>(i|0)){U=35533;break}else{A=Z;B=ac;C=ad}}if((U|0)==35533){return}else if((U|0)==35535){return}}function czc(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0;b=c[3540994]|0;f=c[3528548]|0;g=f<<8;h=c[2385554]|0;do{if((h|0)>31){i=511}else{j=(h<<4)-1|0;if((j|0)>=0){i=j;break}return}}while(0);j=(i|0)>255;k=i&255;l=c[2385550]|0;m=c[2113042]|0;n=c[2113044]|0;o=m+512|0;p=c[2113132]|0;q=(c[2385552]|0)*3|0;r=c[2112968]|0;s=p*3|0;t=c[2415160]|0;u=c[2429858]|0;v=c[2430428]|0;w=c[2429718]|0;x=c[2430092]|0;y=c[3541046]|0;z=c[2430426]|0;A=0;B=0;C=0;L40714:while(1){D=(h|0)>16&(f|0)!=255;E=(h|0)<33;F=511-f|0;G=f+1|0;H=f-255|0;I=~f;J=A;L40716:while(1){K=J+l|0;L=K&511;do{if((L|0)<(m|0)){M=J+m-L|0}else{if((L|0)>=(n|0)){M=o+J-L|0;break}N=(J|0)>255;O=N?16:0;P=J&255;Q=(J|0)<256&j?255:k;if(!D){R=O;S=P;T=Q;U=35559;break L40716}if(E){if(!N){U=35549;break L40716}if((J|0)<(F|0)){M=F;break}else{U=35551;break L40716}}if(N){V=H+P|0;if((V|0)>=0){U=35554;break L40716}N=G+V|0;if((N|0)<0){M=512;break}else{R=0;S=N;T=f;U=35559;break L40716}}else{if((P|0)<=(f|0)){U=35557;break L40716}N=P+I|0;if((N|0)>(f|0)){M=256;break}else{R=16;S=N;T=f;U=35559;break L40716}}}}while(0);if((M|0)>(i|0)){U=35620;break L40714}else{J=M}}if((U|0)==35551){U=0;I=255-f|0;R=O;S=P-I|0;T=Q-I|0;U=35559}else if((U|0)==35557){U=0;W=f;X=P;Y=O;Z=G+J-P|0}else if((U|0)==35554){U=0;W=f;X=V;Y=O;Z=G+J-V|0}else if((U|0)==35549){U=0;_=Q;$=P;aa=O;ab=J+1-P+Q|0;U=35560}if((U|0)==35559){U=0;I=J+1+T-S|0;if(E){_=T;$=S;aa=R;ab=I;U=35560}else{W=T;X=S;Y=R;Z=I}}if((U|0)==35560){U=0;W=(_|0)>(f|0)?f:_;X=$;Y=aa;Z=ab}I=((K|-512)^511)+n|0;H=(W-X|0)>(I|0)?I+X|0:W;if((X|0)>(H|0)){ac=B;ad=C}else{I=X;F=-1;D=B;N=C;ae=r+((ag(p,(L*3|0)-48|0)|0)+q)|0;while(1){af=d[b+(I+g)|0]|0;ah=(af>>>4)+Y|0;do{if((ah|0)==(F|0)){ai=N;aj=D;ak=F}else{al=ah<<1;am=e[t+((al|1)<<1)>>1]|0;an=(am<<12&983040|(e[t+(al<<1)>>1]|0))&u;do{if((am&8|0)==0){if((am&4|0)==0){ao=an;break}ao=v|an&1048572}else{ao=z|an&1048568}}while(0);an=a[w+ao|0]|0;al=an&255;if(an<<24>>24!=0){ai=al;aj=am;ak=ah;break}c[2385344]=x+(ao<<7);c[2440392]=y+((am>>>4&4080)<<2);ai=al;aj=am;ak=ah}}while(0);do{if((ai|0)==0){ah=af<<1&30;al=(aj&2|0)==0?ah:ah^30;ah=c[2385344]|0;an=c[ah+(al<<2)>>2]|0;ap=an&15;aq=(ap|0)==0;if((aj&1|0)==0){if(!aq){ar=c[(c[2440392]|0)+(ap<<2)>>2]|0;a[ae]=ar&255;a[ae+1|0]=ar>>>8&255;a[ae+2|0]=ar>>>16&255}ar=an>>>8&15;if((ar|0)!=0){as=c[(c[2440392]|0)+(ar<<2)>>2]|0;a[ae+3|0]=as&255;a[ae+4|0]=as>>>8&255;a[ae+5|0]=as>>>16&255}as=an>>>12&15;if((as|0)!=0){ar=c[(c[2440392]|0)+(as<<2)>>2]|0;a[ae+6|0]=ar&255;a[ae+7|0]=ar>>>8&255;a[ae+8|0]=ar>>>16&255}ar=an>>>16&15;if((ar|0)!=0){as=c[(c[2440392]|0)+(ar<<2)>>2]|0;a[ae+9|0]=as&255;a[ae+10|0]=as>>>8&255;a[ae+11|0]=as>>>16&255}as=an>>>24&15;if((as|0)!=0){ar=c[(c[2440392]|0)+(as<<2)>>2]|0;a[ae+12|0]=ar&255;a[ae+13|0]=ar>>>8&255;a[ae+14|0]=ar>>>16&255}ar=c[ah+((al|1)<<2)>>2]|0;as=ar&15;if((as|0)!=0){at=c[(c[2440392]|0)+(as<<2)>>2]|0;a[ae+15|0]=at&255;a[ae+16|0]=at>>>8&255;a[ae+17|0]=at>>>16&255}at=ar>>>4&15;if((at|0)!=0){as=c[(c[2440392]|0)+(at<<2)>>2]|0;a[ae+18|0]=as&255;a[ae+19|0]=as>>>8&255;a[ae+20|0]=as>>>16&255}as=ar>>>8&15;if((as|0)!=0){at=c[(c[2440392]|0)+(as<<2)>>2]|0;a[ae+21|0]=at&255;a[ae+22|0]=at>>>8&255;a[ae+23|0]=at>>>16&255}at=ar>>>16&15;if((at|0)!=0){as=c[(c[2440392]|0)+(at<<2)>>2]|0;a[ae+24|0]=as&255;a[ae+25|0]=as>>>8&255;a[ae+26|0]=as>>>16&255}as=ar>>>24&15;if((as|0)!=0){at=c[(c[2440392]|0)+(as<<2)>>2]|0;a[ae+27|0]=at&255;a[ae+28|0]=at>>>8&255;a[ae+29|0]=at>>>16&255}at=ar>>>28;if((at|0)==0){break}ar=c[(c[2440392]|0)+(at<<2)>>2]|0;a[ae+30|0]=ar&255;a[ae+31|0]=ar>>>8&255;a[ae+32|0]=ar>>>16&255;break}else{if(!aq){aq=c[(c[2440392]|0)+(ap<<2)>>2]|0;a[ae+30|0]=aq&255;a[ae+31|0]=aq>>>8&255;a[ae+32|0]=aq>>>16&255}aq=an>>>8&15;if((aq|0)!=0){ap=c[(c[2440392]|0)+(aq<<2)>>2]|0;a[ae+27|0]=ap&255;a[ae+28|0]=ap>>>8&255;a[ae+29|0]=ap>>>16&255}ap=an>>>12&15;if((ap|0)!=0){aq=c[(c[2440392]|0)+(ap<<2)>>2]|0;a[ae+24|0]=aq&255;a[ae+25|0]=aq>>>8&255;a[ae+26|0]=aq>>>16&255}aq=an>>>16&15;if((aq|0)!=0){ap=c[(c[2440392]|0)+(aq<<2)>>2]|0;a[ae+21|0]=ap&255;a[ae+22|0]=ap>>>8&255;a[ae+23|0]=ap>>>16&255}ap=an>>>24&15;if((ap|0)!=0){an=c[(c[2440392]|0)+(ap<<2)>>2]|0;a[ae+18|0]=an&255;a[ae+19|0]=an>>>8&255;a[ae+20|0]=an>>>16&255}an=c[ah+((al|1)<<2)>>2]|0;al=an&15;if((al|0)!=0){ah=c[(c[2440392]|0)+(al<<2)>>2]|0;a[ae+15|0]=ah&255;a[ae+16|0]=ah>>>8&255;a[ae+17|0]=ah>>>16&255}ah=an>>>4&15;if((ah|0)!=0){al=c[(c[2440392]|0)+(ah<<2)>>2]|0;a[ae+12|0]=al&255;a[ae+13|0]=al>>>8&255;a[ae+14|0]=al>>>16&255}al=an>>>8&15;if((al|0)!=0){ah=c[(c[2440392]|0)+(al<<2)>>2]|0;a[ae+9|0]=ah&255;a[ae+10|0]=ah>>>8&255;a[ae+11|0]=ah>>>16&255}ah=an>>>16&15;if((ah|0)!=0){al=c[(c[2440392]|0)+(ah<<2)>>2]|0;a[ae+6|0]=al&255;a[ae+7|0]=al>>>8&255;a[ae+8|0]=al>>>16&255}al=an>>>24&15;if((al|0)!=0){ah=c[(c[2440392]|0)+(al<<2)>>2]|0;a[ae+3|0]=ah&255;a[ae+4|0]=ah>>>8&255;a[ae+5|0]=ah>>>16&255}ah=an>>>28;if((ah|0)==0){break}an=c[(c[2440392]|0)+(ah<<2)>>2]|0;a[ae]=an&255;a[ae+1|0]=an>>>8&255;a[ae+2|0]=an>>>16&255;break}}}while(0);af=I+1|0;if((af|0)>(H|0)){ac=aj;ad=ai;break}else{I=af;F=ak;D=aj;N=ai;ae=ae+s|0}}}if((Z|0)>(i|0)){U=35618;break}else{A=Z;B=ac;C=ad}}if((U|0)==35618){return}else if((U|0)==35620){return}}function czd(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0;b=c[3540994]|0;f=c[3528548]|0;g=f<<8;h=c[2385554]|0;do{if((h|0)>31){i=511}else{j=(h<<4)-1|0;if((j|0)>=0){i=j;break}return}}while(0);j=(i|0)>255;k=i&255;l=c[2385550]|0;m=c[2113042]|0;n=c[2113044]|0;o=m+512|0;p=c[2113132]|0;q=(c[2385552]|0)*3|0;r=c[2112968]|0;s=p*3|0;t=c[2415160]|0;u=c[2429858]|0;v=c[2430428]|0;w=c[2429718]|0;x=c[2430092]|0;y=c[3541046]|0;z=c[2430426]|0;A=0;B=0;C=0;L40835:while(1){D=(h|0)>16&(f|0)!=255;E=(h|0)<33;F=511-f|0;G=f+1|0;H=f-255|0;I=~f;J=A;L40837:while(1){K=J+l|0;L=K&511;do{if((L|0)<(m|0)){M=J+m-L|0}else{if((L|0)>=(n|0)){M=o+J-L|0;break}N=(J|0)>255;O=N?16:0;P=J&255;Q=(J|0)<256&j?255:k;if(!D){R=O;S=P;T=Q;U=35644;break L40837}if(E){if(!N){U=35634;break L40837}if((J|0)<(F|0)){M=F;break}else{U=35636;break L40837}}if(N){V=H+P|0;if((V|0)>=0){U=35639;break L40837}N=G+V|0;if((N|0)<0){M=512;break}else{R=0;S=N;T=f;U=35644;break L40837}}else{if((P|0)<=(f|0)){U=35642;break L40837}N=P+I|0;if((N|0)>(f|0)){M=256;break}else{R=16;S=N;T=f;U=35644;break L40837}}}}while(0);if((M|0)>(i|0)){U=35709;break L40835}else{J=M}}if((U|0)==35634){U=0;W=Q;X=P;Y=O;Z=J+1-P+Q|0;U=35645}else if((U|0)==35642){U=0;_=f;$=P;aa=O;ab=G+J-P|0}else if((U|0)==35639){U=0;_=f;$=V;aa=O;ab=G+J-V|0}else if((U|0)==35636){U=0;I=255-f|0;R=O;S=P-I|0;T=Q-I|0;U=35644}if((U|0)==35644){U=0;I=J+1+T-S|0;if(E){W=T;X=S;Y=R;Z=I;U=35645}else{_=T;$=S;aa=R;ab=I}}if((U|0)==35645){U=0;_=(W|0)>(f|0)?f:W;$=X;aa=Y;ab=Z}I=((K|-512)^511)+n|0;H=(_-$|0)>(I|0)?I+$|0:_;if(($|0)>(H|0)){ac=B;ad=C}else{I=$;F=-1;D=B;N=C;ae=r+((ag(p,(L*3|0)-48|0)|0)+q)|0;while(1){af=d[b+(I+g)|0]|0;ah=(af>>>4)+aa|0;do{if((ah|0)==(F|0)){ai=N;aj=D;ak=F}else{al=ah<<1;am=e[t+((al|1)<<1)>>1]|0;an=(am<<12&983040|(e[t+(al<<1)>>1]|0))&u;do{if((am&8|0)==0){if((am&4|0)==0){ao=an;break}ao=v|an&1048572}else{ao=z|an&1048568}}while(0);an=a[w+ao|0]|0;al=an&255;if(an<<24>>24!=0){ai=al;aj=am;ak=ah;break}c[2385344]=x+(ao<<7);c[2440392]=y+((am>>>4&4080)<<2);ai=al;aj=am;ak=ah}}while(0);do{if((ai|0)==0){ah=af<<1&30;al=(aj&2|0)==0?ah:ah^30;ah=c[2385344]|0;an=c[ah+(al<<2)>>2]|0;ap=an&15;aq=(ap|0)==0;if((aj&1|0)==0){if(!aq){ar=c[(c[2440392]|0)+(ap<<2)>>2]|0;a[ae]=ar&255;a[ae+1|0]=ar>>>8&255;a[ae+2|0]=ar>>>16&255}ar=an>>>8&15;if((ar|0)!=0){as=c[(c[2440392]|0)+(ar<<2)>>2]|0;a[ae+3|0]=as&255;a[ae+4|0]=as>>>8&255;a[ae+5|0]=as>>>16&255}as=an>>>12&15;if((as|0)!=0){ar=c[(c[2440392]|0)+(as<<2)>>2]|0;a[ae+6|0]=ar&255;a[ae+7|0]=ar>>>8&255;a[ae+8|0]=ar>>>16&255}ar=an>>>16&15;if((ar|0)!=0){as=c[(c[2440392]|0)+(ar<<2)>>2]|0;a[ae+9|0]=as&255;a[ae+10|0]=as>>>8&255;a[ae+11|0]=as>>>16&255}as=an>>>24&15;if((as|0)!=0){ar=c[(c[2440392]|0)+(as<<2)>>2]|0;a[ae+12|0]=ar&255;a[ae+13|0]=ar>>>8&255;a[ae+14|0]=ar>>>16&255}ar=an>>>28;if((ar|0)!=0){as=c[(c[2440392]|0)+(ar<<2)>>2]|0;a[ae+15|0]=as&255;a[ae+16|0]=as>>>8&255;a[ae+17|0]=as>>>16&255}as=c[ah+((al|1)<<2)>>2]|0;ar=as&15;if((ar|0)!=0){at=c[(c[2440392]|0)+(ar<<2)>>2]|0;a[ae+18|0]=at&255;a[ae+19|0]=at>>>8&255;a[ae+20|0]=at>>>16&255}at=as>>>4&15;if((at|0)!=0){ar=c[(c[2440392]|0)+(at<<2)>>2]|0;a[ae+21|0]=ar&255;a[ae+22|0]=ar>>>8&255;a[ae+23|0]=ar>>>16&255}ar=as>>>8&15;if((ar|0)!=0){at=c[(c[2440392]|0)+(ar<<2)>>2]|0;a[ae+24|0]=at&255;a[ae+25|0]=at>>>8&255;a[ae+26|0]=at>>>16&255}at=as>>>16&15;if((at|0)!=0){ar=c[(c[2440392]|0)+(at<<2)>>2]|0;a[ae+27|0]=ar&255;a[ae+28|0]=ar>>>8&255;a[ae+29|0]=ar>>>16&255}ar=as>>>24&15;if((ar|0)!=0){at=c[(c[2440392]|0)+(ar<<2)>>2]|0;a[ae+30|0]=at&255;a[ae+31|0]=at>>>8&255;a[ae+32|0]=at>>>16&255}at=as>>>28;if((at|0)==0){break}as=c[(c[2440392]|0)+(at<<2)>>2]|0;a[ae+33|0]=as&255;a[ae+34|0]=as>>>8&255;a[ae+35|0]=as>>>16&255;break}else{if(!aq){aq=c[(c[2440392]|0)+(ap<<2)>>2]|0;a[ae+33|0]=aq&255;a[ae+34|0]=aq>>>8&255;a[ae+35|0]=aq>>>16&255}aq=an>>>8&15;if((aq|0)!=0){ap=c[(c[2440392]|0)+(aq<<2)>>2]|0;a[ae+30|0]=ap&255;a[ae+31|0]=ap>>>8&255;a[ae+32|0]=ap>>>16&255}ap=an>>>12&15;if((ap|0)!=0){aq=c[(c[2440392]|0)+(ap<<2)>>2]|0;a[ae+27|0]=aq&255;a[ae+28|0]=aq>>>8&255;a[ae+29|0]=aq>>>16&255}aq=an>>>16&15;if((aq|0)!=0){ap=c[(c[2440392]|0)+(aq<<2)>>2]|0;a[ae+24|0]=ap&255;a[ae+25|0]=ap>>>8&255;a[ae+26|0]=ap>>>16&255}ap=an>>>24&15;if((ap|0)!=0){aq=c[(c[2440392]|0)+(ap<<2)>>2]|0;a[ae+21|0]=aq&255;a[ae+22|0]=aq>>>8&255;a[ae+23|0]=aq>>>16&255}aq=an>>>28;if((aq|0)!=0){an=c[(c[2440392]|0)+(aq<<2)>>2]|0;a[ae+18|0]=an&255;a[ae+19|0]=an>>>8&255;a[ae+20|0]=an>>>16&255}an=c[ah+((al|1)<<2)>>2]|0;al=an&15;if((al|0)!=0){ah=c[(c[2440392]|0)+(al<<2)>>2]|0;a[ae+15|0]=ah&255;a[ae+16|0]=ah>>>8&255;a[ae+17|0]=ah>>>16&255}ah=an>>>4&15;if((ah|0)!=0){al=c[(c[2440392]|0)+(ah<<2)>>2]|0;a[ae+12|0]=al&255;a[ae+13|0]=al>>>8&255;a[ae+14|0]=al>>>16&255}al=an>>>8&15;if((al|0)!=0){ah=c[(c[2440392]|0)+(al<<2)>>2]|0;a[ae+9|0]=ah&255;a[ae+10|0]=ah>>>8&255;a[ae+11|0]=ah>>>16&255}ah=an>>>16&15;if((ah|0)!=0){al=c[(c[2440392]|0)+(ah<<2)>>2]|0;a[ae+6|0]=al&255;a[ae+7|0]=al>>>8&255;a[ae+8|0]=al>>>16&255}al=an>>>24&15;if((al|0)!=0){ah=c[(c[2440392]|0)+(al<<2)>>2]|0;a[ae+3|0]=ah&255;a[ae+4|0]=ah>>>8&255;a[ae+5|0]=ah>>>16&255}ah=an>>>28;if((ah|0)==0){break}an=c[(c[2440392]|0)+(ah<<2)>>2]|0;a[ae]=an&255;a[ae+1|0]=an>>>8&255;a[ae+2|0]=an>>>16&255;break}}}while(0);af=I+1|0;if((af|0)>(H|0)){ac=aj;ad=ai;break}else{I=af;F=ak;D=aj;N=ai;ae=ae+s|0}}}if((ab|0)>(i|0)){U=35708;break}else{A=ab;B=ac;C=ad}}if((U|0)==35708){return}else if((U|0)==35709){return}}function cze(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0;b=c[3540994]|0;f=c[3528548]|0;g=f<<8;h=c[2385554]|0;do{if((h|0)>31){i=511}else{j=(h<<4)-1|0;if((j|0)>=0){i=j;break}return}}while(0);j=(i|0)>255;k=i&255;l=c[2385550]|0;m=c[2113042]|0;n=c[2113044]|0;o=m+512|0;p=c[2113132]|0;q=(c[2385552]|0)*3|0;r=c[2112968]|0;s=p*3|0;t=c[2415160]|0;u=c[2429858]|0;v=c[2430428]|0;w=c[2429718]|0;x=c[2430092]|0;y=c[3541046]|0;z=c[2430426]|0;A=0;B=0;C=0;L40962:while(1){D=(h|0)>16&(f|0)!=255;E=(h|0)<33;F=511-f|0;G=f+1|0;H=f-255|0;I=~f;J=A;L40964:while(1){K=J+l|0;L=K&511;do{if((L|0)<(m|0)){M=J+m-L|0}else{if((L|0)>=(n|0)){M=o+J-L|0;break}N=(J|0)>255;O=N?16:0;P=J&255;Q=(J|0)<256&j?255:k;if(!D){R=O;S=P;T=Q;U=35733;break L40964}if(E){if(!N){U=35723;break L40964}if((J|0)<(F|0)){M=F;break}else{U=35725;break L40964}}if(N){V=H+P|0;if((V|0)>=0){U=35728;break L40964}N=G+V|0;if((N|0)<0){M=512;break}else{R=0;S=N;T=f;U=35733;break L40964}}else{if((P|0)<=(f|0)){U=35731;break L40964}N=P+I|0;if((N|0)>(f|0)){M=256;break}else{R=16;S=N;T=f;U=35733;break L40964}}}}while(0);if((M|0)>(i|0)){U=35801;break L40962}else{J=M}}if((U|0)==35728){U=0;W=f;X=V;Y=O;Z=G+J-V|0}else if((U|0)==35731){U=0;W=f;X=P;Y=O;Z=G+J-P|0}else if((U|0)==35723){U=0;_=Q;$=P;aa=O;ab=J+1-P+Q|0;U=35734}else if((U|0)==35725){U=0;I=255-f|0;R=O;S=P-I|0;T=Q-I|0;U=35733}if((U|0)==35733){U=0;I=J+1+T-S|0;if(E){_=T;$=S;aa=R;ab=I;U=35734}else{W=T;X=S;Y=R;Z=I}}if((U|0)==35734){U=0;W=(_|0)>(f|0)?f:_;X=$;Y=aa;Z=ab}I=((K|-512)^511)+n|0;H=(W-X|0)>(I|0)?I+X|0:W;if((X|0)>(H|0)){ac=B;ad=C}else{I=X;F=-1;D=B;N=C;ae=r+((ag(p,(L*3|0)-48|0)|0)+q)|0;while(1){af=d[b+(I+g)|0]|0;ah=(af>>>4)+Y|0;do{if((ah|0)==(F|0)){ai=N;aj=D;ak=F}else{al=ah<<1;am=e[t+((al|1)<<1)>>1]|0;an=(am<<12&983040|(e[t+(al<<1)>>1]|0))&u;do{if((am&8|0)==0){if((am&4|0)==0){ao=an;break}ao=v|an&1048572}else{ao=z|an&1048568}}while(0);an=a[w+ao|0]|0;al=an&255;if(an<<24>>24!=0){ai=al;aj=am;ak=ah;break}c[2385344]=x+(ao<<7);c[2440392]=y+((am>>>4&4080)<<2);ai=al;aj=am;ak=ah}}while(0);do{if((ai|0)==0){ah=af<<1&30;al=(aj&2|0)==0?ah:ah^30;ah=c[2385344]|0;an=c[ah+(al<<2)>>2]|0;ap=an&15;aq=(ap|0)==0;if((aj&1|0)==0){if(!aq){ar=c[(c[2440392]|0)+(ap<<2)>>2]|0;a[ae]=ar&255;a[ae+1|0]=ar>>>8&255;a[ae+2|0]=ar>>>16&255}ar=an>>>8&15;if((ar|0)!=0){as=c[(c[2440392]|0)+(ar<<2)>>2]|0;a[ae+3|0]=as&255;a[ae+4|0]=as>>>8&255;a[ae+5|0]=as>>>16&255}as=an>>>12&15;if((as|0)!=0){ar=c[(c[2440392]|0)+(as<<2)>>2]|0;a[ae+6|0]=ar&255;a[ae+7|0]=ar>>>8&255;a[ae+8|0]=ar>>>16&255}ar=an>>>16&15;if((ar|0)!=0){as=c[(c[2440392]|0)+(ar<<2)>>2]|0;a[ae+9|0]=as&255;a[ae+10|0]=as>>>8&255;a[ae+11|0]=as>>>16&255}as=an>>>24&15;if((as|0)!=0){ar=c[(c[2440392]|0)+(as<<2)>>2]|0;a[ae+12|0]=ar&255;a[ae+13|0]=ar>>>8&255;a[ae+14|0]=ar>>>16&255}ar=an>>>28;if((ar|0)!=0){as=c[(c[2440392]|0)+(ar<<2)>>2]|0;a[ae+15|0]=as&255;a[ae+16|0]=as>>>8&255;a[ae+17|0]=as>>>16&255}as=c[ah+((al|1)<<2)>>2]|0;ar=as&15;if((ar|0)!=0){at=c[(c[2440392]|0)+(ar<<2)>>2]|0;a[ae+18|0]=at&255;a[ae+19|0]=at>>>8&255;a[ae+20|0]=at>>>16&255}at=as>>>4&15;if((at|0)!=0){ar=c[(c[2440392]|0)+(at<<2)>>2]|0;a[ae+21|0]=ar&255;a[ae+22|0]=ar>>>8&255;a[ae+23|0]=ar>>>16&255}ar=as>>>8&15;if((ar|0)!=0){at=c[(c[2440392]|0)+(ar<<2)>>2]|0;a[ae+24|0]=at&255;a[ae+25|0]=at>>>8&255;a[ae+26|0]=at>>>16&255}at=as>>>16&15;if((at|0)!=0){ar=c[(c[2440392]|0)+(at<<2)>>2]|0;a[ae+27|0]=ar&255;a[ae+28|0]=ar>>>8&255;a[ae+29|0]=ar>>>16&255}ar=as>>>20&15;if((ar|0)!=0){at=c[(c[2440392]|0)+(ar<<2)>>2]|0;a[ae+30|0]=at&255;a[ae+31|0]=at>>>8&255;a[ae+32|0]=at>>>16&255}at=as>>>24&15;if((at|0)!=0){ar=c[(c[2440392]|0)+(at<<2)>>2]|0;a[ae+33|0]=ar&255;a[ae+34|0]=ar>>>8&255;a[ae+35|0]=ar>>>16&255}ar=as>>>28;if((ar|0)==0){break}as=c[(c[2440392]|0)+(ar<<2)>>2]|0;a[ae+36|0]=as&255;a[ae+37|0]=as>>>8&255;a[ae+38|0]=as>>>16&255;break}else{if(!aq){aq=c[(c[2440392]|0)+(ap<<2)>>2]|0;a[ae+36|0]=aq&255;a[ae+37|0]=aq>>>8&255;a[ae+38|0]=aq>>>16&255}aq=an>>>8&15;if((aq|0)!=0){ap=c[(c[2440392]|0)+(aq<<2)>>2]|0;a[ae+33|0]=ap&255;a[ae+34|0]=ap>>>8&255;a[ae+35|0]=ap>>>16&255}ap=an>>>12&15;if((ap|0)!=0){aq=c[(c[2440392]|0)+(ap<<2)>>2]|0;a[ae+30|0]=aq&255;a[ae+31|0]=aq>>>8&255;a[ae+32|0]=aq>>>16&255}aq=an>>>16&15;if((aq|0)!=0){ap=c[(c[2440392]|0)+(aq<<2)>>2]|0;a[ae+27|0]=ap&255;a[ae+28|0]=ap>>>8&255;a[ae+29|0]=ap>>>16&255}ap=an>>>24&15;if((ap|0)!=0){aq=c[(c[2440392]|0)+(ap<<2)>>2]|0;a[ae+24|0]=aq&255;a[ae+25|0]=aq>>>8&255;a[ae+26|0]=aq>>>16&255}aq=an>>>28;if((aq|0)!=0){an=c[(c[2440392]|0)+(aq<<2)>>2]|0;a[ae+21|0]=an&255;a[ae+22|0]=an>>>8&255;a[ae+23|0]=an>>>16&255}an=c[ah+((al|1)<<2)>>2]|0;al=an&15;if((al|0)!=0){ah=c[(c[2440392]|0)+(al<<2)>>2]|0;a[ae+18|0]=ah&255;a[ae+19|0]=ah>>>8&255;a[ae+20|0]=ah>>>16&255}ah=an>>>4&15;if((ah|0)!=0){al=c[(c[2440392]|0)+(ah<<2)>>2]|0;a[ae+15|0]=al&255;a[ae+16|0]=al>>>8&255;a[ae+17|0]=al>>>16&255}al=an>>>8&15;if((al|0)!=0){ah=c[(c[2440392]|0)+(al<<2)>>2]|0;a[ae+12|0]=ah&255;a[ae+13|0]=ah>>>8&255;a[ae+14|0]=ah>>>16&255}ah=an>>>16&15;if((ah|0)!=0){al=c[(c[2440392]|0)+(ah<<2)>>2]|0;a[ae+9|0]=al&255;a[ae+10|0]=al>>>8&255;a[ae+11|0]=al>>>16&255}al=an>>>20&15;if((al|0)!=0){ah=c[(c[2440392]|0)+(al<<2)>>2]|0;a[ae+6|0]=ah&255;a[ae+7|0]=ah>>>8&255;a[ae+8|0]=ah>>>16&255}ah=an>>>24&15;if((ah|0)!=0){al=c[(c[2440392]|0)+(ah<<2)>>2]|0;a[ae+3|0]=al&255;a[ae+4|0]=al>>>8&255;a[ae+5|0]=al>>>16&255}al=an>>>28;if((al|0)==0){break}an=c[(c[2440392]|0)+(al<<2)>>2]|0;a[ae]=an&255;a[ae+1|0]=an>>>8&255;a[ae+2|0]=an>>>16&255;break}}}while(0);af=I+1|0;if((af|0)>(H|0)){ac=aj;ad=ai;break}else{I=af;F=ak;D=aj;N=ai;ae=ae+s|0}}}if((Z|0)>(i|0)){U=35800;break}else{A=Z;B=ac;C=ad}}if((U|0)==35800){return}else if((U|0)==35801){return}}function czf(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0;b=c[3540994]|0;f=c[3528548]|0;g=f<<8;h=c[2385554]|0;do{if((h|0)>31){i=511}else{j=(h<<4)-1|0;if((j|0)>=0){i=j;break}return}}while(0);j=(i|0)>255;k=i&255;l=c[2385550]|0;m=c[2113042]|0;n=c[2113044]|0;o=m+512|0;p=c[2113132]|0;q=(c[2385552]|0)*3|0;r=c[2112968]|0;s=p*3|0;t=c[2415160]|0;u=c[2429858]|0;v=c[2430428]|0;w=c[2429718]|0;x=c[2430092]|0;y=c[3541046]|0;z=c[2430426]|0;A=0;B=0;C=0;L41095:while(1){D=(h|0)>16&(f|0)!=255;E=(h|0)<33;F=511-f|0;G=f+1|0;H=f-255|0;I=~f;J=A;L41097:while(1){K=J+l|0;L=K&511;do{if((L|0)<(m|0)){M=J+m-L|0}else{if((L|0)>=(n|0)){M=o+J-L|0;break}N=(J|0)>255;O=N?16:0;P=J&255;Q=(J|0)<256&j?255:k;if(!D){R=O;S=P;T=Q;U=35826;break L41097}if(E){if(!N){U=35816;break L41097}if((J|0)<(F|0)){M=F;break}else{U=35818;break L41097}}if(N){V=H+P|0;if((V|0)>=0){U=35821;break L41097}N=G+V|0;if((N|0)<0){M=512;break}else{R=0;S=N;T=f;U=35826;break L41097}}else{if((P|0)<=(f|0)){U=35824;break L41097}N=P+I|0;if((N|0)>(f|0)){M=256;break}else{R=16;S=N;T=f;U=35826;break L41097}}}}while(0);if((M|0)>(i|0)){U=35898;break L41095}else{J=M}}if((U|0)==35816){U=0;W=Q;X=P;Y=O;Z=J+1-P+Q|0;U=35827}else if((U|0)==35821){U=0;_=f;$=V;aa=O;ab=G+J-V|0}else if((U|0)==35824){U=0;_=f;$=P;aa=O;ab=G+J-P|0}else if((U|0)==35818){U=0;I=255-f|0;R=O;S=P-I|0;T=Q-I|0;U=35826}if((U|0)==35826){U=0;I=J+1+T-S|0;if(E){W=T;X=S;Y=R;Z=I;U=35827}else{_=T;$=S;aa=R;ab=I}}if((U|0)==35827){U=0;_=(W|0)>(f|0)?f:W;$=X;aa=Y;ab=Z}I=((K|-512)^511)+n|0;H=(_-$|0)>(I|0)?I+$|0:_;if(($|0)>(H|0)){ac=B;ad=C}else{I=$;F=-1;D=B;N=C;ae=r+((ag(p,(L*3|0)-48|0)|0)+q)|0;while(1){af=d[b+(I+g)|0]|0;ah=(af>>>4)+aa|0;do{if((ah|0)==(F|0)){ai=N;aj=D;ak=F}else{al=ah<<1;am=e[t+((al|1)<<1)>>1]|0;an=(am<<12&983040|(e[t+(al<<1)>>1]|0))&u;do{if((am&8|0)==0){if((am&4|0)==0){ao=an;break}ao=v|an&1048572}else{ao=z|an&1048568}}while(0);an=a[w+ao|0]|0;al=an&255;if(an<<24>>24!=0){ai=al;aj=am;ak=ah;break}c[2385344]=x+(ao<<7);c[2440392]=y+((am>>>4&4080)<<2);ai=al;aj=am;ak=ah}}while(0);do{if((ai|0)==0){ah=af<<1&30;al=(aj&2|0)==0?ah:ah^30;ah=c[2385344]|0;an=c[ah+(al<<2)>>2]|0;ap=an&15;aq=(ap|0)==0;if((aj&1|0)==0){if(!aq){ar=c[(c[2440392]|0)+(ap<<2)>>2]|0;a[ae]=ar&255;a[ae+1|0]=ar>>>8&255;a[ae+2|0]=ar>>>16&255}ar=an>>>4&15;if((ar|0)!=0){as=c[(c[2440392]|0)+(ar<<2)>>2]|0;a[ae+3|0]=as&255;a[ae+4|0]=as>>>8&255;a[ae+5|0]=as>>>16&255}as=an>>>8&15;if((as|0)!=0){ar=c[(c[2440392]|0)+(as<<2)>>2]|0;a[ae+6|0]=ar&255;a[ae+7|0]=ar>>>8&255;a[ae+8|0]=ar>>>16&255}ar=an>>>12&15;if((ar|0)!=0){as=c[(c[2440392]|0)+(ar<<2)>>2]|0;a[ae+9|0]=as&255;a[ae+10|0]=as>>>8&255;a[ae+11|0]=as>>>16&255}as=an>>>16&15;if((as|0)!=0){ar=c[(c[2440392]|0)+(as<<2)>>2]|0;a[ae+12|0]=ar&255;a[ae+13|0]=ar>>>8&255;a[ae+14|0]=ar>>>16&255}ar=an>>>24&15;if((ar|0)!=0){as=c[(c[2440392]|0)+(ar<<2)>>2]|0;a[ae+15|0]=as&255;a[ae+16|0]=as>>>8&255;a[ae+17|0]=as>>>16&255}as=an>>>28;if((as|0)!=0){ar=c[(c[2440392]|0)+(as<<2)>>2]|0;a[ae+18|0]=ar&255;a[ae+19|0]=ar>>>8&255;a[ae+20|0]=ar>>>16&255}ar=c[ah+((al|1)<<2)>>2]|0;as=ar&15;if((as|0)!=0){at=c[(c[2440392]|0)+(as<<2)>>2]|0;a[ae+21|0]=at&255;a[ae+22|0]=at>>>8&255;a[ae+23|0]=at>>>16&255}at=ar>>>4&15;if((at|0)!=0){as=c[(c[2440392]|0)+(at<<2)>>2]|0;a[ae+24|0]=as&255;a[ae+25|0]=as>>>8&255;a[ae+26|0]=as>>>16&255}as=ar>>>8&15;if((as|0)!=0){at=c[(c[2440392]|0)+(as<<2)>>2]|0;a[ae+27|0]=at&255;a[ae+28|0]=at>>>8&255;a[ae+29|0]=at>>>16&255}at=ar>>>16&15;if((at|0)!=0){as=c[(c[2440392]|0)+(at<<2)>>2]|0;a[ae+30|0]=as&255;a[ae+31|0]=as>>>8&255;a[ae+32|0]=as>>>16&255}as=ar>>>20&15;if((as|0)!=0){at=c[(c[2440392]|0)+(as<<2)>>2]|0;a[ae+33|0]=at&255;a[ae+34|0]=at>>>8&255;a[ae+35|0]=at>>>16&255}at=ar>>>24&15;if((at|0)!=0){as=c[(c[2440392]|0)+(at<<2)>>2]|0;a[ae+36|0]=as&255;a[ae+37|0]=as>>>8&255;a[ae+38|0]=as>>>16&255}as=ar>>>28;if((as|0)==0){break}ar=c[(c[2440392]|0)+(as<<2)>>2]|0;a[ae+39|0]=ar&255;a[ae+40|0]=ar>>>8&255;a[ae+41|0]=ar>>>16&255;break}else{if(!aq){aq=c[(c[2440392]|0)+(ap<<2)>>2]|0;a[ae+39|0]=aq&255;a[ae+40|0]=aq>>>8&255;a[ae+41|0]=aq>>>16&255}aq=an>>>4&15;if((aq|0)!=0){ap=c[(c[2440392]|0)+(aq<<2)>>2]|0;a[ae+36|0]=ap&255;a[ae+37|0]=ap>>>8&255;a[ae+38|0]=ap>>>16&255}ap=an>>>8&15;if((ap|0)!=0){aq=c[(c[2440392]|0)+(ap<<2)>>2]|0;a[ae+33|0]=aq&255;a[ae+34|0]=aq>>>8&255;a[ae+35|0]=aq>>>16&255}aq=an>>>12&15;if((aq|0)!=0){ap=c[(c[2440392]|0)+(aq<<2)>>2]|0;a[ae+30|0]=ap&255;a[ae+31|0]=ap>>>8&255;a[ae+32|0]=ap>>>16&255}ap=an>>>16&15;if((ap|0)!=0){aq=c[(c[2440392]|0)+(ap<<2)>>2]|0;a[ae+27|0]=aq&255;a[ae+28|0]=aq>>>8&255;a[ae+29|0]=aq>>>16&255}aq=an>>>24&15;if((aq|0)!=0){ap=c[(c[2440392]|0)+(aq<<2)>>2]|0;a[ae+24|0]=ap&255;a[ae+25|0]=ap>>>8&255;a[ae+26|0]=ap>>>16&255}ap=an>>>28;if((ap|0)!=0){an=c[(c[2440392]|0)+(ap<<2)>>2]|0;a[ae+21|0]=an&255;a[ae+22|0]=an>>>8&255;a[ae+23|0]=an>>>16&255}an=c[ah+((al|1)<<2)>>2]|0;al=an&15;if((al|0)!=0){ah=c[(c[2440392]|0)+(al<<2)>>2]|0;a[ae+18|0]=ah&255;a[ae+19|0]=ah>>>8&255;a[ae+20|0]=ah>>>16&255}ah=an>>>4&15;if((ah|0)!=0){al=c[(c[2440392]|0)+(ah<<2)>>2]|0;a[ae+15|0]=al&255;a[ae+16|0]=al>>>8&255;a[ae+17|0]=al>>>16&255}al=an>>>8&15;if((al|0)!=0){ah=c[(c[2440392]|0)+(al<<2)>>2]|0;a[ae+12|0]=ah&255;a[ae+13|0]=ah>>>8&255;a[ae+14|0]=ah>>>16&255}ah=an>>>16&15;if((ah|0)!=0){al=c[(c[2440392]|0)+(ah<<2)>>2]|0;a[ae+9|0]=al&255;a[ae+10|0]=al>>>8&255;a[ae+11|0]=al>>>16&255}al=an>>>20&15;if((al|0)!=0){ah=c[(c[2440392]|0)+(al<<2)>>2]|0;a[ae+6|0]=ah&255;a[ae+7|0]=ah>>>8&255;a[ae+8|0]=ah>>>16&255}ah=an>>>24&15;if((ah|0)!=0){al=c[(c[2440392]|0)+(ah<<2)>>2]|0;a[ae+3|0]=al&255;a[ae+4|0]=al>>>8&255;a[ae+5|0]=al>>>16&255}al=an>>>28;if((al|0)==0){break}an=c[(c[2440392]|0)+(al<<2)>>2]|0;a[ae]=an&255;a[ae+1|0]=an>>>8&255;a[ae+2|0]=an>>>16&255;break}}}while(0);af=I+1|0;if((af|0)>(H|0)){ac=aj;ad=ai;break}else{I=af;F=ak;D=aj;N=ai;ae=ae+s|0}}}if((ab|0)>(i|0)){U=35897;break}else{A=ab;B=ac;C=ad}}if((U|0)==35897){return}else if((U|0)==35898){return}}function czg(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0;b=c[3540994]|0;f=c[3528548]|0;g=f<<8;h=c[2385554]|0;do{if((h|0)>31){i=511}else{j=(h<<4)-1|0;if((j|0)>=0){i=j;break}return}}while(0);j=(i|0)>255;k=i&255;l=c[2385550]|0;m=c[2113042]|0;n=c[2113044]|0;o=m+512|0;p=c[2113132]|0;q=(c[2385552]|0)*3|0;r=c[2112968]|0;s=p*3|0;t=c[2415160]|0;u=c[2429858]|0;v=c[2430428]|0;w=c[2429718]|0;x=c[2430092]|0;y=c[3541046]|0;z=c[2430426]|0;A=0;B=0;C=0;L41234:while(1){D=(h|0)>16&(f|0)!=255;E=(h|0)<33;F=511-f|0;G=f+1|0;H=f-255|0;I=~f;J=A;L41236:while(1){K=J+l|0;L=K&511;do{if((L|0)<(m|0)){M=J+m-L|0}else{if((L|0)>=(n|0)){M=o+J-L|0;break}N=(J|0)>255;O=N?16:0;P=J&255;Q=(J|0)<256&j?255:k;if(!D){R=O;S=P;T=Q;U=35923;break L41236}if(E){if(!N){U=35913;break L41236}if((J|0)<(F|0)){M=F;break}else{U=35915;break L41236}}if(N){V=H+P|0;if((V|0)>=0){U=35918;break L41236}N=G+V|0;if((N|0)<0){M=512;break}else{R=0;S=N;T=f;U=35923;break L41236}}else{if((P|0)<=(f|0)){U=35921;break L41236}N=P+I|0;if((N|0)>(f|0)){M=256;break}else{R=16;S=N;T=f;U=35923;break L41236}}}}while(0);if((M|0)>(i|0)){U=36e3;break L41234}else{J=M}}if((U|0)==35913){U=0;W=Q;X=P;Y=O;Z=J+1-P+Q|0;U=35924}else if((U|0)==35921){U=0;_=f;$=P;aa=O;ab=G+J-P|0}else if((U|0)==35918){U=0;_=f;$=V;aa=O;ab=G+J-V|0}else if((U|0)==35915){U=0;I=255-f|0;R=O;S=P-I|0;T=Q-I|0;U=35923}if((U|0)==35923){U=0;I=J+1+T-S|0;if(E){W=T;X=S;Y=R;Z=I;U=35924}else{_=T;$=S;aa=R;ab=I}}if((U|0)==35924){U=0;_=(W|0)>(f|0)?f:W;$=X;aa=Y;ab=Z}I=((K|-512)^511)+n|0;H=(_-$|0)>(I|0)?I+$|0:_;if(($|0)>(H|0)){ac=B;ad=C}else{I=$;F=-1;D=B;N=C;ae=r+((ag(p,(L*3|0)-48|0)|0)+q)|0;while(1){af=d[b+(I+g)|0]|0;ah=(af>>>4)+aa|0;do{if((ah|0)==(F|0)){ai=N;aj=D;ak=F}else{al=ah<<1;am=e[t+((al|1)<<1)>>1]|0;an=(am<<12&983040|(e[t+(al<<1)>>1]|0))&u;do{if((am&8|0)==0){if((am&4|0)==0){ao=an;break}ao=v|an&1048572}else{ao=z|an&1048568}}while(0);an=a[w+ao|0]|0;al=an&255;if(an<<24>>24!=0){ai=al;aj=am;ak=ah;break}c[2385344]=x+(ao<<7);c[2440392]=y+((am>>>4&4080)<<2);ai=al;aj=am;ak=ah}}while(0);do{if((ai|0)==0){ah=af<<1&30;al=(aj&2|0)==0?ah:ah^30;ah=c[2385344]|0;an=c[ah+(al<<2)>>2]|0;ap=an&15;aq=(ap|0)==0;if((aj&1|0)==0){if(!aq){ar=c[(c[2440392]|0)+(ap<<2)>>2]|0;a[ae]=ar&255;a[ae+1|0]=ar>>>8&255;a[ae+2|0]=ar>>>16&255}ar=an>>>4&15;if((ar|0)!=0){as=c[(c[2440392]|0)+(ar<<2)>>2]|0;a[ae+3|0]=as&255;a[ae+4|0]=as>>>8&255;a[ae+5|0]=as>>>16&255}as=an>>>8&15;if((as|0)!=0){ar=c[(c[2440392]|0)+(as<<2)>>2]|0;a[ae+6|0]=ar&255;a[ae+7|0]=ar>>>8&255;a[ae+8|0]=ar>>>16&255}ar=an>>>12&15;if((ar|0)!=0){as=c[(c[2440392]|0)+(ar<<2)>>2]|0;a[ae+9|0]=as&255;a[ae+10|0]=as>>>8&255;a[ae+11|0]=as>>>16&255}as=an>>>16&15;if((as|0)!=0){ar=c[(c[2440392]|0)+(as<<2)>>2]|0;a[ae+12|0]=ar&255;a[ae+13|0]=ar>>>8&255;a[ae+14|0]=ar>>>16&255}ar=an>>>24&15;if((ar|0)!=0){as=c[(c[2440392]|0)+(ar<<2)>>2]|0;a[ae+15|0]=as&255;a[ae+16|0]=as>>>8&255;a[ae+17|0]=as>>>16&255}as=an>>>28;if((as|0)!=0){ar=c[(c[2440392]|0)+(as<<2)>>2]|0;a[ae+18|0]=ar&255;a[ae+19|0]=ar>>>8&255;a[ae+20|0]=ar>>>16&255}ar=c[ah+((al|1)<<2)>>2]|0;as=ar&15;if((as|0)!=0){at=c[(c[2440392]|0)+(as<<2)>>2]|0;a[ae+21|0]=at&255;a[ae+22|0]=at>>>8&255;a[ae+23|0]=at>>>16&255}at=ar>>>4&15;if((at|0)!=0){as=c[(c[2440392]|0)+(at<<2)>>2]|0;a[ae+24|0]=as&255;a[ae+25|0]=as>>>8&255;a[ae+26|0]=as>>>16&255}as=ar>>>8&15;if((as|0)!=0){at=c[(c[2440392]|0)+(as<<2)>>2]|0;a[ae+27|0]=at&255;a[ae+28|0]=at>>>8&255;a[ae+29|0]=at>>>16&255}at=ar>>>12&15;if((at|0)!=0){as=c[(c[2440392]|0)+(at<<2)>>2]|0;a[ae+30|0]=as&255;a[ae+31|0]=as>>>8&255;a[ae+32|0]=as>>>16&255}as=ar>>>16&15;if((as|0)!=0){at=c[(c[2440392]|0)+(as<<2)>>2]|0;a[ae+33|0]=at&255;a[ae+34|0]=at>>>8&255;a[ae+35|0]=at>>>16&255}at=ar>>>20&15;if((at|0)!=0){as=c[(c[2440392]|0)+(at<<2)>>2]|0;a[ae+36|0]=as&255;a[ae+37|0]=as>>>8&255;a[ae+38|0]=as>>>16&255}as=ar>>>24&15;if((as|0)!=0){at=c[(c[2440392]|0)+(as<<2)>>2]|0;a[ae+39|0]=at&255;a[ae+40|0]=at>>>8&255;a[ae+41|0]=at>>>16&255}at=ar>>>28;if((at|0)==0){break}ar=c[(c[2440392]|0)+(at<<2)>>2]|0;a[ae+42|0]=ar&255;a[ae+43|0]=ar>>>8&255;a[ae+44|0]=ar>>>16&255;break}else{if(!aq){aq=c[(c[2440392]|0)+(ap<<2)>>2]|0;a[ae+42|0]=aq&255;a[ae+43|0]=aq>>>8&255;a[ae+44|0]=aq>>>16&255}aq=an>>>4&15;if((aq|0)!=0){ap=c[(c[2440392]|0)+(aq<<2)>>2]|0;a[ae+39|0]=ap&255;a[ae+40|0]=ap>>>8&255;a[ae+41|0]=ap>>>16&255}ap=an>>>8&15;if((ap|0)!=0){aq=c[(c[2440392]|0)+(ap<<2)>>2]|0;a[ae+36|0]=aq&255;a[ae+37|0]=aq>>>8&255;a[ae+38|0]=aq>>>16&255}aq=an>>>12&15;if((aq|0)!=0){ap=c[(c[2440392]|0)+(aq<<2)>>2]|0;a[ae+33|0]=ap&255;a[ae+34|0]=ap>>>8&255;a[ae+35|0]=ap>>>16&255}ap=an>>>16&15;if((ap|0)!=0){aq=c[(c[2440392]|0)+(ap<<2)>>2]|0;a[ae+30|0]=aq&255;a[ae+31|0]=aq>>>8&255;a[ae+32|0]=aq>>>16&255}aq=an>>>24&15;if((aq|0)!=0){ap=c[(c[2440392]|0)+(aq<<2)>>2]|0;a[ae+27|0]=ap&255;a[ae+28|0]=ap>>>8&255;a[ae+29|0]=ap>>>16&255}ap=an>>>28;if((ap|0)!=0){an=c[(c[2440392]|0)+(ap<<2)>>2]|0;a[ae+24|0]=an&255;a[ae+25|0]=an>>>8&255;a[ae+26|0]=an>>>16&255}an=c[ah+((al|1)<<2)>>2]|0;al=an&15;if((al|0)!=0){ah=c[(c[2440392]|0)+(al<<2)>>2]|0;a[ae+21|0]=ah&255;a[ae+22|0]=ah>>>8&255;a[ae+23|0]=ah>>>16&255}ah=an>>>4&15;if((ah|0)!=0){al=c[(c[2440392]|0)+(ah<<2)>>2]|0;a[ae+18|0]=al&255;a[ae+19|0]=al>>>8&255;a[ae+20|0]=al>>>16&255}al=an>>>8&15;if((al|0)!=0){ah=c[(c[2440392]|0)+(al<<2)>>2]|0;a[ae+15|0]=ah&255;a[ae+16|0]=ah>>>8&255;a[ae+17|0]=ah>>>16&255}ah=an>>>12&15;if((ah|0)!=0){al=c[(c[2440392]|0)+(ah<<2)>>2]|0;a[ae+12|0]=al&255;a[ae+13|0]=al>>>8&255;a[ae+14|0]=al>>>16&255}al=an>>>16&15;if((al|0)!=0){ah=c[(c[2440392]|0)+(al<<2)>>2]|0;a[ae+9|0]=ah&255;a[ae+10|0]=ah>>>8&255;a[ae+11|0]=ah>>>16&255}ah=an>>>20&15;if((ah|0)!=0){al=c[(c[2440392]|0)+(ah<<2)>>2]|0;a[ae+6|0]=al&255;a[ae+7|0]=al>>>8&255;a[ae+8|0]=al>>>16&255}al=an>>>24&15;if((al|0)!=0){ah=c[(c[2440392]|0)+(al<<2)>>2]|0;a[ae+3|0]=ah&255;a[ae+4|0]=ah>>>8&255;a[ae+5|0]=ah>>>16&255}ah=an>>>28;if((ah|0)==0){break}an=c[(c[2440392]|0)+(ah<<2)>>2]|0;a[ae]=an&255;a[ae+1|0]=an>>>8&255;a[ae+2|0]=an>>>16&255;break}}}while(0);af=I+1|0;if((af|0)>(H|0)){ac=aj;ad=ai;break}else{I=af;F=ak;D=aj;N=ai;ae=ae+s|0}}}if((ab|0)>(i|0)){U=35998;break}else{A=ab;B=ac;C=ad}}if((U|0)==35998){return}else if((U|0)==36e3){return}}function czh(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0;b=c[3540994]|0;f=c[3528548]|0;g=f<<8;h=c[2385554]|0;do{if((h|0)>31){i=511}else{j=(h<<4)-1|0;if((j|0)>=0){i=j;break}return}}while(0);j=(i|0)>255;k=i&255;l=c[2385550]|0;m=c[2113042]|0;n=c[2113044]|0;o=m+512|0;p=c[2113132]|0;q=(c[2385552]|0)*3|0;r=c[2112968]|0;s=p*3|0;t=c[2415160]|0;u=c[2429858]|0;v=c[2430428]|0;w=c[2429718]|0;x=c[2430092]|0;y=c[3541046]|0;z=c[2430426]|0;A=0;B=0;C=0;L41379:while(1){D=(h|0)>16&(f|0)!=255;E=(h|0)<33;F=511-f|0;G=f+1|0;H=f-255|0;I=~f;J=A;L41381:while(1){K=J+l|0;L=K&511;do{if((L|0)<(m|0)){M=J+m-L|0}else{if((L|0)>=(n|0)){M=o+J-L|0;break}N=(J|0)>255;O=N?16:0;P=J&255;Q=(J|0)<256&j?255:k;if(!D){R=O;S=P;T=Q;U=36024;break L41381}if(E){if(!N){U=36014;break L41381}if((J|0)<(F|0)){M=F;break}else{U=36016;break L41381}}if(N){V=H+P|0;if((V|0)>=0){U=36019;break L41381}N=G+V|0;if((N|0)<0){M=512;break}else{R=0;S=N;T=f;U=36024;break L41381}}else{if((P|0)<=(f|0)){U=36022;break L41381}N=P+I|0;if((N|0)>(f|0)){M=256;break}else{R=16;S=N;T=f;U=36024;break L41381}}}}while(0);if((M|0)>(i|0)){U=36104;break L41379}else{J=M}}if((U|0)==36014){U=0;W=Q;X=P;Y=O;Z=J+1-P+Q|0;U=36025}else if((U|0)==36019){U=0;_=f;$=V;aa=O;ab=G+J-V|0}else if((U|0)==36022){U=0;_=f;$=P;aa=O;ab=G+J-P|0}else if((U|0)==36016){U=0;I=255-f|0;R=O;S=P-I|0;T=Q-I|0;U=36024}if((U|0)==36024){U=0;I=J+1+T-S|0;if(E){W=T;X=S;Y=R;Z=I;U=36025}else{_=T;$=S;aa=R;ab=I}}if((U|0)==36025){U=0;_=(W|0)>(f|0)?f:W;$=X;aa=Y;ab=Z}I=((K|-512)^511)+n|0;H=(_-$|0)>(I|0)?I+$|0:_;if(($|0)>(H|0)){ac=B;ad=C}else{I=$;F=-1;D=B;N=C;ae=r+((ag(p,(L*3|0)-48|0)|0)+q)|0;while(1){af=d[b+(I+g)|0]|0;ah=(af>>>4)+aa|0;do{if((ah|0)==(F|0)){ai=N;aj=D;ak=F}else{al=ah<<1;am=e[t+((al|1)<<1)>>1]|0;an=(am<<12&983040|(e[t+(al<<1)>>1]|0))&u;do{if((am&8|0)==0){if((am&4|0)==0){ao=an;break}ao=v|an&1048572}else{ao=z|an&1048568}}while(0);an=a[w+ao|0]|0;al=an&255;if(an<<24>>24!=0){ai=al;aj=am;ak=ah;break}c[2385344]=x+(ao<<7);c[2440392]=y+((am>>>4&4080)<<2);ai=al;aj=am;ak=ah}}while(0);do{if((ai|0)==0){ah=af<<1&30;al=(aj&2|0)==0?ah:ah^30;ah=c[2385344]|0;an=c[ah+(al<<2)>>2]|0;ap=an&15;aq=(ap|0)==0;if((aj&1|0)==0){if(!aq){ar=c[(c[2440392]|0)+(ap<<2)>>2]|0;a[ae]=ar&255;a[ae+1|0]=ar>>>8&255;a[ae+2|0]=ar>>>16&255}ar=an>>>4&15;if((ar|0)!=0){as=c[(c[2440392]|0)+(ar<<2)>>2]|0;a[ae+3|0]=as&255;a[ae+4|0]=as>>>8&255;a[ae+5|0]=as>>>16&255}as=an>>>8&15;if((as|0)!=0){ar=c[(c[2440392]|0)+(as<<2)>>2]|0;a[ae+6|0]=ar&255;a[ae+7|0]=ar>>>8&255;a[ae+8|0]=ar>>>16&255}ar=an>>>12&15;if((ar|0)!=0){as=c[(c[2440392]|0)+(ar<<2)>>2]|0;a[ae+9|0]=as&255;a[ae+10|0]=as>>>8&255;a[ae+11|0]=as>>>16&255}as=an>>>16&15;if((as|0)!=0){ar=c[(c[2440392]|0)+(as<<2)>>2]|0;a[ae+12|0]=ar&255;a[ae+13|0]=ar>>>8&255;a[ae+14|0]=ar>>>16&255}ar=an>>>20&15;if((ar|0)!=0){as=c[(c[2440392]|0)+(ar<<2)>>2]|0;a[ae+15|0]=as&255;a[ae+16|0]=as>>>8&255;a[ae+17|0]=as>>>16&255}as=an>>>24&15;if((as|0)!=0){ar=c[(c[2440392]|0)+(as<<2)>>2]|0;a[ae+18|0]=ar&255;a[ae+19|0]=ar>>>8&255;a[ae+20|0]=ar>>>16&255}ar=an>>>28;if((ar|0)!=0){as=c[(c[2440392]|0)+(ar<<2)>>2]|0;a[ae+21|0]=as&255;a[ae+22|0]=as>>>8&255;a[ae+23|0]=as>>>16&255}as=c[ah+((al|1)<<2)>>2]|0;ar=as&15;if((ar|0)!=0){at=c[(c[2440392]|0)+(ar<<2)>>2]|0;a[ae+24|0]=at&255;a[ae+25|0]=at>>>8&255;a[ae+26|0]=at>>>16&255}at=as>>>4&15;if((at|0)!=0){ar=c[(c[2440392]|0)+(at<<2)>>2]|0;a[ae+27|0]=ar&255;a[ae+28|0]=ar>>>8&255;a[ae+29|0]=ar>>>16&255}ar=as>>>8&15;if((ar|0)!=0){at=c[(c[2440392]|0)+(ar<<2)>>2]|0;a[ae+30|0]=at&255;a[ae+31|0]=at>>>8&255;a[ae+32|0]=at>>>16&255}at=as>>>12&15;if((at|0)!=0){ar=c[(c[2440392]|0)+(at<<2)>>2]|0;a[ae+33|0]=ar&255;a[ae+34|0]=ar>>>8&255;a[ae+35|0]=ar>>>16&255}ar=as>>>16&15;if((ar|0)!=0){at=c[(c[2440392]|0)+(ar<<2)>>2]|0;a[ae+36|0]=at&255;a[ae+37|0]=at>>>8&255;a[ae+38|0]=at>>>16&255}at=as>>>20&15;if((at|0)!=0){ar=c[(c[2440392]|0)+(at<<2)>>2]|0;a[ae+39|0]=ar&255;a[ae+40|0]=ar>>>8&255;a[ae+41|0]=ar>>>16&255}ar=as>>>24&15;if((ar|0)!=0){at=c[(c[2440392]|0)+(ar<<2)>>2]|0;a[ae+42|0]=at&255;a[ae+43|0]=at>>>8&255;a[ae+44|0]=at>>>16&255}at=as>>>28;if((at|0)==0){break}as=c[(c[2440392]|0)+(at<<2)>>2]|0;a[ae+45|0]=as&255;a[ae+46|0]=as>>>8&255;a[ae+47|0]=as>>>16&255;break}else{if(!aq){aq=c[(c[2440392]|0)+(ap<<2)>>2]|0;a[ae+45|0]=aq&255;a[ae+46|0]=aq>>>8&255;a[ae+47|0]=aq>>>16&255}aq=an>>>4&15;if((aq|0)!=0){ap=c[(c[2440392]|0)+(aq<<2)>>2]|0;a[ae+42|0]=ap&255;a[ae+43|0]=ap>>>8&255;a[ae+44|0]=ap>>>16&255}ap=an>>>8&15;if((ap|0)!=0){aq=c[(c[2440392]|0)+(ap<<2)>>2]|0;a[ae+39|0]=aq&255;a[ae+40|0]=aq>>>8&255;a[ae+41|0]=aq>>>16&255}aq=an>>>12&15;if((aq|0)!=0){ap=c[(c[2440392]|0)+(aq<<2)>>2]|0;a[ae+36|0]=ap&255;a[ae+37|0]=ap>>>8&255;a[ae+38|0]=ap>>>16&255}ap=an>>>16&15;if((ap|0)!=0){aq=c[(c[2440392]|0)+(ap<<2)>>2]|0;a[ae+33|0]=aq&255;a[ae+34|0]=aq>>>8&255;a[ae+35|0]=aq>>>16&255}aq=an>>>20&15;if((aq|0)!=0){ap=c[(c[2440392]|0)+(aq<<2)>>2]|0;a[ae+30|0]=ap&255;a[ae+31|0]=ap>>>8&255;a[ae+32|0]=ap>>>16&255}ap=an>>>24&15;if((ap|0)!=0){aq=c[(c[2440392]|0)+(ap<<2)>>2]|0;a[ae+27|0]=aq&255;a[ae+28|0]=aq>>>8&255;a[ae+29|0]=aq>>>16&255}aq=an>>>28;if((aq|0)!=0){an=c[(c[2440392]|0)+(aq<<2)>>2]|0;a[ae+24|0]=an&255;a[ae+25|0]=an>>>8&255;a[ae+26|0]=an>>>16&255}an=c[ah+((al|1)<<2)>>2]|0;al=an&15;if((al|0)!=0){ah=c[(c[2440392]|0)+(al<<2)>>2]|0;a[ae+21|0]=ah&255;a[ae+22|0]=ah>>>8&255;a[ae+23|0]=ah>>>16&255}ah=an>>>4&15;if((ah|0)!=0){al=c[(c[2440392]|0)+(ah<<2)>>2]|0;a[ae+18|0]=al&255;a[ae+19|0]=al>>>8&255;a[ae+20|0]=al>>>16&255}al=an>>>8&15;if((al|0)!=0){ah=c[(c[2440392]|0)+(al<<2)>>2]|0;a[ae+15|0]=ah&255;a[ae+16|0]=ah>>>8&255;a[ae+17|0]=ah>>>16&255}ah=an>>>12&15;if((ah|0)!=0){al=c[(c[2440392]|0)+(ah<<2)>>2]|0;a[ae+12|0]=al&255;a[ae+13|0]=al>>>8&255;a[ae+14|0]=al>>>16&255}al=an>>>16&15;if((al|0)!=0){ah=c[(c[2440392]|0)+(al<<2)>>2]|0;a[ae+9|0]=ah&255;a[ae+10|0]=ah>>>8&255;a[ae+11|0]=ah>>>16&255}ah=an>>>20&15;if((ah|0)!=0){al=c[(c[2440392]|0)+(ah<<2)>>2]|0;a[ae+6|0]=al&255;a[ae+7|0]=al>>>8&255;a[ae+8|0]=al>>>16&255}al=an>>>24&15;if((al|0)!=0){ah=c[(c[2440392]|0)+(al<<2)>>2]|0;a[ae+3|0]=ah&255;a[ae+4|0]=ah>>>8&255;a[ae+5|0]=ah>>>16&255}ah=an>>>28;if((ah|0)==0){break}an=c[(c[2440392]|0)+(ah<<2)>>2]|0;a[ae]=an&255;a[ae+1|0]=an>>>8&255;a[ae+2|0]=an>>>16&255;break}}}while(0);af=I+1|0;if((af|0)>(H|0)){ac=aj;ad=ai;break}else{I=af;F=ak;D=aj;N=ai;ae=ae+s|0}}}if((ab|0)>(i|0)){U=36103;break}else{A=ab;B=ac;C=ad}}if((U|0)==36103){return}else if((U|0)==36104){return}}function czi(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0;b=c[3540994]|0;f=c[3528548]|0;g=f<<8;h=c[2385554]|0;do{if((h|0)>31){i=511}else{j=(h<<4)-1|0;if((j|0)>=0){i=j;break}return}}while(0);j=(i|0)>255;k=i&255;l=c[2385550]|0;m=c[2113042]|0;n=c[2113044]|0;o=m+512|0;p=c[2385552]|0;q=c[2113132]|0;r=p*3|0;s=c[2112968]|0;t=(p|0)>-1;u=q*3|0;v=c[2415160]|0;w=c[2429858]|0;x=c[2430428]|0;y=c[2429718]|0;z=c[2430092]|0;A=c[3541046]|0;B=c[2430426]|0;C=0;D=0;E=0;L41530:while(1){F=(h|0)>16&(f|0)!=255;G=(h|0)<33;H=511-f|0;I=f+1|0;J=f-255|0;K=~f;L=E;L41532:while(1){M=L+l|0;N=M&511;do{if((N|0)<(m|0)){O=L+m-N|0}else{if((N|0)>=(n|0)){O=o+L-N|0;break}P=(L|0)>255;Q=P?16:0;R=L&255;S=(L|0)<256&j?255:k;if(!F){T=S;U=R;V=Q;W=36129;break L41532}if(G){if(!P){W=36119;break L41532}if((L|0)<(H|0)){O=H;break}else{W=36121;break L41532}}if(P){X=J+R|0;if((X|0)>=0){W=36124;break L41532}P=I+X|0;if((P|0)<0){O=512;break}else{T=f;U=P;V=0;W=36129;break L41532}}else{if((R|0)<=(f|0)){W=36127;break L41532}P=R+K|0;if((P|0)>(f|0)){O=256;break}else{T=f;U=P;V=16;W=36129;break L41532}}}}while(0);if((O|0)>(i|0)){W=36152;break L41530}else{L=O}}if((W|0)==36124){W=0;Y=f;Z=Q;_=X;$=I+L-X|0}else if((W|0)==36119){W=0;aa=Q;ab=R;ac=S;ad=L+1-R+S|0;W=36130}else if((W|0)==36127){W=0;Y=f;Z=Q;_=R;$=I+L-R|0}else if((W|0)==36121){W=0;K=255-f|0;T=S-K|0;U=R-K|0;V=Q;W=36129}if((W|0)==36129){W=0;K=L+1-U+T|0;if(G){aa=V;ab=U;ac=T;ad=K;W=36130}else{Y=T;Z=V;_=U;$=K}}if((W|0)==36130){W=0;Y=(ac|0)>(f|0)?f:ac;Z=aa;_=ab;$=ad}K=((M|-512)^511)+n|0;J=(Y-_|0)>(K|0)?K+_|0:Y;if((_|0)>(J|0)){ae=C;af=D}else{K=C;H=-1;F=D;P=_;ah=s+((ag(q,(N*3|0)-48|0)|0)+r)|0;while(1){ai=d[b+(P+g)|0]|0;aj=(ai>>>4)+Z|0;do{if((aj|0)==(H|0)){ak=F;al=H;am=K}else{an=aj<<1;ao=e[v+((an|1)<<1)>>1]|0;ap=(ao<<12&983040|(e[v+(an<<1)>>1]|0))&w;do{if((ao&8|0)==0){if((ao&4|0)==0){aq=ap;break}aq=x|ap&1048572}else{aq=B|ap&1048568}}while(0);ap=a[y+aq|0]|0;an=ap&255;if(ap<<24>>24!=0){ak=an;al=aj;am=ao;break}c[2385344]=z+(aq<<7);c[2440392]=A+((ao>>>4&4080)<<2);ak=an;al=aj;am=ao}}while(0);do{if((ak|0)==0){aj=ai<<1&30;an=c[(c[2385344]|0)+((((am&2|0)==0?aj:aj^30)|1)<<2)>>2]&15;aj=(an|0)==0;if((am&1|0)==0){if(aj){break}if(!(t&(p|0)<(q|0))){break}ap=c[(c[2440392]|0)+(an<<2)>>2]|0;a[ah]=ap&255;a[ah+1|0]=ap>>>8&255;a[ah+2|0]=ap>>>16&255;break}else{if(aj){break}if(!(t&(p|0)<(q|0))){break}aj=c[(c[2440392]|0)+(an<<2)>>2]|0;a[ah]=aj&255;a[ah+1|0]=aj>>>8&255;a[ah+2|0]=aj>>>16&255;break}}}while(0);ai=P+1|0;if((ai|0)>(J|0)){ae=am;af=ak;break}else{K=am;H=al;F=ak;P=ai;ah=ah+u|0}}}if(($|0)>(i|0)){W=36150;break}else{C=ae;D=af;E=$}}if((W|0)==36152){return}else if((W|0)==36150){return}}function czj(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0;b=c[3540994]|0;f=c[3528548]|0;g=f<<8;h=c[2385554]|0;do{if((h|0)>31){i=511}else{j=(h<<4)-1|0;if((j|0)>=0){i=j;break}return}}while(0);j=(i|0)>255;k=i&255;l=c[2385550]|0;m=c[2113042]|0;n=c[2113044]|0;o=m+512|0;p=c[2385552]|0;q=c[2113132]|0;r=p*3|0;s=c[2112968]|0;t=p+1|0;u=(t|0)>-1&(t|0)<(q|0);t=(p|0)>-1&(p|0)<(q|0);p=q*3|0;v=c[2415160]|0;w=c[2429858]|0;x=c[2430428]|0;y=c[2429718]|0;z=c[2430092]|0;A=c[3541046]|0;B=c[2430426]|0;C=0;D=0;E=0;L41593:while(1){F=(h|0)>16&(f|0)!=255;G=(h|0)<33;H=511-f|0;I=f+1|0;J=f-255|0;K=~f;L=D;L41595:while(1){M=L+l|0;N=M&511;do{if((N|0)<(m|0)){O=L+m-N|0}else{if((N|0)>=(n|0)){O=o+L-N|0;break}P=(L|0)>255;Q=P?16:0;R=L&255;S=(L|0)<256&j?255:k;if(!F){T=S;U=R;V=Q;W=36176;break L41595}if(G){if(!P){W=36166;break L41595}if((L|0)<(H|0)){O=H;break}else{W=36168;break L41595}}if(P){X=J+R|0;if((X|0)>=0){W=36171;break L41595}P=I+X|0;if((P|0)<0){O=512;break}else{T=f;U=P;V=0;W=36176;break L41595}}else{if((R|0)<=(f|0)){W=36174;break L41595}P=R+K|0;if((P|0)>(f|0)){O=256;break}else{T=f;U=P;V=16;W=36176;break L41595}}}}while(0);if((O|0)>(i|0)){W=36200;break L41593}else{L=O}}if((W|0)==36166){W=0;Y=Q;Z=R;_=S;$=L+1-R+S|0;W=36177}else if((W|0)==36168){W=0;K=255-f|0;T=S-K|0;U=R-K|0;V=Q;W=36176}else if((W|0)==36174){W=0;aa=f;ab=Q;ac=R;ad=I+L-R|0}else if((W|0)==36171){W=0;aa=f;ab=Q;ac=X;ad=I+L-X|0}if((W|0)==36176){W=0;K=L+1-U+T|0;if(G){Y=V;Z=U;_=T;$=K;W=36177}else{aa=T;ab=V;ac=U;ad=K}}if((W|0)==36177){W=0;aa=(_|0)>(f|0)?f:_;ab=Y;ac=Z;ad=$}K=((M|-512)^511)+n|0;J=(aa-ac|0)>(K|0)?K+ac|0:aa;if((ac|0)>(J|0)){ae=C;af=E}else{K=-1;H=C;F=ac;P=E;ah=s+((ag(q,(N*3|0)-48|0)|0)+r)|0;while(1){ai=d[b+(F+g)|0]|0;aj=(ai>>>4)+ab|0;do{if((aj|0)==(K|0)){ak=P;al=H;am=K}else{an=aj<<1;ao=e[v+((an|1)<<1)>>1]|0;ap=(ao<<12&983040|(e[v+(an<<1)>>1]|0))&w;do{if((ao&8|0)==0){if((ao&4|0)==0){aq=ap;break}aq=x|ap&1048572}else{aq=B|ap&1048568}}while(0);ap=a[y+aq|0]|0;an=ap&255;if(ap<<24>>24!=0){ak=an;al=ao;am=aj;break}c[2385344]=z+(aq<<7);c[2440392]=A+((ao>>>4&4080)<<2);ak=an;al=ao;am=aj}}while(0);do{if((ak|0)==0){aj=ai<<1&30;an=(al&2|0)==0?aj:aj^30;if((al&1|0)==0){aj=c[2385344]|0;ap=(c[aj+(an<<2)>>2]|0)>>>16&15;if(!((ap|0)==0|t^1)){ar=c[(c[2440392]|0)+(ap<<2)>>2]|0;a[ah]=ar&255;a[ah+1|0]=ar>>>8&255;a[ah+2|0]=ar>>>16&255}ar=c[aj+((an|1)<<2)>>2]&15;if((ar|0)==0|u^1){break}aj=c[(c[2440392]|0)+(ar<<2)>>2]|0;a[ah+3|0]=aj&255;a[ah+4|0]=aj>>>8&255;a[ah+5|0]=aj>>>16&255;break}else{aj=c[2385344]|0;ar=(c[aj+(an<<2)>>2]|0)>>>16&15;if(!((ar|0)==0|u^1)){ap=c[(c[2440392]|0)+(ar<<2)>>2]|0;a[ah+3|0]=ap&255;a[ah+4|0]=ap>>>8&255;a[ah+5|0]=ap>>>16&255}ap=c[aj+((an|1)<<2)>>2]&15;if((ap|0)==0|t^1){break}an=c[(c[2440392]|0)+(ap<<2)>>2]|0;a[ah]=an&255;a[ah+1|0]=an>>>8&255;a[ah+2|0]=an>>>16&255;break}}}while(0);ai=F+1|0;if((ai|0)>(J|0)){ae=al;af=ak;break}else{K=am;H=al;F=ai;P=ak;ah=ah+p|0}}}if((ad|0)>(i|0)){W=36199;break}else{C=ae;D=ad;E=af}}if((W|0)==36199){return}else if((W|0)==36200){return}}function czk(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0;b=c[3540994]|0;f=c[3528548]|0;g=f<<8;h=c[2385554]|0;do{if((h|0)>31){i=511}else{j=(h<<4)-1|0;if((j|0)>=0){i=j;break}return}}while(0);j=(i|0)>255;k=i&255;l=c[2385550]|0;m=c[2113042]|0;n=c[2113044]|0;o=m+512|0;p=c[2385552]|0;q=c[2113132]|0;r=p*3|0;s=c[2112968]|0;t=p+2|0;u=(t|0)>-1&(t|0)<(q|0);t=p+1|0;v=(t|0)>-1&(t|0)<(q|0);t=(p|0)>-1&(p|0)<(q|0);p=q*3|0;w=c[2415160]|0;x=c[2429858]|0;y=c[2430428]|0;z=c[2429718]|0;A=c[2430092]|0;B=c[3541046]|0;C=c[2430426]|0;D=0;E=0;F=0;L41660:while(1){G=(h|0)>16&(f|0)!=255;H=(h|0)<33;I=511-f|0;J=f+1|0;K=f-255|0;L=~f;M=D;L41662:while(1){N=M+l|0;O=N&511;do{if((O|0)<(m|0)){P=M+m-O|0}else{if((O|0)>=(n|0)){P=o+M-O|0;break}Q=(M|0)>255;R=Q?16:0;S=M&255;T=(M|0)<256&j?255:k;if(!G){U=T;V=S;W=R;X=36225;break L41662}if(H){if(!Q){X=36215;break L41662}if((M|0)<(I|0)){P=I;break}else{X=36217;break L41662}}if(Q){Y=K+S|0;if((Y|0)>=0){X=36220;break L41662}Q=J+Y|0;if((Q|0)<0){P=512;break}else{U=f;V=Q;W=0;X=36225;break L41662}}else{if((S|0)<=(f|0)){X=36223;break L41662}Q=S+L|0;if((Q|0)>(f|0)){P=256;break}else{U=f;V=Q;W=16;X=36225;break L41662}}}}while(0);if((P|0)>(i|0)){X=36254;break L41660}else{M=P}}if((X|0)==36217){X=0;L=255-f|0;U=T-L|0;V=S-L|0;W=R;X=36225}else if((X|0)==36220){X=0;Z=f;_=R;$=Y;aa=J+M-Y|0}else if((X|0)==36215){X=0;ab=R;ac=S;ad=T;ae=M+1-S+T|0;X=36226}else if((X|0)==36223){X=0;Z=f;_=R;$=S;aa=J+M-S|0}if((X|0)==36225){X=0;L=M+1-V+U|0;if(H){ab=W;ac=V;ad=U;ae=L;X=36226}else{Z=U;_=W;$=V;aa=L}}if((X|0)==36226){X=0;Z=(ad|0)>(f|0)?f:ad;_=ab;$=ac;aa=ae}L=((N|-512)^511)+n|0;K=(Z-$|0)>(L|0)?L+$|0:Z;if(($|0)>(K|0)){af=E;ah=F}else{L=-1;I=$;G=E;Q=F;ai=s+((ag(q,(O*3|0)-48|0)|0)+r)|0;while(1){aj=d[b+(I+g)|0]|0;ak=(aj>>>4)+_|0;do{if((ak|0)==(L|0)){al=Q;am=G;an=L}else{ao=ak<<1;ap=e[w+((ao|1)<<1)>>1]|0;aq=(ap<<12&983040|(e[w+(ao<<1)>>1]|0))&x;do{if((ap&8|0)==0){if((ap&4|0)==0){ar=aq;break}ar=y|aq&1048572}else{ar=C|aq&1048568}}while(0);aq=a[z+ar|0]|0;ao=aq&255;if(aq<<24>>24!=0){al=ao;am=ap;an=ak;break}c[2385344]=A+(ar<<7);c[2440392]=B+((ap>>>4&4080)<<2);al=ao;am=ap;an=ak}}while(0);do{if((al|0)==0){ak=aj<<1&30;ao=(am&2|0)==0?ak:ak^30;if((am&1|0)==0){ak=c[2385344]|0;aq=(c[ak+(ao<<2)>>2]|0)>>>16&15;if(!((aq|0)==0|t^1)){as=c[(c[2440392]|0)+(aq<<2)>>2]|0;a[ai]=as&255;a[ai+1|0]=as>>>8&255;a[ai+2|0]=as>>>16&255}as=c[ak+((ao|1)<<2)>>2]|0;ak=as&15;if(!((ak|0)==0|v^1)){aq=c[(c[2440392]|0)+(ak<<2)>>2]|0;a[ai+3|0]=aq&255;a[ai+4|0]=aq>>>8&255;a[ai+5|0]=aq>>>16&255}aq=as>>>16&15;if((aq|0)==0|u^1){break}as=c[(c[2440392]|0)+(aq<<2)>>2]|0;a[ai+6|0]=as&255;a[ai+7|0]=as>>>8&255;a[ai+8|0]=as>>>16&255;break}else{as=c[2385344]|0;aq=(c[as+(ao<<2)>>2]|0)>>>16&15;if(!((aq|0)==0|u^1)){ak=c[(c[2440392]|0)+(aq<<2)>>2]|0;a[ai+6|0]=ak&255;a[ai+7|0]=ak>>>8&255;a[ai+8|0]=ak>>>16&255}ak=c[as+((ao|1)<<2)>>2]|0;ao=ak&15;if(!((ao|0)==0|v^1)){as=c[(c[2440392]|0)+(ao<<2)>>2]|0;a[ai+3|0]=as&255;a[ai+4|0]=as>>>8&255;a[ai+5|0]=as>>>16&255}as=ak>>>16&15;if((as|0)==0|t^1){break}ak=c[(c[2440392]|0)+(as<<2)>>2]|0;a[ai]=ak&255;a[ai+1|0]=ak>>>8&255;a[ai+2|0]=ak>>>16&255;break}}}while(0);aj=I+1|0;if((aj|0)>(K|0)){af=am;ah=al;break}else{L=an;I=aj;G=am;Q=al;ai=ai+p|0}}}if((aa|0)>(i|0)){X=36252;break}else{D=aa;E=af;F=ah}}if((X|0)==36252){return}else if((X|0)==36254){return}}function czl(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0;b=c[3540994]|0;f=c[3528548]|0;g=f<<8;h=c[2385554]|0;do{if((h|0)>31){i=511}else{j=(h<<4)-1|0;if((j|0)>=0){i=j;break}return}}while(0);j=(i|0)>255;k=i&255;l=c[2385550]|0;m=c[2113042]|0;n=c[2113044]|0;o=m+512|0;p=c[2385552]|0;q=c[2113132]|0;r=p*3|0;s=c[2112968]|0;t=p+3|0;u=(t|0)>-1&(t|0)<(q|0);t=p+2|0;v=(t|0)>-1&(t|0)<(q|0);t=p+1|0;w=(t|0)>-1&(t|0)<(q|0);t=(p|0)>-1&(p|0)<(q|0);p=q*3|0;x=c[2415160]|0;y=c[2429858]|0;z=c[2430428]|0;A=c[2429718]|0;B=c[2430092]|0;C=c[3541046]|0;D=c[2430426]|0;E=0;F=0;G=0;L41733:while(1){H=(h|0)>16&(f|0)!=255;I=(h|0)<33;J=511-f|0;K=f+1|0;L=f-255|0;M=~f;N=E;L41735:while(1){O=N+l|0;P=O&511;do{if((P|0)<(m|0)){Q=N+m-P|0}else{if((P|0)>=(n|0)){Q=o+N-P|0;break}R=(N|0)>255;S=R?16:0;T=N&255;U=(N|0)<256&j?255:k;if(!H){V=U;W=T;X=S;Y=36278;break L41735}if(I){if(!R){Y=36268;break L41735}if((N|0)<(J|0)){Q=J;break}else{Y=36270;break L41735}}if(R){Z=L+T|0;if((Z|0)>=0){Y=36273;break L41735}R=K+Z|0;if((R|0)<0){Q=512;break}else{V=f;W=R;X=0;Y=36278;break L41735}}else{if((T|0)<=(f|0)){Y=36276;break L41735}R=T+M|0;if((R|0)>(f|0)){Q=256;break}else{V=f;W=R;X=16;Y=36278;break L41735}}}}while(0);if((Q|0)>(i|0)){Y=36310;break L41733}else{N=Q}}if((Y|0)==36276){Y=0;_=f;$=S;aa=T;ab=K+N-T|0}else if((Y|0)==36268){Y=0;ac=S;ad=T;ae=U;af=N+1-T+U|0;Y=36279}else if((Y|0)==36273){Y=0;_=f;$=S;aa=Z;ab=K+N-Z|0}else if((Y|0)==36270){Y=0;M=255-f|0;V=U-M|0;W=T-M|0;X=S;Y=36278}if((Y|0)==36278){Y=0;M=N+1-W+V|0;if(I){ac=X;ad=W;ae=V;af=M;Y=36279}else{_=V;$=X;aa=W;ab=M}}if((Y|0)==36279){Y=0;_=(ae|0)>(f|0)?f:ae;$=ac;aa=ad;ab=af}M=((O|-512)^511)+n|0;L=(_-aa|0)>(M|0)?M+aa|0:_;if((aa|0)>(L|0)){ah=F;ai=G}else{M=aa;J=-1;H=F;R=G;aj=s+((ag(q,(P*3|0)-48|0)|0)+r)|0;while(1){ak=d[b+(M+g)|0]|0;al=(ak>>>4)+$|0;do{if((al|0)==(J|0)){am=R;an=H;ao=J}else{ap=al<<1;aq=e[x+((ap|1)<<1)>>1]|0;ar=(aq<<12&983040|(e[x+(ap<<1)>>1]|0))&y;do{if((aq&8|0)==0){if((aq&4|0)==0){as=ar;break}as=z|ar&1048572}else{as=D|ar&1048568}}while(0);ar=a[A+as|0]|0;ap=ar&255;if(ar<<24>>24!=0){am=ap;an=aq;ao=al;break}c[2385344]=B+(as<<7);c[2440392]=C+((aq>>>4&4080)<<2);am=ap;an=aq;ao=al}}while(0);do{if((am|0)==0){al=ak<<1&30;ap=(an&2|0)==0?al:al^30;if((an&1|0)==0){al=c[2385344]|0;ar=c[al+(ap<<2)>>2]|0;at=ar>>>8&15;if(!((at|0)==0|t^1)){au=c[(c[2440392]|0)+(at<<2)>>2]|0;a[aj]=au&255;a[aj+1|0]=au>>>8&255;a[aj+2|0]=au>>>16&255}au=ar>>>16&15;if(!((au|0)==0|w^1)){ar=c[(c[2440392]|0)+(au<<2)>>2]|0;a[aj+3|0]=ar&255;a[aj+4|0]=ar>>>8&255;a[aj+5|0]=ar>>>16&255}ar=c[al+((ap|1)<<2)>>2]|0;al=ar&15;if(!((al|0)==0|v^1)){au=c[(c[2440392]|0)+(al<<2)>>2]|0;a[aj+6|0]=au&255;a[aj+7|0]=au>>>8&255;a[aj+8|0]=au>>>16&255}au=ar>>>16&15;if((au|0)==0|u^1){break}ar=c[(c[2440392]|0)+(au<<2)>>2]|0;a[aj+9|0]=ar&255;a[aj+10|0]=ar>>>8&255;a[aj+11|0]=ar>>>16&255;break}else{ar=c[2385344]|0;au=c[ar+(ap<<2)>>2]|0;al=au>>>8&15;if(!((al|0)==0|u^1)){at=c[(c[2440392]|0)+(al<<2)>>2]|0;a[aj+9|0]=at&255;a[aj+10|0]=at>>>8&255;a[aj+11|0]=at>>>16&255}at=au>>>16&15;if(!((at|0)==0|v^1)){au=c[(c[2440392]|0)+(at<<2)>>2]|0;a[aj+6|0]=au&255;a[aj+7|0]=au>>>8&255;a[aj+8|0]=au>>>16&255}au=c[ar+((ap|1)<<2)>>2]|0;ap=au&15;if(!((ap|0)==0|w^1)){ar=c[(c[2440392]|0)+(ap<<2)>>2]|0;a[aj+3|0]=ar&255;a[aj+4|0]=ar>>>8&255;a[aj+5|0]=ar>>>16&255}ar=au>>>16&15;if((ar|0)==0|t^1){break}au=c[(c[2440392]|0)+(ar<<2)>>2]|0;a[aj]=au&255;a[aj+1|0]=au>>>8&255;a[aj+2|0]=au>>>16&255;break}}}while(0);ak=M+1|0;if((ak|0)>(L|0)){ah=an;ai=am;break}else{M=ak;J=ao;H=an;R=am;aj=aj+p|0}}}if((ab|0)>(i|0)){Y=36309;break}else{E=ab;F=ah;G=ai}}if((Y|0)==36309){return}else if((Y|0)==36310){return}}function czm(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0;b=c[3540994]|0;f=c[3528548]|0;g=f<<8;h=c[2385554]|0;do{if((h|0)>31){i=511}else{j=(h<<4)-1|0;if((j|0)>=0){i=j;break}return}}while(0);j=(i|0)>255;k=i&255;l=c[2385550]|0;m=c[2113042]|0;n=c[2113044]|0;o=m+512|0;p=c[2385552]|0;q=c[2113132]|0;r=p*3|0;s=c[2112968]|0;t=p+4|0;u=(t|0)>-1&(t|0)<(q|0);t=p+3|0;v=(t|0)>-1&(t|0)<(q|0);t=p+2|0;w=(t|0)>-1&(t|0)<(q|0);t=p+1|0;x=(t|0)>-1&(t|0)<(q|0);t=(p|0)>-1&(p|0)<(q|0);p=q*3|0;y=c[2415160]|0;z=c[2429858]|0;A=c[2430428]|0;B=c[2429718]|0;C=c[2430092]|0;D=c[3541046]|0;E=c[2430426]|0;F=0;G=0;H=0;L41812:while(1){I=(h|0)>16&(f|0)!=255;J=(h|0)<33;K=511-f|0;L=f+1|0;M=f-255|0;N=~f;O=F;L41814:while(1){P=O+l|0;Q=P&511;do{if((Q|0)<(m|0)){R=O+m-Q|0}else{if((Q|0)>=(n|0)){R=o+O-Q|0;break}S=(O|0)>255;T=S?16:0;U=O&255;V=(O|0)<256&j?255:k;if(!I){W=T;X=V;Y=U;Z=36335;break L41814}if(J){if(!S){Z=36325;break L41814}if((O|0)<(K|0)){R=K;break}else{Z=36327;break L41814}}if(S){_=M+U|0;if((_|0)>=0){Z=36330;break L41814}S=L+_|0;if((S|0)<0){R=512;break}else{W=0;X=f;Y=S;Z=36335;break L41814}}else{if((U|0)<=(f|0)){Z=36333;break L41814}S=U+N|0;if((S|0)>(f|0)){R=256;break}else{W=16;X=f;Y=S;Z=36335;break L41814}}}}while(0);if((R|0)>(i|0)){Z=36372;break L41812}else{O=R}}if((Z|0)==36327){Z=0;N=255-f|0;W=T;X=V-N|0;Y=U-N|0;Z=36335}else if((Z|0)==36333){Z=0;$=f;aa=U;ab=T;ac=L+O-U|0}else if((Z|0)==36330){Z=0;$=f;aa=_;ab=T;ac=L+O-_|0}else if((Z|0)==36325){Z=0;ad=U;ae=V;af=T;ah=O+1-U+V|0;Z=36336}if((Z|0)==36335){Z=0;N=O+1-Y+X|0;if(J){ad=Y;ae=X;af=W;ah=N;Z=36336}else{$=X;aa=Y;ab=W;ac=N}}if((Z|0)==36336){Z=0;$=(ae|0)>(f|0)?f:ae;aa=ad;ab=af;ac=ah}N=((P|-512)^511)+n|0;M=($-aa|0)>(N|0)?N+aa|0:$;if((aa|0)>(M|0)){ai=G;aj=H}else{N=aa;K=-1;I=G;S=H;ak=s+((ag(q,(Q*3|0)-48|0)|0)+r)|0;while(1){al=d[b+(N+g)|0]|0;am=(al>>>4)+ab|0;do{if((am|0)==(K|0)){an=S;ao=I;ap=K}else{aq=am<<1;ar=e[y+((aq|1)<<1)>>1]|0;as=(ar<<12&983040|(e[y+(aq<<1)>>1]|0))&z;do{if((ar&8|0)==0){if((ar&4|0)==0){at=as;break}at=A|as&1048572}else{at=E|as&1048568}}while(0);as=a[B+at|0]|0;aq=as&255;if(as<<24>>24!=0){an=aq;ao=ar;ap=am;break}c[2385344]=C+(at<<7);c[2440392]=D+((ar>>>4&4080)<<2);an=aq;ao=ar;ap=am}}while(0);do{if((an|0)==0){am=al<<1&30;aq=(ao&2|0)==0?am:am^30;if((ao&1|0)==0){am=c[2385344]|0;as=c[am+(aq<<2)>>2]|0;au=as>>>8&15;if(!((au|0)==0|t^1)){av=c[(c[2440392]|0)+(au<<2)>>2]|0;a[ak]=av&255;a[ak+1|0]=av>>>8&255;a[ak+2|0]=av>>>16&255}av=as>>>16&15;if(!((av|0)==0|x^1)){as=c[(c[2440392]|0)+(av<<2)>>2]|0;a[ak+3|0]=as&255;a[ak+4|0]=as>>>8&255;a[ak+5|0]=as>>>16&255}as=c[am+((aq|1)<<2)>>2]|0;am=as&15;if(!((am|0)==0|w^1)){av=c[(c[2440392]|0)+(am<<2)>>2]|0;a[ak+6|0]=av&255;a[ak+7|0]=av>>>8&255;a[ak+8|0]=av>>>16&255}av=as>>>16&15;if(!((av|0)==0|v^1)){am=c[(c[2440392]|0)+(av<<2)>>2]|0;a[ak+9|0]=am&255;a[ak+10|0]=am>>>8&255;a[ak+11|0]=am>>>16&255}am=as>>>24&15;if((am|0)==0|u^1){break}as=c[(c[2440392]|0)+(am<<2)>>2]|0;a[ak+12|0]=as&255;a[ak+13|0]=as>>>8&255;a[ak+14|0]=as>>>16&255;break}else{as=c[2385344]|0;am=c[as+(aq<<2)>>2]|0;av=am>>>8&15;if(!((av|0)==0|u^1)){au=c[(c[2440392]|0)+(av<<2)>>2]|0;a[ak+12|0]=au&255;a[ak+13|0]=au>>>8&255;a[ak+14|0]=au>>>16&255}au=am>>>16&15;if(!((au|0)==0|v^1)){am=c[(c[2440392]|0)+(au<<2)>>2]|0;a[ak+9|0]=am&255;a[ak+10|0]=am>>>8&255;a[ak+11|0]=am>>>16&255}am=c[as+((aq|1)<<2)>>2]|0;aq=am&15;if(!((aq|0)==0|w^1)){as=c[(c[2440392]|0)+(aq<<2)>>2]|0;a[ak+6|0]=as&255;a[ak+7|0]=as>>>8&255;a[ak+8|0]=as>>>16&255}as=am>>>16&15;if(!((as|0)==0|x^1)){aq=c[(c[2440392]|0)+(as<<2)>>2]|0;a[ak+3|0]=aq&255;a[ak+4|0]=aq>>>8&255;a[ak+5|0]=aq>>>16&255}aq=am>>>24&15;if((aq|0)==0|t^1){break}am=c[(c[2440392]|0)+(aq<<2)>>2]|0;a[ak]=am&255;a[ak+1|0]=am>>>8&255;a[ak+2|0]=am>>>16&255;break}}}while(0);al=N+1|0;if((al|0)>(M|0)){ai=ao;aj=an;break}else{N=al;K=ap;I=ao;S=an;ak=ak+p|0}}}if((ac|0)>(i|0)){Z=36370;break}else{F=ac;G=ai;H=aj}}if((Z|0)==36370){return}else if((Z|0)==36372){return}}function czn(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0;b=c[3540994]|0;f=c[3528548]|0;g=f<<8;h=c[2385554]|0;do{if((h|0)>31){i=511}else{j=(h<<4)-1|0;if((j|0)>=0){i=j;break}return}}while(0);j=(i|0)>255;k=i&255;l=c[2385550]|0;m=c[2113042]|0;n=c[2113044]|0;o=m+512|0;p=c[2385552]|0;q=c[2113132]|0;r=p*3|0;s=c[2112968]|0;t=p+5|0;u=(t|0)>-1&(t|0)<(q|0);t=p+4|0;v=(t|0)>-1&(t|0)<(q|0);t=p+3|0;w=(t|0)>-1&(t|0)<(q|0);t=p+2|0;x=(t|0)>-1&(t|0)<(q|0);t=p+1|0;y=(t|0)>-1&(t|0)<(q|0);t=(p|0)>-1&(p|0)<(q|0);p=q*3|0;z=c[2415160]|0;A=c[2429858]|0;B=c[2430428]|0;C=c[2429718]|0;D=c[2430092]|0;E=c[3541046]|0;F=c[2430426]|0;G=0;H=0;I=0;L41897:while(1){J=(h|0)>16&(f|0)!=255;K=(h|0)<33;L=511-f|0;M=f+1|0;N=f-255|0;O=~f;P=G;L41899:while(1){Q=P+l|0;R=Q&511;do{if((R|0)<(m|0)){S=P+m-R|0}else{if((R|0)>=(n|0)){S=o+P-R|0;break}T=(P|0)>255;U=T?16:0;V=P&255;W=(P|0)<256&j?255:k;if(!J){X=U;Y=V;Z=W;_=36396;break L41899}if(K){if(!T){_=36386;break L41899}if((P|0)<(L|0)){S=L;break}else{_=36388;break L41899}}if(T){$=N+V|0;if(($|0)>=0){_=36391;break L41899}T=M+$|0;if((T|0)<0){S=512;break}else{X=0;Y=T;Z=f;_=36396;break L41899}}else{if((V|0)<=(f|0)){_=36394;break L41899}T=V+O|0;if((T|0)>(f|0)){S=256;break}else{X=16;Y=T;Z=f;_=36396;break L41899}}}}while(0);if((S|0)>(i|0)){_=36436;break L41897}else{P=S}}if((_|0)==36388){_=0;O=255-f|0;X=U;Y=V-O|0;Z=W-O|0;_=36396}else if((_|0)==36394){_=0;aa=f;ab=V;ac=U;ad=M+P-V|0}else if((_|0)==36386){_=0;ae=W;af=V;ah=U;ai=P+1-V+W|0;_=36397}else if((_|0)==36391){_=0;aa=f;ab=$;ac=U;ad=M+P-$|0}if((_|0)==36396){_=0;O=P+1+Z-Y|0;if(K){ae=Z;af=Y;ah=X;ai=O;_=36397}else{aa=Z;ab=Y;ac=X;ad=O}}if((_|0)==36397){_=0;aa=(ae|0)>(f|0)?f:ae;ab=af;ac=ah;ad=ai}O=((Q|-512)^511)+n|0;N=(aa-ab|0)>(O|0)?O+ab|0:aa;if((ab|0)>(N|0)){aj=H;ak=I}else{O=ab;L=-1;J=H;T=I;al=s+((ag(q,(R*3|0)-48|0)|0)+r)|0;while(1){am=d[b+(O+g)|0]|0;an=(am>>>4)+ac|0;do{if((an|0)==(L|0)){ao=T;ap=J;aq=L}else{ar=an<<1;as=e[z+((ar|1)<<1)>>1]|0;at=(as<<12&983040|(e[z+(ar<<1)>>1]|0))&A;do{if((as&8|0)==0){if((as&4|0)==0){au=at;break}au=B|at&1048572}else{au=F|at&1048568}}while(0);at=a[C+au|0]|0;ar=at&255;if(at<<24>>24!=0){ao=ar;ap=as;aq=an;break}c[2385344]=D+(au<<7);c[2440392]=E+((as>>>4&4080)<<2);ao=ar;ap=as;aq=an}}while(0);do{if((ao|0)==0){an=am<<1&30;ar=(ap&2|0)==0?an:an^30;if((ap&1|0)==0){an=c[2385344]|0;at=c[an+(ar<<2)>>2]|0;av=at>>>8&15;if(!((av|0)==0|t^1)){aw=c[(c[2440392]|0)+(av<<2)>>2]|0;a[al]=aw&255;a[al+1|0]=aw>>>8&255;a[al+2|0]=aw>>>16&255}aw=at>>>16&15;if(!((aw|0)==0|y^1)){av=c[(c[2440392]|0)+(aw<<2)>>2]|0;a[al+3|0]=av&255;a[al+4|0]=av>>>8&255;a[al+5|0]=av>>>16&255}av=at>>>24&15;if(!((av|0)==0|x^1)){at=c[(c[2440392]|0)+(av<<2)>>2]|0;a[al+6|0]=at&255;a[al+7|0]=at>>>8&255;a[al+8|0]=at>>>16&255}at=c[an+((ar|1)<<2)>>2]|0;an=at&15;if(!((an|0)==0|w^1)){av=c[(c[2440392]|0)+(an<<2)>>2]|0;a[al+9|0]=av&255;a[al+10|0]=av>>>8&255;a[al+11|0]=av>>>16&255}av=at>>>16&15;if(!((av|0)==0|v^1)){an=c[(c[2440392]|0)+(av<<2)>>2]|0;a[al+12|0]=an&255;a[al+13|0]=an>>>8&255;a[al+14|0]=an>>>16&255}an=at>>>24&15;if((an|0)==0|u^1){break}at=c[(c[2440392]|0)+(an<<2)>>2]|0;a[al+15|0]=at&255;a[al+16|0]=at>>>8&255;a[al+17|0]=at>>>16&255;break}else{at=c[2385344]|0;an=c[at+(ar<<2)>>2]|0;av=an>>>8&15;if(!((av|0)==0|u^1)){aw=c[(c[2440392]|0)+(av<<2)>>2]|0;a[al+15|0]=aw&255;a[al+16|0]=aw>>>8&255;a[al+17|0]=aw>>>16&255}aw=an>>>16&15;if(!((aw|0)==0|v^1)){av=c[(c[2440392]|0)+(aw<<2)>>2]|0;a[al+12|0]=av&255;a[al+13|0]=av>>>8&255;a[al+14|0]=av>>>16&255}av=an>>>24&15;if(!((av|0)==0|w^1)){an=c[(c[2440392]|0)+(av<<2)>>2]|0;a[al+9|0]=an&255;a[al+10|0]=an>>>8&255;a[al+11|0]=an>>>16&255}an=c[at+((ar|1)<<2)>>2]|0;ar=an&15;if(!((ar|0)==0|x^1)){at=c[(c[2440392]|0)+(ar<<2)>>2]|0;a[al+6|0]=at&255;a[al+7|0]=at>>>8&255;a[al+8|0]=at>>>16&255}at=an>>>16&15;if(!((at|0)==0|y^1)){ar=c[(c[2440392]|0)+(at<<2)>>2]|0;a[al+3|0]=ar&255;a[al+4|0]=ar>>>8&255;a[al+5|0]=ar>>>16&255}ar=an>>>24&15;if((ar|0)==0|t^1){break}an=c[(c[2440392]|0)+(ar<<2)>>2]|0;a[al]=an&255;a[al+1|0]=an>>>8&255;a[al+2|0]=an>>>16&255;break}}}while(0);am=O+1|0;if((am|0)>(N|0)){aj=ap;ak=ao;break}else{O=am;L=aq;J=ap;T=ao;al=al+p|0}}}if((ad|0)>(i|0)){_=36435;break}else{G=ad;H=aj;I=ak}}if((_|0)==36435){return}else if((_|0)==36436){return}}function czo(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0;b=c[3540994]|0;f=c[3528548]|0;g=f<<8;h=c[2385554]|0;do{if((h|0)>31){i=511}else{j=(h<<4)-1|0;if((j|0)>=0){i=j;break}return}}while(0);j=(i|0)>255;k=i&255;l=c[2385550]|0;m=c[2113042]|0;n=c[2113044]|0;o=m+512|0;p=c[2385552]|0;q=c[2113132]|0;r=p*3|0;s=c[2112968]|0;t=p+6|0;u=(t|0)>-1&(t|0)<(q|0);t=p+5|0;v=(t|0)>-1&(t|0)<(q|0);t=p+4|0;w=(t|0)>-1&(t|0)<(q|0);t=p+3|0;x=(t|0)>-1&(t|0)<(q|0);t=p+2|0;y=(t|0)>-1&(t|0)<(q|0);t=p+1|0;z=(t|0)>-1&(t|0)<(q|0);t=(p|0)>-1&(p|0)<(q|0);p=q*3|0;A=c[2415160]|0;B=c[2429858]|0;C=c[2430428]|0;D=c[2429718]|0;E=c[2430092]|0;F=c[3541046]|0;G=c[2430426]|0;H=0;I=0;J=0;L41988:while(1){K=(h|0)>16&(f|0)!=255;L=(h|0)<33;M=511-f|0;N=f+1|0;O=f-255|0;P=~f;Q=H;L41990:while(1){R=Q+l|0;S=R&511;do{if((S|0)<(m|0)){T=Q+m-S|0}else{if((S|0)>=(n|0)){T=o+Q-S|0;break}U=(Q|0)>255;V=U?16:0;W=Q&255;X=(Q|0)<256&j?255:k;if(!K){Y=V;Z=W;_=X;$=36461;break L41990}if(L){if(!U){$=36451;break L41990}if((Q|0)<(M|0)){T=M;break}else{$=36453;break L41990}}if(U){aa=O+W|0;if((aa|0)>=0){$=36456;break L41990}U=N+aa|0;if((U|0)<0){T=512;break}else{Y=0;Z=U;_=f;$=36461;break L41990}}else{if((W|0)<=(f|0)){$=36459;break L41990}U=W+P|0;if((U|0)>(f|0)){T=256;break}else{Y=16;Z=U;_=f;$=36461;break L41990}}}}while(0);if((T|0)>(i|0)){$=36506;break L41988}else{Q=T}}if(($|0)==36456){$=0;ab=f;ac=aa;ad=V;ae=N+Q-aa|0}else if(($|0)==36451){$=0;af=X;ah=W;ai=V;aj=Q+1-W+X|0;$=36462}else if(($|0)==36453){$=0;P=255-f|0;Y=V;Z=W-P|0;_=X-P|0;$=36461}else if(($|0)==36459){$=0;ab=f;ac=W;ad=V;ae=N+Q-W|0}if(($|0)==36461){$=0;P=Q+1+_-Z|0;if(L){af=_;ah=Z;ai=Y;aj=P;$=36462}else{ab=_;ac=Z;ad=Y;ae=P}}if(($|0)==36462){$=0;ab=(af|0)>(f|0)?f:af;ac=ah;ad=ai;ae=aj}P=((R|-512)^511)+n|0;O=(ab-ac|0)>(P|0)?P+ac|0:ab;if((ac|0)>(O|0)){ak=I;al=J}else{P=ac;M=-1;K=I;U=J;am=s+((ag(q,(S*3|0)-48|0)|0)+r)|0;while(1){an=d[b+(P+g)|0]|0;ao=(an>>>4)+ad|0;do{if((ao|0)==(M|0)){ap=U;aq=K;ar=M}else{as=ao<<1;at=e[A+((as|1)<<1)>>1]|0;au=(at<<12&983040|(e[A+(as<<1)>>1]|0))&B;do{if((at&8|0)==0){if((at&4|0)==0){av=au;break}av=C|au&1048572}else{av=G|au&1048568}}while(0);au=a[D+av|0]|0;as=au&255;if(au<<24>>24!=0){ap=as;aq=at;ar=ao;break}c[2385344]=E+(av<<7);c[2440392]=F+((at>>>4&4080)<<2);ap=as;aq=at;ar=ao}}while(0);do{if((ap|0)==0){ao=an<<1&30;as=(aq&2|0)==0?ao:ao^30;if((aq&1|0)==0){ao=c[2385344]|0;au=c[ao+(as<<2)>>2]|0;aw=au>>>8&15;if(!((aw|0)==0|t^1)){ax=c[(c[2440392]|0)+(aw<<2)>>2]|0;a[am]=ax&255;a[am+1|0]=ax>>>8&255;a[am+2|0]=ax>>>16&255}ax=au>>>16&15;if(!((ax|0)==0|z^1)){aw=c[(c[2440392]|0)+(ax<<2)>>2]|0;a[am+3|0]=aw&255;a[am+4|0]=aw>>>8&255;a[am+5|0]=aw>>>16&255}aw=au>>>24&15;if(!((aw|0)==0|y^1)){au=c[(c[2440392]|0)+(aw<<2)>>2]|0;a[am+6|0]=au&255;a[am+7|0]=au>>>8&255;a[am+8|0]=au>>>16&255}au=c[ao+((as|1)<<2)>>2]|0;ao=au&15;if(!((ao|0)==0|x^1)){aw=c[(c[2440392]|0)+(ao<<2)>>2]|0;a[am+9|0]=aw&255;a[am+10|0]=aw>>>8&255;a[am+11|0]=aw>>>16&255}aw=au>>>8&15;if(!((aw|0)==0|w^1)){ao=c[(c[2440392]|0)+(aw<<2)>>2]|0;a[am+12|0]=ao&255;a[am+13|0]=ao>>>8&255;a[am+14|0]=ao>>>16&255}ao=au>>>16&15;if(!((ao|0)==0|v^1)){aw=c[(c[2440392]|0)+(ao<<2)>>2]|0;a[am+15|0]=aw&255;a[am+16|0]=aw>>>8&255;a[am+17|0]=aw>>>16&255}aw=au>>>24&15;if((aw|0)==0|u^1){break}au=c[(c[2440392]|0)+(aw<<2)>>2]|0;a[am+18|0]=au&255;a[am+19|0]=au>>>8&255;a[am+20|0]=au>>>16&255;break}else{au=c[2385344]|0;aw=c[au+(as<<2)>>2]|0;ao=aw>>>8&15;if(!((ao|0)==0|u^1)){ax=c[(c[2440392]|0)+(ao<<2)>>2]|0;a[am+18|0]=ax&255;a[am+19|0]=ax>>>8&255;a[am+20|0]=ax>>>16&255}ax=aw>>>16&15;if(!((ax|0)==0|v^1)){ao=c[(c[2440392]|0)+(ax<<2)>>2]|0;a[am+15|0]=ao&255;a[am+16|0]=ao>>>8&255;a[am+17|0]=ao>>>16&255}ao=aw>>>24&15;if(!((ao|0)==0|w^1)){aw=c[(c[2440392]|0)+(ao<<2)>>2]|0;a[am+12|0]=aw&255;a[am+13|0]=aw>>>8&255;a[am+14|0]=aw>>>16&255}aw=c[au+((as|1)<<2)>>2]|0;as=aw&15;if(!((as|0)==0|x^1)){au=c[(c[2440392]|0)+(as<<2)>>2]|0;a[am+9|0]=au&255;a[am+10|0]=au>>>8&255;a[am+11|0]=au>>>16&255}au=aw>>>8&15;if(!((au|0)==0|y^1)){as=c[(c[2440392]|0)+(au<<2)>>2]|0;a[am+6|0]=as&255;a[am+7|0]=as>>>8&255;a[am+8|0]=as>>>16&255}as=aw>>>16&15;if(!((as|0)==0|z^1)){au=c[(c[2440392]|0)+(as<<2)>>2]|0;a[am+3|0]=au&255;a[am+4|0]=au>>>8&255;a[am+5|0]=au>>>16&255}au=aw>>>24&15;if((au|0)==0|t^1){break}aw=c[(c[2440392]|0)+(au<<2)>>2]|0;a[am]=aw&255;a[am+1|0]=aw>>>8&255;a[am+2|0]=aw>>>16&255;break}}}while(0);an=P+1|0;if((an|0)>(O|0)){ak=aq;al=ap;break}else{P=an;M=ar;K=aq;U=ap;am=am+p|0}}}if((ae|0)>(i|0)){$=36504;break}else{H=ae;I=ak;J=al}}if(($|0)==36504){return}else if(($|0)==36506){return}}function czp(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0;b=c[3540994]|0;f=c[3528548]|0;g=f<<8;h=c[2385554]|0;do{if((h|0)>31){i=511}else{j=(h<<4)-1|0;if((j|0)>=0){i=j;break}return}}while(0);j=(i|0)>255;k=i&255;l=c[2385550]|0;m=c[2113042]|0;n=c[2113044]|0;o=m+512|0;p=c[2385552]|0;q=c[2113132]|0;r=p*3|0;s=c[2112968]|0;t=p+7|0;u=(t|0)>-1&(t|0)<(q|0);t=p+6|0;v=(t|0)>-1&(t|0)<(q|0);t=p+5|0;w=(t|0)>-1&(t|0)<(q|0);t=p+4|0;x=(t|0)>-1&(t|0)<(q|0);t=p+3|0;y=(t|0)>-1&(t|0)<(q|0);t=p+2|0;z=(t|0)>-1&(t|0)<(q|0);t=p+1|0;A=(t|0)>-1&(t|0)<(q|0);t=(p|0)>-1&(p|0)<(q|0);p=q*3|0;B=c[2415160]|0;C=c[2429858]|0;D=c[2430428]|0;E=c[2429718]|0;F=c[2430092]|0;G=c[3541046]|0;H=c[2430426]|0;I=0;J=0;K=0;L42085:while(1){L=(h|0)>16&(f|0)!=255;M=(h|0)<33;N=511-f|0;O=f+1|0;P=f-255|0;Q=~f;R=I;L42087:while(1){S=R+l|0;T=S&511;do{if((T|0)<(m|0)){U=R+m-T|0}else{if((T|0)>=(n|0)){U=o+R-T|0;break}V=(R|0)>255;W=V?16:0;X=R&255;Y=(R|0)<256&j?255:k;if(!L){Z=W;_=X;$=Y;aa=36530;break L42087}if(M){if(!V){aa=36520;break L42087}if((R|0)<(N|0)){U=N;break}else{aa=36522;break L42087}}if(V){ab=P+X|0;if((ab|0)>=0){aa=36525;break L42087}V=O+ab|0;if((V|0)<0){U=512;break}else{Z=0;_=V;$=f;aa=36530;break L42087}}else{if((X|0)<=(f|0)){aa=36528;break L42087}V=X+Q|0;if((V|0)>(f|0)){U=256;break}else{Z=16;_=V;$=f;aa=36530;break L42087}}}}while(0);if((U|0)>(i|0)){aa=36578;break L42085}else{R=U}}if((aa|0)==36522){aa=0;Q=255-f|0;Z=W;_=X-Q|0;$=Y-Q|0;aa=36530}else if((aa|0)==36520){aa=0;ac=Y;ad=X;ae=W;af=R+1-X+Y|0;aa=36531}else if((aa|0)==36525){aa=0;ah=f;ai=ab;aj=W;ak=O+R-ab|0}else if((aa|0)==36528){aa=0;ah=f;ai=X;aj=W;ak=O+R-X|0}if((aa|0)==36530){aa=0;Q=R+1+$-_|0;if(M){ac=$;ad=_;ae=Z;af=Q;aa=36531}else{ah=$;ai=_;aj=Z;ak=Q}}if((aa|0)==36531){aa=0;ah=(ac|0)>(f|0)?f:ac;ai=ad;aj=ae;ak=af}Q=((S|-512)^511)+n|0;P=(ah-ai|0)>(Q|0)?Q+ai|0:ah;if((ai|0)>(P|0)){al=J;am=K}else{Q=ai;N=-1;L=J;V=K;an=s+((ag(q,(T*3|0)-48|0)|0)+r)|0;while(1){ao=d[b+(Q+g)|0]|0;ap=(ao>>>4)+aj|0;do{if((ap|0)==(N|0)){aq=V;ar=L;as=N}else{at=ap<<1;au=e[B+((at|1)<<1)>>1]|0;av=(au<<12&983040|(e[B+(at<<1)>>1]|0))&C;do{if((au&8|0)==0){if((au&4|0)==0){aw=av;break}aw=D|av&1048572}else{aw=H|av&1048568}}while(0);av=a[E+aw|0]|0;at=av&255;if(av<<24>>24!=0){aq=at;ar=au;as=ap;break}c[2385344]=F+(aw<<7);c[2440392]=G+((au>>>4&4080)<<2);aq=at;ar=au;as=ap}}while(0);do{if((aq|0)==0){ap=ao<<1&30;at=(ar&2|0)==0?ap:ap^30;if((ar&1|0)==0){ap=c[2385344]|0;av=c[ap+(at<<2)>>2]|0;ax=av&15;if(!((ax|0)==0|t^1)){ay=c[(c[2440392]|0)+(ax<<2)>>2]|0;a[an]=ay&255;a[an+1|0]=ay>>>8&255;a[an+2|0]=ay>>>16&255}ay=av>>>8&15;if(!((ay|0)==0|A^1)){ax=c[(c[2440392]|0)+(ay<<2)>>2]|0;a[an+3|0]=ax&255;a[an+4|0]=ax>>>8&255;a[an+5|0]=ax>>>16&255}ax=av>>>16&15;if(!((ax|0)==0|z^1)){ay=c[(c[2440392]|0)+(ax<<2)>>2]|0;a[an+6|0]=ay&255;a[an+7|0]=ay>>>8&255;a[an+8|0]=ay>>>16&255}ay=av>>>24&15;if(!((ay|0)==0|y^1)){av=c[(c[2440392]|0)+(ay<<2)>>2]|0;a[an+9|0]=av&255;a[an+10|0]=av>>>8&255;a[an+11|0]=av>>>16&255}av=c[ap+((at|1)<<2)>>2]|0;ap=av&15;if(!((ap|0)==0|x^1)){ay=c[(c[2440392]|0)+(ap<<2)>>2]|0;a[an+12|0]=ay&255;a[an+13|0]=ay>>>8&255;a[an+14|0]=ay>>>16&255}ay=av>>>8&15;if(!((ay|0)==0|w^1)){ap=c[(c[2440392]|0)+(ay<<2)>>2]|0;a[an+15|0]=ap&255;a[an+16|0]=ap>>>8&255;a[an+17|0]=ap>>>16&255}ap=av>>>16&15;if(!((ap|0)==0|v^1)){ay=c[(c[2440392]|0)+(ap<<2)>>2]|0;a[an+18|0]=ay&255;a[an+19|0]=ay>>>8&255;a[an+20|0]=ay>>>16&255}ay=av>>>24&15;if((ay|0)==0|u^1){break}av=c[(c[2440392]|0)+(ay<<2)>>2]|0;a[an+21|0]=av&255;a[an+22|0]=av>>>8&255;a[an+23|0]=av>>>16&255;break}else{av=c[2385344]|0;ay=c[av+(at<<2)>>2]|0;ap=ay&15;if(!((ap|0)==0|u^1)){ax=c[(c[2440392]|0)+(ap<<2)>>2]|0;a[an+21|0]=ax&255;a[an+22|0]=ax>>>8&255;a[an+23|0]=ax>>>16&255}ax=ay>>>8&15;if(!((ax|0)==0|v^1)){ap=c[(c[2440392]|0)+(ax<<2)>>2]|0;a[an+18|0]=ap&255;a[an+19|0]=ap>>>8&255;a[an+20|0]=ap>>>16&255}ap=ay>>>16&15;if(!((ap|0)==0|w^1)){ax=c[(c[2440392]|0)+(ap<<2)>>2]|0;a[an+15|0]=ax&255;a[an+16|0]=ax>>>8&255;a[an+17|0]=ax>>>16&255}ax=ay>>>24&15;if(!((ax|0)==0|x^1)){ay=c[(c[2440392]|0)+(ax<<2)>>2]|0;a[an+12|0]=ay&255;a[an+13|0]=ay>>>8&255;a[an+14|0]=ay>>>16&255}ay=c[av+((at|1)<<2)>>2]|0;at=ay&15;if(!((at|0)==0|y^1)){av=c[(c[2440392]|0)+(at<<2)>>2]|0;a[an+9|0]=av&255;a[an+10|0]=av>>>8&255;a[an+11|0]=av>>>16&255}av=ay>>>8&15;if(!((av|0)==0|z^1)){at=c[(c[2440392]|0)+(av<<2)>>2]|0;a[an+6|0]=at&255;a[an+7|0]=at>>>8&255;a[an+8|0]=at>>>16&255}at=ay>>>16&15;if(!((at|0)==0|A^1)){av=c[(c[2440392]|0)+(at<<2)>>2]|0;a[an+3|0]=av&255;a[an+4|0]=av>>>8&255;a[an+5|0]=av>>>16&255}av=ay>>>24&15;if((av|0)==0|t^1){break}ay=c[(c[2440392]|0)+(av<<2)>>2]|0;a[an]=ay&255;a[an+1|0]=ay>>>8&255;a[an+2|0]=ay>>>16&255;break}}}while(0);ao=Q+1|0;if((ao|0)>(P|0)){al=ar;am=aq;break}else{Q=ao;N=as;L=ar;V=aq;an=an+p|0}}}if((ak|0)>(i|0)){aa=36577;break}else{I=ak;J=al;K=am}}if((aa|0)==36577){return}else if((aa|0)==36578){return}}function czq(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0;b=c[3540994]|0;f=c[3528548]|0;g=f<<8;h=c[2385554]|0;do{if((h|0)>31){i=511}else{j=(h<<4)-1|0;if((j|0)>=0){i=j;break}return}}while(0);j=(i|0)>255;k=i&255;l=c[2385550]|0;m=c[2113042]|0;n=c[2113044]|0;o=m+512|0;p=c[2385552]|0;q=c[2113132]|0;r=p*3|0;s=c[2112968]|0;t=p+8|0;u=(t|0)>-1&(t|0)<(q|0);t=p+7|0;v=(t|0)>-1&(t|0)<(q|0);t=p+6|0;w=(t|0)>-1&(t|0)<(q|0);t=p+5|0;x=(t|0)>-1&(t|0)<(q|0);t=p+4|0;y=(t|0)>-1&(t|0)<(q|0);t=p+3|0;z=(t|0)>-1&(t|0)<(q|0);t=p+2|0;A=(t|0)>-1&(t|0)<(q|0);t=p+1|0;B=(t|0)>-1&(t|0)<(q|0);t=(p|0)>-1&(p|0)<(q|0);p=q*3|0;C=c[2415160]|0;D=c[2429858]|0;E=c[2430428]|0;F=c[2429718]|0;G=c[2430092]|0;H=c[3541046]|0;I=c[2430426]|0;J=0;K=0;L=0;L42188:while(1){M=(h|0)>16&(f|0)!=255;N=(h|0)<33;O=511-f|0;P=f+1|0;Q=f-255|0;R=~f;S=J;L42190:while(1){T=S+l|0;U=T&511;do{if((U|0)<(m|0)){V=S+m-U|0}else{if((U|0)>=(n|0)){V=o+S-U|0;break}W=(S|0)>255;X=W?16:0;Y=S&255;Z=(S|0)<256&j?255:k;if(!M){_=X;$=Y;aa=Z;ab=36603;break L42190}if(N){if(!W){ab=36593;break L42190}if((S|0)<(O|0)){V=O;break}else{ab=36595;break L42190}}if(W){ac=Q+Y|0;if((ac|0)>=0){ab=36598;break L42190}W=P+ac|0;if((W|0)<0){V=512;break}else{_=0;$=W;aa=f;ab=36603;break L42190}}else{if((Y|0)<=(f|0)){ab=36601;break L42190}W=Y+R|0;if((W|0)>(f|0)){V=256;break}else{_=16;$=W;aa=f;ab=36603;break L42190}}}}while(0);if((V|0)>(i|0)){ab=36656;break L42188}else{S=V}}if((ab|0)==36595){ab=0;R=255-f|0;_=X;$=Y-R|0;aa=Z-R|0;ab=36603}else if((ab|0)==36601){ab=0;ad=f;ae=Y;af=X;ah=P+S-Y|0}else if((ab|0)==36598){ab=0;ad=f;ae=ac;af=X;ah=P+S-ac|0}else if((ab|0)==36593){ab=0;ai=Z;aj=Y;ak=X;al=S+1-Y+Z|0;ab=36604}if((ab|0)==36603){ab=0;R=S+1+aa-$|0;if(N){ai=aa;aj=$;ak=_;al=R;ab=36604}else{ad=aa;ae=$;af=_;ah=R}}if((ab|0)==36604){ab=0;ad=(ai|0)>(f|0)?f:ai;ae=aj;af=ak;ah=al}R=((T|-512)^511)+n|0;Q=(ad-ae|0)>(R|0)?R+ae|0:ad;if((ae|0)>(Q|0)){am=K;an=L}else{R=ae;O=-1;M=K;W=L;ao=s+((ag(q,(U*3|0)-48|0)|0)+r)|0;while(1){ap=d[b+(R+g)|0]|0;aq=(ap>>>4)+af|0;do{if((aq|0)==(O|0)){ar=W;as=M;at=O}else{au=aq<<1;av=e[C+((au|1)<<1)>>1]|0;aw=(av<<12&983040|(e[C+(au<<1)>>1]|0))&D;do{if((av&8|0)==0){if((av&4|0)==0){ax=aw;break}ax=E|aw&1048572}else{ax=I|aw&1048568}}while(0);aw=a[F+ax|0]|0;au=aw&255;if(aw<<24>>24!=0){ar=au;as=av;at=aq;break}c[2385344]=G+(ax<<7);c[2440392]=H+((av>>>4&4080)<<2);ar=au;as=av;at=aq}}while(0);do{if((ar|0)==0){aq=ap<<1&30;au=(as&2|0)==0?aq:aq^30;if((as&1|0)==0){aq=c[2385344]|0;aw=c[aq+(au<<2)>>2]|0;ay=aw&15;if(!((ay|0)==0|t^1)){az=c[(c[2440392]|0)+(ay<<2)>>2]|0;a[ao]=az&255;a[ao+1|0]=az>>>8&255;a[ao+2|0]=az>>>16&255}az=aw>>>8&15;if(!((az|0)==0|B^1)){ay=c[(c[2440392]|0)+(az<<2)>>2]|0;a[ao+3|0]=ay&255;a[ao+4|0]=ay>>>8&255;a[ao+5|0]=ay>>>16&255}ay=aw>>>16&15;if(!((ay|0)==0|A^1)){az=c[(c[2440392]|0)+(ay<<2)>>2]|0;a[ao+6|0]=az&255;a[ao+7|0]=az>>>8&255;a[ao+8|0]=az>>>16&255}az=aw>>>24&15;if(!((az|0)==0|z^1)){aw=c[(c[2440392]|0)+(az<<2)>>2]|0;a[ao+9|0]=aw&255;a[ao+10|0]=aw>>>8&255;a[ao+11|0]=aw>>>16&255}aw=c[aq+((au|1)<<2)>>2]|0;aq=aw&15;if(!((aq|0)==0|y^1)){az=c[(c[2440392]|0)+(aq<<2)>>2]|0;a[ao+12|0]=az&255;a[ao+13|0]=az>>>8&255;a[ao+14|0]=az>>>16&255}az=aw>>>4&15;if(!((az|0)==0|x^1)){aq=c[(c[2440392]|0)+(az<<2)>>2]|0;a[ao+15|0]=aq&255;a[ao+16|0]=aq>>>8&255;a[ao+17|0]=aq>>>16&255}aq=aw>>>8&15;if(!((aq|0)==0|w^1)){az=c[(c[2440392]|0)+(aq<<2)>>2]|0;a[ao+18|0]=az&255;a[ao+19|0]=az>>>8&255;a[ao+20|0]=az>>>16&255}az=aw>>>16&15;if(!((az|0)==0|v^1)){aq=c[(c[2440392]|0)+(az<<2)>>2]|0;a[ao+21|0]=aq&255;a[ao+22|0]=aq>>>8&255;a[ao+23|0]=aq>>>16&255}aq=aw>>>24&15;if((aq|0)==0|u^1){break}aw=c[(c[2440392]|0)+(aq<<2)>>2]|0;a[ao+24|0]=aw&255;a[ao+25|0]=aw>>>8&255;a[ao+26|0]=aw>>>16&255;break}else{aw=c[2385344]|0;aq=c[aw+(au<<2)>>2]|0;az=aq&15;if(!((az|0)==0|u^1)){ay=c[(c[2440392]|0)+(az<<2)>>2]|0;a[ao+24|0]=ay&255;a[ao+25|0]=ay>>>8&255;a[ao+26|0]=ay>>>16&255}ay=aq>>>8&15;if(!((ay|0)==0|v^1)){az=c[(c[2440392]|0)+(ay<<2)>>2]|0;a[ao+21|0]=az&255;a[ao+22|0]=az>>>8&255;a[ao+23|0]=az>>>16&255}az=aq>>>16&15;if(!((az|0)==0|w^1)){ay=c[(c[2440392]|0)+(az<<2)>>2]|0;a[ao+18|0]=ay&255;a[ao+19|0]=ay>>>8&255;a[ao+20|0]=ay>>>16&255}ay=aq>>>24&15;if(!((ay|0)==0|x^1)){aq=c[(c[2440392]|0)+(ay<<2)>>2]|0;a[ao+15|0]=aq&255;a[ao+16|0]=aq>>>8&255;a[ao+17|0]=aq>>>16&255}aq=c[aw+((au|1)<<2)>>2]|0;au=aq&15;if(!((au|0)==0|y^1)){aw=c[(c[2440392]|0)+(au<<2)>>2]|0;a[ao+12|0]=aw&255;a[ao+13|0]=aw>>>8&255;a[ao+14|0]=aw>>>16&255}aw=aq>>>4&15;if(!((aw|0)==0|z^1)){au=c[(c[2440392]|0)+(aw<<2)>>2]|0;a[ao+9|0]=au&255;a[ao+10|0]=au>>>8&255;a[ao+11|0]=au>>>16&255}au=aq>>>8&15;if(!((au|0)==0|A^1)){aw=c[(c[2440392]|0)+(au<<2)>>2]|0;a[ao+6|0]=aw&255;a[ao+7|0]=aw>>>8&255;a[ao+8|0]=aw>>>16&255}aw=aq>>>16&15;if(!((aw|0)==0|B^1)){au=c[(c[2440392]|0)+(aw<<2)>>2]|0;a[ao+3|0]=au&255;a[ao+4|0]=au>>>8&255;a[ao+5|0]=au>>>16&255}au=aq>>>24&15;if((au|0)==0|t^1){break}aq=c[(c[2440392]|0)+(au<<2)>>2]|0;a[ao]=aq&255;a[ao+1|0]=aq>>>8&255;a[ao+2|0]=aq>>>16&255;break}}}while(0);ap=R+1|0;if((ap|0)>(Q|0)){am=as;an=ar;break}else{R=ap;O=at;M=as;W=ar;ao=ao+p|0}}}if((ah|0)>(i|0)){ab=36654;break}else{J=ah;K=am;L=an}}if((ab|0)==36654){return}else if((ab|0)==36656){return}}function czr(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0;b=c[3540994]|0;f=c[3528548]|0;g=f<<8;h=c[2385554]|0;do{if((h|0)>31){i=511}else{j=(h<<4)-1|0;if((j|0)>=0){i=j;break}return}}while(0);j=(i|0)>255;k=i&255;l=c[2385550]|0;m=c[2113042]|0;n=c[2113044]|0;o=m+512|0;p=c[2385552]|0;q=c[2113132]|0;r=p*3|0;s=c[2112968]|0;t=p+9|0;u=(t|0)>-1&(t|0)<(q|0);t=p+8|0;v=(t|0)>-1&(t|0)<(q|0);t=p+7|0;w=(t|0)>-1&(t|0)<(q|0);t=p+6|0;x=(t|0)>-1&(t|0)<(q|0);t=p+5|0;y=(t|0)>-1&(t|0)<(q|0);t=p+4|0;z=(t|0)>-1&(t|0)<(q|0);t=p+3|0;A=(t|0)>-1&(t|0)<(q|0);t=p+2|0;B=(t|0)>-1&(t|0)<(q|0);t=p+1|0;C=(t|0)>-1&(t|0)<(q|0);t=(p|0)>-1&(p|0)<(q|0);p=q*3|0;D=c[2415160]|0;E=c[2429858]|0;F=c[2430428]|0;G=c[2429718]|0;H=c[2430092]|0;I=c[3541046]|0;J=c[2430426]|0;K=0;L=0;M=0;L42297:while(1){N=(h|0)>16&(f|0)!=255;O=(h|0)<33;P=511-f|0;Q=f+1|0;R=f-255|0;S=~f;T=K;L42299:while(1){U=T+l|0;V=U&511;do{if((V|0)<(m|0)){W=T+m-V|0}else{if((V|0)>=(n|0)){W=o+T-V|0;break}X=(T|0)>255;Y=X?16:0;Z=T&255;_=(T|0)<256&j?255:k;if(!N){$=Y;aa=Z;ab=_;ac=36680;break L42299}if(O){if(!X){ac=36670;break L42299}if((T|0)<(P|0)){W=P;break}else{ac=36672;break L42299}}if(X){ad=R+Z|0;if((ad|0)>=0){ac=36675;break L42299}X=Q+ad|0;if((X|0)<0){W=512;break}else{$=0;aa=X;ab=f;ac=36680;break L42299}}else{if((Z|0)<=(f|0)){ac=36678;break L42299}X=Z+S|0;if((X|0)>(f|0)){W=256;break}else{$=16;aa=X;ab=f;ac=36680;break L42299}}}}while(0);if((W|0)>(i|0)){ac=36735;break L42297}else{T=W}}if((ac|0)==36672){ac=0;S=255-f|0;$=Y;aa=Z-S|0;ab=_-S|0;ac=36680}else if((ac|0)==36678){ac=0;ae=f;af=Z;ah=Y;ai=Q+T-Z|0}else if((ac|0)==36675){ac=0;ae=f;af=ad;ah=Y;ai=Q+T-ad|0}else if((ac|0)==36670){ac=0;aj=_;ak=Z;al=Y;am=T+1-Z+_|0;ac=36681}if((ac|0)==36680){ac=0;S=T+1+ab-aa|0;if(O){aj=ab;ak=aa;al=$;am=S;ac=36681}else{ae=ab;af=aa;ah=$;ai=S}}if((ac|0)==36681){ac=0;ae=(aj|0)>(f|0)?f:aj;af=ak;ah=al;ai=am}S=((U|-512)^511)+n|0;R=(ae-af|0)>(S|0)?S+af|0:ae;if((af|0)>(R|0)){an=L;ao=M}else{S=af;P=-1;N=L;X=M;ap=s+((ag(q,(V*3|0)-48|0)|0)+r)|0;while(1){aq=d[b+(S+g)|0]|0;ar=(aq>>>4)+ah|0;do{if((ar|0)==(P|0)){as=X;at=N;au=P}else{av=ar<<1;aw=e[D+((av|1)<<1)>>1]|0;ax=(aw<<12&983040|(e[D+(av<<1)>>1]|0))&E;do{if((aw&8|0)==0){if((aw&4|0)==0){ay=ax;break}ay=F|ax&1048572}else{ay=J|ax&1048568}}while(0);ax=a[G+ay|0]|0;av=ax&255;if(ax<<24>>24!=0){as=av;at=aw;au=ar;break}c[2385344]=H+(ay<<7);c[2440392]=I+((aw>>>4&4080)<<2);as=av;at=aw;au=ar}}while(0);do{if((as|0)==0){ar=aq<<1&30;av=(at&2|0)==0?ar:ar^30;if((at&1|0)==0){ar=c[2385344]|0;ax=c[ar+(av<<2)>>2]|0;az=ax&15;if(!((az|0)==0|t^1)){aA=c[(c[2440392]|0)+(az<<2)>>2]|0;a[ap]=aA&255;a[ap+1|0]=aA>>>8&255;a[ap+2|0]=aA>>>16&255}aA=ax>>>8&15;if(!((aA|0)==0|C^1)){az=c[(c[2440392]|0)+(aA<<2)>>2]|0;a[ap+3|0]=az&255;a[ap+4|0]=az>>>8&255;a[ap+5|0]=az>>>16&255}az=ax>>>12&15;if(!((az|0)==0|B^1)){aA=c[(c[2440392]|0)+(az<<2)>>2]|0;a[ap+6|0]=aA&255;a[ap+7|0]=aA>>>8&255;a[ap+8|0]=aA>>>16&255}aA=ax>>>16&15;if(!((aA|0)==0|A^1)){az=c[(c[2440392]|0)+(aA<<2)>>2]|0;a[ap+9|0]=az&255;a[ap+10|0]=az>>>8&255;a[ap+11|0]=az>>>16&255}az=ax>>>24&15;if(!((az|0)==0|z^1)){ax=c[(c[2440392]|0)+(az<<2)>>2]|0;a[ap+12|0]=ax&255;a[ap+13|0]=ax>>>8&255;a[ap+14|0]=ax>>>16&255}ax=c[ar+((av|1)<<2)>>2]|0;ar=ax&15;if(!((ar|0)==0|y^1)){az=c[(c[2440392]|0)+(ar<<2)>>2]|0;a[ap+15|0]=az&255;a[ap+16|0]=az>>>8&255;a[ap+17|0]=az>>>16&255}az=ax>>>4&15;if(!((az|0)==0|x^1)){ar=c[(c[2440392]|0)+(az<<2)>>2]|0;a[ap+18|0]=ar&255;a[ap+19|0]=ar>>>8&255;a[ap+20|0]=ar>>>16&255}ar=ax>>>8&15;if(!((ar|0)==0|w^1)){az=c[(c[2440392]|0)+(ar<<2)>>2]|0;a[ap+21|0]=az&255;a[ap+22|0]=az>>>8&255;a[ap+23|0]=az>>>16&255}az=ax>>>16&15;if(!((az|0)==0|v^1)){ar=c[(c[2440392]|0)+(az<<2)>>2]|0;a[ap+24|0]=ar&255;a[ap+25|0]=ar>>>8&255;a[ap+26|0]=ar>>>16&255}ar=ax>>>24&15;if((ar|0)==0|u^1){break}ax=c[(c[2440392]|0)+(ar<<2)>>2]|0;a[ap+27|0]=ax&255;a[ap+28|0]=ax>>>8&255;a[ap+29|0]=ax>>>16&255;break}else{ax=c[2385344]|0;ar=c[ax+(av<<2)>>2]|0;az=ar&15;if(!((az|0)==0|u^1)){aA=c[(c[2440392]|0)+(az<<2)>>2]|0;a[ap+27|0]=aA&255;a[ap+28|0]=aA>>>8&255;a[ap+29|0]=aA>>>16&255}aA=ar>>>8&15;if(!((aA|0)==0|v^1)){az=c[(c[2440392]|0)+(aA<<2)>>2]|0;a[ap+24|0]=az&255;a[ap+25|0]=az>>>8&255;a[ap+26|0]=az>>>16&255}az=ar>>>12&15;if(!((az|0)==0|w^1)){aA=c[(c[2440392]|0)+(az<<2)>>2]|0;a[ap+21|0]=aA&255;a[ap+22|0]=aA>>>8&255;a[ap+23|0]=aA>>>16&255}aA=ar>>>16&15;if(!((aA|0)==0|x^1)){az=c[(c[2440392]|0)+(aA<<2)>>2]|0;a[ap+18|0]=az&255;a[ap+19|0]=az>>>8&255;a[ap+20|0]=az>>>16&255}az=ar>>>24&15;if(!((az|0)==0|y^1)){ar=c[(c[2440392]|0)+(az<<2)>>2]|0;a[ap+15|0]=ar&255;a[ap+16|0]=ar>>>8&255;a[ap+17|0]=ar>>>16&255}ar=c[ax+((av|1)<<2)>>2]|0;av=ar&15;if(!((av|0)==0|z^1)){ax=c[(c[2440392]|0)+(av<<2)>>2]|0;a[ap+12|0]=ax&255;a[ap+13|0]=ax>>>8&255;a[ap+14|0]=ax>>>16&255}ax=ar>>>4&15;if(!((ax|0)==0|A^1)){av=c[(c[2440392]|0)+(ax<<2)>>2]|0;a[ap+9|0]=av&255;a[ap+10|0]=av>>>8&255;a[ap+11|0]=av>>>16&255}av=ar>>>8&15;if(!((av|0)==0|B^1)){ax=c[(c[2440392]|0)+(av<<2)>>2]|0;a[ap+6|0]=ax&255;a[ap+7|0]=ax>>>8&255;a[ap+8|0]=ax>>>16&255}ax=ar>>>16&15;if(!((ax|0)==0|C^1)){av=c[(c[2440392]|0)+(ax<<2)>>2]|0;a[ap+3|0]=av&255;a[ap+4|0]=av>>>8&255;a[ap+5|0]=av>>>16&255}av=ar>>>24&15;if((av|0)==0|t^1){break}ar=c[(c[2440392]|0)+(av<<2)>>2]|0;a[ap]=ar&255;a[ap+1|0]=ar>>>8&255;a[ap+2|0]=ar>>>16&255;break}}}while(0);aq=S+1|0;if((aq|0)>(R|0)){an=at;ao=as;break}else{S=aq;P=au;N=at;X=as;ap=ap+p|0}}}if((ai|0)>(i|0)){ac=36737;break}else{K=ai;L=an;M=ao}}if((ac|0)==36735){return}else if((ac|0)==36737){return}}function czs(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0;b=c[3540994]|0;f=c[3528548]|0;g=f<<8;h=c[2385554]|0;do{if((h|0)>31){i=511}else{j=(h<<4)-1|0;if((j|0)>=0){i=j;break}return}}while(0);j=(i|0)>255;k=i&255;l=c[2385550]|0;m=c[2113042]|0;n=c[2113044]|0;o=m+512|0;p=c[2385552]|0;q=c[2113132]|0;r=p*3|0;s=c[2112968]|0;t=p+10|0;u=(t|0)>-1&(t|0)<(q|0);t=p+9|0;v=(t|0)>-1&(t|0)<(q|0);t=p+8|0;w=(t|0)>-1&(t|0)<(q|0);t=p+7|0;x=(t|0)>-1&(t|0)<(q|0);t=p+6|0;y=(t|0)>-1&(t|0)<(q|0);t=p+5|0;z=(t|0)>-1&(t|0)<(q|0);t=p+4|0;A=(t|0)>-1&(t|0)<(q|0);t=p+3|0;B=(t|0)>-1&(t|0)<(q|0);t=p+2|0;C=(t|0)>-1&(t|0)<(q|0);t=p+1|0;D=(t|0)>-1&(t|0)<(q|0);t=(p|0)>-1&(p|0)<(q|0);p=q*3|0;E=c[2415160]|0;F=c[2429858]|0;G=c[2430428]|0;H=c[2429718]|0;I=c[2430092]|0;J=c[3541046]|0;K=c[2430426]|0;L=0;M=0;N=0;L42412:while(1){O=(h|0)>16&(f|0)!=255;P=(h|0)<33;Q=511-f|0;R=f+1|0;S=f-255|0;T=~f;U=L;L42414:while(1){V=U+l|0;W=V&511;do{if((W|0)<(m|0)){X=U+m-W|0}else{if((W|0)>=(n|0)){X=o+U-W|0;break}Y=(U|0)>255;Z=Y?16:0;_=U&255;$=(U|0)<256&j?255:k;if(!O){aa=Z;ab=_;ac=$;ad=36761;break L42414}if(P){if(!Y){ad=36751;break L42414}if((U|0)<(Q|0)){X=Q;break}else{ad=36753;break L42414}}if(Y){ae=S+_|0;if((ae|0)>=0){ad=36756;break L42414}Y=R+ae|0;if((Y|0)<0){X=512;break}else{aa=0;ab=Y;ac=f;ad=36761;break L42414}}else{if((_|0)<=(f|0)){ad=36759;break L42414}Y=_+T|0;if((Y|0)>(f|0)){X=256;break}else{aa=16;ab=Y;ac=f;ad=36761;break L42414}}}}while(0);if((X|0)>(i|0)){ad=36820;break L42412}else{U=X}}if((ad|0)==36756){ad=0;af=f;ah=ae;ai=Z;aj=R+U-ae|0}else if((ad|0)==36753){ad=0;T=255-f|0;aa=Z;ab=_-T|0;ac=$-T|0;ad=36761}else if((ad|0)==36751){ad=0;ak=$;al=_;am=Z;an=U+1-_+$|0;ad=36762}else if((ad|0)==36759){ad=0;af=f;ah=_;ai=Z;aj=R+U-_|0}if((ad|0)==36761){ad=0;T=U+1+ac-ab|0;if(P){ak=ac;al=ab;am=aa;an=T;ad=36762}else{af=ac;ah=ab;ai=aa;aj=T}}if((ad|0)==36762){ad=0;af=(ak|0)>(f|0)?f:ak;ah=al;ai=am;aj=an}T=((V|-512)^511)+n|0;S=(af-ah|0)>(T|0)?T+ah|0:af;if((ah|0)>(S|0)){ao=M;ap=N}else{T=ah;Q=-1;O=M;Y=N;aq=s+((ag(q,(W*3|0)-48|0)|0)+r)|0;while(1){ar=d[b+(T+g)|0]|0;as=(ar>>>4)+ai|0;do{if((as|0)==(Q|0)){at=Y;au=O;av=Q}else{aw=as<<1;ax=e[E+((aw|1)<<1)>>1]|0;ay=(ax<<12&983040|(e[E+(aw<<1)>>1]|0))&F;do{if((ax&8|0)==0){if((ax&4|0)==0){az=ay;break}az=G|ay&1048572}else{az=K|ay&1048568}}while(0);ay=a[H+az|0]|0;aw=ay&255;if(ay<<24>>24!=0){at=aw;au=ax;av=as;break}c[2385344]=I+(az<<7);c[2440392]=J+((ax>>>4&4080)<<2);at=aw;au=ax;av=as}}while(0);do{if((at|0)==0){as=ar<<1&30;aw=(au&2|0)==0?as:as^30;if((au&1|0)==0){as=c[2385344]|0;ay=c[as+(aw<<2)>>2]|0;aA=ay&15;if(!((aA|0)==0|t^1)){aB=c[(c[2440392]|0)+(aA<<2)>>2]|0;a[aq]=aB&255;a[aq+1|0]=aB>>>8&255;a[aq+2|0]=aB>>>16&255}aB=ay>>>8&15;if(!((aB|0)==0|D^1)){aA=c[(c[2440392]|0)+(aB<<2)>>2]|0;a[aq+3|0]=aA&255;a[aq+4|0]=aA>>>8&255;a[aq+5|0]=aA>>>16&255}aA=ay>>>12&15;if(!((aA|0)==0|C^1)){aB=c[(c[2440392]|0)+(aA<<2)>>2]|0;a[aq+6|0]=aB&255;a[aq+7|0]=aB>>>8&255;a[aq+8|0]=aB>>>16&255}aB=ay>>>16&15;if(!((aB|0)==0|B^1)){aA=c[(c[2440392]|0)+(aB<<2)>>2]|0;a[aq+9|0]=aA&255;a[aq+10|0]=aA>>>8&255;a[aq+11|0]=aA>>>16&255}aA=ay>>>24&15;if(!((aA|0)==0|A^1)){ay=c[(c[2440392]|0)+(aA<<2)>>2]|0;a[aq+12|0]=ay&255;a[aq+13|0]=ay>>>8&255;a[aq+14|0]=ay>>>16&255}ay=c[as+((aw|1)<<2)>>2]|0;as=ay&15;if(!((as|0)==0|z^1)){aA=c[(c[2440392]|0)+(as<<2)>>2]|0;a[aq+15|0]=aA&255;a[aq+16|0]=aA>>>8&255;a[aq+17|0]=aA>>>16&255}aA=ay>>>4&15;if(!((aA|0)==0|y^1)){as=c[(c[2440392]|0)+(aA<<2)>>2]|0;a[aq+18|0]=as&255;a[aq+19|0]=as>>>8&255;a[aq+20|0]=as>>>16&255}as=ay>>>8&15;if(!((as|0)==0|x^1)){aA=c[(c[2440392]|0)+(as<<2)>>2]|0;a[aq+21|0]=aA&255;a[aq+22|0]=aA>>>8&255;a[aq+23|0]=aA>>>16&255}aA=ay>>>16&15;if(!((aA|0)==0|w^1)){as=c[(c[2440392]|0)+(aA<<2)>>2]|0;a[aq+24|0]=as&255;a[aq+25|0]=as>>>8&255;a[aq+26|0]=as>>>16&255}as=ay>>>24&15;if(!((as|0)==0|v^1)){aA=c[(c[2440392]|0)+(as<<2)>>2]|0;a[aq+27|0]=aA&255;a[aq+28|0]=aA>>>8&255;a[aq+29|0]=aA>>>16&255}aA=ay>>>28;if((aA|0)==0|u^1){break}ay=c[(c[2440392]|0)+(aA<<2)>>2]|0;a[aq+30|0]=ay&255;a[aq+31|0]=ay>>>8&255;a[aq+32|0]=ay>>>16&255;break}else{ay=c[2385344]|0;aA=c[ay+(aw<<2)>>2]|0;as=aA&15;if(!((as|0)==0|u^1)){aB=c[(c[2440392]|0)+(as<<2)>>2]|0;a[aq+30|0]=aB&255;a[aq+31|0]=aB>>>8&255;a[aq+32|0]=aB>>>16&255}aB=aA>>>8&15;if(!((aB|0)==0|v^1)){as=c[(c[2440392]|0)+(aB<<2)>>2]|0;a[aq+27|0]=as&255;a[aq+28|0]=as>>>8&255;a[aq+29|0]=as>>>16&255}as=aA>>>12&15;if(!((as|0)==0|w^1)){aB=c[(c[2440392]|0)+(as<<2)>>2]|0;a[aq+24|0]=aB&255;a[aq+25|0]=aB>>>8&255;a[aq+26|0]=aB>>>16&255}aB=aA>>>16&15;if(!((aB|0)==0|x^1)){as=c[(c[2440392]|0)+(aB<<2)>>2]|0;a[aq+21|0]=as&255;a[aq+22|0]=as>>>8&255;a[aq+23|0]=as>>>16&255}as=aA>>>24&15;if(!((as|0)==0|y^1)){aA=c[(c[2440392]|0)+(as<<2)>>2]|0;a[aq+18|0]=aA&255;a[aq+19|0]=aA>>>8&255;a[aq+20|0]=aA>>>16&255}aA=c[ay+((aw|1)<<2)>>2]|0;aw=aA&15;if(!((aw|0)==0|z^1)){ay=c[(c[2440392]|0)+(aw<<2)>>2]|0;a[aq+15|0]=ay&255;a[aq+16|0]=ay>>>8&255;a[aq+17|0]=ay>>>16&255}ay=aA>>>4&15;if(!((ay|0)==0|A^1)){aw=c[(c[2440392]|0)+(ay<<2)>>2]|0;a[aq+12|0]=aw&255;a[aq+13|0]=aw>>>8&255;a[aq+14|0]=aw>>>16&255}aw=aA>>>8&15;if(!((aw|0)==0|B^1)){ay=c[(c[2440392]|0)+(aw<<2)>>2]|0;a[aq+9|0]=ay&255;a[aq+10|0]=ay>>>8&255;a[aq+11|0]=ay>>>16&255}ay=aA>>>16&15;if(!((ay|0)==0|C^1)){aw=c[(c[2440392]|0)+(ay<<2)>>2]|0;a[aq+6|0]=aw&255;a[aq+7|0]=aw>>>8&255;a[aq+8|0]=aw>>>16&255}aw=aA>>>24&15;if(!((aw|0)==0|D^1)){ay=c[(c[2440392]|0)+(aw<<2)>>2]|0;a[aq+3|0]=ay&255;a[aq+4|0]=ay>>>8&255;a[aq+5|0]=ay>>>16&255}ay=aA>>>28;if((ay|0)==0|t^1){break}aA=c[(c[2440392]|0)+(ay<<2)>>2]|0;a[aq]=aA&255;a[aq+1|0]=aA>>>8&255;a[aq+2|0]=aA>>>16&255;break}}}while(0);ar=T+1|0;if((ar|0)>(S|0)){ao=au;ap=at;break}else{T=ar;Q=av;O=au;Y=at;aq=aq+p|0}}}if((aj|0)>(i|0)){ad=36821;break}else{L=aj;M=ao;N=ap}}if((ad|0)==36820){return}else if((ad|0)==36821){return}}function czt(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0;b=c[3540994]|0;f=c[3528548]|0;g=f<<8;h=c[2385554]|0;do{if((h|0)>31){i=511}else{j=(h<<4)-1|0;if((j|0)>=0){i=j;break}return}}while(0);j=(i|0)>255;k=i&255;l=c[2385550]|0;m=c[2113042]|0;n=c[2113044]|0;o=m+512|0;p=c[2385552]|0;q=c[2113132]|0;r=p*3|0;s=c[2112968]|0;t=p+11|0;u=(t|0)>-1&(t|0)<(q|0);t=p+10|0;v=(t|0)>-1&(t|0)<(q|0);t=p+9|0;w=(t|0)>-1&(t|0)<(q|0);t=p+8|0;x=(t|0)>-1&(t|0)<(q|0);t=p+7|0;y=(t|0)>-1&(t|0)<(q|0);t=p+6|0;z=(t|0)>-1&(t|0)<(q|0);t=p+5|0;A=(t|0)>-1&(t|0)<(q|0);t=p+4|0;B=(t|0)>-1&(t|0)<(q|0);t=p+3|0;C=(t|0)>-1&(t|0)<(q|0);t=p+2|0;D=(t|0)>-1&(t|0)<(q|0);t=p+1|0;E=(t|0)>-1&(t|0)<(q|0);t=(p|0)>-1&(p|0)<(q|0);p=q*3|0;F=c[2415160]|0;G=c[2429858]|0;H=c[2430428]|0;I=c[2429718]|0;J=c[2430092]|0;K=c[3541046]|0;L=c[2430426]|0;M=0;N=0;O=0;L42533:while(1){P=(h|0)>16&(f|0)!=255;Q=(h|0)<33;R=511-f|0;S=f+1|0;T=f-255|0;U=~f;V=M;L42535:while(1){W=V+l|0;X=W&511;do{if((X|0)<(m|0)){Y=V+m-X|0}else{if((X|0)>=(n|0)){Y=o+V-X|0;break}Z=(V|0)>255;_=Z?16:0;$=V&255;aa=(V|0)<256&j?255:k;if(!P){ab=_;ac=$;ad=aa;ae=36846;break L42535}if(Q){if(!Z){ae=36836;break L42535}if((V|0)<(R|0)){Y=R;break}else{ae=36838;break L42535}}if(Z){af=T+$|0;if((af|0)>=0){ae=36841;break L42535}Z=S+af|0;if((Z|0)<0){Y=512;break}else{ab=0;ac=Z;ad=f;ae=36846;break L42535}}else{if(($|0)<=(f|0)){ae=36844;break L42535}Z=$+U|0;if((Z|0)>(f|0)){Y=256;break}else{ab=16;ac=Z;ad=f;ae=36846;break L42535}}}}while(0);if((Y|0)>(i|0)){ae=36909;break L42533}else{V=Y}}if((ae|0)==36841){ae=0;ah=f;ai=af;aj=_;ak=S+V-af|0}else if((ae|0)==36836){ae=0;al=aa;am=$;an=_;ao=V+1-$+aa|0;ae=36847}else if((ae|0)==36844){ae=0;ah=f;ai=$;aj=_;ak=S+V-$|0}else if((ae|0)==36838){ae=0;U=255-f|0;ab=_;ac=$-U|0;ad=aa-U|0;ae=36846}if((ae|0)==36846){ae=0;U=V+1+ad-ac|0;if(Q){al=ad;am=ac;an=ab;ao=U;ae=36847}else{ah=ad;ai=ac;aj=ab;ak=U}}if((ae|0)==36847){ae=0;ah=(al|0)>(f|0)?f:al;ai=am;aj=an;ak=ao}U=((W|-512)^511)+n|0;T=(ah-ai|0)>(U|0)?U+ai|0:ah;if((ai|0)>(T|0)){ap=N;aq=O}else{U=ai;R=-1;P=N;Z=O;ar=s+((ag(q,(X*3|0)-48|0)|0)+r)|0;while(1){as=d[b+(U+g)|0]|0;at=(as>>>4)+aj|0;do{if((at|0)==(R|0)){au=Z;av=P;aw=R}else{ax=at<<1;ay=e[F+((ax|1)<<1)>>1]|0;az=(ay<<12&983040|(e[F+(ax<<1)>>1]|0))&G;do{if((ay&8|0)==0){if((ay&4|0)==0){aA=az;break}aA=H|az&1048572}else{aA=L|az&1048568}}while(0);az=a[I+aA|0]|0;ax=az&255;if(az<<24>>24!=0){au=ax;av=ay;aw=at;break}c[2385344]=J+(aA<<7);c[2440392]=K+((ay>>>4&4080)<<2);au=ax;av=ay;aw=at}}while(0);do{if((au|0)==0){at=as<<1&30;ax=(av&2|0)==0?at:at^30;if((av&1|0)==0){at=c[2385344]|0;az=c[at+(ax<<2)>>2]|0;aB=az&15;if(!((aB|0)==0|t^1)){aC=c[(c[2440392]|0)+(aB<<2)>>2]|0;a[ar]=aC&255;a[ar+1|0]=aC>>>8&255;a[ar+2|0]=aC>>>16&255}aC=az>>>8&15;if(!((aC|0)==0|E^1)){aB=c[(c[2440392]|0)+(aC<<2)>>2]|0;a[ar+3|0]=aB&255;a[ar+4|0]=aB>>>8&255;a[ar+5|0]=aB>>>16&255}aB=az>>>12&15;if(!((aB|0)==0|D^1)){aC=c[(c[2440392]|0)+(aB<<2)>>2]|0;a[ar+6|0]=aC&255;a[ar+7|0]=aC>>>8&255;a[ar+8|0]=aC>>>16&255}aC=az>>>16&15;if(!((aC|0)==0|C^1)){aB=c[(c[2440392]|0)+(aC<<2)>>2]|0;a[ar+9|0]=aB&255;a[ar+10|0]=aB>>>8&255;a[ar+11|0]=aB>>>16&255}aB=az>>>24&15;if(!((aB|0)==0|B^1)){aC=c[(c[2440392]|0)+(aB<<2)>>2]|0;a[ar+12|0]=aC&255;a[ar+13|0]=aC>>>8&255;a[ar+14|0]=aC>>>16&255}aC=az>>>28;if(!((aC|0)==0|A^1)){az=c[(c[2440392]|0)+(aC<<2)>>2]|0;a[ar+15|0]=az&255;a[ar+16|0]=az>>>8&255;a[ar+17|0]=az>>>16&255}az=c[at+((ax|1)<<2)>>2]|0;at=az&15;if(!((at|0)==0|z^1)){aC=c[(c[2440392]|0)+(at<<2)>>2]|0;a[ar+18|0]=aC&255;a[ar+19|0]=aC>>>8&255;a[ar+20|0]=aC>>>16&255}aC=az>>>4&15;if(!((aC|0)==0|y^1)){at=c[(c[2440392]|0)+(aC<<2)>>2]|0;a[ar+21|0]=at&255;a[ar+22|0]=at>>>8&255;a[ar+23|0]=at>>>16&255}at=az>>>8&15;if(!((at|0)==0|x^1)){aC=c[(c[2440392]|0)+(at<<2)>>2]|0;a[ar+24|0]=aC&255;a[ar+25|0]=aC>>>8&255;a[ar+26|0]=aC>>>16&255}aC=az>>>16&15;if(!((aC|0)==0|w^1)){at=c[(c[2440392]|0)+(aC<<2)>>2]|0;a[ar+27|0]=at&255;a[ar+28|0]=at>>>8&255;a[ar+29|0]=at>>>16&255}at=az>>>24&15;if(!((at|0)==0|v^1)){aC=c[(c[2440392]|0)+(at<<2)>>2]|0;a[ar+30|0]=aC&255;a[ar+31|0]=aC>>>8&255;a[ar+32|0]=aC>>>16&255}aC=az>>>28;if((aC|0)==0|u^1){break}az=c[(c[2440392]|0)+(aC<<2)>>2]|0;a[ar+33|0]=az&255;a[ar+34|0]=az>>>8&255;a[ar+35|0]=az>>>16&255;break}else{az=c[2385344]|0;aC=c[az+(ax<<2)>>2]|0;at=aC&15;if(!((at|0)==0|u^1)){aB=c[(c[2440392]|0)+(at<<2)>>2]|0;a[ar+33|0]=aB&255;a[ar+34|0]=aB>>>8&255;a[ar+35|0]=aB>>>16&255}aB=aC>>>8&15;if(!((aB|0)==0|v^1)){at=c[(c[2440392]|0)+(aB<<2)>>2]|0;a[ar+30|0]=at&255;a[ar+31|0]=at>>>8&255;a[ar+32|0]=at>>>16&255}at=aC>>>12&15;if(!((at|0)==0|w^1)){aB=c[(c[2440392]|0)+(at<<2)>>2]|0;a[ar+27|0]=aB&255;a[ar+28|0]=aB>>>8&255;a[ar+29|0]=aB>>>16&255}aB=aC>>>16&15;if(!((aB|0)==0|x^1)){at=c[(c[2440392]|0)+(aB<<2)>>2]|0;a[ar+24|0]=at&255;a[ar+25|0]=at>>>8&255;a[ar+26|0]=at>>>16&255}at=aC>>>24&15;if(!((at|0)==0|y^1)){aB=c[(c[2440392]|0)+(at<<2)>>2]|0;a[ar+21|0]=aB&255;a[ar+22|0]=aB>>>8&255;a[ar+23|0]=aB>>>16&255}aB=aC>>>28;if(!((aB|0)==0|z^1)){aC=c[(c[2440392]|0)+(aB<<2)>>2]|0;a[ar+18|0]=aC&255;a[ar+19|0]=aC>>>8&255;a[ar+20|0]=aC>>>16&255}aC=c[az+((ax|1)<<2)>>2]|0;ax=aC&15;if(!((ax|0)==0|A^1)){az=c[(c[2440392]|0)+(ax<<2)>>2]|0;a[ar+15|0]=az&255;a[ar+16|0]=az>>>8&255;a[ar+17|0]=az>>>16&255}az=aC>>>4&15;if(!((az|0)==0|B^1)){ax=c[(c[2440392]|0)+(az<<2)>>2]|0;a[ar+12|0]=ax&255;a[ar+13|0]=ax>>>8&255;a[ar+14|0]=ax>>>16&255}ax=aC>>>8&15;if(!((ax|0)==0|C^1)){az=c[(c[2440392]|0)+(ax<<2)>>2]|0;a[ar+9|0]=az&255;a[ar+10|0]=az>>>8&255;a[ar+11|0]=az>>>16&255}az=aC>>>16&15;if(!((az|0)==0|D^1)){ax=c[(c[2440392]|0)+(az<<2)>>2]|0;a[ar+6|0]=ax&255;a[ar+7|0]=ax>>>8&255;a[ar+8|0]=ax>>>16&255}ax=aC>>>24&15;if(!((ax|0)==0|E^1)){az=c[(c[2440392]|0)+(ax<<2)>>2]|0;a[ar+3|0]=az&255;a[ar+4|0]=az>>>8&255;a[ar+5|0]=az>>>16&255}az=aC>>>28;if((az|0)==0|t^1){break}aC=c[(c[2440392]|0)+(az<<2)>>2]|0;a[ar]=aC&255;a[ar+1|0]=aC>>>8&255;a[ar+2|0]=aC>>>16&255;break}}}while(0);as=U+1|0;if((as|0)>(T|0)){ap=av;aq=au;break}else{U=as;R=aw;P=av;Z=au;ar=ar+p|0}}}if((ak|0)>(i|0)){ae=36911;break}else{M=ak;N=ap;O=aq}}if((ae|0)==36909){return}else if((ae|0)==36911){return}}function czu(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0;b=c[3540994]|0;f=c[3528548]|0;g=f<<8;h=c[2385554]|0;do{if((h|0)>31){i=511}else{j=(h<<4)-1|0;if((j|0)>=0){i=j;break}return}}while(0);j=(i|0)>255;k=i&255;l=c[2385550]|0;m=c[2113042]|0;n=c[2113044]|0;o=m+512|0;p=c[2385552]|0;q=c[2113132]|0;r=p*3|0;s=c[2112968]|0;t=p+12|0;u=(t|0)>-1&(t|0)<(q|0);t=p+11|0;v=(t|0)>-1&(t|0)<(q|0);t=p+10|0;w=(t|0)>-1&(t|0)<(q|0);t=p+9|0;x=(t|0)>-1&(t|0)<(q|0);t=p+8|0;y=(t|0)>-1&(t|0)<(q|0);t=p+7|0;z=(t|0)>-1&(t|0)<(q|0);t=p+6|0;A=(t|0)>-1&(t|0)<(q|0);t=p+5|0;B=(t|0)>-1&(t|0)<(q|0);t=p+4|0;C=(t|0)>-1&(t|0)<(q|0);t=p+3|0;D=(t|0)>-1&(t|0)<(q|0);t=p+2|0;E=(t|0)>-1&(t|0)<(q|0);t=p+1|0;F=(t|0)>-1&(t|0)<(q|0);t=(p|0)>-1&(p|0)<(q|0);p=q*3|0;G=c[2415160]|0;H=c[2429858]|0;I=c[2430428]|0;J=c[2429718]|0;K=c[2430092]|0;L=c[3541046]|0;M=c[2430426]|0;N=0;O=0;P=0;L42660:while(1){Q=(h|0)>16&(f|0)!=255;R=(h|0)<33;S=511-f|0;T=f+1|0;U=f-255|0;V=~f;W=N;L42662:while(1){X=W+l|0;Y=X&511;do{if((Y|0)<(m|0)){Z=W+m-Y|0}else{if((Y|0)>=(n|0)){Z=o+W-Y|0;break}_=(W|0)>255;$=_?16:0;aa=W&255;ab=(W|0)<256&j?255:k;if(!Q){ac=$;ad=aa;ae=ab;af=36935;break L42662}if(R){if(!_){af=36925;break L42662}if((W|0)<(S|0)){Z=S;break}else{af=36927;break L42662}}if(_){ah=U+aa|0;if((ah|0)>=0){af=36930;break L42662}_=T+ah|0;if((_|0)<0){Z=512;break}else{ac=0;ad=_;ae=f;af=36935;break L42662}}else{if((aa|0)<=(f|0)){af=36933;break L42662}_=aa+V|0;if((_|0)>(f|0)){Z=256;break}else{ac=16;ad=_;ae=f;af=36935;break L42662}}}}while(0);if((Z|0)>(i|0)){af=37002;break L42660}else{W=Z}}if((af|0)==36927){af=0;V=255-f|0;ac=$;ad=aa-V|0;ae=ab-V|0;af=36935}else if((af|0)==36925){af=0;ai=ab;aj=aa;ak=$;al=W+1-aa+ab|0;af=36936}else if((af|0)==36930){af=0;am=f;an=ah;ao=$;ap=T+W-ah|0}else if((af|0)==36933){af=0;am=f;an=aa;ao=$;ap=T+W-aa|0}if((af|0)==36935){af=0;V=W+1+ae-ad|0;if(R){ai=ae;aj=ad;ak=ac;al=V;af=36936}else{am=ae;an=ad;ao=ac;ap=V}}if((af|0)==36936){af=0;am=(ai|0)>(f|0)?f:ai;an=aj;ao=ak;ap=al}V=((X|-512)^511)+n|0;U=(am-an|0)>(V|0)?V+an|0:am;if((an|0)>(U|0)){aq=O;ar=P}else{V=an;S=-1;Q=O;_=P;as=s+((ag(q,(Y*3|0)-48|0)|0)+r)|0;while(1){at=d[b+(V+g)|0]|0;au=(at>>>4)+ao|0;do{if((au|0)==(S|0)){av=_;aw=Q;ax=S}else{ay=au<<1;az=e[G+((ay|1)<<1)>>1]|0;aA=(az<<12&983040|(e[G+(ay<<1)>>1]|0))&H;do{if((az&8|0)==0){if((az&4|0)==0){aB=aA;break}aB=I|aA&1048572}else{aB=M|aA&1048568}}while(0);aA=a[J+aB|0]|0;ay=aA&255;if(aA<<24>>24!=0){av=ay;aw=az;ax=au;break}c[2385344]=K+(aB<<7);c[2440392]=L+((az>>>4&4080)<<2);av=ay;aw=az;ax=au}}while(0);do{if((av|0)==0){au=at<<1&30;ay=(aw&2|0)==0?au:au^30;if((aw&1|0)==0){au=c[2385344]|0;aA=c[au+(ay<<2)>>2]|0;aC=aA&15;if(!((aC|0)==0|t^1)){aD=c[(c[2440392]|0)+(aC<<2)>>2]|0;a[as]=aD&255;a[as+1|0]=aD>>>8&255;a[as+2|0]=aD>>>16&255}aD=aA>>>8&15;if(!((aD|0)==0|F^1)){aC=c[(c[2440392]|0)+(aD<<2)>>2]|0;a[as+3|0]=aC&255;a[as+4|0]=aC>>>8&255;a[as+5|0]=aC>>>16&255}aC=aA>>>12&15;if(!((aC|0)==0|E^1)){aD=c[(c[2440392]|0)+(aC<<2)>>2]|0;a[as+6|0]=aD&255;a[as+7|0]=aD>>>8&255;a[as+8|0]=aD>>>16&255}aD=aA>>>16&15;if(!((aD|0)==0|D^1)){aC=c[(c[2440392]|0)+(aD<<2)>>2]|0;a[as+9|0]=aC&255;a[as+10|0]=aC>>>8&255;a[as+11|0]=aC>>>16&255}aC=aA>>>24&15;if(!((aC|0)==0|C^1)){aD=c[(c[2440392]|0)+(aC<<2)>>2]|0;a[as+12|0]=aD&255;a[as+13|0]=aD>>>8&255;a[as+14|0]=aD>>>16&255}aD=aA>>>28;if(!((aD|0)==0|B^1)){aA=c[(c[2440392]|0)+(aD<<2)>>2]|0;a[as+15|0]=aA&255;a[as+16|0]=aA>>>8&255;a[as+17|0]=aA>>>16&255}aA=c[au+((ay|1)<<2)>>2]|0;au=aA&15;if(!((au|0)==0|A^1)){aD=c[(c[2440392]|0)+(au<<2)>>2]|0;a[as+18|0]=aD&255;a[as+19|0]=aD>>>8&255;a[as+20|0]=aD>>>16&255}aD=aA>>>4&15;if(!((aD|0)==0|z^1)){au=c[(c[2440392]|0)+(aD<<2)>>2]|0;a[as+21|0]=au&255;a[as+22|0]=au>>>8&255;a[as+23|0]=au>>>16&255}au=aA>>>8&15;if(!((au|0)==0|y^1)){aD=c[(c[2440392]|0)+(au<<2)>>2]|0;a[as+24|0]=aD&255;a[as+25|0]=aD>>>8&255;a[as+26|0]=aD>>>16&255}aD=aA>>>16&15;if(!((aD|0)==0|x^1)){au=c[(c[2440392]|0)+(aD<<2)>>2]|0;a[as+27|0]=au&255;a[as+28|0]=au>>>8&255;a[as+29|0]=au>>>16&255}au=aA>>>20&15;if(!((au|0)==0|w^1)){aD=c[(c[2440392]|0)+(au<<2)>>2]|0;a[as+30|0]=aD&255;a[as+31|0]=aD>>>8&255;a[as+32|0]=aD>>>16&255}aD=aA>>>24&15;if(!((aD|0)==0|v^1)){au=c[(c[2440392]|0)+(aD<<2)>>2]|0;a[as+33|0]=au&255;a[as+34|0]=au>>>8&255;a[as+35|0]=au>>>16&255}au=aA>>>28;if((au|0)==0|u^1){break}aA=c[(c[2440392]|0)+(au<<2)>>2]|0;a[as+36|0]=aA&255;a[as+37|0]=aA>>>8&255;a[as+38|0]=aA>>>16&255;break}else{aA=c[2385344]|0;au=c[aA+(ay<<2)>>2]|0;aD=au&15;if(!((aD|0)==0|u^1)){aC=c[(c[2440392]|0)+(aD<<2)>>2]|0;a[as+36|0]=aC&255;a[as+37|0]=aC>>>8&255;a[as+38|0]=aC>>>16&255}aC=au>>>8&15;if(!((aC|0)==0|v^1)){aD=c[(c[2440392]|0)+(aC<<2)>>2]|0;a[as+33|0]=aD&255;a[as+34|0]=aD>>>8&255;a[as+35|0]=aD>>>16&255}aD=au>>>12&15;if(!((aD|0)==0|w^1)){aC=c[(c[2440392]|0)+(aD<<2)>>2]|0;a[as+30|0]=aC&255;a[as+31|0]=aC>>>8&255;a[as+32|0]=aC>>>16&255}aC=au>>>16&15;if(!((aC|0)==0|x^1)){aD=c[(c[2440392]|0)+(aC<<2)>>2]|0;a[as+27|0]=aD&255;a[as+28|0]=aD>>>8&255;a[as+29|0]=aD>>>16&255}aD=au>>>24&15;if(!((aD|0)==0|y^1)){aC=c[(c[2440392]|0)+(aD<<2)>>2]|0;a[as+24|0]=aC&255;a[as+25|0]=aC>>>8&255;a[as+26|0]=aC>>>16&255}aC=au>>>28;if(!((aC|0)==0|z^1)){au=c[(c[2440392]|0)+(aC<<2)>>2]|0;a[as+21|0]=au&255;a[as+22|0]=au>>>8&255;a[as+23|0]=au>>>16&255}au=c[aA+((ay|1)<<2)>>2]|0;ay=au&15;if(!((ay|0)==0|A^1)){aA=c[(c[2440392]|0)+(ay<<2)>>2]|0;a[as+18|0]=aA&255;a[as+19|0]=aA>>>8&255;a[as+20|0]=aA>>>16&255}aA=au>>>4&15;if(!((aA|0)==0|B^1)){ay=c[(c[2440392]|0)+(aA<<2)>>2]|0;a[as+15|0]=ay&255;a[as+16|0]=ay>>>8&255;a[as+17|0]=ay>>>16&255}ay=au>>>8&15;if(!((ay|0)==0|C^1)){aA=c[(c[2440392]|0)+(ay<<2)>>2]|0;a[as+12|0]=aA&255;a[as+13|0]=aA>>>8&255;a[as+14|0]=aA>>>16&255}aA=au>>>16&15;if(!((aA|0)==0|D^1)){ay=c[(c[2440392]|0)+(aA<<2)>>2]|0;a[as+9|0]=ay&255;a[as+10|0]=ay>>>8&255;a[as+11|0]=ay>>>16&255}ay=au>>>20&15;if(!((ay|0)==0|E^1)){aA=c[(c[2440392]|0)+(ay<<2)>>2]|0;a[as+6|0]=aA&255;a[as+7|0]=aA>>>8&255;a[as+8|0]=aA>>>16&255}aA=au>>>24&15;if(!((aA|0)==0|F^1)){ay=c[(c[2440392]|0)+(aA<<2)>>2]|0;a[as+3|0]=ay&255;a[as+4|0]=ay>>>8&255;a[as+5|0]=ay>>>16&255}ay=au>>>28;if((ay|0)==0|t^1){break}au=c[(c[2440392]|0)+(ay<<2)>>2]|0;a[as]=au&255;a[as+1|0]=au>>>8&255;a[as+2|0]=au>>>16&255;break}}}while(0);at=V+1|0;if((at|0)>(U|0)){aq=aw;ar=av;break}else{V=at;S=ax;Q=aw;_=av;as=as+p|0}}}if((ap|0)>(i|0)){af=37003;break}else{N=ap;O=aq;P=ar}}if((af|0)==37002){return}else if((af|0)==37003){return}}function czv(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0;b=c[3540994]|0;f=c[3528548]|0;g=f<<8;h=c[2385554]|0;do{if((h|0)>31){i=511}else{j=(h<<4)-1|0;if((j|0)>=0){i=j;break}return}}while(0);j=(i|0)>255;k=i&255;l=c[2385550]|0;m=c[2113042]|0;n=c[2113044]|0;o=m+512|0;p=c[2385552]|0;q=c[2113132]|0;r=p*3|0;s=c[2112968]|0;t=p+13|0;u=(t|0)>-1&(t|0)<(q|0);t=p+12|0;v=(t|0)>-1&(t|0)<(q|0);t=p+11|0;w=(t|0)>-1&(t|0)<(q|0);t=p+10|0;x=(t|0)>-1&(t|0)<(q|0);t=p+9|0;y=(t|0)>-1&(t|0)<(q|0);t=p+8|0;z=(t|0)>-1&(t|0)<(q|0);t=p+7|0;A=(t|0)>-1&(t|0)<(q|0);t=p+6|0;B=(t|0)>-1&(t|0)<(q|0);t=p+5|0;C=(t|0)>-1&(t|0)<(q|0);t=p+4|0;D=(t|0)>-1&(t|0)<(q|0);t=p+3|0;E=(t|0)>-1&(t|0)<(q|0);t=p+2|0;F=(t|0)>-1&(t|0)<(q|0);t=p+1|0;G=(t|0)>-1&(t|0)<(q|0);t=(p|0)>-1&(p|0)<(q|0);p=q*3|0;H=c[2415160]|0;I=c[2429858]|0;J=c[2430428]|0;K=c[2429718]|0;L=c[2430092]|0;M=c[3541046]|0;N=c[2430426]|0;O=0;P=0;Q=0;L42793:while(1){R=(h|0)>16&(f|0)!=255;S=(h|0)<33;T=511-f|0;U=f+1|0;V=f-255|0;W=~f;X=O;L42795:while(1){Y=X+l|0;Z=Y&511;do{if((Z|0)<(m|0)){_=X+m-Z|0}else{if((Z|0)>=(n|0)){_=o+X-Z|0;break}$=(X|0)>255;aa=$?16:0;ab=X&255;ac=(X|0)<256&j?255:k;if(!R){ad=aa;ae=ab;af=ac;ah=37028;break L42795}if(S){if(!$){ah=37018;break L42795}if((X|0)<(T|0)){_=T;break}else{ah=37020;break L42795}}if($){ai=V+ab|0;if((ai|0)>=0){ah=37023;break L42795}$=U+ai|0;if(($|0)<0){_=512;break}else{ad=0;ae=$;af=f;ah=37028;break L42795}}else{if((ab|0)<=(f|0)){ah=37026;break L42795}$=ab+W|0;if(($|0)>(f|0)){_=256;break}else{ad=16;ae=$;af=f;ah=37028;break L42795}}}}while(0);if((_|0)>(i|0)){ah=37099;break L42793}else{X=_}}if((ah|0)==37026){ah=0;aj=f;ak=ab;al=aa;am=U+X-ab|0}else if((ah|0)==37020){ah=0;W=255-f|0;ad=aa;ae=ab-W|0;af=ac-W|0;ah=37028}else if((ah|0)==37023){ah=0;aj=f;ak=ai;al=aa;am=U+X-ai|0}else if((ah|0)==37018){ah=0;an=ac;ao=ab;ap=aa;aq=X+1-ab+ac|0;ah=37029}if((ah|0)==37028){ah=0;W=X+1+af-ae|0;if(S){an=af;ao=ae;ap=ad;aq=W;ah=37029}else{aj=af;ak=ae;al=ad;am=W}}if((ah|0)==37029){ah=0;aj=(an|0)>(f|0)?f:an;ak=ao;al=ap;am=aq}W=((Y|-512)^511)+n|0;V=(aj-ak|0)>(W|0)?W+ak|0:aj;if((ak|0)>(V|0)){ar=P;as=Q}else{W=ak;T=-1;R=P;$=Q;at=s+((ag(q,(Z*3|0)-48|0)|0)+r)|0;while(1){au=d[b+(W+g)|0]|0;av=(au>>>4)+al|0;do{if((av|0)==(T|0)){aw=$;ax=R;ay=T}else{az=av<<1;aA=e[H+((az|1)<<1)>>1]|0;aB=(aA<<12&983040|(e[H+(az<<1)>>1]|0))&I;do{if((aA&8|0)==0){if((aA&4|0)==0){aC=aB;break}aC=J|aB&1048572}else{aC=N|aB&1048568}}while(0);aB=a[K+aC|0]|0;az=aB&255;if(aB<<24>>24!=0){aw=az;ax=aA;ay=av;break}c[2385344]=L+(aC<<7);c[2440392]=M+((aA>>>4&4080)<<2);aw=az;ax=aA;ay=av}}while(0);do{if((aw|0)==0){av=au<<1&30;az=(ax&2|0)==0?av:av^30;if((ax&1|0)==0){av=c[2385344]|0;aB=c[av+(az<<2)>>2]|0;aD=aB&15;if(!((aD|0)==0|t^1)){aE=c[(c[2440392]|0)+(aD<<2)>>2]|0;a[at]=aE&255;a[at+1|0]=aE>>>8&255;a[at+2|0]=aE>>>16&255}aE=aB>>>4&15;if(!((aE|0)==0|G^1)){aD=c[(c[2440392]|0)+(aE<<2)>>2]|0;a[at+3|0]=aD&255;a[at+4|0]=aD>>>8&255;a[at+5|0]=aD>>>16&255}aD=aB>>>8&15;if(!((aD|0)==0|F^1)){aE=c[(c[2440392]|0)+(aD<<2)>>2]|0;a[at+6|0]=aE&255;a[at+7|0]=aE>>>8&255;a[at+8|0]=aE>>>16&255}aE=aB>>>12&15;if(!((aE|0)==0|E^1)){aD=c[(c[2440392]|0)+(aE<<2)>>2]|0;a[at+9|0]=aD&255;a[at+10|0]=aD>>>8&255;a[at+11|0]=aD>>>16&255}aD=aB>>>16&15;if(!((aD|0)==0|D^1)){aE=c[(c[2440392]|0)+(aD<<2)>>2]|0;a[at+12|0]=aE&255;a[at+13|0]=aE>>>8&255;a[at+14|0]=aE>>>16&255}aE=aB>>>24&15;if(!((aE|0)==0|C^1)){aD=c[(c[2440392]|0)+(aE<<2)>>2]|0;a[at+15|0]=aD&255;a[at+16|0]=aD>>>8&255;a[at+17|0]=aD>>>16&255}aD=aB>>>28;if(!((aD|0)==0|B^1)){aB=c[(c[2440392]|0)+(aD<<2)>>2]|0;a[at+18|0]=aB&255;a[at+19|0]=aB>>>8&255;a[at+20|0]=aB>>>16&255}aB=c[av+((az|1)<<2)>>2]|0;av=aB&15;if(!((av|0)==0|A^1)){aD=c[(c[2440392]|0)+(av<<2)>>2]|0;a[at+21|0]=aD&255;a[at+22|0]=aD>>>8&255;a[at+23|0]=aD>>>16&255}aD=aB>>>4&15;if(!((aD|0)==0|z^1)){av=c[(c[2440392]|0)+(aD<<2)>>2]|0;a[at+24|0]=av&255;a[at+25|0]=av>>>8&255;a[at+26|0]=av>>>16&255}av=aB>>>8&15;if(!((av|0)==0|y^1)){aD=c[(c[2440392]|0)+(av<<2)>>2]|0;a[at+27|0]=aD&255;a[at+28|0]=aD>>>8&255;a[at+29|0]=aD>>>16&255}aD=aB>>>16&15;if(!((aD|0)==0|x^1)){av=c[(c[2440392]|0)+(aD<<2)>>2]|0;a[at+30|0]=av&255;a[at+31|0]=av>>>8&255;a[at+32|0]=av>>>16&255}av=aB>>>20&15;if(!((av|0)==0|w^1)){aD=c[(c[2440392]|0)+(av<<2)>>2]|0;a[at+33|0]=aD&255;a[at+34|0]=aD>>>8&255;a[at+35|0]=aD>>>16&255}aD=aB>>>24&15;if(!((aD|0)==0|v^1)){av=c[(c[2440392]|0)+(aD<<2)>>2]|0;a[at+36|0]=av&255;a[at+37|0]=av>>>8&255;a[at+38|0]=av>>>16&255}av=aB>>>28;if((av|0)==0|u^1){break}aB=c[(c[2440392]|0)+(av<<2)>>2]|0;a[at+39|0]=aB&255;a[at+40|0]=aB>>>8&255;a[at+41|0]=aB>>>16&255;break}else{aB=c[2385344]|0;av=c[aB+(az<<2)>>2]|0;aD=av&15;if(!((aD|0)==0|u^1)){aE=c[(c[2440392]|0)+(aD<<2)>>2]|0;a[at+39|0]=aE&255;a[at+40|0]=aE>>>8&255;a[at+41|0]=aE>>>16&255}aE=av>>>4&15;if(!((aE|0)==0|v^1)){aD=c[(c[2440392]|0)+(aE<<2)>>2]|0;a[at+36|0]=aD&255;a[at+37|0]=aD>>>8&255;a[at+38|0]=aD>>>16&255}aD=av>>>8&15;if(!((aD|0)==0|w^1)){aE=c[(c[2440392]|0)+(aD<<2)>>2]|0;a[at+33|0]=aE&255;a[at+34|0]=aE>>>8&255;a[at+35|0]=aE>>>16&255}aE=av>>>12&15;if(!((aE|0)==0|x^1)){aD=c[(c[2440392]|0)+(aE<<2)>>2]|0;a[at+30|0]=aD&255;a[at+31|0]=aD>>>8&255;a[at+32|0]=aD>>>16&255}aD=av>>>16&15;if(!((aD|0)==0|y^1)){aE=c[(c[2440392]|0)+(aD<<2)>>2]|0;a[at+27|0]=aE&255;a[at+28|0]=aE>>>8&255;a[at+29|0]=aE>>>16&255}aE=av>>>24&15;if(!((aE|0)==0|z^1)){aD=c[(c[2440392]|0)+(aE<<2)>>2]|0;a[at+24|0]=aD&255;a[at+25|0]=aD>>>8&255;a[at+26|0]=aD>>>16&255}aD=av>>>28;if(!((aD|0)==0|A^1)){av=c[(c[2440392]|0)+(aD<<2)>>2]|0;a[at+21|0]=av&255;a[at+22|0]=av>>>8&255;a[at+23|0]=av>>>16&255}av=c[aB+((az|1)<<2)>>2]|0;az=av&15;if(!((az|0)==0|B^1)){aB=c[(c[2440392]|0)+(az<<2)>>2]|0;a[at+18|0]=aB&255;a[at+19|0]=aB>>>8&255;a[at+20|0]=aB>>>16&255}aB=av>>>4&15;if(!((aB|0)==0|C^1)){az=c[(c[2440392]|0)+(aB<<2)>>2]|0;a[at+15|0]=az&255;a[at+16|0]=az>>>8&255;a[at+17|0]=az>>>16&255}az=av>>>8&15;if(!((az|0)==0|D^1)){aB=c[(c[2440392]|0)+(az<<2)>>2]|0;a[at+12|0]=aB&255;a[at+13|0]=aB>>>8&255;a[at+14|0]=aB>>>16&255}aB=av>>>16&15;if(!((aB|0)==0|E^1)){az=c[(c[2440392]|0)+(aB<<2)>>2]|0;a[at+9|0]=az&255;a[at+10|0]=az>>>8&255;a[at+11|0]=az>>>16&255}az=av>>>20&15;if(!((az|0)==0|F^1)){aB=c[(c[2440392]|0)+(az<<2)>>2]|0;a[at+6|0]=aB&255;a[at+7|0]=aB>>>8&255;a[at+8|0]=aB>>>16&255}aB=av>>>24&15;if(!((aB|0)==0|G^1)){az=c[(c[2440392]|0)+(aB<<2)>>2]|0;a[at+3|0]=az&255;a[at+4|0]=az>>>8&255;a[at+5|0]=az>>>16&255}az=av>>>28;if((az|0)==0|t^1){break}av=c[(c[2440392]|0)+(az<<2)>>2]|0;a[at]=av&255;a[at+1|0]=av>>>8&255;a[at+2|0]=av>>>16&255;break}}}while(0);au=W+1|0;if((au|0)>(V|0)){ar=ax;as=aw;break}else{W=au;T=ay;R=ax;$=aw;at=at+p|0}}}if((am|0)>(i|0)){ah=37100;break}else{O=am;P=ar;Q=as}}if((ah|0)==37099){return}else if((ah|0)==37100){return}}function czw(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0;b=c[3540994]|0;f=c[3528548]|0;g=f<<8;h=c[2385554]|0;do{if((h|0)>31){i=511}else{j=(h<<4)-1|0;if((j|0)>=0){i=j;break}return}}while(0);j=(i|0)>255;k=i&255;l=c[2385550]|0;m=c[2113042]|0;n=c[2113044]|0;o=m+512|0;p=c[2385552]|0;q=c[2113132]|0;r=p*3|0;s=c[2112968]|0;t=p+14|0;u=(t|0)>-1&(t|0)<(q|0);t=p+13|0;v=(t|0)>-1&(t|0)<(q|0);t=p+12|0;w=(t|0)>-1&(t|0)<(q|0);t=p+11|0;x=(t|0)>-1&(t|0)<(q|0);t=p+10|0;y=(t|0)>-1&(t|0)<(q|0);t=p+9|0;z=(t|0)>-1&(t|0)<(q|0);t=p+8|0;A=(t|0)>-1&(t|0)<(q|0);t=p+7|0;B=(t|0)>-1&(t|0)<(q|0);t=p+6|0;C=(t|0)>-1&(t|0)<(q|0);t=p+5|0;D=(t|0)>-1&(t|0)<(q|0);t=p+4|0;E=(t|0)>-1&(t|0)<(q|0);t=p+3|0;F=(t|0)>-1&(t|0)<(q|0);t=p+2|0;G=(t|0)>-1&(t|0)<(q|0);t=p+1|0;H=(t|0)>-1&(t|0)<(q|0);t=(p|0)>-1&(p|0)<(q|0);p=q*3|0;I=c[2415160]|0;J=c[2429858]|0;K=c[2430428]|0;L=c[2429718]|0;M=c[2430092]|0;N=c[3541046]|0;O=c[2430426]|0;P=0;Q=0;R=0;L42932:while(1){S=(h|0)>16&(f|0)!=255;T=(h|0)<33;U=511-f|0;V=f+1|0;W=f-255|0;X=~f;Y=P;L42934:while(1){Z=Y+l|0;_=Z&511;do{if((_|0)<(m|0)){$=Y+m-_|0}else{if((_|0)>=(n|0)){$=o+Y-_|0;break}aa=(Y|0)>255;ab=aa?16:0;ac=Y&255;ad=(Y|0)<256&j?255:k;if(!S){ae=ab;af=ac;ah=ad;ai=37125;break L42934}if(T){if(!aa){ai=37115;break L42934}if((Y|0)<(U|0)){$=U;break}else{ai=37117;break L42934}}if(aa){aj=W+ac|0;if((aj|0)>=0){ai=37120;break L42934}aa=V+aj|0;if((aa|0)<0){$=512;break}else{ae=0;af=aa;ah=f;ai=37125;break L42934}}else{if((ac|0)<=(f|0)){ai=37123;break L42934}aa=ac+X|0;if((aa|0)>(f|0)){$=256;break}else{ae=16;af=aa;ah=f;ai=37125;break L42934}}}}while(0);if(($|0)>(i|0)){ai=37200;break L42932}else{Y=$}}if((ai|0)==37117){ai=0;X=255-f|0;ae=ab;af=ac-X|0;ah=ad-X|0;ai=37125}else if((ai|0)==37123){ai=0;ak=f;al=ac;am=ab;an=V+Y-ac|0}else if((ai|0)==37115){ai=0;ao=ad;ap=ac;aq=ab;ar=Y+1-ac+ad|0;ai=37126}else if((ai|0)==37120){ai=0;ak=f;al=aj;am=ab;an=V+Y-aj|0}if((ai|0)==37125){ai=0;X=Y+1+ah-af|0;if(T){ao=ah;ap=af;aq=ae;ar=X;ai=37126}else{ak=ah;al=af;am=ae;an=X}}if((ai|0)==37126){ai=0;ak=(ao|0)>(f|0)?f:ao;al=ap;am=aq;an=ar}X=((Z|-512)^511)+n|0;W=(ak-al|0)>(X|0)?X+al|0:ak;if((al|0)>(W|0)){as=Q;at=R}else{X=al;U=-1;S=Q;aa=R;au=s+((ag(q,(_*3|0)-48|0)|0)+r)|0;while(1){av=d[b+(X+g)|0]|0;aw=(av>>>4)+am|0;do{if((aw|0)==(U|0)){ax=aa;ay=S;az=U}else{aA=aw<<1;aB=e[I+((aA|1)<<1)>>1]|0;aC=(aB<<12&983040|(e[I+(aA<<1)>>1]|0))&J;do{if((aB&8|0)==0){if((aB&4|0)==0){aD=aC;break}aD=K|aC&1048572}else{aD=O|aC&1048568}}while(0);aC=a[L+aD|0]|0;aA=aC&255;if(aC<<24>>24!=0){ax=aA;ay=aB;az=aw;break}c[2385344]=M+(aD<<7);c[2440392]=N+((aB>>>4&4080)<<2);ax=aA;ay=aB;az=aw}}while(0);do{if((ax|0)==0){aw=av<<1&30;aA=(ay&2|0)==0?aw:aw^30;if((ay&1|0)==0){aw=c[2385344]|0;aC=c[aw+(aA<<2)>>2]|0;aE=aC&15;if(!((aE|0)==0|t^1)){aF=c[(c[2440392]|0)+(aE<<2)>>2]|0;a[au]=aF&255;a[au+1|0]=aF>>>8&255;a[au+2|0]=aF>>>16&255}aF=aC>>>4&15;if(!((aF|0)==0|H^1)){aE=c[(c[2440392]|0)+(aF<<2)>>2]|0;a[au+3|0]=aE&255;a[au+4|0]=aE>>>8&255;a[au+5|0]=aE>>>16&255}aE=aC>>>8&15;if(!((aE|0)==0|G^1)){aF=c[(c[2440392]|0)+(aE<<2)>>2]|0;a[au+6|0]=aF&255;a[au+7|0]=aF>>>8&255;a[au+8|0]=aF>>>16&255}aF=aC>>>12&15;if(!((aF|0)==0|F^1)){aE=c[(c[2440392]|0)+(aF<<2)>>2]|0;a[au+9|0]=aE&255;a[au+10|0]=aE>>>8&255;a[au+11|0]=aE>>>16&255}aE=aC>>>16&15;if(!((aE|0)==0|E^1)){aF=c[(c[2440392]|0)+(aE<<2)>>2]|0;a[au+12|0]=aF&255;a[au+13|0]=aF>>>8&255;a[au+14|0]=aF>>>16&255}aF=aC>>>24&15;if(!((aF|0)==0|D^1)){aE=c[(c[2440392]|0)+(aF<<2)>>2]|0;a[au+15|0]=aE&255;a[au+16|0]=aE>>>8&255;a[au+17|0]=aE>>>16&255}aE=aC>>>28;if(!((aE|0)==0|C^1)){aC=c[(c[2440392]|0)+(aE<<2)>>2]|0;a[au+18|0]=aC&255;a[au+19|0]=aC>>>8&255;a[au+20|0]=aC>>>16&255}aC=c[aw+((aA|1)<<2)>>2]|0;aw=aC&15;if(!((aw|0)==0|B^1)){aE=c[(c[2440392]|0)+(aw<<2)>>2]|0;a[au+21|0]=aE&255;a[au+22|0]=aE>>>8&255;a[au+23|0]=aE>>>16&255}aE=aC>>>4&15;if(!((aE|0)==0|A^1)){aw=c[(c[2440392]|0)+(aE<<2)>>2]|0;a[au+24|0]=aw&255;a[au+25|0]=aw>>>8&255;a[au+26|0]=aw>>>16&255}aw=aC>>>8&15;if(!((aw|0)==0|z^1)){aE=c[(c[2440392]|0)+(aw<<2)>>2]|0;a[au+27|0]=aE&255;a[au+28|0]=aE>>>8&255;a[au+29|0]=aE>>>16&255}aE=aC>>>12&15;if(!((aE|0)==0|y^1)){aw=c[(c[2440392]|0)+(aE<<2)>>2]|0;a[au+30|0]=aw&255;a[au+31|0]=aw>>>8&255;a[au+32|0]=aw>>>16&255}aw=aC>>>16&15;if(!((aw|0)==0|x^1)){aE=c[(c[2440392]|0)+(aw<<2)>>2]|0;a[au+33|0]=aE&255;a[au+34|0]=aE>>>8&255;a[au+35|0]=aE>>>16&255}aE=aC>>>20&15;if(!((aE|0)==0|w^1)){aw=c[(c[2440392]|0)+(aE<<2)>>2]|0;a[au+36|0]=aw&255;a[au+37|0]=aw>>>8&255;a[au+38|0]=aw>>>16&255}aw=aC>>>24&15;if(!((aw|0)==0|v^1)){aE=c[(c[2440392]|0)+(aw<<2)>>2]|0;a[au+39|0]=aE&255;a[au+40|0]=aE>>>8&255;a[au+41|0]=aE>>>16&255}aE=aC>>>28;if((aE|0)==0|u^1){break}aC=c[(c[2440392]|0)+(aE<<2)>>2]|0;a[au+42|0]=aC&255;a[au+43|0]=aC>>>8&255;a[au+44|0]=aC>>>16&255;break}else{aC=c[2385344]|0;aE=c[aC+(aA<<2)>>2]|0;aw=aE&15;if(!((aw|0)==0|u^1)){aF=c[(c[2440392]|0)+(aw<<2)>>2]|0;a[au+42|0]=aF&255;a[au+43|0]=aF>>>8&255;a[au+44|0]=aF>>>16&255}aF=aE>>>4&15;if(!((aF|0)==0|v^1)){aw=c[(c[2440392]|0)+(aF<<2)>>2]|0;a[au+39|0]=aw&255;a[au+40|0]=aw>>>8&255;a[au+41|0]=aw>>>16&255}aw=aE>>>8&15;if(!((aw|0)==0|w^1)){aF=c[(c[2440392]|0)+(aw<<2)>>2]|0;a[au+36|0]=aF&255;a[au+37|0]=aF>>>8&255;a[au+38|0]=aF>>>16&255}aF=aE>>>12&15;if(!((aF|0)==0|x^1)){aw=c[(c[2440392]|0)+(aF<<2)>>2]|0;a[au+33|0]=aw&255;a[au+34|0]=aw>>>8&255;a[au+35|0]=aw>>>16&255}aw=aE>>>16&15;if(!((aw|0)==0|y^1)){aF=c[(c[2440392]|0)+(aw<<2)>>2]|0;a[au+30|0]=aF&255;a[au+31|0]=aF>>>8&255;a[au+32|0]=aF>>>16&255}aF=aE>>>24&15;if(!((aF|0)==0|z^1)){aw=c[(c[2440392]|0)+(aF<<2)>>2]|0;a[au+27|0]=aw&255;a[au+28|0]=aw>>>8&255;a[au+29|0]=aw>>>16&255}aw=aE>>>28;if(!((aw|0)==0|A^1)){aE=c[(c[2440392]|0)+(aw<<2)>>2]|0;a[au+24|0]=aE&255;a[au+25|0]=aE>>>8&255;a[au+26|0]=aE>>>16&255}aE=c[aC+((aA|1)<<2)>>2]|0;aA=aE&15;if(!((aA|0)==0|B^1)){aC=c[(c[2440392]|0)+(aA<<2)>>2]|0;a[au+21|0]=aC&255;a[au+22|0]=aC>>>8&255;a[au+23|0]=aC>>>16&255}aC=aE>>>4&15;if(!((aC|0)==0|C^1)){aA=c[(c[2440392]|0)+(aC<<2)>>2]|0;a[au+18|0]=aA&255;a[au+19|0]=aA>>>8&255;a[au+20|0]=aA>>>16&255}aA=aE>>>8&15;if(!((aA|0)==0|D^1)){aC=c[(c[2440392]|0)+(aA<<2)>>2]|0;a[au+15|0]=aC&255;a[au+16|0]=aC>>>8&255;a[au+17|0]=aC>>>16&255}aC=aE>>>12&15;if(!((aC|0)==0|E^1)){aA=c[(c[2440392]|0)+(aC<<2)>>2]|0;a[au+12|0]=aA&255;a[au+13|0]=aA>>>8&255;a[au+14|0]=aA>>>16&255}aA=aE>>>16&15;if(!((aA|0)==0|F^1)){aC=c[(c[2440392]|0)+(aA<<2)>>2]|0;a[au+9|0]=aC&255;a[au+10|0]=aC>>>8&255;a[au+11|0]=aC>>>16&255}aC=aE>>>20&15;if(!((aC|0)==0|G^1)){aA=c[(c[2440392]|0)+(aC<<2)>>2]|0;a[au+6|0]=aA&255;a[au+7|0]=aA>>>8&255;a[au+8|0]=aA>>>16&255}aA=aE>>>24&15;if(!((aA|0)==0|H^1)){aC=c[(c[2440392]|0)+(aA<<2)>>2]|0;a[au+3|0]=aC&255;a[au+4|0]=aC>>>8&255;a[au+5|0]=aC>>>16&255}aC=aE>>>28;if((aC|0)==0|t^1){break}aE=c[(c[2440392]|0)+(aC<<2)>>2]|0;a[au]=aE&255;a[au+1|0]=aE>>>8&255;a[au+2|0]=aE>>>16&255;break}}}while(0);av=X+1|0;if((av|0)>(W|0)){as=ay;at=ax;break}else{X=av;U=az;S=ay;aa=ax;au=au+p|0}}}if((an|0)>(i|0)){ai=37201;break}else{P=an;Q=as;R=at}}if((ai|0)==37200){return}else if((ai|0)==37201){return}}function czx(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0;b=c[3540994]|0;f=c[3528548]|0;g=f<<8;h=c[2385554]|0;do{if((h|0)>31){i=511}else{j=(h<<4)-1|0;if((j|0)>=0){i=j;break}return}}while(0);j=(i|0)>255;k=i&255;l=c[2385550]|0;m=c[2113042]|0;n=c[2113044]|0;o=m+512|0;p=c[2385552]|0;q=c[2113132]|0;r=p*3|0;s=c[2112968]|0;t=p+15|0;u=(t|0)>-1&(t|0)<(q|0);t=p+14|0;v=(t|0)>-1&(t|0)<(q|0);t=p+13|0;w=(t|0)>-1&(t|0)<(q|0);t=p+12|0;x=(t|0)>-1&(t|0)<(q|0);t=p+11|0;y=(t|0)>-1&(t|0)<(q|0);t=p+10|0;z=(t|0)>-1&(t|0)<(q|0);t=p+9|0;A=(t|0)>-1&(t|0)<(q|0);t=p+8|0;B=(t|0)>-1&(t|0)<(q|0);t=p+7|0;C=(t|0)>-1&(t|0)<(q|0);t=p+6|0;D=(t|0)>-1&(t|0)<(q|0);t=p+5|0;E=(t|0)>-1&(t|0)<(q|0);t=p+4|0;F=(t|0)>-1&(t|0)<(q|0);t=p+3|0;G=(t|0)>-1&(t|0)<(q|0);t=p+2|0;H=(t|0)>-1&(t|0)<(q|0);t=p+1|0;I=(t|0)>-1&(t|0)<(q|0);t=(p|0)>-1&(p|0)<(q|0);p=q*3|0;J=c[2415160]|0;K=c[2429858]|0;L=c[2430428]|0;M=c[2429718]|0;N=c[2430092]|0;O=c[3541046]|0;P=c[2430426]|0;Q=0;R=0;S=0;L43077:while(1){T=(h|0)>16&(f|0)!=255;U=(h|0)<33;V=511-f|0;W=f+1|0;X=f-255|0;Y=~f;Z=Q;L43079:while(1){_=Z+l|0;$=_&511;do{if(($|0)<(m|0)){aa=Z+m-$|0}else{if(($|0)>=(n|0)){aa=o+Z-$|0;break}ab=(Z|0)>255;ac=ab?16:0;ad=Z&255;ae=(Z|0)<256&j?255:k;if(!T){af=ac;ah=ad;ai=ae;aj=37226;break L43079}if(U){if(!ab){aj=37216;break L43079}if((Z|0)<(V|0)){aa=V;break}else{aj=37218;break L43079}}if(ab){ak=X+ad|0;if((ak|0)>=0){aj=37221;break L43079}ab=W+ak|0;if((ab|0)<0){aa=512;break}else{af=0;ah=ab;ai=f;aj=37226;break L43079}}else{if((ad|0)<=(f|0)){aj=37224;break L43079}ab=ad+Y|0;if((ab|0)>(f|0)){aa=256;break}else{af=16;ah=ab;ai=f;aj=37226;break L43079}}}}while(0);if((aa|0)>(i|0)){aj=37305;break L43077}else{Z=aa}}if((aj|0)==37218){aj=0;Y=255-f|0;af=ac;ah=ad-Y|0;ai=ae-Y|0;aj=37226}else if((aj|0)==37224){aj=0;al=f;am=ad;an=ac;ao=W+Z-ad|0}else if((aj|0)==37216){aj=0;ap=ae;aq=ad;ar=ac;as=Z+1-ad+ae|0;aj=37227}else if((aj|0)==37221){aj=0;al=f;am=ak;an=ac;ao=W+Z-ak|0}if((aj|0)==37226){aj=0;Y=Z+1+ai-ah|0;if(U){ap=ai;aq=ah;ar=af;as=Y;aj=37227}else{al=ai;am=ah;an=af;ao=Y}}if((aj|0)==37227){aj=0;al=(ap|0)>(f|0)?f:ap;am=aq;an=ar;ao=as}Y=((_|-512)^511)+n|0;X=(al-am|0)>(Y|0)?Y+am|0:al;if((am|0)>(X|0)){at=R;au=S}else{Y=am;V=-1;T=R;ab=S;av=s+((ag(q,($*3|0)-48|0)|0)+r)|0;while(1){aw=d[b+(Y+g)|0]|0;ax=(aw>>>4)+an|0;do{if((ax|0)==(V|0)){ay=ab;az=T;aA=V}else{aB=ax<<1;aC=e[J+((aB|1)<<1)>>1]|0;aD=(aC<<12&983040|(e[J+(aB<<1)>>1]|0))&K;do{if((aC&8|0)==0){if((aC&4|0)==0){aE=aD;break}aE=L|aD&1048572}else{aE=P|aD&1048568}}while(0);aD=a[M+aE|0]|0;aB=aD&255;if(aD<<24>>24!=0){ay=aB;az=aC;aA=ax;break}c[2385344]=N+(aE<<7);c[2440392]=O+((aC>>>4&4080)<<2);ay=aB;az=aC;aA=ax}}while(0);do{if((ay|0)==0){ax=aw<<1&30;aB=(az&2|0)==0?ax:ax^30;if((az&1|0)==0){ax=c[2385344]|0;aD=c[ax+(aB<<2)>>2]|0;aF=aD&15;if(!((aF|0)==0|t^1)){aG=c[(c[2440392]|0)+(aF<<2)>>2]|0;a[av]=aG&255;a[av+1|0]=aG>>>8&255;a[av+2|0]=aG>>>16&255}aG=aD>>>4&15;if(!((aG|0)==0|I^1)){aF=c[(c[2440392]|0)+(aG<<2)>>2]|0;a[av+3|0]=aF&255;a[av+4|0]=aF>>>8&255;a[av+5|0]=aF>>>16&255}aF=aD>>>8&15;if(!((aF|0)==0|H^1)){aG=c[(c[2440392]|0)+(aF<<2)>>2]|0;a[av+6|0]=aG&255;a[av+7|0]=aG>>>8&255;a[av+8|0]=aG>>>16&255}aG=aD>>>12&15;if(!((aG|0)==0|G^1)){aF=c[(c[2440392]|0)+(aG<<2)>>2]|0;a[av+9|0]=aF&255;a[av+10|0]=aF>>>8&255;a[av+11|0]=aF>>>16&255}aF=aD>>>16&15;if(!((aF|0)==0|F^1)){aG=c[(c[2440392]|0)+(aF<<2)>>2]|0;a[av+12|0]=aG&255;a[av+13|0]=aG>>>8&255;a[av+14|0]=aG>>>16&255}aG=aD>>>20&15;if(!((aG|0)==0|E^1)){aF=c[(c[2440392]|0)+(aG<<2)>>2]|0;a[av+15|0]=aF&255;a[av+16|0]=aF>>>8&255;a[av+17|0]=aF>>>16&255}aF=aD>>>24&15;if(!((aF|0)==0|D^1)){aG=c[(c[2440392]|0)+(aF<<2)>>2]|0;a[av+18|0]=aG&255;a[av+19|0]=aG>>>8&255;a[av+20|0]=aG>>>16&255}aG=aD>>>28;if(!((aG|0)==0|C^1)){aD=c[(c[2440392]|0)+(aG<<2)>>2]|0;a[av+21|0]=aD&255;a[av+22|0]=aD>>>8&255;a[av+23|0]=aD>>>16&255}aD=c[ax+((aB|1)<<2)>>2]|0;ax=aD&15;if(!((ax|0)==0|B^1)){aG=c[(c[2440392]|0)+(ax<<2)>>2]|0;a[av+24|0]=aG&255;a[av+25|0]=aG>>>8&255;a[av+26|0]=aG>>>16&255}aG=aD>>>4&15;if(!((aG|0)==0|A^1)){ax=c[(c[2440392]|0)+(aG<<2)>>2]|0;a[av+27|0]=ax&255;a[av+28|0]=ax>>>8&255;a[av+29|0]=ax>>>16&255}ax=aD>>>8&15;if(!((ax|0)==0|z^1)){aG=c[(c[2440392]|0)+(ax<<2)>>2]|0;a[av+30|0]=aG&255;a[av+31|0]=aG>>>8&255;a[av+32|0]=aG>>>16&255}aG=aD>>>12&15;if(!((aG|0)==0|y^1)){ax=c[(c[2440392]|0)+(aG<<2)>>2]|0;a[av+33|0]=ax&255;a[av+34|0]=ax>>>8&255;a[av+35|0]=ax>>>16&255}ax=aD>>>16&15;if(!((ax|0)==0|x^1)){aG=c[(c[2440392]|0)+(ax<<2)>>2]|0;a[av+36|0]=aG&255;a[av+37|0]=aG>>>8&255;a[av+38|0]=aG>>>16&255}aG=aD>>>20&15;if(!((aG|0)==0|w^1)){ax=c[(c[2440392]|0)+(aG<<2)>>2]|0;a[av+39|0]=ax&255;a[av+40|0]=ax>>>8&255;a[av+41|0]=ax>>>16&255}ax=aD>>>24&15;if(!((ax|0)==0|v^1)){aG=c[(c[2440392]|0)+(ax<<2)>>2]|0;a[av+42|0]=aG&255;a[av+43|0]=aG>>>8&255;a[av+44|0]=aG>>>16&255}aG=aD>>>28;if((aG|0)==0|u^1){break}aD=c[(c[2440392]|0)+(aG<<2)>>2]|0;a[av+45|0]=aD&255;a[av+46|0]=aD>>>8&255;a[av+47|0]=aD>>>16&255;break}else{aD=c[2385344]|0;aG=c[aD+(aB<<2)>>2]|0;ax=aG&15;if(!((ax|0)==0|u^1)){aF=c[(c[2440392]|0)+(ax<<2)>>2]|0;a[av+45|0]=aF&255;a[av+46|0]=aF>>>8&255;a[av+47|0]=aF>>>16&255}aF=aG>>>4&15;if(!((aF|0)==0|v^1)){ax=c[(c[2440392]|0)+(aF<<2)>>2]|0;a[av+42|0]=ax&255;a[av+43|0]=ax>>>8&255;a[av+44|0]=ax>>>16&255}ax=aG>>>8&15;if(!((ax|0)==0|w^1)){aF=c[(c[2440392]|0)+(ax<<2)>>2]|0;a[av+39|0]=aF&255;a[av+40|0]=aF>>>8&255;a[av+41|0]=aF>>>16&255}aF=aG>>>12&15;if(!((aF|0)==0|x^1)){ax=c[(c[2440392]|0)+(aF<<2)>>2]|0;a[av+36|0]=ax&255;a[av+37|0]=ax>>>8&255;a[av+38|0]=ax>>>16&255}ax=aG>>>16&15;if(!((ax|0)==0|y^1)){aF=c[(c[2440392]|0)+(ax<<2)>>2]|0;a[av+33|0]=aF&255;a[av+34|0]=aF>>>8&255;a[av+35|0]=aF>>>16&255}aF=aG>>>20&15;if(!((aF|0)==0|z^1)){ax=c[(c[2440392]|0)+(aF<<2)>>2]|0;a[av+30|0]=ax&255;a[av+31|0]=ax>>>8&255;a[av+32|0]=ax>>>16&255}ax=aG>>>24&15;if(!((ax|0)==0|A^1)){aF=c[(c[2440392]|0)+(ax<<2)>>2]|0;a[av+27|0]=aF&255;a[av+28|0]=aF>>>8&255;a[av+29|0]=aF>>>16&255}aF=aG>>>28;if(!((aF|0)==0|B^1)){aG=c[(c[2440392]|0)+(aF<<2)>>2]|0;a[av+24|0]=aG&255;a[av+25|0]=aG>>>8&255;a[av+26|0]=aG>>>16&255}aG=c[aD+((aB|1)<<2)>>2]|0;aB=aG&15;if(!((aB|0)==0|C^1)){aD=c[(c[2440392]|0)+(aB<<2)>>2]|0;a[av+21|0]=aD&255;a[av+22|0]=aD>>>8&255;a[av+23|0]=aD>>>16&255}aD=aG>>>4&15;if(!((aD|0)==0|D^1)){aB=c[(c[2440392]|0)+(aD<<2)>>2]|0;a[av+18|0]=aB&255;a[av+19|0]=aB>>>8&255;a[av+20|0]=aB>>>16&255}aB=aG>>>8&15;if(!((aB|0)==0|E^1)){aD=c[(c[2440392]|0)+(aB<<2)>>2]|0;a[av+15|0]=aD&255;a[av+16|0]=aD>>>8&255;a[av+17|0]=aD>>>16&255}aD=aG>>>12&15;if(!((aD|0)==0|F^1)){aB=c[(c[2440392]|0)+(aD<<2)>>2]|0;a[av+12|0]=aB&255;a[av+13|0]=aB>>>8&255;a[av+14|0]=aB>>>16&255}aB=aG>>>16&15;if(!((aB|0)==0|G^1)){aD=c[(c[2440392]|0)+(aB<<2)>>2]|0;a[av+9|0]=aD&255;a[av+10|0]=aD>>>8&255;a[av+11|0]=aD>>>16&255}aD=aG>>>20&15;if(!((aD|0)==0|H^1)){aB=c[(c[2440392]|0)+(aD<<2)>>2]|0;a[av+6|0]=aB&255;a[av+7|0]=aB>>>8&255;a[av+8|0]=aB>>>16&255}aB=aG>>>24&15;if(!((aB|0)==0|I^1)){aD=c[(c[2440392]|0)+(aB<<2)>>2]|0;a[av+3|0]=aD&255;a[av+4|0]=aD>>>8&255;a[av+5|0]=aD>>>16&255}aD=aG>>>28;if((aD|0)==0|t^1){break}aG=c[(c[2440392]|0)+(aD<<2)>>2]|0;a[av]=aG&255;a[av+1|0]=aG>>>8&255;a[av+2|0]=aG>>>16&255;break}}}while(0);aw=Y+1|0;if((aw|0)>(X|0)){at=az;au=ay;break}else{Y=aw;V=aA;T=az;ab=ay;av=av+p|0}}}if((ao|0)>(i|0)){aj=37306;break}else{Q=ao;R=at;S=au}}if((aj|0)==37305){return}else if((aj|0)==37306){return}}function czy(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0;b=c[3540994]|0;f=c[3528548]|0;g=f<<8;h=c[2385554]|0;do{if((h|0)>31){i=511}else{j=(h<<4)-1|0;if((j|0)>=0){i=j;break}return}}while(0);j=(i|0)>255;k=i&255;l=c[2385550]|0;m=c[2113042]|0;n=c[2113044]|0;o=m+512|0;p=c[2113132]|0;q=c[2385552]<<2;r=c[2112968]|0;s=p<<2;t=c[2415160]|0;u=c[2429858]|0;v=c[2430428]|0;w=c[2429718]|0;x=c[2430092]|0;y=c[3541046]|0;z=c[2430426]|0;A=0;B=0;C=0;L43228:while(1){D=(h|0)>16&(f|0)!=255;E=(h|0)<33;F=511-f|0;G=f+1|0;H=f-255|0;I=~f;J=C;L43230:while(1){K=J+l|0;L=K&511;do{if((L|0)<(m|0)){M=J+m-L|0}else{if((L|0)>=(n|0)){M=o+J-L|0;break}N=(J|0)>255;O=N?16:0;P=J&255;Q=(J|0)<256&j?255:k;if(!D){R=Q;S=P;T=O;U=37331;break L43230}if(E){if(!N){U=37321;break L43230}if((J|0)<(F|0)){M=F;break}else{U=37323;break L43230}}if(N){V=H+P|0;if((V|0)>=0){U=37326;break L43230}N=G+V|0;if((N|0)<0){M=512;break}else{R=f;S=N;T=0;U=37331;break L43230}}else{if((P|0)<=(f|0)){U=37329;break L43230}N=P+I|0;if((N|0)>(f|0)){M=256;break}else{R=f;S=N;T=16;U=37331;break L43230}}}}while(0);if((M|0)>(i|0)){U=37350;break L43228}else{J=M}}if((U|0)==37323){U=0;I=255-f|0;R=Q-I|0;S=P-I|0;T=O;U=37331}else if((U|0)==37329){U=0;W=f;X=O;Y=P;Z=G+J-P|0}else if((U|0)==37326){U=0;W=f;X=O;Y=V;Z=G+J-V|0}else if((U|0)==37321){U=0;_=O;$=P;aa=Q;ab=J+1-P+Q|0;U=37332}if((U|0)==37331){U=0;I=J+1-S+R|0;if(E){_=T;$=S;aa=R;ab=I;U=37332}else{W=R;X=T;Y=S;Z=I}}if((U|0)==37332){U=0;W=(aa|0)>(f|0)?f:aa;X=_;Y=$;Z=ab}I=((K|-512)^511)+n|0;H=(W-Y|0)>(I|0)?I+Y|0:W;if((Y|0)>(H|0)){ac=A;ad=B}else{I=A;F=B;D=-1;N=r+((ag(p,(L<<2)-64|0)|0)+q)|0;ae=Y;while(1){af=d[b+(ae+g)|0]|0;ah=(af>>>4)+X|0;do{if((ah|0)==(D|0)){ai=D;aj=F;ak=I}else{al=ah<<1;am=e[t+((al|1)<<1)>>1]|0;an=(am<<12&983040|(e[t+(al<<1)>>1]|0))&u;do{if((am&8|0)==0){if((am&4|0)==0){ao=an;break}ao=v|an&1048572}else{ao=z|an&1048568}}while(0);an=a[w+ao|0]|0;al=an&255;if(an<<24>>24!=0){ai=ah;aj=al;ak=am;break}c[2385344]=x+(ao<<7);c[2440392]=y+((am>>>4&4080)<<2);ai=ah;aj=al;ak=am}}while(0);do{if((aj|0)==0){ah=af<<1&30;al=c[(c[2385344]|0)+((((ak&2|0)==0?ah:ah^30)|1)<<2)>>2]&15;ah=(al|0)==0;if((ak&1|0)==0){if(ah){break}c[N>>2]=c[(c[2440392]|0)+(al<<2)>>2];break}else{if(ah){break}c[N>>2]=c[(c[2440392]|0)+(al<<2)>>2];break}}}while(0);af=ae+1|0;if((af|0)>(H|0)){ac=ak;ad=aj;break}else{I=ak;F=aj;D=ai;N=N+s|0;ae=af}}}if((Z|0)>(i|0)){U=37352;break}else{A=ac;B=ad;C=Z}}if((U|0)==37352){return}else if((U|0)==37350){return}}function czz(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0;b=c[3540994]|0;f=c[3528548]|0;g=f<<8;h=c[2385554]|0;do{if((h|0)>31){i=511}else{j=(h<<4)-1|0;if((j|0)>=0){i=j;break}return}}while(0);j=(i|0)>255;k=i&255;l=c[2385550]|0;m=c[2113042]|0;n=c[2113044]|0;o=m+512|0;p=c[2113132]|0;q=c[2385552]<<2;r=c[2112968]|0;s=p<<2;t=c[2415160]|0;u=c[2429858]|0;v=c[2430428]|0;w=c[2429718]|0;x=c[2430092]|0;y=c[3541046]|0;z=c[2430426]|0;A=0;B=0;C=0;L43289:while(1){D=(h|0)>16&(f|0)!=255;E=(h|0)<33;F=511-f|0;G=f+1|0;H=f-255|0;I=~f;J=C;L43291:while(1){K=J+l|0;L=K&511;do{if((L|0)<(m|0)){M=J+m-L|0}else{if((L|0)>=(n|0)){M=o+J-L|0;break}N=(J|0)>255;O=N?16:0;P=J&255;Q=(J|0)<256&j?255:k;if(!D){R=Q;S=P;T=O;U=37376;break L43291}if(E){if(!N){U=37366;break L43291}if((J|0)<(F|0)){M=F;break}else{U=37368;break L43291}}if(N){V=H+P|0;if((V|0)>=0){U=37371;break L43291}N=G+V|0;if((N|0)<0){M=512;break}else{R=f;S=N;T=0;U=37376;break L43291}}else{if((P|0)<=(f|0)){U=37374;break L43291}N=P+I|0;if((N|0)>(f|0)){M=256;break}else{R=f;S=N;T=16;U=37376;break L43291}}}}while(0);if((M|0)>(i|0)){U=37399;break L43289}else{J=M}}if((U|0)==37371){U=0;W=f;X=O;Y=V;Z=G+J-V|0}else if((U|0)==37368){U=0;I=255-f|0;R=Q-I|0;S=P-I|0;T=O;U=37376}else if((U|0)==37374){U=0;W=f;X=O;Y=P;Z=G+J-P|0}else if((U|0)==37366){U=0;_=O;$=P;aa=Q;ab=J+1-P+Q|0;U=37377}if((U|0)==37376){U=0;I=J+1-S+R|0;if(E){_=T;$=S;aa=R;ab=I;U=37377}else{W=R;X=T;Y=S;Z=I}}if((U|0)==37377){U=0;W=(aa|0)>(f|0)?f:aa;X=_;Y=$;Z=ab}I=((K|-512)^511)+n|0;H=(W-Y|0)>(I|0)?I+Y|0:W;if((Y|0)>(H|0)){ac=A;ad=B}else{I=A;F=B;D=-1;N=r+((ag(p,(L<<2)-64|0)|0)+q)|0;ae=Y;while(1){af=d[b+(ae+g)|0]|0;ah=(af>>>4)+X|0;do{if((ah|0)==(D|0)){ai=D;aj=F;ak=I}else{al=ah<<1;am=e[t+((al|1)<<1)>>1]|0;an=(am<<12&983040|(e[t+(al<<1)>>1]|0))&u;do{if((am&8|0)==0){if((am&4|0)==0){ao=an;break}ao=v|an&1048572}else{ao=z|an&1048568}}while(0);an=a[w+ao|0]|0;al=an&255;if(an<<24>>24!=0){ai=ah;aj=al;ak=am;break}c[2385344]=x+(ao<<7);c[2440392]=y+((am>>>4&4080)<<2);ai=ah;aj=al;ak=am}}while(0);do{if((aj|0)==0){ah=af<<1&30;al=(ak&2|0)==0?ah:ah^30;ah=c[2385344]|0;an=(c[ah+(al<<2)>>2]|0)>>>16&15;ap=(an|0)==0;if((ak&1|0)==0){if(!ap){c[N>>2]=c[(c[2440392]|0)+(an<<2)>>2]}aq=c[ah+((al|1)<<2)>>2]&15;if((aq|0)==0){break}c[N+4>>2]=c[(c[2440392]|0)+(aq<<2)>>2];break}else{if(!ap){c[N+4>>2]=c[(c[2440392]|0)+(an<<2)>>2]}an=c[ah+((al|1)<<2)>>2]&15;if((an|0)==0){break}c[N>>2]=c[(c[2440392]|0)+(an<<2)>>2];break}}}while(0);af=ae+1|0;if((af|0)>(H|0)){ac=ak;ad=aj;break}else{I=ak;F=aj;D=ai;N=N+s|0;ae=af}}}if((Z|0)>(i|0)){U=37400;break}else{A=ac;B=ad;C=Z}}if((U|0)==37400){return}else if((U|0)==37399){return}}function czA(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0;b=c[3540994]|0;f=c[3528548]|0;g=f<<8;h=c[2385554]|0;do{if((h|0)>31){i=511}else{j=(h<<4)-1|0;if((j|0)>=0){i=j;break}return}}while(0);j=(i|0)>255;k=i&255;l=c[2385550]|0;m=c[2113042]|0;n=c[2113044]|0;o=m+512|0;p=c[2113132]|0;q=c[2385552]<<2;r=c[2112968]|0;s=p<<2;t=c[2415160]|0;u=c[2429858]|0;v=c[2430428]|0;w=c[2429718]|0;x=c[2430092]|0;y=c[3541046]|0;z=c[2430426]|0;A=0;B=0;C=0;L43356:while(1){D=(h|0)>16&(f|0)!=255;E=(h|0)<33;F=511-f|0;G=f+1|0;H=f-255|0;I=~f;J=C;L43358:while(1){K=J+l|0;L=K&511;do{if((L|0)<(m|0)){M=J+m-L|0}else{if((L|0)>=(n|0)){M=o+J-L|0;break}N=(J|0)>255;O=N?16:0;P=J&255;Q=(J|0)<256&j?255:k;if(!D){R=Q;S=P;T=O;U=37425;break L43358}if(E){if(!N){U=37415;break L43358}if((J|0)<(F|0)){M=F;break}else{U=37417;break L43358}}if(N){V=H+P|0;if((V|0)>=0){U=37420;break L43358}N=G+V|0;if((N|0)<0){M=512;break}else{R=f;S=N;T=0;U=37425;break L43358}}else{if((P|0)<=(f|0)){U=37423;break L43358}N=P+I|0;if((N|0)>(f|0)){M=256;break}else{R=f;S=N;T=16;U=37425;break L43358}}}}while(0);if((M|0)>(i|0)){U=37452;break L43356}else{J=M}}if((U|0)==37423){U=0;W=f;X=O;Y=P;Z=G+J-P|0}else if((U|0)==37415){U=0;_=O;$=P;aa=Q;ab=J+1-P+Q|0;U=37426}else if((U|0)==37417){U=0;I=255-f|0;R=Q-I|0;S=P-I|0;T=O;U=37425}else if((U|0)==37420){U=0;W=f;X=O;Y=V;Z=G+J-V|0}if((U|0)==37425){U=0;I=J+1-S+R|0;if(E){_=T;$=S;aa=R;ab=I;U=37426}else{W=R;X=T;Y=S;Z=I}}if((U|0)==37426){U=0;W=(aa|0)>(f|0)?f:aa;X=_;Y=$;Z=ab}I=((K|-512)^511)+n|0;H=(W-Y|0)>(I|0)?I+Y|0:W;if((Y|0)>(H|0)){ac=A;ad=B}else{I=A;F=B;D=-1;N=r+((ag(p,(L<<2)-64|0)|0)+q)|0;ae=Y;while(1){af=d[b+(ae+g)|0]|0;ah=(af>>>4)+X|0;do{if((ah|0)==(D|0)){ai=D;aj=F;ak=I}else{al=ah<<1;am=e[t+((al|1)<<1)>>1]|0;an=(am<<12&983040|(e[t+(al<<1)>>1]|0))&u;do{if((am&8|0)==0){if((am&4|0)==0){ao=an;break}ao=v|an&1048572}else{ao=z|an&1048568}}while(0);an=a[w+ao|0]|0;al=an&255;if(an<<24>>24!=0){ai=ah;aj=al;ak=am;break}c[2385344]=x+(ao<<7);c[2440392]=y+((am>>>4&4080)<<2);ai=ah;aj=al;ak=am}}while(0);do{if((aj|0)==0){ah=af<<1&30;al=(ak&2|0)==0?ah:ah^30;ah=c[2385344]|0;an=(c[ah+(al<<2)>>2]|0)>>>16&15;ap=(an|0)==0;if((ak&1|0)==0){if(!ap){c[N>>2]=c[(c[2440392]|0)+(an<<2)>>2]}aq=c[ah+((al|1)<<2)>>2]|0;ar=aq&15;if((ar|0)!=0){c[N+4>>2]=c[(c[2440392]|0)+(ar<<2)>>2]}ar=aq>>>16&15;if((ar|0)==0){break}c[N+8>>2]=c[(c[2440392]|0)+(ar<<2)>>2];break}else{if(!ap){c[N+8>>2]=c[(c[2440392]|0)+(an<<2)>>2]}an=c[ah+((al|1)<<2)>>2]|0;al=an&15;if((al|0)!=0){c[N+4>>2]=c[(c[2440392]|0)+(al<<2)>>2]}al=an>>>16&15;if((al|0)==0){break}c[N>>2]=c[(c[2440392]|0)+(al<<2)>>2];break}}}while(0);af=ae+1|0;if((af|0)>(H|0)){ac=ak;ad=aj;break}else{I=ak;F=aj;D=ai;N=N+s|0;ae=af}}}if((Z|0)>(i|0)){U=37454;break}else{A=ac;B=ad;C=Z}}if((U|0)==37452){return}else if((U|0)==37454){return}}function czB(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0;b=c[3540994]|0;f=c[3528548]|0;g=f<<8;h=c[2385554]|0;do{if((h|0)>31){i=511}else{j=(h<<4)-1|0;if((j|0)>=0){i=j;break}return}}while(0);j=(i|0)>255;k=i&255;l=c[2385550]|0;m=c[2113042]|0;n=c[2113044]|0;o=m+512|0;p=c[2113132]|0;q=c[2385552]<<2;r=c[2112968]|0;s=p<<2;t=c[2415160]|0;u=c[2429858]|0;v=c[2430428]|0;w=c[2429718]|0;x=c[2430092]|0;y=c[3541046]|0;z=c[2430426]|0;A=0;B=0;C=0;L43429:while(1){D=(h|0)>16&(f|0)!=255;E=(h|0)<33;F=511-f|0;G=f+1|0;H=f-255|0;I=~f;J=C;L43431:while(1){K=J+l|0;L=K&511;do{if((L|0)<(m|0)){M=J+m-L|0}else{if((L|0)>=(n|0)){M=o+J-L|0;break}N=(J|0)>255;O=N?16:0;P=J&255;Q=(J|0)<256&j?255:k;if(!D){R=Q;S=P;T=O;U=37478;break L43431}if(E){if(!N){U=37468;break L43431}if((J|0)<(F|0)){M=F;break}else{U=37470;break L43431}}if(N){V=H+P|0;if((V|0)>=0){U=37473;break L43431}N=G+V|0;if((N|0)<0){M=512;break}else{R=f;S=N;T=0;U=37478;break L43431}}else{if((P|0)<=(f|0)){U=37476;break L43431}N=P+I|0;if((N|0)>(f|0)){M=256;break}else{R=f;S=N;T=16;U=37478;break L43431}}}}while(0);if((M|0)>(i|0)){U=37509;break L43429}else{J=M}}if((U|0)==37473){U=0;W=f;X=O;Y=V;Z=G+J-V|0}else if((U|0)==37470){U=0;I=255-f|0;R=Q-I|0;S=P-I|0;T=O;U=37478}else if((U|0)==37468){U=0;_=O;$=P;aa=Q;ab=J+1-P+Q|0;U=37479}else if((U|0)==37476){U=0;W=f;X=O;Y=P;Z=G+J-P|0}if((U|0)==37478){U=0;I=J+1-S+R|0;if(E){_=T;$=S;aa=R;ab=I;U=37479}else{W=R;X=T;Y=S;Z=I}}if((U|0)==37479){U=0;W=(aa|0)>(f|0)?f:aa;X=_;Y=$;Z=ab}I=((K|-512)^511)+n|0;H=(W-Y|0)>(I|0)?I+Y|0:W;if((Y|0)>(H|0)){ac=A;ad=B}else{I=A;F=B;D=-1;N=r+((ag(p,(L<<2)-64|0)|0)+q)|0;ae=Y;while(1){af=d[b+(ae+g)|0]|0;ah=(af>>>4)+X|0;do{if((ah|0)==(D|0)){ai=D;aj=F;ak=I}else{al=ah<<1;am=e[t+((al|1)<<1)>>1]|0;an=(am<<12&983040|(e[t+(al<<1)>>1]|0))&u;do{if((am&8|0)==0){if((am&4|0)==0){ao=an;break}ao=v|an&1048572}else{ao=z|an&1048568}}while(0);an=a[w+ao|0]|0;al=an&255;if(an<<24>>24!=0){ai=ah;aj=al;ak=am;break}c[2385344]=x+(ao<<7);c[2440392]=y+((am>>>4&4080)<<2);ai=ah;aj=al;ak=am}}while(0);do{if((aj|0)==0){ah=af<<1&30;al=(ak&2|0)==0?ah:ah^30;ah=c[2385344]|0;an=c[ah+(al<<2)>>2]|0;ap=an>>>8&15;aq=(ap|0)==0;if((ak&1|0)==0){if(!aq){c[N>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ar=an>>>16&15;if((ar|0)!=0){c[N+4>>2]=c[(c[2440392]|0)+(ar<<2)>>2]}ar=c[ah+((al|1)<<2)>>2]|0;as=ar&15;if((as|0)!=0){c[N+8>>2]=c[(c[2440392]|0)+(as<<2)>>2]}as=ar>>>16&15;if((as|0)==0){break}c[N+12>>2]=c[(c[2440392]|0)+(as<<2)>>2];break}else{if(!aq){c[N+12>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ap=an>>>16&15;if((ap|0)!=0){c[N+8>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ap=c[ah+((al|1)<<2)>>2]|0;al=ap&15;if((al|0)!=0){c[N+4>>2]=c[(c[2440392]|0)+(al<<2)>>2]}al=ap>>>16&15;if((al|0)==0){break}c[N>>2]=c[(c[2440392]|0)+(al<<2)>>2];break}}}while(0);af=ae+1|0;if((af|0)>(H|0)){ac=ak;ad=aj;break}else{I=ak;F=aj;D=ai;N=N+s|0;ae=af}}}if((Z|0)>(i|0)){U=37510;break}else{A=ac;B=ad;C=Z}}if((U|0)==37509){return}else if((U|0)==37510){return}}function czC(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0;b=c[3540994]|0;f=c[3528548]|0;g=f<<8;h=c[2385554]|0;do{if((h|0)>31){i=511}else{j=(h<<4)-1|0;if((j|0)>=0){i=j;break}return}}while(0);j=(i|0)>255;k=i&255;l=c[2385550]|0;m=c[2113042]|0;n=c[2113044]|0;o=m+512|0;p=c[2113132]|0;q=c[2385552]<<2;r=c[2112968]|0;s=p<<2;t=c[2415160]|0;u=c[2429858]|0;v=c[2430428]|0;w=c[2429718]|0;x=c[2430092]|0;y=c[3541046]|0;z=c[2430426]|0;A=0;B=0;C=0;L43508:while(1){D=(h|0)>16&(f|0)!=255;E=(h|0)<33;F=511-f|0;G=f+1|0;H=f-255|0;I=~f;J=C;L43510:while(1){K=J+l|0;L=K&511;do{if((L|0)<(m|0)){M=J+m-L|0}else{if((L|0)>=(n|0)){M=o+J-L|0;break}N=(J|0)>255;O=N?16:0;P=J&255;Q=(J|0)<256&j?255:k;if(!D){R=Q;S=P;T=O;U=37535;break L43510}if(E){if(!N){U=37525;break L43510}if((J|0)<(F|0)){M=F;break}else{U=37527;break L43510}}if(N){V=H+P|0;if((V|0)>=0){U=37530;break L43510}N=G+V|0;if((N|0)<0){M=512;break}else{R=f;S=N;T=0;U=37535;break L43510}}else{if((P|0)<=(f|0)){U=37533;break L43510}N=P+I|0;if((N|0)>(f|0)){M=256;break}else{R=f;S=N;T=16;U=37535;break L43510}}}}while(0);if((M|0)>(i|0)){U=37572;break L43508}else{J=M}}if((U|0)==37525){U=0;W=O;X=P;Y=Q;Z=J+1-P+Q|0;U=37536}else if((U|0)==37533){U=0;_=f;$=O;aa=P;ab=G+J-P|0}else if((U|0)==37530){U=0;_=f;$=O;aa=V;ab=G+J-V|0}else if((U|0)==37527){U=0;I=255-f|0;R=Q-I|0;S=P-I|0;T=O;U=37535}if((U|0)==37535){U=0;I=J+1-S+R|0;if(E){W=T;X=S;Y=R;Z=I;U=37536}else{_=R;$=T;aa=S;ab=I}}if((U|0)==37536){U=0;_=(Y|0)>(f|0)?f:Y;$=W;aa=X;ab=Z}I=((K|-512)^511)+n|0;H=(_-aa|0)>(I|0)?I+aa|0:_;if((aa|0)>(H|0)){ac=A;ad=B}else{I=A;F=B;D=-1;N=r+((ag(p,(L<<2)-64|0)|0)+q)|0;ae=aa;while(1){af=d[b+(ae+g)|0]|0;ah=(af>>>4)+$|0;do{if((ah|0)==(D|0)){ai=D;aj=F;ak=I}else{al=ah<<1;am=e[t+((al|1)<<1)>>1]|0;an=(am<<12&983040|(e[t+(al<<1)>>1]|0))&u;do{if((am&8|0)==0){if((am&4|0)==0){ao=an;break}ao=v|an&1048572}else{ao=z|an&1048568}}while(0);an=a[w+ao|0]|0;al=an&255;if(an<<24>>24!=0){ai=ah;aj=al;ak=am;break}c[2385344]=x+(ao<<7);c[2440392]=y+((am>>>4&4080)<<2);ai=ah;aj=al;ak=am}}while(0);do{if((aj|0)==0){ah=af<<1&30;al=(ak&2|0)==0?ah:ah^30;ah=c[2385344]|0;an=c[ah+(al<<2)>>2]|0;ap=an>>>8&15;aq=(ap|0)==0;if((ak&1|0)==0){if(!aq){c[N>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ar=an>>>16&15;if((ar|0)!=0){c[N+4>>2]=c[(c[2440392]|0)+(ar<<2)>>2]}ar=c[ah+((al|1)<<2)>>2]|0;as=ar&15;if((as|0)!=0){c[N+8>>2]=c[(c[2440392]|0)+(as<<2)>>2]}as=ar>>>16&15;if((as|0)!=0){c[N+12>>2]=c[(c[2440392]|0)+(as<<2)>>2]}as=ar>>>24&15;if((as|0)==0){break}c[N+16>>2]=c[(c[2440392]|0)+(as<<2)>>2];break}else{if(!aq){c[N+16>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ap=an>>>16&15;if((ap|0)!=0){c[N+12>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ap=c[ah+((al|1)<<2)>>2]|0;al=ap&15;if((al|0)!=0){c[N+8>>2]=c[(c[2440392]|0)+(al<<2)>>2]}al=ap>>>16&15;if((al|0)!=0){c[N+4>>2]=c[(c[2440392]|0)+(al<<2)>>2]}al=ap>>>24&15;if((al|0)==0){break}c[N>>2]=c[(c[2440392]|0)+(al<<2)>>2];break}}}while(0);af=ae+1|0;if((af|0)>(H|0)){ac=ak;ad=aj;break}else{I=ak;F=aj;D=ai;N=N+s|0;ae=af}}}if((ab|0)>(i|0)){U=37570;break}else{A=ac;B=ad;C=ab}}if((U|0)==37570){return}else if((U|0)==37572){return}}function czD(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0;b=c[3540994]|0;f=c[3528548]|0;g=f<<8;h=c[2385554]|0;do{if((h|0)>31){i=511}else{j=(h<<4)-1|0;if((j|0)>=0){i=j;break}return}}while(0);j=(i|0)>255;k=i&255;l=c[2385550]|0;m=c[2113042]|0;n=c[2113044]|0;o=m+512|0;p=c[2113132]|0;q=c[2385552]<<2;r=c[2112968]|0;s=p<<2;t=c[2415160]|0;u=c[2429858]|0;v=c[2430428]|0;w=c[2429718]|0;x=c[2430092]|0;y=c[3541046]|0;z=c[2430426]|0;A=0;B=0;C=0;L43593:while(1){D=(h|0)>16&(f|0)!=255;E=(h|0)<33;F=511-f|0;G=f+1|0;H=f-255|0;I=~f;J=C;L43595:while(1){K=J+l|0;L=K&511;do{if((L|0)<(m|0)){M=J+m-L|0}else{if((L|0)>=(n|0)){M=o+J-L|0;break}N=(J|0)>255;O=N?16:0;P=J&255;Q=(J|0)<256&j?255:k;if(!D){R=Q;S=P;T=O;U=37596;break L43595}if(E){if(!N){U=37586;break L43595}if((J|0)<(F|0)){M=F;break}else{U=37588;break L43595}}if(N){V=H+P|0;if((V|0)>=0){U=37591;break L43595}N=G+V|0;if((N|0)<0){M=512;break}else{R=f;S=N;T=0;U=37596;break L43595}}else{if((P|0)<=(f|0)){U=37594;break L43595}N=P+I|0;if((N|0)>(f|0)){M=256;break}else{R=f;S=N;T=16;U=37596;break L43595}}}}while(0);if((M|0)>(i|0)){U=37635;break L43593}else{J=M}}if((U|0)==37588){U=0;I=255-f|0;R=Q-I|0;S=P-I|0;T=O;U=37596}else if((U|0)==37591){U=0;W=f;X=O;Y=V;Z=G+J-V|0}else if((U|0)==37586){U=0;_=O;$=P;aa=Q;ab=J+1-P+Q|0;U=37597}else if((U|0)==37594){U=0;W=f;X=O;Y=P;Z=G+J-P|0}if((U|0)==37596){U=0;I=J+1-S+R|0;if(E){_=T;$=S;aa=R;ab=I;U=37597}else{W=R;X=T;Y=S;Z=I}}if((U|0)==37597){U=0;W=(aa|0)>(f|0)?f:aa;X=_;Y=$;Z=ab}I=((K|-512)^511)+n|0;H=(W-Y|0)>(I|0)?I+Y|0:W;if((Y|0)>(H|0)){ac=A;ad=B}else{I=A;F=B;D=-1;N=r+((ag(p,(L<<2)-64|0)|0)+q)|0;ae=Y;while(1){af=d[b+(ae+g)|0]|0;ah=(af>>>4)+X|0;do{if((ah|0)==(D|0)){ai=D;aj=F;ak=I}else{al=ah<<1;am=e[t+((al|1)<<1)>>1]|0;an=(am<<12&983040|(e[t+(al<<1)>>1]|0))&u;do{if((am&8|0)==0){if((am&4|0)==0){ao=an;break}ao=v|an&1048572}else{ao=z|an&1048568}}while(0);an=a[w+ao|0]|0;al=an&255;if(an<<24>>24!=0){ai=ah;aj=al;ak=am;break}c[2385344]=x+(ao<<7);c[2440392]=y+((am>>>4&4080)<<2);ai=ah;aj=al;ak=am}}while(0);do{if((aj|0)==0){ah=af<<1&30;al=(ak&2|0)==0?ah:ah^30;ah=c[2385344]|0;an=c[ah+(al<<2)>>2]|0;ap=an>>>8&15;aq=(ap|0)==0;if((ak&1|0)==0){if(!aq){c[N>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ar=an>>>16&15;if((ar|0)!=0){c[N+4>>2]=c[(c[2440392]|0)+(ar<<2)>>2]}ar=an>>>24&15;if((ar|0)!=0){c[N+8>>2]=c[(c[2440392]|0)+(ar<<2)>>2]}ar=c[ah+((al|1)<<2)>>2]|0;as=ar&15;if((as|0)!=0){c[N+12>>2]=c[(c[2440392]|0)+(as<<2)>>2]}as=ar>>>16&15;if((as|0)!=0){c[N+16>>2]=c[(c[2440392]|0)+(as<<2)>>2]}as=ar>>>24&15;if((as|0)==0){break}c[N+20>>2]=c[(c[2440392]|0)+(as<<2)>>2];break}else{if(!aq){c[N+20>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ap=an>>>16&15;if((ap|0)!=0){c[N+16>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ap=an>>>24&15;if((ap|0)!=0){c[N+12>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ap=c[ah+((al|1)<<2)>>2]|0;al=ap&15;if((al|0)!=0){c[N+8>>2]=c[(c[2440392]|0)+(al<<2)>>2]}al=ap>>>16&15;if((al|0)!=0){c[N+4>>2]=c[(c[2440392]|0)+(al<<2)>>2]}al=ap>>>24&15;if((al|0)==0){break}c[N>>2]=c[(c[2440392]|0)+(al<<2)>>2];break}}}while(0);af=ae+1|0;if((af|0)>(H|0)){ac=ak;ad=aj;break}else{I=ak;F=aj;D=ai;N=N+s|0;ae=af}}}if((Z|0)>(i|0)){U=37636;break}else{A=ac;B=ad;C=Z}}if((U|0)==37635){return}else if((U|0)==37636){return}}function czE(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0;b=c[3540994]|0;f=c[3528548]|0;g=f<<8;h=c[2385554]|0;do{if((h|0)>31){i=511}else{j=(h<<4)-1|0;if((j|0)>=0){i=j;break}return}}while(0);j=(i|0)>255;k=i&255;l=c[2385550]|0;m=c[2113042]|0;n=c[2113044]|0;o=m+512|0;p=c[2113132]|0;q=c[2385552]<<2;r=c[2112968]|0;s=p<<2;t=c[2415160]|0;u=c[2429858]|0;v=c[2430428]|0;w=c[2429718]|0;x=c[2430092]|0;y=c[3541046]|0;z=c[2430426]|0;A=0;B=0;C=0;L43684:while(1){D=(h|0)>16&(f|0)!=255;E=(h|0)<33;F=511-f|0;G=f+1|0;H=f-255|0;I=~f;J=C;L43686:while(1){K=J+l|0;L=K&511;do{if((L|0)<(m|0)){M=J+m-L|0}else{if((L|0)>=(n|0)){M=o+J-L|0;break}N=(J|0)>255;O=N?16:0;P=J&255;Q=(J|0)<256&j?255:k;if(!D){R=Q;S=P;T=O;U=37661;break L43686}if(E){if(!N){U=37651;break L43686}if((J|0)<(F|0)){M=F;break}else{U=37653;break L43686}}if(N){V=H+P|0;if((V|0)>=0){U=37656;break L43686}N=G+V|0;if((N|0)<0){M=512;break}else{R=f;S=N;T=0;U=37661;break L43686}}else{if((P|0)<=(f|0)){U=37659;break L43686}N=P+I|0;if((N|0)>(f|0)){M=256;break}else{R=f;S=N;T=16;U=37661;break L43686}}}}while(0);if((M|0)>(i|0)){U=37706;break L43684}else{J=M}}if((U|0)==37651){U=0;W=O;X=P;Y=Q;Z=J+1-P+Q|0;U=37662}else if((U|0)==37656){U=0;_=f;$=O;aa=V;ab=G+J-V|0}else if((U|0)==37653){U=0;I=255-f|0;R=Q-I|0;S=P-I|0;T=O;U=37661}else if((U|0)==37659){U=0;_=f;$=O;aa=P;ab=G+J-P|0}if((U|0)==37661){U=0;I=J+1-S+R|0;if(E){W=T;X=S;Y=R;Z=I;U=37662}else{_=R;$=T;aa=S;ab=I}}if((U|0)==37662){U=0;_=(Y|0)>(f|0)?f:Y;$=W;aa=X;ab=Z}I=((K|-512)^511)+n|0;H=(_-aa|0)>(I|0)?I+aa|0:_;if((aa|0)>(H|0)){ac=A;ad=B}else{I=A;F=B;D=-1;N=r+((ag(p,(L<<2)-64|0)|0)+q)|0;ae=aa;while(1){af=d[b+(ae+g)|0]|0;ah=(af>>>4)+$|0;do{if((ah|0)==(D|0)){ai=D;aj=F;ak=I}else{al=ah<<1;am=e[t+((al|1)<<1)>>1]|0;an=(am<<12&983040|(e[t+(al<<1)>>1]|0))&u;do{if((am&8|0)==0){if((am&4|0)==0){ao=an;break}ao=v|an&1048572}else{ao=z|an&1048568}}while(0);an=a[w+ao|0]|0;al=an&255;if(an<<24>>24!=0){ai=ah;aj=al;ak=am;break}c[2385344]=x+(ao<<7);c[2440392]=y+((am>>>4&4080)<<2);ai=ah;aj=al;ak=am}}while(0);do{if((aj|0)==0){ah=af<<1&30;al=(ak&2|0)==0?ah:ah^30;ah=c[2385344]|0;an=c[ah+(al<<2)>>2]|0;ap=an>>>8&15;aq=(ap|0)==0;if((ak&1|0)==0){if(!aq){c[N>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ar=an>>>16&15;if((ar|0)!=0){c[N+4>>2]=c[(c[2440392]|0)+(ar<<2)>>2]}ar=an>>>24&15;if((ar|0)!=0){c[N+8>>2]=c[(c[2440392]|0)+(ar<<2)>>2]}ar=c[ah+((al|1)<<2)>>2]|0;as=ar&15;if((as|0)!=0){c[N+12>>2]=c[(c[2440392]|0)+(as<<2)>>2]}as=ar>>>8&15;if((as|0)!=0){c[N+16>>2]=c[(c[2440392]|0)+(as<<2)>>2]}as=ar>>>16&15;if((as|0)!=0){c[N+20>>2]=c[(c[2440392]|0)+(as<<2)>>2]}as=ar>>>24&15;if((as|0)==0){break}c[N+24>>2]=c[(c[2440392]|0)+(as<<2)>>2];break}else{if(!aq){c[N+24>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ap=an>>>16&15;if((ap|0)!=0){c[N+20>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ap=an>>>24&15;if((ap|0)!=0){c[N+16>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ap=c[ah+((al|1)<<2)>>2]|0;al=ap&15;if((al|0)!=0){c[N+12>>2]=c[(c[2440392]|0)+(al<<2)>>2]}al=ap>>>8&15;if((al|0)!=0){c[N+8>>2]=c[(c[2440392]|0)+(al<<2)>>2]}al=ap>>>16&15;if((al|0)!=0){c[N+4>>2]=c[(c[2440392]|0)+(al<<2)>>2]}al=ap>>>24&15;if((al|0)==0){break}c[N>>2]=c[(c[2440392]|0)+(al<<2)>>2];break}}}while(0);af=ae+1|0;if((af|0)>(H|0)){ac=ak;ad=aj;break}else{I=ak;F=aj;D=ai;N=N+s|0;ae=af}}}if((ab|0)>(i|0)){U=37704;break}else{A=ac;B=ad;C=ab}}if((U|0)==37704){return}else if((U|0)==37706){return}}function czF(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0;b=c[3540994]|0;f=c[3528548]|0;g=f<<8;h=c[2385554]|0;do{if((h|0)>31){i=511}else{j=(h<<4)-1|0;if((j|0)>=0){i=j;break}return}}while(0);j=(i|0)>255;k=i&255;l=c[2385550]|0;m=c[2113042]|0;n=c[2113044]|0;o=m+512|0;p=c[2113132]|0;q=c[2385552]<<2;r=c[2112968]|0;s=p<<2;t=c[2415160]|0;u=c[2429858]|0;v=c[2430428]|0;w=c[2429718]|0;x=c[2430092]|0;y=c[3541046]|0;z=c[2430426]|0;A=0;B=0;C=0;L43781:while(1){D=(h|0)>16&(f|0)!=255;E=(h|0)<33;F=511-f|0;G=f+1|0;H=f-255|0;I=~f;J=C;L43783:while(1){K=J+l|0;L=K&511;do{if((L|0)<(m|0)){M=J+m-L|0}else{if((L|0)>=(n|0)){M=o+J-L|0;break}N=(J|0)>255;O=N?16:0;P=J&255;Q=(J|0)<256&j?255:k;if(!D){R=Q;S=P;T=O;U=37730;break L43783}if(E){if(!N){U=37720;break L43783}if((J|0)<(F|0)){M=F;break}else{U=37722;break L43783}}if(N){V=H+P|0;if((V|0)>=0){U=37725;break L43783}N=G+V|0;if((N|0)<0){M=512;break}else{R=f;S=N;T=0;U=37730;break L43783}}else{if((P|0)<=(f|0)){U=37728;break L43783}N=P+I|0;if((N|0)>(f|0)){M=256;break}else{R=f;S=N;T=16;U=37730;break L43783}}}}while(0);if((M|0)>(i|0)){U=37777;break L43781}else{J=M}}if((U|0)==37728){U=0;W=f;X=O;Y=P;Z=G+J-P|0}else if((U|0)==37722){U=0;I=255-f|0;R=Q-I|0;S=P-I|0;T=O;U=37730}else if((U|0)==37725){U=0;W=f;X=O;Y=V;Z=G+J-V|0}else if((U|0)==37720){U=0;_=O;$=P;aa=Q;ab=J+1-P+Q|0;U=37731}if((U|0)==37730){U=0;I=J+1-S+R|0;if(E){_=T;$=S;aa=R;ab=I;U=37731}else{W=R;X=T;Y=S;Z=I}}if((U|0)==37731){U=0;W=(aa|0)>(f|0)?f:aa;X=_;Y=$;Z=ab}I=((K|-512)^511)+n|0;H=(W-Y|0)>(I|0)?I+Y|0:W;if((Y|0)>(H|0)){ac=A;ad=B}else{I=A;F=B;D=-1;N=r+((ag(p,(L<<2)-64|0)|0)+q)|0;ae=Y;while(1){af=d[b+(ae+g)|0]|0;ah=(af>>>4)+X|0;do{if((ah|0)==(D|0)){ai=D;aj=F;ak=I}else{al=ah<<1;am=e[t+((al|1)<<1)>>1]|0;an=(am<<12&983040|(e[t+(al<<1)>>1]|0))&u;do{if((am&8|0)==0){if((am&4|0)==0){ao=an;break}ao=v|an&1048572}else{ao=z|an&1048568}}while(0);an=a[w+ao|0]|0;al=an&255;if(an<<24>>24!=0){ai=ah;aj=al;ak=am;break}c[2385344]=x+(ao<<7);c[2440392]=y+((am>>>4&4080)<<2);ai=ah;aj=al;ak=am}}while(0);do{if((aj|0)==0){ah=af<<1&30;al=(ak&2|0)==0?ah:ah^30;ah=c[2385344]|0;an=c[ah+(al<<2)>>2]|0;ap=an&15;aq=(ap|0)==0;if((ak&1|0)==0){if(!aq){c[N>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ar=an>>>8&15;if((ar|0)!=0){c[N+4>>2]=c[(c[2440392]|0)+(ar<<2)>>2]}ar=an>>>16&15;if((ar|0)!=0){c[N+8>>2]=c[(c[2440392]|0)+(ar<<2)>>2]}ar=an>>>24&15;if((ar|0)!=0){c[N+12>>2]=c[(c[2440392]|0)+(ar<<2)>>2]}ar=c[ah+((al|1)<<2)>>2]|0;as=ar&15;if((as|0)!=0){c[N+16>>2]=c[(c[2440392]|0)+(as<<2)>>2]}as=ar>>>8&15;if((as|0)!=0){c[N+20>>2]=c[(c[2440392]|0)+(as<<2)>>2]}as=ar>>>16&15;if((as|0)!=0){c[N+24>>2]=c[(c[2440392]|0)+(as<<2)>>2]}as=ar>>>24&15;if((as|0)==0){break}c[N+28>>2]=c[(c[2440392]|0)+(as<<2)>>2];break}else{if(!aq){c[N+28>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ap=an>>>8&15;if((ap|0)!=0){c[N+24>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ap=an>>>16&15;if((ap|0)!=0){c[N+20>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ap=an>>>24&15;if((ap|0)!=0){c[N+16>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ap=c[ah+((al|1)<<2)>>2]|0;al=ap&15;if((al|0)!=0){c[N+12>>2]=c[(c[2440392]|0)+(al<<2)>>2]}al=ap>>>8&15;if((al|0)!=0){c[N+8>>2]=c[(c[2440392]|0)+(al<<2)>>2]}al=ap>>>16&15;if((al|0)!=0){c[N+4>>2]=c[(c[2440392]|0)+(al<<2)>>2]}al=ap>>>24&15;if((al|0)==0){break}c[N>>2]=c[(c[2440392]|0)+(al<<2)>>2];break}}}while(0);af=ae+1|0;if((af|0)>(H|0)){ac=ak;ad=aj;break}else{I=ak;F=aj;D=ai;N=N+s|0;ae=af}}}if((Z|0)>(i|0)){U=37778;break}else{A=ac;B=ad;C=Z}}if((U|0)==37777){return}else if((U|0)==37778){return}}function czG(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0;b=c[3540994]|0;f=c[3528548]|0;g=f<<8;h=c[2385554]|0;do{if((h|0)>31){i=511}else{j=(h<<4)-1|0;if((j|0)>=0){i=j;break}return}}while(0);j=(i|0)>255;k=i&255;l=c[2385550]|0;m=c[2113042]|0;n=c[2113044]|0;o=m+512|0;p=c[2113132]|0;q=c[2385552]<<2;r=c[2112968]|0;s=p<<2;t=c[2415160]|0;u=c[2429858]|0;v=c[2430428]|0;w=c[2429718]|0;x=c[2430092]|0;y=c[3541046]|0;z=c[2430426]|0;A=0;B=0;C=0;L43884:while(1){D=(h|0)>16&(f|0)!=255;E=(h|0)<33;F=511-f|0;G=f+1|0;H=f-255|0;I=~f;J=C;L43886:while(1){K=J+l|0;L=K&511;do{if((L|0)<(m|0)){M=J+m-L|0}else{if((L|0)>=(n|0)){M=o+J-L|0;break}N=(J|0)>255;O=N?16:0;P=J&255;Q=(J|0)<256&j?255:k;if(!D){R=Q;S=P;T=O;U=37803;break L43886}if(E){if(!N){U=37793;break L43886}if((J|0)<(F|0)){M=F;break}else{U=37795;break L43886}}if(N){V=H+P|0;if((V|0)>=0){U=37798;break L43886}N=G+V|0;if((N|0)<0){M=512;break}else{R=f;S=N;T=0;U=37803;break L43886}}else{if((P|0)<=(f|0)){U=37801;break L43886}N=P+I|0;if((N|0)>(f|0)){M=256;break}else{R=f;S=N;T=16;U=37803;break L43886}}}}while(0);if((M|0)>(i|0)){U=37855;break L43884}else{J=M}}if((U|0)==37793){U=0;W=O;X=P;Y=Q;Z=J+1-P+Q|0;U=37804}else if((U|0)==37795){U=0;I=255-f|0;R=Q-I|0;S=P-I|0;T=O;U=37803}else if((U|0)==37798){U=0;_=f;$=O;aa=V;ab=G+J-V|0}else if((U|0)==37801){U=0;_=f;$=O;aa=P;ab=G+J-P|0}if((U|0)==37803){U=0;I=J+1-S+R|0;if(E){W=T;X=S;Y=R;Z=I;U=37804}else{_=R;$=T;aa=S;ab=I}}if((U|0)==37804){U=0;_=(Y|0)>(f|0)?f:Y;$=W;aa=X;ab=Z}I=((K|-512)^511)+n|0;H=(_-aa|0)>(I|0)?I+aa|0:_;if((aa|0)>(H|0)){ac=A;ad=B}else{I=A;F=B;D=-1;N=r+((ag(p,(L<<2)-64|0)|0)+q)|0;ae=aa;while(1){af=d[b+(ae+g)|0]|0;ah=(af>>>4)+$|0;do{if((ah|0)==(D|0)){ai=D;aj=F;ak=I}else{al=ah<<1;am=e[t+((al|1)<<1)>>1]|0;an=(am<<12&983040|(e[t+(al<<1)>>1]|0))&u;do{if((am&8|0)==0){if((am&4|0)==0){ao=an;break}ao=v|an&1048572}else{ao=z|an&1048568}}while(0);an=a[w+ao|0]|0;al=an&255;if(an<<24>>24!=0){ai=ah;aj=al;ak=am;break}c[2385344]=x+(ao<<7);c[2440392]=y+((am>>>4&4080)<<2);ai=ah;aj=al;ak=am}}while(0);do{if((aj|0)==0){ah=af<<1&30;al=(ak&2|0)==0?ah:ah^30;ah=c[2385344]|0;an=c[ah+(al<<2)>>2]|0;ap=an&15;aq=(ap|0)==0;if((ak&1|0)==0){if(!aq){c[N>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ar=an>>>8&15;if((ar|0)!=0){c[N+4>>2]=c[(c[2440392]|0)+(ar<<2)>>2]}ar=an>>>16&15;if((ar|0)!=0){c[N+8>>2]=c[(c[2440392]|0)+(ar<<2)>>2]}ar=an>>>24&15;if((ar|0)!=0){c[N+12>>2]=c[(c[2440392]|0)+(ar<<2)>>2]}ar=c[ah+((al|1)<<2)>>2]|0;as=ar&15;if((as|0)!=0){c[N+16>>2]=c[(c[2440392]|0)+(as<<2)>>2]}as=ar>>>4&15;if((as|0)!=0){c[N+20>>2]=c[(c[2440392]|0)+(as<<2)>>2]}as=ar>>>8&15;if((as|0)!=0){c[N+24>>2]=c[(c[2440392]|0)+(as<<2)>>2]}as=ar>>>16&15;if((as|0)!=0){c[N+28>>2]=c[(c[2440392]|0)+(as<<2)>>2]}as=ar>>>24&15;if((as|0)==0){break}c[N+32>>2]=c[(c[2440392]|0)+(as<<2)>>2];break}else{if(!aq){c[N+32>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ap=an>>>8&15;if((ap|0)!=0){c[N+28>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ap=an>>>16&15;if((ap|0)!=0){c[N+24>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ap=an>>>24&15;if((ap|0)!=0){c[N+20>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ap=c[ah+((al|1)<<2)>>2]|0;al=ap&15;if((al|0)!=0){c[N+16>>2]=c[(c[2440392]|0)+(al<<2)>>2]}al=ap>>>4&15;if((al|0)!=0){c[N+12>>2]=c[(c[2440392]|0)+(al<<2)>>2]}al=ap>>>8&15;if((al|0)!=0){c[N+8>>2]=c[(c[2440392]|0)+(al<<2)>>2]}al=ap>>>16&15;if((al|0)!=0){c[N+4>>2]=c[(c[2440392]|0)+(al<<2)>>2]}al=ap>>>24&15;if((al|0)==0){break}c[N>>2]=c[(c[2440392]|0)+(al<<2)>>2];break}}}while(0);af=ae+1|0;if((af|0)>(H|0)){ac=ak;ad=aj;break}else{I=ak;F=aj;D=ai;N=N+s|0;ae=af}}}if((ab|0)>(i|0)){U=37856;break}else{A=ac;B=ad;C=ab}}if((U|0)==37855){return}else if((U|0)==37856){return}}function czH(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0;b=c[3540994]|0;f=c[3528548]|0;g=f<<8;h=c[2385554]|0;do{if((h|0)>31){i=511}else{j=(h<<4)-1|0;if((j|0)>=0){i=j;break}return}}while(0);j=(i|0)>255;k=i&255;l=c[2385550]|0;m=c[2113042]|0;n=c[2113044]|0;o=m+512|0;p=c[2113132]|0;q=c[2385552]<<2;r=c[2112968]|0;s=p<<2;t=c[2415160]|0;u=c[2429858]|0;v=c[2430428]|0;w=c[2429718]|0;x=c[2430092]|0;y=c[3541046]|0;z=c[2430426]|0;A=0;B=0;C=0;L43993:while(1){D=(h|0)>16&(f|0)!=255;E=(h|0)<33;F=511-f|0;G=f+1|0;H=f-255|0;I=~f;J=C;L43995:while(1){K=J+l|0;L=K&511;do{if((L|0)<(m|0)){M=J+m-L|0}else{if((L|0)>=(n|0)){M=o+J-L|0;break}N=(J|0)>255;O=N?16:0;P=J&255;Q=(J|0)<256&j?255:k;if(!D){R=Q;S=P;T=O;U=37880;break L43995}if(E){if(!N){U=37870;break L43995}if((J|0)<(F|0)){M=F;break}else{U=37872;break L43995}}if(N){V=H+P|0;if((V|0)>=0){U=37875;break L43995}N=G+V|0;if((N|0)<0){M=512;break}else{R=f;S=N;T=0;U=37880;break L43995}}else{if((P|0)<=(f|0)){U=37878;break L43995}N=P+I|0;if((N|0)>(f|0)){M=256;break}else{R=f;S=N;T=16;U=37880;break L43995}}}}while(0);if((M|0)>(i|0)){U=37935;break L43993}else{J=M}}if((U|0)==37875){U=0;W=f;X=O;Y=V;Z=G+J-V|0}else if((U|0)==37878){U=0;W=f;X=O;Y=P;Z=G+J-P|0}else if((U|0)==37870){U=0;_=O;$=P;aa=Q;ab=J+1-P+Q|0;U=37881}else if((U|0)==37872){U=0;I=255-f|0;R=Q-I|0;S=P-I|0;T=O;U=37880}if((U|0)==37880){U=0;I=J+1-S+R|0;if(E){_=T;$=S;aa=R;ab=I;U=37881}else{W=R;X=T;Y=S;Z=I}}if((U|0)==37881){U=0;W=(aa|0)>(f|0)?f:aa;X=_;Y=$;Z=ab}I=((K|-512)^511)+n|0;H=(W-Y|0)>(I|0)?I+Y|0:W;if((Y|0)>(H|0)){ac=A;ad=B}else{I=A;F=B;D=-1;N=r+((ag(p,(L<<2)-64|0)|0)+q)|0;ae=Y;while(1){af=d[b+(ae+g)|0]|0;ah=(af>>>4)+X|0;do{if((ah|0)==(D|0)){ai=D;aj=F;ak=I}else{al=ah<<1;am=e[t+((al|1)<<1)>>1]|0;an=(am<<12&983040|(e[t+(al<<1)>>1]|0))&u;do{if((am&8|0)==0){if((am&4|0)==0){ao=an;break}ao=v|an&1048572}else{ao=z|an&1048568}}while(0);an=a[w+ao|0]|0;al=an&255;if(an<<24>>24!=0){ai=ah;aj=al;ak=am;break}c[2385344]=x+(ao<<7);c[2440392]=y+((am>>>4&4080)<<2);ai=ah;aj=al;ak=am}}while(0);do{if((aj|0)==0){ah=af<<1&30;al=(ak&2|0)==0?ah:ah^30;ah=c[2385344]|0;an=c[ah+(al<<2)>>2]|0;ap=an&15;aq=(ap|0)==0;if((ak&1|0)==0){if(!aq){c[N>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ar=an>>>8&15;if((ar|0)!=0){c[N+4>>2]=c[(c[2440392]|0)+(ar<<2)>>2]}ar=an>>>12&15;if((ar|0)!=0){c[N+8>>2]=c[(c[2440392]|0)+(ar<<2)>>2]}ar=an>>>16&15;if((ar|0)!=0){c[N+12>>2]=c[(c[2440392]|0)+(ar<<2)>>2]}ar=an>>>24&15;if((ar|0)!=0){c[N+16>>2]=c[(c[2440392]|0)+(ar<<2)>>2]}ar=c[ah+((al|1)<<2)>>2]|0;as=ar&15;if((as|0)!=0){c[N+20>>2]=c[(c[2440392]|0)+(as<<2)>>2]}as=ar>>>4&15;if((as|0)!=0){c[N+24>>2]=c[(c[2440392]|0)+(as<<2)>>2]}as=ar>>>8&15;if((as|0)!=0){c[N+28>>2]=c[(c[2440392]|0)+(as<<2)>>2]}as=ar>>>16&15;if((as|0)!=0){c[N+32>>2]=c[(c[2440392]|0)+(as<<2)>>2]}as=ar>>>24&15;if((as|0)==0){break}c[N+36>>2]=c[(c[2440392]|0)+(as<<2)>>2];break}else{if(!aq){c[N+36>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ap=an>>>8&15;if((ap|0)!=0){c[N+32>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ap=an>>>12&15;if((ap|0)!=0){c[N+28>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ap=an>>>16&15;if((ap|0)!=0){c[N+24>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ap=an>>>24&15;if((ap|0)!=0){c[N+20>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ap=c[ah+((al|1)<<2)>>2]|0;al=ap&15;if((al|0)!=0){c[N+16>>2]=c[(c[2440392]|0)+(al<<2)>>2]}al=ap>>>4&15;if((al|0)!=0){c[N+12>>2]=c[(c[2440392]|0)+(al<<2)>>2]}al=ap>>>8&15;if((al|0)!=0){c[N+8>>2]=c[(c[2440392]|0)+(al<<2)>>2]}al=ap>>>16&15;if((al|0)!=0){c[N+4>>2]=c[(c[2440392]|0)+(al<<2)>>2]}al=ap>>>24&15;if((al|0)==0){break}c[N>>2]=c[(c[2440392]|0)+(al<<2)>>2];break}}}while(0);af=ae+1|0;if((af|0)>(H|0)){ac=ak;ad=aj;break}else{I=ak;F=aj;D=ai;N=N+s|0;ae=af}}}if((Z|0)>(i|0)){U=37936;break}else{A=ac;B=ad;C=Z}}if((U|0)==37935){return}else if((U|0)==37936){return}}function czI(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0;b=c[3540994]|0;f=c[3528548]|0;g=f<<8;h=c[2385554]|0;do{if((h|0)>31){i=511}else{j=(h<<4)-1|0;if((j|0)>=0){i=j;break}return}}while(0);j=(i|0)>255;k=i&255;l=c[2385550]|0;m=c[2113042]|0;n=c[2113044]|0;o=m+512|0;p=c[2113132]|0;q=c[2385552]<<2;r=c[2112968]|0;s=p<<2;t=c[2415160]|0;u=c[2429858]|0;v=c[2430428]|0;w=c[2429718]|0;x=c[2430092]|0;y=c[3541046]|0;z=c[2430426]|0;A=0;B=0;C=0;L44108:while(1){D=(h|0)>16&(f|0)!=255;E=(h|0)<33;F=511-f|0;G=f+1|0;H=f-255|0;I=~f;J=C;L44110:while(1){K=J+l|0;L=K&511;do{if((L|0)<(m|0)){M=J+m-L|0}else{if((L|0)>=(n|0)){M=o+J-L|0;break}N=(J|0)>255;O=N?16:0;P=J&255;Q=(J|0)<256&j?255:k;if(!D){R=Q;S=P;T=O;U=37961;break L44110}if(E){if(!N){U=37951;break L44110}if((J|0)<(F|0)){M=F;break}else{U=37953;break L44110}}if(N){V=H+P|0;if((V|0)>=0){U=37956;break L44110}N=G+V|0;if((N|0)<0){M=512;break}else{R=f;S=N;T=0;U=37961;break L44110}}else{if((P|0)<=(f|0)){U=37959;break L44110}N=P+I|0;if((N|0)>(f|0)){M=256;break}else{R=f;S=N;T=16;U=37961;break L44110}}}}while(0);if((M|0)>(i|0)){U=38022;break L44108}else{J=M}}if((U|0)==37953){U=0;I=255-f|0;R=Q-I|0;S=P-I|0;T=O;U=37961}else if((U|0)==37959){U=0;W=f;X=O;Y=P;Z=G+J-P|0}else if((U|0)==37951){U=0;_=O;$=P;aa=Q;ab=J+1-P+Q|0;U=37962}else if((U|0)==37956){U=0;W=f;X=O;Y=V;Z=G+J-V|0}if((U|0)==37961){U=0;I=J+1-S+R|0;if(E){_=T;$=S;aa=R;ab=I;U=37962}else{W=R;X=T;Y=S;Z=I}}if((U|0)==37962){U=0;W=(aa|0)>(f|0)?f:aa;X=_;Y=$;Z=ab}I=((K|-512)^511)+n|0;H=(W-Y|0)>(I|0)?I+Y|0:W;if((Y|0)>(H|0)){ac=A;ad=B}else{I=A;F=B;D=-1;N=r+((ag(p,(L<<2)-64|0)|0)+q)|0;ae=Y;while(1){af=d[b+(ae+g)|0]|0;ah=(af>>>4)+X|0;do{if((ah|0)==(D|0)){ai=D;aj=F;ak=I}else{al=ah<<1;am=e[t+((al|1)<<1)>>1]|0;an=(am<<12&983040|(e[t+(al<<1)>>1]|0))&u;do{if((am&8|0)==0){if((am&4|0)==0){ao=an;break}ao=v|an&1048572}else{ao=z|an&1048568}}while(0);an=a[w+ao|0]|0;al=an&255;if(an<<24>>24!=0){ai=ah;aj=al;ak=am;break}c[2385344]=x+(ao<<7);c[2440392]=y+((am>>>4&4080)<<2);ai=ah;aj=al;ak=am}}while(0);do{if((aj|0)==0){ah=af<<1&30;al=(ak&2|0)==0?ah:ah^30;ah=c[2385344]|0;an=c[ah+(al<<2)>>2]|0;ap=an&15;aq=(ap|0)==0;if((ak&1|0)==0){if(!aq){c[N>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ar=an>>>8&15;if((ar|0)!=0){c[N+4>>2]=c[(c[2440392]|0)+(ar<<2)>>2]}ar=an>>>12&15;if((ar|0)!=0){c[N+8>>2]=c[(c[2440392]|0)+(ar<<2)>>2]}ar=an>>>16&15;if((ar|0)!=0){c[N+12>>2]=c[(c[2440392]|0)+(ar<<2)>>2]}ar=an>>>24&15;if((ar|0)!=0){c[N+16>>2]=c[(c[2440392]|0)+(ar<<2)>>2]}ar=c[ah+((al|1)<<2)>>2]|0;as=ar&15;if((as|0)!=0){c[N+20>>2]=c[(c[2440392]|0)+(as<<2)>>2]}as=ar>>>4&15;if((as|0)!=0){c[N+24>>2]=c[(c[2440392]|0)+(as<<2)>>2]}as=ar>>>8&15;if((as|0)!=0){c[N+28>>2]=c[(c[2440392]|0)+(as<<2)>>2]}as=ar>>>16&15;if((as|0)!=0){c[N+32>>2]=c[(c[2440392]|0)+(as<<2)>>2]}as=ar>>>24&15;if((as|0)!=0){c[N+36>>2]=c[(c[2440392]|0)+(as<<2)>>2]}as=ar>>>28;if((as|0)==0){break}c[N+40>>2]=c[(c[2440392]|0)+(as<<2)>>2];break}else{if(!aq){c[N+40>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ap=an>>>8&15;if((ap|0)!=0){c[N+36>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ap=an>>>12&15;if((ap|0)!=0){c[N+32>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ap=an>>>16&15;if((ap|0)!=0){c[N+28>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ap=an>>>24&15;if((ap|0)!=0){c[N+24>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ap=c[ah+((al|1)<<2)>>2]|0;al=ap&15;if((al|0)!=0){c[N+20>>2]=c[(c[2440392]|0)+(al<<2)>>2]}al=ap>>>4&15;if((al|0)!=0){c[N+16>>2]=c[(c[2440392]|0)+(al<<2)>>2]}al=ap>>>8&15;if((al|0)!=0){c[N+12>>2]=c[(c[2440392]|0)+(al<<2)>>2]}al=ap>>>16&15;if((al|0)!=0){c[N+8>>2]=c[(c[2440392]|0)+(al<<2)>>2]}al=ap>>>24&15;if((al|0)!=0){c[N+4>>2]=c[(c[2440392]|0)+(al<<2)>>2]}al=ap>>>28;if((al|0)==0){break}c[N>>2]=c[(c[2440392]|0)+(al<<2)>>2];break}}}while(0);af=ae+1|0;if((af|0)>(H|0)){ac=ak;ad=aj;break}else{I=ak;F=aj;D=ai;N=N+s|0;ae=af}}}if((Z|0)>(i|0)){U=38021;break}else{A=ac;B=ad;C=Z}}if((U|0)==38021){return}else if((U|0)==38022){return}}function czJ(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0;b=c[3540994]|0;f=c[3528548]|0;g=f<<8;h=c[2385554]|0;do{if((h|0)>31){i=511}else{j=(h<<4)-1|0;if((j|0)>=0){i=j;break}return}}while(0);j=(i|0)>255;k=i&255;l=c[2385550]|0;m=c[2113042]|0;n=c[2113044]|0;o=m+512|0;p=c[2113132]|0;q=c[2385552]<<2;r=c[2112968]|0;s=p<<2;t=c[2415160]|0;u=c[2429858]|0;v=c[2430428]|0;w=c[2429718]|0;x=c[2430092]|0;y=c[3541046]|0;z=c[2430426]|0;A=0;B=0;C=0;L44229:while(1){D=(h|0)>16&(f|0)!=255;E=(h|0)<33;F=511-f|0;G=f+1|0;H=f-255|0;I=~f;J=C;L44231:while(1){K=J+l|0;L=K&511;do{if((L|0)<(m|0)){M=J+m-L|0}else{if((L|0)>=(n|0)){M=o+J-L|0;break}N=(J|0)>255;O=N?16:0;P=J&255;Q=(J|0)<256&j?255:k;if(!D){R=Q;S=P;T=O;U=38046;break L44231}if(E){if(!N){U=38036;break L44231}if((J|0)<(F|0)){M=F;break}else{U=38038;break L44231}}if(N){V=H+P|0;if((V|0)>=0){U=38041;break L44231}N=G+V|0;if((N|0)<0){M=512;break}else{R=f;S=N;T=0;U=38046;break L44231}}else{if((P|0)<=(f|0)){U=38044;break L44231}N=P+I|0;if((N|0)>(f|0)){M=256;break}else{R=f;S=N;T=16;U=38046;break L44231}}}}while(0);if((M|0)>(i|0)){U=38109;break L44229}else{J=M}}if((U|0)==38041){U=0;W=f;X=O;Y=V;Z=G+J-V|0}else if((U|0)==38044){U=0;W=f;X=O;Y=P;Z=G+J-P|0}else if((U|0)==38036){U=0;_=O;$=P;aa=Q;ab=J+1-P+Q|0;U=38047}else if((U|0)==38038){U=0;I=255-f|0;R=Q-I|0;S=P-I|0;T=O;U=38046}if((U|0)==38046){U=0;I=J+1-S+R|0;if(E){_=T;$=S;aa=R;ab=I;U=38047}else{W=R;X=T;Y=S;Z=I}}if((U|0)==38047){U=0;W=(aa|0)>(f|0)?f:aa;X=_;Y=$;Z=ab}I=((K|-512)^511)+n|0;H=(W-Y|0)>(I|0)?I+Y|0:W;if((Y|0)>(H|0)){ac=A;ad=B}else{I=A;F=B;D=-1;N=r+((ag(p,(L<<2)-64|0)|0)+q)|0;ae=Y;while(1){af=d[b+(ae+g)|0]|0;ah=(af>>>4)+X|0;do{if((ah|0)==(D|0)){ai=D;aj=F;ak=I}else{al=ah<<1;am=e[t+((al|1)<<1)>>1]|0;an=(am<<12&983040|(e[t+(al<<1)>>1]|0))&u;do{if((am&8|0)==0){if((am&4|0)==0){ao=an;break}ao=v|an&1048572}else{ao=z|an&1048568}}while(0);an=a[w+ao|0]|0;al=an&255;if(an<<24>>24!=0){ai=ah;aj=al;ak=am;break}c[2385344]=x+(ao<<7);c[2440392]=y+((am>>>4&4080)<<2);ai=ah;aj=al;ak=am}}while(0);do{if((aj|0)==0){ah=af<<1&30;al=(ak&2|0)==0?ah:ah^30;ah=c[2385344]|0;an=c[ah+(al<<2)>>2]|0;ap=an&15;aq=(ap|0)==0;if((ak&1|0)==0){if(!aq){c[N>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ar=an>>>8&15;if((ar|0)!=0){c[N+4>>2]=c[(c[2440392]|0)+(ar<<2)>>2]}ar=an>>>12&15;if((ar|0)!=0){c[N+8>>2]=c[(c[2440392]|0)+(ar<<2)>>2]}ar=an>>>16&15;if((ar|0)!=0){c[N+12>>2]=c[(c[2440392]|0)+(ar<<2)>>2]}ar=an>>>24&15;if((ar|0)!=0){c[N+16>>2]=c[(c[2440392]|0)+(ar<<2)>>2]}ar=an>>>28;if((ar|0)!=0){c[N+20>>2]=c[(c[2440392]|0)+(ar<<2)>>2]}ar=c[ah+((al|1)<<2)>>2]|0;as=ar&15;if((as|0)!=0){c[N+24>>2]=c[(c[2440392]|0)+(as<<2)>>2]}as=ar>>>4&15;if((as|0)!=0){c[N+28>>2]=c[(c[2440392]|0)+(as<<2)>>2]}as=ar>>>8&15;if((as|0)!=0){c[N+32>>2]=c[(c[2440392]|0)+(as<<2)>>2]}as=ar>>>16&15;if((as|0)!=0){c[N+36>>2]=c[(c[2440392]|0)+(as<<2)>>2]}as=ar>>>24&15;if((as|0)!=0){c[N+40>>2]=c[(c[2440392]|0)+(as<<2)>>2]}as=ar>>>28;if((as|0)==0){break}c[N+44>>2]=c[(c[2440392]|0)+(as<<2)>>2];break}else{if(!aq){c[N+44>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ap=an>>>8&15;if((ap|0)!=0){c[N+40>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ap=an>>>12&15;if((ap|0)!=0){c[N+36>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ap=an>>>16&15;if((ap|0)!=0){c[N+32>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ap=an>>>24&15;if((ap|0)!=0){c[N+28>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ap=an>>>28;if((ap|0)!=0){c[N+24>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ap=c[ah+((al|1)<<2)>>2]|0;al=ap&15;if((al|0)!=0){c[N+20>>2]=c[(c[2440392]|0)+(al<<2)>>2]}al=ap>>>4&15;if((al|0)!=0){c[N+16>>2]=c[(c[2440392]|0)+(al<<2)>>2]}al=ap>>>8&15;if((al|0)!=0){c[N+12>>2]=c[(c[2440392]|0)+(al<<2)>>2]}al=ap>>>16&15;if((al|0)!=0){c[N+8>>2]=c[(c[2440392]|0)+(al<<2)>>2]}al=ap>>>24&15;if((al|0)!=0){c[N+4>>2]=c[(c[2440392]|0)+(al<<2)>>2]}al=ap>>>28;if((al|0)==0){break}c[N>>2]=c[(c[2440392]|0)+(al<<2)>>2];break}}}while(0);af=ae+1|0;if((af|0)>(H|0)){ac=ak;ad=aj;break}else{I=ak;F=aj;D=ai;N=N+s|0;ae=af}}}if((Z|0)>(i|0)){U=38110;break}else{A=ac;B=ad;C=Z}}if((U|0)==38109){return}else if((U|0)==38110){return}}function czK(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0;b=c[3540994]|0;f=c[3528548]|0;g=f<<8;h=c[2385554]|0;do{if((h|0)>31){i=511}else{j=(h<<4)-1|0;if((j|0)>=0){i=j;break}return}}while(0);j=(i|0)>255;k=i&255;l=c[2385550]|0;m=c[2113042]|0;n=c[2113044]|0;o=m+512|0;p=c[2113132]|0;q=c[2385552]<<2;r=c[2112968]|0;s=p<<2;t=c[2415160]|0;u=c[2429858]|0;v=c[2430428]|0;w=c[2429718]|0;x=c[2430092]|0;y=c[3541046]|0;z=c[2430426]|0;A=0;B=0;C=0;L44356:while(1){D=(h|0)>16&(f|0)!=255;E=(h|0)<33;F=511-f|0;G=f+1|0;H=f-255|0;I=~f;J=C;L44358:while(1){K=J+l|0;L=K&511;do{if((L|0)<(m|0)){M=J+m-L|0}else{if((L|0)>=(n|0)){M=o+J-L|0;break}N=(J|0)>255;O=N?16:0;P=J&255;Q=(J|0)<256&j?255:k;if(!D){R=Q;S=P;T=O;U=38135;break L44358}if(E){if(!N){U=38125;break L44358}if((J|0)<(F|0)){M=F;break}else{U=38127;break L44358}}if(N){V=H+P|0;if((V|0)>=0){U=38130;break L44358}N=G+V|0;if((N|0)<0){M=512;break}else{R=f;S=N;T=0;U=38135;break L44358}}else{if((P|0)<=(f|0)){U=38133;break L44358}N=P+I|0;if((N|0)>(f|0)){M=256;break}else{R=f;S=N;T=16;U=38135;break L44358}}}}while(0);if((M|0)>(i|0)){U=38204;break L44356}else{J=M}}if((U|0)==38127){U=0;I=255-f|0;R=Q-I|0;S=P-I|0;T=O;U=38135}else if((U|0)==38133){U=0;W=f;X=O;Y=P;Z=G+J-P|0}else if((U|0)==38125){U=0;_=O;$=P;aa=Q;ab=J+1-P+Q|0;U=38136}else if((U|0)==38130){U=0;W=f;X=O;Y=V;Z=G+J-V|0}if((U|0)==38135){U=0;I=J+1-S+R|0;if(E){_=T;$=S;aa=R;ab=I;U=38136}else{W=R;X=T;Y=S;Z=I}}if((U|0)==38136){U=0;W=(aa|0)>(f|0)?f:aa;X=_;Y=$;Z=ab}I=((K|-512)^511)+n|0;H=(W-Y|0)>(I|0)?I+Y|0:W;if((Y|0)>(H|0)){ac=A;ad=B}else{I=A;F=B;D=-1;N=r+((ag(p,(L<<2)-64|0)|0)+q)|0;ae=Y;while(1){af=d[b+(ae+g)|0]|0;ah=(af>>>4)+X|0;do{if((ah|0)==(D|0)){ai=D;aj=F;ak=I}else{al=ah<<1;am=e[t+((al|1)<<1)>>1]|0;an=(am<<12&983040|(e[t+(al<<1)>>1]|0))&u;do{if((am&8|0)==0){if((am&4|0)==0){ao=an;break}ao=v|an&1048572}else{ao=z|an&1048568}}while(0);an=a[w+ao|0]|0;al=an&255;if(an<<24>>24!=0){ai=ah;aj=al;ak=am;break}c[2385344]=x+(ao<<7);c[2440392]=y+((am>>>4&4080)<<2);ai=ah;aj=al;ak=am}}while(0);do{if((aj|0)==0){ah=af<<1&30;al=(ak&2|0)==0?ah:ah^30;ah=c[2385344]|0;an=c[ah+(al<<2)>>2]|0;ap=an&15;aq=(ap|0)==0;if((ak&1|0)==0){if(!aq){c[N>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ar=an>>>8&15;if((ar|0)!=0){c[N+4>>2]=c[(c[2440392]|0)+(ar<<2)>>2]}ar=an>>>12&15;if((ar|0)!=0){c[N+8>>2]=c[(c[2440392]|0)+(ar<<2)>>2]}ar=an>>>16&15;if((ar|0)!=0){c[N+12>>2]=c[(c[2440392]|0)+(ar<<2)>>2]}ar=an>>>24&15;if((ar|0)!=0){c[N+16>>2]=c[(c[2440392]|0)+(ar<<2)>>2]}ar=an>>>28;if((ar|0)!=0){c[N+20>>2]=c[(c[2440392]|0)+(ar<<2)>>2]}ar=c[ah+((al|1)<<2)>>2]|0;as=ar&15;if((as|0)!=0){c[N+24>>2]=c[(c[2440392]|0)+(as<<2)>>2]}as=ar>>>4&15;if((as|0)!=0){c[N+28>>2]=c[(c[2440392]|0)+(as<<2)>>2]}as=ar>>>8&15;if((as|0)!=0){c[N+32>>2]=c[(c[2440392]|0)+(as<<2)>>2]}as=ar>>>16&15;if((as|0)!=0){c[N+36>>2]=c[(c[2440392]|0)+(as<<2)>>2]}as=ar>>>20&15;if((as|0)!=0){c[N+40>>2]=c[(c[2440392]|0)+(as<<2)>>2]}as=ar>>>24&15;if((as|0)!=0){c[N+44>>2]=c[(c[2440392]|0)+(as<<2)>>2]}as=ar>>>28;if((as|0)==0){break}c[N+48>>2]=c[(c[2440392]|0)+(as<<2)>>2];break}else{if(!aq){c[N+48>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ap=an>>>8&15;if((ap|0)!=0){c[N+44>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ap=an>>>12&15;if((ap|0)!=0){c[N+40>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ap=an>>>16&15;if((ap|0)!=0){c[N+36>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ap=an>>>24&15;if((ap|0)!=0){c[N+32>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ap=an>>>28;if((ap|0)!=0){c[N+28>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ap=c[ah+((al|1)<<2)>>2]|0;al=ap&15;if((al|0)!=0){c[N+24>>2]=c[(c[2440392]|0)+(al<<2)>>2]}al=ap>>>4&15;if((al|0)!=0){c[N+20>>2]=c[(c[2440392]|0)+(al<<2)>>2]}al=ap>>>8&15;if((al|0)!=0){c[N+16>>2]=c[(c[2440392]|0)+(al<<2)>>2]}al=ap>>>16&15;if((al|0)!=0){c[N+12>>2]=c[(c[2440392]|0)+(al<<2)>>2]}al=ap>>>20&15;if((al|0)!=0){c[N+8>>2]=c[(c[2440392]|0)+(al<<2)>>2]}al=ap>>>24&15;if((al|0)!=0){c[N+4>>2]=c[(c[2440392]|0)+(al<<2)>>2]}al=ap>>>28;if((al|0)==0){break}c[N>>2]=c[(c[2440392]|0)+(al<<2)>>2];break}}}while(0);af=ae+1|0;if((af|0)>(H|0)){ac=ak;ad=aj;break}else{I=ak;F=aj;D=ai;N=N+s|0;ae=af}}}if((Z|0)>(i|0)){U=38203;break}else{A=ac;B=ad;C=Z}}if((U|0)==38203){return}else if((U|0)==38204){return}}function czL(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0;b=c[3540994]|0;f=c[3528548]|0;g=f<<8;h=c[2385554]|0;do{if((h|0)>31){i=511}else{j=(h<<4)-1|0;if((j|0)>=0){i=j;break}return}}while(0);j=(i|0)>255;k=i&255;l=c[2385550]|0;m=c[2113042]|0;n=c[2113044]|0;o=m+512|0;p=c[2113132]|0;q=c[2385552]<<2;r=c[2112968]|0;s=p<<2;t=c[2415160]|0;u=c[2429858]|0;v=c[2430428]|0;w=c[2429718]|0;x=c[2430092]|0;y=c[3541046]|0;z=c[2430426]|0;A=0;B=0;C=0;L44489:while(1){D=(h|0)>16&(f|0)!=255;E=(h|0)<33;F=511-f|0;G=f+1|0;H=f-255|0;I=~f;J=C;L44491:while(1){K=J+l|0;L=K&511;do{if((L|0)<(m|0)){M=J+m-L|0}else{if((L|0)>=(n|0)){M=o+J-L|0;break}N=(J|0)>255;O=N?16:0;P=J&255;Q=(J|0)<256&j?255:k;if(!D){R=Q;S=P;T=O;U=38228;break L44491}if(E){if(!N){U=38218;break L44491}if((J|0)<(F|0)){M=F;break}else{U=38220;break L44491}}if(N){V=H+P|0;if((V|0)>=0){U=38223;break L44491}N=G+V|0;if((N|0)<0){M=512;break}else{R=f;S=N;T=0;U=38228;break L44491}}else{if((P|0)<=(f|0)){U=38226;break L44491}N=P+I|0;if((N|0)>(f|0)){M=256;break}else{R=f;S=N;T=16;U=38228;break L44491}}}}while(0);if((M|0)>(i|0)){U=38299;break L44489}else{J=M}}if((U|0)==38223){U=0;W=f;X=O;Y=V;Z=G+J-V|0}else if((U|0)==38226){U=0;W=f;X=O;Y=P;Z=G+J-P|0}else if((U|0)==38218){U=0;_=O;$=P;aa=Q;ab=J+1-P+Q|0;U=38229}else if((U|0)==38220){U=0;I=255-f|0;R=Q-I|0;S=P-I|0;T=O;U=38228}if((U|0)==38228){U=0;I=J+1-S+R|0;if(E){_=T;$=S;aa=R;ab=I;U=38229}else{W=R;X=T;Y=S;Z=I}}if((U|0)==38229){U=0;W=(aa|0)>(f|0)?f:aa;X=_;Y=$;Z=ab}I=((K|-512)^511)+n|0;H=(W-Y|0)>(I|0)?I+Y|0:W;if((Y|0)>(H|0)){ac=A;ad=B}else{I=A;F=B;D=-1;N=r+((ag(p,(L<<2)-64|0)|0)+q)|0;ae=Y;while(1){af=d[b+(ae+g)|0]|0;ah=(af>>>4)+X|0;do{if((ah|0)==(D|0)){ai=D;aj=F;ak=I}else{al=ah<<1;am=e[t+((al|1)<<1)>>1]|0;an=(am<<12&983040|(e[t+(al<<1)>>1]|0))&u;do{if((am&8|0)==0){if((am&4|0)==0){ao=an;break}ao=v|an&1048572}else{ao=z|an&1048568}}while(0);an=a[w+ao|0]|0;al=an&255;if(an<<24>>24!=0){ai=ah;aj=al;ak=am;break}c[2385344]=x+(ao<<7);c[2440392]=y+((am>>>4&4080)<<2);ai=ah;aj=al;ak=am}}while(0);do{if((aj|0)==0){ah=af<<1&30;al=(ak&2|0)==0?ah:ah^30;ah=c[2385344]|0;an=c[ah+(al<<2)>>2]|0;ap=an&15;aq=(ap|0)==0;if((ak&1|0)==0){if(!aq){c[N>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ar=an>>>4&15;if((ar|0)!=0){c[N+4>>2]=c[(c[2440392]|0)+(ar<<2)>>2]}ar=an>>>8&15;if((ar|0)!=0){c[N+8>>2]=c[(c[2440392]|0)+(ar<<2)>>2]}ar=an>>>12&15;if((ar|0)!=0){c[N+12>>2]=c[(c[2440392]|0)+(ar<<2)>>2]}ar=an>>>16&15;if((ar|0)!=0){c[N+16>>2]=c[(c[2440392]|0)+(ar<<2)>>2]}ar=an>>>24&15;if((ar|0)!=0){c[N+20>>2]=c[(c[2440392]|0)+(ar<<2)>>2]}ar=an>>>28;if((ar|0)!=0){c[N+24>>2]=c[(c[2440392]|0)+(ar<<2)>>2]}ar=c[ah+((al|1)<<2)>>2]|0;as=ar&15;if((as|0)!=0){c[N+28>>2]=c[(c[2440392]|0)+(as<<2)>>2]}as=ar>>>4&15;if((as|0)!=0){c[N+32>>2]=c[(c[2440392]|0)+(as<<2)>>2]}as=ar>>>8&15;if((as|0)!=0){c[N+36>>2]=c[(c[2440392]|0)+(as<<2)>>2]}as=ar>>>16&15;if((as|0)!=0){c[N+40>>2]=c[(c[2440392]|0)+(as<<2)>>2]}as=ar>>>20&15;if((as|0)!=0){c[N+44>>2]=c[(c[2440392]|0)+(as<<2)>>2]}as=ar>>>24&15;if((as|0)!=0){c[N+48>>2]=c[(c[2440392]|0)+(as<<2)>>2]}as=ar>>>28;if((as|0)==0){break}c[N+52>>2]=c[(c[2440392]|0)+(as<<2)>>2];break}else{if(!aq){c[N+52>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ap=an>>>4&15;if((ap|0)!=0){c[N+48>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ap=an>>>8&15;if((ap|0)!=0){c[N+44>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ap=an>>>12&15;if((ap|0)!=0){c[N+40>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ap=an>>>16&15;if((ap|0)!=0){c[N+36>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ap=an>>>24&15;if((ap|0)!=0){c[N+32>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ap=an>>>28;if((ap|0)!=0){c[N+28>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ap=c[ah+((al|1)<<2)>>2]|0;al=ap&15;if((al|0)!=0){c[N+24>>2]=c[(c[2440392]|0)+(al<<2)>>2]}al=ap>>>4&15;if((al|0)!=0){c[N+20>>2]=c[(c[2440392]|0)+(al<<2)>>2]}al=ap>>>8&15;if((al|0)!=0){c[N+16>>2]=c[(c[2440392]|0)+(al<<2)>>2]}al=ap>>>16&15;if((al|0)!=0){c[N+12>>2]=c[(c[2440392]|0)+(al<<2)>>2]}al=ap>>>20&15;if((al|0)!=0){c[N+8>>2]=c[(c[2440392]|0)+(al<<2)>>2]}al=ap>>>24&15;if((al|0)!=0){c[N+4>>2]=c[(c[2440392]|0)+(al<<2)>>2]}al=ap>>>28;if((al|0)==0){break}c[N>>2]=c[(c[2440392]|0)+(al<<2)>>2];break}}}while(0);af=ae+1|0;if((af|0)>(H|0)){ac=ak;ad=aj;break}else{I=ak;F=aj;D=ai;N=N+s|0;ae=af}}}if((Z|0)>(i|0)){U=38300;break}else{A=ac;B=ad;C=Z}}if((U|0)==38299){return}else if((U|0)==38300){return}}function czM(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0;b=c[3540994]|0;f=c[3528548]|0;g=f<<8;h=c[2385554]|0;do{if((h|0)>31){i=511}else{j=(h<<4)-1|0;if((j|0)>=0){i=j;break}return}}while(0);j=(i|0)>255;k=i&255;l=c[2385550]|0;m=c[2113042]|0;n=c[2113044]|0;o=m+512|0;p=c[2113132]|0;q=c[2385552]<<2;r=c[2112968]|0;s=p<<2;t=c[2415160]|0;u=c[2429858]|0;v=c[2430428]|0;w=c[2429718]|0;x=c[2430092]|0;y=c[3541046]|0;z=c[2430426]|0;A=0;B=0;C=0;L44628:while(1){D=(h|0)>16&(f|0)!=255;E=(h|0)<33;F=511-f|0;G=f+1|0;H=f-255|0;I=~f;J=C;L44630:while(1){K=J+l|0;L=K&511;do{if((L|0)<(m|0)){M=J+m-L|0}else{if((L|0)>=(n|0)){M=o+J-L|0;break}N=(J|0)>255;O=N?16:0;P=J&255;Q=(J|0)<256&j?255:k;if(!D){R=Q;S=P;T=O;U=38325;break L44630}if(E){if(!N){U=38315;break L44630}if((J|0)<(F|0)){M=F;break}else{U=38317;break L44630}}if(N){V=H+P|0;if((V|0)>=0){U=38320;break L44630}N=G+V|0;if((N|0)<0){M=512;break}else{R=f;S=N;T=0;U=38325;break L44630}}else{if((P|0)<=(f|0)){U=38323;break L44630}N=P+I|0;if((N|0)>(f|0)){M=256;break}else{R=f;S=N;T=16;U=38325;break L44630}}}}while(0);if((M|0)>(i|0)){U=38402;break L44628}else{J=M}}if((U|0)==38317){U=0;I=255-f|0;R=Q-I|0;S=P-I|0;T=O;U=38325}else if((U|0)==38323){U=0;W=f;X=O;Y=P;Z=G+J-P|0}else if((U|0)==38315){U=0;_=O;$=P;aa=Q;ab=J+1-P+Q|0;U=38326}else if((U|0)==38320){U=0;W=f;X=O;Y=V;Z=G+J-V|0}if((U|0)==38325){U=0;I=J+1-S+R|0;if(E){_=T;$=S;aa=R;ab=I;U=38326}else{W=R;X=T;Y=S;Z=I}}if((U|0)==38326){U=0;W=(aa|0)>(f|0)?f:aa;X=_;Y=$;Z=ab}I=((K|-512)^511)+n|0;H=(W-Y|0)>(I|0)?I+Y|0:W;if((Y|0)>(H|0)){ac=A;ad=B}else{I=A;F=B;D=-1;N=r+((ag(p,(L<<2)-64|0)|0)+q)|0;ae=Y;while(1){af=d[b+(ae+g)|0]|0;ah=(af>>>4)+X|0;do{if((ah|0)==(D|0)){ai=D;aj=F;ak=I}else{al=ah<<1;am=e[t+((al|1)<<1)>>1]|0;an=(am<<12&983040|(e[t+(al<<1)>>1]|0))&u;do{if((am&8|0)==0){if((am&4|0)==0){ao=an;break}ao=v|an&1048572}else{ao=z|an&1048568}}while(0);an=a[w+ao|0]|0;al=an&255;if(an<<24>>24!=0){ai=ah;aj=al;ak=am;break}c[2385344]=x+(ao<<7);c[2440392]=y+((am>>>4&4080)<<2);ai=ah;aj=al;ak=am}}while(0);do{if((aj|0)==0){ah=af<<1&30;al=(ak&2|0)==0?ah:ah^30;ah=c[2385344]|0;an=c[ah+(al<<2)>>2]|0;ap=an&15;aq=(ap|0)==0;if((ak&1|0)==0){if(!aq){c[N>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ar=an>>>4&15;if((ar|0)!=0){c[N+4>>2]=c[(c[2440392]|0)+(ar<<2)>>2]}ar=an>>>8&15;if((ar|0)!=0){c[N+8>>2]=c[(c[2440392]|0)+(ar<<2)>>2]}ar=an>>>12&15;if((ar|0)!=0){c[N+12>>2]=c[(c[2440392]|0)+(ar<<2)>>2]}ar=an>>>16&15;if((ar|0)!=0){c[N+16>>2]=c[(c[2440392]|0)+(ar<<2)>>2]}ar=an>>>24&15;if((ar|0)!=0){c[N+20>>2]=c[(c[2440392]|0)+(ar<<2)>>2]}ar=an>>>28;if((ar|0)!=0){c[N+24>>2]=c[(c[2440392]|0)+(ar<<2)>>2]}ar=c[ah+((al|1)<<2)>>2]|0;as=ar&15;if((as|0)!=0){c[N+28>>2]=c[(c[2440392]|0)+(as<<2)>>2]}as=ar>>>4&15;if((as|0)!=0){c[N+32>>2]=c[(c[2440392]|0)+(as<<2)>>2]}as=ar>>>8&15;if((as|0)!=0){c[N+36>>2]=c[(c[2440392]|0)+(as<<2)>>2]}as=ar>>>12&15;if((as|0)!=0){c[N+40>>2]=c[(c[2440392]|0)+(as<<2)>>2]}as=ar>>>16&15;if((as|0)!=0){c[N+44>>2]=c[(c[2440392]|0)+(as<<2)>>2]}as=ar>>>20&15;if((as|0)!=0){c[N+48>>2]=c[(c[2440392]|0)+(as<<2)>>2]}as=ar>>>24&15;if((as|0)!=0){c[N+52>>2]=c[(c[2440392]|0)+(as<<2)>>2]}as=ar>>>28;if((as|0)==0){break}c[N+56>>2]=c[(c[2440392]|0)+(as<<2)>>2];break}else{if(!aq){c[N+56>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ap=an>>>4&15;if((ap|0)!=0){c[N+52>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ap=an>>>8&15;if((ap|0)!=0){c[N+48>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ap=an>>>12&15;if((ap|0)!=0){c[N+44>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ap=an>>>16&15;if((ap|0)!=0){c[N+40>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ap=an>>>24&15;if((ap|0)!=0){c[N+36>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ap=an>>>28;if((ap|0)!=0){c[N+32>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ap=c[ah+((al|1)<<2)>>2]|0;al=ap&15;if((al|0)!=0){c[N+28>>2]=c[(c[2440392]|0)+(al<<2)>>2]}al=ap>>>4&15;if((al|0)!=0){c[N+24>>2]=c[(c[2440392]|0)+(al<<2)>>2]}al=ap>>>8&15;if((al|0)!=0){c[N+20>>2]=c[(c[2440392]|0)+(al<<2)>>2]}al=ap>>>12&15;if((al|0)!=0){c[N+16>>2]=c[(c[2440392]|0)+(al<<2)>>2]}al=ap>>>16&15;if((al|0)!=0){c[N+12>>2]=c[(c[2440392]|0)+(al<<2)>>2]}al=ap>>>20&15;if((al|0)!=0){c[N+8>>2]=c[(c[2440392]|0)+(al<<2)>>2]}al=ap>>>24&15;if((al|0)!=0){c[N+4>>2]=c[(c[2440392]|0)+(al<<2)>>2]}al=ap>>>28;if((al|0)==0){break}c[N>>2]=c[(c[2440392]|0)+(al<<2)>>2];break}}}while(0);af=ae+1|0;if((af|0)>(H|0)){ac=ak;ad=aj;break}else{I=ak;F=aj;D=ai;N=N+s|0;ae=af}}}if((Z|0)>(i|0)){U=38401;break}else{A=ac;B=ad;C=Z}}if((U|0)==38401){return}else if((U|0)==38402){return}}function czN(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0;b=c[3540994]|0;f=c[3528548]|0;g=f<<8;h=c[2385554]|0;do{if((h|0)>31){i=511}else{j=(h<<4)-1|0;if((j|0)>=0){i=j;break}return}}while(0);j=(i|0)>255;k=i&255;l=c[2385550]|0;m=c[2113042]|0;n=c[2113044]|0;o=m+512|0;p=c[2113132]|0;q=c[2385552]<<2;r=c[2112968]|0;s=p<<2;t=c[2415160]|0;u=c[2429858]|0;v=c[2430428]|0;w=c[2429718]|0;x=c[2430092]|0;y=c[3541046]|0;z=c[2430426]|0;A=0;B=0;C=0;L44773:while(1){D=(h|0)>16&(f|0)!=255;E=(h|0)<33;F=511-f|0;G=f+1|0;H=f-255|0;I=~f;J=C;L44775:while(1){K=J+l|0;L=K&511;do{if((L|0)<(m|0)){M=J+m-L|0}else{if((L|0)>=(n|0)){M=o+J-L|0;break}N=(J|0)>255;O=N?16:0;P=J&255;Q=(J|0)<256&j?255:k;if(!D){R=Q;S=P;T=O;U=38426;break L44775}if(E){if(!N){U=38416;break L44775}if((J|0)<(F|0)){M=F;break}else{U=38418;break L44775}}if(N){V=H+P|0;if((V|0)>=0){U=38421;break L44775}N=G+V|0;if((N|0)<0){M=512;break}else{R=f;S=N;T=0;U=38426;break L44775}}else{if((P|0)<=(f|0)){U=38424;break L44775}N=P+I|0;if((N|0)>(f|0)){M=256;break}else{R=f;S=N;T=16;U=38426;break L44775}}}}while(0);if((M|0)>(i|0)){U=38505;break L44773}else{J=M}}if((U|0)==38421){U=0;W=f;X=O;Y=V;Z=G+J-V|0}else if((U|0)==38424){U=0;W=f;X=O;Y=P;Z=G+J-P|0}else if((U|0)==38416){U=0;_=O;$=P;aa=Q;ab=J+1-P+Q|0;U=38427}else if((U|0)==38418){U=0;I=255-f|0;R=Q-I|0;S=P-I|0;T=O;U=38426}if((U|0)==38426){U=0;I=J+1-S+R|0;if(E){_=T;$=S;aa=R;ab=I;U=38427}else{W=R;X=T;Y=S;Z=I}}if((U|0)==38427){U=0;W=(aa|0)>(f|0)?f:aa;X=_;Y=$;Z=ab}I=((K|-512)^511)+n|0;H=(W-Y|0)>(I|0)?I+Y|0:W;if((Y|0)>(H|0)){ac=A;ad=B}else{I=A;F=B;D=-1;N=r+((ag(p,(L<<2)-64|0)|0)+q)|0;ae=Y;while(1){af=d[b+(ae+g)|0]|0;ah=(af>>>4)+X|0;do{if((ah|0)==(D|0)){ai=D;aj=F;ak=I}else{al=ah<<1;am=e[t+((al|1)<<1)>>1]|0;an=(am<<12&983040|(e[t+(al<<1)>>1]|0))&u;do{if((am&8|0)==0){if((am&4|0)==0){ao=an;break}ao=v|an&1048572}else{ao=z|an&1048568}}while(0);an=a[w+ao|0]|0;al=an&255;if(an<<24>>24!=0){ai=ah;aj=al;ak=am;break}c[2385344]=x+(ao<<7);c[2440392]=y+((am>>>4&4080)<<2);ai=ah;aj=al;ak=am}}while(0);do{if((aj|0)==0){ah=af<<1&30;al=(ak&2|0)==0?ah:ah^30;ah=c[2385344]|0;an=c[ah+(al<<2)>>2]|0;ap=an&15;aq=(ap|0)==0;if((ak&1|0)==0){if(!aq){c[N>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ar=an>>>4&15;if((ar|0)!=0){c[N+4>>2]=c[(c[2440392]|0)+(ar<<2)>>2]}ar=an>>>8&15;if((ar|0)!=0){c[N+8>>2]=c[(c[2440392]|0)+(ar<<2)>>2]}ar=an>>>12&15;if((ar|0)!=0){c[N+12>>2]=c[(c[2440392]|0)+(ar<<2)>>2]}ar=an>>>16&15;if((ar|0)!=0){c[N+16>>2]=c[(c[2440392]|0)+(ar<<2)>>2]}ar=an>>>20&15;if((ar|0)!=0){c[N+20>>2]=c[(c[2440392]|0)+(ar<<2)>>2]}ar=an>>>24&15;if((ar|0)!=0){c[N+24>>2]=c[(c[2440392]|0)+(ar<<2)>>2]}ar=an>>>28;if((ar|0)!=0){c[N+28>>2]=c[(c[2440392]|0)+(ar<<2)>>2]}ar=c[ah+((al|1)<<2)>>2]|0;as=ar&15;if((as|0)!=0){c[N+32>>2]=c[(c[2440392]|0)+(as<<2)>>2]}as=ar>>>4&15;if((as|0)!=0){c[N+36>>2]=c[(c[2440392]|0)+(as<<2)>>2]}as=ar>>>8&15;if((as|0)!=0){c[N+40>>2]=c[(c[2440392]|0)+(as<<2)>>2]}as=ar>>>12&15;if((as|0)!=0){c[N+44>>2]=c[(c[2440392]|0)+(as<<2)>>2]}as=ar>>>16&15;if((as|0)!=0){c[N+48>>2]=c[(c[2440392]|0)+(as<<2)>>2]}as=ar>>>20&15;if((as|0)!=0){c[N+52>>2]=c[(c[2440392]|0)+(as<<2)>>2]}as=ar>>>24&15;if((as|0)!=0){c[N+56>>2]=c[(c[2440392]|0)+(as<<2)>>2]}as=ar>>>28;if((as|0)==0){break}c[N+60>>2]=c[(c[2440392]|0)+(as<<2)>>2];break}else{if(!aq){c[N+60>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ap=an>>>4&15;if((ap|0)!=0){c[N+56>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ap=an>>>8&15;if((ap|0)!=0){c[N+52>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ap=an>>>12&15;if((ap|0)!=0){c[N+48>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ap=an>>>16&15;if((ap|0)!=0){c[N+44>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ap=an>>>20&15;if((ap|0)!=0){c[N+40>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ap=an>>>24&15;if((ap|0)!=0){c[N+36>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ap=an>>>28;if((ap|0)!=0){c[N+32>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ap=c[ah+((al|1)<<2)>>2]|0;al=ap&15;if((al|0)!=0){c[N+28>>2]=c[(c[2440392]|0)+(al<<2)>>2]}al=ap>>>4&15;if((al|0)!=0){c[N+24>>2]=c[(c[2440392]|0)+(al<<2)>>2]}al=ap>>>8&15;if((al|0)!=0){c[N+20>>2]=c[(c[2440392]|0)+(al<<2)>>2]}al=ap>>>12&15;if((al|0)!=0){c[N+16>>2]=c[(c[2440392]|0)+(al<<2)>>2]}al=ap>>>16&15;if((al|0)!=0){c[N+12>>2]=c[(c[2440392]|0)+(al<<2)>>2]}al=ap>>>20&15;if((al|0)!=0){c[N+8>>2]=c[(c[2440392]|0)+(al<<2)>>2]}al=ap>>>24&15;if((al|0)!=0){c[N+4>>2]=c[(c[2440392]|0)+(al<<2)>>2]}al=ap>>>28;if((al|0)==0){break}c[N>>2]=c[(c[2440392]|0)+(al<<2)>>2];break}}}while(0);af=ae+1|0;if((af|0)>(H|0)){ac=ak;ad=aj;break}else{I=ak;F=aj;D=ai;N=N+s|0;ae=af}}}if((Z|0)>(i|0)){U=38506;break}else{A=ac;B=ad;C=Z}}if((U|0)==38505){return}else if((U|0)==38506){return}}function czO(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0;b=c[3540994]|0;f=c[3528548]|0;g=f<<8;h=c[2385554]|0;do{if((h|0)>31){i=511}else{j=(h<<4)-1|0;if((j|0)>=0){i=j;break}return}}while(0);j=(i|0)>255;k=i&255;l=c[2385550]|0;m=c[2113042]|0;n=c[2113044]|0;o=m+512|0;p=c[2385552]|0;q=c[2113132]|0;r=p<<2;s=c[2112968]|0;t=(p|0)>-1;u=q<<2;v=c[2415160]|0;w=c[2429858]|0;x=c[2430428]|0;y=c[2429718]|0;z=c[2430092]|0;A=c[3541046]|0;B=c[2430426]|0;C=0;D=0;E=0;L44924:while(1){F=(h|0)>16&(f|0)!=255;G=(h|0)<33;H=511-f|0;I=f+1|0;J=f-255|0;K=~f;L=E;L44926:while(1){M=L+l|0;N=M&511;do{if((N|0)<(m|0)){O=L+m-N|0}else{if((N|0)>=(n|0)){O=o+L-N|0;break}P=(L|0)>255;Q=P?16:0;R=L&255;S=(L|0)<256&j?255:k;if(!F){T=S;U=R;V=Q;W=38531;break L44926}if(G){if(!P){W=38521;break L44926}if((L|0)<(H|0)){O=H;break}else{W=38523;break L44926}}if(P){X=J+R|0;if((X|0)>=0){W=38526;break L44926}P=I+X|0;if((P|0)<0){O=512;break}else{T=f;U=P;V=0;W=38531;break L44926}}else{if((R|0)<=(f|0)){W=38529;break L44926}P=R+K|0;if((P|0)>(f|0)){O=256;break}else{T=f;U=P;V=16;W=38531;break L44926}}}}while(0);if((O|0)>(i|0)){W=38554;break L44924}else{L=O}}if((W|0)==38523){W=0;K=255-f|0;T=S-K|0;U=R-K|0;V=Q;W=38531}else if((W|0)==38529){W=0;Y=f;Z=Q;_=R;$=I+L-R|0}else if((W|0)==38521){W=0;aa=Q;ab=R;ac=S;ad=L+1-R+S|0;W=38532}else if((W|0)==38526){W=0;Y=f;Z=Q;_=X;$=I+L-X|0}if((W|0)==38531){W=0;K=L+1-U+T|0;if(G){aa=V;ab=U;ac=T;ad=K;W=38532}else{Y=T;Z=V;_=U;$=K}}if((W|0)==38532){W=0;Y=(ac|0)>(f|0)?f:ac;Z=aa;_=ab;$=ad}K=((M|-512)^511)+n|0;J=(Y-_|0)>(K|0)?K+_|0:Y;if((_|0)>(J|0)){ae=C;af=D}else{K=C;H=D;F=-1;P=s+((ag(q,(N<<2)-64|0)|0)+r)|0;ah=_;while(1){ai=d[b+(ah+g)|0]|0;aj=(ai>>>4)+Z|0;do{if((aj|0)==(F|0)){ak=F;al=H;am=K}else{an=aj<<1;ao=e[v+((an|1)<<1)>>1]|0;ap=(ao<<12&983040|(e[v+(an<<1)>>1]|0))&w;do{if((ao&8|0)==0){if((ao&4|0)==0){aq=ap;break}aq=x|ap&1048572}else{aq=B|ap&1048568}}while(0);ap=a[y+aq|0]|0;an=ap&255;if(ap<<24>>24!=0){ak=aj;al=an;am=ao;break}c[2385344]=z+(aq<<7);c[2440392]=A+((ao>>>4&4080)<<2);ak=aj;al=an;am=ao}}while(0);do{if((al|0)==0){aj=ai<<1&30;an=c[(c[2385344]|0)+((((am&2|0)==0?aj:aj^30)|1)<<2)>>2]&15;aj=(an|0)==0;if((am&1|0)==0){if(aj){break}if(!(t&(p|0)<(q|0))){break}c[P>>2]=c[(c[2440392]|0)+(an<<2)>>2];break}else{if(aj){break}if(!(t&(p|0)<(q|0))){break}c[P>>2]=c[(c[2440392]|0)+(an<<2)>>2];break}}}while(0);ai=ah+1|0;if((ai|0)>(J|0)){ae=am;af=al;break}else{K=am;H=al;F=ak;P=P+u|0;ah=ai}}}if(($|0)>(i|0)){W=38553;break}else{C=ae;D=af;E=$}}if((W|0)==38553){return}else if((W|0)==38554){return}}function czP(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0;b=c[3540994]|0;f=c[3528548]|0;g=f<<8;h=c[2385554]|0;do{if((h|0)>31){i=511}else{j=(h<<4)-1|0;if((j|0)>=0){i=j;break}return}}while(0);j=(i|0)>255;k=i&255;l=c[2385550]|0;m=c[2113042]|0;n=c[2113044]|0;o=m+512|0;p=c[2385552]|0;q=c[2113132]|0;r=p<<2;s=c[2112968]|0;t=p+1|0;u=(t|0)>-1&(t|0)<(q|0);t=(p|0)>-1&(p|0)<(q|0);p=q<<2;v=c[2415160]|0;w=c[2429858]|0;x=c[2430428]|0;y=c[2429718]|0;z=c[2430092]|0;A=c[3541046]|0;B=c[2430426]|0;C=0;D=0;E=0;L44987:while(1){F=(h|0)>16&(f|0)!=255;G=(h|0)<33;H=511-f|0;I=f+1|0;J=f-255|0;K=~f;L=E;L44989:while(1){M=L+l|0;N=M&511;do{if((N|0)<(m|0)){O=L+m-N|0}else{if((N|0)>=(n|0)){O=o+L-N|0;break}P=(L|0)>255;Q=P?16:0;R=L&255;S=(L|0)<256&j?255:k;if(!F){T=S;U=R;V=Q;W=38578;break L44989}if(G){if(!P){W=38568;break L44989}if((L|0)<(H|0)){O=H;break}else{W=38570;break L44989}}if(P){X=J+R|0;if((X|0)>=0){W=38573;break L44989}P=I+X|0;if((P|0)<0){O=512;break}else{T=f;U=P;V=0;W=38578;break L44989}}else{if((R|0)<=(f|0)){W=38576;break L44989}P=R+K|0;if((P|0)>(f|0)){O=256;break}else{T=f;U=P;V=16;W=38578;break L44989}}}}while(0);if((O|0)>(i|0)){W=38601;break L44987}else{L=O}}if((W|0)==38573){W=0;Y=f;Z=Q;_=X;$=I+L-X|0}else if((W|0)==38576){W=0;Y=f;Z=Q;_=R;$=I+L-R|0}else if((W|0)==38568){W=0;aa=Q;ab=R;ac=S;ad=L+1-R+S|0;W=38579}else if((W|0)==38570){W=0;K=255-f|0;T=S-K|0;U=R-K|0;V=Q;W=38578}if((W|0)==38578){W=0;K=L+1-U+T|0;if(G){aa=V;ab=U;ac=T;ad=K;W=38579}else{Y=T;Z=V;_=U;$=K}}if((W|0)==38579){W=0;Y=(ac|0)>(f|0)?f:ac;Z=aa;_=ab;$=ad}K=((M|-512)^511)+n|0;J=(Y-_|0)>(K|0)?K+_|0:Y;if((_|0)>(J|0)){ae=C;af=D}else{K=C;H=D;F=-1;P=s+((ag(q,(N<<2)-64|0)|0)+r)|0;ah=_;while(1){ai=d[b+(ah+g)|0]|0;aj=(ai>>>4)+Z|0;do{if((aj|0)==(F|0)){ak=F;al=H;am=K}else{an=aj<<1;ao=e[v+((an|1)<<1)>>1]|0;ap=(ao<<12&983040|(e[v+(an<<1)>>1]|0))&w;do{if((ao&8|0)==0){if((ao&4|0)==0){aq=ap;break}aq=x|ap&1048572}else{aq=B|ap&1048568}}while(0);ap=a[y+aq|0]|0;an=ap&255;if(ap<<24>>24!=0){ak=aj;al=an;am=ao;break}c[2385344]=z+(aq<<7);c[2440392]=A+((ao>>>4&4080)<<2);ak=aj;al=an;am=ao}}while(0);do{if((al|0)==0){aj=ai<<1&30;an=(am&2|0)==0?aj:aj^30;if((am&1|0)==0){aj=c[2385344]|0;ap=(c[aj+(an<<2)>>2]|0)>>>16&15;if(!((ap|0)==0|t^1)){c[P>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ap=c[aj+((an|1)<<2)>>2]&15;if((ap|0)==0|u^1){break}c[P+4>>2]=c[(c[2440392]|0)+(ap<<2)>>2];break}else{ap=c[2385344]|0;aj=(c[ap+(an<<2)>>2]|0)>>>16&15;if(!((aj|0)==0|u^1)){c[P+4>>2]=c[(c[2440392]|0)+(aj<<2)>>2]}aj=c[ap+((an|1)<<2)>>2]&15;if((aj|0)==0|t^1){break}c[P>>2]=c[(c[2440392]|0)+(aj<<2)>>2];break}}}while(0);ai=ah+1|0;if((ai|0)>(J|0)){ae=am;af=al;break}else{K=am;H=al;F=ak;P=P+p|0;ah=ai}}}if(($|0)>(i|0)){W=38602;break}else{C=ae;D=af;E=$}}if((W|0)==38601){return}else if((W|0)==38602){return}}function czQ(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0;b=c[3540994]|0;f=c[3528548]|0;g=f<<8;h=c[2385554]|0;do{if((h|0)>31){i=511}else{j=(h<<4)-1|0;if((j|0)>=0){i=j;break}return}}while(0);j=(i|0)>255;k=i&255;l=c[2385550]|0;m=c[2113042]|0;n=c[2113044]|0;o=m+512|0;p=c[2385552]|0;q=c[2113132]|0;r=p<<2;s=c[2112968]|0;t=p+2|0;u=(t|0)>-1&(t|0)<(q|0);t=p+1|0;v=(t|0)>-1&(t|0)<(q|0);t=(p|0)>-1&(p|0)<(q|0);p=q<<2;w=c[2415160]|0;x=c[2429858]|0;y=c[2430428]|0;z=c[2429718]|0;A=c[2430092]|0;B=c[3541046]|0;C=c[2430426]|0;D=0;E=0;F=0;L45054:while(1){G=(h|0)>16&(f|0)!=255;H=(h|0)<33;I=511-f|0;J=f+1|0;K=f-255|0;L=~f;M=F;L45056:while(1){N=M+l|0;O=N&511;do{if((O|0)<(m|0)){P=M+m-O|0}else{if((O|0)>=(n|0)){P=o+M-O|0;break}Q=(M|0)>255;R=Q?16:0;S=M&255;T=(M|0)<256&j?255:k;if(!G){U=T;V=S;W=R;X=38627;break L45056}if(H){if(!Q){X=38617;break L45056}if((M|0)<(I|0)){P=I;break}else{X=38619;break L45056}}if(Q){Y=K+S|0;if((Y|0)>=0){X=38622;break L45056}Q=J+Y|0;if((Q|0)<0){P=512;break}else{U=f;V=Q;W=0;X=38627;break L45056}}else{if((S|0)<=(f|0)){X=38625;break L45056}Q=S+L|0;if((Q|0)>(f|0)){P=256;break}else{U=f;V=Q;W=16;X=38627;break L45056}}}}while(0);if((P|0)>(i|0)){X=38654;break L45054}else{M=P}}if((X|0)==38619){X=0;L=255-f|0;U=T-L|0;V=S-L|0;W=R;X=38627}else if((X|0)==38622){X=0;Z=f;_=R;$=Y;aa=J+M-Y|0}else if((X|0)==38625){X=0;Z=f;_=R;$=S;aa=J+M-S|0}else if((X|0)==38617){X=0;ab=R;ac=S;ad=T;ae=M+1-S+T|0;X=38628}if((X|0)==38627){X=0;L=M+1-V+U|0;if(H){ab=W;ac=V;ad=U;ae=L;X=38628}else{Z=U;_=W;$=V;aa=L}}if((X|0)==38628){X=0;Z=(ad|0)>(f|0)?f:ad;_=ab;$=ac;aa=ae}L=((N|-512)^511)+n|0;K=(Z-$|0)>(L|0)?L+$|0:Z;if(($|0)>(K|0)){af=D;ah=E}else{L=D;I=E;G=-1;Q=s+((ag(q,(O<<2)-64|0)|0)+r)|0;ai=$;while(1){aj=d[b+(ai+g)|0]|0;ak=(aj>>>4)+_|0;do{if((ak|0)==(G|0)){al=G;am=I;an=L}else{ao=ak<<1;ap=e[w+((ao|1)<<1)>>1]|0;aq=(ap<<12&983040|(e[w+(ao<<1)>>1]|0))&x;do{if((ap&8|0)==0){if((ap&4|0)==0){ar=aq;break}ar=y|aq&1048572}else{ar=C|aq&1048568}}while(0);aq=a[z+ar|0]|0;ao=aq&255;if(aq<<24>>24!=0){al=ak;am=ao;an=ap;break}c[2385344]=A+(ar<<7);c[2440392]=B+((ap>>>4&4080)<<2);al=ak;am=ao;an=ap}}while(0);do{if((am|0)==0){ak=aj<<1&30;ao=(an&2|0)==0?ak:ak^30;if((an&1|0)==0){ak=c[2385344]|0;aq=(c[ak+(ao<<2)>>2]|0)>>>16&15;if(!((aq|0)==0|t^1)){c[Q>>2]=c[(c[2440392]|0)+(aq<<2)>>2]}aq=c[ak+((ao|1)<<2)>>2]|0;ak=aq&15;if(!((ak|0)==0|v^1)){c[Q+4>>2]=c[(c[2440392]|0)+(ak<<2)>>2]}ak=aq>>>16&15;if((ak|0)==0|u^1){break}c[Q+8>>2]=c[(c[2440392]|0)+(ak<<2)>>2];break}else{ak=c[2385344]|0;aq=(c[ak+(ao<<2)>>2]|0)>>>16&15;if(!((aq|0)==0|u^1)){c[Q+8>>2]=c[(c[2440392]|0)+(aq<<2)>>2]}aq=c[ak+((ao|1)<<2)>>2]|0;ao=aq&15;if(!((ao|0)==0|v^1)){c[Q+4>>2]=c[(c[2440392]|0)+(ao<<2)>>2]}ao=aq>>>16&15;if((ao|0)==0|t^1){break}c[Q>>2]=c[(c[2440392]|0)+(ao<<2)>>2];break}}}while(0);aj=ai+1|0;if((aj|0)>(K|0)){af=an;ah=am;break}else{L=an;I=am;G=al;Q=Q+p|0;ai=aj}}}if((aa|0)>(i|0)){X=38655;break}else{D=af;E=ah;F=aa}}if((X|0)==38655){return}else if((X|0)==38654){return}}function czR(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0;b=c[3540994]|0;f=c[3528548]|0;g=f<<8;h=c[2385554]|0;do{if((h|0)>31){i=511}else{j=(h<<4)-1|0;if((j|0)>=0){i=j;break}return}}while(0);j=(i|0)>255;k=i&255;l=c[2385550]|0;m=c[2113042]|0;n=c[2113044]|0;o=m+512|0;p=c[2385552]|0;q=c[2113132]|0;r=p<<2;s=c[2112968]|0;t=p+3|0;u=(t|0)>-1&(t|0)<(q|0);t=p+2|0;v=(t|0)>-1&(t|0)<(q|0);t=p+1|0;w=(t|0)>-1&(t|0)<(q|0);t=(p|0)>-1&(p|0)<(q|0);p=q<<2;x=c[2415160]|0;y=c[2429858]|0;z=c[2430428]|0;A=c[2429718]|0;B=c[2430092]|0;C=c[3541046]|0;D=c[2430426]|0;E=0;F=0;G=0;L45127:while(1){H=(h|0)>16&(f|0)!=255;I=(h|0)<33;J=511-f|0;K=f+1|0;L=f-255|0;M=~f;N=G;L45129:while(1){O=N+l|0;P=O&511;do{if((P|0)<(m|0)){Q=N+m-P|0}else{if((P|0)>=(n|0)){Q=o+N-P|0;break}R=(N|0)>255;S=R?16:0;T=N&255;U=(N|0)<256&j?255:k;if(!H){V=U;W=T;X=S;Y=38680;break L45129}if(I){if(!R){Y=38670;break L45129}if((N|0)<(J|0)){Q=J;break}else{Y=38672;break L45129}}if(R){Z=L+T|0;if((Z|0)>=0){Y=38675;break L45129}R=K+Z|0;if((R|0)<0){Q=512;break}else{V=f;W=R;X=0;Y=38680;break L45129}}else{if((T|0)<=(f|0)){Y=38678;break L45129}R=T+M|0;if((R|0)>(f|0)){Q=256;break}else{V=f;W=R;X=16;Y=38680;break L45129}}}}while(0);if((Q|0)>(i|0)){Y=38712;break L45127}else{N=Q}}if((Y|0)==38670){Y=0;_=S;$=T;aa=U;ab=N+1-T+U|0;Y=38681}else if((Y|0)==38675){Y=0;ac=f;ad=S;ae=Z;af=K+N-Z|0}else if((Y|0)==38672){Y=0;M=255-f|0;V=U-M|0;W=T-M|0;X=S;Y=38680}else if((Y|0)==38678){Y=0;ac=f;ad=S;ae=T;af=K+N-T|0}if((Y|0)==38680){Y=0;M=N+1-W+V|0;if(I){_=X;$=W;aa=V;ab=M;Y=38681}else{ac=V;ad=X;ae=W;af=M}}if((Y|0)==38681){Y=0;ac=(aa|0)>(f|0)?f:aa;ad=_;ae=$;af=ab}M=((O|-512)^511)+n|0;L=(ac-ae|0)>(M|0)?M+ae|0:ac;if((ae|0)>(L|0)){ah=E;ai=F}else{M=E;J=F;H=-1;R=s+((ag(q,(P<<2)-64|0)|0)+r)|0;aj=ae;while(1){ak=d[b+(aj+g)|0]|0;al=(ak>>>4)+ad|0;do{if((al|0)==(H|0)){am=H;an=J;ao=M}else{ap=al<<1;aq=e[x+((ap|1)<<1)>>1]|0;ar=(aq<<12&983040|(e[x+(ap<<1)>>1]|0))&y;do{if((aq&8|0)==0){if((aq&4|0)==0){as=ar;break}as=z|ar&1048572}else{as=D|ar&1048568}}while(0);ar=a[A+as|0]|0;ap=ar&255;if(ar<<24>>24!=0){am=al;an=ap;ao=aq;break}c[2385344]=B+(as<<7);c[2440392]=C+((aq>>>4&4080)<<2);am=al;an=ap;ao=aq}}while(0);do{if((an|0)==0){al=ak<<1&30;ap=(ao&2|0)==0?al:al^30;if((ao&1|0)==0){al=c[2385344]|0;ar=c[al+(ap<<2)>>2]|0;at=ar>>>8&15;if(!((at|0)==0|t^1)){c[R>>2]=c[(c[2440392]|0)+(at<<2)>>2]}at=ar>>>16&15;if(!((at|0)==0|w^1)){c[R+4>>2]=c[(c[2440392]|0)+(at<<2)>>2]}at=c[al+((ap|1)<<2)>>2]|0;al=at&15;if(!((al|0)==0|v^1)){c[R+8>>2]=c[(c[2440392]|0)+(al<<2)>>2]}al=at>>>16&15;if((al|0)==0|u^1){break}c[R+12>>2]=c[(c[2440392]|0)+(al<<2)>>2];break}else{al=c[2385344]|0;at=c[al+(ap<<2)>>2]|0;ar=at>>>8&15;if(!((ar|0)==0|u^1)){c[R+12>>2]=c[(c[2440392]|0)+(ar<<2)>>2]}ar=at>>>16&15;if(!((ar|0)==0|v^1)){c[R+8>>2]=c[(c[2440392]|0)+(ar<<2)>>2]}ar=c[al+((ap|1)<<2)>>2]|0;ap=ar&15;if(!((ap|0)==0|w^1)){c[R+4>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ap=ar>>>16&15;if((ap|0)==0|t^1){break}c[R>>2]=c[(c[2440392]|0)+(ap<<2)>>2];break}}}while(0);ak=aj+1|0;if((ak|0)>(L|0)){ah=ao;ai=an;break}else{M=ao;J=an;H=am;R=R+p|0;aj=ak}}}if((af|0)>(i|0)){Y=38713;break}else{E=ah;F=ai;G=af}}if((Y|0)==38712){return}else if((Y|0)==38713){return}}function czS(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0;b=c[3540994]|0;f=c[3528548]|0;g=f<<8;h=c[2385554]|0;do{if((h|0)>31){i=511}else{j=(h<<4)-1|0;if((j|0)>=0){i=j;break}return}}while(0);j=(i|0)>255;k=i&255;l=c[2385550]|0;m=c[2113042]|0;n=c[2113044]|0;o=m+512|0;p=c[2385552]|0;q=c[2113132]|0;r=p<<2;s=c[2112968]|0;t=p+4|0;u=(t|0)>-1&(t|0)<(q|0);t=p+3|0;v=(t|0)>-1&(t|0)<(q|0);t=p+2|0;w=(t|0)>-1&(t|0)<(q|0);t=p+1|0;x=(t|0)>-1&(t|0)<(q|0);t=(p|0)>-1&(p|0)<(q|0);p=q<<2;y=c[2415160]|0;z=c[2429858]|0;A=c[2430428]|0;B=c[2429718]|0;C=c[2430092]|0;D=c[3541046]|0;E=c[2430426]|0;F=0;G=0;H=0;L45206:while(1){I=(h|0)>16&(f|0)!=255;J=(h|0)<33;K=511-f|0;L=f+1|0;M=f-255|0;N=~f;O=H;L45208:while(1){P=O+l|0;Q=P&511;do{if((Q|0)<(m|0)){R=O+m-Q|0}else{if((Q|0)>=(n|0)){R=o+O-Q|0;break}S=(O|0)>255;T=S?16:0;U=O&255;V=(O|0)<256&j?255:k;if(!I){W=V;X=U;Y=T;Z=38737;break L45208}if(J){if(!S){Z=38727;break L45208}if((O|0)<(K|0)){R=K;break}else{Z=38729;break L45208}}if(S){_=M+U|0;if((_|0)>=0){Z=38732;break L45208}S=L+_|0;if((S|0)<0){R=512;break}else{W=f;X=S;Y=0;Z=38737;break L45208}}else{if((U|0)<=(f|0)){Z=38735;break L45208}S=U+N|0;if((S|0)>(f|0)){R=256;break}else{W=f;X=S;Y=16;Z=38737;break L45208}}}}while(0);if((R|0)>(i|0)){Z=38772;break L45206}else{O=R}}if((Z|0)==38729){Z=0;N=255-f|0;W=V-N|0;X=U-N|0;Y=T;Z=38737}else if((Z|0)==38732){Z=0;$=f;aa=T;ab=_;ac=L+O-_|0}else if((Z|0)==38735){Z=0;$=f;aa=T;ab=U;ac=L+O-U|0}else if((Z|0)==38727){Z=0;ad=T;ae=U;af=V;ah=O+1-U+V|0;Z=38738}if((Z|0)==38737){Z=0;N=O+1-X+W|0;if(J){ad=Y;ae=X;af=W;ah=N;Z=38738}else{$=W;aa=Y;ab=X;ac=N}}if((Z|0)==38738){Z=0;$=(af|0)>(f|0)?f:af;aa=ad;ab=ae;ac=ah}N=((P|-512)^511)+n|0;M=($-ab|0)>(N|0)?N+ab|0:$;if((ab|0)>(M|0)){ai=F;aj=G}else{N=F;K=G;I=-1;S=s+((ag(q,(Q<<2)-64|0)|0)+r)|0;ak=ab;while(1){al=d[b+(ak+g)|0]|0;am=(al>>>4)+aa|0;do{if((am|0)==(I|0)){an=I;ao=K;ap=N}else{aq=am<<1;ar=e[y+((aq|1)<<1)>>1]|0;as=(ar<<12&983040|(e[y+(aq<<1)>>1]|0))&z;do{if((ar&8|0)==0){if((ar&4|0)==0){at=as;break}at=A|as&1048572}else{at=E|as&1048568}}while(0);as=a[B+at|0]|0;aq=as&255;if(as<<24>>24!=0){an=am;ao=aq;ap=ar;break}c[2385344]=C+(at<<7);c[2440392]=D+((ar>>>4&4080)<<2);an=am;ao=aq;ap=ar}}while(0);do{if((ao|0)==0){am=al<<1&30;aq=(ap&2|0)==0?am:am^30;if((ap&1|0)==0){am=c[2385344]|0;as=c[am+(aq<<2)>>2]|0;au=as>>>8&15;if(!((au|0)==0|t^1)){c[S>>2]=c[(c[2440392]|0)+(au<<2)>>2]}au=as>>>16&15;if(!((au|0)==0|x^1)){c[S+4>>2]=c[(c[2440392]|0)+(au<<2)>>2]}au=c[am+((aq|1)<<2)>>2]|0;am=au&15;if(!((am|0)==0|w^1)){c[S+8>>2]=c[(c[2440392]|0)+(am<<2)>>2]}am=au>>>16&15;if(!((am|0)==0|v^1)){c[S+12>>2]=c[(c[2440392]|0)+(am<<2)>>2]}am=au>>>24&15;if((am|0)==0|u^1){break}c[S+16>>2]=c[(c[2440392]|0)+(am<<2)>>2];break}else{am=c[2385344]|0;au=c[am+(aq<<2)>>2]|0;as=au>>>8&15;if(!((as|0)==0|u^1)){c[S+16>>2]=c[(c[2440392]|0)+(as<<2)>>2]}as=au>>>16&15;if(!((as|0)==0|v^1)){c[S+12>>2]=c[(c[2440392]|0)+(as<<2)>>2]}as=c[am+((aq|1)<<2)>>2]|0;aq=as&15;if(!((aq|0)==0|w^1)){c[S+8>>2]=c[(c[2440392]|0)+(aq<<2)>>2]}aq=as>>>16&15;if(!((aq|0)==0|x^1)){c[S+4>>2]=c[(c[2440392]|0)+(aq<<2)>>2]}aq=as>>>24&15;if((aq|0)==0|t^1){break}c[S>>2]=c[(c[2440392]|0)+(aq<<2)>>2];break}}}while(0);al=ak+1|0;if((al|0)>(M|0)){ai=ap;aj=ao;break}else{N=ap;K=ao;I=an;S=S+p|0;ak=al}}}if((ac|0)>(i|0)){Z=38773;break}else{F=ai;G=aj;H=ac}}if((Z|0)==38772){return}else if((Z|0)==38773){return}}function czT(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0;b=c[3540994]|0;f=c[3528548]|0;g=f<<8;h=c[2385554]|0;do{if((h|0)>31){i=511}else{j=(h<<4)-1|0;if((j|0)>=0){i=j;break}return}}while(0);j=(i|0)>255;k=i&255;l=c[2385550]|0;m=c[2113042]|0;n=c[2113044]|0;o=m+512|0;p=c[2385552]|0;q=c[2113132]|0;r=p<<2;s=c[2112968]|0;t=p+5|0;u=(t|0)>-1&(t|0)<(q|0);t=p+4|0;v=(t|0)>-1&(t|0)<(q|0);t=p+3|0;w=(t|0)>-1&(t|0)<(q|0);t=p+2|0;x=(t|0)>-1&(t|0)<(q|0);t=p+1|0;y=(t|0)>-1&(t|0)<(q|0);t=(p|0)>-1&(p|0)<(q|0);p=q<<2;z=c[2415160]|0;A=c[2429858]|0;B=c[2430428]|0;C=c[2429718]|0;D=c[2430092]|0;E=c[3541046]|0;F=c[2430426]|0;G=0;H=0;I=0;L45291:while(1){J=(h|0)>16&(f|0)!=255;K=(h|0)<33;L=511-f|0;M=f+1|0;N=f-255|0;O=~f;P=I;L45293:while(1){Q=P+l|0;R=Q&511;do{if((R|0)<(m|0)){S=P+m-R|0}else{if((R|0)>=(n|0)){S=o+P-R|0;break}T=(P|0)>255;U=T?16:0;V=P&255;W=(P|0)<256&j?255:k;if(!J){X=W;Y=V;Z=U;_=38798;break L45293}if(K){if(!T){_=38788;break L45293}if((P|0)<(L|0)){S=L;break}else{_=38790;break L45293}}if(T){$=N+V|0;if(($|0)>=0){_=38793;break L45293}T=M+$|0;if((T|0)<0){S=512;break}else{X=f;Y=T;Z=0;_=38798;break L45293}}else{if((V|0)<=(f|0)){_=38796;break L45293}T=V+O|0;if((T|0)>(f|0)){S=256;break}else{X=f;Y=T;Z=16;_=38798;break L45293}}}}while(0);if((S|0)>(i|0)){_=38837;break L45291}else{P=S}}if((_|0)==38788){_=0;aa=U;ab=V;ac=W;ad=P+1-V+W|0;_=38799}else if((_|0)==38796){_=0;ae=f;af=U;ah=V;ai=M+P-V|0}else if((_|0)==38790){_=0;O=255-f|0;X=W-O|0;Y=V-O|0;Z=U;_=38798}else if((_|0)==38793){_=0;ae=f;af=U;ah=$;ai=M+P-$|0}if((_|0)==38798){_=0;O=P+1-Y+X|0;if(K){aa=Z;ab=Y;ac=X;ad=O;_=38799}else{ae=X;af=Z;ah=Y;ai=O}}if((_|0)==38799){_=0;ae=(ac|0)>(f|0)?f:ac;af=aa;ah=ab;ai=ad}O=((Q|-512)^511)+n|0;N=(ae-ah|0)>(O|0)?O+ah|0:ae;if((ah|0)>(N|0)){aj=G;ak=H}else{O=G;L=H;J=-1;T=s+((ag(q,(R<<2)-64|0)|0)+r)|0;al=ah;while(1){am=d[b+(al+g)|0]|0;an=(am>>>4)+af|0;do{if((an|0)==(J|0)){ao=J;ap=L;aq=O}else{ar=an<<1;as=e[z+((ar|1)<<1)>>1]|0;at=(as<<12&983040|(e[z+(ar<<1)>>1]|0))&A;do{if((as&8|0)==0){if((as&4|0)==0){au=at;break}au=B|at&1048572}else{au=F|at&1048568}}while(0);at=a[C+au|0]|0;ar=at&255;if(at<<24>>24!=0){ao=an;ap=ar;aq=as;break}c[2385344]=D+(au<<7);c[2440392]=E+((as>>>4&4080)<<2);ao=an;ap=ar;aq=as}}while(0);do{if((ap|0)==0){an=am<<1&30;ar=(aq&2|0)==0?an:an^30;if((aq&1|0)==0){an=c[2385344]|0;at=c[an+(ar<<2)>>2]|0;av=at>>>8&15;if(!((av|0)==0|t^1)){c[T>>2]=c[(c[2440392]|0)+(av<<2)>>2]}av=at>>>16&15;if(!((av|0)==0|y^1)){c[T+4>>2]=c[(c[2440392]|0)+(av<<2)>>2]}av=at>>>24&15;if(!((av|0)==0|x^1)){c[T+8>>2]=c[(c[2440392]|0)+(av<<2)>>2]}av=c[an+((ar|1)<<2)>>2]|0;an=av&15;if(!((an|0)==0|w^1)){c[T+12>>2]=c[(c[2440392]|0)+(an<<2)>>2]}an=av>>>16&15;if(!((an|0)==0|v^1)){c[T+16>>2]=c[(c[2440392]|0)+(an<<2)>>2]}an=av>>>24&15;if((an|0)==0|u^1){break}c[T+20>>2]=c[(c[2440392]|0)+(an<<2)>>2];break}else{an=c[2385344]|0;av=c[an+(ar<<2)>>2]|0;at=av>>>8&15;if(!((at|0)==0|u^1)){c[T+20>>2]=c[(c[2440392]|0)+(at<<2)>>2]}at=av>>>16&15;if(!((at|0)==0|v^1)){c[T+16>>2]=c[(c[2440392]|0)+(at<<2)>>2]}at=av>>>24&15;if(!((at|0)==0|w^1)){c[T+12>>2]=c[(c[2440392]|0)+(at<<2)>>2]}at=c[an+((ar|1)<<2)>>2]|0;ar=at&15;if(!((ar|0)==0|x^1)){c[T+8>>2]=c[(c[2440392]|0)+(ar<<2)>>2]}ar=at>>>16&15;if(!((ar|0)==0|y^1)){c[T+4>>2]=c[(c[2440392]|0)+(ar<<2)>>2]}ar=at>>>24&15;if((ar|0)==0|t^1){break}c[T>>2]=c[(c[2440392]|0)+(ar<<2)>>2];break}}}while(0);am=al+1|0;if((am|0)>(N|0)){aj=aq;ak=ap;break}else{O=aq;L=ap;J=ao;T=T+p|0;al=am}}}if((ai|0)>(i|0)){_=38838;break}else{G=aj;H=ak;I=ai}}if((_|0)==38837){return}else if((_|0)==38838){return}}function czU(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0;b=c[3540994]|0;f=c[3528548]|0;g=f<<8;h=c[2385554]|0;do{if((h|0)>31){i=511}else{j=(h<<4)-1|0;if((j|0)>=0){i=j;break}return}}while(0);j=(i|0)>255;k=i&255;l=c[2385550]|0;m=c[2113042]|0;n=c[2113044]|0;o=m+512|0;p=c[2385552]|0;q=c[2113132]|0;r=p<<2;s=c[2112968]|0;t=p+6|0;u=(t|0)>-1&(t|0)<(q|0);t=p+5|0;v=(t|0)>-1&(t|0)<(q|0);t=p+4|0;w=(t|0)>-1&(t|0)<(q|0);t=p+3|0;x=(t|0)>-1&(t|0)<(q|0);t=p+2|0;y=(t|0)>-1&(t|0)<(q|0);t=p+1|0;z=(t|0)>-1&(t|0)<(q|0);t=(p|0)>-1&(p|0)<(q|0);p=q<<2;A=c[2415160]|0;B=c[2429858]|0;C=c[2430428]|0;D=c[2429718]|0;E=c[2430092]|0;F=c[3541046]|0;G=c[2430426]|0;H=0;I=0;J=0;L45382:while(1){K=(h|0)>16&(f|0)!=255;L=(h|0)<33;M=511-f|0;N=f+1|0;O=f-255|0;P=~f;Q=J;L45384:while(1){R=Q+l|0;S=R&511;do{if((S|0)<(m|0)){T=Q+m-S|0}else{if((S|0)>=(n|0)){T=o+Q-S|0;break}U=(Q|0)>255;V=U?16:0;W=Q&255;X=(Q|0)<256&j?255:k;if(!K){Y=X;Z=W;_=V;$=38863;break L45384}if(L){if(!U){$=38853;break L45384}if((Q|0)<(M|0)){T=M;break}else{$=38855;break L45384}}if(U){aa=O+W|0;if((aa|0)>=0){$=38858;break L45384}U=N+aa|0;if((U|0)<0){T=512;break}else{Y=f;Z=U;_=0;$=38863;break L45384}}else{if((W|0)<=(f|0)){$=38861;break L45384}U=W+P|0;if((U|0)>(f|0)){T=256;break}else{Y=f;Z=U;_=16;$=38863;break L45384}}}}while(0);if((T|0)>(i|0)){$=38908;break L45382}else{Q=T}}if(($|0)==38858){$=0;ab=f;ac=V;ad=aa;ae=N+Q-aa|0}else if(($|0)==38855){$=0;P=255-f|0;Y=X-P|0;Z=W-P|0;_=V;$=38863}else if(($|0)==38861){$=0;ab=f;ac=V;ad=W;ae=N+Q-W|0}else if(($|0)==38853){$=0;af=V;ah=W;ai=X;aj=Q+1-W+X|0;$=38864}if(($|0)==38863){$=0;P=Q+1-Z+Y|0;if(L){af=_;ah=Z;ai=Y;aj=P;$=38864}else{ab=Y;ac=_;ad=Z;ae=P}}if(($|0)==38864){$=0;ab=(ai|0)>(f|0)?f:ai;ac=af;ad=ah;ae=aj}P=((R|-512)^511)+n|0;O=(ab-ad|0)>(P|0)?P+ad|0:ab;if((ad|0)>(O|0)){ak=H;al=I}else{P=H;M=I;K=-1;U=s+((ag(q,(S<<2)-64|0)|0)+r)|0;am=ad;while(1){an=d[b+(am+g)|0]|0;ao=(an>>>4)+ac|0;do{if((ao|0)==(K|0)){ap=K;aq=M;ar=P}else{as=ao<<1;at=e[A+((as|1)<<1)>>1]|0;au=(at<<12&983040|(e[A+(as<<1)>>1]|0))&B;do{if((at&8|0)==0){if((at&4|0)==0){av=au;break}av=C|au&1048572}else{av=G|au&1048568}}while(0);au=a[D+av|0]|0;as=au&255;if(au<<24>>24!=0){ap=ao;aq=as;ar=at;break}c[2385344]=E+(av<<7);c[2440392]=F+((at>>>4&4080)<<2);ap=ao;aq=as;ar=at}}while(0);do{if((aq|0)==0){ao=an<<1&30;as=(ar&2|0)==0?ao:ao^30;if((ar&1|0)==0){ao=c[2385344]|0;au=c[ao+(as<<2)>>2]|0;aw=au>>>8&15;if(!((aw|0)==0|t^1)){c[U>>2]=c[(c[2440392]|0)+(aw<<2)>>2]}aw=au>>>16&15;if(!((aw|0)==0|z^1)){c[U+4>>2]=c[(c[2440392]|0)+(aw<<2)>>2]}aw=au>>>24&15;if(!((aw|0)==0|y^1)){c[U+8>>2]=c[(c[2440392]|0)+(aw<<2)>>2]}aw=c[ao+((as|1)<<2)>>2]|0;ao=aw&15;if(!((ao|0)==0|x^1)){c[U+12>>2]=c[(c[2440392]|0)+(ao<<2)>>2]}ao=aw>>>8&15;if(!((ao|0)==0|w^1)){c[U+16>>2]=c[(c[2440392]|0)+(ao<<2)>>2]}ao=aw>>>16&15;if(!((ao|0)==0|v^1)){c[U+20>>2]=c[(c[2440392]|0)+(ao<<2)>>2]}ao=aw>>>24&15;if((ao|0)==0|u^1){break}c[U+24>>2]=c[(c[2440392]|0)+(ao<<2)>>2];break}else{ao=c[2385344]|0;aw=c[ao+(as<<2)>>2]|0;au=aw>>>8&15;if(!((au|0)==0|u^1)){c[U+24>>2]=c[(c[2440392]|0)+(au<<2)>>2]}au=aw>>>16&15;if(!((au|0)==0|v^1)){c[U+20>>2]=c[(c[2440392]|0)+(au<<2)>>2]}au=aw>>>24&15;if(!((au|0)==0|w^1)){c[U+16>>2]=c[(c[2440392]|0)+(au<<2)>>2]}au=c[ao+((as|1)<<2)>>2]|0;as=au&15;if(!((as|0)==0|x^1)){c[U+12>>2]=c[(c[2440392]|0)+(as<<2)>>2]}as=au>>>8&15;if(!((as|0)==0|y^1)){c[U+8>>2]=c[(c[2440392]|0)+(as<<2)>>2]}as=au>>>16&15;if(!((as|0)==0|z^1)){c[U+4>>2]=c[(c[2440392]|0)+(as<<2)>>2]}as=au>>>24&15;if((as|0)==0|t^1){break}c[U>>2]=c[(c[2440392]|0)+(as<<2)>>2];break}}}while(0);an=am+1|0;if((an|0)>(O|0)){ak=ar;al=aq;break}else{P=ar;M=aq;K=ap;U=U+p|0;am=an}}}if((ae|0)>(i|0)){$=38906;break}else{H=ak;I=al;J=ae}}if(($|0)==38906){return}else if(($|0)==38908){return}}function czV(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0;b=c[3540994]|0;f=c[3528548]|0;g=f<<8;h=c[2385554]|0;do{if((h|0)>31){i=511}else{j=(h<<4)-1|0;if((j|0)>=0){i=j;break}return}}while(0);j=(i|0)>255;k=i&255;l=c[2385550]|0;m=c[2113042]|0;n=c[2113044]|0;o=m+512|0;p=c[2385552]|0;q=c[2113132]|0;r=p<<2;s=c[2112968]|0;t=p+7|0;u=(t|0)>-1&(t|0)<(q|0);t=p+6|0;v=(t|0)>-1&(t|0)<(q|0);t=p+5|0;w=(t|0)>-1&(t|0)<(q|0);t=p+4|0;x=(t|0)>-1&(t|0)<(q|0);t=p+3|0;y=(t|0)>-1&(t|0)<(q|0);t=p+2|0;z=(t|0)>-1&(t|0)<(q|0);t=p+1|0;A=(t|0)>-1&(t|0)<(q|0);t=(p|0)>-1&(p|0)<(q|0);p=q<<2;B=c[2415160]|0;C=c[2429858]|0;D=c[2430428]|0;E=c[2429718]|0;F=c[2430092]|0;G=c[3541046]|0;H=c[2430426]|0;I=0;J=0;K=0;L45479:while(1){L=(h|0)>16&(f|0)!=255;M=(h|0)<33;N=511-f|0;O=f+1|0;P=f-255|0;Q=~f;R=K;L45481:while(1){S=R+l|0;T=S&511;do{if((T|0)<(m|0)){U=R+m-T|0}else{if((T|0)>=(n|0)){U=o+R-T|0;break}V=(R|0)>255;W=V?16:0;X=R&255;Y=(R|0)<256&j?255:k;if(!L){Z=Y;_=X;$=W;aa=38932;break L45481}if(M){if(!V){aa=38922;break L45481}if((R|0)<(N|0)){U=N;break}else{aa=38924;break L45481}}if(V){ab=P+X|0;if((ab|0)>=0){aa=38927;break L45481}V=O+ab|0;if((V|0)<0){U=512;break}else{Z=f;_=V;$=0;aa=38932;break L45481}}else{if((X|0)<=(f|0)){aa=38930;break L45481}V=X+Q|0;if((V|0)>(f|0)){U=256;break}else{Z=f;_=V;$=16;aa=38932;break L45481}}}}while(0);if((U|0)>(i|0)){aa=38979;break L45479}else{R=U}}if((aa|0)==38922){aa=0;ac=W;ad=X;ae=Y;af=R+1-X+Y|0;aa=38933}else if((aa|0)==38924){aa=0;Q=255-f|0;Z=Y-Q|0;_=X-Q|0;$=W;aa=38932}else if((aa|0)==38930){aa=0;ah=f;ai=W;aj=X;ak=O+R-X|0}else if((aa|0)==38927){aa=0;ah=f;ai=W;aj=ab;ak=O+R-ab|0}if((aa|0)==38932){aa=0;Q=R+1-_+Z|0;if(M){ac=$;ad=_;ae=Z;af=Q;aa=38933}else{ah=Z;ai=$;aj=_;ak=Q}}if((aa|0)==38933){aa=0;ah=(ae|0)>(f|0)?f:ae;ai=ac;aj=ad;ak=af}Q=((S|-512)^511)+n|0;P=(ah-aj|0)>(Q|0)?Q+aj|0:ah;if((aj|0)>(P|0)){al=I;am=J}else{Q=I;N=J;L=-1;V=s+((ag(q,(T<<2)-64|0)|0)+r)|0;an=aj;while(1){ao=d[b+(an+g)|0]|0;ap=(ao>>>4)+ai|0;do{if((ap|0)==(L|0)){aq=L;ar=N;as=Q}else{at=ap<<1;au=e[B+((at|1)<<1)>>1]|0;av=(au<<12&983040|(e[B+(at<<1)>>1]|0))&C;do{if((au&8|0)==0){if((au&4|0)==0){aw=av;break}aw=D|av&1048572}else{aw=H|av&1048568}}while(0);av=a[E+aw|0]|0;at=av&255;if(av<<24>>24!=0){aq=ap;ar=at;as=au;break}c[2385344]=F+(aw<<7);c[2440392]=G+((au>>>4&4080)<<2);aq=ap;ar=at;as=au}}while(0);do{if((ar|0)==0){ap=ao<<1&30;at=(as&2|0)==0?ap:ap^30;if((as&1|0)==0){ap=c[2385344]|0;av=c[ap+(at<<2)>>2]|0;ax=av&15;if(!((ax|0)==0|t^1)){c[V>>2]=c[(c[2440392]|0)+(ax<<2)>>2]}ax=av>>>8&15;if(!((ax|0)==0|A^1)){c[V+4>>2]=c[(c[2440392]|0)+(ax<<2)>>2]}ax=av>>>16&15;if(!((ax|0)==0|z^1)){c[V+8>>2]=c[(c[2440392]|0)+(ax<<2)>>2]}ax=av>>>24&15;if(!((ax|0)==0|y^1)){c[V+12>>2]=c[(c[2440392]|0)+(ax<<2)>>2]}ax=c[ap+((at|1)<<2)>>2]|0;ap=ax&15;if(!((ap|0)==0|x^1)){c[V+16>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ap=ax>>>8&15;if(!((ap|0)==0|w^1)){c[V+20>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ap=ax>>>16&15;if(!((ap|0)==0|v^1)){c[V+24>>2]=c[(c[2440392]|0)+(ap<<2)>>2]}ap=ax>>>24&15;if((ap|0)==0|u^1){break}c[V+28>>2]=c[(c[2440392]|0)+(ap<<2)>>2];break}else{ap=c[2385344]|0;ax=c[ap+(at<<2)>>2]|0;av=ax&15;if(!((av|0)==0|u^1)){c[V+28>>2]=c[(c[2440392]|0)+(av<<2)>>2]}av=ax>>>8&15;if(!((av|0)==0|v^1)){c[V+24>>2]=c[(c[2440392]|0)+(av<<2)>>2]}av=ax>>>16&15;if(!((av|0)==0|w^1)){c[V+20>>2]=c[(c[2440392]|0)+(av<<2)>>2]}av=ax>>>24&15;if(!((av|0)==0|x^1)){c[V+16>>2]=c[(c[2440392]|0)+(av<<2)>>2]}av=c[ap+((at|1)<<2)>>2]|0;at=av&15;if(!((at|0)==0|y^1)){c[V+12>>2]=c[(c[2440392]|0)+(at<<2)>>2]}at=av>>>8&15;if(!((at|0)==0|z^1)){c[V+8>>2]=c[(c[2440392]|0)+(at<<2)>>2]}at=av>>>16&15;if(!((at|0)==0|A^1)){c[V+4>>2]=c[(c[2440392]|0)+(at<<2)>>2]}at=av>>>24&15;if((at|0)==0|t^1){break}c[V>>2]=c[(c[2440392]|0)+(at<<2)>>2];break}}}while(0);ao=an+1|0;if((ao|0)>(P|0)){al=as;am=ar;break}else{Q=as;N=ar;L=aq;V=V+p|0;an=ao}}}if((ak|0)>(i|0)){aa=38980;break}else{I=al;J=am;K=ak}}if((aa|0)==38979){return}else if((aa|0)==38980){return}}function czW(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0;b=c[3540994]|0;f=c[3528548]|0;g=f<<8;h=c[2385554]|0;do{if((h|0)>31){i=511}else{j=(h<<4)-1|0;if((j|0)>=0){i=j;break}return}}while(0);j=(i|0)>255;k=i&255;l=c[2385550]|0;m=c[2113042]|0;n=c[2113044]|0;o=m+512|0;p=c[2385552]|0;q=c[2113132]|0;r=p<<2;s=c[2112968]|0;t=p+8|0;u=(t|0)>-1&(t|0)<(q|0);t=p+7|0;v=(t|0)>-1&(t|0)<(q|0);t=p+6|0;w=(t|0)>-1&(t|0)<(q|0);t=p+5|0;x=(t|0)>-1&(t|0)<(q|0);t=p+4|0;y=(t|0)>-1&(t|0)<(q|0);t=p+3|0;z=(t|0)>-1&(t|0)<(q|0);t=p+2|0;A=(t|0)>-1&(t|0)<(q|0);t=p+1|0;B=(t|0)>-1&(t|0)<(q|0);t=(p|0)>-1&(p|0)<(q|0);p=q<<2;C=c[2415160]|0;D=c[2429858]|0;E=c[2430428]|0;F=c[2429718]|0;G=c[2430092]|0;H=c[3541046]|0;I=c[2430426]|0;J=0;K=0;L=0;L45582:while(1){M=(h|0)>16&(f|0)!=255;N=(h|0)<33;O=511-f|0;P=f+1|0;Q=f-255|0;R=~f;S=L;L45584:while(1){T=S+l|0;U=T&511;do{if((U|0)<(m|0)){V=S+m-U|0}else{if((U|0)>=(n|0)){V=o+S-U|0;break}W=(S|0)>255;X=W?16:0;Y=S&255;Z=(S|0)<256&j?255:k;if(!M){_=Z;$=Y;aa=X;ab=39005;break L45584}if(N){if(!W){ab=38995;break L45584}if((S|0)<(O|0)){V=O;break}else{ab=38997;break L45584}}if(W){ac=Q+Y|0;if((ac|0)>=0){ab=39e3;break L45584}W=P+ac|0;if((W|0)<0){V=512;break}else{_=f;$=W;aa=0;ab=39005;break L45584}}else{if((Y|0)<=(f|0)){ab=39003;break L45584}W=Y+R|0;if((W|0)>(f|0)){V=256;break}else{_=f;$=W;aa=16;ab=39005;break L45584}}}}while(0);if((V|0)>(i|0)){ab=39058;break L45582}else{S=V}}if((ab|0)==39e3){ab=0;ad=f;ae=X;af=ac;ah=P+S-ac|0}else if((ab|0)==38997){ab=0;R=255-f|0;_=Z-R|0;$=Y-R|0;aa=X;ab=39005}else if((ab|0)==39003){ab=0;ad=f;ae=X;af=Y;ah=P+S-Y|0}else if((ab|0)==38995){ab=0;ai=X;aj=Y;ak=Z;al=S+1-Y+Z|0;ab=39006}if((ab|0)==39005){ab=0;R=S+1-$+_|0;if(N){ai=aa;aj=$;ak=_;al=R;ab=39006}else{ad=_;ae=aa;af=$;ah=R}}if((ab|0)==39006){ab=0;ad=(ak|0)>(f|0)?f:ak;ae=ai;af=aj;ah=al}R=((T|-512)^511)+n|0;Q=(ad-af|0)>(R|0)?R+af|0:ad;if((af|0)>(Q|0)){am=J;an=K}else{R=J;O=K;M=-1;W=s+((ag(q,(U<<2)-64|0)|0)+r)|0;ao=af;while(1){ap=d[b+(ao+g)|0]|0;aq=(ap>>>4)+ae|0;do{if((aq|0)==(M|0)){ar=M;as=O;at=R}else{au=aq<<1;av=e[C+((au|1)<<1)>>1]|0;aw=(av<<12&983040|(e[C+(au<<1)>>1]|0))&D;do{if((av&8|0)==0){if((av&4|0)==0){ax=aw;break}ax=E|aw&1048572}else{ax=I|aw&1048568}}while(0);aw=a[F+ax|0]|0;au=aw&255;if(aw<<24>>24!=0){ar=aq;as=au;at=av;break}c[2385344]=G+(ax<<7);c[2440392]=H+((av>>>4&4080)<<2);ar=aq;as=au;at=av}}while(0);do{if((as|0)==0){aq=ap<<1&30;au=(at&2|0)==0?aq:aq^30;if((at&1|0)==0){aq=c[2385344]|0;aw=c[aq+(au<<2)>>2]|0;ay=aw&15;if(!((ay|0)==0|t^1)){c[W>>2]=c[(c[2440392]|0)+(ay<<2)>>2]}ay=aw>>>8&15;if(!((ay|0)==0|B^1)){c[W+4>>2]=c[(c[2440392]|0)+(ay<<2)>>2]}ay=aw>>>16&15;if(!((ay|0)==0|A^1)){c[W+8>>2]=c[(c[2440392]|0)+(ay<<2)>>2]}ay=aw>>>24&15;if(!((ay|0)==0|z^1)){c[W+12>>2]=c[(c[2440392]|0)+(ay<<2)>>2]}ay=c[aq+((au|1)<<2)>>2]|0;aq=ay&15;if(!((aq|0)==0|y^1)){c[W+16>>2]=c[(c[2440392]|0)+(aq<<2)>>2]}aq=ay>>>4&15;if(!((aq|0)==0|x^1)){c[W+20>>2]=c[(c[2440392]|0)+(aq<<2)>>2]}aq=ay>>>8&15;if(!((aq|0)==0|w^1)){c[W+24>>2]=c[(c[2440392]|0)+(aq<<2)>>2]}aq=ay>>>16&15;if(!((aq|0)==0|v^1)){c[W+28>>2]=c[(c[2440392]|0)+(aq<<2)>>2]}aq=ay>>>24&15;if((aq|0)==0|u^1){break}c[W+32>>2]=c[(c[2440392]|0)+(aq<<2)>>2];break}else{aq=c[2385344]|0;ay=c[aq+(au<<2)>>2]|0;aw=ay&15;if(!((aw|0)==0|u^1)){c[W+32>>2]=c[(c[2440392]|0)+(aw<<2)>>2]}aw=ay>>>8&15;if(!((aw|0)==0|v^1)){c[W+28>>2]=c[(c[2440392]|0)+(aw<<2)>>2]}aw=ay>>>16&15;if(!((aw|0)==0|w^1)){c[W+24>>2]=c[(c[2440392]|0)+(aw<<2)>>2]}aw=ay>>>24&15;if(!((aw|0)==0|x^1)){c[W+20>>2]=c[(c[2440392]|0)+(aw<<2)>>2]}aw=c[aq+((au|1)<<2)>>2]|0;au=aw&15;if(!((au|0)==0|y^1)){c[W+16>>2]=c[(c[2440392]|0)+(au<<2)>>2]}au=aw>>>4&15;if(!((au|0)==0|z^1)){c[W+12>>2]=c[(c[2440392]|0)+(au<<2)>>2]}au=aw>>>8&15;if(!((au|0)==0|A^1)){c[W+8>>2]=c[(c[2440392]|0)+(au<<2)>>2]}au=aw>>>16&15;if(!((au|0)==0|B^1)){c[W+4>>2]=c[(c[2440392]|0)+(au<<2)>>2]}au=aw>>>24&15;if((au|0)==0|t^1){break}c[W>>2]=c[(c[2440392]|0)+(au<<2)>>2];break}}}while(0);ap=ao+1|0;if((ap|0)>(Q|0)){am=at;an=as;break}else{R=at;O=as;M=ar;W=W+p|0;ao=ap}}}if((ah|0)>(i|0)){ab=39056;break}else{J=am;K=an;L=ah}}if((ab|0)==39056){return}else if((ab|0)==39058){return}}function czX(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0;b=c[3540994]|0;f=c[3528548]|0;g=f<<8;h=c[2385554]|0;do{if((h|0)>31){i=511}else{j=(h<<4)-1|0;if((j|0)>=0){i=j;break}return}}while(0);j=(i|0)>255;k=i&255;l=c[2385550]|0;m=c[2113042]|0;n=c[2113044]|0;o=m+512|0;p=c[2385552]|0;q=c[2113132]|0;r=p<<2;s=c[2112968]|0;t=p+9|0;u=(t|0)>-1&(t|0)<(q|0);t=p+8|0;v=(t|0)>-1&(t|0)<(q|0);t=p+7|0;w=(t|0)>-1&(t|0)<(q|0);t=p+6|0;x=(t|0)>-1&(t|0)<(q|0);t=p+5|0;y=(t|0)>-1&(t|0)<(q|0);t=p+4|0;z=(t|0)>-1&(t|0)<(q|0);t=p+3|0;A=(t|0)>-1&(t|0)<(q|0);t=p+2|0;B=(t|0)>-1&(t|0)<(q|0);t=p+1|0;C=(t|0)>-1&(t|0)<(q|0);t=(p|0)>-1&(p|0)<(q|0);p=q<<2;D=c[2415160]|0;E=c[2429858]|0;F=c[2430428]|0;G=c[2429718]|0;H=c[2430092]|0;I=c[3541046]|0;J=c[2430426]|0;K=0;L=0;M=0;L45691:while(1){N=(h|0)>16&(f|0)!=255;O=(h|0)<33;P=511-f|0;Q=f+1|0;R=f-255|0;S=~f;T=M;L45693:while(1){U=T+l|0;V=U&511;do{if((V|0)<(m|0)){W=T+m-V|0}else{if((V|0)>=(n|0)){W=o+T-V|0;break}X=(T|0)>255;Y=X?16:0;Z=T&255;_=(T|0)<256&j?255:k;if(!N){$=_;aa=Z;ab=Y;ac=39082;break L45693}if(O){if(!X){ac=39072;break L45693}if((T|0)<(P|0)){W=P;break}else{ac=39074;break L45693}}if(X){ad=R+Z|0;if((ad|0)>=0){ac=39077;break L45693}X=Q+ad|0;if((X|0)<0){W=512;break}else{$=f;aa=X;ab=0;ac=39082;break L45693}}else{if((Z|0)<=(f|0)){ac=39080;break L45693}X=Z+S|0;if((X|0)>(f|0)){W=256;break}else{$=f;aa=X;ab=16;ac=39082;break L45693}}}}while(0);if((W|0)>(i|0)){ac=39137;break L45691}else{T=W}}if((ac|0)==39072){ac=0;ae=Y;af=Z;ah=_;ai=T+1-Z+_|0;ac=39083}else if((ac|0)==39074){ac=0;S=255-f|0;$=_-S|0;aa=Z-S|0;ab=Y;ac=39082}else if((ac|0)==39080){ac=0;aj=f;ak=Y;al=Z;am=Q+T-Z|0}else if((ac|0)==39077){ac=0;aj=f;ak=Y;al=ad;am=Q+T-ad|0}if((ac|0)==39082){ac=0;S=T+1-aa+$|0;if(O){ae=ab;af=aa;ah=$;ai=S;ac=39083}else{aj=$;ak=ab;al=aa;am=S}}if((ac|0)==39083){ac=0;aj=(ah|0)>(f|0)?f:ah;ak=ae;al=af;am=ai}S=((U|-512)^511)+n|0;R=(aj-al|0)>(S|0)?S+al|0:aj;if((al|0)>(R|0)){an=K;ao=L}else{S=K;P=L;N=-1;X=s+((ag(q,(V<<2)-64|0)|0)+r)|0;ap=al;while(1){aq=d[b+(ap+g)|0]|0;ar=(aq>>>4)+ak|0;do{if((ar|0)==(N|0)){as=N;at=P;au=S}else{av=ar<<1;aw=e[D+((av|1)<<1)>>1]|0;ax=(aw<<12&983040|(e[D+(av<<1)>>1]|0))&E;do{if((aw&8|0)==0){if((aw&4|0)==0){ay=ax;break}ay=F|ax&1048572}else{ay=J|ax&1048568}}while(0);ax=a[G+ay|0]|0;av=ax&255;if(ax<<24>>24!=0){as=ar;at=av;au=aw;break}c[2385344]=H+(ay<<7);c[2440392]=I+((aw>>>4&4080)<<2);as=ar;at=av;au=aw}}while(0);do{if((at|0)==0){ar=aq<<1&30;av=(au&2|0)==0?ar:ar^30;if((au&1|0)==0){ar=c[2385344]|0;ax=c[ar+(av<<2)>>2]|0;az=ax&15;if(!((az|0)==0|t^1)){c[X>>2]=c[(c[2440392]|0)+(az<<2)>>2]}az=ax>>>8&15;if(!((az|0)==0|C^1)){c[X+4>>2]=c[(c[2440392]|0)+(az<<2)>>2]}az=ax>>>12&15;if(!((az|0)==0|B^1)){c[X+8>>2]=c[(c[2440392]|0)+(az<<2)>>2]}az=ax>>>16&15;if(!((az|0)==0|A^1)){c[X+12>>2]=c[(c[2440392]|0)+(az<<2)>>2]}az=ax>>>24&15;if(!((az|0)==0|z^1)){c[X+16>>2]=c[(c[2440392]|0)+(az<<2)>>2]}az=c[ar+((av|1)<<2)>>2]|0;ar=az&15;if(!((ar|0)==0|y^1)){c[X+20>>2]=c[(c[2440392]|0)+(ar<<2)>>2]}ar=az>>>4&15;if(!((ar|0)==0|x^1)){c[X+24>>2]=c[(c[2440392]|0)+(ar<<2)>>2]}ar=az>>>8&15;if(!((ar|0)==0|w^1)){c[X+28>>2]=c[(c[2440392]|0)+(ar<<2)>>2]}ar=az>>>16&15;if(!((ar|0)==0|v^1)){c[X+32>>2]=c[(c[2440392]|0)+(ar<<2)>>2]}ar=az>>>24&15;if((ar|0)==0|u^1){break}c[X+36>>2]=c[(c[2440392]|0)+(ar<<2)>>2];break}else{ar=c[2385344]|0;az=c[ar+(av<<2)>>2]|0;ax=az&15;if(!((ax|0)==0|u^1)){c[X+36>>2]=c[(c[2440392]|0)+(ax<<2)>>2]}ax=az>>>8&15;if(!((ax|0)==0|v^1)){c[X+32>>2]=c[(c[2440392]|0)+(ax<<2)>>2]}ax=az>>>12&15;if(!((ax|0)==0|w^1)){c[X+28>>2]=c[(c[2440392]|0)+(ax<<2)>>2]}ax=az>>>16&15;if(!((ax|0)==0|x^1)){c[X+24>>2]=c[(c[2440392]|0)+(ax<<2)>>2]}ax=az>>>24&15;if(!((ax|0)==0|y^1)){c[X+20>>2]=c[(c[2440392]|0)+(ax<<2)>>2]}ax=c[ar+((av|1)<<2)>>2]|0;av=ax&15;if(!((av|0)==0|z^1)){c[X+16>>2]=c[(c[2440392]|0)+(av<<2)>>2]}av=ax>>>4&15;if(!((av|0)==0|A^1)){c[X+12>>2]=c[(c[2440392]|0)+(av<<2)>>2]}av=ax>>>8&15;if(!((av|0)==0|B^1)){c[X+8>>2]=c[(c[2440392]|0)+(av<<2)>>2]}av=ax>>>16&15;if(!((av|0)==0|C^1)){c[X+4>>2]=c[(c[2440392]|0)+(av<<2)>>2]}av=ax>>>24&15;if((av|0)==0|t^1){break}c[X>>2]=c[(c[2440392]|0)+(av<<2)>>2];break}}}while(0);aq=ap+1|0;if((aq|0)>(R|0)){an=au;ao=at;break}else{S=au;P=at;N=as;X=X+p|0;ap=aq}}}if((am|0)>(i|0)){ac=39138;break}else{K=an;L=ao;M=am}}if((ac|0)==39137){return}else if((ac|0)==39138){return}}function czY(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0;b=c[3540994]|0;f=c[3528548]|0;g=f<<8;h=c[2385554]|0;do{if((h|0)>31){i=511}else{j=(h<<4)-1|0;if((j|0)>=0){i=j;break}return}}while(0);j=(i|0)>255;k=i&255;l=c[2385550]|0;m=c[2113042]|0;n=c[2113044]|0;o=m+512|0;p=c[2385552]|0;q=c[2113132]|0;r=p<<2;s=c[2112968]|0;t=p+10|0;u=(t|0)>-1&(t|0)<(q|0);t=p+9|0;v=(t|0)>-1&(t|0)<(q|0);t=p+8|0;w=(t|0)>-1&(t|0)<(q|0);t=p+7|0;x=(t|0)>-1&(t|0)<(q|0);t=p+6|0;y=(t|0)>-1&(t|0)<(q|0);t=p+5|0;z=(t|0)>-1&(t|0)<(q|0);t=p+4|0;A=(t|0)>-1&(t|0)<(q|0);t=p+3|0;B=(t|0)>-1&(t|0)<(q|0);t=p+2|0;C=(t|0)>-1&(t|0)<(q|0);t=p+1|0;D=(t|0)>-1&(t|0)<(q|0);t=(p|0)>-1&(p|0)<(q|0);p=q<<2;E=c[2415160]|0;F=c[2429858]|0;G=c[2430428]|0;H=c[2429718]|0;I=c[2430092]|0;J=c[3541046]|0;K=c[2430426]|0;L=0;M=0;N=0;L45806:while(1){O=(h|0)>16&(f|0)!=255;P=(h|0)<33;Q=511-f|0;R=f+1|0;S=f-255|0;T=~f;U=N;L45808:while(1){V=U+l|0;W=V&511;do{if((W|0)<(m|0)){X=U+m-W|0}else{if((W|0)>=(n|0)){X=o+U-W|0;break}Y=(U|0)>255;Z=Y?16:0;_=U&255;$=(U|0)<256&j?255:k;if(!O){aa=$;ab=_;ac=Z;ad=39163;break L45808}if(P){if(!Y){ad=39153;break L45808}if((U|0)<(Q|0)){X=Q;break}else{ad=39155;break L45808}}if(Y){ae=S+_|0;if((ae|0)>=0){ad=39158;break L45808}Y=R+ae|0;if((Y|0)<0){X=512;break}else{aa=f;ab=Y;ac=0;ad=39163;break L45808}}else{if((_|0)<=(f|0)){ad=39161;break L45808}Y=_+T|0;if((Y|0)>(f|0)){X=256;break}else{aa=f;ab=Y;ac=16;ad=39163;break L45808}}}}while(0);if((X|0)>(i|0)){ad=39222;break L45806}else{U=X}}if((ad|0)==39158){ad=0;af=f;ah=Z;ai=ae;aj=R+U-ae|0}else if((ad|0)==39161){ad=0;af=f;ah=Z;ai=_;aj=R+U-_|0}else if((ad|0)==39155){ad=0;T=255-f|0;aa=$-T|0;ab=_-T|0;ac=Z;ad=39163}else if((ad|0)==39153){ad=0;ak=Z;al=_;am=$;an=U+1-_+$|0;ad=39164}if((ad|0)==39163){ad=0;T=U+1-ab+aa|0;if(P){ak=ac;al=ab;am=aa;an=T;ad=39164}else{af=aa;ah=ac;ai=ab;aj=T}}if((ad|0)==39164){ad=0;af=(am|0)>(f|0)?f:am;ah=ak;ai=al;aj=an}T=((V|-512)^511)+n|0;S=(af-ai|0)>(T|0)?T+ai|0:af;if((ai|0)>(S|0)){ao=L;ap=M}else{T=L;Q=M;O=-1;Y=s+((ag(q,(W<<2)-64|0)|0)+r)|0;aq=ai;while(1){ar=d[b+(aq+g)|0]|0;as=(ar>>>4)+ah|0;do{if((as|0)==(O|0)){at=O;au=Q;av=T}else{aw=as<<1;ax=e[E+((aw|1)<<1)>>1]|0;ay=(ax<<12&983040|(e[E+(aw<<1)>>1]|0))&F;do{if((ax&8|0)==0){if((ax&4|0)==0){az=ay;break}az=G|ay&1048572}else{az=K|ay&1048568}}while(0);ay=a[H+az|0]|0;aw=ay&255;if(ay<<24>>24!=0){at=as;au=aw;av=ax;break}c[2385344]=I+(az<<7);c[2440392]=J+((ax>>>4&4080)<<2);at=as;au=aw;av=ax}}while(0);do{if((au|0)==0){as=ar<<1&30;aw=(av&2|0)==0?as:as^30;if((av&1|0)==0){as=c[2385344]|0;ay=c[as+(aw<<2)>>2]|0;aA=ay&15;if(!((aA|0)==0|t^1)){c[Y>>2]=c[(c[2440392]|0)+(aA<<2)>>2]}aA=ay>>>8&15;if(!((aA|0)==0|D^1)){c[Y+4>>2]=c[(c[2440392]|0)+(aA<<2)>>2]}aA=ay>>>12&15;if(!((aA|0)==0|C^1)){c[Y+8>>2]=c[(c[2440392]|0)+(aA<<2)>>2]}aA=ay>>>16&15;if(!((aA|0)==0|B^1)){c[Y+12>>2]=c[(c[2440392]|0)+(aA<<2)>>2]}aA=ay>>>24&15;if(!((aA|0)==0|A^1)){c[Y+16>>2]=c[(c[2440392]|0)+(aA<<2)>>2]}aA=c[as+((aw|1)<<2)>>2]|0;as=aA&15;if(!((as|0)==0|z^1)){c[Y+20>>2]=c[(c[2440392]|0)+(as<<2)>>2]}as=aA>>>4&15;if(!((as|0)==0|y^1)){c[Y+24>>2]=c[(c[2440392]|0)+(as<<2)>>2]}as=aA>>>8&15;if(!((as|0)==0|x^1)){c[Y+28>>2]=c[(c[2440392]|0)+(as<<2)>>2]}as=aA>>>16&15;if(!((as|0)==0|w^1)){c[Y+32>>2]=c[(c[2440392]|0)+(as<<2)>>2]}as=aA>>>24&15;if(!((as|0)==0|v^1)){c[Y+36>>2]=c[(c[2440392]|0)+(as<<2)>>2]}as=aA>>>28;if((as|0)==0|u^1){break}c[Y+40>>2]=c[(c[2440392]|0)+(as<<2)>>2];break}else{as=c[2385344]|0;aA=c[as+(aw<<2)>>2]|0;ay=aA&15;if(!((ay|0)==0|u^1)){c[Y+40>>2]=c[(c[2440392]|0)+(ay<<2)>>2]}ay=aA>>>8&15;if(!((ay|0)==0|v^1)){c[Y+36>>2]=c[(c[2440392]|0)+(ay<<2)>>2]}ay=aA>>>12&15;if(!((ay|0)==0|w^1)){c[Y+32>>2]=c[(c[2440392]|0)+(ay<<2)>>2]}ay=aA>>>16&15;if(!((ay|0)==0|x^1)){c[Y+28>>2]=c[(c[2440392]|0)+(ay<<2)>>2]}ay=aA>>>24&15;if(!((ay|0)==0|y^1)){c[Y+24>>2]=c[(c[2440392]|0)+(ay<<2)>>2]}ay=c[as+((aw|1)<<2)>>2]|0;aw=ay&15;if(!((aw|0)==0|z^1)){c[Y+20>>2]=c[(c[2440392]|0)+(aw<<2)>>2]}aw=ay>>>4&15;if(!((aw|0)==0|A^1)){c[Y+16>>2]=c[(c[2440392]|0)+(aw<<2)>>2]}aw=ay>>>8&15;if(!((aw|0)==0|B^1)){c[Y+12>>2]=c[(c[2440392]|0)+(aw<<2)>>2]}aw=ay>>>16&15;if(!((aw|0)==0|C^1)){c[Y+8>>2]=c[(c[2440392]|0)+(aw<<2)>>2]}aw=ay>>>24&15;if(!((aw|0)==0|D^1)){c[Y+4>>2]=c[(c[2440392]|0)+(aw<<2)>>2]}aw=ay>>>28;if((aw|0)==0|t^1){break}c[Y>>2]=c[(c[2440392]|0)+(aw<<2)>>2];break}}}while(0);ar=aq+1|0;if((ar|0)>(S|0)){ao=av;ap=au;break}else{T=av;Q=au;O=at;Y=Y+p|0;aq=ar}}}if((aj|0)>(i|0)){ad=39223;break}else{L=ao;M=ap;N=aj}}if((ad|0)==39222){return}else if((ad|0)==39223){return}}function czZ(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0;b=c[3540994]|0;f=c[3528548]|0;g=f<<8;h=c[2385554]|0;do{if((h|0)>31){i=511}else{j=(h<<4)-1|0;if((j|0)>=0){i=j;break}return}}while(0);j=(i|0)>255;k=i&255;l=c[2385550]|0;m=c[2113042]|0;n=c[2113044]|0;o=m+512|0;p=c[2385552]|0;q=c[2113132]|0;r=p<<2;s=c[2112968]|0;t=p+11|0;u=(t|0)>-1&(t|0)<(q|0);t=p+10|0;v=(t|0)>-1&(t|0)<(q|0);t=p+9|0;w=(t|0)>-1&(t|0)<(q|0);t=p+8|0;x=(t|0)>-1&(t|0)<(q|0);t=p+7|0;y=(t|0)>-1&(t|0)<(q|0);t=p+6|0;z=(t|0)>-1&(t|0)<(q|0);t=p+5|0;A=(t|0)>-1&(t|0)<(q|0);t=p+4|0;B=(t|0)>-1&(t|0)<(q|0);t=p+3|0;C=(t|0)>-1&(t|0)<(q|0);t=p+2|0;D=(t|0)>-1&(t|0)<(q|0);t=p+1|0;E=(t|0)>-1&(t|0)<(q|0);t=(p|0)>-1&(p|0)<(q|0);p=q<<2;F=c[2415160]|0;G=c[2429858]|0;H=c[2430428]|0;I=c[2429718]|0;J=c[2430092]|0;K=c[3541046]|0;L=c[2430426]|0;M=0;N=0;O=0;L45927:while(1){P=(h|0)>16&(f|0)!=255;Q=(h|0)<33;R=511-f|0;S=f+1|0;T=f-255|0;U=~f;V=O;L45929:while(1){W=V+l|0;X=W&511;do{if((X|0)<(m|0)){Y=V+m-X|0}else{if((X|0)>=(n|0)){Y=o+V-X|0;break}Z=(V|0)>255;_=Z?16:0;$=V&255;aa=(V|0)<256&j?255:k;if(!P){ab=aa;ac=$;ad=_;ae=39248;break L45929}if(Q){if(!Z){ae=39238;break L45929}if((V|0)<(R|0)){Y=R;break}else{ae=39240;break L45929}}if(Z){af=T+$|0;if((af|0)>=0){ae=39243;break L45929}Z=S+af|0;if((Z|0)<0){Y=512;break}else{ab=f;ac=Z;ad=0;ae=39248;break L45929}}else{if(($|0)<=(f|0)){ae=39246;break L45929}Z=$+U|0;if((Z|0)>(f|0)){Y=256;break}else{ab=f;ac=Z;ad=16;ae=39248;break L45929}}}}while(0);if((Y|0)>(i|0)){ae=39313;break L45927}else{V=Y}}if((ae|0)==39240){ae=0;U=255-f|0;ab=aa-U|0;ac=$-U|0;ad=_;ae=39248}else if((ae|0)==39238){ae=0;ah=_;ai=$;aj=aa;ak=V+1-$+aa|0;ae=39249}else if((ae|0)==39246){ae=0;al=f;am=_;an=$;ao=S+V-$|0}else if((ae|0)==39243){ae=0;al=f;am=_;an=af;ao=S+V-af|0}if((ae|0)==39248){ae=0;U=V+1-ac+ab|0;if(Q){ah=ad;ai=ac;aj=ab;ak=U;ae=39249}else{al=ab;am=ad;an=ac;ao=U}}if((ae|0)==39249){ae=0;al=(aj|0)>(f|0)?f:aj;am=ah;an=ai;ao=ak}U=((W|-512)^511)+n|0;T=(al-an|0)>(U|0)?U+an|0:al;if((an|0)>(T|0)){ap=M;aq=N}else{U=M;R=N;P=-1;Z=s+((ag(q,(X<<2)-64|0)|0)+r)|0;ar=an;while(1){as=d[b+(ar+g)|0]|0;at=(as>>>4)+am|0;do{if((at|0)==(P|0)){au=P;av=R;aw=U}else{ax=at<<1;ay=e[F+((ax|1)<<1)>>1]|0;az=(ay<<12&983040|(e[F+(ax<<1)>>1]|0))&G;do{if((ay&8|0)==0){if((ay&4|0)==0){aA=az;break}aA=H|az&1048572}else{aA=L|az&1048568}}while(0);az=a[I+aA|0]|0;ax=az&255;if(az<<24>>24!=0){au=at;av=ax;aw=ay;break}c[2385344]=J+(aA<<7);c[2440392]=K+((ay>>>4&4080)<<2);au=at;av=ax;aw=ay}}while(0);do{if((av|0)==0){at=as<<1&30;ax=(aw&2|0)==0?at:at^30;if((aw&1|0)==0){at=c[2385344]|0;az=c[at+(ax<<2)>>2]|0;aB=az&15;if(!((aB|0)==0|t^1)){c[Z>>2]=c[(c[2440392]|0)+(aB<<2)>>2]}aB=az>>>8&15;if(!((aB|0)==0|E^1)){c[Z+4>>2]=c[(c[2440392]|0)+(aB<<2)>>2]}aB=az>>>12&15;if(!((aB|0)==0|D^1)){c[Z+8>>2]=c[(c[2440392]|0)+(aB<<2)>>2]}aB=az>>>16&15;if(!((aB|0)==0|C^1)){c[Z+12>>2]=c[(c[2440392]|0)+(aB<<2)>>2]}aB=az>>>24&15;if(!((aB|0)==0|B^1)){c[Z+16>>2]=c[(c[2440392]|0)+(aB<<2)>>2]}aB=az>>>28;if(!((aB|0)==0|A^1)){c[Z+20>>2]=c[(c[2440392]|0)+(aB<<2)>>2]}aB=c[at+((ax|1)<<2)>>2]|0;at=aB&15;if(!((at|0)==0|z^1)){c[Z+24>>2]=c[(c[2440392]|0)+(at<<2)>>2]}at=aB>>>4&15;if(!((at|0)==0|y^1)){c[Z+28>>2]=c[(c[2440392]|0)+(at<<2)>>2]}at=aB>>>8&15;if(!((at|0)==0|x^1)){c[Z+32>>2]=c[(c[2440392]|0)+(at<<2)>>2]}at=aB>>>16&15;if(!((at|0)==0|w^1)){c[Z+36>>2]=c[(c[2440392]|0)+(at<<2)>>2]}at=aB>>>24&15;if(!((at|0)==0|v^1)){c[Z+40>>2]=c[(c[2440392]|0)+(at<<2)>>2]}at=aB>>>28;if((at|0)==0|u^1){break}c[Z+44>>2]=c[(c[2440392]|0)+(at<<2)>>2];break}else{at=c[2385344]|0;aB=c[at+(ax<<2)>>2]|0;az=aB&15;if(!((az|0)==0|u^1)){c[Z+44>>2]=c[(c[2440392]|0)+(az<<2)>>2]}az=aB>>>8&15;if(!((az|0)==0|v^1)){c[Z+40>>2]=c[(c[2440392]|0)+(az<<2)>>2]}az=aB>>>12&15;if(!((az|0)==0|w^1)){c[Z+36>>2]=c[(c[2440392]|0)+(az<<2)>>2]}az=aB>>>16&15;if(!((az|0)==0|x^1)){c[Z+32>>2]=c[(c[2440392]|0)+(az<<2)>>2]}az=aB>>>24&15;if(!((az|0)==0|y^1)){c[Z+28>>2]=c[(c[2440392]|0)+(az<<2)>>2]}az=aB>>>28;if(!((az|0)==0|z^1)){c[Z+24>>2]=c[(c[2440392]|0)+(az<<2)>>2]}az=c[at+((ax|1)<<2)>>2]|0;ax=az&15;if(!((ax|0)==0|A^1)){c[Z+20>>2]=c[(c[2440392]|0)+(ax<<2)>>2]}ax=az>>>4&15;if(!((ax|0)==0|B^1)){c[Z+16>>2]=c[(c[2440392]|0)+(ax<<2)>>2]}ax=az>>>8&15;if(!((ax|0)==0|C^1)){c[Z+12>>2]=c[(c[2440392]|0)+(ax<<2)>>2]}ax=az>>>16&15;if(!((ax|0)==0|D^1)){c[Z+8>>2]=c[(c[2440392]|0)+(ax<<2)>>2]}ax=az>>>24&15;if(!((ax|0)==0|E^1)){c[Z+4>>2]=c[(c[2440392]|0)+(ax<<2)>>2]}ax=az>>>28;if((ax|0)==0|t^1){break}c[Z>>2]=c[(c[2440392]|0)+(ax<<2)>>2];break}}}while(0);as=ar+1|0;if((as|0)>(T|0)){ap=aw;aq=av;break}else{U=aw;R=av;P=au;Z=Z+p|0;ar=as}}}if((ao|0)>(i|0)){ae=39312;break}else{M=ap;N=aq;O=ao}}if((ae|0)==39312){return}else if((ae|0)==39313){return}}function cz_(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0;b=c[3540994]|0;f=c[3528548]|0;g=f<<8;h=c[2385554]|0;do{if((h|0)>31){i=511}else{j=(h<<4)-1|0;if((j|0)>=0){i=j;break}return}}while(0);j=(i|0)>255;k=i&255;l=c[2385550]|0;m=c[2113042]|0;n=c[2113044]|0;o=m+512|0;p=c[2385552]|0;q=c[2113132]|0;r=p<<2;s=c[2112968]|0;t=p+12|0;u=(t|0)>-1&(t|0)<(q|0);t=p+11|0;v=(t|0)>-1&(t|0)<(q|0);t=p+10|0;w=(t|0)>-1&(t|0)<(q|0);t=p+9|0;x=(t|0)>-1&(t|0)<(q|0);t=p+8|0;y=(t|0)>-1&(t|0)<(q|0);t=p+7|0;z=(t|0)>-1&(t|0)<(q|0);t=p+6|0;A=(t|0)>-1&(t|0)<(q|0);t=p+5|0;B=(t|0)>-1&(t|0)<(q|0);t=p+4|0;C=(t|0)>-1&(t|0)<(q|0);t=p+3|0;D=(t|0)>-1&(t|0)<(q|0);t=p+2|0;E=(t|0)>-1&(t|0)<(q|0);t=p+1|0;F=(t|0)>-1&(t|0)<(q|0);t=(p|0)>-1&(p|0)<(q|0);p=q<<2;G=c[2415160]|0;H=c[2429858]|0;I=c[2430428]|0;J=c[2429718]|0;K=c[2430092]|0;L=c[3541046]|0;M=c[2430426]|0;N=0;O=0;P=0;L46054:while(1){Q=(h|0)>16&(f|0)!=255;R=(h|0)<33;S=511-f|0;T=f+1|0;U=f-255|0;V=~f;W=P;L46056:while(1){X=W+l|0;Y=X&511;do{if((Y|0)<(m|0)){Z=W+m-Y|0}else{if((Y|0)>=(n|0)){Z=o+W-Y|0;break}_=(W|0)>255;$=_?16:0;aa=W&255;ab=(W|0)<256&j?255:k;if(!Q){ac=ab;ad=aa;ae=$;af=39337;break L46056}if(R){if(!_){af=39327;break L46056}if((W|0)<(S|0)){Z=S;break}else{af=39329;break L46056}}if(_){ah=U+aa|0;if((ah|0)>=0){af=39332;break L46056}_=T+ah|0;if((_|0)<0){Z=512;break}else{ac=f;ad=_;ae=0;af=39337;break L46056}}else{if((aa|0)<=(f|0)){af=39335;break L46056}_=aa+V|0;if((_|0)>(f|0)){Z=256;break}else{ac=f;ad=_;ae=16;af=39337;break L46056}}}}while(0);if((Z|0)>(i|0)){af=39404;break L46054}else{W=Z}}if((af|0)==39335){af=0;ai=f;aj=$;ak=aa;al=T+W-aa|0}else if((af|0)==39332){af=0;ai=f;aj=$;ak=ah;al=T+W-ah|0}else if((af|0)==39327){af=0;am=$;an=aa;ao=ab;ap=W+1-aa+ab|0;af=39338}else if((af|0)==39329){af=0;V=255-f|0;ac=ab-V|0;ad=aa-V|0;ae=$;af=39337}if((af|0)==39337){af=0;V=W+1-ad+ac|0;if(R){am=ae;an=ad;ao=ac;ap=V;af=39338}else{ai=ac;aj=ae;ak=ad;al=V}}if((af|0)==39338){af=0;ai=(ao|0)>(f|0)?f:ao;aj=am;ak=an;al=ap}V=((X|-512)^511)+n|0;U=(ai-ak|0)>(V|0)?V+ak|0:ai;if((ak|0)>(U|0)){aq=N;ar=O}else{V=N;S=O;Q=-1;_=s+((ag(q,(Y<<2)-64|0)|0)+r)|0;as=ak;while(1){at=d[b+(as+g)|0]|0;au=(at>>>4)+aj|0;do{if((au|0)==(Q|0)){av=Q;aw=S;ax=V}else{ay=au<<1;az=e[G+((ay|1)<<1)>>1]|0;aA=(az<<12&983040|(e[G+(ay<<1)>>1]|0))&H;do{if((az&8|0)==0){if((az&4|0)==0){aB=aA;break}aB=I|aA&1048572}else{aB=M|aA&1048568}}while(0);aA=a[J+aB|0]|0;ay=aA&255;if(aA<<24>>24!=0){av=au;aw=ay;ax=az;break}c[2385344]=K+(aB<<7);c[2440392]=L+((az>>>4&4080)<<2);av=au;aw=ay;ax=az}}while(0);do{if((aw|0)==0){au=at<<1&30;ay=(ax&2|0)==0?au:au^30;if((ax&1|0)==0){au=c[2385344]|0;aA=c[au+(ay<<2)>>2]|0;aC=aA&15;if(!((aC|0)==0|t^1)){c[_>>2]=c[(c[2440392]|0)+(aC<<2)>>2]}aC=aA>>>8&15;if(!((aC|0)==0|F^1)){c[_+4>>2]=c[(c[2440392]|0)+(aC<<2)>>2]}aC=aA>>>12&15;if(!((aC|0)==0|E^1)){c[_+8>>2]=c[(c[2440392]|0)+(aC<<2)>>2]}aC=aA>>>16&15;if(!((aC|0)==0|D^1)){c[_+12>>2]=c[(c[2440392]|0)+(aC<<2)>>2]}aC=aA>>>24&15;if(!((aC|0)==0|C^1)){c[_+16>>2]=c[(c[2440392]|0)+(aC<<2)>>2]}aC=aA>>>28;if(!((aC|0)==0|B^1)){c[_+20>>2]=c[(c[2440392]|0)+(aC<<2)>>2]}aC=c[au+((ay|1)<<2)>>2]|0;au=aC&15;if(!((au|0)==0|A^1)){c[_+24>>2]=c[(c[2440392]|0)+(au<<2)>>2]}au=aC>>>4&15;if(!((au|0)==0|z^1)){c[_+28>>2]=c[(c[2440392]|0)+(au<<2)>>2]}au=aC>>>8&15;if(!((au|0)==0|y^1)){c[_+32>>2]=c[(c[2440392]|0)+(au<<2)>>2]}au=aC>>>16&15;if(!((au|0)==0|x^1)){c[_+36>>2]=c[(c[2440392]|0)+(au<<2)>>2]}au=aC>>>20&15;if(!((au|0)==0|w^1)){c[_+40>>2]=c[(c[2440392]|0)+(au<<2)>>2]}au=aC>>>24&15;if(!((au|0)==0|v^1)){c[_+44>>2]=c[(c[2440392]|0)+(au<<2)>>2]}au=aC>>>28;if((au|0)==0|u^1){break}c[_+48>>2]=c[(c[2440392]|0)+(au<<2)>>2];break}else{au=c[2385344]|0;aC=c[au+(ay<<2)>>2]|0;aA=aC&15;if(!((aA|0)==0|u^1)){c[_+48>>2]=c[(c[2440392]|0)+(aA<<2)>>2]}aA=aC>>>8&15;if(!((aA|0)==0|v^1)){c[_+44>>2]=c[(c[2440392]|0)+(aA<<2)>>2]}aA=aC>>>12&15;if(!((aA|0)==0|w^1)){c[_+40>>2]=c[(c[2440392]|0)+(aA<<2)>>2]}aA=aC>>>16&15;if(!((aA|0)==0|x^1)){c[_+36>>2]=c[(c[2440392]|0)+(aA<<2)>>2]}aA=aC>>>24&15;if(!((aA|0)==0|y^1)){c[_+32>>2]=c[(c[2440392]|0)+(aA<<2)>>2]}aA=aC>>>28;if(!((aA|0)==0|z^1)){c[_+28>>2]=c[(c[2440392]|0)+(aA<<2)>>2]}aA=c[au+((ay|1)<<2)>>2]|0;ay=aA&15;if(!((ay|0)==0|A^1)){c[_+24>>2]=c[(c[2440392]|0)+(ay<<2)>>2]}ay=aA>>>4&15;if(!((ay|0)==0|B^1)){c[_+20>>2]=c[(c[2440392]|0)+(ay<<2)>>2]}ay=aA>>>8&15;if(!((ay|0)==0|C^1)){c[_+16>>2]=c[(c[2440392]|0)+(ay<<2)>>2]}ay=aA>>>16&15;if(!((ay|0)==0|D^1)){c[_+12>>2]=c[(c[2440392]|0)+(ay<<2)>>2]}ay=aA>>>20&15;if(!((ay|0)==0|E^1)){c[_+8>>2]=c[(c[2440392]|0)+(ay<<2)>>2]}ay=aA>>>24&15;if(!((ay|0)==0|F^1)){c[_+4>>2]=c[(c[2440392]|0)+(ay<<2)>>2]}ay=aA>>>28;if((ay|0)==0|t^1){break}c[_>>2]=c[(c[2440392]|0)+(ay<<2)>>2];break}}}while(0);at=as+1|0;if((at|0)>(U|0)){aq=ax;ar=aw;break}else{V=ax;S=aw;Q=av;_=_+p|0;as=at}}}if((al|0)>(i|0)){af=39405;break}else{N=aq;O=ar;P=al}}if((af|0)==39404){return}else if((af|0)==39405){return}}function cz$(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0;b=c[3540994]|0;f=c[3528548]|0;g=f<<8;h=c[2385554]|0;do{if((h|0)>31){i=511}else{j=(h<<4)-1|0;if((j|0)>=0){i=j;break}return}}while(0);j=(i|0)>255;k=i&255;l=c[2385550]|0;m=c[2113042]|0;n=c[2113044]|0;o=m+512|0;p=c[2385552]|0;q=c[2113132]|0;r=p<<2;s=c[2112968]|0;t=p+13|0;u=(t|0)>-1&(t|0)<(q|0);t=p+12|0;v=(t|0)>-1&(t|0)<(q|0);t=p+11|0;w=(t|0)>-1&(t|0)<(q|0);t=p+10|0;x=(t|0)>-1&(t|0)<(q|0);t=p+9|0;y=(t|0)>-1&(t|0)<(q|0);t=p+8|0;z=(t|0)>-1&(t|0)<(q|0);t=p+7|0;A=(t|0)>-1&(t|0)<(q|0);t=p+6|0;B=(t|0)>-1&(t|0)<(q|0);t=p+5|0;C=(t|0)>-1&(t|0)<(q|0);t=p+4|0;D=(t|0)>-1&(t|0)<(q|0);t=p+3|0;E=(t|0)>-1&(t|0)<(q|0);t=p+2|0;F=(t|0)>-1&(t|0)<(q|0);t=p+1|0;G=(t|0)>-1&(t|0)<(q|0);t=(p|0)>-1&(p|0)<(q|0);p=q<<2;H=c[2415160]|0;I=c[2429858]|0;J=c[2430428]|0;K=c[2429718]|0;L=c[2430092]|0;M=c[3541046]|0;N=c[2430426]|0;O=0;P=0;Q=0;L46187:while(1){R=(h|0)>16&(f|0)!=255;S=(h|0)<33;T=511-f|0;U=f+1|0;V=f-255|0;W=~f;X=Q;L46189:while(1){Y=X+l|0;Z=Y&511;do{if((Z|0)<(m|0)){_=X+m-Z|0}else{if((Z|0)>=(n|0)){_=o+X-Z|0;break}$=(X|0)>255;aa=$?16:0;ab=X&255;ac=(X|0)<256&j?255:k;if(!R){ad=ac;ae=ab;af=aa;ah=39430;break L46189}if(S){if(!$){ah=39420;break L46189}if((X|0)<(T|0)){_=T;break}else{ah=39422;break L46189}}if($){ai=V+ab|0;if((ai|0)>=0){ah=39425;break L46189}$=U+ai|0;if(($|0)<0){_=512;break}else{ad=f;ae=$;af=0;ah=39430;break L46189}}else{if((ab|0)<=(f|0)){ah=39428;break L46189}$=ab+W|0;if(($|0)>(f|0)){_=256;break}else{ad=f;ae=$;af=16;ah=39430;break L46189}}}}while(0);if((_|0)>(i|0)){ah=39503;break L46187}else{X=_}}if((ah|0)==39420){ah=0;aj=aa;ak=ab;al=ac;am=X+1-ab+ac|0;ah=39431}else if((ah|0)==39422){ah=0;W=255-f|0;ad=ac-W|0;ae=ab-W|0;af=aa;ah=39430}else if((ah|0)==39425){ah=0;an=f;ao=aa;ap=ai;aq=U+X-ai|0}else if((ah|0)==39428){ah=0;an=f;ao=aa;ap=ab;aq=U+X-ab|0}if((ah|0)==39430){ah=0;W=X+1-ae+ad|0;if(S){aj=af;ak=ae;al=ad;am=W;ah=39431}else{an=ad;ao=af;ap=ae;aq=W}}if((ah|0)==39431){ah=0;an=(al|0)>(f|0)?f:al;ao=aj;ap=ak;aq=am}W=((Y|-512)^511)+n|0;V=(an-ap|0)>(W|0)?W+ap|0:an;if((ap|0)>(V|0)){ar=O;as=P}else{W=O;T=P;R=-1;$=s+((ag(q,(Z<<2)-64|0)|0)+r)|0;at=ap;while(1){au=d[b+(at+g)|0]|0;av=(au>>>4)+ao|0;do{if((av|0)==(R|0)){aw=R;ax=T;ay=W}else{az=av<<1;aA=e[H+((az|1)<<1)>>1]|0;aB=(aA<<12&983040|(e[H+(az<<1)>>1]|0))&I;do{if((aA&8|0)==0){if((aA&4|0)==0){aC=aB;break}aC=J|aB&1048572}else{aC=N|aB&1048568}}while(0);aB=a[K+aC|0]|0;az=aB&255;if(aB<<24>>24!=0){aw=av;ax=az;ay=aA;break}c[2385344]=L+(aC<<7);c[2440392]=M+((aA>>>4&4080)<<2);aw=av;ax=az;ay=aA}}while(0);do{if((ax|0)==0){av=au<<1&30;az=(ay&2|0)==0?av:av^30;if((ay&1|0)==0){av=c[2385344]|0;aB=c[av+(az<<2)>>2]|0;aD=aB&15;if(!((aD|0)==0|t^1)){c[$>>2]=c[(c[2440392]|0)+(aD<<2)>>2]}aD=aB>>>4&15;if(!((aD|0)==0|G^1)){c[$+4>>2]=c[(c[2440392]|0)+(aD<<2)>>2]}aD=aB>>>8&15;if(!((aD|0)==0|F^1)){c[$+8>>2]=c[(c[2440392]|0)+(aD<<2)>>2]}aD=aB>>>12&15;if(!((aD|0)==0|E^1)){c[$+12>>2]=c[(c[2440392]|0)+(aD<<2)>>2]}aD=aB>>>16&15;if(!((aD|0)==0|D^1)){c[$+16>>2]=c[(c[2440392]|0)+(aD<<2)>>2]}aD=aB>>>24&15;if(!((aD|0)==0|C^1)){c[$+20>>2]=c[(c[2440392]|0)+(aD<<2)>>2]}aD=aB>>>28;if(!((aD|0)==0|B^1)){c[$+24>>2]=c[(c[2440392]|0)+(aD<<2)>>2]}aD=c[av+((az|1)<<2)>>2]|0;av=aD&15;if(!((av|0)==0|A^1)){c[$+28>>2]=c[(c[2440392]|0)+(av<<2)>>2]}av=aD>>>4&15;if(!((av|0)==0|z^1)){c[$+32>>2]=c[(c[2440392]|0)+(av<<2)>>2]}av=aD>>>8&15;if(!((av|0)==0|y^1)){c[$+36>>2]=c[(c[2440392]|0)+(av<<2)>>2]}av=aD>>>16&15;if(!((av|0)==0|x^1)){c[$+40>>2]=c[(c[2440392]|0)+(av<<2)>>2]}av=aD>>>20&15;if(!((av|0)==0|w^1)){c[$+44>>2]=c[(c[2440392]|0)+(av<<2)>>2]}av=aD>>>24&15;if(!((av|0)==0|v^1)){c[$+48>>2]=c[(c[2440392]|0)+(av<<2)>>2]}av=aD>>>28;if((av|0)==0|u^1){break}c[$+52>>2]=c[(c[2440392]|0)+(av<<2)>>2];break}else{av=c[2385344]|0;aD=c[av+(az<<2)>>2]|0;aB=aD&15;if(!((aB|0)==0|u^1)){c[$+52>>2]=c[(c[2440392]|0)+(aB<<2)>>2]}aB=aD>>>4&15;if(!((aB|0)==0|v^1)){c[$+48>>2]=c[(c[2440392]|0)+(aB<<2)>>2]}aB=aD>>>8&15;if(!((aB|0)==0|w^1)){c[$+44>>2]=c[(c[2440392]|0)+(aB<<2)>>2]}aB=aD>>>12&15;if(!((aB|0)==0|x^1)){c[$+40>>2]=c[(c[2440392]|0)+(aB<<2)>>2]}aB=aD>>>16&15;if(!((aB|0)==0|y^1)){c[$+36>>2]=c[(c[2440392]|0)+(aB<<2)>>2]}aB=aD>>>24&15;if(!((aB|0)==0|z^1)){c[$+32>>2]=c[(c[2440392]|0)+(aB<<2)>>2]}aB=aD>>>28;if(!((aB|0)==0|A^1)){c[$+28>>2]=c[(c[2440392]|0)+(aB<<2)>>2]}aB=c[av+((az|1)<<2)>>2]|0;az=aB&15;if(!((az|0)==0|B^1)){c[$+24>>2]=c[(c[2440392]|0)+(az<<2)>>2]}az=aB>>>4&15;if(!((az|0)==0|C^1)){c[$+20>>2]=c[(c[2440392]|0)+(az<<2)>>2]}az=aB>>>8&15;if(!((az|0)==0|D^1)){c[$+16>>2]=c[(c[2440392]|0)+(az<<2)>>2]}az=aB>>>16&15;if(!((az|0)==0|E^1)){c[$+12>>2]=c[(c[2440392]|0)+(az<<2)>>2]}az=aB>>>20&15;if(!((az|0)==0|F^1)){c[$+8>>2]=c[(c[2440392]|0)+(az<<2)>>2]}az=aB>>>24&15;if(!((az|0)==0|G^1)){c[$+4>>2]=c[(c[2440392]|0)+(az<<2)>>2]}az=aB>>>28;if((az|0)==0|t^1){break}c[$>>2]=c[(c[2440392]|0)+(az<<2)>>2];break}}}while(0);au=at+1|0;if((au|0)>(V|0)){ar=ay;as=ax;break}else{W=ay;T=ax;R=aw;$=$+p|0;at=au}}}if((aq|0)>(i|0)){ah=39502;break}else{O=ar;P=as;Q=aq}}if((ah|0)==39502){return}else if((ah|0)==39503){return}}function cz0(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0;b=c[3540994]|0;f=c[3528548]|0;g=f<<8;h=c[2385554]|0;do{if((h|0)>31){i=511}else{j=(h<<4)-1|0;if((j|0)>=0){i=j;break}return}}while(0);j=(i|0)>255;k=i&255;l=c[2385550]|0;m=c[2113042]|0;n=c[2113044]|0;o=m+512|0;p=c[2385552]|0;q=c[2113132]|0;r=p<<2;s=c[2112968]|0;t=p+14|0;u=(t|0)>-1&(t|0)<(q|0);t=p+13|0;v=(t|0)>-1&(t|0)<(q|0);t=p+12|0;w=(t|0)>-1&(t|0)<(q|0);t=p+11|0;x=(t|0)>-1&(t|0)<(q|0);t=p+10|0;y=(t|0)>-1&(t|0)<(q|0);t=p+9|0;z=(t|0)>-1&(t|0)<(q|0);t=p+8|0;A=(t|0)>-1&(t|0)<(q|0);t=p+7|0;B=(t|0)>-1&(t|0)<(q|0);t=p+6|0;C=(t|0)>-1&(t|0)<(q|0);t=p+5|0;D=(t|0)>-1&(t|0)<(q|0);t=p+4|0;E=(t|0)>-1&(t|0)<(q|0);t=p+3|0;F=(t|0)>-1&(t|0)<(q|0);t=p+2|0;G=(t|0)>-1&(t|0)<(q|0);t=p+1|0;H=(t|0)>-1&(t|0)<(q|0);t=(p|0)>-1&(p|0)<(q|0);p=q<<2;I=c[2415160]|0;J=c[2429858]|0;K=c[2430428]|0;L=c[2429718]|0;M=c[2430092]|0;N=c[3541046]|0;O=c[2430426]|0;P=0;Q=0;R=0;L46326:while(1){S=(h|0)>16&(f|0)!=255;T=(h|0)<33;U=511-f|0;V=f+1|0;W=f-255|0;X=~f;Y=R;L46328:while(1){Z=Y+l|0;_=Z&511;do{if((_|0)<(m|0)){$=Y+m-_|0}else{if((_|0)>=(n|0)){$=o+Y-_|0;break}aa=(Y|0)>255;ab=aa?16:0;ac=Y&255;ad=(Y|0)<256&j?255:k;if(!S){ae=ad;af=ac;ah=ab;ai=39527;break L46328}if(T){if(!aa){ai=39517;break L46328}if((Y|0)<(U|0)){$=U;break}else{ai=39519;break L46328}}if(aa){aj=W+ac|0;if((aj|0)>=0){ai=39522;break L46328}aa=V+aj|0;if((aa|0)<0){$=512;break}else{ae=f;af=aa;ah=0;ai=39527;break L46328}}else{if((ac|0)<=(f|0)){ai=39525;break L46328}aa=ac+X|0;if((aa|0)>(f|0)){$=256;break}else{ae=f;af=aa;ah=16;ai=39527;break L46328}}}}while(0);if(($|0)>(i|0)){ai=39602;break L46326}else{Y=$}}if((ai|0)==39522){ai=0;ak=f;al=ab;am=aj;an=V+Y-aj|0}else if((ai|0)==39517){ai=0;ao=ab;ap=ac;aq=ad;ar=Y+1-ac+ad|0;ai=39528}else if((ai|0)==39519){ai=0;X=255-f|0;ae=ad-X|0;af=ac-X|0;ah=ab;ai=39527}else if((ai|0)==39525){ai=0;ak=f;al=ab;am=ac;an=V+Y-ac|0}if((ai|0)==39527){ai=0;X=Y+1-af+ae|0;if(T){ao=ah;ap=af;aq=ae;ar=X;ai=39528}else{ak=ae;al=ah;am=af;an=X}}if((ai|0)==39528){ai=0;ak=(aq|0)>(f|0)?f:aq;al=ao;am=ap;an=ar}X=((Z|-512)^511)+n|0;W=(ak-am|0)>(X|0)?X+am|0:ak;if((am|0)>(W|0)){as=P;at=Q}else{X=P;U=Q;S=-1;aa=s+((ag(q,(_<<2)-64|0)|0)+r)|0;au=am;while(1){av=d[b+(au+g)|0]|0;aw=(av>>>4)+al|0;do{if((aw|0)==(S|0)){ax=S;ay=U;az=X}else{aA=aw<<1;aB=e[I+((aA|1)<<1)>>1]|0;aC=(aB<<12&983040|(e[I+(aA<<1)>>1]|0))&J;do{if((aB&8|0)==0){if((aB&4|0)==0){aD=aC;break}aD=K|aC&1048572}else{aD=O|aC&1048568}}while(0);aC=a[L+aD|0]|0;aA=aC&255;if(aC<<24>>24!=0){ax=aw;ay=aA;az=aB;break}c[2385344]=M+(aD<<7);c[2440392]=N+((aB>>>4&4080)<<2);ax=aw;ay=aA;az=aB}}while(0);do{if((ay|0)==0){aw=av<<1&30;aA=(az&2|0)==0?aw:aw^30;if((az&1|0)==0){aw=c[2385344]|0;aC=c[aw+(aA<<2)>>2]|0;aE=aC&15;if(!((aE|0)==0|t^1)){c[aa>>2]=c[(c[2440392]|0)+(aE<<2)>>2]}aE=aC>>>4&15;if(!((aE|0)==0|H^1)){c[aa+4>>2]=c[(c[2440392]|0)+(aE<<2)>>2]}aE=aC>>>8&15;if(!((aE|0)==0|G^1)){c[aa+8>>2]=c[(c[2440392]|0)+(aE<<2)>>2]}aE=aC>>>12&15;if(!((aE|0)==0|F^1)){c[aa+12>>2]=c[(c[2440392]|0)+(aE<<2)>>2]}aE=aC>>>16&15;if(!((aE|0)==0|E^1)){c[aa+16>>2]=c[(c[2440392]|0)+(aE<<2)>>2]}aE=aC>>>24&15;if(!((aE|0)==0|D^1)){c[aa+20>>2]=c[(c[2440392]|0)+(aE<<2)>>2]}aE=aC>>>28;if(!((aE|0)==0|C^1)){c[aa+24>>2]=c[(c[2440392]|0)+(aE<<2)>>2]}aE=c[aw+((aA|1)<<2)>>2]|0;aw=aE&15;if(!((aw|0)==0|B^1)){c[aa+28>>2]=c[(c[2440392]|0)+(aw<<2)>>2]}aw=aE>>>4&15;if(!((aw|0)==0|A^1)){c[aa+32>>2]=c[(c[2440392]|0)+(aw<<2)>>2]}aw=aE>>>8&15;if(!((aw|0)==0|z^1)){c[aa+36>>2]=c[(c[2440392]|0)+(aw<<2)>>2]}aw=aE>>>12&15;if(!((aw|0)==0|y^1)){c[aa+40>>2]=c[(c[2440392]|0)+(aw<<2)>>2]}aw=aE>>>16&15;if(!((aw|0)==0|x^1)){c[aa+44>>2]=c[(c[2440392]|0)+(aw<<2)>>2]}aw=aE>>>20&15;if(!((aw|0)==0|w^1)){c[aa+48>>2]=c[(c[2440392]|0)+(aw<<2)>>2]}aw=aE>>>24&15;if(!((aw|0)==0|v^1)){c[aa+52>>2]=c[(c[2440392]|0)+(aw<<2)>>2]}aw=aE>>>28;if((aw|0)==0|u^1){break}c[aa+56>>2]=c[(c[2440392]|0)+(aw<<2)>>2];break}else{aw=c[2385344]|0;aE=c[aw+(aA<<2)>>2]|0;aC=aE&15;if(!((aC|0)==0|u^1)){c[aa+56>>2]=c[(c[2440392]|0)+(aC<<2)>>2]}aC=aE>>>4&15;if(!((aC|0)==0|v^1)){c[aa+52>>2]=c[(c[2440392]|0)+(aC<<2)>>2]}aC=aE>>>8&15;if(!((aC|0)==0|w^1)){c[aa+48>>2]=c[(c[2440392]|0)+(aC<<2)>>2]}aC=aE>>>12&15;if(!((aC|0)==0|x^1)){c[aa+44>>2]=c[(c[2440392]|0)+(aC<<2)>>2]}aC=aE>>>16&15;if(!((aC|0)==0|y^1)){c[aa+40>>2]=c[(c[2440392]|0)+(aC<<2)>>2]}aC=aE>>>24&15;if(!((aC|0)==0|z^1)){c[aa+36>>2]=c[(c[2440392]|0)+(aC<<2)>>2]}aC=aE>>>28;if(!((aC|0)==0|A^1)){c[aa+32>>2]=c[(c[2440392]|0)+(aC<<2)>>2]}aC=c[aw+((aA|1)<<2)>>2]|0;aA=aC&15;if(!((aA|0)==0|B^1)){c[aa+28>>2]=c[(c[2440392]|0)+(aA<<2)>>2]}aA=aC>>>4&15;if(!((aA|0)==0|C^1)){c[aa+24>>2]=c[(c[2440392]|0)+(aA<<2)>>2]}aA=aC>>>8&15;if(!((aA|0)==0|D^1)){c[aa+20>>2]=c[(c[2440392]|0)+(aA<<2)>>2]}aA=aC>>>12&15;if(!((aA|0)==0|E^1)){c[aa+16>>2]=c[(c[2440392]|0)+(aA<<2)>>2]}aA=aC>>>16&15;if(!((aA|0)==0|F^1)){c[aa+12>>2]=c[(c[2440392]|0)+(aA<<2)>>2]}aA=aC>>>20&15;if(!((aA|0)==0|G^1)){c[aa+8>>2]=c[(c[2440392]|0)+(aA<<2)>>2]}aA=aC>>>24&15;if(!((aA|0)==0|H^1)){c[aa+4>>2]=c[(c[2440392]|0)+(aA<<2)>>2]}aA=aC>>>28;if((aA|0)==0|t^1){break}c[aa>>2]=c[(c[2440392]|0)+(aA<<2)>>2];break}}}while(0);av=au+1|0;if((av|0)>(W|0)){as=az;at=ay;break}else{X=az;U=ay;S=ax;aa=aa+p|0;au=av}}}if((an|0)>(i|0)){ai=39603;break}else{P=as;Q=at;R=an}}if((ai|0)==39602){return}else if((ai|0)==39603){return}}function cz1(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0;b=c[3540994]|0;f=c[3528548]|0;g=f<<8;h=c[2385554]|0;do{if((h|0)>31){i=511}else{j=(h<<4)-1|0;if((j|0)>=0){i=j;break}return}}while(0);j=(i|0)>255;k=i&255;l=c[2385550]|0;m=c[2113042]|0;n=c[2113044]|0;o=m+512|0;p=c[2385552]|0;q=c[2113132]|0;r=p<<2;s=c[2112968]|0;t=p+15|0;u=(t|0)>-1&(t|0)<(q|0);t=p+14|0;v=(t|0)>-1&(t|0)<(q|0);t=p+13|0;w=(t|0)>-1&(t|0)<(q|0);t=p+12|0;x=(t|0)>-1&(t|0)<(q|0);t=p+11|0;y=(t|0)>-1&(t|0)<(q|0);t=p+10|0;z=(t|0)>-1&(t|0)<(q|0);t=p+9|0;A=(t|0)>-1&(t|0)<(q|0);t=p+8|0;B=(t|0)>-1&(t|0)<(q|0);t=p+7|0;C=(t|0)>-1&(t|0)<(q|0);t=p+6|0;D=(t|0)>-1&(t|0)<(q|0);t=p+5|0;E=(t|0)>-1&(t|0)<(q|0);t=p+4|0;F=(t|0)>-1&(t|0)<(q|0);t=p+3|0;G=(t|0)>-1&(t|0)<(q|0);t=p+2|0;H=(t|0)>-1&(t|0)<(q|0);t=p+1|0;I=(t|0)>-1&(t|0)<(q|0);t=(p|0)>-1&(p|0)<(q|0);p=q<<2;J=c[2415160]|0;K=c[2429858]|0;L=c[2430428]|0;M=c[2429718]|0;N=c[2430092]|0;O=c[3541046]|0;P=c[2430426]|0;Q=0;R=0;S=0;L46471:while(1){T=(h|0)>16&(f|0)!=255;U=(h|0)<33;V=511-f|0;W=f+1|0;X=f-255|0;Y=~f;Z=S;L46473:while(1){_=Z+l|0;$=_&511;do{if(($|0)<(m|0)){aa=Z+m-$|0}else{if(($|0)>=(n|0)){aa=o+Z-$|0;break}ab=(Z|0)>255;ac=ab?16:0;ad=Z&255;ae=(Z|0)<256&j?255:k;if(!T){af=ae;ah=ad;ai=ac;aj=39628;break L46473}if(U){if(!ab){aj=39618;break L46473}if((Z|0)<(V|0)){aa=V;break}else{aj=39620;break L46473}}if(ab){ak=X+ad|0;if((ak|0)>=0){aj=39623;break L46473}ab=W+ak|0;if((ab|0)<0){aa=512;break}else{af=f;ah=ab;ai=0;aj=39628;break L46473}}else{if((ad|0)<=(f|0)){aj=39626;break L46473}ab=ad+Y|0;if((ab|0)>(f|0)){aa=256;break}else{af=f;ah=ab;ai=16;aj=39628;break L46473}}}}while(0);if((aa|0)>(i|0)){aj=39707;break L46471}else{Z=aa}}if((aj|0)==39620){aj=0;Y=255-f|0;af=ae-Y|0;ah=ad-Y|0;ai=ac;aj=39628}else if((aj|0)==39623){aj=0;al=f;am=ac;an=ak;ao=W+Z-ak|0}else if((aj|0)==39618){aj=0;ap=ac;aq=ad;ar=ae;as=Z+1-ad+ae|0;aj=39629}else if((aj|0)==39626){aj=0;al=f;am=ac;an=ad;ao=W+Z-ad|0}if((aj|0)==39628){aj=0;Y=Z+1-ah+af|0;if(U){ap=ai;aq=ah;ar=af;as=Y;aj=39629}else{al=af;am=ai;an=ah;ao=Y}}if((aj|0)==39629){aj=0;al=(ar|0)>(f|0)?f:ar;am=ap;an=aq;ao=as}Y=((_|-512)^511)+n|0;X=(al-an|0)>(Y|0)?Y+an|0:al;if((an|0)>(X|0)){at=Q;au=R}else{Y=Q;V=R;T=-1;ab=s+((ag(q,($<<2)-64|0)|0)+r)|0;av=an;while(1){aw=d[b+(av+g)|0]|0;ax=(aw>>>4)+am|0;do{if((ax|0)==(T|0)){ay=T;az=V;aA=Y}else{aB=ax<<1;aC=e[J+((aB|1)<<1)>>1]|0;aD=(aC<<12&983040|(e[J+(aB<<1)>>1]|0))&K;do{if((aC&8|0)==0){if((aC&4|0)==0){aE=aD;break}aE=L|aD&1048572}else{aE=P|aD&1048568}}while(0);aD=a[M+aE|0]|0;aB=aD&255;if(aD<<24>>24!=0){ay=ax;az=aB;aA=aC;break}c[2385344]=N+(aE<<7);c[2440392]=O+((aC>>>4&4080)<<2);ay=ax;az=aB;aA=aC}}while(0);do{if((az|0)==0){ax=aw<<1&30;aB=(aA&2|0)==0?ax:ax^30;if((aA&1|0)==0){ax=c[2385344]|0;aD=c[ax+(aB<<2)>>2]|0;aF=aD&15;if(!((aF|0)==0|t^1)){c[ab>>2]=c[(c[2440392]|0)+(aF<<2)>>2]}aF=aD>>>4&15;if(!((aF|0)==0|I^1)){c[ab+4>>2]=c[(c[2440392]|0)+(aF<<2)>>2]}aF=aD>>>8&15;if(!((aF|0)==0|H^1)){c[ab+8>>2]=c[(c[2440392]|0)+(aF<<2)>>2]}aF=aD>>>12&15;if(!((aF|0)==0|G^1)){c[ab+12>>2]=c[(c[2440392]|0)+(aF<<2)>>2]}aF=aD>>>16&15;if(!((aF|0)==0|F^1)){c[ab+16>>2]=c[(c[2440392]|0)+(aF<<2)>>2]}aF=aD>>>20&15;if(!((aF|0)==0|E^1)){c[ab+20>>2]=c[(c[2440392]|0)+(aF<<2)>>2]}aF=aD>>>24&15;if(!((aF|0)==0|D^1)){c[ab+24>>2]=c[(c[2440392]|0)+(aF<<2)>>2]}aF=aD>>>28;if(!((aF|0)==0|C^1)){c[ab+28>>2]=c[(c[2440392]|0)+(aF<<2)>>2]}aF=c[ax+((aB|1)<<2)>>2]|0;ax=aF&15;if(!((ax|0)==0|B^1)){c[ab+32>>2]=c[(c[2440392]|0)+(ax<<2)>>2]}ax=aF>>>4&15;if(!((ax|0)==0|A^1)){c[ab+36>>2]=c[(c[2440392]|0)+(ax<<2)>>2]}ax=aF>>>8&15;if(!((ax|0)==0|z^1)){c[ab+40>>2]=c[(c[2440392]|0)+(ax<<2)>>2]}ax=aF>>>12&15;if(!((ax|0)==0|y^1)){c[ab+44>>2]=c[(c[2440392]|0)+(ax<<2)>>2]}ax=aF>>>16&15;if(!((ax|0)==0|x^1)){c[ab+48>>2]=c[(c[2440392]|0)+(ax<<2)>>2]}ax=aF>>>20&15;if(!((ax|0)==0|w^1)){c[ab+52>>2]=c[(c[2440392]|0)+(ax<<2)>>2]}ax=aF>>>24&15;if(!((ax|0)==0|v^1)){c[ab+56>>2]=c[(c[2440392]|0)+(ax<<2)>>2]}ax=aF>>>28;if((ax|0)==0|u^1){break}c[ab+60>>2]=c[(c[2440392]|0)+(ax<<2)>>2];break}else{ax=c[2385344]|0;aF=c[ax+(aB<<2)>>2]|0;aD=aF&15;if(!((aD|0)==0|u^1)){c[ab+60>>2]=c[(c[2440392]|0)+(aD<<2)>>2]}aD=aF>>>4&15;if(!((aD|0)==0|v^1)){c[ab+56>>2]=c[(c[2440392]|0)+(aD<<2)>>2]}aD=aF>>>8&15;if(!((aD|0)==0|w^1)){c[ab+52>>2]=c[(c[2440392]|0)+(aD<<2)>>2]}aD=aF>>>12&15;if(!((aD|0)==0|x^1)){c[ab+48>>2]=c[(c[2440392]|0)+(aD<<2)>>2]}aD=aF>>>16&15;if(!((aD|0)==0|y^1)){c[ab+44>>2]=c[(c[2440392]|0)+(aD<<2)>>2]}aD=aF>>>20&15;if(!((aD|0)==0|z^1)){c[ab+40>>2]=c[(c[2440392]|0)+(aD<<2)>>2]}aD=aF>>>24&15;if(!((aD|0)==0|A^1)){c[ab+36>>2]=c[(c[2440392]|0)+(aD<<2)>>2]}aD=aF>>>28;if(!((aD|0)==0|B^1)){c[ab+32>>2]=c[(c[2440392]|0)+(aD<<2)>>2]}aD=c[ax+((aB|1)<<2)>>2]|0;aB=aD&15;if(!((aB|0)==0|C^1)){c[ab+28>>2]=c[(c[2440392]|0)+(aB<<2)>>2]}aB=aD>>>4&15;if(!((aB|0)==0|D^1)){c[ab+24>>2]=c[(c[2440392]|0)+(aB<<2)>>2]}aB=aD>>>8&15;if(!((aB|0)==0|E^1)){c[ab+20>>2]=c[(c[2440392]|0)+(aB<<2)>>2]}aB=aD>>>12&15;if(!((aB|0)==0|F^1)){c[ab+16>>2]=c[(c[2440392]|0)+(aB<<2)>>2]}aB=aD>>>16&15;if(!((aB|0)==0|G^1)){c[ab+12>>2]=c[(c[2440392]|0)+(aB<<2)>>2]}aB=aD>>>20&15;if(!((aB|0)==0|H^1)){c[ab+8>>2]=c[(c[2440392]|0)+(aB<<2)>>2]}aB=aD>>>24&15;if(!((aB|0)==0|I^1)){c[ab+4>>2]=c[(c[2440392]|0)+(aB<<2)>>2]}aB=aD>>>28;if((aB|0)==0|t^1){break}c[ab>>2]=c[(c[2440392]|0)+(aB<<2)>>2];break}}}while(0);aw=av+1|0;if((aw|0)>(X|0)){at=aA;au=az;break}else{Y=aA;V=az;T=ay;ab=ab+p|0;av=aw}}}if((ao|0)>(i|0)){aj=39708;break}else{Q=at;R=au;S=ao}}if((aj|0)==39707){return}else if((aj|0)==39708){return}}function cz2(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;i=(h|0)>67108864?16777216:h>>2;h=1073741824;while(1){j=h>>1;if((h|0)>(i|0)){h=j}else{break}}i=g>>2;g=c[2077650]|0;k=c[2077648]|0;l=c[2077646]|0;m=c[2383592]|0;n=c[2077644]|0;o=c[2383588]|0;p=0;do{q=p<<2;r=f+q|0;s=f+(q|3)|0;t=p>>8;u=p&255;v=p>>>8&255;w=m+v|0;x=a[l+((d[w]|0)^u)|0]|0;y=g+v|0;z=k+v|0;v=a[z]&1|x&-2;A=a[r]|0;B=a[s]|0;C=(t&1|0)==0;a[r]=(C?A:B)^(a[y]&-2|x&1);a[s]=(C?B:A)^v;v=f+(q|1)|0;A=f+(q|2)|0;q=a[n+((d[w]|0)^u)|0]|0;u=a[y]&1|q&-2;y=a[v]|0;w=a[A]|0;B=(((d[o+(t&255)|0]|0)^(p+i|0)>>>16)&1|0)==0;a[v]=(B?y:w)^(a[z]&-2|q&1);a[A]=(B?w:y)^u;p=p+1|0;}while((p|0)<1048576);p=h-1|0;n=f;f=e;e=j-1|0;j=c[2383590]|0;k=c[2383584]|0;g=c[2383586]|0;l=0;do{u=l+i|0;y=(d[m+(u>>>8&255)|0]|0)^u;w=(d[o+(y>>>8&255)|0]|0)<<16^y;y=(d[j+(w&255)|0]|0)<<16^w;if((u|0)<(h|0)){D=y&p}else{D=(y&e)+h|0}y=(d[k+(D&255)|0]|0)<<8^D;c[f+((y^b^(d[g+(y>>>16&255)|0]|0)<<8)<<2)>>2]=c[n+(l<<2)>>2];l=l+1|0;}while((l|0)<1048576);return}function cz3(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;d=i;i=i+48|0;e=d|0;f=c[2388438]|0;do{if((f|0)!=2){g=(c[2388443]|0)+b|0;c[2388443]=g;h=c[2388444]|0;j=g>>>0>=h>>>0;if((f|0)==1){if(!j){break}c[2388438]=0;k=(g>>>0)%(h>>>0)|0;c[2388443]=k;a[9553780]=k>>>0>=h>>>1>>>0|0;break}if(j){j=(g>>>0)%(h>>>0)|0;c[2388443]=j;l=j}else{l=g}a[9553780]=l>>>0>=h>>>1>>>0|0}}while(0);l=(c[2388442]|0)+b|0;c[2388442]=l;if(l>>>0<(c[3528528]|0)>>>0){i=d;return}c[2388442]=(l>>>0)%((c[2388444]|0)>>>0)|0;l=(c[2388430]|0)+1|0;c[2388430]=l;if(l>>>0<=59){i=d;return}c[2388430]=0;l=(c[2388431]|0)+1|0;c[2388431]=l;if(l>>>0<=59){i=d;return}c[2388431]=0;l=(c[2388432]|0)+1|0;c[2388432]=l;if(l>>>0<=23){i=d;return}c[2388432]=0;l=(c[2388436]|0)+1|0;c[2388436]=l>>>0>6?0:l;l=e;gGC(l|0,618648,48)|0;l=c[2388435]|0;if((l&3|0)==0){c[e+8>>2]=32}b=(c[2388433]|0)+1|0;c[2388433]=b;f=c[2388434]|0;if(b>>>0<=(c[e+(f<<2)>>2]|0)>>>0){i=d;return}c[2388433]=1;e=f+1|0;c[2388434]=e;if(e>>>0<=12){i=d;return}c[2388434]=1;e=l+1|0;c[2388435]=e;if(e>>>0<=99){i=d;return}c[2388435]=0;i=d;return}function cz4(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=d<<24>>24!=0;L46668:do{if(f&(a[9553782]|0)==0){g=c[2388441]|0;switch(g&15|0){case 13:{c[2388438]=0;break L46668;break};case 3:{c[2388437]=0;h=c[2388430]|0;i=c[2388431]|0;j=c[2388432]|0;k=c[2388433]|0;c[2388439]=((h>>>0)/10|0)<<4|((h>>>0)%10|0)|((i>>>0)%10|0)<<8|((i>>>0)/10|0)<<12|((j>>>0)%10|0)<<16|((j>>>0)/10|0)<<20|((k>>>0)%10|0)<<24|((k>>>0)/10|0)<<28;k=c[2388435]|0;c[2388440]=c[2388434]<<4|c[2388436]|((k>>>0)%10|0)<<8|((k>>>0)/10|0)<<12;break L46668;break};case 12:{c[2388438]=1;a[9553780]=1;break L46668;break};case 14:{c[2388438]=2;break L46668;break};case 1:{c[2388437]=1;break L46668;break};case 4:case 5:case 6:case 7:{c[2388438]=0;k=((c[3528528]|0)>>>0)/((c[619448+((g&3)<<2)>>2]|0)>>>0)|0;c[2388444]=k;c[2388443]=((c[2388443]|0)>>>0)%(k>>>0)|0;break L46668;break};case 0:{c[2388437]=0;c[2388438]=0;k=(c[3528528]|0)>>>6;c[2388444]=k;c[2388443]=((c[2388443]|0)>>>0)%(k>>>0)|0;break L46668;break};case 8:case 9:case 10:case 11:{c[2388438]=0;c[2388444]=ag(c[3528528]|0,c[619432+((g&3)<<2)>>2]|0)|0;c[2388443]=0;break L46668;break};case 2:{c[2388437]=2;g=c[2388439]|0;c[2388430]=((g>>>4&15)*10|0)+(g&15);c[2388431]=((g>>>12&15)*10|0)+(g>>>8&15);c[2388432]=((g>>>20&15)*10|0)+(g>>>16&15);c[2388433]=((g>>>28)*10|0)+(g>>>24&15);g=c[2388440]|0;c[2388436]=g&15;c[2388434]=g>>>4&15;c[2388435]=((g>>>12&15)*10|0)+(g>>>8&15);break L46668;break};default:{break L46668}}}}while(0);if(!((a[9553781]|0)==0&((f|b<<24>>24==0)^1))){a[9553781]=b;a[9553782]=d;return}do{if((c[2388437]|0)==1){f=(c[2388439]|0)>>>1;c[2388439]=f;g=c[2388440]|0;if((g&1|0)!=0){c[2388439]=f|-2147483648}f=g>>>1&32767;c[2388440]=f;g=c[2388441]|0;if((g&1|0)==0){l=g;break}c[2388440]=f|32768;l=g}else{l=c[2388441]|0}}while(0);g=l>>>1&7;c[2388441]=g;if(e<<24>>24==0){a[9553781]=b;a[9553782]=d;return}c[2388441]=g|8;a[9553781]=b;a[9553782]=d;return}function cz5(){var a=0,b=0,d=0,e=0,f=0;a=c[3541128]|0;b=(c[2113148]|0)-2097152|0;d=(c[2112932]|0)+8192|0;e=2097152;while(1){f=a+(b+e)|0;c[d>>2]=f;c[d+131072>>2]=f;f=e+1024|0;if(f>>>0>3145727){break}else{d=d+4|0;e=f}}return}function cz6(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(a>>>0<=3145711){return}a=((b&255)<<20&7340032)+1048576|0;b=a>>>0<(c[9542144+(c[2113146]<<2)>>2]|0)>>>0?a:1048576;if((b|0)==(c[2113148]|0)){return}c[2113148]=b;a=c[3541128]|0;d=b-2097152|0;b=(c[2112932]|0)+8192|0;e=2097152;while(1){f=a+(d+e)|0;c[b>>2]=f;c[b+131072>>2]=f;f=e+1024|0;if(f>>>0>3145727){break}else{b=b+4|0;e=f}}return}function cz7(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(a>>>0<=3145711){return}a=((b&65535)<<20&7340032)+1048576|0;b=a>>>0<(c[9542144+(c[2113146]<<2)>>2]|0)>>>0?a:1048576;if((b|0)==(c[2113148]|0)){return}c[2113148]=b;a=c[3541128]|0;d=b-2097152|0;b=(c[2112932]|0)+8192|0;e=2097152;while(1){f=a+(d+e)|0;c[b>>2]=f;c[b+131072>>2]=f;f=e+1024|0;if(f>>>0>3145727){break}else{b=b+4|0;e=f}}return}function cz8(b){b=b|0;var c=0;if((b|0)==2621441){c=~a[14164235]}else if((b|0)==2883585){c=3}else{c=-1}return c|0}function cz9(a){a=a|0;var b=0;if((a|0)==2621440){b=(d[14164235]|0)^255}else if((a|0)==2883584){b=3}else{b=-1}return b|0}function cAa(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if((b|0)==3276801){d=c[2113310]|0;if(!((d-10|0)>>>0>1&(d|0)!=12)){e=39;return e|0}d=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;cz3(d-(c[2438114]|0)|0);if((c[2388437]|0)==0){f=(c[2388442]|0)>>>0>=(c[3528528]|0)>>>1>>>0|0}else{f=c[2388439]&1}g=f<<1|a[9553780];c[2438114]=d;e=g<<6|63;return e|0}else if((b|0)==3276800){b=a[9775480]|0;g=c[2440442]|0;if((g|0)==3){h=3;i=h&1;j=(i|0)==0;k=b&127;l=j?k:b;return l|0}d=((c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0)/3|0;f=d+256|0;if((f|0)<=((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)){h=g;i=h&1;j=(i|0)==0;k=b&127;l=j?k:b;return l|0}c[2438218]=d;Sb(f);h=c[2440442]|0;i=h&1;j=(i|0)==0;k=b&127;l=j?k:b;return l|0}else{e=-1;return e|0}return 0}function cAb(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0;g=i;i=i+616|0;h=g|0;j=g+16|0;k=g+32|0;l=g+48|0;m=g+64|0;n=g+80|0;o=g+96|0;p=g+112|0;q=g+128|0;r=g+144|0;s=g+160|0;t=g+176|0;u=g+192|0;v=g+208|0;w=g+224|0;x=g+240|0;y=g+256|0;z=g+272|0;A=g+288|0;B=g+304|0;C=g+320|0;D=g+336|0;E=g+352|0;F=g+368|0;G=g+384|0;H=g+400|0;I=g+416|0;J=g+432|0;K=g+448|0;L=g+464|0;M=g+480|0;N=g+496|0;O=g+512|0;P=g+528|0;Q=g+544|0;R=g+560|0;S=g+576|0;T=g+592|0;U=g+600|0;V=g+608|0;W=c[2113310]|0;X=(f|0)!=0;if(X){c[f>>2]=169747}Y=(e&64|0)!=0;L46754:do{if(Y){gGz(R|0,0,12);c[R>>2]=8453240;c[R+4>>2]=4;c[R+12>>2]=431784;Z=c[2076592]|0;gj[Z&4095](R)|0;if((c[2438154]&24|0)!=0){break}Z=c[2113310]|0;do{if(!((Z|0)==(-1|0)|(Z|0)==12|(Z|0)==11|(Z|0)==10)){if((a[14164120]&116)==32){break}c[2438154]=5;break L46754}}while(0);c[2438154]=6}}while(0);do{if((e&4|0)!=0){R=(c[2438154]&4|0)==0;Z=S|0;c[Z>>2]=c[3541146];_=S+4|0;c[_>>2]=524288;$=S+8|0;c[$>>2]=0;aa=S+12|0;c[aa>>2]=553672;ab=c[2076592]|0;gj[ab&4095](S)|0;if(R){break}c[Z>>2]=c[3541128];c[_>>2]=c[9542144+(c[2113146]<<2)>>2];c[$>>2]=0;c[aa>>2]=496208;R=c[2076592]|0;gj[R&4095](S)|0;c[Z>>2]=c[3541006];c[_>>2]=131072;c[$>>2]=0;c[aa>>2]=333200;R=c[2076592]|0;gj[R&4095](S)|0;c[Z>>2]=c[3540996];c[_>>2]=524288;c[$>>2]=0;c[aa>>2]=501160;R=c[2076592]|0;gj[R&4095](S)|0;R=c[2113146]|0;c[Z>>2]=c[14127400+(R<<2)>>2];c[_>>2]=c[9721648+(R<<2)>>2];c[$>>2]=0;c[aa>>2]=199152;R=c[2076592]|0;gj[R&4095](S)|0;R=c[2113146]|0;c[Z>>2]=c[14127368+(R<<2)>>2];c[_>>2]=c[9721616+(R<<2)>>2];c[$>>2]=0;c[aa>>2]=157704;aa=c[2076592]|0;gj[aa&4095](S)|0}}while(0);do{if((e&16|0)!=0){if((c[2438154]&12|0)!=4){break}aa=e&124;if(X&(aa|0)==16){c[f>>2]=169747;ac=16}else{ac=aa}aa=c[2439434]|0;c[S>>2]=aa;$=S+4|0;c[$>>2]=131072;c[S+8>>2]=0;c[S+12>>2]=93480;do{if((ac|0)==16){if((e&2|0)!=0){a[801632]=1}if((e&1|0)==0){break}a[801632]=0;if((b[aa>>1]|0)==-32768){break}R=d[aa+21|0]<<8|d[aa+23|0];if(R>>>0<=4095){break}c[$>>2]=R}}while(0);$=c[2076592]|0;gj[$&4095](S)|0}}while(0);ac=c[2438154]|0;do{if((ac&16|0)==0){ad=ac}else{if((e&8|0)==0){ad=ac;break}do{if(X){if((e&124|0)!=8){break}c[f>>2]=169747}}while(0);c[S>>2]=c[2439434];c[S+4>>2]=16384;c[S+8>>2]=0;c[S+12>>2]=93480;$=c[2076592]|0;gj[$&4095](S)|0;ad=c[2438154]|0}}while(0);do{if((ad&1|0)!=0){if((e&8|0)==0){break}do{if(X){if((e&124|0)!=8){break}c[f>>2]=169747}}while(0);c[S>>2]=c[2405762];c[S+4>>2]=65536;c[S+8>>2]=0;c[S+12>>2]=102632;ac=c[2076592]|0;gj[ac&4095](S)|0}}while(0);do{if((c[(c[642608+(c[2436]<<2)>>2]|0)+60>>2]&61440|0)==20480){if((e&8|0)==0){break}c[S>>2]=c[2385790];c[S+4>>2]=8192;c[S+8>>2]=0;c[S+12>>2]=79392;X=c[2076592]|0;gj[X&4095](S)|0}}while(0);do{if((e&32|0)!=0){X=c[2438154]|0;if((X&4|0)==0){ae=X}else{X=S|0;c[X>>2]=c[2385792];ad=S+4|0;c[ad>>2]=65536;ac=S+8|0;c[ac>>2]=0;$=S+12|0;c[$>>2]=484192;aa=c[2076592]|0;gj[aa&4095](S)|0;c[X>>2]=c[2385788];c[ad>>2]=2048;c[ac>>2]=0;c[$>>2]=498600;$=c[2076592]|0;gj[$&4095](S)|0;ae=c[2438154]|0}if((ae&16|0)==0){af=S|0;ag=S+4|0;ah=S+8|0;ai=S+12|0}else{$=S|0;c[$>>2]=c[3541128];ac=S+4|0;c[ac>>2]=c[2385536];ad=S+8|0;c[ad>>2]=0;X=S+12|0;c[X>>2]=553376;aa=c[2076592]|0;gj[aa&4095](S)|0;c[$>>2]=c[3540996];c[ac>>2]=524288;c[ad>>2]=0;c[X>>2]=538712;aa=c[2076592]|0;gj[aa&4095](S)|0;af=$;ag=ac;ah=ad;ai=X}c[af>>2]=c[3541048];c[ag>>2]=8192;c[ah>>2]=0;c[ai>>2]=525384;X=c[2076592]|0;gj[X&4095](S)|0;c[af>>2]=c[3541049];c[ag>>2]=8192;c[ah>>2]=0;c[ai>>2]=511784;X=c[2076592]|0;gj[X&4095](S)|0;c[af>>2]=c[3541066];c[ag>>2]=131072;c[ah>>2]=0;c[ai>>2]=499e3;X=c[2076592]|0;gj[X&4095](S)|0;if((c[2438154]&16|0)!=0){c[af>>2]=c[3541040];c[ag>>2]=c[2443854];c[ah>>2]=0;c[ai>>2]=487536;X=c[2076592]|0;gj[X&4095](S)|0;c[af>>2]=c[3541028];c[ag>>2]=c[2113122];c[ah>>2]=0;c[ai>>2]=474544;X=c[2076592]|0;gj[X&4095](S)|0;c[af>>2]=c[3531842];c[ag>>2]=c[2430404];c[ah>>2]=0;c[ai>>2]=463136;X=c[2076592]|0;gj[X&4095](S)|0}X=c[1865440]|0;if((X|0)==0){break}ad=c[X+16>>2]|0;if((ad|0)==0){break}gA[ad&16383](e,f)|0}}while(0);if(!Y){i=g;return 0}Y=l|0;gGz(k|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){S=l+9|0;l=j;ai=j|0;ah=j+4|0;ag=j+12|0;af=k|0;ae=k+4|0;ad=k+12|0;X=0;do{gGC(Y|0,614896,11)|0;a[S]=X+48&255;ac=8452256+(X<<2)|0;gGz(l|0,0,12);c[ai>>2]=ac;c[ah>>2]=4;c[ag>>2]=164976;gj[c[2076592]&4095](j)|0;if((c[ac>>2]|0)!=0){c[af>>2]=c[14130368+(X<<2)>>2];c[ae>>2]=c[8452184+(X<<2)>>2];c[ad>>2]=Y;ac=c[2076592]|0;gj[ac&4095](k)|0}X=X+1|0;}while((X|0)<=(c[2392]|0))}fw$(e);T0(e,f);if((c[2438154]&1|0)!=0){do{if((f|0)!=0){if((c[f>>2]|0)>=133378){break}c[f>>2]=133378}}while(0);gGz(h|0,0,12);c[h>>2]=9553720;c[h+4>>2]=64;c[h+12>>2]=431832;X=c[2076592]|0;gj[X&4095](h)|0}h=c[1865440]|0;do{if((h|0)!=0){X=c[h+16>>2]|0;if((X|0)==0){break}gA[X&16383](e,f)|0}}while(0);gGz(P|0,0,12);c[P>>2]=9762256;c[P+4>>2]=8;c[P+12>>2]=451984;gj[c[2076592]&4095](P)|0;gGz(O|0,0,12);c[O>>2]=9534304;c[O+4>>2]=1;c[O+12>>2]=441128;gj[c[2076592]&4095](O)|0;gGz(N|0,0,12);c[N>>2]=9734240;c[N+4>>2]=4;c[N+12>>2]=429392;gj[c[2076592]&4095](N)|0;gGz(M|0,0,12);c[M>>2]=9775688;c[M+4>>2]=4;c[M+12>>2]=418168;gj[c[2076592]&4095](M)|0;gGz(L|0,0,12);c[L>>2]=14114160;c[L+4>>2]=4;c[L+12>>2]=406296;gj[c[2076592]&4095](L)|0;gGz(K|0,0,12);c[K>>2]=14114168;c[K+4>>2]=4;c[K+12>>2]=395776;gj[c[2076592]&4095](K)|0;gGz(J|0,0,12);c[J>>2]=9757280;c[J+4>>2]=1;c[J+12>>2]=383528;gj[c[2076592]&4095](J)|0;gGz(I|0,0,12);c[I>>2]=9761816;c[I+4>>2]=4;c[I+12>>2]=373928;gj[c[2076592]&4095](I)|0;gGz(H|0,0,12);c[H>>2]=9717768;c[H+4>>2]=1;c[H+12>>2]=364056;gj[c[2076592]&4095](H)|0;if((c[2438154]&4|0)!=0){gGz(G|0,0,12);c[G>>2]=9534320;c[G+4>>2]=1;c[G+12>>2]=356736;H=c[2076592]|0;gj[H&4095](G)|0;gGz(F|0,0,12);c[F>>2]=9541688;c[F+4>>2]=4;c[F+12>>2]=348704;G=c[2076592]|0;gj[G&4095](F)|0;gGz(E|0,0,12);c[E>>2]=9541680;c[E+4>>2]=4;c[E+12>>2]=341048;F=c[2076592]|0;gj[F&4095](E)|0;gGz(D|0,0,12);c[D>>2]=9541672;c[D+4>>2]=4;c[D+12>>2]=333064;E=c[2076592]|0;gj[E&4095](D)|0;gGz(C|0,0,12);c[C>>2]=9541664;c[C+4>>2]=4;c[C+12>>2]=324224;D=c[2076592]|0;gj[D&4095](C)|0;gGz(B|0,0,12);c[B>>2]=8452592;c[B+4>>2]=4;c[B+12>>2]=315568;C=c[2076592]|0;gj[C&4095](B)|0}c[T>>2]=(c[3541066]|0)-(c[2430094]|0);gGz(A|0,0,12);c[A>>2]=T;c[A+4>>2]=4;c[A+12>>2]=306904;gj[c[2076592]&4095](A)|0;A=(e&2|0)!=0;if(A){c[2430094]=(c[3541066]|0)+(c[T>>2]|0)}gGz(z|0,0,12);c[z>>2]=8452520;c[z+4>>2]=4;c[z+12>>2]=298792;gj[c[2076592]&4095](z)|0;gGz(y|0,0,12);c[y>>2]=9721696;c[y+4>>2]=4;c[y+12>>2]=291320;gj[c[2076592]&4095](y)|0;gGz(x|0,0,12);c[x>>2]=9721688;c[x+4>>2]=4;c[x+12>>2]=284832;gj[c[2076592]&4095](x)|0;gGz(w|0,0,12);c[w>>2]=8452544;c[w+4>>2]=4;c[w+12>>2]=278216;gj[c[2076592]&4095](w)|0;gGz(v|0,0,12);c[v>>2]=9775488;c[v+4>>2]=1;c[v+12>>2]=270728;gj[c[2076592]&4095](v)|0;gGz(u|0,0,12);c[u>>2]=9775480;c[u+4>>2]=1;c[u+12>>2]=263488;gj[c[2076592]&4095](u)|0;gGz(t|0,0,12);c[t>>2]=9761768;c[t+4>>2]=4;c[t+12>>2]=254936;gj[c[2076592]&4095](t)|0;gGz(s|0,0,12);c[s>>2]=9734184;c[s+4>>2]=4;c[s+12>>2]=247048;gj[c[2076592]&4095](s)|0;gGz(r|0,0,12);c[r>>2]=9761856;c[r+4>>2]=4;c[r+12>>2]=240336;gj[c[2076592]&4095](r)|0;c[U>>2]=14164232-(c[2442976]|0);gGz(q|0,0,12);c[q>>2]=U;c[q+4>>2]=4;c[q+12>>2]=234024;gj[c[2076592]&4095](q)|0;if(A){c[2442976]=14164232+(c[U>>2]|0)}gGz(p|0,0,12);c[p>>2]=9776568;c[p+4>>2]=8;c[p+12>>2]=99736;gj[c[2076592]&4095](p)|0;gGz(o|0,0,12);c[o>>2]=9752456;c[o+4>>2]=4;c[o+12>>2]=221896;gj[c[2076592]&4095](o)|0;o=c[2113146]|0;c[V>>2]=(c[14164520+(o<<2)>>2]|0)-(c[14164552+(o<<2)>>2]|0);gGz(n|0,0,12);c[n>>2]=V;c[n+4>>2]=4;c[n+12>>2]=217800;gj[c[2076592]&4095](n)|0;if(!A){i=g;return 0}A=c[2113146]|0;n=c[14164520+(A<<2)>>2]|0;o=c[V>>2]|0;V=n+o|0;c[14164552+(A<<2)>>2]=V;p=c[2113310]|0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];U=c[3532592]|0;if((U|0)!=0){gGC(9104152,U|0,280)|0}c[2113054]=c[2113060]}U=(c[2438154]&4|0)==0;do{if(!U){if((c[9542144+(A<<2)>>2]|0)>>>0<=1048576){break}q=(c[2112932]|0)+4|0;r=1024;while(1){s=n+(o+r)|0;c[q>>2]=s;c[q+131072>>2]=s;s=r+1024|0;if(s>>>0>1048575){break}else{q=q+4|0;r=s}}if((n|0)==0){break}r=(c[14164040+(A<<2)>>2]|0)+128|0;q=n+(o+128)|0;gGC(r|0,q|0,896)|0}}while(0);o=c[3541128]|0;if((o|0)!=0&(a[9717768]&1)==0){n=c[2112932]|0;c[n>>2]=V;c[n+131072>>2]=V;aj=n}else{n=c[3541008]|0;V=c[2112932]|0;c[V>>2]=n;c[V+131072>>2]=n;aj=V}V=c[3532592]|0;aj=(V|0)==0;if(!aj){gGC(V|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;L46872:do{if(U){ak=39929}else{n=c[2439330]|0;if((n|0)!=0){A=n;gGC(9706056,A|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];A=c[3528484]|0;c[2076596]=A;q=c[2417276]|0;c[3541536]=q;c[1836236]=0;do{if(a[725016]|0){if((a[9620528]&1)==0){ak=39907;break}r=c[3541006]|0;s=0;t=0;while(1){c[n+76+(t<<2)>>2]=r+(t<<8);u=s+1&65535;if((u&65535)>127){al=0;am=0;break}else{s=u;t=u&65535}}while(1){t=r+(am<<8)|0;c[n+76+(am+512<<2)>>2]=t;c[n+76+(am+768<<2)>>2]=t;t=al+1&65535;if((t&65535)>127){break}else{al=t;am=t&65535}}}else{ak=39907}}while(0);if((ak|0)==39907){r=c[3540996]|0;t=0;s=0;while(1){c[n+76+(s<<2)>>2]=r+(s<<8);u=t+1&65535;if((u&65535)>127){an=0;ao=0;break}else{t=u;s=u&65535}}while(1){s=r+(ao<<8)|0;c[n+76+(ao+512<<2)>>2]=s;c[n+76+(ao+768<<2)>>2]=s;s=an+1&65535;if((s&65535)>127){break}else{an=s;ao=s&65535}}}r=c[2385422]|0;c[2385422]=-1;s=r&15;r=c[3540996]|0;t=(s<<14)-32768|0;u=128;v=128;while(1){c[n+76+(v<<2)>>2]=r+(t+(v<<8));w=u+1&65535;if((w&65535)>191){ap=128;aq=128;break}else{u=w;v=w&65535}}while(1){v=r+(t+(aq<<8))|0;c[n+76+(aq+512<<2)>>2]=v;c[n+76+(aq+768<<2)>>2]=v;v=ap+1&65535;if((v&65535)>191){break}else{ap=v;aq=v&65535}}c[2385422]=s;t=c[2385420]|0;c[2385420]=-1;v=t&31;t=(v<<13)-49152|0;u=192;w=192;while(1){c[n+76+(w<<2)>>2]=r+(t+(w<<8));x=u+1&65535;if((x&65535)>223){ar=192;as=192;break}else{u=x;w=x&65535}}while(1){w=r+(t+(as<<8))|0;c[n+76+(as+512<<2)>>2]=w;c[n+76+(as+768<<2)>>2]=w;w=ar+1&65535;if((w&65535)>223){break}else{ar=w;as=w&65535}}c[2385420]=v;t=c[2385418]|0;c[2385418]=-1;w=t&63;t=w<<12;u=t-57344|0;c[n+972>>2]=r+t;c[n+976>>2]=r+(t|256);c[n+980>>2]=r+(t|512);c[n+984>>2]=r+(t|768);c[n+988>>2]=r+(t|1024);c[n+992>>2]=r+(t|1280);c[n+996>>2]=r+(t|1536);c[n+1e3>>2]=r+(t|1792);c[n+1004>>2]=r+(t|2048);c[n+1008>>2]=r+(t|2304);c[n+1012>>2]=r+(t|2560);c[n+1016>>2]=r+(t|2816);c[n+1020>>2]=r+(t|3072);c[n+1024>>2]=r+(t|3328);c[n+1028>>2]=r+(t|3584);c[n+1032>>2]=r+(t|3840);t=224;s=224;while(1){x=r+(u+(s<<8))|0;c[n+76+(s+512<<2)>>2]=x;c[n+76+(s+768<<2)>>2]=x;x=t+1&65535;if((x&65535)>239){break}else{t=x;s=x&65535}}c[2385418]=w;s=c[2385416]&127;t=s<<11;u=r+t|0;c[n+1036>>2]=u;v=r+(t|256)|0;c[n+1040>>2]=v;x=r+(t|512)|0;c[n+1044>>2]=x;y=r+(t|768)|0;c[n+1048>>2]=y;z=r+(t|1024)|0;c[n+1052>>2]=z;T=r+(t|1280)|0;c[n+1056>>2]=T;e=r+(t|1536)|0;c[n+1060>>2]=e;B=r+(t|1792)|0;c[n+1064>>2]=B;c[n+3084>>2]=u;c[n+4108>>2]=u;c[n+3088>>2]=v;c[n+4112>>2]=v;c[n+3092>>2]=x;c[n+4116>>2]=x;c[n+3096>>2]=y;c[n+4120>>2]=y;c[n+3100>>2]=z;c[n+4124>>2]=z;c[n+3104>>2]=T;c[n+4128>>2]=T;c[n+3108>>2]=e;c[n+4132>>2]=e;c[n+3112>>2]=B;c[n+4136>>2]=B;c[2385416]=s;s=n;gGC(s|0,9706056,76)|0;c[2438118]=c[2433530];c[3528484]=A;c[2417276]=q;c[1836236]=-1;s=c[1865440]|0;do{if((s|0)==0){ak=39920}else{B=c[s+12>>2]|0;if((B|0)==0){ak=39920;break}gu[B&16383]();B=(c[2394]|0)==0;e=c[2113136]|0;c[2113136]=-1;if(B){at=e;break L46872}else{au=e}}}while(0);do{if((ak|0)==39920){if((c[(c[642608+(c[2436]<<2)>>2]|0)+60>>2]&61440|0)==20480){s=c[2113136]|0;c[2113136]=-1;au=s;break}c[2394]=0;s=c[3532596]|0;c[2112932]=s;if(!aj){gGC(9104152,V|0,280)|0}q=c[2113060]|0;c[2113054]=q;A=(c[2113148]|0)-2097152|0;n=s+8192|0;s=2097152;while(1){r=o+(A+s)|0;c[n>>2]=r;c[n+131072>>2]=r;r=s+1024|0;if(r>>>0>3145727){break}else{n=n+4|0;s=r}}s=c[3532592]|0;if((s|0)!=0){gGC(s|0,9104152,280)|0}c[2113060]=q;c[2394]=-1;ak=39929;break L46872}}while(0);av=au;aw=c[3532592]|0;ak=39932}}while(0);if((ak|0)==39929){au=c[2113136]|0;c[2113136]=-1;av=au;aw=V;ak=39932}if((ak|0)==39932){c[2394]=0;c[2112932]=c[3532596];if((aw|0)!=0){gGC(9104152,aw|0,280)|0}c[2113054]=c[2113060];at=av}if((at|0)!=-1){c[2113136]=at;av=c[14164192+(at<<2)>>2]|0;at=c[2112932]|0;c[at+16384>>2]=av;c[at+147456>>2]=av;aw=av+1024|0;c[at+16388>>2]=aw;c[at+147460>>2]=aw;aw=av+2048|0;c[at+16392>>2]=aw;c[at+147464>>2]=aw;aw=av+3072|0;c[at+16396>>2]=aw;c[at+147468>>2]=aw;aw=av+4096|0;c[at+16400>>2]=aw;c[at+147472>>2]=aw;aw=av+5120|0;c[at+16404>>2]=aw;c[at+147476>>2]=aw;aw=av+6144|0;c[at+16408>>2]=aw;c[at+147480>>2]=aw;aw=av+7168|0;c[at+16412>>2]=aw;c[at+147484>>2]=aw;c[3541046]=c[9754600+(c[2113136]<<2)>>2]}aw=c[3532592]|0;if((aw|0)!=0){gGC(aw|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;a[14164176]=1;L46936:do{if((c[2438154]&4|0)!=0){c[2113310]=W;cAc(p);if((c[2438154]&24|0)!=0){break}aw=c[2113310]|0;do{if(!((aw|0)==(-1|0)|(aw|0)==12|(aw|0)==11|(aw|0)==10)){if((a[14164120]&116)==32){break}c[2438154]=5;break L46936}}while(0);c[2438154]=6}}while(0);c[2427030]=-1;gGz(m|0,0,12);c[m>>2]=8452744;c[m+4>>2]=1;c[m+12>>2]=214072;gj[c[2076592]&4095](m)|0;gGz(Q|0,0,12);c[Q>>2]=8452755;c[Q+4>>2]=1;c[Q+12>>2]=210496;gj[c[2076592]&4095](Q)|0;i=g;return 0}function cAc(d){d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;e=i;i=i+360|0;f=e|0;g=e+112|0;h=e+120|0;j=e+232|0;k=e+240|0;l=e+352|0;if((c[2438154]&16|0)!=0){i=e;return}m=c[642608+(c[2436]<<2)>>2]|0;n=m+60|0;o=c[n>>2]|0;p=(o&-65536|0)==84148224?26:(o&61440|0)==8192?25:d;a[9620528]=(p|0)!=0|0;if((p|0)==(c[2113310]|0)){i=e;return}c[2113310]=p;do{if((c[n>>2]&-65536|0)==84017152){d=c[3541146]|0;if((c[3542200]|0)==0){break}o=k+108|0;c[o>>2]=0;q=k+100|0;c[q>>2]=0;r=c[m+76>>2]|0;gA[r&16383](k,p)|0;if((c[o>>2]|0)==0){break}o=c[q>>2]|0;c[l>>2]=9534384;q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[q&16383](l,p,0)|0;if((o|0)<1){break}gzL(d,0,p)|0}else{d=c[3541146]|0;if((p|0)>-1){o=p+128|0;if((c[3542200]|0)==0){break}q=h+108|0;c[q>>2]=0;r=h+100|0;c[r>>2]=0;s=c[m+76>>2]|0;gA[s&16383](h,o)|0;if((c[q>>2]|0)==0){break}q=c[r>>2]|0;c[j>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](j,o,0)|0;if((q|0)<1){break}gzL(d,0,o)|0;break}else{if((c[3542200]|0)==0){break}o=f+108|0;c[o>>2]=0;q=f+100|0;c[q>>2]=0;r=c[m+76>>2]|0;gA[r&16383](f,128)|0;if((c[o>>2]|0)==0){break}o=c[q>>2]|0;c[g>>2]=9534384;q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[q&16383](g,128,0)|0;if((o|0)<1){break}gzL(d,0,128)|0;break}}}while(0);g=c[c[642608+(c[2436]<<2)>>2]>>2]|0;if((fa(g|0,291960)|0)==0){t=39968}else{if((fa(g|0,111200)|0)==0){t=39968}}L46970:do{if((t|0)==39968){g=c[3541146]|0;f=g;m=0;while(1){if((m|0)>=1024){u=0;break}v=9638528+(m<<2)|0;if((c[v>>2]|0)==0){t=39971;break}else{m=m+1|0}}do{if((t|0)==39971){m=gGq(524288)|0;c[v>>2]=m;if((m|0)==0){u=0;break}gGz(m|0,0,524288);u=m}}while(0);m=u;j=0;do{h=(j&32|0)==0?j:j^16;p=~j;l=j<<5&128^160^((p&16|0)==0?h:h^64);h=(j&512|0)==0?l:l^256;l=(p&8192|0)==0?h:h^1024;h=(p&65536|0)==0?l:l^4096;l=b[f+((((j&8192|0)==0?h:h^32768)^c[616432+((j>>>1&56|j&7)<<2)>>2])<<1)>>1]|0;h=(l&65535)>>>2&1^l;l=(h&16)==0?h:h^2;b[m+(j<<1)>>1]=(l&32)==0?l:l^8;j=j+1|0;}while((j|0)<262144);gGC(g|0,u|0,524288)|0;j=0;while(1){if((j|0)>=1024){break L46970}w=9638528+(j<<2)|0;if((c[w>>2]|0)==(u|0)){break}else{j=j+1|0}}gGr(u);c[w>>2]=0}}while(0);w=c[3541146]|0;u=c[3541010]|0;do{if((u|0)!=0){gGC(u|0,w|0,128)|0;if((c[3541130]|0)==0){break}v=u+128|0;t=(c[3541138]|0)+128|0;gGC(v|0,t|0,896)|0}}while(0);u=c[3541011]|0;do{if((u|0)!=0){gGC(u|0,w|0,128)|0;if((c[3541131]|0)==0){break}t=u+128|0;v=(c[3541139]|0)+128|0;gGC(t|0,v|0,896)|0}}while(0);u=c[3541012]|0;do{if((u|0)!=0){gGC(u|0,w|0,128)|0;if((c[3541132]|0)==0){break}v=u+128|0;t=(c[3541140]|0)+128|0;gGC(v|0,t|0,896)|0}}while(0);u=c[3541013]|0;do{if((u|0)!=0){gGC(u|0,w|0,128)|0;if((c[3541133]|0)==0){break}t=u+128|0;v=(c[3541141]|0)+128|0;gGC(t|0,v|0,896)|0}}while(0);u=c[3541014]|0;do{if((u|0)!=0){gGC(u|0,w|0,128)|0;if((c[3541134]|0)==0){break}v=u+128|0;t=(c[3541142]|0)+128|0;gGC(v|0,t|0,896)|0}}while(0);u=c[3541015]|0;do{if((u|0)!=0){gGC(u|0,w|0,128)|0;if((c[3541135]|0)==0){break}t=u+128|0;v=(c[3541143]|0)+128|0;gGC(t|0,v|0,896)|0}}while(0);u=c[3541016]|0;do{if((u|0)!=0){gGC(u|0,w|0,128)|0;if((c[3541136]|0)==0){break}v=u+128|0;t=(c[3541144]|0)+128|0;gGC(v|0,t|0,896)|0}}while(0);u=c[3541017]|0;if((u|0)==0){i=e;return}gGC(u|0,w|0,128)|0;if((c[3541137]|0)==0){i=e;return}w=u+128|0;u=(c[3541145]|0)+128|0;gGC(w|0,u|0,896)|0;i=e;return}function cAd(b){b=b|0;var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0.0,n=0.0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;d=b&65535;switch(d&255|0){case 9:{b=d>>>8&63;if((b|0)==(c[2385418]|0)){e=0;return e|0}f=c[3540996]|0;g=b<<12;i=c[9757320+(c[1836236]<<2)>>2]|0;j=g-57344|0;c[i+972>>2]=f+g;c[i+976>>2]=f+(g|256);c[i+980>>2]=f+(g|512);c[i+984>>2]=f+(g|768);c[i+988>>2]=f+(g|1024);c[i+992>>2]=f+(g|1280);c[i+996>>2]=f+(g|1536);c[i+1e3>>2]=f+(g|1792);c[i+1004>>2]=f+(g|2048);c[i+1008>>2]=f+(g|2304);c[i+1012>>2]=f+(g|2560);c[i+1016>>2]=f+(g|2816);c[i+1020>>2]=f+(g|3072);c[i+1024>>2]=f+(g|3328);c[i+1028>>2]=f+(g|3584);c[i+1032>>2]=f+(g|3840);g=224;k=224;while(1){l=f+(j+(k<<8))|0;c[i+76+(k+512<<2)>>2]=l;c[i+76+(k+768<<2)>>2]=l;l=g+1&65535;if((l&65535)>239){break}else{g=l;k=l&65535}}c[2385418]=b;e=0;return e|0};case 6:{e=a[(c[3541514]|0)+20904|0]|0;return e|0};case 0:{c[2440442]=1;c[2433546]=-1;e=a[9775488]|0;return e|0};case 4:{b=c[3541514]|0;k=b+552|0;m=+h[k>>3];do{if(m!=0.0){n=+h[6675];if(m-(n+ +gC[c[2429842]&255]())>0.0){o=a[b+563|0]|-128;break}else{h[k>>3]=0.0;p=40015;break}}else{p=40015}}while(0);if((p|0)==40015){o=a[b+563|0]|0}e=o&-125;return e|0};case 10:{o=d>>>8&31;if((o|0)==(c[2385420]|0)){e=0;return e|0}b=c[3540996]|0;p=c[9757320+(c[1836236]<<2)>>2]|0;k=(o<<13)-49152|0;g=192;i=192;while(1){c[p+76+(i<<2)>>2]=b+(k+(i<<8));j=g+1&65535;if((j&65535)>223){q=192;r=192;break}else{g=j;i=j&65535}}while(1){i=b+(k+(r<<8))|0;c[p+76+(r+512<<2)>>2]=i;c[p+76+(r+768<<2)>>2]=i;i=q+1&65535;if((i&65535)>223){break}else{q=i;r=i&65535}}c[2385420]=o;e=0;return e|0};case 11:{o=d>>>8&15;if((o|0)==(c[2385422]|0)){e=0;return e|0}r=c[3540996]|0;q=c[9757320+(c[1836236]<<2)>>2]|0;p=(o<<14)-32768|0;k=128;b=128;while(1){c[q+76+(b<<2)>>2]=r+(p+(b<<8));i=k+1&65535;if((i&65535)>191){s=128;t=128;break}else{k=i;b=i&65535}}while(1){b=r+(p+(t<<8))|0;c[q+76+(t+512<<2)>>2]=b;c[q+76+(t+768<<2)>>2]=b;b=s+1&65535;if((b&65535)>191){break}else{s=b;t=b&65535}}c[2385422]=o;e=0;return e|0};case 5:{o=a[(c[3541514]|0)+560|0]|0;do{if((o&255)<16){t=c[2383582]|0;s=c[14168912+(t*252|0)>>2]|0;if((s|0)>15){u=0;break}do{if((s|0)==14){q=c[14168896+(t*252|0)>>2]|0;if((q|0)==0){break}a[14168930+(t*252|0)|0]=gj[q&4095](0)|0}else if((s|0)==15){q=c[14168900+(t*252|0)>>2]|0;if((q|0)==0){break}a[14168931+(t*252|0)|0]=gj[q&4095](0)|0}}while(0);u=a[14168916+(t*252|0)+s|0]|0}else{u=0}}while(0);e=o<<24>>24==-1?1:u;return e|0};case 8:{u=d>>>8&127;if((u|0)==(c[2385416]|0)){e=0;return e|0}d=c[3540996]|0;o=u<<11;q=c[9757320+(c[1836236]<<2)>>2]|0;p=d+o|0;c[q+1036>>2]=p;r=d+(o|256)|0;c[q+1040>>2]=r;b=d+(o|512)|0;c[q+1044>>2]=b;k=d+(o|768)|0;c[q+1048>>2]=k;i=d+(o|1024)|0;c[q+1052>>2]=i;g=d+(o|1280)|0;c[q+1056>>2]=g;j=d+(o|1536)|0;c[q+1060>>2]=j;f=d+(o|1792)|0;c[q+1064>>2]=f;c[q+3084>>2]=p;c[q+4108>>2]=p;c[q+3088>>2]=r;c[q+4112>>2]=r;c[q+3092>>2]=b;c[q+4116>>2]=b;c[q+3096>>2]=k;c[q+4120>>2]=k;c[q+3100>>2]=i;c[q+4124>>2]=i;c[q+3104>>2]=g;c[q+4128>>2]=g;c[q+3108>>2]=j;c[q+4132>>2]=j;c[q+3112>>2]=f;c[q+4136>>2]=f;c[2385416]=u;e=0;return e|0};default:{e=0;return e|0}}return 0}function cAe(b){b=b|0;var d=0,e=0,f=0,g=0.0,i=0.0,j=0,k=0,l=0;d=b&255;if((d|0)==6){e=a[(c[3541514]|0)+20904|0]|0;return e|0}else if((d|0)==4){b=c[3541514]|0;f=b+552|0;g=+h[f>>3];do{if(g!=0.0){i=+h[6675];if(g-(i+ +gC[c[2429842]&255]())>0.0){j=a[b+563|0]|-128;break}else{h[f>>3]=0.0;k=40063;break}}else{k=40063}}while(0);if((k|0)==40063){j=a[b+563|0]|0}e=j&-125;return e|0}else if((d|0)==5){j=a[(c[3541514]|0)+560|0]|0;do{if((j&255)<16){b=c[2383582]|0;k=c[14168912+(b*252|0)>>2]|0;if((k|0)>15){l=0;break}do{if((k|0)==15){f=c[14168900+(b*252|0)>>2]|0;if((f|0)==0){break}a[14168931+(b*252|0)|0]=gj[f&4095](0)|0}else if((k|0)==14){f=c[14168896+(b*252|0)>>2]|0;if((f|0)==0){break}a[14168930+(b*252|0)|0]=gj[f&4095](0)|0}}while(0);l=a[14168916+(b*252|0)+k|0]|0}else{l=0}}while(0);e=j<<24>>24==-1?1:l;return e|0}else if((d|0)==0){c[2440442]=1;c[2433546]=-1;e=a[9775488]|0;return e|0}else{e=0;return e|0}return 0}function cAf(b,d){b=b|0;d=d|0;var e=0;e=b&65535;switch(e&255|0){case 4:case 5:case 6:case 7:{l7(e&3,d);return};case 12:{a[9775480]=d;e=d&255;do{if((c[2433546]|0)==(e|0)){c[2440442]=c[2440442]|2}else{c[2433546]=e;b=c[2440442]|0;if(d<<24>>24==0){c[2440442]=b&-3;break}else{c[2440442]=b|2;break}}}while(0);if(((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)<=(c[2438218]|0)){return}gu[c[3528472]&16383]();c[2443838]=0;return};default:{return}}}function cAg(b){b=b|0;var d=0;if(!(a[849336]|0)){d=-1;return d|0}a[849336]=0;d=c[2433554]|0;return d|0}function cAh(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b&16646144;if((d|0)==3670016){if((b&1|0)!=0){e=-1;return e|0}e=~a[(c[2442976]|0)+2|0];return e|0}else if((d|0)==3407872){if((b&1|0)!=0){e=-1;return e|0}e=~a[(c[2442976]|0)+(c[9542072+(((c[2440464]|0)>>>3&7)<<2)>>2]|0)|0];return e|0}else if((d|0)==3145728){f=b&255;if((f|0)==129){if((c[2438154]&1|0)==0){e=-1;return e|0}e=~a[(c[2442976]|0)+5|0];return e|0}else if((f|0)==1){if((c[2438154]&1|0)==0){e=-1;return e|0}e=~a[(c[2442976]|0)+4|0];return e|0}else if((f|0)==0){e=~a[(c[2442976]|0)+(c[9542104+((c[2440464]&7)<<2)>>2]|0)|0];return e|0}else{e=-1;return e|0}}else if((d|0)==3276800){if((b&1|0)==0){b=a[9775480]|0;d=c[2440442]|0;if((d|0)==3){g=3;h=g&1;i=(h|0)==0;j=b&127;k=i?j:b;return k|0}f=((c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0)/3|0;l=f+256|0;if((l|0)<=((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)){g=d;h=g&1;i=(h|0)==0;j=b&127;k=i?j:b;return k|0}c[2438218]=f;Sb(l);g=c[2440442]|0;h=g&1;i=(h|0)==0;j=b&127;k=i?j:b;return k|0}if((c[2438154]&1|0)==0){e=a[(c[2442976]|0)+3|0]&103^103;return e|0}k=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;cz3(k-(c[2438114]|0)|0);if((c[2388437]|0)==0){m=(c[2388442]|0)>>>0>=(c[3528528]|0)>>>1>>>0|0}else{m=c[2388439]&1}b=m<<1|a[9553780];c[2438114]=k;e=(a[(c[2442976]|0)+3|0]&63|b<<6)^63;return e|0}else{e=-1;return e|0}return 0}function cAi(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=b&16646144;if((d|0)==3276800){e=((gj[c[(c[2112932]|0)+196608>>2]&4095](b)|0)&255)<<8;f=(gj[c[(c[2112932]|0)+196608>>2]&4095](b+1|0)|0)&255|e;return f|0}else if((d|0)==3407872){f=(~a[(c[2442976]|0)+(c[9542072+(((c[2440464]|0)>>>3&7)<<2)>>2]|0)|0]&255)<<8|255;return f|0}else if((d|0)==3670016){f=(~a[(c[2442976]|0)+2|0]&255)<<8|255;return f|0}else if((d|0)==3145728){d=b&254;do{if((d|0)==0){g=(~a[(c[2442976]|0)+(c[9542104+((c[2440464]&7)<<2)>>2]|0)|0]&255)<<8;h=40143}else{b=d|1;if((b|0)==1){g=-256;h=40143;break}else if((b|0)!=129){i=-1;j=-256;break}if((c[2438154]&1|0)==0){i=-1;j=-256;break}i=~a[(c[2442976]|0)+5|0];j=-256}}while(0);do{if((h|0)==40143){if((c[2438154]&1|0)==0){i=-1;j=g;break}i=~a[(c[2442976]|0)+4|0];j=g}}while(0);f=i&255|j;return f|0}else{f=-1;return f|0}return 0}function cAj(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=b&16711680;if((f|0)==3670016){switch(b&255|0){case 1:{c[2440464]=e&255;return};case 225:{c[2442976]=14164240;return};case 81:{if((c[2438154]&1|0)==0){return}cz4(e&2,e&4,e&1);return};case 209:{if((c[2438154]&1|0)==0){return}cz4(e&2,e&4,e&1);return};case 65:{a[8452744]=~e;return};case 97:{c[2442976]=14164232;return};case 33:{c[2113146]=e&255;if((d[9600]|0)<=(e&255)){c[2113146]=0}cAP();return};default:{return}}}else if((f|0)==3276800){if((b&1|0)!=0){return}g=((c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0)/3|0;if((g|0)>((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)){c[2438218]=g;Sb(g)}c[2440442]=c[2440442]&-2;a[9775488]=e;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;e=(c[2433530]|0)+12|0;c[2433530]=e;g=((c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0)/3|0;h=g+512|0;if((h|0)<=((c[2426530]|0)+e-(c[2076596]|0)|0)){return}c[2438218]=g;Sb(h);return}else if((f|0)==3801088){L47246:do{switch(b&31|0){case 3:{i=c[2438154]|0;j=40184;break};case 17:{h=c[2438154]|0;if((h&4|0)==0){k=h;break L47246}a[9534304]=0;return};case 19:{k=c[2438154]|0;break};case 27:{a[9534320]=0;if((a[9620528]&1)==0){return}if(!(a[725016]|0)){return}a[725016]=0;if((c[2438154]&4|0)==0){return}h=c[3540996]|0;g=c[9757320+(c[1836236]<<2)>>2]|0;e=0;l=0;while(1){c[g+76+(l<<2)>>2]=h+(l<<8);m=e+1&65535;if((m&65535)>127){n=0;o=0;break}else{e=m;l=m&65535}}while(1){l=h+(o<<8)|0;c[g+76+(o+512<<2)>>2]=l;c[g+76+(o+768<<2)>>2]=l;l=n+1&65535;if((l&65535)>127){break}else{n=l;o=l&65535}}return};case 29:{a[9757280]=1;return};case 11:{g=c[2438154]|0;a[9534320]=(g&10|0)==0|0;if((a[9620528]&1)==0){return}if(a[725016]|0){return}a[725016]=1;if((g&4|0)==0){return}g=c[3541006]|0;h=c[9757320+(c[1836236]<<2)>>2]|0;l=0;e=0;while(1){c[h+76+(e<<2)>>2]=g+(e<<8);m=l+1&65535;if((m&65535)>127){p=0;q=0;break}else{l=m;e=m&65535}}while(1){e=g+(q<<8)|0;c[h+76+(q+512<<2)>>2]=e;c[h+76+(q+768<<2)>>2]=e;e=p+1&65535;if((e&65535)>127){break}else{p=e;q=e&65535}}return};case 31:{if((c[2113136]|0)==0){return}c[2113136]=0;h=c[3541048]|0;g=c[2112932]|0;c[g+16384>>2]=h;c[g+147456>>2]=h;e=h+1024|0;c[g+16388>>2]=e;c[g+147460>>2]=e;e=h+2048|0;c[g+16392>>2]=e;c[g+147464>>2]=e;e=h+3072|0;c[g+16396>>2]=e;c[g+147468>>2]=e;e=h+4096|0;c[g+16400>>2]=e;c[g+147472>>2]=e;e=h+5120|0;c[g+16404>>2]=e;c[g+147476>>2]=e;e=h+6144|0;c[g+16408>>2]=e;c[g+147480>>2]=e;e=h+7168|0;c[g+16412>>2]=e;c[g+147484>>2]=e;c[3541046]=c[9754600+(c[2113136]<<2)>>2];return};case 1:{e=c[2438154]|0;if((e&4|0)==0){i=e;j=40184;break L47246}a[9534304]=1;return};case 13:{a[9757280]=0;return};case 15:{if((c[2113136]|0)==1){return}c[2113136]=1;e=c[3541049]|0;g=c[2112932]|0;c[g+16384>>2]=e;c[g+147456>>2]=e;h=e+1024|0;c[g+16388>>2]=h;c[g+147460>>2]=h;h=e+2048|0;c[g+16392>>2]=h;c[g+147464>>2]=h;h=e+3072|0;c[g+16396>>2]=h;c[g+147468>>2]=h;h=e+4096|0;c[g+16400>>2]=h;c[g+147472>>2]=h;h=e+5120|0;c[g+16404>>2]=h;c[g+147476>>2]=h;h=e+6144|0;c[g+16408>>2]=h;c[g+147480>>2]=h;h=e+7168|0;c[g+16412>>2]=h;c[g+147484>>2]=h;c[3541046]=c[9754600+(c[2113136]<<2)>>2];return};default:{return}}}while(0);if((j|0)==40184){if((i&4|0)==0){return}if((a[9717768]&1)!=0){return}i=c[3541008]|0;j=c[2112932]|0;c[j>>2]=i;c[j+131072>>2]=i;a[9717768]=1;return}if((k&4|0)==0){return}if((a[9717768]&1)==0){return}if((c[3541128]|0)==0){k=c[3541008]|0;i=c[2112932]|0;c[i>>2]=k;c[i+131072>>2]=k}else{k=c[14164552+(c[2113146]<<2)>>2]|0;i=c[2112932]|0;c[i>>2]=k;c[i+131072>>2]=k}a[9717768]=0;return}else if((f|0)==3145728){if((b&1|0)==0){return}c[2440454]=(c[2276108]|0)-((c[2113056]|0)+(c[2113054]|0));return}else{return}}function cAk(a,b){a=a|0;b=b|0;gg[c[(c[2112932]|0)+196648>>2]&4095](a,(b&65535)>>>8&255);gg[c[(c[2112932]|0)+196648>>2]&4095](a+1|0,b&255);return}function cAl(a){a=a|0;var d=0,f=0;d=a&6;if((d|0)==0|(d|0)==2){f=b[(c[2430094]|0)+(e[4858624]|0)>>1]|0;return f|0}else if((d|0)==4){f=(c[2429860]|0)>>>1&65535;return f|0}else if((d|0)==6){f=((e[4867100]|0)+(((c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0)/(c[2113058]|0)|0)<<7|c[2113130]&7)&65535;return f|0}else{f=0;return f|0}return 0}function cAm(a){a=a|0;var b=0,d=0;if((a&1|0)!=0){b=-1;return b|0}d=a&6;if((d|0)==4){b=(c[2429860]|0)>>>9&255;return b|0}else if((d|0)==6){b=((e[4867100]|0)+(((c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0)/(c[2113058]|0)|0)|0)>>>1&255;return b|0}else if((d|0)==0|(d|0)==2){b=(e[(c[2430094]|0)+(e[4858624]|0)>>1]|0)>>>8&255;return b|0}else{b=0;return b|0}return 0}function cAn(d,f){d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;switch(d&14|0){case 8:{c[3528540]=c[3528540]&65535|(f&65535)<<16&2147418112;return};case 0:{b[4858624]=f<<1;d=c[3541066]|0;c[2430094]=d;if(f<<16>>16>=0){return}c[2430094]=d+65536;return};case 4:{c[2429860]=f<<16>>16<<1;return};case 12:{d=c[2433560]|f&7;c[2433560]=d;if((d&7|0)==7){c[8452200+(c[2394]<<2)>>2]=0;c[2276080]=0;return}do{if((d&1|0)==0){c[8452200+(c[2394]<<2)>>2]=4099;c[2276080]=768;if((c[2276079]|0)>>>0>=768){g=d;break}RH(3);g=c[2433560]|0}else{g=d}}while(0);if((g&2|0)==0){d=c[2440446]|0;c[8452200+(c[2394]<<2)>>2]=d|4096;h=c[2276080]|0;i=d<<8;c[2276080]=i;do{if((h|0)!=1792&(i|0)==1792){RH(7)}else{if(i>>>0<=(c[2276079]|0)>>>0){break}RH(d&16777215)}}while(0);j=c[2433560]|0}else{j=g}if((j&4|0)!=0){return}j=c[3528496]|0;c[8452200+(c[2394]<<2)>>2]=j|4096;g=c[2276080]|0;d=j<<8;c[2276080]=d;if((g|0)!=1792&(d|0)==1792){RH(7);return}if(d>>>0<=(c[2276079]|0)>>>0){return}RH(j&16777215);return};case 6:{j=f&65535;c[2430424]=j>>>8;do{if((c[2443922]&16|0)==0){if((j&16|0)==0){break}d=c[3528542]|0;g=c[2438208]|0;if((d|0)>=(g|0)){break}i=d-g|0;g=c[2276108]|0;if((i|0)<0&(g|0)<(-i|0)){c[2226884]=(c[2226884]|0)-g;k=0}else{c[2113056]=(c[2113056]|0)+i;c[2226884]=(c[2226884]|0)+i;k=g+i|0}c[2276108]=k}}while(0);c[2443922]=j;return};case 2:{j=e[4858624]|0;b[(c[2430094]|0)+j>>1]=f;b[4858624]=j+(c[2429860]|0)&65535;a[9718712]=(a[9718712]|a[9708024])&1;return};case 10:{j=c[3528540]&-65536|f&65535;c[3528540]=j;if((c[2443922]&32|0)==0){return}f=c[2113056]|0;k=c[2276108]|0;i=f+(c[2113054]|0)-k|0;g=i-((i|0)%(c[2113058]|0)|0)|0;i=j+8|0;j=c[2438]|0;d=gGU(j,(j|0)<0|0?-1:0,i,(i|0)<0|0?-1:0)|0;i=K;j=63;h=(i>>>0<j>>>0|i>>>0==j>>>0&d>>>0<-128>>>0?d>>>7|i<<25:2147483647)+g|0;g=(h|0)<0?2147483647:h;c[3528542]=g;h=c[2438208]|0;if((g|0)>=(h|0)){return}i=g-h|0;if((i|0)<0&(k|0)<(-i|0)){c[2226884]=(c[2226884]|0)-k;l=0}else{c[2113056]=f+i;c[2226884]=(c[2226884]|0)+i;l=k+i|0}c[2276108]=l;return};default:{return}}}function cAo(b,c){b=b|0;c=c|0;if((b&1|0)==0){cAn(b,c&255)}a[9718712]=(a[9718712]|a[9708024])&1;return}function cAp(b,d){b=b|0;d=d|0;if((a[9757280]&1)==0){return}a[(c[2405762]|0)+(b&65535^1)|0]=d;return}function cAq(d,e){d=d|0;e=e|0;if((a[9757280]&1)==0){return}b[(c[2405762]|0)+(d&65535)>>1]=e;return}function cAr(b){b=b|0;var d=0;if(!(a[801632]|0)){d=-1;return d|0}do{if((a[14164120]&64)==0){if((b&1|0)==0){d=-1}else{break}return d|0}}while(0);d=a[(c[2439434]|0)+(b&131071)|0]|0;return d|0}function cAs(b,d){b=b|0;d=d|0;if(!(a[801632]|0)){return}if((a[9718704]&1)==0){return}do{if((a[14164120]&64)==0){if((b&1|0)!=0){break}return}}while(0);a[(c[2439434]|0)+(b&131071)|0]=d;return}function cAt(b){b=b|0;var d=0,e=0;d=b&131071;if(d>>>0>16383|(b&1|0)==0){e=-1;return e|0}e=a[(c[2439434]|0)+d|0]|0;return e|0}function cAu(b,d){b=b|0;d=d|0;var e=0;e=b&131071;if(e>>>0>16383|(b&1|0)==0){return}a[(c[2439434]|0)+e|0]=d;return}function cAv(b){b=b|0;var d=0,e=0,f=0,g=0;d=c[2433560]|0;e=d|b&56;c[2433560]=e;if((e&63|0)==63){c[8452200+(c[2394]<<2)>>2]=0;c[2276080]=0;return}if((d&7|0)==7){if((e&8|0)==0){c[2433554]=23;a[849336]=1;c[8452200+(c[2394]<<2)>>2]=4100;c[2276080]=1024;if((c[2276079]|0)>>>0>=1024){return}RH(4);return}if((e&16|0)==0){c[2433554]=22;a[849336]=1;c[8452200+(c[2394]<<2)>>2]=4100;c[2276080]=1024;if((c[2276079]|0)>>>0>=1024){return}RH(4);return}if((e&32|0)!=0){return}c[2433554]=21;a[849336]=1;c[8452200+(c[2394]<<2)>>2]=4100;c[2276080]=1024;if((c[2276079]|0)>>>0>=1024){return}RH(4);return}c[2433560]=e;do{if((d&1|0)==0){c[8452200+(c[2394]<<2)>>2]=4099;c[2276080]=768;if((c[2276079]|0)>>>0>=768){f=e;break}RH(3);f=c[2433560]|0}else{f=e}}while(0);if((f&2|0)==0){e=c[2440446]|0;c[8452200+(c[2394]<<2)>>2]=e|4096;d=c[2276080]|0;b=e<<8;c[2276080]=b;do{if((d|0)!=1792&(b|0)==1792){RH(7)}else{if(b>>>0<=(c[2276079]|0)>>>0){break}RH(e&16777215)}}while(0);g=c[2433560]|0}else{g=f}if((g&4|0)!=0){return}g=c[3528496]|0;c[8452200+(c[2394]<<2)>>2]=g|4096;f=c[2276080]|0;e=g<<8;c[2276080]=e;if((f|0)!=1792&(e|0)==1792){RH(7);return}if(e>>>0<=(c[2276079]|0)>>>0){return}RH(g&16777215);return}function cAw(b){b=b|0;var d=0,e=0,f=0;d=b&65535;if((d|0)==257){e=c[2433558]&255;return e|0}else if((d|0)==23){e=c[3528530]&255;return e|0}else if((d|0)==353){b=c[2429720]|0;if(b>>>0<10){f=a[9717984+b|0]&15}else{f=0}e=(a[9731920]&1)==0?f:f|16;return e|0}else if((d|0)==259){d=c[2433558]|0;f=c[9733560+(d<<2)>>2]|0;if((d|0)==3){c[2433393]=((c[2433391]&64|0)!=0?0:240)|c[2433393]&15}else if((d|0)==13){c[2433391]=c[2433391]|32}c[2433558]=d+1&15;e=f&255;return e|0}else{e=-1;return e|0}return 0}function cAx(a){a=a|0;var b=0;if((a&65535|0)!=284){b=-1;return b|0}b=(d[14164120]|0)<<8&768^-4097;return b|0}function cAy(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0;f=i;i=i+32|0;g=f|0;switch(b&65535|0){case 15:{cAv(e);i=f;return};case 23:{c[3528530]=e&255;i=f;return};case 97:{if((e&64)==0){i=f;return}b=c[2442978]|0;if((b|0)==53245){h=c[2439436]|0;c[2113054]=(c[2113054]|0)+(h<<2);c[2439436]=h-1;if((h|0)==0){i=f;return}h=c[2433356]|0;do{j=h>>24;k=h&16777215;l=c[2112932]|0;m=c[l+((k>>>10|16384)<<2)>>2]|0;if(m>>>0>9){n=h&1023;a[m+n|0]=j&255;a[m+(n+1)|0]=j>>>8&255;o=h;p=l}else{gg[c[l+196728+(m<<2)>>2]&4095](k,j&65535);o=c[2433356]|0;p=c[2112932]|0}j=o+2|0;k=o>>>16;m=j&16777215;l=c[p+((m>>>10|16384)<<2)>>2]|0;if(l>>>0>9){n=j&1023;a[l+n|0]=k&255;a[l+(n+1)|0]=o>>>24&255;q=o;r=p}else{gg[c[p+196728+(l<<2)>>2]&4095](m,k&65535);q=c[2433356]|0;r=c[2112932]|0}k=q+4|0;m=q>>>8;l=k&16777215;n=c[r+((l>>>10|16384)<<2)>>2]|0;if(n>>>0>9){j=k&1023;a[n+j|0]=m&255;a[n+(j+1)|0]=q>>>16&255;s=q;t=r}else{gg[c[r+196728+(n<<2)>>2]&4095](l,m&65535);s=c[2433356]|0;t=c[2112932]|0}m=s+6|0;l=s&65535;n=m&16777215;j=c[t+((n>>>10|16384)<<2)>>2]|0;if(j>>>0>9){k=m&1023;a[j+k|0]=s&255;a[j+(k+1)|0]=(l&65535)>>>8&255;u=s}else{gg[c[t+196728+(j<<2)>>2]&4095](n,l);u=c[2433356]|0}h=u+8|0;c[2433356]=h;l=c[2439436]|0;c[2439436]=l-1;}while((l|0)!=0);i=f;return}else if((b|0)==58077){h=c[2439436]|0;c[2113054]=(c[2113054]|0)+h;c[2439436]=h-1;if((h|0)==0){i=f;return}h=c[2433354]|0;u=c[2433356]|0;do{t=u&16777215;s=c[2112932]|0;r=c[s+(t>>>10<<2)>>2]|0;if(r>>>0>9){v=a[r+(u&1023^1)|0]|0;w=s}else{q=gj[c[s+196608+(r<<2)>>2]&4095](t)|0;v=q;w=c[2112932]|0}q=h&16777215;t=c[w+((q>>>10|16384)<<2)>>2]|0;if(t>>>0>9){r=h&1023;a[t+r|0]=v;a[t+(r+1)|0]=0;x=w}else{gg[c[w+196728+(t<<2)>>2]&4095](q,v&255);x=c[2112932]|0}q=(c[2433354]|0)+2|0;t=(c[2433356]|0)+1|0;r=t&16777215;s=c[x+(r>>>10<<2)>>2]|0;if(s>>>0>9){y=a[s+(t&1023^1)|0]|0;z=x}else{t=gj[c[x+196608+(s<<2)>>2]&4095](r)|0;y=t;z=c[2112932]|0}t=q&16777215;r=c[z+((t>>>10|16384)<<2)>>2]|0;if(r>>>0>9){s=q&1023;a[r+s|0]=y;a[r+(s+1)|0]=0}else{gg[c[z+196728+(r<<2)>>2]&4095](t,y&255)}u=(c[2433356]|0)+2|0;c[2433356]=u;h=(c[2433354]|0)+4|0;c[2433354]=h;t=c[2439436]|0;c[2439436]=t-1;}while((t|0)!=0);i=f;return}else if((b|0)==64557){if((c[2433380]|0)==0){i=f;return}if((c[2433375]&2|0)==0){i=f;return}h=c[2433379]<<8|c[2433378];u=c[2439436]|0;if(((u<<1)+h|0)>2352){i=f;return}c[2113054]=(c[2113054]|0)+(u<<2);c[2439436]=u-1;L47601:do{if((u|0)!=0){y=9748152+h|0;z=c[2433356]|0;while(1){x=a[y]|0;v=z&16777215;w=c[2112932]|0;t=c[w+((v>>>10|16384)<<2)>>2]|0;if(t>>>0>9){a[t+(z&1023^1)|0]=x;A=z;B=w}else{gg[c[w+196648+(t<<2)>>2]&4095](v,x);A=c[2433356]|0;B=c[2112932]|0}x=A+2|0;v=a[y+1|0]|0;t=x&16777215;w=c[B+((t>>>10|16384)<<2)>>2]|0;if(w>>>0>9){a[w+(x&1023^1)|0]=v;D=A}else{gg[c[B+196648+(w<<2)>>2]&4095](t,v);D=c[2433356]|0}v=D+4|0;c[2433356]=v;t=c[2439436]|0;c[2439436]=t-1;if((t|0)==0){break L47601}y=y+2|0;z=v}}}while(0);c[2433380]=0;c[2433391]=c[2433391]|72;i=f;return}else if((b|0)==65085|(b|0)==65133){D=c[2439436]|0;c[2113054]=(c[2113054]|0)+D;c[2439436]=D-1;if((D|0)==0){i=f;return}D=c[2433354]|0;B=c[2433356]|0;do{A=B&16777215;h=c[2112932]|0;u=c[h+(A>>>10<<2)>>2]|0;if(u>>>0>9){z=B&1023;E=d[u+(z+1)|0]<<8|d[u+z|0];F=h}else{z=gj[c[h+196688+(u<<2)>>2]&4095](A)|0;E=z;F=c[2112932]|0}z=D&16777215;A=c[F+((z>>>10|16384)<<2)>>2]|0;if(A>>>0>9){u=D&1023;a[A+u|0]=E&255;a[A+(u+1)|0]=(E&65535)>>>8&255}else{gg[c[F+196728+(A<<2)>>2]&4095](z,E)}B=(c[2433356]|0)+2|0;c[2433356]=B;D=(c[2433354]|0)+2|0;c[2433354]=D;z=c[2439436]|0;c[2439436]=z-1;}while((z|0)!=0);i=f;return}else if((b|0)==65269){D=c[2439436]|0;c[2113054]=(c[2113054]|0)+(D<<1);c[2439436]=D-1;if((D|0)==0){i=f;return}D=c[2433356]|0;do{B=D>>>16;E=D&16777215;F=c[2112932]|0;z=c[F+((E>>>10|16384)<<2)>>2]|0;if(z>>>0>9){A=D&1023;a[z+A|0]=B&255;a[z+(A+1)|0]=D>>>24&255;G=D;H=F}else{gg[c[F+196728+(z<<2)>>2]&4095](E,B&65535);G=c[2433356]|0;H=c[2112932]|0}B=G+2|0;E=G&65535;z=B&16777215;F=c[H+((z>>>10|16384)<<2)>>2]|0;if(F>>>0>9){A=B&1023;a[F+A|0]=G&255;a[F+(A+1)|0]=(E&65535)>>>8&255;I=G}else{gg[c[H+196728+(F<<2)>>2]&4095](z,E);I=c[2433356]|0}D=I+4|0;c[2433356]=D;E=c[2439436]|0;c[2439436]=E-1;}while((E|0)!=0);i=f;return}else if((b|0)==65477){if((c[2433380]|0)==0){i=f;return}if((c[2433375]&2|0)==0){i=f;return}D=c[2433379]<<8|c[2433378];I=c[2439436]|0;if(((I<<1)+D|0)>2352){i=f;return}c[2113054]=(c[2113054]|0)+(I<<2);c[2439436]=I-1;L47656:do{if((I|0)!=0){H=9748152+D|0;G=c[2433356]|0;while(1){E=a[H]|0;z=G&16777215;F=c[2112932]|0;A=c[F+((z>>>10|16384)<<2)>>2]|0;if(A>>>0>9){a[A+(G&1023^1)|0]=E;J=G;K=F}else{gg[c[F+196648+(A<<2)>>2]&4095](z,E);J=c[2433356]|0;K=c[2112932]|0}E=J+1|0;z=a[H+1|0]|0;A=E&16777215;F=c[K+((A>>>10|16384)<<2)>>2]|0;if(F>>>0>9){a[F+(E&1023^1)|0]=z;L=J}else{gg[c[K+196648+(F<<2)>>2]&4095](A,z);L=c[2433356]|0}z=L+2|0;c[2433356]=z;A=c[2439436]|0;c[2439436]=A-1;if((A|0)==0){break L47656}H=H+2|0;G=z}}}while(0);c[2433380]=0;c[2433391]=c[2433391]|72;i=f;return}else if((b|0)==65485|(b|0)==65501){b=c[2439436]|0;c[2113054]=(c[2113054]|0)+b;L=b-1|0;c[2439436]=L;if((b|0)==0){i=f;return}b=c[2433356]|0;K=L;do{L=c[2438656]|0;J=L&65535;D=b&16777215;I=c[2112932]|0;G=c[I+((D>>>10|16384)<<2)>>2]|0;if(G>>>0>9){H=b&1023;a[G+H|0]=L&255;a[G+(H+1)|0]=(J&65535)>>>8&255;M=b;N=K}else{gg[c[I+196728+(G<<2)>>2]&4095](D,J);M=c[2433356]|0;N=c[2439436]|0}b=M+2|0;c[2433356]=b;K=N-1|0;c[2439436]=K;}while((N|0)!=0);i=f;return}else{i=f;return}break};case 257:{c[2433558]=e&15;i=f;return};case 259:{N=c[2433558]|0;switch(N|0){case 3:{c[2433377]=e&15;break};case 6:{c[2433380]=-1;c[2433391]=c[2433391]&-9;break};case 7:{c[2433381]=-1;c[2433391]=c[2433391]&-65;break};case 11:{K=e&255;c[2433385]=K;b=(c[2438654]|0)+150|0;M=(b|0)%4500|0;J=(b|0)%75|0;if((K&1|0)==0){c[2433394]=((b|0)/45e3|0)<<4|(((b|0)/4500|0|0)%10|0);c[2433395]=((M|0)/750|0)<<4|(((M|0)/75|0|0)%10|0);O=1;P=((J|0)/10|0)<<4|((J|0)%10|0)}else{c[2433394]=0;c[2433395]=0;O=0;P=0}c[2433396]=P;c[2433397]=O;break};case 15:{gGz(9733560,0,60);gGz(9733496,0,64);c[2433391]=255;c[2433405]=128;O=(c[2438654]|0)+150|0;P=(O|0)%4500|0;J=(O|0)%75|0;c[2433394]=((O|0)/45e3|0)<<4|(((O|0)/4500|0|0)%10|0);c[2433395]=((P|0)/750|0)<<4|(((P|0)/75|0|0)%10|0);c[2433396]=((J|0)/10|0)<<4|((J|0)%10|0);c[2433397]=1;break};default:{c[9733496+(N<<2)>>2]=e&255}}c[2433558]=N+1&15;i=f;return};case 261:{c[2429618]=e&255;i=f;return};case 289:{c[2429718]=c[2439427];c[2430092]=c[3541033];c[2429858]=c[2113115];c[2430096]=0;i=f;return};case 295:{N=((c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0)/3|0;if((N|0)>((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)){c[2438218]=N;Sb(N)}N=c[1836236]|0;if((N|0)<0){i=f;return}a[(c[9757320+(N<<2)>>2]|0)+4188|0]=1;i=f;return};case 297:{c[2430884]=c[3541021];c[2427052]=c[2430877];i=f;return};case 321:{N=c[2439426]|0;c[2429718]=N;J=c[3541032]|0;c[2430092]=J;c[2429858]=c[2113114];if((a[9720384]&1)!=0){cNQ(c[3541040]|0,J);P=0;while(1){O=P+128|0;M=P;while(1){if((M|0)>=(O|0)){Q=1;break}if((a[J+M|0]|0)==0){M=M+1|0}else{Q=0;break}}a[N+(P>>7)|0]=Q;if((O|0)<1048576){P=O}else{break}}}if((a[9720385]&1)!=0){cNQ((c[3541040]|0)+1048576|0,J+1048576|0);P=1048576;while(1){Q=P+128|0;M=P;while(1){if((M|0)>=(Q|0)){R=1;break}if((a[J+M|0]|0)==0){M=M+1|0}else{R=0;break}}a[N+(P>>7)|0]=R;if((Q|0)<2097152){P=Q}else{break}}}if((a[9720386]&1)!=0){cNQ((c[3541040]|0)+2097152|0,J+2097152|0);P=2097152;while(1){R=P+128|0;M=P;while(1){if((M|0)>=(R|0)){S=1;break}if((a[J+M|0]|0)==0){M=M+1|0}else{S=0;break}}a[N+(P>>7)|0]=S;if((R|0)<3145728){P=R}else{break}}}if((a[9720387]&1)==0){i=f;return}cNQ((c[3541040]|0)+3145728|0,J+3145728|0);P=3145728;while(1){S=P+128|0;M=P;while(1){if((M|0)>=(S|0)){T=1;break}if((a[J+M|0]|0)==0){M=M+1|0}else{T=0;break}}a[N+(P>>7)|0]=T;if((S|0)<4194304){P=S}else{break}}i=f;return};case 327:{P=((c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0)/3|0;if((P|0)>((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)){c[2438218]=P;Sb(P)}P=c[1836236]|0;if((P|0)<0){i=f;return}a[(c[9757320+(P<<2)>>2]|0)+4188|0]=0;i=f;return};case 329:{P=c[3541020]|0;c[2430884]=P;T=c[2430876]|0;c[2427052]=T;N=c[3541028]|0;J=N+131072|0;M=P;R=N;while(1){N=0;while(1){Q=N<<2;a[g+Q|0]=a[R+(N+16)|0]|0;a[g+(Q|1)|0]=a[R+(N+24)|0]|0;a[g+(Q|2)|0]=a[R+N|0]|0;a[g+(Q|3)|0]=a[R+(N+8)|0]|0;Q=N+1|0;if((Q|0)<8){N=Q}else{U=0;break}}do{N=a[g+U|0]|0;a[M+U|0]=(N&255)>>>4|N<<4;U=U+1|0;}while((U|0)<32);N=R+32|0;if(N>>>0<J>>>0){M=M+32|0;R=N}else{break}}if((T|0)==0){i=f;return}else{V=0}while(1){R=T+(V>>5)|0;a[R]=1;M=V+32|0;J=V;while(1){if((J|0)>=(M|0)){break}if((c[P+J>>2]|0)==0){J=J+4|0}else{W=40553;break}}if((W|0)==40553){W=0;a[R]=0}if((M|0)<131072){V=M}else{break}}i=f;return};case 355:{V=c[2429720]|0;if(V>>>0>=10){i=f;return}a[9717256+V|0]=e&15;i=f;return};case 357:{V=e&1;W=e&2;do{if(V<<24>>24!=0){if((a[9731920]&1)!=0){break}P=(c[2429720]|0)+1|0;c[2429720]=P;if((P|0)<=9){break}c[2429720]=0;P=a[9717256]|0;if(!(W<<24>>24!=0&P<<24>>24!=0)){break}T=P&255;P=d[9717258]|0;J=a[9717259]|0;U=J&255;g=d[9717260]|0;N=d[9717261]|0;S=d[9717262]|0;Q=d[9717263]|0;if((-6-T-(d[9717257]|0)-P-U-g-N-S-Q-(d[9717264]|0)&15|0)!=(d[9717265]|0)){break}gGz(9717984,0,10);a[9717985]=15;L47791:do{switch(T|0){case 1:{c[2437626]=14;a[1616472]=0;X=15;Y=0;Z=0;_=0;$=0;aa=0;ab=0;ac=0;break};case 2:{a[9717985]=J;switch(U|0){case 0:{O=((ah(1)|0)&255)/10|0;a[9717986]=O;b=((ah(1)|0)&255)%10|0;a[9717987]=b;K=((ah(2)|0)&255)/10|0;a[9717988]=K;D=((ah(2)|0)&255)%10|0;a[9717989]=D;G=((ah(3)|0)&255)/10|0;a[9717990]=G;I=((ah(3)|0)&255)%10|0;a[9717991]=I;H=ah(7)|0;a[9717992]=H;X=J;Y=O;Z=b;_=K;$=D;aa=G;ab=I;ac=H;break L47791;break};case 1:{H=((ah(4)|0)&255)/10|0;a[9717986]=H;I=((ah(4)|0)&255)%10|0;a[9717987]=I;G=((ah(5)|0)&255)/10|0;a[9717988]=G;D=((ah(5)|0)&255)%10|0;a[9717989]=D;K=((ah(6)|0)&255)/10|0;a[9717990]=K;b=((ah(6)|0)&255)%10|0;a[9717991]=b;O=ah(7)|0;a[9717992]=O;X=J;Y=H;Z=I;_=G;$=D;aa=K;ab=b;ac=O;break L47791;break};case 2:{a[9717986]=0;a[9717987]=0;O=ah(7)|0;a[9717992]=O;X=J;Y=0;Z=0;_=0;$=0;aa=0;ab=0;ac=O;break L47791;break};case 3:{a[9717986]=0;a[9717987]=0;O=((ah(1)|0)&255)/10|0;a[9717988]=O;b=((ah(1)|0)&255)%10|0;a[9717989]=b;K=((ah(2)|0)&255)/10|0;a[9717990]=K;D=((ah(2)|0)&255)%10|0;a[9717991]=D;X=J;Y=0;Z=0;_=O;$=b;aa=K;ab=D;ac=0;break L47791;break};case 4:{a[9717986]=0;a[9717987]=0;D=((ah(1)|0)&255)/10|0;a[9717988]=D;K=((ah(1)|0)&255)%10|0;a[9717989]=K;X=J;Y=0;Z=0;_=D;$=K;aa=0;ab=0;ac=0;break L47791;break};case 5:{a[9717986]=0;a[9717987]=0;K=((ah(1)|0)&255)/10|0;a[9717988]=K;D=((ah(1)|0)&255)%10|0;a[9717989]=D;b=((ah(2)|0)&255)/10|0;a[9717990]=b;O=((ah(2)|0)&255)%10|0;a[9717991]=O;if(((ah(3)|0)&4)==0){ad=b}else{G=b|8;a[9717990]=G;ad=G}G=((((g*10|0)+N|0)>>>0)%10|0)&255;a[9717992]=G;X=J;Y=0;Z=0;_=K;$=D;aa=ad;ab=O;ac=G;break L47791;break};case 6:{G=ah(7)|0;a[9717992]=G;X=J;Y=0;Z=0;_=0;$=0;aa=0;ab=0;ac=G;break L47791;break};case 7:{a[9717986]=0;a[9717987]=5;C=0;a[9717988]=C&255;C=C>>8;a[9717989]=C&255;C=C>>8;a[9717990]=C&255;C=C>>8;a[9717991]=C&255;X=J;Y=0;Z=5;_=0;$=0;aa=0;ab=0;ac=0;break L47791;break};default:{X=J;Y=0;Z=0;_=0;$=0;aa=0;ab=0;ac=0;break L47791}}break};case 3:{if((c[2433384]&4|0)!=0){c[2438654]=(P*45e3|0)-150+(U*4500|0)+(g*750|0)+(N*75|0)+Q+(S*10|0);c[3542110]=4}c[2437626]=1;a[1616472]=1;X=15;Y=0;Z=0;_=0;$=0;aa=0;ab=0;ac=0;break};case 4:{c[3542110]=3;X=15;Y=0;Z=0;_=0;$=0;aa=0;ab=0;ac=0;break};case 6:{c[2437626]=4;a[1616472]=0;X=15;Y=0;Z=0;_=0;$=0;aa=0;ab=0;ac=0;break};case 7:{c[2437626]=1;a[1616472]=1;X=15;Y=0;Z=0;_=0;$=0;aa=0;ab=0;ac=0;break};case 15:case 14:case 8:case 9:case 10:case 11:case 12:case 13:{c[2437626]=9;a[1616472]=0;X=15;Y=0;Z=0;_=0;$=0;aa=0;ab=0;ac=0;break};default:{X=15;Y=0;Z=0;_=0;$=0;aa=0;ab=0;ac=0}}}while(0);S=c[2437626]|0;if((S|0)==1&(c[3542110]|0)==0){c[2437626]=14;a[1616472]=0;ae=14}else{ae=S&255}a[9717984]=ae;a[9717993]=((((((((-6-ae&255)-X&255)-Y&255)-Z&255)-_&255)-$&255)-aa&255)-ab&255)-ac&15}}while(0);a[9731920]=V;i=f;return};case 365:{if((c[3541128]|0)!=0&e<<24>>24==-1){V=c[14164552+(c[2113146]<<2)>>2]|0;ac=c[2112932]|0;c[ac>>2]=V;c[ac+131072>>2]=V;i=f;return}else{V=c[3541008]|0;ac=c[2112932]|0;c[ac>>2]=V;c[ac+131072>>2]=V;i=f;return}break};case 417:{c[2429596]=(e&255)<<20&3145728;i=f;return};case 419:{c[2429904]=(e&255)<<19&524288;i=f;return};default:{i=f;return}}}function cAz(a,b){a=a|0;b=b|0;switch(a&65534|0){case 104:{c[2433354]=c[2433354]&65535|(b&65535)<<16;return};case 126:{c[2442978]=b&65535;return};case 112:{c[2439436]=c[2439436]&65535|(b&65535)<<16;return};case 14:{cAv(b&255);return};case 106:{c[2433354]=c[2433354]&-65536|b&65535;return};case 2:{c[2406704]=b&65535;return};case 114:{c[2439436]=c[2439436]&-65536|b&65535;return};case 108:{c[2438656]=b&65535;return};case 100:{c[2433356]=c[2433356]&65535|(b&65535)<<16;return};case 102:{c[2433356]=c[2433356]&-65536|b&65535;return};default:{return}}}function cAA(b){b=b|0;var d=0,e=0;d=b^1;b=c[2429618]|0;if((b|0)==4){if((d&917504)>>>0>131071){e=-1;return e|0}e=a[(c[3540996]|0)+(d>>>1&65535)|0]|0;return e|0}else if((b|0)==0){e=a[(c[3541040]|0)+((c[2429596]|0)+(d&1048575))|0]|0;return e|0}else if((b|0)==1){e=a[(c[14127400+(c[2113146]<<2)>>2]|0)+((c[2429904]|0)+(d>>>1&524287))|0]|0;return e|0}else if((b|0)==5){e=a[(c[3541028]|0)+(d>>>1&131071)|0]|0;return e|0}else{e=-1;return e|0}return 0}function cAB(a){a=a|0;var e=0,f=0;e=c[2429618]|0;if((e|0)==5){f=d[(c[3541028]|0)+(a>>>1&131071)|0]|0|-256;return f|0}else if((e|0)==0){f=b[(c[3541040]|0)+((c[2429596]|0)+(a&1048575))>>1]|0;return f|0}else if((e|0)==1){f=d[(c[14127400+(c[2113146]<<2)>>2]|0)+((c[2429904]|0)+(a>>>1&524287))|0]|0|-256;return f|0}else if((e|0)==4){if((a&917504)>>>0>131071){f=-1;return f|0}f=d[(c[3540996]|0)+(a>>>1&65535)|0]|0|-256;return f|0}else{f=-1;return f|0}return 0}function cAC(b,d){b=b|0;d=d|0;var e=0,f=0;e=b^1;b=c[2429618]|0;if((b|0)==1){a[(c[14127400+(c[2113146]<<2)>>2]|0)+((c[2429904]|0)+(e>>>1&524287))|0]=d;return}else if((b|0)==5){a[(c[3541028]|0)+(e>>>1&131071)|0]=d;return}else if((b|0)==0){f=c[2429596]|0;a[(c[3541040]|0)+(f+(e&1048575))|0]=d;a[9720384+(f>>20)|0]=1;return}else if((b|0)==4){if((e&917504)>>>0>131071){return}a[(c[3540996]|0)+(e>>>1&65535)|0]=d;return}else{return}}function cAD(d,e){d=d|0;e=e|0;var f=0,g=0;f=c[2429618]|0;if((f|0)==5){a[(c[3541028]|0)+(d>>>1&131071)|0]=e&255;return}else if((f|0)==4){if((d&917504)>>>0>131071|a[681320]){return}if((d|0)==14810610){a[681320]=1}a[(c[3540996]|0)+(d>>>1&65535)|0]=e&255;return}else if((f|0)==0){g=c[2429596]|0;b[(c[3541040]|0)+(g+(d&1048575))>>1]=e;a[9720384+(g>>20)|0]=1;return}else if((f|0)==1){a[(c[14127400+(c[2113146]<<2)>>2]|0)+((c[2429904]|0)+(d>>>1&524287))|0]=e&255;return}else{return}}function cAE(a,d){a=a|0;d=d|0;b[(c[3541128]|0)+a>>1]=d;if(a>>>0<=255){return}b[(c[3541008]|0)+a>>1]=d;return}function cAF(b,d){b=b|0;d=d|0;var e=0;e=b^1;a[(c[3541128]|0)+e|0]=d;if(b>>>0<=255){return}a[(c[3541008]|0)+e|0]=d;return}function cAG(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;b=i;i=i+1112|0;e=b|0;f=b+32|0;g=b+144|0;h=b+152|0;j=b+264|0;k=b+272|0;l=b+384|0;m=b+392|0;n=b+504|0;o=b+512|0;p=b+624|0;q=b+632|0;r=b+744|0;s=b+752|0;t=b+864|0;u=b+872|0;v=b+984|0;w=b+992|0;x=b+1104|0;if(a[632096]|0){y=(cAH()|0)!=0|0;i=b;return y|0}a[632096]=1;c[2438154]=4;z=c[2436]|0;A=c[(c[642608+(z<<2)>>2]|0)+60>>2]&-65536;do{if((A|0)==84148224){c[2438154]=13;c[2113146]=0}else{c[2113146]=0;if((A|0)!=84017152){break}c[2113146]=0;B=a[9736]|0?5860:0;C=0;while(1){D=c[9704+(C<<2)>>2]|0;if(D>>>0<B>>>0){E=40747;break}F=C+1|0;c[2113146]=F;if(F>>>0<8){C=F}else{G=5;break}}if((E|0)==40747){c[2436]=D;c[1865440]=14164288+(C*20|0);y=1;i=b;return y|0}while(1){if(G<<24>>24==0){H=0;break}if((c[9704+((G&255)<<2)>>2]|0)>>>0<B>>>0){H=G;break}else{G=G-1&255}}a[9600]=H;switch(H&255|0){case 2:case 3:{a[9600]=4;break};case 1:{a[9600]=2;break};case 0:{a[9600]=1;break};case 4:case 5:{a[9600]=6;break};default:{}}c[2436]=z;y=1;i=b;return y|0}}while(0);if((cAH()|0)!=0){y=1;i=b;return y|0}a[632096]=0;c[2113146]=0;L47954:do{if((a[9600]|0)!=0){z=0;L47955:while(1){H=0;while(1){I=9638528+(H<<2)|0;G=H+1|0;if((c[I>>2]|0)==0){break}if((G|0)<1024){H=G}else{J=z;break L47955}}H=gGq(1024)|0;c[I>>2]=H;G=c[2113146]|0;if((H|0)==0){J=G;break}c[14164040+(G<<2)>>2]=H;gGz(H|0,0,1024);z=G+1|0;c[2113146]=z;if(z>>>0>=(d[9600]|0)>>>0){break L47954}}c[14164040+(J<<2)>>2]=0;y=1;i=b;return y|0}}while(0);J=c[2414830]|0;c[3541006]=J;c[3540994]=J+131072;c[3541018]=J+262144;I=J+393216|0;if((c[2438154]&4|0)==0){c[3541130]=I;z=c[2385536]|0;c[3541010]=J+(z+393216);c[3541146]=J+(z+394240);c[3540998]=J+(z+918528);G=z+1442816|0;c[3541032]=J+G;z=G+(c[2443854]|0)|0;c[3541020]=J+z;G=z+(c[2113122]|0)|0;c[3531850]=J+G;z=G+(c[2430412]|0)|0;c[3531842]=J+z;K=J+(z+(c[2430404]|0))|0}else{c[3541146]=I;K=J+917504|0}c[2411910]=K;J=K;K=0;while(1){if((K|0)>=1024){break}L=9638528+(K<<2)|0;if((c[L>>2]|0)==0){E=40771;break}else{K=K+1|0}}do{if((E|0)==40771){K=gGq(J)|0;c[L>>2]=K;if((K|0)==0){break}gGz(K|0,0,J|0);c[2414830]=K;gGz(K|0,0,J|0);c[3541006]=K;c[3540994]=K+131072;c[3541018]=K+262144;I=K+393216|0;z=c[2438154]|0;if((z&4|0)==0){c[3541130]=I;G=c[2385536]|0;c[3541010]=K+(G+393216);H=K+(G+394240)|0;c[3541146]=H;c[3540998]=K+(G+918528);D=G+1442816|0;c[3541032]=K+D;G=D+(c[2443854]|0)|0;c[3541020]=K+G;D=G+(c[2113122]|0)|0;c[3531850]=K+D;G=D+(c[2430412]|0)|0;c[3531842]=K+G;M=K+(G+(c[2430404]|0))|0;N=H}else{c[3541146]=I;M=K+917504|0;N=I}c[2411910]=M;do{if((z&8|0)!=0){if((c[3542200]|0)==0){break}I=w+108|0;c[I>>2]=0;K=w+100|0;c[K>>2]=0;H=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[H&16383](w,155)|0;if((c[I>>2]|0)==0){break}I=c[K>>2]|0;c[x>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](x,155,0)|0;if((I|0)<1){break}gzL(N,0,155)|0}}while(0);z=c[642608+(c[2436]<<2)>>2]|0;do{if((c[z+60>>2]&-65536|0)==84017152){I=c[3541006]|0;do{if((c[3542200]|0)!=0){K=u+108|0;c[K>>2]=0;H=u+100|0;c[H>>2]=0;G=c[z+76>>2]|0;gA[G&16383](u,28)|0;if((c[K>>2]|0)==0){break}K=c[H>>2]|0;c[v>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](v,28,0)|0;if((K|0)<1){break}gzL(I,0,28)|0}}while(0);I=c[3541018]|0;do{if((c[3542200]|0)!=0){K=s+108|0;c[K>>2]=0;H=s+100|0;c[H>>2]=0;G=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[G&16383](s,29)|0;if((c[K>>2]|0)==0){break}K=c[H>>2]|0;c[t>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](t,29,0)|0;if((K|0)<1){break}gzL(I,0,29)|0}}while(0);I=c[3540994]|0;if((c[3542200]|0)==0){break}K=q+108|0;c[K>>2]=0;H=q+100|0;c[H>>2]=0;G=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[G&16383](q,30)|0;if((c[K>>2]|0)==0){break}K=c[H>>2]|0;c[r>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](r,30,0)|0;if((K|0)<1){break}gzL(I,0,30)|0}else{if((c[2438154]&8|0)!=0){a[9620528]=0;I=c[3541018]|0;do{if((c[3542200]|0)!=0){K=o+108|0;c[K>>2]=0;H=o+100|0;c[H>>2]=0;G=c[z+76>>2]|0;gA[G&16383](o,157)|0;if((c[K>>2]|0)==0){break}K=c[H>>2]|0;c[p>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](p,157,0)|0;if((K|0)<1){break}gzL(I,0,157)|0}}while(0);I=c[3540994]|0;if((c[3542200]|0)==0){break}K=m+108|0;c[K>>2]=0;H=m+100|0;c[H>>2]=0;G=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[G&16383](m,158)|0;if((c[K>>2]|0)==0){break}K=c[H>>2]|0;c[n>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](n,158,0)|0;if((K|0)<1){break}gzL(I,0,158)|0;break}I=c[3541006]|0;do{if((c[3542200]|0)!=0){K=k+108|0;c[K>>2]=0;H=k+100|0;c[H>>2]=0;G=c[z+76>>2]|0;gA[G&16383](k,156)|0;if((c[K>>2]|0)==0){break}K=c[H>>2]|0;c[l>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](l,156,0)|0;if((K|0)<1){break}gzL(I,0,156)|0}}while(0);I=c[3541018]|0;do{if((c[3542200]|0)!=0){K=h+108|0;c[K>>2]=0;H=h+100|0;c[H>>2]=0;G=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[G&16383](h,157)|0;if((c[K>>2]|0)==0){break}K=c[H>>2]|0;c[j>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](j,157,0)|0;if((K|0)<1){break}gzL(I,0,157)|0}}while(0);I=c[3540994]|0;if((c[3542200]|0)==0){break}K=f+108|0;c[K>>2]=0;H=f+100|0;c[H>>2]=0;G=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[G&16383](f,158)|0;if((c[K>>2]|0)==0){break}K=c[H>>2]|0;c[g>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](g,158,0)|0;if((K|0)<1){break}gzL(I,0,158)|0}}while(0);z=c[3541018]|0;I=z+131072|0;K=z;do{z=0;while(1){H=z<<2;a[e+H|0]=a[K+(z+16)|0]|0;a[e+(H|1)|0]=a[K+(z+24)|0]|0;a[e+(H|2)|0]=a[K+z|0]|0;a[e+(H|3)|0]=a[K+(z+8)|0]|0;H=z+1|0;if((H|0)<8){z=H}else{O=0;break}}do{z=a[e+O|0]|0;a[K+O|0]=(z&255)>>>4|z<<4;O=O+1|0;}while((O|0)<32);K=K+32|0;}while(K>>>0<I>>>0);c[2113310]=9999;cAc(a[14164120]&31);y=cAI()|0;i=b;return y|0}}while(0);c[2414830]=0;y=1;i=b;return y|0}function cAH(){var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0;e=i;i=i+2608|0;f=e|0;g=e+128|0;h=e+240|0;j=e+248|0;k=e+360|0;l=e+368|0;m=e+480|0;n=e+488|0;o=e+600|0;p=e+608|0;q=e+720|0;r=e+728|0;s=e+840|0;t=e+952|0;u=e+960|0;v=e+1072|0;w=e+1080|0;x=e+1192|0;y=e+1200|0;z=e+1232|0;A=e+1344|0;B=e+1352|0;C=e+1464|0;D=e+1576|0;E=e+1584|0;F=e+1696|0;G=e+1808|0;H=e+1920|0;I=e+2032|0;J=e+2144|0;K=e+2256|0;L=e+2368|0;M=e+2480|0;N=e+2488|0;O=e+2496|0;c[L+108>>2]=0;P=L+100|0;c[P>>2]=0;Q=K+108|0;c[Q>>2]=0;c[K+100>>2]=0;R=-1;while(1){S=R+1|0;if((gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](K,S)|0)!=0){T=-1;U=0;break}if((c[Q>>2]&7|0)!=1&(S|0)<128){R=S}else{V=40832;break}}do{if((V|0)==40832){if((S|0)>126){T=-1;U=0;break}else{W=-1}do{W=W+1|0;if((gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](K,W+S|0)|0)!=0){break}}while((c[Q>>2]&7|0)==1);T=S;U=(W|0)<0?0:W}}while(0);W=J+108|0;c[W>>2]=0;c[J+100>>2]=0;S=-1;while(1){X=S+1|0;if((gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](J,X)|0)!=0){Y=-1;break}if((c[W>>2]&7|0)!=2&(X|0)<128){S=X}else{V=40839;break}}L48051:do{if((V|0)==40839){if((X|0)>126){Y=-1;break}else{Z=-1}while(1){S=Z+1|0;if((gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](J,S+X|0)|0)!=0){Y=X;break L48051}if((c[W>>2]&7|0)==2){Z=S}else{Y=X;break}}}}while(0);X=I+108|0;c[X>>2]=0;c[I+100>>2]=0;Z=-1;while(1){_=Z+1|0;if((gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](I,_)|0)!=0){$=-1;aa=0;break}if((c[X>>2]&7|0)!=3&(_|0)<128){Z=_}else{V=40845;break}}do{if((V|0)==40845){if((_|0)>126){$=-1;aa=0;break}else{ab=-1}do{ab=ab+1|0;if((gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](I,ab+_|0)|0)!=0){break}}while((c[X>>2]&7|0)==3);$=_;aa=(ab|0)<0?0:ab}}while(0);ab=H+108|0;c[ab>>2]=0;c[H+100>>2]=0;_=-1;while(1){ac=_+1|0;if((gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](H,ac)|0)!=0){ad=-1;break}if((c[ab>>2]&7|0)!=4&(ac|0)<128){_=ac}else{V=40852;break}}L48070:do{if((V|0)==40852){if((ac|0)>126){ad=-1;break}else{ae=-1}while(1){_=ae+1|0;if((gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](H,_+ac|0)|0)!=0){ad=ac;break L48070}if((c[ab>>2]&7|0)==4){ae=_}else{ad=ac;break}}}}while(0);ac=G+108|0;c[ac>>2]=0;c[G+100>>2]=0;ae=-1;while(1){af=ae+1|0;if((gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](G,af)|0)!=0){ah=-1;ai=0;break}if((c[ac>>2]&7|0)!=5&(af|0)<128){ae=af}else{V=40858;break}}do{if((V|0)==40858){if((af|0)>126){ah=-1;ai=0;break}else{aj=-1}do{aj=aj+1|0;if((gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](G,aj+af|0)|0)!=0){break}}while((c[ac>>2]&7|0)==5);ah=af;ai=(aj|0)<0?0:aj}}while(0);aj=F+108|0;c[aj>>2]=0;c[F+100>>2]=0;af=-1;while(1){ak=af+1|0;if((gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](F,ak)|0)!=0){al=0;break}if((c[aj>>2]&7|0)!=6&(ak|0)<128){af=ak}else{V=40865;break}}do{if((V|0)==40865){if((ak|0)>126){al=0;break}else{am=-1}do{am=am+1|0;if((gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](F,am+ak|0)|0)!=0){break}}while((c[aj>>2]&7|0)==6);al=(am|0)<0?0:am}}while(0);am=c[2113146]|0;c[9542144+(am<<2)>>2]=0;if((U|0)>0){aj=0;do{gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](L,aj+T|0)|0;an=c[2113146]|0;ak=9542144+(an<<2)|0;ao=(c[ak>>2]|0)+(c[P>>2]|0)|0;c[ak>>2]=ao;aj=aj+1|0;}while((aj|0)<(U|0));ap=an;aq=ao+1048575&-1048576}else{ap=am;aq=0}c[9542144+(ap<<2)>>2]=aq;c[9775416+(ap<<2)>>2]=0;ap=c[642608+(c[2436]<<2)>>2]|0;do{if((c[ap+60>>2]&4|0)!=0){aq=c[ap+76>>2]|0;gA[aq&16383](L,$)|0;if((aa|0)==2){c[9775416+(c[2113146]<<2)>>2]=6291456;break}else if((aa|0)!=4){break}aq=$+2|0;am=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[am&16383](L,aq)|0;if((c[P>>2]|0)!=524288){break}c[9775416+(c[2113146]<<2)>>2]=6291456}}while(0);ap=c[2113146]|0;aq=c[9775416+(ap<<2)>>2]|0;if((aq|0)==0){am=aa-2|0;if((am|0)>0){ao=0;while(1){gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](L,ao+$|0)|0;an=c[P>>2]|0;aj=c[2113146]|0;ak=9775416+(aj<<2)|0;F=c[ak>>2]|0;if(an>>>0>F>>>0){c[ak>>2]=an;ar=an}else{ar=F}F=ao+2|0;if((F|0)<(am|0)){ao=F}else{as=ar;at=aj;break}}}else{as=0;at=ap}ar=9775416+(at<<2)|0;c[ar>>2]=ag(as,am)|0;as=c[642608+(c[2436]<<2)>>2]|0;if((fa(550448,c[as>>2]|0)|0)==0){c[ar>>2]=37748736}ar=am+$|0;am=c[as+76>>2]|0;gA[am&16383](L,ar)|0;ar=c[2113146]|0;am=9775416+(ar<<2)|0;as=(c[am>>2]|0)+(c[P>>2]<<1)|0;c[am>>2]=as;au=ar;av=as}else{au=ap;av=aq}aq=8452456+(au<<2)|0;c[aq>>2]=1;if(av>>>0>1){ap=1;while(1){aw=ap<<1;if(aw>>>0<av>>>0){ap=aw}else{break}}c[aq>>2]=aw;ax=(ap>>>6&33554431)-1|0}else{ax=-1}c[aq>>2]=ax;c[8452552+(au<<2)>>2]=av>>>7;av=8452488+(au<<2)|0;do{if((c[av>>2]|0)==0){if((Y|0)>0){ax=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ax&16383](L,Y)|0;ax=c[2113146]|0;c[8452488+(ax<<2)>>2]=c[P>>2];ay=ax;break}else{c[av>>2]=524288;ay=au;break}}else{ay=au}}while(0);c[9721616+(ay<<2)>>2]=0;c[9721648+(ay<<2)>>2]=0;do{if((ah|0)>-1){au=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[au&16383](L,ah)|0;au=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[au&16383](M,ah,0)|0;au=c[2113146]|0;c[9721648+(au<<2)>>2]=c[P>>2];if((ai|0)>1){av=ai-1+ah|0;ax=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ax&16383](L,av)|0;ax=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ax&16383](M,av,0)|0;av=(al|0)==0;ax=c[M>>2]|0;aq=0;while(1){ap=a[ax+aq|0]|0;if((ap<<24>>24|0)==0|(ap<<24>>24|0)==45|(ap<<24>>24|0)==95){break}aq=aq+1|0}if(av){ap=c[2113146]|0;aw=9721648+(ap<<2)|0;as=ag(c[aw>>2]|0,(a[ax+(aq+2)|0]|0)-49|0)|0;c[aw>>2]=as;az=ap;aA=as}else{as=c[2113146]|0;ap=9721648+(as<<2)|0;aw=ag(c[ap>>2]|0,(a[ax+(aq+3)|0]|0)-49|0)|0;c[ap>>2]=aw;az=as;aA=aw}c[9721648+(az<<2)>>2]=(c[P>>2]|0)+aA;aB=az}else{aB=au}if((al|0)==0){aC=aB;break}aw=ah+ai|0;as=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[as&16383](L,aw)|0;as=ag(c[P>>2]|0,al-1|0)|0;c[9721616+(c[2113146]<<2)>>2]=as;as=aw-1+al|0;aw=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aw&16383](L,as)|0;as=c[2113146]|0;aw=9721616+(as<<2)|0;c[aw>>2]=(c[aw>>2]|0)+(c[P>>2]|0);aC=as}else{aC=ay}}while(0);ay=c[642608+(c[2436]<<2)>>2]|0;P=c[ay>>2]|0;if((fa(320040,P|0)|0)==0){L=9721648+(aC<<2)|0;c[L>>2]=(c[L>>2]|0)+8388608;aD=c[ay>>2]|0}else{aD=P}if((fa(137384,aD|0)|0)==0){P=9721648+(aC<<2)|0;c[P>>2]=(c[P>>2]|0)+8388608;aE=c[ay>>2]|0}else{aE=aD}if((fa(305864,aE|0)|0)==0){aD=9721648+(aC<<2)|0;c[aD>>2]=(c[aD>>2]|0)+4194304;aF=c[ay>>2]|0}else{aF=aE}if((fa(303648,aF|0)|0)==0){aE=9721648+(aC<<2)|0;c[aE>>2]=(c[aE>>2]|0)+4194304;aG=c[ay>>2]|0}else{aG=aF}if((fa(302120,aG|0)|0)==0){aF=9721648+(aC<<2)|0;c[aF>>2]=(c[aF>>2]|0)+4194304;aH=c[ay>>2]|0}else{aH=aG}if((fa(300872,aH|0)|0)==0){aG=9721648+(aC<<2)|0;c[aG>>2]=(c[aG>>2]|0)+4194304;aI=c[ay>>2]|0}else{aI=aH}if((fa(182424,aI|0)|0)==0){c[9721648+(aC<<2)>>2]=3670016;aJ=c[ay>>2]|0}else{aJ=aI}if((fa(333048,aJ|0)|0)==0){c[9721648+(aC<<2)>>2]=2097152;aK=c[ay>>2]|0}else{aK=aJ}if((fa(177688,aK|0)|0)==0){c[9721648+(aC<<2)>>2]=1572864;aL=c[ay>>2]|0}else{aL=aK}if((fa(66032,aL|0)|0)==0){c[9721648+(aC<<2)>>2]=3145728;aM=c[ay>>2]|0}else{aM=aL}if((fa(147696,aM|0)|0)==0){c[9721648+(aC<<2)>>2]=8388608}aM=c[9775416+(aC<<2)>>2]|0;aL=c[8452456+(aC<<2)>>2]<<7;ay=aM>>>0<aL>>>0?aL+128|0:aM;aM=0;while(1){if((aM|0)>=1024){aN=aC;break}aO=9638528+(aM<<2)|0;if((c[aO>>2]|0)==0){V=40928;break}else{aM=aM+1|0}}do{if((V|0)==40928){aM=gGq(ay)|0;c[aO>>2]=aM;if((aM|0)==0){aN=c[2113146]|0;break}gGz(aM|0,0,ay|0);aC=c[2113146]|0;c[14164128+(aC<<2)>>2]=aM;aL=c[642608+(c[2436]<<2)>>2]|0;aK=c[aL+60>>2]|0;aJ=c[9775416+(aC<<2)>>2]|0;L48188:do{if((aK&24|0)==0){do{if((fa(550448,c[aL>>2]|0)|0)==0){aP=0;aQ=aK}else{aC=aa-2|0;if((aC|0)<=0){aP=0;aQ=aK;break}aI=r+100|0;aH=0;aG=0;aF=aL;do{gA[c[aF+76>>2]&16383](r,aG+$|0)|0;aE=c[aI>>2]|0;aH=aE>>>0>aH>>>0?aE:aH;aG=aG+1|0;aF=c[642608+(c[2436]<<2)>>2]|0}while((aG|0)<(aC|0));aP=aH;aQ=c[aF+60>>2]|0}}while(0);if((aQ&1024|0)!=0){aC=aa>>2;if((aC|0)<=0){V=41012;break}aG=$+1|0;aI=$+2|0;aE=$+3|0;aD=aC-1|0;P=r+100|0;L=0;aB=0;while(1){az=aB<<2;aA=az+$|0;R6(aM+L|0,aA,4)|0;R6(aM+(L|2)|0,aG+az|0,4)|0;R6(aM+(L|1)|0,aI+az|0,4)|0;R6(aM+(L|3)|0,aE+az|0,4)|0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,aA)|0;aA=aB+1|0;if((aA|0)<(aC|0)){L=(((aB|0)<(aD|0)?aP:c[P>>2]|0)<<2)+L|0;aB=aA}else{V=41012;break L48188}}}aB=aa>>1;if((aB|0)<=0){V=41012;break}L=$+1|0;P=aB-1|0;aD=r+100|0;aC=0;aE=0;while(1){aI=aE<<1;aG=aI+$|0;R6(aM+aC|0,aG,2)|0;R6(aM+(aC|1)|0,L+aI|0,2)|0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,aG)|0;if((aE|0)<(P|0)){if((fa(550448,c[c[642608+(c[2436]<<2)>>2]>>2]|0)|0)==0){V=41010}else{aR=aP}}else{V=41010}if((V|0)==41010){V=0;aR=c[aD>>2]|0}aG=aE+1|0;if((aG|0)<(aB|0)){aC=(aR<<1)+aC|0;aE=aG}else{V=41012;break}}}else{gA[c[aL+76>>2]&16383](r,$)|0;aE=c[r+100>>2]|0;aC=c[(c[642608+(c[2436]<<2)>>2]|0)+60>>2]|0;do{if((aC&8|0)==0){if((aC&16|0)==0){break}c[2077650]=1088160;c[2077648]=1087904;c[2077646]=1087648;c[2077644]=1087392;c[2383586]=682696;c[2383584]=682440;c[2383590]=681960;c[2383588]=681704;c[2383592]=684832}else{c[2077650]=2680704;c[2077648]=2680448;c[2077646]=2680192;c[2077644]=2679936;c[2383586]=684576;c[2383584]=684320;c[2383590]=683584;c[2383588]=683328;c[2383592]=697944}}while(0);aC=aE<<1;aB=0;while(1){if((aB|0)>=1024){break L48188}aS=9638528+(aB<<2)|0;if((c[aS>>2]|0)==0){break}else{aB=aB+1|0}}aB=gGq(aC)|0;c[aS>>2]=aB;if((aB|0)==0){break}gGz(aB|0,0,aC|0);if((c[(c[642608+(c[2436]<<2)>>2]|0)+60>>2]&-65536|0)==84148224){aD=0;while(1){if((aD|0)>=1024){break L48188}aT=9638528+(aD<<2)|0;if((c[aT>>2]|0)==0){break}else{aD=aD+1|0}}aD=gGq(aC)|0;c[aT>>2]=aD;if((aD|0)==0){break}gGz(aD|0,0,aC|0);aU=aD}else{aU=0}aD=aa>>1;if((aD|0)>0){P=(aE|0)==33554432;L=aU+aE|0;aG=$+1|0;aI=aE>>>1;aA=(aI|0)==0;az=aB;M=aU;as=(aE|0)==0;aw=aM+67108864|0;ap=(aC|0)==0;ar=aU;am=aB;at=aB+1|0;ao=n+108|0;aj=n+100|0;F=p+108|0;an=p+100|0;ak=j+108|0;af=j+100|0;ac=g+108|0;G=g+100|0;ae=l+108|0;ab=l+100|0;H=0;while(1){_=c[642608+(c[2436]<<2)>>2]|0;X=H<<1;I=X+$|0;do{if((c[_+60>>2]&-65536|0)==84148224){if(P){do{if((c[3542200]|0)!=0){c[F>>2]=0;c[an>>2]=0;Z=c[_+76>>2]|0;gA[Z&16383](p,I)|0;if((c[F>>2]|0)==0){break}Z=c[an>>2]|0;c[q>>2]=9534384;W=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[W&16383](q,I,0)|0;if((Z|0)<1){break}gzL(aU,0,I)|0}}while(0);Z=X+aG|0;if((c[3542200]|0)==0){break}c[ao>>2]=0;c[aj>>2]=0;W=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[W&16383](n,Z)|0;if((c[ao>>2]|0)==0){break}W=c[aj>>2]|0;c[o>>2]=9534384;J=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[J&16383](o,Z,0)|0;if((W|0)<1){break}gzL(L,0,Z)|0;break}do{if((c[3542200]|0)!=0){c[ae>>2]=0;c[ab>>2]=0;Z=c[_+76>>2]|0;gA[Z&16383](l,I)|0;if((c[ae>>2]|0)==0){break}Z=c[ab>>2]|0;c[m>>2]=9534384;W=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[W&16383](m,I,0)|0;if((Z|0)<1){break}gzL(aB,0,I)|0}}while(0);if(aA){Z=X+aG|0;if((c[3542200]|0)==0){break}c[ak>>2]=0;c[af>>2]=0;W=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[W&16383](j,Z)|0;if((c[ak>>2]|0)==0){break}W=c[af>>2]|0;c[k>>2]=9534384;J=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[J&16383](k,Z,0)|0;if((W|0)<1){break}gzL(aB,0,Z)|0;break}else{aV=0}do{b[M+(aV<<1<<1)>>1]=b[az+(aV<<1)>>1]|0;aV=aV+1|0;}while(aV>>>0<aI>>>0);Z=X+aG|0;do{if((c[3542200]|0)==0){aW=0}else{c[ac>>2]=0;c[G>>2]=0;W=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[W&16383](g,Z)|0;if((c[ac>>2]|0)==0){aW=0;break}W=c[G>>2]|0;c[h>>2]=9534384;J=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[J&16383](h,Z,0)|0;if((W|0)<1){aW=0;break}gzL(aB,0,Z)|0;aW=0}}while(0);do{b[M+((aW<<1|1)<<1)>>1]=b[az+(aW<<1)>>1]|0;aW=aW+1|0;}while(aW>>>0<aI>>>0)}else{R6(aB,I,2)|0;R6(at,X+aG|0,2)|0}}while(0);X=ag(H,aC)|0;do{if(X>>>0<67108864){if(ap){break}I=(c[642608+(c[2436]<<2)>>2]|0)+60|0;_=d[8452536]|0;aF=0;while(1){aH=c[I>>2]|0;if((aH&-65536|0)==84148224){Z=aF+4194304|0;do{if((aH&128|0)==0){W=(aF|0)/4|0;J=(Z|0)/4|0;if((W|0)<(J|0)){aX=W}else{break}do{c[am+(aX<<2)>>2]=c[ar+(((aX<<14&16384|aX&-2097152|aX>>>5&1|aX>>>11<<19&524288|aX>>>4<<20&1048576|aX>>>14<<18&262144|aX>>>8<<17&131072|aX>>>12<<16&65536|aX>>>16<<15&32768|aX>>>10<<13&8192|aX>>>19<<12&4096|aX>>>3<<11&2048|aX>>>6<<10&1024|aX>>>2<<9&512|aX>>>7<<8&256|aX>>>13<<7&128|aX>>>1<<6&64|aX>>>17<<5&32|aX>>>9<<4&16|aX>>>20<<3&8|aX>>>15<<2&4|aX>>>18<<1&2)^821539)<<2)>>2];aX=aX+1|0;}while((aX|0)<(J|0))}else{if((aF|0)==2143289344){break}else{aY=aF}do{J=aB+aY|0;W=aU+(aY>>>22<<21&2097152|aY&-6814976|aY>>>18<<22&4194304|aY>>>17<<18&262144|aY>>>16<<17&131072|aY>>>15<<16&65536|aY>>>14<<15&32768|aY>>>13<<14&16384|aY>>>12<<13&8192|aY>>>11<<12&4096|aY>>>10<<11&2048|aY>>>21<<10&1024)|0;gGC(J|0,W|0,256)|0;aY=aY+256|0;}while((aY|0)<(Z|0))}}while(0);aH=aB+aF|0;cNP(aH);aZ=aH;a_=Z}else{aZ=aB+aF|0;a_=aF+4194304|0}cz2(_,aM,aZ,aF+X|0,aJ);if(a_>>>0<aC>>>0){aF=a_}else{break}}}else{if(as){break}aF=d[8452536]|0;_=0;while(1){I=_+4194304|0;if((_|0)!=2143289344){aH=_;do{W=aB+aH|0;J=aU+(aH>>>22<<21&2097152|aH&-6814976|aH>>>18<<22&4194304|aH>>>17<<18&262144|aH>>>16<<17&131072|aH>>>15<<16&65536|aH>>>14<<15&32768|aH>>>13<<14&16384|aH>>>12<<13&8192|aH>>>11<<12&4096|aH>>>10<<11&2048|aH>>>21<<10&1024)|0;gGC(W|0,J|0,256)|0;aH=aH+256|0;}while((aH|0)<(I|0))}aH=aB+_|0;cNP(aH);cz2(aF,aw,aH,_,16777216);if(I>>>0<aE>>>0){_=I}else{break}}}}while(0);X=H+1|0;if((X|0)<(aD|0)){H=X}else{a$=0;break}}}else{a$=0}while(1){if((a$|0)>=1024){a0=0;break}a1=9638528+(a$<<2)|0;if((c[a1>>2]|0)==(aU|0)){V=40993;break}else{a$=a$+1|0}}if((V|0)==40993){gGr(aU);c[a1>>2]=0;a0=0}while(1){if((a0|0)>=1024){V=41012;break L48188}a2=9638528+(a0<<2)|0;if((c[a2>>2]|0)==(aB|0)){break}else{a0=a0+1|0}}gGr(aB);c[a2>>2]=0;V=41012}}while(0);L48302:do{if((V|0)==41012){if((c[(c[642608+(c[2436]<<2)>>2]|0)+60>>2]&4|0)==0){break}else{a3=0}while(1){if((a3|0)>=1024){break L48302}a4=9638528+(a3<<2)|0;if((c[a4>>2]|0)==0){break}else{a3=a3+1|0}}aB=gGq(6291456)|0;c[a4>>2]=aB;if((aB|0)==0){break}gGz(aB|0,0,6291456);aJ=2097152;do{a[aB+aJ|0]=a[aM+aJ|0]|0;aJ=aJ+1|0;}while((aJ|0)<6291456);aJ=aB+4194304|0;aL=aM+2097152|0;aK=aB+2097152|0;au=aM+4194304|0;aq=0;while(1){b[aL+(aq<<1)>>1]=b[aJ+(aq<<1)>>1]|0;b[au+(aq<<1)>>1]=b[aK+(aq<<1)>>1]|0;ax=aq+1|0;if((ax|0)<1048576){aq=ax}else{a5=0;break}}while(1){if((a5|0)>=1024){break L48302}a6=9638528+(a5<<2)|0;if((c[a6>>2]|0)==(aB|0)){break}else{a5=a5+1|0}}gGr(aB);c[a6>>2]=0}}while(0);aM=c[2113146]|0;aq=c[8452488+(aM<<2)>>2]|0;aK=0;while(1){if((aK|0)>=1024){a7=aM;break}a8=9638528+(aK<<2)|0;if((c[a8>>2]|0)==0){V=41026;break}else{aK=aK+1|0}}do{if((V|0)==41026){aK=gGq(aq)|0;c[a8>>2]=aK;if((aK|0)==0){a7=c[2113146]|0;break}gGz(aK|0,0,aq|0);aM=c[2113146]|0;c[14164080+(aM<<2)>>2]=aK;do{if((Y|0)==-1){au=c[14164128+(aM<<2)>>2]|0;aJ=c[9775416+(aM<<2)>>2]|0;aL=c[8452488+(aM<<2)>>2]|0;do{if((aL|0)==1048576){ax=aJ-524288|0;av=aJ-17301504|0;H=0;do{aD=(H<<2&28|H&-32|H>>>2&2|H>>>4&1)^2;a[aK+H|0]=a[au+(av+aD)|0]|0;a[aK+(H+524288)|0]=a[au+(ax+aD)|0]|0;H=H+1|0;}while((H|0)<524288)}else{H=aJ-aL|0;if((aL|0)>0){a9=0}else{break}do{a[aK+a9|0]=a[au+(H+((a9<<2&28|a9&-32|a9>>>2&2|a9>>>4&1)^2))|0]|0;a9=a9+1|0;}while((a9|0)<(aL|0))}}while(0);if((c[(c[642608+(c[2436]<<2)>>2]|0)+60>>2]&-65536|0)==84148224&(aL|0)>0){ba=0}else{break}do{au=aK+ba|0;aJ=d[au]^210;a[au]=(aJ>>>7<<5|aJ<<6&64|aJ>>>3&1|aJ>>>4<<7&128|aJ>>>2<<4&16|aJ>>>5<<3&8|aJ>>>1<<2&4|aJ>>>6<<1&2)&255;ba=ba+1|0;}while((ba|0)<(aL|0))}else{if((c[3542200]|0)==0){break}aL=w+108|0;c[aL>>2]=0;aJ=w+100|0;c[aJ>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](w,Y)|0;if((c[aL>>2]|0)==0){break}aL=c[aJ>>2]|0;c[x>>2]=9534384;gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](x,Y,0)|0;if((aL|0)<1){break}gzL(aK,0,Y)|0}}while(0);aK=c[2113146]|0;aM=c[9542144+(aK<<2)>>2]|0;aB=0;while(1){if((aB|0)>=1024){bb=aK;break}bc=9638528+(aB<<2)|0;if((c[bc>>2]|0)==0){V=41044;break}else{aB=aB+1|0}}do{if((V|0)==41044){aB=gGq(aM)|0;c[bc>>2]=aB;if((aB|0)==0){bb=c[2113146]|0;break}gGz(aB|0,0,aM|0);aK=c[2113146]|0;c[14164520+(aK<<2)>>2]=aB;c[3541128]=aB;c[14164552+(aK<<2)>>2]=aB;aK=c[642608+(c[2436]<<2)>>2]|0;if((c[aK+60>>2]&64|0)==0){cNO(T,U,aB);bd=0}else{aL=aB+786432|0;do{if((c[3542200]|0)!=0){aB=u+108|0;c[aB>>2]=0;aJ=u+100|0;c[aJ>>2]=0;au=c[aK+76>>2]|0;gA[au&16383](u,0)|0;if((c[aB>>2]|0)==0){break}aB=c[aJ>>2]|0;c[v>>2]=9534384;aJ=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aJ&16383](v,0,0)|0;if((aB|0)<1){break}gzL(aL,0,0)|0}}while(0);cNO(T+1|0,U-1|0,(c[3541128]|0)+1048576|0);bd=0}while(1){if((bd|0)>=1024){break}be=9638528+(bd<<2)|0;if((c[be>>2]|0)==0){V=41056;break}else{bd=bd+1|0}}do{if((V|0)==41056){aL=gGq(524288)|0;c[be>>2]=aL;if((aL|0)==0){break}gGz(aL|0,0,524288);c[14163992+(c[2113146]<<2)>>2]=aL;c[3540996]=aL;do{if((c[3542200]|0)!=0){aK=s+108|0;c[aK>>2]=0;aB=s+100|0;c[aB>>2]=0;aJ=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aJ&16383](s,ad)|0;if((c[aK>>2]|0)==0){break}aK=c[aB>>2]|0;c[t>>2]=9534384;aB=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aB&16383](t,ad,0)|0;if((aK|0)<1){break}gzL(aL,0,ad)|0}}while(0);L48371:do{if((c[(c[642608+(c[2436]<<2)>>2]|0)+60>>2]&256|0)!=0){aL=c[3540996]|0;aK=0;while(1){if((aK|0)>=1024){bf=0;break}bg=9638528+(aK<<2)|0;if((c[bg>>2]|0)==0){V=41066;break}else{aK=aK+1|0}}do{if((V|0)==41066){aK=gGq(524288)|0;c[bg>>2]=aK;if((aK|0)==0){bf=0;break}gGz(aK|0,0,524288);bf=aK}}while(0);aK=0;I=0;do{bh=(d[aL+I|0]|0)+aK|0;I=I+1|0;aK=bh&65535;}while((I|0)<65536);I=aK<<14&16384|bh>>>5&1|aK>>>15<<10|bh>>>13<<8&256|bh>>>10<<7&128|bh>>>6<<4&16|bh>>>11<<3&8|bh>>>9<<2&4|bh>>>14<<1&2|aK>>>12<<15&32768|aK>>>2<<13&8192|aK>>>4<<12&4096|aK>>>8<<11&2048|aK>>>7<<9&512|aK>>>1<<6&64|aK>>>3<<5&32;aB=0;do{aJ=aB>>>16&7;au=aB&65535^I;H=au>>>((c[596288+(aJ<<6)>>2]|0)>>>0)<<14&16384|au>>>((c[596292+(aJ<<6)>>2]|0)>>>0)<<15&32768|au>>>((c[596284+(aJ<<6)>>2]|0)>>>0)<<13&8192|au>>>((c[596280+(aJ<<6)>>2]|0)>>>0)<<12&4096|au>>>((c[596276+(aJ<<6)>>2]|0)>>>0)<<11&2048|au>>>((c[596272+(aJ<<6)>>2]|0)>>>0)<<10&1024|au>>>((c[596268+(aJ<<6)>>2]|0)>>>0)<<9&512|au>>>((c[596264+(aJ<<6)>>2]|0)>>>0)<<8&256;ax=(H|au>>>((c[596260+(aJ<<6)>>2]|0)>>>0)<<7&128|au>>>((c[596256+(aJ<<6)>>2]|0)>>>0)<<6&64|au>>>((c[596252+(aJ<<6)>>2]|0)>>>0)<<5&32|au>>>((c[596248+(aJ<<6)>>2]|0)>>>0)<<4&16|au>>>((c[596244+(aJ<<6)>>2]|0)>>>0)<<3&8|au>>>((c[596240+(aJ<<6)>>2]|0)>>>0)<<2&4|au>>>((c[596236+(aJ<<6)>>2]|0)>>>0)<<1&2|au>>>((c[596232+(aJ<<6)>>2]|0)>>>0)&1)^d[942352+(H>>>8&255)|0];H=ax^d[793712+(ax&255)|0]<<8;a[bf+aB|0]=a[aL+(H&1|aJ<<16|H>>>15<<14&16384|H>>>7<<15&32768|H>>>14<<13&8192|H>>>6<<12&4096|H>>>5<<11&2048|H>>>13<<10&1024|H>>>12<<9&512|H>>>4<<8&256|H>>>11<<7&128|H>>>3<<6&64|H>>>10<<5&32|H>>>2<<4&16|H>>>9<<3&8|H>>>1<<2&4|H>>>8<<1&2)|0]|0;aB=aB+1|0;}while((aB|0)<524288);gGC(aL|0,bf|0,524288)|0;aB=0;while(1){if((aB|0)>=1024){break L48371}bi=9638528+(aB<<2)|0;if((c[bi>>2]|0)==(bf|0)){break}else{aB=aB+1|0}}gGr(bf);c[bi>>2]=0}}while(0);aB=c[1865440]|0;do{if((aB|0)!=0){aL=c[aB>>2]|0;if((aL|0)==0){break}gu[aL&16383]()}}while(0);aB=c[2113146]|0;aL=c[8452488+(aB<<2)>>2]|0;I=c[14164080+(aB<<2)>>2]|0;aK=I+aL|0;if((aL|0)>0){aL=I;do{I=0;while(1){H=I<<2;a[y+H|0]=a[aL+(I+16)|0]|0;a[y+(H|1)|0]=a[aL+(I+24)|0]|0;a[y+(H|2)|0]=a[aL+I|0]|0;a[y+(H|3)|0]=a[aL+(I+8)|0]|0;H=I+1|0;if((H|0)<8){I=H}else{bj=0;break}}do{I=a[y+bj|0]|0;a[aL+bj|0]=(I&255)>>>4|I<<4;bj=bj+1|0;}while((bj|0)<32);aL=aL+32|0;}while(aL>>>0<aK>>>0)}aK=c[14164128+(aB<<2)>>2]|0;aL=f;I=c[9775416+(aB<<2)>>2]>>3;H=0;do{aJ=ag(H,I)|0;ax=aJ+I|0;au=aK+ax|0;if((aJ|0)<(ax|0)){ax=aK+aJ|0;av=0;while(1){aD=(av<<7)+aJ|0;aE=0;do{aw=aE<<2;as=d[ax+(aw+67)|0]|0;aC=d[ax+(aw+65)|0]|0;ar=d[ax+(aw+66)|0]|0;am=d[ax+(aw+64)|0]|0;ap=0;aG=0;do{ap=(as>>>(aG>>>0)<<3&8|am>>>(aG>>>0)&1|aC>>>(aG>>>0)<<2&4|ar>>>(aG>>>0)<<1&2)<<(aG<<2)|ap;aG=aG+1|0;}while((aG|0)<8);aG=aE<<1;c[f+(aG<<2)>>2]=ap;ar=d[ax+(aw|3)|0]|0;aC=d[ax+(aw|1)|0]|0;am=d[ax+(aw|2)|0]|0;as=d[ax+aw|0]|0;at=0;aI=0;do{at=(ar>>>(aI>>>0)<<3&8|as>>>(aI>>>0)&1|aC>>>(aI>>>0)<<2&4|am>>>(aI>>>0)<<1&2)<<(aI<<2)|at;aI=aI+1|0;}while((aI|0)<8);c[f+((aG|1)<<2)>>2]=at;aE=aE+1|0;}while((aE|0)<16);aE=aK+aD|0;gGC(aE|0,aL|0,128)|0;aE=ax+128|0;if(aE>>>0<au>>>0){ax=aE;av=av+1|0}else{break}}}H=H+1|0;}while((H|0)<8);L48422:do{if((ai|0)==0){bk=aB}else{H=c[9721648+(aB<<2)>>2]|0;aL=0;while(1){if((aL|0)>=1024){bl=aB;break}bm=9638528+(aL<<2)|0;if((c[bm>>2]|0)==0){V=41100;break}else{aL=aL+1|0}}do{if((V|0)==41100){aL=gGq(H)|0;c[bm>>2]=aL;if((aL|0)==0){bl=c[2113146]|0;break}gGz(aL|0,0,H|0);c[14127400+(c[2113146]<<2)>>2]=aL;c[O+108>>2]=0;aL=O+100|0;c[aL>>2]=0;aK=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aK&16383](O,ah)|0;aK=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aK&16383](N,ah,0)|0;aK=c[14127400+(c[2113146]<<2)>>2]|0;I=c[642608+(c[2436]<<2)>>2]|0;av=c[I>>2]|0;do{if((fa(av|0,147696)|0)!=0&(ai|0)==2){ax=c[N>>2]|0;au=0;while(1){aJ=a[ax+au|0]|0;if((aJ<<24>>24|0)==0|(aJ<<24>>24|0)==45|(aJ<<24>>24|0)==95){break}au=au+1|0}if((a[ax+(au+2)|0]|0)!=51){bn=aK;break}bn=aK+(c[aL>>2]<<1)|0}else{bn=aK}}while(0);aL=(fa(av|0,182424)|0)==0;aD=aL?aK+2097152|0:bn;c[B+108>>2]=0;aL=B+100|0;c[aL>>2]=0;at=c[I+76>>2]|0;gA[at&16383](B,ah)|0;if((ai|0)>0){at=z+108|0;aG=z+100|0;aJ=0;do{aE=aD+(ag(c[aL>>2]|0,aJ)|0)|0;aI=aJ+ah|0;do{if((c[3542200]|0)!=0){c[at>>2]=0;c[aG>>2]=0;am=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[am&16383](z,aI)|0;if((c[at>>2]|0)==0){break}am=c[aG>>2]|0;c[A>>2]=9534384;aC=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aC&16383](A,aI,0)|0;if((am|0)<1){break}gzL(aE,0,aI)|0}}while(0);aJ=aJ+1|0;}while((aJ|0)<(ai|0))}aJ=c[2113146]|0;if((c[(c[642608+(c[2436]<<2)>>2]|0)+60>>2]&2|0)==0){bk=aJ;break L48422}aG=c[14127400+(aJ<<2)>>2]|0;at=0;while(1){aL=aG+at|0;aD=a[aL]|0;I=aG+(at+2097152)|0;a[aL]=a[I]|0;a[I]=aD;aD=at+1|0;if((aD|0)<2097152){at=aD}else{bk=aJ;break L48422}}}}while(0);c[14127400+(bl<<2)>>2]=0;bo=1;i=e;return bo|0}}while(0);if((al|0)==0){c[14127368+(bk<<2)>>2]=c[14127400+(bk<<2)>>2];c[9721616+(bk<<2)>>2]=c[9721648+(bk<<2)>>2];bo=0;i=e;return bo|0}aB=c[9721616+(bk<<2)>>2]|0;H=0;while(1){if((H|0)>=1024){bp=bk;break}bq=9638528+(H<<2)|0;if((c[bq>>2]|0)==0){V=41123;break}else{H=H+1|0}}do{if((V|0)==41123){H=gGq(aB)|0;c[bq>>2]=H;if((H|0)==0){bp=c[2113146]|0;break}gGz(H|0,0,aB|0);c[14127368+(c[2113146]<<2)>>2]=H;aJ=ah+ai|0;c[E+108>>2]=0;at=E+100|0;c[at>>2]=0;aG=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aG&16383](E,aJ)|0;if((al|0)<=0){bo=0;i=e;return bo|0}aG=C+108|0;aD=C+100|0;I=0;while(1){aL=H+(ag(c[at>>2]|0,I)|0)|0;aK=I+aJ|0;do{if((c[3542200]|0)!=0){c[aG>>2]=0;c[aD>>2]=0;av=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[av&16383](C,aK)|0;if((c[aG>>2]|0)==0){break}av=c[aD>>2]|0;c[D>>2]=9534384;aI=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aI&16383](D,aK,0)|0;if((av|0)<1){break}gzL(aL,0,aK)|0}}while(0);aK=I+1|0;if((aK|0)<(al|0)){I=aK}else{bo=0;break}}i=e;return bo|0}}while(0);c[14127368+(bp<<2)>>2]=0;bo=1;i=e;return bo|0}}while(0);c[14163992+(c[2113146]<<2)>>2]=0;bo=1;i=e;return bo|0}}while(0);c[14164520+(bb<<2)>>2]=0;bo=1;i=e;return bo|0}}while(0);c[14164080+(a7<<2)>>2]=0;bo=1;i=e;return bo|0}}while(0);c[14164128+(aN<<2)>>2]=0;bo=1;i=e;return bo|0}function cAI(){var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0;d=i;i=i+8|0;e=d|0;c[2424]=5918;f=c[642608+(c[2436]<<2)>>2]|0;c[2113132]=c[((c[f+52>>2]&4|0)==0?f+128|0:f+132|0)>>2];g=c[2438154]|0;j=g&4;k=j>>>2;c[3528496]=2-k;c[2440446]=k+1;k=c[2414834]|0;c[3541048]=k;c[3541049]=k+8192;c[3541066]=k+16384;l=k+147456|0;if((j|0)==0){m=l}else{c[2385792]=l;c[2385788]=k+212992;c[2405762]=k+215040;m=k+280576|0}if((c[f+60>>2]&61440|0)==20480){c[2385790]=m;n=m+8192|0}else{n=m}c[2439434]=n;m=n+131072|0;if((g&16|0)==0){o=m}else{c[3541040]=m;m=(c[2443854]|0)+131072|0;c[3541028]=n+m;o=n+(m+(c[2113122]|0))|0}c[2411912]=o;m=o;o=0;while(1){if((o|0)>=1024){break}p=9638528+(o<<2)|0;if((c[p>>2]|0)==0){q=41153;break}else{o=o+1|0}}do{if((q|0)==41153){o=gGq(m)|0;c[p>>2]=o;if((o|0)==0){break}gGz(o|0,0,m|0);c[2414834]=o;gGz(o|0,0,m|0);c[3541048]=o;c[3541049]=o+8192;c[3541066]=o+16384;n=o+147456|0;g=c[2438154]|0;if((g&4|0)==0){r=n}else{c[2385792]=n;c[2385788]=o+212992;c[2405762]=o+215040;r=o+280576|0}if((c[(c[642608+(c[2436]<<2)>>2]|0)+60>>2]&61440|0)==20480){c[2385790]=r;s=r+8192|0}else{s=r}c[2439434]=s;o=s+131072|0;if((g&16|0)==0){t=o}else{c[3541040]=o;o=(c[2443854]|0)+131072|0;c[3541028]=s+o;t=s+(o+(c[2113122]|0))|0}c[2411912]=t;fxU(0,425984);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];o=c[3532592]|0;if((o|0)!=0){gGC(9104152,o|0,280)|0}c[2113054]=c[2113060]}fwR(0);o=c[2439330]|0;g=(o|0)==0;if(!g){n=o;gGC(9706056,n|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];n=c[3528484]|0;c[2076596]=n;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;k=c[2438154]|0;l=(k&16|0)==0;if(!l){c[(c[2112932]|0)+196856>>2]=1120}c[2113058]=768;j=(k&4|0)==0;do{if(j){u=c[3541138]|0;v=c[2112932]|0;w=v|0;x=0;while(1){y=u+x|0;c[w>>2]=y;c[w+65536>>2]=y;c[w+131072>>2]=y;y=x+1024|0;if(y>>>0>2097151){break}else{w=w+4|0;x=y}}x=c[3541146]|0;w=v+49152|0;u=12582912;while(1){y=x+(u-12582912)|0;c[w>>2]=y;c[w+131072>>2]=y;y=u+1024|0;if(y>>>0>13107199){break}else{w=w+4|0;u=y}}u=v+51200|0;w=13107200;while(1){y=x+(w-13107200)|0;c[u>>2]=y;c[u+131072>>2]=y;y=w+1024|0;if(y>>>0>13631487){break}else{u=u+4|0;w=y}}z=v;A=k&8}else{w=c[2385792]|0;u=c[2112932]|0;x=1048576;do{y=x|65535;if(x>>>0<=y>>>0){B=u+(x>>>10<<2)|0;C=x;while(1){D=w+(C-x)|0;c[B>>2]=D;c[B+65536>>2]=D;c[B+131072>>2]=D;D=C+1024|0;if(D>>>0>y>>>0){break}else{B=B+4|0;C=D}}}x=x+65536|0;}while((x|0)<2097152);x=k&8;if((x|0)!=0){z=u;A=x;break}x=c[3541146]|0;w=u+49152|0;v=12582912;while(1){C=x+(v-12582912)|0;c[w>>2]=C;c[w+131072>>2]=C;C=v+1024|0;if(C>>>0>13107199){z=u;A=0;break}else{w=w+4|0;v=C}}}}while(0);c[z+196688>>2]=3248;c[z+196608>>2]=618;c[z+196728>>2]=2710;c[z+196648>>2]=972;c[z+196732>>2]=766;c[z+196652>>2]=818;if((A|0)==0){k=z+32768|0;v=k;w=8388608;while(1){c[v>>2]=2;c[v+131072>>2]=2;u=w+1024|0;if(u>>>0>12582911){E=k;F=8388608;break}else{v=v+4|0;w=u}}while(1){c[E+65536>>2]=2;w=F+1024|0;if(w>>>0>12582911){break}else{E=E+4|0;F=w}}c[z+196616>>2]=3524;c[z+196656>>2]=442}w=z+16384|0;v=4194304;while(1){c[w+65536>>2]=3;k=v+1024|0;if(k>>>0>8388607){break}else{w=w+4|0;v=k}}c[z+196740>>2]=238;c[z+196660>>2]=1140;v=c[3541048]|0;w=v+1024|0;k=v+2048|0;u=v+3072|0;x=4325376;do{if(x>>>0<=(x|8191)>>>0){C=x>>>10;c[z+(C<<2)>>2]=v;c[z+(C+32768<<2)>>2]=v;B=C|1;c[z+(B<<2)>>2]=w;c[z+(B+32768<<2)>>2]=w;c[z+(B+1<<2)>>2]=k;c[z+(B+32769<<2)>>2]=k;B=x|3072;y=C|3;c[z+(y<<2)>>2]=u;c[z+(y+32768<<2)>>2]=u;D=v+(B+1024-x)|0;c[z+(y+1<<2)>>2]=D;c[z+(y+32769<<2)>>2]=D;D=v+(B+2048-x)|0;c[z+(y+2<<2)>>2]=D;c[z+(y+32770<<2)>>2]=D;D=v+(B+3072-x)|0;c[z+(y+3<<2)>>2]=D;c[z+(y+32771<<2)>>2]=D;D=C|7;C=v+((x|7168)-x)|0;c[z+(D<<2)>>2]=C;c[z+(D+32768<<2)>>2]=C}x=x+8192|0;}while((x|0)<8388608);x=z+15360|0;v=3932160;while(1){c[x>>2]=5;c[x+65536>>2]=5;c[x+131072>>2]=5;u=v+1024|0;if(u>>>0>4063231){break}else{x=x+4|0;v=u}}c[z+196708>>2]=1918;c[z+196628>>2]=1402;c[z+196748>>2]=3170;c[z+196668>>2]=1892;if(!l){c[z+65536>>2]=4;c[z+196744>>2]=1594;c[z+196664>>2]=3378;v=z+57344|0;x=14680064;while(1){c[v>>2]=6;c[v+65536>>2]=6;c[v+131072>>2]=6;u=x+1024|0;if(u>>>0>15728639){break}else{v=v+4|0;x=u}}c[z+196712>>2]=740;c[z+196632>>2]=2606;c[z+196752>>2]=3164;c[z+196672>>2]=2196;x=z+61440|0;v=15728640;while(1){c[x>>2]=7;c[x+65536>>2]=7;c[x+131072>>2]=7;u=v+1024|0;if(u>>>0>16777215){break}else{x=x+4|0;v=u}}c[z+196716>>2]=2166;c[z+196636>>2]=1990;c[z+196756>>2]=2690;c[z+196676>>2]=2436;c[z+196616>>2]=422;c[z+196656>>2]=444}if(!j){v=c[2385788]|0;c[o+1068>>2]=v;x=v+256|0;c[o+1072>>2]=x;u=v+512|0;c[o+1076>>2]=u;k=v+768|0;c[o+1080>>2]=k;w=v+1024|0;c[o+1084>>2]=w;C=v+1280|0;c[o+1088>>2]=C;D=v+1536|0;c[o+1092>>2]=D;y=v+1792|0;c[o+1096>>2]=y;c[o+2092>>2]=v;c[o+2096>>2]=x;c[o+2100>>2]=u;c[o+2104>>2]=k;c[o+2108>>2]=w;c[o+2112>>2]=C;c[o+2116>>2]=D;c[o+2120>>2]=y;c[o+3116>>2]=v;c[o+4140>>2]=v;c[o+3120>>2]=x;c[o+4144>>2]=x;c[o+3124>>2]=u;c[o+4148>>2]=u;c[o+3128>>2]=k;c[o+4152>>2]=k;c[o+3132>>2]=w;c[o+4156>>2]=w;c[o+3136>>2]=C;c[o+4160>>2]=C;c[o+3140>>2]=D;c[o+4164>>2]=D;c[o+3144>>2]=y;c[o+4168>>2]=y;c[o+4172>>2]=2608;c[o+4176>>2]=586}if(!l){y=c[3540996]|0;D=0;C=0;while(1){c[o+76+(C<<2)>>2]=y+(C<<8);w=D+1&65535;if((w&65535)>255){G=0;H=0;break}else{D=w;C=w&65535}}while(1){c[o+76+(H+256<<2)>>2]=y+(H<<8);C=G+1&65535;if((C&65535)>255){I=0;J=0;break}else{G=C;H=C&65535}}while(1){C=y+(J<<8)|0;c[o+76+(J+512<<2)>>2]=C;c[o+76+(J+768<<2)>>2]=C;C=I+1&65535;if((C&65535)>255){break}else{I=C;J=C&65535}}c[o+4172>>2]=2302;c[o+4176>>2]=586}if(!g){y=o;gGC(y|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=n;c[2417276]=f;c[1836236]=-1;y=c[2394]|0;C=c[14130368+(y<<2)>>2]|0;if((C|0)!=0){gGC(C|0,9104152,280)|0}c[8452240+(y<<2)>>2]=c[2113054];c[2394]=-1;a[1172008]=0;b[4867100]=248;y=c[642608+(c[2436]<<2)>>2]|0;C=c[y>>2]|0;if((fa(C|0,487976)|0)==0){a[1172008]=1;b[4867100]=251}if((fa(C|0,475016)|0)==0){a[1172008]=1}if((fa(C|0,205440)|0)==0){a[1172008]=1}C=c[y+60>>2]&61440;c[2430446]=C;gGz(9542104,0,32);c[2385518]=1;c[2385519]=1;c[2385520]=1;c[2385521]=1;c[2385522]=1;c[2385523]=1;c[2385524]=1;c[2385525]=1;do{if(l){if((C|0)==4096){c[2385526]=6;c[2385518]=7;break}else if((C|0)==8192){c[2385526]=6;c[2385527]=7;break}else if((C|0)==16384){c[2385527]=16;c[2385528]=17;c[2385530]=18;break}else{break}}else{c[2385530]=16;c[2385522]=17}}while(0);c[2438126]=4e6;if(j){C=c[3531842]|0;TW(C,9721616,C,9721616,1848,1372,76)}else{TW(c[3531850]|0,9721648,c[3531842]|0,9721616,1848,1372,76)}h[745406]=1.0;c[2436786]=1;h[745405]=1.0;c[2436784]=2;h[745404]=.6;a[3203280]=1;C=c[2438126]|0;c[2438228]=C;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;l=gGS(2048e6,0,C,(C|0)<0|0?-1:0)|0;C=gGK(l,K,-1,0)|0;c[2443846]=C;if((c[(c[642608+(c[2436]<<2)>>2]|0)+60>>2]&-65536|0)==84017152){c[2113146]=8;cNN(-1)}else{cNN(0);cNN(-1);C=(c[2113114]|0)+1|0;l=0;while(1){if((l|0)>=1024){L=0;break}M=9638528+(l<<2)|0;if((c[M>>2]|0)==0){q=41236;break}else{l=l+1|0}}do{if((q|0)==41236){l=gGq(C)|0;c[M>>2]=l;if((l|0)==0){L=0;break}gGz(l|0,0,C|0);L=l}}while(0);c[2439426]=L;C=c[2113138]|0;if((C|0)>0){l=c[3541032]|0;j=0;while(1){f=j+1|0;n=f<<7;o=j<<7;while(1){if((o|0)>=(n|0)){N=1;break}if((a[l+o|0]|0)==0){o=o+1|0}else{N=0;break}}a[L+j|0]=N;if((f|0)<(C|0)){j=f}else{break}}}j=c[2113114]|0;l=j+1|0;if(C>>>0<l>>>0){o=C;do{a[L+o|0]=1;o=o+1|0;}while(o>>>0<l>>>0)}c[2429718]=L;c[2430092]=c[3541032];c[2429858]=j}if((c[2438154]&4|0)!=0){l=c[2439330]|0;o=(l|0)==0;if(!o){C=l;gGC(9706056,C|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];C=c[3528484]|0;c[2076596]=C;n=c[2417276]|0;c[3541536]=n;c[1836236]=0;c[2385416]=-1;c[2385418]=-1;c[2385420]=-1;c[2385422]=-1;g=c[3540996]|0;y=128;D=128;while(1){c[l+76+(D<<2)>>2]=g+(D<<8);w=y+1&65535;if((w&65535)>191){O=128;P=128;break}else{y=w;D=w&65535}}while(1){D=g+(P<<8)|0;c[l+76+(P+512<<2)>>2]=D;c[l+76+(P+768<<2)>>2]=D;D=O+1&65535;if((D&65535)>191){break}else{O=D;P=D&65535}}c[2385422]=2;if((c[2385420]|0)!=6){D=192;y=192;while(1){c[l+76+(y<<2)>>2]=g+(y<<8);j=D+1&65535;if((j&65535)>223){Q=192;R=192;break}else{D=j;y=j&65535}}while(1){y=g+(R<<8)|0;c[l+76+(R+512<<2)>>2]=y;c[l+76+(R+768<<2)>>2]=y;y=Q+1&65535;if((y&65535)>223){break}else{Q=y;R=y&65535}}c[2385420]=6}if((c[2385418]|0)!=14){c[l+972>>2]=g+57344;c[l+976>>2]=g+57600;c[l+980>>2]=g+57856;c[l+984>>2]=g+58112;c[l+988>>2]=g+58368;c[l+992>>2]=g+58624;c[l+996>>2]=g+58880;c[l+1e3>>2]=g+59136;c[l+1004>>2]=g+59392;c[l+1008>>2]=g+59648;c[l+1012>>2]=g+59904;c[l+1016>>2]=g+60160;c[l+1020>>2]=g+60416;c[l+1024>>2]=g+60672;c[l+1028>>2]=g+60928;c[l+1032>>2]=g+61184;y=224;D=224;while(1){j=g+(D<<8)|0;c[l+76+(D+512<<2)>>2]=j;c[l+76+(D+768<<2)>>2]=j;j=y+1&65535;if((j&65535)>239){break}else{y=j;D=j&65535}}c[2385418]=14}if((c[2385416]|0)==30){S=0;T=0}else{D=g+61440|0;c[l+1036>>2]=D;y=g+61696|0;c[l+1040>>2]=y;j=g+61952|0;c[l+1044>>2]=j;w=g+62208|0;c[l+1048>>2]=w;k=g+62464|0;c[l+1052>>2]=k;u=g+62720|0;c[l+1056>>2]=u;x=g+62976|0;c[l+1060>>2]=x;v=g+63232|0;c[l+1064>>2]=v;c[l+3084>>2]=D;c[l+4108>>2]=D;c[l+3088>>2]=y;c[l+4112>>2]=y;c[l+3092>>2]=j;c[l+4116>>2]=j;c[l+3096>>2]=w;c[l+4120>>2]=w;c[l+3100>>2]=k;c[l+4124>>2]=k;c[l+3104>>2]=u;c[l+4128>>2]=u;c[l+3108>>2]=x;c[l+4132>>2]=x;c[l+3112>>2]=v;c[l+4136>>2]=v;c[2385416]=30;S=0;T=0}while(1){c[l+76+(T<<2)>>2]=g+(T<<8);v=S+1&65535;if((v&65535)>127){U=0;V=0;break}else{S=v;T=v&65535}}while(1){v=g+(V<<8)|0;c[l+76+(V+512<<2)>>2]=v;c[l+76+(V+768<<2)>>2]=v;v=U+1&65535;if((v&65535)>127){break}else{U=v;V=v&65535}}if(!o){g=l;gGC(g|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=C;c[2417276]=n;c[1836236]=-1}g=c[2438650]|0;if((g|0)!=0){v=g;g=0;while(1){if((g|0)>=1024){break}W=9638528+(g<<2)|0;if((c[W>>2]|0)==(v|0)){q=41272;break}else{g=g+1|0}}if((q|0)==41272){gGr(v);c[W>>2]=0}c[2438650]=0}g=c[2438652]|0;if((g|0)==0){X=0}else{n=g;g=0;while(1){if((g|0)>=1024){break}Y=9638528+(g<<2)|0;if((c[Y>>2]|0)==(n|0)){q=41278;break}else{g=g+1|0}}if((q|0)==41278){gGr(n);c[Y>>2]=0}c[2438652]=0;X=0}while(1){if((X|0)>=1024){Z=0;break}_=9638528+(X<<2)|0;if((c[_>>2]|0)==0){q=41282;break}else{X=X+1|0}}do{if((q|0)==41282){n=gGq(16384)|0;c[_>>2]=n;if((n|0)==0){Z=0;break}gGz(n|0,0,16384);Z=n}}while(0);c[2438650]=Z;n=0;while(1){if((n|0)>=1024){$=0;break}aa=9638528+(n<<2)|0;if((c[aa>>2]|0)==0){q=41287;break}else{n=n+1|0}}do{if((q|0)==41287){n=gGq(8192)|0;c[aa>>2]=n;if((n|0)==0){$=0;break}gGz(n|0,0,8192);$=n}}while(0);c[2438652]=$;n=c[2438651]|0;if((n|0)!=0){g=n;n=0;while(1){if((n|0)>=1024){break}ab=9638528+(n<<2)|0;if((c[ab>>2]|0)==(g|0)){q=41293;break}else{n=n+1|0}}if((q|0)==41293){gGr(g);c[ab>>2]=0}c[2438651]=0}n=c[2438653]|0;if((n|0)==0){ac=0}else{v=n;n=0;while(1){if((n|0)>=1024){break}ad=9638528+(n<<2)|0;if((c[ad>>2]|0)==(v|0)){q=41299;break}else{n=n+1|0}}if((q|0)==41299){gGr(v);c[ad>>2]=0}c[2438653]=0;ac=0}while(1){if((ac|0)>=1024){ae=0;break}af=9638528+(ac<<2)|0;if((c[af>>2]|0)==0){q=41303;break}else{ac=ac+1|0}}do{if((q|0)==41303){v=gGq(16384)|0;c[af>>2]=v;if((v|0)==0){ae=0;break}gGz(v|0,0,16384);ae=v}}while(0);c[2438651]=ae;v=0;while(1){if((v|0)>=1024){ag=0;break}ah=9638528+(v<<2)|0;if((c[ah>>2]|0)==0){q=41308;break}else{v=v+1|0}}do{if((q|0)==41308){v=gGq(8192)|0;c[ah>>2]=v;if((v|0)==0){ag=0;break}gGz(v|0,0,8192);ag=v}}while(0);c[2438653]=ag;a[14164176]=1;c[3528528]=12e6;gGz(9553748,0,28);c[2388444]=187500;a[9553782]=0;a[9553781]=0;a[9553780]=0;c[e>>2]=gb(0)|0;v=a5(e|0)|0;c[2388430]=c[v>>2];c[2388431]=c[v+4>>2];c[2388432]=c[v+8>>2];c[2388433]=c[v+12>>2];c[2388436]=c[v+24>>2];c[2388434]=(c[v+16>>2]|0)+1;c[2388435]=(c[v+20>>2]|0)%100|0;c[2427030]=-1;v=c[2438154]&16;a[801632]=(v|0)!=0;a[9718704]=(v>>>4^1)&255^1;c[2113146]=0;cAN();ai=0;i=d;return ai|0}}while(0);c[2414834]=0;ai=1;i=d;return ai|0}function cAJ(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;b=i;i=i+240|0;d=b|0;e=b+112|0;f=b+120|0;g=b+232|0;a[632096]=0;c[2438154]=16;c[2385536]=2097152;c[2443854]=4194304;c[2113122]=131072;c[2430412]=0;c[2430404]=1048576;h=c[2414830]|0;c[3541006]=h;c[3540994]=h+131072;c[3541018]=h+262144;c[3541130]=h+393216;c[3541010]=h+2490368;c[3541146]=h+2491392;c[3540998]=h+3015680;c[3541032]=h+3539968;c[3541020]=h+7734272;j=h+7865344|0;c[3531850]=j;c[3531842]=j;j=h+8913920|0;c[2411910]=j;h=j;j=0;while(1){if((j|0)>=1024){break}k=9638528+(j<<2)|0;if((c[k>>2]|0)==0){l=41317;break}else{j=j+1|0}}do{if((l|0)==41317){j=gGq(h)|0;c[k>>2]=j;if((j|0)==0){break}gGz(j|0,0,h|0);c[2414830]=j;gGz(j|0,0,h|0);c[3541006]=j;c[3540994]=j+131072;c[3541018]=j+262144;m=j+393216|0;if((c[2438154]&4|0)==0){c[3541130]=m;n=c[2385536]|0;o=j+(n+393216)|0;c[3541010]=o;p=j+(n+394240)|0;c[3541146]=p;q=j+(n+918528)|0;c[3540998]=q;r=n+1442816|0;c[3541032]=j+r;n=r+(c[2443854]|0)|0;c[3541020]=j+n;r=n+(c[2113122]|0)|0;c[3531850]=j+r;n=r+(c[2430412]|0)|0;c[3531842]=j+n;s=j+(n+(c[2430404]|0))|0;t=m;u=o;v=q;w=p}else{c[3541146]=m;s=j+917504|0;t=c[3541130]|0;u=c[3541010]|0;v=c[3540998]|0;w=m}c[2411910]=s;c[3541128]=t;c[3541008]=u;c[3540996]=v;c[3541138]=t;do{if((c[3542200]|0)!=0){m=f+108|0;c[m>>2]=0;j=f+100|0;c[j>>2]=0;p=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[p&16383](f,0)|0;if((c[m>>2]|0)==0){break}m=c[j>>2]|0;c[g>>2]=9534384;j=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[j&16383](g,0,0)|0;if((m|0)<1){break}gzL(w,0,0)|0}}while(0);m=c[3540994]|0;do{if((c[3542200]|0)!=0){j=d+108|0;c[j>>2]=0;p=d+100|0;c[p>>2]=0;q=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[q&16383](d,1)|0;if((c[j>>2]|0)==0){break}j=c[p>>2]|0;c[e>>2]=9534384;p=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[p&16383](e,1,0)|0;if((j|0)<1){break}gzL(m,0,1)|0}}while(0);m=c[3541008]|0;j=c[3541146]|0;gGC(m|0,j|0,256)|0;j=c[3540996]|0;a[j]=-61;a[j+1|0]=0;a[j+2|0]=0;a[9620528]=0;j=c[2443854]|0;m=1;while(1){if(m>>>0<j>>>0){m=m<<1}else{break}}c[2113114]=(m>>>7)-1;c[2113138]=j>>>7;x=cAI()|0;i=b;return x|0}}while(0);c[2414830]=0;x=1;i=b;return x|0}function cAK(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;if(a[632096]|0){b=0;return b|0}a[632096]=1;d=c[2436]|0;do{if((c[(c[642608+(d<<2)>>2]|0)+60>>2]&-65536|0)==84017152){c[2113146]=0;e=a[9736]|0?5860:0;f=0;while(1){g=c[9704+(f<<2)>>2]|0;if(g>>>0<e>>>0){break}h=f+1|0;c[2113146]=h;if(h>>>0<8){f=h}else{i=41342;break}}if((i|0)==41342){c[2436]=d;break}c[2436]=g;b=1;return b|0}}while(0);g=c[2438650]|0;d=0;while(1){if((d|0)>=1024){break}j=9638528+(d<<2)|0;if((c[j>>2]|0)==(g|0)){i=41346;break}else{d=d+1|0}}if((i|0)==41346){gGr(g);c[j>>2]=0}c[2438650]=0;j=c[2438652]|0;g=0;while(1){if((g|0)>=1024){break}k=9638528+(g<<2)|0;if((c[k>>2]|0)==(j|0)){i=41350;break}else{g=g+1|0}}if((i|0)==41350){gGr(j);c[k>>2]=0}c[2438652]=0;k=c[2438651]|0;j=0;while(1){if((j|0)>=1024){break}l=9638528+(j<<2)|0;if((c[l>>2]|0)==(k|0)){i=41354;break}else{j=j+1|0}}if((i|0)==41354){gGr(k);c[l>>2]=0}c[2438651]=0;l=c[2438653]|0;k=0;while(1){if((k|0)>=1024){break}m=9638528+(k<<2)|0;if((c[m>>2]|0)==(l|0)){i=41358;break}else{k=k+1|0}}if((i|0)==41358){gGr(l);c[m>>2]=0}c[2438653]=0;m=c[3541514]|0;if((m|0)!=0){gGr(m|0);c[3541514]=0}c[2113008]=0;c[2076598]=0;c[2383582]=0;c[2438228]=0;c[2433526]=0;c[2406676]=0;c[3528472]=0;m=c[2406698]|0;if((m|0)!=0){gGr(m);c[2406698]=0}m=c[2385412]|0;if((m|0)!=0){gGr(m);c[2385412]=0}a[64232]=0;fwZ();if((c[2392]|0)>=0){m=0;do{l=14130368+(m<<2)|0;k=c[l>>2]|0;if((k|0)!=0){gGr(k);c[l>>2]=0}l=14130384+(m<<2)|0;k=c[l>>2]|0;if((k|0)!=0){gGr(k);c[l>>2]=0}m=m+1|0;}while((m|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;m=c[2438154]|0;if((m&4|0)==0){n=m}else{c[2113146]=0;m=0;do{l=9757704+(m<<2)|0;k=c[l>>2]|0;j=0;while(1){if((j|0)>=1024){o=m;break}p=9638528+(j<<2)|0;if((c[p>>2]|0)==(k|0)){i=41376;break}else{j=j+1|0}}if((i|0)==41376){i=0;gGr(k);c[p>>2]=0;o=c[2113146]|0}c[l>>2]=0;c[2429718]=0;j=c[2429310]|0;g=0;while(1){if((g|0)>=1024){break}q=9638528+(g<<2)|0;if((c[q>>2]|0)==(j|0)){i=41380;break}else{g=g+1|0}}if((i|0)==41380){i=0;gGr(j);c[q>>2]=0}c[2429310]=0;g=9723504+(o<<2)|0;l=c[g>>2]|0;k=0;while(1){if((k|0)>=1024){break}r=9638528+(k<<2)|0;if((c[r>>2]|0)==(l|0)){i=41384;break}else{k=k+1|0}}if((i|0)==41384){i=0;gGr(l);c[r>>2]=0}c[g>>2]=0;c[2427052]=0;k=c[2113146]|0;j=c[14164080+(k<<2)>>2]|0;d=0;while(1){if((d|0)>=1024){s=k;break}t=9638528+(d<<2)|0;if((c[t>>2]|0)==(j|0)){i=41388;break}else{d=d+1|0}}if((i|0)==41388){i=0;gGr(j);c[t>>2]=0;s=c[2113146]|0}c[14164080+(s<<2)>>2]=0;c[8452488+(s<<2)>>2]=0;d=c[14164128+(s<<2)>>2]|0;k=0;while(1){if((k|0)>=1024){u=s;break}v=9638528+(k<<2)|0;if((c[v>>2]|0)==(d|0)){i=41392;break}else{k=k+1|0}}if((i|0)==41392){i=0;gGr(d);c[v>>2]=0;u=c[2113146]|0}c[14164128+(u<<2)>>2]=0;k=c[14164520+(u<<2)>>2]|0;j=0;while(1){if((j|0)>=1024){w=u;break}x=9638528+(j<<2)|0;if((c[x>>2]|0)==(k|0)){i=41396;break}else{j=j+1|0}}if((i|0)==41396){i=0;gGr(k);c[x>>2]=0;w=c[2113146]|0}c[14164520+(w<<2)>>2]=0;j=c[14164040+(w<<2)>>2]|0;d=0;while(1){if((d|0)>=1024){y=w;break}z=9638528+(d<<2)|0;if((c[z>>2]|0)==(j|0)){i=41400;break}else{d=d+1|0}}if((i|0)==41400){i=0;gGr(j);c[z>>2]=0;y=c[2113146]|0}c[14164040+(y<<2)>>2]=0;d=c[14163992+(y<<2)>>2]|0;k=0;while(1){if((k|0)>=1024){A=y;break}B=9638528+(k<<2)|0;if((c[B>>2]|0)==(d|0)){i=41404;break}else{k=k+1|0}}if((i|0)==41404){i=0;gGr(d);c[B>>2]=0;A=c[2113146]|0}c[14163992+(A<<2)>>2]=0;k=c[14127400+(A<<2)>>2]|0;j=0;while(1){if((j|0)>=1024){C=A;break}D=9638528+(j<<2)|0;if((c[D>>2]|0)==(k|0)){i=41408;break}else{j=j+1|0}}if((i|0)==41408){i=0;gGr(k);c[D>>2]=0;C=c[2113146]|0}c[14127400+(C<<2)>>2]=0;j=c[14127368+(C<<2)>>2]|0;d=0;while(1){if((d|0)>=1024){E=C;break}F=9638528+(d<<2)|0;if((c[F>>2]|0)==(j|0)){i=41412;break}else{d=d+1|0}}if((i|0)==41412){i=0;gGr(j);c[F>>2]=0;E=c[2113146]|0}c[14127368+(E<<2)>>2]=0;m=E+1|0;c[2113146]=m;}while(m>>>0<8);n=c[2438154]|0}if((n&16|0)!=0){n=c[2439426]|0;m=0;while(1){if((m|0)>=1024){break}G=9638528+(m<<2)|0;if((c[G>>2]|0)==(n|0)){i=41419;break}else{m=m+1|0}}if((i|0)==41419){gGr(n);c[G>>2]=0}c[2439426]=0;c[2429718]=0;G=c[2429310]|0;n=0;while(1){if((n|0)>=1024){break}H=9638528+(n<<2)|0;if((c[H>>2]|0)==(G|0)){i=41423;break}else{n=n+1|0}}if((i|0)==41423){gGr(G);c[H>>2]=0}c[2429310]=0;H=c[2430876]|0;G=0;while(1){if((G|0)>=1024){break}I=9638528+(G<<2)|0;if((c[I>>2]|0)==(H|0)){i=41427;break}else{G=G+1|0}}if((i|0)==41427){gGr(H);c[I>>2]=0}c[2430876]=0;c[2427052]=0}I=c[2414830]|0;H=0;while(1){if((H|0)>=1024){break}J=9638528+(H<<2)|0;if((c[J>>2]|0)==(I|0)){i=41432;break}else{H=H+1|0}}if((i|0)==41432){gGr(I);c[J>>2]=0}c[2414830]=0;J=c[2414834]|0;I=0;while(1){if((I|0)>=1024){break}K=9638528+(I<<2)|0;if((c[K>>2]|0)==(J|0)){i=41436;break}else{I=I+1|0}}if((i|0)==41436){gGr(J);c[K>>2]=0}c[2414834]=0;gGz(14164288,0,160);c[1865440]=14164288;c[2113122]=0;c[2113310]=9999;c[2113146]=0;c[3541008]=0;c[3541128]=0;c[3540996]=0;c[2385536]=0;a[681320]=0;a[632096]=0;a[64280]=0;b=0;return b|0}function cAL(){cAT();cNR();if((a[9534304]&1)==0){return 0}c[2113042]=16;c[2113044]=240;cyx();cNJ();return 0}function cAM(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;if((a[14164168]|0)!=0){if((c[2438154]&4|0)!=0){gGz(c[2385792]|0,0,65536)}cAN()}f=a[14164237]&31;a[14164237]=f;a[14164245]=0;g=c[2430446]|0;do{if((g|0)==12288){cAO(0);cAO(1)}else if((g|0)==16384){cAO(0);a[14164248]=0;a[14164249]=0;a[14164250]=0;h=0;i=0;j=0;k=0;do{i=((a[h+14164480|0]&1)<<h|i&255)&255;j=((a[h+14164488|0]&1)<<h|j&255)&255;k=((a[h+14164496|0]&1)<<h|k&255)&255;h=h+1|0;}while((h|0)<7);a[14164248]=i;a[14164249]=j;a[14164250]=k}else if((g|0)==8192){a[14164233]=0;a[14164234]=0;a[14164235]=0;h=0;l=0;m=0;n=0;do{l=((a[14164216+h|0]&1)<<h|l&255)&255;m=((a[14164472+h|0]&1)<<h|m&255)&255;n=((a[14164464+h|0]&1)<<h|n&255)&255;h=h+1|0;}while((h|0)<8);a[14164233]=l;a[14164234]=m;a[14164235]=n;h=(c[2444142]|0)+(e[7082252]|0)|0;c[2444142]=h;k=(c[2444143]|0)+(e[7082253]|0)|0;c[2444143]=k;a[14164238]=h>>>8&255;a[14164239]=k>>>8&255;if((a[14164272]|0)==0){break}a[14164237]=f|-128}else if((g|0)==4096){cAO(0);k=(c[2444142]|0)-(e[7082252]|0)|0;c[2444142]=k;h=(c[2444143]|0)-(e[7082253]|0)|0;c[2444143]=h;a[14164238]=k>>>8&255;a[14164239]=h>>>8&255}else if((g|0)==20480){cAO(0)}else{cAO(0)}}while(0);f=c[2438154]|0;do{if((f&4|0)==0){a[14164234]=a[14164234]|112;a[14164248]=0;a[14164249]=0;if((a[14164272]|0)==0){break}a[14164248]=37}else{h=(d[14164120]|0)>>>7;a[9718704]=h;do{if(a[801632]|0){k=a[14164234]|0;a[14164234]=k|48;if(h<<24>>24==0){break}a[14164234]=k|112}}while(0);if((f&2|0)!=0){a[14164234]=a[14164234]|-128}do{if((g|0)!=20480){if((f&1|0)==0){break}h=d[9600]|0;if((h|0)==4){a[14164237]=a[14164237]&-65;a[14164235]=a[14164235]|32;break}else if((h|0)==6){a[14164237]=a[14164237]&-65;a[14164235]=a[14164235]&-33;break}else{a[14164237]=a[14164237]|64;a[14164235]=a[14164235]|32;break}}}while(0);h=a[14164280]|0;if((a[14108248]|0)!=h<<24>>24){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];n=c[3532592]|0;if((n|0)!=0){gGC(9104152,n|0,280)|0}c[2113054]=c[2113060]}n=c[2112932]|0;m=c[n>>2]|0;if(m>>>0>9){o=d[m+273|0]<<8|d[m+272|0]|(d[m+271|0]<<8|d[m+270|0])<<16;p=h;q=n}else{h=gj[c[n+196768+(m<<2)>>2]&4095](270)|0;o=h;p=a[14164280]|0;q=c[2112932]|0}h=o&16777215;m=c[q+((h>>>10|16384)<<2)>>2]|0;if(m>>>0>9){a[m+(o&1023^1)|0]=p}else{gg[c[q+196648+(m<<2)>>2]&4095](h,p)}h=c[2394]|0;m=c[14130368+(h<<2)>>2]|0;if((m|0)!=0){gGC(m|0,9104152,280)|0}c[8452240+(h<<2)>>2]=c[2113054];c[2394]=-1;a[14108248]=a[14164280]|0}h=a[14164281]|0;if((a[14108240]|0)==h<<24>>24){break}if((c[2394]|0)==0){r=c[2112932]|0}else{c[2394]=0;m=c[3532596]|0;c[2112932]=m;n=c[3532592]|0;if((n|0)!=0){gGC(9104152,n|0,280)|0}c[2113054]=c[2113060];r=m}m=c[r>>2]|0;if(m>>>0>9){s=d[m+273|0]<<8|d[m+272|0]|(d[m+271|0]<<8|d[m+270|0])<<16;t=h;u=r}else{h=gj[c[r+196768+(m<<2)>>2]&4095](270)|0;s=h;t=a[14164281]|0;u=c[2112932]|0}h=s+1|0;m=h&16777215;n=c[u+((m>>>10|16384)<<2)>>2]|0;if(n>>>0>9){a[n+(h&1023^1)|0]=t}else{gg[c[u+196648+(n<<2)>>2]&4095](m,t)}m=c[2394]|0;n=c[14130368+(m<<2)>>2]|0;if((n|0)!=0){gGC(n|0,9104152,280)|0}c[8452240+(m<<2)>>2]=c[2113054];c[2394]=-1;a[14108240]=a[14164281]|0}}while(0);t=c[2438]|0;if((c[2427030]|0)!=(t|0)){u=t;s=(t|0)<0|0?-1:0;r=gGU(u,s,12e6,0)|0;p=K;q=~~((+(r>>>0)+ +(p|0)*4294967296.0)/15151.515151515152);c[2440550]=q;c[2440492]=(q|0)/3|0;q=gGU(u,s,4e6,0)|0;s=gGS(q,K,256,0)|0;q=s;c[2438126]=q;c[2438228]=q;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;s=gGS(2048e6,0,q,(q|0)<0|0?-1:0)|0;q=gGK(s,K,-1,0)|0;c[2443846]=q;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];q=c[3532592]|0;if((q|0)!=0){gGC(9104152,q|0,280)|0}c[2113054]=c[2113060]}c[2113058]=~~(+(t|0)*12.0e6/4.0e6);q=c[3532592]|0;if((q|0)!=0){gGC(q|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;q=gGS(r,p,256,0)|0;p=q|0;r=K&0;s=gGU(c[2388442]|0,0,p,r)|0;u=c[3528528]|0;o=0;f=gGV(s,K,u,o)|0;c[2388442]=f;f=gGU(c[2388443]|0,0,p,r)|0;s=gGV(f,K,u,o)|0;c[2388443]=s;s=gGU(c[2388444]|0,0,p,r)|0;r=gGV(s,K,u,o)|0;c[2388444]=r;c[3528528]=q;c[2427030]=t}do{if((c[2438154]&4|0)!=0){if((c[2440454]|0)<=(c[2440550]<<3|0)){break}if(a[64280]|0){break}cAN()}}while(0);a[9771648]=0;a[9708024]=0;if((c[2112968]|0)!=0){cAT();cNR()}c[2113044]=16;t=c[2392]|0;if((t|0)>=0){gGz(8452240,0,((t|0)>0?(t<<2)+4|0:4)|0)}c[2113054]=0;t=c[2385548]|0;if((t|0)>0){gGz(9752472,0,((t|0)>1?t<<2:4)|0)}c[2433530]=0;if((c[2394]|0)==0){v=0}else{c[2394]=0;c[2112932]=c[3532596];t=c[3532592]|0;if((t|0)!=0){gGC(9104152,t|0,280)|0}t=c[2113060]|0;c[2113054]=t;v=t}t=c[2439330]|0;if((t|0)!=0){q=t;gGC(9706056,q|0,76)|0}b[4853030]=c[2426515]&65535;q=c[2438118]|0;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;t=c[2440564]|0;c[2113054]=v+t;c[2433530]=q+(c[2440565]|0);c[2438114]=t;do{if((c[2438154]&16|0)!=0){if((c[2406704]&80|0)==0){break}c[2433560]=c[2433560]&-17;cAv(0);if((c[2406704]&1280|0)==0){break}do{if((c[2437626]|0)==1){if(!(a[1616472]|0)){break}c[2438654]=-1;if((c[2433384]&128|0)==0){break}t=c[2433385]&1;q=t^1;c[2433394]=0;c[2433395]=q;c[2433396]=(t|0)==0?116:0;c[2433397]=q;c[2433402]=128;c[2433403]=0;c[2433404]=16;c[2433405]=0;do{if((a[9748220]|0)==103){if((dW(9748156,205456,16)|0)!=0){break}a[9748220]=102}}while(0);c[2433560]=c[2433560]&-33;cAv(0);c[2433391]=c[2433391]&-33}}while(0);a[1616472]=1}}while(0);q=(c[2113058]|0)*24|0;c[2438208]=q;t=c[2113054]|0;v=c[2113056]|0;r=c[2276108]|0;o=v+t-r|0;if((o|0)<(q|0)){q=o;while(1){o=c[3528542]|0;do{if((o|0)==2147483647|(c[2443922]&16|0)==0|(q|0)<(o|0)){w=o}else{c[2433560]=c[2433560]&-3;u=c[2440446]|0;c[8452200+(c[2394]<<2)>>2]=u|4096;s=c[2276080]|0;p=u<<8;c[2276080]=p;do{if((s|0)!=1792&(p|0)==1792){RH(7)}else{if(p>>>0<=(c[2276079]|0)>>>0){break}RH(u&16777215)}}while(0);if((c[2443922]&128|0)==0){w=c[3528542]|0;break}else{u=(c[3528540]|0)+1|0;p=c[2438]|0;s=gGU(p,(p|0)<0|0?-1:0,u,(u|0)<0|0?-1:0)|0;u=K;p=63;f=(u>>>0<p>>>0|u>>>0==p>>>0&s>>>0<-128>>>0?s>>>7|u<<25:2147483647)+(c[3528542]|0)|0;c[3528542]=f;w=f;break}}}while(0);o=c[2438208]|0;f=c[2113054]|0;u=c[2113056]|0;do{if((o|0)<(w|0)){x=c[2276108]|0;y=41553}else{s=c[2276108]|0;p=u+f-s|0;if((p|0)>=(w|0)){x=s;y=41553;break}s=w-p|0;c[2113056]=s;p=RG(s)|0;z=(c[2113054]|0)+p|0}}while(0);if((y|0)==41553){y=0;p=o-f-u+x|0;c[2113056]=p;s=RG(p)|0;z=(c[2113054]|0)+s|0}c[2113054]=z;c[2276108]=-1;c[2113056]=-1;if((z|0)<(c[2438208]|0)){q=z}else{A=z;B=-1;C=-1;break}}}else{A=t;B=v;C=r}do{if((c[2112968]|0)==0){a[9771648]=0;y=41559}else{r=a[9534304]&1;a[9771648]=r;if(r<<24>>24==0){y=41559;break}r=a[1172008]|0;a[9708024]=r&1;a[9718712]=0;v=(c[2113058]|0)*248|0;c[2439238]=v;if(r){D=v;y=41561}else{E=v;y=41586}}}while(0);if((y|0)==41559){v=a[1172008]|0;a[9708024]=0;a[9718712]=0;r=(c[2113058]|0)*248|0;c[2439238]=r;if(v){D=r;y=41561}else{E=r;y=41586}}L49089:do{if((y|0)==41586){c[2438208]=E;r=B-C+A|0;if((r|0)<(E|0)){F=r}else{break}while(1){r=c[3528542]|0;if((r|0)==2147483647|(c[2443922]&16|0)==0|(F|0)<(r|0)){G=a[9718712]|0}else{c[2433560]=c[2433560]&-3;r=c[2440446]|0;c[8452200+(c[2394]<<2)>>2]=r|4096;v=c[2276080]|0;t=r<<8;c[2276080]=t;do{if((v|0)!=1792&(t|0)==1792){RH(7)}else{if(t>>>0<=(c[2276079]|0)>>>0){break}RH(r&16777215)}}while(0);if((c[2443922]&128|0)!=0){r=(c[3528540]|0)+1|0;t=c[2438]|0;v=gGU(t,(t|0)<0|0?-1:0,r,(r|0)<0|0?-1:0)|0;r=K;t=63;c[3528542]=(r>>>0<t>>>0|r>>>0==t>>>0&v>>>0<-128>>>0?v>>>7|r<<25:2147483647)+(c[3528542]|0)}r=a[9771648]&1;a[9718712]=r;G=r}do{if((G&1)!=0){r=c[2113044]|0;c[2113042]=r;v=(((c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0)/(c[2113058]|0)|0)-5|0;t=(v|0)>240?240:v;c[2113044]=t;if((t-r|0)<=0){break}cyx()}}while(0);a[9718712]=0;r=c[2438208]|0;t=c[3528542]|0;v=c[2113054]|0;z=c[2113056]|0;do{if((r|0)<(t|0)){H=c[2276108]|0;y=41602}else{q=c[2276108]|0;x=z+v-q|0;if((x|0)>=(t|0)){H=q;y=41602;break}q=t-x|0;c[2113056]=q;x=RG(q)|0;I=(c[2113054]|0)+x|0}}while(0);if((y|0)==41602){y=0;t=r-v-z+H|0;c[2113056]=t;x=RG(t)|0;I=(c[2113054]|0)+x|0}c[2113054]=I;c[2276108]=-1;c[2113056]=-1;if((I|0)<(c[2439238]|0)){F=I}else{break}}}else if((y|0)==41561){u=B-C+A|0;if((u|0)>=(D|0)){break}f=c[3528542]|0;o=f-1|0;x=u;u=A;t=B;q=C;w=f;while(1){do{if((x|0)<(w|0)|(c[2443922]&16|0)!=0&(w|0)!=2147483647&(o|0)<(w|0)^1){f=a[9718712]|0;if((f&1)==0){J=o;L=f;y=41574;break}c[2113042]=c[2113044];c[2113044]=((t-q+u|0)/(c[2113058]|0)|0)-6;J=o;L=f;y=41574}else{c[2433560]=c[2433560]&-3;f=c[2440446]|0;c[8452200+(c[2394]<<2)>>2]=f|4096;s=c[2276080]|0;p=f<<8;c[2276080]=p;do{if((s|0)!=1792&(p|0)==1792){RH(7)}else{if(p>>>0<=(c[2276079]|0)>>>0){break}RH(f&16777215)}}while(0);if((c[2443922]&128|0)!=0){f=(c[3528540]|0)+1|0;p=c[2438]|0;s=gGU(p,(p|0)<0|0?-1:0,f,(f|0)<0|0?-1:0)|0;f=K;p=63;c[3528542]=(f>>>0<p>>>0|f>>>0==p>>>0&s>>>0<-128>>>0?s>>>7|f<<25:2147483647)+(c[3528542]|0)}f=a[9771648]&1;a[9718712]=f;if(f<<24>>24==0){M=w;break}c[2113042]=c[2113044];c[2113044]=(((c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0)/(c[2113058]|0)|0)-5;J=w;L=f;y=41574}}while(0);do{if((y|0)==41574){y=0;if((L&1)==0){M=J;break}z=c[2113044]|0;if((z|0)>240){c[2113044]=240;N=240}else{N=z}if((N-(c[2113042]|0)|0)<=0){M=J;break}cyx();M=J}}while(0);a[9718712]=0;z=(c[2113056]|0)+(c[2113054]|0)|0;v=c[2276108]|0;r=z-v|0;f=c[2438208]|0;if((r|0)<(f|0)){O=f}else{s=(c[2113058]|0)+f|0;c[2438208]=s;O=s}s=c[3528542]|0;if((O|0)>=(s|0)&(r|0)<(s|0)){f=s-r|0;c[2113056]=f;r=RG(f)|0;P=(c[2113054]|0)+r|0}else{r=v-z+O|0;c[2113056]=r;z=RG(r)|0;P=(c[2113054]|0)+z|0}c[2113054]=P;c[2276108]=-1;c[2113056]=-1;if((P|0)>=(c[2439238]|0)){break L49089}o=M;x=P;u=P;t=-1;q=-1;w=c[3528542]|0}}}while(0);if((a[9771648]&1)!=0){P=c[2113044]|0;if((P|0)<240){c[2113042]=P;c[2113044]=240;cyx()}cNJ()}c[2433560]=c[2433560]&-5;P=c[3528496]|0;c[8452200+(c[2394]<<2)>>2]=P|4096;M=c[2276080]|0;O=P<<8;c[2276080]=O;do{if((M|0)!=1792&(O|0)==1792){RH(7)}else{if(O>>>0<=(c[2276079]|0)>>>0){break}RH(P&16777215)}}while(0);P=c[2443922]|0;do{if((P&64|0)!=0){O=c[3528540]|0;M=c[2438]|0;J=gGU(M,(M|0)<0|0?-1:0,O,(O|0)<0|0?-1:0)|0;O=K;M=63;N=O>>>0<M>>>0|O>>>0==M>>>0&J>>>0<-128>>>0?J>>>7|O<<25:2147483647;if((N|0)==2147483647){break}c[3528542]=(c[2438208]|0)+N}}while(0);N=c[2440550]|0;c[2438208]=N;O=c[2113054]|0;J=c[2113056]|0;M=c[2276108]|0;L=J+O-M|0;L49165:do{if((L|0)<(N|0)){C=L;B=P;while(1){A=c[3528542]|0;do{if((A|0)==2147483647|(B&16|0)==0|(C|0)<(A|0)){Q=A}else{c[2433560]=c[2433560]&-3;D=c[2440446]|0;c[8452200+(c[2394]<<2)>>2]=D|4096;I=c[2276080]|0;F=D<<8;c[2276080]=F;do{if((I|0)!=1792&(F|0)==1792){RH(7)}else{if(F>>>0<=(c[2276079]|0)>>>0){break}RH(D&16777215)}}while(0);if((c[2443922]&128|0)==0){Q=c[3528542]|0;break}else{D=(c[3528540]|0)+1|0;F=c[2438]|0;I=gGU(F,(F|0)<0|0?-1:0,D,(D|0)<0|0?-1:0)|0;D=K;F=63;H=(D>>>0<F>>>0|D>>>0==F>>>0&I>>>0<-128>>>0?I>>>7|D<<25:2147483647)+(c[3528542]|0)|0;c[3528542]=H;Q=H;break}}}while(0);A=c[2438208]|0;H=c[2113054]|0;D=c[2113056]|0;do{if((A|0)<(Q|0)){R=c[2276108]|0;y=41628}else{I=c[2276108]|0;F=D+H-I|0;if((F|0)>=(Q|0)){R=I;y=41628;break}I=Q-F|0;c[2113056]=I;F=RG(I)|0;S=(c[2113054]|0)+F|0}}while(0);if((y|0)==41628){y=0;F=A-H-D+R|0;c[2113056]=F;I=RG(F)|0;S=(c[2113054]|0)+I|0}c[2113054]=S;c[2276108]=-1;c[2113056]=-1;if((S|0)>=(c[2438208]|0)){T=S;U=-1;V=-1;break L49165}C=S;B=c[2443922]|0}}else{T=O;U=J;V=M}}while(0);M=c[3528542]|0;do{if((M|0)!=2147483647){J=M-(c[2440550]|0)|0;c[3528542]=J;if((J|0)>=0){break}c[3528542]=2147483647}}while(0);c[2438218]=U-V+T;T=c[2440492]|0;V=gGU(T,(T|0)<0|0?-1:0,2048e6,0)|0;U=c[2438228]|0;M=gGS(V,K,U,(U|0)<0|0?-1:0)|0;U=M;Sb(T);T=c[2443830]|0;if((T|0)<1073676288){c[2443830]=T-U}T=c[2443831]|0;if((T|0)<1073676288){c[2443831]=T-U}T=(c[3528512]|0)-U|0;c[3528512]=(T|0)<0?0:T;gg[c[3542118]&4095](c[2112964]|0,a[9688]|0?534:0);T=c[2113054]|0;U=(c[2113056]|0)+T-(c[2276108]|0)|0;cz3(U-(c[2438114]|0)|0);c[2440454]=U+(c[2440454]|0);c[2440564]=U-(c[2440550]|0);U=c[2433530]|0;M=c[2076596]|0;c[2440565]=(c[2426530]|0)+U-M-(c[2440492]|0);V=c[1836236]|0;J=c[9757320+(V<<2)>>2]|0;if((J|0)!=0){O=J;gGC(O|0,9706056,76)|0}c[9752472+(V<<2)>>2]=U;c[14113936+(V<<2)>>2]=M;c[9669104+(V<<2)>>2]=c[3541536];c[1836236]=-1;V=c[2394]|0;M=c[14130368+(V<<2)>>2]|0;if((M|0)!=0){gGC(M|0,9104152,280)|0}c[8452240+(V<<2)>>2]=T;c[2394]=-1;if((c[2443922]&8|0)!=0){return 0}T=(c[2430422]|0)+1|0;c[2430422]=T;if((T|0)<=(c[2430424]|0)){return 0}c[2430422]=0;c[2113130]=(c[2113130]|0)+1;return 0}function cAN(){var e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;e=c[2438154]|0;if((e&4|0)==0){f=e}else{cAc(a[14164120]&31);e=c[2113310]|0;if((e|0)==(-1|0)|(e|0)==23){e=d[14164120]|0;b[(c[3541146]|0)+1024>>1]=(e<<13&32768|e&3)&65535}a[14164280]=0;a[14108248]=0;a[14164281]=0;a[14108240]=0;f=c[2438154]|0}L49218:do{if((f&24|0)==0){e=c[2113310]|0;do{if(!((e|0)==(-1|0)|(e|0)==12|(e|0)==11|(e|0)==10)){if((a[14164120]&116)==32){break}c[2438154]=5;g=5;break L49218}}while(0);c[2438154]=6;g=6}else{g=f}}while(0);a[9757280]=0;a[9534304]=1;a[9534320]=0;a[725016]=0;a[9717768]=1;c[2113136]=-1;c[2430424]=4;c[2430422]=0;c[2113130]=0;c[2433560]=-1;a[9775488]=0;a[9775480]=0;c[2440442]=1;c[2433546]=-1;c[3528540]=0;c[2443922]=0;c[2440464]=0;c[2442976]=14164232;c[2440565]=0;c[2440564]=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060]}f=c[2439330]|0;if((f|0)!=0){e=f;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;if((g&1|0)==0){e=(c[2112932]|0)+53248|0;f=13631488;while(1){c[e>>2]=0;c[e+65536>>2]=0;c[e+131072>>2]=0;i=f+1024|0;if(i>>>0>14680063){break}else{e=e+4|0;f=i}}}else{f=c[2405762]|0;e=c[2112932]|0;i=13631488;do{j=i|65535;if(i>>>0<=j>>>0){k=e+(i>>>10<<2)|0;l=i;while(1){m=f+(l-i)|0;c[k>>2]=m;c[k+65536>>2]=m;c[k+131072>>2]=m;m=l+1024|0;if(m>>>0>j>>>0){break}else{k=k+4|0;l=m}}}i=i+65536|0;}while((i|0)<14680064);i=e+53248|0;e=13631488;while(1){c[i+65536>>2]=1;f=e+1024|0;if(f>>>0>14680063){break}else{i=i+4|0;e=f}}}if((g&4|0)==0){n=g}else{cAP();n=c[2438154]|0}g=c[642608+(c[2436]<<2)>>2]|0;L49253:do{if((n&8|0)==0){o=g}else{e=c[3541146]|0;if((c[g+60>>2]&128|0)!=0){i=c[2112932]|0;f=i+49152|0;l=12582912;while(1){k=e+(l-12582912)|0;c[f>>2]=k;c[f+131072>>2]=k;k=l+1024|0;if(k>>>0>13107199){break}else{f=f+4|0;l=k}}l=i+51200|0;f=13107200;while(1){k=e+(f-13107200)|0;c[l>>2]=k;c[l+131072>>2]=k;k=f+1024|0;if(k>>>0>13631487){o=g;break L49253}else{l=l+4|0;f=k}}}f=(d[14164120]|0)<<17&393216;l=c[2112932]|0;i=f|-12582912;k=l+49152|0;j=12582912;while(1){m=e+(i+j)|0;c[k>>2]=m;c[k+131072>>2]=m;m=j+1024|0;if(m>>>0>12713983){break}else{k=k+4|0;j=m}}j=f-12713984|0;k=l+49664|0;i=12713984;while(1){m=e+(j+i)|0;c[k>>2]=m;c[k+131072>>2]=m;m=i+1024|0;if(m>>>0>12845055){break}else{k=k+4|0;i=m}}i=f-12845056|0;k=l+50176|0;j=12845056;while(1){m=e+(i+j)|0;c[k>>2]=m;c[k+131072>>2]=m;m=j+1024|0;if(m>>>0>12976127){break}else{k=k+4|0;j=m}}j=f-12976128|0;k=l+50688|0;i=12976128;while(1){m=e+(j+i)|0;c[k>>2]=m;c[k+131072>>2]=m;m=i+1024|0;if(m>>>0>13107199){break}else{k=k+4|0;i=m}}i=f|-13107200;k=l+51200|0;j=13107200;while(1){m=e+(i+j)|0;c[k>>2]=m;c[k+131072>>2]=m;m=j+1024|0;if(m>>>0>13238271){break}else{k=k+4|0;j=m}}j=f-13238272|0;k=l+51712|0;i=13238272;while(1){m=e+(j+i)|0;c[k>>2]=m;c[k+131072>>2]=m;m=i+1024|0;if(m>>>0>13369343){break}else{k=k+4|0;i=m}}i=f-13369344|0;k=l+52224|0;j=13369344;while(1){m=e+(i+j)|0;c[k>>2]=m;c[k+131072>>2]=m;m=j+1024|0;if(m>>>0>13500415){break}else{k=k+4|0;j=m}}j=f-13500416|0;k=l+52736|0;i=13500416;while(1){m=e+(j+i)|0;c[k>>2]=m;c[k+131072>>2]=m;m=i+1024|0;if(m>>>0>13631487){o=g;break}else{k=k+4|0;i=m}}}}while(0);g=c[o>>2]|0;do{if((fa(g|0,310208)|0)==0){p=41705}else{if((fa(g|0,308944)|0)==0){p=41705;break}if((fa(g|0,177704)|0)==0){p=41705;break}if((fa(g|0,314568)|0)==0){p=41705;break}if((fa(g|0,170664)|0)==0){p=41705;break}q=c[2112932]|0}}while(0);if((p|0)==41705){p=c[3541146]|0;g=c[2112932]|0;o=(d[14164120]|0)<<17&131072^-12451840;i=g+49152|0;k=12582912;while(1){j=p+(o+k)|0;c[i>>2]=j;c[i+131072>>2]=j;j=k+1024|0;if(j>>>0>12713983){q=g;break}else{i=i+4|0;k=j}}}k=c[3541008]|0;c[q>>2]=k;c[q+131072>>2]=k;if((n&16|0)!=0){c[2429618]=-1;c[2429596]=-1;c[2429904]=-1;a[9731920]=1;gGz(9717256,0,10);gGz(9717984,0,10);c[2429720]=0;c[2437626]=9;gGz(9748152,0,2352);a[1616472]=0;c[3528530]=0;c[2430884]=c[3541020];c[2427052]=c[2430876];c[2429718]=c[2439426];c[2430092]=c[3541032];c[2429858]=c[2113114];c[2430096]=0;gGz(9733560,0,60);gGz(9733496,0,64);c[2433391]=255;c[2433405]=128;n=(c[2438654]|0)+150|0;k=(n|0)%4500|0;q=(n|0)%75|0;c[2433394]=((n|0)/45e3|0)<<4|(((n|0)/4500|0|0)%10|0);c[2433395]=((k|0)/750|0)<<4|(((k|0)/75|0|0)%10|0);c[2433396]=((q|0)/10|0)<<4|((q|0)%10|0);c[2433397]=1}q=c[1836236]|0;if((q|0)>=0){a[(c[9757320+(q<<2)>>2]|0)+4188|0]=0}RI();gGz(9706056,0,76);if((c[2113136]|0)!=0){c[2113136]=0;q=c[3541048]|0;k=c[2112932]|0;c[k+16384>>2]=q;c[k+147456>>2]=q;n=q+1024|0;c[k+16388>>2]=n;c[k+147460>>2]=n;n=q+2048|0;c[k+16392>>2]=n;c[k+147464>>2]=n;n=q+3072|0;c[k+16396>>2]=n;c[k+147468>>2]=n;n=q+4096|0;c[k+16400>>2]=n;c[k+147472>>2]=n;n=q+5120|0;c[k+16404>>2]=n;c[k+147476>>2]=n;n=q+6144|0;c[k+16408>>2]=n;c[k+147480>>2]=n;n=q+7168|0;c[k+16412>>2]=n;c[k+147484>>2]=n;c[3541046]=c[9754600+(c[2113136]<<2)>>2]}n=c[1836236]|0;k=c[9757320+(n<<2)>>2]|0;if((k|0)!=0){q=k;gGC(q|0,9706056,76)|0}c[9752472+(n<<2)>>2]=c[2433530];c[14113936+(n<<2)>>2]=c[2076596];c[9669104+(n<<2)>>2]=c[3541536];c[1836236]=-1;n=c[2394]|0;q=c[14130368+(n<<2)>>2]|0;if((q|0)!=0){gGC(q|0,9104152,280)|0}c[8452240+(n<<2)>>2]=c[2113054];c[2394]=-1;n=c[2439330]|0;if((n|0)!=0){q=n;gGC(9706056,q|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;l6(0);q=c[1836236]|0;n=c[9757320+(q<<2)>>2]|0;if((n|0)==0){r=c[2433530]|0;s=9752472+(q<<2)|0;c[s>>2]=r;t=c[2076596]|0;u=14113936+(q<<2)|0;c[u>>2]=t;v=c[3541536]|0;w=9669104+(q<<2)|0;c[w>>2]=v;c[1836236]=-1;c[2440454]=0;c[3528542]=2147483647;c[2433554]=0;a[849336]=0;c[2406704]=0;return}k=n;gGC(k|0,9706056,76)|0;r=c[2433530]|0;s=9752472+(q<<2)|0;c[s>>2]=r;t=c[2076596]|0;u=14113936+(q<<2)|0;c[u>>2]=t;v=c[3541536]|0;w=9669104+(q<<2)|0;c[w>>2]=v;c[1836236]=-1;c[2440454]=0;c[3528542]=2147483647;c[2433554]=0;a[849336]=0;c[2406704]=0;return}function cAO(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if((b|0)==0){c[3541058]=0;b=0;d=0;e=0;f=0;g=0;do{d=((a[14164224+b|0]&1)<<b|d&255)&255;e=((a[14164216+b|0]&1)<<b|e&255)&255;f=((a[14164472+b|0]&1)<<b|f&255)&255;g=((a[14164464+b|0]&1)<<b|g&255)&255;b=b+1|0;}while((b|0)<8);a[14164232]=d;a[14164233]=e;a[14164234]=f;a[14164235]=g;if((d&3)==3){g=d&-4;a[14164232]=g;h=g}else{h=d}if((h&12)==12){a[14164232]=h&-13}if((e&3)==3){h=e&-4;a[14164233]=h;i=h}else{i=e}if((i&12)==12){a[14164233]=i&-13}if((a[14164272]|0)==0){return}a[14164237]=a[14164237]|-128;return}else{c[3541060]=0;i=0;e=0;h=0;d=0;g=0;do{e=((a[14164208+i|0]&1)<<i|e&255)&255;h=((a[14164200+i|0]&1)<<i|h&255)&255;d=((a[14164456+i|0]&1)<<i|d&255)&255;g=((a[14164448+i|0]&1)<<i|g&255)&255;i=i+1|0;}while((i|0)<8);a[14164240]=e;a[14164241]=h;a[14164242]=d;a[14164243]=g;if((e&3)==3){g=e&-4;a[14164240]=g;j=g}else{j=e}if((j&12)==12){a[14164240]=j&-13}if((h&3)==3){j=h&-4;a[14164241]=j;k=j}else{k=h}if((k&12)==12){a[14164241]=k&-13}if((a[14164273]|0)==0){return}a[14164245]=a[14164245]|-128;return}}function cAP(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;if((c[2438154]&4|0)==0){c[2113146]=0;return}b=((c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0)/3|0;if((b|0)>((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)){c[2438218]=b;Sb(b)}b=c[1865440]|0;do{if((b|0)!=0){d=c[b+8>>2]|0;if((d|0)==0){break}gu[d&16383]()}}while(0);b=c[2113146]|0;d=c[14164040+(b<<2)>>2]|0;c[3541008]=d;e=c[14164520+(b<<2)>>2]|0;if((e|0)==0){c[3541128]=0;f=c[2112932]|0;g=f|0;h=g;i=0;while(1){c[h>>2]=0;c[h+65536>>2]=0;c[h+131072>>2]=0;j=i+1024|0;if(j>>>0>1048575){break}else{h=h+4|0;i=j}}i=f+8192|0;h=2097152;while(1){c[i>>2]=0;c[i+65536>>2]=0;c[i+131072>>2]=0;j=h+1024|0;if(j>>>0>3145727){break}else{i=i+4|0;h=j}}a[9717768]=1;c[g>>2]=d;c[f+131072>>2]=d;c[1865440]=0;d=c[1836236]|0;if((d|0)>=0){a[(c[9757320+(d<<2)>>2]|0)+4188|0]=1}c[2429718]=c[9757704+(b<<2)>>2];c[2430092]=c[14164128+(b<<2)>>2];c[2429858]=c[8452456+(b<<2)>>2];c[2430884]=c[14164080+(b<<2)>>2];c[2427052]=c[9723504+(b<<2)>>2];return}c[3541128]=e;c[3540996]=c[14163992+(b<<2)>>2];c[1865440]=14164288+(b*20|0);e=c[2112932]|0;c[e+196712>>2]=0;c[e+196752>>2]=0;c[e+196632>>2]=0;c[e+196672>>2]=0;c[e+196716>>2]=0;c[e+196756>>2]=0;c[e+196636>>2]=0;c[e+196676>>2]=0;gGz(e+65536|0,0,4096);d=c[9542144+(b<<2)>>2]|0;if(d>>>0<524289){f=c[14164552+(b<<2)>>2]|0;g=e|0;h=0;while(1){i=f+h|0;c[g>>2]=i;c[g+131072>>2]=i;i=h+1024|0;if(i>>>0>524287){break}else{g=g+4|0;h=i}}h=e+2048|0;g=524288;while(1){i=f+(g-524288)|0;c[h>>2]=i;c[h+131072>>2]=i;i=g+1024|0;if(i>>>0>1048575){break}else{h=h+4|0;g=i}}g=e+8192|0;h=2097152;while(1){i=f+(h-2097152)|0;c[g>>2]=i;c[g+131072>>2]=i;i=h+1024|0;if(i>>>0>2621439){break}else{g=g+4|0;h=i}}h=e+10240|0;g=2621440;while(1){i=f+(g-2621440)|0;c[h>>2]=i;c[h+131072>>2]=i;i=g+1024|0;if(i>>>0>3145727){break}else{h=h+4|0;g=i}}}g=c[14164552+(b<<2)>>2]|0;h=e|0;if(d>>>0<1048577){f=h;i=0;while(1){j=g+i|0;c[f>>2]=j;c[f+131072>>2]=j;j=i+1024|0;if(j>>>0>1048575){break}else{f=f+4|0;i=j}}i=e+8192|0;f=2097152;while(1){j=g+(f-2097152)|0;c[i>>2]=j;c[i+131072>>2]=j;j=f+1024|0;if(j>>>0>3145727){break}else{i=i+4|0;f=j}}if(d>>>0>1048576){k=g;l=h;m=41783}}else{k=g;l=h;m=41783}if((m|0)==41783){m=l;l=0;while(1){h=k+l|0;c[m>>2]=h;c[m+131072>>2]=h;h=l+1024|0;if(h>>>0>1048575){break}else{m=m+4|0;l=h}}l=e+8192|0;m=2097152;while(1){c[l+65536>>2]=4;k=m+1024|0;if(k>>>0>3145727){break}else{l=l+4|0;m=k}}c[e+196744>>2]=2536;c[e+196664>>2]=374}e=c[14164292+(b*20|0)>>2]|0;if((e|0)==0){n=d}else{gu[e&16383]();n=c[9542144+(c[2113146]<<2)>>2]|0}do{if(n>>>0>1048576){c[2113148]=1048576;e=c[(c[1865440]|0)+12>>2]|0;if((e|0)!=0){gu[e&16383]();break}if((c[(c[642608+(c[2436]<<2)>>2]|0)+60>>2]&61440|0)==20480){break}e=c[3541128]|0;d=(c[2112932]|0)+8192|0;b=2097152;while(1){m=e+(b-1048576)|0;c[d>>2]=m;c[d+131072>>2]=m;m=b+1024|0;if(m>>>0>3145727){break}else{d=d+4|0;b=m}}}}while(0);n=c[642608+(c[2436]<<2)>>2]|0;do{if((c[n+60>>2]&61440|0)==20480){b=c[2385790]|0;d=c[2112932]|0;c[d+8192>>2]=b;c[d+73728>>2]=b;c[d+139264>>2]=b;e=b+1024|0;c[d+8196>>2]=e;c[d+73732>>2]=e;c[d+139268>>2]=e;e=b+2048|0;c[d+8200>>2]=e;c[d+73736>>2]=e;c[d+139272>>2]=e;e=b+3072|0;c[d+8204>>2]=e;c[d+73740>>2]=e;c[d+139276>>2]=e;e=b+4096|0;c[d+8208>>2]=e;c[d+73744>>2]=e;c[d+139280>>2]=e;e=b+5120|0;c[d+8212>>2]=e;c[d+73748>>2]=e;c[d+139284>>2]=e;e=b+6144|0;c[d+8216>>2]=e;c[d+73752>>2]=e;c[d+139288>>2]=e;e=b+7168|0;c[d+8220>>2]=e;c[d+73756>>2]=e;c[d+139292>>2]=e;e=d+8224|0;b=2105344;while(1){c[e>>2]=6;m=b+1024|0;if(m>>>0>3145727){break}else{e=e+4|0;b=m}}c[d+196632>>2]=3030;c[d+196712>>2]=3404;b=c[n>>2]|0;if((fa(b|0,15e4)|0)!=0){if((fa(b|0,148792)|0)!=0){break}}c[d+12800>>2]=7;c[d+196636>>2]=3004}}while(0);n=c[3540996]|0;b=c[1836236]|0;e=(b|0)<0;do{if((n|0)==0){if(e){o=0;break}a[(c[9757320+(b<<2)>>2]|0)+4188|0]=1;o=0}else{m=c[9757320+(b<<2)>>2]|0;if(!e){a[m+4188|0]=0}c[2385416]=-1;c[2385418]=-1;c[2385420]=-1;c[2385422]=-1;l=128;k=128;while(1){c[m+76+(k<<2)>>2]=n+(k<<8);h=l+1&65535;if((h&65535)>191){p=128;q=128;break}else{l=h;k=h&65535}}while(1){k=n+(q<<8)|0;c[m+76+(q+512<<2)>>2]=k;c[m+76+(q+768<<2)>>2]=k;k=p+1&65535;if((k&65535)>191){break}else{p=k;q=k&65535}}c[2385422]=2;if((c[2385420]|0)!=6){k=192;l=192;while(1){c[m+76+(l<<2)>>2]=n+(l<<8);d=k+1&65535;if((d&65535)>223){r=192;s=192;break}else{k=d;l=d&65535}}while(1){l=n+(s<<8)|0;c[m+76+(s+512<<2)>>2]=l;c[m+76+(s+768<<2)>>2]=l;l=r+1&65535;if((l&65535)>223){break}else{r=l;s=l&65535}}c[2385420]=6}if((c[2385418]|0)!=14){c[m+972>>2]=n+57344;c[m+976>>2]=n+57600;c[m+980>>2]=n+57856;c[m+984>>2]=n+58112;c[m+988>>2]=n+58368;c[m+992>>2]=n+58624;c[m+996>>2]=n+58880;c[m+1e3>>2]=n+59136;c[m+1004>>2]=n+59392;c[m+1008>>2]=n+59648;c[m+1012>>2]=n+59904;c[m+1016>>2]=n+60160;c[m+1020>>2]=n+60416;c[m+1024>>2]=n+60672;c[m+1028>>2]=n+60928;c[m+1032>>2]=n+61184;l=224;k=224;while(1){d=n+(k<<8)|0;c[m+76+(k+512<<2)>>2]=d;c[m+76+(k+768<<2)>>2]=d;d=l+1&65535;if((d&65535)>239){break}else{l=d;k=d&65535}}c[2385418]=14}if((c[2385416]|0)==30){o=n;break}k=n+61440|0;c[m+1036>>2]=k;l=n+61696|0;c[m+1040>>2]=l;d=n+61952|0;c[m+1044>>2]=d;h=n+62208|0;c[m+1048>>2]=h;g=n+62464|0;c[m+1052>>2]=g;f=n+62720|0;c[m+1056>>2]=f;i=n+62976|0;c[m+1060>>2]=i;j=n+63232|0;c[m+1064>>2]=j;c[m+3084>>2]=k;c[m+4108>>2]=k;c[m+3088>>2]=l;c[m+4112>>2]=l;c[m+3092>>2]=d;c[m+4116>>2]=d;c[m+3096>>2]=h;c[m+4120>>2]=h;c[m+3100>>2]=g;c[m+4124>>2]=g;c[m+3104>>2]=f;c[m+4128>>2]=f;c[m+3108>>2]=i;c[m+4132>>2]=i;c[m+3112>>2]=j;c[m+4136>>2]=j;c[2385416]=30;o=n}}while(0);if((c[3541128]|0)!=0&(a[9717768]&1)==0){n=c[14164552+(c[2113146]<<2)>>2]|0;s=c[2112932]|0;c[s>>2]=n;c[s+131072>>2]=n}else{n=c[3541008]|0;s=c[2112932]|0;c[s>>2]=n;c[s+131072>>2]=n}L49469:do{if((c[2438154]&4|0)!=0){do{if(a[725016]|0){if((a[9620528]&1)==0){break}n=c[3541006]|0;s=c[9757320+(b<<2)>>2]|0;r=0;q=0;while(1){c[s+76+(q<<2)>>2]=n+(q<<8);p=r+1&65535;if((p&65535)>127){t=0;u=0;break}else{r=p;q=p&65535}}while(1){q=n+(u<<8)|0;c[s+76+(u+512<<2)>>2]=q;c[s+76+(u+768<<2)>>2]=q;q=t+1&65535;if((q&65535)>127){break L49469}else{t=q;u=q&65535}}}}while(0);m=c[9757320+(b<<2)>>2]|0;s=0;n=0;while(1){c[m+76+(n<<2)>>2]=o+(n<<8);q=s+1&65535;if((q&65535)>127){v=0;w=0;break}else{s=q;n=q&65535}}while(1){n=o+(w<<8)|0;c[m+76+(w+512<<2)>>2]=n;c[m+76+(w+768<<2)>>2]=n;n=v+1&65535;if((n&65535)>127){break}else{v=n;w=n&65535}}}}while(0);w=c[2113146]|0;c[2429718]=c[9757704+(w<<2)>>2];c[2430092]=c[14164128+(w<<2)>>2];c[2429858]=c[8452456+(w<<2)>>2];c[2430884]=c[14164080+(w<<2)>>2];c[2427052]=c[9723504+(w<<2)>>2];gGz((c[3541066]|0)+59904|0,0,512);v=c[14127400+(w<<2)>>2]|0;o=c[9721648+(w<<2)>>2]|0;b=c[14127368+(w<<2)>>2]|0;u=c[9721616+(w<<2)>>2]|0;w=c[3541514]|0;c[w+20412>>2]=v;c[w+20416>>2]=o;c[w+20912>>2]=b;c[w+20936>>2]=u;if((w|0)!=(c[2383472]|0)){return}c[2112888]=v;return}function cAQ(b,c){b=b|0;c=c|0;a[9706117]=c&1;return}function cAR(a){a=a|0;var b=0,d=0;b=(c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=c[2438126]|0;b=gGS(d,K,a,(a|0)<0|0?-1:0)|0;return b|0}function cAS(){return+(+((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)/+(c[2438126]|0))}function cAT(){var d=0,f=0,g=0,h=0,i=0,j=0;if((a[14164176]|0)==0){return}d=0;f=c[3541048]|0;g=c[2438652]|0;h=c[2438650]|0;while(1){b[g>>1]=b[f>>1]|0;i=e[f>>1]|0;j=i&240;c[h>>2]=i<<1&30|i>>>12&1|(i>>>4&240|i>>>11&8)<<8|(i>>>10&8|j|j>>>5)<<3&2016;j=d+1|0;if((j|0)<4096){d=j;f=f+2|0;g=g+2|0;h=h+4|0}else{break}}h=0;g=c[3541049]|0;f=c[2438653]|0;d=c[2438651]|0;while(1){b[f>>1]=b[g>>1]|0;j=e[g>>1]|0;i=j&240;c[d>>2]=j<<1&30|j>>>12&1|(j>>>4&240|j>>>11&8)<<8|(j>>>10&8|i|i>>>5)<<3&2016;i=h+1|0;if((i|0)<4096){h=i;g=g+2|0;f=f+2|0;d=d+4|0}else{break}}a[14164176]=0;return}function cAU(b,d){b=b|0;d=d|0;var f=0,g=0;f=b&8191^1;a[(c[14164192+(c[2113136]<<2)>>2]|0)+f|0]=d;b=(c[9754608+(c[2113136]<<2)>>2]|0)+(f<<1)|0;if((a[b]|0)==d<<24>>24){return}a[b]=d;d=c[2113136]|0;b=e[(c[14164192+(d<<2)>>2]|0)+(f&8190)>>1]|0;g=b&240;c[(c[9754600+(d<<2)>>2]|0)+(f>>>1<<2)>>2]=b<<1&30|b>>>12&1|(b>>>4&240|b>>>11&8)<<8|(b>>>10&8|g|g>>>5)<<3&2016;return}function cAV(a,d){a=a|0;d=d|0;var e=0;e=a>>>1&4095;b[(c[14164192+(c[2113136]<<2)>>2]|0)+(e<<1)>>1]=d;a=(c[9754608+(c[2113136]<<2)>>2]|0)+(e<<1)|0;if((b[a>>1]|0)==d<<16>>16){return}b[a>>1]=d;a=d&65535;d=a&240;c[(c[9754600+(c[2113136]<<2)>>2]|0)+(e<<2)>>2]=a<<1&30|a>>>12&1|(a>>>4&240|a>>>11&8)<<8|(a>>>10&8|d|d>>>5)<<3&2016;return}function cAW(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>30){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5757052+(b*112|0)>>2];c[a+104>>2]=c[5757056+(b*112|0)>>2];c[a+108>>2]=c[5757060+(b*112|0)>>2];d=0;return d|0}function cAX(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<31&(d|0)==0)){e=1;return e|0}c[a>>2]=5756952+(b*112|0);e=0;return e|0}function cAY(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>30){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=2513376+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function cAZ(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=7){if((a|0)==0){d=0;return d|0}e=a;f=1040032+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}f=b-8|0;if(f>>>0>60){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;a=5760424+(f*12|0)|0;c[b>>2]=c[a>>2];c[b+4>>2]=c[a+4>>2];c[b+8>>2]=c[a+8>>2];d=0;return d|0}function cA_(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>30){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5761484+(b*112|0)>>2];c[a+104>>2]=c[5761488+(b*112|0)>>2];c[a+108>>2]=c[5761492+(b*112|0)>>2];d=0;return d|0}function cA$(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<31&(d|0)==0)){e=1;return e|0}c[a>>2]=5761384+(b*112|0);e=0;return e|0}function cA0(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>29){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=2518352+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function cA1(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=33){if((a|0)==0){d=0;return d|0}e=a;f=5764856+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}f=b-34|0;if(f>>>0>33){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;a=4516976+(f*12|0)|0;c[b>>2]=c[a>>2];c[b+4>>2]=c[a+4>>2];c[b+8>>2]=c[a+8>>2];d=0;return d|0}function cA2(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>1){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5761260+(b*112|0)>>2];c[a+104>>2]=c[5761264+(b*112|0)>>2];c[a+108>>2]=c[5761268+(b*112|0)>>2];d=0;return d|0}function cA3(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<2&(d|0)==0)){e=1;return e|0}c[a>>2]=5761160+(b*112|0);e=0;return e|0}function cA4(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4517384+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function cA5(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6517760+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function cA6(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[3541128]|0;b=c[2112932]|0;d=(c[2113148]|0)-2097152|0;e=b+8192|0;f=2097152;while(1){g=a+(d+f)|0;c[e>>2]=g;c[e+131072>>2]=g;g=f+1024|0;if(g>>>0>3138559){break}else{e=e+4|0;f=g}}f=c[2113148]|0;e=a+(f+1042432)|0;c[b+12264>>2]=e;c[b+143336>>2]=e;e=a+(f+1043456)|0;c[b+12268>>2]=e;c[b+143340>>2]=e;e=a+(f+1044480)|0;c[b+12272>>2]=e;c[b+143344>>2]=e;e=a+(f+1045504)|0;c[b+12276>>2]=e;c[b+143348>>2]=e;e=a+(f+1046528)|0;c[b+12280>>2]=e;c[b+143352>>2]=e;return}function cA7(a){a=a|0;var d=0;if((a|0)==3138630){d=-26057;return d|0}d=b[(c[3541128]|0)+(a-2097152+(c[2113148]|0))>>1]|0;return d|0}function cA8(b){b=b|0;var d=0;if((b|0)==3138631){d=55}else if((b|0)==3138630){d=-102}else{d=a[(c[3541128]|0)+(b-2097152+(c[2113148]|0)^1)|0]|0}return d|0}function cA9(a){a=a|0;var d=0,e=0;d=c[2113146]|0;do{if((c[9721720+(d<<3)>>2]|0)!=(a|0)){if((c[9721724+(d<<3)>>2]|0)==(a|0)){break}e=b[(c[3541128]|0)+(a-2097152+(c[2113148]|0))>>1]|0;return e|0}}while(0);a=8452288+(d<<2)|0;d=c[a>>2]|0;c[a>>2]=(d>>2^d>>3^d>>5^d>>6^d>>>7^d>>>11^d>>>12^d>>>15)&1|d<<1&1048574;e=d&65535;return e|0}function cBa(b){b=b|0;var d=0,e=0,f=0;d=b&-2;e=c[2113146]|0;do{if((d|0)!=(c[9721720+(e<<3)>>2]|0)){if((d|0)==(c[9721724+(e<<3)>>2]|0)){break}f=a[(c[3541128]|0)+(b-2097152+(c[2113148]|0)^1)|0]|0;return f|0}}while(0);d=8452288+(e<<2)|0;e=c[d>>2]|0;c[d>>2]=(e>>2^e>>3^e>>5^e>>6^e>>>7^e>>>11^e>>>12^e>>>15)&1|e<<1&1048574;if((b&1|0)==0){f=e>>>8&255;return f|0}else{f=e&255;return f|0}return 0}function cBb(a,b){a=a|0;b=b|0;var d=0;b=i;i=i+16|0;d=b|0;if((a&64|0)==0){i=b;return 0}gGz(d|0,0,12);c[d>>2]=8452288;c[d+4>>2]=32;c[d+12>>2]=538632;gj[c[2076592]&4095](d)|0;i=b;return 0}function cBc(){var a=0;cAK()|0;a=c[2113146]|0;c[9721724+(a<<3)>>2]=0;c[9721720+(a<<3)>>2]=0;return 0}function cBd(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=c[2411924]|0;a[f+(b&8191^1)|0]=e;if((b-3145696|0)>>>0<2){e=a[f+8161|0]|0;g=a[f+8160|0]|0;a[f+8162|0]=g<<1&30|(e&255)>>>4&1;a[f+8163|0]=(g&255)>>>4<<1|(e&255)>>>5&1;a[f+8164|0]=e<<1&30|(e&255)>>>6&1;a[f+8165|0]=(e&255)>>>7;return}if((b-3145704|0)>>>0<4){e=a[f+8169|0]|0;g=a[f+8168|0]|0;h=a[f+8171|0]|0;i=a[f+8170|0]|0;a[f+8172|0]=(g&255)>>>1|(e&255)>>>1<<4;a[f+8173|0]=g<<4&16|e<<5&32|h<<7|(i&255)>>>1|i<<6&64;return}if((b-3145712|0)>>>0>=4){return}b=f+8179|0;i=a[b]|0;h=f+8177|0;e=a[h]|0;g=c[3541128]|0;j=((d[g+264|0]|0)<<16&1048576)+((d[f+8178|0]|0)<<8|(i&255)<<16|e&255)|0;if((c[2113148]|0)==(j|0)){k=e;l=i}else{c[2113148]=j;i=j-2097152|0;j=(c[2112932]|0)+8192|0;e=2097152;while(1){m=g+(i+e)|0;c[j>>2]=m;c[j+131072>>2]=m;m=e+1024|0;if(m>>>0>3137535){break}else{j=j+4|0;e=m}}k=a[h]|0;l=a[b]|0}a[f+8176|0]=-96;a[h]=k&-2;a[b]=l&127;return}function cBe(e,f){e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=c[2411924]|0;b[g+(e&8190)>>1]=f;if((e-3145696|0)>>>0<2){f=a[g+8161|0]|0;h=a[g+8160|0]|0;a[g+8162|0]=h<<1&30|(f&255)>>>4&1;a[g+8163|0]=(h&255)>>>4<<1|(f&255)>>>5&1;a[g+8164|0]=f<<1&30|(f&255)>>>6&1;a[g+8165|0]=(f&255)>>>7;return}if((e-3145704|0)>>>0<4){f=a[g+8169|0]|0;h=a[g+8168|0]|0;i=a[g+8171|0]|0;j=a[g+8170|0]|0;a[g+8172|0]=(h&255)>>>1|(f&255)>>>1<<4;a[g+8173|0]=h<<4&16|f<<5&32|i<<7|(j&255)>>>1|j<<6&64;return}if((e-3145712|0)>>>0>=4){return}e=g+8179|0;j=a[e]|0;i=g+8177|0;f=a[i]|0;h=c[3541128]|0;k=((d[h+264|0]|0)<<16&1048576)+((d[g+8178|0]|0)<<8|(j&255)<<16|f&255)|0;if((c[2113148]|0)==(k|0)){l=f;m=j}else{c[2113148]=k;j=k-2097152|0;k=(c[2112932]|0)+8192|0;f=2097152;while(1){n=h+(j+f)|0;c[k>>2]=n;c[k+131072>>2]=n;n=f+1024|0;if(n>>>0>3137535){break}else{k=k+4|0;f=n}}l=a[i]|0;m=a[e]|0}a[g+8176|0]=-96;a[i]=l&-2;a[e]=m&127;return}function cBf(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>12){f=9763192;break}f=4520888+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cBg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>12){g=9763192;break}g=4520888+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cBh(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>13){f=9763192;break}f=5939424+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cBi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>13){g=9763192;break}g=5939424+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cBj(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>13){f=9763192;break}f=4792144+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cBk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>13){g=9763192;break}g=4792144+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cBl(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>16){f=9763192;break}f=5643392+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cBm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>16){g=9763192;break}g=5643392+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cBn(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>11){f=9763192;break}f=2624232+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cBo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>11){g=9763192;break}g=2624232+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cBp(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>49){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=755616+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function cBq(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=7){if((a|0)==0){d=0;return d|0}e=a;f=1039936+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}f=b-8|0;if(f>>>0>60){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;a=5760424+(f*12|0)|0;c[b>>2]=c[a>>2];c[b+4>>2]=c[a+4>>2];c[b+8>>2]=c[a+8>>2];d=0;return d|0}function cBr(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>13){f=9763192;break}f=4445736+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cBs(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>13){g=9763192;break}g=4445736+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cBt(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>13){f=9763192;break}f=2383104+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cBu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>13){g=9763192;break}g=2383104+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cBv(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>9){f=9763192;break}f=4839536+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cBw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>9){g=9763192;break}g=4839536+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cBx(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>15){f=9763192;break}f=3163088+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cBy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>15){g=9763192;break}g=3163088+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cBz(){c[c[1865440]>>2]=12862;return cAG()|0}function cBA(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>13){f=9763192;break}f=2980576+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cBB(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>13){g=9763192;break}g=2980576+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cBC(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>10){f=9763192;break}f=2192544+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cBD(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>10){g=9763192;break}g=2192544+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cBE(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>8){f=9763192;break}f=5766504+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cBF(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>8){g=9763192;break}g=5766504+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cBG(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>9){f=9763192;break}f=7035328+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cBH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>9){g=9763192;break}g=7035328+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cBI(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>9){f=9763192;break}f=6537808+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cBJ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>9){g=9763192;break}g=6537808+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cBK(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>9){f=9763192;break}f=4417672+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cBL(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>9){g=9763192;break}g=4417672+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cBM(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>9){f=9763192;break}f=2305480+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cBN(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>9){g=9763192;break}g=2305480+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cBO(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>8){f=9763192;break}f=3038536+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cBP(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>8){g=9763192;break}g=3038536+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cBQ(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>8){f=9763192;break}f=1597848+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cBR(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>8){g=9763192;break}g=1597848+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cBS(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>14){f=9763192;break}f=1596168+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cBT(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>14){g=9763192;break}g=1596168+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cBU(){c[c[1865440]>>2]=12398;return cAG()|0}function cBV(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>8){f=9763192;break}f=2646184+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cBW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>8){g=9763192;break}g=2646184+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cBX(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>10){f=9763192;break}f=4694304+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cBY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>10){g=9763192;break}g=4694304+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cBZ(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>10){f=9763192;break}f=2822784+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cB_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>10){g=9763192;break}g=2822784+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cB$(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>6){f=9763192;break}f=5846376+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cB0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>6){g=9763192;break}g=5846376+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cB1(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>5){f=9763192;break}f=2412864+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cB2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>5){g=9763192;break}g=2412864+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cB3(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>5){f=9763192;break}f=1430208+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cB4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>5){g=9763192;break}g=1430208+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cB5(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>8){f=9763192;break}f=4570584+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cB6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>8){g=9763192;break}g=4570584+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cB7(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>8){f=9763192;break}f=2884704+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cB8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>8){g=9763192;break}g=2884704+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cB9(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>7){f=9763192;break}f=2645288+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cCa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>7){g=9763192;break}g=2645288+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cCb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>8){f=9763192;break}f=5948032+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cCc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>8){g=9763192;break}g=5948032+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cCd(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>8){f=9763192;break}f=4816368+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cCe(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>8){g=9763192;break}g=4816368+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cCf(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>8){f=9763192;break}f=4815360+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cCg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>8){g=9763192;break}g=4815360+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cCh(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>8){f=9763192;break}f=2255880+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cCi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>8){g=9763192;break}g=2255880+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cCj(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>8){f=9763192;break}f=1386624+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cCk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>8){g=9763192;break}g=1386624+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cCl(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>9){f=9763192;break}f=2867344+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cCm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>9){g=9763192;break}g=2867344+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cCn(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>8){f=9763192;break}f=2379968+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cCo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>8){g=9763192;break}g=2379968+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cCp(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>8){f=9763192;break}f=2863872+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cCq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>8){g=9763192;break}g=2863872+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cCr(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>9){f=9763192;break}f=6538928+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cCs(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>9){g=9763192;break}g=6538928+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cCt(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>17){f=9763192;break}f=5810840+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cCu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>17){g=9763192;break}g=5810840+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cCv(){c[c[1865440]>>2]=6006;return cAG()|0}function cCw(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>8){f=9763192;break}f=2307720+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cCx(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>8){g=9763192;break}g=2307720+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cCy(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>9){f=9763192;break}f=4793712+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cCz(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>9){g=9763192;break}g=4793712+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cCA(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>8){f=9763192;break}f=2413536+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cCB(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>8){g=9763192;break}g=2413536+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cCC(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>8){f=9763192;break}f=4770928+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cCD(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>8){g=9763192;break}g=4770928+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cCE(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>8){f=9763192;break}f=7362104+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cCF(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>8){g=9763192;break}g=7362104+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cCG(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>11){f=9763192;break}f=5689040+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cCH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>11){g=9763192;break}g=5689040+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cCI(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>11){f=9763192;break}f=4427304+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cCJ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>11){g=9763192;break}g=4427304+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cCK(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>15){f=9763192;break}f=2135224+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cCL(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>15){g=9763192;break}g=2135224+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cCM(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>15){f=9763192;break}f=1353152+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cCN(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>15){g=9763192;break}g=1353152+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cCO(a){a=a|0;var b=0,d=0,e=0;b=c[2385314]|0;d=b>>>24;if((a|0)==2318341|(a|0)==2318349){e=(d<<4|b>>>28)&255}else if((a|0)==2446673|(a|0)==3145713|(a|0)==2097153|(a|0)==3141633|(a|0)==2318337|(a|0)==2318345){e=d&255}else{e=0}return e|0}function cCP(a){a=a|0;var b=0,d=0,e=0,f=0;b=c[2385314]|0;d=b>>>24;e=d&65535;if((a|0)==2318340|(a|0)==2318348){f=(d<<4&240|b>>>28)&65535}else if((a|0)==2446672|(a|0)==3145712|(a|0)==2097152|(a|0)==3141632|(a|0)==2318336|(a|0)==2318344){f=e}else{f=0}return f|0}function cCQ(a,b){a=a|0;b=b|0;if(!((a|0)==2446673|(a|0)==3145713|(a|0)==3141633|(a|0)==2318337|(a|0)==2318341|(a|0)==2318345|(a|0)==2318349)){return}c[2385314]=c[2385314]<<8;return}function cCR(a,b){a=a|0;b=b|0;if((a|0)==2167058){c[2385314]=-16777216}else if((a|0)==2451330){c[2385314]=-262523391}else if((a|0)==2306866){c[2385314]=65535}else if((a|0)==2376770){c[2385314]=16711680}else if((a|0)==2446674){c[2385314]=-16711936}else if((a|0)==2369554){c[2385314]=-2126371816}return}function cCS(a,b){a=a|0;b=b|0;var d=0;b=i;i=i+16|0;d=b|0;if((a&64|0)==0){i=b;return 0}gGz(d|0,0,12);c[d>>2]=9541256;c[d+4>>2]=4;c[d+12>>2]=549136;gj[c[2076592]&4095](d)|0;i=b;return 0}function cCT(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>8){f=9763192;break}f=2866336+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cCU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>8){g=9763192;break}g=2866336+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cCV(){var a=0;a=c[1865440]|0;c[a+4>>2]=5892;c[a+16>>2]=5716;return cAG()|0}function cCW(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>5){f=9763192;break}f=4382056+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cCX(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>5){g=9763192;break}g=4382056+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cCY(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>13){f=9763192;break}f=6548336+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cCZ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>13){g=9763192;break}g=6548336+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cC_(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>13){f=9763192;break}f=7074504+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cC$(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>13){g=9763192;break}g=7074504+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cC0(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>14){f=9763192;break}f=6604720+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cC1(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>14){g=9763192;break}g=6604720+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cC2(){c[c[1865440]>>2]=1480;return cAG()|0}function cC3(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>12){f=9763192;break}f=2868464+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cC4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>12){g=9763192;break}g=2868464+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cC5(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>13){f=9763192;break}f=1554880+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cC6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>13){g=9763192;break}g=1554880+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cC7(){c[c[1865440]>>2]=8116;return cAG()|0}function cC8(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>13){f=9763192;break}f=2333592+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cC9(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>13){g=9763192;break}g=2333592+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cDa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>8){f=9763192;break}f=2215792+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cDb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>8){g=9763192;break}g=2215792+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cDc(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>14){f=9763192;break}f=4433688+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cDd(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>14){g=9763192;break}g=4433688+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cDe(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>16){f=9763192;break}f=2344328+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cDf(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>16){g=9763192;break}g=2344328+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cDg(){c[c[1865440]>>2]=8522;return cAG()|0}function cDh(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>12){f=9763192;break}f=2864880+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cDi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>12){g=9763192;break}g=2864880+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cDj(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>11){f=9763192;break}f=2214448+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cDk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>11){g=9763192;break}g=2214448+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cDl(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>13){f=9763192;break}f=6546768+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cDm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>13){g=9763192;break}g=6546768+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cDn(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>13){f=9763192;break}f=5829336+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cDo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>13){g=9763192;break}g=5829336+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cDp(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>16){f=9763192;break}f=4431784+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cDq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>16){g=9763192;break}g=4431784+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cDr(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>13){f=9763192;break}f=2342760+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cDs(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>13){g=9763192;break}g=2342760+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cDt(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>13){f=9763192;break}f=4713384+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cDu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>13){g=9763192;break}g=4713384+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cDv(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>14){f=9763192;break}f=6497048+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cDw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>14){g=9763192;break}g=6497048+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cDx(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>15){f=9763192;break}f=5730712+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cDy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>15){g=9763192;break}g=5730712+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cDz(){c[c[1865440]>>2]=1898;return cAG()|0}function cDA(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>14){f=9763192;break}f=7072824+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cDB(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>14){g=9763192;break}g=7072824+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cDC(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>14){f=9763192;break}f=6603040+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cDD(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>14){g=9763192;break}g=6603040+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cDE(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>14){f=9763192;break}f=6545088+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cDF(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>14){g=9763192;break}g=6545088+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cDG(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>14){f=9763192;break}f=5827656+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cDH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>14){g=9763192;break}g=5827656+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cDI(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>10){f=9763192;break}f=2213216+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cDJ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>10){g=9763192;break}g=2213216+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cDK(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>14){f=9763192;break}f=5830904+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cDL(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>14){g=9763192;break}g=5830904+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cDM(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>14){f=9763192;break}f=4430104+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cDN(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>14){g=9763192;break}g=4430104+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cDO(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>14){f=9763192;break}f=2341080+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cDP(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>14){g=9763192;break}g=2341080+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cDQ(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>14){f=9763192;break}f=2395088+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cDR(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>14){g=9763192;break}g=2395088+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cDS(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>14){f=9763192;break}f=1426504+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cDT(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>14){g=9763192;break}g=1426504+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cDU(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>12){f=9763192;break}f=6543632+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cDV(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>12){g=9763192;break}g=6543632+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cDW(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>12){f=9763192;break}f=5826200+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cDX(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>12){g=9763192;break}g=5826200+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cDY(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>12){f=9763192;break}f=5824744+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cDZ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>12){g=9763192;break}g=5824744+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cD_(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>12){f=9763192;break}f=2680960+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cD$(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>12){g=9763192;break}g=2680960+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cD0(a){a=a|0;a=c[2113310]|0;return((a-5|0)>>>0<4|(a|0)==10|(a|0)==11?-256:-255)|0}function cD1(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>12){f=9763192;break}f=7348504+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cD2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>12){g=9763192;break}g=7348504+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cD3(){var a=0;c[2438]=266;a=c[1865440]|0;c[a>>2]=788;c[a+4>>2]=11352;return cAG()|0}function cD4(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>12){f=9763192;break}f=4591096+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cD5(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>12){g=9763192;break}g=4591096+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cD6(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>13){f=9763192;break}f=2655368+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cD7(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>13){g=9763192;break}g=2655368+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cD8(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>13){f=9763192;break}f=1512792+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cD9(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>13){g=9763192;break}g=1512792+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cEa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>13){f=9763192;break}f=2647192+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cEb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>13){g=9763192;break}g=2647192+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cEc(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=751624+(d*112|0)|0;break}}else{if(b>>>0>6){f=9763192;break}f=4651256+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cEd(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=751624+(e*112|0)|0;break}}else{if(b>>>0>6){g=9763192;break}g=4651256+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cEe(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=692704+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function cEf(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>42){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=755096+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function cEg(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>13){f=9763192;break}f=6495480+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cEh(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>13){g=9763192;break}g=6495480+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cEi(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>13){f=9763192;break}f=5729144+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cEj(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>13){g=9763192;break}g=5729144+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cEk(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>13){f=9763192;break}f=5727576+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cEl(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>13){g=9763192;break}g=5727576+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cEm(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>9){f=9763192;break}f=5773448+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cEn(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>9){g=9763192;break}g=5773448+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cEo(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;do{if((d|0)==2140842){f=e&255;g=b[4865652]&255|f<<8;b[4865652]=g;h=g&65535;if((h|0)==144){c[(c[3541128]|0)+1024>>2]=12714237;g=c[2112932]|0;i=c[g>>2]|0;if(i>>>0>9){a[i+256|0]=-62;a[i+257|0]=0;a[i+258|0]=-3;a[i+259|0]=0;j=f;break}else{gg[c[g+196808+(i<<2)>>2]&4095](256,12714237);j=f;break}}else if((h|0)==240){c[(c[3541128]|0)+1024>>2]=1313165101;h=c[2112932]|0;i=c[h>>2]|0;if(i>>>0>9){a[i+256|0]=69;a[i+257|0]=78;a[i+258|0]=45;a[i+259|0]=79;j=f;break}else{gg[c[h+196808+(i<<2)>>2]&4095](256,1313165101);j=f;break}}else{j=f;break}}else if((d|0)==2140843){j=e&255}else{return}}while(0);e=b[4865652]&-256|j;b[4865652]=e;j=e&65535;if((j|0)==240){c[(c[3541128]|0)+1024>>2]=1313165101;e=c[2112932]|0;d=c[e>>2]|0;if(d>>>0>9){a[d+256|0]=69;a[d+257|0]=78;a[d+258|0]=45;a[d+259|0]=79;return}else{gg[c[e+196808+(d<<2)>>2]&4095](256,1313165101);return}}else if((j|0)==144){c[(c[3541128]|0)+1024>>2]=12714237;j=c[2112932]|0;d=c[j>>2]|0;if(d>>>0>9){a[d+256|0]=-62;a[d+257|0]=0;a[d+258|0]=-3;a[d+259|0]=0;return}else{gg[c[j+196808+(d<<2)>>2]&4095](256,12714237);return}}else{return}}function cEp(d,e){d=d|0;e=e|0;var f=0;if((d|0)!=2140842){return}b[4865652]=e;d=e&65535;if((d|0)==240){c[(c[3541128]|0)+1024>>2]=1313165101;e=c[2112932]|0;f=c[e>>2]|0;if(f>>>0>9){a[f+256|0]=69;a[f+257|0]=78;a[f+258|0]=45;a[f+259|0]=79;return}else{gg[c[e+196808+(f<<2)>>2]&4095](256,1313165101);return}}else if((d|0)==144){c[(c[3541128]|0)+1024>>2]=12714237;d=c[2112932]|0;f=c[d>>2]|0;if(f>>>0>9){a[f+256|0]=-62;a[f+257|0]=0;a[f+258|0]=-3;a[f+259|0]=0;return}else{gg[c[d+196808+(f<<2)>>2]&4095](256,12714237);return}}else{return}}function cEq(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>15){f=9763192;break}f=6541840+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cEr(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>15){g=9763192;break}g=6541840+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cEs(){var a=0;a=c[1865440]|0;c[a>>2]=10074;c[a+4>>2]=4880;return cAG()|0}function cEt(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>15){f=9763192;break}f=5821160+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cEu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>15){g=9763192;break}g=5821160+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cEv(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>15){f=9763192;break}f=4592552+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cEw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>15){g=9763192;break}g=4592552+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cEx(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>15){f=9763192;break}f=5822952+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cEy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>15){g=9763192;break}g=5822952+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cEz(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>13){f=9763192;break}f=2653800+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cEA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>13){g=9763192;break}g=2653800+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cEB(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>6){f=9763192;break}f=2515328+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cEC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>6){g=9763192;break}g=2515328+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cED(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>12){f=9763192;break}f=5767512+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cEE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>12){g=9763192;break}g=5767512+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cEF(){var a=0;a=c[1865440]|0;c[a+4>>2]=3558;c[a+12>>2]=3422;return cAG()|0}function cEG(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=i;i=i+32|0;e=d|0;f=d+16|0;if((b|0)!=0){c[b>>2]=169767}if((a&64|0)==0){g=cAb(a,b)|0;i=d;return 0}gGz(f|0,0,12);c[f>>2]=9752936;c[f+4>>2]=2;c[f+12>>2]=67016;gj[c[2076592]&4095](f)|0;gGz(e|0,0,12);c[e>>2]=9752928;c[e+4>>2]=2;c[e+12>>2]=66848;gj[c[2076592]&4095](e)|0;g=cAb(a,b)|0;i=d;return 0}function cEH(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;if((a|0)!=3145712){return}a=b&65535;b=c[615696+((a>>>14&1|a&32|a>>>6<<1&2|a>>>8<<2&4|a>>>10<<3&8|a>>>12<<4&16)<<2)>>2]|0;if((b|0)==(c[2113148]|0)){return}c[2113148]=b;a=c[3541128]|0;d=c[2112932]|0;e=b-2097152|0;b=d+8192|0;f=2097152;while(1){g=a+(e+f)|0;c[b>>2]=g;c[b+131072>>2]=g;g=f+1024|0;if(g>>>0>3138559){break}else{b=b+4|0;f=g}}f=c[2113148]|0;b=a+(f+1042432)|0;c[d+12264>>2]=b;c[d+143336>>2]=b;b=a+(f+1043456)|0;c[d+12268>>2]=b;c[d+143340>>2]=b;b=a+(f+1044480)|0;c[d+12272>>2]=b;c[d+143344>>2]=b;b=a+(f+1045504)|0;c[d+12276>>2]=b;c[d+143348>>2]=b;b=a+(f+1046528)|0;c[d+12280>>2]=b;c[d+143352>>2]=b;return}function cEI(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>15){f=9763192;break}f=6540048+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cEJ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>15){g=9763192;break}g=6540048+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cEK(){var b=0,d=0;a[8452536]=0;b=c[2113146]|0;c[9721720+(b<<3)>>2]=3145720;c[9721724+(b<<3)>>2]=3145722;c[9708888+(b<<2)>>2]=3090;d=c[1865440]|0;c[d>>2]=3862;c[d+4>>2]=116;c[d+12>>2]=6938;c[d+16>>2]=5668;c[8452288+(b<<2)>>2]=9029;return cAG()|0}function cEL(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>15){f=9763192;break}f=5817352+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cEM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>15){g=9763192;break}g=5817352+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cEN(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>17){f=9763192;break}f=5819144+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cEO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>17){g=9763192;break}g=5819144+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cEP(){a[8452536]=0;return cAG()|0}function cEQ(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>14){f=9763192;break}f=5815672+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cER(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>14){g=9763192;break}g=5815672+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cES(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>15){f=9763192;break}f=5813880+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cET(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>15){g=9763192;break}g=5813880+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cEU(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;if((a|0)!=3145664){return}a=b&65535;b=c[615952+((a>>>9<<1&2|a>>>5&1|a>>>7<<2&4|a>>>6<<3&8|a>>>14<<4&16|a>>>12<<5&32)<<2)>>2]|0;if((b|0)==(c[2113148]|0)){return}c[2113148]=b;a=c[3541128]|0;d=c[2112932]|0;e=b-2097152|0;b=d+8192|0;f=2097152;while(1){g=a+(e+f)|0;c[b>>2]=g;c[b+131072>>2]=g;g=f+1024|0;if(g>>>0>3138559){break}else{b=b+4|0;f=g}}f=c[2113148]|0;b=a+(f+1042432)|0;c[d+12264>>2]=b;c[d+143336>>2]=b;b=a+(f+1043456)|0;c[d+12268>>2]=b;c[d+143340>>2]=b;b=a+(f+1044480)|0;c[d+12272>>2]=b;c[d+143344>>2]=b;b=a+(f+1045504)|0;c[d+12276>>2]=b;c[d+143348>>2]=b;b=a+(f+1046528)|0;c[d+12280>>2]=b;c[d+143352>>2]=b;return}function cEV(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>17){f=9763192;break}f=6572976+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cEW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>17){g=9763192;break}g=6572976+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cEX(){var b=0,d=0;a[8452536]=6;b=c[2113146]|0;c[9721720+(b<<3)>>2]=3145676;c[9721724+(b<<3)>>2]=3145712;c[9708888+(b<<2)>>2]=1804;d=c[1865440]|0;c[d>>2]=10410;c[d+4>>2]=116;c[d+12>>2]=6938;c[d+16>>2]=5668;c[8452288+(b<<2)>>2]=9029;return cAG()|0}function cEY(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;if((a|0)!=3145664){return}a=b&65535;b=c[615440+((a>>>8<<1&2|a>>>4&1|a>>>14<<2&4|a>>>2<<3&8|a>>>11<<4&16|a>>>13<<5&32)<<2)>>2]|0;if((b|0)==(c[2113148]|0)){return}c[2113148]=b;a=c[3541128]|0;d=c[2112932]|0;e=b-2097152|0;b=d+8192|0;f=2097152;while(1){g=a+(e+f)|0;c[b>>2]=g;c[b+131072>>2]=g;g=f+1024|0;if(g>>>0>3138559){break}else{b=b+4|0;f=g}}f=c[2113148]|0;b=a+(f+1042432)|0;c[d+12264>>2]=b;c[d+143336>>2]=b;b=a+(f+1043456)|0;c[d+12268>>2]=b;c[d+143340>>2]=b;b=a+(f+1044480)|0;c[d+12272>>2]=b;c[d+143344>>2]=b;b=a+(f+1045504)|0;c[d+12276>>2]=b;c[d+143348>>2]=b;b=a+(f+1046528)|0;c[d+12280>>2]=b;c[d+143352>>2]=b;return}function cEZ(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>15){f=9763192;break}f=5890560+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cE_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>15){g=9763192;break}g=5890560+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cE$(){var b=0,d=0;a[8452536]=6;b=c[2113146]|0;c[9721720+(b<<3)>>2]=3145676;c[9721724+(b<<3)>>2]=3145712;c[9708888+(b<<2)>>2]=3340;d=c[1865440]|0;c[d>>2]=12866;c[d+4>>2]=116;c[d+12>>2]=6938;c[d+16>>2]=5668;c[8452288+(b<<2)>>2]=9029;return cAG()|0}function cE0(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>15){f=9763192;break}f=5888768+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cE1(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>15){g=9763192;break}g=5888768+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cE2(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>11){f=9763192;break}f=4705488+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cE3(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>11){g=9763192;break}g=4705488+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cE4(){c[c[1865440]>>2]=5170;return cAG()|0}function cE5(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;if((a|0)!=3145700){return}a=b&65535;b=c[615184+((a>>>15<<2|a>>>14&1|a>>>12<<1&2|a>>>6<<3&8|a>>>3<<4&16|a>>>9<<5&32)<<2)>>2]|0;if((b|0)==(c[2113148]|0)){return}c[2113148]=b;a=c[3541128]|0;d=c[2112932]|0;e=b-2097152|0;b=d+8192|0;f=2097152;while(1){g=a+(e+f)|0;c[b>>2]=g;c[b+131072>>2]=g;g=f+1024|0;if(g>>>0>3138559){break}else{b=b+4|0;f=g}}f=c[2113148]|0;b=a+(f+1042432)|0;c[d+12264>>2]=b;c[d+143336>>2]=b;b=a+(f+1043456)|0;c[d+12268>>2]=b;c[d+143340>>2]=b;b=a+(f+1044480)|0;c[d+12272>>2]=b;c[d+143344>>2]=b;b=a+(f+1045504)|0;c[d+12276>>2]=b;c[d+143348>>2]=b;b=a+(f+1046528)|0;c[d+12280>>2]=b;c[d+143352>>2]=b;b=a+(f+1047552)|0;c[d+12284>>2]=b;c[d+143356>>2]=b;return}function cE6(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>15){f=9763192;break}f=5771656+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cE7(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>15){g=9763192;break}g=5771656+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cE8(){var b=0,d=0;a[8452536]=-83;b=c[2113146]|0;c[9721720+(b<<3)>>2]=0;c[9721724+(b<<3)>>2]=0;c[9708888+(b<<2)>>2]=1264;d=c[1865440]|0;c[d>>2]=9216;c[d+4>>2]=116;c[d+12>>2]=6938;c[d+16>>2]=5668;c[8452288+(b<<2)>>2]=9029;return cAG()|0}function cE9(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>14){f=9763192;break}f=4531576+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cFa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>14){g=9763192;break}g=4531576+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cFb(){a[8452536]=-83;return cAG()|0}function cFc(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>15){f=9763192;break}f=2561632+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cFd(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>15){g=9763192;break}g=2561632+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cFe(){c[c[1865440]>>2]=10032;a[8452536]=-83;return cAG()|0}function cFf(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;if((a|0)!=3145708){return}a=b&65535;b=c[614928+((a&8|a>>>15|a&32|a>>>14<<1&2|a>>>7<<2&4|a>>>10<<4&16)<<2)>>2]|0;if((b|0)==(c[2113148]|0)){return}c[2113148]=b;a=c[3541128]|0;d=c[2112932]|0;e=b-2097152|0;b=d+8192|0;f=2097152;while(1){g=a+(e+f)|0;c[b>>2]=g;c[b+131072>>2]=g;g=f+1024|0;if(g>>>0>3138559){break}else{b=b+4|0;f=g}}f=c[2113148]|0;b=a+(f+1042432)|0;c[d+12264>>2]=b;c[d+143336>>2]=b;b=a+(f+1043456)|0;c[d+12268>>2]=b;c[d+143340>>2]=b;b=a+(f+1044480)|0;c[d+12272>>2]=b;c[d+143344>>2]=b;b=a+(f+1045504)|0;c[d+12276>>2]=b;c[d+143348>>2]=b;b=a+(f+1046528)|0;c[d+12280>>2]=b;c[d+143352>>2]=b;return}function cFg(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>15){f=9763192;break}f=4610248+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cFh(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>15){g=9763192;break}g=4610248+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cFi(){var b=0,d=0;a[8452536]=0;b=c[2113146]|0;c[9721720+(b<<3)>>2]=3145688;c[9721724+(b<<3)>>2]=3145690;c[9708888+(b<<2)>>2]=560;d=c[1865440]|0;c[d>>2]=5366;c[d+4>>2]=116;c[d+12>>2]=6938;c[d+16>>2]=5668;c[8452288+(b<<2)>>2]=9029;return cAG()|0}function cFj(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>14){f=9763192;break}f=2691936+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cFk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>14){g=9763192;break}g=2691936+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cFl(){a[8452536]=0;return cAG()|0}function cFm(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>4){f=9763192;break}f=5623264+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cFn(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>4){g=9763192;break}g=5623264+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cFo(){a[8452536]=-67;return cAG()|0}function cFp(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>9){f=9763192;break}f=2306600+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cFq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>9){g=9763192;break}g=2306600+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cFr(){a[8452536]=-2;return cAG()|0}function cFs(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>14){f=9763192;break}f=4608568+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cFt(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>14){g=9763192;break}g=4608568+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cFu(){a[8452536]=30;return cAG()|0}function cFv(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>14){f=9763192;break}f=2690256+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cFw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>14){g=9763192;break}g=2690256+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cFx(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if((a|0)!=3145712){return}a=c[597944+((b&7)<<2)>>2]|0;if((a|0)==(c[2113148]|0)){return}c[2113148]=a;b=c[3541128]|0;d=a-2097152|0;a=(c[2112932]|0)+8192|0;e=2097152;while(1){f=b+(d+e)|0;c[a>>2]=f;c[a+131072>>2]=f;f=e+1024|0;if(f>>>0>3145727){break}else{a=a+4|0;e=f}}return}function cFy(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if((a|0)!=3145712){return}a=c[597944+((b&7)<<2)>>2]|0;if((a|0)==(c[2113148]|0)){return}c[2113148]=a;b=c[3541128]|0;d=a-2097152|0;a=(c[2112932]|0)+8192|0;e=2097152;while(1){f=b+(d+e)|0;c[a>>2]=f;c[a+131072>>2]=f;f=e+1024|0;if(f>>>0>3145727){break}else{a=a+4|0;e=f}}return}function cFz(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>15){f=9763192;break}f=2987856+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cFA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>15){g=9763192;break}g=2987856+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cFB(){var a=0;c[2438]=266;a=c[1865440]|0;c[a>>2]=10550;c[a+4>>2]=8880;c[a+12>>2]=2508;return cAG()|0}function cFC(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>15){f=9763192;break}f=4760736+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cFD(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>15){g=9763192;break}g=4760736+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cFE(){var a=0;c[2438]=266;a=c[1865440]|0;c[a>>2]=7036;c[a+4>>2]=4976;c[a+12>>2]=2508;return cAG()|0}function cFF(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>15){f=9763192;break}f=4762528+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cFG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>15){g=9763192;break}g=4762528+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cFH(){c[2438]=269;c[c[1865440]>>2]=11810;return cAG()|0}function cFI(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>12){f=9763192;break}f=4607112+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cFJ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>12){g=9763192;break}g=4607112+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cFK(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a[8452536]=-20;c[c[1865440]>>2]=738;b=cAG()|0;if((b|0)==0){d=0}else{return b|0}while(1){if((d|0)>=1024){e=44859;break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==0){break}else{d=d+1|0}}if((e|0)==44859){return b|0}d=gGq(16777216)|0;c[f>>2]=d;if((d|0)==0){return b|0}gGz(d|0,0,16777216);f=c[14127400+(c[2113146]<<2)>>2]|0;gGC(d|0,f|0,16777216)|0;g=0;while(1){h=(g>>>16&1|g&16711678|g<<16&65536)^675840;a[f+h|0]=a[614040+(h&7)|0]^a[d+g|0];h=g+1|0;if((h|0)<16777216){g=h}else{i=0;break}}while(1){if((i|0)>=1024){e=44858;break}j=9638528+(i<<2)|0;if((c[j>>2]|0)==(d|0)){break}else{i=i+1|0}}if((e|0)==44858){return b|0}gGr(d);c[j>>2]=0;return b|0}function cFL(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;d=i;i=i+65536|0;e=d|0;if((b|0)<=0){i=d;return}f=e|0;g=0;do{h=a+g|0;gGC(f|0,h|0,65536)|0;h=0;do{j=h>>3;k=j&7;l=a+(((j<<3&8|h&65072|h>>>((c[616260+(k*24|0)>>2]|0)>>>0)<<8&256|h>>>((c[616256+(k*24|0)>>2]|0)>>>0)<<7&128|h>>>((c[616252+(k*24|0)>>2]|0)>>>0)<<6&64|h>>>((c[616248+(k*24|0)>>2]|0)>>>0)<<2&4|h>>>((c[616244+(k*24|0)>>2]|0)>>>0)<<1&2|h>>>((c[616240+(k*24|0)>>2]|0)>>>0)&1)<<7)+g)|0;k=e+(h<<7)|0;gGC(l|0,k|0,128)|0;h=h+1|0;}while((h|0)<512);g=g+65536|0;}while((g|0)<(b|0));i=d;return}function cFM(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>13){f=9763192;break}f=2688688+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cFN(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>13){g=9763192;break}g=2688688+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cFO(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c[c[1865440]>>2]=11720;b=cAG()|0;if((b|0)==0){d=0}else{return b|0}while(1){if((d|0)>=1024){e=44904;break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==0){break}else{d=d+1|0}}if((e|0)==44904){return b|0}d=gGq(16777216)|0;c[f>>2]=d;if((d|0)==0){return b|0}gGz(d|0,0,16777216);f=c[14127400+(c[2113146]<<2)>>2]|0;gGC(d|0,f|0,16777216)|0;g=0;while(1){h=(g>>>16&1|g&16711678|g<<16&65536)^675840;a[f+h|0]=a[614040+(h&7)|0]^a[d+g|0];h=g+1|0;if((h|0)<16777216){g=h}else{i=0;break}}while(1){if((i|0)>=1024){e=44903;break}j=9638528+(i<<2)|0;if((c[j>>2]|0)==(d|0)){break}else{i=i+1|0}}if((e|0)==44903){return b|0}gGr(d);c[j>>2]=0;return b|0}function cFP(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>13){f=9763192;break}f=2705016+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cFQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>13){g=9763192;break}g=2705016+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cFR(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>13){f=9763192;break}f=2709720+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cFS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>13){g=9763192;break}g=2709720+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cFT(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>13){f=9763192;break}f=4618968+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cFU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>13){g=9763192;break}g=4618968+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cFV(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a[8452536]=-20;c[c[1865440]>>2]=3688;b=cAG()|0;if((b|0)==0){d=0}else{return b|0}while(1){if((d|0)>=1024){e=44983;break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==0){break}else{d=d+1|0}}if((e|0)==44983){return b|0}d=gGq(16777216)|0;c[f>>2]=d;if((d|0)==0){return b|0}gGz(d|0,0,16777216);f=c[14127400+(c[2113146]<<2)>>2]|0;gGC(d|0,f|0,16777216)|0;g=0;while(1){h=(g>>>16&1|g&16711678|g<<16&65536)^675840;a[f+h|0]=a[614040+(h&7)|0]^a[d+g|0];h=g+1|0;if((h|0)<16777216){g=h}else{i=0;break}}while(1){if((i|0)>=1024){e=44984;break}j=9638528+(i<<2)|0;if((c[j>>2]|0)==(d|0)){break}else{i=i+1|0}}if((e|0)==44984){return b|0}gGr(d);c[j>>2]=0;return b|0}function cFW(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>13){f=9763192;break}f=2711288+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cFX(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>13){g=9763192;break}g=2711288+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cFY(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a[8452536]=-20;c[c[1865440]>>2]=3276;b=cAG()|0;if((b|0)==0){d=0}else{return b|0}while(1){if((d|0)>=1024){e=45023;break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==0){break}else{d=d+1|0}}if((e|0)==45023){return b|0}d=gGq(16777216)|0;c[f>>2]=d;if((d|0)==0){return b|0}gGz(d|0,0,16777216);f=c[14127400+(c[2113146]<<2)>>2]|0;gGC(d|0,f|0,16777216)|0;g=0;while(1){h=(g>>>16&1|g&16711678|g<<16&65536)^675840;a[f+h|0]=a[614040+(h&7)|0]^a[d+g|0];h=g+1|0;if((h|0)<16777216){g=h}else{i=0;break}}while(1){if((i|0)>=1024){e=45024;break}j=9638528+(i<<2)|0;if((c[j>>2]|0)==(d|0)){break}else{i=i+1|0}}if((e|0)==45024){return b|0}gGr(d);c[j>>2]=0;return b|0}function cFZ(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0;if((a[(c[2432926]|0)+8188|0]|0)==0){b[(c[2432928]|0)+(d&131070)>>1]=e;return}f=d>>>1;g=e&65535;e=(g>>>4&1|g<<1&2|g>>>2<<6&64|g>>>3<<7&128|g>>>1<<5&32|g>>>5<<4&16|g>>>7<<3&8|g>>>6<<2&4)&255;g=(d>>>4&3|f&131040|f<<2&28)^2;f=(c[2427052]|0)+(g>>>5)|0;L53264:do{if(e<<24>>24==0){if((a[f]|0)!=0){break}d=c[2430884]|0;if((a[d+g|0]|0)==0){break}a[f]=1;h=g+32|0;i=g;while(1){if((i|0)>=(h|0)){break L53264}if((c[d+i>>2]|0)==0){i=i+4|0}else{break}}a[f]=0}else{a[f]=0}}while(0);a[(c[2430884]|0)+g|0]=e;return}function cF_(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;do{if((b|0)==3145713){e=((d&255)<<20&7340032)+1048576|0;f=e>>>0>7340031?1048576:e;if((f|0)==(c[2113148]|0)){break}c[2113148]=f;e=c[3541128]|0;g=f-2097152|0;f=(c[2112932]|0)+8192|0;h=2097152;while(1){i=e+(g+h)|0;c[f>>2]=i;c[f+131072>>2]=i;i=h+1024|0;if(i>>>0>3137535){break}else{f=f+4|0;h=i}}}}while(0);a[(c[2432926]|0)+(b&8191^1)|0]=d;return}function cF$(a,d){a=a|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;do{if((a|0)==3145720){if((b[(c[2432926]|0)+8184>>1]|0)==d<<16>>16){break}e=c[3541128]|0;f=(d&1)!=0?7340032:0;g=(c[2112932]|0)+256|0;h=65536;while(1){i=e+(f+h)|0;c[g>>2]=i;c[g+131072>>2]=i;i=h+1024|0;if(i>>>0>917503){break}else{g=g+4|0;h=i}}}else if((a|0)==3145712){h=((d&65535)<<20&7340032)+1048576|0;g=h>>>0>7340031?1048576:h;if((g|0)==(c[2113148]|0)){break}c[2113148]=g;h=c[3541128]|0;f=g-2097152|0;g=(c[2112932]|0)+8192|0;e=2097152;while(1){i=h+(f+e)|0;c[g>>2]=i;c[g+131072>>2]=i;i=e+1024|0;if(i>>>0>3137535){break}else{g=g+4|0;e=i}}}}while(0);b[(c[2432926]|0)+(a&8190)>>1]=d;return}function cF0(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>19){f=9763192;break}f=4612040+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cF1(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>19){g=9763192;break}g=4612040+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cF2(){var a=0,b=0,d=0,e=0;a=c[1865440]|0;c[a>>2]=6870;c[a+4>>2]=10286;c[a+12>>2]=2324;c[a+16>>2]=15328;c[8452488+(c[2113146]<<2)>>2]=131072;a=cAG()|0;if((a|0)!=0){return a|0}b=c[3541128]|0;d=b+8257536|0;c[2432928]=d;e=b+2088960|0;c[2432926]=e;gGz(d|0,0,131072);gGz(e|0,0,8192);return a|0}function cF3(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>22){f=9763192;break}f=2714648+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cF4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>22){g=9763192;break}g=2714648+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cF5(){c[c[1865440]>>2]=3508;return cAG()|0}function cF6(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>21){f=9763192;break}f=2694400+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cF7(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>21){g=9763192;break}g=2694400+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cF8(){c[c[1865440]>>2]=1200;return cAG()|0}function cF9(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>14){f=9763192;break}f=2685440+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cGa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>14){g=9763192;break}g=2685440+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cGb(){c[c[1865440]>>2]=5030;return cAG()|0}function cGc(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>12){f=9763192;break}f=5768968+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cGd(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>12){g=9763192;break}g=5768968+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cGe(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a[8452536]=25;c[c[1865440]>>2]=4720;b=0;while(1){if((b|0)>=1024){break}d=9638528+(b<<2)|0;if((c[d>>2]|0)==0){e=45173;break}else{b=b+1|0}}do{if((e|0)==45173){b=gGq(8192)|0;c[d>>2]=b;if((b|0)==0){break}c[2411924]=b;gGz(b|0,0,8192);b=c[1865440]|0;c[b+4>>2]=11564;c[b+12>>2]=4296;c[b+16>>2]=14502;b=cAG()|0;if((b|0)==0){f=0}else{g=b;return g|0}while(1){if((f|0)>=1024){g=0;e=45189;break}h=9638528+(f<<2)|0;if((c[h>>2]|0)==0){break}else{f=f+1|0}}if((e|0)==45189){return g|0}b=gGq(16777216)|0;c[h>>2]=b;if((b|0)==0){g=0;return g|0}gGz(b|0,0,16777216);i=c[14127400+(c[2113146]<<2)>>2]|0;gGC(b|0,i|0,16777216)|0;j=0;while(1){k=(j>>>16&1|j&16711678|j<<16&65536)^319489;a[i+k|0]=a[614384+(k&7)|0]^a[b+(j+16657654&16777215)|0];k=j+1|0;if((k|0)<16777216){j=k}else{l=0;break}}while(1){if((l|0)>=1024){g=0;e=45186;break}m=9638528+(l<<2)|0;if((c[m>>2]|0)==(b|0)){break}else{l=l+1|0}}if((e|0)==45186){return g|0}gGr(b);c[m>>2]=0;g=0;return g|0}}while(0);c[2411924]=0;g=1;return g|0}function cGf(){var a=0,b=0,d=0,e=0;a=c[2411924]|0;b=0;while(1){if((b|0)>=1024){break}d=9638528+(b<<2)|0;if((c[d>>2]|0)==(a|0)){e=45194;break}else{b=b+1|0}}if((e|0)==45194){gGr(a);c[d>>2]=0}c[2411924]=0;return cAK()|0}function cGg(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>12){f=9763192;break}f=4527544+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cGh(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>12){g=9763192;break}g=4527544+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cGi(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=1040816+(d*112|0)|0;break}}else{if(b>>>0>7){f=9763192;break}f=5774568+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cGj(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=1040816+(e*112|0)|0;break}}else{if(b>>>0>7){g=9763192;break}g=5774568+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cGk(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>39){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5775464+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function cGl(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if((a|0)!=3145716){return}a=(b&65535)<<16;if((c[2113148]|0)==(a|0)){return}c[2113148]=a;b=c[3541128]|0;d=a-2097152|0;a=(c[2112932]|0)+8192|0;e=2097152;while(1){f=b+(d+e)|0;c[a>>2]=f;c[a+131072>>2]=f;f=e+1024|0;if(f>>>0>3137535){break}else{a=a+4|0;e=f}}return}function cGm(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>14){f=9763192;break}f=4535088+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cGn(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>14){g=9763192;break}g=4535088+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cGo(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[1865440]|0;c[b>>2]=7548;c[b+4>>2]=2572;c[b+12>>2]=4296;a[8452536]=25;b=cAG()|0;if((b|0)==0){d=0}else{return b|0}while(1){if((d|0)>=1024){e=45287;break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==0){break}else{d=d+1|0}}if((e|0)==45287){return b|0}d=gGq(16777216)|0;c[f>>2]=d;if((d|0)==0){return b|0}gGz(d|0,0,16777216);f=c[14127400+(c[2113146]<<2)>>2]|0;gGC(d|0,f|0,16777216)|0;g=0;while(1){h=(g>>>16&1|g&16711678|g<<16&65536)^319489;a[f+h|0]=a[614384+(h&7)|0]^a[d+(g+16657654&16777215)|0];h=g+1|0;if((h|0)<16777216){g=h}else{i=0;break}}while(1){if((i|0)>=1024){e=45289;break}j=9638528+(i<<2)|0;if((c[j>>2]|0)==(d|0)){break}else{i=i+1|0}}if((e|0)==45289){return b|0}gGr(d);c[j>>2]=0;return b|0}function cGp(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=1002776+(d*112|0)|0;break}}else{if(b>>>0>5){f=9763192;break}f=5659760+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cGq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=1002776+(e*112|0)|0;break}}else{if(b>>>0>5){g=9763192;break}g=5659760+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cGr(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>39){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5775464+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function cGs(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a[8452536]=87;c[c[1865440]>>2]=12490;b=0;while(1){if((b|0)>=1024){break}d=9638528+(b<<2)|0;if((c[d>>2]|0)==0){e=45324;break}else{b=b+1|0}}do{if((e|0)==45324){b=gGq(8192)|0;c[d>>2]=b;if((b|0)==0){break}c[2411924]=b;gGz(b|0,0,8192);b=c[1865440]|0;c[b+4>>2]=11564;c[b+12>>2]=4296;c[b+16>>2]=14502;b=cAG()|0;if((b|0)==0){f=0}else{g=b;return g|0}while(1){if((f|0)>=1024){g=0;e=45336;break}h=9638528+(f<<2)|0;if((c[h>>2]|0)==0){break}else{f=f+1|0}}if((e|0)==45336){return g|0}b=gGq(16777216)|0;c[h>>2]=b;if((b|0)==0){g=0;return g|0}gGz(b|0,0,16777216);i=c[14127400+(c[2113146]<<2)>>2]|0;gGC(b|0,i|0,16777216)|0;j=0;while(1){k=(j>>>16&1|j&16711678|j<<16&65536)^794624;a[i+k|0]=a[614368+(k&7)|0]^a[b+(j+16755752&16777215)|0];k=j+1|0;if((k|0)<16777216){j=k}else{l=0;break}}while(1){if((l|0)>=1024){g=0;e=45338;break}m=9638528+(l<<2)|0;if((c[m>>2]|0)==(b|0)){break}else{l=l+1|0}}if((e|0)==45338){return g|0}gGr(b);c[m>>2]=0;g=0;return g|0}}while(0);c[2411924]=0;g=1;return g|0}function cGt(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=1002776+(d*112|0)|0;break}}else{if(b>>>0>7){f=9763192;break}f=4373880+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cGu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=1002776+(e*112|0)|0;break}}else{if(b>>>0>7){g=9763192;break}g=4373880+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cGv(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>12){f=9763192;break}f=7325696+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cGw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>12){g=9763192;break}g=7325696+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cGx(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>14){f=9763192;break}f=4374776+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cGy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>14){g=9763192;break}g=4374776+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cGz(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;c[c[1865440]>>2]=4602;b=0;while(1){if((b|0)>=1024){break}d=9638528+(b<<2)|0;if((c[d>>2]|0)==0){e=45411;break}else{b=b+1|0}}do{if((e|0)==45411){b=gGq(8192)|0;c[d>>2]=b;if((b|0)==0){break}c[2411924]=b;gGz(b|0,0,8192);b=c[1865440]|0;c[b+4>>2]=11564;c[b+12>>2]=4296;c[b+16>>2]=14502;b=cAG()|0;if((b|0)!=0){f=b;return f|0}b=0;g=c[14127400+(c[2113146]<<2)>>2]|0;while(1){h=a[g]|0;i=g+1|0;a[g]=a[i]|0;a[i]=h;h=b+1|0;if((h|0)<8388608){b=h;g=g+2|0}else{f=0;break}}return f|0}}while(0);c[2411924]=0;f=1;return f|0}function cGA(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>16){f=9763192;break}f=4371976+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cGB(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>16){g=9763192;break}g=4371976+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cGC(){var b=0,d=0,e=0,f=0,g=0;c[c[1865440]>>2]=1262;b=cAG()|0;if((b|0)!=0){return b|0}d=0;e=c[14127400+(c[2113146]<<2)>>2]|0;while(1){f=a[e]|0;g=e+1|0;a[e]=a[g]|0;a[g]=f;f=d+1|0;if((f|0)<8388608){d=f;e=e+2|0}else{break}}return b|0}function cGD(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>15){f=9763192;break}f=2188400+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cGE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>15){g=9763192;break}g=2188400+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cGF(){var b=0,d=0,e=0,f=0,g=0;c[c[1865440]>>2]=3828;b=cAG()|0;if((b|0)!=0){return b|0}d=0;e=c[14127400+(c[2113146]<<2)>>2]|0;while(1){f=a[e]|0;g=e+1|0;a[e]=a[g]|0;a[g]=f;f=d+1|0;if((f|0)<8388608){d=f;e=e+2|0}else{break}}return b|0}function cGG(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>15){f=9763192;break}f=2186608+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cGH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>15){g=9763192;break}g=2186608+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cGI(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;c[c[1865440]>>2]=978;b=0;while(1){if((b|0)>=1024){break}d=9638528+(b<<2)|0;if((c[d>>2]|0)==0){e=45501;break}else{b=b+1|0}}do{if((e|0)==45501){b=gGq(8192)|0;c[d>>2]=b;if((b|0)==0){break}c[2411924]=b;gGz(b|0,0,8192);b=c[1865440]|0;c[b+4>>2]=11564;c[b+12>>2]=4296;c[b+16>>2]=14502;b=cAG()|0;if((b|0)!=0){f=b;return f|0}b=0;g=c[14127400+(c[2113146]<<2)>>2]|0;while(1){h=a[g]|0;i=g+1|0;a[g]=a[i]|0;a[i]=h;h=b+1|0;if((h|0)<8388608){b=h;g=g+2|0}else{f=0;break}}return f|0}}while(0);c[2411924]=0;f=1;return f|0}function cGJ(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>12){f=9763192;break}f=4428648+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cGK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>12){g=9763192;break}g=4428648+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cGL(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a[8452536]=15;c[c[1865440]>>2]=2888;b=cAG()|0;if((b|0)==0){d=0}else{return b|0}while(1){if((d|0)>=1024){e=45546;break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==0){break}else{d=d+1|0}}if((e|0)==45546){return b|0}d=gGq(16777216)|0;c[f>>2]=d;if((d|0)==0){return b|0}gGz(d|0,0,16777216);f=c[14127400+(c[2113146]<<2)>>2]|0;gGC(d|0,f|0,16777216)|0;g=0;while(1){h=(g>>>16&1|g&16711678|g<<16&65536)^40960;a[f+h|0]=a[614016+(h&7)|0]^a[d+(g+16691904&16777215)|0];h=g+1|0;if((h|0)<16777216){g=h}else{i=0;break}}while(1){if((i|0)>=1024){e=45545;break}j=9638528+(i<<2)|0;if((c[j>>2]|0)==(d|0)){break}else{i=i+1|0}}if((e|0)==45545){return b|0}gGr(d);c[j>>2]=0;return b|0}function cGM(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>12){f=9763192;break}f=2338280+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cGN(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>12){g=9763192;break}g=2338280+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cGO(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>11){f=9763192;break}f=2339736+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cGP(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>11){g=9763192;break}g=2339736+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cGQ(){var b=0,d=0,e=0,f=0,g=0;c[c[1865440]>>2]=252;b=cAG()|0;if((b|0)!=0){return b|0}d=c[14127400+(c[2113146]<<2)>>2]|0;e=0;do{f=d+e|0;g=a[f]|0;a[f]=g&32|g<<7|g&16|g&8|g&4|(g&255)>>>7|(g&255)>>>1<<6&64|(g&255)>>>6<<1&2;e=e+1|0;}while((e|0)<16777216);return b|0}function cGR(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=797664+(d*112|0)|0;break}}else{if(b>>>0>10){f=9763192;break}f=2699888+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cGS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=797664+(e*112|0)|0;break}}else{if(b>>>0>10){g=9763192;break}g=2699888+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cGT(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>34){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=2701120+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function cGU(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;c[c[1865440]>>2]=2534;c[8452488+(c[2113146]<<2)>>2]=1048576;a[8452536]=-99;b=0;while(1){if((b|0)>=1024){break}d=9638528+(b<<2)|0;if((c[d>>2]|0)==0){e=45629;break}else{b=b+1|0}}do{if((e|0)==45629){b=gGq(8192)|0;c[d>>2]=b;if((b|0)==0){break}c[2411924]=b;gGz(b|0,0,8192);b=c[1865440]|0;c[b+4>>2]=11564;c[b+12>>2]=4296;c[b+16>>2]=14502;b=cAG()|0;if((b|0)==0){f=0}else{g=b;return g|0}while(1){if((f|0)>=1024){break}h=9638528+(f<<2)|0;if((c[h>>2]|0)==0){e=45634;break}else{f=f+1|0}}L53999:do{if((e|0)==45634){b=gGq(16777216)|0;c[h>>2]=b;if((b|0)==0){break}gGz(b|0,0,16777216);i=c[14127400+(c[2113146]<<2)>>2]|0;gGC(b|0,i|0,16777216)|0;j=0;while(1){k=(j>>>16&1|j&16711678|j<<16&65536)^684033;a[i+k|0]=a[607552+(k&7)|0]^a[b+(j+16717034&16777215)|0];k=j+1|0;if((k|0)<16777216){j=k}else{l=0;break}}while(1){if((l|0)>=1024){break L53999}m=9638528+(l<<2)|0;if((c[m>>2]|0)==(b|0)){break}else{l=l+1|0}}gGr(b);c[m>>2]=0}}while(0);j=c[3540996]|0;i=0;while(1){k=j+i|0;n=a[k]|0;a[k]=(n&255)>>>5<<7|n&88|n<<2&4|(n&255)>>>7<<1|(n&255)>>>2&1|(n&255)>>>1<<5&32;n=i+1|0;if((n|0)<524288){i=n}else{g=0;break}}return g|0}}while(0);c[2411924]=0;g=1;return g|0}function cGV(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>13){f=9763192;break}f=4605544+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cGW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>13){g=9763192;break}g=4605544+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cGX(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a[8452536]=-99;c[c[1865440]>>2]=10862;b=0;while(1){if((b|0)>=1024){break}d=9638528+(b<<2)|0;if((c[d>>2]|0)==0){e=45671;break}else{b=b+1|0}}do{if((e|0)==45671){b=gGq(8192)|0;c[d>>2]=b;if((b|0)==0){break}c[2411924]=b;gGz(b|0,0,8192);b=c[1865440]|0;c[b+4>>2]=11564;c[b+12>>2]=4296;c[b+16>>2]=14502;b=cAG()|0;if((b|0)==0){f=0}else{g=b;return g|0}while(1){if((f|0)>=1024){g=0;e=45683;break}h=9638528+(f<<2)|0;if((c[h>>2]|0)==0){break}else{f=f+1|0}}if((e|0)==45683){return g|0}b=gGq(16777216)|0;c[h>>2]=b;if((b|0)==0){g=0;return g|0}gGz(b|0,0,16777216);i=c[14127400+(c[2113146]<<2)>>2]|0;gGC(b|0,i|0,16777216)|0;j=0;while(1){k=(j>>>16&1|j&16711678|j<<16&65536)^684033;a[i+k|0]=a[607552+(k&7)|0]^a[b+(j+16717034&16777215)|0];k=j+1|0;if((k|0)<16777216){j=k}else{l=0;break}}while(1){if((l|0)>=1024){g=0;e=45687;break}m=9638528+(l<<2)|0;if((c[m>>2]|0)==(b|0)){break}else{l=l+1|0}}if((e|0)==45687){return g|0}gGr(b);c[m>>2]=0;g=0;return g|0}}while(0);c[2411924]=0;g=1;return g|0}function cGY(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>13){f=9763192;break}f=2687120+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cGZ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>13){g=9763192;break}g=2687120+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cG_(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a[8452536]=-99;c[c[1865440]>>2]=6468;b=0;while(1){if((b|0)>=1024){break}d=9638528+(b<<2)|0;if((c[d>>2]|0)==0){e=45714;break}else{b=b+1|0}}do{if((e|0)==45714){b=gGq(8192)|0;c[d>>2]=b;if((b|0)==0){break}c[2411924]=b;gGz(b|0,0,8192);b=c[1865440]|0;c[b+4>>2]=11564;c[b+12>>2]=4296;c[b+16>>2]=14502;b=cAG()|0;if((b|0)==0){f=0}else{g=b;return g|0}while(1){if((f|0)>=1024){g=0;e=45726;break}h=9638528+(f<<2)|0;if((c[h>>2]|0)==0){break}else{f=f+1|0}}if((e|0)==45726){return g|0}b=gGq(16777216)|0;c[h>>2]=b;if((b|0)==0){g=0;return g|0}gGz(b|0,0,16777216);i=c[14127400+(c[2113146]<<2)>>2]|0;gGC(b|0,i|0,16777216)|0;j=0;while(1){k=(j>>>16&1|j&16711678|j<<16&65536)^684033;a[i+k|0]=a[607552+(k&7)|0]^a[b+(j+16717034&16777215)|0];k=j+1|0;if((k|0)<16777216){j=k}else{l=0;break}}while(1){if((l|0)>=1024){g=0;e=45731;break}m=9638528+(l<<2)|0;if((c[m>>2]|0)==(b|0)){break}else{l=l+1|0}}if((e|0)==45731){return g|0}gGr(b);c[m>>2]=0;g=0;return g|0}}while(0);c[2411924]=0;g=1;return g|0}function cG$(b){b=b|0;return a[(c[2411924]|0)+8178|0]|0}function cG0(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>13){f=9763192;break}f=4617400+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cG1(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>13){g=9763192;break}g=4617400+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cG2(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a[8452536]=-99;b=c[1865440]|0;c[b>>2]=8130;d=0;while(1){if((d|0)>=1024){e=b;break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==0){g=45758;break}else{d=d+1|0}}do{if((g|0)==45758){d=gGq(8192)|0;c[f>>2]=d;if((d|0)==0){e=c[1865440]|0;break}c[2411924]=d;gGz(d|0,0,8192);d=c[1865440]|0;c[d+4>>2]=11564;c[d+12>>2]=4296;c[d+16>>2]=14502;d=cAG()|0;c[(c[1865440]|0)+4>>2]=6080;if((d|0)==0){h=0}else{i=d;return i|0}while(1){if((h|0)>=1024){i=0;g=45771;break}j=9638528+(h<<2)|0;if((c[j>>2]|0)==0){break}else{h=h+1|0}}if((g|0)==45771){return i|0}d=gGq(16777216)|0;c[j>>2]=d;if((d|0)==0){i=0;return i|0}gGz(d|0,0,16777216);b=c[14127400+(c[2113146]<<2)>>2]|0;gGC(d|0,b|0,16777216)|0;k=0;while(1){l=(k>>>16&1|k&16711678|k<<16&65536)^684033;a[b+l|0]=a[607552+(l&7)|0]^a[d+(k+16717034&16777215)|0];l=k+1|0;if((l|0)<16777216){k=l}else{m=0;break}}while(1){if((m|0)>=1024){i=0;g=45776;break}n=9638528+(m<<2)|0;if((c[n>>2]|0)==(d|0)){break}else{m=m+1|0}}if((g|0)==45776){return i|0}gGr(d);c[n>>2]=0;i=0;return i|0}}while(0);c[2411924]=0;c[e+4>>2]=6080;i=1;return i|0}function cG3(a,e){a=a|0;e=e|0;var f=0,g=0,h=0;f=c[2411924]|0;b[f+(a&8190)>>1]=e;if((a|0)!=3145714){return}a=(d[f+8178|0]|0)<<8|(d[f+8179|0]|0)<<16|(d[f+8176|0]|0);f=a+1048576|0;if((f|0)==(c[2113148]|0)){return}c[2113148]=f;f=c[3541128]|0;e=a-1048576|0;a=(c[2112932]|0)+8192|0;g=2097152;while(1){h=f+(e+g)|0;c[a>>2]=h;c[a+131072>>2]=h;h=g+1024|0;if(h>>>0>3137535){break}else{a=a+4|0;g=h}}return}function cG4(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>14){f=9763192;break}f=2701544+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cG5(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>14){g=9763192;break}g=2701544+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cG6(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a[8452536]=-99;b=c[1865440]|0;c[b>>2]=10104;d=0;while(1){if((d|0)>=1024){e=b;break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==0){g=45810;break}else{d=d+1|0}}do{if((g|0)==45810){d=gGq(8192)|0;c[f>>2]=d;if((d|0)==0){e=c[1865440]|0;break}c[2411924]=d;gGz(d|0,0,8192);d=c[1865440]|0;c[d+4>>2]=11564;c[d+12>>2]=4296;c[d+16>>2]=14502;d=cAG()|0;c[(c[1865440]|0)+4>>2]=9264;if((d|0)==0){h=0}else{i=d;return i|0}while(1){if((h|0)>=1024){i=0;g=45828;break}j=9638528+(h<<2)|0;if((c[j>>2]|0)==0){break}else{h=h+1|0}}if((g|0)==45828){return i|0}d=gGq(16777216)|0;c[j>>2]=d;if((d|0)==0){i=0;return i|0}gGz(d|0,0,16777216);b=c[14127400+(c[2113146]<<2)>>2]|0;gGC(d|0,b|0,16777216)|0;k=0;while(1){l=(k>>>16&1|k&16711678|k<<16&65536)^684033;a[b+l|0]=a[607552+(l&7)|0]^a[d+(k+16717034&16777215)|0];l=k+1|0;if((l|0)<16777216){k=l}else{m=0;break}}while(1){if((m|0)>=1024){i=0;g=45827;break}n=9638528+(m<<2)|0;if((c[n>>2]|0)==(d|0)){break}else{m=m+1|0}}if((g|0)==45827){return i|0}gGr(d);c[n>>2]=0;i=0;return i|0}}while(0);c[2411924]=0;c[e+4>>2]=9264;i=1;return i|0}function cG7(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>14){f=9763192;break}f=4615720+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cG8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>14){g=9763192;break}g=4615720+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cG9(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>12){f=9763192;break}f=2698432+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cHa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>12){g=9763192;break}g=2698432+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cHb(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a[8452536]=-99;b=c[1865440]|0;c[b>>2]=3528;d=0;while(1){if((d|0)>=1024){e=b;break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==0){g=45876;break}else{d=d+1|0}}do{if((g|0)==45876){d=gGq(8192)|0;c[f>>2]=d;if((d|0)==0){e=c[1865440]|0;break}c[2411924]=d;gGz(d|0,0,8192);d=c[1865440]|0;c[d+4>>2]=11564;c[d+12>>2]=4296;c[d+16>>2]=14502;d=cAG()|0;c[(c[1865440]|0)+4>>2]=6080;if((d|0)==0){h=0}else{i=d;return i|0}while(1){if((h|0)>=1024){i=0;g=45893;break}j=9638528+(h<<2)|0;if((c[j>>2]|0)==0){break}else{h=h+1|0}}if((g|0)==45893){return i|0}d=gGq(16777216)|0;c[j>>2]=d;if((d|0)==0){i=0;return i|0}gGz(d|0,0,16777216);b=c[14127400+(c[2113146]<<2)>>2]|0;gGC(d|0,b|0,16777216)|0;k=0;while(1){l=(k>>>16&1|k&16711678|k<<16&65536)^684033;a[b+l|0]=a[607552+(l&7)|0]^a[d+(k+16717034&16777215)|0];l=k+1|0;if((l|0)<16777216){k=l}else{m=0;break}}while(1){if((m|0)>=1024){i=0;g=45892;break}n=9638528+(m<<2)|0;if((c[n>>2]|0)==(d|0)){break}else{m=m+1|0}}if((g|0)==45892){return i|0}gGr(d);c[n>>2]=0;i=0;return i|0}}while(0);c[2411924]=0;c[e+4>>2]=6080;i=1;return i|0}function cHc(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>12){f=9763192;break}f=2346232+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cHd(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>12){g=9763192;break}g=2346232+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cHe(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a[8452536]=13;c[c[1865440]>>2]=12196;b=cAG()|0;if((b|0)==0){d=0}else{return b|0}while(1){if((d|0)>=1024){e=45930;break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==0){break}else{d=d+1|0}}if((e|0)==45930){return b|0}d=gGq(16777216)|0;c[f>>2]=d;if((d|0)==0){return b|0}gGz(d|0,0,16777216);f=c[14127400+(c[2113146]<<2)>>2]|0;gGC(d|0,f|0,16777216)|0;g=0;while(1){h=(g>>>16&1|g&16711678|g<<16&65536)^8192;a[f+h|0]=a[607264+(h&7)|0]^a[d+(g+16757824&16777215)|0];h=g+1|0;if((h|0)<16777216){g=h}else{i=0;break}}while(1){if((i|0)>=1024){e=45929;break}j=9638528+(i<<2)|0;if((c[j>>2]|0)==(d|0)){break}else{i=i+1|0}}if((e|0)==45929){return b|0}gGr(d);c[j>>2]=0;return b|0}function cHf(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>12){f=9763192;break}f=1403984+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cHg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>12){g=9763192;break}g=1403984+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cHh(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>12){f=9763192;break}f=1011248+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cHi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>12){g=9763192;break}g=1011248+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cHj(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>11){f=9763192;break}f=4563304+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cHk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>11){g=9763192;break}g=4563304+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cHl(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>11){f=9763192;break}f=2626248+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cHm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>11){g=9763192;break}g=2626248+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cHn(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>12){f=9763192;break}f=4518424+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cHo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>12){g=9763192;break}g=4518424+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cHp(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>12){f=9763192;break}f=2522560+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cHq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>12){g=9763192;break}g=2522560+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cHr(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>8){f=9763192;break}f=3080848+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cHs(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>8){g=9763192;break}g=3080848+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cHt(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>7){f=9763192;break}f=4767232+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cHu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>7){g=9763192;break}g=4767232+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cHv(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>10){f=9763192;break}f=5642160+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cHw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>10){g=9763192;break}g=5642160+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cHx(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>8){f=9763192;break}f=2521552+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cHy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>8){g=9763192;break}g=2521552+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cHz(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>9){f=9763192;break}f=7324568+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cHA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>9){g=9763192;break}g=7324568+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cHB(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>9){f=9763192;break}f=6987656+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cHC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>9){g=9763192;break}g=6987656+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cHD(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>9){f=9763192;break}f=6454896+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cHE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>9){g=9763192;break}g=6454896+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cHF(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>10){f=9763192;break}f=7323336+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cHG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>10){g=9763192;break}g=7323336+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cHH(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>12){f=9763192;break}f=6986200+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cHI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>12){g=9763192;break}g=6986200+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cHJ(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>12){f=9763192;break}f=7076072+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cHK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>12){g=9763192;break}g=7076072+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cHL(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>13){f=9763192;break}f=7321768+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cHM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>13){g=9763192;break}g=7321768+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cHN(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>5){f=9763192;break}f=2568208+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cHO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>5){g=9763192;break}g=2568208+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cHP(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>9){f=9763192;break}f=4498680+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cHQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>9){g=9763192;break}g=4498680+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cHR(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>13){f=9763192;break}f=2504640+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cHS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>13){g=9763192;break}g=2504640+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cHT(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>8){f=9763192;break}f=2112608+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cHU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>8){g=9763192;break}g=2112608+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cHV(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>5){f=9763192;break}f=2059016+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cHW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>5){g=9763192;break}g=2059016+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cHX(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>6){f=9763192;break}f=2097016+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cHY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>6){g=9763192;break}g=2097016+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cHZ(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>5){f=9763192;break}f=4650584+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cH_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>5){g=9763192;break}g=4650584+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cH$(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>13){f=9763192;break}f=4469768+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cH0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>13){g=9763192;break}g=4469768+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cH1(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>13){f=9763192;break}f=3074240+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cH2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>13){g=9763192;break}g=3074240+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cH3(){a[8452536]=-97;return cAG()|0}function cH4(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>10){f=9763192;break}f=2433248+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cH5(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>10){g=9763192;break}g=2433248+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cH6(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>12){f=9763192;break}f=2231584+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cH7(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>12){g=9763192;break}g=2231584+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cH8(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>10){f=9763192;break}f=2084480+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cH9(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>10){g=9763192;break}g=2084480+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cIa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>9){f=9763192;break}f=4623592+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cIb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>9){g=9763192;break}g=4623592+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cIc(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>8){f=9763192;break}f=4377800+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cId(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>8){g=9763192;break}g=4377800+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cIe(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>5){f=9763192;break}f=2828632+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cIf(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>5){g=9763192;break}g=2828632+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cIg(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>5){f=9763192;break}f=2630728+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cIh(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>5){g=9763192;break}g=2630728+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cIi(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>8){f=9763192;break}f=2629720+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cIj(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>8){g=9763192;break}g=2629720+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cIk(){a[8452536]=-1;return cAG()|0}function cIl(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>4){f=9763192;break}f=7024160+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cIm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>4){g=9763192;break}g=7024160+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cIn(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>8){f=9763192;break}f=5752920+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cIo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>8){g=9763192;break}g=5752920+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cIp(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>5){f=9763192;break}f=4681448+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cIq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>5){g=9763192;break}g=4681448+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cIr(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>7){f=9763192;break}f=2573120+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cIs(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>7){g=9763192;break}g=2573120+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cIt(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>6){f=9763192;break}f=2468488+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cIu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>6){g=9763192;break}g=2468488+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cIv(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>10){f=9763192;break}f=2729440+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cIw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>10){g=9763192;break}g=2729440+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cIx(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>8){f=9763192;break}f=2516784+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cIy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>8){g=9763192;break}g=2516784+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cIz(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>8){f=9763192;break}f=4539680+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cIA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>8){g=9763192;break}g=4539680+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cIB(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>8){f=9763192;break}f=3117088+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cIC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>8){g=9763192;break}g=3117088+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cID(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>8){f=9763192;break}f=2116752+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cIE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>8){g=9763192;break}g=2116752+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cIF(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>8){f=9763192;break}f=6518376+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cIG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>8){g=9763192;break}g=6518376+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cIH(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>9){f=9763192;break}f=2064856+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cII(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>9){g=9763192;break}g=2064856+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cIJ(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>14){f=9763192;break}f=5690384+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cIK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>14){g=9763192;break}g=5690384+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cIL(){a[8452536]=5;return cAG()|0}function cIM(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>9){f=9763192;break}f=4463344+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cIN(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>9){g=9763192;break}g=4463344+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cIO(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>9){f=9763192;break}f=2411744+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cIP(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>9){g=9763192;break}g=2411744+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cIQ(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>7){f=9763192;break}f=4381160+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cIR(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>7){g=9763192;break}g=4381160+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cIS(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>12){f=9763192;break}f=2403568+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cIT(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>12){g=9763192;break}g=2403568+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cIU(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>7){f=9763192;break}f=6502040+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cIV(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>7){g=9763192;break}g=6502040+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cIW(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>8){f=9763192;break}f=2206608+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cIX(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>8){g=9763192;break}g=2206608+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cIY(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>13){f=9763192;break}f=2283208+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cIZ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>13){g=9763192;break}g=2283208+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cI_(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>13){f=9763192;break}f=1393232+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cI$(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>13){g=9763192;break}g=1393232+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cI0(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>12){f=9763192;break}f=2284776+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cI1(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>12){g=9763192;break}g=2284776+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cI2(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>13){f=9763192;break}f=2656936+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cI3(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>13){g=9763192;break}g=2656936+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cI4(){var b=0,d=0,e=0,f=0,g=0;c[c[1865440]>>2]=2528;b=cAG()|0;if((b|0)!=0){return b|0}d=c[14127400+(c[2113146]<<2)>>2]|0;e=0;do{f=d+e|0;g=a[f]|0;a[f]=g&32|g<<7|g&16|g&8|g&4|(g&255)>>>7|(g&255)>>>1<<6&64|(g&255)>>>6<<1&2;e=e+1|0;}while((e|0)<10485760);return b|0}function cI5(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>13){f=9763192;break}f=2843864+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cI6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>13){g=9763192;break}g=2843864+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cI7(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>11){f=9763192;break}f=2093448+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cI8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>11){g=9763192;break}g=2093448+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cI9(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>12){f=9763192;break}f=2463448+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cJa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>12){g=9763192;break}g=2463448+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cJb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>6){f=9763192;break}f=1443072+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cJc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>6){g=9763192;break}g=1443072+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cJd(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>8){f=9763192;break}f=2464904+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cJe(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>8){g=9763192;break}g=2464904+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cJf(){var d=0,e=0,f=0,g=0,h=0,i=0;a[8452536]=46;d=cAG()|0;if((d|0)!=0){return d|0}e=c[14127400+(c[2113146]<<2)>>2]|0;f=0;do{g=e+(f<<1)|0;h=e+((f|1)<<1)|0;i=b[h>>1]|0;b[h>>1]=b[g>>1]|0;b[g>>1]=i;f=f+2|0;}while((f|0)<2097152);return d|0}function cJg(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>4){f=9763192;break}f=6501224+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cJh(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>4){g=9763192;break}g=6501224+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cJi(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>8){f=9763192;break}f=2610976+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cJj(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>8){g=9763192;break}g=2610976+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cJk(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>12){f=9763192;break}f=2926256+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cJl(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>12){g=9763192;break}g=2926256+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cJm(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>13){f=9763192;break}f=2824016+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cJn(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>13){g=9763192;break}g=2824016+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cJo(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>7){f=9763192;break}f=4418792+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cJp(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>7){g=9763192;break}g=4418792+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cJq(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>8){f=9763192;break}f=6460584+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cJr(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>8){g=9763192;break}g=6460584+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cJs(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>8){f=9763192;break}f=2859160+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cJt(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>8){g=9763192;break}g=2859160+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cJu(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>9){f=9763192;break}f=1553760+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cJv(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>9){g=9763192;break}g=1553760+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cJw(){c[c[1865440]>>2]=10152;return cAG()|0}function cJx(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>11){f=9763192;break}f=2428768+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cJy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>11){g=9763192;break}g=2428768+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cJz(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>8){f=9763192;break}f=2253192+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cJA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>8){g=9763192;break}g=2253192+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cJB(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>8){f=9763192;break}f=2252184+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cJC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>8){g=9763192;break}g=2252184+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cJD(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>5){f=9763192;break}f=2446080+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cJE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>5){g=9763192;break}g=2446080+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cJF(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>32){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=848808+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function cJG(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=4){if((a|0)==0){d=0;return d|0}e=a;f=1450760+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}f=b-5|0;if(f>>>0>60){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;a=5760424+(f*12|0)|0;c[b>>2]=c[a>>2];c[b+4>>2]=c[a+4>>2];c[b+8>>2]=c[a+8>>2];d=0;return d|0}function cJH(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>6){f=9763192;break}f=3162304+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cJI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>6){g=9763192;break}g=3162304+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cJJ(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>5){f=9763192;break}f=2418800+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cJK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>5){g=9763192;break}g=2418800+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cJL(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>5){f=9763192;break}f=4515536+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cJM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>5){g=9763192;break}g=4515536+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cJN(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>7){f=9763192;break}f=5880216+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cJO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>7){g=9763192;break}g=5880216+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cJP(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>6){f=9763192;break}f=2514544+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cJQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>6){g=9763192;break}g=2514544+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cJR(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>8){f=9763192;break}f=3052064+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cJS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>8){g=9763192;break}g=3052064+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cJT(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>5){f=9763192;break}f=2419472+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cJU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>5){g=9763192;break}g=2419472+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cJV(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>10){f=9763192;break}f=3050832+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cJW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>10){g=9763192;break}g=3050832+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cJX(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>5){f=9763192;break}f=2855240+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cJY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>5){g=9763192;break}g=2855240+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cJZ(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>6){f=9763192;break}f=2985280+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cJ_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>6){g=9763192;break}g=2985280+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cJ$(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>4){f=9763192;break}f=5892352+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cJ0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>4){g=9763192;break}g=5892352+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cJ1(){a[8452536]=7;return cAG()|0}function cJ2(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>5){f=9763192;break}f=3116416+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cJ3(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>5){g=9763192;break}g=3116416+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cJ4(){a[8452536]=-8;return cAG()|0}function cJ5(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>10){f=9763192;break}f=5770424+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cJ6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>10){g=9763192;break}g=5770424+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cJ7(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a[8452536]=49;d=cAG()|0;if((d|0)!=0){return d|0}e=c[14127400+(c[2113146]<<2)>>2]|0;f=0;do{g=e+(f<<1)|0;h=b[g>>1]|0;i=e+((f|1)<<1)|0;j=e+((f|2)<<1)|0;k=b[j>>1]|0;l=e+((f|3)<<1)|0;m=b[l>>1]|0;b[l>>1]=b[i>>1]|0;b[j>>1]=h;b[i>>1]=m;b[g>>1]=k;f=f+4|0;}while((f|0)<8388608);return d|0}function cJ8(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>10){f=9763192;break}f=4530344+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cJ9(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>10){g=9763192;break}g=4530344+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cKa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>11){f=9763192;break}f=4536768+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cKb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>11){g=9763192;break}g=4536768+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cKc(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>11){f=9763192;break}f=7006776+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cKd(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>11){g=9763192;break}g=7006776+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cKe(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;a[8452536]=63;d=cAG()|0;if((d|0)!=0){return d|0}e=c[14127400+(c[2113146]<<2)>>2]|0;f=0;do{g=e+(f<<1)|0;h=b[g>>1]|0;i=e+((f|1)<<1)|0;j=b[i>>1]|0;k=e+((f|2)<<1)|0;l=b[k>>1]|0;m=e+((f|3)<<1)|0;n=e+((f|4)<<1)|0;o=b[n>>1]|0;p=e+((f|5)<<1)|0;q=b[p>>1]|0;r=e+((f|6)<<1)|0;s=b[r>>1]|0;t=e+((f|7)<<1)|0;u=b[t>>1]|0;b[t>>1]=b[m>>1]|0;b[r>>1]=l;b[p>>1]=j;b[n>>1]=h;b[m>>1]=u;b[k>>1]=s;b[i>>1]=q;b[g>>1]=o;f=f+8|0;}while((f|0)<8388608);return d|0}function cKf(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>12){f=9763192;break}f=5788456+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cKg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>12){g=9763192;break}g=5788456+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cKh(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a[8452536]=106;c[c[1865440]>>2]=738;b=cAG()|0;if((b|0)==0){d=0}else{return b|0}while(1){if((d|0)>=1024){e=47995;break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==0){break}else{d=d+1|0}}if((e|0)==47995){return b|0}d=gGq(16777216)|0;c[f>>2]=d;if((d|0)==0){return b|0}gGz(d|0,0,16777216);f=c[14127400+(c[2113146]<<2)>>2]|0;gGC(d|0,f|0,16777216)|0;g=0;while(1){h=(g>>>16&1|g&16711678|g<<16&65536)^4096;a[f+h|0]=a[614400+(h&7)|0]^a[d+(g+16764448&16777215)|0];h=g+1|0;if((h|0)<16777216){g=h}else{i=0;break}}while(1){if((i|0)>=1024){e=47996;break}j=9638528+(i<<2)|0;if((c[j>>2]|0)==(d|0)){break}else{i=i+1|0}}if((e|0)==47996){return b|0}gGr(d);c[j>>2]=0;return b|0}function cKi(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>14){f=9763192;break}f=2606944+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cKj(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>14){g=9763192;break}g=2606944+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cKk(){var b=0,d=0,e=0,f=0,g=0,h=0;c[c[1865440]>>2]=10676;b=cAG()|0;if((b|0)!=0){return b|0}d=c[14127400+(c[2113146]<<2)>>2]|0;e=0;f=d+4194304|0;while(1){g=a[f]|0;h=f+1|0;a[f]=a[h]|0;a[h]=g;g=e+1|0;if((g|0)<2097152){e=g;f=f+2|0}else{break}}f=0;e=d+12582912|0;while(1){d=a[e]|0;g=e+1|0;a[e]=a[g]|0;a[g]=d;d=f+1|0;if((d|0)<2097152){f=d;e=e+2|0}else{break}}return b|0}function cKl(){a[8452536]=-84;return cAG()|0}function cKm(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>4){f=9763192;break}f=2740992+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cKn(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>4){g=9763192;break}g=2740992+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cKo(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>4){f=9763192;break}f=1526248+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cKp(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>4){g=9763192;break}g=1526248+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cKq(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>4){f=9763192;break}f=5632736+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cKr(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>4){g=9763192;break}g=5632736+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cKs(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>30){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=2095176+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function cKt(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>4){f=9763192;break}f=4328064+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cKu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>4){g=9763192;break}g=4328064+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cKv(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>5){f=9763192;break}f=2943168+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cKw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>5){g=9763192;break}g=2943168+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cKx(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>9){f=9763192;break}f=3115296+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cKy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>9){g=9763192;break}g=3115296+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cKz(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>15){f=9763192;break}f=2986064+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cKA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>15){g=9763192;break}g=2986064+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cKB(){c[c[1865440]>>2]=5610;return cAG()|0}function cKC(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>5){f=9763192;break}f=6574992+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cKD(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>5){g=9763192;break}g=6574992+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cKE(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>7){f=9763192;break}f=2744128+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cKF(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>7){g=9763192;break}g=2744128+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cKG(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=7){if((a|0)==0){d=0;return d|0}e=a;f=707704+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}f=b-8|0;if(f>>>0>60){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;a=5760424+(f*12|0)|0;c[b>>2]=c[a>>2];c[b+4>>2]=c[a+4>>2];c[b+8>>2]=c[a+8>>2];d=0;return d|0}function cKH(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>7){f=9763192;break}f=1527592+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cKI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>7){g=9763192;break}g=1527592+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cKJ(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>5){f=9763192;break}f=3121456+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cKK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>5){g=9763192;break}g=3121456+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cKL(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>7){f=9763192;break}f=2129288+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cKM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>7){g=9763192;break}g=2129288+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cKN(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>15){f=9763192;break}f=4620536+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cKO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>15){g=9763192;break}g=4620536+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cKP(){a[8452536]=30;c[c[1865440]>>2]=1940;return cAG()|0}function cKQ(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>15){f=9763192;break}f=2712856+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cKR(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>15){g=9763192;break}g=2712856+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cKS(){a[8452536]=30;return cAG()|0}function cKT(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>13){f=9763192;break}f=2708152+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cKU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>13){g=9763192;break}g=2708152+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cKV(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>13){f=9763192;break}f=2706584+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cKW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>13){g=9763192;break}g=2706584+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cKX(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a[8452536]=-20;c[c[1865440]>>2]=5544;b=cAG()|0;if((b|0)==0){d=0}else{return b|0}while(1){if((d|0)>=1024){e=48415;break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==0){break}else{d=d+1|0}}if((e|0)==48415){return b|0}d=gGq(16777216)|0;c[f>>2]=d;if((d|0)==0){return b|0}gGz(d|0,0,16777216);f=c[14127400+(c[2113146]<<2)>>2]|0;gGC(d|0,f|0,16777216)|0;g=0;while(1){h=(g>>>16&1|g&16711678|g<<16&65536)^675840;a[f+h|0]=a[614040+(h&7)|0]^a[d+g|0];h=g+1|0;if((h|0)<16777216){g=h}else{i=0;break}}while(1){if((i|0)>=1024){e=48417;break}j=9638528+(i<<2)|0;if((c[j>>2]|0)==(d|0)){break}else{i=i+1|0}}if((e|0)==48417){return b|0}gGr(d);c[j>>2]=0;return b|0}function cKY(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>15){f=9763192;break}f=2703224+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cKZ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>15){g=9763192;break}g=2703224+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cK_(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=cAG()|0;if((b|0)==0){d=0}else{return b|0}while(1){if((d|0)>=1024){e=48454;break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==0){break}else{d=d+1|0}}if((e|0)==48454){return b|0}d=gGq(16777216)|0;c[f>>2]=d;if((d|0)==0){return b|0}gGz(d|0,0,16777216);f=c[14127400+(c[2113146]<<2)>>2]|0;gGC(d|0,f|0,16777216)|0;g=0;while(1){h=(g>>>16&1|g&16711678|g<<16&65536)^675840;a[f+h|0]=a[614040+(h&7)|0]^a[d+g|0];h=g+1|0;if((h|0)<16777216){g=h}else{i=0;break}}while(1){if((i|0)>=1024){e=48451;break}j=9638528+(i<<2)|0;if((c[j>>2]|0)==(d|0)){break}else{i=i+1|0}}if((e|0)==48451){return b|0}gGr(d);c[j>>2]=0;return b|0}function cK$(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>13){f=9763192;break}f=2696864+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cK0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>13){g=9763192;break}g=2696864+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cK1(){c[c[1865440]>>2]=8568;return cAG()|0}function cK2(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>18){f=9763192;break}f=4603416+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cK3(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>18){g=9763192;break}g=4603416+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cK4(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>17){f=9763192;break}f=4601400+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cK5(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>17){g=9763192;break}g=4601400+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cK6(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>15){f=9763192;break}f=4599608+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cK7(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>15){g=9763192;break}g=4599608+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cK8(){c[c[1865440]>>2]=9670;return cAG()|0}function cK9(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>12){f=9763192;break}f=4598152+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cLa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>12){g=9763192;break}g=4598152+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cLb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>12){f=9763192;break}f=2682416+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cLc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>12){g=9763192;break}g=2682416+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cLd(){c[c[1865440]>>2]=906;return cAG()|0}function cLe(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>13){f=9763192;break}f=2683872+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cLf(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>13){g=9763192;break}g=2683872+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cLg(){c[c[1865440]>>2]=12666;return cAG()|0}function cLh(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>12){f=9763192;break}f=4596696+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cLi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>12){g=9763192;break}g=4596696+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cLj(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>20){f=9763192;break}f=4594344+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cLk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>20){g=9763192;break}g=4594344+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cLl(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>9){f=9763192;break}f=6532544+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cLm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>9){g=9763192;break}g=6532544+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cLn(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>11){f=9763192;break}f=4529e3+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cLo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>11){g=9763192;break}g=4529e3+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cLp(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a[8452536]=25;c[c[1865440]>>2]=1612;b=0;while(1){if((b|0)>=1024){break}d=9638528+(b<<2)|0;if((c[d>>2]|0)==0){e=48704;break}else{b=b+1|0}}do{if((e|0)==48704){b=gGq(8192)|0;c[d>>2]=b;if((b|0)==0){break}c[2411924]=b;gGz(b|0,0,8192);b=c[1865440]|0;c[b+4>>2]=11564;c[b+12>>2]=4296;c[b+16>>2]=14502;b=cAG()|0;if((b|0)==0){f=0}else{g=b;return g|0}while(1){if((f|0)>=1024){g=0;e=48719;break}h=9638528+(f<<2)|0;if((c[h>>2]|0)==0){break}else{f=f+1|0}}if((e|0)==48719){return g|0}b=gGq(16777216)|0;c[h>>2]=b;if((b|0)==0){g=0;return g|0}gGz(b|0,0,16777216);i=c[14127400+(c[2113146]<<2)>>2]|0;gGC(b|0,i|0,16777216)|0;j=0;while(1){k=(j>>>16&1|j&16711678|j<<16&65536)^319489;a[i+k|0]=a[614384+(k&7)|0]^a[b+(j+16657654&16777215)|0];k=j+1|0;if((k|0)<16777216){j=k}else{l=0;break}}while(1){if((l|0)>=1024){g=0;e=48716;break}m=9638528+(l<<2)|0;if((c[m>>2]|0)==(b|0)){break}else{l=l+1|0}}if((e|0)==48716){return g|0}gGr(b);c[m>>2]=0;g=0;return g|0}}while(0);c[2411924]=0;g=1;return g|0}function cLq(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>5){f=9763192;break}f=2058344+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cLr(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>5){g=9763192;break}g=2058344+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cLs(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>5){f=9763192;break}f=2851992+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cLt(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>5){g=9763192;break}g=2851992+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cLu(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>54){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1451496+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function cLv(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=7){if((a|0)==0){d=0;return d|0}e=a;f=4516208+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}f=b-8|0;if(f>>>0>60){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;a=5760424+(f*12|0)|0;c[b>>2]=c[a>>2];c[b+4>>2]=c[a+4>>2];c[b+8>>2]=c[a+8>>2];d=0;return d|0}function cLw(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>5){f=9763192;break}f=6599144+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cLx(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>5){g=9763192;break}g=6599144+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cLy(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>5){f=9763192;break}f=7068480+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cLz(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>5){g=9763192;break}g=7068480+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cLA(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>5){f=9763192;break}f=3007008+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cLB(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>5){g=9763192;break}g=3007008+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cLC(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>5){f=9763192;break}f=5791928+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cLD(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>5){g=9763192;break}g=5791928+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cLE(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>5){f=9763192;break}f=4517752+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cLF(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>5){g=9763192;break}g=4517752+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cLG(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>5){f=9763192;break}f=4516304+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cLH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>5){g=9763192;break}g=4516304+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cLI(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>5){f=9763192;break}f=2512704+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cLJ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>5){g=9763192;break}g=2512704+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cLK(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>5){f=9763192;break}f=4514864+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cLL(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>5){g=9763192;break}g=4514864+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cLM(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>5){f=9763192;break}f=2512032+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cLN(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>5){g=9763192;break}g=2512032+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cLO(){a[64280]=1;return cAG()|0}function cLP(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>5){f=9763192;break}f=5754936+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cLQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>5){g=9763192;break}g=5754936+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cLR(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>8){f=9763192;break}f=5753928+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cLS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>8){g=9763192;break}g=5753928+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cLT(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>5){f=9763192;break}f=2448320+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cLU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>5){g=9763192;break}g=2448320+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cLV(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>5){f=9763192;break}f=2179328+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cLW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>5){g=9763192;break}g=2179328+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cLX(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>11){f=9763192;break}f=7067136+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cLY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>11){g=9763192;break}g=7067136+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cLZ(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=7){if((a|0)==0){d=0;return d|0}e=a;f=707800+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}f=b-8|0;if(f>>>0>60){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;a=5760424+(f*12|0)|0;c[b>>2]=c[a>>2];c[b+4>>2]=c[a+4>>2];c[b+8>>2]=c[a+8>>2];d=0;return d|0}function cL_(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>11){f=9763192;break}f=7359144+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cL$(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>11){g=9763192;break}g=7359144+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cL0(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>11){f=9763192;break}f=7060728+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cL1(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>11){g=9763192;break}g=7060728+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cL2(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>11){f=9763192;break}f=6584896+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cL3(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>11){g=9763192;break}g=6584896+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cL4(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>10){f=9763192;break}f=4697328+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cL5(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>10){g=9763192;break}g=4697328+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cL6(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>11){f=9763192;break}f=2375824+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cL7(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>11){g=9763192;break}g=2375824+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cL8(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>10){f=9763192;break}f=2242608+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cL9(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>10){g=9763192;break}g=2242608+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cMa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>11){f=9763192;break}f=6473576+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cMb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>11){g=9763192;break}g=6473576+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cMc(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>11){f=9763192;break}f=5650448+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cMd(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>11){g=9763192;break}g=5650448+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cMe(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>5){f=9763192;break}f=2510688+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cMf(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>5){g=9763192;break}g=2510688+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cMg(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>5){f=9763192;break}f=2506208+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cMh(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>5){g=9763192;break}g=2506208+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cMi(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>5){f=9763192;break}f=2516112+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cMj(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>5){g=9763192;break}g=2516112+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cMk(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>5){f=9763192;break}f=2518832+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cMl(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>5){g=9763192;break}g=2518832+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cMm(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>5){f=9763192;break}f=5755608+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cMn(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>5){g=9763192;break}g=5755608+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cMo(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>6){f=9763192;break}f=4356064+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cMp(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>6){g=9763192;break}g=4356064+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cMq(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>5){f=9763192;break}f=2513872+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cMr(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>5){g=9763192;break}g=2513872+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cMs(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>5){f=9763192;break}f=1450824+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cMt(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>5){g=9763192;break}g=1450824+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cMu(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>5){f=9763192;break}f=5756280+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cMv(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>5){g=9763192;break}g=5756280+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cMw(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>30){e=1;return e|0}else{f=5756952+(d*112|0)|0;break}}else{if(b>>>0>5){f=9763192;break}f=2511360+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function cMx(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>30){f=1;return f|0}else{g=5756952+(e*112|0)|0;break}}else{if(b>>>0>5){g=9763192;break}g=2511360+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function cMy(){var a=0,b=0,d=0,e=0,f=0,g=0;a=0;while(1){if((a|0)>=1024){b=49513;break}d=9638528+(a<<2)|0;if((c[d>>2]|0)==0){break}else{a=a+1|0}}if((b|0)==49513){return}a=gGq(5242880)|0;c[d>>2]=a;if((a|0)==0){return}gGz(a|0,0,5242880);d=c[3541128]|0;gGC(a|0,d|0,5242880)|0;gGz(d|0,0,5242880);gGC(d|0,a|0,1048576)|0;e=d+1048576|0;f=a+1048576|0;gGC(e|0,f|0,1048576)|0;f=d+3145728|0;e=a+2097152|0;gGC(f|0,e|0,1048576)|0;e=d+2097152|0;f=a+3145728|0;gGC(e|0,f|0,1048576)|0;f=d+4194304|0;d=a+4194304|0;gGC(f|0,d|0,1048576)|0;d=0;while(1){if((d|0)>=1024){b=49511;break}g=9638528+(d<<2)|0;if((c[g>>2]|0)==(a|0)){break}else{d=d+1|0}}if((b|0)==49511){return}gGr(a);c[g>>2]=0;return}function cMz(){var a=0,b=0;a=c[2411924]|0;b=c[2112932]|0;c[b+12256>>2]=a;c[b+12260>>2]=a+1024;c[b+12264>>2]=a+2048;c[b+12268>>2]=a+3072;c[b+12272>>2]=a+4096;c[b+12276>>2]=a+5120;c[b+12280>>2]=a+6144;c[b+12284>>2]=a+7168;c[b+77792>>2]=6;c[b+77796>>2]=6;c[b+77800>>2]=6;c[b+77804>>2]=6;c[b+77808>>2]=6;c[b+77812>>2]=6;c[b+77816>>2]=6;c[b+77820>>2]=6;c[b+196752>>2]=2770;c[b+196672>>2]=3472;return}function cMA(){var a=0,b=0,d=0,e=0,f=0;a=c[3541128]|0;b=(c[2113148]|0)-2097152|0;d=(c[2112932]|0)+8192|0;e=2097152;while(1){f=a+(b+e)|0;c[d>>2]=f;c[d+131072>>2]=f;f=e+1024|0;if(f>>>0>3137535){break}else{d=d+4|0;e=f}}return}function cMB(a,b){a=a|0;b=b|0;var d=0;b=i;i=i+16|0;d=b|0;if((a&32|0)==0){i=b;return 0}c[d>>2]=c[2411924];c[d+4>>2]=8192;c[d+8>>2]=0;c[d+12>>2]=70528;gj[c[2076592]&4095](d)|0;i=b;return 0}function cMC(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=0;while(1){if((d|0)>=1024){e=0;break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==0){g=49527;break}else{d=d+1|0}}do{if((g|0)==49527){d=gGq(5242880)|0;c[f>>2]=d;if((d|0)==0){e=0;break}gGz(d|0,0,5242880);e=d}}while(0);f=e;d=c[3541128]|0;h=d;i=0;while(1){b[f+(i<<1)>>1]=b[h+((i^524271)<<1)>>1]|0;j=i+1|0;if((j|0)<524288){i=j}else{k=0;break}}do{b[f+(k+524288<<1)>>1]=b[h+((k^1048559)+524288<<1)>>1]|0;k=k+1|0;}while((k|0)<2097152);gGC(d|0,e|0,5242880)|0;d=0;while(1){if((d|0)>=1024){break}l=9638528+(d<<2)|0;if((c[l>>2]|0)==(e|0)){g=49535;break}else{d=d+1|0}}if((g|0)==49535){gGr(e);c[l>>2]=0}l=c[14164128+(c[2113146]<<2)>>2]|0;e=0;do{g=0;do{d=g+e|0;k=l+(d+64)|0;h=a[k]|0;f=l+d|0;a[k]=a[f]|0;a[f]=h;g=g+1|0;}while((g|0)<64);e=e+128|0;}while((e|0)<41943040);cMD();return}function cMD(){var b=0,d=0,e=0,f=0,g=0;b=c[14164080+(c[2113146]<<2)>>2]|0;d=0;do{e=b+(d|8)|0;f=a[e]|0;g=b+d|0;a[e]=a[g]|0;a[g]=f;f=b+(d|9)|0;g=a[f]|0;e=b+(d|1)|0;a[f]=a[e]|0;a[e]=g;g=b+(d|10)|0;e=a[g]|0;f=b+(d|2)|0;a[g]=a[f]|0;a[f]=e;e=b+(d|11)|0;f=a[e]|0;g=b+(d|3)|0;a[e]=a[g]|0;a[g]=f;f=b+(d|12)|0;g=a[f]|0;e=b+(d|4)|0;a[f]=a[e]|0;a[e]=g;g=b+(d|13)|0;e=a[g]|0;f=b+(d|5)|0;a[g]=a[f]|0;a[f]=e;e=b+(d|14)|0;f=a[e]|0;g=b+(d|6)|0;a[e]=a[g]|0;a[g]=f;f=b+(d|15)|0;g=a[f]|0;e=b+(d|7)|0;a[f]=a[e]|0;a[e]=g;d=d+16|0;}while((d|0)<131072);return}function cME(){cMD();return}function cMF(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;b=i;i=i+120|0;e=b|0;f=b+112|0;g=0;while(1){if((g|0)>=1024){h=49563;break}j=9638528+(g<<2)|0;if((c[j>>2]|0)==0){break}else{g=g+1|0}}if((h|0)==49563){i=b;return}g=gGq(524288)|0;c[j>>2]=g;if((g|0)==0){i=b;return}gGz(g|0,0,524288);do{if((c[3542200]|0)!=0){j=e+108|0;c[j>>2]=0;k=e+100|0;c[k>>2]=0;l=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[l&16383](e,15)|0;if((c[j>>2]|0)==0){break}j=c[k>>2]|0;c[f>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](f,15,0)|0;if((j|0)<1){break}gzL(g,0,15)|0}}while(0);f=c[3541128]|0;e=0;do{j=g+e|0;k=a[f+e|0]|0;if(((d[j]|0)-(k&255)|0)==8){a[j]=k}e=e+1|0;}while(e>>>0<524288);gGC(f|0,g|0,524288)|0;f=0;while(1){if((f|0)>=1024){h=49564;break}m=9638528+(f<<2)|0;if((c[m>>2]|0)==(g|0)){break}else{f=f+1|0}}if((h|0)==49564){i=b;return}gGr(g);c[m>>2]=0;i=b;return}function cMG(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0;a=0;while(1){if((a|0)>=1024){b=49578;break}d=9638528+(a<<2)|0;if((c[d>>2]|0)==0){break}else{a=a+1|0}}if((b|0)==49578){cMD();return}a=gGq(6291456)|0;c[d>>2]=a;if((a|0)==0){cMD();return}gGz(a|0,0,6291456);d=c[3541128]|0;gGC(a|0,d|0,6291456)|0;e=d+5242880|0;f=a+1048576|0;gGC(e|0,f|0,1048576)|0;g=d+4194304|0;h=a+2097152|0;gGC(g|0,h|0,1048576)|0;h=d+3145728|0;g=a+3145728|0;gGC(h|0,g|0,1048576)|0;g=d+2097152|0;h=a+4194304|0;gGC(g|0,h|0,1048576)|0;h=d+1048576|0;g=a+5242880|0;gGC(h|0,g|0,1048576)|0;gGz(a|0,0,6291456);gGC(a|0,d|0,1048576)|0;gGC(f|0,e|0,1048576)|0;e=a+1703936|0;gGC(d|0,e|0,131072)|0;e=d+131072|0;g=a+524288|0;gGC(e|0,g|0,131072)|0;g=d+262144|0;e=a+1310720|0;gGC(g|0,e|0,131072)|0;e=d+393216|0;gGC(e|0,a|0,131072)|0;e=d+524288|0;g=a+1572864|0;gGC(e|0,g|0,131072)|0;g=d+655360|0;e=a+655360|0;gGC(g|0,e|0,131072)|0;e=d+786432|0;gGC(e|0,f|0,131072)|0;f=d+917504|0;d=a+262144|0;gGC(f|0,d|0,131072)|0;d=0;while(1){if((d|0)>=1024){b=49576;break}i=9638528+(d<<2)|0;if((c[i>>2]|0)==(a|0)){break}else{d=d+1|0}}if((b|0)==49576){cMD();return}gGr(a);c[i>>2]=0;cMD();return}function cMH(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=0;while(1){if((b|0)>=1024){break}d=9638528+(b<<2)|0;if((c[d>>2]|0)==0){e=49582;break}else{b=b+1|0}}L58718:do{if((e|0)==49582){b=gGq(4194304)|0;c[d>>2]=b;if((b|0)==0){break}gGz(b|0,0,4194304);f=c[3541128]|0;g=f+1048576|0;gGC(b|0,g|0,4194304)|0;h=b+1048576|0;gGC(g|0,h|0,524288)|0;h=f+1572864|0;g=b+2621440|0;gGC(h|0,g|0,524288)|0;g=f+2097152|0;h=b+3145728|0;gGC(g|0,h|0,524288)|0;h=f+2621440|0;g=b+1572864|0;gGC(h|0,g|0,524288)|0;g=f+3145728|0;gGC(g|0,b|0,524288)|0;g=f+3670016|0;h=b+3670016|0;gGC(g|0,h|0,524288)|0;h=f+4194304|0;g=b+2097152|0;gGC(h|0,g|0,524288)|0;g=f+4718592|0;f=b+524288|0;gGC(g|0,f|0,524288)|0;f=0;while(1){if((f|0)>=1024){break L58718}i=9638528+(f<<2)|0;if((c[i>>2]|0)==(b|0)){break}else{f=f+1|0}}gGr(b);c[i>>2]=0}}while(0);i=c[14164080+(c[2113146]<<2)>>2]|0;d=0;do{e=i+d|0;f=a[e]|0;a[e]=f<<5&32|f&-34|(f&255)>>>5&1;d=d+1|0;}while((d|0)<131072);return}function cMI(){var a=0,b=0,d=0,e=0,f=0,g=0;a=0;while(1){if((a|0)>=1024){b=49602;break}d=9638528+(a<<2)|0;if((c[d>>2]|0)==0){break}else{a=a+1|0}}if((b|0)==49602){return}a=gGq(4194304)|0;c[d>>2]=a;if((a|0)==0){return}gGz(a|0,0,4194304);d=c[3541128]|0;e=d+1048576|0;gGC(a|0,e|0,4194304)|0;f=a+1048576|0;gGC(e|0,f|0,524288)|0;f=d+1572864|0;e=a+2621440|0;gGC(f|0,e|0,524288)|0;e=d+2097152|0;f=a+3145728|0;gGC(e|0,f|0,524288)|0;f=d+2621440|0;e=a+1572864|0;gGC(f|0,e|0,524288)|0;e=d+3145728|0;gGC(e|0,a|0,524288)|0;e=d+3670016|0;f=a+3670016|0;gGC(e|0,f|0,524288)|0;f=d+4194304|0;e=a+2097152|0;gGC(f|0,e|0,524288)|0;e=d+4718592|0;d=a+524288|0;gGC(e|0,d|0,524288)|0;d=0;while(1){if((d|0)>=1024){b=49601;break}g=9638528+(d<<2)|0;if((c[g>>2]|0)==(a|0)){break}else{d=d+1|0}}if((b|0)==49601){return}gGr(a);c[g>>2]=0;return}function cMJ(){var b=0,d=0,e=0,f=0;b=c[14164080+(c[2113146]<<2)>>2]|0;d=0;do{e=b+d|0;f=a[e]|0;a[e]=(f&255)>>>3<<7|(f&255)>>>7|f<<1&2|(f&255)>>>2<<6&64|(f&255)>>>4<<5&32|(f&255)>>>5<<4&16|(f&255)>>>1<<3&8|(f&255)>>>6<<2&4;d=d+1|0;}while((d|0)<131072);return}function cMK(){var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=i;i=i+2048|0;f=e|0;g=0;while(1){if((g|0)>=1024){break}h=9638528+(g<<2)|0;if((c[h>>2]|0)==0){j=49609;break}else{g=g+1|0}}L58754:do{if((j|0)==49609){g=gGq(5242880)|0;c[h>>2]=g;if((g|0)==0){break}gGz(g|0,0,5242880);k=c[3541128]|0;l=0;do{m=g+(l<<17)|0;n=k+((d[600504+l|0]|0)<<17)|0;gGC(m|0,n|0,131072)|0;l=l+1|0;}while((l|0)<40);gGC(k|0,g|0,5242880)|0;l=0;while(1){if((l|0)>=1024){break L58754}o=9638528+(l<<2)|0;if((c[o>>2]|0)==(g|0)){break}else{l=l+1|0}}gGr(g);c[o>>2]=0}}while(0);o=c[3541128]|0;b[o+970766>>1]=20081;b[o+971668>>1]=20081;b[o+666494>>1]=20081;o=c[2113146]|0;h=c[14164080+(o<<2)>>2]|0;j=0;do{l=h+(j+32768)|0;k=a[l]|0;n=h+(j+65536)|0;a[l]=a[n]|0;a[n]=k;j=j+1|0;}while((j|0)<32768);j=c[3540996]|0;h=0;do{k=j+(h+32768)|0;n=a[k]|0;l=j+(h+65536)|0;a[k]=a[l]|0;a[l]=n;h=h+1|0;}while((h|0)<32768);h=f|0;j=c[14164128+(o<<2)>>2]|0;o=0;do{n=c[591848+((o>>>5&15)<<2)>>2]|0;l=c[591764+(n<<4)>>2]|0;k=c[591760+(n<<4)>>2]|0;m=c[591756+(n<<4)>>2]|0;p=c[591752+(n<<4)>>2]|0;n=o<<11;q=0;do{r=f+(q<<7)|0;s=j+(((q>>>(p>>>0)&1|q&240|q>>>(l>>>0)<<3&8|q>>>(k>>>0)<<2&4|q>>>(m>>>0)<<1&2)<<7)+n)|0;gGC(r|0,s|0,128)|0;q=q+1|0;}while((q|0)<16);q=j+n|0;gGC(q|0,h|0,2048)|0;o=o+1|0;}while((o|0)<32768);i=e;return}function cML(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=i;i=i+2048|0;d=b|0;e=0;while(1){if((e|0)>=1024){f=0;break}g=9638528+(e<<2)|0;if((c[g>>2]|0)==0){h=49628;break}else{e=e+1|0}}L58781:do{if((h|0)==49628){e=gGq(131072)|0;c[g>>2]=e;if((e|0)==0){f=0;break}gGz(e|0,0,131072);j=c[3540996]|0;gGC(e|0,j|0,131072)|0;k=0;while(1){l=(k&1|0)==0?k:k^2048;m=(k&2|0)==0?l:l^8192;l=(k&2048|0)==0?m:m^67584;a[j+((k&65536|0)==0?l:l^2048)|0]=a[e+k|0]|0;l=k+1|0;if((l|0)<131072){k=l}else{n=0;break}}while(1){if((n|0)>=1024){f=0;break L58781}o=9638528+(n<<2)|0;if((c[o>>2]|0)==(e|0)){break}else{n=n+1|0}}gGr(e);c[o>>2]=0;f=0}}while(0);while(1){if((f|0)>=1024){break}p=9638528+(f<<2)|0;if((c[p>>2]|0)==0){h=49636;break}else{f=f+1|0}}L58793:do{if((h|0)==49636){f=gGq(4194304)|0;c[p>>2]=f;if((f|0)==0){break}gGz(f|0,0,4194304);o=c[3541128]|0;n=o+1048576|0;gGC(f|0,n|0,4194304)|0;g=f+1048576|0;gGC(n|0,g|0,524288)|0;g=o+1572864|0;n=f+2621440|0;gGC(g|0,n|0,524288)|0;n=o+2097152|0;g=f+3145728|0;gGC(n|0,g|0,524288)|0;g=o+2621440|0;n=f+1572864|0;gGC(g|0,n|0,524288)|0;n=o+3145728|0;gGC(n|0,f|0,524288)|0;n=o+3670016|0;g=f+3670016|0;gGC(n|0,g|0,524288)|0;g=o+4194304|0;n=f+2097152|0;gGC(g|0,n|0,524288)|0;n=o+4718592|0;o=f+524288|0;gGC(n|0,o|0,524288)|0;o=0;while(1){if((o|0)>=1024){break L58793}q=9638528+(o<<2)|0;if((c[q>>2]|0)==(f|0)){break}else{o=o+1|0}}gGr(f);c[q>>2]=0}}while(0);q=d|0;p=c[2113146]|0;h=c[14164128+(p<<2)>>2]|0;o=0;do{e=c[591848+((o>>>5&15)<<2)>>2]|0;n=c[591764+(e<<4)>>2]|0;g=c[591760+(e<<4)>>2]|0;k=c[591756+(e<<4)>>2]|0;j=c[591752+(e<<4)>>2]|0;e=o<<11;l=0;do{m=d+(l<<7)|0;r=h+(((l>>>(j>>>0)&1|l&240|l>>>(n>>>0)<<3&8|l>>>(g>>>0)<<2&4|l>>>(k>>>0)<<1&2)<<7)+e)|0;gGC(m|0,r|0,128)|0;l=l+1|0;}while((l|0)<16);l=h+e|0;gGC(l|0,q|0,2048)|0;o=o+1|0;}while((o|0)<32768);o=c[14164080+(p<<2)>>2]|0;p=0;do{a[o+p|0]=a[h+(((p<<2&28|p&-32|p>>>2&2|p>>>4&1)^2)+66584576)|0]|0;p=p+1|0;}while((p|0)<524288);i=b;return}function cMM(){var a=0,b=0,d=0,e=0,f=0,g=0;a=i;i=i+120|0;b=a|0;d=a+112|0;e=c[3541128]|0;if((c[3542200]|0)==0){i=a;return}f=b+108|0;c[f>>2]=0;g=b+100|0;c[g>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](b,9)|0;if((c[f>>2]|0)==0){i=a;return}f=c[g>>2]|0;c[d>>2]=9534384;gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](d,9,0)|0;if((f|0)<1){i=a;return}gzL(e,0,9)|0;i=a;return}function cMN(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=0;while(1){if((d|0)>=1024){break}e=9638528+(d<<2)|0;if((c[e>>2]|0)==0){f=49660;break}else{d=d+1|0}}L58825:do{if((f|0)==49660){d=gGq(1048576)|0;c[e>>2]=d;if((d|0)==0){break}gGz(d|0,0,1048576);g=c[3541128]|0;h=g+393216|0;gGC(d|0,h|0,131072)|0;h=d+131072|0;i=g+1048576|0;gGC(h|0,i|0,131072)|0;i=d+262144|0;h=g+917504|0;gGC(i|0,h|0,131072)|0;h=d+393216|0;i=g+1572864|0;gGC(h|0,i|0,131072)|0;i=d+524288|0;h=g+131072|0;gGC(i|0,h|0,131072)|0;h=d+655360|0;i=g+1310720|0;gGC(h|0,i|0,131072)|0;i=d+786432|0;h=g+786432|0;gGC(i|0,h|0,131072)|0;h=d+917504|0;i=g+1703936|0;gGC(h|0,i|0,131072)|0;i=d+768768|0;h=g+285440|0;gGC(i|0,h|0,5904)|0;h=d+196592|0;i=g+1741502|0;gGC(h|0,i|0,16)|0;gGC(g|0,d|0,1048576)|0;g=0;while(1){if((g|0)>=1024){break L58825}j=9638528+(g<<2)|0;if((c[j>>2]|0)==(d|0)){break}else{g=g+1|0}}gGr(d);c[j>>2]=0}}while(0);j=c[3541128]|0;e=j+1048576|0;f=j+2097152|0;gGC(e|0,f|0,4194304)|0;f=768768;while(1){e=f+2|0;do{if((b[j+f>>1]&-3393)<<16>>16==17081){g=j+e|0;if((b[g>>1]|0)!=0){break}b[g>>1]=11;g=j+(f+4)|0;b[g>>1]=(b[g>>1]|0)+24576&65535}}while(0);if((e|0)<778240){f=e}else{break}}b[j+184668>>1]=11;b[j+184670>>1]=-17664;b[j+184804>>1]=24578;b[j+191102>>1]=24578;b[j+769232>>1]=24578;b[j+769522>>1]=24578;b[j+769602>>1]=24578;cMD();j=c[14164128+(c[2113146]<<2)>>2]|0;f=0;do{d=0;do{g=d+f|0;i=j+(g+64)|0;h=a[i]|0;k=j+g|0;a[i]=a[k]|0;a[k]=h;d=d+1|0;}while((d|0)<64);f=f+128|0;}while((f|0)<50331648);return}function cMO(){var a=0,b=0,d=0,e=0,f=0,g=0;a=0;while(1){if((a|0)>=1024){b=49685;break}d=9638528+(a<<2)|0;if((c[d>>2]|0)==0){break}else{a=a+1|0}}if((b|0)==49685){return}a=gGq(8388608)|0;c[d>>2]=a;if((a|0)==0){return}gGz(a|0,0,8388608);d=c[3541128]|0;gGC(a|0,d|0,8388608)|0;e=d+524288|0;f=a+524288|0;gGC(e|0,f|0,524288)|0;f=d+1048576|0;e=a+5242880|0;gGC(f|0,e|0,524288)|0;e=d+1572864|0;f=a+4718592|0;gGC(e|0,f|0,524288)|0;f=d+2097152|0;e=a+6291456|0;gGC(f|0,e|0,524288)|0;e=d+2621440|0;f=a+5767168|0;gGC(e|0,f|0,524288)|0;f=d+3145728|0;e=a+7340032|0;gGC(f|0,e|0,524288)|0;e=d+3670016|0;f=a+2621440|0;gGC(e|0,f|0,524288)|0;f=d+4194304|0;e=a+1048576|0;gGC(f|0,e|0,524288)|0;e=d+4718592|0;f=a+6815744|0;gGC(e|0,f|0,524288)|0;f=d+5242880|0;e=a+4194304|0;gGC(f|0,e|0,524288)|0;e=d+5767168|0;f=a+7864320|0;gGC(e|0,f|0,524288)|0;f=d+6291456|0;e=a+2097152|0;gGC(f|0,e|0,524288)|0;e=d+6815744|0;f=a+3670016|0;gGC(e|0,f|0,524288)|0;f=d+7340032|0;e=a+3145728|0;gGC(f|0,e|0,524288)|0;e=d+7864320|0;d=a+1572864|0;gGC(e|0,d|0,524288)|0;d=0;while(1){if((d|0)>=1024){b=49686;break}g=9638528+(d<<2)|0;if((c[g>>2]|0)==(a|0)){break}else{d=d+1|0}}if((b|0)==49686){return}gGr(a);c[g>>2]=0;return}function cMP(){var b=0,d=0,e=0,f=0;b=c[3541128]|0;d=b+1048576|0;gGC(d|0,b|0,6291456)|0;d=b+7340032|0;gGC(b|0,d|0,1048576)|0;d=0;do{a[b+(d+1040384)|0]=a[b+((d>>>1<<6&64|d&8125|d>>>6<<1&2)+853520)|0]|0;d=d+1|0;}while((d|0)<8192);d=c[14164080+(c[2113146]<<2)>>2]|0;b=0;do{e=d+b|0;f=a[e]|0;a[e]=f<<5&32|f&-34|(f&255)>>>5&1;b=b+1|0;}while((b|0)<131072);return}function cMQ(){var a=0,b=0;a=c[2411924]|0;b=c[2112932]|0;c[b+12256>>2]=a;c[b+12260>>2]=a+1024;c[b+12264>>2]=a+2048;c[b+12268>>2]=a+3072;c[b+12272>>2]=a+4096;c[b+12276>>2]=a+5120;c[b+12280>>2]=a+6144;c[b+12284>>2]=a+7168;c[b+77792>>2]=6;c[b+77796>>2]=6;c[b+77800>>2]=6;c[b+77804>>2]=6;c[b+77808>>2]=6;c[b+77812>>2]=6;c[b+77816>>2]=6;c[b+77820>>2]=6;c[b+196752>>2]=2770;c[b+196672>>2]=3472;c[b+1408>>2]=7;c[b+196636>>2]=1340;return}function cMR(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=0;while(1){if((d|0)>=1024){break}e=9638528+(d<<2)|0;if((c[e>>2]|0)==0){f=49697;break}else{d=d+1|0}}L58875:do{if((f|0)==49697){d=gGq(1048576)|0;c[e>>2]=d;if((d|0)==0){break}gGz(d|0,0,1048576);g=c[3541128]|0;h=0;while(1){i=g+h|0;gGC(d|0,i|0,1048576)|0;i=0;do{a[g+(i+h)|0]=a[d+(i>>>1<<19&524288|i&15729665|i>>>2<<18&262144|i>>>3<<17&131072|i>>>4<<16&65536|i>>>5<<15&32768|i>>>6<<14&16384|i>>>7<<13&8192|i>>>8<<12&4096|i>>>9<<11&2048|i>>>11<<9&512|i>>>12<<8&256|i>>>13<<7&128|i>>>14<<6&64|i>>>15<<5&32|i>>>16<<4&16|i>>>17<<3&8|i>>>18<<2&4|i>>>19<<1&2)|0]|0;i=i+1|0;}while((i|0)<1048576);i=h+1048576|0;if((i|0)<7340032){h=i}else{j=0;break}}while(1){if((j|0)>=1024){break L58875}k=9638528+(j<<2)|0;if((c[k>>2]|0)==(d|0)){break}else{j=j+1|0}}gGr(d);c[k>>2]=0}}while(0);b[(c[3541128]|0)+997548>>1]=20085;cMD();return}function cMS(){var a=0,b=0;a=c[2411924]|0;b=c[2112932]|0;c[b+12256>>2]=a;c[b+12260>>2]=a+1024;c[b+12264>>2]=a+2048;c[b+12268>>2]=a+3072;c[b+12272>>2]=a+4096;c[b+12276>>2]=a+5120;c[b+12280>>2]=a+6144;c[b+12284>>2]=a+7168;c[b+77792>>2]=6;c[b+77796>>2]=6;c[b+77800>>2]=6;c[b+77804>>2]=6;c[b+77808>>2]=6;c[b+77812>>2]=6;c[b+77816>>2]=6;c[b+196752>>2]=2770;c[b+196672>>2]=3472;c[b+77820>>2]=7;c[b+196756>>2]=2132;return}function cMT(){var a=0,b=0;a=c[3541128]|0;b=a+1048576|0;gGC(b|0,a|0,7340032)|0;b=a+7340032|0;gGC(a|0,b|0,1048576)|0;cMD();return}function cMU(){var b=0,e=0,f=0,g=0,h=0,i=0;b=c[3541128]|0;e=0;while(1){f=b+e|0;a[f]=a[f]^~a[b+(e&31|1048544)|0];f=e+1|0;if((f|0)<1048576){e=f}else{g=0;break}}while(1){e=b+(g+8388608)|0;a[e]=a[e]^a[b+(g|1048578)|0];e=g+1|0;if((e|0)<1048576){g=e}else{h=1048576;break}}while(1){g=b+h|0;a[g]=a[g]^~a[b+(h&31|8388576)|0];g=h+1|0;if((g|0)<8388608){h=g}else{i=1048576;break}}do{h=i|1;g=b+h|0;e=b+(h+1)|0;h=d[e]|0;f=a[g]|0;a[g]=(f&255)>>>7<<6|f&15|(f&255)>>>6<<7|(f&255)>>>4<<5&32|(f&255)>>>5<<4&16;a[e]=((h<<9&512|h<<8&-4096|(h&65535)>>>2<<11&2048|(h&65535)>>>3<<10&1024|(h&65535)>>>1<<8&256)&65535)>>>8&255;i=i+4|0;}while((i|0)<8388608);i=b+7340032|0;gGC(i|0,b|0,1048576)|0;i=0;do{h=b+(i<<16)|0;e=b+(((i<<2&4|i&240|i>>>2&1|i>>>1<<3&8|i>>>3<<1&2)<<16)+7340032)|0;gGC(h|0,e|0,65536)|0;i=i+1|0;}while((i|0)<16);i=b+2097152|0;e=b+1048576|0;gGC(i|0,e|0,6291456)|0;i=2097152;do{h=0;do{f=b+(h+1048576)|0;g=b+((((h>>>19<<6&64|h>>>15&1|h>>>18<<7&128|h>>>16<<5&32|h>>>17<<4&16|h>>12<<3&8|h>>>13<<2&4|h>>>14<<1&2)<<12|h&3840)^1024)+i)|0;gGC(f|0,g|0,256)|0;h=h+256|0;}while((h|0)<1048576);h=b+i|0;gGC(h|0,e|0,1048576)|0;i=i+1048576|0;}while((i|0)<9437184);return}function cMV(){var b=0,d=0,e=0,f=0,g=0,h=0;b=c[3541128]|0;d=0;while(1){e=b+d|0;a[e]=a[e]^~a[b+(d&31|1048544)|0];e=d+1|0;if((e|0)<1048576){d=e}else{f=0;break}}while(1){d=b+(f+8388608)|0;a[d]=a[d]^a[b+(f|1048578)|0];d=f+1|0;if((d|0)<1048576){f=d}else{g=1048576;break}}while(1){f=b+g|0;a[f]=a[f]^~a[b+(g&31|8388576)|0];f=g+1|0;if((f|0)<8388608){g=f}else{h=1048576;break}}do{g=h|1;f=b+g|0;d=b+(g+1)|0;g=a[d]|0;e=a[f]|0;a[f]=e&8|g<<6&64|e&4|e&2|e&1|(g&255)>>>1<<7|(g&255)>>>3<<5&32|(g&255)>>>2<<4&16;a[d]=(e&255)>>>7<<1|g&-16|(e&255)>>>6&1|(e&255)>>>5<<3&8|(e&255)>>>4<<2&4;h=h+4|0;}while((h|0)<8388608);h=b+7340032|0;gGC(h|0,b|0,1048576)|0;h=0;do{e=b+(h<<16)|0;g=b+(((h<<3&8|h&240|h>>>3&1|h>>>1<<2&4|h>>>2<<1&2)<<16)+7340032)|0;gGC(e|0,g|0,65536)|0;h=h+1|0;}while((h|0)<16);h=b+2097152|0;g=b+1048576|0;gGC(h|0,g|0,6291456)|0;h=2097152;do{e=0;do{d=b+(e+1048576)|0;f=b+((((e>>>17<<6&64|e>>>14&1|e>>>16<<7&128|e>>>18<<5&32|e>>>19<<4&16|e>>>13<<3&8|e>>12<<2&4|e>>>15<<1&2)<<12|e&3840)^2048)+h)|0;gGC(d|0,f|0,256)|0;e=e+256|0;}while((e|0)<1048576);e=b+h|0;gGC(e|0,g|0,1048576)|0;h=h+1048576|0;}while((h|0)<9437184);return}function cMW(){var b=0,d=0,e=0,f=0,g=0,h=0;b=c[3541128]|0;d=0;while(1){e=b+(d+8388608)|0;a[e]=a[e]^a[b+(d|1048578)|0];e=d+1|0;if((e|0)<1048576){d=e}else{f=1048576;break}}while(1){d=b+f|0;a[d]=a[d]^~a[b+(f&31|8388576)|0];d=f+1|0;if((d|0)<8388608){f=d}else{g=1048576;break}}do{f=g|1;d=b+f|0;e=b+(f+1)|0;f=a[e]|0;h=a[d]|0;a[d]=h&8|f<<7|h&4|h&2|h&1|(f&255)>>>1<<6&64|(f&255)>>>2<<5&32|(f&255)>>>3<<4&16;a[e]=(h&255)>>>7|f&-16|(h&255)>>>4<<3&8|(h&255)>>>5<<2&4|(h&255)>>>6<<1&2;g=g+4|0;}while((g|0)<7340032);g=b+7340032|0;gGC(g|0,b|0,1048576)|0;g=0;do{h=b+(g<<16)|0;f=b+(((g<<2&4|g&240|g>>>2&1|g>>>1<<3&8|g>>>3<<1&2)<<16)+7340032)|0;gGC(h|0,f|0,65536)|0;g=g+1|0;}while((g|0)<16);g=b+2097152|0;f=b+1048576|0;gGC(g|0,f|0,6291456)|0;g=2097152;do{h=0;do{e=b+(h+1048576)|0;d=b+((((h>>>17<<6&64|h>>>14&1|h>>>16<<7&128|h>>>18<<5&32|h>>>19<<4&16|h>>>13<<3&8|h>>12<<2&4|h>>>15<<1&2)<<12|h&3840)^768)+g)|0;gGC(e|0,d|0,256)|0;h=h+256|0;}while((h|0)<1048576);h=b+g|0;gGC(h|0,f|0,1048576)|0;g=g+1048576|0;}while((g|0)<9437184);return}function cMX(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=0;while(1){if((b|0)>=1024){e=0;break}f=9638528+(b<<2)|0;if((c[f>>2]|0)==0){g=49746;break}else{b=b+1|0}}L58949:do{if((g|0)==49746){b=gGq(1048576)|0;c[f>>2]=b;if((b|0)==0){e=0;break}gGz(b|0,0,1048576);h=c[3541128]|0;i=0;do{j=0;do{a[b+j|0]=a[h+(((j>>>1<<3&8|j&268435445|j>>>3<<1&2)^786442)+i)|0]|0;j=j+1|0;}while((j|0)<1048576);j=h+i|0;gGC(j|0,b|0,1048576)|0;i=i+1048576|0;}while((i|0)<8388608);i=h+1048576|0;gGC(i|0,h|0,7340032)|0;gGC(h|0,b|0,1048576)|0;i=0;while(1){if((i|0)>=1024){e=0;break L58949}k=9638528+(i<<2)|0;if((c[k>>2]|0)==(b|0)){break}else{i=i+1|0}}gGr(b);c[k>>2]=0;e=0}}while(0);while(1){if((e|0)>=1024){break}l=9638528+(e<<2)|0;if((c[l>>2]|0)==0){g=49757;break}else{e=e+1|0}}L58965:do{if((g|0)==49757){e=gGq(131072)|0;c[l>>2]=e;if((e|0)==0){break}gGz(e|0,0,131072);k=c[14164080+(c[2113146]<<2)>>2]|0;gGC(e|0,k|0,131072)|0;f=0;while(1){i=f|8;h=e+i|0;j=k+f|0;m=h|0;n=h+4|0;h=d[n]|d[n+1|0]<<8|d[n+2|0]<<16|d[n+3|0]<<24|0;n=j|0;C=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;a[n]=C&255;C=C>>8;a[n+1|0]=C&255;C=C>>8;a[n+2|0]=C&255;C=C>>8;a[n+3|0]=C&255;n=j+4|0;C=h;a[n]=C&255;C=C>>8;a[n+1|0]=C&255;C=C>>8;a[n+2|0]=C&255;C=C>>8;a[n+3|0]=C&255;n=e+f|0;h=k+i|0;i=n|0;j=n+4|0;n=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=h|0;C=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;a[j]=C&255;C=C>>8;a[j+1|0]=C&255;C=C>>8;a[j+2|0]=C&255;C=C>>8;a[j+3|0]=C&255;j=h+4|0;C=n;a[j]=C&255;C=C>>8;a[j+1|0]=C&255;C=C>>8;a[j+2|0]=C&255;C=C>>8;a[j+3|0]=C&255;j=f+16|0;if((j|0)<131072){f=j}else{o=0;break}}while(1){if((o|0)>=1024){break L58965}p=9638528+(o<<2)|0;if((c[p>>2]|0)==(e|0)){break}else{o=o+1|0}}gGr(e);c[p>>2]=0}}while(0);p=c[14164128+(c[2113146]<<2)>>2]|0;o=0;do{l=0;do{g=l+o|0;f=p+(g+64)|0;k=a[f]|0;b=p+g|0;a[f]=a[b]|0;a[b]=k;l=l+1|0;}while((l|0)<64);o=o+128|0;}while((o|0)<67108864);return}function cMY(){var a=0,b=0,d=0,e=0,f=0,g=0;a=0;while(1){if((a|0)>=1024){b=49778;break}d=9638528+(a<<2)|0;if((c[d>>2]|0)==0){break}else{a=a+1|0}}if((b|0)==49778){return}a=gGq(8388608)|0;c[d>>2]=a;if((a|0)==0){return}gGz(a|0,0,8388608);d=c[3541128]|0;gGC(a|0,d|0,8388608)|0;e=d+524288|0;f=a+524288|0;gGC(e|0,f|0,524288)|0;f=d+1048576|0;e=a+7340032|0;gGC(f|0,e|0,524288)|0;e=d+1572864|0;f=a+6815744|0;gGC(e|0,f|0,524288)|0;f=d+2097152|0;e=a+5242880|0;gGC(f|0,e|0,524288)|0;e=d+2621440|0;f=a+1572864|0;gGC(e|0,f|0,524288)|0;f=d+3145728|0;e=a+2097152|0;gGC(f|0,e|0,524288)|0;e=d+3670016|0;f=a+4718592|0;gGC(e|0,f|0,524288)|0;f=d+4194304|0;e=a+3145728|0;gGC(f|0,e|0,524288)|0;e=d+4718592|0;f=a+7864320|0;gGC(e|0,f|0,524288)|0;f=d+5242880|0;e=a+6291456|0;gGC(f|0,e|0,524288)|0;e=d+5767168|0;f=a+2621440|0;gGC(e|0,f|0,524288)|0;f=d+6291456|0;e=a+1048576|0;gGC(f|0,e|0,524288)|0;e=d+6815744|0;f=a+5767168|0;gGC(e|0,f|0,524288)|0;f=d+7340032|0;e=a+4194304|0;gGC(f|0,e|0,524288)|0;e=d+7864320|0;d=a+3670016|0;gGC(e|0,d|0,524288)|0;d=0;while(1){if((d|0)>=1024){b=49777;break}g=9638528+(d<<2)|0;if((c[g>>2]|0)==(a|0)){break}else{d=d+1|0}}if((b|0)==49777){return}gGr(a);c[g>>2]=0;return}function cMZ(){var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=i;i=i+2048|0;e=d|0;f=c[3541128]|0;g=1048576;do{h=f+g|0;gGC(f|0,h|0,65536)|0;h=0;do{a[f+(h+g)|0]=a[f+(h>>>9<<14&16384|h&6153|h>>>1<<15&32768|h>>>10<<13&8192|h>>>13<<10&1024|h>>>14<<9&512|h>>>5<<8&256|h>>>4<<7&128|h>>>2<<6&64|h>>>8<<5&32|h>>>7<<4&16|h>>>6<<2&4|h>>>15<<1&2)|0]|0;h=h+1|0;}while((h|0)<65536);g=g+65536|0;}while((g|0)<8388608);g=f+6291456|0;gGC(f|0,g|0,1048576)|0;b[f+40592>>1]=15;b[f+40594>>1]=-13888;b[f+41228>>1]=20153;b[f+41230>>1]=14;b[f+41232>>1]=-26800;f=c[2113146]|0;g=c[14164080+(f<<2)>>2]|0;h=0;do{j=g+h|0;k=a[j]|0;a[j]=k<<5&32|k&-34|(k&255)>>>5&1;h=h+1|0;}while((h|0)<131072);h=e|0;g=c[14164128+(f<<2)>>2]|0;f=0;do{k=c[591912+((f>>>4&15)<<2)>>2]|0;j=c[591764+(k<<4)>>2]|0;l=c[591760+(k<<4)>>2]|0;m=c[591756+(k<<4)>>2]|0;n=c[591752+(k<<4)>>2]|0;k=f<<11;o=0;do{p=e+(o<<7)|0;q=g+(((o>>>(n>>>0)&1|o&240|o>>>(j>>>0)<<3&8|o>>>(l>>>0)<<2&4|o>>>(m>>>0)<<1&2)<<7)+k)|0;gGC(p|0,q|0,128)|0;o=o+1|0;}while((o|0)<16);o=g+k|0;gGC(o|0,h|0,2048)|0;f=f+1|0;}while((f|0)<32768);f=c[3540996]|0;h=0;do{g=f+h|0;e=a[g]|0;o=f+(h+65536)|0;a[g]=a[o]|0;a[o]=e;h=h+1|0;}while((h|0)<65536);i=d;return}function cM_(){var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=i;i=i+2048|0;e=d|0;f=0;while(1){if((f|0)>=1024){break}g=9638528+(f<<2)|0;if((c[g>>2]|0)==0){h=49797;break}else{f=f+1|0}}L59021:do{if((h|0)==49797){f=gGq(1048576)|0;c[g>>2]=f;if((f|0)==0){break}gGz(f|0,0,1048576);j=c[3541128]|0;k=j+5242880|0;gGC(f|0,k|0,1048576)|0;k=j+1048576|0;gGC(k|0,j|0,5242880)|0;gGC(j|0,f|0,1048576)|0;j=0;while(1){if((j|0)>=1024){break L59021}l=9638528+(j<<2)|0;if((c[l>>2]|0)==(f|0)){break}else{j=j+1|0}}gGr(f);c[l>>2]=0}}while(0);b[(c[3541128]|0)+1015830>>1]=13249;l=c[2113146]|0;g=c[14164080+(l<<2)>>2]|0;h=0;do{j=g+h|0;k=a[j]|0;m=g+(h+65536)|0;a[j]=a[m]|0;a[m]=k;h=h+1|0;}while((h|0)<65536);h=e|0;g=c[14164128+(l<<2)>>2]|0;l=0;do{k=c[591912+((l>>>4&15)<<2)>>2]|0;m=c[591764+(k<<4)>>2]|0;j=c[591760+(k<<4)>>2]|0;n=c[591756+(k<<4)>>2]|0;o=c[591752+(k<<4)>>2]|0;k=l<<11;p=0;do{q=e+(p<<7)|0;r=g+(((p>>>(o>>>0)&1|p&240|p>>>(m>>>0)<<3&8|p>>>(j>>>0)<<2&4|p>>>(n>>>0)<<1&2)<<7)+k)|0;gGC(q|0,r|0,128)|0;p=p+1|0;}while((p|0)<16);p=g+k|0;gGC(p|0,h|0,2048)|0;l=l+1|0;}while((l|0)<32768);l=c[3540996]|0;h=0;do{g=l+h|0;e=a[g]|0;p=l+(h+65536)|0;a[g]=a[p]|0;a[p]=e;h=h+1|0;}while((h|0)<65536);i=d;return}function cM$(){var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=i;i=i+2048|0;e=d|0;f=0;while(1){if((f|0)>=1024){break}g=9638528+(f<<2)|0;if((c[g>>2]|0)==0){h=49814;break}else{f=f+1|0}}L59045:do{if((h|0)==49814){f=gGq(1048576)|0;c[g>>2]=f;if((f|0)==0){break}gGz(f|0,0,1048576);j=c[3541128]|0;k=0;do{l=0;do{a[f+l|0]=a[j+(((l>>>1<<19&524288|l&15859697|l>>>2<<18&262144|l>>>3<<17&131072|l>>>17<<3&8|l>>>18<<2&4|l>>>19<<1&2)^917518)+k)|0]|0;l=l+1|0;}while((l|0)<1048576);l=j+k|0;gGC(l|0,f|0,1048576)|0;k=k+1048576|0;}while((k|0)<6291456);k=j+1048576|0;gGC(k|0,j|0,5242880)|0;gGC(j|0,f|0,1048576)|0;k=0;while(1){if((k|0)>=1024){break L59045}m=9638528+(k<<2)|0;if((c[m>>2]|0)==(f|0)){break}else{k=k+1|0}}gGr(f);c[m>>2]=0}}while(0);b[(c[3541128]|0)+1015830>>1]=13249;cMD();m=e|0;g=c[14164128+(c[2113146]<<2)>>2]|0;h=0;do{k=c[591912+((h>>>4&15)<<2)>>2]|0;j=c[591764+(k<<4)>>2]|0;l=c[591760+(k<<4)>>2]|0;n=c[591756+(k<<4)>>2]|0;o=c[591752+(k<<4)>>2]|0;k=h<<11;p=0;do{q=e+(p<<7)|0;r=g+(((p>>>(o>>>0)&1|p&240|p>>>(j>>>0)<<3&8|p>>>(l>>>0)<<2&4|p>>>(n>>>0)<<1&2)<<7)+k)|0;gGC(q|0,r|0,128)|0;p=p+1|0;}while((p|0)<16);p=g+k|0;gGC(p|0,m|0,2048)|0;h=h+1|0;}while((h|0)<32768);h=c[3540996]|0;m=0;do{g=h+m|0;e=a[g]|0;p=h+(m+65536)|0;a[g]=a[p]|0;a[p]=e;m=m+1|0;}while((m|0)<65536);i=d;return}function cM0(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=i;i=i+2048|0;d=b|0;e=c[3541128]|0;f=1048576;do{g=e+f|0;gGC(e|0,g|0,1048576)|0;g=0;do{a[e+(g+f)|0]=a[e+(g&1048473|g>>>2<<6&64|g>>>1<<5&32|g>>>6<<2&4|g>>>5<<1&2)|0]|0;g=g+1|0;}while((g|0)<1048576);f=f+1048576|0;}while((f|0)<8388608);f=e+7340032|0;gGC(e|0,f|0,1048576)|0;f=c[2113146]|0;e=c[14164080+(f<<2)>>2]|0;g=0;do{h=e+g|0;j=a[h]|0;k=e+(g+65536)|0;a[h]=a[k]|0;a[k]=j;g=g+1|0;}while((g|0)<65536);g=d|0;e=c[14164128+(f<<2)>>2]|0;f=0;do{j=c[591912+((f>>>4&15)<<2)>>2]|0;k=c[591764+(j<<4)>>2]|0;h=c[591760+(j<<4)>>2]|0;l=c[591756+(j<<4)>>2]|0;m=c[591752+(j<<4)>>2]|0;j=f<<11;n=0;do{o=d+(n<<7)|0;p=e+(((n>>>(m>>>0)&1|n&240|n>>>(k>>>0)<<3&8|n>>>(h>>>0)<<2&4|n>>>(l>>>0)<<1&2)<<7)+j)|0;gGC(o|0,p|0,128)|0;n=n+1|0;}while((n|0)<16);n=e+j|0;gGC(n|0,g|0,2048)|0;f=f+1|0;}while((f|0)<32768);f=c[3540996]|0;g=0;do{e=f+g|0;d=a[e]|0;n=f+(g+65536)|0;a[e]=a[n]|0;a[n]=d;g=g+1|0;}while((g|0)<65536);i=b;return}function cM1(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541128]|0;e=0;while(1){f=b+e|0;a[f]=a[f]^~a[b+(e&31|1048544)|0];f=e+1|0;if((f|0)<1048576){e=f}else{g=1048576;break}}while(1){e=b+g|0;a[e]=a[e]^~a[b+(g&31|8388576)|0];e=g+1|0;if((e|0)<8388608){g=e}else{h=1048576;break}}do{g=h|1;e=b+g|0;f=b+(g+1)|0;g=d[f]|0;i=a[e]|0;a[e]=(i&255)>>>7<<6|i&15|(i&255)>>>6<<7|(i&255)>>>4<<5&32|(i&255)>>>5<<4&16;a[f]=((g<<9&512|g<<8&-4096|(g&65535)>>>2<<11&2048|(g&65535)>>>3<<10&1024|(g&65535)>>>1<<8&256)&65535)>>>8&255;h=h+4|0;}while((h|0)<6291456);h=b+7340032|0;gGC(h|0,b|0,1048576)|0;g=0;while(1){f=b+(g<<16)|0;i=b+(((g<<1&2|g&240|g>>>1&1|g>>>2<<3&8|g>>>3<<2&4)<<16)+7340032)|0;gGC(f|0,i|0,65536)|0;i=g+1|0;if((i|0)<16){g=i}else{j=1048576;break}}do{g=0;do{i=b+(g+7340032)|0;f=b+((((g>>>17<<6&64|g>>>14&1|g>>>16<<7&128|g>>>18<<5&32|g>>>19<<4&16|g>>>13<<3&8|g>>12<<2&4|g>>>15<<1&2)<<12|g&3840)^2560)+j)|0;gGC(i|0,f|0,256)|0;g=g+256|0;}while((g|0)<1048576);g=b+j|0;gGC(g|0,h|0,1048576)|0;j=j+1048576|0;}while((j|0)<7340032);return}function cM2(){var a=0;a=c[2112932]|0;c[a+77792>>2]=6;c[a+77796>>2]=6;c[a+77800>>2]=6;c[a+77804>>2]=6;c[a+77808>>2]=6;c[a+77812>>2]=6;c[a+77816>>2]=6;c[a+77820>>2]=6;c[a+196752>>2]=64;return}function cM3(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541128]|0;e=0;while(1){f=b+e|0;a[f]=a[f]^a[b+(e&31|1048544)|0];f=e+1|0;if((f|0)<1048576){e=f}else{g=1048576;break}}while(1){e=b+g|0;a[e]=a[e]^~a[b+(g&31|8388576)|0];e=g+1|0;if((e|0)<7340032){g=e}else{h=1048576;break}}do{g=h|1;e=b+g|0;f=b+(g+1)|0;g=d[f]|0;i=a[e]|0;a[e]=(i&255)>>>7<<6|i&15|(i&255)>>>6<<7|(i&255)>>>4<<5&32|(i&255)>>>5<<4&16;a[f]=((g<<9&512|g<<8&-4096|(g&65535)>>>2<<11&2048|(g&65535)>>>3<<10&1024|(g&65535)>>>1<<8&256)&65535)>>>8&255;h=h+4|0;}while((h|0)<5242880);h=b+7340032|0;gGC(h|0,b|0,1048576)|0;g=0;while(1){f=b+(g<<16)|0;i=b+(((g<<2&4|g&240|g>>>2&1|g>>>1<<3&8|g>>>3<<1&2)<<16)+7340032)|0;gGC(f|0,i|0,65536)|0;i=g+1|0;if((i|0)<16){g=i}else{j=1048576;break}}do{g=0;do{i=b+(g+7340032)|0;f=b+((((g>>>16<<6&64|g>>>14&1|g>>>17<<7&128|g>>>19<<5&32|g>>>18<<4&16|g>>>13<<3&8|g>>12<<2&4|g>>>15<<1&2)<<12|g&3840)^1792)+j)|0;gGC(i|0,f|0,256)|0;g=g+256|0;}while((g|0)<1048576);g=b+j|0;gGC(g|0,h|0,1048576)|0;j=j+1048576|0;}while((j|0)<7340032);return}function cM4(){var a=0,b=0,d=0,e=0,f=0,g=0;a=0;while(1){if((a|0)>=1024){b=49873;break}d=9638528+(a<<2)|0;if((c[d>>2]|0)==0){break}else{a=a+1|0}}if((b|0)==49873){return}a=gGq(1048576)|0;c[d>>2]=a;if((a|0)==0){return}gGz(a|0,0,1048576);d=c[3541128]|0;gGC(a|0,d|0,1048576)|0;e=d+4194304|0;gGC(d|0,e|0,1048576)|0;gGC(e|0,a|0,1048576)|0;e=d+1048576|0;gGC(a|0,e|0,1048576)|0;f=d+3145728|0;gGC(e|0,f|0,1048576)|0;gGC(f|0,a|0,1048576)|0;f=0;while(1){if((f|0)>=1024){b=49874;break}g=9638528+(f<<2)|0;if((c[g>>2]|0)==(a|0)){break}else{f=f+1|0}}if((b|0)==49874){return}gGr(a);c[g>>2]=0;return}function cM5(){var b=0,d=0,e=0,f=0,g=0,h=0;b=i;i=i+128|0;d=b|0;e=d|0;f=c[3541128]|0;g=0;do{h=0;do{a[d+h|0]=a[f+((h>>>3<<6&64|h&129|h>>>4<<5&32|h>>>5<<4&16|h>>>6<<3&8|h>>>1<<2&4|h>>>2<<1&2)+g)|0]|0;h=h+1|0;}while((h|0)<128);h=f+g|0;gGC(h|0,e|0,128)|0;g=g+128|0;}while((g|0)<8388608);g=f+6291456|0;gGC(f|0,g|0,1048576)|0;g=c[3540996]|0;f=0;do{e=g+f|0;d=a[e]|0;a[e]=(d&255)>>>7<<4|(d&255)>>>4<<7|d<<3&8|(d&255)>>>3&1|(d&255)>>>5<<6&64|(d&255)>>>6<<5&32|(d&255)>>>1<<2&4|(d&255)>>>2<<1&2;f=f+1|0;}while((f|0)<196608);f=c[14164080+(c[2113146]<<2)>>2]|0;g=0;do{d=f+g|0;e=a[d]|0;a[d]=(e&255)>>>7<<4|(e&255)>>>4<<7|e<<3&8|(e&255)>>>3&1|(e&255)>>>5<<6&64|(e&255)>>>6<<5&32|(e&255)>>>1<<2&4|(e&255)>>>2<<1&2;g=g+1|0;}while((g|0)<131072);i=b;return}function cM6(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0;a=0;while(1){if((a|0)>=1024){break}d=9638528+(a<<2)|0;if((c[d>>2]|0)==0){e=49889;break}else{a=a+1|0}}L59154:do{if((e|0)==49889){a=gGq(1048576)|0;c[d>>2]=a;if((a|0)==0){break}gGz(a|0,0,1048576);f=c[3541128]|0;g=f+393216|0;gGC(a|0,g|0,131072)|0;g=a+131072|0;h=f+1048576|0;gGC(g|0,h|0,131072)|0;h=a+262144|0;g=f+917504|0;gGC(h|0,g|0,131072)|0;g=a+393216|0;h=f+1572864|0;gGC(g|0,h|0,131072)|0;h=a+524288|0;g=f+131072|0;gGC(h|0,g|0,131072)|0;g=a+655360|0;h=f+1310720|0;gGC(g|0,h|0,131072)|0;h=a+786432|0;g=f+786432|0;gGC(h|0,g|0,131072)|0;g=a+917504|0;h=f+1703936|0;gGC(g|0,h|0,131072)|0;h=a+736|0;g=f+262880|0;gGC(h|0,g|0,106)|0;g=a+1020604|0;h=f+299708|0;gGC(g|0,h|0,2974)|0;gGC(f|0,a|0,1048576)|0;f=0;while(1){if((f|0)>=1024){break L59154}i=9638528+(f<<2)|0;if((c[i>>2]|0)==(a|0)){break}else{f=f+1|0}}gGr(a);c[i>>2]=0}}while(0);i=c[3541128]|0;d=i+1048576|0;e=i+2097152|0;gGC(d|0,e|0,6291456)|0;e=1020604;while(1){d=e+2|0;do{if((b[i+e>>1]&-65)<<16>>16==20153){f=i+d|0;if((b[f>>1]|0)!=0){break}b[f>>1]=15}}while(0);if((d|0)<1023576){e=d}else{break}}b[i+834>>1]=15;cMD();return}function cM7(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=0;while(1){if((d|0)>=1024){break}e=9638528+(d<<2)|0;if((c[e>>2]|0)==0){f=49903;break}else{d=d+1|0}}L59173:do{if((f|0)==49903){d=gGq(1048576)|0;c[e>>2]=d;if((d|0)==0){break}gGz(d|0,0,1048576);g=c[3541128]|0;h=0;do{i=0;do{a[d+(i>>>2<<10&1024|i&16776121|i>>>1<<6&64|i>>>10<<2&4|i>>>6<<1&2)|0]=a[g+(i+h)|0]|0;i=i+1|0;}while((i|0)<1048576);i=g+h|0;gGC(i|0,d|0,1048576)|0;h=h+1048576|0;}while((h|0)<8388608);h=g+1048576|0;gGC(h|0,g|0,7340032)|0;gGC(g|0,d|0,1048576)|0;h=0;while(1){if((h|0)>=1024){break L59173}j=9638528+(h<<2)|0;if((c[j>>2]|0)==(d|0)){break}else{h=h+1|0}}gGr(d);c[j>>2]=0}}while(0);j=c[3541128]|0;b[j+292>>1]=13;b[j+294>>1]=-2136;b[j+35828>>1]=20217;b[j+35830>>1]=13;b[j+35832>>1]=-1664;return}function cM8(){var a=0,b=0,d=0,e=0,f=0;a=c[2432928]|0;b=c[2112932]|0;d=b+3584|0;e=917504;while(1){f=a+(e-917504)|0;c[d>>2]=f;c[d+131072>>2]=f;f=e+1024|0;if(f>>>0>1048575){break}else{d=d+4|0;e=f}}e=c[2432926]|0;c[b+12256>>2]=e;c[b+143328>>2]=e;d=e+1024|0;c[b+12260>>2]=d;c[b+143332>>2]=d;d=e+2048|0;c[b+12264>>2]=d;c[b+143336>>2]=d;d=e+3072|0;c[b+12268>>2]=d;c[b+143340>>2]=d;d=e+4096|0;c[b+12272>>2]=d;c[b+143344>>2]=d;d=e+5120|0;c[b+12276>>2]=d;c[b+143348>>2]=d;d=e+6144|0;c[b+12280>>2]=d;c[b+143352>>2]=d;d=e+7168|0;c[b+12284>>2]=d;c[b+143356>>2]=d;c[b+77792>>2]=6;c[b+77796>>2]=6;c[b+77800>>2]=6;c[b+77804>>2]=6;c[b+77808>>2]=6;c[b+77812>>2]=6;c[b+77816>>2]=6;c[b+77820>>2]=6;c[b+196752>>2]=3442;c[b+196672>>2]=3064;d=b+8192|0;e=d;a=2097152;while(1){c[e+65536>>2]=7;f=a+1024|0;if(f>>>0>2359295){break}else{e=e+4|0;a=f}}c[b+196756>>2]=2508;c[2113148]=1048576;b=c[3541128]|0;a=d;d=2097152;while(1){e=b+(d-1048576)|0;c[a>>2]=e;c[a+131072>>2]=e;e=d+1024|0;if(e>>>0>3137535){break}else{a=a+4|0;d=e}}return}function cM9(){var a=0,b=0,d=0,e=0,f=0;a=c[3541128]|0;b=(c[2113148]|0)-2097152|0;d=(c[2112932]|0)+8192|0;e=2097152;while(1){f=a+(b+e)|0;c[d>>2]=f;c[d+131072>>2]=f;f=e+1024|0;if(f>>>0>3137535){break}else{d=d+4|0;e=f}}return}function cNa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=i;i=i+16|0;e=d|0;if((b|0)!=0){c[b>>2]=169747}if((a&32|0)==0){i=d;return 0}a=e|0;c[a>>2]=c[2432928];b=e+4|0;c[b>>2]=131072;f=e+8|0;c[f>>2]=0;g=e+12|0;c[g>>2]=67632;gj[c[2076592]&4095](e)|0;c[a>>2]=c[2432926];c[b>>2]=8192;c[f>>2]=0;c[g>>2]=67392;gj[c[2076592]&4095](e)|0;i=d;return 0}function cNb(){var a=0,b=0,d=0;a=c[3541128]|0;b=a+1835008|0;gGC(a|0,b|0,262144)|0;b=a+786432|0;d=a+1048576|0;gGC(b|0,d|0,262144)|0;b=a+2097152|0;gGC(d|0,b|0,4194304)|0;cMD();return}function cNc(){var b=0,d=0,e=0,f=0;b=c[3541128]|0;d=0;do{a[b+d|0]=a[b+((d&16776960)+3145728+(d>>>3<<6&64|d&129|d>>>4<<5&32|d>>>5<<4&16|d>>>6<<3&8|d>>>1<<2&4|d>>>2<<1&2))|0]|0;d=d+1|0;}while((d|0)<5242880);d=c[14164080+(c[2113146]<<2)>>2]|0;b=0;do{e=d+b|0;f=a[e]|0;a[e]=f<<5&32|f&-34|(f&255)>>>5&1;b=b+1|0;}while((b|0)<131072);return}function cNd(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0;a=0;while(1){if((a|0)>=1024){break}b=9638528+(a<<2)|0;if((c[b>>2]|0)==0){d=49939;break}else{a=a+1|0}}L59221:do{if((d|0)==49939){a=gGq(4194304)|0;c[b>>2]=a;if((a|0)==0){break}gGz(a|0,0,4194304);e=c[3541128]|0;f=e+1048576|0;gGC(a|0,f|0,4194304)|0;g=a+1048576|0;gGC(f|0,g|0,524288)|0;g=e+1572864|0;f=a+2621440|0;gGC(g|0,f|0,524288)|0;f=e+2097152|0;g=a+3145728|0;gGC(f|0,g|0,524288)|0;g=e+2621440|0;f=a+1572864|0;gGC(g|0,f|0,524288)|0;f=e+3145728|0;gGC(f|0,a|0,524288)|0;f=e+3670016|0;g=a+3670016|0;gGC(f|0,g|0,524288)|0;g=e+4194304|0;f=a+2097152|0;gGC(g|0,f|0,524288)|0;f=e+4718592|0;e=a+524288|0;gGC(f|0,e|0,524288)|0;e=0;while(1){if((e|0)>=1024){break L59221}h=9638528+(e<<2)|0;if((c[h>>2]|0)==(a|0)){break}else{e=e+1|0}}gGr(a);c[h>>2]=0}}while(0);h=c[2113146]|0;cFL(c[14164128+(h<<2)>>2]|0,67108864);cFL(c[14164080+(h<<2)>>2]|0,131072);return}function cNe(){var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=i;i=i+2048|0;e=d|0;f=c[3541128]|0;b[f+999770>>1]=20217;b[f+999772>>1]=15;b[f+999774>>1]=19698;g=1761936;while(1){b[f+g>>1]=0;h=g+2|0;if((h|0)<1763536){g=h}else{j=2068208;break}}do{g=f+j|0;b[g>>1]=(b[g>>1]|0)-28672&65535;g=f+(j|2)|0;b[g>>1]=(b[g>>1]|0)-16&65535;j=j+4|0;}while((j|0)<2073072);gGz(f+705792|0,-1|0,32);b[f+627152>>1]=-8957;b[f+627462>>1]=-8957;b[f+627540>>1]=-8957;b[f+627774>>1]=-8957;f=c[3540996]|0;j=0;do{g=f+(j+32768)|0;h=a[g]|0;k=f+(j+65536)|0;a[g]=a[k]|0;a[k]=h;j=j+1|0;}while((j|0)<32768);j=e|0;f=c[14164128+(c[2113146]<<2)>>2]|0;h=0;do{k=c[591848+((h>>>5&15)<<2)>>2]|0;g=c[591764+(k<<4)>>2]|0;l=c[591760+(k<<4)>>2]|0;m=c[591756+(k<<4)>>2]|0;n=c[591752+(k<<4)>>2]|0;k=h<<11;o=0;do{p=e+(o<<7)|0;q=f+(((o>>>(n>>>0)&1|o&240|o>>>(g>>>0)<<3&8|o>>>(l>>>0)<<2&4|o>>>(m>>>0)<<1&2)<<7)+k)|0;gGC(p|0,q|0,128)|0;o=o+1|0;}while((o|0)<16);o=f+k|0;gGC(o|0,j|0,2048)|0;h=h+1|0;}while((h|0)<32768);i=d;return}function cNf(){var b=0,d=0,e=0,f=0,g=0;b=0;while(1){if((b|0)>=1024){d=49969;break}e=9638528+(b<<2)|0;if((c[e>>2]|0)==0){break}else{b=b+1|0}}if((d|0)==49969){cNe();return}b=gGq(262144)|0;c[e>>2]=b;if((b|0)==0){cNe();return}gGz(b|0,0,262144);e=c[14164080+(c[2113146]<<2)>>2]|0;f=0;do{a[b+f|0]=a[e+(f<<15&32768|f&16646208|f>>>12&1|f>>>3<<16&65536|f>>>1<<14&16384|f>>>4<<13&8192|f>>>2<<12&4096|f>>>13<<11&2048|f>>>14<<10&1024|f>>>15<<9&512|f>>>16<<8&256|f>>>5<<7&128|f>>>11<<5&32|f>>>10<<4&16|f>>>9<<3&8|f>>>8<<2&4|f>>>7<<1&2)|0]|0;f=f+1|0;}while((f|0)<262144);gGC(e|0,b|0,262144)|0;e=0;while(1){if((e|0)>=1024){d=49968;break}g=9638528+(e<<2)|0;if((c[g>>2]|0)==(b|0)){break}else{e=e+1|0}}if((d|0)==49968){cNe();return}gGr(b);c[g>>2]=0;cNe();return}function cNg(){var a=0,b=0,d=0,e=0,f=0;a=c[2112932]|0;b=a+8192|0;d=b;e=2097152;while(1){c[d+65536>>2]=6;f=e+1024|0;if(f>>>0>3145727){break}else{d=d+4|0;e=f}}c[a+196752>>2]=642;c[a+196672>>2]=1610;if((c[2113148]|0)==2097152){return}c[2113148]=2097152;a=c[3541128]|0;e=b;b=2097152;while(1){d=a+b|0;c[e>>2]=d;c[e+131072>>2]=d;d=b+1024|0;if(d>>>0>3145727){break}else{e=e+4|0;b=d}}return}function cNh(){var b=0,d=0,e=0,f=0,g=0;b=c[14164080+(c[2113146]<<2)>>2]|0;d=0;do{e=b+(d+32768)|0;f=a[e]|0;g=b+(d+65536)|0;a[e]=a[g]|0;a[g]=f;d=d+1|0;}while((d|0)<32768);cNe();return}function cNi(){var a=0,b=0,d=0,e=0,f=0;a=c[2112932]|0;b=a+8192|0;d=b;e=2097152;while(1){c[d+65536>>2]=6;f=e+1024|0;if(f>>>0>3145727){break}else{d=d+4|0;e=f}}c[a+196752>>2]=642;c[a+196672>>2]=1610;if((c[2113148]|0)==2097152){return}c[2113148]=2097152;a=c[3541128]|0;e=b;b=2097152;while(1){d=a+b|0;c[e>>2]=d;c[e+131072>>2]=d;d=b+1024|0;if(d>>>0>3145727){break}else{e=e+4|0;b=d}}return}function cNj(){var a=0,d=0,e=0,f=0,g=0,h=0,j=0;a=i;i=i+2048|0;d=a|0;e=c[3541128]|0;f=e+1048576|0;g=0;do{h=f+(g<<1)|0;j=b[h>>1]|0;b[h>>1]=(j&65535)>>>12<<15|j&6|(j&65535)>>>15<<11|j<<8&256|(j&65535)>>>4&1|(j&65535)>>>8<<14&16384|(j&65535)>>>11<<13&8192|(j&65535)>>>3<<12&4096|(j&65535)>>>14<<10&1024|(j&65535)>>>7<<9&512|(j&65535)>>>10<<7&128|(j&65535)>>>13<<6&64|(j&65535)>>>6<<5&32|(j&65535)>>>5<<4&16|(j&65535)>>>9<<3&8;g=g+1|0;}while((g|0)<4194304);g=e;e=0;do{b[g+(e<<1)>>1]=b[g+((e<<4&16|e&16547970|e>>>9&1|e>>>8<<17&131072|e>>>4<<16&65536|e>>>13<<14&16384|e>>>3<<13&8192|e>>>14<<12&4096|e>>>16<<11&2048|e>>>2<<10&1024|e>>>6<<9&512|e>>>17<<8&256|e>>>12<<6&64|e>>>10<<5&32|e>>>5<<3&8|e>>>11<<2&4)+3788800<<1)>>1]|0;e=e+1|0;}while((e|0)<393216);e=d;g=0;do{j=f+(g<<1)|0;gGC(e|0,j|0,2048)|0;j=0;do{b[f+(j+g<<1)>>1]=b[d+((j<<2&4|j&16776192|j>>>5&1|j>>>4<<9&512|j>>>1<<8&256|j>>>3<<7&128|j>>>8<<6&64|j>>>6<<5&32|j>>>2<<4&16|j>>>7<<3&8|j>>>9<<1&2)<<1)>>1]|0;j=j+1|0;}while((j|0)<1024);g=g+1024|0;}while((g|0)<3264512);i=a;return}function cNk(){var a=0,b=0;a=c[2112932]|0;c[a+77820>>2]=8;b=c[2113146]|0;c[a+196760>>2]=c[9708888+(b<<2)>>2];c[a+12260>>2]=6;c[a+143332>>2]=6;c[a+196712>>2]=476;c[a+196632>>2]=1068;do{if((c[9721720+(b<<3)>>2]|0)==0){if((c[9721724+(b<<3)>>2]|0)!=0){break}return}}while(0);c[a+12284>>2]=7;c[a+143356>>2]=7;c[a+196716>>2]=1002;c[a+196636>>2]=2038;return}function cNl(){var b=0,d=0,e=0,f=0;b=c[3541128]|0;d=b+1048576|0;gGC(b|0,d|0,5242880)|0;d=c[14164080+(c[2113146]<<2)>>2]|0;b=0;do{e=d+b|0;f=a[e]|0;a[e]=f<<5&32|f&-34|(f&255)>>>5&1;b=b+1|0;}while((b|0)<131072);return}function cNm(){var a=0,d=0,e=0,f=0,g=0,h=0,j=0;a=i;i=i+65536|0;d=a|0;e=c[3541128]|0;f=e+1048576|0;g=0;do{h=f+(g<<1)|0;j=b[h>>1]|0;b[h>>1]=j<<9&512|(j&65535)>>>4<<15|(j&65535)>>>15<<4|(j&65535)>>>6&1|(j&65535)>>>11<<14&16384|(j&65535)>>>14<<13&8192|(j&65535)>>>3<<12&4096|(j&65535)>>>1<<11&2048|(j&65535)>>>13<<10&1024|(j&65535)>>>7<<8&256|(j&65535)>>>2<<7&128|(j&65535)>>>8<<6&64|(j&65535)>>>12<<5&32|(j&65535)>>>10<<3&8|(j&65535)>>>9<<2&4|(j&65535)>>>5<<1&2;g=g+1|0;}while((g|0)<4194304);g=e;e=0;do{b[g+(e<<1)>>1]=b[g+((e<<12&4096|e&16515072|e>>>8&1|e>>>15<<17&131072|e>>>2<<16&65536|e>>>1<<15&32768|e>>>13<<14&16384|e>>>3<<13&8192|e>>>9<<11&2048|e>>>6<<10&1024|e>>>16<<9&512|e>>>4<<8&256|e>>>11<<7&128|e>>>5<<6&64|e>>>7<<5&32|e>>>12<<4&16|e>>>17<<3&8|e>>>14<<2&4|e>>>10<<1&2)+3047424<<1)>>1]|0;e=e+1|0;}while((e|0)<393216);e=d;g=0;do{j=f+(g<<1)|0;gGC(e|0,j|0,65536)|0;j=0;do{b[f+(j+g<<1)>>1]=b[d+((j<<12&4096|j&16744448|j>>>1&1|j>>>2<<14&16384|j>>>11<<13&8192|j>>>14<<11&2048|j>>>6<<10&1024|j>>>4<<9&512|j>>>13<<8&256|j>>>8<<7&128|j>>>9<<6&64|j>>>3<<5&32|j>>>10<<4&16|j>>>7<<3&8|j>>>5<<2&4|j>>>12<<1&2)<<1)>>1]|0;j=j+1|0;}while((j|0)<32768);g=g+32768|0;}while((g|0)<4194304);i=a;return}function cNn(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=c[2113146]|0;d=c[14164080+(b<<2)>>2]|0;e=0;do{f=d+e|0;g=a[f]|0;a[f]=g<<5&32|g&-34|(g&255)>>>5&1;e=e+1|0;}while((e|0)<131072);e=c[14164128+(b<<2)>>2]|0;b=0;do{d=0;do{g=d+b|0;f=e+(g+64)|0;h=a[f]|0;i=e+g|0;a[f]=a[i]|0;a[i]=h;d=d+1|0;}while((d|0)<64);b=b+128|0;}while((b|0)<67108864);return}function cNo(){var a=0,d=0,e=0,f=0,g=0,h=0,j=0;a=i;i=i+32768|0;d=a|0;e=c[3541128]|0;f=e+1048576|0;g=0;do{h=f+(g<<1)|0;j=b[h>>1]|0;b[h>>1]=(j&65535)>>>14<<15|j&4|(j&65535)>>>15<<8|j<<3&8|(j&65535)>>>6&1|(j&65535)>>>5<<14&16384|(j&65535)>>>1<<13&8192|(j&65535)>>>11<<12&4096|(j&65535)>>>7<<11&2048|(j&65535)>>>4<<10&1024|(j&65535)>>>10<<9&512|(j&65535)>>>3<<7&128|(j&65535)>>>12<<6&64|(j&65535)>>>8<<5&32|(j&65535)>>>13<<4&16|(j&65535)>>>9<<1&2;g=g+1|0;}while((g|0)<4194304);g=e;e=0;do{b[g+(e<<1)>>1]=b[g+((e<<5&32|e&16580864|e>>>13&1|e>>>5<<17&131072|e>>>11<<15&32768|e>>>2<<14&16384|e>>>6<<13&8192|e>>>7<<12&4096|e>>>17<<11&2048|e>>>3<<10&1024|e>>>12<<9&512|e>>>14<<7&128|e>>>4<<6&64|e>>>9<<4&16|e>>>1<<3&8|e>>>10<<2&4|e>>>15<<1&2)+4177920<<1)>>1]|0;e=e+1|0;}while((e|0)<393216);e=d;g=0;do{j=f+(g<<1)|0;gGC(e|0,j|0,32768)|0;j=0;do{b[f+(j+g<<1)>>1]=b[d+((j<<1&2|j&16760832|j>>>2&1|j>>>12<<13&8192|j>>>8<<12&4096|j>>>1<<11&2048|j>>>7<<10&1024|j>>>11<<9&512|j>>>3<<8&256|j>>>13<<7&128|j>>>10<<6&64|j>>>6<<5&32|j>>>9<<4&16|j>>>5<<3&8|j>>>4<<2&4)<<1)>>1]|0;j=j+1|0;}while((j|0)<16384);g=g+16384|0;}while((g|0)<4194304);i=a;return}function cNp(){var a=0,d=0,e=0,f=0,g=0,h=0,j=0;a=i;i=i+32768|0;d=a|0;e=c[3541128]|0;f=e+1048576|0;g=0;do{h=f+(g<<1)|0;j=b[h>>1]|0;b[h>>1]=(j&65535)>>>13<<15|j&16|(j&65535)>>>15<<3|j<<2&4|(j&65535)>>>7&1|(j&65535)>>>12<<14&16384|(j&65535)>>>14<<13&8192|(j&65535)>>>10<<12&4096|(j&65535)>>>8<<11&2048|(j&65535)>>>2<<10&1024|(j&65535)>>>3<<9&512|(j&65535)>>>1<<8&256|(j&65535)>>>5<<7&128|(j&65535)>>>9<<6&64|(j&65535)>>>11<<5&32|(j&65535)>>>6<<1&2;g=g+1|0;}while((g|0)<4194304);g=e;e=0;do{b[g+(e<<1)>>1]=b[g+((e>>>4<<17&131072|e&16531457|e>>>5<<16&65536|e>>>16<<15&32768|e>>>7<<13&8192|e>>>9<<12&4096|e>>>6<<11&2048|e>>>13<<10&1024|e>>>17<<9&512|e>>>15<<8&256|e>>>3<<7&128|e>>>1<<6&64|e>>>2<<5&32|e>>>12<<4&16|e>>>11<<3&8|e>>>8<<2&4|e>>>10<<1&2)+3702784<<1)>>1]|0;e=e+1|0;}while((e|0)<393216);e=d;g=0;do{j=f+(g<<1)|0;gGC(e|0,j|0,32768)|0;j=0;do{b[f+(j+g<<1)>>1]=b[d+((j<<5&32|j&16760832|j>>>5&1|j>>>9<<13&8192|j>>>4<<12&4096|j>>>8<<11&2048|j>>>3<<10&1024|j>>>13<<9&512|j>>>6<<8&256|j>>>2<<7&128|j>>>7<<6&64|j>>>12<<4&16|j>>>1<<3&8|j>>>11<<2&4|j>>>10<<1&2)<<1)>>1]|0;j=j+1|0;}while((j|0)<16384);g=g+16384|0;}while((g|0)<4194304);i=a;return}function cNq(){var a=0,d=0,e=0,f=0,g=0,h=0,j=0;a=i;i=i+2048|0;d=a|0;e=c[3541128]|0;f=e+1048576|0;g=0;do{h=f+(g<<1)|0;j=b[h>>1]|0;b[h>>1]=(j&65535)>>>13<<15|(j&65535)>>>15|j<<12&4096|(j&65535)>>>7<<14&16384|(j&65535)>>>3<<13&8192|(j&65535)>>>9<<11&2048|(j&65535)>>>4<<10&1024|(j&65535)>>>5<<9&512|(j&65535)>>>6<<8&256|(j&65535)>>>1<<7&128|(j&65535)>>>12<<6&64|(j&65535)>>>8<<5&32|(j&65535)>>>14<<4&16|(j&65535)>>>10<<3&8|(j&65535)>>>11<<2&4|(j&65535)>>>2<<1&2;g=g+1|0;}while((g|0)<4194304);g=e;e=0;do{b[g+(e<<1)>>1]=b[g+((e<<8&256|e&16516096|e>>>1&1|e>>>11<<17&131072|e>>>6<<16&65536|e>>>14<<15&32768|e>>>17<<14&16384|e>>>16<<13&8192|e>>>5<<12&4096|e>>>8<<11&2048|e>>>12<<9&512|e>>>4<<7&128|e>>>3<<6&64|e>>>2<<5&32|e>>>7<<4&16|e>>>9<<3&8|e>>>15<<2&4|e>>>13<<1&2)+3670016<<1)>>1]|0;e=e+1|0;}while((e|0)<393216);e=d;g=0;do{j=f+(g<<1)|0;gGC(e|0,j|0,2048)|0;j=0;do{b[f+(j+g<<1)>>1]=b[d+((j<<1&2|j&16776192|j>>>5&1|j>>>6<<9&512|j>>>2<<8&256|j>>>4<<7&128|j>>>9<<6&64|j>>>8<<5&32|j>>>3<<4&16|j>>>1<<3&8|j>>>7<<2&4)<<1)>>1]|0;j=j+1|0;}while((j|0)<1024);g=g+1024|0;}while((g|0)<3145728);i=a;return}function cNr(){var a=0;a=c[2112932]|0;c[a+12284>>2]=6;c[a+77820>>2]=6;c[a+143356>>2]=6;c[a+196712>>2]=1380;c[a+196632>>2]=2628;c[a+196752>>2]=236;c[a+196672>>2]=1364;return}function cNs(){var a=0,b=0,d=0,e=0,f=0;a=c[3541128]|0;b=(c[2113148]|0)-2097152|0;d=(c[2112932]|0)+8192|0;e=2097152;while(1){f=a+(b+e)|0;c[d>>2]=f;c[d+131072>>2]=f;f=e+1024|0;if(f>>>0>3144703){break}else{d=d+4|0;e=f}}return}function cNt(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((f|0)!=3145704){g=b[(c[3541128]|0)+((c[2113148]|0)+(f&1048574))>>1]|0;return g|0}f=e[4876468]|0;if((f|0)==4095){h=c[2112932]|0;i=c[h+4336>>2]|0;if(i>>>0>9){j=(d[i+11|0]|0)<<8|(d[i+10|0]|0);k=h}else{l=gj[c[h+196688+(i<<2)>>2]&4095](1110026)|0;j=l;k=c[2112932]|0}l=j&65535;j=(l+32767|0)>>>3;i=(j&4095)+912850&917503;h=c[k+(i>>>10<<2)>>2]|0;if(h>>>0>9){m=a[h+(j+466&1023^1)|0]|0}else{m=gj[c[k+196608+(h<<2)>>2]&4095](i)|0}g=(m&255)>>>((-l&7)>>>0)&1;return g|0}else if((f|0)==1){f=b[4876464]|0;l=(f&65535)>>>3;m=(l&4095)+912850|0;i=c[2112932]|0;h=c[i+(m>>>10<<2)>>2]|0;if(h>>>0>9){n=a[h+(l+466&1023^1)|0]|0;o=f}else{f=gj[c[i+196608+(h<<2)>>2]&4095](m)|0;n=f;o=b[4876464]|0}b[4876464]=o+1&65535;g=(n&255)>>>((o&7^7)>>>0)&1;return g|0}else{g=0;return g|0}return 0}function cNu(b){b=b|0;return a[(c[3541128]|0)+((c[2113148]|0)+(b&1048575)^1)|0]|0}function cNv(a,d){a=a|0;d=d|0;var e=0,f=0,g=0;L59403:do{if((a&16777200|0)==3145696){switch(a|0){case 3145706:{b[4876464]=0;return};case 3145698:case 3145700:{b[4876468]=b[4876468]|d;e=50079;break L59403;break};case 3145696:{b[4876468]=0;return};case 3145712:{break L59403;break};default:{return}}}else{e=50079}}while(0);do{if((e|0)==50079){if((a|0)==3145712){break}return}}while(0);a=(d&65535)<<20&7340032;d=a+1048576|0;if((d|0)==(c[2113148]|0)){return}c[2113148]=d;d=c[3541128]|0;e=a-1048576|0;a=(c[2112932]|0)+8192|0;f=2097152;while(1){g=d+(e+f)|0;c[a>>2]=g;c[a+131072>>2]=g;g=f+1024|0;if(g>>>0>3144703){break}else{a=a+4|0;f=g}}return}function cNw(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if((a|0)!=3145712){return}a=(b&255)<<20&7340032;b=a+1048576|0;if((b|0)==(c[2113148]|0)){return}c[2113148]=b;b=c[3541128]|0;d=a-1048576|0;a=(c[2112932]|0)+8192|0;e=2097152;while(1){f=b+(d+e)|0;c[a>>2]=f;c[a+131072>>2]=f;f=e+1024|0;if(f>>>0>3144703){break}else{a=a+4|0;e=f}}return}function cNx(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;b=0;while(1){if((b|0)>=1024){e=50122;break}f=9638528+(b<<2)|0;if((c[f>>2]|0)==0){break}else{b=b+1|0}}if((e|0)==50122){return}b=gGq(2097152)|0;c[f>>2]=b;if((b|0)==0){return}gGz(b|0,0,2097152);f=c[3541128]|0;gGC(b|0,f|0,2097152)|0;g=2048;do{h=(g|0)>786431;if((g-524288|0)>>>0<262144){i=0;do{j=i+g|0;k=j+256|0;l=0;do{m=(l<<1)+j|0;n=c[607512+(l<<2)>>2]|0;o=b+(n+k)|0;p=f+m|0;C=(d[o]|d[o+1|0]<<8)<<16>>16;a[p]=C&255;C=C>>8;a[p+1|0]=C&255;p=b+(n+j)|0;n=f+(m+256)|0;C=(d[p]|d[p+1|0]<<8)<<16>>16;a[n]=C&255;C=C>>8;a[n+1|0]=C&255;l=l+1|0;}while((l|0)<8);l=b+j|0;n=f+j|0;C=(d[l]|d[l+1|0]<<8)<<16>>16;a[n]=C&255;C=C>>8;a[n+1|0]=C&255;p=b+k|0;m=f+k|0;C=(d[p]|d[p+1|0]<<8)<<16>>16;a[m]=C&255;C=C>>8;a[m+1|0]=C&255;o=j|4;q=b+o|0;r=f+o|0;C=(d[q]|d[q+1|0]<<8)<<16>>16;a[r]=C&255;C=C>>8;a[r+1|0]=C&255;s=j+260|0;t=b+s|0;u=f+s|0;C=(d[t]|d[t+1|0]<<8)<<16>>16;a[u]=C&255;C=C>>8;a[u+1|0]=C&255;u=j|10;t=b+u|0;s=f+u|0;C=(d[t]|d[t+1|0]<<8)<<16>>16;a[s]=C&255;C=C>>8;a[s+1|0]=C&255;v=j+266|0;w=b+v|0;x=f+v|0;C=(d[w]|d[w+1|0]<<8)<<16>>16;a[x]=C&255;C=C>>8;a[x+1|0]=C&255;x=j|14;w=b+x|0;v=f+x|0;C=(d[w]|d[w+1|0]<<8)<<16>>16;a[v]=C&255;C=C>>8;a[v+1|0]=C&255;y=j+270|0;z=b+y|0;A=f+y|0;C=(d[z]|d[z+1|0]<<8)<<16>>16;a[A]=C&255;C=C>>8;a[A+1|0]=C&255;if(h){C=(d[p]|d[p+1|0]<<8)<<16>>16;a[n]=C&255;C=C>>8;a[n+1|0]=C&255;C=(d[l]|d[l+1|0]<<8)<<16>>16;a[m]=C&255;C=C>>8;a[m+1|0]=C&255;m=o+256|0;o=b+m|0;C=(d[o]|d[o+1|0]<<8)<<16>>16;a[r]=C&255;C=C>>8;a[r+1|0]=C&255;r=f+m|0;C=(d[q]|d[q+1|0]<<8)<<16>>16;a[r]=C&255;C=C>>8;a[r+1|0]=C&255;r=u+256|0;u=b+r|0;C=(d[u]|d[u+1|0]<<8)<<16>>16;a[s]=C&255;C=C>>8;a[s+1|0]=C&255;s=f+r|0;C=(d[t]|d[t+1|0]<<8)<<16>>16;a[s]=C&255;C=C>>8;a[s+1|0]=C&255;s=x+256|0;x=b+s|0;C=(d[x]|d[x+1|0]<<8)<<16>>16;a[v]=C&255;C=C>>8;a[v+1|0]=C&255;v=f+s|0;C=(d[w]|d[w+1|0]<<8)<<16>>16;a[v]=C&255;C=C>>8;a[v+1|0]=C&255}i=i+16|0;}while((i|0)<256)}else{i=0;do{v=i+g|0;w=v+256|0;s=0;do{x=(s<<1)+v|0;t=c[607512+(s<<2)>>2]|0;r=b+(t+w)|0;u=f+x|0;C=(d[r]|d[r+1|0]<<8)<<16>>16;a[u]=C&255;C=C>>8;a[u+1|0]=C&255;u=b+(t+v)|0;t=f+(x+256)|0;C=(d[u]|d[u+1|0]<<8)<<16>>16;a[t]=C&255;C=C>>8;a[t+1|0]=C&255;s=s+1|0;}while((s|0)<8);if(h){s=b+w|0;j=f+v|0;C=(d[s]|d[s+1|0]<<8)<<16>>16;a[j]=C&255;C=C>>8;a[j+1|0]=C&255;j=b+v|0;s=f+w|0;C=(d[j]|d[j+1|0]<<8)<<16>>16;a[s]=C&255;C=C>>8;a[s+1|0]=C&255;s=v|4;j=s+256|0;k=b+j|0;t=f+s|0;C=(d[k]|d[k+1|0]<<8)<<16>>16;a[t]=C&255;C=C>>8;a[t+1|0]=C&255;t=b+s|0;s=f+j|0;C=(d[t]|d[t+1|0]<<8)<<16>>16;a[s]=C&255;C=C>>8;a[s+1|0]=C&255;s=v|10;t=s+256|0;j=b+t|0;k=f+s|0;C=(d[j]|d[j+1|0]<<8)<<16>>16;a[k]=C&255;C=C>>8;a[k+1|0]=C&255;k=b+s|0;s=f+t|0;C=(d[k]|d[k+1|0]<<8)<<16>>16;a[s]=C&255;C=C>>8;a[s+1|0]=C&255;s=v|14;k=s+256|0;t=b+k|0;j=f+s|0;C=(d[t]|d[t+1|0]<<8)<<16>>16;a[j]=C&255;C=C>>8;a[j+1|0]=C&255;j=b+s|0;s=f+k|0;C=(d[j]|d[j+1|0]<<8)<<16>>16;a[s]=C&255;C=C>>8;a[s+1|0]=C&255}i=i+16|0;}while((i|0)<256)}i=b+g|0;h=f+g|0;C=(d[i]|d[i+1|0]<<8)<<16>>16;a[h]=C&255;C=C>>8;a[h+1|0]=C&255;h=b+(g+1048576)|0;i=f+(g|2)|0;C=(d[h]|d[h+1|0]<<8)<<16>>16;a[i]=C&255;C=C>>8;a[i+1|0]=C&255;i=g|256;h=b+i|0;s=f+i|0;C=(d[h]|d[h+1|0]<<8)<<16>>16;a[s]=C&255;C=C>>8;a[s+1|0]=C&255;s=b+(g+1048832)|0;h=f+(g|258)|0;C=(d[s]|d[s+1|0]<<8)<<16>>16;a[h]=C&255;C=C>>8;a[h+1|0]=C&255;g=g+512|0;}while((g|0)<1048576);g=f+1048576|0;h=f+2097152|0;gGC(g|0,h|0,4194304)|0;h=0;while(1){if((h|0)>=1024){e=50120;break}B=9638528+(h<<2)|0;if((c[B>>2]|0)==(b|0)){break}else{h=h+1|0}}if((e|0)==50120){return}gGr(b);c[B>>2]=0;return}function cNy(){var a=0,d=0,e=0,f=0;a=c[2112932]|0;d=a+8192|0;e=2097152;while(1){c[d+65536>>2]=6;f=e+1024|0;if(f>>>0>3144703){break}else{d=d+4|0;e=f}}c[a+196752>>2]=1784;c[a+196672>>2]=2928;b[4865652]=0;return}function cNz(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=0;while(1){if((d|0)>=1024){break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==0){g=50130;break}else{d=d+1|0}}L59478:do{if((g|0)==50130){d=gGq(1048576)|0;c[f>>2]=d;if((d|0)==0){break}gGz(d|0,0,1048576);h=c[3541128]|0;i=h+393216|0;gGC(d|0,i|0,131072)|0;i=d+131072|0;j=h+1048576|0;gGC(i|0,j|0,131072)|0;j=d+262144|0;i=h+917504|0;gGC(j|0,i|0,131072)|0;i=d+393216|0;j=h+1572864|0;gGC(i|0,j|0,131072)|0;j=d+524288|0;i=h+131072|0;gGC(j|0,i|0,131072)|0;i=d+655360|0;j=h+1310720|0;gGC(i|0,j|0,131072)|0;j=d+786432|0;i=h+786432|0;gGC(j|0,i|0,131072)|0;i=d+917504|0;j=h+1703936|0;gGC(i|0,j|0,131072)|0;j=d+589824|0;i=h+262144|0;gGC(j|0,i|0,16384)|0;gGC(h|0,d|0,1048576)|0;h=0;while(1){if((h|0)>=1024){break L59478}k=9638528+(h<<2)|0;if((c[k>>2]|0)==(d|0)){break}else{h=h+1|0}}gGr(d);c[k>>2]=0}}while(0);k=c[3541128]|0;f=589824;while(1){g=b[k+f>>1]|0;do{if((g&-3393)<<16>>16==17081){h=k+(f+2)|0;if((b[h>>1]|0)!=0){l=g;break}b[h>>1]=9;l=b[k+f>>1]|0}else{l=g}}while(0);if(l<<16>>16==20152){b[k+f>>1]=24832;g=f+2|0;d=k+g|0;b[d>>1]=(e[d>>1]|0)+(f^65534)&65535;m=g}else{m=f+2|0}if((m|0)<606208){f=m}else{break}}m=k+1958|0;f=k+591782|0;a[m]=a[f]|0;a[m+1|0]=a[f+1|0]|0;a[m+2|0]=a[f+2|0]|0;a[m+3|0]=a[f+3|0]|0;a[m+4|0]=a[f+4|0]|0;a[m+5|0]=a[f+5|0]|0;f=k+1990|0;m=k+591814|0;a[f]=a[m]|0;a[f+1|0]=a[m+1|0]|0;a[f+2|0]=a[m+2|0]|0;a[f+3|0]=a[m+3|0]|0;a[f+4|0]=a[m+4|0]|0;a[f+5|0]=a[m+5|0]|0;m=k+2022|0;f=k+591846|0;a[m]=a[f]|0;a[m+1|0]=a[f+1|0]|0;a[m+2|0]=a[f+2|0]|0;a[m+3|0]=a[f+3|0]|0;a[m+4|0]=a[f+4|0]|0;a[m+5|0]=a[f+5|0]|0;f=k+1048576|0;m=k+2097152|0;gGC(f|0,m|0,4194304)|0;b[k+599212>>1]=9;b[k+599324>>1]=9;cMD();k=c[14164128+(c[2113146]<<2)>>2]|0;m=0;do{f=0;do{l=f+m|0;g=k+(l+64)|0;d=a[g]|0;h=k+l|0;a[g]=a[h]|0;a[h]=d;f=f+1|0;}while((f|0)<64);m=m+128|0;}while((m|0)<41943040);return}function cNA(){var a=0;a=c[2112932]|0;c[a+4092>>2]=6;c[a+196712>>2]=1722;return}function cNB(){var a=0,b=0,d=0,e=0,f=0,g=0;a=i;i=i+120|0;b=a|0;d=a+112|0;e=c[3541128]|0;if((c[3542200]|0)==0){i=a;return}f=b+108|0;c[f>>2]=0;g=b+100|0;c[g>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](b,15)|0;if((c[f>>2]|0)==0){i=a;return}f=c[g>>2]|0;c[d>>2]=9534384;gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](d,15,0)|0;if((f|0)<1){i=a;return}gzL(e,0,15)|0;i=a;return}function cNC(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;a=i;i=i+240|0;b=a|0;d=a+112|0;e=a+120|0;f=a+232|0;g=c[3541128]|0;do{if((c[3542200]|0)!=0){h=e+108|0;c[h>>2]=0;j=e+100|0;c[j>>2]=0;k=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[k&16383](e,15)|0;if((c[h>>2]|0)==0){break}h=c[j>>2]|0;c[f>>2]=9534384;j=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[j&16383](f,15,0)|0;if((h|0)<1){break}gzL(g,0,15)|0}}while(0);g=(c[3541128]|0)+524288|0;if((c[3542200]|0)==0){i=a;return}f=b+108|0;c[f>>2]=0;e=b+100|0;c[e>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](b,16)|0;if((c[f>>2]|0)==0){i=a;return}f=c[e>>2]|0;c[d>>2]=9534384;gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](d,16,0)|0;if((f|0)<1){i=a;return}gzL(g,0,16)|0;i=a;return}function cND(){var a=0,b=0,d=0,e=0,f=0,g=0;a=i;i=i+120|0;b=a|0;d=a+112|0;e=c[3541128]|0;if((c[3542200]|0)==0){i=a;return}f=b+108|0;c[f>>2]=0;g=b+100|0;c[g>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](b,13)|0;if((c[f>>2]|0)==0){i=a;return}f=c[g>>2]|0;c[d>>2]=9534384;gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](d,13,0)|0;if((f|0)<1){i=a;return}gzL(e,0,13)|0;i=a;return}function cNE(){var a=0,b=0,d=0,e=0,f=0,g=0;a=i;i=i+120|0;b=a|0;d=a+112|0;e=c[3541128]|0;if((c[3542200]|0)==0){i=a;return}f=b+108|0;c[f>>2]=0;g=b+100|0;c[g>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](b,14)|0;if((c[f>>2]|0)==0){i=a;return}f=c[g>>2]|0;c[d>>2]=9534384;gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](d,14,0)|0;if((f|0)<1){i=a;return}gzL(e,0,14)|0;i=a;return}function cNF(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0;a=c[2112932]|0;b=a+8192|0;d=b;e=2097152;while(1){c[d+65536>>2]=6;f=e+1024|0;if(f>>>0>3145727){g=b;h=2097152;break}else{d=d+4|0;e=f}}while(1){c[g>>2]=6;e=h+1024|0;if(e>>>0>3145727){break}else{g=g+4|0;h=e}}c[a+196752>>2]=2148;c[a+196672>>2]=1310;c[a+196712>>2]=1106;c[a+196632>>2]=2768;return}function cNG(){R6(c[3541128]|0,0,2)|0;R6((c[3541128]|0)+1|0,1,2)|0;return}function cNH(){R6(c[3541128]|0,0,2)|0;R6((c[3541128]|0)+1|0,1,2)|0;return}function cNI(){R6(c[3541128]|0,0,2)|0;R6((c[3541128]|0)+1|0,1,2)|0;return}function cNJ(){var d=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;d=i;i=i+128|0;f=d|0;g=c[2112968]|0;h=c[3541046]|0;j=c[2113300]<<3;k=c[2113308]|0;l=k<<3;m=c[3541066]|0;do{if((c[2394752]|0)!=(k|0)){c[2394752]=k;if((k|0)==2){c[3528972]=7602;break}else if((k|0)==4){c[3528972]=12942;break}else if((k|0)==3){c[3528972]=5356;break}else{i=d;return}}}while(0);k=(a[9534320]&1)==0;do{if(k){n=c[9776504+(c[2113146]<<2)>>2]|0;if((n|0)==0){break}o=c[2430884]|0;if((o|0)==0){i=d;return}if((n|0)==1){p=12288;q=0;r=0}else{n=c[2427052]|0;s=g;t=m+57348|0;u=3;v=m+59906|0;w=c[2415172]|0;while(1){x=a[673552]&1;c[2415154]=s;if((x|0)<(w|0)){y=x;x=s;z=w;while(1){A=e[t+(y<<5<<1)>>1]|0;B=((e[v+(c[9719456+(y<<2)>>2]<<1)>>1]|0)>>>((c[9731440+(y<<2)>>2]|0)>>>0)<<12&12288|A&4095)^12288;if((a[n+B|0]|0)==0){c[2385342]=o+(B<<5);c[2440390]=h+((A>>>8&240)<<2);gu[c[3528972]&16383]();C=c[2415154]|0;D=c[2415172]|0}else{C=x;D=z}A=y+1|0;B=C+l|0;c[2415154]=B;if((A|0)<(D|0)){y=A;x=B;z=D}else{E=D;break}}}else{E=w}if((u|0)>=30){break}s=s+j|0;t=t+2|0;u=u+1|0;v=v+2|0;w=E}i=d;return}while(1){do{if((b[m+(q+59904)>>1]|0)==512){w=e[m+(q+60160)>>1]|0;if((w&65280|0)!=65280){F=r;G=p;break}v=w<<12&12288^12288;c[f+(r<<2)>>2]=v;F=r+1|0;G=v}else{F=r;G=p}}while(0);v=F+1|0;c[f+(F<<2)>>2]=G;if((v|0)<32){p=G;q=q+4|0;r=v}else{break}}v=g;w=m+57348|0;u=2;t=c[2415172]|0;s=o;while(1){n=c[f+(u-2<<2)>>2]|0;z=c[2427052]|0;x=a[673552]&1;c[2415154]=v;if((x|0)<(t|0)){y=x;x=v;B=t;while(1){A=e[w+(y<<5<<1)>>1]|0;H=(A&4095)+n|0;if((a[z+H|0]|0)==0){c[2385342]=s+(H<<5);c[2440390]=h+((A>>>8&240)<<2);gu[c[3528972]&16383]();I=c[2415154]|0;J=c[2415172]|0}else{I=x;J=B}A=y+1|0;H=I+l|0;c[2415154]=H;if((A|0)<(J|0)){y=A;x=H;B=J}else{K=J;break}}}else{K=t}B=u+1|0;if((B|0)>=30){break}v=v+j|0;w=w+2|0;u=B;t=K;s=c[2430884]|0}i=d;return}}while(0);K=k?c[2430884]|0:c[3541018]|0;J=k?c[2427052]|0:c[2429310]|0;if((K|0)==0){i=d;return}k=g;g=m+57348|0;m=3;I=c[2415172]|0;while(1){f=a[673552]&1;c[2415154]=k;if((f|0)<(I|0)){r=f;f=k;q=I;while(1){G=e[g+(r<<5<<1)>>1]|0;p=G&4095;if((a[J+p|0]|0)==0){c[2385342]=K+(p<<5);c[2440390]=h+((G>>>8&240)<<2);gu[c[3528972]&16383]();L=c[2415154]|0;M=c[2415172]|0}else{L=f;M=q}G=r+1|0;p=L+l|0;c[2415154]=p;if((G|0)<(M|0)){r=G;f=p;q=M}else{N=M;break}}}else{N=I}if((m|0)>=30){break}k=k+j|0;g=g+2|0;m=m+1|0;I=N}i=d;return}function cNK(){var a=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[2113132]<<1;e=c[2440390]|0;f=c[2415154]|0;g=1;h=c[2385342]|0;while(1){i=d[h]|0;j=i>>>4;if((j|0)!=0){b[f>>1]=c[e+(j<<2)>>2]&65535}j=i&15;if((j|0)!=0){b[f+2>>1]=c[e+(j<<2)>>2]&65535}j=d[h+1|0]|0;i=j>>>4;if((i|0)!=0){b[f+4>>1]=c[e+(i<<2)>>2]&65535}i=j&15;if((i|0)!=0){b[f+6>>1]=c[e+(i<<2)>>2]&65535}i=d[h+2|0]|0;j=i>>>4;if((j|0)!=0){b[f+8>>1]=c[e+(j<<2)>>2]&65535}j=i&15;if((j|0)!=0){b[f+10>>1]=c[e+(j<<2)>>2]&65535}k=h+4|0;j=d[h+3|0]|0;i=j>>>4;if((i|0)!=0){b[f+12>>1]=c[e+(i<<2)>>2]&65535}i=j&15;if((i|0)!=0){b[f+14>>1]=c[e+(i<<2)>>2]&65535}if((g|0)>=8){break}f=f+a|0;g=g+1|0;h=k}c[2385342]=k;return}function cNL(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=(c[2113132]|0)*3|0;e=c[2440390]|0;f=1;g=c[2415154]|0;h=c[2385342]|0;while(1){i=d[h]|0;j=i>>>4;if((j|0)!=0){k=c[e+(j<<2)>>2]|0;a[g]=k&255;a[g+1|0]=k>>>8&255;a[g+2|0]=k>>>16&255}k=i&15;if((k|0)!=0){i=c[e+(k<<2)>>2]|0;a[g+3|0]=i&255;a[g+4|0]=i>>>8&255;a[g+5|0]=i>>>16&255}i=d[h+1|0]|0;k=i>>>4;if((k|0)!=0){j=c[e+(k<<2)>>2]|0;a[g+6|0]=j&255;a[g+7|0]=j>>>8&255;a[g+8|0]=j>>>16&255}j=i&15;if((j|0)!=0){i=c[e+(j<<2)>>2]|0;a[g+9|0]=i&255;a[g+10|0]=i>>>8&255;a[g+11|0]=i>>>16&255}i=d[h+2|0]|0;j=i>>>4;if((j|0)!=0){k=c[e+(j<<2)>>2]|0;a[g+12|0]=k&255;a[g+13|0]=k>>>8&255;a[g+14|0]=k>>>16&255}k=i&15;if((k|0)!=0){i=c[e+(k<<2)>>2]|0;a[g+15|0]=i&255;a[g+16|0]=i>>>8&255;a[g+17|0]=i>>>16&255}l=h+4|0;i=d[h+3|0]|0;k=i>>>4;if((k|0)!=0){j=c[e+(k<<2)>>2]|0;a[g+18|0]=j&255;a[g+19|0]=j>>>8&255;a[g+20|0]=j>>>16&255}j=i&15;if((j|0)!=0){i=c[e+(j<<2)>>2]|0;a[g+21|0]=i&255;a[g+22|0]=i>>>8&255;a[g+23|0]=i>>>16&255}if((f|0)>=8){break}f=f+1|0;g=g+b|0;h=l}c[2385342]=l;return}function cNM(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0;a=c[2113132]<<2;b=c[2440390]|0;e=c[2415154]|0;f=1;g=c[2385342]|0;while(1){h=d[g]|0;i=h>>>4;if((i|0)!=0){c[e>>2]=c[b+(i<<2)>>2]}i=h&15;if((i|0)!=0){c[e+4>>2]=c[b+(i<<2)>>2]}i=d[g+1|0]|0;h=i>>>4;if((h|0)!=0){c[e+8>>2]=c[b+(h<<2)>>2]}h=i&15;if((h|0)!=0){c[e+12>>2]=c[b+(h<<2)>>2]}h=d[g+2|0]|0;i=h>>>4;if((i|0)!=0){c[e+16>>2]=c[b+(i<<2)>>2]}i=h&15;if((i|0)!=0){c[e+20>>2]=c[b+(i<<2)>>2]}j=g+4|0;i=d[g+3|0]|0;h=i>>>4;if((h|0)!=0){c[e+24>>2]=c[b+(h<<2)>>2]}h=i&15;if((h|0)!=0){c[e+28>>2]=c[b+(h<<2)>>2]}if((f|0)>=8){break}e=e+a|0;f=f+1|0;g=j}c[2385342]=j;return}function cNN(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((b|0)<0){d=0;while(1){if((d|0)>=1024){e=0;break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==0){g=50301;break}else{d=d+1|0}}do{if((g|0)==50301){d=gGq(4096)|0;c[f>>2]=d;if((d|0)==0){e=0;break}gGz(d|0,0,4096);e=d}}while(0);c[2429310]=e;a[e]=1;f=1;do{a[e+f|0]=1;f=f+1|0;}while((f|0)<4096);f=c[3541018]|0;d=0;do{h=d>>3;i=f+(h<<3)|0;do{if((c[i>>2]|0)==0&(c[i+4>>2]|0)==0){j=f+((h|1)<<3)|0;if(!((c[j>>2]|0)==0&(c[j+4>>2]|0)==0)){k=0;break}j=f+((h|2)<<3)|0;if(!((c[j>>2]|0)==0&(c[j+4>>2]|0)==0)){k=0;break}j=f+((h|3)<<3)|0;k=(c[j>>2]|0)==0&(c[j+4>>2]|0)==0&1}else{k=0}}while(0);a[e+(d>>5)|0]=k;d=d+32|0;}while((d|0)<131072);return}d=8452488+(b<<2)|0;k=c[d>>2]>>5;e=(k|0)<4096?4096:k;k=0;while(1){if((k|0)>=1024){l=0;break}m=9638528+(k<<2)|0;if((c[m>>2]|0)==0){g=50314;break}else{k=k+1|0}}do{if((g|0)==50314){k=gGq(e)|0;c[m>>2]=k;if((k|0)==0){l=0;break}gGz(k|0,0,e|0);l=k}}while(0);c[9723504+(b<<2)>>2]=l;m=(c[2113132]|0)==304;k=m?39:40;a[673552]=m;c[2415172]=k;f=c[14164080+(b<<2)>>2]|0;c[2430884]=f;c[2427052]=l;do{if((e|0)>0){a[l]=1;if((e|0)>1){n=1}else{break}do{a[l+n|0]=1;n=n+1|0;}while((n|0)<(e|0))}}while(0);e=c[d>>2]|0;if((e|0)>0){o=0}else{c[9776504+(b<<2)>>2]=0;return}while(1){d=l+(o>>5)|0;a[d]=1;n=o+32|0;h=o;while(1){if((h|0)>=(n|0)){break}if((c[f+h>>2]|0)==0){h=h+4|0}else{g=50324;break}}if((g|0)==50324){g=0;a[d]=0}if((n|0)<(e|0)){o=n}else{break}}o=9776504+(b<<2)|0;c[o>>2]=0;if((e|0)<=262144){return}if((c[(c[642608+(c[2436]<<2)>>2]|0)+60>>2]&32|0)==0){c[o>>2]=1;return}c[o>>2]=2;o=m&1;do{c[9719456+(o<<2)>>2]=((o|0)/6|0)<<5;c[9731440+(o<<2)>>2]=5-((o|0)%6|0)<<1;o=o+1|0;}while((o|0)<(k|0));return}function cNO(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;f=i;i=i+232|0;g=f|0;h=f+112|0;j=f+120|0;if((d|0)<=0){i=f;return}k=j+100|0;l=g+108|0;m=g+100|0;n=e;e=0;L59769:while(1){c[k>>2]=0;o=e+b|0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,o)|0;p=c[642608+(c[2436]<<2)>>2]|0;q=(e|0)==0;do{if((c[p+60>>2]&512|0)!=0&q){if((R6(n,o,2)|0)!=0){r=50357;break L59769}if((R6(n+1|0,o+1|0,2)|0)!=0){r=50354;break L59769}if((c[k>>2]&2147483647|0)==0){s=1;t=0;break}else{u=0}while(1){v=u|1;w=n+v|0;x=a[w]|0;y=n+(v+1)|0;a[w]=a[y]|0;a[y]=x;x=u+4|0;y=c[k>>2]<<1;if(x>>>0<y>>>0){u=x}else{s=1;t=y;break}}}else{if((c[3542200]|0)==0){r=50360;break L59769}c[l>>2]=0;c[m>>2]=0;gA[c[p+76>>2]&16383](g,o)|0;if((c[l>>2]|0)!=0){y=c[m>>2]|0;c[h>>2]=9534384;x=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[x&16383](h,o,0)|0;if((y|0)<1){r=50355;break L59769}if((gzL(n,0,o)|0)!=0){r=50358;break L59769}}y=c[k>>2]|0;if(!((c[(c[642608+(c[2436]<<2)>>2]|0)+60>>2]&1|0)!=0&q)){s=e;t=y;break}x=y>>>1;if((x|0)==0){s=0;t=y;break}else{z=0;A=x}while(1){x=n+z|0;y=a[x]|0;a[x]=a[n+(z+A)|0]|0;a[n+(((c[k>>2]|0)>>>1)+z)|0]=y;y=z+1|0;x=c[k>>2]|0;w=x>>>1;if(y>>>0<w>>>0){z=y;A=w}else{s=0;t=x;break}}}}while(0);q=s+1|0;if((q|0)>=(d|0)){r=50356;break}n=n+t|0;e=q}if((r|0)==50354){i=f;return}else if((r|0)==50355){i=f;return}else if((r|0)==50356){i=f;return}else if((r|0)==50357){i=f;return}else if((r|0)==50358){i=f;return}else if((r|0)==50360){i=f;return}}function cNP(a){a=a|0;var b=0,d=0,e=0;b=a;a=0;do{d=b+(a<<2)|0;e=c[d>>2]^-373022412;c[d>>2]=e<<28&268435456|e>>>9<<31|e>>>31<<2|e>>>22&1|e>>>13<<30&1073741824|e>>>19<<29&536870912|e>>>23<<27&134217728|e>>>15<<26&67108864|e>>>3<<25&33554432|e>>>5<<24&16777216|e>>>4<<23&8388608|e>>>12<<22&4194304|e>>>17<<21&2097152|e>>>30<<20&1048576|e>>>18<<19&524288|e>>>21<<18&262144|e>>>11<<17&131072|e>>>6<<16&65536|e>>>27<<15&32768|e>>>10<<14&16384|e>>>26<<13&8192|e>>>28<<12&4096|e>>>20<<11&2048|e>>>2<<10&1024|e>>>14<<9&512|e>>>29<<8&256|e>>>24<<7&128|e>>>8<<6&64|e>>>1<<5&32|e>>>16<<4&16|e>>>25<<3&8|e>>>7<<1&2;a=a+1|0;}while((a|0)<1048576);return}function cNQ(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=i;i=i+128|0;f=e|0;g=f;h=a+1048576|0;j=a;a=0;while(1){k=a<<7;l=0;do{m=l<<2;n=d[j+(m+67)|0]|0;o=d[j+(m+66)|0]|0;p=d[j+(m+65)|0]|0;q=d[j+(m+64)|0]|0;r=0;s=0;do{r=(n>>>(s>>>0)<<3&8|q>>>(s>>>0)&1|o>>>(s>>>0)<<2&4|p>>>(s>>>0)<<1&2)<<(s<<2)|r;s=s+1|0;}while((s|0)<8);s=l<<1;c[f+(s<<2)>>2]=r;p=d[j+(m|3)|0]|0;o=d[j+(m|2)|0]|0;q=d[j+(m|1)|0]|0;n=d[j+m|0]|0;t=0;u=0;do{t=(p>>>(u>>>0)<<3&8|n>>>(u>>>0)&1|o>>>(u>>>0)<<2&4|q>>>(u>>>0)<<1&2)<<(u<<2)|t;u=u+1|0;}while((u|0)<8);c[f+((s|1)<<2)>>2]=t;l=l+1|0;}while((l|0)<16);l=b+k|0;gGC(l|0,g|0,128)|0;l=j+128|0;if(l>>>0<h>>>0){j=l;a=a+1|0}else{break}}i=e;return}function cNR(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[(c[3541046]|0)+16380>>2]|0;if((b|0)==0){d=c[2112968]|0;gGz(d|0,0,ag((c[2113132]|0)*224|0,c[2113308]|0)|0);return}d=c[2113308]|0;if((d|0)==4){e=(c[2113132]|0)*224|0;if((e|0)<=7){return}f=(e|0)/8|0;e=0;g=c[2112968]|0;while(1){c[g>>2]=b;c[g+4>>2]=b;c[g+8>>2]=b;c[g+12>>2]=b;c[g+16>>2]=b;c[g+20>>2]=b;c[g+24>>2]=b;c[g+28>>2]=b;h=e+1|0;if((h|0)<(f|0)){e=h;g=g+32|0}else{break}}return}else if((d|0)==3){g=b&255;e=b>>>8&255;f=b>>>16&255;h=(c[2113132]|0)*224|0;if((h|0)<=0){return}i=c[2112968]|0;j=0;while(1){a[i]=g;a[i+1|0]=e;a[i+2|0]=f;k=j+1|0;if((k|0)<(h|0)){i=i+3|0;j=k}else{break}}return}else if((d|0)==2){d=b<<16|b;b=(c[2113132]|0)*224|0;if((b|0)<=15){return}j=(b|0)/16|0;b=c[2112968]|0;i=0;while(1){c[b>>2]=d;c[b+4>>2]=d;c[b+8>>2]=d;c[b+12>>2]=d;c[b+16>>2]=d;c[b+20>>2]=d;c[b+24>>2]=d;c[b+28>>2]=d;h=i+1|0;if((h|0)<(j|0)){b=b+32|0;i=h}else{break}}return}else{return}}function cNS(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;if((b|0)==0){e=1;return e|0}f=c[642608+(c[2436]<<2)>>2]|0;g=c[((d|0)==0?f|0:f+4|0)>>2]|0;if((g|0)==0){c[b>>2]=0;e=1;return e|0}if((a[g]|0)!=0){f=0;do{a[9538800+f|0]=a[g+(f+4)|0]|0;f=f+1|0;}while(f>>>0<(gGy(g|0)|0)>>>0)}c[b>>2]=9538800;e=0;return e|0}function cNT(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;if((b|0)==0){e=1;return e|0}f=c[642608+(c[2436]<<2)>>2]|0;g=c[((d|0)==0?f|0:f+4|0)>>2]|0;if((g|0)==0){c[b>>2]=0;e=1;return e|0}if((a[g]|0)!=0){f=0;do{a[9539064+f|0]=a[g+(f+3)|0]|0;f=f+1|0;}while(f>>>0<(gGy(g|0)|0)>>>0)}c[b>>2]=9539064;e=0;return e|0}function cNU(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;if((b|0)==0){e=1;return e|0}f=c[642608+(c[2436]<<2)>>2]|0;g=c[((d|0)==0?f|0:f+4|0)>>2]|0;if((g|0)==0){c[b>>2]=0;e=1;return e|0}if((a[g]|0)!=0){f=0;do{a[9538536+f|0]=a[g+(f+4)|0]|0;f=f+1|0;}while(f>>>0<(gGy(g|0)|0)>>>0)}c[b>>2]=9538536;e=0;return e|0}function cNV(){return cNW(0)|0}function cNW(e){e=e|0;var f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0.0,I=0.0,J=0,K=0.0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;f=i;i=i+232|0;g=f|0;j=f+112|0;k=f+120|0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,0)|0;l=k+100|0;k=c[l>>2]|0;c[2415060]=0;c[3528990]=0;m=k>>>0>1048576?k:1048576;c[3530144]=m;n=m+4100|0;o=n|0;c[2414768]=o;c[3528988]=o;o=(e|0)==2;p=n+(o?32768:8192)|0;c[3528992]=p;q=p+32768|0;c[2385778]=q;r=p+34816|0;c[2077642]=r;s=p+35840|0;c[2077638]=s;t=p+101376|0;c[2077639]=t;u=p+166912|0;v=u|0;c[2411826]=v;c[2077640]=v;v=p+525328|0;w=v|0;c[2414374]=w;x=w;w=0;while(1){if((w|0)>=1024){break}y=9638528+(w<<2)|0;if((c[y>>2]|0)==0){z=50428;break}else{w=w+1|0}}do{if((z|0)==50428){w=gGq(x)|0;c[y>>2]=w;if((w|0)==0){break}gGz(w|0,0,x|0);c[2415060]=w;gGz(w|0,0,x|0);c[3528990]=w;c[3530144]=w+m;A=w+n|0;c[2414768]=A;c[3528988]=A;c[3528992]=w+p;c[2385778]=w+q;c[2077642]=w+r;c[2077638]=w+s;c[2077639]=w+t;A=w+u|0;c[2411826]=A;c[2077640]=A;c[2414374]=w+v;gGz(w|0,-1|0,k|0);if((c[3542200]|0)==0){B=1;i=f;return B|0}A=g+108|0;c[A>>2]=0;C=g+100|0;c[C>>2]=0;D=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[D&16383](g,0)|0;do{if((c[A>>2]|0)!=0){D=c[C>>2]|0;c[j>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](j,0,0)|0;if((D|0)<1){B=1;i=f;return B|0}if((gzL(w,0,0)|0)==0){break}else{B=1}i=f;return B|0}}while(0);w=c[l>>2]|0;C=c[3528990]|0;if((w&512|0)==0){F=k}else{A=C+512|0;D=w-512|0;gGC(C|0,A|0,D)|0;F=k-512|0}do{if((d[C+8191|0]|0)<224){if((F|0)==0){z=50443;break}else{G=0}while(1){D=C+G|0;A=a[D]|0;a[D]=(A&255)>>>7|A<<7|(A&255)>>>1<<6&64|(A&255)>>>2<<5&32|(A&255)>>>3<<4&16|(A&255)>>>4<<3&8|(A&255)>>>5<<2&4|(A&255)>>>6<<1&2;A=G+1|0;if(A>>>0<F>>>0){G=A}else{z=50439;break}}}else{z=50439}}while(0);do{if((z|0)==50439){if((F|0)==393216){A=C+393216|0;D=C+262144|0;gGC(A|0,D|0,131072)|0;A=C+524288|0;gGC(A|0,D|0,262144)|0;A=C+786432|0;gGC(A|0,D|0,262144)|0;gGC(D|0,C|0,262144)|0;break}else if((F|0)==2621440){a[642600]=1;break}else{if(F>>>0<262145){z=50443;break}else{z=50444;break}}}}while(0);if((z|0)==50443){D=C+262144|0;gGC(D|0,C|0,262144)|0;z=50444}do{if((z|0)==50444){if(F>>>0>=524289){break}D=C+524288|0;gGC(D|0,C|0,524288)|0}}while(0);do{if(e>>>0<2){C=(e|0)==0;fv8();c[2388530]=9554128;D=c[2391608]|0;if((D|0)!=0){A=D;gGC(9661040,A|0,68)|0}c[2382]=0;A=c[3528990]|0;D=0;do{w=A+(D<<11)|0;c[9554144+(D<<2)>>2]=w;c[9562336+(D<<2)>>2]=w;D=D+1|0;}while(D>>>0<512);D=c[3528988]|0;c[2389528]=D;c[2390552]=D;c[2391576]=D;A=D+2048|0;c[2389529]=A;c[2390553]=A;c[2391577]=A;w=D+4096|0;c[2389530]=w;c[2390554]=w;c[2391578]=w;E=D+6144|0;c[2389531]=E;c[2390555]=E;c[2391579]=E;c[2389532]=D;c[2390556]=D;c[2391580]=D;c[2389533]=A;c[2390557]=A;c[2391581]=A;c[2389534]=w;c[2390558]=w;c[2391582]=w;c[2389535]=E;c[2390559]=E;c[2391583]=E;c[2389536]=D;c[2390560]=D;c[2391584]=D;c[2389537]=A;c[2390561]=A;c[2391585]=A;c[2389538]=w;c[2390562]=w;c[2391586]=w;c[2389539]=E;c[2390563]=E;c[2391587]=E;c[2389540]=D;c[2390564]=D;c[2391588]=D;c[2389541]=A;c[2390565]=A;c[2391589]=A;c[2389542]=w;c[2390566]=w;c[2391590]=w;c[2389543]=E;c[2390567]=E;c[2391591]=E;c[2388534]=3044;c[2388533]=496;c[2388532]=3184;E=c[2391608]|0;if((E|0)!=0){w=E;gGC(w|0,9661040,68)|0}c[2382]=-1;c[2385610]=772;if(C){a[2179320]=1;break}else{a[2179320]=0;break}}else{if(!o){break}fv8();c[2388530]=9554128;w=c[2391608]|0;if((w|0)!=0){E=w;gGC(9661040,E|0,68)|0}c[2382]=0;E=c[3528990]|0;w=0;do{A=E+(w<<11)|0;c[9554144+(w<<2)>>2]=A;c[9562336+(w<<2)>>2]=A;w=w+1|0;}while(w>>>0<512);w=c[3528988]|0;E=0;do{C=E+992|0;A=w+(E<<11)|0;c[9554144+(C<<2)>>2]=A;c[9558240+(C<<2)>>2]=A;c[9562336+(C<<2)>>2]=A;E=E+1|0;}while(E>>>0<16);c[2388534]=1898;c[2388533]=3168;c[2388532]=2078;E=c[2391608]|0;if((E|0)!=0){w=E;gGC(w|0,9661040,68)|0}c[2382]=-1;c[2385610]=5290;a[2179320]=1}}while(0);a[7072512]=1;w=c[3530144]|0;E=0;do{A=E>>>3<<5&224;C=E>>>6<<5&224;D=((((E<<5&224)*25|0)+128+(C*129|0)+(A*66|0)|0)>>>8)+16|0;c[w+(E<<2)>>2]=C<<3|E<<2&28|A<<8;c[w+(E+512<<2)>>2]=D<<8&63488|D<<3&2016|D>>>3&31;E=E+1|0;}while((E|0)<512);gGz(9681744,0,17024);H=3579545.0/(a[9680]|0?32.0e3:0.0);I=H*4096.0;E=0;do{E=E+1|0;c[9682356+((E&4095)<<2)>>2]=~~(I/+(E|0));}while((E|0)<4096);I=H*32.0;E=0;while(1){w=E+1|0;c[9682228+(E<<2)>>2]=~~(I/+(w|0));if((w|0)<32){E=w}else{J=0;K=341.328125;break}}while(1){b[9682164+(J<<1)>>1]=~~K;E=J+1|0;if((E|0)<31){J=E;K=K/1.1885022274370185}else{break}}b[4841113]=0;c[2424685]=0;h[1212343]=1.0;h[1212344]=1.0;c[2424690]=1;c[2424691]=2;E=a[9688]|0?2136:0;w=0;while(1){if((w|0)>=1024){L=0;break}M=9638528+(w<<2)|0;if((c[M>>2]|0)==0){z=50476;break}else{w=w+1|0}}do{if((z|0)==50476){w=gGq(E)|0;c[M>>2]=w;if((w|0)==0){L=0;break}gGz(w|0,0,E|0);L=w}}while(0);c[2438892]=L;h[1212343]=1.0;c[2424690]=1;h[1212344]=1.0;c[2424691]=2;E=c[642608+(c[2436]<<2)>>2]|0;w=c[E+128>>2]|0;if((c[E+52>>2]&4|0)==0){c[2113068]=w;D=c[E+132>>2]|0;c[2113070]=D;c[2443814]=w;c[2440436]=D;N=w;O=D}else{c[2113070]=w;D=c[E+132>>2]|0;c[2113068]=D;c[2440436]=w;c[2443814]=D;N=D;O=w}w=ag(N<<1,O)|0;D=gGq(w)|0;c[2112926]=D;if((D|0)!=0){gGz(D|0,0,w|0)}w=c[2414768]|0;gGz(w|0,0,(c[2411826]|0)-w|0);c[2388530]=9554128;w=c[2391608]|0;if((w|0)!=0){D=w;gGC(9661040,D|0,68)|0}c[2382]=0;D=c[2415273]|0;gGz(9661040,0,68);c[2415273]=D;a[9661063]=20;c[2415262]=511;D=c[2388539]|0;do{if((D|0)==0){w=c[2388532]|0;if((w|0)==0){P=0;Q=8191;R=9554128;break}E=gj[w&4095](8190)|0;P=E;Q=(d[9661071]|0)<<13|8191;R=c[2388530]|0}else{P=a[D+2046|0]|0;Q=8191;R=9554128}}while(0);a[9661044]=P;D=c[R+16+(Q>>>11<<2)>>2]|0;do{if((D|0)==0){E=c[R>>2]|0;if((E|0)==0){S=0;T=R;break}w=gj[E&4095](Q)|0;S=w;T=c[2388530]|0}else{S=a[D+2047|0]|0;T=R}}while(0);a[9661045]=S;a[9661075]=4;a[9661073]=0;c[2415270]=131072;c[2415275]=0;gGz(9661084,0,5);D=c[T+12304>>2]|0;if((D|0)!=0){w=D;gGC(w|0,9661040,68)|0}c[2382]=-1;b[4880360]=0;gGz(9553592,0,128);b[4770384]=0;c[2443674]=0;c[2385190]=0;c[3528180]=0;b[4813240]=0;b[4866976]=0;b[7056356]=0;gGz(9751176,0,1024);w=9717352;c[w>>2]=0;c[w+4>>2]=0;c[2429570]=0;c[2426990]=0;w=9731040;c[w>>2]=0;c[w+4>>2]=0;w=9774704;c[w>>2]=0;c[w+4>>2]=0;w=9719120;c[w>>2]=0;c[w+4>>2]=0;a[9626480]=1;a[9626481]=1;gGz(c[2077642]|0,0,1024);b[4887360]=0;b[4887356]=0;c[2427024]=0;c[2388394]=0;c[2432732]=0;c[2432730]=0;gGz(9760184,0,512);Tc(0,17);Tc(1,17);b[4887344]=0;b[4887340]=0;a[9751144]=0;b[4880088]=0;gGz(9681744,0,420);c[2429300]=0;gGz(9720024,0,5);a[9717576]=0;a[9717584]=0;c[2440234]=0;B=0;i=f;return B|0}}while(0);c[2415060]=0;B=1;i=f;return B|0}function cNX(){return cNW(1)|0}function cNY(){return cNW(2)|0}function cNZ(){var a=0,b=0,d=0,e=0,f=0;a=cNW(0)|0;if((a|0)!=0){return a|0}c[2388530]=9554128;b=c[2391608]|0;if((b|0)!=0){d=b;gGC(9661040,d|0,68)|0}c[2382]=0;d=c[3528992]|0;b=0;do{e=b+256|0;f=d+(b<<11)|0;c[9554144+(e<<2)>>2]=f;c[9558240+(e<<2)>>2]=f;c[9562336+(e<<2)>>2]=f;b=b+1|0;}while(b>>>0<16);b=c[2391608]|0;if((b|0)!=0){d=b;gGC(d|0,9661040,68)|0}c[2382]=-1;return a|0}function cN_(){var b=0,d=0,e=0,f=0,g=0;c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}b=c[2438892]|0;if((b|0)!=0){d=b;b=0;while(1){if((b|0)>=1024){break}e=9638528+(b<<2)|0;if((c[e>>2]|0)==(d|0)){f=50521;break}else{b=b+1|0}}if((f|0)==50521){gGr(d);c[e>>2]=0}c[2438892]=0}fv9();e=c[2415060]|0;d=0;while(1){if((d|0)>=1024){f=50528;break}g=9638528+(d<<2)|0;if((c[g>>2]|0)==(e|0)){break}else{d=d+1|0}}if((f|0)==50528){c[2415060]=0;a[642600]=0;return 0}gGr(e);c[g>>2]=0;c[2415060]=0;a[642600]=0;return 0}function cN$(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;if((a[14163800]|0)!=0){d=c[3530144]|0;e=0;do{f=e>>>3<<5&224;g=e>>>6<<5&224;h=((((e<<5&224)*25|0)+128+(g*129|0)+(f*66|0)|0)>>>8)+16|0;c[d+(e<<2)>>2]=g<<3|e<<2&28|f<<8;c[d+(e+512<<2)>>2]=h<<8&63488|h<<3&2016|h>>>3&31;e=e+1|0;}while((e|0)<512);a[14163800]=0}e=c[2113070]|0;if((e|0)<=0){i=c[3530144]|0;R8(i);return 0}d=c[2113068]|0;h=(c[2077640]|0)+19324|0;f=c[2112926]|0;g=0;while(1){if((d|0)>0){j=0;do{b[f+(j<<1)>>1]=b[h+(j<<1)>>1]|0;j=j+1|0;}while((j|0)<(d|0))}j=g+1|0;if((j|0)<(e|0)){h=h+1368|0;f=f+(d<<1)|0;g=j}else{break}}i=c[3530144]|0;R8(i);return 0}function cN0(){var e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;if((a[14163792]|0)!=0){e=c[2414768]|0;gGz(e|0,0,(c[2411826]|0)-e|0);c[2388530]=9554128;e=c[2391608]|0;if((e|0)!=0){f=e;gGC(9661040,f|0,68)|0}c[2382]=0;f=c[2415273]|0;gGz(9661040,0,68);c[2415273]=f;a[9661063]=20;c[2415262]=511;f=c[2388539]|0;do{if((f|0)==0){e=c[2388532]|0;if((e|0)==0){g=0;i=8191;j=9554128;break}k=gj[e&4095](8190)|0;g=k;i=d[9661071]<<13|8191;j=c[2388530]|0}else{g=a[f+2046|0]|0;i=8191;j=9554128}}while(0);a[9661044]=g;g=c[j+16+(i>>>11<<2)>>2]|0;do{if((g|0)==0){f=c[j>>2]|0;if((f|0)==0){l=0;m=j;break}k=gj[f&4095](i)|0;l=k;m=c[2388530]|0}else{l=a[g+2047|0]|0;m=j}}while(0);a[9661045]=l;a[9661075]=4;a[9661073]=0;c[2415270]=131072;c[2415275]=0;gGz(9661084,0,5);l=c[m+12304>>2]|0;if((l|0)!=0){m=l;gGC(m|0,9661040,68)|0}c[2382]=-1;b[4880360]=0;gGz(9553592,0,128);b[4770384]=0;c[2443674]=0;c[2385190]=0;c[3528180]=0;b[4813240]=0;b[4866976]=0;b[7056356]=0;gGz(9751176,0,1024);m=9717352;c[m>>2]=0;c[m+4>>2]=0;c[2429570]=0;c[2426990]=0;m=9731040;c[m>>2]=0;c[m+4>>2]=0;m=9774704;c[m>>2]=0;c[m+4>>2]=0;m=9719120;c[m>>2]=0;c[m+4>>2]=0;a[9626480]=1;a[9626481]=1;gGz(c[2077642]|0,0,1024);b[4887360]=0;b[4887356]=0;c[2427024]=0;c[2388394]=0;c[2432732]=0;c[2432730]=0;gGz(9760184,0,512);Tc(0,17);Tc(1,17);b[4887344]=0;b[4887340]=0;a[9751144]=0;b[4880088]=0;gGz(9681744,0,420);c[2429300]=0;gGz(9720024,0,5);a[9717576]=0;a[9717584]=0;c[2440234]=0}c[(c[2391608]|0)+60>>2]=0;c[(c[2391608]|0)+60>>2]=0;gGz(9543096,-1|0,10);m=0;l=-1;j=-1;g=-1;i=-1;k=-1;do{l=((a[14163872+m|0]&1)<<m^l&65535)&65535;j=((a[14163856+m|0]&1)<<m^j&65535)&65535;g=((a[14163840+m|0]&1)<<m^g&65535)&65535;i=((a[14163824+m|0]&1)<<m^i&65535)&65535;k=((a[14163808+m|0]&1)<<m^k&65535)&65535;m=m+1|0;}while((m|0)<12);b[4771548]=l;b[4771549]=j;b[4771550]=g;b[4771551]=i;b[4771552]=k;k=c[2438]|0;i=gGU(k,(k|0)<0|0?-1:0,7159090,0)|0;k=gGS(i,K,15360,0)|0;c[2388530]=9554128;i=c[2391608]|0;if((i|0)!=0){g=i;gGC(9661040,g|0,68)|0}c[2382]=0;g=(k|0)/262|0;k=0;do{fy_(g)|0;gu[c[2385610]&16383]();k=k+1|0;}while((k|0)<262);k=c[2112964]|0;do{if((k|0)!=0){g=a[9688]|0;i=g?534:0;TG();if((c[2424685]|0)==0){gGz(k|0,0,i<<2|0)}if(!g){break}g=c[2438892]|0;j=0;do{l=c[2424690]|0;if((l&1|0)==0){n=0}else{n=~~(+(b[g+(j<<1<<1)>>1]|0)*+h[1212343])}if((l&2|0)==0){o=0}else{o=~~(+(b[g+(j<<1<<1)>>1]|0)*+h[1212343])}l=c[2424691]|0;if((l&1|0)==0){p=n}else{p=~~(+(b[g+((j<<1|1)<<1)>>1]|0)*+h[1212344])+n|0}if((l&2|0)==0){q=o}else{q=~~(+(b[g+((j<<1|1)<<1)>>1]|0)*+h[1212344])+o|0}if((p|0)<-32768){r=-32768}else{r=(p|0)>32767?32767:p&65535}l=j<<1;b[k+(l<<1)>>1]=r;if((q|0)<-32768){s=-32768}else{s=(q|0)>32767?32767:q&65535}b[k+((l|1)<<1)>>1]=s;j=j+1|0;}while((j|0)<(i|0))}}while(0);s=c[(c[2388530]|0)+12304>>2]|0;if((s|0)!=0){k=s;gGC(k|0,9661040,68)|0}c[2382]=-1;if((c[2112968]|0)==0){return 0}if((a[14163800]|0)!=0){k=c[3530144]|0;s=0;do{q=s>>>3<<5&224;r=s>>>6<<5&224;p=((((s<<5&224)*25|0)+128+(r*129|0)+(q*66|0)|0)>>>8)+16|0;c[k+(s<<2)>>2]=r<<3|s<<2&28|q<<8;c[k+(s+512<<2)>>2]=p<<8&63488|p<<3&2016|p>>>3&31;s=s+1|0;}while((s|0)<512);a[14163800]=0}s=c[2113070]|0;if((s|0)>0){k=c[2113068]|0;p=(c[2077640]|0)+19324|0;q=c[2112926]|0;r=0;while(1){if((k|0)>0){o=0;do{b[q+(o<<1)>>1]=b[p+(o<<1)>>1]|0;o=o+1|0;}while((o|0)<(k|0))}o=r+1|0;if((o|0)<(s|0)){p=p+1368|0;q=q+(k<<1)|0;r=o}else{break}}}R8(c[3530144]|0);return 0}function cN1(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0;e=i;i=i+752|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;l=e+80|0;m=e+96|0;n=e+112|0;o=e+128|0;p=e+144|0;q=e+160|0;r=e+176|0;s=e+192|0;t=e+208|0;u=e+224|0;v=e+240|0;w=e+256|0;x=e+272|0;y=e+288|0;z=e+304|0;A=e+320|0;B=e+336|0;C=e+352|0;D=e+368|0;E=e+384|0;F=e+400|0;G=e+416|0;H=e+432|0;I=e+448|0;J=e+592|0;K=e+608|0;L=e+624|0;M=e+640|0;N=e+656|0;O=e+672|0;P=e+688|0;Q=e+704|0;R=e+720|0;S=e+736|0;T=(d|0)==0;if(!T){c[d>>2]=169624}if((b&32|0)!=0){gGz(S|0,0,12);U=c[2414768]|0;c[S>>2]=U;c[S+4>>2]=(c[2411826]|0)-U;c[S+12>>2]=162152;U=c[2076592]|0;gj[U&4095](S)|0}if((b&64|0)==0){i=e;return 0}b=I;S=e+464|0;U=I|0;V=I+4|0;W=I+12|0;X=c[2391608]|0;if((X|0)!=0){Y=X+52|0;Z=c[Y>>2]|0;gGz(b|0,0,16);c[U>>2]=X;c[V>>2]=68;cC(S|0,165488,(_=i,i=i+8|0,c[_>>2]=0,_)|0)|0;i=_;c[W>>2]=S;X=c[2076592]|0;gj[X&4095](I)|0;c[Y>>2]=Z}Z=c[2394685]|0;if((Z|0)!=0){Y=Z+52|0;X=c[Y>>2]|0;gGz(b|0,0,16);c[U>>2]=Z;c[V>>2]=68;cC(S|0,165488,(_=i,i=i+8|0,c[_>>2]=1,_)|0)|0;i=_;c[W>>2]=S;S=c[2076592]|0;gj[S&4095](I)|0;c[Y>>2]=X}if(!T){c[d>>2]=169730}X=F;Y=F|0;I=F+4|0;S=F+12|0;W=E;_=E|0;V=E+4|0;Z=E+12|0;U=D;b=D|0;$=D+4|0;aa=D+12|0;ab=C;ac=C|0;ad=C+4|0;ae=C+12|0;af=B;ag=B|0;ah=B+4|0;ai=B+12|0;aj=A;ak=A|0;al=A+4|0;am=A+12|0;an=z;ao=z|0;ap=z+4|0;aq=z+12|0;ar=y;as=y|0;at=y+4|0;au=y+12|0;av=x;aw=x|0;ax=x+4|0;ay=x+12|0;az=w;aA=w|0;aB=w+4|0;aC=w+12|0;aD=v;aE=v|0;aF=v+4|0;aG=v+12|0;aH=u;aI=u|0;aJ=u+4|0;aK=u+12|0;aL=t;aM=t|0;aN=t+4|0;aO=t+12|0;aP=s;aQ=s|0;aR=s+4|0;aS=s+12|0;aT=r;aU=r|0;aV=r+4|0;aW=r+12|0;aX=q;aY=q|0;aZ=q+4|0;a_=q+12|0;a$=0;do{gGz(X|0,0,12);c[Y>>2]=9760720+a$;c[I>>2]=1;c[S>>2]=200736;gj[c[2076592]&4095](F)|0;gGz(W|0,0,12);c[_>>2]=9553592+(a$<<6);c[V>>2]=64;c[Z>>2]=511896;gj[c[2076592]&4095](E)|0;gGz(U|0,0,12);c[b>>2]=9540768+a$;c[$>>2]=1;c[aa>>2]=395944;gj[c[2076592]&4095](D)|0;gGz(ab|0,0,12);c[ac>>2]=9774696+(a$<<1);c[ad>>2]=2;c[ae>>2]=306928;gj[c[2076592]&4095](C)|0;gGz(af|0,0,12);c[ag>>2]=9540760+(a$<<1);c[ah>>2]=2;c[ai>>2]=233768;gj[c[2076592]&4095](B)|0;gGz(aj|0,0,12);c[ak>>2]=14112720+(a$<<1);c[al>>2]=2;c[am>>2]=182272;gj[c[2076592]&4095](A)|0;gGz(an|0,0,12);c[ao>>2]=9626480+a$;c[ap>>2]=1;c[aq>>2]=146920;gj[c[2076592]&4095](z)|0;gGz(ar|0,0,12);c[as>>2]=9733952+a$;c[at>>2]=1;c[au>>2]=117520;gj[c[2076592]&4095](y)|0;gGz(av|0,0,12);c[aw>>2]=14112712+a$;c[ax>>2]=1;c[ay>>2]=92448;gj[c[2076592]&4095](x)|0;gGz(az|0,0,12);c[aA>>2]=9751176+(a$<<9);c[aB>>2]=512;c[aC>>2]=72392;gj[c[2076592]&4095](w)|0;gGz(aD|0,0,12);c[aE>>2]=9717352+(a$<<2);c[aF>>2]=4;c[aG>>2]=580112;gj[c[2076592]&4095](v)|0;gGz(aH|0,0,12);c[aI>>2]=9718280+(a$<<1);c[aJ>>2]=2;c[aK>>2]=563168;gj[c[2076592]&4095](u)|0;gGz(aL|0,0,12);c[aM>>2]=9707960+(a$<<1);c[aN>>2]=2;c[aO>>2]=547056;gj[c[2076592]&4095](t)|0;gGz(aP|0,0,12);c[aQ>>2]=9731040+(a$<<2);c[aR>>2]=4;c[aS>>2]=533128;gj[c[2076592]&4095](s)|0;gGz(aT|0,0,12);c[aU>>2]=9774704+(a$<<2);c[aV>>2]=4;c[aW>>2]=519608;gj[c[2076592]&4095](r)|0;gGz(aX|0,0,12);c[aY>>2]=9719120+(a$<<2);c[aZ>>2]=4;c[a_>>2]=506072;gj[c[2076592]&4095](q)|0;a$=a$+1|0;}while((a$|0)<2);a$=G|0;c[a$>>2]=9751176;q=G+4|0;c[q>>2]=1024;a_=G+8|0;c[a_>>2]=0;aZ=G+12|0;c[aZ>>2]=494200;gj[c[2076592]&4095](G)|0;c[a$>>2]=9553592;c[q>>2]=128;c[a_>>2]=0;c[aZ>>2]=482104;gj[c[2076592]&4095](G)|0;gGz(p|0,0,12);c[p>>2]=9774720;c[p+4>>2]=2;c[p+12>>2]=469376;gj[c[2076592]&4095](p)|0;gGz(o|0,0,12);c[o>>2]=9774712;c[o+4>>2]=2;c[o+12>>2]=458080;gj[c[2076592]&4095](o)|0;gGz(n|0,0,12);c[n>>2]=9708096;c[n+4>>2]=4;c[n+12>>2]=447920;gj[c[2076592]&4095](n)|0;gGz(m|0,0,12);c[m>>2]=9774688;c[m+4>>2]=2;c[m+12>>2]=435896;gj[c[2076592]&4095](m)|0;gGz(l|0,0,12);c[l>>2]=9774680;c[l+4>>2]=2;c[l+12>>2]=425440;gj[c[2076592]&4095](l)|0;gGz(k|0,0,12);c[k>>2]=9751144;c[k+4>>2]=1;c[k+12>>2]=412712;gj[c[2076592]&4095](k)|0;gGz(j|0,0,12);c[j>>2]=9760176;c[j+4>>2]=2;c[j+12>>2]=402040;gj[c[2076592]&4095](j)|0;j=h;k=h|0;l=h+4|0;m=h+12|0;n=g;o=g|0;p=g+4|0;aY=g+12|0;aX=f;r=f|0;aW=f+4|0;aV=f+12|0;gGz(j|0,0,12);c[k>>2]=9553576;c[l>>2]=1;c[m>>2]=389976;gj[c[2076592]&4095](h)|0;gGz(n|0,0,12);c[o>>2]=9730928;c[p>>2]=1;c[aY>>2]=379736;gj[c[2076592]&4095](g)|0;gGz(aX|0,0,12);c[r>>2]=9730920;c[aW>>2]=1;c[aV>>2]=369200;gj[c[2076592]&4095](f)|0;gGz(j|0,0,12);c[k>>2]=9553577;c[l>>2]=1;c[m>>2]=389976;gj[c[2076592]&4095](h)|0;gGz(n|0,0,12);c[o>>2]=9730929;c[p>>2]=1;c[aY>>2]=379736;gj[c[2076592]&4095](g)|0;gGz(aX|0,0,12);c[r>>2]=9730921;c[aW>>2]=1;c[aV>>2]=369200;gj[c[2076592]&4095](f)|0;gGz(j|0,0,12);c[k>>2]=9553578;c[l>>2]=1;c[m>>2]=389976;gj[c[2076592]&4095](h)|0;gGz(n|0,0,12);c[o>>2]=9730930;c[p>>2]=1;c[aY>>2]=379736;gj[c[2076592]&4095](g)|0;gGz(aX|0,0,12);c[r>>2]=9730922;c[aW>>2]=1;c[aV>>2]=369200;gj[c[2076592]&4095](f)|0;gGz(j|0,0,12);c[k>>2]=9553579;c[l>>2]=1;c[m>>2]=389976;gj[c[2076592]&4095](h)|0;gGz(n|0,0,12);c[o>>2]=9730931;c[p>>2]=1;c[aY>>2]=379736;gj[c[2076592]&4095](g)|0;gGz(aX|0,0,12);c[r>>2]=9730923;c[aW>>2]=1;c[aV>>2]=369200;gj[c[2076592]&4095](f)|0;c[a$>>2]=9760184;c[q>>2]=512;c[a_>>2]=0;c[aZ>>2]=360712;gj[c[2076592]&4095](G)|0;if(!T){c[d>>2]=169730}c[H>>2]=9681744;c[H+4>>2]=17024;c[H+8>>2]=0;c[H+12>>2]=171040;gj[c[2076592]&4095](H)|0;gGz(R|0,0,12);c[R>>2]=9717576;c[R+4>>2]=1;c[R+12>>2]=550408;gj[c[2076592]&4095](R)|0;gGz(Q|0,0,12);c[Q>>2]=9717584;c[Q+4>>2]=1;c[Q+12>>2]=427616;gj[c[2076592]&4095](Q)|0;gGz(P|0,0,12);c[P>>2]=9720024;c[P+4>>2]=1;c[P+12>>2]=331688;gj[c[2076592]&4095](P)|0;gGz(O|0,0,12);c[O>>2]=9720025;c[O+4>>2]=1;c[O+12>>2]=253584;gj[c[2076592]&4095](O)|0;gGz(N|0,0,12);c[N>>2]=9720026;c[N+4>>2]=1;c[N+12>>2]=198296;gj[c[2076592]&4095](N)|0;gGz(M|0,0,12);c[M>>2]=9720027;c[M+4>>2]=1;c[M+12>>2]=157232;gj[c[2076592]&4095](M)|0;gGz(L|0,0,12);c[L>>2]=9720028;c[L+4>>2]=1;c[L+12>>2]=127080;gj[c[2076592]&4095](L)|0;gGz(K|0,0,12);c[K>>2]=7072512;c[K+4>>2]=1;c[K+12>>2]=102240;gj[c[2076592]&4095](K)|0;if(!(a[642600]|0)){i=e;return 0}gGz(J|0,0,12);c[J>>2]=9760936;c[J+4>>2]=4;c[J+12>>2]=78752;gj[c[2076592]&4095](J)|0;J=c[2440234]&255;c[2440234]=J;K=c[3528990]|0;L=(J<<19)+524288|0;J=c[2388530]|0;M=0;do{N=M+256|0;O=K+(L+(M<<11))|0;c[J+16+(N<<2)>>2]=O;c[J+8208+(N<<2)>>2]=O;M=M+1|0;}while(M>>>0<256);i=e;return 0}function cN2(a,b){a=a|0;b=b|0;if((a&255)>=4){return}Ti(0,a,b);return}function cN3(f,g){f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=f&2097151;if((f&2097136|0)==8176){if(!(a[642600]|0)){return}i=f&3;c[2440234]=i;j=c[3528990]|0;k=(i<<19)+524288|0;i=c[2388530]|0;l=0;do{m=l+256|0;n=j+(k+(l<<11))|0;c[i+16+(m<<2)>>2]=n;c[i+8208+(m<<2)>>2]=n;l=l+1|0;}while(l>>>0<256);return}switch(f&2096128|0){case 2089984:{switch(f&7|0){case 2:{b[4887360]=b[4887360]&256|g&255;return};case 3:{b[4887360]=b[4887360]&255|(g&255)<<8&256;return};case 4:{l=(c[2077642]|0)+(e[4887360]<<1)|0;b[l>>1]=b[l>>1]&256|g&255;return};case 5:{l=(c[2077642]|0)+(e[4887360]<<1)|0;b[l>>1]=b[l>>1]&255|(g&255)<<8&256;b[4887360]=(b[4887360]|0)+1&511;return};case 0:{b[4887356]=g&255;return};default:{return}}break};case 2088960:{Ti(0,f&255,g);return};case 2094080:{a[9661104]=g;l=f&3;if((l|0)==2){a[9661072]=g&7;if((a[9661088]|0)!=0){return}a[9661088]=2;return}else if((l|0)==3){if((a[9661087]|0)==0){return}a[9661087]=0;if((a[9661088]|0)!=0){return}a[9661088]=2;return}else{a[9661104]=g;return}break};case 2091008:{a[9661104]=g;l=g&255;i=d[9681744]|0;k=9681748+(i*52|0)|0;TG();switch(f&15|0){case 7:{a[9681788+(i*52|0)|0]=g;return};case 8:{a[9681746]=g;return};case 9:{a[9681747]=g;return};case 0:{a[9681744]=g&7;return};case 6:{j=a[9681750+(i*52|0)|0]&192;if((j|0)==192){b[9681786+(i*52|0)>>1]=g&31;return}else if((j|0)==0){n=9681784+(i*52|0)|0;a[(a[n]&31)+(9681752+(i*52|0))|0]=g&31;a[n]=(a[n]|0)+1&31;return}else if((j|0)==128){j=9681784+(i*52|0)|0;a[(a[j]&31)+(9681752+(i*52|0))|0]=g&31;a[j]=(a[j]|0)+1&31;return}else{return}break};case 1:{a[9681745]=g;return};case 2:{j=k|0;b[j>>1]=(b[j>>1]&3840|l)&65535;return};case 3:{j=k|0;b[j>>1]=(b[j>>1]&255|l<<8&3840)&65535;return};case 4:{j=9681750+(i*52|0)|0;do{if((a[j]&64)!=0){if((l&64|0)!=0){break}a[9681784+(i*52|0)|0]=0}}while(0);a[j]=g;return};case 5:{a[9681751+(i*52|0)|0]=g;return};default:{return}}break};case 2093056:{a[9661104]=g;i=a[14163889]|0;j=d[14163888]|0;l=g&1;do{if((a[9717584]|0)==0){if(l<<24>>24==0){o=0;break}a[9717576]=(a[9717576]|0)+1&7;o=l}else{o=l}}while(0);a[9717584]=o;if((g&2)==0){return}a[9717576]=0;if((j&3|0)==2){a[9720024]=a[9720024]^1}if((j&12|0)==8){a[9720025]=a[9720025]^1}if((j&48|0)==32){a[9720026]=a[9720026]^1}if((j&192|0)==128){a[9720027]=a[9720027]^1}if((i&3)!=2){return}a[9720028]=a[9720028]^1;return};case 2092032:{a[9661104]=g;i=f&1;if((i|0)==1){j=g&1;if((j|0)!=0&(a[9661073]|0)==0){c[2415269]=c[2415270]}a[9661073]=j&255;return}else if((i|0)==0){i=((g&255)<<10&130048)+1024|0;c[2415269]=i;c[2415270]=i;return}else{return}break};case 2095104:{if(!((f&15|0)==7&g<<24>>24<0)){return}a[7072512]=0;return};default:{if((h-2023424|0)>>>0>2047|(a[7072512]|0)!=0){return}a[(c[2385778]|0)+(f&2047)|0]=g;return}}}function cN4(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;switch(f&2096128|0){case 2094080:{g=f&3;if((g|0)==3){h=(a[9661086]|0)!=0|0;i=(a[9661085]|0)==0?h:h|2;j=(((a[9661087]|0)==0?i:i|4)|a[9661104]&248)&255;return j|0}else if((g|0)==2){j=a[9661104]&-8|a[9661072];return j|0}else{j=a[9661104]|0;return j|0}break};case 2095104:{if((f&15|0)!=3){j=0;return j|0}a[7072512]=1;j=0;return j|0};case 2088960:{g=f&3;if((g|0)==2){j=a[(c[2077638]|0)+(e[4776797]<<1&65534)|0]|0;return j|0}else if((g|0)==0){i=a[14112712]|0;a[14112712]=i&-64;if((a[9661085]|0)==0){j=i;return j|0}a[9661085]=0;if((a[9661088]|0)!=0){j=i;return j|0}a[9661088]=2;j=i;return j|0}else if((g|0)==3){g=b[4776797]|0;if((a[9760720]|0)==2){b[4776797]=(d[9626480]|0)+g&65535}j=a[(c[2077638]|0)+((g&65535)<<1&65534|1)|0]|0;return j|0}else{j=0;return j|0}break};case 2093056:{g=a[9717576]|0;i=g&255;do{if((g&255)<5){h=b[9543096+(i<<1)>>1]|0;if(((d[14163889]<<8|d[14163888])&3<<(i<<1)|0)==0){k=h&255}else{k=(h&4095)>>>(d[9720024+i|0]<<3>>>0)&65535}if((a[9717584]|0)==0){l=k;break}l=(k&65535)>>>4}else{l=255}}while(0);j=(l&15|(a[2179320]|0?64:0)|176)&255;return j|0};case 2091008:{j=a[9661104]|0;return j|0};case 2089984:{l=f&7;if((l|0)==4){j=b[(c[2077642]|0)+(e[4887360]<<1)>>1]&255;return j|0}else if((l|0)==5){l=b[4887360]|0;k=((e[(c[2077642]|0)+((l&65535)<<1)>>1]|0)>>>8|254)&255;b[4887360]=l+1&511;j=k;return j|0}else{j=-1;return j|0}break};case 2092032:{j=(a[9661104]&128|(c[2415269]|0)>>>10&127)&255;return j|0};default:{if(((f&2097151)-2023424|0)>>>0>=2048){j=0;return j|0}j=a[(c[2385778]|0)+(f&2047)|0]|0;return j|0}}return 0}function cN5(b,c){b=b|0;c=c|0;if((b&255)>=4){return}if((a[9751144]|0)==0){Ti(0,b,c);return}else{Ti(1,b,c);return}}function cN6(a,b){a=a|0;b=b|0;var c=0;c=a&2096152;if((c|0)==2088968){Tc(a&7,b);return}else if((c|0)==2088976){Ti(1,a&7,b);return}else if((c|0)==2088960){Ti(0,a&7,b);return}else{cN3(a&2097151,b);return}}function cN7(f){f=f|0;var g=0,h=0,i=0,j=0;g=f&2096152;if((g|0)==2088960){h=f&3;if((h|0)==0){i=a[14112712]|0;a[14112712]=i&-64;if((a[9661085]|0)==0){j=i;return j|0}a[9661085]=0;if((a[9661088]|0)!=0){j=i;return j|0}a[9661088]=2;j=i;return j|0}else if((h|0)==3){i=b[4776797]|0;if((a[9760720]|0)==2){b[4776797]=(d[9626480]|0)+i&65535}j=a[(c[2077638]|0)+((i&65535)<<1&65534|1)|0]|0;return j|0}else if((h|0)==2){j=a[(c[2077638]|0)+(e[4776797]<<1&65534)|0]|0;return j|0}else{j=0;return j|0}}else if((g|0)==2088968){switch(f&7|0){case 0:{j=b[4880088]&255;return j|0};case 2:{j=b[4887344]&255;return j|0};case 3:{j=(e[4887344]|0)>>>8&255;return j|0};case 1:{j=(e[4880088]|0)>>>8&255;return j|0};case 4:{j=b[4887340]&255;return j|0};case 5:{j=(e[4887340]|0)>>>8&255;return j|0};default:{j=0;return j|0}}}else if((g|0)==2088976){g=f&3;if((g|0)==0){h=a[14112713]|0;a[14112713]=h&-64;if((a[9661085]|0)==0){j=h;return j|0}a[9661085]=0;if((a[9661088]|0)!=0){j=h;return j|0}a[9661088]=2;j=h;return j|0}else if((g|0)==2){j=a[(c[2077639]|0)+(e[4776829]<<1&65534)|0]|0;return j|0}else if((g|0)==3){g=b[4776829]|0;if((a[9760721]|0)==2){b[4776829]=(d[9626481]|0)+g&65535}j=a[(c[2077639]|0)+((g&65535)<<1&65534|1)|0]|0;return j|0}else{j=0;return j|0}}else{j=cN4(f&2097151)|0;return j|0}return 0}function cN8(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?848696:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cN9(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?848696:0;e=0;return e|0}function cOa(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>63){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6506840+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function cOb(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7344672+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function cOc(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1033360:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cOd(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1033360:0;e=0;return e|0}function cOe(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?745280:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cOf(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?745280:0;e=0;return e|0}function cOg(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?745168:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cOh(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?745168:0;e=0;return e|0}function cOi(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?745392:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cOj(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?745392:0;e=0;return e|0}function cOk(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1033248:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cOl(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1033248:0;e=0;return e|0}function cOm(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1033136:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cOn(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1033136:0;e=0;return e|0}function cOo(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?745056:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cOp(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?745056:0;e=0;return e|0}function cOq(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?744944:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cOr(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?744944:0;e=0;return e|0}function cOs(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1033024:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cOt(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1033024:0;e=0;return e|0}function cOu(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?848584:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cOv(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?848584:0;e=0;return e|0}function cOw(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?744832:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cOx(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?744832:0;e=0;return e|0}function cOy(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?848472:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cOz(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?848472:0;e=0;return e|0}function cOA(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?744720:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cOB(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?744720:0;e=0;return e|0}function cOC(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?744608:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cOD(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?744608:0;e=0;return e|0}function cOE(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?848360:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cOF(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?848360:0;e=0;return e|0}function cOG(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1032800:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cOH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1032800:0;e=0;return e|0}function cOI(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?744496:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cOJ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?744496:0;e=0;return e|0}function cOK(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1032688:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cOL(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1032688:0;e=0;return e|0}function cOM(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?848248:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cON(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?848248:0;e=0;return e|0}function cOO(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?744384:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cOP(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?744384:0;e=0;return e|0}function cOQ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1032576:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cOR(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1032576:0;e=0;return e|0}function cOS(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?744160:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cOT(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?744160:0;e=0;return e|0}function cOU(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?744048:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cOV(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?744048:0;e=0;return e|0}function cOW(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?706240:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cOX(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?706240:0;e=0;return e|0}function cOY(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?743936:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cOZ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?743936:0;e=0;return e|0}function cO_(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?848136:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cO$(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?848136:0;e=0;return e|0}function cO0(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?743824:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cO1(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?743824:0;e=0;return e|0}function cO2(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?737216:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cO3(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?737216:0;e=0;return e|0}function cO4(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?848024:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cO5(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?848024:0;e=0;return e|0}function cO6(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?743600:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cO7(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?743600:0;e=0;return e|0}function cO8(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?743488:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cO9(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?743488:0;e=0;return e|0}function cPa(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?743376:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cPb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?743376:0;e=0;return e|0}function cPc(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1032240:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cPd(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1032240:0;e=0;return e|0}function cPe(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1032464:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cPf(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1032464:0;e=0;return e|0}function cPg(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?743264:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cPh(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?743264:0;e=0;return e|0}function cPi(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1032352:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cPj(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1032352:0;e=0;return e|0}function cPk(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?743152:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cPl(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?743152:0;e=0;return e|0}function cPm(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?706128:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cPn(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?706128:0;e=0;return e|0}function cPo(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?743712:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cPp(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?743712:0;e=0;return e|0}function cPq(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?742928:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cPr(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?742928:0;e=0;return e|0}function cPs(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?742816:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cPt(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?742816:0;e=0;return e|0}function cPu(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?847800:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cPv(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?847800:0;e=0;return e|0}function cPw(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?847688:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cPx(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?847688:0;e=0;return e|0}function cPy(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?742704:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cPz(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?742704:0;e=0;return e|0}function cPA(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1027872:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cPB(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1027872:0;e=0;return e|0}function cPC(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?742480:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cPD(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?742480:0;e=0;return e|0}function cPE(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?742592:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cPF(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?742592:0;e=0;return e|0}function cPG(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?742368:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cPH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?742368:0;e=0;return e|0}function cPI(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?742256:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cPJ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?742256:0;e=0;return e|0}function cPK(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?741696:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cPL(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?741696:0;e=0;return e|0}function cPM(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?847576:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cPN(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?847576:0;e=0;return e|0}function cPO(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?847464:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cPP(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?847464:0;e=0;return e|0}function cPQ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?742144:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cPR(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?742144:0;e=0;return e|0}function cPS(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?742032:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cPT(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?742032:0;e=0;return e|0}function cPU(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?840744:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cPV(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?840744:0;e=0;return e|0}function cPW(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?741920:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cPX(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?741920:0;e=0;return e|0}function cPY(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?847240:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cPZ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?847240:0;e=0;return e|0}function cP_(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?741808:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cP$(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?741808:0;e=0;return e|0}function cP0(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?847128:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cP1(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?847128:0;e=0;return e|0}function cP2(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1032016:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cP3(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1032016:0;e=0;return e|0}function cP4(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?847016:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cP5(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?847016:0;e=0;return e|0}function cP6(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1032128:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cP7(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1032128:0;e=0;return e|0}function cP8(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?741584:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cP9(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?741584:0;e=0;return e|0}function cQa(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?706016:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cQb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?706016:0;e=0;return e|0}function cQc(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?741472:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cQd(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?741472:0;e=0;return e|0}function cQe(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1031792:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cQf(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1031792:0;e=0;return e|0}function cQg(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?846904:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cQh(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?846904:0;e=0;return e|0}function cQi(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?846792:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cQj(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?846792:0;e=0;return e|0}function cQk(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?741360:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cQl(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?741360:0;e=0;return e|0}function cQm(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?705904:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cQn(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?705904:0;e=0;return e|0}function cQo(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?741248:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cQp(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?741248:0;e=0;return e|0}function cQq(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1031680:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cQr(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1031680:0;e=0;return e|0}function cQs(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?846680:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cQt(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?846680:0;e=0;return e|0}function cQu(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?846568:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cQv(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?846568:0;e=0;return e|0}function cQw(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?741024:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cQx(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?741024:0;e=0;return e|0}function cQy(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?740912:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cQz(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?740912:0;e=0;return e|0}function cQA(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?740800:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cQB(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?740800:0;e=0;return e|0}function cQC(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?705792:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cQD(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?705792:0;e=0;return e|0}function cQE(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2463336:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cQF(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2463336:0;e=0;return e|0}function cQG(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?740688:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cQH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?740688:0;e=0;return e|0}function cQI(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?740576:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cQJ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?740576:0;e=0;return e|0}function cQK(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?740240:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cQL(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?740240:0;e=0;return e|0}function cQM(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?740464:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cQN(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?740464:0;e=0;return e|0}function cQO(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?846456:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cQP(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?846456:0;e=0;return e|0}function cQQ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?740352:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cQR(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?740352:0;e=0;return e|0}function cQS(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?705680:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cQT(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?705680:0;e=0;return e|0}function cQU(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?740128:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cQV(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?740128:0;e=0;return e|0}function cQW(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?740016:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cQX(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?740016:0;e=0;return e|0}function cQY(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?739904:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cQZ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?739904:0;e=0;return e|0}function cQ_(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?739792:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cQ$(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?739792:0;e=0;return e|0}function cQ0(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?846344:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cQ1(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?846344:0;e=0;return e|0}function cQ2(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1442960:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cQ3(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1442960:0;e=0;return e|0}function cQ4(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?739568:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cQ5(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?739568:0;e=0;return e|0}function cQ6(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?739680:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cQ7(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?739680:0;e=0;return e|0}function cQ8(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?739456:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cQ9(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?739456:0;e=0;return e|0}function cRa(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?739344:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cRb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?739344:0;e=0;return e|0}function cRc(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?739232:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cRd(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?739232:0;e=0;return e|0}function cRe(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?739120:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cRf(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?739120:0;e=0;return e|0}function cRg(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1031568:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cRh(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1031568:0;e=0;return e|0}function cRi(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?739008:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cRj(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?739008:0;e=0;return e|0}function cRk(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?743040:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cRl(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?743040:0;e=0;return e|0}function cRm(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1031456:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cRn(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1031456:0;e=0;return e|0}function cRo(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?846232:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cRp(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?846232:0;e=0;return e|0}function cRq(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1031344:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cRr(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1031344:0;e=0;return e|0}function cRs(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?738896:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cRt(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?738896:0;e=0;return e|0}function cRu(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?738784:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cRv(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?738784:0;e=0;return e|0}function cRw(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?738560:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cRx(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?738560:0;e=0;return e|0}function cRy(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?738672:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cRz(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?738672:0;e=0;return e|0}function cRA(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1031232:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cRB(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1031232:0;e=0;return e|0}function cRC(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?846120:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cRD(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?846120:0;e=0;return e|0}function cRE(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1031120:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cRF(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1031120:0;e=0;return e|0}function cRG(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?847352:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cRH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?847352:0;e=0;return e|0}function cRI(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?738448:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cRJ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?738448:0;e=0;return e|0}function cRK(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?738336:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cRL(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?738336:0;e=0;return e|0}function cRM(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?846008:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cRN(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?846008:0;e=0;return e|0}function cRO(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?734304:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cRP(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?734304:0;e=0;return e|0}function cRQ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1442848:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cRR(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1442848:0;e=0;return e|0}function cRS(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?738224:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cRT(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?738224:0;e=0;return e|0}function cRU(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1442736:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cRV(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1442736:0;e=0;return e|0}function cRW(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1031008:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cRX(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1031008:0;e=0;return e|0}function cRY(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?845896:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cRZ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?845896:0;e=0;return e|0}function cR_(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?738112:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cR$(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?738112:0;e=0;return e|0}function cR0(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?841864:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cR1(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?841864:0;e=0;return e|0}function cR2(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?731728:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cR3(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?731728:0;e=0;return e|0}function cR4(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?738e3:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cR5(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?738e3:0;e=0;return e|0}function cR6(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?845784:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cR7(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?845784:0;e=0;return e|0}function cR8(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?737888:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cR9(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?737888:0;e=0;return e|0}function cSa(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?845672:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cSb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?845672:0;e=0;return e|0}function cSc(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?737776:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cSd(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?737776:0;e=0;return e|0}function cSe(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2463224:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cSf(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2463224:0;e=0;return e|0}function cSg(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?737664:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cSh(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?737664:0;e=0;return e|0}function cSi(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?733184:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cSj(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?733184:0;e=0;return e|0}function cSk(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?733072:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cSl(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?733072:0;e=0;return e|0}function cSm(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1030784:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cSn(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1030784:0;e=0;return e|0}function cSo(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?737440:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cSp(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?737440:0;e=0;return e|0}function cSq(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?737552:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cSr(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?737552:0;e=0;return e|0}function cSs(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1030896:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cSt(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1030896:0;e=0;return e|0}function cSu(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?737328:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cSv(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?737328:0;e=0;return e|0}function cSw(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?705568:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cSx(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?705568:0;e=0;return e|0}function cSy(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2463112:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cSz(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2463112:0;e=0;return e|0}function cSA(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1442624:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cSB(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1442624:0;e=0;return e|0}function cSC(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?845560:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cSD(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?845560:0;e=0;return e|0}function cSE(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?737104:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cSF(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?737104:0;e=0;return e|0}function cSG(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?736208:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cSH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?736208:0;e=0;return e|0}function cSI(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?736320:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cSJ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?736320:0;e=0;return e|0}function cSK(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?705456:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cSL(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?705456:0;e=0;return e|0}function cSM(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?736096:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cSN(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?736096:0;e=0;return e|0}function cSO(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?735984:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cSP(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?735984:0;e=0;return e|0}function cSQ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1030672:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cSR(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1030672:0;e=0;return e|0}function cSS(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?845336:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cST(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?845336:0;e=0;return e|0}function cSU(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1028096:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cSV(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1028096:0;e=0;return e|0}function cSW(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?736992:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cSX(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?736992:0;e=0;return e|0}function cSY(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?736880:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cSZ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?736880:0;e=0;return e|0}function cS_(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?736768:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cS$(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?736768:0;e=0;return e|0}function cS0(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?736656:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cS1(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?736656:0;e=0;return e|0}function cS2(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?845448:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cS3(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?845448:0;e=0;return e|0}function cS4(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?736544:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cS5(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?736544:0;e=0;return e|0}function cS6(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?736432:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cS7(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?736432:0;e=0;return e|0}function cS8(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?845224:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cS9(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?845224:0;e=0;return e|0}function cTa(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1442512:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cTb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1442512:0;e=0;return e|0}function cTc(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?735648:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cTd(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?735648:0;e=0;return e|0}function cTe(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?735760:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cTf(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?735760:0;e=0;return e|0}function cTg(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?735872:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cTh(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?735872:0;e=0;return e|0}function cTi(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?735536:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cTj(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?735536:0;e=0;return e|0}function cTk(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?735424:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cTl(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?735424:0;e=0;return e|0}function cTm(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?735312:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cTn(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?735312:0;e=0;return e|0}function cTo(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?705344:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cTp(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?705344:0;e=0;return e|0}function cTq(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1030560:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cTr(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1030560:0;e=0;return e|0}function cTs(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?845112:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cTt(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?845112:0;e=0;return e|0}function cTu(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?744272:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cTv(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?744272:0;e=0;return e|0}function cTw(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?845e3:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cTx(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?845e3:0;e=0;return e|0}function cTy(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?844888:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cTz(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?844888:0;e=0;return e|0}function cTA(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?735200:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cTB(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?735200:0;e=0;return e|0}function cTC(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?735088:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cTD(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?735088:0;e=0;return e|0}function cTE(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1030448:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cTF(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1030448:0;e=0;return e|0}function cTG(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?734976:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cTH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?734976:0;e=0;return e|0}function cTI(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?734864:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cTJ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?734864:0;e=0;return e|0}function cTK(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?734752:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cTL(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?734752:0;e=0;return e|0}function cTM(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?734528:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cTN(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?734528:0;e=0;return e|0}function cTO(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?734640:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cTP(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?734640:0;e=0;return e|0}function cTQ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2463e3:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cTR(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2463e3:0;e=0;return e|0}function cTS(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?734416:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cTT(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?734416:0;e=0;return e|0}function cTU(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?734080:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cTV(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?734080:0;e=0;return e|0}function cTW(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?734192:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cTX(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?734192:0;e=0;return e|0}function cTY(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?844776:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cTZ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?844776:0;e=0;return e|0}function cT_(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1030336:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cT$(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1030336:0;e=0;return e|0}function cT0(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1030224:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cT1(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1030224:0;e=0;return e|0}function cT2(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?844664:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cT3(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?844664:0;e=0;return e|0}function cT4(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1030112:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cT5(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1030112:0;e=0;return e|0}function cT6(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?733968:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cT7(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?733968:0;e=0;return e|0}function cT8(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4490536:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cT9(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4490536:0;e=0;return e|0}function cUa(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?844552:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cUb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?844552:0;e=0;return e|0}function cUc(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?733856:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cUd(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?733856:0;e=0;return e|0}function cUe(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?733744:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cUf(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?733744:0;e=0;return e|0}function cUg(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?844440:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cUh(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?844440:0;e=0;return e|0}function cUi(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?733632:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cUj(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?733632:0;e=0;return e|0}function cUk(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?103e4:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cUl(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?103e4:0;e=0;return e|0}function cUm(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?844104:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cUn(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?844104:0;e=0;return e|0}function cUo(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?844328:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cUp(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?844328:0;e=0;return e|0}function cUq(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?844216:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cUr(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?844216:0;e=0;return e|0}function cUs(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?733520:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cUt(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?733520:0;e=0;return e|0}function cUu(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?843992:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cUv(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?843992:0;e=0;return e|0}function cUw(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?733408:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cUx(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?733408:0;e=0;return e|0}function cUy(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?705232:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cUz(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?705232:0;e=0;return e|0}function cUA(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1029888:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cUB(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1029888:0;e=0;return e|0}function cUC(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?843880:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cUD(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?843880:0;e=0;return e|0}function cUE(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?843432:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cUF(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?843432:0;e=0;return e|0}function cUG(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?733296:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cUH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?733296:0;e=0;return e|0}function cUI(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1442400:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cUJ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1442400:0;e=0;return e|0}function cUK(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?843768:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cUL(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?843768:0;e=0;return e|0}function cUM(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?843656:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cUN(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?843656:0;e=0;return e|0}function cUO(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?843544:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cUP(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?843544:0;e=0;return e|0}function cUQ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1029776:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cUR(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1029776:0;e=0;return e|0}function cUS(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1029664:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cUT(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1029664:0;e=0;return e|0}function cUU(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1029552:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cUV(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1029552:0;e=0;return e|0}function cUW(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1029440:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cUX(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1029440:0;e=0;return e|0}function cUY(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?843320:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cUZ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?843320:0;e=0;return e|0}function cU_(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?843096:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cU$(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?843096:0;e=0;return e|0}function cU0(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?732960:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cU1(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?732960:0;e=0;return e|0}function cU2(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1029328:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cU3(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1029328:0;e=0;return e|0}function cU4(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?843208:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cU5(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?843208:0;e=0;return e|0}function cU6(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?732848:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cU7(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?732848:0;e=0;return e|0}function cU8(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?842984:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cU9(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?842984:0;e=0;return e|0}function cVa(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1029216:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cVb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1029216:0;e=0;return e|0}function cVc(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?842760:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cVd(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?842760:0;e=0;return e|0}function cVe(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?842648:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cVf(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?842648:0;e=0;return e|0}function cVg(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?732736:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cVh(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?732736:0;e=0;return e|0}function cVi(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?732624:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cVj(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?732624:0;e=0;return e|0}function cVk(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1029104:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cVl(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1029104:0;e=0;return e|0}function cVm(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?842872:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cVn(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?842872:0;e=0;return e|0}function cVo(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1028992:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cVp(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1028992:0;e=0;return e|0}function cVq(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1028880:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cVr(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1028880:0;e=0;return e|0}function cVs(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?842536:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cVt(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?842536:0;e=0;return e|0}function cVu(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?732512:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cVv(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?732512:0;e=0;return e|0}function cVw(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?732400:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cVx(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?732400:0;e=0;return e|0}function cVy(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?732288:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cVz(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?732288:0;e=0;return e|0}function cVA(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?732176:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cVB(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?732176:0;e=0;return e|0}function cVC(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?732064:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cVD(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?732064:0;e=0;return e|0}function cVE(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?842200:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cVF(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?842200:0;e=0;return e|0}function cVG(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1028768:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cVH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1028768:0;e=0;return e|0}function cVI(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?842088:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cVJ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?842088:0;e=0;return e|0}function cVK(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?841976:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cVL(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?841976:0;e=0;return e|0}function cVM(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?731616:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cVN(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?731616:0;e=0;return e|0}function cVO(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?841752:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cVP(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?841752:0;e=0;return e|0}function cVQ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?731504:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cVR(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?731504:0;e=0;return e|0}function cVS(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1028656:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cVT(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1028656:0;e=0;return e|0}function cVU(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?731392:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cVV(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?731392:0;e=0;return e|0}function cVW(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?731280:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cVX(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?731280:0;e=0;return e|0}function cVY(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?841416:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cVZ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?841416:0;e=0;return e|0}function cV_(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?841528:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cV$(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?841528:0;e=0;return e|0}function cV0(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?731952:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cV1(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?731952:0;e=0;return e|0}function cV2(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?731168:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cV3(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?731168:0;e=0;return e|0}function cV4(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4490424:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cV5(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4490424:0;e=0;return e|0}function cV6(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?731056:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cV7(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?731056:0;e=0;return e|0}function cV8(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?730944:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cV9(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?730944:0;e=0;return e|0}function cWa(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?841304:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cWb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?841304:0;e=0;return e|0}function cWc(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?730832:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cWd(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?730832:0;e=0;return e|0}function cWe(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1442288:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cWf(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1442288:0;e=0;return e|0}function cWg(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?841080:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cWh(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?841080:0;e=0;return e|0}function cWi(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?841640:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cWj(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?841640:0;e=0;return e|0}function cWk(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1442176:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cWl(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1442176:0;e=0;return e|0}function cWm(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1028544:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cWn(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1028544:0;e=0;return e|0}function cWo(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?841192:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cWp(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?841192:0;e=0;return e|0}function cWq(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?840968:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cWr(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?840968:0;e=0;return e|0}function cWs(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1028432:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cWt(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1028432:0;e=0;return e|0}function cWu(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?847912:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cWv(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?847912:0;e=0;return e|0}function cWw(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?730720:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cWx(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?730720:0;e=0;return e|0}function cWy(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?842312:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cWz(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?842312:0;e=0;return e|0}function cWA(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?731840:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cWB(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?731840:0;e=0;return e|0}function cWC(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?730608:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cWD(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?730608:0;e=0;return e|0}function cWE(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?705120:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cWF(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?705120:0;e=0;return e|0}function cWG(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?730496:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cWH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?730496:0;e=0;return e|0}function cWI(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?842424:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cWJ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?842424:0;e=0;return e|0}function cWK(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?730384:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cWL(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?730384:0;e=0;return e|0}function cWM(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1028320:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cWN(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1028320:0;e=0;return e|0}function cWO(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?730272:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cWP(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?730272:0;e=0;return e|0}function cWQ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1442064:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cWR(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1442064:0;e=0;return e|0}function cWS(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?840856:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cWT(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?840856:0;e=0;return e|0}function cWU(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?730160:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cWV(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?730160:0;e=0;return e|0}function cWW(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?741136:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cWX(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?741136:0;e=0;return e|0}function cWY(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1031904:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cWZ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1031904:0;e=0;return e|0}function cW_(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?730048:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cW$(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?730048:0;e=0;return e|0}function cW0(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1028208:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cW1(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1028208:0;e=0;return e|0}function cW2(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?729936:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cW3(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?729936:0;e=0;return e|0}function cW4(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1032912:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cW5(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1032912:0;e=0;return e|0}function cW6(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?729824:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cW7(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?729824:0;e=0;return e|0}function cW8(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?729712:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cW9(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?729712:0;e=0;return e|0}function cXa(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?729600:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cXb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?729600:0;e=0;return e|0}function cXc(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?729488:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cXd(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?729488:0;e=0;return e|0}function cXe(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?840632:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cXf(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?840632:0;e=0;return e|0}function cXg(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?729264:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cXh(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?729264:0;e=0;return e|0}function cXi(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?729152:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cXj(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?729152:0;e=0;return e|0}function cXk(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?729040:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cXl(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?729040:0;e=0;return e|0}function cXm(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?840520:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cXn(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?840520:0;e=0;return e|0}function cXo(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1441952:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cXp(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1441952:0;e=0;return e|0}function cXq(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?728928:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cXr(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?728928:0;e=0;return e|0}function cXs(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?729376:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cXt(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?729376:0;e=0;return e|0}function cXu(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?840408:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cXv(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?840408:0;e=0;return e|0}function cXw(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?840296:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cXx(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?840296:0;e=0;return e|0}function cXy(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?840072:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cXz(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?840072:0;e=0;return e|0}function cXA(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1027984:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cXB(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1027984:0;e=0;return e|0}function cXC(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?728816:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cXD(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?728816:0;e=0;return e|0}function cXE(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?840184:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cXF(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?840184:0;e=0;return e|0}function cXG(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?839960:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cXH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?839960:0;e=0;return e|0}function cXI(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?839848:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cXJ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?839848:0;e=0;return e|0}function cXK(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2462888:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cXL(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2462888:0;e=0;return e|0}function cXM(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?839736:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cXN(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?839736:0;e=0;return e|0}function cXO(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1027760:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cXP(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1027760:0;e=0;return e|0}function cXQ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1027648:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cXR(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1027648:0;e=0;return e|0}function cXS(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?830064:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cXT(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?830064:0;e=0;return e|0}function cXU(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1380816:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cXV(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1380816:0;e=0;return e|0}function cXW(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?829952:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cXX(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?829952:0;e=0;return e|0}function cXY(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?829840:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cXZ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?829840:0;e=0;return e|0}function cX_(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?829728:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cX$(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?829728:0;e=0;return e|0}function cX0(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?829616:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cX1(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?829616:0;e=0;return e|0}function cX2(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?829504:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cX3(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?829504:0;e=0;return e|0}function cX4(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1002072:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cX5(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1002072:0;e=0;return e|0}function cX6(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2169104:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cX7(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2169104:0;e=0;return e|0}function cX8(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4363016:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cX9(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4363016:0;e=0;return e|0}function cYa(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2169216:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cYb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2169216:0;e=0;return e|0}function cYc(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1001960:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cYd(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1001960:0;e=0;return e|0}function cYe(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?829392:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cYf(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?829392:0;e=0;return e|0}function cYg(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1380704:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cYh(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1380704:0;e=0;return e|0}function cYi(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?827936:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cYj(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?827936:0;e=0;return e|0}function cYk(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1001736:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cYl(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1001736:0;e=0;return e|0}function cYm(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?829280:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cYn(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?829280:0;e=0;return e|0}function cYo(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?829168:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cYp(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?829168:0;e=0;return e|0}function cYq(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?829056:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cYr(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?829056:0;e=0;return e|0}function cYs(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?828944:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cYt(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?828944:0;e=0;return e|0}function cYu(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?828832:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cYv(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?828832:0;e=0;return e|0}function cYw(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?828720:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cYx(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?828720:0;e=0;return e|0}function cYy(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?828608:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cYz(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?828608:0;e=0;return e|0}function cYA(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?828496:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cYB(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?828496:0;e=0;return e|0}function cYC(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1380592:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cYD(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1380592:0;e=0;return e|0}function cYE(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1001512:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cYF(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1001512:0;e=0;return e|0}function cYG(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?828384:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cYH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?828384:0;e=0;return e|0}function cYI(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1001624:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cYJ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1001624:0;e=0;return e|0}function cYK(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?828272:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cYL(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?828272:0;e=0;return e|0}function cYM(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1380480:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cYN(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1380480:0;e=0;return e|0}function cYO(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?828160:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cYP(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?828160:0;e=0;return e|0}function cYQ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?828048:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cYR(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?828048:0;e=0;return e|0}function cYS(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?827824:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cYT(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?827824:0;e=0;return e|0}function cYU(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?827712:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cYV(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?827712:0;e=0;return e|0}function cYW(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1001288:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cYX(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1001288:0;e=0;return e|0}function cYY(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1380368:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cYZ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1380368:0;e=0;return e|0}function cY_(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?827600:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cY$(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?827600:0;e=0;return e|0}function cY0(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1001176:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cY1(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1001176:0;e=0;return e|0}function cY2(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?826704:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cY3(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?826704:0;e=0;return e|0}function cY4(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2168992:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cY5(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2168992:0;e=0;return e|0}function cY6(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?827488:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cY7(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?827488:0;e=0;return e|0}function cY8(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?827376:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cY9(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?827376:0;e=0;return e|0}function cZa(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4362904:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cZb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4362904:0;e=0;return e|0}function cZc(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?4362792:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cZd(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?4362792:0;e=0;return e|0}function cZe(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1001064:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cZf(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1001064:0;e=0;return e|0}function cZg(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1380256:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cZh(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1380256:0;e=0;return e|0}function cZi(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?827264:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cZj(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?827264:0;e=0;return e|0}function cZk(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?827152:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cZl(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?827152:0;e=0;return e|0}function cZm(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?827040:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cZn(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?827040:0;e=0;return e|0}function cZo(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?826816:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cZp(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?826816:0;e=0;return e|0}function cZq(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?826928:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cZr(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?826928:0;e=0;return e|0}function cZs(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?830176:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cZt(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?830176:0;e=0;return e|0}function cZu(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1000952:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cZv(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1000952:0;e=0;return e|0}function cZw(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1000840:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cZx(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1000840:0;e=0;return e|0}function cZy(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1001400:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cZz(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1001400:0;e=0;return e|0}function cZA(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1380144:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cZB(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1380144:0;e=0;return e|0}function cZC(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1000728:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cZD(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1000728:0;e=0;return e|0}function cZE(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1000616:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cZF(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1000616:0;e=0;return e|0}function cZG(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1000504:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cZH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1000504:0;e=0;return e|0}function cZI(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2168880:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cZJ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2168880:0;e=0;return e|0}function cZK(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1000392:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cZL(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1000392:0;e=0;return e|0}function cZM(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2168768:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cZN(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2168768:0;e=0;return e|0}function cZO(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1380032:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cZP(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1380032:0;e=0;return e|0}function cZQ(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?826592:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cZR(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?826592:0;e=0;return e|0}function cZS(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?826368:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cZT(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?826368:0;e=0;return e|0}function cZU(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?826256:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cZV(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?826256:0;e=0;return e|0}function cZW(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1000280:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cZX(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1000280:0;e=0;return e|0}function cZY(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?826144:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cZZ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?826144:0;e=0;return e|0}function cZ_(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?826032:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cZ$(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?826032:0;e=0;return e|0}function cZ0(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?825920:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cZ1(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?825920:0;e=0;return e|0}function cZ2(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1379808:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cZ3(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1379808:0;e=0;return e|0}function cZ4(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?826480:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cZ5(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?826480:0;e=0;return e|0}function cZ6(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1000168:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cZ7(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1000168:0;e=0;return e|0}function cZ8(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1000056:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function cZ9(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1000056:0;e=0;return e|0}function c_a(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?999944:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function c_b(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?999944:0;e=0;return e|0}function c_c(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1001848:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function c_d(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1001848:0;e=0;return e|0}function c_e(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?825808:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function c_f(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?825808:0;e=0;return e|0}function c_g(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?825696:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function c_h(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?825696:0;e=0;return e|0}function c_i(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?825584:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function c_j(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?825584:0;e=0;return e|0}function c_k(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?999832:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function c_l(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?999832:0;e=0;return e|0}function c_m(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?825472:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function c_n(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?825472:0;e=0;return e|0}function c_o(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1379920:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function c_p(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1379920:0;e=0;return e|0}function c_q(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?825360:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function c_r(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?825360:0;e=0;return e|0}function c_s(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?825248:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function c_t(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?825248:0;e=0;return e|0}function c_u(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?825136:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function c_v(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?825136:0;e=0;return e|0}function c_w(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?825024:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function c_x(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?825024:0;e=0;return e|0}function c_y(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?999720:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function c_z(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?999720:0;e=0;return e|0}function c_A(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?824912:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function c_B(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?824912:0;e=0;return e|0}function c_C(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?824800:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function c_D(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?824800:0;e=0;return e|0}function c_E(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?824688:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function c_F(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?824688:0;e=0;return e|0}function c_G(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?824576:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function c_H(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?824576:0;e=0;return e|0}function c_I(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?1379696:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function c_J(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?1379696:0;e=0;return e|0}function c_K(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2168656:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function c_L(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2168656:0;e=0;return e|0}function c_M(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2297640:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function c_N(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2297640:0;e=0;return e|0}function c_O(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?836600:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function c_P(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?836600:0;e=0;return e|0}function c_Q(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?728600:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function c_R(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?728600:0;e=0;return e|0}function c_S(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?728488:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function c_T(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?728488:0;e=0;return e|0}function c_U(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?728376:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function c_V(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?728376:0;e=0;return e|0}function c_W(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>5){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7343836+(b*112|0)>>2];c[a+104>>2]=c[7343840+(b*112|0)>>2];c[a+108>>2]=c[7343844+(b*112|0)>>2];d=0;return d|0}function c_X(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<6&(d|0)==0)){e=1;return e|0}c[a>>2]=7343736+(b*112|0);e=0;return e|0}function c_Y(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>47){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6502936+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function c_Z(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7344408+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function c__(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>11){f=9763080;break}f=2487792+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c_$(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>11){g=9763080;break}g=2487792+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c_0(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=21){if((a|0)==0){d=0;return d|0}e=a;f=7344408+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}f=b-22|0;if(f>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;a=2489136+(f*12|0)|0;c[b>>2]=c[a>>2];c[b+4>>2]=c[a+4>>2];c[b+8>>2]=c[a+8>>2];d=0;return d|0}function c_1(){c[2112954]=11366;return dgh()|0}function c_2(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>11){f=9763080;break}f=745576+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c_3(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>11){g=9763080;break}g=745576+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c_4(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>11){f=9763080;break}f=746920+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c_5(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>11){g=9763080;break}g=746920+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c_6(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>11){f=9763080;break}f=706360+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c_7(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>11){g=9763080;break}g=706360+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c_8(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>14){f=9763080;break}f=748264+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c_9(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>14){g=9763080;break}g=748264+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c$a(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=21){if((a|0)==0){d=0;return d|0}e=a;f=7344408+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}f=b-22|0;if(f>>>0>3){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;a=2489232+(f*12|0)|0;c[b>>2]=c[a>>2];c[b+4>>2]=c[a+4>>2];c[b+8>>2]=c[a+8>>2];d=0;return d|0}function c$b(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>14){f=9763080;break}f=749944+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c$c(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>14){g=9763080;break}g=749944+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c$d(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=21){if((a|0)==0){d=0;return d|0}e=a;f=7344408+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}if((b|0)!=22){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;c[b>>2]=c[622320];c[b+4>>2]=c[622321];c[b+8>>2]=c[622322];d=0;return d|0}function c$e(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>3){f=9763080;break}f=6586240+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c$f(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>3){g=9763080;break}g=6586240+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c$g(){c[2112956]=676;c[2112954]=11462;return dgh()|0}function c$h(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>3){f=9763080;break}f=5905832+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c$i(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>3){g=9763080;break}g=5905832+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c$j(){c[2112956]=11982;c[2112954]=11462;return dgh()|0}function c$k(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>3){f=9763080;break}f=5905384+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c$l(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>3){g=9763080;break}g=5905384+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c$m(){c[2112956]=11202;c[2112954]=11462;return dgh()|0}function c$n(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>3){f=9763080;break}f=5904936+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c$o(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>3){g=9763080;break}g=5904936+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c$p(){c[2112956]=4966;c[2112954]=11462;return dgh()|0}function c$q(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>11){f=9763080;break}f=4614280+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c$r(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>11){g=9763080;break}g=4614280+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c$s(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=21){if((a|0)==0){d=0;return d|0}e=a;f=7344408+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}f=b-22|0;if(f>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;a=4615624+(f*12|0)|0;c[b>>2]=c[a>>2];c[b+4>>2]=c[a+4>>2];c[b+8>>2]=c[a+8>>2];d=0;return d|0}function c$t(){c[2112956]=7552;c[2112954]=1710;return dgh()|0}function c$u(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>14){f=9763080;break}f=1088416+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c$v(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>14){g=9763080;break}g=1088416+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c$w(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>19){f=9763080;break}f=7018328+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c$x(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>19){g=9763080;break}g=7018328+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c$y(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=21){if((a|0)==0){d=0;return d|0}e=a;f=7344408+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}f=b-22|0;if(f>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;a=7020568+(f*12|0)|0;c[b>>2]=c[a>>2];c[b+4>>2]=c[a+4>>2];c[b+8>>2]=c[a+8>>2];d=0;return d|0}function c$z(){c[2112954]=3698;return dgh()|0}function c$A(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>19){f=9763080;break}f=4504992+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c$B(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>19){g=9763080;break}g=4504992+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c$C(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>15){f=9763080;break}f=2495904+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c$D(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>15){g=9763080;break}g=2495904+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c$E(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>14){f=9763080;break}f=2494224+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c$F(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>14){g=9763080;break}g=2494224+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c$G(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>9){f=9763080;break}f=7347288+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c$H(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>9){g=9763080;break}g=7347288+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c$I(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=21){if((a|0)==0){d=0;return d|0}e=a;f=7344408+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}f=b-22|0;if(f>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;a=7348408+(f*12|0)|0;c[b>>2]=c[a>>2];c[b+4>>2]=c[a+4>>2];c[b+8>>2]=c[a+8>>2];d=0;return d|0}function c$J(){c[2112956]=4050;c[2112954]=12626;return dgh()|0}function c$K(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>9){f=9763080;break}f=5808152+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c$L(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>9){g=9763080;break}g=5808152+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c$M(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>13){f=9763080;break}f=5809272+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c$N(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>13){g=9763080;break}g=5809272+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c$O(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>9){f=9763080;break}f=4582008+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c$P(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>9){g=9763080;break}g=4582008+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c$Q(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>13){f=9763080;break}f=2668680+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c$R(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>13){g=9763080;break}g=2668680+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c$S(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>11){f=9763080;break}f=6535120+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c$T(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>11){g=9763080;break}g=6535120+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c$U(){var a=0;c[2112956]=7220;c[2112954]=6806;c[2113094]=16141;a=dgh()|0;c[1744674]=608;return a|0}function c$V(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>11){f=9763080;break}f=2662632+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c$W(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>11){g=9763080;break}g=2662632+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c$X(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>11){f=9763080;break}f=2663976+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c$Y(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>11){g=9763080;break}g=2663976+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c$Z(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>11){f=9763080;break}f=2665320+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c$_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>11){g=9763080;break}g=2665320+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c$$(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>11){f=9763080;break}f=2458400+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c$0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>11){g=9763080;break}g=2458400+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c$1(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=21){if((a|0)==0){d=0;return d|0}e=a;f=7344408+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}f=b-22|0;if(f>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;a=2459744+(f*12|0)|0;c[b>>2]=c[a>>2];c[b+4>>2]=c[a+4>>2];c[b+8>>2]=c[a+8>>2];d=0;return d|0}function c$2(){var a=0;c[2112956]=4656;c[2112954]=6806;c[2113094]=6065;a=dgh()|0;c[1744674]=500;return a|0}function c$3(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>11){f=9763080;break}f=836712+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c$4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>11){g=9763080;break}g=836712+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c$5(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>14){f=9763080;break}f=838056+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c$6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>14){g=9763080;break}g=838056+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c$7(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>6){f=9763080;break}f=2420144+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c$8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>6){g=9763080;break}g=2420144+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c$9(){c[2112956]=2940;c[2112954]=7930;return dgh()|0}function c0a(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>5){f=9763080;break}f=4467320+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c0b(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>5){g=9763080;break}g=4467320+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c0c(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=21){if((a|0)==0){d=0;return d|0}e=a;f=7344408+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}f=b-22|0;if(f>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;a=4467992+(f*12|0)|0;c[b>>2]=c[a>>2];c[b+4>>2]=c[a+4>>2];c[b+8>>2]=c[a+8>>2];d=0;return d|0}function c0d(){a[9592]=1;c[2112956]=10602;c[2112954]=11372;return dgh()|0}function c0e(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>6){f=9763080;break}f=2418016+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c0f(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>6){g=9763080;break}g=2418016+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c0g(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>12){f=9763080;break}f=2611984+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c0h(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>12){g=9763080;break}g=2611984+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c0i(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=21){if((a|0)==0){d=0;return d|0}e=a;f=7344408+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}f=b-22|0;if(f>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;a=2613440+(f*12|0)|0;c[b>>2]=c[a>>2];c[b+4>>2]=c[a+4>>2];c[b+8>>2]=c[a+8>>2];d=0;return d|0}function c0j(){var a=0;c[2112956]=9780;c[2112954]=420;c[2113094]=14273;a=dgh()|0;c[1744674]=134218654;return a|0}function c0k(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>12){f=9763080;break}f=1500992+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c0l(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>12){g=9763080;break}g=1500992+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c0m(){var a=0;c[2112956]=9780;c[2112954]=420;c[2113094]=11445;a=dgh()|0;c[1744674]=134218654;return a|0}function c0n(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>12){f=9763080;break}f=791584+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c0o(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>12){g=9763080;break}g=791584+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c0p(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=21){if((a|0)==0){d=0;return d|0}e=a;f=7344408+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}f=b-22|0;if(f>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;a=793040+(f*12|0)|0;c[b>>2]=c[a>>2];c[b+4>>2]=c[a+4>>2];c[b+8>>2]=c[a+8>>2];d=0;return d|0}function c0q(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>11){f=9763080;break}f=7033984+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c0r(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>11){g=9763080;break}g=7033984+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c0s(){var a=0;c[2112956]=11844;c[2112954]=420;c[2113094]=9189;a=dgh()|0;c[1744674]=134217902;return a|0}function c0t(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>11){f=9763080;break}f=4583128+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c0u(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>11){g=9763080;break}g=4583128+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c0v(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>11){f=9763080;break}f=4584472+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c0w(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>11){g=9763080;break}g=4584472+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c0x(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>11){f=9763080;break}f=4585816+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c0y(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>11){g=9763080;break}g=4585816+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c0z(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>11){f=9763080;break}f=4587160+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c0A(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>11){g=9763080;break}g=4587160+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c0B(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>11){f=9763080;break}f=4588504+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c0C(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>11){g=9763080;break}g=4588504+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c0D(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>11){f=9763080;break}f=6536464+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c0E(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>11){g=9763080;break}g=6536464+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c0F(){var a=0;c[2112956]=856;c[2112954]=420;c[2113094]=9965;a=dgh()|0;c[1744674]=134217894;return a|0}function c0G(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>11){f=9763080;break}f=2670248+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c0H(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>11){g=9763080;break}g=2670248+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c0I(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>11){f=9763080;break}f=2671592+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c0J(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>11){g=9763080;break}g=2671592+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c0K(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>7){f=9763080;break}f=7062992+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c0L(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>7){g=9763080;break}g=7062992+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c0M(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=21){if((a|0)==0){d=0;return d|0}e=a;f=7344408+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}if((b|0)!=22){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;c[b>>2]=c[1765972];c[b+4>>2]=c[1765973];c[b+8>>2]=c[1765974];d=0;return d|0}function c0N(){var a=0;c[2112956]=7532;c[2112954]=420;a=dgh()|0;c[1744674]=134285720;return a|0}function c0O(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>7){f=9763080;break}f=4750560+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c0P(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>7){g=9763080;break}g=4750560+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c0Q(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>7){f=9763080;break}f=4751456+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c0R(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>7){g=9763080;break}g=4751456+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c0S(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>7){f=9763080;break}f=5920280+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c0T(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>7){g=9763080;break}g=5920280+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c0U(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=21){if((a|0)==0){d=0;return d|0}e=a;f=7344408+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}if((b|0)!=22){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;c[b>>2]=c[1480294];c[b+4>>2]=c[1480295];c[b+8>>2]=c[1480296];d=0;return d|0}function c0V(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>7){f=9763080;break}f=1576104+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c0W(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>7){g=9763080;break}g=1576104+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c0X(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>7){f=9763080;break}f=1577e3+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c0Y(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>7){g=9763080;break}g=1577e3+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c0Z(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>7){f=9763080;break}f=6592008+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c0_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>7){g=9763080;break}g=6592008+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c0$(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=21){if((a|0)==0){d=0;return d|0}e=a;f=7344408+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}if((b|0)!=22){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;c[b>>2]=c[1648226];c[b+4>>2]=c[1648227];c[b+8>>2]=c[1648228];d=0;return d|0}function c00(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>7){f=9763080;break}f=2956832+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c01(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>7){g=9763080;break}g=2956832+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c02(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>7){f=9763080;break}f=2960416+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c03(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>7){g=9763080;break}g=2960416+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c04(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>7){f=9763080;break}f=6592920+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c05(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>7){g=9763080;break}g=6592920+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c06(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=21){if((a|0)==0){d=0;return d|0}e=a;f=7344408+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}if((b|0)!=22){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;c[b>>2]=c[622320];c[b+4>>2]=c[622321];c[b+8>>2]=c[622322];d=0;return d|0}function c07(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>7){f=9763080;break}f=2957728+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c08(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>7){g=9763080;break}g=2957728+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c09(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>7){f=9763080;break}f=2961312+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c1a(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>7){g=9763080;break}g=2961312+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c1b(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>7){f=9763080;break}f=6591096+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c1c(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>7){g=9763080;break}g=6591096+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c1d(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=21){if((a|0)==0){d=0;return d|0}e=a;f=7344408+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}if((b|0)!=22){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;c[b>>2]=c[1647998];c[b+4>>2]=c[1647999];c[b+8>>2]=c[1648e3];d=0;return d|0}function c1e(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>7){f=9763080;break}f=2955936+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c1f(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>7){g=9763080;break}g=2955936+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c1g(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>7){f=9763080;break}f=2959520+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c1h(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>7){g=9763080;break}g=2959520+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c1i(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>7){f=9763080;break}f=6593816+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c1j(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>7){g=9763080;break}g=6593816+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c1k(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=21){if((a|0)==0){d=0;return d|0}e=a;f=7344408+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}if((b|0)!=22){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;c[b>>2]=c[1648678];c[b+4>>2]=c[1648679];c[b+8>>2]=c[1648680];d=0;return d|0}function c1l(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>7){f=9763080;break}f=2958624+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c1m(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>7){g=9763080;break}g=2958624+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c1n(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>7){f=9763080;break}f=2962208+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c1o(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>7){g=9763080;break}g=2962208+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c1p(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>7){f=9763080;break}f=5903248+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c1q(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>7){g=9763080;break}g=5903248+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c1r(){var a=0;c[2112956]=9780;c[2112954]=420;a=dgh()|0;c[1744674]=134218280;return a|0}function c1s(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>7){f=9763080;break}f=7059832+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c1t(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>7){g=9763080;break}g=7059832+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c1u(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>9){f=9763080;break}f=4737008+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c1v(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>9){g=9763080;break}g=4737008+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c1w(){var a=0;c[2112956]=7116;c[2112954]=9776;a=dgh()|0;c[1744674]=134221748;return a|0}function c1x(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>9){f=9763080;break}f=2931744+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c1y(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>9){g=9763080;break}g=2931744+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c1z(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>9){f=9763080;break}f=2932864+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c1A(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>9){g=9763080;break}g=2932864+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c1B(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>9){f=9763080;break}f=5805688+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c1C(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>9){g=9763080;break}g=5805688+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c1D(){var a=0;c[2112956]=7758;c[2112954]=3876;c[2113094]=16141;a=dgh()|0;c[1744674]=608;return a|0}function c1E(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>9){f=9763080;break}f=4580888+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c1F(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>9){g=9763080;break}g=4580888+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c1G(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>9){f=9763080;break}f=4579768+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c1H(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>9){g=9763080;break}g=4579768+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c1I(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=21){if((a|0)==0){d=0;return d|0}e=a;f=7344408+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}f=b-22|0;if(f>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;a=2662536+(f*12|0)|0;c[b>>2]=c[a>>2];c[b+4>>2]=c[a+4>>2];c[b+8>>2]=c[a+8>>2];d=0;return d|0}function c1J(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>9){f=9763080;break}f=2493104+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c1K(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>9){g=9763080;break}g=2493104+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c1L(){c[2112956]=2194;c[2112954]=10688;return dgh()|0}function c1M(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>2){e=1;return e|0}else{f=2955600+(d*112|0)|0;break}}else{if(b>>>0>7){f=9763080;break}f=7062096+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c1N(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>2){f=1;return f|0}else{g=2955600+(e*112|0)|0;break}}else{if(b>>>0>7){g=9763080;break}g=7062096+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c1O(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6562872+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function c1P(){c[2112956]=6864;c[2112954]=2852;return dgh()|0}function c1Q(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>2){e=1;return e|0}else{f=2955600+(d*112|0)|0;break}}else{if(b>>>0>7){f=9763080;break}f=6590200+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c1R(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>2){f=1;return f|0}else{g=2955600+(e*112|0)|0;break}}else{if(b>>>0>7){g=9763080;break}g=6590200+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c1S(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>2){e=1;return e|0}else{f=2955600+(d*112|0)|0;break}}else{if(b>>>0>7){f=9763080;break}f=6589304+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c1T(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>2){f=1;return f|0}else{g=2955600+(e*112|0)|0;break}}else{if(b>>>0>7){g=9763080;break}g=6589304+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c1U(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>2){e=1;return e|0}else{f=2955600+(d*112|0)|0;break}}else{if(b>>>0>7){f=9763080;break}f=4749664+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c1V(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>2){f=1;return f|0}else{g=2955600+(e*112|0)|0;break}}else{if(b>>>0>7){g=9763080;break}g=4749664+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c1W(){var b=0,d=0,e=0,f=0,g=0;c[2112956]=6864;c[2112954]=2852;b=dgh()|0;if((b|0)!=0){return b|0}if((c[2394]|0)==0){d=c[2112932]|0}else{c[2394]=0;e=c[3532596]|0;c[2112932]=e;f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];d=e}e=c[d+98360>>2]|0;if(e>>>0>9){a[e]=-128;a[e+1|0]=-107;a[e+2|0]=3;a[e+3|0]=72;g=d}else{gg[c[d+196808+(e<<2)>>2]&4095](8402944,-1786755069);g=c[2112932]|0}e=c[g+98360>>2]|0;if(e>>>0>9){a[e+4|0]=-121;a[e+5|0]=35;a[e+6|0]=101;a[e+7|0]=-112}else{gg[c[g+196808+(e<<2)>>2]&4095](8402948,596086885)}e=c[2394]|0;g=c[14130368+(e<<2)>>2]|0;if((g|0)!=0){gGC(g|0,9104152,280)|0}c[8452240+(e<<2)>>2]=c[2113054];c[2394]=-1;return b|0}function c1X(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>2){e=1;return e|0}else{f=2955600+(d*112|0)|0;break}}else{if(b>>>0>7){f=9763080;break}f=2954704+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c1Y(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>2){f=1;return f|0}else{g=2955600+(e*112|0)|0;break}}else{if(b>>>0>7){g=9763080;break}g=2954704+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c1Z(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>3){e=1;return e|0}else{f=1090096+(d*112|0)|0;break}}else{if(b>>>0>7){f=9763080;break}f=7354088+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c1_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>3){f=1;return f|0}else{g=1090096+(e*112|0)|0;break}}else{if(b>>>0>7){g=9763080;break}g=7354088+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c1$(){c[2112956]=3206;c[2112954]=6566;return dgh()|0}function c10(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>3){e=1;return e|0}else{f=1090096+(d*112|0)|0;break}}else{if(b>>>0>7){f=9763080;break}f=7038368+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c11(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>3){f=1;return f|0}else{g=1090096+(e*112|0)|0;break}}else{if(b>>>0>7){g=9763080;break}g=7038368+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c12(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>3){e=1;return e|0}else{f=1090096+(d*112|0)|0;break}}else{if(b>>>0>7){f=9763080;break}f=7037472+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c13(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>3){f=1;return f|0}else{g=1090096+(e*112|0)|0;break}}else{if(b>>>0>7){g=9763080;break}g=7037472+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c14(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>3){e=1;return e|0}else{f=1090096+(d*112|0)|0;break}}else{if(b>>>0>7){f=9763080;break}f=5832584+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c15(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>3){f=1;return f|0}else{g=1090096+(e*112|0)|0;break}}else{if(b>>>0>7){g=9763080;break}g=5832584+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c16(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>3){e=1;return e|0}else{f=1090096+(d*112|0)|0;break}}else{if(b>>>0>7){f=9763080;break}f=2717224+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c17(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>3){f=1;return f|0}else{g=1090096+(e*112|0)|0;break}}else{if(b>>>0>7){g=9763080;break}g=2717224+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c18(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>3){e=1;return e|0}else{f=1090096+(d*112|0)|0;break}}else{if(b>>>0>7){f=9763080;break}f=1519512+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c19(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>3){f=1;return f|0}else{g=1090096+(e*112|0)|0;break}}else{if(b>>>0>7){g=9763080;break}g=1519512+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c2a(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>3){e=1;return e|0}else{f=1090096+(d*112|0)|0;break}}else{if(b>>>0>7){f=9763080;break}f=1518616+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c2b(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>3){f=1;return f|0}else{g=1090096+(e*112|0)|0;break}}else{if(b>>>0>7){g=9763080;break}g=1518616+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c2c(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>3){e=1;return e|0}else{f=1102992+(d*112|0)|0;break}}else{if(b>>>0>6){f=9763080;break}f=5902464+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c2d(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>3){f=1;return f|0}else{g=1102992+(e*112|0)|0;break}}else{if(b>>>0>6){g=9763080;break}g=5902464+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c2e(){c[2112956]=2410;c[2112954]=6566;return dgh()|0}function c2f(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>4){f=9763080;break}f=4483544+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c2g(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>4){g=9763080;break}g=4483544+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c2h(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>4){f=9763080;break}f=4482984+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c2i(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>4){g=9763080;break}g=4482984+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c2j(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>4){f=9763080;break}f=4484104+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c2k(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>4){g=9763080;break}g=4484104+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c2l(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>7){f=9763080;break}f=2667784+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c2m(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>7){g=9763080;break}g=2667784+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c2n(){var a=0;c[2112956]=4962;c[2112954]=6806;c[2113094]=16141;a=dgh()|0;c[1744674]=608;return a|0}function c2o(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>7){f=9763080;break}f=1517720+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c2p(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>7){g=9763080;break}g=1517720+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c2q(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>9){f=9763080;break}f=2661416+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c2r(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>9){g=9763080;break}g=2661416+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c2s(){var a=0;c[2112956]=1744;c[2112954]=3876;c[2113094]=16141;a=dgh()|0;c[1744674]=608;return a|0}function c2t(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>9){f=9763080;break}f=2666664+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c2u(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>9){g=9763080;break}g=2666664+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c2v(){c[2112954]=12626;return dgh()|0}function c2w(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>9){f=9763080;break}f=1516600+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c2x(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>9){g=9763080;break}g=1516600+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c2y(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>9){f=9763080;break}f=1515480+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c2z(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>9){g=9763080;break}g=1515480+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c2A(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>9){f=9763080;break}f=1514360+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c2B(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>9){g=9763080;break}g=1514360+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c2C(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=b&127;if(d>>>0>5){e=1;return e|0}else{f=7343736+(d*112|0)|0;break}}else{if(b>>>0>11){f=9763080;break}f=5806808+(b*112|0)|0}}while(0);if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[f+100>>2];c[a+104>>2]=c[f+104>>2];c[a+108>>2]=c[f+108>>2];e=0;return e|0}function c2D(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0>127){e=b&127;if(e>>>0>5){f=1;return f|0}else{g=7343736+(e*112|0)|0;break}}else{if(b>>>0>11){g=9763080;break}g=5806808+(b*112|0)|0}}while(0);if((d|0)!=0){f=1;return f|0}c[a>>2]=g;f=0;return f|0}function c2E(){var a=0;c[2112954]=6806;c[2113094]=16141;a=dgh()|0;c[1744674]=608;return a|0}function c2F(){var e=0,f=0,g=0,h=0,i=0;e=c[3540934]|0;b[e+10386>>1]=257;b[e+10398>>1]=263;b[e+10404>>1]=264;b[e+10408>>1]=257;b[e+11250>>1]=18448;b[e+11252>>1]=-32754;b[e+11410>>1]=16399;b[e+11488>>1]=27678;b[e+11490>>1]=72;f=11496;do{g=e+(f|4)|0;h=e+(f|7)|0;i=((d[g]|0)<<8|(d[h]|0))-2528&65535;a[g]=(i&65535)>>>8&255;a[h]=i&255;f=f+8|0;}while((f|0)<11848);return}function c2G(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[3540942]|0;f=c[2113112]|0;if((f|0)>1){g=(f|0)/2|0;f=0;do{h=e+(f<<1)|0;i=(f&262272|0)!=128^b[h>>1];j=(f&16392|0)!=16392|(f&1572864|0)==0?i:i^2;i=(f&48|0)==16?j^4:j;j=(f&66|0)==66?i:i^8;i=(f&33024|0)==32768?j^16:j;j=(f&139268|0)==4?i:i^32;i=(f&71680|0)==65536?j:j^64;b[h>>1]=((f&2080|0)==2080?i^128:i)^(d[7347032+(f&255)|0]|0)<<8;f=f+1|0;}while((f|0)<(g|0))}g=c[3540934]|0;b[g+10386>>1]=257;b[g+10398>>1]=263;b[g+10404>>1]=264;b[g+10408>>1]=257;b[g+11250>>1]=18448;b[g+11252>>1]=-32754;b[g+11410>>1]=16399;b[g+11488>>1]=27678;b[g+11490>>1]=72;f=11496;do{e=g+(f|4)|0;i=g+(f|7)|0;h=((d[e]|0)<<8|(d[i]|0))-2528&65535;a[e]=(h&65535)>>>8&255;a[i]=h&255;f=f+8|0;}while((f|0)<11848);return}function c2H(){var a=0,e=0,f=0,g=0,h=0,i=0;a=c[3540910]|0;e=c[2113108]|0;if((e|0)>1){f=(e|0)/2|0;e=0;do{g=a+(e<<1)|0;h=(e&262272|0)!=128^b[g>>1];i=(e&1064968|0)==1064968?h^2:h;h=(e&524336|0)==524304?i^4:i;i=(e&66|0)==66?h:h^8;h=(e&33024|0)==32768?i^16:i;i=(e&8196|0)==4?h:h^32;h=(e&71680|0)==65536?i:i^64;b[g>>1]=((e&18464|0)==18464?h^128:h)^(d[7361832+(e>>>1&255)|0]|0)<<8;e=e+1|0;}while((e|0)<(f|0))}f=c[3540934]|0;e=f;a=0;do{b[e+(a<<1)>>1]=-226;b[e+((a|1)<<1)>>1]=-7889;a=a+2|0;}while((a|0)<8192);b[e>>1]=-12152;b[f+2>>1]=-6753;b[f+4>>1]=1664;b[f+6>>1]=-7264;b[f+8>>1]=-240;b[f+10>>1]=-7889;b[f+144>>1]=1024;b[f+146>>1]=4096;return}function c2I(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;a=c[3540942]|0;d=a;e=c[2113112]|0;if((e|0)<=1){f=a+200836|0;g=f;b[g>>1]=20115;h=a+201002|0;i=h;b[i>>1]=20115;j=a+201146|0;k=j;b[k>>1]=20115;return}l=(e|0)/2|0;e=0;do{m=d+(e<<1)|0;n=b[m>>1]|0;o=(e&133264|0)==0?n^2:n;n=(e&131072|0)==0;p=n|(e&5376|0)==5120?o:o^2;o=(e&132096|0)!=0|(e&8208|0)==8208?p:p^1024;b[m>>1]=n|(e&328|0)==320?o:o^1024;e=e+1|0;}while((e|0)<(l|0));f=a+200836|0;g=f;b[g>>1]=20115;h=a+201002|0;i=h;b[i>>1]=20115;j=a+201146|0;k=j;b[k>>1]=20115;return}function c2J(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;a=c[3540942]|0;d=a;e=c[2113112]|0;if((e|0)<=1){f=a+197312|0;g=f;b[g>>1]=20115;h=a+197478|0;i=h;b[i>>1]=20115;j=a+197622|0;k=j;b[k>>1]=20115;return}l=(e|0)/2|0;e=0;do{m=d+(e<<1)|0;n=b[m>>1]|0;o=(e&133264|0)==0?n^2:n;n=(e&131072|0)==0;p=n|(e&5376|0)==5120?o:o^2;o=(e&132096|0)!=0|(e&8208|0)==8208?p:p^1024;b[m>>1]=n|(e&328|0)==320?o:o^1024;e=e+1|0;}while((e|0)<(l|0));f=a+197312|0;g=f;b[g>>1]=20115;h=a+197478|0;i=h;b[i>>1]=20115;j=a+197622|0;k=j;b[k>>1]=20115;return}function c2K(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;a=c[3540942]|0;d=a;e=c[2113112]|0;if((e|0)<=1){f=a+197564|0;g=f;b[g>>1]=20115;h=a+197730|0;i=h;b[i>>1]=20115;j=a+197874|0;k=j;b[k>>1]=20115;return}l=(e|0)/2|0;e=0;do{m=d+(e<<1)|0;n=b[m>>1]|0;o=(e&133264|0)==0?n^2:n;n=(e&131072|0)==0;p=n|(e&5376|0)==5120?o:o^2;o=(e&132096|0)!=0|(e&8208|0)==8208?p:p^1024;b[m>>1]=n|(e&328|0)==320?o:o^1024;e=e+1|0;}while((e|0)<(l|0));f=a+197564|0;g=f;b[g>>1]=20115;h=a+197730|0;i=h;b[i>>1]=20115;j=a+197874|0;k=j;b[k>>1]=20115;return}function c2L(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;a=c[3540942]|0;d=a;e=c[2113112]|0;if((e|0)<=1){f=a+200856|0;g=f;b[g>>1]=20115;h=a+201022|0;i=h;b[i>>1]=20115;j=a+201166|0;k=j;b[k>>1]=20115;return}l=(e|0)/2|0;e=0;do{m=d+(e<<1)|0;n=b[m>>1]|0;o=(e&133264|0)==0?n^2:n;n=(e&131072|0)==0;p=n|(e&5376|0)==5120?o:o^2;o=(e&132096|0)!=0|(e&8208|0)==8208?p:p^1024;b[m>>1]=n|(e&328|0)==320?o:o^1024;e=e+1|0;}while((e|0)<(l|0));f=a+200856|0;g=f;b[g>>1]=20115;h=a+201022|0;i=h;b[i>>1]=20115;j=a+201166|0;k=j;b[k>>1]=20115;return}function c2M(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0;if((a[8452368]|0)==0){f=c[3532644]|0}else{g=c[3540926]|0;h=c[3532644]|0;i=0;do{j=e[g+(i<<1)>>1]|0;k=j>>>2&248;c[h+(i<<2)>>2]=j>>>7<<8&63488|j&31|(k>>>5|k)<<3&2016;i=i+1|0;}while((i|0)<2304);a[8452368]=0;f=h}c[f+9216>>2]=c[f+4092>>2];f=ag(c[2113070]|0,c[2113068]|0)|0;if((f|0)>0){h=c[2112926]|0;i=c[2443760]|0;g=c[3528926]|0;k=0;do{b[h+(k<<1)>>1]=2304;b[i+(k<<1)>>1]=0;a[g+k|0]=-1;k=k+1|0;}while((k|0)<(f|0))}f=c[3540918]|0;k=f+2560|0;g=c[3540908]|0;i=f;do{f=b[i+8>>1]|0;h=f&65535;if(f<<16>>16==0){break}f=e[i>>1]|0;j=f&2047;l=e[i+2>>1]|0;m=l&1023;n=f>>>11&15;o=f>>>15;p=l>>>11&15;q=l>>>15;r=e[i+4>>1]|0;s=r>>>8&31;t=r>>>13;u=h>>>9&63;v=r>>>7&1;w=h&511;h=(o|0)==0;x=(q|0)==0;y=(h?n:16-n|0)<<1;n=e[g+((y|2048)<<1)>>1]<<16|e[g+((y|2049)<<1)>>1];y=(x?p:16-p|0)<<1;p=e[g+((y|2048)<<1)>>1]<<16|e[g+((y|2049)<<1)>>1];y=j>>>0>1023?f|-2048:j;j=m>>>0>511?l|-1024:m;m=(r<<16&8323072|e[i+6>>1])<<1;L68583:do{if((u|0)!=0){if((p|n|0)==0){r=t&1;l=c[3540920]|0;f=c[3540922]|0;z=c[2113100]|0;A=c[2113104]|0;B=u<<4;C=s<<5;D=(r|0)!=0;if((w|0)==0){break}E=(t&2|0)==0;F=(y|0)>-1;G=y+B|0;H=B-1|0;I=y+H|0;J=v&255;K=w-1+j|0;L=(H>>>3)+1|0;H=B-8+y|0;M=c[3528926]|0;N=c[2443760]|0;O=m+4|0;P=(((d[l+(z&m+3)|0]<<24|d[l+(z&m+2)|0]<<16|d[l+(z&(m|1))|0]<<8|d[l+(z&m)|0])>>>2)*3|0)&A;Q=0;while(1){do{if(E){R=Q+j|0;S=c[2113070]|0;if((R|0)>=(S|0)){break L68583}if((R|0)>-1){T=c[2443760]|0;U=c[2113068]|0;V=ag(U,R)|0;W=R;X=T+(V<<1)|0;Y=(c[3528926]|0)+V|0;Z=S;_=U;$=58159;break}else{aa=M;ab=N;ac=R;ad=S;ae=c[2113068]|0;$=58157;break}}else{S=K-Q|0;if((S|0)<0){break L68583}R=c[2113070]|0;if((S|0)<(R|0)){U=c[2443760]|0;V=c[2113068]|0;T=ag(V,S)|0;W=S;X=U+(T<<1)|0;Y=(c[3528926]|0)+T|0;Z=R;_=V;$=58159;break}else{W=S;X=N;Y=M;Z=R;_=c[2113068]|0;$=58159;break}}}while(0);L68601:do{if(($|0)==58159){$=0;if(!((W|0)>-1&(W|0)<(Z|0)&F&(G|0)<(_|0))){aa=Y;ab=X;ac=W;ad=Z;ae=_;$=58157;break}if(D){R=O;S=P;V=0;while(1){T=H-V|0;U=(gF[c[1037888+(r<<10)+((a[l+(R&z)|0]&255)<<2)>>2]&2047](X+(T<<1)|0,Y+T|0,(c[3540922]|0)+(c[2113104]&S)|0,C,v)|0)+S|0;T=V+8|0;if((T|0)>=(B|0)){af=U;ah=Y;ai=X;break L68601}R=R+1|0;S=U;V=T}}else{V=O;S=P;R=0;while(1){T=R+y|0;U=(gF[c[1037888+((a[l+(V&z)|0]&255)<<2)>>2]&2047](X+(T<<1)|0,Y+T|0,(c[3540922]|0)+(c[2113104]&S)|0,C,v)|0)+S|0;T=R+8|0;if((T|0)>=(B|0)){af=U;ah=Y;ai=X;break L68601}V=V+1|0;S=U;R=T}}}}while(0);if(($|0)==58157){$=0;R=(ac|0)<0;S=ae+8|0;V=O;T=P;U=0;while(1){aj=a[l+(V&z)|0]|0;ak=aj&255^255;al=V+1|0;am=T&A;an=ak&65535;L68615:do{if((ac|0)>=(ad|0)|R|aj<<24>>24==-1){ao=(d[9540928+an|0]|0)+am|0}else{if(D){ap=I-U|0;if((ap|0)>=-7&(ap|0)<(S|0)){aq=ap;ar=ak;as=am;at=0}else{ao=(d[9540928+an|0]|0)+am|0;break}while(1){if((ar&1)==0){au=as}else{if((aq|0)>-1&(aq|0)<(ae|0)){b[ab+(aq<<1)>>1]=(d[f+as|0]|C)&65535;a[aa+aq|0]=J}au=as+1|0}ap=(ar&65535)>>>1;if(ap<<16>>16==0){ao=au;break L68615}av=at+1|0;if((av|0)<8){aq=aq-1|0;ar=ap;as=au;at=av}else{ao=au;break}}}else{av=U+y|0;if((av|0)>-8&(av|0)<(ae|0)){aw=av;ax=ak;ay=am;az=0}else{ao=(d[9540928+an|0]|0)+am|0;break}while(1){if((ax&1)==0){aA=ay}else{if((aw|0)>-1&(aw|0)<(ae|0)){b[ab+(aw<<1)>>1]=(d[f+ay|0]|C)&65535;a[aa+aw|0]=J}aA=ay+1|0}av=(ax&65535)>>>1;if(av<<16>>16==0){ao=aA;break L68615}ap=az+1|0;if((ap|0)<8){aw=aw+1|0;ax=av;ay=aA;az=ap}else{ao=aA;break}}}}}while(0);am=U+8|0;if((am|0)<(B|0)){V=al;T=ao;U=am}else{af=ao;ah=aa;ai=ab;break}}}U=Q+1|0;if((U|0)<(w|0)){M=ah;N=ai;O=L+O|0;P=af;Q=U}else{break L68583}}}Q=c[3540920]|0;P=c[2113100]|0;O=u<<4;L=s<<5;if((w|0)==0){break}N=O-1|0;M=(N>>>3)+1|0;B=m+4|0;J=c[2385352]|0;C=((d[Q+(P&m+3)|0]<<24|d[Q+(P&m+2)|0]<<16|d[Q+(P&(m|1))|0]<<8|d[Q+(P&m)|0])>>>2)*3|0;f=0;while(1){I=B;D=C;A=0;while(1){aB=(gp[c[2056088+((a[Q+(I&P)|0]&255)<<2)>>2]&16383](J+(A<<1)|0,(c[3540922]|0)+(c[2113104]&D)|0,L)|0)+D|0;z=A+8|0;if((z|0)>=(O|0)){break}I=I+1|0;D=aB;A=z}A=f+1|0;if((A|0)<(w|0)){B=M+B|0;J=J+(O<<1)|0;C=aB;f=A}else{break}}f=(q|0)==1;C=t&2;J=(C|0)!=0;B=w-1|0;M=(t&1|0)==0;L=(o|0)==1;P=v&255;Q=j+1|0;A=(C|0)==0;C=c[2443760]|0;D=c[2113068]|0;I=c[3528926]|0;z=c[2385352]|0;l=0;r=0;H=0;while(1){G=(1<<(r&31)&p|0)!=0;do{if(G&f){F=l+j|0;K=ag(J?H+B|0:r,O)|0;L68658:do{if(F>>>0<224){E=ag(D,F)|0;U=0;T=0;V=0;while(1){if((V|0)>=(O|0)){break L68658}S=b[z+((M?V:N-V|0)+K<<1)>>1]|0;R=S&65535;am=(1<<(V&31)&n|0)!=0;do{if(am&L){an=T+y|0;do{if((R&32768|0)==0){if((an|0)>-1&(an|0)<(D|0)){ak=an+E|0;b[C+(ak<<1)>>1]=S;a[I+ak|0]=P}ak=an+1|0;if(!((ak|0)>-1&(ak|0)<(D|0))){aC=ak;break}aj=ak+E|0;b[C+(aj<<1)>>1]=S;a[I+aj|0]=P;aC=ak}else{aC=an}}while(0);aD=aC;aE=T+2|0}else{if(am&h){aD=U;aE=T;break}an=T+y|0;if((R&32768|0)==0&(an|0)>-1&(an|0)<(D|0)){ak=an+E|0;b[C+(ak<<1)>>1]=S;a[I+ak|0]=P}aD=an;aE=T+1|0}}while(0);if((aD|0)==(D|0)){break}else{U=aD;T=aE;V=V+1|0}}}}while(0);F=Q+l|0;L68679:do{if(F>>>0<224){al=ag(D,F)|0;V=0;T=0;U=0;while(1){if((U|0)>=(O|0)){break L68679}E=b[z+((M?U:N-U|0)+K<<1)>>1]|0;S=E&65535;R=(1<<(U&31)&n|0)!=0;do{if(R&L){am=T+y|0;do{if((S&32768|0)==0){if((am|0)>-1&(am|0)<(D|0)){an=am+al|0;b[C+(an<<1)>>1]=E;a[I+an|0]=P}an=am+1|0;if(!((an|0)>-1&(an|0)<(D|0))){aF=an;break}ak=an+al|0;b[C+(ak<<1)>>1]=E;a[I+ak|0]=P;aF=an}else{aF=am}}while(0);aG=aF;aH=T+2|0}else{if(R&h){aG=V;aH=T;break}am=T+y|0;if((S&32768|0)==0&(am|0)>-1&(am|0)<(D|0)){an=am+al|0;b[C+(an<<1)>>1]=E;a[I+an|0]=P}aG=am;aH=T+1|0}}while(0);if((aG|0)==(D|0)){break}else{V=aG;T=aH;U=U+1|0}}}}while(0);aI=(F|0)==224?w:r;aJ=l+2|0}else{if(G&x){aI=r;aJ=l;break}K=l+j|0;U=ag(A?r:H+B|0,O)|0;L68702:do{if(K>>>0<224){T=ag(D,K)|0;V=0;al=0;E=0;while(1){if((E|0)>=(O|0)){break L68702}S=b[z+((M?E:N-E|0)+U<<1)>>1]|0;R=S&65535;am=(1<<(E&31)&n|0)!=0;do{if(am&L){an=al+y|0;do{if((R&32768|0)==0){if((an|0)>-1&(an|0)<(D|0)){ak=an+T|0;b[C+(ak<<1)>>1]=S;a[I+ak|0]=P}ak=an+1|0;if(!((ak|0)>-1&(ak|0)<(D|0))){aK=ak;break}aj=ak+T|0;b[C+(aj<<1)>>1]=S;a[I+aj|0]=P;aK=ak}else{aK=an}}while(0);aL=aK;aM=al+2|0}else{if(am&h){aL=V;aM=al;break}an=al+y|0;if((R&32768|0)==0&(an|0)>-1&(an|0)<(D|0)){ak=an+T|0;b[C+(ak<<1)>>1]=S;a[I+ak|0]=P}aL=an;aM=al+1|0}}while(0);if((aL|0)==(D|0)){break}else{V=aL;al=aM;E=E+1|0}}}}while(0);aI=(K|0)==224?w:r;aJ=l+1|0}}while(0);G=aI+1|0;if((G|0)<(w|0)){l=aJ;r=G;H=~aI}else{break}}}}while(0);i=i+10|0;}while(k>>>0>i>>>0);i=c[2112926]|0;k=c[2443760]|0;aI=c[3528926]|0;aJ=c[2113068]|0;aM=c[2113070]|0;aL=(ag(aM,aJ)|0)>0;if(aL){aK=0;do{if((a[aI+aK|0]|0)==1){b[i+(aK<<1)>>1]=b[k+(aK<<1)>>1]|0}aK=aK+1|0;}while((aK|0)<(ag(aJ,aM)|0))}aK=c[3540928]|0;aH=aK;aG=c[3540924]|0;aF=c[3540908]|0;aE=b[aF+8192>>1]|0;aD=b[aF+12288>>1]|0;aC=0;while(1){if((aC|0)>=224){$=58252;break}aN=b[aG>>1]|0;if(aN<<16>>16==(b[aG+(aC<<1)>>1]|0)){aC=aC+1|0}else{$=58251;break}}L68736:do{if(($|0)==58251){aC=c[2385474]|0;aB=c[2385206]|0;af=c[3540914]|0;ai=0;ah=i;ab=aN;while(1){aa=(ab&65535)+aD|0;ao=ai+aE|0;aA=aa&31;az=ao<<2&1920;ay=0;do{ax=ay-aA|0;if((ax|0)>=(aJ|0)){break}aw=(ay+aa|0)>>>4&126|az;ae=e[aH+(aw<<1)>>1]|0;L68743:do{if((ae|0)<(aC|0)){if((a[aB+ae|0]|0)==0){break}au=e[aH+((aw|1)<<1)>>1]|0;at=au<<4&992|1024;as=-(au>>>6&1)&31;ar=(ao^-(au>>>7&1))<<5&992|ae<<10;if(ax>>>0<416){au=ax;aq=0;while(1){ad=a[af+((aq^as)+ar)|0]|0;if(ad<<24>>24!=31){b[ah+(au<<1)>>1]=(ad&255|at)&65535}ad=aq+1|0;if((ad|0)<32){au=au+1|0;aq=ad}else{break L68743}}}else{aO=ax;aP=0}while(1){do{if((aO|0)>=0){if((aO|0)>=(aJ|0)){break L68743}aq=a[af+((aP^as)+ar)|0]|0;if(aq<<24>>24==31){break}b[ah+(aO<<1)>>1]=(aq&255|at)&65535}}while(0);aq=aP+1|0;if((aq|0)<32){aO=aO+1|0;aP=aq}else{break}}}}while(0);ay=ay+32|0;}while((ay|0)<480);ay=ai+1|0;if((ay|0)>=224){break L68736}ai=ay;ah=ah+(aJ<<1)|0;ab=b[aG+(ay<<1)>>1]|0}}else if(($|0)==58252){ab=aE&511;ah=aD&2047;ai=c[2385474]|0;af=c[2385206]|0;aB=c[3540914]|0;aC=0;do{ay=(aC<<5&2016)-ah|0;ao=(ay|0)<-31?ay+2048|0:ay;ay=(aC>>6<<5)-ab|0;az=(ay|0)<-31?ay+512|0:ay;L68765:do{if((ao|0)<(aJ|0)&(az|0)<(aM|0)){ay=e[aK+(aC<<2)>>1]|0;if((ay|0)>=(ai|0)){break}aa=a[af+ay|0]|0;if(aa<<24>>24==0){break}aA=e[aH+((aC<<1|1)<<1)>>1]|0;ax=aA>>>1&31|32;ae=aA&128;aw=aA&64;do{if((ao|az|0)>=0){if((ao|0)>=(aJ-32|0)){break}if((az|0)>=(aM-32|0)){break}aA=(ae|0)!=0;at=(aw|0)!=0;if((aa&2)==0){if(aA){if(at){S0(i,ay,ao,az,ax,5,31,aB);break L68765}else{S_(i,ay,ao,az,ax,5,31,aB);break L68765}}else{if(at){SY(i,ay,ao,az,ax,5,31,0,aB);break L68765}else{SW(i,ay,ao,az,ax,5,31,0,aB);break L68765}}}else{if(aA){if(at){SU(i,ay,ao,az,ax,5,aB);break L68765}else{SS(i,ay,ao,az,ax,5,aB);break L68765}}else{if(at){SQ(i,ay,ao,az,ax,5,aB);break L68765}else{SO(i,ay,ao,az,ax,5,aB);break L68765}}}}}while(0);at=(ae|0)!=0;aA=(aw|0)!=0;if((aa&2)==0){if(at){if(aA){S1(i,ay,ao,az,ax,5,31,0,aB);break}else{S$(i,ay,ao,az,ax,5,31,0,aB);break}}else{if(aA){SZ(i,ay,ao,az,ax,5,31,0,aB);break}else{SX(i,ay,ao,az,ax,5,31,0,aB);break}}}else{if(at){if(aA){SV(i,ay,ao,az,ax,5,0,aB);break}else{ST(i,ay,ao,az,ax,5,0,aB);break}}else{if(aA){SR(i,ay,ao,az,ax,5,0,aB);break}else{SP(i,ay,ao,az,ax,5,0,aB);break}}}}}while(0);aC=aC+1|0;}while((aC|0)<1024)}}while(0);if(aL){aL=0;do{if((a[aI+aL|0]|0)==0){b[i+(aL<<1)>>1]=b[k+(aL<<1)>>1]|0}aL=aL+1|0;}while((aL|0)<(ag(aJ,aM)|0))}aL=c[3540912]|0;k=aL;aI=b[aF+24576>>1]&511;aH=b[aF+20480>>1]&255;aF=c[2385220]|0;aK=c[3540916]|0;aD=0;do{aE=aD<<1;$=e[aL+(aD<<2)>>1]|0;aG=a[aF+$|0]|0;L68827:do{if(aG<<24>>24!=0){aP=(aD<<3&504)-aI|0;aO=(aP|0)<-7?aP+512|0:aP;aP=(aD>>6<<3)-aH|0;aN=(aP|0)<-7?aP+256|0:aP;if(!((aO|0)<(aJ|0)&(aN|0)<(aM|0))){break}aP=e[k+((aE|1)<<1)>>1]|0;aC=aP>>>1&31|128;aB=aP&64;af=aP&128;do{if((aO|aN|0)>=0){if((aO|0)>=(aJ-8|0)){break}if((aN|0)>=(aM-8|0)){break}aP=(af|0)!=0;ai=(aB|0)!=0;if((aG&2)==0){if(aP){if(ai){Sw(i,$,aO,aN,aC,4,15,0,aK);break L68827}else{Su(i,$,aO,aN,aC,4,15,0,aK);break L68827}}else{if(ai){Ss(i,$,aO,aN,aC,4,15,0,aK);break L68827}else{Sq(i,$,aO,aN,aC,4,15,0,aK);break L68827}}}else{if(aP){if(ai){So(i,$,aO,aN,aC,4,0,aK);break L68827}else{Sm(i,$,aO,aN,aC,4,0,aK);break L68827}}else{if(ai){Sk(i,$,aO,aN,aC,4,0,aK);break L68827}else{Si(i,$,aO,aN,aC,4,0,aK);break L68827}}}}}while(0);ai=(af|0)!=0;aP=(aB|0)!=0;if((aG&2)==0){if(ai){if(aP){Sx(i,$,aO,aN,aC,4,15,0,aK);break}else{Sv(i,$,aO,aN,aC,4,15,0,aK);break}}else{if(aP){St(i,$,aO,aN,aC,4,15,0,aK);break}else{Sr(i,$,aO,aN,aC,4,15,0,aK);break}}}else{if(ai){if(aP){Sp(i,$,aO,aN,aC,4,0,aK);break}else{Sn(i,$,aO,aN,aC,4,0,aK);break}}else{if(aP){Sl(i,$,aO,aN,aC,4,0,aK);break}else{Sj(i,$,aO,aN,aC,4,0,aK);break}}}}}while(0);aD=aD+1|0;}while((aD|0)<2048);R8(c[3532644]|0);return 0}function c2N(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=(d[c+1|0]|0)+e&65535;b[a+4>>1]=(d[c+2|0]|0)+e&65535;b[a+6>>1]=(d[c+3|0]|0)+e&65535;b[a+8>>1]=(d[c+4|0]|0)+e&65535;b[a+10>>1]=(d[c+5|0]|0)+e&65535;b[a+12>>1]=(d[c+6|0]|0)+e&65535;b[a+14>>1]=(d[c+7|0]|0)+e&65535;return 8}function c2O(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=(d[c]|0)+e&65535;b[a+4>>1]=(d[c+1|0]|0)+e&65535;b[a+6>>1]=(d[c+2|0]|0)+e&65535;b[a+8>>1]=(d[c+3|0]|0)+e&65535;b[a+10>>1]=(d[c+4|0]|0)+e&65535;b[a+12>>1]=(d[c+5|0]|0)+e&65535;b[a+14>>1]=(d[c+6|0]|0)+e&65535;return 7}function c2P(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=-32768;b[a+4>>1]=(d[c+1|0]|0)+e&65535;b[a+6>>1]=(d[c+2|0]|0)+e&65535;b[a+8>>1]=(d[c+3|0]|0)+e&65535;b[a+10>>1]=(d[c+4|0]|0)+e&65535;b[a+12>>1]=(d[c+5|0]|0)+e&65535;b[a+14>>1]=(d[c+6|0]|0)+e&65535;return 7}function c2Q(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=-32768;b[a+4>>1]=(d[c]|0)+e&65535;b[a+6>>1]=(d[c+1|0]|0)+e&65535;b[a+8>>1]=(d[c+2|0]|0)+e&65535;b[a+10>>1]=(d[c+3|0]|0)+e&65535;b[a+12>>1]=(d[c+4|0]|0)+e&65535;b[a+14>>1]=(d[c+5|0]|0)+e&65535;return 6}function c2R(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=(d[c+1|0]|0)+e&65535;b[a+4>>1]=-32768;b[a+6>>1]=(d[c+2|0]|0)+e&65535;b[a+8>>1]=(d[c+3|0]|0)+e&65535;b[a+10>>1]=(d[c+4|0]|0)+e&65535;b[a+12>>1]=(d[c+5|0]|0)+e&65535;b[a+14>>1]=(d[c+6|0]|0)+e&65535;return 7}function c2S(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=(d[c]|0)+e&65535;b[a+4>>1]=-32768;b[a+6>>1]=(d[c+1|0]|0)+e&65535;b[a+8>>1]=(d[c+2|0]|0)+e&65535;b[a+10>>1]=(d[c+3|0]|0)+e&65535;b[a+12>>1]=(d[c+4|0]|0)+e&65535;b[a+14>>1]=(d[c+5|0]|0)+e&65535;return 6}function c2T(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=-32768;b[a+4>>1]=-32768;b[a+6>>1]=(d[c+1|0]|0)+e&65535;b[a+8>>1]=(d[c+2|0]|0)+e&65535;b[a+10>>1]=(d[c+3|0]|0)+e&65535;b[a+12>>1]=(d[c+4|0]|0)+e&65535;b[a+14>>1]=(d[c+5|0]|0)+e&65535;return 6}function c2U(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=-32768;b[a+4>>1]=-32768;b[a+6>>1]=(d[c]|0)+e&65535;b[a+8>>1]=(d[c+1|0]|0)+e&65535;b[a+10>>1]=(d[c+2|0]|0)+e&65535;b[a+12>>1]=(d[c+3|0]|0)+e&65535;b[a+14>>1]=(d[c+4|0]|0)+e&65535;return 5}function c2V(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=(d[c+1|0]|0)+e&65535;b[a+4>>1]=(d[c+2|0]|0)+e&65535;b[a+6>>1]=-32768;b[a+8>>1]=(d[c+3|0]|0)+e&65535;b[a+10>>1]=(d[c+4|0]|0)+e&65535;b[a+12>>1]=(d[c+5|0]|0)+e&65535;b[a+14>>1]=(d[c+6|0]|0)+e&65535;return 7}function c2W(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=(d[c]|0)+e&65535;b[a+4>>1]=(d[c+1|0]|0)+e&65535;b[a+6>>1]=-32768;b[a+8>>1]=(d[c+2|0]|0)+e&65535;b[a+10>>1]=(d[c+3|0]|0)+e&65535;b[a+12>>1]=(d[c+4|0]|0)+e&65535;b[a+14>>1]=(d[c+5|0]|0)+e&65535;return 6}function c2X(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=-32768;b[a+4>>1]=(d[c+1|0]|0)+e&65535;b[a+6>>1]=-32768;b[a+8>>1]=(d[c+2|0]|0)+e&65535;b[a+10>>1]=(d[c+3|0]|0)+e&65535;b[a+12>>1]=(d[c+4|0]|0)+e&65535;b[a+14>>1]=(d[c+5|0]|0)+e&65535;return 6}function c2Y(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=-32768;b[a+4>>1]=(d[c]|0)+e&65535;b[a+6>>1]=-32768;b[a+8>>1]=(d[c+1|0]|0)+e&65535;b[a+10>>1]=(d[c+2|0]|0)+e&65535;b[a+12>>1]=(d[c+3|0]|0)+e&65535;b[a+14>>1]=(d[c+4|0]|0)+e&65535;return 5}function c2Z(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=(d[c+1|0]|0)+e&65535;b[a+4>>1]=-32768;b[a+6>>1]=-32768;b[a+8>>1]=(d[c+2|0]|0)+e&65535;b[a+10>>1]=(d[c+3|0]|0)+e&65535;b[a+12>>1]=(d[c+4|0]|0)+e&65535;b[a+14>>1]=(d[c+5|0]|0)+e&65535;return 6}function c2_(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=(d[c]|0)+e&65535;b[a+4>>1]=-32768;b[a+6>>1]=-32768;b[a+8>>1]=(d[c+1|0]|0)+e&65535;b[a+10>>1]=(d[c+2|0]|0)+e&65535;b[a+12>>1]=(d[c+3|0]|0)+e&65535;b[a+14>>1]=(d[c+4|0]|0)+e&65535;return 5}function c2$(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=-32768;b[a+4>>1]=-32768;b[a+6>>1]=-32768;b[a+8>>1]=(d[c+1|0]|0)+e&65535;b[a+10>>1]=(d[c+2|0]|0)+e&65535;b[a+12>>1]=(d[c+3|0]|0)+e&65535;b[a+14>>1]=(d[c+4|0]|0)+e&65535;return 5}function c20(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=-32768;b[a+4>>1]=-32768;b[a+6>>1]=-32768;b[a+8>>1]=(d[c]|0)+e&65535;b[a+10>>1]=(d[c+1|0]|0)+e&65535;b[a+12>>1]=(d[c+2|0]|0)+e&65535;b[a+14>>1]=(d[c+3|0]|0)+e&65535;return 4}function c21(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=(d[c+1|0]|0)+e&65535;b[a+4>>1]=(d[c+2|0]|0)+e&65535;b[a+6>>1]=(d[c+3|0]|0)+e&65535;b[a+8>>1]=-32768;b[a+10>>1]=(d[c+4|0]|0)+e&65535;b[a+12>>1]=(d[c+5|0]|0)+e&65535;b[a+14>>1]=(d[c+6|0]|0)+e&65535;return 7}function c22(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=(d[c]|0)+e&65535;b[a+4>>1]=(d[c+1|0]|0)+e&65535;b[a+6>>1]=(d[c+2|0]|0)+e&65535;b[a+8>>1]=-32768;b[a+10>>1]=(d[c+3|0]|0)+e&65535;b[a+12>>1]=(d[c+4|0]|0)+e&65535;b[a+14>>1]=(d[c+5|0]|0)+e&65535;return 6}function c23(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=-32768;b[a+4>>1]=(d[c+1|0]|0)+e&65535;b[a+6>>1]=(d[c+2|0]|0)+e&65535;b[a+8>>1]=-32768;b[a+10>>1]=(d[c+3|0]|0)+e&65535;b[a+12>>1]=(d[c+4|0]|0)+e&65535;b[a+14>>1]=(d[c+5|0]|0)+e&65535;return 6}function c24(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=-32768;b[a+4>>1]=(d[c]|0)+e&65535;b[a+6>>1]=(d[c+1|0]|0)+e&65535;b[a+8>>1]=-32768;b[a+10>>1]=(d[c+2|0]|0)+e&65535;b[a+12>>1]=(d[c+3|0]|0)+e&65535;b[a+14>>1]=(d[c+4|0]|0)+e&65535;return 5}function c25(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=(d[c+1|0]|0)+e&65535;b[a+4>>1]=-32768;b[a+6>>1]=(d[c+2|0]|0)+e&65535;b[a+8>>1]=-32768;b[a+10>>1]=(d[c+3|0]|0)+e&65535;b[a+12>>1]=(d[c+4|0]|0)+e&65535;b[a+14>>1]=(d[c+5|0]|0)+e&65535;return 6}function c26(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=(d[c]|0)+e&65535;b[a+4>>1]=-32768;b[a+6>>1]=(d[c+1|0]|0)+e&65535;b[a+8>>1]=-32768;b[a+10>>1]=(d[c+2|0]|0)+e&65535;b[a+12>>1]=(d[c+3|0]|0)+e&65535;b[a+14>>1]=(d[c+4|0]|0)+e&65535;return 5}function c27(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=-32768;b[a+4>>1]=-32768;b[a+6>>1]=(d[c+1|0]|0)+e&65535;b[a+8>>1]=-32768;b[a+10>>1]=(d[c+2|0]|0)+e&65535;b[a+12>>1]=(d[c+3|0]|0)+e&65535;b[a+14>>1]=(d[c+4|0]|0)+e&65535;return 5}function c28(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=-32768;b[a+4>>1]=-32768;b[a+6>>1]=(d[c]|0)+e&65535;b[a+8>>1]=-32768;b[a+10>>1]=(d[c+1|0]|0)+e&65535;b[a+12>>1]=(d[c+2|0]|0)+e&65535;b[a+14>>1]=(d[c+3|0]|0)+e&65535;return 4}function c29(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=(d[c+1|0]|0)+e&65535;b[a+4>>1]=(d[c+2|0]|0)+e&65535;b[a+6>>1]=-32768;b[a+8>>1]=-32768;b[a+10>>1]=(d[c+3|0]|0)+e&65535;b[a+12>>1]=(d[c+4|0]|0)+e&65535;b[a+14>>1]=(d[c+5|0]|0)+e&65535;return 6}function c3a(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=(d[c]|0)+e&65535;b[a+4>>1]=(d[c+1|0]|0)+e&65535;b[a+6>>1]=-32768;b[a+8>>1]=-32768;b[a+10>>1]=(d[c+2|0]|0)+e&65535;b[a+12>>1]=(d[c+3|0]|0)+e&65535;b[a+14>>1]=(d[c+4|0]|0)+e&65535;return 5}function c3b(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=-32768;b[a+4>>1]=(d[c+1|0]|0)+e&65535;b[a+6>>1]=-32768;b[a+8>>1]=-32768;b[a+10>>1]=(d[c+2|0]|0)+e&65535;b[a+12>>1]=(d[c+3|0]|0)+e&65535;b[a+14>>1]=(d[c+4|0]|0)+e&65535;return 5}function c3c(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=-32768;b[a+4>>1]=(d[c]|0)+e&65535;b[a+6>>1]=-32768;b[a+8>>1]=-32768;b[a+10>>1]=(d[c+1|0]|0)+e&65535;b[a+12>>1]=(d[c+2|0]|0)+e&65535;b[a+14>>1]=(d[c+3|0]|0)+e&65535;return 4}function c3d(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=(d[c+1|0]|0)+e&65535;b[a+4>>1]=-32768;b[a+6>>1]=-32768;b[a+8>>1]=-32768;b[a+10>>1]=(d[c+2|0]|0)+e&65535;b[a+12>>1]=(d[c+3|0]|0)+e&65535;b[a+14>>1]=(d[c+4|0]|0)+e&65535;return 5}function c3e(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=(d[c]|0)+e&65535;b[a+4>>1]=-32768;b[a+6>>1]=-32768;b[a+8>>1]=-32768;b[a+10>>1]=(d[c+1|0]|0)+e&65535;b[a+12>>1]=(d[c+2|0]|0)+e&65535;b[a+14>>1]=(d[c+3|0]|0)+e&65535;return 4}function c3f(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=-32768;b[a+4>>1]=-32768;b[a+6>>1]=-32768;b[a+8>>1]=-32768;b[a+10>>1]=(d[c+1|0]|0)+e&65535;b[a+12>>1]=(d[c+2|0]|0)+e&65535;b[a+14>>1]=(d[c+3|0]|0)+e&65535;return 4}function c3g(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=-32768;b[a+4>>1]=-32768;b[a+6>>1]=-32768;b[a+8>>1]=-32768;b[a+10>>1]=(d[c]|0)+e&65535;b[a+12>>1]=(d[c+1|0]|0)+e&65535;b[a+14>>1]=(d[c+2|0]|0)+e&65535;return 3}function c3h(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=(d[c+1|0]|0)+e&65535;b[a+4>>1]=(d[c+2|0]|0)+e&65535;b[a+6>>1]=(d[c+3|0]|0)+e&65535;b[a+8>>1]=(d[c+4|0]|0)+e&65535;b[a+10>>1]=-32768;b[a+12>>1]=(d[c+5|0]|0)+e&65535;b[a+14>>1]=(d[c+6|0]|0)+e&65535;return 7}function c3i(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=(d[c]|0)+e&65535;b[a+4>>1]=(d[c+1|0]|0)+e&65535;b[a+6>>1]=(d[c+2|0]|0)+e&65535;b[a+8>>1]=(d[c+3|0]|0)+e&65535;b[a+10>>1]=-32768;b[a+12>>1]=(d[c+4|0]|0)+e&65535;b[a+14>>1]=(d[c+5|0]|0)+e&65535;return 6}function c3j(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=-32768;b[a+4>>1]=(d[c+1|0]|0)+e&65535;b[a+6>>1]=(d[c+2|0]|0)+e&65535;b[a+8>>1]=(d[c+3|0]|0)+e&65535;b[a+10>>1]=-32768;b[a+12>>1]=(d[c+4|0]|0)+e&65535;b[a+14>>1]=(d[c+5|0]|0)+e&65535;return 6}function c3k(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=-32768;b[a+4>>1]=(d[c]|0)+e&65535;b[a+6>>1]=(d[c+1|0]|0)+e&65535;b[a+8>>1]=(d[c+2|0]|0)+e&65535;b[a+10>>1]=-32768;b[a+12>>1]=(d[c+3|0]|0)+e&65535;b[a+14>>1]=(d[c+4|0]|0)+e&65535;return 5}function c3l(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=(d[c+1|0]|0)+e&65535;b[a+4>>1]=-32768;b[a+6>>1]=(d[c+2|0]|0)+e&65535;b[a+8>>1]=(d[c+3|0]|0)+e&65535;b[a+10>>1]=-32768;b[a+12>>1]=(d[c+4|0]|0)+e&65535;b[a+14>>1]=(d[c+5|0]|0)+e&65535;return 6}function c3m(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=(d[c]|0)+e&65535;b[a+4>>1]=-32768;b[a+6>>1]=(d[c+1|0]|0)+e&65535;b[a+8>>1]=(d[c+2|0]|0)+e&65535;b[a+10>>1]=-32768;b[a+12>>1]=(d[c+3|0]|0)+e&65535;b[a+14>>1]=(d[c+4|0]|0)+e&65535;return 5}function c3n(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=-32768;b[a+4>>1]=-32768;b[a+6>>1]=(d[c+1|0]|0)+e&65535;b[a+8>>1]=(d[c+2|0]|0)+e&65535;b[a+10>>1]=-32768;b[a+12>>1]=(d[c+3|0]|0)+e&65535;b[a+14>>1]=(d[c+4|0]|0)+e&65535;return 5}function c3o(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=-32768;b[a+4>>1]=-32768;b[a+6>>1]=(d[c]|0)+e&65535;b[a+8>>1]=(d[c+1|0]|0)+e&65535;b[a+10>>1]=-32768;b[a+12>>1]=(d[c+2|0]|0)+e&65535;b[a+14>>1]=(d[c+3|0]|0)+e&65535;return 4}function c3p(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=(d[c+1|0]|0)+e&65535;b[a+4>>1]=(d[c+2|0]|0)+e&65535;b[a+6>>1]=-32768;b[a+8>>1]=(d[c+3|0]|0)+e&65535;b[a+10>>1]=-32768;b[a+12>>1]=(d[c+4|0]|0)+e&65535;b[a+14>>1]=(d[c+5|0]|0)+e&65535;return 6}function c3q(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=(d[c]|0)+e&65535;b[a+4>>1]=(d[c+1|0]|0)+e&65535;b[a+6>>1]=-32768;b[a+8>>1]=(d[c+2|0]|0)+e&65535;b[a+10>>1]=-32768;b[a+12>>1]=(d[c+3|0]|0)+e&65535;b[a+14>>1]=(d[c+4|0]|0)+e&65535;return 5}function c3r(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=-32768;b[a+4>>1]=(d[c+1|0]|0)+e&65535;b[a+6>>1]=-32768;b[a+8>>1]=(d[c+2|0]|0)+e&65535;b[a+10>>1]=-32768;b[a+12>>1]=(d[c+3|0]|0)+e&65535;b[a+14>>1]=(d[c+4|0]|0)+e&65535;return 5}function c3s(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=-32768;b[a+4>>1]=(d[c]|0)+e&65535;b[a+6>>1]=-32768;b[a+8>>1]=(d[c+1|0]|0)+e&65535;b[a+10>>1]=-32768;b[a+12>>1]=(d[c+2|0]|0)+e&65535;b[a+14>>1]=(d[c+3|0]|0)+e&65535;return 4}function c3t(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=(d[c+1|0]|0)+e&65535;b[a+4>>1]=-32768;b[a+6>>1]=-32768;b[a+8>>1]=(d[c+2|0]|0)+e&65535;b[a+10>>1]=-32768;b[a+12>>1]=(d[c+3|0]|0)+e&65535;b[a+14>>1]=(d[c+4|0]|0)+e&65535;return 5}function c3u(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=(d[c]|0)+e&65535;b[a+4>>1]=-32768;b[a+6>>1]=-32768;b[a+8>>1]=(d[c+1|0]|0)+e&65535;b[a+10>>1]=-32768;b[a+12>>1]=(d[c+2|0]|0)+e&65535;b[a+14>>1]=(d[c+3|0]|0)+e&65535;return 4}function c3v(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=-32768;b[a+4>>1]=-32768;b[a+6>>1]=-32768;b[a+8>>1]=(d[c+1|0]|0)+e&65535;b[a+10>>1]=-32768;b[a+12>>1]=(d[c+2|0]|0)+e&65535;b[a+14>>1]=(d[c+3|0]|0)+e&65535;return 4}function c3w(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=-32768;b[a+4>>1]=-32768;b[a+6>>1]=-32768;b[a+8>>1]=(d[c]|0)+e&65535;b[a+10>>1]=-32768;b[a+12>>1]=(d[c+1|0]|0)+e&65535;b[a+14>>1]=(d[c+2|0]|0)+e&65535;return 3}function c3x(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=(d[c+1|0]|0)+e&65535;b[a+4>>1]=(d[c+2|0]|0)+e&65535;b[a+6>>1]=(d[c+3|0]|0)+e&65535;b[a+8>>1]=-32768;b[a+10>>1]=-32768;b[a+12>>1]=(d[c+4|0]|0)+e&65535;b[a+14>>1]=(d[c+5|0]|0)+e&65535;return 6}function c3y(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=(d[c]|0)+e&65535;b[a+4>>1]=(d[c+1|0]|0)+e&65535;b[a+6>>1]=(d[c+2|0]|0)+e&65535;b[a+8>>1]=-32768;b[a+10>>1]=-32768;b[a+12>>1]=(d[c+3|0]|0)+e&65535;b[a+14>>1]=(d[c+4|0]|0)+e&65535;return 5}function c3z(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=-32768;b[a+4>>1]=(d[c+1|0]|0)+e&65535;b[a+6>>1]=(d[c+2|0]|0)+e&65535;b[a+8>>1]=-32768;b[a+10>>1]=-32768;b[a+12>>1]=(d[c+3|0]|0)+e&65535;b[a+14>>1]=(d[c+4|0]|0)+e&65535;return 5}function c3A(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=-32768;b[a+4>>1]=(d[c]|0)+e&65535;b[a+6>>1]=(d[c+1|0]|0)+e&65535;b[a+8>>1]=-32768;b[a+10>>1]=-32768;b[a+12>>1]=(d[c+2|0]|0)+e&65535;b[a+14>>1]=(d[c+3|0]|0)+e&65535;return 4}function c3B(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=(d[c+1|0]|0)+e&65535;b[a+4>>1]=-32768;b[a+6>>1]=(d[c+2|0]|0)+e&65535;b[a+8>>1]=-32768;b[a+10>>1]=-32768;b[a+12>>1]=(d[c+3|0]|0)+e&65535;b[a+14>>1]=(d[c+4|0]|0)+e&65535;return 5}function c3C(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=(d[c]|0)+e&65535;b[a+4>>1]=-32768;b[a+6>>1]=(d[c+1|0]|0)+e&65535;b[a+8>>1]=-32768;b[a+10>>1]=-32768;b[a+12>>1]=(d[c+2|0]|0)+e&65535;b[a+14>>1]=(d[c+3|0]|0)+e&65535;return 4}function c3D(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=-32768;b[a+4>>1]=-32768;b[a+6>>1]=(d[c+1|0]|0)+e&65535;b[a+8>>1]=-32768;b[a+10>>1]=-32768;b[a+12>>1]=(d[c+2|0]|0)+e&65535;b[a+14>>1]=(d[c+3|0]|0)+e&65535;return 4}function c3E(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=-32768;b[a+4>>1]=-32768;b[a+6>>1]=(d[c]|0)+e&65535;b[a+8>>1]=-32768;b[a+10>>1]=-32768;b[a+12>>1]=(d[c+1|0]|0)+e&65535;b[a+14>>1]=(d[c+2|0]|0)+e&65535;return 3}function c3F(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=(d[c+1|0]|0)+e&65535;b[a+4>>1]=(d[c+2|0]|0)+e&65535;b[a+6>>1]=-32768;b[a+8>>1]=-32768;b[a+10>>1]=-32768;b[a+12>>1]=(d[c+3|0]|0)+e&65535;b[a+14>>1]=(d[c+4|0]|0)+e&65535;return 5}function c3G(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=(d[c]|0)+e&65535;b[a+4>>1]=(d[c+1|0]|0)+e&65535;b[a+6>>1]=-32768;b[a+8>>1]=-32768;b[a+10>>1]=-32768;b[a+12>>1]=(d[c+2|0]|0)+e&65535;b[a+14>>1]=(d[c+3|0]|0)+e&65535;return 4}function c3H(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=-32768;b[a+4>>1]=(d[c+1|0]|0)+e&65535;b[a+6>>1]=-32768;b[a+8>>1]=-32768;b[a+10>>1]=-32768;b[a+12>>1]=(d[c+2|0]|0)+e&65535;b[a+14>>1]=(d[c+3|0]|0)+e&65535;return 4}function c3I(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=-32768;b[a+4>>1]=(d[c]|0)+e&65535;b[a+6>>1]=-32768;b[a+8>>1]=-32768;b[a+10>>1]=-32768;b[a+12>>1]=(d[c+1|0]|0)+e&65535;b[a+14>>1]=(d[c+2|0]|0)+e&65535;return 3}function c3J(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=(d[c+1|0]|0)+e&65535;b[a+4>>1]=-32768;b[a+6>>1]=-32768;b[a+8>>1]=-32768;b[a+10>>1]=-32768;b[a+12>>1]=(d[c+2|0]|0)+e&65535;b[a+14>>1]=(d[c+3|0]|0)+e&65535;return 4}function c3K(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=(d[c]|0)+e&65535;b[a+4>>1]=-32768;b[a+6>>1]=-32768;b[a+8>>1]=-32768;b[a+10>>1]=-32768;b[a+12>>1]=(d[c+1|0]|0)+e&65535;b[a+14>>1]=(d[c+2|0]|0)+e&65535;return 3}function c3L(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=-32768;b[a+4>>1]=-32768;b[a+6>>1]=-32768;b[a+8>>1]=-32768;b[a+10>>1]=-32768;b[a+12>>1]=(d[c+1|0]|0)+e&65535;b[a+14>>1]=(d[c+2|0]|0)+e&65535;return 3}function c3M(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=-32768;b[a+4>>1]=-32768;b[a+6>>1]=-32768;b[a+8>>1]=-32768;b[a+10>>1]=-32768;b[a+12>>1]=(d[c]|0)+e&65535;b[a+14>>1]=(d[c+1|0]|0)+e&65535;return 2}function c3N(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=(d[c+1|0]|0)+e&65535;b[a+4>>1]=(d[c+2|0]|0)+e&65535;b[a+6>>1]=(d[c+3|0]|0)+e&65535;b[a+8>>1]=(d[c+4|0]|0)+e&65535;b[a+10>>1]=(d[c+5|0]|0)+e&65535;b[a+12>>1]=-32768;b[a+14>>1]=(d[c+6|0]|0)+e&65535;return 7}function c3O(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=(d[c]|0)+e&65535;b[a+4>>1]=(d[c+1|0]|0)+e&65535;b[a+6>>1]=(d[c+2|0]|0)+e&65535;b[a+8>>1]=(d[c+3|0]|0)+e&65535;b[a+10>>1]=(d[c+4|0]|0)+e&65535;b[a+12>>1]=-32768;b[a+14>>1]=(d[c+5|0]|0)+e&65535;return 6}function c3P(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=-32768;b[a+4>>1]=(d[c+1|0]|0)+e&65535;b[a+6>>1]=(d[c+2|0]|0)+e&65535;b[a+8>>1]=(d[c+3|0]|0)+e&65535;b[a+10>>1]=(d[c+4|0]|0)+e&65535;b[a+12>>1]=-32768;b[a+14>>1]=(d[c+5|0]|0)+e&65535;return 6}function c3Q(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=-32768;b[a+4>>1]=(d[c]|0)+e&65535;b[a+6>>1]=(d[c+1|0]|0)+e&65535;b[a+8>>1]=(d[c+2|0]|0)+e&65535;b[a+10>>1]=(d[c+3|0]|0)+e&65535;b[a+12>>1]=-32768;b[a+14>>1]=(d[c+4|0]|0)+e&65535;return 5}function c3R(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=(d[c+1|0]|0)+e&65535;b[a+4>>1]=-32768;b[a+6>>1]=(d[c+2|0]|0)+e&65535;b[a+8>>1]=(d[c+3|0]|0)+e&65535;b[a+10>>1]=(d[c+4|0]|0)+e&65535;b[a+12>>1]=-32768;b[a+14>>1]=(d[c+5|0]|0)+e&65535;return 6}function c3S(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=(d[c]|0)+e&65535;b[a+4>>1]=-32768;b[a+6>>1]=(d[c+1|0]|0)+e&65535;b[a+8>>1]=(d[c+2|0]|0)+e&65535;b[a+10>>1]=(d[c+3|0]|0)+e&65535;b[a+12>>1]=-32768;b[a+14>>1]=(d[c+4|0]|0)+e&65535;return 5}function c3T(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=-32768;b[a+4>>1]=-32768;b[a+6>>1]=(d[c+1|0]|0)+e&65535;b[a+8>>1]=(d[c+2|0]|0)+e&65535;b[a+10>>1]=(d[c+3|0]|0)+e&65535;b[a+12>>1]=-32768;b[a+14>>1]=(d[c+4|0]|0)+e&65535;return 5}function c3U(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=-32768;b[a+4>>1]=-32768;b[a+6>>1]=(d[c]|0)+e&65535;b[a+8>>1]=(d[c+1|0]|0)+e&65535;b[a+10>>1]=(d[c+2|0]|0)+e&65535;b[a+12>>1]=-32768;b[a+14>>1]=(d[c+3|0]|0)+e&65535;return 4}function c3V(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=(d[c+1|0]|0)+e&65535;b[a+4>>1]=(d[c+2|0]|0)+e&65535;b[a+6>>1]=-32768;b[a+8>>1]=(d[c+3|0]|0)+e&65535;b[a+10>>1]=(d[c+4|0]|0)+e&65535;b[a+12>>1]=-32768;b[a+14>>1]=(d[c+5|0]|0)+e&65535;return 6}function c3W(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=(d[c]|0)+e&65535;b[a+4>>1]=(d[c+1|0]|0)+e&65535;b[a+6>>1]=-32768;b[a+8>>1]=(d[c+2|0]|0)+e&65535;b[a+10>>1]=(d[c+3|0]|0)+e&65535;b[a+12>>1]=-32768;b[a+14>>1]=(d[c+4|0]|0)+e&65535;return 5}function c3X(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=-32768;b[a+4>>1]=(d[c+1|0]|0)+e&65535;b[a+6>>1]=-32768;b[a+8>>1]=(d[c+2|0]|0)+e&65535;b[a+10>>1]=(d[c+3|0]|0)+e&65535;b[a+12>>1]=-32768;b[a+14>>1]=(d[c+4|0]|0)+e&65535;return 5}function c3Y(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=-32768;b[a+4>>1]=(d[c]|0)+e&65535;b[a+6>>1]=-32768;b[a+8>>1]=(d[c+1|0]|0)+e&65535;b[a+10>>1]=(d[c+2|0]|0)+e&65535;b[a+12>>1]=-32768;b[a+14>>1]=(d[c+3|0]|0)+e&65535;return 4}function c3Z(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=(d[c+1|0]|0)+e&65535;b[a+4>>1]=-32768;b[a+6>>1]=-32768;b[a+8>>1]=(d[c+2|0]|0)+e&65535;b[a+10>>1]=(d[c+3|0]|0)+e&65535;b[a+12>>1]=-32768;b[a+14>>1]=(d[c+4|0]|0)+e&65535;return 5}function c3_(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=(d[c]|0)+e&65535;b[a+4>>1]=-32768;b[a+6>>1]=-32768;b[a+8>>1]=(d[c+1|0]|0)+e&65535;b[a+10>>1]=(d[c+2|0]|0)+e&65535;b[a+12>>1]=-32768;b[a+14>>1]=(d[c+3|0]|0)+e&65535;return 4}function c3$(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=-32768;b[a+4>>1]=-32768;b[a+6>>1]=-32768;b[a+8>>1]=(d[c+1|0]|0)+e&65535;b[a+10>>1]=(d[c+2|0]|0)+e&65535;b[a+12>>1]=-32768;b[a+14>>1]=(d[c+3|0]|0)+e&65535;return 4}function c30(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=-32768;b[a+4>>1]=-32768;b[a+6>>1]=-32768;b[a+8>>1]=(d[c]|0)+e&65535;b[a+10>>1]=(d[c+1|0]|0)+e&65535;b[a+12>>1]=-32768;b[a+14>>1]=(d[c+2|0]|0)+e&65535;return 3}function c31(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=(d[c+1|0]|0)+e&65535;b[a+4>>1]=(d[c+2|0]|0)+e&65535;b[a+6>>1]=(d[c+3|0]|0)+e&65535;b[a+8>>1]=-32768;b[a+10>>1]=(d[c+4|0]|0)+e&65535;b[a+12>>1]=-32768;b[a+14>>1]=(d[c+5|0]|0)+e&65535;return 6}function c32(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=(d[c]|0)+e&65535;b[a+4>>1]=(d[c+1|0]|0)+e&65535;b[a+6>>1]=(d[c+2|0]|0)+e&65535;b[a+8>>1]=-32768;b[a+10>>1]=(d[c+3|0]|0)+e&65535;b[a+12>>1]=-32768;b[a+14>>1]=(d[c+4|0]|0)+e&65535;return 5}function c33(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=-32768;b[a+4>>1]=(d[c+1|0]|0)+e&65535;b[a+6>>1]=(d[c+2|0]|0)+e&65535;b[a+8>>1]=-32768;b[a+10>>1]=(d[c+3|0]|0)+e&65535;b[a+12>>1]=-32768;b[a+14>>1]=(d[c+4|0]|0)+e&65535;return 5}function c34(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=-32768;b[a+4>>1]=(d[c]|0)+e&65535;b[a+6>>1]=(d[c+1|0]|0)+e&65535;b[a+8>>1]=-32768;b[a+10>>1]=(d[c+2|0]|0)+e&65535;b[a+12>>1]=-32768;b[a+14>>1]=(d[c+3|0]|0)+e&65535;return 4}function c35(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=(d[c+1|0]|0)+e&65535;b[a+4>>1]=-32768;b[a+6>>1]=(d[c+2|0]|0)+e&65535;b[a+8>>1]=-32768;b[a+10>>1]=(d[c+3|0]|0)+e&65535;b[a+12>>1]=-32768;b[a+14>>1]=(d[c+4|0]|0)+e&65535;return 5}function c36(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=(d[c]|0)+e&65535;b[a+4>>1]=-32768;b[a+6>>1]=(d[c+1|0]|0)+e&65535;b[a+8>>1]=-32768;b[a+10>>1]=(d[c+2|0]|0)+e&65535;b[a+12>>1]=-32768;b[a+14>>1]=(d[c+3|0]|0)+e&65535;return 4}function c37(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=-32768;b[a+4>>1]=-32768;b[a+6>>1]=(d[c+1|0]|0)+e&65535;b[a+8>>1]=-32768;b[a+10>>1]=(d[c+2|0]|0)+e&65535;b[a+12>>1]=-32768;b[a+14>>1]=(d[c+3|0]|0)+e&65535;return 4}function c38(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=-32768;b[a+4>>1]=-32768;b[a+6>>1]=(d[c]|0)+e&65535;b[a+8>>1]=-32768;b[a+10>>1]=(d[c+1|0]|0)+e&65535;b[a+12>>1]=-32768;b[a+14>>1]=(d[c+2|0]|0)+e&65535;return 3}function c39(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=(d[c+1|0]|0)+e&65535;b[a+4>>1]=(d[c+2|0]|0)+e&65535;b[a+6>>1]=-32768;b[a+8>>1]=-32768;b[a+10>>1]=(d[c+3|0]|0)+e&65535;b[a+12>>1]=-32768;b[a+14>>1]=(d[c+4|0]|0)+e&65535;return 5}function c4a(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=(d[c]|0)+e&65535;b[a+4>>1]=(d[c+1|0]|0)+e&65535;b[a+6>>1]=-32768;b[a+8>>1]=-32768;b[a+10>>1]=(d[c+2|0]|0)+e&65535;b[a+12>>1]=-32768;b[a+14>>1]=(d[c+3|0]|0)+e&65535;return 4}function c4b(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=-32768;b[a+4>>1]=(d[c+1|0]|0)+e&65535;b[a+6>>1]=-32768;b[a+8>>1]=-32768;b[a+10>>1]=(d[c+2|0]|0)+e&65535;b[a+12>>1]=-32768;b[a+14>>1]=(d[c+3|0]|0)+e&65535;return 4}function c4c(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=-32768;b[a+4>>1]=(d[c]|0)+e&65535;b[a+6>>1]=-32768;b[a+8>>1]=-32768;b[a+10>>1]=(d[c+1|0]|0)+e&65535;b[a+12>>1]=-32768;b[a+14>>1]=(d[c+2|0]|0)+e&65535;return 3}function c4d(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=(d[c+1|0]|0)+e&65535;b[a+4>>1]=-32768;b[a+6>>1]=-32768;b[a+8>>1]=-32768;b[a+10>>1]=(d[c+2|0]|0)+e&65535;b[a+12>>1]=-32768;b[a+14>>1]=(d[c+3|0]|0)+e&65535;return 4}function c4e(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=(d[c]|0)+e&65535;b[a+4>>1]=-32768;b[a+6>>1]=-32768;b[a+8>>1]=-32768;b[a+10>>1]=(d[c+1|0]|0)+e&65535;b[a+12>>1]=-32768;b[a+14>>1]=(d[c+2|0]|0)+e&65535;return 3}function c4f(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=-32768;b[a+4>>1]=-32768;b[a+6>>1]=-32768;b[a+8>>1]=-32768;b[a+10>>1]=(d[c+1|0]|0)+e&65535;b[a+12>>1]=-32768;b[a+14>>1]=(d[c+2|0]|0)+e&65535;return 3}function c4g(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=-32768;b[a+4>>1]=-32768;b[a+6>>1]=-32768;b[a+8>>1]=-32768;b[a+10>>1]=(d[c]|0)+e&65535;b[a+12>>1]=-32768;b[a+14>>1]=(d[c+1|0]|0)+e&65535;return 2}function c4h(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=(d[c+1|0]|0)+e&65535;b[a+4>>1]=(d[c+2|0]|0)+e&65535;b[a+6>>1]=(d[c+3|0]|0)+e&65535;b[a+8>>1]=(d[c+4|0]|0)+e&65535;b[a+10>>1]=-32768;b[a+12>>1]=-32768;b[a+14>>1]=(d[c+5|0]|0)+e&65535;return 6}function c4i(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=(d[c]|0)+e&65535;b[a+4>>1]=(d[c+1|0]|0)+e&65535;b[a+6>>1]=(d[c+2|0]|0)+e&65535;b[a+8>>1]=(d[c+3|0]|0)+e&65535;b[a+10>>1]=-32768;b[a+12>>1]=-32768;b[a+14>>1]=(d[c+4|0]|0)+e&65535;return 5}function c4j(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=-32768;b[a+4>>1]=(d[c+1|0]|0)+e&65535;b[a+6>>1]=(d[c+2|0]|0)+e&65535;b[a+8>>1]=(d[c+3|0]|0)+e&65535;b[a+10>>1]=-32768;b[a+12>>1]=-32768;b[a+14>>1]=(d[c+4|0]|0)+e&65535;return 5}function c4k(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=-32768;b[a+4>>1]=(d[c]|0)+e&65535;b[a+6>>1]=(d[c+1|0]|0)+e&65535;b[a+8>>1]=(d[c+2|0]|0)+e&65535;b[a+10>>1]=-32768;b[a+12>>1]=-32768;b[a+14>>1]=(d[c+3|0]|0)+e&65535;return 4}function c4l(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=(d[c+1|0]|0)+e&65535;b[a+4>>1]=-32768;b[a+6>>1]=(d[c+2|0]|0)+e&65535;b[a+8>>1]=(d[c+3|0]|0)+e&65535;b[a+10>>1]=-32768;b[a+12>>1]=-32768;b[a+14>>1]=(d[c+4|0]|0)+e&65535;return 5}function c4m(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=(d[c]|0)+e&65535;b[a+4>>1]=-32768;b[a+6>>1]=(d[c+1|0]|0)+e&65535;b[a+8>>1]=(d[c+2|0]|0)+e&65535;b[a+10>>1]=-32768;b[a+12>>1]=-32768;b[a+14>>1]=(d[c+3|0]|0)+e&65535;return 4}function c4n(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=-32768;b[a+4>>1]=-32768;b[a+6>>1]=(d[c+1|0]|0)+e&65535;b[a+8>>1]=(d[c+2|0]|0)+e&65535;b[a+10>>1]=-32768;b[a+12>>1]=-32768;b[a+14>>1]=(d[c+3|0]|0)+e&65535;return 4}function c4o(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=-32768;b[a+4>>1]=-32768;b[a+6>>1]=(d[c]|0)+e&65535;b[a+8>>1]=(d[c+1|0]|0)+e&65535;b[a+10>>1]=-32768;b[a+12>>1]=-32768;b[a+14>>1]=(d[c+2|0]|0)+e&65535;return 3}function c4p(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=(d[c+1|0]|0)+e&65535;b[a+4>>1]=(d[c+2|0]|0)+e&65535;b[a+6>>1]=-32768;b[a+8>>1]=(d[c+3|0]|0)+e&65535;b[a+10>>1]=-32768;b[a+12>>1]=-32768;b[a+14>>1]=(d[c+4|0]|0)+e&65535;return 5}function c4q(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=(d[c]|0)+e&65535;b[a+4>>1]=(d[c+1|0]|0)+e&65535;b[a+6>>1]=-32768;b[a+8>>1]=(d[c+2|0]|0)+e&65535;b[a+10>>1]=-32768;b[a+12>>1]=-32768;b[a+14>>1]=(d[c+3|0]|0)+e&65535;return 4}function c4r(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=-32768;b[a+4>>1]=(d[c+1|0]|0)+e&65535;b[a+6>>1]=-32768;b[a+8>>1]=(d[c+2|0]|0)+e&65535;b[a+10>>1]=-32768;b[a+12>>1]=-32768;b[a+14>>1]=(d[c+3|0]|0)+e&65535;return 4}function c4s(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=-32768;b[a+4>>1]=(d[c]|0)+e&65535;b[a+6>>1]=-32768;b[a+8>>1]=(d[c+1|0]|0)+e&65535;b[a+10>>1]=-32768;b[a+12>>1]=-32768;b[a+14>>1]=(d[c+2|0]|0)+e&65535;return 3}function c4t(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=(d[c+1|0]|0)+e&65535;b[a+4>>1]=-32768;b[a+6>>1]=-32768;b[a+8>>1]=(d[c+2|0]|0)+e&65535;b[a+10>>1]=-32768;b[a+12>>1]=-32768;b[a+14>>1]=(d[c+3|0]|0)+e&65535;return 4}function c4u(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=(d[c]|0)+e&65535;b[a+4>>1]=-32768;b[a+6>>1]=-32768;b[a+8>>1]=(d[c+1|0]|0)+e&65535;b[a+10>>1]=-32768;b[a+12>>1]=-32768;b[a+14>>1]=(d[c+2|0]|0)+e&65535;return 3}function c4v(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=-32768;b[a+4>>1]=-32768;b[a+6>>1]=-32768;b[a+8>>1]=(d[c+1|0]|0)+e&65535;b[a+10>>1]=-32768;b[a+12>>1]=-32768;b[a+14>>1]=(d[c+2|0]|0)+e&65535;return 3}function c4w(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=-32768;b[a+4>>1]=-32768;b[a+6>>1]=-32768;b[a+8>>1]=(d[c]|0)+e&65535;b[a+10>>1]=-32768;b[a+12>>1]=-32768;b[a+14>>1]=(d[c+1|0]|0)+e&65535;return 2}function c4x(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=(d[c+1|0]|0)+e&65535;b[a+4>>1]=(d[c+2|0]|0)+e&65535;b[a+6>>1]=(d[c+3|0]|0)+e&65535;b[a+8>>1]=-32768;b[a+10>>1]=-32768;b[a+12>>1]=-32768;b[a+14>>1]=(d[c+4|0]|0)+e&65535;return 5}function c4y(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=(d[c]|0)+e&65535;b[a+4>>1]=(d[c+1|0]|0)+e&65535;b[a+6>>1]=(d[c+2|0]|0)+e&65535;b[a+8>>1]=-32768;b[a+10>>1]=-32768;b[a+12>>1]=-32768;b[a+14>>1]=(d[c+3|0]|0)+e&65535;return 4}function c4z(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=-32768;b[a+4>>1]=(d[c+1|0]|0)+e&65535;b[a+6>>1]=(d[c+2|0]|0)+e&65535;b[a+8>>1]=-32768;b[a+10>>1]=-32768;b[a+12>>1]=-32768;b[a+14>>1]=(d[c+3|0]|0)+e&65535;return 4}function c4A(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=-32768;b[a+4>>1]=(d[c]|0)+e&65535;b[a+6>>1]=(d[c+1|0]|0)+e&65535;b[a+8>>1]=-32768;b[a+10>>1]=-32768;b[a+12>>1]=-32768;b[a+14>>1]=(d[c+2|0]|0)+e&65535;return 3}function c4B(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=(d[c+1|0]|0)+e&65535;b[a+4>>1]=-32768;b[a+6>>1]=(d[c+2|0]|0)+e&65535;b[a+8>>1]=-32768;b[a+10>>1]=-32768;b[a+12>>1]=-32768;b[a+14>>1]=(d[c+3|0]|0)+e&65535;return 4}function c4C(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=(d[c]|0)+e&65535;b[a+4>>1]=-32768;b[a+6>>1]=(d[c+1|0]|0)+e&65535;b[a+8>>1]=-32768;b[a+10>>1]=-32768;b[a+12>>1]=-32768;b[a+14>>1]=(d[c+2|0]|0)+e&65535;return 3}function c4D(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=-32768;b[a+4>>1]=-32768;b[a+6>>1]=(d[c+1|0]|0)+e&65535;b[a+8>>1]=-32768;b[a+10>>1]=-32768;b[a+12>>1]=-32768;b[a+14>>1]=(d[c+2|0]|0)+e&65535;return 3}function c4E(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=-32768;b[a+4>>1]=-32768;b[a+6>>1]=(d[c]|0)+e&65535;b[a+8>>1]=-32768;b[a+10>>1]=-32768;b[a+12>>1]=-32768;b[a+14>>1]=(d[c+1|0]|0)+e&65535;return 2}function c4F(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=(d[c+1|0]|0)+e&65535;b[a+4>>1]=(d[c+2|0]|0)+e&65535;b[a+6>>1]=-32768;b[a+8>>1]=-32768;b[a+10>>1]=-32768;b[a+12>>1]=-32768;b[a+14>>1]=(d[c+3|0]|0)+e&65535;return 4}function c4G(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=(d[c]|0)+e&65535;b[a+4>>1]=(d[c+1|0]|0)+e&65535;b[a+6>>1]=-32768;b[a+8>>1]=-32768;b[a+10>>1]=-32768;b[a+12>>1]=-32768;b[a+14>>1]=(d[c+2|0]|0)+e&65535;return 3}function c4H(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=-32768;b[a+4>>1]=(d[c+1|0]|0)+e&65535;b[a+6>>1]=-32768;b[a+8>>1]=-32768;b[a+10>>1]=-32768;b[a+12>>1]=-32768;b[a+14>>1]=(d[c+2|0]|0)+e&65535;return 3}function c4I(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=-32768;b[a+4>>1]=(d[c]|0)+e&65535;b[a+6>>1]=-32768;b[a+8>>1]=-32768;b[a+10>>1]=-32768;b[a+12>>1]=-32768;b[a+14>>1]=(d[c+1|0]|0)+e&65535;return 2}function c4J(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=(d[c+1|0]|0)+e&65535;b[a+4>>1]=-32768;b[a+6>>1]=-32768;b[a+8>>1]=-32768;b[a+10>>1]=-32768;b[a+12>>1]=-32768;b[a+14>>1]=(d[c+2|0]|0)+e&65535;return 3}function c4K(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=(d[c]|0)+e&65535;b[a+4>>1]=-32768;b[a+6>>1]=-32768;b[a+8>>1]=-32768;b[a+10>>1]=-32768;b[a+12>>1]=-32768;b[a+14>>1]=(d[c+1|0]|0)+e&65535;return 2}function c4L(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=-32768;b[a+4>>1]=-32768;b[a+6>>1]=-32768;b[a+8>>1]=-32768;b[a+10>>1]=-32768;b[a+12>>1]=-32768;b[a+14>>1]=(d[c+1|0]|0)+e&65535;return 2}function c4M(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=-32768;b[a+4>>1]=-32768;b[a+6>>1]=-32768;b[a+8>>1]=-32768;b[a+10>>1]=-32768;b[a+12>>1]=-32768;b[a+14>>1]=(d[c]|0)+e&65535;return 1}function c4N(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=(d[c+1|0]|0)+e&65535;b[a+4>>1]=(d[c+2|0]|0)+e&65535;b[a+6>>1]=(d[c+3|0]|0)+e&65535;b[a+8>>1]=(d[c+4|0]|0)+e&65535;b[a+10>>1]=(d[c+5|0]|0)+e&65535;b[a+12>>1]=(d[c+6|0]|0)+e&65535;b[a+14>>1]=-32768;return 7}function c4O(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=(d[c]|0)+e&65535;b[a+4>>1]=(d[c+1|0]|0)+e&65535;b[a+6>>1]=(d[c+2|0]|0)+e&65535;b[a+8>>1]=(d[c+3|0]|0)+e&65535;b[a+10>>1]=(d[c+4|0]|0)+e&65535;b[a+12>>1]=(d[c+5|0]|0)+e&65535;b[a+14>>1]=-32768;return 6}function c4P(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=-32768;b[a+4>>1]=(d[c+1|0]|0)+e&65535;b[a+6>>1]=(d[c+2|0]|0)+e&65535;b[a+8>>1]=(d[c+3|0]|0)+e&65535;b[a+10>>1]=(d[c+4|0]|0)+e&65535;b[a+12>>1]=(d[c+5|0]|0)+e&65535;b[a+14>>1]=-32768;return 6}function c4Q(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=-32768;b[a+4>>1]=(d[c]|0)+e&65535;b[a+6>>1]=(d[c+1|0]|0)+e&65535;b[a+8>>1]=(d[c+2|0]|0)+e&65535;b[a+10>>1]=(d[c+3|0]|0)+e&65535;b[a+12>>1]=(d[c+4|0]|0)+e&65535;b[a+14>>1]=-32768;return 5}function c4R(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=(d[c+1|0]|0)+e&65535;b[a+4>>1]=-32768;b[a+6>>1]=(d[c+2|0]|0)+e&65535;b[a+8>>1]=(d[c+3|0]|0)+e&65535;b[a+10>>1]=(d[c+4|0]|0)+e&65535;b[a+12>>1]=(d[c+5|0]|0)+e&65535;b[a+14>>1]=-32768;return 6}function c4S(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=(d[c]|0)+e&65535;b[a+4>>1]=-32768;b[a+6>>1]=(d[c+1|0]|0)+e&65535;b[a+8>>1]=(d[c+2|0]|0)+e&65535;b[a+10>>1]=(d[c+3|0]|0)+e&65535;b[a+12>>1]=(d[c+4|0]|0)+e&65535;b[a+14>>1]=-32768;return 5}function c4T(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=-32768;b[a+4>>1]=-32768;b[a+6>>1]=(d[c+1|0]|0)+e&65535;b[a+8>>1]=(d[c+2|0]|0)+e&65535;b[a+10>>1]=(d[c+3|0]|0)+e&65535;b[a+12>>1]=(d[c+4|0]|0)+e&65535;b[a+14>>1]=-32768;return 5}function c4U(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=-32768;b[a+4>>1]=-32768;b[a+6>>1]=(d[c]|0)+e&65535;b[a+8>>1]=(d[c+1|0]|0)+e&65535;b[a+10>>1]=(d[c+2|0]|0)+e&65535;b[a+12>>1]=(d[c+3|0]|0)+e&65535;b[a+14>>1]=-32768;return 4}function c4V(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=(d[c+1|0]|0)+e&65535;b[a+4>>1]=(d[c+2|0]|0)+e&65535;b[a+6>>1]=-32768;b[a+8>>1]=(d[c+3|0]|0)+e&65535;b[a+10>>1]=(d[c+4|0]|0)+e&65535;b[a+12>>1]=(d[c+5|0]|0)+e&65535;b[a+14>>1]=-32768;return 6}function c4W(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=(d[c]|0)+e&65535;b[a+4>>1]=(d[c+1|0]|0)+e&65535;b[a+6>>1]=-32768;b[a+8>>1]=(d[c+2|0]|0)+e&65535;b[a+10>>1]=(d[c+3|0]|0)+e&65535;b[a+12>>1]=(d[c+4|0]|0)+e&65535;b[a+14>>1]=-32768;return 5}function c4X(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=-32768;b[a+4>>1]=(d[c+1|0]|0)+e&65535;b[a+6>>1]=-32768;b[a+8>>1]=(d[c+2|0]|0)+e&65535;b[a+10>>1]=(d[c+3|0]|0)+e&65535;b[a+12>>1]=(d[c+4|0]|0)+e&65535;b[a+14>>1]=-32768;return 5}function c4Y(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=-32768;b[a+4>>1]=(d[c]|0)+e&65535;b[a+6>>1]=-32768;b[a+8>>1]=(d[c+1|0]|0)+e&65535;b[a+10>>1]=(d[c+2|0]|0)+e&65535;b[a+12>>1]=(d[c+3|0]|0)+e&65535;b[a+14>>1]=-32768;return 4}function c4Z(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=(d[c+1|0]|0)+e&65535;b[a+4>>1]=-32768;b[a+6>>1]=-32768;b[a+8>>1]=(d[c+2|0]|0)+e&65535;b[a+10>>1]=(d[c+3|0]|0)+e&65535;b[a+12>>1]=(d[c+4|0]|0)+e&65535;b[a+14>>1]=-32768;return 5}function c4_(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=(d[c]|0)+e&65535;b[a+4>>1]=-32768;b[a+6>>1]=-32768;b[a+8>>1]=(d[c+1|0]|0)+e&65535;b[a+10>>1]=(d[c+2|0]|0)+e&65535;b[a+12>>1]=(d[c+3|0]|0)+e&65535;b[a+14>>1]=-32768;return 4}function c4$(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=-32768;b[a+4>>1]=-32768;b[a+6>>1]=-32768;b[a+8>>1]=(d[c+1|0]|0)+e&65535;b[a+10>>1]=(d[c+2|0]|0)+e&65535;b[a+12>>1]=(d[c+3|0]|0)+e&65535;b[a+14>>1]=-32768;return 4}function c40(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=-32768;b[a+4>>1]=-32768;b[a+6>>1]=-32768;b[a+8>>1]=(d[c]|0)+e&65535;b[a+10>>1]=(d[c+1|0]|0)+e&65535;b[a+12>>1]=(d[c+2|0]|0)+e&65535;b[a+14>>1]=-32768;return 3}function c41(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=(d[c+1|0]|0)+e&65535;b[a+4>>1]=(d[c+2|0]|0)+e&65535;b[a+6>>1]=(d[c+3|0]|0)+e&65535;b[a+8>>1]=-32768;b[a+10>>1]=(d[c+4|0]|0)+e&65535;b[a+12>>1]=(d[c+5|0]|0)+e&65535;b[a+14>>1]=-32768;return 6}function c42(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=(d[c]|0)+e&65535;b[a+4>>1]=(d[c+1|0]|0)+e&65535;b[a+6>>1]=(d[c+2|0]|0)+e&65535;b[a+8>>1]=-32768;b[a+10>>1]=(d[c+3|0]|0)+e&65535;b[a+12>>1]=(d[c+4|0]|0)+e&65535;b[a+14>>1]=-32768;return 5}function c43(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=-32768;b[a+4>>1]=(d[c+1|0]|0)+e&65535;b[a+6>>1]=(d[c+2|0]|0)+e&65535;b[a+8>>1]=-32768;b[a+10>>1]=(d[c+3|0]|0)+e&65535;b[a+12>>1]=(d[c+4|0]|0)+e&65535;b[a+14>>1]=-32768;return 5}function c44(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=-32768;b[a+4>>1]=(d[c]|0)+e&65535;b[a+6>>1]=(d[c+1|0]|0)+e&65535;b[a+8>>1]=-32768;b[a+10>>1]=(d[c+2|0]|0)+e&65535;b[a+12>>1]=(d[c+3|0]|0)+e&65535;b[a+14>>1]=-32768;return 4}function c45(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=(d[c+1|0]|0)+e&65535;b[a+4>>1]=-32768;b[a+6>>1]=(d[c+2|0]|0)+e&65535;b[a+8>>1]=-32768;b[a+10>>1]=(d[c+3|0]|0)+e&65535;b[a+12>>1]=(d[c+4|0]|0)+e&65535;b[a+14>>1]=-32768;return 5}function c46(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=(d[c]|0)+e&65535;b[a+4>>1]=-32768;b[a+6>>1]=(d[c+1|0]|0)+e&65535;b[a+8>>1]=-32768;b[a+10>>1]=(d[c+2|0]|0)+e&65535;b[a+12>>1]=(d[c+3|0]|0)+e&65535;b[a+14>>1]=-32768;return 4}function c47(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=-32768;b[a+4>>1]=-32768;b[a+6>>1]=(d[c+1|0]|0)+e&65535;b[a+8>>1]=-32768;b[a+10>>1]=(d[c+2|0]|0)+e&65535;b[a+12>>1]=(d[c+3|0]|0)+e&65535;b[a+14>>1]=-32768;return 4}function c48(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=-32768;b[a+4>>1]=-32768;b[a+6>>1]=(d[c]|0)+e&65535;b[a+8>>1]=-32768;b[a+10>>1]=(d[c+1|0]|0)+e&65535;b[a+12>>1]=(d[c+2|0]|0)+e&65535;b[a+14>>1]=-32768;return 3}function c49(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=(d[c+1|0]|0)+e&65535;b[a+4>>1]=(d[c+2|0]|0)+e&65535;b[a+6>>1]=-32768;b[a+8>>1]=-32768;b[a+10>>1]=(d[c+3|0]|0)+e&65535;b[a+12>>1]=(d[c+4|0]|0)+e&65535;b[a+14>>1]=-32768;return 5}function c5a(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=(d[c]|0)+e&65535;b[a+4>>1]=(d[c+1|0]|0)+e&65535;b[a+6>>1]=-32768;b[a+8>>1]=-32768;b[a+10>>1]=(d[c+2|0]|0)+e&65535;b[a+12>>1]=(d[c+3|0]|0)+e&65535;b[a+14>>1]=-32768;return 4}function c5b(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=-32768;b[a+4>>1]=(d[c+1|0]|0)+e&65535;b[a+6>>1]=-32768;b[a+8>>1]=-32768;b[a+10>>1]=(d[c+2|0]|0)+e&65535;b[a+12>>1]=(d[c+3|0]|0)+e&65535;b[a+14>>1]=-32768;return 4}function c5c(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=-32768;b[a+4>>1]=(d[c]|0)+e&65535;b[a+6>>1]=-32768;b[a+8>>1]=-32768;b[a+10>>1]=(d[c+1|0]|0)+e&65535;b[a+12>>1]=(d[c+2|0]|0)+e&65535;b[a+14>>1]=-32768;return 3}function c5d(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=(d[c+1|0]|0)+e&65535;b[a+4>>1]=-32768;b[a+6>>1]=-32768;b[a+8>>1]=-32768;b[a+10>>1]=(d[c+2|0]|0)+e&65535;b[a+12>>1]=(d[c+3|0]|0)+e&65535;b[a+14>>1]=-32768;return 4}function c5e(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=(d[c]|0)+e&65535;b[a+4>>1]=-32768;b[a+6>>1]=-32768;b[a+8>>1]=-32768;b[a+10>>1]=(d[c+1|0]|0)+e&65535;b[a+12>>1]=(d[c+2|0]|0)+e&65535;b[a+14>>1]=-32768;return 3}function c5f(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=-32768;b[a+4>>1]=-32768;b[a+6>>1]=-32768;b[a+8>>1]=-32768;b[a+10>>1]=(d[c+1|0]|0)+e&65535;b[a+12>>1]=(d[c+2|0]|0)+e&65535;b[a+14>>1]=-32768;return 3}function c5g(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=-32768;b[a+4>>1]=-32768;b[a+6>>1]=-32768;b[a+8>>1]=-32768;b[a+10>>1]=(d[c]|0)+e&65535;b[a+12>>1]=(d[c+1|0]|0)+e&65535;b[a+14>>1]=-32768;return 2}function c5h(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=(d[c+1|0]|0)+e&65535;b[a+4>>1]=(d[c+2|0]|0)+e&65535;b[a+6>>1]=(d[c+3|0]|0)+e&65535;b[a+8>>1]=(d[c+4|0]|0)+e&65535;b[a+10>>1]=-32768;b[a+12>>1]=(d[c+5|0]|0)+e&65535;b[a+14>>1]=-32768;return 6}function c5i(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=(d[c]|0)+e&65535;b[a+4>>1]=(d[c+1|0]|0)+e&65535;b[a+6>>1]=(d[c+2|0]|0)+e&65535;b[a+8>>1]=(d[c+3|0]|0)+e&65535;b[a+10>>1]=-32768;b[a+12>>1]=(d[c+4|0]|0)+e&65535;b[a+14>>1]=-32768;return 5}function c5j(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=-32768;b[a+4>>1]=(d[c+1|0]|0)+e&65535;b[a+6>>1]=(d[c+2|0]|0)+e&65535;b[a+8>>1]=(d[c+3|0]|0)+e&65535;b[a+10>>1]=-32768;b[a+12>>1]=(d[c+4|0]|0)+e&65535;b[a+14>>1]=-32768;return 5}function c5k(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=-32768;b[a+4>>1]=(d[c]|0)+e&65535;b[a+6>>1]=(d[c+1|0]|0)+e&65535;b[a+8>>1]=(d[c+2|0]|0)+e&65535;b[a+10>>1]=-32768;b[a+12>>1]=(d[c+3|0]|0)+e&65535;b[a+14>>1]=-32768;return 4}function c5l(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=(d[c+1|0]|0)+e&65535;b[a+4>>1]=-32768;b[a+6>>1]=(d[c+2|0]|0)+e&65535;b[a+8>>1]=(d[c+3|0]|0)+e&65535;b[a+10>>1]=-32768;b[a+12>>1]=(d[c+4|0]|0)+e&65535;b[a+14>>1]=-32768;return 5}function c5m(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=(d[c]|0)+e&65535;b[a+4>>1]=-32768;b[a+6>>1]=(d[c+1|0]|0)+e&65535;b[a+8>>1]=(d[c+2|0]|0)+e&65535;b[a+10>>1]=-32768;b[a+12>>1]=(d[c+3|0]|0)+e&65535;b[a+14>>1]=-32768;return 4}function c5n(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=-32768;b[a+4>>1]=-32768;b[a+6>>1]=(d[c+1|0]|0)+e&65535;b[a+8>>1]=(d[c+2|0]|0)+e&65535;b[a+10>>1]=-32768;b[a+12>>1]=(d[c+3|0]|0)+e&65535;b[a+14>>1]=-32768;return 4}function c5o(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=-32768;b[a+4>>1]=-32768;b[a+6>>1]=(d[c]|0)+e&65535;b[a+8>>1]=(d[c+1|0]|0)+e&65535;b[a+10>>1]=-32768;b[a+12>>1]=(d[c+2|0]|0)+e&65535;b[a+14>>1]=-32768;return 3}function c5p(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=(d[c+1|0]|0)+e&65535;b[a+4>>1]=(d[c+2|0]|0)+e&65535;b[a+6>>1]=-32768;b[a+8>>1]=(d[c+3|0]|0)+e&65535;b[a+10>>1]=-32768;b[a+12>>1]=(d[c+4|0]|0)+e&65535;b[a+14>>1]=-32768;return 5}function c5q(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=(d[c]|0)+e&65535;b[a+4>>1]=(d[c+1|0]|0)+e&65535;b[a+6>>1]=-32768;b[a+8>>1]=(d[c+2|0]|0)+e&65535;b[a+10>>1]=-32768;b[a+12>>1]=(d[c+3|0]|0)+e&65535;b[a+14>>1]=-32768;return 4}function c5r(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=-32768;b[a+4>>1]=(d[c+1|0]|0)+e&65535;b[a+6>>1]=-32768;b[a+8>>1]=(d[c+2|0]|0)+e&65535;b[a+10>>1]=-32768;b[a+12>>1]=(d[c+3|0]|0)+e&65535;b[a+14>>1]=-32768;return 4}function c5s(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=-32768;b[a+4>>1]=(d[c]|0)+e&65535;b[a+6>>1]=-32768;b[a+8>>1]=(d[c+1|0]|0)+e&65535;b[a+10>>1]=-32768;b[a+12>>1]=(d[c+2|0]|0)+e&65535;b[a+14>>1]=-32768;return 3}function c5t(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=(d[c+1|0]|0)+e&65535;b[a+4>>1]=-32768;b[a+6>>1]=-32768;b[a+8>>1]=(d[c+2|0]|0)+e&65535;b[a+10>>1]=-32768;b[a+12>>1]=(d[c+3|0]|0)+e&65535;b[a+14>>1]=-32768;return 4}function c5u(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=(d[c]|0)+e&65535;b[a+4>>1]=-32768;b[a+6>>1]=-32768;b[a+8>>1]=(d[c+1|0]|0)+e&65535;b[a+10>>1]=-32768;b[a+12>>1]=(d[c+2|0]|0)+e&65535;b[a+14>>1]=-32768;return 3}function c5v(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=-32768;b[a+4>>1]=-32768;b[a+6>>1]=-32768;b[a+8>>1]=(d[c+1|0]|0)+e&65535;b[a+10>>1]=-32768;b[a+12>>1]=(d[c+2|0]|0)+e&65535;b[a+14>>1]=-32768;return 3}function c5w(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=-32768;b[a+4>>1]=-32768;b[a+6>>1]=-32768;b[a+8>>1]=(d[c]|0)+e&65535;b[a+10>>1]=-32768;b[a+12>>1]=(d[c+1|0]|0)+e&65535;b[a+14>>1]=-32768;return 2}function c5x(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=(d[c+1|0]|0)+e&65535;b[a+4>>1]=(d[c+2|0]|0)+e&65535;b[a+6>>1]=(d[c+3|0]|0)+e&65535;b[a+8>>1]=-32768;b[a+10>>1]=-32768;b[a+12>>1]=(d[c+4|0]|0)+e&65535;b[a+14>>1]=-32768;return 5}function c5y(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=(d[c]|0)+e&65535;b[a+4>>1]=(d[c+1|0]|0)+e&65535;b[a+6>>1]=(d[c+2|0]|0)+e&65535;b[a+8>>1]=-32768;b[a+10>>1]=-32768;b[a+12>>1]=(d[c+3|0]|0)+e&65535;b[a+14>>1]=-32768;return 4}function c5z(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=-32768;b[a+4>>1]=(d[c+1|0]|0)+e&65535;b[a+6>>1]=(d[c+2|0]|0)+e&65535;b[a+8>>1]=-32768;b[a+10>>1]=-32768;b[a+12>>1]=(d[c+3|0]|0)+e&65535;b[a+14>>1]=-32768;return 4}function c5A(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=-32768;b[a+4>>1]=(d[c]|0)+e&65535;b[a+6>>1]=(d[c+1|0]|0)+e&65535;b[a+8>>1]=-32768;b[a+10>>1]=-32768;b[a+12>>1]=(d[c+2|0]|0)+e&65535;b[a+14>>1]=-32768;return 3}function c5B(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=(d[c+1|0]|0)+e&65535;b[a+4>>1]=-32768;b[a+6>>1]=(d[c+2|0]|0)+e&65535;b[a+8>>1]=-32768;b[a+10>>1]=-32768;b[a+12>>1]=(d[c+3|0]|0)+e&65535;b[a+14>>1]=-32768;return 4}function c5C(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=(d[c]|0)+e&65535;b[a+4>>1]=-32768;b[a+6>>1]=(d[c+1|0]|0)+e&65535;b[a+8>>1]=-32768;b[a+10>>1]=-32768;b[a+12>>1]=(d[c+2|0]|0)+e&65535;b[a+14>>1]=-32768;return 3}function c5D(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=-32768;b[a+4>>1]=-32768;b[a+6>>1]=(d[c+1|0]|0)+e&65535;b[a+8>>1]=-32768;b[a+10>>1]=-32768;b[a+12>>1]=(d[c+2|0]|0)+e&65535;b[a+14>>1]=-32768;return 3}function c5E(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=-32768;b[a+4>>1]=-32768;b[a+6>>1]=(d[c]|0)+e&65535;b[a+8>>1]=-32768;b[a+10>>1]=-32768;b[a+12>>1]=(d[c+1|0]|0)+e&65535;b[a+14>>1]=-32768;return 2}function c5F(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=(d[c+1|0]|0)+e&65535;b[a+4>>1]=(d[c+2|0]|0)+e&65535;b[a+6>>1]=-32768;b[a+8>>1]=-32768;b[a+10>>1]=-32768;b[a+12>>1]=(d[c+3|0]|0)+e&65535;b[a+14>>1]=-32768;return 4}function c5G(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=(d[c]|0)+e&65535;b[a+4>>1]=(d[c+1|0]|0)+e&65535;b[a+6>>1]=-32768;b[a+8>>1]=-32768;b[a+10>>1]=-32768;b[a+12>>1]=(d[c+2|0]|0)+e&65535;b[a+14>>1]=-32768;return 3}function c5H(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=-32768;b[a+4>>1]=(d[c+1|0]|0)+e&65535;b[a+6>>1]=-32768;b[a+8>>1]=-32768;b[a+10>>1]=-32768;b[a+12>>1]=(d[c+2|0]|0)+e&65535;b[a+14>>1]=-32768;return 3}function c5I(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=-32768;b[a+4>>1]=(d[c]|0)+e&65535;b[a+6>>1]=-32768;b[a+8>>1]=-32768;b[a+10>>1]=-32768;b[a+12>>1]=(d[c+1|0]|0)+e&65535;b[a+14>>1]=-32768;return 2}function c5J(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=(d[c+1|0]|0)+e&65535;b[a+4>>1]=-32768;b[a+6>>1]=-32768;b[a+8>>1]=-32768;b[a+10>>1]=-32768;b[a+12>>1]=(d[c+2|0]|0)+e&65535;b[a+14>>1]=-32768;return 3}function c5K(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=(d[c]|0)+e&65535;b[a+4>>1]=-32768;b[a+6>>1]=-32768;b[a+8>>1]=-32768;b[a+10>>1]=-32768;b[a+12>>1]=(d[c+1|0]|0)+e&65535;b[a+14>>1]=-32768;return 2}function c5L(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=-32768;b[a+4>>1]=-32768;b[a+6>>1]=-32768;b[a+8>>1]=-32768;b[a+10>>1]=-32768;b[a+12>>1]=(d[c+1|0]|0)+e&65535;b[a+14>>1]=-32768;return 2}function c5M(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=-32768;b[a+4>>1]=-32768;b[a+6>>1]=-32768;b[a+8>>1]=-32768;b[a+10>>1]=-32768;b[a+12>>1]=(d[c]|0)+e&65535;b[a+14>>1]=-32768;return 1}function c5N(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=(d[c+1|0]|0)+e&65535;b[a+4>>1]=(d[c+2|0]|0)+e&65535;b[a+6>>1]=(d[c+3|0]|0)+e&65535;b[a+8>>1]=(d[c+4|0]|0)+e&65535;b[a+10>>1]=(d[c+5|0]|0)+e&65535;b[a+12>>1]=-32768;b[a+14>>1]=-32768;return 6}function c5O(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=(d[c]|0)+e&65535;b[a+4>>1]=(d[c+1|0]|0)+e&65535;b[a+6>>1]=(d[c+2|0]|0)+e&65535;b[a+8>>1]=(d[c+3|0]|0)+e&65535;b[a+10>>1]=(d[c+4|0]|0)+e&65535;b[a+12>>1]=-32768;b[a+14>>1]=-32768;return 5}function c5P(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=-32768;b[a+4>>1]=(d[c+1|0]|0)+e&65535;b[a+6>>1]=(d[c+2|0]|0)+e&65535;b[a+8>>1]=(d[c+3|0]|0)+e&65535;b[a+10>>1]=(d[c+4|0]|0)+e&65535;b[a+12>>1]=-32768;b[a+14>>1]=-32768;return 5}function c5Q(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=-32768;b[a+4>>1]=(d[c]|0)+e&65535;b[a+6>>1]=(d[c+1|0]|0)+e&65535;b[a+8>>1]=(d[c+2|0]|0)+e&65535;b[a+10>>1]=(d[c+3|0]|0)+e&65535;b[a+12>>1]=-32768;b[a+14>>1]=-32768;return 4}function c5R(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=(d[c+1|0]|0)+e&65535;b[a+4>>1]=-32768;b[a+6>>1]=(d[c+2|0]|0)+e&65535;b[a+8>>1]=(d[c+3|0]|0)+e&65535;b[a+10>>1]=(d[c+4|0]|0)+e&65535;b[a+12>>1]=-32768;b[a+14>>1]=-32768;return 5}function c5S(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=(d[c]|0)+e&65535;b[a+4>>1]=-32768;b[a+6>>1]=(d[c+1|0]|0)+e&65535;b[a+8>>1]=(d[c+2|0]|0)+e&65535;b[a+10>>1]=(d[c+3|0]|0)+e&65535;b[a+12>>1]=-32768;b[a+14>>1]=-32768;return 4}function c5T(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=-32768;b[a+4>>1]=-32768;b[a+6>>1]=(d[c+1|0]|0)+e&65535;b[a+8>>1]=(d[c+2|0]|0)+e&65535;b[a+10>>1]=(d[c+3|0]|0)+e&65535;b[a+12>>1]=-32768;b[a+14>>1]=-32768;return 4}function c5U(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=-32768;b[a+4>>1]=-32768;b[a+6>>1]=(d[c]|0)+e&65535;b[a+8>>1]=(d[c+1|0]|0)+e&65535;b[a+10>>1]=(d[c+2|0]|0)+e&65535;b[a+12>>1]=-32768;b[a+14>>1]=-32768;return 3}function c5V(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=(d[c+1|0]|0)+e&65535;b[a+4>>1]=(d[c+2|0]|0)+e&65535;b[a+6>>1]=-32768;b[a+8>>1]=(d[c+3|0]|0)+e&65535;b[a+10>>1]=(d[c+4|0]|0)+e&65535;b[a+12>>1]=-32768;b[a+14>>1]=-32768;return 5}function c5W(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=(d[c]|0)+e&65535;b[a+4>>1]=(d[c+1|0]|0)+e&65535;b[a+6>>1]=-32768;b[a+8>>1]=(d[c+2|0]|0)+e&65535;b[a+10>>1]=(d[c+3|0]|0)+e&65535;b[a+12>>1]=-32768;b[a+14>>1]=-32768;return 4}function c5X(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=-32768;b[a+4>>1]=(d[c+1|0]|0)+e&65535;b[a+6>>1]=-32768;b[a+8>>1]=(d[c+2|0]|0)+e&65535;b[a+10>>1]=(d[c+3|0]|0)+e&65535;b[a+12>>1]=-32768;b[a+14>>1]=-32768;return 4}function c5Y(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=-32768;b[a+4>>1]=(d[c]|0)+e&65535;b[a+6>>1]=-32768;b[a+8>>1]=(d[c+1|0]|0)+e&65535;b[a+10>>1]=(d[c+2|0]|0)+e&65535;b[a+12>>1]=-32768;b[a+14>>1]=-32768;return 3}function c5Z(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=(d[c+1|0]|0)+e&65535;b[a+4>>1]=-32768;b[a+6>>1]=-32768;b[a+8>>1]=(d[c+2|0]|0)+e&65535;b[a+10>>1]=(d[c+3|0]|0)+e&65535;b[a+12>>1]=-32768;b[a+14>>1]=-32768;return 4}function c5_(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=(d[c]|0)+e&65535;b[a+4>>1]=-32768;b[a+6>>1]=-32768;b[a+8>>1]=(d[c+1|0]|0)+e&65535;b[a+10>>1]=(d[c+2|0]|0)+e&65535;b[a+12>>1]=-32768;b[a+14>>1]=-32768;return 3}function c5$(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=-32768;b[a+4>>1]=-32768;b[a+6>>1]=-32768;b[a+8>>1]=(d[c+1|0]|0)+e&65535;b[a+10>>1]=(d[c+2|0]|0)+e&65535;b[a+12>>1]=-32768;b[a+14>>1]=-32768;return 3}function c50(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=-32768;b[a+4>>1]=-32768;b[a+6>>1]=-32768;b[a+8>>1]=(d[c]|0)+e&65535;b[a+10>>1]=(d[c+1|0]|0)+e&65535;b[a+12>>1]=-32768;b[a+14>>1]=-32768;return 2}function c51(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=(d[c+1|0]|0)+e&65535;b[a+4>>1]=(d[c+2|0]|0)+e&65535;b[a+6>>1]=(d[c+3|0]|0)+e&65535;b[a+8>>1]=-32768;b[a+10>>1]=(d[c+4|0]|0)+e&65535;b[a+12>>1]=-32768;b[a+14>>1]=-32768;return 5}function c52(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=(d[c]|0)+e&65535;b[a+4>>1]=(d[c+1|0]|0)+e&65535;b[a+6>>1]=(d[c+2|0]|0)+e&65535;b[a+8>>1]=-32768;b[a+10>>1]=(d[c+3|0]|0)+e&65535;b[a+12>>1]=-32768;b[a+14>>1]=-32768;return 4}function c53(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=-32768;b[a+4>>1]=(d[c+1|0]|0)+e&65535;b[a+6>>1]=(d[c+2|0]|0)+e&65535;b[a+8>>1]=-32768;b[a+10>>1]=(d[c+3|0]|0)+e&65535;b[a+12>>1]=-32768;b[a+14>>1]=-32768;return 4}function c54(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=-32768;b[a+4>>1]=(d[c]|0)+e&65535;b[a+6>>1]=(d[c+1|0]|0)+e&65535;b[a+8>>1]=-32768;b[a+10>>1]=(d[c+2|0]|0)+e&65535;b[a+12>>1]=-32768;b[a+14>>1]=-32768;return 3}function c55(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=(d[c+1|0]|0)+e&65535;b[a+4>>1]=-32768;b[a+6>>1]=(d[c+2|0]|0)+e&65535;b[a+8>>1]=-32768;b[a+10>>1]=(d[c+3|0]|0)+e&65535;b[a+12>>1]=-32768;b[a+14>>1]=-32768;return 4}function c56(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=(d[c]|0)+e&65535;b[a+4>>1]=-32768;b[a+6>>1]=(d[c+1|0]|0)+e&65535;b[a+8>>1]=-32768;b[a+10>>1]=(d[c+2|0]|0)+e&65535;b[a+12>>1]=-32768;b[a+14>>1]=-32768;return 3}function c57(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=-32768;b[a+4>>1]=-32768;b[a+6>>1]=(d[c+1|0]|0)+e&65535;b[a+8>>1]=-32768;b[a+10>>1]=(d[c+2|0]|0)+e&65535;b[a+12>>1]=-32768;b[a+14>>1]=-32768;return 3}function c58(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=-32768;b[a+4>>1]=-32768;b[a+6>>1]=(d[c]|0)+e&65535;b[a+8>>1]=-32768;b[a+10>>1]=(d[c+1|0]|0)+e&65535;b[a+12>>1]=-32768;b[a+14>>1]=-32768;return 2}function c59(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=(d[c+1|0]|0)+e&65535;b[a+4>>1]=(d[c+2|0]|0)+e&65535;b[a+6>>1]=-32768;b[a+8>>1]=-32768;b[a+10>>1]=(d[c+3|0]|0)+e&65535;b[a+12>>1]=-32768;b[a+14>>1]=-32768;return 4}function c6a(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=(d[c]|0)+e&65535;b[a+4>>1]=(d[c+1|0]|0)+e&65535;b[a+6>>1]=-32768;b[a+8>>1]=-32768;b[a+10>>1]=(d[c+2|0]|0)+e&65535;b[a+12>>1]=-32768;b[a+14>>1]=-32768;return 3}function c6b(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=-32768;b[a+4>>1]=(d[c+1|0]|0)+e&65535;b[a+6>>1]=-32768;b[a+8>>1]=-32768;b[a+10>>1]=(d[c+2|0]|0)+e&65535;b[a+12>>1]=-32768;b[a+14>>1]=-32768;return 3}function c6c(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=-32768;b[a+4>>1]=(d[c]|0)+e&65535;b[a+6>>1]=-32768;b[a+8>>1]=-32768;b[a+10>>1]=(d[c+1|0]|0)+e&65535;b[a+12>>1]=-32768;b[a+14>>1]=-32768;return 2}function c6d(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=(d[c+1|0]|0)+e&65535;b[a+4>>1]=-32768;b[a+6>>1]=-32768;b[a+8>>1]=-32768;b[a+10>>1]=(d[c+2|0]|0)+e&65535;b[a+12>>1]=-32768;b[a+14>>1]=-32768;return 3}function c6e(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=(d[c]|0)+e&65535;b[a+4>>1]=-32768;b[a+6>>1]=-32768;b[a+8>>1]=-32768;b[a+10>>1]=(d[c+1|0]|0)+e&65535;b[a+12>>1]=-32768;b[a+14>>1]=-32768;return 2}function c6f(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=-32768;b[a+4>>1]=-32768;b[a+6>>1]=-32768;b[a+8>>1]=-32768;b[a+10>>1]=(d[c+1|0]|0)+e&65535;b[a+12>>1]=-32768;b[a+14>>1]=-32768;return 2}function c6g(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=-32768;b[a+4>>1]=-32768;b[a+6>>1]=-32768;b[a+8>>1]=-32768;b[a+10>>1]=(d[c]|0)+e&65535;b[a+12>>1]=-32768;b[a+14>>1]=-32768;return 1}function c6h(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=(d[c+1|0]|0)+e&65535;b[a+4>>1]=(d[c+2|0]|0)+e&65535;b[a+6>>1]=(d[c+3|0]|0)+e&65535;b[a+8>>1]=(d[c+4|0]|0)+e&65535;b[a+10>>1]=-32768;b[a+12>>1]=-32768;b[a+14>>1]=-32768;return 5}function c6i(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=(d[c]|0)+e&65535;b[a+4>>1]=(d[c+1|0]|0)+e&65535;b[a+6>>1]=(d[c+2|0]|0)+e&65535;b[a+8>>1]=(d[c+3|0]|0)+e&65535;b[a+10>>1]=-32768;b[a+12>>1]=-32768;b[a+14>>1]=-32768;return 4}function c6j(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=-32768;b[a+4>>1]=(d[c+1|0]|0)+e&65535;b[a+6>>1]=(d[c+2|0]|0)+e&65535;b[a+8>>1]=(d[c+3|0]|0)+e&65535;b[a+10>>1]=-32768;b[a+12>>1]=-32768;b[a+14>>1]=-32768;return 4}function c6k(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=-32768;b[a+4>>1]=(d[c]|0)+e&65535;b[a+6>>1]=(d[c+1|0]|0)+e&65535;b[a+8>>1]=(d[c+2|0]|0)+e&65535;b[a+10>>1]=-32768;b[a+12>>1]=-32768;b[a+14>>1]=-32768;return 3}function c6l(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=(d[c+1|0]|0)+e&65535;b[a+4>>1]=-32768;b[a+6>>1]=(d[c+2|0]|0)+e&65535;b[a+8>>1]=(d[c+3|0]|0)+e&65535;b[a+10>>1]=-32768;b[a+12>>1]=-32768;b[a+14>>1]=-32768;return 4}function c6m(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=(d[c]|0)+e&65535;b[a+4>>1]=-32768;b[a+6>>1]=(d[c+1|0]|0)+e&65535;b[a+8>>1]=(d[c+2|0]|0)+e&65535;b[a+10>>1]=-32768;b[a+12>>1]=-32768;b[a+14>>1]=-32768;return 3}function c6n(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=-32768;b[a+4>>1]=-32768;b[a+6>>1]=(d[c+1|0]|0)+e&65535;b[a+8>>1]=(d[c+2|0]|0)+e&65535;b[a+10>>1]=-32768;b[a+12>>1]=-32768;b[a+14>>1]=-32768;return 3}function c6o(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=-32768;b[a+4>>1]=-32768;b[a+6>>1]=(d[c]|0)+e&65535;b[a+8>>1]=(d[c+1|0]|0)+e&65535;b[a+10>>1]=-32768;b[a+12>>1]=-32768;b[a+14>>1]=-32768;return 2}function c6p(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=(d[c+1|0]|0)+e&65535;b[a+4>>1]=(d[c+2|0]|0)+e&65535;b[a+6>>1]=-32768;b[a+8>>1]=(d[c+3|0]|0)+e&65535;b[a+10>>1]=-32768;b[a+12>>1]=-32768;b[a+14>>1]=-32768;return 4}function c6q(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=(d[c]|0)+e&65535;b[a+4>>1]=(d[c+1|0]|0)+e&65535;b[a+6>>1]=-32768;b[a+8>>1]=(d[c+2|0]|0)+e&65535;b[a+10>>1]=-32768;b[a+12>>1]=-32768;b[a+14>>1]=-32768;return 3}function c6r(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=-32768;b[a+4>>1]=(d[c+1|0]|0)+e&65535;b[a+6>>1]=-32768;b[a+8>>1]=(d[c+2|0]|0)+e&65535;b[a+10>>1]=-32768;b[a+12>>1]=-32768;b[a+14>>1]=-32768;return 3}function c6s(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=-32768;b[a+4>>1]=(d[c]|0)+e&65535;b[a+6>>1]=-32768;b[a+8>>1]=(d[c+1|0]|0)+e&65535;b[a+10>>1]=-32768;b[a+12>>1]=-32768;b[a+14>>1]=-32768;return 2}function c6t(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=(d[c+1|0]|0)+e&65535;b[a+4>>1]=-32768;b[a+6>>1]=-32768;b[a+8>>1]=(d[c+2|0]|0)+e&65535;b[a+10>>1]=-32768;b[a+12>>1]=-32768;b[a+14>>1]=-32768;return 3}function c6u(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=(d[c]|0)+e&65535;b[a+4>>1]=-32768;b[a+6>>1]=-32768;b[a+8>>1]=(d[c+1|0]|0)+e&65535;b[a+10>>1]=-32768;b[a+12>>1]=-32768;b[a+14>>1]=-32768;return 2}function c6v(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=-32768;b[a+4>>1]=-32768;b[a+6>>1]=-32768;b[a+8>>1]=(d[c+1|0]|0)+e&65535;b[a+10>>1]=-32768;b[a+12>>1]=-32768;b[a+14>>1]=-32768;return 2}function c6w(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=-32768;b[a+4>>1]=-32768;b[a+6>>1]=-32768;b[a+8>>1]=(d[c]|0)+e&65535;b[a+10>>1]=-32768;b[a+12>>1]=-32768;b[a+14>>1]=-32768;return 1}function c6x(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=(d[c+1|0]|0)+e&65535;b[a+4>>1]=(d[c+2|0]|0)+e&65535;b[a+6>>1]=(d[c+3|0]|0)+e&65535;b[a+8>>1]=-32768;b[a+10>>1]=-32768;b[a+12>>1]=-32768;b[a+14>>1]=-32768;return 4}function c6y(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=(d[c]|0)+e&65535;b[a+4>>1]=(d[c+1|0]|0)+e&65535;b[a+6>>1]=(d[c+2|0]|0)+e&65535;b[a+8>>1]=-32768;b[a+10>>1]=-32768;b[a+12>>1]=-32768;b[a+14>>1]=-32768;return 3}
function euq(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0;if((a[9623904]|0)!=0){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060]}c[2113050]=0;c[2276080]=0;RI();f=c[2394]|0;g=c[14130368+(f<<2)>>2]|0;if((g|0)!=0){gGC(g|0,9104152,280)|0}c[8452240+(f<<2)>>2]=c[2113054];c[2394]=-1;f=c[2439330]|0;g=(f|0)==0;if(!g){h=f;gGC(9706056,h|0,76)|0}h=c[2438118]|0;c[2433530]=h;i=c[3528484]|0;c[2076596]=i;j=c[2417276]|0;c[3541536]=j;c[1836236]=0;gGz(9706056,0,76);if(!g){g=f;gGC(g|0,9706056,76)|0}c[2438118]=h;c[3528484]=i;c[2417276]=j;c[1836236]=-1;c[2113156]=0;a[9628264]=0;c[2407033]=0;j=c[3541206]|0;c[3541190]=j;c[3541198]=j;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=j+256;c[3541199]=j+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=j+512;c[3541200]=j+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=j+768;c[3541201]=j+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;mx(0)}if((a[9753312]|0)!=0){j=d[7024792]|0;i=c[2411418]|0;h=c[2385754]|0;g=0;do{f=e[i+(g<<1)>>1]|0;k=f<<3&248;l=f>>>2&248;m=f>>>7&248;f=ag(k>>>5|k,j)|0;k=(ag(l>>>5|l,j)|0)>>>8;b[h+(g<<1)>>1]=((ag(m>>>5|m,j)|0)>>>11|f&63488|k<<3&2016)&65535;g=g+1|0;}while((g|0)<16384);a[9753312]=0}a[9625592]=0;a[9625594]=0;a[9625596]=0;g=0;j=0;h=0;i=0;do{j=((a[9633032+g|0]&1)<<g|j&255)&255;h=((a[9630904+g|0]&1)<<g|h&255)&255;i=((a[9551760+g|0]&1)<<g|i&255)&255;g=g+1|0;}while((g|0)<8);a[9625592]=j;a[9625594]=h;a[9625596]=i;a[9625593]=a[9551456]&1|a[9625593]&-4|a[9551457]<<1&2;i=c[2392]|0;if((i|0)>=0){gGz(8452240,0,((i|0)>0?(i<<2)+4|0:4)|0)}c[2113054]=0;i=c[2385548]|0;if((i|0)>0){gGz(9752472,0,((i|0)>1?i<<2:4)|0)}c[2433530]=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];i=c[3532592]|0;if((i|0)!=0){gGC(9104152,i|0,280)|0}c[2113054]=c[2113060]}i=c[2439330]|0;if((i|0)!=0){h=i;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;a[670544]=1;c[2113056]=58333;h=RG(58333)|0;c[2113054]=(c[2113054]|0)+h;c[2276108]=-1;c[2113056]=-1;h=c[3528492]>>2;do{if((h|0)>=1){if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){i=gfc(h)|0;c[2433530]=(c[2433530]|0)+i;break}else{c[2433530]=(c[2433530]|0)+h;break}}}while(0);h=c[2112964]|0;if((h|0)==0){n=0}else{i=a[9688]|0?133:0;gg[c[3542124]&4095](h,i);Uu(0,h,i);n=i}a[670544]=0;c[2113056]=58333;i=RG(58333)|0;c[2113054]=(c[2113054]|0)+i;c[2276108]=-1;c[2113056]=-1;c[8452200+(c[2394]<<2)>>2]=8194;c[2276080]=512;if((c[2276079]|0)>>>0<512){RH(2)}i=c[3528492]>>2;do{if((i|0)>=1){if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){h=gfc(i)|0;c[2433530]=(c[2433530]|0)+h;break}else{c[2433530]=(c[2433530]|0)+i;break}}}while(0);i=c[2112964]|0;if((i|0)==0){o=n}else{h=a[9688]|0?267:0;j=h-n|0;g=i+(n<<1<<1)|0;gg[c[3542124]&4095](g,j);Uu(0,g,j);o=h}a[670544]=1;c[2113056]=58333;h=RG(58333)|0;c[2113054]=(c[2113054]|0)+h;c[2276108]=-1;c[2113056]=-1;h=c[3528492]>>2;do{if((h|0)>=1){if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){j=gfc(h)|0;c[2433530]=(c[2433530]|0)+j;break}else{c[2433530]=(c[2433530]|0)+h;break}}}while(0);h=c[2112964]|0;if((h|0)==0){p=o}else{j=a[9688]|0?400:0;g=j-o|0;n=h+(o<<1<<1)|0;gg[c[3542124]&4095](n,g);Uu(0,n,g);p=j}a[670544]=0;c[2113056]=58333;j=RG(58333)|0;c[2113054]=(c[2113054]|0)+j;c[2276108]=-1;c[2113056]=-1;c[8452200+(c[2394]<<2)>>2]=8195;c[2276080]=768;if((c[2276079]|0)>>>0<768){RH(3)}j=c[3528492]>>2;do{if((j|0)>=1){if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){g=gfc(j)|0;c[2433530]=(c[2433530]|0)+g;break}else{c[2433530]=(c[2433530]|0)+j;break}}}while(0);j=c[2112964]|0;if((j|0)!=0){g=(a[9688]|0?534:0)-p|0;n=j+(p<<1<<1)|0;gg[c[3542124]&4095](n,g);Uu(0,n,g)}g=c[1836236]|0;n=c[9757320+(g<<2)>>2]|0;if((n|0)!=0){p=n;gGC(p|0,9706056,76)|0}c[9752472+(g<<2)>>2]=c[2433530];c[14113936+(g<<2)>>2]=c[2076596];c[9669104+(g<<2)>>2]=c[3541536];c[1836236]=-1;g=c[2394]|0;p=c[14130368+(g<<2)>>2]|0;if((p|0)!=0){gGC(p|0,9104152,280)|0}c[8452240+(g<<2)>>2]=c[2113054];c[2394]=-1;g=c[2112968]|0;if((g|0)==0){return 0}p=c[2411376]|0;gGz(p|0,0,81920);n=c[2385754]|0;j=c[2406902]|0;o=g;g=c[2405556]|0;h=0;i=0;k=0;while(1){f=(i|0)==32;m=(f&1)+h|0;l=f?0:i;f=(l<<4)-(e[7057656]|0)|0;q=(f|0)<-191?f+512|0:f;f=(m<<4)-(e[7057648]|0)|0;r=(f|0)<-255?f+512|0:f;f=q+15|0;L5875:do{if(f>>>0<=334){if((r+15|0)>>>0>270){break}s=e[j+(k<<1)>>1]|0;t=s>>>6&960;u=o+((r*320|0)+q<<1)|0;v=g+(s<<8&1048320)|0;if(q>>>0<305&r>>>0<241){s=u;w=v;x=0;while(1){b[s>>1]=b[n+((t|d[w]|12288)<<1)>>1]|0;b[s+2>>1]=b[n+((t|d[w+1|0]|12288)<<1)>>1]|0;b[s+4>>1]=b[n+((t|d[w+2|0]|12288)<<1)>>1]|0;b[s+6>>1]=b[n+((t|d[w+3|0]|12288)<<1)>>1]|0;b[s+8>>1]=b[n+((t|d[w+4|0]|12288)<<1)>>1]|0;b[s+10>>1]=b[n+((t|d[w+5|0]|12288)<<1)>>1]|0;b[s+12>>1]=b[n+((t|d[w+6|0]|12288)<<1)>>1]|0;b[s+14>>1]=b[n+((t|d[w+7|0]|12288)<<1)>>1]|0;b[s+16>>1]=b[n+((t|d[w+8|0]|12288)<<1)>>1]|0;b[s+18>>1]=b[n+((t|d[w+9|0]|12288)<<1)>>1]|0;b[s+20>>1]=b[n+((t|d[w+10|0]|12288)<<1)>>1]|0;b[s+22>>1]=b[n+((t|d[w+11|0]|12288)<<1)>>1]|0;b[s+24>>1]=b[n+((t|d[w+12|0]|12288)<<1)>>1]|0;b[s+26>>1]=b[n+((t|d[w+13|0]|12288)<<1)>>1]|0;b[s+28>>1]=b[n+((t|d[w+14|0]|12288)<<1)>>1]|0;b[s+30>>1]=b[n+((t|d[w+15|0]|12288)<<1)>>1]|0;y=x+1|0;if((y|0)<16){s=s+640|0;w=w+16|0;x=y}else{break L5875}}}x=q>>>0<320;w=(q+1|0)>>>0<320;s=(q+2|0)>>>0<320;y=(q+3|0)>>>0<320;z=(q+4|0)>>>0<320;A=(q+5|0)>>>0<320;B=(q+6|0)>>>0<320;C=(q+7|0)>>>0<320;D=(q+8|0)>>>0<320;E=(q+9|0)>>>0<320;F=(q+10|0)>>>0<320;G=(q+11|0)>>>0<320;H=(q+12|0)>>>0<320;I=(q+13|0)>>>0<320;J=(q+14|0)>>>0<320;K=f>>>0<320;L=u;M=v;N=0;while(1){do{if((N+r|0)>>>0<256){if(x){b[L>>1]=b[n+((t|d[M]|12288)<<1)>>1]|0}if(w){b[L+2>>1]=b[n+((t|d[M+1|0]|12288)<<1)>>1]|0}if(s){b[L+4>>1]=b[n+((t|d[M+2|0]|12288)<<1)>>1]|0}if(y){b[L+6>>1]=b[n+((t|d[M+3|0]|12288)<<1)>>1]|0}if(z){b[L+8>>1]=b[n+((t|d[M+4|0]|12288)<<1)>>1]|0}if(A){b[L+10>>1]=b[n+((t|d[M+5|0]|12288)<<1)>>1]|0}if(B){b[L+12>>1]=b[n+((t|d[M+6|0]|12288)<<1)>>1]|0}if(C){b[L+14>>1]=b[n+((t|d[M+7|0]|12288)<<1)>>1]|0}if(D){b[L+16>>1]=b[n+((t|d[M+8|0]|12288)<<1)>>1]|0}if(E){b[L+18>>1]=b[n+((t|d[M+9|0]|12288)<<1)>>1]|0}if(F){b[L+20>>1]=b[n+((t|d[M+10|0]|12288)<<1)>>1]|0}if(G){b[L+22>>1]=b[n+((t|d[M+11|0]|12288)<<1)>>1]|0}if(H){b[L+24>>1]=b[n+((t|d[M+12|0]|12288)<<1)>>1]|0}if(I){b[L+26>>1]=b[n+((t|d[M+13|0]|12288)<<1)>>1]|0}if(J){b[L+28>>1]=b[n+((t|d[M+14|0]|12288)<<1)>>1]|0}if(!K){break}b[L+30>>1]=b[n+((t|d[M+15|0]|12288)<<1)>>1]|0}}while(0);O=N+1|0;if((O|0)<16){L=L+640|0;M=M+16|0;N=O}else{break}}}}while(0);r=k+1|0;if((r|0)>=1024){break}h=m;i=l+1|0;k=r}k=c[2406904]|0;i=0;h=0;j=0;while(1){r=(h|0)==32;f=(r&1)+i|0;q=r?0:h;r=(q<<4)-(e[7057668]|0)|0;N=(r|0)<-191?r+512|0:r;r=(f<<4)-(e[7057664]|0)|0;M=(r|0)<-255?r+512|0:r;r=N+15|0;L5938:do{if(r>>>0<=334){if((M+15|0)>>>0>270){break}L=(N|0)>-1;t=b[k+((j|1)<<1)>>1]&16383;K=(t|0)==0;if(N>>>0<305&M>>>0<241){if(K){break}J=e[k+(j<<1)>>1]|0;I=J&31;H=((J&16|0)==0?I:I^48)<<6;I=(M*320|0)+N|0;G=o+(I<<1)|0;F=g+(t<<8)|0;E=p+I|0;if((J&128|0)==0){if((J&64|0)==0){D=G;C=F;B=E;A=0;while(1){z=a[C]|0;if(z<<24>>24!=0){b[D>>1]=b[n+((H|z&255|8192)<<1)>>1]|0;a[B]=2}z=a[C+1|0]|0;if(z<<24>>24!=0){b[D+2>>1]=b[n+((H|z&255|8192)<<1)>>1]|0;a[B+1|0]=2}z=a[C+2|0]|0;if(z<<24>>24!=0){b[D+4>>1]=b[n+((H|z&255|8192)<<1)>>1]|0;a[B+2|0]=2}z=a[C+3|0]|0;if(z<<24>>24!=0){b[D+6>>1]=b[n+((H|z&255|8192)<<1)>>1]|0;a[B+3|0]=2}z=a[C+4|0]|0;if(z<<24>>24!=0){b[D+8>>1]=b[n+((H|z&255|8192)<<1)>>1]|0;a[B+4|0]=2}z=a[C+5|0]|0;if(z<<24>>24!=0){b[D+10>>1]=b[n+((H|z&255|8192)<<1)>>1]|0;a[B+5|0]=2}z=a[C+6|0]|0;if(z<<24>>24!=0){b[D+12>>1]=b[n+((H|z&255|8192)<<1)>>1]|0;a[B+6|0]=2}z=a[C+7|0]|0;if(z<<24>>24!=0){b[D+14>>1]=b[n+((H|z&255|8192)<<1)>>1]|0;a[B+7|0]=2}z=a[C+8|0]|0;if(z<<24>>24!=0){b[D+16>>1]=b[n+((H|z&255|8192)<<1)>>1]|0;a[B+8|0]=2}z=a[C+9|0]|0;if(z<<24>>24!=0){b[D+18>>1]=b[n+((H|z&255|8192)<<1)>>1]|0;a[B+9|0]=2}z=a[C+10|0]|0;if(z<<24>>24!=0){b[D+20>>1]=b[n+((H|z&255|8192)<<1)>>1]|0;a[B+10|0]=2}z=a[C+11|0]|0;if(z<<24>>24!=0){b[D+22>>1]=b[n+((H|z&255|8192)<<1)>>1]|0;a[B+11|0]=2}z=a[C+12|0]|0;if(z<<24>>24!=0){b[D+24>>1]=b[n+((H|z&255|8192)<<1)>>1]|0;a[B+12|0]=2}z=a[C+13|0]|0;if(z<<24>>24!=0){b[D+26>>1]=b[n+((H|z&255|8192)<<1)>>1]|0;a[B+13|0]=2}z=a[C+14|0]|0;if(z<<24>>24!=0){b[D+28>>1]=b[n+((H|z&255|8192)<<1)>>1]|0;a[B+14|0]=2}z=a[C+15|0]|0;if(z<<24>>24!=0){b[D+30>>1]=b[n+((H|z&255|8192)<<1)>>1]|0;a[B+15|0]=2}z=A+1|0;if((z|0)<16){D=D+640|0;C=C+16|0;B=B+320|0;A=z}else{break L5938}}}else{A=G;B=F;C=E;D=0;while(1){z=a[B]|0;if(z<<24>>24!=0){b[A+30>>1]=b[n+((H|z&255|8192)<<1)>>1]|0;a[C+15|0]=2}z=a[B+1|0]|0;if(z<<24>>24!=0){b[A+28>>1]=b[n+((H|z&255|8192)<<1)>>1]|0;a[C+14|0]=2}z=a[B+2|0]|0;if(z<<24>>24!=0){b[A+26>>1]=b[n+((H|z&255|8192)<<1)>>1]|0;a[C+13|0]=2}z=a[B+3|0]|0;if(z<<24>>24!=0){b[A+24>>1]=b[n+((H|z&255|8192)<<1)>>1]|0;a[C+12|0]=2}z=a[B+4|0]|0;if(z<<24>>24!=0){b[A+22>>1]=b[n+((H|z&255|8192)<<1)>>1]|0;a[C+11|0]=2}z=a[B+5|0]|0;if(z<<24>>24!=0){b[A+20>>1]=b[n+((H|z&255|8192)<<1)>>1]|0;a[C+10|0]=2}z=a[B+6|0]|0;if(z<<24>>24!=0){b[A+18>>1]=b[n+((H|z&255|8192)<<1)>>1]|0;a[C+9|0]=2}z=a[B+7|0]|0;if(z<<24>>24!=0){b[A+16>>1]=b[n+((H|z&255|8192)<<1)>>1]|0;a[C+8|0]=2}z=a[B+8|0]|0;if(z<<24>>24!=0){b[A+14>>1]=b[n+((H|z&255|8192)<<1)>>1]|0;a[C+7|0]=2}z=a[B+9|0]|0;if(z<<24>>24!=0){b[A+12>>1]=b[n+((H|z&255|8192)<<1)>>1]|0;a[C+6|0]=2}z=a[B+10|0]|0;if(z<<24>>24!=0){b[A+10>>1]=b[n+((H|z&255|8192)<<1)>>1]|0;a[C+5|0]=2}z=a[B+11|0]|0;if(z<<24>>24!=0){b[A+8>>1]=b[n+((H|z&255|8192)<<1)>>1]|0;a[C+4|0]=2}z=a[B+12|0]|0;if(z<<24>>24!=0){b[A+6>>1]=b[n+((H|z&255|8192)<<1)>>1]|0;a[C+3|0]=2}z=a[B+13|0]|0;if(z<<24>>24!=0){b[A+4>>1]=b[n+((H|z&255|8192)<<1)>>1]|0;a[C+2|0]=2}z=a[B+14|0]|0;if(z<<24>>24!=0){b[A+2>>1]=b[n+((H|z&255|8192)<<1)>>1]|0;a[C+1|0]=2}z=a[B+15|0]|0;if(z<<24>>24!=0){b[A>>1]=b[n+((H|z&255|8192)<<1)>>1]|0;a[C]=2}z=D+1|0;if((z|0)<16){A=A+640|0;B=B+16|0;C=C+320|0;D=z}else{break L5938}}}}else{D=I+4800|0;C=o+(D<<1)|0;B=p+D|0;if((J&64|0)==0){D=C;A=F;E=B;G=0;while(1){z=a[A]|0;if(z<<24>>24!=0){b[D>>1]=b[n+((H|z&255|8192)<<1)>>1]|0;a[E]=2}z=a[A+1|0]|0;if(z<<24>>24!=0){b[D+2>>1]=b[n+((H|z&255|8192)<<1)>>1]|0;a[E+1|0]=2}z=a[A+2|0]|0;if(z<<24>>24!=0){b[D+4>>1]=b[n+((H|z&255|8192)<<1)>>1]|0;a[E+2|0]=2}z=a[A+3|0]|0;if(z<<24>>24!=0){b[D+6>>1]=b[n+((H|z&255|8192)<<1)>>1]|0;a[E+3|0]=2}z=a[A+4|0]|0;if(z<<24>>24!=0){b[D+8>>1]=b[n+((H|z&255|8192)<<1)>>1]|0;a[E+4|0]=2}z=a[A+5|0]|0;if(z<<24>>24!=0){b[D+10>>1]=b[n+((H|z&255|8192)<<1)>>1]|0;a[E+5|0]=2}z=a[A+6|0]|0;if(z<<24>>24!=0){b[D+12>>1]=b[n+((H|z&255|8192)<<1)>>1]|0;a[E+6|0]=2}z=a[A+7|0]|0;if(z<<24>>24!=0){b[D+14>>1]=b[n+((H|z&255|8192)<<1)>>1]|0;a[E+7|0]=2}z=a[A+8|0]|0;if(z<<24>>24!=0){b[D+16>>1]=b[n+((H|z&255|8192)<<1)>>1]|0;a[E+8|0]=2}z=a[A+9|0]|0;if(z<<24>>24!=0){b[D+18>>1]=b[n+((H|z&255|8192)<<1)>>1]|0;a[E+9|0]=2}z=a[A+10|0]|0;if(z<<24>>24!=0){b[D+20>>1]=b[n+((H|z&255|8192)<<1)>>1]|0;a[E+10|0]=2}z=a[A+11|0]|0;if(z<<24>>24!=0){b[D+22>>1]=b[n+((H|z&255|8192)<<1)>>1]|0;a[E+11|0]=2}z=a[A+12|0]|0;if(z<<24>>24!=0){b[D+24>>1]=b[n+((H|z&255|8192)<<1)>>1]|0;a[E+12|0]=2}z=a[A+13|0]|0;if(z<<24>>24!=0){b[D+26>>1]=b[n+((H|z&255|8192)<<1)>>1]|0;a[E+13|0]=2}z=a[A+14|0]|0;if(z<<24>>24!=0){b[D+28>>1]=b[n+((H|z&255|8192)<<1)>>1]|0;a[E+14|0]=2}z=a[A+15|0]|0;if(z<<24>>24!=0){b[D+30>>1]=b[n+((H|z&255|8192)<<1)>>1]|0;a[E+15|0]=2}z=G+1|0;if((z|0)<16){D=D-640|0;A=A+16|0;E=E-320|0;G=z}else{break L5938}}}else{G=C;E=F;A=B;D=0;while(1){J=a[E]|0;if(J<<24>>24!=0){b[G+30>>1]=b[n+((H|J&255|8192)<<1)>>1]|0;a[A+15|0]=2}J=a[E+1|0]|0;if(J<<24>>24!=0){b[G+28>>1]=b[n+((H|J&255|8192)<<1)>>1]|0;a[A+14|0]=2}J=a[E+2|0]|0;if(J<<24>>24!=0){b[G+26>>1]=b[n+((H|J&255|8192)<<1)>>1]|0;a[A+13|0]=2}J=a[E+3|0]|0;if(J<<24>>24!=0){b[G+24>>1]=b[n+((H|J&255|8192)<<1)>>1]|0;a[A+12|0]=2}J=a[E+4|0]|0;if(J<<24>>24!=0){b[G+22>>1]=b[n+((H|J&255|8192)<<1)>>1]|0;a[A+11|0]=2}J=a[E+5|0]|0;if(J<<24>>24!=0){b[G+20>>1]=b[n+((H|J&255|8192)<<1)>>1]|0;a[A+10|0]=2}J=a[E+6|0]|0;if(J<<24>>24!=0){b[G+18>>1]=b[n+((H|J&255|8192)<<1)>>1]|0;a[A+9|0]=2}J=a[E+7|0]|0;if(J<<24>>24!=0){b[G+16>>1]=b[n+((H|J&255|8192)<<1)>>1]|0;a[A+8|0]=2}J=a[E+8|0]|0;if(J<<24>>24!=0){b[G+14>>1]=b[n+((H|J&255|8192)<<1)>>1]|0;a[A+7|0]=2}J=a[E+9|0]|0;if(J<<24>>24!=0){b[G+12>>1]=b[n+((H|J&255|8192)<<1)>>1]|0;a[A+6|0]=2}J=a[E+10|0]|0;if(J<<24>>24!=0){b[G+10>>1]=b[n+((H|J&255|8192)<<1)>>1]|0;a[A+5|0]=2}J=a[E+11|0]|0;if(J<<24>>24!=0){b[G+8>>1]=b[n+((H|J&255|8192)<<1)>>1]|0;a[A+4|0]=2}J=a[E+12|0]|0;if(J<<24>>24!=0){b[G+6>>1]=b[n+((H|J&255|8192)<<1)>>1]|0;a[A+3|0]=2}J=a[E+13|0]|0;if(J<<24>>24!=0){b[G+4>>1]=b[n+((H|J&255|8192)<<1)>>1]|0;a[A+2|0]=2}J=a[E+14|0]|0;if(J<<24>>24!=0){b[G+2>>1]=b[n+((H|J&255|8192)<<1)>>1]|0;a[A+1|0]=2}J=a[E+15|0]|0;if(J<<24>>24!=0){b[G>>1]=b[n+((H|J&255|8192)<<1)>>1]|0;a[A]=2}J=D+1|0;if((J|0)<16){G=G-640|0;E=E+16|0;A=A-320|0;D=J}else{break L5938}}}}}if(K){break}D=e[k+(j<<1)>>1]|0;A=D&31;E=((D&16|0)==0?A:A^48)<<6;A=(M*320|0)+N|0;G=o+(A<<1)|0;H=g+(t<<8)|0;B=p+A|0;if((D&128|0)==0){F=(N|0)<320;if((D&64|0)==0){C=(N+1|0)>>>0>319;J=(N+2|0)>>>0>319;I=(N+3|0)>>>0>319;z=(N+4|0)>>>0>319;y=(N+5|0)>>>0>319;s=(N+6|0)>>>0>319;w=(N+7|0)>>>0>319;x=(N+8|0)>>>0>319;v=(N+9|0)>>>0>319;u=(N+10|0)>>>0>319;O=(N+11|0)>>>0>319;P=(N+12|0)>>>0>319;Q=(N+13|0)>>>0>319;R=(N+14|0)>>>0>319;S=r>>>0>319;T=G;U=H;V=B;W=0;while(1){do{if((W+M|0)>>>0<256){X=a[U]|0;if(L&X<<24>>24!=0&F){b[T>>1]=b[n+((E|X&255|8192)<<1)>>1]|0;a[V]=2}X=a[U+1|0]|0;if(!(X<<24>>24==0|C)){b[T+2>>1]=b[n+((E|X&255|8192)<<1)>>1]|0;a[V+1|0]=2}X=a[U+2|0]|0;if(!(X<<24>>24==0|J)){b[T+4>>1]=b[n+((E|X&255|8192)<<1)>>1]|0;a[V+2|0]=2}X=a[U+3|0]|0;if(!(X<<24>>24==0|I)){b[T+6>>1]=b[n+((E|X&255|8192)<<1)>>1]|0;a[V+3|0]=2}X=a[U+4|0]|0;if(!(X<<24>>24==0|z)){b[T+8>>1]=b[n+((E|X&255|8192)<<1)>>1]|0;a[V+4|0]=2}X=a[U+5|0]|0;if(!(X<<24>>24==0|y)){b[T+10>>1]=b[n+((E|X&255|8192)<<1)>>1]|0;a[V+5|0]=2}X=a[U+6|0]|0;if(!(X<<24>>24==0|s)){b[T+12>>1]=b[n+((E|X&255|8192)<<1)>>1]|0;a[V+6|0]=2}X=a[U+7|0]|0;if(!(X<<24>>24==0|w)){b[T+14>>1]=b[n+((E|X&255|8192)<<1)>>1]|0;a[V+7|0]=2}X=a[U+8|0]|0;if(!(X<<24>>24==0|x)){b[T+16>>1]=b[n+((E|X&255|8192)<<1)>>1]|0;a[V+8|0]=2}X=a[U+9|0]|0;if(!(X<<24>>24==0|v)){b[T+18>>1]=b[n+((E|X&255|8192)<<1)>>1]|0;a[V+9|0]=2}X=a[U+10|0]|0;if(!(X<<24>>24==0|u)){b[T+20>>1]=b[n+((E|X&255|8192)<<1)>>1]|0;a[V+10|0]=2}X=a[U+11|0]|0;if(!(X<<24>>24==0|O)){b[T+22>>1]=b[n+((E|X&255|8192)<<1)>>1]|0;a[V+11|0]=2}X=a[U+12|0]|0;if(!(X<<24>>24==0|P)){b[T+24>>1]=b[n+((E|X&255|8192)<<1)>>1]|0;a[V+12|0]=2}X=a[U+13|0]|0;if(!(X<<24>>24==0|Q)){b[T+26>>1]=b[n+((E|X&255|8192)<<1)>>1]|0;a[V+13|0]=2}X=a[U+14|0]|0;if(!(X<<24>>24==0|R)){b[T+28>>1]=b[n+((E|X&255|8192)<<1)>>1]|0;a[V+14|0]=2}X=a[U+15|0]|0;if(X<<24>>24==0|S){break}b[T+30>>1]=b[n+((E|X&255|8192)<<1)>>1]|0;a[V+15|0]=2}}while(0);X=W+1|0;if((X|0)<16){T=T+640|0;U=U+16|0;V=V+320|0;W=X}else{break}}}else{W=r>>>0>319;V=(N+14|0)>>>0>319;U=(N+13|0)>>>0>319;T=(N+12|0)>>>0>319;S=(N+11|0)>>>0>319;R=(N+10|0)>>>0>319;Q=(N+9|0)>>>0>319;P=(N+8|0)>>>0>319;O=(N+7|0)>>>0>319;u=(N+6|0)>>>0>319;v=(N+5|0)>>>0>319;x=(N+4|0)>>>0>319;w=(N+3|0)>>>0>319;s=(N+2|0)>>>0>319;y=(N+1|0)>>>0>319;z=G;I=H;J=B;C=0;while(1){do{if((C+M|0)>>>0<256){t=a[I]|0;if(!(t<<24>>24==0|W)){b[z+30>>1]=b[n+((E|t&255|8192)<<1)>>1]|0;a[J+15|0]=2}t=a[I+1|0]|0;if(!(t<<24>>24==0|V)){b[z+28>>1]=b[n+((E|t&255|8192)<<1)>>1]|0;a[J+14|0]=2}t=a[I+2|0]|0;if(!(t<<24>>24==0|U)){b[z+26>>1]=b[n+((E|t&255|8192)<<1)>>1]|0;a[J+13|0]=2}t=a[I+3|0]|0;if(!(t<<24>>24==0|T)){b[z+24>>1]=b[n+((E|t&255|8192)<<1)>>1]|0;a[J+12|0]=2}t=a[I+4|0]|0;if(!(t<<24>>24==0|S)){b[z+22>>1]=b[n+((E|t&255|8192)<<1)>>1]|0;a[J+11|0]=2}t=a[I+5|0]|0;if(!(t<<24>>24==0|R)){b[z+20>>1]=b[n+((E|t&255|8192)<<1)>>1]|0;a[J+10|0]=2}t=a[I+6|0]|0;if(!(t<<24>>24==0|Q)){b[z+18>>1]=b[n+((E|t&255|8192)<<1)>>1]|0;a[J+9|0]=2}t=a[I+7|0]|0;if(!(t<<24>>24==0|P)){b[z+16>>1]=b[n+((E|t&255|8192)<<1)>>1]|0;a[J+8|0]=2}t=a[I+8|0]|0;if(!(t<<24>>24==0|O)){b[z+14>>1]=b[n+((E|t&255|8192)<<1)>>1]|0;a[J+7|0]=2}t=a[I+9|0]|0;if(!(t<<24>>24==0|u)){b[z+12>>1]=b[n+((E|t&255|8192)<<1)>>1]|0;a[J+6|0]=2}t=a[I+10|0]|0;if(!(t<<24>>24==0|v)){b[z+10>>1]=b[n+((E|t&255|8192)<<1)>>1]|0;a[J+5|0]=2}t=a[I+11|0]|0;if(!(t<<24>>24==0|x)){b[z+8>>1]=b[n+((E|t&255|8192)<<1)>>1]|0;a[J+4|0]=2}t=a[I+12|0]|0;if(!(t<<24>>24==0|w)){b[z+6>>1]=b[n+((E|t&255|8192)<<1)>>1]|0;a[J+3|0]=2}t=a[I+13|0]|0;if(!(t<<24>>24==0|s)){b[z+4>>1]=b[n+((E|t&255|8192)<<1)>>1]|0;a[J+2|0]=2}t=a[I+14|0]|0;if(!(t<<24>>24==0|y)){b[z+2>>1]=b[n+((E|t&255|8192)<<1)>>1]|0;a[J+1|0]=2}t=a[I+15|0]|0;if(!(L&t<<24>>24!=0&F)){break}b[z>>1]=b[n+((E|t&255|8192)<<1)>>1]|0;a[J]=2}}while(0);t=C+1|0;if((t|0)<16){z=z+640|0;I=I+16|0;J=J+320|0;C=t}else{break}}}}else{C=A+4800|0;J=o+(C<<1)|0;I=p+C|0;C=(N|0)<320;if((D&64|0)==0){z=(N+1|0)>>>0>319;F=(N+2|0)>>>0>319;y=(N+3|0)>>>0>319;s=(N+4|0)>>>0>319;w=(N+5|0)>>>0>319;x=(N+6|0)>>>0>319;v=(N+7|0)>>>0>319;u=(N+8|0)>>>0>319;O=(N+9|0)>>>0>319;P=(N+10|0)>>>0>319;Q=(N+11|0)>>>0>319;R=(N+12|0)>>>0>319;S=(N+13|0)>>>0>319;T=(N+14|0)>>>0>319;U=r>>>0>319;V=J;W=H;B=I;G=0;while(1){do{if((G+M|0)>>>0<256){t=a[W]|0;if(L&t<<24>>24!=0&C){b[V>>1]=b[n+((E|t&255|8192)<<1)>>1]|0;a[B]=2}t=a[W+1|0]|0;if(!(t<<24>>24==0|z)){b[V+2>>1]=b[n+((E|t&255|8192)<<1)>>1]|0;a[B+1|0]=2}t=a[W+2|0]|0;if(!(t<<24>>24==0|F)){b[V+4>>1]=b[n+((E|t&255|8192)<<1)>>1]|0;a[B+2|0]=2}t=a[W+3|0]|0;if(!(t<<24>>24==0|y)){b[V+6>>1]=b[n+((E|t&255|8192)<<1)>>1]|0;a[B+3|0]=2}t=a[W+4|0]|0;if(!(t<<24>>24==0|s)){b[V+8>>1]=b[n+((E|t&255|8192)<<1)>>1]|0;a[B+4|0]=2}t=a[W+5|0]|0;if(!(t<<24>>24==0|w)){b[V+10>>1]=b[n+((E|t&255|8192)<<1)>>1]|0;a[B+5|0]=2}t=a[W+6|0]|0;if(!(t<<24>>24==0|x)){b[V+12>>1]=b[n+((E|t&255|8192)<<1)>>1]|0;a[B+6|0]=2}t=a[W+7|0]|0;if(!(t<<24>>24==0|v)){b[V+14>>1]=b[n+((E|t&255|8192)<<1)>>1]|0;a[B+7|0]=2}t=a[W+8|0]|0;if(!(t<<24>>24==0|u)){b[V+16>>1]=b[n+((E|t&255|8192)<<1)>>1]|0;a[B+8|0]=2}t=a[W+9|0]|0;if(!(t<<24>>24==0|O)){b[V+18>>1]=b[n+((E|t&255|8192)<<1)>>1]|0;a[B+9|0]=2}t=a[W+10|0]|0;if(!(t<<24>>24==0|P)){b[V+20>>1]=b[n+((E|t&255|8192)<<1)>>1]|0;a[B+10|0]=2}t=a[W+11|0]|0;if(!(t<<24>>24==0|Q)){b[V+22>>1]=b[n+((E|t&255|8192)<<1)>>1]|0;a[B+11|0]=2}t=a[W+12|0]|0;if(!(t<<24>>24==0|R)){b[V+24>>1]=b[n+((E|t&255|8192)<<1)>>1]|0;a[B+12|0]=2}t=a[W+13|0]|0;if(!(t<<24>>24==0|S)){b[V+26>>1]=b[n+((E|t&255|8192)<<1)>>1]|0;a[B+13|0]=2}t=a[W+14|0]|0;if(!(t<<24>>24==0|T)){b[V+28>>1]=b[n+((E|t&255|8192)<<1)>>1]|0;a[B+14|0]=2}t=a[W+15|0]|0;if(t<<24>>24==0|U){break}b[V+30>>1]=b[n+((E|t&255|8192)<<1)>>1]|0;a[B+15|0]=2}}while(0);t=G+1|0;if((t|0)<16){V=V-640|0;W=W+16|0;B=B-320|0;G=t}else{break}}}else{G=r>>>0>319;B=(N+14|0)>>>0>319;W=(N+13|0)>>>0>319;V=(N+12|0)>>>0>319;U=(N+11|0)>>>0>319;T=(N+10|0)>>>0>319;S=(N+9|0)>>>0>319;R=(N+8|0)>>>0>319;Q=(N+7|0)>>>0>319;P=(N+6|0)>>>0>319;O=(N+5|0)>>>0>319;u=(N+4|0)>>>0>319;v=(N+3|0)>>>0>319;x=(N+2|0)>>>0>319;w=(N+1|0)>>>0>319;s=J;y=H;F=I;z=0;while(1){do{if((z+M|0)>>>0<256){D=a[y]|0;if(!(D<<24>>24==0|G)){b[s+30>>1]=b[n+((E|D&255|8192)<<1)>>1]|0;a[F+15|0]=2}D=a[y+1|0]|0;if(!(D<<24>>24==0|B)){b[s+28>>1]=b[n+((E|D&255|8192)<<1)>>1]|0;a[F+14|0]=2}D=a[y+2|0]|0;if(!(D<<24>>24==0|W)){b[s+26>>1]=b[n+((E|D&255|8192)<<1)>>1]|0;a[F+13|0]=2}D=a[y+3|0]|0;if(!(D<<24>>24==0|V)){b[s+24>>1]=b[n+((E|D&255|8192)<<1)>>1]|0;a[F+12|0]=2}D=a[y+4|0]|0;if(!(D<<24>>24==0|U)){b[s+22>>1]=b[n+((E|D&255|8192)<<1)>>1]|0;a[F+11|0]=2}D=a[y+5|0]|0;if(!(D<<24>>24==0|T)){b[s+20>>1]=b[n+((E|D&255|8192)<<1)>>1]|0;a[F+10|0]=2}D=a[y+6|0]|0;if(!(D<<24>>24==0|S)){b[s+18>>1]=b[n+((E|D&255|8192)<<1)>>1]|0;a[F+9|0]=2}D=a[y+7|0]|0;if(!(D<<24>>24==0|R)){b[s+16>>1]=b[n+((E|D&255|8192)<<1)>>1]|0;a[F+8|0]=2}D=a[y+8|0]|0;if(!(D<<24>>24==0|Q)){b[s+14>>1]=b[n+((E|D&255|8192)<<1)>>1]|0;a[F+7|0]=2}D=a[y+9|0]|0;if(!(D<<24>>24==0|P)){b[s+12>>1]=b[n+((E|D&255|8192)<<1)>>1]|0;a[F+6|0]=2}D=a[y+10|0]|0;if(!(D<<24>>24==0|O)){b[s+10>>1]=b[n+((E|D&255|8192)<<1)>>1]|0;a[F+5|0]=2}D=a[y+11|0]|0;if(!(D<<24>>24==0|u)){b[s+8>>1]=b[n+((E|D&255|8192)<<1)>>1]|0;a[F+4|0]=2}D=a[y+12|0]|0;if(!(D<<24>>24==0|v)){b[s+6>>1]=b[n+((E|D&255|8192)<<1)>>1]|0;a[F+3|0]=2}D=a[y+13|0]|0;if(!(D<<24>>24==0|x)){b[s+4>>1]=b[n+((E|D&255|8192)<<1)>>1]|0;a[F+2|0]=2}D=a[y+14|0]|0;if(!(D<<24>>24==0|w)){b[s+2>>1]=b[n+((E|D&255|8192)<<1)>>1]|0;a[F+1|0]=2}D=a[y+15|0]|0;if(!(L&D<<24>>24!=0&C)){break}b[s>>1]=b[n+((E|D&255|8192)<<1)>>1]|0;a[F]=2}}while(0);D=z+1|0;if((D|0)<16){s=s-640|0;y=y+16|0;F=F-320|0;z=D}else{break}}}}}}while(0);M=j+2|0;if((M|0)<2048){i=f;h=q+1|0;j=M}else{break}}j=c[2411364]|0;h=j+8176|0;do{i=e[h>>1]|0;p=256-(i<<8&768|b[h+2>>1]&255)|0;g=e[h+8>>1]|0;k=g<<8&256|b[h+10>>1]&255;M=k+1|0;N=e[h+4>>1]<<8&65280|b[h+6>>1]&255;r=i>>>4&1;l=i>>>3&1;m=g&62;z=g>>>5&2;F=((g&32|0)==0?m:m^96)<<5;m=(i>>>5&7)+1|0;if((i&4|0)!=0){i=k-511|0;k=0;do{g=k+N|0;y=p-(k<<4)|0;s=y-16|0;euw(g,F,r,l,M,s,z);euw(g,F,r,l,i,s,z);s=y+496|0;euw(g,F,r,l,M,s,z);euw(g,F,r,l,i,s,z);k=k+1|0;}while((k|0)<(m|0))}h=h-16|0;}while(h>>>0>=j>>>0);j=c[2418174]|0;h=c[2405560]|0;m=0;k=0;z=0;while(1){i=(k|0)==64;l=(i&1)+m|0;r=i?0:k;i=r<<3;F=l<<3;M=i|7;L6376:do{if(M>>>0<=326){if((F|7)>>>0>262){break}p=e[j+((z|1)<<1)>>1]|0;N=p<<8&3840|b[j+(z<<1)>>1]&255;q=(N|0)==0;if(!(i>>>0<312&F>>>0<248)){if(q){break}f=p<<2&960;s=(l*2560|0)+i|0;g=N<<6;y=M>>>0<320;if(i>>>0>=320){if(F>>>0>255|y^1){break}b[o+((s|7)<<1)>>1]=b[n+((d[h+(g|7)|0]|f)<<1)>>1]|0;b[o+(s+327<<1)>>1]=b[n+((d[h+(g|15)|0]|f)<<1)>>1]|0;b[o+(s+647<<1)>>1]=b[n+((d[h+((g|8)+15)|0]|f)<<1)>>1]|0;E=g|24;b[o+(s+967<<1)>>1]=b[n+((d[h+(g|31)|0]|f)<<1)>>1]|0;b[o+(s+1287<<1)>>1]=b[n+((d[h+(E+15)|0]|f)<<1)>>1]|0;b[o+(s+1607<<1)>>1]=b[n+((d[h+(E+23)|0]|f)<<1)>>1]|0;b[o+(s+1927<<1)>>1]=b[n+((d[h+(E+31)|0]|f)<<1)>>1]|0;b[o+(s+2247<<1)>>1]=b[n+((d[h+(g|63)|0]|f)<<1)>>1]|0;break}E=o+(s<<1)|0;s=h+g|0;g=0;while(1){do{if((g+F|0)>>>0<256){b[E>>1]=b[n+((d[s]|f)<<1)>>1]|0;b[E+2>>1]=b[n+((d[s+1|0]|f)<<1)>>1]|0;b[E+4>>1]=b[n+((d[s+2|0]|f)<<1)>>1]|0;b[E+6>>1]=b[n+((d[s+3|0]|f)<<1)>>1]|0;b[E+8>>1]=b[n+((d[s+4|0]|f)<<1)>>1]|0;b[E+10>>1]=b[n+((d[s+5|0]|f)<<1)>>1]|0;b[E+12>>1]=b[n+((d[s+6|0]|f)<<1)>>1]|0;if(!y){break}b[E+14>>1]=b[n+((d[s+7|0]|f)<<1)>>1]|0}}while(0);C=g+1|0;if((C|0)<8){E=E+640|0;s=s+8|0;g=C}else{break L6376}}}if(q){break}g=p<<2&960;s=o+((l*2560|0)+i<<1)|0;E=h+(N<<6)|0;f=0;while(1){y=a[E]|0;if(y<<24>>24!=0){b[s>>1]=b[n+((y&255|g)<<1)>>1]|0}y=a[E+1|0]|0;if(y<<24>>24!=0){b[s+2>>1]=b[n+((y&255|g)<<1)>>1]|0}y=a[E+2|0]|0;if(y<<24>>24!=0){b[s+4>>1]=b[n+((y&255|g)<<1)>>1]|0}y=a[E+3|0]|0;if(y<<24>>24!=0){b[s+6>>1]=b[n+((y&255|g)<<1)>>1]|0}y=a[E+4|0]|0;if(y<<24>>24!=0){b[s+8>>1]=b[n+((y&255|g)<<1)>>1]|0}y=a[E+5|0]|0;if(y<<24>>24!=0){b[s+10>>1]=b[n+((y&255|g)<<1)>>1]|0}y=a[E+6|0]|0;if(y<<24>>24!=0){b[s+12>>1]=b[n+((y&255|g)<<1)>>1]|0}y=a[E+7|0]|0;if(y<<24>>24!=0){b[s+14>>1]=b[n+((y&255|g)<<1)>>1]|0}y=f+1|0;if((y|0)<8){s=s+640|0;E=E+8|0;f=y}else{break}}}}while(0);i=z+2|0;if((i|0)<4096){m=l;k=r+1|0;z=i}else{break}}return 0}function eur(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;h=i;i=i+208|0;j=h|0;k=h+16|0;l=h+32|0;m=h+48|0;n=h+64|0;o=h+80|0;p=h+96|0;q=h+112|0;r=h+128|0;s=h+144|0;t=h+160|0;u=h+176|0;v=h+192|0;if((g|0)!=0){c[g>>2]=169585}if((f&32|0)!=0){gGz(v|0,0,12);g=c[2405626]|0;c[v>>2]=g;c[v+4>>2]=(c[2411590]|0)-g;c[v+12>>2]=162152;g=c[2076592]|0;gj[g&4095](v)|0}if((f&64|0)==0){w=f&2}else{v=n|0;gGz(m|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){g=n+9|0;n=l;x=l|0;y=l+4|0;z=l+12|0;A=m|0;B=m+4|0;C=m+12|0;D=0;do{gGC(v|0,614896,11)|0;a[g]=D+48&255;E=8452256+(D<<2)|0;gGz(n|0,0,12);c[x>>2]=E;c[y>>2]=4;c[z>>2]=164976;gj[c[2076592]&4095](l)|0;if((c[E>>2]|0)!=0){c[A>>2]=c[14130368+(D<<2)>>2];c[B>>2]=c[8452184+(D<<2)>>2];c[C>>2]=v;E=c[2076592]|0;gj[E&4095](m)|0}D=D+1|0;}while((D|0)<=(c[2392]|0))}fw$(f);Ut(0);gGz(k|0,0,12);c[k>>2]=8453216;c[k+4>>2]=4;c[k+12>>2]=107480;D=c[2076592]|0;gj[D&4095](k)|0;gGz(j|0,0,12);c[j>>2]=14168504;c[j+4>>2]=256;c[j+12>>2]=476464;k=c[2076592]|0;gj[k&4095](j)|0;j=f&2;if((j|0)!=0){f=0;do{mv(0,f,d[14168504+f|0]|0);f=f+1|0;}while((f|0)<256)}gGz(u|0,0,12);c[u>>2]=9625592;c[u+4>>2]=8;c[u+12>>2]=215728;f=c[2076592]|0;gj[f&4095](u)|0;gGz(t|0,0,12);c[t>>2]=7024792;c[t+4>>2]=1;c[t+12>>2]=564272;u=c[2076592]|0;gj[u&4095](t)|0;gGz(s|0,0,12);c[s>>2]=14115336;c[s+4>>2]=2;c[s+12>>2]=548456;t=c[2076592]|0;gj[t&4095](s)|0;gGz(r|0,0,12);c[r>>2]=14115328;c[r+4>>2]=2;c[r+12>>2]=534304;s=c[2076592]|0;gj[s&4095](r)|0;gGz(q|0,0,12);c[q>>2]=14115312;c[q+4>>2]=2;c[q+12>>2]=520704;r=c[2076592]|0;gj[r&4095](q)|0;gGz(p|0,0,12);c[p>>2]=14115296;c[p+4>>2]=2;c[p+12>>2]=507600;q=c[2076592]|0;gj[q&4095](p)|0;gGz(o|0,0,12);c[o>>2]=9775448;c[o+4>>2]=1;c[o+12>>2]=495376;p=c[2076592]|0;gj[p&4095](o)|0;w=j}if((w|0)==0){i=h;return 0}w=d[7024792]|0;j=c[2411418]|0;o=c[2385754]|0;p=0;do{q=e[j+(p<<1)>>1]|0;r=q<<3&248;s=q>>>2&248;t=q>>>7&248;q=ag(r>>>5|r,w)|0;r=(ag(s>>>5|s,w)|0)>>>8;b[o+(p<<1)>>1]=((ag(t>>>5|t,w)|0)>>>11|q&63488|r<<3&2016)&65535;p=p+1|0;}while((p|0)<16384);i=h;return 0}function eus(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2291468+(b*112|0)>>2];c[a+104>>2]=c[2291472+(b*112|0)>>2];c[a+108>>2]=c[2291476+(b*112|0)>>2];d=0;return d|0}function eut(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=2291368+(b*112|0);e=0;return e|0}function euu(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1009204+(b*112|0)>>2];c[a+104>>2]=c[1009208+(b*112|0)>>2];c[a+108>>2]=c[1009212+(b*112|0)>>2];d=0;return d|0}function euv(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=1009104+(b*112|0);e=0;return e|0}function euw(d,e,f,g,h,i,j){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0;k=c[2112968]|0;l=c[2411376]|0;m=(c[2405558]|0)+(d<<8)|0;d=c[2385754]|0;n=(i*320|0)+h|0;o=k+(n<<1)|0;p=l+n|0;if(!(h>>>0>303|i>>>0>239)){if((g|0)==0){q=j|5;r=1<<j;if((f|0)==0){s=p;t=m;u=o;v=0;while(1){w=a[t]|0;if(w<<24>>24!=0){x=a[s]|0;if((x&255&q|0)==0){b[u>>1]=b[d+((w&255|e)+4096<<1)>>1]|0;y=a[s]|0}else{y=x}a[s]=(y&255|r)&255}x=a[t+1|0]|0;if(x<<24>>24!=0){w=s+1|0;z=a[w]|0;if((z&255&q|0)==0){b[u+2>>1]=b[d+((x&255|e)+4096<<1)>>1]|0;A=a[w]|0}else{A=z}a[w]=(A&255|r)&255}w=a[t+2|0]|0;if(w<<24>>24!=0){z=s+2|0;x=a[z]|0;if((x&255&q|0)==0){b[u+4>>1]=b[d+((w&255|e)+4096<<1)>>1]|0;B=a[z]|0}else{B=x}a[z]=(B&255|r)&255}z=a[t+3|0]|0;if(z<<24>>24!=0){x=s+3|0;w=a[x]|0;if((w&255&q|0)==0){b[u+6>>1]=b[d+((z&255|e)+4096<<1)>>1]|0;C=a[x]|0}else{C=w}a[x]=(C&255|r)&255}x=a[t+4|0]|0;if(x<<24>>24!=0){w=s+4|0;z=a[w]|0;if((z&255&q|0)==0){b[u+8>>1]=b[d+((x&255|e)+4096<<1)>>1]|0;D=a[w]|0}else{D=z}a[w]=(D&255|r)&255}w=a[t+5|0]|0;if(w<<24>>24!=0){z=s+5|0;x=a[z]|0;if((x&255&q|0)==0){b[u+10>>1]=b[d+((w&255|e)+4096<<1)>>1]|0;E=a[z]|0}else{E=x}a[z]=(E&255|r)&255}z=a[t+6|0]|0;if(z<<24>>24!=0){x=s+6|0;w=a[x]|0;if((w&255&q|0)==0){b[u+12>>1]=b[d+((z&255|e)+4096<<1)>>1]|0;F=a[x]|0}else{F=w}a[x]=(F&255|r)&255}x=a[t+7|0]|0;if(x<<24>>24!=0){w=s+7|0;z=a[w]|0;if((z&255&q|0)==0){b[u+14>>1]=b[d+((x&255|e)+4096<<1)>>1]|0;G=a[w]|0}else{G=z}a[w]=(G&255|r)&255}w=a[t+8|0]|0;if(w<<24>>24!=0){z=s+8|0;x=a[z]|0;if((x&255&q|0)==0){b[u+16>>1]=b[d+((w&255|e)+4096<<1)>>1]|0;H=a[z]|0}else{H=x}a[z]=(H&255|r)&255}z=a[t+9|0]|0;if(z<<24>>24!=0){x=s+9|0;w=a[x]|0;if((w&255&q|0)==0){b[u+18>>1]=b[d+((z&255|e)+4096<<1)>>1]|0;I=a[x]|0}else{I=w}a[x]=(I&255|r)&255}x=a[t+10|0]|0;if(x<<24>>24!=0){w=s+10|0;z=a[w]|0;if((z&255&q|0)==0){b[u+20>>1]=b[d+((x&255|e)+4096<<1)>>1]|0;J=a[w]|0}else{J=z}a[w]=(J&255|r)&255}w=a[t+11|0]|0;if(w<<24>>24!=0){z=s+11|0;x=a[z]|0;if((x&255&q|0)==0){b[u+22>>1]=b[d+((w&255|e)+4096<<1)>>1]|0;K=a[z]|0}else{K=x}a[z]=(K&255|r)&255}z=a[t+12|0]|0;if(z<<24>>24!=0){x=s+12|0;w=a[x]|0;if((w&255&q|0)==0){b[u+24>>1]=b[d+((z&255|e)+4096<<1)>>1]|0;L=a[x]|0}else{L=w}a[x]=(L&255|r)&255}x=a[t+13|0]|0;if(x<<24>>24!=0){w=s+13|0;z=a[w]|0;if((z&255&q|0)==0){b[u+26>>1]=b[d+((x&255|e)+4096<<1)>>1]|0;M=a[w]|0}else{M=z}a[w]=(M&255|r)&255}w=a[t+14|0]|0;if(w<<24>>24!=0){z=s+14|0;x=a[z]|0;if((x&255&q|0)==0){b[u+28>>1]=b[d+((w&255|e)+4096<<1)>>1]|0;N=a[z]|0}else{N=x}a[z]=(N&255|r)&255}z=a[t+15|0]|0;if(z<<24>>24!=0){x=s+15|0;w=a[x]|0;if((w&255&q|0)==0){b[u+30>>1]=b[d+((z&255|e)+4096<<1)>>1]|0;O=a[x]|0}else{O=w}a[x]=(O&255|r)&255}x=v+1|0;if((x|0)<16){s=s+320|0;t=t+16|0;u=u+640|0;v=x}else{break}}return}else{v=p;u=m;t=o;s=0;while(1){O=a[u]|0;if(O<<24>>24!=0){N=v+15|0;M=a[N]|0;if((M&255&q|0)==0){b[t+30>>1]=b[d+((O&255|e)+4096<<1)>>1]|0;P=a[N]|0}else{P=M}a[N]=(P&255|r)&255}N=a[u+1|0]|0;if(N<<24>>24!=0){M=v+14|0;O=a[M]|0;if((O&255&q|0)==0){b[t+28>>1]=b[d+((N&255|e)+4096<<1)>>1]|0;Q=a[M]|0}else{Q=O}a[M]=(Q&255|r)&255}M=a[u+2|0]|0;if(M<<24>>24!=0){O=v+13|0;N=a[O]|0;if((N&255&q|0)==0){b[t+26>>1]=b[d+((M&255|e)+4096<<1)>>1]|0;R=a[O]|0}else{R=N}a[O]=(R&255|r)&255}O=a[u+3|0]|0;if(O<<24>>24!=0){N=v+12|0;M=a[N]|0;if((M&255&q|0)==0){b[t+24>>1]=b[d+((O&255|e)+4096<<1)>>1]|0;S=a[N]|0}else{S=M}a[N]=(S&255|r)&255}N=a[u+4|0]|0;if(N<<24>>24!=0){M=v+11|0;O=a[M]|0;if((O&255&q|0)==0){b[t+22>>1]=b[d+((N&255|e)+4096<<1)>>1]|0;T=a[M]|0}else{T=O}a[M]=(T&255|r)&255}M=a[u+5|0]|0;if(M<<24>>24!=0){O=v+10|0;N=a[O]|0;if((N&255&q|0)==0){b[t+20>>1]=b[d+((M&255|e)+4096<<1)>>1]|0;U=a[O]|0}else{U=N}a[O]=(U&255|r)&255}O=a[u+6|0]|0;if(O<<24>>24!=0){N=v+9|0;M=a[N]|0;if((M&255&q|0)==0){b[t+18>>1]=b[d+((O&255|e)+4096<<1)>>1]|0;V=a[N]|0}else{V=M}a[N]=(V&255|r)&255}N=a[u+7|0]|0;if(N<<24>>24!=0){M=v+8|0;O=a[M]|0;if((O&255&q|0)==0){b[t+16>>1]=b[d+((N&255|e)+4096<<1)>>1]|0;W=a[M]|0}else{W=O}a[M]=(W&255|r)&255}M=a[u+8|0]|0;if(M<<24>>24!=0){O=v+7|0;N=a[O]|0;if((N&255&q|0)==0){b[t+14>>1]=b[d+((M&255|e)+4096<<1)>>1]|0;X=a[O]|0}else{X=N}a[O]=(X&255|r)&255}O=a[u+9|0]|0;if(O<<24>>24!=0){N=v+6|0;M=a[N]|0;if((M&255&q|0)==0){b[t+12>>1]=b[d+((O&255|e)+4096<<1)>>1]|0;Y=a[N]|0}else{Y=M}a[N]=(Y&255|r)&255}N=a[u+10|0]|0;if(N<<24>>24!=0){M=v+5|0;O=a[M]|0;if((O&255&q|0)==0){b[t+10>>1]=b[d+((N&255|e)+4096<<1)>>1]|0;Z=a[M]|0}else{Z=O}a[M]=(Z&255|r)&255}M=a[u+11|0]|0;if(M<<24>>24!=0){O=v+4|0;N=a[O]|0;if((N&255&q|0)==0){b[t+8>>1]=b[d+((M&255|e)+4096<<1)>>1]|0;_=a[O]|0}else{_=N}a[O]=(_&255|r)&255}O=a[u+12|0]|0;if(O<<24>>24!=0){N=v+3|0;M=a[N]|0;if((M&255&q|0)==0){b[t+6>>1]=b[d+((O&255|e)+4096<<1)>>1]|0;$=a[N]|0}else{$=M}a[N]=($&255|r)&255}N=a[u+13|0]|0;if(N<<24>>24!=0){M=v+2|0;O=a[M]|0;if((O&255&q|0)==0){b[t+4>>1]=b[d+((N&255|e)+4096<<1)>>1]|0;aa=a[M]|0}else{aa=O}a[M]=(aa&255|r)&255}M=a[u+14|0]|0;if(M<<24>>24!=0){O=v+1|0;N=a[O]|0;if((N&255&q|0)==0){b[t+2>>1]=b[d+((M&255|e)+4096<<1)>>1]|0;ab=a[O]|0}else{ab=N}a[O]=(ab&255|r)&255}O=a[u+15|0]|0;if(O<<24>>24!=0){N=a[v]|0;if((N&255&q|0)==0){b[t>>1]=b[d+((O&255|e)+4096<<1)>>1]|0;ac=a[v]|0}else{ac=N}a[v]=(ac&255|r)&255}N=s+1|0;if((N|0)<16){v=v+320|0;u=u+16|0;t=t+640|0;s=N}else{break}}return}}else{s=n+4800|0;t=k+(s<<1)|0;u=l+s|0;s=j|5;v=1<<j;if((f|0)==0){r=u;ac=m;q=t;ab=0;while(1){aa=a[ac]|0;if(aa<<24>>24!=0){$=a[r]|0;if(($&255&s|0)==0){b[q>>1]=b[d+((aa&255|e)+4096<<1)>>1]|0;ad=a[r]|0}else{ad=$}a[r]=(ad&255|v)&255}$=a[ac+1|0]|0;if($<<24>>24!=0){aa=r+1|0;_=a[aa]|0;if((_&255&s|0)==0){b[q+2>>1]=b[d+(($&255|e)+4096<<1)>>1]|0;ae=a[aa]|0}else{ae=_}a[aa]=(ae&255|v)&255}aa=a[ac+2|0]|0;if(aa<<24>>24!=0){_=r+2|0;$=a[_]|0;if(($&255&s|0)==0){b[q+4>>1]=b[d+((aa&255|e)+4096<<1)>>1]|0;af=a[_]|0}else{af=$}a[_]=(af&255|v)&255}_=a[ac+3|0]|0;if(_<<24>>24!=0){$=r+3|0;aa=a[$]|0;if((aa&255&s|0)==0){b[q+6>>1]=b[d+((_&255|e)+4096<<1)>>1]|0;ag=a[$]|0}else{ag=aa}a[$]=(ag&255|v)&255}$=a[ac+4|0]|0;if($<<24>>24!=0){aa=r+4|0;_=a[aa]|0;if((_&255&s|0)==0){b[q+8>>1]=b[d+(($&255|e)+4096<<1)>>1]|0;ah=a[aa]|0}else{ah=_}a[aa]=(ah&255|v)&255}aa=a[ac+5|0]|0;if(aa<<24>>24!=0){_=r+5|0;$=a[_]|0;if(($&255&s|0)==0){b[q+10>>1]=b[d+((aa&255|e)+4096<<1)>>1]|0;ai=a[_]|0}else{ai=$}a[_]=(ai&255|v)&255}_=a[ac+6|0]|0;if(_<<24>>24!=0){$=r+6|0;aa=a[$]|0;if((aa&255&s|0)==0){b[q+12>>1]=b[d+((_&255|e)+4096<<1)>>1]|0;aj=a[$]|0}else{aj=aa}a[$]=(aj&255|v)&255}$=a[ac+7|0]|0;if($<<24>>24!=0){aa=r+7|0;_=a[aa]|0;if((_&255&s|0)==0){b[q+14>>1]=b[d+(($&255|e)+4096<<1)>>1]|0;ak=a[aa]|0}else{ak=_}a[aa]=(ak&255|v)&255}aa=a[ac+8|0]|0;if(aa<<24>>24!=0){_=r+8|0;$=a[_]|0;if(($&255&s|0)==0){b[q+16>>1]=b[d+((aa&255|e)+4096<<1)>>1]|0;al=a[_]|0}else{al=$}a[_]=(al&255|v)&255}_=a[ac+9|0]|0;if(_<<24>>24!=0){$=r+9|0;aa=a[$]|0;if((aa&255&s|0)==0){b[q+18>>1]=b[d+((_&255|e)+4096<<1)>>1]|0;am=a[$]|0}else{am=aa}a[$]=(am&255|v)&255}$=a[ac+10|0]|0;if($<<24>>24!=0){aa=r+10|0;_=a[aa]|0;if((_&255&s|0)==0){b[q+20>>1]=b[d+(($&255|e)+4096<<1)>>1]|0;an=a[aa]|0}else{an=_}a[aa]=(an&255|v)&255}aa=a[ac+11|0]|0;if(aa<<24>>24!=0){_=r+11|0;$=a[_]|0;if(($&255&s|0)==0){b[q+22>>1]=b[d+((aa&255|e)+4096<<1)>>1]|0;ao=a[_]|0}else{ao=$}a[_]=(ao&255|v)&255}_=a[ac+12|0]|0;if(_<<24>>24!=0){$=r+12|0;aa=a[$]|0;if((aa&255&s|0)==0){b[q+24>>1]=b[d+((_&255|e)+4096<<1)>>1]|0;ap=a[$]|0}else{ap=aa}a[$]=(ap&255|v)&255}$=a[ac+13|0]|0;if($<<24>>24!=0){aa=r+13|0;_=a[aa]|0;if((_&255&s|0)==0){b[q+26>>1]=b[d+(($&255|e)+4096<<1)>>1]|0;aq=a[aa]|0}else{aq=_}a[aa]=(aq&255|v)&255}aa=a[ac+14|0]|0;if(aa<<24>>24!=0){_=r+14|0;$=a[_]|0;if(($&255&s|0)==0){b[q+28>>1]=b[d+((aa&255|e)+4096<<1)>>1]|0;ar=a[_]|0}else{ar=$}a[_]=(ar&255|v)&255}_=a[ac+15|0]|0;if(_<<24>>24!=0){$=r+15|0;aa=a[$]|0;if((aa&255&s|0)==0){b[q+30>>1]=b[d+((_&255|e)+4096<<1)>>1]|0;as=a[$]|0}else{as=aa}a[$]=(as&255|v)&255}$=ab+1|0;if(($|0)<16){r=r-320|0;ac=ac+16|0;q=q-640|0;ab=$}else{break}}return}else{ab=u;u=m;q=t;t=0;while(1){ac=a[u]|0;if(ac<<24>>24!=0){r=ab+15|0;as=a[r]|0;if((as&255&s|0)==0){b[q+30>>1]=b[d+((ac&255|e)+4096<<1)>>1]|0;at=a[r]|0}else{at=as}a[r]=(at&255|v)&255}r=a[u+1|0]|0;if(r<<24>>24!=0){as=ab+14|0;ac=a[as]|0;if((ac&255&s|0)==0){b[q+28>>1]=b[d+((r&255|e)+4096<<1)>>1]|0;au=a[as]|0}else{au=ac}a[as]=(au&255|v)&255}as=a[u+2|0]|0;if(as<<24>>24!=0){ac=ab+13|0;r=a[ac]|0;if((r&255&s|0)==0){b[q+26>>1]=b[d+((as&255|e)+4096<<1)>>1]|0;av=a[ac]|0}else{av=r}a[ac]=(av&255|v)&255}ac=a[u+3|0]|0;if(ac<<24>>24!=0){r=ab+12|0;as=a[r]|0;if((as&255&s|0)==0){b[q+24>>1]=b[d+((ac&255|e)+4096<<1)>>1]|0;aw=a[r]|0}else{aw=as}a[r]=(aw&255|v)&255}r=a[u+4|0]|0;if(r<<24>>24!=0){as=ab+11|0;ac=a[as]|0;if((ac&255&s|0)==0){b[q+22>>1]=b[d+((r&255|e)+4096<<1)>>1]|0;ax=a[as]|0}else{ax=ac}a[as]=(ax&255|v)&255}as=a[u+5|0]|0;if(as<<24>>24!=0){ac=ab+10|0;r=a[ac]|0;if((r&255&s|0)==0){b[q+20>>1]=b[d+((as&255|e)+4096<<1)>>1]|0;ay=a[ac]|0}else{ay=r}a[ac]=(ay&255|v)&255}ac=a[u+6|0]|0;if(ac<<24>>24!=0){r=ab+9|0;as=a[r]|0;if((as&255&s|0)==0){b[q+18>>1]=b[d+((ac&255|e)+4096<<1)>>1]|0;az=a[r]|0}else{az=as}a[r]=(az&255|v)&255}r=a[u+7|0]|0;if(r<<24>>24!=0){as=ab+8|0;ac=a[as]|0;if((ac&255&s|0)==0){b[q+16>>1]=b[d+((r&255|e)+4096<<1)>>1]|0;aA=a[as]|0}else{aA=ac}a[as]=(aA&255|v)&255}as=a[u+8|0]|0;if(as<<24>>24!=0){ac=ab+7|0;r=a[ac]|0;if((r&255&s|0)==0){b[q+14>>1]=b[d+((as&255|e)+4096<<1)>>1]|0;aB=a[ac]|0}else{aB=r}a[ac]=(aB&255|v)&255}ac=a[u+9|0]|0;if(ac<<24>>24!=0){r=ab+6|0;as=a[r]|0;if((as&255&s|0)==0){b[q+12>>1]=b[d+((ac&255|e)+4096<<1)>>1]|0;aC=a[r]|0}else{aC=as}a[r]=(aC&255|v)&255}r=a[u+10|0]|0;if(r<<24>>24!=0){as=ab+5|0;ac=a[as]|0;if((ac&255&s|0)==0){b[q+10>>1]=b[d+((r&255|e)+4096<<1)>>1]|0;aD=a[as]|0}else{aD=ac}a[as]=(aD&255|v)&255}as=a[u+11|0]|0;if(as<<24>>24!=0){ac=ab+4|0;r=a[ac]|0;if((r&255&s|0)==0){b[q+8>>1]=b[d+((as&255|e)+4096<<1)>>1]|0;aE=a[ac]|0}else{aE=r}a[ac]=(aE&255|v)&255}ac=a[u+12|0]|0;if(ac<<24>>24!=0){r=ab+3|0;as=a[r]|0;if((as&255&s|0)==0){b[q+6>>1]=b[d+((ac&255|e)+4096<<1)>>1]|0;aF=a[r]|0}else{aF=as}a[r]=(aF&255|v)&255}r=a[u+13|0]|0;if(r<<24>>24!=0){as=ab+2|0;ac=a[as]|0;if((ac&255&s|0)==0){b[q+4>>1]=b[d+((r&255|e)+4096<<1)>>1]|0;aG=a[as]|0}else{aG=ac}a[as]=(aG&255|v)&255}as=a[u+14|0]|0;if(as<<24>>24!=0){ac=ab+1|0;r=a[ac]|0;if((r&255&s|0)==0){b[q+2>>1]=b[d+((as&255|e)+4096<<1)>>1]|0;aH=a[ac]|0}else{aH=r}a[ac]=(aH&255|v)&255}ac=a[u+15|0]|0;if(ac<<24>>24!=0){r=a[ab]|0;if((r&255&s|0)==0){b[q>>1]=b[d+((ac&255|e)+4096<<1)>>1]|0;aI=a[ab]|0}else{aI=r}a[ab]=(aI&255|v)&255}r=t+1|0;if((r|0)<16){ab=ab-320|0;u=u+16|0;q=q-640|0;t=r}else{break}}return}}}t=h+15|0;if(t>>>0>334){return}if((i+15|0)>>>0>270){return}if((g|0)==0){g=(h|0)>-1;q=(h|0)<320;u=j|5;ab=1<<j;if((f|0)==0){v=(h+1|0)>>>0>319;aI=(h+2|0)>>>0>319;s=(h+3|0)>>>0>319;aH=(h+4|0)>>>0>319;aG=(h+5|0)>>>0>319;aF=(h+6|0)>>>0>319;aE=(h+7|0)>>>0>319;aD=(h+8|0)>>>0>319;aC=(h+9|0)>>>0>319;aB=(h+10|0)>>>0>319;aA=(h+11|0)>>>0>319;az=(h+12|0)>>>0>319;ay=(h+13|0)>>>0>319;ax=(h+14|0)>>>0>319;aw=t>>>0>319;av=p;au=m;at=o;r=0;while(1){do{if((r+i|0)>>>0<256){ac=a[au]|0;if(ac<<24>>24!=0&g&q){as=a[av]|0;if((as&255&u|0)==0){b[at>>1]=b[d+((ac&255|e)+4096<<1)>>1]|0;aJ=a[av]|0}else{aJ=as}a[av]=(aJ&255|ab)&255}as=a[au+1|0]|0;if(!(as<<24>>24==0|v)){ac=av+1|0;ar=a[ac]|0;if((ar&255&u|0)==0){b[at+2>>1]=b[d+((as&255|e)+4096<<1)>>1]|0;aK=a[ac]|0}else{aK=ar}a[ac]=(aK&255|ab)&255}ac=a[au+2|0]|0;if(!(ac<<24>>24==0|aI)){ar=av+2|0;as=a[ar]|0;if((as&255&u|0)==0){b[at+4>>1]=b[d+((ac&255|e)+4096<<1)>>1]|0;aL=a[ar]|0}else{aL=as}a[ar]=(aL&255|ab)&255}ar=a[au+3|0]|0;if(!(ar<<24>>24==0|s)){as=av+3|0;ac=a[as]|0;if((ac&255&u|0)==0){b[at+6>>1]=b[d+((ar&255|e)+4096<<1)>>1]|0;aM=a[as]|0}else{aM=ac}a[as]=(aM&255|ab)&255}as=a[au+4|0]|0;if(!(as<<24>>24==0|aH)){ac=av+4|0;ar=a[ac]|0;if((ar&255&u|0)==0){b[at+8>>1]=b[d+((as&255|e)+4096<<1)>>1]|0;aN=a[ac]|0}else{aN=ar}a[ac]=(aN&255|ab)&255}ac=a[au+5|0]|0;if(!(ac<<24>>24==0|aG)){ar=av+5|0;as=a[ar]|0;if((as&255&u|0)==0){b[at+10>>1]=b[d+((ac&255|e)+4096<<1)>>1]|0;aO=a[ar]|0}else{aO=as}a[ar]=(aO&255|ab)&255}ar=a[au+6|0]|0;if(!(ar<<24>>24==0|aF)){as=av+6|0;ac=a[as]|0;if((ac&255&u|0)==0){b[at+12>>1]=b[d+((ar&255|e)+4096<<1)>>1]|0;aP=a[as]|0}else{aP=ac}a[as]=(aP&255|ab)&255}as=a[au+7|0]|0;if(!(as<<24>>24==0|aE)){ac=av+7|0;ar=a[ac]|0;if((ar&255&u|0)==0){b[at+14>>1]=b[d+((as&255|e)+4096<<1)>>1]|0;aQ=a[ac]|0}else{aQ=ar}a[ac]=(aQ&255|ab)&255}ac=a[au+8|0]|0;if(!(ac<<24>>24==0|aD)){ar=av+8|0;as=a[ar]|0;if((as&255&u|0)==0){b[at+16>>1]=b[d+((ac&255|e)+4096<<1)>>1]|0;aR=a[ar]|0}else{aR=as}a[ar]=(aR&255|ab)&255}ar=a[au+9|0]|0;if(!(ar<<24>>24==0|aC)){as=av+9|0;ac=a[as]|0;if((ac&255&u|0)==0){b[at+18>>1]=b[d+((ar&255|e)+4096<<1)>>1]|0;aS=a[as]|0}else{aS=ac}a[as]=(aS&255|ab)&255}as=a[au+10|0]|0;if(!(as<<24>>24==0|aB)){ac=av+10|0;ar=a[ac]|0;if((ar&255&u|0)==0){b[at+20>>1]=b[d+((as&255|e)+4096<<1)>>1]|0;aT=a[ac]|0}else{aT=ar}a[ac]=(aT&255|ab)&255}ac=a[au+11|0]|0;if(!(ac<<24>>24==0|aA)){ar=av+11|0;as=a[ar]|0;if((as&255&u|0)==0){b[at+22>>1]=b[d+((ac&255|e)+4096<<1)>>1]|0;aU=a[ar]|0}else{aU=as}a[ar]=(aU&255|ab)&255}ar=a[au+12|0]|0;if(!(ar<<24>>24==0|az)){as=av+12|0;ac=a[as]|0;if((ac&255&u|0)==0){b[at+24>>1]=b[d+((ar&255|e)+4096<<1)>>1]|0;aV=a[as]|0}else{aV=ac}a[as]=(aV&255|ab)&255}as=a[au+13|0]|0;if(!(as<<24>>24==0|ay)){ac=av+13|0;ar=a[ac]|0;if((ar&255&u|0)==0){b[at+26>>1]=b[d+((as&255|e)+4096<<1)>>1]|0;aW=a[ac]|0}else{aW=ar}a[ac]=(aW&255|ab)&255}ac=a[au+14|0]|0;if(!(ac<<24>>24==0|ax)){ar=av+14|0;as=a[ar]|0;if((as&255&u|0)==0){b[at+28>>1]=b[d+((ac&255|e)+4096<<1)>>1]|0;aX=a[ar]|0}else{aX=as}a[ar]=(aX&255|ab)&255}ar=a[au+15|0]|0;if(ar<<24>>24==0|aw){break}as=av+15|0;ac=a[as]|0;if((ac&255&u|0)==0){b[at+30>>1]=b[d+((ar&255|e)+4096<<1)>>1]|0;aY=a[as]|0}else{aY=ac}a[as]=(aY&255|ab)&255}}while(0);as=r+1|0;if((as|0)<16){av=av+320|0;au=au+16|0;at=at+640|0;r=as}else{break}}return}else{r=t>>>0>319;at=(h+14|0)>>>0>319;au=(h+13|0)>>>0>319;av=(h+12|0)>>>0>319;aY=(h+11|0)>>>0>319;aw=(h+10|0)>>>0>319;aX=(h+9|0)>>>0>319;ax=(h+8|0)>>>0>319;aW=(h+7|0)>>>0>319;ay=(h+6|0)>>>0>319;aV=(h+5|0)>>>0>319;az=(h+4|0)>>>0>319;aU=(h+3|0)>>>0>319;aA=(h+2|0)>>>0>319;aT=(h+1|0)>>>0>319;aB=p;p=m;aS=o;o=0;while(1){do{if((o+i|0)>>>0<256){aC=a[p]|0;if(!(aC<<24>>24==0|r)){aR=aB+15|0;aD=a[aR]|0;if((aD&255&u|0)==0){b[aS+30>>1]=b[d+((aC&255|e)+4096<<1)>>1]|0;aZ=a[aR]|0}else{aZ=aD}a[aR]=(aZ&255|ab)&255}aR=a[p+1|0]|0;if(!(aR<<24>>24==0|at)){aD=aB+14|0;aC=a[aD]|0;if((aC&255&u|0)==0){b[aS+28>>1]=b[d+((aR&255|e)+4096<<1)>>1]|0;a_=a[aD]|0}else{a_=aC}a[aD]=(a_&255|ab)&255}aD=a[p+2|0]|0;if(!(aD<<24>>24==0|au)){aC=aB+13|0;aR=a[aC]|0;if((aR&255&u|0)==0){b[aS+26>>1]=b[d+((aD&255|e)+4096<<1)>>1]|0;a$=a[aC]|0}else{a$=aR}a[aC]=(a$&255|ab)&255}aC=a[p+3|0]|0;if(!(aC<<24>>24==0|av)){aR=aB+12|0;aD=a[aR]|0;if((aD&255&u|0)==0){b[aS+24>>1]=b[d+((aC&255|e)+4096<<1)>>1]|0;a0=a[aR]|0}else{a0=aD}a[aR]=(a0&255|ab)&255}aR=a[p+4|0]|0;if(!(aR<<24>>24==0|aY)){aD=aB+11|0;aC=a[aD]|0;if((aC&255&u|0)==0){b[aS+22>>1]=b[d+((aR&255|e)+4096<<1)>>1]|0;a1=a[aD]|0}else{a1=aC}a[aD]=(a1&255|ab)&255}aD=a[p+5|0]|0;if(!(aD<<24>>24==0|aw)){aC=aB+10|0;aR=a[aC]|0;if((aR&255&u|0)==0){b[aS+20>>1]=b[d+((aD&255|e)+4096<<1)>>1]|0;a2=a[aC]|0}else{a2=aR}a[aC]=(a2&255|ab)&255}aC=a[p+6|0]|0;if(!(aC<<24>>24==0|aX)){aR=aB+9|0;aD=a[aR]|0;if((aD&255&u|0)==0){b[aS+18>>1]=b[d+((aC&255|e)+4096<<1)>>1]|0;a3=a[aR]|0}else{a3=aD}a[aR]=(a3&255|ab)&255}aR=a[p+7|0]|0;if(!(aR<<24>>24==0|ax)){aD=aB+8|0;aC=a[aD]|0;if((aC&255&u|0)==0){b[aS+16>>1]=b[d+((aR&255|e)+4096<<1)>>1]|0;a4=a[aD]|0}else{a4=aC}a[aD]=(a4&255|ab)&255}aD=a[p+8|0]|0;if(!(aD<<24>>24==0|aW)){aC=aB+7|0;aR=a[aC]|0;if((aR&255&u|0)==0){b[aS+14>>1]=b[d+((aD&255|e)+4096<<1)>>1]|0;a5=a[aC]|0}else{a5=aR}a[aC]=(a5&255|ab)&255}aC=a[p+9|0]|0;if(!(aC<<24>>24==0|ay)){aR=aB+6|0;aD=a[aR]|0;if((aD&255&u|0)==0){b[aS+12>>1]=b[d+((aC&255|e)+4096<<1)>>1]|0;a6=a[aR]|0}else{a6=aD}a[aR]=(a6&255|ab)&255}aR=a[p+10|0]|0;if(!(aR<<24>>24==0|aV)){aD=aB+5|0;aC=a[aD]|0;if((aC&255&u|0)==0){b[aS+10>>1]=b[d+((aR&255|e)+4096<<1)>>1]|0;a7=a[aD]|0}else{a7=aC}a[aD]=(a7&255|ab)&255}aD=a[p+11|0]|0;if(!(aD<<24>>24==0|az)){aC=aB+4|0;aR=a[aC]|0;if((aR&255&u|0)==0){b[aS+8>>1]=b[d+((aD&255|e)+4096<<1)>>1]|0;a8=a[aC]|0}else{a8=aR}a[aC]=(a8&255|ab)&255}aC=a[p+12|0]|0;if(!(aC<<24>>24==0|aU)){aR=aB+3|0;aD=a[aR]|0;if((aD&255&u|0)==0){b[aS+6>>1]=b[d+((aC&255|e)+4096<<1)>>1]|0;a9=a[aR]|0}else{a9=aD}a[aR]=(a9&255|ab)&255}aR=a[p+13|0]|0;if(!(aR<<24>>24==0|aA)){aD=aB+2|0;aC=a[aD]|0;if((aC&255&u|0)==0){b[aS+4>>1]=b[d+((aR&255|e)+4096<<1)>>1]|0;ba=a[aD]|0}else{ba=aC}a[aD]=(ba&255|ab)&255}aD=a[p+14|0]|0;if(!(aD<<24>>24==0|aT)){aC=aB+1|0;aR=a[aC]|0;if((aR&255&u|0)==0){b[aS+2>>1]=b[d+((aD&255|e)+4096<<1)>>1]|0;bb=a[aC]|0}else{bb=aR}a[aC]=(bb&255|ab)&255}aC=a[p+15|0]|0;if(!(aC<<24>>24!=0&g&q)){break}aR=a[aB]|0;if((aR&255&u|0)==0){b[aS>>1]=b[d+((aC&255|e)+4096<<1)>>1]|0;bc=a[aB]|0}else{bc=aR}a[aB]=(bc&255|ab)&255}}while(0);aR=o+1|0;if((aR|0)<16){aB=aB+320|0;p=p+16|0;aS=aS+640|0;o=aR}else{break}}return}}else{o=n+4800|0;n=k+(o<<1)|0;k=l+o|0;o=(h|0)>-1;l=(h|0)<320;aS=j|5;p=1<<j;if((f|0)==0){f=(h+1|0)>>>0>319;j=(h+2|0)>>>0>319;aB=(h+3|0)>>>0>319;ab=(h+4|0)>>>0>319;bc=(h+5|0)>>>0>319;u=(h+6|0)>>>0>319;q=(h+7|0)>>>0>319;g=(h+8|0)>>>0>319;bb=(h+9|0)>>>0>319;aT=(h+10|0)>>>0>319;ba=(h+11|0)>>>0>319;aA=(h+12|0)>>>0>319;a9=(h+13|0)>>>0>319;aU=(h+14|0)>>>0>319;a8=t>>>0>319;az=k;a7=m;aV=n;a6=15;while(1){do{if((a6+i|0)>>>0<256){ay=a[a7]|0;if(ay<<24>>24!=0&o&l){a5=a[az]|0;if((a5&255&aS|0)==0){b[aV>>1]=b[d+((ay&255|e)+4096<<1)>>1]|0;bd=a[az]|0}else{bd=a5}a[az]=(bd&255|p)&255}a5=a[a7+1|0]|0;if(!(a5<<24>>24==0|f)){ay=az+1|0;aW=a[ay]|0;if((aW&255&aS|0)==0){b[aV+2>>1]=b[d+((a5&255|e)+4096<<1)>>1]|0;be=a[ay]|0}else{be=aW}a[ay]=(be&255|p)&255}ay=a[a7+2|0]|0;if(!(ay<<24>>24==0|j)){aW=az+2|0;a5=a[aW]|0;if((a5&255&aS|0)==0){b[aV+4>>1]=b[d+((ay&255|e)+4096<<1)>>1]|0;bf=a[aW]|0}else{bf=a5}a[aW]=(bf&255|p)&255}aW=a[a7+3|0]|0;if(!(aW<<24>>24==0|aB)){a5=az+3|0;ay=a[a5]|0;if((ay&255&aS|0)==0){b[aV+6>>1]=b[d+((aW&255|e)+4096<<1)>>1]|0;bg=a[a5]|0}else{bg=ay}a[a5]=(bg&255|p)&255}a5=a[a7+4|0]|0;if(!(a5<<24>>24==0|ab)){ay=az+4|0;aW=a[ay]|0;if((aW&255&aS|0)==0){b[aV+8>>1]=b[d+((a5&255|e)+4096<<1)>>1]|0;bh=a[ay]|0}else{bh=aW}a[ay]=(bh&255|p)&255}ay=a[a7+5|0]|0;if(!(ay<<24>>24==0|bc)){aW=az+5|0;a5=a[aW]|0;if((a5&255&aS|0)==0){b[aV+10>>1]=b[d+((ay&255|e)+4096<<1)>>1]|0;bi=a[aW]|0}else{bi=a5}a[aW]=(bi&255|p)&255}aW=a[a7+6|0]|0;if(!(aW<<24>>24==0|u)){a5=az+6|0;ay=a[a5]|0;if((ay&255&aS|0)==0){b[aV+12>>1]=b[d+((aW&255|e)+4096<<1)>>1]|0;bj=a[a5]|0}else{bj=ay}a[a5]=(bj&255|p)&255}a5=a[a7+7|0]|0;if(!(a5<<24>>24==0|q)){ay=az+7|0;aW=a[ay]|0;if((aW&255&aS|0)==0){b[aV+14>>1]=b[d+((a5&255|e)+4096<<1)>>1]|0;bk=a[ay]|0}else{bk=aW}a[ay]=(bk&255|p)&255}ay=a[a7+8|0]|0;if(!(ay<<24>>24==0|g)){aW=az+8|0;a5=a[aW]|0;if((a5&255&aS|0)==0){b[aV+16>>1]=b[d+((ay&255|e)+4096<<1)>>1]|0;bl=a[aW]|0}else{bl=a5}a[aW]=(bl&255|p)&255}aW=a[a7+9|0]|0;if(!(aW<<24>>24==0|bb)){a5=az+9|0;ay=a[a5]|0;if((ay&255&aS|0)==0){b[aV+18>>1]=b[d+((aW&255|e)+4096<<1)>>1]|0;bm=a[a5]|0}else{bm=ay}a[a5]=(bm&255|p)&255}a5=a[a7+10|0]|0;if(!(a5<<24>>24==0|aT)){ay=az+10|0;aW=a[ay]|0;if((aW&255&aS|0)==0){b[aV+20>>1]=b[d+((a5&255|e)+4096<<1)>>1]|0;bn=a[ay]|0}else{bn=aW}a[ay]=(bn&255|p)&255}ay=a[a7+11|0]|0;if(!(ay<<24>>24==0|ba)){aW=az+11|0;a5=a[aW]|0;if((a5&255&aS|0)==0){b[aV+22>>1]=b[d+((ay&255|e)+4096<<1)>>1]|0;bo=a[aW]|0}else{bo=a5}a[aW]=(bo&255|p)&255}aW=a[a7+12|0]|0;if(!(aW<<24>>24==0|aA)){a5=az+12|0;ay=a[a5]|0;if((ay&255&aS|0)==0){b[aV+24>>1]=b[d+((aW&255|e)+4096<<1)>>1]|0;bp=a[a5]|0}else{bp=ay}a[a5]=(bp&255|p)&255}a5=a[a7+13|0]|0;if(!(a5<<24>>24==0|a9)){ay=az+13|0;aW=a[ay]|0;if((aW&255&aS|0)==0){b[aV+26>>1]=b[d+((a5&255|e)+4096<<1)>>1]|0;bq=a[ay]|0}else{bq=aW}a[ay]=(bq&255|p)&255}ay=a[a7+14|0]|0;if(!(ay<<24>>24==0|aU)){aW=az+14|0;a5=a[aW]|0;if((a5&255&aS|0)==0){b[aV+28>>1]=b[d+((ay&255|e)+4096<<1)>>1]|0;br=a[aW]|0}else{br=a5}a[aW]=(br&255|p)&255}aW=a[a7+15|0]|0;if(aW<<24>>24==0|a8){break}a5=az+15|0;ay=a[a5]|0;if((ay&255&aS|0)==0){b[aV+30>>1]=b[d+((aW&255|e)+4096<<1)>>1]|0;bs=a[a5]|0}else{bs=ay}a[a5]=(bs&255|p)&255}}while(0);if((a6|0)>0){az=az-320|0;a7=a7+16|0;aV=aV-640|0;a6=a6-1|0}else{break}}return}else{a6=t>>>0>319;t=(h+14|0)>>>0>319;aV=(h+13|0)>>>0>319;a7=(h+12|0)>>>0>319;az=(h+11|0)>>>0>319;bs=(h+10|0)>>>0>319;a8=(h+9|0)>>>0>319;br=(h+8|0)>>>0>319;aU=(h+7|0)>>>0>319;bq=(h+6|0)>>>0>319;a9=(h+5|0)>>>0>319;bp=(h+4|0)>>>0>319;aA=(h+3|0)>>>0>319;bo=(h+2|0)>>>0>319;ba=(h+1|0)>>>0>319;h=k;k=m;m=n;n=15;while(1){do{if((n+i|0)>>>0<256){bn=a[k]|0;if(!(bn<<24>>24==0|a6)){aT=h+15|0;bm=a[aT]|0;if((bm&255&aS|0)==0){b[m+30>>1]=b[d+((bn&255|e)+4096<<1)>>1]|0;bt=a[aT]|0}else{bt=bm}a[aT]=(bt&255|p)&255}aT=a[k+1|0]|0;if(!(aT<<24>>24==0|t)){bm=h+14|0;bn=a[bm]|0;if((bn&255&aS|0)==0){b[m+28>>1]=b[d+((aT&255|e)+4096<<1)>>1]|0;bu=a[bm]|0}else{bu=bn}a[bm]=(bu&255|p)&255}bm=a[k+2|0]|0;if(!(bm<<24>>24==0|aV)){bn=h+13|0;aT=a[bn]|0;if((aT&255&aS|0)==0){b[m+26>>1]=b[d+((bm&255|e)+4096<<1)>>1]|0;bv=a[bn]|0}else{bv=aT}a[bn]=(bv&255|p)&255}bn=a[k+3|0]|0;if(!(bn<<24>>24==0|a7)){aT=h+12|0;bm=a[aT]|0;if((bm&255&aS|0)==0){b[m+24>>1]=b[d+((bn&255|e)+4096<<1)>>1]|0;bw=a[aT]|0}else{bw=bm}a[aT]=(bw&255|p)&255}aT=a[k+4|0]|0;if(!(aT<<24>>24==0|az)){bm=h+11|0;bn=a[bm]|0;if((bn&255&aS|0)==0){b[m+22>>1]=b[d+((aT&255|e)+4096<<1)>>1]|0;bx=a[bm]|0}else{bx=bn}a[bm]=(bx&255|p)&255}bm=a[k+5|0]|0;if(!(bm<<24>>24==0|bs)){bn=h+10|0;aT=a[bn]|0;if((aT&255&aS|0)==0){b[m+20>>1]=b[d+((bm&255|e)+4096<<1)>>1]|0;by=a[bn]|0}else{by=aT}a[bn]=(by&255|p)&255}bn=a[k+6|0]|0;if(!(bn<<24>>24==0|a8)){aT=h+9|0;bm=a[aT]|0;if((bm&255&aS|0)==0){b[m+18>>1]=b[d+((bn&255|e)+4096<<1)>>1]|0;bz=a[aT]|0}else{bz=bm}a[aT]=(bz&255|p)&255}aT=a[k+7|0]|0;if(!(aT<<24>>24==0|br)){bm=h+8|0;bn=a[bm]|0;if((bn&255&aS|0)==0){b[m+16>>1]=b[d+((aT&255|e)+4096<<1)>>1]|0;bA=a[bm]|0}else{bA=bn}a[bm]=(bA&255|p)&255}bm=a[k+8|0]|0;if(!(bm<<24>>24==0|aU)){bn=h+7|0;aT=a[bn]|0;if((aT&255&aS|0)==0){b[m+14>>1]=b[d+((bm&255|e)+4096<<1)>>1]|0;bB=a[bn]|0}else{bB=aT}a[bn]=(bB&255|p)&255}bn=a[k+9|0]|0;if(!(bn<<24>>24==0|bq)){aT=h+6|0;bm=a[aT]|0;if((bm&255&aS|0)==0){b[m+12>>1]=b[d+((bn&255|e)+4096<<1)>>1]|0;bC=a[aT]|0}else{bC=bm}a[aT]=(bC&255|p)&255}aT=a[k+10|0]|0;if(!(aT<<24>>24==0|a9)){bm=h+5|0;bn=a[bm]|0;if((bn&255&aS|0)==0){b[m+10>>1]=b[d+((aT&255|e)+4096<<1)>>1]|0;bD=a[bm]|0}else{bD=bn}a[bm]=(bD&255|p)&255}bm=a[k+11|0]|0;if(!(bm<<24>>24==0|bp)){bn=h+4|0;aT=a[bn]|0;if((aT&255&aS|0)==0){b[m+8>>1]=b[d+((bm&255|e)+4096<<1)>>1]|0;bE=a[bn]|0}else{bE=aT}a[bn]=(bE&255|p)&255}bn=a[k+12|0]|0;if(!(bn<<24>>24==0|aA)){aT=h+3|0;bm=a[aT]|0;if((bm&255&aS|0)==0){b[m+6>>1]=b[d+((bn&255|e)+4096<<1)>>1]|0;bF=a[aT]|0}else{bF=bm}a[aT]=(bF&255|p)&255}aT=a[k+13|0]|0;if(!(aT<<24>>24==0|bo)){bm=h+2|0;bn=a[bm]|0;if((bn&255&aS|0)==0){b[m+4>>1]=b[d+((aT&255|e)+4096<<1)>>1]|0;bG=a[bm]|0}else{bG=bn}a[bm]=(bG&255|p)&255}bm=a[k+14|0]|0;if(!(bm<<24>>24==0|ba)){bn=h+1|0;aT=a[bn]|0;if((aT&255&aS|0)==0){b[m+2>>1]=b[d+((bm&255|e)+4096<<1)>>1]|0;bH=a[bn]|0}else{bH=aT}a[bn]=(bH&255|p)&255}bn=a[k+15|0]|0;if(!(bn<<24>>24!=0&o&l)){break}aT=a[h]|0;if((aT&255&aS|0)==0){b[m>>1]=b[d+((bn&255|e)+4096<<1)>>1]|0;bI=a[h]|0}else{bI=aT}a[h]=(bI&255|p)&255}}while(0);if((n|0)>0){h=h-320|0;k=k+16|0;m=m-640|0;n=n-1|0}else{break}}return}}}function eux(b){b=b|0;if((b|0)==0){a[9706117]=0;return}a[9706117]=1;if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){b=gfc(1024)|0;c[2433530]=(c[2433530]|0)+b;return}else{c[2433530]=(c[2433530]|0)+1024;return}}function euy(b){b=b|0;var e=0,f=0,g=0;switch(b|0){case 8388609:{e=~a[9625584];return e|0};case 8388634:{e=a[9657920]|0;return e|0};case 8389001:{e=c[2113156]&255;return e|0};case 8389004:{b=c[3540984]|0;f=(d[b+5887|0]|0|128)&(d[b+5886|0]|0);if((a[b+5884|0]&2)==0){g=f&255}else{g=(a[(c[b+5828>>2]|0)+100|0]&1|f)&255}e=g|6;return e|0};case 8388633:{e=~a[9625586];return e|0};case 8388608:{e=~a[9625585];return e|0};case 8388636:{e=a[9657921]|0;return e|0};default:{e=0;return e|0}}return 0}function euz(b,e){b=b|0;e=e|0;var f=0,g=0,h=0;if((b|0)==8389004){a[(c[3540984]|0)+5885|0]=e;return}else if((b|0)==8389001){Uv(0,e);return}else if((b|0)==8389006){f=e&1;a[14120976]=f;g=c[3541206]|0;h=(c[2433462]|0)+((f&255)<<18)|0;gGC(g|0,h|0,262144)|0;return}else if((b|0)==8389002){b=c[3540984]|0;h=c[b+5876>>2]|0;if((h|0)!=0){gg[h&4095](c[b+5880>>2]|0,0)}lH(b,d[b+5885|0]|0,e&255);return}else{return}}function euA(a){a=a|0;return 0}function euB(a,c){a=a|0;c=c|0;switch(a|0){case 8388878:{b[7054660]=c&1023;return};case 8388884:{b[7054664]=c&1023;return};case 8388896:{b[7054656]=c&1023;return};case 8388880:{b[7054652]=c&1023;return};case 8388876:{b[7054672]=c&1023;return};case 8388886:{b[7054668]=c&1023;return};default:{return}}}function euC(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;switch(b|0){case 8388976:{e=(c[2113222]&1^((((~~(+((c[3542193]>>8)+8|0)/+(c[2440574]|0)*255.0)&255)*224|0)>>>0)/255|0)+24)&255;return e|0};case 8388634:{e=a[9657920]|0;return e|0};case 8389001:{e=c[2113156]&255;return e|0};case 8388632:{e=a[9625585]|0;return e|0};case 8388636:{e=a[9657921]|0;return e|0};case 8388980:{b=(~~(+((c[3542197]>>8)+8|0)/+(c[2440576]|0)*255.0)&255)*384|0;f=b>>>8;if(b>>>0<90112){g=(((f*208|0)>>>0)/351|0)+48|0}else{g=((f<<5)-11264|0)/31|0}e=(c[2113222]&1^g)&255;return e|0};case 8388984:{e=(c[2113222]&1^((((~~(+((c[3542192]>>8)+8|0)/+(c[2440574]|0)*255.0)&255)*224|0)>>>0)/255|0)+24)&255;return e|0};case 8388633:{e=a[9625584]|0;return e|0};case 8389004:{g=c[3540984]|0;f=(d[g+5887|0]|0|128)&(d[g+5886|0]|0);if((a[g+5884|0]&2)==0){h=f&255}else{h=(a[(c[g+5828>>2]|0)+100|0]&1|f)&255}e=h|6;return e|0};case 8388988:{h=(~~(+((c[3542196]>>8)+8|0)/+(c[2440576]|0)*255.0)&255)*384|0;f=h>>>8;if(h>>>0<90112){i=(((f*208|0)>>>0)/351|0)+48|0}else{i=((f<<5)-11264|0)/31|0}e=(c[2113222]&1^i)&255;return e|0};default:{e=0;return e|0}}return 0}function euD(b,e){b=b|0;e=e|0;var f=0,g=0,h=0;if((b|0)==8389006){f=e&1;a[14120976]=f;g=(c[3541206]|0)+131072|0;h=(c[2433462]|0)+(((f&255)<<17)+131072)|0;gGC(g|0,h|0,131072)|0;return}else if((b|0)==8389004){a[(c[3540984]|0)+5885|0]=e;return}else if((b|0)==8389001){Uv(0,e);return}else if((b|0)==8389002){b=c[3540984]|0;h=c[b+5876>>2]|0;if((h|0)!=0){gg[h&4095](c[b+5880>>2]|0,0)}lH(b,d[b+5885|0]|0,e&255);return}else{return}}function euE(a){a=a|0;return 0}function euF(a,c){a=a|0;c=c|0;switch(a|0){case 8388886:{b[7054668]=c&1023;return};case 8388880:{b[7054652]=c&1023;return};case 8388876:{b[7054672]=c&1023;return};case 8388884:{b[7054664]=c&1023;return};case 8388896:{b[7054656]=c&1023;return};case 8388878:{b[7054660]=c&1023;return};default:{return}}}function euG(b){b=b|0;var d=0,e=0,f=0,g=0;switch(b|0){case 8388645:{d=c[2113156]&255;return d|0};case 8388657:{d=c[2113157]&255;return d|0};case 8388944:{d=a[9657920]|0;return d|0};case 8388948:{d=a[9657921]|0;return d|0};case 8388932:{b=(~~(+((c[3542197]>>8)+8|0)/+(c[2440576]|0)*255.0)&255)*384|0;e=b>>>8;if(b>>>0<90112){f=(((e*208|0)>>>0)/351|0)+48|0}else{f=((e<<5)-11264|0)/31|0}d=(c[2113222]&1^f)+248&255;return d|0};case 8388653:{d=c[(c[3531464]|0)+4240>>2]&255;return d|0};case 8388633:{d=a[9625584]|0;return d|0};case 8388940:{f=(~~(+((c[3542196]>>8)+8|0)/+(c[2440576]|0)*255.0)&255)*384|0;e=f>>>8;if(f>>>0<90112){g=(((e*208|0)>>>0)/351|0)+48|0}else{g=((e<<5)-11264|0)/31|0}d=(c[2113222]&1^g)+248&255;return d|0};case 8388956:{g=a[9625585]|0;if((c[2406632]|0)!=0){d=g;return d|0}e=c[2443744]|0;if((e|0)<=0){d=g;return d|0}c[2443744]=e-1;d=g;return d|0};case 8388928:{d=(c[2113222]&1^((((~~(+((c[3542193]>>8)+8|0)/+(c[2440574]|0)*255.0)&255)*224|0)>>>0)/255|0)+24)+8&255;return d|0};case 8388936:{d=(c[2113222]&1^((((~~(+((c[3542192]>>8)+8|0)/+(c[2440574]|0)*255.0)&255)*224|0)>>>0)/255|0)+24)+8&255;return d|0};default:{d=0;return d|0}}return 0}function euH(b,d){b=b|0;d=d|0;var e=0;switch(b|0){case 8389104:{b=d&255;c[2415256]=b&4;e=b&1;c[3528406]=e^1;if((e|0)==0){c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2]}Tr(b>>>1&1);return};case 8388657:{Uv(1,d);return};case 8388645:{Uv(0,d);return};case 8388649:{c[2113304]=d&255;return};case 8388660:{b=d&3;a[14120976]=b;gGC((c[3541206]|0)+131072|0,(c[2433462]|0)+(((b&255)<<17)+131072)|0,131072)|0;return};case 8388653:{b=c[2113304]|0;a[14168504+b|0]=d;mv(0,b,d&255);return};default:{return}}}function euI(a){a=a|0;return 0}function euJ(a,d){a=a|0;d=d|0;switch(a|0){case 8388880:{b[(c[2443464]|0)+4>>1]=d;return};case 8388896:{b[(c[2443464]|0)+20>>1]=d;return};case 8388886:{b[(c[2443464]|0)+10>>1]=d;return};case 8388878:{b[(c[2443464]|0)+2>>1]=d;return};case 8388876:{b[c[2443464]>>1]=d;return};case 8388884:{b[(c[2443464]|0)+8>>1]=d;return};default:{return}}}function euK(a){a=a|0;return 0}function euL(a,b){a=a|0;b=b|0;return}function euM(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4191540+(b*112|0)>>2];c[a+104>>2]=c[4191544+(b*112|0)>>2];c[a+108>>2]=c[4191548+(b*112|0)>>2];d=0;return d|0}function euN(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=4191440+(b*112|0);e=0;return e|0}function euO(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1303920+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function euP(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>37){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4193568+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function euQ(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;e=i;i=i+120|0;f=e|0;g=e+112|0;c[3527362]=16384;c[2439646]=16384;c[2426688]=0;c[2388022]=0;c[3541206]=1048576;c[2433462]=1310720;c[2405624]=1835008;c[2388042]=1835008;c[2443372]=1916928;c[2443366]=1933312;c[2443360]=1949696;c[2443406]=1966080;c[2439606]=1968128;c[2411588]=2000896;c[2405806]=2000896;c[3529566]=6195200;c[3529958]=10389504;j=0;while(1){if((j|0)>=1024){break}k=9638528+(j<<2)|0;if((c[k>>2]|0)==0){l=5470;break}else{j=j+1|0}}do{if((l|0)==5470){j=gGq(10422272)|0;c[k>>2]=j;if((j|0)==0){break}c[2426688]=j;gGz(j|0,0,10422272);c[2388022]=j;c[3541206]=j+1048576;c[2433462]=j+1310720;m=j+1835008|0;c[2405624]=m;c[2388042]=m;c[2443372]=j+1916928;c[2443366]=j+1933312;c[2443360]=j+1949696;c[2443406]=j+1966080;c[2439606]=j+1968128;m=j+2000896|0;c[2411588]=m;c[2405806]=m;m=(c[3527362]<<8)+2000896|0;c[3529566]=j+m;n=m+(c[2439646]<<8)|0;c[3529958]=j+n;c[2414128]=j+(n+32768);n=0;while(1){if((n|0)>=1024){o=0;break}p=9638528+(n<<2)|0;if((c[p>>2]|0)==0){l=5475;break}else{n=n+1|0}}do{if((l|0)==5475){n=gGq(4194304)|0;c[p>>2]=n;if((n|0)==0){o=0;break}gGz(n|0,0,4194304);o=n}}while(0);c[3529516]=o;if((R6((c[2388022]|0)+1|0,0,2)|0)!=0){q=1;i=e;return q|0}if((R6(c[2388022]|0,1,2)|0)!=0){q=1;i=e;return q|0}if((R6(c[3529516]|0,10,2)|0)!=0){q=1;i=e;return q|0}if((R6((c[3529516]|0)+1|0,11,2)|0)!=0){q=1;i=e;return q|0}if((R6((c[3529516]|0)+1048576|0,12,2)|0)!=0){q=1;i=e;return q|0}if((R6((c[3529516]|0)+1048577|0,13,2)|0)!=0){q=1;i=e;return q|0}if((R6((c[3529516]|0)+2097152|0,14,2)|0)!=0){q=1;i=e;return q|0}if((R6((c[3529516]|0)+2097153|0,15,2)|0)!=0){q=1;i=e;return q|0}if((R6((c[3529516]|0)+3145728|0,16,2)|0)!=0){q=1;i=e;return q|0}if((R6((c[3529516]|0)+3145729|0,17,2)|0)!=0){q=1;i=e;return q|0}n=c[3529516]|0;j=0;do{m=n+j|0;a[m]=~a[m];j=j+1|0;}while((j|0)<4194304);j=c[2405806]|0;m=0;do{r=m<<8;gGz(j+r|0,0,256);s=m<<9;t=0;do{u=1<<7-t;v=(c[684072+(t<<2)>>2]|0)+s|0;w=0;do{x=v+(c[611840+(w<<2)>>2]|0)|0;y=(w<<4)+r|0;z=0;do{A=x+(c[6669352+(z<<2)>>2]|0)|0;if(((d[n+((A|0)/8|0)|0]|0)&128>>>((A&7)>>>0)|0)!=0){A=j+(y+z)|0;a[A]=(d[A]|0|u)&255}z=z+1|0;}while((z|0)<16);w=w+1|0;}while((w|0)<16);t=t+1|0;}while((t|0)<8);m=m+1|0;}while((m|0)<16384);gGz(n|0,0,4194304);if((R6(n,2,2)|0)!=0){q=1;i=e;return q|0}if((R6((c[3529516]|0)+1|0,3,2)|0)!=0){q=1;i=e;return q|0}if((R6((c[3529516]|0)+1048576|0,4,2)|0)!=0){q=1;i=e;return q|0}if((R6((c[3529516]|0)+1048577|0,5,2)|0)!=0){q=1;i=e;return q|0}if((R6((c[3529516]|0)+2097152|0,6,2)|0)!=0){q=1;i=e;return q|0}if((R6((c[3529516]|0)+2097153|0,7,2)|0)!=0){q=1;i=e;return q|0}if((R6((c[3529516]|0)+3145728|0,8,2)|0)!=0){q=1;i=e;return q|0}if((R6((c[3529516]|0)+3145729|0,9,2)|0)!=0){q=1;i=e;return q|0}m=c[3529516]|0;j=0;do{t=m+j|0;a[t]=~a[t];j=j+1|0;}while((j|0)<4194304);j=c[3529566]|0;n=0;do{t=n<<8;gGz(j+t|0,0,256);r=n<<9;s=0;do{w=1<<7-s;u=(c[684072+(s<<2)>>2]|0)+r|0;v=0;do{z=u+(c[611840+(v<<2)>>2]|0)|0;y=(v<<4)+t|0;x=0;do{A=z+(c[6669352+(x<<2)>>2]|0)|0;if(((d[m+((A|0)/8|0)|0]|0)&128>>>((A&7)>>>0)|0)!=0){A=j+(y+x)|0;a[A]=(d[A]|0|w)&255}x=x+1|0;}while((x|0)<16);v=v+1|0;}while((v|0)<16);s=s+1|0;}while((s|0)<8);n=n+1|0;}while((n|0)<16384);n=c[2433462]|0;if((c[3542200]|0)==0){q=1;i=e;return q|0}j=f+108|0;c[j>>2]=0;m=f+100|0;c[m>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,18)|0;do{if((c[j>>2]|0)!=0){s=c[m>>2]|0;c[g>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](g,18,0)|0;if((s|0)<1){q=1;i=e;return q|0}if((gzL(n,0,18)|0)==0){break}else{q=1}i=e;return q|0}}while(0);n=c[3541206]|0;m=c[2433462]|0;gGC(n|0,m|0,262144)|0;m=c[3529516]|0;n=0;while(1){if((n|0)>=1024){break}B=9638528+(n<<2)|0;if((c[B>>2]|0)==(m|0)){l=5526;break}else{n=n+1|0}}if((l|0)==5526){gGr(m);c[B>>2]=0}c[3529516]=0;fxU(0,425984);if((c[2394]|0)==0){C=c[2112932]|0}else{c[2394]=0;n=c[3532596]|0;c[2112932]=n;j=c[3532592]|0;if((j|0)!=0){gGC(9104152,j|0,280)|0}c[2113054]=c[2113060];C=n}n=c[2388022]|0;j=C|0;s=0;while(1){t=n+s|0;c[j>>2]=t;c[j+131072>>2]=t;t=s+1024|0;if(t>>>0>1048575){break}else{j=j+4|0;s=t}}s=c[2443366]|0;c[C+36928>>2]=s;c[C+102464>>2]=s;c[C+168e3>>2]=s;j=s+1024|0;c[C+36932>>2]=j;c[C+102468>>2]=j;c[C+168004>>2]=j;j=s+2048|0;c[C+36936>>2]=j;c[C+102472>>2]=j;c[C+168008>>2]=j;j=s+3072|0;c[C+36940>>2]=j;c[C+102476>>2]=j;c[C+168012>>2]=j;j=s+4096|0;c[C+36944>>2]=j;c[C+102480>>2]=j;c[C+168016>>2]=j;j=s+5120|0;c[C+36948>>2]=j;c[C+102484>>2]=j;c[C+168020>>2]=j;j=s+6144|0;c[C+36952>>2]=j;c[C+102488>>2]=j;c[C+168024>>2]=j;j=s+7168|0;c[C+36956>>2]=j;c[C+102492>>2]=j;c[C+168028>>2]=j;j=s+8192|0;c[C+36960>>2]=j;c[C+102496>>2]=j;c[C+168032>>2]=j;j=s+9216|0;c[C+36964>>2]=j;c[C+102500>>2]=j;c[C+168036>>2]=j;j=s+10240|0;c[C+36968>>2]=j;c[C+102504>>2]=j;c[C+168040>>2]=j;j=s+11264|0;c[C+36972>>2]=j;c[C+102508>>2]=j;c[C+168044>>2]=j;j=s+12288|0;c[C+36976>>2]=j;c[C+102512>>2]=j;c[C+168048>>2]=j;j=s+13312|0;c[C+36980>>2]=j;c[C+102516>>2]=j;c[C+168052>>2]=j;j=s+14336|0;c[C+36984>>2]=j;c[C+102520>>2]=j;c[C+168056>>2]=j;j=s+15360|0;c[C+36988>>2]=j;c[C+102524>>2]=j;c[C+168060>>2]=j;j=c[2443360]|0;c[C+36992>>2]=j;c[C+102528>>2]=j;c[C+168064>>2]=j;s=j+1024|0;c[C+36996>>2]=s;c[C+102532>>2]=s;c[C+168068>>2]=s;s=j+2048|0;c[C+37e3>>2]=s;c[C+102536>>2]=s;c[C+168072>>2]=s;s=j+3072|0;c[C+37004>>2]=s;c[C+102540>>2]=s;c[C+168076>>2]=s;s=j+4096|0;c[C+37008>>2]=s;c[C+102544>>2]=s;c[C+168080>>2]=s;s=j+5120|0;c[C+37012>>2]=s;c[C+102548>>2]=s;c[C+168084>>2]=s;s=j+6144|0;c[C+37016>>2]=s;c[C+102552>>2]=s;c[C+168088>>2]=s;s=j+7168|0;c[C+37020>>2]=s;c[C+102556>>2]=s;c[C+168092>>2]=s;s=j+8192|0;c[C+37024>>2]=s;c[C+102560>>2]=s;c[C+168096>>2]=s;s=j+9216|0;c[C+37028>>2]=s;c[C+102564>>2]=s;c[C+168100>>2]=s;s=j+10240|0;c[C+37032>>2]=s;c[C+102568>>2]=s;c[C+168104>>2]=s;s=j+11264|0;c[C+37036>>2]=s;c[C+102572>>2]=s;c[C+168108>>2]=s;s=j+12288|0;c[C+37040>>2]=s;c[C+102576>>2]=s;c[C+168112>>2]=s;s=j+13312|0;c[C+37044>>2]=s;c[C+102580>>2]=s;c[C+168116>>2]=s;s=j+14336|0;c[C+37048>>2]=s;c[C+102584>>2]=s;c[C+168120>>2]=s;s=j+15360|0;c[C+37052>>2]=s;c[C+102588>>2]=s;c[C+168124>>2]=s;s=c[2443372]|0;c[C+37056>>2]=s;c[C+102592>>2]=s;c[C+168128>>2]=s;j=s+1024|0;c[C+37060>>2]=j;c[C+102596>>2]=j;c[C+168132>>2]=j;j=s+2048|0;c[C+37064>>2]=j;c[C+102600>>2]=j;c[C+168136>>2]=j;j=s+3072|0;c[C+37068>>2]=j;c[C+102604>>2]=j;c[C+168140>>2]=j;j=s+4096|0;c[C+37072>>2]=j;c[C+102608>>2]=j;c[C+168144>>2]=j;j=s+5120|0;c[C+37076>>2]=j;c[C+102612>>2]=j;c[C+168148>>2]=j;j=s+6144|0;c[C+37080>>2]=j;c[C+102616>>2]=j;c[C+168152>>2]=j;j=s+7168|0;c[C+37084>>2]=j;c[C+102620>>2]=j;c[C+168156>>2]=j;j=s+8192|0;c[C+37088>>2]=j;c[C+102624>>2]=j;c[C+168160>>2]=j;j=s+9216|0;c[C+37092>>2]=j;c[C+102628>>2]=j;c[C+168164>>2]=j;j=s+10240|0;c[C+37096>>2]=j;c[C+102632>>2]=j;c[C+168168>>2]=j;j=s+11264|0;c[C+37100>>2]=j;c[C+102636>>2]=j;c[C+168172>>2]=j;j=s+12288|0;c[C+37104>>2]=j;c[C+102640>>2]=j;c[C+168176>>2]=j;j=s+13312|0;c[C+37108>>2]=j;c[C+102644>>2]=j;c[C+168180>>2]=j;j=s+14336|0;c[C+37112>>2]=j;c[C+102648>>2]=j;c[C+168184>>2]=j;j=s+15360|0;c[C+37116>>2]=j;c[C+102652>>2]=j;c[C+168188>>2]=j;j=c[2388042]|0;s=j+65536|0;c[C+37376>>2]=s;c[C+102912>>2]=s;c[C+168448>>2]=s;s=j+66560|0;c[C+37380>>2]=s;c[C+102916>>2]=s;c[C+168452>>2]=s;s=j+67584|0;c[C+37384>>2]=s;c[C+102920>>2]=s;c[C+168456>>2]=s;s=j+68608|0;c[C+37388>>2]=s;c[C+102924>>2]=s;c[C+168460>>2]=s;s=j+69632|0;c[C+37392>>2]=s;c[C+102928>>2]=s;c[C+168464>>2]=s;s=j+70656|0;c[C+37396>>2]=s;c[C+102932>>2]=s;c[C+168468>>2]=s;s=j+71680|0;c[C+37400>>2]=s;c[C+102936>>2]=s;c[C+168472>>2]=s;s=j+72704|0;c[C+37404>>2]=s;c[C+102940>>2]=s;c[C+168476>>2]=s;s=j+73728|0;c[C+37408>>2]=s;c[C+102944>>2]=s;c[C+168480>>2]=s;s=j+74752|0;c[C+37412>>2]=s;c[C+102948>>2]=s;c[C+168484>>2]=s;s=j+75776|0;c[C+37416>>2]=s;c[C+102952>>2]=s;c[C+168488>>2]=s;s=j+76800|0;c[C+37420>>2]=s;c[C+102956>>2]=s;c[C+168492>>2]=s;s=j+77824|0;c[C+37424>>2]=s;c[C+102960>>2]=s;c[C+168496>>2]=s;s=j+78848|0;c[C+37428>>2]=s;c[C+102964>>2]=s;c[C+168500>>2]=s;s=j+79872|0;c[C+37432>>2]=s;c[C+102968>>2]=s;c[C+168504>>2]=s;s=j+80896|0;c[C+37436>>2]=s;c[C+102972>>2]=s;c[C+168508>>2]=s;s=c[2443406]|0;c[C+37632>>2]=s;c[C+103168>>2]=s;c[C+168704>>2]=s;n=s+1024|0;c[C+37636>>2]=n;c[C+103172>>2]=n;c[C+168708>>2]=n;n=c[2439606]|0;s=C+37888|0;m=9699328;while(1){t=n+(m-9699328)|0;c[s>>2]=t;c[s+65536>>2]=t;c[s+131072>>2]=t;t=m+1024|0;if(t>>>0>9732095){break}else{s=s+4|0;m=t}}m=C+65280|0;s=16711680;while(1){n=j+(s-16711680)|0;c[m>>2]=n;c[m+65536>>2]=n;c[m+131072>>2]=n;n=s+1024|0;if(n>>>0>16777215){break}else{m=m+4|0;s=n}}c[C+196688>>2]=3416;c[C+196728>>2]=2336;c[C+196608>>2]=3102;c[C+196648>>2]=2590;s=c[3532592]|0;if((s|0)!=0){gGC(s|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;UL(3579545,0,1698,0);c[2438224]=16e6;c[2433522]=4710;c[2406672]=148;c[3528468]=444;c[2443842]=127;h[745398]=.4;a[3203264]=1;Ux(0,8e3,1);c[2407030]=205;c[2407068]=3;s=c[642608+(c[2436]<<2)>>2]|0;m=c[s+128>>2]|0;if((c[s+52>>2]&4|0)==0){c[2113068]=m;j=c[s+132>>2]|0;c[2113070]=j;c[2443814]=m;c[2440436]=j;D=m;E=j}else{c[2113070]=m;j=c[s+132>>2]|0;c[2113068]=j;c[2440436]=m;c[2443814]=j;D=j;E=m}m=ag(D<<1,E)|0;j=gGq(m)|0;c[2112926]=j;if((j|0)!=0){gGz(j|0,0,m|0)}c[2427046]=7300;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];m=c[3532592]|0;if((m|0)!=0){gGC(9104152,m|0,280)|0}c[2113054]=c[2113060]}RI();m=c[2394]|0;j=c[14130368+(m<<2)>>2]|0;if((j|0)!=0){gGC(j|0,9104152,280)|0}c[8452240+(m<<2)>>2]=c[2113054];c[2394]=-1;c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;lw(c[3540984]|0);c[2113156]=0;a[9628264]=0;c[2407033]=0;m=c[3541206]|0;c[3541190]=m;c[3541198]=m;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=m+256;c[3541199]=m+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=m+512;c[3541200]=m+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=m+768;c[3541201]=m+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;b[7054672]=0;b[7054660]=0;b[7054668]=0;b[7054656]=0;b[7054664]=0;b[7054652]=0;a[14120976]=0;q=0;i=e;return q|0}}while(0);c[2426688]=0;q=1;i=e;return q|0}function euR(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=a[7452584]|0;if(d){e=0;f=d&1;while(1){d=14163936+(e<<2)|0;g=c[d>>2]|0;h=c[2113006]|0;if((h|0)==0){i=5580}else{j=h-1|0;c[2113006]=j;if((j|0)==0){i=5580}}if((i|0)==5580){i=0;c[2383474]=0}if((g|0)==0){k=f}else{gGr(g);k=a[7452584]&1}c[d>>2]=0;d=e+1|0;if((d|0)<(k|0)){e=d;f=k}else{break}}}a[7452584]=0;c[2438224]=0;c[2433522]=0;c[2406672]=0;c[3528468]=0;k=c[2406688]|0;if((k|0)!=0){gGr(k);c[2406688]=0}c[2432972]=0;if((c[2392]|0)>=0){k=0;do{f=14130368+(k<<2)|0;e=c[f>>2]|0;if((e|0)!=0){gGr(e);c[f>>2]=0}f=14130384+(k<<2)|0;e=c[f>>2]|0;if((e|0)!=0){gGr(e);c[f>>2]=0}k=k+1|0;}while((k|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;Uw(0);c[2113070]=0;c[2113068]=0;k=c[2112926]|0;if((k|0)!=0){gGr(k);c[2112926]=0}if((c[2113302]|0)!=0){c[2113302]=0;a[801640]=0;c[2440576]=0;c[2440574]=0;gGz(14168784,0,16);gGz(14168768,0,16)}b[7054672]=0;b[7054660]=0;b[7054668]=0;b[7054656]=0;b[7054664]=0;b[7054652]=0;a[14120976]=0;c[3527362]=0;c[2439646]=0;c[2427046]=0;k=c[2426688]|0;f=0;while(1){if((f|0)>=1024){i=5601;break}l=9638528+(f<<2)|0;if((c[l>>2]|0)==(k|0)){break}else{f=f+1|0}}if((i|0)==5601){c[2426688]=0;return 0}gGr(k);c[l>>2]=0;c[2426688]=0;return 0}function euS(){var d=0,f=0,g=0,i=0,j=0;if((a[9623896]|0)!=0){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;f=c[14130368+(d<<2)>>2]|0;if((f|0)!=0){gGC(f|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;lw(c[3540984]|0);c[2113156]=0;a[9628264]=0;c[2407033]=0;d=c[3541206]|0;c[3541190]=d;c[3541198]=d;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=d+256;c[3541199]=d+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=d+512;c[3541200]=d+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=d+768;c[3541201]=d+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;b[7054672]=0;b[7054660]=0;b[7054668]=0;b[7054656]=0;b[7054664]=0;b[7054652]=0;a[14120976]=0}gu[c[2427046]&16383]();a[6518200]=1;c[2444068]=0;d=c[2392]|0;if((d|0)>=0){gGz(8452240,0,((d|0)>0?(d<<2)+4|0:4)|0)}c[2113054]=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}d=c[2438224]|0;f=gGS(1106509824,127156,d,(d|0)<0|0?-1:0)|0;d=f;UF(266666)|0;f=c[2443826]|0;if((f|0)<1073676288){c[2443826]=f-d}f=c[2443827]|0;if((f|0)<1073676288){c[2443827]=f-d}f=(c[3528508]|0)-d|0;c[3528508]=(f|0)<0?0:f;c[8452200+(c[2394]<<2)>>2]=8194;c[2276080]=512;if((c[2276079]|0)>>>0<512){RH(2)}gg[c[3542112]&4095](c[2112964]|0,a[9688]|0?534:0);Uu(0,c[2112964]|0,a[9688]|0?534:0);f=c[2394]|0;d=c[14130368+(f<<2)>>2]|0;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[8452240+(f<<2)>>2]=c[2113054];c[2394]=-1;if((c[2112968]|0)==0){return 0}f=c[2112926]|0;gGz(f|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);d=c[2439606]|0;g=c[3529958]|0;i=0;do{c[g+(i>>1<<2)>>2]=(e[d+((i|1)<<1)>>1]|0)>>>8&31|b[d+(i<<1)>>1]&2016;i=i+2|0;}while((i|0)<16384);i=ag(c[2113068]|0,c[2113070]|0)|0;if((i|0)>0){d=0;do{b[f+(d<<1)>>1]=7936;d=d+1|0;}while((d|0)<(i|0))}eve(0);evf(0);eve(1);evf(1);eve(2);evf(2);evf(3);R8(g);g=c[2113302]|0;if((g|0)>0){j=0}else{return 0}do{R7(j,c[14168784+(j<<2)>>2]>>8,c[14168768+(j<<2)>>2]>>8);j=j+1|0;}while((j|0)<(g|0));return 0}function euT(a,b){a=a|0;b=b|0;eu9(a,b);if((a&64|0)!=0){UQ(a,b)}if((a&2|0)==0){return 0}a=c[3541206]|0;b=(c[2433462]|0)+((d[14120976]|0)<<18)|0;gGC(a|0,b|0,262144)|0;return 0}function euU(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4856844+(b*112|0)>>2];c[a+104>>2]=c[4856848+(b*112|0)>>2];c[a+108>>2]=c[4856852+(b*112|0)>>2];d=0;return d|0}function euV(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=4856744+(b*112|0);e=0;return e|0}function euW(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1632616+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function euX(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>25){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4857976+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function euY(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;e=i;i=i+1080|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;c[3527362]=32768;c[2439646]=32768;c[2426688]=0;c[2388022]=0;c[3541206]=1048576;c[2433462]=1310720;c[2405624]=1835008;c[2388042]=1835008;c[2443372]=1916928;c[2443366]=1933312;c[2443360]=1949696;c[2443406]=1966080;c[2439606]=1968128;c[2411588]=2000896;c[2405806]=2000896;c[3529566]=10389504;c[3529958]=18778112;z=0;while(1){if((z|0)>=1024){break}A=9638528+(z<<2)|0;if((c[A>>2]|0)==0){B=5672;break}else{z=z+1|0}}do{if((B|0)==5672){z=gGq(18810880)|0;c[A>>2]=z;if((z|0)==0){break}c[2426688]=z;gGz(z|0,0,18810880);c[2388022]=z;c[3541206]=z+1048576;c[2433462]=z+1310720;C=z+1835008|0;c[2405624]=C;c[2388042]=C;c[2443372]=z+1916928;c[2443366]=z+1933312;c[2443360]=z+1949696;c[2443406]=z+1966080;c[2439606]=z+1968128;C=z+2000896|0;c[2411588]=C;c[2405806]=C;C=(c[3527362]<<8)+2000896|0;c[3529566]=z+C;D=C+(c[2439646]<<8)|0;c[3529958]=z+D;c[2414128]=z+(D+32768);D=0;while(1){if((D|0)>=1024){E=0;break}F=9638528+(D<<2)|0;if((c[F>>2]|0)==0){B=5677;break}else{D=D+1|0}}do{if((B|0)==5677){D=gGq(8388608)|0;c[F>>2]=D;if((D|0)==0){E=0;break}gGz(D|0,0,8388608);E=D}}while(0);c[3529516]=E;if((R6((c[2388022]|0)+1|0,0,2)|0)!=0){G=1;i=e;return G|0}if((R6(c[2388022]|0,1,2)|0)!=0){G=1;i=e;return G|0}D=c[3529516]|0;if((c[3542200]|0)==0){G=1;i=e;return G|0}z=x+108|0;c[z>>2]=0;C=x+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,6)|0;do{if((c[z>>2]|0)!=0){H=c[C>>2]|0;c[y>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](y,6,0)|0;if((H|0)<1){G=1;i=e;return G|0}if((gzL(D,0,6)|0)==0){break}else{G=1}i=e;return G|0}}while(0);D=(c[3529516]|0)+2097152|0;if((c[3542200]|0)==0){G=1;i=e;return G|0}C=v+108|0;c[C>>2]=0;z=v+100|0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,7)|0;do{if((c[C>>2]|0)!=0){H=c[z>>2]|0;c[w>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](w,7,0)|0;if((H|0)<1){G=1;i=e;return G|0}if((gzL(D,0,7)|0)==0){break}else{G=1}i=e;return G|0}}while(0);D=(c[3529516]|0)+4194304|0;if((c[3542200]|0)==0){G=1;i=e;return G|0}z=t+108|0;c[z>>2]=0;C=t+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,8)|0;do{if((c[z>>2]|0)!=0){H=c[C>>2]|0;c[u>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](u,8,0)|0;if((H|0)<1){G=1;i=e;return G|0}if((gzL(D,0,8)|0)==0){break}else{G=1}i=e;return G|0}}while(0);D=(c[3529516]|0)+6291456|0;if((c[3542200]|0)==0){G=1;i=e;return G|0}C=r+108|0;c[C>>2]=0;z=r+100|0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,9)|0;do{if((c[C>>2]|0)!=0){H=c[z>>2]|0;c[s>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](s,9,0)|0;if((H|0)<1){G=1;i=e;return G|0}if((gzL(D,0,9)|0)==0){break}else{G=1}i=e;return G|0}}while(0);D=c[3529516]|0;z=0;do{C=D+z|0;a[C]=~a[C];z=z+1|0;}while((z|0)<8388608);z=c[2405806]|0;C=0;do{H=C<<8;gGz(z+H|0,0,256);I=C<<9;J=0;do{K=1<<7-J;L=(c[685304+(J<<2)>>2]|0)+I|0;M=0;do{N=L+(c[611840+(M<<2)>>2]|0)|0;O=(M<<4)+H|0;P=0;do{Q=N+(c[6669352+(P<<2)>>2]|0)|0;if(((d[D+((Q|0)/8|0)|0]|0)&128>>>((Q&7)>>>0)|0)!=0){Q=z+(O+P)|0;a[Q]=(d[Q]|0|K)&255}P=P+1|0;}while((P|0)<16);M=M+1|0;}while((M|0)<16);J=J+1|0;}while((J|0)<8);C=C+1|0;}while((C|0)<32768);gGz(D|0,0,8388608);if((c[3542200]|0)==0){G=1;i=e;return G|0}C=p+108|0;c[C>>2]=0;z=p+100|0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,2)|0;do{if((c[C>>2]|0)!=0){J=c[z>>2]|0;c[q>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](q,2,0)|0;if((J|0)<1){G=1;i=e;return G|0}if((gzL(D,0,2)|0)==0){break}else{G=1}i=e;return G|0}}while(0);D=(c[3529516]|0)+2097152|0;if((c[3542200]|0)==0){G=1;i=e;return G|0}z=n+108|0;c[z>>2]=0;C=n+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,3)|0;do{if((c[z>>2]|0)!=0){J=c[C>>2]|0;c[o>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](o,3,0)|0;if((J|0)<1){G=1;i=e;return G|0}if((gzL(D,0,3)|0)==0){break}else{G=1}i=e;return G|0}}while(0);D=(c[3529516]|0)+4194304|0;if((c[3542200]|0)==0){G=1;i=e;return G|0}C=l+108|0;c[C>>2]=0;z=l+100|0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,4)|0;do{if((c[C>>2]|0)!=0){J=c[z>>2]|0;c[m>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](m,4,0)|0;if((J|0)<1){G=1;i=e;return G|0}if((gzL(D,0,4)|0)==0){break}else{G=1}i=e;return G|0}}while(0);D=(c[3529516]|0)+6291456|0;if((c[3542200]|0)==0){G=1;i=e;return G|0}z=j+108|0;c[z>>2]=0;C=j+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,5)|0;do{if((c[z>>2]|0)!=0){J=c[C>>2]|0;c[k>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](k,5,0)|0;if((J|0)<1){G=1;i=e;return G|0}if((gzL(D,0,5)|0)==0){break}else{G=1}i=e;return G|0}}while(0);D=c[3529516]|0;C=0;do{z=D+C|0;a[z]=~a[z];C=C+1|0;}while((C|0)<8388608);C=c[3529566]|0;z=0;do{J=z<<8;gGz(C+J|0,0,256);H=z<<9;I=0;do{M=1<<7-I;K=(c[685304+(I<<2)>>2]|0)+H|0;L=0;do{P=K+(c[611840+(L<<2)>>2]|0)|0;O=(L<<4)+J|0;N=0;do{Q=P+(c[6669352+(N<<2)>>2]|0)|0;if(((d[D+((Q|0)/8|0)|0]|0)&128>>>((Q&7)>>>0)|0)!=0){Q=C+(O+N)|0;a[Q]=(d[Q]|0|M)&255}N=N+1|0;}while((N|0)<16);L=L+1|0;}while((L|0)<16);I=I+1|0;}while((I|0)<8);z=z+1|0;}while((z|0)<32768);z=c[2433462]|0;if((c[3542200]|0)==0){G=1;i=e;return G|0}C=f+108|0;c[C>>2]=0;D=f+100|0;c[D>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,10)|0;do{if((c[C>>2]|0)!=0){I=c[D>>2]|0;c[g>>2]=9534384;J=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[J&16383](g,10,0)|0;if((I|0)<1){G=1;i=e;return G|0}if((gzL(z,0,10)|0)==0){break}else{G=1}i=e;return G|0}}while(0);z=c[3541206]|0;D=c[2433462]|0;gGC(z|0,D|0,262144)|0;D=c[3529516]|0;z=0;while(1){if((z|0)>=1024){break}R=9638528+(z<<2)|0;if((c[R>>2]|0)==(D|0)){B=5744;break}else{z=z+1|0}}if((B|0)==5744){gGr(D);c[R>>2]=0}c[3529516]=0;fxU(0,425984);if((c[2394]|0)==0){S=c[2112932]|0}else{c[2394]=0;z=c[3532596]|0;c[2112932]=z;C=c[3532592]|0;if((C|0)!=0){gGC(9104152,C|0,280)|0}c[2113054]=c[2113060];S=z}z=c[2388022]|0;C=S|0;I=0;while(1){J=z+I|0;c[C>>2]=J;c[C+131072>>2]=J;J=I+1024|0;if(J>>>0>1048575){break}else{C=C+4|0;I=J}}I=c[2443366]|0;c[S+36928>>2]=I;c[S+102464>>2]=I;c[S+168e3>>2]=I;C=I+1024|0;c[S+36932>>2]=C;c[S+102468>>2]=C;c[S+168004>>2]=C;C=I+2048|0;c[S+36936>>2]=C;c[S+102472>>2]=C;c[S+168008>>2]=C;C=I+3072|0;c[S+36940>>2]=C;c[S+102476>>2]=C;c[S+168012>>2]=C;C=I+4096|0;c[S+36944>>2]=C;c[S+102480>>2]=C;c[S+168016>>2]=C;C=I+5120|0;c[S+36948>>2]=C;c[S+102484>>2]=C;c[S+168020>>2]=C;C=I+6144|0;c[S+36952>>2]=C;c[S+102488>>2]=C;c[S+168024>>2]=C;C=I+7168|0;c[S+36956>>2]=C;c[S+102492>>2]=C;c[S+168028>>2]=C;C=I+8192|0;c[S+36960>>2]=C;c[S+102496>>2]=C;c[S+168032>>2]=C;C=I+9216|0;c[S+36964>>2]=C;c[S+102500>>2]=C;c[S+168036>>2]=C;C=I+10240|0;c[S+36968>>2]=C;c[S+102504>>2]=C;c[S+168040>>2]=C;C=I+11264|0;c[S+36972>>2]=C;c[S+102508>>2]=C;c[S+168044>>2]=C;C=I+12288|0;c[S+36976>>2]=C;c[S+102512>>2]=C;c[S+168048>>2]=C;C=I+13312|0;c[S+36980>>2]=C;c[S+102516>>2]=C;c[S+168052>>2]=C;C=I+14336|0;c[S+36984>>2]=C;c[S+102520>>2]=C;c[S+168056>>2]=C;C=I+15360|0;c[S+36988>>2]=C;c[S+102524>>2]=C;c[S+168060>>2]=C;C=c[2443360]|0;c[S+36992>>2]=C;c[S+102528>>2]=C;c[S+168064>>2]=C;I=C+1024|0;c[S+36996>>2]=I;c[S+102532>>2]=I;c[S+168068>>2]=I;I=C+2048|0;c[S+37e3>>2]=I;c[S+102536>>2]=I;c[S+168072>>2]=I;I=C+3072|0;c[S+37004>>2]=I;c[S+102540>>2]=I;c[S+168076>>2]=I;I=C+4096|0;c[S+37008>>2]=I;c[S+102544>>2]=I;c[S+168080>>2]=I;I=C+5120|0;c[S+37012>>2]=I;c[S+102548>>2]=I;c[S+168084>>2]=I;I=C+6144|0;c[S+37016>>2]=I;c[S+102552>>2]=I;c[S+168088>>2]=I;I=C+7168|0;c[S+37020>>2]=I;c[S+102556>>2]=I;c[S+168092>>2]=I;I=C+8192|0;c[S+37024>>2]=I;c[S+102560>>2]=I;c[S+168096>>2]=I;I=C+9216|0;c[S+37028>>2]=I;c[S+102564>>2]=I;c[S+168100>>2]=I;I=C+10240|0;c[S+37032>>2]=I;c[S+102568>>2]=I;c[S+168104>>2]=I;I=C+11264|0;c[S+37036>>2]=I;c[S+102572>>2]=I;c[S+168108>>2]=I;I=C+12288|0;c[S+37040>>2]=I;c[S+102576>>2]=I;c[S+168112>>2]=I;I=C+13312|0;c[S+37044>>2]=I;c[S+102580>>2]=I;c[S+168116>>2]=I;I=C+14336|0;c[S+37048>>2]=I;c[S+102584>>2]=I;c[S+168120>>2]=I;I=C+15360|0;c[S+37052>>2]=I;c[S+102588>>2]=I;c[S+168124>>2]=I;I=c[2443372]|0;c[S+37056>>2]=I;c[S+102592>>2]=I;c[S+168128>>2]=I;C=I+1024|0;c[S+37060>>2]=C;c[S+102596>>2]=C;c[S+168132>>2]=C;C=I+2048|0;c[S+37064>>2]=C;c[S+102600>>2]=C;c[S+168136>>2]=C;C=I+3072|0;c[S+37068>>2]=C;c[S+102604>>2]=C;c[S+168140>>2]=C;C=I+4096|0;c[S+37072>>2]=C;c[S+102608>>2]=C;c[S+168144>>2]=C;C=I+5120|0;c[S+37076>>2]=C;c[S+102612>>2]=C;c[S+168148>>2]=C;C=I+6144|0;c[S+37080>>2]=C;c[S+102616>>2]=C;c[S+168152>>2]=C;C=I+7168|0;c[S+37084>>2]=C;c[S+102620>>2]=C;c[S+168156>>2]=C;C=I+8192|0;c[S+37088>>2]=C;c[S+102624>>2]=C;c[S+168160>>2]=C;C=I+9216|0;c[S+37092>>2]=C;c[S+102628>>2]=C;c[S+168164>>2]=C;C=I+10240|0;c[S+37096>>2]=C;c[S+102632>>2]=C;c[S+168168>>2]=C;C=I+11264|0;c[S+37100>>2]=C;c[S+102636>>2]=C;c[S+168172>>2]=C;C=I+12288|0;c[S+37104>>2]=C;c[S+102640>>2]=C;c[S+168176>>2]=C;C=I+13312|0;c[S+37108>>2]=C;c[S+102644>>2]=C;c[S+168180>>2]=C;C=I+14336|0;c[S+37112>>2]=C;c[S+102648>>2]=C;c[S+168184>>2]=C;C=I+15360|0;c[S+37116>>2]=C;c[S+102652>>2]=C;c[S+168188>>2]=C;C=c[2388042]|0;I=C+65536|0;c[S+37376>>2]=I;c[S+102912>>2]=I;c[S+168448>>2]=I;I=C+66560|0;c[S+37380>>2]=I;c[S+102916>>2]=I;c[S+168452>>2]=I;I=C+67584|0;c[S+37384>>2]=I;c[S+102920>>2]=I;c[S+168456>>2]=I;I=C+68608|0;c[S+37388>>2]=I;c[S+102924>>2]=I;c[S+168460>>2]=I;I=C+69632|0;c[S+37392>>2]=I;c[S+102928>>2]=I;c[S+168464>>2]=I;I=C+70656|0;c[S+37396>>2]=I;c[S+102932>>2]=I;c[S+168468>>2]=I;I=C+71680|0;c[S+37400>>2]=I;c[S+102936>>2]=I;c[S+168472>>2]=I;I=C+72704|0;c[S+37404>>2]=I;c[S+102940>>2]=I;c[S+168476>>2]=I;I=C+73728|0;c[S+37408>>2]=I;c[S+102944>>2]=I;c[S+168480>>2]=I;I=C+74752|0;c[S+37412>>2]=I;c[S+102948>>2]=I;c[S+168484>>2]=I;I=C+75776|0;c[S+37416>>2]=I;c[S+102952>>2]=I;c[S+168488>>2]=I;I=C+76800|0;c[S+37420>>2]=I;c[S+102956>>2]=I;c[S+168492>>2]=I;I=C+77824|0;c[S+37424>>2]=I;c[S+102960>>2]=I;c[S+168496>>2]=I;I=C+78848|0;c[S+37428>>2]=I;c[S+102964>>2]=I;c[S+168500>>2]=I;I=C+79872|0;c[S+37432>>2]=I;c[S+102968>>2]=I;c[S+168504>>2]=I;I=C+80896|0;c[S+37436>>2]=I;c[S+102972>>2]=I;c[S+168508>>2]=I;I=c[2443406]|0;c[S+37632>>2]=I;c[S+103168>>2]=I;c[S+168704>>2]=I;z=I+1024|0;c[S+37636>>2]=z;c[S+103172>>2]=z;c[S+168708>>2]=z;z=c[2439606]|0;I=S+37888|0;D=9699328;while(1){J=z+(D-9699328)|0;c[I>>2]=J;c[I+65536>>2]=J;c[I+131072>>2]=J;J=D+1024|0;if(J>>>0>9732095){break}else{I=I+4|0;D=J}}D=S+61184|0;I=15663104;while(1){z=C+(I-15663104)|0;c[D>>2]=z;c[D+65536>>2]=z;c[D+131072>>2]=z;z=I+1024|0;if(z>>>0>15728639){break}else{D=D+4|0;I=z}}c[S+196688>>2]=2710;c[S+196728>>2]=3228;c[S+196608>>2]=216;c[S+196648>>2]=1278;I=c[3532592]|0;if((I|0)!=0){gGC(I|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;UL(3579545,0,1698,0);c[2438224]=16e6;c[2433522]=4710;c[2406672]=148;c[3528468]=444;c[2443842]=127;h[745398]=.4;a[3203264]=1;Ux(0,8e3,1);c[2407030]=205;c[2407068]=3;I=c[642608+(c[2436]<<2)>>2]|0;D=c[I+128>>2]|0;if((c[I+52>>2]&4|0)==0){c[2113068]=D;C=c[I+132>>2]|0;c[2113070]=C;c[2443814]=D;c[2440436]=C;T=D;U=C}else{c[2113070]=D;C=c[I+132>>2]|0;c[2113068]=C;c[2440436]=D;c[2443814]=C;T=C;U=D}D=ag(T<<1,U)|0;C=gGq(D)|0;c[2112926]=C;if((C|0)!=0){gGz(C|0,0,D|0)}c[2113302]=2;a[801640]=0;D=c[642608+(c[2436]<<2)>>2]|0;C=c[D+128>>2]|0;if((c[D+52>>2]&4|0)==0){c[2440576]=C;I=c[D+132>>2]|0;c[2440574]=I;V=C;W=I}else{c[2440574]=C;I=c[D+132>>2]|0;c[2440576]=I;V=I;W=C}C=(((V|0)/2|0)<<8)-1792|0;I=(((W|0)/2|0)<<8)-2048|0;c[3542196]=C;c[3542192]=I;c[3542197]=C;c[3542193]=I;c[3542198]=C;c[3542194]=I;c[3542199]=C;c[3542195]=I;c[2427046]=2584;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];I=c[3532592]|0;if((I|0)!=0){gGC(9104152,I|0,280)|0}c[2113054]=c[2113060]}RI();I=c[2394]|0;C=c[14130368+(I<<2)>>2]|0;if((C|0)!=0){gGC(C|0,9104152,280)|0}c[8452240+(I<<2)>>2]=c[2113054];c[2394]=-1;c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;lw(c[3540984]|0);c[2113156]=0;a[9628264]=0;c[2407033]=0;I=c[3541206]|0;c[3541190]=I;c[3541198]=I;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=I+256;c[3541199]=I+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=I+512;c[3541200]=I+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=I+768;c[3541201]=I+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;b[7054672]=0;b[7054660]=0;b[7054668]=0;b[7054656]=0;b[7054664]=0;b[7054652]=0;a[14120976]=0;G=0;i=e;return G|0}}while(0);c[2426688]=0;G=1;i=e;return G|0}function euZ(a,b){a=a|0;b=b|0;eu9(a,b);if((a&64|0)!=0){UQ(a,b)}if((a&2|0)==0){return 0}a=(c[3541206]|0)+131072|0;b=(c[2433462]|0)+(((d[14120976]|0)<<17)+131072)|0;gGC(a|0,b|0,131072)|0;return 0}function eu_(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3189860+(b*112|0)>>2];c[a+104>>2]=c[3189864+(b*112|0)>>2];c[a+108>>2]=c[3189868+(b*112|0)>>2];d=0;return d|0}function eu$(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=3189760+(b*112|0);e=0;return e|0}function eu0(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3191092+(b*112|0)>>2];c[a+104>>2]=c[3191096+(b*112|0)>>2];c[a+108>>2]=c[3191100+(b*112|0)>>2];d=0;return d|0}function eu1(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=3190992+(b*112|0);e=0;return e|0}function eu2(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3192324+(b*112|0)>>2];c[a+104>>2]=c[3192328+(b*112|0)>>2];c[a+108>>2]=c[3192332+(b*112|0)>>2];d=0;return d|0}function eu3(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=3192224+(b*112|0);e=0;return e|0}function eu4(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>40){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3193568+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eu5(){var b=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;b=i;i=i+1200|0;e=b|0;f=b+112|0;g=b+120|0;j=b+232|0;k=b+240|0;l=b+352|0;m=b+360|0;n=b+472|0;o=b+480|0;p=b+592|0;q=b+600|0;r=b+712|0;s=b+720|0;t=b+832|0;u=b+840|0;v=b+952|0;w=b+960|0;x=b+1072|0;y=b+1080|0;z=b+1192|0;c[3527362]=65536;c[2439646]=65536;c[2426688]=0;c[2388022]=0;c[3541206]=2097152;c[2433462]=3407872;c[2405624]=3932160;c[2388042]=3932160;c[2443372]=4079616;c[2443366]=4096e3;c[2443360]=4112384;c[2443406]=4128768;c[2439606]=4130816;c[2443464]=4163584;c[2411588]=4163608;c[2405806]=4163608;c[3529566]=20940824;c[3529958]=37718040;A=0;while(1){if((A|0)>=1024){break}B=9638528+(A<<2)|0;if((c[B>>2]|0)==0){C=5858;break}else{A=A+1|0}}do{if((C|0)==5858){A=gGq(37750808)|0;c[B>>2]=A;if((A|0)==0){break}c[2426688]=A;gGz(A|0,0,37750808);c[2388022]=A;c[3541206]=A+2097152;c[2433462]=A+3407872;D=A+3932160|0;c[2405624]=D;c[2388042]=D;c[2443372]=A+4079616;c[2443366]=A+4096e3;c[2443360]=A+4112384;c[2443406]=A+4128768;c[2439606]=A+4130816;c[2443464]=A+4163584;D=A+4163608|0;c[2411588]=D;c[2405806]=D;D=(c[3527362]<<8)+4163608|0;c[3529566]=A+D;E=D+(c[2439646]<<8)|0;c[3529958]=A+E;c[2414128]=A+(E+32768);E=0;while(1){if((E|0)>=1024){F=0;break}G=9638528+(E<<2)|0;if((c[G>>2]|0)==0){C=5863;break}else{E=E+1|0}}do{if((C|0)==5863){E=gGq(16777216)|0;c[G>>2]=E;if((E|0)==0){F=0;break}gGz(E|0,0,16777216);F=E}}while(0);c[3529516]=F;if((R6(c[2388022]|0,0,2)|0)!=0){H=1;i=b;return H|0}if((R6((c[2388022]|0)+1|0,1,2)|0)!=0){H=1;i=b;return H|0}E=c[2388022]|0;A=0;do{D=E+(A|1)|0;I=a[D]|0;J=E+(A|2)|0;a[D]=a[J]|0;a[J]=I;A=A+4|0;}while((A|0)<2097152);A=c[3529516]|0;if((c[3542200]|0)==0){H=1;i=b;return H|0}E=y+108|0;c[E>>2]=0;I=y+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](y,6)|0;do{if((c[E>>2]|0)!=0){J=c[I>>2]|0;c[z>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](z,6,0)|0;if((J|0)<1){H=1;i=b;return H|0}if((gzL(A,0,6)|0)==0){break}else{H=1}i=b;return H|0}}while(0);A=(c[3529516]|0)+4194304|0;if((c[3542200]|0)==0){H=1;i=b;return H|0}I=w+108|0;c[I>>2]=0;E=w+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](w,7)|0;do{if((c[I>>2]|0)!=0){J=c[E>>2]|0;c[x>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](x,7,0)|0;if((J|0)<1){H=1;i=b;return H|0}if((gzL(A,0,7)|0)==0){break}else{H=1}i=b;return H|0}}while(0);A=(c[3529516]|0)+8388608|0;if((c[3542200]|0)==0){H=1;i=b;return H|0}E=u+108|0;c[E>>2]=0;I=u+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](u,8)|0;do{if((c[E>>2]|0)!=0){J=c[I>>2]|0;c[v>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](v,8,0)|0;if((J|0)<1){H=1;i=b;return H|0}if((gzL(A,0,8)|0)==0){break}else{H=1}i=b;return H|0}}while(0);A=(c[3529516]|0)+12582912|0;if((c[3542200]|0)==0){H=1;i=b;return H|0}I=s+108|0;c[I>>2]=0;E=s+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](s,9)|0;do{if((c[I>>2]|0)!=0){J=c[E>>2]|0;c[t>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](t,9,0)|0;if((J|0)<1){H=1;i=b;return H|0}if((gzL(A,0,9)|0)==0){break}else{H=1}i=b;return H|0}}while(0);A=c[3529516]|0;E=0;do{I=A+E|0;a[I]=~a[I];E=E+1|0;}while((E|0)<16777216);E=c[2405806]|0;I=0;do{J=I<<8;gGz(E+J|0,0,256);D=I<<9;K=0;do{L=1<<7-K;M=(c[683888+(K<<2)>>2]|0)+D|0;N=0;do{O=M+(c[611840+(N<<2)>>2]|0)|0;P=(N<<4)+J|0;Q=0;do{R=O+(c[6669352+(Q<<2)>>2]|0)|0;if(((d[A+((R|0)/8|0)|0]|0)&128>>>((R&7)>>>0)|0)!=0){R=E+(P+Q)|0;a[R]=(d[R]|0|L)&255}Q=Q+1|0;}while((Q|0)<16);N=N+1|0;}while((N|0)<16);K=K+1|0;}while((K|0)<8);I=I+1|0;}while((I|0)<65536);gGz(A|0,0,16777216);if((c[3542200]|0)==0){H=1;i=b;return H|0}I=q+108|0;c[I>>2]=0;E=q+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](q,2)|0;do{if((c[I>>2]|0)!=0){K=c[E>>2]|0;c[r>>2]=9534384;J=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[J&16383](r,2,0)|0;if((K|0)<1){H=1;i=b;return H|0}if((gzL(A,0,2)|0)==0){break}else{H=1}i=b;return H|0}}while(0);A=(c[3529516]|0)+4194304|0;if((c[3542200]|0)==0){H=1;i=b;return H|0}E=o+108|0;c[E>>2]=0;I=o+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](o,3)|0;do{if((c[E>>2]|0)!=0){K=c[I>>2]|0;c[p>>2]=9534384;J=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[J&16383](p,3,0)|0;if((K|0)<1){H=1;i=b;return H|0}if((gzL(A,0,3)|0)==0){break}else{H=1}i=b;return H|0}}while(0);A=(c[3529516]|0)+8388608|0;if((c[3542200]|0)==0){H=1;i=b;return H|0}I=m+108|0;c[I>>2]=0;E=m+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,4)|0;do{if((c[I>>2]|0)!=0){K=c[E>>2]|0;c[n>>2]=9534384;J=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[J&16383](n,4,0)|0;if((K|0)<1){H=1;i=b;return H|0}if((gzL(A,0,4)|0)==0){break}else{H=1}i=b;return H|0}}while(0);A=(c[3529516]|0)+12582912|0;if((c[3542200]|0)==0){H=1;i=b;return H|0}E=k+108|0;c[E>>2]=0;I=k+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,5)|0;do{if((c[E>>2]|0)!=0){K=c[I>>2]|0;c[l>>2]=9534384;J=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[J&16383](l,5,0)|0;if((K|0)<1){H=1;i=b;return H|0}if((gzL(A,0,5)|0)==0){break}else{H=1}i=b;return H|0}}while(0);A=c[3529516]|0;I=0;do{E=A+I|0;a[E]=~a[E];I=I+1|0;}while((I|0)<16777216);I=c[3529566]|0;E=0;do{K=E<<8;gGz(I+K|0,0,256);J=E<<9;D=0;do{N=1<<7-D;L=(c[683888+(D<<2)>>2]|0)+J|0;M=0;do{Q=L+(c[611840+(M<<2)>>2]|0)|0;P=(M<<4)+K|0;O=0;do{R=Q+(c[6669352+(O<<2)>>2]|0)|0;if(((d[A+((R|0)/8|0)|0]|0)&128>>>((R&7)>>>0)|0)!=0){R=I+(P+O)|0;a[R]=(d[R]|0|N)&255}O=O+1|0;}while((O|0)<16);M=M+1|0;}while((M|0)<16);D=D+1|0;}while((D|0)<8);E=E+1|0;}while((E|0)<65536);E=c[2433462]|0;if((c[3542200]|0)==0){H=1;i=b;return H|0}I=g+108|0;c[I>>2]=0;A=g+100|0;c[A>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,10)|0;do{if((c[I>>2]|0)!=0){D=c[A>>2]|0;c[j>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](j,10,0)|0;if((D|0)<1){H=1;i=b;return H|0}if((gzL(E,0,10)|0)==0){break}else{H=1}i=b;return H|0}}while(0);E=(c[3541206]|0)+1048576|0;if((c[3542200]|0)==0){H=1;i=b;return H|0}A=e+108|0;c[A>>2]=0;I=e+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,11)|0;do{if((c[A>>2]|0)!=0){D=c[I>>2]|0;c[f>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](f,11,0)|0;if((D|0)<1){H=1;i=b;return H|0}if((gzL(E,0,11)|0)==0){break}else{H=1}i=b;return H|0}}while(0);E=c[3541206]|0;I=c[2433462]|0;gGC(E|0,I|0,262144)|0;I=c[3529516]|0;E=0;while(1){if((E|0)>=1024){break}S=9638528+(E<<2)|0;if((c[S>>2]|0)==(I|0)){C=5936;break}else{E=E+1|0}}if((C|0)==5936){gGr(I);c[S>>2]=0}c[3529516]=0;fxU(0,110018592);if((c[2394]|0)==0){T=c[2112932]|0}else{c[2394]=0;E=c[3532596]|0;c[2112932]=E;A=c[3532592]|0;if((A|0)!=0){gGC(9104152,A|0,280)|0}c[2113054]=c[2113060];T=E}E=c[2388022]|0;A=T|0;D=0;while(1){K=E+D|0;c[A>>2]=K;c[A+131072>>2]=K;K=D+1024|0;if(K>>>0>2097151){break}else{A=A+4|0;D=K}}D=c[2443366]|0;c[T+36928>>2]=D;c[T+102464>>2]=D;c[T+168e3>>2]=D;A=D+1024|0;c[T+36932>>2]=A;c[T+102468>>2]=A;c[T+168004>>2]=A;A=D+2048|0;c[T+36936>>2]=A;c[T+102472>>2]=A;c[T+168008>>2]=A;A=D+3072|0;c[T+36940>>2]=A;c[T+102476>>2]=A;c[T+168012>>2]=A;A=D+4096|0;c[T+36944>>2]=A;c[T+102480>>2]=A;c[T+168016>>2]=A;A=D+5120|0;c[T+36948>>2]=A;c[T+102484>>2]=A;c[T+168020>>2]=A;A=D+6144|0;c[T+36952>>2]=A;c[T+102488>>2]=A;c[T+168024>>2]=A;A=D+7168|0;c[T+36956>>2]=A;c[T+102492>>2]=A;c[T+168028>>2]=A;A=D+8192|0;c[T+36960>>2]=A;c[T+102496>>2]=A;c[T+168032>>2]=A;A=D+9216|0;c[T+36964>>2]=A;c[T+102500>>2]=A;c[T+168036>>2]=A;A=D+10240|0;c[T+36968>>2]=A;c[T+102504>>2]=A;c[T+168040>>2]=A;A=D+11264|0;c[T+36972>>2]=A;c[T+102508>>2]=A;c[T+168044>>2]=A;A=D+12288|0;c[T+36976>>2]=A;c[T+102512>>2]=A;c[T+168048>>2]=A;A=D+13312|0;c[T+36980>>2]=A;c[T+102516>>2]=A;c[T+168052>>2]=A;A=D+14336|0;c[T+36984>>2]=A;c[T+102520>>2]=A;c[T+168056>>2]=A;A=D+15360|0;c[T+36988>>2]=A;c[T+102524>>2]=A;c[T+168060>>2]=A;A=c[2443360]|0;c[T+36992>>2]=A;c[T+102528>>2]=A;c[T+168064>>2]=A;D=A+1024|0;c[T+36996>>2]=D;c[T+102532>>2]=D;c[T+168068>>2]=D;D=A+2048|0;c[T+37e3>>2]=D;c[T+102536>>2]=D;c[T+168072>>2]=D;D=A+3072|0;c[T+37004>>2]=D;c[T+102540>>2]=D;c[T+168076>>2]=D;D=A+4096|0;c[T+37008>>2]=D;c[T+102544>>2]=D;c[T+168080>>2]=D;D=A+5120|0;c[T+37012>>2]=D;c[T+102548>>2]=D;c[T+168084>>2]=D;D=A+6144|0;c[T+37016>>2]=D;c[T+102552>>2]=D;c[T+168088>>2]=D;D=A+7168|0;c[T+37020>>2]=D;c[T+102556>>2]=D;c[T+168092>>2]=D;D=A+8192|0;c[T+37024>>2]=D;c[T+102560>>2]=D;c[T+168096>>2]=D;D=A+9216|0;c[T+37028>>2]=D;c[T+102564>>2]=D;c[T+168100>>2]=D;D=A+10240|0;c[T+37032>>2]=D;c[T+102568>>2]=D;c[T+168104>>2]=D;D=A+11264|0;c[T+37036>>2]=D;c[T+102572>>2]=D;c[T+168108>>2]=D;D=A+12288|0;c[T+37040>>2]=D;c[T+102576>>2]=D;c[T+168112>>2]=D;D=A+13312|0;c[T+37044>>2]=D;c[T+102580>>2]=D;c[T+168116>>2]=D;D=A+14336|0;c[T+37048>>2]=D;c[T+102584>>2]=D;c[T+168120>>2]=D;D=A+15360|0;c[T+37052>>2]=D;c[T+102588>>2]=D;c[T+168124>>2]=D;D=c[2443372]|0;c[T+37056>>2]=D;c[T+102592>>2]=D;c[T+168128>>2]=D;A=D+1024|0;c[T+37060>>2]=A;c[T+102596>>2]=A;c[T+168132>>2]=A;A=D+2048|0;c[T+37064>>2]=A;c[T+102600>>2]=A;c[T+168136>>2]=A;A=D+3072|0;c[T+37068>>2]=A;c[T+102604>>2]=A;c[T+168140>>2]=A;A=D+4096|0;c[T+37072>>2]=A;c[T+102608>>2]=A;c[T+168144>>2]=A;A=D+5120|0;c[T+37076>>2]=A;c[T+102612>>2]=A;c[T+168148>>2]=A;A=D+6144|0;c[T+37080>>2]=A;c[T+102616>>2]=A;c[T+168152>>2]=A;A=D+7168|0;c[T+37084>>2]=A;c[T+102620>>2]=A;c[T+168156>>2]=A;A=D+8192|0;c[T+37088>>2]=A;c[T+102624>>2]=A;c[T+168160>>2]=A;A=D+9216|0;c[T+37092>>2]=A;c[T+102628>>2]=A;c[T+168164>>2]=A;A=D+10240|0;c[T+37096>>2]=A;c[T+102632>>2]=A;c[T+168168>>2]=A;A=D+11264|0;c[T+37100>>2]=A;c[T+102636>>2]=A;c[T+168172>>2]=A;A=D+12288|0;c[T+37104>>2]=A;c[T+102640>>2]=A;c[T+168176>>2]=A;A=D+13312|0;c[T+37108>>2]=A;c[T+102644>>2]=A;c[T+168180>>2]=A;A=D+14336|0;c[T+37112>>2]=A;c[T+102648>>2]=A;c[T+168184>>2]=A;A=D+15360|0;c[T+37116>>2]=A;c[T+102652>>2]=A;c[T+168188>>2]=A;A=c[2388042]|0;D=A+65536|0;c[T+37376>>2]=D;c[T+102912>>2]=D;c[T+168448>>2]=D;D=A+66560|0;c[T+37380>>2]=D;c[T+102916>>2]=D;c[T+168452>>2]=D;D=A+67584|0;c[T+37384>>2]=D;c[T+102920>>2]=D;c[T+168456>>2]=D;D=A+68608|0;c[T+37388>>2]=D;c[T+102924>>2]=D;c[T+168460>>2]=D;D=A+69632|0;c[T+37392>>2]=D;c[T+102928>>2]=D;c[T+168464>>2]=D;D=A+70656|0;c[T+37396>>2]=D;c[T+102932>>2]=D;c[T+168468>>2]=D;D=A+71680|0;c[T+37400>>2]=D;c[T+102936>>2]=D;c[T+168472>>2]=D;D=A+72704|0;c[T+37404>>2]=D;c[T+102940>>2]=D;c[T+168476>>2]=D;D=A+73728|0;c[T+37408>>2]=D;c[T+102944>>2]=D;c[T+168480>>2]=D;D=A+74752|0;c[T+37412>>2]=D;c[T+102948>>2]=D;c[T+168484>>2]=D;D=A+75776|0;c[T+37416>>2]=D;c[T+102952>>2]=D;c[T+168488>>2]=D;D=A+76800|0;c[T+37420>>2]=D;c[T+102956>>2]=D;c[T+168492>>2]=D;D=A+77824|0;c[T+37424>>2]=D;c[T+102960>>2]=D;c[T+168496>>2]=D;D=A+78848|0;c[T+37428>>2]=D;c[T+102964>>2]=D;c[T+168500>>2]=D;D=A+79872|0;c[T+37432>>2]=D;c[T+102968>>2]=D;c[T+168504>>2]=D;D=A+80896|0;c[T+37436>>2]=D;c[T+102972>>2]=D;c[T+168508>>2]=D;D=c[2443406]|0;c[T+37632>>2]=D;c[T+103168>>2]=D;c[T+168704>>2]=D;E=D+1024|0;c[T+37636>>2]=E;c[T+103172>>2]=E;c[T+168708>>2]=E;E=c[2439606]|0;D=T+37888|0;I=9699328;while(1){K=E+(I-9699328)|0;c[D>>2]=K;c[D+65536>>2]=K;c[D+131072>>2]=K;K=I+1024|0;if(K>>>0>9732095){break}else{D=D+4|0;I=K}}I=T+65024|0;D=16646144;while(1){E=A+(D-16646144)|0;c[I>>2]=E;c[I+65536>>2]=E;c[I+131072>>2]=E;E=D+1024|0;if(E>>>0>16777215){break}else{I=I+4|0;D=E}}c[T+196688>>2]=3234;c[T+196728>>2]=988;c[T+196608>>2]=1366;c[T+196648>>2]=2672;c[T+196768>>2]=2512;c[T+196808>>2]=2396;D=c[3532592]|0;if((D|0)!=0){gGC(D|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;Tq(682280);D=a[9680]|0;I=D?32e3:0;if(D){if(a[9624]|0){D=I*3|0;A=55930;while(1){if((A|0)>(D|0)){A=A>>1}else{U=1222;V=A;break}}}else{U=2462;V=I}c[2429380]=V;c[3542124]=U;mw(3579545,V);A=gGq(262144)|0;c[2406684]=A;gGz(A|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(3579545,11025)}h[745421]=.7;c[2436794]=1;h[745420]=.7;c[2436792]=2;Ux(0,8e3,1);Ux(1,3e4,1);c[2407030]=51;c[2407068]=2;A=c[642608+(c[2436]<<2)>>2]|0;D=c[A+128>>2]|0;if((c[A+52>>2]&4|0)==0){c[2113068]=D;E=c[A+132>>2]|0;c[2113070]=E;c[2443814]=D;c[2440436]=E;W=D;X=E}else{c[2113070]=D;E=c[A+132>>2]|0;c[2113068]=E;c[2440436]=D;c[2443814]=E;W=E;X=D}D=ag(W<<1,X)|0;E=gGq(D)|0;c[2112926]=E;if((E|0)!=0){gGz(E|0,0,D|0)}c[2113302]=2;a[801640]=0;D=c[642608+(c[2436]<<2)>>2]|0;E=c[D+128>>2]|0;if((c[D+52>>2]&4|0)==0){c[2440576]=E;A=c[D+132>>2]|0;c[2440574]=A;Y=E;Z=A}else{c[2440574]=E;A=c[D+132>>2]|0;c[2440576]=A;Y=A;Z=E}E=(((Y|0)/2|0)<<8)-1792|0;A=(((Z|0)/2|0)<<8)-2048|0;c[3542196]=E;c[3542192]=A;c[3542197]=E;c[3542193]=A;c[3542198]=E;c[3542194]=A;c[3542199]=E;c[3542195]=A;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];A=c[3532592]|0;if((A|0)!=0){gGC(9104152,A|0,280)|0}c[2113054]=c[2113060]}RI();A=c[2394]|0;E=c[14130368+(A<<2)>>2]|0;if((E|0)!=0){gGC(E|0,9104152,280)|0}c[8452240+(A<<2)>>2]=c[2113054];c[2394]=-1;c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];mx(0);c[2113156]=0;a[9628264]=0;c[2407033]=0;A=c[3541206]|0;c[3541190]=A;c[3541198]=A;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=A+256;c[3541199]=A+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=A+512;c[3541200]=A+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=A+768;c[3541201]=A+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2113157]=0;a[9628420]=0;c[2407072]=0;E=A+1048576|0;c[3541194]=E;c[3541202]=E;gGz(c[2430122]|0,0,16384);c[2407080]=4;c[3541195]=A+1048832;c[3541203]=A+1114112;gGz(c[2430123]|0,0,16384);c[2407088]=4;c[3541196]=A+1049088;c[3541204]=A+1179648;gGz(c[2430124]|0,0,16384);c[2407096]=4;c[3541197]=A+1049344;c[3541205]=A+1245184;gGz(c[2430125]|0,0,16384);c[2407104]=4;a[14120976]=0;H=0;i=b;return H|0}}while(0);c[2426688]=0;H=1;i=b;return H|0}function eu6(){var d=0,e=0,f=0,g=0,h=0,j=0,k=0;d=i;i=i+128|0;e=d|0;if((c[2392]|0)>=0){f=0;do{g=14130368+(f<<2)|0;h=c[g>>2]|0;if((h|0)!=0){gGr(h);c[g>>2]=0}g=14130384+(f<<2)|0;h=c[g>>2]|0;if((h|0)!=0){gGr(h);c[g>>2]=0}f=f+1|0;}while((f|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;Uw(0);c[2113070]=0;c[2113068]=0;f=c[2112926]|0;if((f|0)!=0){gGr(f);c[2112926]=0}if((c[2113302]|0)!=0){c[2113302]=0;a[801640]=0;c[2440576]=0;c[2440574]=0;gGz(14168784,0,16);gGz(14168768,0,16)}b[7054672]=0;b[7054660]=0;b[7054668]=0;b[7054656]=0;b[7054664]=0;b[7054652]=0;a[14120976]=0;c[3527362]=0;c[2439646]=0;c[2427046]=0;f=c[2426688]|0;g=0;while(1){if((g|0)>=1024){break}j=9638528+(g<<2)|0;if((c[j>>2]|0)==(f|0)){k=6019;break}else{g=g+1|0}}if((k|0)==6019){gGr(f);c[j>>2]=0}c[2426688]=0;j=c[3531464]|0;c[j+44344>>2]=0;c[j+44348>>2]=0;if((j|0)!=0){gGr(j);c[3531464]=0}j=c[2406684]|0;if((j|0)!=0){gGr(j);c[2406684]=0}Uw(1);j=e|0;e=c[c[642608+(c[2436]<<2)>>2]>>2]|0;be(j|0,128,179600,(f=i,i=i+24|0,c[f>>2]=9374064,c[f+8>>2]=47,c[f+16>>2]=e,f)|0)|0;i=f;a[1040128]=0;f=c[2420380]|0;e=c[f>>2]|0;k=c[f+4>>2]|0;f=fw(j|0,389440)|0;if((f|0)==0){i=d;return 0}cj(14100392,k>>3<<e&1023|0,1,f|0)|0;aY(f|0)|0;i=d;return 0}function eu7(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((a[9623896]|0)!=0){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];mx(0);c[2113156]=0;a[9628264]=0;c[2407033]=0;d=c[3541206]|0;c[3541190]=d;c[3541198]=d;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=d+256;c[3541199]=d+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=d+512;c[3541200]=d+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=d+768;c[3541201]=d+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2113157]=0;a[9628420]=0;c[2407072]=0;e=d+1048576|0;c[3541194]=e;c[3541202]=e;gGz(c[2430122]|0,0,16384);c[2407080]=4;c[3541195]=d+1048832;c[3541203]=d+1114112;gGz(c[2430123]|0,0,16384);c[2407088]=4;c[3541196]=d+1049088;c[3541204]=d+1179648;gGz(c[2430124]|0,0,16384);c[2407096]=4;c[3541197]=d+1049344;c[3541205]=d+1245184;gGz(c[2430125]|0,0,16384);c[2407104]=4;a[14120976]=0}a[9625584]=0;a[9625585]=127;d=0;e=0;f=127;do{e=((a[9759152+d|0]&1)<<d|e&255)&255;f=(f&255)-((a[9758960+d|0]&1)<<d)&255;d=d+1|0;}while((d|0)<8);a[9625584]=e;a[9625585]=f;f=c[2438826]|0;e=(c[3542196]|0)+(c[2438830]<<16>>16)|0;c[3542196]=e;d=(c[3542192]|0)+(f<<16>>16)|0;c[3542192]=d;if((e|0)<-2048){c[3542196]=-2048;g=-2048}else{g=e}e=(c[2440576]<<8)-2048|0;if((g|0)>(e|0)){c[3542196]=e}if((d|0)<-2048){c[3542192]=-2048;h=-2048}else{h=d}d=(c[2440574]<<8)-2048|0;if((h|0)>(d|0)){c[3542192]=d}h=c[2438822]|0;g=(c[3542197]|0)+(c[2438824]<<16>>16)|0;c[3542197]=g;f=(c[3542193]|0)+(h<<16>>16)|0;c[3542193]=f;if((g|0)<-2048){c[3542197]=-2048;i=-2048}else{i=g}if((i|0)>(e|0)){c[3542197]=e}if((f|0)<-2048){c[3542193]=-2048;j=-2048}else{j=f}if((j|0)>(d|0)){c[3542193]=d}a[6518200]=1;c[2444068]=0;d=c[2392]|0;if((d|0)>=0){gGz(8452240,0,((d|0)>0?(d<<2)+4|0:4)|0)}c[2113054]=0;d=0;j=0;L8350:while(1){f=j;while(1){if((f|0)>=10){break L8350}if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060]}k=f+1|0;e=(ag(a[6518200]|0?266666:0,k)|0)/10|0;i=e-(c[2444068]|0)|0;c[2438182]=i;c[2113056]=i;e=RG(i)|0;c[2113054]=(c[2113054]|0)+e;c[2276108]=-1;c[2113056]=-1;c[2444068]=(c[2444068]|0)+e;do{if((f|0)==9){c[8452200+(c[2394]<<2)>>2]=8194;c[2276080]=512;if((c[2276079]|0)>>>0>=512){break}RH(2)}}while(0);e=c[2394]|0;i=c[14130368+(e<<2)>>2]|0;if((i|0)!=0){gGC(i|0,9104152,280)|0}c[8452240+(e<<2)>>2]=c[2113054];c[2394]=-1;l=c[2112964]|0;if((l|0)==0){f=k}else{break}}f=a[9688]|0?53:0;e=l+(d<<1<<1)|0;gg[c[3542124]&4095](e,f);Uu(0,e,f);Uu(1,e,f);d=f+d|0;j=k}k=c[2112964]|0;do{if((k|0)!=0){j=a[9688]|0?534:0;l=j-d|0;f=k+(d<<1<<1)|0;if((j|0)==(d|0)){break}gg[c[3542124]&4095](f,l);Uu(0,f,l);Uu(1,f,l)}}while(0);if((c[2112968]|0)==0){return 0}d=c[2112926]|0;gGz(d|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);k=c[2439606]|0;l=c[3529958]|0;f=0;do{j=c[k+(f<<2)>>2]|0;c[l+(f<<2)>>2]=j>>>8&63488|j&2016|j>>>24&31;f=f+1|0;}while((f|0)<8192);f=ag(c[2113068]|0,c[2113070]|0)|0;if((f|0)>0){k=0;do{b[d+(k<<1)>>1]=7936;k=k+1|0;}while((k|0)<(f|0))}eva(3);evb(0);eva(2);evb(1);eva(1);evb(2);eva(0);R8(l);l=c[2113302]|0;if((l|0)>0){m=0}else{return 0}do{R7(m,c[14168784+(m<<2)>>2]>>8,c[14168768+(m<<2)>>2]>>8);m=m+1|0;}while((m|0)<(l|0));return 0}function eu8(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0;e=i;i=i+32|0;f=e|0;g=e+16|0;eu9(a,b);Ts(a,b);if((a&64|0)==0){h=a&2}else{gGz(g|0,0,12);c[g>>2]=8453216;c[g+4>>2]=4;c[g+12>>2]=107480;b=c[2076592]|0;gj[b&4095](g)|0;gGz(f|0,0,12);c[f>>2]=14168504;c[f+4>>2]=256;c[f+12>>2]=476464;g=c[2076592]|0;gj[g&4095](f)|0;f=a&2;if((f|0)!=0){a=0;do{mv(0,a,d[14168504+a|0]|0);a=a+1|0;}while((a|0)<256)}Ut(1);h=f}if((h|0)==0){i=e;return 0}h=(c[3541206]|0)+131072|0;f=(c[2433462]|0)+(((d[14120976]|0)<<17)+131072)|0;gGC(h|0,f|0,131072)|0;i=e;return 0}function eu9(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=i;i=i+144|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;l=e+80|0;m=e+96|0;n=e+112|0;o=e+128|0;if((d|0)!=0){c[d>>2]=169617}if((b&32|0)!=0){gGz(o|0,0,12);d=c[2405624]|0;c[o>>2]=d;c[o+4>>2]=(c[2411588]|0)-d;c[o+12>>2]=162152;d=c[2076592]|0;gj[d&4095](o)|0}if((b&64|0)==0){i=e;return}b=h|0;gGz(g|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){o=h+9|0;h=f;d=f|0;p=f+4|0;q=f+12|0;r=g|0;s=g+4|0;t=g+12|0;u=0;do{gGC(b|0,614896,11)|0;a[o]=u+48&255;v=8452256+(u<<2)|0;gGz(h|0,0,12);c[d>>2]=v;c[p>>2]=4;c[q>>2]=164976;gj[c[2076592]&4095](f)|0;if((c[v>>2]|0)!=0){c[r>>2]=c[14130368+(u<<2)>>2];c[s>>2]=c[8452184+(u<<2)>>2];c[t>>2]=b;v=c[2076592]|0;gj[v&4095](g)|0}u=u+1|0;}while((u|0)<=(c[2392]|0))}Ut(0);gGz(n|0,0,12);c[n>>2]=9776272;c[n+4>>2]=4;c[n+12>>2]=212472;gj[c[2076592]&4095](n)|0;gGz(m|0,0,12);c[m>>2]=9752728;c[m+4>>2]=4;c[m+12>>2]=436576;gj[c[2076592]&4095](m)|0;gGz(l|0,0,12);c[l>>2]=9657920;c[l+4>>2]=2;c[l+12>>2]=483352;gj[c[2076592]&4095](l)|0;gGz(k|0,0,12);c[k>>2]=9625584;c[k+4>>2]=3;c[k+12>>2]=215728;gj[c[2076592]&4095](k)|0;gGz(j|0,0,12);c[j>>2]=14120976;c[j+4>>2]=1;c[j+12>>2]=491248;gj[c[2076592]&4095](j)|0;i=e;return}function eva(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=c[2443406]|0;d=c[2112926]|0;e=c[3529566]|0;f=0;do{g=c[b+(f<<2)>>2]|0;h=c[b+((f|1)<<2)>>2]|0;i=h&65535;j=h>>>16;k=j&64;do{if((h>>>28&3|0)==(a|0)){l=(g>>>16)-14|0;m=(g+449&511)-(g+961&512)|0;n=(l&511)-(l&512)|0;l=(j&32|0)!=0;o=h>>>24<<4&240;if(l){p=-16;q=m-16|0;r=o+m|0}else{s=m+16+o|0;if((m|0)==(s|0)){break}else{p=16;q=s;r=m}}m=(k|0)!=0;s=j&31;o=(n-17|0)>>>0>190;t=i;u=r;while(1){v=t+1|0;do{if((u-17|0)>>>0>350|o){if(l){if(m){SN(d,t,u,n,s,8,0,0,e);break}else{SJ(d,t,u,n,s,8,0,0,e);break}}else{if(m){SL(d,t,u,n,s,8,0,0,e);break}else{SH(d,t,u,n,s,8,0,0,e);break}}}else{if(l){if(m){SM(d,t,u,n,s,8,0,0,e);break}else{SI(d,t,u,n,s,8,0,0,e);break}}else{if(m){SK(d,t,u,n,s,8,0,0,e);break}else{SG(d,t,u,n,s,8,0,0,e);break}}}}while(0);w=u+p|0;if((w|0)==(q|0)){break}else{t=v;u=w}}}}while(0);f=f+2|0;}while((f|0)<512);return}function evb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;b=c[2443464]|0;d=c[b>>2]|0;e=(a|0)==1;do{if(e){f=c[b+20>>2]&65535;g=(c[b+8>>2]|0)>>>16&65535;h=9773464;i=0}else{if((a|0)!=2){f=d>>>16&65535;g=d&65535;h=9773488;i=0;break}f=c[b+4>>2]&65535;g=c[b+8>>2]&65535;h=9773440;i=1}}while(0);b=c[h>>2]|0;h=g&1023;g=f&1023;f=(a|0)==0;a=c[2112926]|0;d=c[2405806]|0;j=0;k=0;while(1){l=(k<<4)-g|0;m=(l|0)<-16?l+1024|0:l;l=m-15|0;n=(m-32|0)>>>0>190;m=j;o=0;while(1){p=c[b+(m<<2)>>2]|0;q=p&65535;r=p>>>16&31;s=(o<<4)-h|0;t=(s|0)<-16?s+1024|0:s;s=f?t-50|0:t;t=e?s-48|0:s;s=i?t-46|0:t;do{if((q|0)!=0){t=(p&2097152|0)==0;u=(p&4194304|0)!=0;if((s-17|0)>>>0>350|n){if(t){if(u){SL(a,q,s,l,r,8,0,0,d);break}else{SH(a,q,s,l,r,8,0,0,d);break}}else{if(u){SN(a,q,s,l,r,8,0,0,d);break}else{SJ(a,q,s,l,r,8,0,0,d);break}}}else{if(t){if(u){SK(a,q,s,l,r,8,0,0,d);break}else{SG(a,q,s,l,r,8,0,0,d);break}}else{if(u){SM(a,q,s,l,r,8,0,0,d);break}else{SI(a,q,s,l,r,8,0,0,d);break}}}}}while(0);r=o+1|0;if((r|0)<64){m=m+1|0;o=r}else{break}}o=k+1|0;if((o|0)<64){j=j+64|0;k=o}else{break}}return}function evc(a){a=a|0;var b=0,d=0;b=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,16e6,0)|0;return a|0}function evd(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;a[9625584]=0;a[9625585]=-1;b=0;d=0;e=-1;do{d=((a[9759152+b|0]&1)<<b|d&255)&255;e=(e&255)-((a[9758960+b|0]&1)<<b)&255;b=b+1|0;}while((b|0)<8);a[9625584]=d;a[9625585]=e;e=c[2438826]|0;d=(c[3542196]|0)+(c[2438830]<<16>>16)|0;c[3542196]=d;b=(c[3542192]|0)+(e<<16>>16)|0;c[3542192]=b;if((d|0)<-2048){c[3542196]=-2048;f=-2048}else{f=d}d=(c[2440576]<<8)-2048|0;if((f|0)>(d|0)){c[3542196]=d}if((b|0)<-2048){c[3542192]=-2048;g=-2048}else{g=b}b=(c[2440574]<<8)-2048|0;if((g|0)>(b|0)){c[3542192]=b}g=c[2438822]|0;f=(c[3542197]|0)+(c[2438824]<<16>>16)|0;c[3542197]=f;e=(c[3542193]|0)+(g<<16>>16)|0;c[3542193]=e;if((f|0)<-2048){c[3542197]=-2048;h=-2048}else{h=f}if((h|0)>(d|0)){c[3542197]=d}if((e|0)<-2048){c[3542193]=-2048;i=-2048}else{i=e}if((i|0)<=(b|0)){return}c[3542193]=b;return}function eve(a){a=a|0;var b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=(a|0)==1;d=(a|0)==2;f=c[(d?9773440:b?9773464:9773488)>>2]|0;g=e[(d?14109328:b?14109336:14109344)>>1]|0;h=e[(d?14109304:b?14109312:14109320)>>1]|0;i=(a|0)==0;a=b?-98:-50;j=c[2112926]|0;k=c[2405806]|0;l=0;m=0;while(1){n=(m<<4)-h|0;o=(n|0)<-16?n+1024|0:n;n=o-15|0;p=(o-32|0)>>>0>190;if(i){o=l;q=0;while(1){r=o<<1;s=e[f+((r|1)<<1)>>1]|0;t=e[f+(r<<1)>>1]|0;r=s&31;u=(q<<4)-g|0;v=((u|0)<-16?u+1024|0:u)+a|0;u=d?v-46|0:v;v=(s&32|0)==0;w=(s&64|0)!=0;do{if((u-17|0)>>>0>350|p){if(v){if(w){SL(j,t,u,n,r,8,0,0,k);break}else{SH(j,t,u,n,r,8,0,0,k);break}}else{if(w){SN(j,t,u,n,r,8,0,0,k);break}else{SJ(j,t,u,n,r,8,0,0,k);break}}}else{if(v){if(w){SK(j,t,u,n,r,8,0,0,k);break}else{SG(j,t,u,n,r,8,0,0,k);break}}else{if(w){SM(j,t,u,n,r,8,0,0,k);break}else{SI(j,t,u,n,r,8,0,0,k);break}}}}while(0);r=q+1|0;if((r|0)<64){o=o+1|0;q=r}else{break}}}else{q=l;o=0;while(1){r=q<<1;u=e[f+((r|1)<<1)>>1]|0;t=e[f+(r<<1)>>1]|0;r=u&31;w=(o<<4)-g|0;v=(w|0)<-16?w+1024|0:w;w=b?v-48|0:v;v=d?w-46|0:w;w=(u&32|0)==0;s=(u&64|0)!=0;do{if((v-17|0)>>>0>350|p){if(w){if(s){SL(j,t,v,n,r,8,0,0,k);break}else{SH(j,t,v,n,r,8,0,0,k);break}}else{if(s){SN(j,t,v,n,r,8,0,0,k);break}else{SJ(j,t,v,n,r,8,0,0,k);break}}}else{if(w){if(s){SK(j,t,v,n,r,8,0,0,k);break}else{SG(j,t,v,n,r,8,0,0,k);break}}else{if(s){SM(j,t,v,n,r,8,0,0,k);break}else{SI(j,t,v,n,r,8,0,0,k);break}}}}while(0);r=o+1|0;if((r|0)<64){q=q+1|0;o=r}else{break}}}o=m+1|0;if((o|0)<64){l=l+64|0;m=o}else{break}}return}function evf(a){a=a|0;var b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=c[2443406]|0;d=c[2112926]|0;f=c[3529566]|0;g=0;do{h=e[b+((g|2)<<1)>>1]|0;i=e[b+((g|3)<<1)>>1]|0;j=i&64;if((i>>>12&3|0)==(a|0)){k=(e[b+(g<<1)>>1]|0)-63|0;l=(e[b+((g|1)<<1)>>1]|0)-14|0;m=(k&511)-(k&512)|0;k=(l&511)-(l&512)|0;l=(i&32|0)!=0;n=i>>>8<<4&240;if(l){o=m+n|0;p=m-16|0;q=-16}else{o=m;p=n+16+m|0;q=16}m=(j|0)!=0;j=i&31;i=(k-17|0)>>>0>190;n=h;h=o;while(1){r=n+1|0;do{if((h-17|0)>>>0>350|i){if(l){if(m){SN(d,n,h,k,j,8,0,0,f);break}else{SJ(d,n,h,k,j,8,0,0,f);break}}else{if(m){SL(d,n,h,k,j,8,0,0,f);break}else{SH(d,n,h,k,j,8,0,0,f);break}}}else{if(l){if(m){SM(d,n,h,k,j,8,0,0,f);break}else{SI(d,n,h,k,j,8,0,0,f);break}}else{if(m){SK(d,n,h,k,j,8,0,0,f);break}else{SG(d,n,h,k,j,8,0,0,f);break}}}}while(0);s=h+q|0;if((s|0)==(p|0)){break}else{n=r;h=s}}}g=g+4|0;}while((g|0)<1024);return}function evg(){var b=0,c=0,d=0,e=0,f=0,g=0;a[9625586]=0;a[9625585]=0;a[9625584]=0;b=0;c=0;d=0;e=0;do{c=((a[9759152+b|0]&1)<<b|c&255)&255;d=((a[9758960+b|0]&1)<<b|d&255)&255;e=((a[9758784+b|0]&1)<<b|e&255)&255;b=b+1|0;}while((b|0)<8);a[9625584]=c;a[9625585]=d;a[9625586]=e;if((c&3)==3){e=c&-4;a[9625584]=e;f=e}else{f=c}if((f&12)==12){a[9625584]=f&-13}if((d&3)==3){f=d&-4;a[9625585]=f;g=f}else{g=d}if((g&12)!=12){return}a[9625585]=g&-13;return}function evh(d){d=d|0;var e=0,f=0,g=0;if((d|0)==14155910){e=c[2388480]|0;f=a[e]|b[4775173]&255;a[e]=0;g=f}else if((d|0)==14155905){g=a[9634920]|0}else if((d|0)==14155904){g=a[9634921]|0}else{g=0}return g|0}function evi(a){a=a|0;return((a|0)==14155908?b[4775172]|0:0)|0}function evj(b,d){b=b|0;d=d|0;if((b|0)!=14155915){return}a[c[3528244]|0]=d;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12;return}function evk(d,e){d=d|0;e=e|0;switch(d|0){case 14155862:{a[c[3528684]|0]=e&1^1;return};case 14155796:case 14155798:case 14155800:case 14155802:case 14155804:case 14155806:{b[(c[2386720]|0)+((d-14155796|0)>>>1<<1)>>1]=e;return};default:{return}}}function evl(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;switch(b&255|0){case 1:{b=c[2113304]|0;a[14168504+b|0]=d;mv(0,b,d&255);return};case 6:{a[c[2388480]|0]=-128;return};case 8:{b=d&7;a[c[3529362]|0]=b&255;e=b<<15;b=c[2385896]|0;f=c[9757320+(c[1836236]<<2)>>2]|0;g=128;h=128;while(1){c[f+76+(h<<2)>>2]=b+((h<<8)+e);i=g+1&65535;if((i&65535)>255){j=128;k=128;break}else{g=i;h=i&65535}}while(1){h=b+((k<<8)+e)|0;c[f+76+(k+512<<2)>>2]=h;c[f+76+(k+768<<2)>>2]=h;h=j+1&65535;if((h&65535)>255){break}else{j=h;k=h&65535}}return};case 0:{c[2113304]=d&255;return};case 2:{Uv(0,(d&255)>>>7|d<<7|(d&255)>>>1<<6&64|(d&255)>>>2<<5&32|(d&255)>>>3<<4&16|(d&255)>>>4<<3&8|(d&255)>>>5<<2&4|(d&255)>>>6<<1&2);return};default:{return}}}function evm(b){b=b|0;var d=0,e=0;d=b&255;if((d|0)==4){e=a[c[3528244]|0]|0;return e|0}else if((d|0)==2){b=c[2113156]|0;e=(b>>>7&1|b<<7&128|b>>>1<<6&64|b>>>2<<5&32|b>>>3<<4&16|b>>>4<<3&8|b>>>5<<2&4|b>>>6<<1&2)&255;return e|0}else if((d|0)==1){e=c[(c[3531464]|0)+4240>>2]&255;return e|0}else{e=0;return e|0}return 0}function evn(b){b=b|0;a[9706117]=(b|0)!=0|0;return}function evo(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3158484+(b*112|0)>>2];c[a+104>>2]=c[3158488+(b*112|0)>>2];c[a+108>>2]=c[3158492+(b*112|0)>>2];d=0;return d|0}function evp(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=3158384+(b*112|0);e=0;return e|0}function evq(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1315192+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function evr(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>33){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4277120+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function evs(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;e=i;i=i+840|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;c[2414922]=0;c[2388118]=0;c[2385896]=524288;c[3530802]=786432;c[3530566]=1835008;c[3530408]=2097152;c[3530320]=4194304;c[3541206]=5242880;c[2386620]=5242880;c[3529956]=5767168;c[2414624]=5775360;c[2388246]=5775360;c[2387154]=5840896;c[2387306]=5844992;c[2387996]=5849088;c[2386326]=5853184;c[2386424]=5861376;c[2386050]=5869568;c[2388480]=5871616;c[3528244]=5871617;c[3528684]=5871618;c[3529362]=5871619;c[2386720]=5871620;c[2411586]=5871636;v=0;while(1){if((v|0)>=1024){break}w=9638528+(v<<2)|0;if((c[w>>2]|0)==0){x=6327;break}else{v=v+1|0}}do{if((x|0)==6327){v=gGq(5871636)|0;c[w>>2]=v;if((v|0)==0){break}c[2414922]=v;gGz(v|0,0,5871636);c[2388118]=v;c[2385896]=v+524288;c[3530802]=v+786432;c[3530566]=v+1835008;c[3530408]=v+2097152;c[3530320]=v+4194304;y=v+5242880|0;c[3541206]=y;c[2386620]=y;c[3529956]=v+5767168;y=v+5775360|0;c[2414624]=y;c[2388246]=y;c[2387154]=v+5840896;c[2387306]=v+5844992;c[2387996]=v+5849088;c[2386326]=v+5853184;c[2386424]=v+5861376;c[2386050]=v+5869568;c[2388480]=v+5871616;c[3528244]=v+5871617;c[3528684]=v+5871618;c[3529362]=v+5871619;c[2386720]=v+5871620;y=v+5871636|0;c[2411586]=y;c[2414126]=y;if((c[3542200]|0)==0){z=1;i=e;return z|0}y=t+108|0;c[y>>2]=0;A=t+100|0;c[A>>2]=0;B=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[B&16383](t,0)|0;do{if((c[y>>2]|0)!=0){B=c[A>>2]|0;c[u>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](u,0,0)|0;if((B|0)<1){z=1;i=e;return z|0}if((gzL(v,0,0)|0)==0){break}else{z=1}i=e;return z|0}}while(0);v=c[2385896]|0;if((c[3542200]|0)==0){z=1;i=e;return z|0}A=r+108|0;c[A>>2]=0;y=r+100|0;c[y>>2]=0;B=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[B&16383](r,1)|0;do{if((c[A>>2]|0)!=0){B=c[y>>2]|0;c[s>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](s,1,0)|0;if((B|0)<1){z=1;i=e;return z|0}if((gzL(v,0,1)|0)==0){break}else{z=1}i=e;return z|0}}while(0);v=c[3530802]|0;if((c[3542200]|0)==0){z=1;i=e;return z|0}y=p+108|0;c[y>>2]=0;A=p+100|0;c[A>>2]=0;B=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[B&16383](p,2)|0;do{if((c[y>>2]|0)!=0){B=c[A>>2]|0;c[q>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](q,2,0)|0;if((B|0)<1){z=1;i=e;return z|0}if((gzL(v,0,2)|0)==0){break}else{z=1}i=e;return z|0}}while(0);if((evy((c[3530802]|0)+524288|0,3)|0)!=0){z=1;i=e;return z|0}v=c[3530566]|0;if((c[3542200]|0)==0){z=1;i=e;return z|0}A=n+108|0;c[A>>2]=0;y=n+100|0;c[y>>2]=0;B=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[B&16383](n,4)|0;do{if((c[A>>2]|0)!=0){B=c[y>>2]|0;c[o>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](o,4,0)|0;if((B|0)<1){z=1;i=e;return z|0}if((gzL(v,0,4)|0)==0){break}else{z=1}i=e;return z|0}}while(0);v=c[3530408]|0;if((c[3542200]|0)==0){z=1;i=e;return z|0}y=l+108|0;c[y>>2]=0;A=l+100|0;c[A>>2]=0;B=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[B&16383](l,5)|0;do{if((c[y>>2]|0)!=0){B=c[A>>2]|0;c[m>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](m,5,0)|0;if((B|0)<1){z=1;i=e;return z|0}if((gzL(v,0,5)|0)==0){break}else{z=1}i=e;return z|0}}while(0);v=c[3530320]|0;if((c[3542200]|0)==0){z=1;i=e;return z|0}A=j+108|0;c[A>>2]=0;y=j+100|0;c[y>>2]=0;B=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[B&16383](j,6)|0;do{if((c[A>>2]|0)!=0){B=c[y>>2]|0;c[k>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](k,6,0)|0;if((B|0)<1){z=1;i=e;return z|0}if((gzL(v,0,6)|0)==0){break}else{z=1}i=e;return z|0}}while(0);if((evy((c[3530320]|0)+524288|0,7)|0)!=0){z=1;i=e;return z|0}v=c[2386620]|0;if((c[3542200]|0)==0){z=1;i=e;return z|0}y=f+108|0;c[y>>2]=0;A=f+100|0;c[A>>2]=0;B=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[B&16383](f,8)|0;do{if((c[y>>2]|0)==0){D=0}else{B=c[A>>2]|0;c[g>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](g,8,0)|0;if((B|0)<1){z=1;i=e;return z|0}if((gzL(v,0,8)|0)==0){D=0;break}else{z=1}i=e;return z|0}}while(0);while(1){if((D|0)>=1024){break}E=9638528+(D<<2)|0;if((c[E>>2]|0)==0){x=6361;break}else{D=D+1|0}}L8791:do{if((x|0)==6361){v=gGq(1048576)|0;c[E>>2]=v;if((v|0)==0){break}gGz(v|0,0,1048576);A=c[3530802]|0;gGC(v|0,A|0,1048576)|0;y=0;do{B=y<<8;gGz(A+B|0,0,256);C=y<<10;F=0;do{G=1<<4-F;H=(c[611464+(F<<2)>>2]|0)+C|0;I=0;do{J=H+(c[611904+(I<<2)>>2]|0)|0;K=(I<<4)+B|0;L=0;do{M=J+(c[610544+(L<<2)>>2]|0)|0;if(((d[v+((M|0)/8|0)|0]|0)&128>>>((M&7)>>>0)|0)!=0){M=A+(K+L)|0;a[M]=(d[M]|0|G)&255}L=L+1|0;}while((L|0)<16);I=I+1|0;}while((I|0)<16);F=F+1|0;}while((F|0)<5);y=y+1|0;}while((y|0)<4096);y=c[3530566]|0;gGC(v|0,y|0,131072)|0;A=0;do{F=A<<6;gGz(y+F|0,0,64);B=A<<8;C=0;do{I=1<<3-C;C=C+1|0;G=(c[611464+(C<<2)>>2]|0)+B|0;H=0;do{L=G+(c[1183816+(H<<2)>>2]|0)|0;K=(H<<3)+F|0;J=0;do{M=L+(c[610544+(J<<2)>>2]|0)|0;if(((d[v+((M|0)/8|0)|0]|0)&128>>>((M&7)>>>0)|0)!=0){M=y+(K+J)|0;a[M]=(d[M]|0|I)&255}J=J+1|0;}while((J|0)<8);H=H+1|0;}while((H|0)<8);}while((C|0)<4);A=A+1|0;}while((A|0)<4096);A=c[3530408]|0;gGC(v|0,A|0,1048576)|0;y=0;do{C=y<<8;gGz(A+C|0,0,256);F=y<<10;B=0;do{H=1<<3-B;I=(c[611152+(B<<2)>>2]|0)+F|0;G=0;do{J=I+(c[611904+(G<<2)>>2]|0)|0;K=(G<<4)+C|0;L=0;do{M=J+(c[609360+(L<<2)>>2]|0)|0;if(((d[v+((M|0)/8|0)|0]|0)&128>>>((M&7)>>>0)|0)!=0){M=A+(K+L)|0;a[M]=(d[M]|0|H)&255}L=L+1|0;}while((L|0)<16);G=G+1|0;}while((G|0)<16);B=B+1|0;}while((B|0)<4);y=y+1|0;}while((y|0)<8192);y=c[3530320]|0;gGC(v|0,y|0,1048576)|0;A=0;while(1){B=A<<8;gGz(y+B|0,0,256);C=A<<10;F=0;do{G=1<<4-F;H=(c[611464+(F<<2)>>2]|0)+C|0;I=0;do{L=H+(c[611904+(I<<2)>>2]|0)|0;K=(I<<4)+B|0;J=0;do{M=L+(c[610544+(J<<2)>>2]|0)|0;if(((d[v+((M|0)/8|0)|0]|0)&128>>>((M&7)>>>0)|0)!=0){M=y+(K+J)|0;a[M]=(d[M]|0|G)&255}J=J+1|0;}while((J|0)<16);I=I+1|0;}while((I|0)<16);F=F+1|0;}while((F|0)<5);F=A+1|0;if((F|0)<4096){A=F}else{N=0;break}}while(1){if((N|0)>=1024){break L8791}O=9638528+(N<<2)|0;if((c[O>>2]|0)==(v|0)){break}else{N=N+1|0}}gGr(v);c[O>>2]=0}}while(0);fxU(0,425984);if((c[2394]|0)==0){P=c[2112932]|0}else{c[2394]=0;A=c[3532596]|0;c[2112932]=A;y=c[3532592]|0;if((y|0)!=0){gGC(9104152,y|0,280)|0}c[2113054]=c[2113060];P=A}A=c[2388118]|0;y=P|0;F=0;while(1){B=A+F|0;c[y>>2]=B;c[y+131072>>2]=B;B=F+1024|0;if(B>>>0>524287){break}else{y=y+4|0;F=B}}F=c[2387306]|0;c[P+49152>>2]=F;c[P+114688>>2]=F;c[P+180224>>2]=F;y=F+1024|0;c[P+49156>>2]=y;c[P+114692>>2]=y;c[P+180228>>2]=y;y=F+2048|0;c[P+49160>>2]=y;c[P+114696>>2]=y;c[P+180232>>2]=y;y=F+3072|0;c[P+49164>>2]=y;c[P+114700>>2]=y;c[P+180236>>2]=y;y=c[2387996]|0;c[P+49168>>2]=y;c[P+114704>>2]=y;c[P+180240>>2]=y;F=y+1024|0;c[P+49172>>2]=F;c[P+114708>>2]=F;c[P+180244>>2]=F;F=y+2048|0;c[P+49176>>2]=F;c[P+114712>>2]=F;c[P+180248>>2]=F;F=y+3072|0;c[P+49180>>2]=F;c[P+114716>>2]=F;c[P+180252>>2]=F;F=c[2386326]|0;c[P+49184>>2]=F;c[P+114720>>2]=F;c[P+180256>>2]=F;y=F+1024|0;c[P+49188>>2]=y;c[P+114724>>2]=y;c[P+180260>>2]=y;y=F+2048|0;c[P+49192>>2]=y;c[P+114728>>2]=y;c[P+180264>>2]=y;y=F+3072|0;c[P+49196>>2]=y;c[P+114732>>2]=y;c[P+180268>>2]=y;y=F+4096|0;c[P+49200>>2]=y;c[P+114736>>2]=y;c[P+180272>>2]=y;y=F+5120|0;c[P+49204>>2]=y;c[P+114740>>2]=y;c[P+180276>>2]=y;y=F+6144|0;c[P+49208>>2]=y;c[P+114744>>2]=y;c[P+180280>>2]=y;y=F+7168|0;c[P+49212>>2]=y;c[P+114748>>2]=y;c[P+180284>>2]=y;y=c[2386424]|0;c[P+51200>>2]=y;c[P+116736>>2]=y;c[P+182272>>2]=y;F=y+1024|0;c[P+51204>>2]=F;c[P+116740>>2]=F;c[P+182276>>2]=F;F=y+2048|0;c[P+51208>>2]=F;c[P+116744>>2]=F;c[P+182280>>2]=F;F=y+3072|0;c[P+51212>>2]=F;c[P+116748>>2]=F;c[P+182284>>2]=F;F=y+4096|0;c[P+51216>>2]=F;c[P+116752>>2]=F;c[P+182288>>2]=F;F=y+5120|0;c[P+51220>>2]=F;c[P+116756>>2]=F;c[P+182292>>2]=F;F=y+6144|0;c[P+51224>>2]=F;c[P+116760>>2]=F;c[P+182296>>2]=F;F=y+7168|0;c[P+51228>>2]=F;c[P+116764>>2]=F;c[P+182300>>2]=F;F=c[2387154]|0;c[P+53248>>2]=F;c[P+118784>>2]=F;c[P+184320>>2]=F;y=F+1024|0;c[P+53252>>2]=y;c[P+118788>>2]=y;c[P+184324>>2]=y;y=F+2048|0;c[P+53256>>2]=y;c[P+118792>>2]=y;c[P+184328>>2]=y;y=F+3072|0;c[P+53260>>2]=y;c[P+118796>>2]=y;c[P+184332>>2]=y;y=c[2388246]|0;F=P+65280|0;A=16711680;while(1){B=y+(A-16711680)|0;c[F>>2]=B;c[F+65536>>2]=B;c[F+131072>>2]=B;B=A+1024|0;if(B>>>0>16777215){break}else{F=F+4|0;A=B}}c[P+196648>>2]=208;c[P+196728>>2]=492;c[P+196608>>2]=598;c[P+196688>>2]=1800;A=c[3532592]|0;if((A|0)!=0){gGC(A|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);A=c[2439330]|0;F=(A|0)==0;if(!F){y=A;gGC(9706056,y|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];y=c[3528484]|0;c[2076596]=y;B=c[2417276]|0;c[3541536]=B;c[1836236]=0;C=c[2385896]|0;I=0;G=0;while(1){c[A+76+(G<<2)>>2]=C+(G<<8);H=I+1&65535;if((H&65535)>63){Q=0;R=0;break}else{I=H;G=H&65535}}while(1){G=C+(R<<8)|0;c[A+76+(R+512<<2)>>2]=G;c[A+76+(R+768<<2)>>2]=G;G=Q+1&65535;if((G&65535)>63){break}else{Q=G;R=G&65535}}C=c[2386050]|0;c[A+556>>2]=C;G=C+256|0;c[A+560>>2]=G;I=C+512|0;c[A+564>>2]=I;H=C+768|0;c[A+568>>2]=H;J=C+1024|0;c[A+572>>2]=J;K=C+1280|0;c[A+576>>2]=K;L=C+1536|0;c[A+580>>2]=L;M=C+1792|0;c[A+584>>2]=M;c[A+1580>>2]=C;c[A+1584>>2]=G;c[A+1588>>2]=I;c[A+1592>>2]=H;c[A+1596>>2]=J;c[A+1600>>2]=K;c[A+1604>>2]=L;c[A+1608>>2]=M;c[A+2604>>2]=C;c[A+3628>>2]=C;c[A+2608>>2]=G;c[A+3632>>2]=G;c[A+2612>>2]=I;c[A+3636>>2]=I;c[A+2616>>2]=H;c[A+3640>>2]=H;c[A+2620>>2]=J;c[A+3644>>2]=J;c[A+2624>>2]=K;c[A+3648>>2]=K;c[A+2628>>2]=L;c[A+3652>>2]=L;c[A+2632>>2]=M;c[A+3656>>2]=M;c[A+4176>>2]=1058;c[A+4172>>2]=1314;if(!F){M=A;gGC(M|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=y;c[2417276]=B;c[1836236]=-1;Ux(0,8500,1);c[2407030]=120;c[2407068]=3;M=a[9680]|0;L=M?32e3:0;if(M){if(a[9624]|0){M=L*3|0;K=55930;while(1){if((K|0)>(M|0)){K=K>>1}else{S=1222;T=K;break}}}else{S=2462;T=L}c[2429380]=T;c[3542124]=S;mw(3579545,T);K=gGq(262144)|0;c[2406684]=K;gGz(K|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(3579545,11025)}c[(c[3531464]|0)+44344>>2]=876;h[745421]=.45;c[2436794]=1;h[745420]=.45;c[2436792]=2;K=c[642608+(c[2436]<<2)>>2]|0;M=c[K+128>>2]|0;if((c[K+52>>2]&4|0)==0){c[2113068]=M;B=c[K+132>>2]|0;c[2113070]=B;c[2443814]=M;c[2440436]=B;U=M;V=B}else{c[2113070]=M;B=c[K+132>>2]|0;c[2113068]=B;c[2440436]=M;c[2443814]=B;U=B;V=M}M=ag(U<<1,V)|0;B=gGq(M)|0;c[2112926]=B;if((B|0)!=0){gGz(B|0,0,M|0)}a[9623888]=0;M=c[2414624]|0;gGz(M|0,0,(c[2411586]|0)-M|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];M=c[3532592]|0;if((M|0)!=0){gGC(9104152,M|0,280)|0}c[2113054]=c[2113060]}RI();M=c[2394]|0;B=c[14130368+(M<<2)>>2]|0;if((B|0)!=0){gGC(B|0,9104152,280)|0}c[8452240+(M<<2)>>2]=c[2113054];c[2394]=-1;M=c[2439330]|0;B=(M|0)==0;if(!B){K=M;gGC(9706056,K|0,76)|0}K=c[2438118]|0;c[2433530]=K;y=c[3528484]|0;c[2076596]=y;A=c[2417276]|0;c[3541536]=A;c[1836236]=0;gGz(9706056,0,76);if(!B){B=M;gGC(B|0,9706056,76)|0}c[2438118]=K;c[3528484]=y;c[2417276]=A;c[1836236]=-1;c[2113156]=0;a[9628264]=0;c[2407033]=0;A=c[3541206]|0;c[3541190]=A;c[3541198]=A;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=A+256;c[3541199]=A+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=A+512;c[3541200]=A+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=A+768;c[3541201]=A+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;mx(0);A=c[2388118]|0;a[A+2652|0]=a[9634922]|0;a[A+2653|0]=a[9634922]|0;z=0;i=e;return z|0}}while(0);c[2414922]=0;z=1;i=e;return z|0}function evt(){var a=0,b=0,d=0,e=0,f=0;c[2113070]=0;c[2113068]=0;a=c[2112926]|0;if((a|0)!=0){gGr(a);c[2112926]=0}a=c[3531464]|0;c[a+44344>>2]=0;c[a+44348>>2]=0;if((a|0)!=0){gGr(a);c[3531464]=0}a=c[2406684]|0;if((a|0)!=0){gGr(a);c[2406684]=0}Uw(0);if((c[2392]|0)>=0){a=0;do{b=14130368+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}b=14130384+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}a=a+1|0;}while((a|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;fwZ();a=c[2414922]|0;b=0;while(1){if((b|0)>=1024){e=6488;break}f=9638528+(b<<2)|0;if((c[f>>2]|0)==(a|0)){break}else{b=b+1|0}}if((e|0)==6488){c[2414922]=0;c[3541206]=0;return 0}gGr(a);c[f>>2]=0;c[2414922]=0;c[3541206]=0;return 0}function evu(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((a[9623888]|0)!=0){a[9623888]=0;d=c[2414624]|0;gGz(d|0,0,(c[2411586]|0)-d|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;h=c[2417276]|0;c[3541536]=h;c[1836236]=0;gGz(9706056,0,76);if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=h;c[1836236]=-1;c[2113156]=0;a[9628264]=0;c[2407033]=0;h=c[3541206]|0;c[3541190]=h;c[3541198]=h;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=h+256;c[3541199]=h+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=h+512;c[3541200]=h+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=h+768;c[3541201]=h+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;mx(0);h=c[2388118]|0;a[h+2652|0]=a[9634922]|0;a[h+2653|0]=a[9634922]|0}c[2387586]=-1;h=0;g=-1;f=-1;do{g=((a[9633016+h|0]&1)<<h^g&65535)&65535;f=((a[9630888+h|0]&1)<<h^f&65535)&65535;h=h+1|0;}while((h|0)<16);b[4775172]=g;b[4775173]=f&127;f=c[2392]|0;if((f|0)>=0){gGz(8452240,0,((f|0)>0?(f<<2)+4|0:4)|0)}c[2113054]=0;f=c[2385548]|0;if((f|0)>0){gGz(9752472,0,((f|0)>1?f<<2:4)|0)}c[2433530]=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060]}f=c[2439330]|0;if((f|0)!=0){g=f;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;g=0;f=0;h=0;e=0;while(1){d=10-e|0;i=(266666-h|0)/(d|0)|0;c[2113056]=i;j=RG(i)|0;c[2113054]=(c[2113054]|0)+j;c[2276108]=-1;c[2113056]=-1;i=j+h|0;j=(1e5-f|0)/(d|0)|0;do{if((j|0)<1){k=0}else{if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){d=gfc(j)|0;c[2433530]=(c[2433530]|0)+d;k=d;break}else{c[2433530]=(c[2433530]|0)+j;k=j;break}}}while(0);j=c[2112964]|0;if((j|0)==0){l=g;m=0}else{d=a[9688]|0?53:0;n=g<<1;gg[c[3542124]&4095](j+(n<<1)|0,d);j=c[2112964]|0;Uu(0,j+(n<<1)|0,d);l=d+g|0;m=j}j=e+1|0;if((j|0)<10){g=l;f=k+f|0;h=i;e=j}else{break}}c[8452200+(c[2394]<<2)>>2]=8193;c[2276080]=256;if((c[2276079]|0)>>>0<256){RH(1);o=c[2112964]|0}else{o=m}do{if((o|0)!=0){m=(a[9688]|0?534:0)-l|0;if((m|0)<=0){break}e=l<<1;gg[c[3542124]&4095](o+(e<<1)|0,m);Uu(0,(c[2112964]|0)+(e<<1)|0,m)}}while(0);o=c[1836236]|0;l=c[9757320+(o<<2)>>2]|0;if((l|0)!=0){m=l;gGC(m|0,9706056,76)|0}c[9752472+(o<<2)>>2]=c[2433530];c[14113936+(o<<2)>>2]=c[2076596];c[9669104+(o<<2)>>2]=c[3541536];c[1836236]=-1;o=c[2394]|0;m=c[14130368+(o<<2)>>2]|0;if((m|0)!=0){gGC(m|0,9104152,280)|0}c[8452240+(o<<2)>>2]=c[2113054];c[2394]=-1;if((c[2112968]|0)==0){return 0}evv()|0;return 0}function evv(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;if((a[9547296]|0)!=0){d=c[2387154]|0;f=c[3529956]|0;g=0;do{h=e[d+g>>1]|0;i=h>>>3;j=h>>>7&30;c[f+(((g|0)/2|0)<<2)>>2]=h>>>1&1|h&61440|i&30|i<<11&2048|((j|h>>>2&1)<<3|j>>>2)<<3&2016;g=g+2|0;}while((g|0)<4096)}g=c[2387996]|0;f=c[3530320]|0;d=c[2386720]|0;j=d+4|0;h=d+6|0;evx(g,f,b[j>>1]&511,b[h>>1]&511,0,0);i=c[2387306]|0;k=c[3530802]|0;l=d+2|0;evx(i,k,b[d>>1]&511,b[l>>1]&511,1,0);m=c[2386424]|0;n=c[2112926]|0;o=c[3530408]|0;p=0;do{q=e[m+((p|6)<<1)>>1]<<8&16128|b[m+((p|5)<<1)>>1]&255;r=m+((p|4)<<1)|0;s=e[r>>1]|0;t=~s;if((t&128|0)!=0){u=e[m+((p|1)<<1)>>1]|0;v=(u<<8&32512|b[m+(p<<1)>>1]&255)-(u<<9&65536)-16|0;u=e[m+((p|3)<<1)>>1]|0;w=(u<<8&32512|b[m+((p|2)<<1)>>1]&255)-(u<<9&65536)-16|0;u=b[m+((p|7)<<1)>>1]&15;x=s&7;y=s&16;z=s&32;do{if((t&8|0)==0){A=v;B=w}else{if((y|0)==0){C=w}else{C=w+(x<<4)|0}if((z|0)==0){A=v;B=C;break}A=v+(x<<4)|0;B=C}}while(0);v=(y|0)!=0;w=(z|0)!=0;t=B;s=A;D=q;E=x;while(1){do{if(v){if(w){SN(n,D,s,t,u,4,0,768,o);SN(n,D,s,t+256|0,u,4,0,768,o);break}else{SL(n,D,s,t,u,4,0,768,o);SL(n,D,s,t+256|0,u,4,0,768,o);break}}else{if(w){SJ(n,D,s,t,u,4,0,768,o);SJ(n,D,s,t+256|0,u,4,0,768,o);break}else{SH(n,D,s,t,u,4,0,768,o);SH(n,D,s,t+256|0,u,4,0,768,o);break}}}while(0);F=D+1|0;do{if((b[r>>1]&8)==0){if(w){G=s-16|0;H=t;break}else{G=s+16|0;H=t;break}}else{if(v){G=s;H=t-16|0;break}else{G=s;H=t+16|0;break}}}while(0);if((E|0)>0){t=H;s=G;D=F;E=E-1|0}else{break}}}p=p+8|0;}while((p|0)<2048);evx(g,f,b[j>>1]&511,b[h>>1]&511,1,1);evx(i,k,b[d>>1]&511,b[l>>1]&511,1,1);l=c[2386326]|0;k=-16-(b[d+8>>1]&511)|0;i=-16-(b[d+10>>1]&511)|0;d=c[3530566]|0;h=c[2113068]|0;j=c[2113070]|0;f=0;do{g=(f<<3&504)+k|0;p=(g|0)<-7?g+512|0:g;g=(f>>6<<3)+i|0;G=(g|0)<-7?g+512|0:g;g=e[l+(f<<1)>>1]|0;H=g&4095;if(!((G|0)>=(j|0)|(p|0)>=(h|0)|(H|0)==0)){Sr(n,H,p,G,g>>>12,4,0,512,d)}f=f+1|0;}while((f|0)<4096);if((a[c[3528684]|0]|0)==0){I=c[3529956]|0;R8(I);return 0}f=ag(j,h)|0;h=(f|0)/2|0;if((f|0)>1){J=0}else{I=c[3529956]|0;R8(I);return 0}do{j=n+(J<<1)|0;d=b[j>>1]|0;J=J+1|0;l=n+(f-J<<1)|0;b[j>>1]=b[l>>1]|0;b[l>>1]=d;}while((J|0)<(h|0));I=c[3529956]|0;R8(I);return 0}function evw(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;g=i;i=i+96|0;h=g|0;j=g+16|0;k=g+32|0;l=g+48|0;m=g+64|0;n=g+80|0;if((f|0)!=0){c[f>>2]=169624}if((e&32|0)!=0){gGz(n|0,0,12);f=c[2414624]|0;c[n>>2]=f;c[n+4>>2]=(c[2411586]|0)-f;c[n+12>>2]=162152;f=c[2076592]|0;gj[f&4095](n)|0}if((e&64|0)==0){o=e&2}else{n=m|0;gGz(l|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){f=m+9|0;m=k;p=k|0;q=k+4|0;r=k+12|0;s=l|0;t=l+4|0;u=l+12|0;v=0;do{gGC(n|0,614896,11)|0;a[f]=v+48&255;w=8452256+(v<<2)|0;gGz(m|0,0,12);c[p>>2]=w;c[q>>2]=4;c[r>>2]=164976;gj[c[2076592]&4095](k)|0;if((c[w>>2]|0)!=0){c[s>>2]=c[14130368+(v<<2)>>2];c[t>>2]=c[8452184+(v<<2)>>2];c[u>>2]=n;w=c[2076592]|0;gj[w&4095](l)|0}v=v+1|0;}while((v|0)<=(c[2392]|0))}fw$(e);gGz(j|0,0,12);c[j>>2]=8453216;c[j+4>>2]=4;c[j+12>>2]=107480;v=c[2076592]|0;gj[v&4095](j)|0;gGz(h|0,0,12);c[h>>2]=14168504;c[h+4>>2]=256;c[h+12>>2]=476464;j=c[2076592]|0;gj[j&4095](h)|0;h=e&2;if((h|0)!=0){e=0;do{mv(0,e,d[14168504+e|0]|0);e=e+1|0;}while((e|0)<256)}Ut(0);o=h}if((o|0)==0){i=g;return 0}o=c[2439330]|0;h=(o|0)==0;if(!h){e=o;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];e=c[3528484]|0;c[2076596]=e;j=c[2417276]|0;c[3541536]=j;c[1836236]=0;v=c[3529362]|0;l=a[v]&7;a[v]=l&255;v=l<<15;l=c[2385896]|0;n=128;u=128;while(1){c[o+76+(u<<2)>>2]=l+((u<<8)+v);t=n+1&65535;if((t&65535)>255){x=128;y=128;break}else{n=t;u=t&65535}}while(1){u=l+((y<<8)+v)|0;c[o+76+(y+512<<2)>>2]=u;c[o+76+(y+768<<2)>>2]=u;u=x+1&65535;if((u&65535)>255){break}else{x=u;y=u&65535}}if(!h){h=o;gGC(h|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=e;c[2417276]=j;c[1836236]=-1;i=g;return 0}function evx(a,d,f,g,h,i){a=a|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;j=a;a=-16-f|0;f=-16-g|0;g=c[2112926]|0;if((h|0)==0){h=0;do{k=h<<1;l=e[j+((k|1)<<1)>>1]|0;do{if((l>>>5&1|0)==(i|0)){m=(h<<4&496)+a|0;n=(m|0)<-15?m+512|0:m;m=(h>>5<<4)+f|0;o=(m|0)<-15?m+512|0:m;if(!((n|0)<(c[2113068]|0)&(o|0)<(c[2113070]|0))){break}m=b[j+(k<<1)>>1]&4095;p=(l&256|0)!=0;q=l&31;if((l&512|0)==0){if(p){SB(g,m,n,o,q,5,1024,d);break}else{Sz(g,m,n,o,q,5,1024,d);break}}else{if(p){SF(g,m,n,o,q,5,1024,d);break}else{SD(g,m,n,o,q,5,1024,d);break}}}}while(0);h=h+1|0;}while((h|0)<1024);return}else{h=0;do{l=h<<1;k=e[j+((l|1)<<1)>>1]|0;do{if((k>>>5&1|0)==(i|0)){q=(h<<4&496)+a|0;o=(q|0)<-15?q+512|0:q;q=(h>>5<<4)+f|0;n=(q|0)<-15?q+512|0:q;if(!((o|0)<(c[2113068]|0)&(n|0)<(c[2113070]|0))){break}q=b[j+(l<<1)>>1]&4095;m=(k&256|0)!=0;p=k&31;if((k&512|0)==0){if(m){SJ(g,q,o,n,p,5,0,1024,d);break}else{SH(g,q,o,n,p,5,0,1024,d);break}}else{if(m){SN(g,q,o,n,p,5,0,1024,d);break}else{SL(g,q,o,n,p,5,0,1024,d);break}}}}while(0);h=h+1|0;}while((h|0)<1024);return}}function evy(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=i;i=i+120|0;f=e|0;g=e+112|0;h=0;while(1){if((h|0)>=1024){j=1;k=6638;break}l=9638528+(h<<2)|0;if((c[l>>2]|0)==0){break}else{h=h+1|0}}if((k|0)==6638){i=e;return j|0}h=gGq(131072)|0;c[l>>2]=h;if((h|0)==0){j=1;i=e;return j|0}gGz(h|0,0,131072);if((c[3542200]|0)==0){j=1;i=e;return j|0}l=f+108|0;c[l>>2]=0;m=f+100|0;c[m>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,d)|0;do{if((c[l>>2]|0)==0){n=0}else{f=c[m>>2]|0;c[g>>2]=9534384;o=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[o&16383](g,d,0)|0;if((f|0)<1){j=1;i=e;return j|0}if((gzL(h,0,d)|0)==0){n=0;break}else{j=1}i=e;return j|0}}while(0);while(1){d=h+n|0;g=a[d]|0;m=n<<2;a[b+m|0]=g<<2&-128|(g&255)>>>1&8;g=a[d]|0;a[b+(m|1)|0]=(g&255)>>>3&8|g&-128;g=a[d]|0;a[b+(m|2)|0]=g<<6&-128|g<<3&8;g=a[d]|0;a[b+(m|3)|0]=g<<4&-128|g<<1&8;g=n+1|0;if((g|0)<131072){n=g}else{p=0;break}}while(1){if((p|0)>=1024){j=0;k=6639;break}q=9638528+(p<<2)|0;if((c[q>>2]|0)==(h|0)){break}else{p=p+1|0}}if((k|0)==6639){i=e;return j|0}gGr(h);c[q>>2]=0;j=0;i=e;return j|0}function evz(b,d){b=b|0;d=d|0;if((b|0)!=2293760){return}a[c[3528242]|0]=d&255;return}function evA(a,b){a=a|0;b=b|0;return}function evB(a){a=a|0;var c=0;if((a|0)==2294272){c=b[4774972]|0}else if((a|0)==2294016){c=b[4774888]|0}else{c=0}return c|0}function evC(a){a=a|0;return 0}function evD(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=b&255;if((e|0)==192){a[c[3528242]|0]=0;return}else if((e|0)==128){Uv(0,d);return}else if((e|0)==112){b=c[3541518]|0;f=b+256|0;a[b+304|0]=d;g=d&255;if((d&255)<16){c[14168912+((c[2383582]|0)*252|0)>>2]=g&15}if((d-45&255)>=3){return}if((g|0)==46){h=b+312|0;i=a[h]|1;a[h]=i;j=i}else if((g|0)==0){a[b+312|0]=2;j=2}else if((g|0)==45){i=b+312|0;h=a[i]|2;a[i]=h;j=h}else if((g|0)==47){a[b+312|0]=0;j=0}else{j=a[b+312|0]|0}b=j&3;j=c[7461744+(b<<2)>>2]|0;lI(f,j,j,c[7461728+(b<<2)>>2]|0);return}else if((e|0)==113){lS(0,1,d);return}else{return}}function evE(b){b=b|0;var e=0,f=0,g=0,i=0,j=0.0,k=0.0;e=b&255;if((e|0)==0){f=a[c[3528242]|0]|0;return f|0}else if((e|0)==113){if((d[(c[3541518]|0)+304|0]|0)>=16){f=0;return f|0}b=c[2383582]|0;g=c[14168912+(b*252|0)>>2]|0;if((g|0)>15){f=0;return f|0}do{if((g|0)==14){i=c[14168896+(b*252|0)>>2]|0;if((i|0)==0){break}a[14168930+(b*252|0)|0]=gj[i&4095](0)|0}else if((g|0)==15){i=c[14168900+(b*252|0)>>2]|0;if((i|0)==0){break}a[14168931+(b*252|0)|0]=gj[i&4095](0)|0}}while(0);f=a[14168916+(b*252|0)+g|0]|0;return f|0}else if((e|0)==112){e=c[3541518]|0;g=e+296|0;j=+h[g>>3];do{if(j!=0.0){k=+h[6675];if(j-(k+ +gC[c[2429842]&255]())<=0.0){h[g>>3]=0.0;break}f=a[e+307|0]|-128;return f|0}}while(0);f=a[e+307|0]|0;return f|0}else{f=0;return f|0}return 0}function evF(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7012740+(b*112|0)>>2];c[a+104>>2]=c[7012744+(b*112|0)>>2];c[a+108>>2]=c[7012748+(b*112|0)>>2];d=0;return d|0}function evG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=7012640+(b*112|0);e=0;return e|0}function evH(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6178408+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function evI(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7161048+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function evJ(){var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;d=i;i=i+240|0;e=d|0;f=d+112|0;g=d+120|0;j=d+232|0;c[2414920]=0;c[2388116]=0;c[2385894]=262144;c[3530800]=327680;c[3530564]=589824;c[3541206]=1114112;c[2386618]=1114112;c[3529954]=1245184;c[2414622]=1247232;c[2388244]=1247232;c[2387152]=1263616;c[2387964]=1264640;c[2387846]=1268736;c[2386048]=1285120;c[3528242]=1287168;c[2411584]=1287169;k=0;while(1){if((k|0)>=1024){break}l=9638528+(k<<2)|0;if((c[l>>2]|0)==0){m=6728;break}else{k=k+1|0}}do{if((m|0)==6728){k=gGq(1287169)|0;c[l>>2]=k;if((k|0)==0){break}c[2414920]=k;gGz(k|0,0,1287169);c[2388116]=k;c[2385894]=k+262144;c[3530800]=k+327680;c[3530564]=k+589824;n=k+1114112|0;c[3541206]=n;c[2386618]=n;c[3529954]=k+1245184;n=k+1247232|0;c[2414622]=n;c[2388244]=n;c[2387152]=k+1263616;c[2387964]=k+1264640;c[2387846]=k+1268736;c[2386048]=k+1285120;c[3528242]=k+1287168;n=k+1287169|0;c[2411584]=n;c[2414122]=n;if((R6(k,0,2)|0)!=0){o=1;i=d;return o|0}if((R6((c[2388116]|0)+1|0,1,2)|0)!=0){o=1;i=d;return o|0}k=c[2385894]|0;if((c[3542200]|0)==0){o=1;i=d;return o|0}n=g+108|0;c[n>>2]=0;p=g+100|0;c[p>>2]=0;q=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[q&16383](g,2)|0;do{if((c[n>>2]|0)!=0){q=c[p>>2]|0;c[j>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](j,2,0)|0;if((q|0)<1){o=1;i=d;return o|0}if((gzL(k,0,2)|0)==0){break}else{o=1}i=d;return o|0}}while(0);k=c[2386618]|0;if((c[3542200]|0)==0){o=1;i=d;return o|0}p=e+108|0;c[p>>2]=0;n=e+100|0;c[n>>2]=0;q=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[q&16383](e,3)|0;do{if((c[p>>2]|0)!=0){q=c[n>>2]|0;c[f>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](f,3,0)|0;if((q|0)<1){o=1;i=d;return o|0}if((gzL(k,0,3)|0)==0){break}else{o=1}i=d;return o|0}}while(0);if((R6(c[3530800]|0,4,2)|0)!=0){o=1;i=d;return o|0}if((R6((c[3530800]|0)+1|0,5,2)|0)!=0){o=1;i=d;return o|0}if((R6(c[3530564]|0,6,2)|0)!=0){o=1;i=d;return o|0}if((R6((c[3530564]|0)+1|0,7,2)|0)!=0){o=1;i=d;return o|0}if((R6((c[3530564]|0)+262144|0,8,2)|0)!=0){o=1;i=d;return o|0}if((R6((c[3530564]|0)+262145|0,9,2)|0)!=0){o=1;i=d;return o|0}fxU(0,425984);if((c[2394]|0)==0){s=c[2112932]|0}else{c[2394]=0;k=c[3532596]|0;c[2112932]=k;n=c[3532592]|0;if((n|0)!=0){gGC(9104152,n|0,280)|0}c[2113054]=c[2113060];s=k}k=c[2388116]|0;n=s|0;p=0;while(1){q=k+p|0;c[n>>2]=q;c[n+131072>>2]=q;q=p+1024|0;if(q>>>0>262143){break}else{n=n+4|0;p=q}}p=c[2388244]|0;c[s+2048>>2]=p;c[s+67584>>2]=p;c[s+133120>>2]=p;n=p+1024|0;c[s+2052>>2]=n;c[s+67588>>2]=n;c[s+133124>>2]=n;n=p+2048|0;c[s+2056>>2]=n;c[s+67592>>2]=n;c[s+133128>>2]=n;n=p+3072|0;c[s+2060>>2]=n;c[s+67596>>2]=n;c[s+133132>>2]=n;n=p+4096|0;c[s+2064>>2]=n;c[s+67600>>2]=n;c[s+133136>>2]=n;n=p+5120|0;c[s+2068>>2]=n;c[s+67604>>2]=n;c[s+133140>>2]=n;n=p+6144|0;c[s+2072>>2]=n;c[s+67608>>2]=n;c[s+133144>>2]=n;n=p+7168|0;c[s+2076>>2]=n;c[s+67612>>2]=n;c[s+133148>>2]=n;n=p+8192|0;c[s+2080>>2]=n;c[s+67616>>2]=n;c[s+133152>>2]=n;n=p+9216|0;c[s+2084>>2]=n;c[s+67620>>2]=n;c[s+133156>>2]=n;n=p+10240|0;c[s+2088>>2]=n;c[s+67624>>2]=n;c[s+133160>>2]=n;n=p+11264|0;c[s+2092>>2]=n;c[s+67628>>2]=n;c[s+133164>>2]=n;n=p+12288|0;c[s+2096>>2]=n;c[s+67632>>2]=n;c[s+133168>>2]=n;n=p+13312|0;c[s+2100>>2]=n;c[s+67636>>2]=n;c[s+133172>>2]=n;n=p+14336|0;c[s+2104>>2]=n;c[s+67640>>2]=n;c[s+133176>>2]=n;n=p+15360|0;c[s+2108>>2]=n;c[s+67644>>2]=n;c[s+133180>>2]=n;n=c[2387964]|0;c[s+8192>>2]=n;c[s+73728>>2]=n;c[s+139264>>2]=n;p=n+1024|0;c[s+8196>>2]=p;c[s+73732>>2]=p;c[s+139268>>2]=p;p=n+2048|0;c[s+8200>>2]=p;c[s+73736>>2]=p;c[s+139272>>2]=p;p=n+3072|0;c[s+8204>>2]=p;c[s+73740>>2]=p;c[s+139276>>2]=p;p=c[2387846]|0;c[s+8448>>2]=p;c[s+73984>>2]=p;c[s+139520>>2]=p;n=p+1024|0;c[s+8452>>2]=n;c[s+73988>>2]=n;c[s+139524>>2]=n;n=p+2048|0;c[s+8456>>2]=n;c[s+73992>>2]=n;c[s+139528>>2]=n;n=p+3072|0;c[s+8460>>2]=n;c[s+73996>>2]=n;c[s+139532>>2]=n;n=p+4096|0;c[s+8464>>2]=n;c[s+74e3>>2]=n;c[s+139536>>2]=n;n=p+5120|0;c[s+8468>>2]=n;c[s+74004>>2]=n;c[s+139540>>2]=n;n=p+6144|0;c[s+8472>>2]=n;c[s+74008>>2]=n;c[s+139544>>2]=n;n=p+7168|0;c[s+8476>>2]=n;c[s+74012>>2]=n;c[s+139548>>2]=n;n=p+8192|0;c[s+8480>>2]=n;c[s+74016>>2]=n;c[s+139552>>2]=n;n=p+9216|0;c[s+8484>>2]=n;c[s+74020>>2]=n;c[s+139556>>2]=n;n=p+10240|0;c[s+8488>>2]=n;c[s+74024>>2]=n;c[s+139560>>2]=n;n=p+11264|0;c[s+8492>>2]=n;c[s+74028>>2]=n;c[s+139564>>2]=n;n=p+12288|0;c[s+8496>>2]=n;c[s+74032>>2]=n;c[s+139568>>2]=n;n=p+13312|0;c[s+8500>>2]=n;c[s+74036>>2]=n;c[s+139572>>2]=n;n=p+14336|0;c[s+8504>>2]=n;c[s+74040>>2]=n;c[s+139576>>2]=n;n=p+15360|0;c[s+8508>>2]=n;c[s+74044>>2]=n;c[s+139580>>2]=n;n=c[2387152]|0;c[s+8704>>2]=n;c[s+74240>>2]=n;c[s+139776>>2]=n;c[s+196728>>2]=1316;c[s+196648>>2]=124;c[s+196688>>2]=2118;c[s+196608>>2]=3116;n=c[3532592]|0;if((n|0)!=0){gGC(n|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);n=c[2439330]|0;p=(n|0)==0;if(!p){k=n;gGC(9706056,k|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];k=c[3528484]|0;c[2076596]=k;q=c[2417276]|0;c[3541536]=q;c[1836236]=0;r=c[2385894]|0;t=0;u=0;while(1){c[n+76+(u<<2)>>2]=r+(u<<8);v=t+1&65535;if((v&65535)>127){w=0;x=0;break}else{t=v;u=v&65535}}while(1){u=r+(x<<8)|0;c[n+76+(x+512<<2)>>2]=u;c[n+76+(x+768<<2)>>2]=u;u=w+1&65535;if((u&65535)>127){break}else{w=u;x=u&65535}}r=c[2386048]|0;c[n+1068>>2]=r;u=r+256|0;c[n+1072>>2]=u;t=r+512|0;c[n+1076>>2]=t;v=r+768|0;c[n+1080>>2]=v;y=r+1024|0;c[n+1084>>2]=y;z=r+1280|0;c[n+1088>>2]=z;A=r+1536|0;c[n+1092>>2]=A;B=r+1792|0;c[n+1096>>2]=B;c[n+2092>>2]=r;c[n+2096>>2]=u;c[n+2100>>2]=t;c[n+2104>>2]=v;c[n+2108>>2]=y;c[n+2112>>2]=z;c[n+2116>>2]=A;c[n+2120>>2]=B;c[n+3116>>2]=r;c[n+4140>>2]=r;c[n+3120>>2]=u;c[n+4144>>2]=u;c[n+3124>>2]=t;c[n+4148>>2]=t;c[n+3128>>2]=v;c[n+4152>>2]=v;c[n+3132>>2]=y;c[n+4156>>2]=y;c[n+3136>>2]=z;c[n+4160>>2]=z;c[n+3140>>2]=A;c[n+4164>>2]=A;c[n+3144>>2]=B;c[n+4168>>2]=B;c[n+4176>>2]=882;c[n+4172>>2]=882;if(!p){B=n;gGC(B|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=k;c[2417276]=q;c[1836236]=-1;Vr(1,3579545,0,3100,40,0);c[2438228]=3579545;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=571;h[745419]=.6;a[3203368]=1;h[745418]=.6;a[3203360]=1;h[745417]=.6;a[3203352]=1;h[745416]=.6;a[3203344]=1;Ux(0,6e3,1);c[2407030]=154;c[2407068]=3;B=c[642608+(c[2436]<<2)>>2]|0;A=c[B+128>>2]|0;if((c[B+52>>2]&4|0)==0){c[2113068]=A;z=c[B+132>>2]|0;c[2113070]=z;c[2443814]=A;c[2440436]=z;C=A;D=z}else{c[2113070]=A;z=c[B+132>>2]|0;c[2113068]=z;c[2440436]=A;c[2443814]=z;C=z;D=A}A=ag(C<<1,D)|0;z=gGq(A)|0;c[2112926]=z;if((z|0)!=0){gGz(z|0,0,A|0)}a[9623880]=0;A=c[2414622]|0;gGz(A|0,0,(c[2411584]|0)-A|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];A=c[3532592]|0;if((A|0)!=0){gGC(9104152,A|0,280)|0}c[2113054]=c[2113060]}RI();A=c[2394]|0;z=c[14130368+(A<<2)>>2]|0;if((z|0)!=0){gGC(z|0,9104152,280)|0}c[8452240+(A<<2)>>2]=c[2113054];c[2394]=-1;A=c[2439330]|0;z=(A|0)==0;if(!z){B=A;gGC(9706056,B|0,76)|0}B=c[2438118]|0;c[2433530]=B;y=c[3528484]|0;c[2076596]=y;v=c[2417276]|0;c[3541536]=v;c[1836236]=0;gGz(9706056,0,76);if(!z){z=A;gGC(z|0,9706056,76)|0}c[2438118]=B;c[3528484]=y;c[2417276]=v;c[1836236]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){v=0;do{lN(v);mB(v);v=v+1|0;}while((v|0)<(c[2385508]|0))}c[2113156]=0;a[9628264]=0;c[2407033]=0;v=c[3541206]|0;c[3541190]=v;c[3541198]=v;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=v+256;c[3541199]=v+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=v+512;c[3541200]=v+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=v+768;c[3541201]=v+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;o=0;i=d;return o|0}}while(0);c[2414920]=0;o=1;i=d;return o|0}function evK(){var b=0,d=0,e=0,f=0,g=0;c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}b=c[3541518]|0;if((b|0)!=0){gGr(b|0);c[3541518]=0}if((c[2385508]|0)>0){c[2113008]=0;c[2076598]=0;c[2383582]=0}c[2438228]=0;c[2433526]=0;c[2406676]=0;c[3528472]=0;b=c[2406680]|0;if((b|0)!=0){gGr(b);c[2406680]=0}c[2385508]=0;c[2432978]=0;a[64240]=0;Uw(0);if((c[2392]|0)>=0){b=0;do{d=14130368+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}d=14130384+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}b=b+1|0;}while((b|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;fwZ();b=c[2414920]|0;d=0;while(1){if((d|0)>=1024){f=6816;break}g=9638528+(d<<2)|0;if((c[g>>2]|0)==(b|0)){break}else{d=d+1|0}}if((f|0)==6816){c[2414920]=0;c[3541206]=0;return 0}gGr(b);c[g>>2]=0;c[2414920]=0;c[3541206]=0;return 0}function evL(){var e=0,f=0,g=0,i=0,j=0;if((a[9623880]|0)!=0){a[9623880]=0;e=c[2414622]|0;gGz(e|0,0,(c[2411584]|0)-e|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060]}RI();e=c[2394]|0;f=c[14130368+(e<<2)>>2]|0;if((f|0)!=0){gGC(f|0,9104152,280)|0}c[8452240+(e<<2)>>2]=c[2113054];c[2394]=-1;e=c[2439330]|0;f=(e|0)==0;if(!f){g=e;gGC(9706056,g|0,76)|0}g=c[2438118]|0;c[2433530]=g;i=c[3528484]|0;c[2076596]=i;j=c[2417276]|0;c[3541536]=j;c[1836236]=0;gGz(9706056,0,76);if(!f){f=e;gGC(f|0,9706056,76)|0}c[2438118]=g;c[3528484]=i;c[2417276]=j;c[1836236]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){j=0;do{lN(j);mB(j);j=j+1|0;}while((j|0)<(c[2385508]|0))}c[2113156]=0;a[9628264]=0;c[2407033]=0;j=c[3541206]|0;c[3541190]=j;c[3541198]=j;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=j+256;c[3541199]=j+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=j+512;c[3541200]=j+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=j+768;c[3541201]=j+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4}j=c[2392]|0;if((j|0)>=0){gGz(8452240,0,((j|0)>0?(j<<2)+4|0:4)|0)}c[2113054]=0;j=c[2385548]|0;if((j|0)>0){gGz(9752472,0,((j|0)>1?j<<2:4)|0)}c[2433530]=0;b[4774972]=-1;b[4774888]=d[9634913]<<8|d[9634912];j=0;i=-1;do{i=((a[9633e3+j|0]&1)<<j^i&65535)&65535;j=j+1|0;}while((j|0)<16);b[4774972]=i;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];i=c[3532592]|0;if((i|0)!=0){gGC(9104152,i|0,280)|0}c[2113054]=c[2113060]}i=c[2439330]|0;if((i|0)!=0){j=i;gGC(9706056,j|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;c[2113056]=11931;j=RG(11931)|0;c[2113054]=(c[2113054]|0)+j;c[2276108]=-1;c[2113056]=-1;Sb(0);i=(119318-j|0)/9|0;c[2113056]=i;g=RG(i)|0;c[2113054]=(c[2113054]|0)+g;c[2276108]=-1;c[2113056]=-1;i=g+j|0;Sb(5965);j=(119318-i|0)/8|0;c[2113056]=j;g=RG(j)|0;c[2113054]=(c[2113054]|0)+g;c[2276108]=-1;c[2113056]=-1;j=g+i|0;Sb(11930);i=(119318-j|0)/7|0;c[2113056]=i;g=RG(i)|0;c[2113054]=(c[2113054]|0)+g;c[2276108]=-1;c[2113056]=-1;i=g+j|0;Sb(17895);j=(119318-i|0)/6|0;c[2113056]=j;g=RG(j)|0;c[2113054]=(c[2113054]|0)+g;c[2276108]=-1;c[2113056]=-1;j=g+i|0;Sb(23860);i=(119318-j|0)/5|0;c[2113056]=i;g=RG(i)|0;c[2113054]=(c[2113054]|0)+g;c[2276108]=-1;c[2113056]=-1;i=g+j|0;Sb(29825);j=(119318-i|0)/4|0;c[2113056]=j;g=RG(j)|0;c[2113054]=(c[2113054]|0)+g;c[2276108]=-1;c[2113056]=-1;j=g+i|0;Sb(35790);i=(119318-j|0)/3|0;c[2113056]=i;g=RG(i)|0;c[2113054]=(c[2113054]|0)+g;c[2276108]=-1;c[2113056]=-1;Sb(41755);i=119318-(g+j)|0;j=(i|0)/2|0;c[2113056]=j;g=RG(j)|0;c[2113054]=(c[2113054]|0)+g;c[2276108]=-1;c[2113056]=-1;Sb(47720);j=i-g|0;c[2113056]=j;g=RG(j)|0;c[2113054]=(c[2113054]|0)+g;c[2276108]=-1;c[2113056]=-1;Sb(53685);a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0;g=c[2438228]|0;j=gGS(-1597636608,28447,g,(g|0)<0|0?-1:0)|0;g=j;Sb(59659);j=c[2443830]|0;if((j|0)<1073676288){c[2443830]=j-g}j=c[2443831]|0;if((j|0)<1073676288){c[2443831]=j-g}j=(c[3528512]|0)-g|0;c[3528512]=(j|0)<0?0:j;j=c[2112964]|0;if((j|0)!=0){gg[c[3542122]&4095](j,a[9688]|0?534:0);Uu(0,c[2112964]|0,a[9688]|0?534:0)}c[8452200+(c[2394]<<2)>>2]=8193;c[2276080]=256;if((c[2276079]|0)>>>0<256){RH(1)}j=c[1836236]|0;g=c[9757320+(j<<2)>>2]|0;if((g|0)!=0){i=g;gGC(i|0,9706056,76)|0}c[9752472+(j<<2)>>2]=c[2433530];c[14113936+(j<<2)>>2]=c[2076596];c[9669104+(j<<2)>>2]=c[3541536];c[1836236]=-1;j=c[2394]|0;i=c[14130368+(j<<2)>>2]|0;if((i|0)!=0){gGC(i|0,9104152,280)|0}c[8452240+(j<<2)>>2]=c[2113054];c[2394]=-1;if((c[2112968]|0)==0){return 0}evM()|0;return 0}function evM(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;if((a[9547288]|0)!=0){f=c[2387152]|0;g=c[3529954]|0;h=0;do{i=b[f+(h<<1)>>1]|0;c[g+(h<<2)>>2]=((i&65535)>>>10<<3&248)<<8|((i&255)<<3&255)>>>3|(((i&65535)>>>5<<3&255|(i&65535)>>>7&4)&255)<<3&2016;h=h+1|0;}while((h|0)<512)}h=c[2387964]|0;g=c[2113070]|0;f=c[2112926]|0;i=c[3530564]|0;j=c[2113068]|0;k=0;do{l=(k<<3&504)-64|0;m=(k>>6<<3)-16|0;do{if(!((l|0)>=(j|0)|(l|0)<-7)){if((m|0)>=(g|0)|(m|0)<-7){break}n=e[h+(k<<1)>>1]|0;o=n&8191;p=(n&16384|0)!=0;if((n&32768|0)!=0){if(p){So(f,o,l,m,0,8,0,i);break}else{Sm(f,o,l,m,0,8,0,i);break}}n=i+(o<<6)|0;c[2112928]=n;o=f+((ag(j,m)|0)+l<<1)|0;if(p){p=o;q=0;r=n;while(1){b[p+14>>1]=d[r]|0;b[p+12>>1]=d[r+1|0]|0;b[p+10>>1]=d[r+2|0]|0;b[p+8>>1]=d[r+3|0]|0;b[p+6>>1]=d[r+4|0]|0;b[p+4>>1]=d[r+5|0]|0;b[p+2>>1]=d[r+6|0]|0;b[p>>1]=d[r+7|0]|0;s=q+1|0;t=r+8|0;if((s|0)<8){p=p+(j<<1)|0;q=s;r=t}else{break}}c[2112928]=t;break}else{r=o;q=0;p=n;while(1){b[r>>1]=d[p]|0;b[r+2>>1]=d[p+1|0]|0;b[r+4>>1]=d[p+2|0]|0;b[r+6>>1]=d[p+3|0]|0;b[r+8>>1]=d[p+4|0]|0;b[r+10>>1]=d[p+5|0]|0;b[r+12>>1]=d[p+6|0]|0;b[r+14>>1]=d[p+7|0]|0;s=q+1|0;u=p+8|0;if((s|0)<8){r=r+(j<<1)|0;q=s;p=u}else{break}}c[2112928]=u;break}}}while(0);k=k+1|0;}while((k|0)<2048);k=c[2387846]|0;u=c[3530800]|0;t=0;do{i=t<<2&508;h=i-64|0;l=(t>>7<<2)-16|0;do{if(!((h|0)>=(j|0)|(h|0)<-3)){if((l|0)>=(g|0)|(l|0)<-3){break}m=e[k+(t<<1)>>1]|0;p=m&16383;if(p>>>0<16){break}q=-(m>>>14&1)&3|-(m>>>15)&12;m=p<<4;p=i-61|0;r=i-62|0;n=i-63|0;o=l;s=0;while(1){v=s<<2;w=a[u+((v^q)+m)|0]|0;if(w<<24>>24!=-1){b[f+((ag(j,o)|0)+h<<1)>>1]=w&255|256}w=a[u+(((v|1)^q)+m)|0]|0;if(w<<24>>24!=-1){b[f+(n+(ag(j,o)|0)<<1)>>1]=w&255|256}w=a[u+(((v|2)^q)+m)|0]|0;if(w<<24>>24!=-1){b[f+(r+(ag(j,o)|0)<<1)>>1]=w&255|256}w=a[u+(((v|3)^q)+m)|0]|0;if(w<<24>>24!=-1){b[f+(p+(ag(j,o)|0)<<1)>>1]=w&255|256}w=s+1|0;if((w|0)<4){o=o+1|0;s=w}else{break}}}}while(0);t=t+1|0;}while((t|0)<8192);R8(c[3529954]|0);return 0}function evN(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=i;i=i+64|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;if((d|0)!=0){c[d>>2]=169731}if((b&32|0)!=0){gGz(j|0,0,12);k=c[2414622]|0;c[j>>2]=k;c[j+4>>2]=(c[2411584]|0)-k;c[j+12>>2]=162152;k=c[2076592]|0;gj[k&4095](j)|0}if((b&64|0)==0){i=e;return 0}j=h|0;gGz(g|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){k=h+9|0;h=f;l=f|0;m=f+4|0;n=f+12|0;o=g|0;p=g+4|0;q=g+12|0;r=0;do{gGC(j|0,614896,11)|0;a[k]=r+48&255;s=8452256+(r<<2)|0;gGz(h|0,0,12);c[l>>2]=s;c[m>>2]=4;c[n>>2]=164976;gj[c[2076592]&4095](f)|0;if((c[s>>2]|0)!=0){c[o>>2]=c[14130368+(r<<2)>>2];c[p>>2]=c[8452184+(r<<2)>>2];c[q>>2]=j;s=c[2076592]|0;gj[s&4095](g)|0}r=r+1|0;}while((r|0)<=(c[2392]|0))}fw$(b);Vx(b,d);Ut(0);i=e;return 0}function evO(a){a=a|0;var b=0,d=0;b=(c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,3579545,0)|0;return a|0}function evP(){return+(+((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)/3579545.0)}function evQ(b,d){b=b|0;d=d|0;var f=0,g=0,h=0,i=0,j=0;if((b&-2048|0)==1310720){f=b&2047;g=(c[2387150]|0)+f|0;a[g]=d;h=e[g>>1]|0;g=h&31;i=h>>>5&31;j=h>>>10&31;h=i<<3|i>>>2;i=f>>>1;c[(c[2406922]|0)+(i<<2)>>2]=j<<3|j>>>2|(g<<3|g>>>2)<<16|h<<8;c[(c[3529952]|0)+(i<<2)>>2]=j|g<<11|h<<3&2016;return}if((b|0)==1572870|(b|0)==1572871){a[9620384]=d&3;return}else if((b|0)==1572878|(b|0)==1572879){a[9760896]=d&7;return}else if((b|0)==1572864|(b|0)==1572865){a[14112960]=d;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12;return}else if((b|0)==1572868|(b|0)==1572869){a[14114504]=d&15;return}else if((b|0)==3145730|(b|0)==3145731|(b|0)==3145732|(b|0)==3145733|(b|0)==3145734|(b|0)==3145735|(b|0)==3145736|(b|0)==3145737){a[(c[2386732]|0)+((b+6&7)<<1)|0]=d;return}else{return}}function evR(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;if((d&-2048|0)==1310720){f=d&2047;b[(c[2387150]|0)+f>>1]=e;g=e&65535;h=g&31;i=g>>>5&31;j=g>>>10&31;g=i<<3|i>>>2;i=f>>>1;c[(c[2406922]|0)+(i<<2)>>2]=j<<3|j>>>2|(h<<3|h>>>2)<<16|g<<8;c[(c[3529952]|0)+(i<<2)>>2]=j|h<<11|g<<3&2016;return}if((d|0)==1572864){a[14112960]=e&255;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12;return}else if((d|0)==1572868){a[14114504]=e&15;return}else if((d|0)==3145730|(d|0)==3145732|(d|0)==3145734|(d|0)==3145736){b[(c[2386732]|0)+((d-3145730|0)>>>1<<1)>>1]=e&511;return}else if((d|0)==1572878){a[9760896]=e&7;return}else if((d|0)==1572870){a[9620384]=e&3;return}else{return}}function evS(c){c=c|0;var d=0;switch(c|0){case 1572873:{d=b[4775168]&255;break};case 1572874:{d=(e[4775169]|0)>>>8&255;break};case 1572872:{d=(e[4775168]|0)>>>8&255;break};case 1572877:{d=b[4775170]&255;break};case 1572875:{d=b[4775169]&255&-81;break};case 1572868:case 1572869:{d=a[14114504]|a[9578768];break};case 1572876:{d=(e[4775170]|0)>>>8&255;break};default:{d=0}}return d|0}function evT(c){c=c|0;var d=0;if((c|0)==1572872){d=b[4775168]|0}else if((c|0)==1572868){d=(a[14114504]|a[9578768])&255}else if((c|0)==1572876){d=b[4775170]|0}else if((c|0)==1572874){d=b[4775169]&-81}else{d=0}return d|0}function evU(b,d){b=b|0;d=d|0;var f=0,g=0,h=0,i=0,j=0;if((b&-2048|0)==4456448){f=b&2047;g=(c[2387150]|0)+f|0;a[g]=d;h=e[g>>1]|0;g=h&31;i=h>>>5&31;j=h>>>10&31;h=i<<3|i>>>2;i=f>>>1;c[(c[2406922]|0)+(i<<2)>>2]=j<<3|j>>>2|(g<<3|g>>>2)<<16|h<<8;c[(c[3529952]|0)+(i<<2)>>2]=j|g<<11|h<<3&2016;return}if((b|0)==4718592|(b|0)==4718593){a[14112960]=d;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12;return}else if((b|0)==4718606|(b|0)==4718607){a[9760896]=d&7;return}else if((b|0)==5242882|(b|0)==5242883|(b|0)==5242884|(b|0)==5242885|(b|0)==5242886|(b|0)==5242887|(b|0)==5242888|(b|0)==5242889){a[(c[2386732]|0)+((b+6&7)<<1)|0]=d;return}else if((b|0)==4718598|(b|0)==4718599){a[9620384]=d&3;return}else if((b|0)==4718596|(b|0)==4718597){a[14114504]=d&15;return}else{return}}function evV(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;if((d&-2048|0)==4456448){f=d&2047;b[(c[2387150]|0)+f>>1]=e;g=e&65535;h=g&31;i=g>>>5&31;j=g>>>10&31;g=i<<3|i>>>2;i=f>>>1;c[(c[2406922]|0)+(i<<2)>>2]=j<<3|j>>>2|(h<<3|h>>>2)<<16|g<<8;c[(c[3529952]|0)+(i<<2)>>2]=j|h<<11|g<<3&2016;return}if((d|0)==5242882|(d|0)==5242884|(d|0)==5242886|(d|0)==5242888){b[(c[2386732]|0)+((d-5242882|0)>>>1<<1)>>1]=e;return}else if((d|0)==4718592){a[14112960]=e&255;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12;return}else if((d|0)==4718598){a[9620384]=e&3;return}else if((d|0)==4718596){a[14114504]=e&15;return}else if((d|0)==4718606){a[9760896]=e&7;return}else{return}}function evW(c){c=c|0;var d=0;switch(c|0){case 4718600:{d=(e[4775168]|0)>>>8&255;break};case 4718605:{d=b[4775170]&255;break};case 4718596:case 4718597:{d=a[14114504]|a[9578768];break};case 4718604:{d=(e[4775170]|0)>>>8&255;break};case 4718601:{d=b[4775168]&255;break};case 4718603:{d=b[4775169]&255;break};case 4718602:{d=(e[4775169]|0)>>>8&255;break};default:{d=0}}return d|0}function evX(c){c=c|0;var d=0;if((c|0)==4718600){d=b[4775168]|0}else if((c|0)==4718604){d=b[4775170]|0}else if((c|0)==4718602){d=b[4775169]|0}else if((c|0)==4718596){d=(a[14114504]|a[9578768])&255}else{d=0}return d|0}function evY(b,e){b=b|0;e=e|0;var f=0,g=0;f=b&255;if((f|0)==17){b=c[3540984]|0;g=c[b+5876>>2]|0;if((g|0)!=0){gg[g&4095](c[b+5880>>2]|0,0)}lH(b,d[b+5885|0]|0,e&255);return}else if((f|0)==16){a[(c[3540984]|0)+5885|0]=e;return}else if((f|0)==28){Uv(0,e);return}else if((f|0)==0){f=e&1;a[14120968]=f;c[3541206]=(c[2386616]|0)+(f<<24>>24!=0?262144:0);return}else{return}}function evZ(b){b=b|0;var e=0,f=0,g=0;e=b&255;if((e|0)==28){f=c[2113156]&255;return f|0}else if((e|0)==24){f=a[14112960]|0;return f|0}else if((e|0)==16){e=c[3540984]|0;b=(d[e+5887|0]|0|128)&(d[e+5886|0]|0);if((a[e+5884|0]&2)==0){g=b&255}else{g=(a[(c[e+5828>>2]|0)+100|0]&1|b)&255}f=g|6;return f|0}else{f=0;return f|0}return 0}function ev_(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7022356+(b*112|0)>>2];c[a+104>>2]=c[7022360+(b*112|0)>>2];c[a+108>>2]=c[7022364+(b*112|0)>>2];d=0;return d|0}function ev$(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=7022256+(b*112|0);e=0;return e|0}function ev0(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6199328+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function ev1(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>41){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7166368+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function ev2(){a[9578768]=16;return ewC(0,0,0)|0}function ev3(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;Uw(0);b=a[7452584]|0;if(b){d=0;e=b&1;while(1){b=14163936+(d<<2)|0;f=c[b>>2]|0;g=c[2113006]|0;if((g|0)==0){h=7066}else{i=g-1|0;c[2113006]=i;if((i|0)==0){h=7066}}if((h|0)==7066){h=0;c[2383474]=0}if((f|0)==0){j=e}else{gGr(f);j=a[7452584]&1}c[b>>2]=0;b=d+1|0;if((b|0)<(j|0)){d=b;e=j}else{break}}}a[7452584]=0;c[2438224]=0;c[2433522]=0;c[2406672]=0;c[3528468]=0;j=c[2406688]|0;if((j|0)!=0){gGr(j);c[2406688]=0}c[2432972]=0;c[2113070]=0;c[2113068]=0;j=c[2112926]|0;if((j|0)!=0){gGr(j);c[2112926]=0}fwZ();if((c[2392]|0)>=0){j=0;do{e=14130368+(j<<2)|0;d=c[e>>2]|0;if((d|0)!=0){gGr(d);c[e>>2]=0}e=14130384+(j<<2)|0;d=c[e>>2]|0;if((d|0)!=0){gGr(d);c[e>>2]=0}j=j+1|0;}while((j|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;j=c[2414918]|0;e=0;while(1){if((e|0)>=1024){h=7085;break}k=9638528+(e<<2)|0;if((c[k>>2]|0)==(j|0)){break}else{e=e+1|0}}if((h|0)==7085){c[2414918]=0;return 0}gGr(j);c[k>>2]=0;c[2414918]=0;return 0}function ev4(){var e=0,f=0,g=0,i=0,j=0;if((a[9623872]|0)!=0){a[9623872]=0;e=c[2414620]|0;gGz(e|0,0,(c[2411580]|0)-e|0);a[9760896]=7;a[14112960]=0;a[14114504]=0;a[9620384]=0;a[14120968]=0;c[3541206]=c[2386616];if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060]}RI();e=c[2394]|0;f=c[14130368+(e<<2)>>2]|0;if((f|0)!=0){gGC(f|0,9104152,280)|0}c[8452240+(e<<2)>>2]=c[2113054];c[2394]=-1;e=c[2439330]|0;f=(e|0)==0;if(!f){g=e;gGC(9706056,g|0,76)|0}g=c[2438118]|0;c[2433530]=g;i=c[3528484]|0;c[2076596]=i;j=c[2417276]|0;c[3541536]=j;c[1836236]=0;gGz(9706056,0,76);if(!f){f=e;gGC(f|0,9706056,76)|0}c[2438118]=g;c[3528484]=i;c[2417276]=j;c[1836236]=-1;c[2113156]=0;a[9628264]=0;c[2407033]=0;j=c[3541206]|0;c[3541190]=j;c[3541198]=j;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=j+256;c[3541199]=j+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=j+512;c[3541200]=j+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=j+768;c[3541201]=j+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;lw(c[3540984]|0)}gGz(9550336,-1|0,6);j=0;i=-1;g=-1;do{i=(d[9630872+j|0]<<j^i&65535)&65535;g=(d[9629368+j|0]<<j^g&65535)&65535;j=j+1|0;}while((j|0)<16);b[4775169]=i;b[4775170]=g;b[4775168]=d[9634905]<<8|d[9634904];g=c[2392]|0;if((g|0)>=0){gGz(8452240,0,((g|0)>0?(g<<2)+4|0:4)|0)}c[2113054]=0;g=c[2385548]|0;if((g|0)>0){gGz(9752472,0,((g|0)>1?g<<2:4)|0)}c[2433530]=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060]}g=c[2439330]|0;if((g|0)!=0){i=g;gGC(9706056,i|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;c[2113056]=266666;i=RG(266666)|0;c[2113054]=(c[2113054]|0)+i;c[2276108]=-1;c[2113056]=-1;c[8452200+(c[2394]<<2)>>2]=8198;c[2276080]=1536;if((c[2276079]|0)>>>0<1536){RH(6)}if((c[2112964]|0)!=0){i=c[2438224]|0;g=gGS(-747372544,31788,i,(i|0)<0|0?-1:0)|0;i=g;UF(66666)|0;g=c[2443826]|0;if((g|0)<1073676288){c[2443826]=g-i}g=c[2443827]|0;if((g|0)<1073676288){c[2443827]=g-i}g=(c[3528508]|0)-i|0;c[3528508]=(g|0)<0?0:g;gg[c[3542112]&4095](c[2112964]|0,a[9688]|0?534:0);Uu(0,c[2112964]|0,a[9688]|0?534:0)}g=c[1836236]|0;i=c[9757320+(g<<2)>>2]|0;if((i|0)!=0){j=i;gGC(j|0,9706056,76)|0}c[9752472+(g<<2)>>2]=c[2433530];c[14113936+(g<<2)>>2]=c[2076596];c[9669104+(g<<2)>>2]=c[3541536];c[1836236]=-1;g=c[2394]|0;j=c[14130368+(g<<2)>>2]|0;if((j|0)!=0){gGC(j|0,9104152,280)|0}c[8452240+(g<<2)>>2]=c[2113054];c[2394]=-1;if((c[2112968]|0)==0){return 0}ev5()|0;return 0}function ev5(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((a[9547280]|0)!=0){b=c[2406922]|0;f=c[3529952]|0;g=0;do{h=c[b+(g<<2)>>2]|0;c[f+(g<<2)>>2]=h>>8<<3&2016|h>>>3&31|h>>16<<8&63488;g=g+1|0;}while((g|0)<1024)}g=c[2386732]|0;f=c[3529454]|0;b=-3-(e[g+4>>1]|0)|0;h=-9-(e[g+6>>1]|0)|0;i=c[3530798]|0;j=c[2112926]|0;k=0;do{l=(k<<3&504)+b|0;m=(k>>6<<3)+h|0;Sj(j,d[9620384]<<16|e[f+(k<<1)>>1],(l|0)<-7?l+512|0:l,(m|0)<-7?m+512|0:m,1,8,0,i);k=k+1|0;}while((k|0)<4096);switch(a[9760896]|0){case 0:{ewF();k=c[3529418]|0;f=1-(e[g>>1]|0)|0;h=-9-(e[g+2>>1]|0)|0;b=0;do{m=(b<<3&504)+f|0;l=(b>>6<<3)+h|0;Sr(j,d[9620384]<<16|e[k+(b<<1)>>1],(m|0)<-7?m+512|0:m,(l|0)<-7?l+512|0:l,0,8,0,0,i);b=b+1|0;}while((b|0)<4096);ewG();n=c[3529952]|0;R8(n);return 0};case 2:{ewF();ewG();b=c[3529418]|0;k=1-(e[g>>1]|0)|0;h=-9-(e[g+2>>1]|0)|0;f=0;do{l=(f<<3&504)+k|0;m=(f>>6<<3)+h|0;Sr(j,d[9620384]<<16|e[b+(f<<1)>>1],(l|0)<-7?l+512|0:l,(m|0)<-7?m+512|0:m,0,8,0,0,i);f=f+1|0;}while((f|0)<4096);n=c[3529952]|0;R8(n);return 0};case 7:{f=c[3529418]|0;b=1-(e[g>>1]|0)|0;h=-9-(e[g+2>>1]|0)|0;k=0;do{m=(k<<3&504)+b|0;l=(k>>6<<3)+h|0;Sr(j,d[9620384]<<16|e[f+(k<<1)>>1],(m|0)<-7?m+512|0:m,(l|0)<-7?l+512|0:l,0,8,0,0,i);k=k+1|0;}while((k|0)<4096);ewG();ewF();n=c[3529952]|0;R8(n);return 0};case 3:{k=c[3529418]|0;f=1-(e[g>>1]|0)|0;h=-9-(e[g+2>>1]|0)|0;b=0;do{l=(b<<3&504)+f|0;m=(b>>6<<3)+h|0;Sr(j,d[9620384]<<16|e[k+(b<<1)>>1],(l|0)<-7?l+512|0:l,(m|0)<-7?m+512|0:m,0,8,0,0,i);b=b+1|0;}while((b|0)<4096);ewF();ewG();n=c[3529952]|0;R8(n);return 0};case 1:{ewG();ewF();b=c[3529418]|0;k=1-(e[g>>1]|0)|0;h=-9-(e[g+2>>1]|0)|0;g=0;do{f=(g<<3&504)+k|0;m=(g>>6<<3)+h|0;Sr(j,d[9620384]<<16|e[b+(g<<1)>>1],(f|0)<-7?f+512|0:f,(m|0)<-7?m+512|0:m,0,8,0,0,i);g=g+1|0;}while((g|0)<4096);n=c[3529952]|0;R8(n);return 0};default:{n=c[3529952]|0;R8(n);return 0}}return 0}function ev6(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;e=i;i=i+160|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;l=e+80|0;m=e+96|0;n=e+112|0;o=e+128|0;p=e+144|0;if((d|0)!=0){c[d>>2]=169618}if((b&32|0)!=0){gGz(p|0,0,12);q=c[2414620]|0;c[p>>2]=q;c[p+4>>2]=(c[2411580]|0)-q;c[p+12>>2]=162152;q=c[2076592]|0;gj[q&4095](p)|0}if((b&64|0)!=0){p=h|0;gGz(g|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){q=h+9|0;h=f;r=f|0;s=f+4|0;t=f+12|0;u=g|0;v=g+4|0;w=g+12|0;x=0;do{gGC(p|0,614896,11)|0;a[q]=x+48&255;y=8452256+(x<<2)|0;gGz(h|0,0,12);c[r>>2]=y;c[s>>2]=4;c[t>>2]=164976;gj[c[2076592]&4095](f)|0;if((c[y>>2]|0)!=0){c[u>>2]=c[14130368+(x<<2)>>2];c[v>>2]=c[8452184+(x<<2)>>2];c[w>>2]=p;y=c[2076592]|0;gj[y&4095](g)|0}x=x+1|0;}while((x|0)<=(c[2392]|0))}fw$(b);UQ(b,d);Ut(0);gGz(o|0,0,12);c[o>>2]=14112960;c[o+4>>2]=1;c[o+12>>2]=191240;d=c[2076592]|0;gj[d&4095](o)|0;gGz(n|0,0,12);c[n>>2]=9578768;c[n+4>>2]=1;c[n+12>>2]=495504;o=c[2076592]|0;gj[o&4095](n)|0;gGz(m|0,0,12);c[m>>2]=14114504;c[m+4>>2]=1;c[m+12>>2]=494064;n=c[2076592]|0;gj[n&4095](m)|0;gGz(l|0,0,12);c[l>>2]=9760896;c[l+4>>2]=1;c[l+12>>2]=492912;m=c[2076592]|0;gj[m&4095](l)|0;gGz(k|0,0,12);c[k>>2]=9620384;c[k+4>>2]=1;c[k+12>>2]=492016;l=c[2076592]|0;gj[l&4095](k)|0;gGz(j|0,0,12);c[j>>2]=14120968;c[j+4>>2]=1;c[j+12>>2]=491248;k=c[2076592]|0;gj[k&4095](j)|0}if((b&2|0)==0){i=e;return 0}b=a[14120968]&1;a[14120968]=b;c[3541206]=(c[2386616]|0)+(b<<24>>24!=0?262144:0);i=e;return 0}function ev7(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6515956+(b*112|0)>>2];c[a+104>>2]=c[6515960+(b*112|0)>>2];c[a+108>>2]=c[6515964+(b*112|0)>>2];d=0;return d|0}function ev8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=6515856+(b*112|0);e=0;return e|0}function ev9(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2312972+(b*112|0)>>2];c[a+104>>2]=c[2312976+(b*112|0)>>2];c[a+108>>2]=c[2312980+(b*112|0)>>2];d=0;return d|0}function ewa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=2312872+(b*112|0);e=0;return e|0}function ewb(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1197848+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function ewc(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>33){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3515608+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function ewd(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2311516+(b*112|0)>>2];c[a+104>>2]=c[2311520+(b*112|0)>>2];c[a+108>>2]=c[2311524+(b*112|0)>>2];d=0;return d|0}function ewe(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=2311416+(b*112|0);e=0;return e|0}function ewf(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>44){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3515064+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function ewg(){a[9578768]=16;c[2424]=5500;return ewC(1,0,0)|0}function ewh(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4489068+(b*112|0)>>2];c[a+104>>2]=c[4489072+(b*112|0)>>2];c[a+108>>2]=c[4489076+(b*112|0)>>2];d=0;return d|0}function ewi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=4488968+(b*112|0);e=0;return e|0}function ewj(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1787624+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function ewk(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>37){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5167248+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function ewl(){a[9578768]=16;return ewC(1,1,1)|0}function ewm(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2461532+(b*112|0)>>2];c[a+104>>2]=c[2461536+(b*112|0)>>2];c[a+108>>2]=c[2461540+(b*112|0)>>2];d=0;return d|0}function ewn(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=2461432+(b*112|0);e=0;return e|0}function ewo(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4706932+(b*112|0)>>2];c[a+104>>2]=c[4706936+(b*112|0)>>2];c[a+108>>2]=c[4706940+(b*112|0)>>2];d=0;return d|0}function ewp(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=4706832+(b*112|0);e=0;return e|0}function ewq(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1909976+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function ewr(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>27){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5391272+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function ews(){a[9578768]=64;return ewC(0,1,1)|0}function ewt(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6510540+(b*112|0)>>2];c[a+104>>2]=c[6510544+(b*112|0)>>2];c[a+108>>2]=c[6510548+(b*112|0)>>2];d=0;return d|0}function ewu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=6510440+(b*112|0);e=0;return e|0}function ewv(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5187728+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eww(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>42){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6822744+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function ewx(){var b=0,d=0,e=0;a[9578768]=32;b=ewC(0,0,1)|0;if((b|0)!=0){return b|0}d=c[2386616]|0;e=d+131072|0;gGC(e|0,d|0,131072)|0;e=d+262144|0;gGC(e|0,d|0,65536)|0;e=d+327680|0;gGC(e|0,d|0,131072)|0;return b|0}function ewy(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2077860+(b*112|0)>>2];c[a+104>>2]=c[2077864+(b*112|0)>>2];c[a+108>>2]=c[2077868+(b*112|0)>>2];d=0;return d|0}function ewz(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=2077760+(b*112|0);e=0;return e|0}function ewA(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>23){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3235464+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function ewB(){a[9578768]=0;return ewC(0,0,0)|0}function ewC(e,f,g){e=e|0;f=f|0;g=g|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;j=i;i=i+840|0;k=j|0;l=j+112|0;m=j+120|0;n=j+232|0;o=j+240|0;p=j+352|0;q=j+360|0;r=j+472|0;s=j+480|0;t=j+592|0;u=j+600|0;v=j+712|0;w=j+720|0;x=j+832|0;c[2414918]=0;c[2388114]=0;c[2385892]=1048576;c[3530798]=1114112;c[3530562]=17891328;c[3541206]=22085632;c[2386616]=22085632;c[3529952]=22609920;c[2414620]=22614016;c[2388242]=22614016;c[2386046]=22679552;c[2387150]=22681600;c[2386422]=22683648;c[3529454]=22685696;c[3529418]=22693888;c[2387956]=22702080;c[2386732]=22767616;c[2406922]=22767624;c[2411580]=22771720;y=0;while(1){if((y|0)>=1024){break}z=9638528+(y<<2)|0;if((c[z>>2]|0)==0){A=7348;break}else{y=y+1|0}}do{if((A|0)==7348){y=gGq(22771720)|0;c[z>>2]=y;if((y|0)==0){break}c[2414918]=y;gGz(y|0,0,22771720);c[2388114]=y;c[2385892]=y+1048576;c[3530798]=y+1114112;c[3530562]=y+17891328;B=y+22085632|0;c[3541206]=B;c[2386616]=B;c[3529952]=y+22609920;B=y+22614016|0;c[2414620]=B;c[2388242]=B;c[2386046]=y+22679552;c[2387150]=y+22681600;c[2386422]=y+22683648;c[3529454]=y+22685696;c[3529418]=y+22693888;c[2387956]=y+22702080;c[2386732]=y+22767616;c[2406922]=y+22767624;B=y+22771720|0;c[2411580]=B;c[2414120]=B;if((R6(y+1|0,0,2)|0)!=0){C=1;i=j;return C|0}if((R6(c[2388114]|0,1,2)|0)!=0){C=1;i=j;return C|0}y=c[2385892]|0;if((c[3542200]|0)==0){C=1;i=j;return C|0}B=w+108|0;c[B>>2]=0;D=w+100|0;c[D>>2]=0;E=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[E&16383](w,2)|0;do{if((c[B>>2]|0)!=0){E=c[D>>2]|0;c[x>>2]=9534384;F=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[F&16383](x,2,0)|0;if((E|0)<1){C=1;i=j;return C|0}if((gzL(y,0,2)|0)==0){break}else{C=1}i=j;return C|0}}while(0);y=(e|0)==0;do{if(y){D=o+108|0;B=o+100|0;E=0;while(1){F=(c[3530798]|0)+(E<<19)|0;G=E+3|0;if((c[3542200]|0)==0){C=1;A=7486;break}c[D>>2]=0;c[B>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](o,G)|0;if((c[D>>2]|0)!=0){H=c[B>>2]|0;c[p>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](p,G,0)|0;if((H|0)<1){C=1;A=7476;break}if((gzL(F,0,G)|0)!=0){C=1;A=7477;break}}G=E+1|0;if((G|0)<8){E=G}else{A=7374;break}}if((A|0)==7374){E=m+108|0;B=m+100|0;D=0;while(1){G=(c[3530562]|0)+(D<<19)|0;F=D+11|0;if((c[3542200]|0)==0){C=1;A=7485;break}c[E>>2]=0;c[B>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,F)|0;if((c[E>>2]|0)!=0){H=c[B>>2]|0;c[n>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](n,F,0)|0;if((H|0)<1){C=1;A=7478;break}if((gzL(G,0,F)|0)!=0){C=1;A=7479;break}}F=D+1|0;if((F|0)<5){D=F}else{A=7385;break}}if((A|0)==7385){D=c[2386616]|0;if((c[3542200]|0)==0){C=1;i=j;return C|0}B=k+108|0;c[B>>2]=0;E=k+100|0;c[E>>2]=0;F=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[F&16383](k,16)|0;if((c[B>>2]|0)==0){J=0;break}B=c[E>>2]|0;c[l>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](l,16,0)|0;if((B|0)<1){C=1;i=j;return C|0}if((gzL(D,0,16)|0)==0){J=0;break}else{C=1}i=j;return C|0}else if((A|0)==7478){i=j;return C|0}else if((A|0)==7479){i=j;return C|0}else if((A|0)==7485){i=j;return C|0}}else if((A|0)==7476){i=j;return C|0}else if((A|0)==7477){i=j;return C|0}else if((A|0)==7486){i=j;return C|0}}else{D=u+108|0;B=u+100|0;E=0;while(1){F=(c[3530798]|0)+(E<<22)|0;G=E+3|0;if((c[3542200]|0)==0){C=1;A=7473;break}c[D>>2]=0;c[B>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](u,G)|0;if((c[D>>2]|0)!=0){H=c[B>>2]|0;c[v>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](v,G,0)|0;if((H|0)<1){C=1;A=7491;break}if((gzL(F,0,G)|0)!=0){C=1;A=7492;break}}G=E+1|0;if((G|0)<4){E=G}else{A=7359;break}}if((A|0)==7473){i=j;return C|0}else if((A|0)==7491){i=j;return C|0}else if((A|0)==7492){i=j;return C|0}else if((A|0)==7359){E=s+108|0;B=s+100|0;D=0;while(1){G=(c[3530562]|0)+(D<<19)|0;F=D+7|0;if((c[3542200]|0)==0){C=1;A=7475;break}c[E>>2]=0;c[B>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](s,F)|0;if((c[E>>2]|0)!=0){H=c[B>>2]|0;c[t>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](t,F,0)|0;if((H|0)<1){C=1;A=7472;break}if((gzL(G,0,F)|0)!=0){C=1;A=7470;break}}F=D+1|0;if((F|0)<5){D=F}else{A=7370;break}}if((A|0)==7370){D=c[2386616]|0;if((c[3542200]|0)==0){C=1;i=j;return C|0}B=q+108|0;c[B>>2]=0;E=q+100|0;c[E>>2]=0;F=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[F&16383](q,12)|0;if((c[B>>2]|0)==0){J=0;break}B=c[E>>2]|0;c[r>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](r,12,0)|0;if((B|0)<1){C=1;i=j;return C|0}if((gzL(D,0,12)|0)==0){J=0;break}else{C=1}i=j;return C|0}else if((A|0)==7470){i=j;return C|0}else if((A|0)==7472){i=j;return C|0}else if((A|0)==7475){i=j;return C|0}}}}while(0);while(1){if((J|0)>=1024){break}K=9638528+(J<<2)|0;if((c[K>>2]|0)==0){A=7391;break}else{J=J+1|0}}L10134:do{if((A|0)==7391){D=gGq(16777216)|0;c[K>>2]=D;if((D|0)==0){break}gGz(D|0,0,16777216);B=c[3530798]|0;gGC(D|0,B|0,16777216)|0;if(y){E=0;do{F=E<<6;gGz(B+F|0,0,64);G=0;do{H=1<<7-G;I=(c[613720+(G<<2)>>2]|0)+F|0;L=0;do{M=I+(c[1238464+(L<<2)>>2]|0)|0;N=(L<<3)+F|0;O=0;do{P=M+(c[614800+(O<<2)>>2]|0)|0;if(((d[D+((P|0)/8|0)|0]|0)&128>>>((P&7)>>>0)|0)!=0){P=B+(N+O)|0;a[P]=(d[P]|0|H)&255}O=O+1|0;}while((O|0)<8);L=L+1|0;}while((L|0)<8);G=G+1|0;}while((G|0)<8);E=E+1|0;}while((E|0)<65536)}else{E=0;do{G=E<<6;gGz(B+G|0,0,64);F=E<<7;L=0;do{H=1<<7-L;I=(c[613664+(L<<2)>>2]|0)+F|0;O=0;do{N=I+(c[6669224+(O<<2)>>2]|0)|0;M=(O<<3)+G|0;P=0;do{Q=N+(c[614800+(P<<2)>>2]|0)|0;if(((d[D+((Q|0)/8|0)|0]|0)&128>>>((Q&7)>>>0)|0)!=0){Q=B+(M+P)|0;a[Q]=(d[Q]|0|H)&255}P=P+1|0;}while((P|0)<8);O=O+1|0;}while((O|0)<8);L=L+1|0;}while((L|0)<8);E=E+1|0;}while((E|0)<262144)}E=c[3530562]|0;gGC(D|0,E|0,4194304)|0;B=0;while(1){L=B<<8;gGz(E+L|0,0,256);G=0;do{F=1<<4-G;O=(c[613696+(G<<2)>>2]|0)+L|0;H=0;do{I=O+(c[609008+(H<<2)>>2]|0)|0;P=(H<<4)+L|0;M=0;do{N=I+(c[610384+(M<<2)>>2]|0)|0;if(((d[D+((N|0)/8|0)|0]|0)&128>>>((N&7)>>>0)|0)!=0){N=E+(P+M)|0;a[N]=(d[N]|0|F)&255}M=M+1|0;}while((M|0)<16);H=H+1|0;}while((H|0)<16);G=G+1|0;}while((G|0)<5);G=B+1|0;if((G|0)<16384){B=G}else{R=0;break}}while(1){if((R|0)>=1024){break L10134}S=9638528+(R<<2)|0;if((c[S>>2]|0)==(D|0)){break}else{R=R+1|0}}gGr(D);c[S>>2]=0}}while(0);fxU(0,425984);if((c[2394]|0)==0){T=c[2112932]|0}else{c[2394]=0;y=c[3532596]|0;c[2112932]=y;B=c[3532592]|0;if((B|0)!=0){gGC(9104152,B|0,280)|0}c[2113054]=c[2113060];T=y}y=c[2388114]|0;B=T|0;E=0;while(1){G=y+E|0;c[B>>2]=G;c[B+131072>>2]=G;G=E+1024|0;if(G>>>0>1048575){break}else{B=B+4|0;E=G}}E=c[2387956]|0;B=T+32768|0;y=8388608;while(1){G=E+(y-8388608)|0;c[B>>2]=G;c[B+65536>>2]=G;c[B+131072>>2]=G;G=y+1024|0;if(G>>>0>8454143){break}else{B=B+4|0;y=G}}y=c[2388242]|0;if((f|0)==0){B=T+4608|0;E=1179648;while(1){G=y+(E-1179648)|0;c[B>>2]=G;c[B+65536>>2]=G;c[B+131072>>2]=G;G=E+1024|0;if(G>>>0>1245183){break}else{B=B+4|0;E=G}}E=c[2387150]|0;c[T+5120>>2]=E;c[T+136192>>2]=E;B=E+1024|0;c[T+5124>>2]=B;c[T+136196>>2]=B;B=c[2386422]|0;c[T+5632>>2]=B;c[T+71168>>2]=B;c[T+136704>>2]=B;E=B+1024|0;c[T+5636>>2]=E;c[T+71172>>2]=E;c[T+136708>>2]=E;E=c[3529454]|0;c[T+12800>>2]=E;c[T+78336>>2]=E;c[T+143872>>2]=E;B=E+1024|0;c[T+12804>>2]=B;c[T+78340>>2]=B;c[T+143876>>2]=B;B=E+2048|0;c[T+12808>>2]=B;c[T+78344>>2]=B;c[T+143880>>2]=B;B=E+3072|0;c[T+12812>>2]=B;c[T+78348>>2]=B;c[T+143884>>2]=B;B=E+4096|0;c[T+12816>>2]=B;c[T+78352>>2]=B;c[T+143888>>2]=B;B=E+5120|0;c[T+12820>>2]=B;c[T+78356>>2]=B;c[T+143892>>2]=B;B=E+6144|0;c[T+12824>>2]=B;c[T+78360>>2]=B;c[T+143896>>2]=B;B=E+7168|0;c[T+12828>>2]=B;c[T+78364>>2]=B;c[T+143900>>2]=B;B=c[3529418]|0;c[T+12832>>2]=B;c[T+78368>>2]=B;c[T+143904>>2]=B;E=B+1024|0;c[T+12836>>2]=E;c[T+78372>>2]=E;c[T+143908>>2]=E;E=B+2048|0;c[T+12840>>2]=E;c[T+78376>>2]=E;c[T+143912>>2]=E;E=B+3072|0;c[T+12844>>2]=E;c[T+78380>>2]=E;c[T+143916>>2]=E;E=B+4096|0;c[T+12848>>2]=E;c[T+78384>>2]=E;c[T+143920>>2]=E;E=B+5120|0;c[T+12852>>2]=E;c[T+78388>>2]=E;c[T+143924>>2]=E;E=B+6144|0;c[T+12856>>2]=E;c[T+78392>>2]=E;c[T+143928>>2]=E;E=B+7168|0;c[T+12860>>2]=E;c[T+78396>>2]=E;c[T+143932>>2]=E;c[T+196648>>2]=2004;c[T+196728>>2]=2518;c[T+196608>>2]=802;c[T+196688>>2]=2846}else{E=T+8192|0;B=2097152;while(1){G=y+(B-2097152)|0;c[E>>2]=G;c[E+65536>>2]=G;c[E+131072>>2]=G;G=B+1024|0;if(G>>>0>2162687){break}else{E=E+4|0;B=G}}B=c[2387150]|0;c[T+17408>>2]=B;c[T+148480>>2]=B;E=B+1024|0;c[T+17412>>2]=E;c[T+148484>>2]=E;E=c[2386422]|0;c[T+17920>>2]=E;c[T+83456>>2]=E;c[T+148992>>2]=E;B=E+1024|0;c[T+17924>>2]=B;c[T+83460>>2]=B;c[T+148996>>2]=B;B=c[3529454]|0;c[T+20992>>2]=B;c[T+86528>>2]=B;c[T+152064>>2]=B;E=B+1024|0;c[T+20996>>2]=E;c[T+86532>>2]=E;c[T+152068>>2]=E;E=B+2048|0;c[T+21e3>>2]=E;c[T+86536>>2]=E;c[T+152072>>2]=E;E=B+3072|0;c[T+21004>>2]=E;c[T+86540>>2]=E;c[T+152076>>2]=E;E=B+4096|0;c[T+21008>>2]=E;c[T+86544>>2]=E;c[T+152080>>2]=E;E=B+5120|0;c[T+21012>>2]=E;c[T+86548>>2]=E;c[T+152084>>2]=E;E=B+6144|0;c[T+21016>>2]=E;c[T+86552>>2]=E;c[T+152088>>2]=E;E=B+7168|0;c[T+21020>>2]=E;c[T+86556>>2]=E;c[T+152092>>2]=E;E=c[3529418]|0;c[T+21024>>2]=E;c[T+86560>>2]=E;c[T+152096>>2]=E;B=E+1024|0;c[T+21028>>2]=B;c[T+86564>>2]=B;c[T+152100>>2]=B;B=E+2048|0;c[T+21032>>2]=B;c[T+86568>>2]=B;c[T+152104>>2]=B;B=E+3072|0;c[T+21036>>2]=B;c[T+86572>>2]=B;c[T+152108>>2]=B;B=E+4096|0;c[T+21040>>2]=B;c[T+86576>>2]=B;c[T+152112>>2]=B;B=E+5120|0;c[T+21044>>2]=B;c[T+86580>>2]=B;c[T+152116>>2]=B;B=E+6144|0;c[T+21048>>2]=B;c[T+86584>>2]=B;c[T+152120>>2]=B;B=E+7168|0;c[T+21052>>2]=B;c[T+86588>>2]=B;c[T+152124>>2]=B;c[T+196648>>2]=2010;c[T+196728>>2]=2418;c[T+196608>>2]=1822;c[T+196688>>2]=1906}B=c[3532592]|0;if((B|0)!=0){gGC(B|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);B=c[2439330]|0;E=(B|0)==0;if(!E){y=B;gGC(9706056,y|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];y=c[3528484]|0;c[2076596]=y;G=c[2417276]|0;c[3541536]=G;c[1836236]=0;L=c[2385892]|0;if((g|0)==0){H=0;F=0;while(1){c[B+76+(F<<2)>>2]=L+(F<<8);O=H+1&65535;if((O&65535)>223){U=0;V=0;break}else{H=O;F=O&65535}}while(1){F=L+(V<<8)|0;c[B+76+(V+512<<2)>>2]=F;c[B+76+(V+768<<2)>>2]=F;F=U+1&65535;if((F&65535)>223){break}else{U=F;V=F&65535}}F=c[2386046]|0;c[B+972>>2]=F;H=F+256|0;c[B+976>>2]=H;O=F+512|0;c[B+980>>2]=O;M=F+768|0;c[B+984>>2]=M;P=F+1024|0;c[B+988>>2]=P;I=F+1280|0;c[B+992>>2]=I;N=F+1536|0;c[B+996>>2]=N;Q=F+1792|0;c[B+1e3>>2]=Q;c[B+1996>>2]=F;c[B+2e3>>2]=H;c[B+2004>>2]=O;c[B+2008>>2]=M;c[B+2012>>2]=P;c[B+2016>>2]=I;c[B+2020>>2]=N;c[B+2024>>2]=Q;c[B+3020>>2]=F;c[B+4044>>2]=F;c[B+3024>>2]=H;c[B+4048>>2]=H;c[B+3028>>2]=O;c[B+4052>>2]=O;c[B+3032>>2]=M;c[B+4056>>2]=M;c[B+3036>>2]=P;c[B+4060>>2]=P;c[B+3040>>2]=I;c[B+4064>>2]=I;c[B+3044>>2]=N;c[B+4068>>2]=N;c[B+3048>>2]=Q;c[B+4072>>2]=Q}else{Q=0;N=0;while(1){c[B+76+(N<<2)>>2]=L+(N<<8);I=Q+1&65535;if((I&65535)>247){W=0;X=0;break}else{Q=I;N=I&65535}}while(1){N=L+(X<<8)|0;c[B+76+(X+512<<2)>>2]=N;c[B+76+(X+768<<2)>>2]=N;N=W+1&65535;if((N&65535)>247){break}else{W=N;X=N&65535}}L=c[2386046]|0;c[B+1068>>2]=L;N=L+256|0;c[B+1072>>2]=N;Q=L+512|0;c[B+1076>>2]=Q;I=L+768|0;c[B+1080>>2]=I;P=L+1024|0;c[B+1084>>2]=P;M=L+1280|0;c[B+1088>>2]=M;O=L+1536|0;c[B+1092>>2]=O;H=L+1792|0;c[B+1096>>2]=H;c[B+2092>>2]=L;c[B+2096>>2]=N;c[B+2100>>2]=Q;c[B+2104>>2]=I;c[B+2108>>2]=P;c[B+2112>>2]=M;c[B+2116>>2]=O;c[B+2120>>2]=H;c[B+3116>>2]=L;c[B+4140>>2]=L;c[B+3120>>2]=N;c[B+4144>>2]=N;c[B+3124>>2]=Q;c[B+4148>>2]=Q;c[B+3128>>2]=I;c[B+4152>>2]=I;c[B+3132>>2]=P;c[B+4156>>2]=P;c[B+3136>>2]=M;c[B+4160>>2]=M;c[B+3140>>2]=O;c[B+4164>>2]=O;c[B+3144>>2]=H;c[B+4168>>2]=H}c[B+4172>>2]=184;c[B+4176>>2]=2330;if(!E){H=B;gGC(H|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=y;c[2417276]=G;c[1836236]=-1;UL(4e6,2894,1406,0);c[2438224]=4e6;c[2433522]=3416;c[2406672]=1752;c[3528468]=9362;c[2443842]=511;h[745398]=1.0;a[3203264]=1;Ux(0,7575,1);c[2407030]=256;c[2407068]=3;H=c[642608+(c[2436]<<2)>>2]|0;O=c[H+128>>2]|0;if((c[H+52>>2]&4|0)==0){c[2113068]=O;M=c[H+132>>2]|0;c[2113070]=M;c[2443814]=O;c[2440436]=M;Y=O;Z=M}else{c[2113070]=O;M=c[H+132>>2]|0;c[2113068]=M;c[2440436]=O;c[2443814]=M;Y=M;Z=O}O=ag(Y<<1,Z)|0;M=gGq(O)|0;c[2112926]=M;if((M|0)!=0){gGz(M|0,0,O|0)}a[9623872]=0;O=c[2414620]|0;gGz(O|0,0,(c[2411580]|0)-O|0);a[9760896]=7;a[14112960]=0;a[14114504]=0;a[9620384]=0;a[14120968]=0;c[3541206]=c[2386616];if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];O=c[3532592]|0;if((O|0)!=0){gGC(9104152,O|0,280)|0}c[2113054]=c[2113060]}RI();O=c[2394]|0;M=c[14130368+(O<<2)>>2]|0;if((M|0)!=0){gGC(M|0,9104152,280)|0}c[8452240+(O<<2)>>2]=c[2113054];c[2394]=-1;O=c[2439330]|0;M=(O|0)==0;if(!M){H=O;gGC(9706056,H|0,76)|0}H=c[2438118]|0;c[2433530]=H;P=c[3528484]|0;c[2076596]=P;I=c[2417276]|0;c[3541536]=I;c[1836236]=0;gGz(9706056,0,76);if(!M){M=O;gGC(M|0,9706056,76)|0}c[2438118]=H;c[3528484]=P;c[2417276]=I;c[1836236]=-1;c[2113156]=0;a[9628264]=0;c[2407033]=0;I=c[3541206]|0;c[3541190]=I;c[3541198]=I;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=I+256;c[3541199]=I+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=I+512;c[3541200]=I+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=I+768;c[3541201]=I+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;lw(c[3540984]|0);C=0;i=j;return C|0}}while(0);c[2414918]=0;C=1;i=j;return C|0}function ewD(b,c){b=b|0;c=c|0;a[9706117]=(c|0)!=0|0;return}function ewE(a){a=a|0;var b=0,d=0;b=(c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,4e6,0)|0;return a|0}function ewF(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;a=c[2386422]|0;b=c[2112926]|0;d=c[3530562]|0;f=0;do{g=e[a+((f|2)<<1)>>1]|0;h=g&511;i=e[a+(f<<1)>>1]|0;j=e[a+((f|1)<<1)>>1]|0;k=g>>>9&15;l=1<<(i>>>9&3);if((l|0)>0){m=j-1+l|0;n=(i&8192|0)==0;o=h>>>0<497;p=g|-512;if((i&16384|0)==0){g=0;do{q=248-((l-g<<4)+i&511)|0;r=g+j|0;if(n){SH(b,r,h,q,k,5,0,512,d);s=0}else{SJ(b,r,h,q,k,5,0,512,d);s=1}do{if(!o){if(s){SJ(b,r,p,q,k,5,0,512,d);break}else{SH(b,r,p,q,k,5,0,512,d);break}}}while(0);g=g+1|0;}while((g|0)<(l|0))}else{g=0;do{j=248-((l-g<<4)+i&511)|0;q=m-g|0;if(n){SL(b,q,h,j,k,5,0,512,d);t=0}else{SN(b,q,h,j,k,5,0,512,d);t=1}do{if(!o){if(t){SN(b,q,p,j,k,5,0,512,d);break}else{SL(b,q,p,j,k,5,0,512,d);break}}}while(0);g=g+1|0;}while((g|0)<(l|0))}}f=f+4|0;}while((f|0)<1024);return}function ewG(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;a=c[2387956]|0;d=c[2113068]|0;e=c[2112926]|0;f=0;g=0;h=0;while(1){i=ag(d,h-9|0)|0;j=f;k=0;l=0;while(1){m=a+((j&65535)<<1)|0;n=b[m>>1]|0;do{if(n<<16>>16!=0){o=(l<<2)-12+i|0;p=(n&65535)>>>12;if((p|0)==0){q=n}else{b[e+(o<<1)>>1]=(p|768)&65535;q=b[m>>1]|0}p=(q&65535)>>>8&15;if((p|0)==0){r=q}else{b[e+((o|1)<<1)>>1]=(p|768)&65535;r=b[m>>1]|0}p=(r&65535)>>>4&15;if((p|0)==0){s=r}else{b[e+((o|2)<<1)>>1]=(p|768)&65535;s=b[m>>1]|0}p=s&15;if((p|0)==0){break}b[e+((o|3)<<1)>>1]=(p|768)&65535}}while(0);m=k+1&65535;if((m&65535)<128){j=j+1&65535;k=m;l=m&65535}else{break}}l=g+1&65535;if((l&65535)<256){f=f+128&65535;g=l;h=l&65535}else{break}}return}function ewH(b){b=b|0;var d=0;L10310:do{if(b>>>0<16776960){d=0}else{switch(b|0){case 16777090:case 16777091:{d=(e[4817269]|0)>>>((b<<3&8^8)>>>0)&255;break L10310;break};case 16777088:case 16777089:{d=(e[4817268]|0)>>>((b<<3&8^8)>>>0)&255;break L10310;break};case 16777092:case 16777093:{d=(e[4817270]|0)>>>((b<<3&8^8)>>>0)&255;break L10310;break};case 16777095:{d=a[9657912]|0;break L10310;break};case 16777097:{d=a[9657913]|0;break L10310;break};case 16777099:{d=a[9657914]|0;break L10310;break};case 16777103:{d=a[9657915]|0;break L10310;break};case 16777120:case 16777121:{d=(e[4817271]|0)>>>((b<<3&8^8)>>>0)&255;break L10310;break};case 16777122:case 16777123:{d=(e[4817272]|0)>>>((b<<3&8^8)>>>0)&255;break L10310;break};case 16777185:{d=a[c[2433506]|0]|0;break L10310;break};default:{d=0;break L10310}}}}while(0);return d|0}function ewI(a){a=a|0;var c=0;L10325:do{if(a>>>0<16776960){c=0}else{switch(a|0){case 16777090:{c=b[4817269]|0;break L10325;break};case 16777092:{c=b[4817270]|0;break L10325;break};case 16777088:{c=b[4817268]|0;break L10325;break};case 16777120:{c=b[4817271]|0;break L10325;break};case 16777122:{c=b[4817272]|0;break L10325;break};default:{c=0;break L10325}}}}while(0);return c|0}function ewJ(d,e){d=d|0;e=e|0;var f=0,g=0,h=0;if((d&16773120|0)==16760832){f=c[2387148]|0;a[f+(d&4095^1)|0]=e;g=d&4094;h=b[f+g>>1]|0;c[(c[3529950]|0)+(g>>>1<<2)>>2]=((h&65535)>>>10<<3&248)<<8|((h&255)<<3&255)>>>3|(((h&65535)>>>5<<3&255|(h&65535)>>>7&4)&255)<<3&2016;return}if(d>>>0<16776960){return}switch(d|0){case 16776968:case 16776969:case 16776970:case 16776971:case 16776972:case 16776973:case 16776974:case 16776975:{a[(c[2430244]|0)+(d&7)|0]=e;return};case 16777024:case 16777025:case 16777026:case 16777027:case 16777028:case 16777029:case 16777030:case 16777031:{a[(c[2429584]|0)+(d&7)|0]=e;return};case 16777153:{d=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;h=a[6517960]|0;g=gGU(d,(d|0)<0|0?-1:0,h?83333:0,h?0:0)|0;h=c[2440516]|0;d=gGS(g,K,h,(h|0)<0|0?-1:0)|0;if((d|0)<=((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)){return}Sb(d);a[c[2433506]|0]=1;a[c[3528238]|0]=e;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12;return};default:{return}}}function ewK(a,d){a=a|0;d=d|0;var e=0;if((a&16773120|0)==16760832){e=a&4094;b[(c[2387148]|0)+e>>1]=d;c[(c[3529950]|0)+(e>>>1<<2)>>2]=((d&65535)>>>10<<3&248)<<8|((d&255)<<3&255)>>>3|(((d&65535)>>>5<<3&255|(d&65535)>>>7&4)&255)<<3&2016;return}if(a>>>0<16776960){return}switch(a|0){case 16776968:case 16776970:case 16776972:case 16776974:{b[(c[2430244]|0)+(a&6)>>1]=d;return};case 16777024:case 16777026:case 16777028:case 16777030:{b[(c[2429584]|0)+(a&6)>>1]=d;return};default:{return}}}function ewL(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=b&65535;switch(f&255|0){case 4:{b=c[2443930]|0;if((d[b]|0|0)==(e&3|0)){return}g=e&3;a[b]=g;h=c[2385890]|0;i=c[9757320+(c[1836236]<<2)>>2]|0;j=((g&255)<<15)-32768|0;g=128;k=128;while(1){c[i+76+(k<<2)>>2]=h+(j+(k<<8));l=g+1&65535;if((l&65535)>255){break}else{g=l;k=l&65535}}k=((d[b]|0)<<15)-32768|0;b=128;g=128;while(1){j=h+(k+(g<<8))|0;c[i+76+(g+512<<2)>>2]=j;c[i+76+(g+768<<2)>>2]=j;j=b+1&65535;if((j&65535)>255){break}else{b=j;g=j&65535}}return};case 0:case 1:case 2:case 3:{l7(f&3,e);return};case 8:{a[c[2433506]|0]=0;return};default:{return}}}function ewM(b){b=b|0;var d=0,e=0,f=0.0,g=0.0,i=0,j=0,k=0;d=b&255;if((d|0)==0){b=c[3541514]|0;e=b+552|0;f=+h[e>>3];do{if(f!=0.0){g=+h[6675];if(f-(g+ +gC[c[2429842]&255]())>0.0){i=a[b+563|0]|-128;break}else{h[e>>3]=0.0;j=7602;break}}else{j=7602}}while(0);if((j|0)==7602){i=a[b+563|0]|0}k=i&-125;return k|0}else if((d|0)==2){k=a[(c[3541514]|0)+20904|0]|0;return k|0}else if((d|0)==12){k=a[c[3528238]|0]|0;return k|0}else{k=0;return k|0}return 0}function ewN(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2177172+(b*112|0)>>2];c[a+104>>2]=c[2177176+(b*112|0)>>2];c[a+108>>2]=c[2177180+(b*112|0)>>2];d=0;return d|0}function ewO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=2177072+(b*112|0);e=0;return e|0}function ewP(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>24){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1183416+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function ewQ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>86){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3328768+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function ewR(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;e=i;i=i+1096|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1088|0;c[2414916]=0;c[2388112]=0;c[2385890]=1048576;c[3530796]=1179648;c[3530560]=13762560;c[3529748]=17956864;c[3529704]=19005440;c[3529950]=21102592;c[2414618]=21110784;c[2388240]=21110784;c[2387148]=21176320;c[2406560]=21180416;c[3529652]=21196800;c[3529632]=21204992;c[2443468]=21270528;c[3527280]=21271552;c[3527276]=21279744;c[3527278]=21345280;c[3527274]=21353472;c[2430244]=21419008;c[2429584]=21419024;c[2433506]=21419040;c[3528238]=21419041;c[2443930]=21419042;c[2386044]=21419043;c[2411578]=21421091;B=0;while(1){if((B|0)>=1024){break}C=9638528+(B<<2)|0;if((c[C>>2]|0)==0){D=7640;break}else{B=B+1|0}}do{if((D|0)==7640){B=gGq(21421091)|0;c[C>>2]=B;if((B|0)==0){break}c[2414916]=B;gGz(B|0,0,21421091);c[2388112]=B;c[2385890]=B+1048576;c[3530796]=B+1179648;c[3530560]=B+13762560;c[3529748]=B+17956864;c[3529704]=B+19005440;c[3529950]=B+21102592;E=B+21110784|0;c[2414618]=E;c[2388240]=E;c[2387148]=B+21176320;c[2406560]=B+21180416;c[3529652]=B+21196800;c[3529632]=B+21204992;c[2443468]=B+21270528;c[3527280]=B+21271552;c[3527276]=B+21279744;c[3527278]=B+21345280;c[3527274]=B+21353472;c[2430244]=B+21419008;c[2429584]=B+21419024;c[2433506]=B+21419040;c[3528238]=B+21419041;c[2443930]=B+21419042;c[2386044]=B+21419043;E=B+21421091|0;c[2411578]=E;c[2414118]=E;if((c[3542200]|0)==0){F=1;i=e;return F|0}E=x+108|0;c[E>>2]=0;G=x+100|0;c[G>>2]=0;H=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[H&16383](x,0)|0;do{if((c[E>>2]|0)!=0){H=c[G>>2]|0;c[y>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](y,0,0)|0;if((H|0)<1){F=1;i=e;return F|0}if((gzL(B,0,0)|0)==0){break}else{F=1}i=e;return F|0}}while(0);B=(c[2388112]|0)+524288|0;if((c[3542200]|0)==0){F=1;i=e;return F|0}G=v+108|0;c[G>>2]=0;E=v+100|0;c[E>>2]=0;H=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[H&16383](v,1)|0;do{if((c[G>>2]|0)!=0){H=c[E>>2]|0;c[w>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](w,1,0)|0;if((H|0)<1){F=1;i=e;return F|0}if((gzL(B,0,1)|0)==0){break}else{F=1}i=e;return F|0}}while(0);B=c[2385890]|0;if((c[3542200]|0)==0){F=1;i=e;return F|0}E=t+108|0;c[E>>2]=0;G=t+100|0;c[G>>2]=0;H=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[H&16383](t,2)|0;do{if((c[E>>2]|0)!=0){H=c[G>>2]|0;c[u>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](u,2,0)|0;if((H|0)<1){F=1;i=e;return F|0}if((gzL(B,0,2)|0)==0){break}else{F=1}i=e;return F|0}}while(0);B=c[3530796]|0;if((c[3542200]|0)==0){F=1;i=e;return F|0}G=r+108|0;c[G>>2]=0;E=r+100|0;c[E>>2]=0;H=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[H&16383](r,3)|0;do{if((c[G>>2]|0)!=0){H=c[E>>2]|0;c[s>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](s,3,0)|0;if((H|0)<1){F=1;i=e;return F|0}if((gzL(B,0,3)|0)==0){break}else{F=1}i=e;return F|0}}while(0);B=(c[3530796]|0)+2097152|0;if((c[3542200]|0)==0){F=1;i=e;return F|0}E=p+108|0;c[E>>2]=0;G=p+100|0;c[G>>2]=0;H=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[H&16383](p,4)|0;do{if((c[E>>2]|0)!=0){H=c[G>>2]|0;c[q>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](q,4,0)|0;if((H|0)<1){F=1;i=e;return F|0}if((gzL(B,0,4)|0)==0){break}else{F=1}i=e;return F|0}}while(0);B=(c[3530796]|0)+4194304|0;if((c[3542200]|0)==0){F=1;i=e;return F|0}G=n+108|0;c[G>>2]=0;E=n+100|0;c[E>>2]=0;H=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[H&16383](n,5)|0;do{if((c[G>>2]|0)!=0){H=c[E>>2]|0;c[o>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](o,5,0)|0;if((H|0)<1){F=1;i=e;return F|0}if((gzL(B,0,5)|0)==0){break}else{F=1}i=e;return F|0}}while(0);B=c[3530560]|0;if((c[3542200]|0)==0){F=1;i=e;return F|0}E=l+108|0;c[E>>2]=0;G=l+100|0;c[G>>2]=0;H=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[H&16383](l,6)|0;do{if((c[E>>2]|0)!=0){H=c[G>>2]|0;c[m>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](m,6,0)|0;if((H|0)<1){F=1;i=e;return F|0}if((gzL(B,0,6)|0)==0){break}else{F=1}i=e;return F|0}}while(0);B=c[3529748]|0;if((c[3542200]|0)==0){F=1;i=e;return F|0}G=j+108|0;c[G>>2]=0;E=j+100|0;c[E>>2]=0;H=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[H&16383](j,7)|0;do{if((c[G>>2]|0)!=0){H=c[E>>2]|0;c[k>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](k,7,0)|0;if((H|0)<1){F=1;i=e;return F|0}if((gzL(B,0,7)|0)==0){break}else{F=1}i=e;return F|0}}while(0);B=c[3529704]|0;if((c[3542200]|0)==0){F=1;i=e;return F|0}E=f+108|0;c[E>>2]=0;G=f+100|0;c[G>>2]=0;H=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[H&16383](f,8)|0;do{if((c[E>>2]|0)==0){J=0}else{H=c[G>>2]|0;c[g>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](g,8,0)|0;if((H|0)<1){F=1;i=e;return F|0}if((gzL(B,0,8)|0)==0){J=0;break}else{F=1}i=e;return F|0}}while(0);while(1){if((J|0)>=1024){break}K=9638528+(J<<2)|0;if((c[K>>2]|0)==0){D=7680;break}else{J=J+1|0}}L10532:do{if((D|0)==7680){B=gGq(6291456)|0;c[K>>2]=B;if((B|0)==0){break}gGz(B|0,0,6291456);G=c[3530796]|0;gGC(B|0,G|0,6291456)|0;E=0;do{H=E<<8;gGz(G+H|0,0,256);I=E<<10;L=0;do{M=1<<3-L;N=(c[703416+(L<<2)>>2]|0)+I|0;O=0;do{P=N+(c[611904+(O<<2)>>2]|0)|0;Q=(O<<4)+H|0;R=0;do{S=P+(c[612512+(R<<2)>>2]|0)|0;if(((d[B+((S|0)/8|0)|0]|0)&128>>>((S&7)>>>0)|0)!=0){S=G+(Q+R)|0;a[S]=(d[S]|0|M)&255}R=R+1|0;}while((R|0)<16);O=O+1|0;}while((O|0)<16);L=L+1|0;}while((L|0)<4);E=E+1|0;}while((E|0)<49152);E=c[3530560]|0;gGC(B|0,E|0,2097152)|0;G=0;while(1){L=G<<8;gGz(E+L|0,0,256);H=G<<10;I=0;do{O=1<<3-I;M=(c[703416+(I<<2)>>2]|0)+H|0;N=0;do{R=M+(c[611904+(N<<2)>>2]|0)|0;Q=(N<<4)+L|0;P=0;do{S=R+(c[612512+(P<<2)>>2]|0)|0;if(((d[B+((S|0)/8|0)|0]|0)&128>>>((S&7)>>>0)|0)!=0){S=E+(Q+P)|0;a[S]=(d[S]|0|O)&255}P=P+1|0;}while((P|0)<16);N=N+1|0;}while((N|0)<16);I=I+1|0;}while((I|0)<4);I=G+1|0;if((I|0)<16384){G=I}else{T=0;break}}while(1){if((T|0)>=1024){break L10532}U=9638528+(T<<2)|0;if((c[U>>2]|0)==(B|0)){break}else{T=T+1|0}}gGr(B);c[U>>2]=0}}while(0);fxU(0,425984);if((c[2394]|0)==0){V=c[2112932]|0}else{c[2394]=0;G=c[3532596]|0;c[2112932]=G;E=c[3532592]|0;if((E|0)!=0){gGC(9104152,E|0,280)|0}c[2113054]=c[2113060];V=G}G=c[2388112]|0;E=V|0;I=0;while(1){L=G+I|0;c[E>>2]=L;c[E+131072>>2]=L;L=I+1024|0;if(L>>>0>1048575){break}else{E=E+4|0;I=L}}I=c[2406560]|0;c[V+32768>>2]=I;c[V+98304>>2]=I;c[V+163840>>2]=I;E=I+1024|0;c[V+32772>>2]=E;c[V+98308>>2]=E;c[V+163844>>2]=E;E=I+2048|0;c[V+32776>>2]=E;c[V+98312>>2]=E;c[V+163848>>2]=E;E=I+3072|0;c[V+32780>>2]=E;c[V+98316>>2]=E;c[V+163852>>2]=E;E=I+4096|0;c[V+32784>>2]=E;c[V+98320>>2]=E;c[V+163856>>2]=E;E=I+5120|0;c[V+32788>>2]=E;c[V+98324>>2]=E;c[V+163860>>2]=E;E=I+6144|0;c[V+32792>>2]=E;c[V+98328>>2]=E;c[V+163864>>2]=E;E=I+7168|0;c[V+32796>>2]=E;c[V+98332>>2]=E;c[V+163868>>2]=E;E=I+8192|0;c[V+32800>>2]=E;c[V+98336>>2]=E;c[V+163872>>2]=E;E=I+9216|0;c[V+32804>>2]=E;c[V+98340>>2]=E;c[V+163876>>2]=E;E=I+10240|0;c[V+32808>>2]=E;c[V+98344>>2]=E;c[V+163880>>2]=E;E=I+11264|0;c[V+32812>>2]=E;c[V+98348>>2]=E;c[V+163884>>2]=E;E=I+12288|0;c[V+32816>>2]=E;c[V+98352>>2]=E;c[V+163888>>2]=E;E=I+13312|0;c[V+32820>>2]=E;c[V+98356>>2]=E;c[V+163892>>2]=E;E=I+14336|0;c[V+32824>>2]=E;c[V+98360>>2]=E;c[V+163896>>2]=E;E=I+15360|0;c[V+32828>>2]=E;c[V+98364>>2]=E;c[V+163900>>2]=E;E=c[3529652]|0;c[V+40960>>2]=E;c[V+106496>>2]=E;c[V+172032>>2]=E;I=E+1024|0;c[V+40964>>2]=I;c[V+106500>>2]=I;c[V+172036>>2]=I;I=E+2048|0;c[V+40968>>2]=I;c[V+106504>>2]=I;c[V+172040>>2]=I;I=E+3072|0;c[V+40972>>2]=I;c[V+106508>>2]=I;c[V+172044>>2]=I;I=E+4096|0;c[V+40976>>2]=I;c[V+106512>>2]=I;c[V+172048>>2]=I;I=E+5120|0;c[V+40980>>2]=I;c[V+106516>>2]=I;c[V+172052>>2]=I;I=E+6144|0;c[V+40984>>2]=I;c[V+106520>>2]=I;c[V+172056>>2]=I;I=E+7168|0;c[V+40988>>2]=I;c[V+106524>>2]=I;c[V+172060>>2]=I;I=c[3529632]|0;E=V+49152|0;G=12582912;while(1){L=I+(G-12582912)|0;c[E>>2]=L;c[E+65536>>2]=L;c[E+131072>>2]=L;L=G+1024|0;if(L>>>0>12648447){break}else{E=E+4|0;G=L}}G=c[2388240]|0;E=V+65024|0;I=16646144;while(1){L=G+(I-16646144)|0;c[E>>2]=L;c[E+65536>>2]=L;c[E+131072>>2]=L;L=I+1024|0;if(L>>>0>16711679){break}else{E=E+4|0;I=L}}I=c[2387148]|0;c[V+65472>>2]=I;c[V+196544>>2]=I;E=I+1024|0;c[V+65476>>2]=E;c[V+196548>>2]=E;E=I+2048|0;c[V+65480>>2]=E;c[V+196552>>2]=E;E=I+3072|0;c[V+65484>>2]=E;c[V+196556>>2]=E;E=c[2443468]|0;c[V+65504>>2]=E;c[V+131040>>2]=E;c[V+196576>>2]=E;c[V+196648>>2]=1228;c[V+196728>>2]=3026;c[V+196608>>2]=244;c[V+196688>>2]=86;E=c[3532592]|0;if((E|0)!=0){gGC(E|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);E=c[2439330]|0;I=(E|0)==0;if(!I){G=E;gGC(9706056,G|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];G=c[3528484]|0;c[2076596]=G;L=c[2417276]|0;c[3541536]=L;c[1836236]=0;H=c[2385890]|0;N=0;O=0;while(1){c[E+76+(O<<2)>>2]=H+(O<<8);M=N+1&65535;if((M&65535)>119){W=0;X=0;break}else{N=M;O=M&65535}}while(1){O=H+(X<<8)|0;c[E+76+(X+512<<2)>>2]=O;c[E+76+(X+768<<2)>>2]=O;O=W+1&65535;if((O&65535)>119){break}else{W=O;X=O&65535}}H=c[2386044]|0;c[E+556>>2]=H;O=H+256|0;c[E+560>>2]=O;N=H+512|0;c[E+564>>2]=N;M=H+768|0;c[E+568>>2]=M;P=H+1024|0;c[E+572>>2]=P;Q=H+1280|0;c[E+576>>2]=Q;R=H+1536|0;c[E+580>>2]=R;S=H+1792|0;c[E+584>>2]=S;c[E+1580>>2]=H;c[E+1584>>2]=O;c[E+1588>>2]=N;c[E+1592>>2]=M;c[E+1596>>2]=P;c[E+1600>>2]=Q;c[E+1604>>2]=R;c[E+1608>>2]=S;c[E+2604>>2]=H;c[E+3628>>2]=H;c[E+2608>>2]=O;c[E+3632>>2]=O;c[E+2612>>2]=N;c[E+3636>>2]=N;c[E+2616>>2]=M;c[E+3640>>2]=M;c[E+2620>>2]=P;c[E+3644>>2]=P;c[E+2624>>2]=Q;c[E+3648>>2]=Q;c[E+2628>>2]=R;c[E+3652>>2]=R;c[E+2632>>2]=S;c[E+3656>>2]=S;c[E+4172>>2]=1412;c[E+4176>>2]=1336;if(!I){S=E;gGC(S|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=G;c[2417276]=L;c[1836236]=-1;c[z>>2]=1048576;c[A>>2]=2097152;TW(c[3529704]|0,A,c[3529748]|0,z,1598,1560,20);c[2438228]=5e6;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=408;h[745406]=1.0;c[2436786]=1;h[745405]=1.0;c[2436784]=2;h[745404]=.25;a[3203280]=1;S=c[642608+(c[2436]<<2)>>2]|0;R=c[S+128>>2]|0;if((c[S+52>>2]&4|0)==0){c[2113068]=R;Q=c[S+132>>2]|0;c[2113070]=Q;c[2443814]=R;c[2440436]=Q;Y=R;Z=Q}else{c[2113070]=R;Q=c[S+132>>2]|0;c[2113068]=Q;c[2440436]=R;c[2443814]=Q;Y=Q;Z=R}R=ag(Y<<1,Z)|0;Q=gGq(R)|0;c[2112926]=Q;if((Q|0)!=0){gGz(Q|0,0,R|0)}a[9623856]=0;R=c[2414618]|0;gGz(R|0,0,(c[2411578]|0)-R|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];R=c[3532592]|0;if((R|0)!=0){gGC(9104152,R|0,280)|0}c[2113054]=c[2113060]}RI();R=c[2394]|0;Q=c[14130368+(R<<2)>>2]|0;if((Q|0)!=0){gGC(Q|0,9104152,280)|0}c[8452240+(R<<2)>>2]=c[2113054];c[2394]=-1;R=c[2439330]|0;if((R|0)!=0){Q=R;gGC(9706056,Q|0,76)|0}c[2433530]=c[2438118];Q=c[3528484]|0;c[2076596]=Q;S=c[2417276]|0;c[3541536]=S;c[1836236]=0;gGz(9706056,0,76);P=c[2443930]|0;a[P]=1;M=c[2385890]|0;N=128;O=128;while(1){c[R+76+(O<<2)>>2]=M+(O<<8);H=N+1&65535;if((H&65535)>255){break}else{N=H;O=H&65535}}O=((d[P]|0)<<15)-32768|0;N=128;L=128;while(1){G=M+(O+(L<<8))|0;c[R+76+(L+512<<2)>>2]=G;c[R+76+(L+768<<2)>>2]=G;G=N+1&65535;if((G&65535)>255){break}else{N=G;L=G&65535}}L=R;gGC(L|0,9706056,76)|0;c[2438118]=c[2433530];c[3528484]=Q;c[2417276]=S;c[1836236]=-1;F=0;i=e;return F|0}}while(0);c[2414916]=0;F=1;i=e;return F|0}function ewS(){var b=0,d=0,e=0,f=0,g=0;c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}b=c[3541514]|0;if((b|0)!=0){gGr(b|0);c[3541514]=0}c[2113008]=0;c[2076598]=0;c[2383582]=0;c[2438228]=0;c[2433526]=0;c[2406676]=0;c[3528472]=0;b=c[2406698]|0;if((b|0)!=0){gGr(b);c[2406698]=0}b=c[2385412]|0;if((b|0)!=0){gGr(b);c[2385412]=0}a[64232]=0;if((c[2392]|0)>=0){b=0;do{d=14130368+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}d=14130384+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}b=b+1|0;}while((b|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;fwZ();b=c[2414916]|0;d=0;while(1){if((d|0)>=1024){f=7791;break}g=9638528+(d<<2)|0;if((c[g>>2]|0)==(b|0)){break}else{d=d+1|0}}if((f|0)==7791){c[2414916]=0;return 0}gGr(b);c[g>>2]=0;c[2414916]=0;return 0}function ewT(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if((a[9623856]|0)!=0){a[9623856]=0;e=c[2414618]|0;gGz(e|0,0,(c[2411578]|0)-e|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060]}RI();e=c[2394]|0;f=c[14130368+(e<<2)>>2]|0;if((f|0)!=0){gGC(f|0,9104152,280)|0}c[8452240+(e<<2)>>2]=c[2113054];c[2394]=-1;e=c[2439330]|0;if((e|0)!=0){f=e;gGC(9706056,f|0,76)|0}c[2433530]=c[2438118];f=c[3528484]|0;c[2076596]=f;g=c[2417276]|0;c[3541536]=g;c[1836236]=0;gGz(9706056,0,76);h=c[2443930]|0;a[h]=1;i=c[2385890]|0;j=128;k=128;while(1){c[e+76+(k<<2)>>2]=i+(k<<8);l=j+1&65535;if((l&65535)>255){break}else{j=l;k=l&65535}}k=(d[h]<<15)-32768|0;h=128;j=128;while(1){l=i+(k+(j<<8))|0;c[e+76+(j+512<<2)>>2]=l;c[e+76+(j+768<<2)>>2]=l;l=h+1&65535;if((l&65535)>255){break}else{h=l;j=l&65535}}j=e;gGC(j|0,9706056,76)|0;c[2438118]=c[2433530];c[3528484]=f;c[2417276]=g;c[1836236]=-1}g=c[2392]|0;if((g|0)>=0){gGz(8452240,0,((g|0)>0?(g<<2)+4|0:4)|0)}c[2113054]=0;g=c[2385548]|0;if((g|0)>0){gGz(9752472,0,((g|0)>1?g<<2:4)|0)}c[2433530]=0;gGz(9634536,-1|0,10);g=0;f=-1;j=-1;e=-1;h=-1;k=-1;do{f=((a[9632976+g|0]&1)<<g^f&65535)&65535;j=((a[9630848+g|0]&1)<<g^j&65535)&65535;e=((a[9629360+g|0]&1)<<g^e&65535)&65535;h=((a[9628896+g|0]&1)<<g^h&65535)&65535;k=((a[9628704+g|0]&1)<<g^k&65535)&65535;g=g+1|0;}while((g|0)<8);b[4817268]=f;b[4817269]=j;b[4817270]=e;b[4817271]=h;b[4817272]=k;k=c[2438]|0;h=gGU(k,(k|0)<0|0?-1:0,16e6,0)|0;k=gGS(h,K,15360,0)|0;h=k;c[2440516]=h;a[6517960]=1;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];k=c[3532592]|0;if((k|0)!=0){gGC(9104152,k|0,280)|0}c[2113054]=c[2113060]}k=c[2439330]|0;if((k|0)!=0){e=k;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;c[2113056]=h;e=RG(h)|0;c[2113054]=(c[2113054]|0)+e;c[2276108]=-1;c[2113056]=-1;c[8452200+(c[2394]<<2)>>2]=8193;c[2276080]=256;if((c[2276079]|0)>>>0<256){RH(1)}e=a[6517960]|0?83333:0;h=gGU(e,0,2048e6,0)|0;k=c[2438228]|0;j=gGS(h,K,k,(k|0)<0|0?-1:0)|0;k=j;Sb(e);e=c[2443830]|0;if((e|0)<1073676288){c[2443830]=e-k}e=c[2443831]|0;if((e|0)<1073676288){c[2443831]=e-k}e=(c[3528512]|0)-k|0;c[3528512]=(e|0)<0?0:e;gg[c[3542118]&4095](c[2112964]|0,a[9688]|0?534:0);e=c[1836236]|0;k=c[9757320+(e<<2)>>2]|0;if((k|0)!=0){j=k;gGC(j|0,9706056,76)|0}c[9752472+(e<<2)>>2]=c[2433530];c[14113936+(e<<2)>>2]=c[2076596];c[9669104+(e<<2)>>2]=c[3541536];c[1836236]=-1;e=c[2394]|0;j=c[14130368+(e<<2)>>2]|0;if((j|0)!=0){gGC(j|0,9104152,280)|0}c[8452240+(e<<2)>>2]=c[2113054];c[2394]=-1;if((c[2112968]|0)==0){m=c[3527278]|0;n=c[3527280]|0;gGC(m|0,n|0,8192)|0;o=c[3527274]|0;p=c[3527276]|0;gGC(o|0,p|0,65536)|0;q=c[3529652]|0;gGC(n|0,q|0,8192)|0;r=c[3529632]|0;gGC(p|0,r|0,65536)|0;return 0}ewU()|0;m=c[3527278]|0;n=c[3527280]|0;gGC(m|0,n|0,8192)|0;o=c[3527274]|0;p=c[3527276]|0;gGC(o|0,p|0,65536)|0;q=c[3529652]|0;gGC(n|0,q|0,8192)|0;r=c[3529632]|0;gGC(p|0,r|0,65536)|0;return 0}function ewU(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;if((a[9547272]|0)!=0){f=c[2387148]|0;g=c[3529950]|0;h=0;do{i=b[f+h>>1]|0;c[g+(((h|0)/2|0)<<2)>>2]=((i&65535)>>>10<<3&248)<<8|((i&255)<<3&255)>>>3|(((i&65535)>>>5<<3&255|(i&65535)>>>7&4)&255)<<3&2016;h=h+2|0;}while((h|0)<4096)}h=c[2406560]|0;g=c[2443468]|0;f=c[2430244]|0;i=c[3530560]|0;j=c[2113068]|0;k=c[2112926]|0;l=0;do{m=l<<1;n=e[g+((m|1)<<1)>>1]|0;o=((e[g+(m<<1)>>1]|0)>>>4)+30|0;m=o>>>4;p=n>>>8<<6&4032;q=n&240;n=o&15;o=ag(j,l)|0;r=0;do{s=r+m|0;t=b[h+((s&63|p|s<<6&4096)<<1)>>1]|0;s=t&65535;u=(t&65535)>>>12<<4;t=(d[f+(s>>>9&7)|0]<<9|s&511)<<8|q;s=(r<<4)-n|0;v=0;do{w=v+s|0;if((w|0)>=0&(w|0)<(j|0)){b[k+(o+w<<1)>>1]=u|d[i+(v+t)|0]|768}v=v+1|0;}while((v|0)<16);r=r+1|0;}while((r|0)<21);l=l+1|0;}while((l|0)<224);l=c[3527278]|0;i=l+8192|0;j=l;l=c[3527274]|0;f=c[2429584]|0;h=c[3530796]|0;g=j;while(1){r=b[g>>1]|0;if(r<<16>>16==16384){x=7865;break}o=(r&65535)<<2&4092;r=e[j+(o<<1)>>1]|0;n=r>>>12;q=e[j+((o|1)<<1)>>1]|0;p=q>>>12;m=r>>>9&7;v=q>>>9&7;t=e[j+((o|2)<<1)>>1]|0;u=t>>>8&31;s=e[j+((o|3)<<1)>>1]|0;o=((ag(v,p)|0)+2|0)>>>2;w=32-p|0;p=32-n|0;y=(t&32768|0)!=0;z=r+16+(((ag(m,n)|0)+2|0)>>>2)|0;n=(t&16384|0)!=0;t=q+16+o|0;o=v+1|0;q=s;s=0;while(1){r=(z+((ag(y?m-s|0:s,p)|0)/2|0)&511)-16|0;if(y){A=q;B=0;while(1){C=b[l+((A&32767)<<1)>>1]|0;D=C&65535;if((C&65535)>16383){E=d[f+(D>>>11&7)|0]<<11|D&2047}else{E=D}D=(((ag(n?v-B|0:B,w)|0)/2|0)+t&511)-16|0;if(n){SN(k,E,D,r,u,4,15,0,h)}else{SL(k,E,D,r,u,4,15,0,h)}D=B+1|0;if((D|0)>(v|0)){break}else{A=A+1|0;B=D}}}else{if(n){B=q;A=0;while(1){D=b[l+((B&32767)<<1)>>1]|0;C=D&65535;if((D&65535)>16383){F=d[f+(C>>>11&7)|0]<<11|C&2047}else{F=C}SJ(k,F,(((ag(v-A|0,w)|0)/2|0)+t&511)-16|0,r,u,4,15,0,h);C=A+1|0;if((C|0)>(v|0)){break}else{B=B+1|0;A=C}}}else{A=q;B=0;while(1){C=b[l+((A&32767)<<1)>>1]|0;D=C&65535;if((C&65535)>16383){G=d[f+(D>>>11&7)|0]<<11|D&2047}else{G=D}SH(k,G,(((ag(B,w)|0)/2|0)+t&511)-16|0,r,u,4,15,0,h);D=B+1|0;if((D|0)>(v|0)){break}else{A=A+1|0;B=D}}}}B=s+1|0;if((B|0)>(m|0)){break}else{q=o+q|0;s=B}}s=g+2|0;if(s>>>0<i>>>0){g=s}else{x=7866;break}}if((x|0)==7865){H=c[3529950]|0;R8(H);return 0}else if((x|0)==7866){H=c[3529950]|0;R8(H);return 0}return 0}function ewV(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=i;i=i+64|0;h=g|0;j=g+16|0;k=g+32|0;l=g+48|0;if((f|0)!=0){c[f>>2]=169624}if((e&32|0)!=0){gGz(l|0,0,12);m=c[2414618]|0;c[l>>2]=m;c[l+4>>2]=(c[2411578]|0)-m;c[l+12>>2]=162152;m=c[2076592]|0;gj[m&4095](l)|0}if((e&64|0)!=0){l=k|0;gGz(j|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){m=k+9|0;k=h;n=h|0;o=h+4|0;p=h+12|0;q=j|0;r=j+4|0;s=j+12|0;t=0;do{gGC(l|0,614896,11)|0;a[m]=t+48&255;u=8452256+(t<<2)|0;gGz(k|0,0,12);c[n>>2]=u;c[o>>2]=4;c[p>>2]=164976;gj[c[2076592]&4095](h)|0;if((c[u>>2]|0)!=0){c[q>>2]=c[14130368+(t<<2)>>2];c[r>>2]=c[8452184+(t<<2)>>2];c[s>>2]=l;u=c[2076592]|0;gj[u&4095](j)|0}t=t+1|0;}while((t|0)<=(c[2392]|0))}fw$(e);T0(e,f)}f=c[2439330]|0;if((f|0)!=0){e=f;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];e=c[3528484]|0;c[2076596]=e;t=c[2417276]|0;c[3541536]=t;c[1836236]=0;j=c[2443930]|0;l=a[j]&3;a[j]=l;s=c[2385890]|0;r=((l&255)<<15)-32768|0;l=128;q=128;while(1){c[f+76+(q<<2)>>2]=s+(r+(q<<8));h=l+1&65535;if((h&65535)>255){break}else{l=h;q=h&65535}}q=((d[j]|0)<<15)-32768|0;j=128;l=128;while(1){r=s+(q+(l<<8))|0;c[f+76+(l+512<<2)>>2]=r;c[f+76+(l+768<<2)>>2]=r;r=j+1&65535;if((r&65535)>255){break}else{j=r;l=r&65535}}l=f;gGC(l|0,9706056,76)|0;c[2438118]=c[2433530];c[3528484]=e;c[2417276]=t;c[1836236]=-1;i=g;return 0}function ewW(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1382148+(b*112|0)>>2];c[a+104>>2]=c[1382152+(b*112|0)>>2];c[a+108>>2]=c[1382156+(b*112|0)>>2];d=0;return d|0}function ewX(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=1382048+(b*112|0);e=0;return e|0}function ewY(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>30){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=946920+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function ewZ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>86){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1665864+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function ew_(b,c){b=b|0;c=c|0;a[9706117]=(c|0)!=0|0;return}function ew$(a){a=a|0;var b=0,d=0;b=(c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,5e6,0)|0;return a|0}function ew0(){return+(+((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)/5.0e6)}function ew1(a){a=a|0;var c=0,d=0;c=a&-2;if((c|0)==5242880){d=b[4775160]|0}else if((c|0)==5242884){d=b[4775162]|0}else if((c|0)==5242882){d=b[4775161]|0}else{d=0}return d|0}function ew2(b){b=b|0;var c=0;switch(b|0){case 5242884:case 5242885:{c=(e[4775162]|0)>>>((b<<3&8^8)>>>0)&255;return c|0};case 5242880:case 5242881:{c=(e[4775160]|0)>>>((b<<3&8^8)>>>0)&255;return c|0};case 5242882:case 5242883:{c=(e[4775161]|0)>>>((b<<3&8^8)>>>0)&255;return c|0};case 5242905:{c=a[9747048]|0;return c|0};default:{c=0;return c|0}}return 0}function ew3(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;if((d&16773120|0)==5505024){f=c[2387146]|0;b[f+(d&4095)>>1]=e;g=d&4094;h=b[f+g>>1]|0;f=h&255;i=((f&255)>>>2&7|f<<3)&255;f=((h&65535)>>>5<<3&255|(h&65535)>>>7&7)&255;j=((h&65535)>>>10<<3&255|(h&65535)>>>12&7)&255;h=g>>>1;c[(c[2406920]|0)+(h<<2)>>2]=f<<8|j|i<<16;c[(c[3529948]|0)+(h<<2)>>2]=f<<3&2016|j>>>3|i<<8&63488;return}i=d&-2;if((i|0)==5242880){a[14112944]=e&255;return}else if((i|0)==5242882){a[14114728]=e&16;return}else{return}}function ew4(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;if((d&16773120|0)==5505024){f=c[2387146]|0;a[f+(d&4095)|0]=e;g=d&4094;h=b[f+g>>1]|0;f=h&255;i=((f&255)>>>2&7|f<<3)&255;f=((h&65535)>>>5<<3&255|(h&65535)>>>7&7)&255;j=((h&65535)>>>10<<3&255|(h&65535)>>>12&7)&255;h=g>>>1;c[(c[2406920]|0)+(h<<2)>>2]=f<<8|j|i<<16;c[(c[3529948]|0)+(h<<2)>>2]=f<<3&2016|j>>>3|i<<8&63488;return}switch(d|0){case 5242888:case 5242889:{d=e&255;if((d|0)==0){a[9747048]=a[9747048]^9;return}else if((d|0)==12){a[9747048]=a[9747048]^3;return}else if((d|0)==8){a[9747048]=a[9747048]^2;return}else{return}break};case 5242880:case 5242881:{a[14112944]=e;return};case 5242882:case 5242883:{a[14114728]=e&16;return};default:{return}}}function ew5(b,e){b=b|0;e=e|0;var f=0,g=0;f=b&65535;if((f|0)==49154|(f|0)==49155){b=e&255;if((f&1|0)==0){c[3542228]=b&15;return}g=c[3542228]|0;if((g|0)>15){return}do{if((g|0)<14){if((g|0)!=13){if((a[14168916+g|0]|0)==e<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(0,g,b);return}else if((f|0)==49152|(f|0)==49153){b=c[3540986]|0;if((f&1|0)==0){a[b+5885|0]=e;return}g=c[b+5876>>2]|0;if((g|0)!=0){gg[g&4095](c[b+5880>>2]|0,0)}lH(b,d[b+5885|0]|0,e&255);return}else if((f|0)==61440){a[9774864]=e;return}else{return}}function ew6(b){b=b|0;return(b<<16>>16==-2048?a[14112944]|0:0)|0}function ew7(a,d){a=a|0;d=d|0;var e=0;e=a&255;if((e|0)==2){US(2,gD[c[2385659]&8191]()|0);b[4771304]=~~(+(b[9732544+(((d&15)*17&255)<<1)>>1]|0)*+h[1192827])&65535;return}else if((e|0)==1){US(1,gD[c[2385651]&8191]()|0);b[4771288]=~~(+(b[9732544+(((d&15)*17&255)<<1)>>1]|0)*+h[1192823])&65535;return}else if((e|0)==0){US(0,gD[c[2385643]&8191]()|0);b[4771272]=~~(+(b[9732544+(((d&15)*17&255)<<1)>>1]|0)*+h[1192819])&65535;return}else if((e|0)==3){US(3,gD[c[2385667]&8191]()|0);b[4771320]=~~(+(b[9732544+(((d&15)*17&255)<<1)>>1]|0)*+h[1192831])&65535;return}else{return}}function ew8(b){b=b|0;return((b&255)==0?a[9774864]|0:0)|0}function ew9(a){a=a|0;var e=0,f=0;do{if((a&16773120|0)==5505024){if((a&512|0)==0){e=b[(c[2387146]|0)+(((d[14115224]|0)<<9)+a&4094)>>1]|0;break}else{e=b[(c[3530224]|0)+(a&4094)>>1]|0;break}}else{f=a&-2;if((f|0)==5242882){e=b[4775161]|0;break}else if((f|0)==5242880){e=b[4775160]|0;break}else if((f|0)==5242886){e=b[4775163]|0;break}else if((f|0)==5242884){e=b[4775162]|0;break}else{e=0;break}}}while(0);return e|0}function exa(b){b=b|0;var f=0;if((b&16773120|0)==5505024){if((b&512|0)==0){f=a[(c[2387146]|0)+(((d[14115224]|0)<<9)+b&4094)|0]|0;return f|0}else{f=a[(c[3530224]|0)+(b&4094)|0]|0;return f|0}}switch(b|0){case 5242886:case 5242887:{f=(e[4775163]|0)>>>((b<<3&8^8)>>>0)&255;return f|0};case 5242880:case 5242881:{f=(e[4775160]|0)>>>((b<<3&8^8)>>>0)&255;return f|0};case 5242882:case 5242883:{f=(e[4775161]|0)>>>((b<<3&8^8)>>>0)&255;return f|0};case 5242884:case 5242885:{f=(e[4775162]|0)>>>((b<<3&8^8)>>>0)&255;return f|0};default:{f=0;return f|0}}return 0}function exb(e,f){e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;if((e&16773120|0)==5505024){if((e&512|0)==0){g=((d[14115224]|0)<<9)+e&65535;b[(c[2387146]|0)+g>>1]=f;h=f&255;i=((h&255)>>>2&7|h<<3)&255;h=((f&65535)>>>5<<3&255|(f&65535)>>>7&7)&255;j=((f&65535)>>>10<<3&255|(f&65535)>>>12&7)&255;k=g>>>1;c[(c[2406920]|0)+(k<<2)>>2]=h<<8|j|i<<16;c[(c[3529948]|0)+(k<<2)>>2]=h<<3&2016|j>>>3|i<<8&63488;return}else{b[(c[3530224]|0)+(e&65535)>>1]=f;return}}i=e&-2;if((i|0)==5242882){a[14114728]=f&1;a[14115224]=(f&65535)>>>2&1;return}else if((i|0)==5242880){a[14112944]=f&255;return}else{return}}function exc(e,f){e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;if((e&16773120|0)==5505024){if((e&512|0)==0){g=((d[14115224]|0)<<9)+e|0;h=c[2387146]|0;a[h+(g&4095)|0]=f;i=g&4094;g=b[h+i>>1]|0;h=g&255;j=((h&255)>>>2&7|h<<3)&255;h=((g&65535)>>>5<<3&255|(g&65535)>>>7&7)&255;k=((g&65535)>>>10<<3&255|(g&65535)>>>12&7)&255;g=i>>>1;c[(c[2406920]|0)+(g<<2)>>2]=h<<8|k|j<<16;c[(c[3529948]|0)+(g<<2)>>2]=h<<3&2016|k>>>3|j<<8&63488;return}else{a[(c[3530224]|0)+(e&4095)|0]=f;return}}if((e|0)==5242882|(e|0)==5242883){a[14114728]=f&1;a[14115224]=(f&255)>>>2&1;return}else if((e|0)==5242880|(e|0)==5242881){a[14112944]=f;return}else{return}}function exd(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((e|0)==63488){c[2113304]=d&255;return}else if((e|0)==63489){b=c[2113304]|0;a[14168504+b|0]=d;mv(0,b,d&255);return}else if((e|0)==64512){a[9774864]=d;return}else{return}}function exe(a){a=a|0;var e=0,f=0;do{if((a&16773120|0)==2097152){if((a&512|0)==0){e=b[(c[2387146]|0)+(((d[14115224]|0)<<9)+a&4094)>>1]|0;break}else{e=b[(c[3530224]|0)+(a&4094)>>1]|0;break}}else{f=a&-2;if((f|0)==6291458){e=b[4775161]|0;break}else if((f|0)==6291460){e=b[4775162]|0;break}else if((f|0)==6291456){e=b[4775160]|0;break}else if((f|0)==6291462){e=b[4775163]|0;break}else{e=0;break}}}while(0);return e|0}function exf(b){b=b|0;var f=0;if((b&16773120|0)==2097152){if((b&512|0)==0){f=a[(c[2387146]|0)+(((d[14115224]|0)<<9)+b&4094)|0]|0;return f|0}else{f=a[(c[3530224]|0)+(b&4094)|0]|0;return f|0}}switch(b|0){case 6291460:case 6291461:{f=(e[4775162]|0)>>>((b<<3&8^8)>>>0)&255;return f|0};case 6291456:case 6291457:{f=(e[4775160]|0)>>>((b<<3&8^8)>>>0)&255;return f|0};case 6291458:case 6291459:{f=(e[4775161]|0)>>>((b<<3&8^8)>>>0)&255;return f|0};case 6291462:case 6291463:{f=(e[4775163]|0)>>>((b<<3&8^8)>>>0)&255;return f|0};default:{f=0;return f|0}}return 0}function exg(e,f){e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;if((e&16773120|0)==2097152){if((e&512|0)==0){g=((d[14115224]|0)<<9)+e&65535;b[(c[2387146]|0)+g>>1]=f;h=f&255;i=((h&255)>>>2&7|h<<3)&255;h=((f&65535)>>>5<<3&255|(f&65535)>>>7&7)&255;j=((f&65535)>>>10<<3&255|(f&65535)>>>12&7)&255;k=g>>>1;c[(c[2406920]|0)+(k<<2)>>2]=h<<8|j|i<<16;c[(c[3529948]|0)+(k<<2)>>2]=h<<3&2016|j>>>3|i<<8&63488;return}else{b[(c[3530224]|0)+(e&65535)>>1]=f;return}}i=e&-2;if((i|0)==6291456){a[14112944]=f&255;return}else if((i|0)==6291460){a[14114728]=f&1;a[14115224]=(f&65535)>>>2&1;return}else{return}}function exh(e,f){e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;if((e&16773120|0)==2097152){if((e&512|0)==0){g=((d[14115224]|0)<<9)+e|0;h=c[2387146]|0;a[h+(g&4095)|0]=f;i=g&4094;g=b[h+i>>1]|0;h=g&255;j=((h&255)>>>2&7|h<<3)&255;h=((g&65535)>>>5<<3&255|(g&65535)>>>7&7)&255;k=((g&65535)>>>10<<3&255|(g&65535)>>>12&7)&255;g=i>>>1;c[(c[2406920]|0)+(g<<2)>>2]=h<<8|k|j<<16;c[(c[3529948]|0)+(g<<2)>>2]=h<<3&2016|k>>>3|j<<8&63488;return}else{a[(c[3530224]|0)+(e&4095)|0]=f;return}}if((e|0)==6291456|(e|0)==6291457){a[14112944]=f;return}else if((e|0)==6291460|(e|0)==6291461){a[14114728]=f&1;a[14115224]=(f&255)>>>2&1;return}else{return}}function exi(d,e){d=d|0;e=e|0;var f=0,g=0,i=0,j=0,k=0,l=0;f=d&255;if((f|0)==1){US(1,gD[c[2385651]&8191]()|0);b[4771288]=~~(+(b[9732544+(((e&15)*17&255)<<1)>>1]|0)*+h[1192823])&65535;return}else if((f|0)==0){US(0,gD[c[2385643]&8191]()|0);b[4771272]=~~(+(b[9732544+(((e&15)*17&255)<<1)>>1]|0)*+h[1192819])&65535;return}else if((f|0)==3){a[9774672]=e;f=c[3529190]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;g=((e&255)<<16&65536|1024)-1024|0;e=4;i=4;while(1){c[d+76+(i<<2)>>2]=f+(g+(i<<8));j=e+1&65535;if((j&65535)>255){k=4;l=4;break}else{e=j;i=j&65535}}while(1){i=f+(g+(l<<8))|0;c[d+76+(l+512<<2)>>2]=i;c[d+76+(l+768<<2)>>2]=i;i=k+1&65535;if((i&65535)>255){break}else{k=i;l=i&65535}}return}else{return}}function exj(b){b=b|0;return((b&255)==0?a[9774864]|0:0)|0}function exk(a){a=a|0;var e=0;L11063:do{if((a&16773120|0)==4194304){if((a&512|0)==0){e=b[(c[2387146]|0)+(((d[14115224]|0)<<9)+a&4094)>>1]|0;break}else{e=b[(c[3530224]|0)+(a&4094)>>1]|0;break}}else{switch(a&-2|0){case 10485762:{e=b[4775161]|0;break L11063;break};case 10485768:{e=b[4775164]|0;break L11063;break};case 10485760:{e=b[4775160]|0;break L11063;break};case 10485764:{e=b[4775162]|0;break L11063;break};case 10485766:{e=b[4775163]|0;break L11063;break};case 10485770:{e=b[4775165]|0;break L11063;break};default:{e=0;break L11063}}}}while(0);return e|0}function exl(b){b=b|0;var f=0;if((b&16773120|0)==4194304){if((b&512|0)==0){f=a[(c[2387146]|0)+(((d[14115224]|0)<<9)+b&4094)|0]|0;return f|0}else{f=a[(c[3530224]|0)+(b&4094)|0]|0;return f|0}}switch(b|0){case 10485762:case 10485763:{f=(e[4775161]|0)>>>((b<<3&8^8)>>>0)&255;return f|0};case 10485760:case 10485761:{f=(e[4775160]|0)>>>((b<<3&8^8)>>>0)&255;return f|0};case 10485766:case 10485767:{f=(e[4775163]|0)>>>((b<<3&8^8)>>>0)&255;return f|0};case 10485768:case 10485769:{f=(e[4775164]|0)>>>((b<<3&8^8)>>>0)&255;return f|0};case 10485764:case 10485765:{f=(e[4775162]|0)>>>((b<<3&8^8)>>>0)&255;return f|0};case 10485770:case 10485771:{f=(e[4775165]|0)>>>((b<<3&8^8)>>>0)&255;return f|0};default:{f=0;return f|0}}return 0}function exm(e,f){e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;if((e&16773120|0)==4194304){if((e&512|0)==0){g=((d[14115224]|0)<<9)+e&65535;b[(c[2387146]|0)+g>>1]=f;h=f&255;i=((h&255)>>>2&7|h<<3)&255;h=((f&65535)>>>5<<3&255|(f&65535)>>>7&7)&255;j=((f&65535)>>>10<<3&255|(f&65535)>>>12&7)&255;k=g>>>1;c[(c[2406920]|0)+(k<<2)>>2]=h<<8|j|i<<16;c[(c[3529948]|0)+(k<<2)>>2]=h<<3&2016|j>>>3|i<<8&63488;return}else{b[(c[3530224]|0)+(e&65535)>>1]=f;return}}i=e&-2;if((i|0)==10485762){a[14114728]=f&1;a[14115224]=(f&65535)>>>2&1;return}else if((i|0)==10485760){a[14112944]=f&255;return}else{return}}function exn(e,f){e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;if((e&16773120|0)==4194304){if((e&512|0)==0){g=((d[14115224]|0)<<9)+e|0;h=c[2387146]|0;a[h+(g&4095)|0]=f;i=g&4094;g=b[h+i>>1]|0;h=g&255;j=((h&255)>>>2&7|h<<3)&255;h=((g&65535)>>>5<<3&255|(g&65535)>>>7&7)&255;k=((g&65535)>>>10<<3&255|(g&65535)>>>12&7)&255;g=i>>>1;c[(c[2406920]|0)+(g<<2)>>2]=h<<8|k|j<<16;c[(c[3529948]|0)+(g<<2)>>2]=h<<3&2016|k>>>3|j<<8&63488;return}else{a[(c[2387146]|0)+(e&4095)|0]=f;return}}if((e|0)==10485762|(e|0)==10485763){a[14114728]=f&1;a[14115224]=(f&255)>>>2&1;return}else if((e|0)==10485760|(e|0)==10485761){a[14112944]=f;return}else{return}}function exo(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((e|0)==64768){a[9774864]=d;return}else if((e|0)==63488){c[2113304]=d&255;return}else if((e|0)==63489){b=c[2113304]|0;a[14168504+b|0]=d;mv(0,b,d&255);return}else if((e|0)==65024){a[9774848]=d;return}else{return}}function exp(b){b=b|0;var d=0,e=0;d=b&65535;if((d|0)==63489){e=c[(c[3531464]|0)+4240>>2]&255}else if((d|0)==64512){e=a[14112944]|0}else{e=0}return e|0}function exq(d,e){d=d|0;e=e|0;var f=0,g=0,i=0,j=0,k=0,l=0;f=d&255;if((f|0)==0){US(0,gD[c[2385643]&8191]()|0);b[4771272]=~~(+(b[9732544+(((e&15)*17&255)<<1)>>1]|0)*+h[1192819])&65535;return}else if((f|0)==1){US(1,gD[c[2385651]&8191]()|0);b[4771288]=~~(+(b[9732544+(((e&15)*17&255)<<1)>>1]|0)*+h[1192823])&65535;return}else if((f|0)==3){f=c[3529190]|0;a[9774672]=e;d=c[9757320+(c[1836236]<<2)>>2]|0;g=((e&255)<<16&458752|4096)-4096|0;e=16;i=16;while(1){c[d+76+(i<<2)>>2]=f+(g+(i<<8));j=e+1&65535;if((j&65535)>255){k=16;l=16;break}else{e=j;i=j&65535}}while(1){i=f+(g+(l<<8))|0;c[d+76+(l+512<<2)>>2]=i;c[d+76+(l+768<<2)>>2]=i;i=k+1&65535;if((i&65535)>255){break}else{k=i;l=i&65535}}return}else{return}}function exr(b){b=b|0;return((b&255)==0?a[9774864]|0:0)|0}function exs(d,e){d=d|0;e=e|0;var f=0,g=0,i=0,j=0,k=0,l=0;f=d&255;if((f|0)==0){US(2,gD[c[2385659]&8191]()|0);b[4771304]=~~(+(b[9732544+(((e&15)*17&255)<<1)>>1]|0)*+h[1192827])&65535;return}else if((f|0)==1){US(3,gD[c[2385667]&8191]()|0);b[4771320]=~~(+(b[9732544+(((e&15)*17&255)<<1)>>1]|0)*+h[1192831])&65535;return}else if((f|0)==3){f=c[3529168]|0;a[9774673]=e;d=c[9757320+(c[1836236]<<2)>>2]|0;g=((e&255)<<16&458752|4096)-4096|0;e=16;i=16;while(1){c[d+76+(i<<2)>>2]=f+(g+(i<<8));j=e+1&65535;if((j&65535)>255){k=16;l=16;break}else{e=j;i=j&65535}}while(1){i=f+(g+(l<<8))|0;c[d+76+(l+512<<2)>>2]=i;c[d+76+(l+768<<2)>>2]=i;i=k+1&65535;if((i&65535)>255){break}else{k=i;l=i&65535}}return}else{return}}function ext(b){b=b|0;return((b&255)==0?a[9774848]|0:0)|0}function exu(a,b){a=a|0;b=b|0;return}function exv(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3099476+(b*112|0)>>2];c[a+104>>2]=c[3099480+(b*112|0)>>2];c[a+108>>2]=c[3099484+(b*112|0)>>2];d=0;return d|0}function exw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=3099376+(b*112|0);e=0;return e|0}function exx(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>27){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1311696+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function exy(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>29){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3101616+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function exz(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0.0,B=0,C=0;c[2444206]=0;c[2414914]=0;c[2388110]=0;c[3529234]=2097152;c[3529190]=2162688;c[3529168]=2686976;c[3530794]=3211264;c[3530558]=9502720;c[3529948]=17891328;d=a[9688]|0?534:0;e=d*6|0|16384;c[2440430]=17891328+e;f=e+(d<<2)|0;d=17891328+f|0;c[2414616]=d;c[2388238]=d;c[3529322]=f+17956864;c[3529650]=f+17960960;c[3529630]=f+18092032;c[2387146]=f+18223104;c[3530224]=f+18227200;c[2406920]=f+18292736;d=f+18309120|0;c[2411576]=d;c[2414116]=d;f=d;d=0;while(1){if((d|0)>=1024){break}g=9638528+(d<<2)|0;if((c[g>>2]|0)==0){i=8249;break}else{d=d+1|0}}do{if((i|0)==8249){d=gGq(f)|0;c[g>>2]=d;if((d|0)==0){break}gGz(d|0,0,f|0);c[2414914]=d;gGz(d|0,0,f|0);c[2388110]=d;c[3529234]=d+2097152;c[3529190]=d+2162688;c[3529168]=d+2686976;c[3530794]=d+3211264;e=d+9502720|0;if((c[2444206]|0)==0){c[3530558]=e;j=d+17891328|0}else{j=e}c[3529948]=j;e=j+16384|0;c[2385360]=e;d=a[9688]|0?534:0;k=d*6|0|16384;c[2440430]=j+k;l=k+(d<<2)|0;k=j+l|0;c[2414616]=k;c[2388238]=k;c[3529322]=j+(l+65536);c[3529650]=j+(l+69632);c[3529630]=j+(l+200704);c[2387146]=j+(l+331776);c[3530224]=j+(l+335872);c[2406920]=j+(l+401408);k=j+(l+417792)|0;c[2411576]=k;c[2414116]=k;c[2439004]=e;c[2439005]=e+(d<<1);c[2439006]=e+(d<<1<<1);if((exY()|0)!=0){m=1;return m|0}fxU(0,425984);if((c[2394]|0)==0){n=c[2112932]|0}else{c[2394]=0;d=c[3532596]|0;c[2112932]=d;e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060];n=d}d=c[2388110]|0;e=n|0;k=0;while(1){l=d+k|0;c[e>>2]=l;c[e+131072>>2]=l;l=k+1024|0;if(l>>>0>262143){break}else{e=e+4|0;k=l}}k=n+1024|0;e=262144;while(1){l=d+(e-262144)|0;c[k>>2]=l;c[k+131072>>2]=l;l=e+1024|0;if(l>>>0>524287){break}else{k=k+4|0;e=l}}e=n+2048|0;k=524288;while(1){l=d+(k-524288)|0;c[e>>2]=l;c[e+131072>>2]=l;l=k+1024|0;if(l>>>0>786431){break}else{e=e+4|0;k=l}}k=n+3072|0;e=786432;while(1){l=d+(e-786432)|0;c[k>>2]=l;c[k+131072>>2]=l;l=e+1024|0;if(l>>>0>1048575){break}else{k=k+4|0;e=l}}e=n+8192|0;k=2097152;while(1){l=d+(k-1048576)|0;c[e>>2]=l;c[e+131072>>2]=l;l=k+1024|0;if(l>>>0>3145727){break}else{e=e+4|0;k=l}}k=c[2387146]|0;c[n+21504>>2]=k;c[n+152576>>2]=k;e=k+1024|0;c[n+21508>>2]=e;c[n+152580>>2]=e;e=k+2048|0;c[n+21512>>2]=e;c[n+152584>>2]=e;e=k+3072|0;c[n+21516>>2]=e;c[n+152588>>2]=e;e=c[3530224]|0;k=n+21520|0;d=5509120;while(1){l=e+(d-5509120)|0;c[k>>2]=l;c[k+65536>>2]=l;c[k+131072>>2]=l;l=d+1024|0;if(l>>>0>5570559){break}else{k=k+4|0;d=l}}d=c[2388238]|0;k=n+22528|0;e=5767168;while(1){l=d+(e-5767168)|0;c[k>>2]=l;c[k+65536>>2]=l;c[k+131072>>2]=l;l=e+1024|0;if(l>>>0>5832703){break}else{k=k+4|0;e=l}}e=c[3529650]|0;k=n+23552|0;d=6029312;while(1){l=e+(d-6029312)|0;c[k>>2]=l;c[k+65536>>2]=l;c[k+131072>>2]=l;l=d+1024|0;if(l>>>0>6160383){break}else{k=k+4|0;d=l}}d=c[3529630]|0;k=n+24064|0;e=6160384;while(1){l=d+(e-6160384)|0;c[k>>2]=l;c[k+65536>>2]=l;c[k+131072>>2]=l;l=e+1024|0;if(l>>>0>6291455){break}else{k=k+4|0;e=l}}c[n+196648>>2]=2694;c[n+196728>>2]=2380;c[n+196608>>2]=2448;c[n+196688>>2]=3442;e=c[3532592]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);e=c[2439330]|0;k=(e|0)==0;if(!k){d=e;gGC(9706056,d|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];d=c[3528484]|0;c[2076596]=d;l=c[2417276]|0;c[3541536]=l;c[1836236]=0;o=c[3529234]|0;p=0;q=0;while(1){c[e+76+(q<<2)>>2]=o+(q<<8);r=p+1&65535;if((r&65535)>191){s=0;t=0;break}else{p=r;q=r&65535}}while(1){q=o+(t<<8)|0;c[e+76+(t+512<<2)>>2]=q;c[e+76+(t+768<<2)>>2]=q;q=s+1&65535;if((q&65535)>191){break}else{s=q;t=q&65535}}o=c[3529322]|0;c[e+972>>2]=o;q=o+256|0;c[e+976>>2]=q;p=o+512|0;c[e+980>>2]=p;r=o+768|0;c[e+984>>2]=r;u=o+1024|0;c[e+988>>2]=u;v=o+1280|0;c[e+992>>2]=v;w=o+1536|0;c[e+996>>2]=w;x=o+1792|0;c[e+1e3>>2]=x;c[e+1996>>2]=o;c[e+2e3>>2]=q;c[e+2004>>2]=p;c[e+2008>>2]=r;c[e+2012>>2]=u;c[e+2016>>2]=v;c[e+2020>>2]=w;c[e+2024>>2]=x;c[e+3020>>2]=o;c[e+4044>>2]=o;c[e+3024>>2]=q;c[e+4048>>2]=q;c[e+3028>>2]=p;c[e+4052>>2]=p;c[e+3032>>2]=r;c[e+4056>>2]=r;c[e+3036>>2]=u;c[e+4060>>2]=u;c[e+3040>>2]=v;c[e+4064>>2]=v;c[e+3044>>2]=w;c[e+4068>>2]=w;c[e+3048>>2]=x;c[e+4072>>2]=x;c[e+4180>>2]=1014;c[e+4184>>2]=144;if(!k){x=e;gGC(x|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=d;c[2417276]=l;c[1836236]=-1;fwR(1);x=c[2439331]|0;w=(x|0)==0;if(!w){v=x;gGC(9706056,v|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];v=c[3528485]|0;c[2076596]=v;u=c[2417277]|0;c[3541536]=u;c[1836236]=1;r=c[3529190]|0;p=0;q=0;while(1){c[x+76+(q<<2)>>2]=r+(q<<8);o=p+1&65535;if((o&65535)>255){y=0;z=0;break}else{p=o;q=o&65535}}while(1){q=r+(z<<8)|0;c[x+76+(z+512<<2)>>2]=q;c[x+76+(z+768<<2)>>2]=q;q=y+1&65535;if((q&65535)>255){break}else{y=q;z=q&65535}}c[x+4172>>2]=2582;c[x+4176>>2]=650;if(!w){r=x;gGC(r|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=v;c[2417277]=u;c[1836236]=-1;U6(3e6,2696,3452,0);c[2438222]=6e6;c[2433520]=3416;c[2406670]=1752;c[3528466]=9362;c[2443840]=340;h[745399]=1.0;a[3203272]=1;r=a[9680]|0?32e3:0;c[3542220]=11200;if((c[2113008]|0)==0){gGz(14168888,0,252);c[3542223]=r;c[3542224]=0;c[3542225]=0;c[3542226]=1060;c[3542227]=0;c[3542234]=~~((+(r|0)*32768.0*8.0+75.0e4)/15.0e5);r=31;A=32767.0;while(1){c[14169012+(r<<2)>>2]=~~(A+.5);q=r-1|0;if((q|0)>0){r=q;A=A/1.188502227}else{break}}c[3542253]=0;h[1771269]=1.0;h[1771270]=1.0;h[1771271]=1.0;c[3542574]=3;c[3542575]=3;c[3542576]=3;mB(0);c[2113008]=(c[2113008]|0)+1}h[1771269]=1.0;c[3542574]=1;h[1771270]=1.0;c[3542575]=2;h[1771271]=0.0;c[3542576]=3;c[2405758]=1;gGz(9542544,0,32);c[2385641]=1;h[1192819]=1.0;c[2385642]=3;c[2385643]=622;r=0;do{u=r*257|0;b[9732544+(r<<1)>>1]=((u|0)/2|0)&65535;b[9753784+(r<<1)>>1]=u+32768&65535;r=r+1|0;}while((r|0)<256);c[3528842]=1;c[2405758]=2;gGz(9542576,0,32);c[2385649]=1;h[1192823]=1.0;c[2385650]=3;c[2385651]=622;r=0;do{u=r*257|0;b[9732544+(r<<1)>>1]=((u|0)/2|0)&65535;b[9753784+(r<<1)>>1]=u+32768&65535;r=r+1|0;}while((r|0)<256);c[3528842]=1;c[2405758]=3;gGz(9542608,0,32);c[2385657]=1;h[1192827]=1.0;c[2385658]=3;c[2385659]=622;r=0;do{u=r*257|0;b[9732544+(r<<1)>>1]=((u|0)/2|0)&65535;b[9753784+(r<<1)>>1]=u+32768&65535;r=r+1|0;}while((r|0)<256);c[3528842]=1;c[2405758]=4;gGz(9542640,0,32);c[2385665]=1;h[1192831]=1.0;c[2385666]=3;c[2385667]=622;r=0;do{u=r*257|0;b[9732544+(r<<1)>>1]=((u|0)/2|0)&65535;b[9753784+(r<<1)>>1]=u+32768&65535;r=r+1|0;}while((r|0)<256);c[3528842]=1;h[1192819]=.4;c[2385642]=1;h[1192823]=.4;c[2385650]=2;h[1192827]=.4;c[2385658]=1;h[1192831]=.4;c[2385666]=2;exW();r=c[642608+(c[2436]<<2)>>2]|0;u=c[r+128>>2]|0;if((c[r+52>>2]&4|0)==0){c[2113068]=u;v=c[r+132>>2]|0;c[2113070]=v;c[2443814]=u;c[2440436]=v;B=u;C=v}else{c[2113070]=u;v=c[r+132>>2]|0;c[2113068]=v;c[2440436]=u;c[2443814]=v;B=v;C=u}u=ag(B<<1,C)|0;v=gGq(u)|0;c[2112926]=v;if((v|0)==0){m=0;return m|0}gGz(v|0,0,u|0);m=0;return m|0}}while(0);c[2414914]=0;m=1;return m|0}function exA(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[2414914]|0;d=0;while(1){if((d|0)>=1024){break}e=9638528+(d<<2)|0;if((c[e>>2]|0)==(b|0)){f=8318;break}else{d=d+1|0}}if((f|0)==8318){gGr(b);c[e>>2]=0}c[2414914]=0;do{if((c[2444206]|0)==0){c[2113008]=0;c[2076598]=0;c[2383582]=0;e=a[7452592]|0;if(e){b=0;d=e&1;while(1){e=14163944+(b<<2)|0;g=c[e>>2]|0;h=c[2113006]|0;if((h|0)==0){f=8328}else{i=h-1|0;c[2113006]=i;if((i|0)==0){f=8328}}if((f|0)==8328){f=0;c[2383474]=0}if((g|0)==0){j=d}else{gGr(g);j=a[7452592]&1}c[e>>2]=0;e=b+1|0;if((e|0)<(j|0)){b=e;d=j}else{break}}}a[7452592]=0;c[2438222]=0;c[2433520]=0;c[2406670]=0;c[3528466]=0;d=c[2406686]|0;if((d|0)!=0){gGr(d);c[2406686]=0}c[2432974]=0}else{d=c[3531464]|0;c[d+44344>>2]=0;c[d+44348>>2]=0;if((d|0)!=0){gGr(d);c[3531464]=0}d=c[2406684]|0;if((d|0)==0){break}gGr(d);c[2406684]=0}}while(0);UT();if((c[2392]|0)>=0){j=0;do{f=14130368+(j<<2)|0;d=c[f>>2]|0;if((d|0)!=0){gGr(d);c[f>>2]=0}f=14130384+(j<<2)|0;d=c[f>>2]|0;if((d|0)!=0){gGr(d);c[f>>2]=0}j=j+1|0;}while((j|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;fwZ();c[2113070]=0;c[2113068]=0;j=c[2112926]|0;if((j|0)==0){return 0}gGr(j);c[2112926]=0;return 0}function exB(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((a[9623848]|0)!=0){exW()}exX();d=c[2392]|0;if((d|0)>=0){gGz(8452240,0,((d|0)>0?(d<<2)+4|0:4)|0)}c[2113054]=0;d=c[2385548]|0;if((d|0)>0){gGz(9752472,0,((d|0)>1?d<<2:4)|0)}c[2433530]=0;if((c[2394]|0)==0){e=0;f=0}else{c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];e=0;f=0}while(1){c[2113056]=2e3;d=RG(2e3)|0;c[2113054]=(c[2113054]|0)+d;c[2276108]=-1;c[2113056]=-1;do{if((e|0)==24){c[8452200+(c[2394]<<2)>>2]=8193;c[2276080]=256;if((c[2276079]|0)>>>0>=256){break}RH(1)}else if((e|0)==49){c[8452200+(c[2394]<<2)>>2]=8194;c[2276080]=512;if((c[2276079]|0)>>>0>=512){break}RH(2)}}while(0);d=c[2439330]|0;if((d|0)!=0){g=d;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;U1(e*2e3|0);g=c[1836236]|0;d=c[9757320+(g<<2)>>2]|0;if((d|0)!=0){h=d;gGC(h|0,9706056,76)|0}c[9752472+(g<<2)>>2]=c[2433530];c[14113936+(g<<2)>>2]=c[2076596];c[9669104+(g<<2)>>2]=c[3541536];c[1836236]=-1;g=c[2439331]|0;if((g|0)!=0){h=g;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;h=c[2438119]|0;c[2433530]=h;c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;if((a[g+4188|0]|0)==0){d=gfc(2e3)|0;i=c[1836236]|0;j=(c[2433530]|0)+d|0;k=i;l=c[9757320+(i<<2)>>2]|0}else{j=h+2e3|0;k=1;l=g}c[2433530]=j;if((l|0)!=0){g=l;gGC(g|0,9706056,76)|0}c[9752472+(k<<2)>>2]=j;c[14113936+(k<<2)>>2]=c[2076596];c[9669104+(k<<2)>>2]=c[3541536];c[1836236]=-1;m=(c[2112964]|0)==0;if(m){n=f}else{g=a[9688]|0?10:0;mF(9756016,(c[2440430]|0)+(f<<1<<1)|0,g,0);n=g+f|0}g=e+1|0;if((g|0)<50){e=g;f=n}else{break}}f=c[2394]|0;e=c[14130368+(f<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(f<<2)>>2]=c[2113054];c[2394]=-1;do{if(!m){f=a[9688]|0?534:0;if((f|0)==(n|0)){break}mF(9756016,(c[2440430]|0)+(n<<1<<1)|0,f-n|0,0)}}while(0);n=c[2439330]|0;if((n|0)!=0){m=n;gGC(9706056,m|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;m=c[2438222]|0;n=gGS(-1220542464,47683,m,(m|0)<0|0?-1:0)|0;m=n;U1(1e5);n=c[2443824]|0;if((n|0)<1073676288){c[2443824]=n-m}n=c[2443825]|0;if((n|0)<1073676288){c[2443825]=n-m}n=(c[3528506]|0)-m|0;c[3528506]=(n|0)<0?0:n;n=c[2112964]|0;if((n|0)!=0){gg[c[3542114]&4095](n,a[9688]|0?534:0);n=a[9688]|0;m=n?534:0;if(n){n=c[2440430]|0;f=c[2112964]|0;e=0;while(1){k=e<<1;j=f+(k<<1)|0;b[j>>1]=(b[j>>1]|0)+(b[n+(k<<1)>>1]|0)&65535;j=k|1;k=f+(j<<1)|0;b[k>>1]=(b[k>>1]|0)+(b[n+(j<<1)>>1]|0)&65535;j=e+1|0;if((j|0)<(m|0)){e=j}else{o=f;break}}}else{o=c[2112964]|0}UR(o,m)}m=c[1836236]|0;o=c[9757320+(m<<2)>>2]|0;if((o|0)!=0){f=o;gGC(f|0,9706056,76)|0}c[9752472+(m<<2)>>2]=c[2433530];c[14113936+(m<<2)>>2]=c[2076596];c[9669104+(m<<2)>>2]=c[3541536];c[1836236]=-1;if((c[2112968]|0)==0){return 0}exC()|0;return 0}function exC(){var d=0,e=0,f=0,g=0,h=0;if((a[9547264]|0)!=0){d=c[2406920]|0;e=c[3529948]|0;f=0;do{g=c[d+(f<<2)>>2]|0;c[e+(f<<2)>>2]=g>>8<<3&2016|g>>>3&31|g>>16<<8&63488;f=f+1|0;}while((f|0)<4096)}f=ag(c[2113070]|0,c[2113068]|0)|0;if((f|0)>0){e=c[2112926]|0;d=0;do{b[e+(d<<1)>>1]=255;d=d+1|0;}while((d|0)<(f|0))}ex$(c[3529650]|0,c[3530794]|0,c[2443924]|0);if((c[2444206]|0)!=0){h=c[3529948]|0;R8(h);return 0}ex$(c[3529630]|0,c[3530558]|0,131072);h=c[3529948]|0;R8(h);return 0}function exD(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;g=i;i=i+272|0;h=g|0;j=g+16|0;k=g+32|0;l=g+48|0;m=g+64|0;n=g+80|0;o=g+96|0;p=g+112|0;q=g+128|0;r=g+144|0;s=g+160|0;t=g+176|0;u=g+192|0;v=g+208|0;w=g+224|0;x=g+240|0;y=g+256|0;z=(f|0)==0;if(!z){c[f>>2]=169618}if((e&96|0)!=0){gGz(y|0,0,12);A=c[2414616]|0;c[y>>2]=A;c[y+4>>2]=(c[2411576]|0)-A;c[y+12>>2]=162152;A=c[2076592]|0;gj[A&4095](y)|0;y=p|0;A=e&64;B=(A|0)==0;do{if(!B){gGz(o|0,0,16);c[2394]=-1;if((c[2392]|0)<0){break}C=p+9|0;D=n;E=n|0;F=n+4|0;G=n+12|0;H=o|0;I=o+4|0;J=o+12|0;K=0;do{gGC(y|0,614896,11)|0;a[C]=K+48&255;L=8452256+(K<<2)|0;gGz(D|0,0,12);c[E>>2]=L;c[F>>2]=4;c[G>>2]=164976;gj[c[2076592]&4095](n)|0;if((c[L>>2]|0)!=0){c[H>>2]=c[14130368+(K<<2)>>2];c[I>>2]=c[8452184+(K<<2)>>2];c[J>>2]=y;L=c[2076592]|0;gj[L&4095](o)|0}K=K+1|0;}while((K|0)<=(c[2392]|0))}}while(0);fw$(e);if(!z){c[f>>2]=169753}if((A|0)!=0&(c[2405758]|0)>0){A=m;o=m|0;y=m+4|0;n=m+12|0;p=0;do{gGz(A|0,0,12);c[o>>2]=9542544+(p<<5);c[y>>2]=2;c[n>>2]=119040;gj[c[2076592]&4095](m)|0;p=p+1|0;}while((p|0)<(c[2405758]|0))}do{if((c[2444206]|0)==0){p=j|0;if(B){break}do{if(!z){if((c[f>>2]|0)>=169110){break}c[f>>2]=169110}}while(0);if((c[2113008]|0)<=0){break}m=h|0;n=h+4|0;y=h+8|0;o=h+12|0;A=0;do{cC(p|0,531144,(K=i,i=i+8|0,c[K>>2]=A,K)|0)|0;i=K;c[m>>2]=14168888+(A*252|0);c[n>>2]=252;c[y>>2]=0;c[o>>2]=p;gj[c[2076592]&4095](h)|0;A=A+1|0;}while((A|0)<(c[2113008]|0))}else{if(B){break}gGz(l|0,0,12);c[l>>2]=8453216;c[l+4>>2]=4;c[l+12>>2]=107480;gj[c[2076592]&4095](l)|0;gGz(k|0,0,12);c[k>>2]=14168504;c[k+4>>2]=256;c[k+12>>2]=476464;gj[c[2076592]&4095](k)|0;if((e&2|0)==0){break}else{M=0}do{mv(0,M,d[14168504+M|0]|0);M=M+1|0;}while((M|0)<256)}}while(0);gGz(x|0,0,12);c[x>>2]=14112944;c[x+4>>2]=1;c[x+12>>2]=191240;M=c[2076592]|0;gj[M&4095](x)|0;gGz(w|0,0,12);c[w>>2]=9774864;c[w+4>>2]=1;c[w+12>>2]=516864;x=c[2076592]|0;gj[x&4095](w)|0;gGz(v|0,0,12);c[v>>2]=9774848;c[v+4>>2]=1;c[v+12>>2]=515992;w=c[2076592]|0;gj[w&4095](v)|0;gGz(u|0,0,12);c[u>>2]=14114728;c[u+4>>2]=1;c[u+12>>2]=142288;v=c[2076592]|0;gj[v&4095](u)|0;gGz(t|0,0,12);c[t>>2]=14115224;c[t+4>>2]=1;c[t+12>>2]=513976;u=c[2076592]|0;gj[u&4095](t)|0;gGz(s|0,0,12);c[s>>2]=9747048;c[s+4>>2]=1;c[s+12>>2]=512544;t=c[2076592]|0;gj[t&4095](s)|0;gGz(r|0,0,12);c[r>>2]=9774672;c[r+4>>2]=1;c[r+12>>2]=511304;s=c[2076592]|0;gj[s&4095](r)|0;gGz(q|0,0,12);c[q>>2]=9774673;c[q+4>>2]=1;c[q+12>>2]=509488;r=c[2076592]|0;gj[r&4095](q)|0}q=c[2444206]|0;if((q|0)==3){N=8437}else if((q|0)!=2){i=g;return 0}do{if((N|0)==8437){r=c[2439331]|0;s=(r|0)==0;if(!s){t=r;gGC(9706056,t|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];t=c[3528485]|0;c[2076596]=t;u=c[2417277]|0;c[3541536]=u;c[1836236]=1;v=c[3529190]|0;w=((d[9774672]|0)<<16&458752|4096)-4096|0;x=16;M=16;while(1){c[r+76+(M<<2)>>2]=v+(w+(M<<8));e=x+1&65535;if((e&65535)>255){O=16;P=16;break}else{x=e;M=e&65535}}while(1){M=v+(w+(P<<8))|0;c[r+76+(P+512<<2)>>2]=M;c[r+76+(P+768<<2)>>2]=M;M=O+1&65535;if((M&65535)>255){break}else{O=M;P=M&65535}}if(!s){w=r;gGC(w|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=t;c[2417277]=u;c[1836236]=-1;w=c[2439332]|0;v=(w|0)==0;if(!v){M=w;gGC(9706056,M|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438120];M=c[3528486]|0;c[2076596]=M;x=c[2417278]|0;c[3541536]=x;c[1836236]=2;e=c[3529168]|0;k=((d[9774673]|0)<<16&458752|4096)-4096|0;l=16;B=16;while(1){c[w+76+(B<<2)>>2]=e+(k+(B<<8));h=l+1&65535;if((h&65535)>255){Q=16;R=16;break}else{l=h;B=h&65535}}while(1){B=e+(k+(R<<8))|0;c[w+76+(R+512<<2)>>2]=B;c[w+76+(R+768<<2)>>2]=B;B=Q+1&65535;if((B&65535)>255){break}else{Q=B;R=B&65535}}if(!v){k=w;gGC(k|0,9706056,76)|0}c[2438120]=c[2433530];c[3528486]=M;c[2417278]=x;c[1836236]=-1;if((q|0)==2){break}i=g;return 0}}while(0);q=c[2439331]|0;R=(q|0)==0;if(!R){Q=q;gGC(9706056,Q|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];Q=c[3528485]|0;c[2076596]=Q;P=c[2417277]|0;c[3541536]=P;c[1836236]=1;O=c[3529190]|0;N=((d[9774672]|0)<<16&65536|1024)-1024|0;k=4;e=4;while(1){c[q+76+(e<<2)>>2]=O+(N+(e<<8));B=k+1&65535;if((B&65535)>255){S=4;T=4;break}else{k=B;e=B&65535}}while(1){e=O+(N+(T<<8))|0;c[q+76+(T+512<<2)>>2]=e;c[q+76+(T+768<<2)>>2]=e;e=S+1&65535;if((e&65535)>255){break}else{S=e;T=e&65535}}if(!R){R=q;gGC(R|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=Q;c[2417277]=P;c[1836236]=-1;i=g;return 0}function exE(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>5){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6479500+(b*112|0)>>2];c[a+104>>2]=c[6479504+(b*112|0)>>2];c[a+108>>2]=c[6479508+(b*112|0)>>2];d=0;return d|0}function exF(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<6&(d|0)==0)){e=1;return e|0}c[a>>2]=6479400+(b*112|0);e=0;return e|0}function exG(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4937776+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function exH(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6480072+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function exI(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;c[2444206]=1;c[2414914]=0;c[2388110]=0;c[3529234]=2097152;c[3529190]=2162688;c[3529168]=2686976;c[3530794]=3211264;c[3529948]=9502720;d=a[9688]|0?534:0;e=d*6|0|16384;c[2440430]=9502720+e;f=e+(d<<2)|0;d=9502720+f|0;c[2414616]=d;c[2388238]=d;c[3529322]=f+9568256;c[3529650]=f+9572352;c[3529630]=f+9703424;c[2387146]=f+9834496;c[3530224]=f+9838592;c[2406920]=f+9904128;d=f+9920512|0;c[2411576]=d;c[2414116]=d;f=d;d=0;while(1){if((d|0)>=1024){break}g=9638528+(d<<2)|0;if((c[g>>2]|0)==0){i=8493;break}else{d=d+1|0}}do{if((i|0)==8493){d=gGq(f)|0;c[g>>2]=d;if((d|0)==0){break}gGz(d|0,0,f|0);c[2414914]=d;gGz(d|0,0,f|0);c[2388110]=d;c[3529234]=d+2097152;c[3529190]=d+2162688;c[3529168]=d+2686976;c[3530794]=d+3211264;e=d+9502720|0;if((c[2444206]|0)==0){c[3530558]=e;j=d+17891328|0}else{j=e}c[3529948]=j;c[2385360]=j+16384;e=a[9688]|0?534:0;d=e*6|0|16384;c[2440430]=j+d;k=d+(e<<2)|0;e=j+k|0;c[2414616]=e;c[2388238]=e;c[3529322]=j+(k+65536);c[3529650]=j+(k+69632);c[3529630]=j+(k+200704);c[2387146]=j+(k+331776);c[3530224]=j+(k+335872);c[2406920]=j+(k+401408);e=j+(k+417792)|0;c[2411576]=e;c[2414116]=e;if((exY()|0)!=0){l=1;return l|0}fxU(0,425984);if((c[2394]|0)==0){m=c[2112932]|0}else{c[2394]=0;e=c[3532596]|0;c[2112932]=e;k=c[3532592]|0;if((k|0)!=0){gGC(9104152,k|0,280)|0}c[2113054]=c[2113060];m=e}e=c[2388110]|0;k=m|0;d=0;while(1){n=e+d|0;c[k>>2]=n;c[k+131072>>2]=n;n=d+1024|0;if(n>>>0>1048575){break}else{k=k+4|0;d=n}}d=c[3530224]|0;c[m+21508>>2]=d;c[m+87044>>2]=d;c[m+152580>>2]=d;k=d+1024|0;c[m+21512>>2]=k;c[m+87048>>2]=k;c[m+152584>>2]=k;k=d+2048|0;c[m+21516>>2]=k;c[m+87052>>2]=k;c[m+152588>>2]=k;k=c[2388238]|0;c[m+22528>>2]=k;c[m+88064>>2]=k;c[m+153600>>2]=k;d=k+1024|0;c[m+22532>>2]=d;c[m+88068>>2]=d;c[m+153604>>2]=d;d=k+2048|0;c[m+22536>>2]=d;c[m+88072>>2]=d;c[m+153608>>2]=d;d=k+3072|0;c[m+22540>>2]=d;c[m+88076>>2]=d;c[m+153612>>2]=d;d=k+4096|0;c[m+22544>>2]=d;c[m+88080>>2]=d;c[m+153616>>2]=d;d=k+5120|0;c[m+22548>>2]=d;c[m+88084>>2]=d;c[m+153620>>2]=d;d=k+6144|0;c[m+22552>>2]=d;c[m+88088>>2]=d;c[m+153624>>2]=d;d=k+7168|0;c[m+22556>>2]=d;c[m+88092>>2]=d;c[m+153628>>2]=d;d=k+8192|0;c[m+22560>>2]=d;c[m+88096>>2]=d;c[m+153632>>2]=d;d=k+9216|0;c[m+22564>>2]=d;c[m+88100>>2]=d;c[m+153636>>2]=d;d=k+10240|0;c[m+22568>>2]=d;c[m+88104>>2]=d;c[m+153640>>2]=d;d=k+11264|0;c[m+22572>>2]=d;c[m+88108>>2]=d;c[m+153644>>2]=d;d=k+12288|0;c[m+22576>>2]=d;c[m+88112>>2]=d;c[m+153648>>2]=d;d=k+13312|0;c[m+22580>>2]=d;c[m+88116>>2]=d;c[m+153652>>2]=d;d=k+14336|0;c[m+22584>>2]=d;c[m+88120>>2]=d;c[m+153656>>2]=d;d=k+15360|0;c[m+22588>>2]=d;c[m+88124>>2]=d;c[m+153660>>2]=d;d=c[3529650]|0;k=m+23552|0;e=6029312;while(1){n=d+(e-6029312)|0;c[k>>2]=n;c[k+65536>>2]=n;c[k+131072>>2]=n;n=e+1024|0;if(n>>>0>6160383){break}else{k=k+4|0;e=n}}c[m+196648>>2]=2162;c[m+196728>>2]=448;c[m+196608>>2]=3458;c[m+196688>>2]=480;e=c[3532592]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);e=c[2439330]|0;k=(e|0)==0;if(!k){d=e;gGC(9706056,d|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];d=c[3528484]|0;c[2076596]=d;n=c[2417276]|0;c[3541536]=n;c[1836236]=0;o=c[3529234]|0;p=0;q=0;while(1){c[e+76+(q<<2)>>2]=o+(q<<8);r=p+1&65535;if((r&65535)>239){s=0;t=0;break}else{p=r;q=r&65535}}while(1){q=o+(t<<8)|0;c[e+76+(t+512<<2)>>2]=q;c[e+76+(t+768<<2)>>2]=q;q=s+1&65535;if((q&65535)>239){break}else{s=q;t=q&65535}}o=c[3529322]|0;c[e+1036>>2]=o;q=o+256|0;c[e+1040>>2]=q;p=o+512|0;c[e+1044>>2]=p;r=o+768|0;c[e+1048>>2]=r;u=o+1024|0;c[e+1052>>2]=u;v=o+1280|0;c[e+1056>>2]=v;w=o+1536|0;c[e+1060>>2]=w;x=o+1792|0;c[e+1064>>2]=x;c[e+2060>>2]=o;c[e+2064>>2]=q;c[e+2068>>2]=p;c[e+2072>>2]=r;c[e+2076>>2]=u;c[e+2080>>2]=v;c[e+2084>>2]=w;c[e+2088>>2]=x;c[e+3084>>2]=o;c[e+4108>>2]=o;c[e+3088>>2]=q;c[e+4112>>2]=q;c[e+3092>>2]=p;c[e+4116>>2]=p;c[e+3096>>2]=r;c[e+4120>>2]=r;c[e+3100>>2]=u;c[e+4124>>2]=u;c[e+3104>>2]=v;c[e+4128>>2]=v;c[e+3108>>2]=w;c[e+4132>>2]=w;c[e+3112>>2]=x;c[e+4136>>2]=x;c[e+4184>>2]=580;c[e+4180>>2]=370;if(!k){x=e;gGC(x|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=d;c[2417276]=n;c[1836236]=-1;fwR(1);x=c[2439331]|0;w=(x|0)==0;if(!w){v=x;gGC(9706056,v|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];v=c[3528485]|0;c[2076596]=v;u=c[2417277]|0;c[3541536]=u;c[1836236]=1;r=c[3529190]|0;c[x+76>>2]=r;c[x+80>>2]=r+256;c[x+84>>2]=r+512;c[x+88>>2]=r+768;c[x+92>>2]=r+1024;c[x+96>>2]=r+1280;c[x+100>>2]=r+1536;c[x+104>>2]=r+1792;c[x+108>>2]=r+2048;c[x+112>>2]=r+2304;c[x+116>>2]=r+2560;c[x+120>>2]=r+2816;c[x+124>>2]=r+3072;c[x+128>>2]=r+3328;c[x+132>>2]=r+3584;c[x+136>>2]=r+3840;p=0;q=0;while(1){o=r+(q<<8)|0;c[x+76+(q+512<<2)>>2]=o;c[x+76+(q+768<<2)>>2]=o;o=p+1&65535;if((o&65535)>15){y=16;z=16;break}else{p=o;q=o&65535}}while(1){c[x+76+(z<<2)>>2]=r+(z<<8);q=y+1&65535;if((q&65535)>255){A=16;B=16;break}else{y=q;z=q&65535}}while(1){q=r+(B<<8)|0;c[x+76+(B+512<<2)>>2]=q;c[x+76+(B+768<<2)>>2]=q;q=A+1&65535;if((q&65535)>255){break}else{A=q;B=q&65535}}c[x+4172>>2]=2372;c[x+4176>>2]=760;if(!w){r=x;gGC(r|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=v;c[2417277]=u;c[1836236]=-1;r=a[9680]|0;q=r?32e3:0;if(r){if(a[9624]|0){r=q*3|0;p=55930;while(1){if((p|0)>(r|0)){p=p>>1}else{C=1222;D=p;break}}}else{C=2462;D=q}c[2429380]=D;c[3542124]=C;mw(3579545,D);p=gGq(262144)|0;c[2406684]=p;gGz(p|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(3579545,11025)}h[745421]=.5;c[2436794]=1;h[745420]=.5;c[2436792]=2;c[2405758]=1;gGz(9542544,0,32);c[2385641]=1;h[1192819]=1.0;c[2385642]=3;c[2385643]=622;p=0;do{r=p*257|0;b[9732544+(p<<1)>>1]=((r|0)/2|0)&65535;b[9753784+(p<<1)>>1]=r+32768&65535;p=p+1|0;}while((p|0)<256);c[3528842]=2;c[2405758]=2;gGz(9542576,0,32);c[2385649]=1;h[1192823]=1.0;c[2385650]=3;c[2385651]=622;p=0;do{q=p*257|0;b[9732544+(p<<1)>>1]=((q|0)/2|0)&65535;b[9753784+(p<<1)>>1]=q+32768&65535;p=p+1|0;}while((p|0)<256);c[3528842]=2;h[1192819]=.5;c[2385642]=1;h[1192823]=.5;c[2385650]=2;exW();p=c[642608+(c[2436]<<2)>>2]|0;q=c[p+128>>2]|0;if((c[p+52>>2]&4|0)==0){c[2113068]=q;r=c[p+132>>2]|0;c[2113070]=r;c[2443814]=q;c[2440436]=r;E=q;F=r}else{c[2113070]=q;r=c[p+132>>2]|0;c[2113068]=r;c[2440436]=q;c[2443814]=r;E=r;F=q}q=ag(E<<1,F)|0;r=gGq(q)|0;c[2112926]=r;if((r|0)==0){l=0;return l|0}gGz(r|0,0,q|0);l=0;return l|0}}while(0);c[2414914]=0;l=1;return l|0}function exJ(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if((a[9623848]|0)!=0){exW()}exX();d=c[2392]|0;if((d|0)>=0){gGz(8452240,0,((d|0)>0?(d<<2)+4|0:4)|0)}c[2113054]=0;d=c[2385548]|0;if((d|0)>0){gGz(9752472,0,((d|0)>1?d<<2:4)|0)}c[2433530]=0;if((c[2394]|0)==0){e=0;f=0}else{c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];e=0;f=0}while(1){c[2113056]=2e3;d=RG(2e3)|0;c[2113054]=(c[2113054]|0)+d;c[2276108]=-1;c[2113056]=-1;do{if((e|0)==49){c[8452200+(c[2394]<<2)>>2]=8193;c[2276080]=256;if((c[2276079]|0)>>>0>=256){break}RH(1)}}while(0);d=c[2439330]|0;if((d|0)!=0){g=d;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;g=c[2438118]|0;c[2433530]=g;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;if((a[d+4188|0]|0)==0){h=gfc(1193)|0;i=c[1836236]|0;j=(c[2433530]|0)+h|0;k=i;l=c[9757320+(i<<2)>>2]|0}else{j=g+1193|0;k=0;l=d}c[2433530]=j;if((l|0)!=0){d=l;gGC(d|0,9706056,76)|0}c[9752472+(k<<2)>>2]=j;c[14113936+(k<<2)>>2]=c[2076596];c[9669104+(k<<2)>>2]=c[3541536];c[1836236]=-1;d=c[2439331]|0;if((d|0)!=0){g=d;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;g=c[2438119]|0;c[2433530]=g;c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;if((a[d+4188|0]|0)==0){i=gfc(2e3)|0;h=c[1836236]|0;m=(c[2433530]|0)+i|0;n=h;o=c[9757320+(h<<2)>>2]|0}else{m=g+2e3|0;n=1;o=d}c[2433530]=m;if((o|0)!=0){d=o;gGC(d|0,9706056,76)|0}c[9752472+(n<<2)>>2]=m;c[14113936+(n<<2)>>2]=c[2076596];c[9669104+(n<<2)>>2]=c[3541536];c[1836236]=-1;d=c[2112964]|0;if((d|0)==0){p=f}else{g=a[9688]|0?10:0;gg[c[3542124]&4095](d+(f<<1<<1)|0,g);p=g+f|0}g=e+1|0;if((g|0)<50){e=g;f=p}else{break}}f=c[2112964]|0;if((f|0)!=0){e=a[9688]|0?534:0;if((e|0)==(p|0)){q=f;r=p}else{gg[c[3542124]&4095](f+(p<<1<<1)|0,e-p|0);q=c[2112964]|0;r=a[9688]|0?534:0}UR(q,r)}r=c[2394]|0;q=c[14130368+(r<<2)>>2]|0;if((q|0)!=0){gGC(q|0,9104152,280)|0}c[8452240+(r<<2)>>2]=c[2113054];c[2394]=-1;if((c[2112968]|0)==0){return 0}exC()|0;return 0}function exK(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2109276+(b*112|0)>>2];c[a+104>>2]=c[2109280+(b*112|0)>>2];c[a+108>>2]=c[2109284+(b*112|0)>>2];d=0;return d|0}function exL(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=2109176+(b*112|0);e=0;return e|0}function exM(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1177128+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function exN(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>42){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=2110072+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function exO(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;c[2444206]=2;c[2414914]=0;c[2388110]=0;c[3529234]=2097152;c[3529190]=2162688;c[3529168]=2686976;c[3530794]=3211264;c[3529948]=9502720;d=a[9688]|0?534:0;e=d*6|0|16384;c[2440430]=9502720+e;f=e+(d<<2)|0;d=9502720+f|0;c[2414616]=d;c[2388238]=d;c[3529322]=f+9568256;c[3529650]=f+9572352;c[3529630]=f+9703424;c[2387146]=f+9834496;c[3530224]=f+9838592;c[2406920]=f+9904128;d=f+9920512|0;c[2411576]=d;c[2414116]=d;f=d;d=0;while(1){if((d|0)>=1024){break}g=9638528+(d<<2)|0;if((c[g>>2]|0)==0){i=8614;break}else{d=d+1|0}}do{if((i|0)==8614){d=gGq(f)|0;c[g>>2]=d;if((d|0)==0){break}gGz(d|0,0,f|0);c[2414914]=d;gGz(d|0,0,f|0);c[2388110]=d;c[3529234]=d+2097152;c[3529190]=d+2162688;c[3529168]=d+2686976;c[3530794]=d+3211264;e=d+9502720|0;if((c[2444206]|0)==0){c[3530558]=e;j=d+17891328|0}else{j=e}c[3529948]=j;c[2385360]=j+16384;e=a[9688]|0?534:0;d=e*6|0|16384;c[2440430]=j+d;k=d+(e<<2)|0;e=j+k|0;c[2414616]=e;c[2388238]=e;c[3529322]=j+(k+65536);c[3529650]=j+(k+69632);c[3529630]=j+(k+200704);c[2387146]=j+(k+331776);c[3530224]=j+(k+335872);c[2406920]=j+(k+401408);e=j+(k+417792)|0;c[2411576]=e;c[2414116]=e;if((exY()|0)!=0){l=1;return l|0}fxU(0,425984);if((c[2394]|0)==0){m=c[2112932]|0}else{c[2394]=0;e=c[3532596]|0;c[2112932]=e;k=c[3532592]|0;if((k|0)!=0){gGC(9104152,k|0,280)|0}c[2113054]=c[2113060];m=e}e=c[2388110]|0;k=m|0;d=0;while(1){n=e+d|0;c[k>>2]=n;c[k+131072>>2]=n;n=d+1024|0;if(n>>>0>1048575){break}else{k=k+4|0;d=n}}d=c[3530224]|0;c[m+8196>>2]=d;c[m+73732>>2]=d;c[m+139268>>2]=d;k=d+1024|0;c[m+8200>>2]=k;c[m+73736>>2]=k;c[m+139272>>2]=k;k=d+2048|0;c[m+8204>>2]=k;c[m+73740>>2]=k;c[m+139276>>2]=k;k=c[3529650]|0;d=m+16384|0;e=4194304;while(1){n=k+(e-4194304)|0;c[d>>2]=n;c[d+65536>>2]=n;c[d+131072>>2]=n;n=e+1024|0;if(n>>>0>4325375){break}else{d=d+4|0;e=n}}e=m+23552|0;d=6029312;while(1){n=k+(d-6029312)|0;c[e>>2]=n;c[e+65536>>2]=n;c[e+131072>>2]=n;n=d+1024|0;if(n>>>0>6160383){break}else{e=e+4|0;d=n}}d=c[2388238]|0;c[m+32768>>2]=d;c[m+98304>>2]=d;c[m+163840>>2]=d;e=d+1024|0;c[m+32772>>2]=e;c[m+98308>>2]=e;c[m+163844>>2]=e;e=d+2048|0;c[m+32776>>2]=e;c[m+98312>>2]=e;c[m+163848>>2]=e;e=d+3072|0;c[m+32780>>2]=e;c[m+98316>>2]=e;c[m+163852>>2]=e;e=d+4096|0;c[m+32784>>2]=e;c[m+98320>>2]=e;c[m+163856>>2]=e;e=d+5120|0;c[m+32788>>2]=e;c[m+98324>>2]=e;c[m+163860>>2]=e;e=d+6144|0;c[m+32792>>2]=e;c[m+98328>>2]=e;c[m+163864>>2]=e;e=d+7168|0;c[m+32796>>2]=e;c[m+98332>>2]=e;c[m+163868>>2]=e;e=d+8192|0;c[m+32800>>2]=e;c[m+98336>>2]=e;c[m+163872>>2]=e;e=d+9216|0;c[m+32804>>2]=e;c[m+98340>>2]=e;c[m+163876>>2]=e;e=d+10240|0;c[m+32808>>2]=e;c[m+98344>>2]=e;c[m+163880>>2]=e;e=d+11264|0;c[m+32812>>2]=e;c[m+98348>>2]=e;c[m+163884>>2]=e;e=d+12288|0;c[m+32816>>2]=e;c[m+98352>>2]=e;c[m+163888>>2]=e;e=d+13312|0;c[m+32820>>2]=e;c[m+98356>>2]=e;c[m+163892>>2]=e;e=d+14336|0;c[m+32824>>2]=e;c[m+98360>>2]=e;c[m+163896>>2]=e;e=d+15360|0;c[m+32828>>2]=e;c[m+98364>>2]=e;c[m+163900>>2]=e;c[m+196648>>2]=840;c[m+196728>>2]=2540;c[m+196608>>2]=2794;c[m+196688>>2]=2384;e=c[3532592]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);e=c[2439330]|0;d=(e|0)==0;if(!d){k=e;gGC(9706056,k|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];k=c[3528484]|0;c[2076596]=k;n=c[2417276]|0;c[3541536]=n;c[1836236]=0;o=c[3529234]|0;p=0;q=0;while(1){c[e+76+(q<<2)>>2]=o+(q<<8);r=p+1&65535;if((r&65535)>239){s=0;t=0;break}else{p=r;q=r&65535}}while(1){q=o+(t<<8)|0;c[e+76+(t+512<<2)>>2]=q;c[e+76+(t+768<<2)>>2]=q;q=s+1&65535;if((q&65535)>239){break}else{s=q;t=q&65535}}o=c[3529322]|0;c[e+1036>>2]=o;q=o+256|0;c[e+1040>>2]=q;p=o+512|0;c[e+1044>>2]=p;r=o+768|0;c[e+1048>>2]=r;u=o+1024|0;c[e+1052>>2]=u;v=o+1280|0;c[e+1056>>2]=v;w=o+1536|0;c[e+1060>>2]=w;x=o+1792|0;c[e+1064>>2]=x;c[e+2060>>2]=o;c[e+2064>>2]=q;c[e+2068>>2]=p;c[e+2072>>2]=r;c[e+2076>>2]=u;c[e+2080>>2]=v;c[e+2084>>2]=w;c[e+2088>>2]=x;c[e+3084>>2]=o;c[e+4108>>2]=o;c[e+3088>>2]=q;c[e+4112>>2]=q;c[e+3092>>2]=p;c[e+4116>>2]=p;c[e+3096>>2]=r;c[e+4120>>2]=r;c[e+3100>>2]=u;c[e+4124>>2]=u;c[e+3104>>2]=v;c[e+4128>>2]=v;c[e+3108>>2]=w;c[e+4132>>2]=w;c[e+3112>>2]=x;c[e+4136>>2]=x;c[e+4184>>2]=580;c[e+4180>>2]=370;if(!d){x=e;gGC(x|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=k;c[2417276]=n;c[1836236]=-1;fwR(1);x=c[2439331]|0;w=(x|0)==0;if(!w){v=x;gGC(9706056,v|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];v=c[3528485]|0;c[2076596]=v;u=c[2417277]|0;c[3541536]=u;c[1836236]=1;r=c[3529190]|0;c[x+76>>2]=r;p=r+256|0;c[x+80>>2]=p;q=r+512|0;c[x+84>>2]=q;o=r+768|0;c[x+88>>2]=o;c[x+2124>>2]=r;c[x+3148>>2]=r;c[x+2128>>2]=p;c[x+3152>>2]=p;c[x+2132>>2]=q;c[x+3156>>2]=q;c[x+2136>>2]=o;c[x+3160>>2]=o;o=4;q=4;while(1){c[x+76+(q<<2)>>2]=r+(q<<8);p=o+1&65535;if((p&65535)>255){y=4;z=4;break}else{o=p;q=p&65535}}while(1){q=r+(z<<8)|0;c[x+76+(z+512<<2)>>2]=q;c[x+76+(z+768<<2)>>2]=q;q=y+1&65535;if((q&65535)>255){break}else{y=q;z=q&65535}}c[x+4172>>2]=2484;c[x+4176>>2]=394;if(!w){r=x;gGC(r|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=v;c[2417277]=u;c[1836236]=-1;r=c[2388110]|0;b[r+4412>>1]=20081;b[r+4414>>1]=20081;b[r+6020>>1]=24588;b[r+6370>>1]=24588;b[r+15444>>1]=24588;b[r+75424>>1]=20081;r=a[9680]|0;q=r?32e3:0;if(r){if(a[9624]|0){r=q*3|0;o=55930;while(1){if((o|0)>(r|0)){o=o>>1}else{A=1222;B=o;break}}}else{A=2462;B=q}c[2429380]=B;c[3542124]=A;mw(3579545,B);o=gGq(262144)|0;c[2406684]=o;gGz(o|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(3579545,11025)}h[745421]=.5;c[2436794]=1;h[745420]=.5;c[2436792]=2;c[2405758]=1;gGz(9542544,0,32);c[2385641]=1;h[1192819]=1.0;c[2385642]=3;c[2385643]=3718;o=0;do{r=o*257|0;b[9732544+(o<<1)>>1]=((r|0)/2|0)&65535;b[9753784+(o<<1)>>1]=r+32768&65535;o=o+1|0;}while((o|0)<256);c[3528842]=1;c[2405758]=2;gGz(9542576,0,32);c[2385649]=1;h[1192823]=1.0;c[2385650]=3;c[2385651]=3718;o=0;do{q=o*257|0;b[9732544+(o<<1)>>1]=((q|0)/2|0)&65535;b[9753784+(o<<1)>>1]=q+32768&65535;o=o+1|0;}while((o|0)<256);c[3528842]=1;h[1192819]=.5;c[2385642]=1;h[1192823]=.5;c[2385650]=2;o=c[642608+(c[2436]<<2)>>2]|0;q=c[o+128>>2]|0;if((c[o+52>>2]&4|0)==0){c[2113068]=q;r=c[o+132>>2]|0;c[2113070]=r;c[2443814]=q;c[2440436]=r;C=q;D=r}else{c[2113070]=q;r=c[o+132>>2]|0;c[2113068]=r;c[2440436]=q;c[2443814]=r;C=r;D=q}q=ag(C<<1,D)|0;r=gGq(q)|0;c[2112926]=r;if((r|0)!=0){gGz(r|0,0,q|0)}exW();l=0;return l|0}}while(0);c[2414914]=0;l=1;return l|0}function exP(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if((a[9623848]|0)!=0){exW()}exX();d=c[2392]|0;if((d|0)>=0){gGz(8452240,0,((d|0)>0?(d<<2)+4|0:4)|0)}c[2113054]=0;d=c[2385548]|0;if((d|0)>0){gGz(9752472,0,((d|0)>1?d<<2:4)|0)}c[2433530]=0;if((c[2394]|0)==0){e=0;f=0}else{c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];e=0;f=0}while(1){c[2113056]=2666;d=RG(2666)|0;c[2113054]=(c[2113054]|0)+d;c[2276108]=-1;c[2113056]=-1;do{if((e|0)==49){c[8452200+(c[2394]<<2)>>2]=8193;c[2276080]=256;if((c[2276079]|0)>>>0>=256){break}RH(1)}}while(0);d=c[2439330]|0;if((d|0)!=0){g=d;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;g=c[2438118]|0;c[2433530]=g;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;if((a[d+4188|0]|0)==0){h=gfc(1193)|0;i=c[1836236]|0;j=(c[2433530]|0)+h|0;k=i;l=c[9757320+(i<<2)>>2]|0}else{j=g+1193|0;k=0;l=d}c[2433530]=j;if((l|0)!=0){d=l;gGC(d|0,9706056,76)|0}c[9752472+(k<<2)>>2]=j;c[14113936+(k<<2)>>2]=c[2076596];c[9669104+(k<<2)>>2]=c[3541536];c[1836236]=-1;d=c[2439331]|0;if((d|0)!=0){g=d;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;g=c[2438119]|0;c[2433530]=g;c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;if((a[d+4188|0]|0)==0){i=gfc(1666)|0;h=c[1836236]|0;m=(c[2433530]|0)+i|0;n=h;o=c[9757320+(h<<2)>>2]|0}else{m=g+1666|0;n=1;o=d}c[2433530]=m;if((o|0)!=0){d=o;gGC(d|0,9706056,76)|0}c[9752472+(n<<2)>>2]=m;c[14113936+(n<<2)>>2]=c[2076596];c[9669104+(n<<2)>>2]=c[3541536];c[1836236]=-1;d=c[2112964]|0;if((d|0)==0){p=f}else{g=a[9688]|0?10:0;gg[c[3542124]&4095](d+(f<<1<<1)|0,g);p=g+f|0}g=e+1|0;if((g|0)<50){e=g;f=p}else{break}}f=c[2112964]|0;if((f|0)!=0){e=a[9688]|0?534:0;if((e|0)==(p|0)){q=f;r=p}else{gg[c[3542124]&4095](f+(p<<1<<1)|0,e-p|0);q=c[2112964]|0;r=a[9688]|0?534:0}UR(q,r)}r=c[2394]|0;q=c[14130368+(r<<2)>>2]|0;if((q|0)!=0){gGC(q|0,9104152,280)|0}c[8452240+(r<<2)>>2]=c[2113054];c[2394]=-1;if((c[2112968]|0)==0){return 0}exC()|0;return 0}function exQ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3046460+(b*112|0)>>2];c[a+104>>2]=c[3046464+(b*112|0)>>2];c[a+108>>2]=c[3046468+(b*112|0)>>2];d=0;return d|0}function exR(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=3046360+(b*112|0);e=0;return e|0}function exS(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>40){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1306896+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function exT(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>45){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3047816+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function exU(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;c[2444206]=3;c[2414914]=0;c[2388110]=0;c[3529234]=2097152;c[3529190]=2162688;c[3529168]=2686976;c[3530794]=3211264;c[3529948]=9502720;d=a[9688]|0?534:0;e=d*6|0|16384;c[2440430]=9502720+e;f=e+(d<<2)|0;d=9502720+f|0;c[2414616]=d;c[2388238]=d;c[3529322]=f+9568256;c[3529650]=f+9572352;c[3529630]=f+9703424;c[2387146]=f+9834496;c[3530224]=f+9838592;c[2406920]=f+9904128;d=f+9920512|0;c[2411576]=d;c[2414116]=d;f=d;d=0;while(1){if((d|0)>=1024){break}g=9638528+(d<<2)|0;if((c[g>>2]|0)==0){i=8736;break}else{d=d+1|0}}do{if((i|0)==8736){d=gGq(f)|0;c[g>>2]=d;if((d|0)==0){break}gGz(d|0,0,f|0);c[2414914]=d;gGz(d|0,0,f|0);c[2388110]=d;c[3529234]=d+2097152;c[3529190]=d+2162688;c[3529168]=d+2686976;c[3530794]=d+3211264;e=d+9502720|0;if((c[2444206]|0)==0){c[3530558]=e;j=d+17891328|0}else{j=e}c[3529948]=j;c[2385360]=j+16384;e=a[9688]|0?534:0;d=e*6|0|16384;c[2440430]=j+d;k=d+(e<<2)|0;e=j+k|0;c[2414616]=e;c[2388238]=e;c[3529322]=j+(k+65536);c[3529650]=j+(k+69632);c[3529630]=j+(k+200704);c[2387146]=j+(k+331776);c[3530224]=j+(k+335872);c[2406920]=j+(k+401408);e=j+(k+417792)|0;c[2411576]=e;c[2414116]=e;if((exY()|0)!=0){l=1;return l|0}fxU(0,425984);if((c[2394]|0)==0){m=c[2112932]|0}else{c[2394]=0;e=c[3532596]|0;c[2112932]=e;k=c[3532592]|0;if((k|0)!=0){gGC(9104152,k|0,280)|0}c[2113054]=c[2113060];m=e}e=c[2388110]|0;k=m|0;d=0;while(1){n=e+d|0;c[k>>2]=n;c[k+131072>>2]=n;n=d+1024|0;if(n>>>0>2097151){break}else{k=k+4|0;d=n}}d=c[2388238]|0;c[m+8192>>2]=d;c[m+73728>>2]=d;c[m+139264>>2]=d;k=d+1024|0;c[m+8196>>2]=k;c[m+73732>>2]=k;c[m+139268>>2]=k;k=d+2048|0;c[m+8200>>2]=k;c[m+73736>>2]=k;c[m+139272>>2]=k;k=d+3072|0;c[m+8204>>2]=k;c[m+73740>>2]=k;c[m+139276>>2]=k;k=d+4096|0;c[m+8208>>2]=k;c[m+73744>>2]=k;c[m+139280>>2]=k;k=d+5120|0;c[m+8212>>2]=k;c[m+73748>>2]=k;c[m+139284>>2]=k;k=d+6144|0;c[m+8216>>2]=k;c[m+73752>>2]=k;c[m+139288>>2]=k;k=d+7168|0;c[m+8220>>2]=k;c[m+73756>>2]=k;c[m+139292>>2]=k;k=d+8192|0;c[m+8224>>2]=k;c[m+73760>>2]=k;c[m+139296>>2]=k;k=d+9216|0;c[m+8228>>2]=k;c[m+73764>>2]=k;c[m+139300>>2]=k;k=d+10240|0;c[m+8232>>2]=k;c[m+73768>>2]=k;c[m+139304>>2]=k;k=d+11264|0;c[m+8236>>2]=k;c[m+73772>>2]=k;c[m+139308>>2]=k;k=d+12288|0;c[m+8240>>2]=k;c[m+73776>>2]=k;c[m+139312>>2]=k;k=d+13312|0;c[m+8244>>2]=k;c[m+73780>>2]=k;c[m+139316>>2]=k;k=d+14336|0;c[m+8248>>2]=k;c[m+73784>>2]=k;c[m+139320>>2]=k;k=d+15360|0;c[m+8252>>2]=k;c[m+73788>>2]=k;c[m+139324>>2]=k;k=c[3530224]|0;c[m+16388>>2]=k;c[m+81924>>2]=k;c[m+147460>>2]=k;d=k+1024|0;c[m+16392>>2]=d;c[m+81928>>2]=d;c[m+147464>>2]=d;d=k+2048|0;c[m+16396>>2]=d;c[m+81932>>2]=d;c[m+147468>>2]=d;d=c[3529650]|0;k=m+24576|0;e=6291456;while(1){n=d+(e-6291456)|0;c[k>>2]=n;c[k+65536>>2]=n;c[k+131072>>2]=n;n=e+1024|0;if(n>>>0>6422527){break}else{k=k+4|0;e=n}}c[m+196648>>2]=1256;c[m+196728>>2]=3106;c[m+196608>>2]=2838;c[m+196688>>2]=1110;e=c[3532592]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);e=c[2439330]|0;k=(e|0)==0;if(!k){d=e;gGC(9706056,d|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];d=c[3528484]|0;c[2076596]=d;n=c[2417276]|0;c[3541536]=n;c[1836236]=0;o=c[3529234]|0;p=0;q=0;while(1){c[e+76+(q<<2)>>2]=o+(q<<8);r=p+1&65535;if((r&65535)>127){s=0;t=0;break}else{p=r;q=r&65535}}while(1){q=o+(t<<8)|0;c[e+76+(t+512<<2)>>2]=q;c[e+76+(t+768<<2)>>2]=q;q=s+1&65535;if((q&65535)>127){break}else{s=q;t=q&65535}}o=c[3529322]|0;c[e+1036>>2]=o;q=o+256|0;c[e+1040>>2]=q;p=o+512|0;c[e+1044>>2]=p;r=o+768|0;c[e+1048>>2]=r;u=o+1024|0;c[e+1052>>2]=u;v=o+1280|0;c[e+1056>>2]=v;w=o+1536|0;c[e+1060>>2]=w;x=o+1792|0;c[e+1064>>2]=x;c[e+2060>>2]=o;c[e+2064>>2]=q;c[e+2068>>2]=p;c[e+2072>>2]=r;c[e+2076>>2]=u;c[e+2080>>2]=v;c[e+2084>>2]=w;c[e+2088>>2]=x;c[e+3084>>2]=o;c[e+4108>>2]=o;c[e+3088>>2]=q;c[e+4112>>2]=q;c[e+3092>>2]=p;c[e+4116>>2]=p;c[e+3096>>2]=r;c[e+4120>>2]=r;c[e+3100>>2]=u;c[e+4124>>2]=u;c[e+3104>>2]=v;c[e+4128>>2]=v;c[e+3108>>2]=w;c[e+4132>>2]=w;c[e+3112>>2]=x;c[e+4136>>2]=x;c[e+4184>>2]=1038;c[e+4180>>2]=370;if(!k){x=e;gGC(x|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=d;c[2417276]=n;c[1836236]=-1;fwR(1);x=c[2439331]|0;w=(x|0)==0;if(!w){v=x;gGC(9706056,v|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];v=c[3528485]|0;c[2076596]=v;u=c[2417277]|0;c[3541536]=u;c[1836236]=1;r=c[3529190]|0;c[x+76>>2]=r;c[x+80>>2]=r+256;c[x+84>>2]=r+512;c[x+88>>2]=r+768;c[x+92>>2]=r+1024;c[x+96>>2]=r+1280;c[x+100>>2]=r+1536;c[x+104>>2]=r+1792;c[x+108>>2]=r+2048;c[x+112>>2]=r+2304;c[x+116>>2]=r+2560;c[x+120>>2]=r+2816;c[x+124>>2]=r+3072;c[x+128>>2]=r+3328;c[x+132>>2]=r+3584;c[x+136>>2]=r+3840;p=0;q=0;while(1){o=r+(q<<8)|0;c[x+76+(q+512<<2)>>2]=o;c[x+76+(q+768<<2)>>2]=o;o=p+1&65535;if((o&65535)>15){y=16;z=16;break}else{p=o;q=o&65535}}while(1){c[x+76+(z<<2)>>2]=r+(z<<8);q=y+1&65535;if((q&65535)>255){A=16;B=16;break}else{y=q;z=q&65535}}while(1){q=r+(B<<8)|0;c[x+76+(B+512<<2)>>2]=q;c[x+76+(B+768<<2)>>2]=q;q=A+1&65535;if((q&65535)>255){break}else{A=q;B=q&65535}}c[x+4172>>2]=2372;c[x+4176>>2]=760;if(!w){r=x;gGC(r|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=v;c[2417277]=u;c[1836236]=-1;fwR(2);r=c[2439332]|0;q=(r|0)==0;if(!q){p=r;gGC(9706056,p|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438120];p=c[3528486]|0;c[2076596]=p;n=c[2417278]|0;c[3541536]=n;c[1836236]=2;d=c[3529168]|0;c[r+76>>2]=d;c[r+80>>2]=d+256;c[r+84>>2]=d+512;c[r+88>>2]=d+768;c[r+92>>2]=d+1024;c[r+96>>2]=d+1280;c[r+100>>2]=d+1536;c[r+104>>2]=d+1792;c[r+108>>2]=d+2048;c[r+112>>2]=d+2304;c[r+116>>2]=d+2560;c[r+120>>2]=d+2816;c[r+124>>2]=d+3072;c[r+128>>2]=d+3328;c[r+132>>2]=d+3584;c[r+136>>2]=d+3840;e=0;k=0;while(1){o=d+(k<<8)|0;c[r+76+(k+512<<2)>>2]=o;c[r+76+(k+768<<2)>>2]=o;o=e+1&65535;if((o&65535)>15){C=16;D=16;break}else{e=o;k=o&65535}}while(1){c[r+76+(D<<2)>>2]=d+(D<<8);k=C+1&65535;if((k&65535)>255){E=16;F=16;break}else{C=k;D=k&65535}}while(1){k=d+(F<<8)|0;c[r+76+(F+512<<2)>>2]=k;c[r+76+(F+768<<2)>>2]=k;k=E+1&65535;if((k&65535)>255){break}else{E=k;F=k&65535}}c[r+4172>>2]=948;c[r+4176>>2]=3280;if(!q){d=r;gGC(d|0,9706056,76)|0}c[2438120]=c[2433530];c[3528486]=p;c[2417278]=n;c[1836236]=-1;d=a[9680]|0;k=d?32e3:0;if(d){if(a[9624]|0){d=k*3|0;e=55930;while(1){if((e|0)>(d|0)){e=e>>1}else{G=1222;H=e;break}}}else{G=2462;H=k}c[2429380]=H;c[3542124]=G;mw(3579545,H);e=gGq(262144)|0;c[2406684]=e;gGz(e|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(3579545,11025)}h[745421]=.2;c[2436794]=1;h[745420]=.2;c[2436792]=2;c[2405758]=1;gGz(9542544,0,32);c[2385641]=1;h[1192819]=1.0;c[2385642]=3;c[2385643]=3718;e=0;do{d=e*257|0;b[9732544+(e<<1)>>1]=((d|0)/2|0)&65535;b[9753784+(e<<1)>>1]=d+32768&65535;e=e+1|0;}while((e|0)<256);c[3528842]=1;c[2405758]=2;gGz(9542576,0,32);c[2385649]=1;h[1192823]=1.0;c[2385650]=3;c[2385651]=3718;e=0;do{k=e*257|0;b[9732544+(e<<1)>>1]=((k|0)/2|0)&65535;b[9753784+(e<<1)>>1]=k+32768&65535;e=e+1|0;}while((e|0)<256);c[3528842]=1;c[2405758]=3;gGz(9542608,0,32);c[2385657]=1;h[1192827]=1.0;c[2385658]=3;c[2385659]=3718;e=0;do{k=e*257|0;b[9732544+(e<<1)>>1]=((k|0)/2|0)&65535;b[9753784+(e<<1)>>1]=k+32768&65535;e=e+1|0;}while((e|0)<256);c[3528842]=1;c[2405758]=4;gGz(9542640,0,32);c[2385665]=1;h[1192831]=1.0;c[2385666]=3;c[2385667]=3718;e=0;do{k=e*257|0;b[9732544+(e<<1)>>1]=((k|0)/2|0)&65535;b[9753784+(e<<1)>>1]=k+32768&65535;e=e+1|0;}while((e|0)<256);c[3528842]=1;h[1192819]=.4;c[2385642]=1;h[1192823]=.4;c[2385650]=2;h[1192827]=.4;c[2385658]=1;h[1192831]=.4;c[2385666]=2;exW();e=c[642608+(c[2436]<<2)>>2]|0;k=c[e+128>>2]|0;if((c[e+52>>2]&4|0)==0){c[2113068]=k;d=c[e+132>>2]|0;c[2113070]=d;c[2443814]=k;c[2440436]=d;I=k;J=d}else{c[2113070]=k;d=c[e+132>>2]|0;c[2113068]=d;c[2440436]=k;c[2443814]=d;I=d;J=k}k=ag(I<<1,J)|0;d=gGq(k)|0;c[2112926]=d;if((d|0)==0){l=0;return l|0}gGz(d|0,0,k|0);l=0;return l|0}}while(0);c[2414914]=0;l=1;return l|0}function exV(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;if((a[9623848]|0)!=0){exW()}exX();d=c[2392]|0;if((d|0)>=0){gGz(8452240,0,((d|0)>0?(d<<2)+4|0:4)|0)}c[2113054]=0;d=c[2385548]|0;if((d|0)>0){gGz(9752472,0,((d|0)>1?d<<2:4)|0)}c[2433530]=0;if((c[2394]|0)==0){e=0;f=0}else{c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];e=0;f=0}while(1){c[2113056]=2666;d=RG(2666)|0;c[2113054]=(c[2113054]|0)+d;c[2276108]=-1;c[2113056]=-1;do{if((e|0)==24){c[8452200+(c[2394]<<2)>>2]=8194;c[2276080]=512;if((c[2276079]|0)>>>0>=512){break}RH(2)}else if((e|0)==49){c[8452200+(c[2394]<<2)>>2]=8193;c[2276080]=256;if((c[2276079]|0)>>>0>=256){break}RH(1)}}while(0);d=c[2439330]|0;if((d|0)!=0){g=d;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;g=c[2438118]|0;c[2433530]=g;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;if((a[d+4188|0]|0)==0){h=gfc(1193)|0;i=c[1836236]|0;j=(c[2433530]|0)+h|0;k=i;l=c[9757320+(i<<2)>>2]|0}else{j=g+1193|0;k=0;l=d}c[2433530]=j;if((l|0)!=0){d=l;gGC(d|0,9706056,76)|0}c[9752472+(k<<2)>>2]=j;c[14113936+(k<<2)>>2]=c[2076596];c[9669104+(k<<2)>>2]=c[3541536];c[1836236]=-1;d=c[2439331]|0;if((d|0)!=0){g=d;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;g=c[2438119]|0;c[2433530]=g;c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;if((a[d+4188|0]|0)==0){i=gfc(1666)|0;h=c[1836236]|0;m=(c[2433530]|0)+i|0;n=h;o=c[9757320+(h<<2)>>2]|0}else{m=g+1666|0;n=1;o=d}c[2433530]=m;if((o|0)!=0){d=o;gGC(d|0,9706056,76)|0}c[9752472+(n<<2)>>2]=m;c[14113936+(n<<2)>>2]=c[2076596];c[9669104+(n<<2)>>2]=c[3541536];c[1836236]=-1;d=c[2439332]|0;if((d|0)!=0){g=d;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;g=c[2438120]|0;c[2433530]=g;c[2076596]=c[3528486];c[3541536]=c[2417278];c[1836236]=2;if((a[d+4188|0]|0)==0){h=gfc(1666)|0;i=c[1836236]|0;p=(c[2433530]|0)+h|0;q=i;r=c[9757320+(i<<2)>>2]|0}else{p=g+1666|0;q=2;r=d}c[2433530]=p;if((r|0)!=0){d=r;gGC(d|0,9706056,76)|0}c[9752472+(q<<2)>>2]=p;c[14113936+(q<<2)>>2]=c[2076596];c[9669104+(q<<2)>>2]=c[3541536];c[1836236]=-1;d=c[2112964]|0;if((d|0)==0){s=f}else{g=a[9688]|0?10:0;gg[c[3542124]&4095](d+(f<<1<<1)|0,g);s=g+f|0}g=e+1|0;if((g|0)<50){e=g;f=s}else{break}}f=c[2112964]|0;if((f|0)!=0){e=a[9688]|0?534:0;if((e|0)==(s|0)){t=f;u=s}else{gg[c[3542124]&4095](f+(s<<1<<1)|0,e-s|0);t=c[2112964]|0;u=a[9688]|0?534:0}UR(t,u)}u=c[2394]|0;t=c[14130368+(u<<2)>>2]|0;if((t|0)!=0){gGC(t|0,9104152,280)|0}c[8452240+(u<<2)>>2]=c[2113054];c[2394]=-1;if((c[2112968]|0)==0){return 0}exC()|0;return 0}function exW(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;a[9623848]=0;d=c[2414616]|0;gGz(d|0,0,(c[2411576]|0)-d|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=i;c[1836236]=-1;i=c[2439331]|0;g=(i|0)==0;if(!g){f=i;gGC(9706056,f|0,76)|0}f=c[2438119]|0;c[2433530]=f;e=c[3528485]|0;c[2076596]=e;d=c[2417277]|0;c[3541536]=d;c[1836236]=1;gGz(9706056,0,76);if(!g){j=i;gGC(j|0,9706056,76)|0}c[2438119]=f;c[3528485]=e;c[2417277]=d;c[1836236]=-1;j=c[2444206]|0;do{if((j|0)==3){k=c[2439332]|0;l=(k|0)==0;if(!l){m=k;gGC(9706056,m|0,76)|0}m=c[2438120]|0;c[2433530]=m;n=c[3528486]|0;c[2076596]=n;o=c[2417278]|0;c[3541536]=o;c[1836236]=2;gGz(9706056,0,76);if(!l){p=k;gGC(p|0,9706056,76)|0}c[2438120]=m;c[3528486]=n;c[2417278]=o;c[1836236]=-1;a[14112944]=0;a[9774864]=0;a[9774848]=0;a[14115224]=0;a[9747048]=0;a[14114728]=0;a[9774673]=0;a[9774672]=0;if(!g){o=i;gGC(9706056,o|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=f;c[2076596]=e;c[3541536]=d;c[1836236]=1;o=c[3529190]|0;n=16;m=16;while(1){c[i+76+(m<<2)>>2]=o+(m<<8);p=n+1&65535;if((p&65535)>255){q=16;r=16;break}else{n=p;m=p&65535}}while(1){m=o+(r<<8)|0;c[i+76+(r+512<<2)>>2]=m;c[i+76+(r+768<<2)>>2]=m;m=q+1&65535;if((m&65535)>255){break}else{q=m;r=m&65535}}if(!g){o=i;gGC(o|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=e;c[2417277]=d;c[1836236]=-1;if(!l){o=k;gGC(9706056,o|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438120];o=c[3528486]|0;c[2076596]=o;m=c[2417278]|0;c[3541536]=m;c[1836236]=2;n=c[3529168]|0;p=16;s=16;while(1){c[k+76+(s<<2)>>2]=n+(s<<8);t=p+1&65535;if((t&65535)>255){u=16;v=16;break}else{p=t;s=t&65535}}while(1){s=n+(v<<8)|0;c[k+76+(v+512<<2)>>2]=s;c[k+76+(v+768<<2)>>2]=s;s=u+1&65535;if((s&65535)>255){break}else{u=s;v=s&65535}}if(!l){n=k;gGC(n|0,9706056,76)|0}c[2438120]=c[2433530];c[3528486]=o;c[2417278]=m;c[1836236]=-1;w=8902}else{a[14112944]=0;a[9774864]=0;a[9774848]=0;a[14115224]=0;a[9747048]=0;a[14114728]=0;a[9774673]=0;a[9774672]=0;if((j|0)==2){if(!g){n=i;gGC(9706056,n|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];n=c[3528485]|0;c[2076596]=n;s=c[2417277]|0;c[3541536]=s;c[1836236]=1;p=c[3529190]|0;t=4;x=4;while(1){c[i+76+(x<<2)>>2]=p+(x<<8);y=t+1&65535;if((y&65535)>255){z=4;A=4;break}else{t=y;x=y&65535}}while(1){x=p+(A<<8)|0;c[i+76+(A+512<<2)>>2]=x;c[i+76+(A+768<<2)>>2]=x;x=z+1&65535;if((x&65535)>255){break}else{z=x;A=x&65535}}if(!g){p=i;gGC(p|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=n;c[2417277]=s;c[1836236]=-1;B=j}else{B=j}if((B|0)==1){if(!g){p=i;gGC(9706056,p|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];p=c[3528485]|0;c[2076596]=p;x=c[2417277]|0;c[3541536]=x;c[1836236]=1;t=c[3529190]|0;m=16;o=16;while(1){c[i+76+(o<<2)>>2]=t+(o<<8);k=m+1&65535;if((k&65535)>255){C=16;D=16;break}else{m=k;o=k&65535}}while(1){o=t+(D<<8)|0;c[i+76+(D+512<<2)>>2]=o;c[i+76+(D+768<<2)>>2]=o;o=C+1&65535;if((o&65535)>255){break}else{C=o;D=o&65535}}if(!g){t=i;gGC(t|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=p;c[2417277]=x;c[1836236]=-1;E=j}else{E=B}if((E|0)!=0){w=8902;break}c[2443825]=1073676288;c[2443824]=1073676288;c[2443817]=1073676288;c[2443816]=1073676288;h[883199]=0.0;c[3528506]=0;lw(c[3540986]|0);mB(0)}}while(0);if((w|0)==8902){mx(0)}w=c[2405758]|0;if((w|0)>0){F=0}else{return}do{c[9542560+(F<<5)>>2]=0;b[9542544+(F<<5)>>1]=0;F=F+1|0;}while((F|0)<(w|0));return}function exX(){var e=0,f=0,g=0,h=0,i=0,j=0;gGz(9550320,-1|0,12);e=0;f=-1;g=-1;h=-1;i=-1;j=-1;do{f=((d[9632960+e|0]|0)<<e^f&65535)&65535;g=((d[9630832+e|0]|0)<<e^g&65535)&65535;h=((d[9629344+e|0]|0)<<e^h&65535)&65535;i=((d[9628880+e|0]|0)<<e^i&65535)&65535;j=((d[9628648+e|0]|0)<<e^j&65535)&65535;e=e+1|0;}while((e|0)<16);b[4775160]=f;b[4775161]=g;b[4775162]=h;b[4775163]=i;b[4775165]=j;i=c[2444206]|0;if((i|0)==0){b[4775162]=(d[9634897]|0)<<8|(d[9634896]|0);return}else if((i|0)==1){b[4775162]=d[9634896]|0;return}else if((i|0)==2){b[4775161]=(d[9634896]|0)<<8|g&255;b[4775162]=d[9634897]|0;b[4775163]=d[9634898]|0;return}else if((i|0)==3){b[4775164]=(d[9634897]|0)<<8|(d[9634896]|0);b[4775165]=j&254|a[9634898]&1|-256;return}else{return}}function exY(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0;b=i;i=i+800|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;l=b+360|0;m=b+472|0;n=b+480|0;o=b+592|0;p=b+600|0;q=b+616|0;r=b+648|0;s=b+680|0;t=b+688|0;u=c[2388110]|0;v=c[3529234]|0;w=c[3529190]|0;x=c[3529168]|0;y=c[3530794]|0;z=c[3530558]|0;if((gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](s,0,0)|0)!=0){c[2443924]=0;A=0;i=b;return A|0}B=t+108|0;C=t+100|0;D=n+108|0;E=n+100|0;F=l+108|0;G=l+100|0;H=j+108|0;I=j+100|0;J=g+108|0;K=g+100|0;L=e+108|0;M=e+100|0;N=u;u=y;y=z;z=0;O=0;P=0;L12154:while(1){gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,P)|0;L12156:do{switch(c[B>>2]&7|0){case 3:{if((c[3542200]|0)==0){A=1;Q=9005;break L12154}c[F>>2]=0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,P)|0;if((c[F>>2]|0)==0){R=P;S=O;T=z;U=y;V=u;W=N;break L12156}X=c[G>>2]|0;c[m>>2]=9534384;gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](m,P,0)|0;if((X|0)<1){A=1;Q=8998;break L12154}if((gzL(w,0,P)|0)==0){R=P;S=O;T=z;U=y;V=u;W=N}else{A=1;Q=9001;break L12154}break};case 6:{if((c[3542200]|0)==0){A=1;Q=9007;break L12154}c[L>>2]=0;c[M>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,P)|0;if((c[L>>2]|0)!=0){X=c[M>>2]|0;c[f>>2]=9534384;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Y&16383](f,P,0)|0;if((X|0)<1){A=1;Q=9012;break L12154}if((gzL(y,0,P)|0)!=0){A=1;Q=9009;break L12154}}X=c[C>>2]|0;R=P;S=X+O|0;T=z;U=y+X|0;V=u;W=N;break};case 4:{if((c[3542200]|0)==0){A=1;Q=9010;break L12154}c[H>>2]=0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,P)|0;if((c[H>>2]|0)==0){R=P;S=O;T=z;U=y;V=u;W=N;break L12156}X=c[I>>2]|0;c[k>>2]=9534384;gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](k,P,0)|0;if((X|0)<1){A=1;Q=8996;break L12154}if((gzL(x,0,P)|0)==0){R=P;S=O;T=z;U=y;V=u;W=N}else{A=1;Q=8997;break L12154}break};case 2:{if((c[3542200]|0)==0){A=1;Q=9011;break L12154}c[D>>2]=0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,P)|0;if((c[D>>2]|0)==0){R=P;S=O;T=z;U=y;V=u;W=N;break L12156}X=c[E>>2]|0;c[o>>2]=9534384;gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](o,P,0)|0;if((X|0)<1){A=1;Q=9e3;break L12154}if((gzL(v,0,P)|0)==0){R=P;S=O;T=z;U=y;V=u;W=N}else{A=1;Q=9004;break L12154}break};case 1:{if((R6(N+1|0,P,2)|0)!=0){A=1;Q=9014;break L12154}X=P+1|0;if((R6(N,X,2)|0)!=0){A=1;Q=8999;break L12154}R=X;S=O;T=z;U=y;V=u;W=N+1048576|0;break};case 5:{if((c[3542200]|0)==0){A=1;Q=9015;break L12154}c[J>>2]=0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,P)|0;if((c[J>>2]|0)!=0){X=c[K>>2]|0;c[h>>2]=9534384;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Y&16383](h,P,0)|0;if((X|0)<1){A=1;Q=8994;break L12154}if((gzL(u,0,P)|0)!=0){A=1;Q=8995;break L12154}}X=c[C>>2]|0;R=P;S=O;T=X+z|0;U=y;V=u+X|0;W=N;break};default:{R=P;S=O;T=z;U=y;V=u;W=N}}}while(0);X=R+1|0;if((gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](s,X,0)|0)==0){N=W;u=V;y=U;z=T;O=S;P=X}else{Q=8952;break}}if((Q|0)==8994){i=b;return A|0}else if((Q|0)==8995){i=b;return A|0}else if((Q|0)==8996){i=b;return A|0}else if((Q|0)==8952){c[2443924]=T>>5;L12190:do{if((T|0)!=0){P=c[3530794]|0;O=q;z=r;U=T<<2;c[p>>2]=U;c[p+4>>2]=U+4;c[p+8>>2]=0;c[p+12>>2]=4;gGC(O|0,6669320,32)|0;gGC(z|0,6669224,32)|0;z=0;while(1){if((z|0)>=1024){break L12190}Z=9638528+(z<<2)|0;if((c[Z>>2]|0)==0){break}else{z=z+1|0}}z=gGq(T)|0;c[Z>>2]=z;if((z|0)==0){break}gGz(z|0,0,T|0);if((T|0)>0){O=0;do{a[z+O|0]=~a[P+O|0];O=O+1|0;}while((O|0)<(T|0))}O=T<<3;U=(O|0)/256|0;if((O|0)>255){O=0;while(1){y=O<<6;gGz(P+y|0,0,64);V=O<<7;u=0;do{W=1<<3-u;N=(c[p+(u<<2)>>2]|0)+V|0;s=0;do{R=N+(c[r+(s<<2)>>2]|0)|0;C=(s<<3)+y|0;h=0;do{K=R+(c[q+(h<<2)>>2]|0)|0;if(((d[z+((K|0)/8|0)|0]|0)&128>>>((K&7)>>>0)|0)!=0){K=P+(C+h)|0;a[K]=(d[K]|0|W)&255}h=h+1|0;}while((h|0)<8);s=s+1|0;}while((s|0)<8);u=u+1|0;}while((u|0)<4);u=O+1|0;if((u|0)<(U|0)){O=u}else{_=0;break}}}else{_=0}while(1){if((_|0)>=1024){break L12190}$=9638528+(_<<2)|0;if((c[$>>2]|0)==(z|0)){break}else{_=_+1|0}}gGr(z);c[$>>2]=0}}while(0);if((S|0)==0){A=0;i=b;return A|0}$=c[3530558]|0;_=q;T=r;Z=S<<2;c[p>>2]=Z;c[p+4>>2]=Z+4;c[p+8>>2]=0;c[p+12>>2]=4;gGC(_|0,6669320,32)|0;gGC(T|0,6669224,32)|0;T=0;while(1){if((T|0)>=1024){A=0;Q=8993;break}aa=9638528+(T<<2)|0;if((c[aa>>2]|0)==0){break}else{T=T+1|0}}if((Q|0)==8993){i=b;return A|0}T=gGq(S)|0;c[aa>>2]=T;if((T|0)==0){A=0;i=b;return A|0}gGz(T|0,0,S|0);if((S|0)>0){aa=0;do{a[T+aa|0]=~a[$+aa|0];aa=aa+1|0;}while((aa|0)<(S|0))}aa=S<<3;S=(aa|0)/256|0;if((aa|0)>255){aa=0;while(1){_=aa<<6;gGz($+_|0,0,64);Z=aa<<7;O=0;do{U=1<<3-O;P=(c[p+(O<<2)>>2]|0)+Z|0;u=0;do{y=P+(c[r+(u<<2)>>2]|0)|0;V=(u<<3)+_|0;s=0;do{W=y+(c[q+(s<<2)>>2]|0)|0;if(((d[T+((W|0)/8|0)|0]|0)&128>>>((W&7)>>>0)|0)!=0){W=$+(V+s)|0;a[W]=(d[W]|0|U)&255}s=s+1|0;}while((s|0)<8);u=u+1|0;}while((u|0)<8);O=O+1|0;}while((O|0)<4);O=aa+1|0;if((O|0)<(S|0)){aa=O}else{ab=0;break}}}else{ab=0}while(1){if((ab|0)>=1024){A=0;Q=9003;break}ac=9638528+(ab<<2)|0;if((c[ac>>2]|0)==(T|0)){break}else{ab=ab+1|0}}if((Q|0)==9003){i=b;return A|0}gGr(T);c[ac>>2]=0;A=0;i=b;return A|0}else if((Q|0)==9011){i=b;return A|0}else if((Q|0)==9012){i=b;return A|0}else if((Q|0)==9014){i=b;return A|0}else if((Q|0)==9015){i=b;return A|0}else if((Q|0)==8997){i=b;return A|0}else if((Q|0)==8998){i=b;return A|0}else if((Q|0)==8999){i=b;return A|0}else if((Q|0)==9e3){i=b;return A|0}else if((Q|0)==9001){i=b;return A|0}else if((Q|0)==9004){i=b;return A|0}else if((Q|0)==9005){i=b;return A|0}else if((Q|0)==9007){i=b;return A|0}else if((Q|0)==9009){i=b;return A|0}else if((Q|0)==9010){i=b;return A|0}return 0}function exZ(){return~~((a[9688]|0?534.0:0.0)*(+((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)/(5.0e6/(+(c[2424]|0)/100.0))))|0}function ex_(){return~~((a[9688]|0?534.0:0.0)*(+((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)/(6.0e6/(+(c[2424]|0)/100.0))))|0}function ex$(b,f,g){b=b|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;h=c[2112926]|0;i=32256;do{j=e[b+(i<<1)>>1]|0;k=e[b+((i|1)<<1)>>1]|0;l=e[b+(i+32768<<1)>>1]|0;m=k>>>12;n=j>>>12;o=j>>>8<<1;p=o&30;q=l<<1;r=l>>>4&12;if((r|0)==4){s=256;t=32;u=9022}else if((r|0)==8){v=p;w=0;x=256;y=304;z=2}else if((r|0)==0){v=p;w=0;x=16;y=256;z=2}else{s=288;t=256;u=9022}if((u|0)==9022){u=0;v=o&28;w=(o&2|0)!=0;x=t;y=s;z=4}o=(k&255)-(k&256)|0;p=y-j-x|0;j=w?-1:1;r=w?z-1|0:0;l=z<<3;A=(n<<5|k&512)<<5;k=m<<14;m=0;n=0;while(1){B=m+q&31|A;C=p+n&255;D=248-C|0;if(w){E=r;F=0;do{G=E+v<<5&992|B;H=e[b+(G<<1)>>1]|0;I=F+o|0;J=H&16384;K=H&32768;if((a[14114728]|0)==0){L=K;M=J^16384;N=C;O=I}else{L=K^32768;M=J;N=D;O=248-I|0}I=(d[14115224]<<4)+(e[b+(G+32768<<1)>>1]|0)&127;G=(H&16383|k|0)%(g|0)|0;H=N-16|0;E=E+j|0;do{if((H|0)>=-15){if((H|0)>((c[2113070]|0)-1|0)|(O|0)<-15){break}if((O|0)>((c[2113068]|0)-1|0)){break}J=(M|0)!=0;if((L|0)==0){if(J){St(h,G,O,H,I,4,15,0,f);break}else{Sr(h,G,O,H,I,4,15,0,f);break}}else{if(J){Sx(h,G,O,H,I,4,15,0,f);break}else{Sv(h,G,O,H,I,4,15,0,f);break}}}}while(0);F=F+8|0;}while((F|0)<(l|0))}else{F=r;E=0;do{I=F+v<<5&992|B;H=e[b+(I<<1)>>1]|0;G=E+o|0;J=H&16384;K=H&32768;if((a[14114728]|0)==0){P=K;Q=J;R=C;S=G}else{P=K^32768;Q=J^16384;R=D;S=248-G|0}G=(d[14115224]<<4)+(e[b+(I+32768<<1)>>1]|0)&127;I=(H&16383|k|0)%(g|0)|0;H=R-16|0;F=F+j|0;do{if((H|0)>=-15){if((H|0)>((c[2113070]|0)-1|0)|(S|0)<-15){break}if((S|0)>((c[2113068]|0)-1|0)){break}J=(Q|0)!=0;if((P|0)==0){if(J){St(h,I,S,H,G,4,15,0,f);break}else{Sr(h,I,S,H,G,4,15,0,f);break}}else{if(J){Sx(h,I,S,H,G,4,15,0,f);break}else{Sv(h,I,S,H,G,4,15,0,f);break}}}}while(0);E=E+8|0;}while((E|0)<(l|0))}E=n+8|0;if((E|0)<(x|0)){m=m+1|0;n=E}else{break}}i=i+2|0;}while((i|0)<32768);return}function ex0(b,c){b=b|0;c=c|0;a[9706117]=(c|0)!=0|0;return}function ex1(a){a=a|0;var b=0,d=0;b=(c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,6e6,0)|0;return a|0}function ex2(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,i=0;if((a|0)==8388609){e=b&255;f=c[2415306]|0;switch(f|0){case 8:case 9:case 10:case 11:case 12:case 13:{c[9661232+((f&7)*56|0)>>2]=e;return};case 20:{c[2415309]=e&1;c[2415323]=e&2;c[2415337]=e&4;c[2415351]=e&8;c[2415365]=e&16;c[2415379]=e&32;return};case 22:{c[2415290]=e&3;c[2415291]=e>>>4&3;return};case 24:case 25:{g=f-24|0;c[9661176+(g<<2)>>2]=e&1;c[9661184+(g<<2)>>2]=e>>>1&7;c[9661192+(g<<2)>>2]=e&16;c[9661200+(g<<2)>>2]=e&32;c[9661168+(g<<2)>>2]=e&128;c[9661208+(g<<2)>>2]=0;return};case 28:{c[2415304]=e&1;g=e&2;c[2415305]=g;if((g|0)==0){return}c[2415320]=0;h[1207658]=0.0;c[2415334]=0;h[1207665]=0.0;c[2415348]=0;h[1207672]=0.0;c[2415362]=0;h[1207679]=0.0;c[2415376]=0;h[1207686]=0.0;c[2415390]=0;h[1207693]=0.0;return};case 0:case 1:case 2:case 3:case 4:case 5:{g=f&7;c[9661248+(g*56|0)>>2]=c[1619072+((e&15)<<2)>>2];c[9661252+(g*56|0)>>2]=c[1619072+(e>>>4<<2)>>2];return};case 21:{c[2415310]=e&1;c[2415324]=e&2;c[2415338]=e&4;c[2415352]=e&8;c[2415366]=e&16;c[2415380]=e&32;return};case 16:case 17:case 18:{g=f<<1;c[9661244+((g-32|0)*56|0)>>2]=e&7;c[9661244+((g-31|0)*56|0)>>2]=e>>>4&7;return};default:{return}}}else if((a|0)==8388611){e=b&31;c[2415306]=e;if((e-24|0)>>>0>=2){return}do{if((c[2415300]|0)!=0){if((c[2415292]|0)==0){c[2415343]=16;c[2415329]=16;c[2415315]=16;c[2415342]=16;c[2415328]=16;c[2415314]=16;break}e=c[2415296]|0;g=c[2415302]|0;f=g+1&63|g&32;c[2415302]=f;g=(c[2415298]|0)==0?15:14;i=d[641016+(e<<6)+f|0]|0;f=i&g;c[2415342]=f;c[2415328]=f;c[2415314]=f;if((c[2415294]&1|0)==0){c[2415343]=f;c[2415329]=f;c[2415315]=f;break}else{f=15-i&g;c[2415343]=f;c[2415329]=f;c[2415315]=f;break}}}while(0);if((c[2415301]|0)==0){return}if((c[2415293]|0)==0){c[2415385]=16;c[2415371]=16;c[2415357]=16;c[2415384]=16;c[2415370]=16;c[2415356]=16;return}f=c[2415297]|0;g=c[2415303]|0;i=g+1&63|g&32;c[2415303]=i;g=(c[2415299]|0)==0?15:14;e=d[641016+(f<<6)+i|0]|0;i=e&g;c[2415384]=i;c[2415370]=i;c[2415356]=i;if((c[2415295]&1|0)==0){c[2415385]=i;c[2415371]=i;c[2415357]=i;return}else{i=15-e&g;c[2415385]=i;c[2415371]=i;c[2415357]=i;return}}else if((a|0)==10485773){c[2415256]=b&1;return}else if((a|0)==10485769){i=b&1;c[3528406]=(i^1)&255;if(i<<24>>24!=0){return}c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];return}else if((a|0)==10485771){Tr(b&1);return}else{return}}function ex3(b){b=b|0;var d=0,e=0,f=0,g=0;if((b|0)==6291457){d=a[9634888]&-17;do{if((c[2406632]|0)==0){e=c[2443744]|0;if((e|0)<=0){f=16;break}c[2443744]=e-1;f=0}else{f=(1<<c[(c[2420380]|0)+4>>2]&c[2432962]|0)!=0?16:0}}while(0);g=f|d;return g|0}else if((b|0)==2097153){g=a[9550312]|0;return g|0}else if((b|0)==4194304){g=a[9550313]|0;return g|0}else{g=0;return g|0}return 0}function ex4(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2067644+(b*112|0)>>2];c[a+104>>2]=c[2067648+(b*112|0)>>2];c[a+108>>2]=c[2067652+(b*112|0)>>2];d=0;return d|0}function ex5(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=2067544+(b*112|0);e=0;return e|0}function ex6(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1172640+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function ex7(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3203376+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function ex8(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0.0,P=0.0,Q=0.0;e=i;i=i+600|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;c[2414912]=0;c[2388108]=0;c[2387812]=131072;c[3531e3]=393216;c[3529946]=393984;c[2414614]=395008;c[2386420]=395008;c[2386200]=409344;c[2411574]=411392;r=0;while(1){if((r|0)>=1024){break}s=9638528+(r<<2)|0;if((c[s>>2]|0)==0){t=9148;break}else{r=r+1|0}}do{if((t|0)==9148){r=gGq(411392)|0;c[s>>2]=r;if((r|0)==0){break}c[2414912]=r;gGz(r|0,0,411392);c[2388108]=r;c[2387812]=r+131072;c[3531e3]=r+393216;c[3529946]=r+393984;u=r+395008|0;c[2414614]=u;c[2386420]=u;c[2386200]=r+409344;u=r+411392|0;c[2411574]=u;c[2414114]=u;if((R6(r+1|0,0,2)|0)!=0){v=1;i=e;return v|0}if((R6(c[2388108]|0,1,2)|0)!=0){v=1;i=e;return v|0}r=c[2387812]|0;if((c[3542200]|0)==0){v=1;i=e;return v|0}u=p+108|0;c[u>>2]=0;w=p+100|0;c[w>>2]=0;x=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[x&16383](p,2)|0;do{if((c[u>>2]|0)!=0){x=c[w>>2]|0;c[q>>2]=9534384;y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[y&16383](q,2,0)|0;if((x|0)<1){v=1;i=e;return v|0}if((gzL(r,0,2)|0)==0){break}else{v=1}i=e;return v|0}}while(0);r=(c[2387812]|0)+65536|0;if((c[3542200]|0)==0){v=1;i=e;return v|0}w=n+108|0;c[w>>2]=0;u=n+100|0;c[u>>2]=0;x=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[x&16383](n,3)|0;do{if((c[w>>2]|0)!=0){x=c[u>>2]|0;c[o>>2]=9534384;y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[y&16383](o,3,0)|0;if((x|0)<1){v=1;i=e;return v|0}if((gzL(r,0,3)|0)==0){break}else{v=1}i=e;return v|0}}while(0);r=c[3531e3]|0;if((c[3542200]|0)==0){v=1;i=e;return v|0}u=l+108|0;c[u>>2]=0;w=l+100|0;c[w>>2]=0;x=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[x&16383](l,4)|0;do{if((c[u>>2]|0)!=0){x=c[w>>2]|0;c[m>>2]=9534384;y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[y&16383](m,4,0)|0;if((x|0)<1){v=1;i=e;return v|0}if((gzL(r,0,4)|0)==0){break}else{v=1}i=e;return v|0}}while(0);r=(c[3531e3]|0)+256|0;if((c[3542200]|0)==0){v=1;i=e;return v|0}w=j+108|0;c[w>>2]=0;u=j+100|0;c[u>>2]=0;x=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[x&16383](j,5)|0;do{if((c[w>>2]|0)!=0){x=c[u>>2]|0;c[k>>2]=9534384;y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[y&16383](k,5,0)|0;if((x|0)<1){v=1;i=e;return v|0}if((gzL(r,0,5)|0)==0){break}else{v=1}i=e;return v|0}}while(0);r=(c[3531e3]|0)+512|0;if((c[3542200]|0)==0){v=1;i=e;return v|0}u=f+108|0;c[u>>2]=0;w=f+100|0;c[w>>2]=0;x=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[x&16383](f,6)|0;do{if((c[u>>2]|0)==0){z=0}else{x=c[w>>2]|0;c[g>>2]=9534384;y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[y&16383](g,6,0)|0;if((x|0)<1){v=1;i=e;return v|0}if((gzL(r,0,6)|0)==0){z=0;break}else{v=1}i=e;return v|0}}while(0);while(1){if((z|0)>=1024){break}A=9638528+(z<<2)|0;if((c[A>>2]|0)==0){t=9174;break}else{z=z+1|0}}L12498:do{if((t|0)==9174){r=gGq(131072)|0;c[A>>2]=r;if((r|0)==0){break}gGz(r|0,0,131072);w=c[2387812]|0;gGC(r|0,w|0,131072)|0;u=0;while(1){x=u<<6;gGz(w+x|0,0,64);y=u<<7;B=0;do{C=1<<3-B;D=(c[613072+(B<<2)>>2]|0)+y|0;E=0;do{F=D+(c[6669224+(E<<2)>>2]|0)|0;G=(E<<3)+x|0;H=0;do{I=F+(c[612480+(H<<2)>>2]|0)|0;if(((d[r+((I|0)/8|0)|0]|0)&128>>>((I&7)>>>0)|0)!=0){I=w+(G+H)|0;a[I]=(d[I]|0|C)&255}H=H+1|0;}while((H|0)<8);E=E+1|0;}while((E|0)<8);B=B+1|0;}while((B|0)<4);B=u+1|0;if((B|0)<4096){u=B}else{J=0;break}}while(1){if((J|0)>=1024){break L12498}K=9638528+(J<<2)|0;if((c[K>>2]|0)==(r|0)){break}else{J=J+1|0}}gGr(r);c[K>>2]=0}}while(0);eyd();u=c[2388108]|0;b[u+5008>>1]=16953;b[u+5010>>1]=255;b[u+5012>>1]=-7786;b[u+5014>>1]=16953;b[u+5016>>1]=255;b[u+5018>>1]=-7785;b[u+5020>>1]=16953;b[u+5022>>1]=255;b[u+5024>>1]=-8004;b[u+5026>>1]=16889;b[u+5028>>1]=255;b[u+5030>>1]=-12338;b[u+5032>>1]=15932;b[u+5034>>1]=15;b[u+5036>>1]=16920;b[u+5038>>1]=20943;b[u+5040>>1]=-4;b[u+5042>>1]=20085;b[u+5044>>1]=12799;fxU(0,425984);if((c[2394]|0)==0){L=c[2112932]|0}else{c[2394]=0;u=c[3532596]|0;c[2112932]=u;w=c[3532592]|0;if((w|0)!=0){gGC(9104152,w|0,280)|0}c[2113054]=c[2113060];L=u}u=c[2388108]|0;w=L|0;B=0;while(1){x=u+B|0;c[w>>2]=x;c[w+131072>>2]=x;x=B+1024|0;if(x>>>0>131071){break}else{w=w+4|0;B=x}}B=c[2386200]|0;c[L+65472>>2]=B;c[L+131008>>2]=B;c[L+196544>>2]=B;w=B+1024|0;c[L+65476>>2]=w;c[L+131012>>2]=w;c[L+196548>>2]=w;w=c[2386420]|0;c[L+65480>>2]=w;c[L+131016>>2]=w;c[L+196552>>2]=w;B=w+1024|0;c[L+65484>>2]=B;c[L+131020>>2]=B;c[L+196556>>2]=B;B=w+2048|0;c[L+65488>>2]=B;c[L+131024>>2]=B;c[L+196560>>2]=B;B=w+3072|0;c[L+65492>>2]=B;c[L+131028>>2]=B;c[L+196564>>2]=B;B=w+4096|0;c[L+65496>>2]=B;c[L+131032>>2]=B;c[L+196568>>2]=B;B=w+5120|0;c[L+65500>>2]=B;c[L+131036>>2]=B;c[L+196572>>2]=B;B=w+6144|0;c[L+65504>>2]=B;c[L+131040>>2]=B;c[L+196576>>2]=B;B=w+7168|0;c[L+65508>>2]=B;c[L+131044>>2]=B;c[L+196580>>2]=B;B=w+8192|0;c[L+65512>>2]=B;c[L+131048>>2]=B;c[L+196584>>2]=B;B=w+9216|0;c[L+65516>>2]=B;c[L+131052>>2]=B;c[L+196588>>2]=B;B=w+10240|0;c[L+65520>>2]=B;c[L+131056>>2]=B;c[L+196592>>2]=B;B=w+11264|0;c[L+65524>>2]=B;c[L+131060>>2]=B;c[L+196596>>2]=B;B=w+12288|0;c[L+65528>>2]=B;c[L+131064>>2]=B;c[L+196600>>2]=B;B=w+13312|0;c[L+65532>>2]=B;c[L+131068>>2]=B;c[L+196604>>2]=B;c[L+196648>>2]=2780;c[L+196608>>2]=1056;B=c[3532592]|0;if((B|0)!=0){gGC(B|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;h[1207702]=31250.0;c[2415406]=0;h[1207704]=1.0;c[2415412]=3;h[1207705]=1.0;c[2415413]=3;Tq(689856);B=c[642608+(c[2436]<<2)>>2]|0;w=c[B+128>>2]|0;if((c[B+52>>2]&4|0)==0){c[2113068]=w;u=c[B+132>>2]|0;c[2113070]=u;c[2443814]=w;c[2440436]=u;M=w;N=u}else{c[2113070]=w;u=c[B+132>>2]|0;c[2113068]=u;c[2440436]=w;c[2443814]=u;M=u;N=w}w=ag(M<<1,N)|0;u=gGq(w)|0;c[2112926]=u;if((u|0)!=0){gGz(u|0,0,w|0)}w=c[2414614]|0;gGz(w|0,0,(c[2411574]|0)-w|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];w=c[3532592]|0;if((w|0)!=0){gGC(9104152,w|0,280)|0}c[2113054]=c[2113060]}RI();w=c[2394]|0;u=c[14130368+(w<<2)>>2]|0;if((u|0)!=0){gGC(u|0,9104152,280)|0}c[8452240+(w<<2)>>2]=c[2113054];c[2394]=-1;c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];O=+h[1207702];w=c[2415406]|0;P=+h[1207704];Q=+h[1207705];u=c[2415412]|0;B=c[2415413]|0;gGz(9661160,0,496);h[1207702]=O;c[2415406]=w;h[1207704]=P;h[1207705]=Q;c[2415412]=u;c[2415413]=B;v=0;i=e;return v|0}}while(0);c[2414912]=0;v=1;i=e;return v|0}function ex9(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;i=i+128|0;c[2113070]=0;c[2113068]=0;d=c[2112926]|0;if((d|0)!=0){gGr(d);c[2112926]=0}d=b|0;e=c[c[642608+(c[2436]<<2)>>2]>>2]|0;be(d|0,128,179600,(f=i,i=i+24|0,c[f>>2]=9374064,c[f+8>>2]=47,c[f+16>>2]=e,f)|0)|0;i=f;a[1040128]=0;f=c[2420380]|0;e=c[f>>2]|0;g=c[f+4>>2]|0;f=fw(d|0,389440)|0;if((f|0)!=0){d=g>>3<<e&1023;cj(14100392,d|0,1,f|0)|0;aY(f|0)|0}if((c[2392]|0)>=0){f=0;do{d=14130368+(f<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}d=14130384+(f<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}f=f+1|0;}while((f|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;f=c[2414912]|0;d=0;while(1){if((d|0)>=1024){h=9245;break}j=9638528+(d<<2)|0;if((c[j>>2]|0)==(f|0)){break}else{d=d+1|0}}if((h|0)==9245){c[2414912]=0;i=b;return 0}gGr(f);c[j>>2]=0;c[2414912]=0;i=b;return 0}function eya(){var e=0,f=0,g=0.0,i=0.0,j=0.0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0.0,s=0,t=0,u=0,v=0,w=0,x=0.0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0.0,H=0,I=0,J=0,K=0,L=0,M=0;if((a[9623840]|0)!=0){e=c[2414614]|0;gGz(e|0,0,(c[2411574]|0)-e|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060]}RI();e=c[2394]|0;f=c[14130368+(e<<2)>>2]|0;if((f|0)!=0){gGC(f|0,9104152,280)|0}c[8452240+(e<<2)>>2]=c[2113054];c[2394]=-1;c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];g=+h[1207702];e=c[2415406]|0;i=+h[1207704];j=+h[1207705];f=c[2415412]|0;k=c[2415413]|0;gGz(9661160,0,496);h[1207702]=g;c[2415406]=e;h[1207704]=i;h[1207705]=j;c[2415412]=f;c[2415413]=k}b[4775156]=-1;k=0;f=-1;e=-1;do{f=((a[9632952+k|0]&1)<<k^f&255)&255;e=((a[9630824+k|0]&1)<<k^e&255)&255;k=k+1|0;}while((k|0)<8);a[9550312]=f;a[9550313]=e;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060]}c[2113056]=41666;e=RG(41666)|0;c[2113054]=(c[2113054]|0)+e;c[2276108]=-1;c[2113056]=-1;c[8452200+(c[2394]<<2)>>2]=8198;c[2276080]=1536;if((c[2276079]|0)>>>0<1536){RH(6)}c[2113056]=41666;e=RG(41666)|0;c[2113054]=(c[2113054]|0)+e;c[2276108]=-1;c[2113056]=41666;e=RG(41666)|0;c[2113054]=(c[2113054]|0)+e;c[2276108]=-1;c[2113056]=-1;c[8452200+(c[2394]<<2)>>2]=8198;c[2276080]=1536;if((c[2276079]|0)>>>0<1536){RH(6)}c[2113056]=41666;e=RG(41666)|0;c[2113054]=(c[2113054]|0)+e;c[2276108]=-1;c[2113056]=-1;c[8452200+(c[2394]<<2)>>2]=8194;c[2276080]=512;if((c[2276079]|0)>>>0<512){RH(2)}e=c[2112964]|0;do{if((e|0)!=0){f=a[9688]|0;k=f?534:0;if((c[2415304]|0)==0){gGz(e|0,0,k<<2|0);break}l=c[2415290]|0;if((l|0)==2){h[1207697]=15625.0}else if((l|0)==1){h[1207697]=31250.0}else if((l|0)==0){h[1207697]=62500.0}else if((l|0)==3){h[1207697]=+h[1207659]}l=c[2415291]|0;if((l|0)==2){h[1207700]=15625.0}else if((l|0)==1){h[1207700]=31250.0}else if((l|0)==0){h[1207700]=62500.0}else if((l|0)==3){h[1207700]=+h[1207680]}if(f){m=e;n=0}else{break}while(1){f=0;l=0;o=0;while(1){p=9661232+(f*56|0)|0;q=9661272+(f*56|0)|0;j=+h[q>>3];if(j==0.0){i=+(31250<<c[9661244+(f*56|0)>>2]|0)/(511.0- +(c[p>>2]|0));h[q>>3]=i;r=i}else{r=j}s=9661264+(f*56|0)|0;j=+h[s>>3]-r;h[s>>3]=j;L12631:do{if(j<0.0){t=9661244+(f*56|0)|0;u=p|0;v=9661280+(f*56|0)|0;w=(f|0)==4;if((f|0)==1){x=j}else{i=j;while(1){h[q>>3]=+(31250<<c[t>>2]|0)/(511.0- +(c[u>>2]|0));h[s>>3]=i+ +h[1207702];c[v>>2]=c[v>>2]^1;do{if(w&(c[2415301]|0)==0){if((c[2415293]|0)==0){c[2415385]=16;c[2415371]=16;c[2415357]=16;c[2415384]=16;c[2415370]=16;c[2415356]=16;break}y=c[2415297]|0;z=c[2415303]|0;A=z+1&63|z&32;c[2415303]=A;z=(c[2415299]|0)==0?15:14;B=d[641016+(y<<6)+A|0]|0;A=B&z;c[2415384]=A;c[2415370]=A;c[2415356]=A;if((c[2415295]&1|0)==0){c[2415385]=A;c[2415371]=A;c[2415357]=A;break}else{A=15-B&z;c[2415385]=A;c[2415371]=A;c[2415357]=A;break}}}while(0);i=+h[s>>3];if(i>=0.0){break L12631}}}do{h[q>>3]=+(31250<<c[t>>2]|0)/(511.0- +(c[u>>2]|0));h[s>>3]=x+ +h[1207702];c[v>>2]=c[v>>2]^1;L12647:do{if((c[2415300]|0)==0){do{if((c[2415292]|0)==0){c[2415343]=16;c[2415329]=16;c[2415315]=16;c[2415342]=16;c[2415328]=16;c[2415314]=16}else{A=c[2415296]|0;z=c[2415302]|0;B=z+1&63|z&32;c[2415302]=B;z=(c[2415298]|0)==0?15:14;y=d[641016+(A<<6)+B|0]|0;B=y&z;c[2415342]=B;c[2415328]=B;c[2415314]=B;if((c[2415294]&1|0)==0){c[2415343]=B;c[2415329]=B;c[2415315]=B;break}else{B=15-y&z;c[2415343]=B;c[2415329]=B;c[2415315]=B;break L12647}}}while(0);if(!(w&(c[2415301]|0)==0)){break}if((c[2415293]|0)==0){c[2415385]=16;c[2415371]=16;c[2415357]=16;c[2415384]=16;c[2415370]=16;c[2415356]=16;break}B=c[2415297]|0;z=c[2415303]|0;y=z+1&63|z&32;c[2415303]=y;z=(c[2415299]|0)==0?15:14;A=d[641016+(B<<6)+y|0]|0;y=A&z;c[2415384]=y;c[2415370]=y;c[2415356]=y;if((c[2415295]&1|0)==0){c[2415385]=y;c[2415371]=y;c[2415357]=y;break}else{y=15-A&z;c[2415385]=y;c[2415371]=y;c[2415357]=y;break}}}while(0);x=+h[s>>3];}while(x<0.0)}}while(0);do{if((c[9661240+(f*56|0)>>2]|0)==0){C=o;D=l}else{if((c[9661584+(((f|0)/3|0)*24|0)>>2]&1|0)==0){C=o;D=l;break}s=l-((ag(c[9661256+(f*56|0)>>2]|0,c[9661248+(f*56|0)>>2]|0)|0)/32|0)|0;C=o-((ag(c[9661260+(f*56|0)>>2]|0,c[9661252+(f*56|0)>>2]|0)|0)/32|0)|0;D=s}}while(0);do{if((c[9661236+(f*56|0)>>2]|0)==0){E=C;F=D}else{if((c[9661280+(f*56|0)>>2]&1|0)==0){E=C;F=D;break}s=((ag(c[9661256+(f*56|0)>>2]|0,c[9661248+(f*56|0)>>2]|0)|0)/16|0)+D|0;E=((ag(c[9661260+(f*56|0)>>2]|0,c[9661252+(f*56|0)>>2]|0)|0)/16|0)+C|0;F=s}}while(0);s=f+1|0;if((s|0)<6){f=s;l=F;o=E}else{break}}j=+h[1207696]- +h[1207697];h[1207696]=j;if(j<0.0){i=+h[1207702];g=j;o=c[2415396]|0;do{g=i+g;o=((o>>>14^o>>>6)&1|o<<1)^1;}while(g<0.0);h[1207696]=g;c[2415396]=o}i=+h[1207699]- +h[1207700];h[1207699]=i;if(i<0.0){j=+h[1207702];G=i;l=c[2415402]|0;do{G=j+G;l=((l>>>14^l>>>6)&1|l<<1)^1;}while(G<0.0);h[1207699]=G;c[2415402]=l}o=c[2415412]|0;if((o&1|0)==0){H=0}else{H=~~(+((F|0)/6|0|0)*+h[1207704])}if((o&2|0)==0){I=0}else{I=~~(+((F|0)/6|0|0)*+h[1207704])}o=c[2415413]|0;if((o&1|0)==0){J=H}else{J=~~(+((E|0)/6|0|0)*+h[1207705])+H|0}if((o&2|0)==0){K=I}else{K=~~(+((E|0)/6|0|0)*+h[1207705])+I|0}if((J|0)<-32768){L=-32768}else{L=(J|0)>32767?32767:J&65535}if((K|0)<-32768){M=-32768}else{M=(K|0)>32767?32767:K&65535}b[m>>1]=L;b[m+2>>1]=M;o=n+1|0;if((o|0)<(k|0)){m=m+4|0;n=o}else{break}}}}while(0);n=c[2394]|0;m=c[14130368+(n<<2)>>2]|0;if((m|0)!=0){gGC(m|0,9104152,280)|0}c[8452240+(n<<2)>>2]=c[2113054];c[2394]=-1;if((c[2112968]|0)==0){return 0}eyb()|0;return 0}function eyb(){var b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((a[9547256]|0)!=0){eyd();a[9547256]=0}b=c[2386200]|0;d=c[2112926]|0;f=c[2387812]|0;g=64;do{h=e[b+(g<<1)>>1]|0;Si(d,h&4095,g<<3&248,(g>>5<<3)-16|0,h>>>12,4,0,f);g=g+1|0;}while((g|0)<960);g=c[2386420]|0;b=0;do{h=e[g+(b<<1)>>1]|0;i=h&255;j=240-(h>>>8)|0;h=j-16|0;k=e[g+((b|1)<<1)>>1]|0;l=k&4092;m=k>>>12;Sr(d,l,i,h,m,4,0,0,f);k=j-8|0;Sr(d,l|1,i,k,m,4,0,0,f);j=i+8|0;Sr(d,l|2,j,h,m,4,0,0,f);Sr(d,l|3,j,k,m,4,0,0,f);b=b+2|0;}while((b|0)<64);R8(c[3529946]|0);return 0}function eyc(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=i;i=i+80|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;if((d|0)!=0){c[d>>2]=169624}if((b&32|0)!=0){gGz(k|0,0,12);l=c[2414614]|0;c[k>>2]=l;c[k+4>>2]=(c[2411574]|0)-l;c[k+12>>2]=162152;l=c[2076592]|0;gj[l&4095](k)|0}if((b&64|0)==0){i=e;return 0}k=j|0;gGz(h|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){l=j+9|0;j=g;m=g|0;n=g+4|0;o=g+12|0;p=h|0;q=h+4|0;r=h+12|0;s=0;do{gGC(k|0,614896,11)|0;a[l]=s+48&255;t=8452256+(s<<2)|0;gGz(j|0,0,12);c[m>>2]=t;c[n>>2]=4;c[o>>2]=164976;gj[c[2076592]&4095](g)|0;if((c[t>>2]|0)!=0){c[p>>2]=c[14130368+(s<<2)>>2];c[q>>2]=c[8452184+(s<<2)>>2];c[r>>2]=k;t=c[2076592]|0;gj[t&4095](h)|0}s=s+1|0;}while((s|0)<=(c[2392]|0))}if((b&96|0)!=0){gGz(f|0,0,12);c[f>>2]=9661160;c[f+4>>2]=496;c[f+12>>2]=95888;s=c[2076592]|0;gj[s&4095](f)|0}Ts(b,d);i=e;return 0}function eyd(){var a=0,b=0,e=0,f=0,g=0,h=0;a=c[3531e3]|0;b=c[3529946]|0;e=0;do{f=d[a+e|0]|0;g=d[a+(e+256)|0]|0;h=d[a+(e+512)|0]|0;c[b+(e<<2)>>2]=(-(g>>>1&1)&30)+(-(g&1)&14)+(-(g>>>2&1)&68)+(-(g>>>3&1)&143)<<3&2016|(-(f>>>1&1)&30)+(-(f&1)&14)+(-(f>>>2&1)&68)+(-(f>>>3&1)&143)<<8&63488|((-(h>>>1&1)&30)+(-(h&1)&14)+(-(h>>>2&1)&68)+(-(h>>>3&1)&143)|0)>>>3&31;e=e+1|0;}while((e|0)<256);return}function eye(a){a=a|0;var b=0;if((a-1572864|0)>>>0>=8){b=0;return b|0}b=(e[9634528+((a>>>1&3)<<1)>>1]|0)>>>((a<<3&8^8)>>>0)&255;return b|0}function eyf(a){a=a|0;var c=0;if(!((a|0)==1572864|(a|0)==1572866|(a|0)==1572868|(a|0)==1572870)){c=0;return c|0}c=b[9634528+((a>>>1&3)<<1)>>1]|0;return c|0}function eyg(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;if((d-1048576|0)>>>0<1536){f=d&2047;g=(c[2387144]|0)+f|0;a[g]=e;h=b[g>>1]|0;g=(h&65535)>>>10&65535;i=g<<3&248|g>>>2;g=h&255;j=i>>>2|((h&65535)>>>5&65535)<<3&248;h=g<<3&248|g>>>2;g=f>>>1;c[(c[2406918]|0)+(g<<2)>>2]=i<<16|h|j<<8;c[(c[3529944]|0)+(g<<2)>>2]=i<<8&63488|h>>>3|j<<3&2016;return}if((d|0)==786432|(d|0)==786433|(d|0)==786434|(d|0)==786435|(d|0)==786436|(d|0)==786437|(d|0)==786438|(d|0)==786439){a[(c[3529378]|0)+(d&7)|0]=e;return}else if((d|0)==1310722|(d|0)==1310723){if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12}else if(!((d|0)==1310720|(d|0)==1310721|(d|0)==1310724|(d|0)==1310725|(d|0)==1310726|(d|0)==1310727)){return}a[(c[3529688]|0)+(d&7)|0]=e;return}function eyh(d,f){d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;if((d-1048576|0)>>>0<1536){g=d&2046;b[(c[2387144]|0)+g>>1]=f;h=(f&65535)>>>10&65535;i=h<<3&248|h>>>2;h=f&255;j=i>>>2|((f&65535)>>>5&65535)<<3&248;k=h<<3&248|h>>>2;h=g>>>1;c[(c[2406918]|0)+(h<<2)>>2]=i<<16|k|j<<8;c[(c[3529944]|0)+(h<<2)>>2]=i<<8&63488|k>>>3|j<<3&2016;return}if((d|0)==786434){j=c[3529378]|0;b[j+2>>1]=f;c[(c[3529792]|0)+4>>2]=(e[j+6>>1]|0)+12;return}else if((d|0)==786432){j=c[3529378]|0;b[j>>1]=f;c[(c[3529798]|0)+4>>2]=(e[j+4>>1]|0)+7;return}else if((d|0)==786436){j=c[3529378]|0;b[j+4>>1]=f;c[c[3529798]>>2]=(e[j>>1]|0)+3;return}else if((d|0)==786438){j=c[3529378]|0;b[j+6>>1]=f;c[c[3529792]>>2]=(e[j+2>>1]|0)+12;return}else if((d|0)==1310722){if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12}else if(!((d|0)==1310720|(d|0)==1310724|(d|0)==1310726)){return}b[(c[3529688]|0)+(d&7)>>1]=f;return}function eyi(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((e|0)==38912){Uv(0,d);return}else if((e|0)==34816){c[2113304]=d&255;return}else if((e|0)==34817){e=c[2113304]|0;a[14168504+e|0]=d;mv(0,e,d&255);return}else{return}}function eyj(b){b=b|0;var d=0,e=0;d=b&65535;if((d|0)==38912){e=c[2113156]&255}else if((d|0)==40960){e=a[c[3528234]|0]|0}else if((d|0)==34817){e=c[(c[3531464]|0)+4240>>2]&255}else{e=0}return e|0}function eyk(b){b=b|0;a[9706117]=(b|0)!=0|0;return}function eyl(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2545276+(b*112|0)>>2];c[a+104>>2]=c[2545280+(b*112|0)>>2];c[a+108>>2]=c[2545284+(b*112|0)>>2];d=0;return d|0}function eym(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=2545176+(b*112|0);e=0;return e|0}function eyn(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1226120+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eyo(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>46){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3676592+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eyp(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;e=i;i=i+360|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;c[2414910]=0;c[2388106]=0;c[2385888]=524288;c[3541206]=589824;c[2386614]=589824;c[3530792]=851968;c[3530556]=7143424;c[3529944]=11337728;c[2414612]=11340800;c[2388236]=11340800;c[2387144]=11406336;c[2386418]=11408384;c[3529452]=11424768;c[3529416]=11428864;c[3529378]=11432960;c[3529688]=11432968;c[3529798]=11432976;c[3529792]=11432984;c[2386042]=11432992;c[2406918]=11435040;c[2411572]=11438112;n=0;while(1){if((n|0)>=1024){break}o=9638528+(n<<2)|0;if((c[o>>2]|0)==0){p=9452;break}else{n=n+1|0}}do{if((p|0)==9452){n=gGq(11438112)|0;c[o>>2]=n;if((n|0)==0){break}c[2414910]=n;gGz(n|0,0,11438112);c[2388106]=n;c[2385888]=n+524288;q=n+589824|0;c[3541206]=q;c[2386614]=q;c[3530792]=n+851968;c[3530556]=n+7143424;c[3529944]=n+11337728;q=n+11340800|0;c[2414612]=q;c[2388236]=q;c[2387144]=n+11406336;c[2386418]=n+11408384;c[3529452]=n+11424768;c[3529416]=n+11428864;c[3529378]=n+11432960;c[3529688]=n+11432968;c[3529798]=n+11432976;c[3529792]=n+11432984;c[2386042]=n+11432992;c[2406918]=n+11435040;q=n+11438112|0;c[2411572]=q;c[2414112]=q;if((R6(n+1|0,0,2)|0)!=0){r=1;i=e;return r|0}if((R6(c[2388106]|0,1,2)|0)!=0){r=1;i=e;return r|0}n=c[2385888]|0;if((c[3542200]|0)==0){r=1;i=e;return r|0}q=l+108|0;c[q>>2]=0;s=l+100|0;c[s>>2]=0;t=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[t&16383](l,2)|0;do{if((c[q>>2]|0)==0){u=0}else{t=c[s>>2]|0;c[m>>2]=9534384;v=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[v&16383](m,2,0)|0;if((t|0)<1){r=1;i=e;return r|0}if((gzL(n,0,2)|0)==0){u=0;break}else{r=1}i=e;return r|0}}while(0);while(1){if((u|0)>=6){p=9461;break}n=u<<19;if((R6((c[3530792]|0)+n|0,u+3|0,2)|0)!=0){r=1;p=9551;break}if((R6((c[3530792]|0)+(n|1)|0,u+4|0,2)|0)==0){u=u+2|0}else{r=1;p=9549;break}}if((p|0)==9461){n=j+108|0;s=j+100|0;q=0;while(1){t=(c[3530556]|0)+(q<<19)|0;v=q+9|0;if((c[3542200]|0)==0){r=1;p=9557;break}c[n>>2]=0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,v)|0;if((c[n>>2]|0)!=0){w=c[s>>2]|0;c[k>>2]=9534384;x=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[x&16383](k,v,0)|0;if((w|0)<1){r=1;p=9546;break}if((gzL(t,0,v)|0)!=0){r=1;p=9545;break}}v=q+1|0;if((v|0)<4){q=v}else{p=9464;break}}if((p|0)==9464){q=f+108|0;s=f+100|0;n=c[2386614]|0;if((c[3542200]|0)==0){r=1;i=e;return r|0}c[q>>2]=0;c[s>>2]=0;v=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[v&16383](f,13)|0;do{if((c[q>>2]|0)!=0){v=c[s>>2]|0;c[g>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](g,13,0)|0;if((v|0)<1){r=1;i=e;return r|0}if((gzL(n,0,13)|0)==0){break}else{r=1}i=e;return r|0}}while(0);n=(c[2386614]|0)+131072|0;if((c[3542200]|0)==0){r=1;i=e;return r|0}c[q>>2]=0;c[s>>2]=0;v=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[v&16383](f,14)|0;do{if((c[q>>2]|0)==0){y=0}else{v=c[s>>2]|0;c[g>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](g,14,0)|0;if((v|0)<1){r=1;i=e;return r|0}if((gzL(n,0,14)|0)==0){y=0;break}else{r=1}i=e;return r|0}}while(0);while(1){if((y|0)>=1024){break}z=9638528+(y<<2)|0;if((c[z>>2]|0)==0){p=9476;break}else{y=y+1|0}}L12898:do{if((p|0)==9476){n=gGq(3145728)|0;c[z>>2]=n;if((n|0)==0){break}gGz(n|0,0,3145728);s=c[3530792]|0;gGC(n|0,s|0,3145728)|0;q=0;do{v=q<<8;gGz(s+v|0,0,256);t=q<<10;w=0;do{x=1<<3-w;A=(c[703416+(w<<2)>>2]|0)+t|0;B=0;do{C=A+(c[611904+(B<<2)>>2]|0)|0;D=(B<<4)+v|0;E=0;do{F=C+(c[610480+(E<<2)>>2]|0)|0;if(((d[n+((F|0)/8|0)|0]|0)&128>>>((F&7)>>>0)|0)!=0){F=s+(D+E)|0;a[F]=(d[F]|0|x)&255}E=E+1|0;}while((E|0)<16);B=B+1|0;}while((B|0)<16);w=w+1|0;}while((w|0)<4);q=q+1|0;}while((q|0)<24576);q=c[3530556]|0;gGC(n|0,q|0,2097152)|0;s=0;while(1){w=s<<8;gGz(q+w|0,0,256);v=0;do{t=1<<3-v;B=(c[601464+(v<<2)>>2]|0)+w|0;x=0;do{A=B+(c[609008+(x<<2)>>2]|0)|0;E=(x<<4)+w|0;D=0;do{C=A+(c[597864+(D<<2)>>2]|0)|0;if(((d[n+((C|0)/8|0)|0]|0)&128>>>((C&7)>>>0)|0)!=0){C=q+(E+D)|0;a[C]=(d[C]|0|t)&255}D=D+1|0;}while((D|0)<16);x=x+1|0;}while((x|0)<16);v=v+1|0;}while((v|0)<4);v=s+1|0;if((v|0)<16384){s=v}else{G=0;break}}while(1){if((G|0)>=1024){break L12898}H=9638528+(G<<2)|0;if((c[H>>2]|0)==(n|0)){break}else{G=G+1|0}}gGr(n);c[H>>2]=0}}while(0);fxU(0,425984);if((c[2394]|0)==0){I=c[2112932]|0}else{c[2394]=0;s=c[3532596]|0;c[2112932]=s;q=c[3532592]|0;if((q|0)!=0){gGC(9104152,q|0,280)|0}c[2113054]=c[2113060];I=s}s=c[2388106]|0;q=I|0;v=0;while(1){w=s+v|0;c[q>>2]=w;c[q+131072>>2]=w;w=v+1024|0;if(w>>>0>524287){break}else{q=q+4|0;v=w}}v=c[3529452]|0;c[I+2048>>2]=v;c[I+67584>>2]=v;c[I+133120>>2]=v;q=v+1024|0;c[I+2052>>2]=q;c[I+67588>>2]=q;c[I+133124>>2]=q;q=v+2048|0;c[I+2056>>2]=q;c[I+67592>>2]=q;c[I+133128>>2]=q;q=v+3072|0;c[I+2060>>2]=q;c[I+67596>>2]=q;c[I+133132>>2]=q;q=c[3529416]|0;c[I+2080>>2]=q;c[I+67616>>2]=q;c[I+133152>>2]=q;v=q+1024|0;c[I+2084>>2]=v;c[I+67620>>2]=v;c[I+133156>>2]=v;v=q+2048|0;c[I+2088>>2]=v;c[I+67624>>2]=v;c[I+133160>>2]=v;v=q+3072|0;c[I+2092>>2]=v;c[I+67628>>2]=v;c[I+133164>>2]=v;v=c[2387144]|0;c[I+4096>>2]=v;c[I+135168>>2]=v;q=v+1024|0;c[I+4100>>2]=q;c[I+135172>>2]=q;q=c[2388236]|0;v=I+7168|0;s=1835008;while(1){w=q+(s-1835008)|0;c[v>>2]=w;c[v+65536>>2]=w;c[v+131072>>2]=w;w=s+1024|0;if(w>>>0>1900543){break}else{v=v+4|0;s=w}}s=c[2386418]|0;c[I+8192>>2]=s;c[I+73728>>2]=s;c[I+139264>>2]=s;v=s+1024|0;c[I+8196>>2]=v;c[I+73732>>2]=v;c[I+139268>>2]=v;v=s+2048|0;c[I+8200>>2]=v;c[I+73736>>2]=v;c[I+139272>>2]=v;v=s+3072|0;c[I+8204>>2]=v;c[I+73740>>2]=v;c[I+139276>>2]=v;v=s+4096|0;c[I+8208>>2]=v;c[I+73744>>2]=v;c[I+139280>>2]=v;v=s+5120|0;c[I+8212>>2]=v;c[I+73748>>2]=v;c[I+139284>>2]=v;v=s+6144|0;c[I+8216>>2]=v;c[I+73752>>2]=v;c[I+139288>>2]=v;v=s+7168|0;c[I+8220>>2]=v;c[I+73756>>2]=v;c[I+139292>>2]=v;v=s+8192|0;c[I+8224>>2]=v;c[I+73760>>2]=v;c[I+139296>>2]=v;v=s+9216|0;c[I+8228>>2]=v;c[I+73764>>2]=v;c[I+139300>>2]=v;v=s+10240|0;c[I+8232>>2]=v;c[I+73768>>2]=v;c[I+139304>>2]=v;v=s+11264|0;c[I+8236>>2]=v;c[I+73772>>2]=v;c[I+139308>>2]=v;v=s+12288|0;c[I+8240>>2]=v;c[I+73776>>2]=v;c[I+139312>>2]=v;v=s+13312|0;c[I+8244>>2]=v;c[I+73780>>2]=v;c[I+139316>>2]=v;v=s+14336|0;c[I+8248>>2]=v;c[I+73784>>2]=v;c[I+139320>>2]=v;v=s+15360|0;c[I+8252>>2]=v;c[I+73788>>2]=v;c[I+139324>>2]=v;c[I+196648>>2]=1456;c[I+196728>>2]=2766;c[I+196608>>2]=3544;c[I+196688>>2]=2426;v=c[3532592]|0;if((v|0)!=0){gGC(v|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);v=c[2439330]|0;s=(v|0)==0;if(!s){q=v;gGC(9706056,q|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];q=c[3528484]|0;c[2076596]=q;w=c[2417276]|0;c[3541536]=w;c[1836236]=0;x=c[2385888]|0;t=0;B=0;while(1){c[v+76+(B<<2)>>2]=x+(B<<8);D=t+1&65535;if((D&65535)>127){J=0;K=0;break}else{t=D;B=D&65535}}while(1){B=x+(K<<8)|0;c[v+76+(K+512<<2)>>2]=B;c[v+76+(K+768<<2)>>2]=B;B=J+1&65535;if((B&65535)>127){break}else{J=B;K=B&65535}}x=c[2386042]|0;c[v+588>>2]=x;B=x+256|0;c[v+592>>2]=B;t=x+512|0;c[v+596>>2]=t;D=x+768|0;c[v+600>>2]=D;E=x+1024|0;c[v+604>>2]=E;A=x+1280|0;c[v+608>>2]=A;C=x+1536|0;c[v+612>>2]=C;F=x+1792|0;c[v+616>>2]=F;c[v+1612>>2]=x;c[v+1616>>2]=B;c[v+1620>>2]=t;c[v+1624>>2]=D;c[v+1628>>2]=E;c[v+1632>>2]=A;c[v+1636>>2]=C;c[v+1640>>2]=F;c[v+2636>>2]=x;c[v+3660>>2]=x;c[v+2640>>2]=B;c[v+3664>>2]=B;c[v+2644>>2]=t;c[v+3668>>2]=t;c[v+2648>>2]=D;c[v+3672>>2]=D;c[v+2652>>2]=E;c[v+3676>>2]=E;c[v+2656>>2]=A;c[v+3680>>2]=A;c[v+2660>>2]=C;c[v+3684>>2]=C;c[v+2664>>2]=F;c[v+3688>>2]=F;c[v+4184>>2]=1282;c[v+4180>>2]=2176;if(!s){F=v;gGC(F|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=q;c[2417276]=w;c[1836236]=-1;F=c[642608+(c[2436]<<2)>>2]|0;C=c[F+128>>2]|0;if((c[F+52>>2]&4|0)==0){c[2113068]=C;A=c[F+132>>2]|0;c[2113070]=A;c[2443814]=C;c[2440436]=A;L=C;M=A}else{c[2113070]=C;A=c[F+132>>2]|0;c[2113068]=A;c[2440436]=C;c[2443814]=A;L=A;M=C}C=ag(L<<1,M)|0;A=gGq(C)|0;c[2112926]=A;if((A|0)!=0){gGz(A|0,0,C|0)}c[3528234]=(c[3529688]|0)+2;C=a[9680]|0;A=C?32e3:0;if(C){if(a[9624]|0){C=A*3|0;F=55930;while(1){if((F|0)>(C|0)){F=F>>1}else{N=1222;O=F;break}}}else{N=2462;O=A}c[2429380]=O;c[3542124]=N;mw(3579545,O);F=gGq(262144)|0;c[2406684]=F;gGz(F|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(3579545,11025)}c[(c[3531464]|0)+44344>>2]=1220;h[745421]=1.0;c[2436794]=1;h[745420]=1.0;c[2436792]=2;Ux(0,8500,1);c[2407030]=128;c[2407068]=3;a[9623832]=0;F=c[2414612]|0;gGz(F|0,0,(c[2411572]|0)-F|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];F=c[3532592]|0;if((F|0)!=0){gGC(9104152,F|0,280)|0}c[2113054]=c[2113060]}RI();F=c[2394]|0;C=c[14130368+(F<<2)>>2]|0;if((C|0)!=0){gGC(C|0,9104152,280)|0}c[8452240+(F<<2)>>2]=c[2113054];c[2394]=-1;F=c[2439330]|0;C=(F|0)==0;if(!C){w=F;gGC(9706056,w|0,76)|0}w=c[2438118]|0;c[2433530]=w;q=c[3528484]|0;c[2076596]=q;v=c[2417276]|0;c[3541536]=v;c[1836236]=0;gGz(9706056,0,76);if(!C){C=F;gGC(C|0,9706056,76)|0}c[2438118]=w;c[3528484]=q;c[2417276]=v;c[1836236]=-1;c[2113156]=0;a[9628264]=0;c[2407033]=0;v=c[3541206]|0;c[3541190]=v;c[3541198]=v;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=v+256;c[3541199]=v+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=v+512;c[3541200]=v+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=v+768;c[3541201]=v+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;mx(0);r=0;i=e;return r|0}else if((p|0)==9545){i=e;return r|0}else if((p|0)==9546){i=e;return r|0}else if((p|0)==9557){i=e;return r|0}}else if((p|0)==9549){i=e;return r|0}else if((p|0)==9551){i=e;return r|0}}}while(0);c[2414910]=0;r=1;i=e;return r|0}function eyq(){var a=0,b=0,d=0,e=0,f=0;c[2113070]=0;c[2113068]=0;a=c[2112926]|0;if((a|0)!=0){gGr(a);c[2112926]=0}if((c[2392]|0)>=0){a=0;do{b=14130368+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}b=14130384+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}a=a+1|0;}while((a|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;fwZ();Uw(0);a=c[3531464]|0;c[a+44344>>2]=0;c[a+44348>>2]=0;if((a|0)!=0){gGr(a);c[3531464]=0}a=c[2406684]|0;if((a|0)!=0){gGr(a);c[2406684]=0}a=c[2414910]|0;b=0;while(1){if((b|0)>=1024){e=9579;break}f=9638528+(b<<2)|0;if((c[f>>2]|0)==(a|0)){break}else{b=b+1|0}}if((e|0)==9579){c[2414910]=0;return 0}gGr(a);c[f>>2]=0;c[2414910]=0;return 0}function eyr(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((a[9623832]|0)!=0){a[9623832]=0;e=c[2414612]|0;gGz(e|0,0,(c[2411572]|0)-e|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060]}RI();e=c[2394]|0;f=c[14130368+(e<<2)>>2]|0;if((f|0)!=0){gGC(f|0,9104152,280)|0}c[8452240+(e<<2)>>2]=c[2113054];c[2394]=-1;e=c[2439330]|0;f=(e|0)==0;if(!f){g=e;gGC(9706056,g|0,76)|0}g=c[2438118]|0;c[2433530]=g;h=c[3528484]|0;c[2076596]=h;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);if(!f){f=e;gGC(f|0,9706056,76)|0}c[2438118]=g;c[3528484]=h;c[2417276]=i;c[1836236]=-1;c[2113156]=0;a[9628264]=0;c[2407033]=0;i=c[3541206]|0;c[3541190]=i;c[3541198]=i;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=i+256;c[3541199]=i+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=i+512;c[3541200]=i+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=i+768;c[3541201]=i+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;mx(0)}i=d[9634880]<<8|255;b[4817264]=i;h=d[9634881]<<8|255;b[4817265]=h;b[4817266]=d[9634882]<<8|255;b[4817267]=d[9634883]<<8|255;g=0;f=i;i=h;do{f=((a[9632936+g|0]&1)<<g^f&65535)&65535;i=((a[9630808+g|0]&1)<<g^i&65535)&65535;g=g+1|0;}while((g|0)<16);b[4817264]=f;b[4817265]=i;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];i=c[3532592]|0;if((i|0)!=0){gGC(9104152,i|0,280)|0}c[2113054]=c[2113060]}i=c[2439330]|0;if((i|0)!=0){f=i;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;f=0;i=0;g=0;while(1){h=10-g|0;e=(2e5-i|0)/(h|0)|0;c[2113056]=e;j=RG(e)|0;c[2113054]=(c[2113054]|0)+j;c[2276108]=-1;c[2113056]=-1;e=j+i|0;do{if((g|0)==9){c[8452200+(c[2394]<<2)>>2]=8198;c[2276080]=1536;if((c[2276079]|0)>>>0>=1536){break}RH(6)}}while(0);j=(66666-f|0)/(h|0)|0;do{if((j|0)<1){k=0}else{if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){l=gfc(j)|0;c[2433530]=(c[2433530]|0)+l;k=l;break}else{c[2433530]=(c[2433530]|0)+j;k=j;break}}}while(0);j=a[9688]|0?53:0;h=c[2112964]|0;if((h|0)!=0){l=c[3542124]|0;m=ag(j,g<<1)|0;gg[l&4095](h+(m<<1)|0,j);Uu(0,(c[2112964]|0)+(m<<1)|0,j)}j=g+1|0;if((j|0)<10){f=k+f|0;i=e;g=j}else{break}}g=c[1836236]|0;i=c[9757320+(g<<2)>>2]|0;if((i|0)!=0){f=i;gGC(f|0,9706056,76)|0}c[9752472+(g<<2)>>2]=c[2433530];c[14113936+(g<<2)>>2]=c[2076596];c[9669104+(g<<2)>>2]=c[3541536];c[1836236]=-1;g=c[2394]|0;f=c[14130368+(g<<2)>>2]|0;if((f|0)!=0){gGC(f|0,9104152,280)|0}c[8452240+(g<<2)>>2]=c[2113054];c[2394]=-1;if((c[2112968]|0)==0){return 0}eys()|0;return 0}function eys(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((a[9547248]|0)!=0){d=c[2406918]|0;f=c[3529944]|0;g=0;do{h=c[d+(g<<2)>>2]|0;c[f+(g<<2)>>2]=h>>8<<3&2016|h>>>3&31|h>>16<<8&63488;g=g+1|0;}while((g|0)<768)}g=c[2112926]|0;gGz(g|0,0,ag(c[2113068]<<1,c[2113070]|0)|0);eyu(c[3529416]|0,512,1);eyu(c[3529452]|0,256,0);f=c[2386418]|0;d=f+16384|0;h=c[3530792]|0;i=f;do{f=e[i+4>>1]<<8&65280|b[i+6>>1]&255;j=e[i+2>>1]|0;k=j&15;l=(j<<3&256|b[i>>1]&255)-28|0;m=(j<<4&256|b[i+8>>1]&255)-24|0;if((j&128|0)==0){SH(g,f,l,m,k,4,0,0,h)}else{SJ(g,f,l,m,k,4,0,0,h)}i=i+16|0;}while(i>>>0<d>>>0);R8(c[3529944]|0);return 0}function eyt(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+96|0;g=f|0;h=f+16|0;j=f+32|0;k=f+48|0;l=f+64|0;m=f+80|0;if((e|0)!=0){c[e>>2]=169623}if((b&32|0)!=0){gGz(m|0,0,12);e=c[2414612]|0;c[m>>2]=e;c[m+4>>2]=(c[2411572]|0)-e;c[m+12>>2]=162152;e=c[2076592]|0;gj[e&4095](m)|0}if((b&64|0)==0){i=f;return 0}m=l|0;gGz(k|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){e=l+9|0;l=j;n=j|0;o=j+4|0;p=j+12|0;q=k|0;r=k+4|0;s=k+12|0;t=0;do{gGC(m|0,614896,11)|0;a[e]=t+48&255;u=8452256+(t<<2)|0;gGz(l|0,0,12);c[n>>2]=u;c[o>>2]=4;c[p>>2]=164976;gj[c[2076592]&4095](j)|0;if((c[u>>2]|0)!=0){c[q>>2]=c[14130368+(t<<2)>>2];c[r>>2]=c[8452184+(t<<2)>>2];c[s>>2]=m;u=c[2076592]|0;gj[u&4095](k)|0}t=t+1|0;}while((t|0)<=(c[2392]|0))}fw$(b);gGz(h|0,0,12);c[h>>2]=8453216;c[h+4>>2]=4;c[h+12>>2]=107480;gj[c[2076592]&4095](h)|0;gGz(g|0,0,12);c[g>>2]=14168504;c[g+4>>2]=256;c[g+12>>2]=476464;gj[c[2076592]&4095](g)|0;if((b&2|0)!=0){b=0;do{mv(0,b,d[14168504+b|0]|0);b=b+1|0;}while((b|0)<256)}Ut(0);i=f;return 0}function eyu(a,b,d){a=a|0;b=b|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=a;a=(c[3529798]|0)+(d<<2)|0;g=(c[3529792]|0)+(d<<2)|0;d=c[2112926]|0;h=c[3530556]|0;i=0;do{j=i<<1;k=e[f+((j|1)<<1)>>1]|0;l=e[f+(j<<1)>>1]|0;j=l&15;m=(i<<4&496)-(c[a>>2]&511)|0;n=(i>>5<<4)-(c[g>>2]&511)|0;o=(m|0)<-15?m+512|0:m;m=(n|0)<-15?n+512|0:n;n=(l&64|0)!=0;do{if((l&128|0)==0){if(n){SJ(d,k,o,m,j,4,0,b,h);break}else{SH(d,k,o,m,j,4,0,b,h);break}}else{if(n){SN(d,k,o,m,j,4,0,b,h);break}else{SL(d,k,o,m,j,4,0,b,h);break}}}while(0);i=i+1|0;}while((i|0)<1024);return}function eyv(a,b){a=a|0;b=b|0;if(!((a|0)==1770240|(a|0)==1835776)){return}Uv(0,b&255);return}function eyw(a){a=a|0;var d=0;if((a|0)==1769984|(a|0)==1835520){d=b[4774884]|0}else if((a|0)==1769728|(a|0)==1835264){d=b[4774968]|0}else if((a|0)==1770240|(a|0)==1835776){d=c[2113156]&65535}else{d=0}return d|0}function eyx(a,b){a=a|0;b=b|0;return}function eyy(a){a=a|0;return 0}function eyz(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6570500+(b*112|0)>>2];c[a+104>>2]=c[6570504+(b*112|0)>>2];c[a+108>>2]=c[6570508+(b*112|0)>>2];d=0;return d|0}function eyA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=6570400+(b*112|0);e=0;return e|0}function eyB(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5369560+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eyC(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6879744+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eyD(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;b=i;i=i+600|0;d=b|0;e=b+112|0;f=b+120|0;g=b+232|0;h=b+240|0;j=b+352|0;k=b+360|0;l=b+472|0;m=b+480|0;n=b+592|0;c[2414908]=0;c[2388104]=0;c[3530790]=524288;c[3530554]=2621440;c[3541206]=3145728;c[2386612]=3145728;c[3529942]=3407872;c[2414610]=3409920;c[2388234]=3409920;c[2387142]=3426304;c[2406558]=3427328;c[2406482]=3435520;c[2411568]=3468288;o=0;while(1){if((o|0)>=1024){break}p=9638528+(o<<2)|0;if((c[p>>2]|0)==0){q=9697;break}else{o=o+1|0}}do{if((q|0)==9697){o=gGq(3468288)|0;c[p>>2]=o;if((o|0)==0){break}c[2414908]=o;gGz(o|0,0,3468288);c[2388104]=o;c[3530790]=o+524288;c[3530554]=o+2621440;r=o+3145728|0;c[3541206]=r;c[2386612]=r;c[3529942]=o+3407872;r=o+3409920|0;c[2414610]=r;c[2388234]=r;c[2387142]=o+3426304;c[2406558]=o+3427328;c[2406482]=o+3435520;r=o+3468288|0;c[2411568]=r;c[2414110]=r;r=(dW(c[c[642608+(c[2436]<<2)>>2]>>2]|0,102024,7)|0)!=0;s=r?0:65536;if((R6(o,0,2)|0)!=0){t=1;i=b;return t|0}if((R6((c[2388104]|0)+1|0,1,2)|0)!=0){t=1;i=b;return t|0}o=c[2386612]|0;if((c[3542200]|0)==0){t=1;i=b;return t|0}r=m+108|0;c[r>>2]=0;u=m+100|0;c[u>>2]=0;v=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[v&16383](m,2)|0;do{if((c[r>>2]|0)!=0){v=c[u>>2]|0;c[n>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](n,2,0)|0;if((v|0)<1){t=1;i=b;return t|0}if((gzL(o,0,2)|0)==0){break}else{t=1}i=b;return t|0}}while(0);o=c[3530554]|0;if((c[3542200]|0)==0){t=1;i=b;return t|0}u=k+108|0;c[u>>2]=0;r=k+100|0;c[r>>2]=0;v=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[v&16383](k,3)|0;do{if((c[u>>2]|0)!=0){v=c[r>>2]|0;c[l>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](l,3,0)|0;if((v|0)<1){t=1;i=b;return t|0}if((gzL(o,0,3)|0)==0){break}else{t=1}i=b;return t|0}}while(0);o=(c[3530554]|0)+262144|0;if((c[3542200]|0)==0){t=1;i=b;return t|0}r=h+108|0;c[r>>2]=0;u=h+100|0;c[u>>2]=0;v=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[v&16383](h,4)|0;do{if((c[r>>2]|0)!=0){v=c[u>>2]|0;c[j>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](j,4,0)|0;if((v|0)<1){t=1;i=b;return t|0}if((gzL(o,0,4)|0)==0){break}else{t=1}i=b;return t|0}}while(0);o=c[3530790]|0;if((c[3542200]|0)==0){t=1;i=b;return t|0}u=f+108|0;c[u>>2]=0;r=f+100|0;c[r>>2]=0;v=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[v&16383](f,5)|0;do{if((c[u>>2]|0)!=0){v=c[r>>2]|0;c[g>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](g,5,0)|0;if((v|0)<1){t=1;i=b;return t|0}if((gzL(o,0,5)|0)==0){break}else{t=1}i=b;return t|0}}while(0);o=(c[3530790]|0)+1048576|0;if((c[3542200]|0)==0){t=1;i=b;return t|0}r=d+108|0;c[r>>2]=0;u=d+100|0;c[u>>2]=0;v=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[v&16383](d,6)|0;do{if((c[r>>2]|0)!=0){v=c[u>>2]|0;c[e>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](e,6,0)|0;if((v|0)<1){t=1;i=b;return t|0}if((gzL(o,0,6)|0)==0){break}else{t=1}i=b;return t|0}}while(0);eyX();fxU(0,425984);if((c[2394]|0)==0){x=c[2112932]|0}else{c[2394]=0;o=c[3532596]|0;c[2112932]=o;u=c[3532592]|0;if((u|0)!=0){gGC(9104152,u|0,280)|0}c[2113054]=c[2113060];x=o}o=c[2388104]|0;u=x|0;r=0;while(1){v=o+r|0;c[u>>2]=v;c[u+131072>>2]=v;v=r+1024|0;if(v>>>0>524287){break}else{u=u+4|0;r=v}}r=c[2388234]|0;c[x+2048>>2]=r;c[x+67584>>2]=r;c[x+133120>>2]=r;u=r+1024|0;c[x+2052>>2]=u;c[x+67588>>2]=u;c[x+133124>>2]=u;u=r+2048|0;c[x+2056>>2]=u;c[x+67592>>2]=u;c[x+133128>>2]=u;u=r+3072|0;c[x+2060>>2]=u;c[x+67596>>2]=u;c[x+133132>>2]=u;u=r+4096|0;c[x+2064>>2]=u;c[x+67600>>2]=u;c[x+133136>>2]=u;u=r+5120|0;c[x+2068>>2]=u;c[x+67604>>2]=u;c[x+133140>>2]=u;u=r+6144|0;c[x+2072>>2]=u;c[x+67608>>2]=u;c[x+133144>>2]=u;u=r+7168|0;c[x+2076>>2]=u;c[x+67612>>2]=u;c[x+133148>>2]=u;u=r+8192|0;c[x+2080>>2]=u;c[x+67616>>2]=u;c[x+133152>>2]=u;u=r+9216|0;c[x+2084>>2]=u;c[x+67620>>2]=u;c[x+133156>>2]=u;u=r+10240|0;c[x+2088>>2]=u;c[x+67624>>2]=u;c[x+133160>>2]=u;u=r+11264|0;c[x+2092>>2]=u;c[x+67628>>2]=u;c[x+133164>>2]=u;u=r+12288|0;c[x+2096>>2]=u;c[x+67632>>2]=u;c[x+133168>>2]=u;u=r+13312|0;c[x+2100>>2]=u;c[x+67636>>2]=u;c[x+133172>>2]=u;u=r+14336|0;c[x+2104>>2]=u;c[x+67640>>2]=u;c[x+133176>>2]=u;u=r+15360|0;c[x+2108>>2]=u;c[x+67644>>2]=u;c[x+133180>>2]=u;u=c[2387142]|0;c[x+6912>>2]=u;c[x+72448>>2]=u;c[x+137984>>2]=u;u=c[2406558]|0;r=s|1966080;o=s|1970175;if(r>>>0<=o>>>0){v=x+(r>>>10<<2)|0;w=r;while(1){y=u+(w-r)|0;c[v>>2]=y;c[v+65536>>2]=y;c[v+131072>>2]=y;y=w+1024|0;if(y>>>0>o>>>0){break}else{v=v+4|0;w=y}}}w=c[2406482]|0;v=s^2031616;o=s^2047999;if(v>>>0<=o>>>0){r=x+(v>>>10<<2)|0;u=v;while(1){y=w+(u-v)|0;c[r>>2]=y;c[r+65536>>2]=y;c[r+131072>>2]=y;y=u+1024|0;if(y>>>0>o>>>0){break}else{r=r+4|0;u=y}}}c[x+196648>>2]=1288;c[x+196608>>2]=3082;c[x+196728>>2]=2044;c[x+196688>>2]=2482;u=c[3532592]|0;if((u|0)!=0){gGC(u|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;Ux(0,8500,0);c[2407030]=120;c[2407068]=3;u=c[642608+(c[2436]<<2)>>2]|0;r=c[u+128>>2]|0;if((c[u+52>>2]&4|0)==0){c[2113068]=r;o=c[u+132>>2]|0;c[2113070]=o;c[2443814]=r;c[2440436]=o;z=r;A=o}else{c[2113070]=r;o=c[u+132>>2]|0;c[2113068]=o;c[2440436]=r;c[2443814]=o;z=o;A=r}r=ag(z<<1,A)|0;o=gGq(r)|0;c[2112926]=o;if((o|0)!=0){gGz(o|0,0,r|0)}a[9623824]=0;r=c[2414610]|0;gGz(r|0,0,(c[2411568]|0)-r|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];r=c[3532592]|0;if((r|0)!=0){gGC(9104152,r|0,280)|0}c[2113054]=c[2113060]}RI();r=c[2394]|0;o=c[14130368+(r<<2)>>2]|0;if((o|0)!=0){gGC(o|0,9104152,280)|0}c[8452240+(r<<2)>>2]=c[2113054];c[2394]=-1;c[2113156]=0;a[9628264]=0;c[2407033]=0;r=c[3541206]|0;c[3541190]=r;c[3541198]=r;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=r+256;c[3541199]=r+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=r+512;c[3541200]=r+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=r+768;c[3541201]=r+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;t=0;i=b;return t|0}}while(0);c[2414908]=0;t=1;i=b;return t|0}function eyE(){var a=0,b=0,d=0,e=0,f=0;c[2113070]=0;c[2113068]=0;a=c[2112926]|0;if((a|0)!=0){gGr(a);c[2112926]=0}Uw(0);if((c[2392]|0)>=0){a=0;do{b=14130368+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}b=14130384+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}a=a+1|0;}while((a|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;a=c[2414908]|0;b=0;while(1){if((b|0)>=1024){e=9781;break}f=9638528+(b<<2)|0;if((c[f>>2]|0)==(a|0)){break}else{b=b+1|0}}if((e|0)==9781){c[2414908]=0;c[3541206]=0;return 0}gGr(a);c[f>>2]=0;c[2414908]=0;c[3541206]=0;return 0}function eyF(){var e=0,f=0,g=0;if((a[9623824]|0)!=0){a[9623824]=0;e=c[2414610]|0;gGz(e|0,0,(c[2411568]|0)-e|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060]}RI();e=c[2394]|0;f=c[14130368+(e<<2)>>2]|0;if((f|0)!=0){gGC(f|0,9104152,280)|0}c[8452240+(e<<2)>>2]=c[2113054];c[2394]=-1;c[2113156]=0;a[9628264]=0;c[2407033]=0;e=c[3541206]|0;c[3541190]=e;c[3541198]=e;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=e+256;c[3541199]=e+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=e+512;c[3541200]=e+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=e+768;c[3541201]=e+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4}b[4774968]=-1;e=0;f=-1;do{f=((a[9632920+e|0]&1)<<e^f&65535)&65535;e=e+1|0;}while((e|0)<16);b[4774968]=f;b[4774884]=d[9634872]<<8|255;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060]}c[2113056]=119318;f=RG(119318)|0;c[2113054]=(c[2113054]|0)+f;c[2276108]=-1;c[2113056]=-1;f=c[2394]|0;c[8452200+(f<<2)>>2]=8193;c[2276080]=256;if((c[2276079]|0)>>>0<256){RH(1);g=c[2394]|0}else{g=f}f=c[14130368+(g<<2)>>2]|0;if((f|0)!=0){gGC(f|0,9104152,280)|0}c[8452240+(g<<2)>>2]=c[2113054];c[2394]=-1;g=c[2112964]|0;if((g|0)!=0){Uu(0,g,a[9688]|0?534:0)}if((c[2112968]|0)==0){return 0}eyG()|0;return 0}function eyG(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;if((a[9547240]|0)!=0){f=c[2387142]|0;g=c[3529942]|0;h=0;do{i=b[f+(h<<1)>>1]|0;j=(i&65535)>>>7;c[g+(h<<2)>>2]=(j&65535)<<8&63488|i&31|(((i&65535)>>>2&255&-8|j&4)&255)<<3&2016;h=h+1|0;}while((h|0)<512)}h=c[2406558]|0;g=c[2113068]|0;f=c[2112926]|0;j=c[3530790]|0;i=128;do{k=(i<<3&504)-64|0;if((k|0)>-1&(k|0)<(g|0)){l=j+(e[h+(i<<1)>>1]<<6&2097088)|0;c[2112928]=l;m=f+((ag(g,(i>>6<<3)-16|0)|0)+k<<1)|0;k=0;n=l;while(1){b[m>>1]=d[n]|0;b[m+2>>1]=d[n+1|0]|0;b[m+4>>1]=d[n+2|0]|0;b[m+6>>1]=d[n+3|0]|0;b[m+8>>1]=d[n+4|0]|0;b[m+10>>1]=d[n+5|0]|0;b[m+12>>1]=d[n+6|0]|0;b[m+14>>1]=d[n+7|0]|0;l=k+1|0;o=n+8|0;if((l|0)<8){m=m+(g<<1)|0;k=l;n=o}else{break}}c[2112928]=o}i=i+1|0;}while((i|0)<1920);i=c[2406482]|0;o=c[3530554]|0;h=512;do{j=(h<<2&508)-64|0;n=e[i+(h<<1)>>1]|0;do{if((j|0)>=0&(j|0)<(g|0)){k=(ag(g,(h>>7<<2)-16|0)|0)+j|0;m=n<<4&524272;l=a[o+m|0]|0;if(l<<24>>24!=-1){b[f+(k<<1)>>1]=l&255|256}l=a[o+(m|1)|0]|0;if(l<<24>>24!=-1){b[f+((k|1)<<1)>>1]=l&255|256}l=a[o+(m|2)|0]|0;if(l<<24>>24!=-1){b[f+((k|2)<<1)>>1]=l&255|256}l=a[o+(m|3)|0]|0;if(l<<24>>24!=-1){b[f+((k|3)<<1)>>1]=l&255|256}l=g+k|0;k=m|4;p=a[o+k|0]|0;if(p<<24>>24!=-1){b[f+(l<<1)>>1]=p&255|256}p=a[o+(m|5)|0]|0;if(p<<24>>24!=-1){b[f+(l+1<<1)>>1]=p&255|256}p=a[o+(m|6)|0]|0;if(p<<24>>24!=-1){b[f+(l+2<<1)>>1]=p&255|256}p=a[o+(m|7)|0]|0;if(p<<24>>24!=-1){b[f+(l+3<<1)>>1]=p&255|256}p=g+l|0;l=a[o+(k+4)|0]|0;if(l<<24>>24!=-1){b[f+(p<<1)>>1]=l&255|256}l=a[o+(k+5)|0]|0;if(l<<24>>24!=-1){b[f+(p+1<<1)>>1]=l&255|256}l=a[o+(k+6)|0]|0;if(l<<24>>24!=-1){b[f+(p+2<<1)>>1]=l&255|256}l=a[o+(k+7)|0]|0;if(l<<24>>24!=-1){b[f+(p+3<<1)>>1]=l&255|256}l=g+p|0;p=a[o+(m|12)|0]|0;if(p<<24>>24!=-1){b[f+(l<<1)>>1]=p&255|256}p=a[o+(m|13)|0]|0;if(p<<24>>24!=-1){b[f+(l+1<<1)>>1]=p&255|256}p=a[o+(m|14)|0]|0;if(p<<24>>24!=-1){b[f+(l+2<<1)>>1]=p&255|256}p=a[o+(m|15)|0]|0;if(p<<24>>24==-1){break}b[f+(l+3<<1)>>1]=p&255|256}}while(0);h=h+1|0;}while((h|0)<7680);R8(c[3529942]|0);return 0}function eyH(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=i;i=i+64|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;if((d|0)!=0){c[d>>2]=169730}if((b&32|0)!=0){gGz(j|0,0,12);d=c[2414610]|0;c[j>>2]=d;c[j+4>>2]=(c[2411568]|0)-d;c[j+12>>2]=162152;d=c[2076592]|0;gj[d&4095](j)|0}if((b&64|0)==0){i=e;return 0}b=h|0;gGz(g|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){j=h+9|0;h=f;d=f|0;k=f+4|0;l=f+12|0;m=g|0;n=g+4|0;o=g+12|0;p=0;do{gGC(b|0,614896,11)|0;a[j]=p+48&255;q=8452256+(p<<2)|0;gGz(h|0,0,12);c[d>>2]=q;c[k>>2]=4;c[l>>2]=164976;gj[c[2076592]&4095](f)|0;if((c[q>>2]|0)!=0){c[m>>2]=c[14130368+(p<<2)>>2];c[n>>2]=c[8452184+(p<<2)>>2];c[o>>2]=b;q=c[2076592]|0;gj[q&4095](g)|0}p=p+1|0;}while((p|0)<=(c[2392]|0))}Ut(0);i=e;return 0}function eyI(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2551212+(b*112|0)>>2];c[a+104>>2]=c[2551216+(b*112|0)>>2];c[a+108>>2]=c[2551220+(b*112|0)>>2];d=0;return d|0}function eyJ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=2551112+(b*112|0);e=0;return e|0}function eyK(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4534404+(b*112|0)>>2];c[a+104>>2]=c[4534408+(b*112|0)>>2];c[a+108>>2]=c[4534412+(b*112|0)>>2];d=0;return d|0}function eyL(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=4534304+(b*112|0);e=0;return e|0}function eyM(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5257888+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eyN(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;b=i;i=i+960|0;d=b|0;e=b+112|0;f=b+120|0;g=b+232|0;h=b+240|0;j=b+352|0;k=b+360|0;l=b+472|0;m=b+480|0;n=b+592|0;o=b+600|0;p=b+712|0;q=b+720|0;r=b+832|0;s=b+840|0;t=b+952|0;c[2414908]=0;c[2388104]=0;c[3530790]=524288;c[3530554]=2621440;c[3541206]=3145728;c[2386612]=3145728;c[3529942]=3407872;c[2414610]=3409920;c[2388234]=3409920;c[2387142]=3426304;c[2406558]=3427328;c[2406482]=3435520;c[2411568]=3468288;u=0;while(1){if((u|0)>=1024){break}v=9638528+(u<<2)|0;if((c[v>>2]|0)==0){w=9901;break}else{u=u+1|0}}do{if((w|0)==9901){u=gGq(3468288)|0;c[v>>2]=u;if((u|0)==0){break}c[2414908]=u;gGz(u|0,0,3468288);c[2388104]=u;c[3530790]=u+524288;c[3530554]=u+2621440;x=u+3145728|0;c[3541206]=x;c[2386612]=x;c[3529942]=u+3407872;x=u+3409920|0;c[2414610]=x;c[2388234]=x;c[2387142]=u+3426304;c[2406558]=u+3427328;c[2406482]=u+3435520;x=u+3468288|0;c[2411568]=x;c[2414110]=x;if((R6(u,0,2)|0)!=0){y=1;i=b;return y|0}if((R6((c[2388104]|0)+1|0,1,2)|0)!=0){y=1;i=b;return y|0}u=c[2386612]|0;if((c[3542200]|0)==0){y=1;i=b;return y|0}x=s+108|0;c[x>>2]=0;z=s+100|0;c[z>>2]=0;A=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[A&16383](s,2)|0;do{if((c[x>>2]|0)!=0){A=c[z>>2]|0;c[t>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](t,2,0)|0;if((A|0)<1){y=1;i=b;return y|0}if((gzL(u,0,2)|0)==0){break}else{y=1}i=b;return y|0}}while(0);u=c[3530554]|0;if((c[3542200]|0)==0){y=1;i=b;return y|0}z=q+108|0;c[z>>2]=0;x=q+100|0;c[x>>2]=0;A=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[A&16383](q,3)|0;do{if((c[z>>2]|0)!=0){A=c[x>>2]|0;c[r>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](r,3,0)|0;if((A|0)<1){y=1;i=b;return y|0}if((gzL(u,0,3)|0)==0){break}else{y=1}i=b;return y|0}}while(0);u=(c[3530554]|0)+262144|0;if((c[3542200]|0)==0){y=1;i=b;return y|0}x=o+108|0;c[x>>2]=0;z=o+100|0;c[z>>2]=0;A=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[A&16383](o,4)|0;do{if((c[x>>2]|0)!=0){A=c[z>>2]|0;c[p>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](p,4,0)|0;if((A|0)<1){y=1;i=b;return y|0}if((gzL(u,0,4)|0)==0){break}else{y=1}i=b;return y|0}}while(0);u=c[642608+(c[2436]<<2)>>2]|0;z=(fa(c[u>>2]|0,119032)|0)==0;x=c[3530790]|0;do{if((c[3542200]|0)==0){C=1}else{A=m+108|0;c[A>>2]=0;B=m+100|0;c[B>>2]=0;D=c[u+76>>2]|0;gA[D&16383](m,5)|0;if((c[A>>2]|0)==0){C=0;break}A=c[B>>2]|0;c[n>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](n,5,0)|0;if((A|0)<1){C=1;break}C=(gzL(x,0,5)|0)!=0}}while(0);do{if(z){if(C){y=1;i=b;return y|0}x=(c[3530790]|0)+1048576|0;if((c[3542200]|0)==0){y=1;i=b;return y|0}u=k+108|0;c[u>>2]=0;A=k+100|0;c[A>>2]=0;B=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[B&16383](k,6)|0;if((c[u>>2]|0)==0){break}u=c[A>>2]|0;c[l>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](l,6,0)|0;if((u|0)<1){y=1;i=b;return y|0}if((gzL(x,0,6)|0)==0){break}else{y=1}i=b;return y|0}else{if(C){y=1;i=b;return y|0}x=(c[3530790]|0)+524288|0;if((c[3542200]|0)==0){y=1;i=b;return y|0}u=h+108|0;c[u>>2]=0;A=h+100|0;c[A>>2]=0;B=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[B&16383](h,6)|0;do{if((c[u>>2]|0)!=0){B=c[A>>2]|0;c[j>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](j,6,0)|0;if((B|0)<1){y=1;i=b;return y|0}if((gzL(x,0,6)|0)==0){break}else{y=1}i=b;return y|0}}while(0);x=(c[3530790]|0)+1048576|0;if((c[3542200]|0)==0){y=1;i=b;return y|0}A=f+108|0;c[A>>2]=0;u=f+100|0;c[u>>2]=0;B=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[B&16383](f,7)|0;do{if((c[A>>2]|0)!=0){B=c[u>>2]|0;c[g>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](g,7,0)|0;if((B|0)<1){y=1;i=b;return y|0}if((gzL(x,0,7)|0)==0){break}else{y=1}i=b;return y|0}}while(0);x=(c[3530790]|0)+1572864|0;if((c[3542200]|0)==0){y=1;i=b;return y|0}u=d+108|0;c[u>>2]=0;A=d+100|0;c[A>>2]=0;B=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[B&16383](d,8)|0;if((c[u>>2]|0)==0){break}u=c[A>>2]|0;c[e>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](e,8,0)|0;if((u|0)<1){y=1;i=b;return y|0}if((gzL(x,0,8)|0)==0){break}else{y=1}i=b;return y|0}}while(0);eyX();fxU(0,425984);if((c[2394]|0)==0){E=c[2112932]|0}else{c[2394]=0;z=c[3532596]|0;c[2112932]=z;x=c[3532592]|0;if((x|0)!=0){gGC(9104152,x|0,280)|0}c[2113054]=c[2113060];E=z}z=c[2388104]|0;x=E|0;u=0;while(1){A=z+u|0;c[x>>2]=A;c[x+131072>>2]=A;A=u+1024|0;if(A>>>0>524287){break}else{x=x+4|0;u=A}}u=c[2388234]|0;c[E+4096>>2]=u;c[E+69632>>2]=u;c[E+135168>>2]=u;x=u+1024|0;c[E+4100>>2]=x;c[E+69636>>2]=x;c[E+135172>>2]=x;x=u+2048|0;c[E+4104>>2]=x;c[E+69640>>2]=x;c[E+135176>>2]=x;x=u+3072|0;c[E+4108>>2]=x;c[E+69644>>2]=x;c[E+135180>>2]=x;x=u+4096|0;c[E+4112>>2]=x;c[E+69648>>2]=x;c[E+135184>>2]=x;x=u+5120|0;c[E+4116>>2]=x;c[E+69652>>2]=x;c[E+135188>>2]=x;x=u+6144|0;c[E+4120>>2]=x;c[E+69656>>2]=x;c[E+135192>>2]=x;x=u+7168|0;c[E+4124>>2]=x;c[E+69660>>2]=x;c[E+135196>>2]=x;x=u+8192|0;c[E+4128>>2]=x;c[E+69664>>2]=x;c[E+135200>>2]=x;x=u+9216|0;c[E+4132>>2]=x;c[E+69668>>2]=x;c[E+135204>>2]=x;x=u+10240|0;c[E+4136>>2]=x;c[E+69672>>2]=x;c[E+135208>>2]=x;x=u+11264|0;c[E+4140>>2]=x;c[E+69676>>2]=x;c[E+135212>>2]=x;x=u+12288|0;c[E+4144>>2]=x;c[E+69680>>2]=x;c[E+135216>>2]=x;x=u+13312|0;c[E+4148>>2]=x;c[E+69684>>2]=x;c[E+135220>>2]=x;x=u+14336|0;c[E+4152>>2]=x;c[E+69688>>2]=x;c[E+135224>>2]=x;x=u+15360|0;c[E+4156>>2]=x;c[E+69692>>2]=x;c[E+135228>>2]=x;x=c[2387142]|0;c[E+6656>>2]=x;c[E+72192>>2]=x;c[E+137728>>2]=x;x=c[2406482]|0;u=E+6400|0;z=1638400;while(1){A=x+(z-1638400)|0;c[u>>2]=A;c[u+65536>>2]=A;c[u+131072>>2]=A;A=z+1024|0;if(A>>>0>1671167){break}else{u=u+4|0;z=A}}z=c[2406558]|0;c[E+7168>>2]=z;c[E+72704>>2]=z;c[E+138240>>2]=z;u=z+1024|0;c[E+7172>>2]=u;c[E+72708>>2]=u;c[E+138244>>2]=u;u=z+2048|0;c[E+7176>>2]=u;c[E+72712>>2]=u;c[E+138248>>2]=u;u=z+3072|0;c[E+7180>>2]=u;c[E+72716>>2]=u;c[E+138252>>2]=u;u=z+4096|0;c[E+7184>>2]=u;c[E+72720>>2]=u;c[E+138256>>2]=u;u=z+5120|0;c[E+7188>>2]=u;c[E+72724>>2]=u;c[E+138260>>2]=u;u=z+6144|0;c[E+7192>>2]=u;c[E+72728>>2]=u;c[E+138264>>2]=u;u=z+7168|0;c[E+7196>>2]=u;c[E+72732>>2]=u;c[E+138268>>2]=u;c[E+196648>>2]=1288;c[E+196608>>2]=3082;c[E+196728>>2]=2044;c[E+196688>>2]=2482;u=c[3532592]|0;if((u|0)!=0){gGC(u|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;Ux(0,8500,0);c[2407030]=120;c[2407068]=3;u=c[642608+(c[2436]<<2)>>2]|0;z=c[u+128>>2]|0;if((c[u+52>>2]&4|0)==0){c[2113068]=z;x=c[u+132>>2]|0;c[2113070]=x;c[2443814]=z;c[2440436]=x;F=z;G=x}else{c[2113070]=z;x=c[u+132>>2]|0;c[2113068]=x;c[2440436]=z;c[2443814]=x;F=x;G=z}z=ag(F<<1,G)|0;x=gGq(z)|0;c[2112926]=x;if((x|0)!=0){gGz(x|0,0,z|0)}a[9623824]=0;z=c[2414610]|0;gGz(z|0,0,(c[2411568]|0)-z|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];z=c[3532592]|0;if((z|0)!=0){gGC(9104152,z|0,280)|0}c[2113054]=c[2113060]}RI();z=c[2394]|0;x=c[14130368+(z<<2)>>2]|0;if((x|0)!=0){gGC(x|0,9104152,280)|0}c[8452240+(z<<2)>>2]=c[2113054];c[2394]=-1;c[2113156]=0;a[9628264]=0;c[2407033]=0;z=c[3541206]|0;c[3541190]=z;c[3541198]=z;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=z+256;c[3541199]=z+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=z+512;c[3541200]=z+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=z+768;c[3541201]=z+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;y=0;i=b;return y|0}}while(0);c[2414908]=0;y=1;i=b;return y|0}function eyO(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2551996+(b*112|0)>>2];c[a+104>>2]=c[2552e3+(b*112|0)>>2];c[a+108>>2]=c[2552004+(b*112|0)>>2];d=0;return d|0}function eyP(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=2551896+(b*112|0);e=0;return e|0}function eyQ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3682080+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eyR(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2964548+(b*112|0)>>2];c[a+104>>2]=c[2964552+(b*112|0)>>2];c[a+108>>2]=c[2964556+(b*112|0)>>2];d=0;return d|0}function eyS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=2964448+(b*112|0);e=0;return e|0}function eyT(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1285176+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eyU(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4096648+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eyV(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2965332+(b*112|0)>>2];c[a+104>>2]=c[2965336+(b*112|0)>>2];c[a+108>>2]=c[2965340+(b*112|0)>>2];d=0;return d|0}function eyW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=2965232+(b*112|0);e=0;return e|0}function eyX(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=0;while(1){if((b|0)>=1024){e=10082;break}f=9638528+(b<<2)|0;if((c[f>>2]|0)==0){break}else{b=b+1|0}}if((e|0)==10082){return}b=gGq(2097152)|0;c[f>>2]=b;if((b|0)==0){return}gGz(b|0,0,2097152);f=c[3530790]|0;gGC(b|0,f|0,2097152)|0;g=0;do{h=g<<6;gGz(f+h|0,0,64);i=g<<8;j=0;do{k=1<<7-j;l=(c[614800+(j<<2)>>2]|0)+i|0;m=0;do{n=l+(c[1183816+(m<<2)>>2]|0)|0;o=(m<<3)+h|0;p=0;do{q=n+(c[610448+(p<<2)>>2]|0)|0;if(((d[b+((q|0)/8|0)|0]|0)&128>>>((q&7)>>>0)|0)!=0){q=f+(o+p)|0;a[q]=(d[q]|0|k)&255}p=p+1|0;}while((p|0)<8);m=m+1|0;}while((m|0)<8);j=j+1|0;}while((j|0)<8);g=g+1|0;}while((g|0)<32768);g=c[3530554]|0;gGC(b|0,g|0,524288)|0;f=0;while(1){j=f<<4;gGz(g+j|0,0,16);h=f<<6;i=0;do{m=1<<7-i;k=(c[614800+(i<<2)>>2]|0)+h|0;l=0;do{p=k+(c[608608+(l<<2)>>2]|0)|0;o=(l<<2)+j|0;if(((d[b+((p|0)/8|0)|0]|0)&128>>>((p&7)>>>0)|0)!=0){n=g+o|0;a[n]=(d[n]|0|m)&255}n=p+2097152|0;if(((d[b+((n|0)/8|0)|0]|0)&128>>>((n&7)>>>0)|0)!=0){n=g+(o|1)|0;a[n]=(d[n]|0|m)&255}n=p+8|0;if(((d[b+((n|0)/8|0)|0]|0)&128>>>((n&7)>>>0)|0)!=0){n=g+(o|2)|0;a[n]=(d[n]|0|m)&255}n=p+2097160|0;if(((d[b+((n|0)/8|0)|0]|0)&128>>>((n&7)>>>0)|0)!=0){n=g+(o|3)|0;a[n]=(d[n]|0|m)&255}l=l+1|0;}while((l|0)<4);i=i+1|0;}while((i|0)<8);i=f+1|0;if((i|0)<32768){f=i}else{r=0;break}}while(1){if((r|0)>=1024){e=10080;break}s=9638528+(r<<2)|0;if((c[s>>2]|0)==(b|0)){break}else{r=r+1|0}}if((e|0)==10080){return}gGr(b);c[s>>2]=0;return}function eyY(a,b){a=a|0;b=b|0;return}function eyZ(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;if((d&-2048|0)==2097152){f=d&2047;b[(c[2387140]|0)+f>>1]=e;g=e&65535;h=g>>>10&31;i=g>>>5&31;j=g&31;g=i<<3|i>>>2;i=f>>>1;c[(c[2406916]|0)+(i<<2)>>2]=j<<3|j>>>2|g<<8|(h<<3|h>>>2)<<16;c[(c[3529940]|0)+(i<<2)>>2]=h<<11|j|g<<3&2016;return}if((d|0)==6291468){a[14112928]=e&255;a[9706117]=1;return}else if((d|0)==5242884|(d|0)==5242886){b[(c[2438296]|0)+((d>>>1&1)<<1)>>1]=e;return}else if((d|0)==5242880|(d|0)==5242882){b[(c[2438298]|0)+((d>>>1&1)<<1)>>1]=e;return}else if((d|0)==6291464){d=e&255;a[9717672]=d&3;a[14114720]=d&-128;return}else{return}}function ey_(a){a=a|0;var b=0,c=0;b=a-6291458|0;if(b>>>0>=6){c=0;return c|0}c=(e[9550304+(b>>>1<<1)>>1]|0)>>>((a<<3&8^8)>>>0)&255;return c|0}function ey$(a){a=a|0;var c=0;if(!((a|0)==6291458|(a|0)==6291460|(a|0)==6291462)){c=0;return c|0}c=b[9550304+((a-6291458|0)>>>1<<1)>>1]|0;return c|0}function ey0(a,b){a=a|0;b=b|0;if((a|0)!=12582926){return}a=b&255;c[2415256]=0;b=a&1;c[3528406]=b^1;if((b|0)==0){c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2]}Tr(a>>>1&1);return}function ey1(d,f){d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;if((d&-4096|0)==8388608){g=d&4095;b[(c[2387140]|0)+g>>1]=f;h=f&65535;i=h>>>10&31;j=h>>>5&31;k=h&31;h=j<<3|j>>>2;j=g>>>1;c[(c[2406916]|0)+(j<<2)>>2]=k<<3|k>>>2|h<<8|(i<<3|i>>>2)<<16;c[(c[3529940]|0)+(j<<2)>>2]=i<<11|k|h<<3&2016;return}if((d|0)==11534344){b[4858800]=f;return}else if((d|0)==13631496){b[(c[3529414]|0)+(((e[4858796]|0)<<6)+(e[4858800]|0)<<1)>>1]=f;return}else if((d|0)==11534340|(d|0)==11534342){b[(c[2438296]|0)+((d>>>1&1)<<1)>>1]=f;return}else if((d|0)==11534336|(d|0)==11534338){b[(c[2438298]|0)+((d>>>1&1)<<1)>>1]=f;return}else if((d|0)==12582920){h=f&255;a[9717672]=h&3;a[14114720]=h&-128;return}else if((d|0)==11534346){b[4858796]=f;return}else if((d|0)==11534350){b[4876524]=f;return}else if((d|0)==12582924){a[14112928]=f&255;a[9706117]=1;return}else{return}}function ey2(a){a=a|0;var b=0,d=0;switch(a|0){case 12582918:{if((c[2406632]|0)!=0){b=(c[2432962]|0)>>>((c[(c[2420380]|0)+4>>2]|0)>>>0)<<7&255;return b|0}d=c[2443744]|0;if((d|0)<=0){b=-128;return b|0}c[2443744]=d-1;b=0;return b|0};case 12582914:case 12582915:case 12582916:case 12582917:{b=(e[9550304+((a-12582914|0)>>>1<<1)>>1]|0)>>>((a<<3&8^8)>>>0)&255;return b|0};default:{b=0;return b|0}}return 0}function ey3(a){a=a|0;return 0}function ey4(a,b){a=a|0;b=b|0;if((a|0)!=5242894){return}a=b&255;c[2415256]=0;b=a&1;c[3528406]=b^1;if((b|0)==0){c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2]}Tr(a>>>1&1);return}function ey5(d,f){d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;if((d&-4096|0)==4194304){g=d&4095;b[(c[2387140]|0)+g>>1]=f;h=f&65535;i=h>>>10&31;j=h>>>5&31;k=h&31;h=j<<3|j>>>2;j=g>>>1;c[(c[2406916]|0)+(j<<2)>>2]=k<<3|k>>>2|h<<8|(i<<3|i>>>2)<<16;c[(c[3529940]|0)+(j<<2)>>2]=i<<11|k|h<<3&2016;return}if((d|0)==7340042){b[4858796]=f;return}else if((d|0)==7340032|(d|0)==7340034){b[(c[2438298]|0)+((d>>>1&1)<<1)>>1]=f;return}else if((d|0)==5242888){h=f&255;a[9717672]=h&3;a[14114720]=h&-128;return}else if((d|0)==7340036|(d|0)==7340038){b[(c[2438296]|0)+((d>>>1&1)<<1)>>1]=f;return}else if((d|0)==7340040){b[4858800]=f;return}else if((d|0)==7340046){b[4876524]=f;return}else if((d|0)==13631496){b[(c[3529414]|0)+(((e[4858796]|0)<<6)+(e[4858800]|0)<<1)>>1]=f;return}else if((d|0)==5242892){a[14112928]=f&255;a[9706117]=1;return}else{return}}function ey6(a){a=a|0;var b=0,d=0;switch(a|0){case 5242886:{if((c[2406632]|0)!=0){b=(c[2432962]|0)>>>((c[(c[2420380]|0)+4>>2]|0)>>>0)<<7&255;return b|0}d=c[2443744]|0;if((d|0)<=0){b=-128;return b|0}c[2443744]=d-1;b=0;return b|0};case 5242882:case 5242883:case 5242884:case 5242885:{b=(e[9550304+((a-5242882|0)>>>1<<1)>>1]|0)>>>((a<<3&8^8)>>>0)&255;return b|0};default:{b=0;return b|0}}return 0}function ey7(a){a=a|0;var c=0;if(!((a|0)==5242882|(a|0)==5242884)){c=0;return c|0}c=b[9550304+((a-5242882|0)>>>1<<1)>>1]|0;return c|0}function ey8(a,b){a=a|0;b=b|0;if((a|0)!=5242894){return}a=b&255;c[2415256]=0;b=a&1;c[3528406]=b^1;if((b|0)==0){c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2]}Tr(a>>>1&1);return}function ey9(d,f){d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;if((d&-4096|0)==1048576){g=d&4095;b[(c[2387140]|0)+g>>1]=f;h=f&65535;i=h>>>10&31;j=h>>>5&31;k=h&31;h=j<<3|j>>>2;j=g>>>1;c[(c[2406916]|0)+(j<<2)>>2]=k<<3|k>>>2|h<<8|(i<<3|i>>>2)<<16;c[(c[3529940]|0)+(j<<2)>>2]=i<<11|k|h<<3&2016;return}if((d|0)==4194312){b[4858800]=f;return}else if((d|0)==6291464){b[(c[3529414]|0)+(((e[4858796]|0)<<6)+(e[4858800]|0)<<1)>>1]=f;return}else if((d|0)==5242888){h=f&255;a[9717672]=h&3;a[14114720]=h&-128;return}else if((d|0)==5242892){a[14112928]=f&255;a[9706117]=1;return}else if((d|0)==4194314){b[4858796]=f;return}else if((d|0)==4194304|(d|0)==4194306){b[(c[2438298]|0)+((d>>>1&1)<<1)>>1]=f;return}else if((d|0)==4194318){b[4876524]=f;return}else if((d|0)==4194308|(d|0)==4194310){b[(c[2438296]|0)+((d>>>1&1)<<1)>>1]=f;return}else{return}}function eza(a){a=a|0;var b=0;switch(a|0){case 5242882:case 5242883:case 5242884:case 5242885:{b=(e[9550304+((a-5242882|0)>>>1<<1)>>1]|0)>>>((a<<3&8^8)>>>0)&255;return b|0};case 5242886:{if((c[2406632]|0)!=0){b=(c[2432962]|0)>>>((c[(c[2420380]|0)+4>>2]|0)>>>0)<<7&255;return b|0}a=c[2443744]|0;if((a|0)<=0){b=-128;return b|0}c[2443744]=a-1;b=0;return b|0};default:{b=0;return b|0}}return 0}function ezb(a){a=a|0;var c=0;if(!((a|0)==5242882|(a|0)==5242884)){c=0;return c|0}c=b[9550304+((a-5242882|0)>>>1<<1)>>1]|0;return c|0}function ezc(a,b){a=a|0;b=b|0;return}function ezd(a){a=a|0;return 0}function eze(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=b&255;if((f|0)==1){b=c[3540984]|0;g=c[b+5876>>2]|0;if((g|0)!=0){gg[g&4095](c[b+5880>>2]|0,0)}lH(b,d[b+5885|0]|0,e&255);return}else if((f|0)==0){a[(c[3540984]|0)+5885|0]=e;return}else if((f|0)==2){Uv(0,e);return}else if((f|0)==5){f=e&15;a[9753176]=f;e=c[2385886]|0;b=c[9757320+(c[1836236]<<2)>>2]|0;g=((f&255)<<14)-32768|0;f=128;h=128;while(1){c[b+76+(h<<2)>>2]=e+(g+(h<<8));i=f+1&65535;if((i&65535)>191){j=128;k=128;break}else{f=i;h=i&65535}}while(1){h=e+(g+(k<<8))|0;c[b+76+(k+512<<2)>>2]=h;c[b+76+(k+768<<2)>>2]=h;h=j+1&65535;if((h&65535)>191){break}else{j=h;k=h&65535}}return}else{return}}function ezf(b){b=b|0;var d=0,e=0;d=b&255;if((d|0)==2){e=c[2113156]&255}else if((d|0)==3){a[9706117]=0;e=a[14112928]|0}else{e=0}return e|0}function ezg(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2541468+(b*112|0)>>2];c[a+104>>2]=c[2541472+(b*112|0)>>2];c[a+108>>2]=c[2541476+(b*112|0)>>2];d=0;return d|0}function ezh(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=2541368+(b*112|0);e=0;return e|0}function ezi(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1225800+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function ezj(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>36){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3676144+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function ezk(){return ezJ(4200)|0}function ezl(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;b=i;i=i+128|0;d=b|0;e=c[c[642608+(c[2436]<<2)>>2]>>2]|0;be(d|0,128,179600,(f=i,i=i+24|0,c[f>>2]=9374064,c[f+8>>2]=47,c[f+16>>2]=e,f)|0)|0;i=f;a[1040128]=0;f=c[2420380]|0;e=c[f>>2]|0;g=c[f+4>>2]|0;f=fw(d|0,389440)|0;if((f|0)!=0){d=g>>3<<e&1023;cj(14100392,d|0,1,f|0)|0;aY(f|0)|0}Uw(0);f=a[7452584]|0;if(f){d=0;e=f&1;while(1){f=14163936+(d<<2)|0;g=c[f>>2]|0;h=c[2113006]|0;if((h|0)==0){j=10297}else{k=h-1|0;c[2113006]=k;if((k|0)==0){j=10297}}if((j|0)==10297){j=0;c[2383474]=0}if((g|0)==0){l=e}else{gGr(g);l=a[7452584]&1}c[f>>2]=0;f=d+1|0;if((f|0)<(l|0)){d=f;e=l}else{break}}}a[7452584]=0;c[2438224]=0;c[2433522]=0;c[2406672]=0;c[3528468]=0;l=c[2406688]|0;if((l|0)!=0){gGr(l);c[2406688]=0}c[2432972]=0;if((c[2392]|0)>=0){l=0;do{e=14130368+(l<<2)|0;d=c[e>>2]|0;if((d|0)!=0){gGr(d);c[e>>2]=0}e=14130384+(l<<2)|0;d=c[e>>2]|0;if((d|0)!=0){gGr(d);c[e>>2]=0}l=l+1|0;}while((l|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;fwZ();c[2113070]=0;c[2113068]=0;l=c[2112926]|0;if((l|0)!=0){gGr(l);c[2112926]=0}l=c[2414906]|0;e=0;while(1){if((e|0)>=1024){j=10317;break}m=9638528+(e<<2)|0;if((c[m>>2]|0)==(l|0)){break}else{e=e+1|0}}if((j|0)==10317){c[2414906]=0;i=b;return 0}gGr(l);c[m>>2]=0;c[2414906]=0;i=b;return 0}function ezm(){var e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;if((a[9623808]|0)!=0){a[9623808]=0;e=c[2414608]|0;gGz(e|0,0,(c[2411566]|0)-e|0);c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060]}RI();e=c[2394]|0;f=c[14130368+(e<<2)>>2]|0;if((f|0)!=0){gGC(f|0,9104152,280)|0}c[8452240+(e<<2)>>2]=c[2113054];c[2394]=-1;e=c[2439330]|0;f=(e|0)==0;if(!f){g=e;gGC(9706056,g|0,76)|0}c[2433530]=c[2438118];g=c[3528484]|0;c[2076596]=g;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);a[9753176]=0;j=c[2385886]|0;k=128;l=128;while(1){c[e+76+(l<<2)>>2]=j+((l<<8)-32768);m=k+1&65535;if((m&65535)>191){n=128;o=128;break}else{k=m;l=m&65535}}while(1){l=j+((o<<8)-32768)|0;c[e+76+(o+512<<2)>>2]=l;c[e+76+(o+768<<2)>>2]=l;l=n+1&65535;if((l&65535)>191){break}else{n=l;o=l&65535}}if(!f){f=e;gGC(f|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=g;c[2417276]=i;c[1836236]=-1;c[2113156]=0;a[9628264]=0;c[2407033]=0;i=c[3541206]|0;c[3541190]=i;c[3541198]=i;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=i+256;c[3541199]=i+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=i+512;c[3541200]=i+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=i+768;c[3541201]=i+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;lw(c[3540984]|0);a[14112928]=0;a[14114720]=0;a[9717672]=0;a[9753176]=0;b[4876524]=0;b[4858800]=0;b[4858796]=0}b[4775154]=-1;b[4775153]=-1;b[4775152]=-1;if((c[2444204]|0)==0){i=d[9634865]<<8|d[9634864];b[4775154]=i;p=0;q=-1;r=-1;s=i}else{p=0;q=-1;r=-1;s=-1}do{q=(d[9632888+p|0]<<p^q&65535)&65535;r=(d[9630776+p|0]<<p^r&65535)&65535;s=(d[9629328+p|0]<<p^s&65535)&65535;p=p+1|0;}while((p|0)<16);b[4775152]=q;b[4775153]=r;b[4775154]=s;s=c[2392]|0;if((s|0)>=0){gGz(8452240,0,((s|0)>0?(s<<2)+4|0:4)|0)}c[2113054]=0;s=c[2385548]|0;if((s|0)>0){gGz(9752472,0,((s|0)>1?s<<2:4)|0)}c[2433530]=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];s=c[3532592]|0;if((s|0)!=0){gGC(9104152,s|0,280)|0}c[2113054]=c[2113060]}s=c[2439330]|0;if((s|0)!=0){r=s;gGC(9706056,r|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;r=0;s=0;do{q=(266666-r|0)/(64-s|0)|0;c[2113056]=q;p=RG(q)|0;c[2113054]=(c[2113054]|0)+p;c[2276108]=-1;c[2113056]=-1;r=p+r|0;UF(s*1041|0)|0;if((s&1|0)!=0){if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12}s=s+1|0;}while((s|0)<64);c[8452200+(c[2394]<<2)>>2]=8198;c[2276080]=1536;if((c[2276079]|0)>>>0<1536){RH(6)}s=c[2438224]|0;r=gGS(-747372544,31788,s,(s|0)<0|0?-1:0)|0;s=r;UF(66666)|0;r=c[2443826]|0;if((r|0)<1073676288){c[2443826]=r-s}r=c[2443827]|0;if((r|0)<1073676288){c[2443827]=r-s}r=(c[3528508]|0)-s|0;c[3528508]=(r|0)<0?0:r;r=c[2112964]|0;if((r|0)!=0){gg[c[3542112]&4095](r,a[9688]|0?534:0);Uu(0,c[2112964]|0,a[9688]|0?534:0)}r=c[1836236]|0;s=c[9757320+(r<<2)>>2]|0;if((s|0)!=0){p=s;gGC(p|0,9706056,76)|0}c[9752472+(r<<2)>>2]=c[2433530];c[14113936+(r<<2)>>2]=c[2076596];c[9669104+(r<<2)>>2]=c[3541536];c[1836236]=-1;r=c[2394]|0;p=c[14130368+(r<<2)>>2]|0;if((p|0)!=0){gGC(p|0,9104152,280)|0}c[8452240+(r<<2)>>2]=c[2113054];c[2394]=-1;if((c[2112968]|0)==0){return 0}ezn()|0;return 0}function ezn(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((a[9547232]|0)!=0){f=c[2406916]|0;g=c[3529940]|0;h=0;do{i=c[f+(h<<2)>>2]|0;c[g+(h<<2)>>2]=i>>8<<3&2016|i>>>3&31|i>>16<<8&63488;h=h+1|0;}while((h|0)<2048)}h=c[3529450]|0;g=d[9717672]|0;f=c[2438298]|0;i=(e[f>>1]|0)+98|0;j=(e[f+2>>1]|0)+8|0;if((b[4876524]&1)==0){ezS(h,g,0,i,j)}else{ezR(h,g,0,i,j)}ezT(1);j=c[3529414]|0;i=c[2438296]|0;g=(e[i>>1]|0)+96|0;h=(e[i+2>>1]|0)+8|0;if((b[4876524]&2)==0){ezS(j,0,1,g,h)}else{ezR(j,0,1,g,h)}ezT(0);if((a[14114720]|0)==0){k=c[3529940]|0;R8(k);return 0}h=ag(c[2113070]|0,c[2113068]|0)|0;g=h>>1;if((g|0)<=0){k=c[3529940]|0;R8(k);return 0}j=c[2112926]|0;i=0;do{f=j+(i<<1)|0;l=b[f>>1]|0;i=i+1|0;m=j+(h-i<<1)|0;b[f>>1]=b[m>>1]|0;b[m>>1]=l;}while((i|0)<(g|0));k=c[3529940]|0;R8(k);return 0}function ezo(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;f=i;i=i+192|0;g=f|0;h=f+16|0;j=f+32|0;k=f+48|0;l=f+64|0;m=f+80|0;n=f+96|0;o=f+112|0;p=f+128|0;q=f+144|0;r=f+160|0;s=f+176|0;if((e|0)!=0){c[e>>2]=169618}if((d&96|0)==0){i=f;return 0}gGz(s|0,0,12);t=c[2414608]|0;c[s>>2]=t;c[s+4>>2]=(c[2411566]|0)-t;c[s+12>>2]=162152;gj[c[2076592]&4095](s)|0;s=j|0;do{if((d&64|0)!=0){gGz(h|0,0,16);c[2394]=-1;if((c[2392]|0)<0){break}t=j+9|0;u=g;v=g|0;w=g+4|0;x=g+12|0;y=h|0;z=h+4|0;A=h+12|0;B=0;do{gGC(s|0,614896,11)|0;a[t]=B+48&255;C=8452256+(B<<2)|0;gGz(u|0,0,12);c[v>>2]=C;c[w>>2]=4;c[x>>2]=164976;gj[c[2076592]&4095](g)|0;if((c[C>>2]|0)!=0){c[y>>2]=c[14130368+(B<<2)>>2];c[z>>2]=c[8452184+(B<<2)>>2];c[A>>2]=s;C=c[2076592]|0;gj[C&4095](h)|0}B=B+1|0;}while((B|0)<=(c[2392]|0))}}while(0);fw$(d);Ts(d,e);UQ(d,e);Ut(0);gGz(r|0,0,12);c[r>>2]=14114720;c[r+4>>2]=1;c[r+12>>2]=142288;gj[c[2076592]&4095](r)|0;gGz(q|0,0,12);c[q>>2]=14112928;c[q+4>>2]=1;c[q+12>>2]=191240;gj[c[2076592]&4095](q)|0;gGz(p|0,0,12);c[p>>2]=9717672;c[p+4>>2]=1;c[p+12>>2]=126696;gj[c[2076592]&4095](p)|0;gGz(o|0,0,12);c[o>>2]=9753048;c[o+4>>2]=2;c[o+12>>2]=123712;gj[c[2076592]&4095](o)|0;gGz(n|0,0,12);c[n>>2]=9717600;c[n+4>>2]=2;c[n+12>>2]=119832;gj[c[2076592]&4095](n)|0;gGz(m|0,0,12);c[m>>2]=9717592;c[m+4>>2]=2;c[m+12>>2]=116960;gj[c[2076592]&4095](m)|0;gGz(l|0,0,12);c[l>>2]=9776816;c[l+4>>2]=4;c[l+12>>2]=114304;gj[c[2076592]&4095](l)|0;gGz(k|0,0,12);c[k>>2]=9753176;c[k+4>>2]=1;c[k+12>>2]=112424;gj[c[2076592]&4095](k)|0;k=c[2439330]|0;l=(k|0)==0;if(!l){m=k;gGC(9706056,m|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];m=c[3528484]|0;c[2076596]=m;n=c[2417276]|0;c[3541536]=n;c[1836236]=0;o=a[9753176]&15;a[9753176]=o;p=c[2385886]|0;q=((o&255)<<14)-32768|0;o=128;r=128;while(1){c[k+76+(r<<2)>>2]=p+(q+(r<<8));e=o+1&65535;if((e&65535)>191){D=128;E=128;break}else{o=e;r=e&65535}}while(1){r=p+(q+(E<<8))|0;c[k+76+(E+512<<2)>>2]=r;c[k+76+(E+768<<2)>>2]=r;r=D+1&65535;if((r&65535)>191){break}else{D=r;E=r&65535}}if(!l){l=k;gGC(l|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=m;c[2417276]=n;c[1836236]=-1;i=f;return 0}function ezp(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2543372+(b*112|0)>>2];c[a+104>>2]=c[2543376+(b*112|0)>>2];c[a+108>>2]=c[2543380+(b*112|0)>>2];d=0;return d|0}function ezq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=2543272+(b*112|0);e=0;return e|0}function ezr(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2778396+(b*112|0)>>2];c[a+104>>2]=c[2778400+(b*112|0)>>2];c[a+108>>2]=c[2778404+(b*112|0)>>2];d=0;return d|0}function ezs(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=2778296+(b*112|0);e=0;return e|0}function ezt(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1240064+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function ezu(){return ezJ(918)|0}function ezv(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2777276+(b*112|0)>>2];c[a+104>>2]=c[2777280+(b*112|0)>>2];c[a+108>>2]=c[2777284+(b*112|0)>>2];d=0;return d|0}function ezw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=2777176+(b*112|0);e=0;return e|0}function ezx(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2602452+(b*112|0)>>2];c[a+104>>2]=c[2602456+(b*112|0)>>2];c[a+108>>2]=c[2602460+(b*112|0)>>2];d=0;return d|0}function ezy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=2602352+(b*112|0);e=0;return e|0}function ezz(){return ezJ(3322)|0}function ezA(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2603460+(b*112|0)>>2];c[a+104>>2]=c[2603464+(b*112|0)>>2];c[a+108>>2]=c[2603468+(b*112|0)>>2];d=0;return d|0}function ezB(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=2603360+(b*112|0);e=0;return e|0}function ezC(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2178180+(b*112|0)>>2];c[a+104>>2]=c[2178184+(b*112|0)>>2];c[a+108>>2]=c[2178188+(b*112|0)>>2];d=0;return d|0}function ezD(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=2178080+(b*112|0);e=0;return e|0}function ezE(){return ezJ(2680)|0}function ezF(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2180100+(b*112|0)>>2];c[a+104>>2]=c[2180104+(b*112|0)>>2];c[a+108>>2]=c[2180108+(b*112|0)>>2];d=0;return d|0}function ezG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=218e4+(b*112|0);e=0;return e|0}function ezH(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1184264+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function ezI(){return ezJ(4030)|0}function ezJ(d){d=d|0;var e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;c[2414906]=0;c[2388102]=0;c[2385886]=524288;c[3530788]=786432;c[3530552]=9175040;c[3530406]=13369344;c[2443556]=19660800;c[2443554]=19693568;c[2443552]=19759104;c[3541206]=19783680;c[2386610]=19783680;c[3529940]=20045824;c[2414608]=20054016;c[2388232]=20054016;c[2386040]=20119552;c[2387140]=20121600;c[2386416]=20125696;c[3529450]=20127744;c[3529414]=20144128;c[2438298]=20160512;c[2438296]=20160516;c[2406916]=20160520;c[2411566]=20168712;e=0;while(1){if((e|0)>=1024){break}f=9638528+(e<<2)|0;if((c[f>>2]|0)==0){g=10511;break}else{e=e+1|0}}do{if((g|0)==10511){e=gGq(20168712)|0;c[f>>2]=e;if((e|0)==0){break}c[2414906]=e;gGz(e|0,0,20168712);c[2388102]=e;c[2385886]=e+524288;c[3530788]=e+786432;c[3530552]=e+9175040;c[3530406]=e+13369344;c[2443556]=e+19660800;c[2443554]=e+19693568;c[2443552]=e+19759104;i=e+19783680|0;c[3541206]=i;c[2386610]=i;c[3529940]=e+20045824;i=e+20054016|0;c[2414608]=i;c[2388232]=i;c[2386040]=e+20119552;c[2387140]=e+20121600;c[2386416]=e+20125696;c[3529450]=e+20127744;c[3529414]=e+20144128;c[2438298]=e+20160512;c[2438296]=e+20160516;c[2406916]=e+20160520;i=e+20168712|0;c[2411566]=i;c[2414108]=i;if((gD[d&8191]()|0)!=0){j=1;return j|0}i=c[2443556]|0;gGz(i|0,1,32768);e=c[2443554]|0;gGz(e|0,1,65536);k=c[2443552]|0;gGz(k|0,1,24576);l=c[3530788]|0;m=0;do{if((a[l+m|0]|0)!=0){a[i+(m>>8)|0]=0}m=m+1|0;}while((m|0)<8388608);m=c[3530552]|0;i=0;do{if((a[m+i|0]|0)!=0){a[e+(i>>6)|0]=0}i=i+1|0;}while((i|0)<4194304);i=c[3530406]|0;e=0;do{if((a[i+e|0]|0)!=0){a[k+(e>>8)|0]=0}e=e+1|0;}while((e|0)<6291456);fwR(0);e=c[2439330]|0;k=(e|0)==0;if(!k){i=e;gGC(9706056,i|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];i=c[3528484]|0;c[2076596]=i;m=c[2417276]|0;c[3541536]=m;c[1836236]=0;l=c[2385886]|0;n=0;o=0;while(1){c[e+76+(o<<2)>>2]=l+(o<<8);p=n+1&65535;if((p&65535)>191){q=0;r=0;break}else{n=p;o=p&65535}}while(1){o=l+(r<<8)|0;c[e+76+(r+512<<2)>>2]=o;c[e+76+(r+768<<2)>>2]=o;o=q+1&65535;if((o&65535)>191){break}else{q=o;r=o&65535}}l=c[2386040]|0;c[e+1068>>2]=l;o=l+256|0;c[e+1072>>2]=o;n=l+512|0;c[e+1076>>2]=n;p=l+768|0;c[e+1080>>2]=p;s=l+1024|0;c[e+1084>>2]=s;t=l+1280|0;c[e+1088>>2]=t;u=l+1536|0;c[e+1092>>2]=u;v=l+1792|0;c[e+1096>>2]=v;c[e+2092>>2]=l;c[e+2096>>2]=o;c[e+2100>>2]=n;c[e+2104>>2]=p;c[e+2108>>2]=s;c[e+2112>>2]=t;c[e+2116>>2]=u;c[e+2120>>2]=v;c[e+3116>>2]=l;c[e+4140>>2]=l;c[e+3120>>2]=o;c[e+4144>>2]=o;c[e+3124>>2]=n;c[e+4148>>2]=n;c[e+3128>>2]=p;c[e+4152>>2]=p;c[e+3132>>2]=s;c[e+4156>>2]=s;c[e+3136>>2]=t;c[e+4160>>2]=t;c[e+3140>>2]=u;c[e+4164>>2]=u;c[e+3144>>2]=v;c[e+4168>>2]=v;c[e+4184>>2]=830;c[e+4180>>2]=532;c[e+4172>>2]=2892;c[e+4176>>2]=2816;if(!k){v=e;gGC(v|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=i;c[2417276]=m;c[1836236]=-1;UL(4e6,0,3610,0);c[2438224]=4e6;c[2433522]=3416;c[2406672]=1752;c[3528468]=9362;c[2443842]=511;h[745398]=.3;a[3203264]=1;Ux(0,8e3,1);c[2407030]=154;c[2407068]=3;Tq(689816);v=c[642608+(c[2436]<<2)>>2]|0;u=c[v+128>>2]|0;if((c[v+52>>2]&4|0)==0){c[2113068]=u;t=c[v+132>>2]|0;c[2113070]=t;c[2443814]=u;c[2440436]=t;w=u;x=t}else{c[2113070]=u;t=c[v+132>>2]|0;c[2113068]=t;c[2440436]=u;c[2443814]=t;w=t;x=u}u=ag(w<<1,x)|0;t=gGq(u)|0;c[2112926]=t;if((t|0)!=0){gGz(t|0,0,u|0)}a[9623808]=0;u=c[2414608]|0;gGz(u|0,0,(c[2411566]|0)-u|0);c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];u=c[3532592]|0;if((u|0)!=0){gGC(9104152,u|0,280)|0}c[2113054]=c[2113060]}RI();u=c[2394]|0;t=c[14130368+(u<<2)>>2]|0;if((t|0)!=0){gGC(t|0,9104152,280)|0}c[8452240+(u<<2)>>2]=c[2113054];c[2394]=-1;u=c[2439330]|0;t=(u|0)==0;if(!t){v=u;gGC(9706056,v|0,76)|0}c[2433530]=c[2438118];v=c[3528484]|0;c[2076596]=v;s=c[2417276]|0;c[3541536]=s;c[1836236]=0;gGz(9706056,0,76);a[9753176]=0;p=c[2385886]|0;n=128;o=128;while(1){c[u+76+(o<<2)>>2]=p+((o<<8)-32768);l=n+1&65535;if((l&65535)>191){y=128;z=128;break}else{n=l;o=l&65535}}while(1){o=p+((z<<8)-32768)|0;c[u+76+(z+512<<2)>>2]=o;c[u+76+(z+768<<2)>>2]=o;o=y+1&65535;if((o&65535)>191){break}else{y=o;z=o&65535}}if(!t){p=u;gGC(p|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=v;c[2417276]=s;c[1836236]=-1;c[2113156]=0;a[9628264]=0;c[2407033]=0;p=c[3541206]|0;c[3541190]=p;c[3541198]=p;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=p+256;c[3541199]=p+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=p+512;c[3541200]=p+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=p+768;c[3541201]=p+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;lw(c[3540984]|0);a[14112928]=0;a[14114720]=0;a[9717672]=0;a[9753176]=0;b[4876524]=0;b[4858800]=0;b[4858796]=0;j=0;return j|0}}while(0);c[2414906]=0;j=1;return j|0}function ezK(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;a=i;i=i+360|0;b=a|0;d=a+112|0;e=a+120|0;f=a+232|0;g=a+240|0;h=a+352|0;c[2444204]=5;if((R6((c[2388102]|0)+1|0,0,2)|0)!=0){j=1;i=a;return j|0}if((R6(c[2388102]|0,1,2)|0)!=0){j=1;i=a;return j|0}k=c[2385886]|0;if((c[3542200]|0)==0){j=1;i=a;return j|0}l=g+108|0;c[l>>2]=0;m=g+100|0;c[m>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,2)|0;do{if((c[l>>2]|0)!=0){g=c[m>>2]|0;c[h>>2]=9534384;n=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[n&16383](h,2,0)|0;if((g|0)<1){j=1;i=a;return j|0}if((gzL(k,0,2)|0)==0){break}else{j=1}i=a;return j|0}}while(0);k=e+108|0;h=e+100|0;m=0;while(1){l=(c[3530788]|0)+(m<<19)|0;g=m+3|0;if((c[3542200]|0)==0){j=1;o=10591;break}c[k>>2]=0;c[h>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,g)|0;if((c[k>>2]|0)!=0){n=c[h>>2]|0;c[f>>2]=9534384;p=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[p&16383](f,g,0)|0;if((n|0)<1){j=1;o=10592;break}if((gzL(l,0,g)|0)!=0){j=1;o=10593;break}}g=m+1|0;if((g|0)<5){m=g}else{o=10568;break}}if((o|0)==10591){i=a;return j|0}else if((o|0)==10568){if((R6(c[3530552]|0,8,2)|0)!=0){j=1;i=a;return j|0}if((R6((c[3530552]|0)+1|0,9,2)|0)!=0){j=1;i=a;return j|0}m=c[2386610]|0;if((c[3542200]|0)==0){j=1;i=a;return j|0}f=b+108|0;c[f>>2]=0;h=b+100|0;c[h>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](b,10)|0;do{if((c[f>>2]|0)!=0){b=c[h>>2]|0;c[d>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](d,10,0)|0;if((b|0)<1){j=1;i=a;return j|0}if((gzL(m,0,10)|0)==0){break}else{j=1}i=a;return j|0}}while(0);ezL();fxU(0,425984);if((c[2394]|0)==0){q=c[2112932]|0}else{c[2394]=0;m=c[3532596]|0;c[2112932]=m;d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];q=m}m=c[2388102]|0;d=q|0;h=0;while(1){f=m+h|0;c[d>>2]=f;c[d+131072>>2]=f;f=h+1024|0;if(f>>>0>524287){break}else{d=d+4|0;h=f}}h=c[2388232]|0;d=q+4096|0;m=1048576;while(1){f=h+(m-1048576)|0;c[d>>2]=f;c[d+65536>>2]=f;c[d+131072>>2]=f;f=m+1024|0;if(f>>>0>1114111){break}else{d=d+4|0;m=f}}m=c[2387140]|0;c[q+32768>>2]=m;c[q+163840>>2]=m;d=m+1024|0;c[q+32772>>2]=d;c[q+163844>>2]=d;d=c[2386416]|0;c[q+36864>>2]=d;c[q+102400>>2]=d;c[q+167936>>2]=d;m=d+1024|0;c[q+36868>>2]=m;c[q+102404>>2]=m;c[q+167940>>2]=m;c[q+36872>>2]=d;c[q+102408>>2]=d;c[q+167944>>2]=d;c[q+36876>>2]=m;c[q+102412>>2]=m;c[q+167948>>2]=m;m=c[3529450]|0;c[q+40960>>2]=m;c[q+106496>>2]=m;c[q+172032>>2]=m;d=m+1024|0;c[q+40964>>2]=d;c[q+106500>>2]=d;c[q+172036>>2]=d;d=m+2048|0;c[q+40968>>2]=d;c[q+106504>>2]=d;c[q+172040>>2]=d;d=m+3072|0;c[q+40972>>2]=d;c[q+106508>>2]=d;c[q+172044>>2]=d;d=m+4096|0;c[q+40976>>2]=d;c[q+106512>>2]=d;c[q+172048>>2]=d;d=m+5120|0;c[q+40980>>2]=d;c[q+106516>>2]=d;c[q+172052>>2]=d;d=m+6144|0;c[q+40984>>2]=d;c[q+106520>>2]=d;c[q+172056>>2]=d;d=m+7168|0;c[q+40988>>2]=d;c[q+106524>>2]=d;c[q+172060>>2]=d;d=m+8192|0;c[q+40992>>2]=d;c[q+106528>>2]=d;c[q+172064>>2]=d;d=m+9216|0;c[q+40996>>2]=d;c[q+106532>>2]=d;c[q+172068>>2]=d;d=m+10240|0;c[q+41e3>>2]=d;c[q+106536>>2]=d;c[q+172072>>2]=d;d=m+11264|0;c[q+41004>>2]=d;c[q+106540>>2]=d;c[q+172076>>2]=d;d=m+12288|0;c[q+41008>>2]=d;c[q+106544>>2]=d;c[q+172080>>2]=d;d=m+13312|0;c[q+41012>>2]=d;c[q+106548>>2]=d;c[q+172084>>2]=d;d=m+14336|0;c[q+41016>>2]=d;c[q+106552>>2]=d;c[q+172088>>2]=d;d=m+15360|0;c[q+41020>>2]=d;c[q+106556>>2]=d;c[q+172092>>2]=d;d=c[3529414]|0;c[q+41472>>2]=d;c[q+107008>>2]=d;c[q+172544>>2]=d;m=d+1024|0;c[q+41476>>2]=m;c[q+107012>>2]=m;c[q+172548>>2]=m;h=d+2048|0;c[q+41480>>2]=h;c[q+107016>>2]=h;c[q+172552>>2]=h;f=d+3072|0;c[q+41484>>2]=f;c[q+107020>>2]=f;c[q+172556>>2]=f;b=d+4096|0;c[q+41488>>2]=b;c[q+107024>>2]=b;c[q+172560>>2]=b;k=d+5120|0;c[q+41492>>2]=k;c[q+107028>>2]=k;c[q+172564>>2]=k;e=d+6144|0;c[q+41496>>2]=e;c[q+107032>>2]=e;c[q+172568>>2]=e;g=d+7168|0;c[q+41500>>2]=g;c[q+107036>>2]=g;c[q+172572>>2]=g;l=d+8192|0;c[q+41504>>2]=l;c[q+107040>>2]=l;c[q+172576>>2]=l;n=d+9216|0;c[q+41508>>2]=n;c[q+107044>>2]=n;c[q+172580>>2]=n;p=d+10240|0;c[q+41512>>2]=p;c[q+107048>>2]=p;c[q+172584>>2]=p;r=d+11264|0;c[q+41516>>2]=r;c[q+107052>>2]=r;c[q+172588>>2]=r;s=d+12288|0;c[q+41520>>2]=s;c[q+107056>>2]=s;c[q+172592>>2]=s;t=d+13312|0;c[q+41524>>2]=t;c[q+107060>>2]=t;c[q+172596>>2]=t;u=d+14336|0;c[q+41528>>2]=u;c[q+107064>>2]=u;c[q+172600>>2]=u;v=d+15360|0;c[q+41532>>2]=v;c[q+107068>>2]=v;c[q+172604>>2]=v;c[q+41536>>2]=d;c[q+107072>>2]=d;c[q+172608>>2]=d;c[q+41540>>2]=m;c[q+107076>>2]=m;c[q+172612>>2]=m;c[q+41544>>2]=h;c[q+107080>>2]=h;c[q+172616>>2]=h;c[q+41548>>2]=f;c[q+107084>>2]=f;c[q+172620>>2]=f;c[q+41552>>2]=b;c[q+107088>>2]=b;c[q+172624>>2]=b;c[q+41556>>2]=k;c[q+107092>>2]=k;c[q+172628>>2]=k;c[q+41560>>2]=e;c[q+107096>>2]=e;c[q+172632>>2]=e;c[q+41564>>2]=g;c[q+107100>>2]=g;c[q+172636>>2]=g;c[q+41568>>2]=l;c[q+107104>>2]=l;c[q+172640>>2]=l;c[q+41572>>2]=n;c[q+107108>>2]=n;c[q+172644>>2]=n;c[q+41576>>2]=p;c[q+107112>>2]=p;c[q+172648>>2]=p;c[q+41580>>2]=r;c[q+107116>>2]=r;c[q+172652>>2]=r;c[q+41584>>2]=s;c[q+107120>>2]=s;c[q+172656>>2]=s;c[q+41588>>2]=t;c[q+107124>>2]=t;c[q+172660>>2]=t;c[q+41592>>2]=u;c[q+107128>>2]=u;c[q+172664>>2]=u;c[q+41596>>2]=v;c[q+107132>>2]=v;c[q+172668>>2]=v;c[q+196648>>2]=1712;c[q+196728>>2]=66;c[q+196608>>2]=3316;c[q+196688>>2]=3324;q=c[3532592]|0;if((q|0)!=0){gGC(q|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;j=0;i=a;return j|0}else if((o|0)==10592){i=a;return j|0}else if((o|0)==10593){i=a;return j|0}return 0}function ezL(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=0;while(1){if((b|0)>=1024){e=10639;break}f=9638528+(b<<2)|0;if((c[f>>2]|0)==0){break}else{b=b+1|0}}if((e|0)==10639){return}b=gGq(6291456)|0;c[f>>2]=b;if((b|0)==0){return}gGz(b|0,0,6291456);f=c[3530788]|0;gGC(b|0,f|0,2621440)|0;g=0;do{h=g<<8;gGz(f+h|0,0,256);i=0;do{j=1<<4-i;k=(c[598144+(i<<2)>>2]|0)+h|0;l=0;do{m=k+(c[609008+(l<<2)>>2]|0)|0;n=(l<<4)+h|0;o=0;do{p=m+(c[610384+(o<<2)>>2]|0)|0;if(((d[b+((p|0)/8|0)|0]|0)&128>>>((p&7)>>>0)|0)!=0){p=f+(n+o)|0;a[p]=(d[p]|0|j)&255}o=o+1|0;}while((o|0)<16);l=l+1|0;}while((l|0)<16);i=i+1|0;}while((i|0)<5);g=g+1|0;}while((g|0)<16384);g=c[3530552]|0;gGC(b|0,g|0,4194304)|0;f=0;do{i=f<<6;gGz(g+i|0,0,64);h=f<<9;l=0;do{j=1<<7-l;k=(c[614800+(l<<2)>>2]|0)+h|0;o=0;do{n=k+(c[1942600+(o<<2)>>2]|0)|0;m=(o<<3)+i|0;p=0;do{q=n+(c[598320+(p<<2)>>2]|0)|0;if(((d[b+((q|0)/8|0)|0]|0)&128>>>((q&7)>>>0)|0)!=0){q=g+(m+p)|0;a[q]=(d[q]|0|j)&255}p=p+1|0;}while((p|0)<8);o=o+1|0;}while((o|0)<8);l=l+1|0;}while((l|0)<8);f=f+1|0;}while((f|0)<65536);f=c[3530406]|0;g=0;while(1){l=g<<8;gGz(f+l|0,0,256);i=g<<11;h=0;do{o=1<<7-h;j=(c[614800+(h<<2)>>2]|0)+i|0;k=0;do{p=j+(c[1942600+(k<<2)>>2]|0)|0;m=(k<<4)+l|0;n=0;do{q=p+(c[598320+(n<<2)>>2]|0)|0;if(((d[b+((q|0)/8|0)|0]|0)&128>>>((q&7)>>>0)|0)!=0){q=f+(m+n)|0;a[q]=(d[q]|0|o)&255}n=n+1|0;}while((n|0)<16);k=k+1|0;}while((k|0)<16);h=h+1|0;}while((h|0)<8);h=g+1|0;if((h|0)<16384){g=h}else{r=0;break}}while(1){if((r|0)>=1024){e=10641;break}s=9638528+(r<<2)|0;if((c[s>>2]|0)==(b|0)){break}else{r=r+1|0}}if((e|0)==10641){return}gGr(b);c[s>>2]=0;return}function ezM(a){a=a|0;var b=0,d=0;b=(c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,4e6,0)|0;return a|0}function ezN(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;a=i;i=i+360|0;b=a|0;d=a+112|0;e=a+120|0;f=a+232|0;g=a+240|0;h=a+352|0;c[2444204]=4;if((R6((c[2388102]|0)+1|0,0,2)|0)!=0){j=1;i=a;return j|0}if((R6(c[2388102]|0,1,2)|0)!=0){j=1;i=a;return j|0}k=c[2385886]|0;if((c[3542200]|0)==0){j=1;i=a;return j|0}l=g+108|0;c[l>>2]=0;m=g+100|0;c[m>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,2)|0;do{if((c[l>>2]|0)!=0){g=c[m>>2]|0;c[h>>2]=9534384;n=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[n&16383](h,2,0)|0;if((g|0)<1){j=1;i=a;return j|0}if((gzL(k,0,2)|0)==0){break}else{j=1}i=a;return j|0}}while(0);k=e+108|0;h=e+100|0;m=0;while(1){l=(c[3530788]|0)+(m<<19)|0;g=m+3|0;if((c[3542200]|0)==0){j=1;o=10679;break}c[k>>2]=0;c[h>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,g)|0;if((c[k>>2]|0)!=0){n=c[h>>2]|0;c[f>>2]=9534384;p=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[p&16383](f,g,0)|0;if((n|0)<1){j=1;o=10678;break}if((gzL(l,0,g)|0)!=0){j=1;o=10683;break}}g=m+1|0;if((g|0)<5){m=g}else{o=10656;break}}if((o|0)==10678){i=a;return j|0}else if((o|0)==10679){i=a;return j|0}else if((o|0)==10656){if((R6(c[3530552]|0,8,2)|0)!=0){j=1;i=a;return j|0}if((R6((c[3530552]|0)+1|0,9,2)|0)!=0){j=1;i=a;return j|0}m=c[2386610]|0;if((c[3542200]|0)==0){j=1;i=a;return j|0}f=b+108|0;c[f>>2]=0;h=b+100|0;c[h>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](b,10)|0;do{if((c[f>>2]|0)!=0){b=c[h>>2]|0;c[d>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](d,10,0)|0;if((b|0)<1){j=1;i=a;return j|0}if((gzL(m,0,10)|0)==0){break}else{j=1}i=a;return j|0}}while(0);ezL();fxU(0,425984);if((c[2394]|0)==0){q=c[2112932]|0}else{c[2394]=0;m=c[3532596]|0;c[2112932]=m;d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];q=m}m=c[2388102]|0;d=q|0;h=0;while(1){f=m+h|0;c[d>>2]=f;c[d+131072>>2]=f;f=h+1024|0;if(f>>>0>524287){break}else{d=d+4|0;h=f}}h=c[2387140]|0;c[q+4096>>2]=h;c[q+135168>>2]=h;d=h+1024|0;c[q+4100>>2]=d;c[q+135172>>2]=d;d=h+2048|0;c[q+4104>>2]=d;c[q+135176>>2]=d;d=h+3072|0;c[q+4108>>2]=d;c[q+135180>>2]=d;d=c[2386416]|0;c[q+8192>>2]=d;c[q+73728>>2]=d;c[q+139264>>2]=d;h=d+1024|0;c[q+8196>>2]=h;c[q+73732>>2]=h;c[q+139268>>2]=h;c[q+8200>>2]=d;c[q+73736>>2]=d;c[q+139272>>2]=d;c[q+8204>>2]=h;c[q+73740>>2]=h;c[q+139276>>2]=h;h=c[3529450]|0;c[q+12288>>2]=h;c[q+77824>>2]=h;c[q+143360>>2]=h;d=h+1024|0;c[q+12292>>2]=d;c[q+77828>>2]=d;c[q+143364>>2]=d;d=h+2048|0;c[q+12296>>2]=d;c[q+77832>>2]=d;c[q+143368>>2]=d;d=h+3072|0;c[q+12300>>2]=d;c[q+77836>>2]=d;c[q+143372>>2]=d;d=h+4096|0;c[q+12304>>2]=d;c[q+77840>>2]=d;c[q+143376>>2]=d;d=h+5120|0;c[q+12308>>2]=d;c[q+77844>>2]=d;c[q+143380>>2]=d;d=h+6144|0;c[q+12312>>2]=d;c[q+77848>>2]=d;c[q+143384>>2]=d;d=h+7168|0;c[q+12316>>2]=d;c[q+77852>>2]=d;c[q+143388>>2]=d;d=h+8192|0;c[q+12320>>2]=d;c[q+77856>>2]=d;c[q+143392>>2]=d;d=h+9216|0;c[q+12324>>2]=d;c[q+77860>>2]=d;c[q+143396>>2]=d;d=h+10240|0;c[q+12328>>2]=d;c[q+77864>>2]=d;c[q+143400>>2]=d;d=h+11264|0;c[q+12332>>2]=d;c[q+77868>>2]=d;c[q+143404>>2]=d;d=h+12288|0;c[q+12336>>2]=d;c[q+77872>>2]=d;c[q+143408>>2]=d;d=h+13312|0;c[q+12340>>2]=d;c[q+77876>>2]=d;c[q+143412>>2]=d;d=h+14336|0;c[q+12344>>2]=d;c[q+77880>>2]=d;c[q+143416>>2]=d;d=h+15360|0;c[q+12348>>2]=d;c[q+77884>>2]=d;c[q+143420>>2]=d;d=c[3529414]|0;c[q+12800>>2]=d;c[q+78336>>2]=d;c[q+143872>>2]=d;h=d+1024|0;c[q+12804>>2]=h;c[q+78340>>2]=h;c[q+143876>>2]=h;m=d+2048|0;c[q+12808>>2]=m;c[q+78344>>2]=m;c[q+143880>>2]=m;f=d+3072|0;c[q+12812>>2]=f;c[q+78348>>2]=f;c[q+143884>>2]=f;b=d+4096|0;c[q+12816>>2]=b;c[q+78352>>2]=b;c[q+143888>>2]=b;k=d+5120|0;c[q+12820>>2]=k;c[q+78356>>2]=k;c[q+143892>>2]=k;e=d+6144|0;c[q+12824>>2]=e;c[q+78360>>2]=e;c[q+143896>>2]=e;g=d+7168|0;c[q+12828>>2]=g;c[q+78364>>2]=g;c[q+143900>>2]=g;l=d+8192|0;c[q+12832>>2]=l;c[q+78368>>2]=l;c[q+143904>>2]=l;n=d+9216|0;c[q+12836>>2]=n;c[q+78372>>2]=n;c[q+143908>>2]=n;p=d+10240|0;c[q+12840>>2]=p;c[q+78376>>2]=p;c[q+143912>>2]=p;r=d+11264|0;c[q+12844>>2]=r;c[q+78380>>2]=r;c[q+143916>>2]=r;s=d+12288|0;c[q+12848>>2]=s;c[q+78384>>2]=s;c[q+143920>>2]=s;t=d+13312|0;c[q+12852>>2]=t;c[q+78388>>2]=t;c[q+143924>>2]=t;u=d+14336|0;c[q+12856>>2]=u;c[q+78392>>2]=u;c[q+143928>>2]=u;v=d+15360|0;c[q+12860>>2]=v;c[q+78396>>2]=v;c[q+143932>>2]=v;c[q+12864>>2]=d;c[q+78400>>2]=d;c[q+143936>>2]=d;c[q+12868>>2]=h;c[q+78404>>2]=h;c[q+143940>>2]=h;c[q+12872>>2]=m;c[q+78408>>2]=m;c[q+143944>>2]=m;c[q+12876>>2]=f;c[q+78412>>2]=f;c[q+143948>>2]=f;c[q+12880>>2]=b;c[q+78416>>2]=b;c[q+143952>>2]=b;c[q+12884>>2]=k;c[q+78420>>2]=k;c[q+143956>>2]=k;c[q+12888>>2]=e;c[q+78424>>2]=e;c[q+143960>>2]=e;c[q+12892>>2]=g;c[q+78428>>2]=g;c[q+143964>>2]=g;c[q+12896>>2]=l;c[q+78432>>2]=l;c[q+143968>>2]=l;c[q+12900>>2]=n;c[q+78436>>2]=n;c[q+143972>>2]=n;c[q+12904>>2]=p;c[q+78440>>2]=p;c[q+143976>>2]=p;c[q+12908>>2]=r;c[q+78444>>2]=r;c[q+143980>>2]=r;c[q+12912>>2]=s;c[q+78448>>2]=s;c[q+143984>>2]=s;c[q+12916>>2]=t;c[q+78452>>2]=t;c[q+143988>>2]=t;c[q+12920>>2]=u;c[q+78456>>2]=u;c[q+143992>>2]=u;c[q+12924>>2]=v;c[q+78460>>2]=v;c[q+143996>>2]=v;v=c[2388232]|0;u=q+28672|0;t=7340032;while(1){s=v+(t-7340032)|0;c[u>>2]=s;c[u+65536>>2]=s;c[u+131072>>2]=s;s=t+1024|0;if(s>>>0>7405567){break}else{u=u+4|0;t=s}}c[q+196648>>2]=196;c[q+196728>>2]=3074;c[q+196608>>2]=2622;c[q+196688>>2]=3092;q=c[3532592]|0;if((q|0)!=0){gGC(q|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;j=0;i=a;return j|0}else if((o|0)==10683){i=a;return j|0}return 0}function ezO(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;a=i;i=i+480|0;b=a|0;d=a+112|0;e=a+120|0;f=a+232|0;g=a+240|0;h=a+352|0;j=a+360|0;k=a+472|0;c[2444204]=3;if((R6((c[2388102]|0)+1|0,0,2)|0)!=0){l=1;i=a;return l|0}if((R6(c[2388102]|0,1,2)|0)!=0){l=1;i=a;return l|0}m=c[2385886]|0;if((c[3542200]|0)==0){l=1;i=a;return l|0}n=j+108|0;c[n>>2]=0;o=j+100|0;c[o>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,2)|0;do{if((c[n>>2]|0)!=0){j=c[o>>2]|0;c[k>>2]=9534384;p=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[p&16383](k,2,0)|0;if((j|0)<1){l=1;i=a;return l|0}if((gzL(m,0,2)|0)==0){break}else{l=1}i=a;return l|0}}while(0);m=c[3530788]|0;if((c[3542200]|0)==0){l=1;i=a;return l|0}k=g+108|0;c[k>>2]=0;o=g+100|0;c[o>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,3)|0;do{if((c[k>>2]|0)!=0){g=c[o>>2]|0;c[h>>2]=9534384;n=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[n&16383](h,3,0)|0;if((g|0)<1){l=1;i=a;return l|0}if((gzL(m,0,3)|0)==0){break}else{l=1}i=a;return l|0}}while(0);m=(c[3530788]|0)+2097152|0;if((c[3542200]|0)==0){l=1;i=a;return l|0}h=e+108|0;c[h>>2]=0;o=e+100|0;c[o>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,4)|0;do{if((c[h>>2]|0)!=0){e=c[o>>2]|0;c[f>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](f,4,0)|0;if((e|0)<1){l=1;i=a;return l|0}if((gzL(m,0,4)|0)==0){break}else{l=1}i=a;return l|0}}while(0);if((R6((c[3530788]|0)+4194304|0,5,2)|0)!=0){l=1;i=a;return l|0}if((R6(c[3530552]|0,6,2)|0)!=0){l=1;i=a;return l|0}if((R6((c[3530552]|0)+1|0,7,2)|0)!=0){l=1;i=a;return l|0}m=c[2386610]|0;if((c[3542200]|0)==0){l=1;i=a;return l|0}f=b+108|0;c[f>>2]=0;o=b+100|0;c[o>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](b,8)|0;do{if((c[f>>2]|0)!=0){b=c[o>>2]|0;c[d>>2]=9534384;h=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[h&16383](d,8,0)|0;if((b|0)<1){l=1;i=a;return l|0}if((gzL(m,0,8)|0)==0){break}else{l=1}i=a;return l|0}}while(0);ezP();fxU(0,425984);if((c[2394]|0)==0){q=c[2112932]|0}else{c[2394]=0;m=c[3532596]|0;c[2112932]=m;d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];q=m}m=c[2388102]|0;d=q|0;o=0;while(1){f=m+o|0;c[d>>2]=f;c[d+131072>>2]=f;f=o+1024|0;if(f>>>0>524287){break}else{d=d+4|0;o=f}}o=c[2388232]|0;d=q+8192|0;m=2097152;while(1){f=o+(m-2097152)|0;c[d>>2]=f;c[d+65536>>2]=f;c[d+131072>>2]=f;f=m+1024|0;if(f>>>0>2162687){break}else{d=d+4|0;m=f}}m=c[3529450]|0;c[q+12288>>2]=m;c[q+77824>>2]=m;c[q+143360>>2]=m;d=m+1024|0;c[q+12292>>2]=d;c[q+77828>>2]=d;c[q+143364>>2]=d;d=m+2048|0;c[q+12296>>2]=d;c[q+77832>>2]=d;c[q+143368>>2]=d;d=m+3072|0;c[q+12300>>2]=d;c[q+77836>>2]=d;c[q+143372>>2]=d;d=m+4096|0;c[q+12304>>2]=d;c[q+77840>>2]=d;c[q+143376>>2]=d;d=m+5120|0;c[q+12308>>2]=d;c[q+77844>>2]=d;c[q+143380>>2]=d;d=m+6144|0;c[q+12312>>2]=d;c[q+77848>>2]=d;c[q+143384>>2]=d;d=m+7168|0;c[q+12316>>2]=d;c[q+77852>>2]=d;c[q+143388>>2]=d;d=m+8192|0;c[q+12320>>2]=d;c[q+77856>>2]=d;c[q+143392>>2]=d;d=m+9216|0;c[q+12324>>2]=d;c[q+77860>>2]=d;c[q+143396>>2]=d;d=m+10240|0;c[q+12328>>2]=d;c[q+77864>>2]=d;c[q+143400>>2]=d;d=m+11264|0;c[q+12332>>2]=d;c[q+77868>>2]=d;c[q+143404>>2]=d;d=m+12288|0;c[q+12336>>2]=d;c[q+77872>>2]=d;c[q+143408>>2]=d;d=m+13312|0;c[q+12340>>2]=d;c[q+77876>>2]=d;c[q+143412>>2]=d;d=m+14336|0;c[q+12344>>2]=d;c[q+77880>>2]=d;c[q+143416>>2]=d;d=m+15360|0;c[q+12348>>2]=d;c[q+77884>>2]=d;c[q+143420>>2]=d;d=c[3529414]|0;c[q+12800>>2]=d;c[q+78336>>2]=d;c[q+143872>>2]=d;m=d+1024|0;c[q+12804>>2]=m;c[q+78340>>2]=m;c[q+143876>>2]=m;o=d+2048|0;c[q+12808>>2]=o;c[q+78344>>2]=o;c[q+143880>>2]=o;f=d+3072|0;c[q+12812>>2]=f;c[q+78348>>2]=f;c[q+143884>>2]=f;b=d+4096|0;c[q+12816>>2]=b;c[q+78352>>2]=b;c[q+143888>>2]=b;h=d+5120|0;c[q+12820>>2]=h;c[q+78356>>2]=h;c[q+143892>>2]=h;e=d+6144|0;c[q+12824>>2]=e;c[q+78360>>2]=e;c[q+143896>>2]=e;k=d+7168|0;c[q+12828>>2]=k;c[q+78364>>2]=k;c[q+143900>>2]=k;g=d+8192|0;c[q+12832>>2]=g;c[q+78368>>2]=g;c[q+143904>>2]=g;n=d+9216|0;c[q+12836>>2]=n;c[q+78372>>2]=n;c[q+143908>>2]=n;j=d+10240|0;c[q+12840>>2]=j;c[q+78376>>2]=j;c[q+143912>>2]=j;p=d+11264|0;c[q+12844>>2]=p;c[q+78380>>2]=p;c[q+143916>>2]=p;r=d+12288|0;c[q+12848>>2]=r;c[q+78384>>2]=r;c[q+143920>>2]=r;s=d+13312|0;c[q+12852>>2]=s;c[q+78388>>2]=s;c[q+143924>>2]=s;t=d+14336|0;c[q+12856>>2]=t;c[q+78392>>2]=t;c[q+143928>>2]=t;u=d+15360|0;c[q+12860>>2]=u;c[q+78396>>2]=u;c[q+143932>>2]=u;c[q+12864>>2]=d;c[q+78400>>2]=d;c[q+143936>>2]=d;c[q+12868>>2]=m;c[q+78404>>2]=m;c[q+143940>>2]=m;c[q+12872>>2]=o;c[q+78408>>2]=o;c[q+143944>>2]=o;c[q+12876>>2]=f;c[q+78412>>2]=f;c[q+143948>>2]=f;c[q+12880>>2]=b;c[q+78416>>2]=b;c[q+143952>>2]=b;c[q+12884>>2]=h;c[q+78420>>2]=h;c[q+143956>>2]=h;c[q+12888>>2]=e;c[q+78424>>2]=e;c[q+143960>>2]=e;c[q+12892>>2]=k;c[q+78428>>2]=k;c[q+143964>>2]=k;c[q+12896>>2]=g;c[q+78432>>2]=g;c[q+143968>>2]=g;c[q+12900>>2]=n;c[q+78436>>2]=n;c[q+143972>>2]=n;c[q+12904>>2]=j;c[q+78440>>2]=j;c[q+143976>>2]=j;c[q+12908>>2]=p;c[q+78444>>2]=p;c[q+143980>>2]=p;c[q+12912>>2]=r;c[q+78448>>2]=r;c[q+143984>>2]=r;c[q+12916>>2]=s;c[q+78452>>2]=s;c[q+143988>>2]=s;c[q+12920>>2]=t;c[q+78456>>2]=t;c[q+143992>>2]=t;c[q+12924>>2]=u;c[q+78460>>2]=u;c[q+143996>>2]=u;u=c[2387140]|0;c[q+16384>>2]=u;c[q+147456>>2]=u;t=u+1024|0;c[q+16388>>2]=t;c[q+147460>>2]=t;t=u+2048|0;c[q+16392>>2]=t;c[q+147464>>2]=t;t=u+3072|0;c[q+16396>>2]=t;c[q+147468>>2]=t;t=c[2386416]|0;c[q+24576>>2]=t;c[q+90112>>2]=t;c[q+155648>>2]=t;u=t+1024|0;c[q+24580>>2]=u;c[q+90116>>2]=u;c[q+155652>>2]=u;c[q+196648>>2]=2744;c[q+196728>>2]=3328;c[q+196608>>2]=2150;c[q+196688>>2]=3240;q=c[3532592]|0;if((q|0)!=0){gGC(q|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;l=0;i=a;return l|0}function ezP(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=0;while(1){if((b|0)>=1024){e=10779;break}f=9638528+(b<<2)|0;if((c[f>>2]|0)==0){break}else{b=b+1|0}}if((e|0)==10779){return}b=gGq(6291456)|0;c[f>>2]=b;if((b|0)==0){return}gGz(b|0,0,6291456);f=c[3530788]|0;gGC(b|0,f|0,5242880)|0;g=0;do{h=g<<8;gGz(f+h|0,0,256);i=g<<9;j=0;do{k=1<<4-j;l=(c[598296+(j<<2)>>2]|0)+i|0;m=0;do{n=l+(c[608544+(m<<2)>>2]|0)|0;o=(m<<4)+h|0;p=0;do{q=n+(c[598384+(p<<2)>>2]|0)|0;if(((d[b+((q|0)/8|0)|0]|0)&128>>>((q&7)>>>0)|0)!=0){q=f+(o+p)|0;a[q]=(d[q]|0|k)&255}p=p+1|0;}while((p|0)<16);m=m+1|0;}while((m|0)<16);j=j+1|0;}while((j|0)<5);g=g+1|0;}while((g|0)<32768);g=c[3530552]|0;gGC(b|0,g|0,4194304)|0;f=0;do{j=f<<6;gGz(g+j|0,0,64);h=f<<9;i=0;do{m=1<<7-i;k=(c[614800+(i<<2)>>2]|0)+h|0;l=0;do{p=k+(c[1942600+(l<<2)>>2]|0)|0;o=(l<<3)+j|0;n=0;do{q=p+(c[598320+(n<<2)>>2]|0)|0;if(((d[b+((q|0)/8|0)|0]|0)&128>>>((q&7)>>>0)|0)!=0){q=g+(o+n)|0;a[q]=(d[q]|0|m)&255}n=n+1|0;}while((n|0)<8);l=l+1|0;}while((l|0)<8);i=i+1|0;}while((i|0)<8);f=f+1|0;}while((f|0)<65536);f=c[3530406]|0;g=0;while(1){i=g<<8;gGz(f+i|0,0,256);j=g<<11;h=0;do{l=1<<7-h;m=(c[614800+(h<<2)>>2]|0)+j|0;k=0;do{n=m+(c[1942600+(k<<2)>>2]|0)|0;o=(k<<4)+i|0;p=0;do{q=n+(c[598320+(p<<2)>>2]|0)|0;if(((d[b+((q|0)/8|0)|0]|0)&128>>>((q&7)>>>0)|0)!=0){q=f+(o+p)|0;a[q]=(d[q]|0|l)&255}p=p+1|0;}while((p|0)<16);k=k+1|0;}while((k|0)<16);h=h+1|0;}while((h|0)<8);h=g+1|0;if((h|0)<16384){g=h}else{r=0;break}}while(1){if((r|0)>=1024){e=10781;break}s=9638528+(r<<2)|0;if((c[s>>2]|0)==(b|0)){break}else{r=r+1|0}}if((e|0)==10781){return}gGr(b);c[s>>2]=0;return}function ezQ(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;a=i;i=i+480|0;b=a|0;d=a+112|0;e=a+120|0;f=a+232|0;g=a+240|0;h=a+352|0;j=a+360|0;k=a+472|0;c[2444204]=1;if((R6((c[2388102]|0)+1|0,0,2)|0)!=0){l=1;i=a;return l|0}if((R6(c[2388102]|0,1,2)|0)!=0){l=1;i=a;return l|0}m=c[2385886]|0;if((c[3542200]|0)==0){l=1;i=a;return l|0}n=j+108|0;c[n>>2]=0;o=j+100|0;c[o>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,2)|0;do{if((c[n>>2]|0)!=0){j=c[o>>2]|0;c[k>>2]=9534384;p=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[p&16383](k,2,0)|0;if((j|0)<1){l=1;i=a;return l|0}if((gzL(m,0,2)|0)==0){break}else{l=1}i=a;return l|0}}while(0);m=c[3530788]|0;if((c[3542200]|0)==0){l=1;i=a;return l|0}k=g+108|0;c[k>>2]=0;o=g+100|0;c[o>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,3)|0;do{if((c[k>>2]|0)!=0){g=c[o>>2]|0;c[h>>2]=9534384;n=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[n&16383](h,3,0)|0;if((g|0)<1){l=1;i=a;return l|0}if((gzL(m,0,3)|0)==0){break}else{l=1}i=a;return l|0}}while(0);m=(c[3530788]|0)+2097152|0;if((c[3542200]|0)==0){l=1;i=a;return l|0}h=e+108|0;c[h>>2]=0;o=e+100|0;c[o>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,4)|0;do{if((c[h>>2]|0)!=0){e=c[o>>2]|0;c[f>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](f,4,0)|0;if((e|0)<1){l=1;i=a;return l|0}if((gzL(m,0,4)|0)==0){break}else{l=1}i=a;return l|0}}while(0);if((R6((c[3530788]|0)+4194304|0,5,2)|0)!=0){l=1;i=a;return l|0}if((R6(c[3530552]|0,6,2)|0)!=0){l=1;i=a;return l|0}if((R6((c[3530552]|0)+1|0,7,2)|0)!=0){l=1;i=a;return l|0}m=c[2386610]|0;if((c[3542200]|0)==0){l=1;i=a;return l|0}f=b+108|0;c[f>>2]=0;o=b+100|0;c[o>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](b,8)|0;do{if((c[f>>2]|0)!=0){b=c[o>>2]|0;c[d>>2]=9534384;h=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[h&16383](d,8,0)|0;if((b|0)<1){l=1;i=a;return l|0}if((gzL(m,0,8)|0)==0){break}else{l=1}i=a;return l|0}}while(0);ezP();fxU(0,425984);if((c[2394]|0)==0){q=c[2112932]|0}else{c[2394]=0;m=c[3532596]|0;c[2112932]=m;d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];q=m}m=c[2388102]|0;d=q|0;o=0;while(1){f=m+o|0;c[d>>2]=f;c[d+131072>>2]=f;f=o+1024|0;if(f>>>0>524287){break}else{d=d+4|0;o=f}}o=c[2388232]|0;d=q+4096|0;m=1048576;while(1){f=o+(m-1048576)|0;c[d>>2]=f;c[d+65536>>2]=f;c[d+131072>>2]=f;f=m+1024|0;if(f>>>0>1114111){break}else{d=d+4|0;m=f}}m=c[2387140]|0;c[q+32768>>2]=m;c[q+163840>>2]=m;d=m+1024|0;c[q+32772>>2]=d;c[q+163844>>2]=d;d=c[2386416]|0;c[q+36864>>2]=d;c[q+102400>>2]=d;c[q+167936>>2]=d;m=d+1024|0;c[q+36868>>2]=m;c[q+102404>>2]=m;c[q+167940>>2]=m;c[q+36872>>2]=d;c[q+102408>>2]=d;c[q+167944>>2]=d;c[q+36876>>2]=m;c[q+102412>>2]=m;c[q+167948>>2]=m;m=c[3529450]|0;c[q+40960>>2]=m;c[q+106496>>2]=m;c[q+172032>>2]=m;d=m+1024|0;c[q+40964>>2]=d;c[q+106500>>2]=d;c[q+172036>>2]=d;d=m+2048|0;c[q+40968>>2]=d;c[q+106504>>2]=d;c[q+172040>>2]=d;d=m+3072|0;c[q+40972>>2]=d;c[q+106508>>2]=d;c[q+172044>>2]=d;d=m+4096|0;c[q+40976>>2]=d;c[q+106512>>2]=d;c[q+172048>>2]=d;d=m+5120|0;c[q+40980>>2]=d;c[q+106516>>2]=d;c[q+172052>>2]=d;d=m+6144|0;c[q+40984>>2]=d;c[q+106520>>2]=d;c[q+172056>>2]=d;d=m+7168|0;c[q+40988>>2]=d;c[q+106524>>2]=d;c[q+172060>>2]=d;d=m+8192|0;c[q+40992>>2]=d;c[q+106528>>2]=d;c[q+172064>>2]=d;d=m+9216|0;c[q+40996>>2]=d;c[q+106532>>2]=d;c[q+172068>>2]=d;d=m+10240|0;c[q+41e3>>2]=d;c[q+106536>>2]=d;c[q+172072>>2]=d;d=m+11264|0;c[q+41004>>2]=d;c[q+106540>>2]=d;c[q+172076>>2]=d;d=m+12288|0;c[q+41008>>2]=d;c[q+106544>>2]=d;c[q+172080>>2]=d;d=m+13312|0;c[q+41012>>2]=d;c[q+106548>>2]=d;c[q+172084>>2]=d;d=m+14336|0;c[q+41016>>2]=d;c[q+106552>>2]=d;c[q+172088>>2]=d;d=m+15360|0;c[q+41020>>2]=d;c[q+106556>>2]=d;c[q+172092>>2]=d;d=c[3529414]|0;c[q+41472>>2]=d;c[q+107008>>2]=d;c[q+172544>>2]=d;m=d+1024|0;c[q+41476>>2]=m;c[q+107012>>2]=m;c[q+172548>>2]=m;o=d+2048|0;c[q+41480>>2]=o;c[q+107016>>2]=o;c[q+172552>>2]=o;f=d+3072|0;c[q+41484>>2]=f;c[q+107020>>2]=f;c[q+172556>>2]=f;b=d+4096|0;c[q+41488>>2]=b;c[q+107024>>2]=b;c[q+172560>>2]=b;h=d+5120|0;c[q+41492>>2]=h;c[q+107028>>2]=h;c[q+172564>>2]=h;e=d+6144|0;c[q+41496>>2]=e;c[q+107032>>2]=e;c[q+172568>>2]=e;k=d+7168|0;c[q+41500>>2]=k;c[q+107036>>2]=k;c[q+172572>>2]=k;g=d+8192|0;c[q+41504>>2]=g;c[q+107040>>2]=g;c[q+172576>>2]=g;n=d+9216|0;c[q+41508>>2]=n;c[q+107044>>2]=n;c[q+172580>>2]=n;j=d+10240|0;c[q+41512>>2]=j;c[q+107048>>2]=j;c[q+172584>>2]=j;p=d+11264|0;c[q+41516>>2]=p;c[q+107052>>2]=p;c[q+172588>>2]=p;r=d+12288|0;c[q+41520>>2]=r;c[q+107056>>2]=r;c[q+172592>>2]=r;s=d+13312|0;c[q+41524>>2]=s;c[q+107060>>2]=s;c[q+172596>>2]=s;t=d+14336|0;c[q+41528>>2]=t;c[q+107064>>2]=t;c[q+172600>>2]=t;u=d+15360|0;c[q+41532>>2]=u;c[q+107068>>2]=u;c[q+172604>>2]=u;c[q+41536>>2]=d;c[q+107072>>2]=d;c[q+172608>>2]=d;c[q+41540>>2]=m;c[q+107076>>2]=m;c[q+172612>>2]=m;c[q+41544>>2]=o;c[q+107080>>2]=o;c[q+172616>>2]=o;c[q+41548>>2]=f;c[q+107084>>2]=f;c[q+172620>>2]=f;c[q+41552>>2]=b;c[q+107088>>2]=b;c[q+172624>>2]=b;c[q+41556>>2]=h;c[q+107092>>2]=h;c[q+172628>>2]=h;c[q+41560>>2]=e;c[q+107096>>2]=e;c[q+172632>>2]=e;c[q+41564>>2]=k;c[q+107100>>2]=k;c[q+172636>>2]=k;c[q+41568>>2]=g;c[q+107104>>2]=g;c[q+172640>>2]=g;c[q+41572>>2]=n;c[q+107108>>2]=n;c[q+172644>>2]=n;c[q+41576>>2]=j;c[q+107112>>2]=j;c[q+172648>>2]=j;c[q+41580>>2]=p;c[q+107116>>2]=p;c[q+172652>>2]=p;c[q+41584>>2]=r;c[q+107120>>2]=r;c[q+172656>>2]=r;c[q+41588>>2]=s;c[q+107124>>2]=s;c[q+172660>>2]=s;c[q+41592>>2]=t;c[q+107128>>2]=t;c[q+172664>>2]=t;c[q+41596>>2]=u;c[q+107132>>2]=u;c[q+172668>>2]=u;c[q+196648>>2]=1712;c[q+196728>>2]=66;c[q+196608>>2]=3316;c[q+196688>>2]=3324;q=c[3532592]|0;if((q|0)!=0){gGC(q|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;l=0;i=a;return l|0}function ezR(d,e,f,g,h){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;i=d;d=g&1023;g=h&1023;if((f|0)==0){f=c[2112926]|0;h=c[3530406]|0;j=c[2113068]|0;k=c[2113070]|0;l=0;do{m=b[i+(l<<1)>>1]&16383;n=(l<<4&1008)-d|0;o=(l>>6<<4)-g|0;p=(n|0)>1023?n-1024|0:n;n=(o|0)>1023?o-1024|0:o;o=(p|0)<-15?p+1024|0:p;p=(n|0)<-15?n+1024|0:n;do{if((p|0)>-16&(o|0)>-16&(o|0)<(j|0)&(p|0)<(k|0)){if((o|p|0)>-1&(o|0)<304&(p|0)<224){Sy(f,m,o,p,e,8,0,h);break}else{Sz(f,m,o,p,e,8,0,h);break}}}while(0);l=l+1|0;}while((l|0)<2048);return}l=c[2443552]|0;h=c[2112926]|0;f=c[3530406]|0;k=0;do{j=b[i+(k<<1)>>1]&16383;do{if((a[l+j|0]|0)==0){p=(k<<4&1008)-d|0;o=(k>>6<<4)-g|0;m=(p|0)>1023?p-1024|0:p;p=(o|0)>1023?o-1024|0:o;o=(m|0)<-15?m+1024|0:m;m=(p|0)<-15?p+1024|0:p;if(!((m|0)>-16&(o|0)>-16&(o|0)<(c[2113068]|0)&(m|0)<(c[2113070]|0))){break}if((o|m|0)>-1&(o|0)<304&(m|0)<224){SG(h,j,o,m,e,8,0,0,f);break}else{SH(h,j,o,m,e,8,0,0,f);break}}}while(0);k=k+1|0;}while((k|0)<2048);return}function ezS(b,d,f,g,h){b=b|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;i=b;b=g&1023;g=h&511;if((f|0)==0){f=c[2112926]|0;h=c[3530552]|0;j=c[2113068]|0;k=c[2113070]|0;l=0;do{m=e[i+(l<<1)>>1]|0;n=(l<<3&1016)-b|0;o=(l>>7<<3)-g|0;p=(n|0)>1023?n-1024|0:n;n=(o|0)>511?o-512|0:o;o=(p|0)<-7?p+1024|0:p;p=(n|0)<-7?n+512|0:n;do{if((p|0)>-8&(o|0)>-8&(o|0)<(j|0)&(p|0)<(k|0)){if((o|p|0)>-1&(o|0)<312&(p|0)<232){Si(f,m,o,p,d,8,0,h);break}else{Sj(f,m,o,p,d,8,0,h);break}}}while(0);l=l+1|0;}while((l|0)<8192);return}l=c[2443554]|0;h=c[2112926]|0;f=c[3530552]|0;k=0;do{j=e[i+(k<<1)>>1]|0;do{if((a[l+j|0]|0)==0){p=(k<<3&1016)-b|0;o=(k>>7<<3)-g|0;m=(p|0)>1023?p-1024|0:p;p=(o|0)>511?o-512|0:o;o=(m|0)<-7?m+1024|0:m;m=(p|0)<-7?p+512|0:p;if(!((m|0)>-8&(o|0)>-8&(o|0)<(c[2113068]|0)&(m|0)<(c[2113070]|0))){break}if((o|m|0)>-1&(o|0)<312&(m|0)<232){Sq(h,j,o,m,d,8,0,0,f);break}else{Sr(h,j,o,m,d,8,0,0,f);break}}}while(0);k=k+1|0;}while((k|0)<8192);return}function ezT(b){b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=c[2386416]|0;f=c[2443556]|0;g=c[2112926]|0;h=c[3530788]|0;i=0;do{j=e[d+((i|2)<<1)>>1]|0;L14717:do{if((j>>>15|0)==(b|0)){k=e[d+(i<<1)>>1]|0;l=(c[2444204]|0)==0;m=j>>>9&15;n=j&511;o=n>>>0>383?j|-512:n;if(l){p=o;q=256-(k&255)+(k&256)|0}else{p=o-24|0;q=k&511^511}if((p|0)>=(c[2113068]|0)|(p|0)<-15){break}o=(-16<<(k>>>9&3))-8+q|0;n=q-8|0;if((o|0)==(n|0)){break}r=(p|0)<304;s=l|(k&8192|0)==0;k=c[2113070]|0;l=e[d+((i|1)<<1)>>1]|0;t=o;while(1){do{if(!((t|0)>=(k|0)|(t|0)<-15)){if((a[f+l|0]|0)!=0){break}if((t|p|0)>-1&r&(t|0)<224){if(s){SG(g,l,p,t,m,5,0,512,h);break}else{SI(g,l,p,t,m,5,0,512,h);break}}else{if(s){SH(g,l,p,t,m,5,0,512,h);break}else{SJ(g,l,p,t,m,5,0,512,h);break}}}}while(0);o=t+16|0;if((o|0)==(n|0)){break L14717}l=l+1|0;t=o}}}while(0);i=i+4|0;}while((i|0)<1020);return}function ezU(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;b=i;i=i+480|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;l=b+360|0;m=b+472|0;c[2444204]=0;if((R6((c[2388102]|0)+1|0,0,2)|0)!=0){n=1;i=b;return n|0}if((R6(c[2388102]|0,1,2)|0)!=0){n=1;i=b;return n|0}o=c[2385886]|0;if((c[3542200]|0)==0){n=1;i=b;return n|0}p=l+108|0;c[p>>2]=0;q=l+100|0;c[q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,2)|0;do{if((c[p>>2]|0)!=0){l=c[q>>2]|0;c[m>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](m,2,0)|0;if((l|0)<1){n=1;i=b;return n|0}if((gzL(o,0,2)|0)==0){break}else{n=1}i=b;return n|0}}while(0);o=j+108|0;m=j+100|0;q=0;while(1){p=(c[3530788]|0)+(q<<18)|0;l=q+3|0;if((c[3542200]|0)==0){n=1;s=10951;break}c[o>>2]=0;c[m>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,l)|0;if((c[o>>2]|0)!=0){r=c[m>>2]|0;c[k>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](k,l,0)|0;if((r|0)<1){n=1;s=10955;break}if((gzL(p,0,l)|0)!=0){n=1;s=10953;break}}l=q+1|0;if((l|0)<5){q=l}else{s=10897;break}}if((s|0)==10897){q=g+108|0;k=g+100|0;m=0;while(1){o=(c[3530552]|0)+(m<<19)|0;j=m+8|0;if((c[3542200]|0)==0){n=1;s=10964;break}c[q>>2]=0;c[k>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,j)|0;if((c[q>>2]|0)!=0){l=c[k>>2]|0;c[h>>2]=9534384;p=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[p&16383](h,j,0)|0;if((l|0)<1){n=1;s=10960;break}if((gzL(o,0,j)|0)!=0){n=1;s=10958;break}}j=m+1|0;if((j|0)<8){m=j}else{s=10908;break}}if((s|0)==10958){i=b;return n|0}else if((s|0)==10960){i=b;return n|0}else if((s|0)==10964){i=b;return n|0}else if((s|0)==10908){m=c[2386610]|0;if((c[3542200]|0)==0){n=1;i=b;return n|0}h=e+108|0;c[h>>2]=0;k=e+100|0;c[k>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,16)|0;do{if((c[h>>2]|0)==0){u=0}else{e=c[k>>2]|0;c[f>>2]=9534384;q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[q&16383](f,16,0)|0;if((e|0)<1){n=1;i=b;return n|0}if((gzL(m,0,16)|0)==0){u=0;break}else{n=1}i=b;return n|0}}while(0);while(1){if((u|0)>=1024){break}v=9638528+(u<<2)|0;if((c[v>>2]|0)==0){s=10914;break}else{u=u+1|0}}L14793:do{if((s|0)==10914){u=gGq(4194304)|0;c[v>>2]=u;if((u|0)==0){break}gGz(u|0,0,4194304);m=c[3530788]|0;gGC(u|0,m|0,1310720)|0;f=0;do{k=f<<8;gGz(m+k|0,0,256);h=0;do{e=1<<4-h;q=(c[608520+(h<<2)>>2]|0)+k|0;g=0;do{j=q+(c[609008+(g<<2)>>2]|0)|0;o=(g<<4)+k|0;l=0;do{p=j+(c[610384+(l<<2)>>2]|0)|0;if(((d[u+((p|0)/8|0)|0]|0)&128>>>((p&7)>>>0)|0)!=0){p=m+(o+l)|0;a[p]=(d[p]|0|e)&255}l=l+1|0;}while((l|0)<16);g=g+1|0;}while((g|0)<16);h=h+1|0;}while((h|0)<5);f=f+1|0;}while((f|0)<8192);f=c[3530552]|0;gGC(u|0,f|0,4194304)|0;m=0;while(1){h=m<<6;gGz(f+h|0,0,64);k=m<<7;g=0;do{e=1<<7-g;q=(c[614800+(g<<2)>>2]|0)+k|0;l=0;do{o=q+(c[6669224+(l<<2)>>2]|0)|0;j=(l<<3)+h|0;p=0;do{r=o+(c[609616+(p<<2)>>2]|0)|0;if(((d[u+((r|0)/8|0)|0]|0)&128>>>((r&7)>>>0)|0)!=0){r=f+(j+p)|0;a[r]=(d[r]|0|e)&255}p=p+1|0;}while((p|0)<8);l=l+1|0;}while((l|0)<8);g=g+1|0;}while((g|0)<8);g=m+1|0;if((g|0)<65536){m=g}else{w=0;break}}while(1){if((w|0)>=1024){break L14793}x=9638528+(w<<2)|0;if((c[x>>2]|0)==(u|0)){break}else{w=w+1|0}}gGr(u);c[x>>2]=0}}while(0);fxU(0,425984);if((c[2394]|0)==0){y=c[2112932]|0}else{c[2394]=0;x=c[3532596]|0;c[2112932]=x;w=c[3532592]|0;if((w|0)!=0){gGC(9104152,w|0,280)|0}c[2113054]=c[2113060];y=x}x=c[2388102]|0;w=y|0;v=0;while(1){m=x+v|0;c[w>>2]=m;c[w+131072>>2]=m;m=v+1024|0;if(m>>>0>524287){break}else{w=w+4|0;v=m}}v=c[2388232]|0;w=y+4096|0;x=1048576;while(1){m=v+(x-1048576)|0;c[w>>2]=m;c[w+65536>>2]=m;c[w+131072>>2]=m;m=x+1024|0;if(m>>>0>1114111){break}else{w=w+4|0;x=m}}x=c[2387140]|0;c[y+8192>>2]=x;c[y+139264>>2]=x;w=x+1024|0;c[y+8196>>2]=w;c[y+139268>>2]=w;w=c[2386416]|0;c[y+12288>>2]=w;c[y+77824>>2]=w;c[y+143360>>2]=w;x=w+1024|0;c[y+12292>>2]=x;c[y+77828>>2]=x;c[y+143364>>2]=x;c[y+12296>>2]=w;c[y+77832>>2]=w;c[y+143368>>2]=w;c[y+12300>>2]=x;c[y+77836>>2]=x;c[y+143372>>2]=x;x=c[3529450]|0;c[y+16384>>2]=x;c[y+81920>>2]=x;c[y+147456>>2]=x;w=x+1024|0;c[y+16388>>2]=w;c[y+81924>>2]=w;c[y+147460>>2]=w;w=x+2048|0;c[y+16392>>2]=w;c[y+81928>>2]=w;c[y+147464>>2]=w;w=x+3072|0;c[y+16396>>2]=w;c[y+81932>>2]=w;c[y+147468>>2]=w;w=x+4096|0;c[y+16400>>2]=w;c[y+81936>>2]=w;c[y+147472>>2]=w;w=x+5120|0;c[y+16404>>2]=w;c[y+81940>>2]=w;c[y+147476>>2]=w;w=x+6144|0;c[y+16408>>2]=w;c[y+81944>>2]=w;c[y+147480>>2]=w;w=x+7168|0;c[y+16412>>2]=w;c[y+81948>>2]=w;c[y+147484>>2]=w;w=x+8192|0;c[y+16416>>2]=w;c[y+81952>>2]=w;c[y+147488>>2]=w;w=x+9216|0;c[y+16420>>2]=w;c[y+81956>>2]=w;c[y+147492>>2]=w;w=x+10240|0;c[y+16424>>2]=w;c[y+81960>>2]=w;c[y+147496>>2]=w;w=x+11264|0;c[y+16428>>2]=w;c[y+81964>>2]=w;c[y+147500>>2]=w;w=x+12288|0;c[y+16432>>2]=w;c[y+81968>>2]=w;c[y+147504>>2]=w;w=x+13312|0;c[y+16436>>2]=w;c[y+81972>>2]=w;c[y+147508>>2]=w;w=x+14336|0;c[y+16440>>2]=w;c[y+81976>>2]=w;c[y+147512>>2]=w;w=x+15360|0;c[y+16444>>2]=w;c[y+81980>>2]=w;c[y+147516>>2]=w;w=c[3529414]|0;c[y+16896>>2]=w;c[y+82432>>2]=w;c[y+147968>>2]=w;x=w+1024|0;c[y+16900>>2]=x;c[y+82436>>2]=x;c[y+147972>>2]=x;x=w+2048|0;c[y+16904>>2]=x;c[y+82440>>2]=x;c[y+147976>>2]=x;x=w+3072|0;c[y+16908>>2]=x;c[y+82444>>2]=x;c[y+147980>>2]=x;x=w+4096|0;c[y+16912>>2]=x;c[y+82448>>2]=x;c[y+147984>>2]=x;x=w+5120|0;c[y+16916>>2]=x;c[y+82452>>2]=x;c[y+147988>>2]=x;x=w+6144|0;c[y+16920>>2]=x;c[y+82456>>2]=x;c[y+147992>>2]=x;x=w+7168|0;c[y+16924>>2]=x;c[y+82460>>2]=x;c[y+147996>>2]=x;x=w+8192|0;c[y+16928>>2]=x;c[y+82464>>2]=x;c[y+148e3>>2]=x;x=w+9216|0;c[y+16932>>2]=x;c[y+82468>>2]=x;c[y+148004>>2]=x;x=w+10240|0;c[y+16936>>2]=x;c[y+82472>>2]=x;c[y+148008>>2]=x;x=w+11264|0;c[y+16940>>2]=x;c[y+82476>>2]=x;c[y+148012>>2]=x;x=w+12288|0;c[y+16944>>2]=x;c[y+82480>>2]=x;c[y+148016>>2]=x;x=w+13312|0;c[y+16948>>2]=x;c[y+82484>>2]=x;c[y+148020>>2]=x;x=w+14336|0;c[y+16952>>2]=x;c[y+82488>>2]=x;c[y+148024>>2]=x;x=w+15360|0;c[y+16956>>2]=x;c[y+82492>>2]=x;c[y+148028>>2]=x;c[y+196648>>2]=2592;c[y+196728>>2]=2954;c[y+196608>>2]=3448;c[y+196688>>2]=3612;y=c[3532592]|0;if((y|0)!=0){gGC(y|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;n=0;i=b;return n|0}}else if((s|0)==10951){i=b;return n|0}else if((s|0)==10953){i=b;return n|0}else if((s|0)==10955){i=b;return n|0}return 0}function ezV(b){b=b|0;var d=0;if((b|0)==6815744){d=~a[9757904]}else if((b|0)==8389633){d=c[2113156]&255}else if((b|0)==6815746){d=~a[9757905]}else if((b|0)==6815748){d=~a[9757906]}else if((b|0)==8388609){c[3542228]=0;d=a[14168916]|0}else{d=0}return d|0}function ezW(b,d){b=b|0;d=d|0;var e=0,f=0;switch(b|0){case 8388624:case 8388626:case 8388628:{e=b>>>1&15;c[3542228]=e;f=d&255;do{if(e>>>0<14){if((e|0)!=13){if((a[14168916+e|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(0,e,f);return};case 8389136:case 8389138:case 8389140:{f=b>>>1&15;c[3542291]=f;b=d&255;do{if(f>>>0<14){if((f|0)!=13){if((a[14169168+f|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(1,f,b);return};case 8389633:{Uv(0,d);return};default:{return}}}function ezX(b){b=b|0;var e=0,f=0;switch(b|0){case 8388622:case 8388636:case 8388638:{e=b>>>1&15;c[3542228]=e;do{if((e|0)==15){b=c[3542225]|0;if((b|0)==0){break}a[14168931]=gj[b&4095](0)|0}else if((e|0)==14){b=c[3542224]|0;if((b|0)==0){break}a[14168930]=gj[b&4095](0)|0}}while(0);f=d[14168916+e|0]|0;return f|0};case 8389632:{f=c[2113156]&65535;return f|0};case 8389134:{c[3542291]=7;f=d[14169175]|0;return f|0};default:{f=0;return f|0}}return 0}function ezY(d,e){d=d|0;e=e|0;var f=0,g=0;if((d|0)==8389632){Uv(0,e&255);return}else if((d|0)==8388608|(d|0)==8388610|(d|0)==8388612|(d|0)==8388614|(d|0)==8388616|(d|0)==8388618|(d|0)==8388620|(d|0)==8388622|(d|0)==8388624|(d|0)==8388626|(d|0)==8388628|(d|0)==8388630|(d|0)==8388632|(d|0)==8388634){f=d>>>1&15;c[3542228]=f;g=e&255;do{if(f>>>0<14){if((f|0)!=13){if((a[14168916+f|0]|0)==(e&255)<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(0,f,g);return}else if((d|0)==5767168){b[4860360]=e;return}else if((d|0)==5242880){b[4875360]=e;return}else if((d|0)==8389120|(d|0)==8389122|(d|0)==8389124|(d|0)==8389126|(d|0)==8389128|(d|0)==8389130|(d|0)==8389132|(d|0)==8389134|(d|0)==8389136|(d|0)==8389138|(d|0)==8389140|(d|0)==8389142|(d|0)==8389144|(d|0)==8389146){g=d>>>1&15;c[3542291]=g;d=e&255;do{if(g>>>0<14){if((g|0)!=13){if((a[14169168+g|0]|0)==(e&255)<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(1,g,d);return}else{return}}function ezZ(b){b=b|0;var c=0;if((b|0)==12582918){c=~a[9757906]}else if((b|0)==12582919){c=-1}else if((b|0)==12582912){c=~a[9757904]}else if((b|0)==12582913){c=a[14108432]|0}else if((b|0)==12582915){c=a[14108433]|0}else if((b|0)==15466496){c=0}else if((b|0)==12582914){c=~a[9757905]}else{c=0}return c|0}function ez_(d,e){d=d|0;e=e|0;var f=0,g=0;if((d|0)!=14680064){return}c[2430150]=e&255;e=c[2439330]|0;if((e|0)!=0){d=e;gGC(9706056,d|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;d=(c[2433530]|0)+12|0;c[2433530]=d;e=c[1836236]|0;f=c[9757320+(e<<2)>>2]|0;if((f|0)!=0){g=f;gGC(g|0,9706056,76)|0}c[9752472+(e<<2)>>2]=d;c[14113936+(e<<2)>>2]=c[2076596];c[9669104+(e<<2)>>2]=c[3541536];c[1836236]=-1;return}function ez$(a){a=a|0;var b=0,d=0;if((a|0)==12582912){b=((gj[c[(c[2112932]|0)+196608>>2]&4095](12582912)|0)&255)<<8;d=(gj[c[(c[2112932]|0)+196608>>2]&4095](12582913)|0)&255|b;return d|0}else if((a|0)==12582914){b=((gj[c[(c[2112932]|0)+196608>>2]&4095](12582914)|0)&255)<<8;d=(gj[c[(c[2112932]|0)+196608>>2]&4095](12582915)|0)&255|b;return d|0}else if((a|0)==12582916){d=-1;return d|0}else if((a|0)==12582918){a=((gj[c[(c[2112932]|0)+196608>>2]&4095](12582918)|0)&255)<<8;d=(gj[c[(c[2112932]|0)+196608>>2]&4095](12582919)|0)&255|a;return d|0}else{d=0;return d|0}return 0}function ez0(a,b){a=a|0;b=b|0;return}function ez1(b){b=b|0;var d=0,e=0,f=0;do{if((b|0)==4194305){c[3542228]=0;d=a[14168916]|0}else if((b|0)==14680065){d=a[14108432]|0}else if((b|0)==4194845){c[3542291]=14;e=c[3542287]|0;if((e|0)==0){d=a[14169182]|0;break}else{f=gj[e&4095](0)|0;a[14169182]=f;d=f;break}}else if((b|0)==14680066){d=~a[9757905]}else if((b|0)==14680068){d=~a[9757906]}else if((b|0)==14680064){d=~a[9757904]}else if((b|0)==14680070){d=-1}else if((b|0)==4195329){d=c[2113156]&255}else{d=0}}while(0);return d|0}function ez2(b,d){b=b|0;d=d|0;var e=0,f=0;if((b|0)==4194319|(b|0)==4194320|(b|0)==4194322|(b|0)==4194324){e=b>>>1&15;c[3542228]=e;f=d&255;do{if(e>>>0<14){if((e|0)!=13){if((a[14168916+e|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(0,e,f);return}else if((b|0)==4194831|(b|0)==4194832|(b|0)==4194834|(b|0)==4194836|(b|0)==4194847){f=b>>>1&15;c[3542291]=f;e=d&255;do{if(f>>>0<14){if((f|0)!=13){if((a[14169168+f|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(1,f,e);return}else if((b|0)==4195329){Uv(0,d);return}else if((b|0)==13631489){b=d&255;c[2415256]=b&2;Tr(b&1);return}else{return}}function ez3(a){a=a|0;return 0}function ez4(d,e){d=d|0;e=e|0;var f=0,g=0,h=0;if((d|0)==9437184){b[4860268]=e;if((e&255)==0){return}b[4859460]=e&2;b[4859456]=e&1;return}else if((d|0)==4194816|(d|0)==4194818|(d|0)==4194820|(d|0)==4194822|(d|0)==4194824|(d|0)==4194826|(d|0)==4194828|(d|0)==4194830|(d|0)==4194832|(d|0)==4194834|(d|0)==4194836|(d|0)==4194838|(d|0)==4194840|(d|0)==4194842|(d|0)==4194844|(d|0)==4194846){f=d>>>1&15;c[3542291]=f;g=e&255;do{if(f>>>0<14){if((f|0)!=13){if((a[14169168+f|0]|0)==(e&255)<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(1,f,g);return}else if((d|0)==4194304|(d|0)==4194306|(d|0)==4194308|(d|0)==4194310|(d|0)==4194312|(d|0)==4194314|(d|0)==4194316|(d|0)==4194318|(d|0)==4194320|(d|0)==4194322|(d|0)==4194324|(d|0)==4194326|(d|0)==4194328|(d|0)==4194330|(d|0)==4194332){g=d>>>1&15;c[3542228]=g;f=e&255;do{if(g>>>0<14){if((g|0)!=13){if((a[14168916+g|0]|0)==(e&255)<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(0,g,f);return}else if((d|0)==4194334){if(!(a[642456]|0)){f=e&7;c[2443290]=f;g=c[3541206]|0;h=(c[2438662]|0)+(f<<18)|0;gGC(g|0,h|0,262144)|0;return}c[3542228]=15;a[14168931]=e&255;if((a[14168923]|0)>=0){return}h=c[3542227]|0;if((h|0)==0){return}gg[h&4095](0,e&255);return}else if((d|0)==13631488){gg[c[(c[2112932]|0)+196648>>2]&4095](13631488,(e&65535)>>>8&255);gg[c[(c[2112932]|0)+196648>>2]&4095](13631489,e&255);return}else{return}}function ez5(b){b=b|0;var d=0,e=0,f=0;do{if((b|0)==4195329){d=c[2113156]&255}else if((b|0)==12582912){d=~a[9757904]}else if((b|0)==12582916){d=~a[9757906]}else if((b|0)==4194845){c[3542291]=14;e=c[3542287]|0;if((e|0)==0){d=a[14169182]|0;break}else{f=gj[e&4095](0)|0;a[14169182]=f;d=f;break}}else if((b|0)==4194305){c[3542228]=0;d=a[14168916]|0}else if((b|0)==12582914){d=63-(a[9757905]|0)&255}else if((b|0)==12582913){d=a[14108432]|0}else{d=0}}while(0);return d|0}function ez6(b){b=b|0;var c=0;do{if((b|0)==9437204){if(!(a[680496]|0)){c=0;break}c=(cT()|0)&255}else if((b|0)==9437205){if(!(a[672472]|0)){c=0;break}c=(cT()|0)&255}else if((b|0)==11534342){c=~a[9757907]}else if((b|0)==11534336){c=~a[9757904]}else if((b|0)==11534338){c=~a[9757905]}else if((b|0)==11534340){c=~a[9757906]}else{c=0}}while(0);return c|0}function ez7(a,c){a=a|0;c=c|0;var d=0,e=0;if((a|0)==7340032|(a|0)==7340034|(a|0)==7340036|(a|0)==7340038|(a|0)==7340040|(a|0)==7340042|(a|0)==7340044|(a|0)==7340046|(a|0)==7340048|(a|0)==7340050|(a|0)==7340052|(a|0)==7340054|(a|0)==7340056|(a|0)==7340058|(a|0)==7340060|(a|0)==7340062){d=(a-7340032|0)>>>1;e=c&255;b[9720536+(d<<1)>>1]=e;if((d|0)!=0|c<<24>>24==0){return}b[4859460]=e&2;b[4859456]=e&1;return}else if((a|0)==6291456|(a|0)==6291458|(a|0)==6291460|(a|0)==6291462|(a|0)==6291464|(a|0)==6291465|(a|0)==6291466|(a|0)==6291467|(a|0)==6291468|(a|0)==6291470|(a|0)==6291472|(a|0)==6291474|(a|0)==6291476|(a|0)==6291478|(a|0)==6291480|(a|0)==6291482|(a|0)==6291484|(a|0)==6291486){b[9720656+((a-6291456|0)>>>1<<1)>>1]=c&255;return}else if((a|0)==6815744|(a|0)==6815746|(a|0)==6815748|(a|0)==6815750|(a|0)==6815752|(a|0)==6815753|(a|0)==6815754|(a|0)==6815755|(a|0)==6815756|(a|0)==6815758|(a|0)==6815760|(a|0)==6815762|(a|0)==6815764|(a|0)==6815766|(a|0)==6815768|(a|0)==6815770|(a|0)==6815772|(a|0)==6815774){b[9720624+((a-6815744|0)>>>1<<1)>>1]=c&255;return}else if((a|0)==8912897){Uv(1,c);return}else if((a|0)==8388609){Uv(0,c);return}else{return}}function ez8(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;if((f|0)==11534336){g=-256-((d[9757904]|0)<<8)&65535;return g|0}else if((f|0)==9437184|(f|0)==9437186|(f|0)==9437188|(f|0)==9437190|(f|0)==9437192|(f|0)==9437194|(f|0)==9437196|(f|0)==9437198|(f|0)==9437200|(f|0)==9437202|(f|0)==9437204|(f|0)==9437206|(f|0)==9437208|(f|0)==9437210|(f|0)==9437212|(f|0)==9437214|(f|0)==9437216|(f|0)==9437218|(f|0)==9437220|(f|0)==9437222|(f|0)==9437224|(f|0)==9437226|(f|0)==9437228|(f|0)==9437230|(f|0)==9437232|(f|0)==9437234|(f|0)==9437236|(f|0)==9437238|(f|0)==9437240){if(!(a[642536]|0)){if(!(a[672472]|0)){if(!(a[680496]|0)){g=0;return g|0}g=(cT()|0)&65535;return g|0}h=(f-9437184|0)>>>1;if((h|0)==10){g=(cT()|0)&65535;return g|0}else if((h|0)==9){g=ag(b[4852912]|0,b[4852916]|0)|0;return g|0}else if((h|0)==2){i=b[4852924]|0;j=b[4852900]|0;do{if((i&65535)>(j&65535)){k=512}else{if(i<<16>>16==j<<16>>16){k=1024;break}k=(i&65535)<(j&65535)?2048:0}}while(0);l=b[4852920]|0;m=b[4852896]|0;do{if((l&65535)>(m&65535)){n=k|8192}else{if(l<<16>>16==m<<16>>16){n=k|16384;break}else{n=(l&65535)<(m&65535)?k|-32768:k;break}}}while(0);k=i-j&65535;j=l-m&65535;g=(j-(b[4852888]|0)&65535&(k-(b[4852892]|0)&65535))<<16>>16<0&((b[4852908]|0)+k&65535)<<16>>16>-1&((b[4852904]|0)+j&65535)<<16>>16>-1&1|n;return g|0}else if((h|0)==8){g=(ag(e[4852912]|0,e[4852916]|0)|0)>>>16&65535;return g|0}else{g=0;return g|0}}h=(f-9437184|0)>>>1;n=b[4852900]|0;j=b[4852924]|0;k=(n&65535)<(j&65535);do{if(k){o=11162}else{m=b[4852908]|0;if((n&65535|0)>=((m&65535)+(j&65535)|0)){o=11162;break}p=(j-n&65535)+m&65535}}while(0);L15111:do{if((o|0)==11162){do{if((j&65535)<(n&65535)){q=b[4852892]|0;r=j&65535;s=n&65535}else{m=n&65535;l=j&65535;i=b[4852892]|0;if((l|0)>=((i&65535)+m|0)){q=i;r=l;s=m;break}p=(n-j&65535)+i&65535;break L15111}}while(0);i=e[4852908]|0;m=q&65535;l=r-s-(m>>>1)+(i>>>1)|0;p=((i+m|0)>>>1)-((l|0)>-1?l:-l|0)&65535}}while(0);s=b[4852896]|0;r=b[4852920]|0;q=(s&65535)<(r&65535);do{if(q){o=11170}else{l=b[4852904]|0;if((s&65535|0)>=((l&65535)+(r&65535)|0)){o=11170;break}t=(r-s&65535)+l&65535}}while(0);L15122:do{if((o|0)==11170){do{if((r&65535)<(s&65535)){u=b[4852888]|0;v=r&65535;w=s&65535}else{l=s&65535;m=r&65535;i=b[4852888]|0;if((m|0)>=((i&65535)+l|0)){u=i;v=m;w=l;break}t=(s-r&65535)+i&65535;break L15122}}while(0);i=e[4852904]|0;l=u&65535;m=v-w-(l>>>1)+(i>>>1)|0;t=((i+l|0)>>>1)-((m|0)>-1?m:-m|0)&65535}}while(0);switch(h|0){case 19:{g=b[4852904]|0;return g|0};case 22:{g=n;return g|0};case 23:{g=b[4852892]|0;return g|0};case 24:{g=s;return g|0};case 25:{g=b[4852888]|0;return g|0};case 1:{g=t;return g|0};case 17:{g=b[4852908]|0;return g|0};case 18:{g=r;return g|0};case 0:{g=p;return g|0};case 2:{do{if(q){x=8192}else{if(r<<16>>16==s<<16>>16){x=16384;break}x=(r&65535)<(s&65535)?-32768:0}}while(0);s=t<<16>>16<0?x|4096:x;do{if(k){y=s|512}else{if(j<<16>>16==n<<16>>16){y=s|1024;break}else{y=(j&65535)<(n&65535)?s|2048:s;break}}}while(0);s=(p<<16>>16<0?y|256:y)|(p<<16>>16>>15)+68&65535&-4;y=t<<16>>16>-1;t=y?s|2:s;if(p<<16>>16<=-1){g=t;return g|0}g=y?t|15:s;return g|0};case 10:{g=(cT()|0)&65535;return g|0};case 16:{g=j;return g|0};default:{g=0;return g|0}}}else if((f|0)==11534342){g=-1;return g|0}else if((f|0)==11534338){g=-256-((d[9757905]|0)<<8)&65535;return g|0}else if((f|0)==11534340){g=-256-((d[9757906]|0)<<8)&65535;return g|0}else if((f|0)==8388608){g=c[2113156]&65535;return g|0}else if((f|0)==8912896){g=c[2113157]&65535;return g|0}else{g=0;return g|0}return 0}function ez9(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0;if((d|0)==2818048){b[4885845]=e;if(!((b[4885844]|0)==-1&e<<16>>16==-1&(b[4885846]|0)==-1&(b[4885847]|0)==-1)){return}f=9771688;c[f>>2]=0;c[f+4>>2]=0;gu[c[3531910]&16383]();return}else if((d|0)==2752512){b[4885844]=e;if(!(e<<16>>16==-1&(b[4885845]|0)==-1&(b[4885846]|0)==-1&(b[4885847]|0)==-1)){return}f=9771688;c[f>>2]=0;c[f+4>>2]=0;gu[c[3531910]&16383]();return}else if((d|0)==8912896){Uv(1,e&255);return}else if((d|0)==8388608){Uv(0,e&255);return}else if((d|0)==9437184|(d|0)==9437186|(d|0)==9437188|(d|0)==9437190|(d|0)==9437192|(d|0)==9437194|(d|0)==9437196|(d|0)==9437198|(d|0)==9437200|(d|0)==9437202|(d|0)==9437204|(d|0)==9437206|(d|0)==9437208|(d|0)==9437210|(d|0)==9437212|(d|0)==9437214|(d|0)==9437216|(d|0)==9437218|(d|0)==9437220|(d|0)==9437222|(d|0)==9437224|(d|0)==9437226|(d|0)==9437228|(d|0)==9437230|(d|0)==9437232|(d|0)==9437234|(d|0)==9437236|(d|0)==9437238|(d|0)==9437240){L15197:do{if(a[672472]|0){switch((d-9437184|0)>>>1|0){case 2:{b[4852920]=e;break L15197;break};case 1:{b[4852908]=e;break L15197;break};case 0:{b[4852924]=e;break L15197;break};case 4:{b[4852900]=e;break L15197;break};case 5:{b[4852892]=e;break L15197;break};case 6:{b[4852896]=e;break L15197;break};case 7:{b[4852888]=e;break L15197;break};case 8:{b[4852916]=e;break L15197;break};case 9:{b[4852912]=e;break L15197;break};case 3:{b[4852904]=e;break L15197;break};default:{break L15197}}}}while(0);if(!(a[642536]|0)){return}switch((d-9437184|0)>>>1|0){case 16:{b[4852924]=e;return};case 17:{b[4852908]=e;return};case 18:{b[4852920]=e;return};case 19:{b[4852904]=e;return};case 22:{b[4852900]=e;return};case 23:{b[4852892]=e;return};case 24:{b[4852896]=e;return};case 25:{b[4852888]=e;return};default:{return}}}else if((d|0)==12582912){b[4858644]=e;return}else if((d|0)==14680064){f=e&15;c[2443290]=f;g=c[3541206]|0;h=(c[2438662]|0)+(f<<18)|0;gGC(g|0,h|0,262144)|0;return}else if((d|0)==15204352){h=e&65535;if(a[680496]|0){g=h&1;c[2443288]=g;f=(c[3541206]|0)+1048576|0;i=(c[2437642]|0)+(g<<18)|0;gGC(f|0,i|0,262144)|0;return}else{c[2443288]=h;i=(c[3541206]|0)+1048576|0;f=(c[2437642]|0)+(h<<18)|0;gGC(i|0,f|0,262144)|0;return}}else if((d|0)==2883584){b[4885846]=e;if(!((b[4885844]|0)==-1&(b[4885845]|0)==-1&e<<16>>16==-1&(b[4885847]|0)==-1)){return}f=9771688;c[f>>2]=0;c[f+4>>2]=0;gu[c[3531910]&16383]();return}else if((d|0)==7340032){b[4860268]=e;if((e&255)==0){return}b[4859460]=e&2;b[4859456]=e&1;return}else if((d|0)==2949120){b[4885847]=e;if(!((b[4885844]|0)==-1&(b[4885845]|0)==-1&(b[4885846]|0)==-1&e<<16>>16==-1)){return}e=9771688;c[e>>2]=0;c[e+4>>2]=0;gu[c[3531910]&16383]();return}else{return}}function eAa(a){a=a|0;var b=0,d=0;b=a&255;if((b|0)==3){d=c[(c[3531464]|0)+4240>>2]&255}else if((b|0)==6){d=c[2430150]&255}else{d=0}return d|0}function eAb(b,d){b=b|0;d=d|0;var e=0;e=b&255;if((e|0)==3){b=c[2113304]|0;a[14168504+b|0]=d;mv(0,b,d&255);return}else if((e|0)==2){c[2113304]=d&255;return}else{return}}function eAc(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4240780+(b*112|0)>>2];c[a+104>>2]=c[4240784+(b*112|0)>>2];c[a+108>>2]=c[4240788+(b*112|0)>>2];d=0;return d|0}function eAd(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=4240680+(b*112|0);e=0;return e|0}function eAe(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>23){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1312144+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eAf(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>43){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4242360+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eAg(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0.0,S=0,T=0;e=i;i=i+600|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;c[2430154]=9216;c[2433414]=4096;c[2431698]=0;r=c[642608+(c[2436]<<2)>>2]|0;s=c[r+128>>2]|0;if((c[r+52>>2]&4|0)==0){c[2113068]=s;t=c[r+132>>2]|0;c[2113070]=t;c[2443814]=s;c[2440436]=t;u=s;v=t}else{c[2113070]=s;t=c[r+132>>2]|0;c[2113068]=t;c[2440436]=s;c[2443814]=t;u=t;v=s}s=ag(u<<1,v)|0;v=gGq(s)|0;c[2112926]=v;if((v|0)==0){w=0}else{gGz(v|0,0,s|0);w=0}while(1){if((w|0)>=1024){x=0;break}y=9638528+(w<<2)|0;if((c[y>>2]|0)==0){z=11358;break}else{w=w+1|0}}do{if((z|0)==11358){w=gGq(36864)|0;c[y>>2]=w;if((w|0)==0){x=0;break}gGz(w|0,0,36864);x=w}}while(0);c[3528200]=x;c[3541224]=9874;a[681672]=0;c[2426984]=4095;a[809552]=0;if(a[680496]|a[642536]|a[672472]){a[681672]=1;c[2426984]=65535;a[809552]=1;A=0}else{A=1}a[703944]=0;c[2429320]=8192;a[682248]=A;c[2429504]=0;A=c[2113068]|0;if((A|0)==256){c[2429504]=91}else if((A|0)==320){c[2429504]=51}a[726896]=0;A=c[2113070]|0;if((A|0)==232|(A|0)==224){a[726896]=1}b[4875360]=0;b[4860360]=0;c[3541224]=7942;a[6872968]=1;a[9707944]=1;c[2426682]=0;eBi();A=c[2414104]|0;x=0;while(1){if((x|0)>=1024){break}B=9638528+(x<<2)|0;if((c[B>>2]|0)==0){z=11370;break}else{x=x+1|0}}do{if((z|0)==11370){x=gGq(A)|0;c[B>>2]=x;if((x|0)==0){break}gGz(x|0,0,A|0);c[2426682]=x;gGz(x|0,0,A|0);eBi();x=0;while(1){if((x|0)>=1024){C=0;break}D=9638528+(x<<2)|0;if((c[D>>2]|0)==0){z=11375;break}else{x=x+1|0}}do{if((z|0)==11375){x=gGq(4194304)|0;c[D>>2]=x;if((x|0)==0){C=0;break}gGz(x|0,0,4194304);C=x}}while(0);c[2437674]=C;if((R6((c[3527104]|0)+1|0,0,2)|0)!=0){E=1;i=e;return E|0}if((R6(c[3527104]|0,1,2)|0)!=0){E=1;i=e;return E|0}x=c[2437674]|0;if((c[3542200]|0)==0){E=1;i=e;return E|0}y=p+108|0;c[y>>2]=0;w=p+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,2)|0;do{if((c[y>>2]|0)!=0){s=c[w>>2]|0;c[q>>2]=9534384;v=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[v&16383](q,2,0)|0;if((s|0)<1){E=1;i=e;return E|0}if((gzL(x,0,2)|0)==0){break}else{E=1}i=e;return E|0}}while(0);x=(c[2437674]|0)+524288|0;if((c[3542200]|0)==0){E=1;i=e;return E|0}w=n+108|0;c[w>>2]=0;y=n+100|0;c[y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,3)|0;do{if((c[w>>2]|0)!=0){s=c[y>>2]|0;c[o>>2]=9534384;v=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[v&16383](o,3,0)|0;if((s|0)<1){E=1;i=e;return E|0}if((gzL(x,0,3)|0)==0){break}else{E=1}i=e;return E|0}}while(0);x=(c[2437674]|0)+1048576|0;if((c[3542200]|0)==0){E=1;i=e;return E|0}y=l+108|0;c[y>>2]=0;w=l+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,4)|0;do{if((c[y>>2]|0)!=0){s=c[w>>2]|0;c[m>>2]=9534384;v=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[v&16383](m,4,0)|0;if((s|0)<1){E=1;i=e;return E|0}if((gzL(x,0,4)|0)==0){break}else{E=1}i=e;return E|0}}while(0);x=c[2430154]|0;w=c[2437674]|0;y=c[2437676]|0;if((x|0)>0){s=0;do{v=s<<8;gGz(y+v|0,0,256);u=s<<10;t=0;do{r=1<<3-t;F=(c[703416+(t<<2)>>2]|0)+u|0;G=0;do{H=F+(c[3946808+(G<<2)>>2]|0)|0;I=(G<<4)+v|0;J=0;do{K=H+(c[3946872+(J<<2)>>2]|0)|0;if(((d[w+((K|0)/8|0)|0]|0)&128>>>((K&7)>>>0)|0)!=0){K=y+(I+J)|0;a[K]=(d[K]|0|r)&255}J=J+1|0;}while((J|0)<16);G=G+1|0;}while((G|0)<16);t=t+1|0;}while((t|0)<4);s=s+1|0;}while((s|0)<(x|0))}gGz(w|0,0,4194304);if((c[3542200]|0)==0){E=1;i=e;return E|0}x=j+108|0;c[x>>2]=0;s=j+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,5)|0;do{if((c[x>>2]|0)!=0){y=c[s>>2]|0;c[k>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](k,5,0)|0;if((y|0)<1){E=1;i=e;return E|0}if((gzL(w,0,5)|0)==0){break}else{E=1}i=e;return E|0}}while(0);w=c[2437674]|0;if((w|0)==0){L=0}else{s=0;while(1){x=w+s|0;y=a[x]|0;a[x]=(y&255)>>>4|y<<4;y=s+1|0;if((y|0)<524288){s=y}else{L=w;break}}}w=c[2433414]|0;s=c[2439470]|0;if((w|0)>0){y=0;while(1){x=y<<8;gGz(s+x|0,0,256);t=y<<10;v=0;do{u=1<<3-v;G=(c[703416+(v<<2)>>2]|0)+t|0;r=0;do{F=G+(c[3946808+(r<<2)>>2]|0)|0;J=(r<<4)+x|0;I=0;do{H=F+(c[3946872+(I<<2)>>2]|0)|0;if(((d[L+((H|0)/8|0)|0]|0)&128>>>((H&7)>>>0)|0)!=0){H=s+(J+I)|0;a[H]=(d[H]|0|u)&255}I=I+1|0;}while((I|0)<16);r=r+1|0;}while((r|0)<16);v=v+1|0;}while((v|0)<4);v=y+1|0;if((v|0)<(w|0)){y=v}else{M=L;break}}}else{M=L}gGz(M|0,0,4194304);if((R6(M,6,2)|0)!=0){E=1;i=e;return E|0}if((R6((c[2437674]|0)+1|0,7,2)|0)!=0){E=1;i=e;return E|0}if((R6((c[2437674]|0)+1048576|0,8,2)|0)!=0){E=1;i=e;return E|0}if((R6((c[2437674]|0)+1048577|0,9,2)|0)!=0){E=1;i=e;return E|0}if((R6((c[2437674]|0)+2097152|0,10,2)|0)!=0){E=1;i=e;return E|0}if((R6((c[2437674]|0)+2097153|0,11,2)|0)!=0){E=1;i=e;return E|0}if((R6((c[2437674]|0)+3145728|0,12,2)|0)!=0){E=1;i=e;return E|0}if((R6((c[2437674]|0)+3145729|0,13,2)|0)!=0){E=1;i=e;return E|0}y=c[2437674]|0;w=c[2433416]|0;s=0;while(1){v=s<<16;x=0;do{t=x+v|0;r=0;do{u=t+(r<<8)|0;G=u<<1;I=d[y+G|0]|0;J=d[y+(G|1)|0]|0;G=I>>>3;F=J>>>1;H=(I<<8|J)>>>6&31^9;J=(G&8|0)==0?G^16:G;G=J+31&31;I=(F&31^19^F<<1&16)+2|0;F=I&31;do{if((H&16|0)==0){N=G}else{if((I&16|0)==0){N=G;break}N=J+30&31}}while(0);b[w+(u<<1)>>1]=(F|H<<5|N<<10)+2048&65535;r=r+1|0;}while((r|0)<256);x=x+1|0;}while((x|0)<256);x=s+1|0;if((x|0)<32){s=x}else{O=0;break}}while(1){if((O|0)>=1024){break}P=9638528+(O<<2)|0;if((c[P>>2]|0)==(y|0)){z=11436;break}else{O=O+1|0}}if((z|0)==11436){gGr(y);c[P>>2]=0}c[2437674]=0;s=c[3541206]|0;if((c[3542200]|0)==0){E=1;i=e;return E|0}w=f+108|0;c[w>>2]=0;x=f+100|0;c[x>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,14)|0;do{if((c[w>>2]|0)!=0){v=c[x>>2]|0;c[g>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](g,14,0)|0;if((v|0)<1){E=1;i=e;return E|0}if((gzL(s,0,14)|0)==0){break}else{E=1}i=e;return E|0}}while(0);s=c[2438662]|0;x=c[3541206]|0;gGC(s|0,x|0,262144)|0;fxU(0,425984);if((c[2394]|0)==0){Q=c[2112932]|0}else{c[2394]=0;x=c[3532596]|0;c[2112932]=x;s=c[3532592]|0;if((s|0)!=0){gGC(9104152,s|0,280)|0}c[2113054]=c[2113060];Q=x}x=c[3527104]|0;s=Q|0;w=0;while(1){y=x+w|0;c[s>>2]=y;c[s+131072>>2]=y;y=w+1024|0;if(y>>>0>262143){break}else{s=s+4|0;w=y}}w=c[3527106]|0;s=Q+8192|0;x=2097152;while(1){y=w+(x-2097152)|0;c[s>>2]=y;c[s+65536>>2]=y;c[s+131072>>2]=y;y=x+1024|0;if(y>>>0>2162687){break}else{s=s+4|0;x=y}}x=c[2431696]|0;c[Q+12512>>2]=x;c[Q+78048>>2]=x;c[Q+143584>>2]=x;s=x+1024|0;c[Q+12516>>2]=s;c[Q+78052>>2]=s;c[Q+143588>>2]=s;s=x+2048|0;c[Q+12520>>2]=s;c[Q+78056>>2]=s;c[Q+143592>>2]=s;s=x+3072|0;c[Q+12524>>2]=s;c[Q+78060>>2]=s;c[Q+143596>>2]=s;s=x+4096|0;c[Q+12528>>2]=s;c[Q+78064>>2]=s;c[Q+143600>>2]=s;s=x+5120|0;c[Q+12532>>2]=s;c[Q+78068>>2]=s;c[Q+143604>>2]=s;s=x+6144|0;c[Q+12536>>2]=s;c[Q+78072>>2]=s;c[Q+143608>>2]=s;s=x+7168|0;c[Q+12540>>2]=s;c[Q+78076>>2]=s;c[Q+143612>>2]=s;s=c[2430152]|0;c[Q+16384>>2]=s;c[Q+81920>>2]=s;c[Q+147456>>2]=s;x=s+1024|0;c[Q+16388>>2]=x;c[Q+81924>>2]=x;c[Q+147460>>2]=x;x=s+2048|0;c[Q+16392>>2]=x;c[Q+81928>>2]=x;c[Q+147464>>2]=x;x=s+3072|0;c[Q+16396>>2]=x;c[Q+81932>>2]=x;c[Q+147468>>2]=x;x=c[2431684]|0;c[Q+49152>>2]=x;c[Q+114688>>2]=x;c[Q+180224>>2]=x;s=x+1024|0;c[Q+49156>>2]=s;c[Q+114692>>2]=s;c[Q+180228>>2]=s;s=x+2048|0;c[Q+49160>>2]=s;c[Q+114696>>2]=s;c[Q+180232>>2]=s;s=x+3072|0;c[Q+49164>>2]=s;c[Q+114700>>2]=s;c[Q+180236>>2]=s;s=c[2431686]|0;c[Q+49168>>2]=s;c[Q+114704>>2]=s;c[Q+180240>>2]=s;x=s+1024|0;c[Q+49172>>2]=x;c[Q+114708>>2]=x;c[Q+180244>>2]=x;x=s+2048|0;c[Q+49176>>2]=x;c[Q+114712>>2]=x;c[Q+180248>>2]=x;x=s+3072|0;c[Q+49180>>2]=x;c[Q+114716>>2]=x;c[Q+180252>>2]=x;x=c[2431692]|0;c[Q+49184>>2]=x;c[Q+114720>>2]=x;c[Q+180256>>2]=x;s=x+1024|0;c[Q+49188>>2]=s;c[Q+114724>>2]=s;c[Q+180260>>2]=s;s=x+2048|0;c[Q+49192>>2]=s;c[Q+114728>>2]=s;c[Q+180264>>2]=s;s=x+3072|0;c[Q+49196>>2]=s;c[Q+114732>>2]=s;c[Q+180268>>2]=s;s=c[2431694]|0;c[Q+49200>>2]=s;c[Q+114736>>2]=s;c[Q+180272>>2]=s;x=s+1024|0;c[Q+49204>>2]=x;c[Q+114740>>2]=x;c[Q+180276>>2]=x;x=s+2048|0;c[Q+49208>>2]=x;c[Q+114744>>2]=x;c[Q+180280>>2]=x;x=s+3072|0;c[Q+49212>>2]=x;c[Q+114748>>2]=x;c[Q+180284>>2]=x;c[Q+118784>>2]=9720656;c[Q+90112>>2]=9720536;c[Q+196608>>2]=1624;c[Q+196688>>2]=3462;c[Q+196648>>2]=2896;c[Q+196728>>2]=1274;x=c[3532592]|0;if((x|0)!=0){gGC(x|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;x=c[2385358]|0;c[2438998]=x;s=a[9688]|0?534:0;c[2438999]=x+(s<<1);c[2439e3]=x+(s<<1<<1);c[2439001]=x+((s*3|0)<<1);c[2439002]=x+(s<<2<<1);c[2439003]=x+((s*5|0)<<1);s=a[9680]|0?32e3:0;c[3542220]=11200;x=c[2113008]|0;if((x|0)==0){gGz(14168888,0,252);c[3542223]=s;c[3542224]=2256;c[3542225]=3114;c[3542226]=0;c[3542227]=0;c[3542234]=~~((+(s|0)*32768.0*8.0+1.0e6)/2.0e6);w=31;R=32767.0;while(1){c[14169012+(w<<2)>>2]=~~(R+.5);y=w-1|0;if((y|0)>0){w=y;R=R/1.188502227}else{break}}c[3542253]=0;h[1771269]=1.0;h[1771270]=1.0;h[1771271]=1.0;c[3542574]=3;c[3542575]=3;c[3542576]=3;mB(0);w=(c[2113008]|0)+1|0;c[2113008]=w;S=w;T=a[9680]|0?32e3:0}else{S=x;T=s}c[3542220]=11200;if((S|0)==1){gGz(14169140,0,252);c[3542286]=T;gGz(14169148,0,16);c[3542297]=~~((+(T|0)*32768.0*8.0+1.0e6)/2.0e6);w=31;R=32767.0;while(1){c[14169264+(w<<2)>>2]=~~(R+.5);y=w-1|0;if((y|0)>0){w=y;R=R/1.188502227}else{break}}c[3542316]=0;h[1771272]=1.0;h[1771273]=1.0;h[1771274]=1.0;c[3542577]=3;c[3542578]=3;c[3542579]=3;mB(1);c[2113008]=(c[2113008]|0)+1}h[1771269]=1.0;c[3542574]=3;h[1771270]=1.0;c[3542575]=3;h[1771271]=1.0;c[3542576]=3;h[1771272]=1.0;c[3542577]=3;h[1771273]=1.0;c[3542578]=3;h[1771274]=1.0;c[3542579]=3;Ux(0,15151,1);c[2407030]=256;c[2407068]=3;c[3541226]=5624;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];w=c[3532592]|0;if((w|0)!=0){gGC(9104152,w|0,280)|0}c[2113054]=c[2113060]}RI();w=c[2394]|0;s=c[14130368+(w<<2)>>2]|0;if((s|0)!=0){gGC(s|0,9104152,280)|0}c[8452240+(w<<2)>>2]=c[2113054];c[2394]=-1;b[4859460]=0;b[4859456]=0;b[4858644]=0;gGz(9720536,0,64);gGz(9720656,0,32);gGz(9720624,0,32);mB(0);mB(1);c[2113156]=0;a[9628264]=0;c[2407033]=0;w=c[3541206]|0;c[3541190]=w;c[3541198]=w;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=w+256;c[3541199]=w+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=w+512;c[3541200]=w+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=w+768;c[3541201]=w+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2443290]=0;b[4875360]=0;b[4860360]=0;E=0;i=e;return E|0}}while(0);c[2426682]=0;E=1;i=e;return E|0}function eAh(){c[2113008]=0;c[2076598]=0;c[2383582]=0;Uw(0);eBw();return 0}function eAi(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;c[2433548]=0;if((a[9757888]|0)!=0){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;b[4859460]=0;b[4859456]=0;b[4858644]=0;gGz(9720536,0,64);gGz(9720656,0,32);gGz(9720624,0,32);mB(0);mB(1);c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];c[2113156]=0;a[9628264]=0;c[2407033]=0;d=c[3541206]|0;c[3541190]=d;c[3541198]=d;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=d+256;c[3541199]=d+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=d+512;c[3541200]=d+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=d+768;c[3541201]=d+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2443290]=0}eBB();a[6518192]=1;c[2444064]=0;d=0;e=(c[2394]|0)==0;while(1){if(!e){c[2394]=0;c[2112932]=c[3532596];f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060]}f=d+1|0;g=(ag(a[6518192]|0?2e5:0,f)|0)/10|0;h=g-(c[2444064]|0)|0;c[2438180]=h;c[2113056]=h;g=RG(h)|0;c[2113054]=(c[2113054]|0)+g;c[2276108]=-1;c[2113056]=-1;c[2444064]=(c[2444064]|0)+g;do{if((d|0)==6){c[8452200+(c[2394]<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0>=1024){break}RH(4)}else if((d|0)==3){c[8452200+(c[2394]<<2)>>2]=8195;c[2276080]=768;if((c[2276079]|0)>>>0>=768){break}RH(3)}else if((d|0)==9){c[8452200+(c[2394]<<2)>>2]=8197;c[2276080]=1280;if((c[2276079]|0)>>>0>=1280){break}RH(5)}}while(0);g=c[2394]|0;h=c[14130368+(g<<2)>>2]|0;if((h|0)!=0){gGC(h|0,9104152,280)|0}c[8452240+(g<<2)>>2]=c[2113054];c[2394]=-1;i=c[2112964]|0;j=(i|0)==0;if(!j){g=a[9688]|0?53:0;mF(9755992,i+(c[2433548]<<1<<1)|0,g,0);c[2433548]=(c[2433548]|0)+g}if((f|0)<10){d=f;e=0}else{break}}if(!j){j=a[9688]|0?534:0;e=c[2433548]|0;if((j|0)!=(e|0)){mF(9755992,i+(e<<1<<1)|0,j-e|0,0)}Uu(0,i,j)}if((c[2112968]|0)==0){return 0}gu[c[3541226]&16383]();return 0}function eAj(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;d=i;i=i+64|0;e=d|0;f=d+32|0;g=d+48|0;h=(b|0)==0;if(!h){c[b>>2]=169586}if((a&64|0)!=0){j=d+16|0;do{if(!h){if((c[b>>2]|0)>=169110){break}c[b>>2]=169110}}while(0);if((c[2113008]|0)>0){h=e|0;k=e+4|0;l=e+8|0;m=e+12|0;n=0;do{cC(j|0,531144,(o=i,i=i+8|0,c[o>>2]=n,o)|0)|0;i=o;c[h>>2]=14168888+(n*252|0);c[k>>2]=252;c[l>>2]=0;c[m>>2]=j;gj[c[2076592]&4095](e)|0;n=n+1|0;}while((n|0)<(c[2113008]|0))}Ut(0);gGz(g|0,0,12);c[g>>2]=9773160;c[g+4>>2]=4;c[g+12>>2]=546800;n=c[2076592]|0;gj[n&4095](g)|0;gGz(f|0,0,12);c[f>>2]=9734192;c[f+4>>2]=4;c[f+12>>2]=492896;g=c[2076592]|0;gj[g&4095](f)|0}if((a&2|0)==0){eBA(a,b);i=d;return 0}f=c[3541206]|0;g=(c[2438662]|0)+(c[2443290]<<18)|0;gGC(f|0,g|0,262144)|0;eBA(a,b);i=d;return 0}function eAk(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2003668+(b*112|0)>>2];c[a+104>>2]=c[2003672+(b*112|0)>>2];c[a+108>>2]=c[2003676+(b*112|0)>>2];d=0;return d|0}function eAl(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=2003568+(b*112|0);e=0;return e|0}function eAm(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>43){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=2005248+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eAn(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5570348+(b*112|0)>>2];c[a+104>>2]=c[5570352+(b*112|0)>>2];c[a+108>>2]=c[5570356+(b*112|0)>>2];d=0;return d|0}function eAo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=5570248+(b*112|0);e=0;return e|0}function eAp(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=2002944+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eAq(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>51){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5571144+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eAr(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;e=i;i=i+480|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;c[2430154]=16384;c[2433414]=8192;c[2431698]=0;p=c[642608+(c[2436]<<2)>>2]|0;q=c[p+128>>2]|0;if((c[p+52>>2]&4|0)==0){c[2113068]=q;r=c[p+132>>2]|0;c[2113070]=r;c[2443814]=q;c[2440436]=r;s=q;t=r}else{c[2113070]=q;r=c[p+132>>2]|0;c[2113068]=r;c[2440436]=q;c[2443814]=r;s=r;t=q}q=ag(s<<1,t)|0;t=gGq(q)|0;c[2112926]=t;if((t|0)==0){u=0}else{gGz(t|0,0,q|0);u=0}while(1){if((u|0)>=1024){v=0;break}w=9638528+(u<<2)|0;if((c[w>>2]|0)==0){x=11597;break}else{u=u+1|0}}do{if((x|0)==11597){u=gGq(36864)|0;c[w>>2]=u;if((u|0)==0){v=0;break}gGz(u|0,0,36864);v=u}}while(0);c[3528200]=v;c[3541224]=9874;a[681672]=0;c[2426984]=4095;a[809552]=0;if(a[680496]|a[642536]|a[672472]){a[681672]=1;c[2426984]=65535;a[809552]=1;y=0}else{y=1}a[703944]=0;c[2429320]=8192;a[682248]=y;c[2429504]=0;y=c[2113068]|0;if((y|0)==256){c[2429504]=91}else if((y|0)==320){c[2429504]=51}a[726896]=0;v=c[2113070]|0;if((v|0)==232|(v|0)==224){a[726896]=1}a[6872968]=0;b[4875360]=0;b[4860360]=0;a[9707944]=0;c[2429320]=4096;a[703944]=1;c[2426682]=0;c[3527104]=0;c[2438684]=524288;c[2405618]=655360;c[3527106]=655360;c[2438686]=720896;c[2430152]=729088;c[2431696]=733184;c[2431686]=737280;c[2431684]=741376;c[2431694]=745472;c[2431692]=749568;c[2411564]=753664;c[2437676]=753664;w=(c[2430154]<<8)+753664|0;c[2439470]=w;u=w+(c[2433414]<<8)|0;c[2443298]=u;w=ag(v,y<<2)|0;q=u+w|0;c[2443299]=q;u=q+w|0;c[2433368]=u;q=u+w|0;c[2433369]=q;u=q+w|0;c[2430126]=u;w=ag(v,y)|0;y=u+w|0;c[2430127]=y;u=y+w|0;c[2437678]=u;w=u+16384|0;c[2414104]=w;u=w;w=0;while(1){if((w|0)>=1024){break}z=9638528+(w<<2)|0;if((c[z>>2]|0)==0){x=11609;break}else{w=w+1|0}}do{if((x|0)==11609){w=gGq(u)|0;c[z>>2]=w;if((w|0)==0){break}gGz(w|0,0,u|0);c[2426682]=w;gGz(w|0,0,u|0);c[3527104]=w;c[2438684]=w+524288;y=w+655360|0;c[2405618]=y;c[3527106]=y;c[2438686]=w+720896;c[2430152]=w+729088;c[2431696]=w+733184;y=c[2429320]|0;c[2431686]=w+(y+733184);c[2431684]=w+(y+737280);c[2431694]=w+(y+741376);c[2431692]=w+(y+745472);v=y+749568|0;y=w+v|0;c[2411564]=y;c[2437676]=y;y=(c[2430154]<<8)+v|0;c[2439470]=w+y;v=y+(c[2433414]<<8)|0;c[2443298]=w+v;y=c[2113068]|0;q=c[2113070]|0;t=ag(y<<2,q)|0;s=t+v|0;c[2443299]=w+s;v=s+t|0;c[2433368]=w+v;s=v+t|0;c[2433369]=w+s;v=s+t|0;c[2430126]=w+v;t=ag(q,y)|0;y=v+t|0;c[2430127]=w+y;v=y+t|0;c[2437678]=w+v;c[2414104]=w+(v+16384);v=0;while(1){if((v|0)>=1024){A=0;break}B=9638528+(v<<2)|0;if((c[B>>2]|0)==0){x=11614;break}else{v=v+1|0}}do{if((x|0)==11614){v=gGq(2097152)|0;c[B>>2]=v;if((v|0)==0){A=0;break}gGz(v|0,0,2097152);A=v}}while(0);c[2437674]=A;if((R6((c[3527104]|0)+1|0,0,2)|0)!=0){C=1;i=e;return C|0}if((R6(c[3527104]|0,1,2)|0)!=0){C=1;i=e;return C|0}v=c[2437674]|0;if((c[3542200]|0)==0){C=1;i=e;return C|0}w=n+108|0;c[w>>2]=0;t=n+100|0;c[t>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,2)|0;do{if((c[w>>2]|0)!=0){y=c[t>>2]|0;c[o>>2]=9534384;q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[q&16383](o,2,0)|0;if((y|0)<1){C=1;i=e;return C|0}if((gzL(v,0,2)|0)==0){break}else{C=1}i=e;return C|0}}while(0);v=(c[2437674]|0)+1048576|0;if((c[3542200]|0)==0){C=1;i=e;return C|0}t=l+108|0;c[t>>2]=0;w=l+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,3)|0;do{if((c[t>>2]|0)!=0){y=c[w>>2]|0;c[m>>2]=9534384;q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[q&16383](m,3,0)|0;if((y|0)<1){C=1;i=e;return C|0}if((gzL(v,0,3)|0)==0){break}else{C=1}i=e;return C|0}}while(0);v=c[2430154]|0;w=c[2437674]|0;t=c[2437676]|0;if((v|0)>0){y=0;do{q=y<<8;gGz(t+q|0,0,256);s=y<<10;r=0;do{p=1<<3-r;D=(c[703416+(r<<2)>>2]|0)+s|0;E=0;do{F=D+(c[3946808+(E<<2)>>2]|0)|0;G=(E<<4)+q|0;H=0;do{I=F+(c[3946872+(H<<2)>>2]|0)|0;if(((d[w+((I|0)/8|0)|0]|0)&128>>>((I&7)>>>0)|0)!=0){I=t+(G+H)|0;a[I]=(d[I]|0|p)&255}H=H+1|0;}while((H|0)<16);E=E+1|0;}while((E|0)<16);r=r+1|0;}while((r|0)<4);y=y+1|0;}while((y|0)<(v|0))}gGz(w|0,0,2097152);if((c[3542200]|0)==0){C=1;i=e;return C|0}v=j+108|0;c[v>>2]=0;y=j+100|0;c[y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,4)|0;do{if((c[v>>2]|0)!=0){t=c[y>>2]|0;c[k>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](k,4,0)|0;if((t|0)<1){C=1;i=e;return C|0}if((gzL(w,0,4)|0)==0){break}else{C=1}i=e;return C|0}}while(0);w=c[2437674]|0;if((w|0)==0){J=0}else{y=0;while(1){v=w+y|0;t=a[v]|0;a[v]=(t&255)>>>4|t<<4;t=y+1|0;if((t|0)<1048576){y=t}else{J=w;break}}}w=c[2433414]|0;y=c[2439470]|0;if((w|0)>0){t=0;while(1){v=t<<8;gGz(y+v|0,0,256);r=t<<10;q=0;do{s=1<<3-q;E=(c[703416+(q<<2)>>2]|0)+r|0;p=0;do{D=E+(c[3946808+(p<<2)>>2]|0)|0;H=(p<<4)+v|0;G=0;do{F=D+(c[3946872+(G<<2)>>2]|0)|0;if(((d[J+((F|0)/8|0)|0]|0)&128>>>((F&7)>>>0)|0)!=0){F=y+(H+G)|0;a[F]=(d[F]|0|s)&255}G=G+1|0;}while((G|0)<16);p=p+1|0;}while((p|0)<16);q=q+1|0;}while((q|0)<4);q=t+1|0;if((q|0)<(w|0)){t=q}else{K=J;break}}}else{K=J}t=0;while(1){if((t|0)>=1024){break}L=9638528+(t<<2)|0;if((c[L>>2]|0)==(K|0)){x=11655;break}else{t=t+1|0}}if((x|0)==11655){gGr(K);c[L>>2]=0}c[2437674]=0;t=c[2438684]|0;if((c[3542200]|0)==0){C=1;i=e;return C|0}w=f+108|0;c[w>>2]=0;y=f+100|0;c[y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,5)|0;do{if((c[w>>2]|0)!=0){q=c[y>>2]|0;c[g>>2]=9534384;v=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[v&16383](g,5,0)|0;if((q|0)<1){C=1;i=e;return C|0}if((gzL(t,0,5)|0)==0){break}else{C=1}i=e;return C|0}}while(0);fxU(0,425984);if((c[2394]|0)==0){M=c[2112932]|0}else{c[2394]=0;t=c[3532596]|0;c[2112932]=t;y=c[3532592]|0;if((y|0)!=0){gGC(9104152,y|0,280)|0}c[2113054]=c[2113060];M=t}t=c[3527104]|0;y=M|0;w=0;while(1){q=t+w|0;c[y>>2]=q;c[y+131072>>2]=q;q=w+1024|0;if(q>>>0>524287){break}else{y=y+4|0;w=q}}w=c[3527106]|0;y=M+12288|0;t=3145728;while(1){q=w+(t-3145728)|0;c[y>>2]=q;c[y+65536>>2]=q;c[y+131072>>2]=q;q=t+1024|0;if(q>>>0>3211263){break}else{y=y+4|0;t=q}}t=c[2430152]|0;c[M+20480>>2]=t;c[M+86016>>2]=t;c[M+151552>>2]=t;y=t+1024|0;c[M+20484>>2]=y;c[M+86020>>2]=y;c[M+151556>>2]=y;y=t+2048|0;c[M+20488>>2]=y;c[M+86024>>2]=y;c[M+151560>>2]=y;y=t+3072|0;c[M+20492>>2]=y;c[M+86028>>2]=y;c[M+151564>>2]=y;y=c[2431684]|0;c[M+24576>>2]=y;c[M+90112>>2]=y;c[M+155648>>2]=y;t=y+1024|0;c[M+24580>>2]=t;c[M+90116>>2]=t;c[M+155652>>2]=t;t=y+2048|0;c[M+24584>>2]=t;c[M+90120>>2]=t;c[M+155656>>2]=t;t=y+3072|0;c[M+24588>>2]=t;c[M+90124>>2]=t;c[M+155660>>2]=t;t=c[2431686]|0;c[M+24592>>2]=t;c[M+90128>>2]=t;c[M+155664>>2]=t;y=t+1024|0;c[M+24596>>2]=y;c[M+90132>>2]=y;c[M+155668>>2]=y;y=t+2048|0;c[M+24600>>2]=y;c[M+90136>>2]=y;c[M+155672>>2]=y;y=t+3072|0;c[M+24604>>2]=y;c[M+90140>>2]=y;c[M+155676>>2]=y;y=c[2431692]|0;c[M+24608>>2]=y;c[M+90144>>2]=y;c[M+155680>>2]=y;t=y+1024|0;c[M+24612>>2]=t;c[M+90148>>2]=t;c[M+155684>>2]=t;t=y+2048|0;c[M+24616>>2]=t;c[M+90152>>2]=t;c[M+155688>>2]=t;t=y+3072|0;c[M+24620>>2]=t;c[M+90156>>2]=t;c[M+155692>>2]=t;t=c[2431694]|0;c[M+24624>>2]=t;c[M+90160>>2]=t;c[M+155696>>2]=t;y=t+1024|0;c[M+24628>>2]=y;c[M+90164>>2]=y;c[M+155700>>2]=y;y=t+2048|0;c[M+24632>>2]=y;c[M+90168>>2]=y;c[M+155704>>2]=y;y=t+3072|0;c[M+24636>>2]=y;c[M+90172>>2]=y;c[M+155708>>2]=y;y=c[2431696]|0;c[M+28672>>2]=y;c[M+94208>>2]=y;c[M+159744>>2]=y;t=y+1024|0;c[M+28676>>2]=t;c[M+94212>>2]=t;c[M+159748>>2]=t;t=y+2048|0;c[M+28680>>2]=t;c[M+94216>>2]=t;c[M+159752>>2]=t;t=y+3072|0;c[M+28684>>2]=t;c[M+94220>>2]=t;c[M+159756>>2]=t;c[M+98304>>2]=9720656;c[M+102400>>2]=9720536;c[M+196608>>2]=2230;c[M+196688>>2]=108;c[M+196648>>2]=112;c[M+196728>>2]=1818;t=c[3532592]|0;if((t|0)!=0){gGC(t|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);t=c[2439330]|0;y=(t|0)==0;if(!y){w=t;gGC(9706056,w|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];w=c[3528484]|0;c[2076596]=w;q=c[2417276]|0;c[3541536]=q;c[1836236]=0;v=c[2438684]|0;r=0;p=0;while(1){c[t+76+(p<<2)>>2]=v+(p<<8);s=r+1&65535;if((s&65535)>127){N=0;O=0;break}else{r=s;p=s&65535}}while(1){p=v+(O<<8)|0;c[t+76+(O+512<<2)>>2]=p;c[t+76+(O+768<<2)>>2]=p;p=N+1&65535;if((p&65535)>127){break}else{N=p;O=p&65535}}v=c[2438686]|0;p=192;r=192;while(1){c[t+76+(r<<2)>>2]=v+((r<<8)-49152);s=p+1&65535;if((s&65535)>223){P=192;Q=192;break}else{p=s;r=s&65535}}while(1){c[t+76+(Q+256<<2)>>2]=v+((Q<<8)-49152);r=P+1&65535;if((r&65535)>223){R=192;S=192;break}else{P=r;Q=r&65535}}while(1){r=v+((S<<8)-49152)|0;c[t+76+(S+512<<2)>>2]=r;c[t+76+(S+768<<2)>>2]=r;r=R+1&65535;if((r&65535)>223){break}else{R=r;S=r&65535}}c[t+4172>>2]=2060;c[t+4176>>2]=1950;if(!y){v=t;gGC(v|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=w;c[2417276]=q;c[1836236]=-1;v=a[9680]|0;r=v?32e3:0;if(v){if(a[9624]|0){v=r*3|0;p=62500;while(1){if((p|0)>(v|0)){p=p>>1}else{T=1222;U=p;break}}}else{T=2462;U=r}c[2429380]=U;c[3542124]=T;mw(4e6,U);p=gGq(262144)|0;c[2406684]=p;gGz(p|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(4e6,11025)}h[745421]=1.0;c[2436794]=1;h[745420]=1.0;c[2436792]=2;c[3541226]=3674;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];p=c[3532592]|0;if((p|0)!=0){gGC(9104152,p|0,280)|0}c[2113054]=c[2113060]}RI();p=c[2394]|0;v=c[14130368+(p<<2)>>2]|0;if((v|0)!=0){gGC(v|0,9104152,280)|0}c[8452240+(p<<2)>>2]=c[2113054];c[2394]=-1;b[4859460]=0;b[4859456]=0;b[4858644]=0;gGz(9720536,0,64);gGz(9720656,0,32);gGz(9720624,0,32);p=c[2439330]|0;v=(p|0)==0;if(!v){q=p;gGC(9706056,q|0,76)|0}q=c[2438118]|0;c[2433530]=q;w=c[3528484]|0;c[2076596]=w;t=c[2417276]|0;c[3541536]=t;c[1836236]=0;gGz(9706056,0,76);if(!v){v=p;gGC(v|0,9706056,76)|0}c[2438118]=q;c[3528484]=w;c[2417276]=t;c[1836236]=-1;mx(0);c[2430150]=0;C=0;i=e;return C|0}}while(0);c[2426682]=0;C=1;i=e;return C|0}function eAs(){var a=0;fwZ();a=c[3531464]|0;c[a+44344>>2]=0;c[a+44348>>2]=0;if((a|0)!=0){gGr(a);c[3531464]=0}a=c[2406684]|0;if((a|0)==0){eBw();return 0}gGr(a);c[2406684]=0;eBw();return 0}function eAt(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;c[2433548]=0;if((a[9757888]|0)!=0){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;b[4859460]=0;b[4859456]=0;b[4858644]=0;gGz(9720536,0,64);gGz(9720656,0,32);gGz(9720624,0,32);d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;h=c[2417276]|0;c[3541536]=h;c[1836236]=0;gGz(9706056,0,76);if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=h;c[1836236]=-1;mx(0);c[2430150]=0}eBB();a[6518192]=1;a[6517952]=1;c[2444065]=0;c[2444064]=0;h=0;while(1){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060]}g=h+1|0;f=(ag(a[6518192]|0?2e5:0,g)|0)/10|0;e=f-(c[2444064]|0)|0;c[2438180]=e;c[2113056]=e;f=RG(e)|0;c[2113054]=(c[2113054]|0)+f;c[2276108]=-1;c[2113056]=-1;c[2444064]=(c[2444064]|0)+f;do{if((h|0)==3){c[8452200+(c[2394]<<2)>>2]=8195;c[2276080]=768;if((c[2276079]|0)>>>0>=768){break}RH(3)}else if((h|0)==6){c[8452200+(c[2394]<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0>=1024){break}RH(4)}else if((h|0)==9){c[8452200+(c[2394]<<2)>>2]=8197;c[2276080]=1280;if((c[2276079]|0)>>>0>=1280){break}RH(5)}}while(0);f=c[2394]|0;e=c[14130368+(f<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(f<<2)>>2]=c[2113054];c[2394]=-1;f=c[2439330]|0;if((f|0)!=0){e=f;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;e=c[2438118]|0;c[2433530]=e;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;d=(ag(a[6517952]|0?66666:0,g)|0)/10|0;i=c[2444065]|0;j=d-i|0;c[2438180]=j;do{if((j|0)<1){k=0;l=i;m=0;n=f;o=e}else{if((a[f+4188|0]|0)==0){d=gfc(j)|0;p=(c[2433530]|0)+d|0;c[2433530]=p;q=c[1836236]|0;k=d;l=c[2444065]|0;m=q;n=c[9757320+(q<<2)>>2]|0;o=p;break}else{p=e+j|0;c[2433530]=p;k=j;l=i;m=0;n=f;o=p;break}}}while(0);c[2438180]=k;c[2444065]=l+k;if((n|0)!=0){f=n;gGC(f|0,9706056,76)|0}c[9752472+(m<<2)>>2]=o;c[14113936+(m<<2)>>2]=c[2076596];c[9669104+(m<<2)>>2]=c[3541536];c[1836236]=-1;f=c[2112964]|0;if((f|0)!=0){i=a[9688]|0?53:0;j=f+(c[2433548]<<1<<1)|0;f=c[2439330]|0;if((f|0)!=0){e=f;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;gg[c[3542124]&4095](j,i);j=c[1836236]|0;e=c[9757320+(j<<2)>>2]|0;if((e|0)!=0){f=e;gGC(f|0,9706056,76)|0}c[9752472+(j<<2)>>2]=c[2433530];c[14113936+(j<<2)>>2]=c[2076596];c[9669104+(j<<2)>>2]=c[3541536];c[1836236]=-1;c[2433548]=(c[2433548]|0)+i}if((g|0)<10){h=g}else{break}}h=c[2112964]|0;do{if((h|0)!=0){m=a[9688]|0?534:0;o=c[2433548]|0;if((m|0)==(o|0)){break}n=c[2439330]|0;if((n|0)!=0){k=n;gGC(9706056,k|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;gg[c[3542124]&4095](h+(o<<1<<1)|0,m-o|0);o=c[1836236]|0;m=c[9757320+(o<<2)>>2]|0;if((m|0)!=0){k=m;gGC(k|0,9706056,76)|0}c[9752472+(o<<2)>>2]=c[2433530];c[14113936+(o<<2)>>2]=c[2076596];c[9669104+(o<<2)>>2]=c[3541536];c[1836236]=-1}}while(0);if((c[2112968]|0)==0){return 0}gu[c[3541226]&16383]();return 0}function eAu(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0;e=i;i=i+48|0;f=e|0;g=e+16|0;h=e+32|0;if((b|0)!=0){c[b>>2]=169586}if((a&64|0)==0){eBA(a,b);i=e;return 0}fw$(a);gGz(g|0,0,12);c[g>>2]=8453216;c[g+4>>2]=4;c[g+12>>2]=107480;gj[c[2076592]&4095](g)|0;gGz(f|0,0,12);c[f>>2]=14168504;c[f+4>>2]=256;c[f+12>>2]=476464;gj[c[2076592]&4095](f)|0;if((a&2|0)!=0){f=0;do{mv(0,f,d[14168504+f|0]|0);f=f+1|0;}while((f|0)<256)}gGz(h|0,0,12);c[h>>2]=9734192;c[h+4>>2]=4;c[h+12>>2]=492896;gj[c[2076592]&4095](h)|0;eBA(a,b);i=e;return 0}function eAv(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>27){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4230228+(b*112|0)>>2];c[a+104>>2]=c[4230232+(b*112|0)>>2];c[a+108>>2]=c[4230236+(b*112|0)>>2];d=0;return d|0}function eAw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<28&(d|0)==0)){e=1;return e|0}c[a>>2]=4230128+(b*112|0);e=0;return e|0}function eAx(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>23){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1309440+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eAy(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>24){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4233264+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eAz(){var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0;e=i;i=i+1560|0;f=e|0;g=e+112|0;h=e+120|0;j=e+232|0;k=e+240|0;l=e+352|0;m=e+360|0;n=e+472|0;o=e+480|0;p=e+592|0;q=e+600|0;r=e+712|0;s=e+720|0;t=e+832|0;u=e+840|0;v=e+952|0;w=e+960|0;x=e+1072|0;y=e+1080|0;z=e+1192|0;A=e+1200|0;B=e+1312|0;C=e+1320|0;D=e+1432|0;E=e+1440|0;F=e+1552|0;a[642536]=1;c[2430154]=122880;c[2433414]=8192;c[2431698]=8192;G=c[642608+(c[2436]<<2)>>2]|0;H=c[G+128>>2]|0;if((c[G+52>>2]&4|0)==0){c[2113068]=H;I=c[G+132>>2]|0;c[2113070]=I;c[2443814]=H;c[2440436]=I;J=H;K=I}else{c[2113070]=H;I=c[G+132>>2]|0;c[2113068]=I;c[2440436]=H;c[2443814]=I;J=I;K=H}H=ag(J<<1,K)|0;K=gGq(H)|0;c[2112926]=K;if((K|0)==0){L=0}else{gGz(K|0,0,H|0);L=0}while(1){if((L|0)>=1024){M=0;break}N=9638528+(L<<2)|0;if((c[N>>2]|0)==0){O=11818;break}else{L=L+1|0}}do{if((O|0)==11818){L=gGq(36864)|0;c[N>>2]=L;if((L|0)==0){M=0;break}gGz(L|0,0,36864);M=L}}while(0);c[3528200]=M;c[3541224]=9874;a[681672]=0;c[2426984]=4095;a[809552]=0;if(a[680496]|a[642536]|a[672472]){a[681672]=1;c[2426984]=65535;a[809552]=1;P=0}else{P=1}a[703944]=0;c[2429320]=8192;a[682248]=P;c[2429504]=0;P=c[2113068]|0;if((P|0)==320){c[2429504]=51}else if((P|0)==256){c[2429504]=91}a[726896]=0;P=c[2113070]|0;if((P|0)==232|(P|0)==224){a[726896]=1}a[6872968]=0;b[4875360]=0;b[4860360]=0;a[9707944]=0;c[3541224]=8078;c[2426682]=0;eBr();P=c[2414104]|0;M=0;while(1){if((M|0)>=1024){break}Q=9638528+(M<<2)|0;if((c[Q>>2]|0)==0){O=11830;break}else{M=M+1|0}}do{if((O|0)==11830){M=gGq(P)|0;c[Q>>2]=M;if((M|0)==0){break}gGz(M|0,0,P|0);c[2426682]=M;gGz(M|0,0,P|0);eBr();M=0;while(1){if((M|0)>=1024){R=0;break}S=9638528+(M<<2)|0;if((c[S>>2]|0)==0){O=11835;break}else{M=M+1|0}}do{if((O|0)==11835){M=gGq(31457280)|0;c[S>>2]=M;if((M|0)==0){R=0;break}gGz(M|0,0,31457280);R=M}}while(0);c[2437674]=R;if((R6((c[3527104]|0)+1|0,0,2)|0)!=0){T=1;i=e;return T|0}if((R6(c[3527104]|0,1,2)|0)!=0){T=1;i=e;return T|0}M=c[2437674]|0;if((c[3542200]|0)==0){T=1;i=e;return T|0}N=E+108|0;c[N>>2]=0;L=E+100|0;c[L>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](E,3)|0;do{if((c[N>>2]|0)!=0){H=c[L>>2]|0;c[F>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](F,3,0)|0;if((H|0)<1){T=1;i=e;return T|0}if((gzL(M,0,3)|0)==0){break}else{T=1}i=e;return T|0}}while(0);M=(c[2437674]|0)+2097152|0;if((c[3542200]|0)==0){T=1;i=e;return T|0}L=C+108|0;c[L>>2]=0;N=C+100|0;c[N>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](C,4)|0;do{if((c[L>>2]|0)!=0){H=c[N>>2]|0;c[D>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](D,4,0)|0;if((H|0)<1){T=1;i=e;return T|0}if((gzL(M,0,4)|0)==0){break}else{T=1}i=e;return T|0}}while(0);M=(c[2437674]|0)+4194304|0;if((c[3542200]|0)==0){T=1;i=e;return T|0}N=A+108|0;c[N>>2]=0;L=A+100|0;c[L>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](A,5)|0;do{if((c[N>>2]|0)!=0){H=c[L>>2]|0;c[B>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](B,5,0)|0;if((H|0)<1){T=1;i=e;return T|0}if((gzL(M,0,5)|0)==0){break}else{T=1}i=e;return T|0}}while(0);M=(c[2437674]|0)+6291456|0;if((c[3542200]|0)==0){T=1;i=e;return T|0}L=y+108|0;c[L>>2]=0;N=y+100|0;c[N>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](y,6)|0;do{if((c[L>>2]|0)!=0){H=c[N>>2]|0;c[z>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](z,6,0)|0;if((H|0)<1){T=1;i=e;return T|0}if((gzL(M,0,6)|0)==0){break}else{T=1}i=e;return T|0}}while(0);M=(c[2437674]|0)+8388608|0;if((c[3542200]|0)==0){T=1;i=e;return T|0}N=w+108|0;c[N>>2]=0;L=w+100|0;c[L>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](w,7)|0;do{if((c[N>>2]|0)!=0){H=c[L>>2]|0;c[x>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](x,7,0)|0;if((H|0)<1){T=1;i=e;return T|0}if((gzL(M,0,7)|0)==0){break}else{T=1}i=e;return T|0}}while(0);M=(c[2437674]|0)+10485760|0;if((c[3542200]|0)==0){T=1;i=e;return T|0}L=u+108|0;c[L>>2]=0;N=u+100|0;c[N>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](u,8)|0;do{if((c[L>>2]|0)!=0){H=c[N>>2]|0;c[v>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](v,8,0)|0;if((H|0)<1){T=1;i=e;return T|0}if((gzL(M,0,8)|0)==0){break}else{T=1}i=e;return T|0}}while(0);M=(c[2437674]|0)+12582912|0;if((c[3542200]|0)==0){T=1;i=e;return T|0}N=s+108|0;c[N>>2]=0;L=s+100|0;c[L>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](s,9)|0;do{if((c[N>>2]|0)!=0){H=c[L>>2]|0;c[t>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](t,9,0)|0;if((H|0)<1){T=1;i=e;return T|0}if((gzL(M,0,9)|0)==0){break}else{T=1}i=e;return T|0}}while(0);M=(c[2437674]|0)+14680064|0;if((c[3542200]|0)==0){T=1;i=e;return T|0}L=q+108|0;c[L>>2]=0;N=q+100|0;c[N>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](q,10)|0;do{if((c[L>>2]|0)!=0){H=c[N>>2]|0;c[r>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](r,10,0)|0;if((H|0)<1){T=1;i=e;return T|0}if((gzL(M,0,10)|0)==0){break}else{T=1}i=e;return T|0}}while(0);M=(c[2437674]|0)+16777216|0;if((c[3542200]|0)==0){T=1;i=e;return T|0}N=o+108|0;c[N>>2]=0;L=o+100|0;c[L>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](o,11)|0;do{if((c[N>>2]|0)!=0){H=c[L>>2]|0;c[p>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](p,11,0)|0;if((H|0)<1){T=1;i=e;return T|0}if((gzL(M,0,11)|0)==0){break}else{T=1}i=e;return T|0}}while(0);if((R6((c[2437674]|0)+18874368|0,12,2)|0)!=0){T=1;i=e;return T|0}if((R6((c[2437674]|0)+18874369|0,13,2)|0)!=0){T=1;i=e;return T|0}if((R6((c[2437674]|0)+20971520|0,14,2)|0)!=0){T=1;i=e;return T|0}if((R6((c[2437674]|0)+20971521|0,15,2)|0)!=0){T=1;i=e;return T|0}if((R6((c[2437674]|0)+23068672|0,16,2)|0)!=0){T=1;i=e;return T|0}if((R6((c[2437674]|0)+23068673|0,17,2)|0)!=0){T=1;i=e;return T|0}if((R6((c[2437674]|0)+25165824|0,18,2)|0)!=0){T=1;i=e;return T|0}if((R6((c[2437674]|0)+25165825|0,19,2)|0)!=0){T=1;i=e;return T|0}if((R6((c[2437674]|0)+27262976|0,20,2)|0)!=0){T=1;i=e;return T|0}if((R6((c[2437674]|0)+27262977|0,21,2)|0)!=0){T=1;i=e;return T|0}if((R6((c[2437674]|0)+29360128|0,22,2)|0)!=0){T=1;i=e;return T|0}if((R6((c[2437674]|0)+29360129|0,23,2)|0)!=0){T=1;i=e;return T|0}M=c[2430154]|0;L=c[2437674]|0;N=c[2437676]|0;if((M|0)>0){H=0;do{K=H<<8;gGz(N+K|0,0,256);J=H<<11;I=0;do{G=1<<7-I;U=(c[614800+(I<<2)>>2]|0)+J|0;V=0;do{W=U+(c[1942600+(V<<2)>>2]|0)|0;X=(V<<4)+K|0;Y=0;do{Z=W+(c[1942664+(Y<<2)>>2]|0)|0;if(((d[L+((Z|0)/8|0)|0]|0)&128>>>((Z&7)>>>0)|0)!=0){Z=N+(X+Y)|0;a[Z]=(d[Z]|0|G)&255}Y=Y+1|0;}while((Y|0)<16);V=V+1|0;}while((V|0)<16);I=I+1|0;}while((I|0)<8);H=H+1|0;}while((H|0)<(M|0))}gGz(L|0,0,31457280);if((c[3542200]|0)==0){T=1;i=e;return T|0}M=m+108|0;c[M>>2]=0;H=m+100|0;c[H>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,24)|0;do{if((c[M>>2]|0)!=0){N=c[H>>2]|0;c[n>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](n,24,0)|0;if((N|0)<1){T=1;i=e;return T|0}if((gzL(L,0,24)|0)==0){break}else{T=1}i=e;return T|0}}while(0);L=c[2437674]|0;if((L|0)==0){_=0}else{H=0;while(1){M=L+H|0;N=a[M]|0;a[M]=(N&255)>>>4|N<<4;N=H+1|0;if((N|0)<1048576){H=N}else{_=L;break}}}L=c[2433414]|0;H=c[2439470]|0;if((L|0)>0){N=0;while(1){M=N<<8;gGz(H+M|0,0,256);I=N<<10;K=0;do{J=1<<3-K;V=(c[703416+(K<<2)>>2]|0)+I|0;G=0;do{U=V+(c[3946808+(G<<2)>>2]|0)|0;Y=(G<<4)+M|0;X=0;do{W=U+(c[3946872+(X<<2)>>2]|0)|0;if(((d[_+((W|0)/8|0)|0]|0)&128>>>((W&7)>>>0)|0)!=0){W=H+(Y+X)|0;a[W]=(d[W]|0|J)&255}X=X+1|0;}while((X|0)<16);G=G+1|0;}while((G|0)<16);K=K+1|0;}while((K|0)<4);K=N+1|0;if((K|0)<(L|0)){N=K}else{$=_;break}}}else{$=_}gGz($|0,0,31457280);if((c[3542200]|0)==0){T=1;i=e;return T|0}N=k+108|0;c[N>>2]=0;L=k+100|0;c[L>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,25)|0;do{if((c[N>>2]|0)!=0){H=c[L>>2]|0;c[l>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](l,25,0)|0;if((H|0)<1){T=1;i=e;return T|0}if((gzL($,0,25)|0)==0){break}else{T=1}i=e;return T|0}}while(0);L=c[2437674]|0;if((L|0)==0){aa=0}else{N=0;while(1){H=L+N|0;K=a[H]|0;a[H]=(K&255)>>>4|K<<4;K=N+1|0;if((K|0)<1048576){N=K}else{aa=L;break}}}L=c[2431698]|0;N=c[2438688]|0;if((L|0)>0){K=0;while(1){H=K<<8;gGz(N+H|0,0,256);M=K<<10;I=0;do{G=1<<3-I;J=(c[703416+(I<<2)>>2]|0)+M|0;V=0;do{X=J+(c[3946808+(V<<2)>>2]|0)|0;Y=(V<<4)+H|0;U=0;do{W=X+(c[3946872+(U<<2)>>2]|0)|0;if(((d[aa+((W|0)/8|0)|0]|0)&128>>>((W&7)>>>0)|0)!=0){W=N+(Y+U)|0;a[W]=(d[W]|0|G)&255}U=U+1|0;}while((U|0)<16);V=V+1|0;}while((V|0)<16);I=I+1|0;}while((I|0)<4);I=K+1|0;if((I|0)<(L|0)){K=I}else{ab=aa;break}}}else{ab=aa}K=0;while(1){if((K|0)>=1024){break}ac=9638528+(K<<2)|0;if((c[ac>>2]|0)==(ab|0)){O=11932;break}else{K=K+1|0}}if((O|0)==11932){gGr(ab);c[ac>>2]=0}c[2437674]=0;K=c[2438662]|0;if((c[3542200]|0)==0){T=1;i=e;return T|0}L=h+108|0;c[L>>2]=0;N=h+100|0;c[N>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](h,26)|0;do{if((c[L>>2]|0)!=0){I=c[N>>2]|0;c[j>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](j,26,0)|0;if((I|0)<1){T=1;i=e;return T|0}if((gzL(K,0,26)|0)==0){break}else{T=1}i=e;return T|0}}while(0);K=c[2437642]|0;if((c[3542200]|0)==0){T=1;i=e;return T|0}N=f+108|0;c[N>>2]=0;L=f+100|0;c[L>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,27)|0;do{if((c[N>>2]|0)!=0){I=c[L>>2]|0;c[g>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](g,27,0)|0;if((I|0)<1){T=1;i=e;return T|0}if((gzL(K,0,27)|0)==0){break}else{T=1}i=e;return T|0}}while(0);K=c[2438662]|0;L=15;do{N=K+((L|0)<3?196608:L<<16)|0;I=L<<18;H=K+I|0;M=K+(I|196608)|0;gGC(M|0,N|0,65536)|0;gGC(H|0,K|0,196608)|0;L=L-1|0;}while((L|0)>0);c[3531910]=8504;c[3541226]=6078;eBs();if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];L=c[3532592]|0;if((L|0)!=0){gGC(9104152,L|0,280)|0}c[2113054]=c[2113060]}RI();L=c[2394]|0;K=c[14130368+(L<<2)>>2]|0;if((K|0)!=0){gGC(K|0,9104152,280)|0}c[8452240+(L<<2)>>2]=c[2113054];c[2394]=-1;b[4859460]=0;b[4859456]=0;b[4858644]=0;gGz(9720536,0,64);gGz(9720656,0,32);gGz(9720624,0,32);c[2113156]=0;a[9628264]=0;c[2407033]=0;L=c[3541206]|0;c[3541190]=L;c[3541198]=L;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=L+256;c[3541199]=L+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=L+512;c[3541200]=L+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=L+768;c[3541201]=L+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2113157]=0;a[9628420]=0;c[2407072]=0;K=L+1048576|0;c[3541194]=K;c[3541202]=K;gGz(c[2430122]|0,0,16384);c[2407080]=4;c[3541195]=L+1048832;c[3541203]=L+1114112;gGz(c[2430123]|0,0,16384);c[2407088]=4;c[3541196]=L+1049088;c[3541204]=L+1179648;gGz(c[2430124]|0,0,16384);c[2407096]=4;c[3541197]=L+1049344;c[3541205]=L+1245184;gGz(c[2430125]|0,0,16384);c[2407104]=4;c[2443290]=0;c[2443288]=0;L=9771688;c[L>>2]=0;c[L+4>>2]=0;T=0;i=e;return T|0}}while(0);c[2426682]=0;T=1;i=e;return T|0}function eAA(){Uw(0);Uw(1);eBw();return 0}function eAB(){var d=0,e=0,f=0;d=(c[2394]|0)==0;if((a[9757888]|0)==0){eBB();if(!d){e=12016}}else{if(!d){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;f=c[14130368+(d<<2)>>2]|0;if((f|0)!=0){gGC(f|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;b[4859460]=0;b[4859456]=0;b[4858644]=0;gGz(9720536,0,64);gGz(9720656,0,32);gGz(9720624,0,32);c[2113156]=0;a[9628264]=0;c[2407033]=0;d=c[3541206]|0;c[3541190]=d;c[3541198]=d;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=d+256;c[3541199]=d+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=d+512;c[3541200]=d+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=d+768;c[3541201]=d+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2113157]=0;a[9628420]=0;c[2407072]=0;f=d+1048576|0;c[3541194]=f;c[3541202]=f;gGz(c[2430122]|0,0,16384);c[2407080]=4;c[3541195]=d+1048832;c[3541203]=d+1114112;gGz(c[2430123]|0,0,16384);c[2407088]=4;c[3541196]=d+1049088;c[3541204]=d+1179648;gGz(c[2430124]|0,0,16384);c[2407096]=4;c[3541197]=d+1049344;c[3541205]=d+1245184;gGz(c[2430125]|0,0,16384);c[2407104]=4;c[2443290]=0;c[2443288]=0;d=9771688;c[d>>2]=0;c[d+4>>2]=0;eBB();e=12016}if((e|0)==12016){c[2394]=0;c[2112932]=c[3532596];e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060]}e=c[2392]|0;if((e|0)>=0){gGz(8452240,0,((e|0)>0?(e<<2)+4|0:4)|0)}c[2113054]=0;c[2113056]=66666;e=RG(66666)|0;c[2113054]=(c[2113054]|0)+e;c[2276108]=-1;c[2113056]=-1;c[8452200+(c[2394]<<2)>>2]=8195;c[2276080]=768;if((c[2276079]|0)>>>0<768){RH(3)}c[2113056]=66666;e=RG(66666)|0;c[2113054]=(c[2113054]|0)+e;c[2276108]=-1;c[2113056]=-1;c[8452200+(c[2394]<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0<1024){RH(4)}c[2113056]=66666;e=RG(66666)|0;c[2113054]=(c[2113054]|0)+e;c[2276108]=-1;c[2113056]=-1;c[8452200+(c[2394]<<2)>>2]=8197;c[2276080]=1280;if((c[2276079]|0)>>>0<1280){RH(5)}c[2113056]=66666;e=RG(66666)|0;d=(c[2113054]|0)+e|0;c[2113054]=d;c[2276108]=-1;c[2113056]=-1;e=c[2394]|0;f=c[14130368+(e<<2)>>2]|0;if((f|0)!=0){gGC(f|0,9104152,280)|0}c[8452240+(e<<2)>>2]=d;c[2394]=-1;d=c[2112964]|0;if((d|0)!=0){e=a[9688]|0?534:0;Uu(0,d,e);Uu(1,d,e)}if((c[2112968]|0)==0){return 0}gu[c[3541226]&16383]();return 0}function eAC(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=i;i=i+48|0;e=d|0;f=d+16|0;g=d+32|0;if((b|0)!=0){c[b>>2]=169586}if((a&64|0)!=0){Ut(0);Ut(1);gGz(g|0,0,12);c[g>>2]=9771688;c[g+4>>2]=8;c[g+12>>2]=548664;h=c[2076592]|0;gj[h&4095](g)|0;gGz(f|0,0,12);c[f>>2]=9773160;c[f+4>>2]=4;c[f+12>>2]=546800;g=c[2076592]|0;gj[g&4095](f)|0;gGz(e|0,0,12);c[e>>2]=9773152;c[e+4>>2]=4;c[e+12>>2]=545240;f=c[2076592]|0;gj[f&4095](e)|0}if((a&2|0)==0){eBA(a,b);i=d;return 0}e=c[3541206]|0;f=(c[2438662]|0)+(c[2443290]<<18)|0;gGC(e|0,f|0,262144)|0;f=e+1048576|0;e=(c[2437642]|0)+(c[2443288]<<18)|0;gGC(f|0,e|0,262144)|0;eBA(a,b);i=d;return 0}function eAD(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5562956+(b*112|0)>>2];c[a+104>>2]=c[5562960+(b*112|0)>>2];c[a+108>>2]=c[5562964+(b*112|0)>>2];d=0;return d|0}function eAE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=5562856+(b*112|0);e=0;return e|0}function eAF(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=2000464+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eAG(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5564424+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eAH(){var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;e=i;i=i+1080|0;f=e|0;g=e+112|0;h=e+120|0;j=e+232|0;k=e+240|0;l=e+352|0;m=e+360|0;n=e+472|0;o=e+480|0;p=e+592|0;q=e+600|0;r=e+712|0;s=e+720|0;t=e+832|0;u=e+840|0;v=e+952|0;w=e+960|0;x=e+1072|0;a[672472]=1;c[2430154]=20480;c[2433414]=16384;c[2431698]=16384;y=c[642608+(c[2436]<<2)>>2]|0;z=c[y+128>>2]|0;if((c[y+52>>2]&4|0)==0){c[2113068]=z;A=c[y+132>>2]|0;c[2113070]=A;c[2443814]=z;c[2440436]=A;B=z;C=A}else{c[2113070]=z;A=c[y+132>>2]|0;c[2113068]=A;c[2440436]=z;c[2443814]=A;B=A;C=z}z=ag(B<<1,C)|0;C=gGq(z)|0;c[2112926]=C;if((C|0)==0){D=0}else{gGz(C|0,0,z|0);D=0}while(1){if((D|0)>=1024){E=0;break}F=9638528+(D<<2)|0;if((c[F>>2]|0)==0){G=12078;break}else{D=D+1|0}}do{if((G|0)==12078){D=gGq(36864)|0;c[F>>2]=D;if((D|0)==0){E=0;break}gGz(D|0,0,36864);E=D}}while(0);c[3528200]=E;c[3541224]=9874;a[681672]=0;c[2426984]=4095;a[809552]=0;if(a[680496]|a[642536]|a[672472]){a[681672]=1;c[2426984]=65535;a[809552]=1;H=0}else{H=1}a[703944]=0;c[2429320]=8192;a[682248]=H;c[2429504]=0;H=c[2113068]|0;if((H|0)==320){c[2429504]=51}else if((H|0)==256){c[2429504]=91}a[726896]=0;H=c[2113070]|0;if((H|0)==232|(H|0)==224){a[726896]=1}a[6872968]=0;b[4875360]=0;b[4860360]=0;a[9707944]=0;c[3541224]=8078;c[2426682]=0;eBr();H=c[2414104]|0;E=0;while(1){if((E|0)>=1024){break}I=9638528+(E<<2)|0;if((c[I>>2]|0)==0){G=12090;break}else{E=E+1|0}}do{if((G|0)==12090){E=gGq(H)|0;c[I>>2]=E;if((E|0)==0){break}gGz(E|0,0,H|0);c[2426682]=E;gGz(E|0,0,H|0);eBr();E=0;while(1){if((E|0)>=1024){J=0;break}K=9638528+(E<<2)|0;if((c[K>>2]|0)==0){G=12095;break}else{E=E+1|0}}do{if((G|0)==12095){E=gGq(5242880)|0;c[K>>2]=E;if((E|0)==0){J=0;break}gGz(E|0,0,5242880);J=E}}while(0);c[2437674]=J;if((R6((c[3527104]|0)+1|0,0,2)|0)!=0){L=1;i=e;return L|0}if((R6(c[3527104]|0,1,2)|0)!=0){L=1;i=e;return L|0}E=c[2437674]|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}F=w+108|0;c[F>>2]=0;D=w+100|0;c[D>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](w,3)|0;do{if((c[F>>2]|0)!=0){z=c[D>>2]|0;c[x>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](x,3,0)|0;if((z|0)<1){L=1;i=e;return L|0}if((gzL(E,0,3)|0)==0){break}else{L=1}i=e;return L|0}}while(0);E=(c[2437674]|0)+2097152|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}D=u+108|0;c[D>>2]=0;F=u+100|0;c[F>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](u,4)|0;do{if((c[D>>2]|0)!=0){z=c[F>>2]|0;c[v>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](v,4,0)|0;if((z|0)<1){L=1;i=e;return L|0}if((gzL(E,0,4)|0)==0){break}else{L=1}i=e;return L|0}}while(0);E=(c[2437674]|0)+3145728|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}F=s+108|0;c[F>>2]=0;D=s+100|0;c[D>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](s,5)|0;do{if((c[F>>2]|0)!=0){z=c[D>>2]|0;c[t>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](t,5,0)|0;if((z|0)<1){L=1;i=e;return L|0}if((gzL(E,0,5)|0)==0){break}else{L=1}i=e;return L|0}}while(0);if((R6((c[2437674]|0)+4194304|0,6,2)|0)!=0){L=1;i=e;return L|0}if((R6((c[2437674]|0)+4194305|0,7,2)|0)!=0){L=1;i=e;return L|0}E=c[2430154]|0;D=c[2437674]|0;F=c[2437676]|0;if((E|0)>0){z=0;do{C=z<<8;gGz(F+C|0,0,256);B=z<<11;A=0;do{y=1<<7-A;M=(c[614800+(A<<2)>>2]|0)+B|0;N=0;do{O=M+(c[1942600+(N<<2)>>2]|0)|0;P=(N<<4)+C|0;Q=0;do{R=O+(c[1942664+(Q<<2)>>2]|0)|0;if(((d[D+((R|0)/8|0)|0]|0)&128>>>((R&7)>>>0)|0)!=0){R=F+(P+Q)|0;a[R]=(d[R]|0|y)&255}Q=Q+1|0;}while((Q|0)<16);N=N+1|0;}while((N|0)<16);A=A+1|0;}while((A|0)<8);z=z+1|0;}while((z|0)<(E|0))}gGz(D|0,0,5242880);if((c[3542200]|0)==0){L=1;i=e;return L|0}E=q+108|0;c[E>>2]=0;z=q+100|0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](q,8)|0;do{if((c[E>>2]|0)!=0){F=c[z>>2]|0;c[r>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](r,8,0)|0;if((F|0)<1){L=1;i=e;return L|0}if((gzL(D,0,8)|0)==0){break}else{L=1}i=e;return L|0}}while(0);D=c[2437674]|0;if((D|0)==0){S=0}else{z=0;while(1){E=D+z|0;F=a[E]|0;a[E]=(F&255)>>>4|F<<4;F=z+1|0;if((F|0)<1048576){z=F}else{S=D;break}}}D=c[2433414]|0;z=c[2439470]|0;if((D|0)>0){F=0;while(1){E=F<<8;gGz(z+E|0,0,256);A=F<<10;C=0;do{B=1<<3-C;N=(c[703416+(C<<2)>>2]|0)+A|0;y=0;do{M=N+(c[3946808+(y<<2)>>2]|0)|0;Q=(y<<4)+E|0;P=0;do{O=M+(c[3946872+(P<<2)>>2]|0)|0;if(((d[S+((O|0)/8|0)|0]|0)&128>>>((O&7)>>>0)|0)!=0){O=z+(Q+P)|0;a[O]=(d[O]|0|B)&255}P=P+1|0;}while((P|0)<16);y=y+1|0;}while((y|0)<16);C=C+1|0;}while((C|0)<4);C=F+1|0;if((C|0)<(D|0)){F=C}else{T=S;break}}}else{T=S}gGz(T|0,0,5242880);if((c[3542200]|0)==0){L=1;i=e;return L|0}F=o+108|0;c[F>>2]=0;D=o+100|0;c[D>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](o,9)|0;do{if((c[F>>2]|0)!=0){z=c[D>>2]|0;c[p>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](p,9,0)|0;if((z|0)<1){L=1;i=e;return L|0}if((gzL(T,0,9)|0)==0){break}else{L=1}i=e;return L|0}}while(0);D=c[2437674]|0;if((D|0)==0){U=0}else{F=0;while(1){z=D+F|0;C=a[z]|0;a[z]=(C&255)>>>4|C<<4;C=F+1|0;if((C|0)<1048576){F=C}else{U=D;break}}}D=c[2431698]|0;F=c[2438688]|0;if((D|0)>0){C=0;while(1){z=C<<8;gGz(F+z|0,0,256);E=C<<10;A=0;do{y=1<<3-A;B=(c[703416+(A<<2)>>2]|0)+E|0;N=0;do{P=B+(c[3946808+(N<<2)>>2]|0)|0;Q=(N<<4)+z|0;M=0;do{O=P+(c[3946872+(M<<2)>>2]|0)|0;if(((d[U+((O|0)/8|0)|0]|0)&128>>>((O&7)>>>0)|0)!=0){O=F+(Q+M)|0;a[O]=(d[O]|0|y)&255}M=M+1|0;}while((M|0)<16);N=N+1|0;}while((N|0)<16);A=A+1|0;}while((A|0)<4);A=C+1|0;if((A|0)<(D|0)){C=A}else{V=U;break}}}else{V=U}C=0;while(1){if((C|0)>=1024){break}W=9638528+(C<<2)|0;if((c[W>>2]|0)==(V|0)){G=12158;break}else{C=C+1|0}}if((G|0)==12158){gGr(V);c[W>>2]=0}c[2437674]=0;C=c[2438662]|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}D=m+108|0;c[D>>2]=0;F=m+100|0;c[F>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,10)|0;do{if((c[D>>2]|0)!=0){A=c[F>>2]|0;c[n>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](n,10,0)|0;if((A|0)<1){L=1;i=e;return L|0}if((gzL(C,0,10)|0)==0){break}else{L=1}i=e;return L|0}}while(0);C=c[2437642]|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}F=k+108|0;c[F>>2]=0;D=k+100|0;c[D>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,11)|0;do{if((c[F>>2]|0)!=0){A=c[D>>2]|0;c[l>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](l,11,0)|0;if((A|0)<1){L=1;i=e;return L|0}if((gzL(C,0,11)|0)==0){break}else{L=1}i=e;return L|0}}while(0);C=(c[2437642]|0)+1048576|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}D=h+108|0;c[D>>2]=0;F=h+100|0;c[F>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](h,12)|0;do{if((c[D>>2]|0)!=0){A=c[F>>2]|0;c[j>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](j,12,0)|0;if((A|0)<1){L=1;i=e;return L|0}if((gzL(C,0,12)|0)==0){break}else{L=1}i=e;return L|0}}while(0);C=(c[2437642]|0)+2097152|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}F=f+108|0;c[F>>2]=0;D=f+100|0;c[D>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,13)|0;do{if((c[F>>2]|0)!=0){A=c[D>>2]|0;c[g>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](g,13,0)|0;if((A|0)<1){L=1;i=e;return L|0}if((gzL(C,0,13)|0)==0){break}else{L=1}i=e;return L|0}}while(0);C=c[2438662]|0;D=15;do{F=C+((D|0)<3?196608:D<<16)|0;A=D<<18;z=C+A|0;E=C+(A|196608)|0;gGC(E|0,F|0,65536)|0;gGC(z|0,C|0,196608)|0;D=D-1|0;}while((D|0)>0);c[3531910]=9762;c[3541226]=6078;eBs();if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];D=c[3532592]|0;if((D|0)!=0){gGC(9104152,D|0,280)|0}c[2113054]=c[2113060]}RI();D=c[2394]|0;C=c[14130368+(D<<2)>>2]|0;if((C|0)!=0){gGC(C|0,9104152,280)|0}c[8452240+(D<<2)>>2]=c[2113054];c[2394]=-1;b[4859460]=0;b[4859456]=0;b[4858644]=0;gGz(9720536,0,64);gGz(9720656,0,32);gGz(9720624,0,32);c[2113156]=0;a[9628264]=0;c[2407033]=0;D=c[3541206]|0;c[3541190]=D;c[3541198]=D;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=D+256;c[3541199]=D+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=D+512;c[3541200]=D+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=D+768;c[3541201]=D+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2113157]=0;a[9628420]=0;c[2407072]=0;C=D+1048576|0;c[3541194]=C;c[3541202]=C;gGz(c[2430122]|0,0,16384);c[2407080]=4;c[3541195]=D+1048832;c[3541203]=D+1114112;gGz(c[2430123]|0,0,16384);c[2407088]=4;c[3541196]=D+1049088;c[3541204]=D+1179648;gGz(c[2430124]|0,0,16384);c[2407096]=4;c[3541197]=D+1049344;c[3541205]=D+1245184;gGz(c[2430125]|0,0,16384);c[2407104]=4;c[2443290]=0;c[2443288]=0;D=9771688;c[D>>2]=0;c[D+4>>2]=0;L=0;i=e;return L|0}}while(0);c[2426682]=0;L=1;i=e;return L|0}function eAI(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4000084+(b*112|0)>>2];c[a+104>>2]=c[4000088+(b*112|0)>>2];c[a+108>>2]=c[4000092+(b*112|0)>>2];d=0;return d|0}function eAJ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=3999984+(b*112|0);e=0;return e|0}function eAK(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1272264+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eAL(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>3){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4000880+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eAM(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0.0,Y=0,Z=0;e=i;i=i+960|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;c[2430154]=18432;c[2433414]=8192;c[2431698]=8192;x=c[642608+(c[2436]<<2)>>2]|0;y=c[x+128>>2]|0;if((c[x+52>>2]&4|0)==0){c[2113068]=y;z=c[x+132>>2]|0;c[2113070]=z;c[2443814]=y;c[2440436]=z;A=y;B=z}else{c[2113070]=y;z=c[x+132>>2]|0;c[2113068]=z;c[2440436]=y;c[2443814]=z;A=z;B=y}y=ag(A<<1,B)|0;B=gGq(y)|0;c[2112926]=B;if((B|0)==0){C=0}else{gGz(B|0,0,y|0);C=0}while(1){if((C|0)>=1024){D=0;break}E=9638528+(C<<2)|0;if((c[E>>2]|0)==0){F=12251;break}else{C=C+1|0}}do{if((F|0)==12251){C=gGq(36864)|0;c[E>>2]=C;if((C|0)==0){D=0;break}gGz(C|0,0,36864);D=C}}while(0);c[3528200]=D;c[3541224]=9874;a[681672]=0;c[2426984]=4095;a[809552]=0;if(a[680496]|a[642536]|a[672472]){a[681672]=1;c[2426984]=65535;a[809552]=1;G=0}else{G=1}a[703944]=0;c[2429320]=8192;a[682248]=G;c[2429504]=0;G=c[2113068]|0;if((G|0)==320){c[2429504]=51}else if((G|0)==256){c[2429504]=91}a[726896]=0;G=c[2113070]|0;if((G|0)==232|(G|0)==224){a[726896]=1}a[6872968]=0;b[4875360]=0;b[4860360]=0;a[9707944]=0;c[2426682]=0;eBi();G=c[2414104]|0;D=0;while(1){if((D|0)>=1024){break}H=9638528+(D<<2)|0;if((c[H>>2]|0)==0){F=12263;break}else{D=D+1|0}}do{if((F|0)==12263){D=gGq(G)|0;c[H>>2]=D;if((D|0)==0){break}gGz(D|0,0,G|0);c[2426682]=D;gGz(D|0,0,G|0);eBi();D=0;while(1){if((D|0)>=1024){I=0;break}J=9638528+(D<<2)|0;if((c[J>>2]|0)==0){F=12268;break}else{D=D+1|0}}do{if((F|0)==12268){D=gGq(2359296)|0;c[J>>2]=D;if((D|0)==0){I=0;break}gGz(D|0,0,2359296);I=D}}while(0);c[2437674]=I;if((R6((c[3527104]|0)+1|0,0,2)|0)!=0){K=1;i=e;return K|0}if((R6(c[3527104]|0,1,2)|0)!=0){K=1;i=e;return K|0}D=c[2437674]|0;if((c[3542200]|0)==0){K=1;i=e;return K|0}E=v+108|0;c[E>>2]=0;C=v+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,2)|0;do{if((c[E>>2]|0)!=0){y=c[C>>2]|0;c[w>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](w,2,0)|0;if((y|0)<1){K=1;i=e;return K|0}if((gzL(D,0,2)|0)==0){break}else{K=1}i=e;return K|0}}while(0);D=(c[2437674]|0)+524288|0;if((c[3542200]|0)==0){K=1;i=e;return K|0}C=t+108|0;c[C>>2]=0;E=t+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,3)|0;do{if((c[C>>2]|0)!=0){y=c[E>>2]|0;c[u>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](u,3,0)|0;if((y|0)<1){K=1;i=e;return K|0}if((gzL(D,0,3)|0)==0){break}else{K=1}i=e;return K|0}}while(0);D=(c[2437674]|0)+1048576|0;if((c[3542200]|0)==0){K=1;i=e;return K|0}E=r+108|0;c[E>>2]=0;C=r+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,2)|0;do{if((c[E>>2]|0)!=0){y=c[C>>2]|0;c[s>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](s,2,0)|0;if((y|0)<1){K=1;i=e;return K|0}if((gzL(D,0,2)|0)==0){break}else{K=1}i=e;return K|0}}while(0);D=(c[2437674]|0)+1572864|0;if((c[3542200]|0)==0){K=1;i=e;return K|0}C=p+108|0;c[C>>2]=0;E=p+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,3)|0;do{if((c[C>>2]|0)!=0){y=c[E>>2]|0;c[q>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](q,3,0)|0;if((y|0)<1){K=1;i=e;return K|0}if((gzL(D,0,3)|0)==0){break}else{K=1}i=e;return K|0}}while(0);D=(c[2437674]|0)+2097152|0;if((c[3542200]|0)==0){K=1;i=e;return K|0}E=n+108|0;c[E>>2]=0;C=n+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,4)|0;do{if((c[E>>2]|0)!=0){y=c[C>>2]|0;c[o>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](o,4,0)|0;if((y|0)<1){K=1;i=e;return K|0}if((gzL(D,0,4)|0)==0){break}else{K=1}i=e;return K|0}}while(0);D=c[2430154]|0;C=c[2437674]|0;E=c[2437676]|0;if((D|0)>0){y=0;do{B=y<<8;gGz(E+B|0,0,256);A=y<<10;z=0;do{x=1<<3-z;L=(c[703416+(z<<2)>>2]|0)+A|0;M=0;do{N=L+(c[3946808+(M<<2)>>2]|0)|0;O=(M<<4)+B|0;P=0;do{Q=N+(c[3946872+(P<<2)>>2]|0)|0;if(((d[C+((Q|0)/8|0)|0]|0)&128>>>((Q&7)>>>0)|0)!=0){Q=E+(O+P)|0;a[Q]=(d[Q]|0|x)&255}P=P+1|0;}while((P|0)<16);M=M+1|0;}while((M|0)<16);z=z+1|0;}while((z|0)<4);y=y+1|0;}while((y|0)<(D|0))}gGz(C|0,0,2359296);if((c[3542200]|0)==0){K=1;i=e;return K|0}D=l+108|0;c[D>>2]=0;y=l+100|0;c[y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,5)|0;do{if((c[D>>2]|0)!=0){E=c[y>>2]|0;c[m>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](m,5,0)|0;if((E|0)<1){K=1;i=e;return K|0}if((gzL(C,0,5)|0)==0){break}else{K=1}i=e;return K|0}}while(0);C=c[2437674]|0;if((C|0)==0){R=0}else{y=0;while(1){D=C+y|0;E=a[D]|0;a[D]=(E&255)>>>4|E<<4;E=y+1|0;if((E|0)<1048576){y=E}else{R=C;break}}}C=c[2433414]|0;y=c[2439470]|0;if((C|0)>0){E=0;while(1){D=E<<8;gGz(y+D|0,0,256);z=E<<10;B=0;do{A=1<<3-B;M=(c[703416+(B<<2)>>2]|0)+z|0;x=0;do{L=M+(c[3946808+(x<<2)>>2]|0)|0;P=(x<<4)+D|0;O=0;do{N=L+(c[3946872+(O<<2)>>2]|0)|0;if(((d[R+((N|0)/8|0)|0]|0)&128>>>((N&7)>>>0)|0)!=0){N=y+(P+O)|0;a[N]=(d[N]|0|A)&255}O=O+1|0;}while((O|0)<16);x=x+1|0;}while((x|0)<16);B=B+1|0;}while((B|0)<4);B=E+1|0;if((B|0)<(C|0)){E=B}else{S=R;break}}}else{S=R}gGz(S|0,0,2359296);if((c[3542200]|0)==0){K=1;i=e;return K|0}E=j+108|0;c[E>>2]=0;C=j+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,6)|0;do{if((c[E>>2]|0)!=0){y=c[C>>2]|0;c[k>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](k,6,0)|0;if((y|0)<1){K=1;i=e;return K|0}if((gzL(S,0,6)|0)==0){break}else{K=1}i=e;return K|0}}while(0);C=c[2437674]|0;if((C|0)==0){T=0}else{E=0;while(1){y=C+E|0;B=a[y]|0;a[y]=(B&255)>>>4|B<<4;B=E+1|0;if((B|0)<1048576){E=B}else{T=C;break}}}C=c[2431698]|0;E=c[2438688]|0;if((C|0)>0){B=0;while(1){y=B<<8;gGz(E+y|0,0,256);D=B<<10;z=0;do{x=1<<3-z;A=(c[703416+(z<<2)>>2]|0)+D|0;M=0;do{O=A+(c[3946808+(M<<2)>>2]|0)|0;P=(M<<4)+y|0;L=0;do{N=O+(c[3946872+(L<<2)>>2]|0)|0;if(((d[T+((N|0)/8|0)|0]|0)&128>>>((N&7)>>>0)|0)!=0){N=E+(P+L)|0;a[N]=(d[N]|0|x)&255}L=L+1|0;}while((L|0)<16);M=M+1|0;}while((M|0)<16);z=z+1|0;}while((z|0)<4);z=B+1|0;if((z|0)<(C|0)){B=z}else{U=T;break}}}else{U=T}gGz(U|0,0,2359296);if((c[3542200]|0)==0){K=1;i=e;return K|0}B=f+108|0;c[B>>2]=0;C=f+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,7)|0;do{if((c[B>>2]|0)!=0){E=c[C>>2]|0;c[g>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](g,7,0)|0;if((E|0)<1){K=1;i=e;return K|0}if((gzL(U,0,7)|0)==0){break}else{K=1}i=e;return K|0}}while(0);C=c[2438662]|0;B=c[2437674]|0;gGC(C|0,B|0,131072)|0;E=C+131072|0;z=B+131072|0;gGC(E|0,z|0,131072)|0;z=C+262144|0;gGC(z|0,B|0,131072)|0;z=C+393216|0;E=B+262144|0;gGC(z|0,E|0,131072)|0;E=C+524288|0;gGC(E|0,B|0,131072)|0;E=C+655360|0;z=B+393216|0;gGC(E|0,z|0,131072)|0;z=C+786432|0;gGC(z|0,B|0,131072)|0;z=C+917504|0;E=B+524288|0;gGC(z|0,E|0,131072)|0;E=C+1048576|0;gGC(E|0,B|0,131072)|0;E=C+1179648|0;z=B+655360|0;gGC(E|0,z|0,131072)|0;z=C+1310720|0;gGC(z|0,B|0,131072)|0;z=C+1441792|0;E=B+786432|0;gGC(z|0,E|0,131072)|0;E=C+1572864|0;gGC(E|0,B|0,131072)|0;E=C+1703936|0;C=B+917504|0;gGC(E|0,C|0,131072)|0;C=0;while(1){if((C|0)>=1024){break}V=9638528+(C<<2)|0;if((c[V>>2]|0)==(B|0)){F=12341;break}else{C=C+1|0}}if((F|0)==12341){gGr(B);c[V>>2]=0}c[2437674]=0;fxU(0,425984);if((c[2394]|0)==0){W=c[2112932]|0}else{c[2394]=0;C=c[3532596]|0;c[2112932]=C;E=c[3532592]|0;if((E|0)!=0){gGC(9104152,E|0,280)|0}c[2113054]=c[2113060];W=C}C=c[3527104]|0;E=W|0;z=0;while(1){y=C+z|0;c[E>>2]=y;c[E+131072>>2]=y;y=z+1024|0;if(y>>>0>524287){break}else{E=E+4|0;z=y}}z=c[3527106]|0;E=W+4096|0;C=1048576;while(1){B=z+(C-1048576)|0;c[E>>2]=B;c[E+65536>>2]=B;c[E+131072>>2]=B;B=C+1024|0;if(B>>>0>1114111){break}else{E=E+4|0;C=B}}C=c[2431684]|0;c[W+20480>>2]=C;c[W+86016>>2]=C;c[W+151552>>2]=C;E=C+1024|0;c[W+20484>>2]=E;c[W+86020>>2]=E;c[W+151556>>2]=E;E=C+2048|0;c[W+20488>>2]=E;c[W+86024>>2]=E;c[W+151560>>2]=E;E=C+3072|0;c[W+20492>>2]=E;c[W+86028>>2]=E;c[W+151564>>2]=E;E=c[2431686]|0;c[W+20496>>2]=E;c[W+86032>>2]=E;c[W+151568>>2]=E;C=E+1024|0;c[W+20500>>2]=C;c[W+86036>>2]=C;c[W+151572>>2]=C;C=E+2048|0;c[W+20504>>2]=C;c[W+86040>>2]=C;c[W+151576>>2]=C;C=E+3072|0;c[W+20508>>2]=C;c[W+86044>>2]=C;c[W+151580>>2]=C;C=c[2431692]|0;c[W+20512>>2]=C;c[W+86048>>2]=C;c[W+151584>>2]=C;E=C+1024|0;c[W+20516>>2]=E;c[W+86052>>2]=E;c[W+151588>>2]=E;E=C+2048|0;c[W+20520>>2]=E;c[W+86056>>2]=E;c[W+151592>>2]=E;E=C+3072|0;c[W+20524>>2]=E;c[W+86060>>2]=E;c[W+151596>>2]=E;E=c[2431694]|0;c[W+20528>>2]=E;c[W+86064>>2]=E;c[W+151600>>2]=E;C=E+1024|0;c[W+20532>>2]=C;c[W+86068>>2]=C;c[W+151604>>2]=C;C=E+2048|0;c[W+20536>>2]=C;c[W+86072>>2]=C;c[W+151608>>2]=C;C=E+3072|0;c[W+20540>>2]=C;c[W+86076>>2]=C;c[W+151612>>2]=C;C=c[2431680]|0;c[W+22528>>2]=C;c[W+88064>>2]=C;c[W+153600>>2]=C;E=C+1024|0;c[W+22532>>2]=E;c[W+88068>>2]=E;c[W+153604>>2]=E;E=C+2048|0;c[W+22536>>2]=E;c[W+88072>>2]=E;c[W+153608>>2]=E;E=C+3072|0;c[W+22540>>2]=E;c[W+88076>>2]=E;c[W+153612>>2]=E;E=c[2431682]|0;c[W+22544>>2]=E;c[W+88080>>2]=E;c[W+153616>>2]=E;C=E+1024|0;c[W+22548>>2]=C;c[W+88084>>2]=C;c[W+153620>>2]=C;C=E+2048|0;c[W+22552>>2]=C;c[W+88088>>2]=C;c[W+153624>>2]=C;C=E+3072|0;c[W+22556>>2]=C;c[W+88092>>2]=C;c[W+153628>>2]=C;C=c[2431688]|0;c[W+22560>>2]=C;c[W+88096>>2]=C;c[W+153632>>2]=C;E=C+1024|0;c[W+22564>>2]=E;c[W+88100>>2]=E;c[W+153636>>2]=E;E=C+2048|0;c[W+22568>>2]=E;c[W+88104>>2]=E;c[W+153640>>2]=E;E=C+3072|0;c[W+22572>>2]=E;c[W+88108>>2]=E;c[W+153644>>2]=E;E=c[2431690]|0;c[W+22576>>2]=E;c[W+88112>>2]=E;c[W+153648>>2]=E;C=E+1024|0;c[W+22580>>2]=C;c[W+88116>>2]=C;c[W+153652>>2]=C;C=E+2048|0;c[W+22584>>2]=C;c[W+88120>>2]=C;c[W+153656>>2]=C;C=E+3072|0;c[W+22588>>2]=C;c[W+88124>>2]=C;c[W+153660>>2]=C;C=c[2431696]|0;c[W+24576>>2]=C;c[W+90112>>2]=C;c[W+155648>>2]=C;E=C+1024|0;c[W+24580>>2]=E;c[W+90116>>2]=E;c[W+155652>>2]=E;E=C+2048|0;c[W+24584>>2]=E;c[W+90120>>2]=E;c[W+155656>>2]=E;E=C+3072|0;c[W+24588>>2]=E;c[W+90124>>2]=E;c[W+155660>>2]=E;E=C+4096|0;c[W+24592>>2]=E;c[W+90128>>2]=E;c[W+155664>>2]=E;E=C+5120|0;c[W+24596>>2]=E;c[W+90132>>2]=E;c[W+155668>>2]=E;E=C+6144|0;c[W+24600>>2]=E;c[W+90136>>2]=E;c[W+155672>>2]=E;E=C+7168|0;c[W+24604>>2]=E;c[W+90140>>2]=E;c[W+155676>>2]=E;E=c[2430152]|0;c[W+28672>>2]=E;c[W+94208>>2]=E;c[W+159744>>2]=E;C=E+1024|0;c[W+28676>>2]=C;c[W+94212>>2]=C;c[W+159748>>2]=C;C=E+2048|0;c[W+28680>>2]=C;c[W+94216>>2]=C;c[W+159752>>2]=C;C=E+3072|0;c[W+28684>>2]=C;c[W+94220>>2]=C;c[W+159756>>2]=C;c[W+98304>>2]=9720656;c[W+102400>>2]=9720536;c[W+110592>>2]=9720624;c[W+196608>>2]=1200;c[W+196688>>2]=3096;c[W+196648>>2]=3088;c[W+196728>>2]=2204;C=c[3532592]|0;if((C|0)!=0){gGC(C|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;C=c[2385358]|0;c[2438998]=C;E=a[9688]|0?534:0;c[2438999]=C+(E<<1);c[2439e3]=C+(E<<1<<1);c[2439001]=C+((E*3|0)<<1);c[2439002]=C+(E<<2<<1);c[2439003]=C+((E*5|0)<<1);a[5334064]=1;Tq(689736);E=a[9680]|0?32e3:0;c[3542220]=11200;C=c[2113008]|0;if((C|0)==0){gGz(14168888,0,252);c[3542223]=E;gGz(14168896,0,16);c[3542234]=~~((+(E|0)*32768.0*8.0+1.0e6)/2.0e6);z=31;X=32767.0;while(1){c[14169012+(z<<2)>>2]=~~(X+.5);B=z-1|0;if((B|0)>0){z=B;X=X/1.188502227}else{break}}c[3542253]=0;h[1771269]=1.0;h[1771270]=1.0;h[1771271]=1.0;c[3542574]=3;c[3542575]=3;c[3542576]=3;mB(0);z=(c[2113008]|0)+1|0;c[2113008]=z;Y=z;Z=a[9680]|0?32e3:0}else{Y=C;Z=E}c[3542220]=11200;if((Y|0)==1){gGz(14169140,0,252);c[3542286]=Z;c[3542287]=362;c[3542288]=0;c[3542289]=0;c[3542290]=1726;c[3542297]=~~((+(Z|0)*32768.0*8.0+1.0e6)/2.0e6);z=31;X=32767.0;while(1){c[14169264+(z<<2)>>2]=~~(X+.5);B=z-1|0;if((B|0)>0){z=B;X=X/1.188502227}else{break}}c[3542316]=0;h[1771272]=1.0;h[1771273]=1.0;h[1771274]=1.0;c[3542577]=3;c[3542578]=3;c[3542579]=3;mB(1);c[2113008]=(c[2113008]|0)+1}Ux(0,15151,1);c[2407030]=256;c[2407068]=3;c[3541226]=3514;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];z=c[3532592]|0;if((z|0)!=0){gGC(9104152,z|0,280)|0}c[2113054]=c[2113060]}RI();z=c[2394]|0;E=c[14130368+(z<<2)>>2]|0;if((E|0)!=0){gGC(E|0,9104152,280)|0}c[8452240+(z<<2)>>2]=c[2113054];c[2394]=-1;b[4859460]=0;b[4859456]=0;b[4858644]=0;gGz(9720536,0,64);gGz(9720656,0,32);gGz(9720624,0,32);mB(0);mB(1);c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];c[2113156]=0;a[9628264]=0;c[2407033]=0;z=c[3541206]|0;c[3541190]=z;c[3541198]=z;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=z+256;c[3541199]=z+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=z+512;c[3541200]=z+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=z+768;c[3541201]=z+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2443290]=0;K=0;i=e;return K|0}}while(0);c[2426682]=0;K=1;i=e;return K|0}function eAN(){c[2113008]=0;c[2076598]=0;c[2383582]=0;Uw(0);eBw();return 0}function eAO(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4253148+(b*112|0)>>2];c[a+104>>2]=c[4253152+(b*112|0)>>2];c[a+108>>2]=c[4253156+(b*112|0)>>2];d=0;return d|0}function eAP(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=4253048+(b*112|0);e=0;return e|0}function eAQ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7207108+(b*112|0)>>2];c[a+104>>2]=c[7207112+(b*112|0)>>2];c[a+108>>2]=c[7207116+(b*112|0)>>2];d=0;return d|0}function eAR(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=7207008+(b*112|0);e=0;return e|0}function eAS(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6283600+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eAT(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7208240+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eAU(){var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;e=i;i=i+720|0;f=e|0;g=e+112|0;h=e+120|0;j=e+232|0;k=e+240|0;l=e+352|0;m=e+360|0;n=e+472|0;o=e+480|0;p=e+592|0;q=e+600|0;r=e+712|0;a[680496]=1;c[2430154]=33792;c[2433414]=16384;c[2431698]=16384;s=c[642608+(c[2436]<<2)>>2]|0;t=c[s+128>>2]|0;if((c[s+52>>2]&4|0)==0){c[2113068]=t;u=c[s+132>>2]|0;c[2113070]=u;c[2443814]=t;c[2440436]=u;v=t;w=u}else{c[2113070]=t;u=c[s+132>>2]|0;c[2113068]=u;c[2440436]=t;c[2443814]=u;v=u;w=t}t=ag(v<<1,w)|0;w=gGq(t)|0;c[2112926]=w;if((w|0)==0){x=0}else{gGz(w|0,0,t|0);x=0}while(1){if((x|0)>=1024){y=0;break}z=9638528+(x<<2)|0;if((c[z>>2]|0)==0){A=12443;break}else{x=x+1|0}}do{if((A|0)==12443){x=gGq(36864)|0;c[z>>2]=x;if((x|0)==0){y=0;break}gGz(x|0,0,36864);y=x}}while(0);c[3528200]=y;c[3541224]=9874;a[681672]=0;c[2426984]=4095;a[809552]=0;if(a[680496]|a[642536]|a[672472]){a[681672]=1;c[2426984]=65535;a[809552]=1;B=0}else{B=1}a[703944]=0;c[2429320]=8192;a[682248]=B;c[2429504]=0;B=c[2113068]|0;if((B|0)==320){c[2429504]=51}else if((B|0)==256){c[2429504]=91}a[726896]=0;B=c[2113070]|0;if((B|0)==232|(B|0)==224){a[726896]=1}a[6872968]=0;b[4875360]=0;b[4860360]=0;a[9707944]=0;c[3541224]=8078;c[2426682]=0;eBr();B=c[2414104]|0;y=0;while(1){if((y|0)>=1024){break}C=9638528+(y<<2)|0;if((c[C>>2]|0)==0){A=12455;break}else{y=y+1|0}}do{if((A|0)==12455){y=gGq(B)|0;c[C>>2]=y;if((y|0)==0){break}gGz(y|0,0,B|0);c[2426682]=y;gGz(y|0,0,B|0);eBr();y=0;while(1){if((y|0)>=1024){D=0;break}E=9638528+(y<<2)|0;if((c[E>>2]|0)==0){A=12460;break}else{y=y+1|0}}do{if((A|0)==12460){y=gGq(8650752)|0;c[E>>2]=y;if((y|0)==0){D=0;break}gGz(y|0,0,8650752);D=y}}while(0);c[2437674]=D;if((R6((c[3527104]|0)+1|0,0,2)|0)!=0){F=1;i=e;return F|0}if((R6(c[3527104]|0,1,2)|0)!=0){F=1;i=e;return F|0}y=c[2437674]|0;if((c[3542200]|0)==0){F=1;i=e;return F|0}z=q+108|0;c[z>>2]=0;x=q+100|0;c[x>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](q,3)|0;do{if((c[z>>2]|0)!=0){t=c[x>>2]|0;c[r>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](r,3,0)|0;if((t|0)<1){F=1;i=e;return F|0}if((gzL(y,0,3)|0)==0){break}else{F=1}i=e;return F|0}}while(0);y=(c[2437674]|0)+2097152|0;if((c[3542200]|0)==0){F=1;i=e;return F|0}x=o+108|0;c[x>>2]=0;z=o+100|0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](o,4)|0;do{if((c[x>>2]|0)!=0){t=c[z>>2]|0;c[p>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](p,4,0)|0;if((t|0)<1){F=1;i=e;return F|0}if((gzL(y,0,4)|0)==0){break}else{F=1}i=e;return F|0}}while(0);y=(c[2437674]|0)+4194304|0;if((c[3542200]|0)==0){F=1;i=e;return F|0}z=m+108|0;c[z>>2]=0;x=m+100|0;c[x>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,5)|0;do{if((c[z>>2]|0)!=0){t=c[x>>2]|0;c[n>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](n,5,0)|0;if((t|0)<1){F=1;i=e;return F|0}if((gzL(y,0,5)|0)==0){break}else{F=1}i=e;return F|0}}while(0);y=(c[2437674]|0)+6291456|0;if((c[3542200]|0)==0){F=1;i=e;return F|0}x=k+108|0;c[x>>2]=0;z=k+100|0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,6)|0;do{if((c[x>>2]|0)!=0){t=c[z>>2]|0;c[l>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](l,6,0)|0;if((t|0)<1){F=1;i=e;return F|0}if((gzL(y,0,6)|0)==0){break}else{F=1}i=e;return F|0}}while(0);if((R6((c[2437674]|0)+8388609|0,7,2)|0)!=0){F=1;i=e;return F|0}if((R6((c[2437674]|0)+8388608|0,8,2)|0)!=0){F=1;i=e;return F|0}y=c[2430154]|0;z=c[2437674]|0;x=c[2437676]|0;if((y|0)>0){t=0;do{w=t<<8;gGz(x+w|0,0,256);v=t<<11;u=0;do{s=1<<7-u;G=(c[614800+(u<<2)>>2]|0)+v|0;H=0;do{I=G+(c[1942600+(H<<2)>>2]|0)|0;J=(H<<4)+w|0;K=0;do{L=I+(c[1942664+(K<<2)>>2]|0)|0;if(((d[z+((L|0)/8|0)|0]|0)&128>>>((L&7)>>>0)|0)!=0){L=x+(J+K)|0;a[L]=(d[L]|0|s)&255}K=K+1|0;}while((K|0)<16);H=H+1|0;}while((H|0)<16);u=u+1|0;}while((u|0)<8);t=t+1|0;}while((t|0)<(y|0))}gGz(z|0,0,8650752);if((c[3542200]|0)==0){F=1;i=e;return F|0}y=h+108|0;c[y>>2]=0;t=h+100|0;c[t>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](h,9)|0;do{if((c[y>>2]|0)!=0){x=c[t>>2]|0;c[j>>2]=9534384;u=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[u&16383](j,9,0)|0;if((x|0)<1){F=1;i=e;return F|0}if((gzL(z,0,9)|0)==0){break}else{F=1}i=e;return F|0}}while(0);z=c[2437674]|0;if((z|0)==0){M=0}else{t=0;while(1){y=z+t|0;x=a[y]|0;a[y]=(x&255)>>>4|x<<4;x=t+1|0;if((x|0)<2097152){t=x}else{M=z;break}}}z=c[2433414]|0;t=c[2439470]|0;if((z|0)>0){x=0;while(1){y=x<<8;gGz(t+y|0,0,256);u=x<<10;w=0;do{v=1<<3-w;H=(c[703416+(w<<2)>>2]|0)+u|0;s=0;do{G=H+(c[3946808+(s<<2)>>2]|0)|0;K=(s<<4)+y|0;J=0;do{I=G+(c[3946872+(J<<2)>>2]|0)|0;if(((d[M+((I|0)/8|0)|0]|0)&128>>>((I&7)>>>0)|0)!=0){I=t+(K+J)|0;a[I]=(d[I]|0|v)&255}J=J+1|0;}while((J|0)<16);s=s+1|0;}while((s|0)<16);w=w+1|0;}while((w|0)<4);w=x+1|0;if((w|0)<(z|0)){x=w}else{N=M;break}}}else{N=M}x=0;while(1){if((x|0)>=1024){O=t;P=z;break}Q=9638528+(x<<2)|0;if((c[Q>>2]|0)==(N|0)){A=12511;break}else{x=x+1|0}}if((A|0)==12511){gGr(N);c[Q>>2]=0;O=c[2439470]|0;P=c[2433414]|0}c[2437674]=0;x=c[2438688]|0;z=P<<8;gGC(x|0,O|0,z)|0;z=c[2438662]|0;if((c[3542200]|0)==0){F=1;i=e;return F|0}x=f+108|0;c[x>>2]=0;t=f+100|0;c[t>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,10)|0;do{if((c[x>>2]|0)!=0){w=c[t>>2]|0;c[g>>2]=9534384;y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[y&16383](g,10,0)|0;if((w|0)<1){F=1;i=e;return F|0}if((gzL(z,0,10)|0)==0){break}else{F=1}i=e;return F|0}}while(0);z=c[2438662]|0;t=15;do{x=z+((t|0)<3?196608:t<<16)|0;w=t<<18;y=z+w|0;u=z+(w|196608)|0;gGC(u|0,x|0,65536)|0;gGC(y|0,z|0,196608)|0;t=t-1|0;}while((t|0)>0);c[3531910]=7424;c[3541226]=12520;eBs();if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];t=c[3532592]|0;if((t|0)!=0){gGC(9104152,t|0,280)|0}c[2113054]=c[2113060]}RI();t=c[2394]|0;z=c[14130368+(t<<2)>>2]|0;if((z|0)!=0){gGC(z|0,9104152,280)|0}c[8452240+(t<<2)>>2]=c[2113054];c[2394]=-1;b[4859460]=0;b[4859456]=0;b[4858644]=0;gGz(9720536,0,64);gGz(9720656,0,32);gGz(9720624,0,32);c[2113156]=0;a[9628264]=0;c[2407033]=0;t=c[3541206]|0;c[3541190]=t;c[3541198]=t;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=t+256;c[3541199]=t+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=t+512;c[3541200]=t+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=t+768;c[3541201]=t+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2113157]=0;a[9628420]=0;c[2407072]=0;z=t+1048576|0;c[3541194]=z;c[3541202]=z;gGz(c[2430122]|0,0,16384);c[2407080]=4;c[3541195]=t+1048832;c[3541203]=t+1114112;gGz(c[2430123]|0,0,16384);c[2407088]=4;c[3541196]=t+1049088;c[3541204]=t+1179648;gGz(c[2430124]|0,0,16384);c[2407096]=4;c[3541197]=t+1049344;c[3541205]=t+1245184;gGz(c[2430125]|0,0,16384);c[2407104]=4;c[2443290]=0;c[2443288]=0;t=9771688;c[t>>2]=0;c[t+4>>2]=0;F=0;i=e;return F|0}}while(0);c[2426682]=0;F=1;i=e;return F|0}function eAV(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6881468+(b*112|0)>>2];c[a+104>>2]=c[6881472+(b*112|0)>>2];c[a+108>>2]=c[6881476+(b*112|0)>>2];d=0;return d|0}function eAW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=6881368+(b*112|0);e=0;return e|0}function eAX(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6880124+(b*112|0)>>2];c[a+104>>2]=c[6880128+(b*112|0)>>2];c[a+108>>2]=c[6880132+(b*112|0)>>2];d=0;return d|0}function eAY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=6880024+(b*112|0);e=0;return e|0}function eAZ(){var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;e=i;i=i+840|0;f=e|0;g=e+112|0;h=e+120|0;j=e+232|0;k=e+240|0;l=e+352|0;m=e+360|0;n=e+472|0;o=e+480|0;p=e+592|0;q=e+600|0;r=e+712|0;s=e+720|0;t=e+832|0;a[680496]=1;c[2430154]=32768;c[2433414]=16384;c[2431698]=16384;u=c[642608+(c[2436]<<2)>>2]|0;v=c[u+128>>2]|0;if((c[u+52>>2]&4|0)==0){c[2113068]=v;w=c[u+132>>2]|0;c[2113070]=w;c[2443814]=v;c[2440436]=w;x=v;y=w}else{c[2113070]=v;w=c[u+132>>2]|0;c[2113068]=w;c[2440436]=v;c[2443814]=w;x=w;y=v}v=ag(x<<1,y)|0;y=gGq(v)|0;c[2112926]=y;if((y|0)==0){z=0}else{gGz(y|0,0,v|0);z=0}while(1){if((z|0)>=1024){A=0;break}B=9638528+(z<<2)|0;if((c[B>>2]|0)==0){C=12581;break}else{z=z+1|0}}do{if((C|0)==12581){z=gGq(36864)|0;c[B>>2]=z;if((z|0)==0){A=0;break}gGz(z|0,0,36864);A=z}}while(0);c[3528200]=A;c[3541224]=9874;a[681672]=0;c[2426984]=4095;a[809552]=0;if(a[680496]|a[642536]|a[672472]){a[681672]=1;c[2426984]=65535;a[809552]=1;D=0}else{D=1}a[703944]=0;c[2429320]=8192;a[682248]=D;c[2429504]=0;D=c[2113068]|0;if((D|0)==256){c[2429504]=91}else if((D|0)==320){c[2429504]=51}a[726896]=0;D=c[2113070]|0;if((D|0)==232|(D|0)==224){a[726896]=1}a[6872968]=0;b[4875360]=0;b[4860360]=0;a[9707944]=0;c[3541224]=8078;c[2426682]=0;eBr();D=c[2414104]|0;A=0;while(1){if((A|0)>=1024){break}E=9638528+(A<<2)|0;if((c[E>>2]|0)==0){C=12593;break}else{A=A+1|0}}do{if((C|0)==12593){A=gGq(D)|0;c[E>>2]=A;if((A|0)==0){break}gGz(A|0,0,D|0);c[2426682]=A;gGz(A|0,0,D|0);eBr();A=0;while(1){if((A|0)>=1024){F=0;break}G=9638528+(A<<2)|0;if((c[G>>2]|0)==0){C=12598;break}else{A=A+1|0}}do{if((C|0)==12598){A=gGq(8388608)|0;c[G>>2]=A;if((A|0)==0){F=0;break}gGz(A|0,0,8388608);F=A}}while(0);c[2437674]=F;if((R6((c[3527104]|0)+1|0,0,2)|0)!=0){H=1;i=e;return H|0}if((R6(c[3527104]|0,1,2)|0)!=0){H=1;i=e;return H|0}if((R6((c[2437674]|0)+6291456|0,7,2)|0)!=0){H=1;i=e;return H|0}if((R6((c[2437674]|0)+6291457|0,8,2)|0)!=0){H=1;i=e;return H|0}A=c[2437674]|0;if((c[3542200]|0)==0){H=1;i=e;return H|0}B=s+108|0;c[B>>2]=0;z=s+100|0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](s,3)|0;do{if((c[B>>2]|0)!=0){v=c[z>>2]|0;c[t>>2]=9534384;y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[y&16383](t,3,0)|0;if((v|0)<1){H=1;i=e;return H|0}if((gzL(A,0,3)|0)==0){break}else{H=1}i=e;return H|0}}while(0);A=(c[2437674]|0)+2097152|0;if((c[3542200]|0)==0){H=1;i=e;return H|0}z=q+108|0;c[z>>2]=0;B=q+100|0;c[B>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](q,4)|0;do{if((c[z>>2]|0)!=0){v=c[B>>2]|0;c[r>>2]=9534384;y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[y&16383](r,4,0)|0;if((v|0)<1){H=1;i=e;return H|0}if((gzL(A,0,4)|0)==0){break}else{H=1}i=e;return H|0}}while(0);A=(c[2437674]|0)+4194304|0;if((c[3542200]|0)==0){H=1;i=e;return H|0}B=o+108|0;c[B>>2]=0;z=o+100|0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](o,5)|0;do{if((c[B>>2]|0)!=0){v=c[z>>2]|0;c[p>>2]=9534384;y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[y&16383](p,5,0)|0;if((v|0)<1){H=1;i=e;return H|0}if((gzL(A,0,5)|0)==0){break}else{H=1}i=e;return H|0}}while(0);A=(c[2437674]|0)+6291456|0;if((c[3542200]|0)==0){H=1;i=e;return H|0}z=m+108|0;c[z>>2]=0;B=m+100|0;c[B>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,6)|0;do{if((c[z>>2]|0)!=0){v=c[B>>2]|0;c[n>>2]=9534384;y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[y&16383](n,6,0)|0;if((v|0)<1){H=1;i=e;return H|0}if((gzL(A,0,6)|0)==0){break}else{H=1}i=e;return H|0}}while(0);A=c[2430154]|0;B=c[2437674]|0;z=c[2437676]|0;if((A|0)>0){v=0;do{y=v<<8;gGz(z+y|0,0,256);x=v<<11;w=0;do{u=1<<7-w;I=(c[614800+(w<<2)>>2]|0)+x|0;J=0;do{K=I+(c[1942600+(J<<2)>>2]|0)|0;L=(J<<4)+y|0;M=0;do{N=K+(c[1942664+(M<<2)>>2]|0)|0;if(((d[B+((N|0)/8|0)|0]|0)&128>>>((N&7)>>>0)|0)!=0){N=z+(L+M)|0;a[N]=(d[N]|0|u)&255}M=M+1|0;}while((M|0)<16);J=J+1|0;}while((J|0)<16);w=w+1|0;}while((w|0)<8);v=v+1|0;}while((v|0)<(A|0))}gGz(B|0,0,8388608);if((c[3542200]|0)==0){H=1;i=e;return H|0}A=k+108|0;c[A>>2]=0;v=k+100|0;c[v>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,9)|0;do{if((c[A>>2]|0)!=0){z=c[v>>2]|0;c[l>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](l,9,0)|0;if((z|0)<1){H=1;i=e;return H|0}if((gzL(B,0,9)|0)==0){break}else{H=1}i=e;return H|0}}while(0);B=c[2437674]|0;if((B|0)==0){O=0}else{v=0;while(1){A=B+v|0;z=a[A]|0;a[A]=(z&255)>>>4|z<<4;z=v+1|0;if((z|0)<2097152){v=z}else{O=B;break}}}B=c[2433414]|0;v=c[2439470]|0;if((B|0)>0){z=0;while(1){A=z<<8;gGz(v+A|0,0,256);w=z<<10;y=0;do{x=1<<3-y;J=(c[703416+(y<<2)>>2]|0)+w|0;u=0;do{I=J+(c[3946808+(u<<2)>>2]|0)|0;M=(u<<4)+A|0;L=0;do{K=I+(c[3946872+(L<<2)>>2]|0)|0;if(((d[O+((K|0)/8|0)|0]|0)&128>>>((K&7)>>>0)|0)!=0){K=v+(M+L)|0;a[K]=(d[K]|0|x)&255}L=L+1|0;}while((L|0)<16);u=u+1|0;}while((u|0)<16);y=y+1|0;}while((y|0)<4);y=z+1|0;if((y|0)<(B|0)){z=y}else{P=O;break}}}else{P=O}z=0;while(1){if((z|0)>=1024){Q=v;R=B;break}S=9638528+(z<<2)|0;if((c[S>>2]|0)==(P|0)){C=12649;break}else{z=z+1|0}}if((C|0)==12649){gGr(P);c[S>>2]=0;Q=c[2439470]|0;R=c[2433414]|0}c[2437674]=0;z=c[2438688]|0;B=R<<8;gGC(z|0,Q|0,B)|0;B=c[2438662]|0;if((c[3542200]|0)==0){H=1;i=e;return H|0}z=h+108|0;c[z>>2]=0;v=h+100|0;c[v>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](h,10)|0;do{if((c[z>>2]|0)!=0){y=c[v>>2]|0;c[j>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](j,10,0)|0;if((y|0)<1){H=1;i=e;return H|0}if((gzL(B,0,10)|0)==0){break}else{H=1}i=e;return H|0}}while(0);B=c[2437642]|0;if((c[3542200]|0)==0){H=1;i=e;return H|0}v=f+108|0;c[v>>2]=0;z=f+100|0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,11)|0;do{if((c[v>>2]|0)!=0){y=c[z>>2]|0;c[g>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](g,11,0)|0;if((y|0)<1){H=1;i=e;return H|0}if((gzL(B,0,11)|0)==0){break}else{H=1}i=e;return H|0}}while(0);B=c[2438662]|0;z=15;do{v=B+((z|0)<3?196608:z<<16)|0;y=z<<18;A=B+y|0;w=B+(y|196608)|0;gGC(w|0,v|0,65536)|0;gGC(A|0,B|0,196608)|0;z=z-1|0;}while((z|0)>0);eBs();c[3531910]=8034;c[3541226]=12520;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];z=c[3532592]|0;if((z|0)!=0){gGC(9104152,z|0,280)|0}c[2113054]=c[2113060]}RI();z=c[2394]|0;B=c[14130368+(z<<2)>>2]|0;if((B|0)!=0){gGC(B|0,9104152,280)|0}c[8452240+(z<<2)>>2]=c[2113054];c[2394]=-1;b[4859460]=0;b[4859456]=0;b[4858644]=0;gGz(9720536,0,64);gGz(9720656,0,32);gGz(9720624,0,32);c[2113156]=0;a[9628264]=0;c[2407033]=0;z=c[3541206]|0;c[3541190]=z;c[3541198]=z;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=z+256;c[3541199]=z+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=z+512;c[3541200]=z+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=z+768;c[3541201]=z+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2113157]=0;a[9628420]=0;c[2407072]=0;B=z+1048576|0;c[3541194]=B;c[3541202]=B;gGz(c[2430122]|0,0,16384);c[2407080]=4;c[3541195]=z+1048832;c[3541203]=z+1114112;gGz(c[2430123]|0,0,16384);c[2407088]=4;c[3541196]=z+1049088;c[3541204]=z+1179648;gGz(c[2430124]|0,0,16384);c[2407096]=4;c[3541197]=z+1049344;c[3541205]=z+1245184;gGz(c[2430125]|0,0,16384);c[2407104]=4;c[2443290]=0;c[2443288]=0;z=9771688;c[z>>2]=0;c[z+4>>2]=0;H=0;i=e;return H|0}}while(0);c[2426682]=0;H=1;i=e;return H|0}function eA_(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5369900+(b*112|0)>>2];c[a+104>>2]=c[5369904+(b*112|0)>>2];c[a+108>>2]=c[5369908+(b*112|0)>>2];d=0;return d|0}function eA$(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=5369800+(b*112|0);e=0;return e|0}function eA0(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6882700+(b*112|0)>>2];c[a+104>>2]=c[6882704+(b*112|0)>>2];c[a+108>>2]=c[6882708+(b*112|0)>>2];d=0;return d|0}function eA1(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=6882600+(b*112|0);e=0;return e|0}function eA2(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6884168+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eA3(){var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;e=i;i=i+840|0;f=e|0;g=e+112|0;h=e+120|0;j=e+232|0;k=e+240|0;l=e+352|0;m=e+360|0;n=e+472|0;o=e+480|0;p=e+592|0;q=e+600|0;r=e+712|0;s=e+720|0;t=e+832|0;a[680496]=1;c[2430154]=32768;c[2433414]=34816;c[2431698]=34816;u=c[642608+(c[2436]<<2)>>2]|0;v=c[u+128>>2]|0;if((c[u+52>>2]&4|0)==0){c[2113068]=v;w=c[u+132>>2]|0;c[2113070]=w;c[2443814]=v;c[2440436]=w;x=v;y=w}else{c[2113070]=v;w=c[u+132>>2]|0;c[2113068]=w;c[2440436]=v;c[2443814]=w;x=w;y=v}v=ag(x<<1,y)|0;y=gGq(v)|0;c[2112926]=y;if((y|0)==0){z=0}else{gGz(y|0,0,v|0);z=0}while(1){if((z|0)>=1024){A=0;break}B=9638528+(z<<2)|0;if((c[B>>2]|0)==0){C=12733;break}else{z=z+1|0}}do{if((C|0)==12733){z=gGq(36864)|0;c[B>>2]=z;if((z|0)==0){A=0;break}gGz(z|0,0,36864);A=z}}while(0);c[3528200]=A;c[3541224]=9874;a[681672]=0;c[2426984]=4095;a[809552]=0;if(a[680496]|a[642536]|a[672472]){a[681672]=1;c[2426984]=65535;a[809552]=1;D=0}else{D=1}a[703944]=0;c[2429320]=8192;a[682248]=D;c[2429504]=0;D=c[2113068]|0;if((D|0)==256){c[2429504]=91}else if((D|0)==320){c[2429504]=51}a[726896]=0;D=c[2113070]|0;if((D|0)==232|(D|0)==224){a[726896]=1}a[6872968]=0;b[4875360]=0;b[4860360]=0;a[9707944]=0;c[3541224]=8078;c[2426682]=0;eBr();D=c[2414104]|0;A=0;while(1){if((A|0)>=1024){break}E=9638528+(A<<2)|0;if((c[E>>2]|0)==0){C=12745;break}else{A=A+1|0}}do{if((C|0)==12745){A=gGq(D)|0;c[E>>2]=A;if((A|0)==0){break}gGz(A|0,0,D|0);c[2426682]=A;gGz(A|0,0,D|0);eBr();A=0;while(1){if((A|0)>=1024){F=0;break}G=9638528+(A<<2)|0;if((c[G>>2]|0)==0){C=12750;break}else{A=A+1|0}}do{if((C|0)==12750){A=gGq(8388608)|0;c[G>>2]=A;if((A|0)==0){F=0;break}gGz(A|0,0,8388608);F=A}}while(0);c[2437674]=F;if((R6((c[3527104]|0)+1|0,0,2)|0)!=0){H=1;i=e;return H|0}if((R6(c[3527104]|0,1,2)|0)!=0){H=1;i=e;return H|0}A=c[2437674]|0;if((c[3542200]|0)==0){H=1;i=e;return H|0}B=s+108|0;c[B>>2]=0;z=s+100|0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](s,3)|0;do{if((c[B>>2]|0)!=0){v=c[z>>2]|0;c[t>>2]=9534384;y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[y&16383](t,3,0)|0;if((v|0)<1){H=1;i=e;return H|0}if((gzL(A,0,3)|0)==0){break}else{H=1}i=e;return H|0}}while(0);A=(c[2437674]|0)+4194304|0;if((c[3542200]|0)==0){H=1;i=e;return H|0}z=q+108|0;c[z>>2]=0;B=q+100|0;c[B>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](q,4)|0;do{if((c[z>>2]|0)!=0){v=c[B>>2]|0;c[r>>2]=9534384;y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[y&16383](r,4,0)|0;if((v|0)<1){H=1;i=e;return H|0}if((gzL(A,0,4)|0)==0){break}else{H=1}i=e;return H|0}}while(0);A=(c[2437674]|0)+6291456|0;if((c[3542200]|0)==0){H=1;i=e;return H|0}B=o+108|0;c[B>>2]=0;z=o+100|0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](o,5)|0;do{if((c[B>>2]|0)!=0){v=c[z>>2]|0;c[p>>2]=9534384;y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[y&16383](p,5,0)|0;if((v|0)<1){H=1;i=e;return H|0}if((gzL(A,0,5)|0)==0){break}else{H=1}i=e;return H|0}}while(0);if((R6((c[2437674]|0)+7340032|0,6,2)|0)!=0){H=1;i=e;return H|0}if((R6((c[2437674]|0)+7340033|0,7,2)|0)!=0){H=1;i=e;return H|0}A=c[2430154]|0;z=c[2437674]|0;B=c[2437676]|0;if((A|0)>0){v=0;do{y=v<<8;gGz(B+y|0,0,256);x=v<<11;w=0;do{u=1<<7-w;I=(c[614800+(w<<2)>>2]|0)+x|0;J=0;do{K=I+(c[1942600+(J<<2)>>2]|0)|0;L=(J<<4)+y|0;M=0;do{N=K+(c[1942664+(M<<2)>>2]|0)|0;if(((d[z+((N|0)/8|0)|0]|0)&128>>>((N&7)>>>0)|0)!=0){N=B+(L+M)|0;a[N]=(d[N]|0|u)&255}M=M+1|0;}while((M|0)<16);J=J+1|0;}while((J|0)<16);w=w+1|0;}while((w|0)<8);v=v+1|0;}while((v|0)<(A|0))}gGz(z|0,0,8388608);if((c[3542200]|0)==0){H=1;i=e;return H|0}A=m+108|0;c[A>>2]=0;v=m+100|0;c[v>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,8)|0;do{if((c[A>>2]|0)!=0){B=c[v>>2]|0;c[n>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](n,8,0)|0;if((B|0)<1){H=1;i=e;return H|0}if((gzL(z,0,8)|0)==0){break}else{H=1}i=e;return H|0}}while(0);z=(c[2437674]|0)+2097152|0;if((c[3542200]|0)==0){H=1;i=e;return H|0}v=k+108|0;c[v>>2]=0;A=k+100|0;c[A>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,9)|0;do{if((c[v>>2]|0)!=0){B=c[A>>2]|0;c[l>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](l,9,0)|0;if((B|0)<1){H=1;i=e;return H|0}if((gzL(z,0,9)|0)==0){break}else{H=1}i=e;return H|0}}while(0);if((R6((c[2437674]|0)+4194304|0,10,2)|0)!=0){H=1;i=e;return H|0}if((R6((c[2437674]|0)+4194305|0,11,2)|0)!=0){H=1;i=e;return H|0}z=c[2437674]|0;if((z|0)==0){O=0}else{A=0;while(1){v=z+A|0;B=a[v]|0;a[v]=(B&255)>>>4|B<<4;B=A+1|0;if((B|0)<4456448){A=B}else{O=z;break}}}z=c[2433414]|0;A=c[2439470]|0;if((z|0)>0){B=0;while(1){v=B<<8;gGz(A+v|0,0,256);w=B<<10;y=0;do{x=1<<3-y;J=(c[703416+(y<<2)>>2]|0)+w|0;u=0;do{I=J+(c[3946808+(u<<2)>>2]|0)|0;M=(u<<4)+v|0;L=0;do{K=I+(c[3946872+(L<<2)>>2]|0)|0;if(((d[O+((K|0)/8|0)|0]|0)&128>>>((K&7)>>>0)|0)!=0){K=A+(M+L)|0;a[K]=(d[K]|0|x)&255}L=L+1|0;}while((L|0)<16);u=u+1|0;}while((u|0)<16);y=y+1|0;}while((y|0)<4);y=B+1|0;if((y|0)<(z|0)){B=y}else{P=O;break}}}else{P=O}B=0;while(1){if((B|0)>=1024){Q=A;R=z;break}S=9638528+(B<<2)|0;if((c[S>>2]|0)==(P|0)){C=12803;break}else{B=B+1|0}}if((C|0)==12803){gGr(P);c[S>>2]=0;Q=c[2439470]|0;R=c[2433414]|0}c[2437674]=0;B=c[2438688]|0;z=R<<8;gGC(B|0,Q|0,z)|0;z=c[2438662]|0;if((c[3542200]|0)==0){H=1;i=e;return H|0}B=h+108|0;c[B>>2]=0;A=h+100|0;c[A>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](h,12)|0;do{if((c[B>>2]|0)!=0){y=c[A>>2]|0;c[j>>2]=9534384;v=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[v&16383](j,12,0)|0;if((y|0)<1){H=1;i=e;return H|0}if((gzL(z,0,12)|0)==0){break}else{H=1}i=e;return H|0}}while(0);z=(c[2437642]|0)+262144|0;if((c[3542200]|0)==0){H=1;i=e;return H|0}A=f+108|0;c[A>>2]=0;B=f+100|0;c[B>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,13)|0;do{if((c[A>>2]|0)!=0){y=c[B>>2]|0;c[g>>2]=9534384;v=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[v&16383](g,13,0)|0;if((y|0)<1){H=1;i=e;return H|0}if((gzL(z,0,13)|0)==0){break}else{H=1}i=e;return H|0}}while(0);z=c[2438662]|0;B=15;do{A=z+((B|0)<3?196608:B<<16)|0;y=B<<18;v=z+y|0;w=z+(y|196608)|0;gGC(w|0,A|0,65536)|0;gGC(v|0,z|0,196608)|0;B=B-1|0;}while((B|0)>0);eBs();c[3531910]=8034;c[3541226]=12520;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];B=c[3532592]|0;if((B|0)!=0){gGC(9104152,B|0,280)|0}c[2113054]=c[2113060]}RI();B=c[2394]|0;z=c[14130368+(B<<2)>>2]|0;if((z|0)!=0){gGC(z|0,9104152,280)|0}c[8452240+(B<<2)>>2]=c[2113054];c[2394]=-1;b[4859460]=0;b[4859456]=0;b[4858644]=0;gGz(9720536,0,64);gGz(9720656,0,32);gGz(9720624,0,32);c[2113156]=0;a[9628264]=0;c[2407033]=0;B=c[3541206]|0;c[3541190]=B;c[3541198]=B;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=B+256;c[3541199]=B+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=B+512;c[3541200]=B+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=B+768;c[3541201]=B+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2113157]=0;a[9628420]=0;c[2407072]=0;z=B+1048576|0;c[3541194]=z;c[3541202]=z;gGz(c[2430122]|0,0,16384);c[2407080]=4;c[3541195]=B+1048832;c[3541203]=B+1114112;gGz(c[2430123]|0,0,16384);c[2407088]=4;c[3541196]=B+1049088;c[3541204]=B+1179648;gGz(c[2430124]|0,0,16384);c[2407096]=4;c[3541197]=B+1049344;c[3541205]=B+1245184;gGz(c[2430125]|0,0,16384);c[2407104]=4;c[2443290]=0;c[2443288]=0;B=9771688;c[B>>2]=0;c[B+4>>2]=0;H=0;i=e;return H|0}}while(0);c[2426682]=0;H=1;i=e;return H|0}function eA4(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6285604+(b*112|0)>>2];c[a+104>>2]=c[6285608+(b*112|0)>>2];c[a+108>>2]=c[6285612+(b*112|0)>>2];d=0;return d|0}function eA5(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=6285504+(b*112|0);e=0;return e|0}function eA6(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6284036+(b*112|0)>>2];c[a+104>>2]=c[6284040+(b*112|0)>>2];c[a+108>>2]=c[6284044+(b*112|0)>>2];d=0;return d|0}function eA7(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=6283936+(b*112|0);e=0;return e|0}function eA8(){var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;e=i;i=i+840|0;f=e|0;g=e+112|0;h=e+120|0;j=e+232|0;k=e+240|0;l=e+352|0;m=e+360|0;n=e+472|0;o=e+480|0;p=e+592|0;q=e+600|0;r=e+712|0;s=e+720|0;t=e+832|0;a[680496]=1;c[2430154]=32768;c[2433414]=34816;c[2431698]=34816;u=c[642608+(c[2436]<<2)>>2]|0;v=c[u+128>>2]|0;if((c[u+52>>2]&4|0)==0){c[2113068]=v;w=c[u+132>>2]|0;c[2113070]=w;c[2443814]=v;c[2440436]=w;x=v;y=w}else{c[2113070]=v;w=c[u+132>>2]|0;c[2113068]=w;c[2440436]=v;c[2443814]=w;x=w;y=v}v=ag(x<<1,y)|0;y=gGq(v)|0;c[2112926]=y;if((y|0)==0){z=0}else{gGz(y|0,0,v|0);z=0}while(1){if((z|0)>=1024){A=0;break}B=9638528+(z<<2)|0;if((c[B>>2]|0)==0){C=12882;break}else{z=z+1|0}}do{if((C|0)==12882){z=gGq(36864)|0;c[B>>2]=z;if((z|0)==0){A=0;break}gGz(z|0,0,36864);A=z}}while(0);c[3528200]=A;c[3541224]=9874;a[681672]=0;c[2426984]=4095;a[809552]=0;if(a[680496]|a[642536]|a[672472]){a[681672]=1;c[2426984]=65535;a[809552]=1;D=0}else{D=1}a[703944]=0;c[2429320]=8192;a[682248]=D;c[2429504]=0;D=c[2113068]|0;if((D|0)==320){c[2429504]=51}else if((D|0)==256){c[2429504]=91}a[726896]=0;D=c[2113070]|0;if((D|0)==232|(D|0)==224){a[726896]=1}a[6872968]=0;b[4875360]=0;b[4860360]=0;a[9707944]=0;c[3541224]=8078;c[2426682]=0;eBr();D=c[2414104]|0;A=0;while(1){if((A|0)>=1024){break}E=9638528+(A<<2)|0;if((c[E>>2]|0)==0){C=12894;break}else{A=A+1|0}}do{if((C|0)==12894){A=gGq(D)|0;c[E>>2]=A;if((A|0)==0){break}gGz(A|0,0,D|0);c[2426682]=A;gGz(A|0,0,D|0);eBr();A=0;while(1){if((A|0)>=1024){F=0;break}G=9638528+(A<<2)|0;if((c[G>>2]|0)==0){C=12899;break}else{A=A+1|0}}do{if((C|0)==12899){A=gGq(8388608)|0;c[G>>2]=A;if((A|0)==0){F=0;break}gGz(A|0,0,8388608);F=A}}while(0);c[2437674]=F;if((R6((c[3527104]|0)+1|0,0,2)|0)!=0){H=1;i=e;return H|0}if((R6(c[3527104]|0,1,2)|0)!=0){H=1;i=e;return H|0}A=c[2437674]|0;if((c[3542200]|0)==0){H=1;i=e;return H|0}B=s+108|0;c[B>>2]=0;z=s+100|0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](s,3)|0;do{if((c[B>>2]|0)!=0){v=c[z>>2]|0;c[t>>2]=9534384;y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[y&16383](t,3,0)|0;if((v|0)<1){H=1;i=e;return H|0}if((gzL(A,0,3)|0)==0){break}else{H=1}i=e;return H|0}}while(0);A=(c[2437674]|0)+4194304|0;if((c[3542200]|0)==0){H=1;i=e;return H|0}z=q+108|0;c[z>>2]=0;B=q+100|0;c[B>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](q,4)|0;do{if((c[z>>2]|0)!=0){v=c[B>>2]|0;c[r>>2]=9534384;y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[y&16383](r,4,0)|0;if((v|0)<1){H=1;i=e;return H|0}if((gzL(A,0,4)|0)==0){break}else{H=1}i=e;return H|0}}while(0);A=(c[2437674]|0)+6291456|0;if((c[3542200]|0)==0){H=1;i=e;return H|0}B=o+108|0;c[B>>2]=0;z=o+100|0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](o,5)|0;do{if((c[B>>2]|0)!=0){v=c[z>>2]|0;c[p>>2]=9534384;y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[y&16383](p,5,0)|0;if((v|0)<1){H=1;i=e;return H|0}if((gzL(A,0,5)|0)==0){break}else{H=1}i=e;return H|0}}while(0);if((R6((c[2437674]|0)+7340032|0,6,2)|0)!=0){H=1;i=e;return H|0}if((R6((c[2437674]|0)+7340033|0,7,2)|0)!=0){H=1;i=e;return H|0}A=c[2430154]|0;z=c[2437674]|0;B=c[2437676]|0;if((A|0)>0){v=0;do{y=v<<8;gGz(B+y|0,0,256);x=v<<11;w=0;do{u=1<<7-w;I=(c[614800+(w<<2)>>2]|0)+x|0;J=0;do{K=I+(c[1942600+(J<<2)>>2]|0)|0;L=(J<<4)+y|0;M=0;do{N=K+(c[1942664+(M<<2)>>2]|0)|0;if(((d[z+((N|0)/8|0)|0]|0)&128>>>((N&7)>>>0)|0)!=0){N=B+(L+M)|0;a[N]=(d[N]|0|u)&255}M=M+1|0;}while((M|0)<16);J=J+1|0;}while((J|0)<16);w=w+1|0;}while((w|0)<8);v=v+1|0;}while((v|0)<(A|0))}gGz(z|0,0,8388608);if((c[3542200]|0)==0){H=1;i=e;return H|0}A=m+108|0;c[A>>2]=0;v=m+100|0;c[v>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,8)|0;do{if((c[A>>2]|0)!=0){B=c[v>>2]|0;c[n>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](n,8,0)|0;if((B|0)<1){H=1;i=e;return H|0}if((gzL(z,0,8)|0)==0){break}else{H=1}i=e;return H|0}}while(0);z=(c[2437674]|0)+2097152|0;if((c[3542200]|0)==0){H=1;i=e;return H|0}v=k+108|0;c[v>>2]=0;A=k+100|0;c[A>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,9)|0;do{if((c[v>>2]|0)!=0){B=c[A>>2]|0;c[l>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](l,9,0)|0;if((B|0)<1){H=1;i=e;return H|0}if((gzL(z,0,9)|0)==0){break}else{H=1}i=e;return H|0}}while(0);if((R6((c[2437674]|0)+4194304|0,10,2)|0)!=0){H=1;i=e;return H|0}if((R6((c[2437674]|0)+4194305|0,11,2)|0)!=0){H=1;i=e;return H|0}z=c[2437674]|0;if((z|0)==0){O=0}else{A=0;while(1){v=z+A|0;B=a[v]|0;a[v]=(B&255)>>>4|B<<4;B=A+1|0;if((B|0)<4456448){A=B}else{O=z;break}}}z=c[2433414]|0;A=c[2439470]|0;if((z|0)>0){B=0;while(1){v=B<<8;gGz(A+v|0,0,256);w=B<<10;y=0;do{x=1<<3-y;J=(c[703416+(y<<2)>>2]|0)+w|0;u=0;do{I=J+(c[3946808+(u<<2)>>2]|0)|0;M=(u<<4)+v|0;L=0;do{K=I+(c[3946872+(L<<2)>>2]|0)|0;if(((d[O+((K|0)/8|0)|0]|0)&128>>>((K&7)>>>0)|0)!=0){K=A+(M+L)|0;a[K]=(d[K]|0|x)&255}L=L+1|0;}while((L|0)<16);u=u+1|0;}while((u|0)<16);y=y+1|0;}while((y|0)<4);y=B+1|0;if((y|0)<(z|0)){B=y}else{P=O;break}}}else{P=O}B=0;while(1){if((B|0)>=1024){Q=A;R=z;break}S=9638528+(B<<2)|0;if((c[S>>2]|0)==(P|0)){C=12952;break}else{B=B+1|0}}if((C|0)==12952){gGr(P);c[S>>2]=0;Q=c[2439470]|0;R=c[2433414]|0}c[2437674]=0;B=c[2438688]|0;z=R<<8;gGC(B|0,Q|0,z)|0;z=c[2438662]|0;if((c[3542200]|0)==0){H=1;i=e;return H|0}B=h+108|0;c[B>>2]=0;A=h+100|0;c[A>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](h,12)|0;do{if((c[B>>2]|0)!=0){y=c[A>>2]|0;c[j>>2]=9534384;v=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[v&16383](j,12,0)|0;if((y|0)<1){H=1;i=e;return H|0}if((gzL(z,0,12)|0)==0){break}else{H=1}i=e;return H|0}}while(0);z=c[2437642]|0;if((c[3542200]|0)==0){H=1;i=e;return H|0}A=f+108|0;c[A>>2]=0;B=f+100|0;c[B>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,13)|0;do{if((c[A>>2]|0)!=0){y=c[B>>2]|0;c[g>>2]=9534384;v=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[v&16383](g,13,0)|0;if((y|0)<1){H=1;i=e;return H|0}if((gzL(z,0,13)|0)==0){break}else{H=1}i=e;return H|0}}while(0);z=c[2438662]|0;B=15;do{A=z+((B|0)<3?196608:B<<16)|0;y=B<<18;v=z+y|0;w=z+(y|196608)|0;gGC(w|0,A|0,65536)|0;gGC(v|0,z|0,196608)|0;B=B-1|0;}while((B|0)>0);eBs();c[3531910]=8034;c[3541226]=12520;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];B=c[3532592]|0;if((B|0)!=0){gGC(9104152,B|0,280)|0}c[2113054]=c[2113060]}RI();B=c[2394]|0;z=c[14130368+(B<<2)>>2]|0;if((z|0)!=0){gGC(z|0,9104152,280)|0}c[8452240+(B<<2)>>2]=c[2113054];c[2394]=-1;b[4859460]=0;b[4859456]=0;b[4858644]=0;gGz(9720536,0,64);gGz(9720656,0,32);gGz(9720624,0,32);c[2113156]=0;a[9628264]=0;c[2407033]=0;B=c[3541206]|0;c[3541190]=B;c[3541198]=B;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=B+256;c[3541199]=B+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=B+512;c[3541200]=B+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=B+768;c[3541201]=B+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2113157]=0;a[9628420]=0;c[2407072]=0;z=B+1048576|0;c[3541194]=z;c[3541202]=z;gGz(c[2430122]|0,0,16384);c[2407080]=4;c[3541195]=B+1048832;c[3541203]=B+1114112;gGz(c[2430123]|0,0,16384);c[2407088]=4;c[3541196]=B+1049088;c[3541204]=B+1179648;gGz(c[2430124]|0,0,16384);c[2407096]=4;c[3541197]=B+1049344;c[3541205]=B+1245184;gGz(c[2430125]|0,0,16384);c[2407104]=4;c[2443290]=0;c[2443288]=0;B=9771688;c[B>>2]=0;c[B+4>>2]=0;H=0;i=e;return H|0}}while(0);c[2426682]=0;H=1;i=e;return H|0}function eA9(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3740252+(b*112|0)>>2];c[a+104>>2]=c[3740256+(b*112|0)>>2];c[a+108>>2]=c[3740260+(b*112|0)>>2];d=0;return d|0}function eBa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=3740152+(b*112|0);e=0;return e|0}function eBb(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=2000464+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eBc(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3741048+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eBd(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0.0,aa=0,ab=0;e=i;i=i+1200|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;a[642456]=1;c[2430154]=20480;c[2433414]=8192;c[2431698]=8192;B=c[642608+(c[2436]<<2)>>2]|0;C=c[B+128>>2]|0;if((c[B+52>>2]&4|0)==0){c[2113068]=C;D=c[B+132>>2]|0;c[2113070]=D;c[2443814]=C;c[2440436]=D;E=C;F=D}else{c[2113070]=C;D=c[B+132>>2]|0;c[2113068]=D;c[2440436]=C;c[2443814]=D;E=D;F=C}C=ag(E<<1,F)|0;F=gGq(C)|0;c[2112926]=F;if((F|0)==0){G=0}else{gGz(F|0,0,C|0);G=0}while(1){if((G|0)>=1024){H=0;break}I=9638528+(G<<2)|0;if((c[I>>2]|0)==0){J=13033;break}else{G=G+1|0}}do{if((J|0)==13033){G=gGq(36864)|0;c[I>>2]=G;if((G|0)==0){H=0;break}gGz(G|0,0,36864);H=G}}while(0);c[3528200]=H;c[3541224]=9874;a[681672]=0;c[2426984]=4095;a[809552]=0;if(a[680496]|a[642536]|a[672472]){a[681672]=1;c[2426984]=65535;a[809552]=1;K=0}else{K=1}a[703944]=0;c[2429320]=8192;a[682248]=K;c[2429504]=0;K=c[2113068]|0;if((K|0)==320){c[2429504]=51}else if((K|0)==256){c[2429504]=91}a[726896]=0;K=c[2113070]|0;if((K|0)==232|(K|0)==224){a[726896]=1}a[6872968]=0;b[4875360]=0;b[4860360]=0;a[9707944]=0;c[2426682]=0;eBi();K=c[2414104]|0;H=0;while(1){if((H|0)>=1024){break}L=9638528+(H<<2)|0;if((c[L>>2]|0)==0){J=13045;break}else{H=H+1|0}}do{if((J|0)==13045){H=gGq(K)|0;c[L>>2]=H;if((H|0)==0){break}gGz(H|0,0,K|0);c[2426682]=H;gGz(H|0,0,K|0);eBi();H=0;while(1){if((H|0)>=1024){M=0;break}N=9638528+(H<<2)|0;if((c[N>>2]|0)==0){J=13050;break}else{H=H+1|0}}do{if((J|0)==13050){H=gGq(2621440)|0;c[N>>2]=H;if((H|0)==0){M=0;break}gGz(H|0,0,2621440);M=H}}while(0);c[2437674]=M;if((R6((c[3527104]|0)+1|0,0,2)|0)!=0){O=1;i=e;return O|0}if((R6(c[3527104]|0,1,2)|0)!=0){O=1;i=e;return O|0}H=c[2437674]|0;if((c[3542200]|0)==0){O=1;i=e;return O|0}I=z+108|0;c[I>>2]=0;G=z+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,2)|0;do{if((c[I>>2]|0)!=0){C=c[G>>2]|0;c[A>>2]=9534384;F=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[F&16383](A,2,0)|0;if((C|0)<1){O=1;i=e;return O|0}if((gzL(H,0,2)|0)==0){break}else{O=1}i=e;return O|0}}while(0);H=(c[2437674]|0)+1048576|0;if((c[3542200]|0)==0){O=1;i=e;return O|0}G=x+108|0;c[G>>2]=0;I=x+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,3)|0;do{if((c[G>>2]|0)!=0){C=c[I>>2]|0;c[y>>2]=9534384;F=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[F&16383](y,3,0)|0;if((C|0)<1){O=1;i=e;return O|0}if((gzL(H,0,3)|0)==0){break}else{O=1}i=e;return O|0}}while(0);H=(c[2437674]|0)+1572864|0;if((c[3542200]|0)==0){O=1;i=e;return O|0}I=v+108|0;c[I>>2]=0;G=v+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,3)|0;do{if((c[I>>2]|0)!=0){C=c[G>>2]|0;c[w>>2]=9534384;F=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[F&16383](w,3,0)|0;if((C|0)<1){O=1;i=e;return O|0}if((gzL(H,0,3)|0)==0){break}else{O=1}i=e;return O|0}}while(0);H=(c[2437674]|0)+2097152|0;if((c[3542200]|0)==0){O=1;i=e;return O|0}G=t+108|0;c[G>>2]=0;I=t+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,4)|0;do{if((c[G>>2]|0)!=0){C=c[I>>2]|0;c[u>>2]=9534384;F=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[F&16383](u,4,0)|0;if((C|0)<1){O=1;i=e;return O|0}if((gzL(H,0,4)|0)==0){break}else{O=1}i=e;return O|0}}while(0);H=(c[2437674]|0)+2228224|0;if((c[3542200]|0)==0){O=1;i=e;return O|0}I=r+108|0;c[I>>2]=0;G=r+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,4)|0;do{if((c[I>>2]|0)!=0){C=c[G>>2]|0;c[s>>2]=9534384;F=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[F&16383](s,4,0)|0;if((C|0)<1){O=1;i=e;return O|0}if((gzL(H,0,4)|0)==0){break}else{O=1}i=e;return O|0}}while(0);H=(c[2437674]|0)+2359296|0;if((c[3542200]|0)==0){O=1;i=e;return O|0}G=p+108|0;c[G>>2]=0;I=p+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,4)|0;do{if((c[G>>2]|0)!=0){C=c[I>>2]|0;c[q>>2]=9534384;F=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[F&16383](q,4,0)|0;if((C|0)<1){O=1;i=e;return O|0}if((gzL(H,0,4)|0)==0){break}else{O=1}i=e;return O|0}}while(0);H=(c[2437674]|0)+2490368|0;if((c[3542200]|0)==0){O=1;i=e;return O|0}I=n+108|0;c[I>>2]=0;G=n+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,4)|0;do{if((c[I>>2]|0)!=0){C=c[G>>2]|0;c[o>>2]=9534384;F=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[F&16383](o,4,0)|0;if((C|0)<1){O=1;i=e;return O|0}if((gzL(H,0,4)|0)==0){break}else{O=1}i=e;return O|0}}while(0);H=c[2430154]|0;G=c[2437674]|0;I=c[2437676]|0;if((H|0)>0){C=0;do{F=C<<8;gGz(I+F|0,0,256);E=C<<10;D=0;do{B=1<<3-D;P=(c[703416+(D<<2)>>2]|0)+E|0;Q=0;do{R=P+(c[3946808+(Q<<2)>>2]|0)|0;S=(Q<<4)+F|0;T=0;do{U=R+(c[3946872+(T<<2)>>2]|0)|0;if(((d[G+((U|0)/8|0)|0]|0)&128>>>((U&7)>>>0)|0)!=0){U=I+(S+T)|0;a[U]=(d[U]|0|B)&255}T=T+1|0;}while((T|0)<16);Q=Q+1|0;}while((Q|0)<16);D=D+1|0;}while((D|0)<4);C=C+1|0;}while((C|0)<(H|0))}gGz(G|0,0,2621440);if((c[3542200]|0)==0){O=1;i=e;return O|0}H=l+108|0;c[H>>2]=0;C=l+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,5)|0;do{if((c[H>>2]|0)!=0){I=c[C>>2]|0;c[m>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](m,5,0)|0;if((I|0)<1){O=1;i=e;return O|0}if((gzL(G,0,5)|0)==0){break}else{O=1}i=e;return O|0}}while(0);G=c[2437674]|0;if((G|0)==0){V=0}else{C=0;while(1){H=G+C|0;I=a[H]|0;a[H]=(I&255)>>>4|I<<4;I=C+1|0;if((I|0)<1048576){C=I}else{V=G;break}}}G=c[2433414]|0;C=c[2439470]|0;if((G|0)>0){I=0;while(1){H=I<<8;gGz(C+H|0,0,256);D=I<<10;F=0;do{E=1<<3-F;Q=(c[703416+(F<<2)>>2]|0)+D|0;B=0;do{P=Q+(c[3946808+(B<<2)>>2]|0)|0;T=(B<<4)+H|0;S=0;do{R=P+(c[3946872+(S<<2)>>2]|0)|0;if(((d[V+((R|0)/8|0)|0]|0)&128>>>((R&7)>>>0)|0)!=0){R=C+(T+S)|0;a[R]=(d[R]|0|E)&255}S=S+1|0;}while((S|0)<16);B=B+1|0;}while((B|0)<16);F=F+1|0;}while((F|0)<4);F=I+1|0;if((F|0)<(G|0)){I=F}else{W=V;break}}}else{W=V}gGz(W|0,0,2621440);if((c[3542200]|0)==0){O=1;i=e;return O|0}I=j+108|0;c[I>>2]=0;G=j+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,6)|0;do{if((c[I>>2]|0)!=0){C=c[G>>2]|0;c[k>>2]=9534384;F=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[F&16383](k,6,0)|0;if((C|0)<1){O=1;i=e;return O|0}if((gzL(W,0,6)|0)==0){break}else{O=1}i=e;return O|0}}while(0);G=c[2437674]|0;if((G|0)==0){X=0}else{I=0;while(1){C=G+I|0;F=a[C]|0;a[C]=(F&255)>>>4|F<<4;F=I+1|0;if((F|0)<1048576){I=F}else{X=G;break}}}G=c[2431698]|0;I=c[2438688]|0;if((G|0)>0){F=0;while(1){C=F<<8;gGz(I+C|0,0,256);H=F<<10;D=0;do{B=1<<3-D;E=(c[703416+(D<<2)>>2]|0)+H|0;Q=0;do{S=E+(c[3946808+(Q<<2)>>2]|0)|0;T=(Q<<4)+C|0;P=0;do{R=S+(c[3946872+(P<<2)>>2]|0)|0;if(((d[X+((R|0)/8|0)|0]|0)&128>>>((R&7)>>>0)|0)!=0){R=I+(T+P)|0;a[R]=(d[R]|0|B)&255}P=P+1|0;}while((P|0)<16);Q=Q+1|0;}while((Q|0)<16);D=D+1|0;}while((D|0)<4);D=F+1|0;if((D|0)<(G|0)){F=D}else{Y=X;break}}}else{Y=X}F=0;while(1){if((F|0)>=1024){break}Z=9638528+(F<<2)|0;if((c[Z>>2]|0)==(Y|0)){J=13127;break}else{F=F+1|0}}if((J|0)==13127){gGr(Y);c[Z>>2]=0}c[2437674]=0;F=c[3541206]|0;if((c[3542200]|0)==0){O=1;i=e;return O|0}G=f+108|0;c[G>>2]=0;I=f+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,7)|0;do{if((c[G>>2]|0)!=0){D=c[I>>2]|0;c[g>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](g,7,0)|0;if((D|0)<1){O=1;i=e;return O|0}if((gzL(F,0,7)|0)==0){break}else{O=1}i=e;return O|0}}while(0);F=c[2438662]|0;I=c[3541206]|0;gGC(F|0,I|0,262144)|0;fxU(0,425984);if((c[2394]|0)==0){_=c[2112932]|0}else{c[2394]=0;I=c[3532596]|0;c[2112932]=I;F=c[3532592]|0;if((F|0)!=0){gGC(9104152,F|0,280)|0}c[2113054]=c[2113060];_=I}I=c[3527104]|0;F=_|0;G=0;while(1){D=I+G|0;c[F>>2]=D;c[F+131072>>2]=D;D=G+1024|0;if(D>>>0>524287){break}else{F=F+4|0;G=D}}G=c[3527106]|0;F=_+12288|0;I=3145728;while(1){D=G+(I-3145728)|0;c[F>>2]=D;c[F+65536>>2]=D;c[F+131072>>2]=D;D=I+1024|0;if(D>>>0>3211263){break}else{F=F+4|0;I=D}}I=c[2430152]|0;c[_+20480>>2]=I;c[_+86016>>2]=I;c[_+151552>>2]=I;F=I+1024|0;c[_+20484>>2]=F;c[_+86020>>2]=F;c[_+151556>>2]=F;F=I+2048|0;c[_+20488>>2]=F;c[_+86024>>2]=F;c[_+151560>>2]=F;F=I+3072|0;c[_+20492>>2]=F;c[_+86028>>2]=F;c[_+151564>>2]=F;F=c[2431684]|0;c[_+24576>>2]=F;c[_+90112>>2]=F;c[_+155648>>2]=F;I=F+1024|0;c[_+24580>>2]=I;c[_+90116>>2]=I;c[_+155652>>2]=I;I=F+2048|0;c[_+24584>>2]=I;c[_+90120>>2]=I;c[_+155656>>2]=I;I=F+3072|0;c[_+24588>>2]=I;c[_+90124>>2]=I;c[_+155660>>2]=I;I=c[2431686]|0;c[_+24592>>2]=I;c[_+90128>>2]=I;c[_+155664>>2]=I;F=I+1024|0;c[_+24596>>2]=F;c[_+90132>>2]=F;c[_+155668>>2]=F;F=I+2048|0;c[_+24600>>2]=F;c[_+90136>>2]=F;c[_+155672>>2]=F;F=I+3072|0;c[_+24604>>2]=F;c[_+90140>>2]=F;c[_+155676>>2]=F;F=c[2431692]|0;c[_+24608>>2]=F;c[_+90144>>2]=F;c[_+155680>>2]=F;I=F+1024|0;c[_+24612>>2]=I;c[_+90148>>2]=I;c[_+155684>>2]=I;I=F+2048|0;c[_+24616>>2]=I;c[_+90152>>2]=I;c[_+155688>>2]=I;I=F+3072|0;c[_+24620>>2]=I;c[_+90156>>2]=I;c[_+155692>>2]=I;I=c[2431694]|0;c[_+24624>>2]=I;c[_+90160>>2]=I;c[_+155696>>2]=I;F=I+1024|0;c[_+24628>>2]=F;c[_+90164>>2]=F;c[_+155700>>2]=F;F=I+2048|0;c[_+24632>>2]=F;c[_+90168>>2]=F;c[_+155704>>2]=F;F=I+3072|0;c[_+24636>>2]=F;c[_+90172>>2]=F;c[_+155708>>2]=F;F=c[2431680]|0;c[_+26624>>2]=F;c[_+92160>>2]=F;c[_+157696>>2]=F;I=F+1024|0;c[_+26628>>2]=I;c[_+92164>>2]=I;c[_+157700>>2]=I;I=F+2048|0;c[_+26632>>2]=I;c[_+92168>>2]=I;c[_+157704>>2]=I;I=F+3072|0;c[_+26636>>2]=I;c[_+92172>>2]=I;c[_+157708>>2]=I;I=c[2431682]|0;c[_+26640>>2]=I;c[_+92176>>2]=I;c[_+157712>>2]=I;F=I+1024|0;c[_+26644>>2]=F;c[_+92180>>2]=F;c[_+157716>>2]=F;F=I+2048|0;c[_+26648>>2]=F;c[_+92184>>2]=F;c[_+157720>>2]=F;F=I+3072|0;c[_+26652>>2]=F;c[_+92188>>2]=F;c[_+157724>>2]=F;F=c[2431688]|0;c[_+26656>>2]=F;c[_+92192>>2]=F;c[_+157728>>2]=F;I=F+1024|0;c[_+26660>>2]=I;c[_+92196>>2]=I;c[_+157732>>2]=I;I=F+2048|0;c[_+26664>>2]=I;c[_+92200>>2]=I;c[_+157736>>2]=I;I=F+3072|0;c[_+26668>>2]=I;c[_+92204>>2]=I;c[_+157740>>2]=I;I=c[2431690]|0;c[_+26672>>2]=I;c[_+92208>>2]=I;c[_+157744>>2]=I;F=I+1024|0;c[_+26676>>2]=F;c[_+92212>>2]=F;c[_+157748>>2]=F;F=I+2048|0;c[_+26680>>2]=F;c[_+92216>>2]=F;c[_+157752>>2]=F;F=I+3072|0;c[_+26684>>2]=F;c[_+92220>>2]=F;c[_+157756>>2]=F;F=c[2431696]|0;c[_+28672>>2]=F;c[_+94208>>2]=F;c[_+159744>>2]=F;I=F+1024|0;c[_+28676>>2]=I;c[_+94212>>2]=I;c[_+159748>>2]=I;I=F+2048|0;c[_+28680>>2]=I;c[_+94216>>2]=I;c[_+159752>>2]=I;I=F+3072|0;c[_+28684>>2]=I;c[_+94220>>2]=I;c[_+159756>>2]=I;I=F+4096|0;c[_+28688>>2]=I;c[_+94224>>2]=I;c[_+159760>>2]=I;I=F+5120|0;c[_+28692>>2]=I;c[_+94228>>2]=I;c[_+159764>>2]=I;I=F+6144|0;c[_+28696>>2]=I;c[_+94232>>2]=I;c[_+159768>>2]=I;I=F+7168|0;c[_+28700>>2]=I;c[_+94236>>2]=I;c[_+159772>>2]=I;c[_+98304>>2]=9720656;c[_+102400>>2]=9720536;c[_+110592>>2]=9720624;c[_+196608>>2]=2418;c[_+196688>>2]=3096;c[_+196648>>2]=3088;c[_+196728>>2]=2204;I=c[3532592]|0;if((I|0)!=0){gGC(I|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;I=c[2385358]|0;c[2438998]=I;F=a[9688]|0?534:0;c[2438999]=I+(F<<1);c[2439e3]=I+(F<<1<<1);c[2439001]=I+((F*3|0)<<1);c[2439002]=I+(F<<2<<1);c[2439003]=I+((F*5|0)<<1);a[5334064]=1;Tq(689736);F=a[9680]|0?32e3:0;c[3542220]=11200;I=c[2113008]|0;if((I|0)==0){gGz(14168888,0,252);c[3542223]=F;gGz(14168896,0,16);c[3542234]=~~((+(F|0)*32768.0*8.0+1.0e6)/2.0e6);G=31;$=32767.0;while(1){c[14169012+(G<<2)>>2]=~~($+.5);D=G-1|0;if((D|0)>0){G=D;$=$/1.188502227}else{break}}c[3542253]=0;h[1771269]=1.0;h[1771270]=1.0;h[1771271]=1.0;c[3542574]=3;c[3542575]=3;c[3542576]=3;mB(0);G=(c[2113008]|0)+1|0;c[2113008]=G;aa=G;ab=a[9680]|0?32e3:0}else{aa=I;ab=F}c[3542220]=11200;if((aa|0)==1){gGz(14169140,0,252);c[3542286]=ab;c[3542287]=362;c[3542288]=0;c[3542289]=0;c[3542290]=1726;c[3542297]=~~((+(ab|0)*32768.0*8.0+1.0e6)/2.0e6);G=31;$=32767.0;while(1){c[14169264+(G<<2)>>2]=~~($+.5);D=G-1|0;if((D|0)>0){G=D;$=$/1.188502227}else{break}}c[3542316]=0;h[1771272]=1.0;h[1771273]=1.0;h[1771274]=1.0;c[3542577]=3;c[3542578]=3;c[3542579]=3;mB(1);c[2113008]=(c[2113008]|0)+1}Ux(0,18181,1);c[2407030]=256;c[2407068]=3;c[3541226]=324;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];G=c[3532592]|0;if((G|0)!=0){gGC(9104152,G|0,280)|0}c[2113054]=c[2113060]}RI();G=c[2394]|0;F=c[14130368+(G<<2)>>2]|0;if((F|0)!=0){gGC(F|0,9104152,280)|0}c[8452240+(G<<2)>>2]=c[2113054];c[2394]=-1;b[4859460]=0;b[4859456]=0;b[4858644]=0;gGz(9720536,0,64);gGz(9720656,0,32);gGz(9720624,0,32);mB(0);mB(1);c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];c[2113156]=0;a[9628264]=0;c[2407033]=0;G=c[3541206]|0;c[3541190]=G;c[3541198]=G;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=G+256;c[3541199]=G+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=G+512;c[3541200]=G+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=G+768;c[3541201]=G+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2443290]=0;O=0;i=e;return O|0}}while(0);c[2426682]=0;O=1;i=e;return O|0}function eBe(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1827644+(b*112|0)>>2];c[a+104>>2]=c[1827648+(b*112|0)>>2];c[a+108>>2]=c[1827652+(b*112|0)>>2];d=0;return d|0}function eBf(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=1827544+(b*112|0);e=0;return e|0}function eBg(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1828540+(b*112|0)>>2];c[a+104>>2]=c[1828544+(b*112|0)>>2];c[a+108>>2]=c[1828548+(b*112|0)>>2];d=0;return d|0}function eBh(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=1828440+(b*112|0);e=0;return e|0}function eBi(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[2426682]|0;c[3527104]=b;c[3541206]=b+524288;c[2438662]=b+786432;d=b+2883584|0;c[2405618]=d;c[3527106]=d;c[2430152]=b+2949120;c[2431696]=b+2953216;d=c[2429320]|0;c[2431686]=b+(d+2953216);c[2431684]=b+(d+2957312);c[2431682]=b+(d+2961408);c[2431680]=b+(d+2965504);c[2431694]=b+(d+2969600);c[2431692]=b+(d+2973696);c[2431690]=b+(d+2977792);c[2431688]=b+(d+2981888);e=d+2985984|0;d=b+e|0;c[2411564]=d;c[2437676]=d;d=(c[2430154]<<8)+e|0;c[2439470]=b+d;e=d+(c[2433414]<<8)|0;c[2443298]=b+e;d=c[2113068]|0;f=c[2113070]|0;g=ag(d<<2,f)|0;h=g+e|0;c[2443299]=b+h;e=h+g|0;c[2433368]=b+e;h=e+g|0;c[2433369]=b+h;e=h+g|0;c[2430126]=b+e;h=ag(f,d)|0;d=e+h|0;c[2430127]=b+d;e=d+h|0;d=b+e|0;f=c[2431698]|0;if((f|0)==0){i=d}else{c[2438688]=d;d=e+(f<<8)|0;c[2443300]=b+d;f=d+g|0;c[2443301]=b+f;d=f+g|0;c[2433370]=b+d;f=d+g|0;c[2433371]=b+f;d=f+g|0;c[2430128]=b+d;g=d+h|0;c[2430129]=b+g;i=b+(g+h)|0}c[2385358]=i;h=a[9688]|0?6408:0;g=i+h|0;if(a[6872968]|0){c[2433416]=g;c[2437678]=i+(h|4194304);j=h|4341760;k=i+j|0;c[2414104]=k;return}else{c[2437678]=g;j=h|16384;k=i+j|0;c[2414104]=k;return}}function eBj(a){a=a|0;var b=0;if((c[2406632]|0)!=0){b=(c[2432962]|0)>>>((c[(c[2420380]|0)+4>>2]|0)>>>0)&1;return b|0}a=c[2443744]|0;if((a|0)<=0){b=1;return b|0}c[2443744]=a-1;b=0;return b|0}function eBk(a,b){a=a|0;b=b|0;a=b&1;c[3528406]=a^1;if((a|0)!=0){return}c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];return}function eBl(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;e=b[4860330]|0;f=b[4860328]|0;g=b[4860314]|0;h=b[4860312]|0;i=b[4860332]|0;j=b[4860316]|0;k=c[2112926]|0;gGz(k|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);k=0;l=c[2430152]|0;m=c[2437678]|0;while(1){n=b[l>>1]|0;c[m>>2]=((n&65535)>>>5<<3&248)<<8|((n&255)<<3&255)>>>3|(((n&65535)>>>12&4|(n&65535)>>>10<<3&255)&255)<<3&2016;n=k+1|0;if((n|0)<4096){k=n;l=l+2|0;m=m+4|0}else{break}}m=j&4096;l=e&65535;e=f&65535;f=g&65535;g=h&65535;h=i&16;k=j&16;j=b[4860332]|0;n=(i&4096)!=0;do{if((j&2048)==0|n){o=0;p=l;q=j}else{i=c[2431694]|0;r=b[i>>1]|0;s=r&65535;t=0;while(1){if((t|0)>=512){u=13245;break}if((b[i+(t<<1)>>1]|0)==r<<16>>16){t=t+1|0}else{u=13244;break}}if((u|0)==13244){eBm(0);o=1;p=l;q=b[4860332]|0;break}else if((u|0)==13245){o=0;p=s+l|0;q=j;break}}}while(0);j=h<<16>>16!=0;do{if((q&8)==0|j){v=0;w=e}else{h=c[2431692]|0;l=b[h>>1]|0;t=l&65535;r=0;while(1){if((r|0)>=512){u=13251;break}if((b[h+(r<<1)>>1]|0)==l<<16>>16){r=r+1|0}else{u=13250;break}}if((u|0)==13251){v=0;w=t+e|0;break}else if((u|0)==13250){eBm(1);v=1;w=e;break}}}while(0);e=b[4860316]|0;q=m<<16>>16!=0;do{if((e&2048)==0|q){x=0;y=f;z=e}else{m=c[2431690]|0;r=b[m>>1]|0;l=r&65535;h=0;while(1){if((h|0)>=512){u=13257;break}if((b[m+(h<<1)>>1]|0)==r<<16>>16){h=h+1|0}else{u=13256;break}}if((u|0)==13256){eBm(2);x=1;y=f;z=b[4860316]|0;break}else if((u|0)==13257){x=0;y=l+f|0;z=e;break}}}while(0);e=k<<16>>16!=0;do{if((z&8)==0|e){A=g;B=1}else{k=c[2431688]|0;f=b[k>>1]|0;h=f&65535;r=0;while(1){if((r|0)>=512){u=13263;break}if((b[k+(r<<1)>>1]|0)==f<<16>>16){r=r+1|0}else{u=13262;break}}if((u|0)==13263){A=h+g|0;B=1;break}else if((u|0)==13262){eBm(3);A=g;B=0;break}}}while(0);g=(x|0)==0;x=(v|0)==0;v=(o|0)==0;o=0;while(1){do{if(!n){if(v){eBn(0,o,p);break}u=c[2438672]|0;if((u|0)<=0){break}z=c[2430126]|0;r=c[2112926]|0;f=c[2443298]|0;k=c[2113068]|0;l=c[2433368]|0;m=a[682248]|0?1024:0;t=0;do{if((d[z+t|0]|0)==(o|0)){s=c[f+(t<<2)>>2]|0;i=r+((ag(s>>>9,k)|0)+(s&511)<<1)|0;b[i>>1]=(m|c[l+(t<<2)>>2])&65535}t=t+1|0;}while((t|0)<(u|0))}}while(0);do{if(!j){if(x){eBn(1,o,w);break}h=c[2438673]|0;if((h|0)<=0){break}u=c[2430127]|0;t=c[2112926]|0;l=c[2443299]|0;m=c[2113068]|0;k=c[2433369]|0;r=a[682248]|0?1024:0;f=0;do{if((d[u+f|0]|0)==(o|0)){z=c[l+(f<<2)>>2]|0;i=t+((ag(z>>>9,m)|0)+(z&511)<<1)|0;b[i>>1]=(r|c[k+(f<<2)>>2])&65535}f=f+1|0;}while((f|0)<(h|0))}}while(0);do{if(!q){if(g){eBn(2,o,y);break}h=c[2438674]|0;if((h|0)<=0){break}f=c[2430128]|0;k=c[2112926]|0;r=c[2443300]|0;m=c[2113068]|0;t=c[2433370]|0;l=a[682248]|0?1024:0;u=0;do{if((d[f+u|0]|0)==(o|0)){i=c[r+(u<<2)>>2]|0;z=k+((ag(i>>>9,m)|0)+(i&511)<<1)|0;b[z>>1]=(l|c[t+(u<<2)>>2])&65535}u=u+1|0;}while((u|0)<(h|0))}}while(0);do{if(!e){if(B){eBn(3,o,A);break}h=c[2438675]|0;if((h|0)<=0){break}u=c[2430129]|0;t=c[2112926]|0;l=c[2443301]|0;m=c[2113068]|0;k=c[2433371]|0;r=a[682248]|0?1024:0;f=0;do{if((d[u+f|0]|0)==(o|0)){z=c[l+(f<<2)>>2]|0;i=t+((ag(z>>>9,m)|0)+(z&511)<<1)|0;b[i>>1]=(r|c[k+(f<<2)>>2])&65535}f=f+1|0;}while((f|0)<(h|0))}}while(0);if((o|0)==1){eBo(0)}else if((o|0)==2){eBo(1)}else if((o|0)==4){eBo(2)}else if((o|0)==6){eBo(3)}else{h=o+1|0;if((h|0)<8){o=h;continue}else{break}}o=o+1|0}R8(c[2437678]|0);return}function eBm(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;f=9754688+(d<<2)|0;c[f>>2]=0;if((d|0)==3){g=c[2431698]|0;h=2;i=1;j=0;k=c[2438688]|0;l=9720624;m=c[2431688]|0;n=c[2431680]|0}else if((d|0)==2){g=c[2431698]|0;h=0;i=3;j=2;k=c[2438688]|0;l=9720624;m=c[2431690]|0;n=c[2431682]|0}else if((d|0)==1){g=c[2433414]|0;h=2;i=1;j=0;k=c[2439470]|0;l=9720656;m=c[2431692]|0;n=c[2431684]|0}else if((d|0)==0){g=c[2433414]|0;h=0;i=3;j=2;k=c[2439470]|0;l=9720656;m=c[2431694]|0;n=c[2431686]|0}else{g=0;h=0;i=0;j=0;k=0;l=0;m=0;n=0}o=e[l+(j<<1)>>1]|0;j=(a[726896]|0?-8:0)-((e[l+(i<<1)>>1]|0)>>>6&511)|0;i=9773192+(d<<2)|0;l=9733472+(d<<2)|0;p=9720504+(d<<2)|0;d=(c[2429504]|0)+h|0;h=c[2113070]|0;q=c[2113068]|0;r=-1;s=0;t=0;while(1){u=(s|0)%16|0;v=((u|0)==0)+r|0;w=s+j|0;x=(w|0)<-30?w+512|0:w;w=((e[m+(s<<1)>>1]|0)+o|0)>>>6&511;y=v<<5;z=x<<9;A=(x|0)>-1&(x|0)<(h|0);x=-1;B=0;C=t;while(1){D=(B|0)%16|0;E=((D|0)==0)+x|0;do{if(A){F=B-w-d|0;G=(F|0)<-7?F+512|0:F;if(!((G|0)>-1&(G|0)<(q|0))){H=C;break}F=E+y<<1;I=e[n+((F|1)<<1)>>1]|0;if((I|0)>=(g|0)){H=C;break}J=b[n+(F<<1)>>1]|0;F=J&65535;L18045:do{if((F&1|0)==0){K=u}else{switch(u|0){case 12:{K=3;break L18045;break};case 7:{K=8;break L18045;break};case 3:{K=12;break L18045;break};case 10:{K=5;break L18045;break};case 11:{K=4;break L18045;break};case 2:{K=13;break L18045;break};case 13:{K=2;break L18045;break};case 8:{K=7;break L18045;break};case 9:{K=6;break L18045;break};case 6:{K=9;break L18045;break};case 0:{K=15;break L18045;break};case 4:{K=11;break L18045;break};case 5:{K=10;break L18045;break};case 1:{K=14;break L18045;break};case 14:{K=1;break L18045;break};default:{K=0;break L18045}}}}while(0);L18064:do{if((F&2|0)==0){L=D}else{switch(D|0){case 1:{L=14;break L18064;break};case 3:{L=12;break L18064;break};case 2:{L=13;break L18064;break};case 11:{L=4;break L18064;break};case 5:{L=10;break L18064;break};case 0:{L=15;break L18064;break};case 12:{L=3;break L18064;break};case 4:{L=11;break L18064;break};case 13:{L=2;break L18064;break};case 14:{L=1;break L18064;break};case 10:{L=5;break L18064;break};case 7:{L=8;break L18064;break};case 6:{L=9;break L18064;break};case 8:{L=7;break L18064;break};case 9:{L=6;break L18064;break};default:{L=0;break L18064}}}}while(0);M=a[k+((K<<4)+(I<<8)+L)|0]|0;if(M<<24>>24==0){H=C;break}c[(c[i>>2]|0)+(C<<2)>>2]=G|z;c[(c[l>>2]|0)+(C<<2)>>2]=M&255|F>>>2<<4&1008;a[(c[p>>2]|0)+C|0]=(J&65535)>>>8&7;M=C+1|0;c[f>>2]=M;H=M}else{H=C}}while(0);D=B+1|0;if((D|0)<512){x=E;B=D;C=H}else{break}}C=s+1|0;if((C|0)<512){r=v;s=C;t=H}else{break}}return}function eBn(b,d,f){b=b|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;if((b|0)==3){g=c[2431698]|0;h=2;i=1;j=c[2438688]|0;k=9720624;l=c[2431680]|0}else if((b|0)==2){g=c[2431698]|0;h=0;i=3;j=c[2438688]|0;k=9720624;l=c[2431682]|0}else if((b|0)==1){g=c[2433414]|0;h=2;i=1;j=c[2439470]|0;k=9720656;l=c[2431684]|0}else if((b|0)==0){g=c[2433414]|0;h=0;i=3;j=c[2439470]|0;k=9720656;l=c[2431686]|0}else{g=0;h=0;i=0;j=0;k=0;l=0}b=f>>>6&511;f=k+(i<<1)|0;i=c[2429504]|0;k=a[726896]|0?-8:0;m=c[2112926]|0;n=a[682248]|0?1024:0;o=0;p=0;while(1){q=o<<4;r=0;s=p;while(1){t=e[l+(s+1<<1)>>1]|0;if((t|0)<(g|0)){u=e[l+(s<<1)>>1]|0;v=u>>>2&63;w=u&3;L18100:do{if((u>>>8&7|0)==(d|0)){x=(r<<4)-b|0;y=q-((e[f>>1]|0)>>>6&511)|0;z=((x|0)<-7?x+512|0:x)-h-i|0;x=((y|0)<-30?y+512|0:y)+k|0;do{if((z|0)>0){if(!((z|0)<((c[2113068]|0)-16|0)&(x|0)>0)){break}if((x|0)>=((c[2113070]|0)-16|0)){break}if((w|0)==1){SK(m,t,z,x,v,4,0,n,j);break L18100}else if((w|0)==0){SG(m,t,z,x,v,4,0,n,j);break L18100}else if((w|0)==2){SI(m,t,z,x,v,4,0,n,j);break L18100}else if((w|0)==3){SM(m,t,z,x,v,4,0,n,j);break L18100}else{break L18100}}}while(0);if((w|0)==2){SJ(m,t,z,x,v,4,0,n,j);break}else if((w|0)==3){SN(m,t,z,x,v,4,0,n,j);break}else if((w|0)==1){SL(m,t,z,x,v,4,0,n,j);break}else if((w|0)==0){SH(m,t,z,x,v,4,0,n,j);break}else{break}}}while(0);A=s+2|0}else{A=s}v=r+1|0;if((v|0)<32){r=v;s=A}else{break}}s=o+1|0;if((s|0)<32){o=s;p=A}else{break}}return}function eBo(d){d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;e=c[3528200]|0;f=gA[c[3541224]&16383](0,e)|0;if((f|0)!=-1){g=0;h=0;i=0;j=0;k=0;l=0;m=0;n=0;o=0;p=0;q=e;e=f;while(1){if((e&2|0)==0){r=c[q>>2]|0}else{f=k+1|0;c[q>>2]=f;r=f}f=q+4|0;if((e&4|0)==0){s=c[q+28>>2]|0;t=c[q+24>>2]|0;u=c[q+20>>2]|0;v=c[q+16>>2]|0;w=c[q+32>>2]|0;x=c[f>>2]|0}else{c[f>>2]=j;c[q+32>>2]=l;c[q+16>>2]=m;c[q+20>>2]=n;c[q+24>>2]=o;c[q+28>>2]=p;s=p;t=o;u=n;v=m;w=l;x=j}f=q+8|0;y=c[f>>2]|0;if((e&1|0)==0){z=y;A=c[q+12>>2]|0}else{B=y+h|0;c[f>>2]=B;y=q+12|0;C=(c[y>>2]|0)+i|0;c[y>>2]=C;z=B;A=C}C=A+u|0;B=z+v+(a[703944]|0?63872:0)|0;c[f>>2]=((B&32704)-(B&32768)|0)/64|0;c[q+12>>2]=((C&32704)-(C&32768)|0)/64|0;C=g+1|0;B=q+36|0;f=gA[c[3541224]&16383](C,B)|0;if((f|0)==-1){break}else{g=C;h=z;i=A;j=x;k=r;l=w;m=v;n=u;o=t;p=s;q=B;e=f}}}e=c[3528200]|0;q=c[2437676]|0;s=c[2430154]|0;p=a[809552]|0?8:4;t=c[2113068]|0;o=t+1|0;u=c[2113070]|0;n=u+1|0;v=c[2112926]|0;m=u-1|0;u=a[681672]|0?16384:0;w=c[2426984]|0;l=e;do{do{if((c[l+32>>2]|0)==(d|0)){r=c[l+8>>2]|0;k=c[l+12>>2]|0;x=(((c[l>>2]|0)>>>0)%(s>>>0)|0)<<8;j=(c[l+4>>2]&63)<<p;A=r+16|0;i=k+16|0;z=(c[l+24>>2]|0)==0;h=z?0:983040;g=z?65536:-65536;z=(c[l+28>>2]|0)==0;f=z?0:983040;B=z?65536:-65536;if((r|0)<0){D=0;E=h-(ag(g,r)|0)|0}else{D=r;E=h}if((k|0)<0){F=0;G=f-(ag(B,k)|0)|0}else{F=k;G=f}f=(A|0)>(o|0)?o:A;A=(i|0)>(n|0)?n:i;if((f|0)>(D|0)&(F|0)<(A|0)){H=G;I=F}else{break}while(1){i=(H>>16<<4)+x|0;k=ag(I,t)|0;if((I|0)<0|(I|0)>(m|0)){J=H}else{h=D;r=E;while(1){z=a[q+(i+(r>>16))|0]|0;if(z<<24>>24!=0&(h|0)>-1&(h|0)<(t|0)){b[v+(h+k<<1)>>1]=(z&255|j|u)&w&65535}z=h+1|0;if((z|0)>=(f|0)){break}h=z;r=r+g|0}J=H+B|0}r=I+1|0;if((r|0)<(A|0)){H=J;I=r}else{break}}}}while(0);l=l+36|0;}while(l>>>0<(e+36864|0)>>>0);return}function eBp(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0;d=c[2431696]|0;f=a<<2;if((f|0)>=(c[2429320]>>1|0)){g=-1;return g|0}a=e[d+(f<<1)>>1]|0;c[b>>2]=e[d+((f|1)<<1)>>1]|0;c[b+8>>2]=e[d+((f|2)<<1)>>1]|0;c[b+12>>2]=e[d+((f|3)<<1)>>1]|0;c[b+4>>2]=a>>>2&63;c[b+32>>2]=a>>>8&3;c[b+28>>2]=a&1;c[b+24>>2]=a&2;f=a>>>11<<1&6;d=e[9720536+((f|9)<<1)>>1]|0;h=b+20|0;c[h>>2]=d;c[b+16>>2]=e[9720536+((f|8)<<1)>>1]|0;c[h>>2]=d-(e[4860269]|0);g=a>>>13&1|a>>>12&4|a>>>14&2;return g|0}function eBq(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0;d=c[2431696]|0;f=a<<2;if((f|0)>=(c[2429320]>>1|0)){g=-1;return g|0}a=e[d+(f<<1)>>1]|0;h=e[d+((f|1)<<1)>>1]|0;i=b|0;c[i>>2]=h;c[b+8>>2]=e[d+((f|2)<<1)>>1]|0;j=e[d+((f|3)<<1)>>1]|0;c[b+12>>2]=j;c[b+4>>2]=a&63;c[b+32>>2]=a>>>6&3;c[b+28>>2]=a&256;c[b+24>>2]=a&512;c[i>>2]=j<<16&65536|h;h=a>>>11<<1&6;j=e[9720536+((h|9)<<1)>>1]|0;i=b+20|0;c[i>>2]=j;c[b+16>>2]=e[9720536+((h|8)<<1)>>1]|0;c[i>>2]=j-(e[4860269]|0);g=a>>>13&1|a>>>12&4|a>>>14&2;return g|0}function eBr(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a=c[2426682]|0;c[3527104]=a;c[3541206]=a+1048576;c[2438662]=a+2359296;c[2437642]=a+6553600;b=a+9699328|0;c[2405618]=b;c[3527106]=b;c[2438690]=a+9863168;c[2439474]=a+9928704;c[2430152]=a+9928960;c[2431696]=a+9994496;b=c[2429320]|0;c[2431686]=a+(b+9994496);c[2431684]=a+(b+9998592);c[2431682]=a+(b+10002688);c[2431680]=a+(b+10006784);c[2431694]=a+(b+10010880);c[2431692]=a+(b+10014976);c[2431690]=a+(b+10019072);c[2431688]=a+(b+10023168);d=b+10027264|0;b=a+d|0;c[2411564]=b;c[2437676]=b;b=(c[2430154]<<8)+d|0;c[2439470]=a+b;d=b+(c[2433414]<<8)|0;c[2443298]=a+d;b=c[2113068]|0;e=c[2113070]|0;f=ag(b<<2,e)|0;g=f+d|0;c[2443299]=a+g;d=g+f|0;c[2433368]=a+d;g=d+f|0;c[2433369]=a+g;d=g+f|0;c[2430126]=a+d;g=ag(e,b)|0;b=d+g|0;c[2430127]=a+b;d=b+g|0;b=a+d|0;e=c[2431698]|0;if((e|0)==0){h=b;i=h;c[2437678]=i;j=h+262144|0;c[2414104]=j;return}c[2438688]=b;b=d+(e<<8)|0;c[2443300]=a+b;e=b+f|0;c[2443301]=a+e;b=e+f|0;c[2433370]=a+b;e=b+f|0;c[2433371]=a+e;b=e+f|0;c[2430128]=a+b;f=b+g|0;c[2430129]=a+f;h=a+(f+g)|0;i=h;c[2437678]=i;j=h+262144|0;c[2414104]=j;return}function eBs(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0;fxU(0,425984);if((c[2394]|0)==0){a=c[2112932]|0}else{c[2394]=0;b=c[3532596]|0;c[2112932]=b;d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];a=b}b=c[3527104]|0;d=a|0;e=0;while(1){f=b+e|0;c[d>>2]=f;c[d+131072>>2]=f;f=e+1024|0;if(f>>>0>1048573){break}else{d=d+4|0;e=f}}e=c[3527106]|0;d=a+4096|0;b=1048576;while(1){f=e+(b-1048576)|0;c[d>>2]=f;c[d+65536>>2]=f;c[d+131072>>2]=f;f=b+1024|0;if(f>>>0>1114111){break}else{d=d+4|0;b=f}}b=c[2438690]|0;d=a+8192|0;f=2097152;while(1){g=b+(f-2097152)|0;c[d>>2]=g;c[d+65536>>2]=g;c[d+131072>>2]=g;g=f+1024|0;if(g>>>0>2162687){break}else{d=d+4|0;f=g}}f=c[2430152]|0;d=a+12288|0;b=3145728;while(1){g=f+(b-3145728)|0;c[d>>2]=g;c[d+65536>>2]=g;c[d+131072>>2]=g;g=b+1024|0;if(g>>>0>3211263){break}else{d=d+4|0;b=g}}b=a+12544|0;d=3211264;while(1){f=e+(d-3145728)|0;c[b>>2]=f;c[b+65536>>2]=f;c[b+131072>>2]=f;f=d+1024|0;if(f>>>0>3309567){break}else{b=b+4|0;d=f}}d=c[2431696]|0;c[a+16384>>2]=d;c[a+81920>>2]=d;c[a+147456>>2]=d;b=d+1024|0;c[a+16388>>2]=b;c[a+81924>>2]=b;c[a+147460>>2]=b;b=d+2048|0;c[a+16392>>2]=b;c[a+81928>>2]=b;c[a+147464>>2]=b;b=d+3072|0;c[a+16396>>2]=b;c[a+81932>>2]=b;c[a+147468>>2]=b;b=d+4096|0;c[a+16400>>2]=b;c[a+81936>>2]=b;c[a+147472>>2]=b;b=d+5120|0;c[a+16404>>2]=b;c[a+81940>>2]=b;c[a+147476>>2]=b;b=d+6144|0;c[a+16408>>2]=b;c[a+81944>>2]=b;c[a+147480>>2]=b;b=d+7168|0;c[a+16412>>2]=b;c[a+81948>>2]=b;c[a+147484>>2]=b;b=c[2431684]|0;c[a+20480>>2]=b;c[a+86016>>2]=b;c[a+151552>>2]=b;d=b+1024|0;c[a+20484>>2]=d;c[a+86020>>2]=d;c[a+151556>>2]=d;d=b+2048|0;c[a+20488>>2]=d;c[a+86024>>2]=d;c[a+151560>>2]=d;d=b+3072|0;c[a+20492>>2]=d;c[a+86028>>2]=d;c[a+151564>>2]=d;d=c[2431686]|0;c[a+20496>>2]=d;c[a+86032>>2]=d;c[a+151568>>2]=d;b=d+1024|0;c[a+20500>>2]=b;c[a+86036>>2]=b;c[a+151572>>2]=b;b=d+2048|0;c[a+20504>>2]=b;c[a+86040>>2]=b;c[a+151576>>2]=b;b=d+3072|0;c[a+20508>>2]=b;c[a+86044>>2]=b;c[a+151580>>2]=b;b=c[2431692]|0;c[a+20512>>2]=b;c[a+86048>>2]=b;c[a+151584>>2]=b;d=b+1024|0;c[a+20516>>2]=d;c[a+86052>>2]=d;c[a+151588>>2]=d;d=b+2048|0;c[a+20520>>2]=d;c[a+86056>>2]=d;c[a+151592>>2]=d;d=b+3072|0;c[a+20524>>2]=d;c[a+86060>>2]=d;c[a+151596>>2]=d;d=c[2431694]|0;c[a+20528>>2]=d;c[a+86064>>2]=d;c[a+151600>>2]=d;b=d+1024|0;c[a+20532>>2]=b;c[a+86068>>2]=b;c[a+151604>>2]=b;b=d+2048|0;c[a+20536>>2]=b;c[a+86072>>2]=b;c[a+151608>>2]=b;b=d+3072|0;c[a+20540>>2]=b;c[a+86076>>2]=b;c[a+151612>>2]=b;b=c[2431680]|0;c[a+22528>>2]=b;c[a+88064>>2]=b;c[a+153600>>2]=b;d=b+1024|0;c[a+22532>>2]=d;c[a+88068>>2]=d;c[a+153604>>2]=d;d=b+2048|0;c[a+22536>>2]=d;c[a+88072>>2]=d;c[a+153608>>2]=d;d=b+3072|0;c[a+22540>>2]=d;c[a+88076>>2]=d;c[a+153612>>2]=d;d=c[2431682]|0;c[a+22544>>2]=d;c[a+88080>>2]=d;c[a+153616>>2]=d;b=d+1024|0;c[a+22548>>2]=b;c[a+88084>>2]=b;c[a+153620>>2]=b;b=d+2048|0;c[a+22552>>2]=b;c[a+88088>>2]=b;c[a+153624>>2]=b;b=d+3072|0;c[a+22556>>2]=b;c[a+88092>>2]=b;c[a+153628>>2]=b;b=c[2431688]|0;c[a+22560>>2]=b;c[a+88096>>2]=b;c[a+153632>>2]=b;d=b+1024|0;c[a+22564>>2]=d;c[a+88100>>2]=d;c[a+153636>>2]=d;d=b+2048|0;c[a+22568>>2]=d;c[a+88104>>2]=d;c[a+153640>>2]=d;d=b+3072|0;c[a+22572>>2]=d;c[a+88108>>2]=d;c[a+153644>>2]=d;d=c[2431690]|0;c[a+22576>>2]=d;c[a+88112>>2]=d;c[a+153648>>2]=d;b=d+1024|0;c[a+22580>>2]=b;c[a+88116>>2]=b;c[a+153652>>2]=b;b=d+2048|0;c[a+22584>>2]=b;c[a+88120>>2]=b;c[a+153656>>2]=b;b=d+3072|0;c[a+22588>>2]=b;c[a+88124>>2]=b;c[a+153660>>2]=b;c[a+90112>>2]=9720656;c[a+92160>>2]=9720624;c[a+94208>>2]=9720536;c[a+196608>>2]=1950;c[a+196688>>2]=2104;c[a+196648>>2]=1632;c[a+196728>>2]=856;a=c[3532592]|0;if((a|0)==0){h=c[2113054]|0;c[2113060]=h;c[2394]=-1;Ux(0,12e3,0);Ux(1,12e3,0);c[2407030]=128;c[2407068]=3;c[2407069]=128;c[2407107]=3;return}gGC(a|0,9104152,280)|0;h=c[2113054]|0;c[2113060]=h;c[2394]=-1;Ux(0,12e3,0);Ux(1,12e3,0);c[2407030]=128;c[2407068]=3;c[2407069]=128;c[2407107]=3;return}function eBt(){var a=0,f=0,g=0,h=0,i=0;a=c[2438690]|0;f=a;g=c[2439474]|0;h=(e[a+18>>1]|0)>>>1;i=(e[a+16>>1]|0)>>>8;if((i|0)==2){a=f+((h&65535)<<1)|0;gGC(a|0,g|0,128)|0;return}else if((i|0)==3){b[f+((h&65535)<<1)>>1]=-256-((d[14108432]|0)<<8)&65535;return}else if((i|0)==4){a=h&65535;b[f+(a<<1)>>1]=21843;b[f+(a+1<<1)>>1]=19789;b[f+(a+2<<1)>>1]=12343;b[f+(a+3<<1)>>1]=12595;b[f+(a+4<<1)>>1]=11604;b[f+(a+5<<1)>>1]=16945;b[f+(a+6<<1)>>1]=14649;b[f+(a+7<<1)>>1]=13344;return}else if((i|0)==66){i=f+((h&65535)<<1)|0;gGC(g|0,i|0,128)|0;return}else{return}}function eBu(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;e=b[4860330]|0;f=b[4860328]|0;g=b[4860314]|0;h=b[4860312]|0;i=b[4860332]|0;j=b[4860316]|0;k=c[2112926]|0;gGz(k|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);k=0;l=c[2430152]|0;m=c[2437678]|0;while(1){n=b[l>>1]|0;c[m>>2]=((n&65535)>>>5<<3&248)<<8|((n&255)<<3&255)>>>3|(((n&65535)>>>12&4|(n&65535)>>>10<<3&255)&255)<<3&2016;n=k+1|0;if((n|0)<65536){k=n;l=l+2|0;m=m+4|0}else{break}}m=j&4096;l=e&65535;e=f&65535;f=g&65535;g=h&65535;h=i&16;k=j&16;if((b[4858644]|0)==0){return}j=b[4860332]|0;n=(i&4096)!=0;do{if((j&2048)==0|n){o=0;p=l;q=j}else{i=c[2431694]|0;r=b[i>>1]|0;s=r&65535;t=0;while(1){if((t|0)>=512){u=13461;break}if((b[i+(t<<1)>>1]|0)==r<<16>>16){t=t+1|0}else{u=13460;break}}if((u|0)==13461){o=0;p=s+l|0;q=j;break}else if((u|0)==13460){eBm(0);o=1;p=l;q=b[4860332]|0;break}}}while(0);l=h<<16>>16!=0;do{if((q&8)==0|l){v=0;w=e}else{h=c[2431692]|0;j=b[h>>1]|0;t=j&65535;r=0;while(1){if((r|0)>=512){u=13467;break}if((b[h+(r<<1)>>1]|0)==j<<16>>16){r=r+1|0}else{u=13466;break}}if((u|0)==13467){v=0;w=t+e|0;break}else if((u|0)==13466){eBm(1);v=1;w=e;break}}}while(0);e=b[4860316]|0;q=m<<16>>16!=0;do{if((e&2048)==0|q){x=0;y=f;z=e}else{m=c[2431690]|0;r=b[m>>1]|0;j=r&65535;h=0;while(1){if((h|0)>=512){u=13473;break}if((b[m+(h<<1)>>1]|0)==r<<16>>16){h=h+1|0}else{u=13472;break}}if((u|0)==13472){eBm(2);x=1;y=f;z=b[4860316]|0;break}else if((u|0)==13473){x=0;y=j+f|0;z=e;break}}}while(0);e=k<<16>>16!=0;do{if((z&8)==0|e){A=g;B=1}else{k=c[2431688]|0;f=b[k>>1]|0;h=f&65535;r=0;while(1){if((r|0)>=512){u=13479;break}if((b[k+(r<<1)>>1]|0)==f<<16>>16){r=r+1|0}else{u=13478;break}}if((u|0)==13479){A=h+g|0;B=1;break}else if((u|0)==13478){eBm(3);A=g;B=0;break}}}while(0);g=(x|0)==0;x=(v|0)==0;v=(o|0)==0;o=0;while(1){do{if(!n){if(v){eBn(0,o,p);break}z=c[2438672]|0;if((z|0)<=0){break}r=c[2430126]|0;f=c[2112926]|0;k=c[2443298]|0;j=c[2113068]|0;m=c[2433368]|0;t=a[682248]|0?1024:0;s=0;do{if((d[r+s|0]|0)==(o|0)){i=c[k+(s<<2)>>2]|0;C=f+((ag(i>>>9,j)|0)+(i&511)<<1)|0;b[C>>1]=(t|c[m+(s<<2)>>2])&65535}s=s+1|0;}while((s|0)<(z|0))}}while(0);do{if(!l){if(x){eBn(1,o,w);break}h=c[2438673]|0;if((h|0)<=0){break}z=c[2430127]|0;s=c[2112926]|0;m=c[2443299]|0;t=c[2113068]|0;j=c[2433369]|0;f=a[682248]|0?1024:0;k=0;do{if((d[z+k|0]|0)==(o|0)){r=c[m+(k<<2)>>2]|0;C=s+((ag(r>>>9,t)|0)+(r&511)<<1)|0;b[C>>1]=(f|c[j+(k<<2)>>2])&65535}k=k+1|0;}while((k|0)<(h|0))}}while(0);do{if(!q){if(g){eBn(2,o,y);break}h=c[2438674]|0;if((h|0)<=0){break}k=c[2430128]|0;j=c[2112926]|0;f=c[2443300]|0;t=c[2113068]|0;s=c[2433370]|0;m=a[682248]|0?1024:0;z=0;do{if((d[k+z|0]|0)==(o|0)){C=c[f+(z<<2)>>2]|0;r=j+((ag(C>>>9,t)|0)+(C&511)<<1)|0;b[r>>1]=(m|c[s+(z<<2)>>2])&65535}z=z+1|0;}while((z|0)<(h|0))}}while(0);do{if(!e){if(B){eBn(3,o,A);break}h=c[2438675]|0;if((h|0)<=0){break}z=c[2430129]|0;s=c[2112926]|0;m=c[2443301]|0;t=c[2113068]|0;j=c[2433371]|0;f=a[682248]|0?1024:0;k=0;do{if((d[z+k|0]|0)==(o|0)){r=c[m+(k<<2)>>2]|0;C=s+((ag(r>>>9,t)|0)+(r&511)<<1)|0;b[C>>1]=(f|c[j+(k<<2)>>2])&65535}k=k+1|0;}while((k|0)<(h|0))}}while(0);if((o|0)==1){eBo(1)}else if((o|0)==7){u=13517;break}else if((o|0)==2){eBo(2)}else if((o|0)==0){eBo(0)}else{h=o+1|0;if((h|0)<8){o=h;continue}else{break}}o=o+1|0}if((u|0)==13517){eBo(3)}R8(c[2437678]|0);return}function eBv(){var a=0,f=0,g=0,h=0,i=0;a=c[2438690]|0;f=a;g=c[2439474]|0;h=(e[a+18>>1]|0)>>>1;i=(e[a+16>>1]|0)>>>8;if((i|0)==66){a=f+((h&65535)<<1)|0;gGC(g|0,a|0,128)|0;return}else if((i|0)==3){b[f+((h&65535)<<1)>>1]=-256-((d[14108432]|0)<<8)&65535;return}else if((i|0)==2){a=f+((h&65535)<<1)|0;gGC(a|0,g|0,128)|0;return}else if((i|0)==4){i=h&65535;b[f+(i<<1)>>1]=19789;b[f+(i+1<<1)>>1]=12341;b[f+(i+2<<1)>>1]=12853;b[f+(i+3<<1)>>1]=11604;b[f+(i+4<<1)>>1]=20313;b[f+(i+5<<1)>>1]=16975;b[f+(i+6<<1)>>1]=22577;b[f+(i+7<<1)>>1]=14649;return}else{return}}function eBw(){var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;d=i;i=i+128|0;e=d|0;if((c[2392]|0)>=0){f=0;do{g=14130368+(f<<2)|0;h=c[g>>2]|0;if((h|0)!=0){gGr(h);c[g>>2]=0}g=14130384+(f<<2)|0;h=c[g>>2]|0;if((h|0)!=0){gGr(h);c[g>>2]=0}f=f+1|0;}while((f|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;do{if(a[5334064]|0){f=e|0;g=c[c[642608+(c[2436]<<2)>>2]>>2]|0;be(f|0,128,179600,(h=i,i=i+24|0,c[h>>2]=9374064,c[h+8>>2]=47,c[h+16>>2]=g,h)|0)|0;i=h;a[1040128]=0;h=c[2420380]|0;g=c[h>>2]|0;j=c[h+4>>2]|0;h=fw(f|0,389440)|0;if((h|0)==0){break}f=j>>3<<g&1023;cj(14100392,f|0,1,h|0)|0;aY(h|0)|0}}while(0);c[2113070]=0;c[2113068]=0;e=c[2112926]|0;if((e|0)!=0){gGr(e);c[2112926]=0}e=c[2426682]|0;h=0;while(1){if((h|0)>=1024){break}k=9638528+(h<<2)|0;if((c[k>>2]|0)==(e|0)){l=13549;break}else{h=h+1|0}}if((l|0)==13549){gGr(e);c[k>>2]=0}c[2426682]=0;k=c[3528200]|0;e=0;while(1){if((e|0)>=1024){break}m=9638528+(e<<2)|0;if((c[m>>2]|0)==(k|0)){l=13553;break}else{e=e+1|0}}if((l|0)==13553){gGr(k);c[m>>2]=0}c[3528200]=0;c[2433414]=0;c[2431698]=0;c[2430154]=0;b[4859460]=0;b[4859456]=0;a[681672]=0;c[2426984]=0;a[682248]=0;b[4858644]=0;a[809552]=0;a[5334064]=0;c[2429504]=0;a[726896]=0;a[6872968]=0;b[4875360]=0;b[4860360]=0;a[9707944]=0;c[2429320]=0;a[703944]=0;c[2430150]=0;c[2443290]=0;c[2443288]=0;gGz(9720536,0,64);gGz(9720656,0,32);gGz(9720624,0,32);m=9771688;c[m>>2]=0;c[m+4>>2]=0;c[3531910]=0;c[3541226]=0;c[3541224]=0;a[680496]=0;a[642536]=0;a[672472]=0;a[642456]=0;i=d;return}function eBx(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;e=b[4860330]|0;f=b[4860328]|0;g=b[4860314]|0;h=b[4860312]|0;i=b[4860332]|0;j=b[4860316]|0;k=c[2112926]|0;gGz(k|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);l=0;m=c[2430152]|0;n=c[2437678]|0;while(1){o=b[m>>1]|0;c[n>>2]=((o&65535)>>>5<<3&248)<<8|((o&255)<<3&255)>>>3|(((o&65535)>>>12&4|(o&65535)>>>10<<3&255)&255)<<3&2016;o=l+1|0;if((o|0)<4096){l=o;m=m+2|0;n=n+4|0}else{break}}n=j&4096;m=e&65535;e=f&65535;f=g&65535;g=h&65535;h=i&16;l=j&16;j=b[4860332]|0;o=(i&4096)!=0;do{if((j&2048)==0|o){p=0;q=m;r=j}else{i=c[2431694]|0;s=b[i>>1]|0;t=s&65535;u=0;while(1){if((u|0)>=512){v=13562;break}if((b[i+(u<<1)>>1]|0)==s<<16>>16){u=u+1|0}else{v=13561;break}}if((v|0)==13562){p=0;q=t+m|0;r=j;break}else if((v|0)==13561){eBm(0);p=1;q=m;r=b[4860332]|0;break}}}while(0);m=h<<16>>16!=0;do{if((r&8)==0|m){w=0;x=e}else{h=c[2431692]|0;j=b[h>>1]|0;u=j&65535;s=0;while(1){if((s|0)>=512){v=13568;break}if((b[h+(s<<1)>>1]|0)==j<<16>>16){s=s+1|0}else{v=13567;break}}if((v|0)==13568){w=0;x=u+e|0;break}else if((v|0)==13567){eBm(1);w=1;x=e;break}}}while(0);e=b[4860316]|0;r=n<<16>>16!=0;do{if((e&2048)==0|r){y=0;z=f;A=e}else{n=c[2431690]|0;s=b[n>>1]|0;j=s&65535;h=0;while(1){if((h|0)>=512){v=13574;break}if((b[n+(h<<1)>>1]|0)==s<<16>>16){h=h+1|0}else{v=13573;break}}if((v|0)==13574){y=0;z=j+f|0;A=e;break}else if((v|0)==13573){eBm(2);y=1;z=f;A=b[4860316]|0;break}}}while(0);f=l<<16>>16!=0;do{if((A&8)==0|f){B=g;C=1}else{l=c[2431688]|0;e=b[l>>1]|0;h=e&65535;s=0;while(1){if((s|0)>=512){v=13580;break}if((b[l+(s<<1)>>1]|0)==e<<16>>16){s=s+1|0}else{v=13579;break}}if((v|0)==13580){B=h+g|0;C=1;break}else if((v|0)==13579){eBm(3);B=g;C=0;break}}}while(0);g=(y|0)==0;y=(w|0)==0;w=(p|0)==0;p=c[2438675]|0;v=(p|0)>0;A=c[2430129]|0;s=c[2443301]|0;e=c[2433371]|0;l=c[2438674]|0;j=(l|0)>0;n=c[2430128]|0;u=c[2443300]|0;t=c[2433370]|0;i=c[2438673]|0;D=(i|0)>0;E=c[2430127]|0;F=c[2443299]|0;G=c[2433369]|0;H=c[2438672]|0;I=(H|0)>0;J=c[2430126]|0;K=c[2443298]|0;L=c[2433368]|0;M=0;do{do{if(!o){if(w){eBn(0,M,q);break}if(!I){break}N=c[2113068]|0;O=a[682248]|0?1024:0;P=0;do{if((d[J+P|0]|0)==(M|0)){Q=c[K+(P<<2)>>2]|0;R=k+((ag(Q>>>9,N)|0)+(Q&511)<<1)|0;b[R>>1]=(O|c[L+(P<<2)>>2])&65535}P=P+1|0;}while((P|0)<(H|0))}}while(0);do{if(!m){if(y){eBn(1,M,x);break}if(!D){break}h=c[2113068]|0;P=a[682248]|0?1024:0;O=0;do{if((d[E+O|0]|0)==(M|0)){N=c[F+(O<<2)>>2]|0;R=k+((ag(N>>>9,h)|0)+(N&511)<<1)|0;b[R>>1]=(P|c[G+(O<<2)>>2])&65535}O=O+1|0;}while((O|0)<(i|0))}}while(0);do{if(!r){if(g){eBn(2,M,z);break}if(!j){break}O=c[2113068]|0;P=a[682248]|0?1024:0;h=0;do{if((d[n+h|0]|0)==(M|0)){R=c[u+(h<<2)>>2]|0;N=k+((ag(R>>>9,O)|0)+(R&511)<<1)|0;b[N>>1]=(P|c[t+(h<<2)>>2])&65535}h=h+1|0;}while((h|0)<(l|0))}}while(0);do{if(!f){if(C){eBn(3,M,B);break}if(!v){break}h=c[2113068]|0;P=a[682248]|0?1024:0;O=0;do{if((d[A+O|0]|0)==(M|0)){N=c[s+(O<<2)>>2]|0;R=k+((ag(N>>>9,h)|0)+(N&511)<<1)|0;b[R>>1]=(P|c[e+(O<<2)>>2])&65535}O=O+1|0;}while((O|0)<(p|0))}}while(0);M=M+1|0;}while((M|0)<8);eBo(0);eBo(1);eBo(2);eBo(3);R8(c[2437678]|0);return}function eBy(){var a=0,f=0,g=0,h=0;a=c[2438690]|0;f=a;g=c[2439474]|0;h=(e[a+18>>1]|0)>>>1;switch((e[a+16>>1]|0)>>>8|0){case 67:{gGC(g|0,4799088,128)|0;return};case 2:{gGC(f+((h&65535)<<1)|0,g|0,128)|0;return};case 3:{b[f+((h&65535)<<1)>>1]=-256-((d[14108432]|0)<<8)&65535;return};case 4:{switch(e[a+20>>1]|0|0){case 49:{gGC(f+((h&65535)<<1)|0,1605712,112)|0;return};case 25:{a=f+((h&65535)<<1)|0;b[a>>1]=b[803256]|0;b[a+2>>1]=b[803257]|0;b[a+4>>1]=b[803258]|0;b[a+6>>1]=b[803259]|0;b[a+8>>1]=b[803260]|0;b[a+10>>1]=b[803261]|0;return};case 5:{a=f+((h&65535)<<1)|0;b[a>>1]=b[803368]|0;b[a+2>>1]=b[803369]|0;b[a+4>>1]=b[803370]|0;b[a+6>>1]=b[803371]|0;b[a+8>>1]=b[803372]|0;b[a+10>>1]=b[803373]|0;return};case 0:{a=f+((h&65535)<<1)|0;b[a>>1]=b[803436]|0;b[a+2>>1]=b[803437]|0;b[a+4>>1]=b[803438]|0;b[a+6>>1]=b[803439]|0;b[a+8>>1]=b[803440]|0;b[a+10>>1]=b[803441]|0;return};case 24:{a=f+((h&65535)<<1)|0;b[a>>1]=b[803264]|0;b[a+2>>1]=b[803265]|0;b[a+4>>1]=b[803266]|0;b[a+6>>1]=b[803267]|0;b[a+8>>1]=b[803268]|0;b[a+10>>1]=b[803269]|0;return};case 52:{gGC(f+((h&65535)<<1)|0,1603e3,18)|0;return};case 12:{a=f+((h&65535)<<1)|0;b[a>>1]=b[803328]|0;b[a+2>>1]=b[803329]|0;b[a+4>>1]=b[803330]|0;b[a+6>>1]=b[803331]|0;b[a+8>>1]=b[803332]|0;b[a+10>>1]=b[803333]|0;return};case 26:{a=f+((h&65535)<<1)|0;b[a>>1]=b[803264]|0;b[a+2>>1]=b[803265]|0;b[a+4>>1]=b[803266]|0;b[a+6>>1]=b[803267]|0;b[a+8>>1]=b[803268]|0;b[a+10>>1]=b[803269]|0;return};case 17:{a=f+((h&65535)<<1)|0;b[a>>1]=b[803288]|0;b[a+2>>1]=b[803289]|0;b[a+4>>1]=b[803290]|0;b[a+6>>1]=b[803291]|0;b[a+8>>1]=b[803292]|0;b[a+10>>1]=b[803293]|0;return};case 6:{a=f+((h&65535)<<1)|0;b[a>>1]=b[803360]|0;b[a+2>>1]=b[803361]|0;b[a+4>>1]=b[803362]|0;b[a+6>>1]=b[803363]|0;b[a+8>>1]=b[803364]|0;b[a+10>>1]=b[803365]|0;return};case 22:{a=f+((h&65535)<<1)|0;b[a>>1]=b[803280]|0;b[a+2>>1]=b[803281]|0;b[a+4>>1]=b[803282]|0;b[a+6>>1]=b[803283]|0;b[a+8>>1]=b[803284]|0;b[a+10>>1]=b[803285]|0;return};case 1:{gGC(f+((h&65535)<<1)|0,1606840,28)|0;return};case 8:{a=f+((h&65535)<<1)|0;b[a>>1]=b[803352]|0;b[a+2>>1]=b[803353]|0;b[a+4>>1]=b[803354]|0;b[a+6>>1]=b[803355]|0;b[a+8>>1]=b[803356]|0;b[a+10>>1]=b[803357]|0;return};case 15:{a=f+((h&65535)<<1)|0;b[a>>1]=b[803288]|0;b[a+2>>1]=b[803289]|0;b[a+4>>1]=b[803290]|0;b[a+6>>1]=b[803291]|0;b[a+8>>1]=b[803292]|0;b[a+10>>1]=b[803293]|0;return};case 10:{a=f+((h&65535)<<1)|0;b[a>>1]=b[803344]|0;b[a+2>>1]=b[803345]|0;b[a+4>>1]=b[803346]|0;b[a+6>>1]=b[803347]|0;b[a+8>>1]=b[803348]|0;b[a+10>>1]=b[803349]|0;return};case 4:{gGC(f+((h&65535)<<1)|0,1606752,28)|0;return};case 13:{a=f+((h&65535)<<1)|0;b[a>>1]=b[803320]|0;b[a+2>>1]=b[803321]|0;b[a+4>>1]=b[803322]|0;b[a+6>>1]=b[803323]|0;b[a+8>>1]=b[803324]|0;b[a+10>>1]=b[803325]|0;return};case 20:{a=f+((h&65535)<<1)|0;b[a>>1]=b[803288]|0;b[a+2>>1]=b[803289]|0;b[a+4>>1]=b[803290]|0;b[a+6>>1]=b[803291]|0;b[a+8>>1]=b[803292]|0;b[a+10>>1]=b[803293]|0;return};case 2:{gGC(f+((h&65535)<<1)|0,1606800,36)|0;return};case 11:{a=f+((h&65535)<<1)|0;b[a>>1]=b[803336]|0;b[a+2>>1]=b[803337]|0;b[a+4>>1]=b[803338]|0;b[a+6>>1]=b[803339]|0;b[a+8>>1]=b[803340]|0;b[a+10>>1]=b[803341]|0;return};case 14:{a=f+((h&65535)<<1)|0;b[a>>1]=b[803312]|0;b[a+2>>1]=b[803313]|0;b[a+4>>1]=b[803314]|0;b[a+6>>1]=b[803315]|0;b[a+8>>1]=b[803316]|0;b[a+10>>1]=b[803317]|0;return};case 7:{a=f+((h&65535)<<1)|0;b[a>>1]=b[803264]|0;b[a+2>>1]=b[803265]|0;b[a+4>>1]=b[803266]|0;b[a+6>>1]=b[803267]|0;b[a+8>>1]=b[803268]|0;b[a+10>>1]=b[803269]|0;return};case 28:{a=f+((h&65535)<<1)|0;b[a>>1]=b[803240]|0;b[a+2>>1]=b[803241]|0;b[a+4>>1]=b[803242]|0;b[a+6>>1]=b[803243]|0;b[a+8>>1]=b[803244]|0;b[a+10>>1]=b[803245]|0;return};case 27:{a=f+((h&65535)<<1)|0;b[a>>1]=b[803248]|0;b[a+2>>1]=b[803249]|0;b[a+4>>1]=b[803250]|0;b[a+6>>1]=b[803251]|0;b[a+8>>1]=b[803252]|0;b[a+10>>1]=b[803253]|0;return};case 23:{a=f+((h&65535)<<1)|0;b[a>>1]=b[803272]|0;b[a+2>>1]=b[803273]|0;b[a+4>>1]=b[803274]|0;b[a+6>>1]=b[803275]|0;b[a+8>>1]=b[803276]|0;b[a+10>>1]=b[803277]|0;return};case 48:{gGC(f+((h&65535)<<1)|0,1605824,656)|0;return};case 16:{gGC(f+((h&65535)<<1)|0,1606592,28)|0;return};case 21:{a=f+((h&65535)<<1)|0;b[a>>1]=b[803240]|0;b[a+2>>1]=b[803241]|0;b[a+4>>1]=b[803242]|0;b[a+6>>1]=b[803243]|0;b[a+8>>1]=b[803244]|0;b[a+10>>1]=b[803245]|0;return};case 9:{a=f+((h&65535)<<1)|0;b[a>>1]=b[803288]|0;b[a+2>>1]=b[803289]|0;b[a+4>>1]=b[803290]|0;b[a+6>>1]=b[803291]|0;b[a+8>>1]=b[803292]|0;b[a+10>>1]=b[803293]|0;return};case 50:{gGC(f+((h&65535)<<1)|0,1605584,128)|0;return};case 19:{a=f+((h&65535)<<1)|0;b[a>>1]=b[803288]|0;b[a+2>>1]=b[803289]|0;b[a+4>>1]=b[803290]|0;b[a+6>>1]=b[803291]|0;b[a+8>>1]=b[803292]|0;b[a+10>>1]=b[803293]|0;return};case 18:{a=f+((h&65535)<<1)|0;b[a>>1]=b[803288]|0;b[a+2>>1]=b[803289]|0;b[a+4>>1]=b[803290]|0;b[a+6>>1]=b[803291]|0;b[a+8>>1]=b[803292]|0;b[a+10>>1]=b[803293]|0;return};case 51:{gGC(f+((h&65535)<<1)|0,1603024,2560)|0;return};case 3:{a=f+((h&65535)<<1)|0;b[a>>1]=b[803392]|0;b[a+2>>1]=b[803393]|0;b[a+4>>1]=b[803394]|0;b[a+6>>1]=b[803395]|0;b[a+8>>1]=b[803396]|0;b[a+10>>1]=b[803397]|0;return};default:{return}}break};case 66:{gGC(g|0,f+((h&65535)<<1)|0,128)|0;return};default:{return}}}function eBz(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;e=b[4860330]|0;f=b[4860328]|0;g=b[4860314]|0;h=b[4860312]|0;i=b[4860332]|0;j=b[4860316]|0;k=c[2112926]|0;gGz(k|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);k=0;l=c[2430152]|0;m=c[2437678]|0;while(1){n=b[l>>1]|0;c[m>>2]=((n&65535)>>>5<<3&248)<<8|((n&255)<<3&255)>>>3|(((n&65535)>>>12&4|(n&65535)>>>10<<3&255)&255)<<3&2016;n=k+1|0;if((n|0)<65536){k=n;l=l+2|0;m=m+4|0}else{break}}m=j&4096;l=e&65535;e=f&65535;f=g&65535;g=h&65535;h=i&16;k=j&16;if((b[4858644]|0)==0){return}j=b[4860332]|0;n=(i&4096)!=0;do{if((j&2048)==0|n){o=0;p=l;q=j}else{i=c[2431694]|0;r=b[i>>1]|0;s=r&65535;t=0;while(1){if((t|0)>=512){u=13705;break}if((b[i+(t<<1)>>1]|0)==r<<16>>16){t=t+1|0}else{u=13704;break}}if((u|0)==13704){eBm(0);o=1;p=l;q=b[4860332]|0;break}else if((u|0)==13705){o=0;p=s+l|0;q=j;break}}}while(0);j=h<<16>>16!=0;do{if((q&8)==0|j){v=0;w=e}else{h=c[2431692]|0;l=b[h>>1]|0;t=l&65535;r=0;while(1){if((r|0)>=512){u=13711;break}if((b[h+(r<<1)>>1]|0)==l<<16>>16){r=r+1|0}else{u=13710;break}}if((u|0)==13711){v=0;w=t+e|0;break}else if((u|0)==13710){eBm(1);v=1;w=e;break}}}while(0);e=b[4860316]|0;q=m<<16>>16!=0;do{if((e&2048)==0|q){x=0;y=f;z=e}else{m=c[2431690]|0;r=b[m>>1]|0;l=r&65535;h=0;while(1){if((h|0)>=512){u=13717;break}if((b[m+(h<<1)>>1]|0)==r<<16>>16){h=h+1|0}else{u=13716;break}}if((u|0)==13717){x=0;y=l+f|0;z=e;break}else if((u|0)==13716){eBm(2);x=1;y=f;z=b[4860316]|0;break}}}while(0);f=k<<16>>16!=0;do{if((z&8)==0|f){A=g;B=1}else{k=c[2431688]|0;e=b[k>>1]|0;h=e&65535;r=0;while(1){if((r|0)>=512){u=13723;break}if((b[k+(r<<1)>>1]|0)==e<<16>>16){r=r+1|0}else{u=13722;break}}if((u|0)==13723){A=h+g|0;B=1;break}else if((u|0)==13722){eBm(3);A=g;B=0;break}}}while(0);g=(x|0)==0;x=(v|0)==0;v=(o|0)==0;o=0;while(1){do{if(!n){if(v){eBn(0,o,p);break}u=c[2438672]|0;if((u|0)<=0){break}z=c[2430126]|0;r=c[2112926]|0;e=c[2443298]|0;k=c[2113068]|0;l=c[2433368]|0;m=a[682248]|0?1024:0;t=0;do{if((d[z+t|0]|0)==(o|0)){s=c[e+(t<<2)>>2]|0;i=r+((ag(s>>>9,k)|0)+(s&511)<<1)|0;b[i>>1]=(m|c[l+(t<<2)>>2])&65535}t=t+1|0;}while((t|0)<(u|0))}}while(0);do{if(!j){if(x){eBn(1,o,w);break}h=c[2438673]|0;if((h|0)<=0){break}u=c[2430127]|0;t=c[2112926]|0;l=c[2443299]|0;m=c[2113068]|0;k=c[2433369]|0;r=a[682248]|0?1024:0;e=0;do{if((d[u+e|0]|0)==(o|0)){z=c[l+(e<<2)>>2]|0;i=t+((ag(z>>>9,m)|0)+(z&511)<<1)|0;b[i>>1]=(r|c[k+(e<<2)>>2])&65535}e=e+1|0;}while((e|0)<(h|0))}}while(0);do{if(!q){if(g){eBn(2,o,y);break}h=c[2438674]|0;if((h|0)<=0){break}e=c[2430128]|0;k=c[2112926]|0;r=c[2443300]|0;m=c[2113068]|0;t=c[2433370]|0;l=a[682248]|0?1024:0;u=0;do{if((d[e+u|0]|0)==(o|0)){i=c[r+(u<<2)>>2]|0;z=k+((ag(i>>>9,m)|0)+(i&511)<<1)|0;b[z>>1]=(l|c[t+(u<<2)>>2])&65535}u=u+1|0;}while((u|0)<(h|0))}}while(0);do{if(!f){if(B){eBn(3,o,A);break}h=c[2438675]|0;if((h|0)<=0){break}u=c[2430129]|0;t=c[2112926]|0;l=c[2443301]|0;m=c[2113068]|0;k=c[2433371]|0;r=a[682248]|0?1024:0;e=0;do{if((d[u+e|0]|0)==(o|0)){z=c[l+(e<<2)>>2]|0;i=t+((ag(z>>>9,m)|0)+(z&511)<<1)|0;b[i>>1]=(r|c[k+(e<<2)>>2])&65535}e=e+1|0;}while((e|0)<(h|0))}}while(0);if((o|0)==4){eBo(2)}else if((o|0)==2){eBo(1)}else if((o|0)==6){eBo(3)}else if((o|0)==1){eBo(0)}else{h=o+1|0;if((h|0)<8){o=h;continue}else{break}}o=o+1|0}R8(c[2437678]|0);return}function eBA(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;e=i;i=i+272|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;l=e+80|0;m=e+96|0;n=e+112|0;o=e+128|0;p=e+144|0;q=e+160|0;r=e+176|0;s=e+192|0;t=e+208|0;u=e+224|0;v=e+240|0;w=e+256|0;if((d|0)!=0){c[d>>2]=169586}if(a[5334064]|0){Ts(b,d)}d=c[2439474]|0;if((b&8|0)!=0&(d|0)!=0){gGz(w|0,0,12);c[w>>2]=d;c[w+4>>2]=256;c[w+12>>2]=544120;d=c[2076592]|0;gj[d&4095](w)|0}if((b&32|0)!=0){gGz(w|0,0,12);d=c[2405618]|0;c[w>>2]=d;c[w+4>>2]=(c[2411564]|0)-d;c[w+12>>2]=162152;d=c[2076592]|0;gj[d&4095](w)|0}if((b&64|0)==0){i=e;return}b=h|0;gGz(g|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){w=h+9|0;h=f;d=f|0;x=f+4|0;y=f+12|0;z=g|0;A=g+4|0;B=g+12|0;C=0;do{gGC(b|0,614896,11)|0;a[w]=C+48&255;D=8452256+(C<<2)|0;gGz(h|0,0,12);c[d>>2]=D;c[x>>2]=4;c[y>>2]=164976;gj[c[2076592]&4095](f)|0;if((c[D>>2]|0)!=0){c[z>>2]=c[14130368+(C<<2)>>2];c[A>>2]=c[8452184+(C<<2)>>2];c[B>>2]=b;D=c[2076592]|0;gj[D&4095](g)|0}C=C+1|0;}while((C|0)<=(c[2392]|0))}gGz(v|0,0,12);c[v>>2]=9776256;c[v+4>>2]=8;c[v+12>>2]=212472;gj[c[2076592]&4095](v)|0;gGz(u|0,0,12);c[u>>2]=9752720;c[u+4>>2]=4;c[u+12>>2]=436576;gj[c[2076592]&4095](u)|0;gGz(t|0,0,12);c[t>>2]=14108432;c[t+4>>2]=2;c[t+12>>2]=539720;gj[c[2076592]&4095](t)|0;gGz(s|0,0,12);c[s>>2]=9757904;c[s+4>>2]=4;c[s+12>>2]=538360;gj[c[2076592]&4095](s)|0;gGz(r|0,0,12);c[r>>2]=9720600;c[r+4>>2]=4;c[r+12>>2]=536504;gj[c[2076592]&4095](r)|0;gGz(q|0,0,12);c[q>>2]=9718920;c[q+4>>2]=2;c[q+12>>2]=534456;gj[c[2076592]&4095](q)|0;gGz(p|0,0,12);c[p>>2]=9718912;c[p+4>>2]=2;c[p+12>>2]=532944;gj[c[2076592]&4095](p)|0;gGz(o|0,0,12);c[o>>2]=9717288;c[o+4>>2]=2;c[o+12>>2]=531664;gj[c[2076592]&4095](o)|0;gGz(n|0,0,12);c[n>>2]=9720536;c[n+4>>2]=64;c[n+12>>2]=530624;gj[c[2076592]&4095](n)|0;gGz(m|0,0,12);c[m>>2]=9720656;c[m+4>>2]=32;c[m+12>>2]=529648;gj[c[2076592]&4095](m)|0;gGz(l|0,0,12);c[l>>2]=9720624;c[l+4>>2]=32;c[l+12>>2]=528824;gj[c[2076592]&4095](l)|0;if(!(a[6872968]|0)){i=e;return}gGz(k|0,0,12);c[k>>2]=9750720;c[k+4>>2]=2;c[k+12>>2]=527832;gj[c[2076592]&4095](k)|0;gGz(j|0,0,12);c[j>>2]=9720720;c[j+4>>2]=2;c[j+12>>2]=526312;gj[c[2076592]&4095](j)|0;i=e;return}function eBB(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;c[2439476]=0;b=0;d=0;e=0;f=0;g=0;do{d=((a[9720712+b|0]&1)<<b|d&255)&255;e=((a[9720704+b|0]&1)<<b|e&255)&255;f=((a[9720696+b|0]&1)<<b|f&255)&255;g=((a[9720688+b|0]&1)<<b|g&255)&255;b=b+1|0;}while((b|0)<8);a[9757904]=d;a[9757905]=e;a[9757906]=f;a[9757907]=g;if((d&3)==3){g=d&-4;a[9757904]=g;h=g}else{h=d}if((h&12)==12){a[9757904]=h&-13}if((e&3)==3){h=e&-4;a[9757905]=h;i=h}else{i=e}if((i&12)!=12){return}a[9757905]=i&-13;return}function eBC(){var a=0,f=0,g=0,h=0,i=0;a=c[2438690]|0;f=a;g=c[2439474]|0;h=(e[a+18>>1]|0)>>>1;i=(e[a+16>>1]|0)>>>8;if((i|0)==3){b[f+((h&65535)<<1)>>1]=-256-((d[14108432]|0)<<8)&65535;return}else if((i|0)==4){switch(e[a+20>>1]|0|0){case 26:{gGC(f+((h&65535)<<1)|0,1143368,1904)|0;return};case 9:{gGC(f+((h&65535)<<1)|0,1165272,32)|0;return};case 32:{gGC(f+((h&65535)<<1)|0,1133944,1104)|0;return};case 19:{gGC(f+((h&65535)<<1)|0,1152280,880)|0;return};case 23:{gGC(f+((h&65535)<<1)|0,1147032,528)|0;return};case 1:{gGC(f+((h&65535)<<1)|0,1165528,32)|0;return};case 28:{gGC(f+((h&65535)<<1)|0,1140536,928)|0;return};case 31:{gGC(f+((h&65535)<<1)|0,1135048,1232)|0;return};case 17:{gGC(f+((h&65535)<<1)|0,1154040,1024)|0;return};case 5:{gGC(f+((h&65535)<<1)|0,1165400,32)|0;return};case 20:{gGC(f+((h&65535)<<1)|0,1150184,2096)|0;return};case 6:{gGC(f+((h&65535)<<1)|0,1165368,32)|0;return};case 11:{gGC(f+((h&65535)<<1)|0,1159736,2768)|0;return};case 8:{gGC(f+((h&65535)<<1)|0,1165304,32)|0;return};case 35:{gGC(f+((h&65535)<<1)|0,1127256,2416)|0;return};case 10:{gGC(f+((h&65535)<<1)|0,1162504,2768)|0;return};case 2:{gGC(f+((h&65535)<<1)|0,1165496,32)|0;return};case 38:{gGC(f+((h&65535)<<1)|0,1123512,1008)|0;return};case 33:{gGC(f+((h&65535)<<1)|0,1131496,2448)|0;return};case 36:{gGC(f+((h&65535)<<1)|0,1125576,1680)|0;return};case 14:{gGC(f+((h&65535)<<1)|0,1156712,624)|0;return};case 22:{gGC(f+((h&65535)<<1)|0,1147560,528)|0;return};case 29:{gGC(f+((h&65535)<<1)|0,1138344,2192)|0;return};case 21:{gGC(f+((h&65535)<<1)|0,1148088,2096)|0;return};case 18:{gGC(f+((h&65535)<<1)|0,1153160,880)|0;return};case 39:{gGC(f+((h&65535)<<1)|0,1122440,1072)|0;return};case 40:{gGC(f+((h&65535)<<1)|0,1121400,1040)|0;return};case 42:{gGC(f+((h&65535)<<1)|0,1119336,1024)|0;return};case 12:{gGC(f+((h&65535)<<1)|0,1158536,1200)|0;return};case 27:{gGC(f+((h&65535)<<1)|0,1141464,1904)|0;return};case 41:{gGC(f+((h&65535)<<1)|0,1120360,1040)|0;return};case 7:{gGC(f+((h&65535)<<1)|0,1165336,32)|0;return};case 3:{gGC(f+((h&65535)<<1)|0,1165464,32)|0;return};case 44:{gGC(f+((h&65535)<<1)|0,1117304,1024)|0;return};case 15:{gGC(f+((h&65535)<<1)|0,1156088,624)|0;return};case 34:{gGC(f+((h&65535)<<1)|0,1129672,1824)|0;return};case 25:{gGC(f+((h&65535)<<1)|0,1145272,880)|0;return};case 43:{gGC(f+((h&65535)<<1)|0,1118328,1008)|0;return};case 37:{gGC(f+((h&65535)<<1)|0,1124520,1056)|0;return};case 45:{gGC(f+((h&65535)<<1)|0,1116280,1024)|0;return};case 13:{gGC(f+((h&65535)<<1)|0,1157336,1200)|0;return};case 24:{gGC(f+((h&65535)<<1)|0,1146152,880)|0;return};case 30:{gGC(f+((h&65535)<<1)|0,1136280,2064)|0;return};case 4:{gGC(f+((h&65535)<<1)|0,1165432,32)|0;return};case 16:{gGC(f+((h&65535)<<1)|0,1155064,1024)|0;return};default:{return}}}else if((i|0)==66){a=f+((h&65535)<<1)|0;gGC(g|0,a|0,128)|0;return}else if((i|0)==2){i=f+((h&65535)<<1)|0;gGC(i|0,g|0,128)|0;return}else{return}}function eBD(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;e=b[4860330]|0;f=b[4860328]|0;g=b[4860332]|0;h=c[2112926]|0;gGz(h|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);h=0;i=c[2430152]|0;j=c[2437678]|0;while(1){k=b[i>>1]|0;c[j>>2]=((k&65535)>>>5<<3&248)<<8|((k&255)<<3&255)>>>3|(((k&65535)>>>12&4|(k&65535)>>>10<<3&255)&255)<<3&2016;k=h+1|0;if((k|0)<2048){h=k;i=i+2|0;j=j+4|0}else{break}}j=e&65535;e=f&65535;f=g&16;i=b[4860332]|0;h=(g&4096)!=0;do{if((i&2048)==0|h){l=0;m=j;n=i}else{g=c[2431694]|0;k=b[g>>1]|0;o=k&65535;p=0;while(1){if((p|0)>=512){q=13909;break}if((b[g+(p<<1)>>1]|0)==k<<16>>16){p=p+1|0}else{q=13908;break}}if((q|0)==13908){eBm(0);l=1;m=j;n=b[4860332]|0;break}else if((q|0)==13909){l=0;m=o+j|0;n=i;break}}}while(0);i=f<<16>>16!=0;do{if((n&8)==0|i){r=e;s=1}else{f=c[2431692]|0;j=b[f>>1]|0;p=j&65535;k=0;while(1){if((k|0)>=512){q=13915;break}if((b[f+(k<<1)>>1]|0)==j<<16>>16){k=k+1|0}else{q=13914;break}}if((q|0)==13915){r=p+e|0;s=1;break}else if((q|0)==13914){eBm(1);r=e;s=0;break}}}while(0);e=(l|0)==0;l=0;while(1){do{if(!h){if(e){eBn(0,l,m);break}n=c[2438672]|0;if((n|0)<=0){break}k=c[2430126]|0;j=c[2112926]|0;f=c[2443298]|0;o=c[2113068]|0;g=c[2433368]|0;t=a[682248]|0?1024:0;u=0;do{if((d[k+u|0]|0)==(l|0)){v=c[f+(u<<2)>>2]|0;w=j+((ag(v>>>9,o)|0)+(v&511)<<1)|0;b[w>>1]=(t|c[g+(u<<2)>>2])&65535}u=u+1|0;}while((u|0)<(n|0))}}while(0);do{if(!i){if(s){eBn(1,l,r);break}p=c[2438673]|0;if((p|0)<=0){break}n=c[2430127]|0;u=c[2112926]|0;g=c[2443299]|0;t=c[2113068]|0;o=c[2433369]|0;j=a[682248]|0?1024:0;f=0;do{if((d[n+f|0]|0)==(l|0)){k=c[g+(f<<2)>>2]|0;w=u+((ag(k>>>9,t)|0)+(k&511)<<1)|0;b[w>>1]=(j|c[o+(f<<2)>>2])&65535}f=f+1|0;}while((f|0)<(p|0))}}while(0);if((l|0)==0){eBo(0)}else if((l|0)==1){eBo(1)}else if((l|0)==7){break}else{p=l+1|0;if((p|0)<8){l=p;continue}else{q=13941;break}}l=l+1|0}if((q|0)==13941){x=c[2437678]|0;R8(x);return}eBo(2);eBo(3);x=c[2437678]|0;R8(x);return}function eBE(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0;d=c[2431696]|0;f=a<<3;a=f|4;if((a|0)>=(c[2429320]>>1|0)){g=-1;return g|0}h=e[d+(a<<1)>>1]|0;c[b>>2]=e[d+((f|5)<<1)>>1]|0;c[b+8>>2]=e[d+((f|6)<<1)>>1]|0;c[b+12>>2]=e[d+((f|7)<<1)>>1]|0;c[b+4>>2]=h>>>2&63;c[b+32>>2]=h>>>8&3;c[b+28>>2]=h&1;c[b+24>>2]=h&2;f=h>>>11<<1&6;d=e[9720536+((f|9)<<1)>>1]|0;a=b+20|0;c[a>>2]=d;c[b+16>>2]=e[9720536+((f|8)<<1)>>1]|0;c[a>>2]=d-(e[4860269]|0);g=h>>>13&1|h>>>12&4|h>>>14&2;return g|0}function eBF(b){b=b|0;return a[14108432]|0}function eBG(b){b=b|0;return a[14108433]|0}function eBH(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;f=b[4860330]|0;g=b[4860328]|0;h=b[4860332]|0;i=c[2112926]|0;gGz(i|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);j=c[2437678]|0;k=0;l=c[2430152]|0;m=j;while(1){n=b[l>>1]|0;c[m>>2]=((n&65535)>>>5<<3&248)<<8|((n&255)<<3&255)>>>3|(((n&65535)>>>12&4|(n&65535)>>>10<<3&255)&255)<<3&2016;n=k+1|0;if((n|0)<2048){k=n;l=l+2|0;m=m+4|0}else{break}}m=h&4096;l=f&65535;f=g&65535;g=h&16;if((a[9707944]|0)!=0){h=0;do{c[j+(h+2048<<2)>>2]=((h&255)<<3&255)>>>3|h>>>5<<11&63488|((h>>>12&4|h>>>10<<3&255)&255)<<3&2016;h=h+1|0;}while((h|0)<32768);a[9707944]=0}h=b[4860332]|0;j=m<<16>>16!=0;do{if((h&2048)==0|j){o=0;p=l;q=h}else{m=c[2431694]|0;k=b[m>>1]|0;n=k&65535;r=0;while(1){if((r|0)>=512){s=13959;break}if((b[m+(r<<1)>>1]|0)==k<<16>>16){r=r+1|0}else{s=13958;break}}if((s|0)==13958){eBm(0);o=1;p=l;q=b[4860332]|0;break}else if((s|0)==13959){o=0;p=n+l|0;q=h;break}}}while(0);h=g<<16>>16!=0;do{if((q&8)==0|h){t=0;u=f}else{g=c[2431692]|0;l=b[g>>1]|0;r=l&65535;k=0;while(1){if((k|0)>=512){s=13965;break}if((b[g+(k<<1)>>1]|0)==l<<16>>16){k=k+1|0}else{s=13964;break}}if((s|0)==13965){t=0;u=r+f|0;break}else if((s|0)==13964){eBm(1);t=1;u=f;break}}}while(0);f=e[4860360]|0;q=c[2113070]|0;if((q|0)>0){k=((f&32|0)==0?f:f^31)<<16&2031616|4096;f=c[2113068]|0;l=c[2433416]|0;g=0;do{n=ag(g,f)|0;if((f|0)>0){m=(g<<8)+k|0;v=0;do{b[i+(v+n<<1)>>1]=b[l+(m+v<<1)>>1]|0;v=v+1|0;}while((v|0)<(f|0))}g=g+1|0;}while((g|0)<(q|0))}q=(t|0)==0;t=(o|0)==0;o=0;while(1){do{if(!j){if(t){eBn(0,o,p);break}g=c[2438672]|0;if((g|0)<=0){break}f=c[2430126]|0;l=c[2112926]|0;i=c[2443298]|0;k=c[2113068]|0;v=c[2433368]|0;m=a[682248]|0?1024:0;n=0;do{if((d[f+n|0]|0)==(o|0)){r=c[i+(n<<2)>>2]|0;w=l+((ag(r>>>9,k)|0)+(r&511)<<1)|0;b[w>>1]=(m|c[v+(n<<2)>>2])&65535}n=n+1|0;}while((n|0)<(g|0))}}while(0);do{if(!h){if(q){eBn(1,o,u);break}g=c[2438673]|0;if((g|0)<=0){break}n=c[2430127]|0;v=c[2112926]|0;m=c[2443299]|0;k=c[2113068]|0;l=c[2433369]|0;i=a[682248]|0?1024:0;f=0;do{if((d[n+f|0]|0)==(o|0)){w=c[m+(f<<2)>>2]|0;r=v+((ag(w>>>9,k)|0)+(w&511)<<1)|0;b[r>>1]=(i|c[l+(f<<2)>>2])&65535}f=f+1|0;}while((f|0)<(g|0))}}while(0);if((o|0)==2){eBo(2)}else if((o|0)==0){eBo(0)}else if((o|0)==7){break}else if((o|0)==1){eBo(1)}else{g=o+1|0;if((g|0)<8){o=g;continue}else{s=13998;break}}o=o+1|0}if((s|0)==13998){x=c[2437678]|0;R8(x);return}eBo(3);x=c[2437678]|0;R8(x);return}function eBI(b,e){b=b|0;e=e|0;if((b|0)==1048590){a[(c[2385208]|0)+(d[c[2385210]|0]|0)|0]=e&31;return}else if((b|0)==1048576){a[c[2385210]|0]=e&3;return}else{return}}function eBJ(d,e){d=d|0;e=e|0;if((d|0)==1048578){b[c[3525086]>>1]=e&1023;return}else if((d|0)==1048584){b[c[3526952]>>1]=e+8&511;return}else if((d|0)==1048580){b[c[3525078]>>1]=e+8&511;return}else if((d|0)==2555904){a[c[3528230]|0]=e&255;return}else if((d|0)==1048582){b[c[3526960]>>1]=e+4&1023;return}else{return}}function eBK(a){a=a|0;var b=0;if((a|0)!=2621442){b=0;return b|0}b=(e[4775149]|0)>>>8&255;return b|0}function eBL(a){a=a|0;var c=0;if(!((a|0)==2621440|(a|0)==2621442|(a|0)==2621444)){c=0;return c|0}c=b[9550296+((a>>>1&3)<<1)>>1]|0;return c|0}function eBM(d,e){d=d|0;e=e|0;var f=0;if((d&268433408|0)!=2097152){return}f=c[2387138]|0;a[f+(d&2047^1)|0]=e;e=d&2046;d=b[f+e>>1]|0;c[(c[3529938]|0)+(e>>>1<<2)>>2]=((d&65535)>>>10<<3&248)<<8|((d&255)<<3&255)>>>3|(((d&65535)>>>5<<3&255|(d&65535)>>>7&4)&255)<<3&2016;return}function eBN(a,d){a=a|0;d=d|0;var e=0;if((a&268433408|0)!=2097152){return}e=a&2046;b[(c[2387138]|0)+e>>1]=d;c[(c[3529938]|0)+(e>>>1<<2)>>2]=((d&65535)>>>10<<3&248)<<8|((d&255)<<3&255)>>>3|(((d&65535)>>>5<<3&255|(d&65535)>>>7&4)&255)<<3&2016;return}function eBO(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((e|0)==49153){b=c[2113304]|0;a[14168504+b|0]=d;mv(0,b,d&255);return}else if((e|0)==49154|(e|0)==49155){Uv(0,d);return}else if((e|0)==49152){c[2113304]=d&255;return}else{return}}function eBP(b){b=b|0;var d=0,e=0;d=b&65535;if((d|0)==49158){e=a[c[3528230]|0]|0}else if((d|0)==49154|(d|0)==49155){e=c[2113156]&255}else if((d|0)==49153){e=c[(c[3531464]|0)+4240>>2]&255}else{e=0}return e|0}function eBQ(b){b=b|0;var c=0;c=(b|0)!=0|0;if((c|0)==0){a[9706117]=0;return}else if((c|0)==1){a[9706117]=1;return}else{return}}function eBR(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4394812+(b*112|0)>>2];c[a+104>>2]=c[4394816+(b*112|0)>>2];c[a+108>>2]=c[4394820+(b*112|0)>>2];d=0;return d|0}function eBS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=4394712+(b*112|0);e=0;return e|0}function eBT(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1695808+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eBU(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>23){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4993240+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eBV(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;e=i;i=i+384|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+256|0;n=e+320|0;c[2414904]=0;c[2388100]=0;c[2385884]=1048576;c[3530786]=1114112;c[3530550]=9502720;c[3541206]=13697024;c[2386608]=13697024;c[3529938]=13959168;c[2414606]=13962240;c[2388230]=13962240;c[2387138]=14027776;c[2406480]=14029824;c[2406556]=14033920;c[2386414]=14038016;c[2386038]=14040064;c[3528230]=14042112;c[2385210]=14042113;c[2385208]=14042114;c[3525086]=14042118;c[3526960]=14042120;c[3525078]=14042122;c[3526952]=14042124;c[2411562]=14042126;o=0;while(1){if((o|0)>=1024){break}p=9638528+(o<<2)|0;if((c[p>>2]|0)==0){q=14089;break}else{o=o+1|0}}do{if((q|0)==14089){o=gGq(14042126)|0;c[p>>2]=o;if((o|0)==0){break}c[2414904]=o;gGz(o|0,0,14042126);c[2388100]=o;c[2385884]=o+1048576;c[3530786]=o+1114112;c[3530550]=o+9502720;r=o+13697024|0;c[3541206]=r;c[2386608]=r;c[3529938]=o+13959168;r=o+13962240|0;c[2414606]=r;c[2388230]=r;c[2387138]=o+14027776;c[2406480]=o+14029824;c[2406556]=o+14033920;c[2386414]=o+14038016;c[2386038]=o+14040064;c[3528230]=o+14042112;c[2385210]=o+14042113;c[2385208]=o+14042114;c[3525086]=o+14042118;c[3526960]=o+14042120;c[3525078]=o+14042122;c[3526952]=o+14042124;r=o+14042126|0;c[2411562]=r;c[2414102]=r;if((R6(o+1|0,0,2)|0)!=0){s=1;i=e;return s|0}if((R6(c[2388100]|0,1,2)|0)!=0){s=1;i=e;return s|0}o=c[2385884]|0;if((c[3542200]|0)==0){s=1;i=e;return s|0}r=j+108|0;c[r>>2]=0;t=j+100|0;c[t>>2]=0;u=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[u&16383](j,2)|0;do{if((c[r>>2]|0)!=0){u=c[t>>2]|0;c[k>>2]=9534384;v=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[v&16383](k,2,0)|0;if((u|0)<1){s=1;i=e;return s|0}if((gzL(o,0,2)|0)==0){break}else{s=1}i=e;return s|0}}while(0);o=c[2386608]|0;if((c[3542200]|0)==0){s=1;i=e;return s|0}t=f+108|0;c[t>>2]=0;r=f+100|0;c[r>>2]=0;u=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[u&16383](f,3)|0;do{if((c[t>>2]|0)!=0){u=c[r>>2]|0;c[g>>2]=9534384;v=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[v&16383](g,3,0)|0;if((u|0)<1){s=1;i=e;return s|0}if((gzL(o,0,3)|0)==0){break}else{s=1}i=e;return s|0}}while(0);if((R6(c[3530550]|0,4,2)|0)!=0){s=1;i=e;return s|0}if((R6((c[3530550]|0)+1|0,5,2)|0)!=0){s=1;i=e;return s|0}if((R6((c[3530550]|0)+1048576|0,6,2)|0)!=0){s=1;i=e;return s|0}if((R6((c[3530550]|0)+1048577|0,7,2)|0)!=0){s=1;i=e;return s|0}if((R6((c[3530550]|0)+2097152|0,8,2)|0)!=0){s=1;i=e;return s|0}if((R6((c[3530550]|0)+2097153|0,9,2)|0)!=0){s=1;i=e;return s|0}if((R6((c[3530550]|0)+3145728|0,10,2)|0)!=0){s=1;i=e;return s|0}if((R6((c[3530550]|0)+3145729|0,11,2)|0)!=0){s=1;i=e;return s|0}o=c[3530550]|0;r=c[3530786]|0;t=0;do{a[r+((t<<3&2097152|t&262143|t>>>1&1835008)^2097184)|0]=a[o+t|0]|0;t=t+1|0;}while((t|0)<4194304);if((R6(o,12,2)|0)!=0){s=1;i=e;return s|0}if((R6((c[3530550]|0)+1|0,13,2)|0)!=0){s=1;i=e;return s|0}if((R6((c[3530550]|0)+1048576|0,14,2)|0)!=0){s=1;i=e;return s|0}if((R6((c[3530550]|0)+1048577|0,15,2)|0)!=0){s=1;i=e;return s|0}t=c[3530786]|0;r=m;u=n;v=l|0;c[v>>2]=16777224;w=l+4|0;c[w>>2]=16777216;x=l+8|0;c[x>>2]=8;y=l+12|0;c[y>>2]=0;gGC(r|0,613816,64)|0;gGC(u|0,608544,64)|0;z=0;while(1){if((z|0)>=1024){break}A=9638528+(z<<2)|0;if((c[A>>2]|0)==0){q=14118;break}else{z=z+1|0}}L19083:do{if((q|0)==14118){z=gGq(4194304)|0;c[A>>2]=z;if((z|0)==0){break}gGz(z|0,0,4194304);gGC(z|0,t|0,4194304)|0;o=0;while(1){B=o<<8;gGz(t+B|0,0,256);C=o<<9;D=0;do{E=1<<3-D;F=(c[l+(D<<2)>>2]|0)+C|0;G=0;do{H=F+(c[n+(G<<2)>>2]|0)|0;I=(G<<4)+B|0;J=0;do{K=H+(c[m+(J<<2)>>2]|0)|0;if(((d[z+((K|0)/8|0)|0]|0)&128>>>((K&7)>>>0)|0)!=0){K=t+(I+J)|0;a[K]=(d[K]|0|E)&255}J=J+1|0;}while((J|0)<16);G=G+1|0;}while((G|0)<16);D=D+1|0;}while((D|0)<4);D=o+1|0;if((D|0)<32768){o=D}else{L=0;break}}while(1){if((L|0)>=1024){break L19083}M=9638528+(L<<2)|0;if((c[M>>2]|0)==(z|0)){break}else{L=L+1|0}}gGr(z);c[M>>2]=0}}while(0);t=c[3530550]|0;c[v>>2]=8388616;c[w>>2]=8388608;c[x>>2]=8;c[y>>2]=0;gGC(r|0,613816,64)|0;gGC(u|0,608544,64)|0;o=0;while(1){if((o|0)>=1024){break}N=9638528+(o<<2)|0;if((c[N>>2]|0)==0){q=14135;break}else{o=o+1|0}}L19108:do{if((q|0)==14135){o=gGq(2097152)|0;c[N>>2]=o;if((o|0)==0){break}gGz(o|0,0,2097152);gGC(o|0,t|0,2097152)|0;u=0;while(1){r=u<<8;gGz(t+r|0,0,256);y=u<<9;x=0;do{w=1<<3-x;v=(c[l+(x<<2)>>2]|0)+y|0;D=0;do{B=v+(c[n+(D<<2)>>2]|0)|0;C=(D<<4)+r|0;G=0;do{E=B+(c[m+(G<<2)>>2]|0)|0;if(((d[o+((E|0)/8|0)|0]|0)&128>>>((E&7)>>>0)|0)!=0){E=t+(C+G)|0;a[E]=(d[E]|0|w)&255}G=G+1|0;}while((G|0)<16);D=D+1|0;}while((D|0)<16);x=x+1|0;}while((x|0)<4);x=u+1|0;if((x|0)<16384){u=x}else{O=0;break}}while(1){if((O|0)>=1024){break L19108}P=9638528+(O<<2)|0;if((c[P>>2]|0)==(o|0)){break}else{O=O+1|0}}gGr(o);c[P>>2]=0}}while(0);fxU(0,425984);if((c[2394]|0)==0){Q=c[2112932]|0}else{c[2394]=0;t=c[3532596]|0;c[2112932]=t;u=c[3532592]|0;if((u|0)!=0){gGC(9104152,u|0,280)|0}c[2113054]=c[2113060];Q=t}t=c[2388100]|0;u=Q|0;z=0;while(1){x=t+z|0;c[u>>2]=x;c[u+131072>>2]=x;x=z+1024|0;if(x>>>0>1048575){break}else{u=u+4|0;z=x}}z=c[2406480]|0;c[Q+4608>>2]=z;c[Q+70144>>2]=z;c[Q+135680>>2]=z;u=z+1024|0;c[Q+4612>>2]=u;c[Q+70148>>2]=u;c[Q+135684>>2]=u;u=z+2048|0;c[Q+4616>>2]=u;c[Q+70152>>2]=u;c[Q+135688>>2]=u;u=z+3072|0;c[Q+4620>>2]=u;c[Q+70156>>2]=u;c[Q+135692>>2]=u;u=c[2406556]|0;c[Q+4640>>2]=u;c[Q+70176>>2]=u;c[Q+135712>>2]=u;z=u+1024|0;c[Q+4644>>2]=z;c[Q+70180>>2]=z;c[Q+135716>>2]=z;z=u+2048|0;c[Q+4648>>2]=z;c[Q+70184>>2]=z;c[Q+135720>>2]=z;z=u+3072|0;c[Q+4652>>2]=z;c[Q+70188>>2]=z;c[Q+135724>>2]=z;z=c[2387138]|0;c[Q+8192>>2]=z;c[Q+139264>>2]=z;u=z+1024|0;c[Q+8196>>2]=u;c[Q+139268>>2]=u;u=c[2386414]|0;c[Q+8448>>2]=u;c[Q+73984>>2]=u;c[Q+139520>>2]=u;z=u+1024|0;c[Q+8452>>2]=z;c[Q+73988>>2]=z;c[Q+139524>>2]=z;z=c[2388230]|0;u=Q+12288|0;t=3145728;while(1){x=z+(t-3145728)|0;c[u>>2]=x;c[u+65536>>2]=x;c[u+131072>>2]=x;x=t+1024|0;if(x>>>0>3211263){break}else{u=u+4|0;t=x}}c[Q+196648>>2]=3190;c[Q+196728>>2]=924;c[Q+196608>>2]=624;c[Q+196688>>2]=2526;c[Q+73728>>2]=1;c[Q+73732>>2]=1;c[Q+196652>>2]=2842;c[Q+196732>>2]=1904;t=c[3532592]|0;if((t|0)!=0){gGC(t|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);t=c[2439330]|0;u=(t|0)==0;if(!u){z=t;gGC(9706056,z|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];z=c[3528484]|0;c[2076596]=z;x=c[2417276]|0;c[3541536]=x;c[1836236]=0;r=c[2385884]|0;y=0;D=0;while(1){c[t+76+(D<<2)>>2]=r+(D<<8);w=y+1&65535;if((w&65535)>191){R=0;S=0;break}else{y=w;D=w&65535}}while(1){D=r+(S<<8)|0;c[t+76+(S+512<<2)>>2]=D;c[t+76+(S+768<<2)>>2]=D;D=R+1&65535;if((D&65535)>191){break}else{R=D;S=D&65535}}r=c[2386038]|0;c[t+908>>2]=r;D=r+256|0;c[t+912>>2]=D;y=r+512|0;c[t+916>>2]=y;w=r+768|0;c[t+920>>2]=w;v=r+1024|0;c[t+924>>2]=v;G=r+1280|0;c[t+928>>2]=G;C=r+1536|0;c[t+932>>2]=C;B=r+1792|0;c[t+936>>2]=B;c[t+1932>>2]=r;c[t+1936>>2]=D;c[t+1940>>2]=y;c[t+1944>>2]=w;c[t+1948>>2]=v;c[t+1952>>2]=G;c[t+1956>>2]=C;c[t+1960>>2]=B;c[t+2956>>2]=r;c[t+3980>>2]=r;c[t+2960>>2]=D;c[t+3984>>2]=D;c[t+2964>>2]=y;c[t+3988>>2]=y;c[t+2968>>2]=w;c[t+3992>>2]=w;c[t+2972>>2]=v;c[t+3996>>2]=v;c[t+2976>>2]=G;c[t+4e3>>2]=G;c[t+2980>>2]=C;c[t+4004>>2]=C;c[t+2984>>2]=B;c[t+4008>>2]=B;c[t+4184>>2]=3322;c[t+4180>>2]=96;if(!u){B=t;gGC(B|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=z;c[2417276]=x;c[1836236]=-1;B=a[9680]|0;C=B?32e3:0;if(B){if(a[9624]|0){B=C*3|0;G=55930;while(1){if((G|0)>(B|0)){G=G>>1}else{T=1222;U=G;break}}}else{T=2462;U=C}c[2429380]=U;c[3542124]=T;mw(3579545,U);G=gGq(262144)|0;c[2406684]=G;gGz(G|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(3579545,11025)}c[(c[3531464]|0)+44344>>2]=1048;h[745421]=.5;c[2436794]=1;h[745420]=.5;c[2436792]=2;Ux(0,7757,1);c[2407030]=51;c[2407068]=3;G=c[642608+(c[2436]<<2)>>2]|0;B=c[G+128>>2]|0;if((c[G+52>>2]&4|0)==0){c[2113068]=B;x=c[G+132>>2]|0;c[2113070]=x;c[2443814]=B;c[2440436]=x;V=B;W=x}else{c[2113070]=B;x=c[G+132>>2]|0;c[2113068]=x;c[2440436]=B;c[2443814]=x;V=x;W=B}B=ag(V<<1,W)|0;x=gGq(B)|0;c[2112926]=x;if((x|0)!=0){gGz(x|0,0,B|0)}B=c[2414606]|0;gGz(B|0,0,(c[2411562]|0)-B|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];B=c[3532592]|0;if((B|0)!=0){gGC(9104152,B|0,280)|0}c[2113054]=c[2113060]}RI();B=c[2394]|0;x=c[14130368+(B<<2)>>2]|0;if((x|0)!=0){gGC(x|0,9104152,280)|0}c[8452240+(B<<2)>>2]=c[2113054];c[2394]=-1;B=c[2439330]|0;x=(B|0)==0;if(!x){G=B;gGC(9706056,G|0,76)|0}G=c[2438118]|0;c[2433530]=G;z=c[3528484]|0;c[2076596]=z;t=c[2417276]|0;c[3541536]=t;c[1836236]=0;gGz(9706056,0,76);if(!x){x=B;gGC(x|0,9706056,76)|0}c[2438118]=G;c[3528484]=z;c[2417276]=t;c[1836236]=-1;mx(0);c[2113156]=0;a[9628264]=0;c[2407033]=0;t=c[3541206]|0;c[3541190]=t;c[3541198]=t;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=t+256;c[3541199]=t+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=t+512;c[3541200]=t+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=t+768;c[3541201]=t+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;s=0;i=e;return s|0}}while(0);c[2414904]=0;s=1;i=e;return s|0}function eBW(){var a=0,b=0,d=0,e=0,f=0;c[2113070]=0;c[2113068]=0;a=c[2112926]|0;if((a|0)!=0){gGr(a);c[2112926]=0}a=c[3531464]|0;c[a+44344>>2]=0;c[a+44348>>2]=0;if((a|0)!=0){gGr(a);c[3531464]=0}a=c[2406684]|0;if((a|0)!=0){gGr(a);c[2406684]=0}Uw(0);c[3541206]=0;if((c[2392]|0)>=0){a=0;do{b=14130368+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}b=14130384+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}a=a+1|0;}while((a|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;fwZ();a=c[2414904]|0;b=0;while(1){if((b|0)>=1024){e=14229;break}f=9638528+(b<<2)|0;if((c[f>>2]|0)==(a|0)){break}else{b=b+1|0}}if((e|0)==14229){c[2414904]=0;return 0}gGr(a);c[f>>2]=0;c[2414904]=0;return 0}function eBX(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((a[9623800]|0)!=0){e=c[2414606]|0;gGz(e|0,0,(c[2411562]|0)-e|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060]}RI();e=c[2394]|0;f=c[14130368+(e<<2)>>2]|0;if((f|0)!=0){gGC(f|0,9104152,280)|0}c[8452240+(e<<2)>>2]=c[2113054];c[2394]=-1;e=c[2439330]|0;f=(e|0)==0;if(!f){g=e;gGC(9706056,g|0,76)|0}g=c[2438118]|0;c[2433530]=g;h=c[3528484]|0;c[2076596]=h;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);if(!f){f=e;gGC(f|0,9706056,76)|0}c[2438118]=g;c[3528484]=h;c[2417276]=i;c[1836236]=-1;mx(0);c[2113156]=0;a[9628264]=0;c[2407033]=0;i=c[3541206]|0;c[3541190]=i;c[3541198]=i;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=i+256;c[3541199]=i+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=i+512;c[3541200]=i+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=i+768;c[3541201]=i+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4}i=c[2392]|0;if((i|0)>=0){gGz(8452240,0,((i|0)>0?(i<<2)+4|0:4)|0)}c[2113054]=0;i=c[2385548]|0;if((i|0)>0){gGz(9752472,0,((i|0)>1?i<<2:4)|0)}c[2433530]=0;b[4775149]=-1;b[4775148]=-1;i=0;h=-1;g=-1;do{h=((a[9632872+i|0]&1)<<i^h&65535)&65535;g=((a[9630760+i|0]&1)<<i^g&65535)&65535;i=i+1|0;}while((i|0)<16);b[4775148]=h;b[4775149]=g;b[4775150]=d[9634857]<<8|d[9634856];if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060]}g=c[2439330]|0;if((g|0)!=0){h=g;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;h=0;g=0;while(1){c[2113056]=2e4;i=RG(2e4)|0;c[2113054]=(c[2113054]|0)+i;c[2276108]=-1;c[2113056]=-1;if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){i=gfc(6826)|0;j=(c[2433530]|0)+i|0}else{j=(c[2433530]|0)+6826|0}c[2433530]=j;i=c[2112964]|0;if((i|0)==0){k=h;l=0}else{f=a[9688]|0?53:0;e=h<<1;gg[c[3542124]&4095](i+(e<<1)|0,f);i=c[2112964]|0;Uu(0,i+(e<<1)|0,f);k=f+h|0;l=i}i=g+1|0;if((i|0)<10){h=k;g=i}else{break}}c[8452200+(c[2394]<<2)>>2]=8198;c[2276080]=1536;if((c[2276079]|0)>>>0<1536){RH(6);m=c[2112964]|0}else{m=l}do{if((m|0)!=0){l=(a[9688]|0?534:0)-k|0;if((l|0)<=0){break}g=k<<1;gg[c[3542124]&4095](m+(g<<1)|0,l);Uu(0,(c[2112964]|0)+(g<<1)|0,l)}}while(0);m=c[1836236]|0;k=c[9757320+(m<<2)>>2]|0;if((k|0)!=0){l=k;gGC(l|0,9706056,76)|0}c[9752472+(m<<2)>>2]=c[2433530];c[14113936+(m<<2)>>2]=c[2076596];c[9669104+(m<<2)>>2]=c[3541536];c[1836236]=-1;m=c[2394]|0;l=c[14130368+(m<<2)>>2]|0;if((l|0)!=0){gGC(l|0,9104152,280)|0}c[8452240+(m<<2)>>2]=c[2113054];c[2394]=-1;if((c[2112968]|0)==0){return 0}eBY()|0;return 0}function eBY(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;if((a[9547224]|0)!=0){f=c[2387138]|0;g=c[3529938]|0;h=0;do{i=b[f+(h<<1)>>1]|0;c[g+(h<<2)>>2]=((i&65535)>>>10<<3&248)<<8|((i&255)<<3&255)>>>3|(((i&65535)>>>5<<3&255|(i&65535)>>>7&4)&255)<<3&2016;h=h+1|0;}while((h|0)<768);a[9547224]=0}h=e[c[3526960]>>1]|0;g=e[c[3526952]>>1]|0;f=c[2406556]|0;i=c[2385208]|0;j=c[3530786]|0;k=c[2112926]|0;l=c[2113070]|0;m=c[2113068]|0;n=0;do{o=n>>6;p=(n<<4&1008)-h|0;q=(p|0)<-15?p+1024|0:p;p=(o<<4)-g|0;r=(p|0)<-15?p+512|0:p;if((r|0)<(l|0)&(q|0)<(m|0)){p=e[f+((o<<5|n&31)+(n<<5&1024)<<1)>>1]|0;Sz(k,d[i+(p>>>10&3)|0]<<10|p&1023,q,r,p>>>12|32,4,0,j)}n=n+1|0;}while((n|0)<2048);n=e[c[3525086]>>1]|0;f=e[c[3525078]>>1]|0;g=c[2406480]|0;h=0;do{p=h>>6;r=(h<<4&1008)-n|0;q=(r|0)<-15?r+1024|0:r;r=(p<<4)-f|0;o=(r|0)<-15?r+512|0:r;if((o|0)<(l|0)&(q|0)<(m|0)){r=e[g+((p<<5|h&31)+(h<<5&1024)<<1)>>1]|0;SH(k,d[i+(r>>>10&3)|0]<<10|r&1023,q,o,r>>>12|16,4,0,0,j)}h=h+1|0;}while((h|0)<2048);h=c[2386414]|0;j=c[3530550]|0;i=(c[2113222]&1|0)==0;g=0;do{m=b[h+((g|1)<<1)>>1]&16383;L19303:do{if((m|0)!=0){l=e[h+(g<<1)>>1]|0;if(!((l&4096|0)==0|i)){break}f=e[h+((g|2)<<1)>>1]|0;n=f>>>9&15;r=l&16384;o=1<<(l>>>9&3);q=o-1|0;p=f&511;s=l&511;t=304-(p>>>0>319?f|-512:p)-5|0;p=(r|0)!=0;f=(p?0:q)+m|0;u=(r>>>13^2)-1|0;if((o|0)<=0){break}o=(l&8192|0)!=0;r=233-(s>>>0>255?l|-512:s)|0;if(p){v=q}else{if(o){p=q;while(1){SJ(k,f-(ag(p,u)|0)|0,t,r-(p<<4)|0,n,4,0,0,j);if((p|0)>0){p=p-1|0}else{break L19303}}}else{p=q;while(1){SH(k,f-(ag(p,u)|0)|0,t,r-(p<<4)|0,n,4,0,0,j);if((p|0)>0){p=p-1|0}else{break L19303}}}}while(1){p=f-(ag(v,u)|0)|0;q=r-(v<<4)|0;if(o){SN(k,p,t,q,n,4,0,0,j)}else{SL(k,p,t,q,n,4,0,0,j)}if((v|0)>0){v=v-1|0}else{break}}}}while(0);g=g+4|0;}while((g|0)<1024);R8(c[3529938]|0);return 0}function eBZ(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=i;i=i+96|0;g=f|0;h=f+16|0;j=f+32|0;k=f+48|0;l=f+64|0;m=f+80|0;if((e|0)!=0){c[e>>2]=169624}if((b&96|0)==0){i=f;return 0}gGz(m|0,0,12);e=c[2414606]|0;c[m>>2]=e;c[m+4>>2]=(c[2411562]|0)-e;c[m+12>>2]=162152;gj[c[2076592]&4095](m)|0;m=l|0;do{if((b&64|0)==0){fw$(b)}else{gGz(k|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){e=l+9|0;n=j;o=j|0;p=j+4|0;q=j+12|0;r=k|0;s=k+4|0;t=k+12|0;u=0;do{gGC(m|0,614896,11)|0;a[e]=u+48&255;v=8452256+(u<<2)|0;gGz(n|0,0,12);c[o>>2]=v;c[p>>2]=4;c[q>>2]=164976;gj[c[2076592]&4095](j)|0;if((c[v>>2]|0)!=0){c[r>>2]=c[14130368+(u<<2)>>2];c[s>>2]=c[8452184+(u<<2)>>2];c[t>>2]=m;v=c[2076592]|0;gj[v&4095](k)|0}u=u+1|0;}while((u|0)<=(c[2392]|0))}fw$(b);gGz(h|0,0,12);c[h>>2]=8453216;c[h+4>>2]=4;c[h+12>>2]=107480;u=c[2076592]|0;gj[u&4095](h)|0;gGz(g|0,0,12);c[g>>2]=14168504;c[g+4>>2]=256;c[g+12>>2]=476464;u=c[2076592]|0;gj[u&4095](g)|0;if((b&2|0)==0){break}else{w=0}do{mv(0,w,d[14168504+w|0]|0);w=w+1|0;}while((w|0)<256)}}while(0);Ut(0);i=f;return 0}function eB_(b){b=b|0;var c=0,d=0;c=b&65535;b=c&255;if((b|0)==3){d=a[9634848]|0}else if((b|0)==0|(b|0)==1|(b|0)==2){d=a[9634520+(c&3)|0]|0}else{d=0}return d|0}function eB$(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;if((b+15360&65535)>=3072){return}f=(b&65535)-50176|0;b=c[2387136]|0;a[b+f|0]=e;e=f&65532;f=a[b+e|0]|0;g=d[b+(e|1)|0]|0;h=g<<8;i=h|f&255;j=d[b+(e|2)|0]|0;b=(j<<16|h)>>>12;h=((f&255)>>>4&3|f<<2)&255;f=e>>>2;c[(c[2406914]|0)+(f<<2)>>2]=h<<8|g>>>2&3|i>>>6<<2&252|(b<<2&252|j&3)<<16;c[(c[3529936]|0)+(f<<2)>>2]=i>>>7&31|h<<3&2016|b<<10&63488;return}function eB0(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=d&255;if((f|0)==1){d=e&63;c[2443938]=d;g=c[3529232]|0;h=c[9757320+(c[1836236]<<2)>>2]|0;i=(d<<14)-32768|0;d=128;j=128;while(1){c[h+76+(j<<2)>>2]=g+(i+(j<<8));k=d+1&65535;if((k&65535)>191){break}else{d=k;j=k&65535}}j=(c[2443938]<<14)-32768|0;d=128;i=128;while(1){c[h+76+(i+256<<2)>>2]=g+(j+(i<<8));k=d+1&65535;if((k&65535)>191){break}else{d=k;i=k&65535}}i=(c[2443938]<<14)-32768|0;d=128;j=128;while(1){k=g+(i+(j<<8))|0;c[h+76+(j+512<<2)>>2]=k;c[h+76+(j+768<<2)>>2]=k;k=d+1&65535;if((k&65535)>191){break}else{d=k;j=k&65535}}return}else if((f|0)==3){a[14112912]=e;j=c[1836236]|0;d=c[9757320+(j<<2)>>2]|0;if((d|0)!=0){h=d;gGC(h|0,9706056,76)|0}c[9752472+(j<<2)>>2]=c[2433530];c[14113936+(j<<2)>>2]=c[2076596];c[9669104+(j<<2)>>2]=c[3541536];c[1836236]=-1;j=c[2439331]|0;if((j|0)!=0){h=j;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0;h=c[1836236]|0;j=c[9757320+(h<<2)>>2]|0;if((j|0)!=0){d=j;gGC(d|0,9706056,76)|0}c[9752472+(h<<2)>>2]=c[2433530];c[14113936+(h<<2)>>2]=c[2076596];c[9669104+(h<<2)>>2]=c[3541536];c[1836236]=-1;h=c[2439330]|0;if((h|0)!=0){d=h;gGC(9706056,d|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;return}else if((f|0)==0){f=e&1;c[2438162]=f;e=c[2386198]|0;d=f<<12;f=c[9757320+(c[1836236]<<2)>>2]|0;c[f+908>>2]=e+d;c[f+912>>2]=e+(d|256);c[f+916>>2]=e+(d|512);c[f+920>>2]=e+(d|768);c[f+924>>2]=e+(d|1024);c[f+928>>2]=e+(d|1280);c[f+932>>2]=e+(d|1536);c[f+936>>2]=e+(d|1792);c[f+940>>2]=e+(d|2048);c[f+944>>2]=e+(d|2304);c[f+948>>2]=e+(d|2560);c[f+952>>2]=e+(d|2816);c[f+956>>2]=e+(d|3072);c[f+960>>2]=e+(d|3328);c[f+964>>2]=e+(d|3584);c[f+968>>2]=e+(d|3840);d=(c[2438162]<<12)-53248|0;h=208;j=208;while(1){c[f+76+(j+256<<2)>>2]=e+(d+(j<<8));i=h+1&65535;if((i&65535)>223){break}else{h=i;j=i&65535}}j=(c[2438162]<<12)-53248|0;h=208;d=208;while(1){i=e+(j+(d<<8))|0;c[f+76+(d+512<<2)>>2]=i;c[f+76+(d+768<<2)>>2]=i;i=h+1&65535;if((i&65535)>223){break}else{h=i;d=i&65535}}return}else{return}}function eB1(a,b){a=a|0;b=b|0;var d=0;d=a&65535;if((d|0)==36864){a=b&1;c[2443952]=a;c[3541206]=(c[2386606]|0)+(a<<18);return}else if((d|0)==38912){Uv(0,b);return}else{return}}function eB2(b){b=b|0;var d=0,e=0;d=b&65535;if((d|0)==38912){e=c[2113156]&255}else if((d|0)==40960){e=a[14112912]|0}else{e=0}return e|0}function eB3(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2845532+(b*112|0)>>2];c[a+104>>2]=c[2845536+(b*112|0)>>2];c[a+108>>2]=c[2845540+(b*112|0)>>2];d=0;return d|0}function eB4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=2845432+(b*112|0);e=0;return e|0}function eB5(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1263608+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eB6(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>23){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3938304+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eB7(){var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;e=i;i=i+720|0;f=e|0;g=e+112|0;h=e+120|0;j=e+232|0;k=e+240|0;l=e+352|0;m=e+360|0;n=e+472|0;o=e+480|0;p=e+592|0;q=e+600|0;r=e+712|0;c[2414902]=0;c[3529232]=0;c[3529188]=262144;c[3541206]=294912;c[2386606]=294912;c[3530784]=819200;c[3530548]=2916352;c[3529936]=5013504;c[2414604]=5016576;c[3529320]=5016576;c[2387136]=5024768;c[2386198]=5027840;c[3529282]=5036032;c[2406914]=5038080;c[2411560]=5041152;s=0;while(1){if((s|0)>=1024){break}t=9638528+(s<<2)|0;if((c[t>>2]|0)==0){u=14392;break}else{s=s+1|0}}do{if((u|0)==14392){s=gGq(5041152)|0;c[t>>2]=s;if((s|0)==0){break}c[2414902]=s;gGz(s|0,0,5041152);c[3529232]=s;c[3529188]=s+262144;v=s+294912|0;c[3541206]=v;c[2386606]=v;c[3530784]=s+819200;c[3530548]=s+2916352;c[3529936]=s+5013504;v=s+5016576|0;c[2414604]=v;c[3529320]=v;c[2387136]=s+5024768;c[2386198]=s+5027840;c[3529282]=s+5036032;c[2406914]=s+5038080;v=s+5041152|0;c[2411560]=v;c[2414100]=v;if((c[3542200]|0)==0){w=1;i=e;return w|0}v=q+108|0;c[v>>2]=0;x=q+100|0;c[x>>2]=0;y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[y&16383](q,0)|0;do{if((c[v>>2]|0)!=0){y=c[x>>2]|0;c[r>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](r,0,0)|0;if((y|0)<1){w=1;i=e;return w|0}if((gzL(s,0,0)|0)==0){break}else{w=1}i=e;return w|0}}while(0);s=o+108|0;x=o+100|0;v=0;while(1){y=(c[3530784]|0)+(v<<18)|0;z=v+1|0;if((c[3542200]|0)==0){w=1;u=14489;break}c[s>>2]=0;c[x>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](o,z)|0;if((c[s>>2]|0)!=0){A=c[x>>2]|0;c[p>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](p,z,0)|0;if((A|0)<1){w=1;u=14497;break}if((gzL(y,0,z)|0)!=0){w=1;u=14484;break}}if((z|0)<8){v=z}else{u=14399;break}}if((u|0)==14399){v=m+108|0;x=m+100|0;s=0;while(1){z=(c[3530548]|0)+(s<<19)|0;y=s+9|0;if((c[3542200]|0)==0){w=1;u=14483;break}c[v>>2]=0;c[x>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,y)|0;if((c[v>>2]|0)!=0){A=c[x>>2]|0;c[n>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](n,y,0)|0;if((A|0)<1){w=1;u=14486;break}if((gzL(z,0,y)|0)!=0){w=1;u=14493;break}}y=s+1|0;if((y|0)<4){s=y}else{u=14410;break}}if((u|0)==14410){s=c[3529188]|0;if((c[3542200]|0)==0){w=1;i=e;return w|0}x=k+108|0;c[x>>2]=0;v=k+100|0;c[v>>2]=0;y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[y&16383](k,13)|0;do{if((c[x>>2]|0)!=0){y=c[v>>2]|0;c[l>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](l,13,0)|0;if((y|0)<1){w=1;i=e;return w|0}if((gzL(s,0,13)|0)==0){break}else{w=1}i=e;return w|0}}while(0);s=c[2386606]|0;if((c[3542200]|0)==0){w=1;i=e;return w|0}v=h+108|0;c[v>>2]=0;x=h+100|0;c[x>>2]=0;y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[y&16383](h,14)|0;do{if((c[v>>2]|0)!=0){y=c[x>>2]|0;c[j>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](j,14,0)|0;if((y|0)<1){w=1;i=e;return w|0}if((gzL(s,0,14)|0)==0){break}else{w=1}i=e;return w|0}}while(0);s=(c[2386606]|0)+131072|0;if((c[3542200]|0)==0){w=1;i=e;return w|0}x=f+108|0;c[x>>2]=0;v=f+100|0;c[v>>2]=0;y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[y&16383](f,15)|0;do{if((c[x>>2]|0)!=0){y=c[v>>2]|0;c[g>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](g,15,0)|0;if((y|0)<1){w=1;i=e;return w|0}if((gzL(s,0,15)|0)==0){break}else{w=1}i=e;return w|0}}while(0);s=c[2386606]|0;v=s+393216|0;x=s+262144|0;gGC(v|0,x|0,131072)|0;gGC(x|0,s|0,131072)|0;s=0;while(1){if((s|0)>=1024){break}C=9638528+(s<<2)|0;if((c[C>>2]|0)==0){u=14425;break}else{s=s+1|0}}L19497:do{if((u|0)==14425){s=gGq(2097152)|0;c[C>>2]=s;if((s|0)==0){break}gGz(s|0,0,2097152);x=c[3530784]|0;v=c[3530548]|0;y=0;do{z=x+y|0;a[z]=~a[z];z=v+y|0;a[z]=~a[z];y=y+1|0;}while((y|0)<2097152);gGC(s|0,x|0,2097152)|0;y=0;do{z=y<<6;gGz(x+z|0,0,64);A=0;do{B=1<<7-A;D=(c[611432+(A<<2)>>2]|0)+z|0;E=0;do{F=D+(c[1238464+(E<<2)>>2]|0)|0;G=(E<<3)+z|0;H=0;do{I=F+(c[614800+(H<<2)>>2]|0)|0;if(((d[s+((I|0)/8|0)|0]|0)&128>>>((I&7)>>>0)|0)!=0){I=x+(G+H)|0;a[I]=(d[I]|0|B)&255}H=H+1|0;}while((H|0)<8);E=E+1|0;}while((E|0)<8);A=A+1|0;}while((A|0)<8);y=y+1|0;}while((y|0)<32768);gGC(s|0,v|0,2097152)|0;y=0;while(1){x=y<<8;gGz(v+x|0,0,256);A=y<<9;z=0;do{E=1<<7-z;B=(c[611232+(z<<2)>>2]|0)+A|0;D=0;do{H=B+(c[608544+(D<<2)>>2]|0)|0;G=(D<<4)+x|0;F=0;do{I=H+(c[609552+(F<<2)>>2]|0)|0;if(((d[s+((I|0)/8|0)|0]|0)&128>>>((I&7)>>>0)|0)!=0){I=v+(G+F)|0;a[I]=(d[I]|0|E)&255}F=F+1|0;}while((F|0)<16);D=D+1|0;}while((D|0)<16);z=z+1|0;}while((z|0)<8);z=y+1|0;if((z|0)<8192){y=z}else{J=0;break}}while(1){if((J|0)>=1024){break L19497}K=9638528+(J<<2)|0;if((c[K>>2]|0)==(s|0)){break}else{J=J+1|0}}gGr(s);c[K>>2]=0}}while(0);fwR(0);y=c[2439330]|0;v=(y|0)==0;if(!v){z=y;gGC(9706056,z|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];z=c[3528484]|0;c[2076596]=z;x=c[2417276]|0;c[3541536]=x;c[1836236]=0;A=c[3529232]|0;D=0;E=0;while(1){c[y+76+(E<<2)>>2]=A+(E<<8);B=D+1&65535;if((B&65535)>127){L=0;M=0;break}else{D=B;E=B&65535}}while(1){E=A+(M<<8)|0;c[y+76+(M+512<<2)>>2]=E;c[y+76+(M+768<<2)>>2]=E;E=L+1&65535;if((E&65535)>127){break}else{L=E;M=E&65535}}A=c[2387136]|0;c[y+860>>2]=A;c[y+864>>2]=A+256;c[y+868>>2]=A+512;c[y+872>>2]=A+768;c[y+876>>2]=A+1024;c[y+880>>2]=A+1280;c[y+884>>2]=A+1536;c[y+888>>2]=A+1792;c[y+892>>2]=A+2048;c[y+896>>2]=A+2304;c[y+900>>2]=A+2560;c[y+904>>2]=A+2816;E=196;D=196;while(1){B=A+((D<<8)-50176)|0;c[y+76+(D+512<<2)>>2]=B;c[y+76+(D+768<<2)>>2]=B;B=E+1&65535;if((B&65535)>207){break}else{E=B;D=B&65535}}D=c[3529320]|0;E=224;A=224;while(1){c[y+76+(A<<2)>>2]=D+((A<<8)-57344);B=E+1&65535;if((B&65535)>255){N=224;O=224;break}else{E=B;A=B&65535}}while(1){c[y+76+(O+256<<2)>>2]=D+((O<<8)-57344);A=N+1&65535;if((A&65535)>255){P=224;Q=224;break}else{N=A;O=A&65535}}while(1){A=D+((Q<<8)-57344)|0;c[y+76+(Q+512<<2)>>2]=A;c[y+76+(Q+768<<2)>>2]=A;A=P+1&65535;if((A&65535)>255){break}else{P=A;Q=A&65535}}c[y+4184>>2]=1592;c[y+4176>>2]=1600;c[y+4172>>2]=3568;if(!v){D=y;gGC(D|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=z;c[2417276]=x;c[1836236]=-1;fwR(1);D=c[2439331]|0;A=(D|0)==0;if(!A){E=D;gGC(9706056,E|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];E=c[3528485]|0;c[2076596]=E;B=c[2417277]|0;c[3541536]=B;c[1836236]=1;F=c[3529188]|0;G=0;H=0;while(1){c[D+76+(H<<2)>>2]=F+(H<<8);I=G+1&65535;if((I&65535)>127){R=0;S=0;break}else{G=I;H=I&65535}}while(1){H=F+(S<<8)|0;c[D+76+(S+512<<2)>>2]=H;c[D+76+(S+768<<2)>>2]=H;H=R+1&65535;if((H&65535)>127){break}else{R=H;S=H&65535}}F=c[3529282]|0;c[D+588>>2]=F;H=F+256|0;c[D+592>>2]=H;G=F+512|0;c[D+596>>2]=G;x=F+768|0;c[D+600>>2]=x;z=F+1024|0;c[D+604>>2]=z;y=F+1280|0;c[D+608>>2]=y;v=F+1536|0;c[D+612>>2]=v;I=F+1792|0;c[D+616>>2]=I;c[D+1612>>2]=F;c[D+1616>>2]=H;c[D+1620>>2]=G;c[D+1624>>2]=x;c[D+1628>>2]=z;c[D+1632>>2]=y;c[D+1636>>2]=v;c[D+1640>>2]=I;c[D+2636>>2]=F;c[D+3660>>2]=F;c[D+2640>>2]=H;c[D+3664>>2]=H;c[D+2644>>2]=G;c[D+3668>>2]=G;c[D+2648>>2]=x;c[D+3672>>2]=x;c[D+2652>>2]=z;c[D+3676>>2]=z;c[D+2656>>2]=y;c[D+3680>>2]=y;c[D+2660>>2]=v;c[D+3684>>2]=v;c[D+2664>>2]=I;c[D+3688>>2]=I;c[D+4184>>2]=356;c[D+4180>>2]=3174;if(!A){I=D;gGC(I|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=E;c[2417277]=B;c[1836236]=-1;Ux(0,8e3,0);c[2407030]=256;c[2407068]=3;I=c[642608+(c[2436]<<2)>>2]|0;v=c[I+128>>2]|0;if((c[I+52>>2]&4|0)==0){c[2113068]=v;y=c[I+132>>2]|0;c[2113070]=y;c[2443814]=v;c[2440436]=y;T=v;U=y}else{c[2113070]=v;y=c[I+132>>2]|0;c[2113068]=y;c[2440436]=v;c[2443814]=y;T=y;U=v}v=ag(T<<1,U)|0;y=gGq(v)|0;c[2112926]=y;if((y|0)==0){w=0;i=e;return w|0}gGz(y|0,0,v|0);w=0;i=e;return w|0}else if((u|0)==14483){i=e;return w|0}else if((u|0)==14486){i=e;return w|0}else if((u|0)==14493){i=e;return w|0}}else if((u|0)==14484){i=e;return w|0}else if((u|0)==14489){i=e;return w|0}else if((u|0)==14497){i=e;return w|0}}}while(0);c[2414902]=0;w=1;i=e;return w|0}function eB8(){var a=0,b=0,d=0,e=0;c[2113070]=0;c[2113068]=0;a=c[2112926]|0;if((a|0)!=0){gGr(a);c[2112926]=0}Uw(0);fwZ();a=c[2414902]|0;b=0;while(1){if((b|0)>=1024){d=14505;break}e=9638528+(b<<2)|0;if((c[e>>2]|0)==(a|0)){break}else{b=b+1|0}}if((d|0)==14505){c[2414902]=0;c[3541206]=0;return 0}gGr(a);c[e>>2]=0;c[2414902]=0;c[3541206]=0;return 0}function eB9(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;if((a[9623792]|0)!=0){a[9623792]=0;d=c[2414604]|0;gGz(d|0,0,(c[2411560]|0)-d|0);d=c[2439330]|0;if((d|0)!=0){e=d;gGC(9706056,e|0,76)|0}c[2433530]=c[2438118];e=c[3528484]|0;c[2076596]=e;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;gGz(9706056,0,76);c[2438162]=0;g=c[2386198]|0;c[d+908>>2]=g;c[d+912>>2]=g+256;c[d+916>>2]=g+512;c[d+920>>2]=g+768;c[d+924>>2]=g+1024;c[d+928>>2]=g+1280;c[d+932>>2]=g+1536;c[d+936>>2]=g+1792;c[d+940>>2]=g+2048;c[d+944>>2]=g+2304;c[d+948>>2]=g+2560;c[d+952>>2]=g+2816;c[d+956>>2]=g+3072;c[d+960>>2]=g+3328;c[d+964>>2]=g+3584;c[d+968>>2]=g+3840;h=(c[2438162]<<12)-53248|0;i=208;j=208;while(1){c[d+76+(j+256<<2)>>2]=g+(h+(j<<8));k=i+1&65535;if((k&65535)>223){break}else{i=k;j=k&65535}}j=(c[2438162]<<12)-53248|0;i=208;h=208;while(1){k=g+(j+(h<<8))|0;c[d+76+(h+512<<2)>>2]=k;c[d+76+(h+768<<2)>>2]=k;k=i+1&65535;if((k&65535)>223){break}else{i=k;h=k&65535}}c[2443938]=0;h=c[3529232]|0;i=128;j=128;while(1){c[d+76+(j<<2)>>2]=h+((j<<8)-32768);g=i+1&65535;if((g&65535)>191){break}else{i=g;j=g&65535}}j=(c[2443938]<<14)-32768|0;i=128;g=128;while(1){c[d+76+(g+256<<2)>>2]=h+(j+(g<<8));k=i+1&65535;if((k&65535)>191){break}else{i=k;g=k&65535}}g=(c[2443938]<<14)-32768|0;i=128;j=128;while(1){k=h+(g+(j<<8))|0;c[d+76+(j+512<<2)>>2]=k;c[d+76+(j+768<<2)>>2]=k;k=i+1&65535;if((k&65535)>191){break}else{i=k;j=k&65535}}j=d;gGC(j|0,9706056,76)|0;c[2438118]=c[2433530];c[3528484]=e;c[2417276]=f;c[1836236]=-1;f=c[2439331]|0;e=(f|0)==0;if(!e){j=f;gGC(9706056,j|0,76)|0}j=c[2438119]|0;c[2433530]=j;d=c[3528485]|0;c[2076596]=d;i=c[2417277]|0;c[3541536]=i;c[1836236]=1;gGz(9706056,0,76);if(!e){e=f;gGC(e|0,9706056,76)|0}c[2438119]=j;c[3528485]=d;c[2417277]=i;c[1836236]=-1;c[2443952]=0;i=c[2386606]|0;c[3541206]=i;c[2113156]=0;a[9628264]=0;c[2407033]=0;c[3541190]=i;c[3541198]=i;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=i+256;c[3541199]=i+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=i+512;c[3541200]=i+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=i+768;c[3541201]=i+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;a[14112912]=0}gGz(9634520,-1|0,3);i=0;d=-1;j=-1;e=-1;do{d=((a[9632864+i|0]&1)<<i^d&255)&255;j=((a[9630752+i|0]&1)<<i^j&255)&255;e=((a[9629320+i|0]&1)<<i^e&255)&255;i=i+1|0;}while((i|0)<8);a[9634520]=d;a[9634521]=j;a[9634522]=e;e=0;j=0;d=0;while(1){i=c[2439330]|0;if((i|0)!=0){f=i;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;f=c[2438118]|0;c[2433530]=f;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;g=10-d|0;h=(1e5-j|0)/(g|0)|0;do{if((h|0)<1){l=0}else{if((a[i+4188|0]|0)==0){k=gfc(h)|0;c[2433530]=(c[2433530]|0)+k;l=k;break}else{c[2433530]=f+h;l=h;break}}}while(0);h=l+j|0;if((d|0)==9){a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0}f=c[1836236]|0;i=c[9757320+(f<<2)>>2]|0;if((i|0)!=0){k=i;gGC(k|0,9706056,76)|0}c[9752472+(f<<2)>>2]=c[2433530];c[14113936+(f<<2)>>2]=c[2076596];c[9669104+(f<<2)>>2]=c[3541536];c[1836236]=-1;f=c[2439331]|0;if((f|0)!=0){k=f;gGC(9706056,k|0,76)|0}b[4853030]=c[2426515]&65535;k=c[2438119]|0;c[2433530]=k;c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;i=(66666-e|0)/(g|0)|0;do{if((i|0)<1){m=0;n=1;o=f;p=k}else{if((a[f+4188|0]|0)==0){q=gfc(i)|0;r=(c[2433530]|0)+q|0;c[2433530]=r;s=c[1836236]|0;m=q;n=s;o=c[9757320+(s<<2)>>2]|0;p=r;break}else{r=k+i|0;c[2433530]=r;m=i;n=1;o=f;p=r;break}}}while(0);if((o|0)!=0){f=o;gGC(f|0,9706056,76)|0}c[9752472+(n<<2)>>2]=p;c[14113936+(n<<2)>>2]=c[2076596];c[9669104+(n<<2)>>2]=c[3541536];c[1836236]=-1;f=d+1|0;if((f|0)<10){e=m+e|0;j=h;d=f}else{break}}d=c[2112964]|0;if((d|0)!=0){Uu(0,d,a[9688]|0?534:0)}if((c[2112968]|0)==0){return 0}eCa()|0;return 0}function eCa(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((a[9547216]|0)!=0){b=c[2406914]|0;e=c[3529936]|0;f=0;do{g=c[b+(f<<2)>>2]|0;c[e+(f<<2)>>2]=g>>8<<3&2016|g>>>3&31|g>>16<<8&63488;f=f+1|0;}while((f|0)<768)}f=c[2112926]|0;gGz(f|0,0,ag(c[2113068]<<1,c[2113070]|0)|0);e=c[2386198]|0;b=c[3530784]|0;g=0;do{h=(g<<2&504)-96|0;i=(g>>7<<3)-16|0;if(!(h>>>0>312|i>>>0>216)){j=d[e+(g|1)|0]|0;Sr(f,j<<8&32512|d[e+g|0],h,i,(j>>>7)+1|0,8,0,0,b)}g=g+2|0;}while((g|0)<4096);g=e+4064|0;b=c[3530548]|0;j=e+8160|0;do{e=a[j+3|0]|0;i=e&255;h=a[j+1|0]|0;k=h&255;l=k<<8&3840|d[j];m=((h&32)!=0&(e&255)<224?i|256:i)-96|0;i=(d[j+2|0]|0)-16|0;if(m>>>0<305|i>>>0<208){SH(f,(k&128|0)==0?l:l|4096,m,i,0,8,255,0,b)}j=j-32|0;}while(j>>>0>g>>>0);R8(c[3529936]|0);return 0}function eCb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0;d=i;i=i+80|0;e=d|0;f=d+16|0;g=d+32|0;h=d+48|0;j=d+64|0;if((b|0)!=0){c[b>>2]=169623}if((a&32|0)!=0){gGz(j|0,0,12);b=c[2414604]|0;c[j>>2]=b;c[j+4>>2]=(c[2411560]|0)-b;c[j+12>>2]=162152;b=c[2076592]|0;gj[b&4095](j)|0}if((a&64|0)!=0){fw$(a);Ut(0);gGz(h|0,0,12);c[h>>2]=14112912;c[h+4>>2]=1;c[h+12>>2]=191240;j=c[2076592]|0;gj[j&4095](h)|0;gGz(g|0,0,12);c[g>>2]=9775808;c[g+4>>2]=4;c[g+12>>2]=581048;h=c[2076592]|0;gj[h&4095](g)|0;gGz(f|0,0,12);c[f>>2]=9775752;c[f+4>>2]=4;c[f+12>>2]=563960;g=c[2076592]|0;gj[g&4095](f)|0;gGz(e|0,0,12);c[e>>2]=9752648;c[e+4>>2]=4;c[e+12>>2]=548152;f=c[2076592]|0;gj[f&4095](e)|0}if((a&2|0)==0){i=d;return 0}a=c[2443952]&1;c[2443952]=a;c[3541206]=(c[2386606]|0)+(a<<18);a=c[2443938]&63;c[2443938]=a;e=c[3529232]|0;f=c[9757320+(c[1836236]<<2)>>2]|0;g=(a<<14)-32768|0;a=128;h=128;while(1){c[f+76+(h<<2)>>2]=e+(g+(h<<8));j=a+1&65535;if((j&65535)>191){break}else{a=j;h=j&65535}}h=(c[2443938]<<14)-32768|0;a=128;g=128;while(1){c[f+76+(g+256<<2)>>2]=e+(h+(g<<8));j=a+1&65535;if((j&65535)>191){break}else{a=j;g=j&65535}}g=(c[2443938]<<14)-32768|0;a=128;h=128;while(1){j=e+(g+(h<<8))|0;c[f+76+(h+512<<2)>>2]=j;c[f+76+(h+768<<2)>>2]=j;j=a+1&65535;if((j&65535)>191){break}else{a=j;h=j&65535}}h=c[2438162]&1;c[2438162]=h;a=c[2386198]|0;g=h<<12;c[f+908>>2]=a+g;c[f+912>>2]=a+(g|256);c[f+916>>2]=a+(g|512);c[f+920>>2]=a+(g|768);c[f+924>>2]=a+(g|1024);c[f+928>>2]=a+(g|1280);c[f+932>>2]=a+(g|1536);c[f+936>>2]=a+(g|1792);c[f+940>>2]=a+(g|2048);c[f+944>>2]=a+(g|2304);c[f+948>>2]=a+(g|2560);c[f+952>>2]=a+(g|2816);c[f+956>>2]=a+(g|3072);c[f+960>>2]=a+(g|3328);c[f+964>>2]=a+(g|3584);c[f+968>>2]=a+(g|3840);g=(c[2438162]<<12)-53248|0;h=208;e=208;while(1){c[f+76+(e+256<<2)>>2]=a+(g+(e<<8));j=h+1&65535;if((j&65535)>223){break}else{h=j;e=j&65535}}e=(c[2438162]<<12)-53248|0;h=208;g=208;while(1){j=a+(e+(g<<8))|0;c[f+76+(g+512<<2)>>2]=j;c[f+76+(g+768<<2)>>2]=j;j=h+1&65535;if((j&65535)>223){break}else{h=j;g=j&65535}}i=d;return 0}function eCc(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2847324+(b*112|0)>>2];c[a+104>>2]=c[2847328+(b*112|0)>>2];c[a+108>>2]=c[2847332+(b*112|0)>>2];d=0;return d|0}function eCd(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=2847224+(b*112|0);e=0;return e|0}function eCe(a,b){a=a|0;b=b|0;return}function eCf(b,d){b=b|0;d=d|0;if((b|0)!=1048576){return}a[c[3528226]|0]=d&255;a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0;return}function eCg(a){a=a|0;var c=0;if((a|0)==1572864){c=(e[4774964]|0)>>>8&255}else if((a|0)==1572865){c=b[4774964]&255}else if((a|0)==1572873){c=b[4774880]&255&-9}else{c=0}return c|0}function eCh(a){a=a|0;var c=0;if((a|0)==1572866){c=d[9634840]|0}else if((a|0)==1572872){c=b[4774880]|0}else{c=0}return c|0}function eCi(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((e|0)==38912){Uv(0,d);return}else if((e|0)==36864){e=d&3;a[c[3528398]|0]=e&255;c[3541206]=(c[2386604]|0)+(e<<18);return}else{return}}function eCj(b){b=b|0;var d=0,e=0;d=b&65535;if((d|0)==38912){e=c[2113156]&255}else if((d|0)==40960){e=a[c[3528226]|0]|0}else{e=0}return e|0}function eCk(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2942036+(b*112|0)>>2];c[a+104>>2]=c[2942040+(b*112|0)>>2];c[a+108>>2]=c[2942044+(b*112|0)>>2];d=0;return d|0}function eCl(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=2941936+(b*112|0);e=0;return e|0}function eCm(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1282792+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eCn(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>23){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4053704+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eCo(){var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;e=i;i=i+360|0;f=e|0;g=e+112|0;h=e+120|0;j=e+232|0;k=e+240|0;l=e+352|0;c[2414900]=0;c[2388098]=0;c[2385882]=262144;c[3530782]=327680;c[3530546]=2424832;c[3541206]=3473408;c[2386604]=3473408;c[3529934]=4521984;c[2414602]=4526080;c[2388228]=4526080;c[2387134]=4591616;c[2386412]=4593664;c[2386036]=4610048;c[3528226]=4612096;c[3528398]=4612097;c[2411558]=4612098;m=0;while(1){if((m|0)>=1024){break}n=9638528+(m<<2)|0;if((c[n>>2]|0)==0){o=14653;break}else{m=m+1|0}}do{if((o|0)==14653){m=gGq(4612098)|0;c[n>>2]=m;if((m|0)==0){break}c[2414900]=m;gGz(m|0,0,4612098);c[2388098]=m;c[2385882]=m+262144;c[3530782]=m+327680;c[3530546]=m+2424832;p=m+3473408|0;c[3541206]=p;c[2386604]=p;c[3529934]=m+4521984;p=m+4526080|0;c[2414602]=p;c[2388228]=p;c[2387134]=m+4591616;c[2386412]=m+4593664;c[2386036]=m+4610048;c[3528226]=m+4612096;c[3528398]=m+4612097;p=m+4612098|0;c[2411558]=p;c[2414098]=p;if((R6(m+1|0,0,2)|0)!=0){q=1;i=e;return q|0}if((R6(c[2388098]|0,1,2)|0)!=0){q=1;i=e;return q|0}m=c[2385882]|0;if((c[3542200]|0)==0){q=1;i=e;return q|0}p=k+108|0;c[p>>2]=0;r=k+100|0;c[r>>2]=0;s=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[s&16383](k,2)|0;do{if((c[p>>2]|0)!=0){s=c[r>>2]|0;c[l>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](l,2,0)|0;if((s|0)<1){q=1;i=e;return q|0}if((gzL(m,0,2)|0)==0){break}else{q=1}i=e;return q|0}}while(0);m=c[2385882]|0;r=m+32768|0;gGC(m|0,r|0,32768)|0;if((R6(c[3530782]|0,3,2)|0)!=0){q=1;i=e;return q|0}if((R6((c[3530782]|0)+1|0,4,2)|0)!=0){q=1;i=e;return q|0}if((R6(c[3530546]|0,5,2)|0)!=0){q=1;i=e;return q|0}if((R6((c[3530546]|0)+1|0,6,2)|0)!=0){q=1;i=e;return q|0}if((R6((c[3530546]|0)+262144|0,7,2)|0)!=0){q=1;i=e;return q|0}if((R6((c[3530546]|0)+262145|0,8,2)|0)!=0){q=1;i=e;return q|0}r=c[2386604]|0;if((c[3542200]|0)==0){q=1;i=e;return q|0}m=h+108|0;c[m>>2]=0;p=h+100|0;c[p>>2]=0;s=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[s&16383](h,9)|0;do{if((c[m>>2]|0)!=0){s=c[p>>2]|0;c[j>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](j,9,0)|0;if((s|0)<1){q=1;i=e;return q|0}if((gzL(r,0,9)|0)==0){break}else{q=1}i=e;return q|0}}while(0);r=c[2386604]|0;p=r+786432|0;m=r+393216|0;gGC(p|0,m|0,131072)|0;m=r+524288|0;p=r+262144|0;gGC(m|0,p|0,131072)|0;m=r+131072|0;gGC(p|0,m|0,131072)|0;if((c[3542200]|0)==0){q=1;i=e;return q|0}p=f+108|0;c[p>>2]=0;r=f+100|0;c[r>>2]=0;s=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[s&16383](f,10)|0;do{if((c[p>>2]|0)!=0){s=c[r>>2]|0;c[g>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](g,10,0)|0;if((s|0)<1){q=1;i=e;return q|0}if((gzL(m,0,10)|0)==0){break}else{q=1}i=e;return q|0}}while(0);m=c[2386604]|0;r=m+917504|0;p=m+131072|0;gGC(r|0,p|0,131072)|0;r=m+655360|0;gGC(r|0,p|0,131072)|0;r=m+393216|0;gGC(r|0,p|0,131072)|0;p=0;while(1){if((p|0)>=1024){break}u=9638528+(p<<2)|0;if((c[u>>2]|0)==0){o=14678;break}else{p=p+1|0}}L19845:do{if((o|0)==14678){p=gGq(1048576)|0;c[u>>2]=p;if((p|0)==0){break}gGz(p|0,0,1048576);r=c[3530782]|0;gGC(p|0,r|0,1048576)|0;m=0;do{s=m<<8;gGz(r+s|0,0,256);t=m<<10;v=0;do{w=1<<3-v;x=(c[703416+(v<<2)>>2]|0)+t|0;y=0;do{z=x+(c[611904+(y<<2)>>2]|0)|0;A=(y<<4)+s|0;B=0;do{C=z+(c[612416+(B<<2)>>2]|0)|0;if(((d[p+((C|0)/8|0)|0]|0)&128>>>((C&7)>>>0)|0)!=0){C=r+(A+B)|0;a[C]=(d[C]|0|w)&255}B=B+1|0;}while((B|0)<16);y=y+1|0;}while((y|0)<16);v=v+1|0;}while((v|0)<4);m=m+1|0;}while((m|0)<8192);m=c[3530546]|0;gGC(p|0,m|0,524288)|0;r=0;while(1){v=r<<8;gGz(m+v|0,0,256);s=r<<10;t=0;do{y=1<<3-t;w=(c[703416+(t<<2)>>2]|0)+s|0;x=0;do{B=w+(c[611904+(x<<2)>>2]|0)|0;A=(x<<4)+v|0;z=0;do{C=B+(c[612416+(z<<2)>>2]|0)|0;if(((d[p+((C|0)/8|0)|0]|0)&128>>>((C&7)>>>0)|0)!=0){C=m+(A+z)|0;a[C]=(d[C]|0|y)&255}z=z+1|0;}while((z|0)<16);x=x+1|0;}while((x|0)<16);t=t+1|0;}while((t|0)<4);t=r+1|0;if((t|0)<4096){r=t}else{D=0;break}}while(1){if((D|0)>=1024){break L19845}E=9638528+(D<<2)|0;if((c[E>>2]|0)==(p|0)){break}else{D=D+1|0}}gGr(p);c[E>>2]=0}}while(0);fxU(0,425984);if((c[2394]|0)==0){F=c[2112932]|0}else{c[2394]=0;r=c[3532596]|0;c[2112932]=r;m=c[3532592]|0;if((m|0)!=0){gGC(9104152,m|0,280)|0}c[2113054]=c[2113060];F=r}r=c[2388098]|0;m=F|0;t=0;while(1){v=r+t|0;c[m>>2]=v;c[m+131072>>2]=v;v=t+1024|0;if(v>>>0>262143){break}else{m=m+4|0;t=v}}t=c[2388228]|0;m=F+1024|0;r=262144;while(1){v=t+(r-262144)|0;c[m>>2]=v;c[m+65536>>2]=v;c[m+131072>>2]=v;v=r+1024|0;if(v>>>0>327679){break}else{m=m+4|0;r=v}}r=c[2386412]|0;c[F+2048>>2]=r;c[F+67584>>2]=r;c[F+133120>>2]=r;m=r+1024|0;c[F+2052>>2]=m;c[F+67588>>2]=m;c[F+133124>>2]=m;m=r+2048|0;c[F+2056>>2]=m;c[F+67592>>2]=m;c[F+133128>>2]=m;m=r+3072|0;c[F+2060>>2]=m;c[F+67596>>2]=m;c[F+133132>>2]=m;m=r+4096|0;c[F+2064>>2]=m;c[F+67600>>2]=m;c[F+133136>>2]=m;m=r+5120|0;c[F+2068>>2]=m;c[F+67604>>2]=m;c[F+133140>>2]=m;m=r+6144|0;c[F+2072>>2]=m;c[F+67608>>2]=m;c[F+133144>>2]=m;m=r+7168|0;c[F+2076>>2]=m;c[F+67612>>2]=m;c[F+133148>>2]=m;m=r+8192|0;c[F+2080>>2]=m;c[F+67616>>2]=m;c[F+133152>>2]=m;m=r+9216|0;c[F+2084>>2]=m;c[F+67620>>2]=m;c[F+133156>>2]=m;m=r+10240|0;c[F+2088>>2]=m;c[F+67624>>2]=m;c[F+133160>>2]=m;m=r+11264|0;c[F+2092>>2]=m;c[F+67628>>2]=m;c[F+133164>>2]=m;m=r+12288|0;c[F+2096>>2]=m;c[F+67632>>2]=m;c[F+133168>>2]=m;m=r+13312|0;c[F+2100>>2]=m;c[F+67636>>2]=m;c[F+133172>>2]=m;m=r+14336|0;c[F+2104>>2]=m;c[F+67640>>2]=m;c[F+133176>>2]=m;m=r+15360|0;c[F+2108>>2]=m;c[F+67644>>2]=m;c[F+133180>>2]=m;m=c[2387134]|0;c[F+5120>>2]=m;c[F+70656>>2]=m;c[F+136192>>2]=m;r=m+1024|0;c[F+5124>>2]=r;c[F+70660>>2]=r;c[F+136196>>2]=r;c[F+196648>>2]=2496;c[F+196728>>2]=812;c[F+196608>>2]=1914;c[F+196688>>2]=2366;r=c[3532592]|0;if((r|0)!=0){gGC(r|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);r=c[2439330]|0;m=(r|0)==0;if(!m){t=r;gGC(9706056,t|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];t=c[3528484]|0;c[2076596]=t;v=c[2417276]|0;c[3541536]=v;c[1836236]=0;s=c[2385882]|0;x=0;y=0;while(1){c[r+76+(y<<2)>>2]=s+(y<<8);w=x+1&65535;if((w&65535)>127){G=0;H=0;break}else{x=w;y=w&65535}}while(1){y=s+(H<<8)|0;c[r+76+(H+512<<2)>>2]=y;c[r+76+(H+768<<2)>>2]=y;y=G+1&65535;if((y&65535)>127){break}else{G=y;H=y&65535}}s=c[2386036]|0;c[r+588>>2]=s;y=s+256|0;c[r+592>>2]=y;x=s+512|0;c[r+596>>2]=x;w=s+768|0;c[r+600>>2]=w;z=s+1024|0;c[r+604>>2]=z;A=s+1280|0;c[r+608>>2]=A;B=s+1536|0;c[r+612>>2]=B;C=s+1792|0;c[r+616>>2]=C;c[r+1612>>2]=s;c[r+1616>>2]=y;c[r+1620>>2]=x;c[r+1624>>2]=w;c[r+1628>>2]=z;c[r+1632>>2]=A;c[r+1636>>2]=B;c[r+1640>>2]=C;c[r+2636>>2]=s;c[r+3660>>2]=s;c[r+2640>>2]=y;c[r+3664>>2]=y;c[r+2644>>2]=x;c[r+3668>>2]=x;c[r+2648>>2]=w;c[r+3672>>2]=w;c[r+2652>>2]=z;c[r+3676>>2]=z;c[r+2656>>2]=A;c[r+3680>>2]=A;c[r+2660>>2]=B;c[r+3684>>2]=B;c[r+2664>>2]=C;c[r+3688>>2]=C;c[r+4184>>2]=272;c[r+4180>>2]=676;if(!m){C=r;gGC(C|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=t;c[2417276]=v;c[1836236]=-1;Ux(0,1e4,0);c[2407030]=128;c[2407068]=3;C=c[642608+(c[2436]<<2)>>2]|0;B=c[C+128>>2]|0;if((c[C+52>>2]&4|0)==0){c[2113068]=B;A=c[C+132>>2]|0;c[2113070]=A;c[2443814]=B;c[2440436]=A;I=B;J=A}else{c[2113070]=B;A=c[C+132>>2]|0;c[2113068]=A;c[2440436]=B;c[2443814]=A;I=A;J=B}B=ag(I<<1,J)|0;A=gGq(B)|0;c[2112926]=A;if((A|0)!=0){gGz(A|0,0,B|0)}a[9623784]=0;B=c[2414602]|0;gGz(B|0,0,(c[2411558]|0)-B|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];B=c[3532592]|0;if((B|0)!=0){gGC(9104152,B|0,280)|0}c[2113054]=c[2113060]}RI();B=c[2394]|0;A=c[14130368+(B<<2)>>2]|0;if((A|0)!=0){gGC(A|0,9104152,280)|0}c[8452240+(B<<2)>>2]=c[2113054];c[2394]=-1;B=c[2439330]|0;A=(B|0)==0;if(!A){C=B;gGC(9706056,C|0,76)|0}C=c[2438118]|0;c[2433530]=C;z=c[3528484]|0;c[2076596]=z;w=c[2417276]|0;c[3541536]=w;c[1836236]=0;gGz(9706056,0,76);if(!A){A=B;gGC(A|0,9706056,76)|0}c[2438118]=C;c[3528484]=z;c[2417276]=w;c[1836236]=-1;a[c[3528398]|0]=0;w=c[2386604]|0;c[3541206]=w;c[2113156]=0;a[9628264]=0;c[2407033]=0;c[3541190]=w;c[3541198]=w;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=w+256;c[3541199]=w+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=w+512;c[3541200]=w+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=w+768;c[3541201]=w+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;q=0;i=e;return q|0}}while(0);c[2414900]=0;q=1;i=e;return q|0}function eCp(){var a=0,b=0,d=0,e=0,f=0;c[2113070]=0;c[2113068]=0;a=c[2112926]|0;if((a|0)!=0){gGr(a);c[2112926]=0}Uw(0);if((c[2392]|0)>=0){a=0;do{b=14130368+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}b=14130384+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}a=a+1|0;}while((a|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;fwZ();a=c[2414900]|0;b=0;while(1){if((b|0)>=1024){e=14770;break}f=9638528+(b<<2)|0;if((c[f>>2]|0)==(a|0)){break}else{b=b+1|0}}if((e|0)==14770){c[2414900]=0;c[3541206]=0;return 0}gGr(a);c[f>>2]=0;c[2414900]=0;c[3541206]=0;return 0}function eCq(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if((a[9623784]|0)!=0){a[9623784]=0;d=c[2414602]|0;gGz(d|0,0,(c[2411558]|0)-d|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;h=c[2417276]|0;c[3541536]=h;c[1836236]=0;gGz(9706056,0,76);if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=h;c[1836236]=-1;a[c[3528398]|0]=0;h=c[2386604]|0;c[3541206]=h;c[2113156]=0;a[9628264]=0;c[2407033]=0;c[3541190]=h;c[3541198]=h;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=h+256;c[3541199]=h+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=h+512;c[3541200]=h+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=h+768;c[3541201]=h+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4}b[4774964]=-1;b[4774880]=-9;h=0;g=-1;f=-9;do{g=((a[9632848+h|0]&1)<<h^g&65535)&65535;f=((a[9630736+h|0]&1)<<h^f&65535)&65535;h=h+1|0;}while((h|0)<16);b[4774964]=g;b[4774880]=f;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060]}f=c[2439330]|0;if((f|0)!=0){g=f;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;c[2113056]=2e4;g=RG(2e4)|0;c[2113054]=(c[2113054]|0)+g;c[2276108]=-1;c[2113056]=-1;if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){f=gfc(6666)|0;i=f;j=(c[2433530]|0)+f|0}else{i=6666;j=(c[2433530]|0)+6666|0}c[2433530]=j;j=(2e5-g|0)/9|0;c[2113056]=j;f=RG(j)|0;c[2113054]=(c[2113054]|0)+f;c[2276108]=-1;c[2113056]=-1;j=f+g|0;g=66666-i|0;f=(g|0)/9|0;do{if((g|0)<9){k=0}else{if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){h=gfc(f)|0;c[2433530]=(c[2433530]|0)+h;k=h;break}else{c[2433530]=(c[2433530]|0)+f;k=f;break}}}while(0);f=k+i|0;i=(2e5-j|0)/8|0;c[2113056]=i;k=RG(i)|0;c[2113054]=(c[2113054]|0)+k;c[2276108]=-1;c[2113056]=-1;i=k+j|0;j=66666-f|0;k=(j|0)/8|0;do{if((j|0)<8){l=0}else{if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){g=gfc(k)|0;c[2433530]=(c[2433530]|0)+g;l=g;break}else{c[2433530]=(c[2433530]|0)+k;l=k;break}}}while(0);k=l+f|0;f=(2e5-i|0)/7|0;c[2113056]=f;l=RG(f)|0;c[2113054]=(c[2113054]|0)+l;c[2276108]=-1;c[2113056]=-1;f=l+i|0;i=66666-k|0;l=(i|0)/7|0;do{if((i|0)<7){m=0}else{if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){j=gfc(l)|0;c[2433530]=(c[2433530]|0)+j;m=j;break}else{c[2433530]=(c[2433530]|0)+l;m=l;break}}}while(0);l=m+k|0;k=(2e5-f|0)/6|0;c[2113056]=k;m=RG(k)|0;c[2113054]=(c[2113054]|0)+m;c[2276108]=-1;c[2113056]=-1;k=m+f|0;f=66666-l|0;m=(f|0)/6|0;do{if((f|0)<6){n=0}else{if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){i=gfc(m)|0;c[2433530]=(c[2433530]|0)+i;n=i;break}else{c[2433530]=(c[2433530]|0)+m;n=m;break}}}while(0);m=n+l|0;l=(2e5-k|0)/5|0;c[2113056]=l;n=RG(l)|0;c[2113054]=(c[2113054]|0)+n;c[2276108]=-1;c[2113056]=-1;l=n+k|0;k=66666-m|0;n=(k|0)/5|0;do{if((k|0)<5){o=0}else{if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){f=gfc(n)|0;c[2433530]=(c[2433530]|0)+f;o=f;break}else{c[2433530]=(c[2433530]|0)+n;o=n;break}}}while(0);n=o+m|0;m=(2e5-l|0)/4|0;c[2113056]=m;o=RG(m)|0;c[2113054]=(c[2113054]|0)+o;c[2276108]=-1;c[2113056]=-1;m=o+l|0;l=66666-n|0;o=(l|0)/4|0;do{if((l|0)<4){p=0}else{if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){k=gfc(o)|0;c[2433530]=(c[2433530]|0)+k;p=k;break}else{c[2433530]=(c[2433530]|0)+o;p=o;break}}}while(0);o=p+n|0;n=(2e5-m|0)/3|0;c[2113056]=n;p=RG(n)|0;c[2113054]=(c[2113054]|0)+p;c[2276108]=-1;c[2113056]=-1;n=p+m|0;m=66666-o|0;p=(m|0)/3|0;do{if((m|0)<3){q=0}else{if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){l=gfc(p)|0;c[2433530]=(c[2433530]|0)+l;q=l;break}else{c[2433530]=(c[2433530]|0)+p;q=p;break}}}while(0);p=2e5-n|0;n=(p|0)/2|0;c[2113056]=n;m=RG(n)|0;c[2113054]=(c[2113054]|0)+m;c[2276108]=-1;c[2113056]=-1;n=66666-(q+o)|0;o=(n|0)/2|0;do{if((n|0)<2){r=0}else{if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){q=gfc(o)|0;c[2433530]=(c[2433530]|0)+q;r=q;break}else{c[2433530]=(c[2433530]|0)+o;r=o;break}}}while(0);o=p-m|0;c[2113056]=o;m=RG(o)|0;c[2113054]=(c[2113054]|0)+m;c[2276108]=-1;c[2113056]=-1;m=n-r|0;do{if((m|0)>=1){if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){r=gfc(m)|0;c[2433530]=(c[2433530]|0)+r;break}else{c[2433530]=(c[2433530]|0)+m;break}}}while(0);c[8452200+(c[2394]<<2)>>2]=8198;c[2276080]=1536;if((c[2276079]|0)>>>0<1536){RH(6)}m=c[2112964]|0;if((m|0)!=0){Uu(0,m,a[9688]|0?534:0)}m=c[1836236]|0;r=c[9757320+(m<<2)>>2]|0;if((r|0)!=0){n=r;gGC(n|0,9706056,76)|0}c[9752472+(m<<2)>>2]=c[2433530];c[14113936+(m<<2)>>2]=c[2076596];c[9669104+(m<<2)>>2]=c[3541536];c[1836236]=-1;m=c[2394]|0;n=c[14130368+(m<<2)>>2]|0;if((n|0)!=0){gGC(n|0,9104152,280)|0}c[8452240+(m<<2)>>2]=c[2113054];c[2394]=-1;if((c[2112968]|0)==0){return 0}eCr()|0;return 0}function eCr(){var b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((a[9547208]|0)!=0){b=c[3529934]|0;d=c[2387134]|0;f=0;while(1){g=e[d>>1]|0;h=g>>>4;c[b+(f<<2)>>2]=(h&12|g&240)<<3&2016|(g<<4|g&8)<<8&63488|(h&240|g>>>8&8)>>>3&31;g=f+1|0;if((g|0)<1024){d=d+2|0;f=g}else{break}}}f=c[2386412]|0;d=c[2112926]|0;b=c[3530546]|0;g=c[3530782]|0;h=(c[2113222]&1|0)==0;i=0;do{j=256-(e[f+((i|4)<<1)>>1]|0)-16|0;k=(480-(e[f+(i<<1)>>1]|0)&511)-173|0;l=e[f+((i|1)<<1)>>1]|0;m=e[f+((i|3)<<1)>>1]|0;n=l>>>4&15|l<<2&48;o=l&2;p=c[2113068]|0;if((l&4096|0)==0){if(!((j|0)>=(c[2113070]|0)|(k|0)>=(p|0)|(k|0)<-15|(j|0)<-15)){q=14850}}else{if(!((k|0)<-15|h&(k|0)<(p|0)&(j|0)<(c[2113070]|0)^1|(j|0)<-15)){q=14850}}do{if((q|0)==14850){q=0;p=(o|0)!=0?b:g;if((l&8|0)==0){SH(d,m,k,j,n,4,0,0,p);break}else{Sz(d,m,k,j,n,4,0,p);break}}}while(0);i=i+8|0;}while((i|0)<8192);R8(c[3529934]|0);return 0}function eCs(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=i;i=i+64|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;if((d|0)!=0){c[d>>2]=169624}if((b&32|0)!=0){gGz(j|0,0,12);d=c[2414602]|0;c[j>>2]=d;c[j+4>>2]=(c[2411558]|0)-d;c[j+12>>2]=162152;d=c[2076592]|0;gj[d&4095](j)|0}if((b&64|0)==0){i=e;return 0}j=h|0;gGz(g|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){d=h+9|0;h=f;k=f|0;l=f+4|0;m=f+12|0;n=g|0;o=g+4|0;p=g+12|0;q=0;do{gGC(j|0,614896,11)|0;a[d]=q+48&255;r=8452256+(q<<2)|0;gGz(h|0,0,12);c[k>>2]=r;c[l>>2]=4;c[m>>2]=164976;gj[c[2076592]&4095](f)|0;if((c[r>>2]|0)!=0){c[n>>2]=c[14130368+(q<<2)>>2];c[o>>2]=c[8452184+(q<<2)>>2];c[p>>2]=j;r=c[2076592]|0;gj[r&4095](g)|0}q=q+1|0;}while((q|0)<=(c[2392]|0))}fw$(b);Ut(0);if((b&2|0)==0){i=e;return 0}b=c[3528398]|0;q=a[b]&3;a[b]=q&255;c[3541206]=(c[2386604]|0)+(q<<18);i=e;return 0}function eCt(a){a=a|0;c[3532412]=a&255;return}function eCu(a){a=a|0;var b=0;b=a&255;c[3532340]=b&16;c[3532378]=b&64^64;c[3532422]=b&128;return}function eCv(d){d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=d&255;d=~e;c[3532550]=d&4;c[3532424]=d&2;if((e&128|0)!=0){return}e=c[2439330]|0;if((e|0)!=0){d=e;gGC(9706056,d|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;d=c[2433530]|0;c[2433530]=d+12;e=c[1836236]|0;f=c[9757320+(e<<2)>>2]|0;if((a[f+4188|0]|0)==0){g=gfc(100)|0;h=c[1836236]|0;i=g;j=(c[2433530]|0)+g|0;k=h;l=c[9757320+(h<<2)>>2]|0}else{i=100;j=d+112|0;k=e;l=f}c[2433530]=j;c[2113036]=(c[2113036]|0)+i;if((l|0)!=0){i=l;gGC(i|0,9706056,76)|0}c[9752472+(k<<2)>>2]=j;c[14113936+(k<<2)>>2]=c[2076596];c[9669104+(k<<2)>>2]=c[3541536];c[1836236]=-1;return}function eCw(){return 0}function eCx(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=a&255;c[3532560]=b>>>2&3;do{if((b&64|0)==0){a=c[2394]|0;d=14130368+(a<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}e=8452240+(a<<2)|0;c[e>>2]=c[2113054];c[2394]=1;c[2112932]=c[3532597];f=c[3532593]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113061];c[2113051]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0<1024){RH(4);g=c[2394]|0;h=g;i=c[14130368+(g<<2)>>2]|0}else{h=1;i=f}if((i|0)!=0){gGC(i|0,9104152,280)|0}c[8452240+(h<<2)>>2]=c[2113054];c[2394]=-1;if((a|0)==-1){break}c[2394]=a;c[2112932]=c[14130384+(a<<2)>>2];a=c[d>>2]|0;if((a|0)!=0){gGC(9104152,a|0,280)|0}c[2113054]=c[e>>2]}}while(0);if((b&32|0)==0){return}b=c[2394]|0;h=14130368+(b<<2)|0;i=c[h>>2]|0;if((i|0)!=0){gGC(i|0,9104152,280)|0}i=8452240+(b<<2)|0;c[i>>2]=c[2113054];c[2394]=1;c[2112932]=c[3532597];e=c[3532593]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113061];RI();e=c[2394]|0;a=c[14130368+(e<<2)>>2]|0;if((a|0)!=0){gGC(a|0,9104152,280)|0}c[8452240+(e<<2)>>2]=c[2113054];c[2394]=-1;if((b|0)==-1){return}c[2394]=b;c[2112932]=c[14130384+(b<<2)>>2];b=c[h>>2]|0;if((b|0)!=0){gGC(9104152,b|0,280)|0}c[2113054]=c[i>>2];return}function eCy(a){a=a|0;var b=0;switch(a|0){case 14684160:{b=(d[14130136]|0)^255;break};case 14680064:case 14680066:case 14680068:case 14680070:{b=(S3(0,(a-14680064|0)>>>1)|0)&255;break};case 14684170:{b=d[14130176]|0;break};case 14684172:{b=d[14130177]|0;break};default:{b=0}}return b|0}function eCz(b){b=b|0;var d=0,e=0;do{if((b|0)==14692353|(b|0)==14692355|(b|0)==14692357|(b|0)==14692359){d=S3(1,(b-14692352|0)>>>1)|0}else if((b|0)==14684173){d=a[14130177]|0}else if((b|0)==14692385){e=c[3532482]|0;if((e|0)==0){d=-1;break}d=gj[e&4095](c[3532560]&65535)|0}else if((b|0)==14684161){d=~a[14130136]}else if((b|0)==14684171){d=a[14130176]|0}else if((b|0)==14680065|(b|0)==14680067|(b|0)==14680069|(b|0)==14680071){d=S3(0,(b-14680064|0)>>>1)|0}else{d=0}}while(0);return d|0}function eCA(a,b){a=a|0;b=b|0;var c=0;c=a-4194304|0;if(c>>>0<16384){eOW(c^1,b);return}if((a|0)==14692353|(a|0)==14692355|(a|0)==14692357|(a|0)==14692359){S4(1,(a-14692352|0)>>>1,b);return}else if((a|0)==14680065|(a|0)==14680067|(a|0)==14680069|(a|0)==14680071){S4(0,(a-14680064|0)>>>1,b);return}else{return}}function eCB(a,b){a=a|0;b=b|0;var c=0;c=a-4194304|0;if(c>>>0<16384){eOV(c,b);return}if(!((a|0)==14680064|(a|0)==14680066|(a|0)==14680068|(a|0)==14680070)){return}S4(0,(a-14680064|0)>>>1,b&255);return}function eCC(a){a=a|0;var b=0;if((a|0)==1310738){b=-1}else if((a|0)==1310742){b=d[14130177]|0}else if((a|0)==1310736){b=(d[14130136]|0)^255}else if((a|0)==1310740){b=d[14130176]|0}else{b=0}return b|0}function eCD(b){b=b|0;var d=0,e=0;L20205:do{switch(b|0){case 1310741:{d=a[14130176]|0;break};case 1310737:{d=~a[14130136];break};case 1310753:case 1310755:case 1310757:case 1310759:{d=S3(1,(b-1310752|0)>>>1)|0;break};case 1310769:{e=c[3532482]|0;if((e|0)==0){d=-1;break L20205}d=gj[e&4095](c[3532560]&65535)|0;break};case 1310721:case 1310723:case 1310725:case 1310727:{d=S3(0,(b-1310720|0)>>>1)|0;break};default:{d=0}}}while(0);return d|0}function eCE(a,b){a=a|0;b=b|0;var c=0;c=a-1048576|0;if(c>>>0<32768){eOW(c^1,b);return}switch(a|0){case 1310721:case 1310723:case 1310725:case 1310727:{S4(0,(a-1310720|0)>>>1,b);return};case 1310753:case 1310755:case 1310757:case 1310759:{S4(1,(a-1310752|0)>>>1,b);return};default:{return}}}function eCF(a,b){a=a|0;b=b|0;var c=0;c=a-1048576|0;if(c>>>0>=32768){return}eOV(c,b);return}function eCG(a){a=a|0;var b=0,d=0,e=0,f=0;b=a&65535;do{if((b|0)==1){d=((c[3532566]|0)>1)<<31>>31}else if((b|0)==3){a=c[3532572]|0;if(((a>>4)-129|0)>>>0<3841){d=-2;break}d=128-(a>>>4)&255}else if((b|0)==0){d=((c[3532568]|0)>1)<<31>>31}else if((b|0)==2){a=c[3532570]|0;if((a&-16|0)==2048){e=255}else{f=(a>>>4)+128&255;if((f|0)==128){d=32;break}else{e=f}}d=(e>>>0>128)<<31>>31}else{d=0}}while(0);return d|0}function eCH(a){a=a|0;var b=0,d=0,e=0;b=a&65535;if((b|0)==0){a=c[3532572]|0;if(((a>>4)-129|0)>>>0<3841){d=-2}else{d=128-(a>>>4)&255}a=(d&255)<32?32:d;e=(a&255)>224?-32:a;return e|0}else if((b|0)==2){e=((c[3532568]|0)>1)<<31>>31;return e|0}else if((b|0)==1){e=((c[3532570]|0)>1)<<31>>31;return e|0}else{e=0;return e|0}return 0}function eCI(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0;fxU(0,425984);if((c[2394]|0)==0){a=c[2112932]|0}else{c[2394]=0;b=c[3532596]|0;c[2112932]=b;d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];a=b}b=c[3532446]|0;d=a|0;e=d;f=0;while(1){c[e>>2]=b+f;g=f+1024|0;if(g>>>0>262143){break}else{e=e+4|0;f=g}}f=c[3532552]|0;e=d;d=0;while(1){c[e+131072>>2]=f+d;b=d+1024|0;if(b>>>0>262143){break}else{e=e+4|0;d=b}}d=c[3532470]|0;c[a+1024>>2]=d;c[a+66560>>2]=d;c[a+132096>>2]=d;e=d+1024|0;c[a+1028>>2]=e;c[a+66564>>2]=e;c[a+132100>>2]=e;e=d+2048|0;c[a+1032>>2]=e;c[a+66568>>2]=e;c[a+132104>>2]=e;e=d+3072|0;c[a+1036>>2]=e;c[a+66572>>2]=e;c[a+132108>>2]=e;e=d+4096|0;c[a+1040>>2]=e;c[a+66576>>2]=e;c[a+132112>>2]=e;e=d+5120|0;c[a+1044>>2]=e;c[a+66580>>2]=e;c[a+132116>>2]=e;e=d+6144|0;c[a+1048>>2]=e;c[a+66584>>2]=e;c[a+132120>>2]=e;e=d+7168|0;c[a+1052>>2]=e;c[a+66588>>2]=e;c[a+132124>>2]=e;e=d+8192|0;c[a+1056>>2]=e;c[a+66592>>2]=e;c[a+132128>>2]=e;e=d+9216|0;c[a+1060>>2]=e;c[a+66596>>2]=e;c[a+132132>>2]=e;e=d+10240|0;c[a+1064>>2]=e;c[a+66600>>2]=e;c[a+132136>>2]=e;e=d+11264|0;c[a+1068>>2]=e;c[a+66604>>2]=e;c[a+132140>>2]=e;e=d+12288|0;c[a+1072>>2]=e;c[a+66608>>2]=e;c[a+132144>>2]=e;e=d+13312|0;c[a+1076>>2]=e;c[a+66612>>2]=e;c[a+132148>>2]=e;e=d+14336|0;c[a+1080>>2]=e;c[a+66616>>2]=e;c[a+132152>>2]=e;e=d+15360|0;c[a+1084>>2]=e;c[a+66620>>2]=e;c[a+132156>>2]=e;e=c[3532356]|0;d=a+4096|0;f=1048576;while(1){c[d>>2]=e+(f-1048576);b=f+1024|0;if(b>>>0>1081343){break}else{d=d+4|0;f=b}}f=c[3532368]|0;c[a+4224>>2]=f;c[a+69760>>2]=f;c[a+135296>>2]=f;d=f+1024|0;c[a+4228>>2]=d;c[a+69764>>2]=d;c[a+135300>>2]=d;d=f+2048|0;c[a+4232>>2]=d;c[a+69768>>2]=d;c[a+135304>>2]=d;d=f+3072|0;c[a+4236>>2]=d;c[a+69772>>2]=d;c[a+135308>>2]=d;d=c[3532484]|0;c[a+4352>>2]=d;c[a+69888>>2]=d;c[a+135424>>2]=d;f=d+1024|0;c[a+4356>>2]=f;c[a+69892>>2]=f;c[a+135428>>2]=f;f=d+2048|0;c[a+4360>>2]=f;c[a+69896>>2]=f;c[a+135432>>2]=f;f=d+3072|0;c[a+4364>>2]=f;c[a+69900>>2]=f;c[a+135436>>2]=f;f=c[3532542]|0;c[a+4672>>2]=f;c[a+70208>>2]=f;c[a+135744>>2]=f;d=f+1024|0;c[a+4676>>2]=d;c[a+70212>>2]=d;c[a+135748>>2]=d;d=f+2048|0;c[a+4680>>2]=d;c[a+70216>>2]=d;c[a+135752>>2]=d;d=f+3072|0;c[a+4684>>2]=d;c[a+70220>>2]=d;c[a+135756>>2]=d;d=f+4096|0;c[a+4688>>2]=d;c[a+70224>>2]=d;c[a+135760>>2]=d;d=f+5120|0;c[a+4692>>2]=d;c[a+70228>>2]=d;c[a+135764>>2]=d;d=f+6144|0;c[a+4696>>2]=d;c[a+70232>>2]=d;c[a+135768>>2]=d;d=f+7168|0;c[a+4700>>2]=d;c[a+70236>>2]=d;c[a+135772>>2]=d;d=f+8192|0;c[a+4704>>2]=d;c[a+70240>>2]=d;c[a+135776>>2]=d;d=f+9216|0;c[a+4708>>2]=d;c[a+70244>>2]=d;c[a+135780>>2]=d;d=f+10240|0;c[a+4712>>2]=d;c[a+70248>>2]=d;c[a+135784>>2]=d;d=f+11264|0;c[a+4716>>2]=d;c[a+70252>>2]=d;c[a+135788>>2]=d;d=f+12288|0;c[a+4720>>2]=d;c[a+70256>>2]=d;c[a+135792>>2]=d;d=f+13312|0;c[a+4724>>2]=d;c[a+70260>>2]=d;c[a+135796>>2]=d;d=f+14336|0;c[a+4728>>2]=d;c[a+70264>>2]=d;c[a+135800>>2]=d;d=f+15360|0;c[a+4732>>2]=d;c[a+70268>>2]=d;c[a+135804>>2]=d;d=c[3532390]|0;c[a+4864>>2]=d;c[a+70400>>2]=d;c[a+135936>>2]=d;f=d+1024|0;c[a+4868>>2]=f;c[a+70404>>2]=f;c[a+135940>>2]=f;f=d+2048|0;c[a+4872>>2]=f;c[a+70408>>2]=f;c[a+135944>>2]=f;f=d+3072|0;c[a+4876>>2]=f;c[a+70412>>2]=f;c[a+135948>>2]=f;f=c[3532456]|0;c[a+50816>>2]=f;c[a+116352>>2]=f;c[a+181888>>2]=f;d=f+1024|0;c[a+50820>>2]=d;c[a+116356>>2]=d;c[a+181892>>2]=d;d=f+2048|0;c[a+50824>>2]=d;c[a+116360>>2]=d;c[a+181896>>2]=d;d=f+3072|0;c[a+50828>>2]=d;c[a+116364>>2]=d;c[a+181900>>2]=d;c[a+196688>>2]=720;c[a+196608>>2]=698;c[a+196648>>2]=1266;c[a+196728>>2]=162;a=c[3532592]|0;if((a|0)==0){h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return}gGC(a|0,9104152,280)|0;h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return}function eCJ(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0;a=0;while(1){if((a|0)>=1024){b=1;d=15025;break}e=9638528+(a<<2)|0;if((c[e>>2]|0)==0){break}else{a=a+1|0}}if((d|0)==15025){return b|0}a=gGq(262144)|0;c[e>>2]=a;if((a|0)==0){b=1;return b|0}gGz(a|0,0,262144);e=c[3532446]|0;gGC(a|0,e|0,262144)|0;gGz(e|0,0,262144);f=a+65536|0;gGC(e|0,f|0,65536)|0;f=e+65536|0;g=a+131072|0;gGC(f|0,g|0,131072)|0;g=e+196608|0;gGC(g|0,a|0,65536)|0;g=0;while(1){if((g|0)>=1024){b=0;d=15023;break}h=9638528+(g<<2)|0;if((c[h>>2]|0)==(a|0)){break}else{g=g+1|0}}if((d|0)==15023){return b|0}gGr(a);c[h>>2]=0;b=0;return b|0}function eCK(){var a=0,d=0,e=0;a=c[3532572]|0;if(((a>>4)-129|0)>>>0<3841){d=-2}else{d=128-(a>>>4)&255}a=(d&255)<32?32:d;d=c[3532570]|0;if(((d>>4)-129|0)>>>0<3841){e=-2}else{e=128-(d>>>4)&255}d=(e&255)<96?96:e;b[(c[3532470]|0)+1170>>1]=((d&255)>160?160:d&255)|((a&255)>224?-8192:(a&255)<<8);return}function eCL(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>48){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5429308+(b*112|0)>>2];c[a+104>>2]=c[5429312+(b*112|0)>>2];c[a+108>>2]=c[5429316+(b*112|0)>>2];d=0;return d|0}function eCM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<49&(d|0)==0)){e=1;return e|0}c[a>>2]=5429208+(b*112|0);e=0;return e|0}function eCN(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1942408+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eCO(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>56){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5434696+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eCP(){var a=0,b=0,d=0,e=0,f=0,g=0;c[3532512]=10786;c[3532482]=1034;c[3532554]=1e7;c[3532494]=98304;a=eOx()|0;b=0;while(1){if((b|0)>=1024){d=0;break}e=9638528+(b<<2)|0;if((c[e>>2]|0)==0){f=15061;break}else{b=b+1|0}}do{if((f|0)==15061){b=gGq(65536)|0;c[e>>2]=b;if((b|0)==0){d=0;break}gGz(b|0,0,65536);d=b}}while(0);e=c[3532500]|0;gGC(d|0,e|0,65536)|0;gGz(e|0,0,98304);gGC(e|0,d|0,32768)|0;b=e+65536|0;e=d+32768|0;gGC(b|0,e|0,32768)|0;e=0;while(1){if((e|0)>=1024){f=15069;break}g=9638528+(e<<2)|0;if((c[g>>2]|0)==(d|0)){break}else{e=e+1|0}}if((f|0)==15069){return a|0}gGr(d);c[g>>2]=0;return a|0}function eCQ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>49){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4009708+(b*112|0)>>2];c[a+104>>2]=c[4009712+(b*112|0)>>2];c[a+108>>2]=c[4009716+(b*112|0)>>2];d=0;return d|0}function eCR(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<50&(d|0)==0)){e=1;return e|0}c[a>>2]=4009608+(b*112|0);e=0;return e|0}function eCS(){c[3532512]=10786;c[3532482]=1034;c[3532554]=1e7;return eOx()|0}function eCT(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>48){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4015308+(b*112|0)>>2];c[a+104>>2]=c[4015312+(b*112|0)>>2];c[a+108>>2]=c[4015316+(b*112|0)>>2];d=0;return d|0}function eCU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<49&(d|0)==0)){e=1;return e|0}c[a>>2]=4015208+(b*112|0);e=0;return e|0}function eCV(){c[3532546]=4514;c[3532548]=4230;c[3532512]=10786;c[3532482]=1034;c[3532554]=1e7;return eOx()|0}function eCW(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>27){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6279180+(b*112|0)>>2];c[a+104>>2]=c[6279184+(b*112|0)>>2];c[a+108>>2]=c[6279188+(b*112|0)>>2];d=0;return d|0}function eCX(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<28&(d|0)==0)){e=1;return e|0}c[a>>2]=6279080+(b*112|0);e=0;return e|0}function eCY(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3877056+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eCZ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>51){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6282216+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eC_(){var b=0;c[3532482]=3108;c[3532554]=6293700;b=eOx()|0;if((b|0)!=0){return b|0}a[7461840]=1;return b|0}function eC$(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>27){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5365716+(b*112|0)>>2];c[a+104>>2]=c[5365720+(b*112|0)>>2];c[a+108>>2]=c[5365724+(b*112|0)>>2];d=0;return d|0}function eC0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<28&(d|0)==0)){e=1;return e|0}c[a>>2]=5365616+(b*112|0);e=0;return e|0}function eC1(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>27){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5362580+(b*112|0)>>2];c[a+104>>2]=c[5362584+(b*112|0)>>2];c[a+108>>2]=c[5362588+(b*112|0)>>2];d=0;return d|0}function eC2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<28&(d|0)==0)){e=1;return e|0}c[a>>2]=5362480+(b*112|0);e=0;return e|0}function eC3(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>51){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3462972+(b*112|0)>>2];c[a+104>>2]=c[3462976+(b*112|0)>>2];c[a+108>>2]=c[3462980+(b*112|0)>>2];d=0;return d|0}function eC4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<52&(d|0)==0)){e=1;return e|0}c[a>>2]=3462872+(b*112|0);e=0;return e|0}function eC5(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1196120+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eC6(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>57){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3468696+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eC7(){c[3532588]=11060;c[3532512]=10786;c[3532554]=1e7;return eOx()|0}function eC8(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>51){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1700260+(b*112|0)>>2];c[a+104>>2]=c[1700264+(b*112|0)>>2];c[a+108>>2]=c[1700268+(b*112|0)>>2];d=0;return d|0}function eC9(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<52&(d|0)==0)){e=1;return e|0}c[a>>2]=1700160+(b*112|0);e=0;return e|0}function eDa(){var a=0,b=0,d=0;a=c[3532446]|0;b=c[3532552]|0;d=a+196608|0;gGC(b|0,d|0,65536)|0;d=b+65536|0;b=a+65536|0;gGC(d|0,b|0,131072)|0;return 0}function eDb(a){a=a|0;c[3532412]=a&255;return}function eDc(b){b=b|0;var d=0;a[14129368]=b;d=b&255;c[3532340]=d&16;if(!(a[642448]|0)){return}c[3532422]=d&128;return}function eDd(d){d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=d&255;if((e&128|0)!=0){f=~e;g=f&4;c[3532550]=g;h=f&2;c[3532424]=h;return}d=c[2439330]|0;if((d|0)!=0){i=d;gGC(9706056,i|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;i=(c[2433530]|0)+12|0;c[2433530]=i;d=c[1836236]|0;j=c[9757320+(d<<2)>>2]|0;if((j|0)!=0){k=j;gGC(k|0,9706056,76)|0}c[9752472+(d<<2)>>2]=i;c[14113936+(d<<2)>>2]=c[2076596];c[9669104+(d<<2)>>2]=c[3541536];c[1836236]=-1;f=~e;g=f&4;c[3532550]=g;h=f&2;c[3532424]=h;return}function eDe(a){a=a|0;var b=0,d=0;if((a|0)==12976128){b=0;return b|0}else if((a|0)==12845056|(a|0)==12845058|(a|0)==12845060|(a|0)==12845062|(a|0)==12849152|(a|0)==12849154|(a|0)==12849156|(a|0)==12849158|(a|0)==12853248|(a|0)==12853250|(a|0)==12853252|(a|0)==12853254){d=((gj[c[(c[2112932]|0)+196608>>2]&4095](a)|0)&255)<<8;b=(gj[c[(c[2112932]|0)+196608>>2]&4095](a+1|0)|0)&255|d;return b|0}else{b=-1;return b|0}return 0}function eDf(b){b=b|0;var c=0;if((b|0)==12976128){c=0}else if((b|0)==12849155){c=~a[14130137]}else if((b|0)==12849153){c=~a[14130136]}else if((b|0)==12845057|(b|0)==12845059|(b|0)==12845061|(b|0)==12845063){c=S3(0,(b-12845056|0)>>>1)|0}else if((b|0)==12849157){c=a[14130178]|0}else if((b|0)==12849159){c=~a[14130138]}else if((b|0)==12853249){c=a[14130176]|0}else if((b|0)==12853251){c=a[14130177]|0}else{c=-1}return c|0}function eDg(a,b){a=a|0;b=b|0;var d=0;d=a-4194304|0;if(d>>>0<65536){eOV(d,b);return}if(!((a|0)==12845056|(a|0)==12845058|(a|0)==12845060|(a|0)==12845062)){return}gg[c[(c[2112932]|0)+196648>>2]&4095](a,(b&65535)>>>8&255);gg[c[(c[2112932]|0)+196648>>2]&4095](a+1|0,b&255);return}function eDh(a,b){a=a|0;b=b|0;var c=0;c=a-4194304|0;if(c>>>0<65536){eOW(c^1,b);return}if(!((a|0)==12845057|(a|0)==12845059|(a|0)==12845061|(a|0)==12845063)){return}S4(0,(a-12845056|0)>>>1,b);return}function eDi(){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;c=b[4866968]|0;if((a[14130104]|0)==0){d=c}else{e=c+64&65535;b[4866968]=e;d=e}if((a[14130105]|0)==0){f=d}else{e=d-64&65535;b[4866968]=e;f=e}do{if(f<<16>>16>255){b[4866968]=0}else{if(f<<16>>16>=0){break}b[4866968]=253}}while(0);f=b[4866964]|0;if((a[14130106]|0)==0){g=f}else{e=f-64&65535;b[4866964]=e;g=e}if((a[14130107]|0)==0){h=g}else{e=g+64&65535;b[4866964]=e;h=e}do{if(h<<16>>16>255){b[4866964]=0}else{if(h<<16>>16>=0){break}b[4866964]=253}}while(0);h=a[9755504]|0;if((a[14130096]|0)==0){i=h}else{e=h+1&255;a[9755504]=e;i=e}if((a[14130097]|0)==0){j=i}else{e=i-1&255;a[9755504]=e;j=e}do{if(j<<24>>24>15){a[9755504]=0}else{if(j<<24>>24>=0){break}a[9755504]=15}}while(0);j=b[4866960]|0;if((a[14130108]|0)==0){k=j}else{e=j+64&65535;b[4866960]=e;k=e}if((a[14130109]|0)==0){l=k}else{e=k-64&65535;b[4866960]=e;l=e}do{if(l<<16>>16>255){b[4866960]=0}else{if(l<<16>>16>=0){break}b[4866960]=253}}while(0);l=b[4866956]|0;if((a[14130110]|0)==0){m=l}else{e=l-64&65535;b[4866956]=e;m=e}if((a[14130111]|0)==0){n=m}else{e=m+64&65535;b[4866956]=e;n=e}do{if(n<<16>>16>255){b[4866956]=0}else{if(n<<16>>16>=0){break}b[4866956]=253}}while(0);n=a[9755496]|0;if((a[14130098]|0)==0){o=n}else{e=n+1&255;a[9755496]=e;o=e}if((a[14130099]|0)==0){p=o}else{e=o-1&255;a[9755496]=e;p=e}if(p<<24>>24>15){a[9755496]=0;return}if(p<<24>>24>=0){return}a[9755496]=15;return}function eDj(c){c=c|0;var d=0,e=0;do{if((c|0)==12849159){d=a[14129368]|0;if((d<<24>>24|0)==28){e=a[14130142]|0;break}else if((d<<24>>24|0)==24){e=b[4866956]&255;break}else if((d<<24>>24|0)==20){e=b[4866960]&255;break}else if((d<<24>>24|0)==16){e=~a[14130141];break}else{e=-1;break}}else if((c|0)==12849157){e=a[9755496]<<4|a[9755504]}else if((c|0)==12849155){d=a[14129368]|0;if((d<<24>>24|0)==28){e=a[14130138]|0;break}else if((d<<24>>24|0)==20){e=b[4866968]&255;break}else if((d<<24>>24|0)==24){e=b[4866964]&255;break}else if((d<<24>>24|0)==16){e=~a[14130137];break}else{e=-1;break}}else if((c|0)==12853251){e=a[14130177]|0}else if((c|0)==12976128){e=0}else if((c|0)==12849153){e=~a[14130136]}else if((c|0)==12853249){e=a[14130176]|0}else{e=-1}}while(0);return e|0}function eDk(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b[4875272]|0;if((a[14130104]|0)==0){e=d}else{f=d-4&65535;b[4875272]=f;e=f}if((a[14130105]|0)==0){g=e}else{f=e+4&65535;b[4875272]=f;g=f}do{if(g<<16>>16>255){b[4875272]=0}else{if(g<<16>>16>=0){break}b[4875272]=252}}while(0);g=b[4875268]|0;if((a[14130106]|0)==0){h=g}else{f=g-4&65535;b[4875268]=f;h=f}if((a[14130107]|0)==0){i=h}else{f=h+4&65535;b[4875268]=f;i=f}do{if(i<<16>>16>255){b[4875268]=0}else{if(i<<16>>16>=0){break}b[4875268]=252}}while(0);i=b[4875264]|0;if((a[14130108]|0)==0){j=i}else{f=i-4&65535;b[4875264]=f;j=f}if((a[14130109]|0)==0){k=j}else{f=j+4&65535;b[4875264]=f;k=f}do{if(k<<16>>16>255){b[4875264]=0}else{if(k<<16>>16>=0){break}b[4875264]=252}}while(0);k=b[4875260]|0;if((a[14130110]|0)==0){l=k}else{f=k-4&65535;b[4875260]=f;l=f}if((a[14130111]|0)==0){m=l}else{f=l+4&65535;b[4875260]=f;m=f}do{if(m<<16>>16>255){b[4875260]=0}else{if(m<<16>>16>=0){break}b[4875260]=252}}while(0);b[4886572]=((c[3532572]|0)>>>4)+128&65535;b[4886568]=((c[3532570]|0)>>>4)+128&65535;return}function eDl(c){c=c|0;var d=0,f=0,g=0;switch(c|0){case 12849153:{c=(a[14129368]&4)!=0;d=(((c?b[4875268]|0:b[4875272]|0)&65535)>>>1&64|63-(a[14130136]|0)&255|(c?b[4875260]|0:b[4875264]|0)&128)&255;return d|0};case 12853251:{d=a[14130177]|0;return d|0};case 12849159:{d=(((a[14129368]&4)!=0?b[4875260]|0:b[4875264]|0)&127|a[14130138]&-128)^-128;return d|0};case 12849155:{d=(((a[14129368]&4)!=0?b[4875268]|0:b[4875272]|0)&127|a[14130137]&-128)^-128;return d|0};case 12849157:{if((a[14129368]&4)!=0){d=(b[4886568]&240|(e[4886572]|0)>>>4)&255;return d|0}c=~a[14130138];f=~a[14130137]&255;do{if((f&1|0)==0){a[9538160]=0}else{if((f&2|0)==0){a[9538160]=1;break}if((f&4|0)==0){a[9538160]=2;break}if((f&8|0)!=0){break}a[9538160]=3}}while(0);f=c&255;do{if((f&1|0)==0){a[9538152]=0;g=0}else{if((f&2|0)==0){a[9538152]=1;g=16;break}if((f&4|0)==0){a[9538152]=2;g=32;break}if((f&8|0)==0){a[9538152]=3;g=48;break}else{g=a[9538152]<<4;break}}}while(0);d=a[9538160]|g;return d|0};case 12853249:{d=a[14130176]|0;return d|0};default:{d=-1;return d|0}}return 0}function eDm(b){b=b|0;var d=0,e=0,f=0,g=0;do{if((b|0)==12853249){d=15385}else if((b|0)==12853251){e=a[14130177]|0}else if((b|0)==12849155){f=c[2384528]|0;c[2384528]=f+1;g=f&3;if((g|0)==0){e=~a[14130137];break}else if((g|0)==3){e=~a[14130140];break}else if((g|0)==2){e=~a[14130139];break}else if((g|0)==1){e=~a[14130138];break}else{d=15385;break}}else if((b|0)==12849153){e=~a[14130136]}else if((b|0)==12976128){e=0}else{e=-1}}while(0);if((d|0)==15385){e=a[14130176]|0}return e|0}function eDn(b){b=b|0;var c=0;if((b|0)==12976128){c=0}else if((b|0)==12849157){c=~a[14130138]}else if((b|0)==12849159){c=~a[14130139]}else if((b|0)==12849155){c=~a[14130137]}else if((b|0)==12849153){c=~a[14130136]}else if((b|0)==12853251){c=a[14130177]|0}else if((b|0)==12853249){c=a[14130176]|0}else{c=-1}return c|0}function eDo(){b[7057916]=(e[7057916]|0)+((c[3532572]|0)>>>8&255)&65535;b[7057908]=(e[7057908]|0)-((c[3532570]|0)>>>8&255)&65535;b[7057900]=(e[7057900]|0)+((c[3532568]|0)>>>8&255)&65535;b[7057892]=(e[7057892]|0)-((c[3532566]|0)>>>8&255)&65535;return}function eDp(c){c=c|0;var d=0;switch(c|0){case 12853251:{d=a[14130177]|0;break};case 12849159:{d=((a[14129368]&4)!=0?b[7057892]|0:b[7057900]|0)&255;break};case 12849155:{d=((a[14129368]&4)!=0?b[7057908]|0:b[7057916]|0)&255;break};case 12849157:{d=~a[14130137];break};case 12853249:{d=a[14130176]|0;break};case 12849153:{d=~a[14130136];break};default:{d=-1}}return d|0}function eDq(a){a=a|0;var b=0;b=((gj[c[(c[2112932]|0)+196608>>2]&4095](a)|0)&255)<<8;return(gj[c[(c[2112932]|0)+196608>>2]&4095](a+1|0)|0)&255|b|0}function eDr(b){b=b|0;var c=0,e=0;L20743:do{switch(b|0){case 12849155:{c=d[9750560]|0;if((a[c+14130137|0]|0)==-1){e=-1;break L20743}e=(1<<c^255)&255;break};case 12853251:{e=a[14130177]|0;break};case 12849153:{e=~a[14130136];break};case 12853249:{e=a[14130176]|0;break};case 12849157:{e=~a[(d[9750560]|0)+14130137|0];break};default:{e=-1}}}while(0);return e|0}function eDs(e,f){e=e|0;f=f|0;var g=0,h=0,i=0,j=0;g=e-4194304|0;if(g>>>0<65536){eOW(g^1,f);return}if((e|0)==12845057){c[3532412]=f&255;g=c[2439330]|0;if((g|0)!=0){h=g;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;h=(c[2433530]|0)+12|0;c[2433530]=h;g=c[1836236]|0;i=c[9757320+(g<<2)>>2]|0;if((i|0)!=0){j=i;gGC(j|0,9706056,76)|0}c[9752472+(g<<2)>>2]=h;c[14113936+(g<<2)>>2]=c[2076596];c[9669104+(g<<2)>>2]=c[3541536];c[1836236]=-1;return}else if((e|0)==12845059){e=f&255;g=(a[14129368]^f)&255;do{if(!((g&12|0)==0|(g&4|0)==0)){if((e&4|0)==0){break}a[9750560]=((((d[9750560]|0)+1|0)>>>0)%6|0)&255}}while(0);a[14129368]=f;c[3532340]=e&16;return}else{return}}function eDt(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=c[3532470]|0;e=a[d+513|0]|0;f=d+512|0;g=a[f]|0;h=a[d+515|0]|0;i=d+514|0;d=a[i]|0;j=h<<24>>24==0;k=d<<24>>24==0;do{if((h|g|d)<<24>>24==0){l=d;m=h;n=g;o=1}else{if(g<<24>>24!=0){l=d;m=h;n=g-1&255;o=e;break}if(j){l=k?0:d-1&255;m=k?0:89;n=k?0:64;o=k?1:e;break}else{l=d;m=((h&15)==0?-7:-1)+h&255;n=64;o=e;break}}}while(0);b[f>>1]=(o&255)<<8|n&255;b[i>>1]=(m&255)<<8|l&255;return}function eDu(){var a=0,e=0;a=c[3532470]|0;e=c[3532368]|0;b[e+4088>>1]=(d[a+3349|0]|0)<<8|(d[a+3348|0]|0);b[e+4090>>1]=(d[a+3353|0]|0)<<8|(d[a+3352|0]|0);b[e+3742>>1]=(d[a+3357|0]|0)<<8|(d[a+3356|0]|0);b[e+3740>>1]=(d[a+3359|0]|0)<<8|(d[a+3358|0]|0);return}function eDv(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2050012+(b*112|0)>>2];c[a+104>>2]=c[2050016+(b*112|0)>>2];c[a+108>>2]=c[2050020+(b*112|0)>>2];d=0;return d|0}function eDw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<22&(d|0)==0)){e=1;return e|0}c[a>>2]=2049912+(b*112|0);e=0;return e|0}function eDx(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>46){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=991088+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eDy(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>47){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=2052376+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eDz(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c[3532514]=5510;a=eOx()|0;if((a|0)!=0){b=a;return b|0}if((c[2394]|0)==0){d=c[2112932]|0;e=c[3532592]|0}else{c[2394]=0;a=c[3532596]|0;c[2112932]=a;f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];d=a;e=f}c[d+196608>>2]=274;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;e=c[3532380]|0;d=0;while(1){if((d|0)>=1024){g=1;h=0;break}i=9638528+(d<<2)|0;if((c[i>>2]|0)==0){j=15480;break}else{d=d+1|0}}do{if((j|0)==15480){d=gGq(e)|0;c[i>>2]=d;if((d|0)==0){g=1;h=0;break}gGz(d|0,0,e|0);f=c[3532374]|0;a=c[3532380]|0;gGC(d|0,f|0,a)|0;gGC(f|0,d|0,65536)|0;a=f+65536|0;k=d+131072|0;gGC(a|0,k|0,65536)|0;k=f+131072|0;a=d+262144|0;gGC(k|0,a|0,65536)|0;a=f+196608|0;k=d+393216|0;gGC(a|0,k|0,65536)|0;k=f+262144|0;a=d+65536|0;gGC(k|0,a|0,65536)|0;a=f+327680|0;k=d+196608|0;gGC(a|0,k|0,65536)|0;k=f+393216|0;a=d+327680|0;gGC(k|0,a|0,65536)|0;a=f+458752|0;f=d+458752|0;gGC(a|0,f|0,65536)|0;g=0;h=d}}while(0);e=0;while(1){if((e|0)>=1024){b=g;j=15489;break}l=9638528+(e<<2)|0;if((c[l>>2]|0)==(h|0)){break}else{e=e+1|0}}if((j|0)==15489){return b|0}gGr(h);c[l>>2]=0;b=g;return b|0}function eDA(){b[4866968]=0;b[4866964]=0;b[4866960]=0;b[4866956]=0;a[9755504]=0;a[9755496]=0;eOI()|0;return 0}function eDB(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;d=i;i=i+96|0;e=d|0;f=d+16|0;g=d+32|0;h=d+48|0;j=d+64|0;k=d+80|0;if((b|0)!=0){c[b>>2]=169568}if((a&64|0)==0){l=eOS(a,b)|0;i=d;return 0}gGz(k|0,0,12);c[k>>2]=9733936;c[k+4>>2]=2;c[k+12>>2]=291712;gj[c[2076592]&4095](k)|0;gGz(j|0,0,12);c[j>>2]=9733928;c[j+4>>2]=2;c[j+12>>2]=291120;gj[c[2076592]&4095](j)|0;gGz(h|0,0,12);c[h>>2]=9733920;c[h+4>>2]=2;c[h+12>>2]=290312;gj[c[2076592]&4095](h)|0;gGz(g|0,0,12);c[g>>2]=9733912;c[g+4>>2]=2;c[g+12>>2]=289624;gj[c[2076592]&4095](g)|0;gGz(f|0,0,12);c[f>>2]=9755504;c[f+4>>2]=1;c[f+12>>2]=288656;gj[c[2076592]&4095](f)|0;gGz(e|0,0,12);c[e>>2]=9755496;c[e+4>>2]=1;c[e+12>>2]=288032;gj[c[2076592]&4095](e)|0;l=eOS(a,b)|0;i=d;return 0}function eDC(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4297788+(b*112|0)>>2];c[a+104>>2]=c[4297792+(b*112|0)>>2];c[a+108>>2]=c[4297796+(b*112|0)>>2];d=0;return d|0}function eDD(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=4297688+(b*112|0);e=0;return e|0}function eDE(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=947432+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eDF(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>57){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4299816+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eDG(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4292300+(b*112|0)>>2];c[a+104>>2]=c[4292304+(b*112|0)>>2];c[a+108>>2]=c[4292308+(b*112|0)>>2];d=0;return d|0}function eDH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=4292200+(b*112|0);e=0;return e|0}function eDI(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>56){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4294328+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eDJ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2047772+(b*112|0)>>2];c[a+104>>2]=c[2047776+(b*112|0)>>2];c[a+108>>2]=c[2047780+(b*112|0)>>2];d=0;return d|0}function eDK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=2047672+(b*112|0);e=0;return e|0}function eDL(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1323388+(b*112|0)>>2];c[a+104>>2]=c[1323392+(b*112|0)>>2];c[a+108>>2]=c[1323396+(b*112|0)>>2];d=0;return d|0}function eDM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=1323288+(b*112|0);e=0;return e|0}function eDN(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=686104+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eDO(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>53){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4290408+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eDP(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=eOx()|0;if((a|0)!=0){b=a;return b|0}a=c[3532380]|0;d=0;while(1){if((d|0)>=1024){e=1;f=0;break}g=9638528+(d<<2)|0;if((c[g>>2]|0)==0){h=15585;break}else{d=d+1|0}}do{if((h|0)==15585){d=gGq(a)|0;c[g>>2]=d;if((d|0)==0){e=1;f=0;break}gGz(d|0,0,a|0);i=c[3532374]|0;j=c[3532380]|0;gGC(d|0,i|0,j)|0;gGC(i|0,d|0,65536)|0;j=i+65536|0;k=d+131072|0;gGC(j|0,k|0,65536)|0;k=i+131072|0;j=d+262144|0;gGC(k|0,j|0,65536)|0;j=i+196608|0;k=d+393216|0;gGC(j|0,k|0,65536)|0;k=i+262144|0;j=d+65536|0;gGC(k|0,j|0,65536)|0;j=i+327680|0;k=d+196608|0;gGC(j|0,k|0,65536)|0;k=i+393216|0;j=d+327680|0;gGC(k|0,j|0,65536)|0;j=i+458752|0;i=d+458752|0;gGC(j|0,i|0,65536)|0;e=0;f=d}}while(0);a=0;while(1){if((a|0)>=1024){b=e;h=15593;break}l=9638528+(a<<2)|0;if((c[l>>2]|0)==(f|0)){break}else{a=a+1|0}}if((h|0)==15593){return b|0}gGr(f);c[l>>2]=0;b=e;return b|0}function eDQ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2045180+(b*112|0)>>2];c[a+104>>2]=c[2045184+(b*112|0)>>2];c[a+108>>2]=c[2045188+(b*112|0)>>2];d=0;return d|0}function eDR(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=2045080+(b*112|0);e=0;return e|0}function eDS(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2040140+(b*112|0)>>2];c[a+104>>2]=c[2040144+(b*112|0)>>2];c[a+108>>2]=c[2040148+(b*112|0)>>2];d=0;return d|0}function eDT(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=2040040+(b*112|0);e=0;return e|0}function eDU(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=eOx()|0;if((a|0)!=0){b=a;return b|0}a=c[3532380]|0;d=0;while(1){if((d|0)>=1024){e=1;f=0;break}g=9638528+(d<<2)|0;if((c[g>>2]|0)==0){h=15623;break}else{d=d+1|0}}do{if((h|0)==15623){d=gGq(a)|0;c[g>>2]=d;if((d|0)==0){e=1;f=0;break}gGz(d|0,0,a|0);i=c[3532374]|0;j=c[3532380]|0;gGC(d|0,i|0,j)|0;gGC(i|0,d|0,65536)|0;j=i+65536|0;k=d+131072|0;gGC(j|0,k|0,65536)|0;k=i+131072|0;j=d+262144|0;gGC(k|0,j|0,65536)|0;j=i+196608|0;k=d+393216|0;gGC(j|0,k|0,65536)|0;k=i+262144|0;j=d+65536|0;gGC(k|0,j|0,65536)|0;j=i+327680|0;k=d+196608|0;gGC(j|0,k|0,65536)|0;k=i+393216|0;j=d+327680|0;gGC(k|0,j|0,65536)|0;j=i+458752|0;i=d+458752|0;gGC(j|0,i|0,65536)|0;e=0;f=d}}while(0);a=0;while(1){if((a|0)>=1024){b=e;h=15630;break}l=9638528+(a<<2)|0;if((c[l>>2]|0)==(f|0)){break}else{a=a+1|0}}if((h|0)==15630){return b|0}gGr(f);c[l>>2]=0;b=e;return b|0}function eDV(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>23){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4222580+(b*112|0)>>2];c[a+104>>2]=c[4222584+(b*112|0)>>2];c[a+108>>2]=c[4222588+(b*112|0)>>2];d=0;return d|0}function eDW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<24&(d|0)==0)){e=1;return e|0}c[a>>2]=4222480+(b*112|0);e=0;return e|0}function eDX(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>38){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4225168+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eDY(){c[3532588]=7656;return eOx()|0}function eDZ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>23){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4030196+(b*112|0)>>2];c[a+104>>2]=c[4030200+(b*112|0)>>2];c[a+108>>2]=c[4030204+(b*112|0)>>2];d=0;return d|0}function eD_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<24&(d|0)==0)){e=1;return e|0}c[a>>2]=4030096+(b*112|0);e=0;return e|0}function eD$(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3983252+(b*112|0)>>2];c[a+104>>2]=c[3983256+(b*112|0)>>2];c[a+108>>2]=c[3983260+(b*112|0)>>2];d=0;return d|0}function eD0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=3983152+(b*112|0);e=0;return e|0}function eD1(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>56){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3984944+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eD2(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1931156+(b*112|0)>>2];c[a+104>>2]=c[1931160+(b*112|0)>>2];c[a+108>>2]=c[1931164+(b*112|0)>>2];d=0;return d|0}function eD3(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=1931056+(b*112|0);e=0;return e|0}function eD4(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1929364+(b*112|0)>>2];c[a+104>>2]=c[1929368+(b*112|0)>>2];c[a+108>>2]=c[1929372+(b*112|0)>>2];d=0;return d|0}function eD5(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=1929264+(b*112|0);e=0;return e|0}function eD6(){c[3532546]=928;c[3532510]=1906;return eOx()|0}function eD7(){var a=0,b=0,d=0,e=0;a=c[3532336]|0;b=0;while(1){if((b|0)>=1024){break}d=9638528+(b<<2)|0;if((c[d>>2]|0)==(a|0)){e=15712;break}else{b=b+1|0}}if((e|0)==15712){gGr(a);c[d>>2]=0}c[3532336]=0;eOI()|0;return 0}function eD8(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3729364+(b*112|0)>>2];c[a+104>>2]=c[3729368+(b*112|0)>>2];c[a+108>>2]=c[3729372+(b*112|0)>>2];d=0;return d|0}function eD9(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=3729264+(b*112|0);e=0;return e|0}function eEa(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>28){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1230936+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eEb(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>49){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3731840+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eEc(){var b=0,d=0,e=0,f=0,g=0;c[3532514]=11320;a[642448]=1;b=eOx()|0;if((b|0)!=0){return b|0}if((c[2394]|0)==0){d=c[2112932]|0;e=c[3532592]|0}else{c[2394]=0;f=c[3532596]|0;c[2112932]=f;g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060];d=f;e=g}c[d+196608>>2]=2216;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;return b|0}function eEd(){b[4875272]=0;b[4875268]=0;b[4875264]=0;b[4875260]=0;b[4886572]=0;b[4886568]=0;a[642448]=0;eOI()|0;return 0}function eEe(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;d=i;i=i+96|0;e=d|0;f=d+16|0;g=d+32|0;h=d+48|0;j=d+64|0;k=d+80|0;if((b|0)!=0){c[b>>2]=169568}if((a&64|0)==0){l=eOS(a,b)|0;i=d;return 0}gGz(k|0,0,12);c[k>>2]=9750544;c[k+4>>2]=2;c[k+12>>2]=324792;gj[c[2076592]&4095](k)|0;gGz(j|0,0,12);c[j>>2]=9750536;c[j+4>>2]=2;c[j+12>>2]=323912;gj[c[2076592]&4095](j)|0;gGz(h|0,0,12);c[h>>2]=9750528;c[h+4>>2]=2;c[h+12>>2]=323016;gj[c[2076592]&4095](h)|0;gGz(g|0,0,12);c[g>>2]=9750520;c[g+4>>2]=2;c[g+12>>2]=321912;gj[c[2076592]&4095](g)|0;gGz(f|0,0,12);c[f>>2]=9773144;c[f+4>>2]=2;c[f+12>>2]=320712;gj[c[2076592]&4095](f)|0;gGz(e|0,0,12);c[e>>2]=9773136;c[e+4>>2]=2;c[e+12>>2]=319816;gj[c[2076592]&4095](e)|0;l=eOS(a,b)|0;i=d;return 0}function eEf(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1218324+(b*112|0)>>2];c[a+104>>2]=c[1218328+(b*112|0)>>2];c[a+108>>2]=c[1218332+(b*112|0)>>2];d=0;return d|0}function eEg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=1218224+(b*112|0);e=0;return e|0}function eEh(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>42){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1788616+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eEi(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>57){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1220240+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eEj(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c[3532380]=65536;a=eOx()|0;if((a|0)!=0){b=a;return b|0}if((c[2394]|0)==0){d=c[2112932]|0;e=c[3532592]|0}else{c[2394]=0;a=c[3532596]|0;c[2112932]=a;f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];d=a;e=f}c[d+196608>>2]=1028;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;e=c[3532380]|0;d=0;while(1){if((d|0)>=1024){g=1;h=0;break}i=9638528+(d<<2)|0;if((c[i>>2]|0)==0){j=15797;break}else{d=d+1|0}}do{if((j|0)==15797){d=gGq(e)|0;c[i>>2]=d;if((d|0)==0){g=1;h=0;break}gGz(d|0,0,e|0);f=c[3532374]|0;a=c[3532380]|0;gGC(d|0,f|0,a)|0;gGC(f|0,d|0,65536)|0;a=f+65536|0;k=d+131072|0;gGC(a|0,k|0,65536)|0;k=f+131072|0;a=d+262144|0;gGC(k|0,a|0,65536)|0;a=f+262144|0;k=d+65536|0;gGC(a|0,k|0,65536)|0;k=f+327680|0;a=d+196608|0;gGC(k|0,a|0,65536)|0;a=f+393216|0;f=d+327680|0;gGC(a|0,f|0,65536)|0;g=0;h=d}}while(0);e=0;while(1){if((e|0)>=1024){b=g;j=15804;break}l=9638528+(e<<2)|0;if((c[l>>2]|0)==(h|0)){break}else{e=e+1|0}}if((j|0)==15804){return b|0}gGr(h);c[l>>2]=0;b=g;return b|0}function eEk(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>26){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5126308+(b*112|0)>>2];c[a+104>>2]=c[5126312+(b*112|0)>>2];c[a+108>>2]=c[5126316+(b*112|0)>>2];d=0;return d|0}function eEl(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<27&(d|0)==0)){e=1;return e|0}c[a>>2]=5126208+(b*112|0);e=0;return e|0}function eEm(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>34){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1761504+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eEn(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>57){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5129232+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eEo(){var a=0,b=0,d=0,e=0,f=0;c[3532588]=1768;a=eOx()|0;if((a|0)!=0){return a|0}if((c[2394]|0)==0){b=c[2112932]|0;d=c[3532592]|0}else{c[2394]=0;e=c[3532596]|0;c[2112932]=e;f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];b=e;d=f}c[b+196608>>2]=3372;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;return a|0}function eEp(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>26){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3586820+(b*112|0)>>2];c[a+104>>2]=c[3586824+(b*112|0)>>2];c[a+108>>2]=c[3586828+(b*112|0)>>2];d=0;return d|0}function eEq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<27&(d|0)==0)){e=1;return e|0}c[a>>2]=3586720+(b*112|0);e=0;return e|0}function eEr(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>23){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3589844+(b*112|0)>>2];c[a+104>>2]=c[3589848+(b*112|0)>>2];c[a+108>>2]=c[3589852+(b*112|0)>>2];d=0;return d|0}function eEs(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<24&(d|0)==0)){e=1;return e|0}c[a>>2]=3589744+(b*112|0);e=0;return e|0}function eEt(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>48){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6161416+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eEu(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1762164+(b*112|0)>>2];c[a+104>>2]=c[1762168+(b*112|0)>>2];c[a+108>>2]=c[1762172+(b*112|0)>>2];d=0;return d|0}function eEv(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=1762064+(b*112|0);e=0;return e|0}function eEw(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7378436+(b*112|0)>>2];c[a+104>>2]=c[7378440+(b*112|0)>>2];c[a+108>>2]=c[7378444+(b*112|0)>>2];d=0;return d|0}function eEx(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=7378336+(b*112|0);e=0;return e|0}function eEy(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6808488+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eEz(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>56){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7380240+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eEA(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c[3532514]=5762;c[3532380]=65536;a=eOx()|0;if((a|0)!=0){b=a;return b|0}if((c[2394]|0)==0){d=c[2112932]|0;e=c[3532592]|0}else{c[2394]=0;a=c[3532596]|0;c[2112932]=a;f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];d=a;e=f}c[d+196608>>2]=1728;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;e=c[3532380]|0;d=0;while(1){if((d|0)>=1024){g=1;h=0;break}i=9638528+(d<<2)|0;if((c[i>>2]|0)==0){j=15925;break}else{d=d+1|0}}do{if((j|0)==15925){d=gGq(e)|0;c[i>>2]=d;if((d|0)==0){g=1;h=0;break}gGz(d|0,0,e|0);f=c[3532374]|0;a=c[3532380]|0;gGC(d|0,f|0,a)|0;gGC(f|0,d|0,65536)|0;a=f+65536|0;k=d+131072|0;gGC(a|0,k|0,65536)|0;k=f+131072|0;a=d+262144|0;gGC(k|0,a|0,65536)|0;a=f+262144|0;k=d+65536|0;gGC(a|0,k|0,65536)|0;k=f+327680|0;a=d+196608|0;gGC(k|0,a|0,65536)|0;a=f+393216|0;f=d+327680|0;gGC(a|0,f|0,65536)|0;g=0;h=d}}while(0);e=0;while(1){if((e|0)>=1024){b=g;j=15933;break}l=9638528+(e<<2)|0;if((c[l>>2]|0)==(h|0)){break}else{e=e+1|0}}if((j|0)==15933){return b|0}gGr(h);c[l>>2]=0;b=g;return b|0}function eEB(){b[7057916]=0;b[7057908]=0;b[7057900]=0;b[7057892]=0;eOI()|0;return 0}function eEC(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0;d=i;i=i+64|0;e=d|0;f=d+16|0;g=d+32|0;h=d+48|0;if((b|0)!=0){c[b>>2]=169568}if((a&64|0)==0){j=eOS(a,b)|0;i=d;return 0}gGz(h|0,0,12);c[h>>2]=14115832;c[h+4>>2]=2;c[h+12>>2]=251288;gj[c[2076592]&4095](h)|0;gGz(g|0,0,12);c[g>>2]=14115816;c[g+4>>2]=2;c[g+12>>2]=250600;gj[c[2076592]&4095](g)|0;gGz(f|0,0,12);c[f>>2]=14115800;c[f+4>>2]=2;c[f+12>>2]=249936;gj[c[2076592]&4095](f)|0;gGz(e|0,0,12);c[e>>2]=14115784;c[e+4>>2]=2;c[e+12>>2]=249208;gj[c[2076592]&4095](e)|0;j=eOS(a,b)|0;i=d;return 0}function eED(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4994612+(b*112|0)>>2];c[a+104>>2]=c[4994616+(b*112|0)>>2];c[a+108>>2]=c[4994620+(b*112|0)>>2];d=0;return d|0}function eEE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=4994512+(b*112|0);e=0;return e|0}function eEF(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=685736+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eEG(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>57){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4997224+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eEH(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=eOx()|0;if((a|0)!=0){b=a;return b|0}a=c[3532380]|0;d=0;while(1){if((d|0)>=1024){e=1;f=0;break}g=9638528+(d<<2)|0;if((c[g>>2]|0)==0){h=15973;break}else{d=d+1|0}}do{if((h|0)==15973){d=gGq(a)|0;c[g>>2]=d;if((d|0)==0){e=1;f=0;break}gGz(d|0,0,a|0);i=c[3532374]|0;j=c[3532380]|0;gGC(d|0,i|0,j)|0;gGC(i|0,d|0,65536)|0;j=i+65536|0;k=d+131072|0;gGC(j|0,k|0,65536)|0;k=i+131072|0;j=d+262144|0;gGC(k|0,j|0,65536)|0;j=i+196608|0;k=d+393216|0;gGC(j|0,k|0,65536)|0;k=i+262144|0;j=d+65536|0;gGC(k|0,j|0,65536)|0;j=i+327680|0;k=d+196608|0;gGC(j|0,k|0,65536)|0;k=i+393216|0;j=d+327680|0;gGC(k|0,j|0,65536)|0;j=i+458752|0;i=d+458752|0;gGC(j|0,i|0,65536)|0;e=0;f=d}}while(0);a=0;while(1){if((a|0)>=1024){b=e;h=15980;break}l=9638528+(a<<2)|0;if((c[l>>2]|0)==(f|0)){break}else{a=a+1|0}}if((h|0)==15980){return b|0}gGr(f);c[l>>2]=0;b=e;return b|0}function eEI(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3458476+(b*112|0)>>2];c[a+104>>2]=c[3458480+(b*112|0)>>2];c[a+108>>2]=c[3458484+(b*112|0)>>2];d=0;return d|0}function eEJ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=3458376+(b*112|0);e=0;return e|0}function eEK(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3447500+(b*112|0)>>2];c[a+104>>2]=c[3447504+(b*112|0)>>2];c[a+108>>2]=c[3447508+(b*112|0)>>2];d=0;return d|0}function eEL(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=3447400+(b*112|0);e=0;return e|0}function eEM(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3449516+(b*112|0)>>2];c[a+104>>2]=c[3449520+(b*112|0)>>2];c[a+108>>2]=c[3449524+(b*112|0)>>2];d=0;return d|0}function eEN(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=3449416+(b*112|0);e=0;return e|0}function eEO(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3440700+(b*112|0)>>2];c[a+104>>2]=c[3440704+(b*112|0)>>2];c[a+108>>2]=c[3440708+(b*112|0)>>2];d=0;return d|0}function eEP(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<22&(d|0)==0)){e=1;return e|0}c[a>>2]=3440600+(b*112|0);e=0;return e|0}function eEQ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>29){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1695328+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eER(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>35){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3443064+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eES(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=eOx()|0;if((a|0)!=0){b=a;return b|0}if((c[2394]|0)==0){d=c[2112932]|0;e=c[3532592]|0}else{c[2394]=0;a=c[3532596]|0;c[2112932]=a;f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];d=a;e=f}c[d+196648>>2]=372;c[d+196608>>2]=2310;c[d+196688>>2]=2468;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;e=c[3532380]|0;d=0;while(1){if((d|0)>=1024){g=1;h=0;break}i=9638528+(d<<2)|0;if((c[i>>2]|0)==0){j=16056;break}else{d=d+1|0}}do{if((j|0)==16056){d=gGq(e)|0;c[i>>2]=d;if((d|0)==0){g=1;h=0;break}gGz(d|0,0,e|0);f=c[3532374]|0;a=c[3532380]|0;gGC(d|0,f|0,a)|0;gGC(f|0,d|0,65536)|0;a=f+65536|0;k=d+131072|0;gGC(a|0,k|0,65536)|0;k=f+131072|0;a=d+262144|0;gGC(k|0,a|0,65536)|0;a=f+196608|0;k=d+393216|0;gGC(a|0,k|0,65536)|0;k=f+262144|0;a=d+65536|0;gGC(k|0,a|0,65536)|0;a=f+327680|0;k=d+196608|0;gGC(a|0,k|0,65536)|0;k=f+393216|0;a=d+327680|0;gGC(k|0,a|0,65536)|0;a=f+458752|0;f=d+458752|0;gGC(a|0,f|0,65536)|0;g=0;h=d}}while(0);e=0;while(1){if((e|0)>=1024){b=g;j=16065;break}l=9638528+(e<<2)|0;if((c[l>>2]|0)==(h|0)){break}else{e=e+1|0}}if((j|0)==16065){return b|0}gGr(h);c[l>>2]=0;b=g;return b|0}function eET(){a[9750560]=0;eOI()|0;return 0}function eEU(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=i;i=i+16|0;e=d|0;if((b|0)!=0){c[b>>2]=169568}if((a&64|0)==0){f=eOS(a,b)|0;i=d;return 0}gGz(e|0,0,12);c[e>>2]=9750560;c[e+4>>2]=1;c[e+12>>2]=294808;gj[c[2076592]&4095](e)|0;f=eOS(a,b)|0;i=d;return 0}function eEV(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6035772+(b*112|0)>>2];c[a+104>>2]=c[6035776+(b*112|0)>>2];c[a+108>>2]=c[6035780+(b*112|0)>>2];d=0;return d|0}function eEW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=6035672+(b*112|0);e=0;return e|0}function eEX(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>43){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6037208+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eEY(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4930844+(b*112|0)>>2];c[a+104>>2]=c[4930848+(b*112|0)>>2];c[a+108>>2]=c[4930852+(b*112|0)>>2];d=0;return d|0}function eEZ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=4930744+(b*112|0);e=0;return e|0}function eE_(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1655748+(b*112|0)>>2];c[a+104>>2]=c[1655752+(b*112|0)>>2];c[a+108>>2]=c[1655756+(b*112|0)>>2];d=0;return d|0}function eE$(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<21&(d|0)==0)){e=1;return e|0}c[a>>2]=1655648+(b*112|0);e=0;return e|0}function eE0(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=690552+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eE1(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>79){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3307600+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eE2(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7106644+(b*112|0)>>2];c[a+104>>2]=c[7106648+(b*112|0)>>2];c[a+108>>2]=c[7106652+(b*112|0)>>2];d=0;return d|0}function eE3(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=7106544+(b*112|0);e=0;return e|0}function eE4(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>52){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7108448+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eE5(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=eOx()|0;if((a|0)!=0){b=a;return b|0}a=c[3532380]|0;d=0;while(1){if((d|0)>=1024){e=1;f=0;break}g=9638528+(d<<2)|0;if((c[g>>2]|0)==0){h=16154;break}else{d=d+1|0}}do{if((h|0)==16154){d=gGq(a)|0;c[g>>2]=d;if((d|0)==0){e=1;f=0;break}gGz(d|0,0,a|0);i=c[3532374]|0;j=c[3532380]|0;gGC(d|0,i|0,j)|0;gGC(i|0,d|0,65536)|0;j=i+65536|0;k=d+131072|0;gGC(j|0,k|0,65536)|0;k=i+131072|0;j=d+262144|0;gGC(k|0,j|0,65536)|0;j=i+196608|0;k=d+393216|0;gGC(j|0,k|0,65536)|0;k=i+262144|0;j=d+65536|0;gGC(k|0,j|0,65536)|0;j=i+327680|0;k=d+196608|0;gGC(j|0,k|0,65536)|0;k=i+393216|0;j=d+327680|0;gGC(k|0,j|0,65536)|0;j=i+458752|0;i=d+458752|0;gGC(j|0,i|0,65536)|0;e=0;f=d}}while(0);a=0;while(1){if((a|0)>=1024){b=e;h=16162;break}l=9638528+(a<<2)|0;if((c[l>>2]|0)==(f|0)){break}else{a=a+1|0}}if((h|0)==16162){return b|0}gGr(f);c[l>>2]=0;b=e;return b|0}function eE6(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7099476+(b*112|0)>>2];c[a+104>>2]=c[7099480+(b*112|0)>>2];c[a+108>>2]=c[7099484+(b*112|0)>>2];d=0;return d|0}function eE7(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=7099376+(b*112|0);e=0;return e|0}function eE8(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=0;while(1){if((b|0)>=1024){e=0;break}f=9638528+(b<<2)|0;if((c[f>>2]|0)==0){g=16179;break}else{b=b+1|0}}do{if((g|0)==16179){b=gGq(32768)|0;c[f>>2]=b;if((b|0)==0){e=0;break}gGz(b|0,0,32768);e=b}}while(0);c[3532336]=e;f=c[3532330]|0;g=0;do{b=f+g|0;h=(g>>>3<<1&2|g&1|g>>>6<<2&4|g>>>9<<3&8|g>>>12<<4&16|g>>>14<<5&32)<<1;i=c[597224+(h<<2)>>2]|0;j=d[b]|0;k=j&170;a[e+g|0]=((j>>>((d[606056+(i<<2)|0]|0)>>>0)<<6&64|k|j>>>((d[606057+(i<<2)|0]|0)>>>0)<<4&16|j>>>((d[606058+(i<<2)|0]|0)>>>0)<<2&4|j>>>((d[606059+(i<<2)|0]|0)>>>0)&1)^(d[597096+h|0]|0))&255;i=h|1;h=c[597224+(i<<2)>>2]|0;a[b]=((j>>>((d[606056+(h<<2)|0]|0)>>>0)<<6&64|k|j>>>((d[606057+(h<<2)|0]|0)>>>0)<<4&16|j>>>((d[606058+(h<<2)|0]|0)>>>0)<<2&4|j>>>((d[606059+(h<<2)|0]|0)>>>0)&1)^(d[597096+i|0]|0))&255;g=g+1|0;}while((g|0)<32768);return 0}function eE9(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a=c[3532330]|0;b=c[9757320+(c[1836236]<<2)>>2]|0;d=0;e=0;while(1){c[b+76+(e<<2)>>2]=a+(e<<8);f=d+1&65535;if((f&65535)>127){break}else{d=f;e=f&65535}}e=c[3532336]|0;d=0;f=0;while(1){g=f<<8;c[b+76+(f+512<<2)>>2]=e+g;c[b+76+(f+768<<2)>>2]=a+g;g=d+1&65535;if((g&65535)>127){break}else{d=g;f=g&65535}}f=c[3532334]|0;c[b+1068>>2]=f;d=f+256|0;c[b+1072>>2]=d;a=f+512|0;c[b+1076>>2]=a;e=f+768|0;c[b+1080>>2]=e;g=f+1024|0;c[b+1084>>2]=g;h=f+1280|0;c[b+1088>>2]=h;i=f+1536|0;c[b+1092>>2]=i;j=f+1792|0;c[b+1096>>2]=j;c[b+2092>>2]=f;c[b+2096>>2]=d;c[b+2100>>2]=a;c[b+2104>>2]=e;c[b+2108>>2]=g;c[b+2112>>2]=h;c[b+2116>>2]=i;c[b+2120>>2]=j;c[b+3116>>2]=f;c[b+4140>>2]=f;c[b+3120>>2]=d;c[b+4144>>2]=d;c[b+3124>>2]=a;c[b+4148>>2]=a;c[b+3128>>2]=e;c[b+4152>>2]=e;c[b+3132>>2]=g;c[b+4156>>2]=g;c[b+3136>>2]=h;c[b+4160>>2]=h;c[b+3140>>2]=i;c[b+4164>>2]=i;c[b+3144>>2]=j;c[b+4168>>2]=j;c[b+4172>>2]=1872;c[b+4176>>2]=456;return}function eFa(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;h=b>>>1&1|b>>>2&2|b>>>3&4|b>>>6&8|b>>>12&4080;b=e&65535;e=b>>>3&1|b>>>5&2|b>>>8&252;i=c[(c[642608+(c[2436]<<2)>>2]|0)+60>>2]|0;do{if((i&1|0)==0){j=e}else{k=a[f+((h|g<<12)^4096)|0]|0;if(k<<24>>24==64){j=e;break}l=(eFb(k,g)|0)&255;k=l>>>4;m=c[7082480+(k*36|0)>>2]^l>>>3&1^(e>>>((c[7082488+(k*36|0)>>2]|0)>>>0)<<6&64|e>>>((c[7082484+(k*36|0)>>2]|0)>>>0)<<7&128|e>>>((c[7082492+(k*36|0)>>2]|0)>>>0)<<5&32|e>>>((c[7082496+(k*36|0)>>2]|0)>>>0)<<4&16|e>>>((c[7082500+(k*36|0)>>2]|0)>>>0)<<3&8|e>>>((c[7082504+(k*36|0)>>2]|0)>>>0)<<2&4|e>>>((c[7082508+(k*36|0)>>2]|0)>>>0)<<1&2|e>>>((c[7082512+(k*36|0)>>2]|0)>>>0)&1);n=(l&1|0)!=0;o=n?m^177:m;m=(g|0)==0;p=m?o:o^52;do{if(m){o=l>>>6;q=d[1616216+(p^o&1)|0]|0;r=l&7;s=(l>>>2&1&(o^1)|0)==0?r:r|8;if((k&1|0)==0){t=s;u=q;break}t=s^8;u=q}else{q=d[1616216+p|0]|0;s=l&7;r=(l>>>2&1&l>>>6|0)==0?s:s|8;if((l&32|0)==0){t=r;u=q;break}t=r^8;u=q}}while(0);do{if(n){l=(u&1|0)==0?u:u^192;p=l>>>4&1;if((l>>>6&1^1|0)==(p|0)){v=l;break}v=l<<2&4|l&224|l>>>3&1|p<<4|l>>>1<<3&8|l>>>2<<1&2}else{l=u>>>4&1;if((u>>>6&1^1|0)==(l|0)){v=u;break}v=u<<3&8|u&224|u>>>2&1|l<<4|u>>>1<<2&4|u>>>3<<1&2}}while(0);if((v&64|0)==0){w=v<<1&2|v&240|v>>>1&1|v>>>2<<3&8|v>>>3<<2&4}else{w=v}n=c[603888+(t*36|0)>>2]^w;j=n>>>((c[603896+(t*36|0)>>2]|0)>>>0)<<6&64|n>>>((c[603892+(t*36|0)>>2]|0)>>>0)<<7&128|n>>>((c[603900+(t*36|0)>>2]|0)>>>0)<<5&32|n>>>((c[603904+(t*36|0)>>2]|0)>>>0)<<4&16|n>>>((c[603908+(t*36|0)>>2]|0)>>>0)<<3&8|n>>>((c[603912+(t*36|0)>>2]|0)>>>0)<<2&4|n>>>((c[603916+(t*36|0)>>2]|0)>>>0)<<1&2|n>>>((c[603920+(t*36|0)>>2]|0)>>>0)&1}}while(0);if((i&2|0)==0){x=j;y=x<<3;z=y&8;A=x<<5;B=A&64;C=x<<8;D=C&64512;E=b&951;F=B|E;G=F|z;H=G|D;I=H&65535;return I|0}i=a[f+((h|g<<12)^4096)|0]|0;if(i<<24>>24==64){x=j;y=x<<3;z=y&8;A=x<<5;B=A&64;C=x<<8;D=C&64512;E=b&951;F=B|E;G=F|z;H=G|D;I=H&65535;return I|0}h=(eFb(i,g)|0)&255;i=h>>>4;f=c[7082480+(i*36|0)>>2]^h>>>3&1^(j>>>((c[7082488+(i*36|0)>>2]|0)>>>0)<<6&64|j>>>((c[7082484+(i*36|0)>>2]|0)>>>0)<<7&128|j>>>((c[7082492+(i*36|0)>>2]|0)>>>0)<<5&32|j>>>((c[7082496+(i*36|0)>>2]|0)>>>0)<<4&16|j>>>((c[7082500+(i*36|0)>>2]|0)>>>0)<<3&8|j>>>((c[7082504+(i*36|0)>>2]|0)>>>0)<<2&4|j>>>((c[7082508+(i*36|0)>>2]|0)>>>0)<<1&2|j>>>((c[7082512+(i*36|0)>>2]|0)>>>0)&1);j=h&1;t=(j|0)==0?f:f^177;f=(g|0)==0;g=f?t:t^52;do{if(f){t=h>>>6;w=d[1616216+(g^t&1)|0]|0;v=h>>>2&1&(t^1);if((i&1|0)==0){J=v;K=w;break}J=v^1;K=w}else{w=d[1616216+g|0]|0;v=h>>>2&1&h>>>6;if((h&32|0)==0){J=v;K=w;break}J=v^1;K=w}}while(0);g=J^K;if((h&4|0)==0){K=g&252;J=g>>>1&1;if((j|0)==(h>>>1&1|0)){x=g<<1&2|K|J;y=x<<3;z=y&8;A=x<<5;B=A&64;C=x<<8;D=C&64512;E=b&951;F=B|E;G=F|z;H=G|D;I=H&65535;return I|0}x=g<<3&8|g&240|g>>>3&1|J<<2|K>>>1&2;y=x<<3;z=y&8;A=x<<5;B=A&64;C=x<<8;D=C&64512;E=b&951;F=B|E;G=F|z;H=G|D;I=H&65535;return I|0}else{K=g>>>1;J=g>>>3;i=g>>>2;if((j|0)==(h>>>1&1|0)){x=g<<2&4|g&240|i&1|K<<3&8|J<<1&2;y=x<<3;z=y&8;A=x<<5;B=A&64;C=x<<8;D=C&64512;E=b&951;F=B|E;G=F|z;H=G|D;I=H&65535;return I|0}x=i<<3&8|g&241|J<<2&4|K<<1&2;y=x<<3;z=y&8;A=x<<5;B=A&64;C=x<<8;D=C&64512;E=b&951;F=B|E;G=F|z;H=G|D;I=H&65535;return I|0}return 0}function eFb(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;do{if((b|0)==0){c=a^112;d=(c&8)==0?a^114:c;c=(d&64)==0?d:d^-128;d=c&24|(c&255)>>>7|c<<6&64|(c&255)>>>1<<7|(c&255)>>>6<<5&32|(c&255)>>>5<<2&4|(c&255)>>>2<<1&2;c=d&255;e=c>>>6&1;if((e|0)==0){f=d;break}f=(e<<6|c&147|c>>>2<<5&32|c>>>5<<3&8|c>>>3<<2&4)&255}else{c=a^28;e=(c&8)==0?a^60:c;c=e<<24>>24<0?e:e^64;e=(c&255)>>>5<<7|c&83|(c&255)>>>7<<5|(c&255)>>>2<<3&8|(c&255)>>>3<<2&4;c=e&255;d=c>>>6&1;if((d|0)==0){f=e;break}f=(d<<6|c&163|c>>>3<<4&16|c>>>2<<3&8|c>>>4<<2&4)&255}}while(0);a=f&255;if((a&64|0)==0){return((a&16|0)==0?f^32:f)|0}else{return((a&32|0)==0?f:f^16)|0}return 0}function eFc(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;if((b|0)==2|(b|0)==3){if((a[14127616]|0)!=0){f=e&65535;a[14127608]=(a[14127608]&3|f>>>2&60)&255;c[3531908]=c[3531908]&16383|f<<14&49152;a[14127616]=0;return}f=e&65535;if((f&49152|0)==32768){eFd(f);return}else{a[14127608]=(a[14127608]&60|f>>>14)&255;c[3531908]=c[3531908]&49152|f&16383;a[14127616]=1;return}}else if((b|0)==0|(b|0)==1){a[14127616]=0;b=a[14127608]&15;if((b|0)==3){f=(e&65535)>>>1;g=(e&65535)>>>5;h=(e&65535)>>>9;c[(c[3541304]|0)+(((c[3531908]|0)>>>1&63|(a[7461856]|0?6144:0))<<2)>>2]=((h<<2&24|h<<5&255)&255)>>>3|((g<<2&28|g<<5&255)&255)<<3|((f<<2&24|f<<5&255)&255)<<8&63488}else if((b|0)==5){f=c[3531908]|0;g=(f&1|0)==0;h=e&255;i=(e&65535)>>>8&255;j=c[3531880]|0;a[j+(f&126)|0]=g?i:h;a[j+(c[3531908]&126|1)|0]=g?h:i}else if((b|0)==1){b=c[3531908]|0;i=(b&1|0)==0;h=e&255;g=(e&65535)>>>8&255;e=c[3531882]|0;a[e+(b&65534)|0]=i?g:h;a[e+(c[3531908]&65534|1)|0]=i?h:g}c[3531908]=(c[3531908]|0)+(d[14165191]|0);return}else{return}}function eFd(b){b=b|0;var d=0,f=0,g=0,h=0;d=b&255;f=b>>>8&31;a[14165176+f|0]=d;switch(f|0){case 5:{c[3531886]=b<<9&64512;return};case 7:{a[14127624]=d&63;return};case 11:{a[14127512]=b>>>2&1;f=b&3;g=e[600584+(f<<1)>>1]|0;c[3531898]=g;if(f>>>0<2){h=(g<<2)+4|0}else{h=896}c[3531896]=h;return};case 2:{c[3531894]=b<<10&57344;return};case 16:{a[14127552]=a[600576+(b&3)|0]|0;a[14127560]=a[600576+(b>>>4&3)|0]|0;return};case 17:{a[14127480]=d&-128;c[3531872]=b<<4&496;return};case 4:{c[3531892]=b<<13&57344;return};case 12:{h=b&129;if((h|0)==129){a[14127464]=64;return}else if((h|0)==0){a[14127464]=32;return}else if((h|0)==1){a[14127464]=64;return}else if((h|0)==128){a[14127464]=64;return}else{return}break};case 10:{a[14127496]=d&-128;c[3531868]=b<<3&248;return};case 3:{c[3531876]=b<<10&63488;return};case 13:{c[3531900]=b<<10&64512;return};default:{return}}}function eFe(){var b=0,d=0,e=0,f=0,g=0,h=0;b=c[3531882]|0;d=0;while(1){if((d|0)>=1024){break}e=9638528+(d<<2)|0;if((c[e>>2]|0)==(b|0)){f=16286;break}else{d=d+1|0}}if((f|0)==16286){gGr(b);c[e>>2]=0}c[3531882]=0;e=c[3531880]|0;b=0;while(1){if((b|0)>=1024){break}g=9638528+(b<<2)|0;if((c[g>>2]|0)==(e|0)){f=16290;break}else{b=b+1|0}}if((f|0)==16290){gGr(e);c[g>>2]=0}c[3531880]=0;g=c[3531884]|0;e=0;while(1){if((e|0)>=1024){break}h=9638528+(e<<2)|0;if((c[h>>2]|0)==(g|0)){f=16294;break}else{e=e+1|0}}if((f|0)==16294){gGr(g);c[h>>2]=0}c[3531884]=0;gGz(14165176,0,32);h=14165224;c[h>>2]=0;c[h+4>>2]=0;h=14165208;c[h>>2]=0;c[h+4>>2]=0;c[3541304]=0;a[7461856]=0;a[14127624]=0;c[3531894]=0;c[3531892]=0;c[3531876]=0;c[3531886]=0;c[3531898]=0;c[3531896]=0;c[3531900]=0;a[14127512]=0;a[14127464]=0;a[14127552]=0;a[14127560]=0;a[14127480]=0;a[14127496]=0;c[3531872]=0;c[3531868]=0;a[14127616]=0;a[14127608]=0;c[3531908]=0;return}function eFf(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;a=i;i=i+336|0;b=a|0;d=a+16|0;e=a+32|0;f=a+48|0;g=a+64|0;h=a+80|0;j=a+96|0;k=a+112|0;l=a+128|0;m=a+144|0;n=a+160|0;o=a+176|0;p=a+192|0;q=a+208|0;r=a+224|0;s=a+240|0;t=a+256|0;u=a+272|0;v=a+288|0;w=a+304|0;x=a+320|0;y=x;gGz(y|0,0,12);z=x|0;c[z>>2]=c[3531882];A=x+4|0;c[A>>2]=65536;B=x+12|0;c[B>>2]=216480;gj[c[2076592]&4095](x)|0;gGz(y|0,0,12);c[z>>2]=c[3531880];c[A>>2]=128;c[B>>2]=515976;gj[c[2076592]&4095](x)|0;gGz(w|0,0,12);c[w>>2]=14165176;c[w+4>>2]=32;c[w+12>>2]=399344;gj[c[2076592]&4095](w)|0;gGz(v|0,0,12);c[v>>2]=14127624;c[v+4>>2]=1;c[v+12>>2]=309304;gj[c[2076592]&4095](v)|0;gGz(u|0,0,12);c[u>>2]=14127576;c[u+4>>2]=4;c[u+12>>2]=236192;gj[c[2076592]&4095](u)|0;gGz(t|0,0,12);c[t>>2]=14127568;c[t+4>>2]=4;c[t+12>>2]=183864;gj[c[2076592]&4095](t)|0;gGz(s|0,0,12);c[s>>2]=14127504;c[s+4>>2]=4;c[s+12>>2]=148248;gj[c[2076592]&4095](s)|0;gGz(r|0,0,12);c[r>>2]=14127544;c[r+4>>2]=4;c[r+12>>2]=118632;gj[c[2076592]&4095](r)|0;gGz(q|0,0,12);c[q>>2]=14127592;c[q+4>>2]=4;c[q+12>>2]=93624;gj[c[2076592]&4095](q)|0;gGz(p|0,0,12);c[p>>2]=14127584;c[p+4>>2]=4;c[p+12>>2]=73648;gj[c[2076592]&4095](p)|0;gGz(o|0,0,12);c[o>>2]=14127600;c[o+4>>2]=4;c[o+12>>2]=580816;gj[c[2076592]&4095](o)|0;gGz(n|0,0,12);c[n>>2]=14127512;c[n+4>>2]=1;c[n+12>>2]=563824;gj[c[2076592]&4095](n)|0;gGz(m|0,0,12);c[m>>2]=14127464;c[m+4>>2]=1;c[m+12>>2]=548080;gj[c[2076592]&4095](m)|0;gGz(l|0,0,12);c[l>>2]=14127552;c[l+4>>2]=1;c[l+12>>2]=533856;gj[c[2076592]&4095](l)|0;gGz(k|0,0,12);c[k>>2]=14127560;c[k+4>>2]=1;c[k+12>>2]=520360;gj[c[2076592]&4095](k)|0;gGz(j|0,0,12);c[j>>2]=14127480;c[j+4>>2]=1;c[j+12>>2]=507080;gj[c[2076592]&4095](j)|0;gGz(h|0,0,12);c[h>>2]=14127496;c[h+4>>2]=1;c[h+12>>2]=494928;gj[c[2076592]&4095](h)|0;gGz(g|0,0,12);c[g>>2]=14127488;c[g+4>>2]=4;c[g+12>>2]=482936;gj[c[2076592]&4095](g)|0;gGz(f|0,0,12);c[f>>2]=14127472;c[f+4>>2]=4;c[f+12>>2]=470480;gj[c[2076592]&4095](f)|0;gGz(e|0,0,12);c[e>>2]=14127616;c[e+4>>2]=1;c[e+12>>2]=459056;gj[c[2076592]&4095](e)|0;gGz(d|0,0,12);c[d>>2]=14127608;c[d+4>>2]=1;c[d+12>>2]=448672;gj[c[2076592]&4095](d)|0;gGz(b|0,0,12);c[b>>2]=14127632;c[b+4>>2]=4;c[b+12>>2]=436920;gj[c[2076592]&4095](b)|0;i=a;return}function eFg(a,b,e,f,g){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=(c[3531900]|0)+b+((c[3531898]&a)<<2)|0;i=c[3531882]|0;j=1024-((d[i+(h&65535)|0]|0)<<8&768|(d[i+(h+1&65535)|0]|0))|0;c[g>>2]=-(j&7);g=j>>>3;j=g&1;h=d[14127512]|0;k=c[3531880]|0;l=k+(b&127)|0;m=k+(b+1&127)|0;n=0;o=f;while(1){f=n-j&63;if((h|0)==0){p=(d[l]|0)<<8&1792|(d[m]|0)}else if((h|0)==1){q=((f|0)==40?76:f>>>1<<2)+b|0;p=(d[k+(q&127)|0]|0)<<8&1792|(d[k+(q+1&127)|0]|0)}else{p=0}q=p+a|0;f=d[14127552]|0;r=(ag(f<<1,(d[14127560]|0)-1&((q|0)/8|0))|0)+e+((f-1&n+g)<<1)|0;c[o>>2]=d[i+(r+1&65535)|0]|0|((q|0)%8|0)<<16|(d[i+(r&65535)|0]|0)<<8;r=n+1|0;if((r|0)<41){n=r;o=o+4|0}else{break}}return}function eFh(a,d,f,g,h,i){a=a|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;if(!((h|0)<=(i|0)&(g|0)<320)){return}j=i-7|0;k=h-8|0;l=c[3531882]|0;m=g;n=d+(g<<1)|0;g=a;while(1){a=g+4|0;d=c[g>>2]|0;do{if((d>>>15&1|0)==(f|0)){o=e[14165224+((d>>>13&3)<<1)>>1]|0;p=d>>>16;q=c[l+(d<<5&65504)+(((d&4096|0)==0?p:p^7)<<2)>>2]|0;if((q|0)==0){break}p=(m|0)<(h|0);if(!((m|0)>(j|0)|p)){if((d&2048|0)==0){r=q>>>4&15;if((r|0)!=0){b[n>>1]=r+o&65535}r=q&15;if((r|0)!=0){b[n+2>>1]=r+o&65535}r=q>>>12&15;if((r|0)!=0){b[n+4>>1]=r+o&65535}r=q>>>8&15;if((r|0)!=0){b[n+6>>1]=r+o&65535}r=q>>>20&15;if((r|0)!=0){b[n+8>>1]=r+o&65535}r=q>>>16&15;if((r|0)!=0){b[n+10>>1]=r+o&65535}r=q>>>28;if((r|0)!=0){b[n+12>>1]=r+o&65535}r=q>>>24&15;if((r|0)==0){break}b[n+14>>1]=r+o&65535;break}else{r=q>>>24&15;if((r|0)!=0){b[n>>1]=r+o&65535}r=q>>>28;if((r|0)!=0){b[n+2>>1]=r+o&65535}r=q>>>16&15;if((r|0)!=0){b[n+4>>1]=r+o&65535}r=q>>>20&15;if((r|0)!=0){b[n+6>>1]=r+o&65535}r=q>>>8&15;if((r|0)!=0){b[n+8>>1]=r+o&65535}r=q>>>12&15;if((r|0)!=0){b[n+10>>1]=r+o&65535}r=q&15;if((r|0)!=0){b[n+12>>1]=r+o&65535}r=q>>>4&15;if((r|0)==0){break}b[n+14>>1]=r+o&65535;break}}if((m|0)<(k|0)|(m|0)>(i|0)){break}if((d&2048|0)==0){r=q>>>4&15;if(!((r|0)==0|p)){b[n>>1]=r+o&65535}r=q&15;do{if((r|0)!=0){s=m+1|0;if((s|0)<(h|0)|(s|0)>(i|0)){break}b[n+2>>1]=r+o&65535}}while(0);r=q>>>12&15;do{if((r|0)!=0){s=m+2|0;if((s|0)<(h|0)|(s|0)>(i|0)){break}b[n+4>>1]=r+o&65535}}while(0);r=q>>>8&15;do{if((r|0)!=0){s=m+3|0;if((s|0)<(h|0)|(s|0)>(i|0)){break}b[n+6>>1]=r+o&65535}}while(0);r=q>>>20&15;do{if((r|0)!=0){s=m+4|0;if((s|0)<(h|0)|(s|0)>(i|0)){break}b[n+8>>1]=r+o&65535}}while(0);r=q>>>16&15;do{if((r|0)!=0){s=m+5|0;if((s|0)<(h|0)|(s|0)>(i|0)){break}b[n+10>>1]=r+o&65535}}while(0);r=q>>>28;do{if((r|0)!=0){s=m+6|0;if((s|0)<(h|0)|(s|0)>(i|0)){break}b[n+12>>1]=r+o&65535}}while(0);r=q>>>24&15;if((r|0)==0){break}s=m+7|0;if((s|0)<(h|0)|(s|0)>(i|0)){break}b[n+14>>1]=r+o&65535;break}else{r=q>>>24&15;if(!((r|0)==0|p)){b[n>>1]=r+o&65535}r=q>>>28;do{if((r|0)!=0){s=m+1|0;if((s|0)<(h|0)|(s|0)>(i|0)){break}b[n+2>>1]=r+o&65535}}while(0);r=q>>>16&15;do{if((r|0)!=0){p=m+2|0;if((p|0)<(h|0)|(p|0)>(i|0)){break}b[n+4>>1]=r+o&65535}}while(0);r=q>>>20&15;do{if((r|0)!=0){p=m+3|0;if((p|0)<(h|0)|(p|0)>(i|0)){break}b[n+6>>1]=r+o&65535}}while(0);r=q>>>8&15;do{if((r|0)!=0){p=m+4|0;if((p|0)<(h|0)|(p|0)>(i|0)){break}b[n+8>>1]=r+o&65535}}while(0);r=q>>>12&15;do{if((r|0)!=0){p=m+5|0;if((p|0)<(h|0)|(p|0)>(i|0)){break}b[n+10>>1]=r+o&65535}}while(0);r=q&15;do{if((r|0)!=0){p=m+6|0;if((p|0)<(h|0)|(p|0)>(i|0)){break}b[n+12>>1]=r+o&65535}}while(0);r=q>>>4&15;if((r|0)==0){break}p=m+7|0;if((p|0)<(h|0)|(p|0)>(i|0)){break}b[n+14>>1]=r+o&65535;break}}}while(0);d=m+8|0;if((d|0)<320){m=d;n=n+16|0;g=a}else{break}}return}function eFi(a,b,c){a=a|0;b=b|0;c=c|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=((d[c]|0)<<8&256|(d[c+1|0]|0))-128|0;g=((d[c+6|0]|0)<<8&256|(d[c+7|0]|0))-128|0;h=d[c+2|0]|0;i=(h<<3&24)+8|0;j=(h>>>2<<3&24)+8|0;if((f|0)>(a|0)){return}if((i+f|0)<=(a|0)){return}if((j+g|0)<0|(g|0)>319){return}h=d[c+4|0]|0;k=h<<8&1792|(d[c+5|0]|0);c=h>>>3&3;l=a-f|0;f=e[14165208+((h>>>5&3)<<1)>>1]|0;h=j>>3;j=i>>3;a=b+(g<<1)|0;if((c|0)==1){b=k+(ag(h-1|0,j)|0)|0;m=g;n=a;o=0;while(1){if((m+7|0)>>>0<327){eFk(n,b,f,l)}p=o+1|0;if((p|0)<(h|0)){b=b-j|0;m=m+8|0;n=n+16|0;o=p}else{break}}return}else if((c|0)==2){o=i+~l|0;n=k;m=g;b=a;p=0;while(1){if((m+7|0)>>>0<327){eFj(b,n,f,o)}q=p+1|0;if((q|0)<(h|0)){n=n+j|0;m=m+8|0;b=b+16|0;p=q}else{break}}return}else if((c|0)==3){p=i+~l|0;i=k+(ag(h-1|0,j)|0)|0;b=g;m=a;n=0;while(1){if((b+7|0)>>>0<327){eFk(m,i,f,p)}o=n+1|0;if((o|0)<(h|0)){i=i-j|0;b=b+8|0;m=m+16|0;n=o}else{break}}return}else if((c|0)==0){c=k;k=g;g=a;a=0;while(1){if((k+7|0)>>>0<327){eFj(g,c,f,l)}n=a+1|0;if((n|0)<(h|0)){c=c+j|0;k=k+8|0;g=g+16|0;a=n}else{break}}return}else{return}}function eFj(d,e,f,g){d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=c[(c[3531882]|0)+((g<<2)+(e<<5)&65535)>>2]|0;if((h|0)==0){return}do{if((f&48|0)==48){if((a[14165188]&8)==0){break}e=h>>>4;g=e&15;do{if((g|0)!=0){if(g>>>0<14){b[d>>1]=g+f&65535;break}else{b[d>>1]=b[(c[3531884]|0)+((b[d>>1]&2047|e<<11&2048)<<1)>>1]|0;break}}}while(0);e=h&15;do{if((e|0)!=0){if(e>>>0<14){b[d+2>>1]=e+f&65535;break}else{g=d+2|0;b[g>>1]=b[(c[3531884]|0)+((b[g>>1]&2047|h<<11&2048)<<1)>>1]|0;break}}}while(0);e=h>>>12;g=e&15;do{if((g|0)!=0){if(g>>>0<14){b[d+4>>1]=g+f&65535;break}else{i=d+4|0;b[i>>1]=b[(c[3531884]|0)+((b[i>>1]&2047|e<<11&2048)<<1)>>1]|0;break}}}while(0);e=h>>>8;g=e&15;do{if((g|0)!=0){if(g>>>0<14){b[d+6>>1]=g+f&65535;break}else{i=d+6|0;b[i>>1]=b[(c[3531884]|0)+((b[i>>1]&2047|e<<11&2048)<<1)>>1]|0;break}}}while(0);e=h>>>20;g=e&15;do{if((g|0)!=0){if(g>>>0<14){b[d+8>>1]=g+f&65535;break}else{i=d+8|0;b[i>>1]=b[(c[3531884]|0)+((b[i>>1]&2047|e<<11&2048)<<1)>>1]|0;break}}}while(0);e=h>>>16;g=e&15;do{if((g|0)!=0){if(g>>>0<14){b[d+10>>1]=g+f&65535;break}else{i=d+10|0;b[i>>1]=b[(c[3531884]|0)+((b[i>>1]&2047|e<<11&2048)<<1)>>1]|0;break}}}while(0);e=h>>>28;do{if((e|0)!=0){if(h>>>0<3758096384){b[d+12>>1]=e+f&65535;break}else{g=d+12|0;b[g>>1]=b[(c[3531884]|0)+((b[g>>1]&2047|e<<11&2048)<<1)>>1]|0;break}}}while(0);e=h>>>24;g=e&15;if((g|0)==0){return}if(g>>>0<14){b[d+14>>1]=g+f&65535;return}else{g=d+14|0;b[g>>1]=b[(c[3531884]|0)+((b[g>>1]&2047|e<<11&2048)<<1)>>1]|0;return}}}while(0);e=h>>>4&15;if((e|0)!=0){b[d>>1]=e+f&65535}e=h&15;if((e|0)!=0){b[d+2>>1]=e+f&65535}e=h>>>12&15;if((e|0)!=0){b[d+4>>1]=e+f&65535}e=h>>>8&15;if((e|0)!=0){b[d+6>>1]=e+f&65535}e=h>>>20&15;if((e|0)!=0){b[d+8>>1]=e+f&65535}e=h>>>16&15;if((e|0)!=0){b[d+10>>1]=e+f&65535}e=h>>>28;if((e|0)!=0){b[d+12>>1]=e+f&65535}e=h>>>24&15;if((e|0)==0){return}b[d+14>>1]=e+f&65535;return}function eFk(d,e,f,g){d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=c[(c[3531882]|0)+((g<<2)+(e<<5)&65535)>>2]|0;if((h|0)==0){return}do{if((f&48|0)==48){if((a[14165188]&8)==0){break}e=h>>>24;g=e&15;do{if((g|0)!=0){if(g>>>0<14){b[d>>1]=g+f&65535;break}else{b[d>>1]=b[(c[3531884]|0)+((b[d>>1]&2047|e<<11&2048)<<1)>>1]|0;break}}}while(0);e=h>>>28;do{if((e|0)!=0){if(h>>>0<3758096384){b[d+2>>1]=e+f&65535;break}else{g=d+2|0;b[g>>1]=b[(c[3531884]|0)+((b[g>>1]&2047|e<<11&2048)<<1)>>1]|0;break}}}while(0);e=h>>>16;g=e&15;do{if((g|0)!=0){if(g>>>0<14){b[d+4>>1]=g+f&65535;break}else{i=d+4|0;b[i>>1]=b[(c[3531884]|0)+((b[i>>1]&2047|e<<11&2048)<<1)>>1]|0;break}}}while(0);e=h>>>20;g=e&15;do{if((g|0)!=0){if(g>>>0<14){b[d+6>>1]=g+f&65535;break}else{i=d+6|0;b[i>>1]=b[(c[3531884]|0)+((b[i>>1]&2047|e<<11&2048)<<1)>>1]|0;break}}}while(0);e=h>>>8;g=e&15;do{if((g|0)!=0){if(g>>>0<14){b[d+8>>1]=g+f&65535;break}else{i=d+8|0;b[i>>1]=b[(c[3531884]|0)+((b[i>>1]&2047|e<<11&2048)<<1)>>1]|0;break}}}while(0);e=h>>>12;g=e&15;do{if((g|0)!=0){if(g>>>0<14){b[d+10>>1]=g+f&65535;break}else{i=d+10|0;b[i>>1]=b[(c[3531884]|0)+((b[i>>1]&2047|e<<11&2048)<<1)>>1]|0;break}}}while(0);e=h&15;do{if((e|0)!=0){if(e>>>0<14){b[d+12>>1]=e+f&65535;break}else{g=d+12|0;b[g>>1]=b[(c[3531884]|0)+((b[g>>1]&2047|h<<11&2048)<<1)>>1]|0;break}}}while(0);e=h>>>4;g=e&15;if((g|0)==0){return}if(g>>>0<14){b[d+14>>1]=g+f&65535;return}else{g=d+14|0;b[g>>1]=b[(c[3531884]|0)+((b[g>>1]&2047|e<<11&2048)<<1)>>1]|0;return}}}while(0);e=h>>>24&15;if((e|0)!=0){b[d>>1]=e+f&65535}e=h>>>28;if((e|0)!=0){b[d+2>>1]=e+f&65535}e=h>>>16&15;if((e|0)!=0){b[d+4>>1]=e+f&65535}e=h>>>20&15;if((e|0)!=0){b[d+6>>1]=e+f&65535}e=h>>>8&15;if((e|0)!=0){b[d+8>>1]=e+f&65535}e=h>>>12&15;if((e|0)!=0){b[d+10>>1]=e+f&65535}e=h&15;if((e|0)!=0){b[d+12>>1]=e+f&65535}e=h>>>4&15;if((e|0)==0){return}b[d+14>>1]=e+f&65535;return}function eFl(b,f,g,h){b=b|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0;if((g|0)==0){i=0;return i|0}j=c[2444202]|0;k=c[2444200]|0;l=c[2444198]|0;m=b&8191;n=d[g+((b&4092|0)==0&(b|0)>3?m|4096:m)|0]|0;m=n>>>7;g=n>>>6;o=((b&4096|0)==0?g:m)&1;if((h|0)==0){p=j;q=k;r=l;s=o}else{h=(b|0)<2;p=h?0:j;q=(b|0)<3?0:k;r=(b|0)<4?0:l;s=h?0:o}o=p&32;h=p&4;l=p&1;b=q>>>5&1;k=q&4;j=r&64;t=r&16;u=r&4;v=n&1;w=r>>>1&1;x=p>>>7&1;y=p>>>1&1;z=n>>>1&1;A=q>>>7&1;B=p>>>3&1;C=n>>>2&1;D=r>>>7&1;E=p>>>4&1;F=n>>>3&1;G=q&1;H=r>>>3&1;I=n>>>4&1;J=q>>>3&1;K=r&1;L=n>>>5&1;n=r>>>5&1;r=p>>>6&1;p=g&1;g=q>>>1&1;M=q>>>6&1;N=q>>>4&1;do{if((f&57344|0)==0){O=f>>>15<<14&16384|f&4095|f>>>12<<15&32768|f>>>14<<13&8192|f>>>13<<12&4096}else{if((f&32768|0)==0){P=f}else{if((h|0)==0){Q=f}else{Q=(f&8|0)==0?f^9232:f}q=(Q&4|0)==0?Q^34:Q;if((z|0)==(B|0)){R=(q&4096|0)==0?q^2120:q}else{R=q}q=(l|0)!=0&(v|0)==(y|0)?R^16641:R;if((C|0)==(E|0)){S=q>>>9<<12&4096|q&60795|q>>>12<<9&512|q>>>2<<7&128|q>>>7<<2&4}else{S=q}P=(S<<9&512|S&32768|S>>>7&1|S>>>9<<14&16384|S>>>10<<13&8192|S>>>13<<12&4096|S>>>3<<11&2048|S>>>12<<10&1024|S>>>14<<8&256|S>>>6<<7&128|S>>>5<<6&64|S>>>2<<5&32|S>>>11<<4&16|S>>>8<<3&8|S>>>1<<2&4|S>>>4<<1&2)^25953}if((P&16384|0)==0){T=P}else{if((o|0)==0){U=P}else{U=(P&2048|0)==0?P:P^36936}if((F|0)==(G|0)){V=(U&4|0)==0?U:U^514}else{V=U}if((p|0)==(g|0)){W=(V&1024|0)==0?V:V^4}else{W=V}q=(L|0)==(r|0)&(v|0)==(x|0)?W^2209:W;if((k|0)==0){X=q}else{X=q>>>10<<13&8192|q&56047|q>>>13<<10&1024|q>>>4<<8&256|q>>>8<<4&16}T=(X<<12&4096|X&16384|X>>>9&1|X>>>13<<15&32768|X>>>7<<13&8192|X>>>8<<11&2048|X>>>6<<10&1024|X>>>4<<9&512|X>>>2<<8&256|X>>>1<<7&128|X>>>15<<6&64|X>>>3<<5&32|X>>>11<<4&16|X>>>12<<3&8|X>>>10<<2&4|X>>>5<<1&2)^13603}if((T&8192|0)==0){Y=T}else{if((I|0)==(J|0)){Z=(T&256|0)==0?T:T^16912}else{Z=T}if((z|0)==(A|0)){_=(Z&64|0)==0?Z:Z^128}else{_=Z}if((m|0)==(N|0)){$=(_&1|0)==0?_:_^4362}else{$=_}q=(I|0)==(K|0)&(v|0)==(w|0)?$^64:$;aa=(b|0)!=0&(p|0)==(M|0)?q^1028:q;if((L|0)==(r|0)){ab=aa<<15&32768|aa&30686|aa>>>5&1|aa>>>15<<11&2048|aa>>>11<<5&32}else{ab=aa}Y=(ab<<10&1024|ab&8192|ab>>>12&1|ab>>>2<<14&16384|ab>>>10<<15&32768|ab>>>7<<12&4096|ab>>>8<<11&2048|ab>>>3<<9&512|ab>>>14<<8&256|ab>>>6<<7&128|ab>>>15<<6&64|ab>>>1<<5&32|ab>>>11<<4&16|ab>>>9<<3&8|ab>>>4<<2&4|ab>>>5<<1&2)^39333}aa=(Y<<10&1024|Y&8704|Y>>>8&1|Y>>>15<<14&16384|Y>>>5<<15&32768|Y>>>14<<12&4096|Y>>>6<<11&2048|Y>>>10<<8&256|Y>>>4<<7&128|Y>>>11<<6&64|Y>>>1<<5&32|Y>>>2<<4&16|Y>>>12<<3&8|Y>>>3<<2&4|Y>>>7<<1&2)^34815;if((u|0)==0){ac=aa}else{ac=aa>>>6<<15&32768|aa&32415|aa>>>5<<8&256|aa>>>15<<6&64|aa>>>8<<5&32}if((j|0)==0){ad=ac}else{ad=ac>>>12<<14&16384|ac&36863|ac>>>14<<13&8192|ac>>>13<<12&4096}if((l|0)==0){ae=ad}else{ae=ad<<2&4|ad&64378|ad>>>7&1|ad>>>2<<10&1024|ad>>>10<<7&128}if((F|0)==(H|0)){af=ae>>>4<<9&512|ae&64997|ae>>>9<<4&16|ae>>>1<<3&8|ae>>>3<<1&2}else{af=ae}if((C|0)==(D|0)){ag=af>>>12<<14&16384|af&45055|af>>>14<<12&4096}else{ag=af}if((t|0)==0){ah=ag}else{ah=ag>>>9<<11&2048|ag&61695|ag>>>8<<10&1024|ag>>>11<<9&512|ag>>>10<<8&256}if((L|0)==(n|0)){ai=ah>>>4<<7&128|ah&65295|ah>>>5<<6&64|ah>>>7<<5&32|ah>>>6<<4&16}else{ai=ah}if((b|0)==0){O=ai;break}O=ai<<3&8|ai&65520|ai>>>1&1|ai>>>3<<2&4|ai>>>2<<1&2}}while(0);ai=O&61568;b=(ai|0)==32768?O^128:O;ah=(ai|0)==49280?b^128:b;b=(O&45184|0)==32768?ah^16384:ah;ah=(O&45312|0)==0?b^16384:b;if(!(a[689336]|0)){a[689336]=1;b=0;while(1){O=e[4558608+(b<<1)>>1]|0;ai=1<<(O>>>1&7);n=O>>>4;O=9708936+n|0;a[O]=(ai|(d[O]|0))&255;O=9713032+n|0;a[O]=(ai|(d[O]|0))&255;O=b+1|0;if(O>>>0<387){b=O}else{aj=0;break}}do{if((aj&65408|0)==20096|(aj&61688|0)==20680|(aj&61440|0)==24576){b=9713032+(aj>>>4)|0;a[b]=(d[b]|0|1<<(aj>>>1&7))&255}aj=aj+2|0;}while(aj>>>0<65536)}i=((d[(ah>>4)+(9708936+(s<<12))|0]|0)&1<<(ah>>>1&7)|0)==0?ah:65535;return i|0}function eFm(b,c){b=b|0;c=c|0;switch(b&65535|0){case 61441:{a[14107792]=c;break};case 61445:{a[14114384]=c;break};case 61443:{a[14107800]=c;break};case 61440:{a[9542864]=c;break};case 61442:{a[9542872]=c;break};case 61444:{a[9635944]=c;break};default:{}}return}function eFn(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=b&65535;switch(e&255|0){case 195:case 194:case 193:case 192:{a[(c[2439256]|0)+(e&3)|0]=d;return};case 66:{e=d&15;c[3527214]=e;d=c[3529230]|0;b=c[9757320+(c[1836236]<<2)>>2]|0;f=(e<<14)+32768|0;e=128;g=128;while(1){c[b+76+(g<<2)>>2]=d+(f+(g<<8));h=e+1&65535;if((h&65535)>191){break}else{e=h;g=h&65535}}g=(c[3527214]<<14)+32768|0;e=128;f=128;while(1){c[b+76+(f<<2)>>2]=d+(g+(f<<8));h=e+1&65535;if((h&65535)>191){break}else{e=h;f=h&65535}}return};default:{return}}}function eFo(d){d=d|0;var e=0,f=0;e=d&65535;switch(e&255|0){case 65:{f=a[9634833]|0;break};case 66:{f=-1;break};case 192:case 193:case 194:case 195:{f=a[(c[2438900]|0)+(e&3)|0]|0;break};case 64:{f=a[9634832]|0;break};case 128:case 129:case 130:{f=b[9550288+((e&3)<<1)>>1]&255;break};default:{f=0}}return f|0}function eFp(b,d){b=b|0;d=d|0;var e=0;e=b&65535;switch(e&255|0){case 64:case 65:{lS(1,e&1,d);return};case 128:case 129:case 130:case 131:{a[(c[2438900]|0)+(e&3)|0]=d;return};case 0:case 1:{lS(0,e&1,d);return};default:{return}}}function eFq(b){b=b|0;var e=0,f=0,g=0.0,i=0.0,j=0,k=0;e=b&65535;switch(e&255|0){case 64:case 65:{b=c[3541518]|0;if((e&1|0)==0){f=b+19320|0;g=+h[f>>3];do{if(g!=0.0){i=+h[6675];if(g-(i+ +gC[c[2429842]&255]())<=0.0){h[f>>3]=0.0;break}j=a[b+19331|0]|-128;return j|0}}while(0);j=a[b+19331|0]|0;return j|0}if((d[b+19328|0]|0)>=16){j=0;return j|0}b=(c[2383582]|0)+1|0;f=c[14168912+(b*252|0)>>2]|0;if((f|0)>15){j=0;return j|0}do{if((f|0)==14){k=c[14168896+(b*252|0)>>2]|0;if((k|0)==0){break}a[14168930+(b*252|0)|0]=gj[k&4095](0)|0}else if((f|0)==15){k=c[14168900+(b*252|0)>>2]|0;if((k|0)==0){break}a[14168931+(b*252|0)|0]=gj[k&4095](0)|0}}while(0);j=a[14168916+(b*252|0)+f|0]|0;return j|0};case 0:case 1:{f=c[3541518]|0;if((e&1|0)==0){b=f+296|0;g=+h[b>>3];do{if(g!=0.0){i=+h[6675];if(g-(i+ +gC[c[2429842]&255]())<=0.0){h[b>>3]=0.0;break}j=a[f+307|0]|-128;return j|0}}while(0);j=a[f+307|0]|0;return j|0}if((d[f+304|0]|0)>=16){j=0;return j|0}f=c[2383582]|0;b=c[14168912+(f*252|0)>>2]|0;if((b|0)>15){j=0;return j|0}do{if((b|0)==15){k=c[14168900+(f*252|0)>>2]|0;if((k|0)==0){break}a[14168931+(f*252|0)|0]=gj[k&4095](0)|0}else if((b|0)==14){k=c[14168896+(f*252|0)>>2]|0;if((k|0)==0){break}a[14168930+(f*252|0)|0]=gj[k&4095](0)|0}}while(0);j=a[14168916+(f*252|0)+b|0]|0;return j|0};case 128:case 129:case 130:case 131:{j=a[(c[2439256]|0)+(e&3)|0]|0;return j|0};default:{j=0;return j|0}}return 0}function eFr(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>25){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3159492+(b*112|0)>>2];c[a+104>>2]=c[3159496+(b*112|0)>>2];c[a+108>>2]=c[3159500+(b*112|0)>>2];d=0;return d|0}function eFs(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<26&(d|0)==0)){e=1;return e|0}c[a>>2]=3159392+(b*112|0);e=0;return e|0}function eFt(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>24){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1317064+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eFu(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>45){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4280968+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eFv(){return eFF(1)|0}function eFw(){var b=0,d=0,e=0,f=0;b=c[3541518]|0;if((b|0)!=0){gGr(b|0);c[3541518]=0}if((c[2385508]|0)>0){c[2113008]=0;c[2076598]=0;c[2383582]=0}c[2438228]=0;c[2433526]=0;c[2406676]=0;c[3528472]=0;b=c[2406680]|0;if((b|0)!=0){gGr(b);c[2406680]=0}c[2385508]=0;c[2432978]=0;a[64240]=0;c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}fwZ();b=c[2414898]|0;d=0;while(1){if((d|0)>=1024){e=16714;break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==(b|0)){break}else{d=d+1|0}}if((e|0)==16714){c[2414898]=0;return 0}gGr(b);c[f>>2]=0;c[2414898]=0;return 0}function eFx(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0;if((a[9623768]|0)!=0){d=c[2414600]|0;gGz(d|0,0,(c[2411554]|0)-d|0);d=c[2439330]|0;if((d|0)!=0){e=d;gGC(9706056,e|0,76)|0}c[2433530]=c[2438118];e=c[3528484]|0;c[2076596]=e;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;gGz(9706056,0,76);c[3527214]=0;g=c[3529230]|0;i=128;j=128;while(1){c[d+76+(j<<2)>>2]=g+((j<<8)+32768);k=i+1&65535;if((k&65535)>191){break}else{i=k;j=k&65535}}j=(c[3527214]<<14)+32768|0;i=128;k=128;while(1){c[d+76+(k<<2)>>2]=g+(j+(k<<8));l=i+1&65535;if((l&65535)>191){break}else{i=l;k=l&65535}}k=d;gGC(k|0,9706056,76)|0;c[2438118]=c[2433530];c[3528484]=e;c[2417276]=f;c[1836236]=-1;f=c[2439331]|0;e=(f|0)==0;if(!e){k=f;gGC(9706056,k|0,76)|0}k=c[2438119]|0;c[2433530]=k;d=c[3528485]|0;c[2076596]=d;i=c[2417277]|0;c[3541536]=i;c[1836236]=1;gGz(9706056,0,76);if(!e){e=f;gGC(e|0,9706056,76)|0}c[2438119]=k;c[3528485]=d;c[2417277]=i;c[1836236]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){i=0;do{lN(i);mB(i);i=i+1|0;}while((i|0)<(c[2385508]|0))}a[9542864]=0;a[9542872]=0;a[14107792]=0;a[14107800]=0;a[9635944]=0;a[14114384]=0}i=c[2385548]|0;if((i|0)>0){gGz(9752472,0,((i|0)>1?i<<2:4)|0)}c[2433530]=0;gGz(9550288,-1|0,3);i=0;d=-1;k=b[4775145]|0;e=b[4775146]|0;do{d=((a[9632824+i|0]&1)<<i^d&65535)&65535;k=((a[9630712+i|0]&1)<<i^k&65535)&65535;e=((a[9629312+i|0]&1)<<i^e&65535)&65535;i=i+1|0;}while((i|0)<8);b[4775145]=k;b[4775146]=e;b[4775144]=a[9634834]&128|d&127;d=0;do{e=c[2439330]|0;if((e|0)!=0){k=e;gGC(9706056,k|0,76)|0}b[4853030]=c[2426515]&65535;k=c[2438118]|0;c[2433530]=k;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;if((a[e+4188|0]|0)==0){e=gfc(13333)|0;m=(c[2433530]|0)+e|0}else{m=k+13333|0}c[2433530]=m;if((d|0)==9){a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0}k=c[1836236]|0;e=c[9757320+(k<<2)>>2]|0;if((e|0)!=0){i=e;gGC(i|0,9706056,76)|0}c[9752472+(k<<2)>>2]=c[2433530];c[14113936+(k<<2)>>2]=c[2076596];c[9669104+(k<<2)>>2]=c[3541536];c[1836236]=-1;k=c[2439331]|0;if((k|0)!=0){i=k;gGC(9706056,i|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;Sb(d*6666|0);i=c[1836236]|0;k=c[9757320+(i<<2)>>2]|0;if((k|0)!=0){e=k;gGC(e|0,9706056,76)|0}c[9752472+(i<<2)>>2]=c[2433530];c[14113936+(i<<2)>>2]=c[2076596];c[9669104+(i<<2)>>2]=c[3541536];c[1836236]=-1;d=d+1|0;}while((d|0)<10);d=c[2439331]|0;if((d|0)!=0){m=d;gGC(9706056,m|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;m=c[2438228]|0;d=gGS(-747372544,31788,m,(m|0)<0|0?-1:0)|0;m=d;Sb(66666);d=c[2443830]|0;if((d|0)<1073676288){c[2443830]=d-m}d=c[2443831]|0;if((d|0)<1073676288){c[2443831]=d-m}d=(c[3528512]|0)-m|0;c[3528512]=(d|0)<0?0:d;d=c[2112964]|0;if((d|0)!=0){gg[c[3542122]&4095](d,a[9688]|0?534:0)}d=c[1836236]|0;m=c[9757320+(d<<2)>>2]|0;if((m|0)!=0){i=m;gGC(i|0,9706056,76)|0}c[9752472+(d<<2)>>2]=c[2433530];c[14113936+(d<<2)>>2]=c[2076596];c[9669104+(d<<2)>>2]=c[3541536];c[1836236]=-1;if((c[2112968]|0)==0){return 0}eFy()|0;return 0}function eFy(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=c[2387132]|0;f=c[3529932]|0;g=0;do{h=a[e+g|0]|0;i=(h&255)>>>4;j=a[e+(g+256)|0]|0;c[f+(g<<2)>>2]=((j&8|j<<4)&255)>>>3|((h&8|h<<4)&255)<<8&63488|((i<<4|i)&255)<<3&2016;g=g+1|0;}while((g|0)<256);g=c[2113070]|0;e=ag(g,c[2113068]|0)|0;i=(e|0)>0;if(i){h=c[2112926]|0;j=0;do{b[h+(j<<1)>>1]=63;j=j+1|0;}while((j|0)<(e|0))}if((a[14114384]|0)>-1){j=c[2112926]|0;h=c[2387958]|0;k=c[3530404]|0;l=d[14107792]|0;m=d[9542864]<<8;n=0;do{o=(n>>5<<3)-8|0;p=(n<<3&248)-l|0;q=(p|0)<-7?p+256|0:p;p=d[h+n|0]|m;Sr(j,p,q,o,0,4,15,0,k);if((q|0)<0){Sr(j,p,q+256|0,o,0,4,15,0,k)}n=n+1|0;}while((n|0)<1024)}n=c[2112926]|0;eFJ(n,128);if((a[14114384]&32)==0){k=c[2386324]|0;j=c[3530780]|0;m=d[9635944]<<8;h=0;do{Sr(n,d[k+h|0]|m,h<<3&248,(h>>5<<3)-8|0,3,4,0,0,j);h=h+1|0;}while((h|0)<1024)}if(i){i=c[2385348]|0;h=0;do{b[i+(h<<1)>>1]=63;h=h+1|0;}while((h|0)<(e|0))}if((a[14114384]&64)==0){e=c[2385348]|0;h=c[2387960]|0;i=c[3530318]|0;j=d[14107800]|0;m=d[9542872]<<8;k=0;do{l=(k>>5<<3)-8|0;o=(k<<3&248)-j|0;q=(o|0)<-7?o+256|0:o;o=d[h+k|0]|m;Sr(e,o,q,l,0,4,15,0,i);if((q|0)<0){Sr(e,o,q+256|0,l,0,4,15,0,i)}k=k+1|0;}while((k|0)<1024)}k=c[2385348]|0;eFJ(k,64);if((a[14114384]&32)==0){i=c[2386324]|0;e=c[3530780]|0;m=d[9635944]<<8;h=0;do{Sr(k,d[i+h|0]|m,h<<3&248,(h>>5<<3)-8|0,3,4,0,0,e);h=h+1|0;}while((h|0)<1024)}if((g|0)<=0){R8(f);return 0}h=k+256|0;k=n+256|0;n=0;while(1){e=k;m=h;gGC(e|0,m|0,256)|0;m=n+1|0;if((m|0)<(g|0)){h=h+512|0;k=k+512|0;n=m}else{break}}R8(f);return 0}function eFz(a,d){a=a|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;e=i;i=i+128|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;l=e+80|0;m=e+96|0;n=e+112|0;if((d|0)!=0){c[d>>2]=169730}if((a&32|0)!=0){gGz(n|0,0,12);o=c[2414600]|0;c[n>>2]=o;c[n+4>>2]=(c[2411554]|0)-o;c[n+12>>2]=162152;o=c[2076592]|0;gj[o&4095](n)|0}if((a&64|0)==0){i=e;return 0}fw$(a);Vx(a,d);gGz(m|0,0,12);c[m>>2]=9542864;c[m+4>>2]=1;c[m+12>>2]=87712;gj[c[2076592]&4095](m)|0;gGz(l|0,0,12);c[l>>2]=9542872;c[l+4>>2]=1;c[l+12>>2]=85760;gj[c[2076592]&4095](l)|0;gGz(k|0,0,12);c[k>>2]=14107792;c[k+4>>2]=1;c[k+12>>2]=83880;gj[c[2076592]&4095](k)|0;gGz(j|0,0,12);c[j>>2]=14107800;c[j+4>>2]=1;c[j+12>>2]=82432;gj[c[2076592]&4095](j)|0;gGz(h|0,0,12);c[h>>2]=9635944;c[h+4>>2]=1;c[h+12>>2]=80712;gj[c[2076592]&4095](h)|0;gGz(g|0,0,12);c[g>>2]=14114384;c[g+4>>2]=1;c[g+12>>2]=78560;gj[c[2076592]&4095](g)|0;gGz(f|0,0,12);c[f>>2]=14108856;c[f+4>>2]=4;c[f+12>>2]=76560;gj[c[2076592]&4095](f)|0;if((a&2|0)==0){i=e;return 0}a=c[2439330]|0;if((a|0)!=0){f=a;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];f=c[3528484]|0;c[2076596]=f;g=c[2417276]|0;c[3541536]=g;c[1836236]=0;h=c[3527214]&15;c[3527214]=h;j=c[3529230]|0;k=(h<<14)+32768|0;h=128;l=128;while(1){c[a+76+(l<<2)>>2]=j+(k+(l<<8));m=h+1&65535;if((m&65535)>191){break}else{h=m;l=m&65535}}l=(c[3527214]<<14)+32768|0;h=128;k=128;while(1){c[a+76+(k<<2)>>2]=j+(l+(k<<8));m=h+1&65535;if((m&65535)>191){break}else{h=m;k=m&65535}}k=a;gGC(k|0,9706056,76)|0;c[2438118]=c[2433530];c[3528484]=f;c[2417276]=g;c[1836236]=-1;i=e;return 0}function eFA(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2246348+(b*112|0)>>2];c[a+104>>2]=c[2246352+(b*112|0)>>2];c[a+108>>2]=c[2246356+(b*112|0)>>2];d=0;return d|0}function eFB(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=2246248+(b*112|0);e=0;return e|0}function eFC(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1188776+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eFD(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>58){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3396240+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eFE(){return eFF(2)|0}function eFF(e){e=e|0;var f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0;f=i;i=i+3840|0;g=f|0;j=f+112|0;k=f+120|0;l=f+232|0;m=f+240|0;n=f+352|0;o=f+360|0;p=f+472|0;q=f+480|0;r=f+592|0;s=f+600|0;t=f+712|0;u=f+720|0;v=f+832|0;w=f+840|0;x=f+952|0;y=f+960|0;z=f+1072|0;A=f+1080|0;B=f+1192|0;C=f+1200|0;D=f+1312|0;E=f+1320|0;F=f+1432|0;G=f+1440|0;H=f+1552|0;I=f+1560|0;J=f+1672|0;K=f+1680|0;L=f+1792|0;M=f+1800|0;N=f+1912|0;O=f+1920|0;P=f+2032|0;Q=f+2040|0;R=f+2152|0;S=f+2160|0;T=f+2272|0;U=f+2280|0;V=f+2392|0;W=f+2400|0;X=f+2512|0;Y=f+2520|0;Z=f+2632|0;_=f+2640|0;$=f+2752|0;aa=f+2760|0;ab=f+2872|0;ac=f+2880|0;ad=f+2992|0;ae=f+3e3|0;af=f+3112|0;ah=f+3120|0;ai=f+3232|0;aj=f+3240|0;ak=f+3352|0;al=f+3360|0;am=f+3472|0;an=f+3480|0;ao=f+3592|0;ap=f+3600|0;aq=f+3712|0;ar=f+3720|0;as=f+3832|0;c[2414898]=0;c[3529230]=0;c[2443348]=262144;c[3529186]=311296;c[3530780]=376832;c[3530544]=442368;c[3530404]=573440;c[3530318]=1097728;c[3529932]=1622016;c[2385348]=1623040;c[2414600]=1745920;c[3529318]=1745920;c[2387958]=1754112;c[2387960]=1755136;c[2386324]=1756160;c[2386410]=1757184;c[2387132]=1757440;c[3529280]=1758464;c[2438900]=1760512;c[2439256]=1760516;c[2411554]=1760520;at=0;while(1){if((at|0)>=1024){break}au=9638528+(at<<2)|0;if((c[au>>2]|0)==0){av=16840;break}else{at=at+1|0}}do{if((av|0)==16840){at=gGq(1760520)|0;c[au>>2]=at;if((at|0)==0){break}c[2414898]=at;gGz(at|0,0,1760520);c[3529230]=at;c[2443348]=at+262144;c[3529186]=at+311296;c[3530780]=at+376832;c[3530544]=at+442368;c[3530404]=at+573440;c[3530318]=at+1097728;c[3529932]=at+1622016;c[2385348]=at+1623040;aw=at+1745920|0;c[2414600]=aw;c[3529318]=aw;c[2387958]=at+1754112;c[2387960]=at+1755136;c[2386324]=at+1756160;c[2386410]=at+1757184;c[2387132]=at+1757440;c[3529280]=at+1758464;c[2438900]=at+1760512;c[2439256]=at+1760516;aw=at+1760520|0;c[2411554]=aw;c[2414094]=aw;aw=(e|0)==1;do{if((c[3542200]|0)==0){ax=1}else{ay=ar+108|0;c[ay>>2]=0;az=ar+100|0;c[az>>2]=0;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aA&16383](ar,0)|0;if((c[ay>>2]|0)==0){ax=0;break}ay=c[az>>2]|0;c[as>>2]=9534384;az=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[az&16383](as,0,0)|0;if((ay|0)<1){ax=1;break}ax=(gzL(at,0,0)|0)!=0}}while(0);do{if(aw){if(ax){aB=1;i=f;return aB|0}at=c[2443348]|0;ay=c[3529230]|0;gGC(at|0,ay|0,32768)|0;at=ay+65536|0;if((c[3542200]|0)==0){aB=1;i=f;return aB|0}ay=ap+108|0;c[ay>>2]=0;az=ap+100|0;c[az>>2]=0;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aA&16383](ap,1)|0;do{if((c[ay>>2]|0)!=0){aA=c[az>>2]|0;c[aq>>2]=9534384;aC=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aC&16383](aq,1,0)|0;if((aA|0)<1){aB=1;i=f;return aB|0}if((gzL(at,0,1)|0)==0){break}else{aB=1}i=f;return aB|0}}while(0);at=(c[3529230]|0)+98304|0;if((c[3542200]|0)==0){aB=1;i=f;return aB|0}az=an+108|0;c[az>>2]=0;ay=an+100|0;c[ay>>2]=0;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aA&16383](an,2)|0;do{if((c[az>>2]|0)!=0){aA=c[ay>>2]|0;c[ao>>2]=9534384;aC=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aC&16383](ao,2,0)|0;if((aA|0)<1){aB=1;i=f;return aB|0}if((gzL(at,0,2)|0)==0){break}else{aB=1}i=f;return aB|0}}while(0);at=(c[3529230]|0)+131072|0;if((c[3542200]|0)==0){aB=1;i=f;return aB|0}ay=al+108|0;c[ay>>2]=0;az=al+100|0;c[az>>2]=0;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aA&16383](al,3)|0;do{if((c[ay>>2]|0)!=0){aA=c[az>>2]|0;c[am>>2]=9534384;aC=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aC&16383](am,3,0)|0;if((aA|0)<1){aB=1;i=f;return aB|0}if((gzL(at,0,3)|0)==0){break}else{aB=1}i=f;return aB|0}}while(0);at=(c[3529230]|0)+163840|0;if((c[3542200]|0)==0){aB=1;i=f;return aB|0}az=aj+108|0;c[az>>2]=0;ay=aj+100|0;c[ay>>2]=0;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aA&16383](aj,4)|0;do{if((c[az>>2]|0)!=0){aA=c[ay>>2]|0;c[ak>>2]=9534384;aC=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aC&16383](ak,4,0)|0;if((aA|0)<1){aB=1;i=f;return aB|0}if((gzL(at,0,4)|0)==0){break}else{aB=1}i=f;return aB|0}}while(0);at=c[3529186]|0;if((c[3542200]|0)==0){aB=1;i=f;return aB|0}ay=ah+108|0;c[ay>>2]=0;az=ah+100|0;c[az>>2]=0;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aA&16383](ah,5)|0;do{if((c[ay>>2]|0)!=0){aA=c[az>>2]|0;c[ai>>2]=9534384;aC=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aC&16383](ai,5,0)|0;if((aA|0)<1){aB=1;i=f;return aB|0}if((gzL(at,0,5)|0)==0){break}else{aB=1}i=f;return aB|0}}while(0);at=c[3530780]|0;if((c[3542200]|0)==0){aB=1;i=f;return aB|0}az=ae+108|0;c[az>>2]=0;ay=ae+100|0;c[ay>>2]=0;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aA&16383](ae,6)|0;do{if((c[az>>2]|0)!=0){aA=c[ay>>2]|0;c[af>>2]=9534384;aC=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aC&16383](af,6,0)|0;if((aA|0)<1){aB=1;i=f;return aB|0}if((gzL(at,0,6)|0)==0){break}else{aB=1}i=f;return aB|0}}while(0);at=c[3530544]|0;if((c[3542200]|0)==0){aB=1;i=f;return aB|0}ay=ac+108|0;c[ay>>2]=0;az=ac+100|0;c[az>>2]=0;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aA&16383](ac,7)|0;do{if((c[ay>>2]|0)!=0){aA=c[az>>2]|0;c[ad>>2]=9534384;aC=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aC&16383](ad,7,0)|0;if((aA|0)<1){aB=1;i=f;return aB|0}if((gzL(at,0,7)|0)==0){break}else{aB=1}i=f;return aB|0}}while(0);at=(c[3530544]|0)+32768|0;if((c[3542200]|0)==0){aB=1;i=f;return aB|0}az=aa+108|0;c[az>>2]=0;ay=aa+100|0;c[ay>>2]=0;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aA&16383](aa,8)|0;do{if((c[az>>2]|0)!=0){aA=c[ay>>2]|0;c[ab>>2]=9534384;aC=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aC&16383](ab,8,0)|0;if((aA|0)<1){aB=1;i=f;return aB|0}if((gzL(at,0,8)|0)==0){break}else{aB=1}i=f;return aB|0}}while(0);at=c[3530404]|0;if((c[3542200]|0)==0){aB=1;i=f;return aB|0}ay=_+108|0;c[ay>>2]=0;az=_+100|0;c[az>>2]=0;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aA&16383](_,9)|0;do{if((c[ay>>2]|0)!=0){aA=c[az>>2]|0;c[$>>2]=9534384;aC=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aC&16383]($,9,0)|0;if((aA|0)<1){aB=1;i=f;return aB|0}if((gzL(at,0,9)|0)==0){break}else{aB=1}i=f;return aB|0}}while(0);at=(c[3530404]|0)+32768|0;if((c[3542200]|0)==0){aB=1;i=f;return aB|0}az=Y+108|0;c[az>>2]=0;ay=Y+100|0;c[ay>>2]=0;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aA&16383](Y,10)|0;do{if((c[az>>2]|0)!=0){aA=c[ay>>2]|0;c[Z>>2]=9534384;aC=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aC&16383](Z,10,0)|0;if((aA|0)<1){aB=1;i=f;return aB|0}if((gzL(at,0,10)|0)==0){break}else{aB=1}i=f;return aB|0}}while(0);at=(c[3530404]|0)+65536|0;if((c[3542200]|0)==0){aB=1;i=f;return aB|0}ay=W+108|0;c[ay>>2]=0;az=W+100|0;c[az>>2]=0;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aA&16383](W,11)|0;do{if((c[ay>>2]|0)!=0){aA=c[az>>2]|0;c[X>>2]=9534384;aC=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aC&16383](X,11,0)|0;if((aA|0)<1){aB=1;i=f;return aB|0}if((gzL(at,0,11)|0)==0){break}else{aB=1}i=f;return aB|0}}while(0);at=(c[3530404]|0)+98304|0;if((c[3542200]|0)==0){aB=1;i=f;return aB|0}az=U+108|0;c[az>>2]=0;ay=U+100|0;c[ay>>2]=0;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aA&16383](U,12)|0;do{if((c[az>>2]|0)!=0){aA=c[ay>>2]|0;c[V>>2]=9534384;aC=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aC&16383](V,12,0)|0;if((aA|0)<1){aB=1;i=f;return aB|0}if((gzL(at,0,12)|0)==0){break}else{aB=1}i=f;return aB|0}}while(0);at=(c[3530404]|0)+131072|0;if((c[3542200]|0)==0){aB=1;i=f;return aB|0}ay=S+108|0;c[ay>>2]=0;az=S+100|0;c[az>>2]=0;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aA&16383](S,13)|0;do{if((c[ay>>2]|0)!=0){aA=c[az>>2]|0;c[T>>2]=9534384;aC=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aC&16383](T,13,0)|0;if((aA|0)<1){aB=1;i=f;return aB|0}if((gzL(at,0,13)|0)==0){break}else{aB=1}i=f;return aB|0}}while(0);at=(c[3530404]|0)+163840|0;if((c[3542200]|0)==0){aB=1;i=f;return aB|0}az=Q+108|0;c[az>>2]=0;ay=Q+100|0;c[ay>>2]=0;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aA&16383](Q,14)|0;do{if((c[az>>2]|0)!=0){aA=c[ay>>2]|0;c[R>>2]=9534384;aC=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aC&16383](R,14,0)|0;if((aA|0)<1){aB=1;i=f;return aB|0}if((gzL(at,0,14)|0)==0){break}else{aB=1}i=f;return aB|0}}while(0);at=(c[3530404]|0)+196608|0;if((c[3542200]|0)==0){aB=1;i=f;return aB|0}ay=O+108|0;c[ay>>2]=0;az=O+100|0;c[az>>2]=0;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aA&16383](O,15)|0;do{if((c[ay>>2]|0)!=0){aA=c[az>>2]|0;c[P>>2]=9534384;aC=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aC&16383](P,15,0)|0;if((aA|0)<1){aB=1;i=f;return aB|0}if((gzL(at,0,15)|0)==0){break}else{aB=1}i=f;return aB|0}}while(0);at=(c[3530404]|0)+229376|0;if((c[3542200]|0)==0){aB=1;i=f;return aB|0}az=M+108|0;c[az>>2]=0;ay=M+100|0;c[ay>>2]=0;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aA&16383](M,16)|0;do{if((c[az>>2]|0)!=0){aA=c[ay>>2]|0;c[N>>2]=9534384;aC=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aC&16383](N,16,0)|0;if((aA|0)<1){aB=1;i=f;return aB|0}if((gzL(at,0,16)|0)==0){break}else{aB=1}i=f;return aB|0}}while(0);at=c[3530318]|0;ay=c[3530404]|0;gGC(at|0,ay|0,262144)|0;aD=0}else{if(ax){aB=1;i=f;return aB|0}ay=c[3529230]|0;eKg(ay,c[2443348]|0,617656,617320,617585,617060);at=ay+65536|0;if((c[3542200]|0)==0){aB=1;i=f;return aB|0}ay=K+108|0;c[ay>>2]=0;az=K+100|0;c[az>>2]=0;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aA&16383](K,1)|0;do{if((c[ay>>2]|0)!=0){aA=c[az>>2]|0;c[L>>2]=9534384;aC=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aC&16383](L,1,0)|0;if((aA|0)<1){aB=1;i=f;return aB|0}if((gzL(at,0,1)|0)==0){break}else{aB=1}i=f;return aB|0}}while(0);at=(c[3529230]|0)+98304|0;if((c[3542200]|0)==0){aB=1;i=f;return aB|0}az=I+108|0;c[az>>2]=0;ay=I+100|0;c[ay>>2]=0;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aA&16383](I,2)|0;do{if((c[az>>2]|0)!=0){aA=c[ay>>2]|0;c[J>>2]=9534384;aC=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aC&16383](J,2,0)|0;if((aA|0)<1){aB=1;i=f;return aB|0}if((gzL(at,0,2)|0)==0){break}else{aB=1}i=f;return aB|0}}while(0);at=(c[3529230]|0)+131072|0;if((c[3542200]|0)==0){aB=1;i=f;return aB|0}ay=G+108|0;c[ay>>2]=0;az=G+100|0;c[az>>2]=0;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aA&16383](G,3)|0;do{if((c[ay>>2]|0)!=0){aA=c[az>>2]|0;c[H>>2]=9534384;aC=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aC&16383](H,3,0)|0;if((aA|0)<1){aB=1;i=f;return aB|0}if((gzL(at,0,3)|0)==0){break}else{aB=1}i=f;return aB|0}}while(0);at=(c[3529230]|0)+163840|0;if((c[3542200]|0)==0){aB=1;i=f;return aB|0}az=E+108|0;c[az>>2]=0;ay=E+100|0;c[ay>>2]=0;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aA&16383](E,4)|0;do{if((c[az>>2]|0)!=0){aA=c[ay>>2]|0;c[F>>2]=9534384;aC=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aC&16383](F,4,0)|0;if((aA|0)<1){aB=1;i=f;return aB|0}if((gzL(at,0,4)|0)==0){break}else{aB=1}i=f;return aB|0}}while(0);at=(c[3529230]|0)+196608|0;if((c[3542200]|0)==0){aB=1;i=f;return aB|0}ay=C+108|0;c[ay>>2]=0;az=C+100|0;c[az>>2]=0;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aA&16383](C,5)|0;do{if((c[ay>>2]|0)!=0){aA=c[az>>2]|0;c[D>>2]=9534384;aC=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aC&16383](D,5,0)|0;if((aA|0)<1){aB=1;i=f;return aB|0}if((gzL(at,0,5)|0)==0){break}else{aB=1}i=f;return aB|0}}while(0);at=c[3529186]|0;if((c[3542200]|0)==0){aB=1;i=f;return aB|0}az=A+108|0;c[az>>2]=0;ay=A+100|0;c[ay>>2]=0;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aA&16383](A,6)|0;do{if((c[az>>2]|0)!=0){aA=c[ay>>2]|0;c[B>>2]=9534384;aC=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aC&16383](B,6,0)|0;if((aA|0)<1){aB=1;i=f;return aB|0}if((gzL(at,0,6)|0)==0){break}else{aB=1}i=f;return aB|0}}while(0);at=c[3530780]|0;if((c[3542200]|0)==0){aB=1;i=f;return aB|0}ay=y+108|0;c[ay>>2]=0;az=y+100|0;c[az>>2]=0;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aA&16383](y,7)|0;do{if((c[ay>>2]|0)!=0){aA=c[az>>2]|0;c[z>>2]=9534384;aC=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aC&16383](z,7,0)|0;if((aA|0)<1){aB=1;i=f;return aB|0}if((gzL(at,0,7)|0)==0){break}else{aB=1}i=f;return aB|0}}while(0);at=c[3530544]|0;if((c[3542200]|0)==0){aB=1;i=f;return aB|0}az=w+108|0;c[az>>2]=0;ay=w+100|0;c[ay>>2]=0;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aA&16383](w,8)|0;do{if((c[az>>2]|0)!=0){aA=c[ay>>2]|0;c[x>>2]=9534384;aC=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aC&16383](x,8,0)|0;if((aA|0)<1){aB=1;i=f;return aB|0}if((gzL(at,0,8)|0)==0){break}else{aB=1}i=f;return aB|0}}while(0);at=(c[3530544]|0)+32768|0;if((c[3542200]|0)==0){aB=1;i=f;return aB|0}ay=u+108|0;c[ay>>2]=0;az=u+100|0;c[az>>2]=0;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aA&16383](u,9)|0;do{if((c[ay>>2]|0)!=0){aA=c[az>>2]|0;c[v>>2]=9534384;aC=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aC&16383](v,9,0)|0;if((aA|0)<1){aB=1;i=f;return aB|0}if((gzL(at,0,9)|0)==0){break}else{aB=1}i=f;return aB|0}}while(0);at=c[3530404]|0;if((c[3542200]|0)==0){aB=1;i=f;return aB|0}az=s+108|0;c[az>>2]=0;ay=s+100|0;c[ay>>2]=0;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aA&16383](s,10)|0;do{if((c[az>>2]|0)!=0){aA=c[ay>>2]|0;c[t>>2]=9534384;aC=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aC&16383](t,10,0)|0;if((aA|0)<1){aB=1;i=f;return aB|0}if((gzL(at,0,10)|0)==0){break}else{aB=1}i=f;return aB|0}}while(0);at=(c[3530404]|0)+32768|0;if((c[3542200]|0)==0){aB=1;i=f;return aB|0}ay=q+108|0;c[ay>>2]=0;az=q+100|0;c[az>>2]=0;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aA&16383](q,11)|0;do{if((c[ay>>2]|0)!=0){aA=c[az>>2]|0;c[r>>2]=9534384;aC=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aC&16383](r,11,0)|0;if((aA|0)<1){aB=1;i=f;return aB|0}if((gzL(at,0,11)|0)==0){break}else{aB=1}i=f;return aB|0}}while(0);at=(c[3530404]|0)+65536|0;if((c[3542200]|0)==0){aB=1;i=f;return aB|0}az=o+108|0;c[az>>2]=0;ay=o+100|0;c[ay>>2]=0;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aA&16383](o,12)|0;do{if((c[az>>2]|0)!=0){aA=c[ay>>2]|0;c[p>>2]=9534384;aC=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aC&16383](p,12,0)|0;if((aA|0)<1){aB=1;i=f;return aB|0}if((gzL(at,0,12)|0)==0){break}else{aB=1}i=f;return aB|0}}while(0);at=c[3530318]|0;if((c[3542200]|0)==0){aB=1;i=f;return aB|0}ay=m+108|0;c[ay>>2]=0;az=m+100|0;c[az>>2]=0;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aA&16383](m,13)|0;do{if((c[ay>>2]|0)!=0){aA=c[az>>2]|0;c[n>>2]=9534384;aC=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aC&16383](n,13,0)|0;if((aA|0)<1){aB=1;i=f;return aB|0}if((gzL(at,0,13)|0)==0){break}else{aB=1}i=f;return aB|0}}while(0);at=(c[3530318]|0)+32768|0;if((c[3542200]|0)==0){aB=1;i=f;return aB|0}az=k+108|0;c[az>>2]=0;ay=k+100|0;c[ay>>2]=0;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aA&16383](k,14)|0;do{if((c[az>>2]|0)!=0){aA=c[ay>>2]|0;c[l>>2]=9534384;aC=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aC&16383](l,14,0)|0;if((aA|0)<1){aB=1;i=f;return aB|0}if((gzL(at,0,14)|0)==0){break}else{aB=1}i=f;return aB|0}}while(0);at=(c[3530318]|0)+65536|0;if((c[3542200]|0)==0){aB=1;i=f;return aB|0}ay=g+108|0;c[ay>>2]=0;az=g+100|0;c[az>>2]=0;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aA&16383](g,15)|0;if((c[ay>>2]|0)==0){aD=0;break}ay=c[az>>2]|0;c[j>>2]=9534384;az=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[az&16383](j,15,0)|0;if((ay|0)<1){aB=1;i=f;return aB|0}if((gzL(at,0,15)|0)==0){aD=0;break}else{aB=1}i=f;return aB|0}}while(0);while(1){if((aD|0)>=1024){break}aE=9638528+(aD<<2)|0;if((c[aE>>2]|0)==0){av=16976;break}else{aD=aD+1|0}}do{if((av|0)==16976){aw=gGq(65536)|0;c[aE>>2]=aw;if((aw|0)==0){break}gGz(aw|0,0,65536);at=c[3530544]|0;gGC(aw|0,at|0,65536)|0;ay=0;while(1){az=ay<<8;gGz(at+az|0,0,256);aA=ay<<9;aC=0;do{aF=1<<3-aC;aG=(c[613104+(aC<<2)>>2]|0)+aA|0;aH=0;do{aI=aG+(c[611840+(aH<<2)>>2]|0)|0;aJ=(aH<<4)+az|0;aK=0;do{aL=aI+(c[612352+(aK<<2)>>2]|0)|0;if(((d[aw+((aL|0)/8|0)|0]|0)&128>>>((aL&7)>>>0)|0)!=0){aL=at+(aJ+aK)|0;a[aL]=(d[aL]|0|aF)&255}aK=aK+1|0;}while((aK|0)<16);aH=aH+1|0;}while((aH|0)<16);aC=aC+1|0;}while((aC|0)<4);aC=ay+1|0;if((aC|0)<512){ay=aC}else{aM=0;break}}while(1){if((aM|0)>=1024){break}aN=9638528+(aM<<2)|0;if((c[aN>>2]|0)==(aw|0)){av=16989;break}else{aM=aM+1|0}}if((av|0)==16989){gGr(aw);c[aN>>2]=0}ay=c[3530780]|0;at=32768;do{at=at-1|0;aC=ay+at|0;az=at<<1;a[ay+(az|1)|0]=a[aC]&15;a[ay+az|0]=(d[aC]|0)>>>4;}while((at|0)>0);at=c[3530404]|0;ay=262144;do{ay=ay-1|0;aw=at+ay|0;aC=ay<<1;a[at+(aC|1)|0]=a[aw]&15;a[at+aC|0]=(d[aw]|0)>>>4;}while((ay|0)>0);ay=c[3530318]|0;at=262144;do{at=at-1|0;aw=ay+at|0;aC=at<<1;a[ay+(aC|1)|0]=a[aw]&15;a[ay+aC|0]=(d[aw]|0)>>>4;}while((at|0)>0)}}while(0);fwR(0);at=c[2439330]|0;ay=(at|0)==0;if(!ay){aw=at;gGC(9706056,aw|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];aw=c[3528484]|0;c[2076596]=aw;aC=c[2417276]|0;c[3541536]=aC;c[1836236]=0;az=c[3529230]|0;aA=0;aH=0;while(1){c[at+76+(aH<<2)>>2]=az+(aH<<8);aF=aA+1&65535;if((aF&65535)>127){break}else{aA=aF;aH=aF&65535}}aH=c[2443348]|0;aA=0;aF=0;while(1){aG=aF<<8;c[at+76+(aF+512<<2)>>2]=aH+aG;c[at+76+(aF+768<<2)>>2]=az+aG;aG=aA+1&65535;if((aG&65535)>127){break}else{aA=aG;aF=aG&65535}}aF=c[3529318]|0;aA=192;az=192;while(1){c[at+76+(az<<2)>>2]=aF+((az<<8)-49152);aH=aA+1&65535;if((aH&65535)>223){aO=192;aP=192;break}else{aA=aH;az=aH&65535}}while(1){c[at+76+(aP+256<<2)>>2]=aF+((aP<<8)-49152);az=aO+1&65535;if((az&65535)>223){aQ=192;aR=192;break}else{aO=az;aP=az&65535}}while(1){az=aF+((aR<<8)-49152)|0;c[at+76+(aR+512<<2)>>2]=az;c[at+76+(aR+768<<2)>>2]=az;az=aQ+1&65535;if((az&65535)>223){break}else{aQ=az;aR=az&65535}}aF=c[2387958]|0;c[at+972>>2]=aF;az=aF+256|0;c[at+976>>2]=az;aA=aF+512|0;c[at+980>>2]=aA;aH=aF+768|0;c[at+984>>2]=aH;c[at+1996>>2]=aF;c[at+2e3>>2]=az;c[at+2004>>2]=aA;c[at+2008>>2]=aH;c[at+3020>>2]=aF;c[at+4044>>2]=aF;c[at+3024>>2]=az;c[at+4048>>2]=az;c[at+3028>>2]=aA;c[at+4052>>2]=aA;c[at+3032>>2]=aH;c[at+4056>>2]=aH;aH=c[2387960]|0;c[at+988>>2]=aH;aA=aH+256|0;c[at+992>>2]=aA;az=aH+512|0;c[at+996>>2]=az;aF=aH+768|0;c[at+1e3>>2]=aF;c[at+2012>>2]=aH;c[at+2016>>2]=aA;c[at+2020>>2]=az;c[at+2024>>2]=aF;c[at+3036>>2]=aH;c[at+4060>>2]=aH;c[at+3040>>2]=aA;c[at+4064>>2]=aA;c[at+3044>>2]=az;c[at+4068>>2]=az;c[at+3048>>2]=aF;c[at+4072>>2]=aF;aF=c[2386324]|0;c[at+1004>>2]=aF;az=aF+256|0;c[at+1008>>2]=az;aA=aF+512|0;c[at+1012>>2]=aA;aH=aF+768|0;c[at+1016>>2]=aH;c[at+2028>>2]=aF;c[at+2032>>2]=az;c[at+2036>>2]=aA;c[at+2040>>2]=aH;c[at+3052>>2]=aF;c[at+4076>>2]=aF;c[at+3056>>2]=az;c[at+4080>>2]=az;c[at+3060>>2]=aA;c[at+4084>>2]=aA;c[at+3064>>2]=aH;c[at+4088>>2]=aH;aH=c[2386410]|0;c[at+1020>>2]=aH;c[at+2044>>2]=aH;c[at+3068>>2]=aH;c[at+4092>>2]=aH;aH=c[2387132]|0;c[at+1024>>2]=aH;aA=aH+256|0;c[at+1028>>2]=aA;az=aH+512|0;c[at+1032>>2]=az;c[at+2048>>2]=aH;c[at+2052>>2]=aA;c[at+2056>>2]=az;c[at+3072>>2]=aH;c[at+4096>>2]=aH;c[at+3076>>2]=aA;c[at+4100>>2]=aA;c[at+3080>>2]=az;c[at+4104>>2]=az;c[at+4184>>2]=3016;c[at+4176>>2]=1554;c[at+4172>>2]=14;if(!ay){az=at;gGC(az|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=aw;c[2417276]=aC;c[1836236]=-1;fwR(1);az=c[2439331]|0;aA=(az|0)==0;if(!aA){aH=az;gGC(9706056,aH|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];aH=c[3528485]|0;c[2076596]=aH;aF=c[2417277]|0;c[3541536]=aF;c[1836236]=1;aG=c[3529186]|0;aK=0;aJ=0;while(1){c[az+76+(aJ<<2)>>2]=aG+(aJ<<8);aI=aK+1&65535;if((aI&65535)>127){aS=0;aT=0;break}else{aK=aI;aJ=aI&65535}}while(1){aJ=aG+(aT<<8)|0;c[az+76+(aT+512<<2)>>2]=aJ;c[az+76+(aT+768<<2)>>2]=aJ;aJ=aS+1&65535;if((aJ&65535)>127){break}else{aS=aJ;aT=aJ&65535}}aG=c[3529280]|0;c[az+588>>2]=aG;aJ=aG+256|0;c[az+592>>2]=aJ;aK=aG+512|0;c[az+596>>2]=aK;aC=aG+768|0;c[az+600>>2]=aC;aw=aG+1024|0;c[az+604>>2]=aw;at=aG+1280|0;c[az+608>>2]=at;ay=aG+1536|0;c[az+612>>2]=ay;aI=aG+1792|0;c[az+616>>2]=aI;c[az+1612>>2]=aG;c[az+1616>>2]=aJ;c[az+1620>>2]=aK;c[az+1624>>2]=aC;c[az+1628>>2]=aw;c[az+1632>>2]=at;c[az+1636>>2]=ay;c[az+1640>>2]=aI;c[az+2636>>2]=aG;c[az+3660>>2]=aG;c[az+2640>>2]=aJ;c[az+3664>>2]=aJ;c[az+2644>>2]=aK;c[az+3668>>2]=aK;c[az+2648>>2]=aC;c[az+3672>>2]=aC;c[az+2652>>2]=aw;c[az+3676>>2]=aw;c[az+2656>>2]=at;c[az+3680>>2]=at;c[az+2660>>2]=ay;c[az+3684>>2]=ay;c[az+2664>>2]=aI;c[az+3688>>2]=aI;c[az+4176>>2]=68;c[az+4172>>2]=968;if(!aA){aI=az;gGC(aI|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=aH;c[2417277]=aF;c[1836236]=-1;Vr(2,4e6,1164,2626,110,0);c[2438228]=4e6;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=511;h[745419]=.45;a[3203368]=1;h[745418]=.65;a[3203360]=1;h[745417]=.65;a[3203352]=1;h[745416]=.65;a[3203344]=1;h[745415]=.45;a[3203336]=1;h[745414]=.65;a[3203328]=1;h[745413]=.65;a[3203320]=1;h[745412]=.65;a[3203312]=1;aI=c[642608+(c[2436]<<2)>>2]|0;ay=c[aI+128>>2]|0;if((c[aI+52>>2]&4|0)==0){c[2113068]=ay;at=c[aI+132>>2]|0;c[2113070]=at;c[2443814]=ay;c[2440436]=at;aU=ay;aV=at}else{c[2113070]=ay;at=c[aI+132>>2]|0;c[2113068]=at;c[2440436]=ay;c[2443814]=at;aU=at;aV=ay}ay=ag(aU<<1,aV)|0;at=gGq(ay)|0;c[2112926]=at;if((at|0)!=0){gGz(at|0,0,ay|0)}ay=c[2414600]|0;gGz(ay|0,0,(c[2411554]|0)-ay|0);ay=c[2439330]|0;if((ay|0)!=0){at=ay;gGC(9706056,at|0,76)|0}c[2433530]=c[2438118];at=c[3528484]|0;c[2076596]=at;aI=c[2417276]|0;c[3541536]=aI;c[1836236]=0;gGz(9706056,0,76);c[3527214]=0;aw=c[3529230]|0;aC=128;aK=128;while(1){c[ay+76+(aK<<2)>>2]=aw+((aK<<8)+32768);aJ=aC+1&65535;if((aJ&65535)>191){break}else{aC=aJ;aK=aJ&65535}}aK=(c[3527214]<<14)+32768|0;aC=128;aF=128;while(1){c[ay+76+(aF<<2)>>2]=aw+(aK+(aF<<8));aH=aC+1&65535;if((aH&65535)>191){break}else{aC=aH;aF=aH&65535}}aF=ay;gGC(aF|0,9706056,76)|0;c[2438118]=c[2433530];c[3528484]=at;c[2417276]=aI;c[1836236]=-1;aF=c[2439331]|0;aC=(aF|0)==0;if(!aC){aK=aF;gGC(9706056,aK|0,76)|0}aK=c[2438119]|0;c[2433530]=aK;aw=c[3528485]|0;c[2076596]=aw;aH=c[2417277]|0;c[3541536]=aH;c[1836236]=1;gGz(9706056,0,76);if(!aC){aC=aF;gGC(aC|0,9706056,76)|0}c[2438119]=aK;c[3528485]=aw;c[2417277]=aH;c[1836236]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){aH=0;do{lN(aH);mB(aH);aH=aH+1|0;}while((aH|0)<(c[2385508]|0))}a[9542864]=0;a[9542872]=0;a[14107792]=0;a[14107800]=0;a[9635944]=0;a[14114384]=0;aB=0;i=f;return aB|0}}while(0);c[2414898]=0;aB=1;i=f;return aB|0}function eFG(b,c){b=b|0;c=c|0;a[9706117]=c&1;return}function eFH(a){a=a|0;var b=0,d=0;b=(c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,4e6,0)|0;return a|0}function eFI(){return+(+((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)/4.0e6)}function eFJ(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=c[2386410]|0;f=c[3530544]|0;g=252;do{h=d[e+(g|1)|0]|0;i=d[e+(g|3)|0]|0;j=d[e+g|0]|0|h<<5&256;k=h<<2&12|2;do{if((h&b|0)!=0){l=(h&16|0)!=0;m=247-(d[e+(g|2)|0]|0)|0;if((h&32|0)==0){if(l){SJ(a,j,i,m,k,4,15,0,f);break}else{SH(a,j,i,m,k,4,15,0,f);break}}else{if(l){SN(a,j,i,m,k,4,15,0,f);break}else{SL(a,j,i,m,k,4,15,0,f);break}}}}while(0);g=g-4|0;}while((g|0)>-1);return}function eFK(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=d&65535;if((f|0)==59392){a[c[3528224]|0]=e;d=c[1836236]|0;g=c[9757320+(d<<2)>>2]|0;if((g|0)!=0){h=g;gGC(h|0,9706056,76)|0}c[9752472+(d<<2)>>2]=c[2433530];c[14113936+(d<<2)>>2]=c[2076596];c[9669104+(d<<2)>>2]=c[3541536];c[1836236]=-1;d=c[2439331]|0;if((d|0)!=0){h=d;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;h=c[2433530]|0;c[2433530]=h+12;d=c[1836236]|0;g=c[9757320+(d<<2)>>2]|0;if((a[g+4188|0]|0)==0){i=gfc(50)|0;j=c[1836236]|0;k=(c[2433530]|0)+i|0;l=j;m=c[9757320+(j<<2)>>2]|0}else{k=h+62|0;l=d;m=g}c[2433530]=k;if((m|0)!=0){g=m;gGC(g|0,9706056,76)|0}c[9752472+(l<<2)>>2]=k;c[14113936+(l<<2)>>2]=c[2076596];c[9669104+(l<<2)>>2]=c[3541536];c[1836236]=-1;l=c[2439330]|0;if((l|0)!=0){k=l;gGC(9706056,k|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;return}else if((f|0)==59393){a[c[3528678]|0]=e&-128;a[c[2406766]|0]=e;return}else{return}}function eFL(b){b=b|0;var d=0,e=0;d=b&65535;if((d|0)==57344){e=a[9634824]|0}else if((d|0)==59393){e=a[c[2406766]|0]|0}else if((d|0)==53248){e=a[9550281]|0}else if((d|0)==51200){e=a[9550280]|0}else if((d|0)==57345){e=a[9634825]|0}else if((d|0)==55296){e=a[9550282]|0}else{e=0}return e|0}function eFM(a,b){a=a|0;b=b|0;var c=0;c=a&65532;if((c|0)==49152){TR(1,b&255);return}else if((c|0)==40960){TR(0,b&255);return}else{return}}function eFN(b){b=b|0;var d=0;if(b<<16>>16!=-8192){d=0;return d|0}d=a[c[3528224]|0]|0;return d|0}function eFO(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2190292+(b*112|0)>>2];c[a+104>>2]=c[2190296+(b*112|0)>>2];c[a+108>>2]=c[2190300+(b*112|0)>>2];d=0;return d|0}function eFP(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=2190192+(b*112|0);e=0;return e|0}function eFQ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1185240+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eFR(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>44){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3331336+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eFS(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0;e=i;i=i+1320|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;B=e+1200|0;C=e+1312|0;c[2414896]=0;c[3529228]=0;c[3529356]=65536;c[3529184]=131072;c[3530778]=196608;c[3530542]=262144;c[3530998]=327680;c[3529930]=329216;c[2414598]=332288;c[3529316]=332288;c[3529278]=334336;c[2386196]=336384;c[2386730]=338176;c[2386408]=338432;c[3528224]=338944;c[3528678]=338945;c[2406766]=338946;c[2411552]=338947;D=0;while(1){if((D|0)>=1024){break}E=9638528+(D<<2)|0;if((c[E>>2]|0)==0){F=17214;break}else{D=D+1|0}}do{if((F|0)==17214){D=gGq(338947)|0;c[E>>2]=D;if((D|0)==0){break}c[2414896]=D;gGz(D|0,0,338947);c[3529228]=D;c[3529356]=D+65536;c[3529184]=D+131072;c[3530778]=D+196608;c[3530542]=D+262144;c[3530998]=D+327680;c[3529930]=D+329216;G=D+332288|0;c[2414598]=G;c[3529316]=G;c[3529278]=D+334336;c[2386196]=D+336384;c[2386730]=D+338176;c[2386408]=D+338432;c[3528224]=D+338944;c[3528678]=D+338945;c[2406766]=D+338946;G=D+338947|0;c[2411552]=G;c[2414092]=G;if((c[3542200]|0)==0){H=1;i=e;return H|0}G=B+108|0;c[G>>2]=0;I=B+100|0;c[I>>2]=0;J=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[J&16383](B,0)|0;do{if((c[G>>2]|0)!=0){J=c[I>>2]|0;c[C>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](C,0,0)|0;if((J|0)<1){H=1;i=e;return H|0}if((gzL(D,0,0)|0)==0){break}else{H=1}i=e;return H|0}}while(0);D=(c[3529228]|0)+16384|0;if((c[3542200]|0)==0){H=1;i=e;return H|0}I=z+108|0;c[I>>2]=0;G=z+100|0;c[G>>2]=0;J=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[J&16383](z,1)|0;do{if((c[I>>2]|0)!=0){J=c[G>>2]|0;c[A>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](A,1,0)|0;if((J|0)<1){H=1;i=e;return H|0}if((gzL(D,0,1)|0)==0){break}else{H=1}i=e;return H|0}}while(0);D=(c[3529228]|0)+32768|0;if((c[3542200]|0)==0){H=1;i=e;return H|0}G=x+108|0;c[G>>2]=0;I=x+100|0;c[I>>2]=0;J=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[J&16383](x,2)|0;do{if((c[G>>2]|0)!=0){J=c[I>>2]|0;c[y>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](y,2,0)|0;if((J|0)<1){H=1;i=e;return H|0}if((gzL(D,0,2)|0)==0){break}else{H=1}i=e;return H|0}}while(0);D=c[3529184]|0;if((c[3542200]|0)==0){H=1;i=e;return H|0}I=v+108|0;c[I>>2]=0;G=v+100|0;c[G>>2]=0;J=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[J&16383](v,3)|0;do{if((c[I>>2]|0)!=0){J=c[G>>2]|0;c[w>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](w,3,0)|0;if((J|0)<1){H=1;i=e;return H|0}if((gzL(D,0,3)|0)==0){break}else{H=1}i=e;return H|0}}while(0);D=c[3530778]|0;if((c[3542200]|0)==0){H=1;i=e;return H|0}G=t+108|0;c[G>>2]=0;I=t+100|0;c[I>>2]=0;J=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[J&16383](t,4)|0;do{if((c[G>>2]|0)!=0){J=c[I>>2]|0;c[u>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](u,4,0)|0;if((J|0)<1){H=1;i=e;return H|0}if((gzL(D,0,4)|0)==0){break}else{H=1}i=e;return H|0}}while(0);D=(c[3530778]|0)+8192|0;if((c[3542200]|0)==0){H=1;i=e;return H|0}I=r+108|0;c[I>>2]=0;G=r+100|0;c[G>>2]=0;J=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[J&16383](r,5)|0;do{if((c[I>>2]|0)!=0){J=c[G>>2]|0;c[s>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](s,5,0)|0;if((J|0)<1){H=1;i=e;return H|0}if((gzL(D,0,5)|0)==0){break}else{H=1}i=e;return H|0}}while(0);D=(c[3530778]|0)+16384|0;if((c[3542200]|0)==0){H=1;i=e;return H|0}G=p+108|0;c[G>>2]=0;I=p+100|0;c[I>>2]=0;J=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[J&16383](p,6)|0;do{if((c[G>>2]|0)!=0){J=c[I>>2]|0;c[q>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](q,6,0)|0;if((J|0)<1){H=1;i=e;return H|0}if((gzL(D,0,6)|0)==0){break}else{H=1}i=e;return H|0}}while(0);D=c[3530542]|0;if((c[3542200]|0)==0){H=1;i=e;return H|0}I=n+108|0;c[I>>2]=0;G=n+100|0;c[G>>2]=0;J=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[J&16383](n,7)|0;do{if((c[I>>2]|0)!=0){J=c[G>>2]|0;c[o>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](o,7,0)|0;if((J|0)<1){H=1;i=e;return H|0}if((gzL(D,0,7)|0)==0){break}else{H=1}i=e;return H|0}}while(0);D=(c[3530542]|0)+16384|0;if((c[3542200]|0)==0){H=1;i=e;return H|0}G=l+108|0;c[G>>2]=0;I=l+100|0;c[I>>2]=0;J=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[J&16383](l,8)|0;do{if((c[G>>2]|0)!=0){J=c[I>>2]|0;c[m>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](m,8,0)|0;if((J|0)<1){H=1;i=e;return H|0}if((gzL(D,0,8)|0)==0){break}else{H=1}i=e;return H|0}}while(0);D=(c[3530998]|0)+512|0;if((c[3542200]|0)==0){H=1;i=e;return H|0}I=j+108|0;c[I>>2]=0;G=j+100|0;c[G>>2]=0;J=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[J&16383](j,9)|0;do{if((c[I>>2]|0)!=0){J=c[G>>2]|0;c[k>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](k,9,0)|0;if((J|0)<1){H=1;i=e;return H|0}if((gzL(D,0,9)|0)==0){break}else{H=1}i=e;return H|0}}while(0);D=c[3530998]|0;G=D+256|0;I=D+512|0;gGC(G|0,I|0,128)|0;G=D+640|0;gGC(D|0,G|0,128)|0;G=D+384|0;J=D+768|0;gGC(G|0,J|0,128)|0;J=D+128|0;G=D+896|0;gGC(J|0,G|0,128)|0;if((c[3542200]|0)==0){H=1;i=e;return H|0}G=f+108|0;c[G>>2]=0;J=f+100|0;c[J>>2]=0;D=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[D&16383](f,10)|0;do{if((c[G>>2]|0)!=0){D=c[J>>2]|0;c[g>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](g,10,0)|0;if((D|0)<1){H=1;i=e;return H|0}if((gzL(I,0,10)|0)==0){break}else{H=1}i=e;return H|0}}while(0);I=c[3529228]|0;J=c[3529356]|0;G=J+32768|0;D=I+32768|0;gGC(G|0,D|0,16384)|0;D=0;do{G=I+D|0;K=d[G]|0;L=K>>>5<<1&2|K>>>3&1;M=(K&128|0)==0;N=M?0:168;O=M?L:L^3;L=K&87;K=(D>>>4<<1&2|D&1|D>>>8<<2&4|D>>>12<<3&8)<<1;M=a[601480+(K<<2)+O|0]|0;P=J+D|0;a[P]=(N^M&255|L)&255;Q=a[601480+((K|1)<<2)+O|0]|0;a[G]=(N^Q&255|L)&255;if(M<<24>>24==-1){a[P]=-18}if(Q<<24>>24==-1){a[G]=-18}D=D+1|0;}while((D|0)<32768);eFZ();D=c[3530778]|0;J=(c[3530998]|0)+512|0;I=0;G=D+24576|0;Q=D;while(1){D=0;P=G;M=Q;while(1){L=P+24576|0;a[L]=0;N=P+16384|0;a[N]=0;O=P+8192|0;a[O]=0;a[P]=0;K=M+8192|0;R=M+16384|0;S=0;T=0;U=0;V=0;W=0;do{X=d[J+((d[K]|0)>>>(S>>>0)<<1&2|(d[M]|0)>>>(S>>>0)<<2&4|(d[R]|0)>>>(S>>>0)&1)|0]|0;T=((X>>>3&1)<<S|T&255)&255;a[P]=T;U=((X>>>2&1)<<S|U&255)&255;a[O]=U;V=((X>>>1&1)<<S|V&255)&255;a[N]=V;W=((X&1)<<S|W&255)&255;a[L]=W;S=S+1|0;}while((S|0)<8);S=D+1|0;if((S|0)<64){D=S;P=P+1|0;M=M+1|0}else{break}}M=I+1|0;if((M|0)<128){J=J+8|0;I=M;G=G+64|0;Q=Q+64|0}else{Y=0;break}}while(1){if((Y|0)>=1024){break}Z=9638528+(Y<<2)|0;if((c[Z>>2]|0)==0){F=17274;break}else{Y=Y+1|0}}L23167:do{if((F|0)==17274){Q=gGq(32768)|0;c[Z>>2]=Q;if((Q|0)==0){break}gGz(Q|0,0,32768);G=c[3530778]|0;I=G+24576|0;gGC(Q|0,I|0,32768)|0;I=0;while(1){J=I<<6;gGz(G+J|0,0,64);M=0;do{P=1<<3-M;D=(c[613088+(M<<2)>>2]|0)+J|0;S=0;do{W=D+(c[1238464+(S<<2)>>2]|0)|0;L=(S<<3)+J|0;V=0;do{N=W+(c[614800+(V<<2)>>2]|0)|0;if(((d[Q+((N|0)/8|0)|0]|0)&128>>>((N&7)>>>0)|0)!=0){N=G+(L+V)|0;a[N]=(d[N]|0|P)&255}V=V+1|0;}while((V|0)<8);S=S+1|0;}while((S|0)<8);M=M+1|0;}while((M|0)<4);M=I+1|0;if((M|0)<1024){I=M}else{_=0;break}}while(1){if((_|0)>=1024){break L23167}$=9638528+(_<<2)|0;if((c[$>>2]|0)==(Q|0)){break}else{_=_+1|0}}gGr(Q);c[$>>2]=0}}while(0);fwR(0);I=c[2439330]|0;if((I|0)!=0){G=I;gGC(9706056,G|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];G=c[3528484]|0;c[2076596]=G;M=c[2417276]|0;c[3541536]=M;c[1836236]=0;J=c[3529228]|0;S=0;P=0;while(1){c[I+76+(P<<2)>>2]=J+(P<<8);D=S+1&65535;if((D&65535)>191){break}else{S=D;P=D&65535}}P=c[3529356]|0;S=0;D=0;while(1){V=D<<8;c[I+76+(D+512<<2)>>2]=P+V;c[I+76+(D+768<<2)>>2]=J+V;V=S+1&65535;if((V&65535)>191){break}else{S=V;D=V&65535}}D=c[2386408]|0;c[I+844>>2]=D;S=D+256|0;c[I+848>>2]=S;c[I+1868>>2]=D;c[I+1872>>2]=S;c[I+2892>>2]=D;c[I+3916>>2]=D;c[I+2896>>2]=S;c[I+3920>>2]=S;S=c[2386196]|0;c[I+1036>>2]=S;D=S+256|0;c[I+1040>>2]=D;J=S+512|0;c[I+1044>>2]=J;P=S+768|0;c[I+1048>>2]=P;V=S+1024|0;c[I+1052>>2]=V;L=S+1280|0;c[I+1056>>2]=L;W=S+1536|0;c[I+1060>>2]=W;c[I+2060>>2]=S;c[I+2064>>2]=D;c[I+2068>>2]=J;c[I+2072>>2]=P;c[I+2076>>2]=V;c[I+2080>>2]=L;c[I+2084>>2]=W;c[I+3084>>2]=S;c[I+4108>>2]=S;c[I+3088>>2]=D;c[I+4112>>2]=D;c[I+3092>>2]=J;c[I+4116>>2]=J;c[I+3096>>2]=P;c[I+4120>>2]=P;c[I+3100>>2]=V;c[I+4124>>2]=V;c[I+3104>>2]=L;c[I+4128>>2]=L;c[I+3108>>2]=W;c[I+4132>>2]=W;W=c[2386730]|0;c[I+1064>>2]=W;c[I+2088>>2]=W;c[I+3112>>2]=W;c[I+4136>>2]=W;W=c[3529316]|0;c[I+1068>>2]=W;L=W+256|0;c[I+1072>>2]=L;V=W+512|0;c[I+1076>>2]=V;P=W+768|0;c[I+1080>>2]=P;J=W+1024|0;c[I+1084>>2]=J;D=W+1280|0;c[I+1088>>2]=D;S=W+1536|0;c[I+1092>>2]=S;N=W+1792|0;c[I+1096>>2]=N;c[I+2092>>2]=W;c[I+2096>>2]=L;c[I+2100>>2]=V;c[I+2104>>2]=P;c[I+2108>>2]=J;c[I+2112>>2]=D;c[I+2116>>2]=S;c[I+2120>>2]=N;c[I+3116>>2]=W;c[I+4140>>2]=W;c[I+3120>>2]=L;c[I+4144>>2]=L;c[I+3124>>2]=V;c[I+4148>>2]=V;c[I+3128>>2]=P;c[I+4152>>2]=P;c[I+3132>>2]=J;c[I+4156>>2]=J;c[I+3136>>2]=D;c[I+4160>>2]=D;c[I+3140>>2]=S;c[I+4164>>2]=S;c[I+3144>>2]=N;c[I+4168>>2]=N;c[I+4184>>2]=2728;c[I+4180>>2]=694;N=I;gGC(N|0,9706056,76)|0;c[2438118]=c[2433530];c[3528484]=G;c[2417276]=M;c[1836236]=-1;fwR(1);N=c[2439331]|0;S=(N|0)==0;if(!S){D=N;gGC(9706056,D|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];D=c[3528485]|0;c[2076596]=D;J=c[2417277]|0;c[3541536]=J;c[1836236]=1;P=c[3529184]|0;V=0;L=0;while(1){c[N+76+(L<<2)>>2]=P+(L<<8);W=V+1&65535;if((W&65535)>127){aa=0;ab=0;break}else{V=W;L=W&65535}}while(1){L=P+(ab<<8)|0;c[N+76+(ab+512<<2)>>2]=L;c[N+76+(ab+768<<2)>>2]=L;L=aa+1&65535;if((L&65535)>127){break}else{aa=L;ab=L&65535}}P=c[3529278]|0;c[N+588>>2]=P;L=P+256|0;c[N+592>>2]=L;V=P+512|0;c[N+596>>2]=V;M=P+768|0;c[N+600>>2]=M;G=P+1024|0;c[N+604>>2]=G;I=P+1280|0;c[N+608>>2]=I;W=P+1536|0;c[N+612>>2]=W;U=P+1792|0;c[N+616>>2]=U;c[N+1612>>2]=P;c[N+1616>>2]=L;c[N+1620>>2]=V;c[N+1624>>2]=M;c[N+1628>>2]=G;c[N+1632>>2]=I;c[N+1636>>2]=W;c[N+1640>>2]=U;c[N+2636>>2]=P;c[N+3660>>2]=P;c[N+2640>>2]=L;c[N+3664>>2]=L;c[N+2644>>2]=V;c[N+3668>>2]=V;c[N+2648>>2]=M;c[N+3672>>2]=M;c[N+2652>>2]=G;c[N+3676>>2]=G;c[N+2656>>2]=I;c[N+3680>>2]=I;c[N+2660>>2]=W;c[N+3684>>2]=W;c[N+2664>>2]=U;c[N+3688>>2]=U;c[N+4184>>2]=1096;c[N+4180>>2]=3440;if(!S){U=N;gGC(U|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=D;c[2417277]=J;c[1836236]=-1;TS(0,4e6,32768,6,0,0);TS(1,2e6,32768,6,0,1);U=c[2420348]|0;h[U+192>>3]=1.0;c[U+200>>2]=3;U=c[2420346]|0;h[U+192>>3]=1.0;c[U+200>>2]=3;U=c[642608+(c[2436]<<2)>>2]|0;W=c[U+128>>2]|0;if((c[U+52>>2]&4|0)==0){c[2113068]=W;I=c[U+132>>2]|0;c[2113070]=I;c[2443814]=W;c[2440436]=I;ac=W;ad=I}else{c[2113070]=W;I=c[U+132>>2]|0;c[2113068]=I;c[2440436]=W;c[2443814]=I;ac=I;ad=W}W=ag(ac<<1,ad)|0;I=gGq(W)|0;c[2112926]=I;if((I|0)!=0){gGz(I|0,0,W|0)}W=c[2414598]|0;gGz(W|0,0,(c[2411552]|0)-W|0);W=c[2439330]|0;I=(W|0)==0;if(!I){U=W;gGC(9706056,U|0,76)|0}U=c[2438118]|0;c[2433530]=U;G=c[3528484]|0;c[2076596]=G;M=c[2417276]|0;c[3541536]=M;c[1836236]=0;gGz(9706056,0,76);if(!I){I=W;gGC(I|0,9706056,76)|0}c[2438118]=U;c[3528484]=G;c[2417276]=M;c[1836236]=-1;M=c[2439331]|0;G=(M|0)==0;if(!G){U=M;gGC(9706056,U|0,76)|0}U=c[2438119]|0;c[2433530]=U;I=c[3528485]|0;c[2076596]=I;W=c[2417277]|0;c[3541536]=W;c[1836236]=1;gGz(9706056,0,76);if(!G){G=M;gGC(G|0,9706056,76)|0}c[2438119]=U;c[3528485]=I;c[2417277]=W;c[1836236]=-1;H=0;i=e;return H|0}}while(0);c[2414896]=0;H=1;i=e;return H|0}function eFT(){var a=0,b=0,d=0,e=0;c[2113070]=0;c[2113068]=0;a=c[2112926]|0;if((a|0)!=0){gGr(a);c[2112926]=0}fwZ();TT();a=c[2414896]|0;b=0;while(1){if((b|0)>=1024){d=17358;break}e=9638528+(b<<2)|0;if((c[e>>2]|0)==(a|0)){break}else{b=b+1|0}}if((d|0)==17358){c[2414896]=0;return 0}gGr(a);c[e>>2]=0;c[2414896]=0;return 0}function eFU(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if((a[9623760]|0)!=0){d=c[2414598]|0;gGz(d|0,0,(c[2411552]|0)-d|0);d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;h=c[2417276]|0;c[3541536]=h;c[1836236]=0;gGz(9706056,0,76);if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=h;c[1836236]=-1;h=c[2439331]|0;g=(h|0)==0;if(!g){f=h;gGC(9706056,f|0,76)|0}f=c[2438119]|0;c[2433530]=f;e=c[3528485]|0;c[2076596]=e;d=c[2417277]|0;c[3541536]=d;c[1836236]=1;gGz(9706056,0,76);if(!g){g=h;gGC(g|0,9706056,76)|0}c[2438119]=f;c[3528485]=e;c[2417277]=d;c[1836236]=-1}gGz(9550280,-1|0,3);d=0;e=-1;f=-1;g=-1;do{e=((a[9632816+d|0]&1)<<d^e&255)&255;f=((a[9630704+d|0]&1)<<d^f&255)&255;g=((a[9629304+d|0]&1)<<d^g&255)&255;d=d+1|0;}while((d|0)<8);a[9550280]=e;a[9550281]=f;a[9550282]=g;g=0;do{f=c[2439330]|0;if((f|0)!=0){e=f;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;e=c[2438118]|0;c[2433530]=e;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;if((a[f+4188|0]|0)==0){f=gfc(666)|0;i=(c[2433530]|0)+f|0}else{i=e+666|0}c[2433530]=i;do{if((g|0)==99){a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0;e=c[1836236]|0;f=c[9757320+(e<<2)>>2]|0;if((f|0)!=0){d=f;gGC(d|0,9706056,76)|0}c[9752472+(e<<2)>>2]=c[2433530];c[14113936+(e<<2)>>2]=c[2076596];c[9669104+(e<<2)>>2]=c[3541536];c[1836236]=-1;e=c[2439331]|0;if((e|0)!=0){d=e;gGC(9706056,d|0,76)|0}b[4853030]=c[2426515]&65535;d=c[2438119]|0;c[2433530]=d;c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;if((a[e+4188|0]|0)==0){e=gfc(666)|0;c[2433530]=(c[2433530]|0)+e;j=17394;break}else{c[2433530]=d+666;j=17394;break}}else{d=c[1836236]|0;e=c[9757320+(d<<2)>>2]|0;if((e|0)!=0){f=e;gGC(f|0,9706056,76)|0}c[9752472+(d<<2)>>2]=i;c[14113936+(d<<2)>>2]=c[2076596];c[9669104+(d<<2)>>2]=c[3541536];c[1836236]=-1;d=c[2439331]|0;if((d|0)!=0){f=d;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;f=c[2438119]|0;c[2433530]=f;c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;if((a[d+4188|0]|0)==0){d=gfc(666)|0;k=(c[2433530]|0)+d|0}else{k=f+666|0}c[2433530]=k;if((g|0)==24|(g|0)==74|(g|0)==49){j=17394}}}while(0);if((j|0)==17394){j=0;a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0}f=c[1836236]|0;d=c[9757320+(f<<2)>>2]|0;if((d|0)!=0){e=d;gGC(e|0,9706056,76)|0}c[9752472+(f<<2)>>2]=c[2433530];c[14113936+(f<<2)>>2]=c[2076596];c[9669104+(f<<2)>>2]=c[3541536];c[1836236]=-1;g=g+1|0;}while((g|0)<100);g=c[2112964]|0;if((g|0)!=0){j=a[9688]|0?534:0;TQ(0,g,j);TQ(1,g,j)}if((c[2112968]|0)==0){return 0}eFV()|0;return 0}function eFV(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;if((a[9547200]|0)!=0){eFZ();a[9547200]=0}eF_(0);e=(a[c[2406766]|0]&32)!=0?512:256;f=c[2386408]|0;g=c[3528678]|0;h=c[3530542]|0;i=c[2113068]|0;j=c[2113070]|0;k=c[2112926]|0;l=0;do{m=d[f+l|0]|0;n=d[f+(l|1)|0]|0;o=n-m|0;p=(d[f+(l|2)|0]|0)-8|0;q=d[f+(l|3)|0]<<4&48|e;r=d[f+(l|5)|0]<<8|d[f+(l|4)|0];s=d[f+(l|7)|0]<<8|d[f+(l|6)|0];L23312:do{if((s|0)!=255){t=(a[g]|0)==0;u=t?1:-1;if((o|0)<=0){break}v=r<<16>>16;w=t?m+1|0:n;t=s;x=1;while(1){y=t+v|0;z=h+(y&32767)|0;A=j+~w|0;L23317:do{if((y&32768|0)==0){B=z;C=0;while(1){D=B+1|0;E=d[B]|0;F=E>>>4;G=E&15;do{if((F|0)==15){break L23317}else if((F|0)!=0){E=C+p|0;if((a[g]|0)==0){H=E;I=w}else{H=i+~E|0;I=A}if((H|0)<0){break}if(!((I|0)>-1&(H|0)<(i|0)&(I|0)<(j|0))){break}b[k+((ag(i,I)|0)+H<<1)>>1]=(F|q)&65535}}while(0);do{if((G|0)==15){break L23317}else if((G|0)!=0){F=C+p|0;if((a[g]|0)==0){J=F+1|0;K=w}else{J=-2-F+i|0;K=A}if((J|0)<0){break}if(!((K|0)>-1&(J|0)<(i|0)&(K|0)<(j|0))){break}b[k+((ag(i,K)|0)+J<<1)>>1]=(G|q)&65535}}while(0);B=D;C=C+2|0}}else{C=z;B=0;while(1){G=C-1|0;F=d[C]|0;E=F&15;L=F>>>4;do{if((E|0)==15){break L23317}else if((E|0)!=0){F=B+p|0;if((a[g]|0)==0){M=F;N=w}else{M=i+~F|0;N=A}if((M|0)<0){break}if(!((N|0)>-1&(M|0)<(i|0)&(N|0)<(j|0))){break}b[k+((ag(i,N)|0)+M<<1)>>1]=(E|q)&65535}}while(0);do{if((L|0)==15){break L23317}else if((L|0)!=0){E=B+p|0;if((a[g]|0)==0){O=E+1|0;P=w}else{O=-2-E+i|0;P=A}if((O|0)<0){break}if(!((P|0)>-1&(O|0)<(i|0)&(P|0)<(j|0))){break}b[k+((ag(i,P)|0)+O<<1)>>1]=(L|q)&65535}}while(0);C=G;B=B+2|0}}}while(0);if((x|0)>=(o|0)){break L23312}w=w+u|0;t=y;x=x+1|0}}}while(0);l=l+16|0;}while((l|0)<512);eF_(32);R8(c[3529930]|0);return 0}function eFW(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=i;i=i+16|0;e=d|0;if((b|0)!=0){c[b>>2]=169748}if((a&96|0)==0){i=d;return 0}gGz(e|0,0,12);f=c[2414598]|0;c[e>>2]=f;c[e+4>>2]=(c[2411552]|0)-f;c[e+12>>2]=162152;gj[c[2076592]&4095](e)|0;fw$(a);TU(a,b);i=d;return 0}function eFX(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1383156+(b*112|0)>>2];c[a+104>>2]=c[1383160+(b*112|0)>>2];c[a+108>>2]=c[1383164+(b*112|0)>>2];d=0;return d|0}function eFY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=1383056+(b*112|0);e=0;return e|0}function eFZ(){var a=0,b=0,e=0,f=0,g=0,h=0;a=c[3530998]|0;b=c[3529930]|0;e=0;do{f=d[a+e|0]|0;g=(-(f>>>1&1)&71)+(-(f&1)&33)+(-(f>>>2&1)&151)<<8&63488|(-(f>>>3&1)&33)+(-(f>>>4&1)&71)+(-(f>>>5&1)&151)<<3&2016;h=((-(f>>>6&1)&71)+(-(f>>>7)&151)|0)>>>3&31;c[b+(e<<2)>>2]=g|h;if((e|0)>255){c[b+(e+256<<2)>>2]=g|((e&15|0)==9?31:h)}e=e+1|0;}while((e|0)<512);return}function eF_(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=c[2386730]|0;f=c[2386196]|0;g=c[3528678]|0;h=c[2112926]|0;i=c[3530778]|0;j=0;do{k=j>>5;l=k<<3;m=(j<<3&248)-(d[e+(k+224)|0]|0)|0;k=(m|0)<-7?m+256|0:m;m=j<<1;n=d[f+(m|1)|0]|0;o=n<<8&768|d[f+m|0];m=n>>>2&7;do{if((n&32|0)==(b|0)){if((a[g]|0)==0){Sj(h,o,k,l,m,4,0,i);break}else{Sp(h,o,238-k|0,216-l|0,m,4,0,i);break}}}while(0);j=j+1|0;}while((j|0)<1024);return}function eF$(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=a-917504|0;L23397:do{if(d>>>0<8){e=d>>>1&3;if((e|0)==0){f=b[4789564]|0;break}else if((e|0)==1){f=b[4789565]|0;break}else if((e|0)==3){f=ag(b[4789565]|0,b[4789564]|0)|0;break}else if((e|0)==2){f=(ag(b[4789565]|0,b[4789564]|0)|0)>>>16&65535;break}else{f=-1;break}}else{e=a-933888|0;if(e>>>0<32){switch(e>>>1&7|0){case 1:{f=b[4822409]|0;break L23397;break};case 5:{f=b[4822413]|0;break L23397;break};case 2:{f=b[4822410]|0;break L23397;break};case 6:{f=b[4822414]|0;break L23397;break};case 4:{f=b[4822412]|0;break L23397;break};case 0:{f=b[4822408]|0;break L23397;break};default:{f=-1;break L23397}}}e=a-950272|0;if(e>>>0<32){switch(e>>>1&15|0){case 7:{f=b[4878611]|0;break L23397;break};case 4:{f=b[4878608]|0;break L23397;break};case 2:{f=b[4878606]|0;break L23397;break};case 3:{f=b[4878607]|0;break L23397;break};case 6:{f=b[4878606]|0;break L23397;break};case 1:{f=b[4878605]|0;break L23397;break};case 0:{f=b[4878604]|0;break L23397;break};case 5:{f=b[4878605]|0;break L23397;break};default:{f=-1;break L23397}}}e=a-3014656|0;if(e>>>0<8){g=e>>>1&3;if((g|0)==0){f=b[4789568]|0;break}else if((g|0)==2){f=(ag(b[4789569]|0,b[4789568]|0)|0)>>>16&65535;break}else if((g|0)==3){f=ag(b[4789569]|0,b[4789568]|0)|0;break}else if((g|0)==1){f=b[4789569]|0;break}else{f=-1;break}}g=a-3031040|0;if(g>>>0<32){switch(g>>>1&7|0){case 6:{f=b[4822422]|0;break L23397;break};case 4:{f=b[4822420]|0;break L23397;break};case 0:{f=b[4822416]|0;break L23397;break};case 5:{f=b[4822421]|0;break L23397;break};case 2:{f=b[4822418]|0;break L23397;break};case 1:{f=b[4822417]|0;break L23397;break};default:{f=-1;break L23397}}}g=a-3047424|0;if(g>>>0>=16){if((a|0)!=3072e3){f=-1;break}e=c[3532454]|0;h=c[3532456]|0;gGC(e|0,h|0,4096)|0;i=e;e=h;h=0;while(1){j=c[i>>2]|0;c[i>>2]=c[e>>2];c[e>>2]=j;j=h+1|0;if((j|0)<1024){i=i+4|0;e=e+4|0;h=j}else{break}}f=c[3532458]&65535;break}switch(g>>>1&15|0){case 0:{f=b[4878622]|0;break L23397;break};case 5:{f=b[4878623]|0;break L23397;break};case 2:{f=b[4878624]|0;break L23397;break};case 7:{f=b[4878629]|0;break L23397;break};case 3:{f=b[4878625]|0;break L23397;break};case 4:{f=b[4878626]|0;break L23397;break};case 1:{f=b[4878623]|0;break L23397;break};case 6:{f=b[4878624]|0;break L23397;break};default:{f=-1;break L23397}}}}while(0);return f|0}function eF0(e){e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;f=e-933888|0;if(f>>>0<32){switch(f>>>1&7|0){case 1:{g=b[4822409]&255;return g|0};case 6:{g=b[4822414]&255;return g|0};case 0:{g=b[4822408]&255;return g|0};case 5:{g=b[4822413]&255;return g|0};case 4:{g=b[4822412]&255;return g|0};case 2:{g=b[4822410]&255;return g|0};default:{g=-1;return g|0}}}f=e-3031040|0;if(f>>>0<32){switch(f>>>1&7|0){case 0:{g=b[4822408]&255;return g|0};case 1:{g=b[4822409]&255;return g|0};case 2:{g=b[4822410]&255;return g|0};case 4:{g=b[4822412]&255;return g|0};case 5:{g=b[4822413]&255;return g|0};case 6:{g=b[4822414]&255;return g|0};default:{g=-1;return g|0}}}if((e-1310720|0)>>>0<65536){switch(e>>>1&7|0){case 2:{f=a[9776722]|0;h=c[2430010]|0;if((h|0)==0){i=0}else{i=(gj[h&4095](0)|0)&255}h=d[9776726]|0;if((h&16|0)==0){j=f&255}else{j=(i&15|f&240)&65535}if((h&32|0)==0){g=j&255;return g|0}g=(j&15|i&240)&255;return g|0};case 0:{i=a[9776720]|0;j=c[2430008]|0;if((j|0)==0){k=255}else{k=(gj[j&4095](-1)|0)&255}j=d[9776726]|0;if((j&1|0)==0){l=i&255}else{l=(k&15|i&240)&65535}if((j&2|0)==0){g=l&255;return g|0}g=(l&15|k&240)&255;return g|0};case 1:{k=a[9776721]|0;l=c[2430009]|0;if((l|0)==0){m=255}else{m=(gj[l&4095](-1)|0)&255}l=d[9776726]|0;if((l&4|0)==0){n=k&255}else{n=(m&15|k&240)&65535}if((l&8|0)==0){g=n&255;return g|0}g=(n&15|m&240)&255;return g|0};case 3:{m=a[9776723]|0;n=c[2430011]|0;if((n|0)==0){o=0}else{o=(gj[n&4095](0)|0)&255}n=d[9776726]|0;if((n&64|0)==0){p=m&255}else{p=(o&15|m&240)&65535}if((n&128|0)==0){g=p&255;return g|0}g=(p&15|o&240)&255;return g|0};case 4:{o=a[9776724]|0;p=c[2430012]|0;if((p|0)==0){q=0}else{q=(gj[p&4095](0)|0)&255}p=a[9776727]|0;if((p&1)==0){r=o&255}else{r=(q&1|o&254)&65535}if((p&2)==0){s=r}else{s=(r&65533|q&2)&65535}if((p&4)==0){t=s}else{t=(s&65531|q&4)&65535}if((p&8)==0){u=t&255}else{u=(t&247|q&8)&255}g=u&15;return g|0};default:{g=0;return g|0}}}if((e-1376256|0)>>>0>=65536){if((e|0)==1245185){v=17617}else if(!((e|0)==3072e3|(e|0)==3072001|(e|0)==3072002)){g=-1;return g|0}do{if((v|0)==17617){u=c[3532482]|0;if((u|0)==0){break}g=gj[u&4095]((a[9776722]&255)>>>2&7)|0;return g|0}}while(0);v=c[3532454]|0;u=c[3532456]|0;gGC(v|0,u|0,4096)|0;q=v;v=u;u=0;while(1){t=c[q>>2]|0;c[q>>2]=c[v>>2];c[v>>2]=t;t=u+1|0;if((t|0)<1024){q=q+4|0;v=v+4|0;u=t}else{break}}g=c[3532458]&255;return g|0}switch(e>>>1&7|0){case 2:{e=a[14130176]|0;u=a[9776730]|0;v=c[2430014]|0;if((v|0)==0){w=e}else{w=gj[v&4095](e)|0}e=d[9776734]|0;if((e&16|0)==0){x=u}else{x=w&15|u&-16}if((e&32|0)==0){g=x;return g|0}g=x&15|w&-16;return g|0};case 1:{w=~(d[14130137]|0);x=a[9776729]|0;e=c[2430013]|0;if((e|0)==0){y=w}else{y=(gj[e&4095](w&255)|0)&255}w=d[9776734]|0;if((w&4|0)==0){z=x&255}else{z=(y&15|x&240)&65535}if((w&8|0)==0){g=z&255;return g|0}g=(z&15|y&240)&255;return g|0};case 0:{y=~(d[14130136]|0);z=a[9776728]|0;w=c[2430012]|0;if((w|0)==0){A=y}else{A=(gj[w&4095](y&255)|0)&255}y=d[9776734]|0;if((y&1|0)==0){B=z&255}else{B=(A&15|z&240)&65535}if((y&2|0)==0){g=B&255;return g|0}g=(B&15|A&240)&255;return g|0};case 4:{A=a[9776732]|0;B=c[2430016]|0;if((B|0)==0){C=0}else{C=(gj[B&4095](0)|0)&255}B=a[9776735]|0;if((B&1)==0){D=A&255}else{D=(C&1|A&254)&65535}if((B&2)==0){E=D}else{E=(D&65533|C&2)&65535}if((B&4)==0){F=E}else{F=(E&65531|C&4)&65535}if((B&8)==0){G=F&255}else{G=(F&247|C&8)&255}g=G&15;return g|0};case 3:{G=a[14130177]|0;C=a[9776731]|0;F=c[2430015]|0;if((F|0)==0){H=G}else{H=gj[F&4095](G)|0}G=d[9776734]|0;if((G&64|0)==0){I=C}else{I=H&15|C&-16}if((G&128|0)==0){g=I;return g|0}g=I&15|H&-16;return g|0};default:{g=0;return g|0}}return 0}function eF1(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;f=d-786432|0;if(f>>>0<65536){eOX(f,e);return}f=d-917504|0;if(f>>>0<8){g=f>>>1&3;if((g|0)==0){b[4789564]=e;return}else if((g|0)==2){b[4789564]=e;return}else if((g|0)==1){b[4789565]=e;return}else if((g|0)==3){b[4789565]=e;return}else{return}}g=d-933888|0;if(g>>>0<32){f=g>>>1;g=f&8;h=f&4;i=f&3;if((i|0)==1){b[4822409]=e}else if((i|0)==0){b[4822408]=e}else if((i|0)==2){b[4822410]=e}if((g|0)==0){return}b[4822414]=0;g=b[4822408]|0;i=b[4822409]|0;f=i&65535;j=(g&65535)<<16|f;k=b[4822410]|0;if((h|0)!=0){if(k<<16>>16==0){b[4822414]=16384;l=g;m=i}else{i=(j>>>0)/((k&65535)>>>0)|0;l=i>>>16&65535;m=i&65535}b[4822412]=l;b[4822413]=m;return}m=k<<16>>16;if(k<<16>>16==0){b[4822414]=16384;n=j;o=-16384}else{n=(j|0)/(m|0)|0;o=-32768}j=f-(ag(n,m)|0)|0;do{if((n|0)<-32768){b[4822414]=o;p=-32768}else{if((n|0)<=32767){p=n&65535;break}b[4822414]=o;p=32767}}while(0);b[4822412]=p;b[4822413]=j&65535;return}j=d-950272|0;if(j>>>0<32){do{if((d|0)==950294){c[3532412]=e&255;p=c[2439330]|0;if((p|0)!=0){o=p;gGC(9706056,o|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;o=c[2433530]|0;c[2433530]=o+12;p=c[1836236]|0;n=c[9757320+(p<<2)>>2]|0;if((a[n+4188|0]|0)==0){m=gfc(100)|0;f=c[1836236]|0;q=m;r=(c[2433530]|0)+m|0;s=f;t=c[9757320+(f<<2)>>2]|0}else{q=100;r=o+112|0;s=p;t=n}c[2433530]=r;c[2113036]=(c[2113036]|0)+q;if((t|0)!=0){n=t;gGC(n|0,9706056,76)|0}c[9752472+(s<<2)>>2]=r;c[14113936+(s<<2)>>2]=c[2076596];c[9669104+(s<<2)>>2]=c[3541536];c[1836236]=-1;if((c[3532326]|0)==0){break}n=c[2439331]|0;if((n|0)!=0){p=n;gGC(9706056,p|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;p=c[2433530]|0;c[2433530]=p+12;n=c[1836236]|0;o=c[9757320+(n<<2)>>2]|0;if((a[o+4188|0]|0)==0){f=gfc(100)|0;m=c[1836236]|0;u=f;v=(c[2433530]|0)+f|0;w=m;x=c[9757320+(m<<2)>>2]|0}else{u=100;v=p+112|0;w=n;x=o}c[2433530]=v;c[2113037]=(c[2113037]|0)+u;if((x|0)!=0){o=x;gGC(o|0,9706056,76)|0}c[9752472+(w<<2)>>2]=v;c[14113936+(w<<2)>>2]=c[2076596];c[9669104+(w<<2)>>2]=c[3541536];c[1836236]=-1}}while(0);eOw(0,j>>>1,e);return}if((d-1310720|0)>>>0<65536){j=d>>>1&7;w=e&255;a[9776720+j|0]=w;do{if((j|0)==2){v=e&65535;c[3532340]=v&32;if((v&1|0)!=0){break}v=c[2439330]|0;x=(v|0)==0;if(!x){u=v;gGC(9706056,u|0,76)|0}u=c[2438118]|0;c[2433530]=u;s=c[3528484]|0;c[2076596]=s;r=c[2417276]|0;c[3541536]=r;c[1836236]=0;gGz(9706056,0,76);if(!x){x=v;gGC(x|0,9706056,76)|0}c[2438118]=u;c[3528484]=s;c[2417276]=r;c[1836236]=-1}}while(0);r=c[9718512+(j<<2)>>2]|0;if((r|0)==0){return}gf[r&2047](w);return}if((d-1376256|0)>>>0<65536){w=d>>>1&7;r=e&255;a[9776728+w|0]=r;j=c[9718496+(w<<2)>>2]|0;if((j|0)==0){return}gf[j&2047](r);return}r=d-3014656|0;if(r>>>0<8){j=r>>>1&3;if((j|0)==3){b[4789569]=e;return}else if((j|0)==0){b[4789568]=e;return}else if((j|0)==1){b[4789569]=e;return}else if((j|0)==2){b[4789568]=e;return}else{return}}j=d-3031040|0;if(j>>>0>=32){r=d-3047424|0;if(r>>>0<16){eOw(1,r>>>1,e);return}if((d|0)==1114112){r=c[3532384]|0;if(r>>>0>3){w=c[3532390]|0;s=r>>>2;u=c[3532386]|0;x=0;v=w;while(1){t=c[v>>2]|0;c[v>>2]=c[u>>2];c[u>>2]=t;t=x+1|0;if(t>>>0<s>>>0){u=u+4|0;x=t;v=v+4|0}else{y=w;break}}}else{y=c[3532390]|0}gGz(y|0,-1|0,r|0);return}else if((d|0)==3072e3){c[3532458]=e&7;return}else{return}}d=j>>>1;j=d&8;r=d&4;y=d&3;if((y|0)==1){b[4822417]=e}else if((y|0)==2){b[4822418]=e}else if((y|0)==0){b[4822416]=e}if((j|0)==0){return}b[4822422]=0;j=b[4822416]|0;e=b[4822417]|0;y=e&65535;d=(j&65535)<<16|y;w=b[4822418]|0;if((r|0)!=0){if(w<<16>>16==0){b[4822422]=16384;z=j;A=e}else{e=(d>>>0)/((w&65535)>>>0)|0;z=e>>>16&65535;A=e&65535}b[4822420]=z;b[4822421]=A;return}A=w<<16>>16;if(w<<16>>16==0){b[4822422]=16384;B=d;C=-16384}else{B=(d|0)/(A|0)|0;C=-32768}d=y-(ag(B,A)|0)|0;do{if((B|0)<-32768){b[4822422]=C;D=-32768}else{if((B|0)<=32767){D=B&65535;break}b[4822422]=C;D=32767}}while(0);b[4822420]=D;b[4822421]=d&65535;return}function eF2(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=d-786432|0;if(f>>>0<65536){eOY(f^1,e);return}if((d-1310720|0)>>>0<65536){f=d>>>1&7;a[9776720+f|0]=e;do{if((f|0)==2){g=e&255;c[3532340]=g&32;if((g&1|0)!=0){break}g=c[2439330]|0;h=(g|0)==0;if(!h){i=g;gGC(9706056,i|0,76)|0}i=c[2438118]|0;c[2433530]=i;j=c[3528484]|0;c[2076596]=j;k=c[2417276]|0;c[3541536]=k;c[1836236]=0;gGz(9706056,0,76);if(!h){h=g;gGC(h|0,9706056,76)|0}c[2438118]=i;c[3528484]=j;c[2417276]=k;c[1836236]=-1}}while(0);k=c[9718512+(f<<2)>>2]|0;if((k|0)==0){return}gf[k&2047](e);return}if((d-1376256|0)>>>0<65536){k=d>>>1&7;a[9776728+k|0]=e;f=c[9718496+(k<<2)>>2]|0;if((f|0)==0){return}gf[f&2047](e);return}if((d|0)==1245185){c[3532560]=e&255;return}else if((d|0)==950295){b[4878615]=e&255;c[3532412]=e&255;e=c[2439330]|0;if((e|0)!=0){f=e;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;f=c[2433530]|0;c[2433530]=f+12;e=c[1836236]|0;k=c[9757320+(e<<2)>>2]|0;if((a[k+4188|0]|0)==0){j=gfc(100)|0;i=c[1836236]|0;l=j;m=(c[2433530]|0)+j|0;n=i;o=c[9757320+(i<<2)>>2]|0}else{l=100;m=f+112|0;n=e;o=k}c[2433530]=m;c[2113036]=(c[2113036]|0)+l;if((o|0)!=0){l=o;gGC(l|0,9706056,76)|0}c[9752472+(n<<2)>>2]=m;c[14113936+(n<<2)>>2]=c[2076596];c[9669104+(n<<2)>>2]=c[3541536];c[1836236]=-1;if((c[3532326]|0)==0){return}n=c[2439331]|0;if((n|0)!=0){m=n;gGC(9706056,m|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;m=c[2433530]|0;c[2433530]=m+12;n=c[1836236]|0;l=c[9757320+(n<<2)>>2]|0;if((a[l+4188|0]|0)==0){o=gfc(100)|0;k=c[1836236]|0;p=o;q=(c[2433530]|0)+o|0;r=k;s=c[9757320+(k<<2)>>2]|0}else{p=100;q=m+112|0;r=n;s=l}c[2433530]=q;c[2113037]=(c[2113037]|0)+p;if((s|0)!=0){p=s;gGC(p|0,9706056,76)|0}c[9752472+(r<<2)>>2]=q;c[14113936+(r<<2)>>2]=c[2076596];c[9669104+(r<<2)>>2]=c[3541536];c[1836236]=-1;return}else if((d|0)==1114112|(d|0)==1114113){d=c[3532384]|0;if(d>>>0>3){r=c[3532390]|0;q=d>>>2;p=c[3532386]|0;s=0;l=r;while(1){n=c[l>>2]|0;c[l>>2]=c[p>>2];c[p>>2]=n;n=s+1|0;if(n>>>0<q>>>0){p=p+4|0;s=n;l=l+4|0}else{t=r;break}}}else{t=c[3532390]|0}gGz(t|0,-1|0,d|0);return}else{return}}function eF3(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=a-917504|0;L23876:do{if(d>>>0<8){e=d>>>1&3;if((e|0)==3){f=ag(b[4789569]|0,b[4789568]|0)|0;break}else if((e|0)==1){f=b[4789569]|0;break}else if((e|0)==2){f=(ag(b[4789569]|0,b[4789568]|0)|0)>>>16&65535;break}else if((e|0)==0){f=b[4789568]|0;break}else{f=-1;break}}else{e=a-933888|0;if(e>>>0<32){switch(e>>>1&7|0){case 6:{f=b[4822422]|0;break L23876;break};case 5:{f=b[4822421]|0;break L23876;break};case 0:{f=b[4822416]|0;break L23876;break};case 2:{f=b[4822418]|0;break L23876;break};case 1:{f=b[4822417]|0;break L23876;break};case 4:{f=b[4822420]|0;break L23876;break};default:{f=-1;break L23876}}}e=a-950272|0;if(e>>>0<16){switch(e>>>1&15|0){case 2:{f=b[4878624]|0;break L23876;break};case 6:{f=b[4878624]|0;break L23876;break};case 3:{f=b[4878625]|0;break L23876;break};case 4:{f=b[4878626]|0;break L23876;break};case 7:{f=b[4878629]|0;break L23876;break};case 0:{f=b[4878622]|0;break L23876;break};case 1:{f=b[4878623]|0;break L23876;break};case 5:{f=b[4878623]|0;break L23876;break};default:{f=-1;break L23876}}}e=a-3014656|0;if(e>>>0<8){g=e>>>1&3;if((g|0)==1){f=b[4789569]|0;break}else if((g|0)==3){f=ag(b[4789569]|0,b[4789568]|0)|0;break}else if((g|0)==0){f=b[4789568]|0;break}else if((g|0)==2){f=(ag(b[4789569]|0,b[4789568]|0)|0)>>>16&65535;break}else{f=-1;break}}g=a-3031040|0;if(g>>>0>=32){if(!((a|0)==974848|(a|0)==3072e3)){f=0;break}e=c[3532454]|0;h=c[3532456]|0;gGC(e|0,h|0,4096)|0;i=e;e=h;h=0;while(1){j=c[i>>2]|0;c[i>>2]=c[e>>2];c[e>>2]=j;j=h+1|0;if((j|0)<1024){i=i+4|0;e=e+4|0;h=j}else{break}}f=c[3532458]&65535;break}switch(g>>>1&7|0){case 0:{f=b[4822416]|0;break L23876;break};case 2:{f=b[4822418]|0;break L23876;break};case 6:{f=b[4822422]|0;break L23876;break};case 5:{f=b[4822421]|0;break L23876;break};case 1:{f=b[4822417]|0;break L23876;break};case 4:{f=b[4822420]|0;break L23876;break};default:{f=-1;break L23876}}}}while(0);return f|0}function eF4(a){a=a|0;var b=0,d=0,e=0,f=0;if((a-974848|0)>>>0>=2){b=0;return b|0}a=c[3532454]|0;d=c[3532456]|0;gGC(a|0,d|0,4096)|0;e=a;a=d;d=0;while(1){f=c[e>>2]|0;c[e>>2]=c[a>>2];c[a>>2]=f;f=d+1|0;if((f|0)<1024){e=e+4|0;a=a+4|0;d=f}else{break}}b=c[3532458]&255;return b|0}function eF5(a,d){a=a|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=a-917504|0;if(e>>>0<8){f=e>>>1&3;if((f|0)==1){b[4789569]=d;return}else if((f|0)==3){b[4789569]=d;return}else if((f|0)==0){b[4789568]=d;return}else if((f|0)==2){b[4789568]=d;return}else{return}}f=a-933888|0;if(f>>>0<32){e=f>>>1;f=e&8;g=e&4;h=e&3;if((h|0)==2){b[4822418]=d}else if((h|0)==0){b[4822416]=d}else if((h|0)==1){b[4822417]=d}if((f|0)==0){return}b[4822422]=0;f=b[4822416]|0;h=b[4822417]|0;e=h&65535;i=(f&65535)<<16|e;j=b[4822418]|0;if((g|0)!=0){if(j<<16>>16==0){b[4822422]=16384;k=f;l=h}else{h=(i>>>0)/((j&65535)>>>0)|0;k=h>>>16&65535;l=h&65535}b[4822420]=k;b[4822421]=l;return}l=j<<16>>16;if(j<<16>>16==0){b[4822422]=16384;m=i;n=-16384}else{m=(i|0)/(l|0)|0;n=-32768}i=e-(ag(m,l)|0)|0;do{if((m|0)<-32768){b[4822422]=n;o=-32768}else{if((m|0)<=32767){o=m&65535;break}b[4822422]=n;o=32767}}while(0);b[4822420]=o;b[4822421]=i&65535;return}i=a-950272|0;if(i>>>0<16){eOw(1,i>>>1,d);return}i=a-3014656|0;if(i>>>0<8){o=i>>>1&3;if((o|0)==1){b[4789569]=d;return}else if((o|0)==3){b[4789569]=d;return}else if((o|0)==0){b[4789568]=d;return}else if((o|0)==2){b[4789568]=d;return}else{return}}o=a-3031040|0;if(o>>>0>=32){if(!((a|0)==974848|(a|0)==3072e3)){return}c[3532458]=d&7;return}a=o>>>1;o=a&8;i=a&4;n=a&3;if((n|0)==0){b[4822416]=d}else if((n|0)==2){b[4822418]=d}else if((n|0)==1){b[4822417]=d}if((o|0)==0){return}b[4822422]=0;o=b[4822416]|0;d=b[4822417]|0;n=d&65535;a=(o&65535)<<16|n;m=b[4822418]|0;if((i|0)!=0){if(m<<16>>16==0){b[4822422]=16384;p=o;q=d}else{d=(a>>>0)/((m&65535)>>>0)|0;p=d>>>16&65535;q=d&65535}b[4822420]=p;b[4822421]=q;return}q=m<<16>>16;if(m<<16>>16==0){b[4822422]=16384;r=a;s=-16384}else{r=(a|0)/(q|0)|0;s=-32768}a=n-(ag(r,q)|0)|0;do{if((r|0)<-32768){b[4822422]=s;t=-32768}else{if((r|0)<=32767){t=r&65535;break}b[4822422]=s;t=32767}}while(0);b[4822420]=t;b[4822421]=a&65535;return}function eF6(a,b){a=a|0;b=b|0;if(!((a|0)==974849|(a|0)==3072e3)){return}c[3532458]=b&7;return}function eF7(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>30){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6979812+(b*112|0)>>2];c[a+104>>2]=c[6979816+(b*112|0)>>2];c[a+108>>2]=c[6979820+(b*112|0)>>2];d=0;return d|0}function eF8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<31&(d|0)==0)){e=1;return e|0}c[a>>2]=6979712+(b*112|0);e=0;return e|0}function eF9(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5623088+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eGa(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>54){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6983184+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eGb(){c[3532482]=2994;return eOx()|0}function eGc(){gGz(9776720|0,0|0,16|0);gGz(9718512|0,0|0,16|0);gGz(9718496|0,0|0,16|0);gGz(9720032|0,0|0,32|0);a[14108408]=0;c[2433373]=0;c[2433372]=0;eOI()|0;return 0}function eGd(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=i;i=i+48|0;e=d|0;f=d+16|0;g=d+32|0;if((b|0)!=0){c[b>>2]=169568}if((a&64|0)==0){h=eOS(a,b)|0;i=d;return 0}gGz(g|0,0,12);c[g>>2]=9776720;c[g+4>>2]=16;c[g+12>>2]=444776;gj[c[2076592]&4095](g)|0;gGz(f|0,0,12);c[f>>2]=9733488;c[f+4>>2]=8;c[f+12>>2]=443936;gj[c[2076592]&4095](f)|0;gGz(e|0,0,12);c[e>>2]=14108408;c[e+4>>2]=1;c[e+12>>2]=443176;gj[c[2076592]&4095](e)|0;h=eOS(a,b)|0;i=d;return 0}function eGe(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>30){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6447156+(b*112|0)>>2];c[a+104>>2]=c[6447160+(b*112|0)>>2];c[a+108>>2]=c[6447164+(b*112|0)>>2];d=0;return d|0}function eGf(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<31&(d|0)==0)){e=1;return e|0}c[a>>2]=6447056+(b*112|0);e=0;return e|0}function eGg(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>27){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4304068+(b*112|0)>>2];c[a+104>>2]=c[4304072+(b*112|0)>>2];c[a+108>>2]=c[4304076+(b*112|0)>>2];d=0;return d|0}function eGh(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<28&(d|0)==0)){e=1;return e|0}c[a>>2]=4303968+(b*112|0);e=0;return e|0}function eGi(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1327320+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eGj(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>57){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4307104+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eGk(){var b=0;c[3532482]=2240;b=eOx()|0;if((b|0)!=0){return b|0}a[7461544]=0;return b|0}function eGl(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>27){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5619388+(b*112|0)>>2];c[a+104>>2]=c[5619392+(b*112|0)>>2];c[a+108>>2]=c[5619396+(b*112|0)>>2];d=0;return d|0}function eGm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<28&(d|0)==0)){e=1;return e|0}c[a>>2]=5619288+(b*112|0);e=0;return e|0}function eGn(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>54){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5622424+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eGo(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>29){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5371916+(b*112|0)>>2];c[a+104>>2]=c[5371920+(b*112|0)>>2];c[a+108>>2]=c[5371924+(b*112|0)>>2];d=0;return d|0}function eGp(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<30&(d|0)==0)){e=1;return e|0}c[a>>2]=5371816+(b*112|0);e=0;return e|0}function eGq(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1875752+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eGr(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>49){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5375176+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eGs(){c[3532482]=1688;return eOx()|0}function eGt(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>29){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3895404+(b*112|0)>>2];c[a+104>>2]=c[3895408+(b*112|0)>>2];c[a+108>>2]=c[3895412+(b*112|0)>>2];d=0;return d|0}function eGu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<30&(d|0)==0)){e=1;return e|0}c[a>>2]=3895304+(b*112|0);e=0;return e|0}function eGv(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>29){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3892044+(b*112|0)>>2];c[a+104>>2]=c[3892048+(b*112|0)>>2];c[a+108>>2]=c[3892052+(b*112|0)>>2];d=0;return d|0}function eGw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<30&(d|0)==0)){e=1;return e|0}c[a>>2]=3891944+(b*112|0);e=0;return e|0}function eGx(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>31){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3802212+(b*112|0)>>2];c[a+104>>2]=c[3802216+(b*112|0)>>2];c[a+108>>2]=c[3802220+(b*112|0)>>2];d=0;return d|0}function eGy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<32&(d|0)==0)){e=1;return e|0}c[a>>2]=3802112+(b*112|0);e=0;return e|0}function eGz(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1235680+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eGA(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>55){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3805696+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eGB(){var b=0;c[2430013]=1284;c[2429631]=260;c[3532514]=1676;b=eOx()|0;if((b|0)!=0){return b|0}a[7461544]=0;h[745421]=.43;c[2436794]=2;h[745420]=.43;c[2436792]=1;return b|0}function eGC(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>29){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5299852+(b*112|0)>>2];c[a+104>>2]=c[5299856+(b*112|0)>>2];c[a+108>>2]=c[5299860+(b*112|0)>>2];d=0;return d|0}function eGD(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<30&(d|0)==0)){e=1;return e|0}c[a>>2]=5299752+(b*112|0);e=0;return e|0}function eGE(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1844288+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eGF(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>58){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5303112+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eGG(){var b=0,d=0,e=0,f=0,g=0;c[2113302]=2;a[801640]=0;b=c[642608+(c[2436]<<2)>>2]|0;d=c[b+128>>2]|0;if((c[b+52>>2]&4|0)==0){c[2440576]=d;e=c[b+132>>2]|0;c[2440574]=e;f=d;g=e}else{c[2440574]=d;e=c[b+132>>2]|0;c[2440576]=e;f=e;g=d}d=(((f|0)/2|0)<<8)-1792|0;f=(((g|0)/2|0)<<8)-2048|0;c[3542196]=d;c[3542192]=f;c[3542197]=d;c[3542193]=f;c[3542198]=d;c[3542194]=f;c[3542199]=d;c[3542195]=f;c[3532482]=2610;return eOx()|0}function eGH(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>29){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3793108+(b*112|0)>>2];c[a+104>>2]=c[3793112+(b*112|0)>>2];c[a+108>>2]=c[3793116+(b*112|0)>>2];d=0;return d|0}function eGI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<30&(d|0)==0)){e=1;return e|0}c[a>>2]=3793008+(b*112|0);e=0;return e|0}function eGJ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>29){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3789748+(b*112|0)>>2];c[a+104>>2]=c[3789752+(b*112|0)>>2];c[a+108>>2]=c[3789756+(b*112|0)>>2];d=0;return d|0}function eGK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<30&(d|0)==0)){e=1;return e|0}c[a>>2]=3789648+(b*112|0);e=0;return e|0}function eGL(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>29){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5121332+(b*112|0)>>2];c[a+104>>2]=c[5121336+(b*112|0)>>2];c[a+108>>2]=c[5121340+(b*112|0)>>2];d=0;return d|0}function eGM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<30&(d|0)==0)){e=1;return e|0}c[a>>2]=5121232+(b*112|0);e=0;return e|0}function eGN(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1760944+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eGO(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>54){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5124592+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eGP(){c[3532482]=810;return eOx()|0}function eGQ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>33){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7123100+(b*112|0)>>2];c[a+104>>2]=c[7123104+(b*112|0)>>2];c[a+108>>2]=c[7123108+(b*112|0)>>2];d=0;return d|0}function eGR(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<34&(d|0)==0)){e=1;return e|0}c[a>>2]=7123e3+(b*112|0);e=0;return e|0}function eGS(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1875752+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eGT(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>57){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7126808+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eGU(){var b=0;c[3532482]=2066;b=eOx()|0;if((b|0)!=0){return b|0}a[7461544]=0;return b|0}function eGV(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>33){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6698572+(b*112|0)>>2];c[a+104>>2]=c[6698576+(b*112|0)>>2];c[a+108>>2]=c[6698580+(b*112|0)>>2];d=0;return d|0}function eGW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<34&(d|0)==0)){e=1;return e|0}c[a>>2]=6698472+(b*112|0);e=0;return e|0}function eGX(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>33){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6702380+(b*112|0)>>2];c[a+104>>2]=c[6702384+(b*112|0)>>2];c[a+108>>2]=c[6702388+(b*112|0)>>2];d=0;return d|0}function eGY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<34&(d|0)==0)){e=1;return e|0}c[a>>2]=6702280+(b*112|0);e=0;return e|0}function eGZ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>33){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6690956+(b*112|0)>>2];c[a+104>>2]=c[6690960+(b*112|0)>>2];c[a+108>>2]=c[6690964+(b*112|0)>>2];d=0;return d|0}function eG_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<34&(d|0)==0)){e=1;return e|0}c[a>>2]=6690856+(b*112|0);e=0;return e|0}function eG$(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>33){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6067340+(b*112|0)>>2];c[a+104>>2]=c[6067344+(b*112|0)>>2];c[a+108>>2]=c[6067348+(b*112|0)>>2];d=0;return d|0}function eG0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<34&(d|0)==0)){e=1;return e|0}c[a>>2]=6067240+(b*112|0);e=0;return e|0}function eG1(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>33){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6063532+(b*112|0)>>2];c[a+104>>2]=c[6063536+(b*112|0)>>2];c[a+108>>2]=c[6063540+(b*112|0)>>2];d=0;return d|0}function eG2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<34&(d|0)==0)){e=1;return e|0}c[a>>2]=6063432+(b*112|0);e=0;return e|0}function eG3(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>33){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6694764+(b*112|0)>>2];c[a+104>>2]=c[6694768+(b*112|0)>>2];c[a+108>>2]=c[6694772+(b*112|0)>>2];d=0;return d|0}function eG4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<34&(d|0)==0)){e=1;return e|0}c[a>>2]=6694664+(b*112|0);e=0;return e|0}function eG5(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>33){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6071148+(b*112|0)>>2];c[a+104>>2]=c[6071152+(b*112|0)>>2];c[a+108>>2]=c[6071156+(b*112|0)>>2];d=0;return d|0}function eG6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<34&(d|0)==0)){e=1;return e|0}c[a>>2]=6071048+(b*112|0);e=0;return e|0}function eG7(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>32){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3315084+(b*112|0)>>2];c[a+104>>2]=c[3315088+(b*112|0)>>2];c[a+108>>2]=c[3315092+(b*112|0)>>2];d=0;return d|0}function eG8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<33&(d|0)==0)){e=1;return e|0}c[a>>2]=3314984+(b*112|0);e=0;return e|0}function eG9(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1180568+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eHa(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>57){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3318680+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eHb(){c[3532482]=938;return eOx()|0}function eHc(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>31){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1661396+(b*112|0)>>2];c[a+104>>2]=c[1661400+(b*112|0)>>2];c[a+108>>2]=c[1661404+(b*112|0)>>2];d=0;return d|0}function eHd(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<32&(d|0)==0)){e=1;return e|0}c[a>>2]=1661296+(b*112|0);e=0;return e|0}function eHe(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>57){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1664880+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eHf(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=a&65535;if((b|0)==2){a=c[3532570]|0;do{if((a&-16|0)==2048){d=-1}else{e=(a>>>4)+128&255;if((e&255)<32){f=32}else{d=e;break}return f|0}}while(0);f=(d&255)>224?-32:d;return f|0}else if((b|0)==1){d=c[3532568]|0;if((d&-16|0)==2048){g=-1}else{g=(d>>>4)+128&255}f=g<<24>>24==1?0:g;return f|0}else if((b|0)==0){b=c[3532572]|0;do{if(((b>>4)-129|0)>>>0<3841){h=-2}else{g=128-(b>>>4)&255;if((g&255)<32){f=32}else{h=g;break}return f|0}}while(0);f=(h&255)>224?-32:h;return f|0}else{f=0;return f|0}return 0}function eHg(a){a=a|0;var b=0,d=0;b=a&65535;do{if((b|0)==0){a=c[3532572]|0;if((a&-16|0)==2048){d=-1;break}d=(a>>>4)+128&255}else if((b|0)==2){d=(c[3532568]|0)>1?-88:40}else if((b|0)==1){d=(c[3532570]|0)>1?-72:56}else{d=0}}while(0);return d|0}function eHh(a){a=a|0;var b=0,d=0,e=0;b=a&65535;if((b|0)==0){a=c[3532572]|0;if(((a>>4)-129|0)>>>0<3841){d=-2}else{d=128-(a>>>4)&255}a=(d&255)<32?32:d;e=(a&255)>224?-32:a;return e|0}else if((b|0)==2){e=((c[3532568]|0)>1)<<31>>31;return e|0}else if((b|0)==1){e=((c[3532570]|0)>1)<<31>>31;return e|0}else{e=0;return e|0}return 0}function eHi(a){a=a|0;var b=0,d=0;b=a&65535;if((b|0)==1){d=~~(+((c[3542192]>>8)+8|0)/+(c[2440574]|0)*255.0)^-1;return d|0}else if((b|0)==0){d=~~(+((c[3542196]>>8)+8|0)/+(c[2440576]|0)*255.0);return d|0}else if((b|0)==2){d=~~(+((c[3542197]>>8)+8|0)/+(c[2440576]|0)*255.0);return d|0}else if((b|0)==3){d=~~(+((c[3542193]>>8)+8|0)/+(c[2440574]|0)*255.0)^-1;return d|0}else{d=0;return d|0}return 0}function eHj(b){b=b|0;var d=0,e=0,f=0;b=a[14108408]|0;d=b&255;e=a[d+14130137|0]|0;if((b&255)<2){f=(15-e&255)+(a[595760+(c[9733488+((d^1)<<2)>>2]>>4)|0]|0)&255;return f|0}else{f=~e;return f|0}return 0}function eHk(b){b=b|0;a[14108408]=(b&255)>>>5&3;return}function eHl(){var b=0;if((a[14130080]|0)!=0){c[2433372]=(c[2433372]|0)-2;a[14130080]=0}if((a[14130081]|0)!=0){c[2433372]=(c[2433372]|0)+2;a[14130081]=0}if((a[14130082]|0)!=0){c[2433373]=(c[2433373]|0)-2;a[14130082]=0}if((a[14130083]|0)!=0){c[2433373]=(c[2433373]|0)+2;a[14130083]=0}b=c[2433372]|0;do{if((b|0)<0){c[2433372]=126}else{if((b|0)<=126){break}c[2433372]=0}}while(0);b=c[2433373]|0;if((b|0)<0){c[2433373]=126;return}if((b|0)<=126){return}c[2433373]=0;return}function eHm(a){a=a|0;var b=0,d=0;b=a&65535;do{if((b|0)==1){d=(c[3532570]|0)>1?16:-17}else if((b|0)==2){d=(c[3532568]|0)>1?16:-17}else if((b|0)==0){a=c[3532572]|0;if((a&-16|0)==2048){d=-1;break}d=(a>>>4)+128&255}else{d=0}}while(0);return d|0}function eHn(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=a&65535;do{if((b|0)==0){a=c[3532572]|0;if((a&-16|0)==2048){d=-1}else{e=(a>>>4)+128&255;if((e&255)<32){f=32;break}else{d=e}}f=(d&255)>224?-32:d}else if((b|0)==1){e=c[3532570]|0;if(((e>>4)-129|0)>>>0<3841){g=-2}else{a=128-(e>>>4)&255;if((a&255)<64){f=64;break}else{g=a}}f=(g&255)>192?-64:g}else if((b|0)==2){a=c[3532568]|0;if((a&-16|0)==2048){f=-1;break}e=(a>>>4)+128&255;if(e>>>0>192){f=-1;break}f=e>>>0<64?0:-128}else{f=0}}while(0);return f|0}function eHo(a){a=a|0;var b=0,d=0,e=0,f=0;b=a&65535;if((b|0)==0){a=c[3532572]|0;do{if(((a>>4)-129|0)>>>0<3841){d=-2}else{e=128-(a>>>4)&255;if((e&255)<32){f=32}else{d=e;break}return f|0}}while(0);f=(d&255)>224?-32:d;return f|0}else if((b|0)==1){f=((c[3532570]|0)>1)<<31>>31;return f|0}else{f=0;return f|0}return 0}function eHp(a){a=a|0;var c=0,d=0,e=0;c=a-524288|0;L24614:do{if(c>>>0<8){d=c>>>1&3;if((d|0)==2){e=(ag(b[4789565]|0,b[4789564]|0)|0)>>>16&65535;break}else if((d|0)==0){e=b[4789564]|0;break}else if((d|0)==1){e=b[4789565]|0;break}else if((d|0)==3){e=ag(b[4789565]|0,b[4789564]|0)|0;break}else{e=-1;break}}else{d=a-540672|0;if(d>>>0>=32){e=-1;break}switch(d>>>1&7|0){case 5:{e=b[4822413]|0;break L24614;break};case 4:{e=b[4822412]|0;break L24614;break};case 2:{e=b[4822410]|0;break L24614;break};case 6:{e=b[4822414]|0;break L24614;break};case 1:{e=b[4822409]|0;break L24614;break};case 0:{e=b[4822408]|0;break L24614;break};default:{e=-1;break L24614}}}}while(0);return e|0}function eHq(b){b=b|0;var c=0,e=0,f=0,g=0;c=b-1048576|0;L24632:do{if(c>>>0<32){e=c>>>1;switch(e|0){case 1:{if((a[9762359]&2)==0){f=~a[14130136];break L24632}else{f=a[9762345]|0;break L24632}break};case 8:{f=83;break L24632;break};case 13:case 15:{f=a[9762359]|0;break L24632;break};case 9:{f=69;break L24632;break};case 10:{f=71;break L24632;break};case 6:{if((a[9762359]&64)==0){f=a[14130177]|0;break L24632}else{f=a[9762350]|0;break L24632}break};case 0:case 2:case 3:case 4:case 7:{if(((d[9762359]|0)&1<<e|0)==0){f=-1;break L24632}f=a[9762344+e|0]|0;break L24632;break};case 5:{if((a[9762359]&32)==0){f=a[14130176]|0;break L24632}else{f=a[9762349]|0;break L24632}break};case 11:{f=65;break L24632;break};case 12:case 14:{f=a[9762358]|0;break L24632;break};default:{f=-1;break L24632}}}else{e=b-1048640|0;if(e>>>0>=8){f=-1;break}g=14107904+(e>>>1)|0;e=a[g]|0;a[g]=e<<1;f=e&-128}}while(0);return f|0}function eHr(a,c){a=a|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=a-1048576|0;if(d>>>0<32){eHs(d>>>1,c);return}d=a-524288|0;if(d>>>0<8){e=d>>>1&3;if((e|0)==0){b[4789564]=c;return}else if((e|0)==3){b[4789565]=c;return}else if((e|0)==1){b[4789565]=c;return}else if((e|0)==2){b[4789564]=c;return}else{return}}e=a-540672|0;if(e>>>0>=32){return}a=e>>>1;e=a&8;d=a&4;f=a&3;if((f|0)==2){b[4822410]=c}else if((f|0)==1){b[4822409]=c}else if((f|0)==0){b[4822408]=c}if((e|0)==0){return}b[4822414]=0;e=b[4822408]|0;c=b[4822409]|0;f=c&65535;a=(e&65535)<<16|f;g=b[4822410]|0;if((d|0)!=0){if(g<<16>>16==0){b[4822414]=16384;h=e;i=c}else{c=(a>>>0)/((g&65535)>>>0)|0;h=c>>>16&65535;i=c&65535}b[4822412]=h;b[4822413]=i;return}i=g<<16>>16;if(g<<16>>16==0){b[4822414]=16384;j=a;k=-16384}else{j=(a|0)/(i|0)|0;k=-32768}a=f-(ag(j,i)|0)|0;do{if((j|0)<-32768){b[4822414]=k;l=-32768}else{if((j|0)<=32767){l=j&65535;break}b[4822414]=k;l=32767}}while(0);b[4822412]=l;b[4822413]=a&65535;return}function eHs(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0;a[9762344+b|0]=d&255;if((b|0)!=4){return}b=d&65535;c[3532340]=b&128;do{if((b&4|0)!=0){d=c[2394]|0;e=14130368+(d<<2)|0;f=c[e>>2]|0;if((f|0)!=0){gGC(f|0,9104152,280)|0}f=8452240+(d<<2)|0;c[f>>2]=c[2113054];c[2394]=2;c[2112932]=c[3532598];g=c[3532594]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113062];RI();g=c[2394]|0;h=c[14130368+(g<<2)>>2]|0;if((h|0)!=0){gGC(h|0,9104152,280)|0}c[8452240+(g<<2)>>2]=c[2113054];c[2394]=-1;if((d|0)==-1){break}c[2394]=d;c[2112932]=c[14130384+(d<<2)>>2];d=c[e>>2]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[f>>2]}}while(0);do{if((b&8|0)!=0){f=c[2394]|0;d=14130368+(f<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}e=8452240+(f<<2)|0;c[e>>2]=c[2113054];c[2394]=1;c[2112932]=c[3532597];g=c[3532593]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113061];RI();g=c[2394]|0;h=c[14130368+(g<<2)>>2]|0;if((h|0)!=0){gGC(h|0,9104152,280)|0}c[8452240+(g<<2)>>2]=c[2113054];c[2394]=-1;if((f|0)==-1){break}c[2394]=f;c[2112932]=c[14130384+(f<<2)>>2];f=c[d>>2]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[e>>2]}}while(0);if((b&16|0)!=0){return}b=c[2439330]|0;e=(b|0)==0;if(!e){f=b;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;d=c[3528484]|0;c[2076596]=d;g=c[2417276]|0;c[3541536]=g;c[1836236]=0;gGz(9706056,0,76);if(!e){e=b;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=d;c[2417276]=g;c[1836236]=-1;return}function eHt(d,e){d=d|0;e=e|0;var f=0,g=0,h=0;f=d-1048576|0;if(f>>>0<32){eHs(f>>>1,e&255);return}f=d-1048640|0;if(f>>>0<8){g=f>>>1;f=c[3532482]|0;h=(f|0)!=0;if((g|0)==3){if(!h){return}a[14107907]=gj[f&4095]((a[9762348]&3)+3&65535)|0;return}else{if(!h){return}a[14107904+g|0]=gj[f&4095](g&3)|0;return}}if((d|0)!=532481){return}c[3532412]=e&255;e=c[2439330]|0;if((e|0)!=0){d=e;gGC(9706056,d|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;d=(c[2433530]|0)+12|0;c[2433530]=d;e=c[1836236]|0;g=c[9757320+(e<<2)>>2]|0;if((g|0)!=0){f=g;gGC(f|0,9706056,76)|0}c[9752472+(e<<2)>>2]=d;c[14113936+(e<<2)>>2]=c[2076596];c[9669104+(e<<2)>>2]=c[3541536];c[1836236]=-1;return}function eHu(a){a=a|0;var c=0,d=0,e=0;c=a-524288|0;L24784:do{if(c>>>0<8){d=c>>>1&3;if((d|0)==1){e=b[4789569]|0;break}else if((d|0)==2){e=(ag(b[4789569]|0,b[4789568]|0)|0)>>>16&65535;break}else if((d|0)==3){e=ag(b[4789569]|0,b[4789568]|0)|0;break}else if((d|0)==0){e=b[4789568]|0;break}else{e=-1;break}}else{d=a-540672|0;if(d>>>0>=32){e=-1;break}switch(d>>>1&7|0){case 1:{e=b[4822417]|0;break L24784;break};case 6:{e=b[4822422]|0;break L24784;break};case 0:{e=b[4822416]|0;break L24784;break};case 4:{e=b[4822420]|0;break L24784;break};case 2:{e=b[4822418]|0;break L24784;break};case 5:{e=b[4822421]|0;break L24784;break};default:{e=-1;break L24784}}}}while(0);return e|0}function eHv(a,c){a=a|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=a-524288|0;if(d>>>0<8){e=d>>>1&3;if((e|0)==2){b[4789568]=c;return}else if((e|0)==1){b[4789569]=c;return}else if((e|0)==0){b[4789568]=c;return}else if((e|0)==3){b[4789569]=c;return}else{return}}e=a-540672|0;if(e>>>0>=32){return}a=e>>>1;e=a&8;d=a&4;f=a&3;if((f|0)==0){b[4822416]=c}else if((f|0)==1){b[4822417]=c}else if((f|0)==2){b[4822418]=c}if((e|0)==0){return}b[4822422]=0;e=b[4822416]|0;c=b[4822417]|0;f=c&65535;a=(e&65535)<<16|f;g=b[4822418]|0;if((d|0)!=0){if(g<<16>>16==0){b[4822422]=16384;h=e;i=c}else{c=(a>>>0)/((g&65535)>>>0)|0;h=c>>>16&65535;i=c&65535}b[4822420]=h;b[4822421]=i;return}i=g<<16>>16;if(g<<16>>16==0){b[4822422]=16384;j=a;k=-16384}else{j=(a|0)/(i|0)|0;k=-32768}a=f-(ag(j,i)|0)|0;do{if((j|0)<-32768){b[4822422]=k;l=-32768}else{if((j|0)<=32767){l=j&65535;break}b[4822422]=k;l=32767}}while(0);b[4822420]=l;b[4822421]=a&65535;return}function eHw(d){d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=d-524288|0;L24845:do{if(e>>>0<8){f=e>>>1&3;if((f|0)==3){g=ag(b[4789573]|0,b[4789572]|0)|0;break}else if((f|0)==2){g=(ag(b[4789573]|0,b[4789572]|0)|0)>>>16&65535;break}else if((f|0)==1){g=b[4789573]|0;break}else if((f|0)==0){g=b[4789572]|0;break}else{g=-1;break}}else{f=d-540672|0;if(f>>>0>=32){if(!((d|0)==1671168&a[7461528])){g=-1;break}h=c[3532428]|0;i=c[3532426]|0;j=0;while(1){k=c[h>>2]|0;c[h>>2]=c[i>>2];c[i>>2]=k;k=j+1|0;if(k>>>0<512){h=h+4|0;i=i+4|0;j=k}else{g=-1;break L24845}}}switch(f>>>1&7|0){case 1:{g=b[4822425]|0;break L24845;break};case 5:{g=b[4822429]|0;break L24845;break};case 2:{g=b[4822426]|0;break L24845;break};case 4:{g=b[4822428]|0;break L24845;break};case 0:{g=b[4822424]|0;break L24845;break};case 6:{g=b[4822430]|0;break L24845;break};default:{g=-1;break L24845}}}}while(0);return g|0}function eHx(a){a=a|0;var c=0,d=0;c=a-540672|0;L24868:do{if(c>>>0<32){switch(c>>>1&7|0){case 1:{d=b[4822425]&255;break L24868;break};case 6:{d=b[4822430]&255;break L24868;break};case 0:{d=b[4822424]&255;break L24868;break};case 5:{d=b[4822429]&255;break L24868;break};case 2:{d=b[4822426]&255;break L24868;break};case 4:{d=b[4822428]&255;break L24868;break};default:{d=-1;break L24868}}}else{d=-1}}while(0);return d|0}function eHy(a,c){a=a|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=a-524288|0;if(d>>>0<8){e=d>>>1&3;if((e|0)==3){b[4789573]=c;return}else if((e|0)==1){b[4789573]=c;return}else if((e|0)==2){b[4789572]=c;return}else if((e|0)==0){b[4789572]=c;return}else{return}}e=a-540672|0;if(e>>>0>=32){return}a=e>>>1;e=a&8;d=a&4;f=a&3;if((f|0)==1){b[4822425]=c}else if((f|0)==2){b[4822426]=c}else if((f|0)==0){b[4822424]=c}if((e|0)==0){return}b[4822430]=0;e=b[4822424]|0;c=b[4822425]|0;f=c&65535;a=(e&65535)<<16|f;g=b[4822426]|0;if((d|0)!=0){if(g<<16>>16==0){b[4822430]=16384;h=e;i=c}else{c=(a>>>0)/((g&65535)>>>0)|0;h=c>>>16&65535;i=c&65535}b[4822428]=h;b[4822429]=i;return}i=g<<16>>16;if(g<<16>>16==0){b[4822430]=16384;j=a;k=-16384}else{j=(a|0)/(i|0)|0;k=-32768}a=f-(ag(j,i)|0)|0;do{if((j|0)<-32768){b[4822430]=k;l=-32768}else{if((j|0)<=32767){l=j&65535;break}b[4822430]=k;l=32767}}while(0);b[4822428]=l;b[4822429]=a&65535;return}function eHz(a){a=a|0;var b=0,d=0,e=0,f=0;b=a&65535;do{if((b|0)==0){a=c[3532572]|0;if((a&-16|0)==2048){d=-1;break}d=(a>>>4)+128&255}else if((b|0)==2){a=c[3532568]|0;if((a&-16|0)==2048){e=-1}else{f=(a>>>4)+128&255;if(f<<24>>24==0){d=1;break}else{e=f}}d=e<<24>>24<0?0:e}else if((b|0)==1){f=c[3532570]|0;if(((f>>4)-129|0)>>>0<3841){d=-2;break}d=128-(f>>>4)&255}else{d=0}}while(0);return d|0}function eHA(a){a=a|0;var b=0,d=0,e=0,f=0;b=a&65535;if((b|0)==4){a=((c[3532568]|0)>>>4)+128&255;if(a>>>0>192){d=-1;return d|0}d=a>>>0<64?0:-128;return d|0}else if((b|0)==5){a=c[3532572]|0;if((a&-16|0)==2048){e=-1}else{e=(a>>>4)+128&255}a=(e&255)<32?32:e;d=(a&255)>224?-32:a;return d|0}else if((b|0)==3){b=c[3532570]|0;if(((b>>4)-129|0)>>>0<3841){f=-2}else{f=128-(b>>>4)&255}b=(f&255)<64?64:f;d=(b&255)>192?-64:b;return d|0}else{d=0;return d|0}return 0}function eHB(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=a&65535;if((b|0)==2){a=c[3532568]|0;if((a&-16|0)==2048){d=-2}else{d=(a>>>4)+127&255}e=d<<24>>24==-2?-1:d;return e|0}else if((b|0)==1){d=c[3532566]|0;if((d&-16|0)==2048){f=-2}else{f=(d>>>4)+127&255}e=f<<24>>24==-2?-1:f;return e|0}else if((b|0)==5){f=c[3532572]|0;if((f&-16|0)==2048){g=-2}else{g=(f>>>4)+127&255}e=g<<24>>24==-2?-1:g;return e|0}else if((b|0)==3){b=c[3532570]|0;if(((b>>4)-129|0)>>>0<3841){h=-3}else{h=127-(b>>>4)&255}e=h<<24>>24==-2?-1:h;return e|0}else{e=0;return e|0}return 0}function eHC(a){a=a|0;var b=0,d=0,e=0;b=a&65535;if((b|0)==4){d=((c[3532570]|0)>1)<<31>>31;return d|0}else if((b|0)==5){a=c[3532572]|0;if((a&-16|0)==2048){e=-1}else{e=(a>>>4)+128&255}a=(e&255)<32?32:e;d=(a&255)>224?-32:a;return d|0}else if((b|0)==3){d=((c[3532568]|0)>1)<<31>>31;return d|0}else{d=0;return d|0}return 0}function eHD(a){a=a|0;var b=0,d=0;b=a&65535;if((b|0)==3){d=~~(+((c[3542193]>>8)+8|0)/+(c[2440574]|0)*255.0);return d|0}else if((b|0)==2){d=~~(+((c[3542197]>>8)+8|0)/+(c[2440576]|0)*255.0);return d|0}else if((b|0)==1){d=~~(+((c[3542192]>>8)+8|0)/+(c[2440574]|0)*255.0);return d|0}else if((b|0)==0){d=~~(+((c[3542196]>>8)+8|0)/+(c[2440576]|0)*255.0);return d|0}else{d=0;return d|0}return 0}function eHE(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>45){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5382620+(b*112|0)>>2];c[a+104>>2]=c[5382624+(b*112|0)>>2];c[a+108>>2]=c[5382628+(b*112|0)>>2];d=0;return d|0}function eHF(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<46&(d|0)==0)){e=1;return e|0}c[a>>2]=5382520+(b*112|0);e=0;return e|0}function eHG(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1897224+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eHH(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>56){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5387672+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eHI(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0;c[3532482]=1118;c[3532494]=1572864;a=eOx()|0;b=0;while(1){if((b|0)>=1024){d=0;break}e=9638528+(b<<2)|0;if((c[e>>2]|0)==0){f=18824;break}else{b=b+1|0}}do{if((f|0)==18824){b=gGq(786432)|0;c[e>>2]=b;if((b|0)==0){d=0;break}gGz(b|0,0,786432);d=b}}while(0);e=c[3532500]|0;gGC(d|0,e|0,786432)|0;gGz(e|0,0,1572864);gGC(e|0,d|0,524288)|0;b=e+524288|0;g=d+524288|0;gGC(b|0,g|0,131072)|0;b=e+655360|0;gGC(b|0,g|0,131072)|0;b=e+786432|0;gGC(b|0,g|0,131072)|0;b=e+917504|0;gGC(b|0,g|0,131072)|0;g=e+1048576|0;b=d+655360|0;gGC(g|0,b|0,131072)|0;g=e+1179648|0;gGC(g|0,b|0,131072)|0;g=e+1310720|0;gGC(g|0,b|0,131072)|0;g=e+1441792|0;gGC(g|0,b|0,131072)|0;b=0;while(1){if((b|0)>=1024){f=18832;break}h=9638528+(b<<2)|0;if((c[h>>2]|0)==(d|0)){break}else{b=b+1|0}}if((f|0)==18832){return a|0}gGr(d);c[h>>2]=0;return a|0}function eHJ(){gGz(9762344|0,0|0,16|0);c[3526976]=0;eOI()|0;return 0}function eHK(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=i;i=i+32|0;e=d|0;f=d+16|0;if((b|0)!=0){c[b>>2]=169568}if((a&64|0)==0){g=eOS(a,b)|0;i=d;return 0}gGz(f|0,0,12);c[f>>2]=9762344;c[f+4>>2]=16;c[f+12>>2]=401064;gj[c[2076592]&4095](f)|0;gGz(e|0,0,12);c[e>>2]=14107904;c[e+4>>2]=4;c[e+12>>2]=503952;gj[c[2076592]&4095](e)|0;g=eOS(a,b)|0;i=d;return 0}function eHL(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>45){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3912932+(b*112|0)>>2];c[a+104>>2]=c[3912936+(b*112|0)>>2];c[a+108>>2]=c[3912940+(b*112|0)>>2];d=0;return d|0}function eHM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<46&(d|0)==0)){e=1;return e|0}c[a>>2]=3912832+(b*112|0);e=0;return e|0}function eHN(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>45){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1892172+(b*112|0)>>2];c[a+104>>2]=c[1892176+(b*112|0)>>2];c[a+108>>2]=c[1892180+(b*112|0)>>2];d=0;return d|0}function eHO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<46&(d|0)==0)){e=1;return e|0}c[a>>2]=1892072+(b*112|0);e=0;return e|0}function eHP(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>47){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7209964+(b*112|0)>>2];c[a+104>>2]=c[7209968+(b*112|0)>>2];c[a+108>>2]=c[7209972+(b*112|0)>>2];d=0;return d|0}function eHQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<48&(d|0)==0)){e=1;return e|0}c[a>>2]=7209864+(b*112|0);e=0;return e|0}function eHR(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6289032+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eHS(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>55){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7215240+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eHT(){c[3532482]=2212;return eOx()|0}function eHU(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>47){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3901228+(b*112|0)>>2];c[a+104>>2]=c[3901232+(b*112|0)>>2];c[a+108>>2]=c[3901236+(b*112|0)>>2];d=0;return d|0}function eHV(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<48&(d|0)==0)){e=1;return e|0}c[a>>2]=3901128+(b*112|0);e=0;return e|0}function eHW(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1241456+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eHX(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>38){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3906504+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eHY(){c[3532482]=668;return eOx()|0}function eHZ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>51){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6172012+(b*112|0)>>2];c[a+104>>2]=c[6172016+(b*112|0)>>2];c[a+108>>2]=c[6172020+(b*112|0)>>2];d=0;return d|0}function eH_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<52&(d|0)==0)){e=1;return e|0}c[a>>2]=6171912+(b*112|0);e=0;return e|0}function eH$(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3651568+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eH0(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>55){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6177736+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eH1(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;c[3532482]=530;a[7461592]=1;c[3532494]=1572864;b=eOx()|0;d=0;while(1){if((d|0)>=1024){e=0;break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==0){g=18948;break}else{d=d+1|0}}do{if((g|0)==18948){d=gGq(786432)|0;c[f>>2]=d;if((d|0)==0){e=0;break}gGz(d|0,0,786432);e=d}}while(0);f=c[3532500]|0;gGC(e|0,f|0,786432)|0;gGz(f|0,0,1572864);gGC(f|0,e|0,524288)|0;d=f+524288|0;h=e+524288|0;gGC(d|0,h|0,131072)|0;d=f+655360|0;gGC(d|0,h|0,131072)|0;d=f+786432|0;gGC(d|0,h|0,131072)|0;d=f+917504|0;gGC(d|0,h|0,131072)|0;h=f+1048576|0;d=e+655360|0;gGC(h|0,d|0,131072)|0;h=f+1179648|0;gGC(h|0,d|0,131072)|0;h=f+1310720|0;gGC(h|0,d|0,131072)|0;h=f+1441792|0;gGC(h|0,d|0,131072)|0;d=0;while(1){if((d|0)>=1024){g=18955;break}i=9638528+(d<<2)|0;if((c[i>>2]|0)==(e|0)){break}else{d=d+1|0}}if((g|0)==18955){return b|0}gGr(e);c[i>>2]=0;return b|0}function eH2(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>51){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5161524+(b*112|0)>>2];c[a+104>>2]=c[5161528+(b*112|0)>>2];c[a+108>>2]=c[5161532+(b*112|0)>>2];d=0;return d|0}function eH3(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<52&(d|0)==0)){e=1;return e|0}c[a>>2]=5161424+(b*112|0);e=0;return e|0}function eH4(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>51){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5155052+(b*112|0)>>2];c[a+104>>2]=c[5155056+(b*112|0)>>2];c[a+108>>2]=c[5155060+(b*112|0)>>2];d=0;return d|0}function eH5(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<52&(d|0)==0)){e=1;return e|0}c[a>>2]=5154952+(b*112|0);e=0;return e|0}function eH6(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>53){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5160776+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eH7(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>51){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5148580+(b*112|0)>>2];c[a+104>>2]=c[5148584+(b*112|0)>>2];c[a+108>>2]=c[5148588+(b*112|0)>>2];d=0;return d|0}function eH8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<52&(d|0)==0)){e=1;return e|0}c[a>>2]=5148480+(b*112|0);e=0;return e|0}function eH9(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>53){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5154304+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eIa(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>37){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6150684+(b*112|0)>>2];c[a+104>>2]=c[6150688+(b*112|0)>>2];c[a+108>>2]=c[6150692+(b*112|0)>>2];d=0;return d|0}function eIb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<38&(d|0)==0)){e=1;return e|0}c[a>>2]=6150584+(b*112|0);e=0;return e|0}function eIc(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3568776+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eId(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>42){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6154840+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eIe(){var b=0,d=0,e=0,f=0,g=0;c[2113302]=2;a[801640]=1;b=c[642608+(c[2436]<<2)>>2]|0;d=c[b+128>>2]|0;if((c[b+52>>2]&4|0)==0){c[2440576]=d;e=c[b+132>>2]|0;c[2440574]=e;f=d;g=e}else{c[2440574]=d;e=c[b+132>>2]|0;c[2440576]=e;f=e;g=d}d=(((f|0)/2|0)<<8)-1792|0;f=(((g|0)/2|0)<<8)-2048|0;c[3542196]=d;c[3542192]=f;c[3542197]=d;c[3542193]=f;c[3542198]=d;c[3542194]=f;c[3542199]=d;c[3542195]=f;c[3532482]=2568;return eOx()|0}function eIf(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>37){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5106092+(b*112|0)>>2];c[a+104>>2]=c[5106096+(b*112|0)>>2];c[a+108>>2]=c[5106100+(b*112|0)>>2];d=0;return d|0}function eIg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<38&(d|0)==0)){e=1;return e|0}c[a>>2]=5105992+(b*112|0);e=0;return e|0}function eIh(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>47){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3344620+(b*112|0)>>2];c[a+104>>2]=c[3344624+(b*112|0)>>2];c[a+108>>2]=c[3344628+(b*112|0)>>2];d=0;return d|0}function eIi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<48&(d|0)==0)){e=1;return e|0}c[a>>2]=3344520+(b*112|0);e=0;return e|0}function eIj(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>55){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3349896+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eIk(b){b=b|0;return((b&255)==0?a[9549920]|0:0)|0}function eIl(b,d){b=b|0;d=d|0;if((b&255)!=0){return}a[c[2409628]|0]=d;return}function eIm(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2927712:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function eIn(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2927712:0;e=0;return e|0}function eIo(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6924064+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eIp(){var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;d=i;i=i+120|0;e=d|0;f=d+112|0;c[2414894]=0;c[2385880]=0;c[3529928]=65536;c[2414596]=65544;c[2386034]=65544;c[2409628]=67592;c[2411548]=67593;g=0;while(1){if((g|0)>=1024){break}h=9638528+(g<<2)|0;if((c[h>>2]|0)==0){j=19096;break}else{g=g+1|0}}do{if((j|0)==19096){g=gGq(67593)|0;c[h>>2]=g;if((g|0)==0){break}c[2414894]=g;gGz(g|0,0,67593);c[2385880]=g;c[3529928]=g+65536;k=g+65544|0;c[2414596]=k;c[2386034]=k;c[2409628]=g+67592;k=g+67593|0;c[2411548]=k;c[2414090]=k;if((c[3542200]|0)==0){l=1;i=d;return l|0}k=e+108|0;c[k>>2]=0;m=e+100|0;c[m>>2]=0;n=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[n&16383](e,0)|0;do{if((c[k>>2]|0)!=0){n=c[m>>2]|0;c[f>>2]=9534384;o=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[o&16383](f,0,0)|0;if((n|0)<1){l=1;i=d;return l|0}if((gzL(g,0,0)|0)==0){break}else{l=1}i=d;return l|0}}while(0);fwR(0);g=c[2439330]|0;m=(g|0)==0;if(!m){k=g;gGC(9706056,k|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];k=c[3528484]|0;c[2076596]=k;n=c[2417276]|0;c[3541536]=n;c[1836236]=0;o=c[2385880]|0;p=0;q=0;while(1){c[g+76+(q<<2)>>2]=o+(q<<8);r=p+1&65535;if((r&65535)>63){s=0;t=0;break}else{p=r;q=r&65535}}while(1){q=o+(t<<8)|0;c[g+76+(t+512<<2)>>2]=q;c[g+76+(t+768<<2)>>2]=q;q=s+1&65535;if((q&65535)>63){break}else{s=q;t=q&65535}}o=c[2386034]|0;c[g+588>>2]=o;q=o+256|0;c[g+592>>2]=q;p=o+512|0;c[g+596>>2]=p;r=o+768|0;c[g+600>>2]=r;u=o+1024|0;c[g+604>>2]=u;v=o+1280|0;c[g+608>>2]=v;w=o+1536|0;c[g+612>>2]=w;x=o+1792|0;c[g+616>>2]=x;c[g+1612>>2]=o;c[g+1616>>2]=q;c[g+1620>>2]=p;c[g+1624>>2]=r;c[g+1628>>2]=u;c[g+1632>>2]=v;c[g+1636>>2]=w;c[g+1640>>2]=x;c[g+2636>>2]=o;c[g+3660>>2]=o;c[g+2640>>2]=q;c[g+3664>>2]=q;c[g+2644>>2]=p;c[g+3668>>2]=p;c[g+2648>>2]=r;c[g+3672>>2]=r;c[g+2652>>2]=u;c[g+3676>>2]=u;c[g+2656>>2]=v;c[g+3680>>2]=v;c[g+2660>>2]=w;c[g+3684>>2]=w;c[g+2664>>2]=x;c[g+3688>>2]=x;c[g+4176>>2]=1486;c[g+4172>>2]=1796;if(!m){x=g;gGC(x|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=k;c[2417276]=n;c[1836236]=-1;x=c[642608+(c[2436]<<2)>>2]|0;w=c[x+128>>2]|0;if((c[x+52>>2]&4|0)==0){c[2113068]=w;v=c[x+132>>2]|0;c[2113070]=v;c[2443814]=w;c[2440436]=v;y=w;z=v}else{c[2113070]=w;v=c[x+132>>2]|0;c[2113068]=v;c[2440436]=w;c[2443814]=v;y=v;z=w}w=ag(y<<1,z)|0;v=gGq(w)|0;c[2112926]=v;if((v|0)!=0){gGz(v|0,0,w|0)}a[9623744]=0;w=c[2414596]|0;gGz(w|0,0,(c[2411548]|0)-w|0);w=c[2439330]|0;v=(w|0)==0;if(!v){x=w;gGC(9706056,x|0,76)|0}x=c[2438118]|0;c[2433530]=x;u=c[3528484]|0;c[2076596]=u;r=c[2417276]|0;c[3541536]=r;c[1836236]=0;gGz(9706056,0,76);if(!v){v=w;gGC(v|0,9706056,76)|0}c[2438118]=x;c[3528484]=u;c[2417276]=r;c[1836236]=-1;l=0;i=d;return l|0}}while(0);c[2414894]=0;l=1;i=d;return l|0}function eIq(){var a=0,b=0,d=0,e=0;c[2113070]=0;c[2113068]=0;a=c[2112926]|0;if((a|0)!=0){gGr(a);c[2112926]=0}fwZ();a=c[2414894]|0;b=0;while(1){if((b|0)>=1024){d=19133;break}e=9638528+(b<<2)|0;if((c[e>>2]|0)==(a|0)){break}else{b=b+1|0}}if((d|0)==19133){c[2414894]=0;return 0}gGr(a);c[e>>2]=0;c[2414894]=0;return 0}function eIr(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;if((a[9623744]|0)==0){d=c[2439330]|0}else{a[9623744]=0;e=c[2414596]|0;gGz(e|0,0,(c[2411548]|0)-e|0);e=c[2439330]|0;f=(e|0)==0;if(!f){g=e;gGC(9706056,g|0,76)|0}g=c[2438118]|0;c[2433530]=g;h=c[3528484]|0;c[2076596]=h;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);if(!f){f=e;gGC(f|0,9706056,76)|0}c[2438118]=g;c[3528484]=h;c[2417276]=i;c[1836236]=-1;d=e}a[9549920]=(a[9632808]|-2)^1^a[9632809]<<1&2^a[9632810]<<2&4^a[9632811]<<3&8^a[9632812]<<4&16^a[9632813]<<5&32^a[9632814]<<6&64^a[9632815]<<7;if((d|0)!=0){e=d;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;e=c[2438118]|0;c[2433530]=e;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;if((a[d+4188|0]|0)==0){d=gfc(66666)|0;j=(c[2433530]|0)+d|0}else{j=e+66666|0}c[2433530]=j;a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0;j=c[1836236]|0;e=c[9757320+(j<<2)>>2]|0;if((e|0)!=0){d=e;gGC(d|0,9706056,76)|0}c[9752472+(j<<2)>>2]=c[2433530];c[14113936+(j<<2)>>2]=c[2076596];c[9669104+(j<<2)>>2]=c[3541536];c[1836236]=-1;if((c[2112968]|0)==0){return 0}eIs()|0;return 0}function eIs(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((a[9547192]|0)!=0){e=c[2409628]|0;f=d[e]|0;g=c[3529928]|0;c[g>>2]=((f&16|0)!=0?224:0)|((f&32|0)!=0?31:0);f=d[e]|0;c[g+4>>2]=((f&2|0)!=0?224:0)|((f&4|0)!=0?31:0)}f=c[2386034]|0;g=c[2113068]|0;e=c[2113070]|0;h=c[2112926]|0;i=0;do{j=i>>4;k=d[f+i|0]|0;l=j<<9;m=l|256;n=(j<<1|0)<(e|0);j=i<<4&240;o=0;while(1){if((j|0)<=(g|0)&n){p=k>>>((7-o|0)>>>0)&1;b[h+((j|l)<<1)>>1]=p;q=j+1|0;b[h+((q|l)<<1)>>1]=p;b[h+((j|m)<<1)>>1]=p;b[h+((q|m)<<1)>>1]=p}p=o+1|0;if((p|0)>=8){break}j=j+2|0;o=p}i=i+1|0;}while((i|0)<1536);R8(c[3529928]|0);return 0}function eIt(a,b){a=a|0;b=b|0;var d=0,e=0;d=i;i=i+16|0;e=d|0;if((b|0)!=0){c[b>>2]=169730}if((a&96|0)==0){i=d;return 0}gGz(e|0,0,12);b=c[2414596]|0;c[e>>2]=b;c[e+4>>2]=(c[2411548]|0)-b;c[e+12>>2]=162152;gj[c[2076592]&4095](e)|0;fw$(a);i=d;return 0}function eIu(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?2927824:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function eIv(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?2927824:0;e=0;return e|0}function eIw(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=b-12582912|0;if(e>>>0>=16){f=-1;return f|0}b=e>>>1;if((b|0)==2|(b|0)==3){a[14127616]=0;f=13824;return f|0}else if((b|0)==0|(b|0)==1){a[14127616]=0;b=a[14127608]&15;if((b|0)==4){e=c[3531908]|0;g=e&126;h=c[3531880]|0;i=(d[h+g|0]|0)<<8|(d[h+(g|1)|0]|0);j=e}else if((b|0)==0){b=c[3531908]|0;e=b&65534;g=c[3531882]|0;i=(d[g+e|0]|0)<<8|(d[g+(e|1)|0]|0);j=b}else{i=0;j=c[3531908]|0}c[3531908]=(d[14165191]|0)+j;f=i;return f|0}else{f=0;return f|0}return 0}function eIx(a){a=a|0;var b=0,c=0;b=a-10747904|0;if(b>>>0<32){c=eIy(b>>>1)|0;return c|0}b=a-14942208|0;if(b>>>0>=32){c=-1;return c|0}c=eIy(b>>>1)|0;return c|0}function eIy(b){b=b|0;var c=0;L25469:do{switch(b|0){case 5:{if((a[9762343]&32)==0){c=a[14130176]|0;break L25469}else{c=a[9762333]|0;break L25469}break};case 6:{if((a[9762343]&64)==0){c=a[14130177]|0;break L25469}else{c=a[9762334]|0;break L25469}break};case 1:{if((a[9762343]&2)==0){c=~a[14130138];break L25469}else{c=a[9762329]|0;break L25469}break};case 2:{if((a[9762343]&4)==0){c=~a[14130139];break L25469}else{c=a[9762330]|0;break L25469}break};case 9:{c=69;break};case 10:{c=71;break};case 11:{c=65;break};case 12:case 14:{c=a[9762342]|0;break};case 13:case 15:{c=a[9762343]|0;break};case 8:{c=83;break};case 4:{if((a[9762343]&16)==0){c=~a[14130136];break L25469}else{c=a[9762332]|0;break L25469}break};case 0:{if((a[9762343]&1)==0){c=~a[14130137];break L25469}else{c=a[9762328]|0;break L25469}break};case 3:case 7:{if(((d[9762343]|0)&1<<b|0)==0){c=-1;break L25469}c=a[9762328+b|0]|0;break};default:{c=-1}}}while(0);return c|0}function eIz(a,b){a=a|0;b=b|0;var d=0;d=a-4194304|0;if(d>>>0<65536){eOX(d,b);return}d=a-12582912|0;if(d>>>0<16){eFc(d>>>1,b);return}if((a|0)!=14950400){return}c[3532304]=b&255;return}function eIA(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=d-4194304|0;if(f>>>0<65536){eOY(f^1,e);return}f=d-4063232|0;if(f>>>0<32){g=f>>>1;if(f>>>0>=16){f=e&255;h=f>>>0<(c[3532380]|0)>>>18>>>0?f<<1:510;f=g<<1;c[14129568+(f-16<<2)>>2]=h;c[14129568+(f-15<<2)>>2]=h|1;return}h=(c[3532508]|0)>>>10;f=e&255;if(f>>>0<h>>>0){i=e&255}else{i=((f>>>0)%(h>>>0)|0)&65535}h=14129432+(g<<2)|0;g=i&65535;if((c[h>>2]|0)==(g|0)){return}c[h>>2]=g;a[7461568]=1;a[7461576]=1;a[7461552]=1;a[7461560]=1;return}g=d-10747904|0;if(g>>>0<8192){eIB(g>>>1,e&255);return}g=d-12582912|0;if(g>>>0<16){eFc(g>>>1,e&255);return}g=d-14942208|0;if(g>>>0<8192){eIB(g>>>1,e&255);return}if((d|0)==10756097|(d|0)==14950401){c[3532304]=e&255;return}else if((d|0)==16646151){c[3532412]=e&255;e=c[2439330]|0;if((e|0)!=0){d=e;gGC(9706056,d|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;d=(c[2433530]|0)+12|0;c[2433530]=d;e=c[1836236]|0;g=c[9757320+(e<<2)>>2]|0;if((g|0)!=0){h=g;gGC(h|0,9706056,76)|0}c[9752472+(e<<2)>>2]=d;c[14113936+(e<<2)>>2]=c[2076596];c[9669104+(e<<2)>>2]=c[3541536];c[1836236]=-1;return}else{return}}function eIB(b,d){b=b|0;d=d|0;var e=0,f=0;e=b&15;b=9762328+e|0;f=a[b]|0;a[b]=d&255;if((e|0)==14){b=d&65535;c[3532340]=b&2;if(((f&255^b)&4|0)==0){return}c[3532306]=b&4;return}else if((e|0)==7){e=d&65535;d=e<<2&60;b=e>>>4<<2&60;if((c[3532358]|0)!=(d|0)){c[3532358]=d;a[7461568]=1;a[7461576]=1;a[7461552]=1;a[7461560]=1}if((c[3532362]|0)!=(b|0)){c[3532362]=b;a[7461568]=1;a[7461576]=1;a[7461552]=1;a[7461560]=1}e=d|1;if((c[3532359]|0)!=(e|0)){c[3532359]=e;a[7461568]=1;a[7461576]=1;a[7461552]=1;a[7461560]=1}e=b|1;if((c[3532363]|0)!=(e|0)){c[3532363]=e;a[7461568]=1;a[7461576]=1;a[7461552]=1;a[7461560]=1}e=d|2;if((c[3532360]|0)!=(e|0)){c[3532360]=e;a[7461568]=1;a[7461576]=1;a[7461552]=1;a[7461560]=1}e=b|2;if((c[3532364]|0)!=(e|0)){c[3532364]=e;a[7461568]=1;a[7461576]=1;a[7461552]=1;a[7461560]=1}e=d|3;if((c[3532361]|0)!=(e|0)){c[3532361]=e;a[7461568]=1;a[7461576]=1;a[7461552]=1;a[7461560]=1}e=b|3;if((c[3532365]|0)==(e|0)){return}c[3532365]=e;a[7461568]=1;a[7461576]=1;a[7461552]=1;a[7461560]=1;return}else{return}}function eIC(a){a=a|0;var b=0,c=0;b=a-10485760|0;if(b>>>0>=32){c=-1;return c|0}c=eIy(b>>>1)|0;return c|0}function eID(a,b){a=a|0;b=b|0;var d=0;d=a-10485760|0;if(d>>>0<8192){eIB(d>>>1,b&255);return}if((a|0)!=10494209){return}c[3532304]=b&255;return}function eIE(b){b=b|0;var c=0;if((b|0)==14954529){c=~a[14130139]}else if((b|0)==14954533){c=~a[14130141]}else if((b|0)==14954531){c=~a[14130140]}else{c=-1}return c|0}function eIF(b){b=b|0;var c=0;if((b|0)==14954513|(b|0)==14954515|(b|0)==14954517|(b|0)==14954519){b=a[14164832]|0;a[14164832]=b<<1;c=b|127}else{c=-1}return c|0}function eIG(b,d){b=b|0;d=d|0;var e=0.0,f=0.0;switch(b|0){case 14954529:{c[3532560]=d&1;return};case 14954517:{if((c[3532560]|0)==0){e=+((c[3542193]>>8)+8|0)/+(c[2440574]|0)}else{e=+((c[3542194]>>8)+8|0)/+(c[2440574]|0)}a[14164832]=~~(e*255.0)^-1;return};case 14954519:{if((c[3532560]|0)==0){f=+((c[3542197]>>8)+8|0)/+(c[2440576]|0)}else{f=+((c[3542198]>>8)+8|0)/+(c[2440576]|0)}a[14164832]=~~(f*255.0);return};case 14954515:{a[14164832]=~~(+((c[3542196]>>8)+8|0)/+(c[2440576]|0)*255.0);return};case 14954513:{a[14164832]=~~(+((c[3542192]>>8)+8|0)/+(c[2440574]|0)*255.0)^-1;return};default:{return}}}function eIH(b){b=b|0;var c=0;switch(b|0){case 12845059:{c=a[14130177]|0;break};case 12849155:{c=~a[14130137];break};case 12845057:{c=a[14130176]|0;break};case 12849157:{c=~a[14130138];break};case 12849159:{c=~a[14130139];break};case 12849153:{c=~a[14130136];break};default:{c=-1}}return c|0}function eII(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0;if((d|0)==12871169){c[3532340]=e&2;return}else if((d|0)==12845063){c[3532412]=e&255;f=c[2439330]|0;if((f|0)!=0){g=f;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;g=(c[2433530]|0)+12|0;c[2433530]=g;f=c[1836236]|0;h=c[9757320+(f<<2)>>2]|0;if((h|0)!=0){i=h;gGC(i|0,9706056,76)|0}c[9752472+(f<<2)>>2]=g;c[14113936+(f<<2)>>2]=c[2076596];c[9669104+(f<<2)>>2]=c[3541536];c[1836236]=-1;return}else if((d|0)==12871681){d=e&255;e=d<<2&60;f=d>>>4<<2;if((c[3532358]|0)!=(e|0)){c[3532358]=e;a[7461568]=1;a[7461576]=1;a[7461552]=1;a[7461560]=1}if((c[3532362]|0)!=(f|0)){c[3532362]=f;a[7461568]=1;a[7461576]=1;a[7461552]=1;a[7461560]=1}d=e|1;if((c[3532359]|0)!=(d|0)){c[3532359]=d;a[7461568]=1;a[7461576]=1;a[7461552]=1;a[7461560]=1}d=f|1;if((c[3532363]|0)!=(d|0)){c[3532363]=d;a[7461568]=1;a[7461576]=1;a[7461552]=1;a[7461560]=1}d=e|2;if((c[3532360]|0)!=(d|0)){c[3532360]=d;a[7461568]=1;a[7461576]=1;a[7461552]=1;a[7461560]=1}d=f|2;if((c[3532364]|0)!=(d|0)){c[3532364]=d;a[7461568]=1;a[7461576]=1;a[7461552]=1;a[7461560]=1}d=e|3;if((c[3532361]|0)!=(d|0)){c[3532361]=d;a[7461568]=1;a[7461576]=1;a[7461552]=1;a[7461560]=1}d=f|3;if((c[3532365]|0)==(d|0)){return}c[3532365]=d;a[7461568]=1;a[7461576]=1;a[7461552]=1;a[7461560]=1;return}else{return}}function eIJ(b,d){b=b|0;d=d|0;if((b|0)==12870144){c[3532414]=d&255;return}else if((b|0)==12869632){c[3532415]=d&255;return}else if((b|0)==12870656){a[14168816]=(d&65535)>>>8&15;c[3532418]=d&255;return}else{return}}function eIK(c){c=c|0;var d=0;if((c|0)==10760201){d=(b[4878680]&255)-(a[14107921]|0)&255;return d|0}else if((c|0)==10760197){d=(b[4878684]&255)-(a[14107912]|0)&255;return d|0}else if((c|0)==10760193){d=(b[4878688]&255)-(a[14107920]|0)&255;return d|0}else if((c|0)==10760205){d=(b[4878676]&255)-(a[14107913]|0)&255;return d|0}else{d=-1;return d|0}return 0}function eIL(c,d){c=c|0;d=d|0;if((c|0)==10760200){a[14107921]=b[4878680]&255;a[14107913]=b[4878676]&255;return}else if((c|0)==10760192){a[14107920]=b[4878688]&255;a[14107912]=b[4878684]&255;return}else{return}}function eIM(){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=b[4878688]|0;if((a[14130121]|0)==0){d=c}else{e=c+4&65535;b[4878688]=e;d=e}if((a[14130122]|0)==0){f=d}else{e=d-4&65535;b[4878688]=e;f=e}do{if(f<<16>>16>255){b[4878688]=0}else{if(f<<16>>16>=0){break}b[4878688]=252}}while(0);f=b[4878684]|0;if((a[14130123]|0)==0){g=f}else{e=f-4&65535;b[4878684]=e;g=e}if((a[14130124]|0)==0){h=g}else{e=g+4&65535;b[4878684]=e;h=e}do{if(h<<16>>16>255){b[4878684]=0}else{if(h<<16>>16>=0){break}b[4878684]=252}}while(0);h=b[4878680]|0;if((a[14130113]|0)==0){i=h}else{e=h+4&65535;b[4878680]=e;i=e}if((a[14130114]|0)==0){j=i}else{e=i-4&65535;b[4878680]=e;j=e}do{if(j<<16>>16>255){b[4878680]=0}else{if(j<<16>>16>=0){break}b[4878680]=252}}while(0);j=b[4878676]|0;if((a[14130115]|0)==0){k=j}else{e=j-4&65535;b[4878676]=e;k=e}if((a[14130116]|0)==0){l=k}else{e=k+4&65535;b[4878676]=e;l=e}if(l<<16>>16>255){b[4878676]=0;return}if(l<<16>>16>=0){return}b[4878676]=252;return}function eIN(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0;fxU(0,425984);if((c[2394]|0)==0){a=c[2112932]|0}else{c[2394]=0;b=c[3532596]|0;c[2112932]=b;d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];a=b}b=c[3532446]|0;d=a|0;e=d;f=0;while(1){c[e>>2]=b+f;g=f+1024|0;if(g>>>0>786431){break}else{e=e+4|0;f=g}}f=c[3532552]|0;e=d;d=0;while(1){c[e+131072>>2]=f+d;b=d+1024|0;if(b>>>0>786431){break}else{e=e+4|0;d=b}}d=c[3532356]|0;e=a+4096|0;f=1048576;while(1){b=d+(f-1048576)|0;c[e>>2]=b;c[e+65536>>2]=b;c[e+131072>>2]=b;b=f+1024|0;if(b>>>0>1114111){break}else{e=e+4|0;f=b}}f=c[3532368]|0;c[a+4352>>2]=f;c[a+69888>>2]=f;c[a+135424>>2]=f;e=f+1024|0;c[a+4356>>2]=e;c[a+69892>>2]=e;c[a+135428>>2]=e;e=f+2048|0;c[a+4360>>2]=e;c[a+69896>>2]=e;c[a+135432>>2]=e;e=f+3072|0;c[a+4364>>2]=e;c[a+69900>>2]=e;c[a+135436>>2]=e;e=c[3532390]|0;c[a+8192>>2]=e;c[a+73728>>2]=e;c[a+139264>>2]=e;f=e+1024|0;c[a+8196>>2]=f;c[a+73732>>2]=f;c[a+139268>>2]=f;f=c[3532484]|0;c[a+5120>>2]=f;c[a+70656>>2]=f;c[a+136192>>2]=f;e=f+1024|0;c[a+5124>>2]=e;c[a+70660>>2]=e;c[a+136196>>2]=e;e=f+2048|0;c[a+5128>>2]=e;c[a+70664>>2]=e;c[a+136200>>2]=e;e=f+3072|0;c[a+5132>>2]=e;c[a+70668>>2]=e;c[a+136204>>2]=e;e=c[3532470]|0;c[a+65472>>2]=e;c[a+131008>>2]=e;c[a+196544>>2]=e;f=e+1024|0;c[a+65476>>2]=f;c[a+131012>>2]=f;c[a+196548>>2]=f;f=e+2048|0;c[a+65480>>2]=f;c[a+131016>>2]=f;c[a+196552>>2]=f;f=e+3072|0;c[a+65484>>2]=f;c[a+131020>>2]=f;c[a+196556>>2]=f;f=e+4096|0;c[a+65488>>2]=f;c[a+131024>>2]=f;c[a+196560>>2]=f;f=e+5120|0;c[a+65492>>2]=f;c[a+131028>>2]=f;c[a+196564>>2]=f;f=e+6144|0;c[a+65496>>2]=f;c[a+131032>>2]=f;c[a+196568>>2]=f;f=e+7168|0;c[a+65500>>2]=f;c[a+131036>>2]=f;c[a+196572>>2]=f;f=e+8192|0;c[a+65504>>2]=f;c[a+131040>>2]=f;c[a+196576>>2]=f;f=e+9216|0;c[a+65508>>2]=f;c[a+131044>>2]=f;c[a+196580>>2]=f;f=e+10240|0;c[a+65512>>2]=f;c[a+131048>>2]=f;c[a+196584>>2]=f;f=e+11264|0;c[a+65516>>2]=f;c[a+131052>>2]=f;c[a+196588>>2]=f;f=e+12288|0;c[a+65520>>2]=f;c[a+131056>>2]=f;c[a+196592>>2]=f;f=e+13312|0;c[a+65524>>2]=f;c[a+131060>>2]=f;c[a+196596>>2]=f;f=e+14336|0;c[a+65528>>2]=f;c[a+131064>>2]=f;c[a+196600>>2]=f;f=e+15360|0;c[a+65532>>2]=f;c[a+131068>>2]=f;c[a+196604>>2]=f;c[a+196688>>2]=2576;c[a+196728>>2]=1922;c[a+196608>>2]=880;c[a+196648>>2]=1400;c[a+40960>>2]=1;c[a+106496>>2]=1;c[a+172032>>2]=1;c[a+40964>>2]=1;c[a+106500>>2]=1;c[a+172036>>2]=1;c[a+40968>>2]=1;c[a+106504>>2]=1;c[a+172040>>2]=1;c[a+40972>>2]=1;c[a+106508>>2]=1;c[a+172044>>2]=1;c[a+40976>>2]=1;c[a+106512>>2]=1;c[a+172048>>2]=1;c[a+40980>>2]=1;c[a+106516>>2]=1;c[a+172052>>2]=1;c[a+40984>>2]=1;c[a+106520>>2]=1;c[a+172056>>2]=1;c[a+40988>>2]=1;c[a+106524>>2]=1;c[a+172060>>2]=1;c[a+40992>>2]=1;c[a+106528>>2]=1;c[a+172064>>2]=1;c[a+40996>>2]=1;c[a+106532>>2]=1;c[a+172068>>2]=1;c[a+41e3>>2]=1;c[a+106536>>2]=1;c[a+172072>>2]=1;c[a+41004>>2]=1;c[a+106540>>2]=1;c[a+172076>>2]=1;c[a+41008>>2]=1;c[a+106544>>2]=1;c[a+172080>>2]=1;c[a+41012>>2]=1;c[a+106548>>2]=1;c[a+172084>>2]=1;c[a+41016>>2]=1;c[a+106552>>2]=1;c[a+172088>>2]=1;c[a+41020>>2]=1;c[a+106556>>2]=1;c[a+172092>>2]=1;c[a+196612>>2]=64;c[a+196652>>2]=2164;a=c[3532592]|0;if((a|0)==0){h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return}gGC(a|0,9104152,280)|0;h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return}function eIO(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6428188+(b*112|0)>>2];c[a+104>>2]=c[6428192+(b*112|0)>>2];c[a+108>>2]=c[6428196+(b*112|0)>>2];d=0;return d|0}function eIP(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=6428088+(b*112|0);e=0;return e|0}function eIQ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>23){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1183880+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eIR(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>53){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4263440+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eIS(){c[3532512]=4770;return eOx()|0}function eIT(){gGz(9762328|0,0|0,16|0);eFe();eOI()|0;return 0}function eIU(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=i;i=i+16|0;e=d|0;if((b|0)!=0){c[b>>2]=169568}if((a&64|0)==0){f=eOS(a,b)|0;i=d;return 0}gGz(e|0,0,12);c[e>>2]=9762328;c[e+4>>2]=16;c[e+12>>2]=401064;gj[c[2076592]&4095](e)|0;eFf();f=eOS(a,b)|0;i=d;return 0}function eIV(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5598596+(b*112|0)>>2];c[a+104>>2]=c[5598600+(b*112|0)>>2];c[a+108>>2]=c[5598604+(b*112|0)>>2];d=0;return d|0}function eIW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=5598496+(b*112|0);e=0;return e|0}function eIX(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>34){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4262880+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eIY(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>53){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6430104+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eIZ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5596580+(b*112|0)>>2];c[a+104>>2]=c[5596584+(b*112|0)>>2];c[a+108>>2]=c[5596588+(b*112|0)>>2];d=0;return d|0}function eI_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=5596480+(b*112|0);e=0;return e|0}function eI$(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5594564+(b*112|0)>>2];c[a+104>>2]=c[5594568+(b*112|0)>>2];c[a+108>>2]=c[5594572+(b*112|0)>>2];d=0;return d|0}function eI0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=5594464+(b*112|0);e=0;return e|0}function eI1(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5565556+(b*112|0)>>2];c[a+104>>2]=c[5565560+(b*112|0)>>2];c[a+108>>2]=c[5565564+(b*112|0)>>2];d=0;return d|0}function eI2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=5565456+(b*112|0);e=0;return e|0}function eI3(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4155892+(b*112|0)>>2];c[a+104>>2]=c[4155896+(b*112|0)>>2];c[a+108>>2]=c[4155900+(b*112|0)>>2];d=0;return d|0}function eI4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=4155792+(b*112|0);e=0;return e|0}function eI5(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>56){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4157696+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eI6(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c[3532430]=1572864;c[3532546]=3894;c[3532380]=4194304;a=eOx()|0;if((a|0)!=0){b=a;return b|0}if((c[2394]|0)==0){d=c[2112932]|0}else{c[2394]=0;a=c[3532596]|0;c[2112932]=a;e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060];d=a}a=c[3532446]|0;e=d+8192|0;d=2097152;while(1){c[e>>2]=a+d;f=d+1024|0;if(f>>>0>2621439){break}else{e=e+4|0;d=f}}d=c[3532592]|0;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;d=0;while(1){if((d|0)>=1024){g=1;h=0;break}i=9638528+(d<<2)|0;if((c[i>>2]|0)==0){j=19589;break}else{d=d+1|0}}do{if((j|0)==19589){d=gGq(4194304)|0;c[i>>2]=d;if((d|0)==0){g=1;h=0;break}gGz(d|0,0,4194304);e=c[3532374]|0;gGC(d|0,e|0,4194304)|0;gGz(e|0,0,c[3532380]|0);gGC(e|0,d|0,1048576)|0;a=e+2097152|0;f=d+1048576|0;gGC(a|0,f|0,1048576)|0;f=e+4194304|0;a=d+2097152|0;gGC(f|0,a|0,1048576)|0;a=e+6291456|0;e=d+3145728|0;gGC(a|0,e|0,1048576)|0;g=0;h=d}}while(0);i=0;while(1){if((i|0)>=1024){b=g;j=19596;break}k=9638528+(i<<2)|0;if((c[k>>2]|0)==(h|0)){break}else{i=i+1|0}}if((j|0)==19596){return b|0}gGr(h);c[k>>2]=0;b=g;return b|0}function eI7(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1979724+(b*112|0)>>2];c[a+104>>2]=c[1979728+(b*112|0)>>2];c[a+108>>2]=c[1979732+(b*112|0)>>2];d=0;return d|0}function eI8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=1979624+(b*112|0);e=0;return e|0}function eI9(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6375300+(b*112|0)>>2];c[a+104>>2]=c[6375304+(b*112|0)>>2];c[a+108>>2]=c[6375308+(b*112|0)>>2];d=0;return d|0}function eJa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=6375200+(b*112|0);e=0;return e|0}function eJb(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>28){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4096184+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eJc(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>57){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6377440+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eJd(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5485772+(b*112|0)>>2];c[a+104>>2]=c[5485776+(b*112|0)>>2];c[a+108>>2]=c[5485780+(b*112|0)>>2];d=0;return d|0}function eJe(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=5485672+(b*112|0);e=0;return e|0}function eJf(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>36){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1962432+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eJg(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>57){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5479800+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eJh(){var a=0,b=0,d=0,e=0,f=0;a=eI6()|0;if((a|0)!=0){return a|0}if((c[2394]|0)==0){b=c[2112932]|0;d=c[3532592]|0}else{c[2394]=0;e=c[3532596]|0;c[2112932]=e;f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];b=e;d=f}c[b+58416>>2]=1;c[b+196612>>2]=478;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;return a|0}function eJi(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5482836+(b*112|0)>>2];c[a+104>>2]=c[5482840+(b*112|0)>>2];c[a+108>>2]=c[5482844+(b*112|0)>>2];d=0;return d|0}function eJj(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=5482736+(b*112|0);e=0;return e|0}function eJk(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1963024+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eJl(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>57){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5484976+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eJm(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5480596+(b*112|0)>>2];c[a+104>>2]=c[5480600+(b*112|0)>>2];c[a+108>>2]=c[5480604+(b*112|0)>>2];d=0;return d|0}function eJn(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=5480496+(b*112|0);e=0;return e|0}function eJo(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4094044+(b*112|0)>>2];c[a+104>>2]=c[4094048+(b*112|0)>>2];c[a+108>>2]=c[4094052+(b*112|0)>>2];d=0;return d|0}function eJp(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=4093944+(b*112|0);e=0;return e|0}function eJq(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5477660+(b*112|0)>>2];c[a+104>>2]=c[5477664+(b*112|0)>>2];c[a+108>>2]=c[5477668+(b*112|0)>>2];d=0;return d|0}function eJr(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=5477560+(b*112|0);e=0;return e|0}function eJs(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4072516+(b*112|0)>>2];c[a+104>>2]=c[4072520+(b*112|0)>>2];c[a+108>>2]=c[4072524+(b*112|0)>>2];d=0;return d|0}function eJt(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=4072416+(b*112|0);e=0;return e|0}function eJu(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>31){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1283720+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eJv(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>55){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4074656+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eJw(){var a=0,b=0,d=0,e=0,f=0;c[3532430]=1048576;c[3532546]=3578;a=eOx()|0;if((a|0)!=0){return a|0}if((c[2394]|0)==0){b=c[2112932]|0}else{c[2394]=0;d=c[3532596]|0;c[2112932]=d;e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060];b=d}d=c[3532446]|0;e=b+8192|0;b=2097152;while(1){c[e>>2]=d+b;f=b+1024|0;if(f>>>0>2621439){break}else{e=e+4|0;b=f}}b=c[3532592]|0;if((b|0)!=0){gGC(b|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;return a|0}function eJx(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1958724+(b*112|0)>>2];c[a+104>>2]=c[1958728+(b*112|0)>>2];c[a+108>>2]=c[1958732+(b*112|0)>>2];d=0;return d|0}function eJy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=1958624+(b*112|0);e=0;return e|0}function eJz(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6247708+(b*112|0)>>2];c[a+104>>2]=c[6247712+(b*112|0)>>2];c[a+108>>2]=c[6247716+(b*112|0)>>2];d=0;return d|0}function eJA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=6247608+(b*112|0);e=0;return e|0}function eJB(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3798872+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eJC(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>56){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6249848+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eJD(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;c[2113302]=3;a[801640]=0;b=c[642608+(c[2436]<<2)>>2]|0;d=c[b+128>>2]|0;if((c[b+52>>2]&4|0)==0){c[2440576]=d;e=c[b+132>>2]|0;c[2440574]=e;f=d;g=e}else{c[2440574]=d;e=c[b+132>>2]|0;c[2440576]=e;f=e;g=d}d=(((f|0)/2|0)<<8)-1792|0;f=(((g|0)/2|0)<<8)-2048|0;c[3542196]=d;c[3542192]=f;c[3542197]=d;c[3542193]=f;c[3542198]=d;c[3542194]=f;c[3542199]=d;c[3542195]=f;f=eI6()|0;if((f|0)!=0){return f|0}if((c[2394]|0)==0){h=c[2112932]|0;i=c[3532592]|0}else{c[2394]=0;d=c[3532596]|0;c[2112932]=d;g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060];h=d;i=g}c[h+58416>>2]=1;c[h+123952>>2]=1;c[h+189488>>2]=1;c[h+196612>>2]=3538;c[h+196652>>2]=3176;if((i|0)!=0){gGC(i|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;return f|0}function eJE(){a[14164832]=0;gGz(9762328|0,0|0,16|0);eFe();eOI()|0;return 0}function eJF(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;d=i;i=i+32|0;e=d|0;f=d+16|0;g=(b|0)==0;if(!g){c[b>>2]=169568}h=(a&64|0)==0;if(!h){gGz(f|0,0,12);c[f>>2]=14164832;c[f+4>>2]=1;c[f+12>>2]=486944;j=c[2076592]|0;gj[j&4095](f)|0}if(!g){c[b>>2]=169568}if(h){k=eOS(a,b)|0;i=d;return 0}gGz(e|0,0,12);c[e>>2]=9762328;c[e+4>>2]=16;c[e+12>>2]=401064;gj[c[2076592]&4095](e)|0;eFf();k=eOS(a,b)|0;i=d;return 0}function eJG(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5308852+(b*112|0)>>2];c[a+104>>2]=c[5308856+(b*112|0)>>2];c[a+108>>2]=c[5308860+(b*112|0)>>2];d=0;return d|0}function eJH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=5308752+(b*112|0);e=0;return e|0}function eJI(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6832932+(b*112|0)>>2];c[a+104>>2]=c[6832936+(b*112|0)>>2];c[a+108>>2]=c[6832940+(b*112|0)>>2];d=0;return d|0}function eJJ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=6832832+(b*112|0);e=0;return e|0}function eJK(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>31){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5232552+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eJL(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>58){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6834960+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eJM(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5230076+(b*112|0)>>2];c[a+104>>2]=c[5230080+(b*112|0)>>2];c[a+108>>2]=c[5230084+(b*112|0)>>2];d=0;return d|0}function eJN(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=5229976+(b*112|0);e=0;return e|0}function eJO(){var a=0,b=0,d=0,e=0,f=0;c[3532546]=3432;c[3532376]=128;a=eOx()|0;if((a|0)!=0){return a|0}if((c[2394]|0)==0){b=c[2112932]|0;d=c[3532592]|0}else{c[2394]=0;e=c[3532596]|0;c[2112932]=e;f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];b=e;d=f}c[b+50176>>2]=1;c[b+50180>>2]=1;c[b+50184>>2]=1;c[b+50188>>2]=1;c[b+50192>>2]=1;c[b+196612>>2]=796;c[b+115712>>2]=2;c[b+115716>>2]=2;c[b+115720>>2]=2;c[b+115724>>2]=2;c[b+115728>>2]=2;c[b+115732>>2]=2;c[b+115736>>2]=2;c[b+115740>>2]=2;c[b+115744>>2]=2;c[b+115748>>2]=2;c[b+115752>>2]=2;c[b+115756>>2]=2;c[b+115760>>2]=2;c[b+115764>>2]=2;c[b+115768>>2]=2;c[b+115772>>2]=2;c[b+115776>>2]=2;c[b+115780>>2]=2;c[b+115784>>2]=2;c[b+115788>>2]=2;c[b+115792>>2]=2;c[b+115796>>2]=2;c[b+115800>>2]=2;c[b+115804>>2]=2;c[b+115808>>2]=2;c[b+115812>>2]=2;c[b+115816>>2]=2;c[b+196656>>2]=2880;c[b+196736>>2]=2938;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;return a|0}function eJP(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3460604+(b*112|0)>>2];c[a+104>>2]=c[3460608+(b*112|0)>>2];c[a+108>>2]=c[3460612+(b*112|0)>>2];d=0;return d|0}function eJQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=3460504+(b*112|0);e=0;return e|0}function eJR(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>56){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3462184+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eJS(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1698580+(b*112|0)>>2];c[a+104>>2]=c[1698584+(b*112|0)>>2];c[a+108>>2]=c[1698588+(b*112|0)>>2];d=0;return d|0}function eJT(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=1698480+(b*112|0);e=0;return e|0}function eJU(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1696900+(b*112|0)>>2];c[a+104>>2]=c[1696904+(b*112|0)>>2];c[a+108>>2]=c[1696908+(b*112|0)>>2];d=0;return d|0}function eJV(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=1696800+(b*112|0);e=0;return e|0}function eJW(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4869508+(b*112|0)>>2];c[a+104>>2]=c[4869512+(b*112|0)>>2];c[a+108>>2]=c[4869516+(b*112|0)>>2];d=0;return d|0}function eJX(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=4869408+(b*112|0);e=0;return e|0}function eJY(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3230560+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eJZ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>49){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5976864+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eJ_(){var a=0,b=0,d=0,e=0,f=0;c[3532514]=6390;a=eOx()|0;if((a|0)!=0){return a|0}if((c[2394]|0)==0){b=c[2112932]|0;d=c[3532592]|0}else{c[2394]=0;e=c[3532596]|0;c[2112932]=e;f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];b=e;d=f}c[b+42032>>2]=1;c[b+107568>>2]=1;c[b+173104>>2]=1;c[b+196612>>2]=836;c[b+196732>>2]=1016;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;return a|0}function eJ$(){b[4878688]=0;b[4878684]=0;b[4878680]=0;b[4878676]=0;b[7053960]=0;b[7053956]=0;gGz(9762328|0,0|0,16|0);eFe();eOI()|0;return 0}function eJ0(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=i;i=i+112|0;e=d|0;f=d+16|0;g=d+32|0;h=d+48|0;j=d+64|0;k=d+80|0;l=d+96|0;m=(b|0)==0;if(!m){c[b>>2]=169568}n=(a&64|0)==0;if(!n){gGz(l|0,0,12);c[l>>2]=9757376;c[l+4>>2]=2;c[l+12>>2]=172936;o=c[2076592]|0;gj[o&4095](l)|0;gGz(k|0,0,12);c[k>>2]=9757368;c[k+4>>2]=2;c[k+12>>2]=169424;l=c[2076592]|0;gj[l&4095](k)|0;gGz(j|0,0,12);c[j>>2]=9757360;c[j+4>>2]=2;c[j+12>>2]=166392;k=c[2076592]|0;gj[k&4095](j)|0;gGz(h|0,0,12);c[h>>2]=9757352;c[h+4>>2]=2;c[h+12>>2]=163560;j=c[2076592]|0;gj[j&4095](h)|0;gGz(g|0,0,12);c[g>>2]=14107920;c[g+4>>2]=2;c[g+12>>2]=159440;h=c[2076592]|0;gj[h&4095](g)|0;gGz(f|0,0,12);c[f>>2]=14107912;c[f+4>>2]=2;c[f+12>>2]=156888;g=c[2076592]|0;gj[g&4095](f)|0}if(!m){c[b>>2]=169568}if(n){p=eOS(a,b)|0;i=d;return 0}gGz(e|0,0,12);c[e>>2]=9762328;c[e+4>>2]=16;c[e+12>>2]=401064;gj[c[2076592]&4095](e)|0;eFf();p=eOS(a,b)|0;i=d;return 0}function eJ1(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3228868+(b*112|0)>>2];c[a+104>>2]=c[3228872+(b*112|0)>>2];c[a+108>>2]=c[3228876+(b*112|0)>>2];d=0;return d|0}function eJ2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=3228768+(b*112|0);e=0;return e|0}function eJ3(){var d=0;d=c[3532446]|0;b[d+459282>>1]=20081;b[d+459030>>1]=20081;b[d+12618>>1]=17986;a[d+12570|0]=63;a[d+459011|0]=0;a[d+459017|0]=0;a[d+30503|0]=0;a[d+30505|0]=0;a[d+30733|0]=0;a[d+30735|0]=0;a[d+30817|0]=0;a[d+32071|0]=0;a[d+30819|0]=0;a[d+34099|0]=0;a[d+34101|0]=0;a[d+34237|0]=0;a[d+34239|0]=0;a[d+39499|0]=0;a[d+39501|0]=0;a[d+39727|0]=0;a[d+39729|0]=0;a[d+41051|0]=0;a[d+41053|0]=0;a[d+41535|0]=0;a[d+41537|0]=0;a[d+65881|0]=0;a[d+65883|0]=0;a[d+68091|0]=0;a[d+68093|0]=0;return 0}function eJ4(){var a=0,b=0,d=0,e=0,f=0,g=0;a=0;while(1){if((a|0)>=1024){b=1;d=20020;break}e=9638528+(a<<2)|0;if((c[e>>2]|0)==0){break}else{a=a+1|0}}if((d|0)==20020){return b|0}a=gGq(3145728)|0;c[e>>2]=a;if((a|0)==0){b=1;return b|0}gGz(a|0,0,3145728);e=c[3532446]|0;gGC(a|0,e|0,3145728)|0;gGz(e|0,0,3145728);gGC(e|0,a|0,1048576)|0;f=e+2097152|0;e=a+1048576|0;gGC(f|0,e|0,1048576)|0;e=0;while(1){if((e|0)>=1024){b=0;d=20019;break}g=9638528+(e<<2)|0;if((c[g>>2]|0)==(a|0)){break}else{e=e+1|0}}if((d|0)==20019){return b|0}gGr(a);c[g>>2]=0;b=0;return b|0}function eJ5(){var a=0,b=0,d=0,e=0,f=0,g=0;a=0;while(1){if((a|0)>=1024){b=1;d=20035;break}e=9638528+(a<<2)|0;if((c[e>>2]|0)==0){break}else{a=a+1|0}}if((d|0)==20035){return b|0}a=gGq(2621440)|0;c[e>>2]=a;if((a|0)==0){b=1;return b|0}gGz(a|0,0,2621440);e=c[3532446]|0;gGC(a|0,e|0,2621440)|0;gGz(e|0,0,2621440);gGC(e|0,a|0,524288)|0;f=e+2097152|0;e=a+524288|0;gGC(f|0,e|0,524288)|0;e=0;while(1){if((e|0)>=1024){b=0;d=20032;break}g=9638528+(e<<2)|0;if((c[g>>2]|0)==(a|0)){break}else{e=e+1|0}}if((d|0)==20032){return b|0}gGr(a);c[g>>2]=0;b=0;return b|0}function eJ6(){eJ7(618496);return}function eJ7(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=c[3527014]|0;f=c[2439400]|0;g=0;do{h=e+g|0;i=d[h]|0;j=i>>>5<<1&2|i>>>3&1;k=(i&128|0)==0;l=k?0:168;m=k?j:j^3;j=i&87;i=(g>>>4<<1&2|g&1|g>>>8<<2&4|g>>>12<<3&8)<<1;k=b+(i<<2)+m|0;n=f+g|0;a[n]=(l^d[k]|j)&255;o=b+((i|1)<<2)+m|0;a[h]=(l^d[o]|j)&255;if((a[k]|0)==-1){a[n]=-18}if((a[o]|0)==-1){a[h]=-18}g=g+1|0;}while((g|0)<32768);g=f+32768|0;f=e+32768|0;gGC(g|0,f|0,16384)|0;return}function eJ8(){eJ7(619088);return}function eJ9(){eJ7(617728);return}function eKa(){eJ7(618960);return}function eKb(){var b=0,d=0,e=0,f=0;b=c[3527014]|0;d=0;do{e=b+d|0;f=a[e]|0;a[e]=f<<1&2|f&-4|(f&255)>>>1&1;d=d+1|0;}while((d|0)<49152);eJ7(618832);return}function eKc(){eJ7(618704);return}function eKd(){eJ7(619568);return}function eKe(){eJ7(619304);return}function eKf(){eKg(c[3527014]|0,c[2439400]|0,618432,617920,617856,618176);return}function eKg(b,e,f,g,h,i){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0;j=0;do{k=b+j|0;l=j>>>3<<1&2|j&1|j>>>6<<2&4|j>>>9<<3&8|j>>>12<<4&16|j>>>14<<5&32;m=c[g+(l<<2)>>2]|0;n=d[k]|0;o=n&170;a[e+j|0]=((n>>>((d[606056+(m<<2)|0]|0)>>>0)<<6&64|o|n>>>((d[606057+(m<<2)|0]|0)>>>0)<<4&16|n>>>((d[606058+(m<<2)|0]|0)>>>0)<<2&4|n>>>((d[606059+(m<<2)|0]|0)>>>0)&1)^(d[f+l|0]|0))&255;m=c[i+(l<<2)>>2]|0;a[k]=((n>>>((d[606056+(m<<2)|0]|0)>>>0)<<6&64|o|n>>>((d[606057+(m<<2)|0]|0)>>>0)<<4&16|n>>>((d[606058+(m<<2)|0]|0)>>>0)<<2&4|n>>>((d[606059+(m<<2)|0]|0)>>>0)&1)^(d[h+l|0]|0))&255;j=j+1|0;}while((j|0)<32768);j=e+32768|0;e=b+32768|0;gGC(j|0,e|0,16384)|0;return}function eKh(b){b=b|0;var d=0;switch(b&255|0){case 4:{d=~a[9771777];break};case 8:{d=~a[9771778];break};case 16:{d=a[14115697]|0;break};case 17:{d=a[14115696]|0;break};case 21:{d=c[2433306]&255;break};case 25:{d=c[2433306]&255;break};case 13:{d=a[14115697]|0;break};case 0:{d=~a[9771776];break};case 12:{d=a[14115696]|0;break};default:{d=0}}return d|0}function eKi(b){b=b|0;var d=0;switch(b&255|0){case 8:{d=~a[9771778];break};case 13:{d=a[14115697]|0;break};case 16:{d=a[14115697]|0;break};case 17:{d=a[14115696]|0;break};case 21:{d=c[2433306]&255;break};case 25:{d=c[2433306]&255;break};case 4:{d=a[9760112]|0;break};case 12:{d=a[14115696]|0;break};case 0:{d=a[9760120]|0;break};default:{d=0}}return d|0}function eKj(b){b=b|0;var d=0;switch(b&255|0){case 4:{d=~a[9771777];break};case 8:{d=~a[9771778];break};case 21:{d=c[2433306]&255;break};case 22:{d=c[2430874]&255;break};case 34:{d=c[2430872]&255;break};case 35:{d=c[2430870]&255;break};case 28:{d=-128;break};case 13:{d=a[14115697]|0;break};case 0:{d=~a[9771776];break};case 12:{d=a[14115696]|0;break};default:{d=0}}return d|0}function eKk(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=d&255;if((f|0)==20|(f|0)==24){c[2430812]=e&255;d=c[1836236]|0;g=c[9757320+(d<<2)>>2]|0;if((g|0)!=0){h=g;gGC(h|0,9706056,76)|0}c[9752472+(d<<2)>>2]=c[2433530];c[14113936+(d<<2)>>2]=c[2076596];c[9669104+(d<<2)>>2]=c[3541536];c[1836236]=-1;d=c[2439331]|0;if((d|0)!=0){h=d;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;h=(c[2433530]|0)+12|0;c[2433530]=h;d=c[1836236]|0;g=c[9757320+(d<<2)>>2]|0;if((g|0)!=0){i=g;gGC(i|0,9706056,76)|0}c[9752472+(d<<2)>>2]=h;c[14113936+(d<<2)>>2]=c[2076596];c[9669104+(d<<2)>>2]=c[3541536];c[1836236]=-1;d=c[2439330]|0;if((d|0)!=0){h=d;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;return}else if((f|0)==21|(f|0)==25){f=e&255;c[2433306]=f;c[2430822]=f&128;return}else{return}}function eKl(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=d&255;if((f|0)==20|(f|0)==24){c[2430812]=e&255;d=c[1836236]|0;g=c[9757320+(d<<2)>>2]|0;if((g|0)!=0){h=g;gGC(h|0,9706056,76)|0}c[9752472+(d<<2)>>2]=c[2433530];c[14113936+(d<<2)>>2]=c[2076596];c[9669104+(d<<2)>>2]=c[3541536];c[1836236]=-1;d=c[2439331]|0;if((d|0)!=0){h=d;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;h=(c[2433530]|0)+12|0;c[2433530]=h;d=c[1836236]|0;g=c[9757320+(d<<2)>>2]|0;if((g|0)!=0){i=g;gGC(i|0,9706056,76)|0}c[9752472+(d<<2)>>2]=h;c[14113936+(d<<2)>>2]=c[2076596];c[9669104+(d<<2)>>2]=c[3541536];c[1836236]=-1;d=c[2439330]|0;if((d|0)!=0){h=d;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;return}else if((f|0)==21|(f|0)==25){f=e&255;c[2433306]=f;c[2430822]=f&128;e=f>>>2&1|f>>>5&2;c[2438420]=e;f=c[3527014]|0;h=c[9757320+(c[1836236]<<2)>>2]|0;d=(e<<14|65536)-32768|0;e=128;i=128;while(1){c[h+76+(i<<2)>>2]=f+(d+(i<<8));g=e+1&65535;if((g&65535)>191){j=128;k=128;break}else{e=g;i=g&65535}}while(1){i=f+(d+(k<<8))|0;c[h+76+(k+512<<2)>>2]=i;c[h+76+(k+768<<2)>>2]=i;i=j+1&65535;if((i&65535)>191){break}else{j=i;k=i&65535}}return}else{return}}function eKm(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;switch(d&255|0){case 21:{d=e&255;c[2433306]=d;c[2430822]=d&128;f=d>>>2&1|d>>>5&2;c[2438420]=f;d=c[3527014]|0;g=c[9757320+(c[1836236]<<2)>>2]|0;h=(f<<14|65536)-32768|0;f=128;i=128;while(1){c[g+76+(i<<2)>>2]=d+(h+(i<<8));j=f+1&65535;if((j&65535)>191){k=128;l=128;break}else{f=j;i=j&65535}}while(1){i=d+(h+(l<<8))|0;c[g+76+(l+512<<2)>>2]=i;c[g+76+(l+768<<2)>>2]=i;i=k+1&65535;if((i&65535)>191){break}else{k=i;l=i&65535}}return};case 22:{c[2430874]=e&255;return};case 23:{c[2430872]=e&255;return};case 36:{c[2430870]=e&255;return};case 20:case 24:{c[2430812]=e&255;e=c[1836236]|0;l=c[9757320+(e<<2)>>2]|0;if((l|0)!=0){k=l;gGC(k|0,9706056,76)|0}c[9752472+(e<<2)>>2]=c[2433530];c[14113936+(e<<2)>>2]=c[2076596];c[9669104+(e<<2)>>2]=c[3541536];c[1836236]=-1;e=c[2439331]|0;if((e|0)!=0){k=e;gGC(9706056,k|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;k=(c[2433530]|0)+12|0;c[2433530]=k;e=c[1836236]|0;l=c[9757320+(e<<2)>>2]|0;if((l|0)!=0){g=l;gGC(g|0,9706056,76)|0}c[9752472+(e<<2)>>2]=k;c[14113936+(e<<2)>>2]=c[2076596];c[9669104+(e<<2)>>2]=c[3541536];c[1836236]=-1;e=c[2439330]|0;if((e|0)!=0){k=e;gGC(9706056,k|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;return};default:{return}}}function eKn(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((b+4096&65535)<1024){a[(c[2429304]|0)+(e-61440)|0]=126;return}if((b+2048&65535)<1024){a[(c[2427080]|0)+(e-63488)|0]=126;return}if((e|0)==61436){a[9753672]=d}else if((e|0)==61437){a[9753673]=d}else if((e|0)==61373){a[9753664]=d}if((b+4352&65535)>=256){return}a[(c[2442936]|0)+(e-61184)|0]=d;return}function eKo(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((b+16384&65535)<1024){a[(c[2429304]|0)+(e-49152)|0]=126;return}if((b+14336&65535)<1024){a[(c[2427080]|0)+(e-51200)|0]=126;return}if((e|0)==61373){a[9753664]=d}else if((e|0)==61436){a[9753672]=d}else if((e|0)==61437){a[9753673]=d}if((b+4352&65535)>=256){return}a[(c[2442936]|0)+(e-61184)|0]=d;return}function eKp(a){a=a|0;var b=0,d=0;b=a&65535;if((b|0)==65535){d=c[2430812]&255}else if((b|0)==57344){d=c[2430812]&255}else{d=0}return d|0}function eKq(a,b){a=a|0;b=b|0;var c=0;c=a&65535;if((c|0)==49152|(c|0)==49153|(c|0)==49154|(c|0)==49155){TR(1,b&255);return}else if((c|0)==40960|(c|0)==40961|(c|0)==40962|(c|0)==40963){TR(0,b&255);return}else{return}}function eKr(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;if((a[9771768]|0)!=0){e=c[2439330]|0;f=(e|0)==0;if(!f){g=e;gGC(9706056,g|0,76)|0}g=c[2438118]|0;c[2433530]=g;h=c[3528484]|0;c[2076596]=h;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);if(!f){f=e;gGC(f|0,9706056,76)|0}c[2438118]=g;c[3528484]=h;c[2417276]=i;c[1836236]=-1;i=c[2439331]|0;h=(i|0)==0;if(!h){g=i;gGC(9706056,g|0,76)|0}g=c[2438119]|0;c[2433530]=g;f=c[3528485]|0;c[2076596]=f;e=c[2417277]|0;c[3541536]=e;c[1836236]=1;gGz(9706056,0,76);if(!h){h=i;gGC(h|0,9706056,76)|0}c[2438119]=g;c[3528485]=f;c[2417277]=e;c[1836236]=-1;a[9753664]=0;a[9753673]=0;a[9753672]=0;c[2433316]=0;c[2433314]=0;c[2433306]=0;c[2430822]=0;c[2430812]=0;c[2438420]=0;c[2430874]=0;c[2430872]=0;c[2430870]=0;a[9760120]=0;a[9760112]=0}gu[c[2430100]&16383]();c[2444061]=0;c[2444060]=0;e=0;f=0;while(1){g=c[2439330]|0;if((g|0)!=0){h=g;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;h=c[2438118]|0;c[2433530]=h;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;i=e+1|0;j=(ag(c[2440508]|0,i)|0)/10|0;k=c[2444060]|0;l=j-k|0;c[2438178]=l;do{if((l|0)<1){m=0;n=k}else{if((a[g+4188|0]|0)==0){j=gfc(l)|0;c[2433530]=(c[2433530]|0)+j;m=j;n=c[2444060]|0;break}else{c[2433530]=h+l;m=l;n=k;break}}}while(0);c[2438178]=m;c[2444060]=n+m;if((e|0)==9){a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0}k=c[1836236]|0;l=c[9757320+(k<<2)>>2]|0;if((l|0)!=0){h=l;gGC(h|0,9706056,76)|0}c[9752472+(k<<2)>>2]=c[2433530];c[14113936+(k<<2)>>2]=c[2076596];c[9669104+(k<<2)>>2]=c[3541536];c[1836236]=-1;k=c[2439331]|0;if((k|0)!=0){h=k;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;h=c[2438119]|0;c[2433530]=h;c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;l=(ag(a[6517936]|0?66666:0,i)|0)/10|0;g=c[2444061]|0;j=l-g|0;c[2438178]=j;do{if((j|0)<1){o=0;p=g}else{if((a[k+4188|0]|0)==0){l=gfc(j)|0;c[2433530]=(c[2433530]|0)+l;o=l;p=c[2444061]|0;break}else{c[2433530]=h+j;o=j;p=g;break}}}while(0);c[2438178]=o;c[2444061]=p+o;if((e|0)==8|(e|0)==6|(e|0)==4|(e|0)==2){a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0}g=c[1836236]|0;j=c[9757320+(g<<2)>>2]|0;if((j|0)!=0){h=j;gGC(h|0,9706056,76)|0}c[9752472+(g<<2)>>2]=c[2433530];c[14113936+(g<<2)>>2]=c[2076596];c[9669104+(g<<2)>>2]=c[3541536];c[1836236]=-1;q=a[9688]|0;g=q?53:0;r=c[2112964]|0;h=r+(f<<1<<1)|0;TQ(0,h,g);TQ(1,h,g);s=g+f|0;if((i|0)<10){e=i;f=s}else{break}}do{if((r|0)!=0){f=q?534:0;e=f-s|0;o=r+(s<<1<<1)|0;if((f|0)==(s|0)){break}TQ(0,o,e);TQ(1,o,e)}}while(0);if((c[2112968]|0)==0){return 0}s=c[2112926]|0;r=ag(c[2443814]<<1,c[2440436]|0)|0;gGz(s|0,0,r|0);q=c[2430814]|0;if(a[947424]|0){e=c[2438422]|0;o=c[2433310]|0;f=c[2436812]|0;p=c[2438424]|0;m=0;while(1){n=d[q+m|0]|0;g=d[e+n|0]|0;h=d[o+n|0]|0;j=d[f+n|0]|0;c[p+(m<<2)>>2]=(-(h>>>1&1)&31)+(-(h&1)&14)+(-(h>>>2&1)&67)+(-(h>>>3&1)&143)<<3&2016|(-(g>>>1&1)&31)+(-(g&1)&14)+(-(g>>>2&1)&67)+(-(g>>>3&1)&143)<<8&63488|((-(j>>>1&1)&31)+(-(j&1)&14)+(-(j>>>2&1)&67)+(-(j>>>3&1)&143)|0)>>>3&31;j=m+1|0;if((j|0)<1536){m=j}else{t=p;break}}}else{p=c[2438424]|0;m=0;while(1){f=a[q+m|0]|0;o=f&255;e=(o&65535)>>>3;j=(o&65535)>>>6;c[p+(m<<2)>>2]=((j<<4|j<<6|j<<2)&65535)>>>3|((f<<2&24|f<<5)&255)<<8&63488|((e<<2&28|e<<5&255)&255)<<3;e=m+1|0;if((e|0)<1536){m=e}else{t=p;break}}}eNv(-1);eNw(0);eNv(0);gGz(c[2430824]|0,-1|0,65536);p=c[2433308]|0;m=(c[2429476]|0)-1|0;q=a[725184]&1;e=c[2438414]|0;f=0;do{j=f<<4;o=a[p+(j|1)|0]|0;L26705:do{if(o<<24>>24!=0){g=d[p+j|0]|0;h=(o&255)-g|0;if((h|0)<=0){break}n=p+(j|3)|0;k=a[n]|0;l=k&255;u=(l>>>5&2|l>>>7)<<15&m;l=g+1|0;g=(d[p+(j|4)|0]|d[p+(j|5)|0]<<8)<<16>>16;v=p+(j|2)|0;w=0;x=d[p+(j|6)|0]|d[p+(j|7)|0]<<8;y=k;while(1){k=x+g|0;z=l+w|0;A=((d[v]|(y&255)<<8&256)+q|0)>>>1;L26710:do{if((k&32768|0)==0){B=k;C=A;while(1){D=d[e+(B&32767|u)|0]|0;E=B+1|0;F=D>>>4;G=D&15;if((F|0)==15){break L26710}else if((F|0)!=0){eNx(C,z,f,F|j)}if((G|0)==15){break L26710}else if((G|0)!=0){eNx(C+1|0,z,f,G|j)}B=E;C=C+2|0}}else{C=k;B=A;while(1){E=d[e+(C&32767|u)|0]|0;G=C-1|0;F=E&15;D=E>>>4;if((F|0)==15){break L26710}else if((F|0)!=0){eNx(B,z,f,F|j)}if((D|0)==15){break L26710}else if((D|0)!=0){eNx(B+1|0,z,f,D|j)}C=G;B=B+2|0}}}while(0);z=w+1|0;if((z|0)>=(h|0)){break L26705}w=z;x=k;y=a[n]|0}}}while(0);f=f+1|0;}while((f|0)<32);eNv(1);eNw(1);if((c[2433306]&16|0)!=0){gGz(s|0,0,r|0)}R8(t);return 0}function eKs(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[981556+(b*112|0)>>2];c[a+104>>2]=c[981560+(b*112|0)>>2];c[a+108>>2]=c[981564+(b*112|0)>>2];d=0;return d|0}function eKt(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=981456+(b*112|0);e=0;return e|0}function eKu(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3675808+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eKv(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>55){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=983136+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eKw(){c[2438852]=5568;return eNt(3,16384,6,8192,4,16384,1)|0}function eKx(){var b=0,d=0,e=0,f=0;fwZ();TT();c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}b=c[2426676]|0;d=0;while(1){if((d|0)>=1024){break}e=9638528+(d<<2)|0;if((c[e>>2]|0)==(b|0)){f=20290;break}else{d=d+1|0}}if((f|0)==20290){gGr(b);c[e>>2]=0}c[2426676]=0;c[2430812]=0;a[9753664]=0;a[9753673]=0;a[9753672]=0;c[2433316]=0;c[2433314]=0;c[2433306]=0;c[2430822]=0;c[2438420]=0;c[2430874]=0;c[2430872]=0;c[2430870]=0;a[9760120]=0;a[9760112]=0;c[2429476]=0;c[2436814]=0;a[725184]=0;a[947424]=0;a[1666936]=0;c[2438852]=0;c[2430050]=0;c[2430100]=0;return 0}function eKy(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;f=i;i=i+288|0;g=f|0;h=f+16|0;j=f+32|0;k=f+48|0;l=f+64|0;m=f+80|0;n=f+96|0;o=f+112|0;p=f+128|0;q=f+144|0;r=f+160|0;s=f+176|0;t=f+192|0;u=f+208|0;v=f+224|0;w=f+240|0;x=f+256|0;y=f+272|0;if((e|0)!=0){c[e>>2]=169589}if((d&32|0)!=0){gGz(y|0,0,12);z=c[2405612]|0;c[y>>2]=z;c[y+4>>2]=(c[2411546]|0)-z;c[y+12>>2]=162152;z=c[2076592]|0;gj[z&4095](y)|0}if((d&64|0)==0){i=f;return 0}fw$(d);TU(d,e);gGz(x|0,0,12);c[x>>2]=9753672;c[x+4>>2]=2;c[x+12>>2]=334824;gj[c[2076592]&4095](x)|0;gGz(w|0,0,12);c[w>>2]=9776240;c[w+4>>2]=8;c[w+12>>2]=212472;gj[c[2076592]&4095](w)|0;gGz(v|0,0,12);c[v>>2]=9752712;c[v+4>>2]=4;c[v+12>>2]=436576;gj[c[2076592]&4095](v)|0;gGz(u|0,0,12);c[u>>2]=14115696;c[u+4>>2]=2;c[u+12>>2]=332792;gj[c[2076592]&4095](u)|0;gGz(t|0,0,12);c[t>>2]=9771776;c[t+4>>2]=3;c[t+12>>2]=331864;gj[c[2076592]&4095](t)|0;gGz(s|0,0,12);c[s>>2]=9753664;c[s+4>>2]=1;c[s+12>>2]=330688;gj[c[2076592]&4095](s)|0;gGz(r|0,0,12);c[r>>2]=9733264;c[r+4>>2]=4;c[r+12>>2]=329800;gj[c[2076592]&4095](r)|0;gGz(q|0,0,12);c[q>>2]=9733256;c[q+4>>2]=4;c[q+12>>2]=329112;gj[c[2076592]&4095](q)|0;gGz(p|0,0,12);c[p>>2]=9733224;c[p+4>>2]=4;c[p+12>>2]=328240;gj[c[2076592]&4095](p)|0;gGz(o|0,0,12);c[o>>2]=9723288;c[o+4>>2]=4;c[o+12>>2]=327400;gj[c[2076592]&4095](o)|0;gGz(n|0,0,12);c[n>>2]=9723248;c[n+4>>2]=4;c[n+12>>2]=326688;gj[c[2076592]&4095](n)|0;gGz(m|0,0,12);c[m>>2]=9753680;c[m+4>>2]=4;c[m+12>>2]=325920;gj[c[2076592]&4095](m)|0;gGz(l|0,0,12);c[l>>2]=9723496;c[l+4>>2]=4;c[l+12>>2]=324712;gj[c[2076592]&4095](l)|0;gGz(k|0,0,12);c[k>>2]=9723488;c[k+4>>2]=4;c[k+12>>2]=323864;gj[c[2076592]&4095](k)|0;gGz(j|0,0,12);c[j>>2]=9723480;c[j+4>>2]=4;c[j+12>>2]=322992;gj[c[2076592]&4095](j)|0;gGz(h|0,0,12);c[h>>2]=9760120;c[h+4>>2]=1;c[h+12>>2]=321880;gj[c[2076592]&4095](h)|0;gGz(g|0,0,12);c[g>>2]=9760112;c[g+4>>2]=1;c[g+12>>2]=320672;gj[c[2076592]&4095](g)|0;if(!((d&2|0)!=0&a[1666936])){i=f;return 0}d=c[2439330]|0;g=(d|0)==0;if(!g){h=d;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];h=c[3528484]|0;c[2076596]=h;j=c[2417276]|0;c[3541536]=j;c[1836236]=0;k=c[3527014]|0;l=(c[2438420]<<14)+32768|0;m=128;n=128;while(1){c[d+76+(n<<2)>>2]=k+(l+(n<<8));o=m+1&65535;if((o&65535)>191){A=128;B=128;break}else{m=o;n=o&65535}}while(1){n=k+(l+(B<<8))|0;c[d+76+(B+512<<2)>>2]=n;c[d+76+(B+768<<2)>>2]=n;n=A+1&65535;if((n&65535)>191){break}else{A=n;B=n&65535}}if(!g){g=d;gGC(g|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=h;c[2417276]=j;c[1836236]=-1;i=f;return 0}function eKz(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4236004+(b*112|0)>>2];c[a+104>>2]=c[4236008+(b*112|0)>>2];c[a+108>>2]=c[4236012+(b*112|0)>>2];d=0;return d|0}function eKA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=4235904+(b*112|0);e=0;return e|0}function eKB(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1310752+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eKC(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>53){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4237584+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eKD(){var a=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;a=i;i=i+120|0;d=a|0;e=a+112|0;f=0;while(1){if((f|0)>=1024){g=0;break}h=9638528+(f<<2)|0;if((c[h>>2]|0)==0){j=20339;break}else{f=f+1|0}}do{if((j|0)==20339){f=gGq(8192)|0;c[h>>2]=f;if((f|0)==0){g=0;break}gGz(f|0,0,8192);g=f}}while(0);c[2433312]=g;do{if((c[3542200]|0)!=0){h=d+108|0;c[h>>2]=0;f=d+100|0;c[f>>2]=0;k=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[k&16383](d,14)|0;if((c[h>>2]|0)==0){break}h=c[f>>2]|0;c[e>>2]=9534384;f=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[f&16383](e,14,0)|0;if((h|0)<1){break}gzL(g,0,14)|0}}while(0);c[2438852]=7154;g=eNt(2,16384,6,8192,4,16384,1)|0;e=c[2433312]|0;d=0;while(1){if((d|0)>=1024){break}l=9638528+(d<<2)|0;if((c[l>>2]|0)==(e|0)){j=20348;break}else{d=d+1|0}}if((j|0)==20348){gGr(e);c[l>>2]=0}c[2433312]=0;l=c[2439330]|0;e=(l|0)==0;if(!e){j=l;gGC(9706056,j|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];j=c[3528484]|0;c[2076596]=j;d=c[2417276]|0;c[3541536]=d;c[1836236]=0;c[l+4172>>2]=2764;if(e){m=c[2433530]|0;c[2438118]=m;c[3528484]=j;c[2417276]=d;c[1836236]=-1;c[2430100]=1436;i=a;return g|0}e=l;gGC(e|0,9706056,76)|0;m=c[2433530]|0;c[2438118]=m;c[3528484]=j;c[2417276]=d;c[1836236]=-1;c[2430100]=1436;i=a;return g|0}function eKE(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6964412+(b*112|0)>>2];c[a+104>>2]=c[6964416+(b*112|0)>>2];c[a+108>>2]=c[6964420+(b*112|0)>>2];d=0;return d|0}function eKF(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=6964312+(b*112|0);e=0;return e|0}function eKG(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>46){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6965880+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eKH(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;a[947424]=1;a[1666936]=1;d=eNt(3,32768,3,16384,3,32768,0)|0;e=c[2439330]|0;f=(e|0)==0;if(!f){g=e;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];g=c[3528484]|0;c[2076596]=g;h=c[2417276]|0;c[3541536]=h;c[1836236]=0;c[e+4176>>2]=1940;if(f){f=c[2433530]|0;c[2438118]=f;c[3528484]=g;c[2417276]=h;c[1836236]=-1;c[2433530]=f;c[2076596]=g;c[3541536]=h;c[1836236]=0;gGz(9706056,0,76);i=f}else{f=e;gGC(f|0,9706056,76)|0;f=c[2433530]|0;c[2438118]=f;c[3528484]=g;c[2417276]=h;c[1836236]=-1;j=e;gGC(9706056,j|0,76)|0;c[2433530]=f;c[2076596]=g;c[3541536]=h;c[1836236]=0;gGz(9706056,0,76);j=e;gGC(j|0,9706056,76)|0;i=f}c[2438118]=i;c[3528484]=g;c[2417276]=h;c[1836236]=-1;h=c[2439331]|0;g=(h|0)==0;if(!g){i=h;gGC(9706056,i|0,76)|0}i=c[2438119]|0;c[2433530]=i;f=c[3528485]|0;c[2076596]=f;j=c[2417277]|0;c[3541536]=j;c[1836236]=1;gGz(9706056,0,76);if(g){c[2438119]=i;c[3528485]=f;c[2417277]=j;c[1836236]=-1;a[9753664]=0;a[9753673]=0;a[9753672]=0;c[2433316]=0;c[2433314]=0;c[2433306]=0;c[2430822]=0;c[2430812]=0;c[2438420]=0;c[2430874]=0;c[2430872]=0;c[2430870]=0;a[9760120]=0;a[9760112]=0;return d|0}g=h;gGC(g|0,9706056,76)|0;c[2438119]=i;c[3528485]=f;c[2417277]=j;c[1836236]=-1;a[9753664]=0;a[9753673]=0;a[9753672]=0;c[2433316]=0;c[2433314]=0;c[2433306]=0;c[2430822]=0;c[2430812]=0;c[2438420]=0;c[2430874]=0;c[2430872]=0;c[2430870]=0;a[9760120]=0;a[9760112]=0;return d|0}function eKI(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5554076+(b*112|0)>>2];c[a+104>>2]=c[5554080+(b*112|0)>>2];c[a+108>>2]=c[5554084+(b*112|0)>>2];d=0;return d|0}function eKJ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=5553976+(b*112|0);e=0;return e|0}function eKK(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>51){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5555768+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eKL(){c[2438852]=8462;return eNt(6,8192,6,8192,2,16384,1)|0}function eKM(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3319476+(b*112|0)>>2];c[a+104>>2]=c[3319480+(b*112|0)>>2];c[a+108>>2]=c[3319484+(b*112|0)>>2];d=0;return d|0}function eKN(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=3319376+(b*112|0);e=0;return e|0}function eKO(){c[2438852]=8462;return eNt(3,16384,6,8192,2,16384,1)|0}function eKP(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6310564+(b*112|0)>>2];c[a+104>>2]=c[6310568+(b*112|0)>>2];c[a+108>>2]=c[6310572+(b*112|0)>>2];d=0;return d|0}function eKQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=6310464+(b*112|0);e=0;return e|0}function eKR(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3955936+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eKS(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>51){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6311808+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eKT(){c[2438852]=614;return eNt(2,16384,6,8192,2,16384,1)|0}function eKU(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5408628+(b*112|0)>>2];c[a+104>>2]=c[5408632+(b*112|0)>>2];c[a+108>>2]=c[5408636+(b*112|0)>>2];d=0;return d|0}function eKV(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=5408528+(b*112|0);e=0;return e|0}function eKW(){c[2438852]=614;return eNt(2,16384,3,16384,2,16384,1)|0}function eKX(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3954468+(b*112|0)>>2];c[a+104>>2]=c[3954472+(b*112|0)>>2];c[a+108>>2]=c[3954476+(b*112|0)>>2];d=0;return d|0}function eKY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=3954368+(b*112|0);e=0;return e|0}function eKZ(){c[2438852]=614;return eNt(4,8192,6,8192,2,16384,1)|0}function eK_(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3953124+(b*112|0)>>2];c[a+104>>2]=c[3953128+(b*112|0)>>2];c[a+108>>2]=c[3953132+(b*112|0)>>2];d=0;return d|0}function eK$(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=3953024+(b*112|0);e=0;return e|0}function eK0(){return eNt(2,16384,6,8192,2,16384,1)|0}function eK1(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1922980+(b*112|0)>>2];c[a+104>>2]=c[1922984+(b*112|0)>>2];c[a+108>>2]=c[1922988+(b*112|0)>>2];d=0;return d|0}function eK2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=1922880+(b*112|0);e=0;return e|0}function eK3(){return eNt(2,16384,3,16384,2,16384,1)|0}function eK4(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5407060+(b*112|0)>>2];c[a+104>>2]=c[5407064+(b*112|0)>>2];c[a+108>>2]=c[5407068+(b*112|0)>>2];d=0;return d|0}function eK5(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=5406960+(b*112|0);e=0;return e|0}function eK6(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6299292+(b*112|0)>>2];c[a+104>>2]=c[6299296+(b*112|0)>>2];c[a+108>>2]=c[6299300+(b*112|0)>>2];d=0;return d|0}function eK7(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=6299192+(b*112|0);e=0;return e|0}function eK8(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>54){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6300872+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eK9(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;a[947424]=1;a[1666936]=1;c[2438852]=950;d=eNt(3,32768,3,16384,4,32768,0)|0;e=c[2439330]|0;f=(e|0)==0;if(!f){g=e;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];g=c[3528484]|0;c[2076596]=g;h=c[2417276]|0;c[3541536]=h;c[1836236]=0;c[e+4176>>2]=1940;if(f){f=c[2433530]|0;c[2438118]=f;c[3528484]=g;c[2417276]=h;c[1836236]=-1;c[2433530]=f;c[2076596]=g;c[3541536]=h;c[1836236]=0;gGz(9706056,0,76);i=f}else{f=e;gGC(f|0,9706056,76)|0;f=c[2433530]|0;c[2438118]=f;c[3528484]=g;c[2417276]=h;c[1836236]=-1;j=e;gGC(9706056,j|0,76)|0;c[2433530]=f;c[2076596]=g;c[3541536]=h;c[1836236]=0;gGz(9706056,0,76);j=e;gGC(j|0,9706056,76)|0;i=f}c[2438118]=i;c[3528484]=g;c[2417276]=h;c[1836236]=-1;h=c[2439331]|0;g=(h|0)==0;if(!g){i=h;gGC(9706056,i|0,76)|0}i=c[2438119]|0;c[2433530]=i;f=c[3528485]|0;c[2076596]=f;j=c[2417277]|0;c[3541536]=j;c[1836236]=1;gGz(9706056,0,76);if(g){c[2438119]=i;c[3528485]=f;c[2417277]=j;c[1836236]=-1;a[9753664]=0;a[9753673]=0;a[9753672]=0;c[2433316]=0;c[2433314]=0;c[2433306]=0;c[2430822]=0;c[2430812]=0;c[2438420]=0;c[2430874]=0;c[2430872]=0;c[2430870]=0;a[9760120]=0;a[9760112]=0;return d|0}g=h;gGC(g|0,9706056,76)|0;c[2438119]=i;c[3528485]=f;c[2417277]=j;c[1836236]=-1;a[9753664]=0;a[9753673]=0;a[9753672]=0;c[2433316]=0;c[2433314]=0;c[2433306]=0;c[2430822]=0;c[2430812]=0;c[2438420]=0;c[2430874]=0;c[2430872]=0;c[2430870]=0;a[9760120]=0;a[9760112]=0;return d|0}function eLa(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3850188+(b*112|0)>>2];c[a+104>>2]=c[3850192+(b*112|0)>>2];c[a+108>>2]=c[3850196+(b*112|0)>>2];d=0;return d|0}function eLb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=3850088+(b*112|0);e=0;return e|0}function eLc(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>54){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3852104+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eLd(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;a[947424]=1;a[1666936]=1;c[2438852]=2756;d=eNt(3,32768,6,16384,4,32768,0)|0;e=c[2439330]|0;f=(e|0)==0;if(!f){g=e;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];g=c[3528484]|0;c[2076596]=g;h=c[2417276]|0;c[3541536]=h;c[1836236]=0;c[e+4176>>2]=1940;if(f){f=c[2433530]|0;c[2438118]=f;c[3528484]=g;c[2417276]=h;c[1836236]=-1;c[2433530]=f;c[2076596]=g;c[3541536]=h;c[1836236]=0;gGz(9706056,0,76);i=f}else{f=e;gGC(f|0,9706056,76)|0;f=c[2433530]|0;c[2438118]=f;c[3528484]=g;c[2417276]=h;c[1836236]=-1;j=e;gGC(9706056,j|0,76)|0;c[2433530]=f;c[2076596]=g;c[3541536]=h;c[1836236]=0;gGz(9706056,0,76);j=e;gGC(j|0,9706056,76)|0;i=f}c[2438118]=i;c[3528484]=g;c[2417276]=h;c[1836236]=-1;h=c[2439331]|0;g=(h|0)==0;if(!g){i=h;gGC(9706056,i|0,76)|0}i=c[2438119]|0;c[2433530]=i;f=c[3528485]|0;c[2076596]=f;j=c[2417277]|0;c[3541536]=j;c[1836236]=1;gGz(9706056,0,76);if(g){c[2438119]=i;c[3528485]=f;c[2417277]=j;c[1836236]=-1;a[9753664]=0;a[9753673]=0;a[9753672]=0;c[2433316]=0;c[2433314]=0;c[2433306]=0;c[2430822]=0;c[2430812]=0;c[2438420]=0;c[2430874]=0;c[2430872]=0;c[2430870]=0;a[9760120]=0;a[9760112]=0;return d|0}g=h;gGC(g|0,9706056,76)|0;c[2438119]=i;c[3528485]=f;c[2417277]=j;c[1836236]=-1;a[9753664]=0;a[9753673]=0;a[9753672]=0;c[2433316]=0;c[2433314]=0;c[2433306]=0;c[2430822]=0;c[2430812]=0;c[2438420]=0;c[2430874]=0;c[2430872]=0;c[2430870]=0;a[9760120]=0;a[9760112]=0;return d|0}function eLe(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5342388+(b*112|0)>>2];c[a+104>>2]=c[5342392+(b*112|0)>>2];c[a+108>>2]=c[5342396+(b*112|0)>>2];d=0;return d|0}function eLf(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=5342288+(b*112|0);e=0;return e|0}function eLg(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>51){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5343744+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eLh(){c[2438852]=10444;return eNt(3,16384,6,8192,2,16384,1)|0}function eLi(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3844964+(b*112|0)>>2];c[a+104>>2]=c[3844968+(b*112|0)>>2];c[a+108>>2]=c[3844972+(b*112|0)>>2];d=0;return d|0}function eLj(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=3844864+(b*112|0);e=0;return e|0}function eLk(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3697004+(b*112|0)>>2];c[a+104>>2]=c[3697008+(b*112|0)>>2];c[a+108>>2]=c[3697012+(b*112|0)>>2];d=0;return d|0}function eLl(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=3696904+(b*112|0);e=0;return e|0}function eLm(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>54){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3698696+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eLn(){c[2438852]=5554;return eNt(6,8192,6,8192,2,16384,1)|0}function eLo(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1819132+(b*112|0)>>2];c[a+104>>2]=c[1819136+(b*112|0)>>2];c[a+108>>2]=c[1819140+(b*112|0)>>2];d=0;return d|0}function eLp(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=1819032+(b*112|0);e=0;return e|0}function eLq(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>51){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3696280+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eLr(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6210148+(b*112|0)>>2];c[a+104>>2]=c[6210152+(b*112|0)>>2];c[a+108>>2]=c[6210156+(b*112|0)>>2];d=0;return d|0}function eLs(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=6210048+(b*112|0);e=0;return e|0}function eLt(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>54){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6211728+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eLu(){return eNt(3,16384,6,8192,4,16384,1)|0}function eLv(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3377268+(b*112|0)>>2];c[a+104>>2]=c[3377272+(b*112|0)>>2];c[a+108>>2]=c[3377276+(b*112|0)>>2];d=0;return d|0}function eLw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=3377168+(b*112|0);e=0;return e|0}function eLx(){c[2438852]=1960;return eNt(3,16384,6,8192,4,16384,1)|0}function eLy(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5228732+(b*112|0)>>2];c[a+104>>2]=c[5228736+(b*112|0)>>2];c[a+108>>2]=c[5228740+(b*112|0)>>2];d=0;return d|0}function eLz(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=5228632+(b*112|0);e=0;return e|0}function eLA(){c[2438852]=8054;c[2430050]=4992;return eNt(3,16384,3,16384,4,16384,1)|0}function eLB(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7388404+(b*112|0)>>2];c[a+104>>2]=c[7388408+(b*112|0)>>2];c[a+108>>2]=c[7388412+(b*112|0)>>2];d=0;return d|0}function eLC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=7388304+(b*112|0);e=0;return e|0}function eLD(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>38){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7165896+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eLE(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;a[947424]=1;a[1666936]=1;d=eNt(3,32768,3,32768,4,32768,0)|0;c[2440508]=133333;a[(c[3527012]|0)+761|0]=40;e=c[2439330]|0;f=(e|0)==0;if(!f){g=e;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];g=c[3528484]|0;c[2076596]=g;h=c[2417276]|0;c[3541536]=h;c[1836236]=0;c[e+4184>>2]=914;c[e+4172>>2]=2368;c[e+4176>>2]=2352;i=e+844|0;gGz(i|0,0,256);gGz(e+1868|0,0,256);j=192;k=192;while(1){c[e+76+(k+512<<2)>>2]=0;c[e+76+(k+768<<2)>>2]=0;l=j+1&65535;if((l&65535)>255){break}else{j=l;k=l&65535}}k=c[2429304]|0;c[i>>2]=k;i=k+256|0;c[e+848>>2]=i;j=k+512|0;c[e+852>>2]=j;l=k+768|0;c[e+856>>2]=l;c[e+2892>>2]=k;c[e+3916>>2]=k;c[e+2896>>2]=i;c[e+3920>>2]=i;c[e+2900>>2]=j;c[e+3924>>2]=j;c[e+2904>>2]=l;c[e+3928>>2]=l;l=c[2442934]|0;c[e+860>>2]=l;j=l+256|0;c[e+864>>2]=j;i=l+512|0;c[e+868>>2]=i;k=l+768|0;c[e+872>>2]=k;c[e+1884>>2]=l;c[e+1888>>2]=j;c[e+1892>>2]=i;c[e+1896>>2]=k;c[e+2908>>2]=l;c[e+3932>>2]=l;c[e+2912>>2]=j;c[e+3936>>2]=j;c[e+2916>>2]=i;c[e+3940>>2]=i;c[e+2920>>2]=k;c[e+3944>>2]=k;k=c[2427080]|0;c[e+876>>2]=k;i=k+256|0;c[e+880>>2]=i;j=k+512|0;c[e+884>>2]=j;l=k+768|0;c[e+888>>2]=l;c[e+2924>>2]=k;c[e+3948>>2]=k;c[e+2928>>2]=i;c[e+3952>>2]=i;c[e+2932>>2]=j;c[e+3956>>2]=j;c[e+2936>>2]=l;c[e+3960>>2]=l;l=c[2442932]|0;c[e+892>>2]=l;j=l+256|0;c[e+896>>2]=j;i=l+512|0;c[e+900>>2]=i;k=l+768|0;c[e+904>>2]=k;c[e+1916>>2]=l;c[e+1920>>2]=j;c[e+1924>>2]=i;c[e+1928>>2]=k;c[e+2940>>2]=l;c[e+3964>>2]=l;c[e+2944>>2]=j;c[e+3968>>2]=j;c[e+2948>>2]=i;c[e+3972>>2]=i;c[e+2952>>2]=k;c[e+3976>>2]=k;k=c[2433308]|0;c[e+908>>2]=k;i=k+256|0;c[e+912>>2]=i;c[e+1932>>2]=k;c[e+1936>>2]=i;c[e+2956>>2]=k;c[e+3980>>2]=k;c[e+2960>>2]=i;c[e+3984>>2]=i;i=c[3527018]|0;k=i+4096|0;c[e+916>>2]=k;j=i+4352|0;c[e+920>>2]=j;l=i+4608|0;c[e+924>>2]=l;m=i+4864|0;c[e+928>>2]=m;n=i+5120|0;c[e+932>>2]=n;o=i+5376|0;c[e+936>>2]=o;c[e+1940>>2]=k;c[e+1944>>2]=j;c[e+1948>>2]=l;c[e+1952>>2]=m;c[e+1956>>2]=n;c[e+1960>>2]=o;c[e+2964>>2]=k;c[e+3988>>2]=k;c[e+2968>>2]=j;c[e+3992>>2]=j;c[e+2972>>2]=l;c[e+3996>>2]=l;c[e+2976>>2]=m;c[e+4e3>>2]=m;c[e+2980>>2]=n;c[e+4004>>2]=n;c[e+2984>>2]=o;c[e+4008>>2]=o;o=c[2430814]|0;c[e+940>>2]=o;n=o+256|0;c[e+944>>2]=n;m=o+512|0;c[e+948>>2]=m;l=o+768|0;c[e+952>>2]=l;j=o+1024|0;c[e+956>>2]=j;k=o+1280|0;c[e+960>>2]=k;c[e+1964>>2]=o;c[e+1968>>2]=n;c[e+1972>>2]=m;c[e+1976>>2]=l;c[e+1980>>2]=j;c[e+1984>>2]=k;c[e+2988>>2]=o;c[e+4012>>2]=o;c[e+2992>>2]=n;c[e+4016>>2]=n;c[e+2996>>2]=m;c[e+4020>>2]=m;c[e+3e3>>2]=l;c[e+4024>>2]=l;c[e+3004>>2]=j;c[e+4028>>2]=j;c[e+3008>>2]=k;c[e+4032>>2]=k;k=c[2442938]|0;c[e+964>>2]=k;j=k+256|0;c[e+968>>2]=j;c[e+1988>>2]=k;c[e+1992>>2]=j;c[e+3012>>2]=k;c[e+4036>>2]=k;c[e+3016>>2]=j;c[e+4040>>2]=j;j=c[2442946]|0;c[e+972>>2]=j;k=j+256|0;c[e+976>>2]=k;l=j+512|0;c[e+980>>2]=l;m=j+768|0;c[e+984>>2]=m;n=j+1024|0;c[e+988>>2]=n;o=j+1280|0;c[e+992>>2]=o;p=j+1536|0;c[e+996>>2]=p;q=j+1792|0;c[e+1e3>>2]=q;c[e+1996>>2]=j;c[e+2e3>>2]=k;c[e+2004>>2]=l;c[e+2008>>2]=m;c[e+2012>>2]=n;c[e+2016>>2]=o;c[e+2020>>2]=p;c[e+2024>>2]=q;c[e+3020>>2]=j;c[e+4044>>2]=j;c[e+3024>>2]=k;c[e+4048>>2]=k;c[e+3028>>2]=l;c[e+4052>>2]=l;c[e+3032>>2]=m;c[e+4056>>2]=m;c[e+3036>>2]=n;c[e+4060>>2]=n;c[e+3040>>2]=o;c[e+4064>>2]=o;c[e+3044>>2]=p;c[e+4068>>2]=p;c[e+3048>>2]=q;c[e+4072>>2]=q;q=c[2436810]|0;c[e+1004>>2]=q;p=q+256|0;c[e+1008>>2]=p;o=q+512|0;c[e+1012>>2]=o;n=q+768|0;c[e+1016>>2]=n;m=q+1024|0;c[e+1020>>2]=m;l=q+1280|0;c[e+1024>>2]=l;k=q+1536|0;c[e+1028>>2]=k;c[e+2028>>2]=q;c[e+2032>>2]=p;c[e+2036>>2]=o;c[e+2040>>2]=n;c[e+2044>>2]=m;c[e+2048>>2]=l;c[e+2052>>2]=k;c[e+3052>>2]=q;c[e+4076>>2]=q;c[e+3056>>2]=p;c[e+4080>>2]=p;c[e+3060>>2]=o;c[e+4084>>2]=o;c[e+3064>>2]=n;c[e+4088>>2]=n;c[e+3068>>2]=m;c[e+4092>>2]=m;c[e+3072>>2]=l;c[e+4096>>2]=l;c[e+3076>>2]=k;c[e+4100>>2]=k;k=c[2442936]|0;c[e+1032>>2]=k;c[e+3080>>2]=k;c[e+4104>>2]=k;c[e+1036>>2]=i;c[e+1040>>2]=i+256;c[e+1044>>2]=i+512;c[e+1048>>2]=i+768;c[e+1052>>2]=i+1024;c[e+1056>>2]=i+1280;c[e+1060>>2]=i+1536;c[e+1064>>2]=i+1792;c[e+1068>>2]=i+2048;c[e+1072>>2]=i+2304;c[e+1076>>2]=i+2560;c[e+1080>>2]=i+2816;c[e+1084>>2]=i+3072;c[e+1088>>2]=i+3328;c[e+1092>>2]=i+3584;c[e+1096>>2]=i+3840;k=240;l=240;while(1){c[e+76+(l+256<<2)>>2]=i+((l<<8)-61440);m=k+1&65535;if((m&65535)>255){r=240;s=240;break}else{k=m;l=m&65535}}while(1){l=i+((s<<8)-61440)|0;c[e+76+(s+512<<2)>>2]=l;c[e+76+(s+768<<2)>>2]=l;l=r+1&65535;if((l&65535)>255){break}else{r=l;s=l&65535}}if(f){f=c[2433530]|0;c[2438118]=f;c[3528484]=g;c[2417276]=h;c[1836236]=-1;c[2433530]=f;c[2076596]=g;c[3541536]=h;c[1836236]=0;gGz(9706056,0,76);t=f}else{f=e;gGC(f|0,9706056,76)|0;f=c[2433530]|0;c[2438118]=f;c[3528484]=g;c[2417276]=h;c[1836236]=-1;s=e;gGC(9706056,s|0,76)|0;c[2433530]=f;c[2076596]=g;c[3541536]=h;c[1836236]=0;gGz(9706056,0,76);s=e;gGC(s|0,9706056,76)|0;t=f}c[2438118]=t;c[3528484]=g;c[2417276]=h;c[1836236]=-1;h=c[2439331]|0;g=(h|0)==0;if(!g){t=h;gGC(9706056,t|0,76)|0}t=c[2438119]|0;c[2433530]=t;f=c[3528485]|0;c[2076596]=f;s=c[2417277]|0;c[3541536]=s;c[1836236]=1;gGz(9706056,0,76);if(g){c[2438119]=t;c[3528485]=f;c[2417277]=s;c[1836236]=-1;a[9753664]=0;a[9753673]=0;a[9753672]=0;c[2433316]=0;c[2433314]=0;c[2433306]=0;c[2430822]=0;c[2430812]=0;c[2438420]=0;c[2430874]=0;c[2430872]=0;c[2430870]=0;a[9760120]=0;a[9760112]=0;return d|0}g=h;gGC(g|0,9706056,76)|0;c[2438119]=t;c[3528485]=f;c[2417277]=s;c[1836236]=-1;a[9753664]=0;a[9753673]=0;a[9753672]=0;c[2433316]=0;c[2433314]=0;c[2433306]=0;c[2430822]=0;c[2430812]=0;c[2438420]=0;c[2430874]=0;c[2430872]=0;c[2430870]=0;a[9760120]=0;a[9760112]=0;return d|0}function eLF(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7164316+(b*112|0)>>2];c[a+104>>2]=c[7164320+(b*112|0)>>2];c[a+108>>2]=c[7164324+(b*112|0)>>2];d=0;return d|0}function eLG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=7164216+(b*112|0);e=0;return e|0}function eLH(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3621788+(b*112|0)>>2];c[a+104>>2]=c[3621792+(b*112|0)>>2];c[a+108>>2]=c[3621796+(b*112|0)>>2];d=0;return d|0}function eLI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=3621688+(b*112|0);e=0;return e|0}function eLJ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>55){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3623144+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eLK(){var a=0;c[2438852]=6370;a=eNt(3,16384,6,8192,2,16384,1)|0;c[2440508]=6e4;return a|0}function eLL(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1785948+(b*112|0)>>2];c[a+104>>2]=c[1785952+(b*112|0)>>2];c[a+108>>2]=c[1785956+(b*112|0)>>2];d=0;return d|0}function eLM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=1785848+(b*112|0);e=0;return e|0}function eLN(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1784492+(b*112|0)>>2];c[a+104>>2]=c[1784496+(b*112|0)>>2];c[a+108>>2]=c[1784500+(b*112|0)>>2];d=0;return d|0}function eLO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=1784392+(b*112|0);e=0;return e|0}function eLP(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>54){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3621024+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eLQ(){var a=0;a=eNt(3,16384,6,8192,2,16384,1)|0;c[2440508]=6e4;return a|0}function eLR(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3579964+(b*112|0)>>2];c[a+104>>2]=c[3579968+(b*112|0)>>2];c[a+108>>2]=c[3579972+(b*112|0)>>2];d=0;return d|0}function eLS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=3579864+(b*112|0);e=0;return e|0}function eLT(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>51){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3581544+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eLU(){c[2438852]=5568;return eNt(3,16384,6,8192,4,16384,1)|0}function eLV(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5102428+(b*112|0)>>2];c[a+104>>2]=c[5102432+(b*112|0)>>2];c[a+108>>2]=c[5102436+(b*112|0)>>2];d=0;return d|0}function eLW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=5102328+(b*112|0);e=0;return e|0}function eLX(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>49){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5104120+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eLY(){c[2438852]=2954;return eNt(6,8192,6,8192,2,16384,1)|0}function eLZ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3566188+(b*112|0)>>2];c[a+104>>2]=c[3566192+(b*112|0)>>2];c[a+108>>2]=c[3566196+(b*112|0)>>2];d=0;return d|0}function eL_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=3566088+(b*112|0);e=0;return e|0}function eL$(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>46){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3567880+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eL0(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3564396+(b*112|0)>>2];c[a+104>>2]=c[3564400+(b*112|0)>>2];c[a+108>>2]=c[3564404+(b*112|0)>>2];d=0;return d|0}function eL1(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=3564296+(b*112|0);e=0;return e|0}function eL2(){return eNt(6,8192,6,8192,2,16384,1)|0}function eL3(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3510380+(b*112|0)>>2];c[a+104>>2]=c[3510384+(b*112|0)>>2];c[a+108>>2]=c[3510388+(b*112|0)>>2];d=0;return d|0}function eL4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=3510280+(b*112|0);e=0;return e|0}function eL5(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1197480+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eL6(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>55){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3511960+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eL7(){c[2438852]=8868;return eNt(3,16384,6,8192,4,16384,1)|0}function eL8(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1740884+(b*112|0)>>2];c[a+104>>2]=c[1740888+(b*112|0)>>2];c[a+108>>2]=c[1740892+(b*112|0)>>2];d=0;return d|0}function eL9(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=1740784+(b*112|0);e=0;return e|0}function eMa(){return eNt(3,16384,6,8192,4,16384,1)|0}function eMb(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6826828+(b*112|0)>>2];c[a+104>>2]=c[6826832+(b*112|0)>>2];c[a+108>>2]=c[6826836+(b*112|0)>>2];d=0;return d|0}function eMc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=6826728+(b*112|0);e=0;return e|0}function eMd(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3658180+(b*112|0)>>2];c[a+104>>2]=c[3658184+(b*112|0)>>2];c[a+108>>2]=c[3658188+(b*112|0)>>2];d=0;return d|0}function eMe(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=3658080+(b*112|0);e=0;return e|0}function eMf(){c[2438852]=614;return eNt(6,8192,6,8192,4,16384,1)|0}function eMg(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1798188+(b*112|0)>>2];c[a+104>>2]=c[1798192+(b*112|0)>>2];c[a+108>>2]=c[1798196+(b*112|0)>>2];d=0;return d|0}function eMh(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=1798088+(b*112|0);e=0;return e|0}function eMi(){c[2438852]=11160;return eNt(3,16384,6,8192,4,16384,1)|0}function eMj(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1796172+(b*112|0)>>2];c[a+104>>2]=c[1796176+(b*112|0)>>2];c[a+108>>2]=c[1796180+(b*112|0)>>2];d=0;return d|0}function eMk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=1796072+(b*112|0);e=0;return e|0}function eMl(){return eNt(6,8192,6,8192,4,16384,1)|0}function eMm(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1799868+(b*112|0)>>2];c[a+104>>2]=c[1799872+(b*112|0)>>2];c[a+108>>2]=c[1799876+(b*112|0)>>2];d=0;return d|0}function eMn(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=1799768+(b*112|0);e=0;return e|0}function eMo(){c[2438852]=614;return eNt(3,16384,6,8192,4,16384,1)|0}function eMp(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4973924+(b*112|0)>>2];c[a+104>>2]=c[4973928+(b*112|0)>>2];c[a+108>>2]=c[4973932+(b*112|0)>>2];d=0;return d|0}function eMq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=4973824+(b*112|0);e=0;return e|0}function eMr(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>54){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4975504+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eMs(){c[2438852]=6708;return eNt(3,16384,6,8192,4,16384,1)|0}function eMt(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3378948+(b*112|0)>>2];c[a+104>>2]=c[3378952+(b*112|0)>>2];c[a+108>>2]=c[3378956+(b*112|0)>>2];d=0;return d|0}function eMu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=3378848+(b*112|0);e=0;return e|0}function eMv(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3363524+(b*112|0)>>2];c[a+104>>2]=c[3363528+(b*112|0)>>2];c[a+108>>2]=c[3363532+(b*112|0)>>2];d=0;return d|0}function eMw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=3363424+(b*112|0);e=0;return e|0}function eMx(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>57){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3365216+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eMy(){return eNt(6,8192,6,8192,2,16384,1)|0}function eMz(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1684580+(b*112|0)>>2];c[a+104>>2]=c[1684584+(b*112|0)>>2];c[a+108>>2]=c[1684588+(b*112|0)>>2];d=0;return d|0}function eMA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=1684480+(b*112|0);e=0;return e|0}function eMB(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>56){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3362736+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eMC(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7116692+(b*112|0)>>2];c[a+104>>2]=c[7116696+(b*112|0)>>2];c[a+108>>2]=c[7116700+(b*112|0)>>2];d=0;return d|0}function eMD(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=7116592+(b*112|0);e=0;return e|0}function eME(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>52){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7118384+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eMF(){c[2438852]=708;return eNt(6,8192,6,8192,2,16384,1)|0}function eMG(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4933868+(b*112|0)>>2];c[a+104>>2]=c[4933872+(b*112|0)>>2];c[a+108>>2]=c[4933876+(b*112|0)>>2];d=0;return d|0}function eMH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=4933768+(b*112|0);e=0;return e|0}function eMI(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>54){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4935448+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eMJ(){c[2438852]=410;return eNt(3,16384,6,8192,4,16384,1)|0}function eMK(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3322556+(b*112|0)>>2];c[a+104>>2]=c[3322560+(b*112|0)>>2];c[a+108>>2]=c[3322564+(b*112|0)>>2];d=0;return d|0}function eML(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=3322456+(b*112|0);e=0;return e|0}function eMM(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1181212+(b*112|0)>>2];c[a+104>>2]=c[1181216+(b*112|0)>>2];c[a+108>>2]=c[1181220+(b*112|0)>>2];d=0;return d|0}function eMN(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=1181112+(b*112|0);e=0;return e|0}function eMO(){c[2438852]=410;return eNt(3,16384,3,16384,4,16384,1)|0}function eMP(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4901532+(b*112|0)>>2];c[a+104>>2]=c[4901536+(b*112|0)>>2];c[a+108>>2]=c[4901540+(b*112|0)>>2];d=0;return d|0}function eMQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=4901432+(b*112|0);e=0;return e|0}function eMR(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1650648+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eMS(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>57){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4903224+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eMT(){c[2438852]=11160;return eNt(6,8192,6,8192,2,16384,1)|0}function eMU(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3271204+(b*112|0)>>2];c[a+104>>2]=c[3271208+(b*112|0)>>2];c[a+108>>2]=c[3271212+(b*112|0)>>2];d=0;return d|0}function eMV(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=3271104+(b*112|0);e=0;return e|0}function eMW(){return eNt(6,8192,6,8192,2,16384,1)|0}function eMX(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7097124+(b*112|0)>>2];c[a+104>>2]=c[7097128+(b*112|0)>>2];c[a+108>>2]=c[7097132+(b*112|0)>>2];d=0;return d|0}function eMY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=7097024+(b*112|0);e=0;return e|0}function eMZ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6003840+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eM_(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>55){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7098704+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eM$(){c[2438852]=10680;return eNt(3,16384,6,8192,4,16384,1)|0}function eM0(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6631436+(b*112|0)>>2];c[a+104>>2]=c[6631440+(b*112|0)>>2];c[a+108>>2]=c[6631444+(b*112|0)>>2];d=0;return d|0}function eM1(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=6631336+(b*112|0);e=0;return e|0}function eM2(){c[2438852]=2756;return eNt(3,16384,6,8192,4,16384,1)|0}function eM3(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6638156+(b*112|0)>>2];c[a+104>>2]=c[6638160+(b*112|0)>>2];c[a+108>>2]=c[6638164+(b*112|0)>>2];d=0;return d|0}function eM4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=6638056+(b*112|0);e=0;return e|0}function eM5(){c[2438852]=9904;return eNt(6,8192,6,8192,4,16384,1)|0}function eM6(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6004212+(b*112|0)>>2];c[a+104>>2]=c[6004216+(b*112|0)>>2];c[a+108>>2]=c[6004220+(b*112|0)>>2];d=0;return d|0}function eM7(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=6004112+(b*112|0);e=0;return e|0}function eM8(){return eNt(6,8192,6,8192,4,16384,1)|0}function eM9(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6635804+(b*112|0)>>2];c[a+104>>2]=c[6635808+(b*112|0)>>2];c[a+108>>2]=c[6635812+(b*112|0)>>2];d=0;return d|0}function eNa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=6635704+(b*112|0);e=0;return e|0}function eNb(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>55){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6637384+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eNc(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6634796+(b*112|0)>>2];c[a+104>>2]=c[6634800+(b*112|0)>>2];c[a+108>>2]=c[6634804+(b*112|0)>>2];d=0;return d|0}function eNd(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=6634696+(b*112|0);e=0;return e|0}function eNe(){c[2438852]=5568;return eNt(2,32768,3,16384,2,32768,1)|0}function eNf(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6633116+(b*112|0)>>2];c[a+104>>2]=c[6633120+(b*112|0)>>2];c[a+108>>2]=c[6633124+(b*112|0)>>2];d=0;return d|0}function eNg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=6633016+(b*112|0);e=0;return e|0}function eNh(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6629396+(b*112|0)>>2];c[a+104>>2]=c[6629400+(b*112|0)>>2];c[a+108>>2]=c[6629404+(b*112|0)>>2];d=0;return d|0}function eNi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=6629296+(b*112|0);e=0;return e|0}function eNj(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>29){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6630976+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eNk(){return eNt(3,16384,6,8192,4,16384,1)|0}function eNl(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3249596+(b*112|0)>>2];c[a+104>>2]=c[3249600+(b*112|0)>>2];c[a+108>>2]=c[3249604+(b*112|0)>>2];d=0;return d|0}function eNm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=3249496+(b*112|0);e=0;return e|0}function eNn(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>58){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3251512+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eNo(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5988804+(b*112|0)>>2];c[a+104>>2]=c[5988808+(b*112|0)>>2];c[a+108>>2]=c[5988812+(b*112|0)>>2];d=0;return d|0}function eNp(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=5988704+(b*112|0);e=0;return e|0}function eNq(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>26){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3246288+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eNr(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>52){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5990496+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eNs(){c[2438852]=1304;return eNt(6,8192,6,8192,2,16384,1)|0}function eNt(e,f,g,j,k,l,m){e=e|0;f=f|0;g=g|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0;n=i;i=i+840|0;o=n|0;p=n+112|0;q=n+120|0;r=n+232|0;s=n+240|0;t=n+352|0;u=n+360|0;v=n+472|0;w=n+480|0;x=n+592|0;y=n+600|0;z=n+712|0;A=n+720|0;B=n+832|0;C=(ag(j,g)|0)/24|0;c[2436814]=C;D=ag(l,k)|0;c[2429476]=D;c[2426676]=0;c[3527014]=0;c[2439400]=131072;c[3527012]=196608;c[2438422]=229376;c[2433310]=229632;c[2436812]=229888;c[2405612]=230144;c[3527018]=230144;c[3527016]=238589;c[2433308]=240637;c[2430814]=241149;c[2442946]=242685;c[2436810]=244733;c[2429304]=246525;c[2427080]=247549;c[2442938]=248573;c[2442936]=249085;c[2442934]=249341;c[2442932]=250365;c[2430824]=251389;c[2411546]=316925;c[2438414]=316925;E=D+316925|0;c[2442940]=E;D=(C<<6)+E|0;c[2429474]=D;E=D+(C<<2)|0;c[2438424]=E;C=E+6144|0;c[2414086]=C;E=C;C=0;while(1){if((C|0)>=1024){break}F=9638528+(C<<2)|0;if((c[F>>2]|0)==0){G=21321;break}else{C=C+1|0}}do{if((G|0)==21321){C=gGq(E)|0;c[F>>2]=C;if((C|0)==0){break}gGz(C|0,0,E|0);c[2426676]=C;gGz(C|0,0,E|0);c[3527014]=C;c[2439400]=C+131072;c[3527012]=C+196608;c[2438422]=C+229376;c[2433310]=C+229632;c[2436812]=C+229888;D=C+230144|0;c[2405612]=D;c[3527018]=D;c[3527016]=C+238589;c[2433308]=C+240637;c[2430814]=C+241149;c[2442946]=C+242685;c[2436810]=C+244733;c[2429304]=C+246525;c[2427080]=C+247549;c[2442938]=C+248573;c[2442936]=C+249085;c[2442934]=C+249341;c[2442932]=C+250365;c[2430824]=C+251389;D=C+316925|0;c[2411546]=D;c[2438414]=D;D=(c[2429476]|0)+316925|0;c[2442940]=C+D;H=c[2436814]|0;I=(H<<6)+D|0;c[2429474]=C+I;D=I+(H<<2)|0;c[2438424]=C+D;c[2414086]=C+(D+6144);D=0;while(1){if((D|0)>=1024){J=0;break}K=9638528+(D<<2)|0;if((c[K>>2]|0)==0){G=21326;break}else{D=D+1|0}}do{if((G|0)==21326){D=gGq(98304)|0;c[K>>2]=D;if((D|0)==0){J=0;break}gGz(D|0,0,98304);J=D}}while(0);c[2438412]=J;L27932:do{if((e|0)>0){D=A+108|0;C=A+100|0;H=0;while(1){I=c[3527014]|0;L=I+(ag(H,f)|0)|0;if((c[3542200]|0)==0){M=1;G=21466;break}c[D>>2]=0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](A,H)|0;if((c[D>>2]|0)!=0){I=c[C>>2]|0;c[B>>2]=9534384;N=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[N&16383](B,H,0)|0;if((I|0)<1){M=1;G=21465;break}if((gzL(L,0,H)|0)!=0){M=1;G=21460;break}}H=H+1|0;if((H|0)>=(e|0)){break L27932}}if((G|0)==21460){i=n;return M|0}else if((G|0)==21465){i=n;return M|0}else if((G|0)==21466){i=n;return M|0}}}while(0);if(a[1666936]|0){H=c[2438412]|0;C=c[3527014]|0;gGC(H|0,C|0,98304)|0;gGz(C|0,0,98304);gGC(C|0,H|0,32768)|0;D=C+65536|0;L=H+32768|0;gGC(D|0,L|0,32768)|0;D=C+32768|0;gGC(D|0,L|0,32768)|0;L=C+98304|0;C=H+65536|0;gGC(L|0,C|0,32768)|0}C=c[2438852]|0;if((C|0)!=0){gu[C&16383]()}C=y+108|0;L=y+100|0;H=c[3527012]|0;if((c[3542200]|0)==0){M=1;i=n;return M|0}c[C>>2]=0;c[L>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](y,e)|0;do{if((c[C>>2]|0)!=0){D=c[L>>2]|0;c[z>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](z,e,0)|0;if((D|0)<1){M=1;i=n;return M|0}if((gzL(H,0,e)|0)==0){break}else{M=1}i=n;return M|0}}while(0);H=c[2438412]|0;gGz(H|0,0,98304);L=e+1|0;L27962:do{if((g|0)>0){C=w+108|0;D=w+100|0;I=0;N=H;while(1){O=N+(ag(I,j)|0)|0;P=I+L|0;do{if((c[3542200]|0)!=0){c[C>>2]=0;c[D>>2]=0;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Q&16383](w,P)|0;if((c[C>>2]|0)==0){break}Q=c[D>>2]|0;c[x>>2]=9534384;R=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[R&16383](x,P,0)|0;if((Q|0)<1){break}gzL(O,0,P)|0}}while(0);P=I+1|0;if((P|0)>=(g|0)){break L27962}I=P;N=c[2438412]|0}}}while(0);if((c[2430050]|0)!=0){eNH()}H=c[2436814]|0;N=c[2438412]|0;I=c[2442940]|0;do{if((H|0)>2048){D=0;while(1){C=D<<6;gGz(I+C|0,0,64);P=0;do{O=C+(c[1238464+(P<<2)>>2]|0)|0;Q=(P<<3)+C|0;R=0;do{S=O+(c[614800+(R<<2)>>2]|0)|0;if(((d[N+((S|0)/8|0)|0]|0)&128>>>((S&7)>>>0)|0)!=0){S=I+(Q+R)|0;a[S]=a[S]|4}R=R+1|0;}while((R|0)<8);P=P+1|0;}while((P|0)<8);P=C+262144|0;R=0;do{Q=P+(c[1238464+(R<<2)>>2]|0)|0;O=(R<<3)+C|0;S=0;do{T=Q+(c[614800+(S<<2)>>2]|0)|0;if(((d[N+((T|0)/8|0)|0]|0)&128>>>((T&7)>>>0)|0)!=0){T=I+(O+S)|0;a[T]=a[T]|2}S=S+1|0;}while((S|0)<8);R=R+1|0;}while((R|0)<8);R=C+524288|0;P=0;do{S=R+(c[1238464+(P<<2)>>2]|0)|0;O=(P<<3)+C|0;Q=0;do{T=S+(c[614800+(Q<<2)>>2]|0)|0;if(((d[N+((T|0)/8|0)|0]|0)&128>>>((T&7)>>>0)|0)!=0){T=I+(O+Q)|0;a[T]=a[T]|1}Q=Q+1|0;}while((Q|0)<8);P=P+1|0;}while((P|0)<8);P=D+1|0;if((P|0)<(H|0)){D=P}else{G=21369;break}}}else{if((H|0)>0){U=0}else{V=0;break}while(1){D=U<<6;gGz(I+D|0,0,64);P=0;do{C=D+(c[1238464+(P<<2)>>2]|0)|0;R=(P<<3)+D|0;Q=0;do{O=C+(c[614800+(Q<<2)>>2]|0)|0;if(((d[N+((O|0)/8|0)|0]|0)&128>>>((O&7)>>>0)|0)!=0){O=I+(R+Q)|0;a[O]=a[O]|4}Q=Q+1|0;}while((Q|0)<8);P=P+1|0;}while((P|0)<8);P=D+131072|0;Q=0;do{R=P+(c[1238464+(Q<<2)>>2]|0)|0;C=(Q<<3)+D|0;O=0;do{S=R+(c[614800+(O<<2)>>2]|0)|0;if(((d[N+((S|0)/8|0)|0]|0)&128>>>((S&7)>>>0)|0)!=0){S=I+(C+O)|0;a[S]=a[S]|2}O=O+1|0;}while((O|0)<8);Q=Q+1|0;}while((Q|0)<8);Q=D+262144|0;P=0;do{O=Q+(c[1238464+(P<<2)>>2]|0)|0;C=(P<<3)+D|0;R=0;do{S=O+(c[614800+(R<<2)>>2]|0)|0;if(((d[N+((S|0)/8|0)|0]|0)&128>>>((S&7)>>>0)|0)!=0){S=I+(C+R)|0;a[S]=a[S]|1}R=R+1|0;}while((R|0)<8);P=P+1|0;}while((P|0)<8);P=U+1|0;if((P|0)<(H|0)){U=P}else{G=21369;break}}}}while(0);do{if((G|0)==21369){if((H|0)<=0){V=0;break}P=c[2429474]|0;D=0;while(1){Q=0;R=0;C=I+(D<<6)|0;while(1){W=1<<(d[C]|0)|R|1<<(d[C+1|0]|0)|1<<(d[C+2|0]|0)|1<<(d[C+3|0]|0)|1<<(d[C+4|0]|0)|1<<(d[C+5|0]|0)|1<<(d[C+6|0]|0)|1<<(d[C+7|0]|0);O=Q+1|0;if((O|0)<8){Q=O;R=W;C=C+8|0}else{break}}c[P+(D<<2)>>2]=W;C=D+1|0;if((C|0)<(H|0)){D=C}else{V=0;break}}}}while(0);while(1){if((V|0)>=1024){break}X=9638528+(V<<2)|0;if((c[X>>2]|0)==(N|0)){G=21376;break}else{V=V+1|0}}if((G|0)==21376){gGr(N);c[X>>2]=0}c[2438412]=0;H=L+g|0;if((k|0)>0){I=u+108|0;D=u+100|0;P=0;do{C=c[2438414]|0;R=C+(ag(P,l)|0)|0;C=P+H|0;do{if((c[3542200]|0)!=0){c[I>>2]=0;c[D>>2]=0;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Q&16383](u,C)|0;if((c[I>>2]|0)==0){break}Q=c[D>>2]|0;c[v>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](v,C,0)|0;if((Q|0)<1){break}gzL(R,0,C)|0}}while(0);P=P+1|0;}while((P|0)<(k|0))}do{if(a[947424]|0){P=H+k|0;D=c[2438422]|0;do{if((c[3542200]|0)!=0){I=s+108|0;c[I>>2]=0;L=s+100|0;c[L>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](s,P)|0;if((c[I>>2]|0)==0){break}I=c[L>>2]|0;c[t>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](t,P,0)|0;if((I|0)<1){break}gzL(D,0,P)|0}}while(0);D=c[2433310]|0;I=P+1|0;do{if((c[3542200]|0)!=0){L=q+108|0;c[L>>2]=0;N=q+100|0;c[N>>2]=0;C=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[C&16383](q,I)|0;if((c[L>>2]|0)==0){break}L=c[N>>2]|0;c[r>>2]=9534384;N=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[N&16383](r,I,0)|0;if((L|0)<1){break}gzL(D,0,I)|0}}while(0);I=c[2436812]|0;D=P+2|0;if((c[3542200]|0)==0){break}L=o+108|0;c[L>>2]=0;N=o+100|0;c[N>>2]=0;C=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[C&16383](o,D)|0;if((c[L>>2]|0)==0){break}L=c[N>>2]|0;c[p>>2]=9534384;N=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[N&16383](p,D,0)|0;if((L|0)<1){break}gzL(I,0,D)|0}}while(0);fwR(0);H=c[2439330]|0;D=(H|0)==0;if(!D){I=H;gGC(9706056,I|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];I=c[3528484]|0;c[2076596]=I;L=c[2417276]|0;c[3541536]=L;c[1836236]=0;c[H+4184>>2]=1394;c[H+4172>>2]=2680;c[H+4176>>2]=1138;N=c[3527014]|0;C=0;R=0;while(1){c[H+76+(R<<2)>>2]=N+(R<<8);Q=C+1&65535;if((Q&65535)>127){Y=128;Z=128;break}else{C=Q;R=Q&65535}}while(1){c[H+76+(Z<<2)>>2]=N+(Z<<8);R=Y+1&65535;if((R&65535)>191){break}else{Y=R;Z=R&65535}}if((c[2438852]|0)==0){R=0;C=0;while(1){Q=N+(C<<8)|0;c[H+76+(C+512<<2)>>2]=Q;c[H+76+(C+768<<2)>>2]=Q;Q=R+1&65535;if((Q&65535)>127){_=128;$=128;break}else{R=Q;C=Q&65535}}while(1){C=N+($<<8)|0;c[H+76+($+512<<2)>>2]=C;c[H+76+($+768<<2)>>2]=C;C=_+1&65535;if((C&65535)>191){break}else{_=C;$=C&65535}}}else{C=c[2439400]|0;R=0;Q=0;while(1){O=Q<<8;c[H+76+(Q+512<<2)>>2]=C+O;c[H+76+(Q+768<<2)>>2]=N+O;O=R+1&65535;if((O&65535)>127){aa=128;ab=128;break}else{R=O;Q=O&65535}}while(1){Q=ab<<8;c[H+76+(ab+512<<2)>>2]=C+Q;c[H+76+(ab+768<<2)>>2]=N+Q;Q=aa+1&65535;if((Q&65535)>191){break}else{aa=Q;ab=Q&65535}}}N=c[3527018]|0;c[H+844>>2]=N;c[H+848>>2]=N+256;c[H+852>>2]=N+512;c[H+856>>2]=N+768;c[H+860>>2]=N+1024;c[H+864>>2]=N+1280;c[H+868>>2]=N+1536;c[H+872>>2]=N+1792;c[H+876>>2]=N+2048;c[H+880>>2]=N+2304;c[H+884>>2]=N+2560;c[H+888>>2]=N+2816;c[H+892>>2]=N+3072;c[H+896>>2]=N+3328;c[H+900>>2]=N+3584;c[H+904>>2]=N+3840;C=192;Q=192;while(1){c[H+76+(Q+256<<2)>>2]=N+((Q<<8)-49152);R=C+1&65535;if((R&65535)>207){ac=192;ad=192;break}else{C=R;Q=R&65535}}while(1){Q=N+((ad<<8)-49152)|0;c[H+76+(ad+512<<2)>>2]=Q;c[H+76+(ad+768<<2)>>2]=Q;Q=ac+1&65535;if((Q&65535)>207){break}else{ac=Q;ad=Q&65535}}Q=c[2433308]|0;c[H+908>>2]=Q;C=Q+256|0;c[H+912>>2]=C;c[H+1932>>2]=Q;c[H+1936>>2]=C;c[H+2956>>2]=Q;c[H+3980>>2]=Q;c[H+2960>>2]=C;c[H+3984>>2]=C;C=N+4096|0;c[H+916>>2]=C;Q=N+4352|0;c[H+920>>2]=Q;R=N+4608|0;c[H+924>>2]=R;O=N+4864|0;c[H+928>>2]=O;S=N+5120|0;c[H+932>>2]=S;T=N+5376|0;c[H+936>>2]=T;c[H+1940>>2]=C;c[H+1944>>2]=Q;c[H+1948>>2]=R;c[H+1952>>2]=O;c[H+1956>>2]=S;c[H+1960>>2]=T;c[H+2964>>2]=C;c[H+3988>>2]=C;c[H+2968>>2]=Q;c[H+3992>>2]=Q;c[H+2972>>2]=R;c[H+3996>>2]=R;c[H+2976>>2]=O;c[H+4e3>>2]=O;c[H+2980>>2]=S;c[H+4004>>2]=S;c[H+2984>>2]=T;c[H+4008>>2]=T;T=c[2430814]|0;c[H+940>>2]=T;S=T+256|0;c[H+944>>2]=S;O=T+512|0;c[H+948>>2]=O;R=T+768|0;c[H+952>>2]=R;Q=T+1024|0;c[H+956>>2]=Q;C=T+1280|0;c[H+960>>2]=C;c[H+1964>>2]=T;c[H+1968>>2]=S;c[H+1972>>2]=O;c[H+1976>>2]=R;c[H+1980>>2]=Q;c[H+1984>>2]=C;c[H+2988>>2]=T;c[H+4012>>2]=T;c[H+2992>>2]=S;c[H+4016>>2]=S;c[H+2996>>2]=O;c[H+4020>>2]=O;c[H+3e3>>2]=R;c[H+4024>>2]=R;c[H+3004>>2]=Q;c[H+4028>>2]=Q;c[H+3008>>2]=C;c[H+4032>>2]=C;C=c[2442938]|0;c[H+964>>2]=C;Q=C+256|0;c[H+968>>2]=Q;c[H+1988>>2]=C;c[H+1992>>2]=Q;c[H+3012>>2]=C;c[H+4036>>2]=C;c[H+3016>>2]=Q;c[H+4040>>2]=Q;Q=c[2442946]|0;c[H+972>>2]=Q;C=Q+256|0;c[H+976>>2]=C;R=Q+512|0;c[H+980>>2]=R;O=Q+768|0;c[H+984>>2]=O;S=Q+1024|0;c[H+988>>2]=S;T=Q+1280|0;c[H+992>>2]=T;ae=Q+1536|0;c[H+996>>2]=ae;af=Q+1792|0;c[H+1e3>>2]=af;c[H+1996>>2]=Q;c[H+2e3>>2]=C;c[H+2004>>2]=R;c[H+2008>>2]=O;c[H+2012>>2]=S;c[H+2016>>2]=T;c[H+2020>>2]=ae;c[H+2024>>2]=af;c[H+3020>>2]=Q;c[H+4044>>2]=Q;c[H+3024>>2]=C;c[H+4048>>2]=C;c[H+3028>>2]=R;c[H+4052>>2]=R;c[H+3032>>2]=O;c[H+4056>>2]=O;c[H+3036>>2]=S;c[H+4060>>2]=S;c[H+3040>>2]=T;c[H+4064>>2]=T;c[H+3044>>2]=ae;c[H+4068>>2]=ae;c[H+3048>>2]=af;c[H+4072>>2]=af;af=c[2436810]|0;c[H+1004>>2]=af;ae=af+256|0;c[H+1008>>2]=ae;T=af+512|0;c[H+1012>>2]=T;S=af+768|0;c[H+1016>>2]=S;O=af+1024|0;c[H+1020>>2]=O;R=af+1280|0;c[H+1024>>2]=R;C=af+1536|0;c[H+1028>>2]=C;c[H+2028>>2]=af;c[H+2032>>2]=ae;c[H+2036>>2]=T;c[H+2040>>2]=S;c[H+2044>>2]=O;c[H+2048>>2]=R;c[H+2052>>2]=C;c[H+3052>>2]=af;c[H+4076>>2]=af;c[H+3056>>2]=ae;c[H+4080>>2]=ae;c[H+3060>>2]=T;c[H+4084>>2]=T;c[H+3064>>2]=S;c[H+4088>>2]=S;c[H+3068>>2]=O;c[H+4092>>2]=O;c[H+3072>>2]=R;c[H+4096>>2]=R;c[H+3076>>2]=C;c[H+4100>>2]=C;C=c[2442936]|0;c[H+1032>>2]=C;c[H+3080>>2]=C;c[H+4104>>2]=C;C=c[2429304]|0;c[H+1036>>2]=C;R=C+256|0;c[H+1040>>2]=R;O=C+512|0;c[H+1044>>2]=O;S=C+768|0;c[H+1048>>2]=S;c[H+3084>>2]=C;c[H+4108>>2]=C;c[H+3088>>2]=R;c[H+4112>>2]=R;c[H+3092>>2]=O;c[H+4116>>2]=O;c[H+3096>>2]=S;c[H+4120>>2]=S;S=c[2442934]|0;c[H+1052>>2]=S;O=S+256|0;c[H+1056>>2]=O;R=S+512|0;c[H+1060>>2]=R;C=S+768|0;c[H+1064>>2]=C;c[H+2076>>2]=S;c[H+2080>>2]=O;c[H+2084>>2]=R;c[H+2088>>2]=C;c[H+3100>>2]=S;c[H+4124>>2]=S;c[H+3104>>2]=O;c[H+4128>>2]=O;c[H+3108>>2]=R;c[H+4132>>2]=R;c[H+3112>>2]=C;c[H+4136>>2]=C;C=c[2427080]|0;c[H+1068>>2]=C;R=C+256|0;c[H+1072>>2]=R;O=C+512|0;c[H+1076>>2]=O;S=C+768|0;c[H+1080>>2]=S;c[H+3116>>2]=C;c[H+4140>>2]=C;c[H+3120>>2]=R;c[H+4144>>2]=R;c[H+3124>>2]=O;c[H+4148>>2]=O;c[H+3128>>2]=S;c[H+4152>>2]=S;S=c[2442932]|0;c[H+1084>>2]=S;O=S+256|0;c[H+1088>>2]=O;R=S+512|0;c[H+1092>>2]=R;C=S+768|0;c[H+1096>>2]=C;c[H+2108>>2]=S;c[H+2112>>2]=O;c[H+2116>>2]=R;c[H+2120>>2]=C;c[H+3132>>2]=S;c[H+4156>>2]=S;c[H+3136>>2]=O;c[H+4160>>2]=O;c[H+3140>>2]=R;c[H+4164>>2]=R;c[H+3144>>2]=C;c[H+4168>>2]=C;if(!D){C=H;gGC(C|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=I;c[2417276]=L;c[1836236]=-1;fwR(1);C=c[2439331]|0;R=(C|0)==0;if(!R){O=C;gGC(9706056,O|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];O=c[3528485]|0;c[2076596]=O;S=c[2417277]|0;c[3541536]=S;c[1836236]=1;c[C+4180>>2]=178;c[C+4184>>2]=1390;T=c[3527012]|0;ae=0;af=0;while(1){c[C+76+(af<<2)>>2]=T+(af<<8);Q=ae+1&65535;if((Q&65535)>127){ah=0;ai=0;break}else{ae=Q;af=Q&65535}}while(1){af=T+(ai<<8)|0;c[C+76+(ai+512<<2)>>2]=af;c[C+76+(ai+768<<2)>>2]=af;af=ah+1&65535;if((af&65535)>127){break}else{ah=af;ai=af&65535}}T=c[3527016]|0;c[C+588>>2]=T;af=T+256|0;c[C+592>>2]=af;ae=T+512|0;c[C+596>>2]=ae;L=T+768|0;c[C+600>>2]=L;I=T+1024|0;c[C+604>>2]=I;H=T+1280|0;c[C+608>>2]=H;D=T+1536|0;c[C+612>>2]=D;N=T+1792|0;c[C+616>>2]=N;c[C+1612>>2]=T;c[C+1616>>2]=af;c[C+1620>>2]=ae;c[C+1624>>2]=L;c[C+1628>>2]=I;c[C+1632>>2]=H;c[C+1636>>2]=D;c[C+1640>>2]=N;c[C+2636>>2]=T;c[C+3660>>2]=T;c[C+2640>>2]=af;c[C+3664>>2]=af;c[C+2644>>2]=ae;c[C+3668>>2]=ae;c[C+2648>>2]=L;c[C+3672>>2]=L;c[C+2652>>2]=I;c[C+3676>>2]=I;c[C+2656>>2]=H;c[C+3680>>2]=H;c[C+2660>>2]=D;c[C+3684>>2]=D;c[C+2664>>2]=N;c[C+3688>>2]=N;if(!R){N=C;gGC(N|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=O;c[2417277]=S;c[1836236]=-1;gGz(c[2430824]|0,-1|0,65536);a[725184]=1;c[2440508]=66666;a[6517936]=1;TS(0,2e6,32768,6,0,0);TS(1,4e6,32768,6,0,1);N=c[2420348]|0;h[N+192>>3]=.5;c[N+200>>2]=3;N=c[2420346]|0;h[N+192>>3]=.5;c[N+200>>2]=3;N=c[642608+(c[2436]<<2)>>2]|0;D=c[N+128>>2]|0;if((c[N+52>>2]&4|0)==0){c[2113068]=D;H=c[N+132>>2]|0;c[2113070]=H;c[2443814]=D;c[2440436]=H;aj=D;ak=H}else{c[2113070]=D;H=c[N+132>>2]|0;c[2113068]=H;c[2440436]=D;c[2443814]=H;aj=H;ak=D}D=ag(aj<<1,ak)|0;H=gGq(D)|0;c[2112926]=H;if((H|0)!=0){gGz(H|0,0,D|0)}c[2430100]=10772;if(!m){M=0;i=n;return M|0}D=c[2439330]|0;H=(D|0)==0;if(!H){N=D;gGC(9706056,N|0,76)|0}N=c[2438118]|0;c[2433530]=N;I=c[3528484]|0;c[2076596]=I;L=c[2417276]|0;c[3541536]=L;c[1836236]=0;gGz(9706056,0,76);if(!H){H=D;gGC(H|0,9706056,76)|0}c[2438118]=N;c[3528484]=I;c[2417276]=L;c[1836236]=-1;L=c[2439331]|0;I=(L|0)==0;if(!I){N=L;gGC(9706056,N|0,76)|0}N=c[2438119]|0;c[2433530]=N;H=c[3528485]|0;c[2076596]=H;D=c[2417277]|0;c[3541536]=D;c[1836236]=1;gGz(9706056,0,76);if(!I){I=L;gGC(I|0,9706056,76)|0}c[2438119]=N;c[3528485]=H;c[2417277]=D;c[1836236]=-1;a[9753664]=0;a[9753673]=0;a[9753672]=0;c[2433316]=0;c[2433314]=0;c[2433306]=0;c[2430822]=0;c[2430812]=0;c[2438420]=0;c[2430874]=0;c[2430872]=0;c[2430870]=0;a[9760120]=0;a[9760112]=0;M=0;i=n;return M|0}}while(0);c[2426676]=0;M=1;i=n;return M|0}function eNu(){var b=0,c=0,d=0,e=0,f=0,g=0;a[9771778]=0;a[9771777]=0;a[9771776]=0;b=0;c=0;d=0;e=0;do{c=((a[9723280+b|0]&1)<<b|c&255)&255;d=((a[9723272+b|0]&1)<<b|d&255)&255;e=((a[9723264+b|0]&1)<<b|e&255)&255;b=b+1|0;}while((b|0)<8);a[9771776]=c;a[9771777]=d;a[9771778]=e;if((c&48)==48){e=c&-49;a[9771776]=e;f=e}else{f=c}if((f&-64)<<24>>24==-64){a[9771776]=f&63}if((d&48)==48){f=d&-49;a[9771777]=f;g=f}else{g=d}if((g&-64)<<24>>24!=-64){return}a[9771777]=g&63;return}function eNv(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=((d[9753673]|0)<<7|(d[9753672]|0)>>>1)+14&255;c[2433316]=b;e=-(d[9753664]|0)&255;c[2433314]=e;if((a|0)==-1){f=c[2442946]|0;g=(c[2436814]|0)+4095|0;h=c[2112926]|0;i=c[2442940]|0;j=c[2113068]|0;k=0;l=b;b=e;while(1){e=d[f+(k|1)|0]|0;m=e<<8&1792|(d[f+k|0]|0);n=m>>>5;o=k>>1;p=(((o|0)%32|0)<<3)+l|0;q=(((o|0)/32|0)<<3)+b|0;o=(j|0)==240?p-8|0:p;p=g&(m|e<<4&2048);Sj(h,p,o,q,n,3,1024,i);e=o-256|0;Sj(h,p,e,q,n,3,1024,i);m=q-256|0;Sj(h,p,o,m,n,3,1024,i);Sj(h,p,e,m,n,3,1024,i);n=k+2|0;if((n|0)>=2048){break}k=n;l=c[2433316]|0;b=c[2433314]|0}return}b=a<<3;a=c[2442946]|0;l=(c[2436814]|0)+4095|0;k=c[2112926]|0;i=c[2442940]|0;h=0;do{g=d[a+(h|1)|0]|0;if((g&8|0)==(b|0)){j=d[a+h|0]|0|g<<8&1792;f=j>>>5;n=h>>1;m=(c[2433316]|0)+(((n|0)%32|0)<<3)|0;e=(c[2433314]|0)+(((n|0)/32|0)<<3)|0;n=(c[2113068]|0)==240?m-8|0:m;m=l&(j|g<<4&2048);Sr(k,m,n,e,f,3,0,1024,i);g=n-256|0;Sr(k,m,g,e,f,3,0,1024,i);j=e-256|0;Sr(k,m,n,j,f,3,0,1024,i);Sr(k,m,g,j,f,3,0,1024,i)}h=h+2|0;}while((h|0)<2048);return}function eNw(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=a<<3;a=c[2436810]|0;e=c[2436814]|0;f=e-1|0;g=c[2429474]|0;h=c[2112926]|0;i=c[2442940]|0;j=0;do{k=d[a+(j|1)|0]|0;do{if((k&8|0)==(b|0)){l=d[a+j|0]|0|k<<8&1792;m=j>>1;n=((m|0)%32|0)<<3;o=((l|k<<4&2048|0)%(e|0)|0)&f;if((c[g+(o<<2)>>2]|0)>>>0<=1){break}Sr(h,o,(c[2113068]|0)==240?n-8|0:n,((m|0)/32|0)<<3,l>>>5,3,0,512,i)}}while(0);j=j+2|0;}while((j|0)<1792);return}function eNx(d,e,f,g){d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;h=c[2113068]|0;i=(h|0)==240?d-8|0:d;if(d>>>0>255|e>>>0>255){return}j=(c[2430824]|0)+((e<<8)+d)|0;k=a[j]|0;if(k<<24>>24!=-1){a[(c[2427080]|0)+((k&255)+(f<<5))|0]=-1}a[j]=f&255;do{if((i|0)>-1){if(!((i|0)<(h|0)&(e|0)>-1&(c[2113070]|0)>(e|0))){break}j=c[2112926]|0;b[j+((ag(h,e)|0)+i<<1)>>1]=g&65535}}while(0);if((a[(c[2442946]|0)+(((e-(c[2433314]|0)|0)>>>3<<5&992|(d-(c[2433316]|0)|0)>>>3&31)<<1|1)|0]&16)==0){return}a[(c[2429304]|0)+(f+32)|0]=-1;return}function eNy(){eKg(c[3527014]|0,c[2439400]|0,607192,606680,606616,606936);return}function eNz(){eJ7(602240);return}function eNA(){eKg(c[3527014]|0,c[2439400]|0,605360,604848,604784,605104);return}function eNB(){eJ7(602048);return}function eNC(){eJ7(602672);return}function eND(){eJ7(606152);return}function eNE(){eJ7(601608);return}function eNF(){eJ7(602800);return}function eNG(){eJ7(601736);return}function eNH(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=c[2438412]|0;d=0;while(1){e=b+d|0;f=a[e]|0;a[e]=f<<6&64|f&-66|(f&255)>>>6&1;f=d+1|0;if((f|0)<16384){d=f}else{g=16384;break}}while(1){d=b+g|0;f=a[d]|0;a[d]=f<<4&32|f&-35|(f&255)>>>4&2;f=g+1|0;if((f|0)<32768){g=f}else{h=32768;break}}while(1){g=b+h|0;f=a[g]|0;a[g]=f<<6&64|f&-66|(f&255)>>>6&1;f=h+1|0;if((f|0)<49152){h=f}else{i=0;break}}do{h=i<<1&32|i&65487|i>>>1&16;if((i|0)<(h|0)){f=b+i|0;g=a[f]|0;d=b+h|0;a[f]=a[d]|0;a[d]=g}i=i+1|0;}while((i|0)<49152);return}function eNI(){eKg(c[3527014]|0,c[2439400]|0,617585,617060,617657,617324);return}function eNJ(){var b=0,d=0,e=0,f=0,g=0,h=0;b=c[3527014]|0;d=c[2439400]|0;e=c[2433312]|0;f=0;do{g=b+f|0;h=a[g]|0;a[d+f|0]=eN6(f,h,e,1)|0;a[g]=eN6(f,h,e,0)|0;f=f+1|0;}while((f|0)<32768);return}function eNK(){a[9771778]=a[9723265]<<1&2|a[9723264]&1|a[9723266]<<2&4|a[9723267]<<3&8|a[9723268]<<4&16|a[9723269]<<5&32|a[9723270]<<6&64|a[9723271]<<7;if((a[9723280]|0)!=0){a[9760120]=(a[9760120]|0)+4&255}if((a[9723281]|0)!=0){a[9760120]=(a[9760120]|0)-4&255}if((a[9723282]|0)!=0){a[9760112]=(a[9760112]|0)+4&255}if((a[9723283]|0)==0){return}a[9760112]=(a[9760112]|0)-4&255;return}function eNL(a,b){a=a|0;b=b|0;do{if((b|0)==0){if((a&65535|0)!=65535){break}eNM(a>>>16)}}while(0);return 0}function eNM(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;g=f&768;if((g|0)==0|(g|0)==256){c[2429290]=f&255}c[2440738]=f;c[2276083]=4096;h=c[3528786]|0;if((h|0)==0){i=0}else{if((g|0)==256){c[2384534]=f&255;a[616984]=0;j=21557}else if((g|0)==0){c[2384534]=f&255;j=21555}else if((g|0)==512){a[616984]=1;j=21556}else if((g|0)==768){a[616984]=0;j=21557}else{j=21555}if((j|0)==21555){if(a[616984]|0){j=21556}else{j=21557}}if((j|0)==21556){k=d[h]|0}else if((j|0)==21557){k=c[2384534]|0}g=d[h+1|0]|0;c[2444202]=g;f=d[h+2|0]|0;c[2444200]=f;l=d[h+3|0]|0;c[2444198]=l;if((k&1|0)==0){m=f;n=l;o=g}else{p=g^4;c[2444202]=p;g=f^128;c[2444200]=g;f=l^128;c[2444198]=f;m=g;n=f;o=p}if((k&2|0)==0){q=m;r=n;s=o}else{p=o^1;c[2444202]=p;o=m^16;c[2444200]=o;m=n^1;c[2444198]=m;q=o;r=m;s=p}if((k&4|0)==0){t=q;u=r;v=s}else{p=s^128;c[2444202]=p;s=q^64;c[2444200]=s;q=r^4;c[2444198]=q;t=s;u=q;v=p}if((k&8|0)==0){w=t;x=u;y=v}else{p=v^32;c[2444202]=p;v=t^2;c[2444200]=v;t=u^32;c[2444198]=t;w=v;x=t;y=p}if((k&16|0)==0){z=w;A=y}else{p=y^66;c[2444202]=p;y=w^8;c[2444200]=y;z=y;A=p}if((k&32|0)==0){B=x;C=A}else{p=A^8;c[2444202]=p;A=x^24;c[2444198]=A;B=A;C=p}if((k&64|0)==0){D=z}else{c[2444202]=C^16;C=z^36;c[2444200]=C;D=C}if((k&128|0)!=0){c[2444200]=D^1;c[2444198]=B^66}i=k&255}k=0;while(1){if((k|0)>=8){break}if((c[9717624+(k<<2)>>2]|0)==(i|0)){j=21578;break}else{k=k+1|0}}if((j|0)==21578){j=c[9720072+(k<<2)>>2]|0;c[2430492]=j;k=c[2394]|0;B=c[3528544]|0;D=(k|0)==(B|0);if((k|0)==-1){if(D){E=-1}else{c[2394]=B;c[2112932]=c[14130384+(B<<2)>>2];C=c[14130368+(B<<2)>>2]|0;if((C|0)!=0){gGC(9104152,C|0,280)|0}c[2113054]=c[8452240+(B<<2)>>2];E=B}C=j;z=c[2112932]|0;p=z|0;A=0;while(1){c[p+131072>>2]=C+A;x=A+1024|0;if(x>>>0>1048575){break}else{p=p+4|0;A=x}}if(a[7461504]|0){A=j+2097152|0;p=z+8192|0;z=2097152;while(1){c[p+131072>>2]=A+(z-2097152);C=z+1024|0;if(C>>>0>2621439){break}else{p=p+4|0;z=C}}}z=c[14130368+(E<<2)>>2]|0;if((z|0)!=0){gGC(z|0,9104152,280)|0}c[8452240+(E<<2)>>2]=c[2113054];c[2394]=-1;return}if(D){D=j;E=c[2112932]|0;z=E|0;p=0;while(1){c[z+131072>>2]=D+p;A=p+1024|0;if(A>>>0>1048575){break}else{z=z+4|0;p=A}}if(!(a[7461504]|0)){return}p=j+2097152|0;z=E+8192|0;E=2097152;while(1){c[z+131072>>2]=p+(E-2097152);D=E+1024|0;if(D>>>0>2621439){break}else{z=z+4|0;E=D}}return}E=c[14130368+(k<<2)>>2]|0;z=(E|0)==0;if(!z){gGC(E|0,9104152,280)|0}p=c[2113054]|0;D=8452240+(k<<2)|0;c[D>>2]=p;c[2394]=-1;if((B|0)==-1){F=-1;G=p}else{c[2394]=B;c[2112932]=c[14130384+(B<<2)>>2];p=c[14130368+(B<<2)>>2]|0;if((p|0)!=0){gGC(9104152,p|0,280)|0}p=c[8452240+(B<<2)>>2]|0;c[2113054]=p;F=B;G=p}p=j;B=c[2112932]|0;A=B|0;C=0;while(1){c[A+131072>>2]=p+C;x=C+1024|0;if(x>>>0>1048575){break}else{A=A+4|0;C=x}}if(a[7461504]|0){C=j+2097152|0;j=B+8192|0;B=2097152;while(1){c[j+131072>>2]=C+(B-2097152);A=B+1024|0;if(A>>>0>2621439){break}else{j=j+4|0;B=A}}}B=c[14130368+(F<<2)>>2]|0;if((B|0)!=0){gGC(B|0,9104152,280)|0}c[8452240+(F<<2)>>2]=G;c[2394]=k;c[2112932]=c[14130384+(k<<2)>>2];if(!z){gGC(9104152,E|0,280)|0}c[2113054]=c[D>>2];return}D=c[2426958]|0;c[9717624+(D<<2)>>2]=i;i=c[2429404]|0;if(i>>>0>1){E=c[2432958]|0;z=c[9720072+(D<<2)>>2]|0;k=i>>>1;i=0;while(1){b[z+(i<<1)>>1]=(eFl(i,e[E+(i<<1)>>1]|0,h,0)|0)&65535;G=i+1|0;if(G>>>0<k>>>0){i=G}else{H=z;break}}}else{H=c[9720072+(D<<2)>>2]|0}c[2430492]=H;z=c[2394]|0;i=c[3528544]|0;k=(z|0)==(i|0);L28350:do{if((z|0)==-1){if(k){I=c[2112932]|0;J=-1}else{c[2394]=i;h=c[14130384+(i<<2)>>2]|0;c[2112932]=h;E=c[14130368+(i<<2)>>2]|0;if((E|0)!=0){gGC(9104152,E|0,280)|0}c[2113054]=c[8452240+(i<<2)>>2];I=h;J=i}h=H;E=I|0;G=0;while(1){c[E+131072>>2]=h+G;F=G+1024|0;if(F>>>0>1048575){break}else{E=E+4|0;G=F}}if(a[7461504]|0){G=H+2097152|0;E=I+8192|0;h=2097152;while(1){c[E+131072>>2]=G+(h-2097152);F=h+1024|0;if(F>>>0>2621439){break}else{E=E+4|0;h=F}}}h=c[14130368+(J<<2)>>2]|0;if((h|0)!=0){gGC(h|0,9104152,280)|0}c[8452240+(J<<2)>>2]=c[2113054];c[2394]=-1}else{if(k){h=H;E=c[2112932]|0;G=E|0;F=0;while(1){c[G+131072>>2]=h+F;B=F+1024|0;if(B>>>0>1048575){break}else{G=G+4|0;F=B}}if(!(a[7461504]|0)){break}F=H+2097152|0;G=E+8192|0;h=2097152;while(1){c[G+131072>>2]=F+(h-2097152);B=h+1024|0;if(B>>>0>2621439){break L28350}else{G=G+4|0;h=B}}}h=c[14130368+(z<<2)>>2]|0;G=(h|0)==0;if(!G){gGC(h|0,9104152,280)|0}F=c[2113054]|0;E=8452240+(z<<2)|0;c[E>>2]=F;c[2394]=-1;if((i|0)==-1){K=c[2112932]|0;L=-1;M=F}else{c[2394]=i;F=c[14130384+(i<<2)>>2]|0;c[2112932]=F;B=c[14130368+(i<<2)>>2]|0;if((B|0)!=0){gGC(9104152,B|0,280)|0}B=c[8452240+(i<<2)>>2]|0;c[2113054]=B;K=F;L=i;M=B}B=H;F=K|0;j=0;while(1){c[F+131072>>2]=B+j;C=j+1024|0;if(C>>>0>1048575){break}else{F=F+4|0;j=C}}if(a[7461504]|0){j=H+2097152|0;F=K+8192|0;B=2097152;while(1){c[F+131072>>2]=j+(B-2097152);C=B+1024|0;if(C>>>0>2621439){break}else{F=F+4|0;B=C}}}B=c[14130368+(L<<2)>>2]|0;if((B|0)!=0){gGC(B|0,9104152,280)|0}c[8452240+(L<<2)>>2]=M;c[2394]=z;c[2112932]=c[14130384+(z<<2)>>2];if(!G){gGC(9104152,h|0,280)|0}c[2113054]=c[E>>2]}}while(0);z=D+1|0;c[2426958]=z;if((z|0)<=7){return}c[2426958]=0;return}function eNN(a){a=a|0;eNM(512);return((a<<2)+96|0)/4|0|0}function eNO(){eNM(768);return 0}function eNP(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=c[2432958]|0;f=c[3528786]|0;g=(eFl(0,e[d>>1]|0,f,1)|0)&65535;h=c[2430492]|0;b[h>>1]=g;b[h+2>>1]=(eFl(1,e[d+2>>1]|0,f,1)|0)&65535;b[h+4>>1]=(eFl(2,e[d+4>>1]|0,f,1)|0)&65535;b[h+6>>1]=(eFl(3,e[d+6>>1]|0,f,1)|0)&65535;f=c[3528544]|0;if((c[2394]|0)==(f|0)){i=c[2112932]|0}else{c[2394]=f;d=c[14130384+(f<<2)>>2]|0;c[2112932]=d;g=c[14130368+(f<<2)>>2]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[8452240+(f<<2)>>2];i=d}d=h;g=i|0;j=0;while(1){c[g+131072>>2]=d+j;k=j+1024|0;if(k>>>0>1048575){break}else{g=g+4|0;j=k}}if(a[7461504]|0){j=h+2097152|0;h=i+8192|0;i=2097152;while(1){c[h+131072>>2]=j+(i-2097152);g=i+1024|0;if(g>>>0>2621439){break}else{h=h+4|0;i=g}}}i=c[14130368+(f<<2)>>2]|0;if((i|0)==0){l=c[2113054]|0;m=8452240+(f<<2)|0;c[m>>2]=l;c[2394]=-1;return}gGC(i|0,9104152,280)|0;l=c[2113054]|0;m=8452240+(f<<2)|0;c[m>>2]=l;c[2394]=-1;return}function eNQ(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;c[3528544]=b;if((b|0)==1){c[2432958]=c[3532444];c[2429404]=c[3532440]}else if((b|0)==0){c[2432958]=c[3532446];c[2429404]=c[3532430]}b=c[3532518]|0;c[3528786]=b;if((b|0)==0){return}b=c[2429404]|0;d=0;while(1){if((d|0)>=1024){e=0;break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==0){g=21687;break}else{d=d+1|0}}do{if((g|0)==21687){d=gGq(b)|0;c[f>>2]=d;if((d|0)==0){e=0;break}gGz(d|0,0,b|0);e=d}}while(0);c[2430018]=e;e=c[2429404]|0;b=0;while(1){if((b|0)>=1024){h=0;break}i=9638528+(b<<2)|0;if((c[i>>2]|0)==0){g=21692;break}else{b=b+1|0}}do{if((g|0)==21692){b=gGq(e)|0;c[i>>2]=b;if((b|0)==0){h=0;break}gGz(b|0,0,e|0);h=b}}while(0);c[2430019]=h;h=c[2429404]|0;e=0;while(1){if((e|0)>=1024){j=0;break}k=9638528+(e<<2)|0;if((c[k>>2]|0)==0){g=21697;break}else{e=e+1|0}}do{if((g|0)==21697){e=gGq(h)|0;c[k>>2]=e;if((e|0)==0){j=0;break}gGz(e|0,0,h|0);j=e}}while(0);c[2430020]=j;j=c[2429404]|0;h=0;while(1){if((h|0)>=1024){l=0;break}m=9638528+(h<<2)|0;if((c[m>>2]|0)==0){g=21702;break}else{h=h+1|0}}do{if((g|0)==21702){h=gGq(j)|0;c[m>>2]=h;if((h|0)==0){l=0;break}gGz(h|0,0,j|0);l=h}}while(0);c[2430021]=l;l=c[2429404]|0;j=0;while(1){if((j|0)>=1024){n=0;break}o=9638528+(j<<2)|0;if((c[o>>2]|0)==0){g=21707;break}else{j=j+1|0}}do{if((g|0)==21707){j=gGq(l)|0;c[o>>2]=j;if((j|0)==0){n=0;break}gGz(j|0,0,l|0);n=j}}while(0);c[2430022]=n;n=c[2429404]|0;l=0;while(1){if((l|0)>=1024){p=0;break}q=9638528+(l<<2)|0;if((c[q>>2]|0)==0){g=21712;break}else{l=l+1|0}}do{if((g|0)==21712){l=gGq(n)|0;c[q>>2]=l;if((l|0)==0){p=0;break}gGz(l|0,0,n|0);p=l}}while(0);c[2430023]=p;p=c[2429404]|0;n=0;while(1){if((n|0)>=1024){r=0;break}s=9638528+(n<<2)|0;if((c[s>>2]|0)==0){g=21717;break}else{n=n+1|0}}do{if((g|0)==21717){n=gGq(p)|0;c[s>>2]=n;if((n|0)==0){r=0;break}gGz(n|0,0,p|0);r=n}}while(0);c[2430024]=r;r=c[2429404]|0;p=0;while(1){if((p|0)>=1024){t=0;break}u=9638528+(p<<2)|0;if((c[u>>2]|0)==0){g=21722;break}else{p=p+1|0}}do{if((g|0)==21722){p=gGq(r)|0;c[u>>2]=p;if((p|0)==0){t=0;break}gGz(p|0,0,r|0);t=p}}while(0);c[2430025]=t;gGz(9717624,-1|0,32);c[2426958]=0;c[2440738]=-1;if((c[3532430]|0)>>>0<=1048575){return}a[7461504]=1;return}function eNR(b){b=b|0;var c=0,d=0,e=0,f=0;c=b&255;if((c|0)==4){d=a[9634816]|0;return d|0}else if((c|0)==0){b=a[9632785]<<1|a[9632784]|a[9632786]<<2;e=a[9632787]<<3|b|a[9632788]<<4|a[9632789]<<5|a[9632790]<<6|a[9632791]<<7;f=(b&5)==5?e&-6:e;d=(f&10)==10?f&-11:f;return d|0}else if((c|0)==2){d=a[9629297]<<1|a[9629296]|a[9629298]<<2|a[9629299]<<3|a[9629300]<<4|a[9629301]<<5|a[9629302]<<6|a[9629303]<<7;return d|0}else if((c|0)==1){c=a[9630681]<<1|a[9630680]|a[9630682]<<2;f=a[9630683]<<3|c|a[9630684]<<4|a[9630685]<<5|a[9630686]<<6|a[9630687]<<7;e=(c&5)==5?f&-6:f;d=(e&10)==10?e&-11:e;return d|0}else{d=0;return d|0}return 0}function eNS(b,c){b=b|0;c=c|0;switch(b&255|0){case 1:{TR(1,c&255);return};case 0:{TR(0,c&255);return};case 2:{TR(2,c&255);return};case 7:{a[9578784]=c&3;a[9731720]=(c&255)>>>4&1;a[14114704]=c&32;return};case 5:{a[9554088]=c;return};default:{return}}}function eNT(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6599940+(b*112|0)>>2];c[a+104>>2]=c[6599944+(b*112|0)>>2];c[a+108>>2]=c[6599948+(b*112|0)>>2];d=0;return d|0}function eNU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=6599840+(b*112|0);e=0;return e|0}function eNV(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4822304+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eNW(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>23){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6601744+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eNX(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;e=i;i=i+968|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=0;while(1){if((w|0)>=1024){break}x=9638528+(w<<2)|0;if((c[x>>2]|0)==0){y=21783;break}else{w=w+1|0}}do{if((y|0)==21783){w=gGq(263680)|0;c[x>>2]=w;if((w|0)==0){break}gGz(w|0,0,263680);c[2426674]=w;c[2426600]=w;c[2424846]=w+65536;c[2424822]=w+131072;c[2424776]=w+262144;c[2406912]=w+262656;z=t+108|0;A=t+100|0;B=0;C=w;while(1){w=C+(B<<14)|0;if((c[3542200]|0)==0){D=1;y=21902;break}c[z>>2]=0;c[A>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,B)|0;if((c[z>>2]|0)!=0){E=c[A>>2]|0;c[u>>2]=9534384;F=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[F&16383](u,B,0)|0;if((E|0)<1){D=1;y=21880;break}if((gzL(w,0,B)|0)!=0){D=1;y=21881;break}}w=B+1|0;if((w|0)>=4){y=21792;break}B=w;C=c[2426600]|0}if((y|0)==21792){C=c[2424846]|0;if((c[3542200]|0)==0){D=1;i=e;return D|0}B=r+108|0;c[B>>2]=0;A=r+100|0;c[A>>2]=0;z=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[z&16383](r,4)|0;do{if((c[B>>2]|0)!=0){z=c[A>>2]|0;c[s>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](s,4,0)|0;if((z|0)<1){D=1;i=e;return D|0}if((gzL(C,0,4)|0)==0){break}else{D=1}i=e;return D|0}}while(0);C=(c[2424846]|0)+8192|0;if((c[3542200]|0)==0){D=1;i=e;return D|0}A=p+108|0;c[A>>2]=0;B=p+100|0;c[B>>2]=0;z=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[z&16383](p,5)|0;do{if((c[A>>2]|0)!=0){z=c[B>>2]|0;c[q>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](q,5,0)|0;if((z|0)<1){D=1;i=e;return D|0}if((gzL(C,0,5)|0)==0){break}else{D=1}i=e;return D|0}}while(0);C=n+108|0;B=n+100|0;A=0;while(1){z=(c[2424822]|0)+(A<<13)|0;w=A+6|0;if((c[3542200]|0)==0){D=1;y=21888;break}c[C>>2]=0;c[B>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,w)|0;if((c[C>>2]|0)!=0){E=c[B>>2]|0;c[o>>2]=9534384;F=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[F&16383](o,w,0)|0;if((E|0)<1){D=1;y=21889;break}if((gzL(z,0,w)|0)!=0){D=1;y=21890;break}}w=A+1|0;if((w|0)<6){A=w}else{y=21806;break}}if((y|0)==21806){A=c[2424776]|0;if((c[3542200]|0)==0){D=1;i=e;return D|0}B=l+108|0;c[B>>2]=0;C=l+100|0;c[C>>2]=0;w=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[w&16383](l,12)|0;do{if((c[B>>2]|0)!=0){w=c[C>>2]|0;c[m>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](m,12,0)|0;if((w|0)<1){D=1;i=e;return D|0}if((gzL(A,0,12)|0)==0){break}else{D=1}i=e;return D|0}}while(0);A=(c[2424776]|0)+32|0;if((c[3542200]|0)==0){D=1;i=e;return D|0}C=j+108|0;c[C>>2]=0;B=j+100|0;c[B>>2]=0;w=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[w&16383](j,13)|0;do{if((c[C>>2]|0)!=0){w=c[B>>2]|0;c[k>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](k,13,0)|0;if((w|0)<1){D=1;i=e;return D|0}if((gzL(A,0,13)|0)==0){break}else{D=1}i=e;return D|0}}while(0);A=(c[2424776]|0)+288|0;if((c[3542200]|0)==0){D=1;i=e;return D|0}B=f+108|0;c[B>>2]=0;C=f+100|0;c[C>>2]=0;w=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[w&16383](f,14)|0;do{if((c[B>>2]|0)==0){G=0}else{w=c[C>>2]|0;c[g>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](g,14,0)|0;if((w|0)<1){D=1;i=e;return D|0}if((gzL(A,0,14)|0)==0){G=0;break}else{D=1}i=e;return D|0}}while(0);while(1){if((G|0)>=1024){D=1;y=21900;break}H=9638528+(G<<2)|0;if((c[H>>2]|0)==0){break}else{G=G+1|0}}if((y|0)==21900){i=e;return D|0}A=gGq(65536)|0;c[H>>2]=A;if((A|0)==0){D=1;i=e;return D|0}gGz(A|0,0,65536);C=c[2424846]|0;gGC(A|0,C|0,65536)|0;B=0;do{w=B<<6;gGz(C+w|0,0,64);z=B<<7;E=0;do{F=z+(c[1238464+(E<<2)>>2]|0)|0;I=(E<<3)+w|0;J=0;do{K=F+(c[600544+(J<<2)>>2]|0)|0;if(((d[A+((K|0)/8|0)|0]|0)&128>>>((K&7)>>>0)|0)!=0){K=C+(I+J)|0;a[K]=a[K]|2}J=J+1|0;}while((J|0)<8);E=E+1|0;}while((E|0)<8);E=z|4;J=0;do{I=E+(c[1238464+(J<<2)>>2]|0)|0;F=(J<<3)+w|0;K=0;do{L=I+(c[600544+(K<<2)>>2]|0)|0;if(((d[A+((L|0)/8|0)|0]|0)&128>>>((L&7)>>>0)|0)!=0){L=C+(F+K)|0;a[L]=a[L]|1}K=K+1|0;}while((K|0)<8);J=J+1|0;}while((J|0)<8);B=B+1|0;}while((B|0)<1024);B=c[2424822]|0;gGC(A|0,B|0,65536)|0;C=0;while(1){J=C<<6;gGz(B+J|0,0,64);w=0;do{E=J+(c[1238464+(w<<2)>>2]|0)|0;z=(w<<3)+J|0;K=0;do{F=E+(c[610352+(K<<2)>>2]|0)|0;if(((d[A+((F|0)/8|0)|0]|0)&128>>>((F&7)>>>0)|0)!=0){F=B+(z+K)|0;a[F]=a[F]|4}K=K+1|0;}while((K|0)<8);w=w+1|0;}while((w|0)<8);w=J+131072|0;K=0;do{z=w+(c[1238464+(K<<2)>>2]|0)|0;E=(K<<3)+J|0;F=0;do{I=z+(c[610352+(F<<2)>>2]|0)|0;if(((d[A+((I|0)/8|0)|0]|0)&128>>>((I&7)>>>0)|0)!=0){I=B+(E+F)|0;a[I]=a[I]|2}F=F+1|0;}while((F|0)<8);K=K+1|0;}while((K|0)<8);K=J+262144|0;w=0;do{F=K+(c[1238464+(w<<2)>>2]|0)|0;E=(w<<3)+J|0;z=0;do{I=F+(c[610352+(z<<2)>>2]|0)|0;if(((d[A+((I|0)/8|0)|0]|0)&128>>>((I&7)>>>0)|0)!=0){I=B+(E+z)|0;a[I]=a[I]|1}z=z+1|0;}while((z|0)<8);w=w+1|0;}while((w|0)<8);w=C+1|0;if((w|0)<2048){C=w}else{M=0;break}}while(1){C=B+M|0;a[C]=a[C]|-128;C=M+1|0;if((C|0)<131072){M=C}else{N=0;break}}while(1){if((N|0)>=1024){break}O=9638528+(N<<2)|0;if((c[O>>2]|0)==(A|0)){y=21840;break}else{N=N+1|0}}if((y|0)==21840){gGr(A);c[O>>2]=0}B=c[2424776]|0;C=B;w=0;while(1){J=d[C]|0;c[v+(w<<2)>>2]=(-(J>>>3&1)&33)+(-(J>>>4&1)&71)+(-(J>>>5&1)&151)<<8|(-(J>>>6&1)&71)+(-(J>>>7)&151)|(-(J>>>1&1)&71)+(-(J&1)&33)+(-(J>>>2&1)&151)<<16;J=w+1|0;if((J|0)<32){C=C+1|0;w=J}else{break}}w=c[2406912]|0;C=B+32|0;A=0;while(1){c[w+(A<<2)>>2]=c[v+((a[C]&15)<<2)>>2];J=A+1|0;if((J|0)<128){C=C+1|0;A=J}else{break}}A=B+288|0;C=0;while(1){c[w+(C+128<<2)>>2]=c[v+((a[A]&15)<<2)>>2];J=C+1|0;if((J|0)<128){A=A+1|0;C=J}else{break}}fwR(0);C=c[2439330]|0;if((C|0)!=0){A=C;gGC(9706056,A|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];A=c[3528484]|0;c[2076596]=A;w=c[2417276]|0;c[3541536]=w;c[1836236]=0;c[C+4172>>2]=2504;c[C+4176>>2]=690;B=c[2426600]|0;J=0;K=0;while(1){c[C+76+(K<<2)>>2]=B+(K<<8);z=J+1&65535;if((z&65535)>223){P=0;Q=0;break}else{J=z;K=z&65535}}while(1){K=B+(Q<<8)|0;c[C+76+(Q+512<<2)>>2]=K;c[C+76+(Q+768<<2)>>2]=K;K=P+1&65535;if((K&65535)>223){break}else{P=K;Q=K&65535}}K=B+57344|0;c[C+972>>2]=K;J=B+57600|0;c[C+976>>2]=J;z=B+57856|0;c[C+980>>2]=z;E=B+58112|0;c[C+984>>2]=E;F=B+58368|0;c[C+988>>2]=F;I=B+58624|0;c[C+992>>2]=I;L=B+58880|0;c[C+996>>2]=L;R=B+59136|0;c[C+1e3>>2]=R;S=B+59392|0;c[C+1004>>2]=S;T=B+59648|0;c[C+1008>>2]=T;U=B+59904|0;c[C+1012>>2]=U;V=B+60160|0;c[C+1016>>2]=V;W=B+60416|0;c[C+1020>>2]=W;X=B+60672|0;c[C+1024>>2]=X;Y=B+60928|0;c[C+1028>>2]=Y;Z=B+61184|0;c[C+1032>>2]=Z;c[C+1996>>2]=K;c[C+2e3>>2]=J;c[C+2004>>2]=z;c[C+2008>>2]=E;c[C+2012>>2]=F;c[C+2016>>2]=I;c[C+2020>>2]=L;c[C+2024>>2]=R;c[C+2028>>2]=S;c[C+2032>>2]=T;c[C+2036>>2]=U;c[C+2040>>2]=V;c[C+2044>>2]=W;c[C+2048>>2]=X;c[C+2052>>2]=Y;c[C+2056>>2]=Z;Z=224;Y=224;while(1){X=B+(Y<<8)|0;c[C+76+(Y+512<<2)>>2]=X;c[C+76+(Y+768<<2)>>2]=X;X=Z+1&65535;if((X&65535)>239){break}else{Z=X;Y=X&65535}}Y=B+61440|0;c[C+1036>>2]=Y;Z=B+61696|0;c[C+1040>>2]=Z;X=B+61952|0;c[C+1044>>2]=X;W=B+62208|0;c[C+1048>>2]=W;V=B+62464|0;c[C+1052>>2]=V;U=B+62720|0;c[C+1056>>2]=U;T=B+62976|0;c[C+1060>>2]=T;S=B+63232|0;c[C+1064>>2]=S;R=B+63488|0;c[C+1068>>2]=R;L=B+63744|0;c[C+1072>>2]=L;I=B+64e3|0;c[C+1076>>2]=I;F=B+64256|0;c[C+1080>>2]=F;E=B+64512|0;c[C+1084>>2]=E;z=B+64768|0;c[C+1088>>2]=z;J=B+65024|0;c[C+1092>>2]=J;K=B+65280|0;c[C+1096>>2]=K;c[C+2060>>2]=Y;c[C+2064>>2]=Z;c[C+2068>>2]=X;c[C+2072>>2]=W;c[C+2076>>2]=V;c[C+2080>>2]=U;c[C+2084>>2]=T;c[C+2088>>2]=S;c[C+2092>>2]=R;c[C+2096>>2]=L;c[C+2100>>2]=I;c[C+2104>>2]=F;c[C+2108>>2]=E;c[C+2112>>2]=z;c[C+2116>>2]=J;c[C+2120>>2]=K;K=C;gGC(K|0,9706056,76)|0;c[2438118]=c[2433530];c[3528484]=A;c[2417276]=w;c[1836236]=-1;TS(0,2578e3,16384,3,1,0);TS(1,2578e3,16384,3,1,1);TS(2,2578e3,16384,3,1,1);K=c[2420348]|0;h[K+192>>3]=1.0;c[K+200>>2]=3;K=c[2420346]|0;h[K+192>>3]=1.0;c[K+200>>2]=3;K=c[2420344]|0;h[K+192>>3]=1.0;c[K+200>>2]=3;a[9623736]=0;gGz((c[2426674]|0)+57344|0,0,8192);K=c[2439330]|0;J=(K|0)==0;if(!J){z=K;gGC(9706056,z|0,76)|0}z=c[2438118]|0;c[2433530]=z;E=c[3528484]|0;c[2076596]=E;F=c[2417276]|0;c[3541536]=F;c[1836236]=0;gGz(9706056,0,76);if(!J){J=K;gGC(J|0,9706056,76)|0}c[2438118]=z;c[3528484]=E;c[2417276]=F;c[1836236]=-1;a[9554088]=0;a[9578784]=0;a[14114704]=0;a[9731720]=0;D=0;i=e;return D|0}else if((y|0)==21888){i=e;return D|0}else if((y|0)==21889){i=e;return D|0}else if((y|0)==21890){i=e;return D|0}}else if((y|0)==21880){i=e;return D|0}else if((y|0)==21881){i=e;return D|0}else if((y|0)==21902){i=e;return D|0}}}while(0);c[2426674]=0;D=1;i=e;return D|0}function eNY(){var b=0,d=0,e=0,f=0;fwZ();TT();b=c[2426674]|0;d=0;while(1){if((d|0)>=1024){break}e=9638528+(d<<2)|0;if((c[e>>2]|0)==(b|0)){f=21906;break}else{d=d+1|0}}if((f|0)==21906){gGr(b);c[e>>2]=0}c[2426674]=0;a[9731720]=0;a[14114704]=0;a[9578784]=0;a[9554088]=0;c[2424776]=0;c[2424822]=0;c[2424846]=0;c[2426600]=0;c[2406912]=0;return 0}function eNZ(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if((a[9623736]|0)==0){e=c[2439330]|0}else{a[9623736]=0;gGz((c[2426674]|0)+57344|0,0,8192);f=c[2439330]|0;g=(f|0)==0;if(!g){h=f;gGC(9706056,h|0,76)|0}h=c[2438118]|0;c[2433530]=h;i=c[3528484]|0;c[2076596]=i;j=c[2417276]|0;c[3541536]=j;c[1836236]=0;gGz(9706056,0,76);if(!g){g=f;gGC(g|0,9706056,76)|0}c[2438118]=h;c[3528484]=i;c[2417276]=j;c[1836236]=-1;a[9554088]=0;a[9578784]=0;a[14114704]=0;a[9731720]=0;e=f}if((e|0)!=0){f=e;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;f=c[2438118]|0;c[2433530]=f;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;if((a[e+4188|0]|0)==0){e=gfc(42966)|0;k=(c[2433530]|0)+e|0}else{k=f+42966|0}c[2433530]=k;if((a[9731720]|0)==0){l=k}else{if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;k=(c[2433530]|0)+12|0;c[2433530]=k;l=k}k=c[1836236]|0;f=c[9757320+(k<<2)>>2]|0;if((f|0)!=0){e=f;gGC(e|0,9706056,76)|0}c[9752472+(k<<2)>>2]=l;c[14113936+(k<<2)>>2]=c[2076596];c[9669104+(k<<2)>>2]=c[3541536];c[1836236]=-1;k=c[2112964]|0;l=a[9688]|0?534:0;TQ(0,k,l);TQ(1,k,l);TQ(2,k,l);if((c[2112968]|0)==0){return 0}if((a[9578784]&2)!=0){eN4(0);l=c[2426600]|0;k=c[2424822]|0;e=0;do{f=d[l+(e+64512)|0]|0;j=f&8;i=a[14114704]|0;if(i<<24>>24==0){m=e>>>2;n=e;o=j}else{h=~e;m=h>>2;n=h;o=j^8}eN5(k,f<<8&1792|d[l+(e+63488)|0],f>>>1&120,(n<<3&248)-24|0,(m&248)-16|0,o,i&255,1);e=e+1|0;}while((e|0)<1024);return 0}e=c[2426600]|0;o=c[2424822]|0;m=0;do{n=d[e+(m+64512)|0]|0;l=n&8;k=a[14114704]|0;if(k<<24>>24==0){p=m>>>2;q=m;r=l}else{i=~m;p=i>>2;q=i;r=l^8}eN5(o,n<<8&1792|d[e+(m+63488)|0],n>>>1&120,(q<<3&248)-24|0,(p&248)-16|0,r,k&255,0);m=m+1|0;}while((m|0)<1024);eN4(1);return 0}function eN_(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;if((a[9578784]&2)!=0){eN4(0);b=c[2426600]|0;e=c[2424822]|0;f=0;do{g=d[b+(f+64512)|0]|0;h=g&8;i=a[14114704]|0;if(i<<24>>24==0){j=f>>>2;k=f;l=h}else{m=~f;j=m>>2;k=m;l=h^8}eN5(e,g<<8&1792|(d[b+(f+63488)|0]|0),g>>>1&120,(k<<3&248)-24|0,(j&248)-16|0,l,i&255,1);f=f+1|0;}while((f|0)<1024);return 0}f=c[2426600]|0;l=c[2424822]|0;j=0;do{k=d[f+(j+64512)|0]|0;b=k&8;e=a[14114704]|0;if(e<<24>>24==0){n=j>>>2;o=j;p=b}else{i=~j;n=i>>2;o=i;p=b^8}eN5(l,k<<8&1792|(d[f+(j+63488)|0]|0),k>>>1&120,(o<<3&248)-24|0,(n&248)-16|0,p,e&255,0);j=j+1|0;}while((j|0)<1024);eN4(1);return 0}function eN$(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0;d=i;i=i+80|0;e=d|0;f=d+16|0;g=d+32|0;h=d+48|0;j=d+64|0;if((b|0)!=0){c[b>>2]=169249}if((a&96|0)==0){i=d;return 0}gGz(j|0,0,12);c[j>>2]=(c[2426600]|0)+57344;c[j+4>>2]=8192;c[j+12>>2]=162152;gj[c[2076592]&4095](j)|0;fw$(a);TU(a,b);gGz(h|0,0,12);c[h>>2]=9554088;c[h+4>>2]=1;c[h+12>>2]=149352;gj[c[2076592]&4095](h)|0;gGz(g|0,0,12);c[g>>2]=9578784;c[g+4>>2]=1;c[g+12>>2]=146072;gj[c[2076592]&4095](g)|0;gGz(f|0,0,12);c[f>>2]=14114704;c[f+4>>2]=1;c[f+12>>2]=142288;gj[c[2076592]&4095](f)|0;gGz(e|0,0,12);c[e>>2]=9731720;c[e+4>>2]=1;c[e+12>>2]=139264;gj[c[2076592]&4095](e)|0;i=d;return 0}function eN0(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6596988+(b*112|0)>>2];c[a+104>>2]=c[6596992+(b*112|0)>>2];c[a+108>>2]=c[6596996+(b*112|0)>>2];d=0;return d|0}function eN1(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=6596888+(b*112|0);e=0;return e|0}function eN2(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4777200+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eN3(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6598792+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eN4(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=c[2426600]|0;f=c[2424846]|0;g=0;do{h=d[e+(g+62464)|0]|0;i=h&4;j=a[14114704]|0;if(j<<24>>24==0){k=g>>>2;l=(g<<3)-(d[9554088]|0)|0;m=i}else{n=~g;k=n>>2;l=(n<<3)-(d[9554088]|0)|0;m=i^4}eN5(f,h<<8&768|(d[e+(g+61440)|0]|0),h>>>1&124,(l&255)-24|0,(k&248)-16|0,m,j&255,b);g=g+1|0;}while((g|0)<1024);return}function eN5(e,f,g,h,i,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;m=e+(f<<6)|0;if((k|0)!=0){k=(j|0)==0;f=h+7|0;e=(l|0)!=0;n=h+8|0;o=h+1|0;p=((n|0)>(o|0)?n:o)-h|0;o=c[2406912]|0;q=c[2112968]|0;r=c[2113308]|0;s=(r|0)>3;t=(r|0)==2;u=m;v=i+7|0;while(1){w=v>>>0>223;x=v*224|0;if(k){y=u;z=h;while(1){do{if(!(z>>>0>223|w)){A=c[o+((d[y]|0|g)<<2)>>2]|0;if(e&(A|0)==0){break}B=ag(r,z+x|0)|0;C=q+B|0;D=A>>16<<8&63488|A>>8<<3&2016;E=D|A>>>3&31;if(s){c[C>>2]=E;break}if(t){b[C>>1]=E&65535;break}else{a[C]=E&255;a[q+(B+1)|0]=D>>>8&255;a[q+(B+2)|0]=0;break}}}while(0);B=z+1|0;if((B|0)<(n|0)){y=y+1|0;z=B}else{break}}F=u+p|0}else{z=u;y=f;while(1){do{if(!(y>>>0>223|w)){B=c[o+((d[z]|0|g)<<2)>>2]|0;if(e&(B|0)==0){break}D=ag(r,y+x|0)|0;E=q+D|0;C=B>>16<<8&63488|B>>8<<3&2016;A=C|B>>>3&31;if(s){c[E>>2]=A;break}if(t){b[E>>1]=A&65535;break}else{a[E]=A&255;a[q+(D+1)|0]=C>>>8&255;a[q+(D+2)|0]=0;break}}}while(0);D=y-1|0;C=z+1|0;if((D|0)<(h|0)){F=C;break}else{z=C;y=D}}}y=v-1|0;if((y|0)<(i|0)){break}else{u=F;v=y}}return}v=i+8|0;F=(j|0)==0;j=h+7|0;u=(l|0)==0;q=h+8|0;t=(l|0)!=0;l=h+1|0;s=((q|0)>(l|0)?q:l)-h|0;l=c[2406912]|0;r=c[2112968]|0;e=c[2113308]|0;o=(e|0)>3;f=(e|0)==2;p=m;m=i;while(1){i=m>>>0>223;n=m*224|0;L28884:do{if(F){k=p;y=h;while(1){do{if(!(y>>>0>223|i)){z=c[l+((d[k]|0|g)<<2)>>2]|0;if(t&(z|0)==0){break}x=ag(e,y+n|0)|0;w=r+x|0;D=z>>16<<8&63488|z>>8<<3&2016;C=D|z>>>3&31;if(o){c[w>>2]=C;break}if(f){b[w>>1]=C&65535;break}else{a[w]=C&255;a[r+(x+1)|0]=D>>>8&255;a[r+(x+2)|0]=0;break}}}while(0);x=y+1|0;if((x|0)<(q|0)){k=k+1|0;y=x}else{break}}G=p+s|0}else{if(i){y=p;k=j;while(1){x=k-1|0;D=y+1|0;if((x|0)<(h|0)){G=D;break L28884}else{y=D;k=x}}}if(u){k=p;y=j;while(1){do{if(y>>>0<=223){x=c[l+((d[k]|0|g)<<2)>>2]|0;D=ag(e,y+n|0)|0;C=r+D|0;w=x>>16<<8&63488|x>>8<<3&2016;z=w|x>>>3&31;if(o){c[C>>2]=z;break}if(f){b[C>>1]=z&65535;break}else{a[C]=z&255;a[r+(D+1)|0]=w>>>8&255;a[r+(D+2)|0]=0;break}}}while(0);D=y-1|0;w=k+1|0;if((D|0)<(h|0)){G=w;break L28884}else{k=w;y=D}}}else{H=p;I=j}while(1){do{if(I>>>0<=223){y=c[l+((d[H]|0|g)<<2)>>2]|0;if((y|0)==0){break}k=ag(e,I+n|0)|0;D=r+k|0;w=y>>16<<8&63488|y>>8<<3&2016;z=w|y>>>3&31;if(o){c[D>>2]=z;break}if(f){b[D>>1]=z&65535;break}else{a[D]=z&255;a[r+(k+1)|0]=w>>>8&255;a[r+(k+2)|0]=0;break}}}while(0);k=I-1|0;w=H+1|0;if((k|0)<(h|0)){G=w;break}else{H=w;I=k}}}}while(0);n=m+1|0;if((n|0)<(v|0)){p=G;m=n}else{break}}return}function eN6(b,c,d,e){b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;f=b>>>4;g=c&255;h=a[d+(b>>>1&8|b&7|b>>>2&16|b>>>3&32|f&192|f&3840|((e|0)!=0?0:4096))|0]|0;f=h&255^255;if(h<<24>>24==-1){i=c;return i|0}c=f&1;h=f>>>2&1;b=c<<1;d=f>>>1&1;j=h<<1;k=f>>>4&1;l=((h^d^k)<<1|k<<2)^(h^c|b|f>>>5<<2&4);h=f>>>3<<1&2;k=(d^c|j)^h;m=f>>>6&1;n=((m^d)<<2|d<<3)^(m^f>>>7)<<3^((b|c)^j^h|c<<2);if((e|0)==0){o=n^1;p=l^1}else{o=n;p=l}switch(p|0){case 1:{i=(eN7(g,o,k)|0)&255;return i|0};case 7:{if((k|0)==1){q=g<<1&2|g&132|g>>>3&1|g>>>5<<6&64|g>>>4<<5&32|g>>>6<<4&16|g>>>1<<3&8}else if((k|0)==2){q=g<<4&16|g&128|g>>>2&1|g>>>4<<6&64|g>>>3<<5&32|g>>>5<<3&8|g>>>1<<2&4|g>>>6<<1&2}else if((k|0)==0){q=g<<3&8|g&48|g>>>1&1|g>>>7<<6|g>>>3<<7&128|g>>>6<<2&4|g>>>2<<1&2}else if((k|0)==3){q=g<<1&2|g&72|g>>>5&1|g>>>7<<2|g>>>2<<7&128|g>>>4<<5&32|g>>>1<<4&16}else{q=g}p=(q&4|0)==0?q:q^128;q=p>>>7&1;if((q|0)==0){r=p}else{r=q<<7|p&87|p>>>3<<5&32|p>>>5<<3&8}p=(o&8|0)!=0;q=p?r^128:r;r=(q&16|0)==0?q:q^64;q=(r&2|0)==0?r:r^84;r=(q&192|0)!=192?q:q^2;q=(r&128|0)==0?r:r^2;r=(p?q^128:q)^o>>>2&1;if(p){s=r<<2&4|r&66|r>>>7&1|r>>>4<<7&128|r>>>3<<5&32|r>>>2<<4&16|r>>>5<<3&8}else{s=r}r=(s&16|0)==0?s:s^2;s=(r&32|0)==0?r:r^16;r=((s&128|0)==0?s:s^4)^(o<<6&128|44);i=((o&1|0)==0?r:r^8)&255;return i|0};case 2:{if((k|0)==1){t=g>>>7|g&62|g<<6&64|g>>>6<<7&128}else if((k|0)==0){t=g>>>7<<2|g&11|g>>>2<<6&64|g>>>4<<7&128|g>>>6<<5&32|g>>>5<<4&16}else if((k|0)==3){t=g>>>4&1|g<<1&2|g>>>7<<2|g>>>5<<6&64|g>>>6<<7&128|g>>>1<<5&32|g>>>3<<4&16|g>>>2<<3&8}else if((k|0)==2){t=g>>>5&1|g<<2&4|g>>>7<<1|g>>>3<<6&64|g>>>2<<7&128|g>>>6<<5&32|g>>>1<<4&16|g>>>4<<3&8}else{t=g}if((o&4|0)==0){u=t}else{u=t>>>1<<5&32|t&205|t>>>5<<4&16|t>>>4<<1&2}t=u>>>1&1^u;u=(t&64|0)==0?t:t^8;t=(u&128|0)==0?u:u^72;u=(t&4|0)==0?t:t^74;t=(u&16|0)==0?u:u^196;u=(((t>>>7^t>>>2)&1|0)==0?t:t^16)^((o&8|0)==0?75:207);t=(o&2|0)==0?u:u^72;if((o&1|0)==0){i=t&255;return i|0}i=(t>>>1<<5&32|t&221|t>>>5<<1&2)&255;return i|0};case 3:{if((k|0)==0){v=g<<6&64|g>>>7|g>>>1<<7&128|g>>>3<<5&32|g>>>2<<4&16|g>>>5<<3&8|g>>>6<<2&4|g>>>4<<1&2}else if((k|0)==1){v=g<<6&64|g&32|g>>>3&1|g>>>7<<3|g>>>2<<7&128|g>>>1<<4&16|g>>>4<<2&4|g>>>6<<1&2}else if((k|0)==2){v=g<<3&8|g&2|g>>>3&1|g>>>7<<5|g>>>4<<6&64|g>>>6<<7&128|g>>>2<<4&16|g>>>5<<2&4}else if((k|0)==3){v=g<<3&8|g&132|g>>>4&1|g>>>1<<6&64|g>>>3<<5&32|g>>>6<<4&16|g>>>5<<1&2}else{v=g}t=(v&5|0)!=5?v:v^144;v=(t&128|0)==0?t:t^4;t=(v&32|0)==0?v:v^132;v=(t&2|0)==0?t:t^32;t=(v&64|0)==0?v:v^2;v=(t&16|0)==0?t:t^96;t=(v&1|0)==0?v:v^70;v=((t&8|0)==0?t:t^199)^((o&8|0)==0?81:67);t=(o&4|0)==0?v:v^201;v=(o&2|0)==0?t:t^24;i=((o&1|0)==0?v:v^71)&255;return i|0};case 4:{if((k|0)==0){w=g<<7&128|g>>>7|g>>>1<<6&64|g>>>4<<5&32|g>>>3<<4&16|g>>>5<<3&8|g>>>6<<2&4|g>>>2<<1&2}else if((k|0)==1){w=g<<5&32|g&2|g>>>2&1|g>>>7<<3|g>>>3<<6&64|g>>>6<<7&128|g>>>5<<4&16|g>>>4<<2&4}else if((k|0)==2){w=g<<3&8|g&64|g>>>2&1|g>>>7<<1|g>>>1<<7&128|g>>>4<<5&32|g>>>5<<4&16|g>>>3<<2&4}else if((k|0)==3){w=g>>>7<<5|g&67|g>>>4<<7&128|g>>>5<<4&16|g>>>2<<3&8|g>>>3<<2&4}else{w=g}v=w>>>3&1;do{if((v|0)==0){if((o&2|0)==0){x=w;break}if((w&4|0)==0){x=w}else{y=22080}}else{y=22080}}while(0);if((y|0)==22080){x=w<<6&64|w&22|w>>>5&1|w>>>6<<7&128|w>>>7<<5&32|v<<3}v=(x&32|0)==0?x:x^128;x=(v&64|0)==0?v:v^32;v=(x&1|0)==0?x:x^64;x=(v&16|0)==0?v:v^9;v=((x&2|0)==0?x:x^4)^((o&4|0)==0?242:237);x=(o&1|0)!=0;if((o&8|0)==0){if(!x){i=v&255;return i|0}i=(v>>>2<<4&16|v&225|v>>>1<<3&8|v>>>3<<2&4|v>>>4<<1&2)&255;return i|0}if(x){i=(v>>>3<<4&16|v&225|v>>>4<<3&8|v>>>1<<2&4|v>>>2<<1&2)&255;return i|0}else{i=(v>>>1<<4&16|v&225|v>>>2<<3&8|v>>>4<<2&4|v>>>3<<1&2)&255;return i|0}break};case 5:{if((k|0)==0){z=g>>>2&1|g<<1&2|g>>>7<<2|g>>>3<<6&64|g>>>1<<7&128|g>>>4<<5&32|g>>>6<<4&16|g>>>5<<3&8}else if((k|0)==1){z=g<<7&128|g&48|g>>>6&1|g>>>7<<3|g>>>1<<6&64|g>>>3<<2&4|g>>>2<<1&2}else if((k|0)==2){z=g>>>7|g&4|g<<1&2|g>>>5<<6&64|g>>>3<<7&128|g>>>4<<5&32|g>>>1<<4&16|g>>>6<<3&8}else if((k|0)==3){z=g>>>1&1|g<<4&16|g>>>7<<2|g>>>2<<6&64|g>>>5<<7&128|g>>>3<<5&32|g>>>4<<3&8|g>>>6<<1&2}else{z=g}v=(z&136|0)!=136?z:z^81;z=(v&128|0)==0?v:v^4;v=(z&32|0)==0?z:z^136;z=(v&2|0)==0?v:v^32;v=(z&16|0)==0?z:z^170;z=(v&160|0)!=160?v:v^17;v=(z&34|0)!=34?z:z^17;z=(v&64|0)==0?v:v^160;v=(z&8|0)==0?z:z^226;z=((v&4|0)==0?v:v^10)^((o&8|0)==0?142:196);v=(o&4|0)==0?z:z^238;z=(o&2|0)==0?v:v^128;i=((o&1|0)==0?z:z^36)&255;return i|0};case 6:{if((k|0)==1){A=g>>>6&1|g<<1&2|g>>>7<<2|g>>>1<<6&64|g>>>3<<7&128|g>>>2<<5&32|g>>>5<<4&16|g>>>4<<3&8}else if((k|0)==3){A=g<<4&16|g&70|g>>>3&1|g>>>7<<5|g>>>5<<7&128|g>>>4<<3&8}else if((k|0)==2){A=g<<2&4|g&64|g>>>3&1|g>>>7<<3|g>>>5<<7&128|g>>>1<<5&32|g>>>2<<4&16|g>>>4<<1&2}else if((k|0)==0){A=g<<3&8|g&4|g>>>4&1|g>>>7<<4|g>>>3<<6&64|g>>>5<<7&128|g>>>1<<5&32|g>>>6<<1&2}else{A=g}z=(A&4|0)==0?A:A^176;A=z>>>3&1^z;z=o&1;if((z|0)==0){B=A}else{B=A<<1&2|A&184|A>>>6&1|A>>>2<<6&64|A>>>1<<2&4}A=(B&2|0)==0?B:B^65;B=(A&8|0)==0?A:A^22;A=(o&8|0)==0?B:B^24;B=A>>>3&1;if((B|0)==0){C=A}else{C=A>>>5<<7&128|A&87|A>>>7<<5&32|B<<3}B=((C&32|0)==0?C:C^6)^(o<<5&128|120);i=(((o&2|0)==0?B:B^16)^z)&255;return i|0};default:{i=(eN7(g,o,k)|0)&255;return i|0}}return 0}function eN7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;if((c|0)==1){d=a>>>6&1|a<<2&4|a>>>3<<6&64|a>>>5<<7&128|a>>>7<<5&32|a>>>2<<4&16|a>>>1<<3&8|a>>>4<<1&2}else if((c|0)==0){d=a<<2&4|a&128|a>>>4&1|a>>>5<<6&64|a>>>3<<5&32|a>>>1<<4&16|a>>>2<<3&8|a>>>6<<1&2}else if((c|0)==2){d=a>>>2&1|a<<7&128|a>>>3<<6&64|a>>>4<<5&32|a>>>6<<4&16|a>>>7<<3&8|a>>>1<<2&4|a>>>5<<1&2}else if((c|0)==3){d=a<<7&128|a&2|a>>>5&1|a>>>7<<6&64|a>>>3<<5&32|a>>>2<<4&16|a>>>6<<3&8|a>>>4<<2&4}else{d=a}if((b&8|0)==0){e=d}else{e=(d&128|0)==0?d:d^41}d=(b&4|0)!=0;if(d){f=(e&64|0)==0?e:e^134}else{f=e}e=(f&64|0)==0?f:f^128;f=(b&2|0)!=0;if(f){g=(e&128|0)==0?e:e^64}else{g=e}e=((g&4|0)==0?g:g^33)^(d?63:26);d=f?e^192:e;e=(b&1|0)!=0;b=e?d^33:d;if(!e){h=b;return h|0}h=b>>>1<<4&16|b&225|b>>>4<<3&8|b>>>3<<2&4|b>>>2<<1&2;return h|0}function eN8(){var a=0,b=0,d=0,e=0,f=0;a=c[2394]|0;b=14130368+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGC(d|0,9104152,280)|0}d=8452240+(a<<2)|0;c[d>>2]=c[2113054];c[2394]=1;c[2112932]=c[3532597];e=c[3532593]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113061];RI();e=c[2394]|0;f=c[14130368+(e<<2)>>2]|0;if((f|0)!=0){gGC(f|0,9104152,280)|0}c[8452240+(e<<2)>>2]=c[2113054];c[2394]=-1;if((a|0)==-1){return 0}c[2394]=a;c[2112932]=c[14130384+(a<<2)>>2];a=c[b>>2]|0;if((a|0)!=0){gGC(9104152,a|0,280)|0}c[2113054]=c[d>>2];return 0}function eN9(b){b=b|0;var d=0,e=0;d=b&255;if((d|0)==64|(d|0)==192){a[9706117]=0;e=c[3532412]&255;return e|0}else if((d|0)==1){e=c[(c[3531464]|0)+4240>>2]&255;return e|0}else if((d|0)==128){if((c[3532344]|0)==0){e=0;return e|0}d=c[2418506]|0;c[2424874]=d;e=((a[d+16|0]|0)==0)<<7;return e|0}else{e=0;return e|0}return 0}function eOa(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0;d=i;i=i+8|0;e=d|0;f=b&255;if((f|0)==1){g=c[(c[3531464]|0)+4240>>2]&255;i=d;return g|0}else if((f|0)==64|(f|0)==192){a[9669004]=0;f=a[9668984]|0;if((f<<24>>24|0)==1){if((a[9668986]|0)!=0|(a[9668990]|0)==0){h=0}else{j=22172}}else if((f<<24>>24|0)==2){if((a[9668990]|0)==0){h=0}else{j=22172}}else{h=0}if((j|0)==22172){a[9668990]=0;h=1}if((a[9668987]|0)!=0|(a[9668985]|0)!=1|(a[9668991]|0)==0){if((h|0)!=0){j=22176}}else{a[9668991]=0;j=22176}do{if((j|0)==22176){h=a[9669001]|0;a[e]=h&a[9669007]|~h;S7(9668984,e);h=a[e]|0;a[9669010]=h;f=c[3540896]|0;if((f|0)==0){break}gf[f&2047](h)}}while(0);g=c[3532412]&255;i=d;return g|0}else{g=0;i=d;return g|0}return 0}function eOb(a){a=a|0;var b=0,d=0;b=a&255;if((b|0)==64|(b|0)==192){d=c[3532412]&255;return d|0}else if((b|0)==1){d=c[(c[3531464]|0)+4240>>2]&255;return d|0}else{d=0;return d|0}return 0}function eOc(a){a=a|0;var b=0,d=0;b=a&255;if((b|0)==64|(b|0)==192){d=c[3532412]&255}else{d=0}return d|0}function eOd(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=b&255;do{if((e|0)==64){if((c[3532344]|0)==0){break}b=d&255;f=c[2418506]|0;c[2424874]=f;g=f+10|0;h=a[g]|0;a[g]=(d&255)>>>7;g=c[2424874]|0;i=g+16|0;do{if((a[i]|h)<<24>>24==0){if((a[g+10|0]|0)==0){j=f;break}if((a[g+9|0]|0)==0){j=f;break}a[i]=2;if(!(a[635136]|0)){j=f;break}k=a[(c[2424874]|0)+11|0]|0;Vk();l=c[2424874]|0;m=a[l+11|0]|0;if(k<<24>>24==m<<24>>24){j=f;break}k=c[l+12>>2]|0;if((k|0)==0){j=f;break}gf[k&2047](m&255);j=c[2418506]|0}else{j=f}}while(0);c[2424874]=j;f=j+9|0;i=a[f]|0;a[f]=(d&255)>>>6&1;do{if(i<<24>>24!=0){if((a[(c[2424874]|0)+9|0]|0)!=0){break}Vl()}}while(0);i=(c[642608+(c[2436]<<2)>>2]|0)+60|0;f=c[i>>2]|0;if((f&4|0)==0){n=f}else{if((b&4|0)==0){c[2430046]=0}if((b&8|0)==0){c[2430046]=65536}if((b&16|0)==0){c[2430046]=131072}if((b&32|0)==0){c[2430046]=196608;o=196608}else{o=c[2430046]|0}c[2430046]=o+(b<<14&49152);n=c[i>>2]|0}if((n&33792|0)==0){p=n}else{c[2430046]=b>>>3<<17&131072|b<<14&114688;p=c[i>>2]|0}if((p&2048|0)==0){q=c[2430046]|0}else{i=b>>>4<<17&131072|b<<14&114688|b>>>3<<18&262144;c[2430046]=i;q=i}i=(q>>>0)%((c[3532344]|0)>>>0)|0;c[2430046]=i;f=c[3532348]|0;g=c[9757320+(c[1836236]<<2)>>2]|0;h=i-32768|0;i=128;m=128;while(1){c[g+76+(m<<2)>>2]=f+(h+(m<<8));k=i+1&65535;if((k&65535)>223){break}else{i=k;m=k&65535}}m=(c[2430046]|0)-32768|0;i=128;h=128;while(1){b=f+(m+(h<<8))|0;c[g+76+(h+512<<2)>>2]=b;c[g+76+(h+768<<2)>>2]=b;b=i+1&65535;if((b&65535)>223){break}else{i=b;h=b&65535}}return}else if((e|0)==1){h=c[2113304]|0;a[14168504+h|0]=d;mv(0,h,d&255);return}else if((e|0)==0){c[2113304]=d&255;return}else if((e|0)!=128){return}}while(0);if((c[3532574]|0)==0){if((c[3532344]|0)==0){return}e=c[2418506]|0;c[2424874]=e;a[e+8|0]=d;return}e=d&255;q=c[2437628]&16383|e<<14&16384;c[2437628]=q;p=c[3532582]|0;if((e&4|0)==0&p>>>0>1){n=q|32768;c[2437628]=n;r=n}else{r=q}if((e&8|0)==0&p>>>0>2){q=r|65536;c[2437628]=q;s=q}else{s=r}if((e&16|0)==0&p>>>0>3){c[2437628]=s|98304}a[9773128]=(d&255)>>>5;return}function eOe(b){b=b|0;var d=0;if((b+4096&65535)>=256){d=0;return d|0}d=a[(c[2424876]|0)+(b&2047)|0]|0;return d|0}function eOf(b,d){b=b|0;d=d|0;if((b+4096&65535)>=256){return}a[(c[2424876]|0)+(b&2047)|0]=d;return}function eOg(b){b=b|0;var d=0,e=0,f=0,g=0,h=0;d=i;i=i+8|0;e=d|0;if((b&255)!=64){f=0;i=d;return f|0}a[9669004]=0;b=a[9668984]|0;if((b<<24>>24|0)==1){if((a[9668986]|0)!=0|(a[9668990]|0)==0){g=0}else{h=22259}}else if((b<<24>>24|0)==2){if((a[9668990]|0)==0){g=0}else{h=22259}}else{g=0}if((h|0)==22259){a[9668990]=0;g=1}if((a[9668987]|0)!=0|(a[9668985]|0)!=1|(a[9668991]|0)==0){if((g|0)!=0){h=22263}}else{a[9668991]=0;h=22263}do{if((h|0)==22263){g=a[9669001]|0;a[e]=g&a[9669007]|~g;S7(9668984,e);g=a[e]|0;a[9669010]=g;b=c[3540896]|0;if((b|0)==0){break}gf[b&2047](g)}}while(0);f=c[3532412]&255;i=d;return f|0}function eOh(b){b=b|0;var d=0,e=0,f=0.0,g=0.0;if((b+8192&65535)<256){d=a[(c[2424876]|0)+(b&2047)|0]|0;return d|0}if(b<<16>>16!=-12288){d=0;return d|0}b=c[3541518]|0;e=b+296|0;f=+h[e>>3];do{if(f!=0.0){g=+h[6675];if(f-(g+ +gC[c[2429842]&255]())<=0.0){h[e>>3]=0.0;break}d=a[b+307|0]|-128;return d|0}}while(0);d=a[b+307|0]|0;return d|0}function eOi(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=b&65535;if((b+8192&65535)<256){a[(c[2424876]|0)+(e&2047)|0]=d;return}if((e|0)==53248){b=c[3541518]|0;f=b+256|0;a[b+304|0]=d;g=d&255;if((d&255)<16){c[14168912+((c[2383582]|0)*252|0)>>2]=g&15}if((d-45&255)>=3){return}if((g|0)==45){h=b+312|0;i=a[h]|2;a[h]=i;j=i}else if((g|0)==0){a[b+312|0]=2;j=2}else if((g|0)==47){a[b+312|0]=0;j=0}else if((g|0)==46){g=b+312|0;i=a[g]|1;a[g]=i;j=i}else{j=a[b+312|0]|0}b=j&3;j=c[7461744+(b<<2)>>2]|0;lI(f,j,j,c[7461728+(b<<2)>>2]|0);return}else if((e|0)==53249){lS(0,1,d);return}else{return}}function eOj(b){b=b|0;var d=0;if((b+4096&65535)>=256){d=0;return d|0}d=a[(c[2424877]|0)+(b&2047)|0]|0;return d|0}function eOk(b,d){b=b|0;d=d|0;if((b+4096&65535)>=256){return}a[(c[2424877]|0)+(b&2047)|0]=d;return}function eOl(b){b=b|0;var d=0,e=0,f=0.0,g=0.0,i=0;d=b&255;if((d|0)==128){b=c[3541512]|0;e=b+552|0;f=+h[e>>3];do{if(f!=0.0){g=+h[6675];if(f-(g+ +gC[c[2429842]&255]())<=0.0){h[e>>3]=0.0;break}i=a[b+563|0]|-128;return i|0}}while(0);i=a[b+563|0]|0;return i|0}else if((d|0)==192){i=c[3532412]&255;return i|0}else{i=0;return i|0}return 0}function eOm(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;switch(b&255|0){case 144:{b=c[3541512]|0;a[b+20984|0]=d;a[b+40832|0]=0;return};case 131:{md(0,3,d);return};case 147:{md(1,3,d);return};case 146:{b=c[3541512]|0;a[b+20984|0]=d;a[b+40832|0]=1;return};case 160:{b=(d&255)<<13;c[2429490]=b;e=c[3532330]|0;f=c[9757320+(c[1836236]<<2)>>2]|0;g=b+24576|0;b=160;h=160;while(1){c[f+76+(h<<2)>>2]=e+(g+(h<<8));i=b+1&65535;if((i&65535)>191){break}else{b=i;h=i&65535}}h=(c[2429490]|0)+24576|0;b=160;g=160;while(1){i=e+(h+(g<<8))|0;c[f+76+(g+512<<2)>>2]=i;c[f+76+(g+768<<2)>>2]=i;i=b+1&65535;if((i&65535)>191){break}else{b=i;g=i&65535}}return};case 129:{md(0,1,d);return};case 128:{g=c[3541512]|0;a[g+560|0]=d;a[g+20408|0]=0;return};case 130:{g=c[3541512]|0;a[g+560|0]=d;a[g+20408|0]=1;return};case 145:{md(1,1,d);return};default:{return}}}function eOn(b){b=b|0;var e=0,f=0;e=b+12288&65535;if((e&65535)>=4096){f=0;return f|0}b=c[2420422]|0;f=a[((d[b+97|0]|0)<<12)+(e&65535)+(b+99)|0]|0;return f|0}function eOo(e,f){e=e|0;f=f|0;var g=0,h=0,i=0;if((e+16384&65535)>=16){g=e+12288&65535;if((g&65535)>=4096){return}h=c[2420422]|0;a[(d[h+97|0]<<12)+(g&65535)+(h+99)|0]=f;return}h=c[2420422]|0;g=h+96|0;i=d[g]|0;switch(e&255|0){case 4:{e=h+(i*12|0)+10|0;b[e>>1]=b[e>>1]&-256|f&255;return};case 1:{a[h+(i*12|0)+2|0]=f;return};case 0:{a[h+(i*12|0)+1|0]=f;return};case 2:{e=h+(i*12|0)+8|0;b[e>>1]=b[e>>1]&-256|f&255;return};case 5:{e=h+(i*12|0)+10|0;b[e>>1]=b[e>>1]&255|(f&255)<<8;return};case 6:{a[h+(i*12|0)+3|0]=f;if((a[h+(i*12|0)|0]|0)!=0){return}c[h+(i*12|0)+4>>2]=(f&255)<<19;return};case 7:{a[h+98|0]=(f&255)>>>7;if((f&64)==0){a[h+97|0]=f&15;return}else{a[g]=f&7;return}break};case 3:{g=h+(i*12|0)+8|0;b[g>>1]=b[g>>1]&255|(f&255)<<8;return};case 8:{g=~(f&255);f=0;do{i=g>>>(f>>>0)&1;a[h+(f*12|0)|0]=i;if(i<<24>>24==0){c[h+(f*12|0)+4>>2]=d[h+(f*12|0)+3|0]<<19}f=f+1|0;}while((f|0)<8);return};default:{return}}}function eOp(c,d){c=c|0;d=d|0;if((d&1|0)==0){b[4859110]=0;a[9718225]=0;a[9718224]=0;a[9718226]=8;a[9718229]=-1;a[9718230]=-1;a[9718227]=0;a[9718237]=0;a[9718236]=0;a[9718249]=0;a[9718238]=0;gGz(9718242|0,0|0,6|0);return}if((d&2|0)==0){fJ$(1);return}else{a[9718248]=0;return}}function eOq(b){b=b|0;var d=0;if((b|0)==258){d=a[9773128]<<4|-128}else if((b|0)==288){d=a[(c[3532584]|0)+(c[2437628]|0)|0]|0}else{d=0}return d|0}function eOr(a,d){a=a|0;d=d|0;var e=0;switch(a|0){case 257:{US(0,gD[c[2385643]&8191]()|0);b[4771272]=~~(+(b[9732544+((d&255)<<1)>>1]|0)*+h[1192819])&65535;return};case 263:case 260:case 261:case 262:{e=(a<<2)-1040|0;a=15<<e;c[2437628]=c[2437628]&((a|-16384)^16383)|a&16383&(d&255)<<e;return};default:{return}}}function eOs(b){b=b|0;var d=0;if(b>>>0>=1024){d=0;return d|0}d=a[(c[3532578]|0)+b|0]|0;return d|0}function eOt(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0;e=i;i=i+1672|0;f=e|0;g=e+112|0;h=e+120|0;j=e+232|0;k=e+240|0;l=e+352|0;m=e+360|0;n=e+472|0;o=e+480|0;p=e+592|0;q=e+600|0;r=e+712|0;s=e+720|0;t=e+832|0;u=e+840|0;v=e+952|0;w=e+960|0;x=e+1072|0;y=e+1080|0;z=e+1192|0;A=e+1200|0;B=e+1312|0;C=e+1320|0;D=e+1432|0;E=e+1440|0;F=e+1552|0;G=e+1560|0;H=G+108|0;c[H>>2]=0;I=G+100|0;c[I>>2]=0;if(!b){b=-1;do{c[I>>2]=0;c[H>>2]=0;b=b+1|0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](G,b)|0;L29366:do{switch(c[H>>2]&255|0){case 13:{c[3532318]=(c[3532318]|0)+(c[I>>2]|0);c[3532320]=(c[3532320]|0)+1;J=22434;break};case 3:{c[3532380]=(c[3532380]|0)+(c[I>>2]|0);c[3532382]=(c[3532382]|0)+1;J=22434;break};case 8:{K=c[I>>2]|0;c[3532344]=(K>>>0<65536?65536:K)+(c[3532344]|0);c[3532346]=(c[3532346]|0)+1;J=22434;break};case 11:{K=c[3532494]|0;if((K|0)==0){c[3532496]=(c[3532496]|0)+(c[I>>2]|0);c[3532498]=(c[3532498]|0)+1;J=22434;break L29366}else{c[3532496]=K;c[3532498]=(c[3532498]|0)+1;J=22434;break L29366}break};case 12:{c[3532324]=(c[3532324]|0)+(c[I>>2]|0);c[3532326]=(c[3532326]|0)+1;J=22434;break};case 9:{c[3532440]=(c[3532440]|0)+(c[I>>2]|0);c[3532442]=(c[3532442]|0)+1;J=22434;break};case 2:{c[3532352]=(c[3532352]|0)+(c[I>>2]|0);c[3532354]=(c[3532354]|0)+1;J=22434;break};case 4:{c[3532308]=(c[3532308]|0)+(c[I>>2]|0);c[3532310]=(c[3532310]|0)+1;J=22434;break};case 6:{c[3532574]=(c[3532574]|0)+(c[I>>2]|0);c[3532576]=(c[3532576]|0)+1;J=22434;break};case 10:{c[3532450]=(c[3532450]|0)+(c[I>>2]|0);c[3532452]=(c[3532452]|0)+1;J=22434;break};case 7:{c[3532580]=(c[3532580]|0)+(c[I>>2]|0);c[3532582]=(c[3532582]|0)+1;J=22434;break};case 19:{c[3532472]=(c[3532472]|0)+1;J=22434;break};case 16:{c[3532476]=(c[3532476]|0)+(c[I>>2]|0);c[3532478]=(c[3532478]|0)+1;J=22434;break};case 15:{c[3532502]=(c[3532502]|0)+(c[I>>2]|0);c[3532504]=(c[3532504]|0)+1;J=22434;break};case 5:{K=c[I>>2]|0;c[3532516]=(c[3532516]|0)+K;L=K;break};case 14:{c[3532312]=(c[3532312]|0)+(c[I>>2]|0);c[3532314]=(c[3532314]|0)+1;J=22434;break};case 17:{c[3532434]=(c[3532434]|0)+(c[I>>2]|0);c[3532436]=(c[3532436]|0)+1;J=22434;break};case 18:{c[3532408]=(c[3532408]|0)+(c[I>>2]|0);c[3532410]=(c[3532410]|0)+1;J=22434;break};case 1:{c[3532430]=(c[3532430]|0)+(c[I>>2]|0);c[3532432]=(c[3532432]|0)+1;J=22434;break};default:{J=22434}}}while(0);if((J|0)==22434){J=0;L=c[I>>2]|0}}while((L|0)!=0);c[3532508]=((c[3532352]|0)>>>0)/24|0;L=c[3532472]|0;if((L|0)==0){M=0;i=e;return M|0}c[3532310]=(c[3532310]|0)+L;c[3532308]=2162688;M=0;i=e;return M|0}L29398:do{if((c[3532432]|0)==0){N=0}else{L=0;H=0;while(1){if((R6((c[3532446]|0)+(H+1)|0,L,2)|0)!=0){M=1;J=22646;break}b=L|1;if((R6((c[3532446]|0)+H|0,b,2)|0)!=0){M=1;J=22645;break}gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](G,L)|0;K=(c[I>>2]|0)+H|0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](G,b)|0;b=L+2|0;O=c[3532432]|0;if(b>>>0<O>>>0){L=b;H=K+(c[I>>2]|0)|0}else{N=O;break L29398}}if((J|0)==22645){i=e;return M|0}else if((J|0)==22646){i=e;return M|0}}}while(0);L29407:do{if((c[3532440]|0)==0){P=N}else{if(N>>>0<((c[3532442]|0)+N|0)>>>0){Q=N;R=0}else{P=N;break}while(1){if((R6((c[3532444]|0)+(R+1)|0,Q,2)|0)!=0){M=1;J=22632;break}H=Q+1|0;if((R6((c[3532444]|0)+R|0,H,2)|0)!=0){M=1;J=22633;break}gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](G,Q)|0;L=(c[I>>2]|0)+R|0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](G,H)|0;H=Q+2|0;O=c[3532432]|0;if(H>>>0<((c[3532442]|0)+O|0)>>>0){Q=H;R=L+(c[I>>2]|0)|0}else{P=O;break L29407}}if((J|0)==22632){i=e;return M|0}else if((J|0)==22633){i=e;return M|0}}}while(0);L29417:do{if((c[3532434]|0)!=0){R=(c[3532442]|0)+P|0;if(R>>>0<(R+(c[3532436]|0)|0)>>>0){S=R;T=0}else{break}while(1){if((R6((c[3532438]|0)+(T+1)|0,S,2)|0)!=0){M=1;J=22668;break}R=S+1|0;if((R6((c[3532438]|0)+T|0,R,2)|0)!=0){M=1;J=22667;break}gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](G,S)|0;Q=(c[I>>2]|0)+T|0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](G,R)|0;R=S+2|0;if(R>>>0<((c[3532442]|0)+(c[3532432]|0)+(c[3532436]|0)|0)>>>0){S=R;T=Q+(c[I>>2]|0)|0}else{break L29417}}if((J|0)==22667){i=e;return M|0}else if((J|0)==22668){i=e;return M|0}}}while(0);T=c[3532352]|0;S=0;while(1){if((S|0)>=1024){U=0;break}V=9638528+(S<<2)|0;if((c[V>>2]|0)==0){J=22456;break}else{S=S+1|0}}do{if((J|0)==22456){S=gGq(T)|0;c[V>>2]=S;if((S|0)==0){U=0;break}gGz(S|0,0,T|0);U=S}}while(0);c[3532370]=U;T=c[3532432]|0;V=c[3532442]|0;S=c[3532436]|0;P=V+T+S|0;Q=c[3532354]|0;L29434:do{if(P>>>0<(P+Q|0)>>>0){if((c[3542200]|0)==0){M=1;i=e;return M|0}R=E+108|0;N=E+100|0;O=0;L=P;H=U;while(1){c[R>>2]=0;c[N>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](E,L)|0;if((c[R>>2]|0)!=0){K=c[N>>2]|0;c[F>>2]=9534384;b=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[b&16383](F,L,0)|0;if((K|0)<1){M=1;J=22634;break}if((gzL(H,0,L)|0)!=0){M=1;J=22635;break}}gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](G,L)|0;K=L+1|0;b=c[3532432]|0;W=c[3532442]|0;X=c[3532436]|0;Y=c[3532354]|0;if(K>>>0>=(W+b+X+Y|0)>>>0){Z=b;_=W;$=X;aa=Y;break L29434}Y=(c[I>>2]|0)+O|0;if((c[3542200]|0)==0){M=1;J=22627;break}else{O=Y;L=K;H=(c[3532370]|0)+Y|0}}if((J|0)==22627){i=e;return M|0}else if((J|0)==22634){i=e;return M|0}else if((J|0)==22635){i=e;return M|0}}else{Z=T;_=V;$=S;aa=Q}}while(0);Q=c[642608+(c[2436]<<2)>>2]|0;S=c[3532352]|0;do{if((c[Q+60>>2]&512|0)==0){ab=S}else{if((S|0)==0){ab=0;break}V=c[3532370]|0;T=0;while(1){F=V+T|0;a[F]=~a[F];F=T+1|0;if(F>>>0<S>>>0){T=F}else{ab=S;break}}}}while(0);S=c[3532350]|0;T=c[3532508]|0;V=(ab<<1>>>0)/3|0;F=(ab>>>0)/3|0;ab=c[3532370]|0;if((T|0)>0){E=0;while(1){U=E<<3;P=U+V|0;H=U+F|0;L=E<<6|7;O=0;do{N=(O<<3)+L|0;R=0;Y=d[ab+(P+O)|0]|0;K=d[ab+(H+O)|0]|0;X=d[ab+(O+U)|0]|0;while(1){W=Y<<2&4;b=(K&1|0)==0?W:W|2;if((X&1|0)==0){ac=b&255}else{ac=(b|1)&255}a[S+(N-R)|0]=ac;b=R+1|0;if((b|0)<8){R=b;Y=Y>>1;K=K>>1;X=X>>1}else{break}}O=O+1|0;}while((O|0)<8);O=E+1|0;if((O|0)<(T|0)){E=O}else{ad=ab;break}}}else{ad=ab}ab=0;while(1){if((ab|0)>=1024){ae=Q;af=Z;ag=_;ah=$;ai=aa;break}aj=9638528+(ab<<2)|0;if((c[aj>>2]|0)==(ad|0)){J=22481;break}else{ab=ab+1|0}}if((J|0)==22481){gGr(ad);c[aj>>2]=0;ae=c[642608+(c[2436]<<2)>>2]|0;af=c[3532432]|0;ag=c[3532442]|0;ah=c[3532436]|0;ai=c[3532354]|0}c[3532370]=0;aj=ag+af+ah+ai|0;ad=c[3532382]|0;ab=aj>>>0<(aj+ad|0)>>>0;L29476:do{if((c[ae+60>>2]&128|0)==0){if(ab){ak=aj;al=0}else{am=af;an=ag;ao=ah;ap=ai;aq=ad;break}while(1){if((R6((c[3532374]|0)+al|0,ak,2)|0)!=0){M=1;J=22638;break}aa=ak+1|0;if((R6((c[3532374]|0)+(al+1)|0,aa,2)|0)!=0){M=1;J=22639;break}gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](G,ak)|0;$=(c[I>>2]|0)+al|0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](G,aa)|0;aa=ak+2|0;_=c[3532432]|0;Z=c[3532442]|0;Q=c[3532436]|0;E=c[3532354]|0;T=c[3532382]|0;if(aa>>>0<(Z+_+Q+E+T|0)>>>0){ak=aa;al=$+(c[I>>2]|0)|0}else{am=_;an=Z;ao=Q;ap=E;aq=T;break L29476}}if((J|0)==22638){i=e;return M|0}else if((J|0)==22639){i=e;return M|0}}else{if(ab){ar=aj;as=0}else{am=af;an=ag;ao=ah;ap=ai;aq=ad;break}while(1){if((R6((c[3532374]|0)+as|0,ar,4)|0)!=0){M=1;J=22655;break}T=ar+1|0;if((R6((c[3532374]|0)+(as+1)|0,T,4)|0)!=0){M=1;J=22656;break}E=ar+2|0;if((R6((c[3532374]|0)+(as+2)|0,E,4)|0)!=0){M=1;J=22636;break}Q=ar+3|0;if((R6((c[3532374]|0)+(as+3)|0,Q,4)|0)!=0){M=1;J=22637;break}gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](G,ar)|0;Z=(c[I>>2]|0)+as|0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](G,T)|0;T=Z+(c[I>>2]|0)|0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](G,E)|0;E=T+(c[I>>2]|0)|0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](G,Q)|0;Q=ar+4|0;T=c[3532432]|0;Z=c[3532442]|0;_=c[3532436]|0;$=c[3532354]|0;aa=c[3532382]|0;if(Q>>>0<(Z+T+_+$+aa|0)>>>0){ar=Q;as=E+(c[I>>2]|0)|0}else{am=T;an=Z;ao=_;ap=$;aq=aa;break L29476}}if((J|0)==22636){i=e;return M|0}else if((J|0)==22637){i=e;return M|0}else if((J|0)==22655){i=e;return M|0}else if((J|0)==22656){i=e;return M|0}}}while(0);L29498:do{if((c[3532408]|0)==0){at=am;au=an;av=ao;aw=ap;ax=aq}else{as=ap+aq+ao+an+am|0;if(as>>>0<((c[3532410]|0)+as|0)>>>0){ay=as;az=0}else{at=am;au=an;av=ao;aw=ap;ax=aq;break}while(1){if((R6((c[3532372]|0)+(az+7)|0,ay,8)|0)!=0){M=1;J=22640;break}as=ay+1|0;if((R6((c[3532372]|0)+(az+6)|0,as,8)|0)!=0){M=1;J=22629;break}ar=ay+2|0;if((R6((c[3532372]|0)+(az+5)|0,ar,8)|0)!=0){M=1;J=22630;break}ad=ay+3|0;if((R6((c[3532372]|0)+(az+4)|0,ad,8)|0)!=0){M=1;J=22631;break}ai=ay+4|0;if((R6((c[3532372]|0)+(az+3)|0,ai,8)|0)!=0){M=1;J=22641;break}ah=ay+5|0;if((R6((c[3532372]|0)+(az+2)|0,ah,8)|0)!=0){M=1;J=22642;break}ag=ay+6|0;if((R6((c[3532372]|0)+(az+1)|0,ag,8)|0)!=0){M=1;J=22643;break}af=ay+7|0;if((R6((c[3532372]|0)+az|0,af,8)|0)!=0){M=1;J=22644;break}gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](G,ay)|0;aj=(c[I>>2]|0)+az|0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](G,as)|0;as=aj+(c[I>>2]|0)|0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](G,ar)|0;ar=as+(c[I>>2]|0)|0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](G,ad)|0;ad=ar+(c[I>>2]|0)|0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](G,ai)|0;ai=ad+(c[I>>2]|0)|0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](G,ah)|0;ah=ai+(c[I>>2]|0)|0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](G,ag)|0;ag=ah+(c[I>>2]|0)|0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](G,af)|0;af=ay+8|0;ah=c[3532432]|0;ai=c[3532442]|0;ad=c[3532436]|0;ar=c[3532354]|0;as=c[3532382]|0;if(af>>>0<(ai+ah+ad+ar+as+(c[3532410]|0)|0)>>>0){ay=af;az=ag+(c[I>>2]|0)|0}else{at=ah;au=ai;av=ad;aw=ar;ax=as;break L29498}}if((J|0)==22629){i=e;return M|0}else if((J|0)==22630){i=e;return M|0}else if((J|0)==22631){i=e;return M|0}else if((J|0)==22640){i=e;return M|0}else if((J|0)==22641){i=e;return M|0}else if((J|0)==22642){i=e;return M|0}else if((J|0)==22643){i=e;return M|0}else if((J|0)==22644){i=e;return M|0}}}while(0);az=c[3532450]|0;if((az|0)==0){aA=at;aB=au;aC=av;aD=aw;aE=ax}else{ax=0;while(1){if((ax|0)>=1024){aF=0;break}aG=9638528+(ax<<2)|0;if((c[aG>>2]|0)==0){J=22507;break}else{ax=ax+1|0}}do{if((J|0)==22507){ax=gGq(az)|0;c[aG>>2]=ax;if((ax|0)==0){aF=0;break}gGz(ax|0,0,az|0);aF=ax}}while(0);c[3532370]=aF;az=c[3532432]|0;aG=c[3532442]|0;ax=c[3532436]|0;aw=c[3532354]|0;av=c[3532382]|0;au=aG+az+ax+aw+av+(c[3532410]|0)|0;L29528:do{if(au>>>0<(au+(c[3532452]|0)|0)>>>0){if((c[3542200]|0)==0){M=1;i=e;return M|0}at=A+108|0;ay=A+100|0;aq=0;ap=au;ao=aF;while(1){c[at>>2]=0;c[ay>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](A,ap)|0;if((c[at>>2]|0)!=0){an=c[ay>>2]|0;c[B>>2]=9534384;am=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[am&16383](B,ap,0)|0;if((an|0)<1){M=1;J=22658;break}if((gzL(ao,0,ap)|0)!=0){M=1;J=22659;break}}gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](G,ap)|0;an=ap+1|0;am=c[3532432]|0;as=c[3532442]|0;ar=c[3532436]|0;ad=c[3532354]|0;ai=c[3532382]|0;if(an>>>0>=(as+am+ar+ad+ai+(c[3532410]|0)+(c[3532452]|0)|0)>>>0){aH=am;aI=as;aJ=ar;aK=ad;aL=ai;break L29528}ai=(c[I>>2]|0)+aq|0;if((c[3542200]|0)==0){M=1;J=22660;break}aq=ai;ap=an;ao=(c[3532370]|0)+ai|0}if((J|0)==22658){i=e;return M|0}else if((J|0)==22659){i=e;return M|0}else if((J|0)==22660){i=e;return M|0}}else{aH=az;aI=aG;aJ=ax;aK=aw;aL=av}}while(0);av=(c[642608+(c[2436]<<2)>>2]|0)+60|0;aw=c[av>>2]|0;ax=aw&-65536;if((ax|0)==34078720|(ax|0)==33619968){ax=c[3532370]|0;aG=c[3532450]|0;az=c[3532448]|0;B=0;do{A=((B<<6&16320|B>>8<<15)>>>0)%(aG>>>0)|0;aF=B<<9;au=A+16384|0;ao=0;do{ap=(ao|0)/8|0;aq=ao&7^7;ay=(d[ax+(au+ap)|0]|0)>>>(aq>>>0)<<1&2|(d[ax+(ap+A)|0]|0)>>>(aq>>>0)&1;a[az+(ao+aF)|0]=(ao-248|0)>>>0<8&(ay|0)==3?7:ay&255;ao=ao+1|0;}while((ao|0)<512);B=B+1|0;}while((B|0)<512);gGz(az+262144|0,3,512);aM=c[av>>2]|0}else{aM=aw}aw=c[3532370]|0;if((aM&-65536|0)==34013184){aM=c[3532450]|0;av=c[3532448]|0;az=0;while(1){B=(az<<6>>>0)%(aM>>>0)|0;ax=az<<9;aG=B|16384;ao=0;do{aF=(ao|0)/8|0;A=ao&7^7;a[av+(ao+ax)|0]=((d[aw+(aF+aG)|0]|0)>>>(A>>>0)<<1&2|(d[aw+(aF+B)|0]|0)>>>(A>>>0)&1)&255;ao=ao+1|0;}while((ao|0)<512);ao=az+1|0;if((ao|0)<256){az=ao}else{aN=aw;break}}}else{aN=aw}aw=0;while(1){if((aw|0)>=1024){aO=aH;aP=aI;aQ=aJ;aR=aK;aS=aL;break}aT=9638528+(aw<<2)|0;if((c[aT>>2]|0)==(aN|0)){J=22532;break}else{aw=aw+1|0}}if((J|0)==22532){gGr(aN);c[aT>>2]=0;aO=c[3532432]|0;aP=c[3532442]|0;aQ=c[3532436]|0;aR=c[3532354]|0;aS=c[3532382]|0}c[3532370]=0;aA=aO;aB=aP;aC=aQ;aD=aR;aE=aS}aS=c[3532472]|0;aR=c[3532410]|0;aQ=c[3532452]|0;aP=aD+aE+aC+aB+aA+aR+aQ|0;aO=c[3532310]|0;aT=aR+aQ+aE+aD+aC+aB+aA+aO|0;if(aP>>>0<aT>>>0){aN=y+108|0;aw=y+100|0;aL=aP;aP=(aS|0)==0?0:65536;while(1){aK=(c[3532330]|0)+aP|0;do{if((c[3542200]|0)==0){J=22540}else{c[aN>>2]=0;c[aw>>2]=0;aJ=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aJ&16383](y,aL)|0;if((c[aN>>2]|0)==0){break}aJ=c[aw>>2]|0;c[z>>2]=9534384;aI=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aI&16383](z,aL,0)|0;if((aJ|0)<1){J=22540;break}if((gzL(aK,0,aL)|0)!=0){J=22540}}}while(0);if((J|0)==22540){J=0;gGz(c[3532330]|0,-1|0,c[3532308]|0)}gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](G,aL)|0;aK=c[3532472]|0;if((aK|0)==0){aU=(c[I>>2]|0)+aP|0}else{aU=aP+524288|0}aJ=aL+1|0;aI=c[3532432]|0;aH=c[3532442]|0;az=c[3532436]|0;av=c[3532354]|0;aM=c[3532382]|0;ao=c[3532410]|0;B=c[3532452]|0;aG=c[3532310]|0;ax=ao+B+aM+av+az+aH+aI+aG|0;if(aJ>>>0<ax>>>0){aL=aJ;aP=aU}else{aV=aK;aW=B;aX=ao;aY=aM;aZ=av;a_=az;a$=aH;a0=aI;a1=aG;a2=ax;break}}}else{aV=aS;aW=aQ;aX=aR;aY=aE;aZ=aD;a_=aC;a$=aB;a0=aA;a1=aO;a2=aT}if((aV|0)!=0){aV=c[3532330]|0;aT=aV+65536|0;gGC(aV|0,aT|0,65536)|0;c[3532472]=0}L29589:do{if((c[3532324]|0)==0){a3=a0;a4=a$;a5=a_;a6=aZ;a7=aY;a8=aX;a9=aW;ba=a1}else{if(a2>>>0>=(aW+a1+aX+aY+aZ+a_+a$+a0+(c[3532326]|0)|0)>>>0){a3=a0;a4=a$;a5=a_;a6=aZ;a7=aY;a8=aX;a9=aW;ba=a1;break}aT=w+108|0;aV=w+100|0;aO=a2;aA=0;while(1){aB=(c[3532328]|0)+aA|0;if((c[3542200]|0)==0){M=1;J=22669;break}c[aT>>2]=0;c[aV>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](w,aO)|0;if((c[aT>>2]|0)!=0){aC=c[aV>>2]|0;c[x>>2]=9534384;aD=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aD&16383](x,aO,0)|0;if((aC|0)<1){M=1;J=22648;break}if((gzL(aB,0,aO)|0)!=0){M=1;J=22649;break}}gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](G,aO)|0;aB=aO+1|0;aC=c[3532432]|0;aD=c[3532442]|0;aE=c[3532436]|0;aR=c[3532354]|0;aQ=c[3532382]|0;aS=c[3532410]|0;aU=c[3532452]|0;aP=c[3532310]|0;if(aB>>>0<(aU+aP+aS+aQ+aR+aE+aD+aC+(c[3532326]|0)|0)>>>0){aO=aB;aA=(c[I>>2]|0)+aA|0}else{a3=aC;a4=aD;a5=aE;a6=aR;a7=aQ;a8=aS;a9=aU;ba=aP;break L29589}}if((J|0)==22648){i=e;return M|0}else if((J|0)==22649){i=e;return M|0}else if((J|0)==22669){i=e;return M|0}}}while(0);L29604:do{if((c[3532318]|0)==0){bb=a3;bc=a4;bd=a5;be=a6;bf=a7;bg=a8;bh=a9;bi=ba}else{x=c[3532326]|0;w=a9+ba+a8+a7+a6+a5+a4+a3+x|0;if(w>>>0>=(ba+x+a9+a8+a7+a6+a5+a4+a3+(c[3532320]|0)|0)>>>0){bb=a3;bc=a4;bd=a5;be=a6;bf=a7;bg=a8;bh=a9;bi=ba;break}x=u+108|0;a2=u+100|0;a1=w;w=0;while(1){aW=(c[3532322]|0)+w|0;if((c[3542200]|0)==0){M=1;J=22650;break}c[x>>2]=0;c[a2>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](u,a1)|0;if((c[x>>2]|0)!=0){aX=c[a2>>2]|0;c[v>>2]=9534384;aY=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aY&16383](v,a1,0)|0;if((aX|0)<1){M=1;J=22651;break}if((gzL(aW,0,a1)|0)!=0){M=1;J=22652;break}}gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](G,a1)|0;aW=a1+1|0;aX=c[3532432]|0;aY=c[3532442]|0;aZ=c[3532436]|0;a_=c[3532354]|0;a$=c[3532382]|0;a0=c[3532410]|0;aA=c[3532452]|0;aO=c[3532310]|0;if(aW>>>0<(aO+(c[3532326]|0)+aA+a0+a$+a_+aZ+aY+aX+(c[3532320]|0)|0)>>>0){a1=aW;w=(c[I>>2]|0)+w|0}else{bb=aX;bc=aY;bd=aZ;be=a_;bf=a$;bg=a0;bh=aA;bi=aO;break L29604}}if((J|0)==22650){i=e;return M|0}else if((J|0)==22651){i=e;return M|0}else if((J|0)==22652){i=e;return M|0}}}while(0);L29619:do{if((c[3532312]|0)==0){bj=bb;bk=bc;bl=bd;bm=be;bn=bf;bo=bg;bp=bh;bq=bi}else{v=c[3532326]|0;u=c[3532320]|0;ba=bh+bi+bg+bf+be+bd+bc+bb+v+u|0;if(ba>>>0>=(v+u+bi+bh+bg+bf+be+bd+bc+bb+(c[3532314]|0)|0)>>>0){bj=bb;bk=bc;bl=bd;bm=be;bn=bf;bo=bg;bp=bh;bq=bi;break}u=s+108|0;v=s+100|0;a9=ba;ba=0;while(1){a8=(c[3532316]|0)+ba|0;if((c[3542200]|0)==0){M=1;J=22653;break}c[u>>2]=0;c[v>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](s,a9)|0;if((c[u>>2]|0)!=0){a7=c[v>>2]|0;c[t>>2]=9534384;a6=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[a6&16383](t,a9,0)|0;if((a7|0)<1){M=1;J=22654;break}if((gzL(a8,0,a9)|0)!=0){M=1;J=22661;break}}gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](G,a9)|0;a8=a9+1|0;a7=c[3532432]|0;a6=c[3532442]|0;a5=c[3532436]|0;a4=c[3532354]|0;a3=c[3532382]|0;w=c[3532410]|0;a1=c[3532452]|0;a2=c[3532310]|0;if(a8>>>0<((c[3532326]|0)+(c[3532320]|0)+a2+a1+w+a3+a4+a5+a6+a7+(c[3532314]|0)|0)>>>0){a9=a8;ba=(c[I>>2]|0)+ba|0}else{bj=a7;bk=a6;bl=a5;bm=a4;bn=a3;bo=w;bp=a1;bq=a2;break L29619}}if((J|0)==22653){i=e;return M|0}else if((J|0)==22654){i=e;return M|0}else if((J|0)==22661){i=e;return M|0}}}while(0);L29634:do{if((c[3532574]|0)==0){br=bj;bs=bk;bt=bl;bu=bm;bv=bn;bw=bo;bx=bp;by=bq}else{t=c[3532326]|0;s=c[3532320]|0;bi=c[3532314]|0;bh=bp+bq+bo+bn+bm+bl+bk+bj+t+s+bi|0;if(bh>>>0>=(s+bi+t+bq+bp+bo+bn+bm+bl+bk+bj+(c[3532576]|0)|0)>>>0){br=bj;bs=bk;bt=bl;bu=bm;bv=bn;bw=bo;bx=bp;by=bq;break}t=q+108|0;bi=q+100|0;s=bh;bh=0;while(1){bg=(c[3532578]|0)+bh|0;if((c[3542200]|0)==0){M=1;J=22662;break}c[t>>2]=0;c[bi>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](q,s)|0;if((c[t>>2]|0)!=0){bf=c[bi>>2]|0;c[r>>2]=9534384;be=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[be&16383](r,s,0)|0;if((bf|0)<1){M=1;J=22663;break}if((gzL(bg,0,s)|0)!=0){M=1;J=22664;break}}gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](G,s)|0;bg=s+1|0;bf=c[3532432]|0;be=c[3532442]|0;bd=c[3532436]|0;bc=c[3532354]|0;bb=c[3532382]|0;ba=c[3532410]|0;a9=c[3532452]|0;v=c[3532310]|0;if(bg>>>0<((c[3532320]|0)+(c[3532314]|0)+(c[3532326]|0)+v+a9+ba+bb+bc+bd+be+bf+(c[3532576]|0)|0)>>>0){s=bg;bh=(c[I>>2]|0)+bh|0}else{br=bf;bs=be;bt=bd;bu=bc;bv=bb;bw=ba;bx=a9;by=v;break L29634}}if((J|0)==22662){i=e;return M|0}else if((J|0)==22663){i=e;return M|0}else if((J|0)==22664){i=e;return M|0}}}while(0);L29649:do{if((c[3532580]|0)==0){bz=br;bA=bs;bB=bt;bC=bu;bD=bv;bE=bw;bF=bx;bG=by}else{r=c[3532326]|0;q=c[3532320]|0;bq=c[3532314]|0;bp=c[3532576]|0;bo=bx+by+bw+bv+bu+bt+bs+br+r+q+bq+bp|0;if(bo>>>0>=(bq+bp+q+r+by+bx+bw+bv+bu+bt+bs+br+(c[3532582]|0)|0)>>>0){bz=br;bA=bs;bB=bt;bC=bu;bD=bv;bE=bw;bF=bx;bG=by;break}r=o+108|0;q=o+100|0;bp=bo;bo=0;while(1){bq=(c[3532584]|0)+bo|0;if((c[3542200]|0)==0){M=1;J=22665;break}c[r>>2]=0;c[q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](o,bp)|0;if((c[r>>2]|0)!=0){bn=c[q>>2]|0;c[p>>2]=9534384;bm=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[bm&16383](p,bp,0)|0;if((bn|0)<1){M=1;J=22666;break}if((gzL(bq,0,bp)|0)!=0){M=1;J=22671;break}}gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](G,bp)|0;bq=bp+1|0;bn=c[3532432]|0;bm=c[3532442]|0;bl=c[3532436]|0;bk=c[3532354]|0;bj=c[3532382]|0;bh=c[3532410]|0;s=c[3532452]|0;bi=c[3532310]|0;if(bq>>>0<((c[3532314]|0)+(c[3532576]|0)+(c[3532320]|0)+(c[3532326]|0)+bi+s+bh+bj+bk+bl+bm+bn+(c[3532582]|0)|0)>>>0){bp=bq;bo=(c[I>>2]|0)+bo|0}else{bz=bn;bA=bm;bB=bl;bC=bk;bD=bj;bE=bh;bF=s;bG=bi;break L29649}}if((J|0)==22665){i=e;return M|0}else if((J|0)==22666){i=e;return M|0}else if((J|0)==22671){i=e;return M|0}}}while(0);do{if((c[3532344]|0)==0){bH=bz;bI=bA;bJ=bB;bK=bC;bL=bD;bM=bE;bN=bF;bO=bG}else{p=c[3532326]|0;o=c[3532320]|0;by=c[3532314]|0;bx=c[3532576]|0;bw=c[3532582]|0;bv=bF+bG+bE+bD+bC+bB+bA+bz+p+o+by+bx+bw|0;if(bv>>>0>=(bx+bw+by+o+p+bG+bF+bE+bD+bC+bB+bA+bz+(c[3532346]|0)|0)>>>0){bH=bz;bI=bA;bJ=bB;bK=bC;bL=bD;bM=bE;bN=bF;bO=bG;break}p=m+108|0;o=m+100|0;by=bv;bv=0;while(1){bw=(c[3532348]|0)+bv|0;do{if((c[3542200]|0)==0){J=22594}else{c[p>>2]=0;c[o>>2]=0;bx=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[bx&16383](m,by)|0;if((c[p>>2]|0)==0){break}bx=c[o>>2]|0;c[n>>2]=9534384;bu=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[bu&16383](n,by,0)|0;if((bx|0)<1){J=22594;break}if((gzL(bw,0,by)|0)!=0){J=22594}}}while(0);if((J|0)==22594){J=0;gGz(c[3532348]|0,-1|0,c[3532344]|0)}gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](G,by)|0;bw=c[I>>2]|0;bx=by+1|0;bu=c[3532432]|0;bt=c[3532442]|0;bs=c[3532436]|0;br=c[3532354]|0;bo=c[3532382]|0;bp=c[3532410]|0;q=c[3532452]|0;r=c[3532310]|0;if(bx>>>0<((c[3532576]|0)+(c[3532582]|0)+(c[3532314]|0)+(c[3532320]|0)+(c[3532326]|0)+r+q+bp+bo+br+bs+bt+bu+(c[3532346]|0)|0)>>>0){by=bx;bv=(bw>>>0<65536?65536:bw)+bv|0}else{bH=bu;bI=bt;bJ=bs;bK=br;bL=bo;bM=bp;bN=q;bO=r;break}}}}while(0);L29677:do{if((c[3532496]|0)==0){bP=bH;bQ=bI;bR=bJ;bS=bK;bT=bL;bU=bM;bV=bN;bW=bO}else{n=c[3532326]|0;m=c[3532320]|0;bG=c[3532314]|0;bF=c[3532576]|0;bE=c[3532582]|0;bD=c[3532346]|0;bC=k+108|0;bB=k+100|0;bA=0;bz=bN+bO+bM+bL+bK+bJ+bI+bH+n+m+bG+bF+bE+bD|0;bv=bH;by=bI;o=bJ;p=bK;r=bL;q=bM;bp=bN;bo=bO;br=n;n=m;m=bG;bG=bF;bF=bE;bE=bD;while(1){if(bz>>>0>=(bF+bE+bG+m+n+br+bo+bp+q+r+p+o+by+bv+(c[3532498]|0)|0)>>>0){bP=bv;bQ=by;bR=o;bS=p;bT=r;bU=q;bV=bp;bW=bo;break L29677}bD=(c[3532500]|0)+bA|0;if((c[3542200]|0)==0){M=1;J=22672;break}c[bC>>2]=0;c[bB>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,bz)|0;if((c[bC>>2]|0)!=0){bs=c[bB>>2]|0;c[l>>2]=9534384;bt=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[bt&16383](l,bz,0)|0;if((bs|0)<1){M=1;J=22673;break}if((gzL(bD,0,bz)|0)!=0){M=1;J=22674;break}}gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](G,bz)|0;bA=(c[I>>2]|0)+bA|0;bz=bz+1|0;bv=c[3532432]|0;by=c[3532442]|0;o=c[3532436]|0;p=c[3532354]|0;r=c[3532382]|0;q=c[3532410]|0;bp=c[3532452]|0;bo=c[3532310]|0;br=c[3532326]|0;n=c[3532320]|0;m=c[3532314]|0;bG=c[3532576]|0;bF=c[3532582]|0;bE=c[3532346]|0}if((J|0)==22672){i=e;return M|0}else if((J|0)==22673){i=e;return M|0}else if((J|0)==22674){i=e;return M|0}}}while(0);L29692:do{if((c[3532502]|0)==0){bX=bP;bY=bQ;bZ=bR;b_=bS;b$=bT;b0=bU;b1=bV;b2=bW}else{l=c[3532326]|0;k=c[3532320]|0;bO=c[3532314]|0;bN=c[3532576]|0;bM=c[3532582]|0;bL=c[3532346]|0;bK=c[3532498]|0;bJ=h+108|0;bI=h+100|0;bH=0;bE=bV+bW+bU+bT+bS+bR+bQ+bP+l+k+bO+bN+bM+bL+bK|0;bF=bP;bG=bQ;m=bR;n=bS;br=bT;bo=bU;bp=bV;q=bW;r=l;l=k;k=bO;bO=bN;bN=bM;bM=bL;bL=bK;while(1){if(bE>>>0>=(bM+bL+bN+bO+k+l+r+q+bp+bo+br+n+m+bG+bF+(c[3532504]|0)|0)>>>0){bX=bF;bY=bG;bZ=m;b_=n;b$=br;b0=bo;b1=bp;b2=q;break L29692}bK=(c[3532506]|0)+bH|0;if((c[3542200]|0)==0){M=1;J=22675;break}c[bJ>>2]=0;c[bI>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](h,bE)|0;if((c[bJ>>2]|0)!=0){p=c[bI>>2]|0;c[j>>2]=9534384;o=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[o&16383](j,bE,0)|0;if((p|0)<1){M=1;J=22676;break}if((gzL(bK,0,bE)|0)!=0){M=1;J=22677;break}}gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](G,bE)|0;bH=(c[I>>2]|0)+bH|0;bE=bE+1|0;bF=c[3532432]|0;bG=c[3532442]|0;m=c[3532436]|0;n=c[3532354]|0;br=c[3532382]|0;bo=c[3532410]|0;bp=c[3532452]|0;q=c[3532310]|0;r=c[3532326]|0;l=c[3532320]|0;k=c[3532314]|0;bO=c[3532576]|0;bN=c[3532582]|0;bM=c[3532346]|0;bL=c[3532498]|0}if((J|0)==22675){i=e;return M|0}else if((J|0)==22676){i=e;return M|0}else if((J|0)==22677){i=e;return M|0}}}while(0);L29707:do{if((c[3532476]|0)==0){b3=bX;b4=bY;b5=bZ;b6=b_;b7=b$;b8=b0;b9=b1;ca=b2}else{j=c[3532326]|0;h=c[3532320]|0;bW=c[3532314]|0;bV=c[3532576]|0;bU=c[3532582]|0;bT=c[3532346]|0;bS=c[3532498]|0;bR=c[3532504]|0;bQ=c[3532472]|0;bP=f+108|0;bL=f+100|0;bM=0;bN=b1+b2+b0+b$+b_+bZ+bY+bX+j+h+bW+bV+bU+bT+bS+bR+bQ|0;bO=bX;k=bY;l=bZ;r=b_;q=b$;bp=b0;bo=b1;br=b2;n=j;j=h;h=bW;bW=bV;bV=bU;bU=bT;bT=bS;bS=bR;bR=bQ;while(1){if(bN>>>0>=(bS+bR+bT+bU+bV+bW+h+j+n+br+bo+bp+q+r+l+k+bO+(c[3532478]|0)|0)>>>0){b3=bO;b4=k;b5=l;b6=r;b7=q;b8=bp;b9=bo;ca=br;break L29707}bQ=(c[3532480]|0)+bM|0;if((c[3542200]|0)==0){M=1;J=22678;break}c[bP>>2]=0;c[bL>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,bN)|0;if((c[bP>>2]|0)!=0){m=c[bL>>2]|0;c[g>>2]=9534384;bG=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[bG&16383](g,bN,0)|0;if((m|0)<1){M=1;J=22679;break}if((gzL(bQ,0,bN)|0)!=0){M=1;J=22680;break}}gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](G,bN)|0;bM=(c[I>>2]|0)+bM|0;bN=bN+1|0;bO=c[3532432]|0;k=c[3532442]|0;l=c[3532436]|0;r=c[3532354]|0;q=c[3532382]|0;bp=c[3532410]|0;bo=c[3532452]|0;br=c[3532310]|0;n=c[3532326]|0;j=c[3532320]|0;h=c[3532314]|0;bW=c[3532576]|0;bV=c[3532582]|0;bU=c[3532346]|0;bT=c[3532498]|0;bS=c[3532504]|0;bR=c[3532472]|0}if((J|0)==22678){i=e;return M|0}else if((J|0)==22679){i=e;return M|0}else if((J|0)==22680){i=e;return M|0}}}while(0);if((c[3532516]|0)==0){M=0;i=e;return M|0}J=b9+ca+b8+b7+b6+b5+b4+b3+(c[3532326]|0)+(c[3532320]|0)+(c[3532314]|0)+(c[3532576]|0)+(c[3532582]|0)+(c[3532346]|0)+(c[3532498]|0)+(c[3532504]|0)+(c[3532472]|0)+(c[3532478]|0)|0;b3=c[3532518]|0;if((c[3542200]|0)==0){M=1;i=e;return M|0}b4=C+108|0;c[b4>>2]=0;b5=C+100|0;c[b5>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](C,J)|0;do{if((c[b4>>2]|0)!=0){C=c[b5>>2]|0;c[D>>2]=9534384;b6=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[b6&16383](D,J,0)|0;if((C|0)<1){M=1;i=e;return M|0}if((gzL(b3,0,J)|0)==0){break}else{M=1}i=e;return M|0}}while(0);M=0;i=e;return M|0}function eOu(){var a=0,b=0,d=0,e=0,f=0,g=0;a=0;while(1){if((a|0)>=1024){b=1;d=22697;break}e=9638528+(a<<2)|0;if((c[e>>2]|0)==0){break}else{a=a+1|0}}if((d|0)==22697){return b|0}a=gGq(786432)|0;c[e>>2]=a;if((a|0)==0){b=1;return b|0}gGz(a|0,0,786432);e=c[3532446]|0;gGC(a|0,e|0,786432)|0;gGz(e|0,0,786432);gGC(e|0,a|0,131072)|0;f=e+524288|0;e=a+131072|0;gGC(f|0,e|0,262144)|0;e=0;while(1){if((e|0)>=1024){b=0;d=22698;break}g=9638528+(e<<2)|0;if((c[g>>2]|0)==(a|0)){break}else{e=e+1|0}}if((d|0)==22698){return b|0}gGr(a);c[g>>2]=0;b=0;return b|0}function eOv(){var a=0,b=0,d=0,e=0,f=0,g=0;a=0;while(1){if((a|0)>=1024){b=1;d=22711;break}e=9638528+(a<<2)|0;if((c[e>>2]|0)==0){break}else{a=a+1|0}}if((d|0)==22711){return b|0}a=gGq(786432)|0;c[e>>2]=a;if((a|0)==0){b=1;return b|0}gGz(a|0,0,786432);e=c[3532446]|0;gGC(a|0,e|0,786432)|0;gGz(e|0,0,786432);gGC(e|0,a|0,262144)|0;f=e+524288|0;e=a+262144|0;gGC(f|0,e|0,262144)|0;e=0;while(1){if((e|0)>=1024){b=0;d=22710;break}g=9638528+(e<<2)|0;if((c[g>>2]|0)==(a|0)){break}else{e=e+1|0}}if((d|0)==22710){return b|0}gGr(a);c[g>>2]=0;b=0;return b|0}function eOw(c,d,f){c=c|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;switch(d&15|0){case 0:{b[9757208+(c*36|0)>>1]=f;d=f<<16>>16;g=b[9757210+(c*36|0)>>1]|0;h=b[9757212+(c*36|0)>>1]|0;i=h<<16>>16;j=(d|0)<(g|0)?d:g;k=(d|0)>(g|0)?d:g;if((i|0)<(j|0)){b[9757222+(c*36|0)>>1]=j&65535;b[9757214+(c*36|0)>>1]=-32768;return}if((i|0)>(k|0)){b[9757222+(c*36|0)>>1]=k&65535;b[9757214+(c*36|0)>>1]=16384;return}else{b[9757222+(c*36|0)>>1]=h;b[9757214+(c*36|0)>>1]=0;return}break};case 1:{b[9757210+(c*36|0)>>1]=f;h=b[9757208+(c*36|0)>>1]|0;k=f<<16>>16;i=b[9757212+(c*36|0)>>1]|0;j=i<<16>>16;g=(h|0)<(k|0)?h:k;d=(h|0)>(k|0)?h:k;if((j|0)<(g|0)){b[9757222+(c*36|0)>>1]=g&65535;b[9757214+(c*36|0)>>1]=-32768;return}if((j|0)>(d|0)){b[9757222+(c*36|0)>>1]=d&65535;b[9757214+(c*36|0)>>1]=16384;return}else{b[9757222+(c*36|0)>>1]=i;b[9757214+(c*36|0)>>1]=0;return}break};case 6:{b[9757212+(c*36|0)>>1]=f;i=b[9757208+(c*36|0)>>1]|0;d=b[9757210+(c*36|0)>>1]|0;j=f<<16>>16;g=(i|0)<(d|0)?i:d;k=(i|0)>(d|0)?i:d;if((j|0)<(g|0)){b[9757222+(c*36|0)>>1]=g&65535;b[9757214+(c*36|0)>>1]=-32768;return}if((j|0)>(k|0)){b[9757222+(c*36|0)>>1]=k&65535;b[9757214+(c*36|0)>>1]=16384;return}else{b[9757222+(c*36|0)>>1]=f;b[9757214+(c*36|0)>>1]=0;return}break};case 11:case 15:{b[9757230+(c*36|0)>>1]=f;return};case 4:{b[9757216+(c*36|0)>>1]=0;a[9757242+(c*36|0)|0]=0;return};case 10:case 14:{b[9757228+(c*36|0)>>1]=f;return};case 8:case 12:{b[9757224+(c*36|0)>>1]=f;return};case 2:{b[9757212+(c*36|0)>>1]=f;k=b[9757208+(c*36|0)>>1]|0;j=b[9757210+(c*36|0)>>1]|0;g=f<<16>>16;d=(k|0)<(j|0)?k:j;i=(k|0)>(j|0)?k:j;do{if((g|0)<(d|0)){b[9757222+(c*36|0)>>1]=d&65535;b[9757214+(c*36|0)>>1]=-32768;l=0}else{if((g|0)>(i|0)){b[9757222+(c*36|0)>>1]=i&65535;b[9757214+(c*36|0)>>1]=16384;l=0;break}else{b[9757222+(c*36|0)>>1]=f;b[9757214+(c*36|0)>>1]=0;l=1;break}}}while(0);f=9757242+(c*36|0)|0;i=a[f]|0;a[f]=i+1&255;f=9757216+(c*36|0)|0;b[f>>1]=(e[f>>1]|l<<(i&255))&65535;return};default:{return}}}function eOx(){var e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0;c[3541162]=0;eOt(0)|0;eOy();e=c[3541160]|0;f=0;while(1){if((f|0)>=1024){break}g=9638528+(f<<2)|0;if((c[g>>2]|0)==0){i=22757;break}else{f=f+1|0}}do{if((i|0)==22757){f=gGq(e)|0;c[g>>2]=f;if((f|0)==0){break}gGz(f|0,0,e|0);c[3541162]=f;gGz(f|0,0,e|0);eOy();do{if((c[(c[642608+(c[2436]<<2)>>2]|0)+60>>2]&32768|0)==0){if((eOt(1)|0)==0){break}else{j=1}return j|0}}while(0);f=c[3532546]|0;do{if((f|0)!=0){if((gD[f&8191]()|0)==0){break}else{j=1}return j|0}}while(0);f=c[3532552]|0;k=c[3532446]|0;l=c[3532430]|0;gGC(f|0,k|0,l)|0;if((c[3532548]|0)!=0){l=k+196608|0;gGC(f|0,l|0,65536)|0;l=f+65536|0;m=k+65536|0;gGC(l|0,m|0,131072)|0}m=c[2436]|0;l=(c[642608+(m<<2)>>2]|0)+60|0;n=c[l>>2]|0;if((n&3|0)==0){o=n}else{n=c[3532518]|0;p=k;k=f;f=0;do{q=(f|0)/2|0;r=p+(q<<1)|0;s=b[r>>1]|0;b[k+(q<<1)>>1]=eFa(f,s,n,1)|0;b[r>>1]=eFa(f,s,n,0)|0;f=f+2|0;}while((f|0)<1048576);o=c[l>>2]|0}do{if((o&8256|0)==0){t=o;u=m}else{if((o&64|0)==0){v=o;w=m}else{eNQ(0);f=c[2436]|0;v=c[(c[642608+(f<<2)>>2]|0)+60>>2]|0;w=f}if((v&8192|0)==0){t=v;u=w;break}eNQ(1);f=c[2436]|0;t=c[(c[642608+(f<<2)>>2]|0)+60>>2]|0;u=f}}while(0);if((t&8|0)==0){x=t}else{m=c[3532330]|0;l=c[3532336]|0;f=c[3532518]|0;n=0;do{k=m+n|0;p=a[k]|0;a[l+n|0]=eN6(n,p,f,1)|0;a[k]=eN6(n,p,f,0)|0;n=n+1|0;}while((n|0)<32768);x=c[(c[642608+(u<<2)>>2]|0)+60>>2]|0}if((x&-65536|0)==33751040){n=c[3532512]|0;if((n|0)==0){fxU(0,425984);if((c[2394]|0)==0){y=c[2112932]|0}else{c[2394]=0;f=c[3532596]|0;c[2112932]=f;l=c[3532592]|0;if((l|0)!=0){gGC(9104152,l|0,280)|0}c[2113054]=c[2113060];y=f}f=c[3532446]|0;l=y|0;m=l;p=0;while(1){c[m>>2]=f+p;k=p+1024|0;if(k>>>0>1048575){break}else{m=m+4|0;p=k}}p=c[3532552]|0;m=l;f=0;while(1){c[m+131072>>2]=p+f;k=f+1024|0;if(k>>>0>1048575){break}else{m=m+4|0;f=k}}f=c[3532356]|0;m=y+16384|0;p=4194304;while(1){c[m>>2]=f+(p-4194304);l=p+1024|0;if(l>>>0>4259839){break}else{m=m+4|0;p=l}}p=c[3532368]|0;c[y+16640>>2]=p;c[y+82176>>2]=p;c[y+147712>>2]=p;m=p+1024|0;c[y+16644>>2]=m;c[y+82180>>2]=m;c[y+147716>>2]=m;m=p+2048|0;c[y+16648>>2]=m;c[y+82184>>2]=m;c[y+147720>>2]=m;m=p+3072|0;c[y+16652>>2]=m;c[y+82188>>2]=m;c[y+147724>>2]=m;m=c[3532390]|0;c[y+17408>>2]=m;c[y+82944>>2]=m;c[y+148480>>2]=m;p=m+1024|0;c[y+17412>>2]=p;c[y+82948>>2]=p;c[y+148484>>2]=p;p=c[3532484]|0;c[y+33792>>2]=p;c[y+99328>>2]=p;c[y+164864>>2]=p;m=p+1024|0;c[y+33796>>2]=m;c[y+99332>>2]=m;c[y+164868>>2]=m;m=p+2048|0;c[y+33800>>2]=m;c[y+99336>>2]=m;c[y+164872>>2]=m;m=p+3072|0;c[y+33804>>2]=m;c[y+99340>>2]=m;c[y+164876>>2]=m;m=c[3532470]|0;c[y+65472>>2]=m;c[y+131008>>2]=m;c[y+196544>>2]=m;p=m+1024|0;c[y+65476>>2]=p;c[y+131012>>2]=p;c[y+196548>>2]=p;p=m+2048|0;c[y+65480>>2]=p;c[y+131016>>2]=p;c[y+196552>>2]=p;p=m+3072|0;c[y+65484>>2]=p;c[y+131020>>2]=p;c[y+196556>>2]=p;p=m+4096|0;c[y+65488>>2]=p;c[y+131024>>2]=p;c[y+196560>>2]=p;p=m+5120|0;c[y+65492>>2]=p;c[y+131028>>2]=p;c[y+196564>>2]=p;p=m+6144|0;c[y+65496>>2]=p;c[y+131032>>2]=p;c[y+196568>>2]=p;p=m+7168|0;c[y+65500>>2]=p;c[y+131036>>2]=p;c[y+196572>>2]=p;p=m+8192|0;c[y+65504>>2]=p;c[y+131040>>2]=p;c[y+196576>>2]=p;p=m+9216|0;c[y+65508>>2]=p;c[y+131044>>2]=p;c[y+196580>>2]=p;p=m+10240|0;c[y+65512>>2]=p;c[y+131048>>2]=p;c[y+196584>>2]=p;p=m+11264|0;c[y+65516>>2]=p;c[y+131052>>2]=p;c[y+196588>>2]=p;p=m+12288|0;c[y+65520>>2]=p;c[y+131056>>2]=p;c[y+196592>>2]=p;p=m+13312|0;c[y+65524>>2]=p;c[y+131060>>2]=p;c[y+196596>>2]=p;p=m+14336|0;c[y+65528>>2]=p;c[y+131064>>2]=p;c[y+196600>>2]=p;p=m+15360|0;c[y+65532>>2]=p;c[y+131068>>2]=p;c[y+196604>>2]=p;c[y+196688>>2]=3288;c[y+196728>>2]=1194;c[y+196608>>2]=714;c[y+196648>>2]=1190;p=c[3532592]|0;if((p|0)!=0){gGC(p|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1}else{gu[n&16383]()}p=(c[3532510]|0)==0;fwR(0);m=c[2439330]|0;f=(m|0)==0;if(!f){l=m;gGC(9706056,l|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];l=c[3528484]|0;c[2076596]=l;k=c[2417276]|0;c[3541536]=k;c[1836236]=0;if(p){p=c[3532330]|0;s=0;r=0;while(1){c[m+76+(r<<2)>>2]=p+(r<<8);q=s+1&65535;if((q&65535)>223){z=0;A=0;break}else{s=q;r=q&65535}}while(1){r=p+(A<<8)|0;c[m+76+(A+512<<2)>>2]=r;c[m+76+(A+768<<2)>>2]=r;r=z+1&65535;if((r&65535)>223){break}else{z=r;A=r&65535}}p=c[3532334]|0;c[m+1068>>2]=p;r=p+256|0;c[m+1072>>2]=r;s=p+512|0;c[m+1076>>2]=s;n=p+768|0;c[m+1080>>2]=n;q=p+1024|0;c[m+1084>>2]=q;B=p+1280|0;c[m+1088>>2]=B;C=p+1536|0;c[m+1092>>2]=C;D=p+1792|0;c[m+1096>>2]=D;c[m+2092>>2]=p;c[m+2096>>2]=r;c[m+2100>>2]=s;c[m+2104>>2]=n;c[m+2108>>2]=q;c[m+2112>>2]=B;c[m+2116>>2]=C;c[m+2120>>2]=D;c[m+3116>>2]=p;c[m+4140>>2]=p;c[m+3120>>2]=r;c[m+4144>>2]=r;c[m+3124>>2]=s;c[m+4148>>2]=s;c[m+3128>>2]=n;c[m+4152>>2]=n;c[m+3132>>2]=q;c[m+4156>>2]=q;c[m+3136>>2]=B;c[m+4160>>2]=B;c[m+3140>>2]=C;c[m+4164>>2]=C;c[m+3144>>2]=D;c[m+4168>>2]=D;c[m+4172>>2]=1872;c[m+4176>>2]=456;if(!f){D=m;gGC(D|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=l;c[2417276]=k}else{gu[c[3532510]&16383]();D=c[1836236]|0;C=c[9757320+(D<<2)>>2]|0;if((C|0)!=0){B=C;gGC(B|0,9706056,76)|0}c[9752472+(D<<2)>>2]=c[2433530];c[14113936+(D<<2)>>2]=c[2076596];c[9669104+(D<<2)>>2]=c[3541536]}c[1836236]=-1;if((c[3540900]|0)==0){c[3540900]=708}if((c[3540898]|0)==0){c[3540898]=1304}if((c[3540896]|0)==0){c[3540896]=286}gGz(9668984,0,27);S6(0,27,0);D=a[9680]|0;B=D?32e3:0;if(D){if(a[9624]|0){D=B*3|0;C=62500;while(1){if((C|0)>(D|0)){C=C>>1}else{E=1222;F=C;break}}}else{E=2462;F=B}c[2429380]=F;c[3542124]=E;mw(4e6,F);C=gGq(262144)|0;c[2406684]=C;gGz(C|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(4e6,11025)}h[745421]=1.0;c[2436794]=3;h[745420]=1.0;c[2436792]=3;if((c[3532574]|0)!=0){C=gGq(128)|0;c[2426620]=C;c[2429563]=0;a[9718232]=0;a[9718233]=127;b[4859117]=2048;gGz(C|0,0,128);a[9718241]=0;c[3541286]=2270;c[3541284]=1026;c[3541282]=1676;c[3541290]=1676;c[3541288]=1676;c[(c[3531464]|0)+44348>>2]=354;h[745421]=.43;c[2436794]=3;h[745420]=.43;c[2436792]=3;c[2405758]=1;gGz(9542544,0,32);c[2385641]=1;h[1192819]=1.0;c[2385642]=3;c[2385643]=4954;C=0;do{D=C*257|0;b[9732544+(C<<1)>>1]=((D|0)/2|0)&65535;b[9753784+(C<<1)>>1]=D+32768&65535;C=C+1|0;}while((C|0)<256);c[3528842]=1;h[1192819]=.8;c[2385642]=3}c[3532366]=4096;a[7461600]=1;eOT(1);G=c[(c[642608+(c[2436]<<2)>>2]|0)+60>>2]|0}else{G=x}if((G&-65536|0)==33816576){C=c[3532512]|0;if((C|0)==0){fxU(0,425984);if((c[2394]|0)==0){H=c[2112932]|0}else{c[2394]=0;B=c[3532596]|0;c[2112932]=B;D=c[3532592]|0;if((D|0)!=0){gGC(9104152,D|0,280)|0}c[2113054]=c[2113060];H=B}B=c[3532446]|0;D=H|0;k=D;l=0;while(1){c[k>>2]=B+l;m=l+1024|0;if(m>>>0>1048575){break}else{k=k+4|0;l=m}}l=c[3532552]|0;k=D;B=0;while(1){c[k+131072>>2]=l+B;m=B+1024|0;if(m>>>0>1048575){break}else{k=k+4|0;B=m}}B=c[3532356]|0;k=H+16384|0;l=4194304;while(1){c[k>>2]=B+(l-4194304);D=l+1024|0;if(D>>>0>4259839){break}else{k=k+4|0;l=D}}l=c[3532368]|0;c[H+16640>>2]=l;c[H+82176>>2]=l;c[H+147712>>2]=l;k=l+1024|0;c[H+16644>>2]=k;c[H+82180>>2]=k;c[H+147716>>2]=k;k=l+2048|0;c[H+16648>>2]=k;c[H+82184>>2]=k;c[H+147720>>2]=k;k=l+3072|0;c[H+16652>>2]=k;c[H+82188>>2]=k;c[H+147724>>2]=k;k=c[3532390]|0;c[H+17408>>2]=k;c[H+82944>>2]=k;c[H+148480>>2]=k;l=k+1024|0;c[H+17412>>2]=l;c[H+82948>>2]=l;c[H+148484>>2]=l;l=c[3532484]|0;c[H+33792>>2]=l;c[H+99328>>2]=l;c[H+164864>>2]=l;k=l+1024|0;c[H+33796>>2]=k;c[H+99332>>2]=k;c[H+164868>>2]=k;k=l+2048|0;c[H+33800>>2]=k;c[H+99336>>2]=k;c[H+164872>>2]=k;k=l+3072|0;c[H+33804>>2]=k;c[H+99340>>2]=k;c[H+164876>>2]=k;k=c[3532470]|0;c[H+65472>>2]=k;c[H+131008>>2]=k;c[H+196544>>2]=k;l=k+1024|0;c[H+65476>>2]=l;c[H+131012>>2]=l;c[H+196548>>2]=l;l=k+2048|0;c[H+65480>>2]=l;c[H+131016>>2]=l;c[H+196552>>2]=l;l=k+3072|0;c[H+65484>>2]=l;c[H+131020>>2]=l;c[H+196556>>2]=l;l=k+4096|0;c[H+65488>>2]=l;c[H+131024>>2]=l;c[H+196560>>2]=l;l=k+5120|0;c[H+65492>>2]=l;c[H+131028>>2]=l;c[H+196564>>2]=l;l=k+6144|0;c[H+65496>>2]=l;c[H+131032>>2]=l;c[H+196568>>2]=l;l=k+7168|0;c[H+65500>>2]=l;c[H+131036>>2]=l;c[H+196572>>2]=l;l=k+8192|0;c[H+65504>>2]=l;c[H+131040>>2]=l;c[H+196576>>2]=l;l=k+9216|0;c[H+65508>>2]=l;c[H+131044>>2]=l;c[H+196580>>2]=l;l=k+10240|0;c[H+65512>>2]=l;c[H+131048>>2]=l;c[H+196584>>2]=l;l=k+11264|0;c[H+65516>>2]=l;c[H+131052>>2]=l;c[H+196588>>2]=l;l=k+12288|0;c[H+65520>>2]=l;c[H+131056>>2]=l;c[H+196592>>2]=l;l=k+13312|0;c[H+65524>>2]=l;c[H+131060>>2]=l;c[H+196596>>2]=l;l=k+14336|0;c[H+65528>>2]=l;c[H+131064>>2]=l;c[H+196600>>2]=l;l=k+15360|0;c[H+65532>>2]=l;c[H+131068>>2]=l;c[H+196604>>2]=l;c[H+196608>>2]=1198;c[H+196648>>2]=268;c[H+196728>>2]=316;l=c[3532592]|0;if((l|0)!=0){gGC(l|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1}else{gu[C&16383]()}if((c[3532310]|0)==0){l=c[642608+(c[2436]<<2)>>2]|0;if((c[l+60>>2]&16384|0)==0){I=l}else{i=22843}}else{i=22843}do{if((i|0)==22843){l=(c[3532510]|0)==0;fwR(0);k=c[2439330]|0;B=(k|0)==0;if(!B){D=k;gGC(9706056,D|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];D=c[3528484]|0;c[2076596]=D;m=c[2417276]|0;c[3541536]=m;c[1836236]=0;if(!l){gu[c[3532510]&16383]();l=c[1836236]|0;f=c[9757320+(l<<2)>>2]|0;if((f|0)!=0){q=f;gGC(q|0,9706056,76)|0}c[9752472+(l<<2)>>2]=c[2433530];c[14113936+(l<<2)>>2]=c[2076596];c[9669104+(l<<2)>>2]=c[3541536];c[1836236]=-1;I=c[642608+(c[2436]<<2)>>2]|0;break}l=c[642608+(c[2436]<<2)>>2]|0;q=c[l+60>>2]&8;f=c[3532330]|0;n=0;s=0;while(1){c[k+76+(s<<2)>>2]=f+(s<<8);r=n+1&65535;if((r&65535)>223){break}else{n=r;s=r&65535}}if((q|0)==0){s=0;n=0;while(1){r=f+(n<<8)|0;c[k+76+(n+512<<2)>>2]=r;c[k+76+(n+768<<2)>>2]=r;r=s+1&65535;if((r&65535)>223){break}else{s=r;n=r&65535}}}else{n=c[3532336]|0;s=0;q=0;while(1){r=q<<8;c[k+76+(q+512<<2)>>2]=n+r;c[k+76+(q+768<<2)>>2]=f+r;r=s+1&65535;if((r&65535)>223){break}else{s=r;q=r&65535}}}q=c[3532334]|0;c[k+1068>>2]=q;s=q+256|0;c[k+1072>>2]=s;f=q+512|0;c[k+1076>>2]=f;n=q+768|0;c[k+1080>>2]=n;r=q+1024|0;c[k+1084>>2]=r;p=q+1280|0;c[k+1088>>2]=p;J=q+1536|0;c[k+1092>>2]=J;K=q+1792|0;c[k+1096>>2]=K;c[k+2092>>2]=q;c[k+2096>>2]=s;c[k+2100>>2]=f;c[k+2104>>2]=n;c[k+2108>>2]=r;c[k+2112>>2]=p;c[k+2116>>2]=J;c[k+2120>>2]=K;c[k+3116>>2]=q;c[k+4140>>2]=q;c[k+3120>>2]=s;c[k+4144>>2]=s;c[k+3124>>2]=f;c[k+4148>>2]=f;c[k+3128>>2]=n;c[k+4152>>2]=n;c[k+3132>>2]=r;c[k+4156>>2]=r;c[k+3136>>2]=p;c[k+4160>>2]=p;c[k+3140>>2]=J;c[k+4164>>2]=J;c[k+3144>>2]=K;c[k+4168>>2]=K;c[k+4172>>2]=140;c[k+4176>>2]=456;if(!B){K=k;gGC(K|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=D;c[2417276]=m;c[1836236]=-1;I=l}}while(0);C=a[9680]|0;if((c[I+60>>2]&4096|0)==0){K=C?32e3:0;if(C){if(a[9624]|0){J=K*3|0;p=62500;while(1){if((p|0)>(J|0)){p=p>>1}else{L=1222;M=p;break}}}else{L=2462;M=K}c[2429380]=M;c[3542124]=L;mw(4e6,M);p=gGq(262144)|0;c[2406684]=p;gGz(p|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(4e6,11025)}h[745421]=.43;c[2436794]=3;h[745420]=.43;c[2436792]=3}else{if(C){mq(5e6,32e3);p=gGq(262144)|0;c[2406690]=p;gGz(p|0,0,262144);c[2439246]=0;h[745411]=1.0;h[745410]=1.0;a[3203304]=1;a[3203296]=1}else{mq(5e6,11025)}h[745411]=1.0;a[3203304]=1;h[745410]=1.0;a[3203296]=1}if((c[3532344]|0)!=0){p=gGq(80)|0;J=p;c[2418506]=J;c[2424874]=J;gGz(p|0,0,80);c[p+4>>2]=~~(16.0e4/(a[9680]|0?32.0e3:0.0)*4194304.0);a[p+16|0]=0;a[635136]=1;a[p+9|0]=1;a[(c[2424874]|0)+10|0]=1;r=c[2424874]|0;h[r+64>>3]=1.0;c[r+72>>2]=3;Vl();c[p+12>>2]=612;c[2424874]=J;h[p+64>>3]=.48;c[p+72>>2]=3}c[3532366]=4096;a[7461600]=1;eOU(1);c[3532554]=1e7;N=c[(c[642608+(c[2436]<<2)>>2]|0)+60>>2]|0}else{N=G}if((N&-65536|0)==33947648){p=c[3532512]|0;if((p|0)==0){fxU(0,425984);if((c[2394]|0)==0){O=c[2112932]|0}else{c[2394]=0;J=c[3532596]|0;c[2112932]=J;r=c[3532592]|0;if((r|0)!=0){gGC(9104152,r|0,280)|0}c[2113054]=c[2113060];O=J}J=c[3532446]|0;r=O|0;n=r;f=0;while(1){c[n>>2]=J+f;s=f+1024|0;if(s>>>0>1048575){break}else{n=n+4|0;f=s}}f=c[3532552]|0;n=r;J=0;while(1){c[n+131072>>2]=f+J;C=J+1024|0;if(C>>>0>1048575){break}else{n=n+4|0;J=C}}J=c[3532356]|0;n=O+16384|0;f=4194304;while(1){c[n>>2]=J+(f-4194304);r=f+1024|0;if(r>>>0>4259839){break}else{n=n+4|0;f=r}}f=c[3532368]|0;c[O+16640>>2]=f;c[O+82176>>2]=f;c[O+147712>>2]=f;n=f+1024|0;c[O+16644>>2]=n;c[O+82180>>2]=n;c[O+147716>>2]=n;n=f+2048|0;c[O+16648>>2]=n;c[O+82184>>2]=n;c[O+147720>>2]=n;n=f+3072|0;c[O+16652>>2]=n;c[O+82188>>2]=n;c[O+147724>>2]=n;n=c[3532390]|0;c[O+17408>>2]=n;c[O+82944>>2]=n;c[O+148480>>2]=n;f=n+1024|0;c[O+17412>>2]=f;c[O+82948>>2]=f;c[O+148484>>2]=f;f=c[3532484]|0;c[O+33792>>2]=f;c[O+99328>>2]=f;c[O+164864>>2]=f;n=f+1024|0;c[O+33796>>2]=n;c[O+99332>>2]=n;c[O+164868>>2]=n;n=f+2048|0;c[O+33800>>2]=n;c[O+99336>>2]=n;c[O+164872>>2]=n;n=f+3072|0;c[O+33804>>2]=n;c[O+99340>>2]=n;c[O+164876>>2]=n;n=c[3532470]|0;c[O+65472>>2]=n;c[O+131008>>2]=n;c[O+196544>>2]=n;f=n+1024|0;c[O+65476>>2]=f;c[O+131012>>2]=f;c[O+196548>>2]=f;f=n+2048|0;c[O+65480>>2]=f;c[O+131016>>2]=f;c[O+196552>>2]=f;f=n+3072|0;c[O+65484>>2]=f;c[O+131020>>2]=f;c[O+196556>>2]=f;f=n+4096|0;c[O+65488>>2]=f;c[O+131024>>2]=f;c[O+196560>>2]=f;f=n+5120|0;c[O+65492>>2]=f;c[O+131028>>2]=f;c[O+196564>>2]=f;f=n+6144|0;c[O+65496>>2]=f;c[O+131032>>2]=f;c[O+196568>>2]=f;f=n+7168|0;c[O+65500>>2]=f;c[O+131036>>2]=f;c[O+196572>>2]=f;f=n+8192|0;c[O+65504>>2]=f;c[O+131040>>2]=f;c[O+196576>>2]=f;f=n+9216|0;c[O+65508>>2]=f;c[O+131044>>2]=f;c[O+196580>>2]=f;f=n+10240|0;c[O+65512>>2]=f;c[O+131048>>2]=f;c[O+196584>>2]=f;f=n+11264|0;c[O+65516>>2]=f;c[O+131052>>2]=f;c[O+196588>>2]=f;f=n+12288|0;c[O+65520>>2]=f;c[O+131056>>2]=f;c[O+196592>>2]=f;f=n+13312|0;c[O+65524>>2]=f;c[O+131060>>2]=f;c[O+196596>>2]=f;f=n+14336|0;c[O+65528>>2]=f;c[O+131064>>2]=f;c[O+196600>>2]=f;f=n+15360|0;c[O+65532>>2]=f;c[O+131068>>2]=f;c[O+196604>>2]=f;c[O+196688>>2]=2576;c[O+196728>>2]=1922;c[O+196608>>2]=880;c[O+196648>>2]=1400;f=c[3532592]|0;if((f|0)!=0){gGC(f|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1}else{gu[p&16383]()}f=(c[3532510]|0)==0;fwR(0);n=c[2439330]|0;J=(n|0)==0;if(!J){r=n;gGC(9706056,r|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];r=c[3528484]|0;c[2076596]=r;C=c[2417276]|0;c[3541536]=C;c[1836236]=0;if(f){f=c[3532330]|0;K=0;s=0;while(1){c[n+76+(s<<2)>>2]=f+(s<<8);q=K+1&65535;if((q&65535)>159){P=0;Q=0;break}else{K=q;s=q&65535}}while(1){s=f+(Q<<8)|0;c[n+76+(Q+512<<2)>>2]=s;c[n+76+(Q+768<<2)>>2]=s;s=P+1&65535;if((s&65535)>159){R=160;S=160;break}else{P=s;Q=s&65535}}while(1){c[n+76+(S<<2)>>2]=f+(S<<8);s=R+1&65535;if((s&65535)>191){T=160;U=160;break}else{R=s;S=s&65535}}while(1){s=f+(U<<8)|0;c[n+76+(U+512<<2)>>2]=s;c[n+76+(U+768<<2)>>2]=s;s=T+1&65535;if((s&65535)>191){break}else{T=s;U=s&65535}}f=c[3532334]|0;s=224;K=224;while(1){c[n+76+(K<<2)>>2]=f+((K<<8)-57344);p=s+1&65535;if((p&65535)>255){V=224;W=224;break}else{s=p;K=p&65535}}while(1){c[n+76+(W+256<<2)>>2]=f+((W<<8)-57344);K=V+1&65535;if((K&65535)>255){X=224;Y=224;break}else{V=K;W=K&65535}}while(1){K=f+((Y<<8)-57344)|0;c[n+76+(Y+512<<2)>>2]=K;c[n+76+(Y+768<<2)>>2]=K;K=X+1&65535;if((K&65535)>255){break}else{X=K;Y=K&65535}}c[n+4180>>2]=392;c[n+4184>>2]=1158;c[n+4172>>2]=3076;c[n+4176>>2]=976;if(!J){f=n;gGC(f|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=r;c[2417276]=C}else{gu[c[3532510]&16383]();f=c[1836236]|0;K=c[9757320+(f<<2)>>2]|0;if((K|0)!=0){s=K;gGC(s|0,9706056,76)|0}c[9752472+(f<<2)>>2]=c[2433530];c[14113936+(f<<2)>>2]=c[2076596];c[9669104+(f<<2)>>2]=c[3541536]}c[1836236]=-1;Uo(2,8e6,0,228,88,1);c[2438228]=8e6;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=255;h[745403]=.4;c[2436782]=3;h[745402]=.4;c[2436780]=3;h[745401]=.4;c[2436778]=3;h[745400]=.4;c[2436776]=3;f=gGq(65664)|0;c[2420422]=f;c[2443778]=~~(26041.0/(a[9680]|0?32.0e3:0.0)*32768.0);s=a[9688]|0?2136:0;c[2420378]=gGq(s)|0;c[2415138]=gGq(s)|0;h[f+65640>>3]=1.0;h[f+65648>>3]=1.0;c[f+65656>>2]=1;c[f+65660>>2]=2;f=c[2420422]|0;h[f+65640>>3]=1.0;c[f+65656>>2]=3;h[f+65648>>3]=1.0;c[f+65660>>2]=3;c[3532366]=1024;a[7461600]=1;eOU(1);c[3541304]=c[3532488];f=0;while(1){if((f|0)>=1024){Z=0;break}_=9638528+(f<<2)|0;if((c[_>>2]|0)==0){i=22911;break}else{f=f+1|0}}do{if((i|0)==22911){f=gGq(65536)|0;c[_>>2]=f;if((f|0)==0){Z=0;break}gGz(f|0,0,65536);Z=f}}while(0);c[3531882]=Z;f=0;while(1){if((f|0)>=1024){$=0;break}aa=9638528+(f<<2)|0;if((c[aa>>2]|0)==0){i=22916;break}else{f=f+1|0}}do{if((i|0)==22916){f=gGq(128)|0;c[aa>>2]=f;if((f|0)==0){$=0;break}gGz(f|0,0,128);$=f}}while(0);c[3531880]=$;f=0;while(1){if((f|0)>=1024){ab=0;break}ac=9638528+(f<<2)|0;if((c[ac>>2]|0)==0){i=22921;break}else{f=f+1|0}}do{if((i|0)==22921){f=gGq(8192)|0;c[ac>>2]=f;if((f|0)==0){ab=0;break}gGz(f|0,0,8192);ab=f}}while(0);c[3531884]=ab;gGz(c[3531882]|0,0,65536);gGz(c[3531880]|0,0,128);f=0;do{C=f&2047;do{if((f&256|0)==0){if((f&2048|0)==0){b[ab+(f<<1)>>1]=(C|4096)&65535;break}else{b[ab+(f<<1)>>1]=(C|2048)&65535;break}}else{b[ab+(f<<1)>>1]=C&65535}}while(0);f=f+1|0;}while((f|0)<4096);a[7461856]=0;b[7082604]=0;b[7082612]=0;b[7082605]=16;b[7082613]=16;b[7082606]=32;b[7082614]=32;b[7082607]=48;b[7082615]=48;f=0;do{eFd(f<<8|(d[618624+f|0]|0)|32768);f=f+1|0;}while((f|0)<24);a[14127616]=0;a[14127608]=0;c[3531908]=0;a[7461856]=1;b[7082604]=6144;b[7082612]=6144;b[7082605]=6160;b[7082613]=6160;b[7082606]=6176;b[7082614]=6176;b[7082607]=6192;b[7082615]=6192;ad=c[(c[642608+(c[2436]<<2)>>2]|0)+60>>2]|0}else{ad=N}if((ad&-65536|0)==34013184){f=c[3532512]|0;if((f|0)==0){fxU(0,425984);if((c[2394]|0)==0){ae=c[2112932]|0}else{c[2394]=0;C=c[3532596]|0;c[2112932]=C;l=c[3532592]|0;if((l|0)!=0){gGC(9104152,l|0,280)|0}c[2113054]=c[2113060];ae=C}C=c[3532446]|0;l=ae|0;m=l;D=0;while(1){c[m>>2]=C+D;k=D+1024|0;if(k>>>0>262143){break}else{m=m+4|0;D=k}}D=c[3532552]|0;m=l;C=0;while(1){c[m+131072>>2]=D+C;k=C+1024|0;if(k>>>0>262143){break}else{m=m+4|0;C=k}}C=c[3532470]|0;m=ae+8192|0;D=2097152;while(1){l=C+(D-2097152)|0;c[m>>2]=l;c[m+65536>>2]=l;c[m+131072>>2]=l;l=D+1024|0;if(l>>>0>2162687){break}else{m=m+4|0;D=l}}D=c[3532356]|0;c[ae+16384>>2]=D;c[ae+16388>>2]=D+1024;c[ae+16392>>2]=D+2048;c[ae+16396>>2]=D+3072;c[ae+16400>>2]=D+4096;c[ae+16404>>2]=D+5120;c[ae+16408>>2]=D+6144;c[ae+16412>>2]=D+7168;c[ae+16416>>2]=D+8192;c[ae+16420>>2]=D+9216;c[ae+16424>>2]=D+10240;c[ae+16428>>2]=D+11264;c[ae+16432>>2]=D+12288;c[ae+16436>>2]=D+13312;c[ae+16440>>2]=D+14336;c[ae+16444>>2]=D+15360;D=c[3532368]|0;c[ae+16640>>2]=D;c[ae+82176>>2]=D;c[ae+147712>>2]=D;m=D+1024|0;c[ae+16644>>2]=m;c[ae+82180>>2]=m;c[ae+147716>>2]=m;m=D+2048|0;c[ae+16648>>2]=m;c[ae+82184>>2]=m;c[ae+147720>>2]=m;m=D+3072|0;c[ae+16652>>2]=m;c[ae+82188>>2]=m;c[ae+147724>>2]=m;m=c[3532390]|0;D=ae+24576|0;C=6291456;while(1){l=m+(C-6291456)|0;c[D>>2]=l;c[D+65536>>2]=l;c[D+131072>>2]=l;l=C+1024|0;if(l>>>0>6324223){break}else{D=D+4|0;C=l}}C=c[3532484]|0;c[ae+40960>>2]=C;c[ae+106496>>2]=C;c[ae+172032>>2]=C;D=C+1024|0;c[ae+40964>>2]=D;c[ae+106500>>2]=D;c[ae+172036>>2]=D;D=C+2048|0;c[ae+40968>>2]=D;c[ae+106504>>2]=D;c[ae+172040>>2]=D;D=C+3072|0;c[ae+40972>>2]=D;c[ae+106508>>2]=D;c[ae+172044>>2]=D;D=c[3532444]|0;C=ae+49152|0;m=12582912;while(1){c[C>>2]=D+(m-12582912);l=m+1024|0;if(l>>>0>12845055){break}else{C=C+4|0;m=l}}m=c[3532456]|0;c[ae+50816>>2]=m;c[ae+116352>>2]=m;c[ae+181888>>2]=m;C=m+1024|0;c[ae+50820>>2]=C;c[ae+116356>>2]=C;c[ae+181892>>2]=C;C=m+2048|0;c[ae+50824>>2]=C;c[ae+116360>>2]=C;c[ae+181896>>2]=C;C=m+3072|0;c[ae+50828>>2]=C;c[ae+116364>>2]=C;c[ae+181900>>2]=C;C=c[3532542]|0;c[ae+51136>>2]=C;c[ae+116672>>2]=C;c[ae+182208>>2]=C;m=C+1024|0;c[ae+51140>>2]=m;c[ae+116676>>2]=m;c[ae+182212>>2]=m;m=C+2048|0;c[ae+51144>>2]=m;c[ae+116680>>2]=m;c[ae+182216>>2]=m;m=C+3072|0;c[ae+51148>>2]=m;c[ae+116684>>2]=m;c[ae+182220>>2]=m;m=C+4096|0;c[ae+51152>>2]=m;c[ae+116688>>2]=m;c[ae+182224>>2]=m;m=C+5120|0;c[ae+51156>>2]=m;c[ae+116692>>2]=m;c[ae+182228>>2]=m;m=C+6144|0;c[ae+51160>>2]=m;c[ae+116696>>2]=m;c[ae+182232>>2]=m;m=C+7168|0;c[ae+51164>>2]=m;c[ae+116700>>2]=m;c[ae+182236>>2]=m;m=C+8192|0;c[ae+51168>>2]=m;c[ae+116704>>2]=m;c[ae+182240>>2]=m;m=C+9216|0;c[ae+51172>>2]=m;c[ae+116708>>2]=m;c[ae+182244>>2]=m;m=C+10240|0;c[ae+51176>>2]=m;c[ae+116712>>2]=m;c[ae+182248>>2]=m;m=C+11264|0;c[ae+51180>>2]=m;c[ae+116716>>2]=m;c[ae+182252>>2]=m;m=C+12288|0;c[ae+51184>>2]=m;c[ae+116720>>2]=m;c[ae+182256>>2]=m;m=C+13312|0;c[ae+51188>>2]=m;c[ae+116724>>2]=m;c[ae+182260>>2]=m;m=C+14336|0;c[ae+51192>>2]=m;c[ae+116728>>2]=m;c[ae+182264>>2]=m;m=C+15360|0;c[ae+51196>>2]=m;c[ae+116732>>2]=m;c[ae+182268>>2]=m;c[ae+196688>>2]=3252;c[ae+196608>>2]=3396;c[ae+196648>>2]=1358;c[ae+196728>>2]=2244;m=c[3532592]|0;if((m|0)!=0){gGC(m|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1}else{gu[f&16383]()}fxU(1,425984);if((c[2394]|0)==1){af=c[2112932]|0}else{c[2394]=1;m=c[3532597]|0;c[2112932]=m;C=c[3532593]|0;if((C|0)!=0){gGC(9104152,C|0,280)|0}c[2113054]=c[2113061];af=m}m=c[3532444]|0;C=af|0;D=C;l=0;while(1){c[D>>2]=m+l;k=l+1024|0;if(k>>>0>262143){ah=C;ai=0;break}else{D=D+4|0;l=k}}while(1){c[ah+131072>>2]=m+ai;l=ai+1024|0;if(l>>>0>262143){break}else{ah=ah+4|0;ai=l}}m=c[3532456]|0;c[af+50816>>2]=m;c[af+116352>>2]=m;c[af+181888>>2]=m;l=m+1024|0;c[af+50820>>2]=l;c[af+116356>>2]=l;c[af+181892>>2]=l;l=m+2048|0;c[af+50824>>2]=l;c[af+116360>>2]=l;c[af+181896>>2]=l;l=m+3072|0;c[af+50828>>2]=l;c[af+116364>>2]=l;c[af+181900>>2]=l;l=c[3532542]|0;c[af+51136>>2]=l;c[af+116672>>2]=l;c[af+182208>>2]=l;m=l+1024|0;c[af+51140>>2]=m;c[af+116676>>2]=m;c[af+182212>>2]=m;m=l+2048|0;c[af+51144>>2]=m;c[af+116680>>2]=m;c[af+182216>>2]=m;m=l+3072|0;c[af+51148>>2]=m;c[af+116684>>2]=m;c[af+182220>>2]=m;m=l+4096|0;c[af+51152>>2]=m;c[af+116688>>2]=m;c[af+182224>>2]=m;m=l+5120|0;c[af+51156>>2]=m;c[af+116692>>2]=m;c[af+182228>>2]=m;m=l+6144|0;c[af+51160>>2]=m;c[af+116696>>2]=m;c[af+182232>>2]=m;m=l+7168|0;c[af+51164>>2]=m;c[af+116700>>2]=m;c[af+182236>>2]=m;m=l+8192|0;c[af+51168>>2]=m;c[af+116704>>2]=m;c[af+182240>>2]=m;m=l+9216|0;c[af+51172>>2]=m;c[af+116708>>2]=m;c[af+182244>>2]=m;m=l+10240|0;c[af+51176>>2]=m;c[af+116712>>2]=m;c[af+182248>>2]=m;m=l+11264|0;c[af+51180>>2]=m;c[af+116716>>2]=m;c[af+182252>>2]=m;m=l+12288|0;c[af+51184>>2]=m;c[af+116720>>2]=m;c[af+182256>>2]=m;m=l+13312|0;c[af+51188>>2]=m;c[af+116724>>2]=m;c[af+182260>>2]=m;m=l+14336|0;c[af+51192>>2]=m;c[af+116728>>2]=m;c[af+182264>>2]=m;m=l+15360|0;c[af+51196>>2]=m;c[af+116732>>2]=m;c[af+182268>>2]=m;m=c[3532593]|0;if((m|0)!=0){gGC(m|0,9104152,280)|0}c[2113061]=c[2113054];c[2394]=-1;do{if((c[3532510]|0)==0){m=(c[(c[642608+(c[2436]<<2)>>2]|0)+60>>2]&256|0)==0;fwR(0);l=c[2439330]|0;D=(l|0)==0;if(!D){C=l;gGC(9706056,C|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];C=c[3528484]|0;c[2076596]=C;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;k=c[3532330]|0;if(m){m=0;B=0;while(1){c[l+76+(B<<2)>>2]=k+(B<<8);r=m+1&65535;if((r&65535)>223){aj=0;ak=0;break}else{m=r;B=r&65535}}while(1){B=k+(ak<<8)|0;c[l+76+(ak+512<<2)>>2]=B;c[l+76+(ak+768<<2)>>2]=B;B=aj+1&65535;if((B&65535)>223){break}else{aj=B;ak=B&65535}}B=c[3532334]|0;c[l+1068>>2]=B;m=B+256|0;c[l+1072>>2]=m;r=B+512|0;c[l+1076>>2]=r;n=B+768|0;c[l+1080>>2]=n;J=B+1024|0;c[l+1084>>2]=J;s=B+1280|0;c[l+1088>>2]=s;K=B+1536|0;c[l+1092>>2]=K;p=B+1792|0;c[l+1096>>2]=p;c[l+2092>>2]=B;c[l+2096>>2]=m;c[l+2100>>2]=r;c[l+2104>>2]=n;c[l+2108>>2]=J;c[l+2112>>2]=s;c[l+2116>>2]=K;c[l+2120>>2]=p;c[l+3116>>2]=B;c[l+4140>>2]=B;c[l+3120>>2]=m;c[l+4144>>2]=m;c[l+3124>>2]=r;c[l+4148>>2]=r;c[l+3128>>2]=n;c[l+4152>>2]=n;c[l+3132>>2]=J;c[l+4156>>2]=J;c[l+3136>>2]=s;c[l+4160>>2]=s;c[l+3140>>2]=K;c[l+4164>>2]=K;c[l+3144>>2]=p;c[l+4168>>2]=p;c[l+4180>>2]=3084;c[l+4184>>2]=150;c[l+4172>>2]=1872;c[l+4176>>2]=456;if(!D){p=l;gGC(p|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=C;c[2417276]=f;c[1836236]=-1;break}else{p=0;K=0;while(1){c[l+76+(K<<2)>>2]=k+(K<<8);s=p+1&65535;if((s&65535)>127){al=0;am=0;break}else{p=s;K=s&65535}}while(1){K=k+(am<<8)|0;c[l+76+(am+512<<2)>>2]=K;c[l+76+(am+768<<2)>>2]=K;K=al+1&65535;if((K&65535)>127){break}else{al=K;am=K&65535}}k=c[3532334]|0;c[l+844>>2]=k;K=k+256|0;c[l+848>>2]=K;p=k+512|0;c[l+852>>2]=p;s=k+768|0;c[l+856>>2]=s;J=k+1024|0;c[l+860>>2]=J;n=k+1280|0;c[l+864>>2]=n;r=k+1536|0;c[l+868>>2]=r;m=k+1792|0;c[l+872>>2]=m;c[l+1868>>2]=k;c[l+1872>>2]=K;c[l+1876>>2]=p;c[l+1880>>2]=s;c[l+1884>>2]=J;c[l+1888>>2]=n;c[l+1892>>2]=r;c[l+1896>>2]=m;c[l+2892>>2]=k;c[l+3916>>2]=k;c[l+2896>>2]=K;c[l+3920>>2]=K;c[l+2900>>2]=p;c[l+3924>>2]=p;c[l+2904>>2]=s;c[l+3928>>2]=s;c[l+2908>>2]=J;c[l+3932>>2]=J;c[l+2912>>2]=n;c[l+3936>>2]=n;c[l+2916>>2]=r;c[l+3940>>2]=r;c[l+2920>>2]=m;c[l+3944>>2]=m;c[l+4180>>2]=358;c[l+4184>>2]=2550;c[l+4172>>2]=3502;if(!D){m=l;gGC(m|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=C;c[2417276]=f;c[1836236]=-1;break}}else{fwR(0);m=c[2439330]|0;if((m|0)!=0){r=m;gGC(9706056,r|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;gu[c[3532510]&16383]();r=c[1836236]|0;m=c[9757320+(r<<2)>>2]|0;if((m|0)!=0){n=m;gGC(n|0,9706056,76)|0}c[9752472+(r<<2)>>2]=c[2433530];c[14113936+(r<<2)>>2]=c[2076596];c[9669104+(r<<2)>>2]=c[3541536];c[1836236]=-1}}while(0);if((c[3540900]|0)==0){c[3540900]=1494}if((c[3540898]|0)==0){c[3540898]=538}if((c[3540896]|0)==0){c[3540896]=1120}if((c[3540890]|0)==0){c[3540890]=2302}if((c[3540888]|0)==0){c[3540888]=492}gGz(9668984,0,27);S6(0,27,0);gGz(9669011,0,27);S6(1,27,0);if((c[(c[642608+(c[2436]<<2)>>2]|0)+60>>2]&256|0)==0){r=a[9680]|0;n=r?32e3:0;if(r){if(a[9624]|0){r=n*3|0;m=62500;while(1){if((m|0)>(r|0)){m=m>>1}else{an=1222;ao=m;break}}}else{an=2462;ao=n}c[2429380]=ao;c[3542124]=an;mw(4e6,ao);m=gGq(262144)|0;c[2406684]=m;gGz(m|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(4e6,11025)}c[(c[3531464]|0)+44344>>2]=1290;h[745421]=.43;c[2436794]=1;h[745420]=.43;c[2436792]=2}else{Vr(1,4e6,1976,1470,108,0);c[2438228]=4e6;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=511;h[745419]=.37;a[3203368]=1;h[745418]=.13;a[3203360]=1;h[745417]=.13;a[3203352]=1;h[745416]=.13;a[3203344]=1}m=c[3532496]|0;if((m|0)!=0){r=c[3532500]|0;if((c[(c[642608+(c[2436]<<2)>>2]|0)+60>>2]&256|0)==0){Vi(0,4e6,12,r,m)}else{Vi(0,8e6,12,r,m)}m=c[2424876]|0;h[m+2080>>3]=1.0;c[m+2096>>2]=1;h[m+2088>>3]=1.0;c[m+2100>>2]=2}c[3532366]=4096;eOT(0);ap=c[(c[642608+(c[2436]<<2)>>2]|0)+60>>2]|0}else{ap=ad}if((ap&-65536|0)==34078720){fxU(0,425984);if((c[2394]|0)==0){aq=c[2112932]|0}else{c[2394]=0;m=c[3532596]|0;c[2112932]=m;r=c[3532592]|0;if((r|0)!=0){gGC(9104152,r|0,280)|0}c[2113054]=c[2113060];aq=m}m=c[3532446]|0;r=aq|0;J=r;s=0;while(1){c[J>>2]=m+s;p=s+1024|0;if(p>>>0>393215){break}else{J=J+4|0;s=p}}s=c[3532552]|0;J=r;m=0;while(1){c[J+131072>>2]=s+m;n=m+1024|0;if(n>>>0>393215){break}else{J=J+4|0;m=n}}m=c[3532542]|0;J=aq+1536|0;s=393216;while(1){r=m+(s-393216)|0;c[J>>2]=r;c[J+65536>>2]=r;c[J+131072>>2]=r;r=s+1024|0;if(r>>>0>425983){break}else{J=J+4|0;s=r}}s=c[3532356]|0;J=aq+4096|0;m=1048576;while(1){c[J>>2]=s+(m-1048576);r=m+1024|0;if(r>>>0>1114111){break}else{J=J+4|0;m=r}}m=c[3532368]|0;c[aq+4352>>2]=m;c[aq+69888>>2]=m;c[aq+135424>>2]=m;J=m+1024|0;c[aq+4356>>2]=J;c[aq+69892>>2]=J;c[aq+135428>>2]=J;J=m+2048|0;c[aq+4360>>2]=J;c[aq+69896>>2]=J;c[aq+135432>>2]=J;J=m+3072|0;c[aq+4364>>2]=J;c[aq+69900>>2]=J;c[aq+135436>>2]=J;J=c[3532484]|0;c[aq+4608>>2]=J;c[aq+70144>>2]=J;c[aq+135680>>2]=J;m=J+1024|0;c[aq+4612>>2]=m;c[aq+70148>>2]=m;c[aq+135684>>2]=m;m=J+2048|0;c[aq+4616>>2]=m;c[aq+70152>>2]=m;c[aq+135688>>2]=m;m=J+3072|0;c[aq+4620>>2]=m;c[aq+70156>>2]=m;c[aq+135692>>2]=m;m=J+4096|0;c[aq+4624>>2]=m;c[aq+70160>>2]=m;c[aq+135696>>2]=m;m=J+5120|0;c[aq+4628>>2]=m;c[aq+70164>>2]=m;c[aq+135700>>2]=m;m=J+6144|0;c[aq+4632>>2]=m;c[aq+70168>>2]=m;c[aq+135704>>2]=m;m=J+7168|0;c[aq+4636>>2]=m;c[aq+70172>>2]=m;c[aq+135708>>2]=m;m=c[3532390]|0;c[aq+4864>>2]=m;c[aq+70400>>2]=m;c[aq+135936>>2]=m;J=m+1024|0;c[aq+4868>>2]=J;c[aq+70404>>2]=J;c[aq+135940>>2]=J;J=m+2048|0;c[aq+4872>>2]=J;c[aq+70408>>2]=J;c[aq+135944>>2]=J;J=m+3072|0;c[aq+4876>>2]=J;c[aq+70412>>2]=J;c[aq+135948>>2]=J;J=c[3532444]|0;m=aq+8192|0;s=2097152;while(1){c[m>>2]=J+(s-2097152);r=s+1024|0;if(r>>>0>2359295){break}else{m=m+4|0;s=r}}s=c[3532470]|0;m=aq+9728|0;J=2490368;while(1){r=s+(J-2490368)|0;c[m>>2]=r;c[m+65536>>2]=r;c[m+131072>>2]=r;r=J+1024|0;if(r>>>0>2523135){break}else{m=m+4|0;J=r}}J=c[3532456]|0;c[aq+10240>>2]=J;c[aq+75776>>2]=J;c[aq+141312>>2]=J;m=J+1024|0;c[aq+10244>>2]=m;c[aq+75780>>2]=m;c[aq+141316>>2]=m;m=J+2048|0;c[aq+10248>>2]=m;c[aq+75784>>2]=m;c[aq+141320>>2]=m;m=J+3072|0;c[aq+10252>>2]=m;c[aq+75788>>2]=m;c[aq+141324>>2]=m;c[aq+196848>>2]=3968;c[aq+196688>>2]=520;c[aq+196728>>2]=2764;c[aq+196608>>2]=868;c[aq+196648>>2]=1188;m=c[3532592]|0;if((m|0)!=0){gGC(m|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fxU(1,425984);if((c[2394]|0)==1){ar=c[2112932]|0}else{c[2394]=1;m=c[3532597]|0;c[2112932]=m;J=c[3532593]|0;if((J|0)!=0){gGC(9104152,J|0,280)|0}c[2113054]=c[2113061];ar=m}m=c[3532444]|0;J=ar|0;s=J;r=0;while(1){c[s>>2]=m+r;n=r+1024|0;if(n>>>0>262143){as=J;at=0;break}else{s=s+4|0;r=n}}while(1){c[as+131072>>2]=m+at;r=at+1024|0;if(r>>>0>262143){break}else{as=as+4|0;at=r}}m=c[3532470]|0;r=ar+1536|0;s=393216;while(1){J=m+(s-393216)|0;c[r>>2]=J;c[r+65536>>2]=J;c[r+131072>>2]=J;J=s+1024|0;if(J>>>0>425983){break}else{r=r+4|0;s=J}}s=c[3532456]|0;c[ar+2048>>2]=s;c[ar+67584>>2]=s;c[ar+133120>>2]=s;r=s+1024|0;c[ar+2052>>2]=r;c[ar+67588>>2]=r;c[ar+133124>>2]=r;r=s+2048|0;c[ar+2056>>2]=r;c[ar+67592>>2]=r;c[ar+133128>>2]=r;r=s+3072|0;c[ar+2060>>2]=r;c[ar+67596>>2]=r;c[ar+133132>>2]=r;c[ar+196728>>2]=1986;c[ar+196608>>2]=884;c[ar+196648>>2]=3008;r=c[3532593]|0;if((r|0)!=0){gGC(r|0,9104152,280)|0}c[2113061]=c[2113054];c[2394]=-1;r=(c[3532510]|0)==0;fwR(0);s=c[2439330]|0;m=(s|0)==0;if(!m){J=s;gGC(9706056,J|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];J=c[3528484]|0;c[2076596]=J;n=c[2417276]|0;c[3541536]=n;c[1836236]=0;if(r){r=c[3532330]|0;p=0;K=0;while(1){c[s+76+(K<<2)>>2]=r+(K<<8);k=p+1&65535;if((k&65535)>223){au=0;av=0;break}else{p=k;K=k&65535}}while(1){K=r+(av<<8)|0;c[s+76+(av+512<<2)>>2]=K;c[s+76+(av+768<<2)>>2]=K;K=au+1&65535;if((K&65535)>223){break}else{au=K;av=K&65535}}r=c[3532334]|0;c[s+1068>>2]=r;K=r+256|0;c[s+1072>>2]=K;p=r+512|0;c[s+1076>>2]=p;k=r+768|0;c[s+1080>>2]=k;B=r+1024|0;c[s+1084>>2]=B;q=r+1280|0;c[s+1088>>2]=q;aw=r+1536|0;c[s+1092>>2]=aw;ax=r+1792|0;c[s+1096>>2]=ax;c[s+2092>>2]=r;c[s+2096>>2]=K;c[s+2100>>2]=p;c[s+2104>>2]=k;c[s+2108>>2]=B;c[s+2112>>2]=q;c[s+2116>>2]=aw;c[s+2120>>2]=ax;c[s+3116>>2]=r;c[s+4140>>2]=r;c[s+3120>>2]=K;c[s+4144>>2]=K;c[s+3124>>2]=p;c[s+4148>>2]=p;c[s+3128>>2]=k;c[s+4152>>2]=k;c[s+3132>>2]=B;c[s+4156>>2]=B;c[s+3136>>2]=q;c[s+4160>>2]=q;c[s+3140>>2]=aw;c[s+4164>>2]=aw;c[s+3144>>2]=ax;c[s+4168>>2]=ax;c[s+4180>>2]=3084;c[s+4184>>2]=150;c[s+4172>>2]=1872;c[s+4176>>2]=456;if(!m){ax=s;gGC(ax|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=J;c[2417276]=n}else{gu[c[3532510]&16383]();ax=c[1836236]|0;aw=c[9757320+(ax<<2)>>2]|0;if((aw|0)!=0){q=aw;gGC(q|0,9706056,76)|0}c[9752472+(ax<<2)>>2]=c[2433530];c[14113936+(ax<<2)>>2]=c[2076596];c[9669104+(ax<<2)>>2]=c[3541536]}c[1836236]=-1;if((c[3540896]|0)==0){c[3540896]=1280}gGz(9668984,0,27);S6(0,27,0);ax=a[9680]|0;q=ax?32e3:0;if(ax){if(a[9624]|0){ax=q*3|0;aw=62500;while(1){if((aw|0)>(ax|0)){aw=aw>>1}else{ay=1222;az=aw;break}}}else{ay=2462;az=q}c[2429380]=az;c[3542124]=ay;mw(4e6,az);aw=gGq(262144)|0;c[2406684]=aw;gGz(aw|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(4e6,11025)}h[745421]=.43;c[2436794]=1;h[745420]=.43;c[2436792]=2;aw=c[3532496]|0;if((aw|0)!=0){Vi(0,4e6,12,c[3532500]|0,aw);aw=c[2424876]|0;h[aw+2080>>3]=1.0;c[aw+2096>>2]=1;h[aw+2088>>3]=1.0;c[aw+2100>>2]=2}c[3532464]=1024;c[3532462]=1056;c[3532460]=1920;c[3532366]=4096;eOU(0);aA=c[(c[642608+(c[2436]<<2)>>2]|0)+60>>2]|0}else{aA=ap}if((aA&-65536|0)==33619968){fxU(0,425984);if((c[2394]|0)==0){aB=c[2112932]|0}else{c[2394]=0;aw=c[3532596]|0;c[2112932]=aw;ax=c[3532592]|0;if((ax|0)!=0){gGC(9104152,ax|0,280)|0}c[2113054]=c[2113060];aB=aw}aw=c[3532446]|0;ax=aB|0;n=ax;J=0;while(1){c[n>>2]=aw+J;s=J+1024|0;if(s>>>0>524287){break}else{n=n+4|0;J=s}}J=c[3532552]|0;n=ax;aw=0;while(1){c[n+131072>>2]=J+aw;q=aw+1024|0;if(q>>>0>524287){break}else{n=n+4|0;aw=q}}aw=c[3532356]|0;n=aB+3072|0;J=786432;while(1){c[n>>2]=aw+(J-786432);ax=J+1024|0;if(ax>>>0>851967){break}else{n=n+4|0;J=ax}}J=c[3532368]|0;c[aB+3328>>2]=J;c[aB+68864>>2]=J;c[aB+134400>>2]=J;n=J+1024|0;c[aB+3332>>2]=n;c[aB+68868>>2]=n;c[aB+134404>>2]=n;n=J+2048|0;c[aB+3336>>2]=n;c[aB+68872>>2]=n;c[aB+134408>>2]=n;n=J+3072|0;c[aB+3340>>2]=n;c[aB+68876>>2]=n;c[aB+134412>>2]=n;n=c[3532390]|0;c[aB+4096>>2]=n;c[aB+69632>>2]=n;c[aB+135168>>2]=n;J=n+1024|0;c[aB+4100>>2]=J;c[aB+69636>>2]=J;c[aB+135172>>2]=J;aw=n+2048|0;c[aB+4104>>2]=aw;c[aB+69640>>2]=aw;c[aB+135176>>2]=aw;ax=n+3072|0;c[aB+4108>>2]=ax;c[aB+69644>>2]=ax;c[aB+135180>>2]=ax;c[aB+4112>>2]=n;c[aB+69648>>2]=n;c[aB+135184>>2]=n;c[aB+4116>>2]=J;c[aB+69652>>2]=J;c[aB+135188>>2]=J;c[aB+4120>>2]=aw;c[aB+69656>>2]=aw;c[aB+135192>>2]=aw;c[aB+4124>>2]=ax;c[aB+69660>>2]=ax;c[aB+135196>>2]=ax;c[aB+4128>>2]=n;c[aB+69664>>2]=n;c[aB+135200>>2]=n;c[aB+4132>>2]=J;c[aB+69668>>2]=J;c[aB+135204>>2]=J;c[aB+4136>>2]=aw;c[aB+69672>>2]=aw;c[aB+135208>>2]=aw;c[aB+4140>>2]=ax;c[aB+69676>>2]=ax;c[aB+135212>>2]=ax;c[aB+4144>>2]=n;c[aB+69680>>2]=n;c[aB+135216>>2]=n;c[aB+4148>>2]=J;c[aB+69684>>2]=J;c[aB+135220>>2]=J;c[aB+4152>>2]=aw;c[aB+69688>>2]=aw;c[aB+135224>>2]=aw;c[aB+4156>>2]=ax;c[aB+69692>>2]=ax;c[aB+135228>>2]=ax;c[aB+4160>>2]=n;c[aB+69696>>2]=n;c[aB+135232>>2]=n;c[aB+4164>>2]=J;c[aB+69700>>2]=J;c[aB+135236>>2]=J;c[aB+4168>>2]=aw;c[aB+69704>>2]=aw;c[aB+135240>>2]=aw;c[aB+4172>>2]=ax;c[aB+69708>>2]=ax;c[aB+135244>>2]=ax;c[aB+4176>>2]=n;c[aB+69712>>2]=n;c[aB+135248>>2]=n;c[aB+4180>>2]=J;c[aB+69716>>2]=J;c[aB+135252>>2]=J;c[aB+4184>>2]=aw;c[aB+69720>>2]=aw;c[aB+135256>>2]=aw;c[aB+4188>>2]=ax;c[aB+69724>>2]=ax;c[aB+135260>>2]=ax;c[aB+4192>>2]=n;c[aB+69728>>2]=n;c[aB+135264>>2]=n;c[aB+4196>>2]=J;c[aB+69732>>2]=J;c[aB+135268>>2]=J;c[aB+4200>>2]=aw;c[aB+69736>>2]=aw;c[aB+135272>>2]=aw;c[aB+4204>>2]=ax;c[aB+69740>>2]=ax;c[aB+135276>>2]=ax;c[aB+4208>>2]=n;c[aB+69744>>2]=n;c[aB+135280>>2]=n;c[aB+4212>>2]=J;c[aB+69748>>2]=J;c[aB+135284>>2]=J;c[aB+4216>>2]=aw;c[aB+69752>>2]=aw;c[aB+135288>>2]=aw;c[aB+4220>>2]=ax;c[aB+69756>>2]=ax;c[aB+135292>>2]=ax;c[aB+4224>>2]=n;c[aB+69760>>2]=n;c[aB+135296>>2]=n;c[aB+4228>>2]=J;c[aB+69764>>2]=J;c[aB+135300>>2]=J;c[aB+4232>>2]=aw;c[aB+69768>>2]=aw;c[aB+135304>>2]=aw;c[aB+4236>>2]=ax;c[aB+69772>>2]=ax;c[aB+135308>>2]=ax;c[aB+4240>>2]=n;c[aB+69776>>2]=n;c[aB+135312>>2]=n;c[aB+4244>>2]=J;c[aB+69780>>2]=J;c[aB+135316>>2]=J;c[aB+4248>>2]=aw;c[aB+69784>>2]=aw;c[aB+135320>>2]=aw;c[aB+4252>>2]=ax;c[aB+69788>>2]=ax;c[aB+135324>>2]=ax;c[aB+4256>>2]=n;c[aB+69792>>2]=n;c[aB+135328>>2]=n;c[aB+4260>>2]=J;c[aB+69796>>2]=J;c[aB+135332>>2]=J;c[aB+4264>>2]=aw;c[aB+69800>>2]=aw;c[aB+135336>>2]=aw;c[aB+4268>>2]=ax;c[aB+69804>>2]=ax;c[aB+135340>>2]=ax;c[aB+4272>>2]=n;c[aB+69808>>2]=n;c[aB+135344>>2]=n;c[aB+4276>>2]=J;c[aB+69812>>2]=J;c[aB+135348>>2]=J;c[aB+4280>>2]=aw;c[aB+69816>>2]=aw;c[aB+135352>>2]=aw;c[aB+4284>>2]=ax;c[aB+69820>>2]=ax;c[aB+135356>>2]=ax;c[aB+4288>>2]=n;c[aB+69824>>2]=n;c[aB+135360>>2]=n;c[aB+4292>>2]=J;c[aB+69828>>2]=J;c[aB+135364>>2]=J;c[aB+4296>>2]=aw;c[aB+69832>>2]=aw;c[aB+135368>>2]=aw;c[aB+4300>>2]=ax;c[aB+69836>>2]=ax;c[aB+135372>>2]=ax;c[aB+4304>>2]=n;c[aB+69840>>2]=n;c[aB+135376>>2]=n;c[aB+4308>>2]=J;c[aB+69844>>2]=J;c[aB+135380>>2]=J;c[aB+4312>>2]=aw;c[aB+69848>>2]=aw;c[aB+135384>>2]=aw;c[aB+4316>>2]=ax;c[aB+69852>>2]=ax;c[aB+135388>>2]=ax;c[aB+4320>>2]=n;c[aB+69856>>2]=n;c[aB+135392>>2]=n;c[aB+4324>>2]=J;c[aB+69860>>2]=J;c[aB+135396>>2]=J;c[aB+4328>>2]=aw;c[aB+69864>>2]=aw;c[aB+135400>>2]=aw;c[aB+4332>>2]=ax;c[aB+69868>>2]=ax;c[aB+135404>>2]=ax;c[aB+4336>>2]=n;c[aB+69872>>2]=n;c[aB+135408>>2]=n;c[aB+4340>>2]=J;c[aB+69876>>2]=J;c[aB+135412>>2]=J;c[aB+4344>>2]=aw;c[aB+69880>>2]=aw;c[aB+135416>>2]=aw;c[aB+4348>>2]=ax;c[aB+69884>>2]=ax;c[aB+135420>>2]=ax;ax=c[3532484]|0;c[aB+4608>>2]=ax;c[aB+70144>>2]=ax;c[aB+135680>>2]=ax;aw=ax+1024|0;c[aB+4612>>2]=aw;c[aB+70148>>2]=aw;c[aB+135684>>2]=aw;aw=ax+2048|0;c[aB+4616>>2]=aw;c[aB+70152>>2]=aw;c[aB+135688>>2]=aw;aw=ax+3072|0;c[aB+4620>>2]=aw;c[aB+70156>>2]=aw;c[aB+135692>>2]=aw;aw=ax+4096|0;c[aB+4624>>2]=aw;c[aB+70160>>2]=aw;c[aB+135696>>2]=aw;aw=ax+5120|0;c[aB+4628>>2]=aw;c[aB+70164>>2]=aw;c[aB+135700>>2]=aw;aw=ax+6144|0;c[aB+4632>>2]=aw;c[aB+70168>>2]=aw;c[aB+135704>>2]=aw;aw=ax+7168|0;c[aB+4636>>2]=aw;c[aB+70172>>2]=aw;c[aB+135708>>2]=aw;aw=ax+8192|0;c[aB+4640>>2]=aw;c[aB+70176>>2]=aw;c[aB+135712>>2]=aw;aw=ax+9216|0;c[aB+4644>>2]=aw;c[aB+70180>>2]=aw;c[aB+135716>>2]=aw;aw=ax+10240|0;c[aB+4648>>2]=aw;c[aB+70184>>2]=aw;c[aB+135720>>2]=aw;aw=ax+11264|0;c[aB+4652>>2]=aw;c[aB+70188>>2]=aw;c[aB+135724>>2]=aw;aw=ax+12288|0;c[aB+4656>>2]=aw;c[aB+70192>>2]=aw;c[aB+135728>>2]=aw;aw=ax+13312|0;c[aB+4660>>2]=aw;c[aB+70196>>2]=aw;c[aB+135732>>2]=aw;aw=ax+14336|0;c[aB+4664>>2]=aw;c[aB+70200>>2]=aw;c[aB+135736>>2]=aw;aw=ax+15360|0;c[aB+4668>>2]=aw;c[aB+70204>>2]=aw;c[aB+135740>>2]=aw;aw=c[3532444]|0;ax=c[2112932]|0;J=ax+8192|0;n=2097152;while(1){c[J>>2]=aw+(n-2097152);q=n+1024|0;if(q>>>0>2621439){break}else{J=J+4|0;n=q}}n=c[3532470]|0;J=ax+10688|0;aw=2736128;while(1){q=n+(aw-2736128)|0;c[J>>2]=q;c[J+65536>>2]=q;c[J+131072>>2]=q;q=aw+1024|0;if(q>>>0>2768895){break}else{J=J+4|0;aw=q}}aw=c[3532456]|0;c[ax+11968>>2]=aw;c[ax+77504>>2]=aw;c[ax+143040>>2]=aw;J=aw+1024|0;c[ax+11972>>2]=J;c[ax+77508>>2]=J;c[ax+143044>>2]=J;n=aw+2048|0;c[ax+11976>>2]=n;c[ax+77512>>2]=n;c[ax+143048>>2]=n;q=aw+3072|0;c[ax+11980>>2]=q;c[ax+77516>>2]=q;c[ax+143052>>2]=q;c[ax+11984>>2]=aw;c[ax+77520>>2]=aw;c[ax+143056>>2]=aw;c[ax+11988>>2]=J;c[ax+77524>>2]=J;c[ax+143060>>2]=J;c[ax+11992>>2]=n;c[ax+77528>>2]=n;c[ax+143064>>2]=n;c[ax+11996>>2]=q;c[ax+77532>>2]=q;c[ax+143068>>2]=q;q=c[3532556]|0;c[ax+65344>>2]=q;c[ax+130880>>2]=q;c[ax+196416>>2]=q;n=q+1024|0;c[ax+65348>>2]=n;c[ax+130884>>2]=n;c[ax+196420>>2]=n;J=q+2048|0;c[ax+65352>>2]=J;c[ax+130888>>2]=J;c[ax+196424>>2]=J;aw=q+3072|0;c[ax+65356>>2]=aw;c[ax+130892>>2]=aw;c[ax+196428>>2]=aw;s=q+4096|0;c[ax+65360>>2]=s;c[ax+130896>>2]=s;c[ax+196432>>2]=s;m=q+5120|0;c[ax+65364>>2]=m;c[ax+130900>>2]=m;c[ax+196436>>2]=m;B=q+6144|0;c[ax+65368>>2]=B;c[ax+130904>>2]=B;c[ax+196440>>2]=B;k=q+7168|0;c[ax+65372>>2]=k;c[ax+130908>>2]=k;c[ax+196444>>2]=k;p=q+8192|0;c[ax+65376>>2]=p;c[ax+130912>>2]=p;c[ax+196448>>2]=p;K=q+9216|0;c[ax+65380>>2]=K;c[ax+130916>>2]=K;c[ax+196452>>2]=K;r=q+10240|0;c[ax+65384>>2]=r;c[ax+130920>>2]=r;c[ax+196456>>2]=r;aC=q+11264|0;c[ax+65388>>2]=aC;c[ax+130924>>2]=aC;c[ax+196460>>2]=aC;aD=q+12288|0;c[ax+65392>>2]=aD;c[ax+130928>>2]=aD;c[ax+196464>>2]=aD;aE=q+13312|0;c[ax+65396>>2]=aE;c[ax+130932>>2]=aE;c[ax+196468>>2]=aE;aF=q+14336|0;c[ax+65400>>2]=aF;c[ax+130936>>2]=aF;c[ax+196472>>2]=aF;aG=q+15360|0;c[ax+65404>>2]=aG;c[ax+130940>>2]=aG;c[ax+196476>>2]=aG;aH=c[3532558]|0;aI=ax+65408|0;aJ=16744448;while(1){aK=aH+(aJ-16744448)|0;c[aI>>2]=aK;c[aI+65536>>2]=aK;c[aI+131072>>2]=aK;aK=aJ+1024|0;if(aK>>>0>16777215){break}else{aI=aI+4|0;aJ=aK}}c[ax+65472>>2]=q;c[ax+131008>>2]=q;c[ax+196544>>2]=q;c[ax+65476>>2]=n;c[ax+131012>>2]=n;c[ax+196548>>2]=n;c[ax+65480>>2]=J;c[ax+131016>>2]=J;c[ax+196552>>2]=J;c[ax+65484>>2]=aw;c[ax+131020>>2]=aw;c[ax+196556>>2]=aw;c[ax+65488>>2]=s;c[ax+131024>>2]=s;c[ax+196560>>2]=s;c[ax+65492>>2]=m;c[ax+131028>>2]=m;c[ax+196564>>2]=m;c[ax+65496>>2]=B;c[ax+131032>>2]=B;c[ax+196568>>2]=B;c[ax+65500>>2]=k;c[ax+131036>>2]=k;c[ax+196572>>2]=k;c[ax+65504>>2]=p;c[ax+131040>>2]=p;c[ax+196576>>2]=p;c[ax+65508>>2]=K;c[ax+131044>>2]=K;c[ax+196580>>2]=K;c[ax+65512>>2]=r;c[ax+131048>>2]=r;c[ax+196584>>2]=r;c[ax+65516>>2]=aC;c[ax+131052>>2]=aC;c[ax+196588>>2]=aC;c[ax+65520>>2]=aD;c[ax+131056>>2]=aD;c[ax+196592>>2]=aD;c[ax+65524>>2]=aE;c[ax+131060>>2]=aE;c[ax+196596>>2]=aE;c[ax+65528>>2]=aF;c[ax+131064>>2]=aF;c[ax+196600>>2]=aF;c[ax+65532>>2]=aG;c[ax+131068>>2]=aG;c[ax+196604>>2]=aG;c[ax+196848>>2]=3968;c[ax+196688>>2]=2084;c[ax+196728>>2]=1488;c[ax+196608>>2]=654;c[ax+196648>>2]=2514;aJ=c[2394]|0;aI=c[14130368+(aJ<<2)>>2]|0;if((aI|0)!=0){gGC(aI|0,9104152,280)|0}c[8452240+(aJ<<2)>>2]=c[2113054];c[2394]=-1;fxU(1,425984);if((c[2394]|0)==1){aL=c[2112932]|0}else{c[2394]=1;aJ=c[3532597]|0;c[2112932]=aJ;aI=c[3532593]|0;if((aI|0)!=0){gGC(9104152,aI|0,280)|0}c[2113054]=c[2113061];aL=aJ}aJ=c[3532444]|0;aI=aL|0;aH=0;while(1){aK=aJ+aH|0;c[aI>>2]=aK;c[aI+131072>>2]=aK;aK=aH+1024|0;if(aK>>>0>524287){break}else{aI=aI+4|0;aH=aK}}aH=c[3532470]|0;aI=aL+2496|0;ax=638976;while(1){aG=aH+(ax-638976)|0;c[aI>>2]=aG;c[aI+65536>>2]=aG;c[aI+131072>>2]=aG;aG=ax+1024|0;if(aG>>>0>671743){break}else{aI=aI+4|0;ax=aG}}ax=c[3532456]|0;c[aL+3776>>2]=ax;c[aL+69312>>2]=ax;c[aL+134848>>2]=ax;aI=ax+1024|0;c[aL+3780>>2]=aI;c[aL+69316>>2]=aI;c[aL+134852>>2]=aI;aG=ax+2048|0;c[aL+3784>>2]=aG;c[aL+69320>>2]=aG;c[aL+134856>>2]=aG;aF=ax+3072|0;c[aL+3788>>2]=aF;c[aL+69324>>2]=aF;c[aL+134860>>2]=aF;aE=aL+8192|0;aD=2097152;while(1){aC=aJ+(aD-2097152)|0;c[aE>>2]=aC;c[aE+131072>>2]=aC;aC=aD+1024|0;if(aC>>>0>2621439){break}else{aE=aE+4|0;aD=aC}}aD=aL+10688|0;aE=2736128;while(1){aJ=aH+(aE-2736128)|0;c[aD>>2]=aJ;c[aD+65536>>2]=aJ;c[aD+131072>>2]=aJ;aJ=aE+1024|0;if(aJ>>>0>2768895){break}else{aD=aD+4|0;aE=aJ}}c[aL+11968>>2]=ax;c[aL+77504>>2]=ax;c[aL+143040>>2]=ax;c[aL+11972>>2]=aI;c[aL+77508>>2]=aI;c[aL+143044>>2]=aI;c[aL+11976>>2]=aG;c[aL+77512>>2]=aG;c[aL+143048>>2]=aG;c[aL+11980>>2]=aF;c[aL+77516>>2]=aF;c[aL+143052>>2]=aF;c[aL+196688>>2]=1768;c[aL+196728>>2]=1426;c[aL+196608>>2]=3468;c[aL+196648>>2]=754;aE=c[3532593]|0;if((aE|0)!=0){gGC(aE|0,9104152,280)|0}c[2113061]=c[2113054];c[2394]=-1;aE=(c[3532510]|0)==0;fwR(0);aD=c[2439330]|0;aH=(aD|0)==0;if(!aH){aJ=aD;gGC(9706056,aJ|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];aJ=c[3528484]|0;c[2076596]=aJ;aC=c[2417276]|0;c[3541536]=aC;c[1836236]=0;if(aE){aE=c[3532330]|0;r=0;K=0;while(1){c[aD+76+(K<<2)>>2]=aE+(K<<8);p=r+1&65535;if((p&65535)>223){aM=0;aN=0;break}else{r=p;K=p&65535}}while(1){K=aE+(aN<<8)|0;c[aD+76+(aN+512<<2)>>2]=K;c[aD+76+(aN+768<<2)>>2]=K;K=aM+1&65535;if((K&65535)>223){break}else{aM=K;aN=K&65535}}aE=c[3532334]|0;c[aD+1068>>2]=aE;K=aE+256|0;c[aD+1072>>2]=K;r=aE+512|0;c[aD+1076>>2]=r;aF=aE+768|0;c[aD+1080>>2]=aF;aG=aE+1024|0;c[aD+1084>>2]=aG;aI=aE+1280|0;c[aD+1088>>2]=aI;ax=aE+1536|0;c[aD+1092>>2]=ax;p=aE+1792|0;c[aD+1096>>2]=p;c[aD+2092>>2]=aE;c[aD+2096>>2]=K;c[aD+2100>>2]=r;c[aD+2104>>2]=aF;c[aD+2108>>2]=aG;c[aD+2112>>2]=aI;c[aD+2116>>2]=ax;c[aD+2120>>2]=p;c[aD+3116>>2]=aE;c[aD+4140>>2]=aE;c[aD+3120>>2]=K;c[aD+4144>>2]=K;c[aD+3124>>2]=r;c[aD+4148>>2]=r;c[aD+3128>>2]=aF;c[aD+4152>>2]=aF;c[aD+3132>>2]=aG;c[aD+4156>>2]=aG;c[aD+3136>>2]=aI;c[aD+4160>>2]=aI;c[aD+3140>>2]=ax;c[aD+4164>>2]=ax;c[aD+3144>>2]=p;c[aD+4168>>2]=p;c[aD+4180>>2]=3084;c[aD+4184>>2]=150;c[aD+4172>>2]=2728;c[aD+4176>>2]=456;if(!aH){p=aD;gGC(p|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=aJ;c[2417276]=aC}else{gu[c[3532510]&16383]();p=c[1836236]|0;ax=c[9757320+(p<<2)>>2]|0;if((ax|0)!=0){aI=ax;gGC(aI|0,9706056,76)|0}c[9752472+(p<<2)>>2]=c[2433530];c[14113936+(p<<2)>>2]=c[2076596];c[9669104+(p<<2)>>2]=c[3541536]}c[1836236]=-1;if((c[3532326]|0)!=0){fwR(1);p=c[2439331]|0;aI=(p|0)==0;if(!aI){ax=p;gGC(9706056,ax|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];ax=c[3528485]|0;c[2076596]=ax;aG=c[2417277]|0;c[3541536]=aG;c[1836236]=1;aF=c[3532328]|0;r=0;K=0;while(1){c[p+76+(K<<2)>>2]=aF+(K<<8);aE=r+1&65535;if((aE&65535)>239){aO=0;aP=0;break}else{r=aE;K=aE&65535}}while(1){K=aF+(aP<<8)|0;c[p+76+(aP+512<<2)>>2]=K;c[p+76+(aP+768<<2)>>2]=K;K=aO+1&65535;if((K&65535)>239){break}else{aO=K;aP=K&65535}}aF=c[3532332]|0;c[p+1068>>2]=aF;K=aF+256|0;c[p+1072>>2]=K;r=aF+512|0;c[p+1076>>2]=r;aC=aF+768|0;c[p+1080>>2]=aC;aJ=aF+1024|0;c[p+1084>>2]=aJ;aD=aF+1280|0;c[p+1088>>2]=aD;aH=aF+1536|0;c[p+1092>>2]=aH;aE=aF+1792|0;c[p+1096>>2]=aE;c[p+2092>>2]=aF;c[p+2096>>2]=K;c[p+2100>>2]=r;c[p+2104>>2]=aC;c[p+2108>>2]=aJ;c[p+2112>>2]=aD;c[p+2116>>2]=aH;c[p+2120>>2]=aE;c[p+3116>>2]=aF;c[p+4140>>2]=aF;c[p+3120>>2]=K;c[p+4144>>2]=K;c[p+3124>>2]=r;c[p+4148>>2]=r;c[p+3128>>2]=aC;c[p+4152>>2]=aC;c[p+3132>>2]=aJ;c[p+4156>>2]=aJ;c[p+3136>>2]=aD;c[p+4160>>2]=aD;c[p+3140>>2]=aH;c[p+4164>>2]=aH;c[p+3144>>2]=aE;c[p+4168>>2]=aE;c[p+4180>>2]=3002;c[p+4184>>2]=478;c[p+4172>>2]=2706;if(!aI){aE=p;gGC(aE|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=ax;c[2417277]=aG;c[1836236]=-1}aE=a[9680]|0;aH=aE?32e3:0;if(aE){if(a[9624]|0){aE=aH*3|0;aD=62500;while(1){if((aD|0)>(aE|0)){aD=aD>>1}else{aQ=1222;aR=aD;break}}}else{aQ=2462;aR=aH}c[2429380]=aR;c[3542124]=aQ;mw(4e6,aR);aD=gGq(262144)|0;c[2406684]=aD;gGz(aD|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(4e6,11025)}c[(c[3531464]|0)+44344>>2]=1290;h[745421]=.43;c[2436794]=1;h[745420]=.43;c[2436792]=2;aD=c[3532496]|0;if((aD|0)!=0){Vi(0,4e6,12,c[3532500]|0,aD);aD=c[2424876]|0;h[aD+2080>>3]=1.0;c[aD+2096>>2]=1;h[aD+2088>>3]=1.0;c[aD+2100>>2]=2}aD=c[3532502]|0;if((aD|0)!=0){Vi(1,4e6,12,c[3532506]|0,aD);aD=c[2424877]|0;h[aD+2080>>3]=1.0;c[aD+2096>>2]=1;h[aD+2088>>3]=1.0;c[aD+2100>>2]=2}c[3532464]=5888;c[3532462]=5920;c[3532460]=6016;a[7461536]=1;a[7461544]=1;a[7461520]=1;c[3532366]=4096;eOU(0);aS=c[(c[642608+(c[2436]<<2)>>2]|0)+60>>2]|0}else{aS=aA}do{if((aS&-65536|0)==33685504){fxU(0,425984);if((c[2394]|0)==0){aT=c[2112932]|0}else{c[2394]=0;aD=c[3532596]|0;c[2112932]=aD;aE=c[3532592]|0;if((aE|0)!=0){gGC(9104152,aE|0,280)|0}c[2113054]=c[2113060];aT=aD}aD=c[3532446]|0;aE=aT|0;aG=aE;ax=0;while(1){c[aG>>2]=aD+ax;p=ax+1024|0;if(p>>>0>524287){break}else{aG=aG+4|0;ax=p}}ax=c[3532552]|0;aG=aE;aD=0;while(1){c[aG+131072>>2]=ax+aD;f=aD+1024|0;if(f>>>0>524287){break}else{aG=aG+4|0;aD=f}}aD=c[3532470]|0;aG=aT+3072|0;ax=786432;while(1){aE=aD+(ax-786432)|0;c[aG>>2]=aE;c[aG+65536>>2]=aE;c[aG+131072>>2]=aE;aE=ax+1024|0;if(aE>>>0>851967){break}else{aG=aG+4|0;ax=aE}}ax=c[3532542]|0;aG=aT+65280|0;aD=16711680;while(1){aE=ax+(aD-16711680)|0;c[aG>>2]=aE;c[aG+65536>>2]=aE;c[aG+131072>>2]=aE;aE=aD+1024|0;if(aE>>>0>16777215){break}else{aG=aG+4|0;aD=aE}}c[aT+196688>>2]=2508;c[aT+196728>>2]=3112;c[aT+196608>>2]=792;c[aT+196648>>2]=1100;aD=c[3532592]|0;if((aD|0)!=0){gGC(aD|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fxU(1,425984);if((c[2394]|0)==1){aU=c[2112932]|0}else{c[2394]=1;aD=c[3532597]|0;c[2112932]=aD;aG=c[3532593]|0;if((aG|0)!=0){gGC(9104152,aG|0,280)|0}c[2113054]=c[2113061];aU=aD}aD=c[3532444]|0;aG=aU|0;ax=0;while(1){aE=aD+ax|0;c[aG>>2]=aE;c[aG+131072>>2]=aE;aE=ax+1024|0;if(aE>>>0>262143){break}else{aG=aG+4|0;ax=aE}}ax=c[3532470]|0;aG=aU+3072|0;aD=786432;while(1){aE=ax+(aD-786432)|0;c[aG>>2]=aE;c[aG+65536>>2]=aE;c[aG+131072>>2]=aE;aE=aD+1024|0;if(aE>>>0>851967){break}else{aG=aG+4|0;aD=aE}}aD=c[3532388]|0;aG=aU+6144|0;ax=1572864;while(1){aE=aD+(ax-1572864)|0;c[aG>>2]=aE;c[aG+65536>>2]=aE;c[aG+131072>>2]=aE;aE=ax+1024|0;if(aE>>>0>1638399){break}else{aG=aG+4|0;ax=aE}}ax=c[3532540]|0;aG=aU+65280|0;aD=16711680;while(1){aE=ax+(aD-16711680)|0;c[aG>>2]=aE;c[aG+65536>>2]=aE;c[aG+131072>>2]=aE;aE=aD+1024|0;if(aE>>>0>16760831){break}else{aG=aG+4|0;aD=aE}}aD=c[3532558]|0;c[aU+65472>>2]=aD;c[aU+131008>>2]=aD;c[aU+196544>>2]=aD;aG=aD+1024|0;c[aU+65476>>2]=aG;c[aU+131012>>2]=aG;c[aU+196548>>2]=aG;aG=aD+2048|0;c[aU+65480>>2]=aG;c[aU+131016>>2]=aG;c[aU+196552>>2]=aG;aG=aD+3072|0;c[aU+65484>>2]=aG;c[aU+131020>>2]=aG;c[aU+196556>>2]=aG;aG=aD+4096|0;c[aU+65488>>2]=aG;c[aU+131024>>2]=aG;c[aU+196560>>2]=aG;aG=aD+5120|0;c[aU+65492>>2]=aG;c[aU+131028>>2]=aG;c[aU+196564>>2]=aG;aG=aD+6144|0;c[aU+65496>>2]=aG;c[aU+131032>>2]=aG;c[aU+196568>>2]=aG;aG=aD+7168|0;c[aU+65500>>2]=aG;c[aU+131036>>2]=aG;c[aU+196572>>2]=aG;aG=aD+8192|0;c[aU+65504>>2]=aG;c[aU+131040>>2]=aG;c[aU+196576>>2]=aG;aG=aD+9216|0;c[aU+65508>>2]=aG;c[aU+131044>>2]=aG;c[aU+196580>>2]=aG;aG=aD+10240|0;c[aU+65512>>2]=aG;c[aU+131048>>2]=aG;c[aU+196584>>2]=aG;aG=aD+11264|0;c[aU+65516>>2]=aG;c[aU+131052>>2]=aG;c[aU+196588>>2]=aG;aG=aD+12288|0;c[aU+65520>>2]=aG;c[aU+131056>>2]=aG;c[aU+196592>>2]=aG;aG=aD+13312|0;c[aU+65524>>2]=aG;c[aU+131060>>2]=aG;c[aU+196596>>2]=aG;aG=aD+14336|0;c[aU+65528>>2]=aG;c[aU+131064>>2]=aG;c[aU+196600>>2]=aG;aG=aD+15360|0;c[aU+65532>>2]=aG;c[aU+131068>>2]=aG;c[aU+196604>>2]=aG;c[aU+196688>>2]=1684;c[aU+196728>>2]=2208;aG=c[3532593]|0;if((aG|0)!=0){gGC(aG|0,9104152,280)|0}c[2113061]=c[2113054];c[2394]=-1;fxU(2,425984);if((c[2394]|0)==2){aV=c[2112932]|0}else{c[2394]=2;aG=c[3532598]|0;c[2112932]=aG;aD=c[3532594]|0;if((aD|0)!=0){gGC(9104152,aD|0,280)|0}c[2113054]=c[2113062];aV=aG}aG=c[3532438]|0;aD=aV|0;ax=0;while(1){aE=aG+ax|0;c[aD>>2]=aE;c[aD+131072>>2]=aE;aE=ax+1024|0;if(aE>>>0>262143){break}else{aD=aD+4|0;ax=aE}}ax=c[3532470]|0;aD=aV+3072|0;aG=786432;while(1){aE=ax+(aG-786432)|0;c[aD>>2]=aE;c[aD+65536>>2]=aE;c[aD+131072>>2]=aE;aE=aG+1024|0;if(aE>>>0>851967){break}else{aD=aD+4|0;aG=aE}}aG=c[3532428]|0;c[aV+6144>>2]=aG;c[aV+71680>>2]=aG;c[aV+137216>>2]=aG;aD=aG+1024|0;c[aV+6148>>2]=aD;c[aV+71684>>2]=aD;c[aV+137220>>2]=aD;aD=c[3532390]|0;c[aV+6272>>2]=aD;c[aV+71808>>2]=aD;c[aV+137344>>2]=aD;aG=aD+1024|0;c[aV+6276>>2]=aG;c[aV+71812>>2]=aG;c[aV+137348>>2]=aG;aG=aD+2048|0;c[aV+6280>>2]=aG;c[aV+71816>>2]=aG;c[aV+137352>>2]=aG;aG=aD+3072|0;c[aV+6284>>2]=aG;c[aV+71820>>2]=aG;c[aV+137356>>2]=aG;aG=c[3532484]|0;c[aV+6400>>2]=aG;c[aV+71936>>2]=aG;c[aV+137472>>2]=aG;aD=aG+1024|0;c[aV+6404>>2]=aD;c[aV+71940>>2]=aD;c[aV+137476>>2]=aD;ax=aG+2048|0;c[aV+6408>>2]=ax;c[aV+71944>>2]=ax;c[aV+137480>>2]=ax;aE=aG+3072|0;c[aV+6412>>2]=aE;c[aV+71948>>2]=aE;c[aV+137484>>2]=aE;f=aG+4096|0;c[aV+6416>>2]=f;c[aV+71952>>2]=f;c[aV+137488>>2]=f;C=aG+5120|0;c[aV+6420>>2]=C;c[aV+71956>>2]=C;c[aV+137492>>2]=C;l=aG+6144|0;c[aV+6424>>2]=l;c[aV+71960>>2]=l;c[aV+137496>>2]=l;D=aG+7168|0;c[aV+6428>>2]=D;c[aV+71964>>2]=D;c[aV+137500>>2]=D;p=aG+8192|0;c[aV+6432>>2]=p;c[aV+71968>>2]=p;c[aV+137504>>2]=p;aI=aG+9216|0;c[aV+6436>>2]=aI;c[aV+71972>>2]=aI;c[aV+137508>>2]=aI;aJ=aG+10240|0;c[aV+6440>>2]=aJ;c[aV+71976>>2]=aJ;c[aV+137512>>2]=aJ;aC=aG+11264|0;c[aV+6444>>2]=aC;c[aV+71980>>2]=aC;c[aV+137516>>2]=aC;r=aG+12288|0;c[aV+6448>>2]=r;c[aV+71984>>2]=r;c[aV+137520>>2]=r;K=aG+13312|0;c[aV+6452>>2]=K;c[aV+71988>>2]=K;c[aV+137524>>2]=K;aF=aG+14336|0;c[aV+6456>>2]=aF;c[aV+71992>>2]=aF;c[aV+137528>>2]=aF;k=aG+15360|0;c[aV+6460>>2]=k;c[aV+71996>>2]=k;c[aV+137532>>2]=k;c[aV+6464>>2]=aG;c[aV+72e3>>2]=aG;c[aV+137536>>2]=aG;c[aV+6468>>2]=aD;c[aV+72004>>2]=aD;c[aV+137540>>2]=aD;c[aV+6472>>2]=ax;c[aV+72008>>2]=ax;c[aV+137544>>2]=ax;c[aV+6476>>2]=aE;c[aV+72012>>2]=aE;c[aV+137548>>2]=aE;c[aV+6480>>2]=f;c[aV+72016>>2]=f;c[aV+137552>>2]=f;c[aV+6484>>2]=C;c[aV+72020>>2]=C;c[aV+137556>>2]=C;c[aV+6488>>2]=l;c[aV+72024>>2]=l;c[aV+137560>>2]=l;c[aV+6492>>2]=D;c[aV+72028>>2]=D;c[aV+137564>>2]=D;c[aV+6496>>2]=p;c[aV+72032>>2]=p;c[aV+137568>>2]=p;c[aV+6500>>2]=aI;c[aV+72036>>2]=aI;c[aV+137572>>2]=aI;c[aV+6504>>2]=aJ;c[aV+72040>>2]=aJ;c[aV+137576>>2]=aJ;c[aV+6508>>2]=aC;c[aV+72044>>2]=aC;c[aV+137580>>2]=aC;c[aV+6512>>2]=r;c[aV+72048>>2]=r;c[aV+137584>>2]=r;c[aV+6516>>2]=K;c[aV+72052>>2]=K;c[aV+137588>>2]=K;c[aV+6520>>2]=aF;c[aV+72056>>2]=aF;c[aV+137592>>2]=aF;c[aV+6524>>2]=k;c[aV+72060>>2]=k;c[aV+137596>>2]=k;k=c[3532538]|0;aF=aV+65280|0;K=16711680;while(1){r=k+(K-16711680)|0;c[aF>>2]=r;c[aF+65536>>2]=r;c[aF+131072>>2]=r;r=K+1024|0;if(r>>>0>16777215){break}else{aF=aF+4|0;K=r}}c[aV+196688>>2]=2584;c[aV+196728>>2]=3424;c[aV+196608>>2]=3294;K=c[3532594]|0;if((K|0)!=0){gGC(K|0,9104152,280)|0}c[2113062]=c[2113054];c[2394]=-1;K=(c[3532510]|0)==0;fwR(0);aF=c[2439330]|0;k=(aF|0)==0;if(!k){r=aF;gGC(9706056,r|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];r=c[3528484]|0;c[2076596]=r;aC=c[2417276]|0;c[3541536]=aC;c[1836236]=0;if(K){K=c[3532330]|0;aJ=0;aI=0;while(1){c[aF+76+(aI<<2)>>2]=K+(aI<<8);p=aJ+1&65535;if((p&65535)>223){aW=0;aX=0;break}else{aJ=p;aI=p&65535}}while(1){aI=K+(aX<<8)|0;c[aF+76+(aX+512<<2)>>2]=aI;c[aF+76+(aX+768<<2)>>2]=aI;aI=aW+1&65535;if((aI&65535)>223){break}else{aW=aI;aX=aI&65535}}K=c[3532334]|0;c[aF+1068>>2]=K;aI=K+256|0;c[aF+1072>>2]=aI;aJ=K+512|0;c[aF+1076>>2]=aJ;p=K+768|0;c[aF+1080>>2]=p;D=K+1024|0;c[aF+1084>>2]=D;l=K+1280|0;c[aF+1088>>2]=l;C=K+1536|0;c[aF+1092>>2]=C;f=K+1792|0;c[aF+1096>>2]=f;c[aF+2092>>2]=K;c[aF+2096>>2]=aI;c[aF+2100>>2]=aJ;c[aF+2104>>2]=p;c[aF+2108>>2]=D;c[aF+2112>>2]=l;c[aF+2116>>2]=C;c[aF+2120>>2]=f;c[aF+3116>>2]=K;c[aF+4140>>2]=K;c[aF+3120>>2]=aI;c[aF+4144>>2]=aI;c[aF+3124>>2]=aJ;c[aF+4148>>2]=aJ;c[aF+3128>>2]=p;c[aF+4152>>2]=p;c[aF+3132>>2]=D;c[aF+4156>>2]=D;c[aF+3136>>2]=l;c[aF+4160>>2]=l;c[aF+3140>>2]=C;c[aF+4164>>2]=C;c[aF+3144>>2]=f;c[aF+4168>>2]=f;c[aF+4180>>2]=3084;c[aF+4184>>2]=150;c[aF+4172>>2]=2728;c[aF+4176>>2]=456;if(!k){f=aF;gGC(f|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=r;c[2417276]=aC}else{gu[c[3532510]&16383]();f=c[1836236]|0;C=c[9757320+(f<<2)>>2]|0;if((C|0)!=0){l=C;gGC(l|0,9706056,76)|0}c[9752472+(f<<2)>>2]=c[2433530];c[14113936+(f<<2)>>2]=c[2076596];c[9669104+(f<<2)>>2]=c[3541536]}c[1836236]=-1;f=a[9680]|0;l=f?32e3:0;if(f){if(a[9624]|0){f=l*3|0;C=62921;while(1){if((C|0)>(f|0)){C=C>>1}else{aY=1222;aZ=C;break}}}else{aY=2462;aZ=l}c[2429380]=aZ;c[3542124]=aY;mw(4026987,aZ);C=gGq(262144)|0;c[2406684]=C;gGz(C|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(4026987,11025)}c[(c[3531464]|0)+44344>>2]=1290;h[745421]=.43;c[2436794]=1;h[745420]=.43;c[2436792]=2;C=c[3532496]|0;if((C|0)==0){break}Vi(0,4026987,16252941,c[3532500]|0,C);C=c[2424876]|0;h[C+2080>>3]=1.0;c[C+2096>>2]=1;h[C+2088>>3]=1.0;c[C+2100>>2]=2}}while(0);aH=c[642608+(c[2436]<<2)>>2]|0;C=c[aH+128>>2]|0;if((c[aH+52>>2]&4|0)==0){c[2113068]=C;f=c[aH+132>>2]|0;c[2113070]=f;c[2443814]=C;c[2440436]=f;a_=C;a$=f}else{c[2113070]=C;f=c[aH+132>>2]|0;c[2113068]=f;c[2440436]=C;c[2443814]=f;a_=f;a$=C}C=ag(a_<<1,a$)|0;f=gGq(C)|0;c[2112926]=f;if((f|0)!=0){gGz(f|0,0,C|0)}a[64248]=0;eOH();j=0;return j|0}}while(0);c[3541162]=0;j=1;return j|0}function eOy(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;b=c[3541162]|0;c[3532486]=2048;c[3532468]=16384;c[3532384]=2048;a[7461528]=0;a[7461608]=0;a[7461616]=0;d=c[642608+(c[2436]<<2)>>2]|0;e=c[d+60>>2]|0;f=e&-65536;g=(f|0)==33947648;h=g?2162688:65536;i=g?8192:2048;L30486:do{if((f|0)==34013184){j=c[d>>2]|0;do{if((fa(j|0,321496)|0)!=0){if((fa(j|0,312072)|0)==0){break}c[3532384]=4096;k=1;l=16384;m=16384;n=4096;break L30486}}while(0);c[3532468]=65536;k=1;l=65536;m=16384;n=2048}else{k=0;l=16384;m=0;n=2048}}while(0);do{if((f|0)==34078720){c[3532486]=4096;c[3532468]=32768;c[3532384]=4096;o=g;p=32768;q=32768;r=0;s=4096;t=0;u=4096;v=0;w=0;x=1;y=1}else{d=m;if((f|0)==33619968){c[3532486]=8192;c[3532468]=32768;c[3532384]=4096;a[7461608]=1;a[7461616]=1;o=g;p=32768;q=d;r=0;s=4096;t=0;u=8192;v=16384;w=16384;x=1;y=1;break}else{z=k;A=0;B=l;C=n;D=2048;E=0;F=d}if((f|0)!=33685504){o=g;p=B;q=F;r=0;s=C;t=0;u=D;v=E;w=E;x=A;y=z;break}c[3532486]=8192;c[3532468]=65536;c[3532384]=4096;a[7461608]=1;a[7461528]=1;o=1;p=65536;q=65536;r=65536;s=4096;t=2048;u=8192;v=16384;w=E;x=A;y=z}}while(0);z=(e&16384|0)==0;A=z?h:262144;if((e&32768|0)==0){G=p}else{c[3532468]=262144;G=262144}c[3532446]=b;p=c[3532430]|0;h=p>>>0>1048576?p:1048576;c[3532552]=b+h;p=h<<1;h=b+p|0;c[3532444]=h;if((c[3532440]|0)==0){H=h}else{H=b+(p+524288)|0}c[3532438]=H;p=(c[3532434]|0)==0?H:H+524288|0;c[3532330]=p;H=p+A|0;if((e&8|0)==0){I=H}else{c[3532336]=H;I=p+(A<<1)|0}c[3532328]=I;A=c[3532324]|0;c[3532322]=I+A;p=(c[3532318]|0)+A|0;c[3532316]=I+p;A=p+(c[3532312]|0)|0;c[3532578]=I+A;p=A+(c[3532574]|0)|0;c[3532584]=I+p;A=p+(c[3532580]|0)|0;c[3532348]=I+A;p=A+(c[3532344]|0)|0;c[3532500]=I+p;A=p+(c[3532496]|0)|0;c[3532506]=I+A;p=A+(c[3532502]|0)|0;A=I+p|0;c[3532474]=A;c[3532518]=A;A=p+(c[3532516]|0)|0;c[3532480]=I+A;p=A+(c[3532476]|0)|0;A=I+p|0;c[3532638]=A;c[3532470]=A;A=p+G|0;c[3532542]=I+A;G=A+(z?q:262144)|0;c[3532540]=I+G;q=G+r|0;c[3532538]=I+q;G=q+r|0;q=I+G|0;c[3532356]=q;z=(c[3532352]|0)==0;if(z){J=q}else{J=I+(G+65536)|0}c[3532368]=J;G=z?J:J+4096|0;c[3532390]=G;c[3532388]=G+s;J=r+s|0;c[3532428]=G+J;r=J+t|0;c[3532426]=G+r;J=r+t|0;if(x){c[3532386]=G+J}x=J+s|0;c[3532484]=G+x;s=(u<<1)+x|0;x=G+s|0;if(y){c[3532456]=x;c[3532454]=G+(s+4096);K=G+(s+8192)|0}else{K=x}c[3532558]=K;c[3532556]=K+v;x=w+v|0;c[3532334]=K+x;v=x+i|0;i=K+v|0;if((c[3532326]|0)==0){L=i}else{c[3532332]=i;L=K+(v+2048)|0}c[3532642]=L;c[3532350]=L;v=c[3532508]<<6;c[3532374]=L+v;K=v+(c[3532380]|0)|0;c[3532372]=L+K;v=K+(c[3532408]|0)|0;K=L+v|0;if(y){c[3532448]=K;M=L+(v+262144)|0}else{M=K}c[3532488]=M;K=(g?256:0)+(u*12|0)|0;if(!o){N=K+524288|0;O=M+N|0;c[3541160]=O;return}c[2112930]=M+K;N=K+524288|0;O=M+N|0;c[3541160]=O;return}function eOz(){return~~((a[9688]|0?534.0:0.0)*(+(~~+h[1214783]+(c[2429636]|0)-(c[2440608]|0)|0)/(4.0e5/(+(c[2424]|0)/100.0))))|0}function eOA(b){b=b|0;if((b|0)==0){return}if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12;return}function eOB(a){a=a|0;var b=0,d=0;b=(c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,8e6,0)|0;return a|0}function eOC(){return+(+((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)/8.0e6)}function eOD(b,c){b=b|0;c=c|0;a[9706117]=c&1;return}function eOE(a){a=a|0;var b=0,d=0;b=(c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,4e6,0)|0;return a|0}function eOF(){return+(+((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)/4.0e6)}function eOG(b){b=b|0;a[9706117]=(b|0)!=0|0;return}function eOH(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=(c[642608+(c[2436]<<2)>>2]|0)+60|0;e=c[d>>2]|0;if((e&8256|0)==0){f=c[2394]|0;g=e;i=(f|0)==0;j=f}else{eNM(256);eNP();f=c[3528544]|0;if((c[2394]|0)==(f|0)){k=c[2112932]|0;l=c[14130368+(f<<2)>>2]|0}else{c[2394]=f;e=c[14130384+(f<<2)>>2]|0;c[2112932]=e;m=c[14130368+(f<<2)>>2]|0;if((m|0)!=0){gGC(9104152,m|0,280)|0}c[2113054]=c[8452240+(f<<2)>>2];k=e;l=m}c[k+196860>>2]=11962;c[k+196852>>2]=2e3;c[k+196856>>2]=1134;if((l|0)!=0){gGC(l|0,9104152,280)|0}c[8452240+(f<<2)>>2]=c[2113054];c[2394]=-1;g=c[d>>2]|0;i=0;j=-1}if((g&16384|0)==0){if(!i){n=23273}}else{if(i){o=c[2112932]|0;p=j}else{c[2394]=0;j=c[3532596]|0;c[2112932]=j;i=c[3532592]|0;if((i|0)!=0){gGC(9104152,i|0,280)|0}c[2113054]=c[2113060];o=j;p=0}j=c[3532446]|0;i=o|0;o=0;while(1){g=j+o|0;c[i>>2]=g;c[i+131072>>2]=g;g=o+1024|0;if(g>>>0>1048575){break}else{i=i+4|0;o=g}}o=c[14130368+(p<<2)>>2]|0;if((o|0)!=0){gGC(o|0,9104152,280)|0}c[8452240+(p<<2)>>2]=c[2113054];c[2394]=-1;n=23273}if((n|0)==23273){c[2394]=0;c[2112932]=c[3532596];p=c[3532592]|0;if((p|0)!=0){gGC(9104152,p|0,280)|0}c[2113054]=c[2113060]}RI();p=c[2394]|0;o=c[14130368+(p<<2)>>2]|0;if((o|0)!=0){gGC(o|0,9104152,280)|0}c[8452240+(p<<2)>>2]=c[2113054];c[2394]=-1;p=c[(c[642608+(c[2436]<<2)>>2]|0)+60>>2]|0;o=p&-65536;do{if((o|0)==34078720|(o|0)==33619968|(o|0)==34013184|(o|0)==33685504){c[2394]=1;c[2112932]=c[3532597];i=c[3532593]|0;if((i|0)!=0){gGC(9104152,i|0,280)|0}c[2113054]=c[2113061];RI();i=c[2394]|0;j=c[14130368+(i<<2)>>2]|0;if((j|0)!=0){gGC(j|0,9104152,280)|0}c[8452240+(i<<2)>>2]=c[2113054];c[2394]=-1;c[2433318]=0;c[3532458]=0;c[3532560]=0;i=(c[642608+(c[2436]<<2)>>2]|0)+60|0;j=c[i>>2]|0;if((j&-65536|0)!=34078720){q=j;break}if(!(a[7461592]|0)){q=j;break}a[14130132]=1;q=c[i>>2]|0}else{q=p}}while(0);do{if((q&-65536|0)==33685504){c[2394]=2;c[2112932]=c[3532598];p=c[3532594]|0;if((p|0)!=0){gGC(9104152,p|0,280)|0}c[2113054]=c[2113062];RI();p=c[2394]|0;o=c[14130368+(p<<2)>>2]|0;if((o|0)!=0){gGC(o|0,9104152,280)|0}c[8452240+(p<<2)>>2]=c[2113054];c[2394]=-1;if(!(a[7461592]|0)){break}a[14130133]=1}}while(0);if((c[3532310]|0)==0){if((c[(c[642608+(c[2436]<<2)>>2]|0)+60>>2]&16384|0)!=0){n=23295}}else{n=23295}if((n|0)==23295){n=c[2439330]|0;q=(n|0)==0;if(!q){p=n;gGC(9706056,p|0,76)|0}p=c[2438118]|0;c[2433530]=p;o=c[3528484]|0;c[2076596]=o;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);if(!q){q=n;gGC(q|0,9706056,76)|0}c[2438118]=p;c[3528484]=o;c[2417276]=i;c[1836236]=-1}if((c[3532326]|0)!=0){i=c[2439331]|0;o=(i|0)==0;if(!o){p=i;gGC(9706056,p|0,76)|0}p=c[2438119]|0;c[2433530]=p;q=c[3528485]|0;c[2076596]=q;n=c[2417277]|0;c[3541536]=n;c[1836236]=1;gGz(9706056,0,76);if(!o){o=i;gGC(o|0,9706056,76)|0}c[2438119]=p;c[3528485]=q;c[2417277]=n;c[1836236]=-1}if((c[3532574]|0)!=0){b[4859110]=0;a[9718225]=0;a[9718224]=0;a[9718226]=8;a[9718229]=-1;a[9718230]=-1;a[9718227]=0;a[9718237]=0;a[9718236]=0;a[9718249]=0;a[9718238]=0;gGz(9718242,0,6);n=c[2405758]|0;if((n|0)>0){q=0;do{c[9542560+(q<<5)>>2]=0;b[9542544+(q<<5)>>1]=0;q=q+1|0;}while((q|0)<(n|0))}a[9773128]=0;c[2437628]=0}if((c[3532344]|0)!=0){Vl();c[2430046]=0}n=c[(c[642608+(c[2436]<<2)>>2]|0)+60>>2]|0;L30635:do{if((n&-65536|0)==33947648){c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385512]|0)>0){q=0;do{mc(q);q=q+1|0;}while((q|0)<(c[2385512]|0))}gGz((c[2420422]|0)+99|0,-1|0,65536)}else{if((n&256|0)!=0){c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){r=0}else{break}while(1){lN(r);mB(r);r=r+1|0;if((r|0)>=(c[2385508]|0)){break L30635}}}if((n&4096|0)==0){mx(0);break}else{mr(c[3540990]|0);break}}}while(0);gGz(14129960,0,16);gGz(14129672,0,16);gGz(14129656,0,16);c[3542204]=0;c[3542202]=0;n=(c[642608+(c[2436]<<2)>>2]|0)+60|0;r=c[n>>2]&4;q=(r|0)==0;c[3532392]=0;c[3532393]=q?1:255;c[3532394]=q?2:255;c[3532395]=q?3:255;c[3532396]=q?4:255;c[3532397]=q?5:255;c[3532398]=q?6:255;c[3532399]=r^7;c[3532400]=q?8:255;c[3532401]=q?9:255;c[3532402]=q?10:255;c[3532403]=q?11:2;c[3532404]=q?12:255;c[3532405]=q?13:1;c[3532406]=q?14:0;c[3532407]=q?15:255;q=c[n>>2]&-65536;if(!((q|0)==33816576|(q|0)==33947648|(q|0)==34078720|(q|0)==33619968)){c[3532340]=0;c[3532306]=0;c[3532304]=0;a[14129368]=0;c[3532422]=0;c[3532412]=0;c[3532550]=0;c[3532424]=0;return}c[3532358]=0;c[3532359]=1;c[3532360]=2;c[3532361]=3;c[3532362]=4;c[3532363]=5;c[3532364]=6;c[3532365]=7;c[3532340]=0;c[3532306]=0;c[3532304]=0;a[14129368]=0;c[3532422]=0;c[3532412]=0;c[3532550]=0;c[3532424]=0;return}function eOI(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;if((c[2392]|0)>=0){b=0;do{d=14130368+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}d=14130384+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}b=b+1|0;}while((b|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;if((c[3532310]|0)==0){if((c[(c[642608+(c[2436]<<2)>>2]|0)+60>>2]&16384|0)!=0){f=23335}}else{f=23335}if((f|0)==23335){fwZ()}if((c[3532574]|0)!=0){b=c[2426620]|0;if((b|0)!=0){gGr(b);c[2426620]=0}c[2440608]=0;UT()}b=c[(c[642608+(c[2436]<<2)>>2]|0)+60>>2]|0;do{if((b&-65536|0)==33947648){d=c[3541512]|0;if((d|0)!=0){gGr(d|0);c[3541512]=0}c[2438228]=0;c[2433526]=0;c[2406676]=0;c[3528472]=0;d=c[2406692]|0;if((d|0)!=0){gGr(d);c[2406692]=0}c[2385512]=0;c[2432976]=0;d=c[2420378]|0;if((d|0)!=0){gGr(d);c[2420378]=0}d=c[2415138]|0;if((d|0)==0){break}gGr(d);c[2415138]=0}else{if((b&256|0)!=0){d=c[3541518]|0;if((d|0)!=0){gGr(d|0);c[3541518]=0}if((c[2385508]|0)>0){c[2113008]=0;c[2076598]=0;c[2383582]=0}c[2438228]=0;c[2433526]=0;c[2406676]=0;c[3528472]=0;d=c[2406680]|0;if((d|0)!=0){gGr(d);c[2406680]=0}c[2385508]=0;c[2432978]=0;a[64240]=0;break}if((b&4096|0)==0){d=c[3531464]|0;c[d+44344>>2]=0;c[d+44348>>2]=0;if((d|0)!=0){gGr(d);c[3531464]=0}d=c[2406684]|0;if((d|0)==0){break}gGr(d);c[2406684]=0;break}d=a[7460880]|0;if(d){e=0;g=d&1;while(1){d=14163960+(e<<2)|0;h=c[d>>2]|0;if((h|0)==0){i=g}else{j=c[2113004]|0;if((j|0)==0){f=23363}else{k=j-1|0;c[2113004]=k;if((k|0)==0){f=23363}}if((f|0)==23363){f=0;c[2383470]=0}gGr(h);i=a[7460880]&1}c[d>>2]=0;d=e+1|0;if((d|0)<(i|0)){e=d;g=i}else{break}}}a[7460880]=0;g=c[2406690]|0;if((g|0)==0){break}gGr(g);c[2406690]=0}}while(0);if((c[3532496]|0)!=0){if(((c[2385510]|0)+1|0)>0){i=0;do{b=9699504+(i<<2)|0;g=c[b>>2]|0;e=0;while(1){if((e|0)>=1024){break}l=9638528+(e<<2)|0;if((c[l>>2]|0)==(g|0)){f=23377;break}else{e=e+1|0}}if((f|0)==23377){f=0;gGr(g);c[l>>2]=0}c[b>>2]=0;e=9699192+(i<<2)|0;d=c[e>>2]|0;h=0;while(1){if((h|0)>=1024){break}m=9638528+(h<<2)|0;if((c[m>>2]|0)==(d|0)){f=23381;break}else{h=h+1|0}}if((f|0)==23381){f=0;gGr(d);c[m>>2]=0}c[e>>2]=0;h=9672656+(i<<2)|0;b=c[h>>2]|0;g=0;while(1){if((g|0)>=1024){break}n=9638528+(g<<2)|0;if((c[n>>2]|0)==(b|0)){f=23385;break}else{g=g+1|0}}if((f|0)==23385){f=0;gGr(b);c[n>>2]=0}c[h>>2]=0;i=i+1|0;}while((i|0)<((c[2385510]|0)+1|0))}c[2385510]=0}if((c[3532344]|0)!=0){i=c[2418506]|0;if((i|0)!=0){gGr(i);c[2418506]=0}i=c[2418507]|0;if((i|0)!=0){gGr(i);c[2418507]=0}a[635136]=0}i=c[(c[642608+(c[2436]<<2)>>2]|0)+60>>2]&-65536;if((i|0)==33751040|(i|0)==34013184|(i|0)==34078720){gGz(9668984,0,81);c[3540906]=0;c[3540904]=0;c[3540902]=0;c[3540900]=0;c[3540898]=0;c[3540896]=0;c[3540894]=0;c[3540892]=0;c[3540890]=0;c[3540888]=0;c[3540886]=0;c[3540884]=0;c[3540882]=0}if((c[2113302]|0)!=0){c[2113302]=0;a[801640]=0;c[2440576]=0;c[2440574]=0;gGz(14168784,0,16);gGz(14168768,0,16)}c[2113070]=0;c[2113068]=0;i=c[2112926]|0;if((i|0)!=0){gGr(i);c[2112926]=0}i=c[2427220]|0;n=0;while(1){if((n|0)>=1024){break}o=9638528+(n<<2)|0;if((c[o>>2]|0)==(i|0)){f=23403;break}else{n=n+1|0}}if((f|0)==23403){gGr(i);c[o>>2]=0}c[2427220]=0;o=c[2426992]|0;i=0;while(1){if((i|0)>=1024){break}p=9638528+(i<<2)|0;if((c[p>>2]|0)==(o|0)){f=23407;break}else{i=i+1|0}}if((f|0)==23407){gGr(o);c[p>>2]=0}c[2426992]=0;p=c[2429594]|0;o=0;while(1){if((o|0)>=1024){break}q=9638528+(o<<2)|0;if((c[q>>2]|0)==(p|0)){f=23411;break}else{o=o+1|0}}if((f|0)==23411){gGr(p);c[q>>2]=0}c[2429594]=0;q=c[2429592]|0;p=0;while(1){if((p|0)>=1024){break}r=9638528+(p<<2)|0;if((c[r>>2]|0)==(q|0)){f=23415;break}else{p=p+1|0}}if((f|0)==23415){gGr(q);c[r>>2]=0}c[2429592]=0;r=c[2429590]|0;q=0;while(1){if((q|0)>=1024){break}s=9638528+(q<<2)|0;if((c[s>>2]|0)==(r|0)){f=23419;break}else{q=q+1|0}}if((f|0)==23419){gGr(r);c[s>>2]=0}c[2429590]=0;s=c[2429588]|0;r=0;while(1){if((r|0)>=1024){break}t=9638528+(r<<2)|0;if((c[t>>2]|0)==(s|0)){f=23423;break}else{r=r+1|0}}if((f|0)==23423){gGr(s);c[t>>2]=0}c[2429588]=0;t=c[2427070]|0;s=0;while(1){if((s|0)>=1024){break}u=9638528+(s<<2)|0;if((c[u>>2]|0)==(t|0)){f=23427;break}else{s=s+1|0}}if((f|0)==23427){gGr(t);c[u>>2]=0}c[2427070]=0;u=c[2427068]|0;t=0;while(1){if((t|0)>=1024){break}v=9638528+(t<<2)|0;if((c[v>>2]|0)==(u|0)){f=23431;break}else{t=t+1|0}}if((f|0)==23431){gGr(u);c[v>>2]=0}c[2427068]=0;v=c[2427066]|0;u=0;while(1){if((u|0)>=1024){break}w=9638528+(u<<2)|0;if((c[w>>2]|0)==(v|0)){f=23435;break}else{u=u+1|0}}if((f|0)==23435){gGr(v);c[w>>2]=0}c[2427066]=0;w=c[2427064]|0;v=0;while(1){if((v|0)>=1024){break}x=9638528+(v<<2)|0;if((c[x>>2]|0)==(w|0)){f=23439;break}else{v=v+1|0}}if((f|0)==23439){gGr(w);c[x>>2]=0}c[2427064]=0;x=c[3541162]|0;w=0;while(1){if((w|0)>=1024){break}y=9638528+(w<<2)|0;if((c[y>>2]|0)==(x|0)){f=23443;break}else{w=w+1|0}}if((f|0)==23443){gGr(x);c[y>>2]=0}c[3541162]=0;gGz(14129960,0,16);gGz(14129672,0,16);gGz(14129656,0,16);c[3542204]=0;c[3542202]=0;gGz(14129568,0,64);gGz(14129432,0,32);c[3532340]=0;c[3532306]=0;c[3532304]=0;c[3532422]=0;c[3532378]=0;c[3532376]=0;a[14129368]=0;c[3532412]=0;c[3532550]=0;c[3532424]=0;a[7461584]=0;c[2433318]=0;a[7461592]=0;c[3532458]=0;c[3532464]=0;c[3532462]=0;c[3532460]=0;a[7461536]=0;a[7461544]=0;c[3532560]=0;c[3532554]=0;c[3532486]=0;c[3532468]=0;c[3532384]=0;a[7461528]=0;a[7461520]=0;c[3532366]=0;a[7461568]=0;a[7461576]=0;a[7461552]=0;a[7461560]=0;a[7461600]=0;a[7461624]=0;a[7461656]=0;a[7461840]=0;a[64248]=0;c[3532338]=0;c[2430046]=0;a[9773128]=0;c[2437628]=0;c[3532430]=0;c[3532432]=0;c[3532440]=0;c[3532442]=0;c[3532434]=0;c[3532436]=0;c[3532352]=0;c[3532354]=0;c[3532508]=0;c[3532380]=0;c[3532382]=0;c[3532408]=0;c[3532410]=0;c[3532450]=0;c[3532452]=0;c[3532308]=0;c[3532310]=0;c[3532324]=0;c[3532326]=0;c[3532318]=0;c[3532320]=0;c[3532312]=0;c[3532314]=0;c[3532574]=0;c[3532576]=0;c[3532580]=0;c[3532582]=0;c[3532344]=0;c[3532346]=0;c[3532494]=0;c[3532496]=0;c[3532498]=0;c[3532502]=0;c[3532504]=0;c[3532472]=0;c[3532476]=0;c[3532478]=0;c[3532516]=0;c[3532588]=0;c[3532512]=0;c[3532510]=0;c[3532546]=0;c[3532548]=0;c[3532482]=0;c[3532514]=0;gGz(9579128,0,24);gGz(9644816,0,48);gGz(9757208,0,72);if((c[(c[642608+(c[2436]<<2)>>2]|0)+60>>2]&8256|0)==0){return 0}a[7461504]=0;c[3528544]=0;y=c[2430018]|0;x=0;while(1){if((x|0)>=1024){break}z=9638528+(x<<2)|0;if((c[z>>2]|0)==(y|0)){f=23448;break}else{x=x+1|0}}if((f|0)==23448){gGr(y);c[z>>2]=0}c[2430018]=0;z=c[2430019]|0;y=0;while(1){if((y|0)>=1024){break}A=9638528+(y<<2)|0;if((c[A>>2]|0)==(z|0)){f=23452;break}else{y=y+1|0}}if((f|0)==23452){gGr(z);c[A>>2]=0}c[2430019]=0;A=c[2430020]|0;z=0;while(1){if((z|0)>=1024){break}B=9638528+(z<<2)|0;if((c[B>>2]|0)==(A|0)){f=23456;break}else{z=z+1|0}}if((f|0)==23456){gGr(A);c[B>>2]=0}c[2430020]=0;B=c[2430021]|0;A=0;while(1){if((A|0)>=1024){break}C=9638528+(A<<2)|0;if((c[C>>2]|0)==(B|0)){f=23460;break}else{A=A+1|0}}if((f|0)==23460){gGr(B);c[C>>2]=0}c[2430021]=0;C=c[2430022]|0;B=0;while(1){if((B|0)>=1024){break}D=9638528+(B<<2)|0;if((c[D>>2]|0)==(C|0)){f=23464;break}else{B=B+1|0}}if((f|0)==23464){gGr(C);c[D>>2]=0}c[2430022]=0;D=c[2430023]|0;C=0;while(1){if((C|0)>=1024){break}E=9638528+(C<<2)|0;if((c[E>>2]|0)==(D|0)){f=23468;break}else{C=C+1|0}}if((f|0)==23468){gGr(D);c[E>>2]=0}c[2430023]=0;E=c[2430024]|0;D=0;while(1){if((D|0)>=1024){break}F=9638528+(D<<2)|0;if((c[F>>2]|0)==(E|0)){f=23472;break}else{D=D+1|0}}if((f|0)==23472){gGr(E);c[F>>2]=0}c[2430024]=0;F=c[2430025]|0;E=0;while(1){if((E|0)>=1024){break}G=9638528+(E<<2)|0;if((c[G>>2]|0)==(F|0)){f=23476;break}else{E=E+1|0}}if((f|0)==23476){gGr(F);c[G>>2]=0}c[2430025]=0;c[2426958]=0;return 0}function eOJ(){var d=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;if((a[14129864]|0)!=0){eOH()}eOK();d=c[2438]|0;f=gGU(d,(d|0)<0|0?-1:0,1e7,0)|0;d=gGS(f,K,15360,0)|0;c[2440506]=d;c[2440480]=66666;c[2440476]=6666;c[2113036]=0;c[2113035]=0;c[2113034]=0;d=c[2392]|0;if((d|0)>=0){gGz(8452240,0,((d|0)>0?(d<<2)+4|0:4)|0)}c[2113054]=0;d=c[2385548]|0;if((d|0)>0){gGz(9752472,0,((d|0)>1?d<<2:4)|0)}c[2433530]=0;h[1214783]=0.0;if((c[2394]|0)==0){g=0;i=0}else{c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];g=0;i=0}L30900:while(1){d=i;do{if((d|0)>=100){break L30900}d=d+1|0;f=(ag(c[2440506]|0,d)|0)/100|0;j=f-(c[2113034]|0)|0;c[2438176]=j;c[2113056]=j;f=RG(j)|0;c[2113054]=(c[2113054]|0)+f;c[2276108]=-1;c[2113056]=-1;c[2113034]=(c[2113034]|0)+f;f=c[2439330]|0;if((f|0)!=0){j=f;gGC(9706056,j|0,76)|0}b[4853030]=c[2426515]&65535;j=c[2438118]|0;c[2433530]=j;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;k=(ag(c[2440480]|0,d)|0)/100|0;l=c[2113035]|0;m=k-l|0;c[2438176]=m;do{if((m|0)<1){n=0;o=l;p=0;q=f;r=j}else{if((a[f+4188|0]|0)==0){k=gfc(m)|0;s=(c[2433530]|0)+k|0;c[2433530]=s;t=c[1836236]|0;n=k;o=c[2113035]|0;p=t;q=c[9757320+(t<<2)>>2]|0;r=s;break}else{s=j+m|0;c[2433530]=s;n=m;o=l;p=0;q=f;r=s;break}}}while(0);c[2438176]=n;c[2113035]=o+n;if((q|0)!=0){f=q;gGC(f|0,9706056,76)|0}c[9752472+(p<<2)>>2]=r;c[14113936+(p<<2)>>2]=c[2076596];c[9669104+(p<<2)>>2]=c[3541536];c[1836236]=-1;if((c[3532574]|0)!=0){f=(ag(c[2440476]|0,d)|0)/100|0;l=f-(c[2113036]|0)|0;c[2438176]=l;f=fJ_(l)|0;c[2438176]=f;c[2113036]=(c[2113036]|0)+f}u=c[2112964]|0;}while((u|0)==0);f=a[9688]|0?5:0;l=c[2439330]|0;if((l|0)!=0){m=l;gGC(9706056,m|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;gg[c[3542124]&4095](u+(g<<1<<1)|0,f);m=c[1836236]|0;l=c[9757320+(m<<2)>>2]|0;if((l|0)!=0){j=l;gGC(j|0,9706056,76)|0}c[9752472+(m<<2)>>2]=c[2433530];c[14113936+(m<<2)>>2]=c[2076596];c[9669104+(m<<2)>>2]=c[3541536];c[1836236]=-1;g=f+g|0;i=d}i=c[2394]|0;c[8452200+(i<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0<1024){RH(4);v=c[2394]|0}else{v=i}i=c[14130368+(v<<2)>>2]|0;if((i|0)!=0){gGC(i|0,9104152,280)|0}c[8452240+(v<<2)>>2]=c[2113054];c[2394]=-1;v=c[3532588]|0;if((v|0)!=0){gu[v&16383]()}v=c[2112964]|0;do{if((v|0)!=0){i=a[9688]|0?534:0;if((i|0)!=(g|0)){u=c[2439330]|0;if((u|0)!=0){p=u;gGC(9706056,p|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;gg[c[3542124]&4095](v+(g<<1<<1)|0,i-g|0);i=c[1836236]|0;p=c[9757320+(i<<2)>>2]|0;if((p|0)!=0){u=p;gGC(u|0,9706056,76)|0}c[9752472+(i<<2)>>2]=c[2433530];c[14113936+(i<<2)>>2]=c[2076596];c[9669104+(i<<2)>>2]=c[3541536];c[1836236]=-1}if((c[3532574]|0)==0){break}UR(c[2112964]|0,a[9688]|0?534:0)}}while(0);if((c[2112968]|0)==0){return 0}if((c[3532340]|0)==0){g=c[2112926]|0;gGz(g|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);return 0}g=c[3532368]|0;v=g;i=c[3532490]|0;u=(c[3532422]|0)==0?1871:1863;p=e[v+(u<<1)>>1]|0;c[3532490]=p;c[3532418]=b[g+4088>>1]&511;c[3532414]=b[g+3876>>1]&255;r=c[3532491]|0;q=e[v+(u-1<<1)>>1]|0;c[3532491]=q;c[3532419]=b[g+4090>>1]&511;c[3532415]=b[g+3878>>1]&255;if((i|0)!=(p|0)){a[7461552]=1}if((r|0)!=(q|0)){a[7461568]=1}eOZ();eO_();eO$(1,0,0);eO0(1);eO$(1,0,1);eO0(2);eO$(1,1,1);eO$(0,0,1);eO0(4);eO$(0,1,1);eO1(0);eO0(8);eO1(1);R8(c[3532488]|0);return 0}function eOK(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;gGz(14130136,0,7);b=0;d=0;e=0;f=0;g=0;h=0;i=0;j=0;do{d=((a[14130128+b|0]&1)<<b|d&255)&255;e=((a[14130120+b|0]&1)<<b|e&255)&255;f=((a[14130112+b|0]&1)<<b|f&255)&255;g=((a[14130104+b|0]&1)<<b|g&255)&255;h=((a[14130096+b|0]&1)<<b|h&255)&255;i=((a[14130088+b|0]&1)<<b|i&255)&255;j=((a[14130080+b|0]&1)<<b|j&255)&255;b=b+1|0;}while((b|0)<8);a[14130136]=d;a[14130137]=e;a[14130138]=f;a[14130139]=g;a[14130140]=h;a[14130141]=i;a[14130142]=j;j=c[3532514]|0;if((j|0)==0){return}gu[j&16383]();return}function eOL(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=(c[(c[642608+(c[2436]<<2)>>2]|0)+60>>2]&4096|0)==0?183:c[3532338]|0;if((a[14129864]|0)!=0){eOH()}eOK();f=c[2438]|0;g=gGU(f,(f|0)<0|0?-1:0,c[3532554]|0,0)|0;f=gGS(g,K,15360,0)|0;c[2440506]=f;c[2440480]=83333;c[2113035]=0;c[2113034]=0;f=c[2392]|0;if((f|0)>=0){gGz(8452240,0,((f|0)>0?(f<<2)+4|0:4)|0)}c[2113054]=0;do{if((c[3532310]|0)==0){if((c[(c[642608+(c[2436]<<2)>>2]|0)+60>>2]&16384|0)==0){break}if((a[7461512]&1)!=0){h=23550}}else{h=23550}}while(0);if((h|0)==23550){f=c[2385548]|0;if((f|0)>0){gGz(9752472,0,((f|0)>1?f<<2:4)|0)}c[2433530]=0}if((c[2394]|0)==0){i=0;j=0}else{c[2394]=0;c[2112932]=c[3532596];f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];i=0;j=0}L30993:while(1){f=j;do{if((f|0)>=(d|0)){break L30993}f=f+1|0;g=(ag(c[2440506]|0,f)|0)/(d|0)|0;k=g-(c[2113034]|0)|0;c[2438176]=k;c[2113056]=k;g=RG(k)|0;c[2113054]=(c[2113054]|0)+g;c[2276108]=-1;c[2113056]=-1;c[2113034]=(c[2113034]|0)+g;do{if((c[(c[642608+(c[2436]<<2)>>2]|0)+60>>2]&4096|0)!=0){c[8452200+(c[2394]<<2)>>2]=8194;c[2276080]=512;if((c[2276079]|0)>>>0>=512){break}RH(2)}}while(0);do{if((c[3532310]|0)==0){if((c[(c[642608+(c[2436]<<2)>>2]|0)+60>>2]&16384|0)==0){break}if((a[7461512]&1)!=0){h=23565}}else{h=23565}}while(0);if((h|0)==23565){h=0;g=c[2439330]|0;if((g|0)!=0){k=g;gGC(9706056,k|0,76)|0}b[4853030]=c[2426515]&65535;k=c[2438118]|0;c[2433530]=k;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;l=(ag(c[2440480]|0,f)|0)/(d|0)|0;m=c[2113035]|0;n=l-m|0;c[2438176]=n;do{if((n|0)<1){o=0;p=m;q=0;r=g;s=k}else{if((a[g+4188|0]|0)==0){l=gfc(n)|0;t=(c[2433530]|0)+l|0;c[2433530]=t;u=c[1836236]|0;o=l;p=c[2113035]|0;q=u;r=c[9757320+(u<<2)>>2]|0;s=t;break}else{t=k+n|0;c[2433530]=t;o=n;p=m;q=0;r=g;s=t;break}}}while(0);c[2438176]=o;c[2113035]=p+o;if((r|0)!=0){g=r;gGC(g|0,9706056,76)|0}c[9752472+(q<<2)>>2]=s;c[14113936+(q<<2)>>2]=c[2076596];c[9669104+(q<<2)>>2]=c[3541536];c[1836236]=-1}v=c[2112964]|0;}while((v|0)==0);g=((a[9688]|0?534:0)|0)/(d|0)|0;m=v+(i<<1<<1)|0;if((c[(c[642608+(c[2436]<<2)>>2]|0)+60>>2]&4096|0)==0){n=c[2439330]|0;if((n|0)!=0){k=n;gGC(9706056,k|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;gg[c[3542124]&4095](m,g);if((c[3532344]|0)!=0){Vj(0,m,g)}k=c[1836236]|0;n=c[9757320+(k<<2)>>2]|0;if((n|0)!=0){t=n;gGC(t|0,9706056,76)|0}c[9752472+(k<<2)>>2]=c[2433530];c[14113936+(k<<2)>>2]=c[2076596];c[9669104+(k<<2)>>2]=c[3541536];c[1836236]=-1}else{Uy(m,g)}i=g+i|0;j=f}j=c[2112964]|0;do{if((j|0)!=0){v=a[9688]|0?534:0;d=v-i|0;q=j+(i<<1<<1)|0;if((v|0)==(i|0)){break}if((c[(c[642608+(c[2436]<<2)>>2]|0)+60>>2]&4096|0)!=0){Uy(q,d);break}v=c[2439330]|0;if((v|0)!=0){s=v;gGC(9706056,s|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;gg[c[3542124]&4095](q,d);if((c[3532344]|0)!=0){Vj(0,q,d)}d=c[1836236]|0;q=c[9757320+(d<<2)>>2]|0;if((q|0)!=0){s=q;gGC(s|0,9706056,76)|0}c[9752472+(d<<2)>>2]=c[2433530];c[14113936+(d<<2)>>2]=c[2076596];c[9669104+(d<<2)>>2]=c[3541536];c[1836236]=-1}}while(0);i=c[2394]|0;c[8452200+(i<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0<1024){RH(4);w=c[2394]|0}else{w=i}i=c[14130368+(w<<2)>>2]|0;if((i|0)!=0){gGC(i|0,9104152,280)|0}c[8452240+(w<<2)>>2]=c[2113054];c[2394]=-1;w=c[3532588]|0;if((w|0)!=0){gu[w&16383]()}if((c[2112968]|0)==0){return 0}if(a[7461624]|0){if((c[3532340]|0)==0){w=c[2112926]|0;gGz(w|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);return 0}w=c[3532368]|0;i=c[3532490]|0;j=e[w+3712>>1]|0;c[3532490]=j;c[3532418]=e[w+3736>>1]|0;c[3532414]=e[w+3728>>1]|0;d=c[3532491]|0;s=e[w+3714>>1]|0;c[3532491]=s;c[3532419]=e[w+3738>>1]|0;c[3532415]=e[w+3730>>1]|0;q=c[3532492]|0;v=e[w+3716>>1]|0;c[3532492]=v;c[3532420]=e[w+3740>>1]|0;c[3532416]=e[w+3732>>1]|0;r=c[3532493]|0;o=e[w+3718>>1]|0;c[3532493]=o;c[3532421]=e[w+3742>>1]|0;c[3532417]=e[w+3734>>1]|0;if((i|0)!=(j|0)){a[7461552]=1}if((d|0)!=(s|0)){a[7461568]=1}if((q|0)!=(v|0)){a[7461560]=1}if((r|0)!=(o|0)){a[7461576]=1}eO7();eO_();eO6(1,0,0);eO3(1);eO6(1,0,1);eO3(2);eO6(1,1,1);eO6(0,0,1);eO3(4);eO6(0,1,1);eO8(0);eO3(8);eO8(1);R8(c[3532488]|0);return 0}if(a[64248]|0){if((c[3532340]|0)==0){o=c[2112926]|0;gGz(o|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);return 0}else{eO_();eO2(1,0,0);eO2(1,1,0);eO3(1);eO2(1,0,1);eO3(2);eO2(1,1,1);eO2(0,0,1);eO3(4);eO2(0,1,1);eO4(0);eO3(8);eO4(1);R8(c[3532488]|0);return 0}}if((c[3532340]|a[7461584]&1|0)==0){o=c[2112926]|0;gGz(o|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);return 0}o=c[3532368]|0;r=c[3532490]|0;v=e[o+3712>>1]|0;c[3532490]=v;c[3532418]=e[o+3736>>1]|0;c[3532414]=e[o+3728>>1]|0;q=c[3532491]|0;s=e[o+3714>>1]|0;c[3532491]=s;c[3532419]=e[o+3738>>1]|0;c[3532415]=e[o+3730>>1]|0;d=c[3532492]|0;j=e[o+3716>>1]|0;c[3532492]=j;c[3532420]=e[o+3740>>1]|0;c[3532416]=e[o+3732>>1]|0;i=c[3532493]|0;w=e[o+3718>>1]|0;c[3532493]=w;c[3532421]=e[o+3742>>1]|0;c[3532417]=e[o+3734>>1]|0;if((r|0)!=(v|0)){a[7461552]=1}if((q|0)!=(s|0)){a[7461568]=1}if((d|0)!=(j|0)){a[7461560]=1}if((i|0)!=(w|0)){a[7461576]=1}eO5();eO_();eO6(1,0,0);eO3(1);eO6(1,0,1);eO3(2);eO6(1,1,1);eO6(0,0,1);eO3(4);eO6(0,1,1);eO4(0);eO3(8);eO4(1);R8(c[3532488]|0);return 0}function eOM(){var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,L=0,M=0,N=0,O=0;f=i;i=i+1176|0;g=f|0;h=f+168|0;j=f+336|0;k=f+504|0;l=f+512|0;m=f+520|0;n=f+848|0;o=a[9688]|0?534:0;if((a[14129864]|0)!=0){eOH()}eOK();p=c[2113302]|0;do{if((p|0)!=0){q=c[3532570]|0;r=(c[3542196]|0)+(c[3532572]<<16>>16)|0;c[3542196]=r;s=(c[3542192]|0)+(q<<16>>16)|0;c[3542192]=s;if((r|0)<-2048){c[3542196]=-2048;t=-2048}else{t=r}r=(c[2440576]<<8)-2048|0;if((t|0)>(r|0)){c[3542196]=r}if((s|0)<-2048){c[3542192]=-2048;u=-2048}else{u=s}s=(c[2440574]<<8)-2048|0;if((u|0)>(s|0)){c[3542192]=s}if((p|0)<=1){break}q=c[3532566]|0;v=(c[3542197]|0)+(c[3532568]<<16>>16)|0;c[3542197]=v;w=(c[3542193]|0)+(q<<16>>16)|0;c[3542193]=w;if((v|0)<-2048){c[3542197]=-2048;x=-2048}else{x=v}if((x|0)>(r|0)){c[3542197]=r}if((w|0)<-2048){c[3542193]=-2048;y=-2048}else{y=w}if((y|0)>(s|0)){c[3542193]=s}if((p|0)<=2){break}w=c[3532562]|0;v=(c[3542198]|0)+(c[3532564]<<16>>16)|0;c[3542198]=v;q=(c[3542194]|0)+(w<<16>>16)|0;c[3542194]=q;if((v|0)<-2048){c[3542198]=-2048;z=-2048}else{z=v}if((z|0)>(r|0)){c[3542198]=r}if((q|0)<-2048){c[3542194]=-2048;A=-2048}else{A=q}if((A|0)<=(s|0)){break}c[3542194]=s}}while(0);A=c[2438]|0;z=gGU(A,(A|0)<0|0?-1:0,1e7,0)|0;A=gGS(z,K,15360,0)|0;c[2440506]=A;c[2440480]=133333;c[2113035]=0;c[2113034]=0;A=c[2392]|0;if((A|0)>=0){gGz(8452240,0,((A|0)>0?(A<<2)+4|0:4)|0)}c[2113054]=0;A=c[2385548]|0;if((A|0)>0){gGz(9752472,0,((A|0)>1?A<<2:4)|0)}c[2433530]=0;if((c[2394]|0)==0){B=0;C=0}else{c[2394]=0;c[2112932]=c[3532596];A=c[3532592]|0;if((A|0)!=0){gGC(9104152,A|0,280)|0}c[2113054]=c[2113060];B=0;C=0}L31162:while(1){A=C;while(1){if((A|0)>=(o|0)){break L31162}D=A+1|0;z=(ag(c[2440506]|0,D)|0)/534|0;p=z-(c[2113034]|0)|0;c[2438176]=p;c[2113056]=p;z=RG(p)|0;c[2113054]=(c[2113054]|0)+z;c[2276108]=-1;c[2113056]=-1;c[2113034]=(c[2113034]|0)+z;z=c[2439330]|0;if((z|0)!=0){p=z;gGC(9706056,p|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;Sb(ag((c[2440480]|0)/534|0,A)|0);p=c[1836236]|0;z=c[9757320+(p<<2)>>2]|0;if((z|0)!=0){y=z;gGC(y|0,9706056,76)|0}c[9752472+(p<<2)>>2]=c[2433530];c[14113936+(p<<2)>>2]=c[2076596];c[9669104+(p<<2)>>2]=c[3541536];c[1836236]=-1;E=c[2112964]|0;if((E|0)==0){A=D}else{break}}A=a[9688]&1;U$(E+(B<<1<<1)|0,A);B=A+B|0;C=D}D=c[2394]|0;c[8452200+(D<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0<1024){RH(4);F=c[2394]|0}else{F=D}D=c[14130368+(F<<2)>>2]|0;if((D|0)!=0){gGC(D|0,9104152,280)|0}c[8452240+(F<<2)>>2]=c[2113054];c[2394]=-1;F=c[2439330]|0;if((F|0)!=0){D=F;gGC(9706056,D|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;D=c[2440480]|0;F=gGU(D,(D|0)<0|0?-1:0,2048e6,0)|0;C=c[2438228]|0;E=gGS(F,K,C,(C|0)<0|0?-1:0)|0;C=E;Sb(D);D=c[2443830]|0;if((D|0)<1073676288){c[2443830]=D-C}D=c[2443831]|0;if((D|0)<1073676288){c[2443831]=D-C}D=(c[3528512]|0)-C|0;c[3528512]=(D|0)<0?0:D;D=c[1836236]|0;C=c[9757320+(D<<2)>>2]|0;if((C|0)!=0){E=C;gGC(E|0,9706056,76)|0}c[9752472+(D<<2)>>2]=c[2433530];c[14113936+(D<<2)>>2]=c[2076596];c[9669104+(D<<2)>>2]=c[3541536];c[1836236]=-1;D=c[2112964]|0;E=(D|0)==0;do{if(!E){C=a[9688]|0?534:0;if((C|0)==(B|0)){break}U$(D+(B<<1<<1)|0,C-B|0)}}while(0);B=c[2439330]|0;if((B|0)!=0){C=B;gGC(9706056,C|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;if(E){G=0;H=B}else{gg[c[3542116]&4095](D,a[9688]|0?534:0);D=c[1836236]|0;G=D;H=c[9757320+(D<<2)>>2]|0}if((H|0)!=0){D=H;gGC(D|0,9706056,76)|0}c[9752472+(G<<2)>>2]=c[2433530];c[14113936+(G<<2)>>2]=c[2076596];c[9669104+(G<<2)>>2]=c[3541536];c[1836236]=-1;if((c[2112968]|0)==0){i=f;return 0}if((c[3532340]|0)==0){G=c[2112926]|0;gGz(G|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);i=f;return 0}G=c[3532304]|0;D=G>>>1&3;H=(G&1|0)==0;G=c[3532368]|0;B=c[3532490]|0;E=e[G+3712>>1]|0;c[3532490]=E;c[3532418]=e[G+3736>>1]|0;c[3532414]=e[G+3728>>1]|0;C=c[3532491]|0;F=e[G+3714>>1]|0;c[3532491]=F;c[3532419]=e[G+3738>>1]|0;c[3532415]=e[G+3730>>1]|0;o=c[3532492]|0;A=e[G+3716>>1]|0;c[3532492]=A;c[3532420]=e[G+3740>>1]|0;c[3532416]=e[G+3732>>1]|0;p=c[3532493]|0;y=e[G+3718>>1]|0;c[3532493]=y;c[3532421]=e[G+3742>>1]|0;c[3532417]=e[G+3734>>1]|0;if((B|0)!=(E|0)){a[7461552]=1}if((C|0)!=(F|0)){a[7461568]=1}if((o|0)!=(A|0)){a[7461560]=1}if((p|0)!=(y|0)){a[7461576]=1}eO5();eO_();if((c[3532306]|0)!=0){y=c[2112930]|0;p=h|0;h=g|0;g=j|0;j=0;do{A=j*320|0;o=y+(A<<1)|0;F=0;do{b[y+(A+F<<1)>>1]=-1;F=F+1|0;}while((F|0)<320);do{if((a[14165177]&64)!=0){F=c[3531886]|0;A=c[3531882]|0;C=0;E=0;B=0;G=0;while(1){z=C+F&65535;x=A+z|0;if((a[A+(z+4)|0]|0)<0){u=E+1|0;c[n+(u<<2)>>2]=x;I=G;J=u}else{u=G+1|0;c[m+(u<<2)>>2]=x;I=u;J=E}u=a[A+(z+3)|0]&127;if((u|0)==0){break}z=B+1|0;if((z|0)<80){C=u<<3;E=J;B=z;G=I}else{break}}eFg(j,2,c[3531892]|0,p,l);eFg(j,0,c[3531894]|0,h,k);G=c[3531876]|0;B=j<<16&458752;E=ag(d[14127464]|0,j>>>3)|0;C=0;F=g;while(1){z=(C+E<<1)+G|0;c[F>>2]=d[A+(z+1&65535)|0]|B|d[A+(z&65535)|0]<<8;z=C+1|0;if((z|0)<40){C=z;F=F+4|0}else{break}}F=(a[14127496]|0)==0;C=(c[3531868]|0)>>>0>j>>>0;do{if(F&C|(F|C)^1){L=319;M=0}else{A=c[3531872]|0;if((a[14127480]|0)!=0){L=319;M=A;break}L=A-1|0;M=0}}while(0);C=(M|0)==0;F=C?L+1|0:0;A=C?319:M-1|0;C=c[l>>2]|0;eFh(p,o,0,C,0,319);B=c[k>>2]|0;eFh(h,o,0,B,F,A);eFh(g,o,0,0,M,L);if((I|0)>0){G=I;do{eFi(j,o,c[m+(G<<2)>>2]|0);G=G-1|0;}while((G|0)>0)}eFh(p,o,1,C,0,319);eFh(h,o,1,B,F,A);eFh(g,o,1,0,M,L);if((J|0)>0){N=J}else{break}do{eFi(j,o,c[n+(N<<2)>>2]|0);N=N-1|0;}while((N|0)>0)}}while(0);j=j+1|0;}while((j|0)<224)}eO6(1,0,0);j=(D|0)==0;if((c[3532306]|0)!=0&j&H){N=c[2112930]|0;n=c[2112926]|0;J=0;do{L=J*320|0;M=0;do{g=M+L|0;h=b[N+(g<<1)>>1]|0;if(h<<16>>16!=-1){b[n+(g<<1)>>1]=h}M=M+1|0;}while((M|0)<320);J=J+1|0;}while((J|0)<224)}eO3(1);if(!(H|(c[3532306]|0)!=0&j^1)){j=c[2112930]|0;J=c[2112926]|0;n=0;do{N=n*320|0;M=0;do{L=M+N|0;h=b[j+(L<<1)>>1]|0;if(h<<16>>16!=-1){b[J+(L<<1)>>1]=h}M=M+1|0;}while((M|0)<320);n=n+1|0;}while((n|0)<224)}eO6(1,0,1);n=(D|0)==1;if((c[3532306]|0)!=0&n&H){J=c[2112930]|0;j=c[2112926]|0;M=0;do{N=M*320|0;h=0;do{L=h+N|0;g=b[J+(L<<1)>>1]|0;if(g<<16>>16!=-1){b[j+(L<<1)>>1]=g}h=h+1|0;}while((h|0)<320);M=M+1|0;}while((M|0)<224)}eO3(2);if(!(H|(c[3532306]|0)!=0&n^1)){n=c[2112930]|0;M=c[2112926]|0;j=0;do{J=j*320|0;h=0;do{N=h+J|0;g=b[n+(N<<1)>>1]|0;if(g<<16>>16!=-1){b[M+(N<<1)>>1]=g}h=h+1|0;}while((h|0)<320);j=j+1|0;}while((j|0)<224)}eO6(1,1,1);eO6(0,0,1);j=(D|0)==2;if((c[3532306]|0)!=0&j&H){M=c[2112930]|0;n=c[2112926]|0;h=0;do{J=h*320|0;g=0;do{N=g+J|0;L=b[M+(N<<1)>>1]|0;if(L<<16>>16!=-1){b[n+(N<<1)>>1]=L}g=g+1|0;}while((g|0)<320);h=h+1|0;}while((h|0)<224)}eO3(4);if(!(H|(c[3532306]|0)!=0&j^1)){j=c[2112930]|0;h=c[2112926]|0;n=0;do{M=n*320|0;g=0;do{J=g+M|0;L=b[j+(J<<1)>>1]|0;if(L<<16>>16!=-1){b[h+(J<<1)>>1]=L}g=g+1|0;}while((g|0)<320);n=n+1|0;}while((n|0)<224)}eO6(0,1,1);eO4(0);n=(D|0)==3;if((c[3532306]|0)!=0&n&H){D=c[2112930]|0;h=c[2112926]|0;j=0;do{g=j*320|0;M=0;do{L=M+g|0;J=b[D+(L<<1)>>1]|0;if(J<<16>>16!=-1){b[h+(L<<1)>>1]=J}M=M+1|0;}while((M|0)<320);j=j+1|0;}while((j|0)<224)}eO3(8);if(!(H|(c[3532306]|0)!=0&n^1)){n=c[2112930]|0;H=c[2112926]|0;j=0;do{h=j*320|0;D=0;do{M=D+h|0;g=b[n+(M<<1)>>1]|0;if(g<<16>>16!=-1){b[H+(M<<1)>>1]=g}D=D+1|0;}while((D|0)<320);j=j+1|0;}while((j|0)<224)}eO4(1);R8(c[3532488]|0);j=c[2113302]|0;if((j|0)>0){O=0}else{i=f;return 0}do{R7(O,c[14168784+(O<<2)>>2]>>8,c[14168768+(O<<2)>>2]>>8);O=O+1|0;}while((O|0)<(j|0));i=f;return 0}function eON(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;if((a[14129864]|0)!=0){eOH()}eOK();d=c[2438]|0;e=gGU(d,(d|0)<0|0?-1:0,c[3532554]|0,0)|0;d=gGS(e,K,15360,0)|0;e=d;c[2440506]=e;c[2440480]=e;c[2440476]=66666;c[2113036]=0;c[2113035]=0;c[2113034]=0;e=c[2392]|0;if((e|0)>=0){gGz(8452240,0,((e|0)>0?(e<<2)+4|0:4)|0)}c[2113054]=0;e=c[2385548]|0;if((e|0)>0){gGz(9752472,0,((e|0)>1?e<<2:4)|0)}c[2433530]=0;e=0;d=0;L31360:while(1){f=e;do{if((f|0)>=10){break L31360}if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060]}f=f+1|0;g=(ag(c[2440506]|0,f)|0)/10|0;h=g-(c[2113034]|0)|0;c[2438176]=h;c[2113056]=h;g=RG(h)|0;h=(c[2113054]|0)+g|0;c[2113054]=h;c[2276108]=-1;c[2113056]=-1;c[2113034]=(c[2113034]|0)+g;g=c[2394]|0;i=c[14130368+(g<<2)>>2]|0;if((i|0)!=0){gGC(i|0,9104152,280)|0}c[8452240+(g<<2)>>2]=h;c[2394]=1;c[2112932]=c[3532597];h=c[3532593]|0;if((h|0)!=0){gGC(9104152,h|0,280)|0}c[2113054]=c[2113061];h=(ag(c[2440480]|0,f)|0)/10|0;g=h-(c[2113035]|0)|0;c[2438176]=g;c[2113056]=g;h=RG(g)|0;g=(c[2113054]|0)+h|0;c[2113054]=g;c[2276108]=-1;c[2113056]=-1;c[2438176]=h;c[2113035]=(c[2113035]|0)+h;h=c[2394]|0;i=c[14130368+(h<<2)>>2]|0;if((i|0)!=0){gGC(i|0,9104152,280)|0}c[8452240+(h<<2)>>2]=g;c[2394]=-1;g=c[2439330]|0;if((g|0)!=0){h=g;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;h=c[2438118]|0;c[2433530]=h;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;i=(ag(c[2440476]|0,f)|0)/10|0;j=c[2113036]|0;k=i-j|0;c[2438176]=k;do{if((k|0)<1){l=0;m=j;n=0;o=g;p=h}else{if((a[g+4188|0]|0)==0){i=gfc(k)|0;q=(c[2433530]|0)+i|0;c[2433530]=q;r=c[1836236]|0;l=i;m=c[2113036]|0;n=r;o=c[9757320+(r<<2)>>2]|0;p=q;break}else{q=h+k|0;c[2433530]=q;l=k;m=j;n=0;o=g;p=q;break}}}while(0);c[2438176]=l;c[2113036]=m+l;if((o|0)!=0){g=o;gGC(g|0,9706056,76)|0}c[9752472+(n<<2)>>2]=p;c[14113936+(n<<2)>>2]=c[2076596];c[9669104+(n<<2)>>2]=c[3541536];c[1836236]=-1;s=c[2112964]|0;}while((s|0)==0);g=a[9688]|0?53:0;j=s+(d<<1<<1)|0;k=c[2439330]|0;if((k|0)!=0){h=k;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;gg[c[3542124]&4095](j,g);h=c[1836236]|0;k=c[9757320+(h<<2)>>2]|0;if((k|0)!=0){q=k;gGC(q|0,9706056,76)|0}c[9752472+(h<<2)>>2]=c[2433530];c[14113936+(h<<2)>>2]=c[2076596];c[9669104+(h<<2)>>2]=c[3541536];c[1836236]=-1;Vh(j,g);e=f;d=g+d|0}e=c[2112964]|0;do{if((e|0)!=0){s=a[9688]|0?534:0;n=s-d|0;p=e+(d<<1<<1)|0;if((s|0)==(d|0)){break}s=c[2439330]|0;if((s|0)!=0){o=s;gGC(9706056,o|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;gg[c[3542124]&4095](p,n);o=c[1836236]|0;s=c[9757320+(o<<2)>>2]|0;if((s|0)!=0){l=s;gGC(l|0,9706056,76)|0}c[9752472+(o<<2)>>2]=c[2433530];c[14113936+(o<<2)>>2]=c[2076596];c[9669104+(o<<2)>>2]=c[3541536];c[1836236]=-1;Vh(p,n)}}while(0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}c[2113050]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0<1024){RH(4);t=c[2394]|0}else{t=0}d=c[14130368+(t<<2)>>2]|0;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[8452240+(t<<2)>>2]=c[2113054];c[2394]=-1;t=c[3532588]|0;if((t|0)!=0){gu[t&16383]()}if((c[2112968]|0)==0){return 0}eO9();return 0}function eOO(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if((a[14129864]|0)!=0){eOH()}eOK();d=c[2438]|0;f=gGU(d,(d|0)<0|0?-1:0,c[3532554]|0,0)|0;d=gGS(f,K,15360,0)|0;f=d;c[2440506]=f;c[2440480]=f;c[2440476]=66666;c[2113036]=0;c[2113035]=0;c[2113034]=0;d=c[2392]|0;if((d|0)>=0){gGz(8452240,0,((d|0)>0?(d<<2)+4|0:4)|0)}c[2113054]=0;d=c[2385548]|0;if((d|0)>0){gGz(9752472,0,((d|0)>1?d<<2:4)|0)}c[2433530]=0;if((c[2394]|0)==0){g=0;h=f;i=0}else{c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];g=0;h=f;i=0}while(1){f=g+1|0;d=((ag(h,f)|0)/100|0)-i|0;c[2438176]=d;c[2113056]=d;j=RG(d)|0;d=(c[2113054]|0)+j|0;c[2113054]=d;c[2276108]=-1;c[2113056]=-1;c[2113034]=(c[2113034]|0)+j;j=c[2394]|0;k=c[14130368+(j<<2)>>2]|0;if((k|0)!=0){gGC(k|0,9104152,280)|0}c[8452240+(j<<2)>>2]=d;c[2394]=1;c[2112932]=c[3532597];d=c[3532593]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113061];d=(ag(c[2440480]|0,f)|0)/100|0;j=d-(c[2113035]|0)|0;c[2438176]=j;c[2113056]=j;d=RG(j)|0;j=(c[2113054]|0)+d|0;c[2113054]=j;c[2276108]=-1;c[2113056]=-1;c[2438176]=d;c[2113035]=(c[2113035]|0)+d;d=c[2394]|0;k=c[14130368+(d<<2)>>2]|0;if((k|0)!=0){gGC(k|0,9104152,280)|0}c[8452240+(d<<2)>>2]=j;c[2394]=-1;j=c[2439330]|0;if((j|0)!=0){d=j;gGC(9706056,d|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;Sb(ag((c[2440476]|0)/100|0,g)|0);d=c[1836236]|0;j=c[9757320+(d<<2)>>2]|0;if((j|0)!=0){k=j;gGC(k|0,9706056,76)|0}c[9752472+(d<<2)>>2]=c[2433530];c[14113936+(d<<2)>>2]=c[2076596];c[9669104+(d<<2)>>2]=c[3541536];c[1836236]=-1;d=(f|0)<100;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];k=c[3532592]|0;if((k|0)!=0){gGC(9104152,k|0,280)|0}c[2113054]=c[2113060]}if(!d){break}g=f;h=c[2440506]|0;i=c[2113034]|0}c[2113050]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0<1024){RH(4);l=c[2394]|0}else{l=0}i=c[14130368+(l<<2)>>2]|0;if((i|0)!=0){gGC(i|0,9104152,280)|0}c[8452240+(l<<2)>>2]=c[2113054];c[2394]=-1;l=c[2439330]|0;if((l|0)!=0){i=l;gGC(9706056,i|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;i=c[2440476]|0;l=gGU(i,(i|0)<0|0?-1:0,2048e6,0)|0;h=c[2438228]|0;g=gGS(l,K,h,(h|0)<0|0?-1:0)|0;h=g;Sb(i);i=c[2443830]|0;if((i|0)<1073676288){c[2443830]=i-h}i=c[2443831]|0;if((i|0)<1073676288){c[2443831]=i-h}i=(c[3528512]|0)-h|0;c[3528512]=(i|0)<0?0:i;i=c[1836236]|0;h=c[9757320+(i<<2)>>2]|0;if((h|0)!=0){g=h;gGC(g|0,9706056,76)|0}c[9752472+(i<<2)>>2]=c[2433530];c[14113936+(i<<2)>>2]=c[2076596];c[9669104+(i<<2)>>2]=c[3541536];c[1836236]=-1;i=c[2112964]|0;if((i|0)!=0){g=c[2439330]|0;if((g|0)!=0){h=g;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;gg[c[3542122]&4095](i,a[9688]|0?534:0);Vh(c[2112964]|0,a[9688]|0?534:0);i=c[1836236]|0;h=c[9757320+(i<<2)>>2]|0;if((h|0)!=0){g=h;gGC(g|0,9706056,76)|0}c[9752472+(i<<2)>>2]=c[2433530];c[14113936+(i<<2)>>2]=c[2076596];c[9669104+(i<<2)>>2]=c[3541536];c[1836236]=-1}i=c[3532588]|0;if((i|0)!=0){gu[i&16383]()}if((c[2112968]|0)==0){return 0}if(!(a[7461840]|0)){eO9();return 0}if((c[3532340]|0)==0){i=c[2112926]|0;gGz(i|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);return 0}eO_();i=c[3532368]|0;g=i;h=c[3532490]|0;l=(c[3532422]|0)==0?1871:1863;f=e[g+(l<<1)>>1]|0;c[3532490]=f;c[3532418]=b[i+4088>>1]&511;c[3532414]=b[i+3876>>1]&255;d=c[3532491]|0;k=e[g+(l-1<<1)>>1]|0;c[3532491]=k;c[3532419]=b[i+4090>>1]&511;c[3532415]=b[i+3878>>1]&255;if((h|0)!=(f|0)){a[7461552]=1}if((d|0)!=(k|0)){a[7461568]=1}eOZ();ePa(0);ePc(1);eO$(1,0,1);ePc(2);eO$(1,1,1);eO$(0,0,1);ePc(4);eO$(0,1,1);ePa(1);ePc(8);eO1(0);eO1(1);R8(c[3532488]|0);return 0}function eOP(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;if((a[14129864]|0)!=0){eOH()}if(a[7461592]|0){a[14130136]=0;d=a[14130144]|0;f=a[14130132]|0;if(d<<24>>24!=0&(c[2433318]|0)==0){g=f^1;a[14130132]=g;h=g}else{h=f}a[14130136]=h<<4&16|a[14130128]&1|a[14130129]<<1&2|a[14130130]<<2&4|a[14130131]<<3&8|a[14130133]<<5&32|a[14130134]<<6&64|a[14130135]<<7;c[2433318]=d&255}else{eOK()}d=c[2438]|0;h=gGU(d,(d|0)<0|0?-1:0,1e7,0)|0;d=gGS(h,K,15360,0)|0;h=d;c[2440506]=h;c[2440480]=h;c[2440476]=66666;c[2113036]=0;c[2113035]=0;c[2113034]=0;h=c[2392]|0;if((h|0)>=0){gGz(8452240,0,((h|0)>0?(h<<2)+4|0:4)|0)}c[2113054]=0;h=c[2385548]|0;if((h|0)>0){gGz(9752472,0,((h|0)>1?h<<2:4)|0)}c[2433530]=0;h=0;d=0;L31534:while(1){f=h;while(1){if((f|0)>=10){break L31534}if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060]}i=f+1|0;g=(ag(c[2440506]|0,i)|0)/10|0;j=g-(c[2113034]|0)|0;c[2438176]=j;c[2113056]=j;g=RG(j)|0;c[2113054]=(c[2113054]|0)+g;c[2276108]=-1;c[2113056]=-1;c[2113034]=(c[2113034]|0)+g;do{if((f|0)==8|(f|0)==6|(f|0)==2){c[8452200+(c[2394]<<2)>>2]=8194;c[2276080]=512;if((c[2276079]|0)>>>0>=512){break}RH(2)}}while(0);g=c[2394]|0;j=c[14130368+(g<<2)>>2]|0;if((j|0)!=0){gGC(j|0,9104152,280)|0}c[8452240+(g<<2)>>2]=c[2113054];c[2394]=1;c[2112932]=c[3532597];g=c[3532593]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113061];g=(ag(c[2440480]|0,i)|0)/10|0;j=g-(c[2113035]|0)|0;c[2438176]=j;c[2113056]=j;g=RG(j)|0;j=(c[2113054]|0)+g|0;c[2113054]=j;c[2276108]=-1;c[2113056]=-1;c[2438176]=g;c[2113035]=(c[2113035]|0)+g;g=c[2394]|0;k=c[14130368+(g<<2)>>2]|0;if((k|0)!=0){gGC(k|0,9104152,280)|0}c[8452240+(g<<2)>>2]=j;c[2394]=-1;j=c[2439330]|0;if((j|0)!=0){g=j;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;g=c[2438118]|0;c[2433530]=g;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;k=(ag(c[2440476]|0,i)|0)/10|0;l=c[2113036]|0;m=k-l|0;c[2438176]=m;do{if((m|0)<1){n=0;o=l;p=0;q=j;r=g}else{if((a[j+4188|0]|0)==0){k=gfc(m)|0;s=(c[2433530]|0)+k|0;c[2433530]=s;t=c[1836236]|0;n=k;o=c[2113036]|0;p=t;q=c[9757320+(t<<2)>>2]|0;r=s;break}else{s=g+m|0;c[2433530]=s;n=m;o=l;p=0;q=j;r=s;break}}}while(0);c[2438176]=n;c[2113036]=o+n;if((q|0)!=0){j=q;gGC(j|0,9706056,76)|0}c[9752472+(p<<2)>>2]=r;c[14113936+(p<<2)>>2]=c[2076596];c[9669104+(p<<2)>>2]=c[3541536];c[1836236]=-1;u=c[2112964]|0;if((u|0)==0){f=i}else{break}}f=a[9688]|0?53:0;j=u+(d<<1<<1)|0;l=c[2439330]|0;if((l|0)!=0){m=l;gGC(9706056,m|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;gg[c[3542124]&4095](j,f);m=c[1836236]|0;l=c[9757320+(m<<2)>>2]|0;if((l|0)!=0){g=l;gGC(g|0,9706056,76)|0}c[9752472+(m<<2)>>2]=c[2433530];c[14113936+(m<<2)>>2]=c[2076596];c[9669104+(m<<2)>>2]=c[3541536];c[1836236]=-1;Vh(j,f);h=i;d=f+d|0}i=c[2112964]|0;do{if((i|0)!=0){h=a[9688]|0?534:0;u=h-d|0;p=i+(d<<1<<1)|0;if((h|0)==(d|0)){break}h=c[2439330]|0;if((h|0)!=0){r=h;gGC(9706056,r|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;gg[c[3542124]&4095](p,u);r=c[1836236]|0;h=c[9757320+(r<<2)>>2]|0;if((h|0)!=0){q=h;gGC(q|0,9706056,76)|0}c[9752472+(r<<2)>>2]=c[2433530];c[14113936+(r<<2)>>2]=c[2076596];c[9669104+(r<<2)>>2]=c[3541536];c[1836236]=-1;Vh(p,u)}}while(0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}c[2113050]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0<1024){RH(4);v=c[2394]|0}else{v=0}d=c[14130368+(v<<2)>>2]|0;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[8452240+(v<<2)>>2]=c[2113054];c[2394]=1;c[2112932]=c[3532597];v=c[3532593]|0;if((v|0)!=0){gGC(9104152,v|0,280)|0}c[2113054]=c[2113061];c[2113051]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0<1024){RH(4);d=c[2394]|0;w=d;x=c[14130368+(d<<2)>>2]|0}else{w=1;x=v}if((x|0)!=0){gGC(x|0,9104152,280)|0}c[8452240+(w<<2)>>2]=c[2113054];c[2394]=-1;if((c[2112968]|0)==0){return 0}w=(c[3532340]|0)==0;if(a[7461656]|0){if(w){x=c[2112926]|0;gGz(x|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);return 0}x=c[3532368]|0;v=c[3532490]|0;d=e[x+3712>>1]|0;c[3532490]=d;c[3532418]=e[x+3736>>1]|0;c[3532414]=e[x+3728>>1]|0;i=c[3532491]|0;u=e[x+3714>>1]|0;c[3532491]=u;c[3532419]=e[x+3738>>1]|0;c[3532415]=e[x+3730>>1]|0;p=c[3532492]|0;r=e[x+3716>>1]|0;c[3532492]=r;c[3532420]=e[x+3740>>1]|0;c[3532416]=e[x+3732>>1]|0;q=c[3532493]|0;h=e[x+3718>>1]|0;c[3532493]=h;c[3532421]=e[x+3742>>1]|0;c[3532417]=e[x+3734>>1]|0;if((v|0)!=(d|0)){a[7461552]=1}if((i|0)!=(u|0)){a[7461568]=1}if((p|0)!=(r|0)){a[7461560]=1}if((q|0)!=(h|0)){a[7461576]=1}eO7();eO_();ePd();eO3(1);eO6(1,0,1);eO3(2);eO6(1,1,1);eO6(0,0,1);eO3(4);eO6(0,1,1);ePf();eO3(8);eO8(0);eO8(1);R8(c[3532488]|0);return 0}else{if(w){w=c[2112926]|0;gGz(w|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);return 0}w=c[3532368]|0;h=c[3532490]|0;q=e[w+3712>>1]|0;c[3532490]=q;c[3532418]=e[w+3736>>1]|0;c[3532414]=e[w+3728>>1]|0;r=c[3532491]|0;p=e[w+3714>>1]|0;c[3532491]=p;c[3532419]=e[w+3738>>1]|0;c[3532415]=e[w+3730>>1]|0;u=c[3532492]|0;i=e[w+3716>>1]|0;c[3532492]=i;c[3532420]=e[w+3740>>1]|0;c[3532416]=e[w+3732>>1]|0;d=c[3532493]|0;v=e[w+3718>>1]|0;c[3532493]=v;c[3532421]=e[w+3742>>1]|0;c[3532417]=e[w+3734>>1]|0;if((h|0)!=(q|0)){a[7461552]=1}if((r|0)!=(p|0)){a[7461568]=1}if((u|0)!=(i|0)){a[7461560]=1}if((d|0)!=(v|0)){a[7461576]=1}eO5();eO_();ePd();ePe(1);eO6(1,0,1);ePe(2);eO6(1,1,1);eO6(0,0,1);ePe(4);eO6(0,1,1);ePf();eO4(0);ePe(8);eO4(1);R8(c[3532488]|0);return 0}return 0}function eOQ(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;if((a[14129864]|0)!=0){eOH()}eOK();d=c[2113302]|0;do{if((d|0)!=0){f=c[3532570]|0;g=(c[3542196]|0)+(c[3532572]<<16>>16)|0;c[3542196]=g;h=(c[3542192]|0)+(f<<16>>16)|0;c[3542192]=h;if((g|0)<-2048){c[3542196]=-2048;i=-2048}else{i=g}g=(c[2440576]<<8)-2048|0;if((i|0)>(g|0)){c[3542196]=g}if((h|0)<-2048){c[3542192]=-2048;j=-2048}else{j=h}h=(c[2440574]<<8)-2048|0;if((j|0)>(h|0)){c[3542192]=h}if((d|0)<=1){break}f=c[3532566]|0;k=(c[3542197]|0)+(c[3532568]<<16>>16)|0;c[3542197]=k;l=(c[3542193]|0)+(f<<16>>16)|0;c[3542193]=l;if((k|0)<-2048){c[3542197]=-2048;m=-2048}else{m=k}if((m|0)>(g|0)){c[3542197]=g}if((l|0)<-2048){c[3542193]=-2048;n=-2048}else{n=l}if((n|0)>(h|0)){c[3542193]=h}if((d|0)<=2){break}l=c[3532562]|0;k=(c[3542198]|0)+(c[3532564]<<16>>16)|0;c[3542198]=k;f=(c[3542194]|0)+(l<<16>>16)|0;c[3542194]=f;if((k|0)<-2048){c[3542198]=-2048;o=-2048}else{o=k}if((o|0)>(g|0)){c[3542198]=g}if((f|0)<-2048){c[3542194]=-2048;p=-2048}else{p=f}if((p|0)<=(h|0)){break}c[3542194]=h}}while(0);p=c[2438]|0;o=gGU(p,(p|0)<0|0?-1:0,125e5,0)|0;p=gGS(o,K,15360,0)|0;o=p;c[2440506]=o;c[2440480]=o;c[2440476]=66666;c[2440474]=66666;gGz(8452136,0,16);o=c[2392]|0;if((o|0)>=0){gGz(8452240,0,((o|0)>0?(o<<2)+4|0:4)|0)}c[2113054]=0;o=c[2385548]|0;if((o|0)>0){gGz(9752472,0,((o|0)>1?o<<2:4)|0)}c[2433530]=0;o=0;p=0;L31698:while(1){d=o;while(1){if((d|0)>=100){break L31698}if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];n=c[3532592]|0;if((n|0)!=0){gGC(9104152,n|0,280)|0}c[2113054]=c[2113060]}q=d+1|0;n=(ag(c[2440506]|0,q)|0)/100|0;m=n-(c[2113034]|0)|0;c[2438176]=m;c[2113056]=m;n=RG(m)|0;c[2113054]=(c[2113054]|0)+n;c[2276108]=-1;c[2113056]=-1;c[2113034]=(c[2113034]|0)+n;L31709:do{switch(d|0){case 80:case 60:case 40:case 20:{c[8452200+(c[2394]<<2)>>2]=8194;c[2276080]=512;if((c[2276079]|0)>>>0>=512){r=0;break L31709}RH(2);r=0;break};case 99:{c[8452200+(c[2394]<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0>=1024){r=1;break L31709}RH(4);r=1;break};default:{r=0}}}while(0);n=c[2394]|0;m=c[14130368+(n<<2)>>2]|0;if((m|0)!=0){gGC(m|0,9104152,280)|0}c[8452240+(n<<2)>>2]=c[2113054];c[2394]=1;c[2112932]=c[3532597];n=c[3532593]|0;if((n|0)!=0){gGC(9104152,n|0,280)|0}c[2113054]=c[2113061];n=(ag(c[2440480]|0,q)|0)/100|0;m=n-(c[2113035]|0)|0;c[2438176]=m;c[2113056]=m;n=RG(m)|0;c[2113054]=(c[2113054]|0)+n;c[2276108]=-1;c[2113056]=-1;c[2438176]=n;c[2113035]=(c[2113035]|0)+n;do{if(r){c[8452200+(c[2394]<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0>=1024){break}RH(4)}}while(0);n=c[2394]|0;m=c[14130368+(n<<2)>>2]|0;if((m|0)!=0){gGC(m|0,9104152,280)|0}c[8452240+(n<<2)>>2]=c[2113054];c[2394]=-1;n=c[2439330]|0;if((n|0)!=0){m=n;gGC(9706056,m|0,76)|0}b[4853030]=c[2426515]&65535;m=c[2438118]|0;c[2433530]=m;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;j=(ag(c[2440476]|0,q)|0)/100|0;i=c[2113036]|0;h=j-i|0;c[2438176]=h;do{if((h|0)<1){s=0;t=i;u=0;v=n;w=m}else{if((a[n+4188|0]|0)==0){j=gfc(h)|0;f=(c[2433530]|0)+j|0;c[2433530]=f;g=c[1836236]|0;s=j;t=c[2113036]|0;u=g;v=c[9757320+(g<<2)>>2]|0;w=f;break}else{f=m+h|0;c[2433530]=f;s=h;t=i;u=0;v=n;w=f;break}}}while(0);c[2438176]=s;c[2113036]=t+s;if((v|0)!=0){n=v;gGC(n|0,9706056,76)|0}c[9752472+(u<<2)>>2]=w;c[14113936+(u<<2)>>2]=c[2076596];c[9669104+(u<<2)>>2]=c[3541536];c[1836236]=-1;if((c[3532326]|0)!=0){n=c[2439331]|0;if((n|0)!=0){i=n;gGC(9706056,i|0,76)|0}b[4853030]=c[2426515]&65535;i=c[2438119]|0;c[2433530]=i;c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;h=(ag(c[2440474]|0,q)|0)/100|0;m=c[2113037]|0;f=h-m|0;c[2438176]=f;do{if((f|0)<1){x=0;y=m;z=1;A=n;B=i}else{if((a[n+4188|0]|0)==0){h=gfc(f)|0;g=(c[2433530]|0)+h|0;c[2433530]=g;j=c[1836236]|0;x=h;y=c[2113037]|0;z=j;A=c[9757320+(j<<2)>>2]|0;B=g;break}else{g=i+f|0;c[2433530]=g;x=f;y=m;z=1;A=n;B=g;break}}}while(0);c[2438176]=x;c[2113037]=y+x;if((A|0)!=0){n=A;gGC(n|0,9706056,76)|0}c[9752472+(z<<2)>>2]=B;c[14113936+(z<<2)>>2]=c[2076596];c[9669104+(z<<2)>>2]=c[3541536];c[1836236]=-1}C=c[2112964]|0;if((C|0)==0){d=q}else{break}}d=a[9688]|0?5:0;n=C+(p<<1<<1)|0;m=c[2439330]|0;if((m|0)!=0){f=m;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;gg[c[3542124]&4095](n,d);f=c[1836236]|0;m=c[9757320+(f<<2)>>2]|0;if((m|0)!=0){i=m;gGC(i|0,9706056,76)|0}c[9752472+(f<<2)>>2]=c[2433530];c[14113936+(f<<2)>>2]=c[2076596];c[9669104+(f<<2)>>2]=c[3541536];c[1836236]=-1;if((c[3532496]|0)!=0){Vh(n,d)}o=q;p=d+p|0}q=c[2112964]|0;do{if((q|0)!=0){o=a[9688]|0?534:0;C=o-p|0;z=q+(p<<1<<1)|0;if((o|0)==(p|0)){break}o=c[2439330]|0;if((o|0)!=0){B=o;gGC(9706056,B|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;gg[c[3542124]&4095](z,C);B=c[1836236]|0;o=c[9757320+(B<<2)>>2]|0;if((o|0)!=0){A=o;gGC(A|0,9706056,76)|0}c[9752472+(B<<2)>>2]=c[2433530];c[14113936+(B<<2)>>2]=c[2076596];c[9669104+(B<<2)>>2]=c[3541536];c[1836236]=-1;if((c[3532496]|0)==0){break}Vh(z,C)}}while(0);if((c[2112968]|0)==0){return 0}if((c[3532340]|0)==0){p=c[2112926]|0;gGz(p|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);return 0}p=c[3532368]|0;q=c[3532490]|0;C=e[p+3712>>1]|0;c[3532490]=C;c[3532418]=e[p+3736>>1]|0;c[3532414]=e[p+3728>>1]|0;z=c[3532491]|0;B=e[p+3714>>1]|0;c[3532491]=B;c[3532419]=e[p+3738>>1]|0;c[3532415]=e[p+3730>>1]|0;A=c[3532492]|0;o=e[p+3716>>1]|0;c[3532492]=o;c[3532420]=e[p+3740>>1]|0;c[3532416]=e[p+3732>>1]|0;x=c[3532493]|0;y=e[p+3718>>1]|0;c[3532493]=y;c[3532421]=e[p+3742>>1]|0;c[3532417]=e[p+3734>>1]|0;if((q|0)!=(C|0)){a[7461552]=1}if((z|0)!=(B|0)){a[7461568]=1}if((A|0)!=(o|0)){a[7461560]=1}if((x|0)!=(y|0)){a[7461576]=1}eO5();eO_();ePd();if(a[7461544]|0){ePg(1);eO6(1,0,1);ePg(2);eO6(1,1,1);eO6(0,0,1);ePg(4);eO6(0,1,1);ePf()}else{ePf();ePg(1);eO6(1,0,1);ePg(2);eO6(1,1,1);eO6(0,0,1);ePg(4);eO6(0,1,1)}eO4(0);ePg(8);eO4(1);R8(c[3532488]|0);y=c[2113302]|0;if((y|0)>0){D=0}else{return 0}do{R7(D,c[14168784+(D<<2)>>2]>>8,c[14168768+(D<<2)>>2]>>8);D=D+1|0;}while((D|0)<(y|0));return 0}function eOR(){var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0;f=i;i=i+4096|0;g=f|0;if((a[14129864]|0)!=0){eOH()}if(a[7461592]|0){a[14130136]=0;h=a[14130144]|0;j=a[14130133]|0;if(h<<24>>24!=0&(c[2433318]|0)==0){k=j^1;a[14130133]=k;l=k}else{l=j}a[14130136]=l<<5&32|a[14130128]&1|a[14130129]<<1&2|a[14130130]<<2&4|a[14130131]<<3&8|a[14130132]<<4&16|a[14130134]<<6&64|a[14130135]<<7;c[2433318]=h&255}else{eOK()}h=c[2113302]|0;do{if((h|0)!=0){l=c[3532570]|0;j=(c[3542196]|0)+(c[3532572]<<16>>16)|0;c[3542196]=j;k=(c[3542192]|0)+(l<<16>>16)|0;c[3542192]=k;if((j|0)<-2048){c[3542196]=-2048;m=-2048}else{m=j}j=(c[2440576]<<8)-2048|0;if((m|0)>(j|0)){c[3542196]=j}if((k|0)<-2048){c[3542192]=-2048;n=-2048}else{n=k}k=(c[2440574]<<8)-2048|0;if((n|0)>(k|0)){c[3542192]=k}if((h|0)<=1){break}l=c[3532566]|0;o=(c[3542197]|0)+(c[3532568]<<16>>16)|0;c[3542197]=o;p=(c[3542193]|0)+(l<<16>>16)|0;c[3542193]=p;if((o|0)<-2048){c[3542197]=-2048;q=-2048}else{q=o}if((q|0)>(j|0)){c[3542197]=j}if((p|0)<-2048){c[3542193]=-2048;r=-2048}else{r=p}if((r|0)>(k|0)){c[3542193]=k}if((h|0)<=2){break}p=c[3532562]|0;o=(c[3542198]|0)+(c[3532564]<<16>>16)|0;c[3542198]=o;l=(c[3542194]|0)+(p<<16>>16)|0;c[3542194]=l;if((o|0)<-2048){c[3542198]=-2048;s=-2048}else{s=o}if((s|0)>(j|0)){c[3542198]=j}if((l|0)<-2048){c[3542194]=-2048;t=-2048}else{t=l}if((t|0)<=(k|0)){break}c[3542194]=k}}while(0);t=c[2438]|0;s=gGU(t,(t|0)<0|0?-1:0,125e5,0)|0;t=gGS(s,K,15360,0)|0;s=t;c[2440506]=s;c[2440480]=s;c[2440476]=s;c[2440474]=67116;gGz(8452136,0,16);s=c[2392]|0;if((s|0)>=0){gGz(8452240,0,((s|0)>0?(s<<2)+4|0:4)|0)}c[2113054]=0;s=c[2385548]|0;if((s|0)>0){gGz(9752472,0,((s|0)>1?s<<2:4)|0)}c[2433530]=0;s=0;t=0;L31861:while(1){h=s;while(1){if((h|0)>=262){break L31861}if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];r=c[3532592]|0;if((r|0)!=0){gGC(9104152,r|0,280)|0}c[2113054]=c[2113060]}u=h+1|0;r=(ag(c[2440506]|0,u)|0)/262|0;q=r-(c[2113034]|0)|0;c[2438176]=q;c[2113056]=q;r=RG(q)|0;c[2113054]=(c[2113054]|0)+r;c[2276108]=-1;c[2113056]=-1;c[2113034]=(c[2113034]|0)+r;r=(h|0)==170;do{if(r){c[8452200+(c[2394]<<2)>>2]=4098;c[2276080]=512;if((c[2276079]|0)>>>0>=512){v=0;w=0;x=0;break}RH(2);v=0;w=0;x=0}else{if((h|0)==224){c[8452200+(c[2394]<<2)>>2]=0;c[2276080]=0;v=0;w=0;x=1;break}else if((h|0)==223){c[8452200+(c[2394]<<2)>>2]=4100;c[2276080]=1024;if((c[2276079]|0)>>>0>=1024){v=1;w=0;x=0;break}RH(4);v=1;w=0;x=0;break}else if((h|0)==171){c[8452200+(c[2394]<<2)>>2]=0;c[2276080]=0;v=0;w=1;x=0;break}else{v=0;w=0;x=0;break}}}while(0);q=c[2394]|0;n=c[14130368+(q<<2)>>2]|0;if((n|0)!=0){gGC(n|0,9104152,280)|0}c[8452240+(q<<2)>>2]=c[2113054];c[2394]=1;c[2112932]=c[3532597];q=c[3532593]|0;if((q|0)!=0){gGC(9104152,q|0,280)|0}c[2113054]=c[2113061];q=(ag(c[2440480]|0,u)|0)/262|0;n=q-(c[2113035]|0)|0;c[2438176]=n;c[2113056]=n;q=RG(n)|0;c[2113054]=(c[2113054]|0)+q;c[2276108]=-1;c[2113056]=-1;c[2438176]=q;c[2113035]=(c[2113035]|0)+q;do{if(r){c[8452200+(c[2394]<<2)>>2]=4098;c[2276080]=512;if((c[2276079]|0)>>>0>=512){break}RH(2)}}while(0);if(w){c[8452200+(c[2394]<<2)>>2]=0;c[2276080]=0}do{if(v){c[8452200+(c[2394]<<2)>>2]=4100;c[2276080]=1024;if((c[2276079]|0)>>>0>=1024){break}RH(4)}}while(0);q=c[2394]|0;if(x){c[8452200+(q<<2)>>2]=0;c[2276080]=0}n=c[14130368+(q<<2)>>2]|0;if((n|0)!=0){gGC(n|0,9104152,280)|0}c[8452240+(q<<2)>>2]=c[2113054];c[2394]=2;c[2112932]=c[3532598];q=c[3532594]|0;if((q|0)!=0){gGC(9104152,q|0,280)|0}c[2113054]=c[2113062];q=(ag(c[2440476]|0,u)|0)/262|0;n=q-(c[2113036]|0)|0;c[2438176]=n;c[2113056]=n;q=RG(n)|0;c[2113054]=(c[2113054]|0)+q;c[2276108]=-1;c[2113056]=-1;c[2438176]=q;c[2113036]=(c[2113036]|0)+q;do{if(r){c[8452200+(c[2394]<<2)>>2]=4098;c[2276080]=512;if((c[2276079]|0)>>>0>=512){break}RH(2)}}while(0);if(w){c[8452200+(c[2394]<<2)>>2]=0;c[2276080]=0}do{if(v){c[8452200+(c[2394]<<2)>>2]=4100;c[2276080]=1024;if((c[2276079]|0)>>>0>=1024){break}RH(4)}}while(0);r=c[2394]|0;if(x){c[8452200+(r<<2)>>2]=0;c[2276080]=0}q=c[14130368+(r<<2)>>2]|0;if((q|0)!=0){gGC(q|0,9104152,280)|0}c[8452240+(r<<2)>>2]=c[2113054];c[2394]=-1;r=c[2439330]|0;if((r|0)!=0){q=r;gGC(9706056,q|0,76)|0}b[4853030]=c[2426515]&65535;q=c[2438118]|0;c[2433530]=q;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;n=(ag(c[2440474]|0,u)|0)/262|0;m=c[2113037]|0;k=n-m|0;c[2438176]=k;do{if((k|0)<1){y=0;z=m;A=0;B=r;C=q}else{if((a[r+4188|0]|0)==0){n=gfc(k)|0;l=(c[2433530]|0)+n|0;c[2433530]=l;j=c[1836236]|0;y=n;z=c[2113037]|0;A=j;B=c[9757320+(j<<2)>>2]|0;C=l;break}else{l=q+k|0;c[2433530]=l;y=k;z=m;A=0;B=r;C=l;break}}}while(0);c[2438176]=y;c[2113037]=z+y;if((B|0)!=0){r=B;gGC(r|0,9706056,76)|0}c[9752472+(A<<2)>>2]=C;c[14113936+(A<<2)>>2]=c[2076596];c[9669104+(A<<2)>>2]=c[3541536];c[1836236]=-1;D=c[2112964]|0;if((D|0)==0){h=u}else{break}}h=a[9688]|0?2:0;r=D+(t<<1<<1)|0;m=c[2439330]|0;if((m|0)!=0){k=m;gGC(9706056,k|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;gg[c[3542124]&4095](r,h);k=c[1836236]|0;m=c[9757320+(k<<2)>>2]|0;if((m|0)!=0){q=m;gGC(q|0,9706056,76)|0}c[9752472+(k<<2)>>2]=c[2433530];c[14113936+(k<<2)>>2]=c[2076596];c[9669104+(k<<2)>>2]=c[3541536];c[1836236]=-1;Vh(r,h);s=u;t=h+t|0}u=c[2112964]|0;do{if((u|0)!=0){s=a[9688]|0?534:0;D=s-t|0;A=u+(t<<1<<1)|0;if((s|0)==(t|0)){break}s=c[2439330]|0;if((s|0)!=0){C=s;gGC(9706056,C|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;gg[c[3542124]&4095](A,D);C=c[1836236]|0;s=c[9757320+(C<<2)>>2]|0;if((s|0)!=0){B=s;gGC(B|0,9706056,76)|0}c[9752472+(C<<2)>>2]=c[2433530];c[14113936+(C<<2)>>2]=c[2076596];c[9669104+(C<<2)>>2]=c[3541536];c[1836236]=-1;Vh(A,D)}}while(0);if((c[2112968]|0)==0){i=f;return 0}if((c[3532340]|0)==0){t=c[2112926]|0;gGz(t|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);i=f;return 0}eO_();t=c[3532408]|0;u=c[3532372]|0;D=c[3532426]|0;A=D;gGz(g|0,0,4096);C=c[2112930]|0;B=0;do{if((e[A+((B&-2)<<1)>>1]|0)<=16383){gGz(C+(B<<9<<1)|0,-1|0,1024)}B=B+1|0;}while((B|0)<512);B=t>>>19;t=u;u=c[3532388]|0;s=u;y=e[s>>1]|0;L31968:do{if((y&32768|0)==0){z=(B&255)<<24>>24==0;x=B&255;v=y;w=s;h=0;do{r=u;k=v<<4&32752;q=e[w+2>>1]|0;m=e[w+4>>1]|0;l=q>>>8&16|m>>>12;j=(q&4095)-1536|0;q=(m&4095)-1536|0;m=b[w+6>>1]|0;n=b[w+8>>1]|0;o=n&65535;p=b[w+10>>1]|0;E=p&65535;F=(E>>>13&2)-1|0;G=E&8192;H=E&4096;I=(H>>>11)-1|0;J=E&2047;E=b[w+12>>1]|0;L=(E&65535)<<1&65024;M=(E&255)<<24>>24;a[g+h|0]=1;h=b[w+14>>1]&4095;L31972:do{if(!((v&20480|0)!=0|n<<16>>16==0)){if(z){N=l}else{N=(l>>>0)%(x>>>0)|0}E=N<<16;O=(J|0)==0?1:J;P=ag(F,o)|0;Q=P+q|0;R=p&16384;if((P|0)==0){break}P=(F|0)<0;S=(G|0)==0;T=(H|0)==0;U=(I|0)>-1;V=p&2047;W=V>>>0>1?V:1;V=q;X=m;Y=0;while(1){L31980:do{if(V>>>0<512){Z=V<<9;_=b[A+((V&-2)<<1)>>1]|0;$=_&65535;if(($&32768|0)!=0&P){break L31972}if((R&_)<<16>>16!=0){break L31972}if(($&49152|0)!=0){break}_=$-1536|0;$=(e[A+((V|1)<<1)>>1]|0)-1536|0;aa=(_|0)<0?0:_;_=($|0)>511?511:$;if(S){$=0;ab=X+1&65535;ac=j;while(1){if((ac|0)>(_|0)|T){if(U|(ac|0)<(aa|0)){break L31980}}ad=ab-1&65535;ae=t+((ad&65535|E)<<3)|0;af=c[ae>>2]|0;ah=c[ae+4>>2]|0;ae=b[r+((af&15|k)<<1)>>1]|0;if(($|0)<512){ai=(ae&65535)<510;aj=(L|ae&65535|4096)&65535;ae=((511-$|0)>>>0)/(W>>>0)|0;ak=ag(ae+1|0,W)|0;al=ac;am=$;while(1){if(al>>>0<512&ai){b[C+(al+Z<<1)>>1]=aj}an=am+O|0;if((an|0)<512){al=al+I|0;am=an}else{break}}ao=ac+I+(ag(ae,I)|0)|0;ap=ak+$|0}else{ao=ac;ap=$}am=ap-512|0;al=b[r+(((af>>>4|ah<<28)&15|k)<<1)>>1]|0;if((am|0)<512){aj=(al&65535)<510;ai=(L|al&65535|4096)&65535;al=((1023-ap|0)>>>0)/(W>>>0)|0;an=ag(al+1|0,W)|0;aq=ao;ar=am;while(1){if(aq>>>0<512&aj){b[C+(aq+Z<<1)>>1]=ai}as=ar+O|0;if((as|0)<512){aq=aq+I|0;ar=as}else{break}}at=ao+I+(ag(al,I)|0)|0;au=an+am|0}else{at=ao;au=am}ar=au-512|0;aq=b[r+(((af>>>8|ah<<24)&15|k)<<1)>>1]|0;if((ar|0)<512){ai=(aq&65535)<510;aj=(L|aq&65535|4096)&65535;aq=((1023-au|0)>>>0)/(W>>>0)|0;ak=ag(aq+1|0,W)|0;ae=at;as=ar;while(1){if(ae>>>0<512&ai){b[C+(ae+Z<<1)>>1]=aj}av=as+O|0;if((av|0)<512){ae=ae+I|0;as=av}else{break}}aw=at+I+(ag(aq,I)|0)|0;ax=ak+ar|0}else{aw=at;ax=ar}as=ax-512|0;ae=b[r+(((af>>>12|ah<<20)&15|k)<<1)>>1]|0;if((as|0)<512){aj=(ae&65535)<510;ai=(L|ae&65535|4096)&65535;ae=((1023-ax|0)>>>0)/(W>>>0)|0;am=ag(ae+1|0,W)|0;an=aw;al=as;while(1){if(an>>>0<512&aj){b[C+(an+Z<<1)>>1]=ai}av=al+O|0;if((av|0)<512){an=an+I|0;al=av}else{break}}ay=aw+I+(ag(ae,I)|0)|0;az=am+as|0}else{ay=aw;az=as}al=az-512|0;an=b[r+(((af>>>16|ah<<16)&15|k)<<1)>>1]|0;if((al|0)<512){ai=(an&65535)<510;aj=(L|an&65535|4096)&65535;an=((1023-az|0)>>>0)/(W>>>0)|0;ar=ag(an+1|0,W)|0;ak=ay;aq=al;while(1){if(ak>>>0<512&ai){b[C+(ak+Z<<1)>>1]=aj}av=aq+O|0;if((av|0)<512){ak=ak+I|0;aq=av}else{break}}aA=ay+I+(ag(an,I)|0)|0;aB=ar+al|0}else{aA=ay;aB=al}aq=aB-512|0;ak=b[r+(((af>>>20|ah<<12)&15|k)<<1)>>1]|0;if((aq|0)<512){aj=(ak&65535)<510;ai=(L|ak&65535|4096)&65535;ak=((1023-aB|0)>>>0)/(W>>>0)|0;as=ag(ak+1|0,W)|0;am=aA;ae=aq;while(1){if(am>>>0<512&aj){b[C+(am+Z<<1)>>1]=ai}av=ae+O|0;if((av|0)<512){am=am+I|0;ae=av}else{break}}aC=aA+I+(ag(ak,I)|0)|0;aD=as+aq|0}else{aC=aA;aD=aq}ae=aD-512|0;am=b[r+(((af>>>24|ah<<8)&15|k)<<1)>>1]|0;if((ae|0)<512){ai=(am&65535)<510;aj=(L|am&65535|4096)&65535;am=((1023-aD|0)>>>0)/(W>>>0)|0;al=ag(am+1|0,W)|0;ar=aC;an=ae;while(1){if(ar>>>0<512&ai){b[C+(ar+Z<<1)>>1]=aj}av=an+O|0;if((av|0)<512){ar=ar+I|0;an=av}else{break}}aE=aC+I+(ag(am,I)|0)|0;aF=al+ae|0}else{aE=aC;aF=ae}an=aF-512|0;ar=b[r+(((af>>>28|ah<<4)&15|k)<<1)>>1]|0;if((an|0)<512){aj=(ar&65535)<510;ai=(L|ar&65535|4096)&65535;ar=((1023-aF|0)>>>0)/(W>>>0)|0;aq=ag(ar+1|0,W)|0;as=aE;ak=an;while(1){if(as>>>0<512&aj){b[C+(as+Z<<1)>>1]=ai}av=ak+O|0;if((av|0)<512){as=as+I|0;ak=av}else{break}}aG=aE+I+(ag(ar,I)|0)|0;aH=aq+an|0}else{aG=aE;aH=an}ak=aH-512|0;as=b[r+((ah&15|k)<<1)>>1]|0;if((ak|0)<512){ai=(as&65535)<510;aj=(L|as&65535|4096)&65535;as=((1023-aH|0)>>>0)/(W>>>0)|0;af=ag(as+1|0,W)|0;ae=aG;al=ak;while(1){if(ae>>>0<512&ai){b[C+(ae+Z<<1)>>1]=aj}am=al+O|0;if((am|0)<512){ae=ae+I|0;al=am}else{break}}aI=aG+I+(ag(as,I)|0)|0;aJ=af+ak|0}else{aI=aG;aJ=ak}al=aJ-512|0;ae=b[r+(((ah>>>4|0<<28)&15|k)<<1)>>1]|0;if((al|0)<512){aj=(ae&65535)<510;ai=(L|ae&65535|4096)&65535;ae=((1023-aJ|0)>>>0)/(W>>>0)|0;an=ag(ae+1|0,W)|0;aq=aI;ar=al;while(1){if(aq>>>0<512&aj){b[C+(aq+Z<<1)>>1]=ai}am=ar+O|0;if((am|0)<512){aq=aq+I|0;ar=am}else{break}}aK=aI+I+(ag(ae,I)|0)|0;aL=an+al|0}else{aK=aI;aL=al}ar=aL-512|0;aq=b[r+(((ah>>>8|0<<24)&15|k)<<1)>>1]|0;if((ar|0)<512){ai=(aq&65535)<510;aj=(L|aq&65535|4096)&65535;aq=((1023-aL|0)>>>0)/(W>>>0)|0;ak=ag(aq+1|0,W)|0;af=aK;as=ar;while(1){if(af>>>0<512&ai){b[C+(af+Z<<1)>>1]=aj}am=as+O|0;if((am|0)<512){af=af+I|0;as=am}else{break}}aM=aK+I+(ag(aq,I)|0)|0;aN=ak+ar|0}else{aM=aK;aN=ar}as=aN-512|0;af=b[r+(((ah>>>12|0<<20)&15|k)<<1)>>1]|0;if((as|0)<512){aj=(af&65535)<510;ai=(L|af&65535|4096)&65535;af=((1023-aN|0)>>>0)/(W>>>0)|0;al=ag(af+1|0,W)|0;an=aM;ae=as;while(1){if(an>>>0<512&aj){b[C+(an+Z<<1)>>1]=ai}am=ae+O|0;if((am|0)<512){an=an+I|0;ae=am}else{break}}aO=aM+I+(ag(af,I)|0)|0;aP=al+as|0}else{aO=aM;aP=as}ae=aP-512|0;an=b[r+(((ah>>>16|0<<16)&15|k)<<1)>>1]|0;if((ae|0)<512){ai=(an&65535)<510;aj=(L|an&65535|4096)&65535;an=((1023-aP|0)>>>0)/(W>>>0)|0;ar=ag(an+1|0,W)|0;ak=aO;aq=ae;while(1){if(ak>>>0<512&ai){b[C+(ak+Z<<1)>>1]=aj}am=aq+O|0;if((am|0)<512){ak=ak+I|0;aq=am}else{break}}aQ=aO+I+(ag(an,I)|0)|0;aR=ar+ae|0}else{aQ=aO;aR=ae}aq=aR-512|0;ak=b[r+(((ah>>>20|0<<12)&15|k)<<1)>>1]|0;if((aq|0)<512){aj=(ak&65535)<510;ai=(L|ak&65535|4096)&65535;ak=((1023-aR|0)>>>0)/(W>>>0)|0;as=ag(ak+1|0,W)|0;al=aQ;af=aq;while(1){if(al>>>0<512&aj){b[C+(al+Z<<1)>>1]=ai}am=af+O|0;if((am|0)<512){al=al+I|0;af=am}else{break}}aS=aQ+I+(ag(ak,I)|0)|0;aT=as+aq|0}else{aS=aQ;aT=aq}af=aT-512|0;al=b[r+(((ah>>>24|0<<8)&15|k)<<1)>>1]|0;if((af|0)<512){ai=(al&65535)<510;aj=(L|al&65535|4096)&65535;al=((1023-aT|0)>>>0)/(W>>>0)|0;ae=ag(al+1|0,W)|0;ar=aS;an=af;while(1){if(ar>>>0<512&ai){b[C+(ar+Z<<1)>>1]=aj}am=an+O|0;if((am|0)<512){ar=ar+I|0;an=am}else{break}}aU=aS+I+(ag(al,I)|0)|0;aV=ae+af|0}else{aU=aS;aV=af}an=aV-512|0;ar=ah>>>28|0<<4;aj=b[r+((ar|k)<<1)>>1]|0;if((an|0)<512){ai=(aj&65535)<510;aq=(L|aj&65535|4096)&65535;aj=((1023-aV|0)>>>0)/(W>>>0)|0;as=ag(aj+1|0,W)|0;ak=aU;am=an;while(1){if(ak>>>0<512&ai){b[C+(ak+Z<<1)>>1]=aq}av=am+O|0;if((av|0)<512){ak=ak+I|0;am=av}else{break}}aW=aU+I+(ag(aj,I)|0)|0;aX=as+an|0}else{aW=aU;aX=an}if((ar|0)==15){break}else{$=aX-512|0;ab=ad;ac=aW}}}else{ac=0;ab=X-1&65535;$=j;while(1){if(($|0)>(_|0)|T){if(U|($|0)<(aa|0)){break L31980}}am=ab+1&65535;ak=t+((am&65535|E)<<3)|0;aq=c[ak>>2]|0;ai=c[ak+4>>2]|0;ak=b[r+((ai>>>28|0<<4|k)<<1)>>1]|0;if((ac|0)<512){ah=(ak&65535)<510;af=(L|ak&65535|4096)&65535;ak=((511-ac|0)>>>0)/(W>>>0)|0;ae=ag(ak+1|0,W)|0;al=$;av=ac;while(1){if(al>>>0<512&ah){b[C+(al+Z<<1)>>1]=af}aY=av+O|0;if((aY|0)<512){al=al+I|0;av=aY}else{break}}aZ=$+I+(ag(ak,I)|0)|0;a_=ae+ac|0}else{aZ=$;a_=ac}av=a_-512|0;al=b[r+(((ai>>>24|0<<8)&15|k)<<1)>>1]|0;if((av|0)<512){af=(al&65535)<510;ah=(L|al&65535|4096)&65535;al=((1023-a_|0)>>>0)/(W>>>0)|0;ad=ag(al+1|0,W)|0;ar=aZ;an=av;while(1){if(ar>>>0<512&af){b[C+(ar+Z<<1)>>1]=ah}as=an+O|0;if((as|0)<512){ar=ar+I|0;an=as}else{break}}a$=aZ+I+(ag(al,I)|0)|0;a0=ad+av|0}else{a$=aZ;a0=av}an=a0-512|0;ar=b[r+(((ai>>>20|0<<12)&15|k)<<1)>>1]|0;if((an|0)<512){ah=(ar&65535)<510;af=(L|ar&65535|4096)&65535;ar=((1023-a0|0)>>>0)/(W>>>0)|0;ae=ag(ar+1|0,W)|0;ak=a$;as=an;while(1){if(ak>>>0<512&ah){b[C+(ak+Z<<1)>>1]=af}aj=as+O|0;if((aj|0)<512){ak=ak+I|0;as=aj}else{break}}a1=a$+I+(ag(ar,I)|0)|0;a2=ae+an|0}else{a1=a$;a2=an}as=a2-512|0;ak=b[r+(((ai>>>16|0<<16)&15|k)<<1)>>1]|0;if((as|0)<512){af=(ak&65535)<510;ah=(L|ak&65535|4096)&65535;ak=((1023-a2|0)>>>0)/(W>>>0)|0;av=ag(ak+1|0,W)|0;ad=a1;al=as;while(1){if(ad>>>0<512&af){b[C+(ad+Z<<1)>>1]=ah}aj=al+O|0;if((aj|0)<512){ad=ad+I|0;al=aj}else{break}}a3=a1+I+(ag(ak,I)|0)|0;a4=av+as|0}else{a3=a1;a4=as}al=a4-512|0;ad=b[r+(((ai>>>12|0<<20)&15|k)<<1)>>1]|0;if((al|0)<512){ah=(ad&65535)<510;af=(L|ad&65535|4096)&65535;ad=((1023-a4|0)>>>0)/(W>>>0)|0;an=ag(ad+1|0,W)|0;ae=a3;ar=al;while(1){if(ae>>>0<512&ah){b[C+(ae+Z<<1)>>1]=af}aj=ar+O|0;if((aj|0)<512){ae=ae+I|0;ar=aj}else{break}}a5=a3+I+(ag(ad,I)|0)|0;a6=an+al|0}else{a5=a3;a6=al}ar=a6-512|0;ae=b[r+(((ai>>>8|0<<24)&15|k)<<1)>>1]|0;if((ar|0)<512){af=(ae&65535)<510;ah=(L|ae&65535|4096)&65535;ae=((1023-a6|0)>>>0)/(W>>>0)|0;as=ag(ae+1|0,W)|0;av=a5;ak=ar;while(1){if(av>>>0<512&af){b[C+(av+Z<<1)>>1]=ah}aj=ak+O|0;if((aj|0)<512){av=av+I|0;ak=aj}else{break}}a7=a5+I+(ag(ae,I)|0)|0;a8=as+ar|0}else{a7=a5;a8=ar}ak=a8-512|0;av=b[r+(((ai>>>4|0<<28)&15|k)<<1)>>1]|0;if((ak|0)<512){ah=(av&65535)<510;af=(L|av&65535|4096)&65535;av=((1023-a8|0)>>>0)/(W>>>0)|0;al=ag(av+1|0,W)|0;an=a7;ad=ak;while(1){if(an>>>0<512&ah){b[C+(an+Z<<1)>>1]=af}aj=ad+O|0;if((aj|0)<512){an=an+I|0;ad=aj}else{break}}a9=a7+I+(ag(av,I)|0)|0;ba=al+ak|0}else{a9=a7;ba=ak}ad=ba-512|0;an=b[r+((ai&15|k)<<1)>>1]|0;if((ad|0)<512){af=(an&65535)<510;ah=(L|an&65535|4096)&65535;an=((1023-ba|0)>>>0)/(W>>>0)|0;ar=ag(an+1|0,W)|0;as=a9;ae=ad;while(1){if(as>>>0<512&af){b[C+(as+Z<<1)>>1]=ah}aj=ae+O|0;if((aj|0)<512){as=as+I|0;ae=aj}else{break}}bb=a9+I+(ag(an,I)|0)|0;bc=ar+ad|0}else{bb=a9;bc=ad}ae=bc-512|0;as=b[r+(((aq>>>28|ai<<4)&15|k)<<1)>>1]|0;if((ae|0)<512){ah=(as&65535)<510;af=(L|as&65535|4096)&65535;as=((1023-bc|0)>>>0)/(W>>>0)|0;ak=ag(as+1|0,W)|0;al=bb;av=ae;while(1){if(al>>>0<512&ah){b[C+(al+Z<<1)>>1]=af}aj=av+O|0;if((aj|0)<512){al=al+I|0;av=aj}else{break}}bd=bb+I+(ag(as,I)|0)|0;be=ak+ae|0}else{bd=bb;be=ae}av=be-512|0;al=b[r+(((aq>>>24|ai<<8)&15|k)<<1)>>1]|0;if((av|0)<512){af=(al&65535)<510;ah=(L|al&65535|4096)&65535;al=((1023-be|0)>>>0)/(W>>>0)|0;ad=ag(al+1|0,W)|0;ar=bd;an=av;while(1){if(ar>>>0<512&af){b[C+(ar+Z<<1)>>1]=ah}aj=an+O|0;if((aj|0)<512){ar=ar+I|0;an=aj}else{break}}bf=bd+I+(ag(al,I)|0)|0;bg=ad+av|0}else{bf=bd;bg=av}an=bg-512|0;ar=b[r+(((aq>>>20|ai<<12)&15|k)<<1)>>1]|0;if((an|0)<512){ah=(ar&65535)<510;af=(L|ar&65535|4096)&65535;ar=((1023-bg|0)>>>0)/(W>>>0)|0;ae=ag(ar+1|0,W)|0;ak=bf;as=an;while(1){if(ak>>>0<512&ah){b[C+(ak+Z<<1)>>1]=af}aj=as+O|0;if((aj|0)<512){ak=ak+I|0;as=aj}else{break}}bh=bf+I+(ag(ar,I)|0)|0;bi=ae+an|0}else{bh=bf;bi=an}as=bi-512|0;ak=b[r+(((aq>>>16|ai<<16)&15|k)<<1)>>1]|0;if((as|0)<512){af=(ak&65535)<510;ah=(L|ak&65535|4096)&65535;ak=((1023-bi|0)>>>0)/(W>>>0)|0;av=ag(ak+1|0,W)|0;ad=bh;al=as;while(1){if(ad>>>0<512&af){b[C+(ad+Z<<1)>>1]=ah}aj=al+O|0;if((aj|0)<512){ad=ad+I|0;al=aj}else{break}}bj=bh+I+(ag(ak,I)|0)|0;bk=av+as|0}else{bj=bh;bk=as}al=bk-512|0;ad=b[r+(((aq>>>12|ai<<20)&15|k)<<1)>>1]|0;if((al|0)<512){ah=(ad&65535)<510;af=(L|ad&65535|4096)&65535;ad=((1023-bk|0)>>>0)/(W>>>0)|0;an=ag(ad+1|0,W)|0;ae=bj;ar=al;while(1){if(ae>>>0<512&ah){b[C+(ae+Z<<1)>>1]=af}aj=ar+O|0;if((aj|0)<512){ae=ae+I|0;ar=aj}else{break}}bl=bj+I+(ag(ad,I)|0)|0;bm=an+al|0}else{bl=bj;bm=al}ar=bm-512|0;ae=b[r+(((aq>>>8|ai<<24)&15|k)<<1)>>1]|0;if((ar|0)<512){af=(ae&65535)<510;ah=(L|ae&65535|4096)&65535;ae=((1023-bm|0)>>>0)/(W>>>0)|0;as=ag(ae+1|0,W)|0;av=bl;ak=ar;while(1){if(av>>>0<512&af){b[C+(av+Z<<1)>>1]=ah}aj=ak+O|0;if((aj|0)<512){av=av+I|0;ak=aj}else{break}}bn=bl+I+(ag(ae,I)|0)|0;bo=as+ar|0}else{bn=bl;bo=ar}ak=bo-512|0;av=b[r+(((aq>>>4|ai<<28)&15|k)<<1)>>1]|0;if((ak|0)<512){ah=(av&65535)<510;af=(L|av&65535|4096)&65535;av=((1023-bo|0)>>>0)/(W>>>0)|0;al=ag(av+1|0,W)|0;an=bn;ad=ak;while(1){if(an>>>0<512&ah){b[C+(an+Z<<1)>>1]=af}aj=ad+O|0;if((aj|0)<512){an=an+I|0;ad=aj}else{break}}bp=bn+I+(ag(av,I)|0)|0;bq=al+ak|0}else{bp=bn;bq=ak}ad=bq-512|0;an=aq&15;af=b[r+((an|k)<<1)>>1]|0;if((ad|0)<512){ah=(af&65535)<510;ai=(L|af&65535|4096)&65535;af=((1023-bq|0)>>>0)/(W>>>0)|0;ar=ag(af+1|0,W)|0;as=bp;ae=ad;while(1){if(as>>>0<512&ah){b[C+(as+Z<<1)>>1]=ai}aj=ae+O|0;if((aj|0)<512){as=as+I|0;ae=aj}else{break}}br=bp+I+(ag(af,I)|0)|0;bs=ar+ad|0}else{br=bp;bs=ad}if((an|0)==15){break}else{ac=bs-512|0;ab=am;$=br}}}}}while(0);$=Y+O|0;ab=(ag($>>>9,M)|0)+(X&65535)&65535;ac=V+F|0;if((ac|0)==(Q|0)){break}else{V=ac;X=ab;Y=$&511}}}}while(0);w=u+(h<<3<<1)|0;v=e[w>>1]|0;if((v&32768|0)!=0){break L31968}}while((a[g+h|0]|0)==0)}}while(0);g=e[D+2024>>1]<<16|e[D+2026>>1];u=e[D+2028>>1]<<16|e[D+2030>>1];br=e[D+2032>>1]<<16|e[D+2034>>1];bs=e[D+2036>>1]<<16|e[D+2038>>1];bp=c[2112926]|0;bq=c[3532486]|0;bn=bq+8191|0;bo=0;bl=(bs*27|0)+(e[D+2020>>1]<<16|e[D+2022>>1])|0;bm=(u*27|0)+(e[D+2016>>1]<<16|e[D+2018>>1])|0;while(1){D=bp+((bo*320|0)<<1)|0;bj=bm;bk=bl;bh=0;while(1){bi=bk>>>14&511;bf=b[C+((bi<<9|bj>>>14&511)<<1)>>1]|0;bg=bf&65535;if(bf<<16>>16==-1){bt=bi&65535}else{bt=bn&(bg&511|bg>>>6&512|bg>>>3&3072|4096)&65535}b[D>>1]=bt;bg=bh+1|0;if((bg|0)<320){D=D+2|0;bj=bj+u|0;bk=bk+bs|0;bh=bg}else{break}}bh=bo+1|0;if((bh|0)<224){bo=bh;bl=bl+g|0;bm=bm+br|0}else{break}}br=c[3532374]|0;bm=(c[3532380]|0)>>>17;g=c[3532390]|0;bl=g+((c[3532384]|0)>>>1<<1)|0;L32299:do{if(g>>>0<bl>>>0){bo=(bm&255)<<24>>24==0;bs=bm&255;u=bq+4095|0;bt=bq+65535|0;bn=c[3532484]|0;C=g;do{bh=b[C+4>>1]|0;bk=bh&65535;if((bk&32768|0)!=0){break L32299}bj=e[C>>1]|0;D=bj>>>8;bg=bj&255;bj=(b[C+2>>1]&511)-184|0;bi=bk&256;bf=(bh&255)<<24>>24;bh=b[C+6>>1]|0;bd=e[C+8>>1]|0;be=c[14129568+((bd>>>8&15)<<2)>>2]|0;bb=bd<<4&2032;bd=C+10|0;bc=b[bd>>1]|0;a9=(bc&65535)>>>5;ba=bc&31;a7=C+14|0;b[a7>>1]=bh;L32304:do{if(!(bg>>>0>=D>>>0|(bk&16384|0)!=0|(be|0)==255)){if(bo){bu=be}else{bu=(be|0)%(bs|0)|0}a8=bu<<16;a5=bc&1023;b[bd>>1]=a5;a6=a9<<10&31744;a3=ba<<2;a4=(bi|0)==0;a1=bg;a2=bh;a$=a5;while(1){a5=(a2&65535)+bf|0;a0=a$+a6&65535;if(a0<<16>>16>-1){bv=a5&65535;bw=a0}else{bv=a5+bf&65535;bw=a0&32767}b[bd>>1]=bw;L32314:do{if(a1>>>0<224){a0=a1*320|0;if(a4){b[a7>>1]=bv-1&65535;a5=a3;aZ=bj;while(1){if((bj-aZ&511|0)==1){break L32314}a_=(b[a7>>1]|0)+1&65535;b[a7>>1]=a_;t=e[br+((a_&65535|a8)<<1)>>1]|0;if(((a5&63)+ba|0)<64){a_=t>>>12;do{if(aZ>>>0<320){if((a_|0)==14){aW=bp+(aZ+a0<<1)|0;aX=e[aW>>1]&bt;b[aW>>1]=aX&65535;b[aW>>1]=(bq<<((d[bn+(aX+1)|0]|0)>>>7&255))+aX&65535;break}else if((a_|0)==15|(a_|0)==0){break}else{b[bp+(aZ+a0<<1)>>1]=u&(bb|a_|2048)&65535;break}}}while(0);bx=aZ+1|0}else{bx=aZ}a_=a5+ba|0;if(((a_&63)+ba|0)<64){am=t>>>8&15;do{if(bx>>>0<320){if((am|0)==14){an=bp+(bx+a0<<1)|0;ad=e[an>>1]&bt;b[an>>1]=ad&65535;b[an>>1]=(bq<<((d[bn+(ad+1)|0]|0)>>>7&255))+ad&65535;break}else if((am|0)==15|(am|0)==0){break}else{b[bp+(bx+a0<<1)>>1]=u&(bb|am|2048)&65535;break}}}while(0);by=bx+1|0}else{by=bx}am=a_+ba|0;if(((am&63)+ba|0)<64){ad=t>>>4&15;do{if(by>>>0<320){if((ad|0)==14){an=bp+(by+a0<<1)|0;ar=e[an>>1]&bt;b[an>>1]=ar&65535;b[an>>1]=(bq<<((d[bn+(ar+1)|0]|0)>>>7&255))+ar&65535;break}else if((ad|0)==15|(ad|0)==0){break}else{b[bp+(by+a0<<1)>>1]=u&(bb|ad|2048)&65535;break}}}while(0);bz=by+1|0}else{bz=by}ad=t&15;a_=(am+ba&63)+ba|0;if((a_|0)<64){do{if(bz>>>0<320){if((ad|0)==14){ar=bp+(bz+a0<<1)|0;an=e[ar>>1]&bt;b[ar>>1]=an&65535;b[ar>>1]=(bq<<((d[bn+(an+1)|0]|0)>>>7&255))+an&65535;break}else if((ad|0)==15|(ad|0)==0){break}else{b[bp+(bz+a0<<1)>>1]=u&(bb|ad|2048)&65535;break}}}while(0);bA=bz+1|0}else{bA=bz}if((ad|0)==15){break}else{a5=a_;aZ=bA}}}else{b[a7>>1]=bv+1&65535;aZ=a3;a5=bj;while(1){if((bj-a5&511|0)==1){break L32314}am=(b[a7>>1]|0)-1&65535;b[a7>>1]=am;t=e[br+((am&65535|a8)<<1)>>1]|0;if(((aZ&63)+ba|0)<64){am=t&15;do{if(a5>>>0<320){if((am|0)==14){an=bp+(a5+a0<<1)|0;ar=e[an>>1]&bt;b[an>>1]=ar&65535;b[an>>1]=(bq<<((d[bn+(ar+1)|0]|0)>>>7&255))+ar&65535;break}else if((am|0)==15|(am|0)==0){break}else{b[bp+(a5+a0<<1)>>1]=u&(bb|am|2048)&65535;break}}}while(0);bB=a5+1|0}else{bB=a5}am=aZ+ba|0;if(((am&63)+ba|0)<64){a_=t>>>4&15;do{if(bB>>>0<320){if((a_|0)==14){ad=bp+(bB+a0<<1)|0;ar=e[ad>>1]&bt;b[ad>>1]=ar&65535;b[ad>>1]=(bq<<((d[bn+(ar+1)|0]|0)>>>7&255))+ar&65535;break}else if((a_|0)==15|(a_|0)==0){break}else{b[bp+(bB+a0<<1)>>1]=u&(bb|a_|2048)&65535;break}}}while(0);bC=bB+1|0}else{bC=bB}a_=am+ba|0;if(((a_&63)+ba|0)<64){ar=t>>>8&15;do{if(bC>>>0<320){if((ar|0)==14){ad=bp+(bC+a0<<1)|0;an=e[ad>>1]&bt;b[ad>>1]=an&65535;b[ad>>1]=(bq<<((d[bn+(an+1)|0]|0)>>>7&255))+an&65535;break}else if((ar|0)==15|(ar|0)==0){break}else{b[bp+(bC+a0<<1)>>1]=u&(bb|ar|2048)&65535;break}}}while(0);bD=bC+1|0}else{bD=bC}ar=t>>>12;am=(a_+ba&63)+ba|0;if((am|0)<64){do{if(bD>>>0<320){if((ar|0)==14){an=bp+(bD+a0<<1)|0;ad=e[an>>1]&bt;b[an>>1]=ad&65535;b[an>>1]=(bq<<((d[bn+(ad+1)|0]|0)>>>7&255))+ad&65535;break}else if((ar|0)==15|(ar|0)==0){break}else{b[bp+(bD+a0<<1)>>1]=u&(bb|ar|2048)&65535;break}}}while(0);bE=bD+1|0}else{bE=bD}if((ar|0)==15){break}else{aZ=am;a5=bE}}}}}while(0);a5=a1+1|0;if((a5|0)>=(D|0)){break L32304}a1=a5;a2=bv;a$=b[bd>>1]|0}}}while(0);C=C+16|0;}while(C>>>0<bl>>>0)}}while(0);R8(c[3532488]|0);bl=c[2113302]|0;if((bl|0)>0){bF=0}else{i=f;return 0}do{R7(bF,c[14168784+(bF<<2)>>2]>>8,c[14168768+(bF<<2)>>2]>>8);bF=bF+1|0;}while((bF|0)<(bl|0));i=f;return 0}function eOS(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0;g=i;i=i+1024|0;h=g|0;j=g+16|0;k=g+32|0;l=g+48|0;m=g+64|0;n=g+80|0;o=g+96|0;p=g+112|0;q=g+128|0;r=g+144|0;s=g+160|0;t=g+176|0;u=g+192|0;v=g+208|0;w=g+224|0;x=g+240|0;y=g+256|0;z=g+272|0;A=g+288|0;B=g+304|0;C=g+320|0;D=g+336|0;E=g+352|0;F=g+368|0;G=g+384|0;H=g+400|0;I=g+416|0;J=g+432|0;K=g+448|0;L=g+464|0;M=g+480|0;N=g+496|0;O=g+512|0;P=g+528|0;Q=g+544|0;R=g+560|0;S=g+576|0;T=g+592|0;U=g+608|0;V=g+624|0;W=g+640|0;X=g+656|0;Y=g+672|0;Z=g+688|0;_=g+704|0;$=g+720|0;aa=g+736|0;ab=g+752|0;ac=g+768|0;ad=g+784|0;ae=g+800|0;af=g+816|0;ag=g+832|0;ah=g+848|0;ai=g+864|0;aj=g+880|0;ak=g+896|0;al=g+912|0;am=g+928|0;an=g+944|0;ao=g+960|0;ap=g+976|0;aq=g+992|0;ar=g+1008|0;as=(f|0)==0;if(!as){c[f>>2]=169753}do{if((e&8|0)!=0){at=c[(c[642608+(c[2436]<<2)>>2]|0)+60>>2]&-65536;do{if((at|0)==33619968|(at|0)==33685504){if(a[7461608]|0){gGz(ar|0,0,12);c[ar>>2]=c[3532558];c[ar+4>>2]=16384;c[ar+12>>2]=210056;au=c[2076592]|0;gj[au&4095](ar)|0}if(!(a[7461616]|0)){break}gGz(ar|0,0,12);c[ar>>2]=c[3532556];c[ar+4>>2]=16384;c[ar+12>>2]=514056;au=c[2076592]|0;gj[au&4095](ar)|0}}while(0);at=c[(c[642608+(c[2436]<<2)>>2]|0)+60>>2]&-65536;if(!((at|0)==34078720|(at|0)==33816576|(at|0)==33751040|(at|0)==33947648)){break}gGz(ar|0,0,12);c[ar>>2]=c[3532470];c[ar+4>>2]=c[3532468];c[ar+12>>2]=397736;at=c[2076592]|0;gj[at&4095](ar)|0}}while(0);if((e&32|0)!=0){gGz(ar|0,0,12);at=c[3532638]|0;c[ar>>2]=at;c[ar+4>>2]=(c[3532642]|0)-at;c[ar+12>>2]=162152;at=c[2076592]|0;gj[at&4095](ar)|0}if((e&64|0)==0){i=g;return 0}ar=N|0;gGz(M|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){at=N+9|0;N=L;au=L|0;av=L+4|0;aw=L+12|0;ax=M|0;ay=M+4|0;az=M+12|0;aA=0;do{gGC(ar|0,614896,11)|0;a[at]=aA+48&255;aB=8452256+(aA<<2)|0;gGz(N|0,0,12);c[au>>2]=aB;c[av>>2]=4;c[aw>>2]=164976;gj[c[2076592]&4095](L)|0;if((c[aB>>2]|0)!=0){c[ax>>2]=c[14130368+(aA<<2)>>2];c[ay>>2]=c[8452184+(aA<<2)>>2];c[az>>2]=ar;aB=c[2076592]|0;gj[aB&4095](M)|0}aA=aA+1|0;}while((aA|0)<=(c[2392]|0))}if((c[3532310]|0)==0){aA=c[(c[642608+(c[2436]<<2)>>2]|0)+60>>2]|0;if((aA&16384|0)==0){aC=aA}else{aD=24543}}else{aD=24543}if((aD|0)==24543){fw$(e);aC=c[(c[642608+(c[2436]<<2)>>2]|0)+60>>2]|0}if((aC&8256|0)==0){aE=aC}else{gGz(u|0,0,12);c[u>>2]=9717160;c[u+4>>2]=4;c[u+12>>2]=211216;aC=c[2076592]|0;gj[aC&4095](u)|0;gGz(t|0,0,12);c[t>>2]=9762952;c[t+4>>2]=4;c[t+12>>2]=514472;u=c[2076592]|0;gj[u&4095](t)|0;t=c[2440738]|0;if((e&2|0)!=0&(t|0)!=-1){u=c[2429290]|0;eNM(256);eNP();aC=c[3528544]|0;if((c[2394]|0)==(aC|0)){aF=c[2112932]|0;aG=c[14130368+(aC<<2)>>2]|0}else{c[2394]=aC;aA=c[14130384+(aC<<2)>>2]|0;c[2112932]=aA;M=c[14130368+(aC<<2)>>2]|0;if((M|0)!=0){gGC(9104152,M|0,280)|0}c[2113054]=c[8452240+(aC<<2)>>2];aF=aA;aG=M}c[aF+196860>>2]=11962;c[aF+196852>>2]=2e3;c[aF+196856>>2]=1134;if((aG|0)!=0){gGC(aG|0,9104152,280)|0}c[8452240+(aC<<2)>>2]=c[2113054];c[2394]=-1;eNM(u);eNM(t)}aE=c[(c[642608+(c[2436]<<2)>>2]|0)+60>>2]|0}t=aE&-65536;if((t|0)==33751040|(t|0)==34013184|(t|0)==34078720){gGz(F|0,0,12);c[F>>2]=9668984;c[F+4>>2]=81;c[F+12>>2]=207392;t=c[2076592]|0;gj[t&4095](F)|0}if((c[2113302]|0)!=0){gGz(E|0,0,12);c[E>>2]=14168784;c[E+4>>2]=16;c[E+12>>2]=249744;F=c[2076592]|0;gj[F&4095](E)|0;gGz(D|0,0,12);c[D>>2]=14168768;c[D+4>>2]=16;c[D+12>>2]=524320;E=c[2076592]|0;gj[E&4095](D)|0}gGz(aq|0,0,12);c[aq>>2]=14129648;c[aq+4>>2]=4;c[aq+12>>2]=235224;gj[c[2076592]&4095](aq)|0;gGz(ap|0,0,12);c[ap>>2]=14130136;c[ap+4>>2]=7;c[ap+12>>2]=183304;gj[c[2076592]&4095](ap)|0;gGz(ao|0,0,12);c[ao>>2]=14130176;c[ao+4>>2]=3;c[ao+12>>2]=147824;gj[c[2076592]&4095](ao)|0;gGz(an|0,0,12);c[an>>2]=14129360;c[an+4>>2]=4;c[an+12>>2]=118256;gj[c[2076592]&4095](an)|0;gGz(am|0,0,12);c[am>>2]=14129688;c[am+4>>2]=4;c[am+12>>2]=93208;gj[c[2076592]&4095](am)|0;gGz(al|0,0,12);c[al>>2]=14129672;c[al+4>>2]=16;c[al+12>>2]=73384;gj[c[2076592]&4095](al)|0;gGz(ak|0,0,12);c[ak>>2]=14129656;c[ak+4>>2]=16;c[ak+12>>2]=580616;gj[c[2076592]&4095](ak)|0;gGz(aj|0,0,12);c[aj>>2]=14130200;c[aj+4>>2]=4;c[aj+12>>2]=563640;gj[c[2076592]&4095](aj)|0;gGz(ai|0,0,12);c[ai>>2]=14129696;c[ai+4>>2]=4;c[ai+12>>2]=547888;gj[c[2076592]&4095](ai)|0;gGz(ah|0,0,12);c[ah>>2]=14129568;c[ah+4>>2]=64;c[ah+12>>2]=533640;gj[c[2076592]&4095](ah)|0;gGz(ag|0,0,12);c[ag>>2]=14129432;c[ag+4>>2]=32;c[ag+12>>2]=520120;gj[c[2076592]&4095](ag)|0;gGz(af|0,0,12);c[af>>2]=14129960;c[af+4>>2]=16;c[af+12>>2]=506728;gj[c[2076592]&4095](af)|0;gGz(ae|0,0,12);c[ae>>2]=14168816;c[ae+4>>2]=4;c[ae+12>>2]=494712;gj[c[2076592]&4095](ae)|0;gGz(ad|0,0,12);c[ad>>2]=14168808;c[ad+4>>2]=4;c[ad+12>>2]=482688;gj[c[2076592]&4095](ad)|0;gGz(ac|0,0,12);c[ac>>2]=14130240;c[ac+4>>2]=4;c[ac+12>>2]=470264;gj[c[2076592]&4095](ac)|0;gGz(ab|0,0,12);c[ab>>2]=9733272;c[ab+4>>2]=4;c[ab+12>>2]=458776;gj[c[2076592]&4095](ab)|0;gGz(aa|0,0,12);c[aa>>2]=8452136;c[aa+4>>2]=16;c[aa+12>>2]=448504;gj[c[2076592]&4095](aa)|0;gGz($|0,0,12);c[$>>2]=9752704;c[$+4>>2]=4;c[$+12>>2]=436576;gj[c[2076592]&4095]($)|0;gGz(_|0,0,12);c[_>>2]=14129832;c[_+4>>2]=4;c[_+12>>2]=425960;gj[c[2076592]&4095](_)|0;gGz(Z|0,0,12);c[Z>>2]=9579128;c[Z+4>>2]=24;c[Z+12>>2]=413544;gj[c[2076592]&4095](Z)|0;gGz(Y|0,0,12);c[Y>>2]=9644816;c[Y+4>>2]=48;c[Y+12>>2]=402656;gj[c[2076592]&4095](Y)|0;gGz(X|0,0,12);c[X>>2]=9757208;c[X+4>>2]=72;c[X+12>>2]=391112;gj[c[2076592]&4095](X)|0;gGz(W|0,0,12);c[W>>2]=9773128;c[W+4>>2]=1;c[W+12>>2]=380288;gj[c[2076592]&4095](W)|0;gGz(V|0,0,12);c[V>>2]=9750512;c[V+4>>2]=4;c[V+12>>2]=369960;gj[c[2076592]&4095](V)|0;gGz(U|0,0,12);c[U>>2]=9720184;c[U+4>>2]=4;c[U+12>>2]=361192;gj[c[2076592]&4095](U)|0;gGz(T|0,0,12);c[T>>2]=14129216;c[T+4>>2]=4;c[T+12>>2]=354064;gj[c[2076592]&4095](T)|0;gGz(S|0,0,12);c[S>>2]=14129224;c[S+4>>2]=4;c[S+12>>2]=346136;gj[c[2076592]&4095](S)|0;gGz(R|0,0,12);c[R>>2]=9717960;c[R+4>>2]=4;c[R+12>>2]=337984;gj[c[2076592]&4095](R)|0;gGz(Q|0,0,12);c[Q>>2]=7461512;c[Q+4>>2]=1;c[Q+12>>2]=330312;gj[c[2076592]&4095](Q)|0;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+60>>2]|0;do{if((Q&-65536|0)==33947648){do{if(!as){if((c[f>>2]|0)>=169249){break}c[f>>2]=169249}}while(0);gGz(B|0,0,12);c[B>>2]=9775320;c[B+4>>2]=8;c[B+12>>2]=111920;R=c[2076592]|0;gj[R&4095](B)|0;gGz(A|0,0,12);c[A>>2]=9775288;c[A+4>>2]=8;c[A+12>>2]=478936;R=c[2076592]|0;gj[R&4095](A)|0;gGz(z|0,0,12);c[z>>2]=53400;c[z+4>>2]=8;c[z+12>>2]=398448;R=c[2076592]|0;gj[R&4095](z)|0;gGz(y|0,0,12);c[y>>2]=14114048;c[y+4>>2]=4;c[y+12>>2]=287368;R=c[2076592]|0;gj[R&4095](y)|0;gGz(C|0,0,12);c[C>>2]=9734152;c[C+4>>2]=4;c[C+12>>2]=139856;R=c[2076592]|0;gj[R&4095](C)|0;gGz(s|0,0,12);c[s>>2]=(c[2420422]|0)+99;c[s+4>>2]=65536;c[s+12>>2]=116280;R=c[2076592]|0;gj[R&4095](s)|0;R=(c[2420422]|0)+96|0;gGz(r|0,0,12);c[r>>2]=R;c[r+4>>2]=1;c[r+12>>2]=481552;R=c[2076592]|0;gj[R&4095](r)|0;R=(c[2420422]|0)+97|0;gGz(q|0,0,12);c[q>>2]=R;c[q+4>>2]=1;c[q+12>>2]=368936;R=c[2076592]|0;gj[R&4095](q)|0;R=(c[2420422]|0)+98|0;gGz(p|0,0,12);c[p>>2]=R;c[p+4>>2]=1;c[p+12>>2]=288328;R=c[2076592]|0;gj[R&4095](p)|0;R=o;S=o|0;T=o+4|0;U=o+12|0;V=n;W=n|0;X=n+4|0;Y=n+12|0;Z=m;_=m|0;$=m+4|0;aa=m+12|0;ab=l;ac=l|0;ad=l+4|0;ae=l+12|0;af=k;ag=k|0;ah=k+4|0;ai=k+12|0;aj=j;ak=j|0;al=j+4|0;am=j+12|0;an=h;ao=h|0;ap=h+4|0;aq=h+12|0;D=0;do{E=c[2420422]|0;gGz(R|0,0,12);c[S>>2]=E+(D*12|0);c[T>>2]=1;c[U>>2]=219528;gj[c[2076592]&4095](o)|0;gGz(V|0,0,12);c[W>>2]=E+(D*12|0)+1;c[X>>2]=1;c[Y>>2]=172136;gj[c[2076592]&4095](n)|0;gGz(Z|0,0,12);c[_>>2]=E+(D*12|0)+2;c[$>>2]=1;c[aa>>2]=138856;gj[c[2076592]&4095](m)|0;gGz(ab|0,0,12);c[ac>>2]=E+(D*12|0)+3;c[ad>>2]=1;c[ae>>2]=112048;gj[c[2076592]&4095](l)|0;gGz(af|0,0,12);c[ag>>2]=E+(D*12|0)+4;c[ah>>2]=4;c[ai>>2]=87320;gj[c[2076592]&4095](k)|0;gGz(aj|0,0,12);c[ak>>2]=E+(D*12|0)+8;c[al>>2]=2;c[am>>2]=67960;gj[c[2076592]&4095](j)|0;gGz(an|0,0,12);c[ao>>2]=E+(D*12|0)+10;c[ap>>2]=2;c[aq>>2]=576128;gj[c[2076592]&4095](h)|0;D=D+1|0;}while((D|0)<8);if((e&2|0)==0){break}D=c[2439330]|0;if((D|0)!=0){aq=D;gGC(9706056,aq|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];aq=c[3528484]|0;c[2076596]=aq;ap=c[2417276]|0;c[3541536]=ap;c[1836236]=0;ao=c[3532330]|0;an=(c[2429490]|0)+24576|0;am=160;al=160;while(1){c[D+76+(al<<2)>>2]=ao+(an+(al<<8));ak=am+1&65535;if((ak&65535)>191){break}else{am=ak;al=ak&65535}}al=(c[2429490]|0)+24576|0;am=160;an=160;while(1){ak=ao+(al+(an<<8))|0;c[D+76+(an+512<<2)>>2]=ak;c[D+76+(an+768<<2)>>2]=ak;ak=am+1&65535;if((ak&65535)>191){break}else{am=ak;an=ak&65535}}an=D;gGC(an|0,9706056,76)|0;c[2438118]=c[2433530];c[3528484]=aq;c[2417276]=ap;c[1836236]=-1}else{if((Q&256|0)!=0){Vx(e,f);break}if((Q&4096|0)!=0){mt(e);break}gGz(x|0,0,12);c[x>>2]=8453216;c[x+4>>2]=4;c[x+12>>2]=107480;gj[c[2076592]&4095](x)|0;gGz(w|0,0,12);c[w>>2]=14168504;c[w+4>>2]=256;c[w+12>>2]=476464;gj[c[2076592]&4095](w)|0;if((e&2|0)==0){break}else{aH=0}do{mv(0,aH,d[14168504+aH|0]|0);aH=aH+1|0;}while((aH|0)<256)}}while(0);do{if((c[3532344]|0)!=0){aH=J|0;if(!as){c[f>>2]=169600}c[2424874]=c[2418506];cC(aH|0,100600,(w=i,i=i+8|0,c[w>>2]=0,w)|0)|0;i=w;c[v>>2]=9699496;c[v+4>>2]=80;c[v+8>>2]=0;c[v+12>>2]=aH;aH=c[2076592]|0;gj[aH&4095](v)|0;if((e&2|0)==0){break}aH=c[2439330]|0;if((aH|0)!=0){w=aH;gGC(9706056,w|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];w=c[3528484]|0;c[2076596]=w;x=c[2417276]|0;c[3541536]=x;c[1836236]=0;Q=c[3532348]|0;h=(c[2430046]|0)-32768|0;j=128;k=128;while(1){c[aH+76+(k<<2)>>2]=Q+(h+(k<<8));l=j+1&65535;if((l&65535)>223){break}else{j=l;k=l&65535}}k=(c[2430046]|0)-32768|0;j=128;h=128;while(1){l=Q+(k+(h<<8))|0;c[aH+76+(h+512<<2)>>2]=l;c[aH+76+(h+768<<2)>>2]=l;l=j+1&65535;if((l&65535)>223){break}else{j=l;h=l&65535}}h=aH;gGC(h|0,9706056,76)|0;c[2438118]=c[2433530];c[3528484]=w;c[2417276]=x;c[1836236]=-1}}while(0);do{if((c[3532574]|0)!=0){v=I;h=J|0;if(!as){c[f>>2]=169753}gGz(H|0,0,12);c[H>>2]=9718216;c[H+4>>2]=56;c[H+12>>2]=164080;j=c[2076592]|0;gj[j&4095](H)|0;gGC(h|0,501144,9)|0;gGz(v|0,0,12);c[I>>2]=c[2426620];c[I+4>>2]=128;c[I+12>>2]=h;h=c[2076592]|0;gj[h&4095](I)|0;gGz(G|0,0,12);c[G>>2]=9762432;c[G+4>>2]=4;c[G+12>>2]=385208;h=c[2076592]|0;gj[h&4095](G)|0;if(!as){c[f>>2]=169753}if((c[2405758]|0)<=0){break}h=K;v=K|0;j=K+4|0;k=K+12|0;Q=0;do{gGz(h|0,0,12);c[v>>2]=9542544+(Q<<5);c[j>>2]=2;c[k>>2]=119040;gj[c[2076592]&4095](K)|0;Q=Q+1|0;}while((Q|0)<(c[2405758]|0))}}while(0);do{if((c[3532496]|0)!=0){K=P;if(!as){c[f>>2]=169753}if(((c[2385510]|0)+1|0)<=0){break}G=O;I=O|0;H=O+4|0;J=O+12|0;Q=P|0;k=P+4|0;j=P+12|0;v=0;do{h=9699504+(v<<2)|0;x=(c[h>>2]|0)+2048|0;gGz(G|0,0,12);c[I>>2]=x;c[H>>2]=16;c[J>>2]=101944;gj[c[2076592]&4095](O)|0;gGz(K|0,0,12);c[Q>>2]=c[h>>2];c[k>>2]=2048;c[j>>2]=473808;gj[c[2076592]&4095](P)|0;v=v+1|0;}while((v|0)<((c[2385510]|0)+1|0))}}while(0);if((e&66|0)!=66){i=g;return 0}e=c[(c[642608+(c[2436]<<2)>>2]|0)+60>>2]&-65536;if((e|0)==33751040|(e|0)==34013184){aD=24606}else if(!((e|0)==33816576|(e|0)==33947648|(e|0)==34078720|(e|0)==33619968)){i=g;return 0}do{if((aD|0)==24606){a[7461568]=1;a[7461552]=1;if((e|0)==33816576|(e|0)==33947648|(e|0)==34078720|(e|0)==33619968){break}i=g;return 0}}while(0);a[7461568]=1;a[7461576]=1;a[7461552]=1;a[7461560]=1;i=g;return 0}function eOT(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((a|0)==0){b=0}else{a=0;while(1){if((a|0)>=1024){d=0;break}e=9638528+(a<<2)|0;if((c[e>>2]|0)==0){f=24617;break}else{a=a+1|0}}do{if((f|0)==24617){a=gGq(1048576)|0;c[e>>2]=a;if((a|0)==0){d=0;break}gGz(a|0,0,1048576);d=a}}while(0);c[2427220]=d;b=0}while(1){if((b|0)>=1024){g=0;break}h=9638528+(b<<2)|0;if((c[h>>2]|0)==0){f=24622;break}else{b=b+1|0}}do{if((f|0)==24622){b=gGq(1048576)|0;c[h>>2]=b;if((b|0)==0){g=0;break}gGz(b|0,0,1048576);g=b}}while(0);c[2429594]=g;g=0;while(1){if((g|0)>=1024){i=0;break}j=9638528+(g<<2)|0;if((c[j>>2]|0)==0){f=24627;break}else{g=g+1|0}}do{if((f|0)==24627){g=gGq(1048576)|0;c[j>>2]=g;if((g|0)==0){i=0;break}gGz(g|0,0,1048576);i=g}}while(0);c[2429592]=i;i=0;while(1){if((i|0)>=1024){k=0;break}l=9638528+(i<<2)|0;if((c[l>>2]|0)==0){f=24632;break}else{i=i+1|0}}do{if((f|0)==24632){i=gGq(1048576)|0;c[l>>2]=i;if((i|0)==0){k=0;break}gGz(i|0,0,1048576);k=i}}while(0);c[2429590]=k;k=0;while(1){if((k|0)>=1024){m=0;f=24640;break}n=9638528+(k<<2)|0;if((c[n>>2]|0)==0){break}else{k=k+1|0}}if((f|0)==24640){c[2429588]=m;return}f=gGq(1048576)|0;c[n>>2]=f;if((f|0)==0){m=0;c[2429588]=m;return}gGz(f|0,0,1048576);m=f;c[2429588]=m;return}function eOU(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;if((a|0)==0){b=0}else{a=0;while(1){if((a|0)>=1024){d=0;break}e=9638528+(a<<2)|0;if((c[e>>2]|0)==0){f=24646;break}else{a=a+1|0}}do{if((f|0)==24646){a=gGq(1048576)|0;c[e>>2]=a;if((a|0)==0){d=0;break}gGz(a|0,0,1048576);d=a}}while(0);c[2427220]=d;d=0;while(1){if((d|0)>=1024){g=0;break}h=9638528+(d<<2)|0;if((c[h>>2]|0)==0){f=24651;break}else{d=d+1|0}}do{if((f|0)==24651){d=gGq(1048576)|0;c[h>>2]=d;if((d|0)==0){g=0;break}gGz(d|0,0,1048576);g=d}}while(0);c[2426992]=g;b=0}while(1){if((b|0)>=1024){i=0;break}j=9638528+(b<<2)|0;if((c[j>>2]|0)==0){f=24656;break}else{b=b+1|0}}do{if((f|0)==24656){b=gGq(1048576)|0;c[j>>2]=b;if((b|0)==0){i=0;break}gGz(b|0,0,1048576);i=b}}while(0);c[2429594]=i;i=0;while(1){if((i|0)>=1024){k=0;break}l=9638528+(i<<2)|0;if((c[l>>2]|0)==0){f=24661;break}else{i=i+1|0}}do{if((f|0)==24661){i=gGq(1048576)|0;c[l>>2]=i;if((i|0)==0){k=0;break}gGz(i|0,0,1048576);k=i}}while(0);c[2429592]=k;k=0;while(1){if((k|0)>=1024){m=0;break}n=9638528+(k<<2)|0;if((c[n>>2]|0)==0){f=24666;break}else{k=k+1|0}}do{if((f|0)==24666){k=gGq(1048576)|0;c[n>>2]=k;if((k|0)==0){m=0;break}gGz(k|0,0,1048576);m=k}}while(0);c[2429590]=m;m=0;while(1){if((m|0)>=1024){o=0;break}p=9638528+(m<<2)|0;if((c[p>>2]|0)==0){f=24671;break}else{m=m+1|0}}do{if((f|0)==24671){m=gGq(1048576)|0;c[p>>2]=m;if((m|0)==0){o=0;break}gGz(m|0,0,1048576);o=m}}while(0);c[2429588]=o;o=0;while(1){if((o|0)>=1024){q=0;break}r=9638528+(o<<2)|0;if((c[r>>2]|0)==0){f=24676;break}else{o=o+1|0}}do{if((f|0)==24676){o=gGq(1048576)|0;c[r>>2]=o;if((o|0)==0){q=0;break}gGz(o|0,0,1048576);q=o}}while(0);c[2427070]=q;q=0;while(1){if((q|0)>=1024){s=0;break}t=9638528+(q<<2)|0;if((c[t>>2]|0)==0){f=24681;break}else{q=q+1|0}}do{if((f|0)==24681){q=gGq(1048576)|0;c[t>>2]=q;if((q|0)==0){s=0;break}gGz(q|0,0,1048576);s=q}}while(0);c[2427068]=s;s=0;while(1){if((s|0)>=1024){u=0;break}v=9638528+(s<<2)|0;if((c[v>>2]|0)==0){f=24686;break}else{s=s+1|0}}do{if((f|0)==24686){s=gGq(1048576)|0;c[v>>2]=s;if((s|0)==0){u=0;break}gGz(s|0,0,1048576);u=s}}while(0);c[2427066]=u;u=0;while(1){if((u|0)>=1024){w=0;f=24694;break}x=9638528+(u<<2)|0;if((c[x>>2]|0)==0){break}else{u=u+1|0}}if((f|0)==24694){c[2427064]=w;return}f=gGq(1048576)|0;c[x>>2]=f;if((f|0)==0){w=0;c[2427064]=w;return}gGz(f|0,0,1048576);w=f;c[2427064]=w;return}function eOV(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=c[3532356]|0;g=c[3532490]|0;h=g<<12&61440;i=g>>>4<<12&61440;j=g>>>8<<12&61440;k=g&61440;g=c[3532491]|0;l=g<<12&61440;m=g>>>4<<12&61440;n=g>>>8<<12&61440;o=g&61440;do{if(h>>>0>d>>>0|(h|4095)>>>0<d>>>0){if(!(i>>>0>d>>>0|(i|4095)>>>0<d>>>0)){p=24701;break}if(!(j>>>0>d>>>0|(j|4095)>>>0<d>>>0)){p=24701;break}if(!(k>>>0>d>>>0|(k|4095)>>>0<d>>>0)){p=24701}}else{p=24701}}while(0);do{if((p|0)==24701){if((b[f+(d>>>1<<1)>>1]|0)==e<<16>>16){break}a[7461552]=1}}while(0);do{if(l>>>0>d>>>0|(l|4095)>>>0<d>>>0){if(!(m>>>0>d>>>0|(m|4095)>>>0<d>>>0)){break}if(!(n>>>0>d>>>0|(n|4095)>>>0<d>>>0)){break}if(!(o>>>0>d>>>0|(o|4095)>>>0<d>>>0)){break}q=f+(d>>>1<<1)|0;b[q>>1]=e;return}}while(0);o=f+(d>>>1<<1)|0;if((b[o>>1]|0)==e<<16>>16){q=o;b[q>>1]=e;return}a[7461568]=1;q=o;b[q>>1]=e;return}function eOW(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=c[3532490]|0;f=e<<12&61440;g=e>>>4<<12&61440;h=e>>>8<<12&61440;i=e&61440;e=c[3532491]|0;j=e<<12&61440;k=e>>>4<<12&61440;l=e>>>8<<12&61440;m=e&61440;do{if(f>>>0>b>>>0|(f|4095)>>>0<b>>>0){if(!(g>>>0>b>>>0|(g|4095)>>>0<b>>>0)){n=24718;break}if(!(h>>>0>b>>>0|(h|4095)>>>0<b>>>0)){n=24718;break}if(!(i>>>0>b>>>0|(i|4095)>>>0<b>>>0)){n=24718}}else{n=24718}}while(0);do{if((n|0)==24718){if((a[(c[3532356]|0)+b|0]|0)==d<<24>>24){break}a[7461552]=1}}while(0);do{if(j>>>0>b>>>0|(j|4095)>>>0<b>>>0){if(!(k>>>0>b>>>0|(k|4095)>>>0<b>>>0)){break}if(!(l>>>0>b>>>0|(l|4095)>>>0<b>>>0)){break}if(!(m>>>0>b>>>0|(m|4095)>>>0<b>>>0)){break}o=c[3532356]|0;p=o+b|0;a[p]=d;return}}while(0);m=c[3532356]|0;if((a[m+b|0]|0)==d<<24>>24){o=m;p=o+b|0;a[p]=d;return}a[7461568]=1;o=m;p=o+b|0;a[p]=d;return}function eOX(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;f=c[3532356]|0;g=c[3532490]|0;h=g<<12&61440;i=g>>>4<<12&61440;j=g>>>8<<12&61440;k=g&61440;g=c[3532491]|0;l=g<<12&61440;m=g>>>4<<12&61440;n=g>>>8<<12&61440;o=g&61440;g=c[3532492]|0;p=g<<12&61440;q=g>>>4<<12&61440;r=g>>>8<<12&61440;s=g&61440;g=c[3532493]|0;t=g<<12&61440;u=g>>>4<<12&61440;v=g>>>8<<12&61440;w=g&61440;do{if(h>>>0>d>>>0|(h|4095)>>>0<d>>>0){if(!(i>>>0>d>>>0|(i|4095)>>>0<d>>>0)){x=24735;break}if(!(j>>>0>d>>>0|(j|4095)>>>0<d>>>0)){x=24735;break}if(!(k>>>0>d>>>0|(k|4095)>>>0<d>>>0)){x=24735}}else{x=24735}}while(0);do{if((x|0)==24735){if((b[f+(d>>>1<<1)>>1]|0)==e<<16>>16){break}a[7461552]=1}}while(0);do{if(l>>>0>d>>>0|(l|4095)>>>0<d>>>0){if(!(m>>>0>d>>>0|(m|4095)>>>0<d>>>0)){x=24741;break}if(!(n>>>0>d>>>0|(n|4095)>>>0<d>>>0)){x=24741;break}if(!(o>>>0>d>>>0|(o|4095)>>>0<d>>>0)){x=24741}}else{x=24741}}while(0);do{if((x|0)==24741){if((b[f+(d>>>1<<1)>>1]|0)==e<<16>>16){break}a[7461568]=1}}while(0);do{if(p>>>0>d>>>0|(p|4095)>>>0<d>>>0){if(!(q>>>0>d>>>0|(q|4095)>>>0<d>>>0)){x=24747;break}if(!(r>>>0>d>>>0|(r|4095)>>>0<d>>>0)){x=24747;break}if(!(s>>>0>d>>>0|(s|4095)>>>0<d>>>0)){x=24747}}else{x=24747}}while(0);do{if((x|0)==24747){if((b[f+(d>>>1<<1)>>1]|0)==e<<16>>16){break}a[7461560]=1}}while(0);do{if(t>>>0>d>>>0|(t|4095)>>>0<d>>>0){if(!(u>>>0>d>>>0|(u|4095)>>>0<d>>>0)){break}if(!(v>>>0>d>>>0|(v|4095)>>>0<d>>>0)){break}if(!(w>>>0>d>>>0|(w|4095)>>>0<d>>>0)){break}y=f+(d>>>1<<1)|0;b[y>>1]=e;return}}while(0);w=f+(d>>>1<<1)|0;if((b[w>>1]|0)==e<<16>>16){y=w;b[y>>1]=e;return}a[7461576]=1;y=w;b[y>>1]=e;return}function eOY(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;e=c[3532490]|0;f=e<<12&61440;g=e>>>4<<12&61440;h=e>>>8<<12&61440;i=e&61440;e=c[3532491]|0;j=e<<12&61440;k=e>>>4<<12&61440;l=e>>>8<<12&61440;m=e&61440;e=c[3532492]|0;n=e<<12&61440;o=e>>>4<<12&61440;p=e>>>8<<12&61440;q=e&61440;e=c[3532493]|0;r=e<<12&61440;s=e>>>4<<12&61440;t=e>>>8<<12&61440;u=e&61440;do{if(f>>>0>b>>>0|(f|4095)>>>0<b>>>0){if(!(g>>>0>b>>>0|(g|4095)>>>0<b>>>0)){v=24764;break}if(!(h>>>0>b>>>0|(h|4095)>>>0<b>>>0)){v=24764;break}if(!(i>>>0>b>>>0|(i|4095)>>>0<b>>>0)){v=24764}}else{v=24764}}while(0);do{if((v|0)==24764){if((a[(c[3532356]|0)+b|0]|0)==d<<24>>24){break}a[7461552]=1}}while(0);do{if(j>>>0>b>>>0|(j|4095)>>>0<b>>>0){if(!(k>>>0>b>>>0|(k|4095)>>>0<b>>>0)){v=24770;break}if(!(l>>>0>b>>>0|(l|4095)>>>0<b>>>0)){v=24770;break}if(!(m>>>0>b>>>0|(m|4095)>>>0<b>>>0)){v=24770}}else{v=24770}}while(0);do{if((v|0)==24770){if((a[(c[3532356]|0)+b|0]|0)==d<<24>>24){break}a[7461568]=1}}while(0);do{if(n>>>0>b>>>0|(n|4095)>>>0<b>>>0){if(!(o>>>0>b>>>0|(o|4095)>>>0<b>>>0)){v=24776;break}if(!(p>>>0>b>>>0|(p|4095)>>>0<b>>>0)){v=24776;break}if(!(q>>>0>b>>>0|(q|4095)>>>0<b>>>0)){v=24776}}else{v=24776}}while(0);do{if((v|0)==24776){if((a[(c[3532356]|0)+b|0]|0)==d<<24>>24){break}a[7461560]=1}}while(0);do{if(r>>>0>b>>>0|(r|4095)>>>0<b>>>0){if(!(s>>>0>b>>>0|(s|4095)>>>0<b>>>0)){break}if(!(t>>>0>b>>>0|(t|4095)>>>0<b>>>0)){break}if(!(u>>>0>b>>>0|(u|4095)>>>0<b>>>0)){break}w=c[3532356]|0;x=w+b|0;a[x]=d;return}}while(0);u=c[3532356]|0;if((a[u+b|0]|0)==d<<24>>24){w=u;x=w+b|0;a[x]=d;return}a[7461576]=1;w=u;x=w+b|0;a[x]=d;return}function eOZ(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;if(a[7461568]|0){f=c[3532356]|0;g=a[7461600]|0;if(g){gGz(c[2427220]|0,0,1048576)}h=c[3532491]|0;i=(h>>>4&1799|h<<4&28784)&65535;h=(c[(c[642608+(c[2436]<<2)>>2]|0)+60>>2]&-65536|0)==34013184?i&13107:i;i=(h&65535)>>>4;j=(h&65535)>>>8;k=(h&65535)>>>12;l=(c[3532508]|0)+8191|0;m=a[7461520]|0?7168:0;n=c[3532350]|0;o=m|256;p=0;q=0;do{q=(p|0)==1?c[2429592]|0:(p|0)==0?c[2429594]|0:q;gGz(q|0,0,1048576);r=0;do{s=(r|0)==1;t=(r|0)==2;u=(r|0)==3;v=u?512:s?512:0;w=u?256:t?256:0;x=((u?k:(t?j:s?i:h)&15)&65535)<<11;s=0;do{t=(s<<3)+w|0;u=(s<<6)+x|0;y=t<<10;z=0;do{A=e[f+(u+z<<1)>>1]|0;if((A>>>12&1|0)==(p|0)){B=(z<<3)+v|0;C=l&(A>>>1&4096|A&4095);D=A>>>5&127;if(D>>>0>63){E=m|(D>>>0>95?768:512)}else{E=D>>>0>31?o:m}if(g){A=c[2427220]|0;F=n+(C<<6)|0;c[2112928]=F;G=E|D<<3;H=A+(B+y<<1)|0;A=0;I=F;while(1){b[H>>1]=(d[I]|0|G)&65535;b[H+2>>1]=(d[I+1|0]|0|G)&65535;b[H+4>>1]=(d[I+2|0]|0|G)&65535;b[H+6>>1]=(d[I+3|0]|0|G)&65535;b[H+8>>1]=(d[I+4|0]|0|G)&65535;b[H+10>>1]=(d[I+5|0]|0|G)&65535;b[H+12>>1]=(d[I+6|0]|0|G)&65535;b[H+14>>1]=(d[I+7|0]|0|G)&65535;F=A+1|0;J=I+8|0;if((F|0)<8){H=H+2048|0;A=F;I=J}else{break}}c[2112928]=J}ePh(q,C,B,t,D,E,n)}z=z+1|0;}while((z|0)<64);s=s+1|0;}while((s|0)<32);r=r+1|0;}while((r|0)<4);p=p+1|0;}while((p|0)<2);a[7461568]=0}if(!(a[7461552]|0)){return}p=c[3532356]|0;gGz(c[2429590]|0,0,1048576);gGz(c[2429588]|0,0,1048576);n=c[3532490]|0;E=(n>>>4&1799|n<<4&28784)&65535;n=(c[(c[642608+(c[2436]<<2)>>2]|0)+60>>2]&-65536|0)==34013184?E&13107:E;E=(n&65535)>>>4;q=(n&65535)>>>8;J=(n&65535)>>>12;g=(c[3532508]|0)-1|0;m=a[7461520]|0?7168:0;o=m|256;l=c[3532350]|0;f=0;do{h=(f|0)==1;i=(f|0)==2;j=(f|0)==3;k=j?512:h?512:0;r=j?256:i?256:0;s=((j?J:(i?q:h?E:n)&15)&65535)<<11;h=0;do{i=(h<<3)+r|0;j=(h<<6)+s|0;v=0;do{x=e[p+(j+v<<1)>>1]|0;w=(v<<3)+k|0;z=(x>>>1&4096|x&4095)&g;t=x>>>5&127;if(t>>>0>63){K=(t>>>0>95?768:512)|m}else{K=t>>>0>31?o:m}if((x&4096|0)==0){ePh(c[2429590]|0,z,w,i,t,K,l)}else{ePh(c[2429588]|0,z,w,i,t,K,l)}v=v+1|0;}while((v|0)<64);h=h+1|0;}while((h|0)<32);f=f+1|0;}while((f|0)<4);a[7461552]=0;return}function eO_(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[3532486]|0;b=a<<1;if((b|0)<=0){return}e=c[3532484]|0;f=c[3532488]|0;g=0;do{h=d[e+(g|1)|0]|0;i=d[e+g|0]|0;j=i<<1&30;k=i>>>2&60;i=h<<1&30;l=j|h>>>4&1;m=(h&32|0)==0?k:k|2;k=i|h>>>6&1;n=(m|h>>>7)<<2|m>>>4;m=(g|0)/2|0;c[f+(m<<2)>>2]=l<<11|k|n<<3&2016;h=((l<<3|j>>>2)*160|0)&63488|((n*160|0|0)/256|0)<<3&2016|((k<<3|i>>>2)*160|0)>>>11&31;c[f+(a+m<<2)>>2]=h;c[f+(b+m<<2)>>2]=h;g=g+2|0;}while((g|0)<(b|0));return}function eO$(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0;f=c[3532368]|0;g=c[14129672+(a<<2)>>2]|0;h=c[14129656+(a<<2)>>2]|0;i=(c[3532550]|0)!=0;j=(c[3532424]|0)!=0;k=c[2113070]|0;l=(k|0)>0;if(i&j){if(!l){return}m=a+1984|0;n=a+1944|0;o=(d|a|0)==0;p=(d|0)==1;q=(a|0)==0&p;r=(a|0)==1;s=(e|0)==1;t=r&(d|0)==0&s;u=r&p&s;s=(e|0)==0;p=r&s;r=c[2113068]|0;v=p?9708880:u?9718368:t?9718376:q?9718352:9718360;w=c[2112926]|0;x=0;y=0;while(1){z=ag(x,r)|0;do{if((r|0)>0){A=200-(b[f+(m+(((x|0)/8|0)<<1)<<1)>>1]&511)|0;if(o){B=0;do{C=(b[f+((((B|0)/16|0)<<1)+n<<1)>>1]&255)+x<<10&523264;D=c[v>>2]|0;E=b[D+((C|B+A&1023)<<1)>>1]|0;do{if(s){b[w+(B+z<<1)>>1]=E}else{if(E<<16>>16==0){break}b[w+(B+z<<1)>>1]=E}}while(0);B=B+1|0;}while((B|0)<(r|0));F=D+(C<<1)|0;break}else{G=0;H=y}while(1){B=(b[f+((((G|0)/16|0)<<1)+n<<1)>>1]&255)+x&511;if(q){I=(c[2429588]|0)+(B<<10<<1)|0}else{I=H}if(t){J=(c[2429594]|0)+(B<<10<<1)|0}else{J=I}if(u){K=(c[2429592]|0)+(B<<10<<1)|0}else{K=J}if(p){L=(c[2427220]|0)+(B<<10<<1)|0}else{L=K}B=b[L+((G+A&1023)<<1)>>1]|0;do{if(s){b[w+(G+z<<1)>>1]=B}else{if(B<<16>>16==0){break}b[w+(G+z<<1)>>1]=B}}while(0);B=G+1|0;if((B|0)<(r|0)){G=B;H=L}else{F=L;break}}}else{F=y}}while(0);z=x+1|0;if((z|0)<(k|0)){x=z;y=F}else{break}}return}if(i){if(!l){return}i=a+1944|0;F=(d|a|0)==0;y=(d|0)==1;x=(a|0)==0&y;L=(a|0)==1;H=(e|0)==1;G=L&(d|0)==0&H;r=L&y&H;H=(e|0)==0;y=L&H;L=200-g|0;w=c[2113068]|0;s=c[2112926]|0;K=0;p=0;while(1){J=ag(K,w)|0;if((w|0)>0){u=0;I=p;while(1){t=(b[f+(i+(((u|0)/16|0)<<1)<<1)>>1]&255)+K&511;if(F){M=(c[2429590]|0)+(t<<10<<1)|0}else{M=I}if(x){N=(c[2429588]|0)+(t<<10<<1)|0}else{N=M}if(G){O=(c[2429594]|0)+(t<<10<<1)|0}else{O=N}if(r){P=(c[2429592]|0)+(t<<10<<1)|0}else{P=O}if(y){Q=(c[2427220]|0)+(t<<10<<1)|0}else{Q=P}t=b[Q+((L+u&1023)<<1)>>1]|0;do{if(H){b[s+(u+J<<1)>>1]=t}else{if(t<<16>>16==0){break}b[s+(u+J<<1)>>1]=t}}while(0);t=u+1|0;if((t|0)<(w|0)){u=t;I=Q}else{R=Q;break}}}else{R=p}I=K+1|0;if((I|0)<(k|0)){K=I;p=R}else{break}}return}if(!j){if(!l){return}j=(d|a|0)==0;R=(d|0)==1;p=(a|0)==0&R;K=(a|0)==1;Q=K&(d|0)==0;w=K&R;R=(e|0)==0;s=K&R;K=200-g|0;g=c[2113068]|0;H=c[2112926]|0;L=0;P=0;while(1){y=ag(L,g)|0;O=L+h&511;if(j){S=(c[2429590]|0)+(O<<10<<1)|0}else{S=P}if(p){T=(c[2429588]|0)+(O<<10<<1)|0}else{T=S}if(Q){U=(c[2429594]|0)+(O<<10<<1)|0}else{U=T}if(w){V=(c[2429592]|0)+(O<<10<<1)|0}else{V=U}if(s){W=(c[2427220]|0)+(O<<10<<1)|0}else{W=V}if((g|0)>0){O=0;do{r=b[W+((K+O&1023)<<1)>>1]|0;do{if(R){b[H+(O+y<<1)>>1]=r}else{if(r<<16>>16==0){break}b[H+(O+y<<1)>>1]=r}}while(0);O=O+1|0;}while((O|0)<(g|0))}O=L+1|0;if((O|0)<(k|0)){L=O;P=W}else{break}}return}if(!l){return}l=a+1984|0;W=(d|a|0)==0;P=(d|0)==1;L=(a|0)==0&P;g=(a|0)==1;a=(e|0)==1;H=g&(d|0)==0&a;d=g&P&a;a=(e|0)==0;e=g&a;g=c[2113068]|0;P=e?9708880:d?9718368:H?9718376:L?9718352:9718360;R=c[2112926]|0;K=0;V=0;while(1){s=ag(K,g)|0;do{if((g|0)>0){U=K+h<<10&523264;w=200-(b[f+(l+(((K|0)/8|0)<<1)<<1)>>1]&511)|0;if(W){T=0;do{X=c[P>>2]|0;Q=b[X+((T+w&1023|U)<<1)>>1]|0;do{if(a){b[R+(T+s<<1)>>1]=Q}else{if(Q<<16>>16==0){break}b[R+(T+s<<1)>>1]=Q}}while(0);T=T+1|0;}while((T|0)<(g|0));Y=X+(U<<1)|0;break}else{Z=0;_=V}while(1){if(L){$=(c[2429588]|0)+(U<<1)|0}else{$=_}if(H){aa=(c[2429594]|0)+(U<<1)|0}else{aa=$}if(d){ab=(c[2429592]|0)+(U<<1)|0}else{ab=aa}if(e){ac=(c[2427220]|0)+(U<<1)|0}else{ac=ab}T=b[ac+((Z+w&1023)<<1)>>1]|0;do{if(a){b[R+(Z+s<<1)>>1]=T}else{if(T<<16>>16==0){break}b[R+(Z+s<<1)>>1]=T}}while(0);T=Z+1|0;if((T|0)<(g|0)){Z=T;_=ac}else{Y=ac;break}}}else{Y=V}}while(0);s=K+1|0;if((s|0)<(k|0)){K=s;V=Y}else{break}}return}function eO0(a){a=a|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;f=(c[3532380]|0)>>>16;g=c[3532374]|0;h=c[3532390]|0;i=h+((c[3532384]|0)>>>1<<1)|0;if(h>>>0>=i>>>0){return}j=(f&255)<<24>>24==0;k=f&255;f=c[2112926]|0;l=c[3532376]|0;m=c[3532486]|0;n=m+65535|0;o=c[3532484]|0;p=m+2047|0;q=h;while(1){h=b[q>>1]|0;r=h&65535;s=r>>>8;if((h&65535)>61695){t=25043;break}h=e[q+8>>1]|0;L32975:do{if((1<<(h&3)|0)==(a|0)){u=s+1|0;v=r&255;w=v+1|0;x=(b[q+2>>1]&511)-189|0;y=b[q+4>>1]|0;z=b[q+6>>1]|0;A=h>>>8<<4&1008;B=c[14129568+((h>>>4&7)<<2)>>2]|0;C=q+14|0;b[C>>1]=z;if(w>>>0>=u>>>0|(B|0)==255){break}if(j){D=B}else{D=(B|0)%(k|0)|0}B=D<<15;if((c[3532422]|0)==0){E=(A|0)==1008;F=w;w=z;while(1){w=w+y&65535;L32985:do{if(F>>>0<224){G=F*320|0;if(w<<16>>16>-1){b[C>>1]=w-1&65535;H=x;while(1){if((x-H&511|0)==1){break L32985}I=(b[C>>1]|0)+1&65535;b[C>>1]=I;J=e[g+((I&32767|B)<<1)>>1]|0;I=J>>>12;K=l+H|0;do{if(K>>>0<320){if((I|0)==15|(I|0)==0){break}if(E){L=f+(K+G<<1)|0;M=(e[L>>1]|0)&n;b[L>>1]=M&65535;b[L>>1]=(m<<((d[o+(M+1)|0]|0)>>>7&255))+M&65535;break}else{b[f+(K+G<<1)>>1]=p&(A|I|1024)&65535;break}}}while(0);I=J>>>8&15;K=H+1+l|0;do{if(K>>>0<320){if((I|0)==15|(I|0)==0){break}if(E){M=f+(K+G<<1)|0;L=(e[M>>1]|0)&n;b[M>>1]=L&65535;b[M>>1]=(m<<((d[o+(L+1)|0]|0)>>>7&255))+L&65535;break}else{b[f+(K+G<<1)>>1]=p&(A|I|1024)&65535;break}}}while(0);I=J>>>4&15;K=H+2+l|0;do{if(K>>>0<320){if((I|0)==15|(I|0)==0){break}if(E){L=f+(K+G<<1)|0;M=(e[L>>1]|0)&n;b[L>>1]=M&65535;b[L>>1]=(m<<((d[o+(M+1)|0]|0)>>>7&255))+M&65535;break}else{b[f+(K+G<<1)>>1]=p&(A|I|1024)&65535;break}}}while(0);I=J&15;K=H+3+l|0;do{if(K>>>0<320){if((I|0)==15|(I|0)==0){break}if(E){M=f+(K+G<<1)|0;L=(e[M>>1]|0)&n;b[M>>1]=L&65535;b[M>>1]=(m<<((d[o+(L+1)|0]|0)>>>7&255))+L&65535;break}else{b[f+(K+G<<1)>>1]=p&(A|I|1024)&65535;break}}}while(0);if((I|0)==15){break}else{H=H+4|0}}}else{b[C>>1]=w+1&65535;H=x;while(1){if((x-H&511|0)==1){break L32985}K=(b[C>>1]|0)-1&65535;b[C>>1]=K;J=e[g+((K&32767|B)<<1)>>1]|0;K=J&15;L=l+H|0;do{if(L>>>0<320){if((K|0)==15|(K|0)==0){break}if(E){M=f+(L+G<<1)|0;N=(e[M>>1]|0)&n;b[M>>1]=N&65535;b[M>>1]=(m<<((d[o+(N+1)|0]|0)>>>7&255))+N&65535;break}else{b[f+(L+G<<1)>>1]=p&(A|K|1024)&65535;break}}}while(0);K=J>>>4&15;L=H+1+l|0;do{if(L>>>0<320){if((K|0)==15|(K|0)==0){break}if(E){I=f+(L+G<<1)|0;N=(e[I>>1]|0)&n;b[I>>1]=N&65535;b[I>>1]=(m<<((d[o+(N+1)|0]|0)>>>7&255))+N&65535;break}else{b[f+(L+G<<1)>>1]=p&(A|K|1024)&65535;break}}}while(0);K=J>>>8&15;L=H+2+l|0;do{if(L>>>0<320){if((K|0)==15|(K|0)==0){break}if(E){N=f+(L+G<<1)|0;I=(e[N>>1]|0)&n;b[N>>1]=I&65535;b[N>>1]=(m<<((d[o+(I+1)|0]|0)>>>7&255))+I&65535;break}else{b[f+(L+G<<1)>>1]=p&(A|K|1024)&65535;break}}}while(0);K=J>>>12;L=H+3+l|0;do{if(L>>>0<320){if((K|0)==15|(K|0)==0){break}if(E){I=f+(L+G<<1)|0;N=(e[I>>1]|0)&n;b[I>>1]=N&65535;b[I>>1]=(m<<((d[o+(N+1)|0]|0)>>>7&255))+N&65535;break}else{b[f+(L+G<<1)>>1]=p&(A|K|1024)&65535;break}}}while(0);if((K|0)==15){break}else{H=H+4|0}}}}}while(0);F=F+1|0;if((F|0)>=(u|0)){break L32975}}}u=s-2|0;F=v-2|0;if((u|0)<=(F|0)){break}E=(A|0)==1008;w=u;u=z;do{u=u+y&65535;L33057:do{if(w>>>0<224){H=w*320|0;if(u<<16>>16>-1){b[C>>1]=u-1&65535;G=x;while(1){if((x-G&511|0)==1){break L33057}L=(b[C>>1]|0)+1&65535;b[C>>1]=L;J=e[g+((L&32767|B)<<1)>>1]|0;L=J>>>12;N=l+G|0;do{if(N>>>0<320){if((L|0)==15|(L|0)==0){break}if(E){I=f+(N+H<<1)|0;M=(e[I>>1]|0)&n;b[I>>1]=M&65535;b[I>>1]=(m<<((d[o+(M+1)|0]|0)>>>7&255))+M&65535;break}else{b[f+(N+H<<1)>>1]=p&(A|L|1024)&65535;break}}}while(0);L=J>>>8&15;N=G+1+l|0;do{if(N>>>0<320){if((L|0)==15|(L|0)==0){break}if(E){K=f+(N+H<<1)|0;M=(e[K>>1]|0)&n;b[K>>1]=M&65535;b[K>>1]=(m<<((d[o+(M+1)|0]|0)>>>7&255))+M&65535;break}else{b[f+(N+H<<1)>>1]=p&(A|L|1024)&65535;break}}}while(0);L=J>>>4&15;N=G+2+l|0;do{if(N>>>0<320){if((L|0)==15|(L|0)==0){break}if(E){M=f+(N+H<<1)|0;K=(e[M>>1]|0)&n;b[M>>1]=K&65535;b[M>>1]=(m<<((d[o+(K+1)|0]|0)>>>7&255))+K&65535;break}else{b[f+(N+H<<1)>>1]=p&(A|L|1024)&65535;break}}}while(0);L=J&15;N=G+3+l|0;do{if(N>>>0<320){if((L|0)==15|(L|0)==0){break}if(E){K=f+(N+H<<1)|0;M=(e[K>>1]|0)&n;b[K>>1]=M&65535;b[K>>1]=(m<<((d[o+(M+1)|0]|0)>>>7&255))+M&65535;break}else{b[f+(N+H<<1)>>1]=p&(A|L|1024)&65535;break}}}while(0);if((L|0)==15){break}else{G=G+4|0}}}else{b[C>>1]=u+1&65535;G=x;while(1){if((x-G&511|0)==1){break L33057}N=(b[C>>1]|0)-1&65535;b[C>>1]=N;J=e[g+((N&32767|B)<<1)>>1]|0;N=J&15;M=l+G|0;do{if(M>>>0<320){if((N|0)==15|(N|0)==0){break}if(E){K=f+(M+H<<1)|0;I=(e[K>>1]|0)&n;b[K>>1]=I&65535;b[K>>1]=(m<<((d[o+(I+1)|0]|0)>>>7&255))+I&65535;break}else{b[f+(M+H<<1)>>1]=p&(A|N|1024)&65535;break}}}while(0);N=J>>>4&15;M=G+1+l|0;do{if(M>>>0<320){if((N|0)==15|(N|0)==0){break}if(E){L=f+(M+H<<1)|0;I=(e[L>>1]|0)&n;b[L>>1]=I&65535;b[L>>1]=(m<<((d[o+(I+1)|0]|0)>>>7&255))+I&65535;break}else{b[f+(M+H<<1)>>1]=p&(A|N|1024)&65535;break}}}while(0);N=J>>>8&15;M=G+2+l|0;do{if(M>>>0<320){if((N|0)==15|(N|0)==0){break}if(E){I=f+(M+H<<1)|0;L=(e[I>>1]|0)&n;b[I>>1]=L&65535;b[I>>1]=(m<<((d[o+(L+1)|0]|0)>>>7&255))+L&65535;break}else{b[f+(M+H<<1)>>1]=p&(A|N|1024)&65535;break}}}while(0);N=J>>>12;M=G+3+l|0;do{if(M>>>0<320){if((N|0)==15|(N|0)==0){break}if(E){L=f+(M+H<<1)|0;I=(e[L>>1]|0)&n;b[L>>1]=I&65535;b[L>>1]=(m<<((d[o+(I+1)|0]|0)>>>7&255))+I&65535;break}else{b[f+(M+H<<1)>>1]=p&(A|N|1024)&65535;break}}}while(0);if((N|0)==15){break}else{G=G+4|0}}}}}while(0);w=w-1|0;}while((w|0)>(F|0))}}while(0);s=q+16|0;if(s>>>0<i>>>0){q=s}else{t=25042;break}}if((t|0)==25042){return}else if((t|0)==25043){return}}function eO1(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=c[3532368]|0;f=c[2112926]|0;g=a[7461520]|0?7168:0;h=c[3532350]|0;i=0;j=0;while(1){k=i<<3;l=(k-8|0)>>>0>207;m=0;n=j;while(1){o=d[e+(n|1)|0]|0;p=d[e+n|0]|0;do{if((o>>>3&1|0)==(b|0)){q=o&7;r=m<<3;s=r-192|0;if((r-200|0)>>>0>303|l){Sr(f,p,s,k,q,3,0,g,h);break}else{Sq(f,p,s,k,q,3,0,g,h);break}}}while(0);p=m+1|0;if((p|0)>=64){break}m=p;n=n+2|0}n=i+1|0;if((n|0)<32){i=n;j=j+128|0}else{break}}return}function eO2(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0;g=i;i=i+2352|0;h=g|0;j=c[14129672+(b<<2)>>2]|0;k=c[14129656+(b<<2)>>2]|0;if((k&32768|0)==0){l=-~~+(k&7|0)|0;if((l|0)>=224){i=g;return}m=(b<<6)+3968|0;n=(j&32768|0)==0;o=j&65535;p=(b|0)==1;q=(b|0)==0;r=(f|0)==0;s=b+2|0;t=14129672+(s<<2)|0;u=14129656+(s<<2)|0;s=c[3532368]|0;v=c[3532356]|0;w=c[3532366]|0;x=(c[3532508]|0)-1|0;y=a[7461520]|0?7168:0;z=y|256;A=c[2112926]|0;B=c[3532350]|0;C=k&65535;k=0;D=l;while(1){l=m+(((D|0)/8|0)<<1)|0;E=(d[s+(l|1)|0]|0)<<8;if(n){F=o}else{F=d[s+l|0]|0|E}if((E&32768|0)==0){G=F;H=C}else{G=c[t>>2]|0;H=c[u>>2]&65535}E=~~+((G|0)%8|0|0);l=(E|0)==1?-7:E;E=(l|0)==2?-6:l;l=(E|0)==3?-5:E;E=(l|0)==4?-4:l;l=(E|0)==5?-3:E;E=(l|0)==6?-2:l;l=(E|0)==7?-1:E;E=(H&511)+D|0;I=(E|0)/8|0;J=(E|0)>511?I-64|0:I;if((l|0)<320){I=G&1023;E=(J|0)<32;K=(J|0)>31;L=J<<7&3968;J=(D-8|0)>>>0>207;M=k;N=l;while(1){l=N-I+192|0;O=(l|0)/8|0;P=(l|0)<-7?O+128|0:O;do{if(p){O=(P|0)<64;if(E&O){Q=d[14168816]|0}else{Q=M}l=(P|0)>63;if(E&l){R=d[14168817]|0}else{R=Q}if(K&O){S=d[14168818]|0}else{S=R}if(!(K&l)){T=S;break}T=d[14168819]|0}else{T=M}}while(0);do{if(q){l=(P|0)<64;if(E&l){U=d[14168808]|0}else{U=T}O=(P|0)>63;if(E&O){V=d[14168809]|0}else{V=U}if(K&l){W=d[14168810]|0}else{W=V}if(!(K&O)){X=W;break}X=d[14168811]|0}else{X=T}}while(0);O=P<<1&126|L|(X&65535)<<12;l=d[v+(O|1)|0]|0;Y=l<<8|(d[v+O|0]|0);do{if((l>>>7|0)==(e|0)){O=Y&8191;Z=x&(ag(c[14129432+(((O|0)/(w|0)|0)<<2)>>2]|0,w)|0)+((O|0)%(w|0)|0);O=Y>>>6&127;if(O>>>0>63){_=y|(O>>>0>95?768:512)}else{_=O>>>0>31?z:y}$=(N-8|0)>>>0>303|J;if(r){if($){Sj(A,Z,N,D,O,3,_,B);break}else{Si(A,Z,N,D,O,3,_,B);break}}else{if($){Sr(A,Z,N,D,O,3,0,_,B);break}else{Sq(A,Z,N,D,O,3,0,_,B);break}}}}while(0);Y=N+8|0;if((Y|0)<320){M=X;N=Y}else{aa=X;break}}}else{aa=k}N=D+8|0;if((N|0)<224){C=H;k=aa;D=N}else{break}}i=g;return}D=b<<6;aa=D+3862|0;k=c[3532368]|0;H=0;do{C=(H|0)/8|0;X=-8;do{B=X+8|0;c[h+((((B|0)/16|0)*28|0)+C<<2)>>2]=H-~~+(a[k+(((B<<1|0)/16|0)+aa)|0]&7|0);X=X+16|0;}while((X|0)<320);H=H+8|0;}while((H|0)<224);H=D+3968|0;D=(j&32768|0)==0;X=j&65535;j=(b|0)==1;C=(b|0)==0;B=(f|0)!=0;f=14129672+(b+2<<2)|0;b=c[3532356]|0;_=c[3532366]|0;A=(c[3532508]|0)-1|0;r=a[7461520]|0?7168:0;y=r|256;z=c[2112926]|0;w=c[3532350]|0;x=0;v=0;while(1){T=H+(x<<1)|0;W=(d[k+(T|1)|0]|0)<<8;if(D){ab=X}else{ab=d[k+T|0]|0|W}if((W&32768|0)==0){ac=ab}else{ac=c[f>>2]|0}W=~~+((ac|0)%8|0|0);T=(W|0)==1?-7:W;W=(T|0)==2?-6:T;T=(W|0)==3?-5:W;W=(T|0)==4?-4:T;T=(W|0)==5?-3:W;W=(T|0)==6?-2:T;T=(W|0)==7?-1:W;W=x<<3;V=ac&1023;U=v;q=-8;while(1){S=q+T|0;R=q+8|0;Q=((R<<1|0)/16|0)+aa|0;p=((d[k+(Q+1)|0]|0)<<8&256|(d[k+Q|0]|0))+W|0;Q=(p|0)/8|0;G=(p|0)>511?Q-64|0:Q;Q=c[h+((((R|0)/16|0)*28|0)+x<<2)>>2]|0;R=S-V+192|0;p=(R|0)/8|0;u=(R|0)<-7?p+128|0:p;do{if(j){p=(G|0)<32;R=(u|0)<64;if(p&R){ad=d[14168816]|0}else{ad=U}t=(u|0)>63;if(p&t){ae=d[14168817]|0}else{ae=ad}p=(G|0)>31;if(p&R){af=d[14168818]|0}else{af=ae}if(!(p&t)){ah=af;break}ah=d[14168819]|0}else{ah=U}}while(0);do{if(C){t=(G|0)<32;p=(u|0)<64;if(t&p){ai=d[14168808]|0}else{ai=ah}R=(u|0)>63;if(t&R){aj=d[14168809]|0}else{aj=ai}t=(G|0)>31;if(t&p){ak=d[14168810]|0}else{ak=aj}if(!(t&R)){al=ak;break}al=d[14168811]|0}else{al=ah}}while(0);R=u<<1&126|G<<7&3968|(al&65535)<<12;t=d[b+(R|1)|0]|0;p=t<<8|(d[b+R|0]|0);F=(d[b+(R+3)|0]|0)<<8|(d[b+(R+2)|0]|0);L33247:do{if((t>>>7|0)==(e|0)){R=p&8191;s=A&(ag(c[14129432+(((R|0)/(_|0)|0)<<2)>>2]|0,_)|0)+((R|0)%(_|0)|0);R=p>>>6&127;if(R>>>0>63){am=r|(R>>>0>95?768:512)}else{am=R>>>0>31?y:r}o=(S-8|0)>>>0<304;L33252:do{if(B){do{if(o){if((Q-8|0)>>>0>=208){break}Sq(z,s,S,Q,R,3,0,am,w);break L33252}}while(0);Sr(z,s,S,Q,R,3,0,am,w)}else{do{if(o){if((Q-8|0)>>>0>=208){break}Si(z,s,S,Q,R,3,am,w);break L33252}}while(0);Sj(z,s,S,Q,R,3,am,w)}}while(0);R=F&8191;s=A&(ag(c[14129432+(((R|0)/(_|0)|0)<<2)>>2]|0,_)|0)+((R|0)%(_|0)|0);R=F>>>6&127;if(R>>>0>63){an=r|(R>>>0>95?768:512)}else{an=R>>>0>31?y:r}o=S+8|0;n=S>>>0<304;if(B){do{if(n){if((Q-8|0)>>>0>=208){break}Sq(z,s,o,Q,R,3,0,an,w);break L33247}}while(0);Sr(z,s,o,Q,R,3,0,an,w);break}else{do{if(n){if((Q-8|0)>>>0>=208){break}Si(z,s,o,Q,R,3,an,w);break L33247}}while(0);Sj(z,s,o,Q,R,3,an,w);break}}}while(0);Q=q+16|0;if((Q|0)<320){U=al;q=Q}else{break}}q=x+1|0;if((q|0)<28){x=q;v=al}else{break}}i=g;return}function eO3(a){a=a|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0;f=c[3532374]|0;g=(c[3532380]|0)>>>17;h=c[3532390]|0;i=h+((c[3532384]|0)>>>1<<1)|0;if(h>>>0>=i>>>0){return}j=(g&255)<<24>>24==0;k=g&255;g=c[2112926]|0;l=c[3532376]|0;m=c[3532486]|0;n=m+65535|0;o=c[3532484]|0;p=m+2047|0;q=h;while(1){h=b[q+4>>1]|0;r=h&65535;if((r&32768|0)!=0){s=25298;break}t=e[q+8>>1]|0;L33288:do{if((1<<(t>>>6&3)|0)==(a|0)){u=e[q>>1]|0;v=u>>>8;w=u&255;u=(b[q+2>>1]&511)-184|0;x=(h&255)<<24>>24;y=b[q+6>>1]|0;z=c[14129568+((t>>>8&15)<<2)>>2]|0;A=t<<4&1008;B=q+10|0;C=b[B>>1]|0;D=C&65535;E=D&31;F=q+14|0;b[F>>1]=y;if(w>>>0>=v>>>0|(r&16384|0)!=0|(z|0)==255){break}if(j){G=z}else{G=(z|0)%(k|0)|0}z=G<<16;H=C&1023;b[B>>1]=H;C=D>>>5<<10&31744;D=E<<2;I=(r&256|0)==0;J=(A|0)==1008;if((c[3532422]|0)==0){K=w;L=y;M=H;while(1){N=(L&65535)+x|0;O=(M&65535)+C|0;P=O&65535;if((O&32768|0)==0){Q=N&65535;R=P}else{Q=N+x&65535;R=P&32767}b[B>>1]=R;L33300:do{if(K>>>0<224){P=K*320|0;if(I){b[F>>1]=Q-1&65535;N=u;O=D;while(1){if((u-N&511|0)==1){break L33300}S=(b[F>>1]|0)+1&65535;b[F>>1]=S;T=e[f+((S&65535|z)<<1)>>1]|0;if(((O&63)+E|0)<64){S=T>>>12;U=l+N|0;do{if(U>>>0<320){if((S|0)==15|(S|0)==0){break}if(J){V=g+(U+P<<1)|0;W=(e[V>>1]|0)&n;b[V>>1]=W&65535;b[V>>1]=(m<<((d[o+(W+1)|0]|0)>>>7&255))+W&65535;break}else{b[g+(U+P<<1)>>1]=p&(A|S|1024)&65535;break}}}while(0);X=N+1|0}else{X=N}S=O+E|0;if(((S&63)+E|0)<64){U=T>>>8&15;W=l+X|0;do{if(W>>>0<320){if((U|0)==15|(U|0)==0){break}if(J){V=g+(W+P<<1)|0;Y=(e[V>>1]|0)&n;b[V>>1]=Y&65535;b[V>>1]=(m<<((d[o+(Y+1)|0]|0)>>>7&255))+Y&65535;break}else{b[g+(W+P<<1)>>1]=p&(A|U|1024)&65535;break}}}while(0);Z=X+1|0}else{Z=X}U=S+E|0;if(((U&63)+E|0)<64){W=T>>>4&15;Y=l+Z|0;do{if(Y>>>0<320){if((W|0)==15|(W|0)==0){break}if(J){V=g+(Y+P<<1)|0;_=(e[V>>1]|0)&n;b[V>>1]=_&65535;b[V>>1]=(m<<((d[o+(_+1)|0]|0)>>>7&255))+_&65535;break}else{b[g+(Y+P<<1)>>1]=p&(A|W|1024)&65535;break}}}while(0);$=Z+1|0}else{$=Z}W=T&15;Y=(U+E&63)+E|0;if((Y|0)<64){S=l+$|0;do{if(S>>>0<320){if((W|0)==15|(W|0)==0){break}if(J){_=g+(S+P<<1)|0;V=(e[_>>1]|0)&n;b[_>>1]=V&65535;b[_>>1]=(m<<((d[o+(V+1)|0]|0)>>>7&255))+V&65535;break}else{b[g+(S+P<<1)>>1]=p&(A|W|1024)&65535;break}}}while(0);aa=$+1|0}else{aa=$}if((W|0)==15){break}else{N=aa;O=Y}}}else{b[F>>1]=Q+1&65535;O=u;N=D;while(1){if((u-O&511|0)==1){break L33300}S=(b[F>>1]|0)-1&65535;b[F>>1]=S;U=e[f+((S&65535|z)<<1)>>1]|0;if(((N&63)+E|0)<64){S=U&15;T=l+O|0;do{if(T>>>0<320){if((S|0)==15|(S|0)==0){break}if(J){V=g+(T+P<<1)|0;_=(e[V>>1]|0)&n;b[V>>1]=_&65535;b[V>>1]=(m<<((d[o+(_+1)|0]|0)>>>7&255))+_&65535;break}else{b[g+(T+P<<1)>>1]=p&(A|S|1024)&65535;break}}}while(0);ab=O+1|0}else{ab=O}S=N+E|0;if(((S&63)+E|0)<64){T=U>>>4&15;Y=l+ab|0;do{if(Y>>>0<320){if((T|0)==15|(T|0)==0){break}if(J){W=g+(Y+P<<1)|0;_=(e[W>>1]|0)&n;b[W>>1]=_&65535;b[W>>1]=(m<<((d[o+(_+1)|0]|0)>>>7&255))+_&65535;break}else{b[g+(Y+P<<1)>>1]=p&(A|T|1024)&65535;break}}}while(0);ac=ab+1|0}else{ac=ab}T=S+E|0;if(((T&63)+E|0)<64){Y=U>>>8&15;_=l+ac|0;do{if(_>>>0<320){if((Y|0)==15|(Y|0)==0){break}if(J){W=g+(_+P<<1)|0;V=(e[W>>1]|0)&n;b[W>>1]=V&65535;b[W>>1]=(m<<((d[o+(V+1)|0]|0)>>>7&255))+V&65535;break}else{b[g+(_+P<<1)>>1]=p&(A|Y|1024)&65535;break}}}while(0);ad=ac+1|0}else{ad=ac}Y=U>>>12;_=(T+E&63)+E|0;if((_|0)<64){S=l+ad|0;do{if(S>>>0<320){if((Y|0)==15|(Y|0)==0){break}if(J){V=g+(S+P<<1)|0;W=(e[V>>1]|0)&n;b[V>>1]=W&65535;b[V>>1]=(m<<((d[o+(W+1)|0]|0)>>>7&255))+W&65535;break}else{b[g+(S+P<<1)>>1]=p&(A|Y|1024)&65535;break}}}while(0);ae=ad+1|0}else{ae=ad}if((Y|0)==15){break}else{O=ae;N=_}}}}}while(0);N=K+1|0;if((N|0)>=(v|0)){break L33288}K=N;L=Q;M=b[B>>1]|0}}else{M=v;L=y;K=H;while(1){N=(L&65535)+x|0;O=(K&65535)+C|0;P=O&65535;if((O&32768|0)==0){af=N&65535;ag=P}else{af=N+x&65535;ag=P&32767}b[B>>1]=ag;L33398:do{if(M>>>0<224){P=M*320|0;if(I){b[F>>1]=af-1&65535;N=D;O=u;while(1){if((u-O&511|0)==1){break L33398}S=(b[F>>1]|0)+1&65535;b[F>>1]=S;T=e[f+((S&65535|z)<<1)>>1]|0;if(((N&63)+E|0)<64){S=T>>>12;U=l+O|0;do{if(U>>>0<320){if((S|0)==15|(S|0)==0){break}if(J){W=g+(U+P<<1)|0;V=(e[W>>1]|0)&n;b[W>>1]=V&65535;b[W>>1]=(m<<((d[o+(V+1)|0]|0)>>>7&255))+V&65535;break}else{b[g+(U+P<<1)>>1]=p&(A|S|1024)&65535;break}}}while(0);ah=O+1|0}else{ah=O}S=N+E|0;if(((S&63)+E|0)<64){U=T>>>8&15;_=l+ah|0;do{if(_>>>0<320){if((U|0)==15|(U|0)==0){break}if(J){Y=g+(_+P<<1)|0;V=(e[Y>>1]|0)&n;b[Y>>1]=V&65535;b[Y>>1]=(m<<((d[o+(V+1)|0]|0)>>>7&255))+V&65535;break}else{b[g+(_+P<<1)>>1]=p&(A|U|1024)&65535;break}}}while(0);ai=ah+1|0}else{ai=ah}U=S+E|0;if(((U&63)+E|0)<64){_=T>>>4&15;V=l+ai|0;do{if(V>>>0<320){if((_|0)==15|(_|0)==0){break}if(J){Y=g+(V+P<<1)|0;W=(e[Y>>1]|0)&n;b[Y>>1]=W&65535;b[Y>>1]=(m<<((d[o+(W+1)|0]|0)>>>7&255))+W&65535;break}else{b[g+(V+P<<1)>>1]=p&(A|_|1024)&65535;break}}}while(0);aj=ai+1|0}else{aj=ai}_=T&15;V=(U+E&63)+E|0;if((V|0)<64){S=l+aj|0;do{if(S>>>0<320){if((_|0)==15|(_|0)==0){break}if(J){W=g+(S+P<<1)|0;Y=(e[W>>1]|0)&n;b[W>>1]=Y&65535;b[W>>1]=(m<<((d[o+(Y+1)|0]|0)>>>7&255))+Y&65535;break}else{b[g+(S+P<<1)>>1]=p&(A|_|1024)&65535;break}}}while(0);ak=aj+1|0}else{ak=aj}if((_|0)==15){break}else{N=V;O=ak}}}else{b[F>>1]=af+1&65535;O=D;N=u;while(1){if((u-N&511|0)==1){break L33398}S=(b[F>>1]|0)-1&65535;b[F>>1]=S;U=e[f+((S&65535|z)<<1)>>1]|0;if(((O&63)+E|0)<64){S=U&15;T=l+N|0;do{if(T>>>0<320){if((S|0)==15|(S|0)==0){break}if(J){Y=g+(T+P<<1)|0;W=(e[Y>>1]|0)&n;b[Y>>1]=W&65535;b[Y>>1]=(m<<((d[o+(W+1)|0]|0)>>>7&255))+W&65535;break}else{b[g+(T+P<<1)>>1]=p&(A|S|1024)&65535;break}}}while(0);al=N+1|0}else{al=N}S=O+E|0;if(((S&63)+E|0)<64){T=U>>>4&15;V=l+al|0;do{if(V>>>0<320){if((T|0)==15|(T|0)==0){break}if(J){_=g+(V+P<<1)|0;W=(e[_>>1]|0)&n;b[_>>1]=W&65535;b[_>>1]=(m<<((d[o+(W+1)|0]|0)>>>7&255))+W&65535;break}else{b[g+(V+P<<1)>>1]=p&(A|T|1024)&65535;break}}}while(0);am=al+1|0}else{am=al}T=S+E|0;if(((T&63)+E|0)<64){V=U>>>8&15;W=l+am|0;do{if(W>>>0<320){if((V|0)==15|(V|0)==0){break}if(J){_=g+(W+P<<1)|0;Y=(e[_>>1]|0)&n;b[_>>1]=Y&65535;b[_>>1]=(m<<((d[o+(Y+1)|0]|0)>>>7&255))+Y&65535;break}else{b[g+(W+P<<1)>>1]=p&(A|V|1024)&65535;break}}}while(0);an=am+1|0}else{an=am}V=U>>>12;W=(T+E&63)+E|0;if((W|0)<64){S=l+an|0;do{if(S>>>0<320){if((V|0)==15|(V|0)==0){break}if(J){Y=g+(S+P<<1)|0;_=(e[Y>>1]|0)&n;b[Y>>1]=_&65535;b[Y>>1]=(m<<((d[o+(_+1)|0]|0)>>>7&255))+_&65535;break}else{b[g+(S+P<<1)>>1]=p&(A|V|1024)&65535;break}}}while(0);ao=an+1|0}else{ao=an}if((V|0)==15){break}else{O=W;N=ao}}}}}while(0);N=M-1|0;if((N|0)<=(w|0)){break L33288}M=N;L=af;K=b[B>>1]|0}}}}while(0);r=q+16|0;if(r>>>0<i>>>0){q=r}else{s=25297;break}}if((s|0)==25297){return}else if((s|0)==25298){return}}function eO4(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=c[3532368]|0;f=(c[3532508]|0)-1|0;g=c[2112926]|0;h=a[7461520]|0?7168:0;i=c[3532350]|0;j=0;k=0;while(1){l=j<<3;m=(l-8|0)>>>0>207;n=0;o=k;while(1){p=d[e+(o|1)|0]|0;do{if((p>>>7|0)==(b|0)){q=p>>>1&7;r=(d[e+o|0]|0|p<<8&256|c[3532358]<<12)&f;s=n<<3;t=s-192|0;if((s-200|0)>>>0>303|m){Sr(g,r,t,l,q,3,0,h,i);break}else{Sq(g,r,t,l,q,3,0,h,i);break}}}while(0);p=n+1|0;if((p|0)>=64){break}n=p;o=o+2|0}o=j+1|0;if((o|0)<32){j=o;k=k+128|0}else{break}}return}function eO5(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0;f=c[3532368]|0;if(a[7461560]|0){a[7461560]=0;g=1984;h=0;while(1){if((b[f+(g<<1)>>1]|0)<0){a[7461560]=1;i=1}else{i=h}j=g+1|0;if((j|0)<2012){g=j;h=i}else{k=i;break}}}else{k=0}if(a[7461576]|0){a[7461576]=0;i=2016;h=0;g=0;while(1){if((b[f+(i<<1)>>1]|0)<0){a[7461576]=1;l=1;m=1}else{l=h;m=g}j=i+1|0;if((j|0)<2044){i=j;h=l;g=m}else{n=l;o=m;break}}}else{n=0;o=0}if(a[7461568]|0){m=c[3532356]|0;l=a[7461600]|0;if(l){gGz(c[2427220]|0,0,1048576)}g=c[3532491]|0;h=g&65535;i=g>>>4&65535;f=g>>>8&65535;j=g>>>12&65535;g=c[3532366]|0;p=(c[3532508]|0)-1|0;q=a[7461520]|0?7168:0;r=q|768;s=q|512;t=c[3532350]|0;u=q|256;v=0;w=0;do{w=(v|0)==1?c[2429592]|0:(v|0)==0?c[2429594]|0:w;gGz(w|0,0,1048576);x=0;do{if((x|0)==1){y=i;z=0;A=512}else if((x|0)==2){y=f;z=256;A=0}else if((x|0)==3){y=j;z=256;A=512}else{y=h;z=0;A=0}B=(y&15)<<11;C=0;do{D=(C<<3)+z|0;E=(C<<6)+B|0;F=D<<10;G=0;do{H=e[m+(E+G<<1)>>1]|0;if((H>>>15|0)==(v|0)){I=(G<<3)+A|0;J=H&8191;K=p&(ag(c[14129432+(((J|0)/(g|0)|0)<<2)>>2]|0,g)|0)+((J|0)%(g|0)|0);J=H>>>6&127;if(J>>>0>63){L=J>>>0>95?r:s}else{L=J>>>0>31?u:q}if(l){H=c[2427220]|0;M=t+(K<<6)|0;c[2112928]=M;N=L|J<<3;O=H+(I+F<<1)|0;H=0;P=M;while(1){b[O>>1]=(d[P]|N)&65535;b[O+2>>1]=(d[P+1|0]|N)&65535;b[O+4>>1]=(d[P+2|0]|N)&65535;b[O+6>>1]=(d[P+3|0]|N)&65535;b[O+8>>1]=(d[P+4|0]|N)&65535;b[O+10>>1]=(d[P+5|0]|N)&65535;b[O+12>>1]=(d[P+6|0]|N)&65535;b[O+14>>1]=(d[P+7|0]|N)&65535;M=H+1|0;Q=P+8|0;if((M|0)<8){O=O+2048|0;H=M;P=Q}else{break}}c[2112928]=Q}ePh(w,K,I,D,J,L,t)}G=G+1|0;}while((G|0)<64);C=C+1|0;}while((C|0)<32);x=x+1|0;}while((x|0)<4);v=v+1|0;}while((v|0)<2);a[7461568]=0;R=o&1}else{R=n}if((R|0)!=0){n=c[3532356]|0;v=a[7461600]|0;if(v){gGz(c[2426992]|0,0,1048576)}t=c[3532493]|0;L=t&65535;w=t>>>4&65535;Q=t>>>8&65535;l=t>>>12&65535;t=c[2427070]|0;q=c[2427068]|0;u=c[3532366]|0;s=(c[3532508]|0)-1|0;r=a[7461520]|0?7168:0;g=r|768;p=r|512;A=c[2426992]|0;m=c[3532350]|0;z=r|256;y=o&1;h=0;j=0;f=R;while(1){R=(h|0)==1?q:(h|0)==0?t:j;if((f|0)==0){S=0}else{gGz(R|0,0,1048576);S=0}do{if((S|0)==1){T=w;U=0;V=512}else if((S|0)==2){T=Q;U=256;V=0}else if((S|0)==3){T=l;U=256;V=512}else{T=L;U=0;V=0}i=(T&15)<<11;x=0;do{C=(x<<3)+U|0;B=(x<<6)+i|0;G=C<<10;D=0;do{F=e[n+(B+D<<1)>>1]|0;do{if((F>>>15|0)==(h|0)){E=(D<<3)+V|0;P=F&8191;H=s&(ag(c[14129432+(((P|0)/(u|0)|0)<<2)>>2]|0,u)|0)+((P|0)%(u|0)|0);P=F>>>6&127;if(P>>>0>63){W=P>>>0>95?g:p}else{W=P>>>0>31?z:r}if(v){O=m+(H<<6)|0;c[2112928]=O;N=W|P<<3;M=A+(E+G<<1)|0;X=0;Y=O;while(1){b[M>>1]=(d[Y]|N)&65535;b[M+2>>1]=(d[Y+1|0]|N)&65535;b[M+4>>1]=(d[Y+2|0]|N)&65535;b[M+6>>1]=(d[Y+3|0]|N)&65535;b[M+8>>1]=(d[Y+4|0]|N)&65535;b[M+10>>1]=(d[Y+5|0]|N)&65535;b[M+12>>1]=(d[Y+6|0]|N)&65535;b[M+14>>1]=(d[Y+7|0]|N)&65535;O=X+1|0;Z=Y+8|0;if((O|0)<8){M=M+2048|0;X=O;Y=Z}else{break}}c[2112928]=Z}if(!o){break}ePh(R,H,E,C,P,W,m)}}while(0);D=D+1|0;}while((D|0)<64);x=x+1|0;}while((x|0)<32);S=S+1|0;}while((S|0)<4);x=h+1|0;if((x|0)<2){h=x;j=R;f=y}else{break}}a[7461576]=0}if(a[7461552]|0){y=c[3532356]|0;gGz(c[2429590]|0,0,1048576);gGz(c[2429588]|0,0,1048576);f=c[3532490]|0;j=f&65535;h=f>>>4&65535;S=f>>>8&65535;m=f>>>12&65535;f=c[3532366]|0;W=(c[3532508]|0)-1|0;o=a[7461520]|0?7168:0;Z=o|256;A=c[3532350]|0;v=0;do{if((v|0)==2){_=S;$=256;aa=0}else if((v|0)==3){_=m;$=256;aa=512}else if((v|0)==1){_=h;$=0;aa=512}else{_=j;$=0;aa=0}r=(_&15)<<11;z=0;do{p=(z<<3)+$|0;g=(z<<6)+r|0;u=0;do{s=e[y+(g+u<<1)>>1]|0;V=s>>>15;n=(u<<3)+aa|0;U=s&8191;T=W&(ag(c[14129432+(((U|0)/(f|0)|0)<<2)>>2]|0,f)|0)+((U|0)%(f|0)|0);U=s>>>6&127;if(U>>>0>63){ab=o|(U>>>0>95?768:512)}else{ab=U>>>0>31?Z:o}if((V|0)==0){ePh(c[2429590]|0,T,n,p,U,ab,A)}else if((V|0)==1){ePh(c[2429588]|0,T,n,p,U,ab,A)}u=u+1|0;}while((u|0)<64);z=z+1|0;}while((z|0)<32);v=v+1|0;}while((v|0)<4);a[7461552]=0}if(!k){return}k=c[3532356]|0;v=c[2427066]|0;gGz(v|0,0,1048576);A=c[2427064]|0;gGz(A|0,0,1048576);ab=c[3532492]|0;o=ab&65535;Z=ab>>>4&65535;f=ab>>>8&65535;W=ab>>>12&65535;ab=c[3532366]|0;aa=(c[3532508]|0)-1|0;y=a[7461520]|0?7168:0;$=y|256;_=c[3532350]|0;j=0;do{if((j|0)==1){ac=Z;ad=0;ae=512}else if((j|0)==2){ac=f;ad=256;ae=0}else if((j|0)==3){ac=W;ad=256;ae=512}else{ac=o;ad=0;ae=0}h=(ac&15)<<11;m=0;do{S=(m<<3)+ad|0;z=(m<<6)+h|0;r=0;do{R=e[k+(z+r<<1)>>1]|0;u=R>>>15;p=(r<<3)+ae|0;g=R&8191;U=aa&(ag(c[14129432+(((g|0)/(ab|0)|0)<<2)>>2]|0,ab)|0)+((g|0)%(ab|0)|0);g=R>>>6&127;if(g>>>0>63){af=y|(g>>>0>95?768:512)}else{af=g>>>0>31?$:y}if((u|0)==0){ePh(v,U,p,S,g,af,_)}else if((u|0)==1){ePh(A,U,p,S,g,af,_)}r=r+1|0;}while((r|0)<64);m=m+1|0;}while((m|0)<32);j=j+1|0;}while((j|0)<4);a[7461560]=0;return}function eO6(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0;g=c[3532368]|0;h=c[14129672+(a<<2)>>2]|0;i=c[14129656+(a<<2)>>2]|0;j=c[2113070]|0;k=(j|0)>0;if((i&32768|0)==0){if(!k){return}l=(a<<5)+1984|0;m=(h&32768|0)!=0;n=(d|a|0)==0;o=(d|0)==1;p=(a|0)==0&o;q=(a|0)==1;r=q&(d|0)==0;s=q&o;o=(f|0)==0;t=q&o;q=a+2|0;u=14129672+(q<<2)|0;v=14129656+(q<<2)|0;q=c[2113068]|0;w=c[2112926]|0;x=c[2427066]|0;y=c[2427064]|0;z=c[2427070]|0;A=c[2427068]|0;B=c[2426992]|0;C=0;D=0;while(1){E=ag(C,q)|0;F=e[g+(l+((C|0)/8|0)<<1)>>1]|0;G=m?F:h;do{if((F&32768|0)==0){H=C+i&511;if(n){I=(c[2429590]|0)+(H<<10<<1)|0}else{I=D}if(p){J=(c[2429588]|0)+(H<<10<<1)|0}else{J=I}if(r){K=(c[2429594]|0)+(H<<10<<1)|0}else{K=J}if(s){L=(c[2429592]|0)+(H<<10<<1)|0}else{L=K}if(!t){M=G;N=L;break}M=G;N=(c[2427220]|0)+(H<<10<<1)|0}else{H=c[u>>2]|0;O=(c[v>>2]|0)+C&511;if(n){P=x+(O<<10<<1)|0}else{P=D}if(p){Q=y+(O<<10<<1)|0}else{Q=P}if(r){R=z+(O<<10<<1)|0}else{R=Q}if(s){S=A+(O<<10<<1)|0}else{S=R}if(!t){M=H;N=S;break}M=H;N=B+(O<<10<<1)|0}}while(0);if((q|0)>0){G=192-M|0;F=0;do{O=b[N+((G+F&1023)<<1)>>1]|0;do{if(o){b[w+(F+E<<1)>>1]=O}else{if(O<<16>>16==0){break}b[w+(F+E<<1)>>1]=O}}while(0);F=F+1|0;}while((F|0)<(q|0))}F=C+1|0;if((F|0)<(j|0)){C=F;D=N}else{break}}return}else{if(!k){return}k=a<<5;N=k+1984|0;D=(h&32768|0)!=0;C=k+1931|0;k=(d|a|0)==0;q=(d|0)==1;w=(a|0)==0&q;o=(a|0)==1;M=o&(d|0)==0;d=(f|0)==1;B=M&d;S=o&q;q=S&d;d=(f|0)==0;f=o&d;o=a+2|0;a=14129672+(o<<2)|0;t=14129656+(o<<2)|0;o=c[2113068]|0;R=c[2112926]|0;A=c[2427066]|0;s=c[2427064]|0;Q=c[2427070]|0;z=c[2427068]|0;r=c[2426992]|0;P=0;y=0;while(1){p=ag(P,o)|0;x=e[g+(N+((P|0)/8|0)<<1)>>1]|0;if((o|0)>0){n=(x&32768|0)==0;v=0;u=y;L=D?x:h;while(1){do{if(n){x=(e[g+(C+((v+9|0)/16|0)<<1)>>1]|0)+P&511;if(k){T=(c[2429590]|0)+(x<<10<<1)|0}else{T=u}if(w){U=(c[2429588]|0)+(x<<10<<1)|0}else{U=T}if(B){V=(c[2429594]|0)+(x<<10<<1)|0}else{V=U}if(q){W=(c[2429592]|0)+(x<<10<<1)|0}else{W=V}if(!f){X=L;Y=W;break}X=L;Y=(c[2427220]|0)+(x<<10<<1)|0}else{x=c[a>>2]|0;K=(c[t>>2]|0)+P&511;if(k){Z=A+(K<<10<<1)|0}else{Z=u}if(w){_=s+(K<<10<<1)|0}else{_=Z}if(M){$=Q+(K<<10<<1)|0}else{$=_}if(S){aa=z+(K<<10<<1)|0}else{aa=$}if(!f){X=x;Y=aa;break}X=x;Y=r+(K<<10<<1)|0}}while(0);K=b[Y+((v+192-X&1023)<<1)>>1]|0;do{if(d){b[R+(v+p<<1)>>1]=K}else{if(K<<16>>16==0){break}b[R+(v+p<<1)>>1]=K}}while(0);K=v+1|0;if((K|0)<(o|0)){v=K;u=Y;L=X}else{ab=Y;break}}}else{ab=y}L=P+1|0;if((L|0)<(j|0)){P=L;y=ab}else{break}}return}}function eO7(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0;f=c[3532368]|0;if(a[7461560]|0){a[7461560]=0;g=1984;h=0;while(1){if((b[f+(g<<1)>>1]|0)<0){a[7461560]=1;i=1}else{i=h}j=g+1|0;if((j|0)<2012){g=j;h=i}else{k=i;break}}}else{k=0}if(a[7461576]|0){a[7461576]=0;i=2016;h=0;g=0;while(1){if((b[f+(i<<1)>>1]|0)<0){a[7461576]=1;l=1;m=1}else{l=h;m=g}j=i+1|0;if((j|0)<2044){i=j;h=l;g=m}else{n=l;o=m;break}}}else{n=0;o=0}if(a[7461568]|0){m=c[3532356]|0;l=a[7461600]|0;if(l){gGz(c[2427220]|0,0,1048576)}g=c[3532491]|0;h=g&65535;i=g>>>4&65535;f=g>>>8&65535;j=g>>>12&65535;g=c[3532366]|0;p=(c[3532508]|0)-1|0;q=a[7461520]|0?7168:0;r=q|768;s=q|512;t=c[3532350]|0;u=q|256;v=0;w=0;do{w=(v|0)==1?c[2429592]|0:(v|0)==0?c[2429594]|0:w;gGz(w|0,0,1048576);x=0;do{if((x|0)==1){y=i;z=0;A=512}else if((x|0)==2){y=f;z=256;A=0}else if((x|0)==3){y=j;z=256;A=512}else{y=h;z=0;A=0}B=(y&15)<<11;C=0;do{D=(C<<3)+z|0;E=(C<<6)+B|0;F=D<<10;G=0;do{H=e[m+(E+G<<1)>>1]|0;if((H>>>15|0)==(v|0)){I=(G<<3)+A|0;J=H&8191;K=p&(ag(c[14129432+(((J|0)/(g|0)|0)<<2)>>2]|0,g)|0)+((J|0)%(g|0)|0);J=H>>>5&127;if(J>>>0>63){L=J>>>0>95?r:s}else{L=J>>>0>31?u:q}if(l){H=c[2427220]|0;M=t+(K<<6)|0;c[2112928]=M;N=L|J<<3;O=H+(I+F<<1)|0;H=0;P=M;while(1){b[O>>1]=(d[P]|N)&65535;b[O+2>>1]=(d[P+1|0]|N)&65535;b[O+4>>1]=(d[P+2|0]|N)&65535;b[O+6>>1]=(d[P+3|0]|N)&65535;b[O+8>>1]=(d[P+4|0]|N)&65535;b[O+10>>1]=(d[P+5|0]|N)&65535;b[O+12>>1]=(d[P+6|0]|N)&65535;b[O+14>>1]=(d[P+7|0]|N)&65535;M=H+1|0;Q=P+8|0;if((M|0)<8){O=O+2048|0;H=M;P=Q}else{break}}c[2112928]=Q}ePh(w,K,I,D,J,L,t)}G=G+1|0;}while((G|0)<64);C=C+1|0;}while((C|0)<32);x=x+1|0;}while((x|0)<4);v=v+1|0;}while((v|0)<2);a[7461568]=0;R=o&1}else{R=n}if((R|0)!=0){n=c[3532356]|0;v=a[7461600]|0;if(v){gGz(c[2426992]|0,0,1048576)}t=c[3532493]|0;L=t&65535;w=t>>>4&65535;Q=t>>>8&65535;l=t>>>12&65535;t=c[2427070]|0;q=c[2427068]|0;u=c[3532366]|0;s=(c[3532508]|0)-1|0;r=a[7461520]|0?7168:0;g=r|768;p=r|512;A=c[2426992]|0;m=c[3532350]|0;z=r|256;y=o&1;h=0;j=0;f=R;while(1){R=(h|0)==1?q:(h|0)==0?t:j;if((f|0)==0){S=0}else{gGz(R|0,0,1048576);S=0}do{if((S|0)==3){T=l;U=256;V=512}else if((S|0)==1){T=w;U=0;V=512}else if((S|0)==2){T=Q;U=256;V=0}else{T=L;U=0;V=0}i=(T&15)<<11;x=0;do{C=(x<<3)+U|0;B=(x<<6)+i|0;G=C<<10;D=0;do{F=e[n+(B+D<<1)>>1]|0;do{if((F>>>15|0)==(h|0)){E=(D<<3)+V|0;P=F&8191;H=s&(ag(c[14129432+(((P|0)/(u|0)|0)<<2)>>2]|0,u)|0)+((P|0)%(u|0)|0);P=F>>>5&127;if(P>>>0>63){W=P>>>0>95?g:p}else{W=P>>>0>31?z:r}if(v){O=m+(H<<6)|0;c[2112928]=O;N=W|P<<3;M=A+(E+G<<1)|0;X=0;Y=O;while(1){b[M>>1]=(d[Y]|N)&65535;b[M+2>>1]=(d[Y+1|0]|N)&65535;b[M+4>>1]=(d[Y+2|0]|N)&65535;b[M+6>>1]=(d[Y+3|0]|N)&65535;b[M+8>>1]=(d[Y+4|0]|N)&65535;b[M+10>>1]=(d[Y+5|0]|N)&65535;b[M+12>>1]=(d[Y+6|0]|N)&65535;b[M+14>>1]=(d[Y+7|0]|N)&65535;O=X+1|0;Z=Y+8|0;if((O|0)<8){M=M+2048|0;X=O;Y=Z}else{break}}c[2112928]=Z}if(!o){break}ePh(R,H,E,C,P,W,m)}}while(0);D=D+1|0;}while((D|0)<64);x=x+1|0;}while((x|0)<32);S=S+1|0;}while((S|0)<4);x=h+1|0;if((x|0)<2){h=x;j=R;f=y}else{break}}a[7461576]=0}if(a[7461552]|0){y=c[3532356]|0;gGz(c[2429590]|0,0,1048576);gGz(c[2429588]|0,0,1048576);f=c[3532490]|0;j=f&65535;h=f>>>4&65535;S=f>>>8&65535;m=f>>>12&65535;f=c[3532366]|0;W=(c[3532508]|0)-1|0;o=a[7461520]|0?7168:0;Z=o|256;A=c[3532350]|0;v=0;do{if((v|0)==1){_=h;$=0;aa=512}else if((v|0)==2){_=S;$=256;aa=0}else if((v|0)==3){_=m;$=256;aa=512}else{_=j;$=0;aa=0}r=(_&15)<<11;z=0;do{p=(z<<3)+$|0;g=(z<<6)+r|0;u=0;do{s=e[y+(g+u<<1)>>1]|0;V=s>>>15;n=(u<<3)+aa|0;U=s&8191;T=W&(ag(c[14129432+(((U|0)/(f|0)|0)<<2)>>2]|0,f)|0)+((U|0)%(f|0)|0);U=s>>>5&127;if(U>>>0>63){ab=o|(U>>>0>95?768:512)}else{ab=U>>>0>31?Z:o}if((V|0)==0){ePh(c[2429590]|0,T,n,p,U,ab,A)}else if((V|0)==1){ePh(c[2429588]|0,T,n,p,U,ab,A)}u=u+1|0;}while((u|0)<64);z=z+1|0;}while((z|0)<32);v=v+1|0;}while((v|0)<4);a[7461552]=0}if(!k){return}k=c[3532356]|0;v=c[2427066]|0;gGz(v|0,0,1048576);A=c[2427064]|0;gGz(A|0,0,1048576);ab=c[3532492]|0;o=ab&65535;Z=ab>>>4&65535;f=ab>>>8&65535;W=ab>>>12&65535;ab=c[3532366]|0;aa=(c[3532508]|0)-1|0;y=a[7461520]|0?7168:0;$=y|256;_=c[3532350]|0;j=0;do{if((j|0)==1){ac=Z;ad=0;ae=512}else if((j|0)==2){ac=f;ad=256;ae=0}else if((j|0)==3){ac=W;ad=256;ae=512}else{ac=o;ad=0;ae=0}m=(ac&15)<<11;S=0;do{h=(S<<3)+ad|0;z=(S<<6)+m|0;r=0;do{R=e[k+(z+r<<1)>>1]|0;u=R>>>15;p=(r<<3)+ae|0;g=R&8191;U=aa&(ag(c[14129432+(((g|0)/(ab|0)|0)<<2)>>2]|0,ab)|0)+((g|0)%(ab|0)|0);g=R>>>5&127;if(g>>>0>63){af=y|(g>>>0>95?768:512)}else{af=g>>>0>31?$:y}if((u|0)==1){ePh(A,U,p,h,g,af,_)}else if((u|0)==0){ePh(v,U,p,h,g,af,_)}r=r+1|0;}while((r|0)<64);S=S+1|0;}while((S|0)<32);j=j+1|0;}while((j|0)<4);a[7461560]=0;return}function eO8(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=c[3532368]|0;f=(c[3532508]|0)-1|0;g=c[2112926]|0;h=a[7461520]|0?7168:0;i=c[3532350]|0;j=0;k=0;while(1){l=j<<3;m=(l-8|0)>>>0>207;n=0;o=k;while(1){p=d[e+(o|1)|0]|0;do{if((p>>>7|0)==(b|0)){q=p&7;r=(c[3532358]<<12|(d[e+o|0]|0))&f;s=n<<3;t=s-192|0;if((s-200|0)>>>0>303|m){Sr(g,r,t,l,q,3,0,h,i);break}else{Sq(g,r,t,l,q,3,0,h,i);break}}}while(0);p=n+1|0;if((p|0)>=64){break}n=p;o=o+2|0}o=j+1|0;if((o|0)<32){j=o;k=k+128|0}else{break}}return}function eO9(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0;if((c[3532340]|0)==0){d=c[2112926]|0;gGz(d|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);return}eO_();d=c[3532368]|0;f=d;g=c[3532490]|0;h=(c[3532422]|0)==0?1871:1863;i=e[f+(h<<1)>>1]|0;c[3532490]=i;c[3532418]=b[d+4088>>1]&511;c[3532414]=b[d+3876>>1]&255;j=c[3532491]|0;k=e[f+(h-1<<1)>>1]|0;c[3532491]=k;c[3532419]=b[d+4090>>1]&511;c[3532415]=b[d+3878>>1]&255;if((g|0)!=(i|0)){a[7461552]=1}if((j|0)!=(k|0)){a[7461568]=1}eOZ();ePa(0);ePb(1);eO$(1,0,1);ePb(2);eO$(1,1,1);eO$(0,0,1);ePb(4);eO$(0,1,1);ePa(1);ePb(8);eO1(0);eO1(1);R8(c[3532488]|0);return}function ePa(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;g=c[3532456]|0;h=c[2112926]|0;i=c[3532448]|0;j=a[7461840]|0;k=0;do{l=k*320|0;m=e[g+(k<<1)>>1]|0;L33916:do{if((m>>>10&3|0)==(f|0)){n=m&255;o=e[g+((n|256)<<1)>>1]|0;p=e[g+((n|512)<<1)>>1]|0;q=e[g+((n|768)<<1)>>1]|0;r=n<<9;n=(m&256|0)==0;s=(m&512|0)==0;t=(q&128|0)!=0;u=0;v=o>>>3&255;w=1;x=o>>>11&1;y=-24;z=o;while(1){o=z&7;A=(o|0)==7;B=n?1:(v&255|0)==255?0:x;if(j){C=s?1:w;D=25601}else{if(s){C=w;D=25601}else{E=3;F=w}}do{if((D|0)==25601){D=0;if((v&192|0)!=192){E=3;F=C;break}G=o|r|v<<3&504;if((u&1|0)==0){E=d[i+(G^7)|0]|0;F=C;break}else{E=d[i+G|0]|0;F=C;break}}}while(0);G=u>>>3&1;H=(E|0)==3;if((F|0)!=0&H){I=p>>>((G<<3^8)>>>0)&63|1984}else{J=t&H?0:E<<1;I=J|q>>>((J|G)>>>0)&1|56}if((y|0)>-1){b[h+(y+l<<1)>>1]=I&65535}G=o+1|0;do{if(A){if((B|0)==0){K=v-1|0;D=25615;break}else{L=v+1|0;D=25614;break}}else{L=v;D=25614}}while(0);if((D|0)==25614){D=0;if((B|0)==0){K=L;D=25615}else{M=1;N=L}}if((D|0)==25615){D=0;M=u>>>7&1^1;N=K}A=y+1|0;if((A|0)>=320){break L33916}u=B|u<<1;v=N;w=M;x=B;y=A;z=G}}}while(0);k=k+1|0;}while((k|0)<224);return}function ePb(a){a=a|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0;f=(c[3532380]|0)>>>17;g=c[3532374]|0;h=c[3532480]|0;i=c[3532390]|0;j=i+((c[3532384]|0)>>>1<<1)|0;if(i>>>0>=j>>>0){return}k=(f&255)<<24>>24==0;l=f&255;f=c[2112926]|0;m=c[3532486]|0;n=m+65535|0;o=c[3532484]|0;p=m+2047|0;q=i;while(1){i=b[q>>1]|0;r=i&65535;if((i&65535)>61695){s=25753;break}i=b[q+4>>1]|0;t=i&65535;do{if((((t&16384|0)!=0?8:2)|0)==(a|0)){u=(r>>>8)+1|0;v=(r&255)+1|0;w=e[q+2>>1]|0;x=c[14129568+((w>>>12&7)<<2)>>2]|0;y=(w&511)-189|0;w=t>>>8<<4&1008;z=i<<9<<16>>16>>9;A=b[q+6>>1]|0;B=e[q+8>>1]|0;C=B>>>8<<1&126;D=q+14|0;b[D>>1]=A;if(v>>>0>=u>>>0|(x|0)==255){break}if(k){E=x}else{E=(x|0)%(l|0)|0}x=E<<15;F=1<<(B&7);G=(t&32768|0)==0;H=B<<5&1792;B=v;v=A;while(1){A=(v&65535)+z|0;I=H+1|0;if(((d[h+H|0]|0)&F|0)==0){J=A&65535}else{J=A+z&65535}L33968:do{if(B>>>0<224){A=B*320|0;if(J<<16>>16>-1){b[D>>1]=J-1&65535;K=0;L=y;while(1){if((L|0)>=320){break L33968}M=(b[D>>1]|0)+1&65535;b[D>>1]=M;N=c[g+((M&32767|x)<<2)>>2]|0;M=N>>>28;if(((K&255)+C|0)<256){do{if((L|0)>-1&L>>>0<320){if((M|0)==15|(M|0)==0){break}if(G&(M|0)==10){O=f+(L+A<<1)|0;P=(e[O>>1]|0)&n;b[O>>1]=P&65535;b[O>>1]=(m<<((d[o+(P+1)|0]|0)>>>7&255))+P&65535;break}else{b[f+(L+A<<1)>>1]=p&(w|M|1024)&65535;break}}}while(0);Q=L+1|0}else{Q=L}M=N>>>24&15;P=K+C|0;if(((P&255)+C|0)<256){do{if((Q|0)>-1&Q>>>0<320){if((M|0)==15|(M|0)==0){break}if(G&(M|0)==10){O=f+(Q+A<<1)|0;R=(e[O>>1]|0)&n;b[O>>1]=R&65535;b[O>>1]=(m<<((d[o+(R+1)|0]|0)>>>7&255))+R&65535;break}else{b[f+(Q+A<<1)>>1]=p&(w|M|1024)&65535;break}}}while(0);S=Q+1|0}else{S=Q}M=N>>>20&15;R=P+C|0;if(((R&255)+C|0)<256){do{if((S|0)>-1&S>>>0<320){if((M|0)==15|(M|0)==0){break}if(G&(M|0)==10){O=f+(S+A<<1)|0;T=(e[O>>1]|0)&n;b[O>>1]=T&65535;b[O>>1]=(m<<((d[o+(T+1)|0]|0)>>>7&255))+T&65535;break}else{b[f+(S+A<<1)>>1]=p&(w|M|1024)&65535;break}}}while(0);U=S+1|0}else{U=S}M=N>>>16&15;P=R+C|0;if(((P&255)+C|0)<256){do{if((U|0)>-1&U>>>0<320){if((M|0)==15|(M|0)==0){break}if(G&(M|0)==10){T=f+(U+A<<1)|0;O=(e[T>>1]|0)&n;b[T>>1]=O&65535;b[T>>1]=(m<<((d[o+(O+1)|0]|0)>>>7&255))+O&65535;break}else{b[f+(U+A<<1)>>1]=p&(w|M|1024)&65535;break}}}while(0);V=U+1|0}else{V=U}M=N>>>12&15;R=P+C|0;if(((R&255)+C|0)<256){do{if((V|0)>-1&V>>>0<320){if((M|0)==15|(M|0)==0){break}if(G&(M|0)==10){O=f+(V+A<<1)|0;T=(e[O>>1]|0)&n;b[O>>1]=T&65535;b[O>>1]=(m<<((d[o+(T+1)|0]|0)>>>7&255))+T&65535;break}else{b[f+(V+A<<1)>>1]=p&(w|M|1024)&65535;break}}}while(0);W=V+1|0}else{W=V}M=N>>>8&15;P=R+C|0;if(((P&255)+C|0)<256){do{if((W|0)>-1&W>>>0<320){if((M|0)==15|(M|0)==0){break}if(G&(M|0)==10){T=f+(W+A<<1)|0;O=(e[T>>1]|0)&n;b[T>>1]=O&65535;b[T>>1]=(m<<((d[o+(O+1)|0]|0)>>>7&255))+O&65535;break}else{b[f+(W+A<<1)>>1]=p&(w|M|1024)&65535;break}}}while(0);X=W+1|0}else{X=W}M=N>>>4&15;R=P+C|0;if(((R&255)+C|0)<256){do{if((X|0)>-1&X>>>0<320){if((M|0)==15|(M|0)==0){break}if(G&(M|0)==10){O=f+(X+A<<1)|0;T=(e[O>>1]|0)&n;b[O>>1]=T&65535;b[O>>1]=(m<<((d[o+(T+1)|0]|0)>>>7&255))+T&65535;break}else{b[f+(X+A<<1)>>1]=p&(w|M|1024)&65535;break}}}while(0);Y=X+1|0}else{Y=X}M=N&15;P=(R+C&255)+C|0;if((P|0)<256){do{if((Y|0)>-1&Y>>>0<320){if((M|0)==15|(M|0)==0){break}if(G&(M|0)==10){T=f+(Y+A<<1)|0;O=(e[T>>1]|0)&n;b[T>>1]=O&65535;b[T>>1]=(m<<((d[o+(O+1)|0]|0)>>>7&255))+O&65535;break}else{b[f+(Y+A<<1)>>1]=p&(w|M|1024)&65535;break}}}while(0);Z=Y+1|0}else{Z=Y}if((M|0)==15){break}else{K=P;L=Z}}}else{b[D>>1]=J+1&65535;L=0;K=y;while(1){if((K|0)>=320){break L33968}R=(b[D>>1]|0)-1&65535;b[D>>1]=R;N=c[g+((R&32767|x)<<2)>>2]|0;R=N&15;if(((L&255)+C|0)<256){do{if((K|0)>-1&K>>>0<320){if((R|0)==15|(R|0)==0){break}if(G&(R|0)==10){O=f+(K+A<<1)|0;T=(e[O>>1]|0)&n;b[O>>1]=T&65535;b[O>>1]=(m<<((d[o+(T+1)|0]|0)>>>7&255))+T&65535;break}else{b[f+(K+A<<1)>>1]=p&(w|R|1024)&65535;break}}}while(0);_=K+1|0}else{_=K}R=N>>>4&15;P=L+C|0;if(((P&255)+C|0)<256){do{if((_|0)>-1&_>>>0<320){if((R|0)==15|(R|0)==0){break}if(G&(R|0)==10){M=f+(_+A<<1)|0;T=(e[M>>1]|0)&n;b[M>>1]=T&65535;b[M>>1]=(m<<((d[o+(T+1)|0]|0)>>>7&255))+T&65535;break}else{b[f+(_+A<<1)>>1]=p&(w|R|1024)&65535;break}}}while(0);$=_+1|0}else{$=_}R=N>>>8&15;T=P+C|0;if(((T&255)+C|0)<256){do{if(($|0)>-1&$>>>0<320){if((R|0)==15|(R|0)==0){break}if(G&(R|0)==10){M=f+($+A<<1)|0;O=(e[M>>1]|0)&n;b[M>>1]=O&65535;b[M>>1]=(m<<((d[o+(O+1)|0]|0)>>>7&255))+O&65535;break}else{b[f+($+A<<1)>>1]=p&(w|R|1024)&65535;break}}}while(0);aa=$+1|0}else{aa=$}R=N>>>12&15;P=T+C|0;if(((P&255)+C|0)<256){do{if((aa|0)>-1&aa>>>0<320){if((R|0)==15|(R|0)==0){break}if(G&(R|0)==10){O=f+(aa+A<<1)|0;M=(e[O>>1]|0)&n;b[O>>1]=M&65535;b[O>>1]=(m<<((d[o+(M+1)|0]|0)>>>7&255))+M&65535;break}else{b[f+(aa+A<<1)>>1]=p&(w|R|1024)&65535;break}}}while(0);ab=aa+1|0}else{ab=aa}R=N>>>16&15;T=P+C|0;if(((T&255)+C|0)<256){do{if((ab|0)>-1&ab>>>0<320){if((R|0)==15|(R|0)==0){break}if(G&(R|0)==10){M=f+(ab+A<<1)|0;O=(e[M>>1]|0)&n;b[M>>1]=O&65535;b[M>>1]=(m<<((d[o+(O+1)|0]|0)>>>7&255))+O&65535;break}else{b[f+(ab+A<<1)>>1]=p&(w|R|1024)&65535;break}}}while(0);ac=ab+1|0}else{ac=ab}R=N>>>20&15;P=T+C|0;if(((P&255)+C|0)<256){do{if((ac|0)>-1&ac>>>0<320){if((R|0)==15|(R|0)==0){break}if(G&(R|0)==10){O=f+(ac+A<<1)|0;M=(e[O>>1]|0)&n;b[O>>1]=M&65535;b[O>>1]=(m<<((d[o+(M+1)|0]|0)>>>7&255))+M&65535;break}else{b[f+(ac+A<<1)>>1]=p&(w|R|1024)&65535;break}}}while(0);ad=ac+1|0}else{ad=ac}R=N>>>24&15;T=P+C|0;if(((T&255)+C|0)<256){do{if((ad|0)>-1&ad>>>0<320){if((R|0)==15|(R|0)==0){break}if(G&(R|0)==10){M=f+(ad+A<<1)|0;O=(e[M>>1]|0)&n;b[M>>1]=O&65535;b[M>>1]=(m<<((d[o+(O+1)|0]|0)>>>7&255))+O&65535;break}else{b[f+(ad+A<<1)>>1]=p&(w|R|1024)&65535;break}}}while(0);ae=ad+1|0}else{ae=ad}R=N>>>28;P=(T+C&255)+C|0;if((P|0)<256){do{if((ae|0)>-1&ae>>>0<320){if((R|0)==15|(R|0)==0){break}if(G&(R|0)==10){O=f+(ae+A<<1)|0;M=(e[O>>1]|0)&n;b[O>>1]=M&65535;b[O>>1]=(m<<((d[o+(M+1)|0]|0)>>>7&255))+M&65535;break}else{b[f+(ae+A<<1)>>1]=p&(w|R|1024)&65535;break}}}while(0);af=ae+1|0}else{af=ae}if((R|0)==15){break}else{L=P;K=af}}}}}while(0);K=B+1|0;if((K|0)<(u|0)){H=I;B=K;v=J}else{break}}}}while(0);t=q+16|0;if(t>>>0<j>>>0){q=t}else{s=25755;break}}if((s|0)==25753){return}else if((s|0)==25755){return}}function ePc(a){a=a|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;f=(c[3532380]|0)>>>16;g=c[3532374]|0;h=c[3532480]|0;i=c[3532390]|0;j=i+((c[3532384]|0)>>>1<<1)|0;if(i>>>0>=j>>>0){return}k=(f&255)<<24>>24==0;l=f&255;f=c[2112926]|0;m=c[3532486]|0;n=m+65535|0;o=m<<((c[3532378]|0)!=0);p=m+2047|0;m=i;while(1){i=b[m>>1]|0;q=i&65535;if((i&65535)>61695){r=25831;break}i=e[m+8>>1]|0;do{if((1<<(i&3)|0)==(a|0)){s=(q>>>8)+1|0;t=(q&255)+1|0;u=e[m+2>>1]|0;v=c[14129568+(u>>>12<<2)>>2]|0;w=(u&511)-189|0;u=b[m+4>>1]|0;x=b[m+6>>1]|0;y=i>>>8<<4&1008;z=i>>>2;A=z<<1&126;B=m+14|0;b[B>>1]=x;if(t>>>0>=s>>>0|(v|0)==255){break}if(k){C=v}else{C=(v|0)%(l|0)|0}v=C<<15;D=1<<(z&7);E=(y|0)==1008;F=z<<5&1792;z=t;t=x;while(1){x=F+1|0;G=(t+u&65535)+(((d[h+F|0]|0)&D|0)==0?0:u)&65535;L34159:do{if(z>>>0<224){H=z*320|0;if(G<<16>>16>-1){b[B>>1]=G-1&65535;I=0;J=w;while(1){if((J|0)>=320){break L34159}K=(b[B>>1]|0)+1&65535;b[B>>1]=K;L=e[g+((K&32767|v)<<1)>>1]|0;K=L>>>12;if(((I&255)+A|0)<256){do{if((J|0)>-1&J>>>0<320){if((K|0)==15|(K|0)==0){break}if(E){M=f+(J+H<<1)|0;b[M>>1]=o+((e[M>>1]|0)&n)&65535;break}else{b[f+(J+H<<1)>>1]=p&(y|K|1024)&65535;break}}}while(0);N=J+1|0}else{N=J}K=L>>>8&15;M=I+A|0;if(((M&255)+A|0)<256){do{if((N|0)>-1&N>>>0<320){if((K|0)==15|(K|0)==0){break}if(E){O=f+(N+H<<1)|0;b[O>>1]=o+((e[O>>1]|0)&n)&65535;break}else{b[f+(N+H<<1)>>1]=p&(y|K|1024)&65535;break}}}while(0);P=N+1|0}else{P=N}K=L>>>4&15;O=M+A|0;if(((O&255)+A|0)<256){do{if((P|0)>-1&P>>>0<320){if((K|0)==15|(K|0)==0){break}if(E){Q=f+(P+H<<1)|0;b[Q>>1]=o+((e[Q>>1]|0)&n)&65535;break}else{b[f+(P+H<<1)>>1]=p&(y|K|1024)&65535;break}}}while(0);R=P+1|0}else{R=P}K=L&15;M=(O+A&255)+A|0;if((M|0)<256){do{if((R|0)>-1&R>>>0<320){if((K|0)==15|(K|0)==0){break}if(E){Q=f+(R+H<<1)|0;b[Q>>1]=o+((e[Q>>1]|0)&n)&65535;break}else{b[f+(R+H<<1)>>1]=p&(y|K|1024)&65535;break}}}while(0);S=R+1|0}else{S=R}if((K|0)==15){break}else{I=M;J=S}}}else{b[B>>1]=G+1&65535;J=0;I=w;while(1){if((I|0)>=320){break L34159}O=(b[B>>1]|0)-1&65535;b[B>>1]=O;L=e[g+((O&32767|v)<<1)>>1]|0;O=L&15;if(((J&255)+A|0)<256){do{if((I|0)>-1&I>>>0<320){if((O|0)==15|(O|0)==0){break}if(E){Q=f+(I+H<<1)|0;b[Q>>1]=o+((e[Q>>1]|0)&n)&65535;break}else{b[f+(I+H<<1)>>1]=p&(y|O|1024)&65535;break}}}while(0);T=I+1|0}else{T=I}O=L>>>4&15;M=J+A|0;if(((M&255)+A|0)<256){do{if((T|0)>-1&T>>>0<320){if((O|0)==15|(O|0)==0){break}if(E){K=f+(T+H<<1)|0;b[K>>1]=o+((e[K>>1]|0)&n)&65535;break}else{b[f+(T+H<<1)>>1]=p&(y|O|1024)&65535;break}}}while(0);U=T+1|0}else{U=T}O=L>>>8&15;K=M+A|0;if(((K&255)+A|0)<256){do{if((U|0)>-1&U>>>0<320){if((O|0)==15|(O|0)==0){break}if(E){Q=f+(U+H<<1)|0;b[Q>>1]=o+((e[Q>>1]|0)&n)&65535;break}else{b[f+(U+H<<1)>>1]=p&(y|O|1024)&65535;break}}}while(0);V=U+1|0}else{V=U}O=L>>>12;M=(K+A&255)+A|0;if((M|0)<256){do{if((V|0)>-1&V>>>0<320){if((O|0)==15|(O|0)==0){break}if(E){Q=f+(V+H<<1)|0;b[Q>>1]=o+((e[Q>>1]|0)&n)&65535;break}else{b[f+(V+H<<1)>>1]=p&(y|O|1024)&65535;break}}}while(0);W=V+1|0}else{W=V}if((O|0)==15){break}else{J=M;I=W}}}}}while(0);I=z+1|0;if((I|0)<(s|0)){F=x;z=I;t=G}else{break}}}}while(0);i=m+16|0;if(i>>>0<j>>>0){m=i}else{r=25832;break}}if((r|0)==25832){return}else if((r|0)==25831){return}}function ePd(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[3532456]|0;d=c[2112926]|0;f=c[3532460]|0;g=0;do{h=g*320|0;i=e[a+(g<<1)>>1]|0;j=e[a+(g+256<<1)>>1]|0;k=c[3532458]&3;do{if((k|0)==3){l=(j&2048|0)==0?-1:j&127;m=25844}else if((k|0)==2){if((j&2048|0)==0){l=(i&2048|0)==0?-1:i&127;m=25844;break}else{n=j&127;m=25845;break}}else if((k|0)==1){if((i&2048|0)==0){l=(j&2048|0)==0?-1:j&127;m=25844;break}else{n=i&127;m=25845;break}}else if((k|0)==0){l=(i&2048|0)==0?-1:i&127;m=25844}}while(0);if((m|0)==25844){m=0;if((l|0)!=-1){n=l;m=25845}}if((m|0)==25845){m=0;i=(f|n)&65535;k=0;do{b[d+(k+h<<1)>>1]=i;k=k+1|0;}while((k|0)<320)}g=g+1|0;}while((g|0)<224);return}function ePe(a){a=a|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0;f=(c[3532380]|0)>>>18;g=c[3532374]|0;h=c[3532386]|0;i=h+((c[3532384]|0)>>>1<<1)|0;if(h>>>0>=i>>>0){return}j=(f&255)<<24>>24==0;k=f&255;f=c[2112926]|0;l=c[3532486]|0;m=l+65535|0;n=c[3532484]|0;o=l+4095|0;p=h;while(1){h=e[p>>1]|0;if((h&32768|0)!=0){q=26014;break}r=e[p+6>>1]|0;do{if((1<<(r>>>12&3)|0)==(a|0)){s=h>>>9&7;t=(h&511)-256|0;u=b[p+2>>1]|0;v=b[p+4>>1]|0;w=b[p+8>>1]|0;x=w&65535;y=(w<<3&-32768|(v&65535)>>>1)<<16>>16>>8;z=v&511;v=r&2047;A=(x>>>14&2)-1|0;B=x&8192;C=(B|0)!=0;D=(B>>>12)-1|0;B=x&2047;E=e[p+10>>1]|0;F=E<<4&2032;G=(D|0)<0;H=(z>>>0<128&G?z|512:z)-190|0;z=p+14|0;b[z>>1]=u;if((h&20480|0)!=0){break}if(j){I=s}else{I=(s>>>0)%(k>>>0)|0}s=I<<16;J=v>>>0<64?64:v;v=B>>>0<64?64:B;B=(ag(A,(E>>>8)+1|0)|0)+t|0;E=(x&16384|0)==0;x=(r&16384|0)!=0;K=w&2047;w=K>>>0>64?K:64;K=t;t=0;L=u;while(1){L34292:do{if(K>>>0<224){u=K*320|0;if(E){b[z>>1]=L+1&65535;M=0;N=H;while(1){if(!(C&(N|0)<320|G&(N|0)>-1)){break L34292}O=(b[z>>1]|0)-1&65535;b[z>>1]=O;P=c[g+((O&65535|s)<<2)>>2]|0;O=P&15;if((M|0)<512){Q=x&(O|0)==10;R=((511-M|0)>>>0)/(w>>>0)|0;S=(ag(R+1|0,w)|0)+M|0;T=o&(F|O|2048)&65535;U=N;V=M;while(1){do{if(U>>>0<320){if((O|0)==15|(O|0)==0){break}W=f+(U+u<<1)|0;if(Q){X=(e[W>>1]|0)&m;b[W>>1]=X&65535;b[W>>1]=(l<<((d[n+(X+1)|0]|0)>>>7&255))+X&65535;break}else{b[W>>1]=T;break}}}while(0);W=V+v|0;if((W|0)<512){U=U+D|0;V=W}else{break}}Y=N+D+(ag(R,D)|0)|0;Z=S}else{Y=N;Z=M}V=Z-512|0;U=P>>>4&15;if((V|0)<512){T=x&(U|0)==10;Q=((1023-Z|0)>>>0)/(w>>>0)|0;O=(ag(Q+1|0,w)|0)+V|0;W=o&(F|U|2048)&65535;X=Y;_=V;while(1){do{if(X>>>0<320){if((U|0)==15|(U|0)==0){break}$=f+(X+u<<1)|0;if(T){aa=(e[$>>1]|0)&m;b[$>>1]=aa&65535;b[$>>1]=(l<<((d[n+(aa+1)|0]|0)>>>7&255))+aa&65535;break}else{b[$>>1]=W;break}}}while(0);$=_+v|0;if(($|0)<512){X=X+D|0;_=$}else{break}}ab=Y+D+(ag(Q,D)|0)|0;ac=O}else{ab=Y;ac=V}_=ac-512|0;X=P>>>8&15;if((_|0)<512){W=x&(X|0)==10;T=((1023-ac|0)>>>0)/(w>>>0)|0;U=(ag(T+1|0,w)|0)+_|0;S=o&(F|X|2048)&65535;R=ab;$=_;while(1){do{if(R>>>0<320){if((X|0)==15|(X|0)==0){break}aa=f+(R+u<<1)|0;if(W){ad=(e[aa>>1]|0)&m;b[aa>>1]=ad&65535;b[aa>>1]=(l<<((d[n+(ad+1)|0]|0)>>>7&255))+ad&65535;break}else{b[aa>>1]=S;break}}}while(0);aa=$+v|0;if((aa|0)<512){R=R+D|0;$=aa}else{break}}ae=ab+D+(ag(T,D)|0)|0;af=U}else{ae=ab;af=_}$=af-512|0;R=P>>>12&15;if(($|0)<512){S=x&(R|0)==10;W=((1023-af|0)>>>0)/(w>>>0)|0;X=(ag(W+1|0,w)|0)+$|0;V=o&(F|R|2048)&65535;O=ae;Q=$;while(1){do{if(O>>>0<320){if((R|0)==15|(R|0)==0){break}aa=f+(O+u<<1)|0;if(S){ad=(e[aa>>1]|0)&m;b[aa>>1]=ad&65535;b[aa>>1]=(l<<((d[n+(ad+1)|0]|0)>>>7&255))+ad&65535;break}else{b[aa>>1]=V;break}}}while(0);aa=Q+v|0;if((aa|0)<512){O=O+D|0;Q=aa}else{break}}ah=ae+D+(ag(W,D)|0)|0;ai=X}else{ah=ae;ai=$}Q=ai-512|0;O=P>>>16&15;if((Q|0)<512){V=x&(O|0)==10;S=((1023-ai|0)>>>0)/(w>>>0)|0;R=(ag(S+1|0,w)|0)+Q|0;_=o&(F|O|2048)&65535;U=ah;T=Q;while(1){do{if(U>>>0<320){if((O|0)==15|(O|0)==0){break}aa=f+(U+u<<1)|0;if(V){ad=(e[aa>>1]|0)&m;b[aa>>1]=ad&65535;b[aa>>1]=(l<<((d[n+(ad+1)|0]|0)>>>7&255))+ad&65535;break}else{b[aa>>1]=_;break}}}while(0);aa=T+v|0;if((aa|0)<512){U=U+D|0;T=aa}else{break}}aj=ah+D+(ag(S,D)|0)|0;ak=R}else{aj=ah;ak=Q}T=ak-512|0;U=P>>>20&15;if((T|0)<512){_=x&(U|0)==10;V=((1023-ak|0)>>>0)/(w>>>0)|0;O=(ag(V+1|0,w)|0)+T|0;$=o&(F|U|2048)&65535;X=aj;W=T;while(1){do{if(X>>>0<320){if((U|0)==15|(U|0)==0){break}aa=f+(X+u<<1)|0;if(_){ad=(e[aa>>1]|0)&m;b[aa>>1]=ad&65535;b[aa>>1]=(l<<((d[n+(ad+1)|0]|0)>>>7&255))+ad&65535;break}else{b[aa>>1]=$;break}}}while(0);aa=W+v|0;if((aa|0)<512){X=X+D|0;W=aa}else{break}}al=aj+D+(ag(V,D)|0)|0;am=O}else{al=aj;am=T}W=am-512|0;X=P>>>24&15;if((W|0)<512){$=x&(X|0)==10;_=((1023-am|0)>>>0)/(w>>>0)|0;U=(ag(_+1|0,w)|0)+W|0;Q=o&(F|X|2048)&65535;R=al;S=W;while(1){do{if(R>>>0<320){if((X|0)==15|(X|0)==0){break}aa=f+(R+u<<1)|0;if($){ad=(e[aa>>1]|0)&m;b[aa>>1]=ad&65535;b[aa>>1]=(l<<((d[n+(ad+1)|0]|0)>>>7&255))+ad&65535;break}else{b[aa>>1]=Q;break}}}while(0);aa=S+v|0;if((aa|0)<512){R=R+D|0;S=aa}else{break}}an=al+D+(ag(_,D)|0)|0;ao=U}else{an=al;ao=W}S=ao-512|0;R=P>>>28;if((S|0)<512){Q=x&(R|0)==10;$=((1023-ao|0)>>>0)/(w>>>0)|0;X=(ag($+1|0,w)|0)+S|0;T=o&(F|R|2048)&65535;O=an;V=S;while(1){do{if(O>>>0<320){if((R|0)==15|(R|0)==0){break}aa=f+(O+u<<1)|0;if(Q){ad=(e[aa>>1]|0)&m;b[aa>>1]=ad&65535;b[aa>>1]=(l<<((d[n+(ad+1)|0]|0)>>>7&255))+ad&65535;break}else{b[aa>>1]=T;break}}}while(0);aa=V+v|0;if((aa|0)<512){O=O+D|0;V=aa}else{break}}ap=an+D+(ag($,D)|0)|0;aq=X}else{ap=an;aq=S}if((P&251658240|0)==251658240){break}else{M=aq-512|0;N=ap}}}else{b[z>>1]=L-1&65535;N=0;M=H;while(1){if(!(C&(M|0)<320|G&(M|0)>-1)){break L34292}V=(b[z>>1]|0)+1&65535;b[z>>1]=V;O=c[g+((V&65535|s)<<2)>>2]|0;V=O>>>28;if((N|0)<512){T=x&(V|0)==10;Q=((511-N|0)>>>0)/(w>>>0)|0;R=(ag(Q+1|0,w)|0)+N|0;W=o&(F|V|2048)&65535;U=M;_=N;while(1){do{if(U>>>0<320){if((V|0)==15|(V|0)==0){break}aa=f+(U+u<<1)|0;if(T){ad=(e[aa>>1]|0)&m;b[aa>>1]=ad&65535;b[aa>>1]=(l<<((d[n+(ad+1)|0]|0)>>>7&255))+ad&65535;break}else{b[aa>>1]=W;break}}}while(0);aa=_+v|0;if((aa|0)<512){U=U+D|0;_=aa}else{break}}ar=M+D+(ag(Q,D)|0)|0;as=R}else{ar=M;as=N}_=as-512|0;U=O>>>24&15;if((_|0)<512){W=x&(U|0)==10;T=((1023-as|0)>>>0)/(w>>>0)|0;V=(ag(T+1|0,w)|0)+_|0;P=o&(F|U|2048)&65535;S=ar;X=_;while(1){do{if(S>>>0<320){if((U|0)==15|(U|0)==0){break}$=f+(S+u<<1)|0;if(W){aa=(e[$>>1]|0)&m;b[$>>1]=aa&65535;b[$>>1]=(l<<((d[n+(aa+1)|0]|0)>>>7&255))+aa&65535;break}else{b[$>>1]=P;break}}}while(0);$=X+v|0;if(($|0)<512){S=S+D|0;X=$}else{break}}at=ar+D+(ag(T,D)|0)|0;au=V}else{at=ar;au=_}X=au-512|0;S=O>>>20&15;if((X|0)<512){P=x&(S|0)==10;W=((1023-au|0)>>>0)/(w>>>0)|0;U=(ag(W+1|0,w)|0)+X|0;R=o&(F|S|2048)&65535;Q=at;$=X;while(1){do{if(Q>>>0<320){if((S|0)==15|(S|0)==0){break}aa=f+(Q+u<<1)|0;if(P){ad=(e[aa>>1]|0)&m;b[aa>>1]=ad&65535;b[aa>>1]=(l<<((d[n+(ad+1)|0]|0)>>>7&255))+ad&65535;break}else{b[aa>>1]=R;break}}}while(0);aa=$+v|0;if((aa|0)<512){Q=Q+D|0;$=aa}else{break}}av=at+D+(ag(W,D)|0)|0;aw=U}else{av=at;aw=X}$=aw-512|0;Q=O>>>16&15;if(($|0)<512){R=x&(Q|0)==10;P=((1023-aw|0)>>>0)/(w>>>0)|0;S=(ag(P+1|0,w)|0)+$|0;_=o&(F|Q|2048)&65535;V=av;T=$;while(1){do{if(V>>>0<320){if((Q|0)==15|(Q|0)==0){break}aa=f+(V+u<<1)|0;if(R){ad=(e[aa>>1]|0)&m;b[aa>>1]=ad&65535;b[aa>>1]=(l<<((d[n+(ad+1)|0]|0)>>>7&255))+ad&65535;break}else{b[aa>>1]=_;break}}}while(0);aa=T+v|0;if((aa|0)<512){V=V+D|0;T=aa}else{break}}ax=av+D+(ag(P,D)|0)|0;ay=S}else{ax=av;ay=$}T=ay-512|0;V=O>>>12&15;if((T|0)<512){_=x&(V|0)==10;R=((1023-ay|0)>>>0)/(w>>>0)|0;Q=(ag(R+1|0,w)|0)+T|0;X=o&(F|V|2048)&65535;U=ax;W=T;while(1){do{if(U>>>0<320){if((V|0)==15|(V|0)==0){break}aa=f+(U+u<<1)|0;if(_){ad=(e[aa>>1]|0)&m;b[aa>>1]=ad&65535;b[aa>>1]=(l<<((d[n+(ad+1)|0]|0)>>>7&255))+ad&65535;break}else{b[aa>>1]=X;break}}}while(0);aa=W+v|0;if((aa|0)<512){U=U+D|0;W=aa}else{break}}az=ax+D+(ag(R,D)|0)|0;aA=Q}else{az=ax;aA=T}W=aA-512|0;U=O>>>8&15;if((W|0)<512){X=x&(U|0)==10;_=((1023-aA|0)>>>0)/(w>>>0)|0;V=(ag(_+1|0,w)|0)+W|0;$=o&(F|U|2048)&65535;S=az;P=W;while(1){do{if(S>>>0<320){if((U|0)==15|(U|0)==0){break}aa=f+(S+u<<1)|0;if(X){ad=(e[aa>>1]|0)&m;b[aa>>1]=ad&65535;b[aa>>1]=(l<<((d[n+(ad+1)|0]|0)>>>7&255))+ad&65535;break}else{b[aa>>1]=$;break}}}while(0);aa=P+v|0;if((aa|0)<512){S=S+D|0;P=aa}else{break}}aB=az+D+(ag(_,D)|0)|0;aC=V}else{aB=az;aC=W}P=aC-512|0;S=O>>>4&15;if((P|0)<512){$=x&(S|0)==10;X=((1023-aC|0)>>>0)/(w>>>0)|0;U=(ag(X+1|0,w)|0)+P|0;T=o&(F|S|2048)&65535;Q=aB;R=P;while(1){do{if(Q>>>0<320){if((S|0)==15|(S|0)==0){break}aa=f+(Q+u<<1)|0;if($){ad=(e[aa>>1]|0)&m;b[aa>>1]=ad&65535;b[aa>>1]=(l<<((d[n+(ad+1)|0]|0)>>>7&255))+ad&65535;break}else{b[aa>>1]=T;break}}}while(0);aa=R+v|0;if((aa|0)<512){Q=Q+D|0;R=aa}else{break}}aD=aB+D+(ag(X,D)|0)|0;aE=U}else{aD=aB;aE=P}R=aE-512|0;Q=O&15;if((R|0)<512){T=x&(Q|0)==10;$=((1023-aE|0)>>>0)/(w>>>0)|0;S=(ag($+1|0,w)|0)+R|0;W=o&(F|Q|2048)&65535;V=aD;_=R;while(1){do{if(V>>>0<320){if((Q|0)==15|(Q|0)==0){break}aa=f+(V+u<<1)|0;if(T){ad=(e[aa>>1]|0)&m;b[aa>>1]=ad&65535;b[aa>>1]=(l<<((d[n+(ad+1)|0]|0)>>>7&255))+ad&65535;break}else{b[aa>>1]=W;break}}}while(0);aa=_+v|0;if((aa|0)<512){V=V+D|0;_=aa}else{break}}aF=aD+D+(ag($,D)|0)|0;aG=S}else{aF=aD;aG=R}if((O&240|0)==240){break}else{N=aG-512|0;M=aF}}}}}while(0);M=t+J|0;N=(ag(M>>>9,y)|0)+(L&65535)&65535;u=K+A|0;if((u|0)==(B|0)){break}else{K=u;t=M&511;L=N}}}}while(0);r=p+16|0;if(r>>>0<i>>>0){p=r}else{q=26013;break}}if((q|0)==26013){return}else if((q|0)==26014){return}}function ePf(){var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;f=i;i=i+64|0;g=f|0;h=c[3532456]|0;j=g|0;k=g+2|0;l=g+4|0;m=g+6|0;n=g+14|0;o=g+32|0;p=g+34|0;q=g+36|0;r=g+38|0;s=g+46|0;t=c[2112926]|0;u=c[3532448]|0;v=u+262144|0;w=c[3532464]|0;x=c[3532462]|0;y=a[7461536]|0;z=y?-166:0;A=y?1362:1528;y=0;do{B=y*320|0;C=e[h+(y<<1)>>1]|0;D=y+256|0;E=e[h+(D<<1)>>1]|0;F=(C&2048|0)!=0;if(F){if((E&2048|0)==0){G=v;H=0;I=26019}}else{G=u+(C>>>1<<9&130560)|0;H=(E&2048|0)!=0;I=26019}do{if((I|0)==26019){I=0;J=c[3532458]|0;K=J&3;L=(J&4|0)==0;J=L?C&511:y;M=e[h+(J+512<<1)>>1]|0;N=b[h+(J+1536<<1)>>1]|0;J=N&65535;if(H){O=v}else{O=u+(E>>>1<<9&130560|131072)|0}P=L?E&511:D;L=e[h+(P+1024<<1)>>1]|0;Q=b[h+(P+1536<<1)>>1]|0;P=Q&65535;R=(w^J&1)&65535;b[j>>1]=R;b[k>>1]=(w^(J>>>1&1|2))&65535;b[l>>1]=(w^(J>>>2&1|4))&65535;if((C&512|0)==0){S=(x^(N&65535)>>>8&255&15)&65535}else{S=R}b[m>>1]=S;b[n>>1]=(w^(J>>>3&1|6))&65535;J=((P>>>4&1|8)^w)&65535;b[o>>1]=J;b[p>>1]=((P>>>5&1|10)^w)&65535;b[q>>1]=((P>>>6&1|12)^w)&65535;if((E&512|0)==0){T=(x^((Q&65535)>>>8&255&15|16))&65535}else{T=J}b[r>>1]=T;b[s>>1]=((P>>>7&1|14)^w)&65535;if((K|0)==0){if(F){break}P=0;J=M+2568-z|0;while(1){Q=J&4095;if(Q>>>0<512){U=d[G+Q|0]|0}else{U=3}b[t+(P+B<<1)>>1]=b[g+(U<<1)>>1]|0;R=P+1|0;if((R|0)<320){P=R;J=Q+1|0}else{break}}}else if((K|0)==1){J=0;P=M-A|0;Q=L-A|0;while(1){R=P&4095;N=Q&4095;if(R>>>0<512){V=d[G+R|0]|0}else{V=3}if(N>>>0<512){W=d[O+N|0]|0}else{W=3}if(((d[591984+V|0]|0)&1<<W|0)==0){b[t+(J+B<<1)>>1]=b[g+(V<<1)>>1]|0}else{b[t+(J+B<<1)>>1]=b[g+(W+16<<1)>>1]|0}X=J+1|0;if((X|0)<320){J=X;P=R+1|0;Q=N+1|0}else{break}}}else if((K|0)==2){Q=0;P=M-A|0;J=L-A|0;while(1){N=P&4095;R=J&4095;if(N>>>0<512){Y=d[G+N|0]|0}else{Y=3}if(R>>>0<512){Z=d[O+R|0]|0}else{Z=3}if(((d[591992+Y|0]|0)&1<<Z|0)==0){b[t+(Q+B<<1)>>1]=b[g+(Y<<1)>>1]|0}else{b[t+(Q+B<<1)>>1]=b[g+(Z+16<<1)>>1]|0}X=Q+1|0;if((X|0)<320){Q=X;P=N+1|0;J=R+1|0}else{break}}}else if((K|0)==3){if(H){break}J=0;P=L+2568-z|0;while(1){Q=P&4095;if(Q>>>0<512){_=(d[O+Q|0]|0)+16|0}else{_=19}b[t+(J+B<<1)>>1]=b[g+(_<<1)>>1]|0;M=J+1|0;if((M|0)<320){J=M;P=Q+1|0}else{break}}}else{break}}}while(0);y=y+1|0;}while((y|0)<224);i=f;return}function ePg(a){a=a|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0;f=(c[3532380]|0)>>>18;g=c[3532374]|0;h=c[3532386]|0;i=h+((c[3532384]|0)>>>1<<1)|0;if(h>>>0>=i>>>0){return}j=(f&255)<<24>>24==0;k=f&255;f=c[2112926]|0;l=c[3532486]|0;m=l+65535|0;n=c[3532484]|0;o=l+4095|0;p=h;while(1){h=e[p>>1]|0;if((h&32768|0)!=0){q=26221;break}r=e[p+6>>1]|0;do{if((1<<(r>>>12&3)|0)==(a|0)){s=h>>>9&7;t=(h&511)-256|0;u=b[p+2>>1]|0;v=b[p+4>>1]|0;w=b[p+8>>1]|0;x=w&65535;y=(w<<3&-32768|(v&65535)>>>1)<<16>>16>>8;z=v&511;v=r&2047;A=(x>>>14&2)-1|0;B=x&8192;C=(B|0)!=0;D=(B>>>12)-1|0;B=x&2047;E=(b[p+10>>1]&4095)+1|0;F=(e[p+12>>1]|0)<<4&4080;G=(D|0)<0;H=(z>>>0<128&G?z|512:z)-190|0;z=p+14|0;b[z>>1]=u;if((h&20480|0)!=0){break}if(j){I=s}else{I=(s>>>0)%(k>>>0)|0}s=I<<16;J=v>>>0<64?64:v;v=B>>>0<64?64:B;B=(ag(A,E)|0)+t|0;E=(x&16384|0)==0;x=(r&16384|0)!=0;K=w&2047;w=K>>>0>64?K:64;K=t;t=0;L=u;while(1){L34591:do{if(K>>>0<224){u=K*320|0;if(E){b[z>>1]=L+1&65535;M=0;N=H;while(1){if(!(C&(N|0)<320|G&(N|0)>-1)){break L34591}O=(b[z>>1]|0)-1&65535;b[z>>1]=O;P=c[g+((O&65535|s)<<2)>>2]|0;O=P&15;if((M|0)<512){Q=x&(O|0)==10;R=((511-M|0)>>>0)/(w>>>0)|0;S=(ag(R+1|0,w)|0)+M|0;T=o&(O|F)&65535;U=N;V=M;while(1){do{if(U>>>0<320){if((O|0)==15|(O|0)==0){break}W=f+(U+u<<1)|0;if(Q){X=(e[W>>1]|0)&m;b[W>>1]=X&65535;b[W>>1]=(l<<((d[n+(X+1)|0]|0)>>>7&255))+X&65535;break}else{b[W>>1]=T;break}}}while(0);W=V+v|0;if((W|0)<512){U=U+D|0;V=W}else{break}}Y=N+D+(ag(R,D)|0)|0;Z=S}else{Y=N;Z=M}V=Z-512|0;U=P>>>4&15;if((V|0)<512){T=x&(U|0)==10;Q=((1023-Z|0)>>>0)/(w>>>0)|0;O=(ag(Q+1|0,w)|0)+V|0;W=o&(U|F)&65535;X=Y;_=V;while(1){do{if(X>>>0<320){if((U|0)==15|(U|0)==0){break}$=f+(X+u<<1)|0;if(T){aa=(e[$>>1]|0)&m;b[$>>1]=aa&65535;b[$>>1]=(l<<((d[n+(aa+1)|0]|0)>>>7&255))+aa&65535;break}else{b[$>>1]=W;break}}}while(0);$=_+v|0;if(($|0)<512){X=X+D|0;_=$}else{break}}ab=Y+D+(ag(Q,D)|0)|0;ac=O}else{ab=Y;ac=V}_=ac-512|0;X=P>>>8&15;if((_|0)<512){W=x&(X|0)==10;T=((1023-ac|0)>>>0)/(w>>>0)|0;U=(ag(T+1|0,w)|0)+_|0;S=o&(X|F)&65535;R=ab;$=_;while(1){do{if(R>>>0<320){if((X|0)==15|(X|0)==0){break}aa=f+(R+u<<1)|0;if(W){ad=(e[aa>>1]|0)&m;b[aa>>1]=ad&65535;b[aa>>1]=(l<<((d[n+(ad+1)|0]|0)>>>7&255))+ad&65535;break}else{b[aa>>1]=S;break}}}while(0);aa=$+v|0;if((aa|0)<512){R=R+D|0;$=aa}else{break}}ae=ab+D+(ag(T,D)|0)|0;af=U}else{ae=ab;af=_}$=af-512|0;R=P>>>12&15;if(($|0)<512){S=x&(R|0)==10;W=((1023-af|0)>>>0)/(w>>>0)|0;X=(ag(W+1|0,w)|0)+$|0;V=o&(R|F)&65535;O=ae;Q=$;while(1){do{if(O>>>0<320){if((R|0)==15|(R|0)==0){break}aa=f+(O+u<<1)|0;if(S){ad=(e[aa>>1]|0)&m;b[aa>>1]=ad&65535;b[aa>>1]=(l<<((d[n+(ad+1)|0]|0)>>>7&255))+ad&65535;break}else{b[aa>>1]=V;break}}}while(0);aa=Q+v|0;if((aa|0)<512){O=O+D|0;Q=aa}else{break}}ah=ae+D+(ag(W,D)|0)|0;ai=X}else{ah=ae;ai=$}Q=ai-512|0;O=P>>>16&15;if((Q|0)<512){V=x&(O|0)==10;S=((1023-ai|0)>>>0)/(w>>>0)|0;R=(ag(S+1|0,w)|0)+Q|0;_=o&(O|F)&65535;U=ah;T=Q;while(1){do{if(U>>>0<320){if((O|0)==15|(O|0)==0){break}aa=f+(U+u<<1)|0;if(V){ad=(e[aa>>1]|0)&m;b[aa>>1]=ad&65535;b[aa>>1]=(l<<((d[n+(ad+1)|0]|0)>>>7&255))+ad&65535;break}else{b[aa>>1]=_;break}}}while(0);aa=T+v|0;if((aa|0)<512){U=U+D|0;T=aa}else{break}}aj=ah+D+(ag(S,D)|0)|0;ak=R}else{aj=ah;ak=Q}T=ak-512|0;U=P>>>20&15;if((T|0)<512){_=x&(U|0)==10;V=((1023-ak|0)>>>0)/(w>>>0)|0;O=(ag(V+1|0,w)|0)+T|0;$=o&(U|F)&65535;X=aj;W=T;while(1){do{if(X>>>0<320){if((U|0)==15|(U|0)==0){break}aa=f+(X+u<<1)|0;if(_){ad=(e[aa>>1]|0)&m;b[aa>>1]=ad&65535;b[aa>>1]=(l<<((d[n+(ad+1)|0]|0)>>>7&255))+ad&65535;break}else{b[aa>>1]=$;break}}}while(0);aa=W+v|0;if((aa|0)<512){X=X+D|0;W=aa}else{break}}al=aj+D+(ag(V,D)|0)|0;am=O}else{al=aj;am=T}W=am-512|0;X=P>>>24&15;if((W|0)<512){$=x&(X|0)==10;_=((1023-am|0)>>>0)/(w>>>0)|0;U=(ag(_+1|0,w)|0)+W|0;Q=o&(X|F)&65535;R=al;S=W;while(1){do{if(R>>>0<320){if((X|0)==15|(X|0)==0){break}aa=f+(R+u<<1)|0;if($){ad=(e[aa>>1]|0)&m;b[aa>>1]=ad&65535;b[aa>>1]=(l<<((d[n+(ad+1)|0]|0)>>>7&255))+ad&65535;break}else{b[aa>>1]=Q;break}}}while(0);aa=S+v|0;if((aa|0)<512){R=R+D|0;S=aa}else{break}}an=al+D+(ag(_,D)|0)|0;ao=U}else{an=al;ao=W}S=ao-512|0;R=P>>>28;if((S|0)<512){Q=x&(R|0)==10;$=((1023-ao|0)>>>0)/(w>>>0)|0;X=(ag($+1|0,w)|0)+S|0;T=o&(R|F)&65535;O=an;V=S;while(1){do{if(O>>>0<320){if((R|0)==15|(R|0)==0){break}aa=f+(O+u<<1)|0;if(Q){ad=(e[aa>>1]|0)&m;b[aa>>1]=ad&65535;b[aa>>1]=(l<<((d[n+(ad+1)|0]|0)>>>7&255))+ad&65535;break}else{b[aa>>1]=T;break}}}while(0);aa=V+v|0;if((aa|0)<512){O=O+D|0;V=aa}else{break}}ap=an+D+(ag($,D)|0)|0;aq=X}else{ap=an;aq=S}if((P&251658240|0)==251658240){break}else{M=aq-512|0;N=ap}}}else{b[z>>1]=L-1&65535;N=0;M=H;while(1){if(!(C&(M|0)<320|G&(M|0)>-1)){break L34591}V=(b[z>>1]|0)+1&65535;b[z>>1]=V;O=c[g+((V&65535|s)<<2)>>2]|0;V=O>>>28;if((N|0)<512){T=x&(V|0)==10;Q=((511-N|0)>>>0)/(w>>>0)|0;R=(ag(Q+1|0,w)|0)+N|0;W=o&(V|F)&65535;U=M;_=N;while(1){do{if(U>>>0<320){if((V|0)==15|(V|0)==0){break}aa=f+(U+u<<1)|0;if(T){ad=(e[aa>>1]|0)&m;b[aa>>1]=ad&65535;b[aa>>1]=(l<<((d[n+(ad+1)|0]|0)>>>7&255))+ad&65535;break}else{b[aa>>1]=W;break}}}while(0);aa=_+v|0;if((aa|0)<512){U=U+D|0;_=aa}else{break}}ar=M+D+(ag(Q,D)|0)|0;as=R}else{ar=M;as=N}_=as-512|0;U=O>>>24&15;if((_|0)<512){W=x&(U|0)==10;T=((1023-as|0)>>>0)/(w>>>0)|0;V=(ag(T+1|0,w)|0)+_|0;P=o&(U|F)&65535;S=ar;X=_;while(1){do{if(S>>>0<320){if((U|0)==15|(U|0)==0){break}$=f+(S+u<<1)|0;if(W){aa=(e[$>>1]|0)&m;b[$>>1]=aa&65535;b[$>>1]=(l<<((d[n+(aa+1)|0]|0)>>>7&255))+aa&65535;break}else{b[$>>1]=P;break}}}while(0);$=X+v|0;if(($|0)<512){S=S+D|0;X=$}else{break}}at=ar+D+(ag(T,D)|0)|0;au=V}else{at=ar;au=_}X=au-512|0;S=O>>>20&15;if((X|0)<512){P=x&(S|0)==10;W=((1023-au|0)>>>0)/(w>>>0)|0;U=(ag(W+1|0,w)|0)+X|0;R=o&(S|F)&65535;Q=at;$=X;while(1){do{if(Q>>>0<320){if((S|0)==15|(S|0)==0){break}aa=f+(Q+u<<1)|0;if(P){ad=(e[aa>>1]|0)&m;b[aa>>1]=ad&65535;b[aa>>1]=(l<<((d[n+(ad+1)|0]|0)>>>7&255))+ad&65535;break}else{b[aa>>1]=R;break}}}while(0);aa=$+v|0;if((aa|0)<512){Q=Q+D|0;$=aa}else{break}}av=at+D+(ag(W,D)|0)|0;aw=U}else{av=at;aw=X}$=aw-512|0;Q=O>>>16&15;if(($|0)<512){R=x&(Q|0)==10;P=((1023-aw|0)>>>0)/(w>>>0)|0;S=(ag(P+1|0,w)|0)+$|0;_=o&(Q|F)&65535;V=av;T=$;while(1){do{if(V>>>0<320){if((Q|0)==15|(Q|0)==0){break}aa=f+(V+u<<1)|0;if(R){ad=(e[aa>>1]|0)&m;b[aa>>1]=ad&65535;b[aa>>1]=(l<<((d[n+(ad+1)|0]|0)>>>7&255))+ad&65535;break}else{b[aa>>1]=_;break}}}while(0);aa=T+v|0;if((aa|0)<512){V=V+D|0;T=aa}else{break}}ax=av+D+(ag(P,D)|0)|0;ay=S}else{ax=av;ay=$}T=ay-512|0;V=O>>>12&15;if((T|0)<512){_=x&(V|0)==10;R=((1023-ay|0)>>>0)/(w>>>0)|0;Q=(ag(R+1|0,w)|0)+T|0;X=o&(V|F)&65535;U=ax;W=T;while(1){do{if(U>>>0<320){if((V|0)==15|(V|0)==0){break}aa=f+(U+u<<1)|0;if(_){ad=(e[aa>>1]|0)&m;b[aa>>1]=ad&65535;b[aa>>1]=(l<<((d[n+(ad+1)|0]|0)>>>7&255))+ad&65535;break}else{b[aa>>1]=X;break}}}while(0);aa=W+v|0;if((aa|0)<512){U=U+D|0;W=aa}else{break}}az=ax+D+(ag(R,D)|0)|0;aA=Q}else{az=ax;aA=T}W=aA-512|0;U=O>>>8&15;if((W|0)<512){X=x&(U|0)==10;_=((1023-aA|0)>>>0)/(w>>>0)|0;V=(ag(_+1|0,w)|0)+W|0;$=o&(U|F)&65535;S=az;P=W;while(1){do{if(S>>>0<320){if((U|0)==15|(U|0)==0){break}aa=f+(S+u<<1)|0;if(X){ad=(e[aa>>1]|0)&m;b[aa>>1]=ad&65535;b[aa>>1]=(l<<((d[n+(ad+1)|0]|0)>>>7&255))+ad&65535;break}else{b[aa>>1]=$;break}}}while(0);aa=P+v|0;if((aa|0)<512){S=S+D|0;P=aa}else{break}}aB=az+D+(ag(_,D)|0)|0;aC=V}else{aB=az;aC=W}P=aC-512|0;S=O>>>4&15;if((P|0)<512){$=x&(S|0)==10;X=((1023-aC|0)>>>0)/(w>>>0)|0;U=(ag(X+1|0,w)|0)+P|0;T=o&(S|F)&65535;Q=aB;R=P;while(1){do{if(Q>>>0<320){if((S|0)==15|(S|0)==0){break}aa=f+(Q+u<<1)|0;if($){ad=(e[aa>>1]|0)&m;b[aa>>1]=ad&65535;b[aa>>1]=(l<<((d[n+(ad+1)|0]|0)>>>7&255))+ad&65535;break}else{b[aa>>1]=T;break}}}while(0);aa=R+v|0;if((aa|0)<512){Q=Q+D|0;R=aa}else{break}}aD=aB+D+(ag(X,D)|0)|0;aE=U}else{aD=aB;aE=P}R=aE-512|0;Q=O&15;if((R|0)<512){T=x&(Q|0)==10;$=((1023-aE|0)>>>0)/(w>>>0)|0;S=(ag($+1|0,w)|0)+R|0;W=o&(Q|F)&65535;V=aD;_=R;while(1){do{if(V>>>0<320){if((Q|0)==15|(Q|0)==0){break}aa=f+(V+u<<1)|0;if(T){ad=(e[aa>>1]|0)&m;b[aa>>1]=ad&65535;b[aa>>1]=(l<<((d[n+(ad+1)|0]|0)>>>7&255))+ad&65535;break}else{b[aa>>1]=W;break}}}while(0);aa=_+v|0;if((aa|0)<512){V=V+D|0;_=aa}else{break}}aF=aD+D+(ag($,D)|0)|0;aG=S}else{aF=aD;aG=R}if((O&240|0)==240){break}else{N=aG-512|0;M=aF}}}}}while(0);M=t+J|0;N=(ag(M>>>9,y)|0)+(L&65535)&65535;u=K+A|0;if((u|0)==(B|0)){break}else{K=u;t=M&511;L=N}}}}while(0);r=p+16|0;if(r>>>0<i>>>0){p=r}else{q=26219;break}}if((q|0)==26219){return}else if((q|0)==26221){return}}function ePh(d,e,f,g,h,i,j){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0;k=j+(e<<6)|0;c[2112928]=k;e=h<<3|i;i=d+((g<<10)+f<<1)|0;f=0;g=k;while(1){k=a[g]|0;if(k<<24>>24!=0){b[i>>1]=(k&255|e)&65535}k=a[g+1|0]|0;if(k<<24>>24!=0){b[i+2>>1]=(k&255|e)&65535}k=a[g+2|0]|0;if(k<<24>>24!=0){b[i+4>>1]=(k&255|e)&65535}k=a[g+3|0]|0;if(k<<24>>24!=0){b[i+6>>1]=(k&255|e)&65535}k=a[g+4|0]|0;if(k<<24>>24!=0){b[i+8>>1]=(k&255|e)&65535}k=a[g+5|0]|0;if(k<<24>>24!=0){b[i+10>>1]=(k&255|e)&65535}k=a[g+6|0]|0;if(k<<24>>24!=0){b[i+12>>1]=(k&255|e)&65535}k=a[g+7|0]|0;if(k<<24>>24!=0){b[i+14>>1]=(k&255|e)&65535}k=f+1|0;l=g+8|0;if((k|0)<8){i=i+2048|0;f=k;g=l}else{break}}c[2112928]=l;return}function ePi(a){a=a|0;var b=0,d=0;b=a&255;if((b|0)==1){d=c[(c[3531464]|0)+4240>>2]&255;return d|0}else if((b|0)==64|(b|0)==192){d=c[3532412]&255;return d|0}else{d=0;return d|0}return 0}function ePj(b,d){b=b|0;d=d|0;var e=0;e=b&255;if((e|0)==0){c[2113304]=d&255;return}else if((e|0)==1){e=c[2113304]|0;a[14168504+e|0]=d;mv(0,e,d&255);return}else{return}}function ePk(b){b=b|0;var d=0,e=0;d=b&65535;if(!((d|0)==57344|(d|0)==59392)){e=0;return e|0}a[9706117]=0;e=c[3532412]&255;return e|0}function ePl(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a=c[3532330]|0;b=c[9757320+(c[1836236]<<2)>>2]|0;d=0;e=0;while(1){c[b+76+(e<<2)>>2]=a+(e<<8);f=d+1&65535;if((f&65535)>127){g=0;h=0;break}else{d=f;e=f&65535}}while(1){e=a+(h<<8)|0;c[b+76+(h+512<<2)>>2]=e;c[b+76+(h+768<<2)>>2]=e;e=g+1&65535;if((e&65535)>127){break}else{g=e;h=e&65535}}h=c[3532334]|0;c[b+1068>>2]=h;g=h+256|0;c[b+1072>>2]=g;a=h+512|0;c[b+1076>>2]=a;e=h+768|0;c[b+1080>>2]=e;d=h+1024|0;c[b+1084>>2]=d;f=h+1280|0;c[b+1088>>2]=f;i=h+1536|0;c[b+1092>>2]=i;j=h+1792|0;c[b+1096>>2]=j;c[b+2092>>2]=h;c[b+2096>>2]=g;c[b+2100>>2]=a;c[b+2104>>2]=e;c[b+2108>>2]=d;c[b+2112>>2]=f;c[b+2116>>2]=i;c[b+2120>>2]=j;c[b+3116>>2]=h;c[b+4140>>2]=h;c[b+3120>>2]=g;c[b+4144>>2]=g;c[b+3124>>2]=a;c[b+4148>>2]=a;c[b+3128>>2]=e;c[b+4152>>2]=e;c[b+3132>>2]=d;c[b+4156>>2]=d;c[b+3136>>2]=f;c[b+4160>>2]=f;c[b+3140>>2]=i;c[b+4164>>2]=i;c[b+3144>>2]=j;c[b+4168>>2]=j;c[b+4180>>2]=226;c[b+4172>>2]=1398;c[b+4176>>2]=2864;return}function ePm(b){b=b|0;var c=0;switch(b|0){case 12853251:{c=a[14130177]|0;break};case 12849159:{c=~a[14130138];break};case 12853249:{c=a[14130176]|0;break};case 12849153:{c=~a[14130136];break};case 12849155:{c=~a[14130137];break};case 12849157:{c=a[14130178]|0;break};default:{c=-1}}return c|0}function ePn(d,e){d=d|0;e=e|0;var f=0,g=0,h=0;f=d-4194304|0;if(f>>>0<65536){eOY(f^1,e);return}if((d|0)==12845057){f=e&255;c[3532340]=f&32;c[3532422]=f&64;return}else if((d|0)==16646151){c[3532412]=e&255;e=c[2439330]|0;d=(e|0)==0;if(!d){f=e;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;h=c[2417276]|0;c[3541536]=h;c[1836236]=0;a[9706117]=1;if(!d){d=e;gGC(d|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=h;c[1836236]=-1;return}else{return}}function ePo(a,b){a=a|0;b=b|0;var c=0;c=a-4194304|0;if(c>>>0>=65536){return}eOX(c,b);return}function ePp(d,e){d=d|0;e=e|0;var f=0,g=0,h=0;if((d|0)!=12582919){return}c[3532412]=e&255;e=c[2439330]|0;d=(e|0)==0;if(!d){f=e;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;h=c[2417276]|0;c[3541536]=h;c[1836236]=0;a[9706117]=1;if(!d){d=e;gGC(d|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=h;c[1836236]=-1;return}function ePq(a,b){a=a|0;b=b|0;if((a|0)!=12853255){return}c[3532412]=b&255;return}function ePr(b,d){b=b|0;d=d|0;switch(b|0){case 4292616:{c[3532418]=1025-(d&1023);return};case 4292640:{a[14168819]=d&15;a[14168811]=(d&65535)>>>4&15;return};case 4292632:{c[3532419]=1027-(d&1023);return};case 4292608:{c[3532414]=(d&65535)+1;return};case 4292642:{a[14168818]=d&15;a[14168810]=(d&65535)>>>4&15;return};case 4292624:{c[3532415]=(d&65535)+1;return};case 4292644:{a[14168817]=d&15;a[14168809]=(d&65535)>>>4&15;return};case 4292646:{a[14168816]=d&15;a[14168808]=(d&65535)>>>4&15;return};default:{return}}}function ePs(b){b=b|0;var c=0;if((b|0)==12849157){c=a[14130176]|0}else if((b|0)==12849153){c=~a[14130136]}else if((b|0)==12849159){c=a[14130177]|0}else if((b|0)==12849155){c=~a[14130137]}else{c=-1}return c|0}function ePt(b,e){b=b|0;e=e|0;var f=0;f=b-4194304|0;if(f>>>0<65536){eOY(f^1,e);return}if((b|0)==4128771){f=e&7;if((c[3532359]|0)==(f|0)){return}c[3532359]=f;a[7461568]=1;a[7461576]=1;a[7461552]=1;a[7461560]=1;return}else if((b|0)==524288){a[(c[3540990]|0)+5972|0]=e;return}else if((b|0)==4128769){f=e&7;if((c[3532358]|0)==(f|0)){return}c[3532358]=f;a[7461568]=1;a[7461576]=1;a[7461552]=1;a[7461560]=1;return}else if((b|0)==524290){b=c[3540990]|0;f=c[b+1868>>2]|0;if((f|0)!=0){gg[f&4095](c[b+1872>>2]|0,0)}ms(b,d[b+5972|0]|0,e&255);return}else{return}}function ePu(b,d){b=b|0;d=d|0;var e=0;if((b|0)==16515075){e=d&7;if((c[3532359]|0)==(e|0)){return}c[3532359]=e;a[7461568]=1;a[7461576]=1;a[7461552]=1;a[7461560]=1;return}else if((b|0)==16515073){b=d&7;if((c[3532358]|0)==(b|0)){return}c[3532358]=b;a[7461568]=1;a[7461576]=1;a[7461552]=1;a[7461560]=1;return}else{return}}function ePv(b){b=b|0;var c=0;switch(b|0){case 9441283:{c=~a[14130137];break};case 9441287:{c=~a[14130138];break};case 9441281:{c=~a[14130136];break};case 9445377:{c=a[14130176]|0;break};case 9445379:{c=a[14130177]|0;break};default:{c=-1}}return c|0}function ePw(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=d-7340032|0;if(f>>>0<65536){eOY(f^1,e);return}if((d|0)==16711687){c[3532412]=e&255;f=c[2439330]|0;g=(f|0)==0;if(!g){h=f;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;h=c[2438118]|0;c[2433530]=h;i=c[3528484]|0;c[2076596]=i;j=c[2417276]|0;c[3541536]=j;c[1836236]=0;a[9706117]=1;if(!g){g=f;gGC(g|0,9706056,76)|0}c[2438118]=h;c[3528484]=i;c[2417276]=j;c[1836236]=-1;return}else if((d|0)==9437185){d=e&255;c[3532340]=d&32;c[3532422]=d&64;return}else{return}}function ePx(a,b){a=a|0;b=b|0;var c=0;c=a-7340032|0;if(c>>>0>=65536){return}eOX(c,b);return}function ePy(b){b=b|0;var c=0;switch(b|0){case 12853251:{c=a[14130177]|0;break};case 12849157:{c=~a[14130139];break};case 12853249:{c=a[14130176]|0;break};case 12849153:{c=~a[14130136];break};case 12849155:{c=~a[14130137];break};case 12849159:{c=~a[14130138];break};default:{c=-1}}return c|0}function ePz(d,e){d=d|0;e=e|0;var f=0,g=0,h=0;if((d|0)!=12582919){return}c[3532412]=e&255;e=c[2439330]|0;d=(e|0)==0;if(!d){f=e;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;h=c[2417276]|0;c[3541536]=h;c[1836236]=0;a[9706117]=1;if(!d){d=e;gGC(d|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=h;c[1836236]=-1;return}function ePA(b){b=b|0;var d=0;if((b|0)==6299651){d=a[14130177]|0}else if((b|0)==6295553){d=~a[14130136]}else if((b|0)==6299649){d=a[14130176]|0}else if((b|0)==7354615){d=a[(c[3532446]|0)+(c[2276056]|0)|0]|0}else if((b|0)==6295559){d=~a[14130138]}else if((b|0)==6295555){d=~a[14130137]}else{d=-1}return d|0}function ePB(d,e){d=d|0;e=e|0;var f=0,g=0,h=0;f=d-4194304|0;if(f>>>0<65536){eOY(f^1,e);return}if((d|0)==6291457){f=e&255;c[3532340]=f&32;c[3532422]=f&64;return}else if((d|0)==1048577){f=e&7;if((c[3532358]|0)==(f|0)){return}c[3532358]=f;a[7461568]=1;a[7461576]=1;a[7461552]=1;a[7461560]=1;return}else if((d|0)==1048579){f=e&7;if((c[3532359]|0)==(f|0)){return}c[3532359]=f;a[7461568]=1;a[7461576]=1;a[7461552]=1;a[7461560]=1;return}else if((d|0)==16711687){c[3532412]=e&255;e=c[2439330]|0;d=(e|0)==0;if(!d){f=e;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;h=c[2417276]|0;c[3541536]=h;c[1836236]=0;a[9706117]=1;if(!d){d=e;gGC(d|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=h;c[1836236]=-1;return}else{return}}function ePC(a,b){a=a|0;b=b|0;var c=0;c=a-4194304|0;if(c>>>0>=65536){return}eOX(c,b);return}function ePD(b,d){b=b|0;d=d|0;var e=0;if((b|0)==4128771){e=d&7;if((c[3532359]|0)==(e|0)){return}c[3532359]=e;a[7461568]=1;a[7461576]=1;a[7461552]=1;a[7461560]=1;return}else if((b|0)==4128769){b=d&7;if((c[3532358]|0)==(b|0)){return}c[3532358]=b;a[7461568]=1;a[7461576]=1;a[7461552]=1;a[7461560]=1;return}else{return}}function ePE(b,c){b=b|0;c=c|0;if((b|0)==12869669){a[14168811]=c&15;a[14168819]=(c&255)>>>4;return}else if((b|0)==12869671){a[14168810]=c&15;a[14168818]=(c&255)>>>4;return}else if((b|0)==12869667){a[14168808]=c&15;a[14168816]=(c&255)>>>4;return}else if((b|0)==12869665){a[14168809]=c&15;a[14168817]=(c&255)>>>4;return}else{return}}function ePF(a,b){a=a|0;b=b|0;if((a|0)==12869632){c[3532415]=b&65535;return}else if((a|0)==12869648){c[3532414]=b&65535;return}else if((a|0)==12869640){c[3532419]=b&511^511;return}else if((a|0)==12869656){c[3532418]=b&511^511;return}else{return}}function ePG(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;if((d|0)==12845063){c[3532412]=e&255;f=c[2439330]|0;g=(f|0)==0;if(!g){h=f;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;h=c[2438118]|0;c[2433530]=h;i=c[3528484]|0;c[2076596]=i;j=c[2417276]|0;c[3541536]=j;c[1836236]=0;a[9706117]=1;if(!g){g=f;gGC(g|0,9706056,76)|0}c[2438118]=h;c[3528484]=i;c[2417276]=j;c[1836236]=-1;return}else if((d|0)==12845057){d=e&255;c[3532340]=d&32;c[3532422]=d&64;return}else{return}}function ePH(){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;c=b[4875488]|0;if((a[14130112]|0)==0){d=c}else{e=c+64&65535;b[4875488]=e;d=e}if((a[14130113]|0)==0){f=d}else{e=d-64&65535;b[4875488]=e;f=e}do{if(f<<16>>16>4095){b[4875488]=0}else{if(f<<16>>16>=0){break}b[4875488]=4032}}while(0);f=b[4875484]|0;if((a[14130114]|0)==0){g=f}else{e=f-64&65535;b[4875484]=e;g=e}if((a[14130115]|0)==0){h=g}else{e=g+64&65535;b[4875484]=e;h=e}do{if(h<<16>>16>4095){b[4875484]=0}else{if(h<<16>>16>=0){break}b[4875484]=4032}}while(0);h=b[4875480]|0;if((a[14130116]|0)==0){i=h}else{e=h+64&65535;b[4875480]=e;i=e}if((a[14130117]|0)==0){j=i}else{e=i-64&65535;b[4875480]=e;j=e}do{if(j<<16>>16>4095){b[4875480]=0}else{if(j<<16>>16>=0){break}b[4875480]=4032}}while(0);j=b[4875476]|0;if((a[14130118]|0)==0){k=j}else{e=j-64&65535;b[4875476]=e;k=e}if((a[14130119]|0)==0){l=k}else{e=k+64&65535;b[4875476]=e;l=e}do{if(l<<16>>16>4095){b[4875476]=0}else{if(l<<16>>16>=0){break}b[4875476]=4032}}while(0);l=b[4875472]|0;if((a[14130104]|0)==0){m=l}else{e=l+64&65535;b[4875472]=e;m=e}if((a[14130105]|0)==0){n=m}else{e=m-64&65535;b[4875472]=e;n=e}do{if(n<<16>>16>4095){b[4875472]=0}else{if(n<<16>>16>=0){break}b[4875472]=4032}}while(0);n=b[4875468]|0;if((a[14130106]|0)==0){o=n}else{e=n-64&65535;b[4875468]=e;o=e}if((a[14130107]|0)==0){p=o}else{e=o+64&65535;b[4875468]=e;p=e}do{if(p<<16>>16>4095){b[4875468]=0}else{if(p<<16>>16>=0){break}b[4875468]=4032}}while(0);p=b[4875464]|0;if((a[14130108]|0)==0){q=p}else{e=p+64&65535;b[4875464]=e;q=e}if((a[14130109]|0)==0){r=q}else{e=q-64&65535;b[4875464]=e;r=e}do{if(r<<16>>16>4095){b[4875464]=0}else{if(r<<16>>16>=0){break}b[4875464]=4032}}while(0);r=b[4875460]|0;if((a[14130110]|0)==0){s=r}else{e=r-64&65535;b[4875460]=e;s=e}if((a[14130111]|0)==0){t=s}else{e=s+64&65535;b[4875460]=e;t=e}if(t<<16>>16>4095){b[4875460]=0;return}if(t<<16>>16>=0){return}b[4875460]=4032;return}function ePI(a){a=a|0;var c=0;switch(a|0){case 12857353:{c=b[4875480]&255;break};case 12857369:{c=b[4875464]&255;break};case 12857367:{c=(e[4875468]|0)>>>8&255;break};case 12857361:{c=b[4875472]&255;break};case 12857345:{c=b[4875488]&255;break};case 12857371:{c=(e[4875464]|0)>>>8&255;break};case 12857359:{c=(e[4875476]|0)>>>8&255;break};case 12857363:{c=(e[4875472]|0)>>>8&255;break};case 12857373:{c=b[4875460]&255;break};case 12857375:{c=(e[4875460]|0)>>>8&255;break};case 12857357:{c=b[4875476]&255;break};case 12857351:{c=(e[4875484]|0)>>>8&255;break};case 12857365:{c=b[4875468]&255;break};case 12857355:{c=(e[4875480]|0)>>>8&255;break};case 12857349:{c=b[4875484]&255;break};case 12857347:{c=(e[4875488]|0)>>>8&255;break};default:{c=-1}}return c|0}function ePJ(a){a=a|0;var c=0,d=0;c=a>>>1&3;if((c|0)==0){d=b[4789564]|0}else if((c|0)==1){d=b[4789565]|0}else if((c|0)==3){d=ag(b[4789565]|0,b[4789564]|0)|0}else if((c|0)==2){d=(ag(b[4789565]|0,b[4789564]|0)|0)>>>16&65535}else{d=-1}return d|0}function ePK(a,c){a=a|0;c=c|0;var d=0;d=a>>>1&3;if((d|0)==1){b[4789565]=c}else if((d|0)==0){b[4789564]=c}else if((d|0)==2){b[4789564]=c}else if((d|0)==3){b[4789565]=c}return}function ePL(a){a=a|0;var c=0;switch(a>>>1&15|0){case 0:{c=b[4878604]|0;break};case 3:{c=b[4878607]|0;break};case 1:{c=b[4878605]|0;break};case 5:{c=b[4878605]|0;break};case 2:{c=b[4878606]|0;break};case 7:{c=b[4878611]|0;break};case 6:{c=b[4878606]|0;break};case 4:{c=b[4878608]|0;break};default:{c=-1}}return c|0}function ePM(a,b){a=a|0;b=b|0;eOw(0,(a-4067328|0)>>>1,b);return}function ePN(d,e){d=d|0;e=e|0;var f=0,g=0,h=0;if((d|0)!=1192967){return}c[3532412]=e&255;e=c[2439330]|0;d=(e|0)==0;if(!d){f=e;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;h=c[2417276]|0;c[3541536]=h;c[1836236]=0;a[9706117]=1;if(!d){d=e;gGC(d|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=h;c[1836236]=-1;return}function ePO(b,d){b=b|0;d=d|0;var e=0;if((b|0)==4071425){e=d&7;if((c[3532358]|0)==(e|0)){return}c[3532358]=e;a[7461568]=1;a[7461576]=1;a[7461552]=1;a[7461560]=1;return}else if((b|0)==4071427){b=d&7;if((c[3532359]|0)==(b|0)){return}c[3532359]=b;a[7461568]=1;a[7461576]=1;a[7461552]=1;a[7461560]=1;return}else{return}}function ePP(d,e){d=d|0;e=e|0;var f=0,g=0,h=0;if((d|0)!=12853255){return}c[3532412]=e&255;e=c[2439330]|0;d=(e|0)==0;if(!d){f=e;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;h=c[2417276]|0;c[3541536]=h;c[1836236]=0;a[9706117]=1;if(!d){d=e;gGC(d|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=h;c[1836236]=-1;return}function ePQ(a,b){a=a|0;b=b|0;if((a|0)!=4292657){return}c[3532359]=b&7;return}function ePR(b,d){b=b|0;d=d|0;switch(b|0){case 4292640:{a[14168811]=(d&65535)>>>12&255;a[14168810]=(d&65535)>>>8&15;a[14168809]=(d&65535)>>>4&15;a[14168808]=d&15;return};case 4292648:{a[14168819]=(d&65535)>>>12&255;a[14168818]=(d&65535)>>>8&15;a[14168817]=(d&65535)>>>4&15;a[14168816]=d&15;return};case 4292616:{c[3532418]=d&65535^65535;return};case 4292608:{c[3532414]=d&65535;return};case 4292624:{c[3532415]=d&65535;return};case 4292632:{c[3532419]=d&65535^65535;return};default:{return}}}function ePS(){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=b[4875456]|0;if((a[14130096]|0)==0){d=c}else{e=c+1&65535;b[4875456]=e;d=e}if((a[14130097]|0)==0){f=d}else{e=d-1&65535;b[4875456]=e;f=e}do{if(f<<16>>16>255){b[4875456]=0}else{if(f<<16>>16>=0){break}b[4875456]=255}}while(0);f=b[4875452]|0;if((a[14130098]|0)==0){g=f}else{e=f-1&65535;b[4875452]=e;g=e}if((a[14130099]|0)==0){h=g}else{e=g+1&65535;b[4875452]=e;h=e}do{if(h<<16>>16>255){b[4875452]=0}else{if(h<<16>>16>=0){break}b[4875452]=255}}while(0);h=b[4875448]|0;if((a[14130100]|0)==0){i=h}else{e=h+4&65535;b[4875448]=e;i=e}if((a[14130101]|0)==0){j=i}else{e=i-4&65535;b[4875448]=e;j=e}do{if(j<<16>>16>255){b[4875448]=0}else{if(j<<16>>16>=0){break}b[4875448]=252}}while(0);j=b[4875444]|0;if((a[14130102]|0)==0){k=j}else{e=j-4&65535;b[4875444]=e;k=e}if((a[14130103]|0)==0){l=k}else{e=k+4&65535;b[4875444]=e;l=e}if(l<<16>>16>255){b[4875444]=0;return}if(l<<16>>16>=0){return}b[4875444]=252;return}function ePT(c){c=c|0;var d=0;switch(c|0){case 12857345:case 12857347:{d=b[4875456]&255;break};case 12857357:case 12857359:{d=b[4875444]&255;break};case 12849159:{d=~a[14130138];break};case 12849153:{d=~a[14130136];break};case 12853249:{d=a[14130176]|0;break};case 12849155:{d=~a[14130137];break};case 12849157:{d=~a[14130139];break};case 12857353:case 12857355:{d=b[4875448]&255;break};case 12853251:{d=a[14130177]|0;break};case 12857349:case 12857351:{d=b[4875452]&255;break};default:{d=-1}}return d|0}function ePU(b,d){b=b|0;d=d|0;var e=0;if((b|0)==4128769){e=d&7;if((c[3532358]|0)==(e|0)){return}c[3532358]=e;a[7461568]=1;a[7461576]=1;a[7461552]=1;a[7461560]=1;return}else if((b|0)==4128771){b=d&7;if((c[3532359]|0)==(b|0)){return}c[3532359]=b;a[7461568]=1;a[7461576]=1;a[7461552]=1;a[7461560]=1;return}else{return}}function ePV(b){b=b|0;var c=0;switch(b|0){case 6295553:{c=~a[14130136];break};case 6291457:{c=a[14130176]|0;break};case 6295557:{c=~a[14130138];break};case 6295555:{c=~a[14130137];break};case 6291459:{c=a[14130177]|0;break};default:{c=-1}}return c|0}function ePW(d,e){d=d|0;e=e|0;var f=0,g=0,h=0;if((d|0)==8663041){f=e&255;c[3532340]=f&32;c[3532422]=f&64;return}else if((d|0)==6291463){c[3532412]=e&255;e=c[2439330]|0;d=(e|0)==0;if(!d){f=e;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;h=c[2417276]|0;c[3541536]=h;c[1836236]=0;a[9706117]=1;if(!d){d=e;gGC(d|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=h;c[1836236]=-1;return}else{return}}function ePX(b,d){b=b|0;d=d|0;switch(b|0){case 12869632:{c[3532414]=d&65535;return};case 12869670:{a[14168816]=(d&65535)>>>12&255;a[14168817]=(d&65535)>>>8&15;a[14168818]=(d&65535)>>>4&15;a[14168819]=d&15;return};case 12869640:{c[3532418]=d&65535^65535;return};case 12869648:{c[3532415]=(d&65535)+2;return};case 12869666:{a[14168811]=(d&65535)>>>12&255;a[14168810]=(d&65535)>>>8&15;a[14168809]=(d&65535)>>>4&15;a[14168808]=d&15;return};case 12869656:{c[3532419]=d&65535^65535;return};default:{return}}}function ePY(a,b){a=a|0;b=b|0;eOY(a-1048576^1,b);return}function ePZ(a,b){a=a|0;b=b|0;eOX(a-1048576|0,b);return}function eP_(a){a=a|0;var c=0,d=0;c=a>>>1&3;if((c|0)==0){d=b[4789564]|0}else if((c|0)==3){d=ag(b[4789565]|0,b[4789564]|0)|0}else if((c|0)==1){d=b[4789565]|0}else if((c|0)==2){d=(ag(b[4789565]|0,b[4789564]|0)|0)>>>16&65535}else{d=-1}return d|0}function eP$(a,c){a=a|0;c=c|0;var d=0;d=a>>>1&3;if((d|0)==0){b[4789564]=c}else if((d|0)==3){b[4789565]=c}else if((d|0)==1){b[4789565]=c}else if((d|0)==2){b[4789564]=c}return}function eP0(a){a=a|0;var c=0;switch(a>>>1&15|0){case 7:{c=b[4878611]|0;break};case 4:{c=b[4878608]|0;break};case 2:{c=b[4878606]|0;break};case 3:{c=b[4878607]|0;break};case 6:{c=b[4878606]|0;break};case 0:{c=b[4878604]|0;break};case 5:{c=b[4878605]|0;break};case 1:{c=b[4878605]|0;break};default:{c=-1}}return c|0}function eP1(a,b){a=a|0;b=b|0;eOw(0,(a-2035712|0)>>>1,b);return}function eP2(a){a=a|0;var c=0;switch(a>>>1&15|0){case 0:{c=b[4878622]|0;break};case 3:{c=b[4878625]|0;break};case 5:{c=b[4878623]|0;break};case 4:{c=b[4878626]|0;break};case 1:{c=b[4878623]|0;break};case 7:{c=b[4878629]|0;break};case 2:{c=b[4878624]|0;break};case 6:{c=b[4878624]|0;break};default:{c=-1}}return c|0}function eP3(a,b){a=a|0;b=b|0;eOw(1,(a-1966080|0)>>>1,b);return}function eP4(b,d){b=b|0;d=d|0;var e=0;if((b|0)==2039811){e=d&7;if((c[3532359]|0)==(e|0)){return}c[3532359]=e;a[7461568]=1;a[7461576]=1;a[7461552]=1;a[7461560]=1;return}else if((b|0)==2039809){b=d&7;if((c[3532358]|0)==(b|0)){return}c[3532358]=b;a[7461568]=1;a[7461576]=1;a[7461552]=1;a[7461560]=1;return}else{return}}function eP5(b,d){b=b|0;d=d|0;var e=0;if((b|0)==2031619){e=d&7;if((c[3532359]|0)==(e|0)){return}c[3532359]=e;a[7461568]=1;a[7461576]=1;a[7461552]=1;a[7461560]=1;return}else if((b|0)==2031617){b=d&7;if((c[3532358]|0)==(b|0)){return}c[3532358]=b;a[7461568]=1;a[7461576]=1;a[7461552]=1;a[7461560]=1;return}else{return}}function eP6(b){b=b|0;var c=0;if(!((b|0)==12857376|(b|0)==12857378|(b|0)==12857380)){c=-1;return c|0}b=a[9750856]|0;a[9750856]=b<<1;c=(b&255)>>>7&255;return c|0}function eP7(b,d){b=b|0;d=d|0;var e=0;if((b|0)==12857376){d=((c[3532572]|0)>>>4)+128|0;e=(d&255|0)==0?1:d&255;a[9750856]=e<<24>>24==-1?-2:e;return}else if((b|0)==12857378){a[9750856]=(c[3532568]|0)>1?-2:38;return}else if((b|0)==12857380){a[9750856]=(c[3532570]|0)>1?-2:38;return}else{return}}function eP8(b,d){b=b|0;d=d|0;var e=0;if((b|0)==4128771){e=d&7;if((c[3532359]|0)==(e|0)){return}c[3532359]=e;a[7461568]=1;a[7461576]=1;a[7461552]=1;a[7461560]=1;return}else if((b|0)==4128769){b=d&7;if((c[3532358]|0)==(b|0)){return}c[3532358]=b;a[7461568]=1;a[7461576]=1;a[7461552]=1;a[7461560]=1;return}else{return}}function eP9(b,d){b=b|0;d=d|0;var e=0;if((b|0)==4136963){e=d&7;if((c[3532359]|0)==(e|0)){return}c[3532359]=e;a[7461568]=1;a[7461576]=1;a[7461552]=1;a[7461560]=1;return}else if((b|0)==4136961){b=d&7;if((c[3532358]|0)==(b|0)){return}c[3532358]=b;a[7461568]=1;a[7461576]=1;a[7461552]=1;a[7461560]=1;return}else{return}}function eQa(b,d){b=b|0;d=d|0;var e=0;if((b|0)==4128771){e=d&7;if((c[3532359]|0)==(e|0)){return}c[3532359]=e;a[7461568]=1;a[7461576]=1;a[7461552]=1;a[7461560]=1;return}else if((b|0)==4128769){b=d&7;if((c[3532358]|0)==(b|0)){return}c[3532358]=b;a[7461568]=1;a[7461576]=1;a[7461552]=1;a[7461560]=1;return}else{return}}function eQb(d,e){d=d|0;e=e|0;var f=0,g=0,h=0;if((d|0)!=12582919){return}c[3532412]=e&255;e=c[2439330]|0;d=(e|0)==0;if(!d){f=e;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;h=c[2417276]|0;c[3541536]=h;c[1836236]=0;a[9706117]=1;if(!d){d=e;gGC(d|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=h;c[1836236]=-1;return}function eQc(b){b=b|0;var c=0;if((b|0)==12857351){c=~a[14130140]}else if((b|0)==12857349){c=~a[14130139]}else if((b|0)==12857347){c=~a[14130138]}else if((b|0)==12857345){c=~a[14130137]}else{c=-1}return c|0}function eQd(b){b=b|0;var c=0;switch(b|0){case 16261123:{c=a[14130177]|0;break};case 16257025:{c=~a[14130136];break};case 16257027:{c=~a[14130137];break};case 16257031:{c=~a[14130138];break};case 16261121:{c=a[14130176]|0;break};default:{c=-1}}return c|0}function eQe(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=d-16384e3|0;if(f>>>0<65536){eOY(f^1,e);return}if((d|0)==15728647){c[3532412]=e&255;f=c[2439330]|0;g=(f|0)==0;if(!g){h=f;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;h=c[2438118]|0;c[2433530]=h;i=c[3528484]|0;c[2076596]=i;j=c[2417276]|0;c[3541536]=j;c[1836236]=0;a[9706117]=1;if(!g){g=f;gGC(g|0,9706056,76)|0}c[2438118]=h;c[3528484]=i;c[2417276]=j;c[1836236]=-1;return}else if((d|0)==15859713){j=e&7;if((c[3532358]|0)==(j|0)){return}c[3532358]=j;a[7461568]=1;a[7461576]=1;a[7461552]=1;a[7461560]=1;return}else if((d|0)==15859715){j=e&7;if((c[3532359]|0)==(j|0)){return}c[3532359]=j;a[7461568]=1;a[7461576]=1;a[7461552]=1;a[7461560]=1;return}else if((d|0)==16252929){d=e&255;c[3532340]=d&32;c[3532422]=d&64;return}else{return}}function eQf(a,b){a=a|0;b=b|0;var c=0;c=a-16384e3|0;if(c>>>0>=65536){return}eOX(c,b);return}function eQg(a){a=a|0;var b=0;if((a|0)==6295552){b=(d[14130136]|0)^255}else if((a|0)==6299648){b=d[14130176]|0}else if((a|0)==6295554){b=(d[14130137]|0)^255}else if((a|0)==6299650){b=d[14130177]|0}else{b=-1}return b|0}function eQh(b,d){b=b|0;d=d|0;var e=0;e=b-4194304|0;if(e>>>0<65536){eOX(e,d);return}if((b|0)==1048578){e=d&7;if((c[3532359]|0)==(e|0)){return}c[3532359]=e;a[7461568]=1;a[7461576]=1;a[7461552]=1;a[7461560]=1;return}else if((b|0)==1048576){e=d&7;if((c[3532358]|0)==(e|0)){return}c[3532358]=e;a[7461568]=1;a[7461576]=1;a[7461552]=1;a[7461560]=1;return}else if((b|0)==6291456){b=d&65535;c[3532340]=b&32;c[3532422]=b&64;return}else{return}}function eQi(d,e){d=d|0;e=e|0;var f=0,g=0,h=0;if((d|0)!=16711687){return}c[3532412]=e&255;e=c[2439330]|0;d=(e|0)==0;if(!d){f=e;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;h=c[2417276]|0;c[3541536]=h;c[1836236]=0;a[9706117]=1;if(!d){d=e;gGC(d|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=h;c[1836236]=-1;return}function eQj(){b[7057912]=(e[7057912]|0)-((c[3532572]|0)>>>8&255)&65535;b[7057904]=(e[7057904]|0)+((c[3532570]|0)>>>8&255)&65535;b[7057896]=(e[7057896]|0)-((c[3532568]|0)>>>8&255)&65535;b[7057888]=(e[7057888]|0)+((c[3532566]|0)>>>8&255)&65535;return}function eQk(c){c=c|0;var d=0;if((c|0)==12853253){d=a[14130176]|0}else if((c|0)==12853251){d=a[14130177]|0}else if((c|0)==12849153){d=~a[14130136]}else if((c|0)==12849157){d=~a[14130137]}else if((c|0)==12857353){d=b[7057896]&255}else if((c|0)==12857345){d=b[7057912]&255}else if((c|0)==12857349){d=b[7057904]&255}else if((c|0)==12857357){d=b[7057888]&255}else{d=-1}return d|0}function eQl(d,e){d=d|0;e=e|0;var f=0,g=0,h=0;if((d|0)!=1192967){return}c[3532412]=e&255;e=c[2439330]|0;d=(e|0)==0;if(!d){f=e;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;h=c[2417276]|0;c[3541536]=h;c[1836236]=0;a[9706117]=1;if(!d){d=e;gGC(d|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=h;c[1836236]=-1;return}function eQm(a){a=a|0;var b=0;b=((gj[c[(c[2112932]|0)+196608>>2]&4095](a)|0)&255)<<8;return(gj[c[(c[2112932]|0)+196608>>2]&4095](a+1|0)|0)&255|b|0}function eQn(b){b=b|0;var c=0,e=0;L35658:do{switch(b|0){case 12849155:{c=d[9750552]|0;if((a[c+14130137|0]|0)==-1){e=-1;break L35658}e=(1<<c^255)&255;break};case 12849153:{e=~a[14130136];break};case 12853249:{e=a[14130176]|0;break};case 12849157:{e=~a[(d[9750552]|0)+14130137|0];break};case 12853251:{e=a[14130177]|0;break};default:{e=-1}}}while(0);return e|0}function eQo(e,f){e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;if((e|0)==12582919){c[3532412]=f&255;g=c[2439330]|0;h=(g|0)==0;if(!h){i=g;gGC(9706056,i|0,76)|0}b[4853030]=c[2426515]&65535;i=c[2438118]|0;c[2433530]=i;j=c[3528484]|0;c[2076596]=j;k=c[2417276]|0;c[3541536]=k;c[1836236]=0;a[9706117]=1;if(!h){h=g;gGC(h|0,9706056,76)|0}c[2438118]=i;c[3528484]=j;c[2417276]=k;c[1836236]=-1;return}else if((e|0)==12845059){e=f&255;c[3532340]=e&32;c[3532422]=e&64;if((e&4|0)==0){return}a[9750552]=((((d[9750552]|0)+1|0)>>>0)%6|0)&255;return}else{return}}function eQp(a){a=a|0;var b=0;if((a|0)==12853250){b=d[14130177]|0|-256}else if((a|0)==12853248){b=d[14130176]|0|-256}else{b=-1}return b|0}function eQq(d,e){d=d|0;e=e|0;var f=0,g=0,h=0;if((d|0)!=1192967){return}c[3532412]=e&255;e=c[2439330]|0;d=(e|0)==0;if(!d){f=e;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;h=c[2417276]|0;c[3541536]=h;c[1836236]=0;a[9706117]=1;if(!d){d=e;gGC(d|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=h;c[1836236]=-1;return}function eQr(b,d){b=b|0;d=d|0;switch(b|0){case 4292624:{c[3532415]=d&65535;return};case 4292608:{c[3532414]=d&65535;return};case 4292616:{c[3532418]=d&1023^1023;return};case 4292640:{a[14168811]=(d&65535)>>>12&255;a[14168810]=(d&65535)>>>8&15;a[14168809]=(d&65535)>>>4&15;a[14168808]=d&15;return};case 4292632:{c[3532419]=1025-(d&1023);return};case 4292648:{a[14168816]=(d&65535)>>>12&255;a[14168817]=(d&65535)>>>8&15;a[14168818]=(d&65535)>>>4&15;a[14168819]=d&15;return};default:{return}}}function eQs(d,e){d=d|0;e=e|0;var f=0,g=0,h=0;if((d|0)!=12853255){return}c[3532412]=e&255;e=c[2439330]|0;d=(e|0)==0;if(!d){f=e;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;h=c[2417276]|0;c[3541536]=h;c[1836236]=0;a[9706117]=1;if(!d){d=e;gGC(d|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=h;c[1836236]=-1;return}function eQt(b){b=b|0;var c=0;switch(b|0){case 14946311:{c=~a[14130138];break};case 14946305:{c=~a[14130136];break};case 14950401:{c=a[14130176]|0;break};case 14946307:{c=~a[14130137];break};case 14950403:{c=a[14130177]|0;break};case 14946309:{c=0;break};default:{c=-1}}return c|0}function eQu(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;if((d|0)==16646151){c[3532412]=e&255;f=c[2439330]|0;g=(f|0)==0;if(!g){h=f;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;h=c[2438118]|0;c[2433530]=h;i=c[3528484]|0;c[2076596]=i;j=c[2417276]|0;c[3541536]=j;c[1836236]=0;a[9706117]=1;if(!g){g=f;gGC(g|0,9706056,76)|0}c[2438118]=h;c[3528484]=i;c[2417276]=j;c[1836236]=-1;return}else if((d|0)==4071427){j=e&7;if((c[3532359]|0)==(j|0)){return}c[3532359]=j;a[7461568]=1;a[7461576]=1;a[7461552]=1;a[7461560]=1;return}else if((d|0)==14942209){j=e&255;c[3532340]=j&32;c[3532422]=j&64;return}else if((d|0)==4071425){d=e&7;if((c[3532358]|0)==(d|0)){return}c[3532358]=d;a[7461568]=1;a[7461576]=1;a[7461552]=1;a[7461560]=1;return}else{return}}function eQv(b){b=b|0;var c=0;if((b|0)==6299649){c=a[14130176]|0}else if((b|0)==6299651){c=a[14130177]|0}else{c=-1}return c|0}function eQw(a,b){a=a|0;b=b|0;var d=0;d=a-4194304|0;if(d>>>0<65536){eOY(d^1,b);return}if((a|0)!=6291457){return}a=b&255;c[3532340]=a&32;c[3532422]=a&64;return}function eQx(d,e){d=d|0;e=e|0;var f=0,g=0,h=0;if((d|0)!=14614535){return}c[3532412]=e&255;e=c[2439330]|0;d=(e|0)==0;if(!d){f=e;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;h=c[2417276]|0;c[3541536]=h;c[1836236]=0;a[9706117]=1;if(!d){d=e;gGC(d|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=h;c[1836236]=-1;return}function eQy(a,b){a=a|0;b=b|0;eOY(a-1048576^1,b);return}function eQz(a,b){a=a|0;b=b|0;eOX(a-1048576|0,b);return}function eQA(b,d){b=b|0;d=d|0;var e=0;if((b|0)==4194307){e=d&7;if((c[3532359]|0)==(e|0)){return}c[3532359]=e;a[7461568]=1;a[7461576]=1;a[7461552]=1;a[7461560]=1;return}else if((b|0)==4194305){b=d&7;if((c[3532358]|0)==(b|0)){return}c[3532358]=b;a[7461568]=1;a[7461576]=1;a[7461552]=1;a[7461560]=1;return}else{return}}function eQB(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=c[3532470]|0;b[e+12482>>1]=(d[14130136]|0)<<8;c[3532359]=a[e+12436|0]&7;f=e+12484|0;g=d[f]|0;h=((d[e+12485|0]|0)<<8|g)&65535;if((h&65280|0)==0){return}c[3532412]=h>>>8;h=c[2439330]|0;e=(h|0)==0;if(!e){i=h;gGC(9706056,i|0,76)|0}b[4853030]=c[2426515]&65535;i=c[2438118]|0;c[2433530]=i;j=c[3528484]|0;c[2076596]=j;k=c[2417276]|0;c[3541536]=k;c[1836236]=0;a[9706117]=1;if(!e){e=h;gGC(e|0,9706056,76)|0}c[2438118]=i;c[3528484]=j;c[2417276]=k;c[1836236]=-1;b[f>>1]=g;return}function eQC(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=c[3532470]|0;b[e+12496>>1]=(d[14130136]|0)<<8;c[3532359]=a[e+12436|0]&7;f=e+12500|0;g=d[f]|0;h=((d[e+12501|0]|0)<<8|g)&65535;if((h&65280|0)==0){return}c[3532412]=h>>>8;h=c[2439330]|0;e=(h|0)==0;if(!e){i=h;gGC(9706056,i|0,76)|0}b[4853030]=c[2426515]&65535;i=c[2438118]|0;c[2433530]=i;j=c[3528484]|0;c[2076596]=j;k=c[2417276]|0;c[3541536]=k;c[1836236]=0;a[9706117]=1;if(!e){e=h;gGC(e|0,9706056,76)|0}c[2438118]=i;c[3528484]=j;c[2417276]=k;c[1836236]=-1;b[f>>1]=g;return}function eQD(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=c[3532470]|0;b[e+12438>>1]=(d[14130136]|0)<<8;c[3532359]=a[e+12436|0]&7;f=e+12440|0;g=d[f]|0;h=((d[e+12441|0]|0)<<8|g)&65535;if((h&65280|0)==0){return}c[3532412]=h>>>8;h=c[2439330]|0;e=(h|0)==0;if(!e){i=h;gGC(9706056,i|0,76)|0}b[4853030]=c[2426515]&65535;i=c[2438118]|0;c[2433530]=i;j=c[3528484]|0;c[2076596]=j;k=c[2417276]|0;c[3541536]=k;c[1836236]=0;a[9706117]=1;if(!e){e=h;gGC(e|0,9706056,76)|0}c[2438118]=i;c[3528484]=j;c[2417276]=k;c[1836236]=-1;b[f>>1]=g;return}function eQE(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0;fxU(0,425984);if((c[2394]|0)==0){a=c[2112932]|0}else{c[2394]=0;b=c[3532596]|0;c[2112932]=b;d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];a=b}b=c[3532446]|0;d=a|0;e=d;f=0;while(1){c[e>>2]=b+f;g=f+1024|0;if(g>>>0>131071){break}else{e=e+4|0;f=g}}f=c[3532552]|0;e=d;d=0;while(1){c[e+131072>>2]=f+d;b=d+1024|0;if(b>>>0>131071){break}else{e=e+4|0;d=b}}d=c[3532356]|0;e=a+16384|0;f=4194304;while(1){c[e>>2]=d+(f-4194304);b=f+1024|0;if(b>>>0>4259839){break}else{e=e+4|0;f=b}}f=c[3532368]|0;c[a+16640>>2]=f;c[a+82176>>2]=f;c[a+147712>>2]=f;e=f+1024|0;c[a+16644>>2]=e;c[a+82180>>2]=e;c[a+147716>>2]=e;e=f+2048|0;c[a+16648>>2]=e;c[a+82184>>2]=e;c[a+147720>>2]=e;e=f+3072|0;c[a+16652>>2]=e;c[a+82188>>2]=e;c[a+147724>>2]=e;e=c[3532484]|0;c[a+33792>>2]=e;c[a+99328>>2]=e;c[a+164864>>2]=e;f=e+1024|0;c[a+33796>>2]=f;c[a+99332>>2]=f;c[a+164868>>2]=f;f=e+2048|0;c[a+33800>>2]=f;c[a+99336>>2]=f;c[a+164872>>2]=f;f=e+3072|0;c[a+33804>>2]=f;c[a+99340>>2]=f;c[a+164876>>2]=f;f=c[3532470]|0;c[a+65472>>2]=f;c[a+131008>>2]=f;c[a+196544>>2]=f;e=f+1024|0;c[a+65476>>2]=e;c[a+131012>>2]=e;c[a+196548>>2]=e;e=f+2048|0;c[a+65480>>2]=e;c[a+131016>>2]=e;c[a+196552>>2]=e;e=f+3072|0;c[a+65484>>2]=e;c[a+131020>>2]=e;c[a+196556>>2]=e;e=f+4096|0;c[a+65488>>2]=e;c[a+131024>>2]=e;c[a+196560>>2]=e;e=f+5120|0;c[a+65492>>2]=e;c[a+131028>>2]=e;c[a+196564>>2]=e;e=f+6144|0;c[a+65496>>2]=e;c[a+131032>>2]=e;c[a+196568>>2]=e;e=f+7168|0;c[a+65500>>2]=e;c[a+131036>>2]=e;c[a+196572>>2]=e;e=f+8192|0;c[a+65504>>2]=e;c[a+131040>>2]=e;c[a+196576>>2]=e;e=f+9216|0;c[a+65508>>2]=e;c[a+131044>>2]=e;c[a+196580>>2]=e;e=f+10240|0;c[a+65512>>2]=e;c[a+131048>>2]=e;c[a+196584>>2]=e;e=f+11264|0;c[a+65516>>2]=e;c[a+131052>>2]=e;c[a+196588>>2]=e;e=f+12288|0;c[a+65520>>2]=e;c[a+131056>>2]=e;c[a+196592>>2]=e;e=f+13312|0;c[a+65524>>2]=e;c[a+131060>>2]=e;c[a+196596>>2]=e;e=f+14336|0;c[a+65528>>2]=e;c[a+131064>>2]=e;c[a+196600>>2]=e;e=f+15360|0;c[a+65532>>2]=e;c[a+131068>>2]=e;c[a+196604>>2]=e;c[a+196728>>2]=316;c[a+196608>>2]=3158;c[a+196648>>2]=3128;a=c[3532592]|0;if((a|0)==0){h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return}gGC(a|0,9104152,280)|0;h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return}function eQF(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0;fxU(0,425984);if((c[2394]|0)==0){a=c[2112932]|0}else{c[2394]=0;b=c[3532596]|0;c[2112932]=b;d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];a=b}b=c[3532446]|0;d=a|0;e=d;f=0;while(1){c[e>>2]=b+f;g=f+1024|0;if(g>>>0>786431){break}else{e=e+4|0;f=g}}f=c[3532552]|0;e=d;d=0;while(1){c[e+131072>>2]=f+d;b=d+1024|0;if(b>>>0>786431){break}else{e=e+4|0;d=b}}d=c[3532470]|0;c[a+20480>>2]=d;c[a+86016>>2]=d;c[a+151552>>2]=d;e=d+1024|0;c[a+20484>>2]=e;c[a+86020>>2]=e;c[a+151556>>2]=e;e=d+2048|0;c[a+20488>>2]=e;c[a+86024>>2]=e;c[a+151560>>2]=e;e=d+3072|0;c[a+20492>>2]=e;c[a+86028>>2]=e;c[a+151564>>2]=e;e=d+4096|0;c[a+20496>>2]=e;c[a+86032>>2]=e;c[a+151568>>2]=e;e=d+5120|0;c[a+20500>>2]=e;c[a+86036>>2]=e;c[a+151572>>2]=e;e=d+6144|0;c[a+20504>>2]=e;c[a+86040>>2]=e;c[a+151576>>2]=e;e=d+7168|0;c[a+20508>>2]=e;c[a+86044>>2]=e;c[a+151580>>2]=e;e=d+8192|0;c[a+20512>>2]=e;c[a+86048>>2]=e;c[a+151584>>2]=e;e=d+9216|0;c[a+20516>>2]=e;c[a+86052>>2]=e;c[a+151588>>2]=e;e=d+10240|0;c[a+20520>>2]=e;c[a+86056>>2]=e;c[a+151592>>2]=e;e=d+11264|0;c[a+20524>>2]=e;c[a+86060>>2]=e;c[a+151596>>2]=e;e=d+12288|0;c[a+20528>>2]=e;c[a+86064>>2]=e;c[a+151600>>2]=e;e=d+13312|0;c[a+20532>>2]=e;c[a+86068>>2]=e;c[a+151604>>2]=e;e=d+14336|0;c[a+20536>>2]=e;c[a+86072>>2]=e;c[a+151608>>2]=e;e=d+15360|0;c[a+20540>>2]=e;c[a+86076>>2]=e;c[a+151612>>2]=e;e=c[3532390]|0;c[a+24576>>2]=e;c[a+90112>>2]=e;c[a+155648>>2]=e;d=e+1024|0;c[a+24580>>2]=d;c[a+90116>>2]=d;c[a+155652>>2]=d;d=c[3532356]|0;e=a+28672|0;f=7340032;while(1){c[e>>2]=d+(f-7340032);b=f+1024|0;if(b>>>0>7405567){break}else{e=e+4|0;f=b}}f=c[3532368]|0;c[a+28928>>2]=f;c[a+94464>>2]=f;c[a+16e4>>2]=f;e=f+1024|0;c[a+28932>>2]=e;c[a+94468>>2]=e;c[a+160004>>2]=e;e=f+2048|0;c[a+28936>>2]=e;c[a+94472>>2]=e;c[a+160008>>2]=e;e=f+3072|0;c[a+28940>>2]=e;c[a+94476>>2]=e;c[a+160012>>2]=e;e=c[3532484]|0;c[a+32768>>2]=e;c[a+98304>>2]=e;c[a+163840>>2]=e;f=e+1024|0;c[a+32772>>2]=f;c[a+98308>>2]=f;c[a+163844>>2]=f;f=e+2048|0;c[a+32776>>2]=f;c[a+98312>>2]=f;c[a+163848>>2]=f;f=e+3072|0;c[a+32780>>2]=f;c[a+98316>>2]=f;c[a+163852>>2]=f;c[a+196608>>2]=3420;c[a+196648>>2]=3232;c[a+196728>>2]=2358;a=c[3532592]|0;if((a|0)==0){h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return}gGC(a|0,9104152,280)|0;h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return}function eQG(){var a=0,b=0,d=0,e=0,f=0,g=0;fxU(0,425984);if((c[2394]|0)==0){a=c[2112932]|0}else{c[2394]=0;b=c[3532596]|0;c[2112932]=b;d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];a=b}b=c[3532446]|0;d=a|0;e=0;while(1){f=b+e|0;c[d>>2]=f;c[d+131072>>2]=f;f=e+1024|0;if(f>>>0>262143){break}else{d=d+4|0;e=f}}e=c[3532356]|0;d=a+16384|0;b=4194304;while(1){c[d>>2]=e+(b-4194304);f=b+1024|0;if(f>>>0>4259839){break}else{d=d+4|0;b=f}}b=c[3532368]|0;c[a+16640>>2]=b;c[a+82176>>2]=b;c[a+147712>>2]=b;d=b+1024|0;c[a+16644>>2]=d;c[a+82180>>2]=d;c[a+147716>>2]=d;d=b+2048|0;c[a+16648>>2]=d;c[a+82184>>2]=d;c[a+147720>>2]=d;d=b+3072|0;c[a+16652>>2]=d;c[a+82188>>2]=d;c[a+147724>>2]=d;d=c[3532390]|0;c[a+17408>>2]=d;c[a+82944>>2]=d;c[a+148480>>2]=d;b=d+1024|0;c[a+17412>>2]=b;c[a+82948>>2]=b;c[a+148484>>2]=b;b=c[3532484]|0;c[a+33792>>2]=b;c[a+99328>>2]=b;c[a+164864>>2]=b;d=b+1024|0;c[a+33796>>2]=d;c[a+99332>>2]=d;c[a+164868>>2]=d;d=b+2048|0;c[a+33800>>2]=d;c[a+99336>>2]=d;c[a+164872>>2]=d;d=b+3072|0;c[a+33804>>2]=d;c[a+99340>>2]=d;c[a+164876>>2]=d;d=c[3532470]|0;c[a+65472>>2]=d;c[a+131008>>2]=d;c[a+196544>>2]=d;b=d+1024|0;c[a+65476>>2]=b;c[a+131012>>2]=b;c[a+196548>>2]=b;b=d+2048|0;c[a+65480>>2]=b;c[a+131016>>2]=b;c[a+196552>>2]=b;b=d+3072|0;c[a+65484>>2]=b;c[a+131020>>2]=b;c[a+196556>>2]=b;b=d+4096|0;c[a+65488>>2]=b;c[a+131024>>2]=b;c[a+196560>>2]=b;b=d+5120|0;c[a+65492>>2]=b;c[a+131028>>2]=b;c[a+196564>>2]=b;b=d+6144|0;c[a+65496>>2]=b;c[a+131032>>2]=b;c[a+196568>>2]=b;b=d+7168|0;c[a+65500>>2]=b;c[a+131036>>2]=b;c[a+196572>>2]=b;b=d+8192|0;c[a+65504>>2]=b;c[a+131040>>2]=b;c[a+196576>>2]=b;b=d+9216|0;c[a+65508>>2]=b;c[a+131044>>2]=b;c[a+196580>>2]=b;b=d+10240|0;c[a+65512>>2]=b;c[a+131048>>2]=b;c[a+196584>>2]=b;b=d+11264|0;c[a+65516>>2]=b;c[a+131052>>2]=b;c[a+196588>>2]=b;b=d+12288|0;c[a+65520>>2]=b;c[a+131056>>2]=b;c[a+196592>>2]=b;b=d+13312|0;c[a+65524>>2]=b;c[a+131060>>2]=b;c[a+196596>>2]=b;b=d+14336|0;c[a+65528>>2]=b;c[a+131064>>2]=b;c[a+196600>>2]=b;b=d+15360|0;c[a+65532>>2]=b;c[a+131068>>2]=b;c[a+196604>>2]=b;c[a+196728>>2]=316;c[a+196608>>2]=1198;c[a+196648>>2]=268;c[a+81664>>2]=1;c[a+196652>>2]=748;a=c[3532592]|0;if((a|0)==0){g=c[2113054]|0;c[2113060]=g;c[2394]=-1;return}gGC(a|0,9104152,280)|0;g=c[2113054]|0;c[2113060]=g;c[2394]=-1;return}function eQH(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0;fxU(0,425984);if((c[2394]|0)==0){a=c[2112932]|0}else{c[2394]=0;b=c[3532596]|0;c[2112932]=b;d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];a=b}b=c[3532446]|0;d=a|0;e=d;f=0;while(1){c[e>>2]=b+f;g=f+1024|0;if(g>>>0>1048575){break}else{e=e+4|0;f=g}}f=c[3532552]|0;e=d;d=0;while(1){c[e+131072>>2]=f+d;b=d+1024|0;if(b>>>0>1048575){break}else{e=e+4|0;d=b}}d=c[3532356]|0;e=a+16384|0;f=4194304;while(1){c[e>>2]=d+(f-4194304);b=f+1024|0;if(b>>>0>4259839){break}else{e=e+4|0;f=b}}f=c[3532368]|0;c[a+16640>>2]=f;c[a+82176>>2]=f;c[a+147712>>2]=f;e=f+1024|0;c[a+16644>>2]=e;c[a+82180>>2]=e;c[a+147716>>2]=e;e=f+2048|0;c[a+16648>>2]=e;c[a+82184>>2]=e;c[a+147720>>2]=e;e=f+3072|0;c[a+16652>>2]=e;c[a+82188>>2]=e;c[a+147724>>2]=e;e=c[3532390]|0;c[a+12288>>2]=e;c[a+77824>>2]=e;c[a+143360>>2]=e;f=e+1024|0;c[a+12292>>2]=f;c[a+77828>>2]=f;c[a+143364>>2]=f;f=c[3532484]|0;c[a+20480>>2]=f;c[a+86016>>2]=f;c[a+151552>>2]=f;e=f+1024|0;c[a+20484>>2]=e;c[a+86020>>2]=e;c[a+151556>>2]=e;e=f+2048|0;c[a+20488>>2]=e;c[a+86024>>2]=e;c[a+151560>>2]=e;e=f+3072|0;c[a+20492>>2]=e;c[a+86028>>2]=e;c[a+151564>>2]=e;e=c[3532470]|0;c[a+8192>>2]=e;c[a+73728>>2]=e;c[a+139264>>2]=e;f=e+1024|0;c[a+8196>>2]=f;c[a+73732>>2]=f;c[a+139268>>2]=f;f=e+2048|0;c[a+8200>>2]=f;c[a+73736>>2]=f;c[a+139272>>2]=f;f=e+3072|0;c[a+8204>>2]=f;c[a+73740>>2]=f;c[a+139276>>2]=f;f=e+4096|0;c[a+8208>>2]=f;c[a+73744>>2]=f;c[a+139280>>2]=f;f=e+5120|0;c[a+8212>>2]=f;c[a+73748>>2]=f;c[a+139284>>2]=f;f=e+6144|0;c[a+8216>>2]=f;c[a+73752>>2]=f;c[a+139288>>2]=f;f=e+7168|0;c[a+8220>>2]=f;c[a+73756>>2]=f;c[a+139292>>2]=f;f=e+8192|0;c[a+8224>>2]=f;c[a+73760>>2]=f;c[a+139296>>2]=f;f=e+9216|0;c[a+8228>>2]=f;c[a+73764>>2]=f;c[a+139300>>2]=f;f=e+10240|0;c[a+8232>>2]=f;c[a+73768>>2]=f;c[a+139304>>2]=f;f=e+11264|0;c[a+8236>>2]=f;c[a+73772>>2]=f;c[a+139308>>2]=f;f=e+12288|0;c[a+8240>>2]=f;c[a+73776>>2]=f;c[a+139312>>2]=f;f=e+13312|0;c[a+8244>>2]=f;c[a+73780>>2]=f;c[a+139316>>2]=f;f=e+14336|0;c[a+8248>>2]=f;c[a+73784>>2]=f;c[a+139320>>2]=f;f=e+15360|0;c[a+8252>>2]=f;c[a+73788>>2]=f;c[a+139324>>2]=f;c[a+196608>>2]=2810;c[a+196648>>2]=2670;c[a+196728>>2]=34;a=c[3532592]|0;if((a|0)==0){h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return}gGC(a|0,9104152,280)|0;h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return}function eQI(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=c[3532470]|0;f=e+3024|0;g=d[f]|0;h=((d[e+3025|0]|0)<<8|g)&65535;if((h&65280|0)==0){return}c[3532412]=h>>>8;h=c[2439330]|0;e=(h|0)==0;if(!e){i=h;gGC(9706056,i|0,76)|0}b[4853030]=c[2426515]&65535;i=c[2438118]|0;c[2433530]=i;j=c[3528484]|0;c[2076596]=j;k=c[2417276]|0;c[3541536]=k;c[1836236]=0;a[9706117]=1;if(!e){e=h;gGC(e|0,9706056,76)|0}c[2438118]=i;c[3528484]=j;c[2417276]=k;c[1836236]=-1;b[f>>1]=g;return}function eQJ(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0;fxU(0,425984);if((c[2394]|0)==0){a=c[2112932]|0}else{c[2394]=0;b=c[3532596]|0;c[2112932]=b;d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];a=b}b=c[3532446]|0;d=a|0;e=d;f=0;while(1){c[e>>2]=b+f;g=f+1024|0;if(g>>>0>786431){break}else{e=e+4|0;f=g}}f=c[3532552]|0;e=d;d=0;while(1){c[e+131072>>2]=f+d;b=d+1024|0;if(b>>>0>786431){break}else{e=e+4|0;d=b}}d=c[3532356]|0;e=a+16384|0;f=4194304;while(1){c[e>>2]=d+(f-4194304);b=f+1024|0;if(b>>>0>4259839){break}else{e=e+4|0;f=b}}f=c[3532368]|0;c[a+16640>>2]=f;c[a+82176>>2]=f;c[a+147712>>2]=f;e=f+1024|0;c[a+16644>>2]=e;c[a+82180>>2]=e;c[a+147716>>2]=e;e=f+2048|0;c[a+16648>>2]=e;c[a+82184>>2]=e;c[a+147720>>2]=e;e=f+3072|0;c[a+16652>>2]=e;c[a+82188>>2]=e;c[a+147724>>2]=e;e=c[3532390]|0;c[a+17408>>2]=e;c[a+82944>>2]=e;c[a+148480>>2]=e;f=e+1024|0;c[a+17412>>2]=f;c[a+82948>>2]=f;c[a+148484>>2]=f;f=c[3532484]|0;c[a+33792>>2]=f;c[a+99328>>2]=f;c[a+164864>>2]=f;e=f+1024|0;c[a+33796>>2]=e;c[a+99332>>2]=e;c[a+164868>>2]=e;e=f+2048|0;c[a+33800>>2]=e;c[a+99336>>2]=e;c[a+164872>>2]=e;e=f+3072|0;c[a+33804>>2]=e;c[a+99340>>2]=e;c[a+164876>>2]=e;e=c[3532470]|0;c[a+65472>>2]=e;c[a+131008>>2]=e;c[a+196544>>2]=e;f=e+1024|0;c[a+65476>>2]=f;c[a+131012>>2]=f;c[a+196548>>2]=f;f=e+2048|0;c[a+65480>>2]=f;c[a+131016>>2]=f;c[a+196552>>2]=f;f=e+3072|0;c[a+65484>>2]=f;c[a+131020>>2]=f;c[a+196556>>2]=f;f=e+4096|0;c[a+65488>>2]=f;c[a+131024>>2]=f;c[a+196560>>2]=f;f=e+5120|0;c[a+65492>>2]=f;c[a+131028>>2]=f;c[a+196564>>2]=f;f=e+6144|0;c[a+65496>>2]=f;c[a+131032>>2]=f;c[a+196568>>2]=f;f=e+7168|0;c[a+65500>>2]=f;c[a+131036>>2]=f;c[a+196572>>2]=f;f=e+8192|0;c[a+65504>>2]=f;c[a+131040>>2]=f;c[a+196576>>2]=f;f=e+9216|0;c[a+65508>>2]=f;c[a+131044>>2]=f;c[a+196580>>2]=f;f=e+10240|0;c[a+65512>>2]=f;c[a+131048>>2]=f;c[a+196584>>2]=f;f=e+11264|0;c[a+65516>>2]=f;c[a+131052>>2]=f;c[a+196588>>2]=f;f=e+12288|0;c[a+65520>>2]=f;c[a+131056>>2]=f;c[a+196592>>2]=f;f=e+13312|0;c[a+65524>>2]=f;c[a+131060>>2]=f;c[a+196596>>2]=f;f=e+14336|0;c[a+65528>>2]=f;c[a+131064>>2]=f;c[a+196600>>2]=f;f=e+15360|0;c[a+65532>>2]=f;c[a+131068>>2]=f;c[a+196604>>2]=f;c[a+196608>>2]=1198;c[a+196648>>2]=268;c[a+196728>>2]=316;a=c[3532592]|0;if((a|0)==0){h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return}gGC(a|0,9104152,280)|0;h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return}function eQK(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0;fxU(0,425984);if((c[2394]|0)==0){a=c[2112932]|0}else{c[2394]=0;b=c[3532596]|0;c[2112932]=b;d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];a=b}b=c[3532446]|0;d=a|0;e=d;f=0;while(1){c[e>>2]=b+f;g=f+1024|0;if(g>>>0>1048575){break}else{e=e+4|0;f=g}}f=c[3532552]|0;e=d;d=0;while(1){c[e+131072>>2]=f+d;b=d+1024|0;if(b>>>0>1048575){break}else{e=e+4|0;d=b}}d=c[3532356]|0;e=a+16384|0;f=4194304;while(1){c[e>>2]=d+(f-4194304);b=f+1024|0;if(b>>>0>4259839){break}else{e=e+4|0;f=b}}f=c[3532368]|0;c[a+16640>>2]=f;c[a+82176>>2]=f;c[a+147712>>2]=f;e=f+1024|0;c[a+16644>>2]=e;c[a+82180>>2]=e;c[a+147716>>2]=e;e=f+2048|0;c[a+16648>>2]=e;c[a+82184>>2]=e;c[a+147720>>2]=e;e=f+3072|0;c[a+16652>>2]=e;c[a+82188>>2]=e;c[a+147724>>2]=e;e=c[3532390]|0;c[a+17408>>2]=e;c[a+82944>>2]=e;c[a+148480>>2]=e;f=e+1024|0;c[a+17412>>2]=f;c[a+82948>>2]=f;c[a+148484>>2]=f;f=c[3532484]|0;c[a+33792>>2]=f;c[a+99328>>2]=f;c[a+164864>>2]=f;e=f+1024|0;c[a+33796>>2]=e;c[a+99332>>2]=e;c[a+164868>>2]=e;e=f+2048|0;c[a+33800>>2]=e;c[a+99336>>2]=e;c[a+164872>>2]=e;e=f+3072|0;c[a+33804>>2]=e;c[a+99340>>2]=e;c[a+164876>>2]=e;e=c[3532470]|0;f=a+8192|0;d=2097152;while(1){b=e+(d-2097152)|0;c[f>>2]=b;c[f+65536>>2]=b;c[f+131072>>2]=b;b=d+1024|0;if(b>>>0>2359295){break}else{f=f+4|0;d=b}}c[a+196728>>2]=316;c[a+196608>>2]=1198;c[a+196648>>2]=268;c[a+81664>>2]=1;c[a+196652>>2]=748;a=c[3532592]|0;if((a|0)==0){h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return}gGC(a|0,9104152,280)|0;h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return}function eQL(){var a=0,b=0,d=0,e=0,f=0,g=0;fxU(0,425984);if((c[2394]|0)==0){a=c[2112932]|0}else{c[2394]=0;b=c[3532596]|0;c[2112932]=b;d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];a=b}b=c[3532446]|0;d=a|0;e=0;while(1){f=b+e|0;c[d>>2]=f;c[d+131072>>2]=f;f=e+1024|0;if(f>>>0>262143){break}else{d=d+4|0;e=f}}e=c[3532356]|0;d=a+16384|0;b=4194304;while(1){c[d>>2]=e+(b-4194304);f=b+1024|0;if(f>>>0>4259839){break}else{d=d+4|0;b=f}}b=c[3532368]|0;c[a+16640>>2]=b;c[a+82176>>2]=b;c[a+147712>>2]=b;d=b+1024|0;c[a+16644>>2]=d;c[a+82180>>2]=d;c[a+147716>>2]=d;d=b+2048|0;c[a+16648>>2]=d;c[a+82184>>2]=d;c[a+147720>>2]=d;d=b+3072|0;c[a+16652>>2]=d;c[a+82188>>2]=d;c[a+147724>>2]=d;d=c[3532390]|0;c[a+17408>>2]=d;c[a+82944>>2]=d;c[a+148480>>2]=d;b=d+1024|0;c[a+17412>>2]=b;c[a+82948>>2]=b;c[a+148484>>2]=b;b=c[3532484]|0;c[a+33792>>2]=b;c[a+99328>>2]=b;c[a+164864>>2]=b;d=b+1024|0;c[a+33796>>2]=d;c[a+99332>>2]=d;c[a+164868>>2]=d;d=b+2048|0;c[a+33800>>2]=d;c[a+99336>>2]=d;c[a+164872>>2]=d;d=b+3072|0;c[a+33804>>2]=d;c[a+99340>>2]=d;c[a+164876>>2]=d;d=c[3532470]|0;c[a+65472>>2]=d;c[a+131008>>2]=d;c[a+196544>>2]=d;b=d+1024|0;c[a+65476>>2]=b;c[a+131012>>2]=b;c[a+196548>>2]=b;b=d+2048|0;c[a+65480>>2]=b;c[a+131016>>2]=b;c[a+196552>>2]=b;b=d+3072|0;c[a+65484>>2]=b;c[a+131020>>2]=b;c[a+196556>>2]=b;b=d+4096|0;c[a+65488>>2]=b;c[a+131024>>2]=b;c[a+196560>>2]=b;b=d+5120|0;c[a+65492>>2]=b;c[a+131028>>2]=b;c[a+196564>>2]=b;b=d+6144|0;c[a+65496>>2]=b;c[a+131032>>2]=b;c[a+196568>>2]=b;b=d+7168|0;c[a+65500>>2]=b;c[a+131036>>2]=b;c[a+196572>>2]=b;b=d+8192|0;c[a+65504>>2]=b;c[a+131040>>2]=b;c[a+196576>>2]=b;b=d+9216|0;c[a+65508>>2]=b;c[a+131044>>2]=b;c[a+196580>>2]=b;b=d+10240|0;c[a+65512>>2]=b;c[a+131048>>2]=b;c[a+196584>>2]=b;b=d+11264|0;c[a+65516>>2]=b;c[a+131052>>2]=b;c[a+196588>>2]=b;b=d+12288|0;c[a+65520>>2]=b;c[a+131056>>2]=b;c[a+196592>>2]=b;b=d+13312|0;c[a+65524>>2]=b;c[a+131060>>2]=b;c[a+196596>>2]=b;b=d+14336|0;c[a+65528>>2]=b;c[a+131064>>2]=b;c[a+196600>>2]=b;b=d+15360|0;c[a+65532>>2]=b;c[a+131068>>2]=b;c[a+196604>>2]=b;c[a+196728>>2]=316;c[a+196608>>2]=1198;c[a+196648>>2]=268;c[a+81664>>2]=1;c[a+196652>>2]=748;a=c[3532592]|0;if((a|0)==0){g=c[2113054]|0;c[2113060]=g;c[2394]=-1;return}gGC(a|0,9104152,280)|0;g=c[2113054]|0;c[2113060]=g;c[2394]=-1;return}function eQM(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0;fxU(0,425984);if((c[2394]|0)==0){a=c[2112932]|0}else{c[2394]=0;b=c[3532596]|0;c[2112932]=b;d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];a=b}b=c[3532446]|0;d=a|0;e=d;f=0;while(1){c[e>>2]=b+f;g=f+1024|0;if(g>>>0>786431){break}else{e=e+4|0;f=g}}f=c[3532552]|0;e=d;d=0;while(1){c[e+131072>>2]=f+d;b=d+1024|0;if(b>>>0>786431){break}else{e=e+4|0;d=b}}d=c[3532356]|0;e=a+4096|0;f=e;b=1048576;while(1){c[f>>2]=d+(b-1048576);g=b+1024|0;if(g>>>0>1114111){break}else{f=f+4|0;b=g}}b=c[3532368]|0;c[a+4352>>2]=b;c[a+69888>>2]=b;c[a+135424>>2]=b;f=b+1024|0;c[a+4356>>2]=f;c[a+69892>>2]=f;c[a+135428>>2]=f;f=b+2048|0;c[a+4360>>2]=f;c[a+69896>>2]=f;c[a+135432>>2]=f;f=b+3072|0;c[a+4364>>2]=f;c[a+69900>>2]=f;c[a+135436>>2]=f;f=c[3532390]|0;c[a+8192>>2]=f;c[a+73728>>2]=f;c[a+139264>>2]=f;b=f+1024|0;c[a+8196>>2]=b;c[a+73732>>2]=b;c[a+139268>>2]=b;c[a+12288>>2]=f;c[a+77824>>2]=f;c[a+143360>>2]=f;c[a+12292>>2]=b;c[a+77828>>2]=b;c[a+143364>>2]=b;c[a+16384>>2]=f;c[a+81920>>2]=f;c[a+147456>>2]=f;c[a+16388>>2]=b;c[a+81924>>2]=b;c[a+147460>>2]=b;c[a+20480>>2]=f;c[a+86016>>2]=f;c[a+151552>>2]=f;c[a+20484>>2]=b;c[a+86020>>2]=b;c[a+151556>>2]=b;c[a+28672>>2]=f;c[a+94208>>2]=f;c[a+159744>>2]=f;c[a+28676>>2]=b;c[a+94212>>2]=b;c[a+159748>>2]=b;c[a+32768>>2]=f;c[a+98304>>2]=f;c[a+163840>>2]=f;c[a+32772>>2]=b;c[a+98308>>2]=b;c[a+163844>>2]=b;c[a+36864>>2]=f;c[a+102400>>2]=f;c[a+167936>>2]=f;c[a+36868>>2]=b;c[a+102404>>2]=b;c[a+167940>>2]=b;c[a+24576>>2]=f;c[a+90112>>2]=f;c[a+155648>>2]=f;c[a+24580>>2]=b;c[a+90116>>2]=b;c[a+155652>>2]=b;b=c[3532484]|0;c[a+5120>>2]=b;c[a+70656>>2]=b;c[a+136192>>2]=b;f=b+1024|0;c[a+5124>>2]=f;c[a+70660>>2]=f;c[a+136196>>2]=f;f=b+2048|0;c[a+5128>>2]=f;c[a+70664>>2]=f;c[a+136200>>2]=f;f=b+3072|0;c[a+5132>>2]=f;c[a+70668>>2]=f;c[a+136204>>2]=f;f=c[3532470]|0;c[a+65472>>2]=f;c[a+131008>>2]=f;c[a+196544>>2]=f;b=f+1024|0;c[a+65476>>2]=b;c[a+131012>>2]=b;c[a+196548>>2]=b;b=f+2048|0;c[a+65480>>2]=b;c[a+131016>>2]=b;c[a+196552>>2]=b;b=f+3072|0;c[a+65484>>2]=b;c[a+131020>>2]=b;c[a+196556>>2]=b;b=f+4096|0;c[a+65488>>2]=b;c[a+131024>>2]=b;c[a+196560>>2]=b;b=f+5120|0;c[a+65492>>2]=b;c[a+131028>>2]=b;c[a+196564>>2]=b;b=f+6144|0;c[a+65496>>2]=b;c[a+131032>>2]=b;c[a+196568>>2]=b;b=f+7168|0;c[a+65500>>2]=b;c[a+131036>>2]=b;c[a+196572>>2]=b;b=f+8192|0;c[a+65504>>2]=b;c[a+131040>>2]=b;c[a+196576>>2]=b;b=f+9216|0;c[a+65508>>2]=b;c[a+131044>>2]=b;c[a+196580>>2]=b;b=f+10240|0;c[a+65512>>2]=b;c[a+131048>>2]=b;c[a+196584>>2]=b;b=f+11264|0;c[a+65516>>2]=b;c[a+131052>>2]=b;c[a+196588>>2]=b;b=f+12288|0;c[a+65520>>2]=b;c[a+131056>>2]=b;c[a+196592>>2]=b;b=f+13312|0;c[a+65524>>2]=b;c[a+131060>>2]=b;c[a+196596>>2]=b;b=f+14336|0;c[a+65528>>2]=b;c[a+131064>>2]=b;c[a+196600>>2]=b;b=f+15360|0;c[a+65532>>2]=b;c[a+131068>>2]=b;c[a+196604>>2]=b;c[a+196608>>2]=1198;c[a+196648>>2]=268;b=e;e=1048576;while(1){c[b+65536>>2]=1;f=e+1024|0;if(f>>>0>1114111){break}else{b=b+4|0;e=f}}c[a+196652>>2]=3372;c[a+196732>>2]=1080;a=c[3532592]|0;if((a|0)==0){h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return}gGC(a|0,9104152,280)|0;h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return}function eQN(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;e=c[3532470]|0;f=e+11480|0;do{if(((d[e+11481|0]|0)<<8|(d[f]|0))<<16>>16==0){g=e+11486|0;h=e+11484|0;i=e+11482|0;if((((a[e+11485|0]|a[e+11487|0])&255)<<8|(d[g]|0)|(d[h]|0)|(d[i]|0)|(d[e+11483|0]|0)<<8)<<16>>16!=0){break}b[f>>1]=1164;b[i>>1]=5533;b[h>>1]=9902;b[g>>1]=14271}}while(0);f=e+11516|0;g=d[f]|0;h=((d[e+11517|0]|0)<<8|g)&65535;if((h&65280|0)==0){j=a[14130137]|0;k=j&255;l=k<<8;m=a[14130138]|0;n=m&255;o=l|n;p=~o;q=e+11472|0;r=q;b[r>>1]=p;s=a[14130136]|0;t=s&255;u=t<<8;v=u^-256;w=e+11414|0;x=w;b[x>>1]=v;return}c[3532412]=h>>>8;h=c[2439330]|0;i=(h|0)==0;if(!i){y=h;gGC(9706056,y|0,76)|0}b[4853030]=c[2426515]&65535;y=c[2438118]|0;c[2433530]=y;z=c[3528484]|0;c[2076596]=z;A=c[2417276]|0;c[3541536]=A;c[1836236]=0;a[9706117]=1;if(!i){i=h;gGC(i|0,9706056,76)|0}c[2438118]=y;c[3528484]=z;c[2417276]=A;c[1836236]=-1;b[f>>1]=g;j=a[14130137]|0;k=j&255;l=k<<8;m=a[14130138]|0;n=m&255;o=l|n;p=~o;q=e+11472|0;r=q;b[r>>1]=p;s=a[14130136]|0;t=s&255;u=t<<8;v=u^-256;w=e+11414|0;x=w;b[x>>1]=v;return}function eQO(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0;fxU(0,425984);if((c[2394]|0)==0){a=c[2112932]|0}else{c[2394]=0;b=c[3532596]|0;c[2112932]=b;d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];a=b}b=c[3532446]|0;d=a|0;e=d;f=0;while(1){c[e>>2]=b+f;g=f+1024|0;if(g>>>0>786431){break}else{e=e+4|0;f=g}}f=c[3532552]|0;e=d;d=0;while(1){c[e+131072>>2]=f+d;b=d+1024|0;if(b>>>0>786431){break}else{e=e+4|0;d=b}}d=c[3532356]|0;e=a+64e3|0;f=16384e3;while(1){c[e>>2]=d+(f-16384e3);b=f+1024|0;if(b>>>0>16449535){break}else{e=e+4|0;f=b}}f=c[3532368]|0;c[a+64256>>2]=f;c[a+129792>>2]=f;c[a+195328>>2]=f;e=f+1024|0;c[a+64260>>2]=e;c[a+129796>>2]=e;c[a+195332>>2]=e;e=f+2048|0;c[a+64264>>2]=e;c[a+129800>>2]=e;c[a+195336>>2]=e;e=f+3072|0;c[a+64268>>2]=e;c[a+129804>>2]=e;c[a+195340>>2]=e;e=c[3532390]|0;c[a+62464>>2]=e;c[a+128e3>>2]=e;c[a+193536>>2]=e;f=e+1024|0;c[a+62468>>2]=f;c[a+128004>>2]=f;c[a+193540>>2]=f;f=c[3532484]|0;c[a+62976>>2]=f;c[a+128512>>2]=f;c[a+194048>>2]=f;e=f+1024|0;c[a+62980>>2]=e;c[a+128516>>2]=e;c[a+194052>>2]=e;e=f+2048|0;c[a+62984>>2]=e;c[a+128520>>2]=e;c[a+194056>>2]=e;e=f+3072|0;c[a+62988>>2]=e;c[a+128524>>2]=e;c[a+194060>>2]=e;e=c[3532470]|0;c[a+65472>>2]=e;c[a+131008>>2]=e;c[a+196544>>2]=e;f=e+1024|0;c[a+65476>>2]=f;c[a+131012>>2]=f;c[a+196548>>2]=f;f=e+2048|0;c[a+65480>>2]=f;c[a+131016>>2]=f;c[a+196552>>2]=f;f=e+3072|0;c[a+65484>>2]=f;c[a+131020>>2]=f;c[a+196556>>2]=f;f=e+4096|0;c[a+65488>>2]=f;c[a+131024>>2]=f;c[a+196560>>2]=f;f=e+5120|0;c[a+65492>>2]=f;c[a+131028>>2]=f;c[a+196564>>2]=f;f=e+6144|0;c[a+65496>>2]=f;c[a+131032>>2]=f;c[a+196568>>2]=f;f=e+7168|0;c[a+65500>>2]=f;c[a+131036>>2]=f;c[a+196572>>2]=f;f=e+8192|0;c[a+65504>>2]=f;c[a+131040>>2]=f;c[a+196576>>2]=f;f=e+9216|0;c[a+65508>>2]=f;c[a+131044>>2]=f;c[a+196580>>2]=f;f=e+10240|0;c[a+65512>>2]=f;c[a+131048>>2]=f;c[a+196584>>2]=f;f=e+11264|0;c[a+65516>>2]=f;c[a+131052>>2]=f;c[a+196588>>2]=f;f=e+12288|0;c[a+65520>>2]=f;c[a+131056>>2]=f;c[a+196592>>2]=f;f=e+13312|0;c[a+65524>>2]=f;c[a+131060>>2]=f;c[a+196596>>2]=f;f=e+14336|0;c[a+65528>>2]=f;c[a+131064>>2]=f;c[a+196600>>2]=f;f=e+15360|0;c[a+65532>>2]=f;c[a+131068>>2]=f;c[a+196604>>2]=f;c[a+196608>>2]=2250;c[a+196648>>2]=676;c[a+196728>>2]=2532;a=c[3532592]|0;if((a|0)==0){h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return}gGC(a|0,9104152,280)|0;h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return}function eQP(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0;fxU(0,425984);if((c[2394]|0)==0){a=c[2112932]|0}else{c[2394]=0;b=c[3532596]|0;c[2112932]=b;d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];a=b}b=c[3532446]|0;d=a|0;e=d;f=0;while(1){c[e>>2]=b+f;g=f+1024|0;if(g>>>0>786431){break}else{e=e+4|0;f=g}}f=c[3532552]|0;e=d;d=0;while(1){c[e+131072>>2]=f+d;b=d+1024|0;if(b>>>0>786431){break}else{e=e+4|0;d=b}}d=c[3532356]|0;e=a+16384|0;f=4194304;while(1){c[e>>2]=d+(f-4194304);b=f+1024|0;if(b>>>0>4259839){break}else{e=e+4|0;f=b}}f=c[3532368]|0;c[a+16640>>2]=f;c[a+82176>>2]=f;c[a+147712>>2]=f;e=f+1024|0;c[a+16644>>2]=e;c[a+82180>>2]=e;c[a+147716>>2]=e;e=f+2048|0;c[a+16648>>2]=e;c[a+82184>>2]=e;c[a+147720>>2]=e;e=f+3072|0;c[a+16652>>2]=e;c[a+82188>>2]=e;c[a+147724>>2]=e;e=c[3532390]|0;c[a+12288>>2]=e;c[a+77824>>2]=e;c[a+143360>>2]=e;f=e+1024|0;c[a+12292>>2]=f;c[a+77828>>2]=f;c[a+143364>>2]=f;c[a+12296>>2]=e;c[a+77832>>2]=e;c[a+143368>>2]=e;c[a+12300>>2]=f;c[a+77836>>2]=f;c[a+143372>>2]=f;f=c[3532484]|0;c[a+20480>>2]=f;c[a+86016>>2]=f;c[a+151552>>2]=f;e=f+1024|0;c[a+20484>>2]=e;c[a+86020>>2]=e;c[a+151556>>2]=e;e=f+2048|0;c[a+20488>>2]=e;c[a+86024>>2]=e;c[a+151560>>2]=e;e=f+3072|0;c[a+20492>>2]=e;c[a+86028>>2]=e;c[a+151564>>2]=e;e=c[3532470]|0;c[a+8192>>2]=e;c[a+73728>>2]=e;c[a+139264>>2]=e;f=e+1024|0;c[a+8196>>2]=f;c[a+73732>>2]=f;c[a+139268>>2]=f;f=e+2048|0;c[a+8200>>2]=f;c[a+73736>>2]=f;c[a+139272>>2]=f;f=e+3072|0;c[a+8204>>2]=f;c[a+73740>>2]=f;c[a+139276>>2]=f;f=e+4096|0;c[a+8208>>2]=f;c[a+73744>>2]=f;c[a+139280>>2]=f;f=e+5120|0;c[a+8212>>2]=f;c[a+73748>>2]=f;c[a+139284>>2]=f;f=e+6144|0;c[a+8216>>2]=f;c[a+73752>>2]=f;c[a+139288>>2]=f;f=e+7168|0;c[a+8220>>2]=f;c[a+73756>>2]=f;c[a+139292>>2]=f;f=e+8192|0;c[a+8224>>2]=f;c[a+73760>>2]=f;c[a+139296>>2]=f;f=e+9216|0;c[a+8228>>2]=f;c[a+73764>>2]=f;c[a+139300>>2]=f;f=e+10240|0;c[a+8232>>2]=f;c[a+73768>>2]=f;c[a+139304>>2]=f;f=e+11264|0;c[a+8236>>2]=f;c[a+73772>>2]=f;c[a+139308>>2]=f;f=e+12288|0;c[a+8240>>2]=f;c[a+73776>>2]=f;c[a+139312>>2]=f;f=e+13312|0;c[a+8244>>2]=f;c[a+73780>>2]=f;c[a+139316>>2]=f;f=e+14336|0;c[a+8248>>2]=f;c[a+73784>>2]=f;c[a+139320>>2]=f;f=e+15360|0;c[a+8252>>2]=f;c[a+73788>>2]=f;c[a+139324>>2]=f;c[a+196688>>2]=2562;c[a+196728>>2]=1510;c[a+196608>>2]=1198;c[a+196648>>2]=1300;a=c[3532592]|0;if((a|0)==0){h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return}gGC(a|0,9104152,280)|0;h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return}function eQQ(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0;fxU(0,425984);if((c[2394]|0)==0){a=c[2112932]|0}else{c[2394]=0;b=c[3532596]|0;c[2112932]=b;d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];a=b}b=c[3532446]|0;d=a|0;e=d;f=0;while(1){c[e>>2]=b+f;g=f+1024|0;if(g>>>0>786431){break}else{e=e+4|0;f=g}}f=c[3532552]|0;e=d;d=0;while(1){c[e+131072>>2]=f+d;b=d+1024|0;if(b>>>0>786431){break}else{e=e+4|0;d=b}}d=c[3532356]|0;e=a+16384|0;f=4194304;while(1){c[e>>2]=d+(f-4194304);b=f+1024|0;if(b>>>0>4259839){break}else{e=e+4|0;f=b}}f=c[3532368]|0;c[a+16640>>2]=f;c[a+82176>>2]=f;c[a+147712>>2]=f;e=f+1024|0;c[a+16644>>2]=e;c[a+82180>>2]=e;c[a+147716>>2]=e;e=f+2048|0;c[a+16648>>2]=e;c[a+82184>>2]=e;c[a+147720>>2]=e;e=f+3072|0;c[a+16652>>2]=e;c[a+82188>>2]=e;c[a+147724>>2]=e;e=c[3532390]|0;c[a+12288>>2]=e;c[a+77824>>2]=e;c[a+143360>>2]=e;f=e+1024|0;c[a+12292>>2]=f;c[a+77828>>2]=f;c[a+143364>>2]=f;f=c[3532484]|0;c[a+20480>>2]=f;c[a+86016>>2]=f;c[a+151552>>2]=f;e=f+1024|0;c[a+20484>>2]=e;c[a+86020>>2]=e;c[a+151556>>2]=e;e=f+2048|0;c[a+20488>>2]=e;c[a+86024>>2]=e;c[a+151560>>2]=e;e=f+3072|0;c[a+20492>>2]=e;c[a+86028>>2]=e;c[a+151564>>2]=e;e=c[3532470]|0;c[a+8192>>2]=e;c[a+73728>>2]=e;c[a+139264>>2]=e;f=e+1024|0;c[a+8196>>2]=f;c[a+73732>>2]=f;c[a+139268>>2]=f;f=e+2048|0;c[a+8200>>2]=f;c[a+73736>>2]=f;c[a+139272>>2]=f;f=e+3072|0;c[a+8204>>2]=f;c[a+73740>>2]=f;c[a+139276>>2]=f;f=e+4096|0;c[a+8208>>2]=f;c[a+73744>>2]=f;c[a+139280>>2]=f;f=e+5120|0;c[a+8212>>2]=f;c[a+73748>>2]=f;c[a+139284>>2]=f;f=e+6144|0;c[a+8216>>2]=f;c[a+73752>>2]=f;c[a+139288>>2]=f;f=e+7168|0;c[a+8220>>2]=f;c[a+73756>>2]=f;c[a+139292>>2]=f;f=e+8192|0;c[a+8224>>2]=f;c[a+73760>>2]=f;c[a+139296>>2]=f;f=e+9216|0;c[a+8228>>2]=f;c[a+73764>>2]=f;c[a+139300>>2]=f;f=e+10240|0;c[a+8232>>2]=f;c[a+73768>>2]=f;c[a+139304>>2]=f;f=e+11264|0;c[a+8236>>2]=f;c[a+73772>>2]=f;c[a+139308>>2]=f;f=e+12288|0;c[a+8240>>2]=f;c[a+73776>>2]=f;c[a+139312>>2]=f;f=e+13312|0;c[a+8244>>2]=f;c[a+73780>>2]=f;c[a+139316>>2]=f;f=e+14336|0;c[a+8248>>2]=f;c[a+73784>>2]=f;c[a+139320>>2]=f;f=e+15360|0;c[a+8252>>2]=f;c[a+73788>>2]=f;c[a+139324>>2]=f;c[a+196608>>2]=2630;c[a+196648>>2]=1212;c[a+196728>>2]=316;a=c[3532592]|0;if((a|0)==0){h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return}gGC(a|0,9104152,280)|0;h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return}function eQR(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=c[3532470]|0;b[e+486>>1]=(d[14130136]|0)<<8^-256;b[e+488>>1]=(d[14130137]|0)<<8^-256;b[e+490>>1]=(d[14130138]|0)<<8^-256;f=e+464|0;g=((d[e+465|0]|0)<<8|(d[f]|0))&65535;if((g&65280|0)==0){return}e=g&255;c[3532412]=e;g=c[2439330]|0;h=(g|0)==0;if(!h){i=g;gGC(9706056,i|0,76)|0}b[4853030]=c[2426515]&65535;i=c[2438118]|0;c[2433530]=i;j=c[3528484]|0;c[2076596]=j;k=c[2417276]|0;c[3541536]=k;c[1836236]=0;a[9706117]=1;if(!h){h=g;gGC(h|0,9706056,76)|0}c[2438118]=i;c[3528484]=j;c[2417276]=k;c[1836236]=-1;b[f>>1]=e&65535;return}function eQS(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=c[3532470]|0;f=e+8|0;g=d[f]|0;h=((d[e+9|0]|0)<<8|g)&65535;if((h&65280|0)==0){return}c[3532412]=h>>>8;h=c[2439330]|0;e=(h|0)==0;if(!e){i=h;gGC(9706056,i|0,76)|0}b[4853030]=c[2426515]&65535;i=c[2438118]|0;c[2433530]=i;j=c[3528484]|0;c[2076596]=j;k=c[2417276]|0;c[3541536]=k;c[1836236]=0;a[9706117]=1;if(!e){e=h;gGC(e|0,9706056,76)|0}c[2438118]=i;c[3528484]=j;c[2417276]=k;c[1836236]=-1;b[f>>1]=g;return}function eQT(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0;fxU(0,425984);if((c[2394]|0)==0){a=c[2112932]|0}else{c[2394]=0;b=c[3532596]|0;c[2112932]=b;d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];a=b}b=c[3532446]|0;d=a|0;e=d;f=0;while(1){c[e>>2]=b+f;g=f+1024|0;if(g>>>0>786431){break}else{e=e+4|0;f=g}}f=c[3532552]|0;e=d;d=0;while(1){c[e+131072>>2]=f+d;b=d+1024|0;if(b>>>0>786431){break}else{e=e+4|0;d=b}}d=c[3532356]|0;e=a+4096|0;f=e;b=1048576;while(1){c[f>>2]=d+(b-1048576);g=b+1024|0;if(g>>>0>1114111){break}else{f=f+4|0;b=g}}b=c[3532368]|0;c[a+4352>>2]=b;c[a+69888>>2]=b;c[a+135424>>2]=b;f=b+1024|0;c[a+4356>>2]=f;c[a+69892>>2]=f;c[a+135428>>2]=f;f=b+2048|0;c[a+4360>>2]=f;c[a+69896>>2]=f;c[a+135432>>2]=f;f=b+3072|0;c[a+4364>>2]=f;c[a+69900>>2]=f;c[a+135436>>2]=f;f=c[3532390]|0;c[a+8192>>2]=f;c[a+73728>>2]=f;c[a+139264>>2]=f;b=f+1024|0;c[a+8196>>2]=b;c[a+73732>>2]=b;c[a+139268>>2]=b;b=c[3532484]|0;c[a+12288>>2]=b;c[a+77824>>2]=b;c[a+143360>>2]=b;f=b+1024|0;c[a+12292>>2]=f;c[a+77828>>2]=f;c[a+143364>>2]=f;f=b+2048|0;c[a+12296>>2]=f;c[a+77832>>2]=f;c[a+143368>>2]=f;f=b+3072|0;c[a+12300>>2]=f;c[a+77836>>2]=f;c[a+143372>>2]=f;f=c[3532470]|0;c[a+65472>>2]=f;c[a+131008>>2]=f;c[a+196544>>2]=f;b=f+1024|0;c[a+65476>>2]=b;c[a+131012>>2]=b;c[a+196548>>2]=b;b=f+2048|0;c[a+65480>>2]=b;c[a+131016>>2]=b;c[a+196552>>2]=b;b=f+3072|0;c[a+65484>>2]=b;c[a+131020>>2]=b;c[a+196556>>2]=b;b=f+4096|0;c[a+65488>>2]=b;c[a+131024>>2]=b;c[a+196560>>2]=b;b=f+5120|0;c[a+65492>>2]=b;c[a+131028>>2]=b;c[a+196564>>2]=b;b=f+6144|0;c[a+65496>>2]=b;c[a+131032>>2]=b;c[a+196568>>2]=b;b=f+7168|0;c[a+65500>>2]=b;c[a+131036>>2]=b;c[a+196572>>2]=b;b=f+8192|0;c[a+65504>>2]=b;c[a+131040>>2]=b;c[a+196576>>2]=b;b=f+9216|0;c[a+65508>>2]=b;c[a+131044>>2]=b;c[a+196580>>2]=b;b=f+10240|0;c[a+65512>>2]=b;c[a+131048>>2]=b;c[a+196584>>2]=b;b=f+11264|0;c[a+65516>>2]=b;c[a+131052>>2]=b;c[a+196588>>2]=b;b=f+12288|0;c[a+65520>>2]=b;c[a+131056>>2]=b;c[a+196592>>2]=b;b=f+13312|0;c[a+65524>>2]=b;c[a+131060>>2]=b;c[a+196596>>2]=b;b=f+14336|0;c[a+65528>>2]=b;c[a+131064>>2]=b;c[a+196600>>2]=b;b=f+15360|0;c[a+65532>>2]=b;c[a+131068>>2]=b;c[a+196604>>2]=b;c[a+196608>>2]=1198;c[a+196648>>2]=268;c[a+81920>>2]=1;c[a+196652>>2]=854;b=e;e=1048576;while(1){c[b+65536>>2]=2;f=e+1024|0;if(f>>>0>1114111){break}else{b=b+4|0;e=f}}c[a+196656>>2]=3092;c[a+196736>>2]=234;a=c[3532592]|0;if((a|0)==0){h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return}gGC(a|0,9104152,280)|0;h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return}function eQU(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=c[3532470]|0;b[e+8322>>1]=~(d[14130136]|0);f=e+8334|0;g=((d[e+8335|0]|0)<<8|(d[f]|0))&65535;if((g&65280|0)==0){return}e=g&255;c[3532412]=e;g=c[2439330]|0;h=(g|0)==0;if(!h){i=g;gGC(9706056,i|0,76)|0}b[4853030]=c[2426515]&65535;i=c[2438118]|0;c[2433530]=i;j=c[3528484]|0;c[2076596]=j;k=c[2417276]|0;c[3541536]=k;c[1836236]=0;a[9706117]=1;if(!h){h=g;gGC(h|0,9706056,76)|0}c[2438118]=i;c[3528484]=j;c[2417276]=k;c[1836236]=-1;b[f>>1]=e&65535;return}function eQV(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4301716+(b*112|0)>>2];c[a+104>>2]=c[4301720+(b*112|0)>>2];c[a+108>>2]=c[4301724+(b*112|0)>>2];d=0;return d|0}function eQW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<21&(d|0)==0)){e=1;return e|0}c[a>>2]=4301616+(b*112|0);e=0;return e|0}function eQX(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=690552+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eQY(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4287508+(b*112|0)>>2];c[a+104>>2]=c[4287512+(b*112|0)>>2];c[a+108>>2]=c[4287516+(b*112|0)>>2];d=0;return d|0}function eQZ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<21&(d|0)==0)){e=1;return e|0}c[a>>2]=4287408+(b*112|0);e=0;return e|0}function eQ_(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=686104+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eQ$(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>53){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4289760+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eQ0(){var a=0,b=0,d=0,e=0,f=0;a=eOx()|0;if((a|0)!=0){return a|0}if((c[2394]|0)==0){b=c[2112932]|0;d=c[3532592]|0}else{c[2394]=0;e=c[3532596]|0;c[2112932]=e;f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];b=e;d=f}c[b+114688>>2]=1;c[b+196652>>2]=1276;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;return a|0}function eQ1(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2042716+(b*112|0)>>2];c[a+104>>2]=c[2042720+(b*112|0)>>2];c[a+108>>2]=c[2042724+(b*112|0)>>2];d=0;return d|0}function eQ2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<22&(d|0)==0)){e=1;return e|0}c[a>>2]=2042616+(b*112|0);e=0;return e|0}function eQ3(){var a=0,b=0,d=0,e=0,f=0;a=eOx()|0;if((a|0)!=0){return a|0}if((c[2394]|0)==0){b=c[2112932]|0;d=c[3532592]|0}else{c[2394]=0;e=c[3532596]|0;c[2112932]=e;f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];b=e;d=f}c[b+114688>>2]=1;c[b+196652>>2]=1276;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;return a|0}function eQ4(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2037676+(b*112|0)>>2];c[a+104>>2]=c[2037680+(b*112|0)>>2];c[a+108>>2]=c[2037684+(b*112|0)>>2];d=0;return d|0}function eQ5(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<22&(d|0)==0)){e=1;return e|0}c[a>>2]=2037576+(b*112|0);e=0;return e|0}function eQ6(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2034564+(b*112|0)>>2];c[a+104>>2]=c[2034568+(b*112|0)>>2];c[a+108>>2]=c[2034572+(b*112|0)>>2];d=0;return d|0}function eQ7(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<22&(d|0)==0)){e=1;return e|0}c[a>>2]=2034464+(b*112|0);e=0;return e|0}function eQ8(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>53){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=2036928+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eQ9(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4284916+(b*112|0)>>2];c[a+104>>2]=c[4284920+(b*112|0)>>2];c[a+108>>2]=c[4284924+(b*112|0)>>2];d=0;return d|0}function eRa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=4284816+(b*112|0);e=0;return e|0}function eRb(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=685736+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eRc(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>56){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4286720+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eRd(){c[3532588]=5782;return eOx()|0}function eRe(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>25){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2021012+(b*112|0)>>2];c[a+104>>2]=c[2021016+(b*112|0)>>2];c[a+108>>2]=c[2021020+(b*112|0)>>2];d=0;return d|0}function eRf(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<26&(d|0)==0)){e=1;return e|0}c[a>>2]=2020912+(b*112|0);e=0;return e|0}function eRg(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c[3532588]=5768;c[3532380]=786432;a=eOx()|0;if((a|0)==0){b=0}else{d=a;return d|0}while(1){if((b|0)>=1024){e=1;f=0;break}g=9638528+(b<<2)|0;if((c[g>>2]|0)==0){h=27481;break}else{b=b+1|0}}do{if((h|0)==27481){b=gGq(917504)|0;c[g>>2]=b;if((b|0)==0){e=1;f=0;break}gGz(b|0,0,917504);a=c[3532374]|0;gGC(b|0,a|0,917504)|0;gGz(a|0,0,1703936);gGC(a|0,b|0,131072)|0;i=a+262144|0;j=b+131072|0;gGC(i|0,j|0,131072)|0;j=a+524288|0;i=b+262144|0;gGC(j|0,i|0,131072)|0;i=a+786432|0;j=b+393216|0;gGC(i|0,j|0,131072)|0;j=a+1048576|0;i=b+524288|0;gGC(j|0,i|0,131072)|0;i=a+1310720|0;j=b+655360|0;gGC(i|0,j|0,131072)|0;j=a+1572864|0;a=b+786432|0;gGC(j|0,a|0,131072)|0;e=0;f=b}}while(0);g=0;while(1){if((g|0)>=1024){d=e;h=27488;break}k=9638528+(g<<2)|0;if((c[k>>2]|0)==(f|0)){break}else{g=g+1|0}}if((h|0)==27488){return d|0}gGr(f);c[k>>2]=0;d=e;return d|0}function eRh(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2032660+(b*112|0)>>2];c[a+104>>2]=c[2032664+(b*112|0)>>2];c[a+108>>2]=c[2032668+(b*112|0)>>2];d=0;return d|0}function eRi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=2032560+(b*112|0);e=0;return e|0}function eRj(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>25){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1317564+(b*112|0)>>2];c[a+104>>2]=c[1317568+(b*112|0)>>2];c[a+108>>2]=c[1317572+(b*112|0)>>2];d=0;return d|0}function eRk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<26&(d|0)==0)){e=1;return e|0}c[a>>2]=1317464+(b*112|0);e=0;return e|0}function eRl(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c[3532380]=786432;a=eOx()|0;if((a|0)==0){b=0}else{d=a;return d|0}while(1){if((b|0)>=1024){e=1;f=0;break}g=9638528+(b<<2)|0;if((c[g>>2]|0)==0){h=27518;break}else{b=b+1|0}}do{if((h|0)==27518){b=gGq(917504)|0;c[g>>2]=b;if((b|0)==0){e=1;f=0;break}gGz(b|0,0,917504);a=c[3532374]|0;gGC(b|0,a|0,917504)|0;gGz(a|0,0,1703936);gGC(a|0,b|0,131072)|0;i=a+262144|0;j=b+131072|0;gGC(i|0,j|0,131072)|0;j=a+524288|0;i=b+262144|0;gGC(j|0,i|0,131072)|0;i=a+786432|0;j=b+393216|0;gGC(i|0,j|0,131072)|0;j=a+1048576|0;i=b+524288|0;gGC(j|0,i|0,131072)|0;i=a+1310720|0;j=b+655360|0;gGC(i|0,j|0,131072)|0;j=a+1572864|0;a=b+786432|0;gGC(j|0,a|0,131072)|0;e=0;f=b}}while(0);g=0;while(1){if((g|0)>=1024){d=e;h=27527;break}k=9638528+(g<<2)|0;if((c[k>>2]|0)==(f|0)){break}else{g=g+1|0}}if((h|0)==27527){return d|0}gGr(f);c[k>>2]=0;d=e;return d|0}function eRm(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>25){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2029748+(b*112|0)>>2];c[a+104>>2]=c[2029752+(b*112|0)>>2];c[a+108>>2]=c[2029756+(b*112|0)>>2];d=0;return d|0}function eRn(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<26&(d|0)==0)){e=1;return e|0}c[a>>2]=2029648+(b*112|0);e=0;return e|0}function eRo(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c[3532380]=786432;a=eOx()|0;if((a|0)==0){b=0}else{d=a;return d|0}while(1){if((b|0)>=1024){e=1;f=0;break}g=9638528+(b<<2)|0;if((c[g>>2]|0)==0){h=27543;break}else{b=b+1|0}}do{if((h|0)==27543){b=gGq(917504)|0;c[g>>2]=b;if((b|0)==0){e=1;f=0;break}gGz(b|0,0,917504);a=c[3532374]|0;gGC(b|0,a|0,917504)|0;gGz(a|0,0,1703936);gGC(a|0,b|0,131072)|0;i=a+262144|0;j=b+131072|0;gGC(i|0,j|0,131072)|0;j=a+524288|0;i=b+262144|0;gGC(j|0,i|0,131072)|0;i=a+786432|0;j=b+393216|0;gGC(i|0,j|0,131072)|0;j=a+1048576|0;i=b+524288|0;gGC(j|0,i|0,131072)|0;i=a+1310720|0;j=b+655360|0;gGC(i|0,j|0,131072)|0;j=a+1572864|0;a=b+786432|0;gGC(j|0,a|0,131072)|0;e=0;f=b}}while(0);g=0;while(1){if((g|0)>=1024){d=e;h=27550;break}k=9638528+(g<<2)|0;if((c[k>>2]|0)==(f|0)){break}else{g=g+1|0}}if((h|0)==27550){return d|0}gGr(f);c[k>>2]=0;d=e;return d|0}function eRp(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>25){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2026836+(b*112|0)>>2];c[a+104>>2]=c[2026840+(b*112|0)>>2];c[a+108>>2]=c[2026844+(b*112|0)>>2];d=0;return d|0}function eRq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<26&(d|0)==0)){e=1;return e|0}c[a>>2]=2026736+(b*112|0);e=0;return e|0}function eRr(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>25){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2023924+(b*112|0)>>2];c[a+104>>2]=c[2023928+(b*112|0)>>2];c[a+108>>2]=c[2023932+(b*112|0)>>2];d=0;return d|0}function eRs(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<26&(d|0)==0)){e=1;return e|0}c[a>>2]=2023824+(b*112|0);e=0;return e|0}function eRt(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c[3532588]=8842;c[3532380]=786432;a=eOx()|0;if((a|0)==0){b=0}else{d=a;return d|0}while(1){if((b|0)>=1024){e=1;f=0;break}g=9638528+(b<<2)|0;if((c[g>>2]|0)==0){h=27580;break}else{b=b+1|0}}do{if((h|0)==27580){b=gGq(917504)|0;c[g>>2]=b;if((b|0)==0){e=1;f=0;break}gGz(b|0,0,917504);a=c[3532374]|0;gGC(b|0,a|0,917504)|0;gGz(a|0,0,1703936);gGC(a|0,b|0,131072)|0;i=a+262144|0;j=b+131072|0;gGC(i|0,j|0,131072)|0;j=a+524288|0;i=b+262144|0;gGC(j|0,i|0,131072)|0;i=a+786432|0;j=b+393216|0;gGC(i|0,j|0,131072)|0;j=a+1048576|0;i=b+524288|0;gGC(j|0,i|0,131072)|0;i=a+1310720|0;j=b+655360|0;gGC(i|0,j|0,131072)|0;j=a+1572864|0;a=b+786432|0;gGC(j|0,a|0,131072)|0;e=0;f=b}}while(0);g=0;while(1){if((g|0)>=1024){d=e;h=27587;break}k=9638528+(g<<2)|0;if((c[k>>2]|0)==(f|0)){break}else{g=g+1|0}}if((h|0)==27587){return d|0}gGr(f);c[k>>2]=0;d=e;return d|0}function eRu(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>25){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1320476+(b*112|0)>>2];c[a+104>>2]=c[1320480+(b*112|0)>>2];c[a+108>>2]=c[1320484+(b*112|0)>>2];d=0;return d|0}function eRv(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<26&(d|0)==0)){e=1;return e|0}c[a>>2]=1320376+(b*112|0);e=0;return e|0}function eRw(){var b=0,d=0,e=0,f=0,g=0;b=eOx()|0;c[3532376]=114;if((b|0)!=0){return b|0}if((c[2394]|0)==0){d=c[2112932]|0;e=c[3532592]|0}else{c[2394]=0;f=c[3532596]|0;c[2112932]=f;g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060];d=f;e=g}c[d+82304>>2]=1;c[d+196732>>2]=78;c[d+115744>>2]=2;c[d+196656>>2]=1284;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;a[64248]=1;return b|0}function eRx(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>4){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5592764+(b*112|0)>>2];c[a+104>>2]=c[5592768+(b*112|0)>>2];c[a+108>>2]=c[5592772+(b*112|0)>>2];d=0;return d|0}function eRy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<5&(d|0)==0)){e=1;return e|0}c[a>>2]=5592664+(b*112|0);e=0;return e|0}function eRz(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=2010880+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eRA(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>47){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5593224+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eRB(){var b=0;c[3532512]=11172;b=eOx()|0;a[7461584]=1;c[3532338]=166;return b|0}function eRC(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>27){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6424340+(b*112|0)>>2];c[a+104>>2]=c[6424344+(b*112|0)>>2];c[a+108>>2]=c[6424348+(b*112|0)>>2];d=0;return d|0}function eRD(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<28&(d|0)==0)){e=1;return e|0}c[a>>2]=6424240+(b*112|0);e=0;return e|0}function eRE(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>58){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6427376+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eRF(){var a=0,b=0,d=0,e=0,f=0;c[3532546]=4020;a=eOx()|0;if((a|0)!=0){return a|0}if((c[2394]|0)==0){b=c[2112932]|0;d=c[3532592]|0}else{c[2394]=0;e=c[3532596]|0;c[2112932]=e;f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];b=e;d=f}c[b+130048>>2]=1;c[b+196652>>2]=2442;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;return a|0}function eRG(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>28){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5589516+(b*112|0)>>2];c[a+104>>2]=c[5589520+(b*112|0)>>2];c[a+108>>2]=c[5589524+(b*112|0)>>2];d=0;return d|0}function eRH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<29&(d|0)==0)){e=1;return e|0}c[a>>2]=5589416+(b*112|0);e=0;return e|0}function eRI(){var a=0,b=0,d=0,e=0,f=0;c[3532546]=4020;a=eOx()|0;if((a|0)!=0){return a|0}if((c[2394]|0)==0){b=c[2112932]|0;d=c[3532592]|0}else{c[2394]=0;e=c[3532596]|0;c[2112932]=e;f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];b=e;d=f}c[b+130048>>2]=1;c[b+196652>>2]=2442;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;return a|0}function eRJ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>28){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5586268+(b*112|0)>>2];c[a+104>>2]=c[5586272+(b*112|0)>>2];c[a+108>>2]=c[5586276+(b*112|0)>>2];d=0;return d|0}function eRK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<29&(d|0)==0)){e=1;return e|0}c[a>>2]=5586168+(b*112|0);e=0;return e|0}function eRL(){var a=0,b=0,d=0,e=0,f=0;c[3532546]=4020;a=eOx()|0;if((a|0)!=0){return a|0}if((c[2394]|0)==0){b=c[2112932]|0;d=c[3532592]|0}else{c[2394]=0;e=c[3532596]|0;c[2112932]=e;f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];b=e;d=f}c[b+130048>>2]=1;c[b+196652>>2]=2442;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;return a|0}function eRM(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4243612+(b*112|0)>>2];c[a+104>>2]=c[4243616+(b*112|0)>>2];c[a+108>>2]=c[4243620+(b*112|0)>>2];d=0;return d|0}function eRN(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=4243512+(b*112|0);e=0;return e|0}function eRO(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>56){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4245192+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eRP(){c[3532512]=10440;c[3532546]=4020;return eOx()|0}function eRQ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2005876+(b*112|0)>>2];c[a+104>>2]=c[2005880+(b*112|0)>>2];c[a+108>>2]=c[2005884+(b*112|0)>>2];d=0;return d|0}function eRR(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=2005776+(b*112|0);e=0;return e|0}function eRS(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2007556+(b*112|0)>>2];c[a+104>>2]=c[2007560+(b*112|0)>>2];c[a+108>>2]=c[2007564+(b*112|0)>>2];d=0;return d|0}function eRT(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<22&(d|0)==0)){e=1;return e|0}c[a>>2]=2007456+(b*112|0);e=0;return e|0}function eRU(){c[3532512]=10440;c[3532546]=2044;return eOx()|0}function eRV(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>3){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5566564+(b*112|0)>>2];c[a+104>>2]=c[5566568+(b*112|0)>>2];c[a+108>>2]=c[5566572+(b*112|0)>>2];d=0;return d|0}function eRW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<4&(d|0)==0)){e=1;return e|0}c[a>>2]=5566464+(b*112|0);e=0;return e|0}function eRX(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>1){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5566912+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eRY(){c[3532512]=3048;c[3532546]=3356;c[3532344]=32768;return eOx()|0}function eRZ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6408228+(b*112|0)>>2];c[a+104>>2]=c[6408232+(b*112|0)>>2];c[a+108>>2]=c[6408236+(b*112|0)>>2];d=0;return d|0}function eR_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=6408128+(b*112|0);e=0;return e|0}function eR$(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>34){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4194024+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eR0(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>35){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6410368+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eR1(){var a=0,b=0,d=0,e=0,f=0;a=eOx()|0;if((a|0)!=0){return a|0}if((c[2394]|0)==0){b=c[2112932]|0;d=c[3532592]|0}else{c[2394]=0;e=c[3532596]|0;c[2112932]=e;f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];b=e;d=f}c[b+196608>>2]=1358;c[b+114688>>2]=1;c[b+196652>>2]=2740;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;return a|0}function eR2(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>28){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6393660+(b*112|0)>>2];c[a+104>>2]=c[6393664+(b*112|0)>>2];c[a+108>>2]=c[6393668+(b*112|0)>>2];d=0;return d|0}function eR3(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<29&(d|0)==0)){e=1;return e|0}c[a>>2]=6393560+(b*112|0);e=0;return e|0}function eR4(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=947432+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eR5(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>48){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6396808+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eR6(){c[3532512]=12374;c[3532546]=4020;return eOx()|0}function eR7(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>28){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5524388+(b*112|0)>>2];c[a+104>>2]=c[5524392+(b*112|0)>>2];c[a+108>>2]=c[5524396+(b*112|0)>>2];d=0;return d|0}function eR8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<29&(d|0)==0)){e=1;return e|0}c[a>>2]=5524288+(b*112|0);e=0;return e|0}function eR9(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>28){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5527636+(b*112|0)>>2];c[a+104>>2]=c[5527640+(b*112|0)>>2];c[a+108>>2]=c[5527644+(b*112|0)>>2];d=0;return d|0}function eSa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<29&(d|0)==0)){e=1;return e|0}c[a>>2]=5527536+(b*112|0);e=0;return e|0}function eSb(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>28){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4145572+(b*112|0)>>2];c[a+104>>2]=c[4145576+(b*112|0)>>2];c[a+108>>2]=c[4145580+(b*112|0)>>2];d=0;return d|0}function eSc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<29&(d|0)==0)){e=1;return e|0}c[a>>2]=4145472+(b*112|0);e=0;return e|0}function eSd(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7311804+(b*112|0)>>2];c[a+104>>2]=c[7311808+(b*112|0)>>2];c[a+108>>2]=c[7311812+(b*112|0)>>2];d=0;return d|0}function eSe(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=7311704+(b*112|0);e=0;return e|0}function eSf(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>53){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7313160+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eSg(){var a=0,b=0,d=0,e=0,f=0;c[3532546]=4020;a=eOx()|0;if((a|0)!=0){return a|0}if((c[2394]|0)==0){b=c[2112932]|0;d=c[3532592]|0}else{c[2394]=0;e=c[3532596]|0;c[2112932]=e;f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];b=e;d=f}c[b+81664>>2]=1;c[b+196652>>2]=994;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;return a|0}function eSh(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6954348+(b*112|0)>>2];c[a+104>>2]=c[6954352+(b*112|0)>>2];c[a+108>>2]=c[6954356+(b*112|0)>>2];d=0;return d|0}function eSi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=6954248+(b*112|0);e=0;return e|0}function eSj(){var a=0,b=0,d=0,e=0,f=0;c[3532588]=9826;c[3532546]=4020;a=eOx()|0;if((a|0)!=0){return a|0}if((c[2394]|0)==0){b=c[2112932]|0;d=c[3532592]|0}else{c[2394]=0;e=c[3532596]|0;c[2112932]=e;f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];b=e;d=f}c[b+81664>>2]=1;c[b+196652>>2]=994;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;return a|0}function eSk(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6353348+(b*112|0)>>2];c[a+104>>2]=c[6353352+(b*112|0)>>2];c[a+108>>2]=c[6353356+(b*112|0)>>2];d=0;return d|0}function eSl(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=6353248+(b*112|0);e=0;return e|0}function eSm(){var b=0,d=0,e=0,f=0,g=0;c[3532546]=4020;c[3532376]=112;c[3532510]=11498;b=eOx()|0;if((b|0)!=0){return b|0}if((c[2394]|0)==0){d=c[2112932]|0;e=c[3532592]|0}else{c[2394]=0;f=c[3532596]|0;c[2112932]=f;g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060];d=f;e=g}c[d+196648>>2]=878;c[d+81664>>2]=1;c[d+196652>>2]=994;c[d+115808>>2]=2;c[d+196656>>2]=2796;c[d+196736>>2]=2606;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;a[64248]=1;return b|0}function eSn(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4027108+(b*112|0)>>2];c[a+104>>2]=c[4027112+(b*112|0)>>2];c[a+108>>2]=c[4027116+(b*112|0)>>2];d=0;return d|0}function eSo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<22&(d|0)==0)){e=1;return e|0}c[a>>2]=4027008+(b*112|0);e=0;return e|0}function eSp(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>34){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1275912+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eSq(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>51){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4029472+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eSr(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c[3532514]=7856;a[7461624]=1;c[3532380]=262144;b=eOx()|0;if((b|0)!=0){d=b;return d|0}if((c[2394]|0)==0){e=c[2112932]|0;f=c[3532592]|0}else{c[2394]=0;b=c[3532596]|0;c[2112932]=b;g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060];e=b;f=g}c[e+50224>>2]=1;c[e+196612>>2]=394;if((f|0)!=0){gGC(f|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;f=0;while(1){if((f|0)>=1024){h=1;i=0;break}j=9638528+(f<<2)|0;if((c[j>>2]|0)==0){k=28002;break}else{f=f+1|0}}do{if((k|0)==28002){f=gGq(524288)|0;c[j>>2]=f;if((f|0)==0){h=1;i=0;break}gGz(f|0,0,524288);e=c[3532374]|0;gGC(f|0,e|0,524288)|0;gGz(e|0,0,524288);gGC(e|0,f|0,65536)|0;g=e+65536|0;gGC(g|0,f|0,65536)|0;g=e+131072|0;b=f+65536|0;gGC(g|0,b|0,65536)|0;g=e+196608|0;gGC(g|0,b|0,65536)|0;b=e+262144|0;g=f+131072|0;gGC(b|0,g|0,65536)|0;b=e+327680|0;gGC(b|0,g|0,65536)|0;g=e+393216|0;b=f+196608|0;gGC(g|0,b|0,65536)|0;g=e+458752|0;gGC(g|0,b|0,65536)|0;h=0;i=f}}while(0);j=0;while(1){if((j|0)>=1024){d=h;k=28010;break}l=9638528+(j<<2)|0;if((c[l>>2]|0)==(i|0)){break}else{j=j+1|0}}if((k|0)==28010){return d|0}gGr(i);c[l>>2]=0;d=h;return d|0}function eSs(){b[4875488]=0;b[4875484]=0;b[4875480]=0;b[4875476]=0;b[4875472]=0;b[4875468]=0;b[4875464]=0;b[4875460]=0;eOI()|0;return 0}function eSt(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;i=i+128|0;e=d|0;f=d+16|0;g=d+32|0;h=d+48|0;j=d+64|0;k=d+80|0;l=d+96|0;m=d+112|0;if((b|0)!=0){c[b>>2]=169568}if((a&64|0)==0){n=eOS(a,b)|0;i=d;return 0}gGz(m|0,0,12);c[m>>2]=9750976;c[m+4>>2]=2;c[m+12>>2]=172992;gj[c[2076592]&4095](m)|0;gGz(l|0,0,12);c[l>>2]=9750968;c[l+4>>2]=2;c[l+12>>2]=172392;gj[c[2076592]&4095](l)|0;gGz(k|0,0,12);c[k>>2]=9750960;c[k+4>>2]=2;c[k+12>>2]=172e3;gj[c[2076592]&4095](k)|0;gGz(j|0,0,12);c[j>>2]=9750952;c[j+4>>2]=2;c[j+12>>2]=171824;gj[c[2076592]&4095](j)|0;gGz(h|0,0,12);c[h>>2]=9750944;c[h+4>>2]=2;c[h+12>>2]=171592;gj[c[2076592]&4095](h)|0;gGz(g|0,0,12);c[g>>2]=9750936;c[g+4>>2]=2;c[g+12>>2]=171408;gj[c[2076592]&4095](g)|0;gGz(f|0,0,12);c[f>>2]=9750928;c[f+4>>2]=2;c[f+12>>2]=171080;gj[c[2076592]&4095](f)|0;gGz(e|0,0,12);c[e>>2]=9750920;c[e+4>>2]=2;c[e+12>>2]=170848;gj[c[2076592]&4095](e)|0;n=eOS(a,b)|0;i=d;return 0}function eSu(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6888908+(b*112|0)>>2];c[a+104>>2]=c[6888912+(b*112|0)>>2];c[a+108>>2]=c[6888916+(b*112|0)>>2];d=0;return d|0}function eSv(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=6888808+(b*112|0);e=0;return e|0}function eSw(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>57){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6890376+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eSx(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c[3532512]=1872;c[3532380]=262144;a=eOx()|0;if((a|0)!=0){b=a;return b|0}if((c[2394]|0)==0){d=c[2112932]|0;e=c[3532592]|0}else{c[2394]=0;a=c[3532596]|0;c[2112932]=a;f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];d=a;e=f}c[d+70196>>2]=1;c[d+196652>>2]=1172;c[d+15872>>2]=2;c[d+81408>>2]=2;c[d+146944>>2]=2;c[d+15876>>2]=2;c[d+81412>>2]=2;c[d+146948>>2]=2;c[d+15880>>2]=2;c[d+81416>>2]=2;c[d+146952>>2]=2;c[d+15884>>2]=2;c[d+81420>>2]=2;c[d+146956>>2]=2;c[d+196696>>2]=2128;c[d+196736>>2]=1682;c[d+15888>>2]=3;c[d+81424>>2]=3;c[d+146960>>2]=3;c[d+15892>>2]=3;c[d+81428>>2]=3;c[d+146964>>2]=3;c[d+15896>>2]=3;c[d+81432>>2]=3;c[d+146968>>2]=3;c[d+15900>>2]=3;c[d+81436>>2]=3;c[d+146972>>2]=3;c[d+196700>>2]=1780;c[d+196740>>2]=114;c[d+81440>>2]=4;c[d+196664>>2]=2294;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;e=0;while(1){if((e|0)>=1024){g=1;h=0;break}i=9638528+(e<<2)|0;if((c[i>>2]|0)==0){j=28050;break}else{e=e+1|0}}do{if((j|0)==28050){e=gGq(1835008)|0;c[i>>2]=e;if((e|0)==0){g=1;h=0;break}gGz(e|0,0,1835008);d=c[3532374]|0;gGC(e|0,d|0,1835008)|0;gGz(d|0,0,1835008);gGC(d|0,e|0,262144)|0;f=d+1048576|0;a=e+262144|0;gGC(f|0,a|0,262144)|0;a=d+262144|0;f=e+524288|0;gGC(a|0,f|0,262144)|0;f=d+1310720|0;a=e+786432|0;gGC(f|0,a|0,262144)|0;a=d+524288|0;f=e+1048576|0;gGC(a|0,f|0,262144)|0;f=d+1572864|0;d=e+1310720|0;gGC(f|0,d|0,262144)|0;g=0;h=e}}while(0);i=0;while(1){if((i|0)>=1024){b=g;j=28058;break}k=9638528+(i<<2)|0;if((c[k>>2]|0)==(h|0)){break}else{i=i+1|0}}if((j|0)==28058){return b|0}gGr(h);c[k>>2]=0;b=g;return b|0}function eSy(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6323436+(b*112|0)>>2];c[a+104>>2]=c[6323440+(b*112|0)>>2];c[a+108>>2]=c[6323444+(b*112|0)>>2];d=0;return d|0}function eSz(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=6323336+(b*112|0);e=0;return e|0}function eSA(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6321868+(b*112|0)>>2];c[a+104>>2]=c[6321872+(b*112|0)>>2];c[a+108>>2]=c[6321876+(b*112|0)>>2];d=0;return d|0}function eSB(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=6321768+(b*112|0);e=0;return e|0}function eSC(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5424620+(b*112|0)>>2];c[a+104>>2]=c[5424624+(b*112|0)>>2];c[a+108>>2]=c[5424628+(b*112|0)>>2];d=0;return d|0}function eSD(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=5424520+(b*112|0);e=0;return e|0}function eSE(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c[3532512]=1872;c[3532376]=124;c[3532380]=262144;b=eOx()|0;if((b|0)!=0){d=b;return d|0}if((c[2394]|0)==0){e=c[2112932]|0;f=c[3532592]|0}else{c[2394]=0;b=c[3532596]|0;c[2112932]=b;g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060];e=b;f=g}c[e+82304>>2]=1;c[e+196732>>2]=1844;c[e+196652>>2]=638;c[e+115744>>2]=2;c[e+196656>>2]=584;c[e+81440>>2]=3;c[e+196660>>2]=2294;if((f|0)!=0){gGC(f|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;f=0;while(1){if((f|0)>=1024){h=1;i=0;break}j=9638528+(f<<2)|0;if((c[j>>2]|0)==0){k=28107;break}else{f=f+1|0}}do{if((k|0)==28107){f=gGq(1835008)|0;c[j>>2]=f;if((f|0)==0){h=1;i=0;break}gGz(f|0,0,1835008);e=c[3532374]|0;gGC(f|0,e|0,1835008)|0;gGz(e|0,0,1835008);gGC(e|0,f|0,262144)|0;g=e+1048576|0;b=f+262144|0;gGC(g|0,b|0,262144)|0;b=e+262144|0;g=f+524288|0;gGC(b|0,g|0,262144)|0;g=e+1310720|0;b=f+786432|0;gGC(g|0,b|0,262144)|0;b=e+524288|0;g=f+1048576|0;gGC(b|0,g|0,262144)|0;g=e+1572864|0;e=f+1310720|0;gGC(g|0,e|0,262144)|0;h=0;i=f}}while(0);j=0;while(1){if((j|0)>=1024){break}l=9638528+(j<<2)|0;if((c[l>>2]|0)==(i|0)){k=28112;break}else{j=j+1|0}}if((k|0)==28112){gGr(i);c[l>>2]=0}a[64248]=1;d=h;return d|0}function eSF(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4001028+(b*112|0)>>2];c[a+104>>2]=c[4001032+(b*112|0)>>2];c[a+108>>2]=c[4001036+(b*112|0)>>2];d=0;return d|0}function eSG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=4000928+(b*112|0);e=0;return e|0}function eSH(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>38){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1272568+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eSI(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>57){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4003504+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eSJ(){var a=0,b=0,d=0,e=0,f=0;c[3532514]=12856;a=eOx()|0;if((a|0)!=0){return a|0}if((c[2394]|0)==0){b=c[2112932]|0;d=c[3532592]|0}else{c[2394]=0;e=c[3532596]|0;c[2112932]=e;f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];b=e;d=f}c[b+196608>>2]=1524;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;return a|0}function eSK(){b[4875456]=0;b[4875452]=0;b[4875448]=0;b[4875444]=0;eOI()|0;return 0}function eSL(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0;d=i;i=i+64|0;e=d|0;f=d+16|0;g=d+32|0;h=d+48|0;if((b|0)!=0){c[b>>2]=169568}if((a&64|0)==0){j=eOS(a,b)|0;i=d;return 0}gGz(h|0,0,12);c[h>>2]=9750912;c[h+4>>2]=2;c[h+12>>2]=193384;gj[c[2076592]&4095](h)|0;gGz(g|0,0,12);c[g>>2]=9750904;c[g+4>>2]=2;c[g+12>>2]=192632;gj[c[2076592]&4095](g)|0;gGz(f|0,0,12);c[f>>2]=9750896;c[f+4>>2]=2;c[f+12>>2]=192056;gj[c[2076592]&4095](f)|0;gGz(e|0,0,12);c[e>>2]=9750888;c[e+4>>2]=2;c[e+12>>2]=191256;gj[c[2076592]&4095](e)|0;j=eOS(a,b)|0;i=d;return 0}function eSM(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3986180+(b*112|0)>>2];c[a+104>>2]=c[3986184+(b*112|0)>>2];c[a+108>>2]=c[3986188+(b*112|0)>>2];d=0;return d|0}function eSN(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<21&(d|0)==0)){e=1;return e|0}c[a>>2]=3986080+(b*112|0);e=0;return e|0}function eSO(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3988432+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eSP(){c[3532512]=6352;c[3532546]=3568;return eOx()|0}function eSQ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1932948+(b*112|0)>>2];c[a+104>>2]=c[1932952+(b*112|0)>>2];c[a+108>>2]=c[1932956+(b*112|0)>>2];d=0;return d|0}function eSR(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=1932848+(b*112|0);e=0;return e|0}function eSS(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>4){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[986500+(b*112|0)>>2];c[a+104>>2]=c[986504+(b*112|0)>>2];c[a+108>>2]=c[986508+(b*112|0)>>2];d=0;return d|0}function eST(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<5&(d|0)==0)){e=1;return e|0}c[a>>2]=986400+(b*112|0);e=0;return e|0}function eSU(){c[3532512]=6352;c[3532546]=270;c[3532344]=131072;return eOx()|0}function eSV(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>3){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3985732+(b*112|0)>>2];c[a+104>>2]=c[3985736+(b*112|0)>>2];c[a+108>>2]=c[3985740+(b*112|0)>>2];d=0;return d|0}function eSW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<4&(d|0)==0)){e=1;return e|0}c[a>>2]=3985632+(b*112|0);e=0;return e|0}function eSX(){c[3532512]=7322;c[3532546]=1890;c[3532344]=65536;return eOx()|0}function eSY(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6308956+(b*112|0)>>2];c[a+104>>2]=c[6308960+(b*112|0)>>2];c[a+108>>2]=c[6308964+(b*112|0)>>2];d=0;return d|0}function eSZ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=6308856+(b*112|0);e=0;return e|0}function eS_(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>49){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6309864+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eS$(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5400092+(b*112|0)>>2];c[a+104>>2]=c[5400096+(b*112|0)>>2];c[a+108>>2]=c[5400100+(b*112|0)>>2];d=0;return d|0}function eS0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=5399992+(b*112|0);e=0;return e|0}function eS1(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3944556+(b*112|0)>>2];c[a+104>>2]=c[3944560+(b*112|0)>>2];c[a+108>>2]=c[3944564+(b*112|0)>>2];d=0;return d|0}function eS2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=3944456+(b*112|0);e=0;return e|0}function eS3(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1264520+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eS4(){var b=0,d=0,e=0,f=0,g=0;c[3532510]=11498;b=eOx()|0;c[3532376]=109;if((b|0)!=0){return b|0}if((c[2394]|0)==0){d=c[2112932]|0;e=c[3532592]|0}else{c[2394]=0;f=c[3532596]|0;c[2112932]=f;g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060];d=f;e=g}c[d+196608>>2]=3514;c[d+196648>>2]=2900;c[d+115808>>2]=1;c[d+196732>>2]=2024;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;a[64248]=1;return b|0}function eS5(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3945452+(b*112|0)>>2];c[a+104>>2]=c[3945456+(b*112|0)>>2];c[a+108>>2]=c[3945460+(b*112|0)>>2];d=0;return d|0}function eS6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=3945352+(b*112|0);e=0;return e|0}function eS7(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3899036+(b*112|0)>>2];c[a+104>>2]=c[3899040+(b*112|0)>>2];c[a+108>>2]=c[3899044+(b*112|0)>>2];d=0;return d|0}function eS8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=3898936+(b*112|0);e=0;return e|0}function eS9(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>51){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3900504+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eTa(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c[3532588]=5166;c[3532512]=4772;c[3532380]=262144;a=eOx()|0;if((a|0)!=0){b=a;return b|0}if((c[2394]|0)==0){d=c[2112932]|0;e=c[3532592]|0}else{c[2394]=0;a=c[3532596]|0;c[2112932]=a;f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];d=a;e=f}c[d+7680>>2]=2;c[d+73216>>2]=2;c[d+138752>>2]=2;c[d+7684>>2]=2;c[d+73220>>2]=2;c[d+138756>>2]=2;c[d+7688>>2]=2;c[d+73224>>2]=2;c[d+138760>>2]=2;c[d+7692>>2]=2;c[d+73228>>2]=2;c[d+138764>>2]=2;c[d+196696>>2]=3038;c[d+196736>>2]=1660;c[d+7936>>2]=3;c[d+73472>>2]=3;c[d+139008>>2]=3;c[d+7940>>2]=3;c[d+73476>>2]=3;c[d+139012>>2]=3;c[d+7944>>2]=3;c[d+73480>>2]=3;c[d+139016>>2]=3;c[d+7948>>2]=3;c[d+73484>>2]=3;c[d+139020>>2]=3;c[d+196700>>2]=424;c[d+196740>>2]=2582;c[d+7952>>2]=4;c[d+73488>>2]=4;c[d+139024>>2]=4;c[d+7956>>2]=4;c[d+73492>>2]=4;c[d+139028>>2]=4;c[d+7960>>2]=4;c[d+73496>>2]=4;c[d+139032>>2]=4;c[d+7964>>2]=4;c[d+73500>>2]=4;c[d+139036>>2]=4;c[d+196704>>2]=430;c[d+196744>>2]=2366;c[d+73504>>2]=5;c[d+196668>>2]=542;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;e=0;while(1){if((e|0)>=1024){g=1;h=0;break}i=9638528+(e<<2)|0;if((c[i>>2]|0)==0){j=28325;break}else{e=e+1|0}}do{if((j|0)==28325){e=gGq(1835008)|0;c[i>>2]=e;if((e|0)==0){g=1;h=0;break}gGz(e|0,0,1835008);d=c[3532374]|0;gGC(e|0,d|0,1835008)|0;gGz(d|0,0,1835008);gGC(d|0,e|0,262144)|0;f=d+1048576|0;a=e+262144|0;gGC(f|0,a|0,262144)|0;a=d+262144|0;f=e+524288|0;gGC(a|0,f|0,262144)|0;f=d+1310720|0;a=e+786432|0;gGC(f|0,a|0,262144)|0;a=d+524288|0;f=e+1048576|0;gGC(a|0,f|0,262144)|0;f=d+1572864|0;d=e+1310720|0;gGC(f|0,d|0,262144)|0;g=0;h=e}}while(0);i=0;while(1){if((i|0)>=1024){b=g;j=28334;break}k=9638528+(i<<2)|0;if((c[k>>2]|0)==(h|0)){break}else{i=i+1|0}}if((j|0)==28334){return b|0}gGr(h);c[k>>2]=0;b=g;return b|0}function eTb(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1883004+(b*112|0)>>2];c[a+104>>2]=c[1883008+(b*112|0)>>2];c[a+108>>2]=c[1883012+(b*112|0)>>2];d=0;return d|0}function eTc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=1882904+(b*112|0);e=0;return e|0}function eTd(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c[3532512]=4772;c[3532380]=262144;a=eOx()|0;if((a|0)!=0){b=a;return b|0}if((c[2394]|0)==0){d=c[2112932]|0;e=c[3532592]|0}else{c[2394]=0;a=c[3532596]|0;c[2112932]=a;f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];d=a;e=f}c[d+7680>>2]=2;c[d+73216>>2]=2;c[d+138752>>2]=2;c[d+7684>>2]=2;c[d+73220>>2]=2;c[d+138756>>2]=2;c[d+7688>>2]=2;c[d+73224>>2]=2;c[d+138760>>2]=2;c[d+7692>>2]=2;c[d+73228>>2]=2;c[d+138764>>2]=2;c[d+196696>>2]=3038;c[d+196736>>2]=1660;c[d+7936>>2]=3;c[d+73472>>2]=3;c[d+139008>>2]=3;c[d+7940>>2]=3;c[d+73476>>2]=3;c[d+139012>>2]=3;c[d+7944>>2]=3;c[d+73480>>2]=3;c[d+139016>>2]=3;c[d+7948>>2]=3;c[d+73484>>2]=3;c[d+139020>>2]=3;c[d+196700>>2]=424;c[d+196740>>2]=2582;c[d+7952>>2]=4;c[d+73488>>2]=4;c[d+139024>>2]=4;c[d+7956>>2]=4;c[d+73492>>2]=4;c[d+139028>>2]=4;c[d+7960>>2]=4;c[d+73496>>2]=4;c[d+139032>>2]=4;c[d+7964>>2]=4;c[d+73500>>2]=4;c[d+139036>>2]=4;c[d+196704>>2]=430;c[d+196744>>2]=2366;c[d+73504>>2]=5;c[d+196668>>2]=542;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;e=0;while(1){if((e|0)>=1024){g=1;h=0;break}i=9638528+(e<<2)|0;if((c[i>>2]|0)==0){j=28358;break}else{e=e+1|0}}do{if((j|0)==28358){e=gGq(1835008)|0;c[i>>2]=e;if((e|0)==0){g=1;h=0;break}gGz(e|0,0,1835008);d=c[3532374]|0;gGC(e|0,d|0,1835008)|0;gGz(d|0,0,1835008);gGC(d|0,e|0,262144)|0;f=d+1048576|0;a=e+262144|0;gGC(f|0,a|0,262144)|0;a=d+262144|0;f=e+524288|0;gGC(a|0,f|0,262144)|0;f=d+1310720|0;a=e+786432|0;gGC(f|0,a|0,262144)|0;a=d+524288|0;f=e+1048576|0;gGC(a|0,f|0,262144)|0;f=d+1572864|0;d=e+1310720|0;gGC(f|0,d|0,262144)|0;g=0;h=e}}while(0);i=0;while(1){if((i|0)>=1024){b=g;j=28366;break}k=9638528+(i<<2)|0;if((c[k>>2]|0)==(h|0)){break}else{i=i+1|0}}if((j|0)==28366){return b|0}gGr(h);c[k>>2]=0;b=g;return b|0}function eTe(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1881212+(b*112|0)>>2];c[a+104>>2]=c[1881216+(b*112|0)>>2];c[a+108>>2]=c[1881220+(b*112|0)>>2];d=0;return d|0}function eTf(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=1881112+(b*112|0);e=0;return e|0}function eTg(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c[3532588]=5166;c[3532512]=4772;c[3532546]=4020;c[3532380]=262144;a=eOx()|0;if((a|0)!=0){b=a;return b|0}if((c[2394]|0)==0){d=c[2112932]|0;e=c[3532592]|0}else{c[2394]=0;a=c[3532596]|0;c[2112932]=a;f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];d=a;e=f}c[d+73472>>2]=2;c[d+196656>>2]=538;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;e=0;while(1){if((e|0)>=1024){g=1;h=0;break}i=9638528+(e<<2)|0;if((c[i>>2]|0)==0){j=28391;break}else{e=e+1|0}}do{if((j|0)==28391){e=gGq(1835008)|0;c[i>>2]=e;if((e|0)==0){g=1;h=0;break}gGz(e|0,0,1835008);d=c[3532374]|0;gGC(e|0,d|0,1835008)|0;gGz(d|0,0,1835008);gGC(d|0,e|0,262144)|0;f=d+1048576|0;a=e+262144|0;gGC(f|0,a|0,262144)|0;a=d+262144|0;f=e+524288|0;gGC(a|0,f|0,262144)|0;f=d+1310720|0;a=e+786432|0;gGC(f|0,a|0,262144)|0;a=d+524288|0;f=e+1048576|0;gGC(a|0,f|0,262144)|0;f=d+1572864|0;d=e+1310720|0;gGC(f|0,d|0,262144)|0;g=0;h=e}}while(0);i=0;while(1){if((i|0)>=1024){b=g;j=28400;break}k=9638528+(i<<2)|0;if((c[k>>2]|0)==(h|0)){break}else{i=i+1|0}}if((j|0)==28400){return b|0}gGr(h);c[k>>2]=0;b=g;return b|0}function eTh(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1879420+(b*112|0)>>2];c[a+104>>2]=c[1879424+(b*112|0)>>2];c[a+108>>2]=c[1879428+(b*112|0)>>2];d=0;return d|0}function eTi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=1879320+(b*112|0);e=0;return e|0}function eTj(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c[3532512]=4772;c[3532546]=4020;c[3532380]=262144;a=eOx()|0;if((a|0)!=0){b=a;return b|0}if((c[2394]|0)==0){d=c[2112932]|0;e=c[3532592]|0}else{c[2394]=0;a=c[3532596]|0;c[2112932]=a;f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];d=a;e=f}c[d+73472>>2]=2;c[d+196656>>2]=538;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;e=0;while(1){if((e|0)>=1024){g=1;h=0;break}i=9638528+(e<<2)|0;if((c[i>>2]|0)==0){j=28424;break}else{e=e+1|0}}do{if((j|0)==28424){e=gGq(1835008)|0;c[i>>2]=e;if((e|0)==0){g=1;h=0;break}gGz(e|0,0,1835008);d=c[3532374]|0;gGC(e|0,d|0,1835008)|0;gGz(d|0,0,1835008);gGC(d|0,e|0,262144)|0;f=d+1048576|0;a=e+262144|0;gGC(f|0,a|0,262144)|0;a=d+262144|0;f=e+524288|0;gGC(a|0,f|0,262144)|0;f=d+1310720|0;a=e+786432|0;gGC(f|0,a|0,262144)|0;a=d+524288|0;f=e+1048576|0;gGC(a|0,f|0,262144)|0;f=d+1572864|0;d=e+1310720|0;gGC(f|0,d|0,262144)|0;g=0;h=e}}while(0);i=0;while(1){if((i|0)>=1024){b=g;j=28433;break}k=9638528+(i<<2)|0;if((c[k>>2]|0)==(h|0)){break}else{i=i+1|0}}if((j|0)==28433){return b|0}gGr(h);c[k>>2]=0;b=g;return b|0}function eTk(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1877628+(b*112|0)>>2];c[a+104>>2]=c[1877632+(b*112|0)>>2];c[a+108>>2]=c[1877636+(b*112|0)>>2];d=0;return d|0}function eTl(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=1877528+(b*112|0);e=0;return e|0}function eTm(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1876060+(b*112|0)>>2];c[a+104>>2]=c[1876064+(b*112|0)>>2];c[a+108>>2]=c[1876068+(b*112|0)>>2];d=0;return d|0}function eTn(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=1875960+(b*112|0);e=0;return e|0}function eTo(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5344852+(b*112|0)>>2];c[a+104>>2]=c[5344856+(b*112|0)>>2];c[a+108>>2]=c[5344860+(b*112|0)>>2];d=0;return d|0}function eTp(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=5344752+(b*112|0);e=0;return e|0}function eTq(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1869104+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eTr(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>54){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5346992+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eTs(){var a=0,b=0,d=0,e=0,f=0;a=eOx()|0;if((a|0)!=0){return a|0}if((c[2394]|0)==0){b=c[2112932]|0;d=c[3532592]|0}else{c[2394]=0;e=c[3532596]|0;c[2112932]=e;f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];b=e;d=f}c[b+81664>>2]=1;c[b+196652>>2]=852;c[b+50224>>2]=2;c[b+115760>>2]=2;c[b+181296>>2]=2;c[b+196696>>2]=3488;c[b+196736>>2]=12;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;return a|0}function eTt(){a[9750856]=0;eOI()|0;return 0}function eTu(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=i;i=i+16|0;e=d|0;if((b|0)!=0){c[b>>2]=169568}if((a&64|0)==0){f=eOS(a,b)|0;i=d;return 0}gGz(e|0,0,12);c[e>>2]=9750856;c[e+4>>2]=1;c[e+12>>2]=199600;gj[c[2076592]&4095](e)|0;f=eOS(a,b)|0;i=d;return 0}function eTv(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3847836+(b*112|0)>>2];c[a+104>>2]=c[3847840+(b*112|0)>>2];c[a+108>>2]=c[3847844+(b*112|0)>>2];d=0;return d|0}function eTw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<21&(d|0)==0)){e=1;return e|0}c[a>>2]=3847736+(b*112|0);e=0;return e|0}function eTx(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7390196+(b*112|0)>>2];c[a+104>>2]=c[7390200+(b*112|0)>>2];c[a+108>>2]=c[7390204+(b*112|0)>>2];d=0;return d|0}function eTy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=7390096+(b*112|0);e=0;return e|0}function eTz(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>58){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7391888+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eTA(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;a=eOx()|0;if((a|0)!=0){b=a;return b|0}if((c[2394]|0)==0){d=c[2112932]|0;e=c[3532592]|0}else{c[2394]=0;a=c[3532596]|0;c[2112932]=a;f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];d=a;e=f}c[d+81696>>2]=1;c[d+196652>>2]=798;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;e=0;while(1){if((e|0)>=1024){g=1;h=0;break}i=9638528+(e<<2)|0;if((c[i>>2]|0)==0){j=28546;break}else{e=e+1|0}}do{if((j|0)==28546){e=gGq(2097152)|0;c[i>>2]=e;if((e|0)==0){g=1;h=0;break}gGz(e|0,0,2097152);d=c[3532374]|0;gGC(e|0,d|0,2097152)|0;gGz(d|0,0,2097152);gGC(d|0,e|0,262144)|0;f=d+1048576|0;a=e+262144|0;gGC(f|0,a|0,262144)|0;a=d+262144|0;f=e+524288|0;gGC(a|0,f|0,262144)|0;f=d+1310720|0;a=e+786432|0;gGC(f|0,a|0,262144)|0;a=d+524288|0;f=e+1048576|0;gGC(a|0,f|0,262144)|0;f=d+1572864|0;a=e+1310720|0;gGC(f|0,a|0,262144)|0;a=d+786432|0;f=e+1572864|0;gGC(a|0,f|0,262144)|0;f=d+1835008|0;d=e+1835008|0;gGC(f|0,d|0,262144)|0;g=0;h=e}}while(0);i=0;while(1){if((i|0)>=1024){b=g;j=28554;break}k=9638528+(i<<2)|0;if((c[k>>2]|0)==(h|0)){break}else{i=i+1|0}}if((j|0)==28554){return b|0}gGr(h);c[k>>2]=0;b=g;return b|0}function eTB(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>24){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7173524+(b*112|0)>>2];c[a+104>>2]=c[7173528+(b*112|0)>>2];c[a+108>>2]=c[7173532+(b*112|0)>>2];d=0;return d|0}function eTC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<25&(d|0)==0)){e=1;return e|0}c[a>>2]=7173424+(b*112|0);e=0;return e|0}function eTD(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c[3532546]=4020;c[3532380]=524288;a=eOx()|0;if((a|0)!=0){b=a;return b|0}if((c[2394]|0)==0){d=c[2112932]|0;e=c[3532592]|0}else{c[2394]=0;a=c[3532596]|0;c[2112932]=a;f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];d=a;e=f}c[d+81664>>2]=1;c[d+196652>>2]=800;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;e=0;while(1){if((e|0)>=1024){g=1;h=0;break}i=9638528+(e<<2)|0;if((c[i>>2]|0)==0){j=28579;break}else{e=e+1|0}}do{if((j|0)==28579){e=gGq(2097152)|0;c[i>>2]=e;if((e|0)==0){g=1;h=0;break}gGz(e|0,0,2097152);d=c[3532374]|0;gGC(e|0,d|0,2097152)|0;gGz(d|0,0,2097152);gGC(d|0,e|0,786432)|0;f=d+1048576|0;d=e+786432|0;gGC(f|0,d|0,786432)|0;g=0;h=e}}while(0);i=0;while(1){if((i|0)>=1024){b=g;j=28588;break}k=9638528+(i<<2)|0;if((c[k>>2]|0)==(h|0)){break}else{i=i+1|0}}if((j|0)==28588){return b|0}gGr(h);c[k>>2]=0;b=g;return b|0}function eTE(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5167852+(b*112|0)>>2];c[a+104>>2]=c[5167856+(b*112|0)>>2];c[a+108>>2]=c[5167860+(b*112|0)>>2];d=0;return d|0}function eTF(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=5167752+(b*112|0);e=0;return e|0}function eTG(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>24){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=685336+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eTH(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>57){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5169656+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eTI(){var a=0,b=0,d=0,e=0,f=0;a=eOx()|0;if((a|0)!=0){return a|0}if((c[2394]|0)==0){b=c[2112932]|0;d=c[3532592]|0}else{c[2394]=0;e=c[3532596]|0;c[2112932]=e;f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];b=e;d=f}c[b+114688>>2]=1;c[b+196652>>2]=2202;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;return a|0}function eTJ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3627996+(b*112|0)>>2];c[a+104>>2]=c[3628e3+(b*112|0)>>2];c[a+108>>2]=c[3628004+(b*112|0)>>2];d=0;return d|0}function eTK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=3627896+(b*112|0);e=0;return e|0}function eTL(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>42){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1788616+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eTM(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>57){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3629800+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eTN(){var a=0,b=0,d=0,e=0,f=0;a=eOx()|0;if((a|0)!=0){return a|0}if((c[2394]|0)==0){b=c[2112932]|0;d=c[3532592]|0}else{c[2394]=0;e=c[3532596]|0;c[2112932]=e;f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];b=e;d=f}c[b+114688>>2]=1;c[b+196652>>2]=2202;c[b+50224>>2]=2;c[b+196616>>2]=1634;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;return a|0}function eTO(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3626092+(b*112|0)>>2];c[a+104>>2]=c[3626096+(b*112|0)>>2];c[a+108>>2]=c[3626100+(b*112|0)>>2];d=0;return d|0}function eTP(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=3625992+(b*112|0);e=0;return e|0}function eTQ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3555572+(b*112|0)>>2];c[a+104>>2]=c[3555576+(b*112|0)>>2];c[a+108>>2]=c[3555580+(b*112|0)>>2];d=0;return d|0}function eTR(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=3555472+(b*112|0);e=0;return e|0}function eTS(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>57){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3557488+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eTT(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c[3532512]=1330;c[3532546]=4020;c[3532380]=262144;a=eOx()|0;if((a|0)==0){b=0}else{d=a;return d|0}while(1){if((b|0)>=1024){e=1;f=0;break}g=9638528+(b<<2)|0;if((c[g>>2]|0)==0){h=28699;break}else{b=b+1|0}}do{if((h|0)==28699){b=gGq(1835008)|0;c[g>>2]=b;if((b|0)==0){e=1;f=0;break}gGz(b|0,0,1835008);a=c[3532374]|0;gGC(b|0,a|0,1835008)|0;gGz(a|0,0,1835008);gGC(a|0,b|0,262144)|0;i=a+1048576|0;j=b+262144|0;gGC(i|0,j|0,262144)|0;j=a+262144|0;i=b+524288|0;gGC(j|0,i|0,262144)|0;i=a+1310720|0;j=b+786432|0;gGC(i|0,j|0,262144)|0;j=a+524288|0;i=b+1048576|0;gGC(j|0,i|0,262144)|0;i=a+1572864|0;a=b+1310720|0;gGC(i|0,a|0,262144)|0;e=0;f=b}}while(0);g=0;while(1){if((g|0)>=1024){d=e;h=28707;break}k=9638528+(g<<2)|0;if((c[k>>2]|0)==(f|0)){break}else{g=g+1|0}}if((h|0)==28707){return d|0}gGr(f);c[k>>2]=0;d=e;return d|0}function eTU(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6142764+(b*112|0)>>2];c[a+104>>2]=c[6142768+(b*112|0)>>2];c[a+108>>2]=c[6142772+(b*112|0)>>2];d=0;return d|0}function eTV(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=6142664+(b*112|0);e=0;return e|0}function eTW(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3532456+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eTX(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>57){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6144008+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eTY(){c[3532512]=11072;return eOx()|0}function eTZ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7148540+(b*112|0)>>2];c[a+104>>2]=c[7148544+(b*112|0)>>2];c[a+108>>2]=c[7148548+(b*112|0)>>2];d=0;return d|0}function eT_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=7148440+(b*112|0);e=0;return e|0}function eT$(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6808488+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eT0(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>56){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7150344+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eT1(){var a=0,b=0,d=0,e=0,f=0;c[3532514]=9866;a=eOx()|0;if((a|0)!=0){return a|0}if((c[2394]|0)==0){b=c[2112932]|0;d=c[3532592]|0}else{c[2394]=0;e=c[3532596]|0;c[2112932]=e;f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];b=e;d=f}c[b+196608>>2]=1836;c[b+70196>>2]=1;c[b+196652>>2]=3102;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;return a|0}function eT2(){b[7057912]=0;b[7057904]=0;b[7057896]=0;b[7057888]=0;eOI()|0;return 0}function eT3(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0;d=i;i=i+64|0;e=d|0;f=d+16|0;g=d+32|0;h=d+48|0;if((b|0)!=0){c[b>>2]=169568}if((a&64|0)==0){j=eOS(a,b)|0;i=d;return 0}gGz(h|0,0,12);c[h>>2]=14115824;c[h+4>>2]=2;c[h+12>>2]=251288;gj[c[2076592]&4095](h)|0;gGz(g|0,0,12);c[g>>2]=14115808;c[g+4>>2]=2;c[g+12>>2]=250600;gj[c[2076592]&4095](g)|0;gGz(f|0,0,12);c[f>>2]=14115792;c[f+4>>2]=2;c[f+12>>2]=249936;gj[c[2076592]&4095](f)|0;gGz(e|0,0,12);c[e>>2]=14115776;c[e+4>>2]=2;c[e+12>>2]=249208;gj[c[2076592]&4095](e)|0;j=eOS(a,b)|0;i=d;return 0}function eT4(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6806796+(b*112|0)>>2];c[a+104>>2]=c[6806800+(b*112|0)>>2];c[a+108>>2]=c[6806804+(b*112|0)>>2];d=0;return d|0}function eT5(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=6806696+(b*112|0);e=0;return e|0}function eT6(){var a=0,b=0,d=0,e=0,f=0;c[3532514]=9866;a=eOx()|0;if((a|0)!=0){return a|0}if((c[2394]|0)==0){b=c[2112932]|0;d=c[3532592]|0}else{c[2394]=0;e=c[3532596]|0;c[2112932]=e;f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];b=e;d=f}c[b+196608>>2]=1836;c[b+70196>>2]=1;c[b+196652>>2]=3102;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;return a|0}function eT7(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5463564+(b*112|0)>>2];c[a+104>>2]=c[5463568+(b*112|0)>>2];c[a+108>>2]=c[5463572+(b*112|0)>>2];d=0;return d|0}function eT8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=5463464+(b*112|0);e=0;return e|0}function eT9(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3456348+(b*112|0)>>2];c[a+104>>2]=c[3456352+(b*112|0)>>2];c[a+108>>2]=c[3456356+(b*112|0)>>2];d=0;return d|0}function eUa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=3456248+(b*112|0);e=0;return e|0}function eUb(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>57){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4996528+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eUc(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3454220+(b*112|0)>>2];c[a+104>>2]=c[3454224+(b*112|0)>>2];c[a+108>>2]=c[3454228+(b*112|0)>>2];d=0;return d|0}function eUd(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=3454120+(b*112|0);e=0;return e|0}function eUe(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3452876+(b*112|0)>>2];c[a+104>>2]=c[3452880+(b*112|0)>>2];c[a+108>>2]=c[3452884+(b*112|0)>>2];d=0;return d|0}function eUf(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=3452776+(b*112|0);e=0;return e|0}function eUg(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3451644+(b*112|0)>>2];c[a+104>>2]=c[3451648+(b*112|0)>>2];c[a+108>>2]=c[3451652+(b*112|0)>>2];d=0;return d|0}function eUh(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=3451544+(b*112|0);e=0;return e|0}function eUi(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4988092+(b*112|0)>>2];c[a+104>>2]=c[4988096+(b*112|0)>>2];c[a+108>>2]=c[4988100+(b*112|0)>>2];d=0;return d|0}function eUj(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<21&(d|0)==0)){e=1;return e|0}c[a>>2]=4987992+(b*112|0);e=0;return e|0}function eUk(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>29){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1695328+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eUl(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>35){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4990344+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eUm(){var b=0,d=0,e=0,f=0,g=0;a[7461624]=1;b=eOx()|0;if((b|0)!=0){return b|0}if((c[2394]|0)==0){d=c[2112932]|0;e=c[3532592]|0}else{c[2394]=0;f=c[3532596]|0;c[2112932]=f;g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060];d=f;e=g}c[d+196648>>2]=2798;c[d+196608>>2]=536;c[d+196688>>2]=666;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;return b|0}function eUn(){a[9750552]=0;eOI()|0;return 0}function eUo(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=i;i=i+16|0;e=d|0;if((b|0)!=0){c[b>>2]=169568}if((a&64|0)==0){f=eOS(a,b)|0;i=d;return 0}gGz(e|0,0,12);c[e>>2]=9750552;c[e+4>>2]=1;c[e+12>>2]=294808;gj[c[2076592]&4095](e)|0;f=eOS(a,b)|0;i=d;return 0}function eUp(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>4){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4978156+(b*112|0)>>2];c[a+104>>2]=c[4978160+(b*112|0)>>2];c[a+108>>2]=c[4978164+(b*112|0)>>2];d=0;return d|0}function eUq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<5&(d|0)==0)){e=1;return e|0}c[a>>2]=4978056+(b*112|0);e=0;return e|0}function eUr(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1690416+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eUs(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4978616+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eUt(){var b=0;c[3532512]=11172;b=eOx()|0;a[7461584]=1;c[3532338]=41;return b|0}function eUu(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3413188+(b*112|0)>>2];c[a+104>>2]=c[3413192+(b*112|0)>>2];c[a+108>>2]=c[3413196+(b*112|0)>>2];d=0;return d|0}function eUv(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=3413088+(b*112|0);e=0;return e|0}function eUw(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>57){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3415216+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eUx(){var a=0,b=0,d=0,e=0,f=0;a=eOx()|0;if((a|0)!=0){return a|0}if((c[2394]|0)==0){b=c[2112932]|0;d=c[3532592]|0}else{c[2394]=0;e=c[3532596]|0;c[2112932]=e;f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];b=e;d=f}c[b+70196>>2]=1;c[b+196652>>2]=3366;c[b+50208>>2]=2;c[b+196696>>2]=3106;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;return a|0}function eUy(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3331980+(b*112|0)>>2];c[a+104>>2]=c[3331984+(b*112|0)>>2];c[a+108>>2]=c[3331988+(b*112|0)>>2];d=0;return d|0}function eUz(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=3331880+(b*112|0);e=0;return e|0}function eUA(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4932860+(b*112|0)>>2];c[a+104>>2]=c[4932864+(b*112|0)>>2];c[a+108>>2]=c[4932868+(b*112|0)>>2];d=0;return d|0}function eUB(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=4932760+(b*112|0);e=0;return e|0}function eUC(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>43){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6036680+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eUD(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4931852+(b*112|0)>>2];c[a+104>>2]=c[4931856+(b*112|0)>>2];c[a+108>>2]=c[4931860+(b*112|0)>>2];d=0;return d|0}function eUE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=4931752+(b*112|0);e=0;return e|0}function eUF(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3321660+(b*112|0)>>2];c[a+104>>2]=c[3321664+(b*112|0)>>2];c[a+108>>2]=c[3321668+(b*112|0)>>2];d=0;return d|0}function eUG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=3321560+(b*112|0);e=0;return e|0}function eUH(){var b=0,d=0,e=0,f=0,g=0;b=eOx()|0;c[3532376]=114;if((b|0)!=0){return b|0}if((c[2394]|0)==0){d=c[2112932]|0;e=c[3532592]|0}else{c[2394]=0;f=c[3532596]|0;c[2112932]=f;g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060];d=f;e=g}c[d+82304>>2]=1;c[d+196732>>2]=1762;c[d+115744>>2]=2;c[d+196656>>2]=142;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;a[64248]=1;return b|0}function eUI(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3304612+(b*112|0)>>2];c[a+104>>2]=c[3304616+(b*112|0)>>2];c[a+108>>2]=c[3304620+(b*112|0)>>2];d=0;return d|0}function eUJ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=3304512+(b*112|0);e=0;return e|0}function eUK(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>79){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3306640+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eUL(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a[7461624]=1;c[3532380]=262144;b=eOx()|0;if((b|0)==0){d=0}else{e=b;return e|0}while(1){if((d|0)>=1024){f=1;g=0;break}h=9638528+(d<<2)|0;if((c[h>>2]|0)==0){i=29066;break}else{d=d+1|0}}do{if((i|0)==29066){d=gGq(524288)|0;c[h>>2]=d;if((d|0)==0){f=1;g=0;break}gGz(d|0,0,524288);b=c[3532374]|0;gGC(d|0,b|0,262144)|0;gGz(b|0,0,524288);gGC(b|0,d|0,131072)|0;j=b+131072|0;k=d+65536|0;gGC(j|0,k|0,131072)|0;k=b+262144|0;j=d+131072|0;gGC(k|0,j|0,131072)|0;j=b+393216|0;b=d+196608|0;gGC(j|0,b|0,131072)|0;f=0;g=d}}while(0);h=0;while(1){if((h|0)>=1024){e=f;i=29075;break}l=9638528+(h<<2)|0;if((c[l>>2]|0)==(g|0)){break}else{h=h+1|0}}if((i|0)==29075){return e|0}gGr(g);c[l>>2]=0;e=f;return e|0}function eUM(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3295820+(b*112|0)>>2];c[a+104>>2]=c[3295824+(b*112|0)>>2];c[a+108>>2]=c[3295828+(b*112|0)>>2];d=0;return d|0}function eUN(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=3295720+(b*112|0);e=0;return e|0}function eUO(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>50){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3297400+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eUP(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;a=eOx()|0;if((a|0)!=0){return a|0}if((c[2394]|0)==0){b=c[2112932]|0;d=c[3532592]|0}else{c[2394]=0;e=c[3532596]|0;c[2112932]=e;f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];b=e;d=f}c[b+196608>>2]=3292;c[b+196648>>2]=3320;f=c[3532470]|0;c[b+65280>>2]=f;c[b+130816>>2]=f;c[b+196352>>2]=f;e=f+1024|0;c[b+65284>>2]=e;c[b+130820>>2]=e;c[b+196356>>2]=e;g=f+2048|0;c[b+65288>>2]=g;c[b+130824>>2]=g;c[b+196360>>2]=g;h=f+3072|0;c[b+65292>>2]=h;c[b+130828>>2]=h;c[b+196364>>2]=h;i=f+4096|0;c[b+65296>>2]=i;c[b+130832>>2]=i;c[b+196368>>2]=i;j=f+5120|0;c[b+65300>>2]=j;c[b+130836>>2]=j;c[b+196372>>2]=j;k=f+6144|0;c[b+65304>>2]=k;c[b+130840>>2]=k;c[b+196376>>2]=k;l=f+7168|0;c[b+65308>>2]=l;c[b+130844>>2]=l;c[b+196380>>2]=l;m=f+8192|0;c[b+65312>>2]=m;c[b+130848>>2]=m;c[b+196384>>2]=m;n=f+9216|0;c[b+65316>>2]=n;c[b+130852>>2]=n;c[b+196388>>2]=n;o=f+10240|0;c[b+65320>>2]=o;c[b+130856>>2]=o;c[b+196392>>2]=o;p=f+11264|0;c[b+65324>>2]=p;c[b+130860>>2]=p;c[b+196396>>2]=p;q=f+12288|0;c[b+65328>>2]=q;c[b+130864>>2]=q;c[b+196400>>2]=q;r=f+13312|0;c[b+65332>>2]=r;c[b+130868>>2]=r;c[b+196404>>2]=r;s=f+14336|0;c[b+65336>>2]=s;c[b+130872>>2]=s;c[b+196408>>2]=s;t=f+15360|0;c[b+65340>>2]=t;c[b+130876>>2]=t;c[b+196412>>2]=t;c[b+65344>>2]=f;c[b+130880>>2]=f;c[b+196416>>2]=f;c[b+65348>>2]=e;c[b+130884>>2]=e;c[b+196420>>2]=e;c[b+65352>>2]=g;c[b+130888>>2]=g;c[b+196424>>2]=g;c[b+65356>>2]=h;c[b+130892>>2]=h;c[b+196428>>2]=h;c[b+65360>>2]=i;c[b+130896>>2]=i;c[b+196432>>2]=i;c[b+65364>>2]=j;c[b+130900>>2]=j;c[b+196436>>2]=j;c[b+65368>>2]=k;c[b+130904>>2]=k;c[b+196440>>2]=k;c[b+65372>>2]=l;c[b+130908>>2]=l;c[b+196444>>2]=l;c[b+65376>>2]=m;c[b+130912>>2]=m;c[b+196448>>2]=m;c[b+65380>>2]=n;c[b+130916>>2]=n;c[b+196452>>2]=n;c[b+65384>>2]=o;c[b+130920>>2]=o;c[b+196456>>2]=o;c[b+65388>>2]=p;c[b+130924>>2]=p;c[b+196460>>2]=p;c[b+65392>>2]=q;c[b+130928>>2]=q;c[b+196464>>2]=q;c[b+65396>>2]=r;c[b+130932>>2]=r;c[b+196468>>2]=r;c[b+65400>>2]=s;c[b+130936>>2]=s;c[b+196472>>2]=s;c[b+65404>>2]=t;c[b+130940>>2]=t;c[b+196476>>2]=t;c[b+65408>>2]=f;c[b+130944>>2]=f;c[b+196480>>2]=f;c[b+65412>>2]=e;c[b+130948>>2]=e;c[b+196484>>2]=e;c[b+65416>>2]=g;c[b+130952>>2]=g;c[b+196488>>2]=g;c[b+65420>>2]=h;c[b+130956>>2]=h;c[b+196492>>2]=h;c[b+65424>>2]=i;c[b+130960>>2]=i;c[b+196496>>2]=i;c[b+65428>>2]=j;c[b+130964>>2]=j;c[b+196500>>2]=j;c[b+65432>>2]=k;c[b+130968>>2]=k;c[b+196504>>2]=k;c[b+65436>>2]=l;c[b+130972>>2]=l;c[b+196508>>2]=l;c[b+65440>>2]=m;c[b+130976>>2]=m;c[b+196512>>2]=m;c[b+65444>>2]=n;c[b+130980>>2]=n;c[b+196516>>2]=n;c[b+65448>>2]=o;c[b+130984>>2]=o;c[b+196520>>2]=o;c[b+65452>>2]=p;c[b+130988>>2]=p;c[b+196524>>2]=p;c[b+65456>>2]=q;c[b+130992>>2]=q;c[b+196528>>2]=q;c[b+65460>>2]=r;c[b+130996>>2]=r;c[b+196532>>2]=r;c[b+65464>>2]=s;c[b+131e3>>2]=s;c[b+196536>>2]=s;c[b+65468>>2]=t;c[b+131004>>2]=t;c[b+196540>>2]=t;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;return a|0}function eUQ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6660364+(b*112|0)>>2];c[a+104>>2]=c[6660368+(b*112|0)>>2];c[a+108>>2]=c[6660372+(b*112|0)>>2];d=0;return d|0}function eUR(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=6660264+(b*112|0);e=0;return e|0}function eUS(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>56){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6662168+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eUT(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c[3532588]=4372;c[3532512]=8090;c[3532380]=393216;a=eOx()|0;if((a|0)==0){b=0}else{d=a;return d|0}while(1){if((b|0)>=1024){e=1;f=0;break}g=9638528+(b<<2)|0;if((c[g>>2]|0)==0){h=29129;break}else{b=b+1|0}}do{if((h|0)==29129){b=gGq(917504)|0;c[g>>2]=b;if((b|0)==0){e=1;f=0;break}gGz(b|0,0,917504);a=c[3532374]|0;gGC(b|0,a|0,524288)|0;gGz(a|0,0,917504);gGC(a|0,b|0,131072)|0;i=a+262144|0;j=b+131072|0;gGC(i|0,j|0,131072)|0;j=a+524288|0;i=b+262144|0;gGC(j|0,i|0,131072)|0;i=a+786432|0;a=b+393216|0;gGC(i|0,a|0,131072)|0;e=0;f=b}}while(0);g=0;while(1){if((g|0)>=1024){d=e;h=29138;break}k=9638528+(g<<2)|0;if((c[k>>2]|0)==(f|0)){break}else{g=g+1|0}}if((h|0)==29138){return d|0}gGr(f);c[k>>2]=0;d=e;return d|0}function eUU(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6024348+(b*112|0)>>2];c[a+104>>2]=c[6024352+(b*112|0)>>2];c[a+108>>2]=c[6024356+(b*112|0)>>2];d=0;return d|0}function eUV(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<21&(d|0)==0)){e=1;return e|0}c[a>>2]=6024248+(b*112|0);e=0;return e|0}function eUW(){c[3532588]=4372;c[3532512]=8090;return eOx()|0}function eUX(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7366284+(b*112|0)>>2];c[a+104>>2]=c[7366288+(b*112|0)>>2];c[a+108>>2]=c[7366292+(b*112|0)>>2];d=0;return d|0}function eUY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=7366184+(b*112|0);e=0;return e|0}function eUZ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>52){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7367864+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eU_(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c[3532588]=8758;c[3532380]=393216;a=eOx()|0;if((a|0)==0){b=0}else{d=a;return d|0}while(1){if((b|0)>=1024){e=1;f=0;break}g=9638528+(b<<2)|0;if((c[g>>2]|0)==0){h=29174;break}else{b=b+1|0}}do{if((h|0)==29174){b=gGq(917504)|0;c[g>>2]=b;if((b|0)==0){e=1;f=0;break}gGz(b|0,0,917504);a=c[3532374]|0;gGC(b|0,a|0,524288)|0;gGz(a|0,0,917504);gGC(a|0,b|0,131072)|0;i=a+262144|0;j=b+131072|0;gGC(i|0,j|0,131072)|0;j=a+524288|0;i=b+262144|0;gGC(j|0,i|0,131072)|0;i=a+786432|0;a=b+393216|0;gGC(i|0,a|0,131072)|0;e=0;f=b}}while(0);g=0;while(1){if((g|0)>=1024){d=e;h=29183;break}k=9638528+(g<<2)|0;if((c[k>>2]|0)==(f|0)){break}else{g=g+1|0}}if((h|0)==29183){return d|0}gGr(f);c[k>>2]=0;d=e;return d|0}function eU$(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7104740+(b*112|0)>>2];c[a+104>>2]=c[7104744+(b*112|0)>>2];c[a+108>>2]=c[7104748+(b*112|0)>>2];d=0;return d|0}function eU0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=7104640+(b*112|0);e=0;return e|0}function eU1(){var a=0,b=0,d=0,e=0,f=0;a=eOx()|0;if((a|0)!=0){return a|0}if((c[2394]|0)==0){b=c[2112932]|0;d=c[3532592]|0}else{c[2394]=0;e=c[3532596]|0;c[2112932]=e;f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];b=e;d=f}c[b+122624>>2]=1;c[b+196652>>2]=154;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;return a|0}function eU2(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7103060+(b*112|0)>>2];c[a+104>>2]=c[7103064+(b*112|0)>>2];c[a+108>>2]=c[7103068+(b*112|0)>>2];d=0;return d|0}function eU3(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=7102960+(b*112|0);e=0;return e|0}function eU4(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c[3532380]=393216;a=eOx()|0;if((a|0)!=0){b=a;return b|0}if((c[2394]|0)==0){d=c[2112932]|0;e=c[3532592]|0}else{c[2394]=0;a=c[3532596]|0;c[2112932]=a;f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];d=a;e=f}c[d+122624>>2]=1;c[d+196652>>2]=154;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;e=0;while(1){if((e|0)>=1024){g=1;h=0;break}i=9638528+(e<<2)|0;if((c[i>>2]|0)==0){j=29231;break}else{e=e+1|0}}do{if((j|0)==29231){e=gGq(917504)|0;c[i>>2]=e;if((e|0)==0){g=1;h=0;break}gGz(e|0,0,917504);d=c[3532374]|0;gGC(e|0,d|0,524288)|0;gGz(d|0,0,917504);gGC(d|0,e|0,131072)|0;f=d+262144|0;a=e+131072|0;gGC(f|0,a|0,131072)|0;a=d+524288|0;f=e+262144|0;gGC(a|0,f|0,131072)|0;f=d+786432|0;d=e+393216|0;gGC(f|0,d|0,131072)|0;g=0;h=e}}while(0);i=0;while(1){if((i|0)>=1024){b=g;j=29239;break}k=9638528+(i<<2)|0;if((c[k>>2]|0)==(h|0)){break}else{i=i+1|0}}if((j|0)==29239){return b|0}gGr(h);c[k>>2]=0;b=g;return b|0}function eU5(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7101380+(b*112|0)>>2];c[a+104>>2]=c[7101384+(b*112|0)>>2];c[a+108>>2]=c[7101388+(b*112|0)>>2];d=0;return d|0}function eU6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=7101280+(b*112|0);e=0;return e|0}function eU7(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3231468+(b*112|0)>>2];c[a+104>>2]=c[3231472+(b*112|0)>>2];c[a+108>>2]=c[3231476+(b*112|0)>>2];d=0;return d|0}function eU8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=3231368+(b*112|0);e=0;return e|0}function eU9(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>51){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3233944+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eVa(){c[3532588]=6558;c[3532512]=10068;c[3532546]=4020;return eOx()|0}function eVb(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1642604+(b*112|0)>>2];c[a+104>>2]=c[1642608+(b*112|0)>>2];c[a+108>>2]=c[1642612+(b*112|0)>>2];d=0;return d|0}function eVc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=1642504+(b*112|0);e=0;return e|0}function eVd(){c[3532512]=10068;c[3532546]=4020;return eOx()|0}function eVe(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1640028+(b*112|0)>>2];c[a+104>>2]=c[1640032+(b*112|0)>>2];c[a+108>>2]=c[1640036+(b*112|0)>>2];d=0;return d|0}function eVf(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=1639928+(b*112|0);e=0;return e|0}function eVg(b){b=b|0;var d=0,e=0;if((b|0)==15204353){d=(c[2439486]|0)+1|0;c[2439486]=d;e=a[9773296]^a[(c[3532446]|0)+(((c[2385544]|0)-1&d)+1048576^1)|0]}else if((b|0)==12853251){e=a[14130177]|0}else if((b|0)==12849159){e=~a[14130138]}else if((b|0)==15204355){e=a[14130178]|0}else if((b|0)==12849153){e=~a[14130136]}else if((b|0)==12849155){e=~a[14130137]}else if((b|0)==12853249){e=a[14130176]|0}else{e=-1}return e|0}function eVh(e,f){e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;g=e-4194304|0;if(g>>>0<65536){eOY(g^1,f);return}if((e|0)==4136963){g=f&7;if((c[3532359]|0)==(g|0)){return}c[3532359]=g;a[7461568]=1;a[7461576]=1;a[7461552]=1;a[7461560]=1;return}else if((e|0)==14680067){c[2385804]=f&255;return}else if((e|0)==16646151){c[3532412]=f&255;g=c[2439330]|0;h=(g|0)==0;if(!h){i=g;gGC(9706056,i|0,76)|0}b[4853030]=c[2426515]&65535;i=c[2438118]|0;c[2433530]=i;j=c[3528484]|0;c[2076596]=j;k=c[2417276]|0;c[3541536]=k;c[1836236]=0;a[9706117]=1;if(!h){h=g;gGC(h|0,9706056,76)|0}c[2438118]=i;c[3528484]=j;c[2417276]=k;c[1836236]=-1;return}else if((e|0)==14680065){k=c[2385804]|0;j=k&15;if((j|0)==0){l=2097151;m=c[3532374]|0}else if((j|0)==1){l=1048575;m=c[3532370]|0}else if((j|0)==2){l=262143;m=c[3532330]|0}else if((j|0)==3){l=1048575;m=(c[3532446]|0)+3145728|0}else{l=0;m=0}L38457:do{if((k&16|0)==0){switch(k&224|0){case 0:{n=(f&255)>>>7<<6|f<<7|(f&255)>>>1&1|(f&255)>>>6<<5&32|(f&255)>>>5<<4&16|(f&255)>>>4<<3&8|(f&255)>>>3<<2&4|(f&255)>>>2<<1&2;break L38457;break};case 64:{n=(f&255)>>>6<<7|(f&255)>>>7|f<<1&2|(f&255)>>>5<<6&64|(f&255)>>>4<<5&32|(f&255)>>>3<<4&16|(f&255)>>>2<<3&8|(f&255)>>>1<<2&4;break L38457;break};case 96:{n=f<<2&4|(f&255)>>>5<<7|(f&255)>>>7<<1|(f&255)>>>6&1|(f&255)>>>4<<6&64|(f&255)>>>3<<5&32|(f&255)>>>2<<4&16|(f&255)>>>1<<3&8;break L38457;break};case 128:{n=f<<3&8|(f&255)>>>4<<7|(f&255)>>>7<<2|(f&255)>>>5&1|(f&255)>>>3<<6&64|(f&255)>>>2<<5&32|(f&255)>>>1<<4&16|(f&255)>>>6<<1&2;break L38457;break};case 160:{n=f<<4&16|(f&255)>>>3<<7|(f&255)>>>7<<3|(f&255)>>>4&1|(f&255)>>>2<<6&64|(f&255)>>>1<<5&32|(f&255)>>>6<<2&4|(f&255)>>>5<<1&2;break L38457;break};case 192:{n=f<<5&32|(f&255)>>>2<<7|(f&255)>>>7<<4|(f&255)>>>3&1|(f&255)>>>1<<6&64|(f&255)>>>6<<3&8|(f&255)>>>5<<2&4|(f&255)>>>4<<1&2;break L38457;break};case 224:{n=(f&255)>>>1<<7|f<<6&64|(f&255)>>>7<<5|(f&255)>>>2&1|(f&255)>>>6<<4&16|(f&255)>>>5<<3&8|(f&255)>>>4<<2&4|(f&255)>>>3<<1&2;break L38457;break};default:{n=f;break L38457}}}else{n=f}}while(0);if((m|0)==0){return}k=a[9543224]|0;do{if((k&4)==0){o=1;p=n}else{if((c[2437704]|0)!=0){c[2437704]=0;o=(n&255)+2|0;p=a[9773288]|0;break}j=a[687288]|0;if(j<<24>>24==8){a[9718944]=n;a[687288]=0;return}if(((d[9718944]|0)&128>>>((j&255)>>>0)|0)==0){a[9773288]=n;c[2437704]=1}a[687288]=j+1&255;o=1;p=n}}while(0);n=c[3532352]|0;j=c[3532370]|0;i=c[3532350]|0;h=1;g=k;while(1){k=((g&8)==0?268435455:1)+(c[2385808]|0)|0;q=k&268435455;c[2385808]=q;r=g&3;if((r|0)==3){s=a[m+(k&l)|0]&p}else if((r|0)==0){s=p}else if((r|0)==1){s=a[m+(k&l)|0]^p}else if((r|0)==2){s=a[m+(k&l)|0]|p}else{s=0}r=c[2385804]|0;L38492:do{if((r&16|0)==0){t=s}else{switch(r&224|0){case 64:{t=(s&255)>>>6<<7|(s&255)>>>7|s<<1&2|(s&255)>>>5<<6&64|(s&255)>>>4<<5&32|(s&255)>>>3<<4&16|(s&255)>>>2<<3&8|(s&255)>>>1<<2&4;break L38492;break};case 96:{t=s<<2&4|(s&255)>>>5<<7|(s&255)>>>7<<1|(s&255)>>>6&1|(s&255)>>>4<<6&64|(s&255)>>>3<<5&32|(s&255)>>>2<<4&16|(s&255)>>>1<<3&8;break L38492;break};case 192:{t=s<<5&32|(s&255)>>>2<<7|(s&255)>>>7<<4|(s&255)>>>3&1|(s&255)>>>1<<6&64|(s&255)>>>6<<3&8|(s&255)>>>5<<2&4|(s&255)>>>4<<1&2;break L38492;break};case 224:{t=(s&255)>>>1<<7|s<<6&64|(s&255)>>>7<<5|(s&255)>>>2&1|(s&255)>>>6<<4&16|(s&255)>>>5<<3&8|(s&255)>>>4<<2&4|(s&255)>>>3<<1&2;break L38492;break};case 128:{t=s<<3&8|(s&255)>>>4<<7|(s&255)>>>7<<2|(s&255)>>>5&1|(s&255)>>>3<<6&64|(s&255)>>>2<<5&32|(s&255)>>>1<<4&16|(s&255)>>>6<<1&2;break L38492;break};case 160:{t=s<<4&16|(s&255)>>>3<<7|(s&255)>>>7<<3|(s&255)>>>4&1|(s&255)>>>2<<6&64|(s&255)>>>1<<5&32|(s&255)>>>6<<2&4|(s&255)>>>5<<1&2;break L38492;break};case 0:{t=(s&255)>>>7<<6|s<<7|(s&255)>>>1&1|(s&255)>>>6<<5&32|(s&255)>>>5<<4&16|(s&255)>>>4<<3&8|(s&255)>>>3<<2&4|(s&255)>>>2<<1&2;break L38492;break};default:{t=s;break L38492}}}}while(0);do{if((r&15|0)==1){if(q>>>0>=n>>>0){break}a[m+q|0]=t;u=(c[2385808]|0)>>>3<<6&1048512;gGz(i+u|0,0,64);v=u|2097152;w=0;do{x=v+(c[1238464+(w<<2)>>2]|0)|0;y=(w<<3)+u|0;z=0;do{A=x+(c[614800+(z<<2)>>2]|0)|0;if(((d[j+((A|0)/8|0)|0]|0)&128>>>((A&7)>>>0)|0)!=0){A=i+(y+z)|0;a[A]=a[A]|4}z=z+1|0;}while((z|0)<8);w=w+1|0;}while((w|0)<8);w=u|1048576;v=0;while(1){z=w+(c[1238464+(v<<2)>>2]|0)|0;y=(v<<3)+u|0;x=0;do{A=z+(c[614800+(x<<2)>>2]|0)|0;if(((d[j+((A|0)/8|0)|0]|0)&128>>>((A&7)>>>0)|0)!=0){A=i+(y+x)|0;a[A]=a[A]|2}x=x+1|0;}while((x|0)<8);x=v+1|0;if((x|0)<8){v=x}else{B=0;break}}do{v=u+(c[1238464+(B<<2)>>2]|0)|0;w=(B<<3)+u|0;x=0;do{y=v+(c[614800+(x<<2)>>2]|0)|0;if(((d[j+((y|0)/8|0)|0]|0)&128>>>((y&7)>>>0)|0)!=0){y=i+(w+x)|0;a[y]=a[y]|1}x=x+1|0;}while((x|0)<8);B=B+1|0;}while((B|0)<8)}else{a[m+(k&l)|0]=t}}while(0);if((h|0)>=(o|0)){break}h=h+1|0;g=a[9543224]|0}return}else if((e|0)==16646153){if((f<<24>>24|0)==0){g=c[2439330]|0;h=(g|0)==0;if(!h){o=g;gGC(9706056,o|0,76)|0}o=c[2438118]|0;c[2433530]=o;t=c[3528484]|0;c[2076596]=t;l=c[2417276]|0;c[3541536]=l;c[1836236]=0;gGz(9706056,0,76);if(!h){h=g;gGC(h|0,9706056,76)|0}c[2438118]=o;c[3528484]=t;c[2417276]=l;c[1836236]=-1;a[7461512]=1;return}else if((f<<24>>24|0)==1){l=c[2439330]|0;t=(l|0)==0;if(!t){o=l;gGC(9706056,o|0,76)|0}o=c[2438118]|0;c[2433530]=o;h=c[3528484]|0;c[2076596]=h;g=c[2417276]|0;c[3541536]=g;c[1836236]=0;gGz(9706056,0,76);if(!t){t=l;gGC(t|0,9706056,76)|0}c[2438118]=o;c[3528484]=h;c[2417276]=g;c[1836236]=-1;a[7461512]=0;return}else{return}}else if((e|0)==4128769){g=f&7;if((c[3532358]|0)==(g|0)){return}c[3532358]=g;a[7461568]=1;a[7461576]=1;a[7461552]=1;a[7461560]=1;return}else if((e|0)==4128771){g=f&7;if((c[3532359]|0)==(g|0)){return}c[3532359]=g;a[7461568]=1;a[7461576]=1;a[7461552]=1;a[7461560]=1;return}else if((e|0)==4136961){g=f&7;if((c[3532358]|0)==(g|0)){return}c[3532358]=g;a[7461568]=1;a[7461576]=1;a[7461552]=1;a[7461560]=1;return}else if((e|0)==12845057){g=f&255;c[3532340]=g&32;c[3532422]=g&64;return}else if((e|0)==16646155){e=c[3532446]|0;g=c[2112932]|0;f=0;while(1){h=e+(f+3145728)|0;c[g>>2]=h;c[g+131072>>2]=h;h=f+1024|0;if(h>>>0>1048575){break}else{g=g+4|0;f=h}}c[2439496]=1;return}else{return}}function eVi(a){a=a|0;var b=0;if((a|0)==15204360){b=(c[2439484]|0)>>>16&65535}else if((a|0)==15204362){b=c[2439484]&65535}else{b=-1}return b|0}function eVj(d,f){d=d|0;f=f|0;var g=0;g=d-4194304|0;if(g>>>0<65536){eOX(g,f);return}if((d|0)==14680068){b[4877416]=f;return}else if((d|0)==14680070){g=b[4877416]|0;a[9543224]=(g&65535)>>>12&255;c[2385808]=(g&65535)<<16&268369920|f&65535;a[687288]=8;a[9718944]=0;c[2437704]=0;return}else if((d|0)==15204356){b[4860380]=f;return}else if((d|0)==15204358){c[2439486]=(e[4860380]|0)<<16|f&65535;return}else if((d|0)==15204360){b[4860376]=f;return}else if((d|0)==15204362){d=(e[4860376]|0)<<16|f&65535;c[2439484]=d;f=c[3541240]|0;if((f|0)==0){return}c[2439484]=gj[f&4095](d)|0;return}else{return}}function eVk(a,b){a=a|0;b=b|0;var d=0,e=0;d=(b|0)==0;b=d?6874088:0;if(!d){e=1;return e|0}if((a|0)==0){e=0;return e|0}c[a+100>>2]=c[b+100>>2];c[a+104>>2]=c[b+104>>2];c[a+108>>2]=c[b+108>>2];e=0;return e|0}function eVl(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((d|b|0)!=0){e=1;return e|0}c[a>>2]=(b|0)==0?6874088:0;e=0;return e|0}function eVm(){var a=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;a=i;i=i+240|0;d=a|0;e=a+112|0;f=a+120|0;g=a+232|0;c[3532430]=4194304;c[3532352]=393216;c[3532380]=2097152;c[3532344]=196608;c[3532512]=2368;h=eOx()|0;if((h|0)==0){gGz(c[3532446]|0,0,4194304);j=0;while(1){if((j|0)>=1024){k=0;break}l=9638528+(j<<2)|0;if((c[l>>2]|0)==0){m=29460;break}else{j=j+1|0}}do{if((m|0)==29460){j=gGq(131072)|0;c[l>>2]=j;if((j|0)==0){k=0;break}gGz(j|0,0,131072);k=j}}while(0);l=k;gGz(k|0,0,131072);j=c[3532446]|0;n=j;if((c[3542200]|0)==0){o=1;i=a;return o|0}p=f+108|0;c[p>>2]=0;q=f+100|0;c[q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,128)|0;do{if((c[p>>2]|0)==0){r=0}else{f=c[q>>2]|0;c[g>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](g,128,0)|0;if((f|0)<1){o=1;i=a;return o|0}if((gzL(j,0,128)|0)==0){r=0;break}else{o=1}i=a;return o|0}}while(0);do{g=b[n+(r<<1)>>1]|0;b[l+((r^16679)<<1)>>1]=g&17416|(g&65535)>>>15|(g&65535)>>>6<<15|g<<8&256|(g&65535)>>>4<<13&8192|(g&65535)>>>2<<12&4096|(g&65535)>>>12<<11&2048|(g&65535)>>>8<<9&512|(g&65535)>>>1<<7&128|(g&65535)>>>9<<6&64|(g&65535)>>>11<<5&32|(g&65535)>>>13<<4&16|(g&65535)>>>5<<2&4|(g&65535)>>>7<<1&2;r=r+1|0;}while(r>>>0<65536);gGC(j|0,k|0,131072)|0;j=0;while(1){if((j|0)>=1024){break}t=9638528+(j<<2)|0;if((c[t>>2]|0)==(k|0)){m=29470;break}else{j=j+1|0}}if((m|0)==29470){gGr(k);c[t>>2]=0}t=(c[3532446]|0)+1048576|0;if((c[3542200]|0)==0){o=1;i=a;return o|0}k=d+108|0;c[k>>2]=0;j=d+100|0;c[j>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](d,0)|0;do{if((c[k>>2]|0)!=0){d=c[j>>2]|0;c[e>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](e,0,0)|0;if((d|0)<1){o=1;i=a;return o|0}if((gzL(t,0,0)|0)==0){break}else{o=1}i=a;return o|0}}while(0);t=c[3532352]|0;e=0;while(1){if((e|0)>=1024){u=0;break}v=9638528+(e<<2)|0;if((c[v>>2]|0)==0){m=29478;break}else{e=e+1|0}}do{if((m|0)==29478){e=gGq(t)|0;c[v>>2]=e;if((e|0)==0){u=0;break}gGz(e|0,0,t|0);u=e}}while(0);c[3532370]=u;t=c[3532352]|0;gGz(u|0,0,t|0);gGz(c[3532350]|0,0,c[3532508]<<6|0);gGz(c[3532374]|0,0,t|0);c[3532348]=(c[3532330]|0)+65536;w=0}else{w=h}c[3532554]=16e6;o=w;i=a;return o|0}function eVn(){var d=0,e=0,f=0,g=0;eOI()|0;d=c[3532370]|0;e=0;while(1){if((e|0)>=1024){break}f=9638528+(e<<2)|0;if((c[f>>2]|0)==(d|0)){g=29493;break}else{e=e+1|0}}if((g|0)==29493){gGr(d);c[f>>2]=0}c[3532370]=0;b[4860380]=0;c[2439486]=0;c[2385804]=0;c[2385808]=0;a[9543224]=0;b[4877416]=0;c[2439484]=0;b[4860376]=0;a[687288]=0;a[9718944]=0;c[2437704]=0;a[9773288]=0;a[9773296]=0;c[2385544]=0;c[3541240]=0;c[2439496]=0;return 0}function eVo(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;f=i;i=i+224|0;g=f|0;h=f+16|0;j=f+32|0;k=f+48|0;l=f+64|0;m=f+80|0;n=f+96|0;o=f+112|0;p=f+128|0;q=f+144|0;r=f+160|0;s=f+176|0;t=f+192|0;u=f+208|0;v=u|0;w=u;if((e|0)!=0){c[e>>2]=169753}if((b&64|0)==0){x=eOS(b,e)|0;i=f;return 0}c[v>>2]=0;c[v+4>>2]=0;y=u;c[y>>2]=c[3532374];z=w+4|0;c[z>>2]=(c[3532380]|0)-1;A=u+8|0;c[A>>2]=0;u=w+12|0;c[u>>2]=409192;gj[c[2076592]&4095](w)|0;c[v>>2]=0;c[v+4>>2]=0;c[y>>2]=c[3532370];c[z>>2]=(c[3532352]|0)-1;c[A>>2]=0;c[u>>2]=408456;gj[c[2076592]&4095](w)|0;c[v>>2]=0;c[v+4>>2]=0;c[y>>2]=c[3532330];c[z>>2]=262143;c[A>>2]=0;c[u>>2]=407768;gj[c[2076592]&4095](w)|0;c[v>>2]=0;c[v+4>>2]=0;c[y>>2]=(c[3532446]|0)+3145728;c[z>>2]=1048575;c[A>>2]=0;c[u>>2]=407e3;gj[c[2076592]&4095](w)|0;gGz(t|0,0,12);c[t>>2]=9720760;c[t+4>>2]=2;c[t+12>>2]=405792;gj[c[2076592]&4095](t)|0;gGz(s|0,0,12);c[s>>2]=9757944;c[s+4>>2]=4;c[s+12>>2]=404424;gj[c[2076592]&4095](s)|0;gGz(r|0,0,12);c[r>>2]=9543216;c[r+4>>2]=4;c[r+12>>2]=403328;gj[c[2076592]&4095](r)|0;gGz(q|0,0,12);c[q>>2]=9543232;c[q+4>>2]=4;c[q+12>>2]=401944;gj[c[2076592]&4095](q)|0;gGz(p|0,0,12);c[p>>2]=9543224;c[p+4>>2]=1;c[p+12>>2]=401e3;gj[c[2076592]&4095](p)|0;gGz(o|0,0,12);c[o>>2]=9754832;c[o+4>>2]=2;c[o+12>>2]=400032;gj[c[2076592]&4095](o)|0;gGz(n|0,0,12);c[n>>2]=9757936;c[n+4>>2]=4;c[n+12>>2]=399288;gj[c[2076592]&4095](n)|0;gGz(m|0,0,12);c[m>>2]=9720752;c[m+4>>2]=2;c[m+12>>2]=398328;gj[c[2076592]&4095](m)|0;gGz(l|0,0,12);c[l>>2]=687288;c[l+4>>2]=1;c[l+12>>2]=397576;gj[c[2076592]&4095](l)|0;gGz(k|0,0,12);c[k>>2]=9718944;c[k+4>>2]=1;c[k+12>>2]=396472;gj[c[2076592]&4095](k)|0;gGz(j|0,0,12);c[j>>2]=9750816;c[j+4>>2]=4;c[j+12>>2]=394864;gj[c[2076592]&4095](j)|0;gGz(h|0,0,12);c[h>>2]=9773288;c[h+4>>2]=1;c[h+12>>2]=393616;gj[c[2076592]&4095](h)|0;gGz(g|0,0,12);c[g>>2]=9757984;c[g+4>>2]=4;c[g+12>>2]=392048;gj[c[2076592]&4095](g)|0;if((b&2|0)==0){x=eOS(b,e)|0;i=f;return 0}if((c[2439496]|0)!=0){if((c[2394]|0)==0){B=c[2112932]|0}else{c[2394]=0;g=c[3532596]|0;c[2112932]=g;h=c[3532592]|0;if((h|0)!=0){gGC(9104152,h|0,280)|0}c[2113054]=c[2113060];B=g}g=c[3532446]|0;h=B|0;B=0;while(1){j=g+(B+3145728)|0;c[h>>2]=j;c[h+131072>>2]=j;j=B+1024|0;if(j>>>0>1048575){break}else{h=h+4|0;B=j}}B=c[3532592]|0;if((B|0)!=0){gGC(B|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1}B=c[3532352]|0;if((B|0)==0){x=eOS(b,e)|0;i=f;return 0}h=c[3532370]|0;g=c[3532350]|0;j=0;do{k=j>>>3<<6&1048512;gGz(g+k|0,0,64);l=k|2097152;m=0;do{n=l+(c[1238464+(m<<2)>>2]|0)|0;o=(m<<3)+k|0;p=0;do{q=n+(c[614800+(p<<2)>>2]|0)|0;if(((d[h+((q|0)/8|0)|0]|0)&128>>>((q&7)>>>0)|0)!=0){q=g+(o+p)|0;a[q]=a[q]|4}p=p+1|0;}while((p|0)<8);m=m+1|0;}while((m|0)<8);m=k|1048576;l=0;while(1){p=m+(c[1238464+(l<<2)>>2]|0)|0;o=(l<<3)+k|0;n=0;do{q=p+(c[614800+(n<<2)>>2]|0)|0;if(((d[h+((q|0)/8|0)|0]|0)&128>>>((q&7)>>>0)|0)!=0){q=g+(o+n)|0;a[q]=a[q]|2}n=n+1|0;}while((n|0)<8);n=l+1|0;if((n|0)<8){l=n}else{C=0;break}}do{l=k+(c[1238464+(C<<2)>>2]|0)|0;m=(C<<3)+k|0;n=0;do{o=l+(c[614800+(n<<2)>>2]|0)|0;if(((d[h+((o|0)/8|0)|0]|0)&128>>>((o&7)>>>0)|0)!=0){o=g+(m+n)|0;a[o]=a[o]|1}n=n+1|0;}while((n|0)<8);C=C+1|0;}while((C|0)<8);j=j+1|0;}while(j>>>0<B>>>0);x=eOS(b,e)|0;i=f;return 0}function eVp(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=(b&127|0)==0;if(d){e=d?6874088:0;break}else{f=1}return f|0}else{e=(b|0)==0?6081016:9762968}}while(0);if((a|0)==0){f=0;return f|0}c[a+100>>2]=c[e+100>>2];c[a+104>>2]=c[e+104>>2];c[a+108>>2]=c[e+108>>2];f=0;return f|0}function eVq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;if(b>>>0>127){e=(b&127|0)==0?6874088:0}else{e=(b|0)==0?6081016:9762968}if(!((e|0)!=0&(d|0)==0)){f=1;return f|0}c[a>>2]=e;f=0;return f|0}function eVr(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>24){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6081128+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eVs(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=eVm()|0;if((d|0)!=0){return d|0}c[2385544]=2097152;e=0;while(1){if((e|0)>=1024){f=0;break}g=9638528+(e<<2)|0;if((c[g>>2]|0)==0){h=29563;break}else{e=e+1|0}}do{if((h|0)==29563){e=gGq(2097152)|0;c[g>>2]=e;if((e|0)==0){f=0;break}gGz(e|0,0,2097152);f=e}}while(0);g=f;gGz(f|0,0,2097152);e=(c[3532446]|0)+1048576|0;i=e;j=0;do{k=b[i+(j<<1)>>1]|0;b[g+((j^428374)<<1)>>1]=(k&65535)>>>8<<15|k&36|k<<8&256|(k&65535)>>>15<<7|(k&65535)>>>13&1|(k&65535)>>>4<<14&16384|(k&65535)>>>12<<13&8192|(k&65535)>>>3<<12&4096|(k&65535)>>>6<<11&2048|(k&65535)>>>7<<10&1024|(k&65535)>>>1<<9&512|(k&65535)>>>11<<6&64|(k&65535)>>>14<<4&16|(k&65535)>>>10<<3&8|(k&65535)>>>9<<1&2;j=j+1|0;}while(j>>>0<1048576);gGC(e|0,f|0,2097152)|0;e=0;while(1){if((e|0)>=1024){break}l=9638528+(e<<2)|0;if((c[l>>2]|0)==(f|0)){h=29570;break}else{e=e+1|0}}if((h|0)==29570){gGr(f);c[l>>2]=0}a[9773296]=102;c[3541240]=894;return d|0}function eVt(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if(b>>>0>127){d=(b&127|0)==0;if(d){e=d?6874088:0;break}else{f=1}return f|0}else{e=(b|0)==0?6037736:9762968}}while(0);if((a|0)==0){f=0;return f|0}c[a+100>>2]=c[e+100>>2];c[a+104>>2]=c[e+104>>2];c[a+108>>2]=c[e+108>>2];f=0;return f|0}function eVu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;if(b>>>0>127){e=(b&127|0)==0?6874088:0}else{e=(b|0)==0?6037736:9762968}if(!((e|0)!=0&(d|0)==0)){f=1;return f|0}c[a>>2]=e;f=0;return f|0}function eVv(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6037848+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eVw(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=eVm()|0;if((d|0)!=0){return d|0}c[2385544]=524288;e=0;while(1){if((e|0)>=1024){f=0;break}g=9638528+(e<<2)|0;if((c[g>>2]|0)==0){h=29603;break}else{e=e+1|0}}do{if((h|0)==29603){e=gGq(524288)|0;c[g>>2]=e;if((e|0)==0){f=0;break}gGz(e|0,0,524288);f=e}}while(0);g=f;e=c[2385544]|0;gGz(f|0,0,e|0);i=(c[3532446]|0)+1048576|0;j=i;if(e>>>0>1){k=e>>>1;l=0;do{m=b[j+(l<<1)>>1]|0;b[g+((l^173798)<<1)>>1]=m<<14&16384|m&4|(m&65535)>>>4<<15|(m&65535)>>>15<<3|(m&65535)>>>8&1|(m&65535)>>>12<<13&8192|(m&65535)>>>5<<12&4096|(m&65535)>>>7<<11&2048|(m&65535)>>>3<<10&1024|(m&65535)>>>1<<9&512|(m&65535)>>>14<<8&256|(m&65535)>>>10<<7&128|(m&65535)>>>11<<6&64|(m&65535)>>>9<<5&32|(m&65535)>>>6<<4&16|(m&65535)>>>13<<1&2;l=l+1|0;}while(l>>>0<k>>>0)}gGC(i|0,f|0,e)|0;e=0;while(1){if((e|0)>=1024){break}n=9638528+(e<<2)|0;if((c[n>>2]|0)==(f|0)){h=29611;break}else{e=e+1|0}}if((h|0)==29611){gGr(f);c[n>>2]=0}a[9773296]=115;c[3541240]=2234;return d|0}function eVx(a){a=a|0;return a|0}function eVy(a){a=a|0;return a>>>19<<31|a&2|a<<26&67108864|a>>>31<<19|a>>>6&1|a>>>20<<30&1073741824|a>>>25<<29&536870912|a>>>26<<28&268435456|a>>>15<<27&134217728|a>>>16<<25&33554432|a>>>2<<24&16777216|a>>>8<<23&8388608|a>>>9<<22&4194304|a>>>13<<21&2097152|a>>>14<<20&1048576|a>>>21<<18&262144|a>>>7<<17&131072|a>>>18<<16&65536|a>>>11<<15&32768|a>>>30<<14&16384|a>>>22<<13&8192|a>>>17<<12&4096|a>>>3<<11&2048|a>>>4<<10&1024|a>>>12<<9&512|a>>>28<<8&256|a>>>29<<7&128|a>>>5<<6&64|a>>>27<<5&32|a>>>10<<4&16|a>>>23<<3&8|a>>>24<<2&4|0}function eVz(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0;fxU(0,425984);if((c[2394]|0)==0){a=c[2112932]|0}else{c[2394]=0;b=c[3532596]|0;c[2112932]=b;d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];a=b}b=c[3532446]|0;d=a|0;e=0;while(1){f=b+e|0;c[d>>2]=f;c[d+131072>>2]=f;f=e+1024|0;if(f>>>0>1048575){break}else{d=d+4|0;e=f}}e=c[3532542]|0;d=a+8192|0;f=2097152;while(1){g=e+(f-2097152)|0;c[d>>2]=g;c[d+65536>>2]=g;c[d+131072>>2]=g;g=f+1024|0;if(g>>>0>2359295){break}else{d=d+4|0;f=g}}f=c[3532356]|0;d=a+16384|0;e=4194304;while(1){c[d>>2]=f+(e-4194304);g=e+1024|0;if(g>>>0>4259839){break}else{d=d+4|0;e=g}}e=c[3532368]|0;c[a+16640>>2]=e;c[a+82176>>2]=e;c[a+147712>>2]=e;d=e+1024|0;c[a+16644>>2]=d;c[a+82180>>2]=d;c[a+147716>>2]=d;d=e+2048|0;c[a+16648>>2]=d;c[a+82184>>2]=d;c[a+147720>>2]=d;d=e+3072|0;c[a+16652>>2]=d;c[a+82188>>2]=d;c[a+147724>>2]=d;d=c[3532390]|0;c[a+17408>>2]=d;c[a+82944>>2]=d;c[a+148480>>2]=d;e=d+1024|0;c[a+17412>>2]=e;c[a+82948>>2]=e;c[a+148484>>2]=e;e=c[3532484]|0;c[a+33792>>2]=e;c[a+99328>>2]=e;c[a+164864>>2]=e;d=e+1024|0;c[a+33796>>2]=d;c[a+99332>>2]=d;c[a+164868>>2]=d;d=e+2048|0;c[a+33800>>2]=d;c[a+99336>>2]=d;c[a+164872>>2]=d;d=e+3072|0;c[a+33804>>2]=d;c[a+99340>>2]=d;c[a+164876>>2]=d;d=a+60928|0;e=15597568;while(1){f=b+(e-14548992)|0;c[d>>2]=f;c[d+131072>>2]=f;f=e+1024|0;if(f>>>0>15728639){break}else{d=d+4|0;e=f}}e=c[3532470]|0;c[a+65472>>2]=e;c[a+131008>>2]=e;c[a+196544>>2]=e;d=e+1024|0;c[a+65476>>2]=d;c[a+131012>>2]=d;c[a+196548>>2]=d;d=e+2048|0;c[a+65480>>2]=d;c[a+131016>>2]=d;c[a+196552>>2]=d;d=e+3072|0;c[a+65484>>2]=d;c[a+131020>>2]=d;c[a+196556>>2]=d;d=e+4096|0;c[a+65488>>2]=d;c[a+131024>>2]=d;c[a+196560>>2]=d;d=e+5120|0;c[a+65492>>2]=d;c[a+131028>>2]=d;c[a+196564>>2]=d;d=e+6144|0;c[a+65496>>2]=d;c[a+131032>>2]=d;c[a+196568>>2]=d;d=e+7168|0;c[a+65500>>2]=d;c[a+131036>>2]=d;c[a+196572>>2]=d;d=e+8192|0;c[a+65504>>2]=d;c[a+131040>>2]=d;c[a+196576>>2]=d;d=e+9216|0;c[a+65508>>2]=d;c[a+131044>>2]=d;c[a+196580>>2]=d;d=e+10240|0;c[a+65512>>2]=d;c[a+131048>>2]=d;c[a+196584>>2]=d;d=e+11264|0;c[a+65516>>2]=d;c[a+131052>>2]=d;c[a+196588>>2]=d;d=e+12288|0;c[a+65520>>2]=d;c[a+131056>>2]=d;c[a+196592>>2]=d;d=e+13312|0;c[a+65524>>2]=d;c[a+131060>>2]=d;c[a+196596>>2]=d;d=e+14336|0;c[a+65528>>2]=d;c[a+131064>>2]=d;c[a+196600>>2]=d;d=e+15360|0;c[a+65532>>2]=d;c[a+131068>>2]=d;c[a+196604>>2]=d;c[a+196688>>2]=1968;c[a+196728>>2]=2610;c[a+196608>>2]=2982;c[a+196648>>2]=298;a=c[3532592]|0;if((a|0)==0){h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return}gGC(a|0,9104152,280)|0;h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return}function eVA(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=i;i=i+480|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;l=b+360|0;m=b+472|0;n=c[3532446]|0;if((c[3542200]|0)==0){o=1;i=b;return o|0}p=l+108|0;c[p>>2]=0;q=l+100|0;c[q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,0)|0;do{if((c[p>>2]|0)!=0){l=c[q>>2]|0;c[m>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](m,0,0)|0;if((l|0)<1){o=1;i=b;return o|0}if((gzL(n,0,0)|0)==0){break}else{o=1}i=b;return o|0}}while(0);n=c[3532352]|0;m=0;while(1){if((m|0)>=1024){s=0;break}t=9638528+(m<<2)|0;if((c[t>>2]|0)==0){u=29643;break}else{m=m+1|0}}do{if((u|0)==29643){m=gGq(n)|0;c[t>>2]=m;if((m|0)==0){s=0;break}gGz(m|0,0,n|0);s=m}}while(0);c[3532370]=s;do{if((c[3542200]|0)!=0){n=j+108|0;c[n>>2]=0;t=j+100|0;c[t>>2]=0;m=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[m&16383](j,1)|0;if((c[n>>2]|0)==0){break}n=c[t>>2]|0;c[k>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](k,1,0)|0;if((n|0)<1){break}gzL(s,0,1)|0}}while(0);s=c[3532370]|0;k=c[3532350]|0;j=0;do{n=j<<6;gGz(k+n|0,0,64);t=j<<8;m=t|1;q=0;do{p=m+(c[1183816+(q<<2)>>2]|0)|0;l=(q<<3)+n|0;r=0;do{v=p+(c[1934976+(r<<2)>>2]|0)|0;if(((d[s+((v|0)/8|0)|0]|0)&128>>>((v&7)>>>0)|0)!=0){v=k+(l+r)|0;a[v]=a[v]|4}r=r+1|0;}while((r|0)<8);q=q+1|0;}while((q|0)<8);q=t|2;m=0;do{r=q+(c[1183816+(m<<2)>>2]|0)|0;l=(m<<3)+n|0;p=0;do{v=r+(c[1934976+(p<<2)>>2]|0)|0;if(((d[s+((v|0)/8|0)|0]|0)&128>>>((v&7)>>>0)|0)!=0){v=k+(l+p)|0;a[v]=a[v]|2}p=p+1|0;}while((p|0)<8);m=m+1|0;}while((m|0)<8);m=t|3;q=0;do{p=m+(c[1183816+(q<<2)>>2]|0)|0;l=(q<<3)+n|0;r=0;do{v=p+(c[1934976+(r<<2)>>2]|0)|0;if(((d[s+((v|0)/8|0)|0]|0)&128>>>((v&7)>>>0)|0)!=0){v=k+(l+r)|0;a[v]=a[v]|1}r=r+1|0;}while((r|0)<8);q=q+1|0;}while((q|0)<8);j=j+1|0;}while((j|0)<8192);c[3532508]=8192;j=0;while(1){if((j|0)>=1024){break}w=9638528+(j<<2)|0;if((c[w>>2]|0)==(s|0)){u=29660;break}else{j=j+1|0}}if((u|0)==29660){gGr(s);c[w>>2]=0}c[3532370]=0;w=c[3532374]|0;do{if((c[3542200]|0)!=0){s=g+108|0;c[s>>2]=0;u=g+100|0;c[u>>2]=0;j=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[j&16383](g,2)|0;if((c[s>>2]|0)==0){break}s=c[u>>2]|0;c[h>>2]=9534384;u=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[u&16383](h,2,0)|0;if((s|0)<1){break}gzL(w,0,2)|0}}while(0);w=c[3532380]>>1;if((w|0)>0){h=0;g=c[3532374]|0;while(1){s=a[g]|0;u=g+1|0;a[g]=a[u]|0;a[u]=s;s=h+1|0;if((s|0)<(w|0)){h=s;g=g+2|0}else{break}}}g=c[3532330]|0;if((c[3542200]|0)==0){o=1;i=b;return o|0}h=e+108|0;c[h>>2]=0;w=e+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,3)|0;do{if((c[h>>2]|0)!=0){e=c[w>>2]|0;c[f>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](f,3,0)|0;if((e|0)<1){o=1;i=b;return o|0}if((gzL(g,0,3)|0)==0){break}else{o=1}i=b;return o|0}}while(0);g=c[3532348]|0;f=(c[3532330]|0)+65536|0;gGC(g|0,f|0,65536)|0;o=0;i=b;return o|0}function eVB(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;b=i;i=i+600|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;l=b+360|0;m=b+472|0;n=b+480|0;o=b+592|0;p=c[3532446]|0;if((c[3542200]|0)==0){q=1;i=b;return q|0}r=n+108|0;c[r>>2]=0;s=n+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,0)|0;do{if((c[r>>2]|0)!=0){n=c[s>>2]|0;c[o>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](o,0,0)|0;if((n|0)<1){q=1;i=b;return q|0}if((gzL(p,0,0)|0)==0){break}else{q=1}i=b;return q|0}}while(0);p=(c[3532446]|0)+524288|0;if((c[3542200]|0)==0){q=1;i=b;return q|0}o=l+108|0;c[o>>2]=0;s=l+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,1)|0;do{if((c[o>>2]|0)!=0){l=c[s>>2]|0;c[m>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](m,1,0)|0;if((l|0)<1){q=1;i=b;return q|0}if((gzL(p,0,1)|0)==0){break}else{q=1}i=b;return q|0}}while(0);p=c[3532552]|0;m=c[3532446]|0;gGC(p|0,m|0,1048576)|0;m=c[3532352]|0;p=0;while(1){if((p|0)>=1024){u=0;break}v=9638528+(p<<2)|0;if((c[v>>2]|0)==0){w=29704;break}else{p=p+1|0}}do{if((w|0)==29704){p=gGq(m)|0;c[v>>2]=p;if((p|0)==0){u=0;break}gGz(p|0,0,m|0);u=p}}while(0);c[3532370]=u;do{if((c[3542200]|0)!=0){m=j+108|0;c[m>>2]=0;v=j+100|0;c[v>>2]=0;p=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[p&16383](j,2)|0;if((c[m>>2]|0)==0){break}m=c[v>>2]|0;c[k>>2]=9534384;v=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[v&16383](k,2,0)|0;if((m|0)<1){break}gzL(u,0,2)|0}}while(0);u=c[3532370]|0;k=c[3532350]|0;j=0;do{m=j<<6;gGz(k+m|0,0,64);v=j<<8;p=v|1;s=0;do{o=p+(c[1183816+(s<<2)>>2]|0)|0;l=(s<<3)+m|0;r=0;do{n=o+(c[1934976+(r<<2)>>2]|0)|0;if(((d[u+((n|0)/8|0)|0]|0)&128>>>((n&7)>>>0)|0)!=0){n=k+(l+r)|0;a[n]=a[n]|4}r=r+1|0;}while((r|0)<8);s=s+1|0;}while((s|0)<8);s=v|2;p=0;do{r=s+(c[1183816+(p<<2)>>2]|0)|0;l=(p<<3)+m|0;o=0;do{n=r+(c[1934976+(o<<2)>>2]|0)|0;if(((d[u+((n|0)/8|0)|0]|0)&128>>>((n&7)>>>0)|0)!=0){n=k+(l+o)|0;a[n]=a[n]|2}o=o+1|0;}while((o|0)<8);p=p+1|0;}while((p|0)<8);p=v|3;s=0;do{o=p+(c[1183816+(s<<2)>>2]|0)|0;l=(s<<3)+m|0;r=0;do{n=o+(c[1934976+(r<<2)>>2]|0)|0;if(((d[u+((n|0)/8|0)|0]|0)&128>>>((n&7)>>>0)|0)!=0){n=k+(l+r)|0;a[n]=a[n]|1}r=r+1|0;}while((r|0)<8);s=s+1|0;}while((s|0)<8);j=j+1|0;}while((j|0)<16384);c[3532508]=16384;j=0;while(1){if((j|0)>=1024){break}x=9638528+(j<<2)|0;if((c[x>>2]|0)==(u|0)){w=29721;break}else{j=j+1|0}}if((w|0)==29721){gGr(u);c[x>>2]=0}c[3532370]=0;x=c[3532374]|0;do{if((c[3542200]|0)!=0){u=g+108|0;c[u>>2]=0;w=g+100|0;c[w>>2]=0;j=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[j&16383](g,3)|0;if((c[u>>2]|0)==0){break}u=c[w>>2]|0;c[h>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](h,3,0)|0;if((u|0)<1){break}gzL(x,0,3)|0}}while(0);x=c[3532330]|0;if((c[3542200]|0)==0){q=1;i=b;return q|0}h=e+108|0;c[h>>2]=0;g=e+100|0;c[g>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,4)|0;do{if((c[h>>2]|0)!=0){e=c[g>>2]|0;c[f>>2]=9534384;u=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[u&16383](f,4,0)|0;if((e|0)<1){q=1;i=b;return q|0}if((gzL(x,0,4)|0)==0){break}else{q=1}i=b;return q|0}}while(0);x=c[3532348]|0;f=(c[3532330]|0)+65536|0;gGC(x|0,f|0,131072)|0;q=0;i=b;return q|0}function eVC(){var a=0,b=0,d=0,e=0;a=eOt(1)|0;b=c[3532446]|0;d=b+524288|0;e=b+262144|0;gGC(d|0,e|0,262144)|0;gGz(e|0,0,262144);e=c[3532552]|0;d=e+524288|0;b=e+262144|0;gGC(d|0,b|0,262144)|0;gGz(b|0,0,262144);return a|0}function eVD(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=i;i=i+480|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;l=b+360|0;m=b+472|0;n=c[3532446]|0;if((c[3542200]|0)==0){o=1;i=b;return o|0}p=l+108|0;c[p>>2]=0;q=l+100|0;c[q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,0)|0;do{if((c[p>>2]|0)!=0){l=c[q>>2]|0;c[m>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](m,0,0)|0;if((l|0)<1){o=1;i=b;return o|0}if((gzL(n,0,0)|0)==0){break}else{o=1}i=b;return o|0}}while(0);n=c[3532352]|0;m=0;while(1){if((m|0)>=1024){s=0;break}t=9638528+(m<<2)|0;if((c[t>>2]|0)==0){u=29762;break}else{m=m+1|0}}do{if((u|0)==29762){m=gGq(n)|0;c[t>>2]=m;if((m|0)==0){s=0;break}gGz(m|0,0,n|0);s=m}}while(0);c[3532370]=s;do{if((c[3542200]|0)!=0){n=j+108|0;c[n>>2]=0;t=j+100|0;c[t>>2]=0;m=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[m&16383](j,1)|0;if((c[n>>2]|0)==0){break}n=c[t>>2]|0;c[k>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](k,1,0)|0;if((n|0)<1){break}gzL(s,0,1)|0}}while(0);s=c[3532370]|0;k=c[3532350]|0;j=0;do{n=j<<6;gGz(k+n|0,0,64);t=j<<8;m=t|1;q=0;do{p=m+(c[1183816+(q<<2)>>2]|0)|0;l=(q<<3)+n|0;r=0;do{v=p+(c[1934976+(r<<2)>>2]|0)|0;if(((d[s+((v|0)/8|0)|0]|0)&128>>>((v&7)>>>0)|0)!=0){v=k+(l+r)|0;a[v]=a[v]|4}r=r+1|0;}while((r|0)<8);q=q+1|0;}while((q|0)<8);q=t|2;m=0;do{r=q+(c[1183816+(m<<2)>>2]|0)|0;l=(m<<3)+n|0;p=0;do{v=r+(c[1934976+(p<<2)>>2]|0)|0;if(((d[s+((v|0)/8|0)|0]|0)&128>>>((v&7)>>>0)|0)!=0){v=k+(l+p)|0;a[v]=a[v]|2}p=p+1|0;}while((p|0)<8);m=m+1|0;}while((m|0)<8);m=t|3;q=0;do{p=m+(c[1183816+(q<<2)>>2]|0)|0;l=(q<<3)+n|0;r=0;do{v=p+(c[1934976+(r<<2)>>2]|0)|0;if(((d[s+((v|0)/8|0)|0]|0)&128>>>((v&7)>>>0)|0)!=0){v=k+(l+r)|0;a[v]=a[v]|1}r=r+1|0;}while((r|0)<8);q=q+1|0;}while((q|0)<8);j=j+1|0;}while((j|0)<8192);c[3532508]=8192;j=0;while(1){if((j|0)>=1024){break}w=9638528+(j<<2)|0;if((c[w>>2]|0)==(s|0)){u=29779;break}else{j=j+1|0}}if((u|0)==29779){gGr(s);c[w>>2]=0}c[3532370]=0;w=c[3532374]|0;do{if((c[3542200]|0)!=0){s=g+108|0;c[s>>2]=0;u=g+100|0;c[u>>2]=0;j=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[j&16383](g,2)|0;if((c[s>>2]|0)==0){break}s=c[u>>2]|0;c[h>>2]=9534384;u=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[u&16383](h,2,0)|0;if((s|0)<1){break}gzL(w,0,2)|0}}while(0);w=c[3532380]>>1;if((w|0)>0){h=0;g=c[3532374]|0;while(1){s=a[g]|0;u=g+1|0;a[g]=a[u]|0;a[u]=s;s=h+1|0;if((s|0)<(w|0)){h=s;g=g+2|0}else{break}}}g=c[3532330]|0;if((c[3542200]|0)==0){o=1;i=b;return o|0}h=e+108|0;c[h>>2]=0;w=e+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,3)|0;do{if((c[h>>2]|0)!=0){e=c[w>>2]|0;c[f>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](f,3,0)|0;if((e|0)<1){o=1;i=b;return o|0}if((gzL(g,0,3)|0)==0){break}else{o=1}i=b;return o|0}}while(0);g=c[3532348]|0;f=(c[3532330]|0)+65536|0;gGC(g|0,f|0,32768)|0;o=0;i=b;return o|0}function eVE(a){a=a|0;var b=0,d=0,e=0,f=0;b=a&255;c[3532340]=b&32;if((b&1|0)!=0){return}b=c[2439330]|0;a=(b|0)==0;if(!a){d=b;gGC(9706056,d|0,76)|0}d=c[2438118]|0;c[2433530]=d;e=c[3528484]|0;c[2076596]=e;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;gGz(9706056|0,0|0,76|0);if(!a){a=b;gGC(a|0,9706056,76)|0}c[2438118]=d;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}function eVF(a){a=a|0;return((a|0)!=1310816)<<31>>31|0}function eVG(b){b=b|0;var d=0,e=0,f=0,g=0;L39112:do{switch(b|0){case 1310721:{if((a[9668996]|0)==0){d=29827;break L39112}e=c[3540906]|0;if((e|0)==0){f=0}else{f=gD[e&8191]()|0}a[9669002]=f;d=29827;break};case 1310741:{g=a[14130176]|0;break};case 1310769:{e=c[3532482]|0;if((e|0)==0){g=-1;break L39112}g=gj[e&4095](c[3532560]&65535)|0;break};case 1310737:{d=29827;break};case 1310743:{g=a[14130177]|0;break};default:{g=-1}}}while(0);if((d|0)==29827){g=~a[14130136]}return g|0}function eVH(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=a-1048576|0;if(d>>>0<65536){eOX(d,b);return}if((a|0)!=1310832){return}a=c[3532384]|0;if(a>>>0>3){b=c[3532390]|0;d=a>>>2;e=c[3532386]|0;f=0;g=b;while(1){h=c[g>>2]|0;c[g>>2]=c[e>>2];c[e>>2]=h;h=f+1|0;if(h>>>0<d>>>0){e=e+4|0;f=h;g=g+4|0}else{i=b;break}}}else{i=c[3532390]|0}gGz(i|0,-1|0,a|0);return}function eVI(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=d-1048576|0;if(f>>>0<65536){eOY(f^1,e);return}if((d|0)==1310833){f=c[3532384]|0;if(f>>>0>3){g=c[3532390]|0;h=f>>>2;i=c[3532386]|0;j=0;k=g;while(1){l=c[k>>2]|0;c[k>>2]=c[i>>2];c[i>>2]=l;l=j+1|0;if(l>>>0<h>>>0){i=i+4|0;j=l;k=k+4|0}else{m=g;break}}}else{m=c[3532390]|0}gGz(m|0,-1|0,f|0);return}else if((d|0)==1310723|(d|0)==1310725|(d|0)==1310727){S4(0,(d-1310720|0)>>>1,e)}else if((d|0)==16776967){c[3532412]=e&255;f=c[2439330]|0;if((f|0)!=0){m=f;gGC(9706056,m|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;m=(c[2433530]|0)+12|0;c[2433530]=m;f=c[1836236]|0;g=c[9757320+(f<<2)>>2]|0;if((g|0)!=0){k=g;gGC(k|0,9706056,76)|0}c[9752472+(f<<2)>>2]=m;c[14113936+(f<<2)>>2]=c[2076596];c[9669104+(f<<2)>>2]=c[3541536];c[1836236]=-1;return}else if((d|0)!=1310769){return}c[3532560]=e&255;return}function eVJ(a){a=a|0;var b=0,d=0,e=0,f=0;if((a-589824|0)>>>0>=2){b=0;return b|0}a=c[3532454]|0;d=c[3532456]|0;gGC(a|0,d|0,4096)|0;e=a;a=d;d=0;while(1){f=c[e>>2]|0;c[e>>2]=c[a>>2];c[a>>2]=f;f=d+1|0;if((f|0)<1024){e=e+4|0;a=a+4|0;d=f}else{break}}b=c[3532458]&255;return b|0}function eVK(a,b){a=a|0;b=b|0;if((a|0)!=589824){return}c[3532458]=b&3;return}function eVL(a,b){a=a|0;b=b|0;if((a|0)!=589825){return}c[3532458]=b&3;return}function eVM(a){a=a|0;var b=0;if((a|0)==1314822){b=d[14130177]|0}else if((a|0)==1314820){b=d[14130176]|0}else if((a|0)==1314818){b=(d[14130136]|0)^255}else{b=-1}return b|0}function eVN(b){b=b|0;var d=0,e=0,f=0,g=0;do{if((b|0)==1314819){d=~a[14130136];return d|0}else if((b|0)==1323041){e=c[3532482]|0;if((e|0)==0){break}d=gj[e&4095](c[3532560]&65535)|0;return d|0}else if((b|0)==1314821){d=a[14130176]|0;return d|0}else if((b|0)==16776965){d=c[3532412]&255;return d|0}else if((b|0)==1314823){d=a[14130177]|0;return d|0}else if((b|0)!=2686976){d=-1;return d|0}}while(0);b=c[3532454]|0;e=c[3532456]|0;gGC(b|0,e|0,4096)|0;f=b;b=e;e=0;while(1){g=c[f>>2]|0;c[f>>2]=c[b>>2];c[b>>2]=g;g=e+1|0;if((g|0)<1024){f=f+4|0;b=b+4|0;e=g}else{break}}d=c[3532458]&255;return d|0}function eVO(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=d-1048576|0;if(f>>>0<65536){eOX(f,e);return}if((d|0)==16776966){c[3532412]=e&255;f=c[2439330]|0;if((f|0)!=0){g=f;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;g=c[2433530]|0;c[2433530]=g+12;f=c[1836236]|0;h=c[9757320+(f<<2)>>2]|0;if((a[h+4188|0]|0)==0){i=gfc(200)|0;j=c[1836236]|0;k=i;l=(c[2433530]|0)+i|0;m=j;n=c[9757320+(j<<2)>>2]|0}else{k=200;l=g+212|0;m=f;n=h}c[2433530]=l;c[2113036]=(c[2113036]|0)+k;if((n|0)!=0){k=n;gGC(k|0,9706056,76)|0}c[9752472+(m<<2)>>2]=l;c[14113936+(m<<2)>>2]=c[2076596];c[9669104+(m<<2)>>2]=c[3541536];c[1836236]=-1;return}else if((d|0)==2686976){c[3532458]=e&3;return}else{return}}function eVP(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=d-1048576|0;if(f>>>0<65536){eOY(f^1,e);return}if((d|0)==16776967){c[3532412]=e&255;f=c[2439330]|0;if((f|0)!=0){g=f;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;g=c[2433530]|0;c[2433530]=g+12;f=c[1836236]|0;h=c[9757320+(f<<2)>>2]|0;if((a[h+4188|0]|0)==0){i=gfc(200)|0;j=c[1836236]|0;k=i;l=(c[2433530]|0)+i|0;m=j;n=c[9757320+(j<<2)>>2]|0}else{k=200;l=g+212|0;m=f;n=h}c[2433530]=l;c[2113036]=(c[2113036]|0)+k;if((n|0)!=0){k=n;gGC(k|0,9706056,76)|0}c[9752472+(m<<2)>>2]=l;c[14113936+(m<<2)>>2]=c[2076596];c[9669104+(m<<2)>>2]=c[3541536];c[1836236]=-1;return}else if((d|0)==1310753){if((e&1)!=0){return}m=c[2439330]|0;l=(m|0)==0;if(!l){k=m;gGC(9706056,k|0,76)|0}k=c[2438118]|0;c[2433530]=k;n=c[3528484]|0;c[2076596]=n;h=c[2417276]|0;c[3541536]=h;c[1836236]=0;gGz(9706056,0,76);if(!l){l=m;gGC(l|0,9706056,76)|0}c[2438118]=k;c[3528484]=n;c[2417276]=h;c[1836236]=-1;return}else if((d|0)==1310721){d=e&255;c[3532560]=d>>>6;c[3532340]=d>>>5&1;return}else{return}}function eVQ(a){a=a|0;var b=0,d=0,e=0;b=a&65535;if((b|0)==8){d=((c[3532568]|0)>1)<<31>>31;return d|0}else if((b|0)==4){d=((c[3532570]|0)>1)<<31>>31;return d|0}else if((b|0)==0){b=c[3532572]|0;if((b&-16|0)==2048){e=-1}else{e=(b>>>4)+128&255}b=(e&255)<32?32:e;d=(b&255)>224?-32:b;return d|0}else{d=0;return d|0}return 0}function eVR(a){a=a|0;var b=0,d=0,e=0;b=a&65535;if((b|0)==2){d=((c[3532568]|0)>1)<<31>>31;return d|0}else if((b|0)==1){d=((c[3532570]|0)>1)<<31>>31;return d|0}else if((b|0)==0){b=c[3532572]|0;if(((b>>4)-129|0)>>>0<3841){e=-2}else{e=128-(b>>>4)&255}b=(e&255)<32?32:e;d=(b&255)>224?-32:b;return d|0}else{d=0;return d|0}return 0}function eVS(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>30){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6183916+(b*112|0)>>2];c[a+104>>2]=c[6183920+(b*112|0)>>2];c[a+108>>2]=c[6183924+(b*112|0)>>2];d=0;return d|0}function eVT(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<31&(d|0)==0)){e=1;return e|0}c[a>>2]=6183816+(b*112|0);e=0;return e|0}function eVU(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3651568+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eVV(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>52){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6187288+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eVW(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;c[3532482]=2560;a[7461592]=1;c[3532494]=393216;b=eOx()|0;if((b|0)==0){d=0}else{return b|0}while(1){if((d|0)>=1024){e=0;break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==0){g=30005;break}else{d=d+1|0}}do{if((g|0)==30005){d=gGq(196608)|0;c[f>>2]=d;if((d|0)==0){e=0;break}gGz(d|0,0,196608);e=d}}while(0);f=c[3532500]|0;gGC(e|0,f|0,196608)|0;gGz(f|0,0,393216);gGC(f|0,e|0,32768)|0;d=f+32768|0;gGC(d|0,e|0,32768)|0;d=f+65536|0;h=e+32768|0;gGC(d|0,h|0,32768)|0;d=f+98304|0;gGC(d|0,h|0,32768)|0;h=f+131072|0;d=e+65536|0;gGC(h|0,d|0,32768)|0;h=f+163840|0;gGC(h|0,d|0,32768)|0;d=f+196608|0;h=e+98304|0;gGC(d|0,h|0,32768)|0;d=f+229376|0;gGC(d|0,h|0,32768)|0;h=f+262144|0;d=e+131072|0;gGC(h|0,d|0,32768)|0;h=f+294912|0;gGC(h|0,d|0,32768)|0;d=f+327680|0;h=e+163840|0;gGC(d|0,h|0,32768)|0;d=f+360448|0;gGC(d|0,h|0,32768)|0;h=0;while(1){if((h|0)>=1024){g=30014;break}i=9638528+(h<<2)|0;if((c[i>>2]|0)==(e|0)){break}else{h=h+1|0}}if((g|0)==30014){return b|0}gGr(e);c[i>>2]=0;return b|0}function eVX(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>54){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5177636+(b*112|0)>>2];c[a+104>>2]=c[5177640+(b*112|0)>>2];c[a+108>>2]=c[5177644+(b*112|0)>>2];d=0;return d|0}function eVY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<55&(d|0)==0)){e=1;return e|0}c[a>>2]=5177536+(b*112|0);e=0;return e|0}function eVZ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>51){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3650944+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eV_(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>62){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3643988+(b*112|0)>>2];c[a+104>>2]=c[3643992+(b*112|0)>>2];c[a+108>>2]=c[3643996+(b*112|0)>>2];d=0;return d|0}function eV$(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<63&(d|0)==0)){e=1;return e|0}c[a>>2]=3643888+(b*112|0);e=0;return e|0}function eV0(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>30){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3640516+(b*112|0)>>2];c[a+104>>2]=c[3640520+(b*112|0)>>2];c[a+108>>2]=c[3640524+(b*112|0)>>2];d=0;return d|0}function eV1(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<31&(d|0)==0)){e=1;return e|0}c[a>>2]=3640416+(b*112|0);e=0;return e|0}function eV2(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>32){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5183796+(b*112|0)>>2];c[a+104>>2]=c[5183800+(b*112|0)>>2];c[a+108>>2]=c[5183804+(b*112|0)>>2];d=0;return d|0}function eV3(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<33&(d|0)==0)){e=1;return e|0}c[a>>2]=5183696+(b*112|0);e=0;return e|0}function eV4(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;c[3532482]=2560;a[7461592]=1;c[3532494]=393216;d=eOx()|0;if((d|0)!=0){return d|0}e=c[3532446]|0;f=e;g=c[3532430]|0;h=g>>>1;if((h|0)!=0){i=0;do{j=f+(i<<1)|0;k=b[j>>1]|0;b[j>>1]=(k&65535)>>>11<<13&8192|k&-10433|(k&65535)>>>13<<11&2048|(k&65535)>>>6<<7&128|(k&65535)>>>7<<6&64;i=i+1|0;}while((i|0)<(h|0))}h=c[3532552]|0;gGC(h|0,e|0,g)|0;g=c[3532444]|0;e=(c[3532440]|0)>>>1;if((e|0)!=0){h=0;do{i=g+(h<<1)|0;f=b[i>>1]|0;b[i>>1]=(f&65535)>>>15<<14|f&16371|(f&65535)>>>14<<15|(f&65535)>>>2<<3&8|(f&65535)>>>3<<2&4;h=h+1|0;}while((h|0)<(e|0))}e=c[3532448]|0;h=0;do{g=e+h|0;f=a[g]|0;a[g]=(f&255)>>>7<<6|f&63|(f&255)>>>6<<7;f=e+(h+131072)|0;g=a[f]|0;a[f]=(g&255)>>>5<<6&64|g&-97|(g&255)>>>6<<5&32;h=h+1|0;}while((h|0)<131072);h=c[3532330]|0;e=c[3532308]|0;if((e|0)>0){g=0;while(1){f=h+g|0;i=a[f]|0;a[f]=(i&255)>>>5<<6&64|i&-97|(i&255)>>>6<<5&32;i=g+1|0;if((i|0)<(e|0)){g=i}else{l=0;break}}}else{l=0}while(1){if((l|0)>=1024){m=0;break}n=9638528+(l<<2)|0;if((c[n>>2]|0)==0){o=30081;break}else{l=l+1|0}}do{if((o|0)==30081){l=gGq(196608)|0;c[n>>2]=l;if((l|0)==0){m=0;break}gGz(l|0,0,196608);m=l}}while(0);n=c[3532500]|0;gGC(m|0,n|0,196608)|0;gGz(n|0,0,393216);gGC(n|0,m|0,32768)|0;l=n+65536|0;g=m+32768|0;gGC(l|0,g|0,32768)|0;g=n+131072|0;l=m+65536|0;gGC(g|0,l|0,32768)|0;l=n+196608|0;g=m+98304|0;gGC(l|0,g|0,32768)|0;g=n+262144|0;l=m+131072|0;gGC(g|0,l|0,32768)|0;l=n+327680|0;n=m+163840|0;gGC(l|0,n|0,32768)|0;n=0;while(1){if((n|0)>=1024){o=30088;break}p=9638528+(n<<2)|0;if((c[p>>2]|0)==(m|0)){break}else{n=n+1|0}}if((o|0)==30088){return d|0}gGr(m);c[p>>2]=0;return d|0}function eV5(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>24){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4998020+(b*112|0)>>2];c[a+104>>2]=c[4998024+(b*112|0)>>2];c[a+108>>2]=c[4998028+(b*112|0)>>2];d=0;return d|0}function eV6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<25&(d|0)==0)){e=1;return e|0}c[a>>2]=4997920+(b*112|0);e=0;return e|0}function eV7(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1709456+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eV8(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>48){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5000720+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eV9(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c[3532482]=3328;a[7461656]=1;c[3532494]=262144;b=eOx()|0;if((b|0)!=0){return b|0}if((c[2394]|0)==0){d=c[2112932]|0;e=c[3532592]|0}else{c[2394]=0;f=c[3532596]|0;c[2112932]=f;g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060];d=f;e=g}c[d+196688>>2]=84;c[d+196728>>2]=2256;c[d+196608>>2]=1376;c[d+196648>>2]=1024;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;c[3532464]=2038;c[3532462]=1984;c[3532460]=1984;e=0;while(1){if((e|0)>=1024){h=0;break}i=9638528+(e<<2)|0;if((c[i>>2]|0)==0){j=30128;break}else{e=e+1|0}}do{if((j|0)==30128){e=gGq(131072)|0;c[i>>2]=e;if((e|0)==0){h=0;break}gGz(e|0,0,131072);h=e}}while(0);i=c[3532500]|0;gGC(h|0,i|0,131072)|0;gGz(i|0,0,262144);gGC(i|0,h|0,32768)|0;e=i+32768|0;gGC(e|0,h|0,32768)|0;e=i+65536|0;d=h+32768|0;gGC(e|0,d|0,32768)|0;e=i+98304|0;gGC(e|0,d|0,32768)|0;d=i+131072|0;e=h+65536|0;gGC(d|0,e|0,32768)|0;d=i+163840|0;gGC(d|0,e|0,32768)|0;e=i+196608|0;d=h+98304|0;gGC(e|0,d|0,32768)|0;e=i+229376|0;gGC(e|0,d|0,32768)|0;d=0;while(1){if((d|0)>=1024){j=30137;break}k=9638528+(d<<2)|0;if((c[k>>2]|0)==(h|0)){break}else{d=d+1|0}}if((j|0)==30137){return b|0}gGr(h);c[k>>2]=0;return b|0}function eWa(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>31){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3473076+(b*112|0)>>2];c[a+104>>2]=c[3473080+(b*112|0)>>2];c[a+108>>2]=c[3473084+(b*112|0)>>2];d=0;return d|0}function eWb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<32&(d|0)==0)){e=1;return e|0}c[a>>2]=3472976+(b*112|0);e=0;return e|0}function eWc(){c[3532482]=3328;c[3532494]=262144;return eV9()|0}function eWd(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>31){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3469492+(b*112|0)>>2];c[a+104>>2]=c[3469496+(b*112|0)>>2];c[a+108>>2]=c[3469500+(b*112|0)>>2];d=0;return d|0}function eWe(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<32&(d|0)==0)){e=1;return e|0}c[a>>2]=3469392+(b*112|0);e=0;return e|0}function eWf(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>30){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1706084+(b*112|0)>>2];c[a+104>>2]=c[1706088+(b*112|0)>>2];c[a+108>>2]=c[1706092+(b*112|0)>>2];d=0;return d|0}function eWg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<31&(d|0)==0)){e=1;return e|0}c[a>>2]=1705984+(b*112|0);e=0;return e|0}function eWh(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>30){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4917276+(b*112|0)>>2];c[a+104>>2]=c[4917280+(b*112|0)>>2];c[a+108>>2]=c[4917284+(b*112|0)>>2];d=0;return d|0}function eWi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<31&(d|0)==0)){e=1;return e|0}c[a>>2]=4917176+(b*112|0);e=0;return e|0}function eWj(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1653648+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eWk(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>56){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4920648+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eWl(){c[3532482]=2560;a[7461592]=1;c[3532494]=393216;return eOx()|0}function eWm(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>30){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3282972+(b*112|0)>>2];c[a+104>>2]=c[3282976+(b*112|0)>>2];c[a+108>>2]=c[3282980+(b*112|0)>>2];d=0;return d|0}function eWn(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<31&(d|0)==0)){e=1;return e|0}c[a>>2]=3282872+(b*112|0);e=0;return e|0}function eWo(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>38){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3291452+(b*112|0)>>2];c[a+104>>2]=c[3291456+(b*112|0)>>2];c[a+108>>2]=c[3291460+(b*112|0)>>2];d=0;return d|0}function eWp(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<39&(d|0)==0)){e=1;return e|0}c[a>>2]=3291352+(b*112|0);e=0;return e|0}function eWq(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>53){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3282224+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eWr(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>38){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3287084+(b*112|0)>>2];c[a+104>>2]=c[3287088+(b*112|0)>>2];c[a+108>>2]=c[3287092+(b*112|0)>>2];d=0;return d|0}function eWs(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<39&(d|0)==0)){e=1;return e|0}c[a>>2]=3286984+(b*112|0);e=0;return e|0}function eWt(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>52){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3286344+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eWu(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=d&65535;if((f&65280|0)==56320){a[(c[2386406]|0)+(f&255)|0]=e;return}if((f|0)==53248){d=e&255;if(!(a[7006512]|0)){a[9533352]=e;c[2161344]=1;if((c[2415208]|0)==1){return}c[2415208]=1;b[4830412]=b[4830412]|1;return}g=c[1836236]|0;L39629:do{if((g|0)<0){h=0;i=0}else{j=c[9757320+(g<<2)>>2]|0;k=c[j+980>>2]|0;do{if((k|0)==0){l=c[j+4180>>2]|0;if((l|0)==0){m=j;n=0;break}o=gj[l&4095](-7522)|0;p=o;q=c[1836236]|0;r=30261}else{p=a[k+158|0]|0;q=g;r=30261}}while(0);do{if((r|0)==30261){k=(p&255)<<8;if((q|0)<0){h=0;i=k;break L39629}j=c[9757320+(q<<2)>>2]|0;o=c[j+980>>2]|0;if((o|0)==0){m=j;n=k;break}h=a[o+157|0]|0;i=k;break L39629}}while(0);k=c[m+4180>>2]|0;if((k|0)==0){h=0;i=n;break}h=gj[k&4095](-7523)|0;i=n}}while(0);n=h&255;h=n|i;c[2161338]=1;switch(d|0){case 65:{d=h+1|0;m=d&65535;q=c[1836236]|0;do{if((q|0)<0){s=0}else{p=c[9757320+(q<<2)>>2]|0;r=c[p+76+((d>>>8&255)<<2)>>2]|0;if((r|0)!=0){s=a[r+(d&255)|0]|0;break}r=c[p+4180>>2]|0;if((r|0)==0){s=0;break}s=gj[r&4095](m)|0}}while(0);a[9533344]=s;return};case 14:{a[9533344]=-1;return};case 1:{a[9533344]=106;return};case 64:{s=h&65535;m=c[1836236]|0;do{if((m|0)<0){t=0}else{d=c[9757320+(m<<2)>>2]|0;q=c[d+76+((i>>>8&255)<<2)>>2]|0;if((q|0)!=0){t=a[q+n|0]|0;break}q=c[d+4180>>2]|0;if((q|0)==0){t=0;break}t=gj[q&4095](s)|0}}while(0);a[9533344]=t;return};case 66:{t=h+2|0;h=t&65535;s=c[1836236]|0;do{if((s|0)<0){u=0}else{n=c[9757320+(s<<2)>>2]|0;i=c[n+76+((t>>>8&255)<<2)>>2]|0;if((i|0)!=0){u=a[i+(t&255)|0]|0;break}i=c[n+4180>>2]|0;if((i|0)==0){u=0;break}u=gj[i&4095](h)|0}}while(0);a[9533344]=u&15;return};default:{a[9533344]=-128;return}}}else if((f|0)==57091){u=e&255;c[2385714]=u>>>4&1;h=u<<3&256;u=c[2387130]|0;t=c[9757320+(c[1836236]<<2)>>2]|0;s=u+h|0;c[t+960>>2]=s;c[t+1984>>2]=s;s=u+(h|512)|0;c[t+964>>2]=s;c[t+1988>>2]=s;a[c[3528674]|0]=e&1^1;return}else if((f|0)==54272){a[c[3528222]|0]=e;if(!(a[7344928]|0)){a[7012632]=1;return}e=c[1836236]|0;f=c[9757320+(e<<2)>>2]|0;if((f|0)!=0){s=f;gGC(s|0,9706056,76)|0}c[9752472+(e<<2)>>2]=c[2433530];c[14113936+(e<<2)>>2]=c[2076596];c[9669104+(e<<2)>>2]=c[3541536];c[1836236]=-1;e=c[2439331]|0;if((e|0)!=0){s=e;gGC(9706056,s|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;s=(c[2433530]|0)+12|0;c[2433530]=s;e=c[1836236]|0;f=c[9757320+(e<<2)>>2]|0;if((f|0)!=0){t=f;gGC(t|0,9706056,76)|0}c[9752472+(e<<2)>>2]=s;c[14113936+(e<<2)>>2]=c[2076596];c[9669104+(e<<2)>>2]=c[3541536];c[1836236]=-1;e=c[2439330]|0;if((e|0)!=0){s=e;gGC(9706056,s|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;return}else{return}}function eWv(b){b=b|0;var d=0,e=0;d=b&65535;switch(d|0){case 53248:{c[2161338]=0;e=a[9533344]|0;break};case 54272:{a[638608]=0;e=a[9553928]|0;break};case 55296:case 55297:case 55298:{e=a[9634808+(d&3)|0]|0;break};case 55299:{e=a[9550272]&63;break};case 55300:{e=a[9550273]|0;break};case 55301:{d=(c[2161344]|0)==0|0;e=((c[2161338]|0)==0?d:d|2)&255;break};case 55302:{e=a[9550274]|0;break};case 55303:{e=a[9550276]|0;break};case 54273:{e=a[638608]|0?-1:-3;break};default:{e=0}}return e|0}function eWw(d,e){d=d|0;e=e|0;var f=0;f=d&65535;switch(f|0){case 56832:{US(0,gD[c[2385643]&8191]()|0);b[4771272]=~~(+(b[9753784+((e&255)<<1)>>1]|0)*+h[1192819])&65535;return};case 55808:{a[7344928]=1;if(!(a[7012632]|0)){return}if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12;a[7012632]=0;return};case 51200:case 51201:{d=e&255;if((f&1|0)==0){c[3542228]=d&15;return}f=c[3542228]|0;if((f|0)>15){return}do{if((f|0)<14){if((f|0)!=13){if((a[14168916+f|0]|0)==e<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(0,f,d);return};case 55296:{a[9553928]=e;a[638608]=1;return};case 56320:{a[7344928]=0;return};default:{return}}}function eWx(b){b=b|0;var d=0;if(b<<16>>16!=-10240){d=0;return d|0}d=a[c[3528222]|0]|0;return d|0}function eWy(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4716172+(b*112|0)>>2];c[a+104>>2]=c[4716176+(b*112|0)>>2];c[a+108>>2]=c[4716180+(b*112|0)>>2];d=0;return d|0}function eWz(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=4716072+(b*112|0);e=0;return e|0}function eWA(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1922592+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eWB(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>73){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5406072+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eWC(){a[7006512]=0;return eWQ()|0}function eWD(){var b=0,d=0,e=0,f=0;c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}fwZ();a[8451544]=0;a[8451536]=0;a[9533800]=0;a[8451528]=0;a[8451520]=0;a[9533792]=0;a[8451512]=0;a[8451504]=0;a[9533784]=0;a[9533352]=0;a[9533344]=0;c[2161338]=0;c[2161344]=0;c[2424906]=0;c[2443666]=0;c[2385780]=0;c[3528996]=0;c[2113008]=0;c[2076598]=0;c[2383582]=0;UT();b=c[2414892]|0;d=0;while(1){if((d|0)>=1024){e=30394;break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==(b|0)){break}else{d=d+1|0}}if((e|0)==30394){c[2414892]=0;return 0}gGr(b);c[f>>2]=0;c[2414892]=0;return 0}function eWE(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if((a[9623728]|0)!=0){a[9623728]=0;d=c[2414594]|0;gGz(d|0,0,(c[2411544]|0)-d|0);d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;h=c[2417276]|0;c[3541536]=h;c[1836236]=0;gGz(9706056,0,76);if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=h;c[1836236]=-1;h=c[2439331]|0;g=(h|0)==0;if(!g){f=h;gGC(9706056,f|0,76)|0}f=c[2438119]|0;c[2433530]=f;e=c[3528485]|0;c[2076596]=e;d=c[2417277]|0;c[3541536]=d;c[1836236]=1;gGz(9706056,0,76);if(!g){g=h;gGC(g|0,9706056,76)|0}c[2438119]=f;c[3528485]=e;c[2417277]=d;c[1836236]=-1;f42();a[8451544]=0;a[8451536]=0;a[9533800]=0;a[8451528]=0;a[8451520]=0;a[9533792]=0;a[8451512]=0;a[8451504]=0;a[9533784]=0;a[9533352]=0;a[9533344]=0;c[2161338]=0;c[2161344]=0;mB(0);d=c[2405758]|0;if((d|0)>0){e=0;do{c[9542560+(e<<5)>>2]=0;b[9542544+(e<<5)>>1]=0;e=e+1|0;}while((e|0)<(d|0))}a[9553928]=0;a[638608]=0;a[7344928]=0;a[7012632]=0;c[2385714]=0}d=c[2385548]|0;if((d|0)>0){gGz(9752472,0,((d|0)>1?d<<2:4)|0)}c[2433530]=0;gGz(9550272,-1|0,5);d=0;e=-1;f=-1;g=-1;do{e=((a[9632776+d|0]&1)<<d^e&255)&255;f=((a[9630672+d|0]&1)<<d^f&255)&255;g=((a[9629288+d|0]&1)<<d^g&255)&255;d=d+1|0;}while((d|0)<8);a[9550272]=e;a[9550273]=f;a[9550274]=g;a[9550275]=-1;a[9550276]=-1;g=0;do{f=c[2439330]|0;if((f|0)!=0){e=f;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;e=c[2438118]|0;c[2433530]=e;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;if((a[f+4188|0]|0)==0){f=gfc(894)|0;i=(c[2433530]|0)+f|0}else{i=e+894|0}c[2433530]=i;e=(g|0)==99;if(e){a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0}f=c[1836236]|0;d=c[9757320+(f<<2)>>2]|0;if((d|0)!=0){h=d;gGC(h|0,9706056,76)|0}c[9752472+(f<<2)>>2]=c[2433530];c[14113936+(f<<2)>>2]=c[2076596];c[9669104+(f<<2)>>2]=c[3541536];c[1836236]=-1;f=c[2439331]|0;if((f|0)!=0){h=f;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;h=c[2438119]|0;c[2433530]=h;c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;if((a[f+4188|0]|0)==0){f=gfc(666)|0;j=(c[2433530]|0)+f|0}else{j=h+666|0}c[2433530]=j;if((g|0)==49){a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0}if(e){a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0}e=c[1836236]|0;h=c[9757320+(e<<2)>>2]|0;if((h|0)!=0){f=h;gGC(f|0,9706056,76)|0}c[9752472+(e<<2)>>2]=c[2433530];c[14113936+(e<<2)>>2]=c[2076596];c[9669104+(e<<2)>>2]=c[3541536];c[1836236]=-1;if(!(a[7006512]|0)){f4Y(512)|0}g=g+1|0;}while((g|0)<100);g=c[2439331]|0;if((g|0)!=0){j=g;gGC(9706056,j|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;j=c[2112964]|0;if((j|0)==0){k=1;l=g}else{g=a[9688]|0?534:0;mF(9755976,j,g,0);UR(j,g);g=c[1836236]|0;k=g;l=c[9757320+(g<<2)>>2]|0}if((l|0)!=0){g=l;gGC(g|0,9706056,76)|0}c[9752472+(k<<2)>>2]=c[2433530];c[14113936+(k<<2)>>2]=c[2076596];c[9669104+(k<<2)>>2]=c[3541536];c[1836236]=-1;if((c[2112968]|0)==0){return 0}k=c[(c[642608+(c[2436]<<2)>>2]|0)+112>>2]|0;if((k|0)==0){return 0}gD[k&8191]()|0;return 0}function eWF(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;if((a[9547184]|0)==0){b=c[3529926]|0}else{d=c[2387130]|0;e=c[3529926]|0;f=0;while(1){g=a[d+f|0]|0;h=a[d+(f+512)|0]|0;i=(g&255)>>>4;c[e+(f<<2)>>2]=((h<<4|h&8)&255)>>>3|((g<<4|g&8)&255)<<8&63488|((i<<4|i)&255)<<3&2016;i=f+1|0;if((i|0)<512){f=i}else{b=e;break}}}eWS(0,0);eWS(1,0);eWS(2,1);eWS(3,1);eWP(0,0);eWP(128,0);R8(b);return 0}function eWG(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2853772+(b*112|0)>>2];c[a+104>>2]=c[2853776+(b*112|0)>>2];c[a+108>>2]=c[2853780+(b*112|0)>>2];d=0;return d|0}function eWH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=2853672+(b*112|0);e=0;return e|0}function eWI(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2489396+(b*112|0)>>2];c[a+104>>2]=c[2489400+(b*112|0)>>2];c[a+108>>2]=c[2489404+(b*112|0)>>2];d=0;return d|0}function eWJ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=2489296+(b*112|0);e=0;return e|0}function eWK(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1224152+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eWL(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>75){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3656784+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eWM(){a[7006512]=1;return eWQ()|0}function eWN(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2491300+(b*112|0)>>2];c[a+104>>2]=c[2491304+(b*112|0)>>2];c[a+108>>2]=c[2491308+(b*112|0)>>2];d=0;return d|0}function eWO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=2491200+(b*112|0);e=0;return e|0}function eWP(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=(e|0)==0;e=c[2386406]|0;g=c[3528674]|0;h=c[2112926]|0;i=c[3530540]|0;j=0;do{k=d[e+(159-j)|0]|0;l=k<<2&124;do{if(!((k&128|0)!=(b|0)&f)){m=d[e+l|0]|0;n=d[e+(l|1)|0]|0;if(f){o=n<<4&768}else{o=n<<3&256}p=o|d[e+(l|2)|0];q=d[e+(l|3)|0]|0;r=n&64;if((a[g]|0)==0){s=r;t=q;u=240-m|0}else{s=r^192;t=240-q&255;u=m}m=u-17|0;q=(n&128|0)!=0;r=(s|0)!=0;v=n&15;do{if(q){if(r){SN(h,p,t,m,v,4,15,256,i);break}else{SL(h,p,t,m,v,4,15,256,i);break}}else{if(r){SJ(h,p,t,m,v,4,15,256,i);break}else{SH(h,p,t,m,v,4,15,256,i);break}}}while(0);if(t>>>0<=240){break}n=t|-256;if(q){if(r){SN(h,p,n,m,v,4,15,256,i);break}else{SL(h,p,n,m,v,4,15,256,i);break}}else{if(r){SJ(h,p,n,m,v,4,15,256,i);break}else{SH(h,p,n,m,v,4,15,256,i);break}}}}while(0);j=j+1|0;}while((j|0)<32);return}function eWQ(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0.0,aS=0,aT=0;e=i;i=i+5840|0;f=e+2240|0;g=e+2352|0;j=e+2360|0;k=e+2472|0;l=e+2480|0;m=e+2592|0;n=e+2600|0;o=e+2712|0;p=e+2720|0;q=e+2832|0;r=e+2840|0;s=e+2952|0;t=e+2960|0;u=e+3072|0;v=e+3080|0;w=e+3192|0;x=e+3200|0;y=e+3312|0;z=e+3320|0;A=e+3432|0;B=e+3440|0;C=e+3552|0;D=e+3560|0;E=e+3672|0;F=e+3680|0;G=e+3792|0;H=e+3800|0;I=e+3912|0;J=e+3920|0;K=e+4032|0;L=e+4040|0;M=e+4152|0;N=e+4160|0;O=e+4272|0;P=e+4280|0;Q=e+4392|0;R=e+4400|0;S=e+4512|0;T=e+4520|0;U=e+4632|0;V=e+4640|0;W=e+4752|0;X=e+4760|0;Y=e+4872|0;Z=e+4880|0;_=e+4992|0;$=e+5e3|0;aa=e+5112|0;ab=e+5120|0;ac=e+5232|0;ad=e+5240|0;ae=e+5352|0;af=e+5360|0;ah=e+5472|0;ai=e+5480|0;aj=e+5592|0;ak=e+5600|0;al=e+5712|0;am=e+5720|0;an=e+5832|0;c[2414892]=0;c[3529226]=0;c[3529182]=65536;c[2387322]=131072;c[3530776]=133120;c[3530540]=395264;c[3529926]=657408;c[2414594]=659456;c[2386194]=659456;c[3529314]=663552;c[3529276]=665600;c[2387130]=667648;c[2386406]=668672;c[2387334]=668928;c[3528222]=669056;c[3528674]=669057;c[2411544]=669058;c[2438994]=669058;ao=a[9688]|0?1068:0;ap=ao+669058|0;c[2438995]=ap;aq=ap+ao|0;c[2438996]=aq;ap=aq+ao|0;c[2414084]=ap;ao=ap;ap=0;while(1){if((ap|0)>=1024){break}ar=9638528+(ap<<2)|0;if((c[ar>>2]|0)==0){as=30533;break}else{ap=ap+1|0}}do{if((as|0)==30533){ap=gGq(ao)|0;c[ar>>2]=ap;if((ap|0)==0){break}gGz(ap|0,0,ao|0);c[2414892]=ap;gGz(ap|0,0,ao|0);c[3529226]=ap;c[3529182]=ap+65536;c[2387322]=ap+131072;c[3530776]=ap+133120;c[3530540]=ap+395264;c[3529926]=ap+657408;aq=ap+659456|0;c[2414594]=aq;c[2386194]=aq;c[3529314]=ap+663552;c[3529276]=ap+665600;c[2387130]=ap+667648;c[2386406]=ap+668672;c[2387334]=ap+668928;c[3528222]=ap+669056;c[3528674]=ap+669057;aq=ap+669058|0;c[2411544]=aq;c[2438994]=aq;aq=a[9688]|0?1068:0;at=aq+669058|0;c[2438995]=ap+at;au=at+aq|0;c[2438996]=ap+au;c[2414084]=ap+(au+aq);aq=a[7006512]&1;do{if((aq|0)==0){if((c[3542200]|0)==0){av=1;i=e;return av|0}au=am+108|0;c[au>>2]=0;at=am+100|0;c[at>>2]=0;aw=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aw&16383](am,0)|0;do{if((c[au>>2]|0)!=0){aw=c[at>>2]|0;c[an>>2]=9534384;ax=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ax&16383](an,0,0)|0;if((aw|0)<1){av=1;i=e;return av|0}if((gzL(ap,0,0)|0)==0){break}else{av=1}i=e;return av|0}}while(0);at=(c[3529226]|0)+16384|0;if((c[3542200]|0)==0){av=1;i=e;return av|0}au=ak+108|0;c[au>>2]=0;aw=ak+100|0;c[aw>>2]=0;ax=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ax&16383](ak,1)|0;do{if((c[au>>2]|0)!=0){ax=c[aw>>2]|0;c[al>>2]=9534384;ay=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ay&16383](al,1,0)|0;if((ax|0)<1){av=1;i=e;return av|0}if((gzL(at,0,1)|0)==0){break}else{av=1}i=e;return av|0}}while(0);at=(c[3529226]|0)+32768|0;if((c[3542200]|0)==0){av=1;i=e;return av|0}aw=ai+108|0;c[aw>>2]=0;au=ai+100|0;c[au>>2]=0;ax=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ax&16383](ai,2)|0;do{if((c[aw>>2]|0)!=0){ax=c[au>>2]|0;c[aj>>2]=9534384;ay=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ay&16383](aj,2,0)|0;if((ax|0)<1){av=1;i=e;return av|0}if((gzL(at,0,2)|0)==0){break}else{av=1}i=e;return av|0}}while(0);at=c[3529182]|0;if((c[3542200]|0)==0){av=1;i=e;return av|0}au=af+108|0;c[au>>2]=0;aw=af+100|0;c[aw>>2]=0;ax=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ax&16383](af,3)|0;do{if((c[au>>2]|0)!=0){ax=c[aw>>2]|0;c[ah>>2]=9534384;ay=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ay&16383](ah,3,0)|0;if((ax|0)<1){av=1;i=e;return av|0}if((gzL(at,0,3)|0)==0){break}else{av=1}i=e;return av|0}}while(0);at=(c[3529182]|0)+8192|0;if((c[3542200]|0)==0){av=1;i=e;return av|0}aw=ad+108|0;c[aw>>2]=0;au=ad+100|0;c[au>>2]=0;ax=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ax&16383](ad,4)|0;do{if((c[aw>>2]|0)!=0){ax=c[au>>2]|0;c[ae>>2]=9534384;ay=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ay&16383](ae,4,0)|0;if((ax|0)<1){av=1;i=e;return av|0}if((gzL(at,0,4)|0)==0){break}else{av=1}i=e;return av|0}}while(0);at=c[3530776]|0;if((c[3542200]|0)==0){av=1;i=e;return av|0}au=ab+108|0;c[au>>2]=0;aw=ab+100|0;c[aw>>2]=0;ax=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ax&16383](ab,5)|0;do{if((c[au>>2]|0)!=0){ax=c[aw>>2]|0;c[ac>>2]=9534384;ay=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ay&16383](ac,5,0)|0;if((ax|0)<1){av=1;i=e;return av|0}if((gzL(at,0,5)|0)==0){break}else{av=1}i=e;return av|0}}while(0);at=(c[3530776]|0)+16384|0;if((c[3542200]|0)==0){av=1;i=e;return av|0}aw=$+108|0;c[aw>>2]=0;au=$+100|0;c[au>>2]=0;ax=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ax&16383]($,6)|0;do{if((c[aw>>2]|0)!=0){ax=c[au>>2]|0;c[aa>>2]=9534384;ay=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ay&16383](aa,6,0)|0;if((ax|0)<1){av=1;i=e;return av|0}if((gzL(at,0,6)|0)==0){break}else{av=1}i=e;return av|0}}while(0);at=(c[3530776]|0)+32768|0;if((c[3542200]|0)==0){av=1;i=e;return av|0}au=Z+108|0;c[au>>2]=0;aw=Z+100|0;c[aw>>2]=0;ax=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ax&16383](Z,7)|0;do{if((c[au>>2]|0)!=0){ax=c[aw>>2]|0;c[_>>2]=9534384;ay=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ay&16383](_,7,0)|0;if((ax|0)<1){av=1;i=e;return av|0}if((gzL(at,0,7)|0)==0){break}else{av=1}i=e;return av|0}}while(0);at=(c[3530776]|0)+49152|0;if((c[3542200]|0)==0){av=1;i=e;return av|0}aw=X+108|0;c[aw>>2]=0;au=X+100|0;c[au>>2]=0;ax=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ax&16383](X,8)|0;do{if((c[aw>>2]|0)!=0){ax=c[au>>2]|0;c[Y>>2]=9534384;ay=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ay&16383](Y,8,0)|0;if((ax|0)<1){av=1;i=e;return av|0}if((gzL(at,0,8)|0)==0){break}else{av=1}i=e;return av|0}}while(0);at=(c[3530776]|0)+65536|0;if((c[3542200]|0)==0){av=1;i=e;return av|0}au=V+108|0;c[au>>2]=0;aw=V+100|0;c[aw>>2]=0;ax=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ax&16383](V,9)|0;do{if((c[au>>2]|0)!=0){ax=c[aw>>2]|0;c[W>>2]=9534384;ay=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ay&16383](W,9,0)|0;if((ax|0)<1){av=1;i=e;return av|0}if((gzL(at,0,9)|0)==0){break}else{av=1}i=e;return av|0}}while(0);at=(c[3530776]|0)+81920|0;if((c[3542200]|0)==0){av=1;i=e;return av|0}aw=T+108|0;c[aw>>2]=0;au=T+100|0;c[au>>2]=0;ax=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ax&16383](T,10)|0;do{if((c[aw>>2]|0)!=0){ax=c[au>>2]|0;c[U>>2]=9534384;ay=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ay&16383](U,10,0)|0;if((ax|0)<1){av=1;i=e;return av|0}if((gzL(at,0,10)|0)==0){break}else{av=1}i=e;return av|0}}while(0);at=(c[3530776]|0)+98304|0;if((c[3542200]|0)==0){av=1;i=e;return av|0}au=R+108|0;c[au>>2]=0;aw=R+100|0;c[aw>>2]=0;ax=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ax&16383](R,11)|0;do{if((c[au>>2]|0)!=0){ax=c[aw>>2]|0;c[S>>2]=9534384;ay=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ay&16383](S,11,0)|0;if((ax|0)<1){av=1;i=e;return av|0}if((gzL(at,0,11)|0)==0){break}else{av=1}i=e;return av|0}}while(0);at=(c[3530776]|0)+114688|0;if((c[3542200]|0)==0){av=1;i=e;return av|0}aw=P+108|0;c[aw>>2]=0;au=P+100|0;c[au>>2]=0;ax=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ax&16383](P,12)|0;do{if((c[aw>>2]|0)!=0){ax=c[au>>2]|0;c[Q>>2]=9534384;ay=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ay&16383](Q,12,0)|0;if((ax|0)<1){av=1;i=e;return av|0}if((gzL(at,0,12)|0)==0){break}else{av=1}i=e;return av|0}}while(0);at=c[2387322]|0;if((c[3542200]|0)==0){av=1;i=e;return av|0}au=N+108|0;c[au>>2]=0;aw=N+100|0;c[aw>>2]=0;ax=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ax&16383](N,13)|0;if((c[au>>2]|0)==0){az=0;break}au=c[aw>>2]|0;c[O>>2]=9534384;aw=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aw&16383](O,13,0)|0;if((au|0)<1){av=1;i=e;return av|0}if((gzL(at,0,13)|0)==0){az=0;break}else{av=1}i=e;return av|0}else if((aq|0)==1){if((c[3542200]|0)==0){av=1;i=e;return av|0}at=L+108|0;c[at>>2]=0;au=L+100|0;c[au>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](L,0)|0;do{if((c[at>>2]|0)!=0){aw=c[au>>2]|0;c[M>>2]=9534384;ax=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ax&16383](M,0,0)|0;if((aw|0)<1){av=1;i=e;return av|0}if((gzL(ap,0,0)|0)==0){break}else{av=1}i=e;return av|0}}while(0);au=(c[3529226]|0)+16384|0;if((c[3542200]|0)==0){av=1;i=e;return av|0}at=J+108|0;c[at>>2]=0;aw=J+100|0;c[aw>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](J,1)|0;do{if((c[at>>2]|0)!=0){ax=c[aw>>2]|0;c[K>>2]=9534384;ay=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ay&16383](K,1,0)|0;if((ax|0)<1){av=1;i=e;return av|0}if((gzL(au,0,1)|0)==0){break}else{av=1}i=e;return av|0}}while(0);au=(c[3529226]|0)+32768|0;if((c[3542200]|0)==0){av=1;i=e;return av|0}aw=H+108|0;c[aw>>2]=0;at=H+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](H,2)|0;do{if((c[aw>>2]|0)!=0){ax=c[at>>2]|0;c[I>>2]=9534384;ay=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ay&16383](I,2,0)|0;if((ax|0)<1){av=1;i=e;return av|0}if((gzL(au,0,2)|0)==0){break}else{av=1}i=e;return av|0}}while(0);au=c[3529182]|0;if((c[3542200]|0)==0){av=1;i=e;return av|0}at=F+108|0;c[at>>2]=0;aw=F+100|0;c[aw>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](F,3)|0;do{if((c[at>>2]|0)!=0){ax=c[aw>>2]|0;c[G>>2]=9534384;ay=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ay&16383](G,3,0)|0;if((ax|0)<1){av=1;i=e;return av|0}if((gzL(au,0,3)|0)==0){break}else{av=1}i=e;return av|0}}while(0);au=(c[3529182]|0)+8192|0;if((c[3542200]|0)==0){av=1;i=e;return av|0}aw=D+108|0;c[aw>>2]=0;at=D+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](D,4)|0;do{if((c[aw>>2]|0)!=0){ax=c[at>>2]|0;c[E>>2]=9534384;ay=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ay&16383](E,4,0)|0;if((ax|0)<1){av=1;i=e;return av|0}if((gzL(au,0,4)|0)==0){break}else{av=1}i=e;return av|0}}while(0);au=(c[3529182]|0)+16384|0;if((c[3542200]|0)==0){av=1;i=e;return av|0}at=B+108|0;c[at>>2]=0;aw=B+100|0;c[aw>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](B,5)|0;do{if((c[at>>2]|0)!=0){ax=c[aw>>2]|0;c[C>>2]=9534384;ay=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ay&16383](C,5,0)|0;if((ax|0)<1){av=1;i=e;return av|0}if((gzL(au,0,5)|0)==0){break}else{av=1}i=e;return av|0}}while(0);au=(c[3529182]|0)+24576|0;if((c[3542200]|0)==0){av=1;i=e;return av|0}aw=z+108|0;c[aw>>2]=0;at=z+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,6)|0;do{if((c[aw>>2]|0)!=0){ax=c[at>>2]|0;c[A>>2]=9534384;ay=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ay&16383](A,6,0)|0;if((ax|0)<1){av=1;i=e;return av|0}if((gzL(au,0,6)|0)==0){break}else{av=1}i=e;return av|0}}while(0);au=(c[3529182]|0)+32768|0;if((c[3542200]|0)==0){av=1;i=e;return av|0}at=x+108|0;c[at>>2]=0;aw=x+100|0;c[aw>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,7)|0;do{if((c[at>>2]|0)!=0){ax=c[aw>>2]|0;c[y>>2]=9534384;ay=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ay&16383](y,7,0)|0;if((ax|0)<1){av=1;i=e;return av|0}if((gzL(au,0,7)|0)==0){break}else{av=1}i=e;return av|0}}while(0);au=c[3530776]|0;if((c[3542200]|0)==0){av=1;i=e;return av|0}aw=v+108|0;c[aw>>2]=0;at=v+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,8)|0;do{if((c[aw>>2]|0)!=0){ax=c[at>>2]|0;c[w>>2]=9534384;ay=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ay&16383](w,8,0)|0;if((ax|0)<1){av=1;i=e;return av|0}if((gzL(au,0,8)|0)==0){break}else{av=1}i=e;return av|0}}while(0);au=(c[3530776]|0)+16384|0;if((c[3542200]|0)==0){av=1;i=e;return av|0}at=t+108|0;c[at>>2]=0;aw=t+100|0;c[aw>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,9)|0;do{if((c[at>>2]|0)!=0){ax=c[aw>>2]|0;c[u>>2]=9534384;ay=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ay&16383](u,9,0)|0;if((ax|0)<1){av=1;i=e;return av|0}if((gzL(au,0,9)|0)==0){break}else{av=1}i=e;return av|0}}while(0);au=(c[3530776]|0)+32768|0;if((c[3542200]|0)==0){av=1;i=e;return av|0}aw=r+108|0;c[aw>>2]=0;at=r+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,10)|0;do{if((c[aw>>2]|0)!=0){ax=c[at>>2]|0;c[s>>2]=9534384;ay=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ay&16383](s,10,0)|0;if((ax|0)<1){av=1;i=e;return av|0}if((gzL(au,0,10)|0)==0){break}else{av=1}i=e;return av|0}}while(0);au=(c[3530776]|0)+49152|0;if((c[3542200]|0)==0){av=1;i=e;return av|0}at=p+108|0;c[at>>2]=0;aw=p+100|0;c[aw>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,11)|0;do{if((c[at>>2]|0)!=0){ax=c[aw>>2]|0;c[q>>2]=9534384;ay=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ay&16383](q,11,0)|0;if((ax|0)<1){av=1;i=e;return av|0}if((gzL(au,0,11)|0)==0){break}else{av=1}i=e;return av|0}}while(0);au=(c[3530776]|0)+65536|0;if((c[3542200]|0)==0){av=1;i=e;return av|0}aw=n+108|0;c[aw>>2]=0;at=n+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,12)|0;do{if((c[aw>>2]|0)!=0){ax=c[at>>2]|0;c[o>>2]=9534384;ay=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ay&16383](o,12,0)|0;if((ax|0)<1){av=1;i=e;return av|0}if((gzL(au,0,12)|0)==0){break}else{av=1}i=e;return av|0}}while(0);au=(c[3530776]|0)+81920|0;if((c[3542200]|0)==0){av=1;i=e;return av|0}at=l+108|0;c[at>>2]=0;aw=l+100|0;c[aw>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,13)|0;do{if((c[at>>2]|0)!=0){ax=c[aw>>2]|0;c[m>>2]=9534384;ay=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ay&16383](m,13,0)|0;if((ax|0)<1){av=1;i=e;return av|0}if((gzL(au,0,13)|0)==0){break}else{av=1}i=e;return av|0}}while(0);au=(c[3530776]|0)+98304|0;if((c[3542200]|0)==0){av=1;i=e;return av|0}aw=j+108|0;c[aw>>2]=0;at=j+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,14)|0;do{if((c[aw>>2]|0)!=0){ax=c[at>>2]|0;c[k>>2]=9534384;ay=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ay&16383](k,14,0)|0;if((ax|0)<1){av=1;i=e;return av|0}if((gzL(au,0,14)|0)==0){break}else{av=1}i=e;return av|0}}while(0);au=(c[3530776]|0)+114688|0;if((c[3542200]|0)==0){av=1;i=e;return av|0}at=f+108|0;c[at>>2]=0;aw=f+100|0;c[aw>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,15)|0;if((c[at>>2]|0)==0){az=0;break}at=c[aw>>2]|0;c[g>>2]=9534384;gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](g,15,0)|0;if((at|0)<1){av=1;i=e;return av|0}if((gzL(au,0,15)|0)==0){az=0;break}else{av=1}i=e;return av|0}else{az=0}}while(0);while(1){if((az|0)>=1024){break}aA=9638528+(az<<2)|0;if((c[aA>>2]|0)==0){as=30658;break}else{az=az+1|0}}L40274:do{if((as|0)==30658){ap=gGq(131072)|0;c[aA>>2]=ap;if((ap|0)==0){break}gGz(ap|0,0,131072);aq=c[3530776]|0;au=0;while(1){a[ap+au|0]=~a[aq+au|0];at=au+1|0;if((at|0)<131072){au=at}else{aB=0;break}}do{au=aB<<6;gGz(aq+au|0,0,64);at=aB<<7;aw=0;do{ax=1<<3-aw;ay=(c[613072+(aw<<2)>>2]|0)+at|0;aC=0;do{aD=ay+(c[597800+(aC<<2)>>2]|0)|0;aE=(aC<<3)+au|0;aF=0;do{aG=aD+(c[612288+(aF<<2)>>2]|0)|0;if(((d[ap+((aG|0)/8|0)|0]|0)&128>>>((aG&7)>>>0)|0)!=0){aG=aq+(aE+aF)|0;a[aG]=(d[aG]|0|ax)&255}aF=aF+1|0;}while((aF|0)<8);aC=aC+1|0;}while((aC|0)<8);aw=aw+1|0;}while((aw|0)<4);aB=aB+1|0;}while((aB|0)<4096);aq=c[3530540]|0;aw=0;while(1){au=aw<<8;gGz(aq+au|0,0,256);at=aw<<9;aC=0;do{ax=1<<3-aC;ay=(c[613072+(aC<<2)>>2]|0)+at|0;aF=0;do{aE=ay+(c[597800+(aF<<2)>>2]|0)|0;aD=(aF<<4)+au|0;aG=0;do{aH=aE+(c[612288+(aG<<2)>>2]|0)|0;if(((d[ap+((aH|0)/8|0)|0]|0)&128>>>((aH&7)>>>0)|0)!=0){aH=aq+(aD+aG)|0;a[aH]=(d[aH]|0|ax)&255}aG=aG+1|0;}while((aG|0)<16);aF=aF+1|0;}while((aF|0)<16);aC=aC+1|0;}while((aC|0)<4);aC=aw+1|0;if((aC|0)<1024){aw=aC}else{aI=0;break}}while(1){if((aI|0)>=1024){break L40274}aJ=9638528+(aI<<2)|0;if((c[aJ>>2]|0)==(ap|0)){break}else{aI=aI+1|0}}gGr(ap);c[aJ>>2]=0}}while(0);fwR(0);aw=c[2439330]|0;aq=(aw|0)==0;if(!aq){aC=aw;gGC(9706056,aC|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];aC=c[3528484]|0;c[2076596]=aC;au=c[2417276]|0;c[3541536]=au;c[1836236]=0;at=c[3529226]|0;aF=0;ax=0;while(1){c[aw+76+(ax<<2)>>2]=at+(ax<<8);ay=aF+1&65535;if((ay&65535)>191){aK=0;aL=0;break}else{aF=ay;ax=ay&65535}}while(1){ax=at+(aL<<8)|0;c[aw+76+(aL+512<<2)>>2]=ax;c[aw+76+(aL+768<<2)>>2]=ax;ax=aK+1&65535;if((ax&65535)>191){break}else{aK=ax;aL=ax&65535}}at=c[2386194]|0;c[aw+844>>2]=at;c[aw+848>>2]=at+256;c[aw+852>>2]=at+512;c[aw+856>>2]=at+768;c[aw+860>>2]=at+1024;c[aw+864>>2]=at+1280;c[aw+868>>2]=at+1536;c[aw+872>>2]=at+1792;c[aw+876>>2]=at+2048;c[aw+880>>2]=at+2304;c[aw+884>>2]=at+2560;c[aw+888>>2]=at+2816;c[aw+892>>2]=at+3072;c[aw+896>>2]=at+3328;c[aw+900>>2]=at+3584;c[aw+904>>2]=at+3840;ax=192;aF=192;while(1){c[aw+76+(aF+256<<2)>>2]=at+((aF<<8)-49152);ay=ax+1&65535;if((ay&65535)>207){aM=192;aN=192;break}else{ax=ay;aF=ay&65535}}while(1){aF=at+((aN<<8)-49152)|0;c[aw+76+(aN+512<<2)>>2]=aF;c[aw+76+(aN+768<<2)>>2]=aF;aF=aM+1&65535;if((aF&65535)>207){break}else{aM=aF;aN=aF&65535}}at=c[2386406]|0;c[aw+956>>2]=at;c[aw+3004>>2]=at;c[aw+4028>>2]=at;at=c[2387130]|0;c[aw+960>>2]=at;c[aw+1984>>2]=at;c[aw+3008>>2]=at;c[aw+4032>>2]=at;aF=at+512|0;c[aw+964>>2]=aF;c[aw+1988>>2]=aF;c[aw+3012>>2]=aF;c[aw+4036>>2]=aF;aF=c[3529314]|0;c[aw+972>>2]=aF;at=aF+256|0;c[aw+976>>2]=at;ax=aF+512|0;c[aw+980>>2]=ax;ay=aF+768|0;c[aw+984>>2]=ay;aG=aF+1024|0;c[aw+988>>2]=aG;aD=aF+1280|0;c[aw+992>>2]=aD;aE=aF+1536|0;c[aw+996>>2]=aE;aH=aF+1792|0;c[aw+1e3>>2]=aH;c[aw+1996>>2]=aF;c[aw+2e3>>2]=at;c[aw+2004>>2]=ax;c[aw+2008>>2]=ay;c[aw+2012>>2]=aG;c[aw+2016>>2]=aD;c[aw+2020>>2]=aE;c[aw+2024>>2]=aH;c[aw+3020>>2]=aF;c[aw+4044>>2]=aF;c[aw+3024>>2]=at;c[aw+4048>>2]=at;c[aw+3028>>2]=ax;c[aw+4052>>2]=ax;c[aw+3032>>2]=ay;c[aw+4056>>2]=ay;c[aw+3036>>2]=aG;c[aw+4060>>2]=aG;c[aw+3040>>2]=aD;c[aw+4064>>2]=aD;c[aw+3044>>2]=aE;c[aw+4068>>2]=aE;c[aw+3048>>2]=aH;c[aw+4072>>2]=aH;c[aw+4184>>2]=2104;c[aw+4180>>2]=3060;if(!aq){aH=aw;gGC(aH|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=aC;c[2417276]=au;c[1836236]=-1;fwR(1);aH=c[2439331]|0;if((aH|0)!=0){aE=aH;gGC(9706056,aE|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];aE=c[3528485]|0;c[2076596]=aE;aD=c[2417277]|0;c[3541536]=aD;c[1836236]=1;aG=c[3529182]|0;ay=0;ax=0;while(1){c[aH+76+(ax<<2)>>2]=aG+(ax<<8);at=ay+1&65535;if((at&65535)>191){aO=0;aP=0;break}else{ay=at;ax=at&65535}}while(1){ax=aG+(aP<<8)|0;c[aH+76+(aP+512<<2)>>2]=ax;c[aH+76+(aP+768<<2)>>2]=ax;ax=aO+1&65535;if((ax&65535)>191){break}else{aO=ax;aP=ax&65535}}ax=c[3529276]|0;c[aH+844>>2]=ax;ay=ax+256|0;c[aH+848>>2]=ay;au=ax+512|0;c[aH+852>>2]=au;aC=ax+768|0;c[aH+856>>2]=aC;aw=ax+1024|0;c[aH+860>>2]=aw;aq=ax+1280|0;c[aH+864>>2]=aq;at=ax+1536|0;c[aH+868>>2]=at;aF=ax+1792|0;c[aH+872>>2]=aF;c[aH+1868>>2]=ax;c[aH+1872>>2]=ay;c[aH+1876>>2]=au;c[aH+1880>>2]=aC;c[aH+1884>>2]=aw;c[aH+1888>>2]=aq;c[aH+1892>>2]=at;c[aH+1896>>2]=aF;c[aH+2892>>2]=ax;c[aH+3916>>2]=ax;c[aH+2896>>2]=ay;c[aH+3920>>2]=ay;c[aH+2900>>2]=au;c[aH+3924>>2]=au;c[aH+2904>>2]=aC;c[aH+3928>>2]=aC;c[aH+2908>>2]=aw;c[aH+3932>>2]=aw;c[aH+2912>>2]=aq;c[aH+3936>>2]=aq;c[aH+2916>>2]=at;c[aH+3940>>2]=at;c[aH+2920>>2]=aF;c[aH+3944>>2]=aF;c[aH+972>>2]=aG+57344;c[aH+976>>2]=aG+57600;c[aH+980>>2]=aG+57856;c[aH+984>>2]=aG+58112;c[aH+988>>2]=aG+58368;c[aH+992>>2]=aG+58624;c[aH+996>>2]=aG+58880;c[aH+1e3>>2]=aG+59136;c[aH+1004>>2]=aG+59392;c[aH+1008>>2]=aG+59648;c[aH+1012>>2]=aG+59904;c[aH+1016>>2]=aG+60160;c[aH+1020>>2]=aG+60416;c[aH+1024>>2]=aG+60672;c[aH+1028>>2]=aG+60928;c[aH+1032>>2]=aG+61184;aF=224;at=224;while(1){aq=aG+(at<<8)|0;c[aH+76+(at+512<<2)>>2]=aq;c[aH+76+(at+768<<2)>>2]=aq;aq=aF+1&65535;if((aq&65535)>239){break}else{aF=aq;at=aq&65535}}c[aH+4184>>2]=740;c[aH+4180>>2]=1744;at=aH;gGC(at|0,9706056,76)|0;c[2438119]=c[2433530];c[3528485]=aE;c[2417277]=aD;c[1836236]=-1;at=c[2387322]|0;aF=c[2387334]|0;c[2424906]=2536;c[2443666]=2047;c[2385780]=7;c[3528996]=3;gGz(9702704,0,32);gGz(9703728,0,32);gGz(9704752,0,32);aG=c[2427044]|0;c[9681616+(aG<<3)>>2]=809328;c[9681620+(aG<<3)>>2]=0;c[2427044]=aG+1;aG=2;while(1){aq=aF+((aG<<3)-16)|0;c[9702704+(aG<<2)>>2]=aq;c[9703728+(aG<<2)>>2]=aq;c[9704752+(aG<<2)>>2]=aq;aq=aG+1|0;if((aq|0)<16){aG=aq}else{aQ=16;break}}do{aG=at+(aQ<<3)|0;c[9702704+(aQ<<2)>>2]=aG;c[9704752+(aQ<<2)>>2]=aG;aQ=aQ+1|0;}while((aQ|0)<256);c[3528586]=3404;c[2385590]=1124;at=a[9680]|0?32e3:0;c[3542220]=11200;if((c[2113008]|0)==0){gGz(14168888,0,252);c[3542223]=at;gGz(14168896,0,16);c[3542234]=~~((+(at|0)*32768.0*8.0+1.0e6)/2.0e6);at=31;aR=32767.0;while(1){c[14169012+(at<<2)>>2]=~~(aR+.5);aG=at-1|0;if((aG|0)>0){at=aG;aR=aR/1.188502227}else{break}}c[3542253]=0;h[1771269]=1.0;h[1771270]=1.0;h[1771271]=1.0;c[3542574]=3;c[3542575]=3;c[3542576]=3;mB(0);c[2113008]=(c[2113008]|0)+1}h[1771269]=.1;c[3542574]=3;h[1771270]=.1;c[3542575]=3;h[1771271]=.1;c[3542576]=3;c[2405758]=1;gGz(9542544,0,32);c[2385641]=1;h[1192819]=1.0;c[2385642]=3;c[2385643]=2180;at=0;do{aG=at*257|0;b[9732544+(at<<1)>>1]=((aG|0)/2|0)&65535;b[9753784+(at<<1)>>1]=aG+32768&65535;at=at+1|0;}while((at|0)<256);c[3528842]=1;h[1192819]=.2;c[2385642]=3;at=c[642608+(c[2436]<<2)>>2]|0;aG=c[at+128>>2]|0;if((c[at+52>>2]&4|0)==0){c[2113068]=aG;aF=c[at+132>>2]|0;c[2113070]=aF;c[2443814]=aG;c[2440436]=aF;aS=aG;aT=aF}else{c[2113070]=aG;aF=c[at+132>>2]|0;c[2113068]=aF;c[2440436]=aG;c[2443814]=aF;aS=aF;aT=aG}aG=ag(aS<<1,aT)|0;aF=gGq(aG)|0;c[2112926]=aF;if((aF|0)!=0){gGz(aF|0,0,aG|0)}a[9623728]=0;aG=c[2414594]|0;gGz(aG|0,0,(c[2411544]|0)-aG|0);aG=c[2439330]|0;aF=(aG|0)==0;if(!aF){at=aG;gGC(9706056,at|0,76)|0}at=c[2438118]|0;c[2433530]=at;aD=c[3528484]|0;c[2076596]=aD;aE=c[2417276]|0;c[3541536]=aE;c[1836236]=0;gGz(9706056,0,76);if(!aF){aF=aG;gGC(aF|0,9706056,76)|0}c[2438118]=at;c[3528484]=aD;c[2417276]=aE;c[1836236]=-1;aE=c[2439331]|0;aD=(aE|0)==0;if(!aD){at=aE;gGC(9706056,at|0,76)|0}at=c[2438119]|0;c[2433530]=at;aF=c[3528485]|0;c[2076596]=aF;aG=c[2417277]|0;c[3541536]=aG;c[1836236]=1;gGz(9706056,0,76);if(!aD){aD=aE;gGC(aD|0,9706056,76)|0}c[2438119]=at;c[3528485]=aF;c[2417277]=aG;c[1836236]=-1;f42();a[8451544]=0;a[8451536]=0;a[9533800]=0;a[8451528]=0;a[8451520]=0;a[9533792]=0;a[8451512]=0;a[8451504]=0;a[9533784]=0;a[9533352]=0;a[9533344]=0;c[2161338]=0;c[2161344]=0;mB(0);aG=c[2405758]|0;if((aG|0)>0){aF=0;do{c[9542560+(aF<<5)>>2]=0;b[9542544+(aF<<5)>>1]=0;aF=aF+1|0;}while((aF|0)<(aG|0))}a[9553928]=0;a[638608]=0;a[7344928]=0;a[7012632]=0;c[2385714]=0;av=0;i=e;return av|0}}while(0);c[2414892]=0;av=1;i=e;return av|0}function eWR(){return~~((a[9688]|0?534.0:0.0)*(+((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)/(4.0e6/(+(c[2424]|0)/100.0))))|0}function eWS(a,e){a=a|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;f=c[595240+(a<<2)>>2]|0;g=(e|0)==0;e=(a|0)==0;h=(a|0)==2;a=c[2386406]|0;i=c[2386194]|0;j=c[2385714]<<11;k=c[2112926]|0;l=c[3530776]|0;m=c[2113070]|0;n=0;do{o=n&31;p=o<<3;q=(n>>5<<3)-16-(d[a+(o|160)|0]|0)|0;o=(q|0)<-7?q+256|0:q;L40384:do{if((o|0)<(m|0)){q=n<<1;r=d[i+(q|1)|0]|0;s=d[i+q|0]|0|r<<2&768|j|1024;q=r&16;t=r&8;u=r<<4&240;if(!g){if((r&32|0)==0){break}}if(e){r=(t|0)!=0;v=u>>>4;if((q|0)==0){if(r){Sl(k,s,p,o,v,4,0,l);break}else{Sj(k,s,p,o,v,4,0,l);break}}else{if(r){Sp(k,s,p,o,v,4,0,l);break}else{Sn(k,s,p,o,v,4,0,l);break}}}v=(q|0)!=0;if(h){q=(t|0)!=0;r=u>>>4;if(v){if(q){Sx(k,s,p,o,r,4,15,0,l);break}else{Sv(k,s,p,o,r,4,15,0,l);break}}else{if(q){St(k,s,p,o,r,4,15,0,l);break}else{Sr(k,s,p,o,r,4,15,0,l);break}}}r=v?56:0;v=(t|0)==0?r:r|7;r=s<<6;s=c[2113068]|0;t=o;q=0;while(1){L40415:do{if((t|0)>-1&(t|0)<(m|0)){w=ag(s,t)|0;x=q<<3;y=p;z=0;while(1){do{if((y|0)<(s|0)){A=d[l+(((z|x)^v)+r)|0]|0;if((1<<A&f|0)!=0){break}b[k+(y+w<<1)>>1]=(A|u)&65535}}while(0);A=z+1|0;if((A|0)>=8){break L40415}y=y+1|0;z=A}}}while(0);z=q+1|0;if((z|0)>=8){break L40384}t=t+1|0;q=z}}}while(0);n=n+1|0;}while((n|0)<1024);return}function eWT(a){a=a|0;return 0}function eWU(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=b-2621440|0;if(e>>>0>=81920){f=b-2883584|0;if(f>>>0<81920){g=f^1;h=(c[3532279]|0)+g|0;do{if((a[h]|0)!=d<<24>>24){i=(f|0)>-1;if((c[3532285]|0)==0){if(i&(g|0)<16384){a[14129209]=1}if(i&(g|0)<32768){a[14129129]=1}if((g-24576|0)>>>0>=4096){break}a[14129201]=1;break}else{if(i&(g|0)<32768){a[14129209]=1}if((g-32768|0)>>>0<32768){a[14129129]=1}if((g-69632|0)>>>0>=4096){break}a[14129201]=1;break}}}while(0);a[h]=d;return}h=b-3145728|0;if(h>>>0>=81920){return}b=h^1;g=(c[3532280]|0)+b|0;do{if((a[g]|0)!=d<<24>>24){f=(h|0)>-1;if((c[3532286]|0)==0){if(f&(b|0)<16384){a[14129210]=1}if(f&(b|0)<32768){a[14129130]=1}if((b-24576|0)>>>0>=4096){break}a[14129202]=1;break}else{if(f&(b|0)<32768){a[14129210]=1}if((b-32768|0)>>>0<32768){a[14129130]=1}if((b-69632|0)>>>0>=4096){break}a[14129202]=1;break}}}while(0);a[g]=d;return}g=e^1;b=(c[3532278]|0)+g|0;do{if((a[b]|0)!=d<<24>>24){h=(e|0)>-1;if((c[3532284]|0)==0){if(h&(g|0)<16384){a[14129208]=1}if(h&(g|0)<32768){a[14129128]=1}if((g-24576|0)>>>0>=4096){break}a[14129200]=1;break}else{if(h&(g|0)<32768){a[14129208]=1}if((g-32768|0)>>>0<32768){a[14129128]=1}if((g-69632|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);h=(c[3532279]|0)+g|0;do{if((a[h]|0)!=d<<24>>24){f=(e|0)>-1;if((c[3532285]|0)==0){if(f&(g|0)<16384){a[14129209]=1}if(f&(g|0)<32768){a[14129129]=1}if((g-24576|0)>>>0>=4096){break}a[14129201]=1;break}else{if(f&(g|0)<32768){a[14129209]=1}if((g-32768|0)>>>0<32768){a[14129129]=1}if((g-69632|0)>>>0>=4096){break}a[14129201]=1;break}}}while(0);f=(c[3532280]|0)+g|0;do{if((a[f]|0)!=d<<24>>24){i=(e|0)>-1;if((c[3532286]|0)==0){if(i&(g|0)<16384){a[14129210]=1}if(i&(g|0)<32768){a[14129130]=1}if((g-24576|0)>>>0>=4096){break}a[14129202]=1;break}else{if(i&(g|0)<32768){a[14129210]=1}if((g-32768|0)>>>0<32768){a[14129130]=1}if((g-69632|0)>>>0>=4096){break}a[14129202]=1;break}}}while(0);a[b]=d;a[h]=d;a[f]=d;return}function eWV(e){e=e|0;var f=0,g=0,h=0;if((e|0)==2097152){switch(d[9757560]|0|0){case 0:{f=a[14129048]|0;break};case 1:{f=a[14129049]|0;break};case 2:{f=a[14129040]|0;break};case 3:{f=a[14129041]|0;break};case 4:{f=a[9757556]|0;break};case 7:{f=a[14129042]|0;break};default:{f=0}}g=f&255;return g|0}else if((e|0)==2097154){g=d[9757560]|0;return g|0}else if((e|0)==2228226){f=a[9540896]|0;switch(f&255|0){case 0:{a[9540896]=f+1&255;h=a[9540892]|0;break};case 1:{a[9540898]=a[9540898]&-5;a[9540896]=f+1&255;h=a[9540893]|0;break};case 2:{a[9540896]=f+1&255;h=a[9540894]|0;break};case 3:{a[9540898]=a[9540898]&-9;a[9540896]=f+1&255;h=a[9540895]|0;break};case 4:{h=a[9540898]|0;break};default:{h=0}}g=h&255;return g|0}else if((e|0)==3407874){g=b[(c[2442928]|0)+(c[2439392]<<1)>>1]|0;return g|0}else if((e|0)==3473410){g=b[(c[2442926]|0)+(c[2439393]<<1)>>1]|0;return g|0}else if((e|0)==3538946){g=b[(c[2442924]|0)+(c[2439394]<<1)>>1]|0;return g|0}else{g=0;return g|0}return 0}function eWW(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=d-2752512|0;if(f>>>0<16){g=f>>>1;b[14129152+(g<<1)>>1]=e;switch(g|0){case 0:{c[2388344]=-(e&65535);return};case 1:{c[2385826]=-(e&65535);return};case 2:{c[3527502]=-(e&65535);return};case 3:{c[2388334]=-(e&65535);return};case 4:{c[2385820]=-(e&65535);return};case 5:{c[3527494]=-(e&65535);return};case 6:{c[3532284]=(e&65535)>>>4&1;return};case 7:{c[2439396]=e&1;return};default:{return}}}g=d-3014656|0;if(g>>>0<16){f=g>>>1;b[14129168+(f<<1)>>1]=e;switch(f|0){case 0:{c[2388345]=-(e&65535);return};case 1:{c[2385827]=-(e&65535);return};case 2:{c[3527503]=-(e&65535);return};case 3:{c[2388335]=-(e&65535);return};case 4:{c[2385821]=-(e&65535);return};case 5:{c[3527495]=-(e&65535);return};case 6:{c[3532285]=(e&65535)>>>4&1;return};case 7:{c[2439397]=e&1;return};default:{return}}}f=d-3276800|0;if(f>>>0<16){g=f>>>1;b[14129184+(g<<1)>>1]=e;switch(g|0){case 0:{c[2388346]=-(e&65535);return};case 1:{c[2385828]=-(e&65535);return};case 2:{c[3527504]=-(e&65535);return};case 3:{c[2388336]=-(e&65535);return};case 4:{c[2385822]=-(e&65535);return};case 5:{c[3527496]=-(e&65535);return};case 6:{c[3532286]=(e&65535)>>>4&1;return};case 7:{c[2439398]=e&1;return};default:{return}}}g=d-2621440|0;if(g>>>0<81920){f=c[3532279]|0;h=c[3532280]|0;i=g>>>1;j=(c[3532278]|0)+(i<<1)|0;do{if((b[j>>1]|0)!=e<<16>>16){if((c[3532284]|0)==0){if(g>>>0<16384){a[14129208]=1}if((d-2654208|0)>>>0<16384){a[14129128]=1}if((d-2646016|0)>>>0>=4096){break}a[14129200]=1;break}else{if(g>>>0<32768){a[14129208]=1}if((d-2654208|0)>>>0<32768){a[14129128]=1}if((d-2691072|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);k=f+(i<<1)|0;do{if((b[k>>1]|0)!=e<<16>>16){if((c[3532285]|0)==0){if(g>>>0<16384){a[14129209]=1}if((d-2654208|0)>>>0<16384){a[14129129]=1}if((d-2646016|0)>>>0>=4096){break}a[14129201]=1;break}else{if(g>>>0<32768){a[14129209]=1}if((d-2654208|0)>>>0<32768){a[14129129]=1}if((d-2691072|0)>>>0>=4096){break}a[14129201]=1;break}}}while(0);f=h+(i<<1)|0;do{if((b[f>>1]|0)!=e<<16>>16){if((c[3532286]|0)==0){if(g>>>0<16384){a[14129210]=1}if((d-2654208|0)>>>0<16384){a[14129130]=1}if((d-2646016|0)>>>0>=4096){break}a[14129202]=1;break}else{if(g>>>0<32768){a[14129210]=1}if((d-2654208|0)>>>0<32768){a[14129130]=1}if((d-2691072|0)>>>0>=4096){break}a[14129202]=1;break}}}while(0);b[j>>1]=e;b[k>>1]=e;b[f>>1]=e;return}f=d-2883584|0;if(f>>>0<81920){k=(c[3532279]|0)+(f>>>1<<1)|0;do{if((b[k>>1]|0)!=e<<16>>16){if((c[3532285]|0)==0){if(f>>>0<16384){a[14129209]=1}if((d-2916352|0)>>>0<16384){a[14129129]=1}if((d-2908160|0)>>>0>=4096){break}a[14129201]=1;break}else{if(f>>>0<32768){a[14129209]=1}if((d-2916352|0)>>>0<32768){a[14129129]=1}if((d-2953216|0)>>>0>=4096){break}a[14129201]=1;break}}}while(0);b[k>>1]=e;return}k=d-3145728|0;if(k>>>0<81920){f=(c[3532280]|0)+(k>>>1<<1)|0;do{if((b[f>>1]|0)!=e<<16>>16){if((c[3532286]|0)==0){if(k>>>0<16384){a[14129210]=1}if((d-3178496|0)>>>0<16384){a[14129130]=1}if((d-3170304|0)>>>0>=4096){break}a[14129202]=1;break}else{if(k>>>0<32768){a[14129210]=1}if((d-3178496|0)>>>0<32768){a[14129130]=1}if((d-3215360|0)>>>0>=4096){break}a[14129202]=1;break}}}while(0);b[f>>1]=e;return}if((d|0)==3473408|(d|0)==3473410){f=(d-3473408|0)>>>1;if((f|0)==0){c[2439393]=e&4095;return}else if((f|0)==1){b[(c[2442926]|0)+(c[2439393]<<1)>>1]=e;c[(c[3532276]|0)+((c[2439393]|4096)<<2)>>2]=((e&65535)>>>10<<3&248)>>>3|((e&255)<<3&255)<<8|(((e&65535)>>>7&4|(e&65535)>>>5<<3&255)&255)<<3&2016;return}else{return}}else if((d|0)==2097152){f=a[9757560]|0;k=e&255;a[9757552+(f&255)|0]=k;if((f<<24>>24|0)==0){c[3531956]=0;return}else if((f<<24>>24|0)==4){f=~k;a[14128520]=f&1;a[14128521]=f&2;return}else{return}}else if((d|0)==2097154){a[9757560]=e&255;return}else if((d|0)==2162688){b[7064256]=e;if((e&1)!=0){return}f=c[2394]|0;k=c[14130368+(f<<2)>>2]|0;if((k|0)!=0){gGC(k|0,9104152,280)|0}c[8452240+(f<<2)>>2]=c[2113054];c[2394]=1;c[2112932]=c[3532597];f=c[3532593]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113061];RI();f=c[2394]|0;k=c[14130368+(f<<2)>>2]|0;if((k|0)!=0){gGC(k|0,9104152,280)|0}c[8452240+(f<<2)>>2]=c[2113054];c[2394]=0;c[2112932]=c[3532596];f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];return}else if((d|0)==2228224){a[9540896]=e&15;return}else if((d|0)==2228226){f=e&15;k=a[9540896]|0;switch(k&255|0){case 0:{a[9540896]=k+1&255;a[9540888]=f;return};case 1:{a[9540896]=k+1&255;a[9540889]=f;a[9540898]=a[9540898]|1;a[9540900]=1;return};case 2:{a[9540896]=k+1&255;a[9540890]=f;return};case 3:{a[9540896]=k+1&255;a[9540891]=f;a[9540898]=a[9540898]|2;a[9540900]=1;return};case 4:{if(f<<24>>24==0){return}f=c[2439330]|0;k=(f|0)==0;if(!k){j=f;gGC(9706056,j|0,76)|0}j=c[2438118]|0;c[2433530]=j;g=c[3528484]|0;c[2076596]=g;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);if(!k){k=f;gGC(k|0,9706056,76)|0}c[2438118]=j;c[3528484]=g;c[2417276]=i;c[1836236]=-1;return};default:{return}}}else if((d|0)==3407872|(d|0)==3407874){i=(d-3407872|0)>>>1;if((i|0)==0){c[2439392]=e&4095;return}else if((i|0)==1){b[(c[2442928]|0)+(c[2439392]<<1)>>1]=e;c[(c[3532276]|0)+(c[2439392]<<2)>>2]=((e&65535)>>>10<<3&248)>>>3|((e&255)<<3&255)<<8|(((e&65535)>>>7&4|(e&65535)>>>5<<3&255)&255)<<3&2016;return}else{return}}else if((d|0)==3538944|(d|0)==3538946){i=(d-3538944|0)>>>1;if((i|0)==0){c[2439394]=e&4095;return}else if((i|0)==1){b[(c[2442924]|0)+(c[2439394]<<1)>>1]=e;c[(c[3532276]|0)+((c[2439394]|8192)<<2)>>2]=((e&65535)>>>10<<3&248)>>>3|((e&255)<<3&255)<<8|(((e&65535)>>>7&4|(e&65535)>>>5<<3&255)&255)<<3&2016;return}else{return}}else{return}}function eWX(a){a=a|0;return 0}function eWY(a,b){a=a|0;b=b|0;return}function eWZ(b){b=b|0;var c=0,e=0;if((b|0)!=2097152){c=0;return c|0}switch(d[9757560]|0|0){case 1:{e=a[14129049]|0;break};case 0:{e=a[14129048]|0;break};case 3:{e=a[14129041]|0;break};case 4:{e=a[9757556]|0;break};case 7:{e=a[14129042]|0;break};case 2:{e=a[14129040]|0;break};default:{e=0}}c=e&255;return c|0}function eW_(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=d-2621440|0;if(f>>>0>=81920){if((d|0)==3538946|(d|0)==3538944){g=(d-3538944|0)>>>1;if((g|0)==0){c[2439394]=e&4095;return}else if((g|0)==1){b[(c[2442924]|0)+(c[2439394]<<1)>>1]=e;c[(c[3532276]|0)+((c[2439394]|8192)<<2)>>2]=((e&65535)>>>10<<3&248)>>>3|((e&255)<<3&255)<<8|(((e&65535)>>>7&4|(e&65535)>>>5<<3&255)&255)<<3&2016;return}else{return}}else if((d|0)==3407872|(d|0)==3407874){g=(d-3407872|0)>>>1;if((g|0)==0){c[2439392]=e&4095;return}else if((g|0)==1){b[(c[2442928]|0)+(c[2439392]<<1)>>1]=e;c[(c[3532276]|0)+(c[2439392]<<2)>>2]=((e&65535)>>>10<<3&248)>>>3|((e&255)<<3&255)<<8|(((e&65535)>>>7&4|(e&65535)>>>5<<3&255)&255)<<3&2016;return}else{return}}else if((d|0)==3473408|(d|0)==3473410){g=(d-3473408|0)>>>1;if((g|0)==1){b[(c[2442926]|0)+(c[2439393]<<1)>>1]=e;c[(c[3532276]|0)+((c[2439393]|4096)<<2)>>2]=((e&65535)>>>10<<3&248)>>>3|((e&255)<<3&255)<<8|(((e&65535)>>>7&4|(e&65535)>>>5<<3&255)&255)<<3&2016;return}else if((g|0)==0){c[2439393]=e&4095;return}else{return}}else{return}}g=c[3532279]|0;h=c[3532280]|0;i=f>>>1;j=(c[3532278]|0)+(i<<1)|0;do{if((b[j>>1]|0)!=e<<16>>16){if((c[3532284]|0)==0){if(f>>>0<16384){a[14129208]=1}if((d-2654208|0)>>>0<16384){a[14129128]=1}if((d-2646016|0)>>>0>=4096){break}a[14129200]=1;break}else{if(f>>>0<32768){a[14129208]=1}if((d-2654208|0)>>>0<32768){a[14129128]=1}if((d-2691072|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);k=g+(i<<1)|0;do{if((b[k>>1]|0)!=e<<16>>16){if((c[3532285]|0)==0){if(f>>>0<16384){a[14129209]=1}if((d-2654208|0)>>>0<16384){a[14129129]=1}if((d-2646016|0)>>>0>=4096){break}a[14129201]=1;break}else{if(f>>>0<32768){a[14129209]=1}if((d-2654208|0)>>>0<32768){a[14129129]=1}if((d-2691072|0)>>>0>=4096){break}a[14129201]=1;break}}}while(0);g=h+(i<<1)|0;do{if((b[g>>1]|0)!=e<<16>>16){if((c[3532286]|0)==0){if(f>>>0<16384){a[14129210]=1}if((d-2654208|0)>>>0<16384){a[14129130]=1}if((d-2646016|0)>>>0>=4096){break}a[14129202]=1;break}else{if(f>>>0<32768){a[14129210]=1}if((d-2654208|0)>>>0<32768){a[14129130]=1}if((d-2691072|0)>>>0>=4096){break}a[14129202]=1;break}}}while(0);b[j>>1]=e;b[k>>1]=e;b[g>>1]=e;return}function eW$(a){a=a|0;return 0}function eW0(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=b-2097152|0;if(e>>>0>=81920){f=b-2359296|0;if(f>>>0>=131072){return}b=f^1;g=(c[3532279]|0)+b|0;do{if((a[g]|0)!=d<<24>>24){h=(f|0)>-1;if((c[3532285]|0)==0){if(h&(b|0)<16384){a[14129209]=1}if(h&(b|0)<32768){a[14129129]=1}if((b-24576|0)>>>0>=4096){break}a[14129201]=1;break}else{if(h&(b|0)<32768){a[14129209]=1}if((b-32768|0)>>>0<32768){a[14129129]=1}if((b-69632|0)>>>0>=4096){break}a[14129201]=1;break}}}while(0);a[g]=d;return}g=e^1;b=(c[3532278]|0)+g|0;do{if((a[b]|0)!=d<<24>>24){f=(e|0)>-1;if((c[3532284]|0)==0){if(f&(g|0)<16384){a[14129208]=1}if(f&(g|0)<32768){a[14129128]=1}if((g-24576|0)>>>0>=4096){break}a[14129200]=1;break}else{if(f&(g|0)<32768){a[14129208]=1}if((g-32768|0)>>>0<32768){a[14129128]=1}if((g-69632|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);f=(c[3532279]|0)+g|0;do{if((a[f]|0)!=d<<24>>24){h=(e|0)>-1;if((c[3532285]|0)==0){if(h&(g|0)<16384){a[14129209]=1}if(h&(g|0)<32768){a[14129129]=1}if((g-24576|0)>>>0>=4096){break}a[14129201]=1;break}else{if(h&(g|0)<32768){a[14129209]=1}if((g-32768|0)>>>0<32768){a[14129129]=1}if((g-69632|0)>>>0>=4096){break}a[14129201]=1;break}}}while(0);a[b]=d;a[f]=d;return}function eW1(d){d=d|0;var e=0,f=0,g=0;if((d|0)==4325378){e=b[(c[2442926]|0)+(c[2439393]<<1)>>1]|0;return e|0}else if((d|0)==8388608|(d|0)==8388610|(d|0)==8388612|(d|0)==8388614|(d|0)==8388616|(d|0)==8388618|(d|0)==8388620|(d|0)==8388622){switch(d>>>1&255|0){case 3:{f=a[14129041]|0;break};case 4:{f=a[9757556]|0;break};case 7:{f=a[14129042]|0;break};case 2:{f=a[14129040]|0;break};case 0:{f=a[14129048]|0;break};case 1:{f=a[14129049]|0;break};default:{f=0}}e=f&255;return e|0}else if((d|0)==4194306){e=b[(c[2442928]|0)+(c[2439392]<<1)>>1]|0;return e|0}else if((d|0)==8585218){d=a[9540896]|0;switch(d&255|0){case 1:{a[9540898]=a[9540898]&-5;a[9540896]=d+1&255;g=a[9540893]|0;break};case 2:{a[9540896]=d+1&255;g=a[9540894]|0;break};case 0:{a[9540896]=d+1&255;g=a[9540892]|0;break};case 4:{g=a[9540898]|0;break};case 3:{a[9540898]=a[9540898]&-9;a[9540896]=d+1&255;g=a[9540895]|0;break};default:{g=0}}e=g&255;return e|0}else{e=0;return e|0}return 0}function eW2(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=d-2097152|0;if(f>>>0<81920){g=c[3532279]|0;h=f>>>1;i=(c[3532278]|0)+(h<<1)|0;do{if((b[i>>1]|0)!=e<<16>>16){if((c[3532284]|0)==0){if(f>>>0<16384){a[14129208]=1}if((d-2129920|0)>>>0<16384){a[14129128]=1}if((d-2121728|0)>>>0>=4096){break}a[14129200]=1;break}else{if(f>>>0<32768){a[14129208]=1}if((d-2129920|0)>>>0<32768){a[14129128]=1}if((d-2166784|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);j=g+(h<<1)|0;do{if((b[j>>1]|0)!=e<<16>>16){if((c[3532285]|0)==0){if(f>>>0<16384){a[14129209]=1}if((d-2129920|0)>>>0<16384){a[14129129]=1}if((d-2121728|0)>>>0>=4096){break}a[14129201]=1;break}else{if(f>>>0<32768){a[14129209]=1}if((d-2129920|0)>>>0<32768){a[14129129]=1}if((d-2166784|0)>>>0>=4096){break}a[14129201]=1;break}}}while(0);b[i>>1]=e;b[j>>1]=e;return}if((d-2179072|0)>>>0<512){return}j=d-2228224|0;if(j>>>0<16){i=j>>>1;b[14129152+(i<<1)>>1]=e;switch(i|0){case 5:{c[3527494]=-(e&65535);return};case 0:{c[2388344]=-(e&65535);return};case 1:{c[2385826]=-(e&65535);return};case 4:{c[2385820]=-(e&65535);return};case 7:{c[2439396]=e&1;return};case 6:{c[3532284]=(e&65535)>>>4&1;return};case 3:{c[2388334]=-(e&65535);return};case 2:{c[3527502]=-(e&65535);return};default:{return}}}i=d-2490368|0;if(i>>>0<16){j=i>>>1;b[14129168+(j<<1)>>1]=e;switch(j|0){case 0:{c[2388345]=-(e&65535);return};case 2:{c[3527503]=-(e&65535);return};case 5:{c[3527495]=-(e&65535);return};case 1:{c[2385827]=-(e&65535);return};case 6:{c[3532285]=(e&65535)>>>4&1;return};case 4:{c[2385821]=-(e&65535);return};case 3:{c[2388335]=-(e&65535);return};case 7:{c[2439397]=e&1;return};default:{return}}}j=d-2359296|0;if(j>>>0<131072){i=(c[3532279]|0)+(j>>>1<<1)|0;do{if((b[i>>1]|0)!=e<<16>>16){if((c[3532285]|0)==0){if(j>>>0<16384){a[14129209]=1}if((d-2392064|0)>>>0<16384){a[14129129]=1}if((d-2383872|0)>>>0>=4096){break}a[14129201]=1;break}else{if(j>>>0<32768){a[14129209]=1}if((d-2392064|0)>>>0<32768){a[14129129]=1}if((d-2428928|0)>>>0>=4096){break}a[14129201]=1;break}}}while(0);b[i>>1]=e;return}if((d|0)==8388608|(d|0)==8388610|(d|0)==8388612|(d|0)==8388614|(d|0)==8388616|(d|0)==8388618|(d|0)==8388620|(d|0)==8388622){i=d>>>1;j=i&255;f=e&255;a[9757552+(i&255)|0]=f;if((j<<24>>24|0)==4){i=~f;a[14128520]=i&1;a[14128521]=i&2;return}else if((j<<24>>24|0)==0){c[3531956]=0;return}else{return}}else if((d|0)==4194304|(d|0)==4194306|(d|0)==4194308){j=(d-4194304|0)>>>1;if((j|0)==0){c[2439392]=e&4095;return}else if((j|0)==1){b[(c[2442928]|0)+(c[2439392]<<1)>>1]=e;c[(c[3532276]|0)+(c[2439392]<<2)>>2]=((e&65535)>>>10<<3&248)>>>3|((e&255)<<3&255)<<8|(((e&65535)>>>7&4|(e&65535)>>>5<<3&255)&255)<<3&2016;return}else{return}}else if((d|0)==8585218){j=e&15;i=a[9540896]|0;switch(i&255|0){case 0:{a[9540896]=i+1&255;a[9540888]=j;return};case 4:{if(j<<24>>24==0){return}f=c[2439330]|0;h=(f|0)==0;if(!h){g=f;gGC(9706056,g|0,76)|0}g=c[2438118]|0;c[2433530]=g;k=c[3528484]|0;c[2076596]=k;l=c[2417276]|0;c[3541536]=l;c[1836236]=0;gGz(9706056,0,76);if(!h){h=f;gGC(h|0,9706056,76)|0}c[2438118]=g;c[3528484]=k;c[2417276]=l;c[1836236]=-1;return};case 1:{a[9540896]=i+1&255;a[9540889]=j;a[9540898]=a[9540898]|1;a[9540900]=1;return};case 2:{a[9540896]=i+1&255;a[9540890]=j;return};case 3:{a[9540896]=i+1&255;a[9540891]=j;a[9540898]=a[9540898]|2;a[9540900]=1;return};default:{return}}}else if((d|0)==8585216){a[9540896]=e&15;return}else if((d|0)==4325376|(d|0)==4325378|(d|0)==4325380){j=(d-4325376|0)>>>1;if((j|0)==1){b[(c[2442926]|0)+(c[2439393]<<1)>>1]=e;c[(c[3532276]|0)+((c[2439393]|4096)<<2)>>2]=((e&65535)>>>10<<3&248)>>>3|((e&255)<<3&255)<<8|(((e&65535)>>>7&4|(e&65535)>>>5<<3&255)&255)<<3&2016;return}else if((j|0)==0){c[2439393]=e&4095;return}else{return}}else{return}}function eW3(a){a=a|0;return 0}function eW4(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=b-3145728|0;if(e>>>0>=81920){f=b-3407872|0;if(f>>>0>=131072){return}b=f^1;g=(c[3532279]|0)+b|0;do{if((a[g]|0)!=d<<24>>24){h=(f|0)>-1;if((c[3532285]|0)==0){if(h&(b|0)<16384){a[14129209]=1}if(h&(b|0)<32768){a[14129129]=1}if((b-24576|0)>>>0>=4096){break}a[14129201]=1;break}else{if(h&(b|0)<32768){a[14129209]=1}if((b-32768|0)>>>0<32768){a[14129129]=1}if((b-69632|0)>>>0>=4096){break}a[14129201]=1;break}}}while(0);a[g]=d;return}g=e^1;b=(c[3532278]|0)+g|0;do{if((a[b]|0)!=d<<24>>24){f=(e|0)>-1;if((c[3532284]|0)==0){if(f&(g|0)<16384){a[14129208]=1}if(f&(g|0)<32768){a[14129128]=1}if((g-24576|0)>>>0>=4096){break}a[14129200]=1;break}else{if(f&(g|0)<32768){a[14129208]=1}if((g-32768|0)>>>0<32768){a[14129128]=1}if((g-69632|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);f=(c[3532279]|0)+g|0;do{if((a[f]|0)!=d<<24>>24){h=(e|0)>-1;if((c[3532285]|0)==0){if(h&(g|0)<16384){a[14129209]=1}if(h&(g|0)<32768){a[14129129]=1}if((g-24576|0)>>>0>=4096){break}a[14129201]=1;break}else{if(h&(g|0)<32768){a[14129209]=1}if((g-32768|0)>>>0<32768){a[14129129]=1}if((g-69632|0)>>>0>=4096){break}a[14129201]=1;break}}}while(0);a[b]=d;a[f]=d;return}function eW5(d){d=d|0;var e=0,f=0,g=0,h=0;e=d-8388608|0;if(e>>>0<16){switch(e>>>1|0){case 2:{f=a[14128912]|0;break};case 4:{f=a[9757532]|0;break};case 1:{f=a[14128921]|0;break};case 0:{f=a[14128920]|0;break};case 3:{f=a[14128913]|0;break};case 7:{f=a[14128914]|0;break};default:{f=-1}}g=f&255;return g|0}if((d|0)==4325378){g=b[(c[2442926]|0)+(c[2439393]<<1)>>1]|0;return g|0}else if((d|0)==4194306){g=b[(c[2442928]|0)+(c[2439392]<<1)>>1]|0;return g|0}else if((d|0)==8585218){d=a[9540896]|0;switch(d&255|0){case 4:{h=a[9540898]|0;break};case 0:{a[9540896]=d+1&255;h=a[9540892]|0;break};case 2:{a[9540896]=d+1&255;h=a[9540894]|0;break};case 1:{a[9540898]=a[9540898]&-5;a[9540896]=d+1&255;h=a[9540893]|0;break};case 3:{a[9540898]=a[9540898]&-9;a[9540896]=d+1&255;h=a[9540895]|0;break};default:{h=0}}g=h&255;return g|0}else{g=0;return g|0}return 0}function eW6(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=d-3145728|0;if(f>>>0<81920){g=c[3532279]|0;h=f>>>1;i=(c[3532278]|0)+(h<<1)|0;do{if((b[i>>1]|0)!=e<<16>>16){if((c[3532284]|0)==0){if(f>>>0<16384){a[14129208]=1}if((d-3178496|0)>>>0<16384){a[14129128]=1}if((d-3170304|0)>>>0>=4096){break}a[14129200]=1;break}else{if(f>>>0<32768){a[14129208]=1}if((d-3178496|0)>>>0<32768){a[14129128]=1}if((d-3215360|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);j=g+(h<<1)|0;do{if((b[j>>1]|0)!=e<<16>>16){if((c[3532285]|0)==0){if(f>>>0<16384){a[14129209]=1}if((d-3178496|0)>>>0<16384){a[14129129]=1}if((d-3170304|0)>>>0>=4096){break}a[14129201]=1;break}else{if(f>>>0<32768){a[14129209]=1}if((d-3178496|0)>>>0<32768){a[14129129]=1}if((d-3215360|0)>>>0>=4096){break}a[14129201]=1;break}}}while(0);b[i>>1]=e;b[j>>1]=e;return}j=d-3407872|0;if(j>>>0<131072){i=(c[3532279]|0)+(j>>>1<<1)|0;do{if((b[i>>1]|0)!=e<<16>>16){if((c[3532285]|0)==0){if(j>>>0<16384){a[14129209]=1}if((d-3440640|0)>>>0<16384){a[14129129]=1}if((d-3432448|0)>>>0>=4096){break}a[14129201]=1;break}else{if(j>>>0<32768){a[14129209]=1}if((d-3440640|0)>>>0<32768){a[14129129]=1}if((d-3477504|0)>>>0>=4096){break}a[14129201]=1;break}}}while(0);b[i>>1]=e;return}i=d-3276800|0;if(i>>>0<16){j=i>>>1;b[14129152+(j<<1)>>1]=e;switch(j|0){case 7:{c[2439396]=e&1;return};case 5:{c[3527494]=-(e&65535);return};case 3:{c[2388334]=-(e&65535);return};case 6:{c[3532284]=(e&65535)>>>4&1;return};case 2:{c[3527502]=-(e&65535);return};case 1:{c[2385826]=-(e&65535);return};case 4:{c[2385820]=-(e&65535);return};case 0:{c[2388344]=-(e&65535);return};default:{return}}}j=d-3538944|0;if(j>>>0<16){i=j>>>1;b[14129168+(i<<1)>>1]=e;switch(i|0){case 5:{c[3527495]=-(e&65535);return};case 4:{c[2385821]=-(e&65535);return};case 7:{c[2439397]=e&1;return};case 1:{c[2385827]=-(e&65535);return};case 0:{c[2388345]=-(e&65535);return};case 2:{c[3527503]=-(e&65535);return};case 6:{c[3532285]=(e&65535)>>>4&1;return};case 3:{c[2388335]=-(e&65535);return};default:{return}}}i=d-8388608|0;if(i>>>0<16){j=i>>>1;i=e&255;a[9757528+j|0]=i;if((j|0)==0){c[3531956]=0;return}else if((j|0)==4){j=~i;a[14128520]=j&1;a[14128521]=j&2;return}else{return}}if((d|0)==8585216){a[9540896]=e&15;return}else if((d|0)==4194304|(d|0)==4194306|(d|0)==4194308){j=(d-4194304|0)>>>1;if((j|0)==0){c[2439392]=e&4095;return}else if((j|0)==1){b[(c[2442928]|0)+(c[2439392]<<1)>>1]=e;c[(c[3532276]|0)+(c[2439392]<<2)>>2]=((e&65535)>>>10<<3&248)>>>3|((e&255)<<3&255)<<8|(((e&65535)>>>7&4|(e&65535)>>>5<<3&255)&255)<<3&2016;return}else{return}}else if((d|0)==4325376|(d|0)==4325378|(d|0)==4325380){j=(d-4325376|0)>>>1;if((j|0)==0){c[2439393]=e&4095;return}else if((j|0)==1){b[(c[2442926]|0)+(c[2439393]<<1)>>1]=e;c[(c[3532276]|0)+((c[2439393]|4096)<<2)>>2]=((e&65535)>>>10<<3&248)>>>3|((e&255)<<3&255)<<8|(((e&65535)>>>7&4|(e&65535)>>>5<<3&255)&255)<<3&2016;return}else{return}}else if((d|0)==8585218){d=e&15;e=a[9540896]|0;switch(e&255|0){case 1:{a[9540896]=e+1&255;a[9540889]=d;a[9540898]=a[9540898]|1;a[9540900]=1;return};case 2:{a[9540896]=e+1&255;a[9540890]=d;return};case 3:{a[9540896]=e+1&255;a[9540891]=d;a[9540898]=a[9540898]|2;a[9540900]=1;return};case 4:{if(d<<24>>24==0){return}j=c[2439330]|0;i=(j|0)==0;if(!i){f=j;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;h=c[3528484]|0;c[2076596]=h;g=c[2417276]|0;c[3541536]=g;c[1836236]=0;gGz(9706056,0,76);if(!i){i=j;gGC(i|0,9706056,76)|0}c[2438118]=f;c[3528484]=h;c[2417276]=g;c[1836236]=-1;return};case 0:{a[9540896]=e+1&255;a[9540888]=d;return};default:{return}}}else{return}}function eW7(b){b=b|0;var d=0,e=0,f=0.0,g=0.0,i=0,j=0;d=b&65535;if((d|0)==57346){e=a[(c[3541514]|0)+20904|0]|0;return e|0}else if((d|0)==57857){e=fdZ()|0;return e|0}else if((d|0)==57344){d=c[3541514]|0;b=d+552|0;f=+h[b>>3];do{if(f!=0.0){g=+h[6675];if(f-(g+ +gC[c[2429842]&255]())>0.0){i=a[d+563|0]|-128;break}else{h[b>>3]=0.0;j=31651;break}}else{j=31651}}while(0);if((j|0)==31651){i=a[d+563|0]|0}e=i&-125;return e|0}else{e=0;return e|0}return 0}function eW8(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,i=0,j=0,k=0,l=0;switch(b&65535|0){case 57857:{fd_(d);return};case 57345:{l7(1,d);return};case 57346:{b=c[3541514]|0;a[b+560|0]=d;a[b+20408|0]=1;return};case 58371:{h[118355]=+(d&255|0)*+h[85170]/255.0;return};case 61952:{b=d+7&7;a[14127752]=b;e=c[3531932]|0;f=(b&255)<<14;b=c[9757320+(c[1836236]<<2)>>2]|0;g=64;i=64;while(1){c[b+76+(i<<2)>>2]=e+((i<<8)+f);j=g+1&65535;if((j&65535)>127){k=64;l=64;break}else{g=j;i=j&65535}}while(1){i=e+((l<<8)+f)|0;c[b+76+(l+512<<2)>>2]=i;c[b+76+(l+768<<2)>>2]=i;i=k+1&65535;if((i&65535)>127){break}else{k=i;l=i&65535}}return};case 57344:{l=c[3541514]|0;a[l+560|0]=d;a[l+20408|0]=0;if((d&255)>=16){return}c[14168912+((c[2383582]|0)*252|0)>>2]=d&15;return};case 57347:{l7(3,d);return};case 58370:{h[146570]=+(d&255|0)*+h[85170]/255.0;return};case 58368:{h[146571]=+(d&255|0)*+h[85170]/255.0;return};case 57856:{a[9540897]=d&15;return};case 58369:{h[118356]=+(d&255|0)*+h[85170]/255.0;return};default:{return}}}function eW9(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5503476+(b*112|0)>>2];c[a+104>>2]=c[5503480+(b*112|0)>>2];c[a+108>>2]=c[5503484+(b*112|0)>>2];d=0;return d|0}function eXa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<22&(d|0)==0)){e=1;return e|0}c[a>>2]=5503376+(b*112|0);e=0;return e|0}function eXb(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1966320+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eXc(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>41){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5505840+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eXd(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;c[3532162]=256;c[3532160]=4;c[3532142]=8;c[3532164]=8;c[3532148]=1983656;c[3532140]=6964248;c[3532138]=6963992;c[3532042]=32768;c[3532002]=1024;c[3532e3]=4;a[7460944]=1;c[3532004]=16;c[3531998]=961424;c[3531992]=4969624;c[3531990]=4969176;c[3532034]=8192;if(a[673136]|0){c[3532034]=16384}c[3532044]=2;c[3532030]=1;a[7460960]=1;eZ9(0)|0;c[3532048]=0;c[3532204]=0;d=c[3532200]|0;c[3532198]=d;e=(c[3532194]|0)+d|0;c[3531932]=e;d=e+(c[3531928]|0)|0;c[3531952]=d;e=d+(c[3531948]|0)|0;c[3531946]=e;d=e+(c[3531942]|0)|0;e=d|0;c[3532020]=e;c[3532208]=e;c[3532206]=d+65536;c[3531936]=d+131072;c[3532008]=d+139264;c[3531970]=d+204800;e=d+221184|0;d=e|0;c[3532022]=d;c[3532136]=d;d=ag(c[3532142]|0,c[3532042]|0)|0;f=(ag(d,c[3532164]|0)|0)+e|0;c[3531962]=f;e=ag(a[7460944]|0?16:0,c[3532034]|0)|0;d=(ag(e,c[3532004]|0)|0)+f|0;c[3532046]=d;f=d;d=0;while(1){if((d|0)>=1024){break}g=9638528+(d<<2)|0;if((c[g>>2]|0)==0){i=31720;break}else{d=d+1|0}}do{if((i|0)==31720){d=gGq(f)|0;c[g>>2]=d;if((d|0)==0){break}gGz(d|0,0,f|0);c[3532048]=d;gGz(d|0,0,f|0);c[3532204]=d;e=c[3532200]|0;c[3532198]=d+e;j=(c[3532194]|0)+e|0;c[3531932]=d+j;e=j+(c[3531928]|0)|0;c[3531952]=d+e;j=e+(c[3531948]|0)|0;c[3531946]=d+j;e=j+(c[3531942]|0)|0;j=d+e|0;c[3532020]=j;c[3532208]=j;c[3532206]=d+(e+65536);c[3531936]=d+(e+131072);c[3532008]=d+(e+139264);c[3531970]=d+(e+204800);j=e+221184|0;e=d+j|0;c[3532022]=e;c[3532136]=e;e=ag(c[3532142]|0,c[3532042]|0)|0;k=(ag(e,c[3532164]|0)|0)+j|0;c[3531962]=d+k;j=ag(a[7460944]|0?16:0,c[3532034]|0)|0;c[3532046]=d+((ag(j,c[3532004]|0)|0)+k);k=c[642608+(c[2436]<<2)>>2]|0;j=c[k+128>>2]|0;if((c[k+52>>2]&4|0)==0){c[2113068]=j;d=c[k+132>>2]|0;c[2113070]=d;c[2443814]=j;c[2440436]=d;l=j;m=d}else{c[2113070]=j;d=c[k+132>>2]|0;c[2113068]=d;c[2440436]=j;c[2443814]=d;l=d;m=j}j=ag(l<<1,m)|0;d=gGq(j)|0;c[2112926]=d;if((d|0)!=0){gGz(d|0,0,j|0)}eX5(0,c[3532042]|0,22,16,0,0);j=c[2113070]|0;c[2430060]=288;c[2429702]=j;c[2429698]=0;eX5(1,c[3532042]|0,24,16,0,0);j=c[2113070]|0;c[2430061]=288;c[2429703]=j;c[2429699]=288;c[2427077]=4096;eX5(2,c[3532042]|0,26,16,0,0);j=c[2113070]|0;c[2430062]=288;c[2429704]=j;c[2429700]=576;c[2427078]=8192;j=0;while(1){if((j|0)>=1024){n=0;break}o=9638528+(j<<2)|0;if((c[o>>2]|0)==0){i=31730;break}else{j=j+1|0}}do{if((i|0)==31730){j=gGq(16384)|0;c[o>>2]=j;if((j|0)==0){n=0;break}gGz(j|0,0,16384);n=j}}while(0);c[2442928]=n;gGz(n|0,0,16384);j=0;while(1){if((j|0)>=1024){p=0;break}q=9638528+(j<<2)|0;if((c[q>>2]|0)==0){i=31789;break}else{j=j+1|0}}do{if((i|0)==31789){j=gGq(16384)|0;c[q>>2]=j;if((j|0)==0){p=0;break}gGz(j|0,0,16384);p=j}}while(0);c[2442926]=p;gGz(p|0,0,16384);j=0;while(1){if((j|0)>=1024){r=0;break}s=9638528+(j<<2)|0;if((c[s>>2]|0)==0){i=31794;break}else{j=j+1|0}}do{if((i|0)==31794){j=gGq(16384)|0;c[s>>2]=j;if((j|0)==0){r=0;break}gGz(j|0,0,16384);r=j}}while(0);c[2442924]=r;gGz(r|0,0,16384);j=0;while(1){if((j|0)>=1024){t=0;break}u=9638528+(j<<2)|0;if((c[u>>2]|0)==0){i=31735;break}else{j=j+1|0}}do{if((i|0)==31735){j=gGq(49152)|0;c[u>>2]=j;if((j|0)==0){t=0;break}gGz(j|0,0,49152);t=j}}while(0);c[3532276]=t;gGz(t|0,0,12288);c[3532274]=12288;a[7461088]=1;a[7461080]=1;a[7461056]=1;if((eZ9(1)|0)!=0){v=1;return v|0}fxU(0,425984);if((c[2394]|0)==0){w=c[2112932]|0}else{c[2394]=0;j=c[3532596]|0;c[2112932]=j;d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];w=j}j=c[3532204]|0;d=w|0;k=0;while(1){e=j+k|0;c[d>>2]=e;c[d+131072>>2]=e;e=k+1024|0;if(e>>>0>786431){break}else{d=d+4|0;k=e}}k=c[3532208]|0;d=w+3072|0;j=786432;while(1){e=k+(j-786432)|0;c[d>>2]=e;c[d+65536>>2]=e;c[d+131072>>2]=e;e=j+1024|0;if(e>>>0>851967){break}else{d=d+4|0;j=e}}j=c[3532008]|0;d=w+9216|0;k=2359296;while(1){e=j+(k-2359296)|0;c[d>>2]=e;c[d+65536>>2]=e;c[d+131072>>2]=e;e=k+1024|0;if(e>>>0>2424831){break}else{d=d+4|0;k=e}}k=c[3531970]|0;c[w+9728>>2]=k;c[w+75264>>2]=k;c[w+140800>>2]=k;d=k+1024|0;c[w+9732>>2]=d;c[w+75268>>2]=d;c[w+140804>>2]=d;d=k+2048|0;c[w+9736>>2]=d;c[w+75272>>2]=d;c[w+140808>>2]=d;d=k+3072|0;c[w+9740>>2]=d;c[w+75276>>2]=d;c[w+140812>>2]=d;d=k+4096|0;c[w+9744>>2]=d;c[w+75280>>2]=d;c[w+140816>>2]=d;d=k+5120|0;c[w+9748>>2]=d;c[w+75284>>2]=d;c[w+140820>>2]=d;d=k+6144|0;c[w+9752>>2]=d;c[w+75288>>2]=d;c[w+140824>>2]=d;d=k+7168|0;c[w+9756>>2]=d;c[w+75292>>2]=d;c[w+140828>>2]=d;d=k+8192|0;c[w+9760>>2]=d;c[w+75296>>2]=d;c[w+140832>>2]=d;d=k+9216|0;c[w+9764>>2]=d;c[w+75300>>2]=d;c[w+140836>>2]=d;d=k+10240|0;c[w+9768>>2]=d;c[w+75304>>2]=d;c[w+140840>>2]=d;d=k+11264|0;c[w+9772>>2]=d;c[w+75308>>2]=d;c[w+140844>>2]=d;d=k+12288|0;c[w+9776>>2]=d;c[w+75312>>2]=d;c[w+140848>>2]=d;d=k+13312|0;c[w+9780>>2]=d;c[w+75316>>2]=d;c[w+140852>>2]=d;d=k+14336|0;c[w+9784>>2]=d;c[w+75320>>2]=d;c[w+140856>>2]=d;d=k+15360|0;c[w+9788>>2]=d;c[w+75324>>2]=d;c[w+140860>>2]=d;d=c[3532278]|0;k=w+10240|0;j=2621440;while(1){c[k>>2]=d+(j-2621440);e=j+1024|0;if(e>>>0>2703359){break}else{k=k+4|0;j=e}}j=c[3532279]|0;k=w+11264|0;d=2883584;while(1){c[k>>2]=j+(d-2883584);e=d+1024|0;if(e>>>0>2965503){break}else{k=k+4|0;d=e}}d=c[3532280]|0;k=w+12288|0;j=3145728;while(1){c[k>>2]=d+(j-3145728);e=j+1024|0;if(e>>>0>3227647){break}else{k=k+4|0;j=e}}c[w+196608>>2]=412;c[w+196648>>2]=2382;c[w+196688>>2]=738;c[w+196728>>2]=2350;j=c[3532592]|0;if((j|0)!=0){gGC(j|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fxU(1,425984);if((c[2394]|0)==1){x=c[2112932]|0}else{c[2394]=1;j=c[3532597]|0;c[2112932]=j;k=c[3532593]|0;if((k|0)!=0){gGC(9104152,k|0,280)|0}c[2113054]=c[2113061];x=j}j=c[3532198]|0;k=x|0;d=0;while(1){e=j+d|0;c[k>>2]=e;c[k+131072>>2]=e;e=d+1024|0;if(e>>>0>393215){break}else{k=k+4|0;d=e}}d=c[3532206]|0;k=x+2048|0;j=524288;while(1){e=d+(j-524288)|0;c[k>>2]=e;c[k+65536>>2]=e;c[k+131072>>2]=e;e=j+1024|0;if(e>>>0>589823){break}else{k=k+4|0;j=e}}j=c[3532008]|0;k=x+9216|0;d=2359296;while(1){e=j+(d-2359296)|0;c[k>>2]=e;c[k+65536>>2]=e;c[k+131072>>2]=e;e=d+1024|0;if(e>>>0>2424831){break}else{k=k+4|0;d=e}}d=c[3531970]|0;c[x+9728>>2]=d;c[x+75264>>2]=d;c[x+140800>>2]=d;k=d+1024|0;c[x+9732>>2]=k;c[x+75268>>2]=k;c[x+140804>>2]=k;k=d+2048|0;c[x+9736>>2]=k;c[x+75272>>2]=k;c[x+140808>>2]=k;k=d+3072|0;c[x+9740>>2]=k;c[x+75276>>2]=k;c[x+140812>>2]=k;k=d+4096|0;c[x+9744>>2]=k;c[x+75280>>2]=k;c[x+140816>>2]=k;k=d+5120|0;c[x+9748>>2]=k;c[x+75284>>2]=k;c[x+140820>>2]=k;k=d+6144|0;c[x+9752>>2]=k;c[x+75288>>2]=k;c[x+140824>>2]=k;k=d+7168|0;c[x+9756>>2]=k;c[x+75292>>2]=k;c[x+140828>>2]=k;k=d+8192|0;c[x+9760>>2]=k;c[x+75296>>2]=k;c[x+140832>>2]=k;k=d+9216|0;c[x+9764>>2]=k;c[x+75300>>2]=k;c[x+140836>>2]=k;k=d+10240|0;c[x+9768>>2]=k;c[x+75304>>2]=k;c[x+140840>>2]=k;k=d+11264|0;c[x+9772>>2]=k;c[x+75308>>2]=k;c[x+140844>>2]=k;k=d+12288|0;c[x+9776>>2]=k;c[x+75312>>2]=k;c[x+140848>>2]=k;k=d+13312|0;c[x+9780>>2]=k;c[x+75316>>2]=k;c[x+140852>>2]=k;k=d+14336|0;c[x+9784>>2]=k;c[x+75320>>2]=k;c[x+140856>>2]=k;k=d+15360|0;c[x+9788>>2]=k;c[x+75324>>2]=k;c[x+140860>>2]=k;k=c[3532278]|0;d=x+10240|0;j=2621440;while(1){c[d>>2]=k+(j-2621440);e=j+1024|0;if(e>>>0>2703359){break}else{d=d+4|0;j=e}}c[x+196608>>2]=3546;c[x+196648>>2]=2698;c[x+196688>>2]=1806;c[x+196728>>2]=1994;j=c[3532593]|0;if((j|0)!=0){gGC(j|0,9104152,280)|0}c[2113061]=c[2113054];c[2394]=-1;fwR(0);j=c[2439330]|0;d=(j|0)==0;if(!d){k=j;gGC(9706056,k|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];k=c[3528484]|0;c[2076596]=k;e=c[2417276]|0;c[3541536]=e;c[1836236]=0;c[j+4180>>2]=1396;c[j+4184>>2]=2632;y=c[3531932]|0;z=0;A=0;while(1){c[j+76+(A<<2)>>2]=y+(A<<8);B=z+1&65535;if((B&65535)>63){C=0;D=0;break}else{z=B;A=B&65535}}while(1){A=y+(D<<8)|0;c[j+76+(D+512<<2)>>2]=A;c[j+76+(D+768<<2)>>2]=A;A=C+1&65535;if((A&65535)>63){E=64;F=64;break}else{C=A;D=A&65535}}while(1){c[j+76+(F<<2)>>2]=y+(F<<8);A=E+1&65535;if((A&65535)>127){G=64;H=64;break}else{E=A;F=A&65535}}while(1){A=y+(H<<8)|0;c[j+76+(H+512<<2)>>2]=A;c[j+76+(H+768<<2)>>2]=A;A=G+1&65535;if((A&65535)>127){break}else{G=A;H=A&65535}}y=c[3531936]|0;A=192;z=192;while(1){c[j+76+(z<<2)>>2]=y+((z<<8)-49152);B=A+1&65535;if((B&65535)>223){I=192;J=192;break}else{A=B;z=B&65535}}while(1){c[j+76+(J+256<<2)>>2]=y+((J<<8)-49152);z=I+1&65535;if((z&65535)>223){K=192;L=192;break}else{I=z;J=z&65535}}while(1){z=y+((L<<8)-49152)|0;c[j+76+(L+512<<2)>>2]=z;c[j+76+(L+768<<2)>>2]=z;z=K+1&65535;if((z&65535)>223){break}else{K=z;L=z&65535}}if(!d){y=j;gGC(y|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=k;c[2417276]=e;c[1836236]=-1;TW(c[3531952]|0,14127792,c[3531946]|0,14127768,1808,3364,16);c[2438228]=4e6;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=511;h[146569]=.25;h[118354]=.25;h[85170]=1.0;a[64232]=1;c[3532118]=11678;c[3532050]=4326;c[3532064]=4;c[2113026]=133333;c[2113024]=133333;c[2113022]=66666;c[3532016]=300;eZ8()|0;v=0;return v|0}}while(0);c[3532048]=0;v=1;return v|0}function eXe(){a[673136]=0;e_a()|0;return 0}function eXf(){var d=0,e=0,f=0,g=0,h=0,i=0;if((a[14128072]|0)!=0){d=c[3532016]|0;gD[d&8191]()|0}gu[c[3532050]&16383]();c[2113032]=0;c[2113031]=0;c[2113030]=0;d=c[2392]|0;if((d|0)>=0){gGz(8452240,0,((d|0)>0?(d<<2)+4|0:4)|0)}c[2113054]=0;d=c[2385548]|0;if((d|0)>0){gGz(9752472,0,((d|0)>1?d<<2:4)|0)}c[2433530]=0;d=0;while(1){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060]}e=d+1|0;f=(ag(c[2113026]|0,e)|0)/100|0;g=f-(c[2113030]|0)|0;c[2113028]=g;c[2113056]=g;f=RG(g)|0;c[2113054]=(c[2113054]|0)+f;c[2276108]=-1;c[2113056]=-1;c[2113030]=(c[2113030]|0)+f;f=(d|0)==99;do{if(f){g=c[3532064]|0;c[8452200+(c[2394]<<2)>>2]=g|8192;h=c[2276080]|0;i=g<<8;c[2276080]=i;if((h|0)!=1792&(i|0)==1792){RH(7);break}if(i>>>0<=(c[2276079]|0)>>>0){break}RH(g&16777215)}}while(0);g=c[2394]|0;i=c[14130368+(g<<2)>>2]|0;if((i|0)!=0){gGC(i|0,9104152,280)|0}c[8452240+(g<<2)>>2]=c[2113054];c[2394]=-1;if((b[7064256]&1)!=0){c[2394]=1;c[2112932]=c[3532597];g=c[3532593]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113061];g=(ag(c[2113024]|0,e)|0)/100|0;i=g-(c[2113031]|0)|0;c[2113028]=i;c[2113056]=i;g=RG(i)|0;c[2113054]=(c[2113054]|0)+g;c[2276108]=-1;c[2113056]=-1;c[2113031]=(c[2113031]|0)+g;do{if(f){g=c[3532064]|0;c[8452200+(c[2394]<<2)>>2]=g|8192;i=c[2276080]|0;h=g<<8;c[2276080]=h;if((i|0)!=1792&(h|0)==1792){RH(7);break}if(h>>>0<=(c[2276079]|0)>>>0){break}RH(g&16777215)}}while(0);f=c[2394]|0;g=c[14130368+(f<<2)>>2]|0;if((g|0)!=0){gGC(g|0,9104152,280)|0}c[8452240+(f<<2)>>2]=c[2113054];c[2394]=-1}f=c[2439330]|0;if((f|0)!=0){g=f;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;Sb(ag((c[2113022]|0)/100|0,d)|0);g=c[1836236]|0;f=c[9757320+(g<<2)>>2]|0;if((f|0)!=0){h=f;gGC(h|0,9706056,76)|0}c[9752472+(g<<2)>>2]=c[2433530];c[14113936+(g<<2)>>2]=c[2076596];c[9669104+(g<<2)>>2]=c[3541536];c[1836236]=-1;if((e|0)<100){d=e}else{break}}d=c[2439330]|0;if((d|0)!=0){g=d;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;g=c[2113022]|0;d=gGU(g,(g|0)<0|0?-1:0,2048e6,0)|0;h=c[2438228]|0;f=gGS(d,K,h,(h|0)<0|0?-1:0)|0;h=f;Sb(g);g=c[2443830]|0;if((g|0)<1073676288){c[2443830]=g-h}g=c[2443831]|0;if((g|0)<1073676288){c[2443831]=g-h}g=(c[3528512]|0)-h|0;c[3528512]=(g|0)<0?0:g;gg[c[3542118]&4095](c[2112964]|0,a[9688]|0?534:0);g=c[1836236]|0;h=c[9757320+(g<<2)>>2]|0;if((h|0)!=0){f=h;gGC(f|0,9706056,76)|0}c[9752472+(g<<2)>>2]=c[2433530];c[14113936+(g<<2)>>2]=c[2076596];c[9669104+(g<<2)>>2]=c[3541536];c[1836236]=-1;if((c[2112968]|0)==0){return 0}gu[c[3532118]&16383]();return 0}function eXg(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;f=i;i=i+128|0;g=f|0;h=f+16|0;j=f+32|0;k=f+48|0;l=f+64|0;m=f+80|0;n=f+96|0;o=f+112|0;if((e|0)!=0){c[e>>2]=169604}if((d&32|0)!=0){gGz(o|0,0,12);p=c[3532020]|0;c[o>>2]=p;c[o+4>>2]=(c[3532022]|0)-p;c[o+12>>2]=162152;p=c[2076592]|0;gj[p&4095](o)|0}eZ7(d);if((d&64|0)!=0){o=j|0;gGz(h|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){p=j+9|0;j=g;q=g|0;r=g+4|0;s=g+12|0;t=h|0;u=h+4|0;v=h+12|0;w=0;do{gGC(o|0,614896,11)|0;a[p]=w+48&255;x=8452256+(w<<2)|0;gGz(j|0,0,12);c[q>>2]=x;c[r>>2]=4;c[s>>2]=164976;gj[c[2076592]&4095](g)|0;if((c[x>>2]|0)!=0){c[t>>2]=c[14130368+(w<<2)>>2];c[u>>2]=c[8452184+(w<<2)>>2];c[v>>2]=o;x=c[2076592]|0;gj[x&4095](h)|0}w=w+1|0;}while((w|0)<=(c[2392]|0))}fw$(d);if(a[7460960]|0){T0(d,e)}gGz(n|0,0,12);c[n>>2]=14128320;c[n+4>>2]=6;c[n+12>>2]=273024;e=c[2076592]|0;gj[e&4095](n)|0;gGz(m|0,0,12);c[m>>2]=14127752;c[m+4>>2]=1;c[m+12>>2]=272344;n=c[2076592]|0;gj[n&4095](m)|0;gGz(l|0,0,12);c[l>>2]=8452120;c[l+4>>2]=16;c[l+12>>2]=270496;m=c[2076592]|0;gj[m&4095](l)|0;gGz(k|0,0,12);c[k>>2]=8452112;c[k+4>>2]=4;c[k+12>>2]=269664;l=c[2076592]|0;gj[l&4095](k)|0}k=a[14127752]|0;if(!((d&2|0)!=0&k<<24>>24!=0)){i=f;return 0}d=c[2439330]|0;l=(d|0)==0;if(!l){m=d;gGC(9706056,m|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];m=c[3528484]|0;c[2076596]=m;n=c[2417276]|0;c[3541536]=n;c[1836236]=0;e=c[3531932]|0;w=(k&255)<<14;k=64;h=64;while(1){c[d+76+(h<<2)>>2]=e+((h<<8)+w);o=k+1&65535;if((o&65535)>127){y=64;z=64;break}else{k=o;h=o&65535}}while(1){h=e+((z<<8)+w)|0;c[d+76+(z+512<<2)>>2]=h;c[d+76+(z+768<<2)>>2]=h;h=y+1&65535;if((h&65535)>127){break}else{y=h;z=h&65535}}if(!l){l=d;gGC(l|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=m;c[2417276]=n;c[1836236]=-1;i=f;return 0}function eXh(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4105444+(b*112|0)>>2];c[a+104>>2]=c[4105448+(b*112|0)>>2];c[a+108>>2]=c[4105452+(b*112|0)>>2];d=0;return d|0}function eXi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=4105344+(b*112|0);e=0;return e|0}function eXj(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1285928+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eXk(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>38){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4107248+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eXl(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;c[3532162]=256;c[3532160]=4;c[3532142]=8;c[3532164]=8;c[3532148]=1983656;c[3532140]=6964248;c[3532138]=6963992;c[3532042]=32768;c[3532002]=1024;c[3532e3]=4;a[7460944]=1;c[3532004]=16;c[3531998]=682264;c[3531992]=691256;c[3531990]=691192;c[3532034]=16384;c[3532044]=1;c[3532030]=1;a[7460960]=1;eZ9(0)|0;c[3532048]=0;c[3532204]=0;d=c[3532200]|0;c[3531932]=d;e=(c[3531928]|0)+d|0;c[3531952]=e;d=e+(c[3531948]|0)|0;c[3531946]=d;e=d+(c[3531942]|0)|0;d=e|0;c[3532020]=d;c[3532208]=d;c[3531936]=e+65536;c[3531970]=e+73728;d=e+78848|0;e=d|0;c[3532022]=e;c[3532136]=e;e=ag(c[3532142]|0,c[3532042]|0)|0;f=(ag(e,c[3532164]|0)|0)+d|0;c[3531962]=f;d=ag(a[7460944]|0?16:0,c[3532034]|0)|0;e=(ag(d,c[3532004]|0)|0)+f|0;c[3532046]=e;f=e;e=0;while(1){if((e|0)>=1024){break}g=9638528+(e<<2)|0;if((c[g>>2]|0)==0){i=31902;break}else{e=e+1|0}}do{if((i|0)==31902){e=gGq(f)|0;c[g>>2]=e;if((e|0)==0){break}gGz(e|0,0,f|0);c[3532048]=e;gGz(e|0,0,f|0);c[3532204]=e;d=c[3532200]|0;c[3531932]=e+d;j=(c[3531928]|0)+d|0;c[3531952]=e+j;d=j+(c[3531948]|0)|0;c[3531946]=e+d;j=d+(c[3531942]|0)|0;d=e+j|0;c[3532020]=d;c[3532208]=d;c[3531936]=e+(j+65536);c[3531970]=e+(j+73728);d=j+78848|0;j=e+d|0;c[3532022]=j;c[3532136]=j;j=ag(c[3532142]|0,c[3532042]|0)|0;k=(ag(j,c[3532164]|0)|0)+d|0;c[3531962]=e+k;d=ag(a[7460944]|0?16:0,c[3532034]|0)|0;c[3532046]=e+((ag(d,c[3532004]|0)|0)+k);k=c[642608+(c[2436]<<2)>>2]|0;d=c[k+128>>2]|0;if((c[k+52>>2]&4|0)==0){c[2113068]=d;e=c[k+132>>2]|0;c[2113070]=e;c[2443814]=d;c[2440436]=e;l=d;m=e}else{c[2113070]=d;e=c[k+132>>2]|0;c[2113068]=e;c[2440436]=d;c[2443814]=e;l=e;m=d}d=ag(l<<1,m)|0;e=gGq(d)|0;c[2112926]=e;if((e|0)!=0){gGz(e|0,0,d|0)}eX5(0,c[3532042]|0,4,24,0,0);d=c[2113070]|0;c[2430060]=320;c[2429702]=d;c[2429698]=0;eX5(1,c[3532042]|0,4,24,0,0);d=c[2113070]|0;c[2430061]=320;c[2429703]=d;c[2429699]=320;c[2427077]=4096;d=0;while(1){if((d|0)>=1024){n=0;break}o=9638528+(d<<2)|0;if((c[o>>2]|0)==0){i=31912;break}else{d=d+1|0}}do{if((i|0)==31912){d=gGq(16384)|0;c[o>>2]=d;if((d|0)==0){n=0;break}gGz(d|0,0,16384);n=d}}while(0);c[2442928]=n;gGz(n|0,0,16384);d=0;while(1){if((d|0)>=1024){p=0;break}q=9638528+(d<<2)|0;if((c[q>>2]|0)==0){i=31952;break}else{d=d+1|0}}do{if((i|0)==31952){d=gGq(16384)|0;c[q>>2]=d;if((d|0)==0){p=0;break}gGz(d|0,0,16384);p=d}}while(0);c[2442926]=p;gGz(p|0,0,16384);d=0;while(1){if((d|0)>=1024){r=0;break}s=9638528+(d<<2)|0;if((c[s>>2]|0)==0){i=31917;break}else{d=d+1|0}}do{if((i|0)==31917){d=gGq(32768)|0;c[s>>2]=d;if((d|0)==0){r=0;break}gGz(d|0,0,32768);r=d}}while(0);c[3532276]=r;gGz(r|0,0,8192);c[3532274]=8192;a[7461088]=1;a[7461080]=1;a[7461056]=1;if((eZ9(1)|0)!=0){t=1;return t|0}fxU(0,425984);if((c[2394]|0)==0){u=c[2112932]|0}else{c[2394]=0;d=c[3532596]|0;c[2112932]=d;e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060];u=d}d=c[3532204]|0;e=u|0;k=0;while(1){j=d+k|0;c[e>>2]=j;c[e+131072>>2]=j;j=k+1024|0;if(j>>>0>1048575){break}else{e=e+4|0;k=j}}k=c[3532208]|0;e=u+4096|0;d=1048576;while(1){j=k+(d-1048576)|0;c[e>>2]=j;c[e+65536>>2]=j;c[e+131072>>2]=j;j=d+1024|0;if(j>>>0>1114111){break}else{e=e+4|0;d=j}}d=c[3532278]|0;e=u+8192|0;k=2097152;while(1){c[e>>2]=d+(k-2097152);j=k+1024|0;if(j>>>0>2179071){break}else{e=e+4|0;k=j}}k=c[3532279]|0;e=u+9216|0;d=2359296;while(1){c[e>>2]=k+(d-2359296);j=d+1024|0;if(j>>>0>2441215){break}else{e=e+4|0;d=j}}d=c[3531970]|0;c[u+24576>>2]=d;c[u+90112>>2]=d;c[u+155648>>2]=d;e=d+1024|0;c[u+24580>>2]=e;c[u+90116>>2]=e;c[u+155652>>2]=e;e=d+2048|0;c[u+24584>>2]=e;c[u+90120>>2]=e;c[u+155656>>2]=e;e=d+3072|0;c[u+24588>>2]=e;c[u+90124>>2]=e;c[u+155660>>2]=e;e=d+4096|0;c[u+24592>>2]=e;c[u+90128>>2]=e;c[u+155664>>2]=e;c[u+196608>>2]=214;c[u+196648>>2]=932;c[u+196688>>2]=1964;c[u+196728>>2]=1596;e=c[3532592]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);e=c[2439330]|0;d=(e|0)==0;if(!d){k=e;gGC(9706056,k|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];k=c[3528484]|0;c[2076596]=k;j=c[2417276]|0;c[3541536]=j;c[1836236]=0;c[e+4180>>2]=1396;c[e+4184>>2]=2632;v=c[3531932]|0;w=0;x=0;while(1){c[e+76+(x<<2)>>2]=v+(x<<8);y=w+1&65535;if((y&65535)>63){z=0;A=0;break}else{w=y;x=y&65535}}while(1){x=v+(A<<8)|0;c[e+76+(A+512<<2)>>2]=x;c[e+76+(A+768<<2)>>2]=x;x=z+1&65535;if((x&65535)>63){B=64;C=64;break}else{z=x;A=x&65535}}while(1){c[e+76+(C<<2)>>2]=v+(C<<8);x=B+1&65535;if((x&65535)>127){D=64;E=64;break}else{B=x;C=x&65535}}while(1){x=v+(E<<8)|0;c[e+76+(E+512<<2)>>2]=x;c[e+76+(E+768<<2)>>2]=x;x=D+1&65535;if((x&65535)>127){break}else{D=x;E=x&65535}}v=c[3531936]|0;x=192;w=192;while(1){c[e+76+(w<<2)>>2]=v+((w<<8)-49152);y=x+1&65535;if((y&65535)>223){F=192;G=192;break}else{x=y;w=y&65535}}while(1){c[e+76+(G+256<<2)>>2]=v+((G<<8)-49152);w=F+1&65535;if((w&65535)>223){H=192;I=192;break}else{F=w;G=w&65535}}while(1){w=v+((I<<8)-49152)|0;c[e+76+(I+512<<2)>>2]=w;c[e+76+(I+768<<2)>>2]=w;w=H+1&65535;if((w&65535)>223){break}else{H=w;I=w&65535}}if(!d){v=e;gGC(v|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=k;c[2417276]=j;c[1836236]=-1;TW(c[3531952]|0,14127792,c[3531946]|0,14127768,1808,3364,16);c[2438228]=4e6;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=511;h[146569]=.25;h[118354]=.25;h[85170]=12.0;a[64232]=1;c[3532118]=11782;c[3532050]=8690;c[3532064]=4;c[2113026]=2e5;c[2113024]=66666;c[3532016]=300;eZ8()|0;t=0;return t|0}}while(0);c[3532048]=0;t=1;return t|0}function eXm(){var d=0,e=0,f=0,g=0,h=0;if((a[14128072]|0)!=0){d=c[3532016]|0;gD[d&8191]()|0}gu[c[3532050]&16383]();c[2113032]=0;c[2113030]=0;d=c[2392]|0;if((d|0)>=0){gGz(8452240,0,((d|0)>0?(d<<2)+4|0:4)|0)}c[2113054]=0;d=c[2385548]|0;if((d|0)>0){gGz(9752472,0,((d|0)>1?d<<2:4)|0)}c[2433530]=0;d=0;while(1){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060]}e=d+1|0;f=(ag(c[2113026]|0,e)|0)/100|0;g=f-(c[2113030]|0)|0;c[2113028]=g;c[2113056]=g;f=RG(g)|0;c[2113054]=(c[2113054]|0)+f;c[2276108]=-1;c[2113056]=-1;c[2113030]=(c[2113030]|0)+f;do{if((d|0)==99){f=c[3532064]|0;c[8452200+(c[2394]<<2)>>2]=f|8192;g=c[2276080]|0;h=f<<8;c[2276080]=h;if((g|0)!=1792&(h|0)==1792){RH(7);break}if(h>>>0<=(c[2276079]|0)>>>0){break}RH(f&16777215)}}while(0);f=c[2394]|0;h=c[14130368+(f<<2)>>2]|0;if((h|0)!=0){gGC(h|0,9104152,280)|0}c[8452240+(f<<2)>>2]=c[2113054];c[2394]=-1;f=c[2439330]|0;if((f|0)!=0){h=f;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;Sb(ag((c[2113024]|0)/100|0,d)|0);h=c[1836236]|0;f=c[9757320+(h<<2)>>2]|0;if((f|0)!=0){g=f;gGC(g|0,9706056,76)|0}c[9752472+(h<<2)>>2]=c[2433530];c[14113936+(h<<2)>>2]=c[2076596];c[9669104+(h<<2)>>2]=c[3541536];c[1836236]=-1;if((e|0)<100){d=e}else{break}}d=c[2439330]|0;if((d|0)!=0){h=d;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;h=c[2113024]|0;d=gGU(h,(h|0)<0|0?-1:0,2048e6,0)|0;g=c[2438228]|0;f=gGS(d,K,g,(g|0)<0|0?-1:0)|0;g=f;Sb(h);h=c[2443830]|0;if((h|0)<1073676288){c[2443830]=h-g}h=c[2443831]|0;if((h|0)<1073676288){c[2443831]=h-g}h=(c[3528512]|0)-g|0;c[3528512]=(h|0)<0?0:h;gg[c[3542118]&4095](c[2112964]|0,a[9688]|0?534:0);h=c[1836236]|0;g=c[9757320+(h<<2)>>2]|0;if((g|0)!=0){f=g;gGC(f|0,9706056,76)|0}c[9752472+(h<<2)>>2]=c[2433530];c[14113936+(h<<2)>>2]=c[2076596];c[9669104+(h<<2)>>2]=c[3541536];c[1836236]=-1;if((c[2112968]|0)==0){return 0}gu[c[3532118]&16383]();return 0}function eXn(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1964516+(b*112|0)>>2];c[a+104>>2]=c[1964520+(b*112|0)>>2];c[a+108>>2]=c[1964524+(b*112|0)>>2];d=0;return d|0}function eXo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=1964416+(b*112|0);e=0;return e|0}function eXp(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>26){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6199764+(b*112|0)>>2];c[a+104>>2]=c[6199768+(b*112|0)>>2];c[a+108>>2]=c[6199772+(b*112|0)>>2];d=0;return d|0}function eXq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<27&(d|0)==0)){e=1;return e|0}c[a>>2]=6199664+(b*112|0);e=0;return e|0}function eXr(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>28){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6202688+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eXs(){a[673136]=1;return eXd()|0}function eXt(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>26){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5204468+(b*112|0)>>2];c[a+104>>2]=c[5204472+(b*112|0)>>2];c[a+108>>2]=c[5204476+(b*112|0)>>2];d=0;return d|0}function eXu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<27&(d|0)==0)){e=1;return e|0}c[a>>2]=5204368+(b*112|0);e=0;return e|0}function eXv(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>28){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5207392+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eXw(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>26){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5201444+(b*112|0)>>2];c[a+104>>2]=c[5201448+(b*112|0)>>2];c[a+108>>2]=c[5201452+(b*112|0)>>2];d=0;return d|0}function eXx(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<27&(d|0)==0)){e=1;return e|0}c[a>>2]=5201344+(b*112|0);e=0;return e|0}function eXy(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3253484+(b*112|0)>>2];c[a+104>>2]=c[3253488+(b*112|0)>>2];c[a+108>>2]=c[3253492+(b*112|0)>>2];d=0;return d|0}function eXz(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=3253384+(b*112|0);e=0;return e|0}function eXA(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>23){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1174592+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eXB(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>45){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3255512+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eXC(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;c[3532162]=256;c[3532160]=4;c[3532142]=8;c[3532164]=8;c[3532148]=1983656;c[3532140]=6964248;c[3532138]=6963992;c[3532042]=65536;c[3532178]=256;c[3532176]=4;a[7461200]=1;a[7461208]=1;c[3532174]=1983656;c[3532168]=6964248;c[3532166]=6963992;c[3532040]=65536;c[3532002]=1024;c[3532e3]=4;a[7460944]=1;c[3532004]=16;c[3531998]=682264;c[3531992]=691256;c[3531990]=691192;c[3532034]=32768;c[3532044]=1;c[3532030]=1;a[7460960]=1;eZ9(0)|0;c[3532048]=0;c[3532204]=0;d=c[3532200]|0;c[3531932]=d;e=(c[3531928]|0)+d|0;c[3531952]=e;d=e+(c[3531948]|0)|0;c[3531946]=d;e=d+(c[3531942]|0)|0;d=e|0;c[3532020]=d;c[3532208]=d;c[3531936]=e+81920;c[3531970]=e+90112;d=e+95232|0;e=d|0;c[3532022]=e;c[3532136]=e;e=ag(c[3532142]|0,c[3532042]|0)|0;f=(ag(e,c[3532164]|0)|0)+d|0;c[3532134]=f;d=ag(a[7461200]|0?8:0,c[3532040]|0)|0;e=(ag(d,a[7461208]|0?8:0)|0)+f|0;c[3531962]=e;f=ag(a[7460944]|0?16:0,c[3532034]|0)|0;d=(ag(f,c[3532004]|0)|0)+e|0;c[3532046]=d;e=d;d=0;while(1){if((d|0)>=1024){break}g=9638528+(d<<2)|0;if((c[g>>2]|0)==0){i=32086;break}else{d=d+1|0}}do{if((i|0)==32086){d=gGq(e)|0;c[g>>2]=d;if((d|0)==0){break}gGz(d|0,0,e|0);c[3532048]=d;gGz(d|0,0,e|0);c[3532204]=d;f=c[3532200]|0;c[3531932]=d+f;j=(c[3531928]|0)+f|0;c[3531952]=d+j;f=j+(c[3531948]|0)|0;c[3531946]=d+f;j=f+(c[3531942]|0)|0;f=d+j|0;c[3532020]=f;c[3532208]=f;c[3531936]=d+(j+81920);c[3531970]=d+(j+90112);f=j+95232|0;j=d+f|0;c[3532022]=j;c[3532136]=j;j=ag(c[3532142]|0,c[3532042]|0)|0;k=(ag(j,c[3532164]|0)|0)+f|0;c[3532134]=d+k;f=ag(a[7461200]|0?8:0,c[3532040]|0)|0;j=(ag(f,a[7461208]|0?8:0)|0)+k|0;c[3531962]=d+j;k=ag(a[7460944]|0?16:0,c[3532034]|0)|0;c[3532046]=d+((ag(k,c[3532004]|0)|0)+j);j=c[642608+(c[2436]<<2)>>2]|0;k=c[j+128>>2]|0;if((c[j+52>>2]&4|0)==0){c[2113068]=k;d=c[j+132>>2]|0;c[2113070]=d;c[2443814]=k;c[2440436]=d;l=k;m=d}else{c[2113070]=k;d=c[j+132>>2]|0;c[2113068]=d;c[2440436]=k;c[2443814]=d;l=d;m=k}k=ag(l<<1,m)|0;d=gGq(k)|0;c[2112926]=d;if((d|0)!=0){gGz(d|0,0,k|0)}eX5(0,c[3532042]|0,4,8,0,0);k=c[2113070]|0;c[2430060]=320;c[2429702]=k;c[2429698]=0;eX5(1,c[3532040]|0,5,8,0,0);k=c[2113070]|0;c[2430061]=320;c[2429703]=k;c[2429699]=320;c[2427077]=4096;k=0;while(1){if((k|0)>=1024){n=0;break}o=9638528+(k<<2)|0;if((c[o>>2]|0)==0){i=32096;break}else{k=k+1|0}}do{if((i|0)==32096){k=gGq(16384)|0;c[o>>2]=k;if((k|0)==0){n=0;break}gGz(k|0,0,16384);n=k}}while(0);c[2442928]=n;gGz(n|0,0,16384);k=0;while(1){if((k|0)>=1024){p=0;break}q=9638528+(k<<2)|0;if((c[q>>2]|0)==0){i=32136;break}else{k=k+1|0}}do{if((i|0)==32136){k=gGq(16384)|0;c[q>>2]=k;if((k|0)==0){p=0;break}gGz(k|0,0,16384);p=k}}while(0);c[2442926]=p;gGz(p|0,0,16384);k=0;while(1){if((k|0)>=1024){r=0;break}s=9638528+(k<<2)|0;if((c[s>>2]|0)==0){i=32101;break}else{k=k+1|0}}do{if((i|0)==32101){k=gGq(32768)|0;c[s>>2]=k;if((k|0)==0){r=0;break}gGz(k|0,0,32768);r=k}}while(0);c[3532276]=r;gGz(r|0,0,8192);c[3532274]=8192;a[7461088]=1;a[7461080]=1;a[7461016]=1;if((eZ9(1)|0)!=0){t=1;return t|0}fxU(0,425984);if((c[2394]|0)==0){u=c[2112932]|0}else{c[2394]=0;k=c[3532596]|0;c[2112932]=k;d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];u=k}k=c[3532204]|0;d=u|0;j=0;while(1){f=k+j|0;c[d>>2]=f;c[d+131072>>2]=f;f=j+1024|0;if(f>>>0>2097151){break}else{d=d+4|0;j=f}}j=c[3532208]|0;d=u+8192|0;k=2097152;while(1){f=j+(k-2097152)|0;c[d>>2]=f;c[d+65536>>2]=f;c[d+131072>>2]=f;f=k+1024|0;if(f>>>0>2179071){break}else{d=d+4|0;k=f}}k=c[3532278]|0;d=u+12288|0;j=3145728;while(1){c[d>>2]=k+(j-3145728);f=j+1024|0;if(f>>>0>3227647){break}else{d=d+4|0;j=f}}j=c[3532279]|0;d=u+13312|0;k=3407872;while(1){c[d>>2]=j+(k-3407872);f=k+1024|0;if(f>>>0>3489791){break}else{d=d+4|0;k=f}}k=c[3531970]|0;c[u+24576>>2]=k;c[u+90112>>2]=k;c[u+155648>>2]=k;d=k+1024|0;c[u+24580>>2]=d;c[u+90116>>2]=d;c[u+155652>>2]=d;d=k+2048|0;c[u+24584>>2]=d;c[u+90120>>2]=d;c[u+155656>>2]=d;d=k+3072|0;c[u+24588>>2]=d;c[u+90124>>2]=d;c[u+155660>>2]=d;d=k+4096|0;c[u+24592>>2]=d;c[u+90128>>2]=d;c[u+155664>>2]=d;c[u+196608>>2]=2590;c[u+196648>>2]=2772;c[u+196688>>2]=3078;c[u+196728>>2]=652;d=c[3532592]|0;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);d=c[2439330]|0;k=(d|0)==0;if(!k){j=d;gGC(9706056,j|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];j=c[3528484]|0;c[2076596]=j;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;c[d+4180>>2]=1396;c[d+4184>>2]=2632;v=c[3531932]|0;w=0;x=0;while(1){c[d+76+(x<<2)>>2]=v+(x<<8);y=w+1&65535;if((y&65535)>63){z=0;A=0;break}else{w=y;x=y&65535}}while(1){x=v+(A<<8)|0;c[d+76+(A+512<<2)>>2]=x;c[d+76+(A+768<<2)>>2]=x;x=z+1&65535;if((x&65535)>63){B=64;C=64;break}else{z=x;A=x&65535}}while(1){c[d+76+(C<<2)>>2]=v+(C<<8);x=B+1&65535;if((x&65535)>127){D=64;E=64;break}else{B=x;C=x&65535}}while(1){x=v+(E<<8)|0;c[d+76+(E+512<<2)>>2]=x;c[d+76+(E+768<<2)>>2]=x;x=D+1&65535;if((x&65535)>127){break}else{D=x;E=x&65535}}v=c[3531936]|0;x=192;w=192;while(1){c[d+76+(w<<2)>>2]=v+((w<<8)-49152);y=x+1&65535;if((y&65535)>223){F=192;G=192;break}else{x=y;w=y&65535}}while(1){c[d+76+(G+256<<2)>>2]=v+((G<<8)-49152);w=F+1&65535;if((w&65535)>223){H=192;I=192;break}else{F=w;G=w&65535}}while(1){w=v+((I<<8)-49152)|0;c[d+76+(I+512<<2)>>2]=w;c[d+76+(I+768<<2)>>2]=w;w=H+1&65535;if((w&65535)>223){break}else{H=w;I=w&65535}}if(!k){v=d;gGC(v|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=j;c[2417276]=f;c[1836236]=-1;TW(c[3531952]|0,14127792,c[3531946]|0,14127768,1808,3364,16);c[2438228]=4e6;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=511;h[146569]=.25;h[118354]=.25;h[85170]=12.0;a[64232]=1;c[3532118]=2206;c[3532050]=5234;c[3532064]=4;c[2113026]=266666;c[2113024]=66666;c[3532016]=300;eZ8()|0;t=0;return t|0}}while(0);c[3532048]=0;t=1;return t|0}function eXD(b,c){b=b|0;c=c|0;a[9706117]=c&1;return}function eXE(a){a=a|0;var b=0,d=0;b=(c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,4e6,0)|0;return a|0}function eXF(){return+(+((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)/4.0e6)}function eXG(){var a=0,d=0,f=0,g=0;a=e[7064582]|0;d=e[7064590]|0;f=c[2112926]|0;gGz(f|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);do{if((b[7064582]&8)==0){if((a&1|0)==0){eX0(0,0,c[3532136]|0)}if((d&1|0)==0){eX0(1,0,c[3532134]|0)}eXI(1);if((a&2|0)==0){eX3(0,0,c[3532136]|0)}if((d&2|0)!=0){break}eX3(1,0,c[3532134]|0)}else{if((a&2|0)==0){eX3(0,0,c[3532136]|0)}if((d&2|0)==0){eX3(1,0,c[3532134]|0)}eXI(1);if((a&1|0)==0){eX0(0,0,c[3532136]|0)}if((d&1|0)!=0){break}eX0(1,0,c[3532134]|0)}}while(0);eXI(0);if((a&4|0)==0){eX4(0)}if((d&4|0)!=0){g=c[3532276]|0;R8(g);return}eX4(1);g=c[3532276]|0;R8(g);return}function eXH(){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a[14128912]=-1;a[14128913]=-1;a[14128914]=-9;if((a[14128888]|0)==0){b=-9}else{a[14128914]=-10;b=-10}if((a[14128889]|0)==0){c=b}else{d=b-2&255;a[14128914]=d;c=d}if((a[14128890]|0)==0){e=c}else{d=c-4&255;a[14128914]=d;e=d}if((a[14128891]|0)==0){f=e}else{d=e|8;a[14128914]=d;f=d}if((a[14128892]|0)==0){g=f}else{d=f-16&255;a[14128914]=d;g=d}if((a[14128893]|0)==0){h=g}else{d=g-32&255;a[14128914]=d;h=d}if((a[14128894]|0)==0){i=h}else{d=h-64&255;a[14128914]=d;i=d}if((a[14128895]|0)==0){j=0;k=-1;l=-1}else{a[14128914]=i^-128;j=0;k=-1;l=-1}do{k=(k&255)-((a[14128904+j|0]&1)<<j)&255;l=(l&255)-((a[14128896+j|0]&1)<<j)&255;j=j+1|0;}while((j|0)<8);a[14128912]=k;a[14128913]=l;return}function eXI(a){a=a|0;var b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=c[3531970]|0;d=(c[3532034]|0)+65535|0;f=c[2112926]|0;g=c[3531962]|0;h=2556;do{i=d&(e[b+((h|1)<<1)>>1]|0);j=e[b+(h<<1)>>1]|0;k=j>>>9&1;l=e[b+((h|2)<<1)>>1]|0;m=l&127;n=e[b+((h|3)<<1)>>1]|0;o=n&1023;p=n>>>10&1;L42157:do{if((l>>>8&1|0)==(a|0)){q=-24-j&511;r=q-16|0;s=o>>>0>960?n|-1024:o;t=(r|0)>384?q-528|0:r;do{if((s|0)>16){if(!((s|0)<((c[2113068]|0)-16|0)&(t|0)>16)){break}if((t|0)>=((c[2113070]|0)-16|0)){break}r=(k|0)!=0;if((p|0)==0){if(r){SK(f,i,s,t,m,4,0,0,g);break L42157}else{SG(f,i,s,t,m,4,0,0,g);break L42157}}else{if(r){SM(f,i,s,t,m,4,0,0,g);break L42157}else{SI(f,i,s,t,m,4,0,0,g);break L42157}}}}while(0);r=(k|0)!=0;if((p|0)==0){if(r){SL(f,i,s,t,m,4,0,0,g);break}else{SH(f,i,s,t,m,4,0,0,g);break}}else{if(r){SN(f,i,s,t,m,4,0,0,g);break}else{SJ(f,i,s,t,m,4,0,0,g);break}}}}while(0);h=h-4|0;}while((h|0)>-1);return}function eXJ(){var a=0,d=0,f=0,g=0;a=e[7064582]|0;d=e[7064590]|0;f=c[2112926]|0;gGz(f|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);do{if((b[7064582]&8)==0){if((a&1|0)==0){eX0(0,0,c[3532136]|0)}if((d&1|0)==0){eX0(1,0,c[3532136]|0)}eXI(1);if((a&2|0)==0){eX3(0,0,c[3532136]|0)}if((d&2|0)!=0){break}eX3(1,0,c[3532136]|0)}else{if((a&2|0)==0){eX3(0,0,c[3532136]|0)}if((d&2|0)==0){eX3(1,0,c[3532136]|0)}eXI(1);if((a&1|0)==0){eX0(0,0,c[3532136]|0)}if((d&1|0)!=0){break}eX0(1,0,c[3532136]|0)}}while(0);eXI(0);if((a&4|0)==0){eX4(0)}if((d&4|0)!=0){g=c[3532276]|0;R8(g);return}eX4(1);g=c[3532276]|0;R8(g);return}function eXK(){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a[14129040]=-1;a[14129041]=-1;a[14129042]=-9;if((a[14129016]|0)==0){b=-9}else{a[14129042]=-10;b=-10}if((a[14129017]|0)==0){c=b}else{d=b-2&255;a[14129042]=d;c=d}if((a[14129018]|0)==0){e=c}else{d=c-4&255;a[14129042]=d;e=d}if((a[14129019]|0)==0){f=e}else{d=e|8;a[14129042]=d;f=d}if((a[14129020]|0)==0){g=f}else{d=f-16&255;a[14129042]=d;g=d}if((a[14129021]|0)==0){h=g}else{d=g-32&255;a[14129042]=d;h=d}if((a[14129022]|0)==0){i=h}else{d=h-64&255;a[14129042]=d;i=d}if((a[14129023]|0)==0){j=0;k=-1;l=-1}else{a[14129042]=i^-128;j=0;k=-1;l=-1}do{k=(k&255)-((a[14129032+j|0]&1)<<j)&255;l=(l&255)-((a[14129024+j|0]&1)<<j)&255;j=j+1|0;}while((j|0)<8);a[14129040]=k;a[14129041]=l;return}function eXL(){var a=0,d=0,f=0,g=0,h=0;a=e[7064582]|0;d=e[7064590]|0;f=e[7064598]|0;g=c[2112926]|0;gGz(g|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);do{if((b[7064582]&8)==0){if((a&1|0)==0){eX0(0,0,c[3532136]|0)}if((d&1|0)==0){eX0(1,0,c[3532136]|0)}if((f&1|0)==0){eX0(2,0,c[3532136]|0)}eXN(1);if((a&2|0)==0){eX3(0,0,c[3532136]|0)}if((d&2|0)==0){eX3(1,0,c[3532136]|0)}if((f&2|0)!=0){break}eX3(2,0,c[3532136]|0)}else{if((a&2|0)==0){eX3(0,0,c[3532136]|0)}if((d&2|0)==0){eX3(1,0,c[3532136]|0)}if((f&2|0)==0){eX3(2,0,c[3532136]|0)}eXN(1);if((a&1|0)==0){eX0(0,0,c[3532136]|0)}if((d&1|0)==0){eX0(1,0,c[3532136]|0)}if((f&1|0)!=0){break}eX0(2,0,c[3532136]|0)}}while(0);eXN(0);if((a&4|0)==0){eX4(0)}if((d&4|0)==0){eX4(1)}if((f&4|0)!=0){h=c[3532276]|0;R8(h);return}eX4(2);h=c[3532276]|0;R8(h);return}function eXM(){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a[14129040]=-30;a[14129041]=-1;a[14129042]=-1;if((a[14129032]|0)==0){b=-30}else{a[14129040]=-29;b=-29}if((a[14129033]|0)==0){c=b}else{d=b-2&255;a[14129040]=d;c=d}if((a[14129034]|0)==0){e=c}else{d=c|4;a[14129040]=d;e=d}if((a[14129035]|0)==0){f=e}else{d=e|8;a[14129040]=d;f=d}if((a[14129036]|0)==0){g=f}else{d=f|16;a[14129040]=d;g=d}if((a[14129037]|0)==0){h=g}else{d=g-32&255;a[14129040]=d;h=d}if((a[14129038]|0)==0){i=h}else{d=h-64&255;a[14129040]=d;i=d}if((a[14129039]|0)==0){j=0;k=-1;l=-1}else{a[14129040]=i^-128;j=0;k=-1;l=-1}do{k=(k&255)-((a[14129024+j|0]&1)<<j)&255;l=(l&255)-((a[14129016+j|0]&1)<<j)&255;j=j+1|0;}while((j|0)<8);a[14129041]=k;a[14129042]=l;return}function eXN(a){a=a|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=c[3531970]|0;f=(c[3532034]|0)+65535|0;g=c[2112926]|0;h=c[3531962]|0;i=8188;do{j=f&(e[d+((i|2)<<1)>>1]|0);L42320:do{if((j|0)!=0){k=(e[d+(i<<1)>>1]|0)+992|0;l=k&1023;m=e[d+((i|3)<<1)>>1]|0;n=m&1;o=m>>>1&1;if((m>>>2&1|0)!=(a|0)){break}p=b[d+((i|1)<<1)>>1]&511;q=m>>>8&127;m=p-16|0;r=l>>>0>960?k|-1024:l;l=(m|0)>384?p-528|0:m;do{if((r|0)>16){if(!((r|0)<((c[2113068]|0)-16|0)&(l|0)>16)){break}if((l|0)>=((c[2113070]|0)-16|0)){break}m=(o|0)!=0;if((n|0)==0){if(m){SK(g,j,r,l,q,4,0,0,h);break L42320}else{SG(g,j,r,l,q,4,0,0,h);break L42320}}else{if(m){SM(g,j,r,l,q,4,0,0,h);break L42320}else{SI(g,j,r,l,q,4,0,0,h);break L42320}}}}while(0);m=(o|0)!=0;if((n|0)==0){if(m){SL(g,j,r,l,q,4,0,0,h);break}else{SH(g,j,r,l,q,4,0,0,h);break}}else{if(m){SN(g,j,r,l,q,4,0,0,h);break}else{SJ(g,j,r,l,q,4,0,0,h);break}}}}while(0);i=i-4|0;}while((i|0)>-1);return}function eXO(a,d){a=a|0;d=d|0;var e=0;e=c[2436808]&64;b[14128936+(a<<1)>>1]=d;switch(a|0){case 7:{c[2388341]=((e|0)==0?d:-d&65535)&65535;return};case 6:{c[2388340]=((e|0)==0?d:-d&65535)&65535;return};case 4:{c[2388338]=((e|0)==0?d:-d&65535)&65535;return};case 5:{c[2388339]=((e|0)==0?d:-d&65535)&65535;return};case 3:{c[2388351]=((e|0)==0?-12-d&65535:d+12&65535)&65535;return};case 0:{c[2388348]=((e|0)==0?-d&65535:d)&65535;return};case 13:{a=(c[2429696]|0)+(c[2429456]|0)|0;c[3527498]=-(((e|0)!=0?a:-a|0)+(d&65535)&65535);return};case 12:{a=c[2429458]|0;c[3527506]=-(((e|0)!=0?a:-a|0)+(d&65535)&65535);return};case 2:{c[2388350]=((e|0)==0?-8-d&65535:d+8&65535)&65535;return};case 1:{c[2388349]=((e|0)==0?-4-d&65535:d+4&65535)&65535;return};case 15:{e=d&65535;c[2436808]=e;c[2430806]=e>>>7&1;return};default:{return}}}function eXP(d,f,g){d=d|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;h=i;i=i+1024|0;j=h|0;k=c[2429846]|0;l=c[3532232]|0;m=(c[2430806]|0)==0;n=m?l+16384|0:l+32768|0;do{if((d|0)==1){if(m){o=l+17408|0;p=l+4096|0;break}o=l+33792|0;p=l+8192|0}else{o=n;p=l}}while(0);l=p;p=m?32:64;n=e[14128936+(d+8<<1)>>1]|0;q=n<<9;gGz(k|0,0,1048576);r=(f|0)==0;f=(c[2430804]|0)+65535|0;s=a[1666920]|0?256:0;t=0;u=0;while(1){v=u<<4;w=t;x=0;while(1){y=w<<1;z=e[l+(y<<1)>>1]|0;A=f&(e[l+((y|1)<<1)>>1]|0);y=s|z&255;B=x<<4;C=(z&16384|0)!=0;D=(z&32768|0)!=0;do{if(r){if(C){if(D){eXX(k,A,B,v,y,g);break}else{eXY(k,A,B,v,y,g);break}}else{if(D){eXZ(k,A,B,v,y,g);break}else{eX_(k,A,B,v,y,g);break}}}else{if(C){if(D){eXT(k,A,B,v,y,g);break}else{eXU(k,A,B,v,y,g);break}}else{if(D){eXV(k,A,B,v,y,g);break}else{eXW(k,A,B,v,y,g);break}}}}while(0);y=x+1|0;if((y|0)>=(p|0)){break}w=w+1|0;x=y}x=u+1|0;if((x|0)<32){t=t+p|0;u=x}else{break}}u=o;o=m?511:1023;m=65536-(n&65280)|0;n=q&130560^130560;q=d<<2;t=((e[14128936+(d+16<<1)>>1]|0)<<8&65280|q+15+(c[9553392+(d<<2)>>2]|0)<<16)^65280;g=t+(ag(-15-q-(c[2433282]|0)|0,m)|0)|0;q=(e[14128936+(d+20<<1)>>1]|0)<<8&65280|c[9553352+(d<<2)>>2]<<16;d=q+(ag((c[2429696]|0)+(c[2433280]|0)|0,n)|0)|0;q=p<<4;p=j|0;if(!r){r=c[2112926]|0;j=c[2113068]|0;t=(j|0)==0;s=c[2113070]|0;l=j-1|0;f=(l|0)==0;x=0;w=d;while(1){v=w>>>16&511;y=ag(v,q)|0;B=0;A=g-((e[u+(v<<1)>>1]|0)<<16)-((e[u+((v|2048)<<1)>>1]|0)<<8&65280)|0;v=p;while(1){b[v>>1]=b[k+((A>>>16&o)+y<<1)>>1]|0;D=B+1|0;if((D|0)<512){B=D;A=A+m|0;v=v+2|0}else{break}}v=r+((ag(j,x)|0)<<1)|0;do{if(!t){b[v>>1]=b[p>>1]|0;if(f){break}else{E=p;F=v;G=l}do{F=F+2|0;E=E+2|0;G=G-1|0;b[F>>1]=b[E>>1]|0;}while((G|0)!=0)}}while(0);v=x+1|0;if((v|0)<(s|0)){x=v;w=w+n|0}else{break}}i=h;return}w=c[2113068]|0;x=(w|0)==0;s=c[2113070]|0;G=c[2112926]|0;E=0;F=d;while(1){d=F>>>16&511;l=ag(d,q)|0;f=0;t=g-((e[u+(d<<1)>>1]|0)<<16)-((e[u+((d|2048)<<1)>>1]|0)<<8&65280)|0;d=p;while(1){j=b[k+((t>>>16&o)+l<<1)>>1]|0;b[d>>1]=(j&15)==0?-32768:j;j=f+1|0;if((j|0)<512){f=j;t=t+m|0;d=d+2|0}else{break}}if(!x){d=G+((ag(w,E)|0)<<1)|0;t=p;f=w;while(1){l=f-1|0;j=b[t>>1]|0;if((j&65535)<32767){b[d>>1]=j}if((l|0)==0){break}else{d=d+2|0;t=t+2|0;f=l}}}f=E+1|0;if((f|0)<(s|0)){E=f;F=F+n|0}else{break}}i=h;return}function eXQ(d,f,g){d=d|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;h=i;i=i+1024|0;j=h|0;k=c[2429846]|0;l=e[14128936+(d+8<<1)>>1]|0;m=65536-(l&65280)|0;n=l<<9&130560^130560;l=c[3532232]|0;o=l+24576|0;p=(c[2430806]|0)==0;if(p){q=l+26624|0;r=o;s=l+18432|0;t=l+8192|0}else{q=l+43008|0;r=l+40960|0;s=l+34816|0;t=l+16384|0}do{if((d|0)==3){if(p){u=l+27648|0;v=l+25600|0;w=l+19456|0;x=l+12288|0;break}u=l+44032|0;v=l+41984|0;w=l+35840|0;x=o}else{u=q;v=r;w=s;x=t}}while(0);t=x;x=p?32:64;gGz(k|0,0,1048576);s=(f|0)==0;r=(c[2430804]|0)+65535|0;q=a[1666920]|0?256:0;o=0;l=0;while(1){y=l<<4;z=o;A=0;while(1){B=z<<1;C=e[t+(B<<1)>>1]|0;D=r&(e[t+((B|1)<<1)>>1]|0);B=q|C&255;E=A<<4;F=(C&16384|0)!=0;G=(C&32768|0)!=0;do{if(s){if(F){if(G){eXX(k,D,E,y,B,g);break}else{eXY(k,D,E,y,B,g);break}}else{if(G){eXZ(k,D,E,y,B,g);break}else{eX_(k,D,E,y,B,g);break}}}else{if(F){if(G){eXT(k,D,E,y,B,g);break}else{eXU(k,D,E,y,B,g);break}}else{if(G){eXV(k,D,E,y,B,g);break}else{eXW(k,D,E,y,B,g);break}}}}while(0);B=A+1|0;if((B|0)>=(x|0)){break}z=z+1|0;A=B}A=l+1|0;if((A|0)<32){o=o+x|0;l=A}else{break}}l=v;v=u;u=w;w=p?511:1023;p=d<<2;o=((e[14128936+(d+16<<1)>>1]|0)<<8&65280|p+15+(c[9553392+(d<<2)>>2]|0)<<16)^65280;g=c[2433282]|0;s=o+(ag(-15-p-g|0,m)|0)|0;o=(e[14128936+(d+20<<1)>>1]|0)<<8&65280|c[9553352+(d<<2)>>2]<<16;q=(c[2429696]|0)+(c[2433280]|0)|0;t=o+(ag(q,n)|0)|0;o=d-1|0;d=x<<4;x=j|0;j=(f|0)!=0;f=p-31-g|0;g=c[2112926]|0;p=c[2113068]|0;r=(p|0)==0;A=c[2113070]|0;z=0;y=t;while(1){t=(e[v+((q+z&511)<<1)>>1]|0)+(y>>>16)&511;if((c[2436808]&o|0)==0){H=0}else{H=e[l+(t<<1)>>1]|0}B=s-((e[u+(t<<1)>>1]|0)<<16)-((e[u+((t|2048)<<1)>>1]|0)<<8&65280)|0;E=H<<8&65280;D=B-(ag(f,E)|0)|0;B=m-((H|0)==0?0:E)|0;E=ag(t,d)|0;if(j){t=0;G=D;F=x;while(1){b[F>>1]=b[k+((G>>>16&w)+E<<1)>>1]|0;C=t+1|0;if((C|0)<512){t=C;G=G+B|0;F=F+2|0}else{break}}}else{F=0;G=D;t=x;while(1){C=b[k+((G>>>16&w)+E<<1)>>1]|0;b[t>>1]=(C&15)==0?-32768:C;C=F+1|0;if((C|0)<512){F=C;G=G+B|0;t=t+2|0}else{break}}}t=g+((ag(p,z)|0)<<1)|0;do{if(j){if(r){break}else{I=t;J=p;K=x}while(1){B=J-1|0;b[I>>1]=b[K>>1]|0;if((B|0)==0){break}else{I=I+2|0;J=B;K=K+2|0}}}else{if(r){break}else{L=t;M=x;N=p}while(1){B=N-1|0;G=b[M>>1]|0;if((G&65535)<32767){b[L>>1]=G}if((B|0)==0){break}else{L=L+2|0;M=M+2|0;N=B}}}}while(0);t=z+1|0;if((t|0)>=(A|0)){break}z=t;y=y+n|0}i=h;return}function eXR(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;b=c[3532232]|0;f=b+49152|0;g=c[2438406]|0;h=0;do{i=h<<6;gGz(g+i|0,0,64);j=h<<8;k=0;do{l=1<<3-k;m=(c[703416+(k<<2)>>2]|0)+j|0;n=0;do{o=m+(c[1183816+(n<<2)>>2]|0)|0;p=(n<<3)+i|0;q=0;do{r=o+(c[1183848+(q<<2)>>2]|0)|0;if(((d[b+(((r|0)/8|0)+57344)|0]|0)&128>>>((r&7)>>>0)|0)!=0){r=g+(p+q)|0;a[r]=(d[r]|0|l)&255}q=q+1|0;}while((q|0)<8);n=n+1|0;}while((n|0)<8);k=k+1|0;}while((k|0)<4);h=h+1|0;}while((h|0)<256);h=f;f=a[1666920]|0?256:0;b=c[2112926]|0;k=0;i=0;while(1){j=i<<3;n=k;l=0;while(1){m=e[h+(n<<1)>>1]|0;q=m&255;p=m>>>14&1;o=m>>>15;r=m>>>8&63|f;m=(l<<3)-(c[3527506]&511)|0;s=j-(c[3527498]&511)|0;t=(m|0)<-8?m+512|0:m;m=(s|0)<-8?s+512|0:s;do{if((t|0)>7){if(!((t|0)<((c[2113068]|0)-8|0)&(m|0)>7)){u=32455;break}if((m|0)>=((c[2113070]|0)-8|0)){u=32455;break}s=(o|0)!=0;if((p|0)==0){if(s){Su(b,q,t,m,r,4,0,0,g);break}else{Sq(b,q,t,m,r,4,0,0,g);break}}else{if(s){Sw(b,q,t,m,r,4,0,0,g);break}else{Ss(b,q,t,m,r,4,0,0,g);break}}}else{u=32455}}while(0);do{if((u|0)==32455){u=0;s=(o|0)!=0;if((p|0)==0){if(s){Sv(b,q,t,m,r,4,0,0,g);break}else{Sr(b,q,t,m,r,4,0,0,g);break}}else{if(s){Sx(b,q,t,m,r,4,0,0,g);break}else{St(b,q,t,m,r,4,0,0,g);break}}}}while(0);r=l+1|0;if((r|0)<64){n=n+1|0;l=r}else{break}}l=i+1|0;if((l|0)<64){k=k+64|0;i=l}else{break}}return}function eXS(b,d,e,f,g,h,i){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;j=0;while(1){if((j|0)>=1024){k=0;break}l=9638528+(j<<2)|0;if((c[l>>2]|0)==0){m=32468;break}else{j=j+1|0}}do{if((m|0)==32468){j=gGq(65536)|0;c[l>>2]=j;if((j|0)==0){k=0;break}gGz(j|0,0,65536);k=j}}while(0);c[3532232]=k;gGz(k|0,0,65536);k=0;while(1){if((k|0)>=1024){n=0;break}o=9638528+(k<<2)|0;if((c[o>>2]|0)==0){m=32473;break}else{k=k+1|0}}do{if((m|0)==32473){k=gGq(16384)|0;c[o>>2]=k;if((k|0)==0){n=0;break}gGz(k|0,0,16384);n=k}}while(0);c[2438406]=n;gGz(n|0,0,16384);c[2430804]=b;b=e+d|0;c[2433282]=-b;c[2433280]=f;c[2429458]=b+3+g;c[2429456]=h+f;f=0;while(1){if((f|0)>=1024){p=0;break}q=9638528+(f<<2)|0;if((c[q>>2]|0)==0){m=32478;break}else{f=f+1|0}}do{if((m|0)==32478){f=gGq(1048576)|0;c[q>>2]=f;if((f|0)==0){p=0;break}gGz(f|0,0,1048576);p=f}}while(0);c[2429846]=p;gGz(p|0,0,1048576);a[1666920]=0;c[2429696]=i;a[7461024]=1;return}function eXT(a,e,f,g,h,i){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;j=h<<4;h=i+(e<<8)|0;c[2112928]=h;e=(c[2430806]|0)==0?512:1024;i=-e|0;k=a+((ag(e,g+15|0)|0)+f<<1)|0;f=15;g=h;while(1){b[k+30>>1]=(d[g]|0|j)&65535;b[k+28>>1]=(d[g+1|0]|0|j)&65535;b[k+26>>1]=(d[g+2|0]|0|j)&65535;b[k+24>>1]=(d[g+3|0]|0|j)&65535;b[k+22>>1]=(d[g+4|0]|0|j)&65535;b[k+20>>1]=(d[g+5|0]|0|j)&65535;b[k+18>>1]=(d[g+6|0]|0|j)&65535;b[k+16>>1]=(d[g+7|0]|0|j)&65535;b[k+14>>1]=(d[g+8|0]|0|j)&65535;b[k+12>>1]=(d[g+9|0]|0|j)&65535;b[k+10>>1]=(d[g+10|0]|0|j)&65535;b[k+8>>1]=(d[g+11|0]|0|j)&65535;b[k+6>>1]=(d[g+12|0]|0|j)&65535;b[k+4>>1]=(d[g+13|0]|0|j)&65535;b[k+2>>1]=(d[g+14|0]|0|j)&65535;b[k>>1]=(d[g+15|0]|0|j)&65535;l=g+16|0;if((f|0)>0){k=k+(i<<1)|0;f=f-1|0;g=l}else{break}}c[2112928]=l;return}function eXU(a,e,f,g,h,i){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0;j=h<<4;h=i+(e<<8)|0;c[2112928]=h;e=(c[2430806]|0)==0?512:1024;i=a+((ag(e,g)|0)+f<<1)|0;f=0;g=h;while(1){b[i+30>>1]=(d[g]|0|j)&65535;b[i+28>>1]=(d[g+1|0]|0|j)&65535;b[i+26>>1]=(d[g+2|0]|0|j)&65535;b[i+24>>1]=(d[g+3|0]|0|j)&65535;b[i+22>>1]=(d[g+4|0]|0|j)&65535;b[i+20>>1]=(d[g+5|0]|0|j)&65535;b[i+18>>1]=(d[g+6|0]|0|j)&65535;b[i+16>>1]=(d[g+7|0]|0|j)&65535;b[i+14>>1]=(d[g+8|0]|0|j)&65535;b[i+12>>1]=(d[g+9|0]|0|j)&65535;b[i+10>>1]=(d[g+10|0]|0|j)&65535;b[i+8>>1]=(d[g+11|0]|0|j)&65535;b[i+6>>1]=(d[g+12|0]|0|j)&65535;b[i+4>>1]=(d[g+13|0]|0|j)&65535;b[i+2>>1]=(d[g+14|0]|0|j)&65535;b[i>>1]=(d[g+15|0]|0|j)&65535;h=f+1|0;k=g+16|0;if((h|0)<16){i=i+(e<<1)|0;f=h;g=k}else{break}}c[2112928]=k;return}function eXV(a,e,f,g,h,i){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;j=h<<4;h=i+(e<<8)|0;c[2112928]=h;e=(c[2430806]|0)==0?512:1024;i=-e|0;k=a+((ag(e,g+15|0)|0)+f<<1)|0;f=15;g=h;while(1){b[k>>1]=(d[g]|0|j)&65535;b[k+2>>1]=(d[g+1|0]|0|j)&65535;b[k+4>>1]=(d[g+2|0]|0|j)&65535;b[k+6>>1]=(d[g+3|0]|0|j)&65535;b[k+8>>1]=(d[g+4|0]|0|j)&65535;b[k+10>>1]=(d[g+5|0]|0|j)&65535;b[k+12>>1]=(d[g+6|0]|0|j)&65535;b[k+14>>1]=(d[g+7|0]|0|j)&65535;b[k+16>>1]=(d[g+8|0]|0|j)&65535;b[k+18>>1]=(d[g+9|0]|0|j)&65535;b[k+20>>1]=(d[g+10|0]|0|j)&65535;b[k+22>>1]=(d[g+11|0]|0|j)&65535;b[k+24>>1]=(d[g+12|0]|0|j)&65535;b[k+26>>1]=(d[g+13|0]|0|j)&65535;b[k+28>>1]=(d[g+14|0]|0|j)&65535;b[k+30>>1]=(d[g+15|0]|0|j)&65535;l=g+16|0;if((f|0)>0){k=k+(i<<1)|0;f=f-1|0;g=l}else{break}}c[2112928]=l;return}function eXW(a,e,f,g,h,i){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0;j=h<<4;h=i+(e<<8)|0;c[2112928]=h;e=(c[2430806]|0)==0?512:1024;i=a+((ag(e,g)|0)+f<<1)|0;f=0;g=h;while(1){b[i>>1]=(d[g]|0|j)&65535;b[i+2>>1]=(d[g+1|0]|0|j)&65535;b[i+4>>1]=(d[g+2|0]|0|j)&65535;b[i+6>>1]=(d[g+3|0]|0|j)&65535;b[i+8>>1]=(d[g+4|0]|0|j)&65535;b[i+10>>1]=(d[g+5|0]|0|j)&65535;b[i+12>>1]=(d[g+6|0]|0|j)&65535;b[i+14>>1]=(d[g+7|0]|0|j)&65535;b[i+16>>1]=(d[g+8|0]|0|j)&65535;b[i+18>>1]=(d[g+9|0]|0|j)&65535;b[i+20>>1]=(d[g+10|0]|0|j)&65535;b[i+22>>1]=(d[g+11|0]|0|j)&65535;b[i+24>>1]=(d[g+12|0]|0|j)&65535;b[i+26>>1]=(d[g+13|0]|0|j)&65535;b[i+28>>1]=(d[g+14|0]|0|j)&65535;b[i+30>>1]=(d[g+15|0]|0|j)&65535;h=f+1|0;k=g+16|0;if((h|0)<16){i=i+(e<<1)|0;f=h;g=k}else{break}}c[2112928]=k;return}function eXX(d,e,f,g,h,i){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;j=h<<4;h=i+(e<<8)|0;c[2112928]=h;e=(c[2430806]|0)==0?512:1024;i=-e|0;k=d+((ag(e,g+15|0)|0)+f<<1)|0;f=15;g=h;while(1){h=a[g]|0;if(h<<24>>24!=0){b[k+30>>1]=(h&255|j)&65535}h=a[g+1|0]|0;if(h<<24>>24!=0){b[k+28>>1]=(h&255|j)&65535}h=a[g+2|0]|0;if(h<<24>>24!=0){b[k+26>>1]=(h&255|j)&65535}h=a[g+3|0]|0;if(h<<24>>24!=0){b[k+24>>1]=(h&255|j)&65535}h=a[g+4|0]|0;if(h<<24>>24!=0){b[k+22>>1]=(h&255|j)&65535}h=a[g+5|0]|0;if(h<<24>>24!=0){b[k+20>>1]=(h&255|j)&65535}h=a[g+6|0]|0;if(h<<24>>24!=0){b[k+18>>1]=(h&255|j)&65535}h=a[g+7|0]|0;if(h<<24>>24!=0){b[k+16>>1]=(h&255|j)&65535}h=a[g+8|0]|0;if(h<<24>>24!=0){b[k+14>>1]=(h&255|j)&65535}h=a[g+9|0]|0;if(h<<24>>24!=0){b[k+12>>1]=(h&255|j)&65535}h=a[g+10|0]|0;if(h<<24>>24!=0){b[k+10>>1]=(h&255|j)&65535}h=a[g+11|0]|0;if(h<<24>>24!=0){b[k+8>>1]=(h&255|j)&65535}h=a[g+12|0]|0;if(h<<24>>24!=0){b[k+6>>1]=(h&255|j)&65535}h=a[g+13|0]|0;if(h<<24>>24!=0){b[k+4>>1]=(h&255|j)&65535}h=a[g+14|0]|0;if(h<<24>>24!=0){b[k+2>>1]=(h&255|j)&65535}h=a[g+15|0]|0;if(h<<24>>24!=0){b[k>>1]=(h&255|j)&65535}l=g+16|0;if((f|0)>0){k=k+(i<<1)|0;f=f-1|0;g=l}else{break}}c[2112928]=l;return}function eXY(d,e,f,g,h,i){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0;j=h<<4;h=i+(e<<8)|0;c[2112928]=h;e=(c[2430806]|0)==0?512:1024;i=d+((ag(e,g)|0)+f<<1)|0;f=0;g=h;while(1){h=a[g]|0;if(h<<24>>24!=0){b[i+30>>1]=(h&255|j)&65535}h=a[g+1|0]|0;if(h<<24>>24!=0){b[i+28>>1]=(h&255|j)&65535}h=a[g+2|0]|0;if(h<<24>>24!=0){b[i+26>>1]=(h&255|j)&65535}h=a[g+3|0]|0;if(h<<24>>24!=0){b[i+24>>1]=(h&255|j)&65535}h=a[g+4|0]|0;if(h<<24>>24!=0){b[i+22>>1]=(h&255|j)&65535}h=a[g+5|0]|0;if(h<<24>>24!=0){b[i+20>>1]=(h&255|j)&65535}h=a[g+6|0]|0;if(h<<24>>24!=0){b[i+18>>1]=(h&255|j)&65535}h=a[g+7|0]|0;if(h<<24>>24!=0){b[i+16>>1]=(h&255|j)&65535}h=a[g+8|0]|0;if(h<<24>>24!=0){b[i+14>>1]=(h&255|j)&65535}h=a[g+9|0]|0;if(h<<24>>24!=0){b[i+12>>1]=(h&255|j)&65535}h=a[g+10|0]|0;if(h<<24>>24!=0){b[i+10>>1]=(h&255|j)&65535}h=a[g+11|0]|0;if(h<<24>>24!=0){b[i+8>>1]=(h&255|j)&65535}h=a[g+12|0]|0;if(h<<24>>24!=0){b[i+6>>1]=(h&255|j)&65535}h=a[g+13|0]|0;if(h<<24>>24!=0){b[i+4>>1]=(h&255|j)&65535}h=a[g+14|0]|0;if(h<<24>>24!=0){b[i+2>>1]=(h&255|j)&65535}h=a[g+15|0]|0;if(h<<24>>24!=0){b[i>>1]=(h&255|j)&65535}h=f+1|0;k=g+16|0;if((h|0)<16){i=i+(e<<1)|0;f=h;g=k}else{break}}c[2112928]=k;return}function eXZ(d,e,f,g,h,i){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;j=h<<4;h=i+(e<<8)|0;c[2112928]=h;e=(c[2430806]|0)==0?512:1024;i=-e|0;k=d+((ag(e,g+15|0)|0)+f<<1)|0;f=15;g=h;while(1){h=a[g]|0;if(h<<24>>24!=0){b[k>>1]=(h&255|j)&65535}h=a[g+1|0]|0;if(h<<24>>24!=0){b[k+2>>1]=(h&255|j)&65535}h=a[g+2|0]|0;if(h<<24>>24!=0){b[k+4>>1]=(h&255|j)&65535}h=a[g+3|0]|0;if(h<<24>>24!=0){b[k+6>>1]=(h&255|j)&65535}h=a[g+4|0]|0;if(h<<24>>24!=0){b[k+8>>1]=(h&255|j)&65535}h=a[g+5|0]|0;if(h<<24>>24!=0){b[k+10>>1]=(h&255|j)&65535}h=a[g+6|0]|0;if(h<<24>>24!=0){b[k+12>>1]=(h&255|j)&65535}h=a[g+7|0]|0;if(h<<24>>24!=0){b[k+14>>1]=(h&255|j)&65535}h=a[g+8|0]|0;if(h<<24>>24!=0){b[k+16>>1]=(h&255|j)&65535}h=a[g+9|0]|0;if(h<<24>>24!=0){b[k+18>>1]=(h&255|j)&65535}h=a[g+10|0]|0;if(h<<24>>24!=0){b[k+20>>1]=(h&255|j)&65535}h=a[g+11|0]|0;if(h<<24>>24!=0){b[k+22>>1]=(h&255|j)&65535}h=a[g+12|0]|0;if(h<<24>>24!=0){b[k+24>>1]=(h&255|j)&65535}h=a[g+13|0]|0;if(h<<24>>24!=0){b[k+26>>1]=(h&255|j)&65535}h=a[g+14|0]|0;if(h<<24>>24!=0){b[k+28>>1]=(h&255|j)&65535}h=a[g+15|0]|0;if(h<<24>>24!=0){b[k+30>>1]=(h&255|j)&65535}l=g+16|0;if((f|0)>0){k=k+(i<<1)|0;f=f-1|0;g=l}else{break}}c[2112928]=l;return}function eX_(d,e,f,g,h,i){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0;j=h<<4;h=i+(e<<8)|0;c[2112928]=h;e=(c[2430806]|0)==0?512:1024;i=d+((ag(e,g)|0)+f<<1)|0;f=0;g=h;while(1){h=a[g]|0;if(h<<24>>24!=0){b[i>>1]=(h&255|j)&65535}h=a[g+1|0]|0;if(h<<24>>24!=0){b[i+2>>1]=(h&255|j)&65535}h=a[g+2|0]|0;if(h<<24>>24!=0){b[i+4>>1]=(h&255|j)&65535}h=a[g+3|0]|0;if(h<<24>>24!=0){b[i+6>>1]=(h&255|j)&65535}h=a[g+4|0]|0;if(h<<24>>24!=0){b[i+8>>1]=(h&255|j)&65535}h=a[g+5|0]|0;if(h<<24>>24!=0){b[i+10>>1]=(h&255|j)&65535}h=a[g+6|0]|0;if(h<<24>>24!=0){b[i+12>>1]=(h&255|j)&65535}h=a[g+7|0]|0;if(h<<24>>24!=0){b[i+14>>1]=(h&255|j)&65535}h=a[g+8|0]|0;if(h<<24>>24!=0){b[i+16>>1]=(h&255|j)&65535}h=a[g+9|0]|0;if(h<<24>>24!=0){b[i+18>>1]=(h&255|j)&65535}h=a[g+10|0]|0;if(h<<24>>24!=0){b[i+20>>1]=(h&255|j)&65535}h=a[g+11|0]|0;if(h<<24>>24!=0){b[i+22>>1]=(h&255|j)&65535}h=a[g+12|0]|0;if(h<<24>>24!=0){b[i+24>>1]=(h&255|j)&65535}h=a[g+13|0]|0;if(h<<24>>24!=0){b[i+26>>1]=(h&255|j)&65535}h=a[g+14|0]|0;if(h<<24>>24!=0){b[i+28>>1]=(h&255|j)&65535}h=a[g+15|0]|0;if(h<<24>>24!=0){b[i+30>>1]=(h&255|j)&65535}h=f+1|0;k=g+16|0;if((h|0)<16){i=i+(e<<1)|0;f=h;g=k}else{break}}c[2112928]=k;return}function eX$(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;d=e[4878768]<<16;f=d&16711680|e[4878769];g=c[2430058]|0;h=ag(b[4878770]|0,g)|0;i=b[4878771]|0;j=e[4878772]<<16;k=j&16711680|e[4878773];l=ag(b[4878774]|0,g)|0;g=b[4878775]|0;m=c[2433284]|0;n=ag(m,h)|0;o=a[1666928]|0?-16:0;p=((d&8388608|0)==0?f:f|251658240)-n-(ag(o,i)|0)|0;n=ag(m,l)|0;m=((j&8388608|0)==0?k:k|251658240)-((ag(o,g)|0)+n)|0;n=p<<4;o=m<<4;k=h<<4;h=l<<4;l=i<<4;i=g<<4;g=c[3532250]|0;if((k|0)==65536&(h|0)==0&(l|0)==0&(i|0)==65536){j=p>>>12&511;p=m>>>12&511;m=c[2112926]|0;f=c[2438974]|0;d=0;q=0;while(1){r=(d<<3)-p|0;s=(r|0)<-8?r+512|0:r;if((s|0)>-1){r=0;t=q;while(1){u=e[g+(t<<1)>>1]|0;v=u&16383;w=(u>>>14)+(c[3532252]|0)|0;u=(r<<3)-j|0;x=(u|0)<-8?u+512|0:u;do{if((x|0)>-1){if((x|0)>=((c[2113068]|0)-8|0)){y=32639;break}if((s|0)>=((c[2113070]|0)-8|0)){y=32639;break}Sq(m,v,x,s,w,4,0,0,f)}else{y=32639}}while(0);if((y|0)==32639){y=0;Sr(m,v,x,s,w,4,0,0,f)}u=r+1|0;if((u|0)<64){r=u;t=t+1|0}else{break}}}else{t=0;r=q;while(1){u=e[g+(r<<1)>>1]|0;z=(t<<3)-j|0;Sr(m,u&16383,(z|0)<-8?z+512|0:z,s,(u>>>14)+(c[3532252]|0)|0,4,0,0,f);u=t+1|0;if((u|0)<64){t=u;r=r+1|0}else{break}}}r=d+1|0;if((r|0)<64){d=r;q=q+64|0}else{break}}return}q=c[2433518]|0;gGz(q|0,0,524288);d=c[2438974]|0;f=0;m=0;while(1){j=f<<12;y=0;p=m;while(1){r=e[g+(p<<1)>>1]|0;t=(r>>>14)+(c[3532252]|0)<<4;s=q+((y<<3)+j<<1)|0;u=0;z=d+(r<<6&1048512)|0;while(1){r=a[z]|0;if(r<<24>>24!=0){b[s>>1]=(r&255|t)&65535}r=a[z+1|0]|0;if(r<<24>>24!=0){b[s+2>>1]=(r&255|t)&65535}r=a[z+2|0]|0;if(r<<24>>24!=0){b[s+4>>1]=(r&255|t)&65535}r=a[z+3|0]|0;if(r<<24>>24!=0){b[s+6>>1]=(r&255|t)&65535}r=a[z+4|0]|0;if(r<<24>>24!=0){b[s+8>>1]=(r&255|t)&65535}r=a[z+5|0]|0;if(r<<24>>24!=0){b[s+10>>1]=(r&255|t)&65535}r=a[z+6|0]|0;if(r<<24>>24!=0){b[s+12>>1]=(r&255|t)&65535}r=a[z+7|0]|0;if(r<<24>>24!=0){b[s+14>>1]=(r&255|t)&65535}r=u+1|0;A=z+8|0;if((r|0)<8){s=s+1024|0;u=r;z=A}else{break}}z=y+1|0;if((z|0)>=64){break}y=z;p=p+1|0}p=f+1|0;if((p|0)<64){f=p;m=m+64|0}else{break}}c[2112928]=A;A=c[2113070]|0;if((A|0)<=0){return}m=c[2113068]|0;f=c[2112926]|0;d=0;g=o;o=n;while(1){L42848:do{if((m|0)>0){n=o;p=g;y=1;j=f+((ag(d,m)|0)<<1)|0;while(1){z=b[q+((p>>>16<<9&261632|n>>>16&511)<<1)>>1]|0;if(z<<16>>16!=0){b[j>>1]=z}if((y|0)>=(m|0)){break L42848}n=n+k|0;p=p+h|0;y=y+1|0;j=j+2|0}}}while(0);j=d+1|0;if((j|0)<(A|0)){d=j;g=g+i|0;o=o+l|0}else{break}}return}function eX0(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;i=c[14129112+(f<<2)>>2]|0;j=i;k=(c[14129136+(f<<2)>>2]|0)==0;l=k?64:128;m=k?511:1023;n=k?i+49152|0:i+65536|0;i=14129208+f|0;if((a[i]|0)==0){o=9757584+(f<<2)|0}else{k=c[9717408+(f<<2)>>2]|0;p=l<<3;gGz(k|0,0,l<<13|0);q=9733208+(f<<2)|0;r=9757584+(f<<2)|0;s=p-8|0;t=c[9733192+(f<<2)>>2]|0;u=(c[9717864+(f<<2)>>2]|0)==0;v=c[9717880+(f<<2)>>2]|0;w=c[9708304+(f<<2)>>2]|0;x=0;y=0;while(1){z=y<<3;A=504-z|0;B=x;C=0;while(1){D=B<<1;E=e[j+(D<<1)>>1]|0;F=(c[q>>2]<<15)+(e[j+((D|1)<<1)>>1]&t)|0;D=E&255;G=E>>>14&1;H=E>>>15;E=C<<3;if(u){I=E;J=G}else{I=s-E|0;J=G^1}if((c[r>>2]|0)==0){K=I;L=z;M=H;N=J}else{K=s-I|0;L=A;M=H^1;N=J^1}H=(M|0)!=0;do{if((N|0)==0){if(H){eX2(k,F,K,L,D,v,w,p,h);break}G=h+(F<<6)|0;c[2112928]=G;E=D<<v|w;O=k+((ag(L,p)|0)+K<<1)|0;P=0;Q=G;while(1){b[O>>1]=(d[Q]|E)&65535;b[O+2>>1]=(d[Q+1|0]|E)&65535;b[O+4>>1]=(d[Q+2|0]|E)&65535;b[O+6>>1]=(d[Q+3|0]|E)&65535;b[O+8>>1]=(d[Q+4|0]|E)&65535;b[O+10>>1]=(d[Q+5|0]|E)&65535;b[O+12>>1]=(d[Q+6|0]|E)&65535;b[O+14>>1]=(d[Q+7|0]|E)&65535;G=P+1|0;R=Q+8|0;if((G|0)<8){O=O+(p<<1)|0;P=G;Q=R}else{break}}c[2112928]=R}else{if(H){eX1(k,F,K,L,D,v,w,p,h);break}Q=h+(F<<6)|0;c[2112928]=Q;P=D<<v|w;O=k+((ag(L,p)|0)+K<<1)|0;E=0;G=Q;while(1){b[O+14>>1]=(d[G]|P)&65535;b[O+12>>1]=(d[G+1|0]|P)&65535;b[O+10>>1]=(d[G+2|0]|P)&65535;b[O+8>>1]=(d[G+3|0]|P)&65535;b[O+6>>1]=(d[G+4|0]|P)&65535;b[O+4>>1]=(d[G+5|0]|P)&65535;b[O+2>>1]=(d[G+6|0]|P)&65535;b[O>>1]=(d[G+7|0]|P)&65535;Q=E+1|0;S=G+8|0;if((Q|0)<8){O=O+(p<<1)|0;E=Q;G=S}else{break}}c[2112928]=S}}while(0);D=C+1|0;if((D|0)<(l|0)){B=B+1|0;C=D}else{break}}C=y+1|0;if((C|0)<64){x=x+l|0;y=C}else{break}}a[i]=0;o=r}r=(c[9733176+(f<<2)>>2]|0)+16|0;i=c[9718792+(f<<2)>>2]|0;y=c[9733160+(f<<2)>>2]|0;x=(c[9553336+(f<<2)>>2]|0)+y|0;S=c[9718808+(f<<2)>>2]|0;if((S|0)<=0){return}p=c[o>>2]|0;K=9553376+(f<<2)|0;L=l<<3;l=9717408+(f<<2)|0;k=(g|0)==0;g=9717848+(f<<2)|0;w=(c[9717864+(f<<2)>>2]|0)==0;v=c[9720240+(f<<2)>>2]|0;f=(v|0)>0;h=c[2113068]|0;R=c[2112926]|0;N=0;M=(p|0)==0?x:272-x|0;x=p;while(1){p=M&511;J=r+(c[K>>2]|0)-(e[n+((N+y&511)<<1)>>1]|0)&m;if((x|0)==0){T=J}else{T=198-J&m}if(w){U=T}else{U=192-T&m}L42902:do{if(f){J=ag(p,L)|0;I=c[l>>2]|0;if(!k){s=ag(h,N)|0;u=c[g>>2]|0;t=(u|0)==0;j=v+i|0;q=U;C=i;while(1){B=s+C|0;b[R+(B<<1)>>1]=b[I+(q+J<<1)>>1]|0;if(!t){a[u+B|0]=1}B=C+1|0;if((B|0)>=(j|0)){break L42902}q=q+1&m;C=B}}C=v+i|0;q=ag(h,N)|0;j=U;u=i;while(1){t=b[I+(j+J<<1)>>1]|0;do{if((t&15)!=0){s=q+u|0;b[R+(s<<1)>>1]=t;B=c[g>>2]|0;if((B|0)==0){break}a[B+s|0]=1}}while(0);t=u+1|0;if((t|0)>=(C|0)){break L42902}j=j+1&m;u=t}}}while(0);u=N+1|0;if((u|0)>=(S|0)){break}N=u;M=p+1|0;x=c[o>>2]|0}return}function eX1(a,e,f,g,h,i,j,k,l){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0;m=l+(e<<6)|0;c[2112928]=m;e=h<<i|j;j=-k|0;i=a+((ag(g+7|0,k)|0)+f<<1)|0;f=7;k=m;while(1){b[i+14>>1]=(d[k]|0|e)&65535;b[i+12>>1]=(d[k+1|0]|0|e)&65535;b[i+10>>1]=(d[k+2|0]|0|e)&65535;b[i+8>>1]=(d[k+3|0]|0|e)&65535;b[i+6>>1]=(d[k+4|0]|0|e)&65535;b[i+4>>1]=(d[k+5|0]|0|e)&65535;b[i+2>>1]=(d[k+6|0]|0|e)&65535;b[i>>1]=(d[k+7|0]|0|e)&65535;n=k+8|0;if((f|0)>0){i=i+(j<<1)|0;f=f-1|0;k=n}else{break}}c[2112928]=n;return}function eX2(a,e,f,g,h,i,j,k,l){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0;m=l+(e<<6)|0;c[2112928]=m;e=h<<i|j;j=-k|0;i=a+((ag(g+7|0,k)|0)+f<<1)|0;f=7;k=m;while(1){b[i>>1]=(d[k]|0|e)&65535;b[i+2>>1]=(d[k+1|0]|0|e)&65535;b[i+4>>1]=(d[k+2|0]|0|e)&65535;b[i+6>>1]=(d[k+3|0]|0|e)&65535;b[i+8>>1]=(d[k+4|0]|0|e)&65535;b[i+10>>1]=(d[k+5|0]|0|e)&65535;b[i+12>>1]=(d[k+6|0]|0|e)&65535;b[i+14>>1]=(d[k+7|0]|0|e)&65535;n=k+8|0;if((f|0)>0){i=i+(j<<1)|0;f=f-1|0;k=n}else{break}}c[2112928]=n;return}function eX3(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;i=c[14129112+(f<<2)>>2]|0;j=i+32768|0;if((c[14129136+(f<<2)>>2]|0)==0){k=511;l=64;m=i+57344|0;n=i+50176|0}else{k=1023;l=128;m=i+67584|0;n=i+66560|0}i=m;m=n;n=14129128+f|0;if((a[n]|0)==0){o=9757584+(f<<2)|0}else{p=c[9717392+(f<<2)>>2]|0;q=l<<3;gGz(p|0,0,l<<13|0);r=9733208+(f<<2)|0;s=9757584+(f<<2)|0;t=q-8|0;u=c[9733192+(f<<2)>>2]|0;v=(c[9717864+(f<<2)>>2]|0)==0;w=c[9717880+(f<<2)>>2]|0;x=c[9708304+(f<<2)>>2]|0;y=0;z=0;while(1){A=z<<3;B=504-A|0;C=y;D=0;while(1){E=C<<1;F=e[j+(E<<1)>>1]|0;G=(c[r>>2]<<15)+(e[j+((E|1)<<1)>>1]&u)|0;E=F&255;H=F>>>14&1;I=F>>>15;F=D<<3;if(v){J=F;K=H}else{J=t-F|0;K=H^1}if((c[s>>2]|0)==0){L=J;M=A;N=I;O=K}else{L=t-J|0;M=B;N=I^1;O=K^1}I=(N|0)!=0;do{if((O|0)==0){if(I){eX2(p,G,L,M,E,w,x,q,h);break}H=h+(G<<6)|0;c[2112928]=H;F=E<<w|x;P=p+((ag(M,q)|0)+L<<1)|0;Q=0;R=H;while(1){b[P>>1]=(d[R]|F)&65535;b[P+2>>1]=(d[R+1|0]|F)&65535;b[P+4>>1]=(d[R+2|0]|F)&65535;b[P+6>>1]=(d[R+3|0]|F)&65535;b[P+8>>1]=(d[R+4|0]|F)&65535;b[P+10>>1]=(d[R+5|0]|F)&65535;b[P+12>>1]=(d[R+6|0]|F)&65535;b[P+14>>1]=(d[R+7|0]|F)&65535;H=Q+1|0;S=R+8|0;if((H|0)<8){P=P+(q<<1)|0;Q=H;R=S}else{break}}c[2112928]=S}else{if(I){eX1(p,G,L,M,E,w,x,q,h);break}R=h+(G<<6)|0;c[2112928]=R;Q=E<<w|x;P=p+((ag(M,q)|0)+L<<1)|0;F=0;H=R;while(1){b[P+14>>1]=(d[H]|Q)&65535;b[P+12>>1]=(d[H+1|0]|Q)&65535;b[P+10>>1]=(d[H+2|0]|Q)&65535;b[P+8>>1]=(d[H+3|0]|Q)&65535;b[P+6>>1]=(d[H+4|0]|Q)&65535;b[P+4>>1]=(d[H+5|0]|Q)&65535;b[P+2>>1]=(d[H+6|0]|Q)&65535;b[P>>1]=(d[H+7|0]|Q)&65535;R=F+1|0;T=H+8|0;if((R|0)<8){P=P+(q<<1)|0;F=R;H=T}else{break}}c[2112928]=T}}while(0);E=D+1|0;if((E|0)<(l|0)){C=C+1|0;D=E}else{break}}D=z+1|0;if((D|0)<64){y=y+l|0;z=D}else{break}}a[n]=0;o=s}s=(c[9733176+(f<<2)>>2]|0)+16|0;n=c[9718792+(f<<2)>>2]|0;z=c[9733160+(f<<2)>>2]|0;y=(c[9543280+(f<<2)>>2]|0)+z|0;T=c[o>>2]|0;q=c[9718808+(f<<2)>>2]|0;if((q|0)<=0){return}L=9543304+(f<<2)|0;M=l<<3;l=9717392+(f<<2)|0;p=(g|0)==0;g=9717848+(f<<2)|0;x=(c[9717864+(f<<2)>>2]|0)==0;w=c[9720240+(f<<2)>>2]|0;f=(w|0)>0;h=c[2113068]|0;S=c[2112926]|0;O=0;N=(T|0)==0?y:272-y|0;y=T;while(1){T=N&511;K=s+(c[L>>2]|0)-(e[m+((O+z&511)<<1)>>1]|0)&k;if((y|0)==0){U=K}else{U=198-K&k}if(x){V=U}else{V=192-U&k}L42978:do{if(f){K=c[l>>2]|0;if(!p){J=ag(h,O)|0;t=c[g>>2]|0;v=(t|0)==0;u=w+n|0;j=V;r=n;while(1){D=J+r|0;b[S+(D<<1)>>1]=b[K+((ag(N-(e[i+((j>>>3&127)<<1)>>1]|0)&511,M)|0)+j<<1)>>1]|0;if(!v){a[t+D|0]=2}D=r+1|0;if((D|0)>=(u|0)){break L42978}j=j+1&k;r=D}}r=w+n|0;j=ag(h,O)|0;u=V;t=n;while(1){v=b[K+((ag(N-(e[i+((u>>>3&127)<<1)>>1]|0)&511,M)|0)+u<<1)>>1]|0;do{if((v&15)!=0){J=j+t|0;b[S+(J<<1)>>1]=v;D=c[g>>2]|0;if((D|0)==0){break}a[D+J|0]=2}}while(0);v=t+1|0;if((v|0)>=(r|0)){break L42978}u=u+1&k;t=v}}}while(0);t=O+1|0;if((t|0)>=(q|0)){break}O=t;N=T+1|0;y=c[o>>2]|0}return}function eX4(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0;g=c[14129112+(f<<2)>>2]|0;h=14129136+(f<<2)|0;if((c[h>>2]|0)==0){i=64;j=64;k=g+24576|0;l=g+16384|0}else{i=32;j=128;k=g+69632|0;l=g+73728|0}g=l;l=14129200+f|0;m=9753632+(f<<2)|0;if((a[l]|0)!=0){n=c[m>>2]|0;o=0;do{p=o<<6;gGz(n+p|0,0,64);q=o<<7;r=q|8;s=0;while(1){t=r+(c[6669224+(s<<2)>>2]|0)|0;u=(s<<3)+p|0;v=0;do{w=t+(c[614800+(v<<2)>>2]|0)|0;if((d[k+((w|0)/8|0)|0]&128>>>((w&7)>>>0)|0)!=0){w=n+(u+v)|0;a[w]=a[w]|2}v=v+1|0;}while((v|0)<8);v=s+1|0;if((v|0)<8){s=v}else{x=0;break}}do{s=q+(c[6669224+(x<<2)>>2]|0)|0;r=(x<<3)+p|0;v=0;do{u=s+(c[614800+(v<<2)>>2]|0)|0;if((d[k+((u|0)/8|0)|0]&128>>>((u&7)>>>0)|0)!=0){u=n+(r+v)|0;a[u]=a[u]|1}v=v+1|0;}while((v|0)<8);x=x+1|0;}while((x|0)<8);o=o+1|0;}while((o|0)<256);a[l]=0}l=9757584+(f<<2)|0;o=9733176+(f<<2)|0;x=9733160+(f<<2)|0;n=14109976+(f<<2)|0;k=14110008+(f<<2)|0;p=9718792+(f<<2)|0;q=9718808+(f<<2)|0;v=9720240+(f<<2)|0;r=9708304+(f<<2)|0;s=9717848+(f<<2)|0;u=c[9717864+(f<<2)>>2]|0;f=(u|0)==0;t=c[2112926]|0;w=c[2113068]|0;y=0;z=0;while(1){A=z<<3;B=8-A|0;C=y;D=0;while(1){E=e[g+(C<<1)>>1]|0;F=E>>>6;G=E>>>14&1;H=E>>>15;I=D<<3;J=I-16|0;K=c[l>>2]|0;L=c[o>>2]|0;do{if((K|0)==0){if(f){M=J-L|0;N=A-(c[x>>2]|0)|0;O=H;P=G;Q=0;R=0;S=1;T=0;break}else{M=16-I-L+(c[v>>2]|0)|0;N=A-(c[x>>2]|0)|0;O=H;P=G^1;Q=0;R=0;S=0;T=u;break}}else{U=L+J|0;if(f){V=1;W=0;X=G;Y=U;Z=c[v>>2]|0}else{_=c[v>>2]|0;V=0;W=u;X=G^1;Y=_-U|0;Z=_}M=Z-Y|0;N=B+(c[x>>2]|0)+(c[q>>2]|0)|0;O=H^1;P=X^1;Q=1;R=K;S=V;T=W}}while(0);K=Q|S^1;do{if((c[h>>2]|0)==0){if(K){$=M;aa=T}else{$=M-(c[k>>2]&511)|0;aa=0}do{if((aa|R|0)==0){H=($|0)<-8?$+512|0:$;ab=(H|0)>511?H-512|0:H;ac=32807}else{H=(c[k>>2]&511)+$|0;G=(H|0)<-8?H+512|0:H;H=(G|0)>511?G-512|0:G;if((R|0)==0){ab=H;ac=32807;break}ad=(c[n>>2]&511)+N|0;ae=H}}while(0);if((ac|0)==32807){ac=0;ad=N-(c[n>>2]&511)|0;ae=ab}H=(ad|0)<-8?ad+512|0:ad;if((H|0)<=511){af=ae;ah=H;break}af=ae;ah=H-512|0}else{if(K){ai=M;aj=T}else{ai=M-(c[k>>2]&1023)|0;aj=0}do{if((aj|R|0)==0){H=(ai|0)<-8?ai+1024|0:ai;ak=(H|0)>1023?H-1024|0:H;ac=32816}else{H=(c[k>>2]&1023)+ai|0;G=(H|0)<-8?H+1024|0:H;H=(G|0)>1023?G-1024|0:G;if((R|0)==0){ak=H;ac=32816;break}al=(c[n>>2]&255)+N|0;am=H}}while(0);if((ac|0)==32816){ac=0;al=N-(c[n>>2]&255)|0;am=ak}H=(al|0)<-8?al+256|0:al;if((H|0)<=255){af=am;ah=H;break}af=am;ah=H-256|0}}while(0);K=F<<2&1008;H=E<<6&16320;G=(P|0)!=0;J=(O|0)!=0;L=G&J;I=0;do{_=(7-I<<3)+H|0;U=I+ah|0;an=(U|0)>-1;ao=(I<<3)+H|0;ap=c[m>>2]|0;aq=ag(w,U)|0;if(J){ar=0;do{as=a[ap+(_+(L?7-ar|0:ar))|0]|0;do{if(as<<24>>24!=0){at=ar+af|0;au=c[p>>2]|0;av=au+at|0;if(!an){break}if(!((U|0)<(c[q>>2]|0)&(at|0)>-1)){break}if((av|0)>=((c[v>>2]|0)+au|0)){break}au=aq+av|0;b[t+(au<<1)>>1]=(as&255|K|c[r>>2])&65535;av=c[s>>2]|0;if((av|0)==0){break}a[av+au|0]=4}}while(0);ar=ar+1|0;}while((ar|0)<8)}else{ar=0;do{_=a[ap+(ao+(G?7-ar|0:ar))|0]|0;do{if(_<<24>>24!=0){as=ar+af|0;au=c[p>>2]|0;av=au+as|0;if(!an){break}if(!((U|0)<(c[q>>2]|0)&(as|0)>-1)){break}if((av|0)>=((c[v>>2]|0)+au|0)){break}au=aq+av|0;b[t+(au<<1)>>1]=(_&255|K|c[r>>2])&65535;av=c[s>>2]|0;if((av|0)==0){break}a[av+au|0]=4}}while(0);ar=ar+1|0;}while((ar|0)<8)}I=I+1|0;}while((I|0)<8);I=D+1|0;if((I|0)>=(j|0)){break}C=C+1|0;D=I}D=z+1|0;if((D|0)<(i|0)){y=y+j|0;z=D}else{break}}return}function eX5(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;i=0;while(1){if((i|0)>=1024){j=0;break}k=9638528+(i<<2)|0;if((c[k>>2]|0)==0){l=32850;break}else{i=i+1|0}}do{if((l|0)==32850){i=gGq(81920)|0;c[k>>2]=i;if((i|0)==0){j=0;break}gGz(i|0,0,81920);j=i}}while(0);c[14129112+(b<<2)>>2]=j;gGz(j|0,0,81920);j=0;while(1){if((j|0)>=1024){m=0;break}n=9638528+(j<<2)|0;if((c[n>>2]|0)==0){l=32855;break}else{j=j+1|0}}do{if((l|0)==32855){j=gGq(16384)|0;c[n>>2]=j;if((j|0)==0){m=0;break}gGz(j|0,0,16384);m=j}}while(0);c[9753632+(b<<2)>>2]=m;gGz(m|0,0,16384);m=0;while(1){if((m|0)>=1024){o=0;break}p=9638528+(m<<2)|0;if((c[p>>2]|0)==0){l=32860;break}else{m=m+1|0}}do{if((l|0)==32860){m=gGq(1048576)|0;c[p>>2]=m;if((m|0)==0){o=0;break}gGz(m|0,0,1048576);o=m}}while(0);c[9717408+(b<<2)>>2]=o;gGz(o|0,0,1048576);o=0;while(1){if((o|0)>=1024){q=0;break}r=9638528+(o<<2)|0;if((c[r>>2]|0)==0){l=32865;break}else{o=o+1|0}}do{if((l|0)==32865){o=gGq(1048576)|0;c[r>>2]=o;if((o|0)==0){q=0;break}gGz(o|0,0,1048576);q=o}}while(0);c[9717392+(b<<2)>>2]=q;gGz(q|0,0,1048576);c[9733176+(b<<2)>>2]=e;c[9733160+(b<<2)>>2]=f;c[9717864+(b<<2)>>2]=g;c[9717848+(b<<2)>>2]=h;c[9717880+(b<<2)>>2]=4;c[9733192+(b<<2)>>2]=d-1;c[14129136+(b<<2)>>2]=0;c[9720240+(b<<2)>>2]=c[2113068];c[9718808+(b<<2)>>2]=c[2113070];c[9718792+(b<<2)>>2]=0;c[9708304+(b<<2)>>2]=0;a[14129128+b|0]=1;a[14129208+b|0]=1;a[14129200+b|0]=1;a[7461096]=1;c[2442930]=(c[2442930]|0)+1;return}function eX6(b){b=b|0;var e=0,f=0;if((b&8|0)!=0){c[2438236]=b;c[2384382]=b;return}if((b|0)==0|(c[2384382]|0)==(b|0)){if((d[9776584]|0)<9){a[9731616]=15}c[2438236]=0;c[2384382]=b;return}do{if((b&1|0)!=0){e=(a[14114256]|0)+1&255;a[14114256]=e;f=a[9776600]|0;if((e&255)<(f&255)){break}a[14114256]=e-f&255;f=(a[9776584]|0)+(a[9776601]|0)&255;a[9776584]=f;if((f&255)>8){a[9776584]=9;a[9731616]=12;break}else{a[9731616]=15;break}}}while(0);do{if((b&2|0)!=0){f=(a[14114248]|0)+1&255;a[14114248]=f;e=a[9776602]|0;if((f&255)<(e&255)){break}a[14114248]=f-e&255;e=(a[9776584]|0)+(a[9776603]|0)&255;a[9776584]=e;if((e&255)>8){a[9776584]=9;a[9731616]=12;break}else{a[9731616]=15;break}}}while(0);if((b&4|0)!=0){a[9776584]=(a[9776584]|0)+1&255}c[2438236]=b;c[2384382]=b;return}function eX7(b){b=b|0;var c=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=a[7461104]|0;L43153:do{if(c){e=b-9437184|0;if(e>>>0>=2048){f=32906;break}g=e>>>1;h=a[14128321]|0;i=a[14128322]|0;j=a[14109952]|0;do{if(j<<24>>24==0){k=a[14128320]|0;if((g|0)==1){l=h;break L43153}else if((g|0)==2){l=i;break L43153}else if((g|0)==3){l=a[9771792]|0;break L43153}else if((g|0)==0){l=k;break L43153}else{break}}else{if(j<<24>>24==1&e>>>0<512){if(e>>>0>=80){l=0;break L43153}l=a[5661104+g|0]|0;break L43153}if(j<<24>>24!=2){break}if((g|0)==2){l=75;break L43153}else if((g|0)==1){l=87;break L43153}else if((g|0)==0){l=71;break L43153}else{break}}}while(0);l=0}else{f=32906}}while(0);L43172:do{if((f|0)==32906){if((b|0)==5242881){l=a[14128480]&15;break}else if((b|0)==8388611){g=a[9540896]|0;switch(g&255|0){case 3:{a[9540898]=a[9540898]&-9;a[9540896]=g+1&255;l=a[9540895]|0;break L43172;break};case 1:{a[9540898]=a[9540898]&-5;a[9540896]=g+1&255;l=a[9540893]|0;break L43172;break};case 4:{l=a[9540898]|0;break L43172;break};case 2:{a[9540896]=g+1&255;l=a[9540894]|0;break L43172;break};case 0:{a[9540896]=g+1&255;l=a[9540892]|0;break L43172;break};default:{l=0;break L43172}}}else if((b|0)==5242885){l=a[14128481]&15;break}else if((b|0)==9437185){l=a[14128320]|0;break}else if((b|0)==5242887){l=(d[14128481]|0)>>>4;break}else if((b|0)==9439235){return c&1|0}else if((b|0)==5242883){l=(d[14128480]|0)>>>4;break}else if((b|0)==9437187){l=a[14128321]|0;break}else if((b|0)==9437189){l=a[14128322]|0;break}else{l=0;break}}}while(0);return l|0}function eX8(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;e=a[7461104]|0;do{if(e){f=b-9437184|0;if(f>>>0>=2048){break}if(!((a[14109952]|0)==0&(f&-2|0)==6)){return}a[9771792]=d;return}}while(0);if((b|0)==9440257){if(!e){return}a[14109952]=d&7;return}else if((b|0)==8388609){a[9540896]=d&15;return}else if((b|0)==8388611){b=d&15;d=a[9540896]|0;switch(d&255|0){case 1:{a[9540896]=d+1&255;a[9540889]=b;a[9540898]=a[9540898]|1;a[9540900]=1;return};case 0:{a[9540896]=d+1&255;a[9540888]=b;return};case 3:{a[9540896]=d+1&255;a[9540891]=b;a[9540898]=a[9540898]|2;a[9540900]=1;return};case 2:{a[9540896]=d+1&255;a[9540890]=b;return};case 4:{if(b<<24>>24==0){return}b=c[2439330]|0;d=(b|0)==0;if(!d){e=b;gGC(9706056,e|0,76)|0}e=c[2438118]|0;c[2433530]=e;f=c[3528484]|0;c[2076596]=f;g=c[2417276]|0;c[3541536]=g;c[1836236]=0;gGz(9706056,0,76);if(!d){d=b;gGC(d|0,9706056,76)|0}c[2438118]=e;c[3528484]=f;c[2417276]=g;c[1836236]=-1;return};default:{return}}}else{return}}function eX9(b){b=b|0;var c=0;if((b|0)==5242880){c=a[14128480]&15}else if((b|0)==5242884){c=a[14128481]&15}else if((b|0)==5242882){c=(d[14128480]|0)>>>4&255}else if((b|0)==5242886){c=(d[14128481]|0)>>>4&255}else{c=0}return c|0}function eYa(b){b=b|0;var d=0,e=0,f=0,g=0,i=0,j=0,k=0.0,l=0.0,m=0,n=0;d=b&65535;if((d|0)==57345){b=a[(c[3541514]|0)+560|0]|0;do{if((b&255)<16){e=c[2383582]|0;f=c[14168912+(e*252|0)>>2]|0;if((f|0)>15){g=0;break}do{if((f|0)==14){i=c[14168896+(e*252|0)>>2]|0;if((i|0)==0){break}a[14168930+(e*252|0)|0]=gj[i&4095](0)|0}else if((f|0)==15){i=c[14168900+(e*252|0)>>2]|0;if((i|0)==0){break}a[14168931+(e*252|0)|0]=gj[i&4095](0)|0}}while(0);g=a[14168916+(e*252|0)+f|0]|0}else{g=0}}while(0);j=b<<24>>24==-1?1:g;return j|0}else if((d|0)==57857){j=fdZ()|0;return j|0}else if((d|0)==57346){j=a[(c[3541514]|0)+20904|0]|0;return j|0}else if((d|0)==57344){d=c[3541514]|0;g=d+552|0;k=+h[g>>3];do{if(k!=0.0){l=+h[6675];if(k-(l+ +gC[c[2429842]&255]())>0.0){m=a[d+563|0]|-128;break}else{h[g>>3]=0.0;n=32966;break}}else{n=32966}}while(0);if((n|0)==32966){m=a[d+563|0]|0}j=m&-125;return j|0}else{j=0;return j|0}return 0}function eYb(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;switch(b&65535|0){case 57346:{b=c[3541514]|0;a[b+560|0]=d;a[b+20408|0]=1;return};case 57856:{a[9540897]=d&15;return};case 57857:{fd_(d);return};case 57347:{l7(3,d);return};case 57344:{b=c[3541514]|0;a[b+560|0]=d;a[b+20408|0]=0;if((d&255)>=16){return}c[14168912+((c[2383582]|0)*252|0)>>2]=d&15;return};case 57345:{l7(1,d);return};case 61952:{b=d+3&3;a[14127752]=b;d=c[3531932]|0;e=(b&255)<<14;b=c[9757320+(c[1836236]<<2)>>2]|0;f=64;g=64;while(1){c[b+76+(g<<2)>>2]=d+((g<<8)+e);h=f+1&65535;if((h&65535)>127){i=64;j=64;break}else{f=h;g=h&65535}}while(1){g=d+((j<<8)+e)|0;c[b+76+(j+512<<2)>>2]=g;c[b+76+(j+768<<2)>>2]=g;g=i+1&65535;if((g&65535)>127){break}else{i=g;j=g&65535}}return};default:{return}}}function eYc(a){a=a|0;var b=0,d=0;b=a&65535;if((b|0)==57857){d=fdZ()|0}else if((b|0)==57345){d=c[(c[3531464]|0)+4240>>2]&255}else{d=0}return d|0}function eYd(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;switch(b&65535|0){case 61952:{b=d+3&3;a[14127752]=b;e=c[3531932]|0;f=(b&255)<<14;b=c[9757320+(c[1836236]<<2)>>2]|0;g=64;h=64;while(1){c[b+76+(h<<2)>>2]=e+((h<<8)+f);i=g+1&65535;if((i&65535)>127){j=64;k=64;break}else{g=i;h=i&65535}}while(1){h=e+((k<<8)+f)|0;c[b+76+(k+512<<2)>>2]=h;c[b+76+(k+768<<2)>>2]=h;h=j+1&65535;if((h&65535)>127){break}else{j=h;k=h&65535}}return};case 57857:{fd_(d);return};case 57344:{c[2113304]=d&255;return};case 57856:{a[9540897]=d&15;return};case 57345:{k=c[2113304]|0;a[14168504+k|0]=d;mv(0,k,d&255);return};default:{return}}}function eYe(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4251716+(b*112|0)>>2];c[a+104>>2]=c[4251720+(b*112|0)>>2];c[a+108>>2]=c[4251724+(b*112|0)>>2];d=0;return d|0}function eYf(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=4251616+(b*112|0);e=0;return e|0}function eYg(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1177464+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eYh(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>34){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4252624+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eYi(){c[3532002]=256;c[3532e3]=4;a[7460944]=1;c[3532004]=16;c[3531998]=727216;c[3531992]=2010240;c[3531990]=2010176;c[3532034]=4096;return eYS(2)|0}function eYj(){e_a()|0;return 0}function eYk(){var d=0,e=0,f=0,g=0,h=0;if((a[14128072]|0)!=0){eZ8()|0}a[14128322]=-1;a[14128321]=-1;a[14128320]=-1;d=0;e=-1;f=-1;g=-1;do{e=(e&255)-((a[14128312+d|0]&1)<<d)&255;f=(f&255)-((a[14128304+d|0]&1)<<d)&255;g=(g&255)-((a[14128296+d|0]&1)<<d)&255;d=d+1|0;}while((d|0)<8);a[14128320]=e;a[14128321]=f;a[14128322]=g;c[2113031]=0;c[2113030]=0;g=c[2392]|0;if((g|0)>=0){gGz(8452240,0,((g|0)>0?(g<<2)+4|0:4)|0)}c[2113054]=0;g=c[2385548]|0;if((g|0)>0){gGz(9752472,0,((g|0)>1?g<<2:4)|0)}c[2433530]=0;g=0;while(1){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060]}f=g+1|0;e=(ag(c[2113026]|0,f)|0)/10|0;d=e-(c[2113030]|0)|0;c[2113028]=d;c[2113056]=d;e=RG(d)|0;c[2113054]=(c[2113054]|0)+e;c[2276108]=-1;c[2113056]=-1;c[2113030]=(c[2113030]|0)+e;do{if((g|0)==9){e=c[3532064]|0;c[8452200+(c[2394]<<2)>>2]=e|8192;d=c[2276080]|0;h=e<<8;c[2276080]=h;if((d|0)!=1792&(h|0)==1792){RH(7);break}if(h>>>0<=(c[2276079]|0)>>>0){break}RH(e&16777215)}}while(0);e=c[2394]|0;h=c[14130368+(e<<2)>>2]|0;if((h|0)!=0){gGC(h|0,9104152,280)|0}c[8452240+(e<<2)>>2]=c[2113054];c[2394]=-1;e=c[2439330]|0;if((e|0)!=0){h=e;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;Sb(ag((c[2113024]|0)/10|0,g)|0);h=c[1836236]|0;e=c[9757320+(h<<2)>>2]|0;if((e|0)!=0){d=e;gGC(d|0,9706056,76)|0}c[9752472+(h<<2)>>2]=c[2433530];c[14113936+(h<<2)>>2]=c[2076596];c[9669104+(h<<2)>>2]=c[3541536];c[1836236]=-1;if((f|0)<10){g=f}else{break}}g=c[2439330]|0;if((g|0)!=0){h=g;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;h=c[2113024]|0;g=gGU(h,(h|0)<0|0?-1:0,2048e6,0)|0;d=c[2438228]|0;e=gGS(g,K,d,(d|0)<0|0?-1:0)|0;d=e;Sb(h);h=c[2443830]|0;if((h|0)<1073676288){c[2443830]=h-d}h=c[2443831]|0;if((h|0)<1073676288){c[2443831]=h-d}h=(c[3528512]|0)-d|0;c[3528512]=(h|0)<0?0:h;h=c[2112964]|0;if((h|0)!=0){gg[c[3542118]&4095](h,a[9688]|0?534:0)}h=c[1836236]|0;d=c[9757320+(h<<2)>>2]|0;if((d|0)!=0){e=d;gGC(e|0,9706056,76)|0}c[9752472+(h<<2)>>2]=c[2433530];c[14113936+(h<<2)>>2]=c[2076596];c[9669104+(h<<2)>>2]=c[3541536];c[1836236]=-1;if((c[2112968]|0)==0){return 0}eYR();return 0}function eYl(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;g=i;i=i+176|0;h=g|0;j=g+16|0;k=g+32|0;l=g+48|0;m=g+64|0;n=g+80|0;o=g+96|0;p=g+112|0;q=g+128|0;r=g+144|0;s=g+160|0;if((f|0)!=0){c[f>>2]=169603}if((e&32|0)!=0){gGz(s|0,0,12);t=c[3532020]|0;c[s>>2]=t;c[s+4>>2]=(c[3532022]|0)-t;c[s+12>>2]=162152;t=c[2076592]|0;gj[t&4095](s)|0}eZ7(e);if((e&64|0)!=0){s=m|0;gGz(l|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){t=m+9|0;m=k;u=k|0;v=k+4|0;w=k+12|0;x=l|0;y=l+4|0;z=l+12|0;A=0;do{gGC(s|0,614896,11)|0;a[t]=A+48&255;B=8452256+(A<<2)|0;gGz(m|0,0,12);c[u>>2]=B;c[v>>2]=4;c[w>>2]=164976;gj[c[2076592]&4095](k)|0;if((c[B>>2]|0)!=0){c[x>>2]=c[14130368+(A<<2)>>2];c[y>>2]=c[8452184+(A<<2)>>2];c[z>>2]=s;B=c[2076592]|0;gj[B&4095](l)|0}A=A+1|0;}while((A|0)<=(c[2392]|0))}fw$(e);if(a[7460960]|0){T0(e,f)}do{if(a[7460968]|0){gGz(j|0,0,12);c[j>>2]=8453216;c[j+4>>2]=4;c[j+12>>2]=107480;f=c[2076592]|0;gj[f&4095](j)|0;gGz(h|0,0,12);c[h>>2]=14168504;c[h+4>>2]=256;c[h+12>>2]=476464;f=c[2076592]|0;gj[f&4095](h)|0;if((e&2|0)==0){break}else{C=0}do{mv(0,C,d[14168504+C|0]|0);C=C+1|0;}while((C|0)<256)}}while(0);gGz(r|0,0,12);c[r>>2]=14128320;c[r+4>>2]=6;c[r+12>>2]=273024;C=c[2076592]|0;gj[C&4095](r)|0;gGz(q|0,0,12);c[q>>2]=14127752;c[q+4>>2]=1;c[q+12>>2]=272344;r=c[2076592]|0;gj[r&4095](q)|0;gGz(p|0,0,12);c[p>>2]=14128024;c[p+4>>2]=1;c[p+12>>2]=451536;q=c[2076592]|0;gj[q&4095](p)|0;gGz(o|0,0,12);c[o>>2]=8452120;c[o+4>>2]=16;c[o+12>>2]=270496;p=c[2076592]|0;gj[p&4095](o)|0;gGz(n|0,0,12);c[n>>2]=8452112;c[n+4>>2]=4;c[n+12>>2]=269664;o=c[2076592]|0;gj[o&4095](n)|0}if((e&2|0)==0){i=g;return 0}e=c[2439330]|0;n=(e|0)==0;if(!n){o=e;gGC(9706056,o|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];o=c[3528484]|0;c[2076596]=o;p=c[2417276]|0;c[3541536]=p;c[1836236]=0;q=c[3531932]|0;r=(d[14127752]|0)<<14;C=64;h=64;while(1){c[e+76+(h<<2)>>2]=q+((h<<8)+r);j=C+1&65535;if((j&65535)>127){D=64;E=64;break}else{C=j;h=j&65535}}while(1){h=q+((E<<8)+r)|0;c[e+76+(E+512<<2)>>2]=h;c[e+76+(E+768<<2)>>2]=h;h=D+1&65535;if((h&65535)>127){break}else{D=h;E=h&65535}}if(!n){n=e;gGC(n|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=o;c[2417276]=p;c[1836236]=-1;i=g;return 0}function eYm(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3908716+(b*112|0)>>2];c[a+104>>2]=c[3908720+(b*112|0)>>2];c[a+108>>2]=c[3908724+(b*112|0)>>2];d=0;return d|0}function eYn(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=3908616+(b*112|0);e=0;return e|0}function eYo(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>42){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3909848+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eYp(){c[3532002]=512;c[3532e3]=4;a[7460944]=1;c[3532004]=16;c[3531998]=961408;c[3531992]=4969560;c[3531990]=4969112;c[3532034]=16384;return eYS(2)|0}function eYq(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1890508+(b*112|0)>>2];c[a+104>>2]=c[1890512+(b*112|0)>>2];c[a+108>>2]=c[1890516+(b*112|0)>>2];d=0;return d|0}function eYr(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=1890408+(b*112|0);e=0;return e|0}function eYs(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3811012+(b*112|0)>>2];c[a+104>>2]=c[3811016+(b*112|0)>>2];c[a+108>>2]=c[3811020+(b*112|0)>>2];d=0;return d|0}function eYt(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=3810912+(b*112|0);e=0;return e|0}function eYu(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>42){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3811920+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eYv(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3337660+(b*112|0)>>2];c[a+104>>2]=c[3337664+(b*112|0)>>2];c[a+108>>2]=c[3337668+(b*112|0)>>2];d=0;return d|0}function eYw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=3337560+(b*112|0);e=0;return e|0}function eYx(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1185736+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eYy(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>30){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3338792+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eYz(){var b=0;a[14109952]=0;a[9771792]=0;a[7461104]=1;c[3532002]=512;c[3532e3]=4;a[7460944]=1;c[3532004]=16;c[3531998]=961408;c[3531992]=4969560;c[3531990]=4969112;c[3532034]=16384;b=eYS(0)|0;c[3532064]=6;return b|0}function eYA(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1667108+(b*112|0)>>2];c[a+104>>2]=c[1667112+(b*112|0)>>2];c[a+108>>2]=c[1667116+(b*112|0)>>2];d=0;return d|0}function eYB(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=1667008+(b*112|0);e=0;return e|0}function eYC(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>30){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1668240+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eYD(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1668716+(b*112|0)>>2];c[a+104>>2]=c[1668720+(b*112|0)>>2];c[a+108>>2]=c[1668724+(b*112|0)>>2];d=0;return d|0}function eYE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=1668616+(b*112|0);e=0;return e|0}function eYF(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>30){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1669848+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eYG(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3275780+(b*112|0)>>2];c[a+104>>2]=c[3275784+(b*112|0)>>2];c[a+108>>2]=c[3275788+(b*112|0)>>2];d=0;return d|0}function eYH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=3275680+(b*112|0);e=0;return e|0}function eYI(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>38){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3276464+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eYJ(){c[3532002]=512;c[3532e3]=4;a[7460944]=1;c[3532004]=16;c[3531998]=961408;c[3531992]=4969560;c[3531990]=4969112;c[3532034]=16384;return eYS(1)|0}function eYK(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;if((a[14128072]|0)!=0){eZ8()|0}a[14128322]=-1;a[14128321]=-1;a[14128320]=-1;d=0;e=-1;f=-1;g=-1;do{e=(e&255)-((a[14128312+d|0]&1)<<d)&255;f=(f&255)-((a[14128304+d|0]&1)<<d)&255;g=(g&255)-((a[14128296+d|0]&1)<<d)&255;d=d+1|0;}while((d|0)<8);a[14128320]=e;a[14128321]=f;a[14128322]=g;c[2113031]=0;c[2113030]=0;g=c[2392]|0;if((g|0)>=0){gGz(8452240,0,((g|0)>0?(g<<2)+4|0:4)|0)}c[2113054]=0;g=c[2385548]|0;if((g|0)>0){gGz(9752472,0,((g|0)>1?g<<2:4)|0)}c[2433530]=0;g=0;f=0;L43605:while(1){e=f;while(1){if((e|0)>=10){break L43605}if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}h=e+1|0;d=(ag(c[2113026]|0,h)|0)/10|0;i=d-(c[2113030]|0)|0;c[2113028]=i;c[2113056]=i;d=RG(i)|0;c[2113054]=(c[2113054]|0)+d;c[2276108]=-1;c[2113056]=-1;c[2113030]=(c[2113030]|0)+d;do{if((e|0)==9){c[8452200+(c[2394]<<2)>>2]=8194;c[2276080]=512;if((c[2276079]|0)>>>0>=512){break}RH(2)}}while(0);d=c[2394]|0;i=c[14130368+(d<<2)>>2]|0;if((i|0)!=0){gGC(i|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;d=c[2439330]|0;if((d|0)!=0){i=d;gGC(9706056,i|0,76)|0}b[4853030]=c[2426515]&65535;i=c[2438118]|0;c[2433530]=i;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;j=(ag(c[2113024]|0,h)|0)/10|0;k=c[2113031]|0;l=j-k|0;c[2113028]=l;do{if((l|0)<1){m=0;n=k;o=0;p=d;q=i}else{if((a[d+4188|0]|0)==0){j=gfc(l)|0;r=(c[2433530]|0)+j|0;c[2433530]=r;s=c[1836236]|0;m=j;n=c[2113031]|0;o=s;p=c[9757320+(s<<2)>>2]|0;q=r;break}else{r=i+l|0;c[2433530]=r;m=l;n=k;o=0;p=d;q=r;break}}}while(0);c[2113028]=m;c[2113031]=n+m;if((p|0)!=0){d=p;gGC(d|0,9706056,76)|0}c[9752472+(o<<2)>>2]=q;c[14113936+(o<<2)>>2]=c[2076596];c[9669104+(o<<2)>>2]=c[3541536];c[1836236]=-1;t=c[2112964]|0;if((t|0)==0){e=h}else{break}}e=a[9688]|0?53:0;d=c[2439330]|0;if((d|0)!=0){k=d;gGC(9706056,k|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;gg[c[3542124]&4095](t+(g<<1<<1)|0,e);k=c[1836236]|0;d=c[9757320+(k<<2)>>2]|0;if((d|0)!=0){l=d;gGC(l|0,9706056,76)|0}c[9752472+(k<<2)>>2]=c[2433530];c[14113936+(k<<2)>>2]=c[2076596];c[9669104+(k<<2)>>2]=c[3541536];c[1836236]=-1;g=e+g|0;f=h}h=c[2112964]|0;do{if((h|0)!=0){f=a[9688]|0?534:0;if((f|0)==(g|0)){break}t=c[2439330]|0;if((t|0)!=0){o=t;gGC(9706056,o|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;gg[c[3542124]&4095](h+(g<<1<<1)|0,f-g|0);f=c[1836236]|0;o=c[9757320+(f<<2)>>2]|0;if((o|0)!=0){t=o;gGC(t|0,9706056,76)|0}c[9752472+(f<<2)>>2]=c[2433530];c[14113936+(f<<2)>>2]=c[2076596];c[9669104+(f<<2)>>2]=c[3541536];c[1836236]=-1}}while(0);if((c[2112968]|0)==0){return 0}eYR();return 0}function eYL(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1651228+(b*112|0)>>2];c[a+104>>2]=c[1651232+(b*112|0)>>2];c[a+108>>2]=c[1651236+(b*112|0)>>2];d=0;return d|0}function eYM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=1651128+(b*112|0);e=0;return e|0}function eYN(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>38){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1651912+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eYO(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4109700+(b*112|0)>>2];c[a+104>>2]=c[4109704+(b*112|0)>>2];c[a+108>>2]=c[4109708+(b*112|0)>>2];d=0;return d|0}function eYP(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=4109600+(b*112|0);e=0;return e|0}function eYQ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>41){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4110384+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eYR(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;a=c[3532028]|0;d=0;f=c[3532026]|0;g=a;while(1){h=b[f>>1]|0;c[g>>2]=((h&65535)>>>10<<3&248)<<8|((h&255)<<3&255)>>>3|(((h&65535)>>>7&4|(h&65535)>>>5<<3&255)&255)<<3&2016;h=d+1|0;if((h|0)<2048){d=h;f=f+2|0;g=g+4|0}else{break}}g=c[2113070]|0;f=c[2113068]|0;d=ag(f,g)|0;if((d|0)>0){h=c[2112926]|0;i=0;do{b[h+(i<<1)>>1]=496;i=i+1|0;}while((i|0)<(d|0))}d=c[3531970]|0;i=d;h=c[3531968]|0;j=d+1536|0;k=b[j>>1]|0;l=k&65535;m=d+1538|0;n=b[m>>1]|0;o=n&65535;p=l&64;q=o&15;r=(o^64^o<<1)<<6&4096;o=(e[d+1542>>1]|0)<<8&65280|b[d+1540>>1]&255;d=l&15;if((d|0)==1){s=4}else if((d|0)==6){s=8}else{s=0}d=(p|0)==0;l=(q|0)==1?16:q;if((l|0)==0){t=k;u=n}else{n=r|1024;k=r|1536;r=-(p>>>5)|1;p=(c[3532034]|0)+65535|0;q=-8-(c[3531940]|0)|0;v=c[2112926]|0;w=c[3531962]|0;x=0;do{y=x<<5;z=b[i+((((y|8)+1024|0)/2|0)<<1)>>1]&255;A=x+s<<5&480;B=r-(b[i+(((y+1024|0)/2|0)<<1)>>1]&255)|0;y=(1<<x&o|0)==0;if(d){C=B+8|0;D=0;do{E=D+A|0;F=e[h+(E+n<<1)>>1]|0;G=F&32768;H=F&16384;I=(D<<4&16)+z|0;J=(e[h+(E+k<<1)>>1]|0)>>>11;E=p&F;F=((y?I:I+256|0)+16&511)-16|0;I=q+(C+(((D|0)/2|0)<<4)&255)|0;do{if((F|0)>16){if(!((F|0)<(f-16|0)&(I|0)>16)){K=33357;break}if((I|0)>=(g-16|0)){K=33357;break}L=(H|0)!=0;if((G|0)==0){if(L){SK(v,E,F,I,J,4,0,0,w);break}else{SG(v,E,F,I,J,4,0,0,w);break}}else{if(L){SM(v,E,F,I,J,4,0,0,w);break}else{SI(v,E,F,I,J,4,0,0,w);break}}}else{K=33357}}while(0);do{if((K|0)==33357){K=0;L=(H|0)!=0;if((G|0)==0){if(L){SL(v,E,F,I,J,4,0,0,w);break}else{SH(v,E,F,I,J,4,0,0,w);break}}else{if(L){SN(v,E,F,I,J,4,0,0,w);break}else{SJ(v,E,F,I,J,4,0,0,w);break}}}}while(0);D=D+1|0;}while((D|0)<32)}else{D=248-B|0;C=0;do{J=C+A|0;I=e[h+(J+n<<1)>>1]|0;F=(C<<4&16)+z|0;E=I>>>15;G=I>>>14&1;H=(e[h+(J+k<<1)>>1]|0)>>>11;J=p&I;I=((y?F:F+256|0)+16&511)-16|0;F=q+(D+(((C|0)/2|0)*-16|0)&255)|0;do{if((I|0)>16){if(!((I|0)<(f-16|0)&(F|0)>16)){K=33382;break}if((F|0)>=(g-16|0)){K=33382;break}L=(G|0)==0;if((E|0)==1){if(L){SK(v,J,I,F,H,4,0,0,w);break}else{SG(v,J,I,F,H,4,0,0,w);break}}else{if(L){SM(v,J,I,F,H,4,0,0,w);break}else{SI(v,J,I,F,H,4,0,0,w);break}}}else{K=33382}}while(0);do{if((K|0)==33382){K=0;L=(G|0)==0;if((E|0)==1){if(L){SL(v,J,I,F,H,4,0,0,w);break}else{SH(v,J,I,F,H,4,0,0,w);break}}else{if(L){SN(v,J,I,F,H,4,0,0,w);break}else{SJ(v,J,I,F,H,4,0,0,w);break}}}}while(0);C=C+1|0;}while((C|0)<32)}x=x+1|0;}while((x|0)<(l|0));t=b[j>>1]|0;u=b[m>>1]|0}m=u&65535;u=(m^64^m<<1)<<6&4096;m=u|512;j=(t&64)==0;t=(c[3532034]|0)+65535|0;l=-6-(c[3531940]|0)|0;x=c[2112926]|0;w=c[3531962]|0;v=511;while(1){q=e[h+(v+u<<1)>>1]|0;p=e[h+(v+m<<1)>>1]|0;k=b[i+(v<<1)>>1]&255;n=q&16384;d=p>>>11;o=t&q;if(j){M=k;N=q&32768;O=n}else{M=240-k|0;N=q>>>15^1;O=n>>>14^1}n=(p+16&511)-16|0;p=l+(248-M&255)|0;do{if((n|0)>16){if(!((n|0)<(f-16|0)&(p|0)>16)){K=33405;break}if((p|0)>=(g-16|0)){K=33405;break}q=(O|0)!=0;if((N|0)==0){if(q){SK(x,o,n,p,d,4,0,0,w);break}else{SG(x,o,n,p,d,4,0,0,w);break}}else{if(q){SM(x,o,n,p,d,4,0,0,w);break}else{SI(x,o,n,p,d,4,0,0,w);break}}}else{K=33405}}while(0);do{if((K|0)==33405){K=0;q=(O|0)!=0;if((N|0)==0){if(q){SL(x,o,n,p,d,4,0,0,w);break}else{SH(x,o,n,p,d,4,0,0,w);break}}else{if(q){SN(x,o,n,p,d,4,0,0,w);break}else{SJ(x,o,n,p,d,4,0,0,w);break}}}}while(0);if((v|0)>0){v=v-1|0}else{break}}R8(a);return}function eYS(d){d=d|0;var e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;c[3532044]=1;c[3532030]=1;e=(d|0)==1;if(e){a[7460968]=1}else{a[7460960]=1}eZ9(0)|0;c[3532048]=0;c[3532204]=0;f=c[3532200]|0;c[3531932]=f;g=(c[3531928]|0)+f|0;c[3531952]=g;f=g+(c[3531948]|0)|0;c[3531946]=f;g=f+(c[3531942]|0)|0;f=g|0;c[3532020]=f;c[3532208]=f;c[3531936]=g+16384;c[3532026]=g+24576;c[3531970]=g+28672;c[3531968]=g+30720;f=g+47104|0;g=f|0;c[3532022]=g;c[3531962]=g;g=ag(a[7460944]|0?16:0,c[3532034]|0)|0;i=(ag(g,c[3532004]|0)|0)+f|0;c[3532028]=i;f=i+8192|0;c[3532046]=f;i=f;f=0;while(1){if((f|0)>=1024){break}j=9638528+(f<<2)|0;if((c[j>>2]|0)==0){k=33420;break}else{f=f+1|0}}do{if((k|0)==33420){f=gGq(i)|0;c[j>>2]=f;if((f|0)==0){break}gGz(f|0,0,i|0);c[3532048]=f;gGz(f|0,0,i|0);c[3532204]=f;g=c[3532200]|0;c[3531932]=f+g;l=(c[3531928]|0)+g|0;c[3531952]=f+l;g=l+(c[3531948]|0)|0;c[3531946]=f+g;l=g+(c[3531942]|0)|0;g=f+l|0;c[3532020]=g;c[3532208]=g;c[3531936]=f+(l+16384);c[3532026]=f+(l+24576);c[3531970]=f+(l+28672);c[3531968]=f+(l+30720);g=l+47104|0;l=f+g|0;c[3532022]=l;c[3531962]=l;l=ag(a[7460944]|0?16:0,c[3532034]|0)|0;m=(ag(l,c[3532004]|0)|0)+g|0;c[3532028]=f+m;c[3532046]=f+(m+8192);if((eZ9(1)|0)!=0){n=1;return n|0}a[7461080]=1;fxU(0,425984);if((c[2394]|0)==0){o=c[2112932]|0}else{c[2394]=0;m=c[3532596]|0;c[2112932]=m;f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];o=m}m=c[3532204]|0;f=(c[3532200]|0)-1|0;g=o|0;l=0;while(1){p=m+l|0;c[g>>2]=p;c[g+131072>>2]=p;p=l+1024|0;if(p>>>0>f>>>0){break}else{g=g+4|0;l=p}}l=c[3532026]|0;c[o+45056>>2]=l;c[o+110592>>2]=l;c[o+176128>>2]=l;g=l+1024|0;c[o+45060>>2]=g;c[o+110596>>2]=g;c[o+176132>>2]=g;g=l+2048|0;c[o+45064>>2]=g;c[o+110600>>2]=g;c[o+176136>>2]=g;g=l+3072|0;c[o+45068>>2]=g;c[o+110604>>2]=g;c[o+176140>>2]=g;g=c[3531970]|0;c[o+53248>>2]=g;c[o+118784>>2]=g;c[o+184320>>2]=g;l=g+1024|0;c[o+53252>>2]=l;c[o+118788>>2]=l;c[o+184324>>2]=l;l=c[3531968]|0;c[o+57344>>2]=l;c[o+122880>>2]=l;c[o+188416>>2]=l;g=l+1024|0;c[o+57348>>2]=g;c[o+122884>>2]=g;c[o+188420>>2]=g;g=l+2048|0;c[o+57352>>2]=g;c[o+122888>>2]=g;c[o+188424>>2]=g;g=l+3072|0;c[o+57356>>2]=g;c[o+122892>>2]=g;c[o+188428>>2]=g;g=l+4096|0;c[o+57360>>2]=g;c[o+122896>>2]=g;c[o+188432>>2]=g;g=l+5120|0;c[o+57364>>2]=g;c[o+122900>>2]=g;c[o+188436>>2]=g;g=l+6144|0;c[o+57368>>2]=g;c[o+122904>>2]=g;c[o+188440>>2]=g;g=l+7168|0;c[o+57372>>2]=g;c[o+122908>>2]=g;c[o+188444>>2]=g;g=l+8192|0;c[o+57376>>2]=g;c[o+122912>>2]=g;c[o+188448>>2]=g;g=l+9216|0;c[o+57380>>2]=g;c[o+122916>>2]=g;c[o+188452>>2]=g;g=l+10240|0;c[o+57384>>2]=g;c[o+122920>>2]=g;c[o+188456>>2]=g;g=l+11264|0;c[o+57388>>2]=g;c[o+122924>>2]=g;c[o+188460>>2]=g;g=l+12288|0;c[o+57392>>2]=g;c[o+122928>>2]=g;c[o+188464>>2]=g;g=l+13312|0;c[o+57396>>2]=g;c[o+122932>>2]=g;c[o+188468>>2]=g;g=l+14336|0;c[o+57400>>2]=g;c[o+122936>>2]=g;c[o+188472>>2]=g;g=l+15360|0;c[o+57404>>2]=g;c[o+122940>>2]=g;c[o+188476>>2]=g;g=c[3532208]|0;c[o+61440>>2]=g;c[o+126976>>2]=g;c[o+192512>>2]=g;l=g+1024|0;c[o+61444>>2]=l;c[o+126980>>2]=l;c[o+192516>>2]=l;l=g+2048|0;c[o+61448>>2]=l;c[o+126984>>2]=l;c[o+192520>>2]=l;l=g+3072|0;c[o+61452>>2]=l;c[o+126988>>2]=l;c[o+192524>>2]=l;l=g+4096|0;c[o+61456>>2]=l;c[o+126992>>2]=l;c[o+192528>>2]=l;l=g+5120|0;c[o+61460>>2]=l;c[o+126996>>2]=l;c[o+192532>>2]=l;l=g+6144|0;c[o+61464>>2]=l;c[o+127e3>>2]=l;c[o+192536>>2]=l;l=g+7168|0;c[o+61468>>2]=l;c[o+127004>>2]=l;c[o+192540>>2]=l;l=g+8192|0;c[o+61472>>2]=l;c[o+127008>>2]=l;c[o+192544>>2]=l;l=g+9216|0;c[o+61476>>2]=l;c[o+127012>>2]=l;c[o+192548>>2]=l;l=g+10240|0;c[o+61480>>2]=l;c[o+127016>>2]=l;c[o+192552>>2]=l;l=g+11264|0;c[o+61484>>2]=l;c[o+127020>>2]=l;c[o+192556>>2]=l;l=g+12288|0;c[o+61488>>2]=l;c[o+127024>>2]=l;c[o+192560>>2]=l;l=g+13312|0;c[o+61492>>2]=l;c[o+127028>>2]=l;c[o+192564>>2]=l;l=g+14336|0;c[o+61496>>2]=l;c[o+127032>>2]=l;c[o+192568>>2]=l;l=g+15360|0;c[o+61500>>2]=l;c[o+127036>>2]=l;c[o+192572>>2]=l;c[o+196608>>2]=572;c[o+196648>>2]=500;c[o+196688>>2]=3314;l=c[3532592]|0;if((l|0)!=0){gGC(l|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);l=c[2439330]|0;g=(l|0)==0;if(!g){f=l;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];f=c[3528484]|0;c[2076596]=f;m=c[2417276]|0;c[3541536]=m;c[1836236]=0;p=l+4180|0;if(e){c[p>>2]=2178;c[l+4184>>2]=634}else{c[p>>2]=756;c[l+4184>>2]=3096}p=c[3531932]|0;q=0;r=0;while(1){c[l+76+(r<<2)>>2]=p+(r<<8);s=q+1&65535;if((s&65535)>63){t=0;u=0;break}else{q=s;r=s&65535}}while(1){r=p+(u<<8)|0;c[l+76+(u+512<<2)>>2]=r;c[l+76+(u+768<<2)>>2]=r;r=t+1&65535;if((r&65535)>63){v=64;w=64;break}else{t=r;u=r&65535}}while(1){c[l+76+(w<<2)>>2]=p+(w<<8);r=v+1&65535;if((r&65535)>127){x=64;y=64;break}else{v=r;w=r&65535}}while(1){r=p+(y<<8)|0;c[l+76+(y+512<<2)>>2]=r;c[l+76+(y+768<<2)>>2]=r;r=x+1&65535;if((r&65535)>127){break}else{x=r;y=r&65535}}p=c[3531936]|0;r=192;q=192;while(1){c[l+76+(q<<2)>>2]=p+((q<<8)-49152);s=r+1&65535;if((s&65535)>223){z=192;A=192;break}else{r=s;q=s&65535}}while(1){c[l+76+(A+256<<2)>>2]=p+((A<<8)-49152);q=z+1&65535;if((q&65535)>223){B=192;C=192;break}else{z=q;A=q&65535}}while(1){q=p+((C<<8)-49152)|0;c[l+76+(C+512<<2)>>2]=q;c[l+76+(C+768<<2)>>2]=q;q=B+1&65535;if((q&65535)>223){break}else{B=q;C=q&65535}}if(!g){p=l;gGC(p|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=f;c[2417276]=m;c[1836236]=-1;if(e){p=a[9680]|0;q=p?32e3:0;if(p){if(a[9624]|0){p=q*3|0;r=62500;while(1){if((r|0)>(p|0)){r=r>>1}else{D=1222;E=r;break}}}else{D=2462;E=q}c[2429380]=E;c[3542124]=D;mw(4e6,E);r=gGq(262144)|0;c[2406684]=r;gGz(r|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(4e6,11025)}c[(c[3531464]|0)+44344>>2]=688;h[745421]=.45;c[2436794]=1;h[745420]=.45;c[2436792]=2}else{r=c[3531946]|0;p=c[3531952]|0;if((d|0)==2){TW(r,14127768,p,14127792,0,3132,52)}else{TW(r,14127768,p,14127792,1800,3132,52)}c[2438228]=4e6;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=511;h[745406]=1.0;c[2436786]=1;h[745405]=1.0;c[2436784]=2;h[745404]=.25;a[3203280]=1}p=c[642608+(c[2436]<<2)>>2]|0;r=c[p+128>>2]|0;if((c[p+52>>2]&4|0)==0){c[2113068]=r;m=c[p+132>>2]|0;c[2113070]=m;c[2443814]=r;c[2440436]=m;F=r;G=m}else{c[2113070]=r;m=c[p+132>>2]|0;c[2113068]=m;c[2440436]=r;c[2443814]=m;F=m;G=r}r=ag(F<<1,G)|0;m=gGq(r)|0;c[2112926]=m;if((m|0)!=0){gGz(m|0,0,r|0)}c[2113026]=133333;c[2113024]=66666;r=c[2113070]|0;if((r|0)==224){c[3531940]=16}else if((r|0)==240){c[3531940]=8}c[3532064]=2;eZ8()|0;n=0;return n|0}}while(0);c[3532048]=0;n=1;return n|0}function eYT(b){b=b|0;a[9706117]=(b|0)!=0|0;return}function eYU(a){a=a|0;var b=0,d=0;b=(c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,4e6,0)|0;return a|0}function eYV(){return+(+((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)/4.0e6)}function eYW(b,c){b=b|0;c=c|0;a[9706117]=c&1;return}function eYX(a){a=a|0;var b=0;if(a<<16>>16!=-1536){b=0;return b|0}b=c[2438752]&255;return b|0}function eYY(e,f){e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=e&65535;if((g|0)==64e3){c[2439538]=f&255;c[2430226]=1;return}else if((g|0)==64003){if(f<<24>>24==0){a[9730848]=1;return}e=c[1836236]|0;h=c[9757320+(e<<2)>>2]|0;if((h|0)!=0){i=h;gGC(i|0,9706056,76)|0}c[9752472+(e<<2)>>2]=c[2433530];c[14113936+(e<<2)>>2]=c[2076596];c[9669104+(e<<2)>>2]=c[3541536];c[1836236]=-1;e=c[2439332]|0;i=(e|0)==0;if(!i){h=e;gGC(9706056,h|0,76)|0}h=c[2438120]|0;c[2433530]=h;j=c[3528486]|0;c[2076596]=j;k=c[2417278]|0;c[3541536]=k;c[1836236]=2;gGz(9706056,0,76);if(!i){i=e;gGC(i|0,9706056,76)|0}c[2438120]=h;c[3528486]=j;c[2417278]=k;c[1836236]=-1;k=c[2439330]|0;if((k|0)!=0){j=k;gGC(9706056,j|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;a[9730848]=0;return}else if((g|0)==64320){g=f&7^4;a[14119312]=g;j=c[3529120]|0;k=c[1836236]|0;h=c[9757320+(k<<2)>>2]|0;i=((g&255)<<14)+32768|0;g=128;e=128;while(1){c[h+76+(e<<2)>>2]=j+(i+(e<<8));l=g+1&65535;if((l&65535)>191){break}else{g=l;e=l&65535}}e=f&255;g=128;l=128;while(1){m=j+(i+(l<<8))|0;c[h+76+(l+512<<2)>>2]=m;c[h+76+(l+768<<2)>>2]=m;m=g+1&65535;if((m&65535)>191){break}else{g=m;l=m&65535}}if((e&16|0)==0){if((h|0)!=0){l=h;gGC(l|0,9706056,76)|0}c[9752472+(k<<2)>>2]=c[2433530];c[14113936+(k<<2)>>2]=c[2076596];c[9669104+(k<<2)>>2]=c[3541536];c[1836236]=-1;k=c[2439331]|0;l=(k|0)==0;if(!l){h=k;gGC(9706056,h|0,76)|0}h=c[2438119]|0;c[2433530]=h;g=c[3528485]|0;c[2076596]=g;i=c[2417277]|0;c[3541536]=i;c[1836236]=1;gGz(9706056,0,76);if(!l){l=k;gGC(l|0,9706056,76)|0}c[2438119]=h;c[3528485]=g;c[2417277]=i;c[1836236]=-1;i=c[2439330]|0;if((i|0)!=0){g=i;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;n=0}else{n=1}a[9730856]=n;do{if((e&32|0)==0){if((a[14109496]|0)==2){f42();a[8451544]=0;a[8451536]=0;a[9533800]=0;a[8451528]=0;a[8451520]=0;a[9533792]=0;a[8451512]=0;a[8451504]=0;a[9533784]=0;a[9533352]=0;a[9533344]=0;c[2161338]=0;c[2161344]=0;o=0;break}a[9660900]=a[9660900]|16;n=c[2437644]|0;g=c[n+1092>>2]|0;do{if((g|0)==0){i=c[n+3144>>2]|0;if((i|0)==0){p=0;q=0;break}h=gj[i&4095](-2)|0;i=c[2437644]|0;l=c[i+1092>>2]|0;k=(h&255)<<8;if((l|0)!=0){r=l;s=k;t=33516;break}l=c[i+3144>>2]|0;if((l|0)==0){p=0;q=k;break}p=gj[l&4095](-1)|0;q=k}else{r=g;s=d[g+254|0]<<8;t=33516}}while(0);if((t|0)==33516){p=a[r+255|0]|0;q=s}g=p&255|q;c[2415221]=g;b[4830442]=g&65535;a[9660920]=0;a[9660921]=0;a[9660928]=0;a[9660930]=0;a[9660931]=0;c[2415234]=0;gGz(9660901,0,5);c[2415235]=65535;c[2415237]=65535;a[9660932]=a[9660932]|64;o=0}else{o=1}}while(0);a[9774056]=o;a[9754904]=f&64;a[9759704]=f&-128;return}else{return}}function eYZ(b){b=b|0;var d=0;switch(b&65535|0){case 65024:{d=c[2418504]<<4&255;break};case 65282:{d=a[9625336]|0;break};case 65283:{d=a[9625288]|0;break};case 65153:case 65154:case 65155:{d=-1;break};case 65025:case 65026:case 65027:{d=(cT()|0)&255;break};case 65152:{d=c[2418502]<<4&255;break};case 65280:{d=a[9657904]|0;break};case 65281:{d=a[9657905]|0;break};default:{d=0}}return d|0}function eY_(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=d&65535;switch(f|0){case 64e3:{c[2439538]=e&255;c[2430226]=1;return};case 65025:{d=c[2418504]|0;g=d&8;h=g>>>3^d>>>1&1;i=(g|0)==0?h|2:h;h=(d&1|0)==0?i|4:i;j=(d&4|0)==0?h^8:h;break};case 65026:{h=c[2418504]|0;d=h&4;i=d>>>2^1;g=(h&8|0)==0?i|2:i;i=(h&2|0)==0?g|4:g;g=(h&1|0)==0?i^8:i;j=(d|0)==0?g^8:g;break};case 64003:{if(e<<24>>24==0){a[9730848]=1;return}g=c[1836236]|0;d=c[9757320+(g<<2)>>2]|0;if((d|0)!=0){i=d;gGC(i|0,9706056,76)|0}c[9752472+(g<<2)>>2]=c[2433530];c[14113936+(g<<2)>>2]=c[2076596];c[9669104+(g<<2)>>2]=c[3541536];c[1836236]=-1;g=c[2439332]|0;i=(g|0)==0;if(!i){d=g;gGC(9706056,d|0,76)|0}d=c[2438120]|0;c[2433530]=d;h=c[3528486]|0;c[2076596]=h;k=c[2417278]|0;c[3541536]=k;c[1836236]=2;gGz(9706056,0,76);if(!i){i=g;gGC(i|0,9706056,76)|0}c[2438120]=d;c[3528486]=h;c[2417278]=k;c[1836236]=-1;k=c[2439330]|0;if((k|0)!=0){h=k;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;a[9730848]=0;return};case 65024:{h=c[2418504]|0;k=h>>>3&1^1;d=(h&1|0)==0;i=d?(d?k|2:k)|4:k;k=(h&2|0)==0?i^4:i;j=(h&4|0)==0?k^8:k;break};case 64320:{k=e&7^4;a[14119312]=k;h=c[3529120]|0;i=c[1836236]|0;d=c[9757320+(i<<2)>>2]|0;g=((k&255)<<14)+32768|0;k=128;l=128;while(1){c[d+76+(l<<2)>>2]=h+(g+(l<<8));m=k+1&65535;if((m&65535)>191){n=128;o=128;break}else{k=m;l=m&65535}}while(1){l=h+(g+(o<<8))|0;c[d+76+(o+512<<2)>>2]=l;c[d+76+(o+768<<2)>>2]=l;l=n+1&65535;if((l&65535)>191){break}else{n=l;o=l&65535}}if((e&16)==0){if((d|0)!=0){o=d;gGC(o|0,9706056,76)|0}c[9752472+(i<<2)>>2]=c[2433530];c[14113936+(i<<2)>>2]=c[2076596];c[9669104+(i<<2)>>2]=c[3541536];c[1836236]=-1;i=c[2439331]|0;o=(i|0)==0;if(!o){d=i;gGC(9706056,d|0,76)|0}d=c[2438119]|0;c[2433530]=d;n=c[3528485]|0;c[2076596]=n;g=c[2417277]|0;c[3541536]=g;c[1836236]=1;gGz(9706056,0,76);if(!o){o=i;gGC(o|0,9706056,76)|0}c[2438119]=d;c[3528485]=n;c[2417277]=g;c[1836236]=-1;g=c[2439330]|0;if((g|0)!=0){n=g;gGC(9706056,n|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;p=0}else{p=1}a[9730856]=p;a[9754904]=e&64;a[9759704]=e&-128;return};case 65155:case 65154:case 65153:case 65152:{c[2418502]=c[619248+(f-65152<<2)>>2]^(e&255)>>>4;return};case 65027:{e=c[2418504]|0;f=e>>>1&1^1;p=(e&4|0)==0?f|2:f;f=(e&8|0)==0;n=f?(f?p^2:p)^4:p;j=(e&1|0)==0?n^8:n;break};default:{return}}c[2418504]=j;return}function eY$(b){b=b|0;var e=0,f=0,g=0,i=0.0,j=0.0,k=0,l=0;e=b&65535;if((e|0)==45056){f=c[2439538]&255;return f|0}else if((e|0)==36864){b=c[3541518]|0;g=b+296|0;i=+h[g>>3];do{if(i!=0.0){j=+h[6675];if(i-(j+ +gC[c[2429842]&255]())<=0.0){h[g>>3]=0.0;break}f=a[b+307|0]|-128;return f|0}}while(0);f=a[b+307|0]|0;return f|0}else if((e|0)==36865){if((d[(c[3541518]|0)+304|0]|0)>=16){f=0;return f|0}b=c[2383582]|0;g=c[14168912+(b*252|0)>>2]|0;if((g|0)>15){f=0;return f|0}do{if((g|0)==14){k=c[14168896+(b*252|0)>>2]|0;if((k|0)==0){break}a[14168930+(b*252|0)|0]=gj[k&4095](0)|0}else if((g|0)==15){k=c[14168900+(b*252|0)>>2]|0;if((k|0)==0){break}a[14168931+(b*252|0)|0]=gj[k&4095](0)|0}}while(0);f=a[14168916+(b*252|0)+g|0]|0;return f|0}else if((e|0)==40960){e=c[3540986]|0;g=(d[e+5887|0]|0|128)&(d[e+5886|0]|0);if((a[e+5884|0]&2)==0){l=g&255}else{l=(a[(c[e+5828>>2]|0)+100|0]&1|g)&255}f=l|6;return f|0}else{f=0;return f|0}return 0}function eY0(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=b&65535;if((f|0)==36865){lS(0,1,e);return}else if((f|0)==45056){c[2438752]=e&255;return}else if((f|0)==36864){b=c[3541518]|0;g=b+256|0;a[b+304|0]=e;h=e&255;if((e&255)<16){c[14168912+((c[2383582]|0)*252|0)>>2]=h&15}if((e-45&255)>=3){return}if((h|0)==0){a[b+312|0]=2;i=2}else if((h|0)==46){j=b+312|0;k=a[j]|1;a[j]=k;i=k}else if((h|0)==47){a[b+312|0]=0;i=0}else if((h|0)==45){h=b+312|0;k=a[h]|2;a[h]=k;i=k}else{i=a[b+312|0]|0}b=i&3;i=c[7461744+(b<<2)>>2]|0;lI(g,i,i,c[7461728+(b<<2)>>2]|0);return}else if((f|0)==45058){c[2432710]=0;return}else if((f|0)==45057){c[2432710]=1;if((c[2430226]|0)==0){return}if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12;c[2430226]=0;return}else if((f|0)==40960){a[(c[3540986]|0)+5885|0]=e;return}else if((f|0)==40961){f=c[3540986]|0;b=c[f+5876>>2]|0;if((b|0)!=0){gg[b&4095](c[f+5880>>2]|0,0)}lH(f,d[f+5885|0]|0,e&255);return}else{return}}function eY1(b){b=b|0;var d=0,e=0;d=b&65535;if((b-64&65535)<192){e=a[(c[2387312]|0)+(d-64)|0]|0;return e|0}switch(d|0){case 2:{d=a[9625336]|0;a[9578848]=d;b=a[9681576]|0;e=b&a[9541296]|d&~b;return e|0};case 1:{e=a[9681568]|0;return e|0};case 5:{e=a[9681552]|0;return e|0};case 3:{b=a[9681568]|0;e=a[9578840]&~b|b&a[9541288];return e|0};case 4:{e=a[9681560]|0;return e|0};case 0:{e=a[9681576]|0;return e|0};case 7:{b=a[9681552]|0;e=a[9578824]&~b|b&a[9541272];return e|0};case 6:{b=a[9681560]|0;e=a[9578832]&~b|b&a[9541280];return e|0};default:{e=0;return e|0}}return 0}function eY2(e,f){e=e|0;f=f|0;var g=0,h=0;g=e&65535;if((e-64&65535)<192){a[(c[2387312]|0)+(g-64)|0]=f;return}if((e-8&65535)<24){f4S(e,f);return}switch(g|0){case 2:{do{if((a[9541296]&64)!=0){if((f&64)!=0){break}g=c[2439330]|0;if((g|0)!=0){e=g;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;a[14125144]=a[c[3529150]|0]|0;a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0;e=c[1836236]|0;g=c[9757320+(e<<2)>>2]|0;if((g|0)!=0){h=g;gGC(h|0,9706056,76)|0}c[9752472+(e<<2)>>2]=c[2433530];c[14113936+(e<<2)>>2]=c[2076596];c[9669104+(e<<2)>>2]=c[3541536];c[1836236]=-1}}while(0);a[9541296]=f;return};case 0:{a[9681576]=f;return};case 1:{a[9681568]=f;return};case 6:{a[9541280]=f;return};case 7:{a[9541272]=f;return};case 4:{a[9681560]=f;return};case 5:{a[9681552]=f;return};case 3:{do{if((a[9541288]&16)==0){e=f&255;if((e&16|0)==0){break}h=d[9541272]|e<<8&3840;if((a[9541296]|0)>=0){if(h>>>0<=3071){break}a[(c[3529150]|0)+(h-3072)|0]=a[9541280]|0;break}if((h|0)==3){a[9578832]=a[9625248]|0;break}else if((h|0)==0){a[9578832]=a[9657904]|0;break}else if((h|0)==1){a[9578832]=a[9657905]|0;break}else if((h|0)==2){a[9578832]=a[9625288]|0;break}else{if(h>>>0<=3071){break}a[9578832]=a[(c[3529150]|0)+(h-3072)|0]|0;break}}}while(0);a[9541288]=f;return};default:{return}}}function eY3(e){e=e|0;var f=0,g=0,h=0,i=0;f=d[e]|0;e=a[9533792]|0;do{if((e&1)!=0){if((f&1|0)!=0){break}if((a[8451520]&1)==0){break}a[8451544]=c[2385564]&255}}while(0);do{if((e&2)!=0){if((f&2|0)==0){break}if((a[8451520]&2)!=0){break}c[2444152]=d[8451536]|0|c[2444152]&65280}}while(0);do{if((e&4)!=0){if((f&4|0)==0){break}if((a[8451520]&4)!=0){break}c[2444152]=(d[8451536]|0)<<8&3840|c[2444152]&255}}while(0);do{if((e&16)==0){g=e}else{if((f&16|0)!=0){g=e;break}if((a[8451520]&16)==0){g=e;break}h=c[2444152]|0;if((f&8|0)==0){if((h&3072|0)!=3072){g=e;break}a[(c[3529150]|0)+(h&1023)|0]=a[8451536]|0;g=a[9533792]|0;break}if((h&2048|0)!=0){if((h&3072|0)!=3072){g=e;break}c[2385564]=d[(c[3529150]|0)+(h&1023)|0]|0;g=e;break}i=h&3;if((i|0)==0){c[2385564]=d[9657904]|0;g=e;break}else if((i|0)==1){c[2385564]=d[9657905]|0;g=e;break}else if((i|0)==3){c[2385564]=d[9625248]|0;g=e;break}else if((i|0)==2){c[2385564]=d[9625288]|0;g=e;break}else{g=e;break}}}while(0);if((g&32)==0){return}if((f&32|0)!=0){return}if((a[8451520]&32)==0){return}f=c[2439330]|0;if((f|0)!=0){g=f;gGC(9706056,g|0,76)|0}g=c[2426515]|0;b[4853030]=g&65535;f=c[2438118]|0;c[2433530]=f;e=c[3528484]|0;c[2076596]=e;c[3541536]=c[2417276];c[1836236]=0;i=c[3529150]|0;a[i+124|0]=((g&65535^f-e+(c[2426530]|0)|0)%6|0)&255;a[14125144]=a[i]|0;a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0;i=c[1836236]|0;e=c[9757320+(i<<2)>>2]|0;if((e|0)!=0){f=e;gGC(f|0,9706056,76)|0}c[9752472+(i<<2)>>2]=c[2433530];c[14113936+(i<<2)>>2]=c[2076596];c[9669104+(i<<2)>>2]=c[3541536];c[1836236]=-1;return}function eY4(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=d&65535;if((f|0)==64256){a[9759704]=e&-128;return}else if((f|0)==64128){d=e&7;a[14119312]=d;g=c[3529120]|0;h=c[9757320+(c[1836236]<<2)>>2]|0;i=((d&255)<<14)+32768|0;d=128;j=128;while(1){c[h+76+(j<<2)>>2]=g+(i+(j<<8));k=d+1&65535;if((k&65535)>191){l=128;m=128;break}else{d=k;j=k&65535}}while(1){j=g+(i+(m<<8))|0;c[h+76+(m+512<<2)>>2]=j;c[h+76+(m+768<<2)>>2]=j;j=l+1&65535;if((j&65535)>191){break}else{l=j;m=j&65535}}return}else if((f|0)==64384){m=c[1836236]|0;l=c[9757320+(m<<2)>>2]|0;if((l|0)!=0){h=l;gGC(h|0,9706056,76)|0}c[9752472+(m<<2)>>2]=c[2433530];c[14113936+(m<<2)>>2]=c[2076596];c[9669104+(m<<2)>>2]=c[3541536];c[1836236]=-1;m=c[2439331]|0;if((m|0)!=0){h=m;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;h=(c[2433530]|0)+12|0;c[2433530]=h;m=c[1836236]|0;l=c[9757320+(m<<2)>>2]|0;if((l|0)!=0){i=l;gGC(i|0,9706056,76)|0}c[9752472+(m<<2)>>2]=h;c[14113936+(m<<2)>>2]=c[2076596];c[9669104+(m<<2)>>2]=c[3541536];c[1836236]=-1;m=c[2439330]|0;if((m|0)!=0){h=m;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;return}else if((f|0)==64512){c[2439538]=e&255;c[2430226]=1;return}else{return}}function eY5(b){b=b|0;var d=0;switch(b&65535|0){case 64007:{d=a[9625248]|0;break};case 64006:{d=a[9625288]|0;break};case 64003:{d=a[9657904]|0;break};case 64512:{d=c[2438752]&255;break};case 65024:{d=-65;break};case 64004:{d=a[9657905]|0;break};case 64005:{d=a[9625336]&-33;break};default:{d=0}}return d|0}function eY6(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=b&65535;if((e|0)==43008){c[2432710]=1;if((c[2430226]|0)==0){return}if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12;c[2430226]=0;return}else if((e|0)==45056){b=c[3541518]|0;f=b+256|0;a[b+304|0]=d;g=d&255;if((d&255)<16){c[14168912+((c[2383582]|0)*252|0)>>2]=g&15}if((d-45&255)>=3){return}if((g|0)==46){h=b+312|0;i=a[h]|1;a[h]=i;j=i}else if((g|0)==0){a[b+312|0]=2;j=2}else if((g|0)==45){i=b+312|0;h=a[i]|2;a[i]=h;j=h}else if((g|0)==47){a[b+312|0]=0;j=0}else{j=a[b+312|0]|0}b=j&3;j=c[7461744+(b<<2)>>2]|0;lI(f,j,j,c[7461728+(b<<2)>>2]|0);return}else if((e|0)==36864){c[2438752]=d&255;return}else if((e|0)==40960){c[2432710]=0;return}else if((e|0)==45057){lS(0,1,d);return}else{return}}function eY7(b){b=b|0;var e=0,f=0,g=0,i=0,j=0.0,k=0.0;e=b&65535;if((e|0)==36864){f=c[2439538]&255;return f|0}else if((e|0)==45057){if((d[(c[3541518]|0)+304|0]|0)>=16){f=0;return f|0}b=c[2383582]|0;g=c[14168912+(b*252|0)>>2]|0;if((g|0)>15){f=0;return f|0}do{if((g|0)==15){i=c[14168900+(b*252|0)>>2]|0;if((i|0)==0){break}a[14168931+(b*252|0)|0]=gj[i&4095](0)|0}else if((g|0)==14){i=c[14168896+(b*252|0)>>2]|0;if((i|0)==0){break}a[14168930+(b*252|0)|0]=gj[i&4095](0)|0}}while(0);f=a[14168916+(b*252|0)+g|0]|0;return f|0}else if((e|0)==45056){e=c[3541518]|0;g=e+296|0;j=+h[g>>3];do{if(j!=0.0){k=+h[6675];if(j-(k+ +gC[c[2429842]&255]())<=0.0){h[g>>3]=0.0;break}f=a[e+307|0]|-128;return f|0}}while(0);f=a[e+307|0]|0;return f|0}else{f=0;return f|0}return 0}function eY8(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4201828+(b*112|0)>>2];c[a+104>>2]=c[4201832+(b*112|0)>>2];c[a+108>>2]=c[4201836+(b*112|0)>>2];d=0;return d|0}function eY9(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<21&(d|0)==0)){e=1;return e|0}c[a>>2]=4201728+(b*112|0);e=0;return e|0}function eZa(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1306624+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eZb(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>40){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4204080+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eZc(){c[2427022]=4560;a[14109496]=1;return eZW()|0}function eZd(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=a[7452592]|0;if(b){d=0;e=b&1;while(1){b=14163944+(d<<2)|0;f=c[b>>2]|0;g=c[2113006]|0;if((g|0)==0){h=33856}else{i=g-1|0;c[2113006]=i;if((i|0)==0){h=33856}}if((h|0)==33856){h=0;c[2383474]=0}if((f|0)==0){j=e}else{gGr(f);j=a[7452592]&1}c[b>>2]=0;b=d+1|0;if((b|0)<(j|0)){d=b;e=j}else{break}}}a[7452592]=0;c[2438222]=0;c[2433520]=0;c[2406670]=0;c[3528466]=0;j=c[2406686]|0;if((j|0)==0){c[2432974]=0;k=eZM()|0;return 0}gGr(j);c[2406686]=0;c[2432974]=0;k=eZM()|0;return 0}function eZe(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((a[9623720]|0)!=0){eZY()}eZQ();a[6518184]=1;a[6517928]=1;a[6517872]=1;c[2440472]=(a[14109496]|0)==2?66666:16666;c[2443958]=0;c[2443966]=0;c[2444008]=0;d=c[2385548]|0;if((d|0)>0){gGz(9752472,0,((d|0)>1?d<<2:4)|0)}c[2433530]=0;d=c[2439330]|0;if((d|0)!=0){e=d;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;e=0;d=1;while(1){U1(ag(d?1e3:0,e)|0);f=a[14109496]|0;if((e|0)!=98|f<<24>>24!=0){g=f}else{a[9706117]=1;g=0}if(!((e|0)!=99|g<<24>>24!=0)){a[9706117]=0}f=c[1836236]|0;h=c[9757320+(f<<2)>>2]|0;if((h|0)!=0){i=h;gGC(i|0,9706056,76)|0}c[9752472+(f<<2)>>2]=c[2433530];c[14113936+(f<<2)>>2]=c[2076596];c[9669104+(f<<2)>>2]=c[3541536];c[1836236]=-1;if((a[9730856]|0)!=0){f=c[2439331]|0;if((f|0)!=0){i=f;gGC(9706056,i|0,76)|0}b[4853030]=c[2426515]&65535;i=c[2438119]|0;c[2433530]=i;c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;h=(ag(a[6517928]|0?1e5:0,e+1|0)|0)/100|0;j=c[2443966]|0;k=h-j|0;c[2438174]=k;do{if((k|0)<1){l=0;m=j;n=i}else{if((a[f+4188|0]|0)==0){h=gfc(k)|0;o=(c[2433530]|0)+h|0;c[2433530]=o;l=h;m=c[2443966]|0;n=o;break}else{o=i+k|0;c[2433530]=o;l=k;m=j;n=o;break}}}while(0);c[2438174]=l;c[2443966]=m+l;if((e|0)==99){a[9706117]=0}else if((e|0)==98){a[9706117]=1}j=c[1836236]|0;k=c[9757320+(j<<2)>>2]|0;if((k|0)!=0){i=k;gGC(i|0,9706056,76)|0}c[9752472+(j<<2)>>2]=n;c[14113936+(j<<2)>>2]=c[2076596];c[9669104+(j<<2)>>2]=c[3541536];c[1836236]=-1}if((a[9730848]|0)!=0){j=c[2439332]|0;if((j|0)!=0){i=j;gGC(9706056,i|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438120];c[2076596]=c[3528486];c[3541536]=c[2417278];c[1836236]=2;Sb(ag(a[6517872]|0?500:0,e)|0);if((c[2430226]|0)!=0&(c[2432710]|0)!=0){if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12;c[2430226]=0}i=c[1836236]|0;j=c[9757320+(i<<2)>>2]|0;if((j|0)!=0){k=j;gGC(k|0,9706056,76)|0}c[9752472+(i<<2)>>2]=c[2433530];c[14113936+(i<<2)>>2]=c[2076596];c[9669104+(i<<2)>>2]=c[3541536];c[1836236]=-1}i=a[14109496]|0;k=e+1|0;if(i<<24>>24!=0&(a[9774056]|0)!=0){j=(ag(c[2440472]|0,k)|0)/100|0;f=j-(c[2443958]|0)|0;c[2438174]=f;do{if(i<<24>>24==2){j=f4Y(f)|0;c[2438174]=j;if((e|0)==99){if((c[2415208]|0)==0){p=j;break}c[2415208]=0;p=j;break}else if((e|0)==49){if((c[2415208]|0)==1){p=j;break}c[2415208]=1;b[4830412]=b[4830412]|1;p=j;break}else{p=j;break}}else{j=f4c(f)|0;c[2113162]=(c[2113162]|0)+j;c[2438174]=j;if((e|0)==98){f01();p=c[2438174]|0;break}else if((e|0)!=99){p=j;break}if((a[9660903]|0)==0){p=j;break}a[9660903]=0;p=j}}while(0);c[2443958]=(c[2443958]|0)+p}f=c[2439330]|0;if((f|0)!=0){i=f;gGC(9706056,i|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;q=a[6518184]|0;if((k|0)<100){e=k;d=q}else{break}}d=q?1e5:0;q=gGU(d,0,2048e6,0)|0;e=c[2438222]|0;p=gGS(q,K,e,(e|0)<0|0?-1:0)|0;e=p;U1(d);d=c[2443824]|0;if((d|0)<1073676288){c[2443824]=d-e}d=c[2443825]|0;if((d|0)<1073676288){c[2443825]=d-e}d=(c[3528506]|0)-e|0;c[3528506]=(d|0)<0?0:d;d=c[1836236]|0;e=c[9757320+(d<<2)>>2]|0;if((e|0)!=0){p=e;gGC(p|0,9706056,76)|0}c[9752472+(d<<2)>>2]=c[2433530];c[14113936+(d<<2)>>2]=c[2076596];c[9669104+(d<<2)>>2]=c[3541536];c[1836236]=-1;if((a[9730848]|0)!=0){d=c[2439332]|0;if((d|0)!=0){p=d;gGC(9706056,p|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438120];c[2076596]=c[3528486];c[3541536]=c[2417278];c[1836236]=2;p=a[6517872]|0?5e4:0;d=gGU(p,0,2048e6,0)|0;e=c[2438228]|0;q=gGS(d,K,e,(e|0)<0|0?-1:0)|0;e=q;Sb(p);p=c[2443830]|0;if((p|0)<1073676288){c[2443830]=p-e}p=c[2443831]|0;if((p|0)<1073676288){c[2443831]=p-e}p=(c[3528512]|0)-e|0;c[3528512]=(p|0)<0?0:p;p=c[1836236]|0;e=c[9757320+(p<<2)>>2]|0;if((e|0)!=0){q=e;gGC(q|0,9706056,76)|0}c[9752472+(p<<2)>>2]=c[2433530];c[14113936+(p<<2)>>2]=c[2076596];c[9669104+(p<<2)>>2]=c[3541536];c[1836236]=-1}p=c[2112964]|0;if((p|0)!=0){q=c[2439332]|0;if((q|0)!=0){e=q;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438120];c[2076596]=c[3528486];c[3541536]=c[2417278];c[1836236]=2;gg[c[3542122]&4095](p,a[9688]|0?534:0);p=c[1836236]|0;e=c[9757320+(p<<2)>>2]|0;if((e|0)!=0){q=e;gGC(q|0,9706056,76)|0}c[9752472+(p<<2)>>2]=c[2433530];c[14113936+(p<<2)>>2]=c[2076596];c[9669104+(p<<2)>>2]=c[3541536];c[1836236]=-1;p=c[2439330]|0;if((p|0)!=0){q=p;gGC(9706056,q|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;gg[c[3542114]&4095](c[2112964]|0,a[9688]|0?534:0);q=c[1836236]|0;p=c[9757320+(q<<2)>>2]|0;if((p|0)!=0){e=p;gGC(e|0,9706056,76)|0}c[9752472+(q<<2)>>2]=c[2433530];c[14113936+(q<<2)>>2]=c[2076596];c[9669104+(q<<2)>>2]=c[3541536];c[1836236]=-1}if((c[2112968]|0)==0){return 0}eZR();return 0}function eZf(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;g=i;i=i+432|0;h=g|0;j=g+16|0;k=g+32|0;l=g+48|0;m=g+64|0;n=g+80|0;o=g+96|0;p=g+112|0;q=g+128|0;r=g+144|0;s=g+160|0;t=g+176|0;u=g+192|0;v=g+208|0;w=g+224|0;x=g+240|0;y=g+256|0;z=g+272|0;A=g+288|0;B=g+304|0;C=g+320|0;D=g+336|0;E=g+352|0;F=g+368|0;G=g+384|0;H=g+400|0;I=g+416|0;if((f|0)!=0){c[f>>2]=169734}if((e&32|0)!=0){gGz(I|0,0,12);J=c[2405610]|0;c[I>>2]=J;c[I+4>>2]=(c[2411542]|0)-J;c[I+12>>2]=162152;J=c[2076592]|0;gj[J&4095](I)|0}if((e&64|0)!=0){fw$(e);I=a[14109496]|0;if(I<<24>>24==1){fwv(e);K=a[14109496]|0}else{K=I}if(K<<24>>24==2){eZ3(e)}Vx(e,f);if((dW(c[c[642608+(c[2436]<<2)>>2]>>2]|0,337832,5)|0)!=0){Vb(e,f)}gGz(H|0,0,12);c[H>>2]=14119312;c[H+4>>2]=1;c[H+12>>2]=511192;f=c[2076592]|0;gj[f&4095](H)|0;gGz(G|0,0,12);c[G>>2]=9730856;c[G+4>>2]=1;c[G+12>>2]=509336;H=c[2076592]|0;gj[H&4095](G)|0;gGz(F|0,0,12);c[F>>2]=9730848;c[F+4>>2]=1;c[F+12>>2]=507664;G=c[2076592]|0;gj[G&4095](F)|0;gGz(E|0,0,12);c[E>>2]=9774056;c[E+4>>2]=1;c[E+12>>2]=505816;F=c[2076592]|0;gj[F&4095](E)|0;gGz(D|0,0,12);c[D>>2]=9754904;c[D+4>>2]=1;c[D+12>>2]=504792;E=c[2076592]|0;gj[E&4095](D)|0;gGz(C|0,0,12);c[C>>2]=9759704;c[C+4>>2]=1;c[C+12>>2]=503888;D=c[2076592]|0;gj[D&4095](C)|0;gGz(B|0,0,12);c[B>>2]=9674016;c[B+4>>2]=4;c[B+12>>2]=502816;C=c[2076592]|0;gj[C&4095](B)|0;gGz(A|0,0,12);c[A>>2]=9674008;c[A+4>>2]=4;c[A+12>>2]=501880;B=c[2076592]|0;gj[B&4095](A)|0;gGz(z|0,0,12);c[z>>2]=9755008;c[z+4>>2]=4;c[z+12>>2]=500776;A=c[2076592]|0;gj[A&4095](z)|0;gGz(y|0,0,12);c[y>>2]=9730840;c[y+4>>2]=4;c[y+12>>2]=499512;z=c[2076592]|0;gj[z&4095](y)|0;gGz(x|0,0,12);c[x>>2]=9720904;c[x+4>>2]=4;c[x+12>>2]=498520;y=c[2076592]|0;gj[y&4095](x)|0;gGz(w|0,0,12);c[w>>2]=9758152;c[w+4>>2]=4;c[w+12>>2]=497064;x=c[2076592]|0;gj[x&4095](w)|0;gGz(v|0,0,12);c[v>>2]=9681576;c[v+4>>2]=1;c[v+12>>2]=495456;w=c[2076592]|0;gj[w&4095](v)|0;gGz(u|0,0,12);c[u>>2]=9681568;c[u+4>>2]=1;c[u+12>>2]=493952;v=c[2076592]|0;gj[v&4095](u)|0;gGz(t|0,0,12);c[t>>2]=9681560;c[t+4>>2]=1;c[t+12>>2]=492848;u=c[2076592]|0;gj[u&4095](t)|0;gGz(s|0,0,12);c[s>>2]=9681552;c[s+4>>2]=1;c[s+12>>2]=491928;t=c[2076592]|0;gj[t&4095](s)|0;gGz(r|0,0,12);c[r>>2]=9578848;c[r+4>>2]=1;c[r+12>>2]=491200;s=c[2076592]|0;gj[s&4095](r)|0;gGz(q|0,0,12);c[q>>2]=9578840;c[q+4>>2]=1;c[q+12>>2]=490392;r=c[2076592]|0;gj[r&4095](q)|0;gGz(p|0,0,12);c[p>>2]=9578832;c[p+4>>2]=1;c[p+12>>2]=489320;q=c[2076592]|0;gj[q&4095](p)|0;gGz(o|0,0,12);c[o>>2]=9578824;c[o+4>>2]=1;c[o+12>>2]=488136;p=c[2076592]|0;gj[p&4095](o)|0;gGz(n|0,0,12);c[n>>2]=9541296;c[n+4>>2]=1;c[n+12>>2]=486840;o=c[2076592]|0;gj[o&4095](n)|0;gGz(m|0,0,12);c[m>>2]=9541288;c[m+4>>2]=1;c[m+12>>2]=485168;n=c[2076592]|0;gj[n&4095](m)|0;gGz(l|0,0,12);c[l>>2]=9541280;c[l+4>>2]=1;c[l+12>>2]=483432;m=c[2076592]|0;gj[m&4095](l)|0;gGz(k|0,0,12);c[k>>2]=9541272;c[k+4>>2]=1;c[k+12>>2]=481768;l=c[2076592]|0;gj[l&4095](k)|0;gGz(j|0,0,12);c[j>>2]=9542256;c[j+4>>2]=4;c[j+12>>2]=480080;k=c[2076592]|0;gj[k&4095](j)|0;gGz(h|0,0,12);c[h>>2]=9776608;c[h+4>>2]=4;c[h+12>>2]=479176;j=c[2076592]|0;gj[j&4095](h)|0}if((e&2|0)==0){i=g;return 0}e=c[2439330]|0;h=(e|0)==0;if(!h){j=e;gGC(9706056,j|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];j=c[3528484]|0;c[2076596]=j;k=c[2417276]|0;c[3541536]=k;c[1836236]=0;l=c[3529120]|0;m=((d[14119312]|0)<<14)+32768|0;n=128;o=128;while(1){c[e+76+(o<<2)>>2]=l+(m+(o<<8));p=n+1&65535;if((p&65535)>191){L=128;M=128;break}else{n=p;o=p&65535}}while(1){o=l+(m+(M<<8))|0;c[e+76+(M+512<<2)>>2]=o;c[e+76+(M+768<<2)>>2]=o;o=L+1&65535;if((o&65535)>191){break}else{L=o;M=o&65535}}if(!h){h=e;gGC(h|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=j;c[2417276]=k;c[1836236]=-1;i=g;return 0}function eZg(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4204676+(b*112|0)>>2];c[a+104>>2]=c[4204680+(b*112|0)>>2];c[a+108>>2]=c[4204684+(b*112|0)>>2];d=0;return d|0}function eZh(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<21&(d|0)==0)){e=1;return e|0}c[a>>2]=4204576+(b*112|0);e=0;return e|0}function eZi(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4199476+(b*112|0)>>2];c[a+104>>2]=c[4199480+(b*112|0)>>2];c[a+108>>2]=c[4199484+(b*112|0)>>2];d=0;return d|0}function eZj(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<21&(d|0)==0)){e=1;return e|0}c[a>>2]=4199376+(b*112|0);e=0;return e|0}function eZk(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4207404+(b*112|0)>>2];c[a+104>>2]=c[4207408+(b*112|0)>>2];c[a+108>>2]=c[4207412+(b*112|0)>>2];d=0;return d|0}function eZl(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<21&(d|0)==0)){e=1;return e|0}c[a>>2]=4207304+(b*112|0);e=0;return e|0}function eZm(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4225740+(b*112|0)>>2];c[a+104>>2]=c[4225744+(b*112|0)>>2];c[a+108>>2]=c[4225748+(b*112|0)>>2];d=0;return d|0}function eZn(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<21&(d|0)==0)){e=1;return e|0}c[a>>2]=4225640+(b*112|0);e=0;return e|0}function eZo(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1308560+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eZp(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>42){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4227992+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eZq(){c[2427022]=4432;return eZW()|0}function eZr(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3528828+(b*112|0)>>2];c[a+104>>2]=c[3528832+(b*112|0)>>2];c[a+108>>2]=c[3528836+(b*112|0)>>2];d=0;return d|0}function eZs(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=3528728+(b*112|0);e=0;return e|0}function eZt(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3526284+(b*112|0)>>2];c[a+104>>2]=c[3526288+(b*112|0)>>2];c[a+108>>2]=c[3526292+(b*112|0)>>2];d=0;return d|0}function eZu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=3526184+(b*112|0);e=0;return e|0}function eZv(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>43){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3528200+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eZw(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4209756+(b*112|0)>>2];c[a+104>>2]=c[4209760+(b*112|0)>>2];c[a+108>>2]=c[4209764+(b*112|0)>>2];d=0;return d|0}function eZx(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=4209656+(b*112|0);e=0;return e|0}function eZy(){c[2427022]=2428;a[14109496]=2;return eZW()|0}function eZz(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6941876+(b*112|0)>>2];c[a+104>>2]=c[6941880+(b*112|0)>>2];c[a+108>>2]=c[6941884+(b*112|0)>>2];d=0;return d|0}function eZA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=6941776+(b*112|0);e=0;return e|0}function eZB(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>48){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6943120+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eZC(){c[2427022]=4366;return eZW()|0}function eZD(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4197460+(b*112|0)>>2];c[a+104>>2]=c[4197464+(b*112|0)>>2];c[a+108>>2]=c[4197468+(b*112|0)>>2];d=0;return d|0}function eZE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=4197360+(b*112|0);e=0;return e|0}function eZF(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1304708+(b*112|0)>>2];c[a+104>>2]=c[1304712+(b*112|0)>>2];c[a+108>>2]=c[1304716+(b*112|0)>>2];d=0;return d|0}function eZG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=1304608+(b*112|0);e=0;return e|0}function eZH(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>25){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6463148+(b*112|0)>>2];c[a+104>>2]=c[6463152+(b*112|0)>>2];c[a+108>>2]=c[6463156+(b*112|0)>>2];d=0;return d|0}function eZI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<26&(d|0)==0)){e=1;return e|0}c[a>>2]=6463048+(b*112|0);e=0;return e|0}function eZJ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4921336+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eZK(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>42){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6662856+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eZL(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0;e=i;i=i+2880|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;B=e+1200|0;C=e+1312|0;D=e+1320|0;E=e+1432|0;F=e+1440|0;G=e+1552|0;H=e+1560|0;I=e+1672|0;J=e+1680|0;K=e+1792|0;L=e+1800|0;M=e+1912|0;N=e+1920|0;O=e+2032|0;P=e+2040|0;Q=e+2152|0;R=e+2160|0;S=e+2272|0;T=e+2280|0;U=e+2392|0;V=e+2400|0;W=e+2512|0;X=e+2520|0;Y=e+2632|0;Z=e+2640|0;_=e+2752|0;$=e+2760|0;aa=e+2872|0;c[2426672]=0;c[3529120]=0;c[3529106]=196608;c[3529102]=229376;c[2407132]=270336;if((a[14109496]|0)==0){ab=270592}else{c[2387310]=270592;ab=274688}c[2405610]=ab;c[2439604]=ab;c[3527216]=ab+512;c[3529150]=ab+7936;c[3529138]=ab+8960;c[2443450]=ab+13056;c[2387312]=ab+19200;c[2443404]=ab+19392;ac=ab+20160|0;c[2411542]=ac;c[2405804]=ac;c[3529924]=ab+1068736;ac=ab+1069760|0;c[2414082]=ac;ab=ac;ac=0;while(1){if((ac|0)>=1024){break}ad=9638528+(ac<<2)|0;if((c[ad>>2]|0)==0){ae=34153;break}else{ac=ac+1|0}}do{if((ae|0)==34153){ac=gGq(ab)|0;c[ad>>2]=ac;if((ac|0)==0){break}gGz(ac|0,0,ab|0);c[2426672]=ac;gGz(ac|0,0,ab|0);c[3529120]=ac;c[3529106]=ac+196608;c[3529102]=ac+229376;c[2407132]=ac+270336;af=ac+270592|0;if((a[14109496]|0)==0){ah=af}else{c[2387310]=af;ah=ac+274688|0}c[2405610]=ah;c[2439604]=ah;c[3527216]=ah+512;c[3529150]=ah+7936;c[3529138]=ah+8960;c[2443450]=ah+13056;c[2387312]=ah+19200;c[2443404]=ah+19392;ac=ah+20160|0;c[2411542]=ac;c[2405804]=ac;c[3529924]=ah+1068736;c[2414082]=ah+1069760;ac=0;while(1){if((ac|0)>=1024){ai=0;break}aj=9638528+(ac<<2)|0;if((c[aj>>2]|0)==0){ae=34160;break}else{ac=ac+1|0}}do{if((ae|0)==34160){ac=gGq(524288)|0;c[aj>>2]=ac;if((ac|0)==0){ai=0;break}gGz(ac|0,0,524288);ai=ac}}while(0);c[3529514]=ai;ac=c[3529120]|0;if((c[3542200]|0)==0){ak=1;i=e;return ak|0}af=$+108|0;c[af>>2]=0;al=$+100|0;c[al>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383]($,0)|0;do{if((c[af>>2]|0)!=0){am=c[al>>2]|0;c[aa>>2]=9534384;an=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[an&16383](aa,0,0)|0;if((am|0)<1){ak=1;i=e;return ak|0}if((gzL(ac,0,0)|0)==0){break}else{ak=1}i=e;return ak|0}}while(0);ac=(c[3529120]|0)+65536|0;if((c[3542200]|0)==0){ak=1;i=e;return ak|0}al=Z+108|0;c[al>>2]=0;af=Z+100|0;c[af>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](Z,1)|0;do{if((c[al>>2]|0)!=0){am=c[af>>2]|0;c[_>>2]=9534384;an=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[an&16383](_,1,0)|0;if((am|0)<1){ak=1;i=e;return ak|0}if((gzL(ac,0,1)|0)==0){break}else{ak=1}i=e;return ak|0}}while(0);ac=(c[3529120]|0)+98304|0;if((c[3542200]|0)==0){ak=1;i=e;return ak|0}af=X+108|0;c[af>>2]=0;al=X+100|0;c[al>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](X,2)|0;do{if((c[af>>2]|0)!=0){am=c[al>>2]|0;c[Y>>2]=9534384;an=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[an&16383](Y,2,0)|0;if((am|0)<1){ak=1;i=e;return ak|0}if((gzL(ac,0,2)|0)==0){break}else{ak=1}i=e;return ak|0}}while(0);ac=(c[3529120]|0)+131072|0;if((c[3542200]|0)==0){ak=1;i=e;return ak|0}al=V+108|0;c[al>>2]=0;af=V+100|0;c[af>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](V,3)|0;do{if((c[al>>2]|0)!=0){am=c[af>>2]|0;c[W>>2]=9534384;an=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[an&16383](W,3,0)|0;if((am|0)<1){ak=1;i=e;return ak|0}if((gzL(ac,0,3)|0)==0){break}else{ak=1}i=e;return ak|0}}while(0);ac=(c[3529120]|0)+163840|0;if((c[3542200]|0)==0){ak=1;i=e;return ak|0}af=T+108|0;c[af>>2]=0;al=T+100|0;c[al>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](T,4)|0;do{if((c[af>>2]|0)!=0){am=c[al>>2]|0;c[U>>2]=9534384;an=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[an&16383](U,4,0)|0;if((am|0)<1){ak=1;i=e;return ak|0}if((gzL(ac,0,4)|0)==0){break}else{ak=1}i=e;return ak|0}}while(0);ac=c[3529106]|0;if((c[3542200]|0)==0){ak=1;i=e;return ak|0}al=R+108|0;c[al>>2]=0;af=R+100|0;c[af>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](R,5)|0;do{if((c[al>>2]|0)!=0){am=c[af>>2]|0;c[S>>2]=9534384;an=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[an&16383](S,5,0)|0;if((am|0)<1){ak=1;i=e;return ak|0}if((gzL(ac,0,5)|0)==0){break}else{ak=1}i=e;return ak|0}}while(0);ac=c[3529102]|0;if((c[3542200]|0)==0){ak=1;i=e;return ak|0}af=P+108|0;c[af>>2]=0;al=P+100|0;c[al>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](P,6)|0;do{if((c[af>>2]|0)!=0){am=c[al>>2]|0;c[Q>>2]=9534384;an=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[an&16383](Q,6,0)|0;if((am|0)<1){ak=1;i=e;return ak|0}if((gzL(ac,0,6)|0)==0){break}else{ak=1}i=e;return ak|0}}while(0);ac=c[3529514]|0;if((c[3542200]|0)==0){ak=1;i=e;return ak|0}al=N+108|0;c[al>>2]=0;af=N+100|0;c[af>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](N,7)|0;do{if((c[al>>2]|0)!=0){am=c[af>>2]|0;c[O>>2]=9534384;an=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[an&16383](O,7,0)|0;if((am|0)<1){ak=1;i=e;return ak|0}if((gzL(ac,0,7)|0)==0){break}else{ak=1}i=e;return ak|0}}while(0);ac=(c[3529514]|0)+32768|0;if((c[3542200]|0)==0){ak=1;i=e;return ak|0}af=L+108|0;c[af>>2]=0;al=L+100|0;c[al>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](L,8)|0;do{if((c[af>>2]|0)!=0){am=c[al>>2]|0;c[M>>2]=9534384;an=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[an&16383](M,8,0)|0;if((am|0)<1){ak=1;i=e;return ak|0}if((gzL(ac,0,8)|0)==0){break}else{ak=1}i=e;return ak|0}}while(0);ac=(c[3529514]|0)+65536|0;if((c[3542200]|0)==0){ak=1;i=e;return ak|0}al=J+108|0;c[al>>2]=0;af=J+100|0;c[af>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](J,9)|0;do{if((c[al>>2]|0)!=0){am=c[af>>2]|0;c[K>>2]=9534384;an=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[an&16383](K,9,0)|0;if((am|0)<1){ak=1;i=e;return ak|0}if((gzL(ac,0,9)|0)==0){break}else{ak=1}i=e;return ak|0}}while(0);ac=(c[3529514]|0)+98304|0;if((c[3542200]|0)==0){ak=1;i=e;return ak|0}af=H+108|0;c[af>>2]=0;al=H+100|0;c[al>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](H,10)|0;do{if((c[af>>2]|0)!=0){am=c[al>>2]|0;c[I>>2]=9534384;an=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[an&16383](I,10,0)|0;if((am|0)<1){ak=1;i=e;return ak|0}if((gzL(ac,0,10)|0)==0){break}else{ak=1}i=e;return ak|0}}while(0);ac=(c[3529514]|0)+131072|0;if((c[3542200]|0)==0){ak=1;i=e;return ak|0}al=F+108|0;c[al>>2]=0;af=F+100|0;c[af>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](F,11)|0;do{if((c[al>>2]|0)!=0){am=c[af>>2]|0;c[G>>2]=9534384;an=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[an&16383](G,11,0)|0;if((am|0)<1){ak=1;i=e;return ak|0}if((gzL(ac,0,11)|0)==0){break}else{ak=1}i=e;return ak|0}}while(0);ac=(c[3529514]|0)+163840|0;if((c[3542200]|0)==0){ak=1;i=e;return ak|0}af=D+108|0;c[af>>2]=0;al=D+100|0;c[al>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](D,12)|0;do{if((c[af>>2]|0)!=0){am=c[al>>2]|0;c[E>>2]=9534384;an=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[an&16383](E,12,0)|0;if((am|0)<1){ak=1;i=e;return ak|0}if((gzL(ac,0,12)|0)==0){break}else{ak=1}i=e;return ak|0}}while(0);ac=(c[3529514]|0)+196608|0;if((c[3542200]|0)==0){ak=1;i=e;return ak|0}al=B+108|0;c[al>>2]=0;af=B+100|0;c[af>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](B,13)|0;do{if((c[al>>2]|0)!=0){am=c[af>>2]|0;c[C>>2]=9534384;an=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[an&16383](C,13,0)|0;if((am|0)<1){ak=1;i=e;return ak|0}if((gzL(ac,0,13)|0)==0){break}else{ak=1}i=e;return ak|0}}while(0);ac=(c[3529514]|0)+229376|0;if((c[3542200]|0)==0){ak=1;i=e;return ak|0}af=z+108|0;c[af>>2]=0;al=z+100|0;c[al>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,14)|0;do{if((c[af>>2]|0)!=0){am=c[al>>2]|0;c[A>>2]=9534384;an=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[an&16383](A,14,0)|0;if((am|0)<1){ak=1;i=e;return ak|0}if((gzL(ac,0,14)|0)==0){break}else{ak=1}i=e;return ak|0}}while(0);ac=(c[3529514]|0)+262144|0;if((c[3542200]|0)==0){ak=1;i=e;return ak|0}al=x+108|0;c[al>>2]=0;af=x+100|0;c[af>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,15)|0;do{if((c[al>>2]|0)!=0){am=c[af>>2]|0;c[y>>2]=9534384;an=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[an&16383](y,15,0)|0;if((am|0)<1){ak=1;i=e;return ak|0}if((gzL(ac,0,15)|0)==0){break}else{ak=1}i=e;return ak|0}}while(0);ac=(c[3529514]|0)+294912|0;if((c[3542200]|0)==0){ak=1;i=e;return ak|0}af=v+108|0;c[af>>2]=0;al=v+100|0;c[al>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,16)|0;do{if((c[af>>2]|0)!=0){am=c[al>>2]|0;c[w>>2]=9534384;an=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[an&16383](w,16,0)|0;if((am|0)<1){ak=1;i=e;return ak|0}if((gzL(ac,0,16)|0)==0){break}else{ak=1}i=e;return ak|0}}while(0);ac=(c[3529514]|0)+327680|0;if((c[3542200]|0)==0){ak=1;i=e;return ak|0}al=t+108|0;c[al>>2]=0;af=t+100|0;c[af>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,17)|0;do{if((c[al>>2]|0)!=0){am=c[af>>2]|0;c[u>>2]=9534384;an=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[an&16383](u,17,0)|0;if((am|0)<1){ak=1;i=e;return ak|0}if((gzL(ac,0,17)|0)==0){break}else{ak=1}i=e;return ak|0}}while(0);ac=(c[3529514]|0)+360448|0;if((c[3542200]|0)==0){ak=1;i=e;return ak|0}af=r+108|0;c[af>>2]=0;al=r+100|0;c[al>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,18)|0;do{if((c[af>>2]|0)!=0){am=c[al>>2]|0;c[s>>2]=9534384;an=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[an&16383](s,18,0)|0;if((am|0)<1){ak=1;i=e;return ak|0}if((gzL(ac,0,18)|0)==0){break}else{ak=1}i=e;return ak|0}}while(0);ac=(c[3529514]|0)+393216|0;if((c[3542200]|0)==0){ak=1;i=e;return ak|0}al=p+108|0;c[al>>2]=0;af=p+100|0;c[af>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,19)|0;do{if((c[al>>2]|0)!=0){am=c[af>>2]|0;c[q>>2]=9534384;an=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[an&16383](q,19,0)|0;if((am|0)<1){ak=1;i=e;return ak|0}if((gzL(ac,0,19)|0)==0){break}else{ak=1}i=e;return ak|0}}while(0);ac=(c[3529514]|0)+425984|0;if((c[3542200]|0)==0){ak=1;i=e;return ak|0}af=n+108|0;c[af>>2]=0;al=n+100|0;c[al>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,20)|0;do{if((c[af>>2]|0)!=0){am=c[al>>2]|0;c[o>>2]=9534384;an=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[an&16383](o,20,0)|0;if((am|0)<1){ak=1;i=e;return ak|0}if((gzL(ac,0,20)|0)==0){break}else{ak=1}i=e;return ak|0}}while(0);ac=(c[3529514]|0)+458752|0;if((c[3542200]|0)==0){ak=1;i=e;return ak|0}al=l+108|0;c[al>>2]=0;af=l+100|0;c[af>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,21)|0;do{if((c[al>>2]|0)!=0){am=c[af>>2]|0;c[m>>2]=9534384;an=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[an&16383](m,21,0)|0;if((am|0)<1){ak=1;i=e;return ak|0}if((gzL(ac,0,21)|0)==0){break}else{ak=1}i=e;return ak|0}}while(0);ac=(c[3529514]|0)+491520|0;if((c[3542200]|0)==0){ak=1;i=e;return ak|0}af=j+108|0;c[af>>2]=0;al=j+100|0;c[al>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,22)|0;do{if((c[af>>2]|0)!=0){am=c[al>>2]|0;c[k>>2]=9534384;an=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[an&16383](k,22,0)|0;if((am|0)<1){ak=1;i=e;return ak|0}if((gzL(ac,0,22)|0)==0){break}else{ak=1}i=e;return ak|0}}while(0);ac=c[3529514]|0;al=0;do{af=ac+al|0;a[af]=~a[af];al=al+1|0;}while((al|0)<524288);al=c[2405804]|0;af=0;do{am=af<<6;gGz(al+am|0,0,64);an=af<<7;ao=0;do{ap=1<<3-ao;aq=(c[1658e3+(ao<<2)>>2]|0)+an|0;ar=0;do{as=aq+(c[6669224+(ar<<2)>>2]|0)|0;at=(ar<<3)+am|0;au=0;do{av=as+(c[6669320+(au<<2)>>2]|0)|0;if((d[ac+((av|0)/8|0)|0]&128>>>((av&7)>>>0)|0)!=0){av=al+(at+au)|0;a[av]=(d[av]|ap)&255}au=au+1|0;}while((au|0)<8);ar=ar+1|0;}while((ar|0)<8);ao=ao+1|0;}while((ao|0)<4);af=af+1|0;}while((af|0)<16384);af=c[2407132]|0;if((c[3542200]|0)==0){ak=1;i=e;return ak|0}al=f+108|0;c[al>>2]=0;ac=f+100|0;c[ac>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,23)|0;do{if((c[al>>2]|0)!=0){ao=c[ac>>2]|0;c[g>>2]=9534384;am=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[am&16383](g,23,0)|0;if((ao|0)<1){ak=1;i=e;return ak|0}if((gzL(af,0,23)|0)==0){break}else{ak=1}i=e;return ak|0}}while(0);af=c[3529514]|0;ac=0;while(1){if((ac|0)>=1024){break}aw=9638528+(ac<<2)|0;if((c[aw>>2]|0)==(af|0)){ae=34273;break}else{ac=ac+1|0}}if((ae|0)==34273){gGr(af);c[aw>>2]=0}c[3529514]=0;fwR(0);ac=c[2439330]|0;al=(ac|0)==0;if(!al){ao=ac;gGC(9706056,ao|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];ao=c[3528484]|0;c[2076596]=ao;am=c[2417276]|0;c[3541536]=am;c[1836236]=0;c[ac+4180>>2]=1550;c[ac+4184>>2]=1696;an=c[3529120]|0;ar=0;ap=0;while(1){c[ac+76+(ap<<2)>>2]=an+(ap<<8);aq=ar+1&65535;if((aq&65535)>127){ax=0;ay=0;break}else{ar=aq;ap=aq&65535}}while(1){ap=an+(ay<<8)|0;c[ac+76+(ay+512<<2)>>2]=ap;c[ac+76+(ay+768<<2)>>2]=ap;ap=ax+1&65535;if((ap&65535)>127){az=128;aA=128;break}else{ax=ap;ay=ap&65535}}while(1){c[ac+76+(aA<<2)>>2]=an+((aA<<8)+32768);ap=az+1&65535;if((ap&65535)>191){aB=128;aC=128;break}else{az=ap;aA=ap&65535}}while(1){ap=an+((aC<<8)+32768)|0;c[ac+76+(aC+512<<2)>>2]=ap;c[ac+76+(aC+768<<2)>>2]=ap;ap=aB+1&65535;if((ap&65535)>191){break}else{aB=ap;aC=ap&65535}}an=c[3527216]|0;ap=192;ar=192;while(1){c[ac+76+(ar<<2)>>2]=an+((ar<<8)-49152);af=ap+1&65535;if((af&65535)>220){aD=192;aE=192;break}else{ap=af;ar=af&65535}}while(1){c[ac+76+(aE+256<<2)>>2]=an+((aE<<8)-49152);ar=aD+1&65535;if((ar&65535)>220){aF=192;aG=192;break}else{aD=ar;aE=ar&65535}}while(1){ar=an+((aG<<8)-49152)|0;c[ac+76+(aG+512<<2)>>2]=ar;c[ac+76+(aG+768<<2)>>2]=ar;ar=aF+1&65535;if((ar&65535)>220){break}else{aF=ar;aG=ar&65535}}an=c[2443404]|0;c[ac+960>>2]=an;ar=an+256|0;c[ac+964>>2]=ar;ap=an+512|0;c[ac+968>>2]=ap;c[ac+1984>>2]=an;c[ac+1988>>2]=ar;c[ac+1992>>2]=ap;c[ac+3008>>2]=an;c[ac+4032>>2]=an;c[ac+3012>>2]=ar;c[ac+4036>>2]=ar;c[ac+3016>>2]=ap;c[ac+4040>>2]=ap;ap=c[2443450]|0;ar=224;an=224;while(1){c[ac+76+(an<<2)>>2]=ap+((an<<8)-57344);af=ar+1&65535;if((af&65535)>247){aH=224;aI=224;break}else{ar=af;an=af&65535}}while(1){c[ac+76+(aI+256<<2)>>2]=ap+((aI<<8)-57344);an=aH+1&65535;if((an&65535)>247){aJ=224;aK=224;break}else{aH=an;aI=an&65535}}while(1){an=ap+((aK<<8)-57344)|0;c[ac+76+(aK+512<<2)>>2]=an;c[ac+76+(aK+768<<2)>>2]=an;an=aJ+1&65535;if((an&65535)>247){break}else{aJ=an;aK=an&65535}}ap=c[2439604]|0;c[ac+1068>>2]=ap;an=ap+256|0;c[ac+1072>>2]=an;c[ac+2092>>2]=ap;c[ac+2096>>2]=an;c[ac+3116>>2]=ap;c[ac+4140>>2]=ap;c[ac+3120>>2]=an;c[ac+4144>>2]=an;if(!al){an=ac;gGC(an|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=ao;c[2417276]=am;c[1836236]=-1;fwR(1);an=c[2439331]|0;ap=(an|0)==0;if(!ap){ar=an;gGC(9706056,ar|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];ar=c[3528485]|0;c[2076596]=ar;af=c[2417277]|0;c[3541536]=af;c[1836236]=1;aq=c[3529106]|0;au=0;at=0;while(1){c[an+76+(at<<2)>>2]=aq+(at<<8);as=au+1&65535;if((as&65535)>127){aL=0;aM=0;break}else{au=as;at=as&65535}}while(1){at=aq+(aM<<8)|0;c[an+76+(aM+512<<2)>>2]=at;c[an+76+(aM+768<<2)>>2]=at;at=aL+1&65535;if((at&65535)>127){break}else{aL=at;aM=at&65535}}aq=c[2443450]|0;at=128;au=128;while(1){c[an+76+(au<<2)>>2]=aq+((au<<8)-32768);am=at+1&65535;if((am&65535)>151){aN=128;aO=128;break}else{at=am;au=am&65535}}while(1){c[an+76+(aO+256<<2)>>2]=aq+((aO<<8)-32768);au=aN+1&65535;if((au&65535)>151){aP=128;aQ=128;break}else{aN=au;aO=au&65535}}while(1){au=aq+((aQ<<8)-32768)|0;c[an+76+(aQ+512<<2)>>2]=au;c[an+76+(aQ+768<<2)>>2]=au;au=aP+1&65535;if((au&65535)>151){break}else{aP=au;aQ=au&65535}}if(!ap){aq=an;gGC(aq|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=ar;c[2417277]=af;c[1836236]=-1;fwR(2);aq=c[2439332]|0;au=(aq|0)==0;if(!au){at=aq;gGC(9706056,at|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438120];at=c[3528486]|0;c[2076596]=at;am=c[2417278]|0;c[3541536]=am;c[1836236]=2;c[aq+4180>>2]=1088;c[aq+4184>>2]=954;ao=c[3529102]|0;ac=0;al=0;while(1){c[aq+76+(al<<2)>>2]=ao+(al<<8);as=ac+1&65535;if((as&65535)>127){aR=0;aS=0;break}else{ac=as;al=as&65535}}while(1){al=ao+(aS<<8)|0;c[aq+76+(aS+512<<2)>>2]=al;c[aq+76+(aS+768<<2)>>2]=al;al=aR+1&65535;if((al&65535)>127){break}else{aR=al;aS=al&65535}}ao=c[3529138]|0;c[aq+588>>2]=ao;c[aq+592>>2]=ao+256;c[aq+596>>2]=ao+512;c[aq+600>>2]=ao+768;c[aq+604>>2]=ao+1024;c[aq+608>>2]=ao+1280;c[aq+612>>2]=ao+1536;c[aq+616>>2]=ao+1792;c[aq+620>>2]=ao+2048;c[aq+624>>2]=ao+2304;c[aq+628>>2]=ao+2560;c[aq+632>>2]=ao+2816;c[aq+636>>2]=ao+3072;c[aq+640>>2]=ao+3328;c[aq+644>>2]=ao+3584;c[aq+648>>2]=ao+3840;al=128;ac=128;while(1){c[aq+76+(ac+256<<2)>>2]=ao+((ac<<8)-32768);af=al+1&65535;if((af&65535)>143){aT=128;aU=128;break}else{al=af;ac=af&65535}}while(1){ac=ao+((aU<<8)-32768)|0;c[aq+76+(aU+512<<2)>>2]=ac;c[aq+76+(aU+768<<2)>>2]=ac;ac=aT+1&65535;if((ac&65535)>143){break}else{aT=ac;aU=ac&65535}}if(!au){ao=aq;gGC(ao|0,9706056,76)|0}c[2438120]=c[2433530];c[3528486]=at;c[2417278]=am;c[1836236]=-1;Vr(1,3e6,1254,2888,90,0);c[2438228]=3e6;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=681;h[745419]=.1;a[3203368]=1;h[745418]=.08;a[3203360]=1;h[745417]=.08;a[3203352]=1;h[745416]=.08;a[3203344]=1;ao=c[642608+(c[2436]<<2)>>2]|0;ac=c[ao+128>>2]|0;if((c[ao+52>>2]&4|0)==0){c[2113068]=ac;al=c[ao+132>>2]|0;c[2113070]=al;c[2443814]=ac;c[2440436]=al;aV=ac;aW=al}else{c[2113070]=ac;al=c[ao+132>>2]|0;c[2113068]=al;c[2440436]=ac;c[2443814]=al;aV=al;aW=ac}ac=ag(aV<<1,aW)|0;al=gGq(ac)|0;c[2112926]=al;if((al|0)!=0){gGz(al|0,0,ac|0)}a[9754904]=1;a[14109496]=0;ac=c[2439330]|0;al=(ac|0)==0;if(!al){ao=ac;gGC(9706056,ao|0,76)|0}ao=c[2438118]|0;c[2433530]=ao;af=c[3528484]|0;c[2076596]=af;ar=c[2417276]|0;c[3541536]=ar;c[1836236]=0;gGz(9706056,0,76);if(!al){al=ac;gGC(al|0,9706056,76)|0}c[2438118]=ao;c[3528484]=af;c[2417276]=ar;c[1836236]=-1;ar=c[2439331]|0;af=(ar|0)==0;if(!af){ao=ar;gGC(9706056,ao|0,76)|0}ao=c[2438119]|0;c[2433530]=ao;al=c[3528485]|0;c[2076596]=al;ac=c[2417277]|0;c[3541536]=ac;c[1836236]=1;gGz(9706056,0,76);if(!af){af=ar;gGC(af|0,9706056,76)|0}c[2438119]=ao;c[3528485]=al;c[2417277]=ac;c[1836236]=-1;ac=c[2439332]|0;al=(ac|0)==0;if(!al){ao=ac;gGC(9706056,ao|0,76)|0}ao=c[2438120]|0;c[2433530]=ao;af=c[3528486]|0;c[2076596]=af;ar=c[2417278]|0;c[3541536]=ar;c[1836236]=2;gGz(9706056,0,76);if(!al){al=ac;gGC(al|0,9706056,76)|0}c[2438120]=ao;c[3528486]=af;c[2417278]=ar;c[1836236]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){ar=0;do{lN(ar);mB(ar);ar=ar+1|0;}while((ar|0)<(c[2385508]|0))}a[14119312]=0;a[9754904]=1;a[9759704]=0;c[2438752]=0;c[2432710]=0;c[2430226]=0;c[2439538]=0;ak=0;i=e;return ak|0}}while(0);c[2426672]=0;ak=1;i=e;return ak|0}function eZM(){var b=0,d=0,e=0,f=0,g=0;fwZ();b=c[3541518]|0;if((b|0)!=0){gGr(b|0);c[3541518]=0}if((c[2385508]|0)>0){c[2113008]=0;c[2076598]=0;c[2383582]=0}c[2438228]=0;c[2433526]=0;c[2406676]=0;c[3528472]=0;b=c[2406680]|0;if((b|0)!=0){gGr(b);c[2406680]=0}c[2385508]=0;c[2432978]=0;a[64240]=0;b=a[14109496]|0;do{if(b<<24>>24==1){d=c[2437644]|0;if((d|0)==0){break}gGr(d);c[2437644]=0;e=a[14109496]|0;f=34416}else{e=b;f=34416}}while(0);do{if((f|0)==34416){if(e<<24>>24!=2){break}c[2443666]=0;c[2385780]=0;c[3528996]=0}}while(0);c[2113070]=0;c[2113068]=0;e=c[2112926]|0;if((e|0)!=0){gGr(e);c[2112926]=0}e=c[2426672]|0;b=0;while(1){if((b|0)>=1024){break}g=9638528+(b<<2)|0;if((c[g>>2]|0)==(e|0)){f=34423;break}else{b=b+1|0}}if((f|0)==34423){gGr(e);c[g>>2]=0}c[2426672]=0;a[14119312]=0;a[9730856]=0;a[9730848]=0;a[9774056]=0;a[9754904]=0;a[9759704]=0;c[2418504]=0;c[2418502]=0;c[2438752]=0;c[2432710]=0;c[2430226]=0;c[2439538]=0;a[14109496]=0;c[2385564]=0;c[2444152]=0;c[2427022]=0;return 0}function eZN(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;if((a[9623720]|0)!=0){d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=i;c[1836236]=-1;i=c[2439331]|0;g=(i|0)==0;if(!g){f=i;gGC(9706056,f|0,76)|0}f=c[2438119]|0;c[2433530]=f;e=c[3528485]|0;c[2076596]=e;d=c[2417277]|0;c[3541536]=d;c[1836236]=1;gGz(9706056,0,76);if(!g){g=i;gGC(g|0,9706056,76)|0}c[2438119]=f;c[3528485]=e;c[2417277]=d;c[1836236]=-1;d=c[2439332]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438120]|0;c[2433530]=f;g=c[3528486]|0;c[2076596]=g;i=c[2417278]|0;c[3541536]=i;c[1836236]=2;gGz(9706056,0,76);if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438120]=f;c[3528486]=g;c[2417278]=i;c[1836236]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){i=0;do{lN(i);mB(i);i=i+1|0;}while((i|0)<(c[2385508]|0))}a[14119312]=0;a[9754904]=1;a[9759704]=0;c[2438752]=0;c[2432710]=0;c[2430226]=0;c[2439538]=0}eZQ();a[6518184]=1;a[6517928]=1;a[6517872]=1;c[2443966]=0;c[2444008]=0;i=c[2385548]|0;if((i|0)>0){gGz(9752472,0,((i|0)>1?i<<2:4)|0)}c[2433530]=0;i=0;while(1){g=c[2439330]|0;if((g|0)!=0){f=g;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;f=c[2438118]|0;c[2433530]=f;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;e=i+1|0;d=(ag(a[6518184]|0?1e5:0,e)|0)/100|0;j=c[2444008]|0;k=d-j|0;c[2438174]=k;do{if((k|0)<1){l=0;m=j;n=f}else{if((a[g+4188|0]|0)==0){d=gfc(k)|0;o=(c[2433530]|0)+d|0;c[2433530]=o;l=d;m=c[2444008]|0;n=o;break}else{o=f+k|0;c[2433530]=o;l=k;m=j;n=o;break}}}while(0);c[2438174]=l;c[2444008]=m+l;j=(i|0)==98;do{if(j){a[9706117]=1;p=0}else{if((i|0)!=99){p=0;break}a[9706117]=0;p=1}}while(0);k=c[1836236]|0;f=c[9757320+(k<<2)>>2]|0;if((f|0)!=0){g=f;gGC(g|0,9706056,76)|0}c[9752472+(k<<2)>>2]=n;c[14113936+(k<<2)>>2]=c[2076596];c[9669104+(k<<2)>>2]=c[3541536];c[1836236]=-1;k=c[2439331]|0;if((k|0)!=0){g=k;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;g=c[2438119]|0;c[2433530]=g;c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;f=(ag(a[6517928]|0?1e5:0,e)|0)/100|0;o=c[2443966]|0;d=f-o|0;c[2438174]=d;do{if((d|0)<1){q=0;r=o;s=g}else{if((a[k+4188|0]|0)==0){f=gfc(d)|0;t=(c[2433530]|0)+f|0;c[2433530]=t;q=f;r=c[2443966]|0;s=t;break}else{t=g+d|0;c[2433530]=t;q=d;r=o;s=t;break}}}while(0);c[2438174]=q;c[2443966]=r+q;if(j){a[9706117]=1}if(p){a[9706117]=0}o=c[1836236]|0;d=c[9757320+(o<<2)>>2]|0;if((d|0)!=0){g=d;gGC(g|0,9706056,76)|0}c[9752472+(o<<2)>>2]=s;c[14113936+(o<<2)>>2]=c[2076596];c[9669104+(o<<2)>>2]=c[3541536];c[1836236]=-1;o=c[2439332]|0;if((o|0)!=0){g=o;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438120];c[2076596]=c[3528486];c[3541536]=c[2417278];c[1836236]=2;Sb(ag(a[6517872]|0?500:0,i)|0);if((c[2430226]|0)!=0&(c[2432710]|0)!=0){if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12;c[2430226]=0}g=c[1836236]|0;o=c[9757320+(g<<2)>>2]|0;if((o|0)!=0){d=o;gGC(d|0,9706056,76)|0}c[9752472+(g<<2)>>2]=c[2433530];c[14113936+(g<<2)>>2]=c[2076596];c[9669104+(g<<2)>>2]=c[3541536];c[1836236]=-1;if((e|0)<100){i=e}else{break}}i=c[2439332]|0;if((i|0)!=0){s=i;gGC(9706056,s|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438120];c[2076596]=c[3528486];c[3541536]=c[2417278];c[1836236]=2;s=a[6517872]|0?5e4:0;i=gGU(s,0,2048e6,0)|0;p=c[2438228]|0;q=gGS(i,K,p,(p|0)<0|0?-1:0)|0;p=q;Sb(s);s=c[2443830]|0;if((s|0)<1073676288){c[2443830]=s-p}s=c[2443831]|0;if((s|0)<1073676288){c[2443831]=s-p}s=(c[3528512]|0)-p|0;c[3528512]=(s|0)<0?0:s;s=c[1836236]|0;p=c[9757320+(s<<2)>>2]|0;if((p|0)!=0){q=p;gGC(q|0,9706056,76)|0}c[9752472+(s<<2)>>2]=c[2433530];c[14113936+(s<<2)>>2]=c[2076596];c[9669104+(s<<2)>>2]=c[3541536];c[1836236]=-1;s=c[2112964]|0;if((s|0)!=0){q=c[2439332]|0;if((q|0)!=0){p=q;gGC(9706056,p|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438120];c[2076596]=c[3528486];c[3541536]=c[2417278];c[1836236]=2;gg[c[3542122]&4095](s,a[9688]|0?534:0);s=c[1836236]|0;p=c[9757320+(s<<2)>>2]|0;if((p|0)!=0){q=p;gGC(q|0,9706056,76)|0}c[9752472+(s<<2)>>2]=c[2433530];c[14113936+(s<<2)>>2]=c[2076596];c[9669104+(s<<2)>>2]=c[3541536];c[1836236]=-1}if((c[2112968]|0)==0){return 0}eZR();return 0}function eZO(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>23){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5645396+(b*112|0)>>2];c[a+104>>2]=c[5645400+(b*112|0)>>2];c[a+108>>2]=c[5645404+(b*112|0)>>2];d=0;return d|0}function eZP(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<24&(d|0)==0)){e=1;return e|0}c[a>>2]=5645296+(b*112|0);e=0;return e|0}function eZQ(){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;a[9625336]=-13;if((a[9759144]|0)==0){b=-13}else{a[9625336]=-14;b=-14}if((a[9759145]|0)==0){c=b}else{d=b-2&255;a[9625336]=d;c=d}if((a[9759146]|0)==0){e=c}else{d=c|4;a[9625336]=d;e=d}if((a[9759147]|0)==0){f=e}else{d=e|8;a[9625336]=d;f=d}if((a[9759148]|0)==0){g=f}else{d=f-16&255;a[9625336]=d;g=d}if((a[9759149]|0)==0){h=g}else{d=g-32&255;a[9625336]=d;h=d}if((a[9759150]|0)==0){i=h}else{d=h-64&255;a[9625336]=d;i=d}if((a[9759151]|0)!=0){a[9625336]=i^-128}a[9625288]=-1;a[9625248]=-1;i=0;d=-1;h=-1;do{d=(d&255)-((a[9758952+i|0]&1)<<i)&255;h=(h&255)-((a[9758776+i|0]&1)<<i)&255;i=i+1|0;}while((i|0)<8);a[9625288]=d;a[9625248]=h;return}function eZR(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;e=c[2113070]|0;f=c[2113068]|0;g=ag(f,e)|0;if((g|0)>0){h=c[2112926]|0;i=0;do{b[h+(i<<1)>>1]=255;i=i+1|0;}while((i|0)<(g|0))}g=c[2439604]|0;i=c[3529924]|0;h=0;do{j=a[g+h|0]|0;k=j&255;l=(k&65535)>>>4;m=((k<<8|d[g+(h|1)|0])&65535)>>>4;c[i+(((h|0)/2|0)<<2)>>2]=((l<<4|l)&65535)<<8&63488|((j<<4|j&12)&255)<<3&2016|((m<<4&255|m&8)&255)>>>3;h=h+2|0;}while((h|0)<512);if((a[9754904]|0)==0){R8(i);return}h=c[2407132]|0;g=c[2443404]|0;m=c[3527216]|0;j=c[2112926]|0;l=c[2405804]|0;k=0;n=0;while(1){o=c[g+k>>2]|0;if((o|0)==0){p=n}else{q=d[g+(k|1)|0]|0;r=d[g+(k|3)|0]|0;s=q>>>1&112|128;t=q<<7&3968;u=(q&160|0)==160?t|4096:t;t=(r&64|0)==0;q=r<<10&15360;r=g+(k|2)|0;v=0;w=n;while(1){x=h+(((v|0)/2|0)+s)|0;y=a[x]|0;z=y&255;L45284:do{if((z&8|0)==0){do{if((z&4|0)==0){A=d[r]|0;if(t){B=A;break}B=A|-256}else{B=w}}while(0);A=v<<1&14;C=(v<<3)-o&255;D=248-C|0;E=0;F=y;while(1){G=(E<<6)+u|A|(F&255)<<4&48;H=d[m+(G|1)|0]|0;I=d[m+G|0]|q|H<<8&768;G=H>>>2&15;J=H&64;K=(E<<3)+B|0;if((a[9759704]|0)==0){L=C;M=K;N=H&128;O=J}else{L=D;M=248-K|0;N=H>>>7^1;O=J>>>6^1}J=L-16|0;do{if((M|0)>8){if(!((M|0)<(f-8|0)&(J|0)>8)){P=34553;break}if((J|0)>=(e-8|0)){P=34553;break}H=(N|0)!=0;if((O|0)==0){if(H){Su(j,I,M,J,G,4,15,0,l);break}else{Sq(j,I,M,J,G,4,15,0,l);break}}else{if(H){Sw(j,I,M,J,G,4,15,0,l);break}else{Ss(j,I,M,J,G,4,15,0,l);break}}}else{P=34553}}while(0);do{if((P|0)==34553){P=0;H=(N|0)!=0;if((O|0)==0){if(H){Sv(j,I,M,J,G,4,15,0,l);break}else{Sr(j,I,M,J,G,4,15,0,l);break}}else{if(H){Sx(j,I,M,J,G,4,15,0,l);break}else{St(j,I,M,J,G,4,15,0,l);break}}}}while(0);G=E+1|0;if((G|0)>=2){Q=B;break L45284}E=G;F=a[x]|0}}else{Q=w}}while(0);x=v+1|0;if((x|0)<32){v=x;w=Q}else{break}}p=Q+16|0}w=k+4|0;if((w|0)<768){k=w;n=p}else{break}}R8(i);return}function eZS(b,c){b=b|0;c=c|0;a[9706117]=c&1;return}function eZT(a){a=a|0;var b=0,d=0;b=(c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,3e6,0)|0;return a|0}function eZU(){return+(+((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)/3.0e6)}function eZV(){var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;e=i;i=i+1440|0;f=e|0;g=e+112|0;h=e+120|0;j=e+232|0;k=e+240|0;l=e+352|0;m=e+360|0;n=e+472|0;o=e+480|0;p=e+592|0;q=e+600|0;r=e+712|0;s=e+720|0;t=e+832|0;u=e+840|0;v=e+952|0;w=e+960|0;x=e+1072|0;y=e+1080|0;z=e+1192|0;A=e+1200|0;B=e+1312|0;C=e+1320|0;D=e+1432|0;E=0;while(1){if((E|0)>=1024){F=0;break}G=9638528+(E<<2)|0;if((c[G>>2]|0)==0){H=34574;break}else{E=E+1|0}}do{if((H|0)==34574){E=gGq(524288)|0;c[G>>2]=E;if((E|0)==0){F=0;break}gGz(E|0,0,524288);F=E}}while(0);c[3529514]=F;F=c[3529120]|0;if((c[3542200]|0)==0){I=1;i=e;return I|0}G=C+108|0;c[G>>2]=0;E=C+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](C,0)|0;do{if((c[G>>2]|0)!=0){C=c[E>>2]|0;c[D>>2]=9534384;J=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[J&16383](D,0,0)|0;if((C|0)<1){I=1;i=e;return I|0}if((gzL(F,0,0)|0)==0){break}else{I=1}i=e;return I|0}}while(0);F=(c[3529120]|0)+65536|0;if((c[3542200]|0)==0){I=1;i=e;return I|0}D=A+108|0;c[D>>2]=0;E=A+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](A,1)|0;do{if((c[D>>2]|0)!=0){A=c[E>>2]|0;c[B>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](B,1,0)|0;if((A|0)<1){I=1;i=e;return I|0}if((gzL(F,0,1)|0)==0){break}else{I=1}i=e;return I|0}}while(0);F=(c[3529120]|0)+98304|0;if((c[3542200]|0)==0){I=1;i=e;return I|0}B=y+108|0;c[B>>2]=0;E=y+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](y,2)|0;do{if((c[B>>2]|0)!=0){y=c[E>>2]|0;c[z>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](z,2,0)|0;if((y|0)<1){I=1;i=e;return I|0}if((gzL(F,0,2)|0)==0){break}else{I=1}i=e;return I|0}}while(0);F=c[3529106]|0;if((c[3542200]|0)==0){I=1;i=e;return I|0}z=w+108|0;c[z>>2]=0;E=w+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](w,3)|0;do{if((c[z>>2]|0)!=0){w=c[E>>2]|0;c[x>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](x,3,0)|0;if((w|0)<1){I=1;i=e;return I|0}if((gzL(F,0,3)|0)==0){break}else{I=1}i=e;return I|0}}while(0);F=c[3529102]|0;if((c[3542200]|0)==0){I=1;i=e;return I|0}x=u+108|0;c[x>>2]=0;E=u+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](u,4)|0;do{if((c[x>>2]|0)!=0){u=c[E>>2]|0;c[v>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](v,4,0)|0;if((u|0)<1){I=1;i=e;return I|0}if((gzL(F,0,4)|0)==0){break}else{I=1}i=e;return I|0}}while(0);F=c[3529514]|0;if((c[3542200]|0)==0){I=1;i=e;return I|0}v=s+108|0;c[v>>2]=0;E=s+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](s,5)|0;do{if((c[v>>2]|0)!=0){s=c[E>>2]|0;c[t>>2]=9534384;x=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[x&16383](t,5,0)|0;if((s|0)<1){I=1;i=e;return I|0}if((gzL(F,0,5)|0)==0){break}else{I=1}i=e;return I|0}}while(0);F=(c[3529514]|0)+65536|0;if((c[3542200]|0)==0){I=1;i=e;return I|0}t=q+108|0;c[t>>2]=0;E=q+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](q,6)|0;do{if((c[t>>2]|0)!=0){q=c[E>>2]|0;c[r>>2]=9534384;v=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[v&16383](r,6,0)|0;if((q|0)<1){I=1;i=e;return I|0}if((gzL(F,0,6)|0)==0){break}else{I=1}i=e;return I|0}}while(0);F=(c[3529514]|0)+131072|0;if((c[3542200]|0)==0){I=1;i=e;return I|0}r=o+108|0;c[r>>2]=0;E=o+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](o,7)|0;do{if((c[r>>2]|0)!=0){o=c[E>>2]|0;c[p>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](p,7,0)|0;if((o|0)<1){I=1;i=e;return I|0}if((gzL(F,0,7)|0)==0){break}else{I=1}i=e;return I|0}}while(0);F=(c[3529514]|0)+262144|0;if((c[3542200]|0)==0){I=1;i=e;return I|0}p=m+108|0;c[p>>2]=0;E=m+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,8)|0;do{if((c[p>>2]|0)!=0){m=c[E>>2]|0;c[n>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](n,8,0)|0;if((m|0)<1){I=1;i=e;return I|0}if((gzL(F,0,8)|0)==0){break}else{I=1}i=e;return I|0}}while(0);F=(c[3529514]|0)+327680|0;if((c[3542200]|0)==0){I=1;i=e;return I|0}n=k+108|0;c[n>>2]=0;E=k+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,9)|0;do{if((c[n>>2]|0)!=0){k=c[E>>2]|0;c[l>>2]=9534384;p=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[p&16383](l,9,0)|0;if((k|0)<1){I=1;i=e;return I|0}if((gzL(F,0,9)|0)==0){break}else{I=1}i=e;return I|0}}while(0);F=(c[3529514]|0)+393216|0;if((c[3542200]|0)==0){I=1;i=e;return I|0}l=h+108|0;c[l>>2]=0;E=h+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](h,10)|0;do{if((c[l>>2]|0)!=0){h=c[E>>2]|0;c[j>>2]=9534384;n=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[n&16383](j,10,0)|0;if((h|0)<1){I=1;i=e;return I|0}if((gzL(F,0,10)|0)==0){break}else{I=1}i=e;return I|0}}while(0);F=c[3529514]|0;j=0;while(1){E=F+j|0;l=a[E]|0;a[E]=~(l<<3&8|l&-16|(l&255)>>>3&1|(l&255)>>>1<<2&4|(l&255)>>>2<<1&2);l=j+1|0;if((l|0)<262144){j=l}else{K=262144;break}}do{j=F+K|0;l=a[j]|0;a[j]=~(l<<2&4|l&-86|(l&255)>>>2&1|(l&255)>>>4<<6&64|(l&255)>>>6<<4&16);K=K+1|0;}while((K|0)<524288);K=c[2405804]|0;l=0;do{j=l<<6;gGz(K+j|0,0,64);E=l<<7;h=0;do{n=1<<3-h;k=(c[1658e3+(h<<2)>>2]|0)+E|0;p=0;do{m=k+(c[6669224+(p<<2)>>2]|0)|0;r=(p<<3)+j|0;o=0;do{t=m+(c[6669320+(o<<2)>>2]|0)|0;if(((d[F+((t|0)/8|0)|0]|0)&128>>>((t&7)>>>0)|0)!=0){t=K+(r+o)|0;a[t]=(d[t]|0|n)&255}o=o+1|0;}while((o|0)<8);p=p+1|0;}while((p|0)<8);h=h+1|0;}while((h|0)<4);l=l+1|0;}while((l|0)<16384);l=c[2407132]|0;if((c[3542200]|0)==0){I=1;i=e;return I|0}K=f+108|0;c[K>>2]=0;F=f+100|0;c[F>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,11)|0;do{if((c[K>>2]|0)!=0){f=c[F>>2]|0;c[g>>2]=9534384;h=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[h&16383](g,11,0)|0;if((f|0)<1){I=1;i=e;return I|0}if((gzL(l,0,11)|0)==0){break}else{I=1}i=e;return I|0}}while(0);l=c[3529514]|0;g=0;while(1){if((g|0)>=1024){break}L=9638528+(g<<2)|0;if((c[L>>2]|0)==(l|0)){H=34640;break}else{g=g+1|0}}if((H|0)==34640){gGr(l);c[L>>2]=0}c[3529514]=0;L=c[2439330]|0;l=(L|0)==0;if(!l){H=L;gGC(9706056,H|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];H=c[3528484]|0;c[2076596]=H;g=c[2417276]|0;c[3541536]=g;c[1836236]=0;c[L+4180>>2]=602;c[L+4184>>2]=1302;F=L+1092|0;c[F>>2]=0;c[F+4>>2]=0;F=L+2116|0;c[F>>2]=0;c[F+4>>2]=0;c[L+3140>>2]=0;c[L+4164>>2]=0;c[L+3144>>2]=0;c[L+4168>>2]=0;if(!l){l=L;gGC(l|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=H;c[2417276]=g;c[1836236]=-1;I=0;i=e;return I|0}function eZW(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;c[2426672]=0;c[3529120]=0;c[3529106]=196608;c[3529102]=229376;c[2407132]=270336;if((a[14109496]|0)==0){d=270592}else{c[2387310]=270592;d=274688}c[2405610]=d;c[2439604]=d;c[3527216]=d+512;c[3529150]=d+7936;c[3529138]=d+8960;c[2443450]=d+13056;c[2387312]=d+19200;c[2443404]=d+19392;e=d+20160|0;c[2411542]=e;c[2405804]=e;c[3529924]=d+1068736;e=d+1069760|0;c[2414082]=e;d=e;e=0;while(1){if((e|0)>=1024){break}f=9638528+(e<<2)|0;if((c[f>>2]|0)==0){g=34689;break}else{e=e+1|0}}do{if((g|0)==34689){e=gGq(d)|0;c[f>>2]=e;if((e|0)==0){break}gGz(e|0,0,d|0);c[2426672]=e;gGz(e|0,0,d|0);c[3529120]=e;c[3529106]=e+196608;c[3529102]=e+229376;c[2407132]=e+270336;i=e+270592|0;if((a[14109496]|0)==0){j=i}else{c[2387310]=i;j=e+274688|0}c[2405610]=j;c[2439604]=j;c[3527216]=j+512;c[3529150]=j+7936;c[3529138]=j+8960;c[2443450]=j+13056;c[2387312]=j+19200;c[2443404]=j+19392;e=j+20160|0;c[2411542]=e;c[2405804]=e;c[3529924]=j+1068736;c[2414082]=j+1069760;fwR(0);e=c[2439330]|0;i=(e|0)==0;if(!i){k=e;gGC(9706056,k|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];k=c[3528484]|0;c[2076596]=k;l=c[2417276]|0;c[3541536]=l;c[1836236]=0;c[e+4180>>2]=2498;c[e+4184>>2]=1070;m=c[3529120]|0;n=0;o=0;while(1){c[e+76+(o<<2)>>2]=m+(o<<8);p=n+1&65535;if((p&65535)>127){q=0;r=0;break}else{n=p;o=p&65535}}while(1){o=m+(r<<8)|0;c[e+76+(r+512<<2)>>2]=o;c[e+76+(r+768<<2)>>2]=o;o=q+1&65535;if((o&65535)>127){s=128;t=128;break}else{q=o;r=o&65535}}while(1){c[e+76+(t<<2)>>2]=m+((t<<8)+32768);o=s+1&65535;if((o&65535)>191){u=128;v=128;break}else{s=o;t=o&65535}}while(1){o=m+((v<<8)+32768)|0;c[e+76+(v+512<<2)>>2]=o;c[e+76+(v+768<<2)>>2]=o;o=u+1&65535;if((o&65535)>191){break}else{u=o;v=o&65535}}m=c[3527216]|0;o=192;n=192;while(1){c[e+76+(n<<2)>>2]=m+((n<<8)-49152);p=o+1&65535;if((p&65535)>220){w=192;x=192;break}else{o=p;n=p&65535}}while(1){c[e+76+(x+256<<2)>>2]=m+((x<<8)-49152);n=w+1&65535;if((n&65535)>220){y=192;z=192;break}else{w=n;x=n&65535}}while(1){n=m+((z<<8)-49152)|0;c[e+76+(z+512<<2)>>2]=n;c[e+76+(z+768<<2)>>2]=n;n=y+1&65535;if((n&65535)>220){break}else{y=n;z=n&65535}}m=c[2443404]|0;c[e+960>>2]=m;n=m+256|0;c[e+964>>2]=n;o=m+512|0;c[e+968>>2]=o;c[e+1984>>2]=m;c[e+1988>>2]=n;c[e+1992>>2]=o;c[e+3008>>2]=m;c[e+4032>>2]=m;c[e+3012>>2]=n;c[e+4036>>2]=n;c[e+3016>>2]=o;c[e+4040>>2]=o;o=c[2443450]|0;n=224;m=224;while(1){c[e+76+(m<<2)>>2]=o+((m<<8)-57344);p=n+1&65535;if((p&65535)>247){A=224;B=224;break}else{n=p;m=p&65535}}while(1){c[e+76+(B+256<<2)>>2]=o+((B<<8)-57344);m=A+1&65535;if((m&65535)>247){C=224;D=224;break}else{A=m;B=m&65535}}while(1){m=o+((D<<8)-57344)|0;c[e+76+(D+512<<2)>>2]=m;c[e+76+(D+768<<2)>>2]=m;m=C+1&65535;if((m&65535)>247){break}else{C=m;D=m&65535}}o=c[2439604]|0;c[e+1068>>2]=o;m=o+256|0;c[e+1072>>2]=m;c[e+2092>>2]=o;c[e+2096>>2]=m;c[e+3116>>2]=o;c[e+4140>>2]=o;c[e+3120>>2]=m;c[e+4144>>2]=m;m=c[3529150]|0;c[e+1084>>2]=m;o=m+256|0;c[e+1088>>2]=o;n=m+512|0;c[e+1092>>2]=n;p=m+768|0;c[e+1096>>2]=p;c[e+2108>>2]=m;c[e+2112>>2]=o;c[e+2116>>2]=n;c[e+2120>>2]=p;c[e+3132>>2]=m;c[e+4156>>2]=m;c[e+3136>>2]=o;c[e+4160>>2]=o;c[e+3140>>2]=n;c[e+4164>>2]=n;c[e+3144>>2]=p;c[e+4168>>2]=p;if(!i){p=e;gGC(p|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=k;c[2417276]=l;c[1836236]=-1;fwR(1);p=c[2439331]|0;n=(p|0)==0;if(!n){o=p;gGC(9706056,o|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];o=c[3528485]|0;c[2076596]=o;m=c[2417277]|0;c[3541536]=m;c[1836236]=1;E=c[3529106]|0;F=0;G=0;while(1){c[p+76+(G<<2)>>2]=E+(G<<8);H=F+1&65535;if((H&65535)>127){I=0;J=0;break}else{F=H;G=H&65535}}while(1){G=E+(J<<8)|0;c[p+76+(J+512<<2)>>2]=G;c[p+76+(J+768<<2)>>2]=G;G=I+1&65535;if((G&65535)>127){break}else{I=G;J=G&65535}}E=c[2443450]|0;G=224;F=224;while(1){c[p+76+(F<<2)>>2]=E+((F<<8)-57344);l=G+1&65535;if((l&65535)>247){K=224;L=224;break}else{G=l;F=l&65535}}while(1){c[p+76+(L+256<<2)>>2]=E+((L<<8)-57344);F=K+1&65535;if((F&65535)>247){M=224;N=224;break}else{K=F;L=F&65535}}while(1){F=E+((N<<8)-57344)|0;c[p+76+(N+512<<2)>>2]=F;c[p+76+(N+768<<2)>>2]=F;F=M+1&65535;if((F&65535)>247){break}else{M=F;N=F&65535}}if(!n){E=p;gGC(E|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=o;c[2417277]=m;c[1836236]=-1;fwR(2);E=c[2439332]|0;F=(E|0)==0;if(!F){G=E;gGC(9706056,G|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438120];G=c[3528486]|0;c[2076596]=G;l=c[2417278]|0;c[3541536]=l;c[1836236]=2;c[E+4180>>2]=3134;c[E+4184>>2]=3282;k=c[3529102]|0;e=0;i=0;while(1){c[E+76+(i<<2)>>2]=k+(i<<8);H=e+1&65535;if((H&65535)>127){O=0;P=0;break}else{e=H;i=H&65535}}while(1){i=k+(P<<8)|0;c[E+76+(P+512<<2)>>2]=i;c[E+76+(P+768<<2)>>2]=i;i=O+1&65535;if((i&65535)>127){break}else{O=i;P=i&65535}}k=c[3529138]|0;c[E+588>>2]=k;c[E+592>>2]=k+256;c[E+596>>2]=k+512;c[E+600>>2]=k+768;c[E+604>>2]=k+1024;c[E+608>>2]=k+1280;c[E+612>>2]=k+1536;c[E+616>>2]=k+1792;c[E+620>>2]=k+2048;c[E+624>>2]=k+2304;c[E+628>>2]=k+2560;c[E+632>>2]=k+2816;c[E+636>>2]=k+3072;c[E+640>>2]=k+3328;c[E+644>>2]=k+3584;c[E+648>>2]=k+3840;i=128;e=128;while(1){c[E+76+(e+256<<2)>>2]=k+((e<<8)-32768);m=i+1&65535;if((m&65535)>143){Q=128;R=128;break}else{i=m;e=m&65535}}while(1){e=k+((R<<8)-32768)|0;c[E+76+(R+512<<2)>>2]=e;c[E+76+(R+768<<2)>>2]=e;e=Q+1&65535;if((e&65535)>143){break}else{Q=e;R=e&65535}}if(!F){k=E;gGC(k|0,9706056,76)|0}c[2438120]=c[2433530];c[3528486]=G;c[2417278]=l;c[1836236]=-1;k=a[14109496]|0;if((k<<24>>24|0)==2){e=c[2387310]|0;i=c[2387312]|0;c[2424906]=682952;c[2443666]=2047;c[2385780]=7;c[3528996]=3;gGz(9702704,0,32);gGz(9703728,0,32);gGz(9704752,0,32);m=c[2427044]|0;c[9681616+(m<<3)>>2]=809328;c[9681620+(m<<3)>>2]=0;c[2427044]=m+1;m=2;while(1){o=i+((m<<3)-16)|0;c[9702704+(m<<2)>>2]=o;c[9703728+(m<<2)>>2]=o;c[9704752+(m<<2)>>2]=o;o=m+1|0;if((o|0)<16){m=o}else{S=16;break}}do{m=e+(S<<3)|0;c[9702704+(S<<2)>>2]=m;c[9704752+(S<<2)>>2]=m;S=S+1|0;}while((S|0)<256);c[3528586]=3404;c[2385590]=1124}else if((k<<24>>24|0)==1){fwj(4);e=c[2387310]|0;m=c[2437644]|0;i=240;l=240;while(1){G=e+((l<<8)-61440)|0;c[m+72+(l<<2)>>2]=G;c[m+72+(l+512<<2)>>2]=G;G=i+1&65535;if((G&65535)>255){break}else{i=G;l=G&65535}}c[m+3144>>2]=3500;c[m+3148>>2]=2642}Vr(1,3e6,1254,2888,90,0);c[2438228]=3e6;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=681;h[745419]=.25;a[3203368]=1;h[745418]=.25;a[3203360]=1;h[745417]=.25;a[3203352]=1;h[745416]=.25;a[3203344]=1;U6(3e6,0,3382,1);c[2438222]=6e6;c[2433520]=3416;c[2406670]=1752;c[3528466]=9362;c[2443840]=340;h[745399]=.5;a[3203272]=1;if((gD[c[2427022]&8191]()|0)!=0){T=1;return T|0}l=c[642608+(c[2436]<<2)>>2]|0;i=c[l+128>>2]|0;if((c[l+52>>2]&4|0)==0){c[2113068]=i;e=c[l+132>>2]|0;c[2113070]=e;c[2443814]=i;c[2440436]=e;U=i;V=e}else{c[2113070]=i;e=c[l+132>>2]|0;c[2113068]=e;c[2440436]=i;c[2443814]=e;U=e;V=i}i=ag(U<<1,V)|0;e=gGq(i)|0;c[2112926]=e;if((e|0)!=0){gGz(e|0,0,i|0)}eZY();T=0;return T|0}}while(0);c[2426672]=0;T=1;return T|0}function eZX(a){a=a|0;var b=0,d=0;b=(c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,6e6,0)|0;return a|0}function eZY(){var e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=c[2439330]|0;f=(e|0)==0;if(!f){g=e;gGC(9706056,g|0,76)|0}g=c[2438118]|0;c[2433530]=g;i=c[3528484]|0;c[2076596]=i;j=c[2417276]|0;c[3541536]=j;c[1836236]=0;gGz(9706056,0,76);if(!f){f=e;gGC(f|0,9706056,76)|0}c[2438118]=g;c[3528484]=i;c[2417276]=j;c[1836236]=-1;j=c[2439331]|0;i=(j|0)==0;if(!i){g=j;gGC(9706056,g|0,76)|0}g=c[2438119]|0;c[2433530]=g;f=c[3528485]|0;c[2076596]=f;e=c[2417277]|0;c[3541536]=e;c[1836236]=1;gGz(9706056,0,76);if(!i){i=j;gGC(i|0,9706056,76)|0}c[2438119]=g;c[3528485]=f;c[2417277]=e;c[1836236]=-1;e=c[2439332]|0;f=(e|0)==0;if(!f){g=e;gGC(9706056,g|0,76)|0}g=c[2438120]|0;c[2433530]=g;i=c[3528486]|0;c[2076596]=i;j=c[2417278]|0;c[3541536]=j;c[1836236]=2;gGz(9706056,0,76);if(!f){f=e;gGC(f|0,9706056,76)|0}c[2438120]=g;c[3528486]=i;c[2417278]=j;c[1836236]=-1;j=a[14109496]|0;if((j<<24>>24|0)==1){a[9660900]=a[9660900]|16;i=c[2437644]|0;g=c[i+1092>>2]|0;do{if((g|0)==0){f=c[i+3144>>2]|0;if((f|0)==0){k=0;l=0;break}e=gj[f&4095](-2)|0;f=c[2437644]|0;m=c[f+1092>>2]|0;n=(e&255)<<8;if((m|0)!=0){o=m;p=n;q=34768;break}m=c[f+3144>>2]|0;if((m|0)==0){k=0;l=n;break}k=gj[m&4095](-1)|0;l=n}else{o=g;p=(d[g+254|0]|0)<<8;q=34768}}while(0);if((q|0)==34768){k=a[o+255|0]|0;l=p}p=k&255|l;c[2415221]=p;b[4830442]=p&65535;a[9660920]=0;a[9660921]=0;a[9660928]=0;a[9660930]=0;a[9660931]=0;c[2415234]=0;gGz(9660901,0,5);c[2415235]=65535;c[2415237]=65535;a[9660932]=a[9660932]|64}else if((j<<24>>24|0)==2){f42();a[8451544]=0;a[8451536]=0;a[9533800]=0;a[8451528]=0;a[8451520]=0;a[9533792]=0;a[8451512]=0;a[8451504]=0;a[9533784]=0;a[9533352]=0;a[9533344]=0;c[2161338]=0;c[2161344]=0}c[2443825]=1073676288;c[2443824]=1073676288;c[2443817]=1073676288;c[2443816]=1073676288;h[883199]=0.0;c[3528506]=0;lw(c[3540986]|0);c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){r=0}else{a[14119312]=0;a[9730856]=0;a[9730848]=0;a[9774056]=0;a[9754904]=0;a[9759704]=0;c[2418504]=0;c[2418502]=0;c[2438752]=0;c[2432710]=0;c[2430226]=0;c[2439538]=0;c[2385564]=0;c[2444152]=0;return}do{lN(r);mB(r);r=r+1|0;}while((r|0)<(c[2385508]|0));a[14119312]=0;a[9730856]=0;a[9730848]=0;a[9774056]=0;a[9754904]=0;a[9759704]=0;c[2418504]=0;c[2418502]=0;c[2438752]=0;c[2432710]=0;c[2430226]=0;c[2439538]=0;c[2385564]=0;c[2444152]=0;return}function eZZ(){a[8451504]=a[9625336]|0;a[9533784]=-1;return}function eZ_(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0;b=i;i=i+2280|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;l=b+360|0;m=b+472|0;n=b+480|0;o=b+592|0;p=b+600|0;q=b+712|0;r=b+720|0;s=b+832|0;t=b+840|0;u=b+952|0;v=b+960|0;w=b+1072|0;x=b+1080|0;y=b+1192|0;z=b+1200|0;A=b+1312|0;B=b+1320|0;C=b+1432|0;D=b+1440|0;E=b+1552|0;F=b+1560|0;G=b+1672|0;H=b+1680|0;I=b+1792|0;J=b+1800|0;K=b+1912|0;L=b+1920|0;M=b+2032|0;N=b+2040|0;O=b+2152|0;P=b+2160|0;Q=b+2272|0;R=0;while(1){if((R|0)>=1024){S=0;break}T=9638528+(R<<2)|0;if((c[T>>2]|0)==0){U=34782;break}else{R=R+1|0}}do{if((U|0)==34782){R=gGq(524288)|0;c[T>>2]=R;if((R|0)==0){S=0;break}gGz(R|0,0,524288);S=R}}while(0);c[3529514]=S;S=c[3529120]|0;if((c[3542200]|0)==0){V=1;i=b;return V|0}T=P+108|0;c[T>>2]=0;R=P+100|0;c[R>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](P,0)|0;do{if((c[T>>2]|0)!=0){P=c[R>>2]|0;c[Q>>2]=9534384;W=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[W&16383](Q,0,0)|0;if((P|0)<1){V=1;i=b;return V|0}if((gzL(S,0,0)|0)==0){break}else{V=1}i=b;return V|0}}while(0);S=(c[3529120]|0)+65536|0;if((c[3542200]|0)==0){V=1;i=b;return V|0}Q=N+108|0;c[Q>>2]=0;R=N+100|0;c[R>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](N,1)|0;do{if((c[Q>>2]|0)!=0){N=c[R>>2]|0;c[O>>2]=9534384;T=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[T&16383](O,1,0)|0;if((N|0)<1){V=1;i=b;return V|0}if((gzL(S,0,1)|0)==0){break}else{V=1}i=b;return V|0}}while(0);S=(c[3529120]|0)+98304|0;if((c[3542200]|0)==0){V=1;i=b;return V|0}O=L+108|0;c[O>>2]=0;R=L+100|0;c[R>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](L,2)|0;do{if((c[O>>2]|0)!=0){L=c[R>>2]|0;c[M>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](M,2,0)|0;if((L|0)<1){V=1;i=b;return V|0}if((gzL(S,0,2)|0)==0){break}else{V=1}i=b;return V|0}}while(0);S=c[3529106]|0;if((c[3542200]|0)==0){V=1;i=b;return V|0}M=J+108|0;c[M>>2]=0;R=J+100|0;c[R>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](J,3)|0;do{if((c[M>>2]|0)!=0){J=c[R>>2]|0;c[K>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](K,3,0)|0;if((J|0)<1){V=1;i=b;return V|0}if((gzL(S,0,3)|0)==0){break}else{V=1}i=b;return V|0}}while(0);S=c[3529102]|0;if((c[3542200]|0)==0){V=1;i=b;return V|0}K=H+108|0;c[K>>2]=0;R=H+100|0;c[R>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](H,4)|0;do{if((c[K>>2]|0)!=0){H=c[R>>2]|0;c[I>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](I,4,0)|0;if((H|0)<1){V=1;i=b;return V|0}if((gzL(S,0,4)|0)==0){break}else{V=1}i=b;return V|0}}while(0);S=c[3529514]|0;if((c[3542200]|0)==0){V=1;i=b;return V|0}I=F+108|0;c[I>>2]=0;R=F+100|0;c[R>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](F,5)|0;do{if((c[I>>2]|0)!=0){F=c[R>>2]|0;c[G>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](G,5,0)|0;if((F|0)<1){V=1;i=b;return V|0}if((gzL(S,0,5)|0)==0){break}else{V=1}i=b;return V|0}}while(0);S=(c[3529514]|0)+32768|0;if((c[3542200]|0)==0){V=1;i=b;return V|0}G=D+108|0;c[G>>2]=0;R=D+100|0;c[R>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](D,6)|0;do{if((c[G>>2]|0)!=0){D=c[R>>2]|0;c[E>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](E,6,0)|0;if((D|0)<1){V=1;i=b;return V|0}if((gzL(S,0,6)|0)==0){break}else{V=1}i=b;return V|0}}while(0);S=(c[3529514]|0)+65536|0;if((c[3542200]|0)==0){V=1;i=b;return V|0}E=B+108|0;c[E>>2]=0;R=B+100|0;c[R>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](B,7)|0;do{if((c[E>>2]|0)!=0){B=c[R>>2]|0;c[C>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](C,7,0)|0;if((B|0)<1){V=1;i=b;return V|0}if((gzL(S,0,7)|0)==0){break}else{V=1}i=b;return V|0}}while(0);S=(c[3529514]|0)+98304|0;if((c[3542200]|0)==0){V=1;i=b;return V|0}C=z+108|0;c[C>>2]=0;R=z+100|0;c[R>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,8)|0;do{if((c[C>>2]|0)!=0){z=c[R>>2]|0;c[A>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](A,8,0)|0;if((z|0)<1){V=1;i=b;return V|0}if((gzL(S,0,8)|0)==0){break}else{V=1}i=b;return V|0}}while(0);S=(c[3529514]|0)+131072|0;if((c[3542200]|0)==0){V=1;i=b;return V|0}A=x+108|0;c[A>>2]=0;R=x+100|0;c[R>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,9)|0;do{if((c[A>>2]|0)!=0){x=c[R>>2]|0;c[y>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](y,9,0)|0;if((x|0)<1){V=1;i=b;return V|0}if((gzL(S,0,9)|0)==0){break}else{V=1}i=b;return V|0}}while(0);S=(c[3529514]|0)+163840|0;if((c[3542200]|0)==0){V=1;i=b;return V|0}y=v+108|0;c[y>>2]=0;R=v+100|0;c[R>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,10)|0;do{if((c[y>>2]|0)!=0){v=c[R>>2]|0;c[w>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](w,10,0)|0;if((v|0)<1){V=1;i=b;return V|0}if((gzL(S,0,10)|0)==0){break}else{V=1}i=b;return V|0}}while(0);S=(c[3529514]|0)+262144|0;if((c[3542200]|0)==0){V=1;i=b;return V|0}w=t+108|0;c[w>>2]=0;R=t+100|0;c[R>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,11)|0;do{if((c[w>>2]|0)!=0){t=c[R>>2]|0;c[u>>2]=9534384;y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[y&16383](u,11,0)|0;if((t|0)<1){V=1;i=b;return V|0}if((gzL(S,0,11)|0)==0){break}else{V=1}i=b;return V|0}}while(0);S=(c[3529514]|0)+294912|0;if((c[3542200]|0)==0){V=1;i=b;return V|0}u=r+108|0;c[u>>2]=0;R=r+100|0;c[R>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,12)|0;do{if((c[u>>2]|0)!=0){r=c[R>>2]|0;c[s>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](s,12,0)|0;if((r|0)<1){V=1;i=b;return V|0}if((gzL(S,0,12)|0)==0){break}else{V=1}i=b;return V|0}}while(0);S=(c[3529514]|0)+327680|0;if((c[3542200]|0)==0){V=1;i=b;return V|0}s=p+108|0;c[s>>2]=0;R=p+100|0;c[R>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,13)|0;do{if((c[s>>2]|0)!=0){p=c[R>>2]|0;c[q>>2]=9534384;u=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[u&16383](q,13,0)|0;if((p|0)<1){V=1;i=b;return V|0}if((gzL(S,0,13)|0)==0){break}else{V=1}i=b;return V|0}}while(0);S=(c[3529514]|0)+360448|0;if((c[3542200]|0)==0){V=1;i=b;return V|0}q=n+108|0;c[q>>2]=0;R=n+100|0;c[R>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,14)|0;do{if((c[q>>2]|0)!=0){n=c[R>>2]|0;c[o>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](o,14,0)|0;if((n|0)<1){V=1;i=b;return V|0}if((gzL(S,0,14)|0)==0){break}else{V=1}i=b;return V|0}}while(0);S=(c[3529514]|0)+393216|0;if((c[3542200]|0)==0){V=1;i=b;return V|0}o=l+108|0;c[o>>2]=0;R=l+100|0;c[R>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,15)|0;do{if((c[o>>2]|0)!=0){l=c[R>>2]|0;c[m>>2]=9534384;q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[q&16383](m,15,0)|0;if((l|0)<1){V=1;i=b;return V|0}if((gzL(S,0,15)|0)==0){break}else{V=1}i=b;return V|0}}while(0);S=(c[3529514]|0)+425984|0;if((c[3542200]|0)==0){V=1;i=b;return V|0}m=j+108|0;c[m>>2]=0;R=j+100|0;c[R>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,16)|0;do{if((c[m>>2]|0)!=0){j=c[R>>2]|0;c[k>>2]=9534384;o=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[o&16383](k,16,0)|0;if((j|0)<1){V=1;i=b;return V|0}if((gzL(S,0,16)|0)==0){break}else{V=1}i=b;return V|0}}while(0);S=c[3529514]|0;k=0;do{R=S+k|0;a[R]=~a[R];k=k+1|0;}while((k|0)<524288);k=c[2405804]|0;R=0;do{m=R<<6;gGz(k+m|0,0,64);j=R<<7;o=0;do{l=1<<3-o;q=(c[1658e3+(o<<2)>>2]|0)+j|0;n=0;do{s=q+(c[6669224+(n<<2)>>2]|0)|0;p=(n<<3)+m|0;u=0;do{r=s+(c[6669320+(u<<2)>>2]|0)|0;if(((d[S+((r|0)/8|0)|0]|0)&128>>>((r&7)>>>0)|0)!=0){r=k+(p+u)|0;a[r]=(d[r]|0|l)&255}u=u+1|0;}while((u|0)<8);n=n+1|0;}while((n|0)<8);o=o+1|0;}while((o|0)<4);R=R+1|0;}while((R|0)<16384);R=c[2407132]|0;if((c[3542200]|0)==0){V=1;i=b;return V|0}k=g+108|0;c[k>>2]=0;S=g+100|0;c[S>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,17)|0;do{if((c[k>>2]|0)!=0){g=c[S>>2]|0;c[h>>2]=9534384;o=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[o&16383](h,17,0)|0;if((g|0)<1){V=1;i=b;return V|0}if((gzL(R,0,17)|0)==0){break}else{V=1}i=b;return V|0}}while(0);R=c[2387310]|0;if((c[3542200]|0)==0){V=1;i=b;return V|0}h=e+108|0;c[h>>2]=0;S=e+100|0;c[S>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,18)|0;do{if((c[h>>2]|0)!=0){e=c[S>>2]|0;c[f>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](f,18,0)|0;if((e|0)<1){V=1;i=b;return V|0}if((gzL(R,0,18)|0)==0){break}else{V=1}i=b;return V|0}}while(0);R=c[3529514]|0;f=0;while(1){if((f|0)>=1024){break}X=9638528+(f<<2)|0;if((c[X>>2]|0)==(R|0)){U=34875;break}else{f=f+1|0}}if((U|0)==34875){gGr(R);c[X>>2]=0}c[3529514]=0;V=0;i=b;return V|0}function eZ$(){var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;e=i;i=i+2160|0;f=e|0;g=e+112|0;h=e+120|0;j=e+232|0;k=e+240|0;l=e+352|0;m=e+360|0;n=e+472|0;o=e+480|0;p=e+592|0;q=e+600|0;r=e+712|0;s=e+720|0;t=e+832|0;u=e+840|0;v=e+952|0;w=e+960|0;x=e+1072|0;y=e+1080|0;z=e+1192|0;A=e+1200|0;B=e+1312|0;C=e+1320|0;D=e+1432|0;E=e+1440|0;F=e+1552|0;G=e+1560|0;H=e+1672|0;I=e+1680|0;J=e+1792|0;K=e+1800|0;L=e+1912|0;M=e+1920|0;N=e+2032|0;O=e+2040|0;P=e+2152|0;Q=0;while(1){if((Q|0)>=1024){R=0;break}S=9638528+(Q<<2)|0;if((c[S>>2]|0)==0){T=34939;break}else{Q=Q+1|0}}do{if((T|0)==34939){Q=gGq(524288)|0;c[S>>2]=Q;if((Q|0)==0){R=0;break}gGz(Q|0,0,524288);R=Q}}while(0);c[3529514]=R;R=c[3529120]|0;if((c[3542200]|0)==0){U=1;i=e;return U|0}S=O+108|0;c[S>>2]=0;Q=O+100|0;c[Q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](O,0)|0;do{if((c[S>>2]|0)!=0){O=c[Q>>2]|0;c[P>>2]=9534384;V=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[V&16383](P,0,0)|0;if((O|0)<1){U=1;i=e;return U|0}if((gzL(R,0,0)|0)==0){break}else{U=1}i=e;return U|0}}while(0);R=(c[3529120]|0)+65536|0;if((c[3542200]|0)==0){U=1;i=e;return U|0}P=M+108|0;c[P>>2]=0;Q=M+100|0;c[Q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](M,1)|0;do{if((c[P>>2]|0)!=0){M=c[Q>>2]|0;c[N>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](N,1,0)|0;if((M|0)<1){U=1;i=e;return U|0}if((gzL(R,0,1)|0)==0){break}else{U=1}i=e;return U|0}}while(0);R=(c[3529120]|0)+98304|0;if((c[3542200]|0)==0){U=1;i=e;return U|0}N=K+108|0;c[N>>2]=0;Q=K+100|0;c[Q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](K,2)|0;do{if((c[N>>2]|0)!=0){K=c[Q>>2]|0;c[L>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](L,2,0)|0;if((K|0)<1){U=1;i=e;return U|0}if((gzL(R,0,2)|0)==0){break}else{U=1}i=e;return U|0}}while(0);R=c[3529106]|0;if((c[3542200]|0)==0){U=1;i=e;return U|0}L=I+108|0;c[L>>2]=0;Q=I+100|0;c[Q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](I,3)|0;do{if((c[L>>2]|0)!=0){I=c[Q>>2]|0;c[J>>2]=9534384;N=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[N&16383](J,3,0)|0;if((I|0)<1){U=1;i=e;return U|0}if((gzL(R,0,3)|0)==0){break}else{U=1}i=e;return U|0}}while(0);R=c[3529102]|0;if((c[3542200]|0)==0){U=1;i=e;return U|0}J=G+108|0;c[J>>2]=0;Q=G+100|0;c[Q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](G,4)|0;do{if((c[J>>2]|0)!=0){G=c[Q>>2]|0;c[H>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](H,4,0)|0;if((G|0)<1){U=1;i=e;return U|0}if((gzL(R,0,4)|0)==0){break}else{U=1}i=e;return U|0}}while(0);R=c[3529514]|0;if((c[3542200]|0)==0){U=1;i=e;return U|0}H=E+108|0;c[H>>2]=0;Q=E+100|0;c[Q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](E,5)|0;do{if((c[H>>2]|0)!=0){E=c[Q>>2]|0;c[F>>2]=9534384;J=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[J&16383](F,5,0)|0;if((E|0)<1){U=1;i=e;return U|0}if((gzL(R,0,5)|0)==0){break}else{U=1}i=e;return U|0}}while(0);R=(c[3529514]|0)+32768|0;if((c[3542200]|0)==0){U=1;i=e;return U|0}F=C+108|0;c[F>>2]=0;Q=C+100|0;c[Q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](C,6)|0;do{if((c[F>>2]|0)!=0){C=c[Q>>2]|0;c[D>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](D,6,0)|0;if((C|0)<1){U=1;i=e;return U|0}if((gzL(R,0,6)|0)==0){break}else{U=1}i=e;return U|0}}while(0);R=(c[3529514]|0)+65536|0;if((c[3542200]|0)==0){U=1;i=e;return U|0}D=A+108|0;c[D>>2]=0;Q=A+100|0;c[Q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](A,7)|0;do{if((c[D>>2]|0)!=0){A=c[Q>>2]|0;c[B>>2]=9534384;F=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[F&16383](B,7,0)|0;if((A|0)<1){U=1;i=e;return U|0}if((gzL(R,0,7)|0)==0){break}else{U=1}i=e;return U|0}}while(0);R=(c[3529514]|0)+98304|0;if((c[3542200]|0)==0){U=1;i=e;return U|0}B=y+108|0;c[B>>2]=0;Q=y+100|0;c[Q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](y,8)|0;do{if((c[B>>2]|0)!=0){y=c[Q>>2]|0;c[z>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](z,8,0)|0;if((y|0)<1){U=1;i=e;return U|0}if((gzL(R,0,8)|0)==0){break}else{U=1}i=e;return U|0}}while(0);R=(c[3529514]|0)+131072|0;if((c[3542200]|0)==0){U=1;i=e;return U|0}z=w+108|0;c[z>>2]=0;Q=w+100|0;c[Q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](w,9)|0;do{if((c[z>>2]|0)!=0){w=c[Q>>2]|0;c[x>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](x,9,0)|0;if((w|0)<1){U=1;i=e;return U|0}if((gzL(R,0,9)|0)==0){break}else{U=1}i=e;return U|0}}while(0);R=(c[3529514]|0)+163840|0;if((c[3542200]|0)==0){U=1;i=e;return U|0}x=u+108|0;c[x>>2]=0;Q=u+100|0;c[Q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](u,10)|0;do{if((c[x>>2]|0)!=0){u=c[Q>>2]|0;c[v>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](v,10,0)|0;if((u|0)<1){U=1;i=e;return U|0}if((gzL(R,0,10)|0)==0){break}else{U=1}i=e;return U|0}}while(0);R=(c[3529514]|0)+262144|0;if((c[3542200]|0)==0){U=1;i=e;return U|0}v=s+108|0;c[v>>2]=0;Q=s+100|0;c[Q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](s,11)|0;do{if((c[v>>2]|0)!=0){s=c[Q>>2]|0;c[t>>2]=9534384;x=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[x&16383](t,11,0)|0;if((s|0)<1){U=1;i=e;return U|0}if((gzL(R,0,11)|0)==0){break}else{U=1}i=e;return U|0}}while(0);R=(c[3529514]|0)+294912|0;if((c[3542200]|0)==0){U=1;i=e;return U|0}t=q+108|0;c[t>>2]=0;Q=q+100|0;c[Q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](q,12)|0;do{if((c[t>>2]|0)!=0){q=c[Q>>2]|0;c[r>>2]=9534384;v=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[v&16383](r,12,0)|0;if((q|0)<1){U=1;i=e;return U|0}if((gzL(R,0,12)|0)==0){break}else{U=1}i=e;return U|0}}while(0);R=(c[3529514]|0)+327680|0;if((c[3542200]|0)==0){U=1;i=e;return U|0}r=o+108|0;c[r>>2]=0;Q=o+100|0;c[Q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](o,13)|0;do{if((c[r>>2]|0)!=0){o=c[Q>>2]|0;c[p>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](p,13,0)|0;if((o|0)<1){U=1;i=e;return U|0}if((gzL(R,0,13)|0)==0){break}else{U=1}i=e;return U|0}}while(0);R=(c[3529514]|0)+360448|0;if((c[3542200]|0)==0){U=1;i=e;return U|0}p=m+108|0;c[p>>2]=0;Q=m+100|0;c[Q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,14)|0;do{if((c[p>>2]|0)!=0){m=c[Q>>2]|0;c[n>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](n,14,0)|0;if((m|0)<1){U=1;i=e;return U|0}if((gzL(R,0,14)|0)==0){break}else{U=1}i=e;return U|0}}while(0);R=(c[3529514]|0)+393216|0;if((c[3542200]|0)==0){U=1;i=e;return U|0}n=k+108|0;c[n>>2]=0;Q=k+100|0;c[Q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,15)|0;do{if((c[n>>2]|0)!=0){k=c[Q>>2]|0;c[l>>2]=9534384;p=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[p&16383](l,15,0)|0;if((k|0)<1){U=1;i=e;return U|0}if((gzL(R,0,15)|0)==0){break}else{U=1}i=e;return U|0}}while(0);R=(c[3529514]|0)+425984|0;if((c[3542200]|0)==0){U=1;i=e;return U|0}l=h+108|0;c[l>>2]=0;Q=h+100|0;c[Q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](h,16)|0;do{if((c[l>>2]|0)!=0){h=c[Q>>2]|0;c[j>>2]=9534384;n=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[n&16383](j,16,0)|0;if((h|0)<1){U=1;i=e;return U|0}if((gzL(R,0,16)|0)==0){break}else{U=1}i=e;return U|0}}while(0);R=c[3529514]|0;j=0;do{Q=R+j|0;a[Q]=~a[Q];j=j+1|0;}while((j|0)<524288);j=c[2405804]|0;Q=0;do{l=Q<<6;gGz(j+l|0,0,64);h=Q<<7;n=0;do{k=1<<3-n;p=(c[1658e3+(n<<2)>>2]|0)+h|0;m=0;do{r=p+(c[6669224+(m<<2)>>2]|0)|0;o=(m<<3)+l|0;t=0;do{q=r+(c[6669320+(t<<2)>>2]|0)|0;if(((d[R+((q|0)/8|0)|0]|0)&128>>>((q&7)>>>0)|0)!=0){q=j+(o+t)|0;a[q]=(d[q]|0|k)&255}t=t+1|0;}while((t|0)<8);m=m+1|0;}while((m|0)<8);n=n+1|0;}while((n|0)<4);Q=Q+1|0;}while((Q|0)<16384);Q=c[2407132]|0;if((c[3542200]|0)==0){U=1;i=e;return U|0}j=f+108|0;c[j>>2]=0;R=f+100|0;c[R>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,17)|0;do{if((c[j>>2]|0)!=0){f=c[R>>2]|0;c[g>>2]=9534384;n=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[n&16383](g,17,0)|0;if((f|0)<1){U=1;i=e;return U|0}if((gzL(Q,0,17)|0)==0){break}else{U=1}i=e;return U|0}}while(0);Q=c[3529514]|0;g=0;while(1){if((g|0)>=1024){break}W=9638528+(g<<2)|0;if((c[W>>2]|0)==(Q|0)){T=35028;break}else{g=g+1|0}}if((T|0)==35028){gGr(Q);c[W>>2]=0}c[3529514]=0;W=c[2439330]|0;Q=(W|0)==0;if(!Q){T=W;gGC(9706056,T|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];T=c[3528484]|0;c[2076596]=T;g=c[2417276]|0;c[3541536]=g;c[1836236]=0;c[W+4180>>2]=602;c[W+4184>>2]=1302;R=W+1092|0;c[R>>2]=0;c[R+4>>2]=0;R=W+2116|0;c[R>>2]=0;c[R+4>>2]=0;c[W+3140>>2]=0;c[W+4164>>2]=0;c[W+3144>>2]=0;c[W+4168>>2]=0;if(!Q){Q=W;gGC(Q|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=T;c[2417276]=g;c[1836236]=-1;U=0;i=e;return U|0}function eZ0(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;b=i;i=i+2160|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;l=b+360|0;m=b+472|0;n=b+480|0;o=b+592|0;p=b+600|0;q=b+712|0;r=b+720|0;s=b+832|0;t=b+840|0;u=b+952|0;v=b+960|0;w=b+1072|0;x=b+1080|0;y=b+1192|0;z=b+1200|0;A=b+1312|0;B=b+1320|0;C=b+1432|0;D=b+1440|0;E=b+1552|0;F=b+1560|0;G=b+1672|0;H=b+1680|0;I=b+1792|0;J=b+1800|0;K=b+1912|0;L=b+1920|0;M=b+2032|0;N=b+2040|0;O=b+2152|0;P=0;while(1){if((P|0)>=1024){Q=0;break}R=9638528+(P<<2)|0;if((c[R>>2]|0)==0){S=35093;break}else{P=P+1|0}}do{if((S|0)==35093){P=gGq(524288)|0;c[R>>2]=P;if((P|0)==0){Q=0;break}gGz(P|0,0,524288);Q=P}}while(0);c[3529514]=Q;Q=c[3529120]|0;if((c[3542200]|0)==0){T=1;i=b;return T|0}R=N+108|0;c[R>>2]=0;P=N+100|0;c[P>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](N,0)|0;do{if((c[R>>2]|0)!=0){N=c[P>>2]|0;c[O>>2]=9534384;U=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[U&16383](O,0,0)|0;if((N|0)<1){T=1;i=b;return T|0}if((gzL(Q,0,0)|0)==0){break}else{T=1}i=b;return T|0}}while(0);Q=(c[3529120]|0)+65536|0;if((c[3542200]|0)==0){T=1;i=b;return T|0}O=L+108|0;c[O>>2]=0;P=L+100|0;c[P>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](L,1)|0;do{if((c[O>>2]|0)!=0){L=c[P>>2]|0;c[M>>2]=9534384;R=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[R&16383](M,1,0)|0;if((L|0)<1){T=1;i=b;return T|0}if((gzL(Q,0,1)|0)==0){break}else{T=1}i=b;return T|0}}while(0);Q=c[3529106]|0;if((c[3542200]|0)==0){T=1;i=b;return T|0}M=J+108|0;c[M>>2]=0;P=J+100|0;c[P>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](J,2)|0;do{if((c[M>>2]|0)!=0){J=c[P>>2]|0;c[K>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](K,2,0)|0;if((J|0)<1){T=1;i=b;return T|0}if((gzL(Q,0,2)|0)==0){break}else{T=1}i=b;return T|0}}while(0);Q=c[3529102]|0;if((c[3542200]|0)==0){T=1;i=b;return T|0}K=H+108|0;c[K>>2]=0;P=H+100|0;c[P>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](H,3)|0;do{if((c[K>>2]|0)!=0){H=c[P>>2]|0;c[I>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](I,3,0)|0;if((H|0)<1){T=1;i=b;return T|0}if((gzL(Q,0,3)|0)==0){break}else{T=1}i=b;return T|0}}while(0);Q=c[2387310]|0;if((c[3542200]|0)==0){T=1;i=b;return T|0}I=F+108|0;c[I>>2]=0;P=F+100|0;c[P>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](F,4)|0;do{if((c[I>>2]|0)!=0){F=c[P>>2]|0;c[G>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](G,4,0)|0;if((F|0)<1){T=1;i=b;return T|0}if((gzL(Q,0,4)|0)==0){break}else{T=1}i=b;return T|0}}while(0);Q=c[3529514]|0;if((c[3542200]|0)==0){T=1;i=b;return T|0}G=D+108|0;c[G>>2]=0;P=D+100|0;c[P>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](D,5)|0;do{if((c[G>>2]|0)!=0){D=c[P>>2]|0;c[E>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](E,5,0)|0;if((D|0)<1){T=1;i=b;return T|0}if((gzL(Q,0,5)|0)==0){break}else{T=1}i=b;return T|0}}while(0);Q=(c[3529514]|0)+32768|0;if((c[3542200]|0)==0){T=1;i=b;return T|0}E=B+108|0;c[E>>2]=0;P=B+100|0;c[P>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](B,6)|0;do{if((c[E>>2]|0)!=0){B=c[P>>2]|0;c[C>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](C,6,0)|0;if((B|0)<1){T=1;i=b;return T|0}if((gzL(Q,0,6)|0)==0){break}else{T=1}i=b;return T|0}}while(0);Q=(c[3529514]|0)+65536|0;if((c[3542200]|0)==0){T=1;i=b;return T|0}C=z+108|0;c[C>>2]=0;P=z+100|0;c[P>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,7)|0;do{if((c[C>>2]|0)!=0){z=c[P>>2]|0;c[A>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](A,7,0)|0;if((z|0)<1){T=1;i=b;return T|0}if((gzL(Q,0,7)|0)==0){break}else{T=1}i=b;return T|0}}while(0);Q=(c[3529514]|0)+98304|0;if((c[3542200]|0)==0){T=1;i=b;return T|0}A=x+108|0;c[A>>2]=0;P=x+100|0;c[P>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,8)|0;do{if((c[A>>2]|0)!=0){x=c[P>>2]|0;c[y>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](y,8,0)|0;if((x|0)<1){T=1;i=b;return T|0}if((gzL(Q,0,8)|0)==0){break}else{T=1}i=b;return T|0}}while(0);Q=(c[3529514]|0)+131072|0;if((c[3542200]|0)==0){T=1;i=b;return T|0}y=v+108|0;c[y>>2]=0;P=v+100|0;c[P>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,9)|0;do{if((c[y>>2]|0)!=0){v=c[P>>2]|0;c[w>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](w,9,0)|0;if((v|0)<1){T=1;i=b;return T|0}if((gzL(Q,0,9)|0)==0){break}else{T=1}i=b;return T|0}}while(0);Q=(c[3529514]|0)+163840|0;if((c[3542200]|0)==0){T=1;i=b;return T|0}w=t+108|0;c[w>>2]=0;P=t+100|0;c[P>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,10)|0;do{if((c[w>>2]|0)!=0){t=c[P>>2]|0;c[u>>2]=9534384;y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[y&16383](u,10,0)|0;if((t|0)<1){T=1;i=b;return T|0}if((gzL(Q,0,10)|0)==0){break}else{T=1}i=b;return T|0}}while(0);Q=(c[3529514]|0)+262144|0;if((c[3542200]|0)==0){T=1;i=b;return T|0}u=r+108|0;c[u>>2]=0;P=r+100|0;c[P>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,11)|0;do{if((c[u>>2]|0)!=0){r=c[P>>2]|0;c[s>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](s,11,0)|0;if((r|0)<1){T=1;i=b;return T|0}if((gzL(Q,0,11)|0)==0){break}else{T=1}i=b;return T|0}}while(0);Q=(c[3529514]|0)+294912|0;if((c[3542200]|0)==0){T=1;i=b;return T|0}s=p+108|0;c[s>>2]=0;P=p+100|0;c[P>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,12)|0;do{if((c[s>>2]|0)!=0){p=c[P>>2]|0;c[q>>2]=9534384;u=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[u&16383](q,12,0)|0;if((p|0)<1){T=1;i=b;return T|0}if((gzL(Q,0,12)|0)==0){break}else{T=1}i=b;return T|0}}while(0);Q=(c[3529514]|0)+327680|0;if((c[3542200]|0)==0){T=1;i=b;return T|0}q=n+108|0;c[q>>2]=0;P=n+100|0;c[P>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,13)|0;do{if((c[q>>2]|0)!=0){n=c[P>>2]|0;c[o>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](o,13,0)|0;if((n|0)<1){T=1;i=b;return T|0}if((gzL(Q,0,13)|0)==0){break}else{T=1}i=b;return T|0}}while(0);Q=(c[3529514]|0)+360448|0;if((c[3542200]|0)==0){T=1;i=b;return T|0}o=l+108|0;c[o>>2]=0;P=l+100|0;c[P>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,14)|0;do{if((c[o>>2]|0)!=0){l=c[P>>2]|0;c[m>>2]=9534384;q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[q&16383](m,14,0)|0;if((l|0)<1){T=1;i=b;return T|0}if((gzL(Q,0,14)|0)==0){break}else{T=1}i=b;return T|0}}while(0);Q=(c[3529514]|0)+393216|0;if((c[3542200]|0)==0){T=1;i=b;return T|0}m=j+108|0;c[m>>2]=0;P=j+100|0;c[P>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,15)|0;do{if((c[m>>2]|0)!=0){j=c[P>>2]|0;c[k>>2]=9534384;o=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[o&16383](k,15,0)|0;if((j|0)<1){T=1;i=b;return T|0}if((gzL(Q,0,15)|0)==0){break}else{T=1}i=b;return T|0}}while(0);Q=(c[3529514]|0)+425984|0;if((c[3542200]|0)==0){T=1;i=b;return T|0}k=g+108|0;c[k>>2]=0;P=g+100|0;c[P>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,16)|0;do{if((c[k>>2]|0)!=0){g=c[P>>2]|0;c[h>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](h,16,0)|0;if((g|0)<1){T=1;i=b;return T|0}if((gzL(Q,0,16)|0)==0){break}else{T=1}i=b;return T|0}}while(0);Q=c[3529514]|0;h=0;do{P=Q+h|0;a[P]=~a[P];h=h+1|0;}while((h|0)<524288);h=c[2405804]|0;P=0;do{k=P<<6;gGz(h+k|0,0,64);g=P<<7;m=0;do{j=1<<3-m;o=(c[1658e3+(m<<2)>>2]|0)+g|0;l=0;do{q=o+(c[6669224+(l<<2)>>2]|0)|0;n=(l<<3)+k|0;s=0;do{p=q+(c[6669320+(s<<2)>>2]|0)|0;if(((d[Q+((p|0)/8|0)|0]|0)&128>>>((p&7)>>>0)|0)!=0){p=h+(n+s)|0;a[p]=(d[p]|0|j)&255}s=s+1|0;}while((s|0)<8);l=l+1|0;}while((l|0)<8);m=m+1|0;}while((m|0)<4);P=P+1|0;}while((P|0)<16384);P=c[2407132]|0;if((c[3542200]|0)==0){T=1;i=b;return T|0}h=e+108|0;c[h>>2]=0;Q=e+100|0;c[Q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,17)|0;do{if((c[h>>2]|0)!=0){e=c[Q>>2]|0;c[f>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](f,17,0)|0;if((e|0)<1){T=1;i=b;return T|0}if((gzL(P,0,17)|0)==0){break}else{T=1}i=b;return T|0}}while(0);P=c[3529514]|0;f=0;while(1){if((f|0)>=1024){break}V=9638528+(f<<2)|0;if((c[V>>2]|0)==(P|0)){S=35182;break}else{f=f+1|0}}if((S|0)==35182){gGr(P);c[V>>2]=0}c[3529514]=0;T=0;i=b;return T|0}function eZ1(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;i=i+8|0;f=e|0;a[f]=d;switch(b&2047|0){case 5:{b=c[(c[2424906]|0)+16>>2]|0;if((b|0)==0){g=d}else{gf[b&2047](f);g=a[f]|0}a[9533792]=g;i=e;return};case 6:{g=c[(c[2424906]|0)+20>>2]|0;if((g|0)==0){h=d}else{gf[g&2047](f);h=a[f]|0}a[9533784]=h;i=e;return};case 2:{h=c[(c[2424906]|0)+8>>2]|0;if((h|0)==0){j=d}else{gf[h&2047](f);j=a[f]|0}a[8451504]=j;i=e;return};case 1:{j=c[(c[2424906]|0)+4>>2]|0;if((j|0)==0){k=d}else{gf[j&2047](f);k=a[f]|0}a[8451520]=k;i=e;return};case 0:{k=c[c[2424906]>>2]|0;if((k|0)==0){l=d}else{gf[k&2047](f);l=a[f]|0}a[8451536]=l;i=e;return};case 4:{l=c[(c[2424906]|0)+12>>2]|0;if((l|0)==0){m=d}else{gf[l&2047](f);m=a[f]|0}a[9533800]=m;i=e;return};default:{i=e;return}}}function eZ2(b){b=b|0;var d=0,e=0;d=b&2047;if((d|0)==2){b=c[(c[2424906]|0)+32>>2]|0;if((b|0)!=0){gu[b&16383]()}b=a[9533784]|0;e=a[8451512]&~b|b&a[8451504];return e|0}else if((d|0)==0){b=c[(c[2424906]|0)+24>>2]|0;if((b|0)!=0){gu[b&16383]()}b=a[9533800]|0;e=a[8451544]&~b|b&a[8451536];return e|0}else if((d|0)==1){d=c[(c[2424906]|0)+28>>2]|0;if((d|0)!=0){gu[d&16383]()}d=a[9533792]|0;e=a[8451528]&~d|d&a[8451520];return e|0}else{e=0;return e|0}return 0}function eZ3(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=i;i=i+224|0;d=b|0;e=b+16|0;f=b+32|0;g=b+48|0;h=b+64|0;j=b+80|0;k=b+96|0;l=b+112|0;m=b+128|0;n=b+144|0;o=b+160|0;p=b+176|0;q=b+192|0;r=b+208|0;if((a&96|0)==0){i=b;return}s=c[2415207]|0;if((a&64|0)!=0){gGz(d|0,0,12);c[d>>2]=9660800;c[d+4>>2]=76;c[d+12>>2]=162384;a=c[2076592]|0;gj[a&4095](d)|0}c[2415207]=s;gGz(r|0,0,12);c[r>>2]=8451544;c[r+4>>2]=1;c[r+12>>2]=197936;gj[c[2076592]&4095](r)|0;gGz(q|0,0,12);c[q>>2]=8451528;c[q+4>>2]=1;c[q+12>>2]=511352;gj[c[2076592]&4095](q)|0;gGz(p|0,0,12);c[p>>2]=8451512;c[p+4>>2]=1;c[p+12>>2]=394944;gj[c[2076592]&4095](p)|0;gGz(o|0,0,12);c[o>>2]=9533800;c[o+4>>2]=1;c[o+12>>2]=306552;gj[c[2076592]&4095](o)|0;gGz(n|0,0,12);c[n>>2]=9533792;c[n+4>>2]=1;c[n+12>>2]=233648;gj[c[2076592]&4095](n)|0;gGz(m|0,0,12);c[m>>2]=9533784;c[m+4>>2]=1;c[m+12>>2]=182264;gj[c[2076592]&4095](m)|0;gGz(l|0,0,12);c[l>>2]=8451536;c[l+4>>2]=1;c[l+12>>2]=146936;gj[c[2076592]&4095](l)|0;gGz(k|0,0,12);c[k>>2]=8451520;c[k+4>>2]=1;c[k+12>>2]=117560;gj[c[2076592]&4095](k)|0;gGz(j|0,0,12);c[j>>2]=8451504;c[j+4>>2]=1;c[j+12>>2]=92504;gj[c[2076592]&4095](j)|0;gGz(h|0,0,12);c[h>>2]=9533352;c[h+4>>2]=1;c[h+12>>2]=493800;gj[c[2076592]&4095](h)|0;gGz(g|0,0,12);c[g>>2]=9533344;c[g+4>>2]=1;c[g+12>>2]=481680;gj[c[2076592]&4095](g)|0;gGz(f|0,0,12);c[f>>2]=8645352;c[f+4>>2]=4;c[f+12>>2]=469144;gj[c[2076592]&4095](f)|0;gGz(e|0,0,12);c[e>>2]=8645376;c[e+4>>2]=4;c[e+12>>2]=457792;gj[c[2076592]&4095](e)|0;i=b;return}function eZ4(b){b=b|0;var d=0;d=a[9533792]|0;do{if((d&2)!=0){if((a[b]&2)!=0){break}if((a[8451520]&2)==0){break}a[8451544]=a[9533352]|0;if(!((c[2161344]|0)==0|(c[2415208]|0)==0)){c[2415208]=0}c[2161344]=0}}while(0);if((d&4)==0){return}if((a[b]&4)==0){return}if((a[8451520]&4)!=0){return}a[9533344]=a[8451536]|0;c[2161338]=1;return}function eZ5(){var b=0;a[8451512]=0;if((c[2161344]|0)==0){b=2}else{a[8451512]=1;b=3}if((c[2161338]|0)!=0){return}a[8451512]=b;return}function eZ6(){var d=0,e=0,f=0,g=0;if(a[7461104]|0){a[14109952]=0;a[9771792]=0}if(a[7461144]|0){gGz(c[2439440]|0,0,2048)}if(a[7461112]|0){gGz(c[2424896]|0,0,1024);gGz(c[2424897]|0,0,1024);gGz(c[2424898]|0,0,1024);gGz(c[2424899]|0,0,1024);gGz(c[2424900]|0,0,1024);gGz(c[2424901]|0,0,1024);gGz(c[2424902]|0,0,1024);gGz(c[2424903]|0,0,1024);c[2443344]=0;a[14109952]=0}if(a[7461136]|0){gGz(c[2406600]|0,0,8192);a[9774608]=0;a[9774624]=-4;a[9774616]=-1;a[14124928]=0;a[14124929]=0;a[818400]=1;a[818392]=1;a[818401]=1;a[818393]=1;a[14109952]=0;a[14124912]=0;a[9698784]=0;a[9698776]=0;a[9698768]=0}if(a[7461e3]|0){a[8310520]=0;a[8310504]=0;a[8310536]=0;a[8310512]=0}do{if(a[7461128]|0){d=c[3528994]|0;if((d|0)<=0){break}e=(d|0)>1?d:1;gGz(14108184,0,e<<4|0);d=e<<2;gGz(9553368,0,d|0);gGz(9553328,0,d|0);gGz(9543296,0,d|0);gGz(9543272,0,d|0)}}while(0);if(a[7461120]|0){c[3540974]=0}do{if(a[7461096]|0){d=c[2442930]|0;if((d|0)<=0){break}e=(d|0)>1?d:1;f=e<<2;gGz(9553376,0,f|0);gGz(9553336,0,f|0);gGz(9543304,0,f|0);gGz(9543280,0,f|0);gGz(14110008,0,f|0);gGz(14109976,0,f|0);gGz(9757584,0,f|0);gGz(9733208,0,f|0);gGz(14129136,0,f|0);gGz(14129208,1,e|0);gGz(14129128,1,e|0);gGz(14129200,1,e|0);e=0;do{f=14129152+(e<<4)|0;g=f|0;C=0;b[g>>1]=C&65535;b[g+2>>1]=C>>16;g=f+4|0;C=0;b[g>>1]=C&65535;b[g+2>>1]=C>>16;gGz(c[9753632+(e<<2)>>2]|0,0,16384);e=e+1|0;}while((e|0)<(d|0))}}while(0);if(a[7461088]|0){c[2439392]=0}if(a[7461080]|0){gGz(9540888,0,13)}if(a[7461064]|0){gGz(c[2429460]|0,0,262144);gGz(c[2430810]|0,0,1024);gGz(c[2430808]|0,0,1024);gGz(c[2429461]|0,0,262144);gGz(c[2430811]|0,0,1024);gGz(c[2430809]|0,0,1024);gGz(9733144,0,16);gGz(c[3532266]|0,0,65536);gGz(c[3532264]|0,0,2048);gGz(c[3532268]|0,0,262144);c[3528672]=0;c[2432956]=0}if(a[7461056]|0){d=9757552;c[d>>2]=0;c[d+4>>2]=0;a[9757560]=0}if(a[7461048]|0){d=9757536;c[d>>2]=0;c[d+4>>2]=0;c[3532252]=0}if(a[7461040]|0){gGz(14128984,0,16)}if(a[7461032]|0){d=9757536;c[d>>2]=0;c[d+4>>2]=0;c[3532252]=0}if(a[7461024]|0){gGz(c[2438406]|0,0,16384);gGz(14128936,0,24);gGz(9553392,0,16);gGz(9553352,0,16);c[3527506]=0;c[3527498]=0;c[2436808]=0;c[2430806]=0}if(a[7461016]|0){d=9757528;c[d>>2]=0;c[d+4>>2]=0}if(!(a[7461008]|0)){c[3531956]=0;return}d=9757520;c[d>>2]=0;c[d+4>>2]=0;c[3531956]=0;return}function eZ7(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0;d=i;i=i+1312|0;e=d|0;f=d+16|0;g=d+32|0;h=d+48|0;j=d+64|0;k=d+80|0;l=d+96|0;m=d+112|0;n=d+128|0;o=d+144|0;p=d+160|0;q=d+176|0;r=d+192|0;s=d+208|0;t=d+224|0;u=d+240|0;v=d+256|0;w=d+272|0;x=d+288|0;y=d+304|0;z=d+320|0;A=d+336|0;B=d+352|0;C=d+368|0;D=d+384|0;E=d+400|0;F=d+416|0;G=d+432|0;H=d+448|0;I=d+464|0;J=d+480|0;K=d+496|0;L=d+512|0;M=d+528|0;N=d+544|0;O=d+560|0;P=d+576|0;Q=d+592|0;R=d+608|0;S=d+624|0;T=d+640|0;U=d+656|0;V=d+672|0;W=d+688|0;X=d+704|0;Y=d+720|0;Z=d+736|0;_=d+752|0;$=d+768|0;aa=d+784|0;ab=d+800|0;ac=d+816|0;ad=d+832|0;ae=d+848|0;af=d+864|0;ag=d+880|0;ah=d+896|0;ai=d+912|0;aj=d+928|0;ak=d+944|0;al=d+960|0;am=d+976|0;an=d+992|0;ao=d+1008|0;ap=d+1024|0;aq=d+1040|0;ar=d+1056|0;as=d+1072|0;at=d+1088|0;au=d+1104|0;av=d+1120|0;aw=d+1136|0;ax=d+1152|0;ay=d+1168|0;az=d+1184|0;aA=d+1200|0;aB=d+1216|0;aC=d+1232|0;aD=d+1248|0;aE=d+1264|0;aF=d+1280|0;aG=d+1296|0;do{if(a[7461104]|0){if((b&64|0)==0){break}gGz(aF|0,0,12);c[aF>>2]=14109952;c[aF+4>>2]=1;c[aF+12>>2]=194456;aH=c[2076592]|0;gj[aH&4095](aF)|0;gGz(aE|0,0,12);c[aE>>2]=9771792;c[aE+4>>2]=1;c[aE+12>>2]=510424;aH=c[2076592]|0;gj[aH&4095](aE)|0}}while(0);do{if(a[7461144]|0){if((b&32|0)==0){break}gGz(aD|0,0,12);c[aD>>2]=c[2439440];c[aD+4>>2]=2048;c[aD+12>>2]=394208;aE=c[2076592]|0;gj[aE&4095](aD)|0}}while(0);do{if(a[7461112]|0){aD=ac;if((b&32|0)!=0){aE=ac|0;aF=ac+4|0;aH=ac+12|0;gGz(aD|0,0,12);c[aE>>2]=c[2424896];c[aF>>2]=1024;c[aH>>2]=394208;aI=c[2076592]|0;gj[aI&4095](ac)|0;gGz(aD|0,0,12);c[aE>>2]=c[2424897];c[aF>>2]=1024;c[aH>>2]=394208;aI=c[2076592]|0;gj[aI&4095](ac)|0;gGz(aD|0,0,12);c[aE>>2]=c[2424898];c[aF>>2]=1024;c[aH>>2]=394208;aI=c[2076592]|0;gj[aI&4095](ac)|0;gGz(aD|0,0,12);c[aE>>2]=c[2424899];c[aF>>2]=1024;c[aH>>2]=394208;aI=c[2076592]|0;gj[aI&4095](ac)|0;gGz(aD|0,0,12);c[aE>>2]=c[2424900];c[aF>>2]=1024;c[aH>>2]=394208;aI=c[2076592]|0;gj[aI&4095](ac)|0;gGz(aD|0,0,12);c[aE>>2]=c[2424901];c[aF>>2]=1024;c[aH>>2]=394208;aI=c[2076592]|0;gj[aI&4095](ac)|0;gGz(aD|0,0,12);c[aE>>2]=c[2424902];c[aF>>2]=1024;c[aH>>2]=394208;aI=c[2076592]|0;gj[aI&4095](ac)|0;gGz(aD|0,0,12);c[aE>>2]=c[2424903];c[aF>>2]=1024;c[aH>>2]=394208;aH=c[2076592]|0;gj[aH&4095](ac)|0}if((b&64|0)==0){break}gGz(ab|0,0,12);c[ab>>2]=14109952;c[ab+4>>2]=1;c[ab+12>>2]=194456;aH=c[2076592]|0;gj[aH&4095](ab)|0}}while(0);do{if(a[7461136]|0){if((b&32|0)!=0){gGz(aa|0,0,12);c[aa>>2]=c[2406600];c[aa+4>>2]=8192;c[aa+12>>2]=305992;ab=c[2076592]|0;gj[ab&4095](aa)|0}if((b&64|0)==0){break}gGz($|0,0,12);c[$>>2]=14109952;c[$+4>>2]=1;c[$+12>>2]=194456;ab=c[2076592]|0;gj[ab&4095]($)|0;gGz(_|0,0,12);c[_>>2]=14124912;c[_+4>>2]=1;c[_+12>>2]=233288;ab=c[2076592]|0;gj[ab&4095](_)|0;gGz(Z|0,0,12);c[Z>>2]=9774608;c[Z+4>>2]=1;c[Z+12>>2]=182024;ab=c[2076592]|0;gj[ab&4095](Z)|0;gGz(Y|0,0,12);c[Y>>2]=9774624;c[Y+4>>2]=1;c[Y+12>>2]=146776;ab=c[2076592]|0;gj[ab&4095](Y)|0;gGz(X|0,0,12);c[X>>2]=9774616;c[X+4>>2]=1;c[X+12>>2]=117448;ab=c[2076592]|0;gj[ab&4095](X)|0;gGz(W|0,0,12);c[W>>2]=818400;c[W+4>>2]=2;c[W+12>>2]=92344;ab=c[2076592]|0;gj[ab&4095](W)|0;gGz(V|0,0,12);c[V>>2]=818392;c[V+4>>2]=2;c[V+12>>2]=72256;ab=c[2076592]|0;gj[ab&4095](V)|0;gGz(U|0,0,12);c[U>>2]=14124928;c[U+4>>2]=2;c[U+12>>2]=579992;ab=c[2076592]|0;gj[ab&4095](U)|0;gGz(T|0,0,12);c[T>>2]=9698784;c[T+4>>2]=1;c[T+12>>2]=563160;ab=c[2076592]|0;gj[ab&4095](T)|0;gGz(S|0,0,12);c[S>>2]=9698776;c[S+4>>2]=1;c[S+12>>2]=547088;ab=c[2076592]|0;gj[ab&4095](S)|0;gGz(R|0,0,12);c[R>>2]=9698768;c[R+4>>2]=1;c[R+12>>2]=533152;ab=c[2076592]|0;gj[ab&4095](R)|0}}while(0);do{if(a[7461e3]|0){if((b&32|0)!=0){gGz(aC|0,0,12);c[aC>>2]=c[2077632];c[aC+4>>2]=8192;c[aC+12>>2]=394208;R=c[2076592]|0;gj[R&4095](aC)|0}if((b&64|0)==0){break}gGz(aB|0,0,12);c[aB>>2]=8310520;c[aB+4>>2]=1;c[aB+12>>2]=458120;R=c[2076592]|0;gj[R&4095](aB)|0;gGz(aA|0,0,12);c[aA>>2]=8310504;c[aA+4>>2]=1;c[aA+12>>2]=448032;R=c[2076592]|0;gj[R&4095](aA)|0;gGz(az|0,0,12);c[az>>2]=8310536;c[az+4>>2]=1;c[az+12>>2]=436e3;R=c[2076592]|0;gj[R&4095](az)|0;gGz(ay|0,0,12);c[ay>>2]=8310512;c[ay+4>>2]=1;c[ay+12>>2]=425512;R=c[2076592]|0;gj[R&4095](ay)|0}}while(0);do{if(a[7461128]|0){ay=Q;az=c[3528994]|0;if((b&32|0)!=0&(az|0)>0){aA=Q|0;aB=Q+4|0;aC=Q+12|0;R=0;while(1){gGz(ay|0,0,12);c[aA>>2]=c[14163912+(R<<2)>>2];c[aB>>2]=65536;c[aC>>2]=191224;gj[c[2076592]&4095](Q)|0;S=R+1|0;T=c[3528994]|0;if((S|0)<(T|0)){R=S}else{aJ=T;break}}}else{aJ=az}if(!((b&64|0)!=0&(aJ|0)>0)){break}R=P;aC=P|0;aB=P+4|0;aA=P+12|0;ay=O;T=O|0;S=O+4|0;U=O+12|0;V=N;W=N|0;X=N+4|0;Y=N+12|0;Z=M;_=M|0;$=M+4|0;aa=M+12|0;ab=L;ac=L|0;aH=L+4|0;aF=L+12|0;aE=0;do{gGz(R|0,0,12);c[aC>>2]=14108184+(aE<<4);c[aB>>2]=16;c[aA>>2]=509272;gj[c[2076592]&4095](P)|0;gGz(ay|0,0,12);c[T>>2]=9553368+(aE<<2);c[S>>2]=4;c[U>>2]=393560;gj[c[2076592]&4095](O)|0;gGz(V|0,0,12);c[W>>2]=9553328+(aE<<2);c[X>>2]=4;c[Y>>2]=305520;gj[c[2076592]&4095](N)|0;gGz(Z|0,0,12);c[_>>2]=9543296+(aE<<2);c[$>>2]=4;c[aa>>2]=232920;gj[c[2076592]&4095](M)|0;gGz(ab|0,0,12);c[ac>>2]=9543272+(aE<<2);c[aH>>2]=4;c[aF>>2]=181512;gj[c[2076592]&4095](L)|0;aE=aE+1|0;}while((aE|0)<(c[3528994]|0))}}while(0);do{if(a[7461120]|0){if((b&32|0)!=0){gGz(ax|0,0,12);c[ax>>2]=c[3540976];c[ax+4>>2]=16384;c[ax+12>>2]=191008;L=c[2076592]|0;gj[L&4095](ax)|0}if((b&64|0)==0){break}gGz(aw|0,0,12);c[aw>>2]=14163896;c[aw+4>>2]=4;c[aw+12>>2]=509208;L=c[2076592]|0;gj[L&4095](aw)|0}}while(0);do{if(a[7461096]|0){if((b&32|0)!=0){gGz(K|0,0,12);c[K>>2]=c[3532278];c[K+4>>2]=81920;c[K+12>>2]=200608;aw=c[2076592]|0;gj[aw&4095](K)|0}if((b&64|0)==0){break}gGz(J|0,0,12);c[J>>2]=14129152;c[J+4>>2]=16;c[J+12>>2]=511968;aw=c[2076592]|0;gj[aw&4095](J)|0;gGz(I|0,0,12);c[I>>2]=9553376;c[I+4>>2]=12;c[I+12>>2]=396048;aw=c[2076592]|0;gj[aw&4095](I)|0;gGz(H|0,0,12);c[H>>2]=9553336;c[H+4>>2]=12;c[H+12>>2]=307080;aw=c[2076592]|0;gj[aw&4095](H)|0;gGz(G|0,0,12);c[G>>2]=9543304;c[G+4>>2]=12;c[G+12>>2]=234272;aw=c[2076592]|0;gj[aw&4095](G)|0;gGz(F|0,0,12);c[F>>2]=9543280;c[F+4>>2]=12;c[F+12>>2]=182536;aw=c[2076592]|0;gj[aw&4095](F)|0;gGz(E|0,0,12);c[E>>2]=14110008;c[E+4>>2]=12;c[E+12>>2]=147384;aw=c[2076592]|0;gj[aw&4095](E)|0;gGz(D|0,0,12);c[D>>2]=14109976;c[D+4>>2]=12;c[D+12>>2]=117784;aw=c[2076592]|0;gj[aw&4095](D)|0;gGz(C|0,0,12);c[C>>2]=9757584;c[C+4>>2]=12;c[C+12>>2]=92760;aw=c[2076592]|0;gj[aw&4095](C)|0;gGz(B|0,0,12);c[B>>2]=9733208;c[B+4>>2]=12;c[B+12>>2]=72848;aw=c[2076592]|0;gj[aw&4095](B)|0;gGz(A|0,0,12);c[A>>2]=14129136;c[A+4>>2]=12;c[A+12>>2]=580296;aw=c[2076592]|0;gj[aw&4095](A)|0}}while(0);do{if(a[7461088]|0){A=av;if((b&32|0)!=0){gGz(A|0,0,12);B=av|0;c[B>>2]=c[2442928];C=av+4|0;c[C>>2]=16384;D=av+12|0;c[D>>2]=183096;E=c[2076592]|0;gj[E&4095](av)|0;gGz(A|0,0,12);c[B>>2]=c[3532276];c[C>>2]=c[3532274]<<2;c[D>>2]=506704;D=c[2076592]|0;gj[D&4095](av)|0}if((b&64|0)==0){break}gGz(au|0,0,12);c[au>>2]=9757568;c[au+4>>2]=4;c[au+12>>2]=391088;D=c[2076592]|0;gj[D&4095](au)|0}}while(0);do{if(a[7461080]|0){if((b&64|0)==0){break}gGz(at|0,0,12);c[at>>2]=9540888;c[at+4>>2]=13;c[at+12>>2]=182168;au=c[2076592]|0;gj[au&4095](at)|0}}while(0);do{if(a[7461072]|0){if((b&32|0)==0){break}gGz(as|0,0,12);c[as>>2]=c[3532272];c[as+4>>2]=8192;c[as+12>>2]=193864;at=c[2076592]|0;gj[at&4095](as)|0}}while(0);do{if(a[7461064]|0){if((b&96|0)==0){break}as=ar|0;c[as>>2]=c[2429460];at=ar+4|0;c[at>>2]=262144;au=ar+12|0;c[au>>2]=196608;av=c[2076592]|0;gj[av&4095](ar)|0;c[as>>2]=c[2429461];c[at>>2]=262144;c[au>>2]=511112;av=c[2076592]|0;gj[av&4095](ar)|0;c[as>>2]=c[3532266];c[at>>2]=65536;c[au>>2]=394800;av=c[2076592]|0;gj[av&4095](ar)|0;c[as>>2]=c[3532264];c[at>>2]=2048;c[au>>2]=306448;av=c[2076592]|0;gj[av&4095](ar)|0;c[as>>2]=c[3532268];c[at>>2]=2048;c[au>>2]=233608;av=c[2076592]|0;gj[av&4095](ar)|0;c[as>>2]=9733144;c[at>>2]=16;c[au>>2]=182216;au=c[2076592]|0;gj[au&4095](ar)|0;gGz(aq|0,0,12);c[aq>>2]=9731824;c[aq+4>>2]=4;c[aq+12>>2]=146888;au=c[2076592]|0;gj[au&4095](aq)|0}}while(0);do{if(a[7461056]|0){if((b&64|0)==0){break}gGz(z|0,0,12);c[z>>2]=14129032;c[z+4>>2]=8;c[z+12>>2]=182992;aq=c[2076592]|0;gj[aq&4095](z)|0;gGz(y|0,0,12);c[y>>2]=14129024;c[y+4>>2]=8;c[y+12>>2]=506632;aq=c[2076592]|0;gj[aq&4095](y)|0;gGz(x|0,0,12);c[x>>2]=14129016;c[x+4>>2]=8;c[x+12>>2]=390944;aq=c[2076592]|0;gj[aq&4095](x)|0;gGz(w|0,0,12);c[w>>2]=14129048;c[w+4>>2]=2;c[w+12>>2]=303792;aq=c[2076592]|0;gj[aq&4095](w)|0;gGz(v|0,0,12);c[v>>2]=14129040;c[v+4>>2]=6;c[v+12>>2]=231712;aq=c[2076592]|0;gj[aq&4095](v)|0;gGz(u|0,0,12);c[u>>2]=9757552;c[u+4>>2]=8;c[u+12>>2]=180776;aq=c[2076592]|0;gj[aq&4095](u)|0;gGz(t|0,0,12);c[t>>2]=9757560;c[t+4>>2]=1;c[t+12>>2]=146016;aq=c[2076592]|0;gj[aq&4095](t)|0}}while(0);do{if(a[7461048]|0){if((b&32|0)!=0){gGz(ap|0,0,12);c[ap>>2]=c[3532250];c[ap+4>>2]=8192;c[ap+12>>2]=200720;t=c[2076592]|0;gj[t&4095](ap)|0}if((b&64|0)==0){break}gGz(ao|0,0,12);c[ao>>2]=9757536;c[ao+4>>2]=16;c[ao+12>>2]=512016;t=c[2076592]|0;gj[t&4095](ao)|0;gGz(an|0,0,12);c[an>>2]=14129008;c[an+4>>2]=4;c[an+12>>2]=396088;t=c[2076592]|0;gj[t&4095](an)|0}}while(0);do{if(a[7461040]|0){if((b&64|0)==0){break}gGz(am|0,0,12);c[am>>2]=14128984;c[am+4>>2]=16;c[am+12>>2]=200088;an=c[2076592]|0;gj[an&4095](am)|0}}while(0);do{if(a[7461032]|0){if((b&32|0)!=0){gGz(al|0,0,12);c[al>>2]=c[3532250];c[al+4>>2]=8192;c[al+12>>2]=200720;am=c[2076592]|0;gj[am&4095](al)|0}if((b&64|0)==0){break}gGz(ak|0,0,12);c[ak>>2]=9757536;c[ak+4>>2]=16;c[ak+12>>2]=512016;am=c[2076592]|0;gj[am&4095](ak)|0;gGz(aj|0,0,12);c[aj>>2]=14129008;c[aj+4>>2]=4;c[aj+12>>2]=396088;am=c[2076592]|0;gj[am&4095](aj)|0}}while(0);do{if(a[7461024]|0){if((b&32|0)!=0){gGz(s|0,0,12);c[s>>2]=c[3532232];c[s+4>>2]=65536;c[s+12>>2]=200752;aj=c[2076592]|0;gj[aj&4095](s)|0}if((b&64|0)==0){break}gGz(r|0,0,12);c[r>>2]=14128936;c[r+4>>2]=48;c[r+12>>2]=512040;aj=c[2076592]|0;gj[aj&4095](r)|0;gGz(q|0,0,12);c[q>>2]=9553392;c[q+4>>2]=16;c[q+12>>2]=396048;aj=c[2076592]|0;gj[aj&4095](q)|0;gGz(p|0,0,12);c[p>>2]=9553352;c[p+4>>2]=16;c[p+12>>2]=307080;aj=c[2076592]|0;gj[aj&4095](p)|0;gGz(o|0,0,12);c[o>>2]=14110024;c[o+4>>2]=4;c[o+12>>2]=147384;aj=c[2076592]|0;gj[aj&4095](o)|0;gGz(n|0,0,12);c[n>>2]=14109992;c[n+4>>2]=4;c[n+12>>2]=117784;aj=c[2076592]|0;gj[aj&4095](n)|0;gGz(m|0,0,12);c[m>>2]=9747232;c[m+4>>2]=4;c[m+12>>2]=147400;aj=c[2076592]|0;gj[aj&4095](m)|0}}while(0);do{if(a[7461016]|0){if((b&64|0)==0){break}gGz(ai|0,0,12);c[ai>>2]=14128904;c[ai+4>>2]=8;c[ai+12>>2]=190904;m=c[2076592]|0;gj[m&4095](ai)|0;gGz(ah|0,0,12);c[ah>>2]=14128896;c[ah+4>>2]=8;c[ah+12>>2]=509104;m=c[2076592]|0;gj[m&4095](ah)|0;gGz(ag|0,0,12);c[ag>>2]=14128888;c[ag+4>>2]=8;c[ag+12>>2]=393464;m=c[2076592]|0;gj[m&4095](ag)|0;gGz(af|0,0,12);c[af>>2]=14128920;c[af+4>>2]=2;c[af+12>>2]=305400;m=c[2076592]|0;gj[m&4095](af)|0;gGz(ae|0,0,12);c[ae>>2]=14128912;c[ae+4>>2]=3;c[ae+12>>2]=232856;m=c[2076592]|0;gj[m&4095](ae)|0;gGz(ad|0,0,12);c[ad>>2]=9757528;c[ad+4>>2]=8;c[ad+12>>2]=181496;m=c[2076592]|0;gj[m&4095](ad)|0}}while(0);ad=b&64;do{if(a[7461008]|0){if((ad|0)==0){i=d;return}else{gGz(l|0,0,12);c[l>>2]=14128872;c[l+4>>2]=8;c[l+12>>2]=193824;b=c[2076592]|0;gj[b&4095](l)|0;gGz(k|0,0,12);c[k>>2]=14128864;c[k+4>>2]=8;c[k+12>>2]=510168;b=c[2076592]|0;gj[b&4095](k)|0;gGz(j|0,0,12);c[j>>2]=14128856;c[j+4>>2]=8;c[j+12>>2]=394e3;b=c[2076592]|0;gj[b&4095](j)|0;gGz(h|0,0,12);c[h>>2]=14128848;c[h+4>>2]=8;c[h+12>>2]=305872;b=c[2076592]|0;gj[b&4095](h)|0;gGz(g|0,0,12);c[g>>2]=14128840;c[g+4>>2]=8;c[g+12>>2]=233184;b=c[2076592]|0;gj[b&4095](g)|0;gGz(f|0,0,12);c[f>>2]=14128880;c[f+4>>2]=5;c[f+12>>2]=202120;b=c[2076592]|0;gj[b&4095](f)|0;gGz(e|0,0,12);c[e>>2]=9757520;c[e+4>>2]=8;c[e+12>>2]=146664;b=c[2076592]|0;gj[b&4095](e)|0;aK=ad;break}}else{aK=ad}}while(0);if((aK|0)==0){i=d;return}gGz(aG|0,0,12);c[aG>>2]=14127824;c[aG+4>>2]=4;c[aG+12>>2]=369064;gj[c[2076592]&4095](aG)|0;i=d;return}function eZ8(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((c[3532044]|0)>0){d=0;e=c[2394]|0;while(1){if((e|0)!=(d|0)){c[2394]=d;c[2112932]=c[14130384+(d<<2)>>2];f=c[14130368+(d<<2)>>2]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[8452240+(d<<2)>>2]}RI();f=c[2394]|0;g=c[14130368+(f<<2)>>2]|0;if((g|0)!=0){gGC(g|0,9104152,280)|0}c[8452240+(f<<2)>>2]=c[2113054];c[2394]=-1;f=d+1|0;if((f|0)<(c[3532044]|0)){d=f;e=-1}else{break}}}e=c[3532030]|0;if((e|0)>0){d=0;do{f=c[9757320+(d<<2)>>2]|0;g=(f|0)==0;if(!g){i=f;gGC(9706056,i|0,76)|0}i=9752472+(d<<2)|0;j=c[i>>2]|0;k=14113936+(d<<2)|0;l=c[k>>2]|0;m=9669104+(d<<2)|0;n=c[m>>2]|0;gGz(9706056,0,76);if(!g){g=f;gGC(g|0,9706056,76)|0}c[i>>2]=j;c[k>>2]=l;c[m>>2]=n;d=d+1|0;}while((d|0)<(e|0));c[2433530]=j;c[2076596]=l;c[3541536]=n;c[1836236]=-1}if(a[7460960]|0){c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;l6(0)}if(a[7460968]|0){mx(0)}do{if((c[3532032]|0)!=0){c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){o=0}else{break}do{lN(o);mB(o);o=o+1|0;}while((o|0)<(c[2385508]|0))}}while(0);if((c[3532036]|0)!=0){UA()}o=a[7460984]|0;n=o&1;if(o){o=c[3541206]|0;c[2113156]=0;l=0;do{a[9628264+(l*156|0)|0]=0;c[9628132+(l*156|0)>>2]=0;j=l<<20;e=o+j|0;c[14164760+(l<<4)>>2]=e;c[14164792+(l<<4)>>2]=e;gGz(c[9720472+(l<<4)>>2]|0,0,16384);c[9628164+(l*156|0)>>2]=4;c[14164764+(l<<4)>>2]=o+(j|256);c[14164796+(l<<4)>>2]=o+(j|65536);gGz(c[9720476+(l<<4)>>2]|0,0,16384);c[9628196+(l*156|0)>>2]=4;c[14164768+(l<<4)>>2]=o+(j|512);c[14164800+(l<<4)>>2]=o+(j|131072);gGz(c[9720480+(l<<4)>>2]|0,0,16384);c[9628228+(l*156|0)>>2]=4;c[14164772+(l<<4)>>2]=o+(j|768);c[14164804+(l<<4)>>2]=o+(j|196608);gGz(c[9720484+(l<<4)>>2]|0,0,16384);c[9628260+(l*156|0)>>2]=4;l=l+1|0;}while((l|0)<(n|0))}if(!(a[7460992]|0)){eZ6();a[14127752]=0;a[14128024]=0;c[3532014]=0;b[7064256]=255;c[3532130]=0;return 0}c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];eZ6();a[14127752]=0;a[14128024]=0;c[3532014]=0;b[7064256]=255;c[3532130]=0;return 0}function eZ9(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0;e=i;i=i+2272|0;f=e|0;g=e+112|0;h=e+120|0;j=e+232|0;k=e+240|0;l=e+352|0;m=e+360|0;n=e+472|0;o=e+480|0;p=e+592|0;q=e+600|0;r=e+712|0;s=e+720|0;t=e+832|0;u=e+840|0;v=e+952|0;w=e+960|0;x=e+1072|0;y=e+1080|0;z=e+1192|0;A=e+1200|0;B=e+1312|0;C=e+1320|0;D=e+1432|0;E=e+1440|0;F=e+1552|0;G=e+1560|0;H=e+1672|0;I=e+1680|0;J=e+1792|0;K=e+1800|0;L=e+1912|0;M=e+1920|0;N=e+2032|0;O=e+2040|0;P=e+2152|0;Q=e+2160|0;R=Q+108|0;c[R>>2]=0;S=Q+100|0;c[S>>2]=0;if((b|0)==0){b=-1;while(1){c[S>>2]=0;c[R>>2]=0;T=b+1|0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](Q,T)|0;U=c[R>>2]&255;if((U-1|0)>>>0<4){c[3532200]=(c[3532200]|0)+(c[S>>2]|0);c[3532202]=(c[3532202]|0)+1}if((U-5|0)>>>0<2){c[3532194]=(c[3532194]|0)+(c[S>>2]|0);c[3532196]=(c[3532196]|0)+1}do{if((U-7|0)>>>0<2){c[3532188]=(c[3532188]|0)+(c[S>>2]|0);c[3532190]=(c[3532190]|0)+1;V=35481}else{if((U|0)==9){W=c[S>>2]|0;c[3531928]=(c[3531928]|0)+W;c[3531930]=(c[3531930]|0)+1;X=W;break}else if((U|0)==10){W=c[S>>2]|0;c[3531922]=(c[3531922]|0)+W;c[3531924]=(c[3531924]|0)+1;X=W;break}else{V=35481;break}}}while(0);L46612:do{if((V|0)==35481){V=0;if((U-11|0)>>>0<2){c[3532144]=(c[3532144]|0)+(c[S>>2]|0);c[3532146]=(c[3532146]|0)+1}if((U-13|0)>>>0<2){c[3532170]=(c[3532170]|0)+(c[S>>2]|0);c[3532172]=(c[3532172]|0)+1}if((U-15|0)>>>0<4){c[3531994]=(c[3531994]|0)+(c[S>>2]|0);c[3531996]=(c[3531996]|0)+1}do{if((U-19|0)>>>0<3){c[3531984]=(c[3531984]|0)+(c[S>>2]|0);c[3531986]=(c[3531986]|0)+1}else{if((U|0)==23){W=c[S>>2]|0;c[3531972]=(c[3531972]|0)+W;c[3531974]=(c[3531974]|0)+1;X=W;break L46612}else if((U|0)==24){W=c[S>>2]|0;c[3531948]=(c[3531948]|0)+W;c[3531950]=(c[3531950]|0)+1;X=W;break L46612}else if((U|0)==25){W=c[S>>2]|0;c[3531942]=(c[3531942]|0)+W;c[3531944]=(c[3531944]|0)+1;X=W;break L46612}else if((U|0)==22){W=c[S>>2]|0;c[3532010]=(c[3532010]|0)+W;c[3532012]=(c[3532012]|0)+1;X=W;break L46612}else{break}}}while(0);do{if((U-26|0)>>>0<2){c[3532058]=(c[3532058]|0)+(c[S>>2]|0);c[3532060]=(c[3532060]|0)+1}else{if((U|0)==28){W=c[S>>2]|0;c[3532154]=(c[3532154]|0)+W;c[3532156]=(c[3532156]|0)+1;X=W;break L46612}else if((U|0)==29){W=c[S>>2]|0;c[3532052]=(c[3532052]|0)+W;c[3532054]=(c[3532054]|0)+1;X=W;break L46612}else{break}}}while(0);if((U-30|0)>>>0<2){W=c[S>>2]|0;c[3532112]=(c[3532112]|0)+W;c[3532114]=(c[3532114]|0)+1;X=W;break}W=c[S>>2]|0;if((U|0)!=32){X=W;break}c[3532122]=(c[3532122]|0)+W;c[3532124]=(c[3532124]|0)+1;X=W}}while(0);if((X|0)==0){Y=0;break}else{b=T}}i=e;return Y|0}L46646:do{if((c[3532202]|0)==0){Z=0}else{b=O+108|0;X=O+100|0;U=0;W=0;while(1){gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](Q,U)|0;_=c[R>>2]|0;if((_&255|0)==2){if((R6((c[3532204]|0)+(W+1)|0,U,2)|0)!=0){Y=1;V=35887;break}$=U+1|0;if((R6((c[3532204]|0)+W|0,$,2)|0)!=0){Y=1;V=35901;break}aa=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aa&16383](Q,U)|0;aa=(c[S>>2]|0)+W|0;ab=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ab&16383](Q,$)|0;ac=aa+(c[S>>2]|0)|0;ad=U+2|0;ae=c[R>>2]|0}else{ac=W;ad=U;ae=_}if((ae&255|0)==4){if((R6((c[3532204]|0)+(ac+1)|0,ad,4)|0)!=0){Y=1;V=35884;break}_=ad+1|0;if((R6((c[3532204]|0)+ac|0,_,4)|0)!=0){Y=1;V=35889;break}aa=ad+2|0;if((R6((c[3532204]|0)+(ac+3)|0,aa,4)|0)!=0){Y=1;V=35885;break}$=ad+3|0;if((R6((c[3532204]|0)+(ac+2)|0,$,4)|0)!=0){Y=1;V=35892;break}ab=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ab&16383](Q,ad)|0;ab=(c[S>>2]|0)+ac|0;af=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[af&16383](Q,_)|0;_=ab+(c[S>>2]|0)|0;ab=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ab&16383](Q,aa)|0;aa=_+(c[S>>2]|0)|0;_=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[_&16383](Q,$)|0;ah=aa+(c[S>>2]|0)|0;ai=ad+4|0;aj=c[R>>2]|0}else{ah=ac;ai=ad;aj=ae}if((aj&255|0)==3){if((R6((c[3532204]|0)+ah|0,ai,2)|0)!=0){Y=1;V=35900;break}aa=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aa&16383](Q,ai)|0;ak=(c[S>>2]|0)+ah|0;al=ai+1|0;am=c[R>>2]|0}else{ak=ah;al=ai;am=aj}if((am&255|0)==1){aa=(c[3532204]|0)+ak|0;if((c[3542200]|0)==0){Y=1;V=35894;break}c[b>>2]=0;c[X>>2]=0;$=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[$&16383](O,al)|0;if((c[b>>2]|0)!=0){$=c[X>>2]|0;c[P>>2]=9534384;_=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[_&16383](P,al,0)|0;if(($|0)<1){Y=1;V=35891;break}if((gzL(aa,0,al)|0)!=0){Y=1;V=35890;break}}aa=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aa&16383](Q,al)|0;an=(c[S>>2]|0)+ak|0;ao=al+1|0}else{an=ak;ao=al}aa=c[3532202]|0;if(ao>>>0<aa>>>0){U=ao;W=an}else{Z=aa;break L46646}}if((V|0)==35884){i=e;return Y|0}else if((V|0)==35885){i=e;return Y|0}else if((V|0)==35887){i=e;return Y|0}else if((V|0)==35889){i=e;return Y|0}else if((V|0)==35890){i=e;return Y|0}else if((V|0)==35891){i=e;return Y|0}else if((V|0)==35892){i=e;return Y|0}else if((V|0)==35894){i=e;return Y|0}else if((V|0)==35900){i=e;return Y|0}else if((V|0)==35901){i=e;return Y|0}}}while(0);L46686:do{if((c[3532194]|0)==0){ap=Z}else{if(Z>>>0>=((c[3532196]|0)+Z|0)>>>0){ap=Z;break}an=M+108|0;ao=M+100|0;al=Z;ak=0;while(1){gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](Q,al)|0;P=c[R>>2]|0;if((P&255|0)==6){if((R6((c[3532198]|0)+(ak+1)|0,al,2)|0)!=0){Y=1;V=35886;break}O=al+1|0;if((R6((c[3532198]|0)+ak|0,O,2)|0)!=0){Y=1;V=35903;break}am=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[am&16383](Q,al)|0;am=(c[S>>2]|0)+ak|0;aj=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aj&16383](Q,O)|0;aq=am+(c[S>>2]|0)|0;ar=al+2|0;as=c[R>>2]|0}else{aq=ak;ar=al;as=P}if((as&255|0)==5){P=(c[3532198]|0)+aq|0;if((c[3542200]|0)==0){Y=1;V=35916;break}c[an>>2]=0;c[ao>>2]=0;am=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[am&16383](M,ar)|0;if((c[an>>2]|0)!=0){am=c[ao>>2]|0;c[N>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](N,ar,0)|0;if((am|0)<1){Y=1;V=35902;break}if((gzL(P,0,ar)|0)!=0){Y=1;V=35931;break}}P=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[P&16383](Q,ar)|0;at=(c[S>>2]|0)+aq|0;au=ar+1|0}else{at=aq;au=ar}P=c[3532202]|0;if(au>>>0<((c[3532196]|0)+P|0)>>>0){al=au;ak=at}else{ap=P;break L46686}}if((V|0)==35886){i=e;return Y|0}else if((V|0)==35902){i=e;return Y|0}else if((V|0)==35903){i=e;return Y|0}else if((V|0)==35916){i=e;return Y|0}else if((V|0)==35931){i=e;return Y|0}}}while(0);L46711:do{if((c[3532188]|0)==0){av=ap}else{at=(c[3532196]|0)+ap|0;if(at>>>0>=(at+(c[3532190]|0)|0)>>>0){av=ap;break}au=K+108|0;ar=K+100|0;aq=at;at=0;while(1){gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](Q,aq)|0;N=c[R>>2]|0;if((N&255|0)==8){if((R6((c[3532192]|0)+(at+1)|0,aq,2)|0)!=0){Y=1;V=35932;break}M=aq+1|0;if((R6((c[3532192]|0)+at|0,M,2)|0)!=0){Y=1;V=35896;break}as=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[as&16383](Q,aq)|0;as=(c[S>>2]|0)+at|0;Z=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Z&16383](Q,M)|0;aw=as+(c[S>>2]|0)|0;ax=aq+2|0;ay=c[R>>2]|0}else{aw=at;ax=aq;ay=N}if((ay&255|0)==7){N=(c[3532192]|0)+aw|0;if((c[3542200]|0)==0){Y=1;V=35850;break}c[au>>2]=0;c[ar>>2]=0;as=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[as&16383](K,ax)|0;if((c[au>>2]|0)!=0){as=c[ar>>2]|0;c[L>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](L,ax,0)|0;if((as|0)<1){Y=1;V=35883;break}if((gzL(N,0,ax)|0)!=0){Y=1;V=35893;break}}N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](Q,ax)|0;az=(c[S>>2]|0)+aw|0;aA=ax+1|0}else{az=aw;aA=ax}N=c[3532202]|0;if(aA>>>0<((c[3532196]|0)+N+(c[3532190]|0)|0)>>>0){aq=aA;at=az}else{av=N;break L46711}}if((V|0)==35850){i=e;return Y|0}else if((V|0)==35883){i=e;return Y|0}else if((V|0)==35893){i=e;return Y|0}else if((V|0)==35896){i=e;return Y|0}else if((V|0)==35932){i=e;return Y|0}}}while(0);do{if((c[3531928]|0)==0){aB=av}else{az=(c[3532196]|0)+av+(c[3532190]|0)|0;if(az>>>0>=(az+(c[3531930]|0)|0)>>>0){aB=av;break}aA=I+108|0;ax=I+100|0;aw=az;az=0;while(1){L=(c[3531932]|0)+az|0;do{if((c[3542200]|0)!=0){c[aA>>2]=0;c[ax>>2]=0;K=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[K&16383](I,aw)|0;if((c[aA>>2]|0)==0){break}K=c[ax>>2]|0;c[J>>2]=9534384;ay=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ay&16383](J,aw,0)|0;if((K|0)<1){break}gzL(L,0,aw)|0}}while(0);gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](Q,aw)|0;L=aw+1|0;K=c[3532202]|0;if(L>>>0<((c[3532196]|0)+K+(c[3532190]|0)+(c[3531930]|0)|0)>>>0){aw=L;az=(c[S>>2]|0)+az|0}else{aB=K;break}}}}while(0);do{if((c[3531922]|0)!=0){J=(c[3532196]|0)+aB+(c[3532190]|0)+(c[3531930]|0)|0;if(J>>>0>=(J+(c[3531924]|0)|0)>>>0){break}I=G+108|0;av=G+100|0;az=J;J=0;while(1){aw=(c[3531926]|0)+J|0;do{if((c[3542200]|0)!=0){c[I>>2]=0;c[av>>2]=0;ax=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ax&16383](G,az)|0;if((c[I>>2]|0)==0){break}ax=c[av>>2]|0;c[H>>2]=9534384;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aA&16383](H,az,0)|0;if((ax|0)<1){break}gzL(aw,0,az)|0}}while(0);gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](Q,az)|0;aw=az+1|0;if(aw>>>0<((c[3532196]|0)+(c[3532202]|0)+(c[3532190]|0)+(c[3531930]|0)+(c[3531924]|0)|0)>>>0){az=aw;J=(c[S>>2]|0)+J|0}else{break}}}}while(0);H=c[3532144]|0;L46758:do{if((H|0)!=0){G=0;while(1){if((G|0)>=1024){aC=0;break}aD=9638528+(G<<2)|0;if((c[aD>>2]|0)==0){V=35573;break}else{G=G+1|0}}do{if((V|0)==35573){G=gGq(H)|0;c[aD>>2]=G;if((G|0)==0){aC=0;break}gGz(G|0,0,H|0);aC=G}}while(0);gGz(aC|0,0,c[3532144]|0);G=(c[3532196]|0)+(c[3532202]|0)+(c[3532190]|0)+(c[3531930]|0)+(c[3531924]|0)|0;L46766:do{if(G>>>0<(G+(c[3532146]|0)|0)>>>0){aB=E+108|0;J=E+100|0;az=G;av=0;while(1){gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](Q,az)|0;I=c[R>>2]|0;if((I&255|0)==11){aw=aC+av|0;if((c[3542200]|0)==0){Y=1;V=35878;break}c[aB>>2]=0;c[J>>2]=0;ax=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ax&16383](E,az)|0;if((c[aB>>2]|0)!=0){ax=c[J>>2]|0;c[F>>2]=9534384;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aA&16383](F,az,0)|0;if((ax|0)<1){Y=1;V=35848;break}if((gzL(aw,0,az)|0)!=0){Y=1;V=35849;break}}aw=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aw&16383](Q,az)|0;aE=(c[S>>2]|0)+av|0;aF=az+1|0;aG=c[R>>2]|0}else{aE=av;aF=az;aG=I}if((aG&255|0)==12){if((R6(aC+aE|0,aF,2)|0)!=0){Y=1;V=35851;break}I=aF+1|0;if((R6(aC+(aE+1)|0,I,2)|0)!=0){Y=1;V=35895;break}aw=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aw&16383](Q,aF)|0;aw=(c[S>>2]|0)+aE|0;ax=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ax&16383](Q,I)|0;aH=aw+(c[S>>2]|0)|0;aI=aF+2|0}else{aH=aE;aI=aF}if(aI>>>0<((c[3532196]|0)+(c[3532202]|0)+(c[3532190]|0)+(c[3531930]|0)+(c[3531924]|0)+(c[3532146]|0)|0)>>>0){az=aI;av=aH}else{aJ=aH;break L46766}}if((V|0)==35848){i=e;return Y|0}else if((V|0)==35849){i=e;return Y|0}else if((V|0)==35851){i=e;return Y|0}else if((V|0)==35878){i=e;return Y|0}else if((V|0)==35895){i=e;return Y|0}}else{aJ=0}}while(0);G=c[3532042]|0;do{if((G|0)==0){av=c[3532136]|0;gGC(av|0,aC|0,aJ)|0;aK=0}else{av=c[3532160]|0;az=c[3532142]|0;J=c[3532164]|0;aB=c[3532148]|0;aw=c[3532140]|0;I=c[3532138]|0;ax=c[3532162]|0;aA=c[3532136]|0;if((G|0)<=0){aK=0;break}K=ag(J,az)|0;L=(av|0)>0;ay=av-1|0;ap=(J|0)<1|(az|0)<1;at=0;while(1){aq=ag(at,K)|0;gGz(aA+aq|0,0,K|0);if(L){ar=ag(at,ax)|0;au=0;do{N=1<<ay-au;as=(c[aB+(au<<2)>>2]|0)+ar|0;if(!ap){M=0;do{Z=as+(c[I+(M<<2)>>2]|0)|0;ak=(ag(M,az)|0)+aq|0;al=0;do{ao=Z+(c[aw+(al<<2)>>2]|0)|0;if(((d[aC+((ao|0)/8|0)|0]|0)&128>>>((ao&7)>>>0)|0)!=0){ao=aA+(ak+al)|0;a[ao]=(d[ao]|0|N)&255}al=al+1|0;}while((al|0)<(az|0));M=M+1|0;}while((M|0)<(J|0))}au=au+1|0;}while((au|0)<(av|0))}au=at+1|0;if((au|0)<(G|0)){at=au}else{aK=0;break}}}}while(0);while(1){if((aK|0)>=1024){break L46758}aL=9638528+(aK<<2)|0;if((c[aL>>2]|0)==(aC|0)){break}else{aK=aK+1|0}}gGr(aC);c[aL>>2]=0}}while(0);aL=c[3532170]|0;L46816:do{if((aL|0)!=0){aC=0;while(1){if((aC|0)>=1024){aM=0;break}aN=9638528+(aC<<2)|0;if((c[aN>>2]|0)==0){V=35608;break}else{aC=aC+1|0}}do{if((V|0)==35608){aC=gGq(aL)|0;c[aN>>2]=aC;if((aC|0)==0){aM=0;break}gGz(aC|0,0,aL|0);aM=aC}}while(0);gGz(aM|0,0,c[3532170]|0);aC=(c[3532196]|0)+(c[3532202]|0)+(c[3532190]|0)+(c[3531930]|0)+(c[3531924]|0)+(c[3532146]|0)|0;L46824:do{if(aC>>>0<(aC+(c[3532172]|0)|0)>>>0){aK=C+108|0;aJ=C+100|0;aH=aC;aI=0;while(1){gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](Q,aH)|0;aF=c[R>>2]|0;if((aF&255|0)==13){aE=aM+aI|0;if((c[3542200]|0)==0){Y=1;V=35879;break}c[aK>>2]=0;c[aJ>>2]=0;aG=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aG&16383](C,aH)|0;if((c[aK>>2]|0)!=0){aG=c[aJ>>2]|0;c[D>>2]=9534384;F=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[F&16383](D,aH,0)|0;if((aG|0)<1){Y=1;V=35880;break}if((gzL(aE,0,aH)|0)!=0){Y=1;V=35881;break}}aE=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aE&16383](Q,aH)|0;aO=(c[S>>2]|0)+aI|0;aP=aH+1|0;aQ=c[R>>2]|0}else{aO=aI;aP=aH;aQ=aF}if((aQ&255|0)==14){if((R6(aM+aO|0,aP,2)|0)!=0){Y=1;V=35882;break}aF=aP+1|0;if((R6(aM+(aO+1)|0,aF,2)|0)!=0){Y=1;V=35888;break}aE=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aE&16383](Q,aP)|0;aE=(c[S>>2]|0)+aO|0;aG=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aG&16383](Q,aF)|0;aR=aE+(c[S>>2]|0)|0;aS=aP+2|0}else{aR=aO;aS=aP}if(aS>>>0<((c[3532196]|0)+(c[3532202]|0)+(c[3532190]|0)+(c[3531930]|0)+(c[3531924]|0)+(c[3532146]|0)+(c[3532172]|0)|0)>>>0){aH=aS;aI=aR}else{break L46824}}if((V|0)==35879){i=e;return Y|0}else if((V|0)==35880){i=e;return Y|0}else if((V|0)==35881){i=e;return Y|0}else if((V|0)==35882){i=e;return Y|0}else if((V|0)==35888){i=e;return Y|0}}}while(0);aC=c[3532040]|0;aI=c[3532176]|0;aH=a[7461200]|0;aJ=aH?8:0;aK=a[7461208]|0;aE=aK?8:0;aF=c[3532174]|0;aG=c[3532168]|0;F=c[3532166]|0;E=c[3532178]|0;H=c[3532134]|0;if((aC|0)>0){aD=ag(aE,aJ)|0;G=(aI|0)>0;at=aI-1|0;av=aK&aH;aH=0;while(1){aK=ag(aH,aD)|0;gGz(H+aK|0,0,aD|0);if(G){J=ag(aH,E)|0;az=0;do{aA=1<<at-az;aw=(c[aF+(az<<2)>>2]|0)+J|0;if(av){I=0;do{ap=aw+(c[F+(I<<2)>>2]|0)|0;aB=(ag(I,aJ)|0)+aK|0;ay=0;do{ax=ap+(c[aG+(ay<<2)>>2]|0)|0;if(((d[aM+((ax|0)/8|0)|0]|0)&128>>>((ax&7)>>>0)|0)!=0){ax=H+(aB+ay)|0;a[ax]=(d[ax]|0|aA)&255}ay=ay+1|0;}while((ay|0)<(aJ|0));I=I+1|0;}while((I|0)<(aE|0))}az=az+1|0;}while((az|0)<(aI|0))}az=aH+1|0;if((az|0)<(aC|0)){aH=az}else{aT=0;break}}}else{aT=0}while(1){if((aT|0)>=1024){break L46816}aU=9638528+(aT<<2)|0;if((c[aU>>2]|0)==(aM|0)){break}else{aT=aT+1|0}}gGr(aM);c[aU>>2]=0}}while(0);aU=c[3531994]|0;L46872:do{if((aU|0)!=0){aM=0;while(1){if((aM|0)>=1024){aV=0;break}aW=9638528+(aM<<2)|0;if((c[aW>>2]|0)==0){V=35641;break}else{aM=aM+1|0}}do{if((V|0)==35641){aM=gGq(aU)|0;c[aW>>2]=aM;if((aM|0)==0){aV=0;break}gGz(aM|0,0,aU|0);aV=aM}}while(0);aM=c[3531994]|0;gGz(aV|0,0,aM|0);aT=c[3532202]|0;aR=c[3532196]|0;aS=c[3532190]|0;aP=c[3531930]|0;aO=c[3531924]|0;aQ=c[3532146]|0;D=c[3532172]|0;C=aR+aT+aS+aP+aO+aQ+D|0;aL=aV+3|0;aN=aV+1048579|0;aH=aV+7|0;aC=aV+1048583|0;aI=aV+2|0;aE=aV+1048578|0;aJ=aV+6|0;H=aV+1048582|0;aG=aV+1|0;F=aV+1048577|0;av=aV+5|0;aF=aV+1048581|0;at=aV+1048576|0;E=aV+4|0;G=aV+1048580|0;do{if(C>>>0<(aQ+D+aO+aP+aS+aR+aT+(c[3531996]|0)|0)>>>0){aD=A+108|0;az=A+100|0;aK=C;J=0;while(1){gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](Q,aK)|0;I=c[R>>2]|0;if((I&255|0)==15){aA=aV+J|0;if((c[3542200]|0)==0){Y=1;V=35858;break}c[aD>>2]=0;c[az>>2]=0;aw=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aw&16383](A,aK)|0;if((c[aD>>2]|0)!=0){aw=c[az>>2]|0;c[B>>2]=9534384;ay=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ay&16383](B,aK,0)|0;if((aw|0)<1){Y=1;V=35852;break}if((gzL(aA,0,aK)|0)!=0){Y=1;V=35853;break}}aA=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aA&16383](Q,aK)|0;aX=(c[S>>2]|0)+J|0;aY=aK+1|0;aZ=c[R>>2]|0}else{aX=J;aY=aK;aZ=I}if((aZ&255|0)==16){if((R6(aV+aX|0,aY,2)|0)!=0){Y=1;V=35854;break}I=aY+1|0;if((R6(aV+(aX+1)|0,I,2)|0)!=0){Y=1;V=35855;break}aA=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aA&16383](Q,aY)|0;aA=(c[S>>2]|0)+aX|0;aw=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aw&16383](Q,I)|0;a_=aA+(c[S>>2]|0)|0;a$=aY+2|0;a0=c[R>>2]|0}else{a_=aX;a$=aY;a0=aZ}if((a0&255|0)==17){if((R6(aV+a_|0,a$,4)|0)!=0){Y=1;V=35856;break}aA=a$+1|0;if((R6(aV+(a_+1)|0,aA,4)|0)!=0){Y=1;V=35857;break}I=a$+2|0;if((R6(aV+(a_+2)|0,I,4)|0)!=0){Y=1;V=35917;break}aw=a$+3|0;if((R6(aV+(a_+3)|0,aw,4)|0)!=0){Y=1;V=35918;break}ay=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ay&16383](Q,a$)|0;ay=(c[S>>2]|0)+a_|0;aB=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aB&16383](Q,aA)|0;aA=ay+(c[S>>2]|0)|0;ay=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ay&16383](Q,I)|0;I=aA+(c[S>>2]|0)|0;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aA&16383](Q,aw)|0;a1=I+(c[S>>2]|0)|0;a2=a$+4|0;a3=c[R>>2]|0}else{a1=a_;a2=a$;a3=a0}if((a3&255|0)==18){if((R6(aL,a2,8)|0)!=0){Y=1;V=35919;break}if((R6(aN,a2+1|0,8)|0)!=0){Y=1;V=35920;break}if((R6(aH,a2+2|0,8)|0)!=0){Y=1;V=35921;break}if((R6(aC,a2+3|0,8)|0)!=0){Y=1;V=35922;break}if((R6(aI,a2+4|0,8)|0)!=0){Y=1;V=35923;break}if((R6(aE,a2+5|0,8)|0)!=0){Y=1;V=35924;break}if((R6(aJ,a2+6|0,8)|0)!=0){Y=1;V=35925;break}if((R6(H,a2+7|0,8)|0)!=0){Y=1;V=35926;break}if((R6(aG,a2+8|0,8)|0)!=0){Y=1;V=35927;break}if((R6(F,a2+9|0,8)|0)!=0){Y=1;V=35928;break}if((R6(av,a2+10|0,8)|0)!=0){Y=1;V=35929;break}if((R6(aF,a2+11|0,8)|0)!=0){Y=1;V=35930;break}if((R6(aV,a2+12|0,8)|0)!=0){Y=1;V=35873;break}if((R6(at,a2+13|0,8)|0)!=0){Y=1;V=35874;break}if((R6(E,a2+14|0,8)|0)!=0){Y=1;V=35875;break}if((R6(G,a2+15|0,8)|0)!=0){Y=1;V=35876;break}a4=a2+16|0}else{a4=a2}if(a4>>>0<((c[3532146]|0)+(c[3532172]|0)+(c[3531924]|0)+(c[3531930]|0)+(c[3532190]|0)+(c[3532196]|0)+(c[3532202]|0)+(c[3531996]|0)|0)>>>0){aK=a4;J=a1}else{V=35680;break}}if((V|0)==35680){a5=a1;a6=c[3531994]|0;break}else if((V|0)==35852){i=e;return Y|0}else if((V|0)==35853){i=e;return Y|0}else if((V|0)==35854){i=e;return Y|0}else if((V|0)==35855){i=e;return Y|0}else if((V|0)==35856){i=e;return Y|0}else if((V|0)==35857){i=e;return Y|0}else if((V|0)==35858){i=e;return Y|0}else if((V|0)==35873){i=e;return Y|0}else if((V|0)==35874){i=e;return Y|0}else if((V|0)==35875){i=e;return Y|0}else if((V|0)==35876){i=e;return Y|0}else if((V|0)==35917){i=e;return Y|0}else if((V|0)==35918){i=e;return Y|0}else if((V|0)==35919){i=e;return Y|0}else if((V|0)==35920){i=e;return Y|0}else if((V|0)==35921){i=e;return Y|0}else if((V|0)==35922){i=e;return Y|0}else if((V|0)==35923){i=e;return Y|0}else if((V|0)==35924){i=e;return Y|0}else if((V|0)==35925){i=e;return Y|0}else if((V|0)==35926){i=e;return Y|0}else if((V|0)==35927){i=e;return Y|0}else if((V|0)==35928){i=e;return Y|0}else if((V|0)==35929){i=e;return Y|0}else if((V|0)==35930){i=e;return Y|0}}else{a5=0;a6=aM}}while(0);if(!((a6|0)==0|a[7460952]^1)){aM=0;do{G=aV+aM|0;a[G]=~a[G];aM=aM+1|0;}while(aM>>>0<a6>>>0)}aM=c[3532034]|0;do{if((aM|0)==0){G=c[3531962]|0;gGC(G|0,aV|0,a5)|0;a7=0}else{G=c[3532e3]|0;E=a[7460944]|0;at=E?16:0;aF=c[3532004]|0;av=c[3531998]|0;F=c[3531992]|0;aG=c[3531990]|0;H=c[3532002]|0;aJ=c[3531962]|0;if((aM|0)<=0){a7=0;break}aE=ag(aF,at)|0;aI=(G|0)>0;aC=G-1|0;aH=(aF|0)<1|E^1;E=0;while(1){aN=ag(E,aE)|0;gGz(aJ+aN|0,0,aE|0);if(aI){aL=ag(E,H)|0;C=0;do{aT=1<<aC-C;aR=(c[av+(C<<2)>>2]|0)+aL|0;if(!aH){aS=0;do{aP=aR+(c[aG+(aS<<2)>>2]|0)|0;aO=(ag(aS,at)|0)+aN|0;D=0;do{aQ=aP+(c[F+(D<<2)>>2]|0)|0;if(((d[aV+((aQ|0)/8|0)|0]|0)&128>>>((aQ&7)>>>0)|0)!=0){aQ=aJ+(aO+D)|0;a[aQ]=(d[aQ]|0|aT)&255}D=D+1|0;}while((D|0)<(at|0));aS=aS+1|0;}while((aS|0)<(aF|0))}C=C+1|0;}while((C|0)<(G|0))}C=E+1|0;if((C|0)<(aM|0)){E=C}else{a7=0;break}}}}while(0);while(1){if((a7|0)>=1024){break L46872}a8=9638528+(a7<<2)|0;if((c[a8>>2]|0)==(aV|0)){break}else{a7=a7+1|0}}gGr(aV);c[a8>>2]=0}}while(0);a8=c[3531984]|0;L46981:do{if((a8|0)!=0){aV=0;while(1){if((aV|0)>=1024){a9=0;break}ba=9638528+(aV<<2)|0;if((c[ba>>2]|0)==0){V=35703;break}else{aV=aV+1|0}}do{if((V|0)==35703){aV=gGq(a8)|0;c[ba>>2]=aV;if((aV|0)==0){a9=0;break}gGz(aV|0,0,a8|0);a9=aV}}while(0);gGz(a9|0,0,c[3531984]|0);aV=c[3532202]|0;a7=c[3532196]|0;a5=c[3532190]|0;a6=c[3531930]|0;a1=c[3531924]|0;a4=c[3532146]|0;a2=c[3532172]|0;a3=c[3531996]|0;a0=a7+aV+a5+a6+a1+a4+a2+a3|0;L46989:do{if(a0>>>0<(a2+a3+a4+a1+a6+a5+a7+aV+(c[3531986]|0)|0)>>>0){a$=y+108|0;a_=y+100|0;aZ=a0;aY=0;while(1){gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](Q,aZ)|0;aX=c[R>>2]|0;if((aX&255|0)==19){B=a9+aY|0;if((c[3542200]|0)==0){Y=1;V=35877;break}c[a$>>2]=0;c[a_>>2]=0;A=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[A&16383](y,aZ)|0;if((c[a$>>2]|0)!=0){A=c[a_>>2]|0;c[z>>2]=9534384;aU=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aU&16383](z,aZ,0)|0;if((A|0)<1){Y=1;V=35859;break}if((gzL(B,0,aZ)|0)!=0){Y=1;V=35860;break}}B=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[B&16383](Q,aZ)|0;bb=(c[S>>2]|0)+aY|0;bc=aZ+1|0;bd=c[R>>2]|0}else{bb=aY;bc=aZ;bd=aX}if((bd&255|0)==20){if((R6(a9+bb|0,bc,2)|0)!=0){Y=1;V=35861;break}aX=bc+1|0;if((R6(a9+(bb+1)|0,aX,2)|0)!=0){Y=1;V=35862;break}B=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[B&16383](Q,bc)|0;B=(c[S>>2]|0)+bb|0;A=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[A&16383](Q,aX)|0;be=B+(c[S>>2]|0)|0;bf=bc+2|0;bg=c[R>>2]|0}else{be=bb;bf=bc;bg=bd}if((bg&255|0)==21){if((R6(a9+be|0,bf,4)|0)!=0){Y=1;V=35863;break}B=bf+1|0;if((R6(a9+(be+1)|0,B,4)|0)!=0){Y=1;V=35864;break}aX=bf+2|0;if((R6(a9+(be+2)|0,aX,4)|0)!=0){Y=1;V=35865;break}A=bf+3|0;if((R6(a9+(be+3)|0,A,4)|0)!=0){Y=1;V=35866;break}aU=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aU&16383](Q,bf)|0;aU=(c[S>>2]|0)+be|0;aW=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aW&16383](Q,B)|0;B=aU+(c[S>>2]|0)|0;aU=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aU&16383](Q,aX)|0;aX=B+(c[S>>2]|0)|0;B=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[B&16383](Q,A)|0;bh=aX+(c[S>>2]|0)|0;bi=bf+4|0}else{bh=be;bi=bf}if(bi>>>0<((c[3532172]|0)+(c[3531996]|0)+(c[3532146]|0)+(c[3531924]|0)+(c[3531930]|0)+(c[3532190]|0)+(c[3532196]|0)+(c[3532202]|0)+(c[3531986]|0)|0)>>>0){aZ=bi;aY=bh}else{break L46989}}if((V|0)==35859){i=e;return Y|0}else if((V|0)==35860){i=e;return Y|0}else if((V|0)==35861){i=e;return Y|0}else if((V|0)==35862){i=e;return Y|0}else if((V|0)==35863){i=e;return Y|0}else if((V|0)==35864){i=e;return Y|0}else if((V|0)==35865){i=e;return Y|0}else if((V|0)==35866){i=e;return Y|0}else if((V|0)==35877){i=e;return Y|0}}}while(0);a0=a[7460976]|0;aV=a0?16384:0;a7=a[7460920]|0;a5=a7?4:0;a6=a[7460912]|0;a1=a6?16:0;a4=a[7460936]|0;a3=a4?16:0;a2=c[3531988]|0;aY=c[3531982]|0;aZ=c[3531980]|0;a_=a[7460928]|0?1024:0;a$=c[3531960]|0;if(a0){a0=ag(a3,a1)|0;aX=a5-1|0;A=a4&a6;a6=0;while(1){a4=ag(a6,a0)|0;gGz(a$+a4|0,0,a0|0);if(a7){B=ag(a6,a_)|0;aU=0;do{aW=1<<aX-aU;aM=(c[a2+(aU<<2)>>2]|0)+B|0;if(A){E=0;do{G=aM+(c[aZ+(E<<2)>>2]|0)|0;aF=(ag(E,a1)|0)+a4|0;at=0;do{aJ=G+(c[aY+(at<<2)>>2]|0)|0;if(((d[a9+((aJ|0)/8|0)|0]|0)&128>>>((aJ&7)>>>0)|0)!=0){aJ=a$+(aF+at)|0;a[aJ]=(d[aJ]|0|aW)&255}at=at+1|0;}while((at|0)<(a1|0));E=E+1|0;}while((E|0)<(a3|0))}aU=aU+1|0;}while((aU|0)<(a5|0))}aU=a6+1|0;if((aU|0)<(aV|0)){a6=aU}else{bj=0;break}}}else{bj=0}while(1){if((bj|0)>=1024){break L46981}bk=9638528+(bj<<2)|0;if((c[bk>>2]|0)==(a9|0)){break}else{bj=bj+1|0}}gGr(a9);c[bk>>2]=0}}while(0);do{if((c[3532010]|0)!=0){bk=c[3532202]|0;a9=c[3532196]|0;bj=c[3532190]|0;bh=c[3531930]|0;bi=c[3531924]|0;bf=c[3532146]|0;be=c[3532172]|0;bg=c[3531996]|0;bd=c[3531986]|0;bc=a9+bk+bj+bh+bi+bf+be+bg+bd|0;if(bc>>>0>=(bg+bd+bi+bh+be+bf+bj+a9+bk+(c[3532012]|0)|0)>>>0){break}bk=w+108|0;a9=w+100|0;bj=bc;bc=0;while(1){bf=(c[3532270]|0)+bc|0;do{if((c[3542200]|0)!=0){c[bk>>2]=0;c[a9>>2]=0;be=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[be&16383](w,bj)|0;if((c[bk>>2]|0)==0){break}be=c[a9>>2]|0;c[x>>2]=9534384;bh=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[bh&16383](x,bj,0)|0;if((be|0)<1){break}gzL(bf,0,bj)|0}}while(0);gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](Q,bj)|0;bf=bj+1|0;if(bf>>>0<((c[3531996]|0)+(c[3531986]|0)+(c[3531924]|0)+(c[3531930]|0)+(c[3532172]|0)+(c[3532146]|0)+(c[3532190]|0)+(c[3532196]|0)+(c[3532202]|0)+(c[3532012]|0)|0)>>>0){bj=bf;bc=(c[S>>2]|0)+bc|0}else{break}}}}while(0);do{if((c[3531972]|0)!=0){x=c[3532202]|0;w=c[3532196]|0;bc=c[3532190]|0;bj=c[3531930]|0;a9=c[3531924]|0;bk=c[3532146]|0;bf=c[3532172]|0;be=c[3531996]|0;bh=c[3531986]|0;bi=c[3532012]|0;bd=w+x+bc+bj+a9+bk+bf+be+bh+bi|0;if(bd>>>0>=(bh+bi+be+a9+bj+bf+bk+bc+w+x+(c[3531974]|0)|0)>>>0){break}x=u+108|0;w=u+100|0;bc=bd;bd=0;while(1){bk=(c[3531976]|0)+bd|0;do{if((c[3542200]|0)!=0){c[x>>2]=0;c[w>>2]=0;bf=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[bf&16383](u,bc)|0;if((c[x>>2]|0)==0){break}bf=c[w>>2]|0;c[v>>2]=9534384;bj=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[bj&16383](v,bc,0)|0;if((bf|0)<1){break}gzL(bk,0,bc)|0}}while(0);gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](Q,bc)|0;bk=bc+1|0;if(bk>>>0<((c[3531986]|0)+(c[3532012]|0)+(c[3531996]|0)+(c[3531924]|0)+(c[3531930]|0)+(c[3532172]|0)+(c[3532146]|0)+(c[3532190]|0)+(c[3532196]|0)+(c[3532202]|0)+(c[3531974]|0)|0)>>>0){bc=bk;bd=(c[S>>2]|0)+bd|0}else{break}}}}while(0);do{if((c[3531948]|0)!=0){v=c[3532202]|0;u=c[3532196]|0;bd=c[3532190]|0;bc=c[3531930]|0;w=c[3531924]|0;x=c[3532146]|0;bk=c[3532172]|0;bf=c[3531996]|0;bj=c[3531986]|0;a9=c[3532012]|0;be=c[3531974]|0;bi=u+v+bd+bc+w+x+bk+bf+bj+a9+be|0;if(bi>>>0>=(a9+be+bj+bf+bk+x+w+bc+bd+u+v+(c[3531950]|0)|0)>>>0){break}v=s+108|0;u=s+100|0;bd=bi;bi=0;while(1){bc=(c[3531952]|0)+bi|0;do{if((c[3542200]|0)!=0){c[v>>2]=0;c[u>>2]=0;w=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[w&16383](s,bd)|0;if((c[v>>2]|0)==0){break}w=c[u>>2]|0;c[t>>2]=9534384;x=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[x&16383](t,bd,0)|0;if((w|0)<1){break}gzL(bc,0,bd)|0}}while(0);gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](Q,bd)|0;bc=bd+1|0;if(bc>>>0<((c[3532012]|0)+(c[3531974]|0)+(c[3531986]|0)+(c[3531996]|0)+(c[3532172]|0)+(c[3532146]|0)+(c[3531924]|0)+(c[3531930]|0)+(c[3532190]|0)+(c[3532196]|0)+(c[3532202]|0)+(c[3531950]|0)|0)>>>0){bd=bc;bi=(c[S>>2]|0)+bi|0}else{break}}}}while(0);do{if((c[3531942]|0)!=0){t=c[3532202]|0;s=c[3532196]|0;bi=c[3532190]|0;bd=c[3531930]|0;u=c[3531924]|0;v=c[3532146]|0;bc=c[3532172]|0;w=c[3531996]|0;x=c[3531986]|0;bk=c[3532012]|0;bf=c[3531974]|0;bj=c[3531950]|0;be=s+t+bi+bd+u+v+bc+w+x+bk+bf+bj|0;if(be>>>0>=(bf+bj+bk+x+w+bc+v+u+bd+bi+s+t+(c[3531944]|0)|0)>>>0){break}t=q+108|0;s=q+100|0;bi=be;be=0;while(1){bd=(c[3531946]|0)+be|0;do{if((c[3542200]|0)!=0){c[t>>2]=0;c[s>>2]=0;u=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[u&16383](q,bi)|0;if((c[t>>2]|0)==0){break}u=c[s>>2]|0;c[r>>2]=9534384;v=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[v&16383](r,bi,0)|0;if((u|0)<1){break}gzL(bd,0,bi)|0}}while(0);gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](Q,bi)|0;bd=bi+1|0;if(bd>>>0<((c[3531974]|0)+(c[3531950]|0)+(c[3532012]|0)+(c[3531986]|0)+(c[3531996]|0)+(c[3532172]|0)+(c[3532146]|0)+(c[3531924]|0)+(c[3531930]|0)+(c[3532190]|0)+(c[3532196]|0)+(c[3532202]|0)+(c[3531944]|0)|0)>>>0){bi=bd;be=(c[S>>2]|0)+be|0}else{break}}}}while(0);L47092:do{if((c[3532058]|0)!=0){r=c[3532202]|0;q=c[3532196]|0;be=c[3532190]|0;bi=c[3531930]|0;s=c[3531924]|0;t=c[3532146]|0;bd=c[3532172]|0;u=c[3531996]|0;v=c[3531986]|0;bc=c[3532012]|0;w=c[3531974]|0;x=c[3531950]|0;bk=c[3531944]|0;bj=q+r+be+bi+s+t+bd+u+v+bc+w+x+bk|0;if(bj>>>0>=(x+bk+w+bc+v+u+bd+t+s+bi+be+q+r+(c[3532060]|0)|0)>>>0){break}r=o+108|0;q=o+100|0;be=bj;bj=0;while(1){gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](Q,be)|0;bi=c[R>>2]|0;if((bi&255|0)==26){s=(c[3532062]|0)+bj|0;if((c[3542200]|0)==0){Y=1;V=35867;break}c[r>>2]=0;c[q>>2]=0;t=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[t&16383](o,be)|0;if((c[r>>2]|0)!=0){t=c[q>>2]|0;c[p>>2]=9534384;bd=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[bd&16383](p,be,0)|0;if((t|0)<1){Y=1;V=35868;break}if((gzL(s,0,be)|0)!=0){Y=1;V=35869;break}}s=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[s&16383](Q,be)|0;bl=(c[S>>2]|0)+bj|0;bm=be+1|0;bn=c[R>>2]|0}else{bl=bj;bm=be;bn=bi}if((bn&255|0)==27){if((R6((c[3532062]|0)+bl|0,bm,2)|0)!=0){Y=1;V=35870;break}bi=bm+1|0;if((R6((c[3532062]|0)+(bl+1)|0,bi,2)|0)!=0){Y=1;V=35871;break}s=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[s&16383](Q,bm)|0;s=(c[S>>2]|0)+bl|0;t=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[t&16383](Q,bi)|0;bo=s+(c[S>>2]|0)|0;bp=bm+2|0}else{bo=bl;bp=bm}if(bp>>>0<((c[3531950]|0)+(c[3531944]|0)+(c[3531974]|0)+(c[3532012]|0)+(c[3531986]|0)+(c[3531996]|0)+(c[3532172]|0)+(c[3532146]|0)+(c[3531924]|0)+(c[3531930]|0)+(c[3532190]|0)+(c[3532196]|0)+(c[3532202]|0)+(c[3532060]|0)|0)>>>0){be=bp;bj=bo}else{break L47092}}if((V|0)==35867){i=e;return Y|0}else if((V|0)==35868){i=e;return Y|0}else if((V|0)==35869){i=e;return Y|0}else if((V|0)==35870){i=e;return Y|0}else if((V|0)==35871){i=e;return Y|0}}}while(0);bo=c[3532154]|0;L47117:do{if((bo|0)!=0){bp=0;while(1){if((bp|0)>=1024){bq=0;break}br=9638528+(bp<<2)|0;if((c[br>>2]|0)==0){V=35788;break}else{bp=bp+1|0}}do{if((V|0)==35788){bp=gGq(bo)|0;c[br>>2]=bp;if((bp|0)==0){bq=0;break}gGz(bp|0,0,bo|0);bq=bp}}while(0);gGz(bq|0,0,c[3532154]|0);bp=m+108|0;bm=m+100|0;bl=0;bn=(c[3532196]|0)+(c[3532202]|0)+(c[3532190]|0)+(c[3531930]|0)+(c[3531924]|0)+(c[3532146]|0)+(c[3532172]|0)+(c[3531996]|0)+(c[3531986]|0)+(c[3532012]|0)+(c[3531974]|0)+(c[3531950]|0)+(c[3531944]|0)+(c[3532060]|0)|0;L47125:while(1){do{if(bn>>>0>=((c[3532196]|0)+(c[3532202]|0)+(c[3532190]|0)+(c[3531930]|0)+(c[3531924]|0)+(c[3532146]|0)+(c[3532172]|0)+(c[3531996]|0)+(c[3531986]|0)+(c[3532012]|0)+(c[3531974]|0)+(c[3531950]|0)+(c[3531944]|0)+(c[3532060]|0)+(c[3532156]|0)|0)>>>0){V=35799;break L47125}gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](Q,bn)|0;}while((c[R>>2]&255|0)!=28);p=bq+bl|0;if((c[3542200]|0)==0){Y=1;V=35872;break}c[bp>>2]=0;c[bm>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,bn)|0;if((c[bp>>2]|0)!=0){o=c[bm>>2]|0;c[n>>2]=9534384;bj=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[bj&16383](n,bn,0)|0;if((o|0)<1){Y=1;V=35904;break}if((gzL(p,0,bn)|0)!=0){Y=1;V=35905;break}}gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](Q,bn)|0;bl=(c[S>>2]|0)+bl|0;bn=bn+1|0}if((V|0)==35799){bn=c[3532038]|0;bl=a[7461176]|0;bm=bl?4:0;bp=a[7461168]|0;p=bp?8:0;o=a[7461192]|0;bj=o?8:0;be=c[3532158]|0;q=c[3532152]|0;r=c[3532150]|0;s=a[7461184]|0?256:0;bi=c[3532132]|0;if((bn|0)>0){t=ag(bj,p)|0;bd=bm-1|0;u=o&bp;bp=0;while(1){o=ag(bp,t)|0;gGz(bi+o|0,0,t|0);if(bl){v=ag(bp,s)|0;bc=0;do{w=1<<bd-bc;bk=(c[be+(bc<<2)>>2]|0)+v|0;if(u){x=0;do{bf=bk+(c[r+(x<<2)>>2]|0)|0;a9=(ag(x,p)|0)+o|0;bh=0;do{bg=bf+(c[q+(bh<<2)>>2]|0)|0;if(((d[bq+((bg|0)/8|0)|0]|0)&128>>>((bg&7)>>>0)|0)!=0){bg=bi+(a9+bh)|0;a[bg]=(d[bg]|0|w)&255}bh=bh+1|0;}while((bh|0)<(p|0));x=x+1|0;}while((x|0)<(bj|0))}bc=bc+1|0;}while((bc|0)<(bm|0))}bc=bp+1|0;if((bc|0)<(bn|0)){bp=bc}else{bs=0;break}}}else{bs=0}while(1){if((bs|0)>=1024){break L47117}bt=9638528+(bs<<2)|0;if((c[bt>>2]|0)==(bq|0)){break}else{bs=bs+1|0}}gGr(bq);c[bt>>2]=0;break}else if((V|0)==35872){i=e;return Y|0}else if((V|0)==35904){i=e;return Y|0}else if((V|0)==35905){i=e;return Y|0}}}while(0);L47165:do{if((c[3532052]|0)!=0){bt=k+108|0;bq=k+100|0;bs=0;n=(c[3532196]|0)+(c[3532202]|0)+(c[3532190]|0)+(c[3531930]|0)+(c[3531924]|0)+(c[3532146]|0)+(c[3532172]|0)+(c[3531996]|0)+(c[3531986]|0)+(c[3532012]|0)+(c[3531974]|0)+(c[3531950]|0)+(c[3531944]|0)+(c[3532060]|0)+(c[3532156]|0)|0;while(1){do{if(n>>>0>=((c[3532196]|0)+(c[3532202]|0)+(c[3532190]|0)+(c[3531930]|0)+(c[3531924]|0)+(c[3532146]|0)+(c[3532172]|0)+(c[3531996]|0)+(c[3531986]|0)+(c[3532012]|0)+(c[3531974]|0)+(c[3531950]|0)+(c[3531944]|0)+(c[3532060]|0)+(c[3532156]|0)+(c[3532054]|0)|0)>>>0){break L47165}gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](Q,n)|0;}while((c[R>>2]&255|0)!=29);m=(c[3532056]|0)+bs|0;if((c[3542200]|0)==0){Y=1;V=35906;break}c[bt>>2]=0;c[bq>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,n)|0;if((c[bt>>2]|0)!=0){bo=c[bq>>2]|0;c[l>>2]=9534384;br=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[br&16383](l,n,0)|0;if((bo|0)<1){Y=1;V=35907;break}if((gzL(m,0,n)|0)!=0){Y=1;V=35908;break}}gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](Q,n)|0;bs=(c[S>>2]|0)+bs|0;n=n+1|0}if((V|0)==35906){i=e;return Y|0}else if((V|0)==35907){i=e;return Y|0}else if((V|0)==35908){i=e;return Y|0}}}while(0);L47183:do{if((c[3532112]|0)!=0){l=c[3532202]|0;k=c[3532196]|0;n=c[3532190]|0;bs=c[3531930]|0;bq=c[3531924]|0;bt=c[3532146]|0;m=c[3532172]|0;bo=c[3531996]|0;br=c[3531986]|0;bp=c[3532012]|0;bn=c[3531974]|0;bm=c[3531950]|0;bj=c[3531944]|0;p=c[3532060]|0;bi=c[3532156]|0;q=c[3532054]|0;r=h+108|0;u=h+100|0;be=0;bd=k+l+n+bs+bq+bt+m+bo+br+bp+bn+bm+bj+p+bi+q|0;s=l;l=k;k=n;n=bs;bs=bq;bq=bt;bt=m;m=bo;bo=br;br=bp;bp=bn;bn=bm;bm=bj;bj=p;p=bi;bi=q;while(1){if(bd>>>0>=(p+bi+bj+bm+bn+bp+br+bo+m+bt+bq+bs+n+k+l+s+(c[3532114]|0)|0)>>>0){break L47183}gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](Q,bd)|0;q=c[R>>2]|0;if((q&255|0)==30){bl=(c[3532116]|0)+be|0;if((c[3542200]|0)==0){Y=1;V=35909;break}c[r>>2]=0;c[u>>2]=0;t=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[t&16383](h,bd)|0;if((c[r>>2]|0)!=0){t=c[u>>2]|0;c[j>>2]=9534384;bc=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[bc&16383](j,bd,0)|0;if((t|0)<1){Y=1;V=35910;break}if((gzL(bl,0,bd)|0)!=0){Y=1;V=35911;break}}bl=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[bl&16383](Q,bd)|0;bu=(c[S>>2]|0)+be|0;bv=bd+1|0;bw=c[R>>2]|0}else{bu=be;bv=bd;bw=q}if((bw&255|0)==31){if((R6((c[3532116]|0)+(bu<<1)|0,bv,2)|0)!=0){Y=1;V=35912;break}q=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[q&16383](Q,bv)|0;bx=(c[S>>2]|0)+bu|0;by=bv+1|0}else{bx=bu;by=bv}be=bx;bd=by;s=c[3532202]|0;l=c[3532196]|0;k=c[3532190]|0;n=c[3531930]|0;bs=c[3531924]|0;bq=c[3532146]|0;bt=c[3532172]|0;m=c[3531996]|0;bo=c[3531986]|0;br=c[3532012]|0;bp=c[3531974]|0;bn=c[3531950]|0;bm=c[3531944]|0;bj=c[3532060]|0;p=c[3532156]|0;bi=c[3532054]|0}if((V|0)==35909){i=e;return Y|0}else if((V|0)==35910){i=e;return Y|0}else if((V|0)==35911){i=e;return Y|0}else if((V|0)==35912){i=e;return Y|0}}}while(0);if((c[3532122]|0)==0){Y=0;i=e;return Y|0}by=f+108|0;bx=f+100|0;bv=0;bu=(c[3532196]|0)+(c[3532202]|0)+(c[3532190]|0)+(c[3531930]|0)+(c[3531924]|0)+(c[3532146]|0)+(c[3532172]|0)+(c[3531996]|0)+(c[3531986]|0)+(c[3532012]|0)+(c[3531974]|0)+(c[3531950]|0)+(c[3531944]|0)+(c[3532060]|0)+(c[3532156]|0)+(c[3532054]|0)+(c[3532114]|0)|0;L47209:while(1){do{if(bu>>>0>=((c[3532196]|0)+(c[3532202]|0)+(c[3532190]|0)+(c[3531930]|0)+(c[3531924]|0)+(c[3532146]|0)+(c[3532172]|0)+(c[3531996]|0)+(c[3531986]|0)+(c[3532012]|0)+(c[3531974]|0)+(c[3531950]|0)+(c[3531944]|0)+(c[3532060]|0)+(c[3532156]|0)+(c[3532054]|0)+(c[3532114]|0)+(c[3532124]|0)|0)>>>0){Y=0;V=35914;break L47209}gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](Q,bu)|0;}while((c[R>>2]&255|0)!=32);bw=(c[3532126]|0)+bv|0;if((c[3542200]|0)==0){Y=1;V=35915;break}c[by>>2]=0;c[bx>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,bu)|0;if((c[by>>2]|0)!=0){j=c[bx>>2]|0;c[g>>2]=9534384;h=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[h&16383](g,bu,0)|0;if((j|0)<1){Y=1;V=35898;break}if((gzL(bw,0,bu)|0)!=0){Y=1;V=35899;break}}gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](Q,bu)|0;bv=(c[S>>2]|0)+bv|0;bu=bu+1|0}if((V|0)==35898){i=e;return Y|0}else if((V|0)==35899){i=e;return Y|0}else if((V|0)==35914){i=e;return Y|0}else if((V|0)==35915){i=e;return Y|0}return 0}function e_a(){var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0;d=i;i=i+128|0;e=d|0;if((c[3532044]|0)!=0){if((c[2392]|0)>=0){f=0;do{g=14130368+(f<<2)|0;h=c[g>>2]|0;if((h|0)!=0){gGr(h);c[g>>2]=0}g=14130384+(f<<2)|0;h=c[g>>2]|0;if((h|0)!=0){gGr(h);c[g>>2]=0}f=f+1|0;}while((f|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1}if((c[3532030]|0)!=0){fwZ()}if(a[7460960]|0){f=c[3541514]|0;if((f|0)!=0){gGr(f|0);c[3541514]=0}c[2113008]=0;c[2076598]=0;c[2383582]=0;c[2438228]=0;c[2433526]=0;c[2406676]=0;c[3528472]=0;f=c[2406698]|0;if((f|0)!=0){gGr(f);c[2406698]=0}f=c[2385412]|0;if((f|0)!=0){gGr(f);c[2385412]=0}a[64232]=0}do{if(a[7460968]|0){f=c[3531464]|0;c[f+44344>>2]=0;c[f+44348>>2]=0;if((f|0)!=0){gGr(f);c[3531464]=0}f=c[2406684]|0;if((f|0)==0){break}gGr(f);c[2406684]=0}}while(0);if((c[3532032]|0)!=0){f=c[3541518]|0;if((f|0)!=0){gGr(f|0);c[3541518]=0}if((c[2385508]|0)>0){c[2113008]=0;c[2076598]=0;c[2383582]=0}c[2438228]=0;c[2433526]=0;c[2406676]=0;c[3528472]=0;f=c[2406680]|0;if((f|0)!=0){gGr(f);c[2406680]=0}c[2385508]=0;c[2432978]=0;a[64240]=0}do{if((c[3532036]|0)!=0){c[2415126]=9662152;f=c[2408988]|0;if((f|0)!=0){gGz(9662152,0,3224);g=f;f=0;while(1){if((f|0)>=1024){break}j=9638528+(f<<2)|0;if((c[j>>2]|0)==(g|0)){k=35969;break}else{f=f+1|0}}if((k|0)==35969){gGr(g);c[j>>2]=0}c[2408988]=0}c[2415126]=9665376;f=c[2408989]|0;if((f|0)==0){break}gGz(9665376,0,3224);h=f;f=0;while(1){if((f|0)>=1024){break}l=9638528+(f<<2)|0;if((c[l>>2]|0)==(h|0)){k=35975;break}else{f=f+1|0}}if((k|0)==35975){gGr(h);c[l>>2]=0}c[2408989]=0}}while(0);if(a[7460984]|0){l=0;do{Uw(l);l=l+1|0;}while((l|0)<(a[7460984]&1|0))}do{if(a[7460992]|0){l=e|0;j=c[c[642608+(c[2436]<<2)>>2]>>2]|0;be(l|0,128,179600,(f=i,i=i+24|0,c[f>>2]=9374064,c[f+8>>2]=47,c[f+16>>2]=j,f)|0)|0;i=f;a[1040128]=0;f=c[2420380]|0;j=c[f>>2]|0;g=c[f+4>>2]|0;f=fw(l|0,389440)|0;if((f|0)==0){break}l=g>>3<<j&1023;cj(14100392,l|0,1,f|0)|0;aY(f|0)|0}}while(0);if(a[7461104]|0){a[14109952]=0;a[9771792]=0}if(a[7461144]|0){e=c[2439440]|0;f=0;while(1){if((f|0)>=1024){break}m=9638528+(f<<2)|0;if((c[m>>2]|0)==(e|0)){k=35988;break}else{f=f+1|0}}if((k|0)==35988){gGr(e);c[m>>2]=0}c[2439440]=0}if(a[7461112]|0){m=c[2424896]|0;e=0;while(1){if((e|0)>=1024){break}n=9638528+(e<<2)|0;if((c[n>>2]|0)==(m|0)){k=35994;break}else{e=e+1|0}}if((k|0)==35994){gGr(m);c[n>>2]=0}c[2424896]=0;n=c[2424897]|0;m=0;while(1){if((m|0)>=1024){break}o=9638528+(m<<2)|0;if((c[o>>2]|0)==(n|0)){k=35998;break}else{m=m+1|0}}if((k|0)==35998){gGr(n);c[o>>2]=0}c[2424897]=0;o=c[2424898]|0;n=0;while(1){if((n|0)>=1024){break}p=9638528+(n<<2)|0;if((c[p>>2]|0)==(o|0)){k=36002;break}else{n=n+1|0}}if((k|0)==36002){gGr(o);c[p>>2]=0}c[2424898]=0;p=c[2424899]|0;o=0;while(1){if((o|0)>=1024){break}q=9638528+(o<<2)|0;if((c[q>>2]|0)==(p|0)){k=36006;break}else{o=o+1|0}}if((k|0)==36006){gGr(p);c[q>>2]=0}c[2424899]=0;q=c[2424900]|0;p=0;while(1){if((p|0)>=1024){break}r=9638528+(p<<2)|0;if((c[r>>2]|0)==(q|0)){k=36010;break}else{p=p+1|0}}if((k|0)==36010){gGr(q);c[r>>2]=0}c[2424900]=0;r=c[2424901]|0;q=0;while(1){if((q|0)>=1024){break}s=9638528+(q<<2)|0;if((c[s>>2]|0)==(r|0)){k=36014;break}else{q=q+1|0}}if((k|0)==36014){gGr(r);c[s>>2]=0}c[2424901]=0;s=c[2424902]|0;r=0;while(1){if((r|0)>=1024){break}t=9638528+(r<<2)|0;if((c[t>>2]|0)==(s|0)){k=36018;break}else{r=r+1|0}}if((k|0)==36018){gGr(s);c[t>>2]=0}c[2424902]=0;t=c[2424903]|0;s=0;while(1){if((s|0)>=1024){break}u=9638528+(s<<2)|0;if((c[u>>2]|0)==(t|0)){k=36022;break}else{s=s+1|0}}if((k|0)==36022){gGr(t);c[u>>2]=0}c[2424903]=0;c[2443344]=0;a[14109952]=0}if(a[7461136]|0){u=c[2406600]|0;t=0;while(1){if((t|0)>=1024){break}v=9638528+(t<<2)|0;if((c[v>>2]|0)==(u|0)){k=36028;break}else{t=t+1|0}}if((k|0)==36028){gGr(u);c[v>>2]=0}c[2406600]=0;c[3527516]=0;a[9774608]=0;a[9774624]=0;a[9774616]=0;a[14124928]=0;a[14124929]=0;a[818400]=0;a[818392]=0;a[818401]=0;a[818393]=0;a[14109952]=0;a[14124912]=0;a[9698784]=0;a[9698776]=0;a[9698768]=0}if(a[7461e3]|0){v=c[2077632]|0;u=0;while(1){if((u|0)>=1024){break}w=9638528+(u<<2)|0;if((c[w>>2]|0)==(v|0)){k=36034;break}else{u=u+1|0}}if((k|0)==36034){gGr(v);c[w>>2]=0}c[2077632]=0}if(a[7461128]|0){w=c[3528994]|0;if((w|0)>0){v=0;u=w;while(1){w=14163912+(v<<2)|0;t=c[w>>2]|0;s=0;while(1){if((s|0)>=1024){x=u;break}y=9638528+(s<<2)|0;if((c[y>>2]|0)==(t|0)){k=36041;break}else{s=s+1|0}}if((k|0)==36041){k=0;gGr(t);c[y>>2]=0;x=c[3528994]|0}c[w>>2]=0;gGz(14108184+(v<<4)|0,0,16);c[9553368+(v<<2)>>2]=0;c[9553328+(v<<2)>>2]=0;c[9543296+(v<<2)>>2]=0;c[9543272+(v<<2)>>2]=0;c[9748120+(v<<2)>>2]=0;c[9754520+(v<<2)>>2]=0;c[9754504+(v<<2)>>2]=0;c[9708200+(v<<2)>>2]=0;c[9754512+(v<<2)>>2]=0;c[9748128+(v<<2)>>2]=0;c[14108216+(v<<2)>>2]=0;s=v+1|0;if((s|0)<(x|0)){v=s;u=x}else{break}}}c[3528994]=0}if(a[7461120]|0){x=c[3540976]|0;u=0;while(1){if((u|0)>=1024){break}z=9638528+(u<<2)|0;if((c[z>>2]|0)==(x|0)){k=36048;break}else{u=u+1|0}}if((k|0)==36048){gGr(x);c[z>>2]=0}c[3540976]=0;c[2437028]=0;c[2438624]=0;a[726072]=0;c[3540974]=0}if(a[7461096]|0){if((c[2442930]|0)>0){z=0;do{x=14129112+(z<<2)|0;u=c[x>>2]|0;v=0;while(1){if((v|0)>=1024){break}A=9638528+(v<<2)|0;if((c[A>>2]|0)==(u|0)){k=36055;break}else{v=v+1|0}}if((k|0)==36055){k=0;gGr(u);c[A>>2]=0}c[x>>2]=0;v=9753632+(z<<2)|0;w=c[v>>2]|0;t=0;while(1){if((t|0)>=1024){break}B=9638528+(t<<2)|0;if((c[B>>2]|0)==(w|0)){k=36059;break}else{t=t+1|0}}if((k|0)==36059){k=0;gGr(w);c[B>>2]=0}c[v>>2]=0;t=9717408+(z<<2)|0;x=c[t>>2]|0;u=0;while(1){if((u|0)>=1024){break}D=9638528+(u<<2)|0;if((c[D>>2]|0)==(x|0)){k=36063;break}else{u=u+1|0}}if((k|0)==36063){k=0;gGr(x);c[D>>2]=0}c[t>>2]=0;u=9717392+(z<<2)|0;v=c[u>>2]|0;w=0;while(1){if((w|0)>=1024){break}E=9638528+(w<<2)|0;if((c[E>>2]|0)==(v|0)){k=36067;break}else{w=w+1|0}}if((k|0)==36067){k=0;gGr(v);c[E>>2]=0}c[u>>2]=0;w=14129152+(z<<4)|0;t=w|0;C=0;b[t>>1]=C&65535;b[t+2>>1]=C>>16;t=w+4|0;C=0;b[t>>1]=C&65535;b[t+2>>1]=C>>16;c[9553376+(z<<2)>>2]=0;c[9553336+(z<<2)>>2]=0;c[9543304+(z<<2)>>2]=0;c[9543280+(z<<2)>>2]=0;c[14110008+(z<<2)>>2]=0;c[14109976+(z<<2)>>2]=0;c[9733176+(z<<2)>>2]=0;c[9733160+(z<<2)>>2]=0;c[9717864+(z<<2)>>2]=0;c[9757584+(z<<2)>>2]=0;c[9717848+(z<<2)>>2]=0;c[9717880+(z<<2)>>2]=0;c[9733208+(z<<2)>>2]=0;c[9733192+(z<<2)>>2]=0;c[14129136+(z<<2)>>2]=0;c[9720240+(z<<2)>>2]=0;c[9718808+(z<<2)>>2]=0;c[9718792+(z<<2)>>2]=0;c[9708304+(z<<2)>>2]=0;a[14129208+z|0]=0;a[14129128+z|0]=0;a[14129200+z|0]=0;z=z+1|0;}while((z|0)<(c[2442930]|0))}c[2442930]=0}if(a[7461088]|0){z=c[2442928]|0;E=0;while(1){if((E|0)>=1024){break}F=9638528+(E<<2)|0;if((c[F>>2]|0)==(z|0)){k=36074;break}else{E=E+1|0}}if((k|0)==36074){gGr(z);c[F>>2]=0}c[2442928]=0;c[2439392]=0;F=c[2442926]|0;z=0;while(1){if((z|0)>=1024){break}G=9638528+(z<<2)|0;if((c[G>>2]|0)==(F|0)){k=36078;break}else{z=z+1|0}}if((k|0)==36078){gGr(F);c[G>>2]=0}c[2442926]=0;c[2439393]=0;G=c[2442924]|0;F=0;while(1){if((F|0)>=1024){break}H=9638528+(F<<2)|0;if((c[H>>2]|0)==(G|0)){k=36082;break}else{F=F+1|0}}if((k|0)==36082){gGr(G);c[H>>2]=0}c[2442924]=0;c[2439394]=0;H=c[3532276]|0;G=0;while(1){if((G|0)>=1024){break}I=9638528+(G<<2)|0;if((c[I>>2]|0)==(H|0)){k=36086;break}else{G=G+1|0}}if((k|0)==36086){gGr(H);c[I>>2]=0}c[3532276]=0;c[3532274]=0}if(a[7461080]|0){gGz(9540888,0,13)}if(a[7461072]|0){I=c[3532270]|0;H=0;while(1){if((H|0)>=1024){break}J=9638528+(H<<2)|0;if((c[J>>2]|0)==(I|0)){k=36094;break}else{H=H+1|0}}if((k|0)==36094){gGr(I);c[J>>2]=0}c[3532270]=0;J=c[3532272]|0;I=0;while(1){if((I|0)>=1024){break}K=9638528+(I<<2)|0;if((c[K>>2]|0)==(J|0)){k=36098;break}else{I=I+1|0}}if((k|0)==36098){gGr(J);c[K>>2]=0}c[3532272]=0;a[725176]=0}if(a[7461064]|0){K=c[2430810]|0;J=0;while(1){if((J|0)>=1024){break}L=9638528+(J<<2)|0;if((c[L>>2]|0)==(K|0)){k=36104;break}else{J=J+1|0}}if((k|0)==36104){gGr(K);c[L>>2]=0}c[2430810]=0;L=c[2430808]|0;K=0;while(1){if((K|0)>=1024){break}M=9638528+(K<<2)|0;if((c[M>>2]|0)==(L|0)){k=36108;break}else{K=K+1|0}}if((k|0)==36108){gGr(L);c[M>>2]=0}c[2430808]=0;c[2388448]=-1;c[2388452]=0;M=c[2429460]|0;L=0;while(1){if((L|0)>=1024){break}N=9638528+(L<<2)|0;if((c[N>>2]|0)==(M|0)){k=36112;break}else{L=L+1|0}}if((k|0)==36112){gGr(M);c[N>>2]=0}c[2429460]=0;N=c[2440184]|0;M=0;while(1){if((M|0)>=1024){break}O=9638528+(M<<2)|0;if((c[O>>2]|0)==(N|0)){k=36116;break}else{M=M+1|0}}if((k|0)==36116){gGr(N);c[O>>2]=0}c[2440184]=0;O=c[2430811]|0;N=0;while(1){if((N|0)>=1024){break}P=9638528+(N<<2)|0;if((c[P>>2]|0)==(O|0)){k=36120;break}else{N=N+1|0}}if((k|0)==36120){gGr(O);c[P>>2]=0}c[2430811]=0;P=c[2430809]|0;O=0;while(1){if((O|0)>=1024){break}Q=9638528+(O<<2)|0;if((c[Q>>2]|0)==(P|0)){k=36124;break}else{O=O+1|0}}if((k|0)==36124){gGr(P);c[Q>>2]=0}c[2430809]=0;c[2388446]=-1;c[2388450]=0;Q=c[2429461]|0;P=0;while(1){if((P|0)>=1024){break}R=9638528+(P<<2)|0;if((c[R>>2]|0)==(Q|0)){k=36128;break}else{P=P+1|0}}if((k|0)==36128){gGr(Q);c[R>>2]=0}c[2429461]=0;R=c[2440182]|0;Q=0;while(1){if((Q|0)>=1024){break}S=9638528+(Q<<2)|0;if((c[S>>2]|0)==(R|0)){k=36132;break}else{Q=Q+1|0}}if((k|0)==36132){gGr(R);c[S>>2]=0}c[2440182]=0;S=c[3528790]|0;R=0;while(1){if((R|0)>=1024){break}T=9638528+(R<<2)|0;if((c[T>>2]|0)==(S|0)){k=36136;break}else{R=R+1|0}}if((k|0)==36136){gGr(S);c[T>>2]=0}c[3528790]=0;T=c[3532266]|0;S=0;while(1){if((S|0)>=1024){break}U=9638528+(S<<2)|0;if((c[U>>2]|0)==(T|0)){k=36140;break}else{S=S+1|0}}if((k|0)==36140){gGr(T);c[U>>2]=0}c[3532266]=0;U=c[3532264]|0;T=0;while(1){if((T|0)>=1024){break}V=9638528+(T<<2)|0;if((c[V>>2]|0)==(U|0)){k=36144;break}else{T=T+1|0}}if((k|0)==36144){gGr(U);c[V>>2]=0}c[3532264]=0;V=c[3532268]|0;U=0;while(1){if((U|0)>=1024){break}W=9638528+(U<<2)|0;if((c[W>>2]|0)==(V|0)){k=36148;break}else{U=U+1|0}}if((k|0)==36148){gGr(V);c[W>>2]=0}c[3532268]=0;a[947416]=0}if(a[7461056]|0){W=9757552;c[W>>2]=0;c[W+4>>2]=0;a[9757560]=0}if(a[7461048]|0){W=c[3532250]|0;V=0;while(1){if((V|0)>=1024){break}X=9638528+(V<<2)|0;if((c[X>>2]|0)==(W|0)){k=36156;break}else{V=V+1|0}}if((k|0)==36156){gGr(W);c[X>>2]=0}c[3532250]=0;X=c[2433518]|0;W=0;while(1){if((W|0)>=1024){break}Y=9638528+(W<<2)|0;if((c[Y>>2]|0)==(X|0)){k=36160;break}else{W=W+1|0}}if((k|0)==36160){gGr(X);c[Y>>2]=0}c[2433518]=0;Y=9757536;c[Y>>2]=0;c[Y+4>>2]=0;c[3532252]=0;c[2430058]=0;c[2433284]=0;a[1666928]=0;c[2438974]=0}if(a[7461040]|0){gGz(14128984,0,16)}if(a[7461032]|0){Y=c[3532250]|0;X=0;while(1){if((X|0)>=1024){break}Z=9638528+(X<<2)|0;if((c[Z>>2]|0)==(Y|0)){k=36168;break}else{X=X+1|0}}if((k|0)==36168){gGr(Y);c[Z>>2]=0}c[3532250]=0;Z=c[2433518]|0;Y=0;while(1){if((Y|0)>=1024){break}_=9638528+(Y<<2)|0;if((c[_>>2]|0)==(Z|0)){k=36172;break}else{Y=Y+1|0}}if((k|0)==36172){gGr(Z);c[_>>2]=0}c[2433518]=0;_=9757536;c[_>>2]=0;c[_+4>>2]=0;c[3532252]=0;c[2430058]=0;c[2433284]=0;a[1666928]=0;c[2438974]=0}if(a[7461024]|0){_=c[3532232]|0;Z=0;while(1){if((Z|0)>=1024){break}$=9638528+(Z<<2)|0;if((c[$>>2]|0)==(_|0)){k=36178;break}else{Z=Z+1|0}}if((k|0)==36178){gGr(_);c[$>>2]=0}c[3532232]=0;$=c[2438406]|0;_=0;while(1){if((_|0)>=1024){break}aa=9638528+(_<<2)|0;if((c[aa>>2]|0)==($|0)){k=36182;break}else{_=_+1|0}}if((k|0)==36182){gGr($);c[aa>>2]=0}c[2438406]=0;aa=c[2429846]|0;$=0;while(1){if(($|0)>=1024){break}ab=9638528+($<<2)|0;if((c[ab>>2]|0)==(aa|0)){k=36186;break}else{$=$+1|0}}if((k|0)==36186){gGr(aa);c[ab>>2]=0}c[2429846]=0;gGz(14128936,0,24);gGz(9553392,0,16);gGz(9553352,0,16);c[3527506]=0;c[3527498]=0;c[2436808]=0;c[2430806]=0;c[2430804]=0;c[2433282]=0;c[2433280]=0;c[2429458]=0;c[2429456]=0;a[1666920]=0;c[2429696]=0}if(a[7461016]|0){ab=9757528;c[ab>>2]=0;c[ab+4>>2]=0}if(a[7461008]|0){ab=9757520;c[ab>>2]=0;c[ab+4>>2]=0}a[7461104]=0;a[7461144]=0;a[7461112]=0;a[7461136]=0;a[7461e3]=0;a[7461128]=0;a[7461120]=0;a[7461096]=0;a[7461088]=0;a[7461080]=0;a[7461072]=0;a[7461064]=0;a[7461056]=0;a[7461048]=0;a[7461040]=0;a[7461032]=0;a[7461024]=0;a[7461016]=0;a[7461008]=0;c[3531956]=0;c[2113070]=0;c[2113068]=0;ab=c[2112926]|0;if((ab|0)!=0){gGr(ab);c[2112926]=0}if((c[2113302]|0)!=0){c[2113302]=0;a[801640]=0;c[2440576]=0;c[2440574]=0;gGz(14168784,0,16);gGz(14168768,0,16)}ab=c[3532048]|0;aa=0;while(1){if((aa|0)>=1024){k=36201;break}ac=9638528+(aa<<2)|0;if((c[ac>>2]|0)==(ab|0)){break}else{aa=aa+1|0}}if((k|0)==36201){c[3532048]=0;c[3532202]=0;c[3532196]=0;c[3532190]=0;c[3531930]=0;c[3531924]=0;c[3532146]=0;c[3532172]=0;c[3532156]=0;c[3531996]=0;c[3531986]=0;c[3532012]=0;c[3531974]=0;c[3531950]=0;c[3531944]=0;c[3532060]=0;c[3532054]=0;c[3532114]=0;c[3532124]=0;c[3532200]=0;c[3532194]=0;c[3532188]=0;c[3531928]=0;c[3531922]=0;c[3532144]=0;c[3532170]=0;c[3532154]=0;c[3531994]=0;c[3531984]=0;c[3532010]=0;c[3531972]=0;c[3531948]=0;c[3531942]=0;c[3532058]=0;c[3532052]=0;c[3532112]=0;c[3532122]=0;c[3532162]=0;c[3532160]=0;c[3532142]=0;c[3532164]=0;c[3532042]=0;c[3532148]=0;c[3532140]=0;c[3532138]=0;c[3532178]=0;c[3532176]=0;a[7461200]=0;a[7461208]=0;c[3532040]=0;c[3532174]=0;c[3532168]=0;c[3532166]=0;a[7461184]=0;a[7461176]=0;a[7461168]=0;a[7461192]=0;c[3532038]=0;c[3532158]=0;c[3532152]=0;c[3532150]=0;c[3532002]=0;c[3532e3]=0;a[7460944]=0;c[3532004]=0;c[3532034]=0;c[3531998]=0;c[3531992]=0;c[3531990]=0;a[7460952]=0;a[7460928]=0;a[7460920]=0;a[7460912]=0;a[7460936]=0;a[7460976]=0;c[3531988]=0;c[3531982]=0;c[3531980]=0;a[14127752]=0;a[14128024]=0;c[3532014]=0;b[7064256]=0;c[3531954]=0;c[3531940]=0;c[3532064]=0;c[3532082]=0;a[7461152]=0;c[3532044]=0;c[3532030]=0;a[7460960]=0;a[7460968]=0;c[3532032]=0;c[3532036]=0;a[7460984]=0;a[7460992]=0;c[3532118]=0;c[3532050]=0;c[3532016]=0;i=d;return 0}gGr(ab);c[ac>>2]=0;c[3532048]=0;c[3532202]=0;c[3532196]=0;c[3532190]=0;c[3531930]=0;c[3531924]=0;c[3532146]=0;c[3532172]=0;c[3532156]=0;c[3531996]=0;c[3531986]=0;c[3532012]=0;c[3531974]=0;c[3531950]=0;c[3531944]=0;c[3532060]=0;c[3532054]=0;c[3532114]=0;c[3532124]=0;c[3532200]=0;c[3532194]=0;c[3532188]=0;c[3531928]=0;c[3531922]=0;c[3532144]=0;c[3532170]=0;c[3532154]=0;c[3531994]=0;c[3531984]=0;c[3532010]=0;c[3531972]=0;c[3531948]=0;c[3531942]=0;c[3532058]=0;c[3532052]=0;c[3532112]=0;c[3532122]=0;c[3532162]=0;c[3532160]=0;c[3532142]=0;c[3532164]=0;c[3532042]=0;c[3532148]=0;c[3532140]=0;c[3532138]=0;c[3532178]=0;c[3532176]=0;a[7461200]=0;a[7461208]=0;c[3532040]=0;c[3532174]=0;c[3532168]=0;c[3532166]=0;a[7461184]=0;a[7461176]=0;a[7461168]=0;a[7461192]=0;c[3532038]=0;c[3532158]=0;c[3532152]=0;c[3532150]=0;c[3532002]=0;c[3532e3]=0;a[7460944]=0;c[3532004]=0;c[3532034]=0;c[3531998]=0;c[3531992]=0;c[3531990]=0;a[7460952]=0;a[7460928]=0;a[7460920]=0;a[7460912]=0;a[7460936]=0;a[7460976]=0;c[3531988]=0;c[3531982]=0;c[3531980]=0;a[14127752]=0;a[14128024]=0;c[3532014]=0;b[7064256]=0;c[3531954]=0;c[3531940]=0;c[3532064]=0;c[3532082]=0;a[7461152]=0;c[3532044]=0;c[3532030]=0;a[7460960]=0;a[7460968]=0;c[3532032]=0;c[3532036]=0;a[7460984]=0;a[7460992]=0;c[3532118]=0;c[3532050]=0;c[3532016]=0;i=d;return 0}function e_b(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;i=a[9733151]&16;c[3528672]=i;j=c[3532264]|0;k=g+9733146|0;l=a[k]|0;m=256-(l&255)|0;n=256/(m>>>0)|0;if((n|0)==0){o=l;p=9723240+(g<<2)|0;q=9723232+(g<<2)|0}else{l=g<<9;r=m<<1;s=9723240+(g<<2)|0;t=9723232+(g<<2)|0;u=0;do{v=(ag(r,u)|0)+l|0;w=ag(u,m)|0;u=u+1|0;x=(ag(u,m)|0)-1|0;if((w|0)<=(x|0)){y=-(b[j+(v<<1)>>1]&1023)|0;z=-(b[j+((v|1)<<1)>>1]&1023)|0;v=w;do{c[(c[s>>2]|0)+(v<<2)>>2]=y;c[(c[t>>2]|0)+(v<<2)>>2]=z;v=v+1|0;}while((v|0)<=(x|0))}}while((u|0)<(n|0));o=a[k]|0;p=s;q=t}t=c[3532266]|0;s=d[9733144+g|0]|0;g=s<<12&61440;k=s<<8&61440;s=c[p>>2]|0;p=c[q>>2]|0;if(o<<24>>24!=0){o=c[2113068]|0;q=o-1|0;n=c[2113070]|0;u=n-1|0;if((n|0)<=0){return}j=(h|0)!=0;m=(i|0)==0;l=c[2112926]|0;r=a[947416]|0?16:0;x=c[2388446]|0;v=c[2388450]|0;z=o+16|0;y=c[2440182]|0;w=0;do{A=ag(m?w:u-w|0,o)|0;B=r+w|0;C=B&255;D=B+(c[p+(C<<2)>>2]|0)|0;B=D>>>4<<6&4032;E=D<<4&240;D=c[s+(C<<2)>>2]|0;if((o+16|0)>0){C=E^240;F=q+A|0;G=0;do{H=D+G|0;I=H>>>4&63|B;J=e[t+((I|k)<<1)>>1]|0;K=(J&63)+f|0;L=e[t+((I|g)<<1)>>1]&x;if(j){M=36219}else{if((a[y+L|0]|0)==0){M=36219}}L47656:do{if((M|0)==36219){M=0;I=G-(H&15)|0;N=K<<4;O=L<<8|((J&128|0)==0?E:C);P=-(J>>>6&1)&15;if(m){if(j){Q=I;R=0;while(1){if(!((Q|0)>=(o|0)|(Q|0)<0)){b[l+(Q+A<<1)>>1]=(d[v+((R^P)+O)|0]|N)&65535}S=R+1|0;if((S|0)>=16){break L47656}Q=Q+1|0;R=S}}else{T=I;U=0}while(1){do{if(!((T|0)>=(o|0)|(T|0)<0)){R=a[v+((U^P)+O)|0]|0;if(R<<24>>24==0){break}b[l+(T+A<<1)>>1]=(R&255|N)&65535}}while(0);R=U+1|0;if((R|0)>=16){break L47656}T=T+1|0;U=R}}else{if(j){R=I;Q=0;while(1){if(!((R|0)>=(o|0)|(R|0)<0)){b[l+(F-R<<1)>>1]=(d[v+((Q^P)+O)|0]|N)&65535}S=Q+1|0;if((S|0)>=16){break L47656}R=R+1|0;Q=S}}else{V=I;W=0}while(1){do{if(!((V|0)>=(o|0)|(V|0)<0)){Q=a[v+((W^P)+O)|0]|0;if(Q<<24>>24==0){break}b[l+(F-V<<1)>>1]=(Q&255|N)&65535}}while(0);Q=W+1|0;if((Q|0)>=16){break L47656}V=V+1|0;W=Q}}}}while(0);G=G+16|0;}while((G|0)<(z|0))}w=w+1|0;}while((w|0)<(n|0));return}n=(h|0)==0;h=a[947416]|0?16:0;w=c[2388446]|0;z=(i|0)==0;i=c[2440182]|0;W=c[2112926]|0;V=c[2388450]|0;l=0;do{v=l>>6<<4;o=v-(c[p+((v+h&255)<<2)>>2]|0)|0;v=(o|0)>1008?o-1024|0:o;o=(l<<4&1008)-(c[s+((v+h&255)<<2)>>2]|0)|0;j=(o|0)>1008?o-1024|0:o;o=e[t+(l+k<<1)>>1]|0;U=(o&63)+f|0;T=o&64;m=o&128;o=e[t+(l+g<<1)>>1]&w;if(z){X=m;Y=T;Z=v;_=j}else{X=m^128;Y=T^64;Z=240-v|0;_=-16-j+(c[2113068]|0)|0}j=Z-h|0;L47698:do{if(n){if((a[i+o|0]|0)!=0){break}do{if((j|0)>-1){if(!((j|0)<((c[2113070]|0)-15|0)&(_|0)>-1)){break}if((_|0)>=((c[2113068]|0)-15|0)){break}v=(Y|0)!=0;if((X|0)==0){if(v){SI(W,o,_,j,U,4,0,0,V);break L47698}else{SG(W,o,_,j,U,4,0,0,V);break L47698}}else{if(v){SM(W,o,_,j,U,4,0,0,V);break L47698}else{SK(W,o,_,j,U,4,0,0,V);break L47698}}}}while(0);v=(Y|0)!=0;if((X|0)==0){if(v){SJ(W,o,_,j,U,4,0,0,V);break}else{SH(W,o,_,j,U,4,0,0,V);break}}else{if(v){SN(W,o,_,j,U,4,0,0,V);break}else{SL(W,o,_,j,U,4,0,0,V);break}}}else{do{if((j|0)>-1){if(!((j|0)<((c[2113070]|0)-15|0)&(_|0)>-1)){break}if((_|0)>=((c[2113068]|0)-15|0)){break}v=(Y|0)!=0;if((X|0)==0){if(v){SA(W,o,_,j,U,4,0,V);break L47698}else{Sy(W,o,_,j,U,4,0,V);break L47698}}else{if(v){SE(W,o,_,j,U,4,0,V);break L47698}else{SC(W,o,_,j,U,4,0,V);break L47698}}}}while(0);v=(Y|0)!=0;if((X|0)==0){if(v){SB(W,o,_,j,U,4,0,V);break}else{Sz(W,o,_,j,U,4,0,V);break}}else{if(v){SF(W,o,_,j,U,4,0,V);break}else{SD(W,o,_,j,U,4,0,V);break}}}}while(0);l=l+1|0;}while((l|0)<4096);return}function e_c(e,f){e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=e<<4;e=d[9733151]|0;h=(e&16|0)!=0;i=c[2113070]|0;j=(i|0)>0;if((e&8|0)!=0){if(h){if(!j){return}e=c[2113068]|0;k=a[947416]|0?16:0;l=c[2112926]|0;m=0;do{if((e|0)>0){n=c[2432956]&1;o=e-1+(ag(i+~m|0,e)|0)|0;p=0;q=l+(o<<1)|0;o=(c[9717840+(n<<2)>>2]|0)+(k+m<<9<<1)|0;while(1){n=b[o>>1]|0;if(n<<16>>16!=0){b[q>>1]=(n&65535)+f&65535}n=p+1|0;if((n|0)<(e|0)){p=n;q=q-2|0;o=o+2|0}else{break}}}m=m+1|0;}while((m|0)<(i|0));return}else{if(!j){return}m=c[2113068]|0;e=a[947416]|0?16:0;k=c[2112926]|0;l=0;do{if((m|0)>0){o=9717840+((c[2432956]&1)<<2)|0;q=ag(l,m)|0;p=(c[o>>2]|0)+(e+l<<9<<1)|0;o=k+(q<<1)|0;q=0;while(1){n=b[p>>1]|0;if(n<<16>>16!=0){b[o>>1]=(n&65535)+f&65535}n=q+1|0;if((n|0)<(m|0)){p=p+2|0;o=o+2|0;q=n}else{break}}}l=l+1|0;}while((l|0)<(i|0));return}}if(h){if(!j){return}h=c[2113068]|0;l=a[947416]|0?16:0;m=c[2112926]|0;k=0;do{if((h|0)>0){e=c[2432956]&1;q=h-1+(ag(i+~k|0,h)|0)|0;o=(c[9717840+(e<<2)>>2]|0)+(l+k<<9<<1)|0;e=m+(q<<1)|0;q=0;while(1){p=o+2|0;n=b[o>>1]|0;r=n&65535;do{if(n<<16>>16!=0){if((r&16|0)!=(g|0)){break}b[e>>1]=r+f&65535}}while(0);r=q+1|0;if((r|0)<(h|0)){o=p;e=e-2|0;q=r}else{break}}}k=k+1|0;}while((k|0)<(i|0));return}else{if(!j){return}j=c[2113068]|0;k=a[947416]|0?16:0;h=c[2112926]|0;m=0;do{if((j|0)>0){l=9717840+((c[2432956]&1)<<2)|0;q=ag(m,j)|0;e=(c[l>>2]|0)+(k+m<<9<<1)|0;l=h+(q<<1)|0;q=0;while(1){o=e+2|0;r=b[e>>1]|0;n=r&65535;do{if(r<<16>>16!=0){if((n&16|0)!=(g|0)){break}b[l>>1]=n+f&65535}}while(0);n=q+1|0;if((n|0)<(j|0)){e=o;l=l+2|0;q=n}else{break}}}m=m+1|0;}while((m|0)<(i|0));return}}function e_d(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;e=b-9437184|0;if(e>>>0<16){f=e>>>1;e=f&255;a[9757552+(f&255)|0]=d;if((e<<24>>24|0)==0){c[3531956]=0;return}else if((e<<24>>24|0)==4){e=~d;a[14128520]=e&1;a[14128521]=e&2;return}else{return}}e=b-12582912|0;if(e>>>0>=65536){return}b=e^1;f=(c[3532278]|0)+b|0;do{if((a[f]|0)!=d<<24>>24){g=(e|0)>-1;if((c[3532284]|0)==0){if(g&(b|0)<16384){a[14129208]=1}if(g&(b|0)<32768){a[14129128]=1}if((b-24576|0)>>>0>=4096){break}a[14129200]=1;break}else{if(g&(b|0)<32768){a[14129208]=1}if((b-32768|0)>>>0<32768){a[14129128]=1}if((b-69632|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);a[f]=d;return}function e_e(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=d-9437184|0;if(f>>>0<16){g=f>>>1;f=g&255;h=e&255;a[9757552+(g&255)|0]=h;if((f<<24>>24|0)==4){g=~h;a[14128520]=g&1;a[14128521]=g&2;return}else if((f<<24>>24|0)==0){c[3531956]=0;return}else{return}}f=d-12582912|0;if(f>>>0<65536){g=(c[3532278]|0)+(f>>>1<<1)|0;do{if((b[g>>1]|0)!=e<<16>>16){if((c[3532284]|0)==0){if(f>>>0<16384){a[14129208]=1}if((d-12615680|0)>>>0<16384){a[14129128]=1}if((d-12607488|0)>>>0>=4096){break}a[14129200]=1;break}else{if(f>>>0<32768){a[14129208]=1}if((d-12615680|0)>>>0<32768){a[14129128]=1}if((d-12652544|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);b[g>>1]=e;return}g=d-12713984|0;if(g>>>0<16){f=g>>>1;b[14129152+(f<<1)>>1]=e;switch(f|0){case 1:{c[2385826]=-(e&65535);return};case 2:{c[3527502]=-(e&65535);return};case 6:{c[3532284]=(e&65535)>>>4&1;return};case 7:{c[2439396]=e&1;return};case 0:{c[2388344]=-(e&65535);return};case 3:{c[2388334]=-(e&65535);return};case 5:{c[3527494]=-(e&65535);return};case 4:{c[2385820]=-(e&65535);return};default:{return}}}if((d|0)==786434){f=c[1836236]|0;g=c[9757320+(f<<2)>>2]|0;if((g|0)!=0){h=g;gGC(h|0,9706056,76)|0}c[9752472+(f<<2)>>2]=c[2433530];c[14113936+(f<<2)>>2]=c[2076596];c[9669104+(f<<2)>>2]=c[3541536];c[1836236]=-1;f=e&15;h=a[9540896]|0;L47912:do{switch(h&255|0){case 2:{a[9540896]=h+1&255;a[9540890]=f;break};case 1:{a[9540896]=h+1&255;a[9540889]=f;a[9540898]=a[9540898]|1;a[9540900]=1;break};case 3:{a[9540896]=h+1&255;a[9540891]=f;a[9540898]=a[9540898]|2;a[9540900]=1;break};case 4:{if(f<<24>>24==0){break L47912}g=c[2439330]|0;i=(g|0)==0;if(!i){j=g;gGC(9706056,j|0,76)|0}j=c[2438118]|0;c[2433530]=j;k=c[3528484]|0;c[2076596]=k;l=c[2417276]|0;c[3541536]=l;c[1836236]=0;gGz(9706056,0,76);if(!i){i=g;gGC(i|0,9706056,76)|0}c[2438118]=j;c[3528484]=k;c[2417276]=l;c[1836236]=-1;break};case 0:{a[9540896]=h+1&255;a[9540888]=f;break};default:{}}}while(0);f=c[2439330]|0;if((f|0)!=0){h=f;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;return}else if((d|0)==786432){a[9540896]=e&15;return}else if((d|0)==10485760|(d|0)==10485762|(d|0)==10485764){h=d>>>1&7;if((h|0)==1){b[(c[2442928]|0)+(c[2439392]<<1)>>1]=e;f=e&255;l=(e&65535)>>>4;k=(e&65535)>>>8;c[(c[3532276]|0)+(c[2439392]<<2)>>2]=((k<<4&255|k&8)&255)>>>3|((f<<4|f&8)&255)<<8&63488|((l<<4&255|l&12)&255)<<3&2016;return}else if((h|0)==0){c[2439392]=e&4095;return}else{return}}else if((d|0)==524288|(d|0)==524290){c[3540974]=(e&65535)>>>2&15;return}else{return}}function e_f(b){b=b|0;var c=0,d=0;c=b-9437184|0;L47943:do{if(c>>>0<16){switch(c>>>1&255|0){case 1:{d=a[14129049]|0;break L47943;break};case 0:{d=a[14129048]|0;break L47943;break};case 7:{d=a[14129042]|0;break L47943;break};case 2:{d=a[14129040]|0;break L47943;break};case 4:{d=a[9757556]|0;break L47943;break};case 3:{d=a[14129041]|0;break L47943;break};default:{d=0;break L47943}}}else{d=0}}while(0);return d|0}function e_g(d){d=d|0;var e=0,f=0,g=0,h=0;e=d-9437184|0;if(e>>>0<16){switch(e>>>1&255|0){case 4:{f=a[9757556]|0;break};case 3:{f=a[14129041]|0;break};case 7:{f=a[14129042]|0;break};case 2:{f=a[14129040]|0;break};case 1:{f=a[14129049]|0;break};case 0:{f=a[14129048]|0;break};default:{f=0}}g=f&255;return g|0}if((d&268435440|0)==12713984){g=b[14129152+((d>>>1&7)<<1)>>1]|0;return g|0}if((d|0)==786434){f=a[9540896]|0;switch(f&255|0){case 1:{a[9540898]=a[9540898]&-5;a[9540896]=f+1&255;h=a[9540893]|0;break};case 0:{a[9540896]=f+1&255;h=a[9540892]|0;break};case 3:{a[9540898]=a[9540898]&-9;a[9540896]=f+1&255;h=a[9540895]|0;break};case 4:{h=a[9540898]|0;break};case 2:{a[9540896]=f+1&255;h=a[9540894]|0;break};default:{h=0}}g=h&255;return g|0}else if((d|0)==10485762){g=b[(c[2442928]|0)+(c[2439392]<<1)>>1]|0;return g|0}else{g=0;return g|0}return 0}function e_h(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=d-4194304|0;if(f>>>0<16){g=f>>>1;f=g&255;a[9757552+(g&255)|0]=e;if((f<<24>>24|0)==0){c[3531956]=0;return}else if((f<<24>>24|0)==4){f=~e;a[14128520]=f&1;a[14128521]=f&2;return}else{return}}f=d-12582912|0;if(f>>>0<65536){g=f^1;h=(c[3532278]|0)+g|0;do{if((a[h]|0)!=e<<24>>24){i=(f|0)>-1;if((c[3532284]|0)==0){if(i&(g|0)<16384){a[14129208]=1}if(i&(g|0)<32768){a[14129128]=1}if((g-24576|0)>>>0>=4096){break}a[14129200]=1;break}else{if(i&(g|0)<32768){a[14129208]=1}if((g-32768|0)>>>0<32768){a[14129128]=1}if((g-69632|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);a[h]=e;return}if((d|0)==4063233){a[9540896]=e&15;return}else if((d|0)==3801089){h=e&255;c[3540974]=h>>>2&15|h<<15&32768;return}else if((d|0)==4063234|(d|0)==4063235){d=c[1836236]|0;h=c[9757320+(d<<2)>>2]|0;if((h|0)!=0){g=h;gGC(g|0,9706056,76)|0}c[9752472+(d<<2)>>2]=c[2433530];c[14113936+(d<<2)>>2]=c[2076596];c[9669104+(d<<2)>>2]=c[3541536];c[1836236]=-1;d=e&15;e=a[9540896]|0;L48027:do{switch(e&255|0){case 2:{a[9540896]=e+1&255;a[9540890]=d;break};case 3:{a[9540896]=e+1&255;a[9540891]=d;a[9540898]=a[9540898]|2;a[9540900]=1;break};case 4:{if(d<<24>>24==0){break L48027}g=c[2439330]|0;h=(g|0)==0;if(!h){f=g;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;i=c[3528484]|0;c[2076596]=i;j=c[2417276]|0;c[3541536]=j;c[1836236]=0;gGz(9706056,0,76);if(!h){h=g;gGC(h|0,9706056,76)|0}c[2438118]=f;c[3528484]=i;c[2417276]=j;c[1836236]=-1;break};case 1:{a[9540896]=e+1&255;a[9540889]=d;a[9540898]=a[9540898]|1;a[9540900]=1;break};case 0:{a[9540896]=e+1&255;a[9540888]=d;break};default:{}}}while(0);d=c[2439330]|0;if((d|0)!=0){e=d;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;return}else{return}}function e_i(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=d-4194304|0;if(f>>>0<16){g=f>>>1;f=g&255;h=e&255;a[9757552+(g&255)|0]=h;if((f<<24>>24|0)==4){g=~h;a[14128520]=g&1;a[14128521]=g&2;return}else if((f<<24>>24|0)==0){c[3531956]=0;return}else{return}}f=d-12582912|0;if(f>>>0<65536){g=(c[3532278]|0)+(f>>>1<<1)|0;do{if((b[g>>1]|0)!=e<<16>>16){if((c[3532284]|0)==0){if(f>>>0<16384){a[14129208]=1}if((d-12615680|0)>>>0<16384){a[14129128]=1}if((d-12607488|0)>>>0>=4096){break}a[14129200]=1;break}else{if(f>>>0<32768){a[14129208]=1}if((d-12615680|0)>>>0<32768){a[14129128]=1}if((d-12652544|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);b[g>>1]=e;return}g=d-12713984|0;if(g>>>0<16){f=g>>>1;b[14129152+(f<<1)>>1]=e;switch(f|0){case 3:{c[2388334]=-(e&65535);return};case 1:{c[2385826]=-(e&65535);return};case 0:{c[2388344]=-(e&65535);return};case 5:{c[3527494]=-(e&65535);return};case 2:{c[3527502]=-(e&65535);return};case 4:{c[2385820]=-(e&65535);return};case 6:{c[3532284]=(e&65535)>>>4&1;return};case 7:{c[2439396]=e&1;return};default:{return}}}if((d|0)==4063234){f=c[1836236]|0;g=c[9757320+(f<<2)>>2]|0;if((g|0)!=0){h=g;gGC(h|0,9706056,76)|0}c[9752472+(f<<2)>>2]=c[2433530];c[14113936+(f<<2)>>2]=c[2076596];c[9669104+(f<<2)>>2]=c[3541536];c[1836236]=-1;f=e&15;h=a[9540896]|0;L48105:do{switch(h&255|0){case 0:{a[9540896]=h+1&255;a[9540888]=f;break};case 1:{a[9540896]=h+1&255;a[9540889]=f;a[9540898]=a[9540898]|1;a[9540900]=1;break};case 3:{a[9540896]=h+1&255;a[9540891]=f;a[9540898]=a[9540898]|2;a[9540900]=1;break};case 4:{if(f<<24>>24==0){break L48105}g=c[2439330]|0;i=(g|0)==0;if(!i){j=g;gGC(9706056,j|0,76)|0}j=c[2438118]|0;c[2433530]=j;k=c[3528484]|0;c[2076596]=k;l=c[2417276]|0;c[3541536]=l;c[1836236]=0;gGz(9706056,0,76);if(!i){i=g;gGC(i|0,9706056,76)|0}c[2438118]=j;c[3528484]=k;c[2417276]=l;c[1836236]=-1;break};case 2:{a[9540896]=h+1&255;a[9540890]=f;break};default:{}}}while(0);f=c[2439330]|0;if((f|0)!=0){h=f;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;return}else if((d|0)==4063232){a[9540896]=e&15;return}else if((d|0)==3801088){h=e&65535;c[3540974]=h>>>2&15|h<<15&32768;return}else if((d|0)==2097152|(d|0)==2097154|(d|0)==2097156){h=d>>>1&7;if((h|0)==0){c[2439392]=e&4095;return}else if((h|0)==1){b[(c[2442928]|0)+(c[2439392]<<1)>>1]=e;c[(c[3532276]|0)+(c[2439392]<<2)>>2]=((e&65535)>>>10<<3&248)>>>3|((e&255)<<3&255)<<8|(((e&65535)>>>7&4|(e&65535)>>>5<<3&255)&255)<<3&2016;return}else{return}}else{return}}function e_j(b){b=b|0;var c=0,d=0,e=0;c=b-4194304|0;L48136:do{if(c>>>0<16){switch(c>>>1&255|0){case 0:{d=a[14129048]|0;break L48136;break};case 7:{d=a[14129042]|0;break L48136;break};case 4:{d=a[9757556]|0;break L48136;break};case 2:{d=a[14129040]|0;break L48136;break};case 1:{d=a[14129049]|0;break L48136;break};case 3:{d=a[14129041]|0;break L48136;break};default:{d=0;break L48136}}}else{if((b-4063234|0)>>>0>=2){d=0;break}e=a[9540896]|0;switch(e&255|0){case 1:{a[9540898]=a[9540898]&-5;a[9540896]=e+1&255;d=a[9540893]|0;break L48136;break};case 2:{a[9540896]=e+1&255;d=a[9540894]|0;break L48136;break};case 0:{a[9540896]=e+1&255;d=a[9540892]|0;break L48136;break};case 3:{a[9540898]=a[9540898]&-9;a[9540896]=e+1&255;d=a[9540895]|0;break L48136;break};case 4:{d=a[9540898]|0;break L48136;break};default:{d=0;break L48136}}}}while(0);return d|0}function e_k(d){d=d|0;var e=0,f=0,g=0,h=0;e=d-4194304|0;if(e>>>0<16){switch(e>>>1&255|0){case 2:{f=a[14129040]|0;break};case 4:{f=a[9757556]|0;break};case 7:{f=a[14129042]|0;break};case 1:{f=a[14129049]|0;break};case 3:{f=a[14129041]|0;break};case 0:{f=a[14129048]|0;break};default:{f=0}}g=f&255;return g|0}if((d&268435440|0)==12713984){g=b[14129152+((d>>>1&7)<<1)>>1]|0;return g|0}if((d|0)==4063234){f=a[9540896]|0;switch(f&255|0){case 4:{h=a[9540898]|0;break};case 0:{a[9540896]=f+1&255;h=a[9540892]|0;break};case 2:{a[9540896]=f+1&255;h=a[9540894]|0;break};case 3:{a[9540898]=a[9540898]&-9;a[9540896]=f+1&255;h=a[9540895]|0;break};case 1:{a[9540898]=a[9540898]&-5;a[9540896]=f+1&255;h=a[9540893]|0;break};default:{h=0}}g=h&255;return g|0}else if((d|0)==2097154){g=b[(c[2442928]|0)+(c[2439392]<<1)>>1]|0;return g|0}else{g=0;return g|0}return 0}function e_l(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;e=b-3145728|0;if(e>>>0<16){f=e>>>1;e=f&255;a[9757552+(f&255)|0]=d;if((e<<24>>24|0)==0){c[3531956]=0;return}else if((e<<24>>24|0)==4){e=~d;a[14128520]=e&1;a[14128521]=e&2;return}else{return}}e=b-4194304|0;if(e>>>0<16){f=e>>>1;e=f&255;a[9757552+(f&255)|0]=d;if((e<<24>>24|0)==4){f=~d;a[14128520]=f&1;a[14128521]=f&2;return}else if((e<<24>>24|0)==0){c[3531956]=0;return}else{return}}e=b-13631488|0;if(e>>>0>=65536){if((b-12599296|0)>>>0<49152){f=(c[3532278]|0)+(b-12582912^1)|0;if((a[f]|0)!=d<<24>>24){a[14129208]=1;a[14129128]=1}a[f]=d;return}else{if((b-4849664|0)>>>0>=2){return}b=d&255;c[3540974]=b>>>2&15|b<<15&32768;return}}b=e^1;f=(c[3532278]|0)+b|0;do{if((a[f]|0)!=d<<24>>24){g=(e|0)>-1;if((c[3532284]|0)==0){if(g&(b|0)<16384){a[14129208]=1}if(g&(b|0)<32768){a[14129128]=1}if((b-24576|0)>>>0>=4096){break}a[14129200]=1;break}else{if(g&(b|0)<32768){a[14129208]=1}if((b-32768|0)>>>0<32768){a[14129128]=1}if((b-69632|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);a[f]=d;return}function e_m(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=d-3145728|0;if(f>>>0<16){g=f>>>1;f=g&255;h=e&255;a[9757552+(g&255)|0]=h;if((f<<24>>24|0)==4){g=~h;a[14128520]=g&1;a[14128521]=g&2;return}else if((f<<24>>24|0)==0){c[3531956]=0;return}else{return}}f=d-4194304|0;if(f>>>0<16){g=f>>>1;f=g&255;h=e&255;a[9757552+(g&255)|0]=h;if((f<<24>>24|0)==0){c[3531956]=0;return}else if((f<<24>>24|0)==4){f=~h;a[14128520]=f&1;a[14128521]=f&2;return}else{return}}f=d-13631488|0;if(f>>>0<65536){h=(c[3532278]|0)+(f>>>1<<1)|0;do{if((b[h>>1]|0)!=e<<16>>16){if((c[3532284]|0)==0){if(f>>>0<16384){a[14129208]=1}if((d-13664256|0)>>>0<16384){a[14129128]=1}if((d-13656064|0)>>>0>=4096){break}a[14129200]=1;break}else{if(f>>>0<32768){a[14129208]=1}if((d-13664256|0)>>>0<32768){a[14129128]=1}if((d-13701120|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);b[h>>1]=e;return}h=d-13762560|0;if(h>>>0<16){f=h>>>1;b[14129152+(f<<1)>>1]=e;switch(f|0){case 2:{c[3527502]=-(e&65535);return};case 1:{c[2385826]=-(e&65535);return};case 0:{c[2388344]=-(e&65535);return};case 3:{c[2388334]=-(e&65535);return};case 7:{c[2439396]=e&1;return};case 4:{c[2385820]=-(e&65535);return};case 5:{c[3527494]=-(e&65535);return};case 6:{c[3532284]=(e&65535)>>>4&1;return};default:{return}}}if((d-12599296|0)>>>0<49152){f=(c[3532278]|0)+((d-12582912|0)>>>1<<1)|0;if((b[f>>1]|0)!=e<<16>>16){a[14129208]=1;a[14129128]=1}b[f>>1]=e;return}if((d|0)==1048576|(d|0)==1048578|(d|0)==1048580){f=d>>>1&7;if((f|0)==0){c[2439392]=e&4095;return}else if((f|0)==1){b[(c[2442928]|0)+(c[2439392]<<1)>>1]=e;c[(c[3532276]|0)+(c[2439392]<<2)>>2]=((e&65535)>>>10<<3&248)>>>3|((e&255)<<3&255)<<8|(((e&65535)>>>7&4|(e&65535)>>>5<<3&255)&255)<<3&2016;return}else{return}}else if((d|0)==5111810){f=c[1836236]|0;h=c[9757320+(f<<2)>>2]|0;if((h|0)!=0){g=h;gGC(g|0,9706056,76)|0}c[9752472+(f<<2)>>2]=c[2433530];c[14113936+(f<<2)>>2]=c[2076596];c[9669104+(f<<2)>>2]=c[3541536];c[1836236]=-1;f=e&15;g=a[9540896]|0;L48322:do{switch(g&255|0){case 3:{a[9540896]=g+1&255;a[9540891]=f;a[9540898]=a[9540898]|2;a[9540900]=1;break};case 4:{if(f<<24>>24==0){break L48322}h=c[2439330]|0;i=(h|0)==0;if(!i){j=h;gGC(9706056,j|0,76)|0}j=c[2438118]|0;c[2433530]=j;k=c[3528484]|0;c[2076596]=k;l=c[2417276]|0;c[3541536]=l;c[1836236]=0;gGz(9706056,0,76);if(!i){i=h;gGC(i|0,9706056,76)|0}c[2438118]=j;c[3528484]=k;c[2417276]=l;c[1836236]=-1;break};case 1:{a[9540896]=g+1&255;a[9540889]=f;a[9540898]=a[9540898]|1;a[9540900]=1;break};case 2:{a[9540896]=g+1&255;a[9540890]=f;break};case 0:{a[9540896]=g+1&255;a[9540888]=f;break};default:{}}}while(0);f=c[2439330]|0;if((f|0)!=0){g=f;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;return}else if((d|0)==5111808){a[9540896]=e&15;return}else{return}}function e_n(b){b=b|0;var c=0,d=0,e=0;c=b-3145728|0;L48343:do{if(c>>>0<16){switch(c>>>1&255|0){case 4:{d=a[9757556]|0;break L48343;break};case 7:{d=a[14129042]|0;break L48343;break};case 1:{d=a[14129049]|0;break L48343;break};case 3:{d=a[14129041]|0;break L48343;break};case 0:{d=a[14129048]|0;break L48343;break};case 2:{d=a[14129040]|0;break L48343;break};default:{d=0;break L48343}}}else{e=b-4194304|0;if(e>>>0<16){switch(e>>>1&255|0){case 1:{d=a[14129049]|0;break L48343;break};case 0:{d=a[14129048]|0;break L48343;break};case 7:{d=a[14129042]|0;break L48343;break};case 2:{d=a[14129040]|0;break L48343;break};case 4:{d=a[9757556]|0;break L48343;break};case 3:{d=a[14129041]|0;break L48343;break};default:{d=0;break L48343}}}else{if((b-5111810|0)>>>0>=2){d=0;break}e=a[9540896]|0;switch(e&255|0){case 2:{a[9540896]=e+1&255;d=a[9540894]|0;break L48343;break};case 0:{a[9540896]=e+1&255;d=a[9540892]|0;break L48343;break};case 3:{a[9540898]=a[9540898]&-9;a[9540896]=e+1&255;d=a[9540895]|0;break L48343;break};case 1:{a[9540898]=a[9540898]&-5;a[9540896]=e+1&255;d=a[9540893]|0;break L48343;break};case 4:{d=a[9540898]|0;break L48343;break};default:{d=0;break L48343}}}}}while(0);return d|0}function e_o(d){d=d|0;var e=0,f=0,g=0,h=0,i=0;e=d-3145728|0;if(e>>>0<16){switch(e>>>1&255|0){case 2:{f=a[14129040]|0;break};case 4:{f=a[9757556]|0;break};case 7:{f=a[14129042]|0;break};case 0:{f=a[14129048]|0;break};case 3:{f=a[14129041]|0;break};case 1:{f=a[14129049]|0;break};default:{f=0}}g=f&255;return g|0}f=d-4194304|0;if(f>>>0<16){switch(f>>>1&255|0){case 2:{h=a[14129040]|0;break};case 3:{h=a[14129041]|0;break};case 7:{h=a[14129042]|0;break};case 4:{h=a[9757556]|0;break};case 1:{h=a[14129049]|0;break};case 0:{h=a[14129048]|0;break};default:{h=0}}g=h&255;return g|0}if((d&268435440|0)==13762560){g=b[14129152+((d>>>1&7)<<1)>>1]|0;return g|0}if((d|0)==1048578){g=b[(c[2442928]|0)+(c[2439392]<<1)>>1]|0;return g|0}else if((d|0)==5111810){d=a[9540896]|0;switch(d&255|0){case 4:{i=a[9540898]|0;break};case 2:{a[9540896]=d+1&255;i=a[9540894]|0;break};case 0:{a[9540896]=d+1&255;i=a[9540892]|0;break};case 3:{a[9540898]=a[9540898]&-9;a[9540896]=d+1&255;i=a[9540895]|0;break};case 1:{a[9540898]=a[9540898]&-5;a[9540896]=d+1&255;i=a[9540893]|0;break};default:{i=0}}g=i&255;return g|0}else{g=0;return g|0}return 0}function e_p(f,g){f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=f-12582912|0;if(h>>>0<65536){i=h^1;j=(c[3532278]|0)+i|0;do{if((a[j]|0)!=g<<24>>24){k=(h|0)>-1;if((c[3532284]|0)==0){if(k&(i|0)<16384){a[14129208]=1}if(k&(i|0)<32768){a[14129128]=1}if((i-24576|0)>>>0>=4096){break}a[14129200]=1;break}else{if(k&(i|0)<32768){a[14129208]=1}if((i-32768|0)>>>0<32768){a[14129128]=1}if((i-69632|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);a[j]=g;return}if((f|0)==3801089){c[3540974]=(g&255)>>>2&15;return}else if((f|0)==4063235){j=c[1836236]|0;i=c[9757320+(j<<2)>>2]|0;if((i|0)!=0){h=i;gGC(h|0,9706056,76)|0}c[9752472+(j<<2)>>2]=c[2433530];c[14113936+(j<<2)>>2]=c[2076596];c[9669104+(j<<2)>>2]=c[3541536];c[1836236]=-1;j=g&15;h=a[9540896]|0;L48445:do{switch(h&255|0){case 4:{if(j<<24>>24==0){break L48445}i=c[2439330]|0;k=(i|0)==0;if(!k){l=i;gGC(9706056,l|0,76)|0}l=c[2438118]|0;c[2433530]=l;m=c[3528484]|0;c[2076596]=m;n=c[2417276]|0;c[3541536]=n;c[1836236]=0;gGz(9706056,0,76);if(!k){k=i;gGC(k|0,9706056,76)|0}c[2438118]=l;c[3528484]=m;c[2417276]=n;c[1836236]=-1;break};case 3:{a[9540896]=h+1&255;a[9540891]=j;a[9540898]=a[9540898]|2;a[9540900]=1;break};case 0:{a[9540896]=h+1&255;a[9540888]=j;break};case 1:{a[9540896]=h+1&255;a[9540889]=j;a[9540898]=a[9540898]|1;a[9540900]=1;break};case 2:{a[9540896]=h+1&255;a[9540890]=j;break};default:{}}}while(0);j=c[2439330]|0;if((j|0)!=0){h=j;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;return}else if((f|0)==8390659){return}else if((f|0)==4063233){a[9540896]=g&15;return}else if((f|0)==8391681){c[2442878]=g&7;return}else{if((f&268433408|0)!=8388608){return}h=g&255;j=f>>>1&2047;if((c[2442878]|0)!=0){return}do{if((j|0)==14){if(g<<24>>24==0){return}f=(d[9681585]<<8|d[9681584])+(d[9681588]|0)+(d[9681589]<<8)|0;n=(d[9681587]<<8|d[9681586])+(d[9681590]|0)+(d[9681591]<<8)|0;m=c[632496+(c[2439296]<<2)>>2]|0;l=b[m>>1]|0;if(l<<16>>16==255){a[9752272]=-1;break}else{o=m;p=l}L48482:while(1){do{if((f|0)>=(p&65535|0)){if((f|0)>=(e[o+2>>1]|0)){break}if((n|0)<(e[o+4>>1]|0)){break}if((n|0)<(e[o+6>>1]|0)){q=36859;break L48482}}}while(0);l=o+16|0;m=b[l>>1]|0;if(m<<16>>16==255){r=-1;break}else{o=l;p=m}}if((q|0)==36859){n=o+8|0;a[9681584]=b[n>>1]&255;a[9681585]=(e[n>>1]|0)>>>8&255;n=o+10|0;a[9681586]=b[n>>1]&255;a[9681587]=(e[n>>1]|0)>>>8&255;n=o+12|0;a[9681588]=b[n>>1]&255;a[9681589]=(e[n>>1]|0)>>>8&255;n=o+14|0;a[9681590]=b[n>>1]&255;a[9681591]=(e[n>>1]|0)>>>8&255;r=0}a[9752272]=r;q=36865}else if((j|0)==16){q=36866}else if((j|0)==8){a[9627072]=g;c[2442888]=(h^-64)>>6;return}else if((j|0)==15){if(g<<24>>24==0){return}n=c[2439296]|0;f=0;while(1){m=b[680504+(n*26|0)+(f<<1)>>1]|0;l=f<<1;a[9681584+l|0]=m&255;a[9681584+(l|1)|0]=(m&65535)>>>8&255;m=f+1|0;if((m|0)<13){f=m}else{q=36865;break}}}}while(0);if((q|0)==36865){if((j|0)==16){q=36866}}if((q|0)==36866){c[2439296]=h;return}h=j-17|0;if(h>>>0>=26){return}a[9681584+h|0]=g;return}}function e_q(d,e){d=d|0;e=e|0;var f=0,g=0;f=d-12582912|0;if(f>>>0<65536){g=(c[3532278]|0)+(f>>>1<<1)|0;do{if((b[g>>1]|0)!=e<<16>>16){if((c[3532284]|0)==0){if(f>>>0<16384){a[14129208]=1}if((d-12615680|0)>>>0<16384){a[14129128]=1}if((d-12607488|0)>>>0>=4096){break}a[14129200]=1;break}else{if(f>>>0<32768){a[14129208]=1}if((d-12615680|0)>>>0<32768){a[14129128]=1}if((d-12652544|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);b[g>>1]=e;return}g=d-12713984|0;if(g>>>0>=16){if((d|0)==2097152|(d|0)==2097154|(d|0)==2097156){f=d>>>1&7;if((f|0)==0){c[2439392]=e&4095;return}else if((f|0)==1){b[(c[2442928]|0)+(c[2439392]<<1)>>1]=e;c[(c[3532276]|0)+(c[2439392]<<2)>>2]=((e&65535)>>>10<<3&248)>>>3|((e&255)<<3&255)<<8|(((e&65535)>>>7&4|(e&65535)>>>5<<3&255)&255)<<3&2016;return}else{return}}else if((d|0)==3932160){c[3531956]=0;return}else{return}}d=g>>>1;b[14129152+(d<<1)>>1]=e;switch(d|0){case 0:{c[2388344]=-(e&65535);return};case 6:{c[3532284]=(e&65535)>>>4&1;return};case 5:{c[3527494]=-(e&65535);return};case 3:{c[2388334]=-(e&65535);return};case 2:{c[3527502]=-(e&65535);return};case 1:{c[2385826]=-(e&65535);return};case 4:{c[2385820]=-(e&65535);return};case 7:{c[2439396]=e&1;return};default:{return}}}function e_r(b){b=b|0;var e=0,f=0,g=0;L48568:do{if((b|0)==4063235){e=a[9540896]|0;switch(e&255|0){case 1:{a[9540898]=a[9540898]&-5;a[9540896]=e+1&255;f=a[9540893]|0;break L48568;break};case 3:{a[9540898]=a[9540898]&-9;a[9540896]=e+1&255;f=a[9540895]|0;break L48568;break};case 2:{a[9540896]=e+1&255;f=a[9540894]|0;break L48568;break};case 0:{a[9540896]=e+1&255;f=a[9540892]|0;break L48568;break};case 4:{f=a[9540898]|0;break L48568;break};default:{f=0;break L48568}}}else if((b|0)==8390659){f=1}else{if((b&-2048|0)!=8388608){f=0;break}e=b>>>1&2047;if((c[2442878]|0)!=0){f=0;break}switch(e|0){case 5:{f=a[14128322]|0;break L48568;break};case 4:{f=(d[14128321]|0)&c[2442888]&255;break L48568;break};case 3:{f=a[14128320]|0;break L48568;break};case 6:{f=a[14128323]|0;break L48568;break};case 14:{f=a[9752272]|0;break L48568;break};case 8:{f=a[9627072]|0;break L48568;break};default:{g=e-17|0;if(g>>>0>=26){f=0;break L48568}f=a[9681584+g|0]|0;break L48568}}}}while(0);return f|0}function e_s(a){a=a|0;var e=0,f=0,g=0;L48590:do{if((a&268435440|0)==12713984){e=b[14129152+((a>>>1&7)<<1)>>1]|0}else{if((a|0)==3997696){e=0;break}else if((a|0)==3735552){e=d[14128480]|0;break}else if((a|0)==2097154){e=b[(c[2442928]|0)+(c[2439392]<<1)>>1]|0;break}else if((a|0)==3866624){e=d[14128481]|0;break}else{if((a&-2048|0)!=8388608){e=0;break}f=a>>>1&2047;if((c[2442878]|0)!=0){e=0;break}switch(f|0){case 8:{e=d[9627072]|0;break L48590;break};case 14:{e=d[9752272]|0;break L48590;break};case 6:{e=d[14128323]|0;break L48590;break};case 3:{e=d[14128320]|0;break L48590;break};case 5:{e=d[14128322]|0;break L48590;break};case 4:{e=(d[14128321]|0)&c[2442888]&65535;break L48590;break};default:{g=f-17|0;if(g>>>0>=26){e=0;break L48590}e=d[9681584+g|0]|0;break L48590}}}}}while(0);return e|0}function e_t(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((e|0)==49152){if((c[3532036]|0)==0){return}c[2415126]=9662152;c[2415540]=0;return}else if((e|0)==53248){if((c[3532036]|0)==0){return}c[2415126]=9662152;c[2415540]=1;c[2440034]=c[2440034]&65280;return}else if((e|0)==36864){c[2113304]=d&255;return}else if((e|0)==40961){fd_(d);return}else if((e|0)==45056){if((c[3532036]|0)==0){return}c[2440034]=c[2440034]&255|(d&255)<<8;return}else if((e|0)==36865){b=c[2113304]|0;a[14168504+b|0]=d;mv(0,b,d&255);return}else if((e|0)==40960){a[9540897]=d&15;return}else{return}}function e_u(a){a=a|0;var b=0,d=0;b=a&65535;if((b|0)==40961){d=fdZ()|0}else if((b|0)==36864|(b|0)==36865){d=c[(c[3531464]|0)+4240>>2]&255}else{d=0}return d|0}function e_v(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=b&65535;switch(e|0){case 57344:case 57345:case 57346:case 57347:{l7(e&3,d);return};case 57856:{a[9540897]=d&15;return};case 61952:{e=d&3;a[14127752]=e;b=c[3531932]|0;f=c[9757320+(c[1836236]<<2)>>2]|0;g=((e&255)<<14)-16384|0;e=64;h=64;while(1){c[f+76+(h<<2)>>2]=b+(g+(h<<8));i=e+1&65535;if((i&65535)>127){j=64;k=64;break}else{e=i;h=i&65535}}while(1){h=b+(g+(k<<8))|0;c[f+76+(k+512<<2)>>2]=h;c[f+76+(k+768<<2)>>2]=h;h=j+1&65535;if((h&65535)>127){break}else{j=h;k=h&65535}}return};case 57857:{fd_(d);return};default:{return}}}function e_w(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=d&3;a[14127752]=b;d=c[3531932]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=((b&255)<<14)-16384|0;b=64;g=64;while(1){c[e+76+(g<<2)>>2]=d+(f+(g<<8));h=b+1&65535;if((h&65535)>127){i=64;j=64;break}else{b=h;g=h&65535}}while(1){g=d+(f+(j<<8))|0;c[e+76+(j+512<<2)>>2]=g;c[e+76+(j+768<<2)>>2]=g;g=i+1&65535;if((g&65535)>127){break}else{i=g;j=g&65535}}return}function e_x(a){a=a|0;var b=0,c=0;b=a&65535;switch(b|0){case 57344:case 57345:case 57346:case 57347:{c=l8(b&3)|0;break};case 57857:{c=fdZ()|0;break};default:{c=0}}return c|0}function e_y(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5936052+(b*112|0)>>2];c[a+104>>2]=c[5936056+(b*112|0)>>2];c[a+108>>2]=c[5936060+(b*112|0)>>2];d=0;return d|0}function e_z(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=5935952+(b*112|0);e=0;return e|0}function e_A(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4191104+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function e_B(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>39){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6407e3+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e_C(){return e$q(1202,11662,5740)|0}function e_D(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if((a[14128072]|0)!=0){e$p()}gu[c[3532050]&16383]();d=c[2392]|0;if((d|0)>=0){gGz(8452240,0,((d|0)>0?(d<<2)+4|0:4)|0)}c[2113054]=0;d=c[2385548]|0;if((d|0)>0){gGz(9752472,0,((d|0)>1?d<<2:4)|0)}c[2433530]=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}d=c[2439330]|0;if((d|0)!=0){e=d;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;e=0;d=0;L48716:while(1){f=d;while(1){if((f|0)>=100){break L48716}g=f+1|0;h=g*2666|0;i=((f|0)==99?h-500|0:h)-(c[2113054]|0)-(c[2113056]|0)+(c[2276108]|0)|0;c[2113056]=i;h=RG(i)|0;c[2113054]=(c[2113054]|0)+h;c[2276108]=-1;c[2113056]=-1;h=c[2433530]|0;i=(g*666|0)-h-(c[2426530]|0)+(c[2076596]|0)|0;do{if((i|0)>=1){if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){j=gfc(i)|0;c[2433530]=(c[2433530]|0)+j;break}else{c[2433530]=i+h;break}}}while(0);k=c[2112964]|0;if((k|0)==0){f=g}else{break}}f=a[9688]|0?5:0;gg[c[3542124]&4095](k+(e<<1<<1)|0,f);e=f+e|0;d=g}c[8452200+(c[2394]<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0<1024){RH(4)}c[2113056]=500;g=RG(500)|0;c[2113054]=(c[2113054]|0)+g;c[2276108]=-1;c[2113056]=-1;c[8452200+(c[2394]<<2)>>2]=8197;c[2276080]=1280;if((c[2276079]|0)>>>0<1280){RH(5)}g=c[2112964]|0;do{if((g|0)!=0){d=a[9688]|0?534:0;if((d|0)==(e|0)){break}gg[c[3542124]&4095](g+(e<<1<<1)|0,d-e|0)}}while(0);e=c[1836236]|0;g=c[9757320+(e<<2)>>2]|0;if((g|0)!=0){d=g;gGC(d|0,9706056,76)|0}c[9752472+(e<<2)>>2]=c[2433530];c[14113936+(e<<2)>>2]=c[2076596];c[9669104+(e<<2)>>2]=c[3541536];c[1836236]=-1;e=c[2394]|0;d=c[14130368+(e<<2)>>2]|0;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[8452240+(e<<2)>>2]=c[2113054];c[2394]=-1;if((c[2112968]|0)==0){return 0}e_E()|0;return 0}function e_E(){var a=0,d=0,f=0;a=e[7064582]|0;d=c[2112926]|0;gGz(d|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);do{if((b[7064582]&8)==0){if((a&1|0)==0){eX0(0,1,c[3532136]|0)}if((c[3540974]&32768|0)!=0){e5L(c[3531962]|0)}if((a&2|0)!=0){break}eX3(0,0,c[3532136]|0)}else{if((a&2|0)==0){eX3(0,1,c[3532136]|0)}if((c[3540974]&32768|0)!=0){e5L(c[3531962]|0)}if((a&1|0)!=0){break}eX0(0,0,c[3532136]|0)}}while(0);if((c[3540974]&32768|0)==0){e5L(c[3531962]|0)}if((a&4|0)!=0){f=c[3532276]|0;R8(f);return 0}eX4(0);f=c[3532276]|0;R8(f);return 0}function e_F(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;g=i;i=i+208|0;h=g|0;j=g+16|0;k=g+32|0;l=g+48|0;m=g+64|0;n=g+80|0;o=g+96|0;p=g+112|0;q=g+128|0;r=g+144|0;s=g+160|0;t=g+176|0;u=g+192|0;if((f|0)!=0){c[f>>2]=169735}if((e&96|0)!=0){gGz(u|0,0,12);v=c[3532020]|0;c[u>>2]=v;c[u+4>>2]=(c[3532022]|0)-v;c[u+12>>2]=162152;v=c[2076592]|0;gj[v&4095](u)|0;u=s|0;v=(e&64|0)==0;do{if(!v){gGz(r|0,0,16);c[2394]=-1;if((c[2392]|0)<0){break}w=s+9|0;x=q;y=q|0;z=q+4|0;A=q+12|0;B=r|0;C=r+4|0;D=r+12|0;E=0;do{gGC(u|0,614896,11)|0;a[w]=E+48&255;F=8452256+(E<<2)|0;gGz(x|0,0,12);c[y>>2]=F;c[z>>2]=4;c[A>>2]=164976;gj[c[2076592]&4095](q)|0;if((c[F>>2]|0)!=0){c[B>>2]=c[14130368+(E<<2)>>2];c[C>>2]=c[8452184+(E<<2)>>2];c[D>>2]=u;F=c[2076592]|0;gj[F&4095](r)|0}E=E+1|0;}while((E|0)<=(c[2392]|0))}}while(0);fw$(e);eZ7(e);if((e&32|0)!=0){gGz(n|0,0,12);c[n>>2]=9681584;c[n+4>>2]=26;c[n+12>>2]=305992;r=c[2076592]|0;gj[r&4095](n)|0}do{if(!v){gGz(m|0,0,12);c[m>>2]=9757184;c[m+4>>2]=4;c[m+12>>2]=519648;n=c[2076592]|0;gj[n&4095](m)|0;gGz(l|0,0,12);c[l>>2]=9771512;c[l+4>>2]=4;c[l+12>>2]=506152;n=c[2076592]|0;gj[n&4095](l)|0;gGz(k|0,0,12);c[k>>2]=9771552;c[k+4>>2]=4;c[k+12>>2]=494264;n=c[2076592]|0;gj[n&4095](k)|0;gGz(j|0,0,12);c[j>>2]=9627072;c[j+4>>2]=1;c[j+12>>2]=482144;n=c[2076592]|0;gj[n&4095](j)|0;gGz(h|0,0,12);c[h>>2]=9752272;c[h+4>>2]=1;c[h+12>>2]=469424;n=c[2076592]|0;gj[n&4095](h)|0;if(v|a[7460968]^1){break}gGz(p|0,0,12);c[p>>2]=8453216;c[p+4>>2]=4;c[p+12>>2]=107480;n=c[2076592]|0;gj[n&4095](p)|0;gGz(o|0,0,12);c[o>>2]=14168504;c[o+4>>2]=256;c[o+12>>2]=476464;n=c[2076592]|0;gj[n&4095](o)|0;if((e&2|0)==0){break}else{G=0}do{mv(0,G,d[14168504+G|0]|0);G=G+1|0;}while((G|0)<256)}}while(0);if(a[7460960]|0){T0(e,f)}if((c[3532036]|0)!=0){UE(e,f)}gGz(t|0,0,12);c[t>>2]=14127752;c[t+4>>2]=1;c[t+12>>2]=272344;f=c[2076592]|0;gj[f&4095](t)|0}if((e&2|0)==0){i=g;return 0}e=c[2439330]|0;t=(e|0)==0;if(!t){f=e;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];f=c[3528484]|0;c[2076596]=f;G=c[2417276]|0;c[3541536]=G;c[1836236]=0;o=a[14127752]&3;a[14127752]=o;p=c[3531932]|0;v=((o&255)<<14)-16384|0;o=64;h=64;while(1){c[e+76+(h<<2)>>2]=p+(v+(h<<8));j=o+1&65535;if((j&65535)>127){H=64;I=64;break}else{o=j;h=j&65535}}while(1){h=p+(v+(I<<8))|0;c[e+76+(I+512<<2)>>2]=h;c[e+76+(I+768<<2)>>2]=h;h=H+1&65535;if((h&65535)>127){break}else{H=h;I=h&65535}}if(!t){t=e;gGC(t|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=f;c[2417276]=G;c[1836236]=-1;i=g;return 0}function e_G(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4786868+(b*112|0)>>2];c[a+104>>2]=c[4786872+(b*112|0)>>2];c[a+108>>2]=c[4786876+(b*112|0)>>2];d=0;return d|0}function e_H(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=4786768+(b*112|0);e=0;return e|0}function e_I(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>39){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5551160+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e_J(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4785972+(b*112|0)>>2];c[a+104>>2]=c[4785976+(b*112|0)>>2];c[a+108>>2]=c[4785980+(b*112|0)>>2];d=0;return d|0}function e_K(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=4785872+(b*112|0);e=0;return e|0}function e_L(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>39){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5550680+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e_M(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4787764+(b*112|0)>>2];c[a+104>>2]=c[4787768+(b*112|0)>>2];c[a+108>>2]=c[4787772+(b*112|0)>>2];d=0;return d|0}function e_N(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=4787664+(b*112|0);e=0;return e|0}function e_O(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4789556+(b*112|0)>>2];c[a+104>>2]=c[4789560+(b*112|0)>>2];c[a+108>>2]=c[4789564+(b*112|0)>>2];d=0;return d|0}function e_P(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=4789456+(b*112|0);e=0;return e|0}function e_Q(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4788660+(b*112|0)>>2];c[a+104>>2]=c[4788664+(b*112|0)>>2];c[a+108>>2]=c[4788668+(b*112|0)>>2];d=0;return d|0}function e_R(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=4788560+(b*112|0);e=0;return e|0}function e_S(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>5){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7358316+(b*112|0)>>2];c[a+104>>2]=c[7358320+(b*112|0)>>2];c[a+108>>2]=c[7358324+(b*112|0)>>2];d=0;return d|0}function e_T(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<6&(d|0)==0)){e=1;return e|0}c[a>>2]=7358216+(b*112|0);e=0;return e|0}function e_U(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4154304+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function e_V(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>25){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7402296+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e_W(){var b=0,d=0,e=0,f=0,g=0;b=e$q(6122,11662,5740)|0;if((b|0)!=0){return b|0}d=0;e=(c[3532204]|0)+262144|0;while(1){f=a[e]|0;g=e+1|0;a[e]=a[g]|0;a[g]=f;f=d+1|0;if((f|0)<262144){d=f;e=e+2|0}else{break}}return b|0}function e_X(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if((a[14128072]|0)!=0){e$p()}gu[c[3532050]&16383]();d=c[2392]|0;if((d|0)>=0){gGz(8452240,0,((d|0)>0?(d<<2)+4|0:4)|0)}c[2113054]=0;d=c[2385548]|0;if((d|0)>0){gGz(9752472,0,((d|0)>1?d<<2:4)|0)}c[2433530]=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}d=c[2439330]|0;if((d|0)!=0){e=d;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;do{if((c[3532036]|0)==0){f=100}else{c[2415126]=9662152;e=c[2415557]|0;d=e&3;if((d|0)==3){f=133;break}f=(4e6/(4e6/((c[2415554]|0)/(c[600992+((e>>>3&1)<<4)+(d<<2)>>2]|0)|0|0)|0|0)|0|0)/((c[2424]|0)/100|0|0)|0}}while(0);d=0;e=0;L48961:while(1){g=e;do{if((g|0)>=(f|0)){break L48961}g=g+1|0;h=ag(133333/(f|0)|0,g)|0;i=h-(c[2113054]|0)-(c[2113056]|0)+(c[2276108]|0)|0;c[2113056]=i;h=RG(i)|0;c[2113054]=(c[2113054]|0)+h;c[2276108]=-1;c[2113056]=-1;h=ag(66666/(f|0)|0,g)|0;i=c[2433530]|0;j=h-i-(c[2426530]|0)+(c[2076596]|0)|0;do{if((j|0)>=1){if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){h=gfc(j)|0;c[2433530]=(c[2433530]|0)+h;break}else{c[2433530]=j+i;break}}}while(0);if((c[3532036]|0)!=0){UD()}k=c[2112964]|0;}while((k|0)==0);i=((a[9688]|0?534:0)|0)/(f|0)|0;gg[c[3542124]&4095](k+(d<<1<<1)|0,i);d=i+d|0;e=g}c[8452200+(c[2394]<<2)>>2]=8197;c[2276080]=1280;if((c[2276079]|0)>>>0<1280){RH(5)}e=c[2112964]|0;do{if((e|0)!=0){k=a[9688]|0?534:0;if((k|0)==(d|0)){break}gg[c[3542124]&4095](e+(d<<1<<1)|0,k-d|0)}}while(0);if((c[3532036]|0)!=0){Uz(0,c[2112964]|0,a[9688]|0?534:0)}d=c[1836236]|0;e=c[9757320+(d<<2)>>2]|0;if((e|0)!=0){k=e;gGC(k|0,9706056,76)|0}c[9752472+(d<<2)>>2]=c[2433530];c[14113936+(d<<2)>>2]=c[2076596];c[9669104+(d<<2)>>2]=c[3541536];c[1836236]=-1;d=c[2394]|0;k=c[14130368+(d<<2)>>2]|0;if((k|0)!=0){gGC(k|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;if((c[2112968]|0)==0){return 0}e_E()|0;return 0}function e_Y(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6602132+(b*112|0)>>2];c[a+104>>2]=c[6602136+(b*112|0)>>2];c[a+108>>2]=c[6602140+(b*112|0)>>2];d=0;return d|0}function e_Z(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=6602032+(b*112|0);e=0;return e|0}function e__(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>40){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6978200+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e_$(){var b=0,d=0,e=0,f=0,g=0;b=e$q(12592,11662,12166)|0;if((b|0)!=0){a[1666912]=1;return b|0}d=0;e=(c[3532204]|0)+262144|0;while(1){f=a[e]|0;g=e+1|0;a[e]=a[g]|0;a[g]=f;f=d+1|0;if((f|0)<262144){d=f;e=e+2|0}else{break}}a[1666912]=1;return b|0}function e_0(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5950372+(b*112|0)>>2];c[a+104>>2]=c[5950376+(b*112|0)>>2];c[a+108>>2]=c[5950380+(b*112|0)>>2];d=0;return d|0}function e_1(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=5950272+(b*112|0);e=0;return e|0}function e_2(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2568980+(b*112|0)>>2];c[a+104>>2]=c[2568984+(b*112|0)>>2];c[a+108>>2]=c[2568988+(b*112|0)>>2];d=0;return d|0}function e_3(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=2568880+(b*112|0);e=0;return e|0}function e_4(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>31){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3721400+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e_5(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>5){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2843292+(b*112|0)>>2];c[a+104>>2]=c[2843296+(b*112|0)>>2];c[a+108>>2]=c[2843300+(b*112|0)>>2];d=0;return d|0}function e_6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<6&(d|0)==0)){e=1;return e|0}c[a>>2]=2843192+(b*112|0);e=0;return e|0}function e_7(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>46){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3928880+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e_8(){var b=0,d=0,e=0,f=0,g=0;b=e$q(12592,11662,5740)|0;if((b|0)!=0){return b|0}d=0;e=(c[3532204]|0)+262144|0;while(1){f=a[e]|0;g=e+1|0;a[e]=a[g]|0;a[g]=f;f=d+1|0;if((f|0)<262144){d=f;e=e+2|0}else{break}}return b|0}function e_9(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2895788+(b*112|0)>>2];c[a+104>>2]=c[2895792+(b*112|0)>>2];c[a+108>>2]=c[2895796+(b*112|0)>>2];d=0;return d|0}function e$a(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=2895688+(b*112|0);e=0;return e|0}function e$b(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>38){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4022968+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e$c(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3059556+(b*112|0)>>2];c[a+104>>2]=c[3059560+(b*112|0)>>2];c[a+108>>2]=c[3059564+(b*112|0)>>2];d=0;return d|0}function e$d(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=3059456+(b*112|0);e=0;return e|0}function e$e(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1307904+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function e$f(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>36){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4217560+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e$g(){return e$q(5964,7920,1176)|0}function e$h(){var d=0,e=0,f=0,g=0,h=0;d=(c[3531956]|0)+1|0;c[3531956]=d;if((a[14128072]|0)!=0|(d|0)>179){e$p()}c[3532080]=-1;a[14128321]=0;d=0;e=-1;f=0;g=-1;h=-1;do{e=((a[14128312+d|0]&1)<<d^e&255)&255;f=((a[14128304+d|0]&1)<<d^f&255)&255;g=((a[14128296+d|0]&1)<<d^g&255)&255;h=((a[14128288+d|0]&1)<<d^h&255)&255;d=d+1|0;}while((d|0)<8);a[14128320]=e;a[14128321]=f;a[14128322]=g;a[14128323]=h;h=c[2392]|0;if((h|0)>=0){gGz(8452240,0,((h|0)>0?(h<<2)+4|0:4)|0)}c[2113054]=0;h=c[2385548]|0;if((h|0)>0){gGz(9752472,0,((h|0)>1?h<<2:4)|0)}c[2433530]=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];h=c[3532592]|0;if((h|0)!=0){gGC(9104152,h|0,280)|0}c[2113054]=c[2113060]}h=c[2439330]|0;if((h|0)!=0){g=h;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;c[2113056]=133333;g=RG(133333)|0;c[2113054]=(c[2113054]|0)+g;c[2276108]=-1;c[2113056]=-1;c[8452200+(c[2394]<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0<1024){RH(4)}g=c[2438228]|0;h=gGS(-747372544,31788,g,(g|0)<0|0?-1:0)|0;g=h;Sb(66666);h=c[2443830]|0;if((h|0)<1073676288){c[2443830]=h-g}h=c[2443831]|0;if((h|0)<1073676288){c[2443831]=h-g}h=(c[3528512]|0)-g|0;c[3528512]=(h|0)<0?0:h;h=c[2112964]|0;if((h|0)!=0){gg[c[3542118]&4095](h,a[9688]|0?534:0)}h=c[1836236]|0;g=c[9757320+(h<<2)>>2]|0;if((g|0)!=0){f=g;gGC(f|0,9706056,76)|0}c[9752472+(h<<2)>>2]=c[2433530];c[14113936+(h<<2)>>2]=c[2076596];c[9669104+(h<<2)>>2]=c[3541536];c[1836236]=-1;h=c[2394]|0;f=c[14130368+(h<<2)>>2]|0;if((f|0)!=0){gGC(f|0,9104152,280)|0}c[8452240+(h<<2)>>2]=c[2113054];c[2394]=-1;if((c[2112968]|0)==0){return 0}e_E()|0;return 0}function e$i(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1602092+(b*112|0)>>2];c[a+104>>2]=c[1602096+(b*112|0)>>2];c[a+108>>2]=c[1602100+(b*112|0)>>2];d=0;return d|0}function e$j(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=1601992+(b*112|0);e=0;return e|0}function e$k(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1601084+(b*112|0)>>2];c[a+104>>2]=c[1601088+(b*112|0)>>2];c[a+108>>2]=c[1601092+(b*112|0)>>2];d=0;return d|0}function e$l(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=1600984+(b*112|0);e=0;return e|0}function e$m(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>36){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3844416+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e$n(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2743220+(b*112|0)>>2];c[a+104>>2]=c[2743224+(b*112|0)>>2];c[a+108>>2]=c[2743228+(b*112|0)>>2];d=0;return d|0}function e$o(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=2743120+(b*112|0);e=0;return e|0}function e$p(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=c[3532020]|0;gGz(d|0,0,(c[3532022]|0)-d|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=i;c[1836236]=-1;if(a[7460960]|0){c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;l6(0)}if((c[3532036]|0)!=0){UA()}i=c[2439330]|0;if((i|0)!=0){g=i;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;if(a[7460968]|0){mx(0);g=c[1836236]|0;j=g;k=c[9757320+(g<<2)>>2]|0}else{j=0;k=i}if((k|0)!=0){i=k;gGC(i|0,9706056,76)|0}c[9752472+(j<<2)>>2]=c[2433530];c[14113936+(j<<2)>>2]=c[2076596];c[9669104+(j<<2)>>2]=c[3541536];c[1836236]=-1;j=c[2439330]|0;i=(j|0)==0;if(!i){k=j;gGC(9706056,k|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];k=c[3528484]|0;c[2076596]=k;g=c[2417276]|0;c[3541536]=g;c[1836236]=0;a[14127752]=1;f=c[3531932]|0;e=64;d=64;while(1){c[j+76+(d<<2)>>2]=f+(d<<8);l=e+1&65535;if((l&65535)>127){m=64;n=64;break}else{e=l;d=l&65535}}while(1){d=f+(n<<8)|0;c[j+76+(n+512<<2)>>2]=d;c[j+76+(n+768<<2)>>2]=d;d=m+1&65535;if((d&65535)>127){break}else{m=d;n=d&65535}}if(i){o=c[2433530]|0;c[2438118]=o;c[3528484]=k;c[2417276]=g;c[1836236]=-1;c[2439296]=0;c[2442878]=0;c[2442888]=0;gGz(9681584,0,26);a[9627072]=0;a[9752272]=0;c[2440034]=0;c[2438870]=-1;return}i=j;gGC(i|0,9706056,76)|0;o=c[2433530]|0;c[2438118]=o;c[3528484]=k;c[2417276]=g;c[1836236]=-1;c[2439296]=0;c[2442878]=0;c[2442888]=0;gGz(9681584,0,26);a[9627072]=0;a[9752272]=0;c[2440034]=0;c[2438870]=-1;return}function e$q(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;c[3532044]=1;c[3532030]=1;a[1666912]=0;eZ9(0)|0;c[3532048]=0;c[3532204]=0;c[3531932]=1048576;c[3532136]=1114112;g=(c[3532144]<<1)+1114112|0;c[3531962]=g;h=g+(c[3531994]<<1)|0;c[3532062]=h;g=h+(c[3532058]|0)|0;c[3531952]=g;h=g+(c[3531948]|0)|0;g=h|0;c[3532020]=g;c[3532208]=g;c[3532206]=h+32768;c[3531936]=h+36864;g=h+45056|0;c[3532022]=g;c[3532046]=g;h=g;g=0;while(1){if((g|0)>=1024){break}i=9638528+(g<<2)|0;if((c[i>>2]|0)==0){j=37514;break}else{g=g+1|0}}do{if((j|0)==37514){g=gGq(h)|0;c[i>>2]=g;if((g|0)==0){break}gGz(g|0,0,h|0);c[3532048]=g;gGz(g|0,0,h|0);c[3532204]=g;c[3531932]=g+1048576;c[3532136]=g+1114112;k=(c[3532144]<<1)+1114112|0;c[3531962]=g+k;l=k+(c[3531994]<<1)|0;c[3532062]=g+l;k=l+(c[3532058]|0)|0;c[3531952]=g+k;l=k+(c[3531948]|0)|0;k=g+l|0;c[3532020]=k;c[3532208]=k;c[3532206]=g+(l+32768);c[3531936]=g+(l+36864);k=g+(l+45056)|0;c[3532022]=k;c[3532046]=k;eZ9(1)|0;k=c[3532136]|0;l=1048576;g=1048574;while(1){m=k+(((g|0)/2|0)^1)|0;a[k+g|0]=(d[m]|0)>>>4;a[k+(l-1)|0]=a[m]&15;m=g-2|0;if((m|0)>-1){l=g;g=m}else{break}}g=c[3531962]|0;l=c[3531994]<<1;k=l-2|0;if((k|0)>-1){m=l;l=k;while(1){k=g+(((l|0)/2|0)^1)|0;a[g+l|0]=(d[k]|0)>>>4;a[g+(m-1)|0]=a[k]&15;k=l-2|0;if((k|0)>-1){m=l;l=k}else{break}}}l=c[642608+(c[2436]<<2)>>2]|0;m=c[l+128>>2]|0;if((c[l+52>>2]&4|0)==0){c[2113068]=m;g=c[l+132>>2]|0;c[2113070]=g;c[2443814]=m;c[2440436]=g;n=m;o=g}else{c[2113070]=m;g=c[l+132>>2]|0;c[2113068]=g;c[2440436]=m;c[2443814]=g;n=g;o=m}m=ag(n<<1,o)|0;g=gGq(m)|0;c[2112926]=g;if((g|0)!=0){gGz(g|0,0,m|0)}m=(c[3531994]|0)>>>7&16777215;g=(256-(c[2113070]|0)|0)/2|0;l=0;while(1){if((l|0)>=1024){p=0;break}q=9638528+(l<<2)|0;if((c[q>>2]|0)==0){j=37528;break}else{l=l+1|0}}do{if((j|0)==37528){l=gGq(16384)|0;c[q>>2]=l;if((l|0)==0){p=0;break}gGz(l|0,0,16384);p=l}}while(0);c[3540976]=p;gGz(p|0,0,16384);c[2437028]=m;c[2438624]=g;a[726072]=0;a[7461120]=1;eX5(0,16384,0,(256-(c[2113070]|0)|0)/2|0,0,0);l=0;while(1){if((l|0)>=1024){r=0;break}s=9638528+(l<<2)|0;if((c[s>>2]|0)==0){j=37533;break}else{l=l+1|0}}do{if((j|0)==37533){l=gGq(16384)|0;c[s>>2]=l;if((l|0)==0){r=0;break}gGz(l|0,0,16384);r=l}}while(0);c[2442928]=r;gGz(r|0,0,16384);l=0;while(1){if((l|0)>=1024){t=0;break}u=9638528+(l<<2)|0;if((c[u>>2]|0)==0){j=37538;break}else{l=l+1|0}}do{if((j|0)==37538){l=gGq(16384)|0;c[u>>2]=l;if((l|0)==0){t=0;break}gGz(l|0,0,16384);t=l}}while(0);c[3532276]=t;gGz(t|0,0,4096);c[3532274]=4096;a[7461088]=1;a[7461056]=1;c[3532050]=872;a[7461080]=1;gu[b&16383]();gu[e&16383]();gu[f&16383]();e$p();v=0;return v|0}}while(0);c[3532048]=0;v=1;return v|0}function e$r(){var a=0,b=0,d=0,e=0,f=0,g=0;fxU(0,425984);if((c[2394]|0)==0){a=c[2112932]|0}else{c[2394]=0;b=c[3532596]|0;c[2112932]=b;d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];a=b}b=c[3532204]|0;d=a|0;e=0;while(1){f=b+e|0;c[d>>2]=f;c[d+131072>>2]=f;f=e+1024|0;if(f>>>0>262143){break}else{d=d+4|0;e=f}}e=a+2048|0;d=524288;while(1){f=b+(d-262144)|0;c[e>>2]=f;c[e+131072>>2]=f;f=d+1024|0;if(f>>>0>1048575){break}else{e=e+4|0;d=f}}d=c[3532208]|0;c[a+4288>>2]=d;c[a+69824>>2]=d;c[a+135360>>2]=d;e=d+1024|0;c[a+4292>>2]=e;c[a+69828>>2]=e;c[a+135364>>2]=e;e=d+2048|0;c[a+4296>>2]=e;c[a+69832>>2]=e;c[a+135368>>2]=e;e=d+3072|0;c[a+4300>>2]=e;c[a+69836>>2]=e;c[a+135372>>2]=e;e=d+4096|0;c[a+4304>>2]=e;c[a+69840>>2]=e;c[a+135376>>2]=e;e=d+5120|0;c[a+4308>>2]=e;c[a+69844>>2]=e;c[a+135380>>2]=e;e=d+6144|0;c[a+4312>>2]=e;c[a+69848>>2]=e;c[a+135384>>2]=e;e=d+7168|0;c[a+4316>>2]=e;c[a+69852>>2]=e;c[a+135388>>2]=e;e=d+8192|0;c[a+4320>>2]=e;c[a+69856>>2]=e;c[a+135392>>2]=e;e=d+9216|0;c[a+4324>>2]=e;c[a+69860>>2]=e;c[a+135396>>2]=e;e=d+10240|0;c[a+4328>>2]=e;c[a+69864>>2]=e;c[a+135400>>2]=e;e=d+11264|0;c[a+4332>>2]=e;c[a+69868>>2]=e;c[a+135404>>2]=e;e=d+12288|0;c[a+4336>>2]=e;c[a+69872>>2]=e;c[a+135408>>2]=e;e=d+13312|0;c[a+4340>>2]=e;c[a+69876>>2]=e;c[a+135412>>2]=e;e=d+14336|0;c[a+4344>>2]=e;c[a+69880>>2]=e;c[a+135416>>2]=e;e=d+15360|0;c[a+4348>>2]=e;c[a+69884>>2]=e;c[a+135420>>2]=e;e=c[3532278]|0;d=a+49152|0;b=12582912;while(1){c[d>>2]=e+(b-12582912);f=b+1024|0;if(f>>>0>12648447){break}else{d=d+4|0;b=f}}b=c[3540976]|0;c[a+53248>>2]=b;c[a+118784>>2]=b;c[a+184320>>2]=b;d=b+1024|0;c[a+53252>>2]=d;c[a+118788>>2]=d;c[a+184324>>2]=d;d=b+2048|0;c[a+53256>>2]=d;c[a+118792>>2]=d;c[a+184328>>2]=d;d=b+3072|0;c[a+53260>>2]=d;c[a+118796>>2]=d;c[a+184332>>2]=d;d=b+4096|0;c[a+53264>>2]=d;c[a+118800>>2]=d;c[a+184336>>2]=d;d=b+5120|0;c[a+53268>>2]=d;c[a+118804>>2]=d;c[a+184340>>2]=d;d=b+6144|0;c[a+53272>>2]=d;c[a+118808>>2]=d;c[a+184344>>2]=d;d=b+7168|0;c[a+53276>>2]=d;c[a+118812>>2]=d;c[a+184348>>2]=d;d=b+8192|0;c[a+53280>>2]=d;c[a+118816>>2]=d;c[a+184352>>2]=d;d=b+9216|0;c[a+53284>>2]=d;c[a+118820>>2]=d;c[a+184356>>2]=d;d=b+10240|0;c[a+53288>>2]=d;c[a+118824>>2]=d;c[a+184360>>2]=d;d=b+11264|0;c[a+53292>>2]=d;c[a+118828>>2]=d;c[a+184364>>2]=d;d=b+12288|0;c[a+53296>>2]=d;c[a+118832>>2]=d;c[a+184368>>2]=d;d=b+13312|0;c[a+53300>>2]=d;c[a+118836>>2]=d;c[a+184372>>2]=d;d=b+14336|0;c[a+53304>>2]=d;c[a+118840>>2]=d;c[a+184376>>2]=d;d=b+15360|0;c[a+53308>>2]=d;c[a+118844>>2]=d;c[a+184380>>2]=d;c[a+196648>>2]=1658;c[a+196728>>2]=6;c[a+196608>>2]=3522;c[a+196688>>2]=186;a=c[3532592]|0;if((a|0)==0){g=c[2113054]|0;c[2113060]=g;c[2394]=-1;return}gGC(a|0,9104152,280)|0;g=c[2113054]|0;c[2113060]=g;c[2394]=-1;return}function e$s(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;fwR(0);a=c[2439330]|0;d=(a|0)==0;if(!d){e=a;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];e=c[3528484]|0;c[2076596]=e;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;g=c[3531932]|0;h=0;i=0;while(1){c[a+76+(i<<2)>>2]=g+(i<<8);j=h+1&65535;if((j&65535)>63){k=0;l=0;break}else{h=j;i=j&65535}}while(1){i=g+(l<<8)|0;c[a+76+(l+512<<2)>>2]=i;c[a+76+(l+768<<2)>>2]=i;i=k+1&65535;if((i&65535)>63){break}else{k=i;l=i&65535}}l=c[3531936]|0;k=192;g=192;while(1){c[a+76+(g<<2)>>2]=l+((g<<8)-49152);i=k+1&65535;if((i&65535)>223){m=192;n=192;break}else{k=i;g=i&65535}}while(1){c[a+76+(n+256<<2)>>2]=l+((n<<8)-49152);g=m+1&65535;if((g&65535)>223){o=192;p=192;break}else{m=g;n=g&65535}}while(1){n=l+((p<<8)-49152)|0;c[a+76+(p+512<<2)>>2]=n;c[a+76+(p+768<<2)>>2]=n;n=o+1&65535;if((n&65535)>223){break}else{o=n;p=n&65535}}c[a+4184>>2]=744;c[a+4180>>2]=3368;if(d){q=c[2433530]|0;c[2438118]=q;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}d=a;gGC(d|0,9706056,76)|0;q=c[2433530]|0;c[2438118]=q;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}function e$t(){var b=0,d=0,e=0;b=i;i=i+8|0;d=b|0;c[d>>2]=524288;e=c[3531952]|0;TW(e,d,e,d,224,3450,22);c[2438228]=4e6;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=511;h[745406]=1.0;c[2436786]=3;h[745405]=1.0;c[2436784]=3;h[745404]=.25;a[3203280]=1;a[7460968]=0;a[7460960]=1;c[3532036]=0;i=b;return}function e$u(b,c){b=b|0;c=c|0;a[9706117]=(c|0)!=0|0;return}function e$v(a){a=a|0;var b=0.0,d=0,e=0;b=+((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0);d=+V(b)>=1.0?b>0.0?(al(+U(b/4294967296.0),4294967295.0)|0)>>>0:~~+af((b- +(~~b>>>0))/4294967296.0)>>>0:0;e=gGU(~~b>>>0,d,a,(a|0)<0|0?-1:0)|0;a=gGS(e,K,4e6,0)|0;return a|0}function e$w(){return+(+((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)/4.0e6)}function e$x(){var b=0,c=0,d=0,e=0,f=0;gGz(14129040,-1|0,6);b=a[1666912]|0?-49:-1;a[14129042]=b;c=0;d=-1;e=-1;f=b;do{d=((a[14129032+c|0]&1)<<c^d&255)&255;e=((a[14129024+c|0]&1)<<c^e&255)&255;f=((a[14129016+c|0]&1)<<c^f&255)&255;c=c+1|0;}while((c|0)<8);a[14129040]=d;a[14129041]=e;a[14129042]=f;return}function e$y(){var a=0,b=0,d=0,e=0,f=0,g=0;fxU(0,425984);if((c[2394]|0)==0){a=c[2112932]|0}else{c[2394]=0;b=c[3532596]|0;c[2112932]=b;d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];a=b}b=c[3532204]|0;d=a|0;e=0;while(1){f=b+e|0;c[d>>2]=f;c[d+131072>>2]=f;f=e+1024|0;if(f>>>0>262143){break}else{d=d+4|0;e=f}}e=a+2048|0;d=524288;while(1){f=b+(d-262144)|0;c[e>>2]=f;c[e+131072>>2]=f;f=d+1024|0;if(f>>>0>1048575){break}else{e=e+4|0;d=f}}d=c[3532208]|0;c[a+4096>>2]=d;c[a+69632>>2]=d;c[a+135168>>2]=d;e=d+1024|0;c[a+4100>>2]=e;c[a+69636>>2]=e;c[a+135172>>2]=e;e=d+2048|0;c[a+4104>>2]=e;c[a+69640>>2]=e;c[a+135176>>2]=e;e=d+3072|0;c[a+4108>>2]=e;c[a+69644>>2]=e;c[a+135180>>2]=e;e=d+4096|0;c[a+4112>>2]=e;c[a+69648>>2]=e;c[a+135184>>2]=e;e=d+5120|0;c[a+4116>>2]=e;c[a+69652>>2]=e;c[a+135188>>2]=e;e=d+6144|0;c[a+4120>>2]=e;c[a+69656>>2]=e;c[a+135192>>2]=e;e=d+7168|0;c[a+4124>>2]=e;c[a+69660>>2]=e;c[a+135196>>2]=e;e=d+8192|0;c[a+4128>>2]=e;c[a+69664>>2]=e;c[a+135200>>2]=e;e=d+9216|0;c[a+4132>>2]=e;c[a+69668>>2]=e;c[a+135204>>2]=e;e=d+10240|0;c[a+4136>>2]=e;c[a+69672>>2]=e;c[a+135208>>2]=e;e=d+11264|0;c[a+4140>>2]=e;c[a+69676>>2]=e;c[a+135212>>2]=e;e=d+12288|0;c[a+4144>>2]=e;c[a+69680>>2]=e;c[a+135216>>2]=e;e=d+13312|0;c[a+4148>>2]=e;c[a+69684>>2]=e;c[a+135220>>2]=e;e=d+14336|0;c[a+4152>>2]=e;c[a+69688>>2]=e;c[a+135224>>2]=e;e=d+15360|0;c[a+4156>>2]=e;c[a+69692>>2]=e;c[a+135228>>2]=e;e=c[3532278]|0;d=a+49152|0;b=12582912;while(1){c[d>>2]=e+(b-12582912);f=b+1024|0;if(f>>>0>12648447){break}else{d=d+4|0;b=f}}b=c[3540976]|0;c[a+53248>>2]=b;c[a+118784>>2]=b;c[a+184320>>2]=b;d=b+1024|0;c[a+53252>>2]=d;c[a+118788>>2]=d;c[a+184324>>2]=d;d=b+2048|0;c[a+53256>>2]=d;c[a+118792>>2]=d;c[a+184328>>2]=d;d=b+3072|0;c[a+53260>>2]=d;c[a+118796>>2]=d;c[a+184332>>2]=d;d=b+4096|0;c[a+53264>>2]=d;c[a+118800>>2]=d;c[a+184336>>2]=d;d=b+5120|0;c[a+53268>>2]=d;c[a+118804>>2]=d;c[a+184340>>2]=d;d=b+6144|0;c[a+53272>>2]=d;c[a+118808>>2]=d;c[a+184344>>2]=d;d=b+7168|0;c[a+53276>>2]=d;c[a+118812>>2]=d;c[a+184348>>2]=d;d=b+8192|0;c[a+53280>>2]=d;c[a+118816>>2]=d;c[a+184352>>2]=d;d=b+9216|0;c[a+53284>>2]=d;c[a+118820>>2]=d;c[a+184356>>2]=d;d=b+10240|0;c[a+53288>>2]=d;c[a+118824>>2]=d;c[a+184360>>2]=d;d=b+11264|0;c[a+53292>>2]=d;c[a+118828>>2]=d;c[a+184364>>2]=d;d=b+12288|0;c[a+53296>>2]=d;c[a+118832>>2]=d;c[a+184368>>2]=d;d=b+13312|0;c[a+53300>>2]=d;c[a+118836>>2]=d;c[a+184372>>2]=d;d=b+14336|0;c[a+53304>>2]=d;c[a+118840>>2]=d;c[a+184376>>2]=d;d=b+15360|0;c[a+53308>>2]=d;c[a+118844>>2]=d;c[a+184380>>2]=d;c[a+196648>>2]=246;c[a+196728>>2]=714;c[a+196608>>2]=1828;c[a+196688>>2]=1032;a=c[3532592]|0;if((a|0)==0){g=c[2113054]|0;c[2113060]=g;c[2394]=-1;return}gGC(a|0,9104152,280)|0;g=c[2113054]|0;c[2113060]=g;c[2394]=-1;return}function e$z(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;fwR(0);a=c[2439330]|0;d=(a|0)==0;if(!d){e=a;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];e=c[3528484]|0;c[2076596]=e;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;g=c[3531932]|0;h=0;i=0;while(1){c[a+76+(i<<2)>>2]=g+(i<<8);j=h+1&65535;if((j&65535)>63){k=0;l=0;break}else{h=j;i=j&65535}}while(1){i=g+(l<<8)|0;c[a+76+(l+512<<2)>>2]=i;c[a+76+(l+768<<2)>>2]=i;i=k+1&65535;if((i&65535)>63){break}else{k=i;l=i&65535}}l=c[3531936]|0;c[a+588>>2]=l;c[a+592>>2]=l+256;c[a+596>>2]=l+512;c[a+600>>2]=l+768;c[a+604>>2]=l+1024;c[a+608>>2]=l+1280;c[a+612>>2]=l+1536;c[a+616>>2]=l+1792;c[a+620>>2]=l+2048;c[a+624>>2]=l+2304;c[a+628>>2]=l+2560;c[a+632>>2]=l+2816;c[a+636>>2]=l+3072;c[a+640>>2]=l+3328;c[a+644>>2]=l+3584;c[a+648>>2]=l+3840;k=128;g=128;while(1){c[a+76+(g+256<<2)>>2]=l+((g<<8)-32768);i=k+1&65535;if((i&65535)>143){m=128;n=128;break}else{k=i;g=i&65535}}while(1){g=l+((n<<8)-32768)|0;c[a+76+(n+512<<2)>>2]=g;c[a+76+(n+768<<2)>>2]=g;g=m+1&65535;if((g&65535)>143){break}else{m=g;n=g&65535}}c[a+4184>>2]=1516;c[a+4180>>2]=2036;if(d){o=c[2433530]|0;c[2438118]=o;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}d=a;gGC(d|0,9706056,76)|0;o=c[2433530]|0;c[2438118]=o;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}function e$A(){var b=0,d=0,e=0,f=0,g=0;b=a[9680]|0;d=b?32e3:0;if(b){if(a[9624]|0){b=d*3|0;e=62500;while(1){if((e|0)>(b|0)){e=e>>1}else{f=1222;g=e;break}}}else{f=2462;g=d}c[2429380]=g;c[3542124]=f;mw(4e6,g);g=gGq(262144)|0;c[2406684]=g;gGz(g|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(4e6,11025)}g=c[3531464]|0;c[g+44344>>2]=668;c[g+44348>>2]=1914;h[745421]=.5;c[2436794]=3;h[745420]=.5;c[2436792]=3;a[7460968]=1;a[7460960]=0;c[3532036]=0;return}function e$B(b){b=b|0;a[9706117]=(b|0)!=0|0;return}function e$C(){var b=0,d=0,e=0,f=0,g=0;b=a[9680]|0;d=b?32e3:0;if(b){if(a[9624]|0){b=d*3|0;e=62500;while(1){if((e|0)>(b|0)){e=e>>1}else{f=1222;g=e;break}}}else{f=2462;g=d}c[2429380]=g;c[3542124]=f;mw(4e6,g);g=gGq(262144)|0;c[2406684]=g;gGz(g|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(4e6,11025)}g=c[3531464]|0;c[g+44344>>2]=668;c[g+44348>>2]=1914;h[745421]=.5;c[2436794]=3;h[745420]=.5;c[2436792]=3;UB(0,3450,384e3,8430,5);c[2415126]=9662152;h[1207773]=1.0;c[2415548]=3;a[7460968]=1;c[3532036]=1;a[7460960]=0;return}function e$D(){var a=0,b=0,e=0;a=c[2438870]|0;if((a|0)!=-1){b=a&15;c[2415126]=9662152;if((c[2415542]|0)==4){e=b}else{e=b<<1&14}c[2415538]=e;c[2438870]=-1;return}e=c[2440034]|0;b=d[(c[3532062]|0)+e|0]|0;c[2438870]=b;c[2440034]=e+1&65535;e=b>>>4;c[2415126]=9662152;if((c[2415542]|0)==4){c[2415538]=e;return}else{c[2415538]=e<<1&14;return}}function e$E(){var a=0,b=0,d=0,e=0,f=0,g=0;fxU(0,425984);if((c[2394]|0)==0){a=c[2112932]|0}else{c[2394]=0;b=c[3532596]|0;c[2112932]=b;d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];a=b}b=c[3532204]|0;d=a|0;e=0;while(1){f=b+e|0;c[d>>2]=f;c[d+131072>>2]=f;f=e+1024|0;if(f>>>0>262143){break}else{d=d+4|0;e=f}}e=a+2048|0;d=524288;while(1){f=b+(d-262144)|0;c[e>>2]=f;c[e+131072>>2]=f;f=d+1024|0;if(f>>>0>1048575){break}else{e=e+4|0;d=f}}d=c[3532208]|0;c[a+8192>>2]=d;c[a+73728>>2]=d;c[a+139264>>2]=d;e=d+1024|0;c[a+8196>>2]=e;c[a+73732>>2]=e;c[a+139268>>2]=e;e=d+2048|0;c[a+8200>>2]=e;c[a+73736>>2]=e;c[a+139272>>2]=e;e=d+3072|0;c[a+8204>>2]=e;c[a+73740>>2]=e;c[a+139276>>2]=e;e=d+4096|0;c[a+8208>>2]=e;c[a+73744>>2]=e;c[a+139280>>2]=e;e=d+5120|0;c[a+8212>>2]=e;c[a+73748>>2]=e;c[a+139284>>2]=e;e=d+6144|0;c[a+8216>>2]=e;c[a+73752>>2]=e;c[a+139288>>2]=e;e=d+7168|0;c[a+8220>>2]=e;c[a+73756>>2]=e;c[a+139292>>2]=e;e=d+8192|0;c[a+8224>>2]=e;c[a+73760>>2]=e;c[a+139296>>2]=e;e=d+9216|0;c[a+8228>>2]=e;c[a+73764>>2]=e;c[a+139300>>2]=e;e=d+10240|0;c[a+8232>>2]=e;c[a+73768>>2]=e;c[a+139304>>2]=e;e=d+11264|0;c[a+8236>>2]=e;c[a+73772>>2]=e;c[a+139308>>2]=e;e=d+12288|0;c[a+8240>>2]=e;c[a+73776>>2]=e;c[a+139312>>2]=e;e=d+13312|0;c[a+8244>>2]=e;c[a+73780>>2]=e;c[a+139316>>2]=e;e=d+14336|0;c[a+8248>>2]=e;c[a+73784>>2]=e;c[a+139320>>2]=e;e=d+15360|0;c[a+8252>>2]=e;c[a+73788>>2]=e;c[a+139324>>2]=e;e=c[3540976]|0;c[a+49152>>2]=e;c[a+114688>>2]=e;c[a+180224>>2]=e;d=e+1024|0;c[a+49156>>2]=d;c[a+114692>>2]=d;c[a+180228>>2]=d;d=e+2048|0;c[a+49160>>2]=d;c[a+114696>>2]=d;c[a+180232>>2]=d;d=e+3072|0;c[a+49164>>2]=d;c[a+114700>>2]=d;c[a+180236>>2]=d;d=e+4096|0;c[a+49168>>2]=d;c[a+114704>>2]=d;c[a+180240>>2]=d;d=e+5120|0;c[a+49172>>2]=d;c[a+114708>>2]=d;c[a+180244>>2]=d;d=e+6144|0;c[a+49176>>2]=d;c[a+114712>>2]=d;c[a+180248>>2]=d;d=e+7168|0;c[a+49180>>2]=d;c[a+114716>>2]=d;c[a+180252>>2]=d;d=e+8192|0;c[a+49184>>2]=d;c[a+114720>>2]=d;c[a+180256>>2]=d;d=e+9216|0;c[a+49188>>2]=d;c[a+114724>>2]=d;c[a+180260>>2]=d;d=e+10240|0;c[a+49192>>2]=d;c[a+114728>>2]=d;c[a+180264>>2]=d;d=e+11264|0;c[a+49196>>2]=d;c[a+114732>>2]=d;c[a+180268>>2]=d;d=e+12288|0;c[a+49200>>2]=d;c[a+114736>>2]=d;c[a+180272>>2]=d;d=e+13312|0;c[a+49204>>2]=d;c[a+114740>>2]=d;c[a+180276>>2]=d;d=e+14336|0;c[a+49208>>2]=d;c[a+114744>>2]=d;c[a+180280>>2]=d;d=e+15360|0;c[a+49212>>2]=d;c[a+114748>>2]=d;c[a+180284>>2]=d;d=c[3532278]|0;e=a+49216|0;b=12599296;while(1){c[e>>2]=d+(b-12582912);f=b+1024|0;if(f>>>0>12648447){break}else{e=e+4|0;b=f}}b=a+53248|0;e=13631488;while(1){c[b>>2]=d+(e-13631488);f=e+1024|0;if(f>>>0>13697023){break}else{b=b+4|0;e=f}}c[a+196648>>2]=3082;c[a+196728>>2]=2190;c[a+196608>>2]=2340;c[a+196688>>2]=1250;a=c[3532592]|0;if((a|0)==0){g=c[2113054]|0;c[2113060]=g;c[2394]=-1;return}gGC(a|0,9104152,280)|0;g=c[2113054]|0;c[2113060]=g;c[2394]=-1;return}function e$F(){var a=0,b=0,d=0,e=0,f=0,g=0;fxU(0,425984);if((c[2394]|0)==0){a=c[2112932]|0}else{c[2394]=0;b=c[3532596]|0;c[2112932]=b;d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];a=b}b=c[3532204]|0;d=a|0;e=0;while(1){f=b+e|0;c[d>>2]=f;c[d+131072>>2]=f;f=e+1024|0;if(f>>>0>524287){break}else{d=d+4|0;e=f}}e=c[3532208]|0;d=a+4096|0;b=1048576;while(1){f=e+(b-1048576)|0;c[d>>2]=f;c[d+65536>>2]=f;c[d+131072>>2]=f;f=b+1024|0;if(f>>>0>1081343){break}else{d=d+4|0;b=f}}b=c[3532206]|0;c[a+32768>>2]=b;c[a+98304>>2]=b;c[a+163840>>2]=b;d=b+1024|0;c[a+32772>>2]=d;c[a+98308>>2]=d;c[a+163844>>2]=d;d=b+2048|0;c[a+32776>>2]=d;c[a+98312>>2]=d;c[a+163848>>2]=d;d=b+3072|0;c[a+32780>>2]=d;c[a+98316>>2]=d;c[a+163852>>2]=d;d=c[3540976]|0;c[a+45056>>2]=d;c[a+110592>>2]=d;c[a+176128>>2]=d;b=d+1024|0;c[a+45060>>2]=b;c[a+110596>>2]=b;c[a+176132>>2]=b;b=d+2048|0;c[a+45064>>2]=b;c[a+110600>>2]=b;c[a+176136>>2]=b;b=d+3072|0;c[a+45068>>2]=b;c[a+110604>>2]=b;c[a+176140>>2]=b;b=d+4096|0;c[a+45072>>2]=b;c[a+110608>>2]=b;c[a+176144>>2]=b;b=d+5120|0;c[a+45076>>2]=b;c[a+110612>>2]=b;c[a+176148>>2]=b;b=d+6144|0;c[a+45080>>2]=b;c[a+110616>>2]=b;c[a+176152>>2]=b;b=d+7168|0;c[a+45084>>2]=b;c[a+110620>>2]=b;c[a+176156>>2]=b;b=d+8192|0;c[a+45088>>2]=b;c[a+110624>>2]=b;c[a+176160>>2]=b;b=d+9216|0;c[a+45092>>2]=b;c[a+110628>>2]=b;c[a+176164>>2]=b;b=d+10240|0;c[a+45096>>2]=b;c[a+110632>>2]=b;c[a+176168>>2]=b;b=d+11264|0;c[a+45100>>2]=b;c[a+110636>>2]=b;c[a+176172>>2]=b;b=d+12288|0;c[a+45104>>2]=b;c[a+110640>>2]=b;c[a+176176>>2]=b;b=d+13312|0;c[a+45108>>2]=b;c[a+110644>>2]=b;c[a+176180>>2]=b;b=d+14336|0;c[a+45112>>2]=b;c[a+110648>>2]=b;c[a+176184>>2]=b;b=d+15360|0;c[a+45116>>2]=b;c[a+110652>>2]=b;c[a+176188>>2]=b;b=c[3532278]|0;d=a+49152|0;e=12582912;while(1){c[d>>2]=b+(e-12582912);f=e+1024|0;if(f>>>0>12648447){break}else{d=d+4|0;e=f}}c[a+196648>>2]=1584;c[a+196728>>2]=570;c[a+196608>>2]=1632;c[a+196688>>2]=1786;a=c[3532592]|0;if((a|0)==0){g=c[2113054]|0;c[2113060]=g;c[2394]=-1;return}gGC(a|0,9104152,280)|0;g=c[2113054]|0;c[2113060]=g;c[2394]=-1;return}function e$G(b){b=b|0;var c=0;if((b|0)==12582928){c=a[14128481]|0}else if((b|0)==12582929){c=a[14128480]|0}else{c=0}return c|0}function e$H(a,b){a=a|0;b=b|0;return}function e$I(c){c=c|0;var e=0,f=0;switch(c|0){case 12582926:{e=b[4877712]|0;return e|0};case 12582920:{e=d[14128320]|0;return e|0};case 12582914:{c=a[9540896]|0;switch(c&255|0){case 4:{f=a[9540898]|0;break};case 3:{a[9540898]=a[9540898]&-9;a[9540896]=c+1&255;f=a[9540895]|0;break};case 0:{a[9540896]=c+1&255;f=a[9540892]|0;break};case 1:{a[9540898]=a[9540898]&-5;a[9540896]=c+1&255;f=a[9540893]|0;break};case 2:{a[9540896]=c+1&255;f=a[9540894]|0;break};default:{f=0}}e=f&255;return e|0};case 12582924:{e=d[14128322]|0;return e|0};case 12582922:{e=d[14128321]|0;return e|0};default:{e=0;return e|0}}return 0}function e$J(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;if((d|0)==12583008){b[4877712]=e;return}else if((d|0)==655360){b[7064256]=e;if((e&1)!=0){return}f=c[2394]|0;g=c[14130368+(f<<2)>>2]|0;if((g|0)!=0){gGC(g|0,9104152,280)|0}c[8452240+(f<<2)>>2]=c[2113054];c[2394]=1;c[2112932]=c[3532597];f=c[3532593]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113061];RI();f=c[2394]|0;g=c[14130368+(f<<2)>>2]|0;if((g|0)!=0){gGC(g|0,9104152,280)|0}c[8452240+(f<<2)>>2]=c[2113054];c[2394]=0;c[2112932]=c[3532596];f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];return}else if((d|0)==13959168){b[7054096]=e;return}else if((d|0)==12582912){a[9540896]=e&15;return}else if((d|0)==12582914){f=e&15;g=a[9540896]|0;switch(g&255|0){case 1:{a[9540896]=g+1&255;a[9540889]=f;a[9540898]=a[9540898]|1;a[9540900]=1;return};case 0:{a[9540896]=g+1&255;a[9540888]=f;return};case 2:{a[9540896]=g+1&255;a[9540890]=f;return};case 4:{if(f<<24>>24==0){return}h=c[2439330]|0;i=(h|0)==0;if(!i){j=h;gGC(9706056,j|0,76)|0}j=c[2438118]|0;c[2433530]=j;k=c[3528484]|0;c[2076596]=k;l=c[2417276]|0;c[3541536]=l;c[1836236]=0;gGz(9706056,0,76);if(!i){i=h;gGC(i|0,9706056,76)|0}c[2438118]=j;c[3528484]=k;c[2417276]=l;c[1836236]=-1;return};case 3:{a[9540896]=g+1&255;a[9540891]=f;a[9540898]=a[9540898]|2;a[9540900]=1;return};default:{return}}}else if((d|0)==13762562|(d|0)==13762560){f=(d-13762560|0)>>>1;b[14108184+(f+2<<1)>>1]=e;g=(c[2438628]|0)==0?e:-e&65535;if((f|0)==0){c[2388332]=-(g&65535);return}else if((f|0)==1){c[2385818]=-(g&65535);return}else{return}}else if((d|0)==13893634|(d|0)==13893632){g=(d-13893632|0)>>>1;b[14108184+(g<<1)>>1]=e;if((g|0)==0){c[2388342]=-(e&65535);return}else if((g|0)==1){c[2385824]=-(e&65535);return}else{return}}else{return}}function e$K(a){a=a|0;return 0}function e$L(a,b){a=a|0;b=b|0;return}function e$M(a){a=a|0;return 0}function e$N(a,b){a=a|0;b=b|0;return}function e$O(b){b=b|0;var e=0,f=0;e=b-1044480|0;if(e>>>0<2048){f=a[(c[2406600]|0)+(((d[14109952]|0)<<10)+(e>>>1))|0]|0;return f|0}if((b|0)!=4063234){f=0;return f|0}b=a[9540896]|0;switch(b&255|0){case 4:{f=a[9540898]|0;return f|0};case 2:{a[9540896]=b+1&255;f=a[9540894]|0;return f|0};case 3:{a[9540898]=a[9540898]&-9;a[9540896]=b+1&255;f=a[9540895]|0;return f|0};case 0:{a[9540896]=b+1&255;f=a[9540892]|0;return f|0};case 1:{a[9540898]=a[9540898]&-5;a[9540896]=b+1&255;f=a[9540893]|0;return f|0};default:{f=0;return f|0}}return 0}function e$P(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=b-1044480|0;if(e>>>0<2048){e2E(c[3532204]|0,e>>>1,d&255);return}if((b|0)==4063232){a[9540896]=d&15;return}else if((b|0)==4063234){b=d&15;d=a[9540896]|0;switch(d&255|0){case 2:{a[9540896]=d+1&255;a[9540890]=b;return};case 1:{a[9540896]=d+1&255;a[9540889]=b;a[9540898]=a[9540898]|1;a[9540900]=1;return};case 4:{if(b<<24>>24==0){return}e=c[2439330]|0;f=(e|0)==0;if(!f){g=e;gGC(9706056,g|0,76)|0}g=c[2438118]|0;c[2433530]=g;h=c[3528484]|0;c[2076596]=h;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);if(!f){f=e;gGC(f|0,9706056,76)|0}c[2438118]=g;c[3528484]=h;c[2417276]=i;c[1836236]=-1;return};case 0:{a[9540896]=d+1&255;a[9540888]=b;return};case 3:{a[9540896]=d+1&255;a[9540891]=b;a[9540898]=a[9540898]|2;a[9540900]=1;return};default:{return}}}else{return}}function e$Q(a){a=a|0;var b=0,e=0;b=a-983040|0;if(b>>>0<2048){e=d[(c[2406600]|0)+(((d[14109952]|0)<<10)+(b>>>1))|0]|0;return e|0}b=a-1044480|0;if(b>>>0<2048){e=d[(c[2406600]|0)+(((d[14109952]|0)<<10)+(b>>>1))|0]|0;return e|0}if((a|0)==3670018){e=d[14128481]|0;return e|0}else if((a|0)==1046530){e=1;return e|0}else if((a|0)==3670016){e=d[14128480]|0;return e|0}else if((a|0)==3801088){e=(c[2433350]|0)+21+(((~~(+((c[3542196]>>8)+8|0)/+(c[2440576]|0)*255.0)&255)*320|0)>>>8)&65535;return e|0}else if((a|0)==3801090){e=(c[2433348]|0)+65500+(~~(+((c[3542192]>>8)+8|0)/+(c[2440574]|0)*255.0)&255)&65535;return e|0}else{e=0;return e|0}return 0}function e$R(d,e){d=d|0;e=e|0;var f=0,g=0;f=d-1044480|0;if(f>>>0<2048){e2E(c[3532204]|0,f>>>1,e);return}if((d|0)==1046530){f=c[2406600]|0;a[f+61|0]=1;a[f+122|0]=1;g=a[f+21|0]&3;if((g|0)==2){a[f+44|0]=60;a[f+119|0]=4;a[f+37|0]=19;a[f+38|0]=15;return}else if((g|0)==0){a[f+44|0]=32;a[f+119|0]=6;a[f+37|0]=7;a[f+38|0]=3;return}else if((g|0)==1){a[f+44|0]=49;a[f+119|0]=5;a[f+37|0]=15;a[f+38|0]=11;return}else if((g|0)==3){a[f+44|0]=49;a[f+119|0]=5;a[f+37|0]=15;a[f+38|0]=11;return}else{return}}else if((d|0)==1047552){a[14109952]=e&7;return}else if((d|0)==12910592){b[7054096]=e;return}else if((d|0)==12845056|(d|0)==12845058){f=(d-12845056|0)>>>1;b[14108184+(f<<1)>>1]=e;if((f|0)==1){c[2385824]=-(e&65535);return}else if((f|0)==0){c[2388342]=-(e&65535);return}else{return}}else if((d|0)==3670016){c[3540974]=(e&65535)>>>5&7;return}else if((d|0)==12713984|(d|0)==12713986){f=(d-12713984|0)>>>1;b[14108184+(f+2<<1)>>1]=e;d=(c[2438628]|0)==0?e:-e&65535;if((f|0)==0){c[2388332]=-(d&65535);return}else if((f|0)==1){c[2385818]=-(d&65535);return}else{return}}else{return}}function e$S(b){b=b|0;var d=0,e=0,f=0;d=b-1044480|0;L49687:do{if(d>>>0<4096){e=a[(c[3531934]|0)+(d>>>1)|0]|0}else{if((b|0)!=4063234){e=0;break}f=a[9540896]|0;switch(f&255|0){case 3:{a[9540898]=a[9540898]&-9;a[9540896]=f+1&255;e=a[9540895]|0;break L49687;break};case 4:{e=a[9540898]|0;break L49687;break};case 1:{a[9540898]=a[9540898]&-5;a[9540896]=f+1&255;e=a[9540893]|0;break L49687;break};case 0:{a[9540896]=f+1&255;e=a[9540892]|0;break L49687;break};case 2:{a[9540896]=f+1&255;e=a[9540894]|0;break L49687;break};default:{e=0;break L49687}}}}while(0);return e|0}function e$T(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=b-1044480|0;if(e>>>0<4096){a[(c[3531934]|0)+(e>>>1)|0]=d;return}if((b|0)==4063232){a[9540896]=d&15;return}else if((b|0)==4063234){b=d&15;d=a[9540896]|0;switch(d&255|0){case 2:{a[9540896]=d+1&255;a[9540890]=b;return};case 4:{if(b<<24>>24==0){return}e=c[2439330]|0;f=(e|0)==0;if(!f){g=e;gGC(9706056,g|0,76)|0}g=c[2438118]|0;c[2433530]=g;h=c[3528484]|0;c[2076596]=h;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);if(!f){f=e;gGC(f|0,9706056,76)|0}c[2438118]=g;c[3528484]=h;c[2417276]=i;c[1836236]=-1;return};case 1:{a[9540896]=d+1&255;a[9540889]=b;a[9540898]=a[9540898]|1;a[9540900]=1;return};case 0:{a[9540896]=d+1&255;a[9540888]=b;return};case 3:{a[9540896]=d+1&255;a[9540891]=b;a[9540898]=a[9540898]|2;a[9540900]=1;return};default:{return}}}else{return}}function e$U(a){a=a|0;var b=0,e=0;b=a-1044480|0;if(b>>>0<4096){e=d[(c[3531934]|0)+(b>>>1)|0]|0;return e|0}if((a|0)==3801090){e=(c[2433348]|0)+65500+(~~(+((c[3542192]>>8)+8|0)/+(c[2440574]|0)*255.0)&255)&65535;return e|0}else if((a|0)==983048){e=d[14128320]|0;return e|0}else if((a|0)==983050){e=d[14128321]|0;return e|0}else if((a|0)==3670016){e=d[14128480]|0;return e|0}else if((a|0)==3670018){e=d[14128481]|0;return e|0}else if((a|0)==3801088){e=(c[2433350]|0)+21+(((~~(+((c[3542196]>>8)+8|0)/+(c[2440576]|0)*255.0)&255)*320|0)>>>8)&65535;return e|0}else{e=0;return e|0}return 0}function e$V(d,e){d=d|0;e=e|0;var f=0,g=0;f=d-1044480|0;if(f>>>0<4096){a[(c[3531934]|0)+(f>>>1)|0]=e&255;return}if((d|0)==12845056|(d|0)==12845058){f=(d-12845056|0)>>>1;b[14108184+(f<<1)>>1]=e;if((f|0)==1){c[2385824]=-(e&65535);return}else if((f|0)==0){c[2388342]=-(e&65535);return}else{return}}else if((d|0)==12910592){b[7054096]=e;return}else if((d|0)==12713984|(d|0)==12713986){f=(d-12713984|0)>>>1;b[14108184+(f+2<<1)>>1]=e;g=(c[2438628]|0)==0?e:-e&65535;if((f|0)==1){c[2385818]=-(g&65535);return}else if((f|0)==0){c[2388332]=-(g&65535);return}else{return}}else if((d|0)==3670016){c[3540974]=(e&65535)>>>5&7;return}else{return}}function e$W(b){b=b|0;var e=0;e=b-8388608|0;if(e>>>0<2048){return a[(c[9699584+((d[14109952]|0)<<2)>>2]|0)+(e>>>1)|0]|0}else{return(b|0)==8390659|0}return 0}function e$X(b,e){b=b|0;e=e|0;var f=0,g=0,h=0;f=b-8388608|0;if(f>>>0<2048){a[(c[9699584+((d[14109952]|0)<<2)>>2]|0)+(f>>>1)|0]=e;return}if((b|0)==8391681){a[14109952]=e&7;return}else if((b|0)==3801089){c[3540974]=(e&255)>>>5;return}else if((b|0)==4063233){a[9540896]=e&15;return}else if((b|0)==4063235){b=e&15;e=a[9540896]|0;switch(e&255|0){case 2:{a[9540896]=e+1&255;a[9540890]=b;return};case 3:{a[9540896]=e+1&255;a[9540891]=b;a[9540898]=a[9540898]|2;a[9540900]=1;return};case 1:{a[9540896]=e+1&255;a[9540889]=b;a[9540898]=a[9540898]|1;a[9540900]=1;return};case 0:{a[9540896]=e+1&255;a[9540888]=b;return};case 4:{if(b<<24>>24==0){return}b=c[2439330]|0;e=(b|0)==0;if(!e){f=b;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;h=c[2417276]|0;c[3541536]=h;c[1836236]=0;gGz(9706056,0,76);if(!e){e=b;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=h;c[1836236]=-1;return};default:{return}}}else{return}}function e$Y(a){a=a|0;var b=0,e=0;b=a-8388608|0;if(b>>>0<2048){e=d[(c[9699584+((d[14109952]|0)<<2)>>2]|0)+(b>>>1)|0]|0;return e|0}if((a|0)==3735552){e=d[14128480]|0;return e|0}else if((a|0)==3866624){e=d[14128481]|0;return e|0}else{e=0;return e|0}return 0}function e$Z(a,d){a=a|0;d=d|0;var e=0,f=0;if((a|0)==12910592){b[7054096]=d;return}else if((a|0)==12713984|(a|0)==12713986){e=(a-12713984|0)>>>1;b[14108184+(e+2<<1)>>1]=d;f=(c[2438628]|0)==0?d:-d&65535;if((e|0)==0){c[2388332]=-(f&65535);return}else if((e|0)==1){c[2385818]=-(f&65535);return}else{return}}else if((a|0)==12845056|(a|0)==12845058){f=(a-12845056|0)>>>1;b[14108184+(f<<1)>>1]=d;if((f|0)==1){c[2385824]=-(d&65535);return}else if((f|0)==0){c[2388342]=-(d&65535);return}else{return}}else{return}}function e$_(b){b=b|0;var c=0;if((b|0)==4198403){c=a[14128321]|0}else if((b|0)==4198401){c=a[14128320]|0}else{c=0}return c|0}function e$$(d,e){d=d|0;e=e|0;var f=0,g=0,h=0;if((d-8388608|0)>>>0<65536){return}if((d|0)==3801089){c[3540974]=e&255;return}else if((d|0)==4194311){a[14128024]=e;e=c[2439330]|0;d=(e|0)==0;if(!d){f=e;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;h=c[2417276]|0;c[3541536]=h;c[1836236]=0;a[9706117]=1;if(!d){d=e;gGC(d|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=h;c[1836236]=-1;return}else{return}}function e$0(a){a=a|0;var b=0;if((a|0)==4194304){b=d[14128480]|0}else if((a|0)==4194306){b=d[14128480]|0}else{b=0}return b|0}function e$1(a,d){a=a|0;d=d|0;var e=0;if(!((a|0)==4390914|(a|0)==4390912)){return}e=(a-4390912|0)>>>1;b[14108184+(e+2<<1)>>1]=d;a=(c[2438628]|0)==0?d:-d&65535;if((e|0)==1){c[2385818]=-(a&65535);return}else if((e|0)==0){c[2388332]=-(a&65535);return}else{return}}function e$2(b){b=b|0;var c=0,d=0;L49879:do{if((b|0)==3735559){c=a[14128323]|0}else if((b|0)==3735563){c=a[14128481]|0}else if((b|0)==4063235){d=a[9540896]|0;switch(d&255|0){case 4:{c=a[9540898]|0;break L49879;break};case 1:{a[9540898]=a[9540898]&-5;a[9540896]=d+1&255;c=a[9540893]|0;break L49879;break};case 0:{a[9540896]=d+1&255;c=a[9540892]|0;break L49879;break};case 2:{a[9540896]=d+1&255;c=a[9540894]|0;break L49879;break};case 3:{a[9540898]=a[9540898]&-9;a[9540896]=d+1&255;c=a[9540895]|0;break L49879;break};default:{c=0;break L49879}}}else if((b|0)==3735555){c=a[14128321]|0}else if((b|0)==3735561){c=a[14128480]|0}else if((b|0)==3735553){c=a[14128320]|0}else if((b|0)==3735557){c=a[14128322]|0}else{c=0}}while(0);return c|0}function e$3(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;if((b|0)==4063235){e=d&15;f=a[9540896]|0;switch(f&255|0){case 1:{a[9540896]=f+1&255;a[9540889]=e;a[9540898]=a[9540898]|1;a[9540900]=1;return};case 4:{if(e<<24>>24==0){return}g=c[2439330]|0;h=(g|0)==0;if(!h){i=g;gGC(9706056,i|0,76)|0}i=c[2438118]|0;c[2433530]=i;j=c[3528484]|0;c[2076596]=j;k=c[2417276]|0;c[3541536]=k;c[1836236]=0;gGz(9706056,0,76);if(!h){h=g;gGC(h|0,9706056,76)|0}c[2438118]=i;c[3528484]=j;c[2417276]=k;c[1836236]=-1;return};case 0:{a[9540896]=f+1&255;a[9540888]=e;return};case 3:{a[9540896]=f+1&255;a[9540891]=e;a[9540898]=a[9540898]|2;a[9540900]=1;return};case 2:{a[9540896]=f+1&255;a[9540890]=e;return};default:{return}}}else if((b|0)==4063233){a[9540896]=d&15;return}else{return}}function e$4(a,d){a=a|0;d=d|0;var e=0,f=0;if((a|0)==12910592){b[7054096]=d;return}else if((a|0)==12713984|(a|0)==12713986){e=(a-12713984|0)>>>1;b[14108184+(e+2<<1)>>1]=d;f=(c[2438628]|0)==0?d:-d&65535;if((e|0)==0){c[2388332]=-(f&65535);return}else if((e|0)==1){c[2385818]=-(f&65535);return}else{return}}else if((a|0)==12845058|(a|0)==12845056){f=(a-12845056|0)>>>1;b[14108184+(f<<1)>>1]=d;if((f|0)==1){c[2385824]=-(d&65535);return}else if((f|0)==0){c[2388342]=-(d&65535);return}else{return}}else if((a|0)==3670016){c[3540974]=(d&65535)>>>5&7;return}else{return}}function e$5(b){b=b|0;var c=0,d=0;L49943:do{if((b|0)==8257539){c=a[9540896]|0;switch(c&255|0){case 3:{a[9540898]=a[9540898]&-9;a[9540896]=c+1&255;d=a[9540895]|0;break L49943;break};case 2:{a[9540896]=c+1&255;d=a[9540894]|0;break L49943;break};case 0:{a[9540896]=c+1&255;d=a[9540892]|0;break L49943;break};case 4:{d=a[9540898]|0;break L49943;break};case 1:{a[9540898]=a[9540898]&-5;a[9540896]=c+1&255;d=a[9540893]|0;break L49943;break};default:{d=0;break L49943}}}else{d=0}}while(0);return d|0}function e$6(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;if((b|0)==8257539){e=d&15;f=a[9540896]|0;switch(f&255|0){case 0:{a[9540896]=f+1&255;a[9540888]=e;return};case 4:{if(e<<24>>24==0){return}g=c[2439330]|0;h=(g|0)==0;if(!h){i=g;gGC(9706056,i|0,76)|0}i=c[2438118]|0;c[2433530]=i;j=c[3528484]|0;c[2076596]=j;k=c[2417276]|0;c[3541536]=k;c[1836236]=0;gGz(9706056,0,76);if(!h){h=g;gGC(h|0,9706056,76)|0}c[2438118]=i;c[3528484]=j;c[2417276]=k;c[1836236]=-1;return};case 2:{a[9540896]=f+1&255;a[9540890]=e;return};case 1:{a[9540896]=f+1&255;a[9540889]=e;a[9540898]=a[9540898]|1;a[9540900]=1;return};case 3:{a[9540896]=f+1&255;a[9540891]=e;a[9540898]=a[9540898]|2;a[9540900]=1;return};default:{return}}}else if((b|0)==8257537){a[9540896]=d&15;return}else{return}}function e$7(a){a=a|0;return 0}function e$8(a,d){a=a|0;d=d|0;var e=0,f=0;if((a-14745600|0)>>>0<65536){return}if((a|0)==10616832|(a|0)==10616834){e=(a-10616832|0)>>>1;b[14108184+(e+2<<1)>>1]=d;f=(c[2438628]|0)==0?d:-d&65535;if((e|0)==0){c[2388332]=-(f&65535);return}else if((e|0)==1){c[2385818]=-(f&65535);return}else{return}}else if((a|0)==11665408|(a|0)==11665410){f=(a-11665408|0)>>>1;b[14108200+(f+2<<1)>>1]=d;e=(c[2438629]|0)==0?d:-d&65535;if((f|0)==0){c[2388333]=-(e&65535);return}else if((f|0)==1){c[2385819]=-(e&65535);return}else{return}}else if((a|0)==11796482|(a|0)==11796480){e=(a-11796480|0)>>>1;b[14108200+(e<<1)>>1]=d;if((e|0)==1){c[2385825]=-(d&65535);return}else if((e|0)==0){c[2388343]=-(d&65535);return}else{return}}else if((a|0)==10747904|(a|0)==10747906){e=(a-10747904|0)>>>1;b[14108184+(e<<1)>>1]=d;if((e|0)==1){c[2385824]=-(d&65535);return}else if((e|0)==0){c[2388342]=-(d&65535);return}else{return}}else if((a|0)==10813440){b[7054096]=d;return}else if((a|0)==11862016){b[7054104]=d;return}else if((a|0)==6291458){b[7064256]=d;if((d&1)!=0){return}d=c[2394]|0;a=c[14130368+(d<<2)>>2]|0;if((a|0)!=0){gGC(a|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=1;c[2112932]=c[3532597];d=c[3532593]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113061];RI();d=c[2394]|0;a=c[14130368+(d<<2)>>2]|0;if((a|0)!=0){gGC(a|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];return}else{return}}function e$9(a){a=a|0;var b=0,c=0,d=0;b=a-9437184|0;do{if(b>>>0<1024){a=b>>>1;if((a|0)==257){c=85;break}else if((a|0)!=0){d=38148;break}c=(cT()|0)&255}else{d=38148}}while(0);if((d|0)==38148){c=0}return c|0}function e0a(a,b){a=a|0;b=b|0;return}function e0b(b){b=b|0;var e=0,f=0;if((b|0)==8912898){e=d[9757560]|0;return e|0}else if((b|0)==8912896){b=c[3532186]|0;switch(d[9757560]|0|0){case 12:{f=b>>>4&255;break};case 7:{f=a[14129042]|0;break};case 2:{f=a[14129040]|0;break};case 3:{f=a[14129041]|0;break};case 13:{f=b>>>12&255;break};case 1:{f=a[14129049]|0;break};case 0:{f=a[14129048]|0;break};case 4:{f=a[9757556]|0;break};default:{f=0}}e=f&255;return e|0}else{e=0;return e|0}return 0}function e0c(b,d){b=b|0;d=d|0;var e=0,f=0;if((b|0)==8912896){e=a[9757560]|0;f=d&255;a[9757552+(e&255)|0]=f;if((e<<24>>24|0)==0){c[3531956]=0;return}else if((e<<24>>24|0)==4){e=~f;a[14128520]=e&1;a[14128521]=e&2;return}else{return}}else if((b|0)==8912898){a[9757560]=d&255;return}else{return}}function e0d(b){b=b|0;var d=0,e=0,f=0,g=0,h=0;d=b-15728640|0;L50073:do{if(d>>>0<2048){e=d>>>1;f=a[8310520]|0;L50075:do{if(f<<24>>24==0){switch(e|0){case 1023:{g=a[8310504]<<1;break L50073;break};case 5:{g=a[14128322]|0;break L50073;break};case 6:{g=a[14128323]|0;break L50073;break};case 4:{g=a[14128321]|0;break L50073;break};case 1022:{g=a[8310512]|0;break L50073;break};case 3:{g=a[14128320]|0;break L50073;break};case 8:{g=a[8310536]|0;break L50073;break};default:{h=0;break L50075}}}else{if(f<<24>>24==2&(e|0)==5){g=124;break L50073}h=(f&255)<<10}}while(0);g=a[(c[2077632]|0)+(h+e)|0]|0}else{if((b|0)==15730691){g=1;break}else if((b|0)==14680067){f=a[9540896]|0;switch(f&255|0){case 0:{a[9540896]=f+1&255;g=a[9540892]|0;break L50073;break};case 2:{a[9540896]=f+1&255;g=a[9540894]|0;break L50073;break};case 1:{a[9540898]=a[9540898]&-5;a[9540896]=f+1&255;g=a[9540893]|0;break L50073;break};case 3:{a[9540898]=a[9540898]&-9;a[9540896]=f+1&255;g=a[9540895]|0;break L50073;break};case 4:{g=a[9540898]|0;break L50073;break};default:{g=0;break L50073}}}else if((b|0)==13631489){g=96;break}else{g=0;break}}}while(0);return g|0}function e0e(f,g){f=f|0;g=g|0;var h=0,i=0,j=0;h=f-4194304|0;if(h>>>0<524288){i=e[4876796]|0;j=(h&1|0)==0?i&255:i>>>8;i=(c[3531958]|0)+(h^1)|0;a[i]=((j^255)&d[i]|j&(g&255))&255;return}j=f-15728640|0;if(j>>>0>=2048){if((f|0)==15731713){a[8310520]=g&7;return}else if((f|0)==7340033){c[3540974]=(g&255)>>>2&15;return}else if((f|0)==13631489){b[4876800]=g&255;return}else{return}}f=j>>>1;a[(c[2077632]|0)+((d[8310520]<<10)+f)|0]=g;if((a[8310520]|0)!=0){return}if((f|0)==1023){a[8310504]=g;return}else if((f|0)==8){a[8310536]=g;return}else if((f|0)==1022){a[8310512]=g;if(g<<24>>24!=0&(g&255)<18){e2F();return}if((g+127&255)<17){e2F();return}else{a[8310512]=0;return}}else{return}}function e0f(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=b-15728640|0;if(d>>>0>=2048){if((b|0)==14680066){e=a[9540896]|0;switch(e&255|0){case 1:{a[9540898]=a[9540898]&-5;a[9540896]=e+1&255;f=a[9540893]|0;break};case 2:{a[9540896]=e+1&255;f=a[9540894]|0;break};case 0:{a[9540896]=e+1&255;f=a[9540892]|0;break};case 3:{a[9540898]=a[9540898]&-9;a[9540896]=e+1&255;f=a[9540895]|0;break};case 4:{f=a[9540898]|0;break};default:{f=0}}g=f&255;return g|0}else if((b|0)==13631488){g=96;return g|0}else{g=0;return g|0}}b=d>>>1;d=a[8310520]|0;L50152:do{if(d<<24>>24==0){switch(b|0){case 1022:{h=a[8310512]|0;break L50152;break};case 1023:{h=a[8310504]<<1;break L50152;break};case 6:{h=a[14128323]|0;break L50152;break};case 8:{h=a[8310536]|0;break L50152;break};case 3:{h=a[14128320]|0;break L50152;break};case 5:{h=a[14128322]|0;break L50152;break};case 4:{h=a[14128321]|0;break L50152;break};default:{i=0;j=38242;break L50152}}}else{if(d<<24>>24==2&(b|0)==5){h=124;break}i=(d&255)<<10;j=38242}}while(0);if((j|0)==38242){h=a[(c[2077632]|0)+(i+b)|0]|0}g=h&255;return g|0}function e0g(e,f){e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=e-4194304|0;if(g>>>0<524288){h=(c[3531958]|0)+(g>>>1<<1)|0;g=b[4876796]|0;b[h>>1]=b[h>>1]&~g|g&f;return}g=e-15728640|0;if(g>>>0<2048){h=g>>>1;g=f&255;a[(c[2077632]|0)+((d[8310520]<<10)+h)|0]=g;if((a[8310520]|0)!=0){return}if((h|0)==1023){a[8310504]=g;return}else if((h|0)==1022){a[8310512]=g;if(g<<24>>24!=0&(g&255)<18){e2F();return}if((g+127&255)<17){e2F();return}else{a[8310512]=0;return}}else if((h|0)==8){a[8310536]=g;return}else{return}}if((e|0)==6291456){b[4876796]=f;return}else if((e|0)==14680066){g=f&15;h=a[9540896]|0;switch(h&255|0){case 0:{a[9540896]=h+1&255;a[9540888]=g;return};case 4:{if(g<<24>>24==0){return}i=c[2439330]|0;j=(i|0)==0;if(!j){k=i;gGC(9706056,k|0,76)|0}k=c[2438118]|0;c[2433530]=k;l=c[3528484]|0;c[2076596]=l;m=c[2417276]|0;c[3541536]=m;c[1836236]=0;gGz(9706056,0,76);if(!j){j=i;gGC(j|0,9706056,76)|0}c[2438118]=k;c[3528484]=l;c[2417276]=m;c[1836236]=-1;return};case 3:{a[9540896]=h+1&255;a[9540891]=g;a[9540898]=a[9540898]|2;a[9540900]=1;return};case 2:{a[9540896]=h+1&255;a[9540890]=g;return};case 1:{a[9540896]=h+1&255;a[9540889]=g;a[9540898]=a[9540898]|1;a[9540900]=1;return};default:{return}}}else if((e|0)==15731712){a[8310520]=f&7;return}else if((e|0)==13631488){b[4876800]=f;return}else if((e|0)==14680064){a[9540896]=f&15;return}else{return}}function e0h(b){b=b|0;var e=0,f=0,g=0.0,i=0.0,j=0,k=0;e=b&65535;if((e|0)==40960){b=c[3541518]|0;f=b+19320|0;g=+h[f>>3];do{if(g!=0.0){i=+h[6675];if(g-(i+ +gC[c[2429842]&255]())<=0.0){h[f>>3]=0.0;break}j=a[b+19331|0]|-128;return j|0}}while(0);j=a[b+19331|0]|0;return j|0}else if((e|0)==36864){b=c[3541518]|0;f=b+296|0;g=+h[f>>3];do{if(g!=0.0){i=+h[6675];if(g-(i+ +gC[c[2429842]&255]())<=0.0){h[f>>3]=0.0;break}j=a[b+307|0]|-128;return j|0}}while(0);j=a[b+307|0]|0;return j|0}else if((e|0)==40961){if((d[(c[3541518]|0)+19328|0]|0)>=16){j=0;return j|0}b=(c[2383582]|0)+1|0;f=c[14168912+(b*252|0)>>2]|0;if((f|0)>15){j=0;return j|0}do{if((f|0)==15){k=c[14168900+(b*252|0)>>2]|0;if((k|0)==0){break}a[14168931+(b*252|0)|0]=gj[k&4095](0)|0}else if((f|0)==14){k=c[14168896+(b*252|0)>>2]|0;if((k|0)==0){break}a[14168930+(b*252|0)|0]=gj[k&4095](0)|0}}while(0);j=a[14168916+(b*252|0)+f|0]|0;return j|0}else if((e|0)==45057){j=fdZ()|0;return j|0}else if((e|0)==36865){if((d[(c[3541518]|0)+304|0]|0)>=16){j=0;return j|0}e=c[2383582]|0;f=c[14168912+(e*252|0)>>2]|0;if((f|0)>15){j=0;return j|0}do{if((f|0)==15){b=c[14168900+(e*252|0)>>2]|0;if((b|0)==0){break}a[14168931+(e*252|0)|0]=gj[b&4095](0)|0}else if((f|0)==14){b=c[14168896+(e*252|0)>>2]|0;if((b|0)==0){break}a[14168930+(e*252|0)|0]=gj[b&4095](0)|0}}while(0);j=a[14168916+(e*252|0)+f|0]|0;return j|0}else{j=0;return j|0}return 0}function e0i(b,e){b=b|0;e=e|0;var f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0.0;f=b&65535;if((f|0)==36865){lS(0,1,e);return}else if((f|0)==36864){b=c[3541518]|0;g=b+256|0;a[b+304|0]=e;i=e&255;if((e&255)<16){c[14168912+((c[2383582]|0)*252|0)>>2]=i&15}if((e-45&255)>=3){return}if((i|0)==45){j=b+312|0;k=a[j]|2;a[j]=k;l=k}else if((i|0)==0){a[b+312|0]=2;l=2}else if((i|0)==46){k=b+312|0;j=a[k]|1;a[k]=j;l=j}else if((i|0)==47){a[b+312|0]=0;l=0}else{l=a[b+312|0]|0}b=l&3;l=c[7461744+(b<<2)>>2]|0;lI(g,l,l,c[7461728+(b<<2)>>2]|0);return}else if((f|0)==56320){b=e&3;a[14127752]=b;l=c[3531932]|0;g=((b&255)<<15)+65536|0;b=c[9757320+(c[1836236]<<2)>>2]|0;i=0;j=0;while(1){c[b+76+(j<<2)>>2]=l+(g+(j<<8));k=i+1&65535;if((k&65535)>127){m=0;n=0;break}else{i=k;j=k&65535}}while(1){j=l+(g+(n<<8))|0;c[b+76+(n+512<<2)>>2]=j;c[b+76+(n+768<<2)>>2]=j;j=m+1&65535;if((j&65535)>127){break}else{m=j;n=j&65535}}return}else if((f|0)==40961){lS(1,1,e);return}else if((f|0)==45056){a[9540897]=e&15;return}else if((f|0)==40960){n=c[3541518]|0;m=n+19280|0;a[n+19328|0]=e;b=e&255;if((e&255)<16){c[14168912+(((c[2383582]|0)+1|0)*252|0)>>2]=b&15}if((e-45&255)>=3){return}if((b|0)==47){a[n+19336|0]=0;o=0}else if((b|0)==0){a[n+19336|0]=2;o=2}else if((b|0)==45){g=n+19336|0;l=a[g]|2;a[g]=l;o=l}else if((b|0)==46){b=n+19336|0;l=a[b]|1;a[b]=l;o=l}else{o=a[n+19336|0]|0}n=o&3;o=c[7461744+(n<<2)>>2]|0;lI(m,o,o,c[7461728+(n<<2)>>2]|0);return}else if((f|0)==54272){a[9720936]=e;return}else if((f|0)==50176){a[9553289]=e;n=e&255;o=d[9553287]|0;m=(ag(o,n)|0)>>>8;l=(ag(o,n^255)|0)>>>8;p=+h[85282];h[146575]=p*+(m|0)/100.0;h[118360]=p*+(l|0)/100.0;return}else if((f|0)==51200){a[9553290]=e;l=e&255;m=d[9553280]|0;n=(ag(m,l)|0)>>>8;o=l^255;b=(ag(m,o)|0)>>>8;p=+h[85166];h[146578]=p*+(n|0)/100.0;h[118363]=p*+(b|0)/100.0;b=d[9553281]|0;n=(ag(b,l)|0)>>>8;m=(ag(o,b)|0)>>>8;h[146577]=p*+(n|0)/100.0;h[118362]=p*+(m|0)/100.0;m=d[9553282]|0;n=(ag(m,l)|0)>>>8;l=(ag(o,m)|0)>>>8;h[146576]=p*+(n|0)/100.0;h[118361]=p*+(l|0)/100.0;return}else if((f|0)==45057){fd_(e);return}else if((f|0)==49152){a[9553288]=e;l=e&255;n=d[9553286]|0;m=(ag(n,l)|0)>>>8;o=(ag(n,l^255)|0)>>>8;p=+h[85282];h[146579]=p*+(m|0)/100.0;h[118364]=p*+(o|0)/100.0;return}else if((f|0)==52224){a[9553291]=e;o=e&255;m=d[9553283]|0;l=(ag(m,o)|0)>>>8;n=o^255;b=(ag(m,n)|0)>>>8;p=+h[85166];h[146574]=p*+(l|0)/100.0;h[118359]=p*+(b|0)/100.0;b=d[9553284]|0;l=(ag(b,o)|0)>>>8;m=(ag(n,b)|0)>>>8;h[146573]=p*+(l|0)/100.0;h[118358]=p*+(m|0)/100.0;m=d[9553285]|0;l=(ag(m,o)|0)>>>8;o=(ag(n,m)|0)>>>8;h[146572]=p*+(l|0)/100.0;h[118357]=p*+(o|0)/100.0;return}else if((f|0)==53248){a[9553292]=e;p=+(c[9774520+((e&15)<<2)>>2]|0)*+h[85210]/100.0;c[2415126]=9662152;h[1207775]=p;return}else{return}}function e0j(b){b=b|0;return((b&255)==0?a[9720936]|0:0)|0}function e0k(a,b){a=a|0;b=b|0;var d=0,e=0;d=a&255;if((d|0)==1){c[2437782]=1;return}else if((d|0)==0){c[2437782]=0;return}else if((d|0)==2){d=b&255;c[2415126]=9662152;if((c[2415542]|0)==4){e=d&15}else{e=d<<1&14}c[2415538]=e;c[2415126]=9662152;c[2415540]=d>>>5&1^1;return}else{return}}function e0l(a){a=a|0;var b=0,d=0;b=a&65535;if((b|0)==36865){d=c[(c[3531464]|0)+4240>>2]&255}else if((b|0)==40961){d=fdZ()|0}else{d=0}return d|0}function e0m(b,e){b=b|0;e=e|0;var f=0;f=b&65535;if((f|0)==36865){b=c[2113304]|0;a[14168504+b|0]=e;mv(0,b,e&255);return}else if((f|0)==40960){a[9540897]=e&15;return}else if((f|0)==36864){c[2113304]=e&255;return}else if((f|0)==45056|(f|0)==45057|(f|0)==45058|(f|0)==45059|(f|0)==45060|(f|0)==45061|(f|0)==45062){b=f-45056|0;a[9757696+b|0]=e;if((b|0)!=4){return}b=((d[9757699]|0)<<8|(d[9757698]|0))<<4;c[2438632]=((d[9757697]|0)<<8|(d[9757696]|0))<<4;c[2438634]=b;c[2415126]=9662152;c[2415540]=0;return}else if((f|0)==49152|(f|0)==49153|(f|0)==49154|(f|0)==49155|(f|0)==49156|(f|0)==49157|(f|0)==49158){b=f-49152|0;a[9757688+b|0]=e;if((b|0)!=4){return}b=((d[9757691]|0)<<8|(d[9757690]|0))<<4;c[2438633]=((d[9757689]|0)<<8|(d[9757688]|0))<<4;c[2438635]=b;c[2415126]=9665376;c[2416346]=0;return}else if((f|0)==40961){fd_(e);return}else{return}}function e0n(a){a=a|0;var b=0,d=0;b=a&65535;if((b|0)==40961){d=fdZ()|0}else if((b|0)==36865){d=c[(c[3531464]|0)+4240>>2]&255}else{d=0}return d|0}function e0o(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((e|0)==36864){c[2113304]=d&255;return}else if((e|0)==40961){fd_(d);return}else if((e|0)==40960){a[9540897]=d&15;return}else if((e|0)==36865){e=c[2113304]|0;a[14168504+e|0]=d;mv(0,e,d&255);return}else{return}}function e0p(b){b=b|0;var d=0,e=0,f=0,g=0.0,i=0.0;d=b&65535;if((d|0)==47104){a[9706117]=0;e=a[14128024]|0;return e|0}else if((d|0)==46080){b=c[3541518]|0;f=b+19320|0;g=+h[f>>3];do{if(g!=0.0){i=+h[6675];if(g-(i+ +gC[c[2429842]&255]())<=0.0){h[f>>3]=0.0;break}e=a[b+19331|0]|-128;return e|0}}while(0);e=a[b+19331|0]|0;return e|0}else if((d|0)==45056){d=c[3541518]|0;b=d+296|0;g=+h[b>>3];do{if(g!=0.0){i=+h[6675];if(g-(i+ +gC[c[2429842]&255]())<=0.0){h[b>>3]=0.0;break}e=a[d+307|0]|-128;return e|0}}while(0);e=a[d+307|0]|0;return e|0}else{e=0;return e|0}return 0}function e0q(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=b&65535;if((e|0)==46081){lS(1,1,d);return}else if((e|0)==45057){lS(0,1,d);return}else if((e|0)==46080){b=c[3541518]|0;f=b+19280|0;a[b+19328|0]=d;g=d&255;if((d&255)<16){c[14168912+(((c[2383582]|0)+1|0)*252|0)>>2]=g&15}if((d-45&255)>=3){return}if((g|0)==47){a[b+19336|0]=0;h=0}else if((g|0)==46){i=b+19336|0;j=a[i]|1;a[i]=j;h=j}else if((g|0)==0){a[b+19336|0]=2;h=2}else if((g|0)==45){g=b+19336|0;j=a[g]|2;a[g]=j;h=j}else{h=a[b+19336|0]|0}b=h&3;h=c[7461744+(b<<2)>>2]|0;lI(f,h,h,c[7461728+(b<<2)>>2]|0);return}else if((e|0)==45056){e=c[3541518]|0;b=e+256|0;a[e+304|0]=d;h=d&255;if((d&255)<16){c[14168912+((c[2383582]|0)*252|0)>>2]=h&15}if((d-45&255)>=3){return}if((h|0)==0){a[e+312|0]=2;k=2}else if((h|0)==45){d=e+312|0;f=a[d]|2;a[d]=f;k=f}else if((h|0)==46){f=e+312|0;d=a[f]|1;a[f]=d;k=d}else if((h|0)==47){a[e+312|0]=0;k=0}else{k=a[e+312|0]|0}e=k&3;k=c[7461744+(e<<2)>>2]|0;lI(b,k,k,c[7461728+(e<<2)>>2]|0);return}else{return}}function e0r(a){a=a|0;var b=0,d=0;b=a&65535;if((b|0)==36865){d=c[(c[3531464]|0)+4240>>2]&255}else if((b|0)==40961){d=fdZ()|0}else{d=0}return d|0}function e0s(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((e|0)==53248){c[2415126]=9662152;c[2415540]=1;c[2438580]=c[2438580]&65280;return}else if((e|0)==36865){b=c[2113304]|0;a[14168504+b|0]=d;mv(0,b,d&255);return}else if((e|0)==40960){a[9540897]=d&15;return}else if((e|0)==36864){c[2113304]=d&255;return}else if((e|0)==49152){c[2415126]=9662152;c[2415540]=0;return}else if((e|0)==40961){fd_(d);return}else if((e|0)==45056){c[2438580]=c[2438580]&255|(d&255)<<8;return}else{return}}function e0t(a){a=a|0;var b=0,d=0;b=a&65535;if((b|0)==40961){d=fdZ()|0}else if((b|0)==36865){d=c[(c[3531464]|0)+4240>>2]&255}else{d=0}return d|0}function e0u(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((e|0)==36864){c[2113304]=d&255;return}else if((e|0)==47104){c[2415126]=9662152;c[2415540]=1;c[2438580]=c[2438580]&65280;return}else if((e|0)==36865){b=c[2113304]|0;a[14168504+b|0]=d;mv(0,b,d&255);return}else if((e|0)==40961){fd_(d);return}else if((e|0)==45056){c[2438580]=c[2438580]&255|(d&255)<<8;c[2415126]=9662152;c[2415540]=0;return}else if((e|0)==40960){a[9540897]=d&15;return}else{return}}function e0v(b){b=b|0;var e=0,f=0,g=0,i=0,j=0.0,k=0.0;e=b&65535;if((e|0)==36865){if((d[(c[3541518]|0)+304|0]|0)>=16){f=0;return f|0}b=c[2383582]|0;g=c[14168912+(b*252|0)>>2]|0;if((g|0)>15){f=0;return f|0}do{if((g|0)==15){i=c[14168900+(b*252|0)>>2]|0;if((i|0)==0){break}a[14168931+(b*252|0)|0]=gj[i&4095](0)|0}else if((g|0)==14){i=c[14168896+(b*252|0)>>2]|0;if((i|0)==0){break}a[14168930+(b*252|0)|0]=gj[i&4095](0)|0}}while(0);f=a[14168916+(b*252|0)+g|0]|0;return f|0}else if((e|0)==34817){f=fdZ()|0;return f|0}else if((e|0)==36864){e=c[3541518]|0;g=e+296|0;j=+h[g>>3];do{if(j!=0.0){k=+h[6675];if(j-(k+ +gC[c[2429842]&255]())<=0.0){h[g>>3]=0.0;break}f=a[e+307|0]|-128;return f|0}}while(0);f=a[e+307|0]|0;return f|0}else{f=0;return f|0}return 0}function e0w(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=b&65535;if((e|0)==34816){a[9540897]=d&15;return}else if((e|0)==34817){fd_(d);return}else if((e|0)==36865){lS(0,1,d);return}else if((e|0)==36864){e=c[3541518]|0;b=e+256|0;a[e+304|0]=d;f=d&255;if((d&255)<16){c[14168912+((c[2383582]|0)*252|0)>>2]=f&15}if((d-45&255)>=3){return}if((f|0)==47){a[e+312|0]=0;g=0}else if((f|0)==45){d=e+312|0;h=a[d]|2;a[d]=h;g=h}else if((f|0)==0){a[e+312|0]=2;g=2}else if((f|0)==46){f=e+312|0;h=a[f]|1;a[f]=h;g=h}else{g=a[e+312|0]|0}e=g&3;g=c[7461744+(e<<2)>>2]|0;lI(b,g,g,c[7461728+(e<<2)>>2]|0);return}else{return}}function e0x(b){b=b|0;var c=0,d=0;c=b&65535;if((c|0)==34816){d=a[14128320]|0}else if((c|0)==38912){d=a[14128320]|0}else{d=0}return d|0}function e0y(a,b){a=a|0;b=b|0;return}function e0z(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>34){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6378812+(b*112|0)>>2];c[a+104>>2]=c[6378816+(b*112|0)>>2];c[a+108>>2]=c[6378820+(b*112|0)>>2];d=0;return d|0}function e0A(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<35&(d|0)==0)){e=1;return e|0}c[a>>2]=6378712+(b*112|0);e=0;return e|0}function e0B(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4105008+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function e0C(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>38){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6382632+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e0D(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;c[3532162]=256;c[3532160]=4;c[3532142]=8;c[3532164]=8;c[3532148]=691176;c[3532140]=987032;c[3532138]=987e3;c[3532042]=12288;c[3532178]=128;c[3532176]=2;a[7461200]=1;a[7461208]=1;c[3532174]=688448;c[3532168]=818360;c[3532166]=818328;c[3532040]=2048;c[3532002]=1024;c[3532e3]=4;a[7460944]=1;c[3532004]=16;c[3531998]=684056;c[3531992]=727152;c[3531990]=727088;c[3532034]=6144;c[3532044]=2;c[3532030]=2;c[3532032]=2;c[3532036]=1;eZ9(0)|0;if((fa(c[c[642608+(c[2436]<<2)>>2]>>2]|0,195520)|0)!=0){c[3532200]=393216}c[3531928]=196608;c[3532048]=0;e1Z();d=c[3532046]|0;e=0;while(1){if((e|0)>=1024){break}f=9638528+(e<<2)|0;if((c[f>>2]|0)==0){g=38620;break}else{e=e+1|0}}do{if((g|0)==38620){e=gGq(d)|0;c[f>>2]=e;if((e|0)==0){break}gGz(e|0,0,d|0);c[3532048]=e;gGz(e|0,0,d|0);e1Z();if((eZ9(1)|0)!=0){i=1;return i|0}if((fa(c[c[642608+(c[2436]<<2)>>2]>>2]|0,195520)|0)!=0){e=c[3532204]|0;j=e+262144|0;k=e+131072|0;gGC(j|0,k|0,131072)|0;gGz(k|0,-1|0,131072)}k=c[3531932]|0;j=k+163840|0;gGC(j|0,k|0,16384)|0;j=k+180224|0;e=k+49152|0;gGC(j|0,e|0,16384)|0;e=k+131072|0;gGC(e|0,k|0,16384)|0;e=k+147456|0;j=k+32768|0;gGC(e|0,j|0,16384)|0;j=k+98304|0;gGC(j|0,k|0,16384)|0;j=k+114688|0;e=k+16384|0;gGC(j|0,e|0,16384)|0;e=k+65536|0;gGC(e|0,k|0,16384)|0;e=k+81920|0;gGC(e|0,k|0,16384)|0;k=c[3532042]|0;e=0;while(1){if((e|0)>=1024){l=0;break}m=9638528+(e<<2)|0;if((c[m>>2]|0)==0){g=38628;break}else{e=e+1|0}}do{if((g|0)==38628){e=gGq(65536)|0;c[m>>2]=e;if((e|0)==0){l=0;break}gGz(e|0,0,65536);l=e}}while(0);c[3540978]=l;gGz(l|0,0,65536);c[2437030]=k;c[2438630]=-16;c[2438626]=0;c[2427050]=0;c[2438628]=0;a[7461128]=1;c[3527054]=128;c[2437032]=1;c[3528994]=(c[3528994]|0)+1;a[7461080]=1;fxU(0,425984);if((c[2394]|0)==0){n=c[2112932]|0}else{c[2394]=0;e=c[3532596]|0;c[2112932]=e;j=c[3532592]|0;if((j|0)!=0){gGC(9104152,j|0,280)|0}c[2113054]=c[2113060];n=e}e=c[3532204]|0;j=n|0;o=0;while(1){p=e+o|0;c[j>>2]=p;c[j+131072>>2]=p;p=o+1024|0;if(p>>>0>393215){break}else{j=j+4|0;o=p}}o=c[3532208]|0;j=n+2048|0;e=524288;while(1){k=o+(e-524288)|0;c[j>>2]=k;c[j+65536>>2]=k;c[j+131072>>2]=k;k=e+1024|0;if(k>>>0>589823){break}else{j=j+4|0;e=k}}e=c[3540978]|0;j=n+53248|0;k=13631488;while(1){p=e+(k-13631488)|0;c[j>>2]=p;c[j+65536>>2]=p;c[j+131072>>2]=p;p=k+1024|0;if(p>>>0>13697023){break}else{j=j+4|0;k=p}}k=c[3532026]|0;c[n+55296>>2]=k;c[n+120832>>2]=k;c[n+186368>>2]=k;j=k+1024|0;c[n+55300>>2]=j;c[n+120836>>2]=j;c[n+186372>>2]=j;j=k+2048|0;c[n+55304>>2]=j;c[n+120840>>2]=j;c[n+186376>>2]=j;j=k+3072|0;c[n+55308>>2]=j;c[n+120844>>2]=j;c[n+186380>>2]=j;j=c[3531970]|0;k=j-256|0;c[n+57344>>2]=k;c[n+122880>>2]=k;c[n+188416>>2]=k;k=j+768|0;c[n+57348>>2]=k;c[n+122884>>2]=k;c[n+188420>>2]=k;k=j+1792|0;c[n+57352>>2]=k;c[n+122888>>2]=k;c[n+188424>>2]=k;k=j+2816|0;c[n+57356>>2]=k;c[n+122892>>2]=k;c[n+188428>>2]=k;k=c[3532008]|0;c[n+57360>>2]=k;c[n+122896>>2]=k;c[n+188432>>2]=k;j=k+1024|0;c[n+57364>>2]=j;c[n+122900>>2]=j;c[n+188436>>2]=j;j=k+2048|0;c[n+57368>>2]=j;c[n+122904>>2]=j;c[n+188440>>2]=j;j=k+3072|0;c[n+57372>>2]=j;c[n+122908>>2]=j;c[n+188444>>2]=j;j=k+4096|0;c[n+57376>>2]=j;c[n+122912>>2]=j;c[n+188448>>2]=j;j=k+5120|0;c[n+57380>>2]=j;c[n+122916>>2]=j;c[n+188452>>2]=j;j=k+6144|0;c[n+57384>>2]=j;c[n+122920>>2]=j;c[n+188456>>2]=j;j=k+7168|0;c[n+57388>>2]=j;c[n+122924>>2]=j;c[n+188460>>2]=j;j=c[3531958]|0;k=n+57472|0;e=14712832;while(1){p=j+(e-14712832)|0;c[k>>2]=p;c[k+65536>>2]=p;c[k+131072>>2]=p;p=e+1024|0;if(p>>>0>14745599){break}else{k=k+4|0;e=p}}e=o+65536|0;c[n+57600>>2]=e;c[n+123136>>2]=e;c[n+188672>>2]=e;e=o+66560|0;c[n+57604>>2]=e;c[n+123140>>2]=e;c[n+188676>>2]=e;e=o+67584|0;c[n+57608>>2]=e;c[n+123144>>2]=e;c[n+188680>>2]=e;e=o+68608|0;c[n+57612>>2]=e;c[n+123148>>2]=e;c[n+188684>>2]=e;c[n+196608>>2]=2096;c[n+196648>>2]=1742;c[n+196688>>2]=2290;c[n+196728>>2]=3300;e=c[3532592]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fxU(1,425984);if((c[2394]|0)==1){q=c[2112932]|0}else{c[2394]=1;e=c[3532597]|0;c[2112932]=e;k=c[3532593]|0;if((k|0)!=0){gGC(9104152,k|0,280)|0}c[2113054]=c[2113061];q=e}e=c[3532198]|0;k=q|0;j=0;while(1){p=e+j|0;c[k>>2]=p;c[k+131072>>2]=p;p=j+1024|0;if(p>>>0>262143){break}else{k=k+4|0;j=p}}j=c[3532206]|0;k=q+1024|0;e=262144;while(1){o=j+(e-262144)|0;c[k>>2]=o;c[k+65536>>2]=o;c[k+131072>>2]=o;o=e+1024|0;if(o>>>0>327679){break}else{k=k+4|0;e=o}}e=c[3532026]|0;c[q+55296>>2]=e;c[q+120832>>2]=e;c[q+186368>>2]=e;k=e+1024|0;c[q+55300>>2]=k;c[q+120836>>2]=k;c[q+186372>>2]=k;k=e+2048|0;c[q+55304>>2]=k;c[q+120840>>2]=k;c[q+186376>>2]=k;k=e+3072|0;c[q+55308>>2]=k;c[q+120844>>2]=k;c[q+186380>>2]=k;k=c[3531970]|0;e=k-256|0;c[q+57344>>2]=e;c[q+122880>>2]=e;c[q+188416>>2]=e;e=k+768|0;c[q+57348>>2]=e;c[q+122884>>2]=e;c[q+188420>>2]=e;e=k+1792|0;c[q+57352>>2]=e;c[q+122888>>2]=e;c[q+188424>>2]=e;e=k+2816|0;c[q+57356>>2]=e;c[q+122892>>2]=e;c[q+188428>>2]=e;e=c[3532008]|0;c[q+57360>>2]=e;c[q+122896>>2]=e;c[q+188432>>2]=e;k=e+1024|0;c[q+57364>>2]=k;c[q+122900>>2]=k;c[q+188436>>2]=k;k=e+2048|0;c[q+57368>>2]=k;c[q+122904>>2]=k;c[q+188440>>2]=k;k=e+3072|0;c[q+57372>>2]=k;c[q+122908>>2]=k;c[q+188444>>2]=k;k=e+4096|0;c[q+57376>>2]=k;c[q+122912>>2]=k;c[q+188448>>2]=k;k=e+5120|0;c[q+57380>>2]=k;c[q+122916>>2]=k;c[q+188452>>2]=k;k=e+6144|0;c[q+57384>>2]=k;c[q+122920>>2]=k;c[q+188456>>2]=k;k=e+7168|0;c[q+57388>>2]=k;c[q+122924>>2]=k;c[q+188460>>2]=k;k=c[3531958]|0;e=q+57472|0;j=14712832;while(1){o=k+(j-14712832)|0;c[e>>2]=o;c[e+65536>>2]=o;c[e+131072>>2]=o;o=j+1024|0;if(o>>>0>14745599){break}else{e=e+4|0;j=o}}c[q+196608>>2]=3142;c[q+196648>>2]=2828;c[q+196688>>2]=542;c[q+196728>>2]=1118;j=c[3532593]|0;if((j|0)!=0){gGC(j|0,9104152,280)|0}c[2113061]=c[2113054];c[2394]=-1;fwR(0);j=c[2439330]|0;e=(j|0)==0;if(!e){k=j;gGC(9706056,k|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];k=c[3528484]|0;c[2076596]=k;o=c[2417276]|0;c[3541536]=o;c[1836236]=0;c[j+4180>>2]=2968;c[j+4184>>2]=308;p=c[3531932]|0;r=0;s=0;while(1){c[j+76+(s<<2)>>2]=p+(s<<8);t=r+1&65535;if((t&65535)>127){u=0;v=0;break}else{r=t;s=t&65535}}while(1){s=p+(v<<8)|0;c[j+76+(v+512<<2)>>2]=s;c[j+76+(v+768<<2)>>2]=s;s=u+1&65535;if((s&65535)>127){break}else{u=s;v=s&65535}}p=c[3531936]|0;c[j+588>>2]=p;c[j+592>>2]=p+256;c[j+596>>2]=p+512;c[j+600>>2]=p+768;c[j+604>>2]=p+1024;c[j+608>>2]=p+1280;c[j+612>>2]=p+1536;c[j+616>>2]=p+1792;c[j+620>>2]=p+2048;c[j+624>>2]=p+2304;c[j+628>>2]=p+2560;c[j+632>>2]=p+2816;c[j+636>>2]=p+3072;c[j+640>>2]=p+3328;c[j+644>>2]=p+3584;c[j+648>>2]=p+3840;s=128;r=128;while(1){c[j+76+(r+256<<2)>>2]=p+((r<<8)-32768);t=s+1&65535;if((t&65535)>143){w=128;x=128;break}else{s=t;r=t&65535}}while(1){r=p+((x<<8)-32768)|0;c[j+76+(x+512<<2)>>2]=r;c[j+76+(x+768<<2)>>2]=r;r=w+1&65535;if((r&65535)>143){break}else{w=r;x=r&65535}}if(!e){p=j;gGC(p|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=k;c[2417276]=o;c[1836236]=-1;fwR(1);p=c[2439331]|0;r=(p|0)==0;if(!r){s=p;gGC(9706056,s|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];s=c[3528485]|0;c[2076596]=s;t=c[2417277]|0;c[3541536]=t;c[1836236]=1;c[p+4172>>2]=1086;c[p+4176>>2]=1978;y=c[3531926]|0;z=0;A=0;while(1){c[p+76+(A<<2)>>2]=y+(A<<8);B=z+1&65535;if((B&65535)>255){C=0;D=0;break}else{z=B;A=B&65535}}while(1){A=y+(D<<8)|0;c[p+76+(D+512<<2)>>2]=A;c[p+76+(D+768<<2)>>2]=A;A=C+1&65535;if((A&65535)>255){break}else{C=A;D=A&65535}}if(!r){y=p;gGC(y|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=s;c[2417277]=t;c[1836236]=-1;Vr(2,4e6,1324,3064,82,0);c[2438228]=4e6;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=511;c[3542224]=0;c[3542225]=0;c[3542226]=3446;c[3542227]=836;c[3542287]=0;c[3542288]=0;c[3542289]=2188;c[3542290]=1586;h[85166]=.08;h[85282]=.6;a[64240]=1;UB(0,3064,384e3,12406,5);h[85210]=1.0;c[2415126]=9662152;c[2415549]=1;y=c[642608+(c[2436]<<2)>>2]|0;A=c[y+128>>2]|0;if((c[y+52>>2]&4|0)==0){c[2113068]=A;z=c[y+132>>2]|0;c[2113070]=z;c[2443814]=A;c[2440436]=z;E=A;F=z}else{c[2113070]=A;z=c[y+132>>2]|0;c[2113068]=z;c[2440436]=A;c[2443814]=z;E=z;F=A}A=ag(E<<1,F)|0;z=gGq(A)|0;c[2112926]=z;if((z|0)!=0){gGz(z|0,0,A|0)}c[3532118]=6478;c[3532050]=6356;c[3532064]=4;c[2113026]=133333;c[2113024]=133333;c[2113022]=66666;a[9544]=1;c[3532016]=2806;eZ8()|0;a[9720936]=0;c[2437782]=0;b[4877712]=0;A=9553280;c[A>>2]=0;c[A+4>>2]=0;gGz(9553288,-128|0,5);A=0;while(1){c[9774520+(A<<2)>>2]=~~(100.0/+X(+10.0,+((32.0- +(A|0)*2.133333444595337)/20.0)));z=A+1|0;if((z|0)<16){A=z}else{i=0;break}}return i|0}}while(0);c[3532048]=0;i=1;return i|0}function e0E(){var d=0,e=0,f=0,g=0,h=0;c[2438580]=0;c[2437014]=0;d=9757696;c[d>>2]=0;c[d+4>>2]=0;d=9757688;c[d>>2]=0;c[d+4>>2]=0;c[2438633]=0;c[2438632]=0;c[2438635]=0;c[2438634]=0;c[2437035]=0;c[2437034]=0;c[2433350]=0;c[2433348]=0;a[9720936]=0;c[2437782]=0;b[4877712]=0;b[4876800]=0;b[4876796]=0;d=c[2430394]|0;e=0;while(1){if((e|0)>=1024){f=38691;break}g=9638528+(e<<2)|0;if((c[g>>2]|0)==(d|0)){break}else{e=e+1|0}}if((f|0)==38691){c[2430394]=0;h=e_a()|0;return 0}gGr(d);c[g>>2]=0;c[2430394]=0;h=e_a()|0;return 0}function e0F(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;c[2415126]=9662152;d=c[2415557]|0;e=d&3;if((e|0)==3){f=133}else{f=(4e6/(4e6/((c[2415554]|0)/(c[600992+((d>>>3&1)<<4)+(e<<2)>>2]|0)|0|0)|0|0)|0|0)/((c[2424]|0)/100|0|0)|0}if((a[14128072]|0)!=0){e=c[3532016]|0;gD[e&8191]()|0}gu[c[3532050]&16383]();gGz(8452120,0,16);e=c[2392]|0;if((e|0)>=0){gGz(8452240,0,((e|0)>0?(e<<2)+4|0:4)|0)}c[2113054]=0;e=c[2385548]|0;if((e|0)>0){gGz(9752472,0,((e|0)>1?e<<2:4)|0)}c[2433530]=0;if((f|0)>0){e=f-1|0;d=0;while(1){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060]}g=d+1|0;h=(ag(c[2113026]|0,g)|0)/(f|0)|0;i=h-(c[2113030]|0)|0;c[2113028]=i;c[2113056]=i;h=RG(i)|0;c[2113054]=(c[2113054]|0)+h;c[2276108]=-1;c[2113056]=-1;c[2113030]=(c[2113030]|0)+h;h=(d|0)==(e|0);do{if(h){i=c[3532064]|0;c[8452200+(c[2394]<<2)>>2]=i|8192;j=c[2276080]|0;k=i<<8;c[2276080]=k;if((j|0)!=1792&(k|0)==1792){RH(7);break}if(k>>>0<=(c[2276079]|0)>>>0){break}RH(i&16777215)}}while(0);i=c[2394]|0;k=c[14130368+(i<<2)>>2]|0;if((k|0)!=0){gGC(k|0,9104152,280)|0}c[8452240+(i<<2)>>2]=c[2113054];c[2394]=-1;if((b[7064256]&1)!=0){c[2394]=1;c[2112932]=c[3532597];i=c[3532593]|0;if((i|0)!=0){gGC(9104152,i|0,280)|0}c[2113054]=c[2113061];i=(ag(c[2113024]|0,g)|0)/(f|0)|0;k=i-(c[2113031]|0)|0;c[2113028]=k;c[2113056]=k;i=RG(k)|0;c[2113054]=(c[2113054]|0)+i;c[2276108]=-1;c[2113056]=-1;c[2113031]=(c[2113031]|0)+i;do{if(h){i=c[3532064]|0;c[8452200+(c[2394]<<2)>>2]=i|8192;k=c[2276080]|0;j=i<<8;c[2276080]=j;if((k|0)!=1792&(j|0)==1792){RH(7);break}if(j>>>0<=(c[2276079]|0)>>>0){break}RH(i&16777215)}}while(0);h=c[2394]|0;i=c[14130368+(h<<2)>>2]|0;if((i|0)!=0){gGC(i|0,9104152,280)|0}c[8452240+(h<<2)>>2]=c[2113054];c[2394]=-1}h=c[2439330]|0;if((h|0)!=0){i=h;gGC(9706056,i|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;Sb(ag((c[2113022]|0)/(f|0)|0,d)|0);i=c[1836236]|0;h=c[9757320+(i<<2)>>2]|0;if((h|0)!=0){j=h;gGC(j|0,9706056,76)|0}c[9752472+(i<<2)>>2]=c[2433530];c[14113936+(i<<2)>>2]=c[2076596];c[9669104+(i<<2)>>2]=c[3541536];c[1836236]=-1;i=c[2439331]|0;if((i|0)!=0){j=i;gGC(9706056,j|0,76)|0}b[4853030]=c[2426515]&65535;j=c[2438119]|0;c[2433530]=j;c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;h=(ag(a[9544]|0?66666:0,g)|0)/(f|0)|0;k=c[2113033]|0;l=h-k|0;c[2113028]=l;do{if((l|0)<1){m=0;n=k}else{if((a[i+4188|0]|0)==0){h=gfc(l)|0;c[2433530]=(c[2433530]|0)+h;m=h;n=c[2113033]|0;break}else{c[2433530]=j+l;m=l;n=k;break}}}while(0);c[2113028]=m;c[2113033]=n+m;UD();k=c[1836236]|0;l=c[9757320+(k<<2)>>2]|0;if((l|0)!=0){j=l;gGC(j|0,9706056,76)|0}c[9752472+(k<<2)>>2]=c[2433530];c[14113936+(k<<2)>>2]=c[2076596];c[9669104+(k<<2)>>2]=c[3541536];c[1836236]=-1;if((g|0)<(f|0)){d=g}else{break}}}d=c[2439330]|0;if((d|0)!=0){f=d;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;f=c[2113022]|0;d=gGU(f,(f|0)<0|0?-1:0,2048e6,0)|0;m=c[2438228]|0;n=gGS(d,K,m,(m|0)<0|0?-1:0)|0;m=n;Sb(f);f=c[2443830]|0;if((f|0)<1073676288){c[2443830]=f-m}f=c[2443831]|0;if((f|0)<1073676288){c[2443831]=f-m}f=(c[3528512]|0)-m|0;c[3528512]=(f|0)<0?0:f;f=c[2112964]|0;if((f|0)!=0){gg[c[3542122]&4095](f,a[9688]|0?534:0)}f=c[1836236]|0;m=c[9757320+(f<<2)>>2]|0;if((m|0)!=0){n=m;gGC(n|0,9706056,76)|0}c[9752472+(f<<2)>>2]=c[2433530];c[14113936+(f<<2)>>2]=c[2076596];c[9669104+(f<<2)>>2]=c[3541536];c[1836236]=-1;f=c[2439331]|0;if((f|0)!=0){n=f;gGC(9706056,n|0,76)|0}b[4853030]=c[2426515]&65535;n=c[2438119]|0;c[2433530]=n;c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;m=(a[9544]|0?66666:0)-(c[2113033]|0)|0;do{if((m|0)>=1){if((a[f+4188|0]|0)==0){d=gfc(m)|0;c[2433530]=(c[2433530]|0)+d;break}else{c[2433530]=n+m;break}}}while(0);m=c[2112964]|0;if((m|0)!=0){Uz(0,m,a[9688]|0?534:0)}m=c[1836236]|0;n=c[9757320+(m<<2)>>2]|0;if((n|0)!=0){f=n;gGC(f|0,9706056,76)|0}c[9752472+(m<<2)>>2]=c[2433530];c[14113936+(m<<2)>>2]=c[2076596];c[9669104+(m<<2)>>2]=c[3541536];c[1836236]=-1;if((c[2112968]|0)==0){return 0}gu[c[3532118]&16383]();return 0}function e0G(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;g=i;i=i+416|0;h=g|0;j=g+16|0;k=g+32|0;l=g+48|0;m=g+64|0;n=g+80|0;o=g+96|0;p=g+112|0;q=g+128|0;r=g+144|0;s=g+160|0;t=g+176|0;u=g+192|0;v=g+208|0;w=g+224|0;x=g+240|0;y=g+256|0;z=g+272|0;A=g+288|0;B=g+304|0;C=g+320|0;D=g+336|0;E=g+352|0;F=g+368|0;G=g+384|0;H=g+400|0;if((f|0)!=0){c[f>>2]=169603}if((e&32|0)!=0){gGz(H|0,0,12);I=c[3532020]|0;c[H>>2]=I;c[H+4>>2]=(c[3532022]|0)-I;c[H+12>>2]=162152;I=c[2076592]|0;gj[I&4095](H)|0}eZ7(e);if((e&64|0)!=0){H=o|0;gGz(n|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){I=o+9|0;o=m;J=m|0;K=m+4|0;L=m+12|0;M=n|0;N=n+4|0;O=n+12|0;P=0;do{gGC(H|0,614896,11)|0;a[I]=P+48&255;Q=8452256+(P<<2)|0;gGz(o|0,0,12);c[J>>2]=Q;c[K>>2]=4;c[L>>2]=164976;gj[c[2076592]&4095](m)|0;if((c[Q>>2]|0)!=0){c[M>>2]=c[14130368+(P<<2)>>2];c[N>>2]=c[8452184+(P<<2)>>2];c[O>>2]=H;Q=c[2076592]|0;gj[Q&4095](n)|0}P=P+1|0;}while((P|0)<=(c[2392]|0))}fw$(e);do{if(a[7460968]|0){gGz(l|0,0,12);c[l>>2]=8453216;c[l+4>>2]=4;c[l+12>>2]=107480;P=c[2076592]|0;gj[P&4095](l)|0;gGz(k|0,0,12);c[k>>2]=14168504;c[k+4>>2]=256;c[k+12>>2]=476464;P=c[2076592]|0;gj[P&4095](k)|0;if((e&2|0)==0){break}else{R=0}do{mv(0,R,d[14168504+R|0]|0);R=R+1|0;}while((R|0)<256)}}while(0);if((c[3532032]|0)!=0){Vx(e,f)}if((c[3532036]|0)!=0){UE(e,f)}gGz(j|0,0,12);c[j>>2]=14168784;c[j+4>>2]=16;c[j+12>>2]=249744;f=c[2076592]|0;gj[f&4095](j)|0;gGz(h|0,0,12);c[h>>2]=14168768;c[h+4>>2]=16;c[h+12>>2]=524320;j=c[2076592]|0;gj[j&4095](h)|0;gGz(G|0,0,12);c[G>>2]=14128320;c[G+4>>2]=6;c[G+12>>2]=273024;h=c[2076592]|0;gj[h&4095](G)|0;gGz(F|0,0,12);c[F>>2]=14128744;c[F+4>>2]=4;c[F+12>>2]=400008;G=c[2076592]|0;gj[G&4095](F)|0;gGz(E|0,0,12);c[E>>2]=14128736;c[E+4>>2]=4;c[E+12>>2]=399240;F=c[2076592]|0;gj[F&4095](E)|0;gGz(D|0,0,12);c[D>>2]=14127752;c[D+4>>2]=1;c[D+12>>2]=272344;E=c[2076592]|0;gj[E&4095](D)|0;gGz(C|0,0,12);c[C>>2]=14128024;c[C+4>>2]=1;c[C+12>>2]=451536;D=c[2076592]|0;gj[D&4095](C)|0;gGz(B|0,0,12);c[B>>2]=9754320;c[B+4>>2]=4;c[B+12>>2]=450256;C=c[2076592]|0;gj[C&4095](B)|0;gGz(A|0,0,12);c[A>>2]=9748056;c[A+4>>2]=4;c[A+12>>2]=448912;B=c[2076592]|0;gj[B&4095](A)|0;gGz(z|0,0,12);c[z>>2]=9757696;c[z+4>>2]=8;c[z+12>>2]=447672;A=c[2076592]|0;gj[A&4095](z)|0;gGz(y|0,0,12);c[y>>2]=9757688;c[y+4>>2]=8;c[y+12>>2]=446496;z=c[2076592]|0;gj[z&4095](y)|0;gGz(x|0,0,12);c[x>>2]=9754528;c[x+4>>2]=8;c[x+12>>2]=445536;y=c[2076592]|0;gj[y&4095](x)|0;gGz(w|0,0,12);c[w>>2]=9754536;c[w+4>>2]=8;c[w+12>>2]=444704;x=c[2076592]|0;gj[x&4095](w)|0;gGz(v|0,0,12);c[v>>2]=9748136;c[v+4>>2]=8;c[v+12>>2]=443872;w=c[2076592]|0;gj[w&4095](v)|0;gGz(u|0,0,12);c[u>>2]=8452120;c[u+4>>2]=16;c[u+12>>2]=270496;v=c[2076592]|0;gj[v&4095](u)|0;gGz(t|0,0,12);c[t>>2]=8452112;c[t+4>>2]=4;c[t+12>>2]=269664;u=c[2076592]|0;gj[u&4095](t)|0;gGz(s|0,0,12);c[s>>2]=9720936;c[s+4>>2]=1;c[s+12>>2]=440384;t=c[2076592]|0;gj[t&4095](s)|0;gGz(r|0,0,12);c[r>>2]=9751128;c[r+4>>2]=4;c[r+12>>2]=438856;s=c[2076592]|0;gj[s&4095](r)|0;gGz(q|0,0,12);c[q>>2]=9755424;c[q+4>>2]=2;c[q+12>>2]=437408;r=c[2076592]|0;gj[r&4095](q)|0;gGz(p|0,0,12);c[p>>2]=14163896;c[p+4>>2]=4;c[p+12>>2]=509208;q=c[2076592]|0;gj[q&4095](p)|0}p=a[14127752]|0;if(!((e&2|0)!=0&p<<24>>24!=0)){i=g;return 0}e=c[2439330]|0;q=(e|0)==0;if(!q){r=e;gGC(9706056,r|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];r=c[3528484]|0;c[2076596]=r;s=c[2417276]|0;c[3541536]=s;c[1836236]=0;t=c[3531932]|0;u=(p&255)<<14;p=64;v=64;while(1){c[e+76+(v<<2)>>2]=t+((v<<8)+u);w=p+1&65535;if((w&65535)>127){S=64;T=64;break}else{p=w;v=w&65535}}while(1){v=t+((T<<8)+u)|0;c[e+76+(T+512<<2)>>2]=v;c[e+76+(T+768<<2)>>2]=v;v=S+1&65535;if((v&65535)>127){break}else{S=v;T=v&65535}}if(!q){q=e;gGC(q|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=r;c[2417276]=s;c[1836236]=-1;i=g;return 0}function e0H(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>32){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5495180+(b*112|0)>>2];c[a+104>>2]=c[5495184+(b*112|0)>>2];c[a+108>>2]=c[5495188+(b*112|0)>>2];d=0;return d|0}function e0I(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<33&(d|0)==0)){e=1;return e|0}c[a>>2]=5495080+(b*112|0);e=0;return e|0}function e0J(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>35){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5498776+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e0K(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>32){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5491484+(b*112|0)>>2];c[a+104>>2]=c[5491488+(b*112|0)>>2];c[a+108>>2]=c[5491492+(b*112|0)>>2];d=0;return d|0}function e0L(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<33&(d|0)==0)){e=1;return e|0}c[a>>2]=5491384+(b*112|0);e=0;return e|0}function e0M(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>32){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5499308+(b*112|0)>>2];c[a+104>>2]=c[5499312+(b*112|0)>>2];c[a+108>>2]=c[5499316+(b*112|0)>>2];d=0;return d|0}function e0N(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<33&(d|0)==0)){e=1;return e|0}c[a>>2]=5499208+(b*112|0);e=0;return e|0}function e0O(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>38){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5502904+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e0P(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6188876+(b*112|0)>>2];c[a+104>>2]=c[6188880+(b*112|0)>>2];c[a+108>>2]=c[6188884+(b*112|0)>>2];d=0;return d|0}function e0Q(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=6188776+(b*112|0);e=0;return e|0}function e0R(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3655360+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function e0S(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>33){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6189672+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e0T(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;c[3532162]=256;c[3532160]=4;c[3532142]=8;c[3532164]=8;c[3532148]=683968;c[3532140]=725912;c[3532138]=725880;c[3532042]=16384;c[3532002]=1024;c[3532e3]=4;a[7460944]=1;c[3532004]=16;c[3531998]=682232;c[3531992]=690968;c[3531990]=690904;c[3532034]=4096;c[3532044]=1;c[3532030]=1;a[7460968]=1;c[3532036]=2;eZ9(0)|0;c[3532048]=0;e1Z();d=c[3532046]|0;e=0;while(1){if((e|0)>=1024){break}f=9638528+(e<<2)|0;if((c[f>>2]|0)==0){g=38872;break}else{e=e+1|0}}do{if((g|0)==38872){e=gGq(d)|0;c[f>>2]=e;if((e|0)==0){break}gGz(e|0,0,d|0);c[3532048]=e;gGz(e|0,0,d|0);e1Z();if((eZ9(1)|0)!=0){i=1;return i|0}e=c[3532042]|0;j=0;while(1){if((j|0)>=1024){k=0;break}l=9638528+(j<<2)|0;if((c[l>>2]|0)==0){g=38878;break}else{j=j+1|0}}do{if((g|0)==38878){j=gGq(65536)|0;c[l>>2]=j;if((j|0)==0){k=0;break}gGz(j|0,0,65536);k=j}}while(0);c[3540978]=k;gGz(k|0,0,65536);c[2437030]=e;c[2438630]=0;c[2438626]=8;c[2427050]=0;c[2438628]=0;a[7461128]=1;c[3527054]=64;c[2437032]=0;c[3528994]=(c[3528994]|0)+1;j=c[3532034]|0;m=0;while(1){if((m|0)>=1024){n=0;break}o=9638528+(m<<2)|0;if((c[o>>2]|0)==0){g=38883;break}else{m=m+1|0}}do{if((g|0)==38883){m=gGq(16384)|0;c[o>>2]=m;if((m|0)==0){n=0;break}gGz(m|0,0,16384);n=m}}while(0);c[3540976]=n;gGz(n|0,0,16384);c[2437028]=j;c[2438624]=8;a[726072]=0;a[7461120]=1;a[7461080]=1;fxU(0,425984);if((c[2394]|0)==0){p=c[2112932]|0}else{c[2394]=0;m=c[3532596]|0;c[2112932]=m;e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060];p=m}m=c[3532204]|0;e=p|0;q=0;while(1){r=m+q|0;c[e>>2]=r;c[e+131072>>2]=r;r=q+1024|0;if(r>>>0>262143){break}else{e=e+4|0;q=r}}q=c[3532208]|0;e=p+4096|0;m=1048576;while(1){j=q+(m-1048576)|0;c[e>>2]=j;c[e+65536>>2]=j;c[e+131072>>2]=j;j=m+1024|0;if(j>>>0>1081343){break}else{e=e+4|0;m=j}}m=c[3532026]|0;c[p+8192>>2]=m;c[p+73728>>2]=m;c[p+139264>>2]=m;e=m+1024|0;c[p+8196>>2]=e;c[p+73732>>2]=e;c[p+139268>>2]=e;e=m+2048|0;c[p+8200>>2]=e;c[p+73736>>2]=e;c[p+139272>>2]=e;e=m+3072|0;c[p+8204>>2]=e;c[p+73740>>2]=e;c[p+139276>>2]=e;e=c[3540978]|0;m=p+49152|0;j=12582912;while(1){r=e+(j-12582912)|0;c[m>>2]=r;c[m+65536>>2]=r;c[m+131072>>2]=r;r=j+1024|0;if(r>>>0>12648447){break}else{m=m+4|0;j=r}}j=p+49408|0;m=12648448;while(1){e=q+(m-12615680)|0;c[j>>2]=e;c[j+65536>>2]=e;c[j+131072>>2]=e;e=m+1024|0;if(e>>>0>12713983){break}else{j=j+4|0;m=e}}m=c[3540976]|0;c[p+53248>>2]=m;c[p+118784>>2]=m;c[p+184320>>2]=m;j=m+1024|0;c[p+53252>>2]=j;c[p+118788>>2]=j;c[p+184324>>2]=j;j=m+2048|0;c[p+53256>>2]=j;c[p+118792>>2]=j;c[p+184328>>2]=j;j=m+3072|0;c[p+53260>>2]=j;c[p+118796>>2]=j;c[p+184332>>2]=j;j=m+4096|0;c[p+53264>>2]=j;c[p+118800>>2]=j;c[p+184336>>2]=j;j=m+5120|0;c[p+53268>>2]=j;c[p+118804>>2]=j;c[p+184340>>2]=j;j=m+6144|0;c[p+53272>>2]=j;c[p+118808>>2]=j;c[p+184344>>2]=j;j=m+7168|0;c[p+53276>>2]=j;c[p+118812>>2]=j;c[p+184348>>2]=j;j=m+8192|0;c[p+53280>>2]=j;c[p+118816>>2]=j;c[p+184352>>2]=j;j=m+9216|0;c[p+53284>>2]=j;c[p+118820>>2]=j;c[p+184356>>2]=j;j=m+10240|0;c[p+53288>>2]=j;c[p+118824>>2]=j;c[p+184360>>2]=j;j=m+11264|0;c[p+53292>>2]=j;c[p+118828>>2]=j;c[p+184364>>2]=j;j=m+12288|0;c[p+53296>>2]=j;c[p+118832>>2]=j;c[p+184368>>2]=j;j=m+13312|0;c[p+53300>>2]=j;c[p+118836>>2]=j;c[p+184372>>2]=j;j=m+14336|0;c[p+53304>>2]=j;c[p+118840>>2]=j;c[p+184376>>2]=j;j=m+15360|0;c[p+53308>>2]=j;c[p+118844>>2]=j;c[p+184380>>2]=j;c[p+196608>>2]=790;c[p+196648>>2]=1376;c[p+196688>>2]=932;c[p+196728>>2]=684;j=c[3532592]|0;if((j|0)!=0){gGC(j|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);j=c[2439330]|0;m=(j|0)==0;if(!m){q=j;gGC(9706056,q|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];q=c[3528484]|0;c[2076596]=q;e=c[2417276]|0;c[3541536]=e;c[1836236]=0;c[j+4180>>2]=3280;c[j+4184>>2]=3382;r=c[3531932]|0;s=0;t=0;while(1){c[j+76+(t<<2)>>2]=r+(t<<8);u=s+1&65535;if((u&65535)>63){v=0;w=0;break}else{s=u;t=u&65535}}while(1){t=r+(w<<8)|0;c[j+76+(w+512<<2)>>2]=t;c[j+76+(w+768<<2)>>2]=t;t=v+1&65535;if((t&65535)>63){x=64;y=64;break}else{v=t;w=t&65535}}while(1){c[j+76+(y<<2)>>2]=r+(y<<8);t=x+1&65535;if((t&65535)>127){z=64;A=64;break}else{x=t;y=t&65535}}while(1){t=r+(A<<8)|0;c[j+76+(A+512<<2)>>2]=t;c[j+76+(A+768<<2)>>2]=t;t=z+1&65535;if((t&65535)>127){break}else{z=t;A=t&65535}}r=c[3531936]|0;c[j+588>>2]=r;c[j+592>>2]=r+256;c[j+596>>2]=r+512;c[j+600>>2]=r+768;c[j+604>>2]=r+1024;c[j+608>>2]=r+1280;c[j+612>>2]=r+1536;c[j+616>>2]=r+1792;c[j+620>>2]=r+2048;c[j+624>>2]=r+2304;c[j+628>>2]=r+2560;c[j+632>>2]=r+2816;c[j+636>>2]=r+3072;c[j+640>>2]=r+3328;c[j+644>>2]=r+3584;c[j+648>>2]=r+3840;t=128;s=128;while(1){c[j+76+(s+256<<2)>>2]=r+((s<<8)-32768);u=t+1&65535;if((u&65535)>143){B=128;C=128;break}else{t=u;s=u&65535}}while(1){s=r+((C<<8)-32768)|0;c[j+76+(C+512<<2)>>2]=s;c[j+76+(C+768<<2)>>2]=s;s=B+1&65535;if((s&65535)>143){break}else{B=s;C=s&65535}}if(!m){r=j;gGC(r|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=q;c[2417276]=e;c[1836236]=-1;r=a[9680]|0;s=r?32e3:0;if(r){if(a[9624]|0){r=s*3|0;t=62500;while(1){if((t|0)>(r|0)){t=t>>1}else{D=1222;E=t;break}}}else{D=2462;E=s}c[2429380]=E;c[3542124]=D;mw(4e6,E);t=gGq(262144)|0;c[2406684]=t;gGz(t|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(4e6,11025)}t=c[3531464]|0;c[t+44344>>2]=1036;c[t+44348>>2]=2498;h[745421]=.75;c[2436794]=1;h[745420]=.75;c[2436792]=2;UB(0,3064,384e3,3170,5);UB(1,3064,384e3,3758,5);h[1207773]=.6;c[2415548]=3;c[2415126]=9665376;h[1208176]=.6;c[2416354]=3;t=c[642608+(c[2436]<<2)>>2]|0;r=c[t+128>>2]|0;if((c[t+52>>2]&4|0)==0){c[2113068]=r;e=c[t+132>>2]|0;c[2113070]=e;c[2443814]=r;c[2440436]=e;F=r;G=e}else{c[2113070]=r;e=c[t+132>>2]|0;c[2113068]=e;c[2440436]=r;c[2443814]=e;F=e;G=r}r=ag(F<<1,G)|0;e=gGq(r)|0;c[2112926]=e;if((e|0)!=0){gGz(e|0,0,r|0)}c[2113302]=1;a[801640]=0;r=c[642608+(c[2436]<<2)>>2]|0;e=c[r+128>>2]|0;if((c[r+52>>2]&4|0)==0){c[2440576]=e;t=c[r+132>>2]|0;c[2440574]=t;H=e;I=t}else{c[2440574]=e;t=c[r+132>>2]|0;c[2440576]=t;H=t;I=e}e=(((H|0)/2|0)<<8)-1792|0;t=(((I|0)/2|0)<<8)-2048|0;c[3542196]=e;c[3542192]=t;c[3542197]=e;c[3542193]=t;c[3542198]=e;c[3542194]=t;c[3542199]=e;c[3542195]=t;c[3532118]=12326;c[3532050]=1860;c[3532064]=5;c[2113026]=2e5;c[2113024]=66666;t=c[3532204]|0;c[2433350]=236-(b[t+262064>>1]&255);c[2433348]=28-(b[t+262062>>1]&255);c[3527516]=b[t+262142>>1]&255;t=0;while(1){if((t|0)>=1024){J=0;break}K=9638528+(t<<2)|0;if((c[K>>2]|0)==0){g=38929;break}else{t=t+1|0}}do{if((g|0)==38929){t=gGq(8192)|0;c[K>>2]=t;if((t|0)==0){J=0;break}gGz(t|0,0,8192);J=t}}while(0);c[2406600]=J;gGz(J|0,0,8192);a[9774608]=0;a[9774624]=-4;a[9774616]=-1;a[14124928]=0;a[14124929]=0;a[818400]=1;a[818392]=1;a[818401]=1;a[818393]=1;a[7461136]=1;c[3532016]=4126;e2t()|0;i=0;return i|0}}while(0);c[3532048]=0;i=1;return i|0}function e0U(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;do{if((c[3532036]|0)==0){d=10}else{c[2415126]=9662152;e=c[2415557]|0;f=e&3;if((f|0)==3){d=133;break}d=(4e6/(4e6/((c[2415554]|0)/(c[600992+((e>>>3&1)<<4)+(f<<2)>>2]|0)|0|0)|0|0)|0|0)/((c[2424]|0)/100|0|0)|0}}while(0);if((a[14128072]|0)!=0){f=c[3532016]|0;gD[f&8191]()|0}gu[c[3532050]&16383]();c[2113032]=0;c[2113031]=0;c[2113030]=0;f=c[2392]|0;if((f|0)>=0){gGz(8452240,0,((f|0)>0?(f<<2)+4|0:4)|0)}c[2113054]=0;f=c[2385548]|0;if((f|0)>0){gGz(9752472,0,((f|0)>1?f<<2:4)|0)}c[2433530]=0;f=0;e=0;L51033:while(1){g=e;while(1){if((g|0)>=(d|0)){break L51033}if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];h=c[3532592]|0;if((h|0)!=0){gGC(9104152,h|0,280)|0}c[2113054]=c[2113060]}i=g+1|0;h=(ag(c[2113026]|0,i)|0)/(d|0)|0;j=h-(c[2113030]|0)|0;c[2113028]=j;c[2113056]=j;h=RG(j)|0;c[2113054]=(c[2113054]|0)+h;c[2276108]=-1;c[2113056]=-1;c[2113030]=(c[2113030]|0)+h;h=(g|0)==9;do{if(h){j=c[3532064]|0;c[8452200+(c[2394]<<2)>>2]=j|8192;k=c[2276080]|0;l=j<<8;c[2276080]=l;if((k|0)!=1792&(l|0)==1792){RH(7);break}if(l>>>0<=(c[2276079]|0)>>>0){break}RH(j&16777215)}}while(0);j=c[2394]|0;l=c[14130368+(j<<2)>>2]|0;if((l|0)!=0){gGC(l|0,9104152,280)|0}c[8452240+(j<<2)>>2]=c[2113054];c[2394]=-1;do{if((c[3532030]|0)>0){j=c[2439330]|0;if((j|0)!=0){l=j;gGC(9706056,l|0,76)|0}b[4853030]=c[2426515]&65535;l=c[2438118]|0;c[2433530]=l;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;k=(ag(c[2113024]|0,i)|0)/(d|0)|0;m=c[2113031]|0;n=k-m|0;c[2113028]=n;do{if((n|0)<1){o=0;p=m}else{if((a[j+4188|0]|0)==0){k=gfc(n)|0;c[2433530]=(c[2433530]|0)+k;o=k;p=c[2113031]|0;break}else{c[2433530]=l+n;o=n;p=m;break}}}while(0);c[2113028]=o;c[2113031]=p+o;if((c[3532036]|0)!=0){UD()}m=c[1836236]|0;n=c[9757320+(m<<2)>>2]|0;if((n|0)!=0){l=n;gGC(l|0,9706056,76)|0}c[9752472+(m<<2)>>2]=c[2433530];c[14113936+(m<<2)>>2]=c[2076596];c[9669104+(m<<2)>>2]=c[3541536];c[1836236]=-1;if((c[3532030]|0)!=2){break}m=c[2439331]|0;if((m|0)!=0){l=m;gGC(9706056,l|0,76)|0}b[4853030]=c[2426515]&65535;l=c[2438119]|0;c[2433530]=l;c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;n=(ag(c[2113022]|0,i)|0)/(d|0)|0;j=c[2113032]|0;k=n-j|0;c[2113028]=k;do{if((k|0)<1){q=0;r=j}else{if((a[m+4188|0]|0)==0){n=gfc(k)|0;c[2433530]=(c[2433530]|0)+n;q=n;r=c[2113032]|0;break}else{c[2433530]=l+k;q=k;r=j;break}}}while(0);c[2113028]=q;c[2113032]=r+q;if(h){a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0}j=c[1836236]|0;k=c[9757320+(j<<2)>>2]|0;if((k|0)!=0){l=k;gGC(l|0,9706056,76)|0}c[9752472+(j<<2)>>2]=c[2433530];c[14113936+(j<<2)>>2]=c[2076596];c[9669104+(j<<2)>>2]=c[3541536];c[1836236]=-1}}while(0);s=c[2112964]|0;if((s|0)==0){g=i}else{break}}g=((a[9688]|0?534:0)|0)/(d|0)|0;h=s+(f<<1<<1)|0;j=c[3532030]|0;if((j|0)>0){l=c[2439330]|0;if((l|0)!=0){k=l;gGC(9706056,k|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0}if(a[7460968]|0){gg[c[3542124]&4095](h,g);t=c[3532030]|0}else{t=j}if((t|0)>0){j=c[1836236]|0;h=c[9757320+(j<<2)>>2]|0;if((h|0)!=0){k=h;gGC(k|0,9706056,76)|0}c[9752472+(j<<2)>>2]=c[2433530];c[14113936+(j<<2)>>2]=c[2076596];c[9669104+(j<<2)>>2]=c[3541536];c[1836236]=-1}f=g+f|0;e=i}i=c[2112964]|0;do{if((i|0)!=0){e=a[9688]|0?534:0;t=e-f|0;s=i+(f<<1<<1)|0;do{if((e|0)!=(f|0)){d=c[3532030]|0;if((d|0)>0){q=c[2439330]|0;if((q|0)!=0){r=q;gGC(9706056,r|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0}if(a[7460968]|0){gg[c[3542124]&4095](s,t);u=c[3532030]|0}else{u=d}if((u|0)<=0){break}d=c[1836236]|0;r=c[9757320+(d<<2)>>2]|0;if((r|0)!=0){q=r;gGC(q|0,9706056,76)|0}c[9752472+(d<<2)>>2]=c[2433530];c[14113936+(d<<2)>>2]=c[2076596];c[9669104+(d<<2)>>2]=c[3541536];c[1836236]=-1}}while(0);t=c[2112964]|0;if((t|0)==0){break}if((c[3532030]|0)>0){s=c[2439330]|0;if((s|0)!=0){e=s;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0}do{if((c[3532036]|0)!=0){Uz(0,t,a[9688]|0?534:0);if((c[3532036]|0)<=1){break}Uz(1,c[2112964]|0,a[9688]|0?534:0)}}while(0);if((c[3532030]|0)<=0){break}t=c[1836236]|0;e=c[9757320+(t<<2)>>2]|0;if((e|0)!=0){s=e;gGC(s|0,9706056,76)|0}c[9752472+(t<<2)>>2]=c[2433530];c[14113936+(t<<2)>>2]=c[2076596];c[9669104+(t<<2)>>2]=c[3541536];c[1836236]=-1}}while(0);if((c[2112968]|0)==0){return 0}gu[c[3532118]&16383]();return 0}function e0V(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5193940+(b*112|0)>>2];c[a+104>>2]=c[5193944+(b*112|0)>>2];c[a+108>>2]=c[5193948+(b*112|0)>>2];d=0;return d|0}function e0W(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=5193840+(b*112|0);e=0;return e|0}function e0X(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5189308+(b*112|0)>>2];c[a+104>>2]=c[5189312+(b*112|0)>>2];c[a+108>>2]=c[5189316+(b*112|0)>>2];d=0;return d|0}function e0Y(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=5189208+(b*112|0);e=0;return e|0}function e0Z(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5188004+(b*112|0)>>2];c[a+104>>2]=c[5188008+(b*112|0)>>2];c[a+108>>2]=c[5188012+(b*112|0)>>2];d=0;return d|0}function e0_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=5187904+(b*112|0);e=0;return e|0}function e0$(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>33){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5188800+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e00(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>29){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5190204+(b*112|0)>>2];c[a+104>>2]=c[5190208+(b*112|0)>>2];c[a+108>>2]=c[5190212+(b*112|0)>>2];d=0;return d|0}function e01(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<30&(d|0)==0)){e=1;return e|0}c[a>>2]=5190104+(b*112|0);e=0;return e|0}function e02(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>30){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5193464+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e03(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;c[3532162]=256;c[3532160]=4;c[3532142]=8;c[3532164]=8;c[3532148]=687240;c[3532140]=809208;c[3532138]=809176;c[3532042]=16384;c[3532002]=1024;c[3532e3]=4;a[7460944]=1;c[3532004]=16;c[3531998]=683192;c[3531992]=703624;c[3531990]=703560;c[3532034]=4096;c[3532044]=1;c[3532030]=2;a[7460968]=1;c[3532036]=2;eZ9(0)|0;c[3532048]=0;e1Z();d=c[3532046]|0;e=0;while(1){if((e|0)>=1024){break}f=9638528+(e<<2)|0;if((c[f>>2]|0)==0){g=39088;break}else{e=e+1|0}}do{if((g|0)==39088){e=gGq(d)|0;c[f>>2]=e;if((e|0)==0){break}gGz(e|0,0,d|0);c[3532048]=e;gGz(e|0,0,d|0);e1Z();if((eZ9(1)|0)!=0){i=1;return i|0}e=c[3532042]|0;j=0;while(1){if((j|0)>=1024){k=0;break}l=9638528+(j<<2)|0;if((c[l>>2]|0)==0){g=39094;break}else{j=j+1|0}}do{if((g|0)==39094){j=gGq(65536)|0;c[l>>2]=j;if((j|0)==0){k=0;break}gGz(j|0,0,65536);k=j}}while(0);c[3540978]=k;gGz(k|0,0,65536);c[2437030]=e;c[2438630]=0;c[2438626]=8;c[2427050]=0;c[2438628]=0;a[7461128]=1;c[3527054]=64;c[2437032]=0;c[3528994]=(c[3528994]|0)+1;j=c[3532034]|0;m=0;while(1){if((m|0)>=1024){n=0;break}o=9638528+(m<<2)|0;if((c[o>>2]|0)==0){g=39099;break}else{m=m+1|0}}do{if((g|0)==39099){m=gGq(16384)|0;c[o>>2]=m;if((m|0)==0){n=0;break}gGz(m|0,0,16384);n=m}}while(0);c[3540976]=n;gGz(n|0,0,16384);c[2437028]=j;c[2438624]=8;a[726072]=0;a[7461120]=1;a[7461080]=1;fxU(0,425984);if((c[2394]|0)==0){p=c[2112932]|0}else{c[2394]=0;m=c[3532596]|0;c[2112932]=m;e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060];p=m}m=c[3532204]|0;e=p|0;q=0;while(1){r=m+q|0;c[e>>2]=r;c[e+131072>>2]=r;r=q+1024|0;if(r>>>0>262143){break}else{e=e+4|0;q=r}}q=c[3532208]|0;e=p+4096|0;m=1048576;while(1){j=q+(m-1048576)|0;c[e>>2]=j;c[e+65536>>2]=j;c[e+131072>>2]=j;j=m+1024|0;if(j>>>0>1081343){break}else{e=e+4|0;m=j}}m=c[3532026]|0;c[p+8192>>2]=m;c[p+73728>>2]=m;c[p+139264>>2]=m;e=m+1024|0;c[p+8196>>2]=e;c[p+73732>>2]=e;c[p+139268>>2]=e;e=m+2048|0;c[p+8200>>2]=e;c[p+73736>>2]=e;c[p+139272>>2]=e;e=m+3072|0;c[p+8204>>2]=e;c[p+73740>>2]=e;c[p+139276>>2]=e;e=c[3540978]|0;m=p+49152|0;j=12582912;while(1){r=e+(j-12582912)|0;c[m>>2]=r;c[m+65536>>2]=r;c[m+131072>>2]=r;r=j+1024|0;if(r>>>0>12648447){break}else{m=m+4|0;j=r}}j=p+49408|0;m=12648448;while(1){e=q+(m-12615680)|0;c[j>>2]=e;c[j+65536>>2]=e;c[j+131072>>2]=e;e=m+1024|0;if(e>>>0>12713983){break}else{j=j+4|0;m=e}}m=c[3540976]|0;c[p+53248>>2]=m;c[p+118784>>2]=m;c[p+184320>>2]=m;j=m+1024|0;c[p+53252>>2]=j;c[p+118788>>2]=j;c[p+184324>>2]=j;j=m+2048|0;c[p+53256>>2]=j;c[p+118792>>2]=j;c[p+184328>>2]=j;j=m+3072|0;c[p+53260>>2]=j;c[p+118796>>2]=j;c[p+184332>>2]=j;j=m+4096|0;c[p+53264>>2]=j;c[p+118800>>2]=j;c[p+184336>>2]=j;j=m+5120|0;c[p+53268>>2]=j;c[p+118804>>2]=j;c[p+184340>>2]=j;j=m+6144|0;c[p+53272>>2]=j;c[p+118808>>2]=j;c[p+184344>>2]=j;j=m+7168|0;c[p+53276>>2]=j;c[p+118812>>2]=j;c[p+184348>>2]=j;j=m+8192|0;c[p+53280>>2]=j;c[p+118816>>2]=j;c[p+184352>>2]=j;j=m+9216|0;c[p+53284>>2]=j;c[p+118820>>2]=j;c[p+184356>>2]=j;j=m+10240|0;c[p+53288>>2]=j;c[p+118824>>2]=j;c[p+184360>>2]=j;j=m+11264|0;c[p+53292>>2]=j;c[p+118828>>2]=j;c[p+184364>>2]=j;j=m+12288|0;c[p+53296>>2]=j;c[p+118832>>2]=j;c[p+184368>>2]=j;j=m+13312|0;c[p+53300>>2]=j;c[p+118836>>2]=j;c[p+184372>>2]=j;j=m+14336|0;c[p+53304>>2]=j;c[p+118840>>2]=j;c[p+184376>>2]=j;j=m+15360|0;c[p+53308>>2]=j;c[p+118844>>2]=j;c[p+184380>>2]=j;c[p+196608>>2]=2406;c[p+196648>>2]=346;c[p+196688>>2]=502;c[p+196728>>2]=1606;j=c[3532592]|0;if((j|0)!=0){gGC(j|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);j=c[2439330]|0;m=(j|0)==0;if(!m){q=j;gGC(9706056,q|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];q=c[3528484]|0;c[2076596]=q;e=c[2417276]|0;c[3541536]=e;c[1836236]=0;c[j+4180>>2]=3280;c[j+4184>>2]=3382;r=c[3531932]|0;s=0;t=0;while(1){c[j+76+(t<<2)>>2]=r+(t<<8);u=s+1&65535;if((u&65535)>63){v=0;w=0;break}else{s=u;t=u&65535}}while(1){t=r+(w<<8)|0;c[j+76+(w+512<<2)>>2]=t;c[j+76+(w+768<<2)>>2]=t;t=v+1&65535;if((t&65535)>63){x=64;y=64;break}else{v=t;w=t&65535}}while(1){c[j+76+(y<<2)>>2]=r+(y<<8);t=x+1&65535;if((t&65535)>127){z=64;A=64;break}else{x=t;y=t&65535}}while(1){t=r+(A<<8)|0;c[j+76+(A+512<<2)>>2]=t;c[j+76+(A+768<<2)>>2]=t;t=z+1&65535;if((t&65535)>127){break}else{z=t;A=t&65535}}r=c[3531936]|0;c[j+588>>2]=r;c[j+592>>2]=r+256;c[j+596>>2]=r+512;c[j+600>>2]=r+768;c[j+604>>2]=r+1024;c[j+608>>2]=r+1280;c[j+612>>2]=r+1536;c[j+616>>2]=r+1792;c[j+620>>2]=r+2048;c[j+624>>2]=r+2304;c[j+628>>2]=r+2560;c[j+632>>2]=r+2816;c[j+636>>2]=r+3072;c[j+640>>2]=r+3328;c[j+644>>2]=r+3584;c[j+648>>2]=r+3840;t=128;s=128;while(1){c[j+76+(s+256<<2)>>2]=r+((s<<8)-32768);u=t+1&65535;if((u&65535)>143){B=128;C=128;break}else{t=u;s=u&65535}}while(1){s=r+((C<<8)-32768)|0;c[j+76+(C+512<<2)>>2]=s;c[j+76+(C+768<<2)>>2]=s;s=B+1&65535;if((s&65535)>143){break}else{B=s;C=s&65535}}if(!m){r=j;gGC(r|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=q;c[2417276]=e;c[1836236]=-1;fwR(1);r=c[2439331]|0;s=(r|0)==0;if(!s){t=r;gGC(9706056,t|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];t=c[3528485]|0;c[2076596]=t;u=c[2417277]|0;c[3541536]=u;c[1836236]=1;c[r+4180>>2]=1940;c[r+4184>>2]=2948;D=c[3531926]|0;E=0;F=0;while(1){c[r+76+(F<<2)>>2]=D+(F<<8);G=E+1&65535;if((G&65535)>127){H=0;I=0;break}else{E=G;F=G&65535}}while(1){F=D+(I<<8)|0;c[r+76+(I+512<<2)>>2]=F;c[r+76+(I+768<<2)>>2]=F;F=H+1&65535;if((F&65535)>127){break}else{H=F;I=F&65535}}D=c[3531934]|0;c[r+844>>2]=D;F=D+256|0;c[r+848>>2]=F;E=D+512|0;c[r+852>>2]=E;e=D+768|0;c[r+856>>2]=e;q=D+1024|0;c[r+860>>2]=q;j=D+1280|0;c[r+864>>2]=j;m=D+1536|0;c[r+868>>2]=m;G=D+1792|0;c[r+872>>2]=G;c[r+1868>>2]=D;c[r+1872>>2]=F;c[r+1876>>2]=E;c[r+1880>>2]=e;c[r+1884>>2]=q;c[r+1888>>2]=j;c[r+1892>>2]=m;c[r+1896>>2]=G;c[r+2892>>2]=D;c[r+3916>>2]=D;c[r+2896>>2]=F;c[r+3920>>2]=F;c[r+2900>>2]=E;c[r+3924>>2]=E;c[r+2904>>2]=e;c[r+3928>>2]=e;c[r+2908>>2]=q;c[r+3932>>2]=q;c[r+2912>>2]=j;c[r+3936>>2]=j;c[r+2916>>2]=m;c[r+3940>>2]=m;c[r+2920>>2]=G;c[r+3944>>2]=G;if(!s){G=r;gGC(G|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=t;c[2417277]=u;c[1836236]=-1;G=a[9680]|0;m=G?32e3:0;if(G){if(a[9624]|0){G=m*3|0;j=62500;while(1){if((j|0)>(G|0)){j=j>>1}else{J=1222;K=j;break}}}else{J=2462;K=m}c[2429380]=K;c[3542124]=J;mw(4e6,K);j=gGq(262144)|0;c[2406684]=j;gGz(j|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(4e6,11025)}j=c[3531464]|0;c[j+44344>>2]=1036;c[j+44348>>2]=2498;h[745421]=.75;c[2436794]=1;h[745420]=.75;c[2436792]=2;UB(0,3064,384e3,3170,5);UB(1,3064,384e3,3758,5);h[1207773]=.6;c[2415548]=3;c[2415126]=9665376;h[1208176]=.6;c[2416354]=3;j=c[642608+(c[2436]<<2)>>2]|0;G=c[j+128>>2]|0;if((c[j+52>>2]&4|0)==0){c[2113068]=G;u=c[j+132>>2]|0;c[2113070]=u;c[2443814]=G;c[2440436]=u;L=G;M=u}else{c[2113070]=G;u=c[j+132>>2]|0;c[2113068]=u;c[2440436]=G;c[2443814]=u;L=u;M=G}G=ag(L<<1,M)|0;u=gGq(G)|0;c[2112926]=u;if((u|0)!=0){gGz(u|0,0,G|0)}c[2113302]=1;a[801640]=0;G=c[642608+(c[2436]<<2)>>2]|0;u=c[G+128>>2]|0;if((c[G+52>>2]&4|0)==0){c[2440576]=u;j=c[G+132>>2]|0;c[2440574]=j;N=u;O=j}else{c[2440574]=u;j=c[G+132>>2]|0;c[2440576]=j;N=j;O=u}u=(((N|0)/2|0)<<8)-1792|0;j=(((O|0)/2|0)<<8)-2048|0;c[3542196]=u;c[3542192]=j;c[3542197]=u;c[3542193]=j;c[3542198]=u;c[3542194]=j;c[3542199]=u;c[3542195]=j;c[3532118]=12326;c[3532050]=4564;c[3532064]=5;c[2113026]=2e5;c[2113024]=66666;c[2113022]=66666;c[2433350]=-2;c[2433348]=17;c[3532016]=4126;e2t()|0;i=0;return i|0}}while(0);c[3532048]=0;i=1;return i|0}function e04(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3569116+(b*112|0)>>2];c[a+104>>2]=c[3569120+(b*112|0)>>2];c[a+108>>2]=c[3569124+(b*112|0)>>2];d=0;return d|0}function e05(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=3569016+(b*112|0);e=0;return e|0}function e06(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1205648+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function e07(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>42){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3570360+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e08(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0;c[3532162]=256;c[3532160]=4;c[3532142]=8;c[3532164]=8;c[3532148]=683968;c[3532140]=725912;c[3532138]=725880;c[3532042]=16384;c[3532002]=1024;c[3532e3]=4;a[7460944]=1;c[3532004]=16;c[3531998]=682232;c[3531992]=690968;c[3531990]=690904;c[3532034]=5120;c[3532044]=1;c[3532030]=1;a[7460968]=1;eZ9(0)|0;c[3532048]=0;e1Z();d=c[3532046]|0;e=0;while(1){if((e|0)>=1024){break}f=9638528+(e<<2)|0;if((c[f>>2]|0)==0){g=39183;break}else{e=e+1|0}}do{if((g|0)==39183){e=gGq(d)|0;c[f>>2]=e;if((e|0)==0){break}gGz(e|0,0,d|0);c[3532048]=e;gGz(e|0,0,d|0);e1Z();if((eZ9(1)|0)!=0){i=1;return i|0}e=c[3532042]|0;j=0;while(1){if((j|0)>=1024){k=0;break}l=9638528+(j<<2)|0;if((c[l>>2]|0)==0){g=39189;break}else{j=j+1|0}}do{if((g|0)==39189){j=gGq(65536)|0;c[l>>2]=j;if((j|0)==0){k=0;break}gGz(j|0,0,65536);k=j}}while(0);c[3540978]=k;gGz(k|0,0,65536);c[2437030]=e;c[2438630]=0;c[2438626]=16;c[2427050]=0;c[2438628]=0;a[7461128]=1;c[3527054]=64;c[2437032]=0;c[3528994]=(c[3528994]|0)+1;j=c[3532034]|0;m=0;while(1){if((m|0)>=1024){n=0;break}o=9638528+(m<<2)|0;if((c[o>>2]|0)==0){g=39194;break}else{m=m+1|0}}do{if((g|0)==39194){m=gGq(16384)|0;c[o>>2]=m;if((m|0)==0){n=0;break}gGz(m|0,0,16384);n=m}}while(0);c[3540976]=n;gGz(n|0,0,16384);c[2437028]=j;c[2438624]=16;a[726072]=0;a[7461120]=1;a[7461080]=1;fxU(0,425984);if((c[2394]|0)==0){p=c[2112932]|0}else{c[2394]=0;m=c[3532596]|0;c[2112932]=m;e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060];p=m}m=c[3532204]|0;e=p|0;q=0;while(1){r=m+q|0;c[e>>2]=r;c[e+131072>>2]=r;r=q+1024|0;if(r>>>0>524287){break}else{e=e+4|0;q=r}}q=c[3532208]|0;c[p+4288>>2]=q;c[p+69824>>2]=q;c[p+135360>>2]=q;e=q+1024|0;c[p+4292>>2]=e;c[p+69828>>2]=e;c[p+135364>>2]=e;e=q+2048|0;c[p+4296>>2]=e;c[p+69832>>2]=e;c[p+135368>>2]=e;e=q+3072|0;c[p+4300>>2]=e;c[p+69836>>2]=e;c[p+135372>>2]=e;e=q+4096|0;c[p+4304>>2]=e;c[p+69840>>2]=e;c[p+135376>>2]=e;e=q+5120|0;c[p+4308>>2]=e;c[p+69844>>2]=e;c[p+135380>>2]=e;e=q+6144|0;c[p+4312>>2]=e;c[p+69848>>2]=e;c[p+135384>>2]=e;e=q+7168|0;c[p+4316>>2]=e;c[p+69852>>2]=e;c[p+135388>>2]=e;e=q+8192|0;c[p+4320>>2]=e;c[p+69856>>2]=e;c[p+135392>>2]=e;e=q+9216|0;c[p+4324>>2]=e;c[p+69860>>2]=e;c[p+135396>>2]=e;e=q+10240|0;c[p+4328>>2]=e;c[p+69864>>2]=e;c[p+135400>>2]=e;e=q+11264|0;c[p+4332>>2]=e;c[p+69868>>2]=e;c[p+135404>>2]=e;e=q+12288|0;c[p+4336>>2]=e;c[p+69872>>2]=e;c[p+135408>>2]=e;e=q+13312|0;c[p+4340>>2]=e;c[p+69876>>2]=e;c[p+135412>>2]=e;e=q+14336|0;c[p+4344>>2]=e;c[p+69880>>2]=e;c[p+135416>>2]=e;e=q+15360|0;c[p+4348>>2]=e;c[p+69884>>2]=e;c[p+135420>>2]=e;e=c[3532026]|0;c[p+8192>>2]=e;c[p+73728>>2]=e;c[p+139264>>2]=e;m=e+1024|0;c[p+8196>>2]=m;c[p+73732>>2]=m;c[p+139268>>2]=m;m=e+2048|0;c[p+8200>>2]=m;c[p+73736>>2]=m;c[p+139272>>2]=m;m=e+3072|0;c[p+8204>>2]=m;c[p+73740>>2]=m;c[p+139276>>2]=m;m=q+16384|0;c[p+8208>>2]=m;c[p+73744>>2]=m;c[p+139280>>2]=m;m=q+17408|0;c[p+8212>>2]=m;c[p+73748>>2]=m;c[p+139284>>2]=m;m=q+18432|0;c[p+8216>>2]=m;c[p+73752>>2]=m;c[p+139288>>2]=m;m=q+19456|0;c[p+8220>>2]=m;c[p+73756>>2]=m;c[p+139292>>2]=m;m=q+20480|0;c[p+8224>>2]=m;c[p+73760>>2]=m;c[p+139296>>2]=m;m=q+21504|0;c[p+8228>>2]=m;c[p+73764>>2]=m;c[p+139300>>2]=m;m=q+22528|0;c[p+8232>>2]=m;c[p+73768>>2]=m;c[p+139304>>2]=m;m=q+23552|0;c[p+8236>>2]=m;c[p+73772>>2]=m;c[p+139308>>2]=m;m=q+24576|0;c[p+8240>>2]=m;c[p+73776>>2]=m;c[p+139312>>2]=m;m=q+25600|0;c[p+8244>>2]=m;c[p+73780>>2]=m;c[p+139316>>2]=m;m=q+26624|0;c[p+8248>>2]=m;c[p+73784>>2]=m;c[p+139320>>2]=m;m=q+27648|0;c[p+8252>>2]=m;c[p+73788>>2]=m;c[p+139324>>2]=m;m=c[3540978]|0;q=p+49152|0;e=12582912;while(1){j=m+(e-12582912)|0;c[q>>2]=j;c[q+65536>>2]=j;c[q+131072>>2]=j;j=e+1024|0;if(j>>>0>12648447){break}else{q=q+4|0;e=j}}e=c[3540976]|0;c[p+53248>>2]=e;c[p+118784>>2]=e;c[p+184320>>2]=e;q=e+1024|0;c[p+53252>>2]=q;c[p+118788>>2]=q;c[p+184324>>2]=q;q=e+2048|0;c[p+53256>>2]=q;c[p+118792>>2]=q;c[p+184328>>2]=q;q=e+3072|0;c[p+53260>>2]=q;c[p+118796>>2]=q;c[p+184332>>2]=q;q=e+4096|0;c[p+53264>>2]=q;c[p+118800>>2]=q;c[p+184336>>2]=q;q=e+5120|0;c[p+53268>>2]=q;c[p+118804>>2]=q;c[p+184340>>2]=q;q=e+6144|0;c[p+53272>>2]=q;c[p+118808>>2]=q;c[p+184344>>2]=q;q=e+7168|0;c[p+53276>>2]=q;c[p+118812>>2]=q;c[p+184348>>2]=q;q=e+8192|0;c[p+53280>>2]=q;c[p+118816>>2]=q;c[p+184352>>2]=q;q=e+9216|0;c[p+53284>>2]=q;c[p+118820>>2]=q;c[p+184356>>2]=q;q=e+10240|0;c[p+53288>>2]=q;c[p+118824>>2]=q;c[p+184360>>2]=q;q=e+11264|0;c[p+53292>>2]=q;c[p+118828>>2]=q;c[p+184364>>2]=q;q=e+12288|0;c[p+53296>>2]=q;c[p+118832>>2]=q;c[p+184368>>2]=q;q=e+13312|0;c[p+53300>>2]=q;c[p+118836>>2]=q;c[p+184372>>2]=q;q=e+14336|0;c[p+53304>>2]=q;c[p+118840>>2]=q;c[p+184376>>2]=q;q=e+15360|0;c[p+53308>>2]=q;c[p+118844>>2]=q;c[p+184380>>2]=q;c[p+196608>>2]=830;c[p+196648>>2]=62;c[p+196688>>2]=1332;c[p+196728>>2]=1476;q=c[3532592]|0;if((q|0)!=0){gGC(q|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);q=c[2439330]|0;e=(q|0)==0;if(!e){m=q;gGC(9706056,m|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];m=c[3528484]|0;c[2076596]=m;j=c[2417276]|0;c[3541536]=j;c[1836236]=0;c[q+4180>>2]=408;c[q+4184>>2]=2472;r=c[3531932]|0;s=0;t=0;while(1){c[q+76+(t<<2)>>2]=r+(t<<8);u=s+1&65535;if((u&65535)>63){v=0;w=0;break}else{s=u;t=u&65535}}while(1){t=r+(w<<8)|0;c[q+76+(w+512<<2)>>2]=t;c[q+76+(w+768<<2)>>2]=t;t=v+1&65535;if((t&65535)>63){x=64;y=64;break}else{v=t;w=t&65535}}while(1){c[q+76+(y<<2)>>2]=r+(y<<8);t=x+1&65535;if((t&65535)>127){z=64;A=64;break}else{x=t;y=t&65535}}while(1){t=r+(A<<8)|0;c[q+76+(A+512<<2)>>2]=t;c[q+76+(A+768<<2)>>2]=t;t=z+1&65535;if((t&65535)>127){break}else{z=t;A=t&65535}}r=c[3531936]|0;c[q+588>>2]=r;c[q+592>>2]=r+256;c[q+596>>2]=r+512;c[q+600>>2]=r+768;c[q+604>>2]=r+1024;c[q+608>>2]=r+1280;c[q+612>>2]=r+1536;c[q+616>>2]=r+1792;c[q+620>>2]=r+2048;c[q+624>>2]=r+2304;c[q+628>>2]=r+2560;c[q+632>>2]=r+2816;c[q+636>>2]=r+3072;c[q+640>>2]=r+3328;c[q+644>>2]=r+3584;c[q+648>>2]=r+3840;t=128;s=128;while(1){c[q+76+(s+256<<2)>>2]=r+((s<<8)-32768);u=t+1&65535;if((u&65535)>143){B=128;C=128;break}else{t=u;s=u&65535}}while(1){s=r+((C<<8)-32768)|0;c[q+76+(C+512<<2)>>2]=s;c[q+76+(C+768<<2)>>2]=s;s=B+1&65535;if((s&65535)>143){break}else{B=s;C=s&65535}}if(!e){r=q;gGC(r|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=m;c[2417276]=j;c[1836236]=-1;r=a[9680]|0;s=r?32e3:0;if(r){if(a[9624]|0){r=s*3|0;t=62500;while(1){if((t|0)>(r|0)){t=t>>1}else{D=1222;E=t;break}}}else{D=2462;E=s}c[2429380]=E;c[3542124]=D;mw(4e6,E);t=gGq(262144)|0;c[2406684]=t;gGz(t|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(4e6,11025)}t=c[3531464]|0;c[t+44344>>2]=1036;c[t+44348>>2]=2498;h[745421]=.5;c[2436794]=3;h[745420]=.5;c[2436792]=3;t=c[642608+(c[2436]<<2)>>2]|0;r=c[t+128>>2]|0;if((c[t+52>>2]&4|0)==0){c[2113068]=r;j=c[t+132>>2]|0;c[2113070]=j;c[2443814]=r;c[2440436]=j;F=r;G=j}else{c[2113070]=r;j=c[t+132>>2]|0;c[2113068]=j;c[2440436]=r;c[2443814]=j;F=j;G=r}r=ag(F<<1,G)|0;j=gGq(r)|0;c[2112926]=j;if((j|0)!=0){gGz(j|0,0,r|0)}c[3532118]=4492;c[3532050]=3592;c[3532064]=4;c[2113026]=133333;c[2113024]=66666;c[2443344]=(fa(c[c[642608+(c[2436]<<2)>>2]>>2]|0,353576)|0)==0;r=0;while(1){if((r|0)>=1024){H=0;break}I=9638528+(r<<2)|0;if((c[I>>2]|0)==0){g=39233;break}else{r=r+1|0}}do{if((g|0)==39233){r=gGq(1024)|0;c[I>>2]=r;if((r|0)==0){H=0;break}gGz(r|0,0,1024);H=r}}while(0);c[2424896]=H;gGz(H|0,0,1024);r=0;while(1){if((r|0)>=1024){J=0;break}K=9638528+(r<<2)|0;if((c[K>>2]|0)==0){g=39238;break}else{r=r+1|0}}do{if((g|0)==39238){r=gGq(1024)|0;c[K>>2]=r;if((r|0)==0){J=0;break}gGz(r|0,0,1024);J=r}}while(0);c[2424897]=J;gGz(J|0,0,1024);r=0;while(1){if((r|0)>=1024){L=0;break}M=9638528+(r<<2)|0;if((c[M>>2]|0)==0){g=39243;break}else{r=r+1|0}}do{if((g|0)==39243){r=gGq(1024)|0;c[M>>2]=r;if((r|0)==0){L=0;break}gGz(r|0,0,1024);L=r}}while(0);c[2424898]=L;gGz(L|0,0,1024);r=0;while(1){if((r|0)>=1024){N=0;break}O=9638528+(r<<2)|0;if((c[O>>2]|0)==0){g=39248;break}else{r=r+1|0}}do{if((g|0)==39248){r=gGq(1024)|0;c[O>>2]=r;if((r|0)==0){N=0;break}gGz(r|0,0,1024);N=r}}while(0);c[2424899]=N;gGz(N|0,0,1024);r=0;while(1){if((r|0)>=1024){P=0;break}Q=9638528+(r<<2)|0;if((c[Q>>2]|0)==0){g=39253;break}else{r=r+1|0}}do{if((g|0)==39253){r=gGq(1024)|0;c[Q>>2]=r;if((r|0)==0){P=0;break}gGz(r|0,0,1024);P=r}}while(0);c[2424900]=P;gGz(P|0,0,1024);r=0;while(1){if((r|0)>=1024){R=0;break}S=9638528+(r<<2)|0;if((c[S>>2]|0)==0){g=39258;break}else{r=r+1|0}}do{if((g|0)==39258){r=gGq(1024)|0;c[S>>2]=r;if((r|0)==0){R=0;break}gGz(r|0,0,1024);R=r}}while(0);c[2424901]=R;gGz(R|0,0,1024);r=0;while(1){if((r|0)>=1024){T=0;break}U=9638528+(r<<2)|0;if((c[U>>2]|0)==0){g=39263;break}else{r=r+1|0}}do{if((g|0)==39263){r=gGq(1024)|0;c[U>>2]=r;if((r|0)==0){T=0;break}gGz(r|0,0,1024);T=r}}while(0);c[2424902]=T;gGz(T|0,0,1024);r=0;while(1){if((r|0)>=1024){V=0;break}W=9638528+(r<<2)|0;if((c[W>>2]|0)==0){g=39268;break}else{r=r+1|0}}do{if((g|0)==39268){r=gGq(1024)|0;c[W>>2]=r;if((r|0)==0){V=0;break}gGz(r|0,0,1024);V=r}}while(0);c[2424903]=V;gGz(V|0,0,1024);a[7461112]=1;c[3532016]=418;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];r=c[3532592]|0;if((r|0)!=0){gGC(9104152,r|0,280)|0}c[2113054]=c[2113060]}RI();r=c[2394]|0;s=c[14130368+(r<<2)>>2]|0;if((s|0)!=0){gGC(s|0,9104152,280)|0}c[8452240+(r<<2)>>2]=c[2113054];c[2394]=-1;r=c[2439330]|0;s=(r|0)==0;if(!s){j=r;gGC(9706056,j|0,76)|0}j=c[2438118]|0;c[2433530]=j;t=c[3528484]|0;c[2076596]=t;m=c[2417276]|0;c[3541536]=m;c[1836236]=0;gGz(9706056,0,76);if(s){c[2438118]=j;c[3528484]=t;c[2417276]=m;c[1836236]=-1;X=0}else{s=r;gGC(s|0,9706056,76)|0;c[2438118]=j;c[3528484]=t;c[2417276]=m;c[1836236]=-1;X=c[2426515]&65535}b[4853030]=X;c[2433530]=j;c[2076596]=t;c[3541536]=m;c[1836236]=0;mx(0);m=c[1836236]|0;t=c[9757320+(m<<2)>>2]|0;if((t|0)!=0){j=t;gGC(j|0,9706056,76)|0}c[9752472+(m<<2)>>2]=c[2433530];c[14113936+(m<<2)>>2]=c[2076596];c[9669104+(m<<2)>>2]=c[3541536];c[1836236]=-1;i=0;return i|0}}while(0);c[3532048]=0;i=1;return i|0}function e09(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1755748+(b*112|0)>>2];c[a+104>>2]=c[1755752+(b*112|0)>>2];c[a+108>>2]=c[1755756+(b*112|0)>>2];d=0;return d|0}function e1a(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=1755648+(b*112|0);e=0;return e|0}function e1b(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1757092+(b*112|0)>>2];c[a+104>>2]=c[1757096+(b*112|0)>>2];c[a+108>>2]=c[1757100+(b*112|0)>>2];d=0;return d|0}function e1c(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=1756992+(b*112|0);e=0;return e|0}function e1d(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>27){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5335532+(b*112|0)>>2];c[a+104>>2]=c[5335536+(b*112|0)>>2];c[a+108>>2]=c[5335540+(b*112|0)>>2];d=0;return d|0}function e1e(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<28&(d|0)==0)){e=1;return e|0}c[a>>2]=5335432+(b*112|0);e=0;return e|0}function e1f(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1867520+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function e1g(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>30){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5338568+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e1h(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;c[3532162]=64;c[3532160]=4;c[3532142]=8;c[3532164]=8;c[3532148]=687272;c[3532140]=809592;c[3532138]=809560;c[3532042]=16384;c[3532002]=256;c[3532e3]=4;a[7460944]=1;c[3532004]=16;c[3531998]=683240;c[3531992]=704016;c[3531990]=703952;a[7460952]=1;c[3532034]=5120;c[3532044]=1;c[3532030]=1;c[3532032]=2;eZ9(0)|0;c[3532048]=0;e1Z();d=c[3532046]|0;e=0;while(1){if((e|0)>=1024){break}f=9638528+(e<<2)|0;if((c[f>>2]|0)==0){g=39341;break}else{e=e+1|0}}do{if((g|0)==39341){e=gGq(d)|0;c[f>>2]=e;if((e|0)==0){break}gGz(e|0,0,d|0);c[3532048]=e;gGz(e|0,0,d|0);e1Z();if((eZ9(1)|0)!=0){i=1;return i|0}e=c[3532042]|0;j=0;while(1){if((j|0)>=1024){k=0;break}l=9638528+(j<<2)|0;if((c[l>>2]|0)==0){g=39347;break}else{j=j+1|0}}do{if((g|0)==39347){j=gGq(65536)|0;c[l>>2]=j;if((j|0)==0){k=0;break}gGz(j|0,0,65536);k=j}}while(0);c[3540978]=k;gGz(k|0,0,65536);c[2437030]=e;c[2438630]=0;c[2438626]=16;c[2427050]=0;c[2438628]=1;a[7461128]=1;c[3527054]=64;c[2437032]=0;c[3528994]=(c[3528994]|0)+1;fxU(0,425984);if((c[2394]|0)==0){m=c[2112932]|0}else{c[2394]=0;j=c[3532596]|0;c[2112932]=j;n=c[3532592]|0;if((n|0)!=0){gGC(9104152,n|0,280)|0}c[2113054]=c[2113060];m=j}j=c[3532204]|0;n=m|0;o=0;while(1){p=j+o|0;c[n>>2]=p;c[n+131072>>2]=p;p=o+1024|0;if(p>>>0>655359){break}else{n=n+4|0;o=p}}o=c[3532208]|0;c[m+4288>>2]=o;c[m+69824>>2]=o;c[m+135360>>2]=o;n=o+1024|0;c[m+4292>>2]=n;c[m+69828>>2]=n;c[m+135364>>2]=n;n=o+2048|0;c[m+4296>>2]=n;c[m+69832>>2]=n;c[m+135368>>2]=n;n=o+3072|0;c[m+4300>>2]=n;c[m+69836>>2]=n;c[m+135372>>2]=n;n=o+4096|0;c[m+4304>>2]=n;c[m+69840>>2]=n;c[m+135376>>2]=n;n=o+5120|0;c[m+4308>>2]=n;c[m+69844>>2]=n;c[m+135380>>2]=n;n=o+6144|0;c[m+4312>>2]=n;c[m+69848>>2]=n;c[m+135384>>2]=n;n=o+7168|0;c[m+4316>>2]=n;c[m+69852>>2]=n;c[m+135388>>2]=n;n=o+8192|0;c[m+4320>>2]=n;c[m+69856>>2]=n;c[m+135392>>2]=n;n=o+9216|0;c[m+4324>>2]=n;c[m+69860>>2]=n;c[m+135396>>2]=n;n=o+10240|0;c[m+4328>>2]=n;c[m+69864>>2]=n;c[m+135400>>2]=n;n=o+11264|0;c[m+4332>>2]=n;c[m+69868>>2]=n;c[m+135404>>2]=n;n=o+12288|0;c[m+4336>>2]=n;c[m+69872>>2]=n;c[m+135408>>2]=n;n=o+13312|0;c[m+4340>>2]=n;c[m+69876>>2]=n;c[m+135412>>2]=n;n=o+14336|0;c[m+4344>>2]=n;c[m+69880>>2]=n;c[m+135416>>2]=n;n=o+15360|0;c[m+4348>>2]=n;c[m+69884>>2]=n;c[m+135420>>2]=n;n=c[3532026]|0;c[m+8192>>2]=n;c[m+73728>>2]=n;c[m+139264>>2]=n;j=n+1024|0;c[m+8196>>2]=j;c[m+73732>>2]=j;c[m+139268>>2]=j;j=n+2048|0;c[m+8200>>2]=j;c[m+73736>>2]=j;c[m+139272>>2]=j;j=n+3072|0;c[m+8204>>2]=j;c[m+73740>>2]=j;c[m+139276>>2]=j;j=o+16384|0;c[m+8208>>2]=j;c[m+73744>>2]=j;c[m+139280>>2]=j;j=o+17408|0;c[m+8212>>2]=j;c[m+73748>>2]=j;c[m+139284>>2]=j;j=o+18432|0;c[m+8216>>2]=j;c[m+73752>>2]=j;c[m+139288>>2]=j;j=o+19456|0;c[m+8220>>2]=j;c[m+73756>>2]=j;c[m+139292>>2]=j;j=o+20480|0;c[m+8224>>2]=j;c[m+73760>>2]=j;c[m+139296>>2]=j;j=o+21504|0;c[m+8228>>2]=j;c[m+73764>>2]=j;c[m+139300>>2]=j;j=o+22528|0;c[m+8232>>2]=j;c[m+73768>>2]=j;c[m+139304>>2]=j;j=o+23552|0;c[m+8236>>2]=j;c[m+73772>>2]=j;c[m+139308>>2]=j;j=o+24576|0;c[m+8240>>2]=j;c[m+73776>>2]=j;c[m+139312>>2]=j;j=o+25600|0;c[m+8244>>2]=j;c[m+73780>>2]=j;c[m+139316>>2]=j;j=o+26624|0;c[m+8248>>2]=j;c[m+73784>>2]=j;c[m+139320>>2]=j;j=o+27648|0;c[m+8252>>2]=j;c[m+73788>>2]=j;c[m+139324>>2]=j;j=c[3531970]|0;c[m+17408>>2]=j;c[m+82944>>2]=j;c[m+148480>>2]=j;o=j+1024|0;c[m+17412>>2]=o;c[m+82948>>2]=o;c[m+148484>>2]=o;o=c[3540978]|0;n=m+49152|0;e=12582912;while(1){p=o+(e-12582912)|0;c[n>>2]=p;c[n+65536>>2]=p;c[n+131072>>2]=p;p=e+1024|0;if(p>>>0>12648447){break}else{n=n+4|0;e=p}}e=j+2048|0;c[m+53248>>2]=e;c[m+118784>>2]=e;c[m+184320>>2]=e;e=j+3072|0;c[m+53252>>2]=e;c[m+118788>>2]=e;c[m+184324>>2]=e;e=j+4096|0;c[m+53256>>2]=e;c[m+118792>>2]=e;c[m+184328>>2]=e;e=j+5120|0;c[m+53260>>2]=e;c[m+118796>>2]=e;c[m+184332>>2]=e;e=j+6144|0;c[m+53264>>2]=e;c[m+118800>>2]=e;c[m+184336>>2]=e;e=j+7168|0;c[m+53268>>2]=e;c[m+118804>>2]=e;c[m+184340>>2]=e;e=j+8192|0;c[m+53272>>2]=e;c[m+118808>>2]=e;c[m+184344>>2]=e;e=j+9216|0;c[m+53276>>2]=e;c[m+118812>>2]=e;c[m+184348>>2]=e;c[m+196608>>2]=466;c[m+196648>>2]=166;c[m+196688>>2]=2958;c[m+196728>>2]=2242;e=c[3532592]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);e=c[2439330]|0;n=(e|0)==0;if(!n){o=e;gGC(9706056,o|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];o=c[3528484]|0;c[2076596]=o;p=c[2417276]|0;c[3541536]=p;c[1836236]=0;c[e+4180>>2]=1480;c[e+4184>>2]=1520;q=c[3531932]|0;r=0;s=0;while(1){c[e+76+(s<<2)>>2]=q+(s<<8);t=r+1&65535;if((t&65535)>127){u=0;v=0;break}else{r=t;s=t&65535}}while(1){s=q+(v<<8)|0;c[e+76+(v+512<<2)>>2]=s;c[e+76+(v+768<<2)>>2]=s;s=u+1&65535;if((s&65535)>127){break}else{u=s;v=s&65535}}s=c[3531936]|0;c[e+588>>2]=s;c[e+592>>2]=s+256;c[e+596>>2]=s+512;c[e+600>>2]=s+768;c[e+604>>2]=s+1024;c[e+608>>2]=s+1280;c[e+612>>2]=s+1536;c[e+616>>2]=s+1792;c[e+620>>2]=s+2048;c[e+624>>2]=s+2304;c[e+628>>2]=s+2560;c[e+632>>2]=s+2816;c[e+636>>2]=s+3072;c[e+640>>2]=s+3328;c[e+644>>2]=s+3584;c[e+648>>2]=s+3840;r=128;j=128;while(1){c[e+76+(j+256<<2)>>2]=s+((j<<8)-32768);t=r+1&65535;if((t&65535)>143){w=128;x=128;break}else{r=t;j=t&65535}}while(1){j=s+((x<<8)-32768)|0;c[e+76+(x+512<<2)>>2]=j;c[e+76+(x+768<<2)>>2]=j;j=w+1&65535;if((j&65535)>143){y=192;z=192;break}else{w=j;x=j&65535}}while(1){c[e+76+(z<<2)>>2]=q+(z<<8);s=y+1&65535;if((s&65535)>255){A=192;B=192;break}else{y=s;z=s&65535}}while(1){s=q+(B<<8)|0;c[e+76+(B+512<<2)>>2]=s;c[e+76+(B+768<<2)>>2]=s;s=A+1&65535;if((s&65535)>255){break}else{A=s;B=s&65535}}if(!n){q=e;gGC(q|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=o;c[2417276]=p;c[1836236]=-1;Vr(2,3579545,0,3064,82,0);c[2438228]=4e6;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=511;h[745419]=.3;a[3203368]=1;h[745418]=.3;a[3203360]=1;h[745417]=.3;a[3203352]=1;h[745416]=.3;a[3203344]=1;h[745415]=.3;a[3203336]=1;h[745414]=.3;a[3203328]=1;h[745413]=.3;a[3203320]=1;h[745412]=.3;a[3203312]=1;q=c[642608+(c[2436]<<2)>>2]|0;s=c[q+128>>2]|0;if((c[q+52>>2]&4|0)==0){c[2113068]=s;j=c[q+132>>2]|0;c[2113070]=j;c[2443814]=s;c[2440436]=j;C=s;D=j}else{c[2113070]=s;j=c[q+132>>2]|0;c[2113068]=j;c[2440436]=s;c[2443814]=j;C=j;D=s}s=ag(C<<1,D)|0;j=gGq(s)|0;c[2112926]=j;if((j|0)!=0){gGz(j|0,0,s|0)}c[3532118]=1402;c[3532050]=11756;c[3532064]=4;c[2427050]=15;c[2113026]=133333;c[2113024]=66666;c[3532016]=300;eZ8()|0;i=0;return i|0}}while(0);c[3532048]=0;i=1;return i|0}function e1i(){var d=0,e=0,f=0,g=0,h=0;if((a[14128072]|0)!=0){d=c[3532016]|0;gD[d&8191]()|0}gu[c[3532050]&16383]();c[2113031]=0;c[2113030]=0;d=c[2392]|0;if((d|0)>=0){gGz(8452240,0,((d|0)>0?(d<<2)+4|0:4)|0)}c[2113054]=0;d=c[2385548]|0;if((d|0)>0){gGz(9752472,0,((d|0)>1?d<<2:4)|0)}c[2433530]=0;d=0;while(1){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060]}e=d+1|0;f=(ag(c[2113026]|0,e)|0)/100|0;g=f-(c[2113030]|0)|0;c[2113028]=g;c[2113056]=g;f=RG(g)|0;c[2113054]=(c[2113054]|0)+f;c[2276108]=-1;c[2113056]=-1;c[2113030]=(c[2113030]|0)+f;do{if((d|0)==99){f=c[3532064]|0;c[8452200+(c[2394]<<2)>>2]=f|8192;g=c[2276080]|0;h=f<<8;c[2276080]=h;if((g|0)!=1792&(h|0)==1792){RH(7);break}if(h>>>0<=(c[2276079]|0)>>>0){break}RH(f&16777215)}}while(0);f=c[2394]|0;h=c[14130368+(f<<2)>>2]|0;if((h|0)!=0){gGC(h|0,9104152,280)|0}c[8452240+(f<<2)>>2]=c[2113054];c[2394]=-1;f=c[2439330]|0;if((f|0)!=0){h=f;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;Sb(ag((c[2113024]|0)/100|0,d)|0);h=c[1836236]|0;f=c[9757320+(h<<2)>>2]|0;if((f|0)!=0){g=f;gGC(g|0,9706056,76)|0}c[9752472+(h<<2)>>2]=c[2433530];c[14113936+(h<<2)>>2]=c[2076596];c[9669104+(h<<2)>>2]=c[3541536];c[1836236]=-1;if((e|0)<100){d=e}else{break}}d=c[2439330]|0;if((d|0)!=0){h=d;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;h=c[2113024]|0;d=gGU(h,(h|0)<0|0?-1:0,2048e6,0)|0;g=c[2438228]|0;f=gGS(d,K,g,(g|0)<0|0?-1:0)|0;g=f;Sb(h);h=c[2443830]|0;if((h|0)<1073676288){c[2443830]=h-g}h=c[2443831]|0;if((h|0)<1073676288){c[2443831]=h-g}h=(c[3528512]|0)-g|0;c[3528512]=(h|0)<0?0:h;h=c[2112964]|0;if((h|0)!=0){gg[c[3542122]&4095](h,a[9688]|0?534:0)}h=c[1836236]|0;g=c[9757320+(h<<2)>>2]|0;if((g|0)!=0){f=g;gGC(f|0,9706056,76)|0}c[9752472+(h<<2)>>2]=c[2433530];c[14113936+(h<<2)>>2]=c[2076596];c[9669104+(h<<2)>>2]=c[3541536];c[1836236]=-1;if((c[2112968]|0)==0){return 0}gu[c[3532118]&16383]();return 0}function e1j(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6155460+(b*112|0)>>2];c[a+104>>2]=c[6155464+(b*112|0)>>2];c[a+108>>2]=c[6155468+(b*112|0)>>2];d=0;return d|0}function e1k(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=6155360+(b*112|0);e=0;return e|0}function e1l(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3577168+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function e1m(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>41){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6157152+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e1n(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;c[3532162]=128;c[3532160]=4;c[3532142]=8;c[3532164]=8;c[3532148]=691032;c[3532140]=963880;c[3532138]=963848;c[3532042]=16384;c[3532002]=512;c[3532e3]=4;a[7460944]=1;c[3532004]=16;c[3531998]=683984;c[3531992]=726008;c[3531990]=725944;c[3532034]=4096;c[3532044]=1;c[3532030]=1;a[7460968]=1;c[3532036]=1;eZ9(0)|0;c[3532048]=0;e1Z();d=c[3532046]|0;e=0;while(1){if((e|0)>=1024){break}f=9638528+(e<<2)|0;if((c[f>>2]|0)==0){g=39449;break}else{e=e+1|0}}do{if((g|0)==39449){e=gGq(d)|0;c[f>>2]=e;if((e|0)==0){break}gGz(e|0,0,d|0);c[3532048]=e;gGz(e|0,0,d|0);e1Z();if((eZ9(1)|0)!=0){i=1;return i|0}e=c[3532042]|0;j=0;while(1){if((j|0)>=1024){k=0;break}l=9638528+(j<<2)|0;if((c[l>>2]|0)==0){g=39455;break}else{j=j+1|0}}do{if((g|0)==39455){j=gGq(65536)|0;c[l>>2]=j;if((j|0)==0){k=0;break}gGz(j|0,0,65536);k=j}}while(0);c[3540978]=k;gGz(k|0,0,65536);c[2437030]=e;c[2438630]=0;c[2438626]=8;c[2427050]=0;c[2438628]=0;a[7461128]=1;c[3527054]=64;c[2437032]=0;c[3528994]=(c[3528994]|0)+1;j=c[3532034]|0;m=0;while(1){if((m|0)>=1024){n=0;break}o=9638528+(m<<2)|0;if((c[o>>2]|0)==0){g=39460;break}else{m=m+1|0}}do{if((g|0)==39460){m=gGq(16384)|0;c[o>>2]=m;if((m|0)==0){n=0;break}gGz(m|0,0,16384);n=m}}while(0);c[3540976]=n;gGz(n|0,0,16384);c[2437028]=j;c[2438624]=8;a[726072]=0;a[7461120]=1;a[7461080]=1;fxU(0,425984);if((c[2394]|0)==0){p=c[2112932]|0}else{c[2394]=0;m=c[3532596]|0;c[2112932]=m;e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060];p=m}m=c[3532204]|0;e=p|0;q=0;while(1){r=m+q|0;c[e>>2]=r;c[e+131072>>2]=r;r=q+1024|0;if(r>>>0>393215){break}else{e=e+4|0;q=r}}q=c[3532208]|0;c[p+4288>>2]=q;c[p+69824>>2]=q;c[p+135360>>2]=q;e=q+1024|0;c[p+4292>>2]=e;c[p+69828>>2]=e;c[p+135364>>2]=e;e=q+2048|0;c[p+4296>>2]=e;c[p+69832>>2]=e;c[p+135368>>2]=e;e=q+3072|0;c[p+4300>>2]=e;c[p+69836>>2]=e;c[p+135372>>2]=e;e=q+4096|0;c[p+4304>>2]=e;c[p+69840>>2]=e;c[p+135376>>2]=e;e=q+5120|0;c[p+4308>>2]=e;c[p+69844>>2]=e;c[p+135380>>2]=e;e=q+6144|0;c[p+4312>>2]=e;c[p+69848>>2]=e;c[p+135384>>2]=e;e=q+7168|0;c[p+4316>>2]=e;c[p+69852>>2]=e;c[p+135388>>2]=e;e=q+8192|0;c[p+4320>>2]=e;c[p+69856>>2]=e;c[p+135392>>2]=e;e=q+9216|0;c[p+4324>>2]=e;c[p+69860>>2]=e;c[p+135396>>2]=e;e=q+10240|0;c[p+4328>>2]=e;c[p+69864>>2]=e;c[p+135400>>2]=e;e=q+11264|0;c[p+4332>>2]=e;c[p+69868>>2]=e;c[p+135404>>2]=e;e=q+12288|0;c[p+4336>>2]=e;c[p+69872>>2]=e;c[p+135408>>2]=e;e=q+13312|0;c[p+4340>>2]=e;c[p+69876>>2]=e;c[p+135412>>2]=e;e=q+14336|0;c[p+4344>>2]=e;c[p+69880>>2]=e;c[p+135416>>2]=e;e=q+15360|0;c[p+4348>>2]=e;c[p+69884>>2]=e;c[p+135420>>2]=e;e=c[3532026]|0;c[p+8192>>2]=e;c[p+73728>>2]=e;c[p+139264>>2]=e;q=e+1024|0;c[p+8196>>2]=q;c[p+73732>>2]=q;c[p+139268>>2]=q;q=e+2048|0;c[p+8200>>2]=q;c[p+73736>>2]=q;c[p+139272>>2]=q;q=e+3072|0;c[p+8204>>2]=q;c[p+73740>>2]=q;c[p+139276>>2]=q;q=c[3540978]|0;e=p+49152|0;m=12582912;while(1){j=q+(m-12582912)|0;c[e>>2]=j;c[e+65536>>2]=j;c[e+131072>>2]=j;j=m+1024|0;if(j>>>0>12648447){break}else{e=e+4|0;m=j}}m=c[3540976]|0;c[p+53248>>2]=m;c[p+118784>>2]=m;c[p+184320>>2]=m;e=m+1024|0;c[p+53252>>2]=e;c[p+118788>>2]=e;c[p+184324>>2]=e;e=m+2048|0;c[p+53256>>2]=e;c[p+118792>>2]=e;c[p+184328>>2]=e;e=m+3072|0;c[p+53260>>2]=e;c[p+118796>>2]=e;c[p+184332>>2]=e;e=m+4096|0;c[p+53264>>2]=e;c[p+118800>>2]=e;c[p+184336>>2]=e;e=m+5120|0;c[p+53268>>2]=e;c[p+118804>>2]=e;c[p+184340>>2]=e;e=m+6144|0;c[p+53272>>2]=e;c[p+118808>>2]=e;c[p+184344>>2]=e;e=m+7168|0;c[p+53276>>2]=e;c[p+118812>>2]=e;c[p+184348>>2]=e;e=m+8192|0;c[p+53280>>2]=e;c[p+118816>>2]=e;c[p+184352>>2]=e;e=m+9216|0;c[p+53284>>2]=e;c[p+118820>>2]=e;c[p+184356>>2]=e;e=m+10240|0;c[p+53288>>2]=e;c[p+118824>>2]=e;c[p+184360>>2]=e;e=m+11264|0;c[p+53292>>2]=e;c[p+118828>>2]=e;c[p+184364>>2]=e;e=m+12288|0;c[p+53296>>2]=e;c[p+118832>>2]=e;c[p+184368>>2]=e;e=m+13312|0;c[p+53300>>2]=e;c[p+118836>>2]=e;c[p+184372>>2]=e;e=m+14336|0;c[p+53304>>2]=e;c[p+118840>>2]=e;c[p+184376>>2]=e;e=m+15360|0;c[p+53308>>2]=e;c[p+118844>>2]=e;c[p+184380>>2]=e;c[p+196608>>2]=116;c[p+196648>>2]=2934;c[p+196728>>2]=1622;e=c[3532592]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);e=c[2439330]|0;m=(e|0)==0;if(!m){q=e;gGC(9706056,q|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];q=c[3528484]|0;c[2076596]=q;j=c[2417276]|0;c[3541536]=j;c[1836236]=0;c[e+4180>>2]=1166;c[e+4184>>2]=116;r=c[3531932]|0;s=0;t=0;while(1){c[e+76+(t<<2)>>2]=r+(t<<8);u=s+1&65535;if((u&65535)>63){v=0;w=0;break}else{s=u;t=u&65535}}while(1){t=r+(w<<8)|0;c[e+76+(w+512<<2)>>2]=t;c[e+76+(w+768<<2)>>2]=t;t=v+1&65535;if((t&65535)>63){x=64;y=64;break}else{v=t;w=t&65535}}while(1){c[e+76+(y<<2)>>2]=r+(y<<8);t=x+1&65535;if((t&65535)>127){z=64;A=64;break}else{x=t;y=t&65535}}while(1){t=r+(A<<8)|0;c[e+76+(A+512<<2)>>2]=t;c[e+76+(A+768<<2)>>2]=t;t=z+1&65535;if((t&65535)>127){break}else{z=t;A=t&65535}}r=c[3531936]|0;c[e+588>>2]=r;c[e+592>>2]=r+256;c[e+596>>2]=r+512;c[e+600>>2]=r+768;c[e+604>>2]=r+1024;c[e+608>>2]=r+1280;c[e+612>>2]=r+1536;c[e+616>>2]=r+1792;c[e+620>>2]=r+2048;c[e+624>>2]=r+2304;c[e+628>>2]=r+2560;c[e+632>>2]=r+2816;c[e+636>>2]=r+3072;c[e+640>>2]=r+3328;c[e+644>>2]=r+3584;c[e+648>>2]=r+3840;t=128;s=128;while(1){c[e+76+(s+256<<2)>>2]=r+((s<<8)-32768);u=t+1&65535;if((u&65535)>143){B=128;C=128;break}else{t=u;s=u&65535}}while(1){s=r+((C<<8)-32768)|0;c[e+76+(C+512<<2)>>2]=s;c[e+76+(C+768<<2)>>2]=s;s=B+1&65535;if((s&65535)>143){break}else{B=s;C=s&65535}}if(!m){r=e;gGC(r|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=q;c[2417276]=j;c[1836236]=-1;r=a[9680]|0;s=r?32e3:0;if(r){if(a[9624]|0){r=s*3|0;t=62500;while(1){if((t|0)>(r|0)){t=t>>1}else{D=1222;E=t;break}}}else{D=2462;E=s}c[2429380]=E;c[3542124]=D;mw(4e6,E);t=gGq(262144)|0;c[2406684]=t;gGz(t|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(4e6,11025)}t=c[3531464]|0;c[t+44344>>2]=1036;c[t+44348>>2]=2284;h[745421]=.5;c[2436794]=3;h[745420]=.5;c[2436792]=3;UB(0,3064,384e3,5992,5);c[2415126]=9662152;h[1207773]=.6;c[2415548]=3;t=c[642608+(c[2436]<<2)>>2]|0;r=c[t+128>>2]|0;if((c[t+52>>2]&4|0)==0){c[2113068]=r;j=c[t+132>>2]|0;c[2113070]=j;c[2443814]=r;c[2440436]=j;F=r;G=j}else{c[2113070]=r;j=c[t+132>>2]|0;c[2113068]=j;c[2440436]=r;c[2443814]=j;F=j;G=r}r=ag(F<<1,G)|0;j=gGq(r)|0;c[2112926]=j;if((j|0)!=0){gGz(j|0,0,r|0)}c[3532118]=3906;c[3532050]=2286;c[3532064]=5;c[2113026]=133333;c[2113024]=66666;c[3532016]=990;eZ8()|0;c[2438580]=0;c[2437014]=-1;i=0;return i|0}}while(0);c[3532048]=0;i=1;return i|0}function e1o(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5112140+(b*112|0)>>2];c[a+104>>2]=c[5112144+(b*112|0)>>2];c[a+108>>2]=c[5112148+(b*112|0)>>2];d=0;return d|0}function e1p(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=5112040+(b*112|0);e=0;return e|0}function e1q(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5110348+(b*112|0)>>2];c[a+104>>2]=c[5110352+(b*112|0)>>2];c[a+108>>2]=c[5110356+(b*112|0)>>2];d=0;return d|0}function e1r(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=5110248+(b*112|0);e=0;return e|0}function e1s(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>41){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3572672+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e1t(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3575476+(b*112|0)>>2];c[a+104>>2]=c[3575480+(b*112|0)>>2];c[a+108>>2]=c[3575484+(b*112|0)>>2];d=0;return d|0}function e1u(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=3575376+(b*112|0);e=0;return e|0}function e1v(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3573684+(b*112|0)>>2];c[a+104>>2]=c[3573688+(b*112|0)>>2];c[a+108>>2]=c[3573692+(b*112|0)>>2];d=0;return d|0}function e1w(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=3573584+(b*112|0);e=0;return e|0}function e1x(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3570980+(b*112|0)>>2];c[a+104>>2]=c[3570984+(b*112|0)>>2];c[a+108>>2]=c[3570988+(b*112|0)>>2];d=0;return d|0}function e1y(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=3570880+(b*112|0);e=0;return e|0}function e1z(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1758436+(b*112|0)>>2];c[a+104>>2]=c[1758440+(b*112|0)>>2];c[a+108>>2]=c[1758444+(b*112|0)>>2];d=0;return d|0}function e1A(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=1758336+(b*112|0);e=0;return e|0}function e1B(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>30){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3298692+(b*112|0)>>2];c[a+104>>2]=c[3298696+(b*112|0)>>2];c[a+108>>2]=c[3298700+(b*112|0)>>2];d=0;return d|0}function e1C(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<31&(d|0)==0)){e=1;return e|0}c[a>>2]=3298592+(b*112|0);e=0;return e|0}function e1D(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1178184+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function e1E(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>38){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3302064+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e1F(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;c[3532162]=256;c[3532160]=4;c[3532142]=8;c[3532164]=8;c[3532148]=683920;c[3532140]=725120;c[3532138]=725088;c[3532042]=8192;c[3532002]=512;c[3532e3]=4;a[7460944]=1;c[3532004]=8;c[3531998]=682216;c[3531992]=690488;c[3531990]=690456;c[3532034]=32768;c[3532044]=2;c[3532030]=1;a[7460968]=1;c[3532036]=1;eZ9(0)|0;c[3532048]=0;e1Z();d=c[3532046]|0;e=0;while(1){if((e|0)>=1024){break}f=9638528+(e<<2)|0;if((c[f>>2]|0)==0){g=39609;break}else{e=e+1|0}}do{if((g|0)==39609){e=gGq(d)|0;c[f>>2]=e;if((e|0)==0){break}gGz(e|0,0,d|0);c[3532048]=e;gGz(e|0,0,d|0);e1Z();if((eZ9(1)|0)!=0){i=1;return i|0}e=c[3532042]|0;j=0;while(1){if((j|0)>=1024){k=0;break}l=9638528+(j<<2)|0;if((c[l>>2]|0)==0){g=39615;break}else{j=j+1|0}}do{if((g|0)==39615){j=gGq(65536)|0;c[l>>2]=j;if((j|0)==0){k=0;break}gGz(j|0,0,65536);k=j}}while(0);c[3540978]=k;gGz(k|0,0,65536);c[2437030]=e;c[2438630]=0;c[2438626]=8;c[2427050]=0;c[2438628]=0;a[7461128]=1;c[3527054]=64;c[2437032]=0;c[3528994]=(c[3528994]|0)+1;j=c[3532042]|0;m=0;while(1){if((m|0)>=1024){n=0;break}o=9638528+(m<<2)|0;if((c[o>>2]|0)==0){g=39620;break}else{m=m+1|0}}do{if((g|0)==39620){m=gGq(65536)|0;c[o>>2]=m;if((m|0)==0){n=0;break}gGz(m|0,0,65536);n=m}}while(0);c[3540979]=n;gGz(n|0,0,65536);c[2437031]=j;c[2438631]=0;c[2438627]=8;c[2427051]=0;c[2438629]=0;a[7461128]=1;c[3527055]=64;c[2437033]=0;c[3528994]=(c[3528994]|0)+1;a[7461080]=1;a[7461056]=1;fxU(0,425984);if((c[2394]|0)==0){p=c[2112932]|0}else{c[2394]=0;m=c[3532596]|0;c[2112932]=m;e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060];p=m}m=c[3532204]|0;e=p|0;q=0;while(1){r=m+q|0;c[e>>2]=r;c[e+131072>>2]=r;r=q+1024|0;if(r>>>0>131071){break}else{e=e+4|0;q=r}}q=p+2048|0;e=524288;while(1){j=m+(e-393216)|0;c[q>>2]=j;c[q+131072>>2]=j;j=e+1024|0;if(j>>>0>1048575){break}else{q=q+4|0;e=j}}e=c[3532008]|0;q=p+16384|0;m=4194304;while(1){j=e+(m-4194304)|0;c[q>>2]=j;c[q+65536>>2]=j;c[q+131072>>2]=j;j=m+1024|0;if(j>>>0>4259839){break}else{q=q+4|0;m=j}}m=c[3532026]|0;c[p+20480>>2]=m;c[p+86016>>2]=m;c[p+151552>>2]=m;q=m+1024|0;c[p+20484>>2]=q;c[p+86020>>2]=q;c[p+151556>>2]=q;q=m+2048|0;c[p+20488>>2]=q;c[p+86024>>2]=q;c[p+151560>>2]=q;q=m+3072|0;c[p+20492>>2]=q;c[p+86028>>2]=q;c[p+151564>>2]=q;q=m+4096|0;c[p+20496>>2]=q;c[p+86032>>2]=q;c[p+151568>>2]=q;q=m+5120|0;c[p+20500>>2]=q;c[p+86036>>2]=q;c[p+151572>>2]=q;q=m+6144|0;c[p+20504>>2]=q;c[p+86040>>2]=q;c[p+151576>>2]=q;q=m+7168|0;c[p+20508>>2]=q;c[p+86044>>2]=q;c[p+151580>>2]=q;q=m+8192|0;c[p+20512>>2]=q;c[p+86048>>2]=q;c[p+151584>>2]=q;q=m+9216|0;c[p+20516>>2]=q;c[p+86052>>2]=q;c[p+151588>>2]=q;q=m+10240|0;c[p+20520>>2]=q;c[p+86056>>2]=q;c[p+151592>>2]=q;q=m+11264|0;c[p+20524>>2]=q;c[p+86060>>2]=q;c[p+151596>>2]=q;q=m+12288|0;c[p+20528>>2]=q;c[p+86064>>2]=q;c[p+151600>>2]=q;q=m+13312|0;c[p+20532>>2]=q;c[p+86068>>2]=q;c[p+151604>>2]=q;q=m+14336|0;c[p+20536>>2]=q;c[p+86072>>2]=q;c[p+151608>>2]=q;q=m+15360|0;c[p+20540>>2]=q;c[p+86076>>2]=q;c[p+151612>>2]=q;q=c[3532208]|0;m=p+32768|0;e=8388608;while(1){j=q+(e-8388608)|0;c[m>>2]=j;c[m+65536>>2]=j;c[m+131072>>2]=j;j=e+1024|0;if(j>>>0>8454143){break}else{m=m+4|0;e=j}}e=c[3540978]|0;m=p+40960|0;q=10485760;while(1){j=e+(q-10485760)|0;c[m>>2]=j;c[m+65536>>2]=j;c[m+131072>>2]=j;j=q+1024|0;if(j>>>0>10551295){break}else{m=m+4|0;q=j}}q=c[3540979]|0;m=p+45056|0;e=11534336;while(1){j=q+(e-11534336)|0;c[m>>2]=j;c[m+65536>>2]=j;c[m+131072>>2]=j;j=e+1024|0;if(j>>>0>11599871){break}else{m=m+4|0;e=j}}e=c[3531970]|0;c[p+53248>>2]=e;c[p+118784>>2]=e;c[p+184320>>2]=e;m=e+1024|0;c[p+53252>>2]=m;c[p+118788>>2]=m;c[p+184324>>2]=m;m=e+2048|0;c[p+53256>>2]=m;c[p+118792>>2]=m;c[p+184328>>2]=m;m=e+3072|0;c[p+53260>>2]=m;c[p+118796>>2]=m;c[p+184332>>2]=m;m=c[3531958]|0;e=p+57344|0;q=14680064;while(1){j=m+(q-14680064)|0;c[e>>2]=j;c[e+65536>>2]=j;c[e+131072>>2]=j;j=q+1024|0;if(j>>>0>14745599){break}else{e=e+4|0;q=j}}c[p+196608>>2]=1826;c[p+196648>>2]=270;c[p+196688>>2]=1554;c[p+196728>>2]=266;q=c[3532592]|0;if((q|0)!=0){gGC(q|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fxU(1,425984);if((c[2394]|0)==1){s=c[2112932]|0}else{c[2394]=1;q=c[3532597]|0;c[2112932]=q;e=c[3532593]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113061];s=q}q=c[3532198]|0;e=s|0;m=0;while(1){j=q+m|0;c[e>>2]=j;c[e+131072>>2]=j;j=m+1024|0;if(j>>>0>131071){break}else{e=e+4|0;m=j}}m=c[3532008]|0;e=s+16384|0;q=4194304;while(1){j=m+(q-4194304)|0;c[e>>2]=j;c[e+65536>>2]=j;c[e+131072>>2]=j;j=q+1024|0;if(j>>>0>4259839){break}else{e=e+4|0;q=j}}c[s+196608>>2]=3282;c[s+196648>>2]=2888;c[s+196688>>2]=2196;c[s+196728>>2]=2078;q=c[3532593]|0;if((q|0)!=0){gGC(q|0,9104152,280)|0}c[2113061]=c[2113054];c[2394]=-1;fwR(0);q=c[2439330]|0;e=(q|0)==0;if(!e){m=q;gGC(9706056,m|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];m=c[3528484]|0;c[2076596]=m;j=c[2417276]|0;c[3541536]=j;c[1836236]=0;c[q+4180>>2]=158;c[q+4184>>2]=1688;r=c[3531932]|0;t=0;u=0;while(1){c[q+76+(u<<2)>>2]=r+(u<<8);v=t+1&65535;if((v&65535)>63){w=0;x=0;break}else{t=v;u=v&65535}}while(1){u=r+(x<<8)|0;c[q+76+(x+512<<2)>>2]=u;c[q+76+(x+768<<2)>>2]=u;u=w+1&65535;if((u&65535)>63){break}else{w=u;x=u&65535}}r=c[3531936]|0;c[q+588>>2]=r;c[q+592>>2]=r+256;c[q+596>>2]=r+512;c[q+600>>2]=r+768;c[q+604>>2]=r+1024;c[q+608>>2]=r+1280;c[q+612>>2]=r+1536;c[q+616>>2]=r+1792;c[q+620>>2]=r+2048;c[q+624>>2]=r+2304;c[q+628>>2]=r+2560;c[q+632>>2]=r+2816;c[q+636>>2]=r+3072;c[q+640>>2]=r+3328;c[q+644>>2]=r+3584;c[q+648>>2]=r+3840;u=128;t=128;while(1){c[q+76+(t+256<<2)>>2]=r+((t<<8)-32768);v=u+1&65535;if((v&65535)>143){y=128;z=128;break}else{u=v;t=v&65535}}while(1){t=r+((z<<8)-32768)|0;c[q+76+(z+512<<2)>>2]=t;c[q+76+(z+768<<2)>>2]=t;t=y+1&65535;if((t&65535)>143){break}else{y=t;z=t&65535}}if(!e){r=q;gGC(r|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=m;c[2417276]=j;c[1836236]=-1;r=a[9680]|0;t=r?32e3:0;if(r){if(a[9624]|0){r=t*3|0;u=62500;while(1){if((u|0)>(r|0)){u=u>>1}else{A=1222;B=u;break}}}else{A=2462;B=t}c[2429380]=B;c[3542124]=A;mw(4e6,B);u=gGq(262144)|0;c[2406684]=u;gGz(u|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(4e6,11025)}u=c[3531464]|0;c[u+44344>>2]=1036;c[u+44348>>2]=1964;h[745421]=.3;c[2436794]=3;h[745420]=.3;c[2436792]=3;UB(0,3064,384e3,1130,5);c[2415126]=9662152;h[1207773]=.6;c[2415548]=3;u=c[642608+(c[2436]<<2)>>2]|0;r=c[u+128>>2]|0;if((c[u+52>>2]&4|0)==0){c[2113068]=r;j=c[u+132>>2]|0;c[2113070]=j;c[2443814]=r;c[2440436]=j;C=r;D=j}else{c[2113070]=r;j=c[u+132>>2]|0;c[2113068]=j;c[2440436]=r;c[2443814]=j;C=j;D=r}r=ag(C<<1,D)|0;j=gGq(r)|0;c[2112926]=j;if((j|0)!=0){gGz(j|0,0,r|0)}c[3532118]=9486;c[3532050]=6600;c[3532064]=5;c[2113026]=2e5;c[2113024]=2e5;c[2113022]=66666;r=0;while(1){if((r|0)>=1024){E=0;break}F=9638528+(r<<2)|0;if((c[F>>2]|0)==0){g=39678;break}else{r=r+1|0}}do{if((g|0)==39678){r=gGq(524288)|0;c[F>>2]=r;if((r|0)==0){E=0;break}gGz(r|0,0,524288);E=r}}while(0);c[2430394]=E;c[3532016]=4942;eZ8()|0;c[2438580]=0;c[2437014]=-1;i=0;return i|0}}while(0);c[3532048]=0;i=1;return i|0}function e1G(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;do{if((c[3532036]|0)==0){d=10}else{c[2415126]=9662152;e=c[2415557]|0;f=e&3;if((f|0)==3){d=133;break}d=(4e6/(4e6/((c[2415554]|0)/(c[600992+((e>>>3&1)<<4)+(f<<2)>>2]|0)|0|0)|0|0)|0|0)/((c[2424]|0)/100|0|0)|0}}while(0);if((a[14128072]|0)!=0){f=c[3532016]|0;gD[f&8191]()|0}gu[c[3532050]&16383]();c[2113032]=0;c[2113031]=0;c[2113030]=0;f=c[2392]|0;if((f|0)>=0){gGz(8452240,0,((f|0)>0?(f<<2)+4|0:4)|0)}c[2113054]=0;f=c[2385548]|0;if((f|0)>0){gGz(9752472,0,((f|0)>1?f<<2:4)|0)}c[2433530]=0;f=(d|0)/2|0;e=d-1|0;g=0;h=0;L52016:while(1){i=h;while(1){if((i|0)>=(d|0)){break L52016}if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];j=c[3532592]|0;if((j|0)!=0){gGC(9104152,j|0,280)|0}c[2113054]=c[2113060]}k=i+1|0;j=(ag(c[2113026]|0,k)|0)/(d|0)|0;l=j-(c[2113030]|0)|0;c[2113028]=l;c[2113056]=l;j=RG(l)|0;c[2113054]=(c[2113054]|0)+j;c[2276108]=-1;c[2113056]=-1;c[2113030]=(c[2113030]|0)+j;j=(i|0)!=(f|0)|4536>>>0<=0;do{if(!j){c[8452200+(c[2394]<<2)>>2]=8198;c[2276080]=1536;if((c[2276079]|0)>>>0>=1536){break}RH(6)}}while(0);l=(i|0)==(e|0);do{if(l){m=c[3532064]|0;c[8452200+(c[2394]<<2)>>2]=m|8192;n=c[2276080]|0;o=m<<8;c[2276080]=o;if((n|0)!=1792&(o|0)==1792){RH(7);break}if(o>>>0<=(c[2276079]|0)>>>0){break}RH(m&16777215)}}while(0);m=c[2394]|0;o=c[14130368+(m<<2)>>2]|0;if((o|0)!=0){gGC(o|0,9104152,280)|0}c[8452240+(m<<2)>>2]=c[2113054];c[2394]=-1;if((b[7064256]&1)!=0){c[2394]=1;c[2112932]=c[3532597];m=c[3532593]|0;if((m|0)!=0){gGC(9104152,m|0,280)|0}c[2113054]=c[2113061];m=(ag(c[2113024]|0,k)|0)/(d|0)|0;o=m-(c[2113031]|0)|0;c[2113028]=o;c[2113056]=o;m=RG(o)|0;c[2113054]=(c[2113054]|0)+m;c[2276108]=-1;c[2113056]=-1;c[2113031]=(c[2113031]|0)+m;do{if(!j){c[8452200+(c[2394]<<2)>>2]=8198;c[2276080]=1536;if((c[2276079]|0)>>>0>=1536){break}RH(6)}}while(0);do{if(l){j=c[3532064]|0;c[8452200+(c[2394]<<2)>>2]=j|8192;m=c[2276080]|0;o=j<<8;c[2276080]=o;if((m|0)!=1792&(o|0)==1792){RH(7);break}if(o>>>0<=(c[2276079]|0)>>>0){break}RH(j&16777215)}}while(0);l=c[2394]|0;j=c[14130368+(l<<2)>>2]|0;if((j|0)!=0){gGC(j|0,9104152,280)|0}c[8452240+(l<<2)>>2]=c[2113054];c[2394]=-1}if((c[3532030]|0)>0){l=c[2439330]|0;if((l|0)!=0){j=l;gGC(9706056,j|0,76)|0}b[4853030]=c[2426515]&65535;j=c[2438118]|0;c[2433530]=j;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;o=(ag(c[2113022]|0,k)|0)/(d|0)|0;m=c[2113032]|0;n=o-m|0;c[2113028]=n;do{if((n|0)<1){p=0;q=m}else{if((a[l+4188|0]|0)==0){o=gfc(n)|0;c[2433530]=(c[2433530]|0)+o;p=o;q=c[2113032]|0;break}else{c[2433530]=j+n;p=n;q=m;break}}}while(0);c[2113028]=p;c[2113032]=q+p;if((c[3532036]|0)!=0){UD()}m=c[1836236]|0;n=c[9757320+(m<<2)>>2]|0;if((n|0)!=0){j=n;gGC(j|0,9706056,76)|0}c[9752472+(m<<2)>>2]=c[2433530];c[14113936+(m<<2)>>2]=c[2076596];c[9669104+(m<<2)>>2]=c[3541536];c[1836236]=-1}r=c[2112964]|0;if((r|0)==0){i=k}else{break}}i=((a[9688]|0?534:0)|0)/(d|0)|0;m=r+(g<<1<<1)|0;j=c[3532030]|0;if((j|0)>0){n=c[2439330]|0;if((n|0)!=0){l=n;gGC(9706056,l|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0}if(a[7460968]|0){gg[c[3542124]&4095](m,i);s=c[3532030]|0}else{s=j}if((s|0)>0){j=c[1836236]|0;m=c[9757320+(j<<2)>>2]|0;if((m|0)!=0){l=m;gGC(l|0,9706056,76)|0}c[9752472+(j<<2)>>2]=c[2433530];c[14113936+(j<<2)>>2]=c[2076596];c[9669104+(j<<2)>>2]=c[3541536];c[1836236]=-1}g=i+g|0;h=k}k=c[2112964]|0;do{if((k|0)!=0){h=a[9688]|0?534:0;s=h-g|0;r=k+(g<<1<<1)|0;do{if((h|0)!=(g|0)){d=c[3532030]|0;if((d|0)>0){p=c[2439330]|0;if((p|0)!=0){q=p;gGC(9706056,q|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0}if(a[7460968]|0){gg[c[3542124]&4095](r,s);t=c[3532030]|0}else{t=d}if((t|0)<=0){break}d=c[1836236]|0;q=c[9757320+(d<<2)>>2]|0;if((q|0)!=0){p=q;gGC(p|0,9706056,76)|0}c[9752472+(d<<2)>>2]=c[2433530];c[14113936+(d<<2)>>2]=c[2076596];c[9669104+(d<<2)>>2]=c[3541536];c[1836236]=-1}}while(0);s=c[2112964]|0;if((s|0)==0){break}r=c[3532030]|0;if((r|0)>0){h=c[2439330]|0;if((h|0)!=0){d=h;gGC(9706056,d|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0}if((c[3532036]|0)==0){u=r}else{Uz(0,s,a[9688]|0?534:0);u=c[3532030]|0}if((u|0)<=0){break}s=c[1836236]|0;r=c[9757320+(s<<2)>>2]|0;if((r|0)!=0){d=r;gGC(d|0,9706056,76)|0}c[9752472+(s<<2)>>2]=c[2433530];c[14113936+(s<<2)>>2]=c[2076596];c[9669104+(s<<2)>>2]=c[3541536];c[1836236]=-1}}while(0);if((c[2112968]|0)==0){return 0}gu[c[3532118]&16383]();return 0}function e1H(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1653956+(b*112|0)>>2];c[a+104>>2]=c[1653960+(b*112|0)>>2];c[a+108>>2]=c[1653964+(b*112|0)>>2];d=0;return d|0}function e1I(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=1653856+(b*112|0);e=0;return e|0}function e1J(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>38){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3940960+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e1K(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3939268+(b*112|0)>>2];c[a+104>>2]=c[3939272+(b*112|0)>>2];c[a+108>>2]=c[3939276+(b*112|0)>>2];d=0;return d|0}function e1L(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=3939168+(b*112|0);e=0;return e|0}function e1M(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4890700+(b*112|0)>>2];c[a+104>>2]=c[4890704+(b*112|0)>>2];c[a+108>>2]=c[4890708+(b*112|0)>>2];d=0;return d|0}function e1N(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=4890600+(b*112|0);e=0;return e|0}function e1O(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1648104+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function e1P(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>42){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4892728+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e1Q(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;c[3532042]=0;c[3532002]=1024;c[3532e3]=4;a[7460944]=1;c[3532004]=16;c[3531998]=683032;c[3531992]=699976;c[3531990]=699912;c[3532034]=6144;c[3532044]=1;c[3532030]=1;c[3532032]=1;eZ9(0)|0;c[3532048]=0;e1Z();d=c[3532046]|0;e=0;while(1){if((e|0)>=1024){break}f=9638528+(e<<2)|0;if((c[f>>2]|0)==0){g=39837;break}else{e=e+1|0}}do{if((g|0)==39837){e=gGq(d)|0;c[f>>2]=e;if((e|0)==0){break}gGz(e|0,0,d|0);c[3532048]=e;gGz(e|0,0,d|0);e1Z();if((eZ9(1)|0)!=0){i=1;return i|0}e=c[3532034]|0;j=0;while(1){if((j|0)>=1024){k=0;break}l=9638528+(j<<2)|0;if((c[l>>2]|0)==0){g=39843;break}else{j=j+1|0}}do{if((g|0)==39843){j=gGq(16384)|0;c[l>>2]=j;if((j|0)==0){k=0;break}gGz(j|0,0,16384);k=j}}while(0);c[3540976]=k;gGz(k|0,0,16384);c[2437028]=e;c[2438624]=8;a[7461120]=1;a[726072]=1;a[7461080]=1;fxU(0,425984);if((c[2394]|0)==0){m=c[2112932]|0}else{c[2394]=0;j=c[3532596]|0;c[2112932]=j;n=c[3532592]|0;if((n|0)!=0){gGC(9104152,n|0,280)|0}c[2113054]=c[2113060];m=j}j=c[3532204]|0;n=m|0;o=0;while(1){p=j+o|0;c[n>>2]=p;c[n+131072>>2]=p;p=o+1024|0;if(p>>>0>262143){break}else{n=n+4|0;o=p}}o=m+2048|0;n=524288;while(1){e=j+(n-262144)|0;c[o>>2]=e;c[o+131072>>2]=e;e=n+1024|0;if(e>>>0>1048575){break}else{o=o+4|0;n=e}}n=c[3532208]|0;c[m+4096>>2]=n;c[m+69632>>2]=n;c[m+135168>>2]=n;o=n+1024|0;c[m+4100>>2]=o;c[m+69636>>2]=o;c[m+135172>>2]=o;o=n+2048|0;c[m+4104>>2]=o;c[m+69640>>2]=o;c[m+135176>>2]=o;o=n+3072|0;c[m+4108>>2]=o;c[m+69644>>2]=o;c[m+135180>>2]=o;o=n+4096|0;c[m+4112>>2]=o;c[m+69648>>2]=o;c[m+135184>>2]=o;o=n+5120|0;c[m+4116>>2]=o;c[m+69652>>2]=o;c[m+135188>>2]=o;o=n+6144|0;c[m+4120>>2]=o;c[m+69656>>2]=o;c[m+135192>>2]=o;o=n+7168|0;c[m+4124>>2]=o;c[m+69660>>2]=o;c[m+135196>>2]=o;o=n+8192|0;c[m+4128>>2]=o;c[m+69664>>2]=o;c[m+135200>>2]=o;o=n+9216|0;c[m+4132>>2]=o;c[m+69668>>2]=o;c[m+135204>>2]=o;o=n+10240|0;c[m+4136>>2]=o;c[m+69672>>2]=o;c[m+135208>>2]=o;o=n+11264|0;c[m+4140>>2]=o;c[m+69676>>2]=o;c[m+135212>>2]=o;o=n+12288|0;c[m+4144>>2]=o;c[m+69680>>2]=o;c[m+135216>>2]=o;o=n+13312|0;c[m+4148>>2]=o;c[m+69684>>2]=o;c[m+135220>>2]=o;o=n+14336|0;c[m+4152>>2]=o;c[m+69688>>2]=o;c[m+135224>>2]=o;o=n+15360|0;c[m+4156>>2]=o;c[m+69692>>2]=o;c[m+135228>>2]=o;o=c[3540976]|0;c[m+8192>>2]=o;c[m+73728>>2]=o;c[m+139264>>2]=o;n=o+1024|0;c[m+8196>>2]=n;c[m+73732>>2]=n;c[m+139268>>2]=n;n=o+2048|0;c[m+8200>>2]=n;c[m+73736>>2]=n;c[m+139272>>2]=n;n=o+3072|0;c[m+8204>>2]=n;c[m+73740>>2]=n;c[m+139276>>2]=n;n=o+4096|0;c[m+8208>>2]=n;c[m+73744>>2]=n;c[m+139280>>2]=n;n=o+5120|0;c[m+8212>>2]=n;c[m+73748>>2]=n;c[m+139284>>2]=n;n=o+6144|0;c[m+8216>>2]=n;c[m+73752>>2]=n;c[m+139288>>2]=n;n=o+7168|0;c[m+8220>>2]=n;c[m+73756>>2]=n;c[m+139292>>2]=n;n=o+8192|0;c[m+8224>>2]=n;c[m+73760>>2]=n;c[m+139296>>2]=n;n=o+9216|0;c[m+8228>>2]=n;c[m+73764>>2]=n;c[m+139300>>2]=n;n=o+10240|0;c[m+8232>>2]=n;c[m+73768>>2]=n;c[m+139304>>2]=n;n=o+11264|0;c[m+8236>>2]=n;c[m+73772>>2]=n;c[m+139308>>2]=n;n=o+12288|0;c[m+8240>>2]=n;c[m+73776>>2]=n;c[m+139312>>2]=n;n=o+13312|0;c[m+8244>>2]=n;c[m+73780>>2]=n;c[m+139316>>2]=n;n=o+14336|0;c[m+8248>>2]=n;c[m+73784>>2]=n;c[m+139320>>2]=n;n=o+15360|0;c[m+8252>>2]=n;c[m+73788>>2]=n;c[m+139324>>2]=n;n=c[3531958]|0;o=m+16384|0;j=4194304;while(1){c[o>>2]=n+(j-4194304);e=j+1024|0;if(e>>>0>4718591){break}else{o=o+4|0;j=e}}j=c[3532026]|0;c[m+20480>>2]=j;c[m+86016>>2]=j;c[m+151552>>2]=j;o=j+1024|0;c[m+20484>>2]=o;c[m+86020>>2]=o;c[m+151556>>2]=o;o=j+2048|0;c[m+20488>>2]=o;c[m+86024>>2]=o;c[m+151560>>2]=o;o=j+3072|0;c[m+20492>>2]=o;c[m+86028>>2]=o;c[m+151564>>2]=o;o=j+4096|0;c[m+20496>>2]=o;c[m+86032>>2]=o;c[m+151568>>2]=o;o=j+5120|0;c[m+20500>>2]=o;c[m+86036>>2]=o;c[m+151572>>2]=o;o=j+6144|0;c[m+20504>>2]=o;c[m+86040>>2]=o;c[m+151576>>2]=o;o=j+7168|0;c[m+20508>>2]=o;c[m+86044>>2]=o;c[m+151580>>2]=o;o=j+8192|0;c[m+20512>>2]=o;c[m+86048>>2]=o;c[m+151584>>2]=o;o=j+9216|0;c[m+20516>>2]=o;c[m+86052>>2]=o;c[m+151588>>2]=o;o=j+10240|0;c[m+20520>>2]=o;c[m+86056>>2]=o;c[m+151592>>2]=o;o=j+11264|0;c[m+20524>>2]=o;c[m+86060>>2]=o;c[m+151596>>2]=o;o=j+12288|0;c[m+20528>>2]=o;c[m+86064>>2]=o;c[m+151600>>2]=o;o=j+13312|0;c[m+20532>>2]=o;c[m+86068>>2]=o;c[m+151604>>2]=o;o=j+14336|0;c[m+20536>>2]=o;c[m+86072>>2]=o;c[m+151608>>2]=o;o=j+15360|0;c[m+20540>>2]=o;c[m+86076>>2]=o;c[m+151612>>2]=o;c[m+196608>>2]=1482;c[m+196648>>2]=92;c[m+196688>>2]=3138;c[m+196728>>2]=2598;o=c[3532592]|0;if((o|0)!=0){gGC(o|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);o=c[2439330]|0;j=(o|0)==0;if(!j){n=o;gGC(9706056,n|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];n=c[3528484]|0;c[2076596]=n;e=c[2417276]|0;c[3541536]=e;c[1836236]=0;c[o+4180>>2]=2542;c[o+4184>>2]=1912;p=c[3531932]|0;q=0;r=0;while(1){c[o+76+(r<<2)>>2]=p+(r<<8);s=q+1&65535;if((s&65535)>127){t=0;u=0;break}else{q=s;r=s&65535}}while(1){r=p+(u<<8)|0;c[o+76+(u+512<<2)>>2]=r;c[o+76+(u+768<<2)>>2]=r;r=t+1&65535;if((r&65535)>127){break}else{t=r;u=r&65535}}p=c[3531936]|0;c[o+588>>2]=p;r=p+256|0;c[o+592>>2]=r;q=p+512|0;c[o+596>>2]=q;s=p+768|0;c[o+600>>2]=s;v=p+1024|0;c[o+604>>2]=v;w=p+1280|0;c[o+608>>2]=w;x=p+1536|0;c[o+612>>2]=x;y=p+1792|0;c[o+616>>2]=y;c[o+1612>>2]=p;c[o+1616>>2]=r;c[o+1620>>2]=q;c[o+1624>>2]=s;c[o+1628>>2]=v;c[o+1632>>2]=w;c[o+1636>>2]=x;c[o+1640>>2]=y;c[o+2636>>2]=p;c[o+3660>>2]=p;c[o+2640>>2]=r;c[o+3664>>2]=r;c[o+2644>>2]=q;c[o+3668>>2]=q;c[o+2648>>2]=s;c[o+3672>>2]=s;c[o+2652>>2]=v;c[o+3676>>2]=v;c[o+2656>>2]=w;c[o+3680>>2]=w;c[o+2660>>2]=x;c[o+3684>>2]=x;c[o+2664>>2]=y;c[o+3688>>2]=y;if(!j){y=o;gGC(y|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=n;c[2417276]=e;c[1836236]=-1;Vr(1,4e6,1324,3064,82,0);c[3542224]=48;c[3542225]=716;c[3542226]=0;c[3542227]=0;c[2438228]=4e6;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=511;h[745419]=.6;a[3203368]=1;h[745418]=.15;a[3203360]=1;h[745417]=.15;a[3203352]=1;h[745416]=.15;a[3203344]=1;y=c[642608+(c[2436]<<2)>>2]|0;x=c[y+128>>2]|0;if((c[y+52>>2]&4|0)==0){c[2113068]=x;w=c[y+132>>2]|0;c[2113070]=w;c[2443814]=x;c[2440436]=w;z=x;A=w}else{c[2113070]=x;w=c[y+132>>2]|0;c[2113068]=w;c[2440436]=x;c[2443814]=w;z=w;A=x}x=ag(z<<1,A)|0;w=gGq(x)|0;c[2112926]=w;if((w|0)!=0){gGz(w|0,0,x|0)}c[3532118]=9782;c[3532050]=3060;c[3532064]=4;c[2113026]=133333;c[2113024]=66666;x=0;while(1){if((x|0)>=1024){B=0;break}C=9638528+(x<<2)|0;if((c[C>>2]|0)==0){g=39873;break}else{x=x+1|0}}do{if((g|0)==39873){x=gGq(8192)|0;c[C>>2]=x;if((x|0)==0){B=0;break}gGz(x|0,0,8192);B=x}}while(0);c[2077632]=B;a[7461e3]=1;c[3532016]=5096;eZ8()|0;b[4876800]=0;b[4876796]=0;i=0;return i|0}}while(0);c[3532048]=0;i=1;return i|0}function e1R(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3259860+(b*112|0)>>2];c[a+104>>2]=c[3259864+(b*112|0)>>2];c[a+108>>2]=c[3259868+(b*112|0)>>2];d=0;return d|0}function e1S(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=3259760+(b*112|0);e=0;return e|0}function e1T(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>42){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3261888+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e1U(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1646076+(b*112|0)>>2];c[a+104>>2]=c[1646080+(b*112|0)>>2];c[a+108>>2]=c[1646084+(b*112|0)>>2];d=0;return d|0}function e1V(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=1645976+(b*112|0);e=0;return e|0}function e1W(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3257276+(b*112|0)>>2];c[a+104>>2]=c[3257280+(b*112|0)>>2];c[a+108>>2]=c[3257284+(b*112|0)>>2];d=0;return d|0}function e1X(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=3257176+(b*112|0);e=0;return e|0}function e1Y(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>37){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3259304+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function e1Z(){var b=0,d=0,e=0,f=0;b=c[3532048]|0;c[3532204]=b;d=c[3532200]|0;c[3532198]=b+d;e=(c[3532194]|0)+d|0;c[3531932]=b+e;d=e+(c[3531928]|0)|0;c[3531926]=b+d;e=d+(c[3531922]|0)|0;c[3531976]=b+e;d=e+(c[3531972]|0)|0;c[3532062]=b+d;e=d+(c[3532058]|0)|0;d=b+e|0;c[3532020]=d;c[3532208]=d;c[3531936]=b+(e+98304);if((c[3532030]|0)==2){c[3531934]=b+(e+102400)}c[3532026]=b+(e+104448);c[3531970]=b+(e+120832);c[3532008]=b+(e+182272);c[3531958]=b+(e+247808);c[3532206]=b+(e+772096);d=e+837632|0;e=b+d|0;c[3532022]=e;c[3532136]=e;e=ag(c[3532142]|0,c[3532042]|0)|0;f=(ag(e,c[3532164]|0)|0)+d|0;c[3532134]=b+f;d=ag(a[7461200]|0?8:0,c[3532040]|0)|0;e=(ag(d,a[7461208]|0?8:0)|0)+f|0;c[3531962]=b+e;f=ag(a[7460944]|0?16:0,c[3532034]|0)|0;d=(ag(f,c[3532004]|0)|0)+e|0;c[3532028]=b+d;c[3532046]=b+(d+32768);return}function e1_(b,c){b=b|0;c=c|0;a[9706117]=c&1;return}function e1$(a){a=a|0;var b=0.0;b=+(a|0)*+((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)/4.0e6;+V(b)>=1.0?b>0.0?(al(+U(b/4294967296.0),4294967295.0)|0)>>>0:~~+af((b- +(~~b>>>0))/4294967296.0)>>>0:0;return~~b>>>0|0}function e10(){return+(+((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)/4.0e6)}function e11(b){b=b|0;return a[14128480]|0}function e12(b){b=b|0;return a[14128481]|0}function e13(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;a=c[2112926]|0;gGz(a|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);d=c[3532028]|0;f=0;g=c[3532026]|0;h=d;while(1){i=b[g>>1]|0;c[h>>2]=((i&65535)>>>10<<3&248)>>>3|((i&255)<<3&255)<<8|(((i&65535)>>>7&4|(i&65535)>>>5<<3&255)&255)<<3&2016;i=f+1|0;if((i|0)<8192){f=i;g=g+2|0;h=h+4|0}else{break}}h=c[3531958]|0;g=c[2113070]|0;if((g+8|0)<=0){j=c[3531962]|0;e5L(j);R8(d);return}f=c[2113068]|0;i=(b[4876800]&1)==0?h:h+262144|0;h=0;while(1){do{if((f|0)>0){k=h-8|0;if((k|0)<=-1){break}l=(k|0)<(g|0);m=1;do{n=e[i+(m<<1)>>1]|0;o=n<<2&1792;do{if((n&32768|0)==0){p=(o|n&15)&65535}else{q=(o|n>>>9&15|2048)&65535;if((n&8192|0)==0){p=q;break}p=q&3840}}while(0);if(l){b[a+(m-1+(ag(f,k)|0)<<1)>>1]=p}m=m+1|0;}while((m|0)<(f+1|0))}}while(0);m=h+1|0;if((m|0)<(g+8|0)){i=i+1024|0;h=m}else{break}}j=c[3531962]|0;e5L(j);R8(d);return}function e14(){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;a[14128320]=-1;a[14128321]=-4;a[14128322]=-1;a[14128323]=-1;if((a[14128312]|0)==0){b=-1}else{a[14128320]=-2;b=-2}if((a[14128313]|0)==0){c=b}else{d=b-2&255;a[14128320]=d;c=d}if((a[14128314]|0)==0){e=c}else{d=c-4&255;a[14128320]=d;e=d}if((a[14128315]|0)==0){f=e}else{d=e-8&255;a[14128320]=d;f=d}if((a[14128316]|0)==0){g=f}else{d=f-16&255;a[14128320]=d;g=d}if((a[14128317]|0)==0){h=g}else{d=g-32&255;a[14128320]=d;h=d}if((a[14128318]|0)==0){i=h}else{d=h-64&255;a[14128320]=d;i=d}if((a[14128319]|0)!=0){a[14128320]=i^-128}if((a[14128304]|0)==0){j=-4}else{a[14128321]=-3;j=-3}if((a[14128305]|0)==0){k=j}else{i=j|2;a[14128321]=i;k=i}if((a[14128306]|0)==0){l=k}else{i=k-4&255;a[14128321]=i;l=i}if((a[14128307]|0)==0){m=l}else{i=l-8&255;a[14128321]=i;m=i}if((a[14128308]|0)==0){n=m}else{i=m-16&255;a[14128321]=i;n=i}if((a[14128309]|0)==0){o=n}else{i=n-32&255;a[14128321]=i;o=i}if((a[14128310]|0)==0){p=o}else{i=o-64&255;a[14128321]=i;p=i}if((a[14128311]|0)!=0){a[14128321]=p^-128}if((a[14128296]|0)==0){q=-1}else{a[14128322]=-2;q=-2}if((a[14128297]|0)==0){r=q}else{p=q-2&255;a[14128322]=p;r=p}if((a[14128298]|0)==0){s=r}else{p=r-4&255;a[14128322]=p;s=p}if((a[14128299]|0)==0){t=s}else{p=s-8&255;a[14128322]=p;t=p}if((a[14128300]|0)==0){u=t}else{p=t-16&255;a[14128322]=p;u=p}if((a[14128301]|0)==0){v=u}else{p=u-32&255;a[14128322]=p;v=p}if((a[14128302]|0)==0){w=v}else{p=v-64&255;a[14128322]=p;w=p}if((a[14128303]|0)!=0){a[14128322]=w^-128}if((a[14128288]|0)==0){x=-1}else{a[14128323]=-2;x=-2}if((a[14128289]|0)==0){y=x}else{w=x-2&255;a[14128323]=w;y=w}if((a[14128290]|0)==0){z=y}else{w=y-4&255;a[14128323]=w;z=w}if((a[14128291]|0)==0){A=z}else{w=z-8&255;a[14128323]=w;A=w}if((a[14128292]|0)==0){B=A}else{w=A-16&255;a[14128323]=w;B=w}if((a[14128293]|0)==0){C=B}else{w=B-32&255;a[14128323]=w;C=w}if((a[14128294]|0)==0){D=C}else{w=C-64&255;a[14128323]=w;D=w}if((a[14128295]|0)==0){return}a[14128323]=D^-128;return}function e15(){eZ8()|0;b[4876800]=0;b[4876796]=0;return 0}function e16(){return c[2113222]|0}function e17(b){b=b|0;a[9706117]=(b|0)!=0|0;return}function e18(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=d&3;if((b|0)==0){return}d=b+255|0;a[14127752]=d&255;b=c[3531932]|0;e=d<<14&4177920;d=c[9757320+(c[1836236]<<2)>>2]|0;f=64;g=64;while(1){c[d+76+(g<<2)>>2]=b+((g<<8)+e);h=f+1&65535;if((h&65535)>127){i=64;j=64;break}else{f=h;g=h&65535}}while(1){g=b+((j<<8)+e)|0;c[d+76+(j+512<<2)>>2]=g;c[d+76+(j+768<<2)>>2]=g;g=i+1&65535;if((g&65535)>127){break}else{i=g;j=g&65535}}return}function e19(){var a=0,b=0,e=0;a=c[2437014]|0;if((a|0)!=-1){b=a&15;c[2415126]=9662152;if((c[2415542]|0)==4){e=b}else{e=b<<1&14}c[2415538]=e;c[2437014]=-1;return}e=c[2438580]|0;b=d[(c[3532062]|0)+e|0]|0;c[2437014]=b;c[2438580]=e+1&131071;e=b>>>4;c[2415126]=9662152;if((c[2415542]|0)==4){c[2415538]=e;return}else{c[2415538]=e<<1&14;return}}function e2a(){var a=0,d=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;a=i;i=i+1024|0;d=a|0;f=c[2112926]|0;gGz(f|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);g=c[3532028]|0;h=0;j=c[3532026]|0;k=g;while(1){l=b[j>>1]|0;c[k>>2]=((l&65535)>>>10<<3&248)>>>3|((l&255)<<3&255)<<8|(((l&65535)>>>7&4|(l&65535)>>>5<<3&255)&255)<<3&2016;l=h+1|0;if((l|0)<8192){h=l;j=j+2|0;k=k+4|0}else{break}}k=c[3532136]|0;e5G(1,1,k,f);e2d(1);j=c[2430394]|0;h=c[3532208]|0;l=h;m=j;gGz(m|0,0,524288);n=c[3540979]|0;o=n;p=c[3527055]|0;q=(c[2437033]|0)==0;r=(c[2437031]|0)+65535|0;s=0;t=0;while(1){if((p|0)>0){u=t<<3;v=s;w=0;while(1){x=v<<1;if(q){y=x;z=r&(e[o+((x|1)<<1)>>1]|0)}else{y=v;z=b[o+(v+8192<<1)>>1]&16383}x=e[o+(y<<1)>>1]|0;A=x&511;B=w<<3;C=(x&32768|0)!=0;do{if((x&16384|0)==0){if(C){e5J(j,z,B,u,A,k);break}else{e5K(j,z,B,u,A,k);break}}else{if(C){e5H(j,z,B,u,A,k);break}else{e5I(j,z,B,u,A,k);break}}}while(0);A=v+1|0;B=w+1|0;if((B|0)<(p|0)){v=A;w=B}else{D=A;break}}}else{D=s}w=t+1|0;if((w|0)<64){s=D;t=w}else{break}}if(q){E=n+16384|0}else{E=0}n=c[2113068]|0;q=(c[2113070]|0)-1|0;t=(c[2388343]&511)+16-(c[2438631]|0)|0;D=c[2388333]|0;s=c[2438627]|0;p=d|0;d=(n|0)>0;z=(n|0)==0;y=0;o=(D&511)+s|0;r=D;while(1){D=o-r|0;w=t-(b[E+((D&511)<<1)>>1]&511)|0;v=o<<9&261632;if(d){u=e[l+((D+254+s&255)<<1)>>1]|0;D=(u&8|0)==0;A=(u&4|0)==0;B=(u&16|0)==0;C=(u&2|0)==0;if((u&65504|0)==65504){u=0;x=w;F=p;while(1){G=b[j+((x&511|v)<<1)>>1]|0;H=G&15;L52507:do{if(H<<16>>16==0){I=-32768}else{J=G&32752;K=G+10&65535;L=J|14;switch(H&65535|0){case 5:{I=J|15;break L52507;break};case 4:{I=L;break L52507;break};case 3:{I=A?K:L;break L52507;break};case 2:{I=D?K:L;break L52507;break};case 1:{I=D?K:L;break L52507;break};default:{I=K;break L52507}}}}while(0);b[F>>1]=I;H=u+1|0;if((H|0)<(n|0)){u=H;x=x+1|0;F=F+2|0}else{break}}}else{F=0;x=w;u=p;while(1){H=b[j+((x&511|v)<<1)>>1]|0;G=H&15;L52518:do{if(G<<16>>16==0){M=-32768}else{K=H&32752;L=K|4;J=K|5;K=B?L:L+5&65535;switch(G&65535|0){case 3:{M=A?H:K;break L52518;break};case 4:{M=K;break L52518;break};case 5:{M=C?J:J+5&65535;break L52518;break};case 1:{M=D?H:K;break L52518;break};case 2:{M=D?H:K;break L52518;break};default:{M=H;break L52518}}}}while(0);b[u>>1]=M;H=F+1|0;if((H|0)<(n|0)){F=H;x=x+1|0;u=u+2|0}else{break}}}}L52528:do{if(!z){u=f+((ag(n,y)|0)<<1)|0;x=p;F=n;while(1){D=F-1|0;C=b[x>>1]|0;if((C&65535)<32767){b[u>>1]=C}if((D|0)==0){break L52528}u=u+2|0;x=x+2|0;F=D}}}while(0);F=y+1|0;if((F|0)>(q|0)){break}y=F;o=o+1|0;r=c[2388333]|0}r=h+512|0;gGz(m|0,0,524288);m=c[3540978]|0;h=m+32768|0;o=c[3527054]|0;y=(c[2437032]|0)==0;M=(c[2437030]|0)+65535|0;I=0;s=0;while(1){if((o|0)>0){l=s<<3;E=I;t=0;while(1){F=E<<1;if(y){N=F;O=M&(e[h+((F|1)<<1)>>1]|0)}else{N=E;O=b[h+(E+8192<<1)>>1]&16383}F=e[h+(N<<1)>>1]|0;x=F&511;u=t<<3;D=(F&32768|0)!=0;do{if((F&16384|0)==0){if(D){e5J(j,O,u,l,x,k);break}else{e5K(j,O,u,l,x,k);break}}else{if(D){e5H(j,O,u,l,x,k);break}else{e5I(j,O,u,l,x,k);break}}}while(0);x=E+1|0;u=t+1|0;if((u|0)<(o|0)){E=x;t=u}else{P=x;break}}}else{P=I}t=s+1|0;if((t|0)<64){I=P;s=t}else{break}}if(y){Q=m+49152|0}else{Q=0}m=(c[2385824]&511)+16-(c[2438630]|0)|0;y=c[2385818]|0;s=c[2438626]|0;P=0;I=(y&511)+s|0;o=y;while(1){y=I-o|0;O=I<<9&261632;if(d){N=e[r+((y+254+s&255)<<1)>>1]|0;h=(N&65504|0)==65504;M=(N&8|0)==0;t=(N&4|0)==0;E=(N&16|0)==0;l=(N&2|0)==0;N=0;x=m-(b[Q+((y&511)<<1)>>1]&511)|0;y=p;while(1){u=b[j+((x&511|O)<<1)>>1]|0;D=u&15;L52570:do{if(D<<16>>16==0){R=-32768}else{F=u&32752;C=F|4;A=F|5;if(h){S=u+10&65535;T=F|15;U=F|14}else{S=u;T=l?A:A+5&65535;U=E?C:C+5&65535}switch(D&65535|0){case 2:{R=M?S:U;break L52570;break};case 3:{R=t?S:U;break L52570;break};case 4:{R=U;break L52570;break};case 5:{R=T;break L52570;break};case 1:{R=M?S:U;break L52570;break};default:{R=S;break L52570}}}}while(0);b[y>>1]=R;D=N+1|0;if((D|0)<(n|0)){N=D;x=x+1|0;y=y+2|0}else{break}}}L52584:do{if(!z){y=f+((ag(n,P)|0)<<1)|0;x=p;N=n;while(1){M=N-1|0;t=b[x>>1]|0;if((t&65535)<32767){b[y>>1]=t}if((M|0)==0){break L52584}y=y+2|0;x=x+2|0;N=M}}}while(0);N=P+1|0;if((N|0)>(q|0)){break}P=N;I=I+1|0;o=c[2385818]|0}e2d(0);e5F(0,k,f);R8(g);i=a;return}function e2b(){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;a[14129040]=19;a[14129041]=15;a[14129042]=-1;if((a[14129032]|0)==0){b=19}else{a[14129040]=18;b=18}if((a[14129033]|0)==0){c=b}else{d=b-2&255;a[14129040]=d;c=d}if((a[14129034]|0)==0){e=c}else{d=c|4;a[14129040]=d;e=d}if((a[14129035]|0)==0){f=e}else{d=e|8;a[14129040]=d;f=d}if((a[14129036]|0)==0){g=f}else{d=f-16&255;a[14129040]=d;g=d}if((a[14129037]|0)==0){h=g}else{d=g|32;a[14129040]=d;h=d}if((a[14129038]|0)==0){i=h}else{d=h|64;a[14129040]=d;i=d}if((a[14129039]|0)!=0){a[14129040]=i|-128}if((a[14129024]|0)==0){j=15}else{a[14129041]=14;j=14}if((a[14129025]|0)==0){k=j}else{i=j-2&255;a[14129041]=i;k=i}if((a[14129026]|0)==0){l=k}else{i=k-4&255;a[14129041]=i;l=i}if((a[14129027]|0)==0){m=l}else{i=l-8&255;a[14129041]=i;m=i}if((a[14129028]|0)==0){n=m}else{i=m|16;a[14129041]=i;n=i}if((a[14129029]|0)==0){o=n}else{i=n|32;a[14129041]=i;o=i}if((a[14129030]|0)==0){p=o}else{i=o|64;a[14129041]=i;p=i}if((a[14129031]|0)!=0){a[14129041]=p|-128}if((a[14129016]|0)==0){q=-1}else{a[14129042]=-2;q=-2}if((a[14129017]|0)==0){r=q}else{p=q-2&255;a[14129042]=p;r=p}if((a[14129018]|0)==0){s=r}else{p=r-4&255;a[14129042]=p;s=p}if((a[14129019]|0)==0){t=s}else{p=s-8&255;a[14129042]=p;t=p}if((a[14129020]|0)==0){u=t}else{p=t-16&255;a[14129042]=p;u=p}if((a[14129021]|0)==0){v=u}else{p=u-32&255;a[14129042]=p;v=p}if((a[14129022]|0)==0){w=v}else{p=v-64&255;a[14129042]=p;w=p}if((a[14129023]|0)==0){return}a[14129042]=w^-128;return}function e2c(){eZ8()|0;c[2438580]=0;c[2437014]=-1;return 0}function e2d(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;f=c[3531970]|0;g=c[3531958]|0;h=c[3531962]|0;i=c[3532034]|0;j=a[7460944]|0?16:0;k=c[3532004]|0;l=a[7461152]|0;m=j<<16;n=k<<16;o=c[2113068]|0;p=c[2113070]|0;q=c[2112926]|0;r=348;do{s=b[f+((r|2)<<1)>>1]|0;t=b[f+((r|3)<<1)>>1]|0;u=s&65535;v=(s&65535)>>>14&1;w=b[f+((r|1)<<1)>>1]|0;x=(w&65535)>>>15;y=u&511;z=b[f+(r<<1)>>1]|0;A=z&511;if(!(((s&65535)>>>15&65535|0)!=(d|0)|(A|0)==384)){s=(t&255)<<7;B=((z&65535)>>>9&255)+1&255;z=A+131-B|0;A=y>>>0>320?u|-512:y;y=(z|0)>320?z-512|0:z;z=v<<24>>24!=0;u=x<<16>>16!=0;C=(w&127)+1&255;w=(t&65535)>>>8<<4;t=x<<16>>16==0;x=v^1;D=0;do{E=(D|0)%8|0;F=(D|0)/8|0;G=E&255;H=F&255;I=e[g+(((z?7-E|0:E)&255)+s+((u?15-F|0:F)<<3&2040)<<1)>>1]|0;L52677:do{if((I&32768|0)==0){F=((ag(G,C)|0)>>>3)+A|0;E=((ag(H,B)|0)>>>4)+y|0;J=((ag(G+1|0,C)|0)>>>3)+A-F|0;K=E-16|0;L=J<<12&1044480;J=((ag(H+1|0,B)|0)>>>4)+y-E<<13&2088960;E=ag(ag(j,(I>>>0)%(i>>>0)|0)|0,k)|0;M=((ag(k,J)|0)+32768|0)>>>16;J=(ag(j,L)|0)>>>16;if(l){N=320-F-(L>>>12)|0;O=x}else{N=F;O=v}if((J|0)==0|(M|0)==0){break}F=(m>>>0)/(J>>>0)|0;L=(n>>>0)/(M>>>0)|0;P=N+J|0;Q=M+K|0;if(O<<24>>24==0){R=F;S=0}else{R=-F|0;S=ag(F,J-1|0)|0}if(t){T=L;U=0}else{T=-L|0;U=ag(L,M-1|0)|0}if((N|0)<0){V=0;W=S-(ag(R,N)|0)|0}else{V=N;W=S}if((K|0)<0){X=0;Y=U-(ag(T,K)|0)|0}else{X=K;Y=U}K=(P|0)>(o|0)?o:P;P=(Q|0)>(p|0)?p:Q;if((K|0)>(V|0)&(X|0)<(P|0)){Z=Y;_=X}else{break}while(1){Q=(ag(Z>>16,j)|0)+E|0;M=ag(_,o)|0;L=V;J=W;while(1){F=a[h+(Q+(J>>16))|0]|0;if(F<<24>>24!=0){b[q+(L+M<<1)>>1]=F&255|w}F=L+1|0;if((F|0)<(K|0)){L=F;J=J+R|0}else{break}}J=_+1|0;if((J|0)>=(P|0)){break L52677}Z=Z+T|0;_=J}}}while(0);D=D+1|0;}while((D|0)<128)}r=r-4|0;}while((r|0)>-1);return}function e2e(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=d&3;if((b|0)==0){return}d=b+255|0;a[14127752]=d&255;b=c[3531932]|0;e=d<<14&4177920;d=c[9757320+(c[1836236]<<2)>>2]|0;f=64;g=64;while(1){c[d+76+(g<<2)>>2]=b+((g<<8)+e);h=f+1&65535;if((h&65535)>127){i=64;j=64;break}else{f=h;g=h&65535}}while(1){g=b+((j<<8)+e)|0;c[d+76+(j+512<<2)>>2]=g;c[d+76+(j+768<<2)>>2]=g;g=i+1&65535;if((g&65535)>127){break}else{i=g;j=g&65535}}return}function e2f(){var a=0,b=0,e=0;a=c[2437014]|0;if((a|0)!=-1){b=a&15;c[2415126]=9662152;if((c[2415542]|0)==4){e=b}else{e=b<<1&14}c[2415538]=e;c[2437014]=-1;return}e=c[2438580]|0;b=d[(c[3532062]|0)+e|0]|0;c[2437014]=b;c[2438580]=e+1&65535;e=b>>>4;c[2415126]=9662152;if((c[2415542]|0)==4){c[2415538]=e;return}else{c[2415538]=e<<1&14;return}}function e2g(){var a=0,d=0,e=0,f=0,g=0,h=0;a=c[2112926]|0;gGz(a|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);d=c[3532028]|0;e=0;f=c[3532026]|0;g=d;while(1){h=b[f>>1]|0;c[g>>2]=((h&65535)>>>10<<3&248)>>>3|((h&255)<<3&255)<<8|(((h&65535)>>>7&4|(h&65535)>>>5<<3&255)&255)<<3&2016;h=e+1|0;if((h|0)<8192){e=h;f=f+2|0;g=g+4|0}else{break}}g=c[3532136]|0;e5F(1,g,a);e5G(0,0,g,a);e5L(c[3531962]|0);R8(d);return}function e2h(){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;a[14128320]=-1;a[14128321]=-1;a[14128322]=-113;a[14128323]=31;if((a[14128312]|0)==0){b=-1}else{a[14128320]=-2;b=-2}if((a[14128313]|0)==0){c=b}else{d=b-2&255;a[14128320]=d;c=d}if((a[14128314]|0)==0){e=c}else{d=c-4&255;a[14128320]=d;e=d}if((a[14128315]|0)==0){f=e}else{d=e-8&255;a[14128320]=d;f=d}if((a[14128316]|0)==0){g=f}else{d=f-16&255;a[14128320]=d;g=d}if((a[14128317]|0)==0){h=g}else{d=g-32&255;a[14128320]=d;h=d}if((a[14128318]|0)==0){i=h}else{d=h-64&255;a[14128320]=d;i=d}if((a[14128319]|0)!=0){a[14128320]=i^-128}if((a[14128304]|0)==0){j=-1}else{a[14128321]=-2;j=-2}if((a[14128305]|0)==0){k=j}else{i=j-2&255;a[14128321]=i;k=i}if((a[14128306]|0)==0){l=k}else{i=k-4&255;a[14128321]=i;l=i}if((a[14128307]|0)==0){m=l}else{i=l-8&255;a[14128321]=i;m=i}if((a[14128308]|0)==0){n=m}else{i=m-16&255;a[14128321]=i;n=i}if((a[14128309]|0)==0){o=n}else{i=n-32&255;a[14128321]=i;o=i}if((a[14128310]|0)==0){p=o}else{i=o-64&255;a[14128321]=i;p=i}if((a[14128311]|0)!=0){a[14128321]=p^-128}if((a[14128288]|0)==0){q=31}else{a[14128323]=30;q=30}if((a[14128289]|0)==0){r=q}else{p=q-2&255;a[14128323]=p;r=p}if((a[14128290]|0)==0){s=r}else{p=r-4&255;a[14128323]=p;s=p}if((a[14128291]|0)==0){t=s}else{p=s-8&255;a[14128323]=p;t=p}if((a[14128292]|0)==0){u=t}else{p=t-16&255;a[14128323]=p;u=p}if((a[14128293]|0)==0){v=u}else{p=u|32;a[14128323]=p;v=p}if((a[14128294]|0)==0){w=v}else{p=v|64;a[14128323]=p;w=p}if((a[14128295]|0)==0){return}a[14128323]=w|-128;return}function e2i(){eZ8()|0;c[2438580]=0;c[2437014]=-1;return 0}function e2j(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;a=c[2112926]|0;gGz(a|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);d=c[3532028]|0;f=0;g=c[3532026]|0;h=d;while(1){i=b[g>>1]|0;j=i&255;k=(i&65535)>>>4;l=(i&65535)>>>8;c[h>>2]=((l<<4&255|l&8)&255)>>>3|((j<<4|j&8)&255)<<8&63488|((k<<4&255|k&12)&255)<<3&2016;k=f+1|0;if((k|0)<2048){f=k;g=g+2|0;h=h+4|0}else{break}}c[2385824]=16;c[2385818]=0;h=c[3532136]|0;e5F(1,h,a);g=(c[3540974]|0)>>>1&112;f=c[3531970]|0;k=c[3531962]|0;j=1016;do{l=b[f+(j<<1)>>1]|0;i=l&65535;L52814:do{if((l&65535)<5120){m=(e[f+((j|1)<<1)>>1]|0)+15&511^511;n=(e[f+((j|2)<<1)>>1]|0)+456|0;o=n&511;p=o>>>0>400?n|-512:o;o=e[f+((j|3)<<1)>>1]|0;n=b[f+((j|4)<<1)>>1]&15|g;q=o&64;r=o&128;o=(m>>>0>400?m|-512:m)-15|0;do{if((p|0)>16){if(!((p|0)<((c[2113068]|0)-16|0)&(o|0)>16)){break}if((o|0)>=((c[2113070]|0)-16|0)){break}m=(r|0)!=0;if((q|0)==0){if(m){SK(a,i,p,o,n,4,15,0,k);break L52814}else{SG(a,i,p,o,n,4,15,0,k);break L52814}}else{if(m){SM(a,i,p,o,n,4,15,0,k);break L52814}else{SI(a,i,p,o,n,4,15,0,k);break L52814}}}}while(0);m=(r|0)!=0;if((q|0)==0){if(m){SL(a,i,p,o,n,4,15,0,k);break}else{SH(a,i,p,o,n,4,15,0,k);break}}else{if(m){SN(a,i,p,o,n,4,15,0,k);break}else{SJ(a,i,p,o,n,4,15,0,k);break}}}}while(0);j=j-8|0;}while((j|0)>-1);e5G(0,0,h,a);R8(d);return}function e2k(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;c[3532080]=-1;if((a[14128312]|0)==0){b=-1}else{a[14128320]=-2;b=-2}if((a[14128313]|0)==0){d=b}else{e=b-2&255;a[14128320]=e;d=e}if((a[14128314]|0)==0){f=d}else{e=d-4&255;a[14128320]=e;f=e}if((a[14128315]|0)==0){g=f}else{e=f-8&255;a[14128320]=e;g=e}if((a[14128316]|0)==0){h=g}else{e=g-16&255;a[14128320]=e;h=e}if((a[14128317]|0)==0){i=h}else{e=h-32&255;a[14128320]=e;i=e}if((a[14128318]|0)==0){j=i}else{e=i-64&255;a[14128320]=e;j=e}if((a[14128319]|0)!=0){a[14128320]=j^-128}if((a[14128304]|0)==0){k=-1}else{a[14128321]=-2;k=-2}if((a[14128305]|0)==0){l=k}else{j=k-2&255;a[14128321]=j;l=j}if((a[14128306]|0)==0){m=l}else{j=l-4&255;a[14128321]=j;m=j}if((a[14128307]|0)==0){n=m}else{j=m-8&255;a[14128321]=j;n=j}if((a[14128308]|0)==0){o=n}else{j=n-16&255;a[14128321]=j;o=j}if((a[14128309]|0)==0){p=o}else{j=o-32&255;a[14128321]=j;p=j}if((a[14128310]|0)==0){q=p}else{j=p-64&255;a[14128321]=j;q=j}if((a[14128311]|0)==0){return}a[14128321]=q^-128;return}function e2l(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=d+3&3;a[14127752]=b;d=c[3531932]|0;e=(b&255)<<14;b=c[9757320+(c[1836236]<<2)>>2]|0;f=64;g=64;while(1){c[b+76+(g<<2)>>2]=d+((g<<8)+e);h=f+1&65535;if((h&65535)>127){i=64;j=64;break}else{f=h;g=h&65535}}while(1){g=d+((j<<8)+e)|0;c[b+76+(j+512<<2)>>2]=g;c[b+76+(j+768<<2)>>2]=g;g=i+1&65535;if((g&65535)>127){break}else{i=g;j=g&65535}}return}function e2m(){var a=0,d=0,e=0,f=0,g=0,h=0;a=c[2112926]|0;gGz(a|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);d=c[3532028]|0;e=0;f=c[3532026]|0;g=d;while(1){h=b[f>>1]|0;c[g>>2]=((h&65535)>>>10<<3&248)>>>3|((h&255)<<3&255)<<8|(((h&65535)>>>7&4|(h&65535)>>>5<<3&255)&255)<<3&2016;h=e+1|0;if((h|0)<8192){e=h;f=f+2|0;g=g+4|0}else{break}}g=c[3532136]|0;e5F(1,g,a);e5L(c[3531962]|0);e5G(0,0,g,a);R8(d);return}function e2n(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;a[14128320]=-1;a[14128321]=-4;a[14128322]=-1;a[14128323]=-1;if((a[14128312]|0)==0){e=-1}else{a[14128320]=-2;e=-2}if((a[14128313]|0)==0){f=e}else{g=e-2&255;a[14128320]=g;f=g}if((a[14128314]|0)==0){h=f}else{g=f-4&255;a[14128320]=g;h=g}if((a[14128315]|0)==0){i=h}else{g=h-8&255;a[14128320]=g;i=g}if((a[14128316]|0)==0){j=i}else{g=i-16&255;a[14128320]=g;j=g}if((a[14128317]|0)==0){k=j}else{g=j-32&255;a[14128320]=g;k=g}if((a[14128318]|0)==0){l=k}else{g=k-64&255;a[14128320]=g;l=g}if((a[14128319]|0)==0){m=l}else{g=l^-128;a[14128320]=g;m=g}if((a[14128304]|0)==0){n=-4}else{a[14128321]=-3;n=-3}if((a[14128305]|0)==0){o=n}else{g=n|2;a[14128321]=g;o=g}if((a[14128306]|0)==0){p=o}else{g=o-4&255;a[14128321]=g;p=g}if((a[14128307]|0)==0){q=p}else{g=p-8&255;a[14128321]=g;q=g}if((a[14128308]|0)==0){r=q}else{g=q-16&255;a[14128321]=g;r=g}if((a[14128309]|0)==0){s=r}else{g=r-32&255;a[14128321]=g;s=g}if((a[14128310]|0)==0){t=s}else{g=s-64&255;a[14128321]=g;t=g}if((a[14128311]|0)==0){u=t}else{g=t^-128;a[14128321]=g;u=g}if((a[14128296]|0)==0){v=-1}else{a[14128322]=-2;v=-2}if((a[14128297]|0)==0){w=v}else{g=v-2&255;a[14128322]=g;w=g}if((a[14128298]|0)==0){x=w}else{g=w-4&255;a[14128322]=g;x=g}if((a[14128299]|0)==0){y=x}else{g=x-8&255;a[14128322]=g;y=g}if((a[14128300]|0)==0){z=y}else{g=y-16&255;a[14128322]=g;z=g}if((a[14128301]|0)==0){A=z}else{g=z-32&255;a[14128322]=g;A=g}if((a[14128302]|0)==0){B=A}else{g=A-64&255;a[14128322]=g;B=g}if((a[14128303]|0)==0){C=B}else{g=B^-128;a[14128322]=g;C=g}if((a[14128288]|0)==0){D=-1}else{a[14128323]=-2;D=-2}if((a[14128289]|0)==0){E=D}else{g=D-2&255;a[14128323]=g;E=g}if((a[14128290]|0)==0){F=E}else{g=E-4&255;a[14128323]=g;F=g}if((a[14128291]|0)==0){G=F}else{g=F-8&255;a[14128323]=g;G=g}if((a[14128292]|0)==0){H=G}else{g=G-16&255;a[14128323]=g;H=g}if((a[14128293]|0)==0){I=H}else{g=H-32&255;a[14128323]=g;I=g}if((a[14128294]|0)==0){J=I}else{g=I-64&255;a[14128323]=g;J=g}if((a[14128295]|0)==0){K=J}else{g=J^-128;a[14128323]=g;K=g}g=c[2424897]|0;J=g+256|0;if((a[J]|0)==1){I=a[g+321|0]|0;H=I&255;gGC(g|0,7452240,321)|0;G=c[2424898]|0;gGC(G|0,7452136,98)|0;G=b[945368+(H<<1)>>1]|0;a[g+1|0]=G&255;a[g+2|0]=(G&65535)>>>8&255;G=c[801416+(H<<2)>>2]|0;a[g+322|0]=G>>>24&255;a[g+323|0]=G>>>16&255;a[g+324|0]=G>>>8&255;a[g+325|0]=G&255;if((I&255)>39){L=1}else{L=(H&3|0)==3|0}a[g+328|0]=L;a[J]=-1}J=c[2424901]|0;if((a[J]|0)==1){L=(d[(c[2424896]|0)+13|0]|0)>>>2;H=(c[2443344]|0)==0;if(H){M=L}else{M=d[600592+L|0]|0}L=(c[2424900]|0)+2|0;I=c[7452056+(M<<3)>>2]|0;G=c[7452060+(M<<3)>>2]|0;gGC(L|0,I|0,G)|0;G=J+2|0;I=c[7451976+(M<<3)>>2]|0;L=c[7451980+(M<<3)>>2]|0;gGC(G|0,I|0,L)|0;L=(c[2424903]|0)+2|0;I=c[7451576+(M<<3)>>2]|0;F=c[7451580+(M<<3)>>2]|0;gGC(L|0,I|0,F)|0;if(H){H=(c[2424902]|0)+2|0;gGC(H|0,7451656,320)|0}else{H=0;do{F=b[1115008+(M<<4)+(H<<1)>>1]|0;if(F<<16>>16!=0){I=H*22|0;a[J+(I+18+(d[G]|0))|0]=F&255;a[J+(I+19+(d[G]|0))|0]=(F&65535)>>>8&255}H=H+1|0;}while((H|0)<8);H=(c[2424902]|0)+2|0;gGC(H|0,1992360,320)|0}a[J]=-1}if((a[g+329|0]|0)!=1){N=c[2424896]|0;O=N+3|0;a[O]=m;P=N+4|0;a[P]=u;Q=N+5|0;a[Q]=C;R=N+6|0;a[R]=K;return}g=(cT()|0)%15|0;J=c[2424897]|0;a[J+331|0]=0;a[J+333|0]=16;a[J+335|0]=32;a[J+337|0]=56;a[J+339|0]=80;a[J+341|0]=96;a[J+330|0]=a[6599048+(g*6|0)|0]|0;a[J+332|0]=a[6599049+(g*6|0)|0]|0;a[J+334|0]=a[6599050+(g*6|0)|0]|0;a[J+336|0]=a[6599051+(g*6|0)|0]|0;a[J+338|0]=a[6599052+(g*6|0)|0]|0;a[J+340|0]=a[6599053+(g*6|0)|0]|0;a[J+329|0]=-1;N=c[2424896]|0;O=N+3|0;a[O]=m;P=N+4|0;a[P]=u;Q=N+5|0;a[Q]=C;R=N+6|0;a[R]=K;return}function e2o(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];a=c[3532592]|0;if((a|0)!=0){gGC(9104152,a|0,280)|0}c[2113054]=c[2113060]}RI();a=c[2394]|0;d=c[14130368+(a<<2)>>2]|0;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[8452240+(a<<2)>>2]=c[2113054];c[2394]=-1;a=c[2439330]|0;d=(a|0)==0;if(!d){e=a;gGC(9706056,e|0,76)|0}e=c[2438118]|0;c[2433530]=e;f=c[3528484]|0;c[2076596]=f;g=c[2417276]|0;c[3541536]=g;c[1836236]=0;gGz(9706056,0,76);if(d){c[2438118]=e;c[3528484]=f;c[2417276]=g;c[1836236]=-1;h=0}else{d=a;gGC(d|0,9706056,76)|0;c[2438118]=e;c[3528484]=f;c[2417276]=g;c[1836236]=-1;h=c[2426515]&65535}b[4853030]=h;c[2433530]=e;c[2076596]=f;c[3541536]=g;c[1836236]=0;mx(0);g=c[1836236]|0;f=c[9757320+(g<<2)>>2]|0;if((f|0)==0){i=c[2433530]|0;j=9752472+(g<<2)|0;c[j>>2]=i;k=c[2076596]|0;l=14113936+(g<<2)|0;c[l>>2]=k;m=c[3541536]|0;n=9669104+(g<<2)|0;c[n>>2]=m;c[1836236]=-1;return 0}e=f;gGC(e|0,9706056,76)|0;i=c[2433530]|0;j=9752472+(g<<2)|0;c[j>>2]=i;k=c[2076596]|0;l=14113936+(g<<2)|0;c[l>>2]=k;m=c[3541536]|0;n=9669104+(g<<2)|0;c[n>>2]=m;c[1836236]=-1;return 0}function e2p(){var a=0,b=0,e=0,f=0;a=c[2437034]|0;if((a|0)==-1){b=c[2438632]|0;e=d[(c[3532062]|0)+b|0]|0;c[2437034]=e;c[2438632]=b+1&524287;b=e>>>4;c[2415126]=9662152;if((c[2415542]|0)==4){c[2415538]=b;return}else{c[2415538]=b<<1&14;return}}b=a&15;c[2415126]=9662152;if((c[2415542]|0)==4){f=b}else{f=b<<1&14}c[2415538]=f;c[2437034]=-1;if((c[2438632]|0)!=(c[2438634]|0)){return}c[2415126]=9662152;c[2415540]=1;return}function e2q(){var a=0,b=0,e=0,f=0;a=c[2437035]|0;if((a|0)==-1){b=c[2438633]|0;e=d[(c[3532062]|0)+b|0]|0;c[2437035]=e;c[2438633]=b+1&524287;b=e>>>4;c[2415126]=9665376;if((c[2416348]|0)==4){c[2416344]=b;return}else{c[2416344]=b<<1&14;return}}b=a&15;c[2415126]=9665376;if((c[2416348]|0)==4){f=b}else{f=b<<1&14}c[2416344]=f;c[2437035]=-1;if((c[2438633]|0)!=(c[2438635]|0)){return}c[2415126]=9665376;c[2416346]=1;return}function e2r(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[2112926]|0;gGz(a|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);d=c[3532028]|0;e=0;f=c[3532026]|0;g=d;while(1){h=b[f>>1]|0;i=(h&65535)>>>8;j=(h&65535)>>>4;k=h&255;c[g>>2]=((j<<4&255|j&12)&255)<<3&2016|((k<<4|k&8)&255)>>>3|((i<<4&255|i&8)&255)<<8&63488;i=e+1|0;if((i|0)<2048){e=i;f=f+2|0;g=g+4|0}else{break}}g=c[3532136]|0;e5F(1,g,a);e5L(c[3531962]|0);e5G(0,0,g,a);R8(d);d=c[2113302]|0;if((d|0)>0){l=0}else{return}do{R7(l,c[14168784+(l<<2)>>2]>>8,c[14168768+(l<<2)>>2]>>8);l=l+1|0;}while((l|0)<(d|0));return}function e2s(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;a[14128320]=-4;a[14128321]=-1;a[14128322]=-1;a[14128323]=-1;if((a[14128312]|0)==0){b=-4}else{a[14128320]=-3;b=-3}if((a[14128313]|0)==0){d=b}else{e=b|2;a[14128320]=e;d=e}if((a[14128314]|0)==0){f=d}else{e=d-4&255;a[14128320]=e;f=e}if((a[14128315]|0)==0){g=f}else{e=f-8&255;a[14128320]=e;g=e}if((a[14128316]|0)==0){h=g}else{e=g-16&255;a[14128320]=e;h=e}if((a[14128317]|0)==0){i=h}else{e=h-32&255;a[14128320]=e;i=e}if((a[14128318]|0)==0){j=i}else{e=i-64&255;a[14128320]=e;j=e}if((a[14128319]|0)!=0){a[14128320]=j^-128}if((a[14128304]|0)==0){k=-1}else{a[14128321]=-2;k=-2}if((a[14128305]|0)==0){l=k}else{j=k-2&255;a[14128321]=j;l=j}if((a[14128306]|0)==0){m=l}else{j=l-4&255;a[14128321]=j;m=j}if((a[14128307]|0)==0){n=m}else{j=m-8&255;a[14128321]=j;n=j}if((a[14128308]|0)==0){o=n}else{j=n-16&255;a[14128321]=j;o=j}if((a[14128309]|0)==0){p=o}else{j=o-32&255;a[14128321]=j;p=j}if((a[14128310]|0)==0){q=p}else{j=p-64&255;a[14128321]=j;q=j}if((a[14128311]|0)!=0){a[14128321]=q^-128}q=c[3532184]|0;j=(c[3542196]|0)+(c[3532186]<<16>>16)|0;c[3542196]=j;p=(c[3542192]|0)+(q<<16>>16)|0;c[3542192]=p;if((j|0)<-2048){c[3542196]=-2048;r=-2048}else{r=j}j=(c[2440576]<<8)-2048|0;if((r|0)>(j|0)){c[3542196]=j}if((p|0)<-2048){c[3542192]=-2048;s=-2048}else{s=p}p=(c[2440574]<<8)-2048|0;if((s|0)<=(p|0)){return}c[3542192]=p;return}function e2t(){var a=0,d=0,e=0,f=0,g=0,h=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];a=c[3532592]|0;if((a|0)!=0){gGC(9104152,a|0,280)|0}c[2113054]=c[2113060]}RI();a=c[2394]|0;d=c[14130368+(a<<2)>>2]|0;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[8452240+(a<<2)>>2]=c[2113054];c[2394]=-1;a=c[2439330]|0;d=(a|0)==0;if(!d){e=a;gGC(9706056,e|0,76)|0}e=c[2438118]|0;c[2433530]=e;f=c[3528484]|0;c[2076596]=f;g=c[2417276]|0;c[3541536]=g;c[1836236]=0;gGz(9706056,0,76);if(d){c[2438118]=e;c[3528484]=f;c[2417276]=g;c[1836236]=-1;h=0}else{d=a;gGC(d|0,9706056,76)|0;c[2438118]=e;c[3528484]=f;c[2417276]=g;c[1836236]=-1;h=c[2426515]&65535}b[4853030]=h;c[2433530]=e;c[2076596]=f;c[3541536]=g;c[1836236]=0;mx(0);g=c[1836236]|0;f=c[9757320+(g<<2)>>2]|0;if((f|0)!=0){e=f;gGC(e|0,9706056,76)|0}c[9752472+(g<<2)>>2]=c[2433530];c[14113936+(g<<2)>>2]=c[2076596];c[9669104+(g<<2)>>2]=c[3541536];c[1836236]=-1;UA();g=9757696;c[g>>2]=0;c[g+4>>2]=0;g=9757688;c[g>>2]=0;c[g+4>>2]=0;c[2438633]=0;c[2438632]=0;c[2438635]=0;c[2438634]=0;c[2437035]=-1;c[2437034]=-1;c[2415540]=1;c[2415126]=9665376;c[2416346]=1;return 0}function e2u(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;a[14128320]=-4;a[14128321]=-1;a[14128322]=-1;a[14128323]=-1;if((a[14128312]|0)==0){f=-4}else{a[14128320]=-3;f=-3}if((a[14128313]|0)==0){g=f}else{h=f|2;a[14128320]=h;g=h}if((a[14128314]|0)==0){i=g}else{h=g-4&255;a[14128320]=h;i=h}if((a[14128315]|0)==0){j=i}else{h=i-8&255;a[14128320]=h;j=h}if((a[14128316]|0)==0){k=j}else{h=j-16&255;a[14128320]=h;k=h}if((a[14128317]|0)==0){l=k}else{h=k-32&255;a[14128320]=h;l=h}if((a[14128318]|0)==0){m=l}else{h=l-64&255;a[14128320]=h;m=h}if((a[14128319]|0)==0){n=m}else{h=m^-128;a[14128320]=h;n=h}if((a[14128304]|0)==0){o=-1}else{a[14128321]=-2;o=-2}if((a[14128305]|0)==0){p=o}else{h=o-2&255;a[14128321]=h;p=h}if((a[14128306]|0)==0){q=p}else{h=p-4&255;a[14128321]=h;q=h}if((a[14128307]|0)==0){r=q}else{h=q-8&255;a[14128321]=h;r=h}if((a[14128308]|0)==0){s=r}else{h=r-16&255;a[14128321]=h;s=h}if((a[14128309]|0)==0){t=s}else{h=s-32&255;a[14128321]=h;t=h}if((a[14128310]|0)==0){u=t}else{h=t-64&255;a[14128321]=h;u=h}if((a[14128311]|0)==0){v=u}else{h=u^-128;a[14128321]=h;v=h}h=c[3532184]|0;u=(c[3542196]|0)+(c[3532186]<<16>>16)|0;c[3542196]=u;t=(c[3542192]|0)+(h<<16>>16)|0;c[3542192]=t;if((u|0)<-2048){c[3542196]=-2048;w=-2048}else{w=u}u=(c[2440576]<<8)-2048|0;if((w|0)>(u|0)){c[3542196]=u}if((t|0)<-2048){c[3542192]=-2048;x=-2048}else{x=t}t=(c[2440574]<<8)-2048|0;if((x|0)>(t|0)){c[3542192]=t}t=c[2406600]|0;x=t+4|0;a[x]=n;u=t+5|0;a[u]=v;do{if(n<<24>>24!=(a[9774624]|0)){v=(n&2)==0?((n&1)-1&255)<<24>>24:1;do{if((v|0)!=-1){w=14124928+v|0;h=(a[w]|0)+1&255;a[w]=h;s=818400+v|0;if((h&255)<(d[s]|0)){break}h=t+83|0;a[h]=(a[h]|0)+(a[818392+v|0]|0)&255;a[t+81|0]=85;a[t+82|0]=85;a[w]=(a[w]|0)-(a[s]|0)&255}}while(0);v=t+83|0;if((d[v]|0)<=9){break}a[v]=9}}while(0);a[9774624]=a[x]|0;x=a[u]|0;if(x<<24>>24!=(a[9774616]|0)&(x&4)==0){u=t+83|0;a[u]=(a[u]|0)+1&255;a[t+81|0]=85;a[t+82|0]=85}a[9774616]=x;x=t+27|0;do{if((a[x]|0)==6){u=a[9698768]|0;do{if(u<<24>>24==0){if((a[t+114|0]&120)>>>0<=7){y=0;break}n=t+116|0;if((a[n]|0)!=0){y=0;break}if((a[t+28|0]|0)!=0){y=0;break}if((a[t+29|0]|0)!=0){y=0;break}if((a[t+31|0]|0)!=0){y=0;break}a[t+48|0]=1;a[n]=1;a[9698768]=1;y=1}else{y=u}}while(0);u=t+26|0;if((a[u]|0)==-112){a[t+116|0]=0;z=a[9698768]|0}else{z=y}do{if(z<<24>>24!=0&(a[9698776]|0)==0){if((a[t+39|0]|0)!=0){break}n=t+117|0;if((a[n]|0)!=0){break}if((a[t+28|0]|0)!=0){break}if((a[t+29|0]|0)!=0){break}if((a[t+30|0]|0)!=0){break}if((a[t+31|0]|0)!=0){break}a[t+49|0]=1;a[n]=1;a[9698776]=1}}while(0);n=t+43|0;do{if((a[n]|0)==1){a[n]=0;do{if((a[t+48|0]|0)==1){v=a[u]|0;if(v<<24>>24==-112){break}a[u]=v-1&255}}while(0);v=t+114|0;if((a[v]|0)!=9){s=a[9698784]|-128;a[9698784]=s;a[v]=s;a[9698784]=(a[9698784]|0)+1&255;a[u]=(a[u]|0)-3&255;break}s=t+118|0;if((a[s]|0)==4){break}a[s]=3}}while(0);u=t+118|0;if((a[u]|0)!=0){break}a[u]=1;u=a[t+21|0]&3;if((u|0)==3){a[t+44|0]=70;a[t+119|0]=5;a[t+37|0]=17;a[t+38|0]=14;break}else if((u|0)==0){a[t+44|0]=48;a[t+119|0]=6;a[t+37|0]=11;a[t+38|0]=3;break}else if((u|0)==1){a[t+44|0]=58;a[t+119|0]=5;a[t+37|0]=15;a[t+38|0]=9;break}else if((u|0)==2){a[t+44|0]=76;a[t+119|0]=4;a[t+37|0]=25;a[t+38|0]=17;break}else{break}}}while(0);if((d[t+52|0]|0)<2){z=a[t+21|0]&3;if((z|0)==1){a[t+44|0]=49;a[t+119|0]=5;a[t+37|0]=15;a[t+38|0]=11}else if((z|0)==2){a[t+44|0]=60;a[t+119|0]=4;a[t+37|0]=19;a[t+38|0]=15}else if((z|0)==3){a[t+44|0]=49;a[t+119|0]=5;a[t+37|0]=15;a[t+38|0]=11}else if((z|0)==0){a[t+44|0]=32;a[t+119|0]=6;a[t+37|0]=7;a[t+38|0]=3}a[t+118|0]=0;a[t+117|0]=0;a[t+116|0]=0;a[t+114|0]=0;a[t+113|0]=0;a[t+112|0]=0;a[t+102|0]=0;a[t+43|0]=0;a[t+48|0]=0;a[t+49|0]=0;a[t+50|0]=0;a[t+39|0]=0;a[9698784]=0;a[9698776]=0;a[9698768]=0}do{if((a[t+28|0]|0)==0){if((a[t+29|0]|0)!=0){break}if((a[t+30|0]|0)!=0){break}if((a[t+31|0]|0)!=0){break}if((a[t+32|0]|0)!=0){break}if((a[x]|0)!=6){a[t+50|0]=1;break}if((a[t+39|0]|0)!=1){break}a[t+50|0]=1}}while(0);z=t+14|0;if((a[z]|0)==1){a[z]=-3;a[t+97|0]=4}z=t+122|0;y=a[z]|0;if(y<<24>>24!=0|(a[9774608]|0)==0|(a[14124912]|0)==-11){A=y}else{a[14124912]=-11;y=c[1087056+(d[x]<<2)>>2]|0;x=0;do{u=y+(x<<1)|0;n=x<<1;a[t+(n+512)|0]=(e[u>>1]|0)>>>8&255;a[t+(n+513)|0]=b[u>>1]&255;x=x+1|0;}while((x|0)<204);a[t]=0;a[t+118|0]=0;a[t+117|0]=0;a[t+116|0]=0;a[t+114|0]=0;a[t+113|0]=0;a[t+112|0]=0;a[t+102|0]=0;a[t+43|0]=0;a[t+48|0]=0;a[t+49|0]=0;a[t+50|0]=0;a[t+39|0]=0;a[9698784]=0;a[9698776]=0;a[9698768]=0;a[t+26|0]=0;a[z]=1;a[14124912]=0;A=a[z]|0}a[9774608]=A;if((a[t+127|0]|0)!=10){B=t+100|0;a[B]=0;C=t+102|0;a[C]=0;return}a[t+254|0]=-9;a[t+255|0]=110;B=t+100|0;a[B]=0;C=t+102|0;a[C]=0;return}function e2v(b,e){b=b|0;e=e|0;var f=0,g=0,i=0,j=0.0;b=c[9774520+((e>>>4&15)<<2)>>2]|0;a[9553280]=b&255;f=c[9774520+((e&15)<<2)>>2]|0;a[9553286]=f&255;e=d[9553288]|0;g=f&255;f=(ag(e,g)|0)>>>8;i=(ag(e^255,g)|0)>>>8;j=+h[85282];h[146579]=j*+(f|0)/100.0;h[118364]=j*+(i|0)/100.0;i=d[9553290]|0;f=b&255;b=(ag(f,i)|0)>>>8;g=(ag(i^255,f)|0)>>>8;j=+h[85166];h[146578]=j*+(b|0)/100.0;h[118363]=j*+(g|0)/100.0;return}function e2w(b,e){b=b|0;e=e|0;var f=0,g=0,i=0,j=0,k=0.0;b=c[9774520+((e>>>4&15)<<2)>>2]|0;a[9553281]=b&255;f=c[9774520+((e&15)<<2)>>2]|0;a[9553282]=f&255;e=d[9553290]|0;g=b&255;b=(ag(e,g)|0)>>>8;i=e^255;j=(ag(i,g)|0)>>>8;k=+h[85166];h[146577]=k*+(b|0)/100.0;h[118362]=k*+(j|0)/100.0;j=f&255;f=(ag(j,e)|0)>>>8;e=(ag(i,j)|0)>>>8;h[146576]=k*+(f|0)/100.0;h[118361]=k*+(e|0)/100.0;return}function e2x(b,e){b=b|0;e=e|0;var f=0,g=0,i=0,j=0.0;b=c[9774520+((e>>>4&15)<<2)>>2]|0;a[9553283]=b&255;f=c[9774520+((e&15)<<2)>>2]|0;a[9553287]=f&255;e=d[9553289]|0;g=f&255;f=(ag(e,g)|0)>>>8;i=(ag(e^255,g)|0)>>>8;j=+h[85282];h[146575]=j*+(f|0)/100.0;h[118360]=j*+(i|0)/100.0;i=d[9553291]|0;f=b&255;b=(ag(f,i)|0)>>>8;g=(ag(i^255,f)|0)>>>8;j=+h[85166];h[146574]=j*+(b|0)/100.0;h[118359]=j*+(g|0)/100.0;return}function e2y(b,e){b=b|0;e=e|0;var f=0,g=0,i=0,j=0,k=0.0;b=c[9774520+((e>>>4&15)<<2)>>2]|0;a[9553284]=b&255;f=c[9774520+((e&15)<<2)>>2]|0;a[9553285]=f&255;e=d[9553291]|0;g=b&255;b=(ag(e,g)|0)>>>8;i=e^255;j=(ag(i,g)|0)>>>8;k=+h[85166];h[146573]=k*+(b|0)/100.0;h[118358]=k*+(j|0)/100.0;j=f&255;f=(ag(j,e)|0)>>>8;e=(ag(i,j)|0)>>>8;h[146572]=k*+(f|0)/100.0;h[118357]=k*+(e|0)/100.0;return}function e2z(){if((c[2437782]|0)==0){return}if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12;return}function e2A(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;a=c[2112926]|0;gGz(a|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);d=c[3532028]|0;f=0;g=c[3532026]|0;h=d;while(1){i=b[g>>1]|0;c[h>>2]=((i&65535)>>>10<<3&248)>>>3|((i&255)<<3&255)<<8|(((i&65535)>>>7&4|(i&65535)>>>5<<3&255)&255)<<3&2016;i=f+1|0;if((i|0)<8192){f=i;g=g+2|0;h=h+4|0}else{break}}h=c[3532136]|0;e5F(1,h,a);e2D(0);e5G(0,0,h,a);e2D(1);h=c[3531958]|0;g=(c[3532040]|0)+65535|0;f=c[3532134]|0;i=0;j=0;while(1){k=i<<3;l=(k|0)>8;m=j;n=0;while(1){o=g&(e[h+(m+8192<<1)>>1]|0);p=e[h+(m<<1)>>1]|0;q=p<<2&1020;r=p>>>14&1;s=p>>>15;p=n<<3;do{if((p|0)>8){if(!((p|0)<((c[2113068]|0)-8|0)&l)){t=40666;break}if((k|0)>=((c[2113070]|0)-8|0)){t=40666;break}u=(s|0)!=0;if((r|0)==0){if(u){Su(a,o,p,k,q,2,0,0,f);break}else{Sq(a,o,p,k,q,2,0,0,f);break}}else{if(u){Sw(a,o,p,k,q,2,0,0,f);break}else{Ss(a,o,p,k,q,2,0,0,f);break}}}else{t=40666}}while(0);do{if((t|0)==40666){t=0;u=(s|0)!=0;if((r|0)==0){if(u){Sv(a,o,p,k,q,2,0,0,f);break}else{Sr(a,o,p,k,q,2,0,0,f);break}}else{if(u){Sx(a,o,p,k,q,2,0,0,f);break}else{St(a,o,p,k,q,2,0,0,f);break}}}}while(0);q=n+1|0;if((q|0)<128){m=m+1|0;n=q}else{break}}n=i+1|0;if((n|0)<64){i=n;j=j+128|0}else{break}}R8(d);return}function e2B(){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;a[14128320]=-1;a[14128321]=-1;a[14128322]=-4;a[14128323]=-1;if((a[14128312]|0)==0){b=-1}else{a[14128320]=-2;b=-2}if((a[14128313]|0)==0){c=b}else{d=b-2&255;a[14128320]=d;c=d}if((a[14128314]|0)==0){e=c}else{d=c-4&255;a[14128320]=d;e=d}if((a[14128315]|0)==0){f=e}else{d=e-8&255;a[14128320]=d;f=d}if((a[14128316]|0)==0){g=f}else{d=f-16&255;a[14128320]=d;g=d}if((a[14128317]|0)==0){h=g}else{d=g-32&255;a[14128320]=d;h=d}if((a[14128318]|0)==0){i=h}else{d=h-64&255;a[14128320]=d;i=d}if((a[14128319]|0)!=0){a[14128320]=i^-128}if((a[14128304]|0)==0){j=-1}else{a[14128321]=-2;j=-2}if((a[14128305]|0)==0){k=j}else{i=j-2&255;a[14128321]=i;k=i}if((a[14128306]|0)==0){l=k}else{i=k-4&255;a[14128321]=i;l=i}if((a[14128307]|0)==0){m=l}else{i=l-8&255;a[14128321]=i;m=i}if((a[14128308]|0)==0){n=m}else{i=m-16&255;a[14128321]=i;n=i}if((a[14128309]|0)==0){o=n}else{i=n-32&255;a[14128321]=i;o=i}if((a[14128310]|0)==0){p=o}else{i=o-64&255;a[14128321]=i;p=i}if((a[14128311]|0)!=0){a[14128321]=p^-128}if((a[14128296]|0)==0){q=-4}else{a[14128322]=-3;q=-3}if((a[14128297]|0)==0){r=q}else{p=q|2;a[14128322]=p;r=p}if((a[14128298]|0)==0){s=r}else{p=r-4&255;a[14128322]=p;s=p}if((a[14128299]|0)==0){t=s}else{p=s-8&255;a[14128322]=p;t=p}if((a[14128300]|0)==0){u=t}else{p=t-16&255;a[14128322]=p;u=p}if((a[14128301]|0)==0){v=u}else{p=u-32&255;a[14128322]=p;v=p}if((a[14128302]|0)==0){w=v}else{p=v-64&255;a[14128322]=p;w=p}if((a[14128303]|0)==0){return}a[14128322]=w^-128;return}function e2C(){var d=0;eZ8()|0;a[9720936]=0;c[2437782]=0;b[4877712]=0;d=9553280;c[d>>2]=0;c[d+4>>2]=0;gGz(9553288,-128|0,5);d=0;do{c[9774520+(d<<2)>>2]=~~(100.0/+X(+10.0,+((32.0- +(d|0)*2.133333444595337)/20.0)));d=d+1|0;}while((d|0)<16);return 0}function e2D(a){a=a|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=c[3531970]|0;f=c[2112926]|0;g=c[3531962]|0;h=30716;do{i=b[d+((h|2)<<1)>>1]|0;j=i&8191;L53440:do{if(j<<16>>16!=0){k=256-(e[d+(h<<1)>>1]|0)|0;l=k&511;m=e[d+((h|1)<<1)>>1]|0;n=m&1023;o=(i&65535)>>>14&1;p=(i&65535)>>>15&255;q=b[d+((h|3)<<1)>>1]|0;if(((q&65535)>>>7&255&1|0)!=(a|0)){break}r=q&127;q=n>>>0>900?m|-1024:n;n=(l>>>0>400?k|-512:l)-16|0;do{if((q|0)>16){if(!((q|0)<((c[2113068]|0)-16|0)&(n|0)>16)){break}if((n|0)>=((c[2113070]|0)-16|0)){break}l=p<<24>>24!=0;k=j&65535;m=r&255;if(o<<24>>24==0){if(l){SK(f,k,q,n,m,4,0,0,g);break L53440}else{SG(f,k,q,n,m,4,0,0,g);break L53440}}else{if(l){SM(f,k,q,n,m,4,0,0,g);break L53440}else{SI(f,k,q,n,m,4,0,0,g);break L53440}}}}while(0);m=p<<24>>24!=0;k=j&65535;l=r&255;if(o<<24>>24==0){if(m){SL(f,k,q,n,l,4,0,0,g);break}else{SH(f,k,q,n,l,4,0,0,g);break}}else{if(m){SN(f,k,q,n,l,4,0,0,g);break}else{SJ(f,k,q,n,l,4,0,0,g);break}}}}while(0);h=h-4|0;}while((h|0)>-1);return}function e2E(e,f,g){e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0;h=g&65535;i=c[2406600]|0;a[i+((d[14109952]<<10)+f)|0]=g&255;if((a[14109952]|0)!=0){return}if((f|0)==20){g=e;e=c[3527516]|0;j=(e-1|0)>>>0<2;k=j?262094:0;l=(e-3|0)>>>0<2;e=h>>>6<<2&12^12;m=l?262110:k;if(!(l|j)){return}j=l?262126:k;k=h>>>4<<2&12^12;a[818400]=b[g+((m+k|0)>>>1<<1)>>1]&255;a[818392]=b[g+(((k|2)+m|0)>>>1<<1)>>1]&255;if((j|0)==0){return}a[818401]=b[g+((j+e|0)>>>1<<1)>>1]&255;a[818393]=b[g+(((e|2)+j|0)>>>1<<1)>>1]&255;return}else if((f|0)==21){f=a[i+21|0]&3;if((f|0)==3){a[i+44|0]=49;a[i+119|0]=5;a[i+37|0]=15;a[i+38|0]=11;return}else if((f|0)==0){a[i+44|0]=32;a[i+119|0]=6;a[i+37|0]=7;a[i+38|0]=3;return}else if((f|0)==1){a[i+44|0]=49;a[i+119|0]=5;a[i+37|0]=15;a[i+38|0]=11;return}else if((f|0)==2){a[i+44|0]=60;a[i+119|0]=4;a[i+37|0]=19;a[i+38|0]=15;return}else{return}}else{return}}function e2F(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0;d=a[8310512]|0;if(d<<24>>24!=0&(d&255)<18){f=c[745504+((d&255)<<2)>>2]|0;g=c[2077632]|0;h=0;do{i=f+(h<<1)|0;j=h<<1;a[g+(j+16)|0]=(e[i>>1]|0)>>>8&255;a[g+(j+17)|0]=b[i>>1]&255;h=h+1|0;}while((h|0)<80);k=a[8310512]|0}else{k=d}L53500:do{if((k+127&255)<17){switch(k&255|0){case 135:{a[(c[2077632]|0)+35|0]=6;break L53500;break};case 142:{a[(c[2077632]|0)+35|0]=8;break L53500;break};case 143:{a[(c[2077632]|0)+35|0]=6;break L53500;break};case 141:{a[(c[2077632]|0)+35|0]=1;break L53500;break};case 139:{a[(c[2077632]|0)+35|0]=10;break L53500;break};case 140:{a[(c[2077632]|0)+35|0]=1;break L53500;break};case 145:{a[(c[2077632]|0)+35|0]=0;break L53500;break};case 138:{a[(c[2077632]|0)+35|0]=1;break L53500;break};case 136:{a[(c[2077632]|0)+35|0]=15;break L53500;break};case 137:{a[(c[2077632]|0)+35|0]=8;break L53500;break};case 129:{a[(c[2077632]|0)+35|0]=15;break L53500;break};case 130:{a[(c[2077632]|0)+35|0]=1;break L53500;break};case 131:{a[(c[2077632]|0)+35|0]=6;break L53500;break};case 132:{a[(c[2077632]|0)+35|0]=15;break L53500;break};case 134:{a[(c[2077632]|0)+35|0]=6;break L53500;break};case 144:{a[(c[2077632]|0)+35|0]=10;break L53500;break};case 133:{a[(c[2077632]|0)+35|0]=9;break L53500;break};default:{break L53500}}}}while(0);a[8310512]=0;return}function e2G(d,f,g,h){d=d|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0;j=i;i=i+3072|0;k=j+1024|0;l=j+2048|0;m=c[3532272]|0;n=m;o=c[3532270]|0;p=e[m+8190>>1]|0;m=(d<<2)+64|0;d=(p<<2&3072)+m|0;q=(p&3072)+m|0;m=k|0;r=l|0;s=(g|0)!=0;t=s?1:4;u=(h|0)==0;h=s?3:0;v=j|0;w=(g|0)!=2&(p&2048|0)==0;p=c[2113068]|0;g=(p|0)>0;x=c[2113070]|0;y=a[725176]|0;z=c[2112926]|0;A=0;do{B=A<<2;C=d+B|0;D=q+B|0;if(g){B=0;E=r;F=m;while(1){b[F>>1]=-32768;b[E>>1]=-32768;G=B+1|0;if((G|0)<(p|0)){B=G;E=E+2|0;F=F+2|0}else{break}}}F=b[n+(C<<1)>>1]|0;E=b[n+((C|1)<<1)>>1]|0;B=b[n+(D<<1)>>1]|0;G=b[n+((D|1)<<1)>>1]|0;H=b[n+((D|2)<<1)>>1]|0;I=e[n+((C|2)<<1)>>1]|0;J=H&65535;K=E&65535;L=(K&8192|0)==0?3:2;M=G&65535;N=(M&8192|0)==0?L:L+14&255;L=F&65535;O=(L&8192|0)==0?3:2;P=B&65535;Q=(P&8192|0)==0?O:O-2&255;O=(Q<<24>>24==0)+Q&255;Q=L>>>11&2;R=K>>>11&2;S=e[n+((C|3)<<1)>>1]|0;T=S&1023;U=167-(I&2047)|0;V=1535-(U&2047)|0;W=V-(K&1023)|0;X=(L&1023)+1+V|0;Y=(E|F)<<16>>16!=0;F=Y&1;E=W+1|0;Z=(E|0)<0?0:E;_=(X|0)>(p|0)?p:X;if((X|0)<0){$=512-X&2047;aa=0}else{$=512;aa=X}if((W|0)<(p|0)){ab=0;ac=W}else{ab=E-p|0;ac=p-1|0}E=(V|0)>(p+510|0);V=(S>>>10&60)+f|0;S=Z+U|0;U=k+(p+~Z<<1)|0;L53534:do{if(Y&(Z|0)<(_|0)){W=S&2047;X=T<<8;ad=V+(I>>>11&3)<<4|t;ae=(((H&65535)>>>13&1|((I&8192|0)==0?2:4))&255)<<12&65535;if((T|0)==0){break}if(u){af=S;ah=Z;ai=U;aj=W;while(1){ak=e[o+((aj>>>3|X)<<1)>>1]|0;al=af&7^7;am=ak>>>((al|8)>>>0)<<1&2|ak>>>(al>>>0)&1;if(s){an=am+3&3}else{an=am&65535}b[ai>>1]=((an&65535)+ad|ae)&65535;am=aj+1|0;al=ah+1|0;if((al|0)<(_|0)){af=am;ah=al;ai=ai-2|0;aj=am&2047}else{break L53534}}}else{ao=S;ap=Z;aq=U;ar=W}while(1){aj=e[o+((ar>>>3|X)<<1)>>1]|0;ai=ao&7^7;ah=aj>>>((ai|8)>>>0)<<1&2|aj>>>(ai>>>0)&1;ai=ah&65535;if(ai<<16>>16==0){as=-4096}else{if(s){at=ah+3&3}else{at=ai}as=((at&65535)+ad|ae)&65535}b[aq>>1]=as;ai=ar+1|0;ah=ap+1|0;if((ah|0)<(_|0)){ao=ai;ap=ah;aq=aq-2|0;ar=ai&2047}else{break}}}}while(0);_=V+R<<4|t;L53552:do{if(E){if(!((K&32768|0)!=0&g)){break}U=_+h&65535;Z=0;S=m;while(1){b[S>>1]=U;I=Z+1|0;if((I|0)<(p|0)){Z=I;S=S+2|0}else{break}}}else{if((ac|0)<=-1){break}if((ac|0)>=(p|0)|Y^1){break}S=511-ab|0;Z=k+(p+~ac<<1)|0;U=S&2047;I=T<<8;if((K&32768|0)==0){au=S;av=ac;aw=Z;ax=U}else{H=S;S=ac;C=Z;Z=U;while(1){U=e[o+((Z>>>3|I)<<1)>>1]|0;ae=H&7^7;ad=U>>>((ae|8)>>>0)<<1&2|U>>>(ae>>>0)&1;if(s){ay=ad+3&3}else{ay=ad&65535}b[C>>1]=((ay&65535)+_|((ad|0)==0?0:4096))&65535;ad=Z-1|0;if((S|0)>0){H=ad;S=S-1|0;C=C+2|0;Z=ad&2047}else{break L53552}}}while(1){Z=e[o+((ax>>>3|I)<<1)>>1]|0;C=au&7^7;S=Z>>>((C|8)>>>0)<<1&2|Z>>>(C>>>0)&1;C=(S|0)==0;Z=C?0:4096;if(!C){if(s){az=S+3&3}else{az=S&65535}b[aw>>1]=((az&65535)+_|Z)&65535}Z=ax-1|0;if((av|0)>0){au=Z;av=av-1|0;aw=aw+2|0;ax=Z&2047}else{break}}}}while(0);if(!((aa|0)<0|(aa|0)>=(p|0)|Y^1)){_=T<<8;K=V+Q<<4|t;E=(L&32768|0)!=0;R=$;I=aa;Z=k+(p+~aa<<1)|0;while(1){S=e[o+((R>>3)+_<<1)>>1]|0;C=7-((R|0)%8|0)|0;H=S>>>((C+8|0)>>>0)<<1&2|S>>>(C>>>0)&1;C=(H|0)==0;S=C?0:4096;if(E|C^1){if(s){aA=H+3&3}else{aA=H&65535}b[Z>>1]=((aA&65535)+K|S)&65535}S=I+1|0;if((S|0)<(p|0)){R=R+1&2047;I=S;Z=Z-2|0}else{break}}}Z=P>>>11&2;I=M>>>11&2;R=e[n+((D|3)<<1)>>1]|0;K=R&1023;E=167-(J&2047)|0;_=1535-(E&2047)|0;L=_-(M&1023)|0;Q=(P&1023)+1+_|0;V=(G|B)<<16>>16==0|w;T=V?F:1;Y=L+1|0;S=(Y|0)<0?0:Y;H=(Q|0)>(p|0)?p:Q;if((Q|0)<0){aB=512-Q&2047;aC=0}else{aB=512;aC=Q}if((L|0)<(p|0)){aD=0;aE=L}else{aD=Y-p|0;aE=p-1|0}Y=(_|0)>(p+510|0);_=(R>>>10&60)+f|0;R=_+(J>>>11&3)<<4;L=S+E&2047;do{if(L>>>0>1023){if(!((K|0)!=0&(V^1)&(S|0)<(H|0))){break}E=K<<8;Q=R|t;C=L;ad=S;ae=l+(p+~S<<1)|0;while(1){U=e[o+((C>>>3|E)<<1)>>1]|0;X=C&7^7;W=U>>>((X|8)>>>0)<<1&2|U>>>(X>>>0)&1;X=W&65535;if(X<<16>>16!=0|u){if(s){aF=W+3&3}else{aF=X}aG=((aF&65535)+Q|4096)&65535}else{aG=-4096}b[ae>>1]=aG;X=ad+1|0;if((X|0)<(H|0)){C=C+1&2047;ad=X;ae=ae-2|0}else{break}}}}while(0);H=_+I<<4|t;S=(N&255)<<12;L53604:do{if(Y){if(!(g&(((M&32768|0)==0|V)^1))){break}L=H+h&65535;R=0;J=r;while(1){b[J>>1]=L;F=R+1|0;if((F|0)<(p|0)){R=F;J=J+2|0}else{break}}}else{if((aE|0)<=-1){break}if((aE|0)>=(p|0)|(T|0)==0){break}J=K<<8;R=S&65535;L=(M&32768|0)!=0;F=511-aD&2047;B=aE;G=l+(p+~aE<<1)|0;while(1){D=e[o+((F>>3)+J<<1)>>1]|0;ae=7-((F|0)%8|0)|0;ad=D>>>((ae+8|0)>>>0)<<1&2|D>>>(ae>>>0)&1;ae=(ad|0)==0;D=ae?0:R;if(L|ae^1){if(s){aH=ad+3&3}else{aH=ad&65535}b[G>>1]=((aH&65535)+H|D)&65535}D=F-1|0;if((D|0)<0){break L53604}if((B|0)>0){F=D;B=B-1|0;G=G+2|0}else{break}}}}while(0);L53622:do{if(!((aC|0)<0|(aC|0)>=(p|0)|V)){H=K<<8;M=(O&255)<<12&65535;S=_+Z<<4|t;Y=(P&32768|0)!=0;N=aB;I=aC;G=l+(p+~aC<<1)|0;while(1){B=e[o+((N>>3)+H<<1)>>1]|0;F=7-((N|0)%8|0)|0;L=B>>>((F+8|0)>>>0)<<1&2|B>>>(F>>>0)&1;F=(L|0)==0;B=F?0:M;if(Y|F^1){if(s){aI=L+3&3}else{aI=L&65535}b[G>>1]=((aI&65535)+S|B)&65535}B=N+1|0;if((B|0)>1023){break L53622}L=I+1|0;if((L|0)<(p|0)){N=B;I=L;G=G-2|0}else{break}}}}while(0);L53634:do{if((T|0)!=0){L53636:do{if(g){P=0;Z=v;while(1){_=b[k+(P<<1)>>1]|0;O=_&65535;K=b[l+(P<<1)>>1]|0;V=K&65535;do{if(_<<16>>16==-32768){b[Z>>1]=K&-28673}else{if(K<<16>>16==-32768){b[Z>>1]=_&-28673;break}if((V&28672)>>>0>(O&28672)>>>0){b[Z>>1]=K&-28673;break}else{b[Z>>1]=_&-28673;break}}}while(0);_=P+1|0;if((_|0)>=(p|0)){break L53636}P=_;Z=Z+2|0}}}while(0);Z=ag(p,A)|0;P=(p|0)==0;if(y){if(P){break}_=z+(p-1+Z<<1)|0;K=v;O=p;while(1){V=O-1|0;G=b[K>>1]|0;if((G&65535)<32767){b[_>>1]=G}if((V|0)==0){break L53634}_=_-2|0;K=K+2|0;O=V}}else{if(P){break}O=z+(Z<<1)|0;K=v;_=p;while(1){V=_-1|0;G=b[K>>1]|0;if((G&65535)<32767){b[O>>1]=G}if((V|0)==0){break L53634}O=O+2|0;K=K+2|0;_=V}}}}while(0);A=A+1|0;}while((A|0)<(x|0));i=j;return}function e2H(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;e=b-10485760|0;if(e>>>0>=65536){return}b=e^1;f=(c[3532278]|0)+b|0;do{if((a[f]|0)!=d<<24>>24){g=(e|0)>-1;if((c[3532284]|0)==0){if(g&(b|0)<16384){a[14129208]=1}if(g&(b|0)<32768){a[14129128]=1}if((b-24576|0)>>>0>=4096){break}a[14129200]=1;break}else{if(g&(b|0)<32768){a[14129208]=1}if((b-32768|0)>>>0<32768){a[14129128]=1}if((b-69632|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);a[f]=d;return}function e2I(d,e){d=d|0;e=e|0;var f=0,g=0;f=d-10485760|0;if(f>>>0<65536){g=(c[3532278]|0)+(f>>>1<<1)|0;do{if((b[g>>1]|0)!=e<<16>>16){if((c[3532284]|0)==0){if(f>>>0<16384){a[14129208]=1}if((d-10518528|0)>>>0<16384){a[14129128]=1}if((d-10510336|0)>>>0>=4096){break}a[14129200]=1;break}else{if(f>>>0<32768){a[14129208]=1}if((d-10518528|0)>>>0<32768){a[14129128]=1}if((d-10555392|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);b[g>>1]=e;return}g=d-10616832|0;if(g>>>0<16){f=g>>>1;b[14129152+(f<<1)>>1]=e;switch(f|0){case 4:{c[2385820]=-(e&65535);return};case 5:{c[3527494]=-(e&65535);return};case 1:{c[2385826]=-(e&65535);return};case 2:{c[3527502]=-(e&65535);return};case 3:{c[2388334]=-(e&65535);return};case 7:{c[2439396]=e&1;return};case 0:{c[2388344]=-(e&65535);return};case 6:{c[3532284]=(e&65535)>>>4&1;return};default:{return}}}if((d|0)==3145728|(d|0)==3145730){f=(d-3145728|0)>>>1;if((f|0)==0){c[2439392]=e&4095;return}else if((f|0)==1){b[(c[2442928]|0)+(c[2439392]<<1)>>1]=e;c[(c[3532276]|0)+(c[2439392]<<2)>>2]=((e&65535)>>>10<<3&248)>>>3|((e&255)<<3&255)<<8|(((e&65535)>>>7&4|(e&65535)>>>5<<3&255)&255)<<3&2016;return}else{return}}else if((d|0)==2097152){b[7064256]=e;if((e&1)!=0){return}e=c[2394]|0;d=c[14130368+(e<<2)>>2]|0;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[8452240+(e<<2)>>2]=c[2113054];c[2394]=1;c[2112932]=c[3532597];e=c[3532593]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113061];RI();e=c[2394]|0;d=c[14130368+(e<<2)>>2]|0;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[8452240+(e<<2)>>2]=c[2113054];c[2394]=0;c[2112932]=c[3532596];e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060];return}else{return}}function e2J(b){b=b|0;var c=0,d=0,e=0;c=b-2097152|0;L53768:do{if(c>>>0<16){switch(c>>>1&255|0){case 1:{d=a[14129049]|0;break L53768;break};case 3:{d=a[14129041]|0;break L53768;break};case 4:{d=a[9757556]|0;break L53768;break};case 7:{d=a[14129042]|0;break L53768;break};case 2:{d=a[14129040]|0;break L53768;break};case 0:{d=a[14129048]|0;break L53768;break};default:{d=0;break L53768}}}else{if((b|0)!=3145731){d=0;break}e=a[9540896]|0;switch(e&255|0){case 0:{a[9540896]=e+1&255;d=a[9540892]|0;break L53768;break};case 1:{a[9540898]=a[9540898]&-5;a[9540896]=e+1&255;d=a[9540893]|0;break L53768;break};case 2:{a[9540896]=e+1&255;d=a[9540894]|0;break L53768;break};case 3:{a[9540898]=a[9540898]&-9;a[9540896]=e+1&255;d=a[9540895]|0;break L53768;break};case 4:{d=a[9540898]|0;break L53768;break};default:{d=0;break L53768}}}}while(0);return d|0}function e2K(b){b=b|0;var c=0,d=0,e=0;c=b-2097152|0;if(c>>>0>=16){d=0;return d|0}switch(c>>>1&255|0){case 1:{e=a[14129049]|0;break};case 0:{e=a[14129048]|0;break};case 3:{e=a[14129041]|0;break};case 4:{e=a[9757556]|0;break};case 7:{e=a[14129042]|0;break};case 2:{e=a[14129040]|0;break};default:{e=0}}d=e&255;return d|0}function e2L(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=b-2097152|0;if(e>>>0<16){f=e>>>1;e=f&255;g=d&255;a[9757552+(f&255)|0]=g;if((e<<24>>24|0)==4){f=~g;a[14128520]=f&1;a[14128521]=f&2;return}else if((e<<24>>24|0)==0){c[3531956]=0;return}else{return}}if((b|0)==3145730){e=d&15;f=a[9540896]|0;switch(f&255|0){case 1:{a[9540896]=f+1&255;a[9540889]=e;a[9540898]=a[9540898]|1;a[9540900]=1;return};case 2:{a[9540896]=f+1&255;a[9540890]=e;return};case 0:{a[9540896]=f+1&255;a[9540888]=e;return};case 4:{if(e<<24>>24==0){return}g=c[2439330]|0;h=(g|0)==0;if(!h){i=g;gGC(9706056,i|0,76)|0}i=c[2438118]|0;c[2433530]=i;j=c[3528484]|0;c[2076596]=j;k=c[2417276]|0;c[3541536]=k;c[1836236]=0;gGz(9706056,0,76);if(!h){h=g;gGC(h|0,9706056,76)|0}c[2438118]=i;c[3528484]=j;c[2417276]=k;c[1836236]=-1;return};case 3:{a[9540896]=f+1&255;a[9540891]=e;a[9540898]=a[9540898]|2;a[9540900]=1;return};default:{return}}}else if((b|0)==3145728){a[9540896]=d&15;return}else{return}}function e2M(b){b=b|0;var d=0,e=0,f=0;d=b-4194304|0;L53836:do{if(d>>>0<16){switch(d>>>1&255|0){case 1:{e=a[14129049]|0;break L53836;break};case 3:{e=a[14129041]|0;break L53836;break};case 4:{e=a[9757556]|0;break L53836;break};case 7:{e=a[14129042]|0;break L53836;break};case 0:{e=a[14129048]|0;break L53836;break};case 2:{e=a[14129040]|0;break L53836;break};default:{e=0;break L53836}}}else{if(!((b|0)==8388609|(b|0)==8388611|(b|0)==8388613|(b|0)==8388615)){e=0;break}f=(b-8388608|0)>>>1;if((f|0)==1|(f|0)==3){e=-1;break}else if((f|0)==2){e=(c[3532184]|0)>>>4&255;break}else if((f|0)==0){f=(c[3532186]|0)>>>4;e=(f&4095|0)==0?0:4096-f&255;break}else{e=0;break}}}while(0);return e|0}function e2N(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;e=b-4194304|0;if(e>>>0<16){f=e>>>1;e=f&255;a[9757552+(f&255)|0]=d;if((e<<24>>24|0)==4){f=~d;a[14128520]=f&1;a[14128521]=f&2;return}else if((e<<24>>24|0)==0){c[3531956]=0;return}else{return}}e=b-13631488|0;if(e>>>0>=65536){return}b=e^1;f=(c[3532278]|0)+b|0;do{if((a[f]|0)!=d<<24>>24){g=(e|0)>-1;if((c[3532284]|0)==0){if(g&(b|0)<16384){a[14129208]=1}if(g&(b|0)<32768){a[14129128]=1}if((b-24576|0)>>>0>=4096){break}a[14129200]=1;break}else{if(g&(b|0)<32768){a[14129208]=1}if((b-32768|0)>>>0<32768){a[14129128]=1}if((b-69632|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);a[f]=d;return}function e2O(d,e){d=d|0;e=e|0;var f=0,g=0,h=0;f=d-4194304|0;if(f>>>0<16){g=f>>>1;f=g&255;h=e&255;a[9757552+(g&255)|0]=h;if((f<<24>>24|0)==4){g=~h;a[14128520]=g&1;a[14128521]=g&2;return}else if((f<<24>>24|0)==0){c[3531956]=0;return}else{return}}f=d-13631488|0;if(f>>>0<65536){g=(c[3532278]|0)+(f>>>1<<1)|0;do{if((b[g>>1]|0)!=e<<16>>16){if((c[3532284]|0)==0){if(f>>>0<16384){a[14129208]=1}if((d-13664256|0)>>>0<16384){a[14129128]=1}if((d-13656064|0)>>>0>=4096){break}a[14129200]=1;break}else{if(f>>>0<32768){a[14129208]=1}if((d-13664256|0)>>>0<32768){a[14129128]=1}if((d-13701120|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);b[g>>1]=e;return}g=d-13762560|0;if(g>>>0<16){f=g>>>1;b[14129152+(f<<1)>>1]=e;switch(f|0){case 3:{c[2388334]=-(e&65535);return};case 6:{c[3532284]=(e&65535)>>>4&1;return};case 4:{c[2385820]=-(e&65535);return};case 5:{c[3527494]=-(e&65535);return};case 7:{c[2439396]=e&1;return};case 1:{c[2385826]=-(e&65535);return};case 2:{c[3527502]=-(e&65535);return};case 0:{c[2388344]=-(e&65535);return};default:{return}}}else{if((d|0)==6291456){b[7064256]=e;if((e&1)!=0){return}e=c[2394]|0;f=c[14130368+(e<<2)>>2]|0;if((f|0)!=0){gGC(f|0,9104152,280)|0}c[8452240+(e<<2)>>2]=c[2113054];c[2394]=1;c[2112932]=c[3532597];e=c[3532593]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113061];RI();e=c[2394]|0;f=c[14130368+(e<<2)>>2]|0;if((f|0)!=0){gGC(f|0,9104152,280)|0}c[8452240+(e<<2)>>2]=c[2113054];c[2394]=0;c[2112932]=c[3532596];e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060];return}else if((d|0)==8388608|(d|0)==8388610|(d|0)==8388612|(d|0)==8388614){c[2113056]=1e4;d=RG(1e4)|0;c[2113054]=(c[2113054]|0)+d;c[2276108]=-1;c[2113056]=-1;c[2113030]=(c[2113030]|0)+d;c[8452200+(c[2394]<<2)>>2]=8198;c[2276080]=1536;if((c[2276079]|0)>>>0>=1536){return}RH(6);return}else{return}}}function e2P(b){b=b|0;var e=0,f=0,g=0.0,i=0.0,j=0,k=0,l=0;if((b|0)==6291456){e=c[3541514]|0;f=e+552|0;g=+h[f>>3];do{if(g!=0.0){i=+h[6675];if(g-(i+ +gC[c[2429842]&255]())>0.0){j=a[e+563|0]|-128;break}else{h[f>>3]=0.0;k=41137;break}}else{k=41137}}while(0);if((k|0)==41137){j=a[e+563|0]|0}l=j&-125&255;return l|0}else if((b|0)==6291460){l=d[(c[3541514]|0)+20904|0]|0;return l|0}else{l=0;return l|0}return 0}function e2Q(b,d){b=b|0;d=d|0;var e=0;if((b|0)==6291458){l7(1,d&255);return}else if((b|0)==6291462){l7(3,d&255);return}else if((b|0)==6291460){e=c[3541514]|0;a[e+560|0]=d&255;a[e+20408|0]=1;return}else if((b|0)==6291456){b=d&255;e=c[3541514]|0;a[e+560|0]=b;a[e+20408|0]=0;if((b&255)>=16){return}c[14168912+((c[2383582]|0)*252|0)>>2]=d&15;return}else{return}}function e2R(b){b=b|0;var e=0,f=0,g=0;L53995:do{if((b|0)==4194305){e=c[3532186]|0;f=d[9757560]|0;switch(f|0){case 13:{g=e>>>12&255;break L53995;break};case 12:{g=e>>>4&255;break L53995;break};case 8:case 9:case 10:case 11:{g=-1;break L53995;break};default:{switch(f|0){case 3:{g=a[14129041]|0;break L53995;break};case 4:{g=a[9757556]|0;break L53995;break};case 1:{g=a[14129049]|0;break L53995;break};case 0:{g=a[14129048]|0;break L53995;break};case 7:{g=a[14129042]|0;break L53995;break};case 2:{g=a[14129040]|0;break L53995;break};default:{g=0;break L53995}}}}}else if((b|0)==8519683){f=a[9540896]|0;switch(f&255|0){case 4:{g=a[9540898]|0;break L53995;break};case 1:{a[9540898]=a[9540898]&-5;a[9540896]=f+1&255;g=a[9540893]|0;break L53995;break};case 0:{a[9540896]=f+1&255;g=a[9540892]|0;break L53995;break};case 2:{a[9540896]=f+1&255;g=a[9540894]|0;break L53995;break};case 3:{a[9540898]=a[9540898]&-9;a[9540896]=f+1&255;g=a[9540895]|0;break L53995;break};default:{g=0;break L53995}}}else{g=0}}while(0);return g|0}function e2S(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=d-12582912|0;if(f>>>0<65536){g=f^1;h=(c[3532278]|0)+g|0;do{if((a[h]|0)!=e<<24>>24){i=(f|0)>-1;if((c[3532284]|0)==0){if(i&(g|0)<16384){a[14129208]=1}if(i&(g|0)<32768){a[14129128]=1}if((g-24576|0)>>>0>=4096){break}a[14129200]=1;break}else{if(i&(g|0)<32768){a[14129208]=1}if((g-32768|0)>>>0<32768){a[14129128]=1}if((g-69632|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);a[h]=e;return}if((d|0)==8388609){h=e&255;b[7064256]=h;if((h&1)!=0){return}h=c[2394]|0;g=c[14130368+(h<<2)>>2]|0;if((g|0)!=0){gGC(g|0,9104152,280)|0}c[8452240+(h<<2)>>2]=c[2113054];c[2394]=1;c[2112932]=c[3532597];h=c[3532593]|0;if((h|0)!=0){gGC(9104152,h|0,280)|0}c[2113054]=c[2113061];RI();h=c[2394]|0;g=c[14130368+(h<<2)>>2]|0;if((g|0)!=0){gGC(g|0,9104152,280)|0}c[8452240+(h<<2)>>2]=c[2113054];c[2394]=0;c[2112932]=c[3532596];h=c[3532592]|0;if((h|0)!=0){gGC(9104152,h|0,280)|0}c[2113054]=c[2113060];return}else if((d|0)==4194305){h=a[9757560]|0;a[9757552+(h&255)|0]=e;if((h<<24>>24|0)==0){c[3531956]=0;return}else if((h<<24>>24|0)==4){h=~e;a[14128520]=h&1;a[14128521]=h&2;return}else{return}}else if((d|0)==8519681){a[9540896]=e&15;return}else if((d|0)==8519683){h=e&15;g=a[9540896]|0;switch(g&255|0){case 1:{a[9540896]=g+1&255;a[9540889]=h;a[9540898]=a[9540898]|1;a[9540900]=1;return};case 2:{a[9540896]=g+1&255;a[9540890]=h;return};case 4:{if(h<<24>>24==0){return}f=c[2439330]|0;i=(f|0)==0;if(!i){j=f;gGC(9706056,j|0,76)|0}j=c[2438118]|0;c[2433530]=j;k=c[3528484]|0;c[2076596]=k;l=c[2417276]|0;c[3541536]=l;c[1836236]=0;gGz(9706056,0,76);if(!i){i=f;gGC(i|0,9706056,76)|0}c[2438118]=j;c[3528484]=k;c[2417276]=l;c[1836236]=-1;return};case 3:{a[9540896]=g+1&255;a[9540891]=h;a[9540898]=a[9540898]|2;a[9540900]=1;return};case 0:{a[9540896]=g+1&255;a[9540888]=h;return};default:{return}}}else if((d|0)==4194307){a[9757560]=e;return}else{return}}function e2T(a){a=a|0;var e=0;if((a|0)==4194306){e=d[9757560]|0}else if((a|0)==10485762){e=b[(c[2442928]|0)+(c[2439392]<<1)>>1]|0}else{e=0}return e|0}function e2U(d,e){d=d|0;e=e|0;var f=0,g=0;f=d-12582912|0;if(f>>>0<65536){g=(c[3532278]|0)+(f>>>1<<1)|0;do{if((b[g>>1]|0)!=e<<16>>16){if((c[3532284]|0)==0){if(f>>>0<16384){a[14129208]=1}if((d-12615680|0)>>>0<16384){a[14129128]=1}if((d-12607488|0)>>>0>=4096){break}a[14129200]=1;break}else{if(f>>>0<32768){a[14129208]=1}if((d-12615680|0)>>>0<32768){a[14129128]=1}if((d-12652544|0)>>>0>=4096){break}a[14129200]=1;break}}}while(0);b[g>>1]=e;return}g=d-12713984|0;if(g>>>0>=16){if((d|0)==4194306){a[9757560]=e&255;return}else if((d|0)==10485760|(d|0)==10485762){f=(d-10485760|0)>>>1;if((f|0)==0){c[2439392]=e&4095;return}else if((f|0)==1){b[(c[2442928]|0)+(c[2439392]<<1)>>1]=e;c[(c[3532276]|0)+(c[2439392]<<2)>>2]=((e&65535)>>>10<<3&248)>>>3|((e&255)<<3&255)<<8|(((e&65535)>>>7&4|(e&65535)>>>5<<3&255)&255)<<3&2016;return}else{return}}else if((d|0)==4194304){d=a[9757560]|0;f=e&255;a[9757552+(d&255)|0]=f;if((d<<24>>24|0)==0){c[3531956]=0;return}else if((d<<24>>24|0)==4){d=~f;a[14128520]=d&1;a[14128521]=d&2;return}else{return}}else{return}}d=g>>>1;b[14129152+(d<<1)>>1]=e;switch(d|0){case 6:{c[3532284]=(e&65535)>>>4&1;return};case 7:{c[2439396]=e&1;return};case 4:{c[2385820]=-(e&65535);return};case 5:{c[3527494]=-(e&65535);return};case 0:{c[2388344]=-(e&65535);return};case 1:{c[2385826]=-(e&65535);return};case 2:{c[3527502]=-(e&65535);return};case 3:{c[2388334]=-(e&65535);return};default:{return}}}
function af8(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=c[3541654]|0;e=c[2113308]|0;f=c[2113300]|0;g=c[2113224]|0;h=1;i=0;j=c[3541650]|0;k=c[2112960]|0;l=c[2112962]|0;while(1){m=ag(b[j>>1]|0,e)|0;n=c[k+4>>2]|0;o=n&15;if((o|0)!=0){p=c[d+(o<<2)>>2]|0;a[l+m|0]=p&255;a[l+(m+1)|0]=p>>>8&255;a[l+(m+2)|0]=p>>>16&255}p=n>>>4&15;if((p|0)!=0){o=c[d+(p<<2)>>2]|0;a[l+(m+3)|0]=o&255;a[l+(m+4)|0]=o>>>8&255;a[l+(m+5)|0]=o>>>16&255}o=n>>>8&15;if((o|0)!=0){p=c[d+(o<<2)>>2]|0;a[l+(m+6)|0]=p&255;a[l+(m+7)|0]=p>>>8&255;a[l+(m+8)|0]=p>>>16&255}p=n>>>12&15;if((p|0)!=0){o=c[d+(p<<2)>>2]|0;a[l+(m+9)|0]=o&255;a[l+(m+10)|0]=o>>>8&255;a[l+(m+11)|0]=o>>>16&255}o=n>>>16&15;if((o|0)!=0){p=c[d+(o<<2)>>2]|0;a[l+(m+12)|0]=p&255;a[l+(m+13)|0]=p>>>8&255;a[l+(m+14)|0]=p>>>16&255}p=n>>>20&15;if((p|0)!=0){o=c[d+(p<<2)>>2]|0;a[l+(m+15)|0]=o&255;a[l+(m+16)|0]=o>>>8&255;a[l+(m+17)|0]=o>>>16&255}o=n>>>24&15;if((o|0)!=0){p=c[d+(o<<2)>>2]|0;a[l+(m+18)|0]=p&255;a[l+(m+19)|0]=p>>>8&255;a[l+(m+20)|0]=p>>>16&255}p=n>>>28;if((p|0)!=0){o=c[d+(p<<2)>>2]|0;a[l+(m+21)|0]=o&255;a[l+(m+22)|0]=o>>>8&255;a[l+(m+23)|0]=o>>>16&255}o=c[k>>2]|0;q=n|i|o;n=o&15;if((n|0)!=0){p=c[d+(n<<2)>>2]|0;a[l+(m+24)|0]=p&255;a[l+(m+25)|0]=p>>>8&255;a[l+(m+26)|0]=p>>>16&255}p=o>>>4&15;if((p|0)!=0){n=c[d+(p<<2)>>2]|0;a[l+(m+27)|0]=n&255;a[l+(m+28)|0]=n>>>8&255;a[l+(m+29)|0]=n>>>16&255}n=o>>>8&15;if((n|0)!=0){p=c[d+(n<<2)>>2]|0;a[l+(m+30)|0]=p&255;a[l+(m+31)|0]=p>>>8&255;a[l+(m+32)|0]=p>>>16&255}p=o>>>12&15;if((p|0)!=0){n=c[d+(p<<2)>>2]|0;a[l+(m+33)|0]=n&255;a[l+(m+34)|0]=n>>>8&255;a[l+(m+35)|0]=n>>>16&255}n=o>>>16&15;if((n|0)!=0){p=c[d+(n<<2)>>2]|0;a[l+(m+36)|0]=p&255;a[l+(m+37)|0]=p>>>8&255;a[l+(m+38)|0]=p>>>16&255}p=o>>>20&15;if((p|0)!=0){n=c[d+(p<<2)>>2]|0;a[l+(m+39)|0]=n&255;a[l+(m+40)|0]=n>>>8&255;a[l+(m+41)|0]=n>>>16&255}n=o>>>24&15;if((n|0)!=0){p=c[d+(n<<2)>>2]|0;a[l+(m+42)|0]=p&255;a[l+(m+43)|0]=p>>>8&255;a[l+(m+44)|0]=p>>>16&255}p=o>>>28;if((p|0)!=0){o=c[d+(p<<2)>>2]|0;a[l+(m+45)|0]=o&255;a[l+(m+46)|0]=o>>>8&255;a[l+(m+47)|0]=o>>>16&255}r=l+f|0;s=k+g|0;if((h|0)>=16){break}h=h+1|0;i=q;j=j+2|0;k=s;l=r}c[2112960]=s;c[2112962]=r;return(q|0)==0|0}function af9(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;d=c[3541654]|0;e=c[2113228]|0;f=c[2113308]|0;g=c[2113300]|0;h=c[2113224]|0;i=1;j=0;k=c[3541650]|0;l=c[2113226]|0;m=c[2112962]|0;n=c[2112960]|0;while(1){o=l+32767|0;do{if((l&536887296|0)==0){p=b[k>>1]|0;q=ag(p,f)|0;r=(p*32767|0)+e|0;p=c[n>>2]|0;s=p|j;if((r&536887296|0)==0&p>>>0>268435455){t=c[d+(p>>>28<<2)>>2]|0;a[m+q|0]=t&255;a[m+(q+1)|0]=t>>>8&255;a[m+(q+2)|0]=t>>>16&255}t=m+(q+3)|0;do{if((r+32767&536887296|0)==0){if(p<<4>>>0<=268435455){break}u=c[d+((p>>>24&15)<<2)>>2]|0;a[t]=u&255;a[m+(q+4)|0]=u>>>8&255;a[m+(q+5)|0]=u>>>16&255}}while(0);t=m+(q+6)|0;do{if((r+65534&536887296|0)==0){if(p<<8>>>0<=268435455){break}u=c[d+((p>>>20&15)<<2)>>2]|0;a[t]=u&255;a[m+(q+7)|0]=u>>>8&255;a[m+(q+8)|0]=u>>>16&255}}while(0);t=m+(q+9)|0;do{if((r+98301&536887296|0)==0){if(p<<12>>>0<=268435455){break}u=c[d+((p>>>16&15)<<2)>>2]|0;a[t]=u&255;a[m+(q+10)|0]=u>>>8&255;a[m+(q+11)|0]=u>>>16&255}}while(0);t=m+(q+12)|0;do{if((r+131068&536887296|0)==0){if(p<<16>>>0<=268435455){break}u=c[d+((p>>>12&15)<<2)>>2]|0;a[t]=u&255;a[m+(q+13)|0]=u>>>8&255;a[m+(q+14)|0]=u>>>16&255}}while(0);t=m+(q+15)|0;do{if((r+163835&536887296|0)==0){if(p<<20>>>0<=268435455){break}u=c[d+((p>>>8&15)<<2)>>2]|0;a[t]=u&255;a[m+(q+16)|0]=u>>>8&255;a[m+(q+17)|0]=u>>>16&255}}while(0);t=m+(q+18)|0;do{if((r+196602&536887296|0)==0){if(p<<24>>>0<=268435455){break}u=c[d+((p>>>4&15)<<2)>>2]|0;a[t]=u&255;a[m+(q+19)|0]=u>>>8&255;a[m+(q+20)|0]=u>>>16&255}}while(0);t=m+(q+21)|0;do{if((r+229369&536887296|0)==0){u=p&15;if((u|0)==0){break}v=c[d+(u<<2)>>2]|0;a[t]=v&255;a[m+(q+22)|0]=v>>>8&255;a[m+(q+23)|0]=v>>>16&255}}while(0);t=c[n+4>>2]|0;p=s|t;if((r+262136&536887296|0)==0&t>>>0>268435455){v=c[d+(t>>>28<<2)>>2]|0;a[m+(q+24)|0]=v&255;a[m+(q+25)|0]=v>>>8&255;a[m+(q+26)|0]=v>>>16&255}v=m+(q+27)|0;do{if((r+294903&536887296|0)==0){if(t<<4>>>0<=268435455){break}u=c[d+((t>>>24&15)<<2)>>2]|0;a[v]=u&255;a[m+(q+28)|0]=u>>>8&255;a[m+(q+29)|0]=u>>>16&255}}while(0);v=m+(q+30)|0;do{if((r+327670&536887296|0)==0){if(t<<8>>>0<=268435455){break}s=c[d+((t>>>20&15)<<2)>>2]|0;a[v]=s&255;a[m+(q+31)|0]=s>>>8&255;a[m+(q+32)|0]=s>>>16&255}}while(0);v=m+(q+33)|0;do{if((r+360437&536887296|0)==0){if(t<<12>>>0<=268435455){break}s=c[d+((t>>>16&15)<<2)>>2]|0;a[v]=s&255;a[m+(q+34)|0]=s>>>8&255;a[m+(q+35)|0]=s>>>16&255}}while(0);v=m+(q+36)|0;do{if((r+393204&536887296|0)==0){if(t<<16>>>0<=268435455){break}s=c[d+((t>>>12&15)<<2)>>2]|0;a[v]=s&255;a[m+(q+37)|0]=s>>>8&255;a[m+(q+38)|0]=s>>>16&255}}while(0);v=m+(q+39)|0;do{if((r+425971&536887296|0)==0){if(t<<20>>>0<=268435455){break}s=c[d+((t>>>8&15)<<2)>>2]|0;a[v]=s&255;a[m+(q+40)|0]=s>>>8&255;a[m+(q+41)|0]=s>>>16&255}}while(0);v=m+(q+42)|0;do{if((r+458738&536887296|0)==0){if(t<<24>>>0<=268435455){break}s=c[d+((t>>>4&15)<<2)>>2]|0;a[v]=s&255;a[m+(q+43)|0]=s>>>8&255;a[m+(q+44)|0]=s>>>16&255}}while(0);if((r+491505&536887296|0)!=0){w=p;break}v=t&15;if((v|0)==0){w=p;break}s=c[d+(v<<2)>>2]|0;a[m+(q+45)|0]=s&255;a[m+(q+46)|0]=s>>>8&255;a[m+(q+47)|0]=s>>>16&255;w=p}else{w=j}}while(0);x=m+g|0;y=n+h|0;if((i|0)>=16){break}i=i+1|0;j=w;k=k+2|0;l=o;m=x;n=y}c[2113226]=o;c[2112962]=x;c[2112960]=y;return(w|0)==0|0}function aga(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;d=c[3541654]|0;e=c[2113228]|0;f=c[2113308]|0;g=c[2113300]|0;h=c[2113224]|0;i=1;j=0;k=c[3541650]|0;l=c[2113226]|0;m=c[2112962]|0;n=c[2112960]|0;while(1){o=l+32767|0;do{if((l&536887296|0)==0){p=b[k>>1]|0;q=ag(p,f)|0;r=m+q|0;s=(p*32767|0)+e|0;p=c[n+4>>2]|0;t=p|j;do{if((s&536887296|0)==0){u=p&15;if((u|0)==0){break}v=c[d+(u<<2)>>2]|0;a[r]=v&255;a[m+(q+1)|0]=v>>>8&255;a[m+(q+2)|0]=v>>>16&255}}while(0);r=m+(q+3)|0;do{if((s+32767&536887296|0)==0){v=p>>>4&15;if((v|0)==0){break}u=c[d+(v<<2)>>2]|0;a[r]=u&255;a[m+(q+4)|0]=u>>>8&255;a[m+(q+5)|0]=u>>>16&255}}while(0);r=m+(q+6)|0;do{if((s+65534&536887296|0)==0){u=p>>>8&15;if((u|0)==0){break}v=c[d+(u<<2)>>2]|0;a[r]=v&255;a[m+(q+7)|0]=v>>>8&255;a[m+(q+8)|0]=v>>>16&255}}while(0);r=m+(q+9)|0;do{if((s+98301&536887296|0)==0){v=p>>>12&15;if((v|0)==0){break}u=c[d+(v<<2)>>2]|0;a[r]=u&255;a[m+(q+10)|0]=u>>>8&255;a[m+(q+11)|0]=u>>>16&255}}while(0);r=m+(q+12)|0;do{if((s+131068&536887296|0)==0){u=p>>>16&15;if((u|0)==0){break}v=c[d+(u<<2)>>2]|0;a[r]=v&255;a[m+(q+13)|0]=v>>>8&255;a[m+(q+14)|0]=v>>>16&255}}while(0);r=m+(q+15)|0;do{if((s+163835&536887296|0)==0){v=p>>>20&15;if((v|0)==0){break}u=c[d+(v<<2)>>2]|0;a[r]=u&255;a[m+(q+16)|0]=u>>>8&255;a[m+(q+17)|0]=u>>>16&255}}while(0);r=m+(q+18)|0;do{if((s+196602&536887296|0)==0){u=p>>>24&15;if((u|0)==0){break}v=c[d+(u<<2)>>2]|0;a[r]=v&255;a[m+(q+19)|0]=v>>>8&255;a[m+(q+20)|0]=v>>>16&255}}while(0);r=m+(q+21)|0;do{if((s+229369&536887296|0)==0){v=p>>>28;if((v|0)==0){break}u=c[d+(v<<2)>>2]|0;a[r]=u&255;a[m+(q+22)|0]=u>>>8&255;a[m+(q+23)|0]=u>>>16&255}}while(0);r=m+(q+24)|0;p=c[n>>2]|0;u=t|p;do{if((s+262136&536887296|0)==0){v=p&15;if((v|0)==0){break}w=c[d+(v<<2)>>2]|0;a[r]=w&255;a[m+(q+25)|0]=w>>>8&255;a[m+(q+26)|0]=w>>>16&255}}while(0);r=m+(q+27)|0;do{if((s+294903&536887296|0)==0){t=p>>>4&15;if((t|0)==0){break}w=c[d+(t<<2)>>2]|0;a[r]=w&255;a[m+(q+28)|0]=w>>>8&255;a[m+(q+29)|0]=w>>>16&255}}while(0);r=m+(q+30)|0;do{if((s+327670&536887296|0)==0){w=p>>>8&15;if((w|0)==0){break}t=c[d+(w<<2)>>2]|0;a[r]=t&255;a[m+(q+31)|0]=t>>>8&255;a[m+(q+32)|0]=t>>>16&255}}while(0);r=m+(q+33)|0;do{if((s+360437&536887296|0)==0){t=p>>>12&15;if((t|0)==0){break}w=c[d+(t<<2)>>2]|0;a[r]=w&255;a[m+(q+34)|0]=w>>>8&255;a[m+(q+35)|0]=w>>>16&255}}while(0);r=m+(q+36)|0;do{if((s+393204&536887296|0)==0){w=p>>>16&15;if((w|0)==0){break}t=c[d+(w<<2)>>2]|0;a[r]=t&255;a[m+(q+37)|0]=t>>>8&255;a[m+(q+38)|0]=t>>>16&255}}while(0);r=m+(q+39)|0;do{if((s+425971&536887296|0)==0){t=p>>>20&15;if((t|0)==0){break}w=c[d+(t<<2)>>2]|0;a[r]=w&255;a[m+(q+40)|0]=w>>>8&255;a[m+(q+41)|0]=w>>>16&255}}while(0);r=m+(q+42)|0;do{if((s+458738&536887296|0)==0){w=p>>>24&15;if((w|0)==0){break}t=c[d+(w<<2)>>2]|0;a[r]=t&255;a[m+(q+43)|0]=t>>>8&255;a[m+(q+44)|0]=t>>>16&255}}while(0);if((s+491505&536887296|0)!=0){x=u;break}r=p>>>28;if((r|0)==0){x=u;break}t=c[d+(r<<2)>>2]|0;a[m+(q+45)|0]=t&255;a[m+(q+46)|0]=t>>>8&255;a[m+(q+47)|0]=t>>>16&255;x=u}else{x=j}}while(0);y=m+g|0;z=n+h|0;if((i|0)>=16){break}i=i+1|0;j=x;k=k+2|0;l=o;m=y;n=z}c[2113226]=o;c[2112962]=y;c[2112960]=z;return(x|0)==0|0}function agb(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[3541654]|0;d=c[2113300]|0;e=c[2113224]|0;f=0;g=0;h=c[2112960]|0;i=c[2112962]|0;do{j=c[h>>2]|0;if(j>>>0>268435455){k=c[b+(j>>>28<<2)>>2]|0;a[i]=k&255;a[i+1|0]=k>>>8&255;a[i+2|0]=k>>>16&255}if(j<<4>>>0>268435455){k=c[b+((j>>>24&15)<<2)>>2]|0;a[i+3|0]=k&255;a[i+4|0]=k>>>8&255;a[i+5|0]=k>>>16&255}if(j<<8>>>0>268435455){k=c[b+((j>>>20&15)<<2)>>2]|0;a[i+6|0]=k&255;a[i+7|0]=k>>>8&255;a[i+8|0]=k>>>16&255}if(j<<12>>>0>268435455){k=c[b+((j>>>16&15)<<2)>>2]|0;a[i+9|0]=k&255;a[i+10|0]=k>>>8&255;a[i+11|0]=k>>>16&255}if(j<<16>>>0>268435455){k=c[b+((j>>>12&15)<<2)>>2]|0;a[i+12|0]=k&255;a[i+13|0]=k>>>8&255;a[i+14|0]=k>>>16&255}if(j<<20>>>0>268435455){k=c[b+((j>>>8&15)<<2)>>2]|0;a[i+15|0]=k&255;a[i+16|0]=k>>>8&255;a[i+17|0]=k>>>16&255}if(j<<24>>>0>268435455){k=c[b+((j>>>4&15)<<2)>>2]|0;a[i+18|0]=k&255;a[i+19|0]=k>>>8&255;a[i+20|0]=k>>>16&255}k=j&15;if((k|0)!=0){l=c[b+(k<<2)>>2]|0;a[i+21|0]=l&255;a[i+22|0]=l>>>8&255;a[i+23|0]=l>>>16&255}l=c[h+4>>2]|0;if(l>>>0>268435455){k=c[b+(l>>>28<<2)>>2]|0;a[i+24|0]=k&255;a[i+25|0]=k>>>8&255;a[i+26|0]=k>>>16&255}if(l<<4>>>0>268435455){k=c[b+((l>>>24&15)<<2)>>2]|0;a[i+27|0]=k&255;a[i+28|0]=k>>>8&255;a[i+29|0]=k>>>16&255}if(l<<8>>>0>268435455){k=c[b+((l>>>20&15)<<2)>>2]|0;a[i+30|0]=k&255;a[i+31|0]=k>>>8&255;a[i+32|0]=k>>>16&255}if(l<<12>>>0>268435455){k=c[b+((l>>>16&15)<<2)>>2]|0;a[i+33|0]=k&255;a[i+34|0]=k>>>8&255;a[i+35|0]=k>>>16&255}if(l<<16>>>0>268435455){k=c[b+((l>>>12&15)<<2)>>2]|0;a[i+36|0]=k&255;a[i+37|0]=k>>>8&255;a[i+38|0]=k>>>16&255}if(l<<20>>>0>268435455){k=c[b+((l>>>8&15)<<2)>>2]|0;a[i+39|0]=k&255;a[i+40|0]=k>>>8&255;a[i+41|0]=k>>>16&255}if(l<<24>>>0>268435455){k=c[b+((l>>>4&15)<<2)>>2]|0;a[i+42|0]=k&255;a[i+43|0]=k>>>8&255;a[i+44|0]=k>>>16&255}k=l&15;if((k|0)!=0){m=c[b+(k<<2)>>2]|0;a[i+45|0]=m&255;a[i+46|0]=m>>>8&255;a[i+47|0]=m>>>16&255}m=c[h+8>>2]|0;if(m>>>0>268435455){k=c[b+(m>>>28<<2)>>2]|0;a[i+48|0]=k&255;a[i+49|0]=k>>>8&255;a[i+50|0]=k>>>16&255}if(m<<4>>>0>268435455){k=c[b+((m>>>24&15)<<2)>>2]|0;a[i+51|0]=k&255;a[i+52|0]=k>>>8&255;a[i+53|0]=k>>>16&255}if(m<<8>>>0>268435455){k=c[b+((m>>>20&15)<<2)>>2]|0;a[i+54|0]=k&255;a[i+55|0]=k>>>8&255;a[i+56|0]=k>>>16&255}if(m<<12>>>0>268435455){k=c[b+((m>>>16&15)<<2)>>2]|0;a[i+57|0]=k&255;a[i+58|0]=k>>>8&255;a[i+59|0]=k>>>16&255}if(m<<16>>>0>268435455){k=c[b+((m>>>12&15)<<2)>>2]|0;a[i+60|0]=k&255;a[i+61|0]=k>>>8&255;a[i+62|0]=k>>>16&255}if(m<<20>>>0>268435455){k=c[b+((m>>>8&15)<<2)>>2]|0;a[i+63|0]=k&255;a[i+64|0]=k>>>8&255;a[i+65|0]=k>>>16&255}if(m<<24>>>0>268435455){k=c[b+((m>>>4&15)<<2)>>2]|0;a[i+66|0]=k&255;a[i+67|0]=k>>>8&255;a[i+68|0]=k>>>16&255}k=m&15;if((k|0)!=0){n=c[b+(k<<2)>>2]|0;a[i+69|0]=n&255;a[i+70|0]=n>>>8&255;a[i+71|0]=n>>>16&255}n=c[h+12>>2]|0;g=j|g|l|m|n;if(n>>>0>268435455){m=c[b+(n>>>28<<2)>>2]|0;a[i+72|0]=m&255;a[i+73|0]=m>>>8&255;a[i+74|0]=m>>>16&255}if(n<<4>>>0>268435455){m=c[b+((n>>>24&15)<<2)>>2]|0;a[i+75|0]=m&255;a[i+76|0]=m>>>8&255;a[i+77|0]=m>>>16&255}if(n<<8>>>0>268435455){m=c[b+((n>>>20&15)<<2)>>2]|0;a[i+78|0]=m&255;a[i+79|0]=m>>>8&255;a[i+80|0]=m>>>16&255}if(n<<12>>>0>268435455){m=c[b+((n>>>16&15)<<2)>>2]|0;a[i+81|0]=m&255;a[i+82|0]=m>>>8&255;a[i+83|0]=m>>>16&255}if(n<<16>>>0>268435455){m=c[b+((n>>>12&15)<<2)>>2]|0;a[i+84|0]=m&255;a[i+85|0]=m>>>8&255;a[i+86|0]=m>>>16&255}if(n<<20>>>0>268435455){m=c[b+((n>>>8&15)<<2)>>2]|0;a[i+87|0]=m&255;a[i+88|0]=m>>>8&255;a[i+89|0]=m>>>16&255}if(n<<24>>>0>268435455){m=c[b+((n>>>4&15)<<2)>>2]|0;a[i+90|0]=m&255;a[i+91|0]=m>>>8&255;a[i+92|0]=m>>>16&255}m=n&15;if((m|0)!=0){n=c[b+(m<<2)>>2]|0;a[i+93|0]=n&255;a[i+94|0]=n>>>8&255;a[i+95|0]=n>>>16&255}f=f+1|0;i=i+d|0;h=h+e|0;}while((f|0)<32);c[2112960]=h;c[2112962]=i;return(g|0)==0|0}function agc(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[3541654]|0;d=c[2113300]|0;e=c[2113224]|0;f=0;g=0;h=c[2112960]|0;i=c[2112962]|0;do{j=c[h+12>>2]|0;k=j&15;if((k|0)!=0){l=c[b+(k<<2)>>2]|0;a[i]=l&255;a[i+1|0]=l>>>8&255;a[i+2|0]=l>>>16&255}l=j>>>4&15;if((l|0)!=0){k=c[b+(l<<2)>>2]|0;a[i+3|0]=k&255;a[i+4|0]=k>>>8&255;a[i+5|0]=k>>>16&255}k=j>>>8&15;if((k|0)!=0){l=c[b+(k<<2)>>2]|0;a[i+6|0]=l&255;a[i+7|0]=l>>>8&255;a[i+8|0]=l>>>16&255}l=j>>>12&15;if((l|0)!=0){k=c[b+(l<<2)>>2]|0;a[i+9|0]=k&255;a[i+10|0]=k>>>8&255;a[i+11|0]=k>>>16&255}k=j>>>16&15;if((k|0)!=0){l=c[b+(k<<2)>>2]|0;a[i+12|0]=l&255;a[i+13|0]=l>>>8&255;a[i+14|0]=l>>>16&255}l=j>>>20&15;if((l|0)!=0){k=c[b+(l<<2)>>2]|0;a[i+15|0]=k&255;a[i+16|0]=k>>>8&255;a[i+17|0]=k>>>16&255}k=j>>>24&15;if((k|0)!=0){l=c[b+(k<<2)>>2]|0;a[i+18|0]=l&255;a[i+19|0]=l>>>8&255;a[i+20|0]=l>>>16&255}l=j>>>28;if((l|0)!=0){k=c[b+(l<<2)>>2]|0;a[i+21|0]=k&255;a[i+22|0]=k>>>8&255;a[i+23|0]=k>>>16&255}k=c[h+8>>2]|0;l=k&15;if((l|0)!=0){m=c[b+(l<<2)>>2]|0;a[i+24|0]=m&255;a[i+25|0]=m>>>8&255;a[i+26|0]=m>>>16&255}m=k>>>4&15;if((m|0)!=0){l=c[b+(m<<2)>>2]|0;a[i+27|0]=l&255;a[i+28|0]=l>>>8&255;a[i+29|0]=l>>>16&255}l=k>>>8&15;if((l|0)!=0){m=c[b+(l<<2)>>2]|0;a[i+30|0]=m&255;a[i+31|0]=m>>>8&255;a[i+32|0]=m>>>16&255}m=k>>>12&15;if((m|0)!=0){l=c[b+(m<<2)>>2]|0;a[i+33|0]=l&255;a[i+34|0]=l>>>8&255;a[i+35|0]=l>>>16&255}l=k>>>16&15;if((l|0)!=0){m=c[b+(l<<2)>>2]|0;a[i+36|0]=m&255;a[i+37|0]=m>>>8&255;a[i+38|0]=m>>>16&255}m=k>>>20&15;if((m|0)!=0){l=c[b+(m<<2)>>2]|0;a[i+39|0]=l&255;a[i+40|0]=l>>>8&255;a[i+41|0]=l>>>16&255}l=k>>>24&15;if((l|0)!=0){m=c[b+(l<<2)>>2]|0;a[i+42|0]=m&255;a[i+43|0]=m>>>8&255;a[i+44|0]=m>>>16&255}m=k>>>28;if((m|0)!=0){l=c[b+(m<<2)>>2]|0;a[i+45|0]=l&255;a[i+46|0]=l>>>8&255;a[i+47|0]=l>>>16&255}l=c[h+4>>2]|0;m=l&15;if((m|0)!=0){n=c[b+(m<<2)>>2]|0;a[i+48|0]=n&255;a[i+49|0]=n>>>8&255;a[i+50|0]=n>>>16&255}n=l>>>4&15;if((n|0)!=0){m=c[b+(n<<2)>>2]|0;a[i+51|0]=m&255;a[i+52|0]=m>>>8&255;a[i+53|0]=m>>>16&255}m=l>>>8&15;if((m|0)!=0){n=c[b+(m<<2)>>2]|0;a[i+54|0]=n&255;a[i+55|0]=n>>>8&255;a[i+56|0]=n>>>16&255}n=l>>>12&15;if((n|0)!=0){m=c[b+(n<<2)>>2]|0;a[i+57|0]=m&255;a[i+58|0]=m>>>8&255;a[i+59|0]=m>>>16&255}m=l>>>16&15;if((m|0)!=0){n=c[b+(m<<2)>>2]|0;a[i+60|0]=n&255;a[i+61|0]=n>>>8&255;a[i+62|0]=n>>>16&255}n=l>>>20&15;if((n|0)!=0){m=c[b+(n<<2)>>2]|0;a[i+63|0]=m&255;a[i+64|0]=m>>>8&255;a[i+65|0]=m>>>16&255}m=l>>>24&15;if((m|0)!=0){n=c[b+(m<<2)>>2]|0;a[i+66|0]=n&255;a[i+67|0]=n>>>8&255;a[i+68|0]=n>>>16&255}n=l>>>28;if((n|0)!=0){m=c[b+(n<<2)>>2]|0;a[i+69|0]=m&255;a[i+70|0]=m>>>8&255;a[i+71|0]=m>>>16&255}m=c[h>>2]|0;g=j|g|k|l|m;l=m&15;if((l|0)!=0){k=c[b+(l<<2)>>2]|0;a[i+72|0]=k&255;a[i+73|0]=k>>>8&255;a[i+74|0]=k>>>16&255}k=m>>>4&15;if((k|0)!=0){l=c[b+(k<<2)>>2]|0;a[i+75|0]=l&255;a[i+76|0]=l>>>8&255;a[i+77|0]=l>>>16&255}l=m>>>8&15;if((l|0)!=0){k=c[b+(l<<2)>>2]|0;a[i+78|0]=k&255;a[i+79|0]=k>>>8&255;a[i+80|0]=k>>>16&255}k=m>>>12&15;if((k|0)!=0){l=c[b+(k<<2)>>2]|0;a[i+81|0]=l&255;a[i+82|0]=l>>>8&255;a[i+83|0]=l>>>16&255}l=m>>>16&15;if((l|0)!=0){k=c[b+(l<<2)>>2]|0;a[i+84|0]=k&255;a[i+85|0]=k>>>8&255;a[i+86|0]=k>>>16&255}k=m>>>20&15;if((k|0)!=0){l=c[b+(k<<2)>>2]|0;a[i+87|0]=l&255;a[i+88|0]=l>>>8&255;a[i+89|0]=l>>>16&255}l=m>>>24&15;if((l|0)!=0){k=c[b+(l<<2)>>2]|0;a[i+90|0]=k&255;a[i+91|0]=k>>>8&255;a[i+92|0]=k>>>16&255}k=m>>>28;if((k|0)!=0){m=c[b+(k<<2)>>2]|0;a[i+93|0]=m&255;a[i+94|0]=m>>>8&255;a[i+95|0]=m>>>16&255}f=f+1|0;i=i+d|0;h=h+e|0;}while((f|0)<32);c[2112960]=h;c[2112962]=i;return(g|0)==0|0}function agd(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;b=c[3541654]|0;d=c[2113228]|0;e=(d&536887296|0)==0;f=(d+32767&536887296|0)==0;g=(d+65534&536887296|0)==0;h=(d+98301&536887296|0)==0;i=(d+131068&536887296|0)==0;j=(d+163835&536887296|0)==0;k=(d+196602&536887296|0)==0;l=(d+229369&536887296|0)==0;m=(d+262136&536887296|0)==0;n=(d+294903&536887296|0)==0;o=(d+327670&536887296|0)==0;p=(d+360437&536887296|0)==0;q=(d+393204&536887296|0)==0;r=(d+425971&536887296|0)==0;s=(d+458738&536887296|0)==0;t=(d+491505&536887296|0)==0;u=(d+524272&536887296|0)==0;v=(d+557039&536887296|0)==0;w=(d+589806&536887296|0)==0;x=(d+622573&536887296|0)==0;y=(d+655340&536887296|0)==0;z=(d+688107&536887296|0)==0;A=(d+720874&536887296|0)==0;B=(d+753641&536887296|0)==0;C=(d+786408&536887296|0)==0;D=(d+819175&536887296|0)==0;E=(d+851942&536887296|0)==0;F=(d+884709&536887296|0)==0;G=(d+917476&536887296|0)==0;H=(d+950243&536887296|0)==0;I=(d+983010&536887296|0)==0;J=(d+1015777&536887296|0)==0;d=c[2113300]|0;K=c[2113224]|0;L=1;M=0;N=c[2113226]|0;O=c[2112962]|0;P=c[2112960]|0;while(1){Q=N+32767|0;do{if((N&536887296|0)==0){R=c[P>>2]|0;S=R|M;if(e&R>>>0>268435455){T=c[b+(R>>>28<<2)>>2]|0;a[O]=T&255;a[O+1|0]=T>>>8&255;a[O+2|0]=T>>>16&255}T=O+3|0;do{if(f){if(R<<4>>>0<=268435455){break}U=c[b+((R>>>24&15)<<2)>>2]|0;a[T]=U&255;a[O+4|0]=U>>>8&255;a[O+5|0]=U>>>16&255}}while(0);T=O+6|0;do{if(g){if(R<<8>>>0<=268435455){break}U=c[b+((R>>>20&15)<<2)>>2]|0;a[T]=U&255;a[O+7|0]=U>>>8&255;a[O+8|0]=U>>>16&255}}while(0);T=O+9|0;do{if(h){if(R<<12>>>0<=268435455){break}U=c[b+((R>>>16&15)<<2)>>2]|0;a[T]=U&255;a[O+10|0]=U>>>8&255;a[O+11|0]=U>>>16&255}}while(0);T=O+12|0;do{if(i){if(R<<16>>>0<=268435455){break}U=c[b+((R>>>12&15)<<2)>>2]|0;a[T]=U&255;a[O+13|0]=U>>>8&255;a[O+14|0]=U>>>16&255}}while(0);T=O+15|0;do{if(j){if(R<<20>>>0<=268435455){break}U=c[b+((R>>>8&15)<<2)>>2]|0;a[T]=U&255;a[O+16|0]=U>>>8&255;a[O+17|0]=U>>>16&255}}while(0);T=O+18|0;do{if(k){if(R<<24>>>0<=268435455){break}U=c[b+((R>>>4&15)<<2)>>2]|0;a[T]=U&255;a[O+19|0]=U>>>8&255;a[O+20|0]=U>>>16&255}}while(0);T=O+21|0;do{if(l){U=R&15;if((U|0)==0){break}V=c[b+(U<<2)>>2]|0;a[T]=V&255;a[O+22|0]=V>>>8&255;a[O+23|0]=V>>>16&255}}while(0);T=c[P+4>>2]|0;R=S|T;if(m&T>>>0>268435455){V=c[b+(T>>>28<<2)>>2]|0;a[O+24|0]=V&255;a[O+25|0]=V>>>8&255;a[O+26|0]=V>>>16&255}V=O+27|0;do{if(n){if(T<<4>>>0<=268435455){break}U=c[b+((T>>>24&15)<<2)>>2]|0;a[V]=U&255;a[O+28|0]=U>>>8&255;a[O+29|0]=U>>>16&255}}while(0);V=O+30|0;do{if(o){if(T<<8>>>0<=268435455){break}S=c[b+((T>>>20&15)<<2)>>2]|0;a[V]=S&255;a[O+31|0]=S>>>8&255;a[O+32|0]=S>>>16&255}}while(0);V=O+33|0;do{if(p){if(T<<12>>>0<=268435455){break}S=c[b+((T>>>16&15)<<2)>>2]|0;a[V]=S&255;a[O+34|0]=S>>>8&255;a[O+35|0]=S>>>16&255}}while(0);V=O+36|0;do{if(q){if(T<<16>>>0<=268435455){break}S=c[b+((T>>>12&15)<<2)>>2]|0;a[V]=S&255;a[O+37|0]=S>>>8&255;a[O+38|0]=S>>>16&255}}while(0);V=O+39|0;do{if(r){if(T<<20>>>0<=268435455){break}S=c[b+((T>>>8&15)<<2)>>2]|0;a[V]=S&255;a[O+40|0]=S>>>8&255;a[O+41|0]=S>>>16&255}}while(0);V=O+42|0;do{if(s){if(T<<24>>>0<=268435455){break}S=c[b+((T>>>4&15)<<2)>>2]|0;a[V]=S&255;a[O+43|0]=S>>>8&255;a[O+44|0]=S>>>16&255}}while(0);V=O+45|0;do{if(t){S=T&15;if((S|0)==0){break}U=c[b+(S<<2)>>2]|0;a[V]=U&255;a[O+46|0]=U>>>8&255;a[O+47|0]=U>>>16&255}}while(0);V=c[P+8>>2]|0;T=R|V;if(u&V>>>0>268435455){U=c[b+(V>>>28<<2)>>2]|0;a[O+48|0]=U&255;a[O+49|0]=U>>>8&255;a[O+50|0]=U>>>16&255}U=O+51|0;do{if(v){if(V<<4>>>0<=268435455){break}S=c[b+((V>>>24&15)<<2)>>2]|0;a[U]=S&255;a[O+52|0]=S>>>8&255;a[O+53|0]=S>>>16&255}}while(0);U=O+54|0;do{if(w){if(V<<8>>>0<=268435455){break}R=c[b+((V>>>20&15)<<2)>>2]|0;a[U]=R&255;a[O+55|0]=R>>>8&255;a[O+56|0]=R>>>16&255}}while(0);U=O+57|0;do{if(x){if(V<<12>>>0<=268435455){break}R=c[b+((V>>>16&15)<<2)>>2]|0;a[U]=R&255;a[O+58|0]=R>>>8&255;a[O+59|0]=R>>>16&255}}while(0);U=O+60|0;do{if(y){if(V<<16>>>0<=268435455){break}R=c[b+((V>>>12&15)<<2)>>2]|0;a[U]=R&255;a[O+61|0]=R>>>8&255;a[O+62|0]=R>>>16&255}}while(0);U=O+63|0;do{if(z){if(V<<20>>>0<=268435455){break}R=c[b+((V>>>8&15)<<2)>>2]|0;a[U]=R&255;a[O+64|0]=R>>>8&255;a[O+65|0]=R>>>16&255}}while(0);U=O+66|0;do{if(A){if(V<<24>>>0<=268435455){break}R=c[b+((V>>>4&15)<<2)>>2]|0;a[U]=R&255;a[O+67|0]=R>>>8&255;a[O+68|0]=R>>>16&255}}while(0);U=O+69|0;do{if(B){R=V&15;if((R|0)==0){break}S=c[b+(R<<2)>>2]|0;a[U]=S&255;a[O+70|0]=S>>>8&255;a[O+71|0]=S>>>16&255}}while(0);U=c[P+12>>2]|0;V=T|U;if(C&U>>>0>268435455){S=c[b+(U>>>28<<2)>>2]|0;a[O+72|0]=S&255;a[O+73|0]=S>>>8&255;a[O+74|0]=S>>>16&255}S=O+75|0;do{if(D){if(U<<4>>>0<=268435455){break}R=c[b+((U>>>24&15)<<2)>>2]|0;a[S]=R&255;a[O+76|0]=R>>>8&255;a[O+77|0]=R>>>16&255}}while(0);S=O+78|0;do{if(E){if(U<<8>>>0<=268435455){break}T=c[b+((U>>>20&15)<<2)>>2]|0;a[S]=T&255;a[O+79|0]=T>>>8&255;a[O+80|0]=T>>>16&255}}while(0);S=O+81|0;do{if(F){if(U<<12>>>0<=268435455){break}T=c[b+((U>>>16&15)<<2)>>2]|0;a[S]=T&255;a[O+82|0]=T>>>8&255;a[O+83|0]=T>>>16&255}}while(0);S=O+84|0;do{if(G){if(U<<16>>>0<=268435455){break}T=c[b+((U>>>12&15)<<2)>>2]|0;a[S]=T&255;a[O+85|0]=T>>>8&255;a[O+86|0]=T>>>16&255}}while(0);S=O+87|0;do{if(H){if(U<<20>>>0<=268435455){break}T=c[b+((U>>>8&15)<<2)>>2]|0;a[S]=T&255;a[O+88|0]=T>>>8&255;a[O+89|0]=T>>>16&255}}while(0);S=O+90|0;do{if(I){if(U<<24>>>0<=268435455){break}T=c[b+((U>>>4&15)<<2)>>2]|0;a[S]=T&255;a[O+91|0]=T>>>8&255;a[O+92|0]=T>>>16&255}}while(0);if(!J){W=V;break}S=U&15;if((S|0)==0){W=V;break}T=c[b+(S<<2)>>2]|0;a[O+93|0]=T&255;a[O+94|0]=T>>>8&255;a[O+95|0]=T>>>16&255;W=V}else{W=M}}while(0);X=O+d|0;Y=P+K|0;if((L|0)>=32){break}L=L+1|0;M=W;N=Q;O=X;P=Y}c[2113226]=Q;c[2112962]=X;c[2112960]=Y;return(W|0)==0|0}function age(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;b=c[3541654]|0;d=c[2113228]|0;e=(d&536887296|0)==0;f=(d+32767&536887296|0)==0;g=(d+65534&536887296|0)==0;h=(d+98301&536887296|0)==0;i=(d+131068&536887296|0)==0;j=(d+163835&536887296|0)==0;k=(d+196602&536887296|0)==0;l=(d+229369&536887296|0)==0;m=(d+262136&536887296|0)==0;n=(d+294903&536887296|0)==0;o=(d+327670&536887296|0)==0;p=(d+360437&536887296|0)==0;q=(d+393204&536887296|0)==0;r=(d+425971&536887296|0)==0;s=(d+458738&536887296|0)==0;t=(d+491505&536887296|0)==0;u=(d+524272&536887296|0)==0;v=(d+557039&536887296|0)==0;w=(d+589806&536887296|0)==0;x=(d+622573&536887296|0)==0;y=(d+655340&536887296|0)==0;z=(d+688107&536887296|0)==0;A=(d+720874&536887296|0)==0;B=(d+753641&536887296|0)==0;C=(d+786408&536887296|0)==0;D=(d+819175&536887296|0)==0;E=(d+851942&536887296|0)==0;F=(d+884709&536887296|0)==0;G=(d+917476&536887296|0)==0;H=(d+950243&536887296|0)==0;I=(d+983010&536887296|0)==0;J=(d+1015777&536887296|0)==0;d=c[2113300]|0;K=c[2113224]|0;L=1;M=0;N=c[2113226]|0;O=c[2112962]|0;P=c[2112960]|0;while(1){Q=N+32767|0;do{if((N&536887296|0)==0){R=c[P+12>>2]|0;S=R|M;do{if(e){T=R&15;if((T|0)==0){break}U=c[b+(T<<2)>>2]|0;a[O]=U&255;a[O+1|0]=U>>>8&255;a[O+2|0]=U>>>16&255}}while(0);U=O+3|0;do{if(f){T=R>>>4&15;if((T|0)==0){break}V=c[b+(T<<2)>>2]|0;a[U]=V&255;a[O+4|0]=V>>>8&255;a[O+5|0]=V>>>16&255}}while(0);U=O+6|0;do{if(g){V=R>>>8&15;if((V|0)==0){break}T=c[b+(V<<2)>>2]|0;a[U]=T&255;a[O+7|0]=T>>>8&255;a[O+8|0]=T>>>16&255}}while(0);U=O+9|0;do{if(h){T=R>>>12&15;if((T|0)==0){break}V=c[b+(T<<2)>>2]|0;a[U]=V&255;a[O+10|0]=V>>>8&255;a[O+11|0]=V>>>16&255}}while(0);U=O+12|0;do{if(i){V=R>>>16&15;if((V|0)==0){break}T=c[b+(V<<2)>>2]|0;a[U]=T&255;a[O+13|0]=T>>>8&255;a[O+14|0]=T>>>16&255}}while(0);U=O+15|0;do{if(j){T=R>>>20&15;if((T|0)==0){break}V=c[b+(T<<2)>>2]|0;a[U]=V&255;a[O+16|0]=V>>>8&255;a[O+17|0]=V>>>16&255}}while(0);U=O+18|0;do{if(k){V=R>>>24&15;if((V|0)==0){break}T=c[b+(V<<2)>>2]|0;a[U]=T&255;a[O+19|0]=T>>>8&255;a[O+20|0]=T>>>16&255}}while(0);U=O+21|0;do{if(l){T=R>>>28;if((T|0)==0){break}V=c[b+(T<<2)>>2]|0;a[U]=V&255;a[O+22|0]=V>>>8&255;a[O+23|0]=V>>>16&255}}while(0);U=O+24|0;R=c[P+8>>2]|0;V=S|R;do{if(m){T=R&15;if((T|0)==0){break}W=c[b+(T<<2)>>2]|0;a[U]=W&255;a[O+25|0]=W>>>8&255;a[O+26|0]=W>>>16&255}}while(0);U=O+27|0;do{if(n){S=R>>>4&15;if((S|0)==0){break}W=c[b+(S<<2)>>2]|0;a[U]=W&255;a[O+28|0]=W>>>8&255;a[O+29|0]=W>>>16&255}}while(0);U=O+30|0;do{if(o){W=R>>>8&15;if((W|0)==0){break}S=c[b+(W<<2)>>2]|0;a[U]=S&255;a[O+31|0]=S>>>8&255;a[O+32|0]=S>>>16&255}}while(0);U=O+33|0;do{if(p){S=R>>>12&15;if((S|0)==0){break}W=c[b+(S<<2)>>2]|0;a[U]=W&255;a[O+34|0]=W>>>8&255;a[O+35|0]=W>>>16&255}}while(0);U=O+36|0;do{if(q){W=R>>>16&15;if((W|0)==0){break}S=c[b+(W<<2)>>2]|0;a[U]=S&255;a[O+37|0]=S>>>8&255;a[O+38|0]=S>>>16&255}}while(0);U=O+39|0;do{if(r){S=R>>>20&15;if((S|0)==0){break}W=c[b+(S<<2)>>2]|0;a[U]=W&255;a[O+40|0]=W>>>8&255;a[O+41|0]=W>>>16&255}}while(0);U=O+42|0;do{if(s){W=R>>>24&15;if((W|0)==0){break}S=c[b+(W<<2)>>2]|0;a[U]=S&255;a[O+43|0]=S>>>8&255;a[O+44|0]=S>>>16&255}}while(0);U=O+45|0;do{if(t){S=R>>>28;if((S|0)==0){break}W=c[b+(S<<2)>>2]|0;a[U]=W&255;a[O+46|0]=W>>>8&255;a[O+47|0]=W>>>16&255}}while(0);U=O+48|0;R=c[P+4>>2]|0;W=V|R;do{if(u){S=R&15;if((S|0)==0){break}T=c[b+(S<<2)>>2]|0;a[U]=T&255;a[O+49|0]=T>>>8&255;a[O+50|0]=T>>>16&255}}while(0);U=O+51|0;do{if(v){V=R>>>4&15;if((V|0)==0){break}T=c[b+(V<<2)>>2]|0;a[U]=T&255;a[O+52|0]=T>>>8&255;a[O+53|0]=T>>>16&255}}while(0);U=O+54|0;do{if(w){T=R>>>8&15;if((T|0)==0){break}V=c[b+(T<<2)>>2]|0;a[U]=V&255;a[O+55|0]=V>>>8&255;a[O+56|0]=V>>>16&255}}while(0);U=O+57|0;do{if(x){V=R>>>12&15;if((V|0)==0){break}T=c[b+(V<<2)>>2]|0;a[U]=T&255;a[O+58|0]=T>>>8&255;a[O+59|0]=T>>>16&255}}while(0);U=O+60|0;do{if(y){T=R>>>16&15;if((T|0)==0){break}V=c[b+(T<<2)>>2]|0;a[U]=V&255;a[O+61|0]=V>>>8&255;a[O+62|0]=V>>>16&255}}while(0);U=O+63|0;do{if(z){V=R>>>20&15;if((V|0)==0){break}T=c[b+(V<<2)>>2]|0;a[U]=T&255;a[O+64|0]=T>>>8&255;a[O+65|0]=T>>>16&255}}while(0);U=O+66|0;do{if(A){T=R>>>24&15;if((T|0)==0){break}V=c[b+(T<<2)>>2]|0;a[U]=V&255;a[O+67|0]=V>>>8&255;a[O+68|0]=V>>>16&255}}while(0);U=O+69|0;do{if(B){V=R>>>28;if((V|0)==0){break}T=c[b+(V<<2)>>2]|0;a[U]=T&255;a[O+70|0]=T>>>8&255;a[O+71|0]=T>>>16&255}}while(0);U=O+72|0;R=c[P>>2]|0;T=W|R;do{if(C){V=R&15;if((V|0)==0){break}S=c[b+(V<<2)>>2]|0;a[U]=S&255;a[O+73|0]=S>>>8&255;a[O+74|0]=S>>>16&255}}while(0);U=O+75|0;do{if(D){W=R>>>4&15;if((W|0)==0){break}S=c[b+(W<<2)>>2]|0;a[U]=S&255;a[O+76|0]=S>>>8&255;a[O+77|0]=S>>>16&255}}while(0);U=O+78|0;do{if(E){S=R>>>8&15;if((S|0)==0){break}W=c[b+(S<<2)>>2]|0;a[U]=W&255;a[O+79|0]=W>>>8&255;a[O+80|0]=W>>>16&255}}while(0);U=O+81|0;do{if(F){W=R>>>12&15;if((W|0)==0){break}S=c[b+(W<<2)>>2]|0;a[U]=S&255;a[O+82|0]=S>>>8&255;a[O+83|0]=S>>>16&255}}while(0);U=O+84|0;do{if(G){S=R>>>16&15;if((S|0)==0){break}W=c[b+(S<<2)>>2]|0;a[U]=W&255;a[O+85|0]=W>>>8&255;a[O+86|0]=W>>>16&255}}while(0);U=O+87|0;do{if(H){W=R>>>20&15;if((W|0)==0){break}S=c[b+(W<<2)>>2]|0;a[U]=S&255;a[O+88|0]=S>>>8&255;a[O+89|0]=S>>>16&255}}while(0);U=O+90|0;do{if(I){S=R>>>24&15;if((S|0)==0){break}W=c[b+(S<<2)>>2]|0;a[U]=W&255;a[O+91|0]=W>>>8&255;a[O+92|0]=W>>>16&255}}while(0);if(!J){X=T;break}U=R>>>28;if((U|0)==0){X=T;break}W=c[b+(U<<2)>>2]|0;a[O+93|0]=W&255;a[O+94|0]=W>>>8&255;a[O+95|0]=W>>>16&255;X=T}else{X=M}}while(0);Y=O+d|0;Z=P+K|0;if((L|0)>=32){break}L=L+1|0;M=X;N=Q;O=Y;P=Z}c[2113226]=Q;c[2112962]=Y;c[2112960]=Z;return(X|0)==0|0}function agf(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[3541654]|0;d=c[2113300]|0;e=c[2113224]|0;f=c[3541652]|0;g=0;h=0;i=c[2112962]|0;j=c[2112960]|0;do{k=c[j>>2]|0;h=k|h;l=k>>>28;do{if((l|0)!=0){if((f&1<<(l^15)|0)==0){break}b[i>>1]=c[a+(l<<2)>>2]&65535}}while(0);l=i+2|0;m=k&15;n=k>>>24&15;do{if((n|0)!=0){if((f&1<<(n^15)|0)==0){break}b[l>>1]=c[a+(n<<2)>>2]&65535}}while(0);n=i+4|0;l=k>>>20&15;do{if((l|0)!=0){if((f&1<<(l^15)|0)==0){break}b[n>>1]=c[a+(l<<2)>>2]&65535}}while(0);l=i+6|0;n=k>>>16&15;do{if((n|0)!=0){if((f&1<<(n^15)|0)==0){break}b[l>>1]=c[a+(n<<2)>>2]&65535}}while(0);n=i+8|0;l=k>>>12&15;do{if((l|0)!=0){if((f&1<<(l^15)|0)==0){break}b[n>>1]=c[a+(l<<2)>>2]&65535}}while(0);l=i+10|0;n=k>>>8&15;do{if((n|0)!=0){if((f&1<<(n^15)|0)==0){break}b[l>>1]=c[a+(n<<2)>>2]&65535}}while(0);n=i+12|0;l=k>>>4&15;do{if((l|0)!=0){if((f&1<<(l^15)|0)==0){break}b[n>>1]=c[a+(l<<2)>>2]&65535}}while(0);l=i+14|0;do{if((m|0)!=0){if((f&1<<(m^15)|0)==0){break}b[l>>1]=c[a+(m<<2)>>2]&65535}}while(0);g=g+1|0;i=i+d|0;j=j+e|0;}while((g|0)<8);c[2112962]=i;c[2112960]=j;return(h|0)==0|0}function agg(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[3541654]|0;d=c[2113300]|0;e=c[2113224]|0;f=c[3541652]|0;g=0;h=0;i=c[2112962]|0;j=c[2112960]|0;do{k=c[j>>2]|0;h=k|h;l=k&15;do{if((l|0)!=0){if((f&1<<(l^15)|0)==0){break}b[i>>1]=c[a+(l<<2)>>2]&65535}}while(0);l=i+2|0;m=k>>>4&15;do{if((m|0)!=0){if((f&1<<(m^15)|0)==0){break}b[l>>1]=c[a+(m<<2)>>2]&65535}}while(0);m=i+4|0;l=k>>>8&15;do{if((l|0)!=0){if((f&1<<(l^15)|0)==0){break}b[m>>1]=c[a+(l<<2)>>2]&65535}}while(0);l=i+6|0;m=k>>>12&15;do{if((m|0)!=0){if((f&1<<(m^15)|0)==0){break}b[l>>1]=c[a+(m<<2)>>2]&65535}}while(0);m=i+8|0;l=k>>>16&15;do{if((l|0)!=0){if((f&1<<(l^15)|0)==0){break}b[m>>1]=c[a+(l<<2)>>2]&65535}}while(0);l=i+10|0;m=k>>>20&15;do{if((m|0)!=0){if((f&1<<(m^15)|0)==0){break}b[l>>1]=c[a+(m<<2)>>2]&65535}}while(0);m=i+12|0;l=k>>>24&15;do{if((l|0)!=0){if((f&1<<(l^15)|0)==0){break}b[m>>1]=c[a+(l<<2)>>2]&65535}}while(0);l=i+14|0;m=k>>>28;do{if((m|0)!=0){if((f&1<<(m^15)|0)==0){break}b[l>>1]=c[a+(m<<2)>>2]&65535}}while(0);g=g+1|0;i=i+d|0;j=j+e|0;}while((g|0)<8);c[2112962]=i;c[2112960]=j;return(h|0)==0|0}function agh(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;a=c[3541654]|0;d=c[2113228]|0;e=(d&536887296|0)==0;f=c[3541652]|0;g=(d+32767&536887296|0)==0;h=(d+65534&536887296|0)==0;i=(d+98301&536887296|0)==0;j=(d+131068&536887296|0)==0;k=(d+163835&536887296|0)==0;l=(d+196602&536887296|0)==0;m=(d+229369&536887296|0)==0;d=c[2113300]|0;n=c[2113224]|0;o=1;p=0;q=c[2113226]|0;r=c[2112962]|0;s=c[2112960]|0;while(1){t=q+32767|0;do{if((q&536887296|0)==0){u=c[s>>2]|0;v=u|p;do{if(e){w=u>>>28;if((w|0)==0){break}if((f&1<<(w^15)|0)==0){break}b[r>>1]=c[a+(w<<2)>>2]&65535}}while(0);w=r+2|0;do{if(g){x=u>>>24&15;if((x|0)==0){break}if((f&1<<(x^15)|0)==0){break}b[w>>1]=c[a+(x<<2)>>2]&65535}}while(0);w=r+4|0;do{if(h){x=u>>>20&15;if((x|0)==0){break}if((f&1<<(x^15)|0)==0){break}b[w>>1]=c[a+(x<<2)>>2]&65535}}while(0);w=r+6|0;do{if(i){x=u>>>16&15;if((x|0)==0){break}if((f&1<<(x^15)|0)==0){break}b[w>>1]=c[a+(x<<2)>>2]&65535}}while(0);w=r+8|0;do{if(j){x=u>>>12&15;if((x|0)==0){break}if((f&1<<(x^15)|0)==0){break}b[w>>1]=c[a+(x<<2)>>2]&65535}}while(0);w=r+10|0;do{if(k){x=u>>>8&15;if((x|0)==0){break}if((f&1<<(x^15)|0)==0){break}b[w>>1]=c[a+(x<<2)>>2]&65535}}while(0);w=r+12|0;do{if(l){x=u>>>4&15;if((x|0)==0){break}if((f&1<<(x^15)|0)==0){break}b[w>>1]=c[a+(x<<2)>>2]&65535}}while(0);if(!m){y=v;break}w=u&15;if((w|0)==0){y=v;break}if((f&1<<(w^15)|0)==0){y=v;break}b[r+14>>1]=c[a+(w<<2)>>2]&65535;y=v}else{y=p}}while(0);z=r+d|0;A=s+n|0;if((o|0)>=8){break}o=o+1|0;p=y;q=t;r=z;s=A}c[2113226]=t;c[2112962]=z;c[2112960]=A;return(y|0)==0|0}function agi(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;a=c[3541654]|0;d=c[2113228]|0;e=(d&536887296|0)==0;f=c[3541652]|0;g=(d+32767&536887296|0)==0;h=(d+65534&536887296|0)==0;i=(d+98301&536887296|0)==0;j=(d+131068&536887296|0)==0;k=(d+163835&536887296|0)==0;l=(d+196602&536887296|0)==0;m=(d+229369&536887296|0)==0;d=c[2113300]|0;n=c[2113224]|0;o=1;p=0;q=c[2113226]|0;r=c[2112962]|0;s=c[2112960]|0;while(1){t=q+32767|0;do{if((q&536887296|0)==0){u=c[s>>2]|0;v=u|p;do{if(e){w=u&15;if((w|0)==0){break}if((f&1<<(w^15)|0)==0){break}b[r>>1]=c[a+(w<<2)>>2]&65535}}while(0);w=r+2|0;do{if(g){x=u>>>4&15;if((x|0)==0){break}if((f&1<<(x^15)|0)==0){break}b[w>>1]=c[a+(x<<2)>>2]&65535}}while(0);w=r+4|0;do{if(h){x=u>>>8&15;if((x|0)==0){break}if((f&1<<(x^15)|0)==0){break}b[w>>1]=c[a+(x<<2)>>2]&65535}}while(0);w=r+6|0;do{if(i){x=u>>>12&15;if((x|0)==0){break}if((f&1<<(x^15)|0)==0){break}b[w>>1]=c[a+(x<<2)>>2]&65535}}while(0);w=r+8|0;do{if(j){x=u>>>16&15;if((x|0)==0){break}if((f&1<<(x^15)|0)==0){break}b[w>>1]=c[a+(x<<2)>>2]&65535}}while(0);w=r+10|0;do{if(k){x=u>>>20&15;if((x|0)==0){break}if((f&1<<(x^15)|0)==0){break}b[w>>1]=c[a+(x<<2)>>2]&65535}}while(0);w=r+12|0;do{if(l){x=u>>>24&15;if((x|0)==0){break}if((f&1<<(x^15)|0)==0){break}b[w>>1]=c[a+(x<<2)>>2]&65535}}while(0);if(!m){y=v;break}w=u>>>28;if((w|0)==0){y=v;break}if((f&1<<(w^15)|0)==0){y=v;break}b[r+14>>1]=c[a+(w<<2)>>2]&65535;y=v}else{y=p}}while(0);z=r+d|0;A=s+n|0;if((o|0)>=8){break}o=o+1|0;p=y;q=t;r=z;s=A}c[2113226]=t;c[2112962]=z;c[2112960]=A;return(y|0)==0|0}function agj(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=c[3541654]|0;d=c[2113300]|0;e=c[2113224]|0;f=c[3541652]|0;g=0;h=0;i=c[2112960]|0;j=c[2112962]|0;do{k=c[i>>2]|0;l=k|h;m=k>>>28;do{if((m|0)!=0){if((f&1<<(m^15)|0)==0){break}b[j>>1]=c[a+(m<<2)>>2]&65535}}while(0);m=j+2|0;n=k&15;o=k>>>24&15;do{if((o|0)!=0){if((f&1<<(o^15)|0)==0){break}b[m>>1]=c[a+(o<<2)>>2]&65535}}while(0);o=j+4|0;m=k>>>20&15;do{if((m|0)!=0){if((f&1<<(m^15)|0)==0){break}b[o>>1]=c[a+(m<<2)>>2]&65535}}while(0);m=j+6|0;o=k>>>16&15;do{if((o|0)!=0){if((f&1<<(o^15)|0)==0){break}b[m>>1]=c[a+(o<<2)>>2]&65535}}while(0);o=j+8|0;m=k>>>12&15;do{if((m|0)!=0){if((f&1<<(m^15)|0)==0){break}b[o>>1]=c[a+(m<<2)>>2]&65535}}while(0);m=j+10|0;o=k>>>8&15;do{if((o|0)!=0){if((f&1<<(o^15)|0)==0){break}b[m>>1]=c[a+(o<<2)>>2]&65535}}while(0);o=j+12|0;m=k>>>4&15;do{if((m|0)!=0){if((f&1<<(m^15)|0)==0){break}b[o>>1]=c[a+(m<<2)>>2]&65535}}while(0);m=j+14|0;do{if((n|0)!=0){if((f&1<<(n^15)|0)==0){break}b[m>>1]=c[a+(n<<2)>>2]&65535}}while(0);n=j+16|0;m=c[i+4>>2]|0;h=l|m;o=m>>>28;do{if((o|0)!=0){if((f&1<<(o^15)|0)==0){break}b[n>>1]=c[a+(o<<2)>>2]&65535}}while(0);o=j+18|0;n=m&15;l=m>>>24&15;do{if((l|0)!=0){if((f&1<<(l^15)|0)==0){break}b[o>>1]=c[a+(l<<2)>>2]&65535}}while(0);l=j+20|0;o=m>>>20&15;do{if((o|0)!=0){if((f&1<<(o^15)|0)==0){break}b[l>>1]=c[a+(o<<2)>>2]&65535}}while(0);o=j+22|0;l=m>>>16&15;do{if((l|0)!=0){if((f&1<<(l^15)|0)==0){break}b[o>>1]=c[a+(l<<2)>>2]&65535}}while(0);l=j+24|0;o=m>>>12&15;do{if((o|0)!=0){if((f&1<<(o^15)|0)==0){break}b[l>>1]=c[a+(o<<2)>>2]&65535}}while(0);o=j+26|0;l=m>>>8&15;do{if((l|0)!=0){if((f&1<<(l^15)|0)==0){break}b[o>>1]=c[a+(l<<2)>>2]&65535}}while(0);l=j+28|0;o=m>>>4&15;do{if((o|0)!=0){if((f&1<<(o^15)|0)==0){break}b[l>>1]=c[a+(o<<2)>>2]&65535}}while(0);o=j+30|0;do{if((n|0)!=0){if((f&1<<(n^15)|0)==0){break}b[o>>1]=c[a+(n<<2)>>2]&65535}}while(0);g=g+1|0;j=j+d|0;i=i+e|0;}while((g|0)<16);c[2112960]=i;c[2112962]=j;return(h|0)==0|0}function agk(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[3541654]|0;d=c[2113300]|0;e=c[2113224]|0;f=c[3541652]|0;g=0;h=0;i=c[2112960]|0;j=c[2112962]|0;do{k=c[i+4>>2]|0;l=k|h;m=k&15;do{if((m|0)!=0){if((f&1<<(m^15)|0)==0){break}b[j>>1]=c[a+(m<<2)>>2]&65535}}while(0);m=j+2|0;n=k>>>4&15;do{if((n|0)!=0){if((f&1<<(n^15)|0)==0){break}b[m>>1]=c[a+(n<<2)>>2]&65535}}while(0);n=j+4|0;m=k>>>8&15;do{if((m|0)!=0){if((f&1<<(m^15)|0)==0){break}b[n>>1]=c[a+(m<<2)>>2]&65535}}while(0);m=j+6|0;n=k>>>12&15;do{if((n|0)!=0){if((f&1<<(n^15)|0)==0){break}b[m>>1]=c[a+(n<<2)>>2]&65535}}while(0);n=j+8|0;m=k>>>16&15;do{if((m|0)!=0){if((f&1<<(m^15)|0)==0){break}b[n>>1]=c[a+(m<<2)>>2]&65535}}while(0);m=j+10|0;n=k>>>20&15;do{if((n|0)!=0){if((f&1<<(n^15)|0)==0){break}b[m>>1]=c[a+(n<<2)>>2]&65535}}while(0);n=j+12|0;m=k>>>24&15;do{if((m|0)!=0){if((f&1<<(m^15)|0)==0){break}b[n>>1]=c[a+(m<<2)>>2]&65535}}while(0);m=j+14|0;n=k>>>28;do{if((n|0)!=0){if((f&1<<(n^15)|0)==0){break}b[m>>1]=c[a+(n<<2)>>2]&65535}}while(0);n=j+16|0;m=c[i>>2]|0;h=l|m;k=m&15;do{if((k|0)!=0){if((f&1<<(k^15)|0)==0){break}b[n>>1]=c[a+(k<<2)>>2]&65535}}while(0);k=j+18|0;n=m>>>4&15;do{if((n|0)!=0){if((f&1<<(n^15)|0)==0){break}b[k>>1]=c[a+(n<<2)>>2]&65535}}while(0);n=j+20|0;k=m>>>8&15;do{if((k|0)!=0){if((f&1<<(k^15)|0)==0){break}b[n>>1]=c[a+(k<<2)>>2]&65535}}while(0);k=j+22|0;n=m>>>12&15;do{if((n|0)!=0){if((f&1<<(n^15)|0)==0){break}b[k>>1]=c[a+(n<<2)>>2]&65535}}while(0);n=j+24|0;k=m>>>16&15;do{if((k|0)!=0){if((f&1<<(k^15)|0)==0){break}b[n>>1]=c[a+(k<<2)>>2]&65535}}while(0);k=j+26|0;n=m>>>20&15;do{if((n|0)!=0){if((f&1<<(n^15)|0)==0){break}b[k>>1]=c[a+(n<<2)>>2]&65535}}while(0);n=j+28|0;k=m>>>24&15;do{if((k|0)!=0){if((f&1<<(k^15)|0)==0){break}b[n>>1]=c[a+(k<<2)>>2]&65535}}while(0);k=j+30|0;n=m>>>28;do{if((n|0)!=0){if((f&1<<(n^15)|0)==0){break}b[k>>1]=c[a+(n<<2)>>2]&65535}}while(0);g=g+1|0;j=j+d|0;i=i+e|0;}while((g|0)<16);c[2112960]=i;c[2112962]=j;return(h|0)==0|0}function agl(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;a=c[3541654]|0;d=c[2113228]|0;e=(d&536887296|0)==0;f=c[3541652]|0;g=(d+32767&536887296|0)==0;h=(d+65534&536887296|0)==0;i=(d+98301&536887296|0)==0;j=(d+131068&536887296|0)==0;k=(d+163835&536887296|0)==0;l=(d+196602&536887296|0)==0;m=(d+229369&536887296|0)==0;n=(d+262136&536887296|0)==0;o=(d+294903&536887296|0)==0;p=(d+327670&536887296|0)==0;q=(d+360437&536887296|0)==0;r=(d+393204&536887296|0)==0;s=(d+425971&536887296|0)==0;t=(d+458738&536887296|0)==0;u=(d+491505&536887296|0)==0;d=c[2113300]|0;v=c[2113224]|0;w=1;x=0;y=c[2113226]|0;z=c[2112962]|0;A=c[2112960]|0;while(1){B=y+32767|0;do{if((y&536887296|0)==0){C=c[A>>2]|0;D=C|x;do{if(e){E=C>>>28;if((E|0)==0){break}if((f&1<<(E^15)|0)==0){break}b[z>>1]=c[a+(E<<2)>>2]&65535}}while(0);E=z+2|0;do{if(g){F=C>>>24&15;if((F|0)==0){break}if((f&1<<(F^15)|0)==0){break}b[E>>1]=c[a+(F<<2)>>2]&65535}}while(0);E=z+4|0;do{if(h){F=C>>>20&15;if((F|0)==0){break}if((f&1<<(F^15)|0)==0){break}b[E>>1]=c[a+(F<<2)>>2]&65535}}while(0);E=z+6|0;do{if(i){F=C>>>16&15;if((F|0)==0){break}if((f&1<<(F^15)|0)==0){break}b[E>>1]=c[a+(F<<2)>>2]&65535}}while(0);E=z+8|0;do{if(j){F=C>>>12&15;if((F|0)==0){break}if((f&1<<(F^15)|0)==0){break}b[E>>1]=c[a+(F<<2)>>2]&65535}}while(0);E=z+10|0;do{if(k){F=C>>>8&15;if((F|0)==0){break}if((f&1<<(F^15)|0)==0){break}b[E>>1]=c[a+(F<<2)>>2]&65535}}while(0);E=z+12|0;do{if(l){F=C>>>4&15;if((F|0)==0){break}if((f&1<<(F^15)|0)==0){break}b[E>>1]=c[a+(F<<2)>>2]&65535}}while(0);E=z+14|0;do{if(m){F=C&15;if((F|0)==0){break}if((f&1<<(F^15)|0)==0){break}b[E>>1]=c[a+(F<<2)>>2]&65535}}while(0);E=z+16|0;C=c[A+4>>2]|0;F=D|C;do{if(n){G=C>>>28;if((G|0)==0){break}if((f&1<<(G^15)|0)==0){break}b[E>>1]=c[a+(G<<2)>>2]&65535}}while(0);E=z+18|0;do{if(o){D=C>>>24&15;if((D|0)==0){break}if((f&1<<(D^15)|0)==0){break}b[E>>1]=c[a+(D<<2)>>2]&65535}}while(0);E=z+20|0;do{if(p){D=C>>>20&15;if((D|0)==0){break}if((f&1<<(D^15)|0)==0){break}b[E>>1]=c[a+(D<<2)>>2]&65535}}while(0);E=z+22|0;do{if(q){D=C>>>16&15;if((D|0)==0){break}if((f&1<<(D^15)|0)==0){break}b[E>>1]=c[a+(D<<2)>>2]&65535}}while(0);E=z+24|0;do{if(r){D=C>>>12&15;if((D|0)==0){break}if((f&1<<(D^15)|0)==0){break}b[E>>1]=c[a+(D<<2)>>2]&65535}}while(0);E=z+26|0;do{if(s){D=C>>>8&15;if((D|0)==0){break}if((f&1<<(D^15)|0)==0){break}b[E>>1]=c[a+(D<<2)>>2]&65535}}while(0);E=z+28|0;do{if(t){D=C>>>4&15;if((D|0)==0){break}if((f&1<<(D^15)|0)==0){break}b[E>>1]=c[a+(D<<2)>>2]&65535}}while(0);if(!u){H=F;break}E=C&15;if((E|0)==0){H=F;break}if((f&1<<(E^15)|0)==0){H=F;break}b[z+30>>1]=c[a+(E<<2)>>2]&65535;H=F}else{H=x}}while(0);I=z+d|0;J=A+v|0;if((w|0)>=16){break}w=w+1|0;x=H;y=B;z=I;A=J}c[2113226]=B;c[2112962]=I;c[2112960]=J;return(H|0)==0|0}function agm(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;a=c[3541654]|0;d=c[2113228]|0;e=(d&536887296|0)==0;f=c[3541652]|0;g=(d+32767&536887296|0)==0;h=(d+65534&536887296|0)==0;i=(d+98301&536887296|0)==0;j=(d+131068&536887296|0)==0;k=(d+163835&536887296|0)==0;l=(d+196602&536887296|0)==0;m=(d+229369&536887296|0)==0;n=(d+262136&536887296|0)==0;o=(d+294903&536887296|0)==0;p=(d+327670&536887296|0)==0;q=(d+360437&536887296|0)==0;r=(d+393204&536887296|0)==0;s=(d+425971&536887296|0)==0;t=(d+458738&536887296|0)==0;u=(d+491505&536887296|0)==0;d=c[2113300]|0;v=c[2113224]|0;w=1;x=0;y=c[2113226]|0;z=c[2112962]|0;A=c[2112960]|0;while(1){B=y+32767|0;do{if((y&536887296|0)==0){C=c[A+4>>2]|0;D=C|x;do{if(e){E=C&15;if((E|0)==0){break}if((f&1<<(E^15)|0)==0){break}b[z>>1]=c[a+(E<<2)>>2]&65535}}while(0);E=z+2|0;do{if(g){F=C>>>4&15;if((F|0)==0){break}if((f&1<<(F^15)|0)==0){break}b[E>>1]=c[a+(F<<2)>>2]&65535}}while(0);E=z+4|0;do{if(h){F=C>>>8&15;if((F|0)==0){break}if((f&1<<(F^15)|0)==0){break}b[E>>1]=c[a+(F<<2)>>2]&65535}}while(0);E=z+6|0;do{if(i){F=C>>>12&15;if((F|0)==0){break}if((f&1<<(F^15)|0)==0){break}b[E>>1]=c[a+(F<<2)>>2]&65535}}while(0);E=z+8|0;do{if(j){F=C>>>16&15;if((F|0)==0){break}if((f&1<<(F^15)|0)==0){break}b[E>>1]=c[a+(F<<2)>>2]&65535}}while(0);E=z+10|0;do{if(k){F=C>>>20&15;if((F|0)==0){break}if((f&1<<(F^15)|0)==0){break}b[E>>1]=c[a+(F<<2)>>2]&65535}}while(0);E=z+12|0;do{if(l){F=C>>>24&15;if((F|0)==0){break}if((f&1<<(F^15)|0)==0){break}b[E>>1]=c[a+(F<<2)>>2]&65535}}while(0);E=z+14|0;do{if(m){F=C>>>28;if((F|0)==0){break}if((f&1<<(F^15)|0)==0){break}b[E>>1]=c[a+(F<<2)>>2]&65535}}while(0);E=z+16|0;C=c[A>>2]|0;F=D|C;do{if(n){G=C&15;if((G|0)==0){break}if((f&1<<(G^15)|0)==0){break}b[E>>1]=c[a+(G<<2)>>2]&65535}}while(0);E=z+18|0;do{if(o){D=C>>>4&15;if((D|0)==0){break}if((f&1<<(D^15)|0)==0){break}b[E>>1]=c[a+(D<<2)>>2]&65535}}while(0);E=z+20|0;do{if(p){D=C>>>8&15;if((D|0)==0){break}if((f&1<<(D^15)|0)==0){break}b[E>>1]=c[a+(D<<2)>>2]&65535}}while(0);E=z+22|0;do{if(q){D=C>>>12&15;if((D|0)==0){break}if((f&1<<(D^15)|0)==0){break}b[E>>1]=c[a+(D<<2)>>2]&65535}}while(0);E=z+24|0;do{if(r){D=C>>>16&15;if((D|0)==0){break}if((f&1<<(D^15)|0)==0){break}b[E>>1]=c[a+(D<<2)>>2]&65535}}while(0);E=z+26|0;do{if(s){D=C>>>20&15;if((D|0)==0){break}if((f&1<<(D^15)|0)==0){break}b[E>>1]=c[a+(D<<2)>>2]&65535}}while(0);E=z+28|0;do{if(t){D=C>>>24&15;if((D|0)==0){break}if((f&1<<(D^15)|0)==0){break}b[E>>1]=c[a+(D<<2)>>2]&65535}}while(0);if(!u){H=F;break}E=C>>>28;if((E|0)==0){H=F;break}if((f&1<<(E^15)|0)==0){H=F;break}b[z+30>>1]=c[a+(E<<2)>>2]&65535;H=F}else{H=x}}while(0);I=z+d|0;J=A+v|0;if((w|0)>=16){break}w=w+1|0;x=H;y=B;z=I;A=J}c[2113226]=B;c[2112962]=I;c[2112960]=J;return(H|0)==0|0}function agn(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=c[3541654]|0;d=c[2113300]|0;e=c[2113224]|0;f=c[3541652]|0;g=0;h=0;i=c[2112960]|0;j=c[2112962]|0;do{k=c[i>>2]|0;l=k|h;m=k>>>28;do{if((m|0)!=0){if((f&1<<(m^15)|0)==0){break}b[j>>1]=c[a+(m<<2)>>2]&65535}}while(0);m=j+2|0;n=k&15;o=k>>>24&15;do{if((o|0)!=0){if((f&1<<(o^15)|0)==0){break}b[m>>1]=c[a+(o<<2)>>2]&65535}}while(0);o=j+4|0;m=k>>>20&15;do{if((m|0)!=0){if((f&1<<(m^15)|0)==0){break}b[o>>1]=c[a+(m<<2)>>2]&65535}}while(0);m=j+6|0;o=k>>>16&15;do{if((o|0)!=0){if((f&1<<(o^15)|0)==0){break}b[m>>1]=c[a+(o<<2)>>2]&65535}}while(0);o=j+8|0;m=k>>>12&15;do{if((m|0)!=0){if((f&1<<(m^15)|0)==0){break}b[o>>1]=c[a+(m<<2)>>2]&65535}}while(0);m=j+10|0;o=k>>>8&15;do{if((o|0)!=0){if((f&1<<(o^15)|0)==0){break}b[m>>1]=c[a+(o<<2)>>2]&65535}}while(0);o=j+12|0;m=k>>>4&15;do{if((m|0)!=0){if((f&1<<(m^15)|0)==0){break}b[o>>1]=c[a+(m<<2)>>2]&65535}}while(0);m=j+14|0;do{if((n|0)!=0){if((f&1<<(n^15)|0)==0){break}b[m>>1]=c[a+(n<<2)>>2]&65535}}while(0);n=j+16|0;m=c[i+4>>2]|0;o=l|m;k=m>>>28;do{if((k|0)!=0){if((f&1<<(k^15)|0)==0){break}b[n>>1]=c[a+(k<<2)>>2]&65535}}while(0);k=j+18|0;n=m&15;l=m>>>24&15;do{if((l|0)!=0){if((f&1<<(l^15)|0)==0){break}b[k>>1]=c[a+(l<<2)>>2]&65535}}while(0);l=j+20|0;k=m>>>20&15;do{if((k|0)!=0){if((f&1<<(k^15)|0)==0){break}b[l>>1]=c[a+(k<<2)>>2]&65535}}while(0);k=j+22|0;l=m>>>16&15;do{if((l|0)!=0){if((f&1<<(l^15)|0)==0){break}b[k>>1]=c[a+(l<<2)>>2]&65535}}while(0);l=j+24|0;k=m>>>12&15;do{if((k|0)!=0){if((f&1<<(k^15)|0)==0){break}b[l>>1]=c[a+(k<<2)>>2]&65535}}while(0);k=j+26|0;l=m>>>8&15;do{if((l|0)!=0){if((f&1<<(l^15)|0)==0){break}b[k>>1]=c[a+(l<<2)>>2]&65535}}while(0);l=j+28|0;k=m>>>4&15;do{if((k|0)!=0){if((f&1<<(k^15)|0)==0){break}b[l>>1]=c[a+(k<<2)>>2]&65535}}while(0);k=j+30|0;do{if((n|0)!=0){if((f&1<<(n^15)|0)==0){break}b[k>>1]=c[a+(n<<2)>>2]&65535}}while(0);n=j+32|0;k=c[i+8>>2]|0;l=o|k;m=k>>>28;do{if((m|0)!=0){if((f&1<<(m^15)|0)==0){break}b[n>>1]=c[a+(m<<2)>>2]&65535}}while(0);m=j+34|0;n=k&15;o=k>>>24&15;do{if((o|0)!=0){if((f&1<<(o^15)|0)==0){break}b[m>>1]=c[a+(o<<2)>>2]&65535}}while(0);o=j+36|0;m=k>>>20&15;do{if((m|0)!=0){if((f&1<<(m^15)|0)==0){break}b[o>>1]=c[a+(m<<2)>>2]&65535}}while(0);m=j+38|0;o=k>>>16&15;do{if((o|0)!=0){if((f&1<<(o^15)|0)==0){break}b[m>>1]=c[a+(o<<2)>>2]&65535}}while(0);o=j+40|0;m=k>>>12&15;do{if((m|0)!=0){if((f&1<<(m^15)|0)==0){break}b[o>>1]=c[a+(m<<2)>>2]&65535}}while(0);m=j+42|0;o=k>>>8&15;do{if((o|0)!=0){if((f&1<<(o^15)|0)==0){break}b[m>>1]=c[a+(o<<2)>>2]&65535}}while(0);o=j+44|0;m=k>>>4&15;do{if((m|0)!=0){if((f&1<<(m^15)|0)==0){break}b[o>>1]=c[a+(m<<2)>>2]&65535}}while(0);m=j+46|0;do{if((n|0)!=0){if((f&1<<(n^15)|0)==0){break}b[m>>1]=c[a+(n<<2)>>2]&65535}}while(0);n=j+48|0;m=c[i+12>>2]|0;h=l|m;o=m>>>28;do{if((o|0)!=0){if((f&1<<(o^15)|0)==0){break}b[n>>1]=c[a+(o<<2)>>2]&65535}}while(0);o=j+50|0;n=m&15;l=m>>>24&15;do{if((l|0)!=0){if((f&1<<(l^15)|0)==0){break}b[o>>1]=c[a+(l<<2)>>2]&65535}}while(0);l=j+52|0;o=m>>>20&15;do{if((o|0)!=0){if((f&1<<(o^15)|0)==0){break}b[l>>1]=c[a+(o<<2)>>2]&65535}}while(0);o=j+54|0;l=m>>>16&15;do{if((l|0)!=0){if((f&1<<(l^15)|0)==0){break}b[o>>1]=c[a+(l<<2)>>2]&65535}}while(0);l=j+56|0;o=m>>>12&15;do{if((o|0)!=0){if((f&1<<(o^15)|0)==0){break}b[l>>1]=c[a+(o<<2)>>2]&65535}}while(0);o=j+58|0;l=m>>>8&15;do{if((l|0)!=0){if((f&1<<(l^15)|0)==0){break}b[o>>1]=c[a+(l<<2)>>2]&65535}}while(0);l=j+60|0;o=m>>>4&15;do{if((o|0)!=0){if((f&1<<(o^15)|0)==0){break}b[l>>1]=c[a+(o<<2)>>2]&65535}}while(0);o=j+62|0;do{if((n|0)!=0){if((f&1<<(n^15)|0)==0){break}b[o>>1]=c[a+(n<<2)>>2]&65535}}while(0);g=g+1|0;j=j+d|0;i=i+e|0;}while((g|0)<32);c[2112960]=i;c[2112962]=j;return(h|0)==0|0}function ago(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=c[3541654]|0;d=c[2113300]|0;e=c[2113224]|0;f=c[3541652]|0;g=0;h=0;i=c[2112960]|0;j=c[2112962]|0;do{k=c[i+12>>2]|0;l=k|h;m=k&15;do{if((m|0)!=0){if((f&1<<(m^15)|0)==0){break}b[j>>1]=c[a+(m<<2)>>2]&65535}}while(0);m=j+2|0;n=k>>>4&15;do{if((n|0)!=0){if((f&1<<(n^15)|0)==0){break}b[m>>1]=c[a+(n<<2)>>2]&65535}}while(0);n=j+4|0;m=k>>>8&15;do{if((m|0)!=0){if((f&1<<(m^15)|0)==0){break}b[n>>1]=c[a+(m<<2)>>2]&65535}}while(0);m=j+6|0;n=k>>>12&15;do{if((n|0)!=0){if((f&1<<(n^15)|0)==0){break}b[m>>1]=c[a+(n<<2)>>2]&65535}}while(0);n=j+8|0;m=k>>>16&15;do{if((m|0)!=0){if((f&1<<(m^15)|0)==0){break}b[n>>1]=c[a+(m<<2)>>2]&65535}}while(0);m=j+10|0;n=k>>>20&15;do{if((n|0)!=0){if((f&1<<(n^15)|0)==0){break}b[m>>1]=c[a+(n<<2)>>2]&65535}}while(0);n=j+12|0;m=k>>>24&15;do{if((m|0)!=0){if((f&1<<(m^15)|0)==0){break}b[n>>1]=c[a+(m<<2)>>2]&65535}}while(0);m=j+14|0;n=k>>>28;do{if((n|0)!=0){if((f&1<<(n^15)|0)==0){break}b[m>>1]=c[a+(n<<2)>>2]&65535}}while(0);n=j+16|0;m=c[i+8>>2]|0;k=l|m;o=m&15;do{if((o|0)!=0){if((f&1<<(o^15)|0)==0){break}b[n>>1]=c[a+(o<<2)>>2]&65535}}while(0);o=j+18|0;n=m>>>4&15;do{if((n|0)!=0){if((f&1<<(n^15)|0)==0){break}b[o>>1]=c[a+(n<<2)>>2]&65535}}while(0);n=j+20|0;o=m>>>8&15;do{if((o|0)!=0){if((f&1<<(o^15)|0)==0){break}b[n>>1]=c[a+(o<<2)>>2]&65535}}while(0);o=j+22|0;n=m>>>12&15;do{if((n|0)!=0){if((f&1<<(n^15)|0)==0){break}b[o>>1]=c[a+(n<<2)>>2]&65535}}while(0);n=j+24|0;o=m>>>16&15;do{if((o|0)!=0){if((f&1<<(o^15)|0)==0){break}b[n>>1]=c[a+(o<<2)>>2]&65535}}while(0);o=j+26|0;n=m>>>20&15;do{if((n|0)!=0){if((f&1<<(n^15)|0)==0){break}b[o>>1]=c[a+(n<<2)>>2]&65535}}while(0);n=j+28|0;o=m>>>24&15;do{if((o|0)!=0){if((f&1<<(o^15)|0)==0){break}b[n>>1]=c[a+(o<<2)>>2]&65535}}while(0);o=j+30|0;n=m>>>28;do{if((n|0)!=0){if((f&1<<(n^15)|0)==0){break}b[o>>1]=c[a+(n<<2)>>2]&65535}}while(0);n=j+32|0;o=c[i+4>>2]|0;m=k|o;l=o&15;do{if((l|0)!=0){if((f&1<<(l^15)|0)==0){break}b[n>>1]=c[a+(l<<2)>>2]&65535}}while(0);l=j+34|0;n=o>>>4&15;do{if((n|0)!=0){if((f&1<<(n^15)|0)==0){break}b[l>>1]=c[a+(n<<2)>>2]&65535}}while(0);n=j+36|0;l=o>>>8&15;do{if((l|0)!=0){if((f&1<<(l^15)|0)==0){break}b[n>>1]=c[a+(l<<2)>>2]&65535}}while(0);l=j+38|0;n=o>>>12&15;do{if((n|0)!=0){if((f&1<<(n^15)|0)==0){break}b[l>>1]=c[a+(n<<2)>>2]&65535}}while(0);n=j+40|0;l=o>>>16&15;do{if((l|0)!=0){if((f&1<<(l^15)|0)==0){break}b[n>>1]=c[a+(l<<2)>>2]&65535}}while(0);l=j+42|0;n=o>>>20&15;do{if((n|0)!=0){if((f&1<<(n^15)|0)==0){break}b[l>>1]=c[a+(n<<2)>>2]&65535}}while(0);n=j+44|0;l=o>>>24&15;do{if((l|0)!=0){if((f&1<<(l^15)|0)==0){break}b[n>>1]=c[a+(l<<2)>>2]&65535}}while(0);l=j+46|0;n=o>>>28;do{if((n|0)!=0){if((f&1<<(n^15)|0)==0){break}b[l>>1]=c[a+(n<<2)>>2]&65535}}while(0);n=j+48|0;l=c[i>>2]|0;h=m|l;o=l&15;do{if((o|0)!=0){if((f&1<<(o^15)|0)==0){break}b[n>>1]=c[a+(o<<2)>>2]&65535}}while(0);o=j+50|0;n=l>>>4&15;do{if((n|0)!=0){if((f&1<<(n^15)|0)==0){break}b[o>>1]=c[a+(n<<2)>>2]&65535}}while(0);n=j+52|0;o=l>>>8&15;do{if((o|0)!=0){if((f&1<<(o^15)|0)==0){break}b[n>>1]=c[a+(o<<2)>>2]&65535}}while(0);o=j+54|0;n=l>>>12&15;do{if((n|0)!=0){if((f&1<<(n^15)|0)==0){break}b[o>>1]=c[a+(n<<2)>>2]&65535}}while(0);n=j+56|0;o=l>>>16&15;do{if((o|0)!=0){if((f&1<<(o^15)|0)==0){break}b[n>>1]=c[a+(o<<2)>>2]&65535}}while(0);o=j+58|0;n=l>>>20&15;do{if((n|0)!=0){if((f&1<<(n^15)|0)==0){break}b[o>>1]=c[a+(n<<2)>>2]&65535}}while(0);n=j+60|0;o=l>>>24&15;do{if((o|0)!=0){if((f&1<<(o^15)|0)==0){break}b[n>>1]=c[a+(o<<2)>>2]&65535}}while(0);o=j+62|0;n=l>>>28;do{if((n|0)!=0){if((f&1<<(n^15)|0)==0){break}b[o>>1]=c[a+(n<<2)>>2]&65535}}while(0);g=g+1|0;j=j+d|0;i=i+e|0;}while((g|0)<32);c[2112960]=i;c[2112962]=j;return(h|0)==0|0}function agp(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;a=c[3541654]|0;d=c[2113228]|0;e=(d&536887296|0)==0;f=c[3541652]|0;g=(d+32767&536887296|0)==0;h=(d+65534&536887296|0)==0;i=(d+98301&536887296|0)==0;j=(d+131068&536887296|0)==0;k=(d+163835&536887296|0)==0;l=(d+196602&536887296|0)==0;m=(d+229369&536887296|0)==0;n=(d+262136&536887296|0)==0;o=(d+294903&536887296|0)==0;p=(d+327670&536887296|0)==0;q=(d+360437&536887296|0)==0;r=(d+393204&536887296|0)==0;s=(d+425971&536887296|0)==0;t=(d+458738&536887296|0)==0;u=(d+491505&536887296|0)==0;v=(d+524272&536887296|0)==0;w=(d+557039&536887296|0)==0;x=(d+589806&536887296|0)==0;y=(d+622573&536887296|0)==0;z=(d+655340&536887296|0)==0;A=(d+688107&536887296|0)==0;B=(d+720874&536887296|0)==0;C=(d+753641&536887296|0)==0;D=(d+786408&536887296|0)==0;E=(d+819175&536887296|0)==0;F=(d+851942&536887296|0)==0;G=(d+884709&536887296|0)==0;H=(d+917476&536887296|0)==0;I=(d+950243&536887296|0)==0;J=(d+983010&536887296|0)==0;K=(d+1015777&536887296|0)==0;d=c[2113300]|0;L=c[2113224]|0;M=1;N=0;O=c[2113226]|0;P=c[2112962]|0;Q=c[2112960]|0;while(1){R=O+32767|0;do{if((O&536887296|0)==0){S=c[Q>>2]|0;T=S|N;do{if(e){U=S>>>28;if((U|0)==0){break}if((f&1<<(U^15)|0)==0){break}b[P>>1]=c[a+(U<<2)>>2]&65535}}while(0);U=P+2|0;do{if(g){V=S>>>24&15;if((V|0)==0){break}if((f&1<<(V^15)|0)==0){break}b[U>>1]=c[a+(V<<2)>>2]&65535}}while(0);U=P+4|0;do{if(h){V=S>>>20&15;if((V|0)==0){break}if((f&1<<(V^15)|0)==0){break}b[U>>1]=c[a+(V<<2)>>2]&65535}}while(0);U=P+6|0;do{if(i){V=S>>>16&15;if((V|0)==0){break}if((f&1<<(V^15)|0)==0){break}b[U>>1]=c[a+(V<<2)>>2]&65535}}while(0);U=P+8|0;do{if(j){V=S>>>12&15;if((V|0)==0){break}if((f&1<<(V^15)|0)==0){break}b[U>>1]=c[a+(V<<2)>>2]&65535}}while(0);U=P+10|0;do{if(k){V=S>>>8&15;if((V|0)==0){break}if((f&1<<(V^15)|0)==0){break}b[U>>1]=c[a+(V<<2)>>2]&65535}}while(0);U=P+12|0;do{if(l){V=S>>>4&15;if((V|0)==0){break}if((f&1<<(V^15)|0)==0){break}b[U>>1]=c[a+(V<<2)>>2]&65535}}while(0);U=P+14|0;do{if(m){V=S&15;if((V|0)==0){break}if((f&1<<(V^15)|0)==0){break}b[U>>1]=c[a+(V<<2)>>2]&65535}}while(0);U=P+16|0;S=c[Q+4>>2]|0;V=T|S;do{if(n){W=S>>>28;if((W|0)==0){break}if((f&1<<(W^15)|0)==0){break}b[U>>1]=c[a+(W<<2)>>2]&65535}}while(0);U=P+18|0;do{if(o){T=S>>>24&15;if((T|0)==0){break}if((f&1<<(T^15)|0)==0){break}b[U>>1]=c[a+(T<<2)>>2]&65535}}while(0);U=P+20|0;do{if(p){T=S>>>20&15;if((T|0)==0){break}if((f&1<<(T^15)|0)==0){break}b[U>>1]=c[a+(T<<2)>>2]&65535}}while(0);U=P+22|0;do{if(q){T=S>>>16&15;if((T|0)==0){break}if((f&1<<(T^15)|0)==0){break}b[U>>1]=c[a+(T<<2)>>2]&65535}}while(0);U=P+24|0;do{if(r){T=S>>>12&15;if((T|0)==0){break}if((f&1<<(T^15)|0)==0){break}b[U>>1]=c[a+(T<<2)>>2]&65535}}while(0);U=P+26|0;do{if(s){T=S>>>8&15;if((T|0)==0){break}if((f&1<<(T^15)|0)==0){break}b[U>>1]=c[a+(T<<2)>>2]&65535}}while(0);U=P+28|0;do{if(t){T=S>>>4&15;if((T|0)==0){break}if((f&1<<(T^15)|0)==0){break}b[U>>1]=c[a+(T<<2)>>2]&65535}}while(0);U=P+30|0;do{if(u){T=S&15;if((T|0)==0){break}if((f&1<<(T^15)|0)==0){break}b[U>>1]=c[a+(T<<2)>>2]&65535}}while(0);U=P+32|0;S=c[Q+8>>2]|0;T=V|S;do{if(v){W=S>>>28;if((W|0)==0){break}if((f&1<<(W^15)|0)==0){break}b[U>>1]=c[a+(W<<2)>>2]&65535}}while(0);U=P+34|0;do{if(w){V=S>>>24&15;if((V|0)==0){break}if((f&1<<(V^15)|0)==0){break}b[U>>1]=c[a+(V<<2)>>2]&65535}}while(0);U=P+36|0;do{if(x){V=S>>>20&15;if((V|0)==0){break}if((f&1<<(V^15)|0)==0){break}b[U>>1]=c[a+(V<<2)>>2]&65535}}while(0);U=P+38|0;do{if(y){V=S>>>16&15;if((V|0)==0){break}if((f&1<<(V^15)|0)==0){break}b[U>>1]=c[a+(V<<2)>>2]&65535}}while(0);U=P+40|0;do{if(z){V=S>>>12&15;if((V|0)==0){break}if((f&1<<(V^15)|0)==0){break}b[U>>1]=c[a+(V<<2)>>2]&65535}}while(0);U=P+42|0;do{if(A){V=S>>>8&15;if((V|0)==0){break}if((f&1<<(V^15)|0)==0){break}b[U>>1]=c[a+(V<<2)>>2]&65535}}while(0);U=P+44|0;do{if(B){V=S>>>4&15;if((V|0)==0){break}if((f&1<<(V^15)|0)==0){break}b[U>>1]=c[a+(V<<2)>>2]&65535}}while(0);U=P+46|0;do{if(C){V=S&15;if((V|0)==0){break}if((f&1<<(V^15)|0)==0){break}b[U>>1]=c[a+(V<<2)>>2]&65535}}while(0);U=P+48|0;S=c[Q+12>>2]|0;V=T|S;do{if(D){W=S>>>28;if((W|0)==0){break}if((f&1<<(W^15)|0)==0){break}b[U>>1]=c[a+(W<<2)>>2]&65535}}while(0);U=P+50|0;do{if(E){T=S>>>24&15;if((T|0)==0){break}if((f&1<<(T^15)|0)==0){break}b[U>>1]=c[a+(T<<2)>>2]&65535}}while(0);U=P+52|0;do{if(F){T=S>>>20&15;if((T|0)==0){break}if((f&1<<(T^15)|0)==0){break}b[U>>1]=c[a+(T<<2)>>2]&65535}}while(0);U=P+54|0;do{if(G){T=S>>>16&15;if((T|0)==0){break}if((f&1<<(T^15)|0)==0){break}b[U>>1]=c[a+(T<<2)>>2]&65535}}while(0);U=P+56|0;do{if(H){T=S>>>12&15;if((T|0)==0){break}if((f&1<<(T^15)|0)==0){break}b[U>>1]=c[a+(T<<2)>>2]&65535}}while(0);U=P+58|0;do{if(I){T=S>>>8&15;if((T|0)==0){break}if((f&1<<(T^15)|0)==0){break}b[U>>1]=c[a+(T<<2)>>2]&65535}}while(0);U=P+60|0;do{if(J){T=S>>>4&15;if((T|0)==0){break}if((f&1<<(T^15)|0)==0){break}b[U>>1]=c[a+(T<<2)>>2]&65535}}while(0);if(!K){X=V;break}U=S&15;if((U|0)==0){X=V;break}if((f&1<<(U^15)|0)==0){X=V;break}b[P+62>>1]=c[a+(U<<2)>>2]&65535;X=V}else{X=N}}while(0);Y=P+d|0;Z=Q+L|0;if((M|0)>=32){break}M=M+1|0;N=X;O=R;P=Y;Q=Z}c[2113226]=R;c[2112962]=Y;c[2112960]=Z;return(X|0)==0|0}function agq(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;a=c[3541654]|0;d=c[2113228]|0;e=(d&536887296|0)==0;f=c[3541652]|0;g=(d+32767&536887296|0)==0;h=(d+65534&536887296|0)==0;i=(d+98301&536887296|0)==0;j=(d+131068&536887296|0)==0;k=(d+163835&536887296|0)==0;l=(d+196602&536887296|0)==0;m=(d+229369&536887296|0)==0;n=(d+262136&536887296|0)==0;o=(d+294903&536887296|0)==0;p=(d+327670&536887296|0)==0;q=(d+360437&536887296|0)==0;r=(d+393204&536887296|0)==0;s=(d+425971&536887296|0)==0;t=(d+458738&536887296|0)==0;u=(d+491505&536887296|0)==0;v=(d+524272&536887296|0)==0;w=(d+557039&536887296|0)==0;x=(d+589806&536887296|0)==0;y=(d+622573&536887296|0)==0;z=(d+655340&536887296|0)==0;A=(d+688107&536887296|0)==0;B=(d+720874&536887296|0)==0;C=(d+753641&536887296|0)==0;D=(d+786408&536887296|0)==0;E=(d+819175&536887296|0)==0;F=(d+851942&536887296|0)==0;G=(d+884709&536887296|0)==0;H=(d+917476&536887296|0)==0;I=(d+950243&536887296|0)==0;J=(d+983010&536887296|0)==0;K=(d+1015777&536887296|0)==0;d=c[2113300]|0;L=c[2113224]|0;M=1;N=0;O=c[2113226]|0;P=c[2112962]|0;Q=c[2112960]|0;while(1){R=O+32767|0;do{if((O&536887296|0)==0){S=c[Q+12>>2]|0;T=S|N;do{if(e){U=S&15;if((U|0)==0){break}if((f&1<<(U^15)|0)==0){break}b[P>>1]=c[a+(U<<2)>>2]&65535}}while(0);U=P+2|0;do{if(g){V=S>>>4&15;if((V|0)==0){break}if((f&1<<(V^15)|0)==0){break}b[U>>1]=c[a+(V<<2)>>2]&65535}}while(0);U=P+4|0;do{if(h){V=S>>>8&15;if((V|0)==0){break}if((f&1<<(V^15)|0)==0){break}b[U>>1]=c[a+(V<<2)>>2]&65535}}while(0);U=P+6|0;do{if(i){V=S>>>12&15;if((V|0)==0){break}if((f&1<<(V^15)|0)==0){break}b[U>>1]=c[a+(V<<2)>>2]&65535}}while(0);U=P+8|0;do{if(j){V=S>>>16&15;if((V|0)==0){break}if((f&1<<(V^15)|0)==0){break}b[U>>1]=c[a+(V<<2)>>2]&65535}}while(0);U=P+10|0;do{if(k){V=S>>>20&15;if((V|0)==0){break}if((f&1<<(V^15)|0)==0){break}b[U>>1]=c[a+(V<<2)>>2]&65535}}while(0);U=P+12|0;do{if(l){V=S>>>24&15;if((V|0)==0){break}if((f&1<<(V^15)|0)==0){break}b[U>>1]=c[a+(V<<2)>>2]&65535}}while(0);U=P+14|0;do{if(m){V=S>>>28;if((V|0)==0){break}if((f&1<<(V^15)|0)==0){break}b[U>>1]=c[a+(V<<2)>>2]&65535}}while(0);U=P+16|0;S=c[Q+8>>2]|0;V=T|S;do{if(n){W=S&15;if((W|0)==0){break}if((f&1<<(W^15)|0)==0){break}b[U>>1]=c[a+(W<<2)>>2]&65535}}while(0);U=P+18|0;do{if(o){T=S>>>4&15;if((T|0)==0){break}if((f&1<<(T^15)|0)==0){break}b[U>>1]=c[a+(T<<2)>>2]&65535}}while(0);U=P+20|0;do{if(p){T=S>>>8&15;if((T|0)==0){break}if((f&1<<(T^15)|0)==0){break}b[U>>1]=c[a+(T<<2)>>2]&65535}}while(0);U=P+22|0;do{if(q){T=S>>>12&15;if((T|0)==0){break}if((f&1<<(T^15)|0)==0){break}b[U>>1]=c[a+(T<<2)>>2]&65535}}while(0);U=P+24|0;do{if(r){T=S>>>16&15;if((T|0)==0){break}if((f&1<<(T^15)|0)==0){break}b[U>>1]=c[a+(T<<2)>>2]&65535}}while(0);U=P+26|0;do{if(s){T=S>>>20&15;if((T|0)==0){break}if((f&1<<(T^15)|0)==0){break}b[U>>1]=c[a+(T<<2)>>2]&65535}}while(0);U=P+28|0;do{if(t){T=S>>>24&15;if((T|0)==0){break}if((f&1<<(T^15)|0)==0){break}b[U>>1]=c[a+(T<<2)>>2]&65535}}while(0);U=P+30|0;do{if(u){T=S>>>28;if((T|0)==0){break}if((f&1<<(T^15)|0)==0){break}b[U>>1]=c[a+(T<<2)>>2]&65535}}while(0);U=P+32|0;S=c[Q+4>>2]|0;T=V|S;do{if(v){W=S&15;if((W|0)==0){break}if((f&1<<(W^15)|0)==0){break}b[U>>1]=c[a+(W<<2)>>2]&65535}}while(0);U=P+34|0;do{if(w){V=S>>>4&15;if((V|0)==0){break}if((f&1<<(V^15)|0)==0){break}b[U>>1]=c[a+(V<<2)>>2]&65535}}while(0);U=P+36|0;do{if(x){V=S>>>8&15;if((V|0)==0){break}if((f&1<<(V^15)|0)==0){break}b[U>>1]=c[a+(V<<2)>>2]&65535}}while(0);U=P+38|0;do{if(y){V=S>>>12&15;if((V|0)==0){break}if((f&1<<(V^15)|0)==0){break}b[U>>1]=c[a+(V<<2)>>2]&65535}}while(0);U=P+40|0;do{if(z){V=S>>>16&15;if((V|0)==0){break}if((f&1<<(V^15)|0)==0){break}b[U>>1]=c[a+(V<<2)>>2]&65535}}while(0);U=P+42|0;do{if(A){V=S>>>20&15;if((V|0)==0){break}if((f&1<<(V^15)|0)==0){break}b[U>>1]=c[a+(V<<2)>>2]&65535}}while(0);U=P+44|0;do{if(B){V=S>>>24&15;if((V|0)==0){break}if((f&1<<(V^15)|0)==0){break}b[U>>1]=c[a+(V<<2)>>2]&65535}}while(0);U=P+46|0;do{if(C){V=S>>>28;if((V|0)==0){break}if((f&1<<(V^15)|0)==0){break}b[U>>1]=c[a+(V<<2)>>2]&65535}}while(0);U=P+48|0;S=c[Q>>2]|0;V=T|S;do{if(D){W=S&15;if((W|0)==0){break}if((f&1<<(W^15)|0)==0){break}b[U>>1]=c[a+(W<<2)>>2]&65535}}while(0);U=P+50|0;do{if(E){T=S>>>4&15;if((T|0)==0){break}if((f&1<<(T^15)|0)==0){break}b[U>>1]=c[a+(T<<2)>>2]&65535}}while(0);U=P+52|0;do{if(F){T=S>>>8&15;if((T|0)==0){break}if((f&1<<(T^15)|0)==0){break}b[U>>1]=c[a+(T<<2)>>2]&65535}}while(0);U=P+54|0;do{if(G){T=S>>>12&15;if((T|0)==0){break}if((f&1<<(T^15)|0)==0){break}b[U>>1]=c[a+(T<<2)>>2]&65535}}while(0);U=P+56|0;do{if(H){T=S>>>16&15;if((T|0)==0){break}if((f&1<<(T^15)|0)==0){break}b[U>>1]=c[a+(T<<2)>>2]&65535}}while(0);U=P+58|0;do{if(I){T=S>>>20&15;if((T|0)==0){break}if((f&1<<(T^15)|0)==0){break}b[U>>1]=c[a+(T<<2)>>2]&65535}}while(0);U=P+60|0;do{if(J){T=S>>>24&15;if((T|0)==0){break}if((f&1<<(T^15)|0)==0){break}b[U>>1]=c[a+(T<<2)>>2]&65535}}while(0);if(!K){X=V;break}U=S>>>28;if((U|0)==0){X=V;break}if((f&1<<(U^15)|0)==0){X=V;break}b[P+62>>1]=c[a+(U<<2)>>2]&65535;X=V}else{X=N}}while(0);Y=P+d|0;Z=Q+L|0;if((M|0)>=32){break}M=M+1|0;N=X;O=R;P=Y;Q=Z}c[2113226]=R;c[2112962]=Y;c[2112960]=Z;return(X|0)==0|0}function agr(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;a=c[3541654]|0;d=b[3726284]|0;f=c[2113300]|0;g=c[2113224]|0;h=0;i=0;j=c[2112962]|0;k=c[2112960]|0;l=c[2112924]|0;do{m=c[k>>2]|0;i=m|i;do{if(m>>>0>268435455){if((e[l>>1]|0)>=(d&65535)){break}b[j>>1]=c[a+(m>>>28<<2)>>2]&65535;b[l>>1]=d}}while(0);n=j+2|0;o=l+2|0;do{if(m<<4>>>0>268435455){if((e[o>>1]|0)>=(d&65535)){break}b[n>>1]=c[a+((m>>>24&15)<<2)>>2]&65535;b[o>>1]=d}}while(0);o=j+4|0;n=l+4|0;do{if(m<<8>>>0>268435455){if((e[n>>1]|0)>=(d&65535)){break}b[o>>1]=c[a+((m>>>20&15)<<2)>>2]&65535;b[n>>1]=d}}while(0);n=j+6|0;o=l+6|0;do{if(m<<12>>>0>268435455){if((e[o>>1]|0)>=(d&65535)){break}b[n>>1]=c[a+((m>>>16&15)<<2)>>2]&65535;b[o>>1]=d}}while(0);o=j+8|0;n=l+8|0;do{if(m<<16>>>0>268435455){if((e[n>>1]|0)>=(d&65535)){break}b[o>>1]=c[a+((m>>>12&15)<<2)>>2]&65535;b[n>>1]=d}}while(0);n=j+10|0;o=l+10|0;do{if(m<<20>>>0>268435455){if((e[o>>1]|0)>=(d&65535)){break}b[n>>1]=c[a+((m>>>8&15)<<2)>>2]&65535;b[o>>1]=d}}while(0);o=j+12|0;n=l+12|0;do{if(m<<24>>>0>268435455){if((e[n>>1]|0)>=(d&65535)){break}b[o>>1]=c[a+((m>>>4&15)<<2)>>2]&65535;b[n>>1]=d}}while(0);n=j+14|0;o=l+14|0;p=m&15;do{if((p|0)!=0){if((e[o>>1]|0)>=(d&65535)){break}b[n>>1]=c[a+(p<<2)>>2]&65535;b[o>>1]=d}}while(0);h=h+1|0;j=j+f|0;k=k+g|0;l=l+768|0;}while((h|0)<8);c[2112962]=j;c[2112960]=k;c[2112924]=l;return(i|0)==0|0}function ags(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;a=c[3541654]|0;d=c[2113300]|0;f=c[2113224]|0;g=b[3726284]|0;h=0;i=0;j=c[2112962]|0;k=c[2112960]|0;l=c[2112924]|0;do{m=c[k>>2]|0;i=m|i;n=m&15;do{if((n|0)!=0){if((e[l>>1]|0)>=(g&65535)){break}b[j>>1]=c[a+(n<<2)>>2]&65535;b[l>>1]=g}}while(0);n=j+2|0;o=l+2|0;p=m>>>4&15;do{if((p|0)!=0){if((e[o>>1]|0)>=(g&65535)){break}b[n>>1]=c[a+(p<<2)>>2]&65535;b[o>>1]=g}}while(0);o=j+4|0;p=l+4|0;n=m>>>8&15;do{if((n|0)!=0){if((e[p>>1]|0)>=(g&65535)){break}b[o>>1]=c[a+(n<<2)>>2]&65535;b[p>>1]=g}}while(0);p=j+6|0;n=l+6|0;o=m>>>12&15;do{if((o|0)!=0){if((e[n>>1]|0)>=(g&65535)){break}b[p>>1]=c[a+(o<<2)>>2]&65535;b[n>>1]=g}}while(0);n=j+8|0;o=l+8|0;p=m>>>16&15;do{if((p|0)!=0){if((e[o>>1]|0)>=(g&65535)){break}b[n>>1]=c[a+(p<<2)>>2]&65535;b[o>>1]=g}}while(0);o=j+10|0;p=l+10|0;n=m>>>20&15;do{if((n|0)!=0){if((e[p>>1]|0)>=(g&65535)){break}b[o>>1]=c[a+(n<<2)>>2]&65535;b[p>>1]=g}}while(0);p=j+12|0;n=l+12|0;o=m>>>24&15;do{if((o|0)!=0){if((e[n>>1]|0)>=(g&65535)){break}b[p>>1]=c[a+(o<<2)>>2]&65535;b[n>>1]=g}}while(0);n=j+14|0;o=l+14|0;p=m>>>28;do{if((p|0)!=0){if((e[o>>1]|0)>=(g&65535)){break}b[n>>1]=c[a+(p<<2)>>2]&65535;b[o>>1]=g}}while(0);h=h+1|0;j=j+d|0;k=k+f|0;l=l+768|0;}while((h|0)<8);c[2112962]=j;c[2112960]=k;c[2112924]=l;return(i|0)==0|0}function agt(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;a=c[3541654]|0;d=c[2113228]|0;f=(d&536887296|0)==0;g=b[3726284]|0;h=(d+32767&536887296|0)==0;i=(d+65534&536887296|0)==0;j=(d+98301&536887296|0)==0;k=(d+131068&536887296|0)==0;l=(d+163835&536887296|0)==0;m=(d+196602&536887296|0)==0;n=(d+229369&536887296|0)==0;d=c[2113300]|0;o=c[2113224]|0;p=1;q=0;r=c[2113226]|0;s=c[2112962]|0;t=c[2112924]|0;u=c[2112960]|0;while(1){v=r+32767|0;do{if((r&536887296|0)==0){w=c[u>>2]|0;x=w|q;do{if(f&w>>>0>268435455){if((e[t>>1]|0)>=(g&65535)){break}b[s>>1]=c[a+(w>>>28<<2)>>2]&65535;b[t>>1]=g}}while(0);y=s+2|0;z=t+2|0;do{if(h){if(w<<4>>>0<=268435455){break}if((e[z>>1]|0)>=(g&65535)){break}b[y>>1]=c[a+((w>>>24&15)<<2)>>2]&65535;b[z>>1]=g}}while(0);z=s+4|0;y=t+4|0;do{if(i){if(w<<8>>>0<=268435455){break}if((e[y>>1]|0)>=(g&65535)){break}b[z>>1]=c[a+((w>>>20&15)<<2)>>2]&65535;b[y>>1]=g}}while(0);y=s+6|0;z=t+6|0;do{if(j){if(w<<12>>>0<=268435455){break}if((e[z>>1]|0)>=(g&65535)){break}b[y>>1]=c[a+((w>>>16&15)<<2)>>2]&65535;b[z>>1]=g}}while(0);z=s+8|0;y=t+8|0;do{if(k){if(w<<16>>>0<=268435455){break}if((e[y>>1]|0)>=(g&65535)){break}b[z>>1]=c[a+((w>>>12&15)<<2)>>2]&65535;b[y>>1]=g}}while(0);y=s+10|0;z=t+10|0;do{if(l){if(w<<20>>>0<=268435455){break}if((e[z>>1]|0)>=(g&65535)){break}b[y>>1]=c[a+((w>>>8&15)<<2)>>2]&65535;b[z>>1]=g}}while(0);z=s+12|0;y=t+12|0;do{if(m){if(w<<24>>>0<=268435455){break}if((e[y>>1]|0)>=(g&65535)){break}b[z>>1]=c[a+((w>>>4&15)<<2)>>2]&65535;b[y>>1]=g}}while(0);y=t+14|0;if(!n){A=x;break}z=w&15;if((z|0)==0){A=x;break}if((e[y>>1]|0)>=(g&65535)){A=x;break}b[s+14>>1]=c[a+(z<<2)>>2]&65535;b[y>>1]=g;A=x}else{A=q}}while(0);B=s+d|0;C=u+o|0;D=t+768|0;if((p|0)>=8){break}p=p+1|0;q=A;r=v;s=B;t=D;u=C}c[2113226]=v;c[2112962]=B;c[2112924]=D;c[2112960]=C;return(A|0)==0|0}function agu(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;a=c[3541654]|0;d=c[2113228]|0;f=(d&536887296|0)==0;g=b[3726284]|0;h=(d+32767&536887296|0)==0;i=(d+65534&536887296|0)==0;j=(d+98301&536887296|0)==0;k=(d+131068&536887296|0)==0;l=(d+163835&536887296|0)==0;m=(d+196602&536887296|0)==0;n=(d+229369&536887296|0)==0;d=c[2113300]|0;o=c[2113224]|0;p=1;q=0;r=c[2113226]|0;s=c[2112962]|0;t=c[2112924]|0;u=c[2112960]|0;while(1){v=r+32767|0;do{if((r&536887296|0)==0){w=c[u>>2]|0;x=w|q;do{if(f){y=w&15;if((y|0)==0){break}if((e[t>>1]|0)>=(g&65535)){break}b[s>>1]=c[a+(y<<2)>>2]&65535;b[t>>1]=g}}while(0);y=s+2|0;z=t+2|0;do{if(h){A=w>>>4&15;if((A|0)==0){break}if((e[z>>1]|0)>=(g&65535)){break}b[y>>1]=c[a+(A<<2)>>2]&65535;b[z>>1]=g}}while(0);z=s+4|0;y=t+4|0;do{if(i){A=w>>>8&15;if((A|0)==0){break}if((e[y>>1]|0)>=(g&65535)){break}b[z>>1]=c[a+(A<<2)>>2]&65535;b[y>>1]=g}}while(0);y=s+6|0;z=t+6|0;do{if(j){A=w>>>12&15;if((A|0)==0){break}if((e[z>>1]|0)>=(g&65535)){break}b[y>>1]=c[a+(A<<2)>>2]&65535;b[z>>1]=g}}while(0);z=s+8|0;y=t+8|0;do{if(k){A=w>>>16&15;if((A|0)==0){break}if((e[y>>1]|0)>=(g&65535)){break}b[z>>1]=c[a+(A<<2)>>2]&65535;b[y>>1]=g}}while(0);y=s+10|0;z=t+10|0;do{if(l){A=w>>>20&15;if((A|0)==0){break}if((e[z>>1]|0)>=(g&65535)){break}b[y>>1]=c[a+(A<<2)>>2]&65535;b[z>>1]=g}}while(0);z=s+12|0;y=t+12|0;do{if(m){A=w>>>24&15;if((A|0)==0){break}if((e[y>>1]|0)>=(g&65535)){break}b[z>>1]=c[a+(A<<2)>>2]&65535;b[y>>1]=g}}while(0);y=t+14|0;if(!n){B=x;break}z=w>>>28;if((z|0)==0){B=x;break}if((e[y>>1]|0)>=(g&65535)){B=x;break}b[s+14>>1]=c[a+(z<<2)>>2]&65535;b[y>>1]=g;B=x}else{B=q}}while(0);C=s+d|0;D=u+o|0;E=t+768|0;if((p|0)>=8){break}p=p+1|0;q=B;r=v;s=C;t=E;u=D}c[2113226]=v;c[2112962]=C;c[2112924]=E;c[2112960]=D;return(B|0)==0|0}function agv(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;a=c[3541654]|0;d=b[3726284]|0;f=c[2113300]|0;g=c[2113224]|0;h=0;i=0;j=c[2112960]|0;k=c[2112962]|0;l=c[2112924]|0;do{m=c[j>>2]|0;n=m|i;do{if(m>>>0>268435455){if((e[l>>1]|0)>=(d&65535)){break}b[k>>1]=c[a+(m>>>28<<2)>>2]&65535;b[l>>1]=d}}while(0);o=k+2|0;p=l+2|0;do{if(m<<4>>>0>268435455){if((e[p>>1]|0)>=(d&65535)){break}b[o>>1]=c[a+((m>>>24&15)<<2)>>2]&65535;b[p>>1]=d}}while(0);p=k+4|0;o=l+4|0;do{if(m<<8>>>0>268435455){if((e[o>>1]|0)>=(d&65535)){break}b[p>>1]=c[a+((m>>>20&15)<<2)>>2]&65535;b[o>>1]=d}}while(0);o=k+6|0;p=l+6|0;do{if(m<<12>>>0>268435455){if((e[p>>1]|0)>=(d&65535)){break}b[o>>1]=c[a+((m>>>16&15)<<2)>>2]&65535;b[p>>1]=d}}while(0);p=k+8|0;o=l+8|0;do{if(m<<16>>>0>268435455){if((e[o>>1]|0)>=(d&65535)){break}b[p>>1]=c[a+((m>>>12&15)<<2)>>2]&65535;b[o>>1]=d}}while(0);o=k+10|0;p=l+10|0;do{if(m<<20>>>0>268435455){if((e[p>>1]|0)>=(d&65535)){break}b[o>>1]=c[a+((m>>>8&15)<<2)>>2]&65535;b[p>>1]=d}}while(0);p=k+12|0;o=l+12|0;do{if(m<<24>>>0>268435455){if((e[o>>1]|0)>=(d&65535)){break}b[p>>1]=c[a+((m>>>4&15)<<2)>>2]&65535;b[o>>1]=d}}while(0);o=k+14|0;p=l+14|0;q=m&15;do{if((q|0)!=0){if((e[p>>1]|0)>=(d&65535)){break}b[o>>1]=c[a+(q<<2)>>2]&65535;b[p>>1]=d}}while(0);p=k+16|0;q=l+16|0;o=c[j+4>>2]|0;i=n|o;do{if(o>>>0>268435455){if((e[q>>1]|0)>=(d&65535)){break}b[p>>1]=c[a+(o>>>28<<2)>>2]&65535;b[q>>1]=d}}while(0);q=k+18|0;p=l+18|0;do{if(o<<4>>>0>268435455){if((e[p>>1]|0)>=(d&65535)){break}b[q>>1]=c[a+((o>>>24&15)<<2)>>2]&65535;b[p>>1]=d}}while(0);p=k+20|0;q=l+20|0;do{if(o<<8>>>0>268435455){if((e[q>>1]|0)>=(d&65535)){break}b[p>>1]=c[a+((o>>>20&15)<<2)>>2]&65535;b[q>>1]=d}}while(0);q=k+22|0;p=l+22|0;do{if(o<<12>>>0>268435455){if((e[p>>1]|0)>=(d&65535)){break}b[q>>1]=c[a+((o>>>16&15)<<2)>>2]&65535;b[p>>1]=d}}while(0);p=k+24|0;q=l+24|0;do{if(o<<16>>>0>268435455){if((e[q>>1]|0)>=(d&65535)){break}b[p>>1]=c[a+((o>>>12&15)<<2)>>2]&65535;b[q>>1]=d}}while(0);q=k+26|0;p=l+26|0;do{if(o<<20>>>0>268435455){if((e[p>>1]|0)>=(d&65535)){break}b[q>>1]=c[a+((o>>>8&15)<<2)>>2]&65535;b[p>>1]=d}}while(0);p=k+28|0;q=l+28|0;do{if(o<<24>>>0>268435455){if((e[q>>1]|0)>=(d&65535)){break}b[p>>1]=c[a+((o>>>4&15)<<2)>>2]&65535;b[q>>1]=d}}while(0);q=k+30|0;p=l+30|0;n=o&15;do{if((n|0)!=0){if((e[p>>1]|0)>=(d&65535)){break}b[q>>1]=c[a+(n<<2)>>2]&65535;b[p>>1]=d}}while(0);h=h+1|0;k=k+f|0;j=j+g|0;l=l+768|0;}while((h|0)<16);c[2112960]=j;c[2112962]=k;c[2112924]=l;return(i|0)==0|0}function agw(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;a=c[3541654]|0;d=c[2113300]|0;f=c[2113224]|0;g=b[3726284]|0;h=0;i=0;j=c[2112960]|0;k=c[2112962]|0;l=c[2112924]|0;do{m=c[j+4>>2]|0;n=m|i;o=m&15;do{if((o|0)!=0){if((e[l>>1]|0)>=(g&65535)){break}b[k>>1]=c[a+(o<<2)>>2]&65535;b[l>>1]=g}}while(0);o=k+2|0;p=l+2|0;q=m>>>4&15;do{if((q|0)!=0){if((e[p>>1]|0)>=(g&65535)){break}b[o>>1]=c[a+(q<<2)>>2]&65535;b[p>>1]=g}}while(0);p=k+4|0;q=l+4|0;o=m>>>8&15;do{if((o|0)!=0){if((e[q>>1]|0)>=(g&65535)){break}b[p>>1]=c[a+(o<<2)>>2]&65535;b[q>>1]=g}}while(0);q=k+6|0;o=l+6|0;p=m>>>12&15;do{if((p|0)!=0){if((e[o>>1]|0)>=(g&65535)){break}b[q>>1]=c[a+(p<<2)>>2]&65535;b[o>>1]=g}}while(0);o=k+8|0;p=l+8|0;q=m>>>16&15;do{if((q|0)!=0){if((e[p>>1]|0)>=(g&65535)){break}b[o>>1]=c[a+(q<<2)>>2]&65535;b[p>>1]=g}}while(0);p=k+10|0;q=l+10|0;o=m>>>20&15;do{if((o|0)!=0){if((e[q>>1]|0)>=(g&65535)){break}b[p>>1]=c[a+(o<<2)>>2]&65535;b[q>>1]=g}}while(0);q=k+12|0;o=l+12|0;p=m>>>24&15;do{if((p|0)!=0){if((e[o>>1]|0)>=(g&65535)){break}b[q>>1]=c[a+(p<<2)>>2]&65535;b[o>>1]=g}}while(0);o=k+14|0;p=l+14|0;q=m>>>28;do{if((q|0)!=0){if((e[p>>1]|0)>=(g&65535)){break}b[o>>1]=c[a+(q<<2)>>2]&65535;b[p>>1]=g}}while(0);p=k+16|0;q=l+16|0;o=c[j>>2]|0;i=n|o;m=o&15;do{if((m|0)!=0){if((e[q>>1]|0)>=(g&65535)){break}b[p>>1]=c[a+(m<<2)>>2]&65535;b[q>>1]=g}}while(0);q=k+18|0;m=l+18|0;p=o>>>4&15;do{if((p|0)!=0){if((e[m>>1]|0)>=(g&65535)){break}b[q>>1]=c[a+(p<<2)>>2]&65535;b[m>>1]=g}}while(0);m=k+20|0;p=l+20|0;q=o>>>8&15;do{if((q|0)!=0){if((e[p>>1]|0)>=(g&65535)){break}b[m>>1]=c[a+(q<<2)>>2]&65535;b[p>>1]=g}}while(0);p=k+22|0;q=l+22|0;m=o>>>12&15;do{if((m|0)!=0){if((e[q>>1]|0)>=(g&65535)){break}b[p>>1]=c[a+(m<<2)>>2]&65535;b[q>>1]=g}}while(0);q=k+24|0;m=l+24|0;p=o>>>16&15;do{if((p|0)!=0){if((e[m>>1]|0)>=(g&65535)){break}b[q>>1]=c[a+(p<<2)>>2]&65535;b[m>>1]=g}}while(0);m=k+26|0;p=l+26|0;q=o>>>20&15;do{if((q|0)!=0){if((e[p>>1]|0)>=(g&65535)){break}b[m>>1]=c[a+(q<<2)>>2]&65535;b[p>>1]=g}}while(0);p=k+28|0;q=l+28|0;m=o>>>24&15;do{if((m|0)!=0){if((e[q>>1]|0)>=(g&65535)){break}b[p>>1]=c[a+(m<<2)>>2]&65535;b[q>>1]=g}}while(0);q=k+30|0;m=l+30|0;p=o>>>28;do{if((p|0)!=0){if((e[m>>1]|0)>=(g&65535)){break}b[q>>1]=c[a+(p<<2)>>2]&65535;b[m>>1]=g}}while(0);h=h+1|0;k=k+d|0;j=j+f|0;l=l+768|0;}while((h|0)<16);c[2112960]=j;c[2112962]=k;c[2112924]=l;return(i|0)==0|0}function agx(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;a=c[3541654]|0;d=c[2113228]|0;f=(d&536887296|0)==0;g=b[3726284]|0;h=(d+32767&536887296|0)==0;i=(d+65534&536887296|0)==0;j=(d+98301&536887296|0)==0;k=(d+131068&536887296|0)==0;l=(d+163835&536887296|0)==0;m=(d+196602&536887296|0)==0;n=(d+229369&536887296|0)==0;o=(d+262136&536887296|0)==0;p=(d+294903&536887296|0)==0;q=(d+327670&536887296|0)==0;r=(d+360437&536887296|0)==0;s=(d+393204&536887296|0)==0;t=(d+425971&536887296|0)==0;u=(d+458738&536887296|0)==0;v=(d+491505&536887296|0)==0;d=c[2113300]|0;w=c[2113224]|0;x=1;y=0;z=c[2113226]|0;A=c[2112962]|0;B=c[2112924]|0;C=c[2112960]|0;while(1){D=z+32767|0;do{if((z&536887296|0)==0){E=c[C>>2]|0;F=E|y;do{if(f&E>>>0>268435455){if((e[B>>1]|0)>=(g&65535)){break}b[A>>1]=c[a+(E>>>28<<2)>>2]&65535;b[B>>1]=g}}while(0);G=A+2|0;H=B+2|0;do{if(h){if(E<<4>>>0<=268435455){break}if((e[H>>1]|0)>=(g&65535)){break}b[G>>1]=c[a+((E>>>24&15)<<2)>>2]&65535;b[H>>1]=g}}while(0);H=A+4|0;G=B+4|0;do{if(i){if(E<<8>>>0<=268435455){break}if((e[G>>1]|0)>=(g&65535)){break}b[H>>1]=c[a+((E>>>20&15)<<2)>>2]&65535;b[G>>1]=g}}while(0);G=A+6|0;H=B+6|0;do{if(j){if(E<<12>>>0<=268435455){break}if((e[H>>1]|0)>=(g&65535)){break}b[G>>1]=c[a+((E>>>16&15)<<2)>>2]&65535;b[H>>1]=g}}while(0);H=A+8|0;G=B+8|0;do{if(k){if(E<<16>>>0<=268435455){break}if((e[G>>1]|0)>=(g&65535)){break}b[H>>1]=c[a+((E>>>12&15)<<2)>>2]&65535;b[G>>1]=g}}while(0);G=A+10|0;H=B+10|0;do{if(l){if(E<<20>>>0<=268435455){break}if((e[H>>1]|0)>=(g&65535)){break}b[G>>1]=c[a+((E>>>8&15)<<2)>>2]&65535;b[H>>1]=g}}while(0);H=A+12|0;G=B+12|0;do{if(m){if(E<<24>>>0<=268435455){break}if((e[G>>1]|0)>=(g&65535)){break}b[H>>1]=c[a+((E>>>4&15)<<2)>>2]&65535;b[G>>1]=g}}while(0);G=A+14|0;H=B+14|0;do{if(n){I=E&15;if((I|0)==0){break}if((e[H>>1]|0)>=(g&65535)){break}b[G>>1]=c[a+(I<<2)>>2]&65535;b[H>>1]=g}}while(0);H=A+16|0;G=B+16|0;E=c[C+4>>2]|0;I=F|E;do{if(o&E>>>0>268435455){if((e[G>>1]|0)>=(g&65535)){break}b[H>>1]=c[a+(E>>>28<<2)>>2]&65535;b[G>>1]=g}}while(0);G=A+18|0;H=B+18|0;do{if(p){if(E<<4>>>0<=268435455){break}if((e[H>>1]|0)>=(g&65535)){break}b[G>>1]=c[a+((E>>>24&15)<<2)>>2]&65535;b[H>>1]=g}}while(0);H=A+20|0;G=B+20|0;do{if(q){if(E<<8>>>0<=268435455){break}if((e[G>>1]|0)>=(g&65535)){break}b[H>>1]=c[a+((E>>>20&15)<<2)>>2]&65535;b[G>>1]=g}}while(0);G=A+22|0;H=B+22|0;do{if(r){if(E<<12>>>0<=268435455){break}if((e[H>>1]|0)>=(g&65535)){break}b[G>>1]=c[a+((E>>>16&15)<<2)>>2]&65535;b[H>>1]=g}}while(0);H=A+24|0;G=B+24|0;do{if(s){if(E<<16>>>0<=268435455){break}if((e[G>>1]|0)>=(g&65535)){break}b[H>>1]=c[a+((E>>>12&15)<<2)>>2]&65535;b[G>>1]=g}}while(0);G=A+26|0;H=B+26|0;do{if(t){if(E<<20>>>0<=268435455){break}if((e[H>>1]|0)>=(g&65535)){break}b[G>>1]=c[a+((E>>>8&15)<<2)>>2]&65535;b[H>>1]=g}}while(0);H=A+28|0;G=B+28|0;do{if(u){if(E<<24>>>0<=268435455){break}if((e[G>>1]|0)>=(g&65535)){break}b[H>>1]=c[a+((E>>>4&15)<<2)>>2]&65535;b[G>>1]=g}}while(0);G=B+30|0;if(!v){J=I;break}H=E&15;if((H|0)==0){J=I;break}if((e[G>>1]|0)>=(g&65535)){J=I;break}b[A+30>>1]=c[a+(H<<2)>>2]&65535;b[G>>1]=g;J=I}else{J=y}}while(0);K=A+d|0;L=C+w|0;M=B+768|0;if((x|0)>=16){break}x=x+1|0;y=J;z=D;A=K;B=M;C=L}c[2113226]=D;c[2112962]=K;c[2112924]=M;c[2112960]=L;return(J|0)==0|0}function agy(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;a=c[3541654]|0;d=c[2113228]|0;f=(d&536887296|0)==0;g=b[3726284]|0;h=(d+32767&536887296|0)==0;i=(d+65534&536887296|0)==0;j=(d+98301&536887296|0)==0;k=(d+131068&536887296|0)==0;l=(d+163835&536887296|0)==0;m=(d+196602&536887296|0)==0;n=(d+229369&536887296|0)==0;o=(d+262136&536887296|0)==0;p=(d+294903&536887296|0)==0;q=(d+327670&536887296|0)==0;r=(d+360437&536887296|0)==0;s=(d+393204&536887296|0)==0;t=(d+425971&536887296|0)==0;u=(d+458738&536887296|0)==0;v=(d+491505&536887296|0)==0;d=c[2113300]|0;w=c[2113224]|0;x=1;y=0;z=c[2113226]|0;A=c[2112962]|0;B=c[2112924]|0;C=c[2112960]|0;while(1){D=z+32767|0;do{if((z&536887296|0)==0){E=c[C+4>>2]|0;F=E|y;do{if(f){G=E&15;if((G|0)==0){break}if((e[B>>1]|0)>=(g&65535)){break}b[A>>1]=c[a+(G<<2)>>2]&65535;b[B>>1]=g}}while(0);G=A+2|0;H=B+2|0;do{if(h){I=E>>>4&15;if((I|0)==0){break}if((e[H>>1]|0)>=(g&65535)){break}b[G>>1]=c[a+(I<<2)>>2]&65535;b[H>>1]=g}}while(0);H=A+4|0;G=B+4|0;do{if(i){I=E>>>8&15;if((I|0)==0){break}if((e[G>>1]|0)>=(g&65535)){break}b[H>>1]=c[a+(I<<2)>>2]&65535;b[G>>1]=g}}while(0);G=A+6|0;H=B+6|0;do{if(j){I=E>>>12&15;if((I|0)==0){break}if((e[H>>1]|0)>=(g&65535)){break}b[G>>1]=c[a+(I<<2)>>2]&65535;b[H>>1]=g}}while(0);H=A+8|0;G=B+8|0;do{if(k){I=E>>>16&15;if((I|0)==0){break}if((e[G>>1]|0)>=(g&65535)){break}b[H>>1]=c[a+(I<<2)>>2]&65535;b[G>>1]=g}}while(0);G=A+10|0;H=B+10|0;do{if(l){I=E>>>20&15;if((I|0)==0){break}if((e[H>>1]|0)>=(g&65535)){break}b[G>>1]=c[a+(I<<2)>>2]&65535;b[H>>1]=g}}while(0);H=A+12|0;G=B+12|0;do{if(m){I=E>>>24&15;if((I|0)==0){break}if((e[G>>1]|0)>=(g&65535)){break}b[H>>1]=c[a+(I<<2)>>2]&65535;b[G>>1]=g}}while(0);G=A+14|0;H=B+14|0;do{if(n){I=E>>>28;if((I|0)==0){break}if((e[H>>1]|0)>=(g&65535)){break}b[G>>1]=c[a+(I<<2)>>2]&65535;b[H>>1]=g}}while(0);H=A+16|0;G=B+16|0;E=c[C>>2]|0;I=F|E;do{if(o){J=E&15;if((J|0)==0){break}if((e[G>>1]|0)>=(g&65535)){break}b[H>>1]=c[a+(J<<2)>>2]&65535;b[G>>1]=g}}while(0);G=A+18|0;H=B+18|0;do{if(p){F=E>>>4&15;if((F|0)==0){break}if((e[H>>1]|0)>=(g&65535)){break}b[G>>1]=c[a+(F<<2)>>2]&65535;b[H>>1]=g}}while(0);H=A+20|0;G=B+20|0;do{if(q){F=E>>>8&15;if((F|0)==0){break}if((e[G>>1]|0)>=(g&65535)){break}b[H>>1]=c[a+(F<<2)>>2]&65535;b[G>>1]=g}}while(0);G=A+22|0;H=B+22|0;do{if(r){F=E>>>12&15;if((F|0)==0){break}if((e[H>>1]|0)>=(g&65535)){break}b[G>>1]=c[a+(F<<2)>>2]&65535;b[H>>1]=g}}while(0);H=A+24|0;G=B+24|0;do{if(s){F=E>>>16&15;if((F|0)==0){break}if((e[G>>1]|0)>=(g&65535)){break}b[H>>1]=c[a+(F<<2)>>2]&65535;b[G>>1]=g}}while(0);G=A+26|0;H=B+26|0;do{if(t){F=E>>>20&15;if((F|0)==0){break}if((e[H>>1]|0)>=(g&65535)){break}b[G>>1]=c[a+(F<<2)>>2]&65535;b[H>>1]=g}}while(0);H=A+28|0;G=B+28|0;do{if(u){F=E>>>24&15;if((F|0)==0){break}if((e[G>>1]|0)>=(g&65535)){break}b[H>>1]=c[a+(F<<2)>>2]&65535;b[G>>1]=g}}while(0);G=B+30|0;if(!v){K=I;break}H=E>>>28;if((H|0)==0){K=I;break}if((e[G>>1]|0)>=(g&65535)){K=I;break}b[A+30>>1]=c[a+(H<<2)>>2]&65535;b[G>>1]=g;K=I}else{K=y}}while(0);L=A+d|0;M=C+w|0;N=B+768|0;if((x|0)>=16){break}x=x+1|0;y=K;z=D;A=L;B=N;C=M}c[2113226]=D;c[2112962]=L;c[2112924]=N;c[2112960]=M;return(K|0)==0|0}function agz(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;a=c[3541654]|0;d=b[3726284]|0;f=c[2113300]|0;g=c[2113224]|0;h=0;i=0;j=c[2112960]|0;k=c[2112962]|0;l=c[2112924]|0;do{m=c[j>>2]|0;n=m|i;do{if(m>>>0>268435455){if((e[l>>1]|0)>=(d&65535)){break}b[k>>1]=c[a+(m>>>28<<2)>>2]&65535;b[l>>1]=d}}while(0);o=k+2|0;p=l+2|0;do{if(m<<4>>>0>268435455){if((e[p>>1]|0)>=(d&65535)){break}b[o>>1]=c[a+((m>>>24&15)<<2)>>2]&65535;b[p>>1]=d}}while(0);p=k+4|0;o=l+4|0;do{if(m<<8>>>0>268435455){if((e[o>>1]|0)>=(d&65535)){break}b[p>>1]=c[a+((m>>>20&15)<<2)>>2]&65535;b[o>>1]=d}}while(0);o=k+6|0;p=l+6|0;do{if(m<<12>>>0>268435455){if((e[p>>1]|0)>=(d&65535)){break}b[o>>1]=c[a+((m>>>16&15)<<2)>>2]&65535;b[p>>1]=d}}while(0);p=k+8|0;o=l+8|0;do{if(m<<16>>>0>268435455){if((e[o>>1]|0)>=(d&65535)){break}b[p>>1]=c[a+((m>>>12&15)<<2)>>2]&65535;b[o>>1]=d}}while(0);o=k+10|0;p=l+10|0;do{if(m<<20>>>0>268435455){if((e[p>>1]|0)>=(d&65535)){break}b[o>>1]=c[a+((m>>>8&15)<<2)>>2]&65535;b[p>>1]=d}}while(0);p=k+12|0;o=l+12|0;do{if(m<<24>>>0>268435455){if((e[o>>1]|0)>=(d&65535)){break}b[p>>1]=c[a+((m>>>4&15)<<2)>>2]&65535;b[o>>1]=d}}while(0);o=k+14|0;p=l+14|0;q=m&15;do{if((q|0)!=0){if((e[p>>1]|0)>=(d&65535)){break}b[o>>1]=c[a+(q<<2)>>2]&65535;b[p>>1]=d}}while(0);p=k+16|0;q=l+16|0;o=c[j+4>>2]|0;m=n|o;do{if(o>>>0>268435455){if((e[q>>1]|0)>=(d&65535)){break}b[p>>1]=c[a+(o>>>28<<2)>>2]&65535;b[q>>1]=d}}while(0);q=k+18|0;p=l+18|0;do{if(o<<4>>>0>268435455){if((e[p>>1]|0)>=(d&65535)){break}b[q>>1]=c[a+((o>>>24&15)<<2)>>2]&65535;b[p>>1]=d}}while(0);p=k+20|0;q=l+20|0;do{if(o<<8>>>0>268435455){if((e[q>>1]|0)>=(d&65535)){break}b[p>>1]=c[a+((o>>>20&15)<<2)>>2]&65535;b[q>>1]=d}}while(0);q=k+22|0;p=l+22|0;do{if(o<<12>>>0>268435455){if((e[p>>1]|0)>=(d&65535)){break}b[q>>1]=c[a+((o>>>16&15)<<2)>>2]&65535;b[p>>1]=d}}while(0);p=k+24|0;q=l+24|0;do{if(o<<16>>>0>268435455){if((e[q>>1]|0)>=(d&65535)){break}b[p>>1]=c[a+((o>>>12&15)<<2)>>2]&65535;b[q>>1]=d}}while(0);q=k+26|0;p=l+26|0;do{if(o<<20>>>0>268435455){if((e[p>>1]|0)>=(d&65535)){break}b[q>>1]=c[a+((o>>>8&15)<<2)>>2]&65535;b[p>>1]=d}}while(0);p=k+28|0;q=l+28|0;do{if(o<<24>>>0>268435455){if((e[q>>1]|0)>=(d&65535)){break}b[p>>1]=c[a+((o>>>4&15)<<2)>>2]&65535;b[q>>1]=d}}while(0);q=k+30|0;p=l+30|0;n=o&15;do{if((n|0)!=0){if((e[p>>1]|0)>=(d&65535)){break}b[q>>1]=c[a+(n<<2)>>2]&65535;b[p>>1]=d}}while(0);p=k+32|0;n=l+32|0;q=c[j+8>>2]|0;o=m|q;do{if(q>>>0>268435455){if((e[n>>1]|0)>=(d&65535)){break}b[p>>1]=c[a+(q>>>28<<2)>>2]&65535;b[n>>1]=d}}while(0);n=k+34|0;p=l+34|0;do{if(q<<4>>>0>268435455){if((e[p>>1]|0)>=(d&65535)){break}b[n>>1]=c[a+((q>>>24&15)<<2)>>2]&65535;b[p>>1]=d}}while(0);p=k+36|0;n=l+36|0;do{if(q<<8>>>0>268435455){if((e[n>>1]|0)>=(d&65535)){break}b[p>>1]=c[a+((q>>>20&15)<<2)>>2]&65535;b[n>>1]=d}}while(0);n=k+38|0;p=l+38|0;do{if(q<<12>>>0>268435455){if((e[p>>1]|0)>=(d&65535)){break}b[n>>1]=c[a+((q>>>16&15)<<2)>>2]&65535;b[p>>1]=d}}while(0);p=k+40|0;n=l+40|0;do{if(q<<16>>>0>268435455){if((e[n>>1]|0)>=(d&65535)){break}b[p>>1]=c[a+((q>>>12&15)<<2)>>2]&65535;b[n>>1]=d}}while(0);n=k+42|0;p=l+42|0;do{if(q<<20>>>0>268435455){if((e[p>>1]|0)>=(d&65535)){break}b[n>>1]=c[a+((q>>>8&15)<<2)>>2]&65535;b[p>>1]=d}}while(0);p=k+44|0;n=l+44|0;do{if(q<<24>>>0>268435455){if((e[n>>1]|0)>=(d&65535)){break}b[p>>1]=c[a+((q>>>4&15)<<2)>>2]&65535;b[n>>1]=d}}while(0);n=k+46|0;p=l+46|0;m=q&15;do{if((m|0)!=0){if((e[p>>1]|0)>=(d&65535)){break}b[n>>1]=c[a+(m<<2)>>2]&65535;b[p>>1]=d}}while(0);p=k+48|0;m=l+48|0;n=c[j+12>>2]|0;i=o|n;do{if(n>>>0>268435455){if((e[m>>1]|0)>=(d&65535)){break}b[p>>1]=c[a+(n>>>28<<2)>>2]&65535;b[m>>1]=d}}while(0);m=k+50|0;p=l+50|0;do{if(n<<4>>>0>268435455){if((e[p>>1]|0)>=(d&65535)){break}b[m>>1]=c[a+((n>>>24&15)<<2)>>2]&65535;b[p>>1]=d}}while(0);p=k+52|0;m=l+52|0;do{if(n<<8>>>0>268435455){if((e[m>>1]|0)>=(d&65535)){break}b[p>>1]=c[a+((n>>>20&15)<<2)>>2]&65535;b[m>>1]=d}}while(0);m=k+54|0;p=l+54|0;do{if(n<<12>>>0>268435455){if((e[p>>1]|0)>=(d&65535)){break}b[m>>1]=c[a+((n>>>16&15)<<2)>>2]&65535;b[p>>1]=d}}while(0);p=k+56|0;m=l+56|0;do{if(n<<16>>>0>268435455){if((e[m>>1]|0)>=(d&65535)){break}b[p>>1]=c[a+((n>>>12&15)<<2)>>2]&65535;b[m>>1]=d}}while(0);m=k+58|0;p=l+58|0;do{if(n<<20>>>0>268435455){if((e[p>>1]|0)>=(d&65535)){break}b[m>>1]=c[a+((n>>>8&15)<<2)>>2]&65535;b[p>>1]=d}}while(0);p=k+60|0;m=l+60|0;do{if(n<<24>>>0>268435455){if((e[m>>1]|0)>=(d&65535)){break}b[p>>1]=c[a+((n>>>4&15)<<2)>>2]&65535;b[m>>1]=d}}while(0);m=k+62|0;p=l+62|0;o=n&15;do{if((o|0)!=0){if((e[p>>1]|0)>=(d&65535)){break}b[m>>1]=c[a+(o<<2)>>2]&65535;b[p>>1]=d}}while(0);h=h+1|0;k=k+f|0;j=j+g|0;l=l+768|0;}while((h|0)<32);c[2112960]=j;c[2112962]=k;c[2112924]=l;return(i|0)==0|0}function agA(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;a=c[3541654]|0;d=c[2113300]|0;f=c[2113224]|0;g=b[3726284]|0;h=0;i=0;j=c[2112960]|0;k=c[2112962]|0;l=c[2112924]|0;do{m=c[j+12>>2]|0;n=m|i;o=m&15;do{if((o|0)!=0){if((e[l>>1]|0)>=(g&65535)){break}b[k>>1]=c[a+(o<<2)>>2]&65535;b[l>>1]=g}}while(0);o=k+2|0;p=l+2|0;q=m>>>4&15;do{if((q|0)!=0){if((e[p>>1]|0)>=(g&65535)){break}b[o>>1]=c[a+(q<<2)>>2]&65535;b[p>>1]=g}}while(0);p=k+4|0;q=l+4|0;o=m>>>8&15;do{if((o|0)!=0){if((e[q>>1]|0)>=(g&65535)){break}b[p>>1]=c[a+(o<<2)>>2]&65535;b[q>>1]=g}}while(0);q=k+6|0;o=l+6|0;p=m>>>12&15;do{if((p|0)!=0){if((e[o>>1]|0)>=(g&65535)){break}b[q>>1]=c[a+(p<<2)>>2]&65535;b[o>>1]=g}}while(0);o=k+8|0;p=l+8|0;q=m>>>16&15;do{if((q|0)!=0){if((e[p>>1]|0)>=(g&65535)){break}b[o>>1]=c[a+(q<<2)>>2]&65535;b[p>>1]=g}}while(0);p=k+10|0;q=l+10|0;o=m>>>20&15;do{if((o|0)!=0){if((e[q>>1]|0)>=(g&65535)){break}b[p>>1]=c[a+(o<<2)>>2]&65535;b[q>>1]=g}}while(0);q=k+12|0;o=l+12|0;p=m>>>24&15;do{if((p|0)!=0){if((e[o>>1]|0)>=(g&65535)){break}b[q>>1]=c[a+(p<<2)>>2]&65535;b[o>>1]=g}}while(0);o=k+14|0;p=l+14|0;q=m>>>28;do{if((q|0)!=0){if((e[p>>1]|0)>=(g&65535)){break}b[o>>1]=c[a+(q<<2)>>2]&65535;b[p>>1]=g}}while(0);p=k+16|0;q=l+16|0;o=c[j+8>>2]|0;m=n|o;r=o&15;do{if((r|0)!=0){if((e[q>>1]|0)>=(g&65535)){break}b[p>>1]=c[a+(r<<2)>>2]&65535;b[q>>1]=g}}while(0);q=k+18|0;r=l+18|0;p=o>>>4&15;do{if((p|0)!=0){if((e[r>>1]|0)>=(g&65535)){break}b[q>>1]=c[a+(p<<2)>>2]&65535;b[r>>1]=g}}while(0);r=k+20|0;p=l+20|0;q=o>>>8&15;do{if((q|0)!=0){if((e[p>>1]|0)>=(g&65535)){break}b[r>>1]=c[a+(q<<2)>>2]&65535;b[p>>1]=g}}while(0);p=k+22|0;q=l+22|0;r=o>>>12&15;do{if((r|0)!=0){if((e[q>>1]|0)>=(g&65535)){break}b[p>>1]=c[a+(r<<2)>>2]&65535;b[q>>1]=g}}while(0);q=k+24|0;r=l+24|0;p=o>>>16&15;do{if((p|0)!=0){if((e[r>>1]|0)>=(g&65535)){break}b[q>>1]=c[a+(p<<2)>>2]&65535;b[r>>1]=g}}while(0);r=k+26|0;p=l+26|0;q=o>>>20&15;do{if((q|0)!=0){if((e[p>>1]|0)>=(g&65535)){break}b[r>>1]=c[a+(q<<2)>>2]&65535;b[p>>1]=g}}while(0);p=k+28|0;q=l+28|0;r=o>>>24&15;do{if((r|0)!=0){if((e[q>>1]|0)>=(g&65535)){break}b[p>>1]=c[a+(r<<2)>>2]&65535;b[q>>1]=g}}while(0);q=k+30|0;r=l+30|0;p=o>>>28;do{if((p|0)!=0){if((e[r>>1]|0)>=(g&65535)){break}b[q>>1]=c[a+(p<<2)>>2]&65535;b[r>>1]=g}}while(0);r=k+32|0;p=l+32|0;q=c[j+4>>2]|0;o=m|q;n=q&15;do{if((n|0)!=0){if((e[p>>1]|0)>=(g&65535)){break}b[r>>1]=c[a+(n<<2)>>2]&65535;b[p>>1]=g}}while(0);p=k+34|0;n=l+34|0;r=q>>>4&15;do{if((r|0)!=0){if((e[n>>1]|0)>=(g&65535)){break}b[p>>1]=c[a+(r<<2)>>2]&65535;b[n>>1]=g}}while(0);n=k+36|0;r=l+36|0;p=q>>>8&15;do{if((p|0)!=0){if((e[r>>1]|0)>=(g&65535)){break}b[n>>1]=c[a+(p<<2)>>2]&65535;b[r>>1]=g}}while(0);r=k+38|0;p=l+38|0;n=q>>>12&15;do{if((n|0)!=0){if((e[p>>1]|0)>=(g&65535)){break}b[r>>1]=c[a+(n<<2)>>2]&65535;b[p>>1]=g}}while(0);p=k+40|0;n=l+40|0;r=q>>>16&15;do{if((r|0)!=0){if((e[n>>1]|0)>=(g&65535)){break}b[p>>1]=c[a+(r<<2)>>2]&65535;b[n>>1]=g}}while(0);n=k+42|0;r=l+42|0;p=q>>>20&15;do{if((p|0)!=0){if((e[r>>1]|0)>=(g&65535)){break}b[n>>1]=c[a+(p<<2)>>2]&65535;b[r>>1]=g}}while(0);r=k+44|0;p=l+44|0;n=q>>>24&15;do{if((n|0)!=0){if((e[p>>1]|0)>=(g&65535)){break}b[r>>1]=c[a+(n<<2)>>2]&65535;b[p>>1]=g}}while(0);p=k+46|0;n=l+46|0;r=q>>>28;do{if((r|0)!=0){if((e[n>>1]|0)>=(g&65535)){break}b[p>>1]=c[a+(r<<2)>>2]&65535;b[n>>1]=g}}while(0);n=k+48|0;r=l+48|0;p=c[j>>2]|0;i=o|p;q=p&15;do{if((q|0)!=0){if((e[r>>1]|0)>=(g&65535)){break}b[n>>1]=c[a+(q<<2)>>2]&65535;b[r>>1]=g}}while(0);r=k+50|0;q=l+50|0;n=p>>>4&15;do{if((n|0)!=0){if((e[q>>1]|0)>=(g&65535)){break}b[r>>1]=c[a+(n<<2)>>2]&65535;b[q>>1]=g}}while(0);q=k+52|0;n=l+52|0;r=p>>>8&15;do{if((r|0)!=0){if((e[n>>1]|0)>=(g&65535)){break}b[q>>1]=c[a+(r<<2)>>2]&65535;b[n>>1]=g}}while(0);n=k+54|0;r=l+54|0;q=p>>>12&15;do{if((q|0)!=0){if((e[r>>1]|0)>=(g&65535)){break}b[n>>1]=c[a+(q<<2)>>2]&65535;b[r>>1]=g}}while(0);r=k+56|0;q=l+56|0;n=p>>>16&15;do{if((n|0)!=0){if((e[q>>1]|0)>=(g&65535)){break}b[r>>1]=c[a+(n<<2)>>2]&65535;b[q>>1]=g}}while(0);q=k+58|0;n=l+58|0;r=p>>>20&15;do{if((r|0)!=0){if((e[n>>1]|0)>=(g&65535)){break}b[q>>1]=c[a+(r<<2)>>2]&65535;b[n>>1]=g}}while(0);n=k+60|0;r=l+60|0;q=p>>>24&15;do{if((q|0)!=0){if((e[r>>1]|0)>=(g&65535)){break}b[n>>1]=c[a+(q<<2)>>2]&65535;b[r>>1]=g}}while(0);r=k+62|0;q=l+62|0;n=p>>>28;do{if((n|0)!=0){if((e[q>>1]|0)>=(g&65535)){break}b[r>>1]=c[a+(n<<2)>>2]&65535;b[q>>1]=g}}while(0);h=h+1|0;k=k+d|0;j=j+f|0;l=l+768|0;}while((h|0)<32);c[2112960]=j;c[2112962]=k;c[2112924]=l;return(i|0)==0|0}function agB(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0;a=c[3541654]|0;d=c[2113228]|0;f=(d&536887296|0)==0;g=b[3726284]|0;h=(d+32767&536887296|0)==0;i=(d+65534&536887296|0)==0;j=(d+98301&536887296|0)==0;k=(d+131068&536887296|0)==0;l=(d+163835&536887296|0)==0;m=(d+196602&536887296|0)==0;n=(d+229369&536887296|0)==0;o=(d+262136&536887296|0)==0;p=(d+294903&536887296|0)==0;q=(d+327670&536887296|0)==0;r=(d+360437&536887296|0)==0;s=(d+393204&536887296|0)==0;t=(d+425971&536887296|0)==0;u=(d+458738&536887296|0)==0;v=(d+491505&536887296|0)==0;w=(d+524272&536887296|0)==0;x=(d+557039&536887296|0)==0;y=(d+589806&536887296|0)==0;z=(d+622573&536887296|0)==0;A=(d+655340&536887296|0)==0;B=(d+688107&536887296|0)==0;C=(d+720874&536887296|0)==0;D=(d+753641&536887296|0)==0;E=(d+786408&536887296|0)==0;F=(d+819175&536887296|0)==0;G=(d+851942&536887296|0)==0;H=(d+884709&536887296|0)==0;I=(d+917476&536887296|0)==0;J=(d+950243&536887296|0)==0;K=(d+983010&536887296|0)==0;L=(d+1015777&536887296|0)==0;d=c[2113300]|0;M=c[2113224]|0;N=1;O=0;P=c[2113226]|0;Q=c[2112962]|0;R=c[2112924]|0;S=c[2112960]|0;while(1){T=P+32767|0;do{if((P&536887296|0)==0){U=c[S>>2]|0;V=U|O;do{if(f&U>>>0>268435455){if((e[R>>1]|0)>=(g&65535)){break}b[Q>>1]=c[a+(U>>>28<<2)>>2]&65535;b[R>>1]=g}}while(0);W=Q+2|0;X=R+2|0;do{if(h){if(U<<4>>>0<=268435455){break}if((e[X>>1]|0)>=(g&65535)){break}b[W>>1]=c[a+((U>>>24&15)<<2)>>2]&65535;b[X>>1]=g}}while(0);X=Q+4|0;W=R+4|0;do{if(i){if(U<<8>>>0<=268435455){break}if((e[W>>1]|0)>=(g&65535)){break}b[X>>1]=c[a+((U>>>20&15)<<2)>>2]&65535;b[W>>1]=g}}while(0);W=Q+6|0;X=R+6|0;do{if(j){if(U<<12>>>0<=268435455){break}if((e[X>>1]|0)>=(g&65535)){break}b[W>>1]=c[a+((U>>>16&15)<<2)>>2]&65535;b[X>>1]=g}}while(0);X=Q+8|0;W=R+8|0;do{if(k){if(U<<16>>>0<=268435455){break}if((e[W>>1]|0)>=(g&65535)){break}b[X>>1]=c[a+((U>>>12&15)<<2)>>2]&65535;b[W>>1]=g}}while(0);W=Q+10|0;X=R+10|0;do{if(l){if(U<<20>>>0<=268435455){break}if((e[X>>1]|0)>=(g&65535)){break}b[W>>1]=c[a+((U>>>8&15)<<2)>>2]&65535;b[X>>1]=g}}while(0);X=Q+12|0;W=R+12|0;do{if(m){if(U<<24>>>0<=268435455){break}if((e[W>>1]|0)>=(g&65535)){break}b[X>>1]=c[a+((U>>>4&15)<<2)>>2]&65535;b[W>>1]=g}}while(0);W=Q+14|0;X=R+14|0;do{if(n){Y=U&15;if((Y|0)==0){break}if((e[X>>1]|0)>=(g&65535)){break}b[W>>1]=c[a+(Y<<2)>>2]&65535;b[X>>1]=g}}while(0);X=Q+16|0;W=R+16|0;U=c[S+4>>2]|0;Y=V|U;do{if(o&U>>>0>268435455){if((e[W>>1]|0)>=(g&65535)){break}b[X>>1]=c[a+(U>>>28<<2)>>2]&65535;b[W>>1]=g}}while(0);W=Q+18|0;X=R+18|0;do{if(p){if(U<<4>>>0<=268435455){break}if((e[X>>1]|0)>=(g&65535)){break}b[W>>1]=c[a+((U>>>24&15)<<2)>>2]&65535;b[X>>1]=g}}while(0);X=Q+20|0;W=R+20|0;do{if(q){if(U<<8>>>0<=268435455){break}if((e[W>>1]|0)>=(g&65535)){break}b[X>>1]=c[a+((U>>>20&15)<<2)>>2]&65535;b[W>>1]=g}}while(0);W=Q+22|0;X=R+22|0;do{if(r){if(U<<12>>>0<=268435455){break}if((e[X>>1]|0)>=(g&65535)){break}b[W>>1]=c[a+((U>>>16&15)<<2)>>2]&65535;b[X>>1]=g}}while(0);X=Q+24|0;W=R+24|0;do{if(s){if(U<<16>>>0<=268435455){break}if((e[W>>1]|0)>=(g&65535)){break}b[X>>1]=c[a+((U>>>12&15)<<2)>>2]&65535;b[W>>1]=g}}while(0);W=Q+26|0;X=R+26|0;do{if(t){if(U<<20>>>0<=268435455){break}if((e[X>>1]|0)>=(g&65535)){break}b[W>>1]=c[a+((U>>>8&15)<<2)>>2]&65535;b[X>>1]=g}}while(0);X=Q+28|0;W=R+28|0;do{if(u){if(U<<24>>>0<=268435455){break}if((e[W>>1]|0)>=(g&65535)){break}b[X>>1]=c[a+((U>>>4&15)<<2)>>2]&65535;b[W>>1]=g}}while(0);W=Q+30|0;X=R+30|0;do{if(v){V=U&15;if((V|0)==0){break}if((e[X>>1]|0)>=(g&65535)){break}b[W>>1]=c[a+(V<<2)>>2]&65535;b[X>>1]=g}}while(0);X=Q+32|0;W=R+32|0;U=c[S+8>>2]|0;V=Y|U;do{if(w&U>>>0>268435455){if((e[W>>1]|0)>=(g&65535)){break}b[X>>1]=c[a+(U>>>28<<2)>>2]&65535;b[W>>1]=g}}while(0);W=Q+34|0;X=R+34|0;do{if(x){if(U<<4>>>0<=268435455){break}if((e[X>>1]|0)>=(g&65535)){break}b[W>>1]=c[a+((U>>>24&15)<<2)>>2]&65535;b[X>>1]=g}}while(0);X=Q+36|0;W=R+36|0;do{if(y){if(U<<8>>>0<=268435455){break}if((e[W>>1]|0)>=(g&65535)){break}b[X>>1]=c[a+((U>>>20&15)<<2)>>2]&65535;b[W>>1]=g}}while(0);W=Q+38|0;X=R+38|0;do{if(z){if(U<<12>>>0<=268435455){break}if((e[X>>1]|0)>=(g&65535)){break}b[W>>1]=c[a+((U>>>16&15)<<2)>>2]&65535;b[X>>1]=g}}while(0);X=Q+40|0;W=R+40|0;do{if(A){if(U<<16>>>0<=268435455){break}if((e[W>>1]|0)>=(g&65535)){break}b[X>>1]=c[a+((U>>>12&15)<<2)>>2]&65535;b[W>>1]=g}}while(0);W=Q+42|0;X=R+42|0;do{if(B){if(U<<20>>>0<=268435455){break}if((e[X>>1]|0)>=(g&65535)){break}b[W>>1]=c[a+((U>>>8&15)<<2)>>2]&65535;b[X>>1]=g}}while(0);X=Q+44|0;W=R+44|0;do{if(C){if(U<<24>>>0<=268435455){break}if((e[W>>1]|0)>=(g&65535)){break}b[X>>1]=c[a+((U>>>4&15)<<2)>>2]&65535;b[W>>1]=g}}while(0);W=Q+46|0;X=R+46|0;do{if(D){Y=U&15;if((Y|0)==0){break}if((e[X>>1]|0)>=(g&65535)){break}b[W>>1]=c[a+(Y<<2)>>2]&65535;b[X>>1]=g}}while(0);X=Q+48|0;W=R+48|0;U=c[S+12>>2]|0;Y=V|U;do{if(E&U>>>0>268435455){if((e[W>>1]|0)>=(g&65535)){break}b[X>>1]=c[a+(U>>>28<<2)>>2]&65535;b[W>>1]=g}}while(0);W=Q+50|0;X=R+50|0;do{if(F){if(U<<4>>>0<=268435455){break}if((e[X>>1]|0)>=(g&65535)){break}b[W>>1]=c[a+((U>>>24&15)<<2)>>2]&65535;b[X>>1]=g}}while(0);X=Q+52|0;W=R+52|0;do{if(G){if(U<<8>>>0<=268435455){break}if((e[W>>1]|0)>=(g&65535)){break}b[X>>1]=c[a+((U>>>20&15)<<2)>>2]&65535;b[W>>1]=g}}while(0);W=Q+54|0;X=R+54|0;do{if(H){if(U<<12>>>0<=268435455){break}if((e[X>>1]|0)>=(g&65535)){break}b[W>>1]=c[a+((U>>>16&15)<<2)>>2]&65535;b[X>>1]=g}}while(0);X=Q+56|0;W=R+56|0;do{if(I){if(U<<16>>>0<=268435455){break}if((e[W>>1]|0)>=(g&65535)){break}b[X>>1]=c[a+((U>>>12&15)<<2)>>2]&65535;b[W>>1]=g}}while(0);W=Q+58|0;X=R+58|0;do{if(J){if(U<<20>>>0<=268435455){break}if((e[X>>1]|0)>=(g&65535)){break}b[W>>1]=c[a+((U>>>8&15)<<2)>>2]&65535;b[X>>1]=g}}while(0);X=Q+60|0;W=R+60|0;do{if(K){if(U<<24>>>0<=268435455){break}if((e[W>>1]|0)>=(g&65535)){break}b[X>>1]=c[a+((U>>>4&15)<<2)>>2]&65535;b[W>>1]=g}}while(0);W=R+62|0;if(!L){Z=Y;break}X=U&15;if((X|0)==0){Z=Y;break}if((e[W>>1]|0)>=(g&65535)){Z=Y;break}b[Q+62>>1]=c[a+(X<<2)>>2]&65535;b[W>>1]=g;Z=Y}else{Z=O}}while(0);_=Q+d|0;$=S+M|0;aa=R+768|0;if((N|0)>=32){break}N=N+1|0;O=Z;P=T;Q=_;R=aa;S=$}c[2113226]=T;c[2112962]=_;c[2112924]=aa;c[2112960]=$;return(Z|0)==0|0}function agC(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0;a=c[3541654]|0;d=c[2113228]|0;f=(d&536887296|0)==0;g=b[3726284]|0;h=(d+32767&536887296|0)==0;i=(d+65534&536887296|0)==0;j=(d+98301&536887296|0)==0;k=(d+131068&536887296|0)==0;l=(d+163835&536887296|0)==0;m=(d+196602&536887296|0)==0;n=(d+229369&536887296|0)==0;o=(d+262136&536887296|0)==0;p=(d+294903&536887296|0)==0;q=(d+327670&536887296|0)==0;r=(d+360437&536887296|0)==0;s=(d+393204&536887296|0)==0;t=(d+425971&536887296|0)==0;u=(d+458738&536887296|0)==0;v=(d+491505&536887296|0)==0;w=(d+524272&536887296|0)==0;x=(d+557039&536887296|0)==0;y=(d+589806&536887296|0)==0;z=(d+622573&536887296|0)==0;A=(d+655340&536887296|0)==0;B=(d+688107&536887296|0)==0;C=(d+720874&536887296|0)==0;D=(d+753641&536887296|0)==0;E=(d+786408&536887296|0)==0;F=(d+819175&536887296|0)==0;G=(d+851942&536887296|0)==0;H=(d+884709&536887296|0)==0;I=(d+917476&536887296|0)==0;J=(d+950243&536887296|0)==0;K=(d+983010&536887296|0)==0;L=(d+1015777&536887296|0)==0;d=c[2113300]|0;M=c[2113224]|0;N=1;O=0;P=c[2113226]|0;Q=c[2112962]|0;R=c[2112924]|0;S=c[2112960]|0;while(1){T=P+32767|0;do{if((P&536887296|0)==0){U=c[S+12>>2]|0;V=U|O;do{if(f){W=U&15;if((W|0)==0){break}if((e[R>>1]|0)>=(g&65535)){break}b[Q>>1]=c[a+(W<<2)>>2]&65535;b[R>>1]=g}}while(0);W=Q+2|0;X=R+2|0;do{if(h){Y=U>>>4&15;if((Y|0)==0){break}if((e[X>>1]|0)>=(g&65535)){break}b[W>>1]=c[a+(Y<<2)>>2]&65535;b[X>>1]=g}}while(0);X=Q+4|0;W=R+4|0;do{if(i){Y=U>>>8&15;if((Y|0)==0){break}if((e[W>>1]|0)>=(g&65535)){break}b[X>>1]=c[a+(Y<<2)>>2]&65535;b[W>>1]=g}}while(0);W=Q+6|0;X=R+6|0;do{if(j){Y=U>>>12&15;if((Y|0)==0){break}if((e[X>>1]|0)>=(g&65535)){break}b[W>>1]=c[a+(Y<<2)>>2]&65535;b[X>>1]=g}}while(0);X=Q+8|0;W=R+8|0;do{if(k){Y=U>>>16&15;if((Y|0)==0){break}if((e[W>>1]|0)>=(g&65535)){break}b[X>>1]=c[a+(Y<<2)>>2]&65535;b[W>>1]=g}}while(0);W=Q+10|0;X=R+10|0;do{if(l){Y=U>>>20&15;if((Y|0)==0){break}if((e[X>>1]|0)>=(g&65535)){break}b[W>>1]=c[a+(Y<<2)>>2]&65535;b[X>>1]=g}}while(0);X=Q+12|0;W=R+12|0;do{if(m){Y=U>>>24&15;if((Y|0)==0){break}if((e[W>>1]|0)>=(g&65535)){break}b[X>>1]=c[a+(Y<<2)>>2]&65535;b[W>>1]=g}}while(0);W=Q+14|0;X=R+14|0;do{if(n){Y=U>>>28;if((Y|0)==0){break}if((e[X>>1]|0)>=(g&65535)){break}b[W>>1]=c[a+(Y<<2)>>2]&65535;b[X>>1]=g}}while(0);X=Q+16|0;W=R+16|0;U=c[S+8>>2]|0;Y=V|U;do{if(o){Z=U&15;if((Z|0)==0){break}if((e[W>>1]|0)>=(g&65535)){break}b[X>>1]=c[a+(Z<<2)>>2]&65535;b[W>>1]=g}}while(0);W=Q+18|0;X=R+18|0;do{if(p){V=U>>>4&15;if((V|0)==0){break}if((e[X>>1]|0)>=(g&65535)){break}b[W>>1]=c[a+(V<<2)>>2]&65535;b[X>>1]=g}}while(0);X=Q+20|0;W=R+20|0;do{if(q){V=U>>>8&15;if((V|0)==0){break}if((e[W>>1]|0)>=(g&65535)){break}b[X>>1]=c[a+(V<<2)>>2]&65535;b[W>>1]=g}}while(0);W=Q+22|0;X=R+22|0;do{if(r){V=U>>>12&15;if((V|0)==0){break}if((e[X>>1]|0)>=(g&65535)){break}b[W>>1]=c[a+(V<<2)>>2]&65535;b[X>>1]=g}}while(0);X=Q+24|0;W=R+24|0;do{if(s){V=U>>>16&15;if((V|0)==0){break}if((e[W>>1]|0)>=(g&65535)){break}b[X>>1]=c[a+(V<<2)>>2]&65535;b[W>>1]=g}}while(0);W=Q+26|0;X=R+26|0;do{if(t){V=U>>>20&15;if((V|0)==0){break}if((e[X>>1]|0)>=(g&65535)){break}b[W>>1]=c[a+(V<<2)>>2]&65535;b[X>>1]=g}}while(0);X=Q+28|0;W=R+28|0;do{if(u){V=U>>>24&15;if((V|0)==0){break}if((e[W>>1]|0)>=(g&65535)){break}b[X>>1]=c[a+(V<<2)>>2]&65535;b[W>>1]=g}}while(0);W=Q+30|0;X=R+30|0;do{if(v){V=U>>>28;if((V|0)==0){break}if((e[X>>1]|0)>=(g&65535)){break}b[W>>1]=c[a+(V<<2)>>2]&65535;b[X>>1]=g}}while(0);X=Q+32|0;W=R+32|0;U=c[S+4>>2]|0;V=Y|U;do{if(w){Z=U&15;if((Z|0)==0){break}if((e[W>>1]|0)>=(g&65535)){break}b[X>>1]=c[a+(Z<<2)>>2]&65535;b[W>>1]=g}}while(0);W=Q+34|0;X=R+34|0;do{if(x){Y=U>>>4&15;if((Y|0)==0){break}if((e[X>>1]|0)>=(g&65535)){break}b[W>>1]=c[a+(Y<<2)>>2]&65535;b[X>>1]=g}}while(0);X=Q+36|0;W=R+36|0;do{if(y){Y=U>>>8&15;if((Y|0)==0){break}if((e[W>>1]|0)>=(g&65535)){break}b[X>>1]=c[a+(Y<<2)>>2]&65535;b[W>>1]=g}}while(0);W=Q+38|0;X=R+38|0;do{if(z){Y=U>>>12&15;if((Y|0)==0){break}if((e[X>>1]|0)>=(g&65535)){break}b[W>>1]=c[a+(Y<<2)>>2]&65535;b[X>>1]=g}}while(0);X=Q+40|0;W=R+40|0;do{if(A){Y=U>>>16&15;if((Y|0)==0){break}if((e[W>>1]|0)>=(g&65535)){break}b[X>>1]=c[a+(Y<<2)>>2]&65535;b[W>>1]=g}}while(0);W=Q+42|0;X=R+42|0;do{if(B){Y=U>>>20&15;if((Y|0)==0){break}if((e[X>>1]|0)>=(g&65535)){break}b[W>>1]=c[a+(Y<<2)>>2]&65535;b[X>>1]=g}}while(0);X=Q+44|0;W=R+44|0;do{if(C){Y=U>>>24&15;if((Y|0)==0){break}if((e[W>>1]|0)>=(g&65535)){break}b[X>>1]=c[a+(Y<<2)>>2]&65535;b[W>>1]=g}}while(0);W=Q+46|0;X=R+46|0;do{if(D){Y=U>>>28;if((Y|0)==0){break}if((e[X>>1]|0)>=(g&65535)){break}b[W>>1]=c[a+(Y<<2)>>2]&65535;b[X>>1]=g}}while(0);X=Q+48|0;W=R+48|0;U=c[S>>2]|0;Y=V|U;do{if(E){Z=U&15;if((Z|0)==0){break}if((e[W>>1]|0)>=(g&65535)){break}b[X>>1]=c[a+(Z<<2)>>2]&65535;b[W>>1]=g}}while(0);W=Q+50|0;X=R+50|0;do{if(F){V=U>>>4&15;if((V|0)==0){break}if((e[X>>1]|0)>=(g&65535)){break}b[W>>1]=c[a+(V<<2)>>2]&65535;b[X>>1]=g}}while(0);X=Q+52|0;W=R+52|0;do{if(G){V=U>>>8&15;if((V|0)==0){break}if((e[W>>1]|0)>=(g&65535)){break}b[X>>1]=c[a+(V<<2)>>2]&65535;b[W>>1]=g}}while(0);W=Q+54|0;X=R+54|0;do{if(H){V=U>>>12&15;if((V|0)==0){break}if((e[X>>1]|0)>=(g&65535)){break}b[W>>1]=c[a+(V<<2)>>2]&65535;b[X>>1]=g}}while(0);X=Q+56|0;W=R+56|0;do{if(I){V=U>>>16&15;if((V|0)==0){break}if((e[W>>1]|0)>=(g&65535)){break}b[X>>1]=c[a+(V<<2)>>2]&65535;b[W>>1]=g}}while(0);W=Q+58|0;X=R+58|0;do{if(J){V=U>>>20&15;if((V|0)==0){break}if((e[X>>1]|0)>=(g&65535)){break}b[W>>1]=c[a+(V<<2)>>2]&65535;b[X>>1]=g}}while(0);X=Q+60|0;W=R+60|0;do{if(K){V=U>>>24&15;if((V|0)==0){break}if((e[W>>1]|0)>=(g&65535)){break}b[X>>1]=c[a+(V<<2)>>2]&65535;b[W>>1]=g}}while(0);W=R+62|0;if(!L){_=Y;break}X=U>>>28;if((X|0)==0){_=Y;break}if((e[W>>1]|0)>=(g&65535)){_=Y;break}b[Q+62>>1]=c[a+(X<<2)>>2]&65535;b[W>>1]=g;_=Y}else{_=O}}while(0);$=Q+d|0;aa=S+M|0;ab=R+768|0;if((N|0)>=32){break}N=N+1|0;O=_;P=T;Q=$;R=ab;S=aa}c[2113226]=T;c[2112962]=$;c[2112924]=ab;c[2112960]=aa;return(_|0)==0|0}function agD(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[3541654]|0;d=c[2113300]|0;e=c[2113224]|0;f=0;g=0;h=c[2112962]|0;i=c[2112960]|0;do{j=c[i>>2]|0;g=j|g;if(j>>>0>268435455){b[h>>1]=c[a+(j>>>28<<2)>>2]&65535}if(j<<4>>>0>268435455){b[h+2>>1]=c[a+((j>>>24&15)<<2)>>2]&65535}if(j<<8>>>0>268435455){b[h+4>>1]=c[a+((j>>>20&15)<<2)>>2]&65535}if(j<<12>>>0>268435455){b[h+6>>1]=c[a+((j>>>16&15)<<2)>>2]&65535}if(j<<16>>>0>268435455){b[h+8>>1]=c[a+((j>>>12&15)<<2)>>2]&65535}if(j<<20>>>0>268435455){b[h+10>>1]=c[a+((j>>>8&15)<<2)>>2]&65535}if(j<<24>>>0>268435455){b[h+12>>1]=c[a+((j>>>4&15)<<2)>>2]&65535}k=j&15;if((k|0)!=0){b[h+14>>1]=c[a+(k<<2)>>2]&65535}f=f+1|0;h=h+d|0;i=i+e|0;}while((f|0)<8);c[2112962]=h;c[2112960]=i;return(g|0)==0|0}function agE(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[3541654]|0;d=c[2113300]|0;e=c[2113224]|0;f=0;g=0;h=c[2112962]|0;i=c[2112960]|0;do{j=c[i>>2]|0;g=j|g;k=j&15;if((k|0)!=0){b[h>>1]=c[a+(k<<2)>>2]&65535}k=j>>>4&15;if((k|0)!=0){b[h+2>>1]=c[a+(k<<2)>>2]&65535}k=j>>>8&15;if((k|0)!=0){b[h+4>>1]=c[a+(k<<2)>>2]&65535}k=j>>>12&15;if((k|0)!=0){b[h+6>>1]=c[a+(k<<2)>>2]&65535}k=j>>>16&15;if((k|0)!=0){b[h+8>>1]=c[a+(k<<2)>>2]&65535}k=j>>>20&15;if((k|0)!=0){b[h+10>>1]=c[a+(k<<2)>>2]&65535}k=j>>>24&15;if((k|0)!=0){b[h+12>>1]=c[a+(k<<2)>>2]&65535}k=j>>>28;if((k|0)!=0){b[h+14>>1]=c[a+(k<<2)>>2]&65535}f=f+1|0;h=h+d|0;i=i+e|0;}while((f|0)<8);c[2112962]=h;c[2112960]=i;return(g|0)==0|0}function agF(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;a=c[3541654]|0;d=c[2113228]|0;e=(d&536887296|0)==0;f=(d+32767&536887296|0)==0;g=(d+65534&536887296|0)==0;h=(d+98301&536887296|0)==0;i=(d+131068&536887296|0)==0;j=(d+163835&536887296|0)==0;k=(d+196602&536887296|0)==0;l=(d+229369&536887296|0)==0;d=c[2113300]|0;m=c[2113224]|0;n=1;o=0;p=c[2113226]|0;q=c[2112962]|0;r=c[2112960]|0;while(1){s=p+32767|0;do{if((p&536887296|0)==0){t=c[r>>2]|0;u=t|o;if(e&t>>>0>268435455){b[q>>1]=c[a+(t>>>28<<2)>>2]&65535}v=q+2|0;do{if(f){if(t<<4>>>0<=268435455){break}b[v>>1]=c[a+((t>>>24&15)<<2)>>2]&65535}}while(0);v=q+4|0;do{if(g){if(t<<8>>>0<=268435455){break}b[v>>1]=c[a+((t>>>20&15)<<2)>>2]&65535}}while(0);v=q+6|0;do{if(h){if(t<<12>>>0<=268435455){break}b[v>>1]=c[a+((t>>>16&15)<<2)>>2]&65535}}while(0);v=q+8|0;do{if(i){if(t<<16>>>0<=268435455){break}b[v>>1]=c[a+((t>>>12&15)<<2)>>2]&65535}}while(0);v=q+10|0;do{if(j){if(t<<20>>>0<=268435455){break}b[v>>1]=c[a+((t>>>8&15)<<2)>>2]&65535}}while(0);v=q+12|0;do{if(k){if(t<<24>>>0<=268435455){break}b[v>>1]=c[a+((t>>>4&15)<<2)>>2]&65535}}while(0);if(!l){w=u;break}v=t&15;if((v|0)==0){w=u;break}b[q+14>>1]=c[a+(v<<2)>>2]&65535;w=u}else{w=o}}while(0);x=q+d|0;y=r+m|0;if((n|0)>=8){break}n=n+1|0;o=w;p=s;q=x;r=y}c[2113226]=s;c[2112962]=x;c[2112960]=y;return(w|0)==0|0}function agG(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;a=c[3541654]|0;d=c[2113228]|0;e=(d&536887296|0)==0;f=(d+32767&536887296|0)==0;g=(d+65534&536887296|0)==0;h=(d+98301&536887296|0)==0;i=(d+131068&536887296|0)==0;j=(d+163835&536887296|0)==0;k=(d+196602&536887296|0)==0;l=(d+229369&536887296|0)==0;d=c[2113300]|0;m=c[2113224]|0;n=1;o=0;p=c[2113226]|0;q=c[2112962]|0;r=c[2112960]|0;while(1){s=p+32767|0;do{if((p&536887296|0)==0){t=c[r>>2]|0;u=t|o;do{if(e){v=t&15;if((v|0)==0){break}b[q>>1]=c[a+(v<<2)>>2]&65535}}while(0);v=q+2|0;do{if(f){w=t>>>4&15;if((w|0)==0){break}b[v>>1]=c[a+(w<<2)>>2]&65535}}while(0);v=q+4|0;do{if(g){w=t>>>8&15;if((w|0)==0){break}b[v>>1]=c[a+(w<<2)>>2]&65535}}while(0);v=q+6|0;do{if(h){w=t>>>12&15;if((w|0)==0){break}b[v>>1]=c[a+(w<<2)>>2]&65535}}while(0);v=q+8|0;do{if(i){w=t>>>16&15;if((w|0)==0){break}b[v>>1]=c[a+(w<<2)>>2]&65535}}while(0);v=q+10|0;do{if(j){w=t>>>20&15;if((w|0)==0){break}b[v>>1]=c[a+(w<<2)>>2]&65535}}while(0);v=q+12|0;do{if(k){w=t>>>24&15;if((w|0)==0){break}b[v>>1]=c[a+(w<<2)>>2]&65535}}while(0);if(!l){x=u;break}v=t>>>28;if((v|0)==0){x=u;break}b[q+14>>1]=c[a+(v<<2)>>2]&65535;x=u}else{x=o}}while(0);y=q+d|0;z=r+m|0;if((n|0)>=8){break}n=n+1|0;o=x;p=s;q=y;r=z}c[2113226]=s;c[2112962]=y;c[2112960]=z;return(x|0)==0|0}function agH(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[3541654]|0;d=c[2113300]|0;e=c[2113224]|0;f=0;g=0;h=c[2112960]|0;i=c[2112962]|0;do{j=c[h>>2]|0;if(j>>>0>268435455){b[i>>1]=c[a+(j>>>28<<2)>>2]&65535}if(j<<4>>>0>268435455){b[i+2>>1]=c[a+((j>>>24&15)<<2)>>2]&65535}if(j<<8>>>0>268435455){b[i+4>>1]=c[a+((j>>>20&15)<<2)>>2]&65535}if(j<<12>>>0>268435455){b[i+6>>1]=c[a+((j>>>16&15)<<2)>>2]&65535}if(j<<16>>>0>268435455){b[i+8>>1]=c[a+((j>>>12&15)<<2)>>2]&65535}if(j<<20>>>0>268435455){b[i+10>>1]=c[a+((j>>>8&15)<<2)>>2]&65535}if(j<<24>>>0>268435455){b[i+12>>1]=c[a+((j>>>4&15)<<2)>>2]&65535}k=j&15;if((k|0)!=0){b[i+14>>1]=c[a+(k<<2)>>2]&65535}k=c[h+4>>2]|0;g=j|g|k;if(k>>>0>268435455){b[i+16>>1]=c[a+(k>>>28<<2)>>2]&65535}if(k<<4>>>0>268435455){b[i+18>>1]=c[a+((k>>>24&15)<<2)>>2]&65535}if(k<<8>>>0>268435455){b[i+20>>1]=c[a+((k>>>20&15)<<2)>>2]&65535}if(k<<12>>>0>268435455){b[i+22>>1]=c[a+((k>>>16&15)<<2)>>2]&65535}if(k<<16>>>0>268435455){b[i+24>>1]=c[a+((k>>>12&15)<<2)>>2]&65535}if(k<<20>>>0>268435455){b[i+26>>1]=c[a+((k>>>8&15)<<2)>>2]&65535}if(k<<24>>>0>268435455){b[i+28>>1]=c[a+((k>>>4&15)<<2)>>2]&65535}j=k&15;if((j|0)!=0){b[i+30>>1]=c[a+(j<<2)>>2]&65535}f=f+1|0;i=i+d|0;h=h+e|0;}while((f|0)<16);c[2112960]=h;c[2112962]=i;return(g|0)==0|0}function agI(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[3541654]|0;d=c[2113300]|0;e=c[2113224]|0;f=0;g=0;h=c[2112960]|0;i=c[2112962]|0;do{j=c[h+4>>2]|0;k=j&15;if((k|0)!=0){b[i>>1]=c[a+(k<<2)>>2]&65535}k=j>>>4&15;if((k|0)!=0){b[i+2>>1]=c[a+(k<<2)>>2]&65535}k=j>>>8&15;if((k|0)!=0){b[i+4>>1]=c[a+(k<<2)>>2]&65535}k=j>>>12&15;if((k|0)!=0){b[i+6>>1]=c[a+(k<<2)>>2]&65535}k=j>>>16&15;if((k|0)!=0){b[i+8>>1]=c[a+(k<<2)>>2]&65535}k=j>>>20&15;if((k|0)!=0){b[i+10>>1]=c[a+(k<<2)>>2]&65535}k=j>>>24&15;if((k|0)!=0){b[i+12>>1]=c[a+(k<<2)>>2]&65535}k=j>>>28;if((k|0)!=0){b[i+14>>1]=c[a+(k<<2)>>2]&65535}k=c[h>>2]|0;g=j|g|k;j=k&15;if((j|0)!=0){b[i+16>>1]=c[a+(j<<2)>>2]&65535}j=k>>>4&15;if((j|0)!=0){b[i+18>>1]=c[a+(j<<2)>>2]&65535}j=k>>>8&15;if((j|0)!=0){b[i+20>>1]=c[a+(j<<2)>>2]&65535}j=k>>>12&15;if((j|0)!=0){b[i+22>>1]=c[a+(j<<2)>>2]&65535}j=k>>>16&15;if((j|0)!=0){b[i+24>>1]=c[a+(j<<2)>>2]&65535}j=k>>>20&15;if((j|0)!=0){b[i+26>>1]=c[a+(j<<2)>>2]&65535}j=k>>>24&15;if((j|0)!=0){b[i+28>>1]=c[a+(j<<2)>>2]&65535}j=k>>>28;if((j|0)!=0){b[i+30>>1]=c[a+(j<<2)>>2]&65535}f=f+1|0;i=i+d|0;h=h+e|0;}while((f|0)<16);c[2112960]=h;c[2112962]=i;return(g|0)==0|0}function agJ(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;a=c[3541654]|0;d=c[2113228]|0;e=(d&536887296|0)==0;f=(d+32767&536887296|0)==0;g=(d+65534&536887296|0)==0;h=(d+98301&536887296|0)==0;i=(d+131068&536887296|0)==0;j=(d+163835&536887296|0)==0;k=(d+196602&536887296|0)==0;l=(d+229369&536887296|0)==0;m=(d+262136&536887296|0)==0;n=(d+294903&536887296|0)==0;o=(d+327670&536887296|0)==0;p=(d+360437&536887296|0)==0;q=(d+393204&536887296|0)==0;r=(d+425971&536887296|0)==0;s=(d+458738&536887296|0)==0;t=(d+491505&536887296|0)==0;d=c[2113300]|0;u=c[2113224]|0;v=1;w=0;x=c[2113226]|0;y=c[2112962]|0;z=c[2112960]|0;while(1){A=x+32767|0;do{if((x&536887296|0)==0){B=c[z>>2]|0;C=B|w;if(e&B>>>0>268435455){b[y>>1]=c[a+(B>>>28<<2)>>2]&65535}D=y+2|0;do{if(f){if(B<<4>>>0<=268435455){break}b[D>>1]=c[a+((B>>>24&15)<<2)>>2]&65535}}while(0);D=y+4|0;do{if(g){if(B<<8>>>0<=268435455){break}b[D>>1]=c[a+((B>>>20&15)<<2)>>2]&65535}}while(0);D=y+6|0;do{if(h){if(B<<12>>>0<=268435455){break}b[D>>1]=c[a+((B>>>16&15)<<2)>>2]&65535}}while(0);D=y+8|0;do{if(i){if(B<<16>>>0<=268435455){break}b[D>>1]=c[a+((B>>>12&15)<<2)>>2]&65535}}while(0);D=y+10|0;do{if(j){if(B<<20>>>0<=268435455){break}b[D>>1]=c[a+((B>>>8&15)<<2)>>2]&65535}}while(0);D=y+12|0;do{if(k){if(B<<24>>>0<=268435455){break}b[D>>1]=c[a+((B>>>4&15)<<2)>>2]&65535}}while(0);D=y+14|0;do{if(l){E=B&15;if((E|0)==0){break}b[D>>1]=c[a+(E<<2)>>2]&65535}}while(0);D=c[z+4>>2]|0;B=C|D;if(m&D>>>0>268435455){b[y+16>>1]=c[a+(D>>>28<<2)>>2]&65535}E=y+18|0;do{if(n){if(D<<4>>>0<=268435455){break}b[E>>1]=c[a+((D>>>24&15)<<2)>>2]&65535}}while(0);E=y+20|0;do{if(o){if(D<<8>>>0<=268435455){break}b[E>>1]=c[a+((D>>>20&15)<<2)>>2]&65535}}while(0);E=y+22|0;do{if(p){if(D<<12>>>0<=268435455){break}b[E>>1]=c[a+((D>>>16&15)<<2)>>2]&65535}}while(0);E=y+24|0;do{if(q){if(D<<16>>>0<=268435455){break}b[E>>1]=c[a+((D>>>12&15)<<2)>>2]&65535}}while(0);E=y+26|0;do{if(r){if(D<<20>>>0<=268435455){break}b[E>>1]=c[a+((D>>>8&15)<<2)>>2]&65535}}while(0);E=y+28|0;do{if(s){if(D<<24>>>0<=268435455){break}b[E>>1]=c[a+((D>>>4&15)<<2)>>2]&65535}}while(0);if(!t){F=B;break}E=D&15;if((E|0)==0){F=B;break}b[y+30>>1]=c[a+(E<<2)>>2]&65535;F=B}else{F=w}}while(0);G=y+d|0;H=z+u|0;if((v|0)>=16){break}v=v+1|0;w=F;x=A;y=G;z=H}c[2113226]=A;c[2112962]=G;c[2112960]=H;return(F|0)==0|0}function agK(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;a=c[3541654]|0;d=c[2113228]|0;e=(d&536887296|0)==0;f=(d+32767&536887296|0)==0;g=(d+65534&536887296|0)==0;h=(d+98301&536887296|0)==0;i=(d+131068&536887296|0)==0;j=(d+163835&536887296|0)==0;k=(d+196602&536887296|0)==0;l=(d+229369&536887296|0)==0;m=(d+262136&536887296|0)==0;n=(d+294903&536887296|0)==0;o=(d+327670&536887296|0)==0;p=(d+360437&536887296|0)==0;q=(d+393204&536887296|0)==0;r=(d+425971&536887296|0)==0;s=(d+458738&536887296|0)==0;t=(d+491505&536887296|0)==0;d=c[2113300]|0;u=c[2113224]|0;v=1;w=0;x=c[2113226]|0;y=c[2112962]|0;z=c[2112960]|0;while(1){A=x+32767|0;do{if((x&536887296|0)==0){B=c[z+4>>2]|0;C=B|w;do{if(e){D=B&15;if((D|0)==0){break}b[y>>1]=c[a+(D<<2)>>2]&65535}}while(0);D=y+2|0;do{if(f){E=B>>>4&15;if((E|0)==0){break}b[D>>1]=c[a+(E<<2)>>2]&65535}}while(0);D=y+4|0;do{if(g){E=B>>>8&15;if((E|0)==0){break}b[D>>1]=c[a+(E<<2)>>2]&65535}}while(0);D=y+6|0;do{if(h){E=B>>>12&15;if((E|0)==0){break}b[D>>1]=c[a+(E<<2)>>2]&65535}}while(0);D=y+8|0;do{if(i){E=B>>>16&15;if((E|0)==0){break}b[D>>1]=c[a+(E<<2)>>2]&65535}}while(0);D=y+10|0;do{if(j){E=B>>>20&15;if((E|0)==0){break}b[D>>1]=c[a+(E<<2)>>2]&65535}}while(0);D=y+12|0;do{if(k){E=B>>>24&15;if((E|0)==0){break}b[D>>1]=c[a+(E<<2)>>2]&65535}}while(0);D=y+14|0;do{if(l){E=B>>>28;if((E|0)==0){break}b[D>>1]=c[a+(E<<2)>>2]&65535}}while(0);D=y+16|0;B=c[z>>2]|0;E=C|B;do{if(m){F=B&15;if((F|0)==0){break}b[D>>1]=c[a+(F<<2)>>2]&65535}}while(0);D=y+18|0;do{if(n){C=B>>>4&15;if((C|0)==0){break}b[D>>1]=c[a+(C<<2)>>2]&65535}}while(0);D=y+20|0;do{if(o){C=B>>>8&15;if((C|0)==0){break}b[D>>1]=c[a+(C<<2)>>2]&65535}}while(0);D=y+22|0;do{if(p){C=B>>>12&15;if((C|0)==0){break}b[D>>1]=c[a+(C<<2)>>2]&65535}}while(0);D=y+24|0;do{if(q){C=B>>>16&15;if((C|0)==0){break}b[D>>1]=c[a+(C<<2)>>2]&65535}}while(0);D=y+26|0;do{if(r){C=B>>>20&15;if((C|0)==0){break}b[D>>1]=c[a+(C<<2)>>2]&65535}}while(0);D=y+28|0;do{if(s){C=B>>>24&15;if((C|0)==0){break}b[D>>1]=c[a+(C<<2)>>2]&65535}}while(0);if(!t){G=E;break}D=B>>>28;if((D|0)==0){G=E;break}b[y+30>>1]=c[a+(D<<2)>>2]&65535;G=E}else{G=w}}while(0);H=y+d|0;I=z+u|0;if((v|0)>=16){break}v=v+1|0;w=G;x=A;y=H;z=I}c[2113226]=A;c[2112962]=H;c[2112960]=I;return(G|0)==0|0}function agL(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;a=c[3541654]|0;d=c[2113308]|0;e=c[2113300]|0;f=c[2113224]|0;g=1;h=0;i=c[3541650]|0;j=c[2112960]|0;k=c[2112962]|0;while(1){l=ag(b[i>>1]|0,d)|0;m=c[j>>2]|0;if(m>>>0>268435455){b[k+l>>1]=c[a+(m>>>28<<2)>>2]&65535}if(m<<4>>>0>268435455){b[k+(l+2)>>1]=c[a+((m>>>24&15)<<2)>>2]&65535}if(m<<8>>>0>268435455){b[k+(l+4)>>1]=c[a+((m>>>20&15)<<2)>>2]&65535}if(m<<12>>>0>268435455){b[k+(l+6)>>1]=c[a+((m>>>16&15)<<2)>>2]&65535}if(m<<16>>>0>268435455){b[k+(l+8)>>1]=c[a+((m>>>12&15)<<2)>>2]&65535}if(m<<20>>>0>268435455){b[k+(l+10)>>1]=c[a+((m>>>8&15)<<2)>>2]&65535}if(m<<24>>>0>268435455){b[k+(l+12)>>1]=c[a+((m>>>4&15)<<2)>>2]&65535}n=m&15;if((n|0)!=0){b[k+(l+14)>>1]=c[a+(n<<2)>>2]&65535}n=c[j+4>>2]|0;o=m|h|n;if(n>>>0>268435455){b[k+(l+16)>>1]=c[a+(n>>>28<<2)>>2]&65535}if(n<<4>>>0>268435455){b[k+(l+18)>>1]=c[a+((n>>>24&15)<<2)>>2]&65535}if(n<<8>>>0>268435455){b[k+(l+20)>>1]=c[a+((n>>>20&15)<<2)>>2]&65535}if(n<<12>>>0>268435455){b[k+(l+22)>>1]=c[a+((n>>>16&15)<<2)>>2]&65535}if(n<<16>>>0>268435455){b[k+(l+24)>>1]=c[a+((n>>>12&15)<<2)>>2]&65535}if(n<<20>>>0>268435455){b[k+(l+26)>>1]=c[a+((n>>>8&15)<<2)>>2]&65535}if(n<<24>>>0>268435455){b[k+(l+28)>>1]=c[a+((n>>>4&15)<<2)>>2]&65535}m=n&15;if((m|0)!=0){b[k+(l+30)>>1]=c[a+(m<<2)>>2]&65535}p=k+e|0;q=j+f|0;if((g|0)>=16){break}g=g+1|0;h=o;i=i+2|0;j=q;k=p}c[2112960]=q;c[2112962]=p;return(o|0)==0|0}function agM(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;a=c[3541654]|0;d=c[2113308]|0;e=c[2113300]|0;f=c[2113224]|0;g=1;h=0;i=c[3541650]|0;j=c[2112960]|0;k=c[2112962]|0;while(1){l=ag(b[i>>1]|0,d)|0;m=c[j+4>>2]|0;n=m&15;if((n|0)!=0){b[k+l>>1]=c[a+(n<<2)>>2]&65535}n=m>>>4&15;if((n|0)!=0){b[k+(l+2)>>1]=c[a+(n<<2)>>2]&65535}n=m>>>8&15;if((n|0)!=0){b[k+(l+4)>>1]=c[a+(n<<2)>>2]&65535}n=m>>>12&15;if((n|0)!=0){b[k+(l+6)>>1]=c[a+(n<<2)>>2]&65535}n=m>>>16&15;if((n|0)!=0){b[k+(l+8)>>1]=c[a+(n<<2)>>2]&65535}n=m>>>20&15;if((n|0)!=0){b[k+(l+10)>>1]=c[a+(n<<2)>>2]&65535}n=m>>>24&15;if((n|0)!=0){b[k+(l+12)>>1]=c[a+(n<<2)>>2]&65535}n=m>>>28;if((n|0)!=0){b[k+(l+14)>>1]=c[a+(n<<2)>>2]&65535}n=c[j>>2]|0;o=m|h|n;m=n&15;if((m|0)!=0){b[k+(l+16)>>1]=c[a+(m<<2)>>2]&65535}m=n>>>4&15;if((m|0)!=0){b[k+(l+18)>>1]=c[a+(m<<2)>>2]&65535}m=n>>>8&15;if((m|0)!=0){b[k+(l+20)>>1]=c[a+(m<<2)>>2]&65535}m=n>>>12&15;if((m|0)!=0){b[k+(l+22)>>1]=c[a+(m<<2)>>2]&65535}m=n>>>16&15;if((m|0)!=0){b[k+(l+24)>>1]=c[a+(m<<2)>>2]&65535}m=n>>>20&15;if((m|0)!=0){b[k+(l+26)>>1]=c[a+(m<<2)>>2]&65535}m=n>>>24&15;if((m|0)!=0){b[k+(l+28)>>1]=c[a+(m<<2)>>2]&65535}m=n>>>28;if((m|0)!=0){b[k+(l+30)>>1]=c[a+(m<<2)>>2]&65535}p=k+e|0;q=j+f|0;if((g|0)>=16){break}g=g+1|0;h=o;i=i+2|0;j=q;k=p}c[2112960]=q;c[2112962]=p;return(o|0)==0|0}function agN(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;a=c[3541654]|0;d=c[2113228]|0;e=c[2113308]|0;f=c[2113300]|0;g=c[2113224]|0;h=1;i=0;j=c[3541650]|0;k=c[2113226]|0;l=c[2112962]|0;m=c[2112960]|0;while(1){n=k+32767|0;do{if((k&536887296|0)==0){o=b[j>>1]|0;p=ag(o,e)|0;q=(o*32767|0)+d|0;o=c[m>>2]|0;r=o|i;if((q&536887296|0)==0&o>>>0>268435455){b[l+p>>1]=c[a+(o>>>28<<2)>>2]&65535}s=l+(p+2)|0;do{if((q+32767&536887296|0)==0){if(o<<4>>>0<=268435455){break}b[s>>1]=c[a+((o>>>24&15)<<2)>>2]&65535}}while(0);s=l+(p+4)|0;do{if((q+65534&536887296|0)==0){if(o<<8>>>0<=268435455){break}b[s>>1]=c[a+((o>>>20&15)<<2)>>2]&65535}}while(0);s=l+(p+6)|0;do{if((q+98301&536887296|0)==0){if(o<<12>>>0<=268435455){break}b[s>>1]=c[a+((o>>>16&15)<<2)>>2]&65535}}while(0);s=l+(p+8)|0;do{if((q+131068&536887296|0)==0){if(o<<16>>>0<=268435455){break}b[s>>1]=c[a+((o>>>12&15)<<2)>>2]&65535}}while(0);s=l+(p+10)|0;do{if((q+163835&536887296|0)==0){if(o<<20>>>0<=268435455){break}b[s>>1]=c[a+((o>>>8&15)<<2)>>2]&65535}}while(0);s=l+(p+12)|0;do{if((q+196602&536887296|0)==0){if(o<<24>>>0<=268435455){break}b[s>>1]=c[a+((o>>>4&15)<<2)>>2]&65535}}while(0);s=l+(p+14)|0;do{if((q+229369&536887296|0)==0){t=o&15;if((t|0)==0){break}b[s>>1]=c[a+(t<<2)>>2]&65535}}while(0);s=c[m+4>>2]|0;o=r|s;if((q+262136&536887296|0)==0&s>>>0>268435455){b[l+(p+16)>>1]=c[a+(s>>>28<<2)>>2]&65535}t=l+(p+18)|0;do{if((q+294903&536887296|0)==0){if(s<<4>>>0<=268435455){break}b[t>>1]=c[a+((s>>>24&15)<<2)>>2]&65535}}while(0);t=l+(p+20)|0;do{if((q+327670&536887296|0)==0){if(s<<8>>>0<=268435455){break}b[t>>1]=c[a+((s>>>20&15)<<2)>>2]&65535}}while(0);t=l+(p+22)|0;do{if((q+360437&536887296|0)==0){if(s<<12>>>0<=268435455){break}b[t>>1]=c[a+((s>>>16&15)<<2)>>2]&65535}}while(0);t=l+(p+24)|0;do{if((q+393204&536887296|0)==0){if(s<<16>>>0<=268435455){break}b[t>>1]=c[a+((s>>>12&15)<<2)>>2]&65535}}while(0);t=l+(p+26)|0;do{if((q+425971&536887296|0)==0){if(s<<20>>>0<=268435455){break}b[t>>1]=c[a+((s>>>8&15)<<2)>>2]&65535}}while(0);t=l+(p+28)|0;do{if((q+458738&536887296|0)==0){if(s<<24>>>0<=268435455){break}b[t>>1]=c[a+((s>>>4&15)<<2)>>2]&65535}}while(0);if((q+491505&536887296|0)!=0){u=o;break}t=s&15;if((t|0)==0){u=o;break}b[l+(p+30)>>1]=c[a+(t<<2)>>2]&65535;u=o}else{u=i}}while(0);v=l+f|0;w=m+g|0;if((h|0)>=16){break}h=h+1|0;i=u;j=j+2|0;k=n;l=v;m=w}c[2113226]=n;c[2112962]=v;c[2112960]=w;return(u|0)==0|0}function agO(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;a=c[3541654]|0;d=c[2113228]|0;e=c[2113308]|0;f=c[2113300]|0;g=c[2113224]|0;h=1;i=0;j=c[3541650]|0;k=c[2113226]|0;l=c[2112962]|0;m=c[2112960]|0;while(1){n=k+32767|0;do{if((k&536887296|0)==0){o=b[j>>1]|0;p=ag(o,e)|0;q=l+p|0;r=(o*32767|0)+d|0;o=c[m+4>>2]|0;s=o|i;do{if((r&536887296|0)==0){t=o&15;if((t|0)==0){break}b[q>>1]=c[a+(t<<2)>>2]&65535}}while(0);q=l+(p+2)|0;do{if((r+32767&536887296|0)==0){t=o>>>4&15;if((t|0)==0){break}b[q>>1]=c[a+(t<<2)>>2]&65535}}while(0);q=l+(p+4)|0;do{if((r+65534&536887296|0)==0){t=o>>>8&15;if((t|0)==0){break}b[q>>1]=c[a+(t<<2)>>2]&65535}}while(0);q=l+(p+6)|0;do{if((r+98301&536887296|0)==0){t=o>>>12&15;if((t|0)==0){break}b[q>>1]=c[a+(t<<2)>>2]&65535}}while(0);q=l+(p+8)|0;do{if((r+131068&536887296|0)==0){t=o>>>16&15;if((t|0)==0){break}b[q>>1]=c[a+(t<<2)>>2]&65535}}while(0);q=l+(p+10)|0;do{if((r+163835&536887296|0)==0){t=o>>>20&15;if((t|0)==0){break}b[q>>1]=c[a+(t<<2)>>2]&65535}}while(0);q=l+(p+12)|0;do{if((r+196602&536887296|0)==0){t=o>>>24&15;if((t|0)==0){break}b[q>>1]=c[a+(t<<2)>>2]&65535}}while(0);q=l+(p+14)|0;do{if((r+229369&536887296|0)==0){t=o>>>28;if((t|0)==0){break}b[q>>1]=c[a+(t<<2)>>2]&65535}}while(0);q=l+(p+16)|0;o=c[m>>2]|0;t=s|o;do{if((r+262136&536887296|0)==0){u=o&15;if((u|0)==0){break}b[q>>1]=c[a+(u<<2)>>2]&65535}}while(0);q=l+(p+18)|0;do{if((r+294903&536887296|0)==0){s=o>>>4&15;if((s|0)==0){break}b[q>>1]=c[a+(s<<2)>>2]&65535}}while(0);q=l+(p+20)|0;do{if((r+327670&536887296|0)==0){s=o>>>8&15;if((s|0)==0){break}b[q>>1]=c[a+(s<<2)>>2]&65535}}while(0);q=l+(p+22)|0;do{if((r+360437&536887296|0)==0){s=o>>>12&15;if((s|0)==0){break}b[q>>1]=c[a+(s<<2)>>2]&65535}}while(0);q=l+(p+24)|0;do{if((r+393204&536887296|0)==0){s=o>>>16&15;if((s|0)==0){break}b[q>>1]=c[a+(s<<2)>>2]&65535}}while(0);q=l+(p+26)|0;do{if((r+425971&536887296|0)==0){s=o>>>20&15;if((s|0)==0){break}b[q>>1]=c[a+(s<<2)>>2]&65535}}while(0);q=l+(p+28)|0;do{if((r+458738&536887296|0)==0){s=o>>>24&15;if((s|0)==0){break}b[q>>1]=c[a+(s<<2)>>2]&65535}}while(0);if((r+491505&536887296|0)!=0){v=t;break}q=o>>>28;if((q|0)==0){v=t;break}b[l+(p+30)>>1]=c[a+(q<<2)>>2]&65535;v=t}else{v=i}}while(0);w=l+f|0;x=m+g|0;if((h|0)>=16){break}h=h+1|0;i=v;j=j+2|0;k=n;l=w;m=x}c[2113226]=n;c[2112962]=w;c[2112960]=x;return(v|0)==0|0}function agP(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[3541654]|0;d=c[2113300]|0;e=c[2113224]|0;f=0;g=0;h=c[2112960]|0;i=c[2112962]|0;do{j=c[h>>2]|0;if(j>>>0>268435455){b[i>>1]=c[a+(j>>>28<<2)>>2]&65535}if(j<<4>>>0>268435455){b[i+2>>1]=c[a+((j>>>24&15)<<2)>>2]&65535}if(j<<8>>>0>268435455){b[i+4>>1]=c[a+((j>>>20&15)<<2)>>2]&65535}if(j<<12>>>0>268435455){b[i+6>>1]=c[a+((j>>>16&15)<<2)>>2]&65535}if(j<<16>>>0>268435455){b[i+8>>1]=c[a+((j>>>12&15)<<2)>>2]&65535}if(j<<20>>>0>268435455){b[i+10>>1]=c[a+((j>>>8&15)<<2)>>2]&65535}if(j<<24>>>0>268435455){b[i+12>>1]=c[a+((j>>>4&15)<<2)>>2]&65535}k=j&15;if((k|0)!=0){b[i+14>>1]=c[a+(k<<2)>>2]&65535}k=c[h+4>>2]|0;if(k>>>0>268435455){b[i+16>>1]=c[a+(k>>>28<<2)>>2]&65535}if(k<<4>>>0>268435455){b[i+18>>1]=c[a+((k>>>24&15)<<2)>>2]&65535}if(k<<8>>>0>268435455){b[i+20>>1]=c[a+((k>>>20&15)<<2)>>2]&65535}if(k<<12>>>0>268435455){b[i+22>>1]=c[a+((k>>>16&15)<<2)>>2]&65535}if(k<<16>>>0>268435455){b[i+24>>1]=c[a+((k>>>12&15)<<2)>>2]&65535}if(k<<20>>>0>268435455){b[i+26>>1]=c[a+((k>>>8&15)<<2)>>2]&65535}if(k<<24>>>0>268435455){b[i+28>>1]=c[a+((k>>>4&15)<<2)>>2]&65535}l=k&15;if((l|0)!=0){b[i+30>>1]=c[a+(l<<2)>>2]&65535}l=c[h+8>>2]|0;if(l>>>0>268435455){b[i+32>>1]=c[a+(l>>>28<<2)>>2]&65535}if(l<<4>>>0>268435455){b[i+34>>1]=c[a+((l>>>24&15)<<2)>>2]&65535}if(l<<8>>>0>268435455){b[i+36>>1]=c[a+((l>>>20&15)<<2)>>2]&65535}if(l<<12>>>0>268435455){b[i+38>>1]=c[a+((l>>>16&15)<<2)>>2]&65535}if(l<<16>>>0>268435455){b[i+40>>1]=c[a+((l>>>12&15)<<2)>>2]&65535}if(l<<20>>>0>268435455){b[i+42>>1]=c[a+((l>>>8&15)<<2)>>2]&65535}if(l<<24>>>0>268435455){b[i+44>>1]=c[a+((l>>>4&15)<<2)>>2]&65535}m=l&15;if((m|0)!=0){b[i+46>>1]=c[a+(m<<2)>>2]&65535}m=c[h+12>>2]|0;g=j|g|k|l|m;if(m>>>0>268435455){b[i+48>>1]=c[a+(m>>>28<<2)>>2]&65535}if(m<<4>>>0>268435455){b[i+50>>1]=c[a+((m>>>24&15)<<2)>>2]&65535}if(m<<8>>>0>268435455){b[i+52>>1]=c[a+((m>>>20&15)<<2)>>2]&65535}if(m<<12>>>0>268435455){b[i+54>>1]=c[a+((m>>>16&15)<<2)>>2]&65535}if(m<<16>>>0>268435455){b[i+56>>1]=c[a+((m>>>12&15)<<2)>>2]&65535}if(m<<20>>>0>268435455){b[i+58>>1]=c[a+((m>>>8&15)<<2)>>2]&65535}if(m<<24>>>0>268435455){b[i+60>>1]=c[a+((m>>>4&15)<<2)>>2]&65535}l=m&15;if((l|0)!=0){b[i+62>>1]=c[a+(l<<2)>>2]&65535}f=f+1|0;i=i+d|0;h=h+e|0;}while((f|0)<32);c[2112960]=h;c[2112962]=i;return(g|0)==0|0}function agQ(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[3541654]|0;d=c[2113300]|0;e=c[2113224]|0;f=0;g=0;h=c[2112960]|0;i=c[2112962]|0;do{j=c[h+12>>2]|0;k=j&15;if((k|0)!=0){b[i>>1]=c[a+(k<<2)>>2]&65535}k=j>>>4&15;if((k|0)!=0){b[i+2>>1]=c[a+(k<<2)>>2]&65535}k=j>>>8&15;if((k|0)!=0){b[i+4>>1]=c[a+(k<<2)>>2]&65535}k=j>>>12&15;if((k|0)!=0){b[i+6>>1]=c[a+(k<<2)>>2]&65535}k=j>>>16&15;if((k|0)!=0){b[i+8>>1]=c[a+(k<<2)>>2]&65535}k=j>>>20&15;if((k|0)!=0){b[i+10>>1]=c[a+(k<<2)>>2]&65535}k=j>>>24&15;if((k|0)!=0){b[i+12>>1]=c[a+(k<<2)>>2]&65535}k=j>>>28;if((k|0)!=0){b[i+14>>1]=c[a+(k<<2)>>2]&65535}k=c[h+8>>2]|0;l=k&15;if((l|0)!=0){b[i+16>>1]=c[a+(l<<2)>>2]&65535}l=k>>>4&15;if((l|0)!=0){b[i+18>>1]=c[a+(l<<2)>>2]&65535}l=k>>>8&15;if((l|0)!=0){b[i+20>>1]=c[a+(l<<2)>>2]&65535}l=k>>>12&15;if((l|0)!=0){b[i+22>>1]=c[a+(l<<2)>>2]&65535}l=k>>>16&15;if((l|0)!=0){b[i+24>>1]=c[a+(l<<2)>>2]&65535}l=k>>>20&15;if((l|0)!=0){b[i+26>>1]=c[a+(l<<2)>>2]&65535}l=k>>>24&15;if((l|0)!=0){b[i+28>>1]=c[a+(l<<2)>>2]&65535}l=k>>>28;if((l|0)!=0){b[i+30>>1]=c[a+(l<<2)>>2]&65535}l=c[h+4>>2]|0;m=l&15;if((m|0)!=0){b[i+32>>1]=c[a+(m<<2)>>2]&65535}m=l>>>4&15;if((m|0)!=0){b[i+34>>1]=c[a+(m<<2)>>2]&65535}m=l>>>8&15;if((m|0)!=0){b[i+36>>1]=c[a+(m<<2)>>2]&65535}m=l>>>12&15;if((m|0)!=0){b[i+38>>1]=c[a+(m<<2)>>2]&65535}m=l>>>16&15;if((m|0)!=0){b[i+40>>1]=c[a+(m<<2)>>2]&65535}m=l>>>20&15;if((m|0)!=0){b[i+42>>1]=c[a+(m<<2)>>2]&65535}m=l>>>24&15;if((m|0)!=0){b[i+44>>1]=c[a+(m<<2)>>2]&65535}m=l>>>28;if((m|0)!=0){b[i+46>>1]=c[a+(m<<2)>>2]&65535}m=c[h>>2]|0;g=j|g|k|l|m;l=m&15;if((l|0)!=0){b[i+48>>1]=c[a+(l<<2)>>2]&65535}l=m>>>4&15;if((l|0)!=0){b[i+50>>1]=c[a+(l<<2)>>2]&65535}l=m>>>8&15;if((l|0)!=0){b[i+52>>1]=c[a+(l<<2)>>2]&65535}l=m>>>12&15;if((l|0)!=0){b[i+54>>1]=c[a+(l<<2)>>2]&65535}l=m>>>16&15;if((l|0)!=0){b[i+56>>1]=c[a+(l<<2)>>2]&65535}l=m>>>20&15;if((l|0)!=0){b[i+58>>1]=c[a+(l<<2)>>2]&65535}l=m>>>24&15;if((l|0)!=0){b[i+60>>1]=c[a+(l<<2)>>2]&65535}l=m>>>28;if((l|0)!=0){b[i+62>>1]=c[a+(l<<2)>>2]&65535}f=f+1|0;i=i+d|0;h=h+e|0;}while((f|0)<32);c[2112960]=h;c[2112962]=i;return(g|0)==0|0}function agR(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0;a=c[3541654]|0;d=c[2113228]|0;e=(d&536887296|0)==0;f=(d+32767&536887296|0)==0;g=(d+65534&536887296|0)==0;h=(d+98301&536887296|0)==0;i=(d+131068&536887296|0)==0;j=(d+163835&536887296|0)==0;k=(d+196602&536887296|0)==0;l=(d+229369&536887296|0)==0;m=(d+262136&536887296|0)==0;n=(d+294903&536887296|0)==0;o=(d+327670&536887296|0)==0;p=(d+360437&536887296|0)==0;q=(d+393204&536887296|0)==0;r=(d+425971&536887296|0)==0;s=(d+458738&536887296|0)==0;t=(d+491505&536887296|0)==0;u=(d+524272&536887296|0)==0;v=(d+557039&536887296|0)==0;w=(d+589806&536887296|0)==0;x=(d+622573&536887296|0)==0;y=(d+655340&536887296|0)==0;z=(d+688107&536887296|0)==0;A=(d+720874&536887296|0)==0;B=(d+753641&536887296|0)==0;C=(d+786408&536887296|0)==0;D=(d+819175&536887296|0)==0;E=(d+851942&536887296|0)==0;F=(d+884709&536887296|0)==0;G=(d+917476&536887296|0)==0;H=(d+950243&536887296|0)==0;I=(d+983010&536887296|0)==0;J=(d+1015777&536887296|0)==0;d=c[2113300]|0;K=c[2113224]|0;L=1;M=0;N=c[2113226]|0;O=c[2112962]|0;P=c[2112960]|0;while(1){Q=N+32767|0;do{if((N&536887296|0)==0){R=c[P>>2]|0;S=R|M;if(e&R>>>0>268435455){b[O>>1]=c[a+(R>>>28<<2)>>2]&65535}T=O+2|0;do{if(f){if(R<<4>>>0<=268435455){break}b[T>>1]=c[a+((R>>>24&15)<<2)>>2]&65535}}while(0);T=O+4|0;do{if(g){if(R<<8>>>0<=268435455){break}b[T>>1]=c[a+((R>>>20&15)<<2)>>2]&65535}}while(0);T=O+6|0;do{if(h){if(R<<12>>>0<=268435455){break}b[T>>1]=c[a+((R>>>16&15)<<2)>>2]&65535}}while(0);T=O+8|0;do{if(i){if(R<<16>>>0<=268435455){break}b[T>>1]=c[a+((R>>>12&15)<<2)>>2]&65535}}while(0);T=O+10|0;do{if(j){if(R<<20>>>0<=268435455){break}b[T>>1]=c[a+((R>>>8&15)<<2)>>2]&65535}}while(0);T=O+12|0;do{if(k){if(R<<24>>>0<=268435455){break}b[T>>1]=c[a+((R>>>4&15)<<2)>>2]&65535}}while(0);T=O+14|0;do{if(l){U=R&15;if((U|0)==0){break}b[T>>1]=c[a+(U<<2)>>2]&65535}}while(0);T=c[P+4>>2]|0;R=S|T;if(m&T>>>0>268435455){b[O+16>>1]=c[a+(T>>>28<<2)>>2]&65535}U=O+18|0;do{if(n){if(T<<4>>>0<=268435455){break}b[U>>1]=c[a+((T>>>24&15)<<2)>>2]&65535}}while(0);U=O+20|0;do{if(o){if(T<<8>>>0<=268435455){break}b[U>>1]=c[a+((T>>>20&15)<<2)>>2]&65535}}while(0);U=O+22|0;do{if(p){if(T<<12>>>0<=268435455){break}b[U>>1]=c[a+((T>>>16&15)<<2)>>2]&65535}}while(0);U=O+24|0;do{if(q){if(T<<16>>>0<=268435455){break}b[U>>1]=c[a+((T>>>12&15)<<2)>>2]&65535}}while(0);U=O+26|0;do{if(r){if(T<<20>>>0<=268435455){break}b[U>>1]=c[a+((T>>>8&15)<<2)>>2]&65535}}while(0);U=O+28|0;do{if(s){if(T<<24>>>0<=268435455){break}b[U>>1]=c[a+((T>>>4&15)<<2)>>2]&65535}}while(0);U=O+30|0;do{if(t){S=T&15;if((S|0)==0){break}b[U>>1]=c[a+(S<<2)>>2]&65535}}while(0);U=c[P+8>>2]|0;T=R|U;if(u&U>>>0>268435455){b[O+32>>1]=c[a+(U>>>28<<2)>>2]&65535}S=O+34|0;do{if(v){if(U<<4>>>0<=268435455){break}b[S>>1]=c[a+((U>>>24&15)<<2)>>2]&65535}}while(0);S=O+36|0;do{if(w){if(U<<8>>>0<=268435455){break}b[S>>1]=c[a+((U>>>20&15)<<2)>>2]&65535}}while(0);S=O+38|0;do{if(x){if(U<<12>>>0<=268435455){break}b[S>>1]=c[a+((U>>>16&15)<<2)>>2]&65535}}while(0);S=O+40|0;do{if(y){if(U<<16>>>0<=268435455){break}b[S>>1]=c[a+((U>>>12&15)<<2)>>2]&65535}}while(0);S=O+42|0;do{if(z){if(U<<20>>>0<=268435455){break}b[S>>1]=c[a+((U>>>8&15)<<2)>>2]&65535}}while(0);S=O+44|0;do{if(A){if(U<<24>>>0<=268435455){break}b[S>>1]=c[a+((U>>>4&15)<<2)>>2]&65535}}while(0);S=O+46|0;do{if(B){R=U&15;if((R|0)==0){break}b[S>>1]=c[a+(R<<2)>>2]&65535}}while(0);S=c[P+12>>2]|0;U=T|S;if(C&S>>>0>268435455){b[O+48>>1]=c[a+(S>>>28<<2)>>2]&65535}R=O+50|0;do{if(D){if(S<<4>>>0<=268435455){break}b[R>>1]=c[a+((S>>>24&15)<<2)>>2]&65535}}while(0);R=O+52|0;do{if(E){if(S<<8>>>0<=268435455){break}b[R>>1]=c[a+((S>>>20&15)<<2)>>2]&65535}}while(0);R=O+54|0;do{if(F){if(S<<12>>>0<=268435455){break}b[R>>1]=c[a+((S>>>16&15)<<2)>>2]&65535}}while(0);R=O+56|0;do{if(G){if(S<<16>>>0<=268435455){break}b[R>>1]=c[a+((S>>>12&15)<<2)>>2]&65535}}while(0);R=O+58|0;do{if(H){if(S<<20>>>0<=268435455){break}b[R>>1]=c[a+((S>>>8&15)<<2)>>2]&65535}}while(0);R=O+60|0;do{if(I){if(S<<24>>>0<=268435455){break}b[R>>1]=c[a+((S>>>4&15)<<2)>>2]&65535}}while(0);if(!J){V=U;break}R=S&15;if((R|0)==0){V=U;break}b[O+62>>1]=c[a+(R<<2)>>2]&65535;V=U}else{V=M}}while(0);W=O+d|0;X=P+K|0;if((L|0)>=32){break}L=L+1|0;M=V;N=Q;O=W;P=X}c[2113226]=Q;c[2112962]=W;c[2112960]=X;return(V|0)==0|0}function agS(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;a=c[3541654]|0;d=c[2113228]|0;e=(d&536887296|0)==0;f=(d+32767&536887296|0)==0;g=(d+65534&536887296|0)==0;h=(d+98301&536887296|0)==0;i=(d+131068&536887296|0)==0;j=(d+163835&536887296|0)==0;k=(d+196602&536887296|0)==0;l=(d+229369&536887296|0)==0;m=(d+262136&536887296|0)==0;n=(d+294903&536887296|0)==0;o=(d+327670&536887296|0)==0;p=(d+360437&536887296|0)==0;q=(d+393204&536887296|0)==0;r=(d+425971&536887296|0)==0;s=(d+458738&536887296|0)==0;t=(d+491505&536887296|0)==0;u=(d+524272&536887296|0)==0;v=(d+557039&536887296|0)==0;w=(d+589806&536887296|0)==0;x=(d+622573&536887296|0)==0;y=(d+655340&536887296|0)==0;z=(d+688107&536887296|0)==0;A=(d+720874&536887296|0)==0;B=(d+753641&536887296|0)==0;C=(d+786408&536887296|0)==0;D=(d+819175&536887296|0)==0;E=(d+851942&536887296|0)==0;F=(d+884709&536887296|0)==0;G=(d+917476&536887296|0)==0;H=(d+950243&536887296|0)==0;I=(d+983010&536887296|0)==0;J=(d+1015777&536887296|0)==0;d=c[2113300]|0;K=c[2113224]|0;L=1;M=0;N=c[2113226]|0;O=c[2112962]|0;P=c[2112960]|0;while(1){Q=N+32767|0;do{if((N&536887296|0)==0){R=c[P+12>>2]|0;S=R|M;do{if(e){T=R&15;if((T|0)==0){break}b[O>>1]=c[a+(T<<2)>>2]&65535}}while(0);T=O+2|0;do{if(f){U=R>>>4&15;if((U|0)==0){break}b[T>>1]=c[a+(U<<2)>>2]&65535}}while(0);T=O+4|0;do{if(g){U=R>>>8&15;if((U|0)==0){break}b[T>>1]=c[a+(U<<2)>>2]&65535}}while(0);T=O+6|0;do{if(h){U=R>>>12&15;if((U|0)==0){break}b[T>>1]=c[a+(U<<2)>>2]&65535}}while(0);T=O+8|0;do{if(i){U=R>>>16&15;if((U|0)==0){break}b[T>>1]=c[a+(U<<2)>>2]&65535}}while(0);T=O+10|0;do{if(j){U=R>>>20&15;if((U|0)==0){break}b[T>>1]=c[a+(U<<2)>>2]&65535}}while(0);T=O+12|0;do{if(k){U=R>>>24&15;if((U|0)==0){break}b[T>>1]=c[a+(U<<2)>>2]&65535}}while(0);T=O+14|0;do{if(l){U=R>>>28;if((U|0)==0){break}b[T>>1]=c[a+(U<<2)>>2]&65535}}while(0);T=O+16|0;R=c[P+8>>2]|0;U=S|R;do{if(m){V=R&15;if((V|0)==0){break}b[T>>1]=c[a+(V<<2)>>2]&65535}}while(0);T=O+18|0;do{if(n){S=R>>>4&15;if((S|0)==0){break}b[T>>1]=c[a+(S<<2)>>2]&65535}}while(0);T=O+20|0;do{if(o){S=R>>>8&15;if((S|0)==0){break}b[T>>1]=c[a+(S<<2)>>2]&65535}}while(0);T=O+22|0;do{if(p){S=R>>>12&15;if((S|0)==0){break}b[T>>1]=c[a+(S<<2)>>2]&65535}}while(0);T=O+24|0;do{if(q){S=R>>>16&15;if((S|0)==0){break}b[T>>1]=c[a+(S<<2)>>2]&65535}}while(0);T=O+26|0;do{if(r){S=R>>>20&15;if((S|0)==0){break}b[T>>1]=c[a+(S<<2)>>2]&65535}}while(0);T=O+28|0;do{if(s){S=R>>>24&15;if((S|0)==0){break}b[T>>1]=c[a+(S<<2)>>2]&65535}}while(0);T=O+30|0;do{if(t){S=R>>>28;if((S|0)==0){break}b[T>>1]=c[a+(S<<2)>>2]&65535}}while(0);T=O+32|0;R=c[P+4>>2]|0;S=U|R;do{if(u){V=R&15;if((V|0)==0){break}b[T>>1]=c[a+(V<<2)>>2]&65535}}while(0);T=O+34|0;do{if(v){U=R>>>4&15;if((U|0)==0){break}b[T>>1]=c[a+(U<<2)>>2]&65535}}while(0);T=O+36|0;do{if(w){U=R>>>8&15;if((U|0)==0){break}b[T>>1]=c[a+(U<<2)>>2]&65535}}while(0);T=O+38|0;do{if(x){U=R>>>12&15;if((U|0)==0){break}b[T>>1]=c[a+(U<<2)>>2]&65535}}while(0);T=O+40|0;do{if(y){U=R>>>16&15;if((U|0)==0){break}b[T>>1]=c[a+(U<<2)>>2]&65535}}while(0);T=O+42|0;do{if(z){U=R>>>20&15;if((U|0)==0){break}b[T>>1]=c[a+(U<<2)>>2]&65535}}while(0);T=O+44|0;do{if(A){U=R>>>24&15;if((U|0)==0){break}b[T>>1]=c[a+(U<<2)>>2]&65535}}while(0);T=O+46|0;do{if(B){U=R>>>28;if((U|0)==0){break}b[T>>1]=c[a+(U<<2)>>2]&65535}}while(0);T=O+48|0;R=c[P>>2]|0;U=S|R;do{if(C){V=R&15;if((V|0)==0){break}b[T>>1]=c[a+(V<<2)>>2]&65535}}while(0);T=O+50|0;do{if(D){S=R>>>4&15;if((S|0)==0){break}b[T>>1]=c[a+(S<<2)>>2]&65535}}while(0);T=O+52|0;do{if(E){S=R>>>8&15;if((S|0)==0){break}b[T>>1]=c[a+(S<<2)>>2]&65535}}while(0);T=O+54|0;do{if(F){S=R>>>12&15;if((S|0)==0){break}b[T>>1]=c[a+(S<<2)>>2]&65535}}while(0);T=O+56|0;do{if(G){S=R>>>16&15;if((S|0)==0){break}b[T>>1]=c[a+(S<<2)>>2]&65535}}while(0);T=O+58|0;do{if(H){S=R>>>20&15;if((S|0)==0){break}b[T>>1]=c[a+(S<<2)>>2]&65535}}while(0);T=O+60|0;do{if(I){S=R>>>24&15;if((S|0)==0){break}b[T>>1]=c[a+(S<<2)>>2]&65535}}while(0);if(!J){W=U;break}T=R>>>28;if((T|0)==0){W=U;break}b[O+62>>1]=c[a+(T<<2)>>2]&65535;W=U}else{W=M}}while(0);X=O+d|0;Y=P+K|0;if((L|0)>=32){break}L=L+1|0;M=W;N=Q;O=X;P=Y}c[2113226]=Q;c[2112962]=X;c[2112960]=Y;return(W|0)==0|0}function agT(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0;fxU(0,425984);c[2414530]=0;c[3541932]=0;c[3541930]=196608;c[3541926]=262144;c[3541898]=262400;d=(c[3542068]|0)==2;if(d&(a[7462104]^1)|a[7462128]){c[3541878]=270592;c[3541876]=274688;e=278784}else{e=270592}if(d){c[3541936]=e;c[3541934]=e+16384;c[3542030]=e+81920;c[3531284]=e+81936;d=e+253968|0;c[2438858]=d;f=e+256784|0;c[2438860]=f;c[3541886]=d;c[3541900]=f;c[3541887]=e+254224;c[3541901]=e+256800;c[3541888]=e+254480;c[3541902]=e+256816;c[3541889]=e+254736;c[3541903]=e+256832;c[3541890]=e+254992;c[3541904]=e+256848;c[3541891]=e+255248;c[3541905]=e+256864;c[3541892]=e+255504;c[3541906]=e+256880;c[3541893]=e+255760;c[3541907]=e+256896;c[3541894]=e+256016;c[3541908]=e+256912;c[3541895]=e+256272;c[3541909]=e+256928;c[3541896]=e+256528;c[3541910]=e+256944;g=e+256960|0}else{c[2438858]=e;f=e+256|0;c[2438860]=f;c[3541886]=e;c[3541900]=f;g=e+272|0}c[2388326]=g;e=g;g=0;while(1){if((g|0)>=1024){break}i=9638528+(g<<2)|0;if((c[i>>2]|0)==0){j=2389;break}else{g=g+1|0}}do{if((j|0)==2389){g=gGq(e)|0;c[i>>2]=g;if((g|0)==0){break}gGz(g|0,0,e|0);c[2414530]=g;gGz(g|0,0,e|0);c[3541932]=g;c[3541930]=g+196608;c[3541926]=g+262144;c[3541898]=g+262400;f=g+270592|0;d=c[3542068]|0;k=a[7462104]|0;l=(d|0)==2;m=a[7462128]|0;if(l&(k^1)|m){c[3541878]=f;c[3541876]=g+274688;n=g+278784|0}else{n=f}if(l){c[3541936]=n;c[3541934]=n+16384;c[3542030]=n+81920;c[3531284]=n+81936;f=n+253968|0;c[2438858]=f;o=n+256784|0;c[2438860]=o;c[3541886]=f;c[3541900]=o;c[3541887]=n+254224;c[3541901]=n+256800;c[3541888]=n+254480;c[3541902]=n+256816;c[3541889]=n+254736;c[3541903]=n+256832;c[3541890]=n+254992;c[3541904]=n+256848;c[3541891]=n+255248;c[3541905]=n+256864;c[3541892]=n+255504;c[3541906]=n+256880;c[3541893]=n+255760;c[3541907]=n+256896;c[3541894]=n+256016;c[3541908]=n+256912;c[3541895]=n+256272;c[3541909]=n+256928;c[3541896]=n+256528;c[3541910]=n+256944;p=n+256960|0}else{c[2438858]=n;o=n+256|0;c[2438860]=o;c[3541886]=n;c[3541900]=o;p=n+272|0}c[2388326]=p;if((c[2394]|0)==0){q=c[2112932]|0}else{c[2394]=0;o=c[3532596]|0;c[2112932]=o;f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];q=o}c[q+196848>>2]=4876;o=c[3541922]|0;f=c[2113250]|0;r=f-1|0;s=q|0;t=s;u=0;while(1){c[t>>2]=o+u;v=u+1024|0;if(v>>>0>r>>>0){break}else{t=t+4|0;u=v}}u=c[2113272]|0;if((u|0)==0){w=0}else{t=c[3542034]|0;v=u-1|0;x=s;y=0;while(1){c[x+131072>>2]=t+y;z=y+1024|0;if(z>>>0>v>>>0){w=u;break}else{x=x+4|0;y=z}}}do{if(f>>>0>w>>>0){y=w&-1024;if(y>>>0>r>>>0){break}x=q+(w>>>10<<2)|0;u=y;while(1){c[x+131072>>2]=o+u;y=u+1024|0;if(y>>>0>r>>>0){break}else{x=x+4|0;u=y}}}}while(0);if(l){c[2113256]=0;r=c[3541934]|0;c[q+28800>>2]=r;c[q+94336>>2]=r;c[q+159872>>2]=r;o=r+1024|0;c[q+28804>>2]=o;c[q+94340>>2]=o;c[q+159876>>2]=o;f=r+2048|0;c[q+28808>>2]=f;c[q+94344>>2]=f;c[q+159880>>2]=f;u=r+3072|0;c[q+28812>>2]=u;c[q+94348>>2]=u;c[q+159884>>2]=u;x=r+4096|0;c[q+28816>>2]=x;c[q+94352>>2]=x;c[q+159888>>2]=x;y=r+5120|0;c[q+28820>>2]=y;c[q+94356>>2]=y;c[q+159892>>2]=y;v=r+6144|0;c[q+28824>>2]=v;c[q+94360>>2]=v;c[q+159896>>2]=v;t=r+7168|0;c[q+28828>>2]=t;c[q+94364>>2]=t;c[q+159900>>2]=t;c[q+28832>>2]=r;c[q+94368>>2]=r;c[q+159904>>2]=r;c[q+28836>>2]=o;c[q+94372>>2]=o;c[q+159908>>2]=o;c[q+28840>>2]=f;c[q+94376>>2]=f;c[q+159912>>2]=f;c[q+28844>>2]=u;c[q+94380>>2]=u;c[q+159916>>2]=u;c[q+28848>>2]=x;c[q+94384>>2]=x;c[q+159920>>2]=x;c[q+28852>>2]=y;c[q+94388>>2]=y;c[q+159924>>2]=y;c[q+28856>>2]=v;c[q+94392>>2]=v;c[q+159928>>2]=v;c[q+28860>>2]=t;c[q+94396>>2]=t;c[q+159932>>2]=t;c[q+28864>>2]=r;c[q+94400>>2]=r;c[q+159936>>2]=r;c[q+28868>>2]=o;c[q+94404>>2]=o;c[q+159940>>2]=o;c[q+28872>>2]=f;c[q+94408>>2]=f;c[q+159944>>2]=f;c[q+28876>>2]=u;c[q+94412>>2]=u;c[q+159948>>2]=u;c[q+28880>>2]=x;c[q+94416>>2]=x;c[q+159952>>2]=x;c[q+28884>>2]=y;c[q+94420>>2]=y;c[q+159956>>2]=y;c[q+28888>>2]=v;c[q+94424>>2]=v;c[q+159960>>2]=v;c[q+28892>>2]=t;c[q+94428>>2]=t;c[q+159964>>2]=t;c[q+28896>>2]=r;c[q+94432>>2]=r;c[q+159968>>2]=r;c[q+28900>>2]=o;c[q+94436>>2]=o;c[q+159972>>2]=o;c[q+28904>>2]=f;c[q+94440>>2]=f;c[q+159976>>2]=f;c[q+28908>>2]=u;c[q+94444>>2]=u;c[q+159980>>2]=u;c[q+28912>>2]=x;c[q+94448>>2]=x;c[q+159984>>2]=x;c[q+28916>>2]=y;c[q+94452>>2]=y;c[q+159988>>2]=y;c[q+28920>>2]=v;c[q+94456>>2]=v;c[q+159992>>2]=v;c[q+28924>>2]=t;c[q+94460>>2]=t;c[q+159996>>2]=t;t=c[3541936]|0;c[q+26112>>2]=t;c[q+91648>>2]=t;c[q+157184>>2]=t;v=t+1024|0;c[q+26116>>2]=v;c[q+91652>>2]=v;c[q+157188>>2]=v;v=t+2048|0;c[q+26120>>2]=v;c[q+91656>>2]=v;c[q+157192>>2]=v;v=t+3072|0;c[q+26124>>2]=v;c[q+91660>>2]=v;c[q+157196>>2]=v;v=t+4096|0;c[q+26128>>2]=v;c[q+91664>>2]=v;c[q+157200>>2]=v;v=t+5120|0;c[q+26132>>2]=v;c[q+91668>>2]=v;c[q+157204>>2]=v;v=t+6144|0;c[q+26136>>2]=v;c[q+91672>>2]=v;c[q+157208>>2]=v;v=t+7168|0;c[q+26140>>2]=v;c[q+91676>>2]=v;c[q+157212>>2]=v;v=t+8192|0;c[q+26144>>2]=v;c[q+91680>>2]=v;c[q+157216>>2]=v;v=t+9216|0;c[q+26148>>2]=v;c[q+91684>>2]=v;c[q+157220>>2]=v;v=t+10240|0;c[q+26152>>2]=v;c[q+91688>>2]=v;c[q+157224>>2]=v;v=t+11264|0;c[q+26156>>2]=v;c[q+91692>>2]=v;c[q+157228>>2]=v;v=t+12288|0;c[q+26160>>2]=v;c[q+91696>>2]=v;c[q+157232>>2]=v;v=t+13312|0;c[q+26164>>2]=v;c[q+91700>>2]=v;c[q+157236>>2]=v;v=t+14336|0;c[q+26168>>2]=v;c[q+91704>>2]=v;c[q+157240>>2]=v;v=t+15360|0;c[q+26172>>2]=v;c[q+91708>>2]=v;c[q+157244>>2]=v}v=q+36864|0;t=9437184;while(1){y=g+(t-9437184)|0;c[v>>2]=y;c[v+65536>>2]=y;c[v+131072>>2]=y;y=t+1024|0;if(y>>>0>9633791){break}else{v=v+4|0;t=y}}t=q+65280|0;v=16711680;while(1){y=g+(v-16515072)|0;c[t>>2]=y;c[t+65536>>2]=y;c[t+131072>>2]=y;y=v+1024|0;if(y>>>0>16777215){break}else{t=t+4|0;v=y}}c[q+196608>>2]=1044;c[q+196648>>2]=1344;c[q+196688>>2]=3582;c[q+196728>>2]=400;if(!((d|0)!=2|k)){c[q+24960>>2]=1;c[q+90496>>2]=1;c[q+156032>>2]=1;c[q+24964>>2]=1;c[q+90500>>2]=1;c[q+156036>>2]=1;c[q+24968>>2]=1;c[q+90504>>2]=1;c[q+156040>>2]=1;c[q+24972>>2]=1;c[q+90508>>2]=1;c[q+156044>>2]=1;c[q+24976>>2]=1;c[q+90512>>2]=1;c[q+156048>>2]=1;c[q+24980>>2]=1;c[q+90516>>2]=1;c[q+156052>>2]=1;c[q+24984>>2]=1;c[q+90520>>2]=1;c[q+156056>>2]=1;c[q+24988>>2]=1;c[q+90524>>2]=1;c[q+156060>>2]=1;c[q+196612>>2]=1240;c[q+196652>>2]=1246}if(m){v=c[3542032]|0;t=32767;while(1){g=t<<1;a[v+g|0]=a[v+t|0]|0;a[v+(g|1)|0]=-1;if((t|0)>0){t=t-1|0}else{break}}t=q+61440|0;k=15728640;while(1){d=v+(k-15728640)|0;c[t>>2]=d;c[t+131072>>2]=d;d=k+1024|0;if(d>>>0>15794175){break}else{t=t+4|0;k=d}}c[q+61824>>2]=1;c[q+127360>>2]=1;c[q+192896>>2]=1;c[q+61828>>2]=1;c[q+127364>>2]=1;c[q+192900>>2]=1;c[q+61832>>2]=1;c[q+127368>>2]=1;c[q+192904>>2]=1;c[q+61836>>2]=1;c[q+127372>>2]=1;c[q+192908>>2]=1;c[q+61840>>2]=1;c[q+127376>>2]=1;c[q+192912>>2]=1;c[q+61844>>2]=1;c[q+127380>>2]=1;c[q+192916>>2]=1;c[q+61848>>2]=1;c[q+127384>>2]=1;c[q+192920>>2]=1;c[q+61852>>2]=1;c[q+127388>>2]=1;c[q+192924>>2]=1;c[q+61920>>2]=2;c[q+127456>>2]=2;c[q+192992>>2]=2;c[q+61924>>2]=2;c[q+127460>>2]=2;c[q+192996>>2]=2;c[q+61928>>2]=2;c[q+127464>>2]=2;c[q+193e3>>2]=2;c[q+61932>>2]=2;c[q+127468>>2]=2;c[q+193004>>2]=2;c[q+61936>>2]=2;c[q+127472>>2]=2;c[q+193008>>2]=2;c[q+61940>>2]=2;c[q+127476>>2]=2;c[q+193012>>2]=2;c[q+61944>>2]=2;c[q+127480>>2]=2;c[q+193016>>2]=2;c[q+61948>>2]=2;c[q+127484>>2]=2;c[q+193020>>2]=2;c[q+196612>>2]=1240;c[q+196652>>2]=1246;c[q+196616>>2]=534;c[q+196656>>2]=926}k=c[3532592]|0;if((k|0)!=0){gGC(k|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;do{if(l|a[7461720]){Tq(698984)}else{if(!(m|a[7462008])){break}Tq(684272)}}while(0);a[14165112]=0;m=14168104;c[m>>2]=0;c[m+4>>2]=0;a[14165104]=0;m=14168096;c[m>>2]=0;c[m+4>>2]=0;a[14165096]=0;m=14168088;c[m>>2]=0;c[m+4>>2]=0;a[14165088]=0;m=14168080;c[m>>2]=0;c[m+4>>2]=0;a[14165080]=0;m=14168072;c[m>>2]=0;c[m+4>>2]=0;a[14165072]=0;m=14168064;c[m>>2]=0;c[m+4>>2]=0;a[14165064]=0;m=14168056;c[m>>2]=0;c[m+4>>2]=0;a[14165056]=0;m=14168048;c[m>>2]=0;c[m+4>>2]=0;a[14165048]=0;m=14168040;c[m>>2]=0;c[m+4>>2]=0;a[14165040]=0;m=14168032;c[m>>2]=0;c[m+4>>2]=0;a[14165032]=0;m=14168024;c[m>>2]=0;c[m+4>>2]=0;a[14165024]=0;m=14168016;c[m>>2]=0;c[m+4>>2]=0;a[14165016]=0;m=14168008;c[m>>2]=0;c[m+4>>2]=0;a[14165008]=0;m=14168e3;c[m>>2]=0;c[m+4>>2]=0;a[14165e3]=0;m=14167976;c[m>>2]=0;c[m+4>>2]=0;a[14164992]=0;m=14167968;c[m>>2]=0;c[m+4>>2]=0;a[14164984]=0;m=14167960;c[m>>2]=0;c[m+4>>2]=0;a[14164976]=0;m=14167952;c[m>>2]=0;c[m+4>>2]=0;a[14164968]=0;m=14167944;c[m>>2]=0;c[m+4>>2]=0;a[9628480]=0;m=14167920;c[m>>2]=0;c[m+4>>2]=0;a[9628472]=0;m=14167912;c[m>>2]=0;c[m+4>>2]=0;a[9628464]=0;m=14167904;c[m>>2]=0;c[m+4>>2]=0;a[9628456]=0;m=14167896;c[m>>2]=0;c[m+4>>2]=0;b[7083992]=0;b[7083996]=0;m=0;while(1){if((m|0)>=1024){break}A=9638528+(m<<2)|0;if((c[A>>2]|0)==0){j=2433;break}else{m=m+1|0}}do{if((j|0)==2433){m=gGq(6144)|0;c[A>>2]=m;if((m|0)==0){break}c[2388324]=m;gGz(m|0,0,6144);m=0;while(1){if((m|0)>=1024){break}B=9638528+(m<<2)|0;if((c[B>>2]|0)==0){j=2438;break}else{m=m+1|0}}do{if((j|0)==2438){m=gGq(12288)|0;c[B>>2]=m;if((m|0)==0){break}gGz(m|0,0,12288);c[3541942]=m;c[2420374]=256;if((c[3542068]|0)==2){c[2420374]=1024;C=16384}else{C=4096}a[7024720]=1;m=0;while(1){if((m|0)>=1024){break}D=9638528+(m<<2)|0;if((c[D>>2]|0)==0){j=2445;break}else{m=m+1|0}}do{if((j|0)==2445){m=gGq(C)|0;c[D>>2]=m;if((m|0)==0){break}gGz(m|0,0,C|0);c[2411926]=m;if(a[7024720]|0){l=c[2420374]<<3;c[2426852]=m;c[2426853]=0;c[2426856]=m+l;c[2426857]=0}c[2394758]=0;l=c[3542068]|0;if((l|0)==2){gGz(c[3531284]|0,0,172032);c[2394732]=0;c[2385516]=0;c[3528532]=1}m=a[7462128]|0;L3236:do{if((l&1|0)!=0&(m^1)&(a[7462160]^1)){k=4e8/(c[2424]|0)|0;c[2113248]=k;c[2443848]=(k|0)/32|0;if((c[2113246]|0)>>>0<32768|(c[3541874]|0)==0){E=1;return E|0}else{F=0}while(1){if((F|0)>=1024){break}G=9638528+(F<<2)|0;if((c[G>>2]|0)==0){j=2455;break}else{F=F+1|0}}do{if((j|0)==2455){k=gGq(2048)|0;c[G>>2]=k;if((k|0)==0){break}gGz(k|0,0,2048);c[2405730]=k;fwR(0);k=c[2439330]|0;t=(k|0)==0;if(!t){v=k;gGC(9706056,v|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];v=c[3528484]|0;c[2076596]=v;d=c[2417276]|0;c[3541536]=d;c[1836236]=0;g=k+4180|0;if(a[7461808]|0){c[g>>2]=1978;c[k+4184>>2]=2578}else{c[g>>2]=1260;c[k+4184>>2]=2878}g=c[3541874]|0;y=0;x=0;while(1){c[k+76+(x<<2)>>2]=g+(x<<8);u=y+1&65535;if((u&65535)>127){H=0;I=0;break}else{y=u;x=u&65535}}while(1){x=g+(I<<8)|0;c[k+76+(I+512<<2)>>2]=x;c[k+76+(I+768<<2)>>2]=x;x=H+1&65535;if((x&65535)>127){break}else{H=x;I=x&65535}}c[3528526]=0;x=(c[2113246]|0)>>>0<49152?-32768:0;y=128;u=128;while(1){c[k+76+(u<<2)>>2]=g+(x+(u<<8));f=y+1&65535;if((f&65535)>191){J=128;K=128;break}else{y=f;u=f&65535}}while(1){u=g+(x+(K<<8))|0;c[k+76+(K+512<<2)>>2]=u;c[k+76+(K+768<<2)>>2]=u;u=J+1&65535;if((u&65535)>191){break}else{J=u;K=u&65535}}x=c[2405730]|0;c[k+908>>2]=x;u=x+256|0;c[k+912>>2]=u;y=x+512|0;c[k+916>>2]=y;f=x+768|0;c[k+920>>2]=f;o=x+1024|0;c[k+924>>2]=o;r=x+1280|0;c[k+928>>2]=r;s=x+1536|0;c[k+932>>2]=s;z=x+1792|0;c[k+936>>2]=z;c[k+1932>>2]=x;c[k+1936>>2]=u;c[k+1940>>2]=y;c[k+1944>>2]=f;c[k+1948>>2]=o;c[k+1952>>2]=r;c[k+1956>>2]=s;c[k+1960>>2]=z;c[k+2956>>2]=x;c[k+3980>>2]=x;c[k+2960>>2]=u;c[k+3984>>2]=u;c[k+2964>>2]=y;c[k+3988>>2]=y;c[k+2968>>2]=f;c[k+3992>>2]=f;c[k+2972>>2]=o;c[k+3996>>2]=o;c[k+2976>>2]=r;c[k+4e3>>2]=r;c[k+2980>>2]=s;c[k+4004>>2]=s;c[k+2984>>2]=z;c[k+4008>>2]=z;gGz(k+1036|0,0,64);gGz(k+2060|0,0,64);z=192;s=192;while(1){r=g+((s<<8)-49152)|0;c[k+76+(s+512<<2)>>2]=r;c[k+76+(s+768<<2)>>2]=r;r=z+1&65535;if((r&65535)>207){L=216;M=216;break}else{z=r;s=r&65535}}while(1){s=g+((M<<8)-55296)|0;c[k+76+(M+512<<2)>>2]=s;c[k+76+(M+768<<2)>>2]=s;s=L+1&65535;if((s&65535)>255){break}else{L=s;M=s&65535}}if(!t){g=k;gGC(g|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=v;c[2417276]=d;c[1836236]=-1;a[64264]=0;g=a[9680]|0;s=g?32e3:0;if(g){if(a[9624]|0){g=s*3|0;z=55930;while(1){if((z|0)>(g|0)){z=z>>1}else{N=1222;O=z;break}}}else{N=2462;O=s}c[2429380]=O;c[3542124]=N;mw(3579540,O);z=gGq(262144)|0;c[2406684]=z;gGz(z|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(3579540,11025)}h[745421]=.35;c[2436794]=3;h[745420]=.35;c[2436792]=3;z=a[9688]|0?2136:0;g=0;while(1){if((g|0)>=1024){j=2483;break}P=9638528+(g<<2)|0;if((c[P>>2]|0)==0){j=2482;break}else{g=g+1|0}}do{if((j|0)==2482){g=gGq(z)|0;c[P>>2]=g;if((g|0)==0){j=2483;break}gGz(g|0,0,z|0);c[2406808]=g;gGz(g|0,0,z|0);c[3541206]=c[3542044];if(a[7461928]|0){Ux(0,6061,1)}else{Ux(0,7576,1)}c[2407030]=77;c[2407068]=3;a[64264]=1}}while(0);do{if((j|0)==2483){c[2406808]=0;a[64264]=0;Uw(0);z=c[2406808]|0;g=0;while(1){if((g|0)>=1024){break}Q=9638528+(g<<2)|0;if((c[Q>>2]|0)==(z|0)){j=2486;break}else{g=g+1|0}}if((j|0)==2486){gGr(z);c[Q>>2]=0}c[2406808]=0;g=c[3531464]|0;c[g+44344>>2]=0;c[g+44348>>2]=0;if((g|0)!=0){gGr(g);c[3531464]=0}g=c[2406684]|0;if((g|0)==0){break}gGr(g);c[2406684]=0}}while(0);c[(c[3531464]|0)+44344>>2]=1460;a[14130592]=0;a[14130584]=0;c[2444124]=0;R=c[3542068]|0;S=a[7462128]|0;break L3236}}while(0);c[2405730]=0;E=1;return E|0}else{R=l;S=m}}while(0);if((R|0)==2&(a[7462104]^1)|S){if((c[2113246]|0)>>>0<32768|(c[3541874]|0)==0){E=1;return E|0}fwR(0);m=c[2439330]|0;l=(m|0)==0;if(!l){g=m;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];g=c[3528484]|0;c[2076596]=g;s=c[2417276]|0;c[3541536]=s;c[1836236]=0;c[m+4180>>2]=2072;c[m+4184>>2]=1290;d=a[7462128]|0;v=c[3541874]|0;if(d){k=(c[2113246]|0)>>>1;t=0;r=0;while(1){c[m+76+(r<<2)>>2]=v+((r<<8)-k);o=t+1&65535;if((o&65535)>127){T=0;U=0;break}else{t=o;r=o&65535}}while(1){r=U<<8;c[m+76+(U+512<<2)>>2]=v+r;c[m+76+(U+768<<2)>>2]=v+(r-k);r=T+1&65535;if((r&65535)>127){break}else{T=r;U=r&65535}}}else{k=0;r=0;while(1){c[m+76+(r<<2)>>2]=v+(r<<8);t=k+1&65535;if((t&65535)>127){V=0;X=0;break}else{k=t;r=t&65535}}while(1){r=v+(X<<8)|0;c[m+76+(X+512<<2)>>2]=r;c[m+76+(X+768<<2)>>2]=r;r=V+1&65535;if((r&65535)>127){break}else{V=r;X=r&65535}}}c[3528524]=0;Wx();r=c[3541878]|0;c[m+844>>2]=r;c[m+848>>2]=r+256;c[m+852>>2]=r+512;c[m+856>>2]=r+768;c[m+860>>2]=r+1024;c[m+864>>2]=r+1280;c[m+868>>2]=r+1536;c[m+872>>2]=r+1792;c[m+876>>2]=r+2048;c[m+880>>2]=r+2304;c[m+884>>2]=r+2560;c[m+888>>2]=r+2816;c[m+892>>2]=r+3072;c[m+896>>2]=r+3328;c[m+900>>2]=r+3584;c[m+904>>2]=r+3840;k=192;t=192;while(1){c[m+76+(t+256<<2)>>2]=r+((t<<8)-49152);o=k+1&65535;if((o&65535)>207){Y=192;Z=192;break}else{k=o;t=o&65535}}while(1){t=r+((Z<<8)-49152)|0;c[m+76+(Z+512<<2)>>2]=t;c[m+76+(Z+768<<2)>>2]=t;t=Y+1&65535;if((t&65535)>207){break}else{Y=t;Z=t&65535}}gGz(m+908|0,0,128);gGz(m+1932|0,0,128);if(d){r=(c[2113246]|0)>>>1;t=208;k=208;while(1){o=(k<<8)-53248|0;c[m+76+(k+512<<2)>>2]=v+o;c[m+76+(k+768<<2)>>2]=v+(o-r);o=t+1&65535;if((o&65535)>239){break}else{t=o;k=o&65535}}}else{k=208;t=208;while(1){r=v+((t<<8)-53248)|0;c[m+76+(t+512<<2)>>2]=r;c[m+76+(t+768<<2)>>2]=r;r=k+1&65535;if((r&65535)>239){break}else{k=r;t=r&65535}}}t=c[3541876]|0;c[m+1036>>2]=t;c[m+1040>>2]=t+256;c[m+1044>>2]=t+512;c[m+1048>>2]=t+768;c[m+1052>>2]=t+1024;c[m+1056>>2]=t+1280;c[m+1060>>2]=t+1536;c[m+1064>>2]=t+1792;c[m+1068>>2]=t+2048;c[m+1072>>2]=t+2304;c[m+1076>>2]=t+2560;c[m+1080>>2]=t+2816;c[m+1084>>2]=t+3072;c[m+1088>>2]=t+3328;c[m+1092>>2]=t+3584;c[m+1096>>2]=t+3840;k=240;v=240;while(1){c[m+76+(v+256<<2)>>2]=t+((v<<8)-61440);r=k+1&65535;if((r&65535)>255){_=240;$=240;break}else{k=r;v=r&65535}}while(1){v=t+(($<<8)-61440)|0;c[m+76+($+512<<2)>>2]=v;c[m+76+($+768<<2)>>2]=v;v=_+1&65535;if((v&65535)>255){break}else{_=v;$=v&65535}}if(!l){t=m;gGC(t|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=g;c[2417276]=s;c[1836236]=-1;c[2429844]=7710;c[2429842]=80;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;c[2113248]=((d?6e8:8e8)|0)/(c[2424]|0)|0;c[2438228]=d?6e6:8e6;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=d?340:255;c[2394736]=a[9680]|0?32e3:0;t=0;do{c[9754360+(t<<2)>>2]=~~(+W(+(+(t|0)))*45.25483399593904);t=t+1|0;}while((t|0)<33);gGz(9673112,0,896);t=c[3541940]|0;c[2418279]=t;c[2418293]=t;c[2418307]=t;c[2418321]=t;c[2418335]=t;c[2418349]=t;c[2418363]=t;c[2418377]=t;c[2418391]=t;c[2418405]=t;c[2418419]=t;c[2418433]=t;c[2418447]=t;c[2418461]=t;c[2418475]=t;c[2418489]=t;h[80230]=1.0;a[6163584]=1;h[80229]=1.0;a[6163576]=1;aa=c[3542068]|0;ab=d}else{aa=R;ab=0}if((aa|0)==2|a[7461720]|ab|a[7462008]){c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2]}t=c[3541914]|0;if((t|0)!=0){gD[t&8191]()|0}agU();t=(c[3542068]|0)==2;c[3541960]=t?6184:3228;c[3541884]=t?1408:8694;c[3541882]=t?12332:5744;c[3541952]=t?13656:15606;c[3541660]=t?68:94;c[3541658]=t?586:3678;c[2112966]=c[3541942];E=0;return E|0}}while(0);c[2411926]=0;E=1;return E|0}}while(0);c[3541942]=0;E=1;return E|0}}while(0);c[2388324]=0;E=1;return E|0}}while(0);c[2414530]=0;E=1;return E|0}function agU(){var d=0,e=0,f=0,g=0,i=0,j=0;if((c[3542068]|0)==2|a[7461720]|a[7462128]|a[7462008]){c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2]}if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;d=c[3542068]|0;if((d&1|0)==0|a[7462160]){if(!((d|0)!=2|a[7462104])){f=2545}}else{f=2545}if((f|0)==2545){f=c[2439330]|0;e=(f|0)==0;if(!e){g=f;gGC(9706056,g|0,76)|0}g=c[2438118]|0;c[2433530]=g;i=c[3528484]|0;c[2076596]=i;j=c[2417276]|0;c[3541536]=j;c[1836236]=0;gGz(9706056,0,76);if(!e){e=f;gGC(e|0,9706056,76)|0}c[2438118]=g;c[3528484]=i;c[2417276]=j;c[1836236]=-1}j=(d|0)==2;if(j){d=c[3541926]|0;b[d+78>>1]=512;i=a[9640]|0?262:259;b[d+80>>1]=i;b[d+82>>1]=i}c[2394]=0;c[2112932]=c[3532596];i=c[3532592]|0;if((i|0)!=0){gGC(9104152,i|0,280)|0}d=c[2113060]|0;c[2113054]=d;Wz(0);if((i|0)!=0){gGC(i|0,9104152,280)|0}c[2113060]=d;c[2394]=-1;c[2433566]=0;if(j&(a[7462104]^1)|a[7462128]){j=c[2439330]|0;if((j|0)!=0){d=j;gGC(9706056,d|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;gu[c[3528472]&16383]();c[2443830]=8126984;c[2443822]=8126984;d=gD[c[2433526]&8191]()|0;j=gGU(d,(d|0)<0|0?-1:0,2048e6,0)|0;d=c[2438228]|0;i=gGS(j,K,d,(d|0)<0|0?-1:0)|0;d=gGK(c[2443830]|0,0,i,K)|0;c[2443830]=d;d=c[1836236]|0;i=c[9757320+(d<<2)>>2]|0;if((i|0)!=0){j=i;gGC(j|0,9706056,76)|0}c[9752472+(d<<2)>>2]=c[2433530];c[14113936+(d<<2)>>2]=c[2076596];c[9669104+(d<<2)>>2]=c[3541536];c[1836236]=-1;c[2432836]=0}d=c[3541912]|0;if((d|0)==0){return}gD[d&8191]()|0;return}function agV(){var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=i;i=i+128|0;e=c[3542068]|0;if((e|0)==2|a[7461720]|a[7462128]|a[7462008]){f=d|0;g=c[c[642608+(c[2436]<<2)>>2]>>2]|0;be(f|0,128,179600,(h=i,i=i+24|0,c[h>>2]=9374064,c[h+8>>2]=47,c[h+16>>2]=g,h)|0)|0;i=h;a[1040128]=0;h=c[2420380]|0;g=c[h>>2]|0;j=c[h+4>>2]|0;h=fw(f|0,389440)|0;if((h|0)!=0){f=j>>3<<g&1023;cj(14100392,f|0,1,h|0)|0;aY(h|0)|0}k=c[3542068]|0;l=a[7462128]|0}else{k=e;l=0}if((k|0)==2&(a[7462104]^1)|l){c[2394736]=0;l=c[2424774]|0;e=0;while(1){if((e|0)>=1024){break}m=9638528+(e<<2)|0;if((c[m>>2]|0)==(l|0)){n=2575;break}else{e=e+1|0}}if((n|0)==2575){gGr(l);c[m>>2]=0}c[2424774]=0;c[170120]=-1;fwZ();o=c[3542068]|0;p=a[7462128]|0}else{o=k;p=0}if(!(p|(o|0)==2|a[7462160])){a[64264]=0;Uw(0);o=c[2406808]|0;p=0;while(1){if((p|0)>=1024){break}q=9638528+(p<<2)|0;if((c[q>>2]|0)==(o|0)){n=2581;break}else{p=p+1|0}}if((n|0)==2581){gGr(o);c[q>>2]=0}c[2406808]=0;q=c[3531464]|0;c[q+44344>>2]=0;c[q+44348>>2]=0;if((q|0)!=0){gGr(q);c[3531464]=0}q=c[2406684]|0;if((q|0)!=0){gGr(q);c[2406684]=0}q=c[2405730]|0;o=0;while(1){if((o|0)>=1024){break}r=9638528+(o<<2)|0;if((c[r>>2]|0)==(q|0)){n=2589;break}else{o=o+1|0}}if((n|0)==2589){gGr(q);c[r>>2]=0}c[2405730]=0;fwZ()}if(a[7024720]|0){c[2426852]=0;c[2426853]=0;c[2426856]=0;c[2426857]=0}r=c[2411926]|0;q=0;while(1){if((q|0)>=1024){break}s=9638528+(q<<2)|0;if((c[s>>2]|0)==(r|0)){n=2596;break}else{q=q+1|0}}if((n|0)==2596){gGr(r);c[s>>2]=0}c[2411926]=0;a[7024720]=0;c[2420374]=0;a[7462176]=0;c[3542064]=0;c[3542066]=0;s=c[3541942]|0;r=0;while(1){if((r|0)>=1024){break}t=9638528+(r<<2)|0;if((c[t>>2]|0)==(s|0)){n=2600;break}else{r=r+1|0}}if((n|0)==2600){gGr(s);c[t>>2]=0}c[3541942]=0;t=c[2388324]|0;s=0;while(1){if((s|0)>=1024){break}u=9638528+(s<<2)|0;if((c[u>>2]|0)==(t|0)){n=2604;break}else{s=s+1|0}}if((n|0)==2604){gGr(t);c[u>>2]=0}c[2388324]=0;c[3531284]=0;a[14165112]=0;u=14168104;c[u>>2]=0;c[u+4>>2]=0;a[14165104]=0;u=14168096;c[u>>2]=0;c[u+4>>2]=0;a[14165096]=0;u=14168088;c[u>>2]=0;c[u+4>>2]=0;a[14165088]=0;u=14168080;c[u>>2]=0;c[u+4>>2]=0;a[14165080]=0;u=14168072;c[u>>2]=0;c[u+4>>2]=0;a[14165072]=0;u=14168064;c[u>>2]=0;c[u+4>>2]=0;a[14165064]=0;u=14168056;c[u>>2]=0;c[u+4>>2]=0;a[14165056]=0;u=14168048;c[u>>2]=0;c[u+4>>2]=0;a[14165048]=0;u=14168040;c[u>>2]=0;c[u+4>>2]=0;a[14165040]=0;u=14168032;c[u>>2]=0;c[u+4>>2]=0;a[14165032]=0;u=14168024;c[u>>2]=0;c[u+4>>2]=0;a[14165024]=0;u=14168016;c[u>>2]=0;c[u+4>>2]=0;a[14165016]=0;u=14168008;c[u>>2]=0;c[u+4>>2]=0;a[14165008]=0;u=14168e3;c[u>>2]=0;c[u+4>>2]=0;a[14165e3]=0;u=14167976;c[u>>2]=0;c[u+4>>2]=0;a[14164992]=0;u=14167968;c[u>>2]=0;c[u+4>>2]=0;a[14164984]=0;u=14167960;c[u>>2]=0;c[u+4>>2]=0;a[14164976]=0;u=14167952;c[u>>2]=0;c[u+4>>2]=0;a[14164968]=0;u=14167944;c[u>>2]=0;c[u+4>>2]=0;a[9628480]=0;u=14167920;c[u>>2]=0;c[u+4>>2]=0;a[9628472]=0;u=14167912;c[u>>2]=0;c[u+4>>2]=0;a[9628464]=0;u=14167904;c[u>>2]=0;c[u+4>>2]=0;a[9628456]=0;u=14167896;c[u>>2]=0;c[u+4>>2]=0;b[7083992]=0;b[7083996]=0;c[3541938]=0;u=c[2414530]|0;t=0;while(1){if((t|0)>=1024){break}v=9638528+(t<<2)|0;if((c[v>>2]|0)==(u|0)){n=2608;break}else{t=t+1|0}}if((n|0)==2608){gGr(u);c[v>>2]=0}c[2414530]=0;c[3541954]=0;if((c[2392]|0)>=0){v=0;do{u=14130368+(v<<2)|0;n=c[u>>2]|0;if((n|0)!=0){gGr(n);c[u>>2]=0}u=14130384+(v<<2)|0;n=c[u>>2]|0;if((n|0)!=0){gGr(n);c[u>>2]=0}v=v+1|0;}while((v|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;v=c[3541920]|0;if((v|0)==0){c[3541914]=0;c[3541912]=0;c[3541916]=0;c[3541918]=0;c[1865530]=2;a[7462104]=0;a[7462008]=0;i=d;return}gD[v&8191]()|0;c[3541920]=0;c[3541914]=0;c[3541912]=0;c[3541916]=0;c[3541918]=0;c[1865530]=2;a[7462104]=0;a[7462008]=0;i=d;return}function agW(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((a[14167696]|0)!=0){agU()}d=c[2392]|0;if((d|0)>=0){gGz(8452240,0,((d|0)>0?(d<<2)+4|0:4)|0)}c[2113054]=0;do{if(a[7462128]|0){d=c[2385548]|0;if((d|0)>0){gGz(9752472,0,((d|0)>1?d<<2:4)|0)}c[2433530]=0;d=c[2439330]|0;if((d|0)!=0){e=d;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;e=c[2438118]|0;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;c[2433530]=(c[2432836]|0)+e;c[2420370]=0}else{if(a[7462160]|0){break}e=c[2439330]|0;if((e|0)!=0){d=e;gGC(9706056,d|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;d=c[2385548]|0;if((d|0)>0){gGz(9752472,0,((d|0)>1?d<<2:4)|0)}c[2420372]=0;c[2385480]=c[2443848];c[2433530]=(c[2444124]|0)%(c[2113248]|0)|0;c[2444124]=0}}while(0);d=c[3541916]|0;if((d|0)!=0){gu[d&16383]()}d=c[2113296]|0;e=c[2438]|0;f=gGU(e,(e|0)<0|0?-1:0,d,(d|0)<0|0?-1:0)|0;d=f>>>8|K<<24;f=d;c[2113270]=f;VV();e=a[9640]|0?262:259;g=(f*240|0|0)/(e|0)|0;if((c[2394]|0)==0){h=c[2113054]|0}else{c[2394]=0;c[2112932]=c[3532596];f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}f=c[2113060]|0;c[2113054]=f;h=f}c[2113054]=h+(c[2433566]|0);h=(d<<4|0>>>28|0)/(e|0)|0;c[2113056]=h;e=RG(h)|0;c[2113054]=(c[2113054]|0)+e;c[2276108]=-1;c[2113056]=-1;VD();e=0;h=c[2113054]|0;d=c[2113056]|0;f=c[2276108]|0;while(1){i=e+1|0;j=(ag(c[2113270]|0,i)|0)>>2;if((d+h-f|0)<(g|0)&(j|0)>(g|0)){k=j-g|0;c[2113056]=k;l=RG(k)|0;c[2113054]=(c[2113054]|0)+l;c[2276108]=-1;c[2113056]=-1;l=c[3541886]|0;k=c[3541926]|0;gGC(l|0,k|0,256)|0;k=c[1865530]|0;c[8452200+(c[2394]<<2)>>2]=k|8192;l=c[2276080]|0;m=k<<8;c[2276080]=m;do{if((l|0)!=1792&(m|0)==1792){RH(7)}else{if(m>>>0<=(c[2276079]|0)>>>0){break}RH(k&16777215)}}while(0);n=c[2113054]|0;o=c[2113056]|0;p=c[2276108]|0}else{n=h;o=d;p=f}k=p+j-o-n|0;c[2113056]=k;m=RG(k)|0;k=(c[2113054]|0)+m|0;c[2113054]=k;c[2276108]=-1;c[2113056]=-1;if((i|0)<4){e=i;h=k;d=-1;f=-1}else{break}}if((c[2112968]|0)!=0){asS()}do{if(a[7462128]|0){WX()}else{if(a[7462160]|0){break}Wv(c[2113248]|0);f=a[9688]|0?534:0;d=c[2112964]|0;do{if(!((d|0)==0|a[64264]^1)){h=c[2420372]|0;if((h|0)>=(f|0)){break}gg[c[3542124]&4095](d+(h<<1<<1)|0,f-h|0);h=c[2420372]|0;Uu(0,(c[2112964]|0)+(h<<1<<1)|0,f-h|0);c[2420372]=f}}while(0);f=c[1836236]|0;d=c[9757320+(f<<2)>>2]|0;if((d|0)!=0){i=d;gGC(i|0,9706056,76)|0}c[9752472+(f<<2)>>2]=c[2433530];c[14113936+(f<<2)>>2]=c[2076596];c[9669104+(f<<2)>>2]=c[3541536];c[1836236]=-1}}while(0);f=c[3541918]|0;if((f|0)!=0){gu[f&16383]()}f=c[2113054]|0;c[2433566]=(c[2113056]|0)+f-(c[2276108]|0)-(c[2113270]|0);i=c[2394]|0;d=c[14130368+(i<<2)>>2]|0;if((d|0)==0){q=8452240+(i<<2)|0;c[q>>2]=f;c[2394]=-1;return 0}gGC(d|0,9104152,280)|0;q=8452240+(i<<2)|0;c[q>>2]=f;c[2394]=-1;return 0}function agX(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0.0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;if((a[14167696]|0)!=0){agU()}d=c[2392]|0;if((d|0)>=0){gGz(8452240,0,((d|0)>0?(d<<2)+4|0:4)|0)}c[2113054]=0;if(!(a[7462104]|0)){d=c[2385548]|0;if((d|0)>0){gGz(9752472,0,((d|0)>1?d<<2:4)|0)}c[2433530]=0;d=c[2439330]|0;if((d|0)!=0){e=d;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;e=c[2438118]|0;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;c[2433530]=(c[2432836]|0)+e;c[2420370]=0}e=c[2113296]|0;d=c[2438]|0;f=gGU(d,(d|0)<0|0?-1:0,e,(e|0)<0|0?-1:0)|0;e=gGS(f,K,256,0)|0;f=e;c[2113270]=f;if((c[2394]|0)==0){g=0}else{c[2394]=0;c[2112932]=c[3532596];e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}e=c[2113060]|0;c[2113054]=e;g=e}e=a[9640]|0?262:259;c[2113058]=(f|0)/(e|0)|0;VV();if(((c[2113222]|0)%5|0|0)==0){d=c[1865524]|0;if((a[14168240]|0)==0){i=d}else{j=d+1|0;c[1865524]=j;i=j}if((a[14168248]|0)==0){k=i}else{j=i-1|0;c[1865524]=j;k=j}do{if((k|0)>39){c[1865524]=39;l=39}else{if((k|0)>=0){l=k;break}c[1865524]=0;l=0}}while(0);m=+(l|0)/39.0;h[80230]=m;a[6163584]=1;h[80229]=m;a[6163576]=1}c[3528538]=0;gGz(8452320,0,48);l=(f*240|0|0)/(e|0)|0;a[1616480]=0;a[1616488]=0;c[2113190]=e;c[2113192]=e;k=c[3541926]|0;j=b[k+80>>1]|0;if(j<<16>>16<0){a[1616488]=1;n=2696}else{if((b[k+78>>1]&512)==0){n=2696}else{o=e}}if((n|0)==2696){i=j&511;c[2113192]=i;o=i}i=b[k+82>>1]|0;if(i<<16>>16<0){a[1616480]=1;n=2700}else{if((b[k+78>>1]&512)==0){n=2700}else{p=e}}if((n|0)==2700){n=i&511;c[2113190]=n;p=n}n=o>>>0>e>>>0?e:o;o=p>>>0<n>>>0?p:n;if(o>>>0<e>>>0){c[2394754]=o;q=(ag(o,f)|0)/(e|0)|0}else{q=f}o=q+1|0;c[3528536]=o;q=g+(c[2433566]|0)|0;c[2113054]=q;if((o|0)<((f<<4|0)/(e|0)|0|0)){c[2113056]=o;g=RG(o)|0;c[2113054]=(c[2113054]|0)+g;c[2276108]=-1;c[2113056]=-1;agY();r=c[2113270]|0;s=a[9640]|0?262:259;t=c[2113054]|0}else{r=f;s=e;t=q}q=(r<<4|0)/(s|0)|0;r=c[2113056]|0;e=c[2276108]|0;f=r+t-e|0;if((f|0)<(q|0)){g=q-f|0;c[2113056]=g;f=RG(g)|0;g=(c[2113054]|0)+f|0;c[2113054]=g;c[2276108]=-1;c[2113056]=-1;u=a[9640]|0?262:259;v=g;w=-1;x=-1}else{u=s;v=t;w=r;x=e}e=c[3541886]|0;r=c[3541926]|0;gGC(e|0,r|0,256)|0;e=c[3541900]|0;t=c[3542030]|0;gGC(e|0,t|0,16)|0;do{if((c[2394754]|0)>=(u|0)){if((b[r+78>>1]&512)!=0){break}t=b[r+80>>1]&511;c[2113192]=t;e=b[r+82>>1]&511;c[2113190]=e;s=(t|0)>(u|0)?u:t;t=(e|0)<(s|0)?e:s;if((t|0)<(u|0)){c[2394754]=t;y=(ag(c[2113270]|0,t)|0)/(u|0)|0}else{y=c[2113270]|0}c[3528536]=y+1}}while(0);y=(l|0)/3|0;u=c[3528536]|0;r=w+v-x|0;if((y|0)>(u|0)&(c[3528538]|0)<10){x=u;u=r;while(1){v=x-u|0;c[2113056]=v;w=RG(v)|0;c[2113054]=(c[2113054]|0)+w;c[2276108]=-1;c[2113056]=-1;agY();w=c[3528536]|0;v=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;if((y|0)>(w|0)&(c[3528538]|0)<10){x=w;u=v}else{z=v;break}}}else{z=r}r=y-z|0;c[2113056]=r;z=RG(r)|0;r=(c[2113054]|0)+z|0;c[2113054]=r;c[2276108]=-1;c[2113056]=-1;z=(l<<1|0)/3|0;y=c[3528536]|0;if((z|0)>(y|0)&(c[3528538]|0)<10){u=y;y=r;while(1){x=u-y|0;c[2113056]=x;v=RG(x)|0;c[2113054]=(c[2113054]|0)+v;c[2276108]=-1;c[2113056]=-1;agY();v=c[3528536]|0;x=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;if((z|0)>(v|0)&(c[3528538]|0)<10){u=v;y=x}else{A=x;break}}}else{A=r}r=z-A|0;c[2113056]=r;A=RG(r)|0;r=(c[2113054]|0)+A|0;c[2113054]=r;c[2276108]=-1;c[2113056]=-1;A=c[3528536]|0;if((l|0)>(A|0)&(c[3528538]|0)<10){z=A;A=r;while(1){y=z-A|0;c[2113056]=y;u=RG(y)|0;c[2113054]=(c[2113054]|0)+u;c[2276108]=-1;c[2113056]=-1;agY();u=c[3528536]|0;y=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;if((l|0)>(u|0)&(c[3528538]|0)<10){z=u;A=y}else{B=y;break}}}else{B=r}r=l-B|0;c[2113056]=r;B=RG(r)|0;c[2113054]=(c[2113054]|0)+B;c[2276108]=-1;c[2113056]=-1;VD();c[8452200+(c[2394]<<2)>>2]=8194;c[2276080]=512;if((c[2276079]|0)>>>0<512){RH(2)}if((c[2112968]|0)!=0){asS()}B=(c[2113270]|0)-(c[2113054]|0)-(c[2113056]|0)+(c[2276108]|0)|0;c[2113056]=B;r=RG(B)|0;B=(c[2113054]|0)+r|0;c[2113054]=B;c[2276108]=-1;c[2113056]=-1;c[2433566]=B-(c[2113270]|0);if(!(a[7462104]|0)){WX()}B=c[2394]|0;r=c[14130368+(B<<2)>>2]|0;if((r|0)==0){C=c[2113054]|0;D=8452240+(B<<2)|0;c[D>>2]=C;c[2394]=-1;return 0}gGC(r|0,9104152,280)|0;C=c[2113054]|0;D=8452240+(B<<2)|0;c[D>>2]=C;c[2394]=-1;return 0}function agY(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[2394754]|0;if((b|0)>15){d=(c[3528538]|0)+1|0;c[3528538]=d;c[8452320+(d<<2)>>2]=b-16}c[8452200+(c[2394]<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0<1024){RH(4)}b=(c[2113270]|0)/((a[9640]|0?262:259)|0)|0;c[2113056]=b;d=RG(b)|0;b=(c[2113054]|0)+d|0;c[2113054]=b;c[2276108]=-1;c[2113056]=-1;d=c[3528538]|0;e=8452320+(d<<2)|0;if((c[e>>2]|0)<224){f=c[14167544+(d<<2)>>2]|0;g=c[3541926]|0;gGC(f|0,g|0,256)|0;g=c[14167600+(d<<2)>>2]|0;d=c[3542030]|0;gGC(g|0,d|0,16)|0}else{c[e>>2]=0}e=c[2394754]|0;d=c[2113192]|0;do{if(a[1616488]|0){if((e|0)!=(d|0)){h=d;break}g=e+32|0;c[2113192]=g;h=g}else{if((e|0)<(d|0)){h=d;break}g=a[9640]|0?262:259;c[2113192]=g;h=g}}while(0);d=c[2113190]|0;do{if(a[1616480]|0){if((e|0)!=(d|0)){i=d;break}g=e+32|0;c[2113190]=g;i=g}else{if((e|0)<(d|0)){i=d;break}g=a[9640]|0?262:259;c[2113190]=g;i=g}}while(0);d=a[9640]|0?262:259;e=(h|0)>(d|0)?d:h;h=(i|0)<(e|0)?i:e;if((h|0)<(d|0)){c[2394754]=h;j=(ag(c[2113270]|0,h)|0)/(d|0)|0;k=j+1|0;l=(k|0)<(b|0);m=b+1|0;n=l?m:k;c[3528536]=n;return}else{j=c[2113270]|0;k=j+1|0;l=(k|0)<(b|0);m=b+1|0;n=l?m:k;c[3528536]=n;return}}function agZ(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;e=c[2113248]|0;f=e;g=(e|0)<0|0?-1:0;e=gGU(d,(d|0)<0|0?-1:0,f,g)|0;d=c[2113270]|0;h=gGS(e,K,d,(d|0)<0|0?-1:0)|0;d=gGL(h,K,(c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0,0)|0;h=c[2438574]|0;e=c[2427048]|0;i=d;d=gGU(i,(i|0)<0|0?-1:0,e,(e|0)<0|0?-1:0)|0;e=gGS(d,K,f,g)|0;g=gGK(e,K,h,0)|0;e=g;if((h|0)<(e|0)){j=h}else{k=b&65535;l=k&255;c[2433338]=l;a[9706117]=1;return}do{h=c[2427082]|0;do{if((h|0)>=1){if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){g=gfc(h)|0;c[2433530]=(c[2433530]|0)+g;break}else{c[2433530]=(c[2433530]|0)+h;break}}}while(0);UD();c[2438574]=j;j=j+1|0;}while((j|0)<(e|0));k=b&65535;l=k&255;c[2433338]=l;a[9706117]=1;return}function ag_(b){b=b|0;var d=0,e=0;d=b&65535;if((d|0)==55297){e=c[(c[3531464]|0)+4240>>2]&255;return e|0}else if((d|0)==56320){a[9706117]=0;e=c[2433338]&255;return e|0}else{e=0;return e|0}return 0}function ag$(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,i=0,j=0;switch(b&65535|0){case 55296:{c[2113304]=d&255;return};case 55297:{b=c[2113304]|0;a[14168504+b|0]=d;mv(0,b,d&255);return};case 57344:{b=d&255;h[1207773]=(b&32|0)!=0?0.0:.25;c[2415548]=3;c[2415126]=9665376;h[1208176]=(b&16|0)!=0?0.0:.25;c[2416354]=3;e=(c[2430840]&b)<<14;c[2429488]=e;b=c[3541874]|0;f=c[9757320+(c[1836236]<<2)>>2]|0;g=e-32768|0;e=128;i=128;while(1){c[f+76+(i<<2)>>2]=b+(g+(i<<8));j=e+1&65535;if((j&65535)>191){break}else{e=j;i=j&65535}}i=(c[2429488]|0)-32768|0;e=128;g=128;while(1){j=b+(i+(g<<8))|0;c[f+76+(g+512<<2)>>2]=j;c[f+76+(g+768<<2)>>2]=j;j=e+1&65535;if((j&65535)>191){break}else{e=j;g=j&65535}}return};case 58368:{c[2429714]=d&255;return};case 59392:{c[2429712]=d&255;return};default:{return}}}function ag0(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;d=0;while(1){if((d|0)>=1024){e=0;break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==0){g=2788;break}else{d=d+1|0}}do{if((g|0)==2788){d=gGq(2048)|0;c[f>>2]=d;if((d|0)==0){e=0;break}gGz(d|0,0,2048);e=d}}while(0);c[2442956]=e;fwR(0);e=c[2439330]|0;f=(e|0)==0;if(!f){g=e;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];g=c[3528484]|0;c[2076596]=g;d=c[2417276]|0;c[3541536]=d;c[1836236]=0;c[e+4180>>2]=252;c[e+4184>>2]=846;i=c[3541874]|0;j=0;k=0;while(1){c[e+76+(k<<2)>>2]=i+(k<<8);l=j+1&65535;if((l&65535)>127){m=0;n=0;break}else{j=l;k=l&65535}}while(1){k=i+(n<<8)|0;c[e+76+(n+512<<2)>>2]=k;c[e+76+(n+768<<2)>>2]=k;k=m+1&65535;if((k&65535)>127){o=128;p=128;break}else{m=k;n=k&65535}}while(1){c[e+76+(p<<2)>>2]=i+(p<<8);n=o+1&65535;if((n&65535)>191){q=128;r=128;break}else{o=n;p=n&65535}}while(1){p=i+(r<<8)|0;c[e+76+(r+512<<2)>>2]=p;c[e+76+(r+768<<2)>>2]=p;p=q+1&65535;if((p&65535)>191){break}else{q=p;r=p&65535}}r=c[2442956]|0;c[e+908>>2]=r;q=r+256|0;c[e+912>>2]=q;i=r+512|0;c[e+916>>2]=i;p=r+768|0;c[e+920>>2]=p;o=r+1024|0;c[e+924>>2]=o;n=r+1280|0;c[e+928>>2]=n;m=r+1536|0;c[e+932>>2]=m;k=r+1792|0;c[e+936>>2]=k;c[e+1932>>2]=r;c[e+1936>>2]=q;c[e+1940>>2]=i;c[e+1944>>2]=p;c[e+1948>>2]=o;c[e+1952>>2]=n;c[e+1956>>2]=m;c[e+1960>>2]=k;c[e+2956>>2]=r;c[e+3980>>2]=r;c[e+2960>>2]=q;c[e+3984>>2]=q;c[e+2964>>2]=i;c[e+3988>>2]=i;c[e+2968>>2]=p;c[e+3992>>2]=p;c[e+2972>>2]=o;c[e+3996>>2]=o;c[e+2976>>2]=n;c[e+4e3>>2]=n;c[e+2980>>2]=m;c[e+4004>>2]=m;c[e+2984>>2]=k;c[e+4008>>2]=k;if(!f){f=e;gGC(f|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=g;c[2417276]=d;c[1836236]=-1;d=a[9680]|0;g=d?32e3:0;if(!d){mw(3579540,11025);h[745421]=.35;c[2436794]=3;h[745420]=.35;c[2436792]=3;UB(0,1268,375e3,9636,4);UB(1,1268,375e3,1568,4);h[1207773]=.25;c[2415548]=3;c[2415126]=9665376;h[1208176]=.25;c[2416354]=3;s=c[2424]|0;t=357954e3/(s|0)|0;c[2113248]=t;u=c[2113246]|0;v=u>>>14;w=v-1|0;c[2430840]=w;return 0}if(a[9624]|0){d=g*3|0;f=55930;while(1){if((f|0)>(d|0)){f=f>>1}else{x=1222;y=f;break}}}else{x=2462;y=g}c[2429380]=y;c[3542124]=x;mw(3579540,y);y=gGq(262144)|0;c[2406684]=y;gGz(y|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3;h[745421]=.35;c[2436794]=3;h[745420]=.35;c[2436792]=3;UB(0,1268,375e3,9636,4);UB(1,1268,375e3,1568,4);h[1207773]=.25;c[2415548]=3;c[2415126]=9665376;h[1208176]=.25;c[2416354]=3;s=c[2424]|0;t=357954e3/(s|0)|0;c[2113248]=t;u=c[2113246]|0;v=u>>>14;w=v-1|0;c[2430840]=w;return 0}function ag1(a){a=a|0;var b=0.0;b=+(a|0)*+((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)/3579540.0;+V(b)>=1.0?b>0.0?(al(+U(b/4294967296.0),4294967295.0)|0)>>>0:~~+af((b- +(~~b>>>0))/4294967296.0)>>>0:0;return~~b>>>0|0}function ag2(){var b=0,d=0,e=0;b=c[2429714]|0;d=b&15;c[2415126]=9662152;if((c[2415542]|0)==4){e=d}else{e=d<<1&14}c[2415538]=e;c[2429714]=b>>4;b=c[2429710]|0;c[2429710]=b^1;if((b|0)!=1){return}if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12;return}function ag3(){var a=0,b=0,d=0;a=c[2429712]|0;b=a&15;c[2415126]=9665376;if((c[2416348]|0)==4){d=b}else{d=b<<1&14}c[2416344]=d;c[2429712]=a>>4;c[2429708]=c[2429708]^1;return}function ag4(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0;a=c[2439330]|0;if((a|0)!=0){b=a;gGC(9706056,b|0,76)|0}c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;gGz(9706056,0,76);mx(0);UA();c[2429488]=32768;b=c[3541874]|0;a=c[1836236]|0;d=c[9757320+(a<<2)>>2]|0;e=128;f=128;while(1){c[d+76+(f<<2)>>2]=b+(f<<8);g=e+1&65535;if((g&65535)>191){break}else{e=g;f=g&65535}}f=(c[2429488]|0)-32768|0;e=128;g=128;while(1){h=b+(f+(g<<8))|0;c[d+76+(g+512<<2)>>2]=h;c[d+76+(g+768<<2)>>2]=h;h=e+1&65535;if((h&65535)>191){break}else{e=h;g=h&65535}}g=d;gGC(g|0,9706056,76)|0;c[9752472+(a<<2)>>2]=c[2433530];c[14113936+(a<<2)>>2]=c[2076596];c[9669104+(a<<2)>>2]=c[3541536];c[1836236]=-1;c[2433338]=0;c[2429714]=0;c[2429712]=0;c[2429710]=0;c[2429708]=0;return 0}function ag5(){var a=0,b=0,d=0,e=0,f=0,g=0;fwZ();a=c[3531464]|0;c[a+44344>>2]=0;c[a+44348>>2]=0;if((a|0)!=0){gGr(a);c[3531464]=0}a=c[2406684]|0;if((a|0)!=0){gGr(a);c[2406684]=0}c[2415126]=9662152;a=c[2408988]|0;if((a|0)!=0){gGz(9662152,0,3224);b=a;a=0;while(1){if((a|0)>=1024){break}d=9638528+(a<<2)|0;if((c[d>>2]|0)==(b|0)){e=2836;break}else{a=a+1|0}}if((e|0)==2836){gGr(b);c[d>>2]=0}c[2408988]=0}c[2415126]=9665376;d=c[2408989]|0;if((d|0)!=0){gGz(9665376,0,3224);b=d;d=0;while(1){if((d|0)>=1024){break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==(b|0)){e=2842;break}else{d=d+1|0}}if((e|0)==2842){gGr(b);c[f>>2]=0}c[2408989]=0}f=c[2442956]|0;b=0;while(1){if((b|0)>=1024){break}g=9638528+(b<<2)|0;if((c[g>>2]|0)==(f|0)){e=2847;break}else{b=b+1|0}}if((e|0)==2847){gGr(f);c[g>>2]=0}c[2442956]=0;c[2429488]=0;c[2433338]=0;c[2427048]=0;c[2429714]=0;c[2429712]=0;c[2429710]=0;c[2429708]=0;c[2427082]=0;c[2430840]=0;c[2113248]=0;return 0}function ag6(){var a=0,d=0,e=0;c[2415126]=9662152;a=c[2415557]|0;d=a&3;if((d|0)==3){e=133}else{e=(3579540/(3579540/((c[2415554]|0)/(c[600992+((a>>>3&1)<<4)+(d<<2)>>2]|0)|0|0)|0|0)|0|0)/((c[2424]|0)/100|0|0)|0}c[2427048]=e;c[2438574]=0;d=c[2113248]|0;a=gGS(d,(d|0)<0|0?-1:0,e,(e|0)<0|0?-1:0)|0;c[2427082]=a;a=c[2385548]|0;if((a|0)>0){gGz(9752472,0,((a|0)>1?a<<2:4)|0)}c[2433530]=0;a=c[2439330]|0;if((a|0)!=0){e=a;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;return}function ag7(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[2438574]|0;if((b|0)<(c[2427048]|0)){d=b;do{b=c[2427082]|0;do{if((b|0)>=1){if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){e=gfc(b)|0;c[2433530]=(c[2433530]|0)+e;break}else{c[2433530]=(c[2433530]|0)+b;break}}}while(0);UD();c[2438574]=d;d=d+1|0;}while((d|0)<(c[2427048]|0))}d=c[2433530]|0;b=(c[2113248]|0)-d-(c[2426530]|0)+(c[2076596]|0)|0;do{if((b|0)>=1){if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){e=gfc(b)|0;c[2433530]=(c[2433530]|0)+e;break}else{c[2433530]=b+d;break}}}while(0);d=c[2112964]|0;if((d|0)!=0){gg[c[3542124]&4095](d,a[9688]|0?534:0);Uz(0,c[2112964]|0,a[9688]|0?534:0);Uz(1,c[2112964]|0,a[9688]|0?534:0)}d=c[1836236]|0;b=c[9757320+(d<<2)>>2]|0;if((b|0)==0){f=c[2433530]|0;g=9752472+(d<<2)|0;c[g>>2]=f;h=c[2076596]|0;i=14113936+(d<<2)|0;c[i>>2]=h;j=c[3541536]|0;k=9669104+(d<<2)|0;c[k>>2]=j;c[1836236]=-1;return}e=b;gGC(e|0,9706056,76)|0;f=c[2433530]|0;g=9752472+(d<<2)|0;c[g>>2]=f;h=c[2076596]|0;i=14113936+(d<<2)|0;c[i>>2]=h;j=c[3541536]|0;k=9669104+(d<<2)|0;c[k>>2]=j;c[1836236]=-1;return}function ag8(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=i;i=i+160|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;l=e+80|0;m=e+96|0;n=e+112|0;o=e+128|0;p=e+144|0;if((a&32|0)!=0){gGz(p|0,0,12);c[p>>2]=c[2442956];c[p+4>>2]=2048;c[p+12>>2]=434336;q=c[2076592]|0;gj[q&4095](p)|0}if((a&64|0)==0){i=e;return 0}fw$(a);gGz(g|0,0,12);c[g>>2]=8453216;c[g+4>>2]=4;c[g+12>>2]=107480;gj[c[2076592]&4095](g)|0;gGz(f|0,0,12);c[f>>2]=14168504;c[f+4>>2]=256;c[f+12>>2]=476464;gj[c[2076592]&4095](f)|0;if((a&2|0)!=0){f=0;do{mv(0,f,d[14168504+f|0]|0);f=f+1|0;}while((f|0)<256)}UE(a,b);gGz(o|0,0,12);c[o>>2]=9717952;c[o+4>>2]=4;c[o+12>>2]=553880;gj[c[2076592]&4095](o)|0;gGz(n|0,0,12);c[n>>2]=9733352;c[n+4>>2]=4;c[n+12>>2]=429840;gj[c[2076592]&4095](n)|0;gGz(m|0,0,12);c[m>>2]=9718856;c[m+4>>2]=4;c[m+12>>2]=333424;gj[c[2076592]&4095](m)|0;gGz(l|0,0,12);c[l>>2]=9718848;c[l+4>>2]=4;c[l+12>>2]=255440;gj[c[2076592]&4095](l)|0;gGz(k|0,0,12);c[k>>2]=9718840;c[k+4>>2]=4;c[k+12>>2]=199512;gj[c[2076592]&4095](k)|0;gGz(j|0,0,12);c[j>>2]=9718832;c[j+4>>2]=4;c[j+12>>2]=157752;gj[c[2076592]&4095](j)|0;gGz(h|0,0,12);c[h>>2]=9754296;c[h+4>>2]=4;c[h+12>>2]=127552;gj[c[2076592]&4095](h)|0;i=e;return 0}function ag9(b){b=b|0;var c=0;switch(b|0){case 8921088:{c=~a[14165112];break};case 8921089:{c=~a[14165104];break};case 8921096:{c=~a[14165048];break};case 8921098:{c=~a[14168296];break};case 8921100:{c=~a[14168288];break};case 8921102:{c=~a[14168280];break};default:{c=0}}return c|0}function aha(a){a=a|0;return 0}function ahb(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;if((b|0)!=8921094){return}b=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;e=c[2113248]|0;f=e;g=(e|0)<0|0?-1:0;e=gGU(b,(b|0)<0|0?-1:0,f,g)|0;b=c[2113270]|0;h=gGS(e,K,b,(b|0)<0|0?-1:0)|0;b=gGL(h,K,(c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0,0)|0;h=c[2438718]|0;e=c[2427054]|0;i=b;b=gGU(i,(i|0)<0|0?-1:0,e,(e|0)<0|0?-1:0)|0;e=gGS(b,K,f,g)|0;g=gGK(e,K,h,0)|0;e=g;if((h|0)<(e|0)){g=h;while(1){h=g+1|0;Sb(ag(c[2427084]|0,h)|0);UD();c[2438718]=g;if((h|0)<(e|0)){g=h}else{break}}}c[2433432]=d&255;a[9706117]=1;return}function ahc(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;if((b|0)!=8921094){return}b=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;e=c[2113248]|0;f=e;g=(e|0)<0|0?-1:0;e=gGU(b,(b|0)<0|0?-1:0,f,g)|0;b=c[2113270]|0;h=gGS(e,K,b,(b|0)<0|0?-1:0)|0;b=gGL(h,K,(c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0,0)|0;h=c[2438718]|0;e=c[2427054]|0;i=b;b=gGU(i,(i|0)<0|0?-1:0,e,(e|0)<0|0?-1:0)|0;e=gGS(b,K,f,g)|0;g=gGK(e,K,h,0)|0;e=g;if((h|0)<(e|0)){g=h;while(1){h=g+1|0;Sb(ag(c[2427084]|0,h)|0);UD();c[2438718]=g;if((h|0)<(e|0)){g=h}else{break}}}c[2433432]=d&255;a[9706117]=1;return}function ahd(a,d){a=a|0;d=d|0;switch(a|0){case 9961472:{b[(c[3541926]|0)+14>>1]=d;return};case 9961474:{b[(c[3541926]|0)+12>>1]=d-64&65535;return};case 9961476:{b[(c[3541926]|0)+18>>1]=d;return};case 9961478:{b[(c[3541926]|0)+16>>1]=d-64&65535;return};case 9961480:{b[(c[3541926]|0)+22>>1]=d;return};case 9961482:{b[(c[3541926]|0)+20>>1]=d-64&65535;return};default:{return}}}function ahe(a,d){a=a|0;d=d|0;if((a|0)==8389154){b[(c[3541926]|0)+6>>1]=d;return}else{gg[c[(c[2112932]|0)+196648>>2]&4095](a,(d&65535)>>>8&255);gg[c[(c[2112932]|0)+196648>>2]&4095](a+1|0,d&255);return}}function ahf(a){a=a|0;return-1|0}function ahg(b){b=b|0;var c=0;switch(b|0){case 8912910:{c=~a[14168280];break};case 8912908:{c=~a[14168288];break};case 8912896:{c=~a[14165112];break};case 8912904:{c=~a[14165048];break};case 8912906:{c=~a[14168296];break};default:{c=0}}return c|0}function ahh(a){a=a|0;var b=0;if((a|0)==8912896){b=~(d[14165104]|0)}else{b=0}return b|0}function ahi(a,b){a=a|0;b=b|0;return}function ahj(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;if((b|0)!=8912902){return}b=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;e=c[2113248]|0;f=e;g=(e|0)<0|0?-1:0;e=gGU(b,(b|0)<0|0?-1:0,f,g)|0;b=c[2113270]|0;h=gGS(e,K,b,(b|0)<0|0?-1:0)|0;b=gGL(h,K,(c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0,0)|0;h=c[2438718]|0;e=c[2427054]|0;i=b;b=gGU(i,(i|0)<0|0?-1:0,e,(e|0)<0|0?-1:0)|0;e=gGS(b,K,f,g)|0;g=gGK(e,K,h,0)|0;e=g;if((h|0)<(e|0)){g=h;while(1){h=g+1|0;Sb(ag(c[2427084]|0,h)|0);UD();c[2438718]=g;if((h|0)<(e|0)){g=h}else{break}}}c[2433432]=d&255;a[9706117]=1;return}function ahk(b){b=b|0;return a[((b&1|0)==0?c[3541930]|0:c[2424883]|0)+(b>>>1&32767)|0]|0}function ahl(a){a=a|0;var b=0;b=((gj[c[(c[2112932]|0)+196612>>2]&4095](a)|0)&255)<<8;return(gj[c[(c[2112932]|0)+196612>>2]&4095](a+1|0)|0)&255|b|0}function ahm(b,d){b=b|0;d=d|0;var e=0;e=b>>>1&32767;if((b&1|0)==0){a[(c[3541930]|0)+e|0]=d;return}else{Tt(e,d);return}}function ahn(a,b){a=a|0;b=b|0;gg[c[(c[2112932]|0)+196652>>2]&4095](a,(b&65535)>>>8&255);gg[c[(c[2112932]|0)+196652>>2]&4095](a+1|0,b&255);return}function aho(a,d){a=a|0;d=d|0;if((a|0)!=8912896){return}b[(c[3541926]|0)+(c[2113254]|0)>>1]=d;return}function ahp(a,d){a=a|0;d=d|0;switch(a|0){case 9961472:{b[(c[3541926]|0)+14>>1]=d;return};case 9961474:{b[(c[3541926]|0)+12>>1]=d-64&65535;return};case 9961476:{b[(c[3541926]|0)+18>>1]=d;return};case 9961478:{b[(c[3541926]|0)+16>>1]=d-64&65535;return};case 9961480:{b[(c[3541926]|0)+22>>1]=d;return};case 9961482:{b[(c[3541926]|0)+20>>1]=d-64&65535;return};case 9961484:{a=d&65535;if((a|0)==0){c[2412]=1;c[2413]=0;c[2414]=2;c[2415]=3;return}else if((a|0)==1){c[2412]=1;c[2413]=0;c[2414]=-1;c[2415]=3;return}else if((a|0)==2){c[2412]=3;c[2413]=-1;c[2414]=-1;c[2415]=1;return}else if((a|0)==6){gGz(9648,-1|0,16);return}else{gGz(9648,0,16);return}break};default:{return}}}function ahq(b,d){b=b|0;d=d|0;a[(c[3541930]|0)+(b&65535^1)|0]=d;return}function ahr(a,d){a=a|0;d=d|0;if((a|0)==16713346){b[(c[3541926]|0)+(c[3541188]|0)>>1]=d}else if((a|0)==16713348){b[(c[3541926]|0)+(c[3541189]|0)>>1]=d}else if((a|0)==16713344){b[(c[3541926]|0)+(c[3541187]|0)>>1]=d}b[(c[3541930]|0)+((a>>>1&32767)<<1)>>1]=d;return}function ahs(a,d){a=a|0;d=d|0;switch(a|0){case 9961478:{b[(c[3541926]|0)+16>>1]=d-60&65535;return};case 9961482:{b[(c[3541926]|0)+20>>1]=d-64&65535;return};case 9961508:{b[(c[3541926]|0)+(c[3541189]|0)>>1]=d;return};case 9961472:{b[(c[3541926]|0)+14>>1]=d;return};case 9961474:{b[(c[3541926]|0)+12>>1]=d-62&65535;return};case 9961476:{b[(c[3541926]|0)+18>>1]=d;return};case 9961504:{b[(c[3541926]|0)+(c[3541187]|0)>>1]=d;return};case 9961506:{b[(c[3541926]|0)+(c[3541188]|0)>>1]=d;return};case 9961480:{b[(c[3541926]|0)+22>>1]=d;return};case 9961484:{a=d&65535;if((a|0)==40960){c[2412]=2;c[2413]=1;c[2414]=0;c[2415]=3;return}else if((a|0)==8192){c[2412]=0;c[2413]=1;c[2414]=2;c[2415]=3;return}else if((a|0)==33023|(a|0)==34815|(a|0)==55296){c[2412]=1;c[2413]=0;c[2414]=3;c[2415]=2;return}else if((a|0)==0|(a|0)==31|(a|0)==255|(a|0)==2047|(a|0)==22528|(a|0)==24320){c[2412]=1;c[2413]=0;c[2414]=2;c[2415]=3;return}else{c[2412]=1;c[2413]=0;c[2414]=2;c[2415]=3;return}break};default:{return}}}function aht(b){b=b|0;var c=0;if((b|0)==10035208){c=~a[14165048]}else if((b|0)==10035200){c=~a[14165112]}else if((b|0)==10035201){c=~a[14165104]}else if((b|0)==10035209){c=-1}else{c=0}return c|0}function ahu(b,d){b=b|0;d=d|0;var e=0,f=0;if((b|0)!=10035207){return}b=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;e=c[2113248]|0;f=gGU(b,(b|0)<0|0?-1:0,e,(e|0)<0|0?-1:0)|0;e=c[2113270]|0;b=gGS(f,K,e,(e|0)<0|0?-1:0)|0;Wv(b);a[14130592]=d;return}function ahv(a,d){a=a|0;d=d|0;switch(a|0){case 9961474:{b[(c[3541926]|0)+12>>1]=d-62&65535;return};case 9961480:{b[(c[3541926]|0)+22>>1]=d;return};case 9961504:{b[(c[3541926]|0)+(c[3541187]|0)>>1]=d;return};case 9961506:{b[(c[3541926]|0)+(c[3541188]|0)>>1]=d;return};case 9961476:{b[(c[3541926]|0)+18>>1]=d;return};case 9961482:{b[(c[3541926]|0)+20>>1]=d-64&65535;return};case 9961472:{b[(c[3541926]|0)+14>>1]=d;return};case 9961478:{b[(c[3541926]|0)+16>>1]=d-60&65535;return};case 9961484:{b[(c[3541926]|0)+(c[2113258]|0)>>1]=d;return};default:{return}}}function ahw(a){a=a|0;return-1|0}function ahx(a,d){a=a|0;d=d|0;switch(a|0){case 9961484:{b[4858984]=d;return};case 9961486:{if((d<<16>>16|0)==0){a=e[4858984]|0;if((a|0)==36){c[2412]=1;c[2413]=0;c[2414]=3;c[2415]=2;return}else if((a|0)==100){c[2412]=1;c[2413]=0;c[2414]=2;c[2415]=3;return}else if((a|0)==124){c[2412]=0;c[2413]=1;c[2414]=3;c[2415]=2;return}else if((a|0)==84){c[2412]=1;c[2413]=0;c[2414]=2;c[2415]=3;return}else{return}}else if((d<<16>>16|0)==(-1|0)){a=e[4858984]|0;if((a|0)==84){c[2412]=1;c[2413]=0;c[2414]=2;c[2415]=-1;return}else if((a|0)==100){c[2412]=1;c[2413]=0;c[2414]=2;c[2415]=-1;return}else if((a|0)==36){c[2412]=1;c[2413]=0;c[2414]=-1;c[2415]=3;return}else{return}}else{return}break};case 9961472:{b[(c[3541926]|0)+14>>1]=d;return};case 9961474:{b[(c[3541926]|0)+12>>1]=d-70&65535;return};case 9961476:{b[(c[3541926]|0)+18>>1]=d;return};case 9961478:{b[(c[3541926]|0)+16>>1]=d-64&65535;return};case 9961480:{b[(c[3541926]|0)+22>>1]=d;return};case 9961482:{b[(c[3541926]|0)+20>>1]=d-70&65535;return};default:{return}}}function ahy(b,d){b=b|0;d=d|0;a[(c[3541930]|0)+(b&65535^1)|0]=d;return}function ahz(a,d){a=a|0;d=d|0;switch(a|0){case 16735024:{b[(c[3541926]|0)+(c[3541187]|0)>>1]=d;break};case 16735026:{b[(c[3541926]|0)+(c[3541188]|0)>>1]=d;break};case 16735028:{b[(c[3541926]|0)+(c[3541189]|0)>>1]=d;break};case 16735114:{b[(c[3541926]|0)+2>>1]=d;break};case 16735116:{b[(c[3541926]|0)+4>>1]=d;break};case 16735118:{b[(c[3541926]|0)+6>>1]=d;break};default:{}}b[(c[3541930]|0)+((a>>>1&32767)<<1)>>1]=d;return}function ahA(a){a=a|0;var b=0;if((a|0)==2101761){b=2}else if((a|0)==2626049){b=64}else{b=0}return b|0}function ahB(a){a=a|0;return 0}function ahC(a){a=a|0;return((a|0)==2626049?64:0)|0}function ahD(a){a=a|0;return 0}function ahE(b){b=b|0;var c=0;switch(b|0){case 7389184:{c=~a[14165112];break};case 7389210:{c=~a[14168296];break};case 7389208:{c=~a[14165048];break};case 7389192:{c=-1;break};case 7389193:{c=~a[14164992];break};case 7389185:{c=~a[14165104];break};case 7389212:{c=~a[14168288];break};case 7389214:{c=~a[14168280];break};default:{c=0}}return c|0}function ahF(a){a=a|0;return 0}function ahG(a,b){a=a|0;b=b|0;if((a|0)!=7389446){return}agZ(b&255);return}function ahH(a,d){a=a|0;d=d|0;switch(a|0){case 7373068:{b[(c[3541926]|0)+20>>1]=d-66&65535;return};case 7373070:{b[(c[3541926]|0)+22>>1]=d;return};case 7373072:{b[(c[3541926]|0)+16>>1]=d-64&65535;return};case 7373076:{a=c[3541926]|0;b[a+18>>1]=d;b[a+32>>1]=d;b[a+8>>1]=b[(c[3541930]|0)+32814>>1]|0;return};case 7373078:{b[(c[3541926]|0)+14>>1]=d;return};case 7373132:{b[(c[3541926]|0)+(c[2113258]|0)>>1]=d;return};case 7373074:{b[(c[3541926]|0)+12>>1]=d-66&65535;return};default:{return}}}function ahI(a,d){a=a|0;d=d|0;switch(a|0){case 7373068:{b[(c[3541926]|0)+12>>1]=d-66&65535;return};case 7373070:{b[(c[3541926]|0)+14>>1]=d;return};case 7373072:{b[(c[3541926]|0)+20>>1]=d-66&65535;return};case 7373074:{a=c[3541926]|0;b[a+18>>1]=d;b[a+32>>1]=d;b[a+8>>1]=b[(c[3541930]|0)+32814>>1]|0;return};case 7373078:{b[(c[3541926]|0)+22>>1]=d;return};case 7373132:{b[(c[3541926]|0)+(c[2113258]|0)>>1]=d;return};default:{return}}}function ahJ(a,d){a=a|0;d=d|0;switch(a|0){case 9961472:{b[(c[3541926]|0)+14>>1]=d;return};case 9961494:{b[(c[3541926]|0)+6>>1]=d;return};case 9961474:{b[(c[3541926]|0)+12>>1]=d-64&65535;return};case 9961476:{b[(c[3541926]|0)+18>>1]=d;return};case 9961478:{b[(c[3541926]|0)+16>>1]=d-60&65535;return};case 9961480:{b[(c[3541926]|0)+22>>1]=d;return};case 9961482:{b[(c[3541926]|0)+20>>1]=d-64&65535;return};case 9961484:{switch(d&65535|0){case 1:{c[2412]=0;c[2413]=3;c[2414]=2;c[2415]=1;return};case 5:{c[2412]=0;c[2413]=2;c[2414]=3;c[2415]=1;return};case 4:{c[2412]=1;c[2413]=0;c[2414]=2;c[2415]=3;return};case 3:{c[2412]=0;c[2413]=2;c[2414]=1;c[2415]=3;return};case 0:{c[2412]=0;c[2413]=1;c[2414]=3;c[2415]=2;return};case 2:{c[2412]=0;c[2413]=1;c[2414]=2;c[2415]=3;return};default:{c[2412]=0;c[2413]=3;c[2414]=2;c[2415]=1;return}}break};default:{return}}}function ahK(b){b=b|0;var c=0;switch(b|0){case 8388625:{c=~a[14165064];break};case 8388624:{c=~a[14165072];break};case 8388652:{c=~a[14168288];break};case 8388650:{c=~a[14168296];break};case 8388998:{c=~a[14164976];break};case 8388649:{c=~a[14165008];break};case 8388654:{c=~a[14168280];break};default:{c=0}}return c|0}function ahL(b,d){b=b|0;d=d|0;var e=0,f=0;if((b|0)!=8389009){return}b=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;e=c[2113248]|0;f=gGU(b,(b|0)<0|0?-1:0,e,(e|0)<0|0?-1:0)|0;e=c[2113270]|0;b=gGS(f,K,e,(e|0)<0|0?-1:0)|0;Wv(b);a[14130592]=d;return}function ahM(b,d){b=b|0;d=d|0;var f=0,g=0;switch(b|0){case 8388864:{b=c[3541926]|0;a[b]=d&255;a[b+1|0]=(d&65535)>>>8&255;return};case 8388874:{b=c[3541926]|0;f=b+10|0;a[f]=d&255;a[b+11|0]=(d&65535)>>>8&255;b=(e[f>>1]|0)<<8&16776192;do{if(b>>>0>9437183&(b+6144|0)>>>0<9633793){f=(c[3541932]|0)+(b-9437184)|0;if((f|0)==0){break}g=c[3541898]|0;gGC(g|0,f|0,6144)|0}}while(0);W9(c[3541898]|0);return};case 8389032:{b=c[3541926]|0;a[b+8|0]=d&255;a[b+9|0]=(d&65535)>>>8&255;return};case 8388898:{b=c[3541926]|0;a[b+34|0]=d&255;a[b+35|0]=(d&65535)>>>8&255;return};case 8388938:{b=c[3541926]|0;a[b+74|0]=d&255;a[b+75|0]=(d&65535)>>>8&255;return};case 8388946:{b=c[3541926]|0;a[b+82|0]=d&255;a[b+83|0]=(d&65535)>>>8&255;return};case 8388942:{b=c[3541926]|0;a[b+78|0]=d&255;a[b+79|0]=(d&65535)>>>8&255;return};case 8388866:{b=c[3541926]|0;a[b+2|0]=d&255;a[b+3|0]=(d&65535)>>>8&255;return};case 8388868:{b=c[3541926]|0;a[b+4|0]=d&255;a[b+5|0]=(d&65535)>>>8&255;return};case 8388870:{b=c[3541926]|0;a[b+6|0]=d&255;a[b+7|0]=(d&65535)>>>8&255;return};case 8388940:{b=c[3541926]|0;a[b+76|0]=d&255;a[b+77|0]=(d&65535)>>>8&255;return};case 8389056:{b=c[3541926]|0;a[b+32|0]=d&255;a[b+33|0]=(d&65535)>>>8&255;return};case 8389060:{b=c[3541926]|0;a[b+196|0]=d&255;a[b+197|0]=(d&65535)>>>8&255;return};case 8388944:{b=c[3541926]|0;a[b+80|0]=d&255;a[b+81|0]=(d&65535)>>>8&255;return};case 8389044:{b=c[3541926]|0;a[b+20|0]=d&255;a[b+21|0]=(d&65535)>>>8&255;return};case 8389046:{b=c[3541926]|0;a[b+22|0]=d&255;a[b+23|0]=(d&65535)>>>8&255;return};case 8389036:{b=c[3541926]|0;a[b+12|0]=d&255;a[b+13|0]=(d&65535)>>>8&255;return};case 8389038:{b=c[3541926]|0;a[b+14|0]=d&255;a[b+15|0]=(d&65535)>>>8&255;return};case 8389040:{b=c[3541926]|0;a[b+16|0]=d&255;a[b+17|0]=(d&65535)>>>8&255;return};case 8389042:{b=c[3541926]|0;a[b+18|0]=d&255;a[b+19|0]=(d&65535)>>>8&255;return};default:{return}}}function ahN(a){a=a|0;return 0}function ahO(a){a=a|0;var b=0;if((a|0)==1572864){b=512}else if((a|0)==2060352){b=528}else{b=0}return b|0}function ahP(a,b){a=a|0;b=b|0;VP(a&511,b);return}function ahQ(a,d){a=a|0;d=d|0;if((a|0)==8388900){b[(c[3541926]|0)+32>>1]=d;return}else{gg[c[(c[2112932]|0)+196652>>2]&4095](a,(d&65535)>>>8&255);gg[c[(c[2112932]|0)+196652>>2]&4095](a+1|0,d&255);return}}function ahR(a){a=a|0;return-1|0}function ahS(a,d){a=a|0;d=d|0;switch(a|0){case 9961476:{b[(c[3541926]|0)+18>>1]=d;return};case 9961472:{b[(c[3541926]|0)+14>>1]=d;return};case 9961474:{b[(c[3541926]|0)+12>>1]=d-64&65535;return};case 9961478:{b[(c[3541926]|0)+16>>1]=d-64&65535;return};case 9961480:{b[(c[3541926]|0)+22>>1]=d;return};case 9961482:{b[(c[3541926]|0)+20>>1]=d-64&65535;return};case 9961484:{b[(c[3541926]|0)+4>>1]=d<<4;return};default:{return}}}function ahT(b,d){b=b|0;d=d|0;a[(c[3541930]|0)+(b&65535^1)|0]=d;return}function ahU(a,d){a=a|0;d=d|0;if((a|0)==16747894){b[(c[3541926]|0)+(c[3541188]|0)>>1]=d}else if((a|0)==16747896){b[(c[3541926]|0)+(c[3541189]|0)>>1]=d}else if((a|0)==16747892){b[(c[3541926]|0)+(c[3541187]|0)>>1]=d}b[(c[3541930]|0)+((a>>>1&32767)<<1)>>1]=d;return}function ahV(a){a=a|0;return-1|0}function ahW(a){a=a|0;return-1|0}function ahX(b){b=b|0;var c=0;switch(b|0){case 8916600:{c=a[9757384]|0;break};case 8912896:{c=~a[14165112];break};case 8912897:{c=~a[14165104];break};case 8912902:{c=~a[14165048];break};case 8912903:{c=~a[14164992];break};case 8912904:{c=~a[14168296];break};case 8912906:{c=~a[14168288];break};case 8912908:{c=~a[14168280];break};default:{c=0}}return c|0}function ahY(a){a=a|0;var b=0;b=((gj[c[(c[2112932]|0)+196620>>2]&4095](a)|0)&255)<<8;return(gj[c[(c[2112932]|0)+196620>>2]&4095](a+1|0)|0)&255|b|0}function ahZ(b,d){b=b|0;d=d|0;var e=0,f=0;if((b|0)!=8912910){return}b=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;e=c[2113248]|0;f=gGU(b,(b|0)<0|0?-1:0,e,(e|0)<0|0?-1:0)|0;e=c[2113270]|0;b=gGS(f,K,e,(e|0)<0|0?-1:0)|0;Wv(b);a[14130592]=d;return}function ah_(b,d){b=b|0;d=d|0;var e=0,f=0;if((b|0)!=8912910){return}b=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;e=c[2113248]|0;f=gGU(b,(b|0)<0|0?-1:0,e,(e|0)<0|0?-1:0)|0;e=c[2113270]|0;b=gGS(f,K,e,(e|0)<0|0?-1:0)|0;Wv(b);a[14130592]=d&255;return}function ah$(b,d){b=b|0;d=d|0;a[(c[3541930]|0)+(b&65535^1)|0]=d;return}function ah0(a,d){a=a|0;d=d|0;if((a|0)==16737180){b[(c[3541926]|0)+(c[3541188]|0)>>1]=d}else if((a|0)==16737182){b[(c[3541926]|0)+(c[3541189]|0)>>1]=d}else if((a|0)==16737178){b[(c[3541926]|0)+(c[3541187]|0)>>1]=d}b[(c[3541930]|0)+((a>>>1&32767)<<1)>>1]=d;return}function ah1(b){b=b|0;var c=0;switch(b|0){case 8912896:{c=~a[14165112];break};case 8912904:{c=~a[14165048];break};case 8912910:{c=~a[14168280];break};case 8912906:{c=~a[14168296];break};case 8915998:case 8916606:{c=-1;break};case 8912905:{c=~a[14164992];break};case 8912897:{c=~a[14165104];break};case 8912908:{c=~a[14168288];break};default:{c=0}}return c|0}function ah2(a){a=a|0;var b=0;b=((gj[c[(c[2112932]|0)+196620>>2]&4095](a)|0)&255)<<8;return(gj[c[(c[2112932]|0)+196620>>2]&4095](a+1|0)|0)&255|b|0}function ah3(b,d){b=b|0;d=d|0;var e=0,f=0;if((b|0)!=8912902){return}b=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;e=c[2113248]|0;f=gGU(b,(b|0)<0|0?-1:0,e,(e|0)<0|0?-1:0)|0;e=c[2113270]|0;b=gGS(f,K,e,(e|0)<0|0?-1:0)|0;Wv(b);a[14130592]=d;return}function ah4(b,d){b=b|0;d=d|0;var e=0,f=0;if((b|0)!=8912902){return}b=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;e=c[2113248]|0;f=gGU(b,(b|0)<0|0?-1:0,e,(e|0)<0|0?-1:0)|0;e=c[2113270]|0;b=gGS(f,K,e,(e|0)<0|0?-1:0)|0;Wv(b);a[14130592]=d&255;return}function ah5(a,d){a=a|0;d=d|0;switch(a|0){case 9961484:{switch(d&65535|0){case 1:case 5:case 15:{c[2412]=1;c[2413]=0;c[2414]=3;c[2415]=2;return};case 3:case 7:case 9:{c[2412]=1;c[2413]=3;c[2414]=0;c[2415]=2;return};case 0:case 4:case 6:case 8:case 10:case 11:case 14:{c[2412]=1;c[2413]=0;c[2414]=2;c[2415]=3;return};default:{c[2412]=1;c[2413]=0;c[2414]=2;c[2415]=3;return}}break};case 9961472:{b[(c[3541926]|0)+14>>1]=d;return};case 9961474:{b[(c[3541926]|0)+12>>1]=d;return};case 9961476:{b[(c[3541926]|0)+18>>1]=d;return};case 9961478:{b[(c[3541926]|0)+16>>1]=d;return};case 9961480:{b[(c[3541926]|0)+22>>1]=d;return};case 9961482:{b[(c[3541926]|0)+20>>1]=d;return};default:{return}}}function ah6(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5226604+(b*112|0)>>2];c[a+104>>2]=c[5226608+(b*112|0)>>2];c[a+108>>2]=c[5226612+(b*112|0)>>2];d=0;return d|0}function ah7(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=5226504+(b*112|0);e=0;return e|0}function ah8(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6209712+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function ah9(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>66){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7170376+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aia(){var b=0,d=0,e=0,f=0,g=0;b=c[c[642608+(c[2436]<<2)>>2]>>2]|0;d=7314048;while(1){e=c[d>>2]|0;if((e|0)==0){break}if((fa(e|0,b|0)|0)==0){f=3388;break}else{d=d+20|0}}if((f|0)==3388){b=c[d+12>>2]|0;c[2443334]=b;VO(c[d+4>>2]|0,b);VN(c[d+8>>2]|0);c[2429506]=c[d+16>>2]}asO(0);c[3542068]=1;if((Wo()|0)!=0){g=1;return g|0}asO(1);d=c[2429532]|0;if((d|0)!=0){gu[d&16383]()}d=c[c[642608+(c[2436]<<2)>>2]>>2]|0;b=7314048;while(1){e=c[b>>2]|0;if((e|0)==0){break}if((fa(e|0,d|0)|0)==0){f=3395;break}else{b=b+20|0}}if((f|0)==3395){f=c[b+12>>2]|0;c[2443334]=f;VO(c[b+4>>2]|0,f);VN(c[b+8>>2]|0);c[2429506]=c[b+16>>2]}if(a[7462128]|0){gu[c[2429506]&16383]()}if((agT()|0)!=0){g=1;return g|0}c[1865530]=2;g=0;return g|0}function aib(){var b=0,d=0,e=0,f=0;agV();Wr();c[2113250]=0;c[2113246]=0;c[2113268]=0;c[2113274]=0;c[2113252]=0;c[2439242]=0;c[2433564]=0;c[2427232]=0;c[2427032]=0;c[2439240]=0;c[2433562]=0;c[2429862]=0;c[2432858]=0;c[2429366]=0;c[2429506]=0;c[2443334]=0;c[2429532]=0;c[3541966]=0;c[3541964]=0;c[3541962]=0;a[7461984]=0;a[7461976]=0;a[7461968]=0;a[7461992]=0;a[7462144]=0;gGz(9648,-1|0,16);c[3542068]=0;a[7462128]=0;a[7462160]=0;a[7461928]=0;a[7461848]=0;a[7461808]=0;a[7461720]=0;a[7462152]=0;a[7462168]=0;a[7462e3]=0;a[7461936]=0;a[7461672]=0;a[7461712]=0;a[7462136]=0;c[2426966]=0;b=c[3542036]|0;d=0;while(1){if((d|0)>=1024){e=3410;break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==(b|0)){break}else{d=d+1|0}}if((e|0)==3410){c[3542036]=0;return 0}gGr(b);c[f>>2]=0;c[3542036]=0;return 0}function aic(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1811068+(b*112|0)>>2];c[a+104>>2]=c[1811072+(b*112|0)>>2];c[a+108>>2]=c[1811076+(b*112|0)>>2];d=0;return d|0}function aid(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=1810968+(b*112|0);e=0;return e|0}function aie(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3669372+(b*112|0)>>2];c[a+104>>2]=c[3669376+(b*112|0)>>2];c[a+108>>2]=c[3669380+(b*112|0)>>2];d=0;return d|0}function aif(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=3669272+(b*112|0);e=0;return e|0}function aig(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>33){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3671500+(b*112|0)>>2];c[a+104>>2]=c[3671504+(b*112|0)>>2];c[a+108>>2]=c[3671508+(b*112|0)>>2];d=0;return d|0}function aih(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<34&(d|0)==0)){e=1;return e|0}c[a>>2]=3671400+(b*112|0);e=0;return e|0}function aii(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>26){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[803892+(b*112|0)>>2];c[a+104>>2]=c[803896+(b*112|0)>>2];c[a+108>>2]=c[803900+(b*112|0)>>2];d=0;return d|0}function aij(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<27&(d|0)==0)){e=1;return e|0}c[a>>2]=803792+(b*112|0);e=0;return e|0}function aik(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=703064+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function ail(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>68){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=806816+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aim(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>26){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[700140+(b*112|0)>>2];c[a+104>>2]=c[700144+(b*112|0)>>2];c[a+108>>2]=c[700148+(b*112|0)>>2];d=0;return d|0}function ain(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<27&(d|0)==0)){e=1;return e|0}c[a>>2]=700040+(b*112|0);e=0;return e|0}function aio(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>26){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3235852+(b*112|0)>>2];c[a+104>>2]=c[3235856+(b*112|0)>>2];c[a+108>>2]=c[3235860+(b*112|0)>>2];d=0;return d|0}function aip(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<27&(d|0)==0)){e=1;return e|0}c[a>>2]=3235752+(b*112|0);e=0;return e|0}function aiq(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>50){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4873460+(b*112|0)>>2];c[a+104>>2]=c[4873464+(b*112|0)>>2];c[a+108>>2]=c[4873468+(b*112|0)>>2];d=0;return d|0}function air(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<51&(d|0)==0)){e=1;return e|0}c[a>>2]=4873360+(b*112|0);e=0;return e|0}function ais(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>34){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3238876+(b*112|0)>>2];c[a+104>>2]=c[3238880+(b*112|0)>>2];c[a+108>>2]=c[3238884+(b*112|0)>>2];d=0;return d|0}function ait(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<35&(d|0)==0)){e=1;return e|0}c[a>>2]=3238776+(b*112|0);e=0;return e|0}function aiu(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3242796+(b*112|0)>>2];c[a+104>>2]=c[3242800+(b*112|0)>>2];c[a+108>>2]=c[3242804+(b*112|0)>>2];d=0;return d|0}function aiv(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=3242696+(b*112|0);e=0;return e|0}function aiw(){var d=0,e=0;a[64288]=1;c[2426966]=134;c[3541966]=4;c[3541964]=6;c[3541962]=10;d=aia()|0;e=c[3541926]|0;b[e+4>>1]=-28480;b[e+6>>1]=-28416;b[e+10>>1]=-28352;b[e+(c[2113254]|0)>>1]=63;return d|0}function aix(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>24){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4185412+(b*112|0)>>2];c[a+104>>2]=c[4185416+(b*112|0)>>2];c[a+108>>2]=c[4185420+(b*112|0)>>2];d=0;return d|0}function aiy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<25&(d|0)==0)){e=1;return e|0}c[a>>2]=4185312+(b*112|0);e=0;return e|0}function aiz(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>37){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1298648+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aiA(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>56){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4188112+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aiB(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>24){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1294492+(b*112|0)>>2];c[a+104>>2]=c[1294496+(b*112|0)>>2];c[a+108>>2]=c[1294500+(b*112|0)>>2];d=0;return d|0}function aiC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<25&(d|0)==0)){e=1;return e|0}c[a>>2]=1294392+(b*112|0);e=0;return e|0}function aiD(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>24){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1984140+(b*112|0)>>2];c[a+104>>2]=c[1984144+(b*112|0)>>2];c[a+108>>2]=c[1984148+(b*112|0)>>2];d=0;return d|0}function aiE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<25&(d|0)==0)){e=1;return e|0}c[a>>2]=1984040+(b*112|0);e=0;return e|0}function aiF(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>24){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1986940+(b*112|0)>>2];c[a+104>>2]=c[1986944+(b*112|0)>>2];c[a+108>>2]=c[1986948+(b*112|0)>>2];d=0;return d|0}function aiG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<25&(d|0)==0)){e=1;return e|0}c[a>>2]=1986840+(b*112|0);e=0;return e|0}function aiH(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>24){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[987484+(b*112|0)>>2];c[a+104>>2]=c[987488+(b*112|0)>>2];c[a+108>>2]=c[987492+(b*112|0)>>2];d=0;return d|0}function aiI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<25&(d|0)==0)){e=1;return e|0}c[a>>2]=987384+(b*112|0);e=0;return e|0}function aiJ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1989740+(b*112|0)>>2];c[a+104>>2]=c[1989744+(b*112|0)>>2];c[a+108>>2]=c[1989748+(b*112|0)>>2];d=0;return d|0}function aiK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=1989640+(b*112|0);e=0;return e|0}function aiL(){c[3541966]=-8;c[3541964]=-11;c[3541962]=-12;a[7461992]=1;a[7462176]=1;c[2426966]=674;return aia()|0}function aiM(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1297292+(b*112|0)>>2];c[a+104>>2]=c[1297296+(b*112|0)>>2];c[a+108>>2]=c[1297300+(b*112|0)>>2];d=0;return d|0}function aiN(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=1297192+(b*112|0);e=0;return e|0}function aiO(){a[7462160]=1;c[3541914]=3658;c[3541912]=4102;c[3541920]=1072;c[3541916]=2604;c[3541918]=1748;c[3541938]=120;c[3541954]=3790;return aia()|0}function aiP(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6404300+(b*112|0)>>2];c[a+104>>2]=c[6404304+(b*112|0)>>2];c[a+108>>2]=c[6404308+(b*112|0)>>2];d=0;return d|0}function aiQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=6404200+(b*112|0);e=0;return e|0}function aiR(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>23){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4183456+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aiS(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>55){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6406328+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aiT(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4177844+(b*112|0)>>2];c[a+104>>2]=c[4177848+(b*112|0)>>2];c[a+108>>2]=c[4177852+(b*112|0)>>2];d=0;return d|0}function aiU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=4177744+(b*112|0);e=0;return e|0}function aiV(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5542492+(b*112|0)>>2];c[a+104>>2]=c[5542496+(b*112|0)>>2];c[a+108>>2]=c[5542500+(b*112|0)>>2];d=0;return d|0}function aiW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=5542392+(b*112|0);e=0;return e|0}function aiX(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>33){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5544620+(b*112|0)>>2];c[a+104>>2]=c[5544624+(b*112|0)>>2];c[a+108>>2]=c[5544628+(b*112|0)>>2];d=0;return d|0}function aiY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<34&(d|0)==0)){e=1;return e|0}c[a>>2]=5544520+(b*112|0);e=0;return e|0}function aiZ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4179972+(b*112|0)>>2];c[a+104>>2]=c[4179976+(b*112|0)>>2];c[a+108>>2]=c[4179980+(b*112|0)>>2];d=0;return d|0}function ai_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=4179872+(b*112|0);e=0;return e|0}function ai$(){var b=0,d=0,e=0,f=0,g=0;a[7462160]=1;a[64288]=1;c[3541966]=-63;c[3541964]=-62;c[3541962]=-65;c[3542064]=3544;c[3542066]=4732;c[2426966]=1970;c[3541914]=582;c[3541912]=3614;c[3541920]=2626;c[3541916]=3090;c[3541918]=4552;c[3541954]=4954;aia()|0;if((c[2394]|0)==0){b=c[2112932]|0;d=c[3532592]|0}else{c[2394]=0;e=c[3532596]|0;c[2112932]=e;f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];b=e;d=f}c[b+34848>>2]=1;c[b+100384>>2]=1;c[b+34852>>2]=1;c[b+100388>>2]=1;c[b+34856>>2]=1;c[b+100392>>2]=1;c[b+34860>>2]=1;c[b+100396>>2]=1;c[b+196612>>2]=682;c[b+196692>>2]=3570;c[b+196652>>2]=1484;c[b+196732>>2]=2126;if((d|0)==0){g=c[2113054]|0;c[2113060]=g;c[2394]=-1;c[1865530]=6;return 0}gGC(d|0,9104152,280)|0;g=c[2113054]|0;c[2113060]=g;c[2394]=-1;c[1865530]=6;return 0}function ai0(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>24){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4180756+(b*112|0)>>2];c[a+104>>2]=c[4180760+(b*112|0)>>2];c[a+108>>2]=c[4180764+(b*112|0)>>2];d=0;return d|0}function ai1(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<25&(d|0)==0)){e=1;return e|0}c[a>>2]=4180656+(b*112|0);e=0;return e|0}function ai2(){var b=0,d=0,e=0,f=0,g=0;a[7462160]=1;a[64288]=1;c[3541966]=-63;c[3541964]=-62;c[3541962]=-65;c[3542064]=3544;c[3542066]=4732;c[2426966]=704;c[3541914]=582;c[3541912]=3614;c[3541920]=2626;c[3541916]=3090;c[3541918]=4552;c[3541954]=4954;aia()|0;if((c[2394]|0)==0){b=c[2112932]|0;d=c[3532592]|0}else{c[2394]=0;e=c[3532596]|0;c[2112932]=e;f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];b=e;d=f}c[b+34848>>2]=1;c[b+100384>>2]=1;c[b+34852>>2]=1;c[b+100388>>2]=1;c[b+34856>>2]=1;c[b+100392>>2]=1;c[b+34860>>2]=1;c[b+100396>>2]=1;c[b+196612>>2]=682;c[b+196692>>2]=3570;c[b+196652>>2]=1484;c[b+196732>>2]=2126;if((d|0)==0){g=c[2113054]|0;c[2113060]=g;c[2394]=-1;c[1865530]=6;return 0}gGC(d|0,9104152,280)|0;g=c[2113054]|0;c[2113060]=g;c[2394]=-1;c[1865530]=6;return 0}function ai3(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4144228+(b*112|0)>>2];c[a+104>>2]=c[4144232+(b*112|0)>>2];c[a+108>>2]=c[4144236+(b*112|0)>>2];d=0;return d|0}function ai4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=4144128+(b*112|0);e=0;return e|0}function ai5(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3979552+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function ai6(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>65){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6316592+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function ai7(){a[64288]=1;return aia()|0}function ai8(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>34){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4122660+(b*112|0)>>2];c[a+104>>2]=c[4122664+(b*112|0)>>2];c[a+108>>2]=c[4122668+(b*112|0)>>2];d=0;return d|0}function ai9(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<35&(d|0)==0)){e=1;return e|0}c[a>>2]=4122560+(b*112|0);e=0;return e|0}function aja(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1288392+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function ajb(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>51){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4126480+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function ajc(){c[2113296]=12e6;return aia()|0}function ajd(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>27){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7308620+(b*112|0)>>2];c[a+104>>2]=c[7308624+(b*112|0)>>2];c[a+108>>2]=c[7308628+(b*112|0)>>2];d=0;return d|0}function aje(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<28&(d|0)==0)){e=1;return e|0}c[a>>2]=7308520+(b*112|0);e=0;return e|0}function ajf(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>27){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6350720+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function ajg(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>3){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7311656+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function ajh(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>27){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6948236+(b*112|0)>>2];c[a+104>>2]=c[6948240+(b*112|0)>>2];c[a+108>>2]=c[6948244+(b*112|0)>>2];d=0;return d|0}function aji(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<28&(d|0)==0)){e=1;return e|0}c[a>>2]=6948136+(b*112|0);e=0;return e|0}function ajj(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>27){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6944092+(b*112|0)>>2];c[a+104>>2]=c[6944096+(b*112|0)>>2];c[a+108>>2]=c[6944100+(b*112|0)>>2];d=0;return d|0}function ajk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<28&(d|0)==0)){e=1;return e|0}c[a>>2]=6943992+(b*112|0);e=0;return e|0}function ajl(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5457588+(b*112|0)>>2];c[a+104>>2]=c[5457592+(b*112|0)>>2];c[a+108>>2]=c[5457596+(b*112|0)>>2];d=0;return d|0}function ajm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=5457488+(b*112|0);e=0;return e|0}function ajn(){var b=0,d=0,e=0,f=0,g=0,h=0;a[7462160]=1;a[7462008]=1;c[2426966]=1564;c[3542064]=3904;c[3542066]=4732;c[3541954]=10646;c[2113296]=12e6;b=aia()|0;d=0;while(1){if((d|0)>=1024){e=0;break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==0){g=3859;break}else{d=d+1|0}}do{if((g|0)==3859){d=gGq(16384)|0;c[f>>2]=d;if((d|0)==0){e=0;break}gGz(d|0,0,16384);e=d}}while(0);c[3542036]=e;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060]}f=c[2112932]|0;c[f+39168>>2]=e;c[f+104704>>2]=e;c[f+170240>>2]=e;g=e+1024|0;c[f+39172>>2]=g;c[f+104708>>2]=g;c[f+170244>>2]=g;g=e+2048|0;c[f+39176>>2]=g;c[f+104712>>2]=g;c[f+170248>>2]=g;g=e+3072|0;c[f+39180>>2]=g;c[f+104716>>2]=g;c[f+170252>>2]=g;g=e+4096|0;c[f+39184>>2]=g;c[f+104720>>2]=g;c[f+170256>>2]=g;g=e+5120|0;c[f+39188>>2]=g;c[f+104724>>2]=g;c[f+170260>>2]=g;g=e+6144|0;c[f+39192>>2]=g;c[f+104728>>2]=g;c[f+170264>>2]=g;g=e+7168|0;c[f+39196>>2]=g;c[f+104732>>2]=g;c[f+170268>>2]=g;c[f+104448>>2]=1;c[f+196732>>2]=512;c[f+98304>>2]=2;c[f+196736>>2]=1866;f=c[3532592]|0;if((f|0)==0){h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return b|0}gGC(f|0,9104152,280)|0;h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return b|0}function ajo(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4060468+(b*112|0)>>2];c[a+104>>2]=c[4060472+(b*112|0)>>2];c[a+108>>2]=c[4060476+(b*112|0)>>2];d=0;return d|0}function ajp(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=4060368+(b*112|0);e=0;return e|0}function ajq(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4058228+(b*112|0)>>2];c[a+104>>2]=c[4058232+(b*112|0)>>2];c[a+108>>2]=c[4058236+(b*112|0)>>2];d=0;return d|0}function ajr(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=4058128+(b*112|0);e=0;return e|0}function ajs(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6951372+(b*112|0)>>2];c[a+104>>2]=c[6951376+(b*112|0)>>2];c[a+108>>2]=c[6951380+(b*112|0)>>2];d=0;return d|0}function ajt(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=6951272+(b*112|0);e=0;return e|0}function aju(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>29){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5459056+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function ajv(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>3){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6953176+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function ajw(){var b=0,d=0,e=0,f=0,g=0,h=0;a[7462136]=1;c[2113296]=12e6;b=aia()|0;if((c[2394]|0)==0){d=c[2112932]|0;e=c[3532592]|0}else{c[2394]=0;f=c[3532596]|0;c[2112932]=f;g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060];d=f;e=g}c[d+61824>>2]=1;c[d+61828>>2]=1;c[d+61832>>2]=1;c[d+61836>>2]=1;c[d+61840>>2]=1;c[d+61844>>2]=1;c[d+61848>>2]=1;c[d+61852>>2]=1;c[d+196612>>2]=3590;if((e|0)==0){h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return b|0}gGC(e|0,9104152,280)|0;h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return b|0}function ajx(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6947228+(b*112|0)>>2];c[a+104>>2]=c[6947232+(b*112|0)>>2];c[a+108>>2]=c[6947236+(b*112|0)>>2];d=0;return d|0}function ajy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=6947128+(b*112|0);e=0;return e|0}function ajz(){var b=0,d=0,e=0,f=0,g=0,h=0;a[7462136]=1;c[2429532]=10128;c[2426966]=1846;c[2113296]=12e6;b=aia()|0;if((c[2394]|0)==0){d=c[2112932]|0;e=c[3532592]|0}else{c[2394]=0;f=c[3532596]|0;c[2112932]=f;g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060];d=f;e=g}c[d+61824>>2]=1;c[d+61828>>2]=1;c[d+61832>>2]=1;c[d+61836>>2]=1;c[d+61840>>2]=1;c[d+61844>>2]=1;c[d+61848>>2]=1;c[d+61852>>2]=1;c[d+196612>>2]=3590;if((e|0)==0){h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return b|0}gGC(e|0,9104152,280)|0;h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return b|0}function ajA(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>3){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4054796+(b*112|0)>>2];c[a+104>>2]=c[4054800+(b*112|0)>>2];c[a+108>>2]=c[4054804+(b*112|0)>>2];d=0;return d|0}function ajB(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<4&(d|0)==0)){e=1;return e|0}c[a>>2]=4054696+(b*112|0);e=0;return e|0}function ajC(){var b=0,d=0,e=0,f=0,g=0,h=0;a[7462160]=1;a[7462008]=1;c[2426966]=1846;c[3542064]=3904;c[3542066]=4732;c[3541954]=10646;c[2113296]=12e6;b=aia()|0;d=0;while(1){if((d|0)>=1024){e=0;break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==0){g=3967;break}else{d=d+1|0}}do{if((g|0)==3967){d=gGq(16384)|0;c[f>>2]=d;if((d|0)==0){e=0;break}gGz(d|0,0,16384);e=d}}while(0);c[3542036]=e;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060]}f=c[2112932]|0;c[f+39168>>2]=e;c[f+104704>>2]=e;c[f+170240>>2]=e;g=e+1024|0;c[f+39172>>2]=g;c[f+104708>>2]=g;c[f+170244>>2]=g;g=e+2048|0;c[f+39176>>2]=g;c[f+104712>>2]=g;c[f+170248>>2]=g;g=e+3072|0;c[f+39180>>2]=g;c[f+104716>>2]=g;c[f+170252>>2]=g;g=e+4096|0;c[f+39184>>2]=g;c[f+104720>>2]=g;c[f+170256>>2]=g;g=e+5120|0;c[f+39188>>2]=g;c[f+104724>>2]=g;c[f+170260>>2]=g;g=e+6144|0;c[f+39192>>2]=g;c[f+104728>>2]=g;c[f+170264>>2]=g;g=e+7168|0;c[f+39196>>2]=g;c[f+104732>>2]=g;c[f+170268>>2]=g;c[f+104448>>2]=1;c[f+196732>>2]=512;c[f+98304>>2]=2;c[f+196736>>2]=1866;f=c[3532592]|0;if((f|0)==0){h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return b|0}gGC(f|0,9104152,280)|0;h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return b|0}function ajD(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4062708+(b*112|0)>>2];c[a+104>>2]=c[4062712+(b*112|0)>>2];c[a+108>>2]=c[4062716+(b*112|0)>>2];d=0;return d|0}function ajE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=4062608+(b*112|0);e=0;return e|0}function ajF(){var b=0,d=0,e=0,f=0,g=0,h=0;a[7461936]=1;a[7462008]=1;c[2113296]=12e6;b=aia()|0;if((c[2394]|0)==0){d=c[2112932]|0;e=c[3532592]|0}else{c[2394]=0;f=c[3532596]|0;c[2112932]=f;g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060];d=f;e=g}c[d+61824>>2]=1;c[d+61828>>2]=1;c[d+61832>>2]=1;c[d+61836>>2]=1;c[d+61840>>2]=1;c[d+61844>>2]=1;c[d+61848>>2]=1;c[d+61852>>2]=1;c[d+196612>>2]=3590;if((e|0)==0){h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return b|0}gGC(e|0,9104152,280)|0;h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return b|0}function ajG(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6349028+(b*112|0)>>2];c[a+104>>2]=c[6349032+(b*112|0)>>2];c[a+108>>2]=c[6349036+(b*112|0)>>2];d=0;return d|0}function ajH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=6348928+(b*112|0);e=0;return e|0}function ajI(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6347460+(b*112|0)>>2];c[a+104>>2]=c[6347464+(b*112|0)>>2];c[a+108>>2]=c[6347468+(b*112|0)>>2];d=0;return d|0}function ajJ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=6347360+(b*112|0);e=0;return e|0}function ajK(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6328156+(b*112|0)>>2];c[a+104>>2]=c[6328160+(b*112|0)>>2];c[a+108>>2]=c[6328164+(b*112|0)>>2];d=0;return d|0}function ajL(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=6328056+(b*112|0);e=0;return e|0}function ajM(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4026016+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function ajN(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>50){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6330632+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function ajO(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>49){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5442276+(b*112|0)>>2];c[a+104>>2]=c[5442280+(b*112|0)>>2];c[a+108>>2]=c[5442284+(b*112|0)>>2];d=0;return d|0}function ajP(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<50&(d|0)==0)){e=1;return e|0}c[a>>2]=5442176+(b*112|0);e=0;return e|0}function ajQ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>49){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5436676+(b*112|0)>>2];c[a+104>>2]=c[5436680+(b*112|0)>>2];c[a+108>>2]=c[5436684+(b*112|0)>>2];d=0;return d|0}function ajR(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<50&(d|0)==0)){e=1;return e|0}c[a>>2]=5436576+(b*112|0);e=0;return e|0}function ajS(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4023540+(b*112|0)>>2];c[a+104>>2]=c[4023544+(b*112|0)>>2];c[a+108>>2]=c[4023548+(b*112|0)>>2];d=0;return d|0}function ajT(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=4023440+(b*112|0);e=0;return e|0}function ajU(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6314564+(b*112|0)>>2];c[a+104>>2]=c[6314568+(b*112|0)>>2];c[a+108>>2]=c[6314572+(b*112|0)>>2];d=0;return d|0}function ajV(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=6314464+(b*112|0);e=0;return e|0}function ajW(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5419284+(b*112|0)>>2];c[a+104>>2]=c[5419288+(b*112|0)>>2];c[a+108>>2]=c[5419292+(b*112|0)>>2];d=0;return d|0}function ajX(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=5419184+(b*112|0);e=0;return e|0}function ajY(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5413348+(b*112|0)>>2];c[a+104>>2]=c[5413352+(b*112|0)>>2];c[a+108>>2]=c[5413356+(b*112|0)>>2];d=0;return d|0}function ajZ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=5413248+(b*112|0);e=0;return e|0}function aj_(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3966772+(b*112|0)>>2];c[a+104>>2]=c[3966776+(b*112|0)>>2];c[a+108>>2]=c[3966780+(b*112|0)>>2];d=0;return d|0}function aj$(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<22&(d|0)==0)){e=1;return e|0}c[a>>2]=3966672+(b*112|0);e=0;return e|0}function aj0(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3964644+(b*112|0)>>2];c[a+104>>2]=c[3964648+(b*112|0)>>2];c[a+108>>2]=c[3964652+(b*112|0)>>2];d=0;return d|0}function aj1(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=3964544+(b*112|0);e=0;return e|0}function aj2(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3962516+(b*112|0)>>2];c[a+104>>2]=c[3962520+(b*112|0)>>2];c[a+108>>2]=c[3962524+(b*112|0)>>2];d=0;return d|0}function aj3(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=3962416+(b*112|0);e=0;return e|0}function aj4(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>33){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5415476+(b*112|0)>>2];c[a+104>>2]=c[5415480+(b*112|0)>>2];c[a+108>>2]=c[5415484+(b*112|0)>>2];d=0;return d|0}function aj5(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<34&(d|0)==0)){e=1;return e|0}c[a>>2]=5415376+(b*112|0);e=0;return e|0}function aj6(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>33){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3975060+(b*112|0)>>2];c[a+104>>2]=c[3975064+(b*112|0)>>2];c[a+108>>2]=c[3975068+(b*112|0)>>2];d=0;return d|0}function aj7(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<34&(d|0)==0)){e=1;return e|0}c[a>>2]=3974960+(b*112|0);e=0;return e|0}function aj8(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>33){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3971252+(b*112|0)>>2];c[a+104>>2]=c[3971256+(b*112|0)>>2];c[a+108>>2]=c[3971260+(b*112|0)>>2];d=0;return d|0}function aj9(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<34&(d|0)==0)){e=1;return e|0}c[a>>2]=3971152+(b*112|0);e=0;return e|0}function aka(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3969236+(b*112|0)>>2];c[a+104>>2]=c[3969240+(b*112|0)>>2];c[a+108>>2]=c[3969244+(b*112|0)>>2];d=0;return d|0}function akb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=3969136+(b*112|0);e=0;return e|0}function akc(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3978868+(b*112|0)>>2];c[a+104>>2]=c[3978872+(b*112|0)>>2];c[a+108>>2]=c[3978876+(b*112|0)>>2];d=0;return d|0}function akd(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=3978768+(b*112|0);e=0;return e|0}function ake(){var b=0,d=0,e=0,f=0,g=0,h=0;a[7462160]=1;a[64288]=1;c[3541966]=-63;c[3541964]=-60;c[3541962]=65472;c[2426966]=1970;c[3542064]=1192;c[3542066]=4732;c[3541914]=582;c[3541912]=3614;c[3541920]=2626;c[3541916]=3090;c[3541918]=4552;c[3541954]=4954;b=aia()|0;if((c[2394]|0)==0){d=c[2112932]|0}else{c[2394]=0;e=c[3532596]|0;c[2112932]=e;f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];d=e}e=d+34816|0;f=8912896;while(1){c[e>>2]=1;c[e+65536>>2]=1;g=f+1024|0;if(g>>>0>9043967){break}else{e=e+4|0;f=g}}c[d+196612>>2]=3072;c[d+196692>>2]=2538;c[d+196652>>2]=2668;c[d+196732>>2]=1932;d=c[3532592]|0;if((d|0)==0){h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return b|0}gGC(d|0,9104152,280)|0;h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return b|0}function akf(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>24){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6317484+(b*112|0)>>2];c[a+104>>2]=c[6317488+(b*112|0)>>2];c[a+108>>2]=c[6317492+(b*112|0)>>2];d=0;return d|0}function akg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<25&(d|0)==0)){e=1;return e|0}c[a>>2]=6317384+(b*112|0);e=0;return e|0}function akh(){var b=0,d=0,e=0,f=0,g=0,h=0;a[7462160]=1;a[64288]=1;c[3541966]=-63;c[3541964]=-60;c[3541962]=65472;c[2429532]=9454;c[2426966]=704;c[3542064]=1192;c[3542066]=4732;c[3541914]=582;c[3541912]=3614;c[3541920]=2626;c[3541916]=3090;c[3541918]=4552;c[3541954]=4954;b=aia()|0;if((c[2394]|0)==0){d=c[2112932]|0}else{c[2394]=0;e=c[3532596]|0;c[2112932]=e;f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];d=e}e=d+34816|0;f=8912896;while(1){c[e>>2]=1;c[e+65536>>2]=1;g=f+1024|0;if(g>>>0>9043967){break}else{e=e+4|0;f=g}}c[d+196612>>2]=3072;c[d+196692>>2]=2538;c[d+196652>>2]=2668;c[d+196732>>2]=1932;d=c[3532592]|0;if((d|0)==0){h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return b|0}gGC(d|0,9104152,280)|0;h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return b|0}function aki(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>34){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3947036+(b*112|0)>>2];c[a+104>>2]=c[3947040+(b*112|0)>>2];c[a+108>>2]=c[3947044+(b*112|0)>>2];d=0;return d|0}function akj(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<35&(d|0)==0)){e=1;return e|0}c[a>>2]=3946936+(b*112|0);e=0;return e|0}function akk(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1269976+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function akl(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>41){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3950856+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function akm(){var b=0,d=0;a[7461928]=1;c[2426966]=1896;b=aia()|0;d=(c[3542028]|0)+((c[2113268]|0)-8192)|0;c[3541880]=d;Wl(d);return b|0}function akn(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>31){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1918756+(b*112|0)>>2];c[a+104>>2]=c[1918760+(b*112|0)>>2];c[a+108>>2]=c[1918764+(b*112|0)>>2];d=0;return d|0}function ako(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<32&(d|0)==0)){e=1;return e|0}c[a>>2]=1918656+(b*112|0);e=0;return e|0}function akp(){var b=0,d=0;a[7461928]=1;c[2426966]=3484;b=aia()|0;d=(c[3542028]|0)+((c[2113268]|0)-8192)|0;c[3541880]=d;Wl(d);return b|0}function akq(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1267500+(b*112|0)>>2];c[a+104>>2]=c[1267504+(b*112|0)>>2];c[a+108>>2]=c[1267508+(b*112|0)>>2];d=0;return d|0}function akr(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=1267400+(b*112|0);e=0;return e|0}function aks(){var b=0,d=0;a[7461928]=1;b=aia()|0;d=(c[3542028]|0)+((c[2113268]|0)-8192)|0;c[3541880]=d;Wk(d,9);return b|0}function akt(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1264924+(b*112|0)>>2];c[a+104>>2]=c[1264928+(b*112|0)>>2];c[a+108>>2]=c[1264932+(b*112|0)>>2];d=0;return d|0}function aku(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=1264824+(b*112|0);e=0;return e|0}function akv(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[983908+(b*112|0)>>2];c[a+104>>2]=c[983912+(b*112|0)>>2];c[a+108>>2]=c[983916+(b*112|0)>>2];d=0;return d|0}function akw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=983808+(b*112|0);e=0;return e|0}function akx(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3785388+(b*112|0)>>2];c[a+104>>2]=c[3785392+(b*112|0)>>2];c[a+108>>2]=c[3785396+(b*112|0)>>2];d=0;return d|0}function aky(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=3785288+(b*112|0);e=0;return e|0}function akz(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1840244+(b*112|0)>>2];c[a+104>>2]=c[1840248+(b*112|0)>>2];c[a+108>>2]=c[1840252+(b*112|0)>>2];d=0;return d|0}function akA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=1840144+(b*112|0);e=0;return e|0}function akB(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5391708+(b*112|0)>>2];c[a+104>>2]=c[5391712+(b*112|0)>>2];c[a+108>>2]=c[5391716+(b*112|0)>>2];d=0;return d|0}function akC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=5391608+(b*112|0);e=0;return e|0}function akD(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1910152+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function akE(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>45){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5394184+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function akF(){var a=0,b=0,d=0,e=0,f=0,g=0;c[3541916]=1478;c[3541954]=3250;a=aia()|0;if((c[2394]|0)==0){b=c[2112932]|0}else{c[2394]=0;d=c[3532596]|0;c[2112932]=d;e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060];b=d}d=b+65280|0;e=16711680;while(1){c[d>>2]=1;c[d+65536>>2]=1;c[d+131072>>2]=1;f=e+1024|0;if(f>>>0>16777215){break}else{d=d+4|0;e=f}}c[b+196612>>2]=492;c[b+196692>>2]=870;c[b+196652>>2]=136;c[b+196732>>2]=1816;b=c[3532592]|0;if((b|0)==0){g=c[2113054]|0;c[2113060]=g;c[2394]=-1;Tv(2);return a|0}gGC(b|0,9104152,280)|0;g=c[2113054]|0;c[2113060]=g;c[2394]=-1;Tv(2);return a|0}function akG(){var b=0,d=0,e=0,f=0;if(a[727232]|0){gGr(c[2424883]|0);c[2424883]=0}a[727232]=0;gGz(9699520,0,64);agV();Wr();c[2113250]=0;c[2113246]=0;c[2113268]=0;c[2113274]=0;c[2113252]=0;c[2439242]=0;c[2433564]=0;c[2427232]=0;c[2427032]=0;c[2439240]=0;c[2433562]=0;c[2429862]=0;c[2432858]=0;c[2429366]=0;c[2429506]=0;c[2443334]=0;c[2429532]=0;c[3541966]=0;c[3541964]=0;c[3541962]=0;a[7461984]=0;a[7461976]=0;a[7461968]=0;a[7461992]=0;a[7462144]=0;gGz(9648,-1|0,16);c[3542068]=0;a[7462128]=0;a[7462160]=0;a[7461928]=0;a[7461848]=0;a[7461808]=0;a[7461720]=0;a[7462152]=0;a[7462168]=0;a[7462e3]=0;a[7461936]=0;a[7461672]=0;a[7461712]=0;a[7462136]=0;c[2426966]=0;b=c[3542036]|0;d=0;while(1){if((d|0)>=1024){e=4401;break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==(b|0)){break}else{d=d+1|0}}if((e|0)==4401){c[3542036]=0;return 0}gGr(b);c[f>>2]=0;c[3542036]=0;return 0}function akH(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>32){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6291092+(b*112|0)>>2];c[a+104>>2]=c[6291096+(b*112|0)>>2];c[a+108>>2]=c[6291100+(b*112|0)>>2];d=0;return d|0}function akI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<33&(d|0)==0)){e=1;return e|0}c[a>>2]=6290992+(b*112|0);e=0;return e|0}function akJ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3910928+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function akK(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>52){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6294688+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function akL(){a[7461848]=1;c[2429532]=10558;return aia()|0}function akM(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>32){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5377900+(b*112|0)>>2];c[a+104>>2]=c[5377904+(b*112|0)>>2];c[a+108>>2]=c[5377908+(b*112|0)>>2];d=0;return d|0}function akN(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<33&(d|0)==0)){e=1;return e|0}c[a>>2]=5377800+(b*112|0);e=0;return e|0}function akO(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>55){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5381496+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function akP(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>47){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4110988+(b*112|0)>>2];c[a+104>>2]=c[4110992+(b*112|0)>>2];c[a+108>>2]=c[4110996+(b*112|0)>>2];d=0;return d|0}function akQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<48&(d|0)==0)){e=1;return e|0}c[a>>2]=4110888+(b*112|0);e=0;return e|0}function akR(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>55){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4116264+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function akS(){a[7461848]=1;return aia()|0}function akT(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1968340+(b*112|0)>>2];c[a+104>>2]=c[1968344+(b*112|0)>>2];c[a+108>>2]=c[1968348+(b*112|0)>>2];d=0;return d|0}function akU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<21&(d|0)==0)){e=1;return e|0}c[a>>2]=1968240+(b*112|0);e=0;return e|0}function akV(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>34){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1970692+(b*112|0)>>2];c[a+104>>2]=c[1970696+(b*112|0)>>2];c[a+108>>2]=c[1970700+(b*112|0)>>2];d=0;return d|0}function akW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<35&(d|0)==0)){e=1;return e|0}c[a>>2]=1970592+(b*112|0);e=0;return e|0}function akX(){var b=0,d=0,e=0,f=0,g=0,h=0;a[7461848]=1;a[7461712]=1;a[7462144]=1;c[3542064]=1922;c[3542066]=4732;c[3541954]=10646;b=aia()|0;d=0;while(1){if((d|0)>=1024){e=0;break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==0){g=4495;break}else{d=d+1|0}}do{if((g|0)==4495){d=gGq(16384)|0;c[f>>2]=d;if((d|0)==0){e=0;break}gGz(d|0,0,16384);e=d}}while(0);c[3542036]=e;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060]}f=c[2112932]|0;c[f+39168>>2]=e;c[f+104704>>2]=e;c[f+170240>>2]=e;g=e+1024|0;c[f+39172>>2]=g;c[f+104708>>2]=g;c[f+170244>>2]=g;g=e+2048|0;c[f+39176>>2]=g;c[f+104712>>2]=g;c[f+170248>>2]=g;g=e+3072|0;c[f+39180>>2]=g;c[f+104716>>2]=g;c[f+170252>>2]=g;g=e+4096|0;c[f+39184>>2]=g;c[f+104720>>2]=g;c[f+170256>>2]=g;g=e+5120|0;c[f+39188>>2]=g;c[f+104724>>2]=g;c[f+170260>>2]=g;g=e+6144|0;c[f+39192>>2]=g;c[f+104728>>2]=g;c[f+170264>>2]=g;g=e+7168|0;c[f+39196>>2]=g;c[f+104732>>2]=g;c[f+170268>>2]=g;g=f+34816|0;e=8912896;while(1){c[g+65536>>2]=1;d=e+1024|0;if(d>>>0>8978431){break}else{g=g+4|0;e=d}}c[f+196732>>2]=1056;e=f+38912|0;g=9961472;while(1){c[e+65536>>2]=2;d=g+1024|0;if(d>>>0>10027007){break}else{e=e+4|0;g=d}}c[f+196736>>2]=2260;g=f+65280|0;e=16711680;while(1){c[g+65536>>2]=3;d=e+1024|0;if(d>>>0>16777215){break}else{g=g+4|0;e=d}}c[f+196660>>2]=3422;c[f+196740>>2]=1250;f=c[3532592]|0;if((f|0)==0){h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return b|0}gGC(f|0,9104152,280)|0;h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return b|0}function akY(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5325252+(b*112|0)>>2];c[a+104>>2]=c[5325256+(b*112|0)>>2];c[a+108>>2]=c[5325260+(b*112|0)>>2];d=0;return d|0}function akZ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=5325152+(b*112|0);e=0;return e|0}function ak_(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>29){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1863040+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function ak$(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>61){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5327728+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function ak0(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3821324+(b*112|0)>>2];c[a+104>>2]=c[3821328+(b*112|0)>>2];c[a+108>>2]=c[3821332+(b*112|0)>>2];d=0;return d|0}function ak1(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=3821224+(b*112|0);e=0;return e|0}function ak2(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3823900+(b*112|0)>>2];c[a+104>>2]=c[3823904+(b*112|0)>>2];c[a+108>>2]=c[3823908+(b*112|0)>>2];d=0;return d|0}function ak3(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=3823800+(b*112|0);e=0;return e|0}function ak4(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>51){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1851716+(b*112|0)>>2];c[a+104>>2]=c[1851720+(b*112|0)>>2];c[a+108>>2]=c[1851724+(b*112|0)>>2];d=0;return d|0}function ak5(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<52&(d|0)==0)){e=1;return e|0}c[a>>2]=1851616+(b*112|0);e=0;return e|0}function ak6(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3827932+(b*112|0)>>2];c[a+104>>2]=c[3827936+(b*112|0)>>2];c[a+108>>2]=c[3827940+(b*112|0)>>2];d=0;return d|0}function ak7(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=3827832+(b*112|0);e=0;return e|0}function ak8(){var b=0,d=0,e=0,f=0,g=0,h=0;a[7462160]=1;a[64288]=1;a[7462144]=1;a[7461712]=1;c[3542064]=3904;c[3542066]=4732;c[3541914]=3658;c[3541912]=4102;c[3541920]=1072;c[3541916]=2604;c[3541918]=1748;c[3541938]=120;c[3541954]=758;b=aia()|0;d=0;while(1){if((d|0)>=1024){e=0;break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==0){g=4589;break}else{d=d+1|0}}do{if((g|0)==4589){d=gGq(16384)|0;c[f>>2]=d;if((d|0)==0){e=0;break}gGz(d|0,0,16384);e=d}}while(0);c[3542036]=e;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060]}f=c[2112932]|0;c[f+39168>>2]=e;c[f+104704>>2]=e;c[f+170240>>2]=e;g=e+1024|0;c[f+39172>>2]=g;c[f+104708>>2]=g;c[f+170244>>2]=g;g=e+2048|0;c[f+39176>>2]=g;c[f+104712>>2]=g;c[f+170248>>2]=g;g=e+3072|0;c[f+39180>>2]=g;c[f+104716>>2]=g;c[f+170252>>2]=g;g=e+4096|0;c[f+39184>>2]=g;c[f+104720>>2]=g;c[f+170256>>2]=g;g=e+5120|0;c[f+39188>>2]=g;c[f+104724>>2]=g;c[f+170260>>2]=g;g=e+6144|0;c[f+39192>>2]=g;c[f+104728>>2]=g;c[f+170264>>2]=g;g=e+7168|0;c[f+39196>>2]=g;c[f+104732>>2]=g;c[f+170268>>2]=g;g=e+8192|0;c[f+39200>>2]=g;c[f+104736>>2]=g;c[f+170272>>2]=g;g=e+9216|0;c[f+39204>>2]=g;c[f+104740>>2]=g;c[f+170276>>2]=g;g=e+10240|0;c[f+39208>>2]=g;c[f+104744>>2]=g;c[f+170280>>2]=g;g=e+11264|0;c[f+39212>>2]=g;c[f+104748>>2]=g;c[f+170284>>2]=g;g=e+12288|0;c[f+39216>>2]=g;c[f+104752>>2]=g;c[f+170288>>2]=g;g=e+13312|0;c[f+39220>>2]=g;c[f+104756>>2]=g;c[f+170292>>2]=g;g=e+14336|0;c[f+39224>>2]=g;c[f+104760>>2]=g;c[f+170296>>2]=g;g=e+15360|0;c[f+39228>>2]=g;c[f+104764>>2]=g;c[f+170300>>2]=g;g=f+38912|0;e=9961472;while(1){c[g+65536>>2]=1;d=e+1024|0;if(d>>>0>10027007){break}else{g=g+4|0;e=d}}c[f+196732>>2]=468;f=c[3532592]|0;if((f|0)==0){h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return b|0}gGC(f|0,9104152,280)|0;h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return b|0}function ak9(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1861684+(b*112|0)>>2];c[a+104>>2]=c[1861688+(b*112|0)>>2];c[a+108>>2]=c[1861692+(b*112|0)>>2];d=0;return d|0}function ala(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=1861584+(b*112|0);e=0;return e|0}function alb(){a[7461992]=1;a[7462176]=1;return aia()|0}function alc(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1860228+(b*112|0)>>2];c[a+104>>2]=c[1860232+(b*112|0)>>2];c[a+108>>2]=c[1860236+(b*112|0)>>2];d=0;return d|0}function ald(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=1860128+(b*112|0);e=0;return e|0}function ale(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1858996+(b*112|0)>>2];c[a+104>>2]=c[1859e3+(b*112|0)>>2];c[a+108>>2]=c[1859004+(b*112|0)>>2];d=0;return d|0}function alf(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=1858896+(b*112|0);e=0;return e|0}function alg(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3826476+(b*112|0)>>2];c[a+104>>2]=c[3826480+(b*112|0)>>2];c[a+108>>2]=c[3826484+(b*112|0)>>2];d=0;return d|0}function alh(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=3826376+(b*112|0);e=0;return e|0}function ali(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1857540+(b*112|0)>>2];c[a+104>>2]=c[1857544+(b*112|0)>>2];c[a+108>>2]=c[1857548+(b*112|0)>>2];d=0;return d|0}function alj(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=1857440+(b*112|0);e=0;return e|0}function alk(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>27){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7396940+(b*112|0)>>2];c[a+104>>2]=c[7396944+(b*112|0)>>2];c[a+108>>2]=c[7396948+(b*112|0)>>2];d=0;return d|0}function all(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<28&(d|0)==0)){e=1;return e|0}c[a>>2]=7396840+(b*112|0);e=0;return e|0}function alm(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>29){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1863040+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aln(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>61){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7399976+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function alo(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>27){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6860900+(b*112|0)>>2];c[a+104>>2]=c[6860904+(b*112|0)>>2];c[a+108>>2]=c[6860908+(b*112|0)>>2];d=0;return d|0}function alp(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<28&(d|0)==0)){e=1;return e|0}c[a>>2]=6860800+(b*112|0);e=0;return e|0}function alq(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>61){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6863936+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function alr(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>27){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7193172+(b*112|0)>>2];c[a+104>>2]=c[7193176+(b*112|0)>>2];c[a+108>>2]=c[7193180+(b*112|0)>>2];d=0;return d|0}function als(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<28&(d|0)==0)){e=1;return e|0}c[a>>2]=7193072+(b*112|0);e=0;return e|0}function alt(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>24){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7196308+(b*112|0)>>2];c[a+104>>2]=c[7196312+(b*112|0)>>2];c[a+108>>2]=c[7196316+(b*112|0)>>2];d=0;return d|0}function alu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<25&(d|0)==0)){e=1;return e|0}c[a>>2]=7196208+(b*112|0);e=0;return e|0}function alv(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>51){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6864780+(b*112|0)>>2];c[a+104>>2]=c[6864784+(b*112|0)>>2];c[a+108>>2]=c[6864788+(b*112|0)>>2];d=0;return d|0}function alw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<52&(d|0)==0)){e=1;return e|0}c[a>>2]=6864680+(b*112|0);e=0;return e|0}function alx(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7200564+(b*112|0)>>2];c[a+104>>2]=c[7200568+(b*112|0)>>2];c[a+108>>2]=c[7200572+(b*112|0)>>2];d=0;return d|0}function aly(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=7200464+(b*112|0);e=0;return e|0}function alz(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;a[7461808]=1;a[64288]=1;a[7462e3]=1;c[2429532]=6110;c[2426966]=1190;c[3542064]=154;c[3542066]=4732;b=aia()|0;d=0;while(1){if((d|0)>=1024){e=0;break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==0){g=4759;break}else{d=d+1|0}}do{if((g|0)==4759){d=gGq(16384)|0;c[f>>2]=d;if((d|0)==0){e=0;break}gGz(d|0,0,16384);e=d}}while(0);c[3542036]=e;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060]}f=c[2112932]|0;c[f+36864>>2]=e;c[f+102400>>2]=e;c[f+167936>>2]=e;g=e+1024|0;c[f+36868>>2]=g;c[f+102404>>2]=g;c[f+167940>>2]=g;d=e+2048|0;c[f+36872>>2]=d;c[f+102408>>2]=d;c[f+167944>>2]=d;h=e+3072|0;c[f+36876>>2]=h;c[f+102412>>2]=h;c[f+167948>>2]=h;i=e+4096|0;c[f+36880>>2]=i;c[f+102416>>2]=i;c[f+167952>>2]=i;j=e+5120|0;c[f+36884>>2]=j;c[f+102420>>2]=j;c[f+167956>>2]=j;k=e+6144|0;c[f+36888>>2]=k;c[f+102424>>2]=k;c[f+167960>>2]=k;l=e+7168|0;c[f+36892>>2]=l;c[f+102428>>2]=l;c[f+167964>>2]=l;m=e+8192|0;c[f+36896>>2]=m;c[f+102432>>2]=m;c[f+167968>>2]=m;n=e+9216|0;c[f+36900>>2]=n;c[f+102436>>2]=n;c[f+167972>>2]=n;o=e+10240|0;c[f+36904>>2]=o;c[f+102440>>2]=o;c[f+167976>>2]=o;p=e+11264|0;c[f+36908>>2]=p;c[f+102444>>2]=p;c[f+167980>>2]=p;q=e+12288|0;c[f+36912>>2]=q;c[f+102448>>2]=q;c[f+167984>>2]=q;r=e+13312|0;c[f+36916>>2]=r;c[f+102452>>2]=r;c[f+167988>>2]=r;s=e+14336|0;c[f+36920>>2]=s;c[f+102456>>2]=s;c[f+167992>>2]=s;t=e+15360|0;c[f+36924>>2]=t;c[f+102460>>2]=t;c[f+167996>>2]=t;c[f+36928>>2]=e;c[f+102464>>2]=e;c[f+168e3>>2]=e;c[f+36932>>2]=g;c[f+102468>>2]=g;c[f+168004>>2]=g;c[f+36936>>2]=d;c[f+102472>>2]=d;c[f+168008>>2]=d;c[f+36940>>2]=h;c[f+102476>>2]=h;c[f+168012>>2]=h;c[f+36944>>2]=i;c[f+102480>>2]=i;c[f+168016>>2]=i;c[f+36948>>2]=j;c[f+102484>>2]=j;c[f+168020>>2]=j;c[f+36952>>2]=k;c[f+102488>>2]=k;c[f+168024>>2]=k;c[f+36956>>2]=l;c[f+102492>>2]=l;c[f+168028>>2]=l;c[f+36960>>2]=m;c[f+102496>>2]=m;c[f+168032>>2]=m;c[f+36964>>2]=n;c[f+102500>>2]=n;c[f+168036>>2]=n;c[f+36968>>2]=o;c[f+102504>>2]=o;c[f+168040>>2]=o;c[f+36972>>2]=p;c[f+102508>>2]=p;c[f+168044>>2]=p;c[f+36976>>2]=q;c[f+102512>>2]=q;c[f+168048>>2]=q;c[f+36980>>2]=r;c[f+102516>>2]=r;c[f+168052>>2]=r;c[f+36984>>2]=s;c[f+102520>>2]=s;c[f+168056>>2]=s;c[f+36988>>2]=t;c[f+102524>>2]=t;c[f+168060>>2]=t;t=f+38912|0;s=9961472;while(1){c[t+65536>>2]=1;r=s+1024|0;if(r>>>0>10092543){break}else{t=t+4|0;s=r}}c[f+196652>>2]=1428;c[f+196732>>2]=2290;c[f+39200>>2]=2;c[f+196616>>2]=770;f=c[3532592]|0;if((f|0)==0){u=c[2113054]|0;c[2113060]=u;c[2394]=-1;c[1865530]=4;return b|0}gGC(f|0,9104152,280)|0;u=c[2113054]|0;c[2113060]=u;c[2394]=-1;c[1865530]=4;return b|0}function alA(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7199108+(b*112|0)>>2];c[a+104>>2]=c[7199112+(b*112|0)>>2];c[a+108>>2]=c[7199116+(b*112|0)>>2];d=0;return d|0}function alB(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=7199008+(b*112|0);e=0;return e|0}function alC(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>29){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6268456+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function alD(){return aia()|0}function alE(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6870604+(b*112|0)>>2];c[a+104>>2]=c[6870608+(b*112|0)>>2];c[a+108>>2]=c[6870612+(b*112|0)>>2];d=0;return d|0}function alF(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<22&(d|0)==0)){e=1;return e|0}c[a>>2]=6870504+(b*112|0);e=0;return e|0}function alG(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>31){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5283244+(b*112|0)>>2];c[a+104>>2]=c[5283248+(b*112|0)>>2];c[a+108>>2]=c[5283252+(b*112|0)>>2];d=0;return d|0}function alH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<32&(d|0)==0)){e=1;return e|0}c[a>>2]=5283144+(b*112|0);e=0;return e|0}function alI(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>23){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1830424+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function alJ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>51){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5286728+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function alK(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>31){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3748852+(b*112|0)>>2];c[a+104>>2]=c[3748856+(b*112|0)>>2];c[a+108>>2]=c[3748860+(b*112|0)>>2];d=0;return d|0}function alL(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<32&(d|0)==0)){e=1;return e|0}c[a>>2]=3748752+(b*112|0);e=0;return e|0}function alM(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>31){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3533692+(b*112|0)>>2];c[a+104>>2]=c[3533696+(b*112|0)>>2];c[a+108>>2]=c[3533700+(b*112|0)>>2];d=0;return d|0}function alN(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<32&(d|0)==0)){e=1;return e|0}c[a>>2]=3533592+(b*112|0);e=0;return e|0}function alO(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>48){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3537176+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function alP(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>27){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6851036+(b*112|0)>>2];c[a+104>>2]=c[6851040+(b*112|0)>>2];c[a+108>>2]=c[6851044+(b*112|0)>>2];d=0;return d|0}function alQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<28&(d|0)==0)){e=1;return e|0}c[a>>2]=6850936+(b*112|0);e=0;return e|0}function alR(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>29){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5282664+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function alS(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>44){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6854072+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function alT(){a[7462168]=1;return aia()|0}function alU(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>27){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6235044+(b*112|0)>>2];c[a+104>>2]=c[6235048+(b*112|0)>>2];c[a+108>>2]=c[6235052+(b*112|0)>>2];d=0;return d|0}function alV(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<28&(d|0)==0)){e=1;return e|0}c[a>>2]=6234944+(b*112|0);e=0;return e|0}function alW(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>27){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3744484+(b*112|0)>>2];c[a+104>>2]=c[3744488+(b*112|0)>>2];c[a+108>>2]=c[3744492+(b*112|0)>>2];d=0;return d|0}function alX(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<28&(d|0)==0)){e=1;return e|0}c[a>>2]=3744384+(b*112|0);e=0;return e|0}function alY(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>42){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6238180+(b*112|0)>>2];c[a+104>>2]=c[6238184+(b*112|0)>>2];c[a+108>>2]=c[6238188+(b*112|0)>>2];d=0;return d|0}function alZ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<43&(d|0)==0)){e=1;return e|0}c[a>>2]=6238080+(b*112|0);e=0;return e|0}function al_(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6219740+(b*112|0)>>2];c[a+104>>2]=c[6219744+(b*112|0)>>2];c[a+108>>2]=c[6219748+(b*112|0)>>2];d=0;return d|0}function al$(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=6219640+(b*112|0);e=0;return e|0}function al0(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>23){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3679672+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function al1(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>67){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6221768+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function al2(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3677644+(b*112|0)>>2];c[a+104>>2]=c[3677648+(b*112|0)>>2];c[a+108>>2]=c[3677652+(b*112|0)>>2];d=0;return d|0}function al3(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=3677544+(b*112|0);e=0;return e|0}function al4(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>33){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5242980+(b*112|0)>>2];c[a+104>>2]=c[5242984+(b*112|0)>>2];c[a+108>>2]=c[5242988+(b*112|0)>>2];d=0;return d|0}function al5(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<34&(d|0)==0)){e=1;return e|0}c[a>>2]=5242880+(b*112|0);e=0;return e|0}function al6(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5240852+(b*112|0)>>2];c[a+104>>2]=c[5240856+(b*112|0)>>2];c[a+108>>2]=c[5240860+(b*112|0)>>2];d=0;return d|0}function al7(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=5240752+(b*112|0);e=0;return e|0}function al8(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6216972+(b*112|0)>>2];c[a+104>>2]=c[6216976+(b*112|0)>>2];c[a+108>>2]=c[6216980+(b*112|0)>>2];d=0;return d|0}function al9(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=6216872+(b*112|0);e=0;return e|0}function ama(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>23){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3677160+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function amb(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>52){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6219e3+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function amc(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>33){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6400492+(b*112|0)>>2];c[a+104>>2]=c[6400496+(b*112|0)>>2];c[a+108>>2]=c[6400500+(b*112|0)>>2];d=0;return d|0}function amd(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<34&(d|0)==0)){e=1;return e|0}c[a>>2]=6400392+(b*112|0);e=0;return e|0}function ame(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7167628+(b*112|0)>>2];c[a+104>>2]=c[7167632+(b*112|0)>>2];c[a+108>>2]=c[7167636+(b*112|0)>>2];d=0;return d|0}function amf(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=7167528+(b*112|0);e=0;return e|0}function amg(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>23){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3679672+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function amh(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>59){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7169656+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function ami(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>33){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6829124+(b*112|0)>>2];c[a+104>>2]=c[6829128+(b*112|0)>>2];c[a+108>>2]=c[6829132+(b*112|0)>>2];d=0;return d|0}function amj(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<34&(d|0)==0)){e=1;return e|0}c[a>>2]=6829024+(b*112|0);e=0;return e|0}function amk(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6819516+(b*112|0)>>2];c[a+104>>2]=c[6819520+(b*112|0)>>2];c[a+108>>2]=c[6819524+(b*112|0)>>2];d=0;return d|0}function aml(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=6819416+(b*112|0);e=0;return e|0}function amm(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5176064+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function amn(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>3){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6821320+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function amo(){c[2429532]=1038;a[7461720]=1;c[2113296]=12e6;return aia()|0}function amp(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5170452+(b*112|0)>>2];c[a+104>>2]=c[5170456+(b*112|0)>>2];c[a+108>>2]=c[5170460+(b*112|0)>>2];d=0;return d|0}function amq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=5170352+(b*112|0);e=0;return e|0}function amr(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3634476+(b*112|0)>>2];c[a+104>>2]=c[3634480+(b*112|0)>>2];c[a+108>>2]=c[3634484+(b*112|0)>>2];d=0;return d|0}function ams(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=3634376+(b*112|0);e=0;return e|0}function amt(){c[2426966]=40;c[2429532]=1038;a[7461720]=1;c[2113296]=12e6;return aia()|0}function amu(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6182012+(b*112|0)>>2];c[a+104>>2]=c[6182016+(b*112|0)>>2];c[a+108>>2]=c[6182020+(b*112|0)>>2];d=0;return d|0}function amv(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=6181912+(b*112|0);e=0;return e|0}function amw(){a[7461720]=1;c[2113296]=12e6;return aia()|0}function amx(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5174260+(b*112|0)>>2];c[a+104>>2]=c[5174264+(b*112|0)>>2];c[a+108>>2]=c[5174268+(b*112|0)>>2];d=0;return d|0}function amy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=5174160+(b*112|0);e=0;return e|0}function amz(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5172356+(b*112|0)>>2];c[a+104>>2]=c[5172360+(b*112|0)>>2];c[a+108>>2]=c[5172364+(b*112|0)>>2];d=0;return d|0}function amA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=5172256+(b*112|0);e=0;return e|0}function amB(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6180108+(b*112|0)>>2];c[a+104>>2]=c[6180112+(b*112|0)>>2];c[a+108>>2]=c[6180116+(b*112|0)>>2];d=0;return d|0}function amC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=6180008+(b*112|0);e=0;return e|0}function amD(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>29){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6164740+(b*112|0)>>2];c[a+104>>2]=c[6164744+(b*112|0)>>2];c[a+108>>2]=c[6164748+(b*112|0)>>2];d=0;return d|0}function amE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<30&(d|0)==0)){e=1;return e|0}c[a>>2]=6164640+(b*112|0);e=0;return e|0}function amF(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3618544+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function amG(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>40){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6168e3+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function amH(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>33){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3602444+(b*112|0)>>2];c[a+104>>2]=c[3602448+(b*112|0)>>2];c[a+108>>2]=c[3602452+(b*112|0)>>2];d=0;return d|0}function amI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<34&(d|0)==0)){e=1;return e|0}c[a>>2]=3602344+(b*112|0);e=0;return e|0}function amJ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1213328+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function amK(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>3){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6821320+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function amL(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>33){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1767316+(b*112|0)>>2];c[a+104>>2]=c[1767320+(b*112|0)>>2];c[a+108>>2]=c[1767324+(b*112|0)>>2];d=0;return d|0}function amM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<34&(d|0)==0)){e=1;return e|0}c[a>>2]=1767216+(b*112|0);e=0;return e|0}function amN(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>27){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1771124+(b*112|0)>>2];c[a+104>>2]=c[1771128+(b*112|0)>>2];c[a+108>>2]=c[1771132+(b*112|0)>>2];d=0;return d|0}function amO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<28&(d|0)==0)){e=1;return e|0}c[a>>2]=1771024+(b*112|0);e=0;return e|0}function amP(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>33){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1774260+(b*112|0)>>2];c[a+104>>2]=c[1774264+(b*112|0)>>2];c[a+108>>2]=c[1774268+(b*112|0)>>2];d=0;return d|0}function amQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<34&(d|0)==0)){e=1;return e|0}c[a>>2]=1774160+(b*112|0);e=0;return e|0}function amR(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5139484+(b*112|0)>>2];c[a+104>>2]=c[5139488+(b*112|0)>>2];c[a+108>>2]=c[5139492+(b*112|0)>>2];d=0;return d|0}function amS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=5139384+(b*112|0);e=0;return e|0}function amT(){var b=0,d=0,e=0,f=0,g=0,h=0;a[7462160]=1;a[64288]=1;a[7462144]=1;a[7462008]=1;c[2426966]=1564;c[3542064]=3904;c[3542066]=4732;c[3541954]=14344;c[2113296]=12e6;b=aia()|0;d=0;while(1){if((d|0)>=1024){e=0;break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==0){g=5266;break}else{d=d+1|0}}do{if((g|0)==5266){d=gGq(16384)|0;c[f>>2]=d;if((d|0)==0){e=0;break}gGz(d|0,0,16384);e=d}}while(0);c[3542036]=e;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060]}f=c[2112932]|0;c[f+39168>>2]=e;c[f+104704>>2]=e;c[f+170240>>2]=e;g=e+1024|0;c[f+39172>>2]=g;c[f+104708>>2]=g;c[f+170244>>2]=g;g=e+2048|0;c[f+39176>>2]=g;c[f+104712>>2]=g;c[f+170248>>2]=g;g=e+3072|0;c[f+39180>>2]=g;c[f+104716>>2]=g;c[f+170252>>2]=g;g=e+4096|0;c[f+39184>>2]=g;c[f+104720>>2]=g;c[f+170256>>2]=g;g=e+5120|0;c[f+39188>>2]=g;c[f+104724>>2]=g;c[f+170260>>2]=g;g=e+6144|0;c[f+39192>>2]=g;c[f+104728>>2]=g;c[f+170264>>2]=g;g=e+7168|0;c[f+39196>>2]=g;c[f+104732>>2]=g;c[f+170268>>2]=g;g=e+8192|0;c[f+39200>>2]=g;c[f+104736>>2]=g;c[f+170272>>2]=g;g=e+9216|0;c[f+39204>>2]=g;c[f+104740>>2]=g;c[f+170276>>2]=g;g=e+10240|0;c[f+39208>>2]=g;c[f+104744>>2]=g;c[f+170280>>2]=g;g=e+11264|0;c[f+39212>>2]=g;c[f+104748>>2]=g;c[f+170284>>2]=g;g=e+12288|0;c[f+39216>>2]=g;c[f+104752>>2]=g;c[f+170288>>2]=g;g=e+13312|0;c[f+39220>>2]=g;c[f+104756>>2]=g;c[f+170292>>2]=g;g=e+14336|0;c[f+39224>>2]=g;c[f+104760>>2]=g;c[f+170296>>2]=g;g=e+15360|0;c[f+39228>>2]=g;c[f+104764>>2]=g;c[f+170300>>2]=g;c[f+61824>>2]=1;c[f+61828>>2]=1;c[f+61832>>2]=1;c[f+61836>>2]=1;c[f+61840>>2]=1;c[f+61844>>2]=1;c[f+61848>>2]=1;c[f+61852>>2]=1;c[f+196612>>2]=1956;c[f+104448>>2]=2;c[f+104452>>2]=2;c[f+104456>>2]=2;c[f+104460>>2]=2;c[f+196736>>2]=2130;g=f+65280|0;e=16711680;while(1){c[g+65536>>2]=3;d=e+1024|0;if(d>>>0>16777215){break}else{g=g+4|0;e=d}}c[f+196660>>2]=3288;c[f+196740>>2]=1002;f=c[3532592]|0;if((f|0)==0){h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return b|0}gGC(f|0,9104152,280)|0;h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return b|0}function amU(){var d=0,e=0,f=0,g=0;b[4858984]=0;agV();Wr();c[2113250]=0;c[2113246]=0;c[2113268]=0;c[2113274]=0;c[2113252]=0;c[2439242]=0;c[2433564]=0;c[2427232]=0;c[2427032]=0;c[2439240]=0;c[2433562]=0;c[2429862]=0;c[2432858]=0;c[2429366]=0;c[2429506]=0;c[2443334]=0;c[2429532]=0;c[3541966]=0;c[3541964]=0;c[3541962]=0;a[7461984]=0;a[7461976]=0;a[7461968]=0;a[7461992]=0;a[7462144]=0;gGz(9648,-1|0,16);c[3542068]=0;a[7462128]=0;a[7462160]=0;a[7461928]=0;a[7461848]=0;a[7461808]=0;a[7461720]=0;a[7462152]=0;a[7462168]=0;a[7462e3]=0;a[7461936]=0;a[7461672]=0;a[7461712]=0;a[7462136]=0;c[2426966]=0;d=c[3542036]|0;e=0;while(1){if((e|0)>=1024){f=5285;break}g=9638528+(e<<2)|0;if((c[g>>2]|0)==(d|0)){break}else{e=e+1|0}}if((f|0)==5285){c[3542036]=0;return 0}gGr(d);c[g>>2]=0;c[3542036]=0;return 0}function amV(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3606924+(b*112|0)>>2];c[a+104>>2]=c[3606928+(b*112|0)>>2];c[a+108>>2]=c[3606932+(b*112|0)>>2];d=0;return d|0}function amW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=3606824+(b*112|0);e=0;return e|0}function amX(){var b=0,d=0,e=0,f=0,g=0,h=0;a[7462160]=1;a[64288]=1;a[7462144]=1;a[7462008]=1;c[2426966]=568;c[3542064]=3904;c[3542066]=4732;c[3541954]=14344;c[2113296]=12e6;b=aia()|0;d=0;while(1){if((d|0)>=1024){e=0;break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==0){g=5301;break}else{d=d+1|0}}do{if((g|0)==5301){d=gGq(16384)|0;c[f>>2]=d;if((d|0)==0){e=0;break}gGz(d|0,0,16384);e=d}}while(0);c[3542036]=e;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060]}f=c[2112932]|0;c[f+39168>>2]=e;c[f+104704>>2]=e;c[f+170240>>2]=e;g=e+1024|0;c[f+39172>>2]=g;c[f+104708>>2]=g;c[f+170244>>2]=g;g=e+2048|0;c[f+39176>>2]=g;c[f+104712>>2]=g;c[f+170248>>2]=g;g=e+3072|0;c[f+39180>>2]=g;c[f+104716>>2]=g;c[f+170252>>2]=g;g=e+4096|0;c[f+39184>>2]=g;c[f+104720>>2]=g;c[f+170256>>2]=g;g=e+5120|0;c[f+39188>>2]=g;c[f+104724>>2]=g;c[f+170260>>2]=g;g=e+6144|0;c[f+39192>>2]=g;c[f+104728>>2]=g;c[f+170264>>2]=g;g=e+7168|0;c[f+39196>>2]=g;c[f+104732>>2]=g;c[f+170268>>2]=g;g=e+8192|0;c[f+39200>>2]=g;c[f+104736>>2]=g;c[f+170272>>2]=g;g=e+9216|0;c[f+39204>>2]=g;c[f+104740>>2]=g;c[f+170276>>2]=g;g=e+10240|0;c[f+39208>>2]=g;c[f+104744>>2]=g;c[f+170280>>2]=g;g=e+11264|0;c[f+39212>>2]=g;c[f+104748>>2]=g;c[f+170284>>2]=g;g=e+12288|0;c[f+39216>>2]=g;c[f+104752>>2]=g;c[f+170288>>2]=g;g=e+13312|0;c[f+39220>>2]=g;c[f+104756>>2]=g;c[f+170292>>2]=g;g=e+14336|0;c[f+39224>>2]=g;c[f+104760>>2]=g;c[f+170296>>2]=g;g=e+15360|0;c[f+39228>>2]=g;c[f+104764>>2]=g;c[f+170300>>2]=g;c[f+61824>>2]=1;c[f+61828>>2]=1;c[f+61832>>2]=1;c[f+61836>>2]=1;c[f+61840>>2]=1;c[f+61844>>2]=1;c[f+61848>>2]=1;c[f+61852>>2]=1;c[f+196612>>2]=1956;c[f+104448>>2]=2;c[f+104452>>2]=2;c[f+104456>>2]=2;c[f+104460>>2]=2;c[f+196736>>2]=2130;g=f+65280|0;e=16711680;while(1){c[g+65536>>2]=3;d=e+1024|0;if(d>>>0>16777215){break}else{g=g+4|0;e=d}}c[f+196660>>2]=3288;c[f+196740>>2]=1002;f=c[3532592]|0;if((f|0)==0){h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return b|0}gGC(f|0,9104152,280)|0;h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return b|0}function amY(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>5){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3606252+(b*112|0)>>2];c[a+104>>2]=c[3606256+(b*112|0)>>2];c[a+108>>2]=c[3606260+(b*112|0)>>2];d=0;return d|0}function amZ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<6&(d|0)==0)){e=1;return e|0}c[a>>2]=3606152+(b*112|0);e=0;return e|0}function am_(){var b=0,d=0,e=0,f=0,g=0,h=0;a[7462160]=1;a[64288]=1;a[7462144]=1;a[7462008]=1;c[2426966]=1846;c[3542064]=3904;c[3542066]=4732;c[3541954]=14344;c[2113296]=12e6;b=aia()|0;d=0;while(1){if((d|0)>=1024){e=0;break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==0){g=5329;break}else{d=d+1|0}}do{if((g|0)==5329){d=gGq(16384)|0;c[f>>2]=d;if((d|0)==0){e=0;break}gGz(d|0,0,16384);e=d}}while(0);c[3542036]=e;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060]}f=c[2112932]|0;c[f+39168>>2]=e;c[f+104704>>2]=e;c[f+170240>>2]=e;g=e+1024|0;c[f+39172>>2]=g;c[f+104708>>2]=g;c[f+170244>>2]=g;g=e+2048|0;c[f+39176>>2]=g;c[f+104712>>2]=g;c[f+170248>>2]=g;g=e+3072|0;c[f+39180>>2]=g;c[f+104716>>2]=g;c[f+170252>>2]=g;g=e+4096|0;c[f+39184>>2]=g;c[f+104720>>2]=g;c[f+170256>>2]=g;g=e+5120|0;c[f+39188>>2]=g;c[f+104724>>2]=g;c[f+170260>>2]=g;g=e+6144|0;c[f+39192>>2]=g;c[f+104728>>2]=g;c[f+170264>>2]=g;g=e+7168|0;c[f+39196>>2]=g;c[f+104732>>2]=g;c[f+170268>>2]=g;g=e+8192|0;c[f+39200>>2]=g;c[f+104736>>2]=g;c[f+170272>>2]=g;g=e+9216|0;c[f+39204>>2]=g;c[f+104740>>2]=g;c[f+170276>>2]=g;g=e+10240|0;c[f+39208>>2]=g;c[f+104744>>2]=g;c[f+170280>>2]=g;g=e+11264|0;c[f+39212>>2]=g;c[f+104748>>2]=g;c[f+170284>>2]=g;g=e+12288|0;c[f+39216>>2]=g;c[f+104752>>2]=g;c[f+170288>>2]=g;g=e+13312|0;c[f+39220>>2]=g;c[f+104756>>2]=g;c[f+170292>>2]=g;g=e+14336|0;c[f+39224>>2]=g;c[f+104760>>2]=g;c[f+170296>>2]=g;g=e+15360|0;c[f+39228>>2]=g;c[f+104764>>2]=g;c[f+170300>>2]=g;c[f+61824>>2]=1;c[f+61828>>2]=1;c[f+61832>>2]=1;c[f+61836>>2]=1;c[f+61840>>2]=1;c[f+61844>>2]=1;c[f+61848>>2]=1;c[f+61852>>2]=1;c[f+196612>>2]=1956;c[f+104448>>2]=2;c[f+104452>>2]=2;c[f+104456>>2]=2;c[f+104460>>2]=2;c[f+196736>>2]=2130;g=f+65280|0;e=16711680;while(1){c[g+65536>>2]=3;d=e+1024|0;if(d>>>0>16777215){break}else{g=g+4|0;e=d}}c[f+196660>>2]=3288;c[f+196740>>2]=1002;f=c[3532592]|0;if((f|0)==0){h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return b|0}gGC(f|0,9104152,280)|0;h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return b|0}function am$(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1211204+(b*112|0)>>2];c[a+104>>2]=c[1211208+(b*112|0)>>2];c[a+108>>2]=c[1211212+(b*112|0)>>2];d=0;return d|0}function am0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=1211104+(b*112|0);e=0;return e|0}function am1(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=808808+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function am2(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>44){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1212784+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function am3(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7384668+(b*112|0)>>2];c[a+104>>2]=c[7384672+(b*112|0)>>2];c[a+108>>2]=c[7384676+(b*112|0)>>2];d=0;return d|0}function am4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=7384568+(b*112|0);e=0;return e|0}function am5(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1288392+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function am6(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>49){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7387144+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function am7(){a[7462168]=1;c[2113296]=12e6;return aia()|0}function am8(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6812716+(b*112|0)>>2];c[a+104>>2]=c[6812720+(b*112|0)>>2];c[a+108>>2]=c[6812724+(b*112|0)>>2];d=0;return d|0}function am9(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=6812616+(b*112|0);e=0;return e|0}function ana(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>42){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6814744+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function anb(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>27){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5130028+(b*112|0)>>2];c[a+104>>2]=c[5130032+(b*112|0)>>2];c[a+108>>2]=c[5130036+(b*112|0)>>2];d=0;return d|0}function anc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<28&(d|0)==0)){e=1;return e|0}c[a>>2]=5129928+(b*112|0);e=0;return e|0}function and(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1288392+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function ane(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>50){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5133064+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function anf(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>30){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7374348+(b*112|0)>>2];c[a+104>>2]=c[7374352+(b*112|0)>>2];c[a+108>>2]=c[7374356+(b*112|0)>>2];d=0;return d|0}function ang(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<31&(d|0)==0)){e=1;return e|0}c[a>>2]=7374248+(b*112|0);e=0;return e|0}function anh(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>29){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6806216+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function ani(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>50){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7377720+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function anj(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>30){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6797580+(b*112|0)>>2];c[a+104>>2]=c[6797584+(b*112|0)>>2];c[a+108>>2]=c[6797588+(b*112|0)>>2];d=0;return d|0}function ank(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<31&(d|0)==0)){e=1;return e|0}c[a>>2]=6797480+(b*112|0);e=0;return e|0}function anl(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>30){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6794108+(b*112|0)>>2];c[a+104>>2]=c[6794112+(b*112|0)>>2];c[a+108>>2]=c[6794116+(b*112|0)>>2];d=0;return d|0}function anm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<31&(d|0)==0)){e=1;return e|0}c[a>>2]=6794008+(b*112|0);e=0;return e|0}function ann(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>29){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5031616+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function ano(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>23){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5041212+(b*112|0)>>2];c[a+104>>2]=c[5041216+(b*112|0)>>2];c[a+108>>2]=c[5041220+(b*112|0)>>2];d=0;return d|0}function anp(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<24&(d|0)==0)){e=1;return e|0}c[a>>2]=5041112+(b*112|0);e=0;return e|0}function anq(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>29){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3479232+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function anr(){var b=0;b=aia()|0;a[7462152]=1;c[3541966]=-12;a[7461984]=1;c[3541964]=-14;a[7461976]=1;c[3541962]=-16;a[7461968]=1;a[7461992]=1;return b|0}function ans(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6105788+(b*112|0)>>2];c[a+104>>2]=c[6105792+(b*112|0)>>2];c[a+108>>2]=c[6105796+(b*112|0)>>2];d=0;return d|0}function ant(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=6105688+(b*112|0);e=0;return e|0}function anu(){var b=0;c[2426966]=2286;b=aia()|0;a[7462152]=1;c[3541966]=-12;a[7461984]=1;c[3541964]=-14;a[7461976]=1;c[3541962]=-16;a[7461968]=1;a[7461992]=1;return b|0}function anv(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>30){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6768124+(b*112|0)>>2];c[a+104>>2]=c[6768128+(b*112|0)>>2];c[a+108>>2]=c[6768132+(b*112|0)>>2];d=0;return d|0}function anw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<31&(d|0)==0)){e=1;return e|0}c[a>>2]=6768024+(b*112|0);e=0;return e|0}function anx(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>30){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6764652+(b*112|0)>>2];c[a+104>>2]=c[6764656+(b*112|0)>>2];c[a+108>>2]=c[6764660+(b*112|0)>>2];d=0;return d|0}function any(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<31&(d|0)==0)){e=1;return e|0}c[a>>2]=6764552+(b*112|0);e=0;return e|0}function anz(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>30){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6761180+(b*112|0)>>2];c[a+104>>2]=c[6761184+(b*112|0)>>2];c[a+108>>2]=c[6761188+(b*112|0)>>2];d=0;return d|0}function anA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<31&(d|0)==0)){e=1;return e|0}c[a>>2]=6761080+(b*112|0);e=0;return e|0}function anB(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>30){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6757708+(b*112|0)>>2];c[a+104>>2]=c[6757712+(b*112|0)>>2];c[a+108>>2]=c[6757716+(b*112|0)>>2];d=0;return d|0}function anC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<31&(d|0)==0)){e=1;return e|0}c[a>>2]=6757608+(b*112|0);e=0;return e|0}function anD(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>30){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6754236+(b*112|0)>>2];c[a+104>>2]=c[6754240+(b*112|0)>>2];c[a+108>>2]=c[6754244+(b*112|0)>>2];d=0;return d|0}function anE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<31&(d|0)==0)){e=1;return e|0}c[a>>2]=6754136+(b*112|0);e=0;return e|0}function anF(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>30){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6750764+(b*112|0)>>2];c[a+104>>2]=c[6750768+(b*112|0)>>2];c[a+108>>2]=c[6750772+(b*112|0)>>2];d=0;return d|0}function anG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<31&(d|0)==0)){e=1;return e|0}c[a>>2]=6750664+(b*112|0);e=0;return e|0}function anH(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>30){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6747292+(b*112|0)>>2];c[a+104>>2]=c[6747296+(b*112|0)>>2];c[a+108>>2]=c[6747300+(b*112|0)>>2];d=0;return d|0}function anI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<31&(d|0)==0)){e=1;return e|0}c[a>>2]=6747192+(b*112|0);e=0;return e|0}function anJ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>30){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6743820+(b*112|0)>>2];c[a+104>>2]=c[6743824+(b*112|0)>>2];c[a+108>>2]=c[6743828+(b*112|0)>>2];d=0;return d|0}function anK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<31&(d|0)==0)){e=1;return e|0}c[a>>2]=6743720+(b*112|0);e=0;return e|0}function anL(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>30){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6740348+(b*112|0)>>2];c[a+104>>2]=c[6740352+(b*112|0)>>2];c[a+108>>2]=c[6740356+(b*112|0)>>2];d=0;return d|0}function anM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<31&(d|0)==0)){e=1;return e|0}c[a>>2]=6740248+(b*112|0);e=0;return e|0}function anN(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>30){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7141172+(b*112|0)>>2];c[a+104>>2]=c[7141176+(b*112|0)>>2];c[a+108>>2]=c[7141180+(b*112|0)>>2];d=0;return d|0}function anO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<31&(d|0)==0)){e=1;return e|0}c[a>>2]=7141072+(b*112|0);e=0;return e|0}function anP(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>53){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7144544+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function anQ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>30){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6787500+(b*112|0)>>2];c[a+104>>2]=c[6787504+(b*112|0)>>2];c[a+108>>2]=c[6787508+(b*112|0)>>2];d=0;return d|0}function anR(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<31&(d|0)==0)){e=1;return e|0}c[a>>2]=6787400+(b*112|0);e=0;return e|0}function anS(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>30){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6784028+(b*112|0)>>2];c[a+104>>2]=c[6784032+(b*112|0)>>2];c[a+108>>2]=c[6784036+(b*112|0)>>2];d=0;return d|0}function anT(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<31&(d|0)==0)){e=1;return e|0}c[a>>2]=6783928+(b*112|0);e=0;return e|0}function anU(){a[7462168]=1;return aia()|0}function anV(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>30){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6780556+(b*112|0)>>2];c[a+104>>2]=c[6780560+(b*112|0)>>2];c[a+108>>2]=c[6780564+(b*112|0)>>2];d=0;return d|0}function anW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<31&(d|0)==0)){e=1;return e|0}c[a>>2]=6780456+(b*112|0);e=0;return e|0}function anX(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>30){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6777084+(b*112|0)>>2];c[a+104>>2]=c[6777088+(b*112|0)>>2];c[a+108>>2]=c[6777092+(b*112|0)>>2];d=0;return d|0}function anY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<31&(d|0)==0)){e=1;return e|0}c[a>>2]=6776984+(b*112|0);e=0;return e|0}function anZ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>30){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6773612+(b*112|0)>>2];c[a+104>>2]=c[6773616+(b*112|0)>>2];c[a+108>>2]=c[6773620+(b*112|0)>>2];d=0;return d|0}function an_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<31&(d|0)==0)){e=1;return e|0}c[a>>2]=6773512+(b*112|0);e=0;return e|0}function an$(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6120684+(b*112|0)>>2];c[a+104>>2]=c[6120688+(b*112|0)>>2];c[a+108>>2]=c[6120692+(b*112|0)>>2];d=0;return d|0}function an0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<22&(d|0)==0)){e=1;return e|0}c[a>>2]=6120584+(b*112|0);e=0;return e|0}function an1(){c[2429532]=288;return aia()|0}function an2(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>27){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3492132+(b*112|0)>>2];c[a+104>>2]=c[3492136+(b*112|0)>>2];c[a+108>>2]=c[3492140+(b*112|0)>>2];d=0;return d|0}function an3(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<28&(d|0)==0)){e=1;return e|0}c[a>>2]=3492032+(b*112|0);e=0;return e|0}function an4(){a[7461672]=1;return aia()|0}function an5(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>28){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7145292+(b*112|0)>>2];c[a+104>>2]=c[7145296+(b*112|0)>>2];c[a+108>>2]=c[7145300+(b*112|0)>>2];d=0;return d|0}function an6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<29&(d|0)==0)){e=1;return e|0}c[a>>2]=7145192+(b*112|0);e=0;return e|0}function an7(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6804188+(b*112|0)>>2];c[a+104>>2]=c[6804192+(b*112|0)>>2];c[a+108>>2]=c[6804196+(b*112|0)>>2];d=0;return d|0}function an8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=6804088+(b*112|0);e=0;return e|0}function an9(){c[2426966]=2286;return aia()|0}function aoa(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>27){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6801052+(b*112|0)>>2];c[a+104>>2]=c[6801056+(b*112|0)>>2];c[a+108>>2]=c[6801060+(b*112|0)>>2];d=0;return d|0}function aob(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<28&(d|0)==0)){e=1;return e|0}c[a>>2]=6800952+(b*112|0);e=0;return e|0}function aoc(){c[2113296]=7e6;return aia()|0}function aod(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>27){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5062716+(b*112|0)>>2];c[a+104>>2]=c[5062720+(b*112|0)>>2];c[a+108>>2]=c[5062724+(b*112|0)>>2];d=0;return d|0}function aoe(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<28&(d|0)==0)){e=1;return e|0}c[a>>2]=5062616+(b*112|0);e=0;return e|0}function aof(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>27){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5059580+(b*112|0)>>2];c[a+104>>2]=c[5059584+(b*112|0)>>2];c[a+108>>2]=c[5059588+(b*112|0)>>2];d=0;return d|0}function aog(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<28&(d|0)==0)){e=1;return e|0}c[a>>2]=5059480+(b*112|0);e=0;return e|0}function aoh(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>27){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5056444+(b*112|0)>>2];c[a+104>>2]=c[5056448+(b*112|0)>>2];c[a+108>>2]=c[5056452+(b*112|0)>>2];d=0;return d|0}function aoi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<28&(d|0)==0)){e=1;return e|0}c[a>>2]=5056344+(b*112|0);e=0;return e|0}function aoj(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>27){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5053308+(b*112|0)>>2];c[a+104>>2]=c[5053312+(b*112|0)>>2];c[a+108>>2]=c[5053316+(b*112|0)>>2];d=0;return d|0}function aok(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<28&(d|0)==0)){e=1;return e|0}c[a>>2]=5053208+(b*112|0);e=0;return e|0}function aol(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>27){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5050172+(b*112|0)>>2];c[a+104>>2]=c[5050176+(b*112|0)>>2];c[a+108>>2]=c[5050180+(b*112|0)>>2];d=0;return d|0}function aom(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<28&(d|0)==0)){e=1;return e|0}c[a>>2]=5050072+(b*112|0);e=0;return e|0}function aon(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>27){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5047036+(b*112|0)>>2];c[a+104>>2]=c[5047040+(b*112|0)>>2];c[a+108>>2]=c[5047044+(b*112|0)>>2];d=0;return d|0}function aoo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<28&(d|0)==0)){e=1;return e|0}c[a>>2]=5046936+(b*112|0);e=0;return e|0}function aop(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>27){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5043900+(b*112|0)>>2];c[a+104>>2]=c[5043904+(b*112|0)>>2];c[a+108>>2]=c[5043908+(b*112|0)>>2];d=0;return d|0}function aoq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<28&(d|0)==0)){e=1;return e|0}c[a>>2]=5043800+(b*112|0);e=0;return e|0}function aor(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6137772+(b*112|0)>>2];c[a+104>>2]=c[6137776+(b*112|0)>>2];c[a+108>>2]=c[6137780+(b*112|0)>>2];d=0;return d|0}function aos(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=6137672+(b*112|0);e=0;return e|0}function aot(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5080860+(b*112|0)>>2];c[a+104>>2]=c[5080864+(b*112|0)>>2];c[a+108>>2]=c[5080868+(b*112|0)>>2];d=0;return d|0}function aou(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=5080760+(b*112|0);e=0;return e|0}function aov(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3505460+(b*112|0)>>2];c[a+104>>2]=c[3505464+(b*112|0)>>2];c[a+108>>2]=c[3505468+(b*112|0)>>2];d=0;return d|0}function aow(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=3505360+(b*112|0);e=0;return e|0}function aox(){c[2429532]=4742;c[2113296]=7e6;return aia()|0}function aoy(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3503444+(b*112|0)>>2];c[a+104>>2]=c[3503448+(b*112|0)>>2];c[a+108>>2]=c[3503452+(b*112|0)>>2];d=0;return d|0}function aoz(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=3503344+(b*112|0);e=0;return e|0}function aoA(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0;c[2113296]=7e6;a=aia()|0;if((c[2394]|0)==0){b=c[2112932]|0}else{c[2394]=0;d=c[3532596]|0;c[2112932]=d;e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060];b=d}d=c[3541922]|0;e=b+10240|0;f=2621440;while(1){g=d+(f-2621440)|0;c[e>>2]=g;c[e+131072>>2]=g;g=f+1024|0;if(g>>>0>3145727){break}else{e=e+4|0;f=g}}f=b+8192|0;b=2097152;while(1){e=d+(b-1572864)|0;c[f>>2]=e;c[f+131072>>2]=e;e=b+1024|0;if(e>>>0>2621439){break}else{f=f+4|0;b=e}}b=c[3532592]|0;if((b|0)==0){h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return a|0}gGC(b|0,9104152,280)|0;h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return a|0}function aoB(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6771596+(b*112|0)>>2];c[a+104>>2]=c[6771600+(b*112|0)>>2];c[a+108>>2]=c[6771604+(b*112|0)>>2];d=0;return d|0}function aoC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=6771496+(b*112|0);e=0;return e|0}function aoD(){var a=0,b=0,d=0,e=0,f=0,g=0;c[2429532]=8564;c[2113296]=7e6;a=aia()|0;if((c[2394]|0)==0){b=c[2112932]|0}else{c[2394]=0;d=c[3532596]|0;c[2112932]=d;e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060];b=d}d=b+8192|0;e=2097152;while(1){c[d>>2]=1;f=e+1024|0;if(f>>>0>3145727){break}else{d=d+4|0;e=f}}c[b+196612>>2]=1392;c[b+196692>>2]=1996;b=c[3532592]|0;if((b|0)==0){g=c[2113054]|0;c[2113060]=g;c[2394]=-1;return a|0}gGC(b|0,9104152,280)|0;g=c[2113054]|0;c[2113060]=g;c[2394]=-1;return a|0}function aoE(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>23){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6117996+(b*112|0)>>2];c[a+104>>2]=c[6118e3+(b*112|0)>>2];c[a+108>>2]=c[6118004+(b*112|0)>>2];d=0;return d|0}function aoF(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<24&(d|0)==0)){e=1;return e|0}c[a>>2]=6117896+(b*112|0);e=0;return e|0}function aoG(){var a=0,b=0,d=0,e=0,f=0,g=0;c[2113296]=7e6;a=aia()|0;if((c[2394]|0)==0){b=c[2112932]|0}else{c[2394]=0;d=c[3532596]|0;c[2112932]=d;e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060];b=d}d=b+8192|0;e=2097152;while(1){c[d>>2]=1;f=e+1024|0;if(f>>>0>3145727){break}else{d=d+4|0;e=f}}c[b+196612>>2]=1708;c[b+196692>>2]=1228;b=c[3532592]|0;if((b|0)==0){g=c[2113054]|0;c[2113060]=g;c[2394]=-1;return a|0}gGC(b|0,9104152,280)|0;g=c[2113054]|0;c[2113060]=g;c[2394]=-1;return a|0}function aoH(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6115980+(b*112|0)>>2];c[a+104>>2]=c[6115984+(b*112|0)>>2];c[a+108>>2]=c[6115988+(b*112|0)>>2];d=0;return d|0}function aoI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=6115880+(b*112|0);e=0;return e|0}function aoJ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6113964+(b*112|0)>>2];c[a+104>>2]=c[6113968+(b*112|0)>>2];c[a+108>>2]=c[6113972+(b*112|0)>>2];d=0;return d|0}function aoK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=6113864+(b*112|0);e=0;return e|0}function aoL(){c[3541966]=-12;c[3541964]=-14;c[3541962]=-16;a[7461992]=1;c[2113296]=7e6;return aia()|0}function aoM(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6111836+(b*112|0)>>2];c[a+104>>2]=c[6111840+(b*112|0)>>2];c[a+108>>2]=c[6111844+(b*112|0)>>2];d=0;return d|0}function aoN(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=6111736+(b*112|0);e=0;return e|0}function aoO(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6109820+(b*112|0)>>2];c[a+104>>2]=c[6109824+(b*112|0)>>2];c[a+108>>2]=c[6109828+(b*112|0)>>2];d=0;return d|0}function aoP(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=6109720+(b*112|0);e=0;return e|0}function aoQ(){c[2429532]=2578;c[2113296]=7e6;return aia()|0}function aoR(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6107804+(b*112|0)>>2];c[a+104>>2]=c[6107808+(b*112|0)>>2];c[a+108>>2]=c[6107812+(b*112|0)>>2];d=0;return d|0}function aoS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=6107704+(b*112|0);e=0;return e|0}function aoT(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5032196+(b*112|0)>>2];c[a+104>>2]=c[5032200+(b*112|0)>>2];c[a+108>>2]=c[5032204+(b*112|0)>>2];d=0;return d|0}function aoU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=5032096+(b*112|0);e=0;return e|0}function aoV(){c[2113250]=262144;a[7462152]=1;c[2429532]=9512;c[3541966]=-12;c[3541964]=-14;c[3541962]=-16;a[7461992]=1;c[2113296]=7e6;return aia()|0}function aoW(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5029700+(b*112|0)>>2];c[a+104>>2]=c[5029704+(b*112|0)>>2];c[a+108>>2]=c[5029708+(b*112|0)>>2];d=0;return d|0}function aoX(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=5029600+(b*112|0);e=0;return e|0}function aoY(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3481828+(b*112|0)>>2];c[a+104>>2]=c[3481832+(b*112|0)>>2];c[a+108>>2]=c[3481836+(b*112|0)>>2];d=0;return d|0}function aoZ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=3481728+(b*112|0);e=0;return e|0}function ao_(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3479812+(b*112|0)>>2];c[a+104>>2]=c[3479816+(b*112|0)>>2];c[a+108>>2]=c[3479820+(b*112|0)>>2];d=0;return d|0}function ao$(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=3479712+(b*112|0);e=0;return e|0}function ao0(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3501428+(b*112|0)>>2];c[a+104>>2]=c[3501432+(b*112|0)>>2];c[a+108>>2]=c[3501436+(b*112|0)>>2];d=0;return d|0}function ao1(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=3501328+(b*112|0);e=0;return e|0}function ao2(){var a=0,b=0,d=0,e=0,f=0,g=0;c[2113296]=7e6;a=aia()|0;if((c[2394]|0)==0){b=c[2112932]|0}else{c[2394]=0;d=c[3532596]|0;c[2112932]=d;e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060];b=d}d=b+6144|0;e=1572864;while(1){c[d>>2]=1;f=e+1024|0;if(f>>>0>2097151){break}else{d=d+4|0;e=f}}c[b+196612>>2]=2496;c[b+196692>>2]=2824;b=c[3532592]|0;if((b|0)==0){g=c[2113054]|0;c[2113060]=g;c[2394]=-1;return a|0}gGC(b|0,9104152,280)|0;g=c[2113054]|0;c[2113060]=g;c[2394]=-1;return a|0}function ao3(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>27){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6131324+(b*112|0)>>2];c[a+104>>2]=c[6131328+(b*112|0)>>2];c[a+108>>2]=c[6131332+(b*112|0)>>2];d=0;return d|0}function ao4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<28&(d|0)==0)){e=1;return e|0}c[a>>2]=6131224+(b*112|0);e=0;return e|0}function ao5(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>53){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6134360+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function ao6(){c[2429532]=288;c[2113296]=7e6;return aia()|0}function ao7(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>27){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6790972+(b*112|0)>>2];c[a+104>>2]=c[6790976+(b*112|0)>>2];c[a+108>>2]=c[6790980+(b*112|0)>>2];d=0;return d|0}function ao8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<28&(d|0)==0)){e=1;return e|0}c[a>>2]=6790872+(b*112|0);e=0;return e|0}function ao9(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>27){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6125052+(b*112|0)>>2];c[a+104>>2]=c[6125056+(b*112|0)>>2];c[a+108>>2]=c[6125060+(b*112|0)>>2];d=0;return d|0}function apa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<28&(d|0)==0)){e=1;return e|0}c[a>>2]=6124952+(b*112|0);e=0;return e|0}function apb(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>27){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6128188+(b*112|0)>>2];c[a+104>>2]=c[6128192+(b*112|0)>>2];c[a+108>>2]=c[6128196+(b*112|0)>>2];d=0;return d|0}function apc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<28&(d|0)==0)){e=1;return e|0}c[a>>2]=6128088+(b*112|0);e=0;return e|0}function apd(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5039084+(b*112|0)>>2];c[a+104>>2]=c[5039088+(b*112|0)>>2];c[a+108>>2]=c[5039092+(b*112|0)>>2];d=0;return d|0}function ape(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=5038984+(b*112|0);e=0;return e|0}function apf(){var b=0,d=0,e=0,f=0,g=0,h=0;c[3541966]=-12;c[3541964]=-14;c[3541962]=-16;a[7461992]=1;c[2113296]=7e6;b=aia()|0;if((c[2394]|0)==0){d=c[2112932]|0;e=c[3532592]|0}else{c[2394]=0;f=c[3532596]|0;c[2112932]=f;g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060];d=f;e=g}c[d+98304>>2]=1;c[d+98308>>2]=1;c[d+98312>>2]=1;c[d+98316>>2]=1;c[d+98320>>2]=1;c[d+98324>>2]=1;c[d+98328>>2]=1;c[d+98332>>2]=1;c[d+98336>>2]=1;c[d+98340>>2]=1;c[d+98344>>2]=1;c[d+98348>>2]=1;c[d+98352>>2]=1;c[d+98356>>2]=1;c[d+98360>>2]=1;c[d+98364>>2]=1;c[d+98368>>2]=1;c[d+98372>>2]=1;c[d+98376>>2]=1;c[d+98380>>2]=1;c[d+98384>>2]=1;c[d+98388>>2]=1;c[d+98392>>2]=1;c[d+98396>>2]=1;c[d+98400>>2]=1;c[d+98404>>2]=1;c[d+98408>>2]=1;c[d+98412>>2]=1;c[d+98416>>2]=1;c[d+98420>>2]=1;c[d+98424>>2]=1;c[d+98428>>2]=1;c[d+196652>>2]=3188;c[d+196732>>2]=222;if((e|0)==0){h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return b|0}gGC(e|0,9104152,280)|0;h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return b|0}function apg(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3499300+(b*112|0)>>2];c[a+104>>2]=c[3499304+(b*112|0)>>2];c[a+108>>2]=c[3499308+(b*112|0)>>2];d=0;return d|0}function aph(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=3499200+(b*112|0);e=0;return e|0}function api(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6103212+(b*112|0)>>2];c[a+104>>2]=c[6103216+(b*112|0)>>2];c[a+108>>2]=c[6103220+(b*112|0)>>2];d=0;return d|0}function apj(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=6103112+(b*112|0);e=0;return e|0}function apk(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5027124+(b*112|0)>>2];c[a+104>>2]=c[5027128+(b*112|0)>>2];c[a+108>>2]=c[5027132+(b*112|0)>>2];d=0;return d|0}function apl(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=5027024+(b*112|0);e=0;return e|0}function apm(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3497844+(b*112|0)>>2];c[a+104>>2]=c[3497848+(b*112|0)>>2];c[a+108>>2]=c[3497852+(b*112|0)>>2];d=0;return d|0}function apn(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=3497744+(b*112|0);e=0;return e|0}function apo(){c[2426966]=3432;a[7462152]=1;c[3541966]=-12;c[3541964]=-14;c[3541962]=-16;a[7461992]=1;c[2113296]=7e6;return aia()|0}function app(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1712212+(b*112|0)>>2];c[a+104>>2]=c[1712216+(b*112|0)>>2];c[a+108>>2]=c[1712220+(b*112|0)>>2];d=0;return d|0}function apq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=1712112+(b*112|0);e=0;return e|0}function apr(){a[7462152]=1;c[3541966]=-12;c[3541964]=-14;c[3541962]=-16;a[7461992]=1;c[2113296]=7e6;return aia()|0}function aps(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1709748+(b*112|0)>>2];c[a+104>>2]=c[1709752+(b*112|0)>>2];c[a+108>>2]=c[1709756+(b*112|0)>>2];d=0;return d|0}function apt(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<22&(d|0)==0)){e=1;return e|0}c[a>>2]=1709648+(b*112|0);e=0;return e|0}function apu(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6135108+(b*112|0)>>2];c[a+104>>2]=c[6135112+(b*112|0)>>2];c[a+108>>2]=c[6135116+(b*112|0)>>2];d=0;return d|0}function apv(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=6135008+(b*112|0);e=0;return e|0}function apw(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>53){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6137024+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function apx(){c[2426966]=3432;a[7462152]=1;c[3541966]=-12;c[3541964]=-14;c[3541962]=-16;a[7461992]=1;c[2113296]=7e6;return aia()|0}function apy(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5078396+(b*112|0)>>2];c[a+104>>2]=c[5078400+(b*112|0)>>2];c[a+108>>2]=c[5078404+(b*112|0)>>2];d=0;return d|0}function apz(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<22&(d|0)==0)){e=1;return e|0}c[a>>2]=5078296+(b*112|0);e=0;return e|0}function apA(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>23){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5075708+(b*112|0)>>2];c[a+104>>2]=c[5075712+(b*112|0)>>2];c[a+108>>2]=c[5075716+(b*112|0)>>2];d=0;return d|0}function apB(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<24&(d|0)==0)){e=1;return e|0}c[a>>2]=5075608+(b*112|0);e=0;return e|0}function apC(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5073580+(b*112|0)>>2];c[a+104>>2]=c[5073584+(b*112|0)>>2];c[a+108>>2]=c[5073588+(b*112|0)>>2];d=0;return d|0}function apD(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=5073480+(b*112|0);e=0;return e|0}function apE(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>23){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5070892+(b*112|0)>>2];c[a+104>>2]=c[5070896+(b*112|0)>>2];c[a+108>>2]=c[5070900+(b*112|0)>>2];d=0;return d|0}function apF(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<24&(d|0)==0)){e=1;return e|0}c[a>>2]=5070792+(b*112|0);e=0;return e|0}function apG(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>27){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5067756+(b*112|0)>>2];c[a+104>>2]=c[5067760+(b*112|0)>>2];c[a+108>>2]=c[5067764+(b*112|0)>>2];d=0;return d|0}function apH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<28&(d|0)==0)){e=1;return e|0}c[a>>2]=5067656+(b*112|0);e=0;return e|0}function apI(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5065852+(b*112|0)>>2];c[a+104>>2]=c[5065856+(b*112|0)>>2];c[a+108>>2]=c[5065860+(b*112|0)>>2];d=0;return d|0}function apJ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=5065752+(b*112|0);e=0;return e|0}function apK(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5034772+(b*112|0)>>2];c[a+104>>2]=c[5034776+(b*112|0)>>2];c[a+108>>2]=c[5034780+(b*112|0)>>2];d=0;return d|0}function apL(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<22&(d|0)==0)){e=1;return e|0}c[a>>2]=5034672+(b*112|0);e=0;return e|0}function apM(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>50){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5037136+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function apN(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3495268+(b*112|0)>>2];c[a+104>>2]=c[3495272+(b*112|0)>>2];c[a+108>>2]=c[3495276+(b*112|0)>>2];d=0;return d|0}function apO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=3495168+(b*112|0);e=0;return e|0}function apP(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6123148+(b*112|0)>>2];c[a+104>>2]=c[6123152+(b*112|0)>>2];c[a+108>>2]=c[6123156+(b*112|0)>>2];d=0;return d|0}function apQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=6123048+(b*112|0);e=0;return e|0}function apR(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;a[64288]=1;a[7462160]=1;c[2426966]=2162;c[3542064]=662;c[3542066]=4732;c[3541914]=3658;c[3541912]=4102;c[3541920]=1072;c[3541916]=2604;c[3541918]=1748;c[3541938]=120;c[3541954]=14494;c[2113296]=7e6;b=aia()|0;d=0;while(1){if((d|0)>=1024){e=0;break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==0){g=6402;break}else{d=d+1|0}}do{if((g|0)==6402){d=gGq(16384)|0;c[f>>2]=d;if((d|0)==0){e=0;break}gGz(d|0,0,16384);e=d}}while(0);c[3542036]=e;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060]}f=c[2112932]|0;c[f+28672>>2]=e;c[f+94208>>2]=e;c[f+159744>>2]=e;g=e+1024|0;c[f+28676>>2]=g;c[f+94212>>2]=g;c[f+159748>>2]=g;d=e+2048|0;c[f+28680>>2]=d;c[f+94216>>2]=d;c[f+159752>>2]=d;h=e+3072|0;c[f+28684>>2]=h;c[f+94220>>2]=h;c[f+159756>>2]=h;i=e+4096|0;c[f+28688>>2]=i;c[f+94224>>2]=i;c[f+159760>>2]=i;j=e+5120|0;c[f+28692>>2]=j;c[f+94228>>2]=j;c[f+159764>>2]=j;k=e+6144|0;c[f+28696>>2]=k;c[f+94232>>2]=k;c[f+159768>>2]=k;l=e+7168|0;c[f+28700>>2]=l;c[f+94236>>2]=l;c[f+159772>>2]=l;m=e+8192|0;c[f+28704>>2]=m;c[f+94240>>2]=m;c[f+159776>>2]=m;n=e+9216|0;c[f+28708>>2]=n;c[f+94244>>2]=n;c[f+159780>>2]=n;o=e+10240|0;c[f+28712>>2]=o;c[f+94248>>2]=o;c[f+159784>>2]=o;p=e+11264|0;c[f+28716>>2]=p;c[f+94252>>2]=p;c[f+159788>>2]=p;q=e+12288|0;c[f+28720>>2]=q;c[f+94256>>2]=q;c[f+159792>>2]=q;r=e+13312|0;c[f+28724>>2]=r;c[f+94260>>2]=r;c[f+159796>>2]=r;s=e+14336|0;c[f+28728>>2]=s;c[f+94264>>2]=s;c[f+159800>>2]=s;t=e+15360|0;c[f+28732>>2]=t;c[f+94268>>2]=t;c[f+159804>>2]=t;c[f+28736>>2]=e;c[f+94272>>2]=e;c[f+159808>>2]=e;c[f+28740>>2]=g;c[f+94276>>2]=g;c[f+159812>>2]=g;c[f+28744>>2]=d;c[f+94280>>2]=d;c[f+159816>>2]=d;c[f+28748>>2]=h;c[f+94284>>2]=h;c[f+159820>>2]=h;c[f+28752>>2]=i;c[f+94288>>2]=i;c[f+159824>>2]=i;c[f+28756>>2]=j;c[f+94292>>2]=j;c[f+159828>>2]=j;c[f+28760>>2]=k;c[f+94296>>2]=k;c[f+159832>>2]=k;c[f+28764>>2]=l;c[f+94300>>2]=l;c[f+159836>>2]=l;c[f+28768>>2]=m;c[f+94304>>2]=m;c[f+159840>>2]=m;c[f+28772>>2]=n;c[f+94308>>2]=n;c[f+159844>>2]=n;c[f+28776>>2]=o;c[f+94312>>2]=o;c[f+159848>>2]=o;c[f+28780>>2]=p;c[f+94316>>2]=p;c[f+159852>>2]=p;c[f+28784>>2]=q;c[f+94320>>2]=q;c[f+159856>>2]=q;c[f+28788>>2]=r;c[f+94324>>2]=r;c[f+159860>>2]=r;c[f+28792>>2]=s;c[f+94328>>2]=s;c[f+159864>>2]=s;c[f+28796>>2]=t;c[f+94332>>2]=t;c[f+159868>>2]=t;t=f+28800|0;s=7372800;while(1){c[t>>2]=1;c[t+65536>>2]=1;r=s+1024|0;if(r>>>0>8388607){break}else{t=t+4|0;s=r}}c[f+196612>>2]=3018;c[f+196692>>2]=248;c[f+196652>>2]=352;c[f+196732>>2]=48;f=c[3532592]|0;if((f|0)==0){u=c[2113054]|0;c[2113060]=u;c[2394]=-1;c[1865530]=4;return b|0}gGC(f|0,9104152,280)|0;u=c[2113054]|0;c[2113060]=u;c[2394]=-1;c[1865530]=4;return b|0}function apS(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5037852+(b*112|0)>>2];c[a+104>>2]=c[5037856+(b*112|0)>>2];c[a+108>>2]=c[5037860+(b*112|0)>>2];d=0;return d|0}function apT(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=5037752+(b*112|0);e=0;return e|0}function apU(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;a[64288]=1;a[7462160]=1;c[3541964]=65472;c[2426966]=786;c[3542064]=662;c[3542066]=4732;c[3541914]=3658;c[3541912]=4102;c[3541920]=1072;c[3541916]=2604;c[3541918]=1748;c[3541938]=120;c[3541954]=14494;c[2113296]=7e6;b=aia()|0;d=0;while(1){if((d|0)>=1024){e=0;break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==0){g=6430;break}else{d=d+1|0}}do{if((g|0)==6430){d=gGq(16384)|0;c[f>>2]=d;if((d|0)==0){e=0;break}gGz(d|0,0,16384);e=d}}while(0);c[3542036]=e;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060]}f=c[2112932]|0;c[f+28672>>2]=e;c[f+94208>>2]=e;c[f+159744>>2]=e;g=e+1024|0;c[f+28676>>2]=g;c[f+94212>>2]=g;c[f+159748>>2]=g;d=e+2048|0;c[f+28680>>2]=d;c[f+94216>>2]=d;c[f+159752>>2]=d;h=e+3072|0;c[f+28684>>2]=h;c[f+94220>>2]=h;c[f+159756>>2]=h;i=e+4096|0;c[f+28688>>2]=i;c[f+94224>>2]=i;c[f+159760>>2]=i;j=e+5120|0;c[f+28692>>2]=j;c[f+94228>>2]=j;c[f+159764>>2]=j;k=e+6144|0;c[f+28696>>2]=k;c[f+94232>>2]=k;c[f+159768>>2]=k;l=e+7168|0;c[f+28700>>2]=l;c[f+94236>>2]=l;c[f+159772>>2]=l;m=e+8192|0;c[f+28704>>2]=m;c[f+94240>>2]=m;c[f+159776>>2]=m;n=e+9216|0;c[f+28708>>2]=n;c[f+94244>>2]=n;c[f+159780>>2]=n;o=e+10240|0;c[f+28712>>2]=o;c[f+94248>>2]=o;c[f+159784>>2]=o;p=e+11264|0;c[f+28716>>2]=p;c[f+94252>>2]=p;c[f+159788>>2]=p;q=e+12288|0;c[f+28720>>2]=q;c[f+94256>>2]=q;c[f+159792>>2]=q;r=e+13312|0;c[f+28724>>2]=r;c[f+94260>>2]=r;c[f+159796>>2]=r;s=e+14336|0;c[f+28728>>2]=s;c[f+94264>>2]=s;c[f+159800>>2]=s;t=e+15360|0;c[f+28732>>2]=t;c[f+94268>>2]=t;c[f+159804>>2]=t;c[f+28736>>2]=e;c[f+94272>>2]=e;c[f+159808>>2]=e;c[f+28740>>2]=g;c[f+94276>>2]=g;c[f+159812>>2]=g;c[f+28744>>2]=d;c[f+94280>>2]=d;c[f+159816>>2]=d;c[f+28748>>2]=h;c[f+94284>>2]=h;c[f+159820>>2]=h;c[f+28752>>2]=i;c[f+94288>>2]=i;c[f+159824>>2]=i;c[f+28756>>2]=j;c[f+94292>>2]=j;c[f+159828>>2]=j;c[f+28760>>2]=k;c[f+94296>>2]=k;c[f+159832>>2]=k;c[f+28764>>2]=l;c[f+94300>>2]=l;c[f+159836>>2]=l;c[f+28768>>2]=m;c[f+94304>>2]=m;c[f+159840>>2]=m;c[f+28772>>2]=n;c[f+94308>>2]=n;c[f+159844>>2]=n;c[f+28776>>2]=o;c[f+94312>>2]=o;c[f+159848>>2]=o;c[f+28780>>2]=p;c[f+94316>>2]=p;c[f+159852>>2]=p;c[f+28784>>2]=q;c[f+94320>>2]=q;c[f+159856>>2]=q;c[f+28788>>2]=r;c[f+94324>>2]=r;c[f+159860>>2]=r;c[f+28792>>2]=s;c[f+94328>>2]=s;c[f+159864>>2]=s;c[f+28796>>2]=t;c[f+94332>>2]=t;c[f+159868>>2]=t;t=c[3541930]|0;s=f+64512|0;r=16515072;while(1){q=t+(r-16515072)|0;c[s>>2]=q;c[s+65536>>2]=q;c[s+131072>>2]=q;q=r+1024|0;if(q>>>0>16580607){break}else{s=s+4|0;r=q}}r=f+28800|0;s=7372800;while(1){c[r>>2]=1;c[r+65536>>2]=1;t=s+1024|0;if(t>>>0>8388607){break}else{r=r+4|0;s=t}}c[f+196612>>2]=3018;c[f+196692>>2]=248;c[f+196652>>2]=352;c[f+196732>>2]=2910;f=c[3532592]|0;if((f|0)==0){u=c[2113054]|0;c[2113060]=u;c[2394]=-1;c[1865530]=4;return b|0}gGC(f|0,9104152,280)|0;u=c[2113054]|0;c[2113060]=u;c[2394]=-1;c[1865530]=4;return b|0}function apV(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>29){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=962072+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function apW(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1736852+(b*112|0)>>2];c[a+104>>2]=c[1736856+(b*112|0)>>2];c[a+108>>2]=c[1736860+(b*112|0)>>2];d=0;return d|0}function apX(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=1736752+(b*112|0);e=0;return e|0}function apY(){var b=0,d=0,e=0,f=0,g=0,h=0;c[2426966]=1710;a[7461712]=1;a[64288]=1;a[7462144]=1;c[3542064]=3904;c[3542066]=4732;c[2113296]=7e6;b=aia()|0;d=0;while(1){if((d|0)>=1024){e=0;break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==0){g=6467;break}else{d=d+1|0}}do{if((g|0)==6467){d=gGq(16384)|0;c[f>>2]=d;if((d|0)==0){e=0;break}gGz(d|0,0,16384);e=d}}while(0);c[3542036]=e;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060]}f=c[2112932]|0;c[f+39168>>2]=e;c[f+104704>>2]=e;c[f+170240>>2]=e;g=e+1024|0;c[f+39172>>2]=g;c[f+104708>>2]=g;c[f+170244>>2]=g;g=e+2048|0;c[f+39176>>2]=g;c[f+104712>>2]=g;c[f+170248>>2]=g;g=e+3072|0;c[f+39180>>2]=g;c[f+104716>>2]=g;c[f+170252>>2]=g;g=e+4096|0;c[f+39184>>2]=g;c[f+104720>>2]=g;c[f+170256>>2]=g;g=e+5120|0;c[f+39188>>2]=g;c[f+104724>>2]=g;c[f+170260>>2]=g;g=e+6144|0;c[f+39192>>2]=g;c[f+104728>>2]=g;c[f+170264>>2]=g;g=e+7168|0;c[f+39196>>2]=g;c[f+104732>>2]=g;c[f+170268>>2]=g;g=e+8192|0;c[f+39200>>2]=g;c[f+104736>>2]=g;c[f+170272>>2]=g;g=e+9216|0;c[f+39204>>2]=g;c[f+104740>>2]=g;c[f+170276>>2]=g;g=e+10240|0;c[f+39208>>2]=g;c[f+104744>>2]=g;c[f+170280>>2]=g;g=e+11264|0;c[f+39212>>2]=g;c[f+104748>>2]=g;c[f+170284>>2]=g;g=e+12288|0;c[f+39216>>2]=g;c[f+104752>>2]=g;c[f+170288>>2]=g;g=e+13312|0;c[f+39220>>2]=g;c[f+104756>>2]=g;c[f+170292>>2]=g;g=e+14336|0;c[f+39224>>2]=g;c[f+104760>>2]=g;c[f+170296>>2]=g;g=e+15360|0;c[f+39228>>2]=g;c[f+104764>>2]=g;c[f+170300>>2]=g;c[f+104448>>2]=1;c[f+104452>>2]=1;c[f+104456>>2]=1;c[f+104460>>2]=1;c[f+196732>>2]=3194;f=c[3532592]|0;if((f|0)==0){h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return b|0}gGC(f|0,9104152,280)|0;h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return b|0}function apZ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1738868+(b*112|0)>>2];c[a+104>>2]=c[1738872+(b*112|0)>>2];c[a+108>>2]=c[1738876+(b*112|0)>>2];d=0;return d|0}function ap_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=1738768+(b*112|0);e=0;return e|0}function ap$(){var b=0,d=0,e=0,f=0,g=0,h=0;a[7461712]=1;a[64288]=1;a[7462144]=1;c[3542064]=3904;c[3542066]=4732;c[2113296]=7e6;b=aia()|0;d=0;while(1){if((d|0)>=1024){e=0;break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==0){g=6493;break}else{d=d+1|0}}do{if((g|0)==6493){d=gGq(16384)|0;c[f>>2]=d;if((d|0)==0){e=0;break}gGz(d|0,0,16384);e=d}}while(0);c[3542036]=e;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060]}f=c[2112932]|0;c[f+39168>>2]=e;c[f+104704>>2]=e;c[f+170240>>2]=e;g=e+1024|0;c[f+39172>>2]=g;c[f+104708>>2]=g;c[f+170244>>2]=g;g=e+2048|0;c[f+39176>>2]=g;c[f+104712>>2]=g;c[f+170248>>2]=g;g=e+3072|0;c[f+39180>>2]=g;c[f+104716>>2]=g;c[f+170252>>2]=g;g=e+4096|0;c[f+39184>>2]=g;c[f+104720>>2]=g;c[f+170256>>2]=g;g=e+5120|0;c[f+39188>>2]=g;c[f+104724>>2]=g;c[f+170260>>2]=g;g=e+6144|0;c[f+39192>>2]=g;c[f+104728>>2]=g;c[f+170264>>2]=g;g=e+7168|0;c[f+39196>>2]=g;c[f+104732>>2]=g;c[f+170268>>2]=g;g=e+8192|0;c[f+39200>>2]=g;c[f+104736>>2]=g;c[f+170272>>2]=g;g=e+9216|0;c[f+39204>>2]=g;c[f+104740>>2]=g;c[f+170276>>2]=g;g=e+10240|0;c[f+39208>>2]=g;c[f+104744>>2]=g;c[f+170280>>2]=g;g=e+11264|0;c[f+39212>>2]=g;c[f+104748>>2]=g;c[f+170284>>2]=g;g=e+12288|0;c[f+39216>>2]=g;c[f+104752>>2]=g;c[f+170288>>2]=g;g=e+13312|0;c[f+39220>>2]=g;c[f+104756>>2]=g;c[f+170292>>2]=g;g=e+14336|0;c[f+39224>>2]=g;c[f+104760>>2]=g;c[f+170296>>2]=g;g=e+15360|0;c[f+39228>>2]=g;c[f+104764>>2]=g;c[f+170300>>2]=g;c[f+104448>>2]=1;c[f+104452>>2]=1;c[f+104456>>2]=1;c[f+104460>>2]=1;c[f+196732>>2]=3194;f=c[3532592]|0;if((f|0)==0){h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return b|0}gGC(f|0,9104152,280)|0;h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return b|0}function ap0(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1732708+(b*112|0)>>2];c[a+104>>2]=c[1732712+(b*112|0)>>2];c[a+108>>2]=c[1732716+(b*112|0)>>2];d=0;return d|0}function ap1(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=1732608+(b*112|0);e=0;return e|0}function ap2(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1734836+(b*112|0)>>2];c[a+104>>2]=c[1734840+(b*112|0)>>2];c[a+108>>2]=c[1734844+(b*112|0)>>2];d=0;return d|0}function ap3(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=1734736+(b*112|0);e=0;return e|0}function ap4(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1718372+(b*112|0)>>2];c[a+104>>2]=c[1718376+(b*112|0)>>2];c[a+108>>2]=c[1718380+(b*112|0)>>2];d=0;return d|0}function ap5(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=1718272+(b*112|0);e=0;return e|0}function ap6(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>29){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=961592+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function ap7(){var b=0,d=0,e=0,f=0,g=0,h=0;c[3541966]=-16;c[3541964]=-16;c[3541962]=-16;a[7461992]=1;c[2113296]=7e6;b=aia()|0;if((c[2394]|0)==0){d=c[2112932]|0;e=c[3532592]|0}else{c[2394]=0;f=c[3532596]|0;c[2112932]=f;g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060];d=f;e=g}c[d+32768>>2]=1;c[d+98304>>2]=1;c[d+163840>>2]=1;c[d+196612>>2]=748;c[d+196652>>2]=3150;c[d+196732>>2]=1200;if((e|0)==0){h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return b|0}gGC(e|0,9104152,280)|0;h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return b|0}function ap8(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1730580+(b*112|0)>>2];c[a+104>>2]=c[1730584+(b*112|0)>>2];c[a+108>>2]=c[1730588+(b*112|0)>>2];d=0;return d|0}function ap9(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=1730480+(b*112|0);e=0;return e|0}function aqa(){var b=0,d=0,e=0,f=0,g=0,h=0;a[7461688]=1;a[7461680]=1;c[3541966]=-16;c[3541964]=-16;c[3541962]=-16;a[7461992]=1;c[2113296]=7e6;b=aia()|0;if((c[2394]|0)==0){d=c[2112932]|0;e=c[3532592]|0}else{c[2394]=0;f=c[3532596]|0;c[2112932]=f;g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060];d=f;e=g}c[d+32768>>2]=1;c[d+98304>>2]=1;c[d+163840>>2]=1;c[d+196612>>2]=748;c[d+196652>>2]=3150;c[d+196732>>2]=1200;if((e|0)==0){h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return b|0}gGC(e|0,9104152,280)|0;h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return b|0}function aqb(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1728676+(b*112|0)>>2];c[a+104>>2]=c[1728680+(b*112|0)>>2];c[a+108>>2]=c[1728684+(b*112|0)>>2];d=0;return d|0}function aqc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=1728576+(b*112|0);e=0;return e|0}function aqd(){var b=0,d=0,e=0,f=0,g=0,h=0;c[2426966]=3386;c[3541966]=-16;c[3541964]=-16;c[3541962]=-16;a[7461992]=1;c[2113296]=7e6;b=aia()|0;if((c[2394]|0)==0){d=c[2112932]|0;e=c[3532592]|0}else{c[2394]=0;f=c[3532596]|0;c[2112932]=f;g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060];d=f;e=g}c[d+32768>>2]=1;c[d+98304>>2]=1;c[d+163840>>2]=1;c[d+196612>>2]=748;c[d+196652>>2]=3150;c[d+196732>>2]=1200;if((e|0)==0){h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return b|0}gGC(e|0,9104152,280)|0;h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return b|0}function aqe(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1727220+(b*112|0)>>2];c[a+104>>2]=c[1727224+(b*112|0)>>2];c[a+108>>2]=c[1727228+(b*112|0)>>2];d=0;return d|0}function aqf(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=1727120+(b*112|0);e=0;return e|0}function aqg(){var b=0,d=0,e=0,f=0,g=0,h=0;c[2426966]=3432;c[3541966]=-16;c[3541964]=-16;c[3541962]=-16;a[7461992]=1;c[2113296]=7e6;b=aia()|0;if((c[2394]|0)==0){d=c[2112932]|0;e=c[3532592]|0}else{c[2394]=0;f=c[3532596]|0;c[2112932]=f;g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060];d=f;e=g}c[d+32768>>2]=1;c[d+98304>>2]=1;c[d+163840>>2]=1;c[d+196612>>2]=748;c[d+196652>>2]=3150;c[d+196732>>2]=1200;if((e|0)==0){h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return b|0}gGC(e|0,9104152,280)|0;h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return b|0}function aqh(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>34){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1723300+(b*112|0)>>2];c[a+104>>2]=c[1723304+(b*112|0)>>2];c[a+108>>2]=c[1723308+(b*112|0)>>2];d=0;return d|0}function aqi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<35&(d|0)==0)){e=1;return e|0}c[a>>2]=1723200+(b*112|0);e=0;return e|0}function aqj(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>25){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1720388+(b*112|0)>>2];c[a+104>>2]=c[1720392+(b*112|0)>>2];c[a+108>>2]=c[1720396+(b*112|0)>>2];d=0;return d|0}function aqk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<26&(d|0)==0)){e=1;return e|0}c[a>>2]=1720288+(b*112|0);e=0;return e|0}function aql(){c[2429532]=2816;c[2426966]=1710;c[2113296]=7e6;return aia()|0}function aqm(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>35){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1714340+(b*112|0)>>2];c[a+104>>2]=c[1714344+(b*112|0)>>2];c[a+108>>2]=c[1714348+(b*112|0)>>2];d=0;return d|0}function aqn(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<36&(d|0)==0)){e=1;return e|0}c[a>>2]=1714240+(b*112|0);e=0;return e|0}function aqo(){c[2429532]=12720;c[2113296]=7e6;return aia()|0}function aqp(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3489556+(b*112|0)>>2];c[a+104>>2]=c[3489560+(b*112|0)>>2];c[a+108>>2]=c[3489564+(b*112|0)>>2];d=0;return d|0}function aqq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=3489456+(b*112|0);e=0;return e|0}function aqr(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3486980+(b*112|0)>>2];c[a+104>>2]=c[3486984+(b*112|0)>>2];c[a+108>>2]=c[3486988+(b*112|0)>>2];d=0;return d|0}function aqs(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=3486880+(b*112|0);e=0;return e|0}function aqt(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3484404+(b*112|0)>>2];c[a+104>>2]=c[3484408+(b*112|0)>>2];c[a+108>>2]=c[3484412+(b*112|0)>>2];d=0;return d|0}function aqu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=3484304+(b*112|0);e=0;return e|0}function aqv(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6708764+(b*112|0)>>2];c[a+104>>2]=c[6708768+(b*112|0)>>2];c[a+108>>2]=c[6708772+(b*112|0)>>2];d=0;return d|0}function aqw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=6708664+(b*112|0);e=0;return e|0}function aqx(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>24){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5001312+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aqy(){var a=0;c[2113296]=12e6;a=aia()|0;c[3542068]=3;return a|0}function aqz(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>39){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3429532+(b*112|0)>>2];c[a+104>>2]=c[3429536+(b*112|0)>>2];c[a+108>>2]=c[3429540+(b*112|0)>>2];d=0;return d|0}function aqA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<40&(d|0)==0)){e=1;return e|0}c[a>>2]=3429432+(b*112|0);e=0;return e|0}function aqB(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>39){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1192792+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aqC(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>3){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3433912+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aqD(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>39){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1690708+(b*112|0)>>2];c[a+104>>2]=c[1690712+(b*112|0)>>2];c[a+108>>2]=c[1690716+(b*112|0)>>2];d=0;return d|0}function aqE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<40&(d|0)==0)){e=1;return e|0}c[a>>2]=1690608+(b*112|0);e=0;return e|0}function aqF(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>36){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3760780+(b*112|0)>>2];c[a+104>>2]=c[3760784+(b*112|0)>>2];c[a+108>>2]=c[3760788+(b*112|0)>>2];d=0;return d|0}function aqG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<37&(d|0)==0)){e=1;return e|0}c[a>>2]=3760680+(b*112|0);e=0;return e|0}function aqH(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>42){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5288276+(b*112|0)>>2];c[a+104>>2]=c[5288280+(b*112|0)>>2];c[a+108>>2]=c[5288284+(b*112|0)>>2];d=0;return d|0}function aqI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<43&(d|0)==0)){e=1;return e|0}c[a>>2]=5288176+(b*112|0);e=0;return e|0}function aqJ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>42){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3755964+(b*112|0)>>2];c[a+104>>2]=c[3755968+(b*112|0)>>2];c[a+108>>2]=c[3755972+(b*112|0)>>2];d=0;return d|0}function aqK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<43&(d|0)==0)){e=1;return e|0}c[a>>2]=3755864+(b*112|0);e=0;return e|0}function aqL(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4981332+(b*112|0)>>2];c[a+104>>2]=c[4981336+(b*112|0)>>2];c[a+108>>2]=c[4981340+(b*112|0)>>2];d=0;return d|0}function aqM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=4981232+(b*112|0);e=0;return e|0}function aqN(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a[7462160]=1;a[7462008]=1;a[64288]=1;c[2426966]=1838;c[3542064]=662;c[3542066]=4732;c[3541954]=10646;c[2113296]=12e6;b=aia()|0;d=c[3541874]|0;e=32767;while(1){f=e<<1;a[d+f|0]=a[d+e|0]|0;a[d+(f|1)|0]=-1;if((e|0)>0){e=e-1|0}else{g=0;break}}while(1){if((g|0)>=1024){h=0;break}i=9638528+(g<<2)|0;if((c[i>>2]|0)==0){j=6807;break}else{g=g+1|0}}do{if((j|0)==6807){g=gGq(16384)|0;c[i>>2]=g;if((g|0)==0){h=0;break}gGz(g|0,0,16384);h=g}}while(0);c[3542036]=h;if((c[2394]|0)==0){k=c[2112932]|0}else{c[2394]=0;i=c[3532596]|0;c[2112932]=i;j=c[3532592]|0;if((j|0)!=0){gGC(9104152,j|0,280)|0}c[2113054]=c[2113060];k=i}i=c[3541874]|0;j=k+61440|0;g=15728640;while(1){e=i+(g-15728640)|0;c[j>>2]=e;c[j+131072>>2]=e;e=g+1024|0;if(e>>>0>15794175){break}else{j=j+4|0;g=e}}c[k+39168>>2]=h;c[k+104704>>2]=h;c[k+170240>>2]=h;g=h+1024|0;c[k+39172>>2]=g;c[k+104708>>2]=g;c[k+170244>>2]=g;g=h+2048|0;c[k+39176>>2]=g;c[k+104712>>2]=g;c[k+170248>>2]=g;g=h+3072|0;c[k+39180>>2]=g;c[k+104716>>2]=g;c[k+170252>>2]=g;g=h+4096|0;c[k+39184>>2]=g;c[k+104720>>2]=g;c[k+170256>>2]=g;g=h+5120|0;c[k+39188>>2]=g;c[k+104724>>2]=g;c[k+170260>>2]=g;g=h+6144|0;c[k+39192>>2]=g;c[k+104728>>2]=g;c[k+170264>>2]=g;g=h+7168|0;c[k+39196>>2]=g;c[k+104732>>2]=g;c[k+170268>>2]=g;g=h+8192|0;c[k+39200>>2]=g;c[k+104736>>2]=g;c[k+170272>>2]=g;g=h+9216|0;c[k+39204>>2]=g;c[k+104740>>2]=g;c[k+170276>>2]=g;g=h+10240|0;c[k+39208>>2]=g;c[k+104744>>2]=g;c[k+170280>>2]=g;g=h+11264|0;c[k+39212>>2]=g;c[k+104748>>2]=g;c[k+170284>>2]=g;g=h+12288|0;c[k+39216>>2]=g;c[k+104752>>2]=g;c[k+170288>>2]=g;g=h+13312|0;c[k+39220>>2]=g;c[k+104756>>2]=g;c[k+170292>>2]=g;g=h+14336|0;c[k+39224>>2]=g;c[k+104760>>2]=g;c[k+170296>>2]=g;g=h+15360|0;c[k+39228>>2]=g;c[k+104764>>2]=g;c[k+170300>>2]=g;c[k+61824>>2]=1;c[k+61828>>2]=1;c[k+61832>>2]=1;c[k+61836>>2]=1;c[k+61840>>2]=1;c[k+61844>>2]=1;c[k+61848>>2]=1;c[k+61852>>2]=1;c[k+196612>>2]=2748;c[k+61920>>2]=2;c[k+61924>>2]=2;c[k+61928>>2]=2;c[k+61932>>2]=2;c[k+61936>>2]=2;c[k+61940>>2]=2;c[k+61944>>2]=2;c[k+61948>>2]=2;c[k+196616>>2]=2748;c[k+104448>>2]=3;c[k+104452>>2]=3;c[k+104456>>2]=3;c[k+104460>>2]=3;c[k+196740>>2]=1398;g=k+65280|0;h=16711680;while(1){c[g+65536>>2]=4;j=h+1024|0;if(j>>>0>16777215){break}else{g=g+4|0;h=j}}c[k+196664>>2]=2176;c[k+196744>>2]=2268;k=c[3532592]|0;if((k|0)==0){l=c[2113054]|0;c[2113060]=l;c[2394]=-1;return b|0}gGC(k|0,9104152,280)|0;l=c[2113054]|0;c[2113060]=l;c[2394]=-1;return b|0}function aqO(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4939636+(b*112|0)>>2];c[a+104>>2]=c[4939640+(b*112|0)>>2];c[a+108>>2]=c[4939644+(b*112|0)>>2];d=0;return d|0}function aqP(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=4939536+(b*112|0);e=0;return e|0}function aqQ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1682656+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aqR(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>61){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4942112+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aqS(){var a=0,b=0;a=aia()|0;b=(c[3542028]|0)+((c[2113268]|0)-8192)|0;c[3541880]=b;Wk(b,5);return a|0}function aqT(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1676820+(b*112|0)>>2];c[a+104>>2]=c[1676824+(b*112|0)>>2];c[a+108>>2]=c[1676828+(b*112|0)>>2];d=0;return d|0}function aqU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=1676720+(b*112|0);e=0;return e|0}function aqV(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>64){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1679296+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aqW(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1680180+(b*112|0)>>2];c[a+104>>2]=c[1680184+(b*112|0)>>2];c[a+108>>2]=c[1680188+(b*112|0)>>2];d=0;return d|0}function aqX(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=1680080+(b*112|0);e=0;return e|0}function aqY(){var a=0,b=0;c[2113296]=12e6;a=aia()|0;b=(c[3542028]|0)+((c[2113268]|0)-8192)|0;c[3541880]=b;Wk(b,2);return a|0}function aqZ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>49){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3350668+(b*112|0)>>2];c[a+104>>2]=c[3350672+(b*112|0)>>2];c[a+108>>2]=c[3350676+(b*112|0)>>2];d=0;return d|0}function aq_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<50&(d|0)==0)){e=1;return e|0}c[a>>2]=3350568+(b*112|0);e=0;return e|0}function aq$(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;b=i;i=i+352|0;d=b|0;e=b+112|0;f=b+120|0;g=b+232|0;h=b+240|0;j=aia()|0;k=c[3542028]|0;l=(c[2113268]|0)-8192|0;c[3541880]=k+l;m=h+100|0;c[m>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](h,8)|0;n=c[m>>2]|0;L8291:do{if((n|0)==0){o=0;p=6905}else{q=0;while(1){if((q|0)>=1024){o=0;p=6905;break L8291}r=9638528+(q<<2)|0;if((c[r>>2]|0)==0){break}else{q=q+1|0}}q=gGq(n)|0;c[r>>2]=q;if((q|0)==0){o=0;p=6905;break}gGz(q|0,0,n|0);do{if((c[3542200]|0)==0){s=0}else{t=f+108|0;c[t>>2]=0;u=f+100|0;c[u>>2]=0;v=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[v&16383](f,8)|0;if((c[t>>2]|0)==0){w=q;break L8291}t=c[u>>2]|0;c[g>>2]=9534384;u=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[u&16383](g,8,0)|0;if((t|0)<1){s=0;break}if((gzL(q,0,8)|0)==0){w=q;break L8291}else{s=0}}}while(0);while(1){if((s|0)>=1024){o=0;p=6905;break L8291}x=9638528+(s<<2)|0;if((c[x>>2]|0)==(q|0)){break}else{s=s+1|0}}gGr(q);c[x>>2]=0;o=0;p=6905}}while(0);L8305:do{if((p|0)==6905){while(1){p=0;if((o|0)>=1024){y=0;break}z=9638528+(o<<2)|0;if((c[z>>2]|0)==0){p=6907;break}else{o=o+1|0;p=6905}}if((p|0)==6907){gGr(0);c[z>>2]=0;y=0}while(1){if((y|0)>=1024){w=0;break L8305}A=9638528+(y<<2)|0;if((c[A>>2]|0)==0){break}else{y=y+1|0}}gGr(0);c[A>>2]=0;w=0}}while(0);c[m>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](h,12)|0;h=c[m>>2]|0;L8316:do{if((h|0)==0){B=0;p=6929}else{m=0;while(1){if((m|0)>=1024){B=0;p=6929;break L8316}C=9638528+(m<<2)|0;if((c[C>>2]|0)==0){break}else{m=m+1|0}}m=gGq(h)|0;c[C>>2]=m;if((m|0)==0){B=0;p=6929;break}gGz(m|0,0,h|0);do{if((c[3542200]|0)==0){D=0}else{A=d+108|0;c[A>>2]=0;y=d+100|0;c[y>>2]=0;z=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[z&16383](d,12)|0;if((c[A>>2]|0)==0){E=w;F=m;break L8316}A=c[y>>2]|0;c[e>>2]=9534384;y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[y&16383](e,12,0)|0;if((A|0)<1){D=0;break}if((gzL(m,0,12)|0)==0){E=w;F=m;break L8316}else{D=0}}}while(0);while(1){if((D|0)>=1024){B=0;p=6929;break L8316}G=9638528+(D<<2)|0;if((c[G>>2]|0)==(m|0)){break}else{D=D+1|0}}gGr(m);c[G>>2]=0;B=0;p=6929}}while(0);L8330:do{if((p|0)==6929){while(1){p=0;if((B|0)>=1024){H=0;break}I=9638528+(B<<2)|0;if((c[I>>2]|0)==(w|0)){p=6931;break}else{B=B+1|0;p=6929}}if((p|0)==6931){gGr(w);c[I>>2]=0;H=0}while(1){if((H|0)>=1024){E=0;F=0;break L8330}J=9638528+(H<<2)|0;if((c[J>>2]|0)==0){break}else{H=H+1|0}}gGr(0);c[J>>2]=0;E=0;F=0}}while(0);J=0;while(1){a[k+(l+J)|0]=a[E+J|0]|0;a[k+(l+(J+4096))|0]=a[F+J|0]|0;H=J+1|0;if((H|0)<4096){J=H}else{K=0;break}}while(1){if((K|0)>=1024){L=0;break}M=9638528+(K<<2)|0;if((c[M>>2]|0)==(E|0)){p=6915;break}else{K=K+1|0}}if((p|0)==6915){gGr(E);c[M>>2]=0;L=0}while(1){if((L|0)>=1024){p=6937;break}N=9638528+(L<<2)|0;if((c[N>>2]|0)==(F|0)){break}else{L=L+1|0}}if((p|0)==6937){i=b;return j|0}gGr(F);c[N>>2]=0;i=b;return j|0}function aq0(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4904020+(b*112|0)>>2];c[a+104>>2]=c[4904024+(b*112|0)>>2];c[a+108>>2]=c[4904028+(b*112|0)>>2];d=0;return d|0}function aq1(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=4903920+(b*112|0);e=0;return e|0}function aq2(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>23){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4183456+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aq3(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>52){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4905936+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aq4(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>32){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6434164+(b*112|0)>>2];c[a+104>>2]=c[6434168+(b*112|0)>>2];c[a+108>>2]=c[6434172+(b*112|0)>>2];d=0;return d|0}function aq5(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<33&(d|0)==0)){e=1;return e|0}c[a>>2]=6434064+(b*112|0);e=0;return e|0}function aq6(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5606100+(b*112|0)>>2];c[a+104>>2]=c[5606104+(b*112|0)>>2];c[a+108>>2]=c[5606108+(b*112|0)>>2];d=0;return d|0}function aq7(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=5606e3+(b*112|0);e=0;return e|0}function aq8(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6654924+(b*112|0)>>2];c[a+104>>2]=c[6654928+(b*112|0)>>2];c[a+108>>2]=c[6654932+(b*112|0)>>2];d=0;return d|0}function aq9(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<22&(d|0)==0)){e=1;return e|0}c[a>>2]=6654824+(b*112|0);e=0;return e|0}function ara(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>23){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4898400+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function arb(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>60){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6657288+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function arc(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4896036+(b*112|0)>>2];c[a+104>>2]=c[4896040+(b*112|0)>>2];c[a+108>>2]=c[4896044+(b*112|0)>>2];d=0;return d|0}function ard(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<22&(d|0)==0)){e=1;return e|0}c[a>>2]=4895936+(b*112|0);e=0;return e|0}function are(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>34){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6016276+(b*112|0)>>2];c[a+104>>2]=c[6016280+(b*112|0)>>2];c[a+108>>2]=c[6016284+(b*112|0)>>2];d=0;return d|0}function arf(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<35&(d|0)==0)){e=1;return e|0}c[a>>2]=6016176+(b*112|0);e=0;return e|0}function arg(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6014372+(b*112|0)>>2];c[a+104>>2]=c[6014376+(b*112|0)>>2];c[a+108>>2]=c[6014380+(b*112|0)>>2];d=0;return d|0}function arh(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=6014272+(b*112|0);e=0;return e|0}function ari(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>26){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5993452+(b*112|0)>>2];c[a+104>>2]=c[5993456+(b*112|0)>>2];c[a+108>>2]=c[5993460+(b*112|0)>>2];d=0;return d|0}function arj(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<27&(d|0)==0)){e=1;return e|0}c[a>>2]=5993352+(b*112|0);e=0;return e|0}function ark(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>23){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3679672+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function arl(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>63){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5996376+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function arm(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>26){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4882796+(b*112|0)>>2];c[a+104>>2]=c[4882800+(b*112|0)>>2];c[a+108>>2]=c[4882804+(b*112|0)>>2];d=0;return d|0}function arn(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<27&(d|0)==0)){e=1;return e|0}c[a>>2]=4882696+(b*112|0);e=0;return e|0}function aro(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>41){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4885820+(b*112|0)>>2];c[a+104>>2]=c[4885824+(b*112|0)>>2];c[a+108>>2]=c[4885828+(b*112|0)>>2];d=0;return d|0}function arp(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<42&(d|0)==0)){e=1;return e|0}c[a>>2]=4885720+(b*112|0);e=0;return e|0}function arq(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>26){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7363212+(b*112|0)>>2];c[a+104>>2]=c[7363216+(b*112|0)>>2];c[a+108>>2]=c[7363220+(b*112|0)>>2];d=0;return d|0}function arr(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<27&(d|0)==0)){e=1;return e|0}c[a>>2]=7363112+(b*112|0);e=0;return e|0}function ars(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>27){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6350720+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function art(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>3){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7366136+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aru(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>26){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6614164+(b*112|0)>>2];c[a+104>>2]=c[6614168+(b*112|0)>>2];c[a+108>>2]=c[6614172+(b*112|0)>>2];d=0;return d|0}function arv(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<27&(d|0)==0)){e=1;return e|0}c[a>>2]=6614064+(b*112|0);e=0;return e|0}function arw(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>26){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7083156+(b*112|0)>>2];c[a+104>>2]=c[7083160+(b*112|0)>>2];c[a+108>>2]=c[7083164+(b*112|0)>>2];d=0;return d|0}function arx(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<27&(d|0)==0)){e=1;return e|0}c[a>>2]=7083056+(b*112|0);e=0;return e|0}function ary(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>26){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7086180+(b*112|0)>>2];c[a+104>>2]=c[7086184+(b*112|0)>>2];c[a+108>>2]=c[7086188+(b*112|0)>>2];d=0;return d|0}function arz(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<27&(d|0)==0)){e=1;return e|0}c[a>>2]=7086080+(b*112|0);e=0;return e|0}function arA(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>26){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7091804+(b*112|0)>>2];c[a+104>>2]=c[7091808+(b*112|0)>>2];c[a+108>>2]=c[7091812+(b*112|0)>>2];d=0;return d|0}function arB(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<27&(d|0)==0)){e=1;return e|0}c[a>>2]=7091704+(b*112|0);e=0;return e|0}function arC(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>27){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6619540+(b*112|0)>>2];c[a+104>>2]=c[6619544+(b*112|0)>>2];c[a+108>>2]=c[6619548+(b*112|0)>>2];d=0;return d|0}function arD(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<28&(d|0)==0)){e=1;return e|0}c[a>>2]=6619440+(b*112|0);e=0;return e|0}function arE(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4879072+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function arF(){var b=0;a[7462128]=1;c[2113296]=12e6;b=aia()|0;c[3542068]=3;return b|0}function arG(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5980028+(b*112|0)>>2];c[a+104>>2]=c[5980032+(b*112|0)>>2];c[a+108>>2]=c[5980036+(b*112|0)>>2];d=0;return d|0}function arH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=5979928+(b*112|0);e=0;return e|0}function arI(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>29){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1863040+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function arJ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>29){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5981384+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function arK(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>4){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7089204+(b*112|0)>>2];c[a+104>>2]=c[7089208+(b*112|0)>>2];c[a+108>>2]=c[7089212+(b*112|0)>>2];d=0;return d|0}function arL(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<5&(d|0)==0)){e=1;return e|0}c[a>>2]=7089104+(b*112|0);e=0;return e|0}function arM(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>28){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5981744+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function arN(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>29){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7089664+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function arO(){var b=0,d=0,e=0,f=0,g=0,h=0;a[9757384]=-48;a[64288]=1;c[3541966]=65472;c[3541964]=65472;c[3541962]=65472;c[2426966]=1846;c[3542064]=3544;c[3542066]=4732;c[2113296]=12e6;b=aia()|0;if((c[2394]|0)==0){d=c[2112932]|0}else{c[2394]=0;e=c[3532596]|0;c[2112932]=e;f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];d=e}e=d+34816|0;f=8912896;while(1){c[e>>2]=3;c[e+65536>>2]=3;g=f+1024|0;if(g>>>0>9043967){break}else{e=e+4|0;f=g}}c[d+196620>>2]=2816;c[d+196700>>2]=2564;c[d+196660>>2]=1862;c[d+196740>>2]=2512;c[d+4944>>2]=4;c[d+4948>>2]=4;c[d+4952>>2]=4;c[d+4956>>2]=4;c[d+196624>>2]=2942;c[d+196704>>2]=176;f=d+65280|0;e=16711680;while(1){c[f+65536>>2]=5;g=e+1024|0;if(g>>>0>16777215){break}else{f=f+4|0;e=g}}c[d+196668>>2]=1322;c[d+196748>>2]=3062;d=c[3532592]|0;if((d|0)==0){h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return b|0}gGC(d|0,9104152,280)|0;h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return b|0}function arP(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>5){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6618868+(b*112|0)>>2];c[a+104>>2]=c[6618872+(b*112|0)>>2];c[a+108>>2]=c[6618876+(b*112|0)>>2];d=0;return d|0}function arQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<6&(d|0)==0)){e=1;return e|0}c[a>>2]=6618768+(b*112|0);e=0;return e|0}function arR(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>5){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6706188+(b*112|0)>>2];c[a+104>>2]=c[6706192+(b*112|0)>>2];c[a+108>>2]=c[6706196+(b*112|0)>>2];d=0;return d|0}function arS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<6&(d|0)==0)){e=1;return e|0}c[a>>2]=6706088+(b*112|0);e=0;return e|0}function arT(){var b=0,d=0,e=0,f=0,g=0,h=0;a[9757384]=-48;a[64288]=1;c[3541966]=65472;c[3541964]=65472;c[3541962]=65472;c[2426966]=1846;c[2429532]=12798;c[3542064]=3544;c[3542066]=4732;c[2113296]=12e6;b=aia()|0;if((c[2394]|0)==0){d=c[2112932]|0}else{c[2394]=0;e=c[3532596]|0;c[2112932]=e;f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];d=e}e=d+34816|0;f=8912896;while(1){c[e>>2]=3;c[e+65536>>2]=3;g=f+1024|0;if(g>>>0>9043967){break}else{e=e+4|0;f=g}}c[d+196620>>2]=2816;c[d+196700>>2]=2564;c[d+196660>>2]=1862;c[d+196740>>2]=2512;c[d+4944>>2]=4;c[d+4948>>2]=4;c[d+4952>>2]=4;c[d+4956>>2]=4;c[d+196624>>2]=2942;c[d+196704>>2]=176;f=d+65280|0;e=16711680;while(1){c[f+65536>>2]=5;g=e+1024|0;if(g>>>0>16777215){break}else{f=f+4|0;e=g}}c[d+196668>>2]=1322;c[d+196748>>2]=3062;c[d+102400>>2]=6;c[d+102404>>2]=6;c[d+196832>>2]=2124;d=c[3532592]|0;if((d|0)==0){h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return b|0}gGC(d|0,9104152,280)|0;h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return b|0}function arU(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5986812+(b*112|0)>>2];c[a+104>>2]=c[5986816+(b*112|0)>>2];c[a+108>>2]=c[5986820+(b*112|0)>>2];d=0;return d|0}function arV(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=5986712+(b*112|0);e=0;return e|0}function arW(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>30){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3245384+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function arX(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>25){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5988392+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function arY(){c[2429532]=1944;c[2113296]=12e6;return aia()|0}function arZ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4880196+(b*112|0)>>2];c[a+104>>2]=c[4880200+(b*112|0)>>2];c[a+108>>2]=c[4880204+(b*112|0)>>2];d=0;return d|0}function ar_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=4880096+(b*112|0);e=0;return e|0}function ar$(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>29){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4880880+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function ar0(){var b=0,d=0,e=0,f=0,g=0,h=0;c[2429532]=12798;a[9757384]=80;a[64288]=1;c[3541966]=65472;c[3541964]=65472;c[3541962]=65472;c[2426966]=1846;c[3542064]=3544;c[3542066]=4732;c[2113296]=12e6;b=aia()|0;if((c[2394]|0)==0){d=c[2112932]|0}else{c[2394]=0;e=c[3532596]|0;c[2112932]=e;f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];d=e}e=d+34816|0;f=8912896;while(1){c[e>>2]=3;c[e+65536>>2]=3;g=f+1024|0;if(g>>>0>9043967){break}else{e=e+4|0;f=g}}c[d+196620>>2]=2816;c[d+196700>>2]=2564;c[d+196660>>2]=1862;c[d+196740>>2]=2512;f=d+65280|0;e=16711680;while(1){c[f+65536>>2]=4;g=e+1024|0;if(g>>>0>16777215){break}else{f=f+4|0;e=g}}c[d+196664>>2]=1322;c[d+196744>>2]=3062;d=c[3532592]|0;if((d|0)==0){h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return b|0}gGC(d|0,9104152,280)|0;h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return b|0}function ar1(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5985668+(b*112|0)>>2];c[a+104>>2]=c[5985672+(b*112|0)>>2];c[a+108>>2]=c[5985676+(b*112|0)>>2];d=0;return d|0}function ar2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=5985568+(b*112|0);e=0;return e|0}function ar3(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>29){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5986352+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function ar4(){var b=0,d=0,e=0,f=0,g=0,h=0;a[64288]=1;c[3541966]=65472;c[3541964]=65472;c[3541962]=65472;c[2426966]=1846;c[3542064]=3544;c[3542066]=4732;c[2113296]=12e6;b=aia()|0;if((c[2394]|0)==0){d=c[2112932]|0}else{c[2394]=0;e=c[3532596]|0;c[2112932]=e;f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];d=e}e=d+34816|0;f=8912896;while(1){c[e>>2]=3;c[e+65536>>2]=3;g=f+1024|0;if(g>>>0>9043967){break}else{e=e+4|0;f=g}}c[d+196620>>2]=1802;c[d+196700>>2]=1692;c[d+196660>>2]=2876;c[d+196740>>2]=606;f=d+65280|0;e=16711680;while(1){c[f+65536>>2]=4;g=e+1024|0;if(g>>>0>16777215){break}else{f=f+4|0;e=g}}c[d+196664>>2]=1322;c[d+196744>>2]=3062;d=c[3532592]|0;if((d|0)==0){h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return b|0}gGC(d|0,9104152,280)|0;h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return b|0}function ar5(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>5){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4879524+(b*112|0)>>2];c[a+104>>2]=c[4879528+(b*112|0)>>2];c[a+108>>2]=c[4879532+(b*112|0)>>2];d=0;return d|0}function ar6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<6&(d|0)==0)){e=1;return e|0}c[a>>2]=4879424+(b*112|0);e=0;return e|0}function ar7(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6612708+(b*112|0)>>2];c[a+104>>2]=c[6612712+(b*112|0)>>2];c[a+108>>2]=c[6612716+(b*112|0)>>2];d=0;return d|0}function ar8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=6612608+(b*112|0);e=0;return e|0}function ar9(){var b=0,d=0,e=0,f=0,g=0,h=0;a[64288]=1;c[3541966]=65472;c[3541964]=65472;c[3541962]=65472;c[3542064]=3544;c[3542066]=4732;c[2113296]=12e6;b=aia()|0;if((c[2394]|0)==0){d=c[2112932]|0}else{c[2394]=0;e=c[3532596]|0;c[2112932]=e;f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];d=e}e=d+34816|0;f=8912896;while(1){c[e>>2]=3;c[e+65536>>2]=3;g=f+1024|0;if(g>>>0>9043967){break}else{e=e+4|0;f=g}}c[d+196620>>2]=1802;c[d+196700>>2]=1692;c[d+196660>>2]=2876;c[d+196740>>2]=606;f=d+65280|0;e=16711680;while(1){c[f+65536>>2]=4;g=e+1024|0;if(g>>>0>16777215){break}else{f=f+4|0;e=g}}c[d+196664>>2]=1322;c[d+196744>>2]=3062;d=c[3532592]|0;if((d|0)==0){h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return b|0}gGC(d|0,9104152,280)|0;h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return b|0}function asa(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5978684+(b*112|0)>>2];c[a+104>>2]=c[5978688+(b*112|0)>>2];c[a+108>>2]=c[5978692+(b*112|0)>>2];d=0;return d|0}function asb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=5978584+(b*112|0);e=0;return e|0}function asc(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5977564+(b*112|0)>>2];c[a+104>>2]=c[5977568+(b*112|0)>>2];c[a+108>>2]=c[5977572+(b*112|0)>>2];d=0;return d|0}function asd(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=5977464+(b*112|0);e=0;return e|0}function ase(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>27){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3244936+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function asf(){c[3541966]=2;c[3541964]=4;c[3541962]=8;a[7462160]=1;c[2113296]=12e6;return aia()|0}function asg(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7090124+(b*112|0)>>2];c[a+104>>2]=c[7090128+(b*112|0)>>2];c[a+108>>2]=c[7090132+(b*112|0)>>2];d=0;return d|0}function ash(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=7090024+(b*112|0);e=0;return e|0}function asi(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a[64288]=1;a[7462144]=1;a[7461712]=1;a[7462008]=1;c[3541966]=65472;c[3541964]=65472;c[3541962]=65472;c[2426966]=1564;c[3542064]=3904;c[3542066]=4732;c[3541954]=10646;c[2113296]=12e6;d=aia()|0;e=0;while(1){if((e|0)>=1024){f=0;break}g=9638528+(e<<2)|0;if((c[g>>2]|0)==0){h=7477;break}else{e=e+1|0}}do{if((h|0)==7477){e=gGq(16384)|0;c[g>>2]=e;if((e|0)==0){f=0;break}gGz(e|0,0,16384);f=e}}while(0);c[3542036]=f;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060]}g=c[2112932]|0;c[g+39168>>2]=f;c[g+104704>>2]=f;c[g+170240>>2]=f;h=f+1024|0;c[g+39172>>2]=h;c[g+104708>>2]=h;c[g+170244>>2]=h;h=f+2048|0;c[g+39176>>2]=h;c[g+104712>>2]=h;c[g+170248>>2]=h;h=f+3072|0;c[g+39180>>2]=h;c[g+104716>>2]=h;c[g+170252>>2]=h;h=f+4096|0;c[g+39184>>2]=h;c[g+104720>>2]=h;c[g+170256>>2]=h;h=f+5120|0;c[g+39188>>2]=h;c[g+104724>>2]=h;c[g+170260>>2]=h;h=f+6144|0;c[g+39192>>2]=h;c[g+104728>>2]=h;c[g+170264>>2]=h;h=f+7168|0;c[g+39196>>2]=h;c[g+104732>>2]=h;c[g+170268>>2]=h;h=f+8192|0;c[g+39200>>2]=h;c[g+104736>>2]=h;c[g+170272>>2]=h;h=f+9216|0;c[g+39204>>2]=h;c[g+104740>>2]=h;c[g+170276>>2]=h;h=f+10240|0;c[g+39208>>2]=h;c[g+104744>>2]=h;c[g+170280>>2]=h;h=f+11264|0;c[g+39212>>2]=h;c[g+104748>>2]=h;c[g+170284>>2]=h;h=f+12288|0;c[g+39216>>2]=h;c[g+104752>>2]=h;c[g+170288>>2]=h;h=f+13312|0;c[g+39220>>2]=h;c[g+104756>>2]=h;c[g+170292>>2]=h;h=f+14336|0;c[g+39224>>2]=h;c[g+104760>>2]=h;c[g+170296>>2]=h;h=f+15360|0;c[g+39228>>2]=h;c[g+104764>>2]=h;c[g+170300>>2]=h;h=g+38912|0;f=9961472;while(1){c[h+65536>>2]=1;e=f+1024|0;if(e>>>0>10027007){break}else{h=h+4|0;f=e}}c[g+196732>>2]=2038;f=g+65280|0;h=16711680;while(1){c[f+65536>>2]=2;e=h+1024|0;if(e>>>0>16777215){break}else{f=f+4|0;h=e}}c[g+196656>>2]=1322;c[g+196736>>2]=3062;g=c[3532592]|0;if((g|0)==0){i=c[2113054]|0;c[2113060]=i;c[2394]=-1;j=c[3541926]|0;k=j+6|0;l=k;b[l>>1]=-28416;return d|0}gGC(g|0,9104152,280)|0;i=c[2113054]|0;c[2113060]=i;c[2394]=-1;j=c[3541926]|0;k=j+6|0;l=k;b[l>>1]=-28416;return d|0}function asj(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6617188+(b*112|0)>>2];c[a+104>>2]=c[6617192+(b*112|0)>>2];c[a+108>>2]=c[6617196+(b*112|0)>>2];d=0;return d|0}function ask(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=6617088+(b*112|0);e=0;return e|0}function asl(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6622676+(b*112|0)>>2];c[a+104>>2]=c[6622680+(b*112|0)>>2];c[a+108>>2]=c[6622684+(b*112|0)>>2];d=0;return d|0}function asm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=6622576+(b*112|0);e=0;return e|0}function asn(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5983988+(b*112|0)>>2];c[a+104>>2]=c[5983992+(b*112|0)>>2];c[a+108>>2]=c[5983996+(b*112|0)>>2];d=0;return d|0}function aso(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=5983888+(b*112|0);e=0;return e|0}function asp(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5982308+(b*112|0)>>2];c[a+104>>2]=c[5982312+(b*112|0)>>2];c[a+108>>2]=c[5982316+(b*112|0)>>2];d=0;return d|0}function asq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=5982208+(b*112|0);e=0;return e|0}function asr(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4142884+(b*112|0)>>2];c[a+104>>2]=c[4142888+(b*112|0)>>2];c[a+108>>2]=c[4142892+(b*112|0)>>2];d=0;return d|0}function ass(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=4142784+(b*112|0);e=0;return e|0}function ast(a,b){a=a|0;b=b|0;var d=0;b=i;i=i+16|0;d=b|0;if((a&32|0)==0){i=b;return 0}gGz(d|0,0,12);c[d>>2]=c[3542036];c[d+4>>2]=16384;c[d+12>>2]=168280;gj[c[2076592]&4095](d)|0;i=b;return 0}function asu(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=0;while(1){if((b|0)>=1024){break}d=9638528+(b<<2)|0;if((c[d>>2]|0)==0){e=7560;break}else{b=b+1|0}}L9054:do{if((e|0)==7560){b=gGq(262144)|0;c[d>>2]=b;if((b|0)==0){break}gGz(b|0,0,262144);f=c[3541922]|0;g=f+262144|0;gGC(b|0,g|0,262144)|0;h=f+524288|0;gGC(g|0,h|0,262144)|0;gGC(h|0,b|0,262144)|0;h=0;while(1){if((h|0)>=1024){break L9054}i=9638528+(h<<2)|0;if((c[i>>2]|0)==(b|0)){break}else{h=h+1|0}}gGr(b);c[i>>2]=0}}while(0);a[(c[3541922]|0)+9289|0]=7;return}function asv(){var a=0,b=0,d=0;a=c[3541922]|0;b=a+786432|0;d=a+1048576|0;gGC(b|0,d|0,262144)|0;gGz(d|0,0,262144);return}function asw(a,b){a=a|0;b=b|0;var d=0;d=(b|0)==-1?-268439553:b;c[(c[3541932]|0)+(a&262140)>>2]=d<<16|d>>>16;return}function asx(){var a=0,b=0,d=0;a=c[3541922]|0;b=a+1572864|0;gGC(a|0,b|0,262144)|0;b=a+524288|0;d=a+1835008|0;gGC(b|0,d|0,262144)|0;d=a+1048576|0;b=a+2097152|0;gGC(d|0,b|0,262144)|0;return}function asy(){var a=0,b=0,d=0;a=c[3541922]|0;b=a+786432|0;d=a+1310720|0;gGC(b|0,d|0,262144)|0;return}function asz(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=i;i=i+16|0;e=d|0;if((a&32|0)==0){f=ag8(a,b)|0;i=d;return 0}gGz(e|0,0,12);c[e>>2]=c[3542036];c[e+4>>2]=16384;c[e+12>>2]=168280;gj[c[2076592]&4095](e)|0;f=ag8(a,b)|0;i=d;return 0}function asA(){var a=0,b=0,d=0,e=0,f=0,g=0;a=0;while(1){if((a|0)>=1024){b=7585;break}d=9638528+(a<<2)|0;if((c[d>>2]|0)==0){break}else{a=a+1|0}}if((b|0)==7585){return}a=gGq(1048576)|0;c[d>>2]=a;if((a|0)==0){return}gGz(a|0,0,1048576);d=c[3541922]|0;gGC(a|0,d|0,1048576)|0;gGz(d|0,0,1048576);gGC(d|0,a|0,262144)|0;e=d+786432|0;f=a+262144|0;gGC(e|0,f|0,262144)|0;f=d+524288|0;e=a+524288|0;gGC(f|0,e|0,262144)|0;e=d+262144|0;d=a+786432|0;gGC(e|0,d|0,262144)|0;d=0;while(1){if((d|0)>=1024){b=7586;break}g=9638528+(d<<2)|0;if((c[g>>2]|0)==(a|0)){break}else{d=d+1|0}}if((b|0)==7586){return}gGr(a);c[g>>2]=0;return}function asB(){var a=0,b=0,d=0;a=c[3541922]|0;b=a+1310720|0;d=a+1048576|0;gGC(b|0,d|0,262144)|0;return}function asC(){var a=0,b=0,d=0,e=0,f=0,g=0;a=0;while(1){if((a|0)>=1024){b=7598;break}d=9638528+(a<<2)|0;if((c[d>>2]|0)==0){break}else{a=a+1|0}}if((b|0)==7598){return}a=gGq(1572864)|0;c[d>>2]=a;if((a|0)==0){return}gGz(a|0,0,1572864);d=c[3541922]|0;gGC(a|0,d|0,1572864)|0;e=d+524288|0;gGC(e|0,d|0,262144)|0;e=d+1310720|0;f=a+262144|0;gGC(e|0,f|0,262144)|0;f=d+1048576|0;e=a+524288|0;gGC(f|0,e|0,262144)|0;e=d+262144|0;f=a+786432|0;gGC(e|0,f|0,262144)|0;f=a+1048576|0;gGC(d|0,f|0,262144)|0;f=d+786432|0;d=a+1310720|0;gGC(f|0,d|0,262144)|0;d=0;while(1){if((d|0)>=1024){b=7601;break}g=9638528+(d<<2)|0;if((c[g>>2]|0)==(a|0)){break}else{d=d+1|0}}if((b|0)==7601){return}gGr(a);c[g>>2]=0;return}function asD(){var b=0,d=0,e=0,f=0;b=0;d=c[3541922]|0;while(1){e=a[d]|0;f=d+1|0;a[d]=a[f]|0;a[f]=e;e=b+1|0;if((e|0)<524288){b=e;d=d+2|0}else{break}}return}function asE(){return}function asF(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;b=i;i=i+32|0;d=b|0;e=b+16|0;if((a&64|0)!=0){gGz(e|0,0,12);c[e>>2]=9717968;c[e+4>>2]=2;c[e+12>>2]=101264;f=c[2076592]|0;gj[f&4095](e)|0}if((a&32|0)==0){i=b;return 0}gGz(d|0,0,12);c[d>>2]=c[3542036];c[d+4>>2]=16384;c[d+12>>2]=168280;gj[c[2076592]&4095](d)|0;i=b;return 0}function asG(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[3541922]|0;e=524288;do{f=b+e|0;g=d[f]|0;h=g<<2&4;i=((g&2|0)==0?h:h|33)^g>>>2&1;h=~g;j=(h&8|0)==0?i:i|80;i=(g&16|0)==0?j:j^64;j=(g&32|0)==0?i:i^6;i=(g&64|0)==0?j:j^8;if((h&128|0)==0){k=i&255}else{k=(i^136)&255}a[f]=k;e=e+2|0;}while((e|0)<1048576);return}function asH(){a[(c[3541922]|0)+2387|0]=7;return}function asI(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=i;i=i+16|0;e=d|0;if((a&32|0)==0){f=ag8(a,b)|0;i=d;return 0}gGz(e|0,0,12);c[e>>2]=c[3542036];c[e+4>>2]=16384;c[e+12>>2]=168280;gj[c[2076592]&4095](e)|0;f=ag8(a,b)|0;i=d;return 0}function asJ(){var b=0,d=0,e=0,f=0;b=0;d=(c[3541922]|0)+524288|0;while(1){e=a[d]|0;f=d+1|0;a[d]=a[f]|0;a[f]=e;e=b+1|0;if((e|0)<262144){b=e;d=d+2|0}else{break}}return}function asK(){var a=0,b=0,d=0,e=0;if(((c[2113222]|0)%60|0|0)==0){Tu()}if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];a=c[3532592]|0;if((a|0)!=0){gGC(9104152,a|0,280)|0}c[2113054]=c[2113060]}c[2113050]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0<1024){RH(4);b=c[2394]|0}else{b=0}a=c[14130368+(b<<2)>>2]|0;if((a|0)==0){d=c[2113054]|0;e=8452240+(b<<2)|0;c[e>>2]=d;c[2394]=-1;return}gGC(a|0,9104152,280)|0;d=c[2113054]|0;e=8452240+(b<<2)|0;c[e>>2]=d;c[2394]=-1;return}function asL(a,b){a=a|0;b=b|0;var d=0;b=i;i=i+16|0;d=b|0;if((a&8|0)==0){i=b;return 0}gGz(d|0,0,12);c[d>>2]=c[2424883];c[d+4>>2]=c[2424885];c[d+12>>2]=174400;gj[c[2076592]&4095](d)|0;i=b;return 0}function asM(){a[(c[3541922]|0)+9745|0]=7;return}function asN(){var a=0,b=0,d=0,e=0,f=0,g=0;a=0;while(1){if((a|0)>=1024){b=7656;break}d=9638528+(a<<2)|0;if((c[d>>2]|0)==0){break}else{a=a+1|0}}if((b|0)==7656){return}a=gGq(2097152)|0;c[d>>2]=a;if((a|0)==0){return}gGz(a|0,0,2097152);d=c[3541922]|0;gGC(a|0,d|0,2097152)|0;gGz(d|0,0,2097152);e=d+524288|0;gGC(e|0,a|0,524288)|0;e=a+524288|0;gGC(d|0,e|0,524288)|0;e=d+1572864|0;f=a+1048576|0;gGC(e|0,f|0,524288)|0;f=d+1048576|0;d=a+1572864|0;gGC(f|0,d|0,524288)|0;d=0;while(1){if((d|0)>=1024){b=7657;break}g=9638528+(d<<2)|0;if((c[g>>2]|0)==(a|0)){break}else{d=d+1|0}}if((b|0)==7657){return}gGr(a);c[g>>2]=0;return}function asO(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0;e=i;i=i+3496|0;f=e|0;g=e+112|0;h=e+120|0;j=e+232|0;k=e+240|0;l=e+352|0;m=e+360|0;n=e+472|0;o=e+480|0;p=e+592|0;q=e+704|0;r=e+816|0;s=e+928|0;t=e+1040|0;u=e+1048|0;v=e+1160|0;w=e+1168|0;x=e+1280|0;y=e+1288|0;z=e+1400|0;A=e+1408|0;B=e+1520|0;C=e+1632|0;D=e+1744|0;E=e+1856|0;F=e+1968|0;G=e+1976|0;H=e+2088|0;I=e+2096|0;J=e+2208|0;K=e+2216|0;L=e+2328|0;M=e+2336|0;N=e+2448|0;O=e+2560|0;P=e+2672|0;Q=e+2784|0;R=e+2896|0;S=e+2904|0;T=e+3016|0;U=e+3024|0;V=e+3136|0;W=e+3144|0;X=e+3256|0;Y=e+3264|0;Z=e+3376|0;_=e+3384|0;$=_+108|0;c[$>>2]=0;aa=_+100|0;c[aa>>2]=0;if((b|0)==0){b=-1;do{c[aa>>2]=0;c[$>>2]=0;b=b+1|0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](_,b)|0;ab=c[$>>2]&255;L9180:do{switch(ab|0){case 4:{c[2113268]=(c[2113268]|0)+(c[aa>>2]|0);c[2433562]=(c[2433562]|0)+1;ac=7669;break};case 1:{c[2113250]=(c[2113250]|0)+(c[aa>>2]|0);c[2427232]=(c[2427232]|0)+1;ac=7669;break};case 2:{c[2113250]=(c[2113250]|0)+(c[aa>>2]|0);c[2427032]=(c[2427032]|0)+1;ac=7669;break};case 3:{c[2113246]=(c[2113246]|0)+(c[aa>>2]|0);c[2439240]=(c[2439240]|0)+1;ac=7669;break};case 5:{c[2113274]=(c[2113274]|0)+(c[aa>>2]|0);c[2429862]=(c[2429862]|0)+1;ac=7669;break};case 6:{a[7462128]=1;c[2113252]=(c[2113252]|0)+(c[aa>>2]|0);c[2432858]=(c[2432858]|0)+1;ac=7669;break};case 7:{c[2439242]=(c[2439242]|0)+1;ac=7669;break};default:{if((ab-8|0)>>>0>=4){ac=7669;break L9180}ad=c[aa>>2]|0;c[2433564]=(c[2433564]|0)+ad;c[2429366]=(c[2429366]|0)+1;ae=ad}}}while(0);if((ac|0)==7669){ac=0;ae=c[aa>>2]|0}}while((ae|0)!=0);if(a[7462128]|0){c[2113246]=c[2113246]<<1}if((c[2443334]|0)!=0){c[2113268]=(c[2113268]|0)+8192}if(a[7461720]|0){c[2113268]=c[2113268]<<1}if((c[2439242]|0)==0){i=e;return}a[7462160]=1;i=e;return}ae=c[2427232]|0;b=c[2427032]|0;L9208:do{if((b|0)==(-ae|0)){af=0;ag=0;ah=ae;ai=b}else{ab=Y+108|0;ad=Y+100|0;aj=0;ak=0;while(1){gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](_,aj)|0;al=c[$>>2]|0;if((al&255|0)==1){if((R6((c[3541922]|0)+(ak+1)|0,aj,2)|0)!=0){ac=7959;break}am=aj+1|0;if((R6((c[3541922]|0)+ak|0,am,2)|0)!=0){ac=7960;break}an=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[an&16383](_,aj)|0;an=(c[aa>>2]|0)+ak|0;ao=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ao&16383](_,am)|0;ap=an+(c[aa>>2]|0)|0;aq=aj+2|0;ar=c[$>>2]|0}else{ap=ak;aq=aj;ar=al}if((ar&255|0)==2){al=(c[3541922]|0)+ap|0;if((c[3542200]|0)==0){ac=7961;break}c[ab>>2]=0;c[ad>>2]=0;an=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[an&16383](Y,aq)|0;if((c[ab>>2]|0)!=0){an=c[ad>>2]|0;c[Z>>2]=9534384;am=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[am&16383](Z,aq,0)|0;if((an|0)<1){ac=7962;break}if((gzL(al,0,aq)|0)!=0){ac=7963;break}}al=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[al&16383](_,aq)|0;as=(c[aa>>2]|0)+ap|0;at=aq+1|0}else{as=ap;at=aq}al=c[2427232]|0;an=c[2427032]|0;am=an+al|0;if(at>>>0<am>>>0){aj=at;ak=as}else{af=at;ag=am;ah=al;ai=an;break L9208}}if((ac|0)==7959){i=e;return}else if((ac|0)==7960){i=e;return}else if((ac|0)==7961){i=e;return}else if((ac|0)==7962){i=e;return}else if((ac|0)==7963){i=e;return}}}while(0);L9232:do{if((c[2113268]|0)==0){au=af;av=ah;aw=ai}else{if(ag>>>0>=(ah+ai+(c[2433562]|0)|0)>>>0){au=ag;av=ah;aw=ai;break}at=P+100|0;as=O+100|0;aq=N+100|0;ap=M+100|0;Z=E+108|0;Y=E+100|0;ar=G+108|0;b=G+100|0;ae=I+108|0;ak=I+100|0;aj=K+108|0;ad=K+100|0;ab=ag;an=0;while(1){al=ab;while(1){am=c[2426966]|0;if((am|0)==0){ao=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ao&16383](_,al)|0;if((c[aa>>2]|0)>>>0<524288){ac=7700;break}if(a[7461720]|0){ac=7703;break}ao=c[2433562]|0;if(ao>>>0<4){ax=ao}else{ac=7772;break}}else{gj[am&4095](al)|0;ax=c[2433562]|0}am=ax+al|0;ao=c[2427232]|0;ay=c[2427032]|0;if(am>>>0<(ao+ax+ay|0)>>>0){al=am}else{au=am;av=ao;aw=ay;break L9232}}if((ac|0)==7700){ac=0;VX((c[3542028]|0)+an|0,al);ay=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ay&16383](_,al)|0;ay=(c[aa>>2]|0)+an|0;ao=al+1|0;am=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[am&16383](_,ao)|0;ao=ay+(c[aa>>2]|0)|0;ay=al+2|0;am=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[am&16383](_,ay)|0;ay=ao+(c[aa>>2]|0)|0;ao=al+3|0;am=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[am&16383](_,ao)|0;ao=ay+(c[aa>>2]|0)|0;ay=al+4|0;am=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[am&16383](_,ay)|0;ay=ao+(c[aa>>2]|0)|0;ao=al+5|0;am=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[am&16383](_,ao)|0;ao=ay+(c[aa>>2]|0)|0;ay=al+6|0;am=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[am&16383](_,ay)|0;ay=ao+(c[aa>>2]|0)|0;ao=al+7|0;am=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[am&16383](_,ao)|0;az=ay+(c[aa>>2]|0)|0;aA=al+8|0}else if((ac|0)==7703){ac=0;ay=c[3542028]|0;ao=ay+an|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](P,al)|0;am=c[at>>2]|0;L9248:do{if((am|0)!=0){aB=0;while(1){if((aB|0)>=1024){break L9248}aC=9638528+(aB<<2)|0;if((c[aC>>2]|0)==0){break}else{aB=aB+1|0}}aB=gGq(am)|0;c[aC>>2]=aB;if((aB|0)==0){break}gGz(aB|0,0,am|0);do{if((c[3542200]|0)==0){aD=0}else{c[aj>>2]=0;c[ad>>2]=0;aE=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aE&16383](K,al)|0;if((c[aj>>2]|0)!=0){aE=c[ad>>2]|0;c[L>>2]=9534384;aF=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aF&16383](L,al,0)|0;if((aE|0)<1){aD=0;break}if((gzL(aB,0,al)|0)!=0){aD=0;break}}aE=c[at>>2]&-2;if((aE|0)>0){aF=ao;aG=aB;aH=0;while(1){aI=aH+2|0;aJ=aF;c[aJ>>2]=c[9620648+((d[aG+1|0]|0)<<2)>>2]<<1|c[9620648+((d[aG]|0)<<2)>>2]|c[aJ>>2];if((aI|0)<(aE|0)){aF=aF+8|0;aG=aG+2|0;aH=aI}else{aK=0;break}}}else{aK=0}while(1){if((aK|0)>=1024){break L9248}aL=9638528+(aK<<2)|0;if((c[aL>>2]|0)==(aB|0)){break}else{aK=aK+1|0}}gGr(aB);c[aL>>2]=0;break L9248}}while(0);while(1){if((aD|0)>=1024){break L9248}aM=9638528+(aD<<2)|0;if((c[aM>>2]|0)==(aB|0)){break}else{aD=aD+1|0}}gGr(aB);c[aM>>2]=0}}while(0);am=al+1|0;c[as>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](O,am)|0;aH=c[as>>2]|0;L9272:do{if((aH|0)!=0){aG=0;while(1){if((aG|0)>=1024){break L9272}aN=9638528+(aG<<2)|0;if((c[aN>>2]|0)==0){break}else{aG=aG+1|0}}aG=gGq(aH)|0;c[aN>>2]=aG;if((aG|0)==0){break}gGz(aG|0,0,aH|0);do{if((c[3542200]|0)==0){aO=0}else{c[ae>>2]=0;c[ak>>2]=0;aB=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aB&16383](I,am)|0;if((c[ae>>2]|0)!=0){aB=c[ak>>2]|0;c[J>>2]=9534384;aF=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aF&16383](J,am,0)|0;if((aB|0)<1){aO=0;break}if((gzL(aG,0,am)|0)!=0){aO=0;break}}aB=c[as>>2]&-2;if((aB|0)>0){aF=ao;aE=aG;aI=0;while(1){aJ=aI+2|0;aP=aF;c[aP>>2]=(c[9620648+((d[aE+1|0]|0)<<2)>>2]<<1|c[9620648+((d[aE]|0)<<2)>>2])<<2|c[aP>>2];if((aJ|0)<(aB|0)){aF=aF+8|0;aE=aE+2|0;aI=aJ}else{aQ=0;break}}}else{aQ=0}while(1){if((aQ|0)>=1024){break L9272}aR=9638528+(aQ<<2)|0;if((c[aR>>2]|0)==(aG|0)){break}else{aQ=aQ+1|0}}gGr(aG);c[aR>>2]=0;break L9272}}while(0);while(1){if((aO|0)>=1024){break L9272}aS=9638528+(aO<<2)|0;if((c[aS>>2]|0)==(aG|0)){break}else{aO=aO+1|0}}gGr(aG);c[aS>>2]=0}}while(0);ao=ay+(an+4)|0;c[aq>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](N,al)|0;aH=c[aq>>2]|0;L9296:do{if((aH|0)!=0){aI=0;while(1){if((aI|0)>=1024){break L9296}aT=9638528+(aI<<2)|0;if((c[aT>>2]|0)==0){break}else{aI=aI+1|0}}aI=gGq(aH)|0;c[aT>>2]=aI;if((aI|0)==0){break}gGz(aI|0,0,aH|0);do{if((c[3542200]|0)==0){aU=0}else{c[ar>>2]=0;c[b>>2]=0;aG=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aG&16383](G,al)|0;if((c[ar>>2]|0)!=0){aG=c[b>>2]|0;c[H>>2]=9534384;aE=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aE&16383](H,al,0)|0;if((aG|0)<1){aU=0;break}if((gzL(aI,0,al)|0)!=0){aU=0;break}}aG=c[aq>>2]&-2;if((aG|0)>1048576){aE=1048576;aF=ao;aB=aI+1048576|0;while(1){aJ=aE+2|0;aP=aF;c[aP>>2]=c[9620648+((d[aB+1|0]|0)<<2)>>2]<<1|c[9620648+((d[aB]|0)<<2)>>2]|c[aP>>2];if((aJ|0)<(aG|0)){aE=aJ;aF=aF+8|0;aB=aB+2|0}else{aV=0;break}}}else{aV=0}while(1){if((aV|0)>=1024){break L9296}aW=9638528+(aV<<2)|0;if((c[aW>>2]|0)==(aI|0)){break}else{aV=aV+1|0}}gGr(aI);c[aW>>2]=0;break L9296}}while(0);while(1){if((aU|0)>=1024){break L9296}aX=9638528+(aU<<2)|0;if((c[aX>>2]|0)==(aI|0)){break}else{aU=aU+1|0}}gGr(aI);c[aX>>2]=0}}while(0);c[ap>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](M,am)|0;aH=c[ap>>2]|0;L9321:do{if((aH|0)!=0){ay=0;while(1){if((ay|0)>=1024){break L9321}aY=9638528+(ay<<2)|0;if((c[aY>>2]|0)==0){break}else{ay=ay+1|0}}ay=gGq(aH)|0;c[aY>>2]=ay;if((ay|0)==0){break}gGz(ay|0,0,aH|0);do{if((c[3542200]|0)==0){aZ=0}else{c[Z>>2]=0;c[Y>>2]=0;aI=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aI&16383](E,am)|0;if((c[Z>>2]|0)!=0){aI=c[Y>>2]|0;c[F>>2]=9534384;aB=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aB&16383](F,am,0)|0;if((aI|0)<1){aZ=0;break}if((gzL(ay,0,am)|0)!=0){aZ=0;break}}aI=c[ap>>2]&-2;if((aI|0)>1048576){aB=1048576;aF=ao;aE=ay+1048576|0;while(1){aG=aB+2|0;aJ=aF;c[aJ>>2]=(c[9620648+((d[aE+1|0]|0)<<2)>>2]<<1|c[9620648+((d[aE]|0)<<2)>>2])<<2|c[aJ>>2];if((aG|0)<(aI|0)){aB=aG;aF=aF+8|0;aE=aE+2|0}else{a_=0;break}}}else{a_=0}while(1){if((a_|0)>=1024){break L9321}a$=9638528+(a_<<2)|0;if((c[a$>>2]|0)==(ay|0)){break}else{a_=a_+1|0}}gGr(ay);c[a$>>2]=0;break L9321}}while(0);while(1){if((aZ|0)>=1024){break L9321}a0=9638528+(aZ<<2)|0;if((c[a0>>2]|0)==(ay|0)){break}else{aZ=aZ+1|0}}gGr(ay);c[a0>>2]=0}}while(0);gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](_,al)|0;ao=(c[aa>>2]|0)+an|0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](_,am)|0;aH=ao+(c[aa>>2]|0)|0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](_,al+2|0)|0;ao=aH+(c[aa>>2]|0)|0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](_,al+3|0)|0;az=ao+(c[aa>>2]|0)|0;aA=al+4|0}else if((ac|0)==7772){ac=0;VW((c[3542028]|0)+an|0,al);gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](_,al)|0;ao=(c[aa>>2]|0)+an|0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](_,al+1|0)|0;aH=ao+(c[aa>>2]|0)|0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](_,al+2|0)|0;ao=aH+(c[aa>>2]|0)|0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](_,al+3|0)|0;az=ao+(c[aa>>2]|0)|0;aA=al+4|0}ao=c[2427232]|0;aH=c[2427032]|0;if(aA>>>0<(aH+ao+(c[2433562]|0)|0)>>>0){ab=aA;an=az}else{au=aA;av=ao;aw=aH;break}}}}while(0);do{if((c[2113246]|0)==0){a1=au}else{aA=av+aw+(c[2433562]|0)|0;if(aA>>>0>=(aA+(c[2439240]|0)|0)>>>0){a1=aA;break}az=U+108|0;ac=U+100|0;a0=W+108|0;aZ=W+100|0;a$=aA;aA=0;while(1){a_=(c[3541874]|0)+aA|0;do{if((c[3542200]|0)!=0){c[a0>>2]=0;c[aZ>>2]=0;F=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[F&16383](W,a$)|0;if((c[a0>>2]|0)==0){break}F=c[aZ>>2]|0;c[X>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](X,a$,0)|0;if((F|0)<1){break}gzL(a_,0,a$)|0}}while(0);do{if(a[7462128]|0){a_=(c[3542032]|0)+aA|0;if((c[3542200]|0)==0){break}c[az>>2]=0;c[ac>>2]=0;al=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[al&16383](U,a$)|0;if((c[az>>2]|0)==0){break}al=c[ac>>2]|0;c[V>>2]=9534384;am=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[am&16383](V,a$,0)|0;if((al|0)<1){break}gzL(a_,0,a$)|0}}while(0);gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](_,a$)|0;a_=a$+1|0;if(a_>>>0<((c[2427032]|0)+(c[2427232]|0)+(c[2433562]|0)+(c[2439240]|0)|0)>>>0){a$=a_;aA=(c[aa>>2]|0)+aA|0}else{a1=a_;break}}}}while(0);if((c[2439242]|0)!=0){V=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[V&16383](_,a1)|0}do{if((c[2113274]|0)!=0){a1=(c[2427032]|0)+(c[2427232]|0)+(c[2433562]|0)+(c[2439240]|0)|0;if(a1>>>0>=(a1+(c[2429862]|0)|0)>>>0){break}V=S+108|0;U=S+100|0;X=a1;a1=0;while(1){W=(c[3542044]|0)+a1|0;do{if((c[3542200]|0)!=0){c[V>>2]=0;c[U>>2]=0;aw=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aw&16383](S,X)|0;if((c[V>>2]|0)==0){break}aw=c[U>>2]|0;c[T>>2]=9534384;av=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[av&16383](T,X,0)|0;if((aw|0)<1){break}gzL(W,0,X)|0}}while(0);gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](_,X)|0;W=X+1|0;if(W>>>0<((c[2427032]|0)+(c[2427232]|0)+(c[2433562]|0)+(c[2439240]|0)+(c[2429862]|0)|0)>>>0){X=W;a1=(c[aa>>2]|0)+a1|0}else{break}}}}while(0);do{if((c[2113252]|0)!=0){T=(c[2427032]|0)+(c[2427232]|0)+(c[2433562]|0)+(c[2439240]|0)|0;if(T>>>0>=(T+(c[2432858]|0)|0)>>>0){break}S=Q+108|0;a1=Q+100|0;X=T;T=0;while(1){U=(c[3541940]|0)+T|0;do{if((c[3542200]|0)!=0){c[S>>2]=0;c[a1>>2]=0;V=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[V&16383](Q,X)|0;if((c[S>>2]|0)==0){break}V=c[a1>>2]|0;c[R>>2]=9534384;W=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[W&16383](R,X,0)|0;if((V|0)<1){break}gzL(U,0,X)|0}}while(0);gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](_,X)|0;U=X+1|0;if(U>>>0<((c[2427032]|0)+(c[2427232]|0)+(c[2433562]|0)+(c[2439240]|0)+(c[2432858]|0)|0)>>>0){X=U;T=(c[aa>>2]|0)+T|0}else{break}}}}while(0);if((c[2433564]|0)==0){i=e;return}aa=(c[2427032]|0)+(c[2427232]|0)+(c[2433562]|0)+(c[2439240]|0)+(c[2432858]|0)|0;if(aa>>>0>=(aa+(c[2429366]|0)|0)>>>0){i=e;return}R=D+100|0;Q=C+100|0;T=B+100|0;X=A+100|0;a1=s+108|0;S=s+100|0;U=u+108|0;V=u+100|0;W=w+108|0;aw=w+100|0;av=y+108|0;au=y+100|0;aA=r+100|0;a$=q+100|0;ac=p+100|0;az=o+100|0;aZ=f+108|0;a0=f+100|0;a_=h+108|0;al=h+100|0;am=k+108|0;F=k+100|0;E=m+108|0;aY=m+100|0;M=aa;do{gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](_,M)|0;aa=c[$>>2]|0;if((aa&255|0)==8){aX=c[3542028]|0;aU=aX+4194304|0;gGz(aU|0,0,c[2433564]|0);c[R>>2]=0;aW=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aW&16383](D,M)|0;aW=c[R>>2]|0;L9401:do{if((aW|0)!=0){aV=0;while(1){if((aV|0)>=1024){break L9401}a2=9638528+(aV<<2)|0;if((c[a2>>2]|0)==0){break}else{aV=aV+1|0}}aV=gGq(aW)|0;c[a2>>2]=aV;if((aV|0)==0){break}gGz(aV|0,0,aW|0);do{if((c[3542200]|0)==0){a3=0}else{c[av>>2]=0;c[au>>2]=0;H=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[H&16383](y,M)|0;if((c[av>>2]|0)==0){a4=aU;a5=aV;a6=0}else{H=c[au>>2]|0;c[z>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](z,M,0)|0;if((H|0)<1){a3=0;break}if((gzL(aV,0,M)|0)==0){a4=aU;a5=aV;a6=0}else{a3=0;break}}while(1){H=a6+1|0;G=a4;c[G>>2]=c[G>>2]|c[9620648+((d[a5]|0)<<2)>>2];if((H|0)<65536){a4=a4+8|0;a5=a5+1|0;a6=H}else{break}}ay=aX+4194308|0;H=aV+65536|0;G=0;while(1){aT=G+1|0;N=ay;c[N>>2]=c[N>>2]|c[9620648+((d[H]|0)<<2)>>2];if((aT|0)<65536){ay=ay+8|0;H=H+1|0;G=aT}else{a7=0;break}}while(1){if((a7|0)>=1024){break L9401}a8=9638528+(a7<<2)|0;if((c[a8>>2]|0)==(aV|0)){break}else{a7=a7+1|0}}gGr(aV);c[a8>>2]=0;break L9401}}while(0);while(1){if((a3|0)>=1024){break L9401}a9=9638528+(a3<<2)|0;if((c[a9>>2]|0)==(aV|0)){break}else{a3=a3+1|0}}gGr(aV);c[a9>>2]=0}}while(0);aW=M+1|0;c[Q>>2]=0;G=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[G&16383](C,aW)|0;G=c[Q>>2]|0;L9426:do{if((G|0)!=0){H=0;while(1){if((H|0)>=1024){break L9426}ba=9638528+(H<<2)|0;if((c[ba>>2]|0)==0){break}else{H=H+1|0}}H=gGq(G)|0;c[ba>>2]=H;if((H|0)==0){break}gGz(H|0,0,G|0);do{if((c[3542200]|0)==0){bb=0}else{c[W>>2]=0;c[aw>>2]=0;aV=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aV&16383](w,aW)|0;if((c[W>>2]|0)==0){bc=aU;bd=H;be=0}else{aV=c[aw>>2]|0;c[x>>2]=9534384;ay=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ay&16383](x,aW,0)|0;if((aV|0)<1){bb=0;break}if((gzL(H,0,aW)|0)==0){bc=aU;bd=H;be=0}else{bb=0;break}}while(1){aV=be+1|0;ay=bc;c[ay>>2]=c[ay>>2]|c[9620648+((d[bd]|0)<<2)>>2]<<2;if((aV|0)<65536){bc=bc+8|0;bd=bd+1|0;be=aV}else{break}}aV=aX+4194308|0;ay=H+65536|0;aT=0;while(1){N=aT+1|0;aS=aV;c[aS>>2]=c[aS>>2]|c[9620648+((d[ay]|0)<<2)>>2]<<2;if((N|0)<65536){aV=aV+8|0;ay=ay+1|0;aT=N}else{bf=0;break}}while(1){if((bf|0)>=1024){break L9426}bg=9638528+(bf<<2)|0;if((c[bg>>2]|0)==(H|0)){break}else{bf=bf+1|0}}gGr(H);c[bg>>2]=0;break L9426}}while(0);while(1){if((bb|0)>=1024){break L9426}bh=9638528+(bb<<2)|0;if((c[bh>>2]|0)==(H|0)){break}else{bb=bb+1|0}}gGr(H);c[bh>>2]=0}}while(0);aW=M+2|0;c[T>>2]=0;G=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[G&16383](B,aW)|0;G=c[T>>2]|0;L9451:do{if((G|0)!=0){aT=0;while(1){if((aT|0)>=1024){break L9451}bi=9638528+(aT<<2)|0;if((c[bi>>2]|0)==0){break}else{aT=aT+1|0}}aT=gGq(G)|0;c[bi>>2]=aT;if((aT|0)==0){break}gGz(aT|0,0,G|0);do{if((c[3542200]|0)==0){bj=0}else{c[U>>2]=0;c[V>>2]=0;H=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[H&16383](u,aW)|0;if((c[U>>2]|0)==0){bk=aU;bl=aT;bm=0}else{H=c[V>>2]|0;c[v>>2]=9534384;ay=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ay&16383](v,aW,0)|0;if((H|0)<1){bj=0;break}if((gzL(aT,0,aW)|0)==0){bk=aU;bl=aT;bm=0}else{bj=0;break}}while(1){H=bm+1|0;ay=bk;c[ay>>2]=c[ay>>2]|c[9620648+((d[bl]|0)<<2)>>2]<<1;if((H|0)<65536){bk=bk+8|0;bl=bl+1|0;bm=H}else{break}}H=aX+4194308|0;ay=aT+65536|0;aV=0;while(1){N=aV+1|0;aS=H;c[aS>>2]=c[aS>>2]|c[9620648+((d[ay]|0)<<2)>>2]<<1;if((N|0)<65536){H=H+8|0;ay=ay+1|0;aV=N}else{bn=0;break}}while(1){if((bn|0)>=1024){break L9451}bo=9638528+(bn<<2)|0;if((c[bo>>2]|0)==(aT|0)){break}else{bn=bn+1|0}}gGr(aT);c[bo>>2]=0;break L9451}}while(0);while(1){if((bj|0)>=1024){break L9451}bp=9638528+(bj<<2)|0;if((c[bp>>2]|0)==(aT|0)){break}else{bj=bj+1|0}}gGr(aT);c[bp>>2]=0}}while(0);aW=M+3|0;c[X>>2]=0;G=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[G&16383](A,aW)|0;G=c[X>>2]|0;L9476:do{if((G|0)!=0){aV=0;while(1){if((aV|0)>=1024){break L9476}bq=9638528+(aV<<2)|0;if((c[bq>>2]|0)==0){break}else{aV=aV+1|0}}aV=gGq(G)|0;c[bq>>2]=aV;if((aV|0)==0){break}gGz(aV|0,0,G|0);do{if((c[3542200]|0)==0){br=0}else{c[a1>>2]=0;c[S>>2]=0;aT=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aT&16383](s,aW)|0;if((c[a1>>2]|0)==0){bs=aU;bt=aV;bu=0}else{aT=c[S>>2]|0;c[t>>2]=9534384;ay=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ay&16383](t,aW,0)|0;if((aT|0)<1){br=0;break}if((gzL(aV,0,aW)|0)==0){bs=aU;bt=aV;bu=0}else{br=0;break}}while(1){aT=bu+1|0;ay=bs;c[ay>>2]=c[ay>>2]|c[9620648+((d[bt]|0)<<2)>>2]<<3;if((aT|0)<65536){bs=bs+8|0;bt=bt+1|0;bu=aT}else{break}}aT=aX+4194308|0;ay=aV+65536|0;H=0;while(1){N=H+1|0;aS=aT;c[aS>>2]=c[aS>>2]|c[9620648+((d[ay]|0)<<2)>>2]<<3;if((N|0)<65536){aT=aT+8|0;ay=ay+1|0;H=N}else{bv=0;break}}while(1){if((bv|0)>=1024){break L9476}bw=9638528+(bv<<2)|0;if((c[bw>>2]|0)==(aV|0)){break}else{bv=bv+1|0}}gGr(aV);c[bw>>2]=0;break L9476}}while(0);while(1){if((br|0)>=1024){break L9476}bx=9638528+(br<<2)|0;if((c[bx>>2]|0)==(aV|0)){break}else{br=br+1|0}}gGr(aV);c[bx>>2]=0}}while(0);by=M+4|0;bz=c[$>>2]|0}else{by=M;bz=aa}if((bz&255|0)==9){aX=(c[3542028]|0)+4194304|0;gGz(aX|0,0,c[2433564]|0);VW(aX,by);bA=by+4|0;bB=c[$>>2]|0}else{bA=by;bB=bz}if((bB&255|0)==10){aX=(c[3542028]|0)+4194304|0;gGz(aX|0,0,c[2433564]|0);V_(aX,bA,0);V_(aX,bA+1|0,2);bC=bA+2|0;bD=c[$>>2]|0}else{bC=bA;bD=bB}if((bD&255|0)==11){aX=c[3542028]|0;aU=aX+4194304|0;gGz(aU|0,0,c[2433564]|0);c[aA>>2]=0;aW=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aW&16383](r,bC)|0;aW=c[aA>>2]|0;L9510:do{if((aW|0)!=0){G=0;while(1){if((G|0)>=1024){break L9510}bE=9638528+(G<<2)|0;if((c[bE>>2]|0)==0){break}else{G=G+1|0}}G=gGq(aW)|0;c[bE>>2]=G;if((G|0)==0){break}gGz(G|0,0,aW|0);do{if((c[3542200]|0)==0){bF=0}else{c[E>>2]=0;c[aY>>2]=0;aV=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aV&16383](m,bC)|0;if((c[E>>2]|0)!=0){aV=c[aY>>2]|0;c[n>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](n,bC,0)|0;if((aV|0)<1){bF=0;break}if((gzL(G,0,bC)|0)!=0){bF=0;break}}aV=aX+4194308|0;H=G;ay=0;while(1){aT=ay+1|0;N=aV;c[N>>2]=c[N>>2]|c[9620648+((d[H]|0)<<2)>>2];if((aT|0)<65536){aV=aV+8|0;H=H+1|0;ay=aT}else{break}}ay=aU;H=G+65536|0;aV=0;while(1){aT=aV+1|0;N=ay;c[N>>2]=c[N>>2]|c[9620648+((d[H]|0)<<2)>>2];if((aT|0)<65536){ay=ay+8|0;H=H+1|0;aV=aT}else{bG=0;break}}while(1){if((bG|0)>=1024){break L9510}bH=9638528+(bG<<2)|0;if((c[bH>>2]|0)==(G|0)){break}else{bG=bG+1|0}}gGr(G);c[bH>>2]=0;break L9510}}while(0);while(1){if((bF|0)>=1024){break L9510}bI=9638528+(bF<<2)|0;if((c[bI>>2]|0)==(G|0)){break}else{bF=bF+1|0}}gGr(G);c[bI>>2]=0}}while(0);aW=bC+1|0;c[a$>>2]=0;aa=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aa&16383](q,aW)|0;aa=c[a$>>2]|0;L9536:do{if((aa|0)!=0){aV=0;while(1){if((aV|0)>=1024){break L9536}bJ=9638528+(aV<<2)|0;if((c[bJ>>2]|0)==0){break}else{aV=aV+1|0}}aV=gGq(aa)|0;c[bJ>>2]=aV;if((aV|0)==0){break}gGz(aV|0,0,aa|0);do{if((c[3542200]|0)==0){bK=0}else{c[am>>2]=0;c[F>>2]=0;G=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[G&16383](k,aW)|0;if((c[am>>2]|0)!=0){G=c[F>>2]|0;c[l>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](l,aW,0)|0;if((G|0)<1){bK=0;break}if((gzL(aV,0,aW)|0)!=0){bK=0;break}}G=aX+4194308|0;H=aV;ay=0;while(1){aT=ay+1|0;N=G;c[N>>2]=c[N>>2]|c[9620648+((d[H]|0)<<2)>>2]<<2;if((aT|0)<65536){G=G+8|0;H=H+1|0;ay=aT}else{break}}ay=aU;H=aV+65536|0;G=0;while(1){aT=G+1|0;N=ay;c[N>>2]=c[N>>2]|c[9620648+((d[H]|0)<<2)>>2]<<2;if((aT|0)<65536){ay=ay+8|0;H=H+1|0;G=aT}else{bL=0;break}}while(1){if((bL|0)>=1024){break L9536}bM=9638528+(bL<<2)|0;if((c[bM>>2]|0)==(aV|0)){break}else{bL=bL+1|0}}gGr(aV);c[bM>>2]=0;break L9536}}while(0);while(1){if((bK|0)>=1024){break L9536}bN=9638528+(bK<<2)|0;if((c[bN>>2]|0)==(aV|0)){break}else{bK=bK+1|0}}gGr(aV);c[bN>>2]=0}}while(0);aW=bC+2|0;c[ac>>2]=0;aa=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aa&16383](p,aW)|0;aa=c[ac>>2]|0;L9562:do{if((aa|0)!=0){G=0;while(1){if((G|0)>=1024){break L9562}bO=9638528+(G<<2)|0;if((c[bO>>2]|0)==0){break}else{G=G+1|0}}G=gGq(aa)|0;c[bO>>2]=G;if((G|0)==0){break}gGz(G|0,0,aa|0);do{if((c[3542200]|0)==0){bP=0}else{c[a_>>2]=0;c[al>>2]=0;aV=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aV&16383](h,aW)|0;if((c[a_>>2]|0)!=0){aV=c[al>>2]|0;c[j>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](j,aW,0)|0;if((aV|0)<1){bP=0;break}if((gzL(G,0,aW)|0)!=0){bP=0;break}}aV=aX+4194308|0;H=G;ay=0;while(1){aT=ay+1|0;N=aV;c[N>>2]=c[N>>2]|c[9620648+((d[H]|0)<<2)>>2]<<1;if((aT|0)<65536){aV=aV+8|0;H=H+1|0;ay=aT}else{break}}ay=aU;H=G+65536|0;aV=0;while(1){aT=aV+1|0;N=ay;c[N>>2]=c[N>>2]|c[9620648+((d[H]|0)<<2)>>2]<<1;if((aT|0)<65536){ay=ay+8|0;H=H+1|0;aV=aT}else{bQ=0;break}}while(1){if((bQ|0)>=1024){break L9562}bR=9638528+(bQ<<2)|0;if((c[bR>>2]|0)==(G|0)){break}else{bQ=bQ+1|0}}gGr(G);c[bR>>2]=0;break L9562}}while(0);while(1){if((bP|0)>=1024){break L9562}bS=9638528+(bP<<2)|0;if((c[bS>>2]|0)==(G|0)){break}else{bP=bP+1|0}}gGr(G);c[bS>>2]=0}}while(0);aW=bC+3|0;c[az>>2]=0;aa=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aa&16383](o,aW)|0;aa=c[az>>2]|0;L9588:do{if((aa|0)!=0){aV=0;while(1){if((aV|0)>=1024){break L9588}bT=9638528+(aV<<2)|0;if((c[bT>>2]|0)==0){break}else{aV=aV+1|0}}aV=gGq(aa)|0;c[bT>>2]=aV;if((aV|0)==0){break}gGz(aV|0,0,aa|0);do{if((c[3542200]|0)==0){bU=0}else{c[aZ>>2]=0;c[a0>>2]=0;G=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[G&16383](f,aW)|0;if((c[aZ>>2]|0)!=0){G=c[a0>>2]|0;c[g>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](g,aW,0)|0;if((G|0)<1){bU=0;break}if((gzL(aV,0,aW)|0)!=0){bU=0;break}}G=aX+4194308|0;H=aV;ay=0;while(1){aT=ay+1|0;N=G;c[N>>2]=c[N>>2]|c[9620648+((d[H]|0)<<2)>>2]<<3;if((aT|0)<65536){G=G+8|0;H=H+1|0;ay=aT}else{break}}ay=aU;H=aV+65536|0;G=0;while(1){aT=G+1|0;N=ay;c[N>>2]=c[N>>2]|c[9620648+((d[H]|0)<<2)>>2]<<3;if((aT|0)<65536){ay=ay+8|0;H=H+1|0;G=aT}else{bV=0;break}}while(1){if((bV|0)>=1024){break L9588}bW=9638528+(bV<<2)|0;if((c[bW>>2]|0)==(aV|0)){break}else{bV=bV+1|0}}gGr(aV);c[bW>>2]=0;break L9588}}while(0);while(1){if((bU|0)>=1024){break L9588}bX=9638528+(bU<<2)|0;if((c[bX>>2]|0)==(aV|0)){break}else{bU=bU+1|0}}gGr(aV);c[bX>>2]=0}}while(0);bY=bC+4|0}else{bY=bC}M=bY+1|0;}while(M>>>0<((c[2427032]|0)+(c[2427232]|0)+(c[2433562]|0)+(c[2439240]|0)+(c[2432858]|0)+(c[2429366]|0)|0)>>>0);i=e;return}function asP(){var b=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;b=i;i=i+360|0;f=b|0;g=b+160|0;h=b+320|0;j=c[2385516]|0;c[2394732]=j;if((j|0)>64511){gGz(c[3531284]|0,0,172032);c[2394732]=0;k=0}else{k=j}c[3528532]=k+1;c[2385516]=k;k=c[2113258]|0;j=c[3541969]|0;l=c[3541970]|0;m=c[3541971]|0;n=0;do{o=e[(c[14167544+(n<<2)>>2]|0)+k>>1]|0;p=(o&j|0)==0?1:3;q=(l&o|0)==0?p:p|4;c[h+(n<<2)>>2]=((m&o|0)==0?q:q|8)&255;q=o>>>12&3;c[f+(n<<4)+12>>2]=q;p=o>>>10&3;r=f+(n<<4)+8|0;c[r>>2]=p;s=o>>>8&3;t=f+(n<<4)+4|0;c[t>>2]=s;u=o>>>6&3;v=f+(n<<4)|0;c[v>>2]=u;w=c[14167600+(n<<2)>>2]|0;x=d[w+4|0]|0;y=d[w+5|0]|0;c[g+(n<<4)+12>>2]=x>>>4&7;c[g+(n<<4)+8>>2]=x&7;c[g+(n<<4)+4>>2]=y>>>4&7;c[g+(n<<4)>>2]=0;if((q|0)==(p|0)){c[r>>2]=-1;z=-1}else{z=p}if((q|0)==(s|0)){c[t>>2]=-1;A=-1}else{A=s}if((z|0)==(A|0)){c[t>>2]=-1;B=-1}else{B=A}if((q|0)==(u|0)){c[v>>2]=-1;C=-1}else{C=u}if((z|0)==(C|0)){c[v>>2]=-1;D=-1}else{D=C}if((B|0)==(D|0)){c[v>>2]=-1;E=-1}else{E=D}do{if((q|0)==0){F=9999}else{v=g+(n<<4)+(q<<2)|0;u=c[v>>2]|0;if((u|0)<=9999){F=u;break}c[v>>2]=9999;F=9999}}while(0);do{if((z|0)>0){q=g+(n<<4)+(z<<2)|0;v=c[q>>2]|0;if((v|0)<=(F|0)){G=v;break}c[q>>2]=F;G=F}else{G=F}}while(0);do{if((B|0)>0){q=g+(n<<4)+(B<<2)|0;v=c[q>>2]|0;if((v|0)<=(G|0)){H=v;break}c[q>>2]=G;H=G}else{H=G}}while(0);do{if((E|0)>0){q=g+(n<<4)+(E<<2)|0;if((c[q>>2]|0)<=(H|0)){break}c[q>>2]=H}}while(0);n=n+1|0;if((n|0)>=10){break}}while((c[8452320+(n<<2)>>2]|0)!=0);c[2385802]=o;o=c[h>>2]&1;n=(o|0)==0;H=-1;E=0;while(1){G=H;B=0;while(1){F=8452320+(B<<2)|0;z=B+1|0;D=8452320+(z<<2)|0;C=h+(B<<2)|0;A=14167544+(B<<2)|0;if(n){m=0;while(1){l=c[f+(B<<4)+(m<<2)>>2]|0;do{if((c[g+(B<<4)+(l<<2)>>2]|0)==(E|0)){c[2113038]=c[F>>2];j=c[D>>2]|0;c[2113214]=(j|0)==0?224:j;if((l|0)==1){if((c[C>>2]&2|0)==0){break}j=c[A>>2]|0;k=c[2416]|0;q=(a[7462144]&(k|0)!=-1?k:e[j+2>>1]|0)<<8&16760832;if(!(q>>>0>9437183&(q+16384|0)>>>0<9633793)){break}k=(c[3541932]|0)+(q-9437184)|0;if((k|0)==0){break}q=(e[j+14>>1]|0)+16+(a[7461984]&1)|0;v=(e[j+12>>1]|0)+64+(c[3541966]|0)|0;j=c[3541884]|0;gp[j&16383](k,v,q)|0;break}else if((l|0)==2){if((c[C>>2]&4|0)==0){break}asU(B);if((c[3541872]|0)!=0){q=c[3541658]|0;gD[q&8191]()|0}c[3541872]=0;c[2113242]=0;c[2113240]=0;c[3541656]=0;break}else if((l|0)==3){if((c[C>>2]&8|0)==0){break}q=c[A>>2]|0;v=c[2418]|0;k=(a[7462144]&(v|0)!=-1?v:e[q+6>>1]|0)<<8&16760832;if(!(k>>>0>9437183&(k+16384|0)>>>0<9633793)){break}v=(c[3541932]|0)+(k-9437184)|0;if((v|0)==0){break}gp[c[3541882]&16383](v,(e[q+20>>1]|0)+64+(c[3541962]|0)|0,(e[q+22>>1]|0)+16+(a[7461968]&1)|0)|0;break}else{break}}}while(0);l=m+1|0;if((l|0)<4){m=l}else{I=G;break}}}else{m=G;l=0;while(1){q=c[f+(B<<4)+(l<<2)>>2]|0;do{if((c[g+(B<<4)+(q<<2)>>2]|0)==(E|0)){if((m|0)<(E|0)){v=c[3541952]|0;k=m+1|0;gA[v&16383](k,E)|0;J=E}else{J=m}c[2113038]=c[F>>2];k=c[D>>2]|0;c[2113214]=(k|0)==0?224:k;if((q|0)==2){if((c[C>>2]&4|0)==0){K=J;break}asU(B);if((c[3541872]|0)!=0){k=c[3541658]|0;gD[k&8191]()|0}c[3541872]=0;c[2113242]=0;c[2113240]=0;c[3541656]=0;K=J;break}else if((q|0)==3){if((c[C>>2]&8|0)==0){K=J;break}k=c[A>>2]|0;v=c[2418]|0;j=(a[7462144]&(v|0)!=-1?v:e[k+6>>1]|0)<<8&16760832;if(!(j>>>0>9437183&(j+16384|0)>>>0<9633793)){K=J;break}v=(c[3541932]|0)+(j-9437184)|0;if((v|0)==0){K=J;break}gp[c[3541882]&16383](v,(e[k+20>>1]|0)+64+(c[3541962]|0)|0,(e[k+22>>1]|0)+16+(a[7461968]&1)|0)|0;K=J;break}else if((q|0)==1){if((c[C>>2]&2|0)==0){K=J;break}k=c[A>>2]|0;v=c[2416]|0;j=(a[7462144]&(v|0)!=-1?v:e[k+2>>1]|0)<<8&16760832;if(!(j>>>0>9437183&(j+16384|0)>>>0<9633793)){K=J;break}v=(c[3541932]|0)+(j-9437184)|0;if((v|0)==0){K=J;break}gp[c[3541884]&16383](v,(e[k+12>>1]|0)+64+(c[3541966]|0)|0,(e[k+14>>1]|0)+16+(a[7461984]&1)|0)|0;K=J;break}else{K=J;break}}else{K=m}}while(0);q=l+1|0;if((q|0)<4){m=K;l=q}else{I=K;break}}}if((z|0)>=10){break}if((c[D>>2]|0)==0){break}else{G=I;B=z}}B=E+1|0;if((B|0)<8){H=I;E=B}else{break}}if(!((o|0)!=0&(I|0)<7)){i=b;return}gA[c[3541952]&16383](I+1|0,7)|0;i=b;return}function asQ(){var d=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;d=i;i=i+16|0;f=d|0;g=f|0;h=f;c[g>>2]=-1;c[g+4>>2]=-1;g=c[3541886]|0;j=e[g+(c[2113258]|0)>>1]|0;c[2385802]=j;k=(j&c[3541969]|0)==0?1:3;l=(c[3541970]&j|0)==0?k:k|4;k=(c[3541971]&j|0)==0?l:l|8;l=j>>>12&3;m=f;c[m>>2]=l;n=j>>>10&3;o=h+4|0;c[o>>2]=n;p=j>>>8&3;q=f+8|0;c[q>>2]=p;f=j>>>6&3;r=h+12|0;c[r>>2]=f;if(a[7462144]|0){s=c[2412]|0;c[m>>2]=s;m=c[2413]|0;c[o>>2]=m;t=c[2414]|0;c[q>>2]=t;u=c[2415]|0;c[r>>2]=u;v=(m|0)==-1?1:3;w=(t|0)==-1?v:v|4;x=(u|0)==-1?w:w|8;y=s;z=m;A=t;B=u}else{x=k;y=l;z=n;A=p;B=f}if((y|0)==(z|0)){c[o>>2]=-1;C=-1}else{C=z}if((y|0)==(A|0)){c[q>>2]=-1;D=-1}else{D=A}if((y|0)==(B|0)){c[r>>2]=-1;E=-1}else{E=B}if((C|0)==(D|0)){c[q>>2]=-1;F=-1}else{F=D}if((C|0)==(E|0)){c[r>>2]=-1;G=-1}else{G=E}if((F|0)==(G|0)){c[r>>2]=-1;H=-1}else{H=G}G=c[3541880]|0;r=(c[2113222]|0)>>>4&15;F=c[2112968]|0;E=c[2113300]|0;C=c[2113308]|0;D=c[3541942]|0;q=(C|0)>3;B=(C|0)==2;y=0;do{if((c[14167872+(y+4<<2)>>2]&j|0)!=0){A=y<<12;z=y<<2;o=(y<<9)+2048|0;f=g+(z+24)|0;p=g+(z+26)|0;z=0;do{n=a[G+(z+A)|0]|0;l=n&255;do{if(n<<24>>24!=15){k=((z>>8<<5)+448|l&31)-(e[f>>1]|0)&511;u=z+240-(e[p>>1]|0)&255;if(!(k>>>0<384&u>>>0<224)){break}t=ag(E,u)|0;u=(ag(C,k)|0)+t|0;t=F+u|0;k=c[D+((l>>>1&112|o|r)<<2)>>2]|0;if(q){c[t>>2]=k;break}if(B){b[t>>1]=k&65535;break}else{a[t]=k&255;a[F+(u+1)|0]=k>>>8&255;a[F+(u+2)|0]=k>>>16&255;break}}}while(0);z=z+1|0;}while((z|0)<4096)}y=y+1|0;}while((y|0)<2);asU(0);y=(x&1|0)==0;F=(x&2|0)==0;B=(x&4|0)==0;q=(x&8|0)==0;x=3;r=H;while(1){do{if((r|0)==0){if(!y){H=c[3541952]|0;gA[H&16383](0,7)|0}if(a[7462168]|0){break}a[9760]=1;H=c[h+(x+1<<2)>>2]|0;do{if((H|0)==1){if(F){break}D=c[3541886]|0;C=c[2416]|0;E=(a[7462144]&(C|0)!=-1?C:e[D+2>>1]|0)<<8&16760832;if(!(E>>>0>9437183&(E+16384|0)>>>0<9633793)){break}C=(c[3541932]|0)+(E-9437184)|0;if((C|0)==0){break}E=(e[D+14>>1]|0)+16+(a[7461984]&1)|0;G=(e[D+12>>1]|0)+64+(c[3541966]|0)|0;D=c[3541884]|0;gp[D&16383](C,G,E)|0}else if((H|0)==2){if(B|(c[3541872]|0)==0){break}gD[c[3541658]&8191]()|0}else if((H|0)==3){if(q){break}E=c[3541886]|0;G=c[2418]|0;C=(a[7462144]&(G|0)!=-1?G:e[E+6>>1]|0)<<8&16760832;if(!(C>>>0>9437183&(C+16384|0)>>>0<9633793)){break}G=(c[3541932]|0)+(C-9437184)|0;if((G|0)==0){break}gp[c[3541882]&16383](G,(e[E+20>>1]|0)+64+(c[3541962]|0)|0,(e[E+22>>1]|0)+16+(a[7461968]&1)|0)|0}}while(0);a[9760]=0}else if((r|0)==1){if(F){break}H=c[3541886]|0;E=c[2416]|0;G=(a[7462144]&(E|0)!=-1?E:e[H+2>>1]|0)<<8&16760832;if(!(G>>>0>9437183&(G+16384|0)>>>0<9633793)){break}E=(c[3541932]|0)+(G-9437184)|0;if((E|0)==0){break}gp[c[3541884]&16383](E,(e[H+12>>1]|0)+64+(c[3541966]|0)|0,(e[H+14>>1]|0)+16+(a[7461984]&1)|0)|0}else if((r|0)==2){if(B|(c[3541872]|0)==0){break}gD[c[3541658]&8191]()|0}else if((r|0)==3){if(q){break}H=c[3541886]|0;E=c[2418]|0;G=(a[7462144]&(E|0)!=-1?E:e[H+6>>1]|0)<<8&16760832;if(!(G>>>0>9437183&(G+16384|0)>>>0<9633793)){break}E=(c[3541932]|0)+(G-9437184)|0;if((E|0)==0){break}gp[c[3541882]&16383](E,(e[H+20>>1]|0)+64+(c[3541962]|0)|0,(e[H+22>>1]|0)+16+(a[7461968]&1)|0)|0}}while(0);H=x-1|0;if((x|0)<=0){break}x=H;r=c[h+(H<<2)>>2]|0}c[3541872]=0;c[2113242]=0;c[2113240]=0;c[3541656]=0;i=d;return}function asR(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;if((c[3542068]|0)!=1){gGz(c[2112968]|0,0,(c[2113308]|0)*86016|0|0);return}b=c[2113308]|0;if((b|0)==3){d=c[(c[3541942]|0)+12224>>2]|0;e=d>>>8&255;f=d>>>16&255;g=d&255;d=c[2112968]|0;h=0;while(1){a[d]=g;a[d+1|0]=e;a[d+2|0]=f;i=h+1|0;if((i|0)<86016){d=d+3|0;h=i}else{break}}return}else if((b|0)==4){h=c[(c[3541942]|0)+12224>>2]|0;d=0;f=c[2112968]|0;while(1){c[f>>2]=h;c[f+4>>2]=h;c[f+8>>2]=h;c[f+12>>2]=h;c[f+16>>2]=h;c[f+20>>2]=h;c[f+24>>2]=h;c[f+28>>2]=h;e=d+1|0;if((e|0)<10752){d=e;f=f+32|0}else{break}}return}else if((b|0)==2){b=c[(c[3541942]|0)+12224>>2]|0;f=b<<16|b;b=c[2112968]|0;d=0;while(1){c[b>>2]=f;c[b+4>>2]=f;c[b+8>>2]=f;c[b+12>>2]=f;c[b+16>>2]=f;c[b+20>>2]=f;c[b+24>>2]=f;c[b+28>>2]=f;h=d+1|0;if((h|0)<5376){b=b+32|0;d=h}else{break}}return}else{return}}function asS(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0;b=d[14167712]|0;f=c[2113308]|0;do{if((f|0)!=(c[2394744]|0)){if((f|0)==2){gGC(14166472,673416,128)|0;gGC(14166216,672216,128)|0;gGC(14166344,672344,128)|0;break}else if((f|0)==3){gGC(14166472,673288,128)|0;gGC(14166216,671960,128)|0;gGC(14166344,672088,128)|0;break}else if((f|0)==4){gGC(14166472,673160,128)|0;gGC(14166216,671704,128)|0;gGC(14166344,671832,128)|0;break}else{break}}}while(0);c[2394744]=f;f=a[64288]|0;g=f&1;do{if(f){h=(e[(c[3541926]|0)+10>>1]|0)<<8&16776192;if(!(h>>>0>9437183&(h+6144|0)>>>0<9633793)){i=g;break}j=(c[3541932]|0)+(h-9437184)|0;if((j|0)==0){i=g;break}h=c[3541898]|0;gGC(h|0,j|0,6144)|0;i=g}else{i=0}}while(0);if((i|b|0)==0){asR();k=c[3541960]|0;gu[k&16383]();a[14167712]=0;return}W9(c[3541898]|0);asR();k=c[3541960]|0;gu[k&16383]();a[14167712]=0;return}function asT(){var b=0,d=0;b=c[2113308]|0;do{if((b|0)!=(c[2394744]|0)){if((b|0)==3){gGC(14166472,673288,128)|0;gGC(14166216,671960,128)|0;gGC(14166344,672088,128)|0;break}else if((b|0)==4){gGC(14166472,673160,128)|0;gGC(14166216,671704,128)|0;gGC(14166344,671832,128)|0;break}else if((b|0)==2){gGC(14166472,673416,128)|0;gGC(14166216,672216,128)|0;gGC(14166344,672344,128)|0;break}else{break}}}while(0);c[2394744]=b;do{if(a[64288]|0){b=(e[(c[3541926]|0)+10>>1]|0)<<8&16776192;if(!(b>>>0>9437183&(b+6144|0)>>>0<9633793)){break}d=(c[3541932]|0)+(b-9437184)|0;if((d|0)==0){break}b=c[3541898]|0;gGC(b|0,d|0,6144)|0}}while(0);W9(c[3541898]|0);asR();gu[c[3541960]&16383]();a[14167712]=0;return 0}function asU(d){d=d|0;var f=0,g=0,h=0,i=0,j=0;f=c[14167544+(d<<2)>>2]|0;d=c[2417]|0;g=e[f+18>>1]|0;h=b[f+34>>1]|0;i=(a[7462144]&(d|0)!=-1?d:e[f+4>>1]|0)<<8;c[2113242]=(e[f+16>>1]|0)+64+(c[3541964]|0)&1023;c[2113240]=g+16+(a[7461976]&1)&1023;g=i&16760832;if(!(g>>>0>9437183&(g+16384|0)>>>0<9633793)){c[3541872]=0;return}i=c[3541932]|0;d=i+(g-9437184)|0;c[3541872]=d;if((d|0)==0){return}c[3541656]=0;if(!((h&1)==0|a[7462e3])){h=e[f+32>>1]|0;d=(e[f+8>>1]|0)<<8&16775168;if(d>>>0>9437183&(d+2048|0)>>>0<9633793){j=i+(d-9437184)|0}else{j=0}c[3541656]=j;c[2113244]=h+16}gD[c[3541660]&8191]()|0;return}function asV(a){a=a|0;var d=0,f=0,g=0;if((a|0)==8388611){d=~(b[4812957]&255);return d|0}else if((a|0)==8388610){a=e[4812957]|0;do{if((c[2406632]|0)==0){f=c[2443744]|0;if((f|0)<=0){g=8;break}c[2443744]=f-1;g=0}else{g=(c[2432962]|0)>>>((c[(c[2420380]|0)+4>>2]|0)>>>0)<<3&8}}while(0);d=((g|a)^247)&255;return d|0}else{d=0;return d|0}return 0}function asW(a,b){a=a|0;b=b|0;if((a|0)!=9437184){return}a=b&255;c[2415256]=a&8;b=a>>>1&1;c[3528406]=b^1;if((b|0)==0){c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2]}Tr(a>>>2&1);return}function asX(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;if((d|0)==3145728|(d|0)==3145730){f=(a[9775248]<<1|a[9541792])&255;return f|0}else if((d|0)==3145734){g=a[9541792]|0;h=a[9775248]<<1|g;a[9775248]=1;i=8452200+(c[2394]<<2)|0;do{if(g<<24>>24==0|(a[9542024]|0)==0){c[i>>2]=4097;c[2276080]=256;if((c[2276079]|0)>>>0>=256){break}RH(1)}else{c[i>>2]=0;c[2276080]=0}}while(0);f=h&255;return f|0}else if((d|0)==3145732){h=a[9775248]|0;i=h<<1|a[9541792];a[9541792]=1;do{if((a[9542024]|0)==0){j=4096;k=8168}else{g=h<<24>>24==0;if(g){j=g?4096:0;k=8168;break}c[8452200+(c[2394]<<2)>>2]=0;c[2276080]=0}}while(0);do{if((k|0)==8168){c[8452200+(c[2394]<<2)>>2]=j|1;c[2276080]=256;if((c[2276079]|0)>>>0>=256){break}RH(1)}}while(0);f=i&255;return f|0}else if((d|0)==8388608){f=~b[4812956];return f|0}else if((d|0)==8388610){i=e[4812957]|0;do{if((c[2406632]|0)==0){j=c[2443744]|0;if((j|0)<=0){l=2048;break}c[2443744]=j-1;l=0}else{l=(c[2432962]|0)>>>((c[(c[2420380]|0)+4>>2]|0)>>>0)<<11&2048}}while(0);f=((l|i)^63487)&65535;return f|0}else if((d|0)==3145838){d=c[2429484]|0;if((d|0)>(c[2430068]|0)){c[2429484]=0;c[2430068]=-1;f=0;return f|0}else{c[2429484]=d+1;f=c[9747840+(d<<2)>>2]&65535;return f|0}}else{f=0;return f|0}return 0}function asY(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0;if((b-3145738|0)>>>0<93|(b-3145834|0)>>>0<3|(b-3145732|0)>>>0<3){return}if((b|0)==3145730){c[2113278]=d&65535;return}else if((b|0)==3145728){c[2113282]=d&65535;return}else if((b|0)==3145838){c[3528938]=d&65535;c[2433332]=c[2433332]|12;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;e=c[2433530]|0;c[2433530]=e+12;if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){f=gfc(1024)|0;g=f;h=(c[2433530]|0)+f|0}else{g=1024;h=e+1036|0}c[2433530]=h;c[2444006]=(c[2444006]|0)+g;return}else if((b|0)==3145736){c[2113288]=d&65535;return}else if((b|0)==6291456){c[3542081]=d&65535;return}else if((b|0)==6291458){c[3542082]=d&65535;return}else if((b|0)==6291460){c[3542083]=d&65535;return}else if((b|0)==7340032){c[3542078]=d&65535;return}else if((b|0)==7340034){c[3542079]=d&65535;return}else if((b|0)==7340036){c[3542080]=d&65535;return}else if((b|0)==9437184){b=(d&65535)>>>8&65535;c[2415256]=b&8;d=b>>>1&1;c[3528406]=d^1;if((d|0)==0){c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2]}Tr(b>>>2&1);return}else{return}}function asZ(b,d){b=b|0;d=d|0;var f=0,g=0;f=b&65535^1;b=c[3542108]|0;a[b+f|0]=d;g=(c[3527514]|0)+(f<<1)|0;if((a[g]|0)==d<<24>>24){return}a[g]=d;d=e[b+(f&65534)>>1]|0;b=d>>>7&248;c[(c[3542106]|0)+(f>>>1<<2)>>2]=d>>>2<<8&63488|d&31|(b>>>5|b)<<3&2016;return}function as_(a,d){a=a|0;d=d|0;var e=0;e=a>>>1&32767;b[(c[3542108]|0)+(e<<1)>>1]=d;a=(c[3527514]|0)+(e<<1)|0;if((b[a>>1]|0)==d<<16>>16){return}b[a>>1]=d;a=d&65535;d=a>>>7&248;c[(c[3542106]|0)+(e<<2)>>2]=a>>>2<<8&63488|a&31|(d>>>5|d)<<3&2016;return}function as$(b){b=b|0;var d=0,e=0,f=0.0,g=0.0;d=b&255;if((d|0)==48){c[2433332]=c[2433332]|4;e=c[3528938]&255;return e|0}else if((d|0)==82){d=c[3541518]|0;b=d+296|0;f=+h[b>>3];do{if(f!=0.0){g=+h[6675];if(f-(g+ +gC[c[2429842]&255]())<=0.0){h[b>>3]=0.0;break}e=a[d+307|0]|-128;return e|0}}while(0);e=a[d+307|0]|0;return e|0}else{e=0;return e|0}return 0}function as0(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;switch(b&255|0){case 0:{b=d&7;a[14117504]=b;e=c[2411312]|0;f=c[9757320+(c[1836236]<<2)>>2]|0;g=((b&255)<<14)-16384|0;b=64;h=64;while(1){c[f+76+(h<<2)>>2]=e+(g+(h<<8));i=b+1&65535;if((i&65535)>127){j=64;k=64;break}else{b=i;h=i&65535}}while(1){h=e+(g+(k<<8))|0;c[f+76+(k+512<<2)>>2]=h;c[f+76+(k+768<<2)>>2]=h;h=j+1&65535;if((h&65535)>127){break}else{j=h;k=h&65535}}return};case 16:{k=c[2430068]|0;if((c[2429484]|0)>(k|0)){c[2430068]=-1;c[2429484]=0;l=-1}else{l=k}k=l+1|0;c[2430068]=k;c[9747840+(k<<2)>>2]=d&255;return};case 81:{lS(0,1,d);return};case 112:{Uv(0,d);return};case 116:{k=d&3;a[14109440]=k;l=(d&255)>>>4&3;a[14109416]=l;j=c[3541206]|0;f=c[2439444]|0;g=f+((k&255)<<17)|0;gGC(j|0,g|0,131072)|0;g=j+131072|0;j=f+((l&255)<<17)|0;gGC(g|0,j|0,131072)|0;return};case 80:{j=c[3541518]|0;g=j+256|0;a[j+304|0]=d;l=d&255;if((d&255)<16){c[14168912+((c[2383582]|0)*252|0)>>2]=l&15}if((d-45&255)>=3){return}if((l|0)==47){a[j+312|0]=0;m=0}else if((l|0)==45){d=j+312|0;f=a[d]|2;a[d]=f;m=f}else if((l|0)==0){a[j+312|0]=2;m=2}else if((l|0)==46){l=j+312|0;f=a[l]|1;a[l]=f;m=f}else{m=a[j+312|0]|0}j=m&3;m=c[7461744+(j<<2)>>2]|0;lI(g,m,m,c[7461728+(j<<2)>>2]|0);return};default:{return}}}function as1(a){a=a|0;return 0}function as2(a,b){a=a|0;b=b|0;return}function as3(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2606036+(b*112|0)>>2];c[a+104>>2]=c[2606040+(b*112|0)>>2];c[a+108>>2]=c[2606044+(b*112|0)>>2];d=0;return d|0}function as4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=2605936+(b*112|0);e=0;return e|0}function as5(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1086288+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function as6(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0;e=i;i=i+1080|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;c[2424]=5755;c[2426826]=0;c[2418162]=0;c[2411312]=1048576;c[3542098]=1179648;c[3542090]=9568256;c[3542091]=13762560;c[3541206]=17956864;c[2439444]=18219008;c[2388314]=18743296;c[2405728]=18743424;c[2418276]=18743424;c[2411358]=18808960;c[3542094]=18813056;c[3542095]=18845824;c[3542100]=18878592;c[3542108]=18944128;c[2411896]=19009664;z=0;while(1){if((z|0)>=1024){break}A=9638528+(z<<2)|0;if((c[A>>2]|0)==0){B=8304;break}else{z=z+1|0}}do{if((B|0)==8304){z=gGq(19009664)|0;c[A>>2]=z;if((z|0)==0){break}c[2426826]=z;gGz(z|0,0,19009664);c[2418162]=z;c[2411312]=z+1048576;c[3542098]=z+1179648;c[3542090]=z+9568256;c[3542091]=z+13762560;c[3541206]=z+17956864;c[2439444]=z+18219008;c[2388314]=z+18743296;C=z+18743424|0;c[2405728]=C;c[2418276]=C;c[2411358]=z+18808960;c[3542094]=z+18813056;c[3542095]=z+18845824;c[3542100]=z+18878592;c[3542108]=z+18944128;C=z+19009664|0;c[2411896]=C;c[2414448]=C;do{if((c[3542200]|0)!=0){C=x+108|0;c[C>>2]=0;D=x+100|0;c[D>>2]=0;E=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[E&16383](x,0)|0;if((c[C>>2]|0)==0){break}C=c[D>>2]|0;c[y>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](y,0,0)|0;if((C|0)<1){break}gzL(z,0,0)|0}}while(0);z=(c[2418162]|0)+524288|0;do{if((c[3542200]|0)!=0){C=v+108|0;c[C>>2]=0;D=v+100|0;c[D>>2]=0;E=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[E&16383](v,1)|0;if((c[C>>2]|0)==0){break}C=c[D>>2]|0;c[w>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](w,1,0)|0;if((C|0)<1){break}gzL(z,0,1)|0}}while(0);z=c[2411312]|0;do{if((c[3542200]|0)==0){F=0}else{C=t+108|0;c[C>>2]=0;D=t+100|0;c[D>>2]=0;E=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[E&16383](t,2)|0;if((c[C>>2]|0)==0){F=0;break}C=c[D>>2]|0;c[u>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](u,2,0)|0;if((C|0)<1){F=0;break}gzL(z,0,2)|0;F=0}}while(0);while(1){if((F|0)>=1024){G=0;break}H=9638528+(F<<2)|0;if((c[H>>2]|0)==0){B=8320;break}else{F=F+1|0}}do{if((B|0)==8320){z=gGq(4194304)|0;c[H>>2]=z;if((z|0)==0){G=0;break}gGz(z|0,0,4194304);G=z}}while(0);do{if((c[3542200]|0)!=0){z=r+108|0;c[z>>2]=0;C=r+100|0;c[C>>2]=0;D=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[D&16383](r,3)|0;if((c[z>>2]|0)==0){break}z=c[C>>2]|0;c[s>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](s,3,0)|0;if((z|0)<1){break}gzL(G,0,3)|0}}while(0);z=G+2097152|0;do{if((c[3542200]|0)!=0){C=p+108|0;c[C>>2]=0;D=p+100|0;c[D>>2]=0;E=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[E&16383](p,4)|0;if((c[C>>2]|0)==0){break}C=c[D>>2]|0;c[q>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](q,4,0)|0;if((C|0)<1){break}gzL(z,0,4)|0}}while(0);z=c[3542098]|0;C=0;while(1){a[z+(C^57224)|0]=a[G+(C>>>9<<18&262144|C&16285697|C>>>7<<17&131072|C>>>3<<16&65536|C>>>4<<14&16384|C>>>17<<13&8192|C>>>14<<12&4096|C>>>18<<11&2048|C>>>2<<10&1024|C>>>16<<9&512|C>>>5<<8&256|C>>>11<<7&128|C>>>8<<6&64|C>>>6<<5&32|C>>>13<<4&16|C>>>1<<3&8|C>>>10<<2&4|C>>>12<<1&2)|0]|0;D=C+1|0;if((D|0)<4194304){C=D}else{I=0;break}}while(1){if((I|0)>=1024){J=z;break}K=9638528+(I<<2)|0;if((c[K>>2]|0)==(G|0)){B=8334;break}else{I=I+1|0}}if((B|0)==8334){gGr(G);c[K>>2]=0;J=c[3542098]|0}z=J+4194303|0;C=J+8388606|0;D=0;while(1){a[C]=a[z]&15;a[C+1|0]=(d[z]|0)>>>4;E=D+1|0;if((E|0)<4194304){z=z-1|0;C=C-2|0;D=E}else{break}}D=c[3542090]|0;do{if((c[3542200]|0)!=0){C=n+108|0;c[C>>2]=0;z=n+100|0;c[z>>2]=0;E=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[E&16383](n,5)|0;if((c[C>>2]|0)==0){break}C=c[z>>2]|0;c[o>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](o,5,0)|0;if((C|0)<1){break}gzL(D,0,5)|0}}while(0);D=c[3542090]|0;C=D+2097151|0;z=D+4194302|0;D=0;while(1){a[z+1|0]=a[C]&15;a[z]=(d[C]|0)>>>4;E=D+1|0;if((E|0)<2097152){C=C-1|0;z=z-2|0;D=E}else{L=0;break}}while(1){if((L|0)>=1024){M=0;break}N=9638528+(L<<2)|0;if((c[N>>2]|0)==0){B=8345;break}else{L=L+1|0}}do{if((B|0)==8345){D=gGq(2097152)|0;c[N>>2]=D;if((D|0)==0){M=0;break}gGz(D|0,0,2097152);M=D}}while(0);do{if((c[3542200]|0)!=0){D=l+108|0;c[D>>2]=0;z=l+100|0;c[z>>2]=0;C=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[C&16383](l,6)|0;if((c[D>>2]|0)==0){break}D=c[z>>2]|0;c[m>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](m,6,0)|0;if((D|0)<1){break}gzL(M,0,6)|0}}while(0);D=c[3542091]|0;z=0;while(1){C=z<<1;E=M+C|0;O=C|1;P=M+O|0;a[D+O|0]=a[P]<<4|a[E]&15;a[D+C|0]=a[P]&-16|(d[E]|0)>>>4;E=z+1|0;if((E|0)<1048576){z=E}else{Q=0;break}}while(1){if((Q|0)>=1024){break}R=9638528+(Q<<2)|0;if((c[R>>2]|0)==(M|0)){B=8355;break}else{Q=Q+1|0}}if((B|0)==8355){gGr(M);c[R>>2]=0}z=c[2439444]|0;do{if((c[3542200]|0)!=0){D=j+108|0;c[D>>2]=0;E=j+100|0;c[E>>2]=0;P=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[P&16383](j,7)|0;if((c[D>>2]|0)==0){break}D=c[E>>2]|0;c[k>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](k,7,0)|0;if((D|0)<1){break}gzL(z,0,7)|0}}while(0);z=c[2388314]|0;do{if((c[3542200]|0)!=0){D=f+108|0;c[D>>2]=0;E=f+100|0;c[E>>2]=0;P=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[P&16383](f,8)|0;if((c[D>>2]|0)==0){break}D=c[E>>2]|0;c[g>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](g,8,0)|0;if((D|0)<1){break}gzL(z,0,8)|0}}while(0);fxU(0,425984);if((c[2394]|0)==0){S=c[2112932]|0}else{c[2394]=0;z=c[3532596]|0;c[2112932]=z;D=c[3532592]|0;if((D|0)!=0){gGC(9104152,D|0,280)|0}c[2113054]=c[2113060];S=z}z=c[2418162]|0;D=S|0;E=0;while(1){P=z+E|0;c[D>>2]=P;c[D+131072>>2]=P;P=E+1024|0;if(P>>>0>524287){break}else{D=D+4|0;E=P}}E=c[2418276]|0;D=S+4096|0;P=1048576;while(1){C=E+(P-1048576)|0;c[D>>2]=C;c[D+65536>>2]=C;c[D+131072>>2]=C;C=P+1024|0;if(C>>>0>1114111){break}else{D=D+4|0;P=C}}P=c[3542100]|0;D=S+8192|0;E=2097152;while(1){C=P+(E-2097152)|0;c[D>>2]=C;c[D+65536>>2]=C;c[D+131072>>2]=C;C=E+1024|0;if(C>>>0>2162687){break}else{D=D+4|0;E=C}}E=c[3542095]|0;D=E+16384|0;c[S+16384>>2]=D;c[S+81920>>2]=D;c[S+147456>>2]=D;P=E+17408|0;c[S+16388>>2]=P;c[S+81924>>2]=P;c[S+147460>>2]=P;C=E+18432|0;c[S+16392>>2]=C;c[S+81928>>2]=C;c[S+147464>>2]=C;O=E+19456|0;c[S+16396>>2]=O;c[S+81932>>2]=O;c[S+147468>>2]=O;T=E+20480|0;c[S+16400>>2]=T;c[S+81936>>2]=T;c[S+147472>>2]=T;U=E+21504|0;c[S+16404>>2]=U;c[S+81940>>2]=U;c[S+147476>>2]=U;V=E+22528|0;c[S+16408>>2]=V;c[S+81944>>2]=V;c[S+147480>>2]=V;W=E+23552|0;c[S+16412>>2]=W;c[S+81948>>2]=W;c[S+147484>>2]=W;X=E+24576|0;c[S+16416>>2]=X;c[S+81952>>2]=X;c[S+147488>>2]=X;Y=E+25600|0;c[S+16420>>2]=Y;c[S+81956>>2]=Y;c[S+147492>>2]=Y;Z=E+26624|0;c[S+16424>>2]=Z;c[S+81960>>2]=Z;c[S+147496>>2]=Z;_=E+27648|0;c[S+16428>>2]=_;c[S+81964>>2]=_;c[S+147500>>2]=_;$=E+28672|0;c[S+16432>>2]=$;c[S+81968>>2]=$;c[S+147504>>2]=$;aa=E+29696|0;c[S+16436>>2]=aa;c[S+81972>>2]=aa;c[S+147508>>2]=aa;ab=E+30720|0;c[S+16440>>2]=ab;c[S+81976>>2]=ab;c[S+147512>>2]=ab;ac=E+31744|0;c[S+16444>>2]=ac;c[S+81980>>2]=ac;c[S+147516>>2]=ac;c[S+16448>>2]=D;c[S+81984>>2]=D;c[S+147520>>2]=D;c[S+16452>>2]=P;c[S+81988>>2]=P;c[S+147524>>2]=P;c[S+16456>>2]=C;c[S+81992>>2]=C;c[S+147528>>2]=C;c[S+16460>>2]=O;c[S+81996>>2]=O;c[S+147532>>2]=O;c[S+16464>>2]=T;c[S+82e3>>2]=T;c[S+147536>>2]=T;c[S+16468>>2]=U;c[S+82004>>2]=U;c[S+147540>>2]=U;c[S+16472>>2]=V;c[S+82008>>2]=V;c[S+147544>>2]=V;c[S+16476>>2]=W;c[S+82012>>2]=W;c[S+147548>>2]=W;c[S+16480>>2]=X;c[S+82016>>2]=X;c[S+147552>>2]=X;c[S+16484>>2]=Y;c[S+82020>>2]=Y;c[S+147556>>2]=Y;c[S+16488>>2]=Z;c[S+82024>>2]=Z;c[S+147560>>2]=Z;c[S+16492>>2]=_;c[S+82028>>2]=_;c[S+147564>>2]=_;c[S+16496>>2]=$;c[S+82032>>2]=$;c[S+147568>>2]=$;c[S+16500>>2]=aa;c[S+82036>>2]=aa;c[S+147572>>2]=aa;c[S+16504>>2]=ab;c[S+82040>>2]=ab;c[S+147576>>2]=ab;c[S+16508>>2]=ac;c[S+82044>>2]=ac;c[S+147580>>2]=ac;ac=c[3542094]|0;ab=ac+16384|0;c[S+20480>>2]=ab;c[S+86016>>2]=ab;c[S+151552>>2]=ab;aa=ac+17408|0;c[S+20484>>2]=aa;c[S+86020>>2]=aa;c[S+151556>>2]=aa;$=ac+18432|0;c[S+20488>>2]=$;c[S+86024>>2]=$;c[S+151560>>2]=$;_=ac+19456|0;c[S+20492>>2]=_;c[S+86028>>2]=_;c[S+151564>>2]=_;Z=ac+20480|0;c[S+20496>>2]=Z;c[S+86032>>2]=Z;c[S+151568>>2]=Z;Y=ac+21504|0;c[S+20500>>2]=Y;c[S+86036>>2]=Y;c[S+151572>>2]=Y;X=ac+22528|0;c[S+20504>>2]=X;c[S+86040>>2]=X;c[S+151576>>2]=X;W=ac+23552|0;c[S+20508>>2]=W;c[S+86044>>2]=W;c[S+151580>>2]=W;V=ac+24576|0;c[S+20512>>2]=V;c[S+86048>>2]=V;c[S+151584>>2]=V;U=ac+25600|0;c[S+20516>>2]=U;c[S+86052>>2]=U;c[S+151588>>2]=U;T=ac+26624|0;c[S+20520>>2]=T;c[S+86056>>2]=T;c[S+151592>>2]=T;O=ac+27648|0;c[S+20524>>2]=O;c[S+86060>>2]=O;c[S+151596>>2]=O;C=ac+28672|0;c[S+20528>>2]=C;c[S+86064>>2]=C;c[S+151600>>2]=C;P=ac+29696|0;c[S+20532>>2]=P;c[S+86068>>2]=P;c[S+151604>>2]=P;D=ac+30720|0;c[S+20536>>2]=D;c[S+86072>>2]=D;c[S+151608>>2]=D;E=ac+31744|0;c[S+20540>>2]=E;c[S+86076>>2]=E;c[S+151612>>2]=E;c[S+20544>>2]=ab;c[S+86080>>2]=ab;c[S+151616>>2]=ab;c[S+20548>>2]=aa;c[S+86084>>2]=aa;c[S+151620>>2]=aa;c[S+20552>>2]=$;c[S+86088>>2]=$;c[S+151624>>2]=$;c[S+20556>>2]=_;c[S+86092>>2]=_;c[S+151628>>2]=_;c[S+20560>>2]=Z;c[S+86096>>2]=Z;c[S+151632>>2]=Z;c[S+20564>>2]=Y;c[S+86100>>2]=Y;c[S+151636>>2]=Y;c[S+20568>>2]=X;c[S+86104>>2]=X;c[S+151640>>2]=X;c[S+20572>>2]=W;c[S+86108>>2]=W;c[S+151644>>2]=W;c[S+20576>>2]=V;c[S+86112>>2]=V;c[S+151648>>2]=V;c[S+20580>>2]=U;c[S+86116>>2]=U;c[S+151652>>2]=U;c[S+20584>>2]=T;c[S+86120>>2]=T;c[S+151656>>2]=T;c[S+20588>>2]=O;c[S+86124>>2]=O;c[S+151660>>2]=O;c[S+20592>>2]=C;c[S+86128>>2]=C;c[S+151664>>2]=C;c[S+20596>>2]=P;c[S+86132>>2]=P;c[S+151668>>2]=P;c[S+20600>>2]=D;c[S+86136>>2]=D;c[S+151672>>2]=D;c[S+20604>>2]=E;c[S+86140>>2]=E;c[S+151676>>2]=E;E=c[3542108]|0;c[S+49280>>2]=E;c[S+114816>>2]=E;c[S+180352>>2]=E;D=E+1024|0;c[S+49284>>2]=D;c[S+114820>>2]=D;c[S+180356>>2]=D;D=S+49288|0;P=12617728;while(1){C=E+(P-12582912)|0;c[D>>2]=C;c[D+131072>>2]=C;C=P+1024|0;if(C>>>0>12648447){break}else{D=D+4|0;P=C}}c[S+114824>>2]=1;c[S+114828>>2]=1;c[S+114832>>2]=1;c[S+114836>>2]=1;c[S+114840>>2]=1;c[S+114844>>2]=1;c[S+114848>>2]=1;c[S+114852>>2]=1;c[S+114856>>2]=1;c[S+114860>>2]=1;c[S+114864>>2]=1;c[S+114868>>2]=1;c[S+114872>>2]=1;c[S+114876>>2]=1;c[S+114880>>2]=1;c[S+114884>>2]=1;c[S+114888>>2]=1;c[S+114892>>2]=1;c[S+114896>>2]=1;c[S+114900>>2]=1;c[S+114904>>2]=1;c[S+114908>>2]=1;c[S+114912>>2]=1;c[S+114916>>2]=1;c[S+114920>>2]=1;c[S+114924>>2]=1;c[S+114928>>2]=1;c[S+114932>>2]=1;c[S+114936>>2]=1;c[S+114940>>2]=1;P=S+53248|0;D=13631488;while(1){E=z+(D-13107200)|0;c[P>>2]=E;c[P+131072>>2]=E;E=D+1024|0;if(E>>>0>14155775){break}else{P=P+4|0;D=E}}c[S+196608>>2]=752;c[S+196648>>2]=172;c[S+196688>>2]=2344;c[S+196728>>2]=2750;c[S+196732>>2]=402;c[S+196652>>2]=2604;D=c[3532592]|0;if((D|0)!=0){gGC(D|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);D=c[2439330]|0;P=(D|0)==0;if(!P){z=D;gGC(9706056,z|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];z=c[3528484]|0;c[2076596]=z;E=c[2417276]|0;c[3541536]=E;c[1836236]=0;c[D+4172>>2]=896;c[D+4176>>2]=3330;c[D+4180>>2]=1742;c[D+4184>>2]=936;C=c[2411312]|0;O=0;T=0;while(1){c[D+76+(T<<2)>>2]=C+(T<<8);U=O+1&65535;if((U&65535)>63){ad=0;ae=0;break}else{O=U;T=U&65535}}while(1){T=C+(ae<<8)|0;c[D+76+(ae+512<<2)>>2]=T;c[D+76+(ae+768<<2)>>2]=T;T=ad+1&65535;if((T&65535)>63){af=64;ag=64;break}else{ad=T;ae=T&65535}}while(1){c[D+76+(ag<<2)>>2]=C+(ag<<8);T=af+1&65535;if((T&65535)>127){ah=64;ai=64;break}else{af=T;ag=T&65535}}while(1){T=C+(ai<<8)|0;c[D+76+(ai+512<<2)>>2]=T;c[D+76+(ai+768<<2)>>2]=T;T=ah+1&65535;if((T&65535)>127){break}else{ah=T;ai=T&65535}}C=c[2411358]|0;c[D+844>>2]=C;T=C+256|0;c[D+848>>2]=T;O=C+512|0;c[D+852>>2]=O;U=C+768|0;c[D+856>>2]=U;V=C+1024|0;c[D+860>>2]=V;W=C+1280|0;c[D+864>>2]=W;X=C+1536|0;c[D+868>>2]=X;Y=C+1792|0;c[D+872>>2]=Y;c[D+1868>>2]=C;c[D+1872>>2]=T;c[D+1876>>2]=O;c[D+1880>>2]=U;c[D+1884>>2]=V;c[D+1888>>2]=W;c[D+1892>>2]=X;c[D+1896>>2]=Y;c[D+2892>>2]=C;c[D+3916>>2]=C;c[D+2896>>2]=T;c[D+3920>>2]=T;c[D+2900>>2]=O;c[D+3924>>2]=O;c[D+2904>>2]=U;c[D+3928>>2]=U;c[D+2908>>2]=V;c[D+3932>>2]=V;c[D+2912>>2]=W;c[D+3936>>2]=W;c[D+2916>>2]=X;c[D+3940>>2]=X;c[D+2920>>2]=Y;c[D+3944>>2]=Y;Y=C+2048|0;c[D+1068>>2]=Y;X=C+2304|0;c[D+1072>>2]=X;W=C+2560|0;c[D+1076>>2]=W;V=C+2816|0;c[D+1080>>2]=V;U=C+3072|0;c[D+1084>>2]=U;O=C+3328|0;c[D+1088>>2]=O;T=C+3584|0;c[D+1092>>2]=T;Z=C+3840|0;c[D+1096>>2]=Z;c[D+2092>>2]=Y;c[D+2096>>2]=X;c[D+2100>>2]=W;c[D+2104>>2]=V;c[D+2108>>2]=U;c[D+2112>>2]=O;c[D+2116>>2]=T;c[D+2120>>2]=Z;c[D+3116>>2]=Y;c[D+4140>>2]=Y;c[D+3120>>2]=X;c[D+4144>>2]=X;c[D+3124>>2]=W;c[D+4148>>2]=W;c[D+3128>>2]=V;c[D+4152>>2]=V;c[D+3132>>2]=U;c[D+4156>>2]=U;c[D+3136>>2]=O;c[D+4160>>2]=O;c[D+3140>>2]=T;c[D+4164>>2]=T;c[D+3144>>2]=Z;c[D+4168>>2]=Z;if(!P){Z=D;gGC(Z|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=z;c[2417276]=E;c[1836236]=-1;Z=0;while(1){if((Z|0)>=1024){aj=0;break}ak=9638528+(Z<<2)|0;if((c[ak>>2]|0)==0){B=8393;break}else{Z=Z+1|0}}do{if((B|0)==8393){Z=gGq(131072)|0;c[ak>>2]=Z;if((Z|0)==0){aj=0;break}gGz(Z|0,0,131072);aj=Z}}while(0);c[3542106]=aj;gGz(aj|0,0,131072);Z=0;while(1){if((Z|0)>=1024){al=0;break}am=9638528+(Z<<2)|0;if((c[am>>2]|0)==0){B=8398;break}else{Z=Z+1|0}}do{if((B|0)==8398){Z=gGq(65536)|0;c[am>>2]=Z;if((Z|0)==0){al=0;break}gGz(Z|0,0,65536);al=Z}}while(0);c[3527514]=al;gGz(al|0,0,65536);c[2112966]=c[3542106];c[3542078]=0;c[3542079]=0;c[3542080]=16;c[3542081]=0;c[3542082]=0;c[3542083]=16;c[3542084]=0;c[3542085]=0;c[3542086]=16;c[3542087]=0;c[3542088]=0;c[3542089]=16;c[2113284]=0;Z=c[642608+(c[2436]<<2)>>2]|0;if((c[Z+52>>2]&4|0)==0){E=c[Z+128>>2]|0;c[2113280]=E;an=Z+132|0;ao=E}else{E=c[Z+132>>2]|0;c[2113280]=E;an=Z+128|0;ao=E}E=c[an>>2]|0;c[2113276]=E;c[2406716]=ao-8;c[2394778]=ao-16;c[2406714]=E-8;c[2394776]=E-16;c[3528974]=c[3564288+(((ao|0)!=320)<<2)>>2];auH(2,8388608);axI(0,4194304,8,0);axI(1,4194304,6,17408);Vr(1,4e6,1860,302,70,0);c[2438228]=4e6;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=511;h[745419]=.6;a[3203368]=1;h[745418]=.2;a[3203360]=1;h[745417]=.2;a[3203352]=1;h[745416]=.2;a[3203344]=1;E=c[3541206]|0;Z=c[2439444]|0;gGC(E|0,Z|0,262144)|0;Ux(0,8e3,1);c[2407030]=512;c[2407068]=3;Tq(690336);if(!(a[1040128]|0)){Z=c[2388314]|0;gGC(14100392,Z|0,128)|0}a[7072816]=1;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];Z=c[3532592]|0;if((Z|0)!=0){gGC(9104152,Z|0,280)|0}c[2113054]=c[2113060]}RI();c[2113056]=1e4;Z=RG(1e4)|0;c[2113054]=(c[2113054]|0)+Z;c[2276108]=-1;c[2113056]=-1;RI();Z=c[2394]|0;E=c[14130368+(Z<<2)>>2]|0;if((E|0)!=0){gGC(E|0,9104152,280)|0}c[8452240+(Z<<2)>>2]=c[2113054];c[2394]=-1;Z=c[2439330]|0;E=(Z|0)==0;if(!E){z=Z;gGC(9706056,z|0,76)|0}z=c[2438118]|0;c[2433530]=z;D=c[3528484]|0;c[2076596]=D;P=c[2417276]|0;c[3541536]=P;c[1836236]=0;gGz(9706056,0,76);if(!E){E=Z;gGC(E|0,9706056,76)|0}c[2438118]=z;c[3528484]=D;c[2417276]=P;c[1836236]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){P=0;do{lN(P);mB(P);P=P+1|0;}while((P|0)<(c[2385508]|0))}c[2113156]=0;a[9628264]=0;c[2407033]=0;P=c[3541206]|0;c[3541190]=P;c[3541198]=P;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=P+256;c[3541199]=P+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=P+512;c[3541200]=P+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=P+768;c[3541201]=P+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];a[9541792]=1;a[9542024]=1;a[9775248]=1;a[14117504]=0;a[14109440]=0;a[14109416]=0;c[3528938]=0;c[2433332]=12;gGz(9747840,0,192);c[2429484]=0;c[2430068]=-1;ap=0;i=e;return ap|0}}while(0);c[2426826]=0;ap=1;i=e;return ap|0}function as7(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;i=i+128|0;d=b|0;e=c[c[642608+(c[2436]<<2)>>2]>>2]|0;be(d|0,128,179600,(f=i,i=i+24|0,c[f>>2]=9374064,c[f+8>>2]=47,c[f+16>>2]=e,f)|0)|0;i=f;a[1040128]=0;f=c[2420380]|0;e=c[f>>2]|0;g=c[f+4>>2]|0;f=fw(d|0,389440)|0;if((f|0)!=0){d=g>>3<<e&1023;cj(14100392,d|0,1,f|0)|0;aY(f|0)|0}Uw(0);axH();f=c[2443764]|0;d=0;while(1){if((d|0)>=1024){break}h=9638528+(d<<2)|0;if((c[h>>2]|0)==(f|0)){j=8426;break}else{d=d+1|0}}if((j|0)==8426){gGr(f);c[h>>2]=0}c[2443764]=0;h=c[2394718]|0;f=0;while(1){if((f|0)>=1024){break}k=9638528+(f<<2)|0;if((c[k>>2]|0)==(h|0)){j=8430;break}else{f=f+1|0}}if((j|0)==8430){gGr(h);c[k>>2]=0}c[2394718]=0;a[7462192]=0;k=c[3542106]|0;h=0;while(1){if((h|0)>=1024){break}l=9638528+(h<<2)|0;if((c[l>>2]|0)==(k|0)){j=8434;break}else{h=h+1|0}}if((j|0)==8434){gGr(k);c[l>>2]=0}c[3542106]=0;l=c[3527514]|0;k=0;while(1){if((k|0)>=1024){break}m=9638528+(k<<2)|0;if((c[m>>2]|0)==(l|0)){j=8438;break}else{k=k+1|0}}if((j|0)==8438){gGr(l);c[m>>2]=0}c[3527514]=0;if((c[2392]|0)>=0){m=0;do{l=14130368+(m<<2)|0;k=c[l>>2]|0;if((k|0)!=0){gGr(k);c[l>>2]=0}l=14130384+(m<<2)|0;k=c[l>>2]|0;if((k|0)!=0){gGr(k);c[l>>2]=0}m=m+1|0;}while((m|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;fwZ();m=c[3541518]|0;if((m|0)!=0){gGr(m|0);c[3541518]=0}if((c[2385508]|0)>0){c[2113008]=0;c[2076598]=0;c[2383582]=0}c[2438228]=0;c[2433526]=0;c[2406676]=0;c[3528472]=0;m=c[2406680]|0;if((m|0)!=0){gGr(m);c[2406680]=0}c[2385508]=0;c[2432978]=0;a[64240]=0;c[3528938]=0;a[14117504]=0;a[14109440]=0;a[14109416]=0;m=c[2426826]|0;l=0;while(1){if((l|0)>=1024){j=8456;break}n=9638528+(l<<2)|0;if((c[n>>2]|0)==(m|0)){break}else{l=l+1|0}}if((j|0)==8456){c[2426826]=0;i=b;return 0}gGr(m);c[n>>2]=0;c[2426826]=0;i=b;return 0}function as8(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;if((a[9625128]|0)!=0){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();c[2113056]=1e4;d=RG(1e4)|0;c[2113054]=(c[2113054]|0)+d;c[2276108]=-1;c[2113056]=-1;RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=i;c[1836236]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){i=0;do{lN(i);mB(i);i=i+1|0;}while((i|0)<(c[2385508]|0))}c[2113156]=0;a[9628264]=0;c[2407033]=0;i=c[3541206]|0;c[3541190]=i;c[3541198]=i;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=i+256;c[3541199]=i+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=i+512;c[3541200]=i+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=i+768;c[3541201]=i+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];a[9541792]=1;a[9542024]=1;a[9775248]=1;a[14117504]=0;a[14109440]=0;a[14109416]=0;c[3528938]=0;c[2433332]=12;gGz(9747840,0,192);c[2429484]=0;c[2430068]=-1}b[4812956]=0;b[4812957]=0;i=0;g=0;f=0;do{g=((a[9634480+i|0]&1)<<i|g&65535)&65535;f=((a[9632240+i|0]&1)<<i|f&65535)&65535;i=i+1|0;}while((i|0)<10);b[4812956]=g;b[4812957]=f;if((g&3)==3){i=g&-4;b[4812956]=i;j=i}else{j=g}if((j&12)==12){b[4812956]=j&-13}if((f&3)==3){j=f&-4;b[4812957]=j;k=j}else{k=f}if((k&12)==12){b[4812957]=k&-13}k=c[2392]|0;if((k|0)>=0){gGz(8452240,0,((k|0)>0?(k<<2)+4|0:4)|0)}c[2113054]=0;k=c[2385548]|0;if((k|0)>0){gGz(9752472,0,((k|0)>1?k<<2:4)|0)}c[2433530]=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];k=c[3532592]|0;if((k|0)!=0){gGC(9104152,k|0,280)|0}c[2113054]=c[2113060]}k=c[2439330]|0;if((k|0)!=0){f=k;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;f=c[2438]|0;k=gGU(f,(f|0)<0|0?-1:0,16e6,0)|0;f=~~((+(k>>>0)+ +(K|0)*4294967296.0)/14732.965009208103);c[2440562]=f;a[6518176]=1;c[2444006]=0;c[2444058]=0;k=f-~~(+(f*12|0|0)/271.5)|0;a[9627184]=0;j=1;g=f;f=1;while(1){i=(ag(j,g)|0)/80|0;do{if(f&(i|0)>(k|0)){e=c[2444058]|0;if((e|0)<(k|0)){d=k-e|0;c[2113056]=d;e=RG(d)|0;c[2113054]=(c[2113054]|0)+e;c[2276108]=-1;c[2113056]=-1;c[2444058]=(c[2444058]|0)+e}e=c[2112968]|0;do{if((e|0)!=0){if((a[14168416]|0)==0){l=c[3542106]|0}else{d=c[3527514]|0;m=c[3542106]|0;n=(c[3542108]|0)+34816|0;o=0;while(1){p=(o<<8)+17408|0;q=0;r=n;s=d+(p<<1)|0;t=m+(p<<2)|0;while(1){p=b[r>>1]|0;b[s>>1]=p;u=p&65535;p=u>>>7&248;c[t>>2]=u>>>2<<8&63488|u&31|(p>>>5|p)<<3&2016;p=q+1|0;if((p|0)<256){q=p;r=r+2|0;s=s+2|0;t=t+4|0}else{break}}t=o+1|0;if((t|0)<12){n=n+512|0;o=t}else{break}}a[14168416]=1;l=m}avg(64);o=c[l+64512>>2]|0;do{if((o|0)==0){gGz(e|0,0,ag(c[2113280]<<1,c[2113276]|0)|0)}else{n=o<<16|o;d=ag(c[2113276]|0,c[2113280]|0)|0;if((d|0)<=15){break}t=e;s=(d|0)/16|0;while(1){c[t>>2]=n;c[t+4>>2]=n;c[t+8>>2]=n;c[t+12>>2]=n;c[t+16>>2]=n;c[t+20>>2]=n;c[t+24>>2]=n;c[t+28>>2]=n;d=s-1|0;if((d|0)>0){t=t+32|0;s=d}else{break}}}}while(0);if(!(a[7072816]|0)){break}axE(1)}}while(0);e=c[3542102]|0;gD[e&8191]()|0;e=c[2113288]|0;c[2113288]=c[2113286];c[2113286]=e&255;a[9627184]=1;a[9541792]=0;a[9775248]=0;c[8452200+(c[2394]<<2)>>2]=4097;c[2276080]=256;if((c[2276079]|0)>>>0>=256){break}RH(1)}}while(0);e=i-(c[2444058]|0)|0;c[2113056]=e;o=RG(e)|0;c[2113054]=(c[2113054]|0)+o;c[2276108]=-1;c[2113056]=-1;c[2444058]=(c[2444058]|0)+o;Sb(ag(a[6518176]|0?868:0,j)|0);o=j+1|0;if((o|0)>=81){break}j=o;g=c[2440562]|0;f=(a[9627184]&1)==0}f=c[2394]|0;g=c[14130368+(f<<2)>>2]|0;if((g|0)!=0){gGC(g|0,9104152,280)|0}c[8452240+(f<<2)>>2]=c[2113054];c[2394]=-1;f=a[6518176]|0?69504:0;g=gGU(f,0,2048e6,0)|0;j=c[2438228]|0;l=gGS(g,K,j,(j|0)<0|0?-1:0)|0;j=l;Sb(f);f=c[2443830]|0;if((f|0)<1073676288){c[2443830]=f-j}f=c[2443831]|0;if((f|0)<1073676288){c[2443831]=f-j}f=(c[3528512]|0)-j|0;c[3528512]=(f|0)<0?0:f;f=c[2112964]|0;if((f|0)!=0){gg[c[3542122]&4095](f,a[9688]|0?534:0);Uu(0,c[2112964]|0,a[9688]|0?534:0)}f=c[1836236]|0;j=c[9757320+(f<<2)>>2]|0;if((j|0)==0){v=c[2433530]|0;w=9752472+(f<<2)|0;c[w>>2]=v;x=c[2076596]|0;y=14113936+(f<<2)|0;c[y>>2]=x;z=c[3541536]|0;A=9669104+(f<<2)|0;c[A>>2]=z;c[1836236]=-1;return 0}l=j;gGC(l|0,9706056,76)|0;v=c[2433530]|0;w=9752472+(f<<2)|0;c[w>>2]=v;x=c[2076596]|0;y=14113936+(f<<2)|0;c[y>>2]=x;z=c[3541536]|0;A=9669104+(f<<2)|0;c[A>>2]=z;c[1836236]=-1;return 0}function as9(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((a[14168416]|0)==0){d=c[3542106]|0}else{e=c[3527514]|0;f=c[3542106]|0;g=(c[3542108]|0)+34816|0;h=0;while(1){i=(h<<8)+17408|0;j=0;k=g;l=e+(i<<1)|0;m=f+(i<<2)|0;while(1){i=b[k>>1]|0;b[l>>1]=i;n=i&65535;i=n>>>7&248;c[m>>2]=n>>>2<<8&63488|n&31|(i>>>5|i)<<3&2016;i=j+1|0;if((i|0)<256){j=i;k=k+2|0;l=l+2|0;m=m+4|0}else{break}}m=h+1|0;if((m|0)<12){g=g+512|0;h=m}else{break}}a[14168416]=1;d=f}avg(64);f=c[d+64512>>2]|0;d=c[2112968]|0;do{if((f|0)==0){gGz(d|0,0,ag(c[2113280]<<1,c[2113276]|0)|0)}else{h=f<<16|f;g=ag(c[2113276]|0,c[2113280]|0)|0;if((g|0)<=15){break}e=d;m=(g|0)/16|0;while(1){c[e>>2]=h;c[e+4>>2]=h;c[e+8>>2]=h;c[e+12>>2]=h;c[e+16>>2]=h;c[e+20>>2]=h;c[e+24>>2]=h;c[e+28>>2]=h;g=m-1|0;if((g|0)>0){e=e+32|0;m=g}else{break}}}}while(0);if(!(a[7072816]|0)){return 0}axE(1);return 0}function ata(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;g=i;i=i+208|0;h=g|0;j=g+16|0;k=g+32|0;l=g+48|0;m=g+64|0;n=g+80|0;o=g+96|0;p=g+112|0;q=g+128|0;r=g+144|0;s=g+160|0;t=g+176|0;u=g+192|0;if((f|0)!=0){c[f>>2]=133378}Ts(e,f);if((e&96|0)==0){i=g;return 0}gGz(u|0,0,12);v=c[2405728]|0;c[u>>2]=v;c[u+4>>2]=(c[2411896]|0)-v;c[u+12>>2]=219592;gj[c[2076592]&4095](u)|0;u=k|0;do{if((e&64|0)!=0){gGz(j|0,0,16);c[2394]=-1;if((c[2392]|0)<0){break}v=k+9|0;w=h;x=h|0;y=h+4|0;z=h+12|0;A=j|0;B=j+4|0;C=j+12|0;D=0;do{gGC(u|0,614896,11)|0;a[v]=D+48&255;E=8452256+(D<<2)|0;gGz(w|0,0,12);c[x>>2]=E;c[y>>2]=4;c[z>>2]=164976;gj[c[2076592]&4095](h)|0;if((c[E>>2]|0)!=0){c[A>>2]=c[14130368+(D<<2)>>2];c[B>>2]=c[8452184+(D<<2)>>2];c[C>>2]=u;E=c[2076592]|0;gj[E&4095](j)|0}D=D+1|0;}while((D|0)<=(c[2392]|0))}}while(0);fw$(e);Vx(e,f);Ut(0);gGz(t|0,0,12);c[t>>2]=9541792;c[t+4>>2]=1;c[t+12>>2]=148144;gj[c[2076592]&4095](t)|0;gGz(s|0,0,12);c[s>>2]=9542024;c[s+4>>2]=1;c[s+12>>2]=118544;gj[c[2076592]&4095](s)|0;gGz(r|0,0,12);c[r>>2]=9775248;c[r+4>>2]=1;c[r+12>>2]=93520;gj[c[2076592]&4095](r)|0;gGz(q|0,0,12);c[q>>2]=9627184;c[q+4>>2]=1;c[q+12>>2]=490464;gj[c[2076592]&4095](q)|0;ayc();gGz(p|0,0,12);c[p>>2]=9625912;c[p+4>>2]=4;c[p+12>>2]=215728;gj[c[2076592]&4095](p)|0;gGz(o|0,0,12);c[o>>2]=14115752;c[o+4>>2]=4;c[o+12>>2]=361464;gj[c[2076592]&4095](o)|0;gGz(n|0,0,12);c[n>>2]=14117504;c[n+4>>2]=1;c[n+12>>2]=435944;gj[c[2076592]&4095](n)|0;gGz(m|0,0,12);c[m>>2]=14109440;c[m+4>>2]=1;c[m+12>>2]=533728;gj[c[2076592]&4095](m)|0;gGz(l|0,0,12);c[l>>2]=14109416;c[l+4>>2]=1;c[l+12>>2]=520224;gj[c[2076592]&4095](l)|0;if((e&2|0)==0){i=g;return 0}e=c[2439330]|0;l=(e|0)==0;if(!l){m=e;gGC(9706056,m|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];m=c[3528484]|0;c[2076596]=m;n=c[2417276]|0;c[3541536]=n;c[1836236]=0;o=c[2411312]|0;p=((d[14117504]|0)<<14)-16384|0;q=64;r=64;while(1){c[e+76+(r<<2)>>2]=o+(p+(r<<8));s=q+1&65535;if((s&65535)>127){F=64;G=64;break}else{q=s;r=s&65535}}while(1){r=o+(p+(G<<8))|0;c[e+76+(G+512<<2)>>2]=r;c[e+76+(G+768<<2)>>2]=r;r=F+1&65535;if((r&65535)>127){break}else{F=r;G=r&65535}}if(!l){l=e;gGC(l|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=m;c[2417276]=n;c[1836236]=-1;n=c[3541206]|0;m=c[2439444]|0;l=m+((d[14109440]|0)<<17)|0;gGC(n|0,l|0,131072)|0;l=n+131072|0;n=m+((d[14109416]|0)<<17)|0;gGC(l|0,n|0,131072)|0;a[14168416]=1;i=g;return 0}function atb(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1500084+(b*112|0)>>2];c[a+104>>2]=c[1500088+(b*112|0)>>2];c[a+108>>2]=c[1500092+(b*112|0)>>2];d=0;return d|0}function atc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=1499984+(b*112|0);e=0;return e|0}function atd(b,c){b=b|0;c=c|0;a[9706117]=c&1;return}function ate(a){a=a|0;var b=0,d=0;b=(c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,4e6,0)|0;return a|0}function atf(){return+(+((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)/4.0e6)}function atg(d){d=d|0;var f=0,g=0,h=0,i=0,j=0;if((d|0)==6291460|(d|0)==6291461){f=a[9775240]|0;g=f<<1|a[9541784];a[9541784]=1;h=(a[9542016]|0)==0|f<<24>>24==0;a[9775680]=h&1;f=8452200+(c[2394]<<2)|0;if(!h){c[f>>2]=0;c[2276080]=0;i=g;return i|0}c[f>>2]=4097;c[2276080]=256;if((c[2276079]|0)>>>0>=256){i=g;return i|0}RH(1);i=g;return i|0}else if((d|0)==6291456|(d|0)==6291457|(d|0)==6291458|(d|0)==6291459){i=a[9775240]<<1|a[9541784];return i|0}else if((d|0)==3145731){g=c[2113010]|0;c[2113010]=0;c[2430402]=0;f=c[3531294]|0;if((f|0)!=0){gf[f&2047](0)}i=g&255;return i|0}else if((d|0)==6291462|(d|0)==6291463){g=a[9541784]|0;f=a[9775240]<<1|g;a[9775240]=1;h=g<<24>>24==0|(a[9542016]|0)==0;a[9775680]=h&1;g=8452200+(c[2394]<<2)|0;if(!h){c[g>>2]=0;c[2276080]=0;i=f;return i|0}c[g>>2]=4097;c[2276080]=256;if((c[2276079]|0)>>>0>=256){i=f;return i|0}RH(1);i=f;return i|0}else if((d|0)==9437184){i=((e[4812892]|0)>>>8^255)&255;return i|0}else if((d|0)==9437185){i=~(b[4812892]&255);return i|0}else if((d|0)==9437186){f=(e[4812893]|0)>>>8;do{if((c[2406632]|0)==0){g=c[2443744]|0;if((g|0)<=0){j=8;break}c[2443744]=g-1;j=0}else{j=(c[2432962]|0)>>>((c[(c[2420380]|0)+4>>2]|0)>>>0)<<3&8}}while(0);i=((j|f)^247)&255;return i|0}else if((d|0)==9437187){i=~(b[4812893]&255);return i|0}else{i=0;return i|0}return 0}function ath(d){d=d|0;var f=0,g=0,h=0,i=0,j=0;if((d|0)==6291460){f=a[9775240]|0;g=f<<24>>24<<1|a[9541784];a[9541784]=1;h=(a[9542016]|0)==0|f<<24>>24==0;a[9775680]=h&1;f=8452200+(c[2394]<<2)|0;if(!h){c[f>>2]=0;c[2276080]=0;i=g;return i|0}c[f>>2]=4097;c[2276080]=256;if((c[2276079]|0)>>>0>=256){i=g;return i|0}RH(1);i=g;return i|0}else if((d|0)==6291456|(d|0)==6291458){i=a[9775240]<<1|a[9541784];return i|0}else if((d|0)==3145730){g=c[2113010]|0;c[2113010]=0;c[2430402]=0;f=c[3531294]|0;if((f|0)!=0){gf[f&2047](0)}i=g&65535;return i|0}else if((d|0)==6291462){g=a[9541784]|0;f=a[9775240]<<1|g<<24>>24;a[9775240]=1;h=g<<24>>24==0|(a[9542016]|0)==0;a[9775680]=h&1;g=8452200+(c[2394]<<2)|0;if(!h){c[g>>2]=0;c[2276080]=0;i=f;return i|0}c[g>>2]=4097;c[2276080]=256;if((c[2276079]|0)>>>0>=256){i=f;return i|0}RH(1);i=f;return i|0}else if((d|0)==9437184){i=~b[4812892];return i|0}else if((d|0)==9437186){d=e[4812893]|0;do{if((c[2406632]|0)==0){f=c[2443744]|0;if((f|0)<=0){j=2048;break}c[2443744]=f-1;j=0}else{j=(c[2432962]|0)>>>((c[(c[2420380]|0)+4>>2]|0)>>>0)<<11&2048}}while(0);i=((j|d)^63487)&65535;return i|0}else{i=0;return i|0}return 0}function ati(a,b){a=a|0;b=b|0;if((a|0)==3145729){c[2113012]=b&255;return}else if((a|0)==3145731){Ui(b);return}else if((a|0)==10485760){a=b&255;c[2415256]=a&8;b=a>>>1&1;c[3528406]=b^1;if((b|0)==0){c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2]}Tr(a>>>2&1);return}else{return}}function atj(a,b){a=a|0;b=b|0;if((a|0)==3145728){c[2113012]=b&255;return}else if((a|0)==7340034){c[3542079]=b&65535;return}else if((a|0)==6291456){c[2113282]=b&65535;return}else if((a|0)==7340032){c[3542078]=b&65535;return}else if((a|0)==6291464){gD[c[3542102]&8191]()|0;c[2113288]=b&65535;return}else if((a|0)==6291458){c[2113278]=b&65535;return}else if((a|0)==3145730){Ui(b&255);return}else if((a|0)==7340036){c[3542080]=b&65535;return}else if((a|0)==10485760){a=(b&65535)>>>8&65535;c[2415256]=a&8;b=a>>>1&1;c[3528406]=b^1;if((b|0)==0){c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2]}Tr(a>>>2&1);return}else{return}}function atk(b,d){b=b|0;d=d|0;var f=0,g=0;f=b&65535^1;b=c[3542108]|0;a[b+f|0]=d;g=(c[3527514]|0)+(f<<1)|0;if((a[g]|0)==d<<24>>24){return}a[g]=d;d=e[b+(f&65534)>>1]|0;b=d>>>7&248;c[(c[3542106]|0)+(f>>>1<<2)>>2]=d>>>2<<8&63488|d&31|(b>>>5|b)<<3&2016;return}function atl(a,d){a=a|0;d=d|0;var e=0;e=a>>>1&32767;b[(c[3542108]|0)+(e<<1)>>1]=d;a=(c[3527514]|0)+(e<<1)|0;if((b[a>>1]|0)==d<<16>>16){return}b[a>>1]=d;a=d&65535;d=a>>>7&248;c[(c[3542106]|0)+(e<<2)>>2]=a>>>2<<8&63488|a&31|(d>>>5|d)<<3&2016;return}function atm(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>5){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5635988+(b*112|0)>>2];c[a+104>>2]=c[5635992+(b*112|0)>>2];c[a+108>>2]=c[5635996+(b*112|0)>>2];d=0;return d|0}function atn(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<6&(d|0)==0)){e=1;return e|0}c[a>>2]=5635888+(b*112|0);e=0;return e|0}function ato(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=2104472+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function atp(){var b=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;b=i;i=i+480|0;e=b|0;f=b+112|0;g=b+120|0;j=b+232|0;k=b+240|0;l=b+352|0;m=b+360|0;n=b+472|0;c[2424]=5755;c[2426748]=0;c[2418160]=0;c[3542098]=1048576;c[3542090]=9437184;c[3531292]=13631488;c[2440004]=15728640;c[2405676]=15728768;c[2418274]=15728768;c[3542094]=15794304;c[3542100]=15827072;c[3542108]=15892608;c[2411712]=15958144;o=0;while(1){if((o|0)>=1024){break}p=9638528+(o<<2)|0;if((c[p>>2]|0)==0){q=8714;break}else{o=o+1|0}}do{if((q|0)==8714){o=gGq(15958144)|0;c[p>>2]=o;if((o|0)==0){break}c[2426748]=o;gGz(o|0,0,15958144);c[2418160]=o;c[3542098]=o+1048576;c[3542090]=o+9437184;c[3531292]=o+13631488;c[2440004]=o+15728640;r=o+15728768|0;c[2405676]=r;c[2418274]=r;c[3542094]=o+15794304;c[3542100]=o+15827072;c[3542108]=o+15892608;r=o+15958144|0;c[2411712]=r;c[2414254]=r;R6(o,1,2)|0;o=(c[2418160]|0)+1|0;R6(o,0,2)|0;o=c[3542098]|0;do{if((c[3542200]|0)!=0){r=m+108|0;c[r>>2]=0;s=m+100|0;c[s>>2]=0;t=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[t&16383](m,2)|0;if((c[r>>2]|0)==0){break}r=c[s>>2]|0;c[n>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](n,2,0)|0;if((r|0)<1){break}gzL(o,0,2)|0}}while(0);o=c[3542098]|0;r=o+4194303|0;s=o+8388606|0;o=0;while(1){a[s]=a[r]&15;a[s+1|0]=(d[r]|0)>>>4;t=o+1|0;if((t|0)<4194304){r=r-1|0;s=s-2|0;o=t}else{break}}o=c[3542090]|0;do{if((c[3542200]|0)!=0){s=k+108|0;c[s>>2]=0;r=k+100|0;c[r>>2]=0;t=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[t&16383](k,3)|0;if((c[s>>2]|0)==0){break}s=c[r>>2]|0;c[l>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](l,3,0)|0;if((s|0)<1){break}gzL(o,0,3)|0}}while(0);o=0;s=c[3542090]|0;while(1){r=a[s]|0;t=s+1|0;u=a[t]|0;a[t]=u<<4|r&15;a[s]=u&-16|(r&255)>>>4;r=o+1|0;if((r|0)<2097152){o=r;s=s+2|0}else{break}}s=c[3531292]|0;do{if((c[3542200]|0)!=0){o=g+108|0;c[o>>2]=0;r=g+100|0;c[r>>2]=0;u=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[u&16383](g,4)|0;if((c[o>>2]|0)==0){break}o=c[r>>2]|0;c[j>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](j,4,0)|0;if((o|0)<1){break}gzL(s,0,4)|0}}while(0);s=c[2440004]|0;do{if((c[3542200]|0)!=0){o=e+108|0;c[o>>2]=0;r=e+100|0;c[r>>2]=0;u=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[u&16383](e,5)|0;if((c[o>>2]|0)==0){break}o=c[r>>2]|0;c[f>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](f,5,0)|0;if((o|0)<1){break}gzL(s,0,5)|0}}while(0);Tq(690296);if(!(a[1040128]|0)){s=c[2440004]|0;gGC(14100392,s|0,128)|0}fxU(0,425984);if((c[2394]|0)==0){v=c[2112932]|0}else{c[2394]=0;s=c[3532596]|0;c[2112932]=s;o=c[3532592]|0;if((o|0)!=0){gGC(9104152,o|0,280)|0}c[2113054]=c[2113060];v=s}s=c[2418160]|0;o=v|0;r=0;while(1){u=s+r|0;c[o>>2]=u;c[o+131072>>2]=u;u=r+1024|0;if(u>>>0>1048575){break}else{o=o+4|0;r=u}}r=c[2418274]|0;o=v+4096|0;s=1048576;while(1){u=r+(s-1048576)|0;c[o>>2]=u;c[o+65536>>2]=u;c[o+131072>>2]=u;u=s+1024|0;if(u>>>0>1114111){break}else{o=o+4|0;s=u}}s=c[3542100]|0;o=v+16384|0;r=4194304;while(1){u=s+(r-4194304)|0;c[o>>2]=u;c[o+65536>>2]=u;c[o+131072>>2]=u;u=r+1024|0;if(u>>>0>4259839){break}else{o=o+4|0;r=u}}r=c[3542094]|0;o=v+20480|0;s=5242880;while(1){u=r+(s-5242880)|0;c[o>>2]=u;c[o+65536>>2]=u;c[o+131072>>2]=u;u=s+1024|0;if(u>>>0>5275647){break}else{o=o+4|0;s=u}}s=c[3542108]|0;o=v+32768|0;r=o;u=8388608;while(1){t=s+(u-8388608)|0;c[r>>2]=t;c[r+131072>>2]=t;t=u+1024|0;if(t>>>0>8454143){w=o;x=8388608;break}else{r=r+4|0;u=t}}while(1){c[w+65536>>2]=1;u=x+1024|0;if(u>>>0>8454143){break}else{w=w+4|0;x=u}}c[v+196688>>2]=26;c[v+196608>>2]=3398;c[v+196728>>2]=1960;c[v+196648>>2]=2662;c[v+196732>>2]=2654;c[v+196652>>2]=420;u=c[3532592]|0;if((u|0)!=0){gGC(u|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;c[2113290]=1;u=0;while(1){if((u|0)>=1024){y=0;break}z=9638528+(u<<2)|0;if((c[z>>2]|0)==0){q=8759;break}else{u=u+1|0}}do{if((q|0)==8759){u=gGq(131072)|0;c[z>>2]=u;if((u|0)==0){y=0;break}gGz(u|0,0,131072);y=u}}while(0);c[3542106]=y;gGz(y|0,0,131072);u=0;while(1){if((u|0)>=1024){A=0;break}B=9638528+(u<<2)|0;if((c[B>>2]|0)==0){q=8764;break}else{u=u+1|0}}do{if((q|0)==8764){u=gGq(65536)|0;c[B>>2]=u;if((u|0)==0){A=0;break}gGz(u|0,0,65536);A=u}}while(0);c[3527514]=A;gGz(A|0,0,65536);c[2112966]=c[3542106];c[3542078]=0;c[3542079]=0;c[3542080]=16;c[3542081]=0;c[3542082]=0;c[3542083]=16;c[3542084]=0;c[3542085]=0;c[3542086]=16;c[3542087]=0;c[3542088]=0;c[3542089]=16;c[2113284]=0;u=c[642608+(c[2436]<<2)>>2]|0;if((c[u+52>>2]&4|0)==0){r=c[u+128>>2]|0;c[2113280]=r;C=u+132|0;D=r}else{r=c[u+132>>2]|0;c[2113280]=r;C=u+128|0;D=r}r=c[C>>2]|0;c[2113276]=r;c[2406716]=D-8;c[2394778]=D-16;c[2406714]=r-8;c[2394776]=r-16;c[3528974]=c[3564288+(((D|0)!=320)<<2)>>2];auH(1,8388608);axI(0,4194304,8,16384);Uf(16934400,1156);h[607287]=1.0;c[2433116]=1;h[607286]=1.0;c[2433114]=2;a[7072808]=1;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];r=c[3532592]|0;if((r|0)!=0){gGC(9104152,r|0,280)|0}c[2113054]=c[2113060]}RI();r=c[2394]|0;u=c[14130368+(r<<2)>>2]|0;if((u|0)!=0){gGC(u|0,9104152,280)|0}c[8452240+(r<<2)>>2]=c[2113054];c[2394]=-1;c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];gGz(14125184,0,668);c[2433532]=0;c[2430402]=0;c[2113010]=0;a[9753304]=0;c[2433552]=0;gGz(c[2430036]|0,0,16384);c[3531316]=4;gGz(c[2430037]|0,0,16384);c[3531337]=4;gGz(c[2430038]|0,0,16384);c[3531358]=4;gGz(c[2430039]|0,0,16384);c[3531379]=4;gGz(c[2430040]|0,0,16384);c[3531400]=4;gGz(c[2430041]|0,0,16384);c[3531421]=4;gGz(c[2430042]|0,0,16384);c[3531442]=4;gGz(c[2430043]|0,0,16384);c[3531463]=4;a[9541784]=1;a[9542016]=1;a[9775240]=1;a[9775680]=0;E=0;i=b;return E|0}}while(0);c[2426748]=0;E=1;i=b;return E|0}function atq(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;i=i+128|0;d=c[2406694]|0;if((d|0)!=0){gGr(d);c[2406694]=0}c[3531294]=0;d=b|0;e=c[c[642608+(c[2436]<<2)>>2]>>2]|0;be(d|0,128,179600,(f=i,i=i+24|0,c[f>>2]=9374064,c[f+8>>2]=47,c[f+16>>2]=e,f)|0)|0;i=f;a[1040128]=0;f=c[2420380]|0;e=c[f>>2]|0;g=c[f+4>>2]|0;f=fw(d|0,389440)|0;if((f|0)!=0){d=g>>3<<e&1023;cj(14100392,d|0,1,f|0)|0;aY(f|0)|0}axH();f=c[2443764]|0;d=0;while(1){if((d|0)>=1024){break}h=9638528+(d<<2)|0;if((c[h>>2]|0)==(f|0)){j=8786;break}else{d=d+1|0}}if((j|0)==8786){gGr(f);c[h>>2]=0}c[2443764]=0;h=c[2394718]|0;f=0;while(1){if((f|0)>=1024){break}k=9638528+(f<<2)|0;if((c[k>>2]|0)==(h|0)){j=8790;break}else{f=f+1|0}}if((j|0)==8790){gGr(h);c[k>>2]=0}c[2394718]=0;a[7462192]=0;k=c[3542106]|0;h=0;while(1){if((h|0)>=1024){break}l=9638528+(h<<2)|0;if((c[l>>2]|0)==(k|0)){j=8794;break}else{h=h+1|0}}if((j|0)==8794){gGr(k);c[l>>2]=0}c[3542106]=0;l=c[3527514]|0;k=0;while(1){if((k|0)>=1024){break}m=9638528+(k<<2)|0;if((c[m>>2]|0)==(l|0)){j=8798;break}else{k=k+1|0}}if((j|0)==8798){gGr(l);c[m>>2]=0}c[3527514]=0;if((c[2392]|0)>=0){m=0;do{l=14130368+(m<<2)|0;k=c[l>>2]|0;if((k|0)!=0){gGr(k);c[l>>2]=0}l=14130384+(m<<2)|0;k=c[l>>2]|0;if((k|0)!=0){gGr(k);c[l>>2]=0}m=m+1|0;}while((m|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;m=c[2426748]|0;l=0;while(1){if((l|0)>=1024){j=8810;break}n=9638528+(l<<2)|0;if((c[n>>2]|0)==(m|0)){break}else{l=l+1|0}}if((j|0)==8810){c[2426748]=0;i=b;return 0}gGr(m);c[n>>2]=0;c[2426748]=0;i=b;return 0}function atr(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;if((a[9624384]|0)!=0){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];gGz(14125184,0,668);c[2433532]=0;c[2430402]=0;c[2113010]=0;a[9753304]=0;c[2433552]=0;gGz(c[2430036]|0,0,16384);c[3531316]=4;gGz(c[2430037]|0,0,16384);c[3531337]=4;gGz(c[2430038]|0,0,16384);c[3531358]=4;gGz(c[2430039]|0,0,16384);c[3531379]=4;gGz(c[2430040]|0,0,16384);c[3531400]=4;gGz(c[2430041]|0,0,16384);c[3531421]=4;gGz(c[2430042]|0,0,16384);c[3531442]=4;gGz(c[2430043]|0,0,16384);c[3531463]=4;a[9541784]=1;a[9542016]=1;a[9775240]=1;a[9775680]=0}b[4812892]=0;b[4812893]=0;d=0;e=0;f=0;do{e=((a[9633792+d|0]&1)<<d|e&65535)&65535;f=((a[9631592+d|0]&1)<<d|f&65535)&65535;d=d+1|0;}while((d|0)<16);b[4812892]=e;b[4812893]=f;if((e&3)==3){d=e&-4;b[4812892]=d;g=d}else{g=e}if((g&12)==12){b[4812892]=g&-13}if((f&3)==3){g=f&-4;b[4812893]=g;h=g}else{h=f}if((h&12)==12){b[4812893]=h&-13}h=c[2392]|0;if((h|0)>=0){gGz(8452240,0,((h|0)>0?(h<<2)+4|0:4)|0)}c[2113054]=0;h=c[2438]|0;f=gGU(h,(h|0)<0|0?-1:0,16e6,0)|0;h=~~((+(f>>>0)+ +(K|0)*4294967296.0)/14732.965009208103);c[2440540]=h;c[2444094]=0;f=h-~~(+(h*12|0|0)/271.5)|0;a[9627176]=0;if((c[2394]|0)==0){i=1;j=0}else{c[2394]=0;c[2112932]=c[3532596];h=c[3532592]|0;if((h|0)!=0){gGC(9104152,h|0,280)|0}c[2113054]=c[2113060];i=1;j=0}while(1){h=c[2112964]|0;if((i&1|0)==0&(h|0)!=0){g=(ag(a[9688]|0?534:0,i)|0)/8|0;Ug(h+(j<<1<<1)|0,g-j|0);k=g}else{k=j}a[7024784]=0;g=(ag(c[2440540]|0,i)|0)/8|0;if((a[9627176]&1)==0&(g|0)>(f|0)){h=c[2444094]|0;if((h|0)<(f|0)){e=f-h|0;c[2113056]=e;h=RG(e)|0;c[2113054]=(c[2113054]|0)+h;c[2276108]=-1;c[2113056]=-1;e=9776376+(a[7024784]<<31>>31<<2)|0;c[e>>2]=(c[e>>2]|0)+h}h=c[2112968]|0;do{if((h|0)!=0){if((a[14168416]|0)==0){l=c[3542106]|0}else{e=c[3527514]|0;d=c[3542106]|0;m=c[3542108]|0;n=0;while(1){o=n<<8;p=0;q=m;r=e+(o<<1)|0;s=d+(o<<2)|0;while(1){o=b[q>>1]|0;b[r>>1]=o;t=o&65535;o=t>>>7&248;c[s>>2]=t>>>2<<8&63488|t&31|(o>>>5|o)<<3&2016;o=p+1|0;if((o|0)<256){p=o;q=q+2|0;r=r+2|0;s=s+4|0}else{break}}s=n+1|0;if((s|0)<128){m=m+512|0;n=s}else{break}}a[14168416]=0;l=d}n=c[l+130048>>2]|0;do{if((n|0)==0){gGz(h|0,0,ag(c[2113280]<<1,c[2113276]|0)|0)}else{m=n<<16|n;e=ag(c[2113276]|0,c[2113280]|0)|0;if((e|0)<=15){break}s=h;r=(e|0)/16|0;while(1){c[s>>2]=m;c[s+4>>2]=m;c[s+8>>2]=m;c[s+12>>2]=m;c[s+16>>2]=m;c[s+20>>2]=m;c[s+24>>2]=m;c[s+28>>2]=m;e=r-1|0;if((e|0)>0){s=s+32|0;r=e}else{break}}}}while(0);if(!(a[7072808]|0)){break}axE(1)}}while(0);a[9627176]=1;a[9541784]=0;a[9775680]=1;c[8452200+(c[2394]<<2)>>2]=4097;c[2276080]=256;if((c[2276079]|0)>>>0<256){RH(1)}u=a[7024784]<<31>>31}else{u=0}h=g-(c[9776376+(u<<2)>>2]|0)|0;c[2113056]=h;n=RG(h)|0;c[2113054]=(c[2113054]|0)+n;c[2276108]=-1;c[2113056]=-1;h=9776376+(a[7024784]<<31>>31<<2)|0;c[h>>2]=(c[h>>2]|0)+n;a[7024784]=1;n=i+1|0;if((n|0)<9){i=n;j=k}else{break}}j=c[2112964]|0;do{if((j|0)!=0){i=a[9688]|0?534:0;if((i|0)==(k|0)){break}Ug(j+(k<<1<<1)|0,i-k|0)}}while(0);k=c[2394]|0;j=c[14130368+(k<<2)>>2]|0;if((j|0)==0){v=c[2113054]|0;w=8452240+(k<<2)|0;c[w>>2]=v;c[2394]=-1;return 0}gGC(j|0,9104152,280)|0;v=c[2113054]|0;w=8452240+(k<<2)|0;c[w>>2]=v;c[2394]=-1;return 0}function ats(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((a[14168416]|0)==0){d=c[3542106]|0}else{e=c[3527514]|0;f=c[3542106]|0;g=c[3542108]|0;h=0;while(1){i=h<<8;j=0;k=g;l=e+(i<<1)|0;m=f+(i<<2)|0;while(1){i=b[k>>1]|0;b[l>>1]=i;n=i&65535;i=n>>>7&248;c[m>>2]=n>>>2<<8&63488|n&31|(i>>>5|i)<<3&2016;i=j+1|0;if((i|0)<256){j=i;k=k+2|0;l=l+2|0;m=m+4|0}else{break}}m=h+1|0;if((m|0)<128){g=g+512|0;h=m}else{break}}a[14168416]=0;d=f}f=c[d+130048>>2]|0;d=c[2112968]|0;do{if((f|0)==0){gGz(d|0,0,ag(c[2113280]<<1,c[2113276]|0)|0)}else{h=f<<16|f;g=ag(c[2113276]|0,c[2113280]|0)|0;if((g|0)<=15){break}e=d;m=(g|0)/16|0;while(1){c[e>>2]=h;c[e+4>>2]=h;c[e+8>>2]=h;c[e+12>>2]=h;c[e+16>>2]=h;c[e+20>>2]=h;c[e+24>>2]=h;c[e+28>>2]=h;g=m-1|0;if((g|0)>0){e=e+32|0;m=g}else{break}}}}while(0);if(!(a[7072808]|0)){return 0}axE(1);return 0}function att(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;e=i;i=i+144|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;l=e+80|0;m=e+96|0;n=e+112|0;o=e+128|0;if((d|0)!=0){c[d>>2]=133378}Ts(b,d);if((b&96|0)==0){i=e;return 0}gGz(o|0,0,12);d=c[2405676]|0;c[o>>2]=d;c[o+4>>2]=(c[2411712]|0)-d;c[o+12>>2]=219592;gj[c[2076592]&4095](o)|0;o=h|0;do{if((b&64|0)!=0){gGz(g|0,0,16);c[2394]=-1;if((c[2392]|0)<0){break}d=h+9|0;p=f;q=f|0;r=f+4|0;s=f+12|0;t=g|0;u=g+4|0;v=g+12|0;w=0;do{gGC(o|0,614896,11)|0;a[d]=w+48&255;x=8452256+(w<<2)|0;gGz(p|0,0,12);c[q>>2]=x;c[r>>2]=4;c[s>>2]=164976;gj[c[2076592]&4095](f)|0;if((c[x>>2]|0)!=0){c[t>>2]=c[14130368+(w<<2)>>2];c[u>>2]=c[8452184+(w<<2)>>2];c[v>>2]=o;x=c[2076592]|0;gj[x&4095](g)|0}w=w+1|0;}while((w|0)<=(c[2392]|0))}}while(0);Ue();gGz(n|0,0,12);c[n>>2]=9541784;c[n+4>>2]=1;c[n+12>>2]=148144;gj[c[2076592]&4095](n)|0;gGz(m|0,0,12);c[m>>2]=9542016;c[m+4>>2]=1;c[m+12>>2]=118544;gj[c[2076592]&4095](m)|0;gGz(l|0,0,12);c[l>>2]=9775240;c[l+4>>2]=1;c[l+12>>2]=93520;gj[c[2076592]&4095](l)|0;gGz(k|0,0,12);c[k>>2]=9627176;c[k+4>>2]=1;c[k+12>>2]=490464;gj[c[2076592]&4095](k)|0;ayc();gGz(j|0,0,12);c[j>>2]=9625784;c[j+4>>2]=4;c[j+12>>2]=215728;gj[c[2076592]&4095](j)|0;i=e;return 0}function atu(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>5){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4335028+(b*112|0)>>2];c[a+104>>2]=c[4335032+(b*112|0)>>2];c[a+108>>2]=c[4335036+(b*112|0)>>2];d=0;return d|0}function atv(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<6&(d|0)==0)){e=1;return e|0}c[a>>2]=4334928+(b*112|0);e=0;return e|0}function atw(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=(b^1)&255;a[9542016]=d;do{if((a[9541784]|0)==0|d<<24>>24==0){a[9775680]=1;e=4096;f=1;g=8913}else{b=(a[9775240]|0)==0;h=b&1;a[9775680]=h;if(b){e=b?4096:0;f=h;g=8913;break}c[8452200+(c[2394]<<2)>>2]=0;c[2276080]=0;i=h}}while(0);do{if((g|0)==8913){c[8452200+(c[2394]<<2)>>2]=e|1;c[2276080]=256;if((c[2276079]|0)>>>0>=256){i=f;break}RH(1);i=a[9775680]|0}}while(0);if(!(i<<24>>24!=0&a[7024784])){return}c[2113056]=1024;i=RG(1024)|0;c[2113054]=(c[2113054]|0)+i;c[2276108]=-1;c[2113056]=-1;c[2444094]=(c[2444094]|0)+i;return}function atx(a){a=a|0;return 0}function aty(a,b){a=a|0;b=b|0;if((a|0)!=13631488){return}a=b&255;c[2415256]=a&8;b=a>>>1&1;c[3528406]=b^1;if((b|0)==0){c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2]}Tr(a>>>2&1);return}function atz(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;if((d|0)==11010054){f=a[9541776]|0;g=a[9775232]<<1|f;a[9775232]=1;h=8452200+(c[2394]<<2)|0;do{if(f<<24>>24==0|(a[9542008]|0)==0){c[h>>2]=4097;c[2276080]=256;if((c[2276079]|0)>>>0>=256){break}RH(1)}else{c[h>>2]=0;c[2276080]=0}}while(0);i=g&255;return i|0}else if((d|0)==11010052){g=a[9775232]|0;h=g<<1|a[9541776];a[9541776]=1;do{if((a[9542008]|0)==0){j=4096;k=8933}else{f=g<<24>>24==0;if(f){j=f?4096:0;k=8933;break}c[8452200+(c[2394]<<2)>>2]=0;c[2276080]=0}}while(0);do{if((k|0)==8933){c[8452200+(c[2394]<<2)>>2]=j|1;c[2276080]=256;if((c[2276079]|0)>>>0>=256){break}RH(1)}}while(0);i=h&255;return i|0}else if((d|0)==11010048|(d|0)==11010050){i=(a[9775232]<<1|a[9541776])&255;return i|0}else if((d|0)==11010156){i=(c[2429482]|0)>(a[961584]<<31>>31|0)?2:0;return i|0}else if((d|0)==11010158){h=c[2429482]|0;if((h|0)>(a[961584]<<31>>31|0)){c[2429482]=0;a[961584]=1;i=0;return i|0}else{c[2429482]=h+1;i=c[9747648+(h<<2)>>2]&65535;return i|0}}else if((d|0)==13107200){i=~b[4812888];return i|0}else if((d|0)==13107202){d=e[4812889]|0;do{if((c[2406632]|0)==0){h=c[2443744]|0;if((h|0)<=0){l=2048;break}c[2443744]=h-1;l=0}else{l=(c[2432962]|0)>>>((c[(c[2420380]|0)+4>>2]|0)>>>0)<<11&2048}}while(0);i=((l|d)^63487)&65535;return i|0}else{i=0;return i|0}return 0}function atA(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0;if((b-11010058|0)>>>0<95|(b-11010154|0)>>>0<3|(b-11010052|0)>>>0<3){return}if((b|0)==11534338){c[3542085]=d&65535;return}else if((b|0)==11010056){gD[c[3542102]&8191]()|0;c[2113288]=d&65535;return}else if((b|0)==11010048){c[2113282]=d&65535;return}else if((b|0)==11010050){c[2113278]=d&65535;return}else if((b|0)==11010158){c[3528934]=d&65535;c[2433330]=c[2433330]|12;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;e=c[2433530]|0;c[2433530]=e+12;if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){f=gfc(1024)|0;g=f;h=(c[2433530]|0)+f|0}else{g=1024;h=e+1036|0}c[2433530]=h;c[2443974]=(c[2443974]|0)+g;return}else if((b|0)==12058626){c[3542082]=d&65535;return}else if((b|0)==13631488){if((d&256)!=0){return}g=(d&65535)>>>8&65535;c[2415256]=g&8;h=g>>>1&1;c[3528406]=h^1;if((h|0)==0){c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2]}Tr(g>>>2&1);return}else if((b|0)==11534336){c[3542084]=d&65535;return}else if((b|0)==12582916){c[3542080]=d&65535;return}else if((b|0)==12058624){c[3542081]=d&65535;return}else if((b|0)==12582914){c[3542079]=d&65535;return}else if((b|0)==12058628){c[3542083]=d&65535;return}else if((b|0)==12582912){c[3542078]=d&65535;return}else if((b|0)==11534340){c[3542086]=d&65535;return}else{return}}function atB(a){a=a|0;var b=0,d=0;b=a&255;if((b|0)==81){d=c[(c[3531464]|0)+4240>>2]&255;return d|0}else if((b|0)==48){c[2433330]=c[2433330]|4;d=c[3528934]&255;return d|0}else if((b|0)==64){c[2433330]=c[2433330]|8;d=(c[3528934]|0)>>>8&255;return d|0}else{d=0;return d|0}return 0}function atC(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;switch(b&255|0){case 80:{c[2113304]=d&255;return};case 0:{b=d&15;a[14117480]=b;e=c[2411310]|0;f=c[9757320+(c[1836236]<<2)>>2]|0;g=((b&255)<<14)-16384|0;b=64;h=64;while(1){c[f+76+(h<<2)>>2]=e+(g+(h<<8));i=b+1&65535;if((i&65535)>127){j=64;k=64;break}else{b=i;h=i&65535}}while(1){h=e+(g+(k<<8))|0;c[f+76+(k+512<<2)>>2]=h;c[f+76+(k+768<<2)>>2]=h;h=j+1&65535;if((h&65535)>127){break}else{j=h;k=h&65535}}return};case 144:{k=d&7;a[9758560]=k;j=(d&255)>>>4&7;a[9758552]=j;f=c[3541206]|0;g=f+1048576|0;e=c[2438658]|0;h=e+((k&255)<<17)|0;gGC(g|0,h|0,131072)|0;h=f+1179648|0;f=e+((j&255)<<17)|0;gGC(h|0,f|0,131072)|0;return};case 81:{f=c[2113304]|0;a[14168504+f|0]=d;mv(0,f,d&255);return};case 112:{f=d&7;a[9758576]=f;h=(d&255)>>>4&7;a[9758568]=h;j=c[3541206]|0;e=c[2438660]|0;g=e+((f&255)<<17)|0;gGC(j|0,g|0,131072)|0;g=j+131072|0;j=e+((h&255)<<17)|0;gGC(g|0,j|0,131072)|0;return};case 96:{Uv(0,d);return};case 128:{Uv(1,d);return};default:{return}}}function atD(a){a=a|0;return 0}function atE(a,b){a=a|0;b=b|0;return}function atF(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2575460+(b*112|0)>>2];c[a+104>>2]=c[2575464+(b*112|0)>>2];c[a+108>>2]=c[2575468+(b*112|0)>>2];d=0;return d|0}function atG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=2575360+(b*112|0);e=0;return e|0}function atH(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1044816+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function atI(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0;e=i;i=i+1560|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;B=e+1200|0;C=e+1312|0;D=e+1320|0;E=e+1432|0;F=e+1440|0;G=e+1552|0;c[2424]=5755;c[2426740]=0;c[2418158]=0;c[2411310]=1572864;c[3542098]=1835008;c[3542090]=18612224;c[3542091]=22806528;c[3542092]=27000832;c[3541206]=31195136;c[2438660]=32505856;c[2438658]=34603008;c[2405674]=36700160;c[2418272]=36700160;c[2411352]=36798464;c[3542094]=36806656;c[3542095]=36839424;c[3542096]=36872192;c[3542100]=36904960;c[3542108]=36970496;c[2411702]=37036032;H=0;while(1){if((H|0)>=1024){break}I=9638528+(H<<2)|0;if((c[I>>2]|0)==0){J=9056;break}else{H=H+1|0}}do{if((J|0)==9056){H=gGq(37036032)|0;c[I>>2]=H;if((H|0)==0){break}c[2426740]=H;gGz(H|0,0,37036032);c[2418158]=H;c[2411310]=H+1572864;c[3542098]=H+1835008;c[3542090]=H+18612224;c[3542091]=H+22806528;c[3542092]=H+27000832;c[3541206]=H+31195136;c[2438660]=H+32505856;c[2438658]=H+34603008;K=H+36700160|0;c[2405674]=K;c[2418272]=K;c[2411352]=H+36798464;c[3542094]=H+36806656;c[3542095]=H+36839424;c[3542096]=H+36872192;c[3542100]=H+36904960;c[3542108]=H+36970496;K=H+37036032|0;c[2411702]=K;c[2414240]=K;do{if((c[3542200]|0)!=0){K=F+108|0;c[K>>2]=0;L=F+100|0;c[L>>2]=0;M=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[M&16383](F,0)|0;if((c[K>>2]|0)==0){break}K=c[L>>2]|0;c[G>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](G,0,0)|0;if((K|0)<1){break}gzL(H,0,0)|0}}while(0);H=(c[2418158]|0)+524288|0;do{if((c[3542200]|0)!=0){K=D+108|0;c[K>>2]=0;L=D+100|0;c[L>>2]=0;M=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[M&16383](D,1)|0;if((c[K>>2]|0)==0){break}K=c[L>>2]|0;c[E>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](E,1,0)|0;if((K|0)<1){break}gzL(H,0,1)|0}}while(0);H=(c[2418158]|0)+1048576|0;do{if((c[3542200]|0)!=0){K=B+108|0;c[K>>2]=0;L=B+100|0;c[L>>2]=0;M=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[M&16383](B,2)|0;if((c[K>>2]|0)==0){break}K=c[L>>2]|0;c[C>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](C,2,0)|0;if((K|0)<1){break}gzL(H,0,2)|0}}while(0);H=c[2411310]|0;do{if((c[3542200]|0)!=0){K=z+108|0;c[K>>2]=0;L=z+100|0;c[L>>2]=0;M=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[M&16383](z,3)|0;if((c[K>>2]|0)==0){break}K=c[L>>2]|0;c[A>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](A,3,0)|0;if((K|0)<1){break}gzL(H,0,3)|0}}while(0);H=c[3542098]|0;do{if((c[3542200]|0)!=0){K=x+108|0;c[K>>2]=0;L=x+100|0;c[L>>2]=0;M=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[M&16383](x,4)|0;if((c[K>>2]|0)==0){break}K=c[L>>2]|0;c[y>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](y,4,0)|0;if((K|0)<1){break}gzL(H,0,4)|0}}while(0);H=(c[3542098]|0)+2097152|0;do{if((c[3542200]|0)!=0){K=v+108|0;c[K>>2]=0;L=v+100|0;c[L>>2]=0;M=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[M&16383](v,5)|0;if((c[K>>2]|0)==0){break}K=c[L>>2]|0;c[w>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](w,5,0)|0;if((K|0)<1){break}gzL(H,0,5)|0}}while(0);H=(c[3542098]|0)+4194304|0;do{if((c[3542200]|0)!=0){K=t+108|0;c[K>>2]=0;L=t+100|0;c[L>>2]=0;M=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[M&16383](t,6)|0;if((c[K>>2]|0)==0){break}K=c[L>>2]|0;c[u>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](u,6,0)|0;if((K|0)<1){break}gzL(H,0,6)|0}}while(0);H=(c[3542098]|0)+6291456|0;do{if((c[3542200]|0)!=0){K=r+108|0;c[K>>2]=0;L=r+100|0;c[L>>2]=0;M=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[M&16383](r,7)|0;if((c[K>>2]|0)==0){break}K=c[L>>2]|0;c[s>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](s,7,0)|0;if((K|0)<1){break}gzL(H,0,7)|0}}while(0);H=c[3542098]|0;K=H+8388607|0;L=H+16777214|0;H=0;while(1){a[L]=a[K]&15;a[L+1|0]=(d[K]|0)>>>4;M=H+1|0;if((M|0)<8388608){K=K-1|0;L=L-2|0;H=M}else{break}}H=c[3542090]|0;do{if((c[3542200]|0)!=0){L=p+108|0;c[L>>2]=0;K=p+100|0;c[K>>2]=0;M=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[M&16383](p,8)|0;if((c[L>>2]|0)==0){break}L=c[K>>2]|0;c[q>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](q,8,0)|0;if((L|0)<1){break}gzL(H,0,8)|0}}while(0);H=c[3542090]|0;L=H+2097151|0;K=H+4194302|0;H=0;while(1){a[K+1|0]=a[L]&15;a[K]=(d[L]|0)>>>4;M=H+1|0;if((M|0)<2097152){L=L-1|0;K=K-2|0;H=M}else{break}}H=c[3542091]|0;do{if((c[3542200]|0)!=0){K=n+108|0;c[K>>2]=0;L=n+100|0;c[L>>2]=0;M=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[M&16383](n,9)|0;if((c[K>>2]|0)==0){break}K=c[L>>2]|0;c[o>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](o,9,0)|0;if((K|0)<1){break}gzL(H,0,9)|0}}while(0);H=c[3542091]|0;K=H+2097151|0;L=H+4194302|0;H=0;while(1){a[L+1|0]=a[K]&15;a[L]=(d[K]|0)>>>4;M=H+1|0;if((M|0)<2097152){K=K-1|0;L=L-2|0;H=M}else{break}}H=c[3542092]|0;do{if((c[3542200]|0)!=0){L=l+108|0;c[L>>2]=0;K=l+100|0;c[K>>2]=0;M=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[M&16383](l,10)|0;if((c[L>>2]|0)==0){break}L=c[K>>2]|0;c[m>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](m,10,0)|0;if((L|0)<1){break}gzL(H,0,10)|0}}while(0);H=c[3542092]|0;L=H+2097151|0;K=H+4194302|0;H=0;while(1){a[K+1|0]=a[L]&15;a[K]=(d[L]|0)>>>4;M=H+1|0;if((M|0)<2097152){L=L-1|0;K=K-2|0;H=M}else{break}}H=c[2438660]|0;do{if((c[3542200]|0)!=0){K=j+108|0;c[K>>2]=0;L=j+100|0;c[L>>2]=0;M=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[M&16383](j,11)|0;if((c[K>>2]|0)==0){break}K=c[L>>2]|0;c[k>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](k,11,0)|0;if((K|0)<1){break}gzL(H,0,11)|0}}while(0);H=c[2438658]|0;do{if((c[3542200]|0)!=0){K=f+108|0;c[K>>2]=0;L=f+100|0;c[L>>2]=0;M=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[M&16383](f,12)|0;if((c[K>>2]|0)==0){break}K=c[L>>2]|0;c[g>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](g,12,0)|0;if((K|0)<1){break}gzL(H,0,12)|0}}while(0);Tq(690256);fxU(0,425984);if((c[2394]|0)==0){N=c[2112932]|0}else{c[2394]=0;H=c[3532596]|0;c[2112932]=H;K=c[3532592]|0;if((K|0)!=0){gGC(9104152,K|0,280)|0}c[2113054]=c[2113060];N=H}H=c[2418158]|0;K=N|0;L=0;while(1){M=H+L|0;c[K>>2]=M;c[K+131072>>2]=M;M=L+1024|0;if(M>>>0>524287){break}else{K=K+4|0;L=M}}L=N+4096|0;K=1048576;while(1){M=H+(K-524288)|0;c[L>>2]=M;c[L+131072>>2]=M;M=K+1024|0;if(M>>>0>1572863){break}else{L=L+4|0;K=M}}K=N+8192|0;L=2097152;while(1){M=H+(L-1048576)|0;c[K>>2]=M;c[K+131072>>2]=M;M=L+1024|0;if(M>>>0>2621439){break}else{K=K+4|0;L=M}}L=c[3542096]|0;K=N+34816|0;H=8912896;while(1){M=L+(H-8912896)|0;c[K>>2]=M;c[K+65536>>2]=M;c[K+131072>>2]=M;M=H+1024|0;if(M>>>0>8945663){break}else{K=K+4|0;H=M}}H=c[2418272]|0;K=N+34944|0;L=8945664;while(1){M=H+(L-8945664)|0;c[K>>2]=M;c[K+65536>>2]=M;c[K+131072>>2]=M;M=L+1024|0;if(M>>>0>8978431){break}else{K=K+4|0;L=M}}L=c[3542095]|0;K=N+36864|0;M=9437184;while(1){O=L+(M-9437184)|0;c[K>>2]=O;c[K+65536>>2]=O;c[K+131072>>2]=O;O=M+1024|0;if(O>>>0>9469951){break}else{K=K+4|0;M=O}}M=N+36992|0;K=9469952;while(1){L=H+(K-9437184)|0;c[M>>2]=L;c[M+65536>>2]=L;c[M+131072>>2]=L;L=K+1024|0;if(L>>>0>9502719){break}else{M=M+4|0;K=L}}K=c[3542094]|0;M=N+38912|0;L=9961472;while(1){O=K+(L-9961472)|0;c[M>>2]=O;c[M+65536>>2]=O;c[M+131072>>2]=O;O=L+1024|0;if(O>>>0>9994239){break}else{M=M+4|0;L=O}}L=N+39040|0;M=9994240;while(1){K=H+(M-9928704)|0;c[L>>2]=K;c[L+65536>>2]=K;c[L+131072>>2]=K;K=M+1024|0;if(K>>>0>10027007){break}else{L=L+4|0;M=K}}M=c[3542108]|0;c[N+16512>>2]=M;c[N+82048>>2]=M;c[N+147584>>2]=M;L=M+1024|0;c[N+16516>>2]=L;c[N+82052>>2]=L;c[N+147588>>2]=L;L=M+2048|0;c[N+16520>>2]=L;c[N+82056>>2]=L;c[N+147592>>2]=L;L=M+3072|0;c[N+16524>>2]=L;c[N+82060>>2]=L;c[N+147596>>2]=L;L=c[3542100]|0;M=N+61440|0;H=15728640;while(1){K=L+(H-15728640)|0;c[M>>2]=K;c[M+65536>>2]=K;c[M+131072>>2]=K;K=H+1024|0;if(K>>>0>15794175){break}else{M=M+4|0;H=K}}c[N+196608>>2]=1584;c[N+196648>>2]=2312;c[N+196688>>2]=1242;c[N+196728>>2]=2702;H=c[3532592]|0;if((H|0)!=0){gGC(H|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);H=c[2439330]|0;M=(H|0)==0;if(!M){L=H;gGC(9706056,L|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];L=c[3528484]|0;c[2076596]=L;K=c[2417276]|0;c[3541536]=K;c[1836236]=0;c[H+4172>>2]=1622;c[H+4176>>2]=2094;c[H+4180>>2]=3182;c[H+4184>>2]=2830;O=c[2411310]|0;P=0;Q=0;while(1){c[H+76+(Q<<2)>>2]=O+(Q<<8);R=P+1&65535;if((R&65535)>63){S=0;T=0;break}else{P=R;Q=R&65535}}while(1){Q=O+(T<<8)|0;c[H+76+(T+512<<2)>>2]=Q;c[H+76+(T+768<<2)>>2]=Q;Q=S+1&65535;if((Q&65535)>63){U=64;V=64;break}else{S=Q;T=Q&65535}}while(1){c[H+76+(V<<2)>>2]=O+(V<<8);Q=U+1&65535;if((Q&65535)>127){W=64;X=64;break}else{U=Q;V=Q&65535}}while(1){Q=O+(X<<8)|0;c[H+76+(X+512<<2)>>2]=Q;c[H+76+(X+768<<2)>>2]=Q;Q=W+1&65535;if((Q&65535)>127){break}else{W=Q;X=Q&65535}}O=c[2411352]|0;Q=224;P=224;while(1){c[H+76+(P<<2)>>2]=O+((P<<8)-57344);R=Q+1&65535;if((R&65535)>255){Y=224;Z=224;break}else{Q=R;P=R&65535}}while(1){c[H+76+(Z+256<<2)>>2]=O+((Z<<8)-57344);P=Y+1&65535;if((P&65535)>255){_=224;$=224;break}else{Y=P;Z=P&65535}}while(1){P=O+(($<<8)-57344)|0;c[H+76+($+512<<2)>>2]=P;c[H+76+($+768<<2)>>2]=P;P=_+1&65535;if((P&65535)>255){break}else{_=P;$=P&65535}}if(!M){O=H;gGC(O|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=L;c[2417276]=K;c[1836236]=-1;O=0;while(1){if((O|0)>=1024){aa=0;break}ab=9638528+(O<<2)|0;if((c[ab>>2]|0)==0){J=9161;break}else{O=O+1|0}}do{if((J|0)==9161){O=gGq(131072)|0;c[ab>>2]=O;if((O|0)==0){aa=0;break}gGz(O|0,0,131072);aa=O}}while(0);c[3542106]=aa;gGz(aa|0,0,131072);O=0;while(1){if((O|0)>=1024){ac=0;break}ad=9638528+(O<<2)|0;if((c[ad>>2]|0)==0){J=9166;break}else{O=O+1|0}}do{if((J|0)==9166){O=gGq(65536)|0;c[ad>>2]=O;if((O|0)==0){ac=0;break}gGz(O|0,0,65536);ac=O}}while(0);c[3527514]=ac;gGz(ac|0,0,65536);c[2112966]=c[3542106];c[3542078]=0;c[3542079]=0;c[3542080]=16;c[3542081]=0;c[3542082]=0;c[3542083]=16;c[3542084]=0;c[3542085]=0;c[3542086]=16;c[3542087]=0;c[3542088]=0;c[3542089]=16;c[2113284]=0;O=c[642608+(c[2436]<<2)>>2]|0;if((c[O+52>>2]&4|0)==0){K=c[O+128>>2]|0;c[2113280]=K;ae=O+132|0;af=K}else{K=c[O+132>>2]|0;c[2113280]=K;ae=O+128|0;af=K}K=c[ae>>2]|0;c[2113276]=K;c[2406716]=af-8;c[2394778]=af-16;c[2406714]=K-8;c[2394776]=K-16;c[3528974]=c[3564288+(((af|0)!=320)<<2)>>2];auH(2,16777216);axI(0,4194304,8,16384);axI(1,4194304,8,16384);axI(2,4194304,8,16384);c[2113294]=-126;a[7462192]=1;K=a[9680]|0;O=K?32e3:0;if(K){if(a[9624]|0){K=O*3|0;L=62500;while(1){if((L|0)>(K|0)){L=L>>1}else{ag=1222;ah=L;break}}}else{ag=2462;ah=O}c[2429380]=ah;c[3542124]=ag;mw(4e6,ah);L=gGq(262144)|0;c[2406684]=L;gGz(L|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(4e6,11025)}c[(c[3531464]|0)+44344>>2]=476;h[745421]=1.2;c[2436794]=1;h[745420]=1.2;c[2436792]=2;L=c[3541206]|0;K=c[2438660]|0;gGC(L|0,K|0,262144)|0;K=L+1048576|0;L=c[2438658]|0;gGC(K|0,L|0,262144)|0;Ux(0,15151,1);Ux(1,15151,1);c[2407030]=256;c[2407068]=3;c[2407069]=256;c[2407107]=3;a[7072800]=1;atP();ai=0;i=e;return ai|0}}while(0);c[2426740]=0;ai=1;i=e;return ai|0}function atJ(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;i=i+128|0;d=b|0;e=c[c[642608+(c[2436]<<2)>>2]>>2]|0;be(d|0,128,179600,(f=i,i=i+24|0,c[f>>2]=9374064,c[f+8>>2]=47,c[f+16>>2]=e,f)|0)|0;i=f;a[1040128]=0;f=c[2420380]|0;e=c[f>>2]|0;g=c[f+4>>2]|0;f=fw(d|0,389440)|0;if((f|0)!=0){d=g>>3<<e&1023;cj(14100392,d|0,1,f|0)|0;aY(f|0)|0}f=c[3531464]|0;c[f+44344>>2]=0;c[f+44348>>2]=0;if((f|0)!=0){gGr(f);c[3531464]=0}f=c[2406684]|0;if((f|0)!=0){gGr(f);c[2406684]=0}Uw(0);Uw(1);axH();f=c[2443764]|0;d=0;while(1){if((d|0)>=1024){break}h=9638528+(d<<2)|0;if((c[h>>2]|0)==(f|0)){j=9190;break}else{d=d+1|0}}if((j|0)==9190){gGr(f);c[h>>2]=0}c[2443764]=0;h=c[2394718]|0;f=0;while(1){if((f|0)>=1024){break}k=9638528+(f<<2)|0;if((c[k>>2]|0)==(h|0)){j=9194;break}else{f=f+1|0}}if((j|0)==9194){gGr(h);c[k>>2]=0}c[2394718]=0;a[7462192]=0;k=c[3542106]|0;h=0;while(1){if((h|0)>=1024){break}l=9638528+(h<<2)|0;if((c[l>>2]|0)==(k|0)){j=9198;break}else{h=h+1|0}}if((j|0)==9198){gGr(k);c[l>>2]=0}c[3542106]=0;l=c[3527514]|0;k=0;while(1){if((k|0)>=1024){break}m=9638528+(k<<2)|0;if((c[m>>2]|0)==(l|0)){j=9202;break}else{k=k+1|0}}if((j|0)==9202){gGr(l);c[m>>2]=0}c[3527514]=0;if((c[2392]|0)>=0){m=0;do{l=14130368+(m<<2)|0;k=c[l>>2]|0;if((k|0)!=0){gGr(k);c[l>>2]=0}l=14130384+(m<<2)|0;k=c[l>>2]|0;if((k|0)!=0){gGr(k);c[l>>2]=0}m=m+1|0;}while((m|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;fwZ();c[3528934]=0;a[14117480]=0;a[9758576]=0;a[9758568]=0;a[9758560]=0;a[9758552]=0;m=c[2426740]|0;l=0;while(1){if((l|0)>=1024){j=9214;break}n=9638528+(l<<2)|0;if((c[n>>2]|0)==(m|0)){break}else{l=l+1|0}}if((j|0)==9214){c[2426740]=0;i=b;return 0}gGr(m);c[n>>2]=0;c[2426740]=0;i=b;return 0}function atK(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;if((a[9624320]|0)!=0){atP()}b[4812888]=0;b[4812889]=0;d=0;e=0;f=0;do{e=((a[9633680+d|0]&1)<<d|e&65535)&65535;f=((a[9631496+d|0]&1)<<d|f&65535)&65535;d=d+1|0;}while((d|0)<11);b[4812888]=e;b[4812889]=f;if((e&3)==3){d=e&-4;b[4812888]=d;g=d}else{g=e}if((g&12)==12){b[4812888]=g&-13}if((f&3)==3){g=f&-4;b[4812889]=g;h=g}else{h=f}if((h&12)==12){b[4812889]=h&-13}h=c[2392]|0;if((h|0)>=0){gGz(8452240,0,((h|0)>0?(h<<2)+4|0:4)|0)}c[2113054]=0;h=c[2385548]|0;if((h|0)>0){gGz(9752472,0,((h|0)>1?h<<2:4)|0)}c[2433530]=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];h=c[3532592]|0;if((h|0)!=0){gGC(9104152,h|0,280)|0}c[2113054]=c[2113060]}h=c[2439330]|0;if((h|0)!=0){f=h;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;f=c[2438]|0;h=gGU(f,(f|0)<0|0?-1:0,16e6,0)|0;f=~~((+(h>>>0)+ +(K|0)*4294967296.0)/14732.965009208103);c[2440538]=f;a[6518040]=1;c[2443974]=0;c[2444022]=0;h=f-~~(+(f*12|0|0)/271.5)|0;a[9627168]=0;f=0;g=1;L11257:while(1){e=g;do{if((e|0)>=9){break L11257}d=(ag(c[2440538]|0,e)|0)/8|0;do{if((a[9627168]&1)==0&(d|0)>(h|0)){i=c[2444022]|0;if((i|0)<(h|0)){j=h-i|0;c[2113056]=j;i=RG(j)|0;c[2113054]=(c[2113054]|0)+i;c[2276108]=-1;c[2113056]=-1;c[2444022]=(c[2444022]|0)+i}i=c[2112968]|0;do{if((i|0)!=0){avg(128);j=c[(c[3542106]|0)+130048>>2]|0;do{if((j|0)==0){gGz(i|0,0,ag(c[2113280]<<1,c[2113276]|0)|0)}else{k=j<<16|j;l=ag(c[2113276]|0,c[2113280]|0)|0;if((l|0)<=15){break}m=i;n=(l|0)/16|0;while(1){c[m>>2]=k;c[m+4>>2]=k;c[m+8>>2]=k;c[m+12>>2]=k;c[m+16>>2]=k;c[m+20>>2]=k;c[m+24>>2]=k;c[m+28>>2]=k;l=n-1|0;if((l|0)>0){m=m+32|0;n=l}else{break}}}}while(0);if(!(a[7072800]|0)){break}axE(1)}}while(0);i=c[2113288]|0;c[2113288]=c[2113286];c[2113286]=i&255;a[9627168]=1;a[9541776]=0;a[9775232]=0;c[8452200+(c[2394]<<2)>>2]=4097;c[2276080]=256;if((c[2276079]|0)>>>0>=256){break}RH(1)}}while(0);c[8452200+(c[2394]<<2)>>2]=8193;c[2276080]=256;if((c[2276079]|0)>>>0<256){RH(1)}i=d-(c[2444022]|0)|0;c[2113056]=i;j=RG(i)|0;c[2113054]=(c[2113054]|0)+j;c[2276108]=-1;c[2113056]=-1;c[2444022]=(c[2444022]|0)+j;e=e+1|0;j=(ag(a[6518040]|0?139008:0,e)|0)/8|0;i=c[2443974]|0;n=j-i|0;do{if((n|0)<1){o=0;p=i}else{if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){j=gfc(n)|0;c[2433530]=(c[2433530]|0)+j;o=j;p=c[2443974]|0;break}else{c[2433530]=(c[2433530]|0)+n;o=n;p=i;break}}}while(0);c[2443974]=p+o;q=c[2112964]|0;}while((q|0)==0);i=a[9688]|0?66:0;n=q+(f<<1<<1)|0;gg[c[3542124]&4095](n,i);Uu(0,n,i);Uu(1,n,i);f=i+f|0;g=e}g=c[2112964]|0;do{if((g|0)!=0){q=a[9688]|0?534:0;o=q-f|0;p=g+(f<<1<<1)|0;if((q|0)==(f|0)){break}gg[c[3542124]&4095](p,o);Uu(0,p,o);Uu(1,p,o)}}while(0);f=c[2394]|0;g=c[14130368+(f<<2)>>2]|0;if((g|0)!=0){gGC(g|0,9104152,280)|0}c[8452240+(f<<2)>>2]=c[2113054];c[2394]=-1;f=c[1836236]|0;g=c[9757320+(f<<2)>>2]|0;if((g|0)==0){r=c[2433530]|0;s=9752472+(f<<2)|0;c[s>>2]=r;t=c[2076596]|0;u=14113936+(f<<2)|0;c[u>>2]=t;v=c[3541536]|0;w=9669104+(f<<2)|0;c[w>>2]=v;c[1836236]=-1;return 0}o=g;gGC(o|0,9706056,76)|0;r=c[2433530]|0;s=9752472+(f<<2)|0;c[s>>2]=r;t=c[2076596]|0;u=14113936+(f<<2)|0;c[u>>2]=t;v=c[3541536]|0;w=9669104+(f<<2)|0;c[w>>2]=v;c[1836236]=-1;return 0}function atL(){var b=0,d=0,e=0,f=0,g=0,h=0;avg(128);b=c[(c[3542106]|0)+130048>>2]|0;d=c[2112968]|0;do{if((b|0)==0){gGz(d|0,0,ag(c[2113280]<<1,c[2113276]|0)|0)}else{e=b<<16|b;f=ag(c[2113276]|0,c[2113280]|0)|0;if((f|0)<=15){break}g=d;h=(f|0)/16|0;while(1){c[g>>2]=e;c[g+4>>2]=e;c[g+8>>2]=e;c[g+12>>2]=e;c[g+16>>2]=e;c[g+20>>2]=e;c[g+24>>2]=e;c[g+28>>2]=e;f=h-1|0;if((f|0)>0){g=g+32|0;h=f}else{break}}}}while(0);if(!(a[7072800]|0)){return 0}axE(1);return 0}function atM(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;g=i;i=i+272|0;h=g|0;j=g+16|0;k=g+32|0;l=g+48|0;m=g+64|0;n=g+80|0;o=g+96|0;p=g+112|0;q=g+128|0;r=g+144|0;s=g+160|0;t=g+176|0;u=g+192|0;v=g+208|0;w=g+224|0;x=g+240|0;y=g+256|0;if((f|0)!=0){c[f>>2]=133378}Ts(e,f);if((e&96|0)==0){i=g;return 0}gGz(y|0,0,12);f=c[2405674]|0;c[y>>2]=f;c[y+4>>2]=(c[2411702]|0)-f;c[y+12>>2]=219592;gj[c[2076592]&4095](y)|0;y=m|0;do{if((e&64|0)==0){fw$(e);z=e&2}else{gGz(l|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){f=m+9|0;A=k;B=k|0;C=k+4|0;D=k+12|0;E=l|0;F=l+4|0;G=l+12|0;H=0;do{gGC(y|0,614896,11)|0;a[f]=H+48&255;I=8452256+(H<<2)|0;gGz(A|0,0,12);c[B>>2]=I;c[C>>2]=4;c[D>>2]=164976;gj[c[2076592]&4095](k)|0;if((c[I>>2]|0)!=0){c[E>>2]=c[14130368+(H<<2)>>2];c[F>>2]=c[8452184+(H<<2)>>2];c[G>>2]=y;I=c[2076592]|0;gj[I&4095](l)|0}H=H+1|0;}while((H|0)<=(c[2392]|0))}fw$(e);gGz(j|0,0,12);c[j>>2]=8453216;c[j+4>>2]=4;c[j+12>>2]=107480;H=c[2076592]|0;gj[H&4095](j)|0;gGz(h|0,0,12);c[h>>2]=14168504;c[h+4>>2]=256;c[h+12>>2]=476464;H=c[2076592]|0;gj[H&4095](h)|0;H=e&2;if((H|0)==0){z=H;break}else{J=0}while(1){mv(0,J,d[14168504+J|0]|0);G=J+1|0;if((G|0)<256){J=G}else{z=H;break}}}}while(0);Ut(0);Ut(1);gGz(x|0,0,12);c[x>>2]=9541776;c[x+4>>2]=1;c[x+12>>2]=148144;gj[c[2076592]&4095](x)|0;gGz(w|0,0,12);c[w>>2]=9542008;c[w+4>>2]=1;c[w+12>>2]=118544;gj[c[2076592]&4095](w)|0;gGz(v|0,0,12);c[v>>2]=9775232;c[v+4>>2]=1;c[v+12>>2]=93520;gj[c[2076592]&4095](v)|0;gGz(u|0,0,12);c[u>>2]=9627168;c[u+4>>2]=1;c[u+12>>2]=490464;gj[c[2076592]&4095](u)|0;ayc();gGz(t|0,0,12);c[t>>2]=9625776;c[t+4>>2]=4;c[t+12>>2]=215728;gj[c[2076592]&4095](t)|0;gGz(s|0,0,12);c[s>>2]=14115736;c[s+4>>2]=4;c[s+12>>2]=361464;gj[c[2076592]&4095](s)|0;gGz(r|0,0,12);c[r>>2]=14117480;c[r+4>>2]=1;c[r+12>>2]=435944;gj[c[2076592]&4095](r)|0;gGz(q|0,0,12);c[q>>2]=9758576;c[q+4>>2]=1;c[q+12>>2]=496880;gj[c[2076592]&4095](q)|0;gGz(p|0,0,12);c[p>>2]=9758568;c[p+4>>2]=1;c[p+12>>2]=484928;gj[c[2076592]&4095](p)|0;gGz(o|0,0,12);c[o>>2]=9758560;c[o+4>>2]=1;c[o+12>>2]=471960;gj[c[2076592]&4095](o)|0;gGz(n|0,0,12);c[n>>2]=9758552;c[n+4>>2]=1;c[n+12>>2]=461e3;gj[c[2076592]&4095](n)|0;if((z|0)==0){i=g;return 0}z=c[2439330]|0;n=(z|0)==0;if(!n){o=z;gGC(9706056,o|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];o=c[3528484]|0;c[2076596]=o;p=c[2417276]|0;c[3541536]=p;c[1836236]=0;q=c[2411310]|0;r=((d[14117480]|0)<<14)-16384|0;s=64;t=64;while(1){c[z+76+(t<<2)>>2]=q+(r+(t<<8));u=s+1&65535;if((u&65535)>127){K=64;L=64;break}else{s=u;t=u&65535}}while(1){t=q+(r+(L<<8))|0;c[z+76+(L+512<<2)>>2]=t;c[z+76+(L+768<<2)>>2]=t;t=K+1&65535;if((t&65535)>127){break}else{K=t;L=t&65535}}if(!n){n=z;gGC(n|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=o;c[2417276]=p;c[1836236]=-1;p=c[3541206]|0;o=c[2438660]|0;n=o+((d[9758576]|0)<<17)|0;gGC(p|0,n|0,131072)|0;n=p+131072|0;z=o+((d[9758568]|0)<<17)|0;gGC(n|0,z|0,131072)|0;z=p+1048576|0;n=c[2438658]|0;o=n+((d[9758560]|0)<<17)|0;gGC(z|0,o|0,131072)|0;o=p+1179648|0;p=n+((d[9758552]|0)<<17)|0;gGC(o|0,p|0,131072)|0;a[14168416]=1;i=g;return 0}function atN(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4511588+(b*112|0)>>2];c[a+104>>2]=c[4511592+(b*112|0)>>2];c[a+108>>2]=c[4511596+(b*112|0)>>2];d=0;return d|0}function atO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=4511488+(b*112|0);e=0;return e|0}function atP(){var b=0,d=0,e=0,f=0,g=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];b=c[3532592]|0;if((b|0)!=0){gGC(9104152,b|0,280)|0}c[2113054]=c[2113060]}RI();c[2113056]=1e4;b=RG(1e4)|0;c[2113054]=(c[2113054]|0)+b;c[2276108]=-1;c[2113056]=-1;RI();b=c[2394]|0;d=c[14130368+(b<<2)>>2]|0;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[8452240+(b<<2)>>2]=c[2113054];c[2394]=-1;b=c[2439330]|0;d=(b|0)==0;if(!d){e=b;gGC(9706056,e|0,76)|0}e=c[2438118]|0;c[2433530]=e;f=c[3528484]|0;c[2076596]=f;g=c[2417276]|0;c[3541536]=g;c[1836236]=0;gGz(9706056,0,76);if(!d){d=b;gGC(d|0,9706056,76)|0}c[2438118]=e;c[3528484]=f;c[2417276]=g;c[1836236]=-1;mx(0);c[2113156]=0;a[9628264]=0;c[2407033]=0;g=c[3541206]|0;c[3541190]=g;c[3541198]=g;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=g+256;c[3541199]=g+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=g+512;c[3541200]=g+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=g+768;c[3541201]=g+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2113157]=0;a[9628420]=0;c[2407072]=0;f=g+1048576|0;c[3541194]=f;c[3541202]=f;gGz(c[2430122]|0,0,16384);c[2407080]=4;c[3541195]=g+1048832;c[3541203]=g+1114112;gGz(c[2430123]|0,0,16384);c[2407088]=4;c[3541196]=g+1049088;c[3541204]=g+1179648;gGz(c[2430124]|0,0,16384);c[2407096]=4;c[3541197]=g+1049344;c[3541205]=g+1245184;gGz(c[2430125]|0,0,16384);c[2407104]=4;c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];a[9541776]=1;a[9542008]=1;a[9775232]=1;a[14117480]=0;a[9758576]=0;a[9758568]=0;a[9758560]=0;a[9758552]=0;c[3528934]=0;c[2433330]=12;gGz(9747648,0,192);c[2429482]=0;a[961584]=1;return}function atQ(b){b=b|0;a[9706117]=(b|0)!=0|0;return}function atR(d){d=d|0;var f=0,g=0,h=0,i=0,j=0;if((d|0)==8388610|(d|0)==8388611|(d|0)==8388612|(d|0)==8388613|(d|0)==8388614|(d|0)==8388615){f=a[9541768]|6;return f|0}else if((d|0)==8388608|(d|0)==8388609){g=a[9541768]|6;a[9541768]=1;do{if((a[9542e3]|0)==0){a[9775672]=1;h=4096}else{i=(a[9775224]|0)==0;a[9775672]=i&1;if(i){h=i?4096:0;break}c[8452200+(c[2394]<<2)>>2]=0;c[2276080]=0;f=g;return f|0}}while(0);c[8452200+(c[2394]<<2)>>2]=h|1;c[2276080]=256;if((c[2276079]|0)>>>0>=256){f=g;return f|0}RH(1);f=g;return f|0}else if((d|0)==13631490){g=(e[4812881]|0)>>>8;do{if((c[2406632]|0)==0){h=c[2443744]|0;if((h|0)<=0){j=8;break}c[2443744]=h-1;j=0}else{j=(c[2432962]|0)>>>((c[(c[2420380]|0)+4>>2]|0)>>>0)<<3&8}}while(0);f=((j|g)^247)&255;return f|0}else if((d|0)==13631491){f=~(b[4812881]&255);return f|0}else if((d|0)==3145730|(d|0)==3145731){g=c[2113010]|0;c[2113010]=0;c[2430402]=0;j=c[3531294]|0;if((j|0)!=0){gf[j&2047](0)}f=g&255;return f|0}else if((d|0)==13631488){f=((e[4812880]|0)>>>8^255)&255;return f|0}else if((d|0)==13631489){f=~(b[4812880]&255);return f|0}else{f=0;return f|0}return 0}function atS(d){d=d|0;var f=0,g=0,h=0,i=0,j=0;if((d|0)==8388608){f=a[9541768]|6;a[9541768]=1;do{if((a[9542e3]|0)==0){a[9775672]=1;g=4096}else{h=(a[9775224]|0)==0;a[9775672]=h&1;if(h){g=h?4096:0;break}c[8452200+(c[2394]<<2)>>2]=0;c[2276080]=0;i=f;return i|0}}while(0);c[8452200+(c[2394]<<2)>>2]=g|1;c[2276080]=256;if((c[2276079]|0)>>>0>=256){i=f;return i|0}RH(1);i=f;return i|0}else if((d|0)==3145730){f=c[2113010]|0;c[2113010]=0;c[2430402]=0;g=c[3531294]|0;if((g|0)!=0){gf[g&2047](0)}i=f&65535;return i|0}else if((d|0)==8388610|(d|0)==8388612|(d|0)==8388614){i=a[9541768]|6;return i|0}else if((d|0)==13631488){i=~b[4812880];return i|0}else if((d|0)==13631490){d=e[4812881]|0;do{if((c[2406632]|0)==0){f=c[2443744]|0;if((f|0)<=0){j=2048;break}c[2443744]=f-1;j=0}else{j=(c[2432962]|0)>>>((c[(c[2420380]|0)+4>>2]|0)>>>0)<<11&2048}}while(0);i=((j|d)^63487)&65535;return i|0}else{i=0;return i|0}return 0}function atT(a,b){a=a|0;b=b|0;var d=0,e=0;if((a|0)==3145731){Ui(b);return}else if((a|0)==14680064){d=b&255;c[2415256]=d&8;e=d>>>1&1;c[3528406]=e^1;if((e|0)==0){c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2]}Tr(d>>>2&1);return}else if((a|0)==3145729){c[2113012]=b&255;return}else{return}}function atU(a,b){a=a|0;b=b|0;var d=0,e=0;if((a|0)==10485762){c[3542082]=b&65535;return}else if((a|0)==3145728){c[2113012]=b&255;return}else if((a|0)==8388616){gD[c[3542102]&8191]()|0;c[2113288]=b&65535;return}else if((a|0)==8388608){c[2113282]=b&65535;return}else if((a|0)==8388610){c[2113278]=b&65535;return}else if((a|0)==3145730){Ui(b&255);return}else if((a|0)==9437188){c[3542080]=b&65535;return}else if((a|0)==11534340){c[3542086]=b&65535;return}else if((a|0)==9437184){c[3542078]=b&65535;return}else if((a|0)==11534338){c[3542085]=b&65535;return}else if((a|0)==10485760){c[3542081]=b&65535;return}else if((a|0)==11534336){c[3542084]=b&65535;return}else if((a|0)==10485764){c[3542083]=b&65535;return}else if((a|0)==14680064){d=(b&65535)>>>8&65535;c[2415256]=d&8;e=d>>>1&1;c[3528406]=e^1;if((e|0)==0){c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2]}Tr(d>>>2&1);return}else if((a|0)==9437186){c[3542079]=b&65535;return}else{return}}function atV(b,d){b=b|0;d=d|0;var f=0,g=0;f=b&65535^1;b=c[3542108]|0;a[b+f|0]=d;g=(c[3527514]|0)+(f<<1)|0;if((a[g]|0)==d<<24>>24){return}a[g]=d;d=e[b+(f&65534)>>1]|0;b=d>>>7&248;c[(c[3542106]|0)+(f>>>1<<2)>>2]=d>>>2<<8&63488|d&31|(b>>>5|b)<<3&2016;return}function atW(a,d){a=a|0;d=d|0;var e=0;e=a>>>1&32767;b[(c[3542108]|0)+(e<<1)>>1]=d;a=(c[3527514]|0)+(e<<1)|0;if((b[a>>1]|0)==d<<16>>16){return}b[a>>1]=d;a=d&65535;d=a>>>7&248;c[(c[3542106]|0)+(e<<2)>>2]=a>>>2<<8&63488|a&31|(d>>>5|d)<<3&2016;return}function atX(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2963204+(b*112|0)>>2];c[a+104>>2]=c[2963208+(b*112|0)>>2];c[a+108>>2]=c[2963212+(b*112|0)>>2];d=0;return d|0}function atY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=2963104+(b*112|0);e=0;return e|0}function atZ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1113648+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function at_(){var b=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0;b=i;i=i+1200|0;e=b|0;f=b+112|0;g=b+120|0;j=b+232|0;k=b+240|0;l=b+352|0;m=b+360|0;n=b+472|0;o=b+480|0;p=b+592|0;q=b+600|0;r=b+712|0;s=b+720|0;t=b+832|0;u=b+840|0;v=b+952|0;w=b+960|0;x=b+1072|0;y=b+1080|0;z=b+1192|0;c[2424]=5755;c[2426736]=0;c[2418156]=0;c[3542098]=1048576;c[3542090]=17825792;c[3542091]=22020096;c[3542092]=26214400;c[3531292]=28311552;c[2440002]=32505856;c[2405670]=32505984;c[2418270]=32505984;c[3542094]=32571520;c[3542095]=32604288;c[3542096]=32637056;c[3542100]=32669824;c[3542108]=32735360;c[2411688]=32800896;A=0;while(1){if((A|0)>=1024){break}B=9638528+(A<<2)|0;if((c[B>>2]|0)==0){C=9465;break}else{A=A+1|0}}do{if((C|0)==9465){A=gGq(32800896)|0;c[B>>2]=A;if((A|0)==0){break}c[2426736]=A;gGz(A|0,0,32800896);c[2418156]=A;c[3542098]=A+1048576;c[3542090]=A+17825792;c[3542091]=A+22020096;c[3542092]=A+26214400;c[3531292]=A+28311552;c[2440002]=A+32505856;D=A+32505984|0;c[2405670]=D;c[2418270]=D;c[3542094]=A+32571520;c[3542095]=A+32604288;c[3542096]=A+32637056;c[3542100]=A+32669824;c[3542108]=A+32735360;D=A+32800896|0;c[2411688]=D;c[2414226]=D;R6(A,1,2)|0;A=(c[2418156]|0)+1|0;R6(A,0,2)|0;A=c[3542098]|0;do{if((c[3542200]|0)!=0){D=y+108|0;c[D>>2]=0;E=y+100|0;c[E>>2]=0;F=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[F&16383](y,2)|0;if((c[D>>2]|0)==0){break}D=c[E>>2]|0;c[z>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](z,2,0)|0;if((D|0)<1){break}gzL(A,0,2)|0}}while(0);A=(c[3542098]|0)+2097152|0;do{if((c[3542200]|0)!=0){D=w+108|0;c[D>>2]=0;E=w+100|0;c[E>>2]=0;F=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[F&16383](w,3)|0;if((c[D>>2]|0)==0){break}D=c[E>>2]|0;c[x>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](x,3,0)|0;if((D|0)<1){break}gzL(A,0,3)|0}}while(0);A=(c[3542098]|0)+4194304|0;do{if((c[3542200]|0)!=0){D=u+108|0;c[D>>2]=0;E=u+100|0;c[E>>2]=0;F=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[F&16383](u,4)|0;if((c[D>>2]|0)==0){break}D=c[E>>2]|0;c[v>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](v,4,0)|0;if((D|0)<1){break}gzL(A,0,4)|0}}while(0);A=(c[3542098]|0)+6291456|0;do{if((c[3542200]|0)!=0){D=s+108|0;c[D>>2]=0;E=s+100|0;c[E>>2]=0;F=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[F&16383](s,5)|0;if((c[D>>2]|0)==0){break}D=c[E>>2]|0;c[t>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](t,5,0)|0;if((D|0)<1){break}gzL(A,0,5)|0}}while(0);A=c[3542098]|0;D=0;E=A;while(1){F=a[E]|0;G=E+1|0;a[E]=a[G]|0;a[G]=F;F=D+1|0;if((F|0)<4194304){D=F;E=E+2|0}else{break}}E=A+8388607|0;D=A+16777214|0;F=0;while(1){a[D+1|0]=a[E]&15;a[D]=(d[E]|0)>>>4;G=F+1|0;if((G|0)<8388608){E=E-1|0;D=D-2|0;F=G}else{break}}F=c[3542090]|0;do{if((c[3542200]|0)!=0){D=q+108|0;c[D>>2]=0;E=q+100|0;c[E>>2]=0;A=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[A&16383](q,6)|0;if((c[D>>2]|0)==0){break}D=c[E>>2]|0;c[r>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](r,6,0)|0;if((D|0)<1){break}gzL(F,0,6)|0}}while(0);F=c[3542090]|0;D=F+2097151|0;E=F+4194302|0;F=0;while(1){a[E+1|0]=a[D]&15;a[E]=(d[D]|0)>>>4;A=F+1|0;if((A|0)<2097152){D=D-1|0;E=E-2|0;F=A}else{break}}F=c[3542091]|0;do{if((c[3542200]|0)!=0){E=o+108|0;c[E>>2]=0;D=o+100|0;c[D>>2]=0;A=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[A&16383](o,7)|0;if((c[E>>2]|0)==0){break}E=c[D>>2]|0;c[p>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](p,7,0)|0;if((E|0)<1){break}gzL(F,0,7)|0}}while(0);F=c[3542091]|0;E=F+2097151|0;D=F+4194302|0;F=0;while(1){a[D+1|0]=a[E]&15;a[D]=(d[E]|0)>>>4;A=F+1|0;if((A|0)<2097152){E=E-1|0;D=D-2|0;F=A}else{H=0;break}}while(1){if((H|0)>=1024){I=0;break}J=9638528+(H<<2)|0;if((c[J>>2]|0)==0){C=9501;break}else{H=H+1|0}}do{if((C|0)==9501){F=gGq(2097152)|0;c[J>>2]=F;if((F|0)==0){I=0;break}gGz(F|0,0,2097152);I=F}}while(0);do{if((c[3542200]|0)!=0){F=m+108|0;c[F>>2]=0;D=m+100|0;c[D>>2]=0;E=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[E&16383](m,8)|0;if((c[F>>2]|0)==0){break}F=c[D>>2]|0;c[n>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](n,8,0)|0;if((F|0)<1){break}gzL(I,0,8)|0}}while(0);F=c[3542092]|0;D=0;while(1){E=D<<1;A=I+E|0;G=E|1;K=I+G|0;a[F+G|0]=a[K]<<4|a[A]&15;a[F+E|0]=a[K]&-16|(d[A]|0)>>>4;A=D+1|0;if((A|0)<1048576){D=A}else{L=0;break}}while(1){if((L|0)>=1024){break}M=9638528+(L<<2)|0;if((c[M>>2]|0)==(I|0)){C=9511;break}else{L=L+1|0}}if((C|0)==9511){gGr(I);c[M>>2]=0}D=c[3531292]|0;do{if((c[3542200]|0)!=0){F=k+108|0;c[F>>2]=0;A=k+100|0;c[A>>2]=0;K=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[K&16383](k,9)|0;if((c[F>>2]|0)==0){break}F=c[A>>2]|0;c[l>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](l,9,0)|0;if((F|0)<1){break}gzL(D,0,9)|0}}while(0);D=(c[3531292]|0)+2097152|0;do{if((c[3542200]|0)!=0){F=g+108|0;c[F>>2]=0;A=g+100|0;c[A>>2]=0;K=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[K&16383](g,10)|0;if((c[F>>2]|0)==0){break}F=c[A>>2]|0;c[j>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](j,10,0)|0;if((F|0)<1){break}gzL(D,0,10)|0}}while(0);D=c[2440002]|0;do{if((c[3542200]|0)!=0){F=e+108|0;c[F>>2]=0;A=e+100|0;c[A>>2]=0;K=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[K&16383](e,11)|0;if((c[F>>2]|0)==0){break}F=c[A>>2]|0;c[f>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](f,11,0)|0;if((F|0)<1){break}gzL(D,0,11)|0}}while(0);Tq(690176);if(!(a[1040128]|0)){D=c[2440002]|0;gGC(14100392,D|0,128)|0}fxU(0,425984);if((c[2394]|0)==0){N=c[2112932]|0}else{c[2394]=0;D=c[3532596]|0;c[2112932]=D;F=c[3532592]|0;if((F|0)!=0){gGC(9104152,F|0,280)|0}c[2113054]=c[2113060];N=D}D=c[2418156]|0;F=N|0;A=0;while(1){K=D+A|0;c[F>>2]=K;c[F+131072>>2]=K;K=A+1024|0;if(K>>>0>1048575){break}else{F=F+4|0;A=K}}A=c[2418270]|0;F=N+4096|0;D=1048576;while(1){K=A+(D-1048576)|0;c[F>>2]=K;c[F+65536>>2]=K;c[F+131072>>2]=K;K=D+1024|0;if(K>>>0>1114111){break}else{F=F+4|0;D=K}}D=c[3542100]|0;F=N+16384|0;A=4194304;while(1){K=D+(A-4194304)|0;c[F>>2]=K;c[F+65536>>2]=K;c[F+131072>>2]=K;K=A+1024|0;if(K>>>0>4259839){break}else{F=F+4|0;A=K}}A=c[3542094]|0;F=N+20480|0;D=5242880;while(1){K=A+(D-5242880)|0;c[F>>2]=K;c[F+65536>>2]=K;c[F+131072>>2]=K;K=D+1024|0;if(K>>>0>5275647){break}else{F=F+4|0;D=K}}D=c[3542095]|0;F=N+24576|0;A=6291456;while(1){K=D+(A-6291456)|0;c[F>>2]=K;c[F+65536>>2]=K;c[F+131072>>2]=K;K=A+1024|0;if(K>>>0>6324223){break}else{F=F+4|0;A=K}}A=c[3542096]|0;F=A+16384|0;c[N+28672>>2]=F;c[N+94208>>2]=F;c[N+159744>>2]=F;D=A+17408|0;c[N+28676>>2]=D;c[N+94212>>2]=D;c[N+159748>>2]=D;K=A+18432|0;c[N+28680>>2]=K;c[N+94216>>2]=K;c[N+159752>>2]=K;E=A+19456|0;c[N+28684>>2]=E;c[N+94220>>2]=E;c[N+159756>>2]=E;G=A+20480|0;c[N+28688>>2]=G;c[N+94224>>2]=G;c[N+159760>>2]=G;O=A+21504|0;c[N+28692>>2]=O;c[N+94228>>2]=O;c[N+159764>>2]=O;P=A+22528|0;c[N+28696>>2]=P;c[N+94232>>2]=P;c[N+159768>>2]=P;Q=A+23552|0;c[N+28700>>2]=Q;c[N+94236>>2]=Q;c[N+159772>>2]=Q;R=A+24576|0;c[N+28704>>2]=R;c[N+94240>>2]=R;c[N+159776>>2]=R;S=A+25600|0;c[N+28708>>2]=S;c[N+94244>>2]=S;c[N+159780>>2]=S;T=A+26624|0;c[N+28712>>2]=T;c[N+94248>>2]=T;c[N+159784>>2]=T;U=A+27648|0;c[N+28716>>2]=U;c[N+94252>>2]=U;c[N+159788>>2]=U;V=A+28672|0;c[N+28720>>2]=V;c[N+94256>>2]=V;c[N+159792>>2]=V;W=A+29696|0;c[N+28724>>2]=W;c[N+94260>>2]=W;c[N+159796>>2]=W;X=A+30720|0;c[N+28728>>2]=X;c[N+94264>>2]=X;c[N+159800>>2]=X;Y=A+31744|0;c[N+28732>>2]=Y;c[N+94268>>2]=Y;c[N+159804>>2]=Y;c[N+28736>>2]=F;c[N+94272>>2]=F;c[N+159808>>2]=F;c[N+28740>>2]=D;c[N+94276>>2]=D;c[N+159812>>2]=D;c[N+28744>>2]=K;c[N+94280>>2]=K;c[N+159816>>2]=K;c[N+28748>>2]=E;c[N+94284>>2]=E;c[N+159820>>2]=E;c[N+28752>>2]=G;c[N+94288>>2]=G;c[N+159824>>2]=G;c[N+28756>>2]=O;c[N+94292>>2]=O;c[N+159828>>2]=O;c[N+28760>>2]=P;c[N+94296>>2]=P;c[N+159832>>2]=P;c[N+28764>>2]=Q;c[N+94300>>2]=Q;c[N+159836>>2]=Q;c[N+28768>>2]=R;c[N+94304>>2]=R;c[N+159840>>2]=R;c[N+28772>>2]=S;c[N+94308>>2]=S;c[N+159844>>2]=S;c[N+28776>>2]=T;c[N+94312>>2]=T;c[N+159848>>2]=T;c[N+28780>>2]=U;c[N+94316>>2]=U;c[N+159852>>2]=U;c[N+28784>>2]=V;c[N+94320>>2]=V;c[N+159856>>2]=V;c[N+28788>>2]=W;c[N+94324>>2]=W;c[N+159860>>2]=W;c[N+28792>>2]=X;c[N+94328>>2]=X;c[N+159864>>2]=X;c[N+28796>>2]=Y;c[N+94332>>2]=Y;c[N+159868>>2]=Y;c[N+28800>>2]=F;c[N+94336>>2]=F;c[N+159872>>2]=F;c[N+28804>>2]=D;c[N+94340>>2]=D;c[N+159876>>2]=D;c[N+28808>>2]=K;c[N+94344>>2]=K;c[N+159880>>2]=K;c[N+28812>>2]=E;c[N+94348>>2]=E;c[N+159884>>2]=E;c[N+28816>>2]=G;c[N+94352>>2]=G;c[N+159888>>2]=G;c[N+28820>>2]=O;c[N+94356>>2]=O;c[N+159892>>2]=O;c[N+28824>>2]=P;c[N+94360>>2]=P;c[N+159896>>2]=P;c[N+28828>>2]=Q;c[N+94364>>2]=Q;c[N+159900>>2]=Q;c[N+28832>>2]=R;c[N+94368>>2]=R;c[N+159904>>2]=R;c[N+28836>>2]=S;c[N+94372>>2]=S;c[N+159908>>2]=S;c[N+28840>>2]=T;c[N+94376>>2]=T;c[N+159912>>2]=T;c[N+28844>>2]=U;c[N+94380>>2]=U;c[N+159916>>2]=U;c[N+28848>>2]=V;c[N+94384>>2]=V;c[N+159920>>2]=V;c[N+28852>>2]=W;c[N+94388>>2]=W;c[N+159924>>2]=W;c[N+28856>>2]=X;c[N+94392>>2]=X;c[N+159928>>2]=X;c[N+28860>>2]=Y;c[N+94396>>2]=Y;c[N+159932>>2]=Y;c[N+28864>>2]=F;c[N+94400>>2]=F;c[N+159936>>2]=F;c[N+28868>>2]=D;c[N+94404>>2]=D;c[N+159940>>2]=D;c[N+28872>>2]=K;c[N+94408>>2]=K;c[N+159944>>2]=K;c[N+28876>>2]=E;c[N+94412>>2]=E;c[N+159948>>2]=E;c[N+28880>>2]=G;c[N+94416>>2]=G;c[N+159952>>2]=G;c[N+28884>>2]=O;c[N+94420>>2]=O;c[N+159956>>2]=O;c[N+28888>>2]=P;c[N+94424>>2]=P;c[N+159960>>2]=P;c[N+28892>>2]=Q;c[N+94428>>2]=Q;c[N+159964>>2]=Q;c[N+28896>>2]=R;c[N+94432>>2]=R;c[N+159968>>2]=R;c[N+28900>>2]=S;c[N+94436>>2]=S;c[N+159972>>2]=S;c[N+28904>>2]=T;c[N+94440>>2]=T;c[N+159976>>2]=T;c[N+28908>>2]=U;c[N+94444>>2]=U;c[N+159980>>2]=U;c[N+28912>>2]=V;c[N+94448>>2]=V;c[N+159984>>2]=V;c[N+28916>>2]=W;c[N+94452>>2]=W;c[N+159988>>2]=W;c[N+28920>>2]=X;c[N+94456>>2]=X;c[N+159992>>2]=X;c[N+28924>>2]=Y;c[N+94460>>2]=Y;c[N+159996>>2]=Y;Y=c[3542108]|0;X=N+49152|0;W=X;V=12582912;while(1){U=Y+(V-12582912)|0;c[W>>2]=U;c[W+131072>>2]=U;U=V+1024|0;if(U>>>0>12648447){Z=X;_=12582912;break}else{W=W+4|0;V=U}}while(1){c[Z+65536>>2]=1;V=_+1024|0;if(V>>>0>12648447){break}else{Z=Z+4|0;_=V}}c[N+196688>>2]=3330;c[N+196608>>2]=3426;c[N+196728>>2]=3468;c[N+196648>>2]=900;c[N+196732>>2]=3376;c[N+196652>>2]=670;V=c[3532592]|0;if((V|0)!=0){gGC(V|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;c[2113290]=1;V=0;while(1){if((V|0)>=1024){$=0;break}aa=9638528+(V<<2)|0;if((c[aa>>2]|0)==0){C=9549;break}else{V=V+1|0}}do{if((C|0)==9549){V=gGq(131072)|0;c[aa>>2]=V;if((V|0)==0){$=0;break}gGz(V|0,0,131072);$=V}}while(0);c[3542106]=$;gGz($|0,0,131072);V=0;while(1){if((V|0)>=1024){ab=0;break}ac=9638528+(V<<2)|0;if((c[ac>>2]|0)==0){C=9554;break}else{V=V+1|0}}do{if((C|0)==9554){V=gGq(65536)|0;c[ac>>2]=V;if((V|0)==0){ab=0;break}gGz(V|0,0,65536);ab=V}}while(0);c[3527514]=ab;gGz(ab|0,0,65536);c[2112966]=c[3542106];c[3542078]=0;c[3542079]=0;c[3542080]=16;c[3542081]=0;c[3542082]=0;c[3542083]=16;c[3542084]=0;c[3542085]=0;c[3542086]=16;c[3542087]=0;c[3542088]=0;c[3542089]=16;c[2113284]=0;V=c[642608+(c[2436]<<2)>>2]|0;if((c[V+52>>2]&4|0)==0){W=c[V+128>>2]|0;c[2113280]=W;ad=V+132|0;ae=W}else{W=c[V+132>>2]|0;c[2113280]=W;ad=V+128|0;ae=W}W=c[ad>>2]|0;c[2113276]=W;c[2406716]=ae-8;c[2394778]=ae-16;c[2406714]=W-8;c[2394776]=W-16;c[3528974]=c[3564288+(((ae|0)!=320)<<2)>>2];auH(0,16777216);axI(0,4194304,8,16384);axI(1,4194304,8,16384);axI(2,2097152,8,16384);Uf(16934400,1564);h[607287]=1.0;c[2433116]=1;h[607286]=1.0;c[2433114]=2;a[7072792]=1;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];W=c[3532592]|0;if((W|0)!=0){gGC(9104152,W|0,280)|0}c[2113054]=c[2113060]}RI();W=c[2394]|0;V=c[14130368+(W<<2)>>2]|0;if((V|0)!=0){gGC(V|0,9104152,280)|0}c[8452240+(W<<2)>>2]=c[2113054];c[2394]=-1;c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];gGz(14125184,0,668);c[2433532]=0;c[2430402]=0;c[2113010]=0;a[9753304]=0;c[2433552]=0;gGz(c[2430036]|0,0,16384);c[3531316]=4;gGz(c[2430037]|0,0,16384);c[3531337]=4;gGz(c[2430038]|0,0,16384);c[3531358]=4;gGz(c[2430039]|0,0,16384);c[3531379]=4;gGz(c[2430040]|0,0,16384);c[3531400]=4;gGz(c[2430041]|0,0,16384);c[3531421]=4;gGz(c[2430042]|0,0,16384);c[3531442]=4;gGz(c[2430043]|0,0,16384);c[3531463]=4;a[9541768]=1;a[9542e3]=1;a[9775224]=1;a[9775672]=0;af=0;i=b;return af|0}}while(0);c[2426736]=0;af=1;i=b;return af|0}function at$(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;i=i+128|0;d=c[2406694]|0;if((d|0)!=0){gGr(d);c[2406694]=0}c[3531294]=0;d=b|0;e=c[c[642608+(c[2436]<<2)>>2]>>2]|0;be(d|0,128,179600,(f=i,i=i+24|0,c[f>>2]=9374064,c[f+8>>2]=47,c[f+16>>2]=e,f)|0)|0;i=f;a[1040128]=0;f=c[2420380]|0;e=c[f>>2]|0;g=c[f+4>>2]|0;f=fw(d|0,389440)|0;if((f|0)!=0){d=g>>3<<e&1023;cj(14100392,d|0,1,f|0)|0;aY(f|0)|0}axH();f=c[2443764]|0;d=0;while(1){if((d|0)>=1024){break}h=9638528+(d<<2)|0;if((c[h>>2]|0)==(f|0)){j=9576;break}else{d=d+1|0}}if((j|0)==9576){gGr(f);c[h>>2]=0}c[2443764]=0;h=c[2394718]|0;f=0;while(1){if((f|0)>=1024){break}k=9638528+(f<<2)|0;if((c[k>>2]|0)==(h|0)){j=9580;break}else{f=f+1|0}}if((j|0)==9580){gGr(h);c[k>>2]=0}c[2394718]=0;a[7462192]=0;k=c[3542106]|0;h=0;while(1){if((h|0)>=1024){break}l=9638528+(h<<2)|0;if((c[l>>2]|0)==(k|0)){j=9584;break}else{h=h+1|0}}if((j|0)==9584){gGr(k);c[l>>2]=0}c[3542106]=0;l=c[3527514]|0;k=0;while(1){if((k|0)>=1024){break}m=9638528+(k<<2)|0;if((c[m>>2]|0)==(l|0)){j=9588;break}else{k=k+1|0}}if((j|0)==9588){gGr(l);c[m>>2]=0}c[3527514]=0;if((c[2392]|0)>=0){m=0;do{l=14130368+(m<<2)|0;k=c[l>>2]|0;if((k|0)!=0){gGr(k);c[l>>2]=0}l=14130384+(m<<2)|0;k=c[l>>2]|0;if((k|0)!=0){gGr(k);c[l>>2]=0}m=m+1|0;}while((m|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;m=c[2426736]|0;l=0;while(1){if((l|0)>=1024){j=9600;break}n=9638528+(l<<2)|0;if((c[n>>2]|0)==(m|0)){break}else{l=l+1|0}}if((j|0)==9600){c[2426736]=0;i=b;return 0}gGr(m);c[n>>2]=0;c[2426736]=0;i=b;return 0}function at0(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;if((a[9624264]|0)!=0){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];gGz(14125184,0,668);c[2433532]=0;c[2430402]=0;c[2113010]=0;a[9753304]=0;c[2433552]=0;gGz(c[2430036]|0,0,16384);c[3531316]=4;gGz(c[2430037]|0,0,16384);c[3531337]=4;gGz(c[2430038]|0,0,16384);c[3531358]=4;gGz(c[2430039]|0,0,16384);c[3531379]=4;gGz(c[2430040]|0,0,16384);c[3531400]=4;gGz(c[2430041]|0,0,16384);c[3531421]=4;gGz(c[2430042]|0,0,16384);c[3531442]=4;gGz(c[2430043]|0,0,16384);c[3531463]=4;a[9541768]=1;a[9542e3]=1;a[9775224]=1;a[9775672]=0}b[4812880]=0;b[4812881]=0;d=0;e=0;f=0;do{e=((a[9633552+d|0]&1)<<d|e&65535)&65535;f=((a[9631400+d|0]&1)<<d|f&65535)&65535;d=d+1|0;}while((d|0)<10);b[4812880]=e;b[4812881]=f;if((e&3)==3){d=e&-4;b[4812880]=d;g=d}else{g=e}if((g&12)==12){b[4812880]=g&-13}if((f&3)==3){g=f&-4;b[4812881]=g;h=g}else{h=f}if((h&12)==12){b[4812881]=h&-13}h=c[2392]|0;if((h|0)>=0){gGz(8452240,0,((h|0)>0?(h<<2)+4|0:4)|0)}c[2113054]=0;h=c[2438]|0;f=gGU(h,(h|0)<0|0?-1:0,16e6,0)|0;h=~~((+(f>>>0)+ +(K|0)*4294967296.0)/14732.965009208103);c[2440534]=h;c[2444090]=0;f=h-~~(+(h*12|0|0)/271.5)|0;a[9627152]=0;if((c[2394]|0)==0){i=1;j=0}else{c[2394]=0;c[2112932]=c[3532596];h=c[3532592]|0;if((h|0)!=0){gGC(9104152,h|0,280)|0}c[2113054]=c[2113060];i=1;j=0}while(1){h=c[2112964]|0;if((i&1|0)==0&(h|0)!=0){g=(ag(a[9688]|0?534:0,i)|0)/8|0;Ug(h+(j<<1<<1)|0,g-j|0);k=g}else{k=j}a[7024776]=0;g=(ag(c[2440534]|0,i)|0)/8|0;if((a[9627152]&1)==0&(g|0)>(f|0)){h=c[2444090]|0;if((h|0)<(f|0)){e=f-h|0;c[2113056]=e;h=RG(e)|0;c[2113054]=(c[2113054]|0)+h;c[2276108]=-1;c[2113056]=-1;e=9776360+(a[7024776]<<31>>31<<2)|0;c[e>>2]=(c[e>>2]|0)+h}h=c[2112968]|0;do{if((h|0)!=0){if((a[14168416]|0)==0){l=c[3542106]|0}else{e=c[3527514]|0;d=c[3542106]|0;m=c[3542108]|0;n=0;while(1){o=n<<8;p=0;q=m;r=e+(o<<1)|0;s=d+(o<<2)|0;while(1){o=b[q>>1]|0;b[r>>1]=o;t=o&65535;o=t>>>7&248;c[s>>2]=t>>>2<<8&63488|t&31|(o>>>5|o)<<3&2016;o=p+1|0;if((o|0)<256){p=o;q=q+2|0;r=r+2|0;s=s+4|0}else{break}}s=n+1|0;if((s|0)<128){m=m+512|0;n=s}else{break}}a[14168416]=0;l=d}n=c[l+130048>>2]|0;do{if((n|0)==0){gGz(h|0,0,ag(c[2113280]<<1,c[2113276]|0)|0)}else{m=n<<16|n;e=ag(c[2113276]|0,c[2113280]|0)|0;if((e|0)<=15){break}s=h;r=(e|0)/16|0;while(1){c[s>>2]=m;c[s+4>>2]=m;c[s+8>>2]=m;c[s+12>>2]=m;c[s+16>>2]=m;c[s+20>>2]=m;c[s+24>>2]=m;c[s+28>>2]=m;e=r-1|0;if((e|0)>0){s=s+32|0;r=e}else{break}}}}while(0);if(!(a[7072792]|0)){break}axE(1)}}while(0);a[9627152]=1;a[9541768]=0;a[9775672]=1;c[8452200+(c[2394]<<2)>>2]=4097;c[2276080]=256;if((c[2276079]|0)>>>0<256){RH(1)}u=a[7024776]<<31>>31}else{u=0}h=g-(c[9776360+(u<<2)>>2]|0)|0;c[2113056]=h;n=RG(h)|0;c[2113054]=(c[2113054]|0)+n;c[2276108]=-1;c[2113056]=-1;h=9776360+(a[7024776]<<31>>31<<2)|0;c[h>>2]=(c[h>>2]|0)+n;a[7024776]=1;n=i+1|0;if((n|0)<9){i=n;j=k}else{break}}j=c[2112964]|0;do{if((j|0)!=0){i=a[9688]|0?534:0;if((i|0)==(k|0)){break}Ug(j+(k<<1<<1)|0,i-k|0)}}while(0);k=c[2394]|0;j=c[14130368+(k<<2)>>2]|0;if((j|0)==0){v=c[2113054]|0;w=8452240+(k<<2)|0;c[w>>2]=v;c[2394]=-1;return 0}gGC(j|0,9104152,280)|0;v=c[2113054]|0;w=8452240+(k<<2)|0;c[w>>2]=v;c[2394]=-1;return 0}function at1(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((a[14168416]|0)==0){d=c[3542106]|0}else{e=c[3527514]|0;f=c[3542106]|0;g=c[3542108]|0;h=0;while(1){i=h<<8;j=0;k=g;l=e+(i<<1)|0;m=f+(i<<2)|0;while(1){i=b[k>>1]|0;b[l>>1]=i;n=i&65535;i=n>>>7&248;c[m>>2]=n>>>2<<8&63488|n&31|(i>>>5|i)<<3&2016;i=j+1|0;if((i|0)<256){j=i;k=k+2|0;l=l+2|0;m=m+4|0}else{break}}m=h+1|0;if((m|0)<128){g=g+512|0;h=m}else{break}}a[14168416]=0;d=f}f=c[d+130048>>2]|0;d=c[2112968]|0;do{if((f|0)==0){gGz(d|0,0,ag(c[2113280]<<1,c[2113276]|0)|0)}else{h=f<<16|f;g=ag(c[2113276]|0,c[2113280]|0)|0;if((g|0)<=15){break}e=d;m=(g|0)/16|0;while(1){c[e>>2]=h;c[e+4>>2]=h;c[e+8>>2]=h;c[e+12>>2]=h;c[e+16>>2]=h;c[e+20>>2]=h;c[e+24>>2]=h;c[e+28>>2]=h;g=m-1|0;if((g|0)>0){e=e+32|0;m=g}else{break}}}}while(0);if(!(a[7072792]|0)){return 0}axE(1);return 0}function at2(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;e=i;i=i+144|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;l=e+80|0;m=e+96|0;n=e+112|0;o=e+128|0;if((d|0)!=0){c[d>>2]=133378}Ts(b,d);if((b&96|0)!=0){gGz(o|0,0,12);d=c[2405670]|0;c[o>>2]=d;c[o+4>>2]=(c[2411688]|0)-d;c[o+12>>2]=219592;d=c[2076592]|0;gj[d&4095](o)|0;o=h|0;do{if((b&64|0)!=0){gGz(g|0,0,16);c[2394]=-1;if((c[2392]|0)<0){break}d=h+9|0;p=f;q=f|0;r=f+4|0;s=f+12|0;t=g|0;u=g+4|0;v=g+12|0;w=0;do{gGC(o|0,614896,11)|0;a[d]=w+48&255;x=8452256+(w<<2)|0;gGz(p|0,0,12);c[q>>2]=x;c[r>>2]=4;c[s>>2]=164976;gj[c[2076592]&4095](f)|0;if((c[x>>2]|0)!=0){c[t>>2]=c[14130368+(w<<2)>>2];c[u>>2]=c[8452184+(w<<2)>>2];c[v>>2]=o;x=c[2076592]|0;gj[x&4095](g)|0}w=w+1|0;}while((w|0)<=(c[2392]|0))}}while(0);Ue();gGz(n|0,0,12);c[n>>2]=9541768;c[n+4>>2]=1;c[n+12>>2]=148144;g=c[2076592]|0;gj[g&4095](n)|0;gGz(m|0,0,12);c[m>>2]=9542e3;c[m+4>>2]=1;c[m+12>>2]=118544;n=c[2076592]|0;gj[n&4095](m)|0;gGz(l|0,0,12);c[l>>2]=9775224;c[l+4>>2]=1;c[l+12>>2]=93520;m=c[2076592]|0;gj[m&4095](l)|0;gGz(k|0,0,12);c[k>>2]=9627152;c[k+4>>2]=1;c[k+12>>2]=490464;l=c[2076592]|0;gj[l&4095](k)|0;ayc();gGz(j|0,0,12);c[j>>2]=9625760;c[j+4>>2]=4;c[j+12>>2]=215728;k=c[2076592]|0;gj[k&4095](j)|0}if((b&2|0)==0){i=e;return 0}a[14168416]=1;i=e;return 0}function at3(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1577996+(b*112|0)>>2];c[a+104>>2]=c[1578e3+(b*112|0)>>2];c[a+108>>2]=c[1578004+(b*112|0)>>2];d=0;return d|0}function at4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=1577896+(b*112|0);e=0;return e|0}function at5(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1112404+(b*112|0)>>2];c[a+104>>2]=c[1112408+(b*112|0)>>2];c[a+108>>2]=c[1112412+(b*112|0)>>2];d=0;return d|0}function at6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=1112304+(b*112|0);e=0;return e|0}function at7(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=(b^1)&255;a[9542e3]=d;do{if((a[9541768]|0)==0|d<<24>>24==0){a[9775672]=1;e=4096;f=1;g=9717}else{b=(a[9775224]|0)==0;h=b&1;a[9775672]=h;if(b){e=b?4096:0;f=h;g=9717;break}c[8452200+(c[2394]<<2)>>2]=0;c[2276080]=0;i=h}}while(0);do{if((g|0)==9717){c[8452200+(c[2394]<<2)>>2]=e|1;c[2276080]=256;if((c[2276079]|0)>>>0>=256){i=f;break}RH(1);i=a[9775672]|0}}while(0);if(!(i<<24>>24!=0&a[7024776])){return}c[2113056]=1024;i=RG(1024)|0;c[2113054]=(c[2113054]|0)+i;c[2276108]=-1;c[2113056]=-1;c[2444090]=(c[2444090]|0)+i;return}function at8(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0;if((d|0)==11534353){f=c[2113157]&255;return f|0}else if((d|0)==9437190|(d|0)==9437191){g=a[9541760]|0;h=a[9775216]<<1|g;a[9775216]=1;i=8452200+(c[2394]<<2)|0;if(!(g<<24>>24==0|(a[9541992]|0)==0)){c[i>>2]=0;c[2276080]=0;f=h;return f|0}c[i>>2]=4097;c[2276080]=256;if((c[2276079]|0)>>>0>=256){f=h;return f|0}RH(1);f=h;return f|0}else if((d|0)==9437184|(d|0)==9437185|(d|0)==9437186|(d|0)==9437187){f=a[9775216]<<1|a[9541760];return f|0}else if((d|0)==11534337){f=c[2113156]&255;return f|0}else if((d|0)==12582914){h=(e[4812873]|0)>>>8;do{if((c[2406632]|0)==0){i=c[2443744]|0;if((i|0)<=0){j=8;break}c[2443744]=i-1;j=0}else{j=(c[2432962]|0)>>>((c[(c[2420380]|0)+4>>2]|0)>>>0)<<3&8}}while(0);f=((j|h)^247)&255;return f|0}else if((d|0)==12582915){f=~(b[4812873]&255);return f|0}else if((d|0)==9437188|(d|0)==9437189){h=a[9775216]|0;j=h<<1|a[9541760];a[9541760]=1;do{if((a[9541992]|0)==0){k=4096}else{i=h<<24>>24==0;if(i){k=i?4096:0;break}c[8452200+(c[2394]<<2)>>2]=0;c[2276080]=0;f=j;return f|0}}while(0);c[8452200+(c[2394]<<2)>>2]=k|1;c[2276080]=256;if((c[2276079]|0)>>>0>=256){f=j;return f|0}RH(1);f=j;return f|0}else if((d|0)==12582913){f=~(b[4812872]&255);return f|0}else if((d|0)==12582912){f=((e[4812872]|0)>>>8^255)&255;return f|0}else{f=0;return f|0}return 0}function at9(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0;if((d|0)==11534352){f=c[2113157]&65535;return f|0}else if((d|0)==9437184|(d|0)==9437186){f=a[9775216]<<1|a[9541760];return f|0}else if((d|0)==9437188){g=a[9775216]|0;h=g<<24>>24<<1|a[9541760];a[9541760]=1;do{if((a[9541992]|0)==0){i=4096}else{j=g<<24>>24==0;if(j){i=j?4096:0;break}c[8452200+(c[2394]<<2)>>2]=0;c[2276080]=0;f=h;return f|0}}while(0);c[8452200+(c[2394]<<2)>>2]=i|1;c[2276080]=256;if((c[2276079]|0)>>>0>=256){f=h;return f|0}RH(1);f=h;return f|0}else if((d|0)==9437190){h=a[9541760]|0;i=a[9775216]<<1|h<<24>>24;a[9775216]=1;g=8452200+(c[2394]<<2)|0;if(!(h<<24>>24==0|(a[9541992]|0)==0)){c[g>>2]=0;c[2276080]=0;f=i;return f|0}c[g>>2]=4097;c[2276080]=256;if((c[2276079]|0)>>>0>=256){f=i;return f|0}RH(1);f=i;return f|0}else if((d|0)==11534336){f=c[2113156]&65535;return f|0}else if((d|0)==12582914){i=e[4812873]|0;do{if((c[2406632]|0)==0){g=c[2443744]|0;if((g|0)<=0){k=2048;break}c[2443744]=g-1;k=0}else{k=(c[2432962]|0)>>>((c[(c[2420380]|0)+4>>2]|0)>>>0)<<11&2048}}while(0);f=((k|i)^63487)&65535;return f|0}else if((d|0)==12582912){f=~b[4812872];return f|0}else{f=0;return f|0}return 0}function aua(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;if((a|0)==13631488){d=b&255;c[2415256]=d&8;e=d>>>1&1;c[3528406]=e^1;if((e|0)==0){c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2]}Tr(d>>>2&1);return}else if((a|0)==11534352|(a|0)==11534353|(a|0)==11534354|(a|0)==11534355){Uv(1,b);return}else if((a|0)==11534368|(a|0)==11534369|(a|0)==11534370|(a|0)==11534371|(a|0)==11534372|(a|0)==11534373|(a|0)==11534374|(a|0)==11534375|(a|0)==11534376|(a|0)==11534377|(a|0)==11534378|(a|0)==11534379|(a|0)==11534380|(a|0)==11534381|(a|0)==11534382|(a|0)==11534383){d=a>>>3&1;e=c[632392+(d<<2)>>2]|0;f=(b&255)<<16;while(1){if((f|0)>(e|0)){f=f-e|0}else{break}}e=a>>>1&3;g=c[3541206]|0;if((d|0)!=0){c[14164808+(e<<2)>>2]=g+f;c[14164776+(e<<2)>>2]=g+(f+(e<<8));return}d=g+(f+1048576)|0;c[14164792+(e<<2)>>2]=d;if((e|0)!=0){return}c[3541190]=d;c[3541191]=g+(f+1048832);c[3541192]=g+(f+1049088);c[3541193]=g+(f+1049344);return}else if((a|0)==11534336|(a|0)==11534337|(a|0)==11534338|(a|0)==11534339){Uv(0,b);return}else{return}}function aub(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;if((a|0)==7340032){c[3542078]=b&65535;return}else if((a|0)==6291456){c[3542081]=b&65535;return}else if((a|0)==6291458){c[3542082]=b&65535;return}else if((a|0)==6291460){c[3542083]=b&65535;return}else if((a|0)==8388608){c[3542084]=b&65535;return}else if((a|0)==7340034){c[3542079]=b&65535;return}else if((a|0)==9437184){c[2113282]=b&65535;return}else if((a|0)==11534352|(a|0)==11534354){Uv(1,b&255);return}else if((a|0)==13631488){d=(b&65535)>>>8&65535;c[2415256]=d&8;e=d>>>1&1;c[3528406]=e^1;if((e|0)==0){c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2]}Tr(d>>>2&1);return}else if((a|0)==7340036){c[3542080]=b&65535;return}else if((a|0)==9437192){gD[c[3542102]&8191]()|0;c[2113288]=b&65535;return}else if((a|0)==11534368|(a|0)==11534369|(a|0)==11534370|(a|0)==11534371|(a|0)==11534372|(a|0)==11534373|(a|0)==11534374|(a|0)==11534375|(a|0)==11534376|(a|0)==11534377|(a|0)==11534378|(a|0)==11534379|(a|0)==11534380|(a|0)==11534381|(a|0)==11534382|(a|0)==11534383){d=a>>>3&1;e=c[632392+(d<<2)>>2]|0;f=(b&65535)<<16;while(1){if((f|0)>(e|0)){f=f-e|0}else{break}}e=a>>>1&3;g=c[3541206]|0;if((d|0)!=0){c[14164808+(e<<2)>>2]=g+f;c[14164776+(e<<2)>>2]=g+(f+(e<<8));return}d=g+(f+1048576)|0;c[14164792+(e<<2)>>2]=d;if((e|0)!=0){return}c[3541190]=d;c[3541191]=g+(f+1048832);c[3541192]=g+(f+1049088);c[3541193]=g+(f+1049344);return}else if((a|0)==8388610){c[3542085]=b&65535;return}else if((a|0)==8388612){c[3542086]=b&65535;return}else if((a|0)==11534336|(a|0)==11534338){Uv(0,b&255);return}else if((a|0)==9437186){c[2113278]=b&65535;return}else{return}}function auc(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2929380+(b*112|0)>>2];c[a+104>>2]=c[2929384+(b*112|0)>>2];c[a+108>>2]=c[2929388+(b*112|0)>>2];d=0;return d|0}function aud(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=2929280+(b*112|0);e=0;return e|0}function aue(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1107872+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function auf(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0;b=i;i=i+1080|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;l=b+360|0;m=b+472|0;n=b+480|0;o=b+592|0;p=b+600|0;q=b+712|0;r=b+720|0;s=b+832|0;t=b+840|0;u=b+952|0;v=b+960|0;w=b+1072|0;c[2424]=5755;c[2426728]=0;c[2418154]=0;c[3542098]=524288;c[3542090]=8912896;c[3542091]=11010048;c[3542092]=13107200;c[3541206]=13631488;c[244e4]=16777216;c[2405662]=16777344;c[2418268]=16777344;c[3542094]=16842880;c[3542095]=16875648;c[3542096]=16908416;c[3542100]=16941184;c[3542108]=17006720;c[2411676]=17010816;x=0;while(1){if((x|0)>=1024){break}y=9638528+(x<<2)|0;if((c[y>>2]|0)==0){z=9879;break}else{x=x+1|0}}do{if((z|0)==9879){x=gGq(17010816)|0;c[y>>2]=x;if((x|0)==0){break}c[2426728]=x;gGz(x|0,0,17010816);c[2418154]=x;c[3542098]=x+524288;c[3542090]=x+8912896;c[3542091]=x+11010048;c[3542092]=x+13107200;c[3541206]=x+13631488;c[244e4]=x+16777216;A=x+16777344|0;c[2405662]=A;c[2418268]=A;c[3542094]=x+16842880;c[3542095]=x+16875648;c[3542096]=x+16908416;c[3542100]=x+16941184;c[3542108]=x+17006720;A=x+17010816|0;c[2411676]=A;c[2414216]=A;do{if((c[3542200]|0)!=0){A=v+108|0;c[A>>2]=0;B=v+100|0;c[B>>2]=0;C=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[C&16383](v,0)|0;if((c[A>>2]|0)==0){break}A=c[B>>2]|0;c[w>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](w,0,0)|0;if((A|0)<1){break}gzL(x,0,0)|0}}while(0);x=c[3542098]|0;do{if((c[3542200]|0)!=0){A=t+108|0;c[A>>2]=0;B=t+100|0;c[B>>2]=0;C=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[C&16383](t,1)|0;if((c[A>>2]|0)==0){break}A=c[B>>2]|0;c[u>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](u,1,0)|0;if((A|0)<1){break}gzL(x,0,1)|0}}while(0);x=(c[3542098]|0)+2097152|0;do{if((c[3542200]|0)!=0){A=r+108|0;c[A>>2]=0;B=r+100|0;c[B>>2]=0;C=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[C&16383](r,2)|0;if((c[A>>2]|0)==0){break}A=c[B>>2]|0;c[s>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](s,2,0)|0;if((A|0)<1){break}gzL(x,0,2)|0}}while(0);x=c[3542098]|0;A=0;B=x;while(1){C=a[B]|0;D=B+1|0;a[B]=a[D]|0;a[D]=C;C=A+1|0;if((C|0)<2097152){A=C;B=B+2|0}else{break}}B=x+4194303|0;A=x+8388606|0;C=0;while(1){a[A+1|0]=a[B]&15;a[A]=(d[B]|0)>>>4;D=C+1|0;if((D|0)<4194304){B=B-1|0;A=A-2|0;C=D}else{break}}C=c[3542090]|0;do{if((c[3542200]|0)!=0){A=p+108|0;c[A>>2]=0;B=p+100|0;c[B>>2]=0;x=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[x&16383](p,3)|0;if((c[A>>2]|0)==0){break}A=c[B>>2]|0;c[q>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](q,3,0)|0;if((A|0)<1){break}gzL(C,0,3)|0}}while(0);C=c[3542090]|0;A=C+1048575|0;B=C+2097150|0;C=0;while(1){a[B+1|0]=a[A]&15;a[B]=(d[A]|0)>>>4;x=C+1|0;if((x|0)<1048576){A=A-1|0;B=B-2|0;C=x}else{break}}C=c[3542091]|0;do{if((c[3542200]|0)!=0){B=n+108|0;c[B>>2]=0;A=n+100|0;c[A>>2]=0;x=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[x&16383](n,4)|0;if((c[B>>2]|0)==0){break}B=c[A>>2]|0;c[o>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](o,4,0)|0;if((B|0)<1){break}gzL(C,0,4)|0}}while(0);C=c[3542091]|0;B=C+1048575|0;A=C+2097150|0;C=0;while(1){a[A+1|0]=a[B]&15;a[A]=(d[B]|0)>>>4;x=C+1|0;if((x|0)<1048576){B=B-1|0;A=A-2|0;C=x}else{break}}C=c[3542092]|0;do{if((c[3542200]|0)!=0){A=l+108|0;c[A>>2]=0;B=l+100|0;c[B>>2]=0;x=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[x&16383](l,5)|0;if((c[A>>2]|0)==0){break}A=c[B>>2]|0;c[m>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](m,5,0)|0;if((A|0)<1){break}gzL(C,0,5)|0}}while(0);C=c[3542092]|0;A=C+262143|0;B=C+524286|0;C=0;while(1){a[B+1|0]=a[A]&15;a[B]=(d[A]|0)>>>4;x=C+1|0;if((x|0)<262144){A=A-1|0;B=B-2|0;C=x}else{break}}C=c[3541206]|0;do{if((c[3542200]|0)!=0){B=j+108|0;c[B>>2]=0;A=j+100|0;c[A>>2]=0;x=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[x&16383](j,6)|0;if((c[B>>2]|0)==0){break}B=c[A>>2]|0;c[k>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](k,6,0)|0;if((B|0)<1){break}gzL(C,0,6)|0}}while(0);C=(c[3541206]|0)+1048576|0;do{if((c[3542200]|0)!=0){B=g+108|0;c[B>>2]=0;A=g+100|0;c[A>>2]=0;x=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[x&16383](g,7)|0;if((c[B>>2]|0)==0){break}B=c[A>>2]|0;c[h>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](h,7,0)|0;if((B|0)<1){break}gzL(C,0,7)|0}}while(0);C=c[244e4]|0;do{if((c[3542200]|0)!=0){B=e+108|0;c[B>>2]=0;A=e+100|0;c[A>>2]=0;x=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[x&16383](e,8)|0;if((c[B>>2]|0)==0){break}B=c[A>>2]|0;c[f>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](f,8,0)|0;if((B|0)<1){break}gzL(C,0,8)|0}}while(0);Tq(690136);if(!(a[1040128]|0)){C=c[244e4]|0;gGC(14100392,C|0,128)|0}fxU(0,425984);if((c[2394]|0)==0){E=c[2112932]|0}else{c[2394]=0;C=c[3532596]|0;c[2112932]=C;B=c[3532592]|0;if((B|0)!=0){gGC(9104152,B|0,280)|0}c[2113054]=c[2113060];E=C}C=c[2418154]|0;B=E|0;A=0;while(1){x=C+A|0;c[B>>2]=x;c[B+131072>>2]=x;x=A+1024|0;if(x>>>0>524287){break}else{B=B+4|0;A=x}}A=c[2418268]|0;B=E+4096|0;C=1048576;while(1){x=A+(C-1048576)|0;c[B>>2]=x;c[B+65536>>2]=x;c[B+131072>>2]=x;x=C+1024|0;if(x>>>0>1114111){break}else{B=B+4|0;C=x}}C=c[3542095]|0;B=E+8192|0;A=2097152;while(1){x=C+(A-2097152)|0;c[B>>2]=x;c[B+65536>>2]=x;c[B+131072>>2]=x;x=A+1024|0;if(x>>>0>2129919){break}else{B=B+4|0;A=x}}A=c[3542094]|0;B=E+12288|0;C=3145728;while(1){x=A+(C-3145728)|0;c[B>>2]=x;c[B+65536>>2]=x;c[B+131072>>2]=x;x=C+1024|0;if(x>>>0>3178495){break}else{B=B+4|0;C=x}}C=c[3542096]|0;B=C+16384|0;c[E+16384>>2]=B;c[E+81920>>2]=B;c[E+147456>>2]=B;A=C+17408|0;c[E+16388>>2]=A;c[E+81924>>2]=A;c[E+147460>>2]=A;x=C+18432|0;c[E+16392>>2]=x;c[E+81928>>2]=x;c[E+147464>>2]=x;D=C+19456|0;c[E+16396>>2]=D;c[E+81932>>2]=D;c[E+147468>>2]=D;F=C+20480|0;c[E+16400>>2]=F;c[E+81936>>2]=F;c[E+147472>>2]=F;G=C+21504|0;c[E+16404>>2]=G;c[E+81940>>2]=G;c[E+147476>>2]=G;H=C+22528|0;c[E+16408>>2]=H;c[E+81944>>2]=H;c[E+147480>>2]=H;I=C+23552|0;c[E+16412>>2]=I;c[E+81948>>2]=I;c[E+147484>>2]=I;J=C+24576|0;c[E+16416>>2]=J;c[E+81952>>2]=J;c[E+147488>>2]=J;K=C+25600|0;c[E+16420>>2]=K;c[E+81956>>2]=K;c[E+147492>>2]=K;L=C+26624|0;c[E+16424>>2]=L;c[E+81960>>2]=L;c[E+147496>>2]=L;M=C+27648|0;c[E+16428>>2]=M;c[E+81964>>2]=M;c[E+147500>>2]=M;N=C+28672|0;c[E+16432>>2]=N;c[E+81968>>2]=N;c[E+147504>>2]=N;O=C+29696|0;c[E+16436>>2]=O;c[E+81972>>2]=O;c[E+147508>>2]=O;P=C+30720|0;c[E+16440>>2]=P;c[E+81976>>2]=P;c[E+147512>>2]=P;Q=C+31744|0;c[E+16444>>2]=Q;c[E+81980>>2]=Q;c[E+147516>>2]=Q;c[E+16448>>2]=B;c[E+81984>>2]=B;c[E+147520>>2]=B;c[E+16452>>2]=A;c[E+81988>>2]=A;c[E+147524>>2]=A;c[E+16456>>2]=x;c[E+81992>>2]=x;c[E+147528>>2]=x;c[E+16460>>2]=D;c[E+81996>>2]=D;c[E+147532>>2]=D;c[E+16464>>2]=F;c[E+82e3>>2]=F;c[E+147536>>2]=F;c[E+16468>>2]=G;c[E+82004>>2]=G;c[E+147540>>2]=G;c[E+16472>>2]=H;c[E+82008>>2]=H;c[E+147544>>2]=H;c[E+16476>>2]=I;c[E+82012>>2]=I;c[E+147548>>2]=I;c[E+16480>>2]=J;c[E+82016>>2]=J;c[E+147552>>2]=J;c[E+16484>>2]=K;c[E+82020>>2]=K;c[E+147556>>2]=K;c[E+16488>>2]=L;c[E+82024>>2]=L;c[E+147560>>2]=L;c[E+16492>>2]=M;c[E+82028>>2]=M;c[E+147564>>2]=M;c[E+16496>>2]=N;c[E+82032>>2]=N;c[E+147568>>2]=N;c[E+16500>>2]=O;c[E+82036>>2]=O;c[E+147572>>2]=O;c[E+16504>>2]=P;c[E+82040>>2]=P;c[E+147576>>2]=P;c[E+16508>>2]=Q;c[E+82044>>2]=Q;c[E+147580>>2]=Q;Q=c[3542100]|0;P=E+20480|0;O=5242880;while(1){N=Q+(O-5242880)|0;c[P>>2]=N;c[P+65536>>2]=N;c[P+131072>>2]=N;N=O+1024|0;if(N>>>0>5308415){break}else{P=P+4|0;O=N}}O=c[3542108]|0;c[E+41088>>2]=O;c[E+106624>>2]=O;c[E+172160>>2]=O;P=O+1024|0;c[E+41092>>2]=P;c[E+106628>>2]=P;c[E+172164>>2]=P;P=O+2048|0;c[E+41096>>2]=P;c[E+106632>>2]=P;c[E+172168>>2]=P;P=O+3072|0;c[E+41100>>2]=P;c[E+106636>>2]=P;c[E+172172>>2]=P;c[E+196688>>2]=1202;c[E+196608>>2]=1562;c[E+196728>>2]=2282;c[E+196648>>2]=1750;P=c[3532592]|0;if((P|0)!=0){gGC(P|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;P=0;while(1){if((P|0)>=1024){R=0;break}S=9638528+(P<<2)|0;if((c[S>>2]|0)==0){z=9949;break}else{P=P+1|0}}do{if((z|0)==9949){P=gGq(131072)|0;c[S>>2]=P;if((P|0)==0){R=0;break}gGz(P|0,0,131072);R=P}}while(0);c[3542106]=R;gGz(R|0,0,131072);P=0;while(1){if((P|0)>=1024){T=0;break}U=9638528+(P<<2)|0;if((c[U>>2]|0)==0){z=9954;break}else{P=P+1|0}}do{if((z|0)==9954){P=gGq(65536)|0;c[U>>2]=P;if((P|0)==0){T=0;break}gGz(P|0,0,65536);T=P}}while(0);c[3527514]=T;gGz(T|0,0,65536);c[2112966]=c[3542106];c[3542078]=0;c[3542079]=0;c[3542080]=16;c[3542081]=0;c[3542082]=0;c[3542083]=16;c[3542084]=0;c[3542085]=0;c[3542086]=16;c[3542087]=0;c[3542088]=0;c[3542089]=16;c[2113284]=0;P=c[642608+(c[2436]<<2)>>2]|0;if((c[P+52>>2]&4|0)==0){O=c[P+128>>2]|0;c[2113280]=O;V=P+132|0;W=O}else{O=c[P+132>>2]|0;c[2113280]=O;V=P+128|0;W=O}O=c[V>>2]|0;c[2113276]=O;c[2406716]=W-8;c[2394778]=W-16;c[2406714]=O-8;c[2394776]=O-16;c[3528974]=c[3564288+(((W|0)!=320)<<2)>>2];auH(0,8388608);axI(0,2097152,8,16384);axI(1,2097152,8,16384);axI(2,524288,8,16384);Ux(0,8e3,0);Ux(1,16e3,0);c[2407030]=410;c[2407068]=3;c[2407069]=256;c[2407107]=3;O=c[3541206]|0;P=O+1048576|0;c[3541198]=P;c[3541190]=P;c[3541199]=P;c[3541191]=O+1048832;c[3541200]=P;c[3541192]=O+1049088;c[3541201]=P;c[3541193]=O+1049344;a[7072784]=1;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];O=c[3532592]|0;if((O|0)!=0){gGC(9104152,O|0,280)|0}c[2113054]=c[2113060]}RI();O=c[2394]|0;P=c[14130368+(O<<2)>>2]|0;if((P|0)!=0){gGC(P|0,9104152,280)|0}c[8452240+(O<<2)>>2]=c[2113054];c[2394]=-1;c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];a[9541760]=1;a[9541992]=1;a[9775216]=1;c[2113156]=0;a[9628264]=0;c[2407033]=0;O=c[3541206]|0;c[3541190]=O;c[3541198]=O;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=O+256;c[3541199]=O+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=O+512;c[3541200]=O+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=O+768;c[3541201]=O+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2113157]=0;a[9628420]=0;c[2407072]=0;P=O+1048576|0;c[3541194]=P;c[3541202]=P;gGz(c[2430122]|0,0,16384);c[2407080]=4;c[3541195]=O+1048832;c[3541203]=O+1114112;gGz(c[2430123]|0,0,16384);c[2407088]=4;c[3541196]=O+1049088;c[3541204]=O+1179648;gGz(c[2430124]|0,0,16384);c[2407096]=4;c[3541197]=O+1049344;c[3541205]=O+1245184;gGz(c[2430125]|0,0,16384);c[2407104]=4;X=0;i=b;return X|0}}while(0);c[2426728]=0;X=1;i=b;return X|0}function aug(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;i=i+128|0;d=b|0;e=c[c[642608+(c[2436]<<2)>>2]>>2]|0;be(d|0,128,179600,(f=i,i=i+24|0,c[f>>2]=9374064,c[f+8>>2]=47,c[f+16>>2]=e,f)|0)|0;i=f;a[1040128]=0;f=c[2420380]|0;e=c[f>>2]|0;g=c[f+4>>2]|0;f=fw(d|0,389440)|0;if((f|0)!=0){d=g>>3<<e&1023;cj(14100392,d|0,1,f|0)|0;aY(f|0)|0}Uw(0);Uw(1);axH();f=c[2443764]|0;d=0;while(1){if((d|0)>=1024){break}h=9638528+(d<<2)|0;if((c[h>>2]|0)==(f|0)){j=9974;break}else{d=d+1|0}}if((j|0)==9974){gGr(f);c[h>>2]=0}c[2443764]=0;h=c[2394718]|0;f=0;while(1){if((f|0)>=1024){break}k=9638528+(f<<2)|0;if((c[k>>2]|0)==(h|0)){j=9978;break}else{f=f+1|0}}if((j|0)==9978){gGr(h);c[k>>2]=0}c[2394718]=0;a[7462192]=0;k=c[3542106]|0;h=0;while(1){if((h|0)>=1024){break}l=9638528+(h<<2)|0;if((c[l>>2]|0)==(k|0)){j=9982;break}else{h=h+1|0}}if((j|0)==9982){gGr(k);c[l>>2]=0}c[3542106]=0;l=c[3527514]|0;k=0;while(1){if((k|0)>=1024){break}m=9638528+(k<<2)|0;if((c[m>>2]|0)==(l|0)){j=9986;break}else{k=k+1|0}}if((j|0)==9986){gGr(l);c[m>>2]=0}c[3527514]=0;if((c[2392]|0)>=0){m=0;do{l=14130368+(m<<2)|0;k=c[l>>2]|0;if((k|0)!=0){gGr(k);c[l>>2]=0}l=14130384+(m<<2)|0;k=c[l>>2]|0;if((k|0)!=0){gGr(k);c[l>>2]=0}m=m+1|0;}while((m|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;m=c[2426728]|0;l=0;while(1){if((l|0)>=1024){j=9998;break}n=9638528+(l<<2)|0;if((c[n>>2]|0)==(m|0)){break}else{l=l+1|0}}if((j|0)==9998){c[2426728]=0;i=b;return 0}gGr(m);c[n>>2]=0;c[2426728]=0;i=b;return 0}function auh(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;if((a[9624232]|0)!=0){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];a[9541760]=1;a[9541992]=1;a[9775216]=1;c[2113156]=0;a[9628264]=0;c[2407033]=0;d=c[3541206]|0;c[3541190]=d;c[3541198]=d;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=d+256;c[3541199]=d+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=d+512;c[3541200]=d+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=d+768;c[3541201]=d+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2113157]=0;a[9628420]=0;c[2407072]=0;e=d+1048576|0;c[3541194]=e;c[3541202]=e;gGz(c[2430122]|0,0,16384);c[2407080]=4;c[3541195]=d+1048832;c[3541203]=d+1114112;gGz(c[2430123]|0,0,16384);c[2407088]=4;c[3541196]=d+1049088;c[3541204]=d+1179648;gGz(c[2430124]|0,0,16384);c[2407096]=4;c[3541197]=d+1049344;c[3541205]=d+1245184;gGz(c[2430125]|0,0,16384);c[2407104]=4}b[4812872]=0;b[4812873]=0;d=0;e=0;f=0;do{e=((a[9633512+d|0]&1)<<d|e&65535)&65535;f=((a[9631368+d|0]&1)<<d|f&65535)&65535;d=d+1|0;}while((d|0)<10);b[4812872]=e;b[4812873]=f;if((e&3)==3){d=e&-4;b[4812872]=d;g=d}else{g=e}if((g&12)==12){b[4812872]=g&-13}if((f&3)==3){g=f&-4;b[4812873]=g;h=g}else{h=f}if((h&12)==12){b[4812873]=h&-13}h=c[2392]|0;if((h|0)>=0){gGz(8452240,0,((h|0)>0?(h<<2)+4|0:4)|0)}c[2113054]=0;h=c[2438]|0;f=gGU(h,(h|0)<0|0?-1:0,16e6,0)|0;h=~~((+(f>>>0)+ +(K|0)*4294967296.0)/14732.965009208103);f=h-~~(+(h*12|0|0)/271.5)|0;a[9627144]=0;if((c[2394]|0)==0){i=0;j=1;k=1}else{c[2394]=0;c[2112932]=c[3532596];g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060];i=0;j=1;k=1}while(1){g=(ag(j,h)|0)/8|0;do{if(k&(g|0)>(f|0)){if((i|0)<(f|0)){e=f-i|0;c[2113056]=e;d=RG(e)|0;c[2113054]=(c[2113054]|0)+d;c[2276108]=-1;c[2113056]=-1;l=d+i|0}else{l=i}d=c[2112968]|0;do{if((d|0)!=0){avg(128);e=c[(c[3542106]|0)+130048>>2]|0;do{if((e|0)==0){gGz(d|0,0,ag(c[2113280]<<1,c[2113276]|0)|0)}else{m=e<<16|e;n=ag(c[2113276]|0,c[2113280]|0)|0;if((n|0)<=15){break}o=d;p=(n|0)/16|0;while(1){c[o>>2]=m;c[o+4>>2]=m;c[o+8>>2]=m;c[o+12>>2]=m;c[o+16>>2]=m;c[o+20>>2]=m;c[o+24>>2]=m;c[o+28>>2]=m;n=p-1|0;if((n|0)>0){o=o+32|0;p=n}else{break}}}}while(0);if(!(a[7072784]|0)){break}axE(1)}}while(0);a[9627144]=1;a[9541760]=0;c[8452200+(c[2394]<<2)>>2]=4097;c[2276080]=256;if((c[2276079]|0)>>>0>=256){q=l;break}RH(1);q=l}else{q=i}}while(0);d=g-q|0;c[2113056]=d;e=RG(d)|0;r=(c[2113054]|0)+e|0;c[2113054]=r;c[2276108]=-1;c[2113056]=-1;d=j+1|0;if((d|0)>=9){break}i=e+q|0;j=d;k=(a[9627144]&1)==0}k=c[2112964]|0;do{if((k|0)!=0){j=a[9688]|0;q=j?534:0;if(!j){break}Uu(0,k,q);Uu(1,k,q)}}while(0);k=c[2394]|0;q=c[14130368+(k<<2)>>2]|0;if((q|0)==0){s=8452240+(k<<2)|0;c[s>>2]=r;c[2394]=-1;return 0}gGC(q|0,9104152,280)|0;s=8452240+(k<<2)|0;c[s>>2]=r;c[2394]=-1;return 0}function aui(){var b=0,d=0,e=0,f=0,g=0,h=0;avg(128);b=c[(c[3542106]|0)+130048>>2]|0;d=c[2112968]|0;do{if((b|0)==0){gGz(d|0,0,ag(c[2113280]<<1,c[2113276]|0)|0)}else{e=b<<16|b;f=ag(c[2113276]|0,c[2113280]|0)|0;if((f|0)<=15){break}g=d;h=(f|0)/16|0;while(1){c[g>>2]=e;c[g+4>>2]=e;c[g+8>>2]=e;c[g+12>>2]=e;c[g+16>>2]=e;c[g+20>>2]=e;c[g+24>>2]=e;c[g+28>>2]=e;f=h-1|0;if((f|0)>0){g=g+32|0;h=f}else{break}}}}while(0);if(!(a[7072784]|0)){return 0}axE(1);return 0}function auj(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;e=i;i=i+144|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;l=e+80|0;m=e+96|0;n=e+112|0;o=e+128|0;if((d|0)!=0){c[d>>2]=133378}Ts(b,d);if((b&96|0)!=0){gGz(o|0,0,12);d=c[2405662]|0;c[o>>2]=d;c[o+4>>2]=(c[2411676]|0)-d;c[o+12>>2]=219592;d=c[2076592]|0;gj[d&4095](o)|0;o=h|0;do{if((b&64|0)!=0){gGz(g|0,0,16);c[2394]=-1;if((c[2392]|0)<0){break}d=h+9|0;p=f;q=f|0;r=f+4|0;s=f+12|0;t=g|0;u=g+4|0;v=g+12|0;w=0;do{gGC(o|0,614896,11)|0;a[d]=w+48&255;x=8452256+(w<<2)|0;gGz(p|0,0,12);c[q>>2]=x;c[r>>2]=4;c[s>>2]=164976;gj[c[2076592]&4095](f)|0;if((c[x>>2]|0)!=0){c[t>>2]=c[14130368+(w<<2)>>2];c[u>>2]=c[8452184+(w<<2)>>2];c[v>>2]=o;x=c[2076592]|0;gj[x&4095](g)|0}w=w+1|0;}while((w|0)<=(c[2392]|0))}}while(0);Ut(0);Ut(1);gGz(n|0,0,12);c[n>>2]=9541760;c[n+4>>2]=1;c[n+12>>2]=148144;g=c[2076592]|0;gj[g&4095](n)|0;gGz(m|0,0,12);c[m>>2]=9541992;c[m+4>>2]=1;c[m+12>>2]=118544;n=c[2076592]|0;gj[n&4095](m)|0;gGz(l|0,0,12);c[l>>2]=9775216;c[l+4>>2]=1;c[l+12>>2]=93520;m=c[2076592]|0;gj[m&4095](l)|0;gGz(k|0,0,12);c[k>>2]=9627144;c[k+4>>2]=1;c[k+12>>2]=490464;l=c[2076592]|0;gj[l&4095](k)|0;ayc();gGz(j|0,0,12);c[j>>2]=9625744;c[j+4>>2]=4;c[j+12>>2]=215728;k=c[2076592]|0;gj[k&4095](j)|0}if((b&2|0)==0){i=e;return 0}a[14168416]=1;i=e;return 0}function auk(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1561884+(b*112|0)>>2];c[a+104>>2]=c[1561888+(b*112|0)>>2];c[a+108>>2]=c[1561892+(b*112|0)>>2];d=0;return d|0}function aul(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=1561784+(b*112|0);e=0;return e|0}function aum(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1105732+(b*112|0)>>2];c[a+104>>2]=c[1105736+(b*112|0)>>2];c[a+108>>2]=c[1105740+(b*112|0)>>2];d=0;return d|0}function aun(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=1105632+(b*112|0);e=0;return e|0}function auo(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1106852+(b*112|0)>>2];c[a+104>>2]=c[1106856+(b*112|0)>>2];c[a+108>>2]=c[1106860+(b*112|0)>>2];d=0;return d|0}function aup(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=1106752+(b*112|0);e=0;return e|0}function auq(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((d|0)==1835010|(d|0)==1835011|(d|0)==3145730|(d|0)==3145731){f=a[9775208]<<1|a[9541752];return f|0}else if((d|0)==2621441){f=b[4812852]&255;return f|0}else if((d|0)==2621443){f=a[642512]<<31>>31;return f|0}else if((d|0)==2621442){g=(a[642512]<<31>>31&65535)>>>8&239;do{if((c[2406632]|0)==0){h=c[2443744]|0;if((h|0)<=0){i=16;break}c[2443744]=h-1;i=0}else{i=(1<<c[(c[2420380]|0)+4>>2]&c[2432962]|0)!=0?16:0}}while(0);f=(i|g)&255;return f|0}else if((d|0)==1835008|(d|0)==1835009|(d|0)==3145728|(d|0)==3145729){f=a[9775208]<<1|a[9541752]|a[9627136]<<2&4^4;return f|0}else if((d|0)==1835014|(d|0)==1835015|(d|0)==3145734|(d|0)==3145735){a[9775208]=1;g=a[9541752]|0;i=g<<24>>24==0|(a[9541984]|0)==0;a[9775664]=i&1;h=8452200+(c[2394]<<2)|0;do{if(i){c[h>>2]=4098;c[2276080]=512;if((c[2276079]|0)>>>0>=512){j=2;k=g;break}RH(2);j=a[9775208]<<1;k=a[9541752]|0}else{c[h>>2]=0;c[2276080]=0;j=2;k=g}}while(0);f=j|k;return f|0}else if((d|0)==1835012|(d|0)==1835013|(d|0)==3145732|(d|0)==3145733){a[9541752]=1;do{if((a[9541984]|0)==0){a[9775664]=1;l=4096;m=10114}else{k=(a[9775208]|0)==0;a[9775664]=k&1;if(k){l=k?4096:0;m=10114;break}c[8452200+(c[2394]<<2)>>2]=0;c[2276080]=0;n=1}}while(0);do{if((m|0)==10114){c[8452200+(c[2394]<<2)>>2]=l|2;c[2276080]=512;if((c[2276079]|0)>>>0>=512){n=1;break}RH(2);n=a[9541752]|0}}while(0);f=a[9775208]<<1|n;return f|0}else if((d|0)==2621440){f=((e[4812852]|0)>>>8&95|((c[2433664]|0)!=0?0:128)|a[9657944]&32)&255;return f|0}else{f=0;return f|0}return 0}function aur(e){e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((e|0)==1835012|(e|0)==3145732){a[9541752]=1;do{if((a[9541984]|0)==0){a[9775664]=1;f=4096;g=10147}else{h=(a[9775208]|0)==0;a[9775664]=h&1;if(h){f=h?4096:0;g=10147;break}c[8452200+(c[2394]<<2)>>2]=0;c[2276080]=0;i=1}}while(0);do{if((g|0)==10147){c[8452200+(c[2394]<<2)>>2]=f|2;c[2276080]=512;if((c[2276079]|0)>>>0>=512){i=1;break}RH(2);i=a[9541752]|0}}while(0);j=a[9775208]<<1|i;return j|0}else if((e|0)==1835014|(e|0)==3145734){a[9775208]=1;i=a[9541752]|0;f=i<<24>>24==0|(a[9541984]|0)==0;a[9775664]=f&1;g=8452200+(c[2394]<<2)|0;do{if(f){c[g>>2]=4098;c[2276080]=512;if((c[2276079]|0)>>>0>=512){k=2;l=i;break}RH(2);k=a[9775208]<<1;l=a[9541752]|0}else{c[g>>2]=0;c[2276080]=0;k=2;l=i}}while(0);j=k|l<<24>>24;return j|0}else if((e|0)==1835010|(e|0)==3145730){j=a[9775208]<<1|a[9541752];return j|0}else if((e|0)==1835008|(e|0)==3145728){j=a[9775208]<<1|a[9541752]|((a[9627136]&1)!=0?4:0);return j|0}else if((e|0)==2621440){j=((c[2433664]|0)!=0?0:-32768)|b[4812852]&24575|d[9657944]<<8&8192;return j|0}else if((e|0)==2621442){e=a[642512]<<31>>31&61439;do{if((c[2406632]|0)==0){l=c[2443744]|0;if((l|0)<=0){m=4096;break}c[2443744]=l-1;m=0}else{m=(c[2432962]|0)>>>((c[(c[2420380]|0)+4>>2]|0)>>>0)<<12&4096}}while(0);j=(m|e)&65535;return j|0}else{j=0;return j|0}return 0}function aus(a,b){a=a|0;b=b|0;if((a|0)==2359299){Ui(b);return}else if((a|0)==2359297){c[2113012]=b&255;return}else if((a|0)==2621450){a=b&255;c[2433664]=a&1;c[2415256]=a&64;b=a>>>4&1;c[3528406]=b^1;if((b|0)==0){c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2]}Tr(a>>>5&1);return}else{return}}function aut(a,b){a=a|0;b=b|0;var d=0,e=0;if((a|0)==1310722){c[3542079]=b&65535;return}else if((a|0)==1835010|(a|0)==3145730){c[2113278]=b&65535;return}else if((a|0)==2359296){c[2113012]=b&255;return}else if((a|0)==2359298){Ui(b&255);return}else if((a|0)==1310724){c[3542080]=b&65535;return}else if((a|0)==1310720){c[3542078]=b&65535;return}else if((a|0)==1835016|(a|0)==3145736){gD[c[3542102]&8191]()|0;c[2113288]=b&65535;return}else if((a|0)==2621450){d=(b&65535)>>>8&65535;c[2433664]=d&1;c[2415256]=d&64;e=d>>>4&1;c[3528406]=e^1;if((e|0)==0){c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2]}Tr(d>>>5&1);return}else if((a|0)==1835008|(a|0)==3145728){c[2113282]=b&65535;return}else{return}}function auu(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>4){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2674420+(b*112|0)>>2];c[a+104>>2]=c[2674424+(b*112|0)>>2];c[a+108>>2]=c[2674428+(b*112|0)>>2];d=0;return d|0}function auv(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<5&(d|0)==0)){e=1;return e|0}c[a>>2]=2674320+(b*112|0);e=0;return e|0}function auw(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1237008+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aux(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>3){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3820392+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function auy(){var b=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;b=i;i=i+600|0;e=b|0;f=b+112|0;g=b+120|0;j=b+232|0;k=b+240|0;l=b+352|0;m=b+360|0;n=b+472|0;o=b+480|0;p=b+592|0;c[2424]=5755;c[2426722]=0;c[2418152]=0;c[3542098]=524288;c[3542090]=4718592;c[3531292]=6815744;c[2405654]=8912896;c[2418266]=8912896;c[3542094]=8978432;c[3542100]=9011200;c[3542108]=9076736;c[2411660]=9142272;q=0;while(1){if((q|0)>=1024){break}r=9638528+(q<<2)|0;if((c[r>>2]|0)==0){s=10233;break}else{q=q+1|0}}do{if((s|0)==10233){q=gGq(9142272)|0;c[r>>2]=q;if((q|0)==0){break}c[2426722]=q;gGz(q|0,0,9142272);c[2418152]=q;c[3542098]=q+524288;c[3542090]=q+4718592;c[3531292]=q+6815744;t=q+8912896|0;c[2405654]=t;c[2418266]=t;c[3542094]=q+8978432;c[3542100]=q+9011200;c[3542108]=q+9076736;t=q+9142272|0;c[2411660]=t;c[2414202]=t;do{if((c[3542200]|0)!=0){t=o+108|0;c[t>>2]=0;u=o+100|0;c[u>>2]=0;v=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[v&16383](o,0)|0;if((c[t>>2]|0)==0){break}t=c[u>>2]|0;c[p>>2]=9534384;u=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[u&16383](p,0,0)|0;if((t|0)<1){break}gzL(q,0,0)|0}}while(0);q=c[3542098]|0;do{if((c[3542200]|0)!=0){t=m+108|0;c[t>>2]=0;u=m+100|0;c[u>>2]=0;v=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[v&16383](m,1)|0;if((c[t>>2]|0)==0){break}t=c[u>>2]|0;c[n>>2]=9534384;u=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[u&16383](n,1,0)|0;if((t|0)<1){break}gzL(q,0,1)|0}}while(0);q=(c[3542098]|0)+1048576|0;do{if((c[3542200]|0)!=0){t=k+108|0;c[t>>2]=0;u=k+100|0;c[u>>2]=0;v=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[v&16383](k,2)|0;if((c[t>>2]|0)==0){break}t=c[u>>2]|0;c[l>>2]=9534384;u=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[u&16383](l,2,0)|0;if((t|0)<1){break}gzL(q,0,2)|0}}while(0);q=c[3542098]|0;t=q+1572863|0;u=q+3145726|0;q=0;while(1){a[u]=a[t]&15;a[u+1|0]=(d[t]|0)>>>4;v=q+1|0;if((v|0)<1572864){t=t-1|0;u=u-2|0;q=v}else{break}}q=c[3542090]|0;do{if((c[3542200]|0)!=0){u=g+108|0;c[u>>2]=0;t=g+100|0;c[t>>2]=0;v=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[v&16383](g,3)|0;if((c[u>>2]|0)==0){break}u=c[t>>2]|0;c[j>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](j,3,0)|0;if((u|0)<1){break}gzL(q,0,3)|0}}while(0);q=c[3542090]|0;u=q+1048575|0;t=q+2097150|0;q=0;while(1){a[t+1|0]=a[u]&15;a[t]=(d[u]|0)>>>4;v=q+1|0;if((v|0)<1048576){u=u-1|0;t=t-2|0;q=v}else{break}}q=c[3531292]|0;do{if((c[3542200]|0)!=0){t=e+108|0;c[t>>2]=0;u=e+100|0;c[u>>2]=0;v=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[v&16383](e,4)|0;if((c[t>>2]|0)==0){break}t=c[u>>2]|0;c[f>>2]=9534384;u=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[u&16383](f,4,0)|0;if((t|0)<1){break}gzL(q,0,4)|0}}while(0);Tq(681624);fxU(0,425984);if((c[2394]|0)==0){w=c[2112932]|0}else{c[2394]=0;q=c[3532596]|0;c[2112932]=q;t=c[3532592]|0;if((t|0)!=0){gGC(9104152,t|0,280)|0}c[2113054]=c[2113060];w=q}q=c[2418152]|0;t=w|0;u=0;while(1){v=q+u|0;c[t>>2]=v;c[t+131072>>2]=v;v=u+1024|0;if(v>>>0>524287){break}else{t=t+4|0;u=v}}u=c[3542094]|0;t=w+4096|0;q=1048576;while(1){v=u+(q-1048576)|0;c[t>>2]=v;c[t+65536>>2]=v;c[t+131072>>2]=v;v=q+1024|0;if(v>>>0>1081343){break}else{t=t+4|0;q=v}}q=c[3542100]|0;t=w+6144|0;u=1572864;while(1){v=q+(u-1572864)|0;c[t>>2]=v;c[t+65536>>2]=v;c[t+131072>>2]=v;v=u+1024|0;if(v>>>0>1605631){break}else{t=t+4|0;u=v}}u=c[3542108]|0;t=w+8192|0;q=2097152;while(1){v=u+(q-2097152)|0;c[t>>2]=v;c[t+65536>>2]=v;c[t+131072>>2]=v;v=q+1024|0;if(v>>>0>2129919){break}else{t=t+4|0;q=v}}q=c[2418266]|0;t=w+12288|0;u=3145728;while(1){v=q+(u-3145728)|0;c[t>>2]=v;c[t+65536>>2]=v;c[t+131072>>2]=v;v=u+1024|0;if(v>>>0>3211263){break}else{t=t+4|0;u=v}}c[w+196688>>2]=3480;c[w+196608>>2]=926;c[w+196728>>2]=1672;c[w+196648>>2]=3448;u=c[3532592]|0;if((u|0)!=0){gGC(u|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;c[2113290]=1;u=0;while(1){if((u|0)>=1024){x=0;break}y=9638528+(u<<2)|0;if((c[y>>2]|0)==0){s=10279;break}else{u=u+1|0}}do{if((s|0)==10279){u=gGq(131072)|0;c[y>>2]=u;if((u|0)==0){x=0;break}gGz(u|0,0,131072);x=u}}while(0);c[3542106]=x;gGz(x|0,0,131072);u=0;while(1){if((u|0)>=1024){z=0;break}A=9638528+(u<<2)|0;if((c[A>>2]|0)==0){s=10284;break}else{u=u+1|0}}do{if((s|0)==10284){u=gGq(65536)|0;c[A>>2]=u;if((u|0)==0){z=0;break}gGz(u|0,0,65536);z=u}}while(0);c[3527514]=z;gGz(z|0,0,65536);c[2112966]=c[3542106];c[3542078]=0;c[3542079]=0;c[3542080]=16;c[3542081]=0;c[3542082]=0;c[3542083]=16;c[3542084]=0;c[3542085]=0;c[3542086]=16;c[3542087]=0;c[3542088]=0;c[3542089]=16;c[2113284]=0;u=c[642608+(c[2436]<<2)>>2]|0;if((c[u+52>>2]&4|0)==0){t=c[u+128>>2]|0;c[2113280]=t;B=u+132|0;C=t}else{t=c[u+132>>2]|0;c[2113280]=t;B=u+128|0;C=t}t=c[B>>2]|0;c[2113276]=t;c[2406716]=C-8;c[2394778]=C-16;c[2406714]=t-8;c[2394776]=t-16;c[3528974]=c[3564288+(((C|0)!=320)<<2)>>2];auH(1,3145728);axI(0,2097152,4,17408);Uf(16934400,1316);h[607287]=1.0;c[2433116]=1;h[607286]=1.0;c[2433114]=2;a[7072776]=1;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];t=c[3532592]|0;if((t|0)!=0){gGC(9104152,t|0,280)|0}c[2113054]=c[2113060]}RI();t=c[2394]|0;u=c[14130368+(t<<2)>>2]|0;if((u|0)!=0){gGC(u|0,9104152,280)|0}c[8452240+(t<<2)>>2]=c[2113054];c[2394]=-1;c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];gGz(14125184,0,668);c[2433532]=0;c[2430402]=0;c[2113010]=0;a[9753304]=0;c[2433552]=0;gGz(c[2430036]|0,0,16384);c[3531316]=4;gGz(c[2430037]|0,0,16384);c[3531337]=4;gGz(c[2430038]|0,0,16384);c[3531358]=4;gGz(c[2430039]|0,0,16384);c[3531379]=4;gGz(c[2430040]|0,0,16384);c[3531400]=4;gGz(c[2430041]|0,0,16384);c[3531421]=4;gGz(c[2430042]|0,0,16384);c[3531442]=4;gGz(c[2430043]|0,0,16384);c[3531463]=4;a[9541752]=1;a[9541984]=1;a[9775208]=1;a[9775664]=0;D=0;i=b;return D|0}}while(0);c[2426722]=0;D=1;i=b;return D|0}function auz(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;i=i+128|0;d=c[2406694]|0;if((d|0)!=0){gGr(d);c[2406694]=0}c[3531294]=0;d=b|0;e=c[c[642608+(c[2436]<<2)>>2]>>2]|0;be(d|0,128,179600,(f=i,i=i+24|0,c[f>>2]=9374064,c[f+8>>2]=47,c[f+16>>2]=e,f)|0)|0;i=f;a[1040128]=0;f=c[2420380]|0;e=c[f>>2]|0;g=c[f+4>>2]|0;f=fw(d|0,389440)|0;if((f|0)!=0){d=g>>3<<e&1023;cj(14100392,d|0,1,f|0)|0;aY(f|0)|0}axH();f=c[2443764]|0;d=0;while(1){if((d|0)>=1024){break}h=9638528+(d<<2)|0;if((c[h>>2]|0)==(f|0)){j=10306;break}else{d=d+1|0}}if((j|0)==10306){gGr(f);c[h>>2]=0}c[2443764]=0;h=c[2394718]|0;f=0;while(1){if((f|0)>=1024){break}k=9638528+(f<<2)|0;if((c[k>>2]|0)==(h|0)){j=10310;break}else{f=f+1|0}}if((j|0)==10310){gGr(h);c[k>>2]=0}c[2394718]=0;a[7462192]=0;k=c[3542106]|0;h=0;while(1){if((h|0)>=1024){break}l=9638528+(h<<2)|0;if((c[l>>2]|0)==(k|0)){j=10314;break}else{h=h+1|0}}if((j|0)==10314){gGr(k);c[l>>2]=0}c[3542106]=0;l=c[3527514]|0;k=0;while(1){if((k|0)>=1024){break}m=9638528+(k<<2)|0;if((c[m>>2]|0)==(l|0)){j=10318;break}else{k=k+1|0}}if((j|0)==10318){gGr(l);c[m>>2]=0}c[3527514]=0;if((c[2392]|0)>=0){m=0;do{l=14130368+(m<<2)|0;k=c[l>>2]|0;if((k|0)!=0){gGr(k);c[l>>2]=0}l=14130384+(m<<2)|0;k=c[l>>2]|0;if((k|0)!=0){gGr(k);c[l>>2]=0}m=m+1|0;}while((m|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;m=c[2426722]|0;l=0;while(1){if((l|0)>=1024){j=10330;break}n=9638528+(l<<2)|0;if((c[n>>2]|0)==(m|0)){break}else{l=l+1|0}}if((j|0)==10330){c[2426722]=0;i=b;return 0}gGr(m);c[n>>2]=0;c[2426722]=0;i=b;return 0}function auA(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((a[9624160]|0)!=0){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];gGz(14125184,0,668);c[2433532]=0;c[2430402]=0;c[2113010]=0;a[9753304]=0;c[2433552]=0;gGz(c[2430036]|0,0,16384);c[3531316]=4;gGz(c[2430037]|0,0,16384);c[3531337]=4;gGz(c[2430038]|0,0,16384);c[3531358]=4;gGz(c[2430039]|0,0,16384);c[3531379]=4;gGz(c[2430040]|0,0,16384);c[3531400]=4;gGz(c[2430041]|0,0,16384);c[3531421]=4;gGz(c[2430042]|0,0,16384);c[3531442]=4;gGz(c[2430043]|0,0,16384);c[3531463]=4;a[9541752]=1;a[9541984]=1;a[9775208]=1;a[9775664]=0}b[4812852]=0;a[642512]=0;d=0;e=0;do{e=((a[9633416+d|0]&1)<<d|e&65535)&65535;d=d+1|0;}while((d|0)<16);d=(e&3)==3?e&-4:e;b[4812852]=~((d&12)==12?d&-13:d);a[642512]=1;d=c[2392]|0;if((d|0)>=0){gGz(8452240,0,((d|0)>0?(d<<2)+4|0:4)|0)}c[2113054]=0;d=c[2438]|0;e=gGU(d,(d|0)<0|0?-1:0,16e6,0)|0;d=~~((+(e>>>0)+ +(K|0)*4294967296.0)/14732.965009208103);c[2440528]=d;c[2444082]=0;e=d-~~(+(d*12|0|0)/271.5)|0;a[9627136]=0;if((c[2394]|0)==0){f=1;g=0}else{c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];f=1;g=0}while(1){d=c[2112964]|0;if((f&1|0)==0&(d|0)!=0){h=(ag(a[9688]|0?534:0,f)|0)/8|0;Ug(d+(g<<1<<1)|0,h-g|0);i=h}else{i=g}a[7024768]=0;h=(ag(c[2440528]|0,f)|0)/8|0;if((a[9627136]&1)==0&(h|0)>(e|0)){d=c[2444082]|0;if((d|0)<(e|0)){j=e-d|0;c[2113056]=j;d=RG(j)|0;c[2113054]=(c[2113054]|0)+d;c[2276108]=-1;c[2113056]=-1;j=9776328+(a[7024768]<<31>>31<<2)|0;c[j>>2]=(c[j>>2]|0)+d}if((c[2112968]|0)!=0){auB()|0}a[9627136]=1;a[9541752]=0;a[9775664]=1;c[8452200+(c[2394]<<2)>>2]=4098;c[2276080]=512;if((c[2276079]|0)>>>0<512){RH(2)}k=a[7024768]<<31>>31}else{k=0}d=h-(c[9776328+(k<<2)>>2]|0)|0;c[2113056]=d;h=RG(d)|0;c[2113054]=(c[2113054]|0)+h;c[2276108]=-1;c[2113056]=-1;d=9776328+(a[7024768]<<31>>31<<2)|0;c[d>>2]=(c[d>>2]|0)+h;a[7024768]=1;h=f+1|0;if((h|0)<9){f=h;g=i}else{break}}g=c[2112964]|0;do{if((g|0)!=0){f=a[9688]|0?534:0;if((f|0)==(i|0)){break}Ug(g+(i<<1<<1)|0,f-i|0)}}while(0);i=c[2394]|0;g=c[14130368+(i<<2)>>2]|0;if((g|0)==0){l=c[2113054]|0;m=8452240+(i<<2)|0;c[m>>2]=l;c[2394]=-1;return 0}gGC(g|0,9104152,280)|0;l=c[2113054]|0;m=8452240+(i<<2)|0;c[m>>2]=l;c[2394]=-1;return 0}function auB(){var b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=c[3542108]|0;d=c[3542106]|0;f=0;while(1){g=f<<4;h=f<<8;i=0;while(1){j=e[b+((i|g)<<1|30720)>>1]|0;k=j>>>7&248;c[d+((i|h)<<2)>>2]=j>>>2<<8&63488|j&31|(k>>>5|k)<<3&2016;k=i+1|0;if((k|0)<16){i=k}else{l=16;break}}do{i=l|h;g=e[b+(i<<1)>>1]|0;k=g>>>7&248;c[d+(i<<2)>>2]=g>>>2<<8&63488|g&31|(k>>>5|k)<<3&2016;l=l+1|0;}while((l|0)<256);h=f+1|0;if((h|0)<64){f=h}else{m=0;break}}do{f=e[b+(m<<1)>>1]|0;l=f>>>7&248;c[d+(m+16384<<2)>>2]=f>>>2<<8&63488|f&31|(l>>>5|l)<<3&2016;m=m+1|0;}while((m|0)<16384);c[2112966]=d;m=c[d+64512>>2]|0;d=c[2112968]|0;do{if((m|0)==0){gGz(d|0,0,ag(c[2113280]<<1,c[2113276]|0)|0)}else{b=m<<16|m;l=ag(c[2113276]|0,c[2113280]|0)|0;if((l|0)<=15){break}f=d;h=(l|0)/16|0;while(1){c[f>>2]=b;c[f+4>>2]=b;c[f+8>>2]=b;c[f+12>>2]=b;c[f+16>>2]=b;c[f+20>>2]=b;c[f+24>>2]=b;c[f+28>>2]=b;l=h-1|0;if((l|0)>0){f=f+32|0;h=l}else{break}}}}while(0);gD[c[3542102]&8191]()|0;if(!(a[7072776]|0)){return 0}axE(1);return 0}function auC(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;e=i;i=i+144|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;l=e+80|0;m=e+96|0;n=e+112|0;o=e+128|0;if((d|0)!=0){c[d>>2]=133378}Ts(b,d);if((b&96|0)==0){i=e;return 0}gGz(o|0,0,12);d=c[2405654]|0;c[o>>2]=d;c[o+4>>2]=(c[2411660]|0)-d;c[o+12>>2]=219592;gj[c[2076592]&4095](o)|0;o=h|0;do{if((b&64|0)!=0){gGz(g|0,0,16);c[2394]=-1;if((c[2392]|0)<0){break}d=h+9|0;p=f;q=f|0;r=f+4|0;s=f+12|0;t=g|0;u=g+4|0;v=g+12|0;w=0;do{gGC(o|0,614896,11)|0;a[d]=w+48&255;x=8452256+(w<<2)|0;gGz(p|0,0,12);c[q>>2]=x;c[r>>2]=4;c[s>>2]=164976;gj[c[2076592]&4095](f)|0;if((c[x>>2]|0)!=0){c[t>>2]=c[14130368+(w<<2)>>2];c[u>>2]=c[8452184+(w<<2)>>2];c[v>>2]=o;x=c[2076592]|0;gj[x&4095](g)|0}w=w+1|0;}while((w|0)<=(c[2392]|0))}}while(0);Ue();gGz(n|0,0,12);c[n>>2]=9541752;c[n+4>>2]=1;c[n+12>>2]=148144;gj[c[2076592]&4095](n)|0;gGz(m|0,0,12);c[m>>2]=9541984;c[m+4>>2]=1;c[m+12>>2]=118544;gj[c[2076592]&4095](m)|0;gGz(l|0,0,12);c[l>>2]=9775208;c[l+4>>2]=1;c[l+12>>2]=93520;gj[c[2076592]&4095](l)|0;gGz(k|0,0,12);c[k>>2]=9627136;c[k+4>>2]=1;c[k+12>>2]=490464;gj[c[2076592]&4095](k)|0;gGz(j|0,0,12);c[j>>2]=9734656;c[j+4>>2]=4;c[j+12>>2]=471600;gj[c[2076592]&4095](j)|0;ayc();i=e;return 0}function auD(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>5){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2991540+(b*112|0)>>2];c[a+104>>2]=c[2991544+(b*112|0)>>2];c[a+108>>2]=c[2991548+(b*112|0)>>2];d=0;return d|0}function auE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<6&(d|0)==0)){e=1;return e|0}c[a>>2]=2991440+(b*112|0);e=0;return e|0}function auF(){var b=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;b=i;i=i+720|0;e=b|0;f=b+112|0;g=b+120|0;j=b+232|0;k=b+240|0;l=b+352|0;m=b+360|0;n=b+472|0;o=b+480|0;p=b+592|0;q=b+600|0;r=b+712|0;c[2424]=5755;c[2426722]=0;c[2418152]=0;c[3542098]=524288;c[3542090]=4718592;c[3531292]=6815744;c[2405654]=8912896;c[2418266]=8912896;c[3542094]=8978432;c[3542100]=9011200;c[3542108]=9076736;c[2411660]=9142272;s=0;while(1){if((s|0)>=1024){break}t=9638528+(s<<2)|0;if((c[t>>2]|0)==0){u=10411;break}else{s=s+1|0}}do{if((u|0)==10411){s=gGq(9142272)|0;c[t>>2]=s;if((s|0)==0){break}c[2426722]=s;gGz(s|0,0,9142272);c[2418152]=s;c[3542098]=s+524288;c[3542090]=s+4718592;c[3531292]=s+6815744;v=s+8912896|0;c[2405654]=v;c[2418266]=v;c[3542094]=s+8978432;c[3542100]=s+9011200;c[3542108]=s+9076736;v=s+9142272|0;c[2411660]=v;c[2414202]=v;do{if((c[3542200]|0)!=0){v=q+108|0;c[v>>2]=0;w=q+100|0;c[w>>2]=0;x=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[x&16383](q,0)|0;if((c[v>>2]|0)==0){break}v=c[w>>2]|0;c[r>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](r,0,0)|0;if((v|0)<1){break}gzL(s,0,0)|0}}while(0);s=c[3542098]|0;do{if((c[3542200]|0)!=0){v=o+108|0;c[v>>2]=0;w=o+100|0;c[w>>2]=0;x=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[x&16383](o,1)|0;if((c[v>>2]|0)==0){break}v=c[w>>2]|0;c[p>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](p,1,0)|0;if((v|0)<1){break}gzL(s,0,1)|0}}while(0);s=(c[3542098]|0)+1048576|0;do{if((c[3542200]|0)!=0){v=m+108|0;c[v>>2]=0;w=m+100|0;c[w>>2]=0;x=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[x&16383](m,2)|0;if((c[v>>2]|0)==0){break}v=c[w>>2]|0;c[n>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](n,2,0)|0;if((v|0)<1){break}gzL(s,0,2)|0}}while(0);s=c[3542098]|0;v=s+2097151|0;w=s+4194302|0;s=0;while(1){a[w]=a[v]&15;a[w+1|0]=(d[v]|0)>>>4;x=s+1|0;if((x|0)<2097152){v=v-1|0;w=w-2|0;s=x}else{break}}s=c[3542090]|0;do{if((c[3542200]|0)!=0){w=k+108|0;c[w>>2]=0;v=k+100|0;c[v>>2]=0;x=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[x&16383](k,3)|0;if((c[w>>2]|0)==0){break}w=c[v>>2]|0;c[l>>2]=9534384;v=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[v&16383](l,3,0)|0;if((w|0)<1){break}gzL(s,0,3)|0}}while(0);s=c[3542090]|0;w=s+1048575|0;v=s+2097150|0;s=0;while(1){a[v+1|0]=a[w]&15;a[v]=(d[w]|0)>>>4;x=s+1|0;if((x|0)<1048576){w=w-1|0;v=v-2|0;s=x}else{break}}s=c[3531292]|0;do{if((c[3542200]|0)!=0){v=g+108|0;c[v>>2]=0;w=g+100|0;c[w>>2]=0;x=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[x&16383](g,4)|0;if((c[v>>2]|0)==0){break}v=c[w>>2]|0;c[j>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](j,4,0)|0;if((v|0)<1){break}gzL(s,0,4)|0}}while(0);s=(c[3531292]|0)+1048576|0;do{if((c[3542200]|0)!=0){v=e+108|0;c[v>>2]=0;w=e+100|0;c[w>>2]=0;x=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[x&16383](e,5)|0;if((c[v>>2]|0)==0){break}v=c[w>>2]|0;c[f>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](f,5,0)|0;if((v|0)<1){break}gzL(s,0,5)|0}}while(0);Tq(681624);fxU(0,425984);if((c[2394]|0)==0){y=c[2112932]|0}else{c[2394]=0;s=c[3532596]|0;c[2112932]=s;v=c[3532592]|0;if((v|0)!=0){gGC(9104152,v|0,280)|0}c[2113054]=c[2113060];y=s}s=c[2418152]|0;v=y|0;w=0;while(1){x=s+w|0;c[v>>2]=x;c[v+131072>>2]=x;x=w+1024|0;if(x>>>0>524287){break}else{v=v+4|0;w=x}}w=c[3542094]|0;v=y+4096|0;s=1048576;while(1){x=w+(s-1048576)|0;c[v>>2]=x;c[v+65536>>2]=x;c[v+131072>>2]=x;x=s+1024|0;if(x>>>0>1081343){break}else{v=v+4|0;s=x}}s=c[3542100]|0;v=y+6144|0;w=1572864;while(1){x=s+(w-1572864)|0;c[v>>2]=x;c[v+65536>>2]=x;c[v+131072>>2]=x;x=w+1024|0;if(x>>>0>1605631){break}else{v=v+4|0;w=x}}w=c[3542108]|0;v=y+8192|0;s=2097152;while(1){x=w+(s-2097152)|0;c[v>>2]=x;c[v+65536>>2]=x;c[v+131072>>2]=x;x=s+1024|0;if(x>>>0>2129919){break}else{v=v+4|0;s=x}}s=c[2418266]|0;v=y+13312|0;w=3407872;while(1){x=s+(w-3407872)|0;c[v>>2]=x;c[v+65536>>2]=x;c[v+131072>>2]=x;x=w+1024|0;if(x>>>0>3473407){break}else{v=v+4|0;w=x}}c[y+196688>>2]=3480;c[y+196608>>2]=926;c[y+196728>>2]=1672;c[y+196648>>2]=3448;w=c[3532592]|0;if((w|0)!=0){gGC(w|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;c[2113290]=1;w=0;while(1){if((w|0)>=1024){z=0;break}A=9638528+(w<<2)|0;if((c[A>>2]|0)==0){u=10461;break}else{w=w+1|0}}do{if((u|0)==10461){w=gGq(131072)|0;c[A>>2]=w;if((w|0)==0){z=0;break}gGz(w|0,0,131072);z=w}}while(0);c[3542106]=z;gGz(z|0,0,131072);w=0;while(1){if((w|0)>=1024){B=0;break}C=9638528+(w<<2)|0;if((c[C>>2]|0)==0){u=10466;break}else{w=w+1|0}}do{if((u|0)==10466){w=gGq(65536)|0;c[C>>2]=w;if((w|0)==0){B=0;break}gGz(w|0,0,65536);B=w}}while(0);c[3527514]=B;gGz(B|0,0,65536);c[2112966]=c[3542106];c[3542078]=0;c[3542079]=0;c[3542080]=16;c[3542081]=0;c[3542082]=0;c[3542083]=16;c[3542084]=0;c[3542085]=0;c[3542086]=16;c[3542087]=0;c[3542088]=0;c[3542089]=16;c[2113284]=0;w=c[642608+(c[2436]<<2)>>2]|0;if((c[w+52>>2]&4|0)==0){v=c[w+128>>2]|0;c[2113280]=v;D=w+132|0;E=v}else{v=c[w+132>>2]|0;c[2113280]=v;D=w+128|0;E=v}v=c[D>>2]|0;c[2113276]=v;c[2406716]=E-8;c[2394778]=E-16;c[2406714]=v-8;c[2394776]=v-16;c[3528974]=c[3564288+(((E|0)!=320)<<2)>>2];auH(1,4194304);axI(0,2097152,4,17408);Uf(16934400,1316);h[607287]=1.0;c[2433116]=1;h[607286]=1.0;c[2433114]=2;a[7072776]=1;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];v=c[3532592]|0;if((v|0)!=0){gGC(9104152,v|0,280)|0}c[2113054]=c[2113060]}RI();v=c[2394]|0;w=c[14130368+(v<<2)>>2]|0;if((w|0)!=0){gGC(w|0,9104152,280)|0}c[8452240+(v<<2)>>2]=c[2113054];c[2394]=-1;c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];gGz(14125184,0,668);c[2433532]=0;c[2430402]=0;c[2113010]=0;a[9753304]=0;c[2433552]=0;gGz(c[2430036]|0,0,16384);c[3531316]=4;gGz(c[2430037]|0,0,16384);c[3531337]=4;gGz(c[2430038]|0,0,16384);c[3531358]=4;gGz(c[2430039]|0,0,16384);c[3531379]=4;gGz(c[2430040]|0,0,16384);c[3531400]=4;gGz(c[2430041]|0,0,16384);c[3531421]=4;gGz(c[2430042]|0,0,16384);c[3531442]=4;gGz(c[2430043]|0,0,16384);c[3531463]=4;a[9541752]=1;a[9541984]=1;a[9775208]=1;a[9775664]=0;F=0;i=b;return F|0}}while(0);c[2426722]=0;F=1;i=b;return F|0}function auG(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=(b^1)&255;a[9541984]=d;do{if((a[9541752]|0)==0|d<<24>>24==0){a[9775664]=1;e=4096;f=1;g=10484}else{b=(a[9775208]|0)==0;h=b&1;a[9775664]=h;if(b){e=b?4096:0;f=h;g=10484;break}c[8452200+(c[2394]<<2)>>2]=0;c[2276080]=0;i=h}}while(0);do{if((g|0)==10484){c[8452200+(c[2394]<<2)>>2]=e|2;c[2276080]=512;if((c[2276079]|0)>>>0>=512){i=f;break}RH(2);i=a[9775664]|0}}while(0);if(!(i<<24>>24!=0&a[7024768])){return}c[2113056]=1024;i=RG(1024)|0;c[2113054]=(c[2113054]|0)+i;c[2276108]=-1;c[2113056]=-1;c[2444082]=(c[2444082]|0)+i;return}function auH(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=c[2443764]|0;if((e|0)==0){f=0}else{g=e|0;e=0;while(1){if((e|0)>=1024){break}h=9638528+(e<<2)|0;if((c[h>>2]|0)==(g|0)){i=10496;break}else{e=e+1|0}}if((i|0)==10496){gGr(g);c[h>>2]=0}c[2443764]=0;f=0}while(1){if((f|0)>=1024){break}j=9638528+(f<<2)|0;if((c[j>>2]|0)==0){i=10500;break}else{f=f+1|0}}do{if((i|0)==10500){f=gGq(32800)|0;c[j>>2]=f;if((f|0)==0){break}gGz(f|0,0,32800);h=f;c[2443764]=h;c[f+20>>2]=256;c[f+24>>2]=256;f=1;do{c[h+(f<<5)+20>>2]=256;c[h+(f<<5)+24>>2]=256;f=f+1|0;}while((f|0)<1024);gGz(9775584,-1|0,16);c[2440468]=65536;c[2440469]=65536;c[2440470]=65536;c[2440471]=65536;f=c[2394718]|0;if((f|0)!=0){h=f;f=0;while(1){if((f|0)>=1024){break}k=9638528+(f<<2)|0;if((c[k>>2]|0)==(h|0)){i=10516;break}else{f=f+1|0}}if((i|0)==10516){gGr(h);c[k>>2]=0}c[2394718]=0}f=ag(c[2113280]<<1,c[2113276]|0)|0;g=0;while(1){if((g|0)>=1024){break}l=9638528+(g<<2)|0;if((c[l>>2]|0)==0){i=10521;break}else{g=g+1|0}}do{if((i|0)==10521){g=gGq(f)|0;c[l>>2]=g;if((g|0)==0){break}gGz(g|0,0,f|0);h=g;c[2394718]=h;e=c[2113280]|0;gGz(g|0,0,ag(e<<1,c[2113276]|0)|0);c[2394728]=0;g=1;while(1){if((g|0)<(d|0)){g=g<<1}else{break}}c[2429856]=g-1;if((b|0)==1){c[3542102]=4232}else if((b|0)==0){c[3542102]=3712}else if((b|0)==3){c[3542102]=2122}else if((b|0)==2){c[3542102]=2316}else{m=c[2443764]|0;n=0;while(1){if((n|0)>=1024){o=h;break}p=9638528+(n<<2)|0;if((c[p>>2]|0)==(m|0)){i=10541;break}else{n=n+1|0}}if((i|0)==10541){gGr(m);c[p>>2]=0;o=c[2394718]|0}c[2443764]=0;n=o;h=0;while(1){if((h|0)>=1024){break}q=9638528+(h<<2)|0;if((c[q>>2]|0)==(n|0)){i=10545;break}else{h=h+1|0}}if((i|0)==10545){gGr(n);c[q>>2]=0}c[2394718]=0;a[7462192]=0;return}c[2113288]=0;c[2113286]=0;c[2442960]=c[1205640+(((e|0)!=320)<<2)>>2];return}}while(0);c[2394718]=0;f=c[2443764]|0;h=0;while(1){if((h|0)>=1024){r=0;break}s=9638528+(h<<2)|0;if((c[s>>2]|0)==(f|0)){i=10525;break}else{h=h+1|0}}if((i|0)==10525){gGr(f);c[s>>2]=0;r=c[2394718]|0}c[2443764]=0;h=0;while(1){if((h|0)>=1024){break}t=9638528+(h<<2)|0;if((c[t>>2]|0)==(r|0)){i=10529;break}else{h=h+1|0}}if((i|0)==10529){gGr(r);c[t>>2]=0}c[2394718]=0;a[7462192]=0;return}}while(0);c[2443764]=0;t=0;while(1){if((t|0)>=1024){break}u=9638528+(t<<2)|0;if((c[u>>2]|0)==0){i=10505;break}else{t=t+1|0}}if((i|0)==10505){gGr(0);c[u>>2]=0}c[2443764]=0;u=c[2394718]|0;t=0;while(1){if((t|0)>=1024){break}v=9638528+(t<<2)|0;if((c[v>>2]|0)==(u|0)){i=10509;break}else{t=t+1|0}}if((i|0)==10509){gGr(u);c[v>>2]=0}c[2394718]=0;a[7462192]=0;return}function auI(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=(c[3542100]|0)+(c[2113288]<<14)|0;f=c[2443764]|0;c[2440468]=65536;c[2440469]=65536;c[2440470]=65536;c[2440471]=65536;gGz(9775584,-1|0,16);g=a[7462192]|0?898:0;h=f;f=d;d=0;i=0;while(1){j=b[f+8>>1]|0;k=j>>>4&496;l=j<<4&496;do{if((l|0)==0|(k|0)==0){m=i;n=h}else{j=(e[f+4>>1]|0)+g&1023;if(j>>>0>319){if((j+k|0)<1025){m=i;n=h;break}}o=b[f+6>>1]&1023;if(o>>>0>239){if((o+l|0)<1025){m=i;n=h;break}}p=b[f>>1]|0;q=p<<16>>16;r=q>>>4&3;s=9775584+(r<<2)|0;if((c[s>>2]|0)==-1){c[9761872+(r<<2)>>2]=i}c[s>>2]=i;a[h+1|0]=8>>>(r>>>0)&255;a[h|0]=q>>>2&3;b[h+2>>1]=p&16128;c[h+28>>2]=e[f+2>>1]|q<<16&196608;c[h+4>>2]=j;c[h+8>>2]=o;c[h+12>>2]=k;c[h+16>>2]=l;m=i+1|0;n=h+32|0}}while(0);l=d+1|0;if((l|0)<1024){h=n;f=f+16|0;d=l;i=m}else{break}}return 0}function auJ(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=(c[3542100]|0)+(c[2113288]<<14)|0;f=c[2443764]|0;c[2440468]=65536;c[2440469]=65536;c[2440470]=65536;c[2440471]=65536;gGz(9775584,-1|0,16);g=a[7462192]|0?898:0;h=f;f=d;d=0;i=0;while(1){j=b[f+12>>1]|0;k=j>>>4&496;l=j<<4&496;L12949:do{if((l|0)==0|(k|0)==0){m=i;n=h}else{j=b[f+4>>1]|0;o=j<<16>>16;p=o>>>4&3;q=((e[f>>1]|0)>>>6)+g&1023;r=b[f+2>>1]|0;s=(r&65535)>>>6;t=f+8|0;do{if((e[t>>1]|0)<257){if((e[f+10>>1]|0)>=257){break}if(q>>>0>319){if((q+k|0)<1025){m=i;n=h;break L12949}}if((r&65535)<=15359){break}if((s+l|0)<1025){m=i;n=h;break L12949}}}while(0);r=9775584+(p<<2)|0;if((c[r>>2]|0)==-1){c[9761872+(p<<2)>>2]=i}c[r>>2]=i;a[h+1|0]=8>>>(p>>>0)&255;c[h+20>>2]=e[t>>1]|0;c[h+24>>2]=e[f+10>>1]|0;c[h+12>>2]=k;c[h+16>>2]=l;c[h+4>>2]=q;c[h+8>>2]=s;a[h|0]=o>>>2&3;b[h+2>>1]=j&16128;c[h+28>>2]=e[f+6>>1]|o<<16&196608;m=i+1|0;n=h+32|0}}while(0);l=d+1|0;if((l|0)<1024){h=n;f=f+16|0;d=l;i=m}else{break}}return 0}function auK(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=(c[3542100]|0)+(c[2113288]<<14)|0;f=c[2443764]|0;c[2440468]=65536;c[2440469]=65536;c[2440470]=65536;c[2440471]=65536;gGz(9775584,-1|0,16);g=a[7462192]|0?898:0;h=c[2113280]|0;i=c[2113276]|0;j=f;f=d;d=0;k=0;while(1){l=b[f+12>>1]|0;m=l>>>4&496;n=l<<4&496;L12967:do{if((n|0)==0|(m|0)==0){o=k;p=j}else{l=b[f+4>>1]|0;q=l<<16>>16;r=q>>>4&3;s=(e[f>>1]|0)+g&1023;t=b[f+2>>1]&1023;u=f+8|0;do{if((e[u>>1]|0)<257){if((e[f+10>>1]|0)>=257){break}if((s|0)>=(h|0)){if((s+m|0)<1025){o=k;p=j;break L12967}}if((t|0)<(i|0)){break}if((t+n|0)<1025){o=k;p=j;break L12967}}}while(0);v=9775584+(r<<2)|0;if((c[v>>2]|0)==-1){c[9761872+(r<<2)>>2]=k}c[v>>2]=k;a[j+1|0]=8>>>(r>>>0)&255;c[j+20>>2]=e[u>>1]|0;c[j+24>>2]=e[f+10>>1]|0;c[j+12>>2]=m;c[j+16>>2]=n;c[j+4>>2]=s;c[j+8>>2]=t;a[j|0]=q>>>2&3;b[j+2>>1]=l&16128;c[j+28>>2]=e[f+6>>1]|q<<16&196608;o=k+1|0;p=j+32|0}}while(0);n=d+1|0;if((n|0)<1024){j=p;f=f+16|0;d=n;k=o}else{break}}return 0}function auL(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=(c[3542100]|0)+(c[2113288]<<14)|0;f=c[2443764]|0;c[2440468]=65536;c[2440469]=65536;c[2440470]=65536;c[2440471]=65536;gGz(9775584,-1|0,16);g=c[2113294]|0;h=c[2113292]|0;i=f;f=d;d=0;j=0;while(1){k=b[f+8>>1]|0;l=k>>>4&496;m=k<<4&496;do{if((m|0)==0|(l|0)==0){n=j;o=i}else{k=(e[f+4>>1]|0)+g&1023;if(k>>>0>319){if((k+l|0)<1025){n=j;o=i;break}}p=(e[f+6>>1]|0)+h&1023;if(p>>>0>239){if((p+m|0)<1025){n=j;o=i;break}}q=b[f>>1]|0;r=q>>4;s=r&1|2;t=9775584+(s<<2)|0;if((c[t>>2]|0)==-1){c[9761872+(s<<2)>>2]=j}c[t>>2]=j;a[i+1|0]=8>>>(s>>>0)&255;a[i|0]=q>>>2&3;b[i+2>>1]=(r&1008|q<<5&3072)&65535;c[i+28>>2]=e[f+2>>1]|q<<16&196608;c[i+4>>2]=k;c[i+8>>2]=p;c[i+12>>2]=l;c[i+16>>2]=m;n=j+1|0;o=i+32|0}}while(0);m=d+1|0;if((m|0)<1024){i=o;f=f+16|0;d=m;j=n}else{break}}return 0}function auM(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;c[3528514]=0;a=c[2409614]|0;if((a|0)<=0){return}d=c[2409618]|0;e=c[2415168]|0;f=c[2438140]|0;g=c[2438094]|0;h=(e|0)>-1;i=(e|0)>-2;j=(e|0)>-3;k=(e|0)<-3;l=(e|0)>-5;m=(e|0)>-6;n=(e|0)>-7;o=(e|0)<-7;p=(e|0)>-9;q=(e|0)>-10;r=(e|0)>-11;s=(e|0)<-11;t=(e|0)>-13;u=(e|0)>-14;v=(e|0)>-15;w=c[2443766]|0;x=c[2420368]|0;y=0;do{L13004:do{if((d|0)>0){z=0;A=e;B=x;while(1){C=c[w+(z<<2)>>2]|0;do{if(A>>>0<304){D=C&255;if((D|0)!=0){b[B>>1]=c[g+(D<<2)>>2]&65535}D=C>>>8&255;if((D|0)!=0){b[B+2>>1]=c[g+(D<<2)>>2]&65535}D=C>>>16&255;if((D|0)!=0){b[B+4>>1]=c[g+(D<<2)>>2]&65535}D=C>>>24;if((D|0)!=0){b[B+6>>1]=c[g+(D<<2)>>2]&65535}D=c[w+((z|1)<<2)>>2]|0;E=D&255;if((E|0)!=0){b[B+8>>1]=c[g+(E<<2)>>2]&65535}E=D>>>8&255;if((E|0)!=0){b[B+10>>1]=c[g+(E<<2)>>2]&65535}E=D>>>16&255;if((E|0)!=0){b[B+12>>1]=c[g+(E<<2)>>2]&65535}E=D>>>24;if((E|0)!=0){b[B+14>>1]=c[g+(E<<2)>>2]&65535}E=c[w+((z|2)<<2)>>2]|0;D=E&255;if((D|0)!=0){b[B+16>>1]=c[g+(D<<2)>>2]&65535}D=E>>>8&255;if((D|0)!=0){b[B+18>>1]=c[g+(D<<2)>>2]&65535}D=E>>>16&255;if((D|0)!=0){b[B+20>>1]=c[g+(D<<2)>>2]&65535}D=E>>>24;if((D|0)!=0){b[B+22>>1]=c[g+(D<<2)>>2]&65535}D=c[w+((z|3)<<2)>>2]|0;E=D&255;if((E|0)!=0){b[B+24>>1]=c[g+(E<<2)>>2]&65535}E=D>>>8&255;if((E|0)!=0){b[B+26>>1]=c[g+(E<<2)>>2]&65535}E=D>>>16&255;if((E|0)!=0){b[B+28>>1]=c[g+(E<<2)>>2]&65535}E=D>>>24;if((E|0)==0){break}b[B+30>>1]=c[g+(E<<2)>>2]&65535}else{if((A|0)>319){break}do{if(h){E=C&255;if((E|0)==0){break}b[B>>1]=c[g+(E<<2)>>2]&65535}}while(0);if((A|0)>318){break}do{if(i){E=C>>>8&255;if((E|0)==0){break}b[B+2>>1]=c[g+(E<<2)>>2]&65535}}while(0);if((A|0)>317){break}do{if(j){E=C>>>16&255;if((E|0)==0){break}b[B+4>>1]=c[g+(E<<2)>>2]&65535}}while(0);E=C>>>24;if((A|0)>316){break}if(!(k|(E|0)==0)){b[B+6>>1]=c[g+(E<<2)>>2]&65535}E=c[w+((z|1)<<2)>>2]|0;if((A|0)>315){break}do{if(l){D=E&255;if((D|0)==0){break}b[B+8>>1]=c[g+(D<<2)>>2]&65535}}while(0);if((A|0)>314){break}do{if(m){D=E>>>8&255;if((D|0)==0){break}b[B+10>>1]=c[g+(D<<2)>>2]&65535}}while(0);if((A|0)>313){break}do{if(n){D=E>>>16&255;if((D|0)==0){break}b[B+12>>1]=c[g+(D<<2)>>2]&65535}}while(0);D=E>>>24;if((A|0)>312){break}if(!(o|(D|0)==0)){b[B+14>>1]=c[g+(D<<2)>>2]&65535}D=c[w+((z|2)<<2)>>2]|0;if((A|0)>311){break}do{if(p){F=D&255;if((F|0)==0){break}b[B+16>>1]=c[g+(F<<2)>>2]&65535}}while(0);if((A|0)>310){break}do{if(q){E=D>>>8&255;if((E|0)==0){break}b[B+18>>1]=c[g+(E<<2)>>2]&65535}}while(0);if((A|0)>309){break}do{if(r){E=D>>>16&255;if((E|0)==0){break}b[B+20>>1]=c[g+(E<<2)>>2]&65535}}while(0);E=D>>>24;if((A|0)>308){break}if(!(s|(E|0)==0)){b[B+22>>1]=c[g+(E<<2)>>2]&65535}E=c[w+((z|3)<<2)>>2]|0;if((A|0)>307){break}do{if(t){F=E&255;if((F|0)==0){break}b[B+24>>1]=c[g+(F<<2)>>2]&65535}}while(0);if((A|0)>306){break}do{if(u){D=E>>>8&255;if((D|0)==0){break}b[B+26>>1]=c[g+(D<<2)>>2]&65535}}while(0);if((A|0)>305){break}do{if(v){D=E>>>16&255;if((D|0)==0){break}b[B+28>>1]=c[g+(D<<2)>>2]&65535}}while(0);if(!((A|0)<305&(e|0)>-16)){break}D=E>>>24;if((D|0)==0){break}b[B+30>>1]=c[g+(D<<2)>>2]&65535}}while(0);C=z+4|0;D=B+32|0;if((C|0)>=(d|0)){G=x;H=y;I=D;break L13004}z=C;A=A+16|0;B=D}}else{G=x;H=y;I=x}}while(0);x=G+640|0;y=H+1|0;w=w+(f<<2)|0;}while((y|0)<(a|0));c[2443766]=w;c[2409608]=I;c[2420368]=x;c[3528514]=y;return}function auN(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;c[3528514]=0;a=c[2409614]|0;if((a|0)<=0){return}d=c[2409618]|0;f=c[2415168]|0;g=c[2438140]|0;h=c[2415166]|0;i=c[2438094]|0;j=(f|0)>-1;k=(f|0)>-2;l=(f|0)>-3;m=(f|0)<-3;n=(f|0)>-5;o=(f|0)>-6;p=(f|0)>-7;q=(f|0)<-7;r=(f|0)>-9;s=(f|0)>-10;t=(f|0)>-11;u=(f|0)<-11;v=(f|0)>-13;w=(f|0)>-14;x=(f|0)>-15;y=c[2443766]|0;z=c[2420368]|0;A=c[2415140]|0;B=0;do{L13141:do{if((d|0)>0){C=0;D=f;E=A;F=z;while(1){G=c[y+(C<<2)>>2]|0;do{if(D>>>0<304){H=G&255;do{if((H|0)!=0){if((e[E>>1]|0|0)>(h|0)){break}b[F>>1]=c[i+(H<<2)>>2]&65535}}while(0);H=G>>>8&255;do{if((H|0)!=0){if((e[E+2>>1]|0|0)>(h|0)){break}b[F+2>>1]=c[i+(H<<2)>>2]&65535}}while(0);H=G>>>16&255;do{if((H|0)!=0){if((e[E+4>>1]|0|0)>(h|0)){break}b[F+4>>1]=c[i+(H<<2)>>2]&65535}}while(0);H=G>>>24;do{if((H|0)!=0){if((e[E+6>>1]|0|0)>(h|0)){break}b[F+6>>1]=c[i+(H<<2)>>2]&65535}}while(0);H=c[y+((C|1)<<2)>>2]|0;I=H&255;do{if((I|0)!=0){if((e[E+8>>1]|0|0)>(h|0)){break}b[F+8>>1]=c[i+(I<<2)>>2]&65535}}while(0);I=H>>>8&255;do{if((I|0)!=0){if((e[E+10>>1]|0|0)>(h|0)){break}b[F+10>>1]=c[i+(I<<2)>>2]&65535}}while(0);I=H>>>16&255;do{if((I|0)!=0){if((e[E+12>>1]|0|0)>(h|0)){break}b[F+12>>1]=c[i+(I<<2)>>2]&65535}}while(0);I=H>>>24;do{if((I|0)!=0){if((e[E+14>>1]|0|0)>(h|0)){break}b[F+14>>1]=c[i+(I<<2)>>2]&65535}}while(0);I=c[y+((C|2)<<2)>>2]|0;H=I&255;do{if((H|0)!=0){if((e[E+16>>1]|0|0)>(h|0)){break}b[F+16>>1]=c[i+(H<<2)>>2]&65535}}while(0);H=I>>>8&255;do{if((H|0)!=0){if((e[E+18>>1]|0|0)>(h|0)){break}b[F+18>>1]=c[i+(H<<2)>>2]&65535}}while(0);H=I>>>16&255;do{if((H|0)!=0){if((e[E+20>>1]|0|0)>(h|0)){break}b[F+20>>1]=c[i+(H<<2)>>2]&65535}}while(0);H=I>>>24;do{if((H|0)!=0){if((e[E+22>>1]|0|0)>(h|0)){break}b[F+22>>1]=c[i+(H<<2)>>2]&65535}}while(0);H=c[y+((C|3)<<2)>>2]|0;I=H&255;do{if((I|0)!=0){if((e[E+24>>1]|0|0)>(h|0)){break}b[F+24>>1]=c[i+(I<<2)>>2]&65535}}while(0);I=H>>>8&255;do{if((I|0)!=0){if((e[E+26>>1]|0|0)>(h|0)){break}b[F+26>>1]=c[i+(I<<2)>>2]&65535}}while(0);I=H>>>16&255;do{if((I|0)!=0){if((e[E+28>>1]|0|0)>(h|0)){break}b[F+28>>1]=c[i+(I<<2)>>2]&65535}}while(0);I=H>>>24;if((I|0)==0){break}if((e[E+30>>1]|0|0)>(h|0)){break}b[F+30>>1]=c[i+(I<<2)>>2]&65535}else{if((D|0)>319){break}do{if(j){I=G&255;if((I|0)==0){break}if((e[E>>1]|0|0)>(h|0)){break}b[F>>1]=c[i+(I<<2)>>2]&65535}}while(0);if((D|0)>318){break}do{if(k){H=G>>>8&255;if((H|0)==0){break}if((e[E+2>>1]|0|0)>(h|0)){break}b[F+2>>1]=c[i+(H<<2)>>2]&65535}}while(0);if((D|0)>317){break}do{if(l){H=G>>>16&255;if((H|0)==0){break}if((e[E+4>>1]|0|0)>(h|0)){break}b[F+4>>1]=c[i+(H<<2)>>2]&65535}}while(0);H=G>>>24;if((D|0)>316){break}do{if(!(m|(H|0)==0)){if((e[E+6>>1]|0|0)>(h|0)){break}b[F+6>>1]=c[i+(H<<2)>>2]&65535}}while(0);H=c[y+((C|1)<<2)>>2]|0;if((D|0)>315){break}do{if(n){I=H&255;if((I|0)==0){break}if((e[E+8>>1]|0|0)>(h|0)){break}b[F+8>>1]=c[i+(I<<2)>>2]&65535}}while(0);if((D|0)>314){break}do{if(o){I=H>>>8&255;if((I|0)==0){break}if((e[E+10>>1]|0|0)>(h|0)){break}b[F+10>>1]=c[i+(I<<2)>>2]&65535}}while(0);if((D|0)>313){break}do{if(p){I=H>>>16&255;if((I|0)==0){break}if((e[E+12>>1]|0|0)>(h|0)){break}b[F+12>>1]=c[i+(I<<2)>>2]&65535}}while(0);I=H>>>24;if((D|0)>312){break}do{if(!(q|(I|0)==0)){if((e[E+14>>1]|0|0)>(h|0)){break}b[F+14>>1]=c[i+(I<<2)>>2]&65535}}while(0);I=c[y+((C|2)<<2)>>2]|0;if((D|0)>311){break}do{if(r){H=I&255;if((H|0)==0){break}if((e[E+16>>1]|0|0)>(h|0)){break}b[F+16>>1]=c[i+(H<<2)>>2]&65535}}while(0);if((D|0)>310){break}do{if(s){H=I>>>8&255;if((H|0)==0){break}if((e[E+18>>1]|0|0)>(h|0)){break}b[F+18>>1]=c[i+(H<<2)>>2]&65535}}while(0);if((D|0)>309){break}do{if(t){H=I>>>16&255;if((H|0)==0){break}if((e[E+20>>1]|0|0)>(h|0)){break}b[F+20>>1]=c[i+(H<<2)>>2]&65535}}while(0);H=I>>>24;if((D|0)>308){break}do{if(!(u|(H|0)==0)){if((e[E+22>>1]|0|0)>(h|0)){break}b[F+22>>1]=c[i+(H<<2)>>2]&65535}}while(0);H=c[y+((C|3)<<2)>>2]|0;if((D|0)>307){break}do{if(v){I=H&255;if((I|0)==0){break}if((e[E+24>>1]|0|0)>(h|0)){break}b[F+24>>1]=c[i+(I<<2)>>2]&65535}}while(0);if((D|0)>306){break}do{if(w){I=H>>>8&255;if((I|0)==0){break}if((e[E+26>>1]|0|0)>(h|0)){break}b[F+26>>1]=c[i+(I<<2)>>2]&65535}}while(0);if((D|0)>305){break}do{if(x){I=H>>>16&255;if((I|0)==0){break}if((e[E+28>>1]|0|0)>(h|0)){break}b[F+28>>1]=c[i+(I<<2)>>2]&65535}}while(0);if(!((D|0)<305&(f|0)>-16)){break}I=H>>>24;if((I|0)==0){break}if((e[E+30>>1]|0|0)>(h|0)){break}b[F+30>>1]=c[i+(I<<2)>>2]&65535}}while(0);G=C+4|0;I=F+32|0;J=E+32|0;if((G|0)>=(d|0)){K=z;L=A;M=B;N=J;O=I;break L13141}C=G;D=D+16|0;E=J;F=I}}else{K=z;L=A;M=B;N=A;O=z}}while(0);z=K+640|0;A=L+640|0;B=M+1|0;y=y+(g<<2)|0;}while((B|0)<(a|0));c[2443766]=y;c[2406666]=N;c[2409608]=O;c[2420368]=z;c[2415140]=A;c[3528514]=B;return}function auO(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;c[3528514]=0;a=c[2409614]|0;if((a|0)<=0){return}d=c[2409618]|0;e=c[2415168]|0;f=c[2438140]|0;g=c[2415166]&65535;h=c[2438094]|0;i=(e|0)>-1;j=(e|0)>-2;k=(e|0)>-3;l=(e|0)<-3;m=(e|0)>-5;n=(e|0)>-6;o=(e|0)>-7;p=(e|0)<-7;q=(e|0)>-9;r=(e|0)>-10;s=(e|0)>-11;t=(e|0)<-11;u=(e|0)>-13;v=(e|0)>-14;w=(e|0)>-15;x=c[2443766]|0;y=c[2420368]|0;z=c[2415140]|0;A=0;do{L13310:do{if((d|0)>0){B=0;C=e;D=y;E=z;while(1){F=c[x+(B<<2)>>2]|0;do{if(C>>>0<304){G=F&255;if((G|0)!=0){b[E>>1]=g;b[D>>1]=c[h+(G<<2)>>2]&65535}G=F>>>8&255;if((G|0)!=0){b[E+2>>1]=g;b[D+2>>1]=c[h+(G<<2)>>2]&65535}G=F>>>16&255;if((G|0)!=0){b[E+4>>1]=g;b[D+4>>1]=c[h+(G<<2)>>2]&65535}G=F>>>24;if((G|0)!=0){b[E+6>>1]=g;b[D+6>>1]=c[h+(G<<2)>>2]&65535}G=c[x+((B|1)<<2)>>2]|0;H=G&255;if((H|0)!=0){b[E+8>>1]=g;b[D+8>>1]=c[h+(H<<2)>>2]&65535}H=G>>>8&255;if((H|0)!=0){b[E+10>>1]=g;b[D+10>>1]=c[h+(H<<2)>>2]&65535}H=G>>>16&255;if((H|0)!=0){b[E+12>>1]=g;b[D+12>>1]=c[h+(H<<2)>>2]&65535}H=G>>>24;if((H|0)!=0){b[E+14>>1]=g;b[D+14>>1]=c[h+(H<<2)>>2]&65535}H=c[x+((B|2)<<2)>>2]|0;G=H&255;if((G|0)!=0){b[E+16>>1]=g;b[D+16>>1]=c[h+(G<<2)>>2]&65535}G=H>>>8&255;if((G|0)!=0){b[E+18>>1]=g;b[D+18>>1]=c[h+(G<<2)>>2]&65535}G=H>>>16&255;if((G|0)!=0){b[E+20>>1]=g;b[D+20>>1]=c[h+(G<<2)>>2]&65535}G=H>>>24;if((G|0)!=0){b[E+22>>1]=g;b[D+22>>1]=c[h+(G<<2)>>2]&65535}G=c[x+((B|3)<<2)>>2]|0;H=G&255;if((H|0)!=0){b[E+24>>1]=g;b[D+24>>1]=c[h+(H<<2)>>2]&65535}H=G>>>8&255;if((H|0)!=0){b[E+26>>1]=g;b[D+26>>1]=c[h+(H<<2)>>2]&65535}H=G>>>16&255;if((H|0)!=0){b[E+28>>1]=g;b[D+28>>1]=c[h+(H<<2)>>2]&65535}H=G>>>24;if((H|0)==0){break}b[E+30>>1]=g;b[D+30>>1]=c[h+(H<<2)>>2]&65535}else{if((C|0)>319){break}do{if(i){H=F&255;if((H|0)==0){break}b[E>>1]=g;b[D>>1]=c[h+(H<<2)>>2]&65535}}while(0);if((C|0)>318){break}do{if(j){H=F>>>8&255;if((H|0)==0){break}b[E+2>>1]=g;b[D+2>>1]=c[h+(H<<2)>>2]&65535}}while(0);if((C|0)>317){break}do{if(k){H=F>>>16&255;if((H|0)==0){break}b[E+4>>1]=g;b[D+4>>1]=c[h+(H<<2)>>2]&65535}}while(0);H=F>>>24;if((C|0)>316){break}if(!(l|(H|0)==0)){b[E+6>>1]=g;b[D+6>>1]=c[h+(H<<2)>>2]&65535}H=c[x+((B|1)<<2)>>2]|0;if((C|0)>315){break}do{if(m){G=H&255;if((G|0)==0){break}b[E+8>>1]=g;b[D+8>>1]=c[h+(G<<2)>>2]&65535}}while(0);if((C|0)>314){break}do{if(n){G=H>>>8&255;if((G|0)==0){break}b[E+10>>1]=g;b[D+10>>1]=c[h+(G<<2)>>2]&65535}}while(0);if((C|0)>313){break}do{if(o){G=H>>>16&255;if((G|0)==0){break}b[E+12>>1]=g;b[D+12>>1]=c[h+(G<<2)>>2]&65535}}while(0);G=H>>>24;if((C|0)>312){break}if(!(p|(G|0)==0)){b[E+14>>1]=g;b[D+14>>1]=c[h+(G<<2)>>2]&65535}G=c[x+((B|2)<<2)>>2]|0;if((C|0)>311){break}do{if(q){I=G&255;if((I|0)==0){break}b[E+16>>1]=g;b[D+16>>1]=c[h+(I<<2)>>2]&65535}}while(0);if((C|0)>310){break}do{if(r){H=G>>>8&255;if((H|0)==0){break}b[E+18>>1]=g;b[D+18>>1]=c[h+(H<<2)>>2]&65535}}while(0);if((C|0)>309){break}do{if(s){H=G>>>16&255;if((H|0)==0){break}b[E+20>>1]=g;b[D+20>>1]=c[h+(H<<2)>>2]&65535}}while(0);H=G>>>24;if((C|0)>308){break}if(!(t|(H|0)==0)){b[E+22>>1]=g;b[D+22>>1]=c[h+(H<<2)>>2]&65535}H=c[x+((B|3)<<2)>>2]|0;if((C|0)>307){break}do{if(u){I=H&255;if((I|0)==0){break}b[E+24>>1]=g;b[D+24>>1]=c[h+(I<<2)>>2]&65535}}while(0);if((C|0)>306){break}do{if(v){G=H>>>8&255;if((G|0)==0){break}b[E+26>>1]=g;b[D+26>>1]=c[h+(G<<2)>>2]&65535}}while(0);if((C|0)>305){break}do{if(w){G=H>>>16&255;if((G|0)==0){break}b[E+28>>1]=g;b[D+28>>1]=c[h+(G<<2)>>2]&65535}}while(0);if(!((C|0)<305&(e|0)>-16)){break}G=H>>>24;if((G|0)==0){break}b[E+30>>1]=g;b[D+30>>1]=c[h+(G<<2)>>2]&65535}}while(0);F=B+4|0;G=D+32|0;I=E+32|0;if((F|0)>=(d|0)){J=y;K=z;L=A;M=G;N=I;break L13310}B=F;C=C+16|0;D=G;E=I}}else{J=y;K=z;L=A;M=y;N=z}}while(0);y=J+640|0;z=K+640|0;A=L+1|0;x=x+(f<<2)|0;}while((A|0)<(a|0));c[2443766]=x;c[2409608]=M;c[2406666]=N;c[2420368]=y;c[2415140]=z;c[3528514]=A;return}function auP(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;c[3528514]=0;a=c[2409614]|0;if((a|0)<=0){return}d=c[2409618]|0;f=c[2415168]|0;g=c[2438140]|0;h=c[2415166]|0;i=h&65535;j=c[2438094]|0;k=(f|0)>-1;l=(f|0)>-2;m=(f|0)>-3;n=(f|0)<-3;o=(f|0)>-5;p=(f|0)>-6;q=(f|0)>-7;r=(f|0)<-7;s=(f|0)>-9;t=(f|0)>-10;u=(f|0)>-11;v=(f|0)<-11;w=(f|0)>-13;x=(f|0)>-14;y=(f|0)>-15;z=c[2443766]|0;A=c[2420368]|0;B=c[2415140]|0;C=0;do{L13447:do{if((d|0)>0){D=0;E=f;F=A;G=B;while(1){H=c[z+(D<<2)>>2]|0;do{if(E>>>0<304){I=H&255;do{if((I|0)!=0){if((e[G>>1]|0|0)>(h|0)){break}b[G>>1]=i;b[F>>1]=c[j+(I<<2)>>2]&65535}}while(0);I=H>>>8&255;do{if((I|0)!=0){J=G+2|0;if((e[J>>1]|0|0)>(h|0)){break}b[J>>1]=i;b[F+2>>1]=c[j+(I<<2)>>2]&65535}}while(0);I=H>>>16&255;do{if((I|0)!=0){J=G+4|0;if((e[J>>1]|0|0)>(h|0)){break}b[J>>1]=i;b[F+4>>1]=c[j+(I<<2)>>2]&65535}}while(0);I=H>>>24;do{if((I|0)!=0){J=G+6|0;if((e[J>>1]|0|0)>(h|0)){break}b[J>>1]=i;b[F+6>>1]=c[j+(I<<2)>>2]&65535}}while(0);I=c[z+((D|1)<<2)>>2]|0;J=I&255;do{if((J|0)!=0){K=G+8|0;if((e[K>>1]|0|0)>(h|0)){break}b[K>>1]=i;b[F+8>>1]=c[j+(J<<2)>>2]&65535}}while(0);J=I>>>8&255;do{if((J|0)!=0){K=G+10|0;if((e[K>>1]|0|0)>(h|0)){break}b[K>>1]=i;b[F+10>>1]=c[j+(J<<2)>>2]&65535}}while(0);J=I>>>16&255;do{if((J|0)!=0){K=G+12|0;if((e[K>>1]|0|0)>(h|0)){break}b[K>>1]=i;b[F+12>>1]=c[j+(J<<2)>>2]&65535}}while(0);J=I>>>24;do{if((J|0)!=0){K=G+14|0;if((e[K>>1]|0|0)>(h|0)){break}b[K>>1]=i;b[F+14>>1]=c[j+(J<<2)>>2]&65535}}while(0);J=c[z+((D|2)<<2)>>2]|0;I=J&255;do{if((I|0)!=0){K=G+16|0;if((e[K>>1]|0|0)>(h|0)){break}b[K>>1]=i;b[F+16>>1]=c[j+(I<<2)>>2]&65535}}while(0);I=J>>>8&255;do{if((I|0)!=0){K=G+18|0;if((e[K>>1]|0|0)>(h|0)){break}b[K>>1]=i;b[F+18>>1]=c[j+(I<<2)>>2]&65535}}while(0);I=J>>>16&255;do{if((I|0)!=0){K=G+20|0;if((e[K>>1]|0|0)>(h|0)){break}b[K>>1]=i;b[F+20>>1]=c[j+(I<<2)>>2]&65535}}while(0);I=J>>>24;do{if((I|0)!=0){K=G+22|0;if((e[K>>1]|0|0)>(h|0)){break}b[K>>1]=i;b[F+22>>1]=c[j+(I<<2)>>2]&65535}}while(0);I=c[z+((D|3)<<2)>>2]|0;J=I&255;do{if((J|0)!=0){K=G+24|0;if((e[K>>1]|0|0)>(h|0)){break}b[K>>1]=i;b[F+24>>1]=c[j+(J<<2)>>2]&65535}}while(0);J=I>>>8&255;do{if((J|0)!=0){K=G+26|0;if((e[K>>1]|0|0)>(h|0)){break}b[K>>1]=i;b[F+26>>1]=c[j+(J<<2)>>2]&65535}}while(0);J=I>>>16&255;do{if((J|0)!=0){K=G+28|0;if((e[K>>1]|0|0)>(h|0)){break}b[K>>1]=i;b[F+28>>1]=c[j+(J<<2)>>2]&65535}}while(0);J=I>>>24;if((J|0)==0){break}K=G+30|0;if((e[K>>1]|0|0)>(h|0)){break}b[K>>1]=i;b[F+30>>1]=c[j+(J<<2)>>2]&65535}else{if((E|0)>319){break}do{if(k){J=H&255;if((J|0)==0){break}if((e[G>>1]|0|0)>(h|0)){break}b[G>>1]=i;b[F>>1]=c[j+(J<<2)>>2]&65535}}while(0);if((E|0)>318){break}do{if(l){I=H>>>8&255;if((I|0)==0){break}J=G+2|0;if((e[J>>1]|0|0)>(h|0)){break}b[J>>1]=i;b[F+2>>1]=c[j+(I<<2)>>2]&65535}}while(0);if((E|0)>317){break}do{if(m){I=H>>>16&255;if((I|0)==0){break}J=G+4|0;if((e[J>>1]|0|0)>(h|0)){break}b[J>>1]=i;b[F+4>>1]=c[j+(I<<2)>>2]&65535}}while(0);I=H>>>24;if((E|0)>316){break}do{if(!(n|(I|0)==0)){J=G+6|0;if((e[J>>1]|0|0)>(h|0)){break}b[J>>1]=i;b[F+6>>1]=c[j+(I<<2)>>2]&65535}}while(0);I=c[z+((D|1)<<2)>>2]|0;if((E|0)>315){break}do{if(o){J=I&255;if((J|0)==0){break}K=G+8|0;if((e[K>>1]|0|0)>(h|0)){break}b[K>>1]=i;b[F+8>>1]=c[j+(J<<2)>>2]&65535}}while(0);if((E|0)>314){break}do{if(p){J=I>>>8&255;if((J|0)==0){break}K=G+10|0;if((e[K>>1]|0|0)>(h|0)){break}b[K>>1]=i;b[F+10>>1]=c[j+(J<<2)>>2]&65535}}while(0);if((E|0)>313){break}do{if(q){J=I>>>16&255;if((J|0)==0){break}K=G+12|0;if((e[K>>1]|0|0)>(h|0)){break}b[K>>1]=i;b[F+12>>1]=c[j+(J<<2)>>2]&65535}}while(0);J=I>>>24;if((E|0)>312){break}do{if(!(r|(J|0)==0)){K=G+14|0;if((e[K>>1]|0|0)>(h|0)){break}b[K>>1]=i;b[F+14>>1]=c[j+(J<<2)>>2]&65535}}while(0);J=c[z+((D|2)<<2)>>2]|0;if((E|0)>311){break}do{if(s){I=J&255;if((I|0)==0){break}K=G+16|0;if((e[K>>1]|0|0)>(h|0)){break}b[K>>1]=i;b[F+16>>1]=c[j+(I<<2)>>2]&65535}}while(0);if((E|0)>310){break}do{if(t){I=J>>>8&255;if((I|0)==0){break}K=G+18|0;if((e[K>>1]|0|0)>(h|0)){break}b[K>>1]=i;b[F+18>>1]=c[j+(I<<2)>>2]&65535}}while(0);if((E|0)>309){break}do{if(u){I=J>>>16&255;if((I|0)==0){break}K=G+20|0;if((e[K>>1]|0|0)>(h|0)){break}b[K>>1]=i;b[F+20>>1]=c[j+(I<<2)>>2]&65535}}while(0);I=J>>>24;if((E|0)>308){break}do{if(!(v|(I|0)==0)){K=G+22|0;if((e[K>>1]|0|0)>(h|0)){break}b[K>>1]=i;b[F+22>>1]=c[j+(I<<2)>>2]&65535}}while(0);I=c[z+((D|3)<<2)>>2]|0;if((E|0)>307){break}do{if(w){J=I&255;if((J|0)==0){break}K=G+24|0;if((e[K>>1]|0|0)>(h|0)){break}b[K>>1]=i;b[F+24>>1]=c[j+(J<<2)>>2]&65535}}while(0);if((E|0)>306){break}do{if(x){J=I>>>8&255;if((J|0)==0){break}K=G+26|0;if((e[K>>1]|0|0)>(h|0)){break}b[K>>1]=i;b[F+26>>1]=c[j+(J<<2)>>2]&65535}}while(0);if((E|0)>305){break}do{if(y){J=I>>>16&255;if((J|0)==0){break}K=G+28|0;if((e[K>>1]|0|0)>(h|0)){break}b[K>>1]=i;b[F+28>>1]=c[j+(J<<2)>>2]&65535}}while(0);if(!((E|0)<305&(f|0)>-16)){break}J=I>>>24;if((J|0)==0){break}K=G+30|0;if((e[K>>1]|0|0)>(h|0)){break}b[K>>1]=i;b[F+30>>1]=c[j+(J<<2)>>2]&65535}}while(0);H=D+4|0;J=F+32|0;K=G+32|0;if((H|0)>=(d|0)){L=A;M=B;N=C;O=J;P=K;break L13447}D=H;E=E+16|0;F=J;G=K}}else{L=A;M=B;N=C;O=A;P=B}}while(0);A=L+640|0;B=M+640|0;C=N+1|0;z=z+(g<<2)|0;}while((C|0)<(a|0));c[2443766]=z;c[2409608]=O;c[2406666]=P;c[2420368]=A;c[2415140]=B;c[3528514]=C;return}function auQ(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;c[3528514]=0;a=c[2409614]|0;if((a|0)<=0){return}d=c[2415168]|0;e=c[2409618]|0;f=e-4|0;g=(f|0)>-1;h=c[2438140]|0;i=c[2438094]|0;j=c[2443766]|0;k=c[2420368]|0;l=0;do{L13616:do{if(g){m=e;n=d;o=f;p=k;while(1){q=c[j+(m-1<<2)>>2]|0;do{if(n>>>0<304){r=q&255;if((r|0)!=0){b[p+6>>1]=c[i+(r<<2)>>2]&65535}r=q>>>8&255;if((r|0)!=0){b[p+4>>1]=c[i+(r<<2)>>2]&65535}r=q>>>16&255;if((r|0)!=0){b[p+2>>1]=c[i+(r<<2)>>2]&65535}r=q>>>24;if((r|0)!=0){b[p>>1]=c[i+(r<<2)>>2]&65535}r=c[j+(m-2<<2)>>2]|0;s=r&255;if((s|0)!=0){b[p+14>>1]=c[i+(s<<2)>>2]&65535}s=r>>>8&255;if((s|0)!=0){b[p+12>>1]=c[i+(s<<2)>>2]&65535}s=r>>>16&255;if((s|0)!=0){b[p+10>>1]=c[i+(s<<2)>>2]&65535}s=r>>>24;if((s|0)!=0){b[p+8>>1]=c[i+(s<<2)>>2]&65535}s=c[j+(m-3<<2)>>2]|0;r=s&255;if((r|0)!=0){b[p+22>>1]=c[i+(r<<2)>>2]&65535}r=s>>>8&255;if((r|0)!=0){b[p+20>>1]=c[i+(r<<2)>>2]&65535}r=s>>>16&255;if((r|0)!=0){b[p+18>>1]=c[i+(r<<2)>>2]&65535}r=s>>>24;if((r|0)!=0){b[p+16>>1]=c[i+(r<<2)>>2]&65535}r=c[j+(o<<2)>>2]|0;s=r&255;if((s|0)!=0){b[p+30>>1]=c[i+(s<<2)>>2]&65535}s=r>>>8&255;if((s|0)!=0){b[p+28>>1]=c[i+(s<<2)>>2]&65535}s=r>>>16&255;if((s|0)!=0){b[p+26>>1]=c[i+(s<<2)>>2]&65535}s=r>>>24;if((s|0)==0){break}b[p+24>>1]=c[i+(s<<2)>>2]&65535}else{do{if((n+3|0)>>>0<320){s=q&255;if((s|0)==0){break}b[p+6>>1]=c[i+(s<<2)>>2]&65535}}while(0);do{if((n+2|0)>>>0<320){s=q>>>8&255;if((s|0)==0){break}b[p+4>>1]=c[i+(s<<2)>>2]&65535}}while(0);do{if((n+1|0)>>>0<320){s=q>>>16&255;if((s|0)==0){break}b[p+2>>1]=c[i+(s<<2)>>2]&65535}}while(0);do{if(n>>>0<320){s=q>>>24;if((s|0)==0){break}b[p>>1]=c[i+(s<<2)>>2]&65535}}while(0);s=c[j+(m-2<<2)>>2]|0;do{if((n+7|0)>>>0<320){r=s&255;if((r|0)==0){break}b[p+14>>1]=c[i+(r<<2)>>2]&65535}}while(0);do{if((n+6|0)>>>0<320){r=s>>>8&255;if((r|0)==0){break}b[p+12>>1]=c[i+(r<<2)>>2]&65535}}while(0);do{if((n+5|0)>>>0<320){r=s>>>16&255;if((r|0)==0){break}b[p+10>>1]=c[i+(r<<2)>>2]&65535}}while(0);do{if((n+4|0)>>>0<320){r=s>>>24;if((r|0)==0){break}b[p+8>>1]=c[i+(r<<2)>>2]&65535}}while(0);s=c[j+(m-3<<2)>>2]|0;do{if((n+11|0)>>>0<320){r=s&255;if((r|0)==0){break}b[p+22>>1]=c[i+(r<<2)>>2]&65535}}while(0);do{if((n+10|0)>>>0<320){r=s>>>8&255;if((r|0)==0){break}b[p+20>>1]=c[i+(r<<2)>>2]&65535}}while(0);do{if((n+9|0)>>>0<320){r=s>>>16&255;if((r|0)==0){break}b[p+18>>1]=c[i+(r<<2)>>2]&65535}}while(0);do{if((n+8|0)>>>0<320){r=s>>>24;if((r|0)==0){break}b[p+16>>1]=c[i+(r<<2)>>2]&65535}}while(0);s=c[j+(o<<2)>>2]|0;do{if((n+15|0)>>>0<320){r=s&255;if((r|0)==0){break}b[p+30>>1]=c[i+(r<<2)>>2]&65535}}while(0);do{if((n+14|0)>>>0<320){r=s>>>8&255;if((r|0)==0){break}b[p+28>>1]=c[i+(r<<2)>>2]&65535}}while(0);do{if((n+13|0)>>>0<320){r=s>>>16&255;if((r|0)==0){break}b[p+26>>1]=c[i+(r<<2)>>2]&65535}}while(0);if((n+12|0)>>>0>=320){break}r=s>>>24;if((r|0)==0){break}b[p+24>>1]=c[i+(r<<2)>>2]&65535}}while(0);q=p+32|0;r=o-4|0;if((r|0)<=-1){t=k;u=l;v=q;break L13616}m=o;n=n+16|0;o=r;p=q}}else{t=k;u=l;v=k}}while(0);k=t+640|0;l=u+1|0;j=j+(h<<2)|0;}while((l|0)<(a|0));c[2443766]=j;c[2409608]=v;c[2420368]=k;c[3528514]=l;return}function auR(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;c[3528514]=0;a=c[2409614]|0;if((a|0)<=0){return}d=c[2415168]|0;f=c[2409618]|0;g=f-4|0;h=(g|0)>-1;i=c[2438140]|0;j=c[2415166]|0;k=c[2438094]|0;l=c[2443766]|0;m=c[2420368]|0;n=c[2415140]|0;o=0;do{L13741:do{if(h){p=f;q=d;r=g;s=n;t=m;while(1){u=c[l+(p-1<<2)>>2]|0;do{if(q>>>0<304){v=u&255;do{if((v|0)!=0){if((e[s+6>>1]|0|0)>(j|0)){break}b[t+6>>1]=c[k+(v<<2)>>2]&65535}}while(0);v=u>>>8&255;do{if((v|0)!=0){if((e[s+4>>1]|0|0)>(j|0)){break}b[t+4>>1]=c[k+(v<<2)>>2]&65535}}while(0);v=u>>>16&255;do{if((v|0)!=0){if((e[s+2>>1]|0|0)>(j|0)){break}b[t+2>>1]=c[k+(v<<2)>>2]&65535}}while(0);v=u>>>24;do{if((v|0)!=0){if((e[s>>1]|0|0)>(j|0)){break}b[t>>1]=c[k+(v<<2)>>2]&65535}}while(0);v=c[l+(p-2<<2)>>2]|0;w=v&255;do{if((w|0)!=0){if((e[s+14>>1]|0|0)>(j|0)){break}b[t+14>>1]=c[k+(w<<2)>>2]&65535}}while(0);w=v>>>8&255;do{if((w|0)!=0){if((e[s+12>>1]|0|0)>(j|0)){break}b[t+12>>1]=c[k+(w<<2)>>2]&65535}}while(0);w=v>>>16&255;do{if((w|0)!=0){if((e[s+10>>1]|0|0)>(j|0)){break}b[t+10>>1]=c[k+(w<<2)>>2]&65535}}while(0);w=v>>>24;do{if((w|0)!=0){if((e[s+8>>1]|0|0)>(j|0)){break}b[t+8>>1]=c[k+(w<<2)>>2]&65535}}while(0);w=c[l+(p-3<<2)>>2]|0;v=w&255;do{if((v|0)!=0){if((e[s+22>>1]|0|0)>(j|0)){break}b[t+22>>1]=c[k+(v<<2)>>2]&65535}}while(0);v=w>>>8&255;do{if((v|0)!=0){if((e[s+20>>1]|0|0)>(j|0)){break}b[t+20>>1]=c[k+(v<<2)>>2]&65535}}while(0);v=w>>>16&255;do{if((v|0)!=0){if((e[s+18>>1]|0|0)>(j|0)){break}b[t+18>>1]=c[k+(v<<2)>>2]&65535}}while(0);v=w>>>24;do{if((v|0)!=0){if((e[s+16>>1]|0|0)>(j|0)){break}b[t+16>>1]=c[k+(v<<2)>>2]&65535}}while(0);v=c[l+(r<<2)>>2]|0;w=v&255;do{if((w|0)!=0){if((e[s+30>>1]|0|0)>(j|0)){break}b[t+30>>1]=c[k+(w<<2)>>2]&65535}}while(0);w=v>>>8&255;do{if((w|0)!=0){if((e[s+28>>1]|0|0)>(j|0)){break}b[t+28>>1]=c[k+(w<<2)>>2]&65535}}while(0);w=v>>>16&255;do{if((w|0)!=0){if((e[s+26>>1]|0|0)>(j|0)){break}b[t+26>>1]=c[k+(w<<2)>>2]&65535}}while(0);w=v>>>24;if((w|0)==0){break}if((e[s+24>>1]|0|0)>(j|0)){break}b[t+24>>1]=c[k+(w<<2)>>2]&65535}else{do{if((q+3|0)>>>0<320){w=u&255;if((w|0)==0){break}if((e[s+6>>1]|0|0)>(j|0)){break}b[t+6>>1]=c[k+(w<<2)>>2]&65535}}while(0);do{if((q+2|0)>>>0<320){v=u>>>8&255;if((v|0)==0){break}if((e[s+4>>1]|0|0)>(j|0)){break}b[t+4>>1]=c[k+(v<<2)>>2]&65535}}while(0);do{if((q+1|0)>>>0<320){v=u>>>16&255;if((v|0)==0){break}if((e[s+2>>1]|0|0)>(j|0)){break}b[t+2>>1]=c[k+(v<<2)>>2]&65535}}while(0);do{if(q>>>0<320){v=u>>>24;if((v|0)==0){break}if((e[s>>1]|0|0)>(j|0)){break}b[t>>1]=c[k+(v<<2)>>2]&65535}}while(0);v=c[l+(p-2<<2)>>2]|0;do{if((q+7|0)>>>0<320){w=v&255;if((w|0)==0){break}if((e[s+14>>1]|0|0)>(j|0)){break}b[t+14>>1]=c[k+(w<<2)>>2]&65535}}while(0);do{if((q+6|0)>>>0<320){w=v>>>8&255;if((w|0)==0){break}if((e[s+12>>1]|0|0)>(j|0)){break}b[t+12>>1]=c[k+(w<<2)>>2]&65535}}while(0);do{if((q+5|0)>>>0<320){w=v>>>16&255;if((w|0)==0){break}if((e[s+10>>1]|0|0)>(j|0)){break}b[t+10>>1]=c[k+(w<<2)>>2]&65535}}while(0);do{if((q+4|0)>>>0<320){w=v>>>24;if((w|0)==0){break}if((e[s+8>>1]|0|0)>(j|0)){break}b[t+8>>1]=c[k+(w<<2)>>2]&65535}}while(0);v=c[l+(p-3<<2)>>2]|0;do{if((q+11|0)>>>0<320){w=v&255;if((w|0)==0){break}if((e[s+22>>1]|0|0)>(j|0)){break}b[t+22>>1]=c[k+(w<<2)>>2]&65535}}while(0);do{if((q+10|0)>>>0<320){w=v>>>8&255;if((w|0)==0){break}if((e[s+20>>1]|0|0)>(j|0)){break}b[t+20>>1]=c[k+(w<<2)>>2]&65535}}while(0);do{if((q+9|0)>>>0<320){w=v>>>16&255;if((w|0)==0){break}if((e[s+18>>1]|0|0)>(j|0)){break}b[t+18>>1]=c[k+(w<<2)>>2]&65535}}while(0);do{if((q+8|0)>>>0<320){w=v>>>24;if((w|0)==0){break}if((e[s+16>>1]|0|0)>(j|0)){break}b[t+16>>1]=c[k+(w<<2)>>2]&65535}}while(0);v=c[l+(r<<2)>>2]|0;do{if((q+15|0)>>>0<320){w=v&255;if((w|0)==0){break}if((e[s+30>>1]|0|0)>(j|0)){break}b[t+30>>1]=c[k+(w<<2)>>2]&65535}}while(0);do{if((q+14|0)>>>0<320){w=v>>>8&255;if((w|0)==0){break}if((e[s+28>>1]|0|0)>(j|0)){break}b[t+28>>1]=c[k+(w<<2)>>2]&65535}}while(0);do{if((q+13|0)>>>0<320){w=v>>>16&255;if((w|0)==0){break}if((e[s+26>>1]|0|0)>(j|0)){break}b[t+26>>1]=c[k+(w<<2)>>2]&65535}}while(0);if((q+12|0)>>>0>=320){break}w=v>>>24;if((w|0)==0){break}if((e[s+24>>1]|0|0)>(j|0)){break}b[t+24>>1]=c[k+(w<<2)>>2]&65535}}while(0);u=t+32|0;w=s+32|0;x=r-4|0;if((x|0)<=-1){y=m;z=n;A=o;B=w;C=u;break L13741}p=r;q=q+16|0;r=x;s=w;t=u}}else{y=m;z=n;A=o;B=n;C=m}}while(0);m=y+640|0;n=z+640|0;o=A+1|0;l=l+(i<<2)|0;}while((o|0)<(a|0));c[2443766]=l;c[2406666]=B;c[2409608]=C;c[2420368]=m;c[2415140]=n;c[3528514]=o;return}function auS(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;c[3528514]=0;a=c[2409614]|0;if((a|0)<=0){return}d=c[2415168]|0;e=c[2409618]|0;f=e-4|0;g=(f|0)>-1;h=c[2438140]|0;i=c[2415166]&65535;j=c[2438094]|0;k=c[2443766]|0;l=c[2420368]|0;m=c[2415140]|0;n=0;do{L13898:do{if(g){o=e;p=d;q=f;r=l;s=m;while(1){t=c[k+(o-1<<2)>>2]|0;do{if(p>>>0<304){u=t&255;if((u|0)!=0){b[s+6>>1]=i;b[r+6>>1]=c[j+(u<<2)>>2]&65535}u=t>>>8&255;if((u|0)!=0){b[s+4>>1]=i;b[r+4>>1]=c[j+(u<<2)>>2]&65535}u=t>>>16&255;if((u|0)!=0){b[s+2>>1]=i;b[r+2>>1]=c[j+(u<<2)>>2]&65535}u=t>>>24;if((u|0)!=0){b[s>>1]=i;b[r>>1]=c[j+(u<<2)>>2]&65535}u=c[k+(o-2<<2)>>2]|0;v=u&255;if((v|0)!=0){b[s+14>>1]=i;b[r+14>>1]=c[j+(v<<2)>>2]&65535}v=u>>>8&255;if((v|0)!=0){b[s+12>>1]=i;b[r+12>>1]=c[j+(v<<2)>>2]&65535}v=u>>>16&255;if((v|0)!=0){b[s+10>>1]=i;b[r+10>>1]=c[j+(v<<2)>>2]&65535}v=u>>>24;if((v|0)!=0){b[s+8>>1]=i;b[r+8>>1]=c[j+(v<<2)>>2]&65535}v=c[k+(o-3<<2)>>2]|0;u=v&255;if((u|0)!=0){b[s+22>>1]=i;b[r+22>>1]=c[j+(u<<2)>>2]&65535}u=v>>>8&255;if((u|0)!=0){b[s+20>>1]=i;b[r+20>>1]=c[j+(u<<2)>>2]&65535}u=v>>>16&255;if((u|0)!=0){b[s+18>>1]=i;b[r+18>>1]=c[j+(u<<2)>>2]&65535}u=v>>>24;if((u|0)!=0){b[s+16>>1]=i;b[r+16>>1]=c[j+(u<<2)>>2]&65535}u=c[k+(q<<2)>>2]|0;v=u&255;if((v|0)!=0){b[s+30>>1]=i;b[r+30>>1]=c[j+(v<<2)>>2]&65535}v=u>>>8&255;if((v|0)!=0){b[s+28>>1]=i;b[r+28>>1]=c[j+(v<<2)>>2]&65535}v=u>>>16&255;if((v|0)!=0){b[s+26>>1]=i;b[r+26>>1]=c[j+(v<<2)>>2]&65535}v=u>>>24;if((v|0)==0){break}b[s+24>>1]=i;b[r+24>>1]=c[j+(v<<2)>>2]&65535}else{do{if((p+3|0)>>>0<320){v=t&255;if((v|0)==0){break}b[s+6>>1]=i;b[r+6>>1]=c[j+(v<<2)>>2]&65535}}while(0);do{if((p+2|0)>>>0<320){v=t>>>8&255;if((v|0)==0){break}b[s+4>>1]=i;b[r+4>>1]=c[j+(v<<2)>>2]&65535}}while(0);do{if((p+1|0)>>>0<320){v=t>>>16&255;if((v|0)==0){break}b[s+2>>1]=i;b[r+2>>1]=c[j+(v<<2)>>2]&65535}}while(0);do{if(p>>>0<320){v=t>>>24;if((v|0)==0){break}b[s>>1]=i;b[r>>1]=c[j+(v<<2)>>2]&65535}}while(0);v=c[k+(o-2<<2)>>2]|0;do{if((p+7|0)>>>0<320){u=v&255;if((u|0)==0){break}b[s+14>>1]=i;b[r+14>>1]=c[j+(u<<2)>>2]&65535}}while(0);do{if((p+6|0)>>>0<320){u=v>>>8&255;if((u|0)==0){break}b[s+12>>1]=i;b[r+12>>1]=c[j+(u<<2)>>2]&65535}}while(0);do{if((p+5|0)>>>0<320){u=v>>>16&255;if((u|0)==0){break}b[s+10>>1]=i;b[r+10>>1]=c[j+(u<<2)>>2]&65535}}while(0);do{if((p+4|0)>>>0<320){u=v>>>24;if((u|0)==0){break}b[s+8>>1]=i;b[r+8>>1]=c[j+(u<<2)>>2]&65535}}while(0);v=c[k+(o-3<<2)>>2]|0;do{if((p+11|0)>>>0<320){u=v&255;if((u|0)==0){break}b[s+22>>1]=i;b[r+22>>1]=c[j+(u<<2)>>2]&65535}}while(0);do{if((p+10|0)>>>0<320){u=v>>>8&255;if((u|0)==0){break}b[s+20>>1]=i;b[r+20>>1]=c[j+(u<<2)>>2]&65535}}while(0);do{if((p+9|0)>>>0<320){u=v>>>16&255;if((u|0)==0){break}b[s+18>>1]=i;b[r+18>>1]=c[j+(u<<2)>>2]&65535}}while(0);do{if((p+8|0)>>>0<320){u=v>>>24;if((u|0)==0){break}b[s+16>>1]=i;b[r+16>>1]=c[j+(u<<2)>>2]&65535}}while(0);v=c[k+(q<<2)>>2]|0;do{if((p+15|0)>>>0<320){u=v&255;if((u|0)==0){break}b[s+30>>1]=i;b[r+30>>1]=c[j+(u<<2)>>2]&65535}}while(0);do{if((p+14|0)>>>0<320){u=v>>>8&255;if((u|0)==0){break}b[s+28>>1]=i;b[r+28>>1]=c[j+(u<<2)>>2]&65535}}while(0);do{if((p+13|0)>>>0<320){u=v>>>16&255;if((u|0)==0){break}b[s+26>>1]=i;b[r+26>>1]=c[j+(u<<2)>>2]&65535}}while(0);if((p+12|0)>>>0>=320){break}u=v>>>24;if((u|0)==0){break}b[s+24>>1]=i;b[r+24>>1]=c[j+(u<<2)>>2]&65535}}while(0);t=r+32|0;u=s+32|0;w=q-4|0;if((w|0)<=-1){x=l;y=m;z=n;A=t;B=u;break L13898}o=q;p=p+16|0;q=w;r=t;s=u}}else{x=l;y=m;z=n;A=l;B=m}}while(0);l=x+640|0;m=y+640|0;n=z+1|0;k=k+(h<<2)|0;}while((n|0)<(a|0));c[2443766]=k;c[2409608]=A;c[2406666]=B;c[2420368]=l;c[2415140]=m;c[3528514]=n;return}function auT(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;c[3528514]=0;a=c[2409614]|0;if((a|0)<=0){return}d=c[2415168]|0;f=c[2409618]|0;g=f-4|0;h=(g|0)>-1;i=c[2438140]|0;j=c[2415166]|0;k=j&65535;l=c[2438094]|0;m=c[2443766]|0;n=c[2420368]|0;o=c[2415140]|0;p=0;do{L14023:do{if(h){q=f;r=d;s=g;t=n;u=o;while(1){v=c[m+(q-1<<2)>>2]|0;do{if(r>>>0<304){w=v&255;do{if((w|0)!=0){x=u+6|0;if((e[x>>1]|0|0)>(j|0)){break}b[x>>1]=k;b[t+6>>1]=c[l+(w<<2)>>2]&65535}}while(0);w=v>>>8&255;do{if((w|0)!=0){x=u+4|0;if((e[x>>1]|0|0)>(j|0)){break}b[x>>1]=k;b[t+4>>1]=c[l+(w<<2)>>2]&65535}}while(0);w=v>>>16&255;do{if((w|0)!=0){x=u+2|0;if((e[x>>1]|0|0)>(j|0)){break}b[x>>1]=k;b[t+2>>1]=c[l+(w<<2)>>2]&65535}}while(0);w=v>>>24;do{if((w|0)!=0){if((e[u>>1]|0|0)>(j|0)){break}b[u>>1]=k;b[t>>1]=c[l+(w<<2)>>2]&65535}}while(0);w=c[m+(q-2<<2)>>2]|0;x=w&255;do{if((x|0)!=0){y=u+14|0;if((e[y>>1]|0|0)>(j|0)){break}b[y>>1]=k;b[t+14>>1]=c[l+(x<<2)>>2]&65535}}while(0);x=w>>>8&255;do{if((x|0)!=0){y=u+12|0;if((e[y>>1]|0|0)>(j|0)){break}b[y>>1]=k;b[t+12>>1]=c[l+(x<<2)>>2]&65535}}while(0);x=w>>>16&255;do{if((x|0)!=0){y=u+10|0;if((e[y>>1]|0|0)>(j|0)){break}b[y>>1]=k;b[t+10>>1]=c[l+(x<<2)>>2]&65535}}while(0);x=w>>>24;do{if((x|0)!=0){y=u+8|0;if((e[y>>1]|0|0)>(j|0)){break}b[y>>1]=k;b[t+8>>1]=c[l+(x<<2)>>2]&65535}}while(0);x=c[m+(q-3<<2)>>2]|0;w=x&255;do{if((w|0)!=0){y=u+22|0;if((e[y>>1]|0|0)>(j|0)){break}b[y>>1]=k;b[t+22>>1]=c[l+(w<<2)>>2]&65535}}while(0);w=x>>>8&255;do{if((w|0)!=0){y=u+20|0;if((e[y>>1]|0|0)>(j|0)){break}b[y>>1]=k;b[t+20>>1]=c[l+(w<<2)>>2]&65535}}while(0);w=x>>>16&255;do{if((w|0)!=0){y=u+18|0;if((e[y>>1]|0|0)>(j|0)){break}b[y>>1]=k;b[t+18>>1]=c[l+(w<<2)>>2]&65535}}while(0);w=x>>>24;do{if((w|0)!=0){y=u+16|0;if((e[y>>1]|0|0)>(j|0)){break}b[y>>1]=k;b[t+16>>1]=c[l+(w<<2)>>2]&65535}}while(0);w=c[m+(s<<2)>>2]|0;x=w&255;do{if((x|0)!=0){y=u+30|0;if((e[y>>1]|0|0)>(j|0)){break}b[y>>1]=k;b[t+30>>1]=c[l+(x<<2)>>2]&65535}}while(0);x=w>>>8&255;do{if((x|0)!=0){y=u+28|0;if((e[y>>1]|0|0)>(j|0)){break}b[y>>1]=k;b[t+28>>1]=c[l+(x<<2)>>2]&65535}}while(0);x=w>>>16&255;do{if((x|0)!=0){y=u+26|0;if((e[y>>1]|0|0)>(j|0)){break}b[y>>1]=k;b[t+26>>1]=c[l+(x<<2)>>2]&65535}}while(0);x=w>>>24;if((x|0)==0){break}y=u+24|0;if((e[y>>1]|0|0)>(j|0)){break}b[y>>1]=k;b[t+24>>1]=c[l+(x<<2)>>2]&65535}else{do{if((r+3|0)>>>0<320){x=v&255;if((x|0)==0){break}y=u+6|0;if((e[y>>1]|0|0)>(j|0)){break}b[y>>1]=k;b[t+6>>1]=c[l+(x<<2)>>2]&65535}}while(0);do{if((r+2|0)>>>0<320){w=v>>>8&255;if((w|0)==0){break}x=u+4|0;if((e[x>>1]|0|0)>(j|0)){break}b[x>>1]=k;b[t+4>>1]=c[l+(w<<2)>>2]&65535}}while(0);do{if((r+1|0)>>>0<320){w=v>>>16&255;if((w|0)==0){break}x=u+2|0;if((e[x>>1]|0|0)>(j|0)){break}b[x>>1]=k;b[t+2>>1]=c[l+(w<<2)>>2]&65535}}while(0);do{if(r>>>0<320){w=v>>>24;if((w|0)==0){break}if((e[u>>1]|0|0)>(j|0)){break}b[u>>1]=k;b[t>>1]=c[l+(w<<2)>>2]&65535}}while(0);w=c[m+(q-2<<2)>>2]|0;do{if((r+7|0)>>>0<320){x=w&255;if((x|0)==0){break}y=u+14|0;if((e[y>>1]|0|0)>(j|0)){break}b[y>>1]=k;b[t+14>>1]=c[l+(x<<2)>>2]&65535}}while(0);do{if((r+6|0)>>>0<320){x=w>>>8&255;if((x|0)==0){break}y=u+12|0;if((e[y>>1]|0|0)>(j|0)){break}b[y>>1]=k;b[t+12>>1]=c[l+(x<<2)>>2]&65535}}while(0);do{if((r+5|0)>>>0<320){x=w>>>16&255;if((x|0)==0){break}y=u+10|0;if((e[y>>1]|0|0)>(j|0)){break}b[y>>1]=k;b[t+10>>1]=c[l+(x<<2)>>2]&65535}}while(0);do{if((r+4|0)>>>0<320){x=w>>>24;if((x|0)==0){break}y=u+8|0;if((e[y>>1]|0|0)>(j|0)){break}b[y>>1]=k;b[t+8>>1]=c[l+(x<<2)>>2]&65535}}while(0);w=c[m+(q-3<<2)>>2]|0;do{if((r+11|0)>>>0<320){x=w&255;if((x|0)==0){break}y=u+22|0;if((e[y>>1]|0|0)>(j|0)){break}b[y>>1]=k;b[t+22>>1]=c[l+(x<<2)>>2]&65535}}while(0);do{if((r+10|0)>>>0<320){x=w>>>8&255;if((x|0)==0){break}y=u+20|0;if((e[y>>1]|0|0)>(j|0)){break}b[y>>1]=k;b[t+20>>1]=c[l+(x<<2)>>2]&65535}}while(0);do{if((r+9|0)>>>0<320){x=w>>>16&255;if((x|0)==0){break}y=u+18|0;if((e[y>>1]|0|0)>(j|0)){break}b[y>>1]=k;b[t+18>>1]=c[l+(x<<2)>>2]&65535}}while(0);do{if((r+8|0)>>>0<320){x=w>>>24;if((x|0)==0){break}y=u+16|0;if((e[y>>1]|0|0)>(j|0)){break}b[y>>1]=k;b[t+16>>1]=c[l+(x<<2)>>2]&65535}}while(0);w=c[m+(s<<2)>>2]|0;do{if((r+15|0)>>>0<320){x=w&255;if((x|0)==0){break}y=u+30|0;if((e[y>>1]|0|0)>(j|0)){break}b[y>>1]=k;b[t+30>>1]=c[l+(x<<2)>>2]&65535}}while(0);do{if((r+14|0)>>>0<320){x=w>>>8&255;if((x|0)==0){break}y=u+28|0;if((e[y>>1]|0|0)>(j|0)){break}b[y>>1]=k;b[t+28>>1]=c[l+(x<<2)>>2]&65535}}while(0);do{if((r+13|0)>>>0<320){x=w>>>16&255;if((x|0)==0){break}y=u+26|0;if((e[y>>1]|0|0)>(j|0)){break}b[y>>1]=k;b[t+26>>1]=c[l+(x<<2)>>2]&65535}}while(0);if((r+12|0)>>>0>=320){break}x=w>>>24;if((x|0)==0){break}y=u+24|0;if((e[y>>1]|0|0)>(j|0)){break}b[y>>1]=k;b[t+24>>1]=c[l+(x<<2)>>2]&65535}}while(0);v=t+32|0;x=u+32|0;y=s-4|0;if((y|0)<=-1){z=n;A=o;B=p;C=v;D=x;break L14023}q=s;r=r+16|0;s=y;t=v;u=x}}else{z=n;A=o;B=p;C=n;D=o}}while(0);n=z+640|0;o=A+640|0;p=B+1|0;m=m+(i<<2)|0;}while((p|0)<(a|0));c[2443766]=m;c[2409608]=C;c[2406666]=D;c[2420368]=n;c[2415140]=o;c[3528514]=p;return}function auU(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=c[2409614]|0;c[3528514]=d;if((d|0)<=0){return}e=c[2443766]|0;f=c[2438140]|0;g=c[2438138]|0;h=c[2409618]|0;i=(h|0)>0;j=c[2432830]|0;k=c[2432832]|0;l=c[2438094]|0;m=c[2420368]|0;n=d;d=c[2438134]|0;do{o=ag(f,d>>16)|0;if(i){p=h;q=g;r=m;while(1){s=a[e+((q>>16)+o)|0]|0;if(s<<24>>24!=0){b[r>>1]=c[l+((s&255)<<2)>>2]&65535}s=r+2|0;t=p-65536|0;if((t|0)>0){p=t;q=k+q|0;r=s}else{u=m;v=n;w=d;x=s;break}}}else{u=m;v=n;w=d;x=m}m=u+640|0;n=v-65536|0;d=j+w|0;}while((n|0)>0);c[2409608]=x;c[2420368]=m;c[3528514]=n;c[2438134]=d;return}function auV(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;d=c[2409614]|0;c[3528514]=d;if((d|0)<=0){return}f=c[2443766]|0;g=c[2438140]|0;h=c[2438138]|0;i=c[2409618]|0;j=(i|0)>0;k=c[2432830]|0;l=c[2432832]|0;m=c[2415166]|0;n=c[2438094]|0;o=c[2420368]|0;p=c[2415140]|0;q=d;d=c[2438134]|0;do{r=ag(g,d>>16)|0;if(j){s=i;t=h;u=o;v=p;while(1){w=a[f+((t>>16)+r)|0]|0;do{if(w<<24>>24==0){x=u;y=v}else{if((e[v>>1]|0|0)>(m|0)){x=u;y=v;break}b[u>>1]=c[n+((w&255)<<2)>>2]&65535;x=u;y=v}}while(0);w=x+2|0;z=y+2|0;A=s-65536|0;if((A|0)>0){s=A;t=l+t|0;u=w;v=z}else{B=o;C=p;D=q;E=d;F=w;G=z;break}}}else{B=o;C=p;D=q;E=d;F=o;G=p}o=B+640|0;p=C+640|0;q=D-65536|0;d=k+E|0;}while((q|0)>0);c[2409608]=F;c[2406666]=G;c[2420368]=o;c[2415140]=p;c[3528514]=q;c[2438134]=d;return}function auW(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;e=c[2409614]|0;c[3528514]=e;if((e|0)<=0){return}f=c[2443766]|0;g=c[2438140]|0;h=c[2438138]|0;i=c[2409618]|0;j=(i|0)>0;k=c[2432830]|0;l=c[2432832]|0;m=c[2415166]&65535;n=c[2438094]|0;o=c[2420368]|0;p=c[2415140]|0;q=e;e=c[2438134]|0;do{r=ag(g,e>>16)|0;if(j){s=i;t=h;u=o;v=p;while(1){w=f+((t>>16)+r)|0;if((a[w]|0)!=0){b[v>>1]=m;b[u>>1]=c[n+(d[w]<<2)>>2]&65535}w=u+2|0;x=v+2|0;y=s-65536|0;if((y|0)>0){s=y;t=l+t|0;u=w;v=x}else{z=o;A=p;B=q;C=e;D=w;E=x;break}}}else{z=o;A=p;B=q;C=e;D=o;E=p}o=z+640|0;p=A+640|0;q=B-65536|0;e=k+C|0;}while((q|0)>0);c[2409608]=D;c[2406666]=E;c[2420368]=o;c[2415140]=p;c[3528514]=q;c[2438134]=e;return}function auX(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;f=c[2409614]|0;c[3528514]=f;if((f|0)<=0){return}g=c[2443766]|0;h=c[2438140]|0;i=c[2438138]|0;j=c[2409618]|0;k=(j|0)>0;l=c[2432830]|0;m=c[2432832]|0;n=c[2415166]|0;o=n&65535;p=c[2438094]|0;q=c[2420368]|0;r=c[2415140]|0;s=f;f=c[2438134]|0;do{t=ag(h,f>>16)|0;if(k){u=j;v=i;w=q;x=r;while(1){y=g+((v>>16)+t)|0;do{if((a[y]|0)==0){z=w;A=x}else{if((e[x>>1]|0)>(n|0)){z=w;A=x;break}b[x>>1]=o;b[w>>1]=c[p+(d[y]<<2)>>2]&65535;z=w;A=x}}while(0);y=z+2|0;B=A+2|0;C=u-65536|0;if((C|0)>0){u=C;v=m+v|0;w=y;x=B}else{D=q;E=r;F=s;G=f;H=y;I=B;break}}}else{D=q;E=r;F=s;G=f;H=q;I=r}q=D+640|0;r=E+640|0;s=F-65536|0;f=l+G|0;}while((s|0)>0);c[2409608]=H;c[2406666]=I;c[2420368]=q;c[2415140]=r;c[3528514]=s;c[2438134]=f;return}function auY(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;d=c[2438138]|0;e=d&-65536;f=c[2438134]|0;g=f&-65536;h=(e|0)==0?-19131852:e;e=c[2409614]|0;c[3528514]=e;if((e|0)<=0){return}i=c[2432830]|0;j=c[2443766]|0;k=c[2438140]|0;l=c[2409618]|0;m=(l|0)>0;n=c[2438094]|0;o=c[2432832]|0;p=(g|0)==0?-19131852:g;g=c[2420368]|0;q=e;e=f;while(1){do{if((p^e)>>>0<65536){r=p;s=q;t=e}else{f=ag(k,e>>16)|0;c[2409608]=g;if(m){u=l;v=d;w=h;x=g}else{r=e;s=q;t=e;break}while(1){do{if((v^w)>>>0>65535){y=a[j+((v>>16)+f)|0]|0;if(y<<24>>24==0){z=v;A=x;break}b[x>>1]=c[n+((y&255)<<2)>>2]&65535;z=v;A=x}else{z=w;A=x}}while(0);B=A+2|0;y=u-65536|0;if((y|0)>0){u=y;v=o+v|0;w=z;x=B}else{break}}c[2409608]=B;r=e;s=q;t=e}}while(0);C=g+640|0;D=s-65536|0;E=i+t|0;if((D|0)>0){p=r;g=C;q=D;e=E}else{break}}c[2420368]=C;c[3528514]=D;c[2438134]=E;return}function auZ(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;d=c[2438138]|0;f=d&-65536;g=c[2438134]|0;h=g&-65536;i=(f|0)==0?-19131852:f;f=c[2409614]|0;c[3528514]=f;if((f|0)<=0){return}j=c[2432830]|0;k=c[2443766]|0;l=c[2438140]|0;m=c[2409618]|0;n=(m|0)>0;o=c[2415166]|0;p=c[2438094]|0;q=c[2432832]|0;r=(h|0)==0?-19131852:h;h=c[2415140]|0;s=c[2420368]|0;t=f;f=g;while(1){do{if((r^f)>>>0<65536){u=r;v=t;w=f}else{g=ag(l,f>>16)|0;c[2406666]=h;c[2409608]=s;if(n){x=m;y=d;z=i;A=s;B=h}else{u=f;v=t;w=f;break}while(1){do{if((y^z)>>>0>65535){C=a[k+((y>>16)+g)|0]|0;if(C<<24>>24==0){D=y;E=A;F=B;break}if((e[B>>1]|0|0)>(o|0)){D=y;E=A;F=B;break}b[A>>1]=c[p+((C&255)<<2)>>2]&65535;D=y;E=A;F=B}else{D=z;E=A;F=B}}while(0);G=E+2|0;H=F+2|0;C=x-65536|0;if((C|0)>0){x=C;y=q+y|0;z=D;A=G;B=H}else{break}}c[2409608]=G;c[2406666]=H;u=f;v=t;w=f}}while(0);I=s+640|0;J=h+640|0;K=v-65536|0;L=j+w|0;if((K|0)>0){r=u;h=J;s=I;t=K;f=L}else{break}}c[2415140]=J;c[2420368]=I;c[3528514]=K;c[2438134]=L;return}function au_(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;e=c[2438138]|0;f=e&-65536;g=c[2438134]|0;h=g&-65536;i=(f|0)==0?-19131852:f;f=c[2409614]|0;c[3528514]=f;if((f|0)<=0){return}j=c[2432830]|0;k=c[2443766]|0;l=c[2438140]|0;m=c[2409618]|0;n=(m|0)>0;o=c[2415166]&65535;p=c[2438094]|0;q=c[2432832]|0;r=(h|0)==0?-19131852:h;h=c[2415140]|0;s=c[2420368]|0;t=f;f=g;while(1){do{if((r^f)>>>0<65536){u=r;v=t;w=f}else{g=ag(l,f>>16)|0;c[2406666]=h;c[2409608]=s;if(n){x=m;y=e;z=i;A=s;B=h}else{u=f;v=t;w=f;break}while(1){do{if((y^z)>>>0>65535){C=k+((y>>16)+g)|0;if((a[C]|0)==0){D=y;E=A;F=B;break}b[B>>1]=o;b[A>>1]=c[p+(d[C]<<2)>>2]&65535;D=y;E=A;F=B}else{D=z;E=A;F=B}}while(0);G=E+2|0;H=F+2|0;C=x-65536|0;if((C|0)>0){x=C;y=q+y|0;z=D;A=G;B=H}else{break}}c[2409608]=G;c[2406666]=H;u=f;v=t;w=f}}while(0);I=s+640|0;J=h+640|0;K=v-65536|0;L=j+w|0;if((K|0)>0){r=u;h=J;s=I;t=K;f=L}else{break}}c[2415140]=J;c[2420368]=I;c[3528514]=K;c[2438134]=L;return}function au$(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;f=c[2438138]|0;g=f&-65536;h=c[2438134]|0;i=h&-65536;j=(g|0)==0?-19131852:g;g=c[2409614]|0;c[3528514]=g;if((g|0)<=0){return}k=c[2432830]|0;l=c[2443766]|0;m=c[2438140]|0;n=c[2409618]|0;o=(n|0)>0;p=c[2415166]|0;q=p&65535;r=c[2438094]|0;s=c[2432832]|0;t=(i|0)==0?-19131852:i;i=c[2415140]|0;u=c[2420368]|0;v=g;g=h;while(1){do{if((t^g)>>>0<65536){w=t;x=v;y=g}else{h=ag(m,g>>16)|0;c[2406666]=i;c[2409608]=u;if(o){z=n;A=f;B=j;C=u;D=i}else{w=g;x=v;y=g;break}while(1){do{if((A^B)>>>0>65535){E=l+((A>>16)+h)|0;if((a[E]|0)==0){F=A;G=C;H=D;break}if((e[D>>1]|0)>(p|0)){F=A;G=C;H=D;break}b[D>>1]=q;b[C>>1]=c[r+(d[E]<<2)>>2]&65535;F=A;G=C;H=D}else{F=B;G=C;H=D}}while(0);I=G+2|0;J=H+2|0;E=z-65536|0;if((E|0)>0){z=E;A=s+A|0;B=F;C=I;D=J}else{break}}c[2409608]=I;c[2406666]=J;w=g;x=v;y=g}}while(0);K=u+640|0;L=i+640|0;M=x-65536|0;N=k+y|0;if((M|0)>0){t=w;i=L;u=K;v=M;g=N}else{break}}c[2415140]=L;c[2420368]=K;c[3528514]=M;c[2438134]=N;return}function au0(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;c[3528514]=0;a=c[2409614]|0;if((a|0)<=0){return}d=c[2409618]|0;e=c[2415168]|0;f=c[2438140]|0;g=c[2438094]|0;h=(e|0)>-1;i=(e|0)>-2;j=(e|0)>-3;k=(e|0)<-3;l=(e|0)>-5;m=(e|0)>-6;n=(e|0)>-7;o=(e|0)<-7;p=(e|0)>-9;q=(e|0)>-10;r=(e|0)>-11;s=(e|0)<-11;t=(e|0)>-13;u=(e|0)>-14;v=(e|0)>-15;w=c[2443766]|0;x=c[2420368]|0;y=0;do{L14316:do{if((d|0)>0){z=0;A=e;B=x;while(1){C=c[w+(z<<2)>>2]|0;do{if(A>>>0<368){D=C&255;if((D|0)!=0){b[B>>1]=c[g+(D<<2)>>2]&65535}D=C>>>8&255;if((D|0)!=0){b[B+2>>1]=c[g+(D<<2)>>2]&65535}D=C>>>16&255;if((D|0)!=0){b[B+4>>1]=c[g+(D<<2)>>2]&65535}D=C>>>24;if((D|0)!=0){b[B+6>>1]=c[g+(D<<2)>>2]&65535}D=c[w+((z|1)<<2)>>2]|0;E=D&255;if((E|0)!=0){b[B+8>>1]=c[g+(E<<2)>>2]&65535}E=D>>>8&255;if((E|0)!=0){b[B+10>>1]=c[g+(E<<2)>>2]&65535}E=D>>>16&255;if((E|0)!=0){b[B+12>>1]=c[g+(E<<2)>>2]&65535}E=D>>>24;if((E|0)!=0){b[B+14>>1]=c[g+(E<<2)>>2]&65535}E=c[w+((z|2)<<2)>>2]|0;D=E&255;if((D|0)!=0){b[B+16>>1]=c[g+(D<<2)>>2]&65535}D=E>>>8&255;if((D|0)!=0){b[B+18>>1]=c[g+(D<<2)>>2]&65535}D=E>>>16&255;if((D|0)!=0){b[B+20>>1]=c[g+(D<<2)>>2]&65535}D=E>>>24;if((D|0)!=0){b[B+22>>1]=c[g+(D<<2)>>2]&65535}D=c[w+((z|3)<<2)>>2]|0;E=D&255;if((E|0)!=0){b[B+24>>1]=c[g+(E<<2)>>2]&65535}E=D>>>8&255;if((E|0)!=0){b[B+26>>1]=c[g+(E<<2)>>2]&65535}E=D>>>16&255;if((E|0)!=0){b[B+28>>1]=c[g+(E<<2)>>2]&65535}E=D>>>24;if((E|0)==0){break}b[B+30>>1]=c[g+(E<<2)>>2]&65535}else{if((A|0)>383){break}do{if(h){E=C&255;if((E|0)==0){break}b[B>>1]=c[g+(E<<2)>>2]&65535}}while(0);if((A|0)>382){break}do{if(i){E=C>>>8&255;if((E|0)==0){break}b[B+2>>1]=c[g+(E<<2)>>2]&65535}}while(0);if((A|0)>381){break}do{if(j){E=C>>>16&255;if((E|0)==0){break}b[B+4>>1]=c[g+(E<<2)>>2]&65535}}while(0);E=C>>>24;if((A|0)>380){break}if(!(k|(E|0)==0)){b[B+6>>1]=c[g+(E<<2)>>2]&65535}E=c[w+((z|1)<<2)>>2]|0;if((A|0)>379){break}do{if(l){D=E&255;if((D|0)==0){break}b[B+8>>1]=c[g+(D<<2)>>2]&65535}}while(0);if((A|0)>378){break}do{if(m){D=E>>>8&255;if((D|0)==0){break}b[B+10>>1]=c[g+(D<<2)>>2]&65535}}while(0);if((A|0)>377){break}do{if(n){D=E>>>16&255;if((D|0)==0){break}b[B+12>>1]=c[g+(D<<2)>>2]&65535}}while(0);D=E>>>24;if((A|0)>376){break}if(!(o|(D|0)==0)){b[B+14>>1]=c[g+(D<<2)>>2]&65535}D=c[w+((z|2)<<2)>>2]|0;if((A|0)>375){break}do{if(p){F=D&255;if((F|0)==0){break}b[B+16>>1]=c[g+(F<<2)>>2]&65535}}while(0);if((A|0)>374){break}do{if(q){E=D>>>8&255;if((E|0)==0){break}b[B+18>>1]=c[g+(E<<2)>>2]&65535}}while(0);if((A|0)>373){break}do{if(r){E=D>>>16&255;if((E|0)==0){break}b[B+20>>1]=c[g+(E<<2)>>2]&65535}}while(0);E=D>>>24;if((A|0)>372){break}if(!(s|(E|0)==0)){b[B+22>>1]=c[g+(E<<2)>>2]&65535}E=c[w+((z|3)<<2)>>2]|0;if((A|0)>371){break}do{if(t){F=E&255;if((F|0)==0){break}b[B+24>>1]=c[g+(F<<2)>>2]&65535}}while(0);if((A|0)>370){break}do{if(u){D=E>>>8&255;if((D|0)==0){break}b[B+26>>1]=c[g+(D<<2)>>2]&65535}}while(0);if((A|0)>369){break}do{if(v){D=E>>>16&255;if((D|0)==0){break}b[B+28>>1]=c[g+(D<<2)>>2]&65535}}while(0);if(!((A|0)<369&(e|0)>-16)){break}D=E>>>24;if((D|0)==0){break}b[B+30>>1]=c[g+(D<<2)>>2]&65535}}while(0);C=z+4|0;D=B+32|0;if((C|0)>=(d|0)){G=x;H=y;I=D;break L14316}z=C;A=A+16|0;B=D}}else{G=x;H=y;I=x}}while(0);x=G+768|0;y=H+1|0;w=w+(f<<2)|0;}while((y|0)<(a|0));c[2443766]=w;c[2409608]=I;c[2420368]=x;c[3528514]=y;return}function au1(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;c[3528514]=0;a=c[2409614]|0;if((a|0)<=0){return}d=c[2409618]|0;f=c[2415168]|0;g=c[2438140]|0;h=c[2415166]|0;i=c[2438094]|0;j=(f|0)>-1;k=(f|0)>-2;l=(f|0)>-3;m=(f|0)<-3;n=(f|0)>-5;o=(f|0)>-6;p=(f|0)>-7;q=(f|0)<-7;r=(f|0)>-9;s=(f|0)>-10;t=(f|0)>-11;u=(f|0)<-11;v=(f|0)>-13;w=(f|0)>-14;x=(f|0)>-15;y=c[2443766]|0;z=c[2420368]|0;A=c[2415140]|0;B=0;do{L14453:do{if((d|0)>0){C=0;D=f;E=A;F=z;while(1){G=c[y+(C<<2)>>2]|0;do{if(D>>>0<368){H=G&255;do{if((H|0)!=0){if((e[E>>1]|0|0)>(h|0)){break}b[F>>1]=c[i+(H<<2)>>2]&65535}}while(0);H=G>>>8&255;do{if((H|0)!=0){if((e[E+2>>1]|0|0)>(h|0)){break}b[F+2>>1]=c[i+(H<<2)>>2]&65535}}while(0);H=G>>>16&255;do{if((H|0)!=0){if((e[E+4>>1]|0|0)>(h|0)){break}b[F+4>>1]=c[i+(H<<2)>>2]&65535}}while(0);H=G>>>24;do{if((H|0)!=0){if((e[E+6>>1]|0|0)>(h|0)){break}b[F+6>>1]=c[i+(H<<2)>>2]&65535}}while(0);H=c[y+((C|1)<<2)>>2]|0;I=H&255;do{if((I|0)!=0){if((e[E+8>>1]|0|0)>(h|0)){break}b[F+8>>1]=c[i+(I<<2)>>2]&65535}}while(0);I=H>>>8&255;do{if((I|0)!=0){if((e[E+10>>1]|0|0)>(h|0)){break}b[F+10>>1]=c[i+(I<<2)>>2]&65535}}while(0);I=H>>>16&255;do{if((I|0)!=0){if((e[E+12>>1]|0|0)>(h|0)){break}b[F+12>>1]=c[i+(I<<2)>>2]&65535}}while(0);I=H>>>24;do{if((I|0)!=0){if((e[E+14>>1]|0|0)>(h|0)){break}b[F+14>>1]=c[i+(I<<2)>>2]&65535}}while(0);I=c[y+((C|2)<<2)>>2]|0;H=I&255;do{if((H|0)!=0){if((e[E+16>>1]|0|0)>(h|0)){break}b[F+16>>1]=c[i+(H<<2)>>2]&65535}}while(0);H=I>>>8&255;do{if((H|0)!=0){if((e[E+18>>1]|0|0)>(h|0)){break}b[F+18>>1]=c[i+(H<<2)>>2]&65535}}while(0);H=I>>>16&255;do{if((H|0)!=0){if((e[E+20>>1]|0|0)>(h|0)){break}b[F+20>>1]=c[i+(H<<2)>>2]&65535}}while(0);H=I>>>24;do{if((H|0)!=0){if((e[E+22>>1]|0|0)>(h|0)){break}b[F+22>>1]=c[i+(H<<2)>>2]&65535}}while(0);H=c[y+((C|3)<<2)>>2]|0;I=H&255;do{if((I|0)!=0){if((e[E+24>>1]|0|0)>(h|0)){break}b[F+24>>1]=c[i+(I<<2)>>2]&65535}}while(0);I=H>>>8&255;do{if((I|0)!=0){if((e[E+26>>1]|0|0)>(h|0)){break}b[F+26>>1]=c[i+(I<<2)>>2]&65535}}while(0);I=H>>>16&255;do{if((I|0)!=0){if((e[E+28>>1]|0|0)>(h|0)){break}b[F+28>>1]=c[i+(I<<2)>>2]&65535}}while(0);I=H>>>24;if((I|0)==0){break}if((e[E+30>>1]|0|0)>(h|0)){break}b[F+30>>1]=c[i+(I<<2)>>2]&65535}else{if((D|0)>383){break}do{if(j){I=G&255;if((I|0)==0){break}if((e[E>>1]|0|0)>(h|0)){break}b[F>>1]=c[i+(I<<2)>>2]&65535}}while(0);if((D|0)>382){break}do{if(k){H=G>>>8&255;if((H|0)==0){break}if((e[E+2>>1]|0|0)>(h|0)){break}b[F+2>>1]=c[i+(H<<2)>>2]&65535}}while(0);if((D|0)>381){break}do{if(l){H=G>>>16&255;if((H|0)==0){break}if((e[E+4>>1]|0|0)>(h|0)){break}b[F+4>>1]=c[i+(H<<2)>>2]&65535}}while(0);H=G>>>24;if((D|0)>380){break}do{if(!(m|(H|0)==0)){if((e[E+6>>1]|0|0)>(h|0)){break}b[F+6>>1]=c[i+(H<<2)>>2]&65535}}while(0);H=c[y+((C|1)<<2)>>2]|0;if((D|0)>379){break}do{if(n){I=H&255;if((I|0)==0){break}if((e[E+8>>1]|0|0)>(h|0)){break}b[F+8>>1]=c[i+(I<<2)>>2]&65535}}while(0);if((D|0)>378){break}do{if(o){I=H>>>8&255;if((I|0)==0){break}if((e[E+10>>1]|0|0)>(h|0)){break}b[F+10>>1]=c[i+(I<<2)>>2]&65535}}while(0);if((D|0)>377){break}do{if(p){I=H>>>16&255;if((I|0)==0){break}if((e[E+12>>1]|0|0)>(h|0)){break}b[F+12>>1]=c[i+(I<<2)>>2]&65535}}while(0);I=H>>>24;if((D|0)>376){break}do{if(!(q|(I|0)==0)){if((e[E+14>>1]|0|0)>(h|0)){break}b[F+14>>1]=c[i+(I<<2)>>2]&65535}}while(0);I=c[y+((C|2)<<2)>>2]|0;if((D|0)>375){break}do{if(r){H=I&255;if((H|0)==0){break}if((e[E+16>>1]|0|0)>(h|0)){break}b[F+16>>1]=c[i+(H<<2)>>2]&65535}}while(0);if((D|0)>374){break}do{if(s){H=I>>>8&255;if((H|0)==0){break}if((e[E+18>>1]|0|0)>(h|0)){break}b[F+18>>1]=c[i+(H<<2)>>2]&65535}}while(0);if((D|0)>373){break}do{if(t){H=I>>>16&255;if((H|0)==0){break}if((e[E+20>>1]|0|0)>(h|0)){break}b[F+20>>1]=c[i+(H<<2)>>2]&65535}}while(0);H=I>>>24;if((D|0)>372){break}do{if(!(u|(H|0)==0)){if((e[E+22>>1]|0|0)>(h|0)){break}b[F+22>>1]=c[i+(H<<2)>>2]&65535}}while(0);H=c[y+((C|3)<<2)>>2]|0;if((D|0)>371){break}do{if(v){I=H&255;if((I|0)==0){break}if((e[E+24>>1]|0|0)>(h|0)){break}b[F+24>>1]=c[i+(I<<2)>>2]&65535}}while(0);if((D|0)>370){break}do{if(w){I=H>>>8&255;if((I|0)==0){break}if((e[E+26>>1]|0|0)>(h|0)){break}b[F+26>>1]=c[i+(I<<2)>>2]&65535}}while(0);if((D|0)>369){break}do{if(x){I=H>>>16&255;if((I|0)==0){break}if((e[E+28>>1]|0|0)>(h|0)){break}b[F+28>>1]=c[i+(I<<2)>>2]&65535}}while(0);if(!((D|0)<369&(f|0)>-16)){break}I=H>>>24;if((I|0)==0){break}if((e[E+30>>1]|0|0)>(h|0)){break}b[F+30>>1]=c[i+(I<<2)>>2]&65535}}while(0);G=C+4|0;I=F+32|0;J=E+32|0;if((G|0)>=(d|0)){K=z;L=A;M=B;N=J;O=I;break L14453}C=G;D=D+16|0;E=J;F=I}}else{K=z;L=A;M=B;N=A;O=z}}while(0);z=K+768|0;A=L+768|0;B=M+1|0;y=y+(g<<2)|0;}while((B|0)<(a|0));c[2443766]=y;c[2406666]=N;c[2409608]=O;c[2420368]=z;c[2415140]=A;c[3528514]=B;return}function au2(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;c[3528514]=0;a=c[2409614]|0;if((a|0)<=0){return}d=c[2409618]|0;e=c[2415168]|0;f=c[2438140]|0;g=c[2415166]&65535;h=c[2438094]|0;i=(e|0)>-1;j=(e|0)>-2;k=(e|0)>-3;l=(e|0)<-3;m=(e|0)>-5;n=(e|0)>-6;o=(e|0)>-7;p=(e|0)<-7;q=(e|0)>-9;r=(e|0)>-10;s=(e|0)>-11;t=(e|0)<-11;u=(e|0)>-13;v=(e|0)>-14;w=(e|0)>-15;x=c[2443766]|0;y=c[2420368]|0;z=c[2415140]|0;A=0;do{L14622:do{if((d|0)>0){B=0;C=e;D=y;E=z;while(1){F=c[x+(B<<2)>>2]|0;do{if(C>>>0<368){G=F&255;if((G|0)!=0){b[E>>1]=g;b[D>>1]=c[h+(G<<2)>>2]&65535}G=F>>>8&255;if((G|0)!=0){b[E+2>>1]=g;b[D+2>>1]=c[h+(G<<2)>>2]&65535}G=F>>>16&255;if((G|0)!=0){b[E+4>>1]=g;b[D+4>>1]=c[h+(G<<2)>>2]&65535}G=F>>>24;if((G|0)!=0){b[E+6>>1]=g;b[D+6>>1]=c[h+(G<<2)>>2]&65535}G=c[x+((B|1)<<2)>>2]|0;H=G&255;if((H|0)!=0){b[E+8>>1]=g;b[D+8>>1]=c[h+(H<<2)>>2]&65535}H=G>>>8&255;if((H|0)!=0){b[E+10>>1]=g;b[D+10>>1]=c[h+(H<<2)>>2]&65535}H=G>>>16&255;if((H|0)!=0){b[E+12>>1]=g;b[D+12>>1]=c[h+(H<<2)>>2]&65535}H=G>>>24;if((H|0)!=0){b[E+14>>1]=g;b[D+14>>1]=c[h+(H<<2)>>2]&65535}H=c[x+((B|2)<<2)>>2]|0;G=H&255;if((G|0)!=0){b[E+16>>1]=g;b[D+16>>1]=c[h+(G<<2)>>2]&65535}G=H>>>8&255;if((G|0)!=0){b[E+18>>1]=g;b[D+18>>1]=c[h+(G<<2)>>2]&65535}G=H>>>16&255;if((G|0)!=0){b[E+20>>1]=g;b[D+20>>1]=c[h+(G<<2)>>2]&65535}G=H>>>24;if((G|0)!=0){b[E+22>>1]=g;b[D+22>>1]=c[h+(G<<2)>>2]&65535}G=c[x+((B|3)<<2)>>2]|0;H=G&255;if((H|0)!=0){b[E+24>>1]=g;b[D+24>>1]=c[h+(H<<2)>>2]&65535}H=G>>>8&255;if((H|0)!=0){b[E+26>>1]=g;b[D+26>>1]=c[h+(H<<2)>>2]&65535}H=G>>>16&255;if((H|0)!=0){b[E+28>>1]=g;b[D+28>>1]=c[h+(H<<2)>>2]&65535}H=G>>>24;if((H|0)==0){break}b[E+30>>1]=g;b[D+30>>1]=c[h+(H<<2)>>2]&65535}else{if((C|0)>383){break}do{if(i){H=F&255;if((H|0)==0){break}b[E>>1]=g;b[D>>1]=c[h+(H<<2)>>2]&65535}}while(0);if((C|0)>382){break}do{if(j){H=F>>>8&255;if((H|0)==0){break}b[E+2>>1]=g;b[D+2>>1]=c[h+(H<<2)>>2]&65535}}while(0);if((C|0)>381){break}do{if(k){H=F>>>16&255;if((H|0)==0){break}b[E+4>>1]=g;b[D+4>>1]=c[h+(H<<2)>>2]&65535}}while(0);H=F>>>24;if((C|0)>380){break}if(!(l|(H|0)==0)){b[E+6>>1]=g;b[D+6>>1]=c[h+(H<<2)>>2]&65535}H=c[x+((B|1)<<2)>>2]|0;if((C|0)>379){break}do{if(m){G=H&255;if((G|0)==0){break}b[E+8>>1]=g;b[D+8>>1]=c[h+(G<<2)>>2]&65535}}while(0);if((C|0)>378){break}do{if(n){G=H>>>8&255;if((G|0)==0){break}b[E+10>>1]=g;b[D+10>>1]=c[h+(G<<2)>>2]&65535}}while(0);if((C|0)>377){break}do{if(o){G=H>>>16&255;if((G|0)==0){break}b[E+12>>1]=g;b[D+12>>1]=c[h+(G<<2)>>2]&65535}}while(0);G=H>>>24;if((C|0)>376){break}if(!(p|(G|0)==0)){b[E+14>>1]=g;b[D+14>>1]=c[h+(G<<2)>>2]&65535}G=c[x+((B|2)<<2)>>2]|0;if((C|0)>375){break}do{if(q){I=G&255;if((I|0)==0){break}b[E+16>>1]=g;b[D+16>>1]=c[h+(I<<2)>>2]&65535}}while(0);if((C|0)>374){break}do{if(r){H=G>>>8&255;if((H|0)==0){break}b[E+18>>1]=g;b[D+18>>1]=c[h+(H<<2)>>2]&65535}}while(0);if((C|0)>373){break}do{if(s){H=G>>>16&255;if((H|0)==0){break}b[E+20>>1]=g;b[D+20>>1]=c[h+(H<<2)>>2]&65535}}while(0);H=G>>>24;if((C|0)>372){break}if(!(t|(H|0)==0)){b[E+22>>1]=g;b[D+22>>1]=c[h+(H<<2)>>2]&65535}H=c[x+((B|3)<<2)>>2]|0;if((C|0)>371){break}do{if(u){I=H&255;if((I|0)==0){break}b[E+24>>1]=g;b[D+24>>1]=c[h+(I<<2)>>2]&65535}}while(0);if((C|0)>370){break}do{if(v){G=H>>>8&255;if((G|0)==0){break}b[E+26>>1]=g;b[D+26>>1]=c[h+(G<<2)>>2]&65535}}while(0);if((C|0)>369){break}do{if(w){G=H>>>16&255;if((G|0)==0){break}b[E+28>>1]=g;b[D+28>>1]=c[h+(G<<2)>>2]&65535}}while(0);if(!((C|0)<369&(e|0)>-16)){break}G=H>>>24;if((G|0)==0){break}b[E+30>>1]=g;b[D+30>>1]=c[h+(G<<2)>>2]&65535}}while(0);F=B+4|0;G=D+32|0;I=E+32|0;if((F|0)>=(d|0)){J=y;K=z;L=A;M=G;N=I;break L14622}B=F;C=C+16|0;D=G;E=I}}else{J=y;K=z;L=A;M=y;N=z}}while(0);y=J+768|0;z=K+768|0;A=L+1|0;x=x+(f<<2)|0;}while((A|0)<(a|0));c[2443766]=x;c[2409608]=M;c[2406666]=N;c[2420368]=y;c[2415140]=z;c[3528514]=A;return}function au3(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;c[3528514]=0;a=c[2409614]|0;if((a|0)<=0){return}d=c[2409618]|0;f=c[2415168]|0;g=c[2438140]|0;h=c[2415166]|0;i=h&65535;j=c[2438094]|0;k=(f|0)>-1;l=(f|0)>-2;m=(f|0)>-3;n=(f|0)<-3;o=(f|0)>-5;p=(f|0)>-6;q=(f|0)>-7;r=(f|0)<-7;s=(f|0)>-9;t=(f|0)>-10;u=(f|0)>-11;v=(f|0)<-11;w=(f|0)>-13;x=(f|0)>-14;y=(f|0)>-15;z=c[2443766]|0;A=c[2420368]|0;B=c[2415140]|0;C=0;do{L14759:do{if((d|0)>0){D=0;E=f;F=A;G=B;while(1){H=c[z+(D<<2)>>2]|0;do{if(E>>>0<368){I=H&255;do{if((I|0)!=0){if((e[G>>1]|0|0)>(h|0)){break}b[G>>1]=i;b[F>>1]=c[j+(I<<2)>>2]&65535}}while(0);I=H>>>8&255;do{if((I|0)!=0){J=G+2|0;if((e[J>>1]|0|0)>(h|0)){break}b[J>>1]=i;b[F+2>>1]=c[j+(I<<2)>>2]&65535}}while(0);I=H>>>16&255;do{if((I|0)!=0){J=G+4|0;if((e[J>>1]|0|0)>(h|0)){break}b[J>>1]=i;b[F+4>>1]=c[j+(I<<2)>>2]&65535}}while(0);I=H>>>24;do{if((I|0)!=0){J=G+6|0;if((e[J>>1]|0|0)>(h|0)){break}b[J>>1]=i;b[F+6>>1]=c[j+(I<<2)>>2]&65535}}while(0);I=c[z+((D|1)<<2)>>2]|0;J=I&255;do{if((J|0)!=0){K=G+8|0;if((e[K>>1]|0|0)>(h|0)){break}b[K>>1]=i;b[F+8>>1]=c[j+(J<<2)>>2]&65535}}while(0);J=I>>>8&255;do{if((J|0)!=0){K=G+10|0;if((e[K>>1]|0|0)>(h|0)){break}b[K>>1]=i;b[F+10>>1]=c[j+(J<<2)>>2]&65535}}while(0);J=I>>>16&255;do{if((J|0)!=0){K=G+12|0;if((e[K>>1]|0|0)>(h|0)){break}b[K>>1]=i;b[F+12>>1]=c[j+(J<<2)>>2]&65535}}while(0);J=I>>>24;do{if((J|0)!=0){K=G+14|0;if((e[K>>1]|0|0)>(h|0)){break}b[K>>1]=i;b[F+14>>1]=c[j+(J<<2)>>2]&65535}}while(0);J=c[z+((D|2)<<2)>>2]|0;I=J&255;do{if((I|0)!=0){K=G+16|0;if((e[K>>1]|0|0)>(h|0)){break}b[K>>1]=i;b[F+16>>1]=c[j+(I<<2)>>2]&65535}}while(0);I=J>>>8&255;do{if((I|0)!=0){K=G+18|0;if((e[K>>1]|0|0)>(h|0)){break}b[K>>1]=i;b[F+18>>1]=c[j+(I<<2)>>2]&65535}}while(0);I=J>>>16&255;do{if((I|0)!=0){K=G+20|0;if((e[K>>1]|0|0)>(h|0)){break}b[K>>1]=i;b[F+20>>1]=c[j+(I<<2)>>2]&65535}}while(0);I=J>>>24;do{if((I|0)!=0){K=G+22|0;if((e[K>>1]|0|0)>(h|0)){break}b[K>>1]=i;b[F+22>>1]=c[j+(I<<2)>>2]&65535}}while(0);I=c[z+((D|3)<<2)>>2]|0;J=I&255;do{if((J|0)!=0){K=G+24|0;if((e[K>>1]|0|0)>(h|0)){break}b[K>>1]=i;b[F+24>>1]=c[j+(J<<2)>>2]&65535}}while(0);J=I>>>8&255;do{if((J|0)!=0){K=G+26|0;if((e[K>>1]|0|0)>(h|0)){break}b[K>>1]=i;b[F+26>>1]=c[j+(J<<2)>>2]&65535}}while(0);J=I>>>16&255;do{if((J|0)!=0){K=G+28|0;if((e[K>>1]|0|0)>(h|0)){break}b[K>>1]=i;b[F+28>>1]=c[j+(J<<2)>>2]&65535}}while(0);J=I>>>24;if((J|0)==0){break}K=G+30|0;if((e[K>>1]|0|0)>(h|0)){break}b[K>>1]=i;b[F+30>>1]=c[j+(J<<2)>>2]&65535}else{if((E|0)>383){break}do{if(k){J=H&255;if((J|0)==0){break}if((e[G>>1]|0|0)>(h|0)){break}b[G>>1]=i;b[F>>1]=c[j+(J<<2)>>2]&65535}}while(0);if((E|0)>382){break}do{if(l){I=H>>>8&255;if((I|0)==0){break}J=G+2|0;if((e[J>>1]|0|0)>(h|0)){break}b[J>>1]=i;b[F+2>>1]=c[j+(I<<2)>>2]&65535}}while(0);if((E|0)>381){break}do{if(m){I=H>>>16&255;if((I|0)==0){break}J=G+4|0;if((e[J>>1]|0|0)>(h|0)){break}b[J>>1]=i;b[F+4>>1]=c[j+(I<<2)>>2]&65535}}while(0);I=H>>>24;if((E|0)>380){break}do{if(!(n|(I|0)==0)){J=G+6|0;if((e[J>>1]|0|0)>(h|0)){break}b[J>>1]=i;b[F+6>>1]=c[j+(I<<2)>>2]&65535}}while(0);I=c[z+((D|1)<<2)>>2]|0;if((E|0)>379){break}do{if(o){J=I&255;if((J|0)==0){break}K=G+8|0;if((e[K>>1]|0|0)>(h|0)){break}b[K>>1]=i;b[F+8>>1]=c[j+(J<<2)>>2]&65535}}while(0);if((E|0)>378){break}do{if(p){J=I>>>8&255;if((J|0)==0){break}K=G+10|0;if((e[K>>1]|0|0)>(h|0)){break}b[K>>1]=i;b[F+10>>1]=c[j+(J<<2)>>2]&65535}}while(0);if((E|0)>377){break}do{if(q){J=I>>>16&255;if((J|0)==0){break}K=G+12|0;if((e[K>>1]|0|0)>(h|0)){break}b[K>>1]=i;b[F+12>>1]=c[j+(J<<2)>>2]&65535}}while(0);J=I>>>24;if((E|0)>376){break}do{if(!(r|(J|0)==0)){K=G+14|0;if((e[K>>1]|0|0)>(h|0)){break}b[K>>1]=i;b[F+14>>1]=c[j+(J<<2)>>2]&65535}}while(0);J=c[z+((D|2)<<2)>>2]|0;if((E|0)>375){break}do{if(s){I=J&255;if((I|0)==0){break}K=G+16|0;if((e[K>>1]|0|0)>(h|0)){break}b[K>>1]=i;b[F+16>>1]=c[j+(I<<2)>>2]&65535}}while(0);if((E|0)>374){break}do{if(t){I=J>>>8&255;if((I|0)==0){break}K=G+18|0;if((e[K>>1]|0|0)>(h|0)){break}b[K>>1]=i;b[F+18>>1]=c[j+(I<<2)>>2]&65535}}while(0);if((E|0)>373){break}do{if(u){I=J>>>16&255;if((I|0)==0){break}K=G+20|0;if((e[K>>1]|0|0)>(h|0)){break}b[K>>1]=i;b[F+20>>1]=c[j+(I<<2)>>2]&65535}}while(0);I=J>>>24;if((E|0)>372){break}do{if(!(v|(I|0)==0)){K=G+22|0;if((e[K>>1]|0|0)>(h|0)){break}b[K>>1]=i;b[F+22>>1]=c[j+(I<<2)>>2]&65535}}while(0);I=c[z+((D|3)<<2)>>2]|0;if((E|0)>371){break}do{if(w){J=I&255;if((J|0)==0){break}K=G+24|0;if((e[K>>1]|0|0)>(h|0)){break}b[K>>1]=i;b[F+24>>1]=c[j+(J<<2)>>2]&65535}}while(0);if((E|0)>370){break}do{if(x){J=I>>>8&255;if((J|0)==0){break}K=G+26|0;if((e[K>>1]|0|0)>(h|0)){break}b[K>>1]=i;b[F+26>>1]=c[j+(J<<2)>>2]&65535}}while(0);if((E|0)>369){break}do{if(y){J=I>>>16&255;if((J|0)==0){break}K=G+28|0;if((e[K>>1]|0|0)>(h|0)){break}b[K>>1]=i;b[F+28>>1]=c[j+(J<<2)>>2]&65535}}while(0);if(!((E|0)<369&(f|0)>-16)){break}J=I>>>24;if((J|0)==0){break}K=G+30|0;if((e[K>>1]|0|0)>(h|0)){break}b[K>>1]=i;b[F+30>>1]=c[j+(J<<2)>>2]&65535}}while(0);H=D+4|0;J=F+32|0;K=G+32|0;if((H|0)>=(d|0)){L=A;M=B;N=C;O=J;P=K;break L14759}D=H;E=E+16|0;F=J;G=K}}else{L=A;M=B;N=C;O=A;P=B}}while(0);A=L+768|0;B=M+768|0;C=N+1|0;z=z+(g<<2)|0;}while((C|0)<(a|0));c[2443766]=z;c[2409608]=O;c[2406666]=P;c[2420368]=A;c[2415140]=B;c[3528514]=C;return}function au4(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;c[3528514]=0;a=c[2409614]|0;if((a|0)<=0){return}d=c[2415168]|0;e=c[2409618]|0;f=e-4|0;g=(f|0)>-1;h=c[2438140]|0;i=c[2438094]|0;j=c[2443766]|0;k=c[2420368]|0;l=0;do{L14928:do{if(g){m=e;n=d;o=f;p=k;while(1){q=c[j+(m-1<<2)>>2]|0;do{if(n>>>0<368){r=q&255;if((r|0)!=0){b[p+6>>1]=c[i+(r<<2)>>2]&65535}r=q>>>8&255;if((r|0)!=0){b[p+4>>1]=c[i+(r<<2)>>2]&65535}r=q>>>16&255;if((r|0)!=0){b[p+2>>1]=c[i+(r<<2)>>2]&65535}r=q>>>24;if((r|0)!=0){b[p>>1]=c[i+(r<<2)>>2]&65535}r=c[j+(m-2<<2)>>2]|0;s=r&255;if((s|0)!=0){b[p+14>>1]=c[i+(s<<2)>>2]&65535}s=r>>>8&255;if((s|0)!=0){b[p+12>>1]=c[i+(s<<2)>>2]&65535}s=r>>>16&255;if((s|0)!=0){b[p+10>>1]=c[i+(s<<2)>>2]&65535}s=r>>>24;if((s|0)!=0){b[p+8>>1]=c[i+(s<<2)>>2]&65535}s=c[j+(m-3<<2)>>2]|0;r=s&255;if((r|0)!=0){b[p+22>>1]=c[i+(r<<2)>>2]&65535}r=s>>>8&255;if((r|0)!=0){b[p+20>>1]=c[i+(r<<2)>>2]&65535}r=s>>>16&255;if((r|0)!=0){b[p+18>>1]=c[i+(r<<2)>>2]&65535}r=s>>>24;if((r|0)!=0){b[p+16>>1]=c[i+(r<<2)>>2]&65535}r=c[j+(o<<2)>>2]|0;s=r&255;if((s|0)!=0){b[p+30>>1]=c[i+(s<<2)>>2]&65535}s=r>>>8&255;if((s|0)!=0){b[p+28>>1]=c[i+(s<<2)>>2]&65535}s=r>>>16&255;if((s|0)!=0){b[p+26>>1]=c[i+(s<<2)>>2]&65535}s=r>>>24;if((s|0)==0){break}b[p+24>>1]=c[i+(s<<2)>>2]&65535}else{do{if((n+3|0)>>>0<384){s=q&255;if((s|0)==0){break}b[p+6>>1]=c[i+(s<<2)>>2]&65535}}while(0);do{if((n+2|0)>>>0<384){s=q>>>8&255;if((s|0)==0){break}b[p+4>>1]=c[i+(s<<2)>>2]&65535}}while(0);do{if((n+1|0)>>>0<384){s=q>>>16&255;if((s|0)==0){break}b[p+2>>1]=c[i+(s<<2)>>2]&65535}}while(0);do{if(n>>>0<384){s=q>>>24;if((s|0)==0){break}b[p>>1]=c[i+(s<<2)>>2]&65535}}while(0);s=c[j+(m-2<<2)>>2]|0;do{if((n+7|0)>>>0<384){r=s&255;if((r|0)==0){break}b[p+14>>1]=c[i+(r<<2)>>2]&65535}}while(0);do{if((n+6|0)>>>0<384){r=s>>>8&255;if((r|0)==0){break}b[p+12>>1]=c[i+(r<<2)>>2]&65535}}while(0);do{if((n+5|0)>>>0<384){r=s>>>16&255;if((r|0)==0){break}b[p+10>>1]=c[i+(r<<2)>>2]&65535}}while(0);do{if((n+4|0)>>>0<384){r=s>>>24;if((r|0)==0){break}b[p+8>>1]=c[i+(r<<2)>>2]&65535}}while(0);s=c[j+(m-3<<2)>>2]|0;do{if((n+11|0)>>>0<384){r=s&255;if((r|0)==0){break}b[p+22>>1]=c[i+(r<<2)>>2]&65535}}while(0);do{if((n+10|0)>>>0<384){r=s>>>8&255;if((r|0)==0){break}b[p+20>>1]=c[i+(r<<2)>>2]&65535}}while(0);do{if((n+9|0)>>>0<384){r=s>>>16&255;if((r|0)==0){break}b[p+18>>1]=c[i+(r<<2)>>2]&65535}}while(0);do{if((n+8|0)>>>0<384){r=s>>>24;if((r|0)==0){break}b[p+16>>1]=c[i+(r<<2)>>2]&65535}}while(0);s=c[j+(o<<2)>>2]|0;do{if((n+15|0)>>>0<384){r=s&255;if((r|0)==0){break}b[p+30>>1]=c[i+(r<<2)>>2]&65535}}while(0);do{if((n+14|0)>>>0<384){r=s>>>8&255;if((r|0)==0){break}b[p+28>>1]=c[i+(r<<2)>>2]&65535}}while(0);do{if((n+13|0)>>>0<384){r=s>>>16&255;if((r|0)==0){break}b[p+26>>1]=c[i+(r<<2)>>2]&65535}}while(0);if((n+12|0)>>>0>=384){break}r=s>>>24;if((r|0)==0){break}b[p+24>>1]=c[i+(r<<2)>>2]&65535}}while(0);q=p+32|0;r=o-4|0;if((r|0)<=-1){t=k;u=l;v=q;break L14928}m=o;n=n+16|0;o=r;p=q}}else{t=k;u=l;v=k}}while(0);k=t+768|0;l=u+1|0;j=j+(h<<2)|0;}while((l|0)<(a|0));c[2443766]=j;c[2409608]=v;c[2420368]=k;c[3528514]=l;return}function au5(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;c[3528514]=0;a=c[2409614]|0;if((a|0)<=0){return}d=c[2415168]|0;f=c[2409618]|0;g=f-4|0;h=(g|0)>-1;i=c[2438140]|0;j=c[2415166]|0;k=c[2438094]|0;l=c[2443766]|0;m=c[2420368]|0;n=c[2415140]|0;o=0;do{L15053:do{if(h){p=f;q=d;r=g;s=n;t=m;while(1){u=c[l+(p-1<<2)>>2]|0;do{if(q>>>0<368){v=u&255;do{if((v|0)!=0){if((e[s+6>>1]|0|0)>(j|0)){break}b[t+6>>1]=c[k+(v<<2)>>2]&65535}}while(0);v=u>>>8&255;do{if((v|0)!=0){if((e[s+4>>1]|0|0)>(j|0)){break}b[t+4>>1]=c[k+(v<<2)>>2]&65535}}while(0);v=u>>>16&255;do{if((v|0)!=0){if((e[s+2>>1]|0|0)>(j|0)){break}b[t+2>>1]=c[k+(v<<2)>>2]&65535}}while(0);v=u>>>24;do{if((v|0)!=0){if((e[s>>1]|0|0)>(j|0)){break}b[t>>1]=c[k+(v<<2)>>2]&65535}}while(0);v=c[l+(p-2<<2)>>2]|0;w=v&255;do{if((w|0)!=0){if((e[s+14>>1]|0|0)>(j|0)){break}b[t+14>>1]=c[k+(w<<2)>>2]&65535}}while(0);w=v>>>8&255;do{if((w|0)!=0){if((e[s+12>>1]|0|0)>(j|0)){break}b[t+12>>1]=c[k+(w<<2)>>2]&65535}}while(0);w=v>>>16&255;do{if((w|0)!=0){if((e[s+10>>1]|0|0)>(j|0)){break}b[t+10>>1]=c[k+(w<<2)>>2]&65535}}while(0);w=v>>>24;do{if((w|0)!=0){if((e[s+8>>1]|0|0)>(j|0)){break}b[t+8>>1]=c[k+(w<<2)>>2]&65535}}while(0);w=c[l+(p-3<<2)>>2]|0;v=w&255;do{if((v|0)!=0){if((e[s+22>>1]|0|0)>(j|0)){break}b[t+22>>1]=c[k+(v<<2)>>2]&65535}}while(0);v=w>>>8&255;do{if((v|0)!=0){if((e[s+20>>1]|0|0)>(j|0)){break}b[t+20>>1]=c[k+(v<<2)>>2]&65535}}while(0);v=w>>>16&255;do{if((v|0)!=0){if((e[s+18>>1]|0|0)>(j|0)){break}b[t+18>>1]=c[k+(v<<2)>>2]&65535}}while(0);v=w>>>24;do{if((v|0)!=0){if((e[s+16>>1]|0|0)>(j|0)){break}b[t+16>>1]=c[k+(v<<2)>>2]&65535}}while(0);v=c[l+(r<<2)>>2]|0;w=v&255;do{if((w|0)!=0){if((e[s+30>>1]|0|0)>(j|0)){break}b[t+30>>1]=c[k+(w<<2)>>2]&65535}}while(0);w=v>>>8&255;do{if((w|0)!=0){if((e[s+28>>1]|0|0)>(j|0)){break}b[t+28>>1]=c[k+(w<<2)>>2]&65535}}while(0);w=v>>>16&255;do{if((w|0)!=0){if((e[s+26>>1]|0|0)>(j|0)){break}b[t+26>>1]=c[k+(w<<2)>>2]&65535}}while(0);w=v>>>24;if((w|0)==0){break}if((e[s+24>>1]|0|0)>(j|0)){break}b[t+24>>1]=c[k+(w<<2)>>2]&65535}else{do{if((q+3|0)>>>0<384){w=u&255;if((w|0)==0){break}if((e[s+6>>1]|0|0)>(j|0)){break}b[t+6>>1]=c[k+(w<<2)>>2]&65535}}while(0);do{if((q+2|0)>>>0<384){v=u>>>8&255;if((v|0)==0){break}if((e[s+4>>1]|0|0)>(j|0)){break}b[t+4>>1]=c[k+(v<<2)>>2]&65535}}while(0);do{if((q+1|0)>>>0<384){v=u>>>16&255;if((v|0)==0){break}if((e[s+2>>1]|0|0)>(j|0)){break}b[t+2>>1]=c[k+(v<<2)>>2]&65535}}while(0);do{if(q>>>0<384){v=u>>>24;if((v|0)==0){break}if((e[s>>1]|0|0)>(j|0)){break}b[t>>1]=c[k+(v<<2)>>2]&65535}}while(0);v=c[l+(p-2<<2)>>2]|0;do{if((q+7|0)>>>0<384){w=v&255;if((w|0)==0){break}if((e[s+14>>1]|0|0)>(j|0)){break}b[t+14>>1]=c[k+(w<<2)>>2]&65535}}while(0);do{if((q+6|0)>>>0<384){w=v>>>8&255;if((w|0)==0){break}if((e[s+12>>1]|0|0)>(j|0)){break}b[t+12>>1]=c[k+(w<<2)>>2]&65535}}while(0);do{if((q+5|0)>>>0<384){w=v>>>16&255;if((w|0)==0){break}if((e[s+10>>1]|0|0)>(j|0)){break}b[t+10>>1]=c[k+(w<<2)>>2]&65535}}while(0);do{if((q+4|0)>>>0<384){w=v>>>24;if((w|0)==0){break}if((e[s+8>>1]|0|0)>(j|0)){break}b[t+8>>1]=c[k+(w<<2)>>2]&65535}}while(0);v=c[l+(p-3<<2)>>2]|0;do{if((q+11|0)>>>0<384){w=v&255;if((w|0)==0){break}if((e[s+22>>1]|0|0)>(j|0)){break}b[t+22>>1]=c[k+(w<<2)>>2]&65535}}while(0);do{if((q+10|0)>>>0<384){w=v>>>8&255;if((w|0)==0){break}if((e[s+20>>1]|0|0)>(j|0)){break}b[t+20>>1]=c[k+(w<<2)>>2]&65535}}while(0);do{if((q+9|0)>>>0<384){w=v>>>16&255;if((w|0)==0){break}if((e[s+18>>1]|0|0)>(j|0)){break}b[t+18>>1]=c[k+(w<<2)>>2]&65535}}while(0);do{if((q+8|0)>>>0<384){w=v>>>24;if((w|0)==0){break}if((e[s+16>>1]|0|0)>(j|0)){break}b[t+16>>1]=c[k+(w<<2)>>2]&65535}}while(0);v=c[l+(r<<2)>>2]|0;do{if((q+15|0)>>>0<384){w=v&255;if((w|0)==0){break}if((e[s+30>>1]|0|0)>(j|0)){break}b[t+30>>1]=c[k+(w<<2)>>2]&65535}}while(0);do{if((q+14|0)>>>0<384){w=v>>>8&255;if((w|0)==0){break}if((e[s+28>>1]|0|0)>(j|0)){break}b[t+28>>1]=c[k+(w<<2)>>2]&65535}}while(0);do{if((q+13|0)>>>0<384){w=v>>>16&255;if((w|0)==0){break}if((e[s+26>>1]|0|0)>(j|0)){break}b[t+26>>1]=c[k+(w<<2)>>2]&65535}}while(0);if((q+12|0)>>>0>=384){break}w=v>>>24;if((w|0)==0){break}if((e[s+24>>1]|0|0)>(j|0)){break}b[t+24>>1]=c[k+(w<<2)>>2]&65535}}while(0);u=t+32|0;w=s+32|0;x=r-4|0;if((x|0)<=-1){y=m;z=n;A=o;B=w;C=u;break L15053}p=r;q=q+16|0;r=x;s=w;t=u}}else{y=m;z=n;A=o;B=n;C=m}}while(0);m=y+768|0;n=z+768|0;o=A+1|0;l=l+(i<<2)|0;}while((o|0)<(a|0));c[2443766]=l;c[2406666]=B;c[2409608]=C;c[2420368]=m;c[2415140]=n;c[3528514]=o;return}function au6(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;c[3528514]=0;a=c[2409614]|0;if((a|0)<=0){return}d=c[2415168]|0;e=c[2409618]|0;f=e-4|0;g=(f|0)>-1;h=c[2438140]|0;i=c[2415166]&65535;j=c[2438094]|0;k=c[2443766]|0;l=c[2420368]|0;m=c[2415140]|0;n=0;do{L15210:do{if(g){o=e;p=d;q=f;r=l;s=m;while(1){t=c[k+(o-1<<2)>>2]|0;do{if(p>>>0<368){u=t&255;if((u|0)!=0){b[s+6>>1]=i;b[r+6>>1]=c[j+(u<<2)>>2]&65535}u=t>>>8&255;if((u|0)!=0){b[s+4>>1]=i;b[r+4>>1]=c[j+(u<<2)>>2]&65535}u=t>>>16&255;if((u|0)!=0){b[s+2>>1]=i;b[r+2>>1]=c[j+(u<<2)>>2]&65535}u=t>>>24;if((u|0)!=0){b[s>>1]=i;b[r>>1]=c[j+(u<<2)>>2]&65535}u=c[k+(o-2<<2)>>2]|0;v=u&255;if((v|0)!=0){b[s+14>>1]=i;b[r+14>>1]=c[j+(v<<2)>>2]&65535}v=u>>>8&255;if((v|0)!=0){b[s+12>>1]=i;b[r+12>>1]=c[j+(v<<2)>>2]&65535}v=u>>>16&255;if((v|0)!=0){b[s+10>>1]=i;b[r+10>>1]=c[j+(v<<2)>>2]&65535}v=u>>>24;if((v|0)!=0){b[s+8>>1]=i;b[r+8>>1]=c[j+(v<<2)>>2]&65535}v=c[k+(o-3<<2)>>2]|0;u=v&255;if((u|0)!=0){b[s+22>>1]=i;b[r+22>>1]=c[j+(u<<2)>>2]&65535}u=v>>>8&255;if((u|0)!=0){b[s+20>>1]=i;b[r+20>>1]=c[j+(u<<2)>>2]&65535}u=v>>>16&255;if((u|0)!=0){b[s+18>>1]=i;b[r+18>>1]=c[j+(u<<2)>>2]&65535}u=v>>>24;if((u|0)!=0){b[s+16>>1]=i;b[r+16>>1]=c[j+(u<<2)>>2]&65535}u=c[k+(q<<2)>>2]|0;v=u&255;if((v|0)!=0){b[s+30>>1]=i;b[r+30>>1]=c[j+(v<<2)>>2]&65535}v=u>>>8&255;if((v|0)!=0){b[s+28>>1]=i;b[r+28>>1]=c[j+(v<<2)>>2]&65535}v=u>>>16&255;if((v|0)!=0){b[s+26>>1]=i;b[r+26>>1]=c[j+(v<<2)>>2]&65535}v=u>>>24;if((v|0)==0){break}b[s+24>>1]=i;b[r+24>>1]=c[j+(v<<2)>>2]&65535}else{do{if((p+3|0)>>>0<384){v=t&255;if((v|0)==0){break}b[s+6>>1]=i;b[r+6>>1]=c[j+(v<<2)>>2]&65535}}while(0);do{if((p+2|0)>>>0<384){v=t>>>8&255;if((v|0)==0){break}b[s+4>>1]=i;b[r+4>>1]=c[j+(v<<2)>>2]&65535}}while(0);do{if((p+1|0)>>>0<384){v=t>>>16&255;if((v|0)==0){break}b[s+2>>1]=i;b[r+2>>1]=c[j+(v<<2)>>2]&65535}}while(0);do{if(p>>>0<384){v=t>>>24;if((v|0)==0){break}b[s>>1]=i;b[r>>1]=c[j+(v<<2)>>2]&65535}}while(0);v=c[k+(o-2<<2)>>2]|0;do{if((p+7|0)>>>0<384){u=v&255;if((u|0)==0){break}b[s+14>>1]=i;b[r+14>>1]=c[j+(u<<2)>>2]&65535}}while(0);do{if((p+6|0)>>>0<384){u=v>>>8&255;if((u|0)==0){break}b[s+12>>1]=i;b[r+12>>1]=c[j+(u<<2)>>2]&65535}}while(0);do{if((p+5|0)>>>0<384){u=v>>>16&255;if((u|0)==0){break}b[s+10>>1]=i;b[r+10>>1]=c[j+(u<<2)>>2]&65535}}while(0);do{if((p+4|0)>>>0<384){u=v>>>24;if((u|0)==0){break}b[s+8>>1]=i;b[r+8>>1]=c[j+(u<<2)>>2]&65535}}while(0);v=c[k+(o-3<<2)>>2]|0;do{if((p+11|0)>>>0<384){u=v&255;if((u|0)==0){break}b[s+22>>1]=i;b[r+22>>1]=c[j+(u<<2)>>2]&65535}}while(0);do{if((p+10|0)>>>0<384){u=v>>>8&255;if((u|0)==0){break}b[s+20>>1]=i;b[r+20>>1]=c[j+(u<<2)>>2]&65535}}while(0);do{if((p+9|0)>>>0<384){u=v>>>16&255;if((u|0)==0){break}b[s+18>>1]=i;b[r+18>>1]=c[j+(u<<2)>>2]&65535}}while(0);do{if((p+8|0)>>>0<384){u=v>>>24;if((u|0)==0){break}b[s+16>>1]=i;b[r+16>>1]=c[j+(u<<2)>>2]&65535}}while(0);v=c[k+(q<<2)>>2]|0;do{if((p+15|0)>>>0<384){u=v&255;if((u|0)==0){break}b[s+30>>1]=i;b[r+30>>1]=c[j+(u<<2)>>2]&65535}}while(0);do{if((p+14|0)>>>0<384){u=v>>>8&255;if((u|0)==0){break}b[s+28>>1]=i;b[r+28>>1]=c[j+(u<<2)>>2]&65535}}while(0);do{if((p+13|0)>>>0<384){u=v>>>16&255;if((u|0)==0){break}b[s+26>>1]=i;b[r+26>>1]=c[j+(u<<2)>>2]&65535}}while(0);if((p+12|0)>>>0>=384){break}u=v>>>24;if((u|0)==0){break}b[s+24>>1]=i;b[r+24>>1]=c[j+(u<<2)>>2]&65535}}while(0);t=r+32|0;u=s+32|0;w=q-4|0;if((w|0)<=-1){x=l;y=m;z=n;A=t;B=u;break L15210}o=q;p=p+16|0;q=w;r=t;s=u}}else{x=l;y=m;z=n;A=l;B=m}}while(0);l=x+768|0;m=y+768|0;n=z+1|0;k=k+(h<<2)|0;}while((n|0)<(a|0));c[2443766]=k;c[2409608]=A;c[2406666]=B;c[2420368]=l;c[2415140]=m;c[3528514]=n;return}function au7(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;c[3528514]=0;a=c[2409614]|0;if((a|0)<=0){return}d=c[2415168]|0;f=c[2409618]|0;g=f-4|0;h=(g|0)>-1;i=c[2438140]|0;j=c[2415166]|0;k=j&65535;l=c[2438094]|0;m=c[2443766]|0;n=c[2420368]|0;o=c[2415140]|0;p=0;do{L15335:do{if(h){q=f;r=d;s=g;t=n;u=o;while(1){v=c[m+(q-1<<2)>>2]|0;do{if(r>>>0<368){w=v&255;do{if((w|0)!=0){x=u+6|0;if((e[x>>1]|0|0)>(j|0)){break}b[x>>1]=k;b[t+6>>1]=c[l+(w<<2)>>2]&65535}}while(0);w=v>>>8&255;do{if((w|0)!=0){x=u+4|0;if((e[x>>1]|0|0)>(j|0)){break}b[x>>1]=k;b[t+4>>1]=c[l+(w<<2)>>2]&65535}}while(0);w=v>>>16&255;do{if((w|0)!=0){x=u+2|0;if((e[x>>1]|0|0)>(j|0)){break}b[x>>1]=k;b[t+2>>1]=c[l+(w<<2)>>2]&65535}}while(0);w=v>>>24;do{if((w|0)!=0){if((e[u>>1]|0|0)>(j|0)){break}b[u>>1]=k;b[t>>1]=c[l+(w<<2)>>2]&65535}}while(0);w=c[m+(q-2<<2)>>2]|0;x=w&255;do{if((x|0)!=0){y=u+14|0;if((e[y>>1]|0|0)>(j|0)){break}b[y>>1]=k;b[t+14>>1]=c[l+(x<<2)>>2]&65535}}while(0);x=w>>>8&255;do{if((x|0)!=0){y=u+12|0;if((e[y>>1]|0|0)>(j|0)){break}b[y>>1]=k;b[t+12>>1]=c[l+(x<<2)>>2]&65535}}while(0);x=w>>>16&255;do{if((x|0)!=0){y=u+10|0;if((e[y>>1]|0|0)>(j|0)){break}b[y>>1]=k;b[t+10>>1]=c[l+(x<<2)>>2]&65535}}while(0);x=w>>>24;do{if((x|0)!=0){y=u+8|0;if((e[y>>1]|0|0)>(j|0)){break}b[y>>1]=k;b[t+8>>1]=c[l+(x<<2)>>2]&65535}}while(0);x=c[m+(q-3<<2)>>2]|0;w=x&255;do{if((w|0)!=0){y=u+22|0;if((e[y>>1]|0|0)>(j|0)){break}b[y>>1]=k;b[t+22>>1]=c[l+(w<<2)>>2]&65535}}while(0);w=x>>>8&255;do{if((w|0)!=0){y=u+20|0;if((e[y>>1]|0|0)>(j|0)){break}b[y>>1]=k;b[t+20>>1]=c[l+(w<<2)>>2]&65535}}while(0);w=x>>>16&255;do{if((w|0)!=0){y=u+18|0;if((e[y>>1]|0|0)>(j|0)){break}b[y>>1]=k;b[t+18>>1]=c[l+(w<<2)>>2]&65535}}while(0);w=x>>>24;do{if((w|0)!=0){y=u+16|0;if((e[y>>1]|0|0)>(j|0)){break}b[y>>1]=k;b[t+16>>1]=c[l+(w<<2)>>2]&65535}}while(0);w=c[m+(s<<2)>>2]|0;x=w&255;do{if((x|0)!=0){y=u+30|0;if((e[y>>1]|0|0)>(j|0)){break}b[y>>1]=k;b[t+30>>1]=c[l+(x<<2)>>2]&65535}}while(0);x=w>>>8&255;do{if((x|0)!=0){y=u+28|0;if((e[y>>1]|0|0)>(j|0)){break}b[y>>1]=k;b[t+28>>1]=c[l+(x<<2)>>2]&65535}}while(0);x=w>>>16&255;do{if((x|0)!=0){y=u+26|0;if((e[y>>1]|0|0)>(j|0)){break}b[y>>1]=k;b[t+26>>1]=c[l+(x<<2)>>2]&65535}}while(0);x=w>>>24;if((x|0)==0){break}y=u+24|0;if((e[y>>1]|0|0)>(j|0)){break}b[y>>1]=k;b[t+24>>1]=c[l+(x<<2)>>2]&65535}else{do{if((r+3|0)>>>0<384){x=v&255;if((x|0)==0){break}y=u+6|0;if((e[y>>1]|0|0)>(j|0)){break}b[y>>1]=k;b[t+6>>1]=c[l+(x<<2)>>2]&65535}}while(0);do{if((r+2|0)>>>0<384){w=v>>>8&255;if((w|0)==0){break}x=u+4|0;if((e[x>>1]|0|0)>(j|0)){break}b[x>>1]=k;b[t+4>>1]=c[l+(w<<2)>>2]&65535}}while(0);do{if((r+1|0)>>>0<384){w=v>>>16&255;if((w|0)==0){break}x=u+2|0;if((e[x>>1]|0|0)>(j|0)){break}b[x>>1]=k;b[t+2>>1]=c[l+(w<<2)>>2]&65535}}while(0);do{if(r>>>0<384){w=v>>>24;if((w|0)==0){break}if((e[u>>1]|0|0)>(j|0)){break}b[u>>1]=k;b[t>>1]=c[l+(w<<2)>>2]&65535}}while(0);w=c[m+(q-2<<2)>>2]|0;do{if((r+7|0)>>>0<384){x=w&255;if((x|0)==0){break}y=u+14|0;if((e[y>>1]|0|0)>(j|0)){break}b[y>>1]=k;b[t+14>>1]=c[l+(x<<2)>>2]&65535}}while(0);do{if((r+6|0)>>>0<384){x=w>>>8&255;if((x|0)==0){break}y=u+12|0;if((e[y>>1]|0|0)>(j|0)){break}b[y>>1]=k;b[t+12>>1]=c[l+(x<<2)>>2]&65535}}while(0);do{if((r+5|0)>>>0<384){x=w>>>16&255;if((x|0)==0){break}y=u+10|0;if((e[y>>1]|0|0)>(j|0)){break}b[y>>1]=k;b[t+10>>1]=c[l+(x<<2)>>2]&65535}}while(0);do{if((r+4|0)>>>0<384){x=w>>>24;if((x|0)==0){break}y=u+8|0;if((e[y>>1]|0|0)>(j|0)){break}b[y>>1]=k;b[t+8>>1]=c[l+(x<<2)>>2]&65535}}while(0);w=c[m+(q-3<<2)>>2]|0;do{if((r+11|0)>>>0<384){x=w&255;if((x|0)==0){break}y=u+22|0;if((e[y>>1]|0|0)>(j|0)){break}b[y>>1]=k;b[t+22>>1]=c[l+(x<<2)>>2]&65535}}while(0);do{if((r+10|0)>>>0<384){x=w>>>8&255;if((x|0)==0){break}y=u+20|0;if((e[y>>1]|0|0)>(j|0)){break}b[y>>1]=k;b[t+20>>1]=c[l+(x<<2)>>2]&65535}}while(0);do{if((r+9|0)>>>0<384){x=w>>>16&255;if((x|0)==0){break}y=u+18|0;if((e[y>>1]|0|0)>(j|0)){break}b[y>>1]=k;b[t+18>>1]=c[l+(x<<2)>>2]&65535}}while(0);do{if((r+8|0)>>>0<384){x=w>>>24;if((x|0)==0){break}y=u+16|0;if((e[y>>1]|0|0)>(j|0)){break}b[y>>1]=k;b[t+16>>1]=c[l+(x<<2)>>2]&65535}}while(0);w=c[m+(s<<2)>>2]|0;do{if((r+15|0)>>>0<384){x=w&255;if((x|0)==0){break}y=u+30|0;if((e[y>>1]|0|0)>(j|0)){break}b[y>>1]=k;b[t+30>>1]=c[l+(x<<2)>>2]&65535}}while(0);do{if((r+14|0)>>>0<384){x=w>>>8&255;if((x|0)==0){break}y=u+28|0;if((e[y>>1]|0|0)>(j|0)){break}b[y>>1]=k;b[t+28>>1]=c[l+(x<<2)>>2]&65535}}while(0);do{if((r+13|0)>>>0<384){x=w>>>16&255;if((x|0)==0){break}y=u+26|0;if((e[y>>1]|0|0)>(j|0)){break}b[y>>1]=k;b[t+26>>1]=c[l+(x<<2)>>2]&65535}}while(0);if((r+12|0)>>>0>=384){break}x=w>>>24;if((x|0)==0){break}y=u+24|0;if((e[y>>1]|0|0)>(j|0)){break}b[y>>1]=k;b[t+24>>1]=c[l+(x<<2)>>2]&65535}}while(0);v=t+32|0;x=u+32|0;y=s-4|0;if((y|0)<=-1){z=n;A=o;B=p;C=v;D=x;break L15335}q=s;r=r+16|0;s=y;t=v;u=x}}else{z=n;A=o;B=p;C=n;D=o}}while(0);n=z+768|0;o=A+768|0;p=B+1|0;m=m+(i<<2)|0;}while((p|0)<(a|0));c[2443766]=m;c[2409608]=C;c[2406666]=D;c[2420368]=n;c[2415140]=o;c[3528514]=p;return}function au8(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=c[2409614]|0;c[3528514]=d;if((d|0)<=0){return}e=c[2443766]|0;f=c[2438140]|0;g=c[2438138]|0;h=c[2409618]|0;i=(h|0)>0;j=c[2432830]|0;k=c[2432832]|0;l=c[2438094]|0;m=c[2420368]|0;n=d;d=c[2438134]|0;do{o=ag(f,d>>16)|0;if(i){p=h;q=g;r=m;while(1){s=a[e+((q>>16)+o)|0]|0;if(s<<24>>24!=0){b[r>>1]=c[l+((s&255)<<2)>>2]&65535}s=r+2|0;t=p-65536|0;if((t|0)>0){p=t;q=k+q|0;r=s}else{u=m;v=n;w=d;x=s;break}}}else{u=m;v=n;w=d;x=m}m=u+768|0;n=v-65536|0;d=j+w|0;}while((n|0)>0);c[2409608]=x;c[2420368]=m;c[3528514]=n;c[2438134]=d;return}function au9(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;d=c[2409614]|0;c[3528514]=d;if((d|0)<=0){return}f=c[2443766]|0;g=c[2438140]|0;h=c[2438138]|0;i=c[2409618]|0;j=(i|0)>0;k=c[2432830]|0;l=c[2432832]|0;m=c[2415166]|0;n=c[2438094]|0;o=c[2420368]|0;p=c[2415140]|0;q=d;d=c[2438134]|0;do{r=ag(g,d>>16)|0;if(j){s=i;t=h;u=o;v=p;while(1){w=a[f+((t>>16)+r)|0]|0;do{if(w<<24>>24==0){x=u;y=v}else{if((e[v>>1]|0|0)>(m|0)){x=u;y=v;break}b[u>>1]=c[n+((w&255)<<2)>>2]&65535;x=u;y=v}}while(0);w=x+2|0;z=y+2|0;A=s-65536|0;if((A|0)>0){s=A;t=l+t|0;u=w;v=z}else{B=o;C=p;D=q;E=d;F=w;G=z;break}}}else{B=o;C=p;D=q;E=d;F=o;G=p}o=B+768|0;p=C+768|0;q=D-65536|0;d=k+E|0;}while((q|0)>0);c[2409608]=F;c[2406666]=G;c[2420368]=o;c[2415140]=p;c[3528514]=q;c[2438134]=d;return}function ava(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;e=c[2409614]|0;c[3528514]=e;if((e|0)<=0){return}f=c[2443766]|0;g=c[2438140]|0;h=c[2438138]|0;i=c[2409618]|0;j=(i|0)>0;k=c[2432830]|0;l=c[2432832]|0;m=c[2415166]&65535;n=c[2438094]|0;o=c[2420368]|0;p=c[2415140]|0;q=e;e=c[2438134]|0;do{r=ag(g,e>>16)|0;if(j){s=i;t=h;u=o;v=p;while(1){w=f+((t>>16)+r)|0;if((a[w]|0)!=0){b[v>>1]=m;b[u>>1]=c[n+(d[w]<<2)>>2]&65535}w=u+2|0;x=v+2|0;y=s-65536|0;if((y|0)>0){s=y;t=l+t|0;u=w;v=x}else{z=o;A=p;B=q;C=e;D=w;E=x;break}}}else{z=o;A=p;B=q;C=e;D=o;E=p}o=z+768|0;p=A+768|0;q=B-65536|0;e=k+C|0;}while((q|0)>0);c[2409608]=D;c[2406666]=E;c[2420368]=o;c[2415140]=p;c[3528514]=q;c[2438134]=e;return}function avb(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;f=c[2409614]|0;c[3528514]=f;if((f|0)<=0){return}g=c[2443766]|0;h=c[2438140]|0;i=c[2438138]|0;j=c[2409618]|0;k=(j|0)>0;l=c[2432830]|0;m=c[2432832]|0;n=c[2415166]|0;o=n&65535;p=c[2438094]|0;q=c[2420368]|0;r=c[2415140]|0;s=f;f=c[2438134]|0;do{t=ag(h,f>>16)|0;if(k){u=j;v=i;w=q;x=r;while(1){y=g+((v>>16)+t)|0;do{if((a[y]|0)==0){z=w;A=x}else{if((e[x>>1]|0)>(n|0)){z=w;A=x;break}b[x>>1]=o;b[w>>1]=c[p+(d[y]<<2)>>2]&65535;z=w;A=x}}while(0);y=z+2|0;B=A+2|0;C=u-65536|0;if((C|0)>0){u=C;v=m+v|0;w=y;x=B}else{D=q;E=r;F=s;G=f;H=y;I=B;break}}}else{D=q;E=r;F=s;G=f;H=q;I=r}q=D+768|0;r=E+768|0;s=F-65536|0;f=l+G|0;}while((s|0)>0);c[2409608]=H;c[2406666]=I;c[2420368]=q;c[2415140]=r;c[3528514]=s;c[2438134]=f;return}function avc(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;d=c[2438138]|0;e=d&-65536;f=c[2438134]|0;g=f&-65536;h=(e|0)==0?-19131852:e;e=c[2409614]|0;c[3528514]=e;if((e|0)<=0){return}i=c[2432830]|0;j=c[2443766]|0;k=c[2438140]|0;l=c[2409618]|0;m=(l|0)>0;n=c[2438094]|0;o=c[2432832]|0;p=(g|0)==0?-19131852:g;g=c[2420368]|0;q=e;e=f;while(1){do{if((p^e)>>>0<65536){r=p;s=q;t=e}else{f=ag(k,e>>16)|0;c[2409608]=g;if(m){u=l;v=d;w=h;x=g}else{r=e;s=q;t=e;break}while(1){do{if((v^w)>>>0>65535){y=a[j+((v>>16)+f)|0]|0;if(y<<24>>24==0){z=v;A=x;break}b[x>>1]=c[n+((y&255)<<2)>>2]&65535;z=v;A=x}else{z=w;A=x}}while(0);B=A+2|0;y=u-65536|0;if((y|0)>0){u=y;v=o+v|0;w=z;x=B}else{break}}c[2409608]=B;r=e;s=q;t=e}}while(0);C=g+768|0;D=s-65536|0;E=i+t|0;if((D|0)>0){p=r;g=C;q=D;e=E}else{break}}c[2420368]=C;c[3528514]=D;c[2438134]=E;return}function avd(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;d=c[2438138]|0;f=d&-65536;g=c[2438134]|0;h=g&-65536;i=(f|0)==0?-19131852:f;f=c[2409614]|0;c[3528514]=f;if((f|0)<=0){return}j=c[2432830]|0;k=c[2443766]|0;l=c[2438140]|0;m=c[2409618]|0;n=(m|0)>0;o=c[2415166]|0;p=c[2438094]|0;q=c[2432832]|0;r=(h|0)==0?-19131852:h;h=c[2415140]|0;s=c[2420368]|0;t=f;f=g;while(1){do{if((r^f)>>>0<65536){u=r;v=t;w=f}else{g=ag(l,f>>16)|0;c[2406666]=h;c[2409608]=s;if(n){x=m;y=d;z=i;A=s;B=h}else{u=f;v=t;w=f;break}while(1){do{if((y^z)>>>0>65535){C=a[k+((y>>16)+g)|0]|0;if(C<<24>>24==0){D=y;E=A;F=B;break}if((e[B>>1]|0|0)>(o|0)){D=y;E=A;F=B;break}b[A>>1]=c[p+((C&255)<<2)>>2]&65535;D=y;E=A;F=B}else{D=z;E=A;F=B}}while(0);G=E+2|0;H=F+2|0;C=x-65536|0;if((C|0)>0){x=C;y=q+y|0;z=D;A=G;B=H}else{break}}c[2409608]=G;c[2406666]=H;u=f;v=t;w=f}}while(0);I=s+768|0;J=h+768|0;K=v-65536|0;L=j+w|0;if((K|0)>0){r=u;h=J;s=I;t=K;f=L}else{break}}c[2415140]=J;c[2420368]=I;c[3528514]=K;c[2438134]=L;return}function ave(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;e=c[2438138]|0;f=e&-65536;g=c[2438134]|0;h=g&-65536;i=(f|0)==0?-19131852:f;f=c[2409614]|0;c[3528514]=f;if((f|0)<=0){return}j=c[2432830]|0;k=c[2443766]|0;l=c[2438140]|0;m=c[2409618]|0;n=(m|0)>0;o=c[2415166]&65535;p=c[2438094]|0;q=c[2432832]|0;r=(h|0)==0?-19131852:h;h=c[2415140]|0;s=c[2420368]|0;t=f;f=g;while(1){do{if((r^f)>>>0<65536){u=r;v=t;w=f}else{g=ag(l,f>>16)|0;c[2406666]=h;c[2409608]=s;if(n){x=m;y=e;z=i;A=s;B=h}else{u=f;v=t;w=f;break}while(1){do{if((y^z)>>>0>65535){C=k+((y>>16)+g)|0;if((a[C]|0)==0){D=y;E=A;F=B;break}b[B>>1]=o;b[A>>1]=c[p+(d[C]<<2)>>2]&65535;D=y;E=A;F=B}else{D=z;E=A;F=B}}while(0);G=E+2|0;H=F+2|0;C=x-65536|0;if((C|0)>0){x=C;y=q+y|0;z=D;A=G;B=H}else{break}}c[2409608]=G;c[2406666]=H;u=f;v=t;w=f}}while(0);I=s+768|0;J=h+768|0;K=v-65536|0;L=j+w|0;if((K|0)>0){r=u;h=J;s=I;t=K;f=L}else{break}}c[2415140]=J;c[2420368]=I;c[3528514]=K;c[2438134]=L;return}function avf(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;f=c[2438138]|0;g=f&-65536;h=c[2438134]|0;i=h&-65536;j=(g|0)==0?-19131852:g;g=c[2409614]|0;c[3528514]=g;if((g|0)<=0){return}k=c[2432830]|0;l=c[2443766]|0;m=c[2438140]|0;n=c[2409618]|0;o=(n|0)>0;p=c[2415166]|0;q=p&65535;r=c[2438094]|0;s=c[2432832]|0;t=(i|0)==0?-19131852:i;i=c[2415140]|0;u=c[2420368]|0;v=g;g=h;while(1){do{if((t^g)>>>0<65536){w=t;x=v;y=g}else{h=ag(m,g>>16)|0;c[2406666]=i;c[2409608]=u;if(o){z=n;A=f;B=j;C=u;D=i}else{w=g;x=v;y=g;break}while(1){do{if((A^B)>>>0>65535){E=l+((A>>16)+h)|0;if((a[E]|0)==0){F=A;G=C;H=D;break}if((e[D>>1]|0)>(p|0)){F=A;G=C;H=D;break}b[D>>1]=q;b[C>>1]=c[r+(d[E]<<2)>>2]&65535;F=A;G=C;H=D}else{F=B;G=C;H=D}}while(0);I=G+2|0;J=H+2|0;E=z-65536|0;if((E|0)>0){z=E;A=s+A|0;B=F;C=I;D=J}else{break}}c[2409608]=I;c[2406666]=J;w=g;x=v;y=g}}while(0);K=u+768|0;L=i+768|0;M=x-65536|0;N=k+y|0;if((M|0)>0){t=w;i=L;u=K;v=M;g=N}else{break}}c[2415140]=L;c[2420368]=K;c[3528514]=M;c[2438134]=N;return}function avg(d){d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=c[3542108]|0;f=(d|0)>0;if((a[14168416]|0)!=0){if(f){g=c[3527514]|0;h=c[3542106]|0;i=0;j=e;while(1){k=i<<8;l=0;m=j;n=g+(k<<1)|0;o=h+(k<<2)|0;while(1){k=b[m>>1]|0;b[n>>1]=k;p=k&65535;k=p>>>7&248;c[o>>2]=p>>>2<<8&63488|p&31|(k>>>5|k)<<3&2016;k=l+1|0;if((k|0)<16){l=k;m=m+2|0;n=n+2|0;o=o+4|0}else{break}}o=i+1|0;if((o|0)<(d|0)){i=o;j=j+32|0}else{break}}}a[14168416]=0;return}if(!f){return}f=c[3527514]|0;j=c[3542106]|0;i=0;h=e;while(1){e=i<<8;g=0;o=h;n=f+(e<<1)|0;m=j+(e<<2)|0;while(1){e=b[o>>1]|0;if((b[n>>1]|0)!=e<<16>>16){b[n>>1]=e;l=e&65535;e=l>>>7&248;c[m>>2]=l>>>2<<8&63488|l&31|(e>>>5|e)<<3&2016}e=g+1|0;if((e|0)<16){g=e;o=o+2|0;n=n+2|0;m=m+4|0}else{break}}m=i+1|0;if((m|0)>=(d|0)){break}i=m;h=h+32|0}return}function avh(a){a=a|0;var b=0;switch(a&255|0){case 81:{b=c[(c[3531464]|0)+4240>>2]&255;return b|0};case 96:{b=c[2113156]&255;return b|0};case 48:{c[2433328]=c[2433328]|4;b=c[3528932]&255;return b|0};case 64:{c[2433328]=c[2433328]|8;b=(c[3528932]|0)>>>8&255;return b|0};case 128:{b=c[2113157]&255;return b|0};default:{b=0;return b|0}}return 0}function avi(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;switch(b&255|0){case 16:{b=c[2430066]|0;if((c[2429480]|0)>(b|0)){c[2430066]=-1;c[2429480]=0;e=-1}else{e=b}b=e+1|0;c[2430066]=b;c[9747456+(b<<2)>>2]=d&255;return};case 81:{b=c[2113304]|0;a[14168504+b|0]=d;mv(0,b,d&255);return};case 112:{b=c[3541206]|0;e=d&255;f=e<<17&1966080;g=b+f|0;c[3541190]=g;c[3541191]=b+(f|256);c[3541192]=b+(f|512);c[3541193]=b+(f|768);c[3541198]=g;c[3541199]=b+(f|65536);f=e<<13&1966080;c[3541200]=b+f;c[3541201]=b+(f|65536);return};case 128:{Uv(1,d);return};case 80:{c[2113304]=d&255;return};case 0:{f=d&31;if((f|0)==(c[2440570]|0)){return}b=c[2411304]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;g=(f<<14)-16384|0;h=64;i=64;while(1){c[e+76+(i<<2)>>2]=b+(g+(i<<8));j=h+1&65535;if((j&65535)>127){k=64;l=64;break}else{h=j;i=j&65535}}while(1){i=b+(g+(l<<8))|0;c[e+76+(l+512<<2)>>2]=i;c[e+76+(l+768<<2)>>2]=i;i=k+1&65535;if((i&65535)>127){break}else{k=i;l=i&65535}}c[2440570]=f;return};case 96:{Uv(0,d);return};case 192:{f=c[3541206]|0;l=d&255;d=l<<17&1966080;k=f+(d|2097152)|0;c[3541194]=k;c[3541195]=f+(d|2097408);c[3541196]=f+(d|2097664);c[3541197]=f+(d|2097920);c[3541202]=k;c[3541203]=f+(d|2162688);d=l<<13&1966080;c[3541204]=f+(d|2097152);c[3541205]=f+(d|2162688);return};default:{return}}}function avj(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0;if((d|0)==12058628|(d|0)==12058629){f=a[9775200]|0;g=f<<1|a[9541744];a[9541744]=1;do{if((a[9541976]|0)==0){h=4096}else{i=f<<24>>24==0;if(i){h=i?4096:0;break}c[8452200+(c[2394]<<2)>>2]=0;c[2276080]=0;j=g;return j|0}}while(0);c[8452200+(c[2394]<<2)>>2]=h|1;c[2276080]=256;if((c[2276079]|0)>>>0>=256){j=g;return j|0}RH(1);j=g;return j|0}else if((d|0)==12058624|(d|0)==12058625){j=a[9626832]<<2^4|a[9775200]<<1|a[9541744];return j|0}else if((d|0)==6291457){j=~(b[4812836]&255);return j|0}else if((d|0)==6291456){j=((e[4812836]|0)>>>8^255)&255;return j|0}else if((d|0)==12058626|(d|0)==12058627){j=a[9775200]<<1|a[9541744];return j|0}else if((d|0)==6291459){j=~(b[4812837]&255);return j|0}else if((d|0)==6291458){g=(e[4812837]|0)>>>8;do{if((c[2406632]|0)==0){h=c[2443744]|0;if((h|0)<=0){k=8;break}c[2443744]=h-1;k=0}else{k=(c[2432962]|0)>>>((c[(c[2420380]|0)+4>>2]|0)>>>0)<<3&8}}while(0);j=((k|g)^247)&255;return j|0}else if((d|0)==12058630|(d|0)==12058631){d=a[9541744]|0;g=a[9775200]<<1|d;a[9775200]=1;k=8452200+(c[2394]<<2)|0;if(!(d<<24>>24==0|(a[9541976]|0)==0)){c[k>>2]=0;c[2276080]=0;j=g;return j|0}c[k>>2]=4097;c[2276080]=256;if((c[2276079]|0)>>>0>=256){j=g;return j|0}RH(1);j=g;return j|0}else{j=0;return j|0}return 0}function avk(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0;if((d|0)==12058624){f=a[9626832]<<2^4|a[9775200]<<1|a[9541744];return f|0}else if((d|0)==12058628){g=a[9775200]|0;h=g<<24>>24<<1|a[9541744];a[9541744]=1;do{if((a[9541976]|0)==0){i=4096}else{j=g<<24>>24==0;if(j){i=j?4096:0;break}c[8452200+(c[2394]<<2)>>2]=0;c[2276080]=0;f=h;return f|0}}while(0);c[8452200+(c[2394]<<2)>>2]=i|1;c[2276080]=256;if((c[2276079]|0)>>>0>=256){f=h;return f|0}RH(1);f=h;return f|0}else if((d|0)==12058734){h=c[2429480]|0;if((h|0)>(c[2430066]|0)){c[2429480]=0;c[2430066]=-1;f=0;return f|0}else{c[2429480]=h+1;f=c[9747456+(h<<2)>>2]&65535;return f|0}}else if((d|0)==6291458){h=e[4812837]|0;do{if((c[2406632]|0)==0){i=c[2443744]|0;if((i|0)<=0){k=2048;break}c[2443744]=i-1;k=0}else{k=(c[2432962]|0)>>>((c[(c[2420380]|0)+4>>2]|0)>>>0)<<11&2048}}while(0);f=((k|h)^63487)&65535;return f|0}else if((d|0)==12058626){f=a[9775200]<<1|a[9541744];return f|0}else if((d|0)==6291456){f=~b[4812836];return f|0}else if((d|0)==12058732){f=(c[2429480]|0)>(c[2430066]|0)?2:0;return f|0}else if((d|0)==12058630){d=a[9541744]|0;h=a[9775200]<<1|d<<24>>24;a[9775200]=1;k=8452200+(c[2394]<<2)|0;if(!(d<<24>>24==0|(a[9541976]|0)==0)){c[k>>2]=0;c[2276080]=0;f=h;return f|0}c[k>>2]=4097;c[2276080]=256;if((c[2276079]|0)>>>0>=256){f=h;return f|0}RH(1);f=h;return f|0}else{f=0;return f|0}return 0}function avl(a,b){a=a|0;b=b|0;if((a|0)!=7340032){return}a=b&255;c[2113284]=a&1;c[2415256]=a&8;b=a>>>1&1;c[3528406]=b^1;if((b|0)==0){c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2]}Tr(a>>>2&1);return}function avm(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0;if((b|0)==10485760){c[3542078]=d&65535;return}else if((b|0)==11534340){c[3542086]=d&65535;return}else if((b|0)==11010050){c[3542082]=d&65535;return}else if((b|0)==10485764){c[3542080]=d&65535;return}else if((b|0)==12058626){c[2113278]=d&65535;return}else if((b|0)==11010052){c[3542083]=d&65535;return}else if((b|0)==12058734){c[3528932]=d&65535;c[2433328]=c[2433328]|12;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;e=c[2433530]|0;c[2433530]=e+12;if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){f=gfc(1024)|0;g=f;h=(c[2433530]|0)+f|0}else{g=1024;h=e+1036|0}c[2433530]=h;c[2433568]=(c[2433568]|0)+g;return}else if((b|0)==10485762){c[3542079]=d&65535;return}else if((b|0)==7340032){g=(d&65535)>>>8&65535;c[2113284]=g&1;c[2415256]=g&8;h=g>>>1&1;c[3528406]=h^1;if((h|0)==0){c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2]}Tr(g>>>2&1);return}else if((b|0)==12058632){gD[c[3542102]&8191]()|0;c[2113288]=d&65535;return}else if((b|0)==12058624){c[2113282]=d&65535;return}else if((b|0)==11010048){c[3542081]=d&65535;return}else if((b|0)==11534338){c[3542085]=d&65535;return}else if((b|0)==11534336){c[3542084]=d&65535;return}else{return}}function avn(b,d){b=b|0;d=d|0;var f=0,g=0;f=b&65535^1;b=c[3542108]|0;a[b+f|0]=d;g=(c[3527514]|0)+(f<<1)|0;if((a[g]|0)==d<<24>>24){return}a[g]=d;d=e[b+(f&65534)>>1]|0;b=d>>>7&248;c[(c[3542106]|0)+(f>>>1<<2)>>2]=d>>>2<<8&63488|d&31|(b>>>5|b)<<3&2016;return}function avo(a,d){a=a|0;d=d|0;var e=0;e=a>>>1&32767;b[(c[3542108]|0)+(e<<1)>>1]=d;a=(c[3527514]|0)+(e<<1)|0;if((b[a>>1]|0)==d<<16>>16){return}b[a>>1]=d;a=d&65535;d=a>>>7&248;c[(c[3542106]|0)+(e<<2)>>2]=a>>>2<<8&63488|a&31|(d>>>5|d)<<3&2016;return}function avp(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2349468+(b*112|0)>>2];c[a+104>>2]=c[2349472+(b*112|0)>>2];c[a+108>>2]=c[2349476+(b*112|0)>>2];d=0;return d|0}function avq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=2349368+(b*112|0);e=0;return e|0}function avr(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1022784+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function avs(){a[9536]=0;return av4()|0}function avt(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;i=i+128|0;d=b|0;e=c[c[642608+(c[2436]<<2)>>2]>>2]|0;be(d|0,128,179600,(f=i,i=i+24|0,c[f>>2]=9374064,c[f+8>>2]=47,c[f+16>>2]=e,f)|0)|0;i=f;a[1040128]=0;f=c[2420380]|0;e=c[f>>2]|0;g=c[f+4>>2]|0;f=fw(d|0,389440)|0;if((f|0)!=0){d=g>>3<<e&1023;cj(14100392,d|0,1,f|0)|0;aY(f|0)|0}Uw(0);Uw(1);f=c[3531464]|0;c[f+44344>>2]=0;c[f+44348>>2]=0;if((f|0)!=0){gGr(f);c[3531464]=0}f=c[2406684]|0;if((f|0)!=0){gGr(f);c[2406684]=0}axH();f=c[2443764]|0;d=0;while(1){if((d|0)>=1024){break}h=9638528+(d<<2)|0;if((c[h>>2]|0)==(f|0)){j=12830;break}else{d=d+1|0}}if((j|0)==12830){gGr(f);c[h>>2]=0}c[2443764]=0;h=c[2394718]|0;f=0;while(1){if((f|0)>=1024){break}k=9638528+(f<<2)|0;if((c[k>>2]|0)==(h|0)){j=12834;break}else{f=f+1|0}}if((j|0)==12834){gGr(h);c[k>>2]=0}c[2394718]=0;a[7462192]=0;k=c[3542106]|0;h=0;while(1){if((h|0)>=1024){break}l=9638528+(h<<2)|0;if((c[l>>2]|0)==(k|0)){j=12838;break}else{h=h+1|0}}if((j|0)==12838){gGr(k);c[l>>2]=0}c[3542106]=0;l=c[3527514]|0;k=0;while(1){if((k|0)>=1024){break}m=9638528+(k<<2)|0;if((c[m>>2]|0)==(l|0)){j=12842;break}else{k=k+1|0}}if((j|0)==12842){gGr(l);c[m>>2]=0}c[3527514]=0;fwZ();if((c[2392]|0)>=0){m=0;do{l=14130368+(m<<2)|0;k=c[l>>2]|0;if((k|0)!=0){gGr(k);c[l>>2]=0}l=14130384+(m<<2)|0;k=c[l>>2]|0;if((k|0)!=0){gGr(k);c[l>>2]=0}m=m+1|0;}while((m|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;m=c[2426710]|0;l=0;while(1){if((l|0)>=1024){j=12854;break}n=9638528+(l<<2)|0;if((c[n>>2]|0)==(m|0)){break}else{l=l+1|0}}if((j|0)==12854){c[2426710]=0;i=b;return 0}gGr(m);c[n>>2]=0;c[2426710]=0;i=b;return 0}function avu(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;if((a[9624056]|0)!=0){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;c[2440570]=-1;d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];f=c[3528484]|0;c[2076596]=f;g=c[2417276]|0;c[3541536]=g;c[1836236]=0;h=c[2411304]|0;i=64;j=64;while(1){c[d+76+(j<<2)>>2]=h+((j<<8)-16384);k=i+1&65535;if((k&65535)>127){l=64;m=64;break}else{i=k;j=k&65535}}while(1){j=h+((m<<8)-16384)|0;c[d+76+(m+512<<2)>>2]=j;c[d+76+(m+768<<2)>>2]=j;j=l+1&65535;if((j&65535)>127){break}else{l=j;m=j&65535}}c[2440570]=0;gGz(9706056,0,76);if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=f;c[2417276]=g;c[1836236]=-1;c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];a[9541744]=1;a[9541976]=1;a[9775200]=1;c[3528932]=0;c[2433328]=12;gGz(9747456,0,192);c[2429480]=0;c[2430066]=-1;c[2433568]=0;c[2433570]=0;c[2113156]=0;a[9628264]=0;c[2407033]=0;g=c[3541206]|0;c[3541190]=g;c[3541198]=g;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=g+256;c[3541199]=g+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=g+512;c[3541200]=g+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=g+768;c[3541201]=g+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2113157]=0;a[9628420]=0;c[2407072]=0;f=g+1048576|0;c[3541194]=f;c[3541202]=f;gGz(c[2430122]|0,0,16384);c[2407080]=4;c[3541195]=g+1048832;c[3541203]=g+1114112;gGz(c[2430123]|0,0,16384);c[2407088]=4;c[3541196]=g+1049088;c[3541204]=g+1179648;gGz(c[2430124]|0,0,16384);c[2407096]=4;c[3541197]=g+1049344;c[3541205]=g+1245184;gGz(c[2430125]|0,0,16384);c[2407104]=4;mx(0)}b[4812836]=0;b[4812837]=0;g=0;f=0;e=0;do{f=((a[9633256+g|0]&1)<<g|f&65535)&65535;e=((a[9631128+g|0]&1)<<g|e&65535)&65535;g=g+1|0;}while((g|0)<10);b[4812836]=f;b[4812837]=e;if((f&3)==3){g=f&-4;b[4812836]=g;n=g}else{n=f}if((n&12)==12){b[4812836]=n&-13}if((e&3)==3){n=e&-4;b[4812837]=n;o=n}else{o=e}if((o&12)==12){b[4812837]=o&-13}o=c[2392]|0;if((o|0)>=0){gGz(8452240,0,((o|0)>0?(o<<2)+4|0:4)|0)}c[2113054]=0;o=c[2438]|0;e=gGU(o,(o|0)<0|0?-1:0,16e6,0)|0;o=~~((+(e>>>0)+ +(K|0)*4294967296.0)/14732.965009208103);c[2433570]=0;e=(c[2433568]|0)-139008|0;c[2433568]=(e|0)<0?0:e;e=o-~~(+(o|0)*31.5/271.5)|0;a[9626832]=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];n=c[3532592]|0;if((n|0)!=0){gGC(9104152,n|0,280)|0}c[2113054]=c[2113060]}n=c[2439330]|0;if((n|0)!=0){f=n;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;f=0;n=0;L15956:while(1){g=n;do{if((g|0)>=4){break L15956}g=g+1|0;d=(ag(g,o)|0)/4|0;do{if((a[9626832]|0)==0&(d|0)>(e|0)){m=c[2433570]|0;if((m|0)<(e|0)){l=e-m|0;c[2113056]=l;m=RG(l)|0;c[2113054]=(c[2113054]|0)+m;c[2276108]=-1;c[2113056]=-1;c[2433570]=(c[2433570]|0)+m}if((c[2112968]|0)!=0){avv()|0}a[9626832]=1;a[9541744]=0;c[8452200+(c[2394]<<2)>>2]=4097;c[2276080]=256;if((c[2276079]|0)>>>0>=256){break}RH(1)}}while(0);m=d-(c[2433570]|0)|0;c[2113056]=m;l=RG(m)|0;c[2113054]=(c[2113054]|0)+l;c[2276108]=-1;c[2113056]=-1;c[2433570]=(c[2433570]|0)+l;l=c[2433568]|0;m=((g*139008|0|0)/4|0)-l|0;do{if((m|0)<1){p=0;q=l}else{if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){h=gfc(m)|0;c[2433530]=(c[2433530]|0)+h;p=h;q=c[2433568]|0;break}else{c[2433530]=(c[2433530]|0)+m;p=m;q=l;break}}}while(0);c[2433568]=q+p;r=c[2112964]|0;}while((r|0)==0);l=a[9688]|0?133:0;m=r+(f<<1<<1)|0;gg[c[3542124]&4095](m,l);Uu(0,m,l);Uu(1,m,l);f=l+f|0;n=g}n=c[2394]|0;r=c[14130368+(n<<2)>>2]|0;if((r|0)!=0){gGC(r|0,9104152,280)|0}c[8452240+(n<<2)>>2]=c[2113054];c[2394]=-1;n=c[2112964]|0;do{if((n|0)!=0){r=a[9688]|0?534:0;p=r-f|0;q=n+(f<<1<<1)|0;if((r|0)==(f|0)){break}gg[c[3542124]&4095](q,p);Uu(0,q,p);Uu(1,q,p)}}while(0);f=c[1836236]|0;n=c[9757320+(f<<2)>>2]|0;if((n|0)==0){s=c[2433530]|0;t=9752472+(f<<2)|0;c[t>>2]=s;u=c[2076596]|0;v=14113936+(f<<2)|0;c[v>>2]=u;w=c[3541536]|0;x=9669104+(f<<2)|0;c[x>>2]=w;c[1836236]=-1;return 0}p=n;gGC(p|0,9706056,76)|0;s=c[2433530]|0;t=9752472+(f<<2)|0;c[t>>2]=s;u=c[2076596]|0;v=14113936+(f<<2)|0;c[v>>2]=u;w=c[3541536]|0;x=9669104+(f<<2)|0;c[x>>2]=w;c[1836236]=-1;return 0}function avv(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((a[14168416]|0)==0){d=c[3542106]|0}else{e=c[3527514]|0;f=c[3542106]|0;g=(c[3542108]|0)+34816|0;h=0;while(1){i=(h<<8)+17408|0;j=0;k=g;l=e+(i<<1)|0;m=f+(i<<2)|0;while(1){i=b[k>>1]|0;b[l>>1]=i;n=i&65535;i=n>>>7&248;c[m>>2]=n>>>2<<8&63488|n&31|(i>>>5|i)<<3&2016;i=j+1|0;if((i|0)<256){j=i;k=k+2|0;l=l+2|0;m=m+4|0}else{break}}m=h+1|0;if((m|0)<12){g=g+512|0;h=m}else{break}}a[14168416]=1;d=f}avg(64);f=a[9536]|0;h=c[d+((f?16128:24560)<<2)>>2]|0;d=c[2112968]|0;do{if((h|0)==0){gGz(d|0,0,ag(c[2113280]<<1,c[2113276]|0)|0)}else{g=h<<16|h;e=ag(c[2113276]|0,c[2113280]|0)|0;if((e|0)<=15){break}m=d;l=(e|0)/16|0;while(1){c[m>>2]=g;c[m+4>>2]=g;c[m+8>>2]=g;c[m+12>>2]=g;c[m+16>>2]=g;c[m+20>>2]=g;c[m+24>>2]=g;c[m+28>>2]=g;e=l-1|0;if((e|0)>0){m=m+32|0;l=e}else{break}}}}while(0);if(!(a[7072768]|0)){return 0}if(f){axE(0);return 0}else{axE(1);return 0}return 0}function avw(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;g=i;i=i+272|0;h=g|0;j=g+16|0;k=g+32|0;l=g+48|0;m=g+64|0;n=g+80|0;o=g+96|0;p=g+112|0;q=g+128|0;r=g+144|0;s=g+160|0;t=g+176|0;u=g+192|0;v=g+208|0;w=g+224|0;x=g+240|0;y=g+256|0;if((f|0)!=0){c[f>>2]=169753}Ts(e,f);if((e&96|0)==0){i=g;return 0}gGz(y|0,0,12);f=c[2405644]|0;c[y>>2]=f;c[y+4>>2]=(c[2411632]|0)-f;c[y+12>>2]=219592;gj[c[2076592]&4095](y)|0;y=m|0;f=(e&64|0)==0;do{if(!f){gGz(l|0,0,16);c[2394]=-1;if((c[2392]|0)<0){break}z=m+9|0;A=k;B=k|0;C=k+4|0;D=k+12|0;E=l|0;F=l+4|0;G=l+12|0;H=0;do{gGC(y|0,614896,11)|0;a[z]=H+48&255;I=8452256+(H<<2)|0;gGz(A|0,0,12);c[B>>2]=I;c[C>>2]=4;c[D>>2]=164976;gj[c[2076592]&4095](k)|0;if((c[I>>2]|0)!=0){c[E>>2]=c[14130368+(H<<2)>>2];c[F>>2]=c[8452184+(H<<2)>>2];c[G>>2]=y;I=c[2076592]|0;gj[I&4095](l)|0}H=H+1|0;}while((H|0)<=(c[2392]|0))}}while(0);fw$(e);gGz(x|0,0,12);c[x>>2]=14115728;c[x+4>>2]=4;c[x+12>>2]=361464;gj[c[2076592]&4095](x)|0;gGz(w|0,0,12);c[w>>2]=9733312;c[w+4>>2]=4;c[w+12>>2]=146336;gj[c[2076592]&4095](w)|0;gGz(v|0,0,12);c[v>>2]=9747456;c[v+4>>2]=192;c[v+12>>2]=142432;gj[c[2076592]&4095](v)|0;gGz(u|0,0,12);c[u>>2]=9717920;c[u+4>>2]=4;c[u+12>>2]=139520;gj[c[2076592]&4095](u)|0;gGz(t|0,0,12);c[t>>2]=9720264;c[t+4>>2]=4;c[t+12>>2]=136904;gj[c[2076592]&4095](t)|0;gGz(s|0,0,12);c[s>>2]=9762280;c[s+4>>2]=4;c[s+12>>2]=69312;gj[c[2076592]&4095](s)|0;Ut(0);Ut(1);do{if(f){J=e&2}else{gGz(j|0,0,12);c[j>>2]=8453216;c[j+4>>2]=4;c[j+12>>2]=107480;s=c[2076592]|0;gj[s&4095](j)|0;gGz(h|0,0,12);c[h>>2]=14168504;c[h+4>>2]=256;c[h+12>>2]=476464;s=c[2076592]|0;gj[s&4095](h)|0;s=e&2;if((s|0)==0){J=0;break}else{K=0}while(1){mv(0,K,d[14168504+K|0]|0);t=K+1|0;if((t|0)<256){K=t}else{J=s;break}}}}while(0);gGz(r|0,0,12);c[r>>2]=9541744;c[r+4>>2]=1;c[r+12>>2]=148144;gj[c[2076592]&4095](r)|0;gGz(q|0,0,12);c[q>>2]=9541976;c[q+4>>2]=1;c[q+12>>2]=118544;gj[c[2076592]&4095](q)|0;gGz(p|0,0,12);c[p>>2]=9775200;c[p+4>>2]=1;c[p+12>>2]=93520;gj[c[2076592]&4095](p)|0;gGz(o|0,0,12);c[o>>2]=9626832;c[o+4>>2]=1;c[o+12>>2]=163632;gj[c[2076592]&4095](o)|0;ayc();gGz(n|0,0,12);c[n>>2]=9625672;c[n+4>>2]=4;c[n+12>>2]=215728;gj[c[2076592]&4095](n)|0;if((J|0)==0){i=g;return 0}J=c[2440570]|0;c[2440570]=-1;n=c[2439330]|0;o=(n|0)==0;if(!o){p=n;gGC(9706056,p|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];p=c[3528484]|0;c[2076596]=p;q=c[2417276]|0;c[3541536]=q;c[1836236]=0;r=J&31;J=c[2411304]|0;K=(r<<14)-16384|0;e=64;h=64;while(1){c[n+76+(h<<2)>>2]=J+(K+(h<<8));j=e+1&65535;if((j&65535)>127){L=64;M=64;break}else{e=j;h=j&65535}}while(1){h=J+(K+(M<<8))|0;c[n+76+(M+512<<2)>>2]=h;c[n+76+(M+768<<2)>>2]=h;h=L+1&65535;if((h&65535)>127){break}else{L=h;M=h&65535}}c[2440570]=r;if(!o){o=n;gGC(o|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=p;c[2417276]=q;c[1836236]=-1;a[14168416]=1;i=g;return 0}function avx(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1407220+(b*112|0)>>2];c[a+104>>2]=c[1407224+(b*112|0)>>2];c[a+108>>2]=c[1407228+(b*112|0)>>2];d=0;return d|0}function avy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=1407120+(b*112|0);e=0;return e|0}function avz(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1415284+(b*112|0)>>2];c[a+104>>2]=c[1415288+(b*112|0)>>2];c[a+108>>2]=c[1415292+(b*112|0)>>2];d=0;return d|0}function avA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=1415184+(b*112|0);e=0;return e|0}function avB(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1413268+(b*112|0)>>2];c[a+104>>2]=c[1413272+(b*112|0)>>2];c[a+108>>2]=c[1413276+(b*112|0)>>2];d=0;return d|0}function avC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=1413168+(b*112|0);e=0;return e|0}function avD(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1409236+(b*112|0)>>2];c[a+104>>2]=c[1409240+(b*112|0)>>2];c[a+108>>2]=c[1409244+(b*112|0)>>2];d=0;return d|0}function avE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=1409136+(b*112|0);e=0;return e|0}function avF(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1417300+(b*112|0)>>2];c[a+104>>2]=c[1417304+(b*112|0)>>2];c[a+108>>2]=c[1417308+(b*112|0)>>2];d=0;return d|0}function avG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=1417200+(b*112|0);e=0;return e|0}function avH(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1411252+(b*112|0)>>2];c[a+104>>2]=c[1411256+(b*112|0)>>2];c[a+108>>2]=c[1411260+(b*112|0)>>2];d=0;return d|0}function avI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=1411152+(b*112|0);e=0;return e|0}function avJ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1012804+(b*112|0)>>2];c[a+104>>2]=c[1012808+(b*112|0)>>2];c[a+108>>2]=c[1012812+(b*112|0)>>2];d=0;return d|0}function avK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=1012704+(b*112|0);e=0;return e|0}function avL(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1018852+(b*112|0)>>2];c[a+104>>2]=c[1018856+(b*112|0)>>2];c[a+108>>2]=c[1018860+(b*112|0)>>2];d=0;return d|0}function avM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=1018752+(b*112|0);e=0;return e|0}function avN(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1016836+(b*112|0)>>2];c[a+104>>2]=c[1016840+(b*112|0)>>2];c[a+108>>2]=c[1016844+(b*112|0)>>2];d=0;return d|0}function avO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=1016736+(b*112|0);e=0;return e|0}function avP(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1014820+(b*112|0)>>2];c[a+104>>2]=c[1014824+(b*112|0)>>2];c[a+108>>2]=c[1014828+(b*112|0)>>2];d=0;return d|0}function avQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=1014720+(b*112|0);e=0;return e|0}function avR(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1020868+(b*112|0)>>2];c[a+104>>2]=c[1020872+(b*112|0)>>2];c[a+108>>2]=c[1020876+(b*112|0)>>2];d=0;return d|0}function avS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=1020768+(b*112|0);e=0;return e|0}function avT(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4852628+(b*112|0)>>2];c[a+104>>2]=c[4852632+(b*112|0)>>2];c[a+108>>2]=c[4852636+(b*112|0)>>2];d=0;return d|0}function avU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=4852528+(b*112|0);e=0;return e|0}function avV(){a[9536]=1;return av4()|0}function avW(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3175060+(b*112|0)>>2];c[a+104>>2]=c[3175064+(b*112|0)>>2];c[a+108>>2]=c[3175068+(b*112|0)>>2];d=0;return d|0}function avX(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=3174960+(b*112|0);e=0;return e|0}function avY(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3178756+(b*112|0)>>2];c[a+104>>2]=c[3178760+(b*112|0)>>2];c[a+108>>2]=c[3178764+(b*112|0)>>2];d=0;return d|0}function avZ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=3178656+(b*112|0);e=0;return e|0}function av_(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3177524+(b*112|0)>>2];c[a+104>>2]=c[3177528+(b*112|0)>>2];c[a+108>>2]=c[3177532+(b*112|0)>>2];d=0;return d|0}function av$(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=3177424+(b*112|0);e=0;return e|0}function av0(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3176292+(b*112|0)>>2];c[a+104>>2]=c[3176296+(b*112|0)>>2];c[a+108>>2]=c[3176300+(b*112|0)>>2];d=0;return d|0}function av1(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=3176192+(b*112|0);e=0;return e|0}function av2(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3179988+(b*112|0)>>2];c[a+104>>2]=c[3179992+(b*112|0)>>2];c[a+108>>2]=c[3179996+(b*112|0)>>2];d=0;return d|0}function av3(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=3179888+(b*112|0);e=0;return e|0}function av4(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0;e=i;i=i+3720|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;B=e+1200|0;C=e+1312|0;D=e+1320|0;E=e+1432|0;F=e+1440|0;G=e+1552|0;H=e+1560|0;I=e+1672|0;J=e+1680|0;K=e+1792|0;L=e+1800|0;M=e+1912|0;N=e+1920|0;O=e+2032|0;P=e+2040|0;Q=e+2152|0;R=e+2160|0;S=e+2272|0;T=e+2280|0;U=e+2392|0;V=e+2400|0;W=e+2512|0;X=e+2520|0;Y=e+2632|0;Z=e+2640|0;_=e+2752|0;$=e+2760|0;aa=e+2872|0;ab=e+2880|0;ac=e+2992|0;ad=e+3e3|0;ae=e+3112|0;af=e+3120|0;ag=e+3232|0;ah=e+3240|0;ai=e+3352|0;aj=e+3360|0;ak=e+3472|0;al=e+3480|0;am=e+3592|0;an=e+3600|0;ao=e+3712|0;c[2424]=5755;c[2426710]=0;c[2418148]=0;c[2418092]=524288;c[2411304]=2621440;c[3542098]=3145728;c[3542090]=11534336;c[3542091]=15728640;ap=a[9536]|0;c[3542092]=19922944;aq=ap?24117248:40894464;c[3541206]=aq;c[2388312]=aq+4194304;ap=aq+4194432|0;c[2405644]=ap;c[2418262]=ap;c[2418206]=aq+4259970;c[2418192]=aq+4292738;c[2411346]=aq+4309124;c[3542094]=aq+4317316;c[3542095]=aq+4350084;c[3542096]=aq+4382852;c[3542100]=aq+4415622;c[3542108]=aq+4481160;ap=aq+4546696|0;c[2411632]=ap;c[2414174]=ap;aq=ap;ap=0;while(1){if((ap|0)>=1024){break}ar=9638528+(ap<<2)|0;if((c[ar>>2]|0)==0){as=13169;break}else{ap=ap+1|0}}do{if((as|0)==13169){ap=gGq(aq)|0;c[ar>>2]=ap;if((ap|0)==0){break}gGz(ap|0,0,aq|0);c[2426710]=ap;gGz(ap|0,0,aq|0);c[2418148]=ap;c[2418092]=ap+524288;c[2411304]=ap+2621440;c[3542098]=ap+3145728;c[3542090]=ap+11534336;c[3542091]=ap+15728640;at=a[9536]|0;c[3542092]=ap+19922944;au=at?ap+24117248|0:ap+40894464|0;c[3541206]=au;c[2388312]=au+4194304;av=au+4194432|0;c[2405644]=av;c[2418262]=av;c[2418206]=au+4259970;c[2418192]=au+4292738;c[2411346]=au+4309124;c[3542094]=au+4317316;c[3542095]=au+4350084;c[3542096]=au+4382852;c[3542100]=au+4415622;c[3542108]=au+4481160;av=au+4546696|0;c[2411632]=av;c[2414174]=av;do{if((c[3542200]|0)!=0){av=an+108|0;c[av>>2]=0;au=an+100|0;c[au>>2]=0;aw=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aw&16383](an,0)|0;if((c[av>>2]|0)==0){break}av=c[au>>2]|0;c[ao>>2]=9534384;au=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[au&16383](ao,0,0)|0;if((av|0)<1){break}gzL(ap,0,0)|0}}while(0);do{if(at){ap=c[2411304]|0;do{if((c[3542200]|0)!=0){av=al+108|0;c[av>>2]=0;au=al+100|0;c[au>>2]=0;aw=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aw&16383](al,1)|0;if((c[av>>2]|0)==0){break}av=c[au>>2]|0;c[am>>2]=9534384;au=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[au&16383](am,1,0)|0;if((av|0)<1){break}gzL(ap,0,1)|0}}while(0);ap=c[3542098]|0;do{if((c[3542200]|0)!=0){av=aj+108|0;c[av>>2]=0;au=aj+100|0;c[au>>2]=0;aw=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aw&16383](aj,2)|0;if((c[av>>2]|0)==0){break}av=c[au>>2]|0;c[ak>>2]=9534384;au=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[au&16383](ak,2,0)|0;if((av|0)<1){break}gzL(ap,0,2)|0}}while(0);ap=(c[3542098]|0)+2097152|0;do{if((c[3542200]|0)!=0){av=ah+108|0;c[av>>2]=0;au=ah+100|0;c[au>>2]=0;aw=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aw&16383](ah,3)|0;if((c[av>>2]|0)==0){break}av=c[au>>2]|0;c[ai>>2]=9534384;au=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[au&16383](ai,3,0)|0;if((av|0)<1){break}gzL(ap,0,3)|0}}while(0);ap=c[3542098]|0;av=ap+4194303|0;au=ap+8388606|0;ap=0;while(1){a[au]=a[av]&15;a[au+1|0]=(d[av]|0)>>>4;aw=ap+1|0;if((aw|0)<4194304){av=av-1|0;au=au-2|0;ap=aw}else{break}}ap=c[3542090]|0;do{if((c[3542200]|0)!=0){au=af+108|0;c[au>>2]=0;av=af+100|0;c[av>>2]=0;aw=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aw&16383](af,4)|0;if((c[au>>2]|0)==0){break}au=c[av>>2]|0;c[ag>>2]=9534384;av=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[av&16383](ag,4,0)|0;if((au|0)<1){break}gzL(ap,0,4)|0}}while(0);ap=c[3542090]|0;au=ap+2097151|0;av=ap+4194302|0;ap=0;while(1){a[av+1|0]=a[au]&15;a[av]=(d[au]|0)>>>4;aw=ap+1|0;if((aw|0)<2097152){au=au-1|0;av=av-2|0;ap=aw}else{break}}ap=c[3542091]|0;do{if((c[3542200]|0)!=0){av=ad+108|0;c[av>>2]=0;au=ad+100|0;c[au>>2]=0;aw=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aw&16383](ad,5)|0;if((c[av>>2]|0)==0){break}av=c[au>>2]|0;c[ae>>2]=9534384;au=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[au&16383](ae,5,0)|0;if((av|0)<1){break}gzL(ap,0,5)|0}}while(0);ap=c[3542091]|0;av=ap+2097151|0;au=ap+4194302|0;ap=0;while(1){a[au+1|0]=a[av]&15;a[au]=(d[av]|0)>>>4;aw=ap+1|0;if((aw|0)<2097152){av=av-1|0;au=au-2|0;ap=aw}else{break}}ap=c[3542092]|0;do{if((c[3542200]|0)!=0){au=ab+108|0;c[au>>2]=0;av=ab+100|0;c[av>>2]=0;aw=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aw&16383](ab,6)|0;if((c[au>>2]|0)==0){break}au=c[av>>2]|0;c[ac>>2]=9534384;av=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[av&16383](ac,6,0)|0;if((au|0)<1){break}gzL(ap,0,6)|0}}while(0);ap=c[3542092]|0;au=ap+2097151|0;av=ap+4194302|0;ap=0;while(1){a[av+1|0]=a[au]&15;a[av]=(d[au]|0)>>>4;aw=ap+1|0;if((aw|0)<2097152){au=au-1|0;av=av-2|0;ap=aw}else{ax=0;break}}while(1){if((ax|0)>=1024){ay=0;break}az=9638528+(ax<<2)|0;if((c[az>>2]|0)==0){as=13210;break}else{ax=ax+1|0}}do{if((as|0)==13210){ap=gGq(2097152)|0;c[az>>2]=ap;if((ap|0)==0){ay=0;break}gGz(ap|0,0,2097152);ay=ap}}while(0);do{if((c[3542200]|0)!=0){ap=$+108|0;c[ap>>2]=0;av=$+100|0;c[av>>2]=0;au=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[au&16383]($,7)|0;if((c[ap>>2]|0)==0){break}ap=c[av>>2]|0;c[aa>>2]=9534384;av=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[av&16383](aa,7,0)|0;if((ap|0)<1){break}gzL(ay,0,7)|0}}while(0);ap=c[3542092]|0;av=0;while(1){au=ay+av|0;aw=av<<2;aA=ap+aw|0;a[aA]=a[aA]|a[au]<<4&48;aA=ap+(aw|1)|0;a[aA]=a[aA]|a[au]<<2&48;aA=ap+(aw|2)|0;a[aA]=a[aA]|a[au]&48;aA=ap+(aw|3)|0;a[aA]=a[aA]|(d[au]|0)>>>2&48;au=av+1|0;if((au|0)<1048576){av=au}else{aB=0;break}}while(1){if((aB|0)>=1024){break}aC=9638528+(aB<<2)|0;if((c[aC>>2]|0)==(ay|0)){as=13220;break}else{aB=aB+1|0}}if((as|0)==13220){gGr(ay);c[aC>>2]=0}av=c[3541206]|0;do{if((c[3542200]|0)!=0){ap=Z+108|0;c[ap>>2]=0;au=Z+100|0;c[au>>2]=0;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aA&16383](Z,8)|0;if((c[ap>>2]|0)==0){break}ap=c[au>>2]|0;c[_>>2]=9534384;au=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[au&16383](_,8,0)|0;if((ap|0)<1){break}gzL(av,0,8)|0}}while(0);av=(c[3541206]|0)+2097152|0;do{if((c[3542200]|0)!=0){ap=X+108|0;c[ap>>2]=0;au=X+100|0;c[au>>2]=0;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aA&16383](X,9)|0;if((c[ap>>2]|0)==0){break}ap=c[au>>2]|0;c[Y>>2]=9534384;au=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[au&16383](Y,9,0)|0;if((ap|0)<1){break}gzL(av,0,9)|0}}while(0);av=c[2388312]|0;if((c[3542200]|0)==0){break}ap=V+108|0;c[ap>>2]=0;au=V+100|0;c[au>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](V,10)|0;if((c[ap>>2]|0)==0){break}ap=c[au>>2]|0;c[W>>2]=9534384;gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](W,10,0)|0;if((ap|0)<1){break}gzL(av,0,10)|0}else{av=c[2418092]|0;do{if((c[3542200]|0)!=0){ap=T+108|0;c[ap>>2]=0;au=T+100|0;c[au>>2]=0;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aA&16383](T,1)|0;if((c[ap>>2]|0)==0){break}ap=c[au>>2]|0;c[U>>2]=9534384;au=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[au&16383](U,1,0)|0;if((ap|0)<1){break}gzL(av,0,1)|0}}while(0);av=c[2411304]|0;do{if((c[3542200]|0)==0){aD=0}else{ap=R+108|0;c[ap>>2]=0;au=R+100|0;c[au>>2]=0;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aA&16383](R,2)|0;if((c[ap>>2]|0)==0){aD=0;break}ap=c[au>>2]|0;c[S>>2]=9534384;au=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[au&16383](S,2,0)|0;if((ap|0)<1){aD=0;break}gzL(av,0,2)|0;aD=0}}while(0);while(1){if((aD|0)>=1024){aE=0;break}aF=9638528+(aD<<2)|0;if((c[aF>>2]|0)==0){as=13243;break}else{aD=aD+1|0}}do{if((as|0)==13243){av=gGq(4194304)|0;c[aF>>2]=av;if((av|0)==0){aE=0;break}gGz(av|0,0,4194304);aE=av}}while(0);do{if((c[3542200]|0)!=0){av=P+108|0;c[av>>2]=0;ap=P+100|0;c[ap>>2]=0;au=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[au&16383](P,3)|0;if((c[av>>2]|0)==0){break}av=c[ap>>2]|0;c[Q>>2]=9534384;ap=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ap&16383](Q,3,0)|0;if((av|0)<1){break}gzL(aE,0,3)|0}}while(0);av=aE+2097152|0;do{if((c[3542200]|0)!=0){ap=N+108|0;c[ap>>2]=0;au=N+100|0;c[au>>2]=0;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aA&16383](N,4)|0;if((c[ap>>2]|0)==0){break}ap=c[au>>2]|0;c[O>>2]=9534384;au=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[au&16383](O,4,0)|0;if((ap|0)<1){break}gzL(av,0,4)|0}}while(0);av=c[3542098]|0;ap=0;while(1){a[av+(ap^610500)|0]=a[aE+(ap>>>15<<19&524288|ap&15736833|ap>>>10<<18&262144|ap>>>12<<17&131072|ap>>>6<<16&65536|ap>>>11<<15&32768|ap>>>1<<14&16384|ap>>>3<<12&4096|ap>>>16<<11&2048|ap>>>17<<10&1024|ap>>>2<<9&512|ap>>>5<<8&256|ap>>>14<<7&128|ap>>>7<<6&64|ap>>>18<<5&32|ap>>>8<<4&16|ap>>>4<<3&8|ap>>>19<<2&4|ap>>>9<<1&2)|0]|0;au=ap+1|0;if((au|0)<4194304){ap=au}else{aG=0;break}}while(1){if((aG|0)>=1024){aH=av;break}aI=9638528+(aG<<2)|0;if((c[aI>>2]|0)==(aE|0)){as=13257;break}else{aG=aG+1|0}}if((as|0)==13257){gGr(aE);c[aI>>2]=0;aH=c[3542098]|0}av=aH+4194303|0;ap=aH+8388606|0;au=0;while(1){a[ap]=a[av]&15;a[ap+1|0]=(d[av]|0)>>>4;aA=au+1|0;if((aA|0)<4194304){av=av-1|0;ap=ap-2|0;au=aA}else{break}}au=c[3542090]|0;do{if((c[3542200]|0)!=0){ap=L+108|0;c[ap>>2]=0;av=L+100|0;c[av>>2]=0;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aA&16383](L,5)|0;if((c[ap>>2]|0)==0){break}ap=c[av>>2]|0;c[M>>2]=9534384;av=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[av&16383](M,5,0)|0;if((ap|0)<1){break}gzL(au,0,5)|0}}while(0);au=c[3542090]|0;ap=au+2097151|0;av=au+4194302|0;au=0;while(1){a[av+1|0]=a[ap]&15;a[av]=(d[ap]|0)>>>4;aA=au+1|0;if((aA|0)<2097152){ap=ap-1|0;av=av-2|0;au=aA}else{break}}au=c[3542091]|0;do{if((c[3542200]|0)!=0){av=J+108|0;c[av>>2]=0;ap=J+100|0;c[ap>>2]=0;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aA&16383](J,6)|0;if((c[av>>2]|0)==0){break}av=c[ap>>2]|0;c[K>>2]=9534384;ap=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ap&16383](K,6,0)|0;if((av|0)<1){break}gzL(au,0,6)|0}}while(0);au=c[3542091]|0;av=au+2097151|0;ap=au+4194302|0;au=0;while(1){a[ap+1|0]=a[av]&15;a[ap]=(d[av]|0)>>>4;aA=au+1|0;if((aA|0)<2097152){av=av-1|0;ap=ap-2|0;au=aA}else{break}}au=c[3542092]|0;do{if((c[3542200]|0)!=0){ap=H+108|0;c[ap>>2]=0;av=H+100|0;c[av>>2]=0;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aA&16383](H,7)|0;if((c[ap>>2]|0)==0){break}ap=c[av>>2]|0;c[I>>2]=9534384;av=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[av&16383](I,7,0)|0;if((ap|0)<1){break}gzL(au,0,7)|0}}while(0);au=(c[3542092]|0)+2097152|0;do{if((c[3542200]|0)!=0){ap=F+108|0;c[ap>>2]=0;av=F+100|0;c[av>>2]=0;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aA&16383](F,8)|0;if((c[ap>>2]|0)==0){break}ap=c[av>>2]|0;c[G>>2]=9534384;av=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[av&16383](G,8,0)|0;if((ap|0)<1){break}gzL(au,0,8)|0}}while(0);au=(c[3542092]|0)+4194304|0;do{if((c[3542200]|0)!=0){ap=D+108|0;c[ap>>2]=0;av=D+100|0;c[av>>2]=0;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aA&16383](D,9)|0;if((c[ap>>2]|0)==0){break}ap=c[av>>2]|0;c[E>>2]=9534384;av=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[av&16383](E,9,0)|0;if((ap|0)<1){break}gzL(au,0,9)|0}}while(0);au=(c[3542092]|0)+6291456|0;do{if((c[3542200]|0)!=0){ap=B+108|0;c[ap>>2]=0;av=B+100|0;c[av>>2]=0;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aA&16383](B,10)|0;if((c[ap>>2]|0)==0){break}ap=c[av>>2]|0;c[C>>2]=9534384;av=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[av&16383](C,10,0)|0;if((ap|0)<1){break}gzL(au,0,10)|0}}while(0);au=(c[3542092]|0)+8388608|0;do{if((c[3542200]|0)!=0){ap=z+108|0;c[ap>>2]=0;av=z+100|0;c[av>>2]=0;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aA&16383](z,11)|0;if((c[ap>>2]|0)==0){break}ap=c[av>>2]|0;c[A>>2]=9534384;av=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[av&16383](A,11,0)|0;if((ap|0)<1){break}gzL(au,0,11)|0}}while(0);au=c[3542092]|0;ap=au+10485759|0;av=au+20971518|0;au=0;while(1){a[av+1|0]=a[ap]&15;a[av]=(d[ap]|0)>>>4;aA=au+1|0;if((aA|0)<10485760){ap=ap-1|0;av=av-2|0;au=aA}else{aJ=0;break}}while(1){if((aJ|0)>=1024){aK=0;break}aL=9638528+(aJ<<2)|0;if((c[aL>>2]|0)==0){as=13296;break}else{aJ=aJ+1|0}}do{if((as|0)==13296){au=gGq(6291456)|0;c[aL>>2]=au;if((au|0)==0){aK=0;break}gGz(au|0,0,6291456);aK=au}}while(0);do{if((c[3542200]|0)!=0){au=x+108|0;c[au>>2]=0;av=x+100|0;c[av>>2]=0;ap=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ap&16383](x,12)|0;if((c[au>>2]|0)==0){break}au=c[av>>2]|0;c[y>>2]=9534384;av=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[av&16383](y,12,0)|0;if((au|0)<1){break}gzL(aK,0,12)|0}}while(0);au=aK+2097152|0;do{if((c[3542200]|0)!=0){av=v+108|0;c[av>>2]=0;ap=v+100|0;c[ap>>2]=0;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aA&16383](v,13)|0;if((c[av>>2]|0)==0){break}av=c[ap>>2]|0;c[w>>2]=9534384;ap=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ap&16383](w,13,0)|0;if((av|0)<1){break}gzL(au,0,13)|0}}while(0);au=aK+4194304|0;do{if((c[3542200]|0)!=0){av=t+108|0;c[av>>2]=0;ap=t+100|0;c[ap>>2]=0;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aA&16383](t,14)|0;if((c[av>>2]|0)==0){break}av=c[ap>>2]|0;c[u>>2]=9534384;ap=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ap&16383](u,14,0)|0;if((av|0)<1){break}gzL(au,0,14)|0}}while(0);au=c[3542092]|0;av=0;while(1){ap=aK+av|0;aA=av<<2;aw=au+aA|0;a[aw]=a[aw]|a[ap]<<4&48;aw=au+(aA|1)|0;a[aw]=a[aw]|a[ap]<<2&48;aw=au+(aA|2)|0;a[aw]=a[aw]|a[ap]&48;aw=au+(aA|3)|0;a[aw]=a[aw]|(d[ap]|0)>>>2&48;ap=av+1|0;if((ap|0)<5242880){av=ap}else{aM=0;break}}while(1){if((aM|0)>=1024){break}aN=9638528+(aM<<2)|0;if((c[aN>>2]|0)==(aK|0)){as=13314;break}else{aM=aM+1|0}}if((as|0)==13314){gGr(aK);c[aN>>2]=0}av=c[3541206]|0;do{if((c[3542200]|0)!=0){au=r+108|0;c[au>>2]=0;ap=r+100|0;c[ap>>2]=0;aw=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aw&16383](r,15)|0;if((c[au>>2]|0)==0){break}au=c[ap>>2]|0;c[s>>2]=9534384;ap=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ap&16383](s,15,0)|0;if((au|0)<1){break}gzL(av,0,15)|0}}while(0);av=(c[3541206]|0)+2097152|0;do{if((c[3542200]|0)!=0){au=p+108|0;c[au>>2]=0;ap=p+100|0;c[ap>>2]=0;aw=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aw&16383](p,16)|0;if((c[au>>2]|0)==0){break}au=c[ap>>2]|0;c[q>>2]=9534384;ap=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ap&16383](q,16,0)|0;if((au|0)<1){break}gzL(av,0,16)|0}}while(0);av=(c[3541206]|0)+2621440|0;do{if((c[3542200]|0)!=0){au=n+108|0;c[au>>2]=0;ap=n+100|0;c[ap>>2]=0;aw=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aw&16383](n,16)|0;if((c[au>>2]|0)==0){break}au=c[ap>>2]|0;c[o>>2]=9534384;ap=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ap&16383](o,16,0)|0;if((au|0)<1){break}gzL(av,0,16)|0}}while(0);av=(c[3541206]|0)+3145728|0;do{if((c[3542200]|0)!=0){au=l+108|0;c[au>>2]=0;ap=l+100|0;c[ap>>2]=0;aw=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aw&16383](l,16)|0;if((c[au>>2]|0)==0){break}au=c[ap>>2]|0;c[m>>2]=9534384;ap=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ap&16383](m,16,0)|0;if((au|0)<1){break}gzL(av,0,16)|0}}while(0);av=(c[3541206]|0)+3670016|0;do{if((c[3542200]|0)!=0){au=j+108|0;c[au>>2]=0;ap=j+100|0;c[ap>>2]=0;aw=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aw&16383](j,16)|0;if((c[au>>2]|0)==0){break}au=c[ap>>2]|0;c[k>>2]=9534384;ap=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ap&16383](k,16,0)|0;if((au|0)<1){break}gzL(av,0,16)|0}}while(0);av=c[2388312]|0;if((c[3542200]|0)==0){break}au=f+108|0;c[au>>2]=0;ap=f+100|0;c[ap>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,17)|0;if((c[au>>2]|0)==0){break}au=c[ap>>2]|0;c[g>>2]=9534384;gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](g,17,0)|0;if((au|0)<1){break}gzL(av,0,17)|0}}while(0);fxU(0,425984);if((c[2394]|0)==0){aO=c[2112932]|0}else{c[2394]=0;at=c[3532596]|0;c[2112932]=at;av=c[3532592]|0;if((av|0)!=0){gGC(9104152,av|0,280)|0}c[2113054]=c[2113060];aO=at}at=c[2418148]|0;av=aO|0;au=0;while(1){ap=at+au|0;c[av>>2]=ap;c[av+131072>>2]=ap;ap=au+1024|0;if(ap>>>0>524287){break}else{av=av+4|0;au=ap}}au=c[2418262]|0;av=aO+4096|0;at=1048576;while(1){ap=au+(at-1048576)|0;c[av>>2]=ap;c[av+65536>>2]=ap;c[av+131072>>2]=ap;ap=at+1024|0;if(ap>>>0>1114113){break}else{av=av+4|0;at=ap}}at=c[2418092]|0;av=aO+8192|0;au=2097152;while(1){ap=at+(au-2097152)|0;c[av>>2]=ap;c[av+131072>>2]=ap;ap=au+1024|0;if(ap>>>0>4194303){break}else{av=av+4|0;au=ap}}au=c[2418206]|0;av=aO+16384|0;at=4194304;while(1){ap=au+(at-4194304)|0;c[av>>2]=ap;c[av+65536>>2]=ap;c[av+131072>>2]=ap;ap=at+1024|0;if(ap>>>0>4227071){break}else{av=av+4|0;at=ap}}at=c[2418192]|0;c[aO+16576>>2]=at;c[aO+82112>>2]=at;c[aO+147648>>2]=at;av=at+1024|0;c[aO+16580>>2]=av;c[aO+82116>>2]=av;c[aO+147652>>2]=av;av=at+2048|0;c[aO+16584>>2]=av;c[aO+82120>>2]=av;c[aO+147656>>2]=av;av=at+3072|0;c[aO+16588>>2]=av;c[aO+82124>>2]=av;c[aO+147660>>2]=av;av=at+4096|0;c[aO+16592>>2]=av;c[aO+82128>>2]=av;c[aO+147664>>2]=av;av=at+5120|0;c[aO+16596>>2]=av;c[aO+82132>>2]=av;c[aO+147668>>2]=av;av=at+6144|0;c[aO+16600>>2]=av;c[aO+82136>>2]=av;c[aO+147672>>2]=av;av=at+7168|0;c[aO+16604>>2]=av;c[aO+82140>>2]=av;c[aO+147676>>2]=av;av=at+8192|0;c[aO+16608>>2]=av;c[aO+82144>>2]=av;c[aO+147680>>2]=av;av=at+9216|0;c[aO+16612>>2]=av;c[aO+82148>>2]=av;c[aO+147684>>2]=av;av=at+10240|0;c[aO+16616>>2]=av;c[aO+82152>>2]=av;c[aO+147688>>2]=av;av=at+11264|0;c[aO+16620>>2]=av;c[aO+82156>>2]=av;c[aO+147692>>2]=av;av=at+12288|0;c[aO+16624>>2]=av;c[aO+82160>>2]=av;c[aO+147696>>2]=av;av=at+13312|0;c[aO+16628>>2]=av;c[aO+82164>>2]=av;c[aO+147700>>2]=av;av=at+14336|0;c[aO+16632>>2]=av;c[aO+82168>>2]=av;c[aO+147704>>2]=av;av=at+15360|0;c[aO+16636>>2]=av;c[aO+82172>>2]=av;c[aO+147708>>2]=av;av=at+16384|0;c[aO+16640>>2]=av;c[aO+82176>>2]=av;c[aO+147712>>2]=av;av=c[3542100]|0;at=aO+20480|0;au=5242880;while(1){ap=av+(au-5242880)|0;c[at>>2]=ap;c[at+65536>>2]=ap;c[at+131072>>2]=ap;ap=au+1024|0;if(ap>>>0>5308417){break}else{at=at+4|0;au=ap}}au=c[3542094]|0;at=aO+32768|0;av=8388608;while(1){ap=au+(av-8388608)|0;c[at>>2]=ap;c[at+65536>>2]=ap;c[at+131072>>2]=ap;ap=av+1024|0;if(ap>>>0>8421375){break}else{at=at+4|0;av=ap}}av=c[3542095]|0;at=aO+34816|0;au=8912896;while(1){ap=av+(au-8912896)|0;c[at>>2]=ap;c[at+65536>>2]=ap;c[at+131072>>2]=ap;ap=au+1024|0;if(ap>>>0>8945663){break}else{at=at+4|0;au=ap}}au=c[3542096]|0;at=aO+36864|0;av=9437184;while(1){ap=au+(av-9437184)|0;c[at>>2]=ap;c[at+65536>>2]=ap;c[at+131072>>2]=ap;ap=av+1024|0;if(ap>>>0>9469953){break}else{at=at+4|0;av=ap}}av=c[3542108]|0;c[aO+16512>>2]=av;c[aO+82048>>2]=av;c[aO+147584>>2]=av;at=av+1024|0;c[aO+16516>>2]=at;c[aO+82052>>2]=at;c[aO+147588>>2]=at;at=av+34816|0;c[aO+16520>>2]=at;c[aO+147592>>2]=at;at=av+35840|0;c[aO+16524>>2]=at;c[aO+147596>>2]=at;at=av+36864|0;c[aO+16528>>2]=at;c[aO+147600>>2]=at;at=av+37888|0;c[aO+16532>>2]=at;c[aO+147604>>2]=at;at=av+38912|0;c[aO+16536>>2]=at;c[aO+147608>>2]=at;at=av+39936|0;c[aO+16540>>2]=at;c[aO+147612>>2]=at;at=av+40960|0;c[aO+16544>>2]=at;c[aO+147616>>2]=at;at=av+41984|0;c[aO+16548>>2]=at;c[aO+147620>>2]=at;at=av+43008|0;c[aO+16552>>2]=at;c[aO+147624>>2]=at;at=av+44032|0;c[aO+16556>>2]=at;c[aO+147628>>2]=at;at=av+45056|0;c[aO+16560>>2]=at;c[aO+147632>>2]=at;at=av+46080|0;c[aO+16564>>2]=at;c[aO+147636>>2]=at;at=av+47104|0;c[aO+16568>>2]=at;c[aO+147640>>2]=at;at=av+48128|0;c[aO+16572>>2]=at;c[aO+147644>>2]=at;c[aO+82056>>2]=1;c[aO+82060>>2]=1;c[aO+82064>>2]=1;c[aO+82068>>2]=1;c[aO+82072>>2]=1;c[aO+82076>>2]=1;c[aO+82080>>2]=1;c[aO+82084>>2]=1;c[aO+82088>>2]=1;c[aO+82092>>2]=1;c[aO+82096>>2]=1;c[aO+82100>>2]=1;c[aO+82104>>2]=1;c[aO+82108>>2]=1;c[aO+196688>>2]=588;c[aO+196608>>2]=946;c[aO+196728>>2]=2688;c[aO+196648>>2]=186;c[aO+196732>>2]=906;c[aO+196652>>2]=2576;at=c[3532592]|0;if((at|0)!=0){gGC(at|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);at=c[2439330]|0;av=(at|0)==0;if(!av){au=at;gGC(9706056,au|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];au=c[3528484]|0;c[2076596]=au;ap=c[2417276]|0;c[3541536]=ap;c[1836236]=0;c[at+4172>>2]=2730;c[at+4176>>2]=1142;aw=c[2411304]|0;aA=0;aP=0;while(1){c[at+76+(aP<<2)>>2]=aw+(aP<<8);aQ=aA+1&65535;if((aQ&65535)>63){aR=0;aS=0;break}else{aA=aQ;aP=aQ&65535}}while(1){aP=aw+(aS<<8)|0;c[at+76+(aS+512<<2)>>2]=aP;c[at+76+(aS+768<<2)>>2]=aP;aP=aR+1&65535;if((aP&65535)>63){aT=64;aU=64;break}else{aR=aP;aS=aP&65535}}while(1){c[at+76+(aU<<2)>>2]=aw+((aU<<8)-16384);aP=aT+1&65535;if((aP&65535)>127){aV=64;aW=64;break}else{aT=aP;aU=aP&65535}}while(1){aP=aw+((aW<<8)-16384)|0;c[at+76+(aW+512<<2)>>2]=aP;c[at+76+(aW+768<<2)>>2]=aP;aP=aV+1&65535;if((aP&65535)>127){break}else{aV=aP;aW=aP&65535}}aw=c[2411346]|0;aP=192;aA=192;while(1){c[at+76+(aA<<2)>>2]=aw+((aA<<8)-49152);aQ=aP+1&65535;if((aQ&65535)>223){aX=192;aY=192;break}else{aP=aQ;aA=aQ&65535}}while(1){c[at+76+(aY+256<<2)>>2]=aw+((aY<<8)-49152);aA=aX+1&65535;if((aA&65535)>223){aZ=192;a_=192;break}else{aX=aA;aY=aA&65535}}while(1){aA=aw+((a_<<8)-49152)|0;c[at+76+(a_+512<<2)>>2]=aA;c[at+76+(a_+768<<2)>>2]=aA;aA=aZ+1&65535;if((aA&65535)>223){a$=224;a0=224;break}else{aZ=aA;a_=aA&65535}}while(1){c[at+76+(a0<<2)>>2]=aw+((a0<<8)-57344);aA=a$+1&65535;if((aA&65535)>255){a1=224;a2=224;break}else{a$=aA;a0=aA&65535}}while(1){c[at+76+(a2+256<<2)>>2]=aw+((a2<<8)-57344);aA=a1+1&65535;if((aA&65535)>255){a3=224;a4=224;break}else{a1=aA;a2=aA&65535}}while(1){aA=aw+((a4<<8)-57344)|0;c[at+76+(a4+512<<2)>>2]=aA;c[at+76+(a4+768<<2)>>2]=aA;aA=a3+1&65535;if((aA&65535)>255){break}else{a3=aA;a4=aA&65535}}if(!av){aw=at;gGC(aw|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=au;c[2417276]=ap;c[1836236]=-1;c[2113294]=-1;c[2113290]=2;aw=0;while(1){if((aw|0)>=1024){a5=0;break}a6=9638528+(aw<<2)|0;if((c[a6>>2]|0)==0){as=13381;break}else{aw=aw+1|0}}do{if((as|0)==13381){aw=gGq(131072)|0;c[a6>>2]=aw;if((aw|0)==0){a5=0;break}gGz(aw|0,0,131072);a5=aw}}while(0);c[3542106]=a5;gGz(a5|0,0,131072);aw=0;while(1){if((aw|0)>=1024){a7=0;break}a8=9638528+(aw<<2)|0;if((c[a8>>2]|0)==0){as=13386;break}else{aw=aw+1|0}}do{if((as|0)==13386){aw=gGq(65536)|0;c[a8>>2]=aw;if((aw|0)==0){a7=0;break}gGz(aw|0,0,65536);a7=aw}}while(0);c[3527514]=a7;gGz(a7|0,0,65536);c[2112966]=c[3542106];c[3542078]=0;c[3542079]=0;c[3542080]=16;c[3542081]=0;c[3542082]=0;c[3542083]=16;c[3542084]=0;c[3542085]=0;c[3542086]=16;c[3542087]=0;c[3542088]=0;c[3542089]=16;c[2113284]=0;aw=c[642608+(c[2436]<<2)>>2]|0;if((c[aw+52>>2]&4|0)==0){ap=c[aw+128>>2]|0;c[2113280]=ap;a9=aw+132|0;ba=ap}else{ap=c[aw+132>>2]|0;c[2113280]=ap;a9=aw+128|0;ba=ap}ap=c[a9>>2]|0;c[2113276]=ap;c[2406716]=ba-8;c[2394778]=ba-16;c[2406714]=ap-8;c[2394776]=ap-16;c[3528974]=c[3564288+(((ba|0)!=320)<<2)>>2];if(a[9536]|0){auH(1,8388608)}else{auH(2,8388608)}axI(0,4194304,4,17408);axI(1,4194304,4,18432);if(a[9536]|0){axI(2,4194304,6,19456)}else{axI(2,20971520,6,19456)}ap=a[9680]|0;aw=ap?32e3:0;if(ap){if(a[9624]|0){ap=aw*3|0;au=62500;while(1){if((au|0)>(ap|0)){au=au>>1}else{bb=1222;bc=au;break}}}else{bb=2462;bc=aw}c[2429380]=bc;c[3542124]=bb;mw(4e6,bc);au=gGq(262144)|0;c[2406684]=au;gGz(au|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(4e6,11025)}c[(c[3531464]|0)+44344>>2]=578;h[745421]=.3;c[2436794]=1;h[745420]=.3;c[2436792]=2;Ux(0,16e3,1);Ux(1,16e3,1);c[2407030]=256;c[2407068]=3;c[2407069]=256;c[2407107]=3;Tq(690016);if(!(a[1040128]|0)){au=c[2388312]|0;gGC(14100392,au|0,128)|0}a[7072768]=1;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];au=c[3532592]|0;if((au|0)!=0){gGC(9104152,au|0,280)|0}c[2113054]=c[2113060]}RI();au=c[2394]|0;ap=c[14130368+(au<<2)>>2]|0;if((ap|0)!=0){gGC(ap|0,9104152,280)|0}c[8452240+(au<<2)>>2]=c[2113054];c[2394]=-1;c[2440570]=-1;au=c[2439330]|0;ap=(au|0)==0;if(!ap){at=au;gGC(9706056,at|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];at=c[3528484]|0;c[2076596]=at;av=c[2417276]|0;c[3541536]=av;c[1836236]=0;aA=c[2411304]|0;aP=64;aQ=64;while(1){c[au+76+(aQ<<2)>>2]=aA+((aQ<<8)-16384);bd=aP+1&65535;if((bd&65535)>127){be=64;bf=64;break}else{aP=bd;aQ=bd&65535}}while(1){aQ=aA+((bf<<8)-16384)|0;c[au+76+(bf+512<<2)>>2]=aQ;c[au+76+(bf+768<<2)>>2]=aQ;aQ=be+1&65535;if((aQ&65535)>127){break}else{be=aQ;bf=aQ&65535}}c[2440570]=0;gGz(9706056,0,76);if(!ap){aA=au;gGC(aA|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=at;c[2417276]=av;c[1836236]=-1;c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];a[9541744]=1;a[9541976]=1;a[9775200]=1;c[3528932]=0;c[2433328]=12;gGz(9747456,0,192);c[2429480]=0;c[2430066]=-1;c[2433568]=0;c[2433570]=0;c[2113156]=0;a[9628264]=0;c[2407033]=0;aA=c[3541206]|0;c[3541190]=aA;c[3541198]=aA;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=aA+256;c[3541199]=aA+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=aA+512;c[3541200]=aA+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=aA+768;c[3541201]=aA+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2113157]=0;a[9628420]=0;c[2407072]=0;aQ=aA+1048576|0;c[3541194]=aQ;c[3541202]=aQ;gGz(c[2430122]|0,0,16384);c[2407080]=4;c[3541195]=aA+1048832;c[3541203]=aA+1114112;gGz(c[2430123]|0,0,16384);c[2407088]=4;c[3541196]=aA+1049088;c[3541204]=aA+1179648;gGz(c[2430124]|0,0,16384);c[2407096]=4;c[3541197]=aA+1049344;c[3541205]=aA+1245184;gGz(c[2430125]|0,0,16384);c[2407104]=4;mx(0);bg=0;i=e;return bg|0}}while(0);c[2426710]=0;bg=1;i=e;return bg|0}function av5(b){b=b|0;a[9706117]=(b|0)!=0|0;return}function av6(d){d=d|0;var f=0,g=0,h=0,i=0,j=0;if((d|0)==11534339){f=~(b[4812821]&255);return f|0}else if((d|0)==3145731){g=c[2113010]|0;c[2113010]=0;c[2430402]=0;h=c[3531294]|0;if((h|0)!=0){gf[h&2047](0)}f=g&255;return f|0}else if((d|0)==8388608|(d|0)==8388609|(d|0)==8388610|(d|0)==8388611){f=a[9775192]<<1|a[9541736];return f|0}else if((d|0)==11534336){f=((e[4812820]|0)>>>8^255)&255;return f|0}else if((d|0)==11534337){f=~(b[4812820]&255);return f|0}else if((d|0)==8388614|(d|0)==8388615){g=a[9541736]|0;h=a[9775192]<<1|g;a[9775192]=1;i=g<<24>>24==0|(a[9541968]|0)==0;a[9775656]=i&1;g=8452200+(c[2394]<<2)|0;if(!i){c[g>>2]=0;c[2276080]=0;f=h;return f|0}c[g>>2]=4097;c[2276080]=256;if((c[2276079]|0)>>>0>=256){f=h;return f|0}RH(1);f=h;return f|0}else if((d|0)==8388612|(d|0)==8388613){h=a[9775192]|0;g=h<<1|a[9541736];a[9541736]=1;i=(a[9541968]|0)==0|h<<24>>24==0;a[9775656]=i&1;h=8452200+(c[2394]<<2)|0;if(!i){c[h>>2]=0;c[2276080]=0;f=g;return f|0}c[h>>2]=4097;c[2276080]=256;if((c[2276079]|0)>>>0>=256){f=g;return f|0}RH(1);f=g;return f|0}else if((d|0)==11534338){d=(e[4812821]|0)>>>8;do{if((c[2406632]|0)==0){g=c[2443744]|0;if((g|0)<=0){j=8;break}c[2443744]=g-1;j=0}else{j=(c[2432962]|0)>>>((c[(c[2420380]|0)+4>>2]|0)>>>0)<<3&8}}while(0);f=((j|d)^247)&255;return f|0}else{f=0;return f|0}return 0}function av7(d){d=d|0;var f=0,g=0,h=0,i=0,j=0;if((d|0)==3145730){f=c[2113010]|0;c[2113010]=0;c[2430402]=0;g=c[3531294]|0;if((g|0)!=0){gf[g&2047](0)}h=f&65535;return h|0}else if((d|0)==8388608|(d|0)==8388610){h=(a[9775192]<<1|a[9541736])&255;return h|0}else if((d|0)==8388612){f=a[9775192]|0;g=f<<1|a[9541736];a[9541736]=1;i=(a[9541968]|0)==0|f<<24>>24==0;a[9775656]=i&1;f=8452200+(c[2394]<<2)|0;do{if(i){c[f>>2]=4097;c[2276080]=256;if((c[2276079]|0)>>>0>=256){break}RH(1)}else{c[f>>2]=0;c[2276080]=0}}while(0);h=g&255;return h|0}else if((d|0)==8388614){g=a[9541736]|0;f=a[9775192]<<1|g;a[9775192]=1;i=g<<24>>24==0|(a[9541968]|0)==0;a[9775656]=i&1;g=8452200+(c[2394]<<2)|0;do{if(i){c[g>>2]=4097;c[2276080]=256;if((c[2276079]|0)>>>0>=256){break}RH(1)}else{c[g>>2]=0;c[2276080]=0}}while(0);h=f&255;return h|0}else if((d|0)==11534338){f=e[4812821]|0;do{if((c[2406632]|0)==0){g=c[2443744]|0;if((g|0)<=0){j=2048;break}c[2443744]=g-1;j=0}else{j=(c[2432962]|0)>>>((c[(c[2420380]|0)+4>>2]|0)>>>0)<<11&2048}}while(0);h=((j|f)^63487)&65535;return h|0}else if((d|0)==11534336){h=~b[4812820];return h|0}else{h=0;return h|0}return 0}function av8(a,b){a=a|0;b=b|0;if((a|0)==3145731){Ui(b);return}else if((a|0)==3145729){c[2113012]=b&255;return}else if((a|0)==12582912){a=b&255;c[2415256]=a&8;b=a>>>1&1;c[3528406]=b^1;if((b|0)==0){c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2]}Tr(a>>>2&1);return}else{return}}function av9(a,b){a=a|0;b=b|0;if((a|0)==3145728){c[2113012]=b&255;return}else if((a|0)==3145730){Ui(b&255);return}else if((a|0)==9437184){c[3542078]=b&65535;return}else if((a|0)==8388608){c[2113282]=b&65535;return}else if((a|0)==10485764){c[3542083]=b&65535;return}else if((a|0)==9437188){c[3542080]=b&65535;return}else if((a|0)==8388616){gD[c[3542102]&8191]()|0;c[2113288]=b&65535;return}else if((a|0)==10485762){c[3542082]=b&65535;return}else if((a|0)==8388610){c[2113278]=b&65535;return}else if((a|0)==9437186){c[3542079]=b&65535;return}else if((a|0)==10485760){c[3542081]=b&65535;return}else if((a|0)==12582912){a=(b&65535)>>>8&65535;c[2415256]=a&8;b=a>>>1&1;c[3528406]=b^1;if((b|0)==0){c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2]}Tr(a>>>2&1);return}else{return}}function awa(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2863076+(b*112|0)>>2];c[a+104>>2]=c[2863080+(b*112|0)>>2];c[a+108>>2]=c[2863084+(b*112|0)>>2];d=0;return d|0}function awb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=2862976+(b*112|0);e=0;return e|0}function awc(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1102640+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function awd(){var b=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;b=i;i=i+720|0;e=b|0;f=b+112|0;g=b+120|0;j=b+232|0;k=b+240|0;l=b+352|0;m=b+360|0;n=b+472|0;o=b+480|0;p=b+592|0;q=b+600|0;r=b+712|0;c[2424]=5755;c[2426700]=0;c[2418146]=0;c[3542098]=1048576;c[3542090]=17825792;c[3542091]=22020096;c[3531292]=26214400;c[2439998]=30408704;c[2405636]=30408832;c[2418260]=30408832;c[2418204]=30474368;c[3542094]=30478464;c[3542095]=30511232;c[3542100]=30544e3;c[3542108]=30609536;c[2411618]=30613632;s=0;while(1){if((s|0)>=1024){break}t=9638528+(s<<2)|0;if((c[t>>2]|0)==0){u=13549;break}else{s=s+1|0}}do{if((u|0)==13549){s=gGq(30613632)|0;c[t>>2]=s;if((s|0)==0){break}c[2426700]=s;gGz(s|0,0,30613632);c[2418146]=s;c[3542098]=s+1048576;c[3542090]=s+17825792;c[3542091]=s+22020096;c[3531292]=s+26214400;c[2439998]=s+30408704;v=s+30408832|0;c[2405636]=v;c[2418260]=v;c[2418204]=s+30474368;c[3542094]=s+30478464;c[3542095]=s+30511232;c[3542100]=s+30544e3;c[3542108]=s+30609536;v=s+30613632|0;c[2411618]=v;c[2414156]=v;R6(s,1,2)|0;s=(c[2418146]|0)+1|0;R6(s,0,2)|0;s=c[3542098]|0;do{if((c[3542200]|0)!=0){v=q+108|0;c[v>>2]=0;w=q+100|0;c[w>>2]=0;x=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[x&16383](q,2)|0;if((c[v>>2]|0)==0){break}v=c[w>>2]|0;c[r>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](r,2,0)|0;if((v|0)<1){break}gzL(s,0,2)|0}}while(0);s=(c[3542098]|0)+4194304|0;do{if((c[3542200]|0)!=0){v=o+108|0;c[v>>2]=0;w=o+100|0;c[w>>2]=0;x=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[x&16383](o,3)|0;if((c[v>>2]|0)==0){break}v=c[w>>2]|0;c[p>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](p,3,0)|0;if((v|0)<1){break}gzL(s,0,3)|0}}while(0);s=c[3542098]|0;v=s+8388607|0;w=s+16777214|0;s=0;while(1){a[w]=a[v]&15;a[w+1|0]=(d[v]|0)>>>4;x=s+1|0;if((x|0)<8388608){v=v-1|0;w=w-2|0;s=x}else{break}}s=c[3542090]|0;do{if((c[3542200]|0)!=0){w=m+108|0;c[w>>2]=0;v=m+100|0;c[v>>2]=0;x=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[x&16383](m,4)|0;if((c[w>>2]|0)==0){break}w=c[v>>2]|0;c[n>>2]=9534384;v=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[v&16383](n,4,0)|0;if((w|0)<1){break}gzL(s,0,4)|0}}while(0);s=c[3542090]|0;w=s+2097151|0;v=s+4194302|0;s=0;while(1){a[v+1|0]=a[w]&15;a[v]=(d[w]|0)>>>4;x=s+1|0;if((x|0)<2097152){w=w-1|0;v=v-2|0;s=x}else{break}}s=c[3542091]|0;do{if((c[3542200]|0)!=0){v=k+108|0;c[v>>2]=0;w=k+100|0;c[w>>2]=0;x=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[x&16383](k,5)|0;if((c[v>>2]|0)==0){break}v=c[w>>2]|0;c[l>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](l,5,0)|0;if((v|0)<1){break}gzL(s,0,5)|0}}while(0);s=c[3542091]|0;v=s+2097151|0;w=s+4194302|0;s=0;while(1){a[w+1|0]=a[v]&15;a[w]=(d[v]|0)>>>4;x=s+1|0;if((x|0)<2097152){v=v-1|0;w=w-2|0;s=x}else{break}}s=c[3531292]|0;do{if((c[3542200]|0)!=0){w=g+108|0;c[w>>2]=0;v=g+100|0;c[v>>2]=0;x=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[x&16383](g,6)|0;if((c[w>>2]|0)==0){break}w=c[v>>2]|0;c[j>>2]=9534384;v=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[v&16383](j,6,0)|0;if((w|0)<1){break}gzL(s,0,6)|0}}while(0);s=c[2439998]|0;do{if((c[3542200]|0)!=0){w=e+108|0;c[w>>2]=0;v=e+100|0;c[v>>2]=0;x=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[x&16383](e,7)|0;if((c[w>>2]|0)==0){break}w=c[v>>2]|0;c[f>>2]=9534384;v=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[v&16383](f,7,0)|0;if((w|0)<1){break}gzL(s,0,7)|0}}while(0);Tq(689976);if(!(a[1040128]|0)){s=c[2439998]|0;gGC(14100392,s|0,128)|0}fxU(0,425984);if((c[2394]|0)==0){y=c[2112932]|0}else{c[2394]=0;s=c[3532596]|0;c[2112932]=s;w=c[3532592]|0;if((w|0)!=0){gGC(9104152,w|0,280)|0}c[2113054]=c[2113060];y=s}s=c[2418146]|0;w=y|0;v=0;while(1){x=s+v|0;c[w>>2]=x;c[w+131072>>2]=x;x=v+1024|0;if(x>>>0>1048575){break}else{w=w+4|0;v=x}}v=c[2418260]|0;w=y+4096|0;s=1048576;while(1){x=v+(s-1048576)|0;c[w>>2]=x;c[w+65536>>2]=x;c[w+131072>>2]=x;x=s+1024|0;if(x>>>0>1114111){break}else{w=w+4|0;s=x}}s=c[3542100]|0;w=y+16384|0;v=4194304;while(1){x=s+(v-4194304)|0;c[w>>2]=x;c[w+65536>>2]=x;c[w+131072>>2]=x;x=v+1024|0;if(x>>>0>4259839){break}else{w=w+4|0;v=x}}v=c[3542094]|0;w=y+20480|0;s=5242880;while(1){x=v+(s-5242880)|0;c[w>>2]=x;c[w+65536>>2]=x;c[w+131072>>2]=x;x=s+1024|0;if(x>>>0>5275647){break}else{w=w+4|0;s=x}}s=c[3542095]|0;w=y+24576|0;v=6291456;while(1){x=s+(v-6291456)|0;c[w>>2]=x;c[w+65536>>2]=x;c[w+131072>>2]=x;x=v+1024|0;if(x>>>0>6324223){break}else{w=w+4|0;v=x}}v=c[3542108]|0;c[y+28800>>2]=v;c[y+94336>>2]=v;c[y+159872>>2]=v;w=v+1024|0;c[y+28804>>2]=w;c[y+94340>>2]=w;c[y+159876>>2]=w;w=v+2048|0;c[y+28808>>2]=w;c[y+94344>>2]=w;c[y+159880>>2]=w;w=v+3072|0;c[y+28812>>2]=w;c[y+94348>>2]=w;c[y+159884>>2]=w;w=c[2418204]|0;c[y+28928>>2]=w;c[y+16e4>>2]=w;v=w+1024|0;c[y+28932>>2]=v;c[y+160004>>2]=v;v=w+2048|0;c[y+28936>>2]=v;c[y+160008>>2]=v;c[y+28940>>2]=w;c[y+94476>>2]=w;c[y+160012>>2]=w;c[y+196688>>2]=2052;c[y+196608>>2]=1924;c[y+196728>>2]=2372;c[y+196648>>2]=3364;w=c[3532592]|0;if((w|0)!=0){gGC(w|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;c[2113290]=1;w=0;while(1){if((w|0)>=1024){z=0;break}A=9638528+(w<<2)|0;if((c[A>>2]|0)==0){u=13603;break}else{w=w+1|0}}do{if((u|0)==13603){w=gGq(131072)|0;c[A>>2]=w;if((w|0)==0){z=0;break}gGz(w|0,0,131072);z=w}}while(0);c[3542106]=z;gGz(z|0,0,131072);w=0;while(1){if((w|0)>=1024){B=0;break}C=9638528+(w<<2)|0;if((c[C>>2]|0)==0){u=13608;break}else{w=w+1|0}}do{if((u|0)==13608){w=gGq(65536)|0;c[C>>2]=w;if((w|0)==0){B=0;break}gGz(w|0,0,65536);B=w}}while(0);c[3527514]=B;gGz(B|0,0,65536);c[2112966]=c[3542106];c[3542078]=0;c[3542079]=0;c[3542080]=16;c[3542081]=0;c[3542082]=0;c[3542083]=16;c[3542084]=0;c[3542085]=0;c[3542086]=16;c[3542087]=0;c[3542088]=0;c[3542089]=16;c[2113284]=0;w=c[642608+(c[2436]<<2)>>2]|0;if((c[w+52>>2]&4|0)==0){v=c[w+128>>2]|0;c[2113280]=v;D=w+132|0;E=v}else{v=c[w+132>>2]|0;c[2113280]=v;D=w+128|0;E=v}v=c[D>>2]|0;c[2113276]=v;c[2406716]=E-8;c[2394778]=E-16;c[2406714]=v-8;c[2394776]=v-16;c[3528974]=c[3564288+(((E|0)!=320)<<2)>>2];auH(1,16777216);axI(0,4194304,8,16384);axI(1,4194304,8,16384);Uf(16934400,358);h[607287]=1.0;c[2433116]=1;h[607286]=1.0;c[2433114]=2;a[7072760]=1;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];v=c[3532592]|0;if((v|0)!=0){gGC(9104152,v|0,280)|0}c[2113054]=c[2113060]}RI();v=c[2394]|0;w=c[14130368+(v<<2)>>2]|0;if((w|0)!=0){gGC(w|0,9104152,280)|0}c[8452240+(v<<2)>>2]=c[2113054];c[2394]=-1;c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];gGz(14125184,0,668);c[2433532]=0;c[2430402]=0;c[2113010]=0;a[9753304]=0;c[2433552]=0;gGz(c[2430036]|0,0,16384);c[3531316]=4;gGz(c[2430037]|0,0,16384);c[3531337]=4;gGz(c[2430038]|0,0,16384);c[3531358]=4;gGz(c[2430039]|0,0,16384);c[3531379]=4;gGz(c[2430040]|0,0,16384);c[3531400]=4;gGz(c[2430041]|0,0,16384);c[3531421]=4;gGz(c[2430042]|0,0,16384);c[3531442]=4;gGz(c[2430043]|0,0,16384);c[3531463]=4;a[9541736]=1;a[9541968]=1;a[9775192]=1;a[9775656]=0;F=0;i=b;return F|0}}while(0);c[2426700]=0;F=1;i=b;return F|0}function awe(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;i=i+128|0;d=b|0;e=c[c[642608+(c[2436]<<2)>>2]>>2]|0;be(d|0,128,179600,(f=i,i=i+24|0,c[f>>2]=9374064,c[f+8>>2]=47,c[f+16>>2]=e,f)|0)|0;i=f;a[1040128]=0;f=c[2420380]|0;e=c[f>>2]|0;g=c[f+4>>2]|0;f=fw(d|0,389440)|0;if((f|0)!=0){d=g>>3<<e&1023;cj(14100392,d|0,1,f|0)|0;aY(f|0)|0}f=c[2406694]|0;if((f|0)!=0){gGr(f);c[2406694]=0}c[3531294]=0;axH();f=c[2443764]|0;d=0;while(1){if((d|0)>=1024){break}h=9638528+(d<<2)|0;if((c[h>>2]|0)==(f|0)){j=13630;break}else{d=d+1|0}}if((j|0)==13630){gGr(f);c[h>>2]=0}c[2443764]=0;h=c[2394718]|0;f=0;while(1){if((f|0)>=1024){break}k=9638528+(f<<2)|0;if((c[k>>2]|0)==(h|0)){j=13634;break}else{f=f+1|0}}if((j|0)==13634){gGr(h);c[k>>2]=0}c[2394718]=0;a[7462192]=0;k=c[3542106]|0;h=0;while(1){if((h|0)>=1024){break}l=9638528+(h<<2)|0;if((c[l>>2]|0)==(k|0)){j=13638;break}else{h=h+1|0}}if((j|0)==13638){gGr(k);c[l>>2]=0}c[3542106]=0;l=c[3527514]|0;k=0;while(1){if((k|0)>=1024){break}m=9638528+(k<<2)|0;if((c[m>>2]|0)==(l|0)){j=13642;break}else{k=k+1|0}}if((j|0)==13642){gGr(l);c[m>>2]=0}c[3527514]=0;if((c[2392]|0)>=0){m=0;do{l=14130368+(m<<2)|0;k=c[l>>2]|0;if((k|0)!=0){gGr(k);c[l>>2]=0}l=14130384+(m<<2)|0;k=c[l>>2]|0;if((k|0)!=0){gGr(k);c[l>>2]=0}m=m+1|0;}while((m|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;m=c[2426700]|0;l=0;while(1){if((l|0)>=1024){j=13654;break}n=9638528+(l<<2)|0;if((c[n>>2]|0)==(m|0)){break}else{l=l+1|0}}if((j|0)==13654){c[2426700]=0;i=b;return 0}gGr(m);c[n>>2]=0;c[2426700]=0;i=b;return 0}function awf(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((a[9624016]|0)!=0){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];gGz(14125184,0,668);c[2433532]=0;c[2430402]=0;c[2113010]=0;a[9753304]=0;c[2433552]=0;gGz(c[2430036]|0,0,16384);c[3531316]=4;gGz(c[2430037]|0,0,16384);c[3531337]=4;gGz(c[2430038]|0,0,16384);c[3531358]=4;gGz(c[2430039]|0,0,16384);c[3531379]=4;gGz(c[2430040]|0,0,16384);c[3531400]=4;gGz(c[2430041]|0,0,16384);c[3531421]=4;gGz(c[2430042]|0,0,16384);c[3531442]=4;gGz(c[2430043]|0,0,16384);c[3531463]=4;a[9541736]=1;a[9541968]=1;a[9775192]=1;a[9775656]=0}b[4812820]=0;b[4812821]=0;d=0;e=0;f=0;do{e=((a[9633208+d|0]&1)<<d|e&65535)&65535;f=((a[9631080+d|0]&1)<<d|f&65535)&65535;d=d+1|0;}while((d|0)<10);b[4812820]=e;b[4812821]=f;if((e&3)==3){d=e&-4;b[4812820]=d;g=d}else{g=e}if((g&12)==12){b[4812820]=g&-13}if((f&3)==3){g=f&-4;b[4812821]=g;h=g}else{h=f}if((h&12)==12){b[4812821]=h&-13}h=c[2392]|0;if((h|0)>=0){gGz(8452240,0,((h|0)>0?(h<<2)+4|0:4)|0)}c[2113054]=0;h=c[2438]|0;f=gGU(h,(h|0)<0|0?-1:0,16e6,0)|0;h=~~((+(f>>>0)+ +(K|0)*4294967296.0)/14732.965009208103);c[2440522]=h;c[2444074]=0;f=h-~~(+(h*12|0|0)/271.5)|0;a[9627128]=0;if((c[2394]|0)==0){i=1;j=0}else{c[2394]=0;c[2112932]=c[3532596];h=c[3532592]|0;if((h|0)!=0){gGC(9104152,h|0,280)|0}c[2113054]=c[2113060];i=1;j=0}while(1){h=c[2112964]|0;if((i&1|0)==0&(h|0)!=0){g=(ag(a[9688]|0?534:0,i)|0)/8|0;Ug(h+(j<<1<<1)|0,g-j|0);k=g}else{k=j}a[7024760]=0;g=(ag(c[2440522]|0,i)|0)/8|0;if((a[9627128]&1)==0&(g|0)>(f|0)){h=c[2444074]|0;if((h|0)<(f|0)){e=f-h|0;c[2113056]=e;h=RG(e)|0;c[2113054]=(c[2113054]|0)+h;c[2276108]=-1;c[2113056]=-1;e=9776296+(a[7024760]<<31>>31<<2)|0;c[e>>2]=(c[e>>2]|0)+h}h=c[2112968]|0;do{if((h|0)!=0){avg(128);e=c[(c[3542106]|0)+64512>>2]|0;do{if((e|0)==0){gGz(h|0,0,ag(c[2113280]<<1,c[2113276]|0)|0)}else{d=e<<16|e;l=ag(c[2113276]|0,c[2113280]|0)|0;if((l|0)<=15){break}m=h;n=(l|0)/16|0;while(1){c[m>>2]=d;c[m+4>>2]=d;c[m+8>>2]=d;c[m+12>>2]=d;c[m+16>>2]=d;c[m+20>>2]=d;c[m+24>>2]=d;c[m+28>>2]=d;l=n-1|0;if((l|0)>0){m=m+32|0;n=l}else{break}}}}while(0);if(!(a[7072760]|0)){break}axE(1)}}while(0);a[9627128]=1;a[9541736]=0;a[9775656]=1;c[8452200+(c[2394]<<2)>>2]=4097;c[2276080]=256;if((c[2276079]|0)>>>0<256){RH(1)}o=a[7024760]<<31>>31}else{o=0}h=g-(c[9776296+(o<<2)>>2]|0)|0;c[2113056]=h;e=RG(h)|0;c[2113054]=(c[2113054]|0)+e;c[2276108]=-1;c[2113056]=-1;h=9776296+(a[7024760]<<31>>31<<2)|0;c[h>>2]=(c[h>>2]|0)+e;a[7024760]=1;e=i+1|0;if((e|0)<9){i=e;j=k}else{break}}j=c[2112964]|0;do{if((j|0)!=0){i=a[9688]|0?534:0;if((i|0)==(k|0)){break}Ug(j+(k<<1<<1)|0,i-k|0)}}while(0);k=c[2394]|0;j=c[14130368+(k<<2)>>2]|0;if((j|0)==0){p=c[2113054]|0;q=8452240+(k<<2)|0;c[q>>2]=p;c[2394]=-1;return 0}gGC(j|0,9104152,280)|0;p=c[2113054]|0;q=8452240+(k<<2)|0;c[q>>2]=p;c[2394]=-1;return 0}function awg(){var b=0,d=0,e=0,f=0,g=0,h=0;avg(128);b=c[(c[3542106]|0)+64512>>2]|0;d=c[2112968]|0;do{if((b|0)==0){gGz(d|0,0,ag(c[2113280]<<1,c[2113276]|0)|0)}else{e=b<<16|b;f=ag(c[2113276]|0,c[2113280]|0)|0;if((f|0)<=15){break}g=d;h=(f|0)/16|0;while(1){c[g>>2]=e;c[g+4>>2]=e;c[g+8>>2]=e;c[g+12>>2]=e;c[g+16>>2]=e;c[g+20>>2]=e;c[g+24>>2]=e;c[g+28>>2]=e;f=h-1|0;if((f|0)>0){g=g+32|0;h=f}else{break}}}}while(0);if(!(a[7072760]|0)){return 0}axE(1);return 0}function awh(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;e=i;i=i+144|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;l=e+80|0;m=e+96|0;n=e+112|0;o=e+128|0;if((d|0)!=0){c[d>>2]=133378}Ts(b,d);if((b&96|0)!=0){gGz(o|0,0,12);d=c[2405636]|0;c[o>>2]=d;c[o+4>>2]=(c[2411618]|0)-d;c[o+12>>2]=219592;d=c[2076592]|0;gj[d&4095](o)|0;o=h|0;do{if((b&64|0)!=0){gGz(g|0,0,16);c[2394]=-1;if((c[2392]|0)<0){break}d=h+9|0;p=f;q=f|0;r=f+4|0;s=f+12|0;t=g|0;u=g+4|0;v=g+12|0;w=0;do{gGC(o|0,614896,11)|0;a[d]=w+48&255;x=8452256+(w<<2)|0;gGz(p|0,0,12);c[q>>2]=x;c[r>>2]=4;c[s>>2]=164976;gj[c[2076592]&4095](f)|0;if((c[x>>2]|0)!=0){c[t>>2]=c[14130368+(w<<2)>>2];c[u>>2]=c[8452184+(w<<2)>>2];c[v>>2]=o;x=c[2076592]|0;gj[x&4095](g)|0}w=w+1|0;}while((w|0)<=(c[2392]|0))}}while(0);Ue();gGz(n|0,0,12);c[n>>2]=9541736;c[n+4>>2]=1;c[n+12>>2]=148144;g=c[2076592]|0;gj[g&4095](n)|0;gGz(m|0,0,12);c[m>>2]=9541968;c[m+4>>2]=1;c[m+12>>2]=118544;n=c[2076592]|0;gj[n&4095](m)|0;gGz(l|0,0,12);c[l>>2]=9775192;c[l+4>>2]=1;c[l+12>>2]=93520;m=c[2076592]|0;gj[m&4095](l)|0;gGz(k|0,0,12);c[k>>2]=9627128;c[k+4>>2]=1;c[k+12>>2]=490464;l=c[2076592]|0;gj[l&4095](k)|0;ayc();gGz(j|0,0,12);c[j>>2]=9625640;c[j+4>>2]=4;c[j+12>>2]=215728;k=c[2076592]|0;gj[k&4095](j)|0}if((b&2|0)==0){i=e;return 0}a[14168416]=1;i=e;return 0}function awi(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2943940+(b*112|0)>>2];c[a+104>>2]=c[2943944+(b*112|0)>>2];c[a+108>>2]=c[2943948+(b*112|0)>>2];d=0;return d|0}function awj(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=2943840+(b*112|0);e=0;return e|0}function awk(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=(b^1)&255;a[9541968]=d;do{if((a[9541736]|0)==0|d<<24>>24==0){a[9775656]=1;e=4096;f=1;g=13745}else{b=(a[9775192]|0)==0;h=b&1;a[9775656]=h;if(b){e=b?4096:0;f=h;g=13745;break}c[8452200+(c[2394]<<2)>>2]=0;c[2276080]=0;i=h}}while(0);do{if((g|0)==13745){c[8452200+(c[2394]<<2)>>2]=e|1;c[2276080]=256;if((c[2276079]|0)>>>0>=256){i=f;break}RH(1);i=a[9775656]|0}}while(0);if(!(i<<24>>24!=0&a[7024760])){return}c[2113056]=1024;i=RG(1024)|0;c[2113054]=(c[2113054]|0)+i;c[2276108]=-1;c[2113056]=-1;c[2444074]=(c[2444074]|0)+i;return}function awl(d){d=d|0;var f=0,g=0,h=0,i=0;if((d|0)==8388608|(d|0)==8388609|(d|0)==8388610|(d|0)==8388611){f=a[9775184]<<1|a[9541728];return f|0}else if((d|0)==13631508){f=((e[4812814]|0)>>>8^255)&255;return f|0}else if((d|0)==3145731){g=c[2113010]|0;c[2113010]=0;c[2430402]=0;h=c[3531294]|0;if((h|0)!=0){gf[h&2047](0)}f=g&255;return f|0}else if((d|0)==13631504){f=((e[4812812]|0)>>>8^255)&255;return f|0}else if((d|0)==13631505){f=~(b[4812812]&255);return f|0}else if((d|0)==8388614|(d|0)==8388615){g=a[9541728]|0;h=a[9775184]<<1|g;a[9775184]=1;i=g<<24>>24==0|(a[9541960]|0)==0;a[9775648]=i&1;g=8452200+(c[2394]<<2)|0;if(!i){c[g>>2]=0;c[2276080]=0;f=h;return f|0}c[g>>2]=4097;c[2276080]=256;if((c[2276079]|0)>>>0>=256){f=h;return f|0}RH(1);f=h;return f|0}else if((d|0)==8388612|(d|0)==8388613){h=a[9775184]|0;g=h<<1|a[9541728];a[9541728]=1;i=(a[9541960]|0)==0|h<<24>>24==0;a[9775648]=i&1;h=8452200+(c[2394]<<2)|0;if(!i){c[h>>2]=0;c[2276080]=0;f=g;return f|0}c[h>>2]=4097;c[2276080]=256;if((c[2276079]|0)>>>0>=256){f=g;return f|0}RH(1);f=g;return f|0}else if((d|0)==13631506){f=((e[4812813]|0)>>>8^255)&255;return f|0}else if((d|0)==13631507){f=~(b[4812813]&255);return f|0}else if((d|0)==13631509){f=~(b[4812814]&255);return f|0}else{f=0;return f|0}return 0}function awm(d){d=d|0;var e=0,f=0,g=0,h=0;if((d|0)==3145730){e=c[2113010]|0;c[2113010]=0;c[2430402]=0;f=c[3531294]|0;if((f|0)!=0){gf[f&2047](0)}g=e&65535;return g|0}else if((d|0)==8388608|(d|0)==8388610){g=a[9775184]<<1|a[9541728];return g|0}else if((d|0)==13631504){g=~b[4812812];return g|0}else if((d|0)==13631506){g=~b[4812813];return g|0}else if((d|0)==8388614){e=a[9541728]|0;f=a[9775184]<<1|e<<24>>24;a[9775184]=1;h=e<<24>>24==0|(a[9541960]|0)==0;a[9775648]=h&1;e=8452200+(c[2394]<<2)|0;if(!h){c[e>>2]=0;c[2276080]=0;g=f;return g|0}c[e>>2]=4097;c[2276080]=256;if((c[2276079]|0)>>>0>=256){g=f;return g|0}RH(1);g=f;return g|0}else if((d|0)==13631508){g=~b[4812814];return g|0}else if((d|0)==8388612){d=a[9775184]|0;f=d<<24>>24<<1|a[9541728];a[9541728]=1;e=(a[9541960]|0)==0|d<<24>>24==0;a[9775648]=e&1;d=8452200+(c[2394]<<2)|0;if(!e){c[d>>2]=0;c[2276080]=0;g=f;return g|0}c[d>>2]=4097;c[2276080]=256;if((c[2276079]|0)>>>0>=256){g=f;return g|0}RH(1);g=f;return g|0}else{g=0;return g|0}return 0}function awn(a,b){a=a|0;b=b|0;if((a|0)==3145729){c[2113012]=b&255;return}else if((a|0)==3145731){Ui(b);return}else{return}}function awo(a,b){a=a|0;b=b|0;var d=0;if((a|0)==8388616){d=c[3542102]|0;gD[d&8191]()|0;c[2113288]=b&65535;return}else if((a|0)==3145728){c[2113012]=b&255;return}else if((a|0)==10485764){c[3542083]=b&65535;return}else if((a|0)==10485760){c[3542081]=b&65535;return}else if((a|0)==3145730){Ui(b&255);return}else if((a|0)==8388610){c[2113278]=b&65535;return}else if((a|0)==8388608){c[2113282]=b&65535;return}else if((a|0)==11534338){c[3542085]=b&65535;return}else if((a|0)==9437184){c[3542078]=b&65535;return}else if((a|0)==11534340){c[3542086]=b&65535;return}else if((a|0)==10485762){c[3542082]=b&65535;return}else if((a|0)==9437188){c[3542080]=b&65535;return}else if((a|0)==9437186){c[3542079]=b&65535;return}else if((a|0)==11534336){c[3542084]=b&65535;return}else{return}}function awp(b,d){b=b|0;d=d|0;var f=0,g=0;f=b&65535^1;b=c[3542108]|0;a[b+f|0]=d;g=(c[3527514]|0)+(f<<1)|0;if((a[g]|0)==d<<24>>24){return}a[g]=d;d=e[b+(f&65534)>>1]|0;b=d>>>7&248;c[(c[3542106]|0)+(f>>>1<<2)>>2]=d>>>2<<8&63488|d&31|(b>>>5|b)<<3&2016;return}function awq(a,d){a=a|0;d=d|0;var e=0;e=a>>>1&32767;b[(c[3542108]|0)+(e<<1)>>1]=d;a=(c[3527514]|0)+(e<<1)|0;if((b[a>>1]|0)==d<<16>>16){return}b[a>>1]=d;a=d&65535;d=a>>>7&248;c[(c[3542106]|0)+(e<<2)>>2]=a>>>2<<8&63488|a&31|(d>>>5|d)<<3&2016;return}function awr(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7052540+(b*112|0)>>2];c[a+104>>2]=c[7052544+(b*112|0)>>2];c[a+108>>2]=c[7052548+(b*112|0)>>2];d=0;return d|0}function aws(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=7052440+(b*112|0);e=0;return e|0}function awt(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>24){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5897168+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function awu(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>89){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7053560+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function awv(){var b=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;b=i;i=i+960|0;e=b|0;f=b+112|0;g=b+120|0;j=b+232|0;k=b+240|0;l=b+352|0;m=b+360|0;n=b+472|0;o=b+480|0;p=b+592|0;q=b+600|0;r=b+712|0;s=b+720|0;t=b+832|0;u=b+840|0;v=b+952|0;c[2424]=5800;c[2426694]=0;c[2418144]=0;c[3542098]=1048576;c[3542090]=17825792;c[3542091]=22020096;c[3542092]=26214400;c[3531292]=30408704;c[2418258]=42991616;c[3542094]=43057152;c[3542095]=43122688;c[3542096]=43188224;c[3542100]=43253760;c[3542108]=43319296;w=0;while(1){if((w|0)>=1024){break}x=9638528+(w<<2)|0;if((c[x>>2]|0)==0){y=13894;break}else{w=w+1|0}}do{if((y|0)==13894){w=gGq(43384832)|0;c[x>>2]=w;if((w|0)==0){break}c[2426694]=w;gGz(w|0,0,43384832);c[2418144]=w;c[3542098]=w+1048576;c[3542090]=w+17825792;c[3542091]=w+22020096;c[3542092]=w+26214400;c[3531292]=w+30408704;z=w+42991616|0;c[2405630]=z;c[2418258]=z;c[3542094]=w+43057152;c[3542095]=w+43122688;c[3542096]=w+43188224;c[3542100]=w+43253760;c[3542108]=w+43319296;z=w+43384832|0;c[2411600]=z;c[2414140]=z;R6(w,1,2)|0;w=(c[2418144]|0)+1|0;R6(w,0,2)|0;w=c[3542098]|0;do{if((c[3542200]|0)!=0){z=u+108|0;c[z>>2]=0;A=u+100|0;c[A>>2]=0;B=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[B&16383](u,2)|0;if((c[z>>2]|0)==0){break}z=c[A>>2]|0;c[v>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](v,2,0)|0;if((z|0)<1){break}gzL(w,0,2)|0}}while(0);w=(c[3542098]|0)+4194304|0;do{if((c[3542200]|0)!=0){z=s+108|0;c[z>>2]=0;A=s+100|0;c[A>>2]=0;B=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[B&16383](s,3)|0;if((c[z>>2]|0)==0){break}z=c[A>>2]|0;c[t>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](t,3,0)|0;if((z|0)<1){break}gzL(w,0,3)|0}}while(0);w=c[3542098]|0;z=w+8388607|0;A=w+16777214|0;w=0;while(1){a[A]=a[z]&15;a[A+1|0]=(d[z]|0)>>>4;B=w+1|0;if((B|0)<8388608){z=z-1|0;A=A-2|0;w=B}else{break}}w=c[3542090]|0;do{if((c[3542200]|0)!=0){A=q+108|0;c[A>>2]=0;z=q+100|0;c[z>>2]=0;B=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[B&16383](q,4)|0;if((c[A>>2]|0)==0){break}A=c[z>>2]|0;c[r>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](r,4,0)|0;if((A|0)<1){break}gzL(w,0,4)|0}}while(0);w=0;A=c[3542090]|0;while(1){z=a[A]|0;B=A+1|0;C=a[B]|0;a[B]=C<<4|z&15;a[A]=C&-16|(z&255)>>>4;z=w+1|0;if((z|0)<4194304){w=z;A=A+2|0}else{break}}A=c[3542091]|0;do{if((c[3542200]|0)!=0){w=o+108|0;c[w>>2]=0;z=o+100|0;c[z>>2]=0;C=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[C&16383](o,5)|0;if((c[w>>2]|0)==0){break}w=c[z>>2]|0;c[p>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](p,5,0)|0;if((w|0)<1){break}gzL(A,0,5)|0}}while(0);A=0;w=c[3542091]|0;while(1){z=a[w]|0;C=w+1|0;B=a[C]|0;a[C]=B<<4|z&15;a[w]=B&-16|(z&255)>>>4;z=A+1|0;if((z|0)<4194304){A=z;w=w+2|0}else{break}}w=c[3542092]|0;do{if((c[3542200]|0)!=0){A=m+108|0;c[A>>2]=0;z=m+100|0;c[z>>2]=0;B=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[B&16383](m,6)|0;if((c[A>>2]|0)==0){break}A=c[z>>2]|0;c[n>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](n,6,0)|0;if((A|0)<1){break}gzL(w,0,6)|0}}while(0);w=0;A=c[3542092]|0;while(1){z=a[A]|0;B=A+1|0;C=a[B]|0;a[B]=C<<4|z&15;a[A]=C&-16|(z&255)>>>4;z=w+1|0;if((z|0)<4194304){w=z;A=A+2|0}else{break}}A=c[3531292]|0;do{if((c[3542200]|0)!=0){w=k+108|0;c[w>>2]=0;z=k+100|0;c[z>>2]=0;C=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[C&16383](k,7)|0;if((c[w>>2]|0)==0){break}w=c[z>>2]|0;c[l>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](l,7,0)|0;if((w|0)<1){break}gzL(A,0,7)|0}}while(0);A=(c[3531292]|0)+4194304|0;do{if((c[3542200]|0)!=0){w=g+108|0;c[w>>2]=0;z=g+100|0;c[z>>2]=0;C=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[C&16383](g,8)|0;if((c[w>>2]|0)==0){break}w=c[z>>2]|0;c[j>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](j,8,0)|0;if((w|0)<1){break}gzL(A,0,8)|0}}while(0);A=(c[3531292]|0)+8388608|0;do{if((c[3542200]|0)!=0){w=e+108|0;c[w>>2]=0;z=e+100|0;c[z>>2]=0;C=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[C&16383](e,9)|0;if((c[w>>2]|0)==0){break}w=c[z>>2]|0;c[f>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](f,9,0)|0;if((w|0)<1){break}gzL(A,0,9)|0}}while(0);fxU(0,425984);if((c[2394]|0)==0){D=c[2112932]|0}else{c[2394]=0;A=c[3532596]|0;c[2112932]=A;w=c[3532592]|0;if((w|0)!=0){gGC(9104152,w|0,280)|0}c[2113054]=c[2113060];D=A}A=c[2418144]|0;w=D|0;z=0;while(1){C=A+z|0;c[w>>2]=C;c[w+131072>>2]=C;C=z+1024|0;if(C>>>0>1048575){break}else{w=w+4|0;z=C}}z=c[2418258]|0;w=D+4096|0;A=1048576;while(1){C=z+(A-1048576)|0;c[w>>2]=C;c[w+65536>>2]=C;c[w+131072>>2]=C;C=A+1024|0;if(C>>>0>1114111){break}else{w=w+4|0;A=C}}A=c[3542100]|0;w=D+16384|0;z=4194304;while(1){C=A+(z-4194304)|0;c[w>>2]=C;c[w+65536>>2]=C;c[w+131072>>2]=C;C=z+1024|0;if(C>>>0>4259839){break}else{w=w+4|0;z=C}}z=c[3542094]|0;w=D+20480|0;A=5242880;while(1){C=z+(A-5242880)|0;c[w>>2]=C;c[w+65536>>2]=C;c[w+131072>>2]=C;C=A+1024|0;if(C>>>0>5308415){break}else{w=w+4|0;A=C}}A=c[3542095]|0;w=D+24576|0;z=6291456;while(1){C=A+(z-6291456)|0;c[w>>2]=C;c[w+65536>>2]=C;c[w+131072>>2]=C;C=z+1024|0;if(C>>>0>6356991){break}else{w=w+4|0;z=C}}z=c[3542096]|0;w=D+28672|0;A=7340032;while(1){C=z+(A-7340032)|0;c[w>>2]=C;c[w+65536>>2]=C;c[w+131072>>2]=C;C=A+1024|0;if(C>>>0>7405567){break}else{w=w+4|0;A=C}}A=c[3542108]|0;w=D+49152|0;z=w;C=12582912;while(1){B=A+(C-12582912)|0;c[z>>2]=B;c[z+131072>>2]=B;B=C+1024|0;if(B>>>0>12648447){E=w;F=12582912;break}else{z=z+4|0;C=B}}while(1){c[E+65536>>2]=1;C=F+1024|0;if(C>>>0>12648447){break}else{E=E+4|0;F=C}}c[D+196688>>2]=1596;c[D+196608>>2]=3384;c[D+196728>>2]=3260;c[D+196648>>2]=502;c[D+196732>>2]=470;c[D+196652>>2]=3296;C=c[3532592]|0;if((C|0)!=0){gGC(C|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;c[2113290]=0;C=0;while(1){if((C|0)>=1024){G=0;break}H=9638528+(C<<2)|0;if((c[H>>2]|0)==0){y=13961;break}else{C=C+1|0}}do{if((y|0)==13961){C=gGq(131072)|0;c[H>>2]=C;if((C|0)==0){G=0;break}gGz(C|0,0,131072);G=C}}while(0);c[3542106]=G;gGz(G|0,0,131072);C=0;while(1){if((C|0)>=1024){I=0;break}J=9638528+(C<<2)|0;if((c[J>>2]|0)==0){y=13966;break}else{C=C+1|0}}do{if((y|0)==13966){C=gGq(65536)|0;c[J>>2]=C;if((C|0)==0){I=0;break}gGz(C|0,0,65536);I=C}}while(0);c[3527514]=I;gGz(I|0,0,65536);c[2112966]=c[3542106];c[3542078]=0;c[3542079]=0;c[3542080]=16;c[3542081]=0;c[3542082]=0;c[3542083]=16;c[3542084]=0;c[3542085]=0;c[3542086]=16;c[3542087]=0;c[3542088]=0;c[3542089]=16;c[2113284]=0;C=c[642608+(c[2436]<<2)>>2]|0;if((c[C+52>>2]&4|0)==0){z=c[C+128>>2]|0;c[2113280]=z;K=C+132|0;L=z}else{z=c[C+132>>2]|0;c[2113280]=z;K=C+128|0;L=z}z=c[K>>2]|0;c[2113276]=z;c[2406716]=L-8;c[2394778]=L-16;c[2406714]=z-8;c[2394776]=z-16;c[3528974]=c[3564288+(((L|0)!=320)<<2)>>2];auH(2,16777216);axI(0,4194304,8,16384);axI(1,4194304,8,16384);axI(2,4194304,8,16384);Uf(16e6,200);h[607287]=1.0;c[2433116]=1;h[607286]=1.0;c[2433114]=2;a[7072752]=1;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];z=c[3532592]|0;if((z|0)!=0){gGC(9104152,z|0,280)|0}c[2113054]=c[2113060]}RI();z=c[2394]|0;C=c[14130368+(z<<2)>>2]|0;if((C|0)!=0){gGC(C|0,9104152,280)|0}c[8452240+(z<<2)>>2]=c[2113054];c[2394]=-1;a[9541728]=1;a[9541960]=1;a[9775184]=1;a[9775648]=0;gGz(14125184,0,668);c[2433532]=0;c[2430402]=0;c[2113010]=0;a[9753304]=0;c[2433552]=0;gGz(c[2430036]|0,0,16384);c[3531316]=4;gGz(c[2430037]|0,0,16384);c[3531337]=4;gGz(c[2430038]|0,0,16384);c[3531358]=4;gGz(c[2430039]|0,0,16384);c[3531379]=4;gGz(c[2430040]|0,0,16384);c[3531400]=4;gGz(c[2430041]|0,0,16384);c[3531421]=4;gGz(c[2430042]|0,0,16384);c[3531442]=4;gGz(c[2430043]|0,0,16384);c[3531463]=4;M=0;i=b;return M|0}}while(0);c[2426694]=0;M=1;i=b;return M|0}function aww(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[2406694]|0;if((b|0)!=0){gGr(b);c[2406694]=0}c[3531294]=0;axH();b=c[2443764]|0;d=0;while(1){if((d|0)>=1024){break}e=9638528+(d<<2)|0;if((c[e>>2]|0)==(b|0)){f=13986;break}else{d=d+1|0}}if((f|0)==13986){gGr(b);c[e>>2]=0}c[2443764]=0;e=c[2394718]|0;b=0;while(1){if((b|0)>=1024){break}g=9638528+(b<<2)|0;if((c[g>>2]|0)==(e|0)){f=13990;break}else{b=b+1|0}}if((f|0)==13990){gGr(e);c[g>>2]=0}c[2394718]=0;a[7462192]=0;g=c[3542106]|0;e=0;while(1){if((e|0)>=1024){break}h=9638528+(e<<2)|0;if((c[h>>2]|0)==(g|0)){f=13994;break}else{e=e+1|0}}if((f|0)==13994){gGr(g);c[h>>2]=0}c[3542106]=0;h=c[3527514]|0;g=0;while(1){if((g|0)>=1024){break}i=9638528+(g<<2)|0;if((c[i>>2]|0)==(h|0)){f=13998;break}else{g=g+1|0}}if((f|0)==13998){gGr(h);c[i>>2]=0}c[3527514]=0;if((c[2392]|0)>=0){i=0;do{h=14130368+(i<<2)|0;g=c[h>>2]|0;if((g|0)!=0){gGr(g);c[h>>2]=0}h=14130384+(i<<2)|0;g=c[h>>2]|0;if((g|0)!=0){gGr(g);c[h>>2]=0}i=i+1|0;}while((i|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;i=c[2426694]|0;h=0;while(1){if((h|0)>=1024){f=14010;break}j=9638528+(h<<2)|0;if((c[j>>2]|0)==(i|0)){break}else{h=h+1|0}}if((f|0)==14010){c[2426694]=0;return 0}gGr(i);c[j>>2]=0;c[2426694]=0;return 0}function awx(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;if((a[9623952]|0)!=0){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;a[9541728]=1;a[9541960]=1;a[9775184]=1;a[9775648]=0;gGz(14125184,0,668);c[2433532]=0;c[2430402]=0;c[2113010]=0;a[9753304]=0;c[2433552]=0;gGz(c[2430036]|0,0,16384);c[3531316]=4;gGz(c[2430037]|0,0,16384);c[3531337]=4;gGz(c[2430038]|0,0,16384);c[3531358]=4;gGz(c[2430039]|0,0,16384);c[3531379]=4;gGz(c[2430040]|0,0,16384);c[3531400]=4;gGz(c[2430041]|0,0,16384);c[3531421]=4;gGz(c[2430042]|0,0,16384);c[3531442]=4;gGz(c[2430043]|0,0,16384);c[3531463]=4}b[4812812]=0;b[4812813]=0;d=0;e=0;f=0;do{g=(a[9633104+d|0]&1)<<d|e&65535;e=g&65535;f=((a[9630976+d|0]&1)<<d|f&65535)&65535;d=d+1|0;}while((d|0)<16);b[4812812]=e;b[4812813]=f;f=g&255;g=(e&65535)>>>8&255;if((f&3)==3){e=f&-4;a[9625624]=e;h=e}else{h=f}if((h&12)==12){a[9625624]=h&-13}if((g&3)==3){h=g&-4;a[9625625]=h;i=h}else{i=g}if((i&12)==12){a[9625625]=i&-13}i=c[2392]|0;if((i|0)>=0){gGz(8452240,0,((i|0)>0?(i<<2)+4|0:4)|0)}c[2113054]=0;i=c[2438]|0;g=gGU(i,(i|0)<0|0?-1:0,16e6,0)|0;i=gGS(g,K,14848,0)|0;g=i;c[2440520]=g;c[2444072]=0;i=g-~~(+(g*12|0|0)/265.5)|0;a[9626824]=0;if((c[2394]|0)==0){j=1;k=0}else{c[2394]=0;c[2112932]=c[3532596];g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060];j=1;k=0}while(1){g=c[2112964]|0;if((j&1|0)==0&(g|0)!=0){h=(ag(a[9688]|0?534:0,j)|0)/8|0;Ug(g+(k<<1<<1)|0,h-k|0);l=h}else{l=k}a[7024752]=0;h=(ag(c[2440520]|0,j)|0)/8|0;if((a[9626824]|0)==0&(h|0)>(i|0)){g=c[2444072]|0;if((g|0)<(i|0)){f=i-g|0;c[2113056]=f;g=RG(f)|0;c[2113054]=(c[2113054]|0)+g;c[2276108]=-1;c[2113056]=-1;f=9776288+(a[7024752]<<31>>31<<2)|0;c[f>>2]=(c[f>>2]|0)+g}g=c[2112968]|0;do{if((g|0)!=0){if((a[14168416]|0)==0){m=c[3542106]|0}else{f=c[3527514]|0;e=c[3542106]|0;d=c[3542108]|0;n=0;while(1){o=n<<8;p=0;q=d;r=f+(o<<1)|0;s=e+(o<<2)|0;while(1){o=b[q>>1]|0;b[r>>1]=o;t=o&65535;o=t>>>7&248;c[s>>2]=t>>>2<<8&63488|t&31|(o>>>5|o)<<3&2016;o=p+1|0;if((o|0)<256){p=o;q=q+2|0;r=r+2|0;s=s+4|0}else{break}}s=n+1|0;if((s|0)<128){d=d+512|0;n=s}else{break}}a[14168416]=0;m=e}n=c[m>>2]|0;do{if((n|0)==0){gGz(g|0,0,ag(c[2113280]<<1,c[2113276]|0)|0)}else{d=n<<16|n;f=ag(c[2113276]|0,c[2113280]|0)|0;if((f|0)<=15){break}s=g;r=(f|0)/16|0;while(1){c[s>>2]=d;c[s+4>>2]=d;c[s+8>>2]=d;c[s+12>>2]=d;c[s+16>>2]=d;c[s+20>>2]=d;c[s+24>>2]=d;c[s+28>>2]=d;f=r-1|0;if((f|0)>0){s=s+32|0;r=f}else{break}}}}while(0);if(!(a[7072752]|0)){break}axE(1)}}while(0);a[9626824]=1;a[9541728]=0;a[9775648]=1;c[8452200+(c[2394]<<2)>>2]=4097;c[2276080]=256;if((c[2276079]|0)>>>0<256){RH(1)}u=a[7024752]<<31>>31}else{u=0}g=h-(c[9776288+(u<<2)>>2]|0)|0;c[2113056]=g;n=RG(g)|0;c[2113054]=(c[2113054]|0)+n;c[2276108]=-1;c[2113056]=-1;g=9776288+(a[7024752]<<31>>31<<2)|0;c[g>>2]=(c[g>>2]|0)+n;a[7024752]=1;n=j+1|0;if((n|0)<9){j=n;k=l}else{break}}k=c[2112964]|0;do{if((k|0)!=0){j=a[9688]|0?534:0;if((j|0)==(l|0)){break}Ug(k+(l<<1<<1)|0,j-l|0)}}while(0);l=c[2394]|0;k=c[14130368+(l<<2)>>2]|0;if((k|0)==0){v=c[2113054]|0;w=8452240+(l<<2)|0;c[w>>2]=v;c[2394]=-1;return 0}gGC(k|0,9104152,280)|0;v=c[2113054]|0;w=8452240+(l<<2)|0;c[w>>2]=v;c[2394]=-1;return 0}function awy(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((a[14168416]|0)==0){d=c[3542106]|0}else{e=c[3527514]|0;f=c[3542106]|0;g=c[3542108]|0;h=0;while(1){i=h<<8;j=0;k=g;l=e+(i<<1)|0;m=f+(i<<2)|0;while(1){i=b[k>>1]|0;b[l>>1]=i;n=i&65535;i=n>>>7&248;c[m>>2]=n>>>2<<8&63488|n&31|(i>>>5|i)<<3&2016;i=j+1|0;if((i|0)<256){j=i;k=k+2|0;l=l+2|0;m=m+4|0}else{break}}m=h+1|0;if((m|0)<128){g=g+512|0;h=m}else{break}}a[14168416]=0;d=f}f=c[d>>2]|0;d=c[2112968]|0;do{if((f|0)==0){gGz(d|0,0,ag(c[2113280]<<1,c[2113276]|0)|0)}else{h=f<<16|f;g=ag(c[2113276]|0,c[2113280]|0)|0;if((g|0)<=15){break}e=d;m=(g|0)/16|0;while(1){c[e>>2]=h;c[e+4>>2]=h;c[e+8>>2]=h;c[e+12>>2]=h;c[e+16>>2]=h;c[e+20>>2]=h;c[e+24>>2]=h;c[e+28>>2]=h;g=m-1|0;if((g|0)>0){e=e+32|0;m=g}else{break}}}}while(0);if(!(a[7072752]|0)){return 0}axE(1);return 0}function awz(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;e=i;i=i+144|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;l=e+80|0;m=e+96|0;n=e+112|0;o=e+128|0;if((d|0)!=0){c[d>>2]=133378}if((b&4|0)!=0){c[o>>2]=c[2418144];c[o+4>>2]=1048576;c[o+8>>2]=0;c[o+12>>2]=496208;d=c[2076592]|0;gj[d&4095](o)|0}if((b&32|0)!=0){d=o|0;c[d>>2]=c[2418258];p=o+4|0;c[p>>2]=65536;q=o+8|0;c[q>>2]=0;r=o+12|0;c[r>>2]=484192;s=c[2076592]|0;gj[s&4095](o)|0;c[d>>2]=c[3542094];c[p>>2]=65536;c[q>>2]=0;c[r>>2]=497240;s=c[2076592]|0;gj[s&4095](o)|0;c[d>>2]=c[3542095];c[p>>2]=65536;c[q>>2]=0;c[r>>2]=495616;s=c[2076592]|0;gj[s&4095](o)|0;c[d>>2]=c[3542096];c[p>>2]=65536;c[q>>2]=0;c[r>>2]=185744;s=c[2076592]|0;gj[s&4095](o)|0;c[d>>2]=c[3542100];c[p>>2]=65536;c[q>>2]=0;c[r>>2]=492944;s=c[2076592]|0;gj[s&4095](o)|0;c[d>>2]=c[3542108];c[p>>2]=65536;c[q>>2]=0;c[r>>2]=426800;r=c[2076592]|0;gj[r&4095](o)|0}if((b&64|0)==0){i=e;return 0}o=h|0;gGz(g|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){r=h+9|0;h=f;q=f|0;p=f+4|0;d=f+12|0;s=g|0;t=g+4|0;u=g+12|0;v=0;do{gGC(o|0,614896,11)|0;a[r]=v+48&255;w=8452256+(v<<2)|0;gGz(h|0,0,12);c[q>>2]=w;c[p>>2]=4;c[d>>2]=164976;gj[c[2076592]&4095](f)|0;if((c[w>>2]|0)!=0){c[s>>2]=c[14130368+(v<<2)>>2];c[t>>2]=c[8452184+(v<<2)>>2];c[u>>2]=o;w=c[2076592]|0;gj[w&4095](g)|0}v=v+1|0;}while((v|0)<=(c[2392]|0))}Ue();gGz(n|0,0,12);c[n>>2]=9541728;c[n+4>>2]=1;c[n+12>>2]=148144;gj[c[2076592]&4095](n)|0;gGz(m|0,0,12);c[m>>2]=9541960;c[m+4>>2]=1;c[m+12>>2]=118544;gj[c[2076592]&4095](m)|0;gGz(l|0,0,12);c[l>>2]=9775184;c[l+4>>2]=1;c[l+12>>2]=93520;gj[c[2076592]&4095](l)|0;gGz(k|0,0,12);c[k>>2]=9626824;c[k+4>>2]=1;c[k+12>>2]=163632;gj[c[2076592]&4095](k)|0;ayc();gGz(j|0,0,12);c[j>>2]=9625624;c[j+4>>2]=6;c[j+12>>2]=215728;gj[c[2076592]&4095](j)|0;if((b&2|0)==0){i=e;return 0}a[14168416]=1;i=e;return 0}function awA(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4359972+(b*112|0)>>2];c[a+104>>2]=c[4359976+(b*112|0)>>2];c[a+108>>2]=c[4359980+(b*112|0)>>2];d=0;return d|0}function awB(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=4359872+(b*112|0);e=0;return e|0}function awC(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>65){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4360992+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function awD(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=(b^1)&255;a[9541960]=d;do{if((a[9541728]|0)==0|d<<24>>24==0){a[9775648]=1;e=4096;f=1;g=14125}else{b=(a[9775184]|0)==0;h=b&1;a[9775648]=h;if(b){e=b?4096:0;f=h;g=14125;break}c[8452200+(c[2394]<<2)>>2]=0;c[2276080]=0;i=h}}while(0);do{if((g|0)==14125){c[8452200+(c[2394]<<2)>>2]=e|1;c[2276080]=256;if((c[2276079]|0)>>>0>=256){i=f;break}RH(1);i=a[9775648]|0}}while(0);if(!(i<<24>>24!=0&a[7024752])){return}c[2113056]=1024;i=RG(1024)|0;c[2113054]=(c[2113054]|0)+i;c[2276108]=-1;c[2113056]=-1;c[2444072]=(c[2444072]|0)+i;return}function awE(a){a=a|0;return 0}function awF(a,b){a=a|0;b=b|0;return}function awG(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0;if((d-6291456|0)>>>0<1048576){f=0;return f|0}if((d|0)==15204352){if((c[2406632]|0)!=0){f=((c[2432962]|0)>>>((c[(c[2420380]|0)+4>>2]|0)>>>0)<<3|65527)&65535;return f|0}g=c[2443744]|0;if((g|0)<=0){f=-1;return f|0}c[2443744]=g-1;f=-9;return f|0}else if((d|0)==11010052){g=a[9775176]|0;h=g<<24>>24<<1|a[9541720];a[9541720]=1;do{if((a[9541952]|0)==0){i=4096}else{j=g<<24>>24==0;if(j){i=j?4096:0;break}c[8452200+(c[2394]<<2)>>2]=0;c[2276080]=0;f=h;return f|0}}while(0);c[8452200+(c[2394]<<2)>>2]=i|1;c[2276080]=256;if((c[2276079]|0)>>>0>=256){f=h;return f|0}RH(1);f=h;return f|0}else if((d|0)==11010054){h=a[9541720]|0;i=a[9775176]<<1|h<<24>>24;a[9775176]=1;g=8452200+(c[2394]<<2)|0;if(!(h<<24>>24==0|(a[9541952]|0)==0)){c[g>>2]=0;c[2276080]=0;f=i;return f|0}c[g>>2]=4097;c[2276080]=256;if((c[2276079]|0)>>>0>=256){f=i;return f|0}RH(1);f=i;return f|0}else if((d|0)==5242882){i=e[4812801]|0;do{if((c[2406632]|0)==0){g=c[2443744]|0;if((g|0)<=0){k=2048;break}c[2443744]=g-1;k=0}else{k=(c[2432962]|0)>>>((c[(c[2420380]|0)+4>>2]|0)>>>0)<<11&2048}}while(0);f=((k|i)^63487)&65535;return f|0}else if((d|0)==5242880){f=~b[4812800];return f|0}else if((d|0)==14155776){i=c[2429478]|0;if((i|0)>(c[2430064]|0)){c[2429478]=0;c[2430064]=-1;f=0;return f|0}else{c[2429478]=i+1;f=c[9747264+(i<<2)>>2]&65535;return f|0}}else if((d|0)==11010048|(d|0)==11010050){f=a[9775176]<<1|a[9541720];return f|0}else{f=0;return f|0}return 0}function awH(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;if((b-11010058|0)>>>0<115|(b-11010052|0)>>>0<3){return}if((b|0)==11534340){e=d&15;if((e|0)==1){f=d&-16}else if((e|0)==2){f=d&-16|1}else if((e|0)==4){f=d&-16|2}else{f=d&-16|3}c[3542086]=f&65535;return}else if((b|0)==14680064){c[3528930]=d&65535;c[2433326]=c[2433326]|12;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12;return}else if((b|0)==12058624){c[3542078]=d&65535;return}else if((b|0)==12058626){c[3542079]=d&65535;return}else if((b|0)==11534336){c[3542084]=d&65535;return}else if((b|0)==13107204){f=d&15;if((f|0)==1){g=d&-16}else if((f|0)==2){g=d&-16|1}else if((f|0)==4){g=d&-16|2}else{g=d&-16|3}c[3542089]=g&65535;return}else if((b|0)==12582912){c[3542081]=d&65535;return}else if((b|0)==12582916){g=d&15;if((g|0)==2){h=d&-16|1}else if((g|0)==4){h=d&-16|2}else if((g|0)==1){h=d&-16}else{h=d&-16|3}c[3542083]=h&65535;return}else if((b|0)==11010048){c[2113282]=d&65535;return}else if((b|0)==11010050){c[2113278]=d&65535;return}else if((b|0)==12058628){h=d&15;if((h|0)==4){i=d&-16|2}else if((h|0)==2){i=d&-16|1}else if((h|0)==1){i=d&-16}else{i=d&-16|3}c[3542080]=i&65535;return}else if((b|0)==13107200){c[3542087]=d&65535;return}else if((b|0)==7340032){i=(d&65535)>>>8&65535;c[2415256]=i&8;h=i>>>1&1;c[3528406]=h^1;if((h|0)==0){c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2]}Tr(i>>>2&1);return}else if((b|0)==12582914){c[3542082]=d&65535;return}else if((b|0)==11010056){gD[c[3542102]&8191]()|0;c[2113288]=d&65535;return}else if((b|0)==11534338){c[3542085]=d&65535;return}else if((b|0)==13107202){c[3542088]=d&65535;return}else{return}}function awI(b){b=b|0;var e=0,f=0.0,g=0.0,i=0,j=0;switch(b&255|0){case 64:{b=c[3541518]|0;e=b+296|0;f=+h[e>>3];do{if(f!=0.0){g=+h[6675];if(f-(g+ +gC[c[2429842]&255]())<=0.0){h[e>>3]=0.0;break}i=a[b+307|0]|-128;return i|0}}while(0);i=a[b+307|0]|0;return i|0};case 65:{if((d[(c[3541518]|0)+304|0]|0)>=16){i=0;return i|0}b=c[2383582]|0;e=c[14168912+(b*252|0)>>2]|0;if((e|0)>15){i=0;return i|0}do{if((e|0)==15){j=c[14168900+(b*252|0)>>2]|0;if((j|0)==0){break}a[14168931+(b*252|0)|0]=gj[j&4095](0)|0}else if((e|0)==14){j=c[14168896+(b*252|0)>>2]|0;if((j|0)==0){break}a[14168930+(b*252|0)|0]=gj[j&4095](0)|0}}while(0);i=a[14168916+(b*252|0)+e|0]|0;return i|0};case 8:{i=c[2113157]&255;return i|0};case 96:{c[2433326]=c[2433326]|8;i=(c[3528930]|0)>>>8&255;return i|0};case 112:{c[2433326]=c[2433326]|4;i=c[3528930]&255;return i|0};case 0:{i=c[2113156]&255;return i|0};default:{i=0;return i|0}}return 0}function awJ(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=b&255;switch(e|0){case 80:{b=c[2430064]|0;if((c[2429478]|0)>(b|0)){c[2430064]=-1;c[2429478]=0;f=-1}else{f=b}b=f+1|0;c[2430064]=b;c[9747264+(b<<2)>>2]=d&255;return};case 128:{b=d&7;a[14117456]=b;f=c[2411298]|0;g=c[9757320+(c[1836236]<<2)>>2]|0;h=((b&255)<<14)-32768|0;b=128;i=128;while(1){c[g+76+(i<<2)>>2]=f+(h+(i<<8));j=b+1&65535;if((j&65535)>191){k=128;l=128;break}else{b=j;i=j&65535}}while(1){i=f+(h+(l<<8))|0;c[g+76+(l+512<<2)>>2]=i;c[g+76+(l+768<<2)>>2]=i;i=k+1&65535;if((i&65535)>191){break}else{k=i;l=i&65535}}return};case 16:case 17:case 18:case 19:case 20:case 21:case 22:case 23:{l=e-16|0;e=l&3;if((l&4|0)==0){a[14109432+e|0]=d;l=(d&255)<<16;k=c[3541206]|0;c[14164792+(e<<2)>>2]=k+l;c[14164760+(e<<2)>>2]=k+(e<<8|l);return}else{a[14109408+e|0]=d;l=c[3541206]|0;k=((d&255)<<16)+4194304|0;c[14164808+(e<<2)>>2]=l+k;c[14164776+(e<<2)>>2]=l+(e<<8|k);return}break};case 0:{Uv(0,d);return};case 65:{lS(0,1,d);return};case 64:{k=c[3541518]|0;e=k+256|0;a[k+304|0]=d;l=d&255;if((d&255)<16){c[14168912+((c[2383582]|0)*252|0)>>2]=l&15}if((d-45&255)>=3){return}if((l|0)==46){g=k+312|0;h=a[g]|1;a[g]=h;m=h}else if((l|0)==0){a[k+312|0]=2;m=2}else if((l|0)==47){a[k+312|0]=0;m=0}else if((l|0)==45){l=k+312|0;h=a[l]|2;a[l]=h;m=h}else{m=a[k+312|0]|0}k=m&3;m=c[7461744+(k<<2)>>2]|0;lI(e,m,m,c[7461728+(k<<2)>>2]|0);return};case 8:{Uv(1,d);return};default:{return}}}function awK(a){a=a|0;return 0}function awL(a,b){a=a|0;b=b|0;return}function awM(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2415876+(b*112|0)>>2];c[a+104>>2]=c[2415880+(b*112|0)>>2];c[a+108>>2]=c[2415884+(b*112|0)>>2];d=0;return d|0}function awN(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=2415776+(b*112|0);e=0;return e|0}function awO(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1026880+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function awP(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0;e=i;i=i+1920|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;B=e+1200|0;C=e+1312|0;D=e+1320|0;E=e+1432|0;F=e+1440|0;G=e+1552|0;H=e+1560|0;I=e+1672|0;J=e+1680|0;K=e+1792|0;L=e+1800|0;M=e+1912|0;c[2424]=5755;c[2426686]=0;c[2418142]=0;c[2411298]=3145728;c[3542098]=3407872;c[3542090]=36962304;c[3542091]=41156608;c[3542092]=45350912;c[3542093]=49545216;c[3541206]=51642368;c[2405622]=60030976;c[2418256]=60030976;c[2411340]=60194816;c[3542094]=60203008;c[3542095]=60235776;c[3542096]=60268544;c[3542097]=60301312;c[3542100]=60334080;c[3542108]=60366848;c[2411582]=60387328;N=0;while(1){if((N|0)>=1024){break}O=9638528+(N<<2)|0;if((c[O>>2]|0)==0){P=14327;break}else{N=N+1|0}}do{if((P|0)==14327){N=gGq(60387328)|0;c[O>>2]=N;if((N|0)==0){break}c[2426686]=N;gGz(N|0,0,60387328);c[2418142]=N;c[2411298]=N+3145728;c[3542098]=N+3407872;c[3542090]=N+36962304;c[3542091]=N+41156608;c[3542092]=N+45350912;c[3542093]=N+49545216;c[3541206]=N+51642368;Q=N+60030976|0;c[2405622]=Q;c[2418256]=Q;c[2411340]=N+60194816;c[3542094]=N+60203008;c[3542095]=N+60235776;c[3542096]=N+60268544;c[3542097]=N+60301312;c[3542100]=N+60334080;c[3542108]=N+60366848;Q=N+60387328|0;c[2411582]=Q;c[2414124]=Q;Q=N+1|0;R6(Q,0,2)|0;Q=c[2418142]|0;R6(Q,1,2)|0;Q=(c[2418142]|0)+1048577|0;R6(Q,2,2)|0;Q=(c[2418142]|0)+1048576|0;R6(Q,3,2)|0;Q=c[2411298]|0;do{if((c[3542200]|0)==0){R=0}else{N=L+108|0;c[N>>2]=0;S=L+100|0;c[S>>2]=0;T=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[T&16383](L,4)|0;if((c[N>>2]|0)==0){R=0;break}N=c[S>>2]|0;c[M>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](M,4,0)|0;if((N|0)<1){R=0;break}gzL(Q,0,4)|0;R=0}}while(0);while(1){if((R|0)>=1024){U=0;break}V=9638528+(R<<2)|0;if((c[V>>2]|0)==0){P=14335;break}else{R=R+1|0}}do{if((P|0)==14335){Q=gGq(14680064)|0;c[V>>2]=Q;if((Q|0)==0){U=0;break}gGz(Q|0,0,14680064);U=Q}}while(0);do{if((c[3542200]|0)!=0){Q=J+108|0;c[Q>>2]=0;N=J+100|0;c[N>>2]=0;S=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[S&16383](J,5)|0;if((c[Q>>2]|0)==0){break}Q=c[N>>2]|0;c[K>>2]=9534384;N=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[N&16383](K,5,0)|0;if((Q|0)<1){break}gzL(U,0,5)|0}}while(0);Q=U+2097152|0;do{if((c[3542200]|0)!=0){N=H+108|0;c[N>>2]=0;S=H+100|0;c[S>>2]=0;T=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[T&16383](H,6)|0;if((c[N>>2]|0)==0){break}N=c[S>>2]|0;c[I>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](I,6,0)|0;if((N|0)<1){break}gzL(Q,0,6)|0}}while(0);Q=U+4194304|0;do{if((c[3542200]|0)!=0){N=F+108|0;c[N>>2]=0;S=F+100|0;c[S>>2]=0;T=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[T&16383](F,7)|0;if((c[N>>2]|0)==0){break}N=c[S>>2]|0;c[G>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](G,7,0)|0;if((N|0)<1){break}gzL(Q,0,7)|0}}while(0);Q=U+6291456|0;do{if((c[3542200]|0)!=0){N=D+108|0;c[N>>2]=0;S=D+100|0;c[S>>2]=0;T=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[T&16383](D,8)|0;if((c[N>>2]|0)==0){break}N=c[S>>2]|0;c[E>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](E,8,0)|0;if((N|0)<1){break}gzL(Q,0,8)|0}}while(0);Q=U+8388608|0;do{if((c[3542200]|0)!=0){N=B+108|0;c[N>>2]=0;S=B+100|0;c[S>>2]=0;T=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[T&16383](B,9)|0;if((c[N>>2]|0)==0){break}N=c[S>>2]|0;c[C>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](C,9,0)|0;if((N|0)<1){break}gzL(Q,0,9)|0}}while(0);Q=U+10485760|0;do{if((c[3542200]|0)!=0){N=z+108|0;c[N>>2]=0;S=z+100|0;c[S>>2]=0;T=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[T&16383](z,10)|0;if((c[N>>2]|0)==0){break}N=c[S>>2]|0;c[A>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](A,10,0)|0;if((N|0)<1){break}gzL(Q,0,10)|0}}while(0);Q=U+12582912|0;do{if((c[3542200]|0)!=0){N=x+108|0;c[N>>2]=0;S=x+100|0;c[S>>2]=0;T=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[T&16383](x,11)|0;if((c[N>>2]|0)==0){break}N=c[S>>2]|0;c[y>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](y,11,0)|0;if((N|0)<1){break}gzL(Q,0,11)|0}}while(0);Q=c[3542098]|0;N=0;while(1){S=N>>>2<<6&64|N&16777088|N>>>4<<5&32|N>>>6<<4&16|N>>>1<<3&8|N>>>5<<2&4|N>>>3<<1&2;T=S|N&1;W=S&6;if((W|0)==0|(W|0)==6){X=T^6}else{X=T}T=a[U+N|0]|0;a[Q+(X^7)|0]=(T&255)>>>4|T<<4;T=N+1|0;if((T|0)<14680064){N=T}else{Y=0;break}}while(1){if((Y|0)>=1024){Z=Q;break}_=9638528+(Y<<2)|0;if((c[_>>2]|0)==(U|0)){P=14371;break}else{Y=Y+1|0}}if((P|0)==14371){gGr(U);c[_>>2]=0;Z=c[3542098]|0}Q=Z+14680063|0;N=Z+29360126|0;T=0;while(1){a[N]=a[Q]&15;a[N+1|0]=(d[Q]|0)>>>4;W=T+1|0;if((W|0)<14680064){Q=Q-1|0;N=N-2|0;T=W}else{break}}T=c[3542090]|0;do{if((c[3542200]|0)!=0){N=v+108|0;c[N>>2]=0;Q=v+100|0;c[Q>>2]=0;W=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[W&16383](v,12)|0;if((c[N>>2]|0)==0){break}N=c[Q>>2]|0;c[w>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](w,12,0)|0;if((N|0)<1){break}gzL(T,0,12)|0}}while(0);T=c[3542090]|0;N=T+2097151|0;Q=T+4194302|0;T=0;while(1){a[Q+1|0]=a[N]&15;a[Q]=(d[N]|0)>>>4;W=T+1|0;if((W|0)<2097152){N=N-1|0;Q=Q-2|0;T=W}else{break}}T=c[3542091]|0;do{if((c[3542200]|0)!=0){Q=t+108|0;c[Q>>2]=0;N=t+100|0;c[N>>2]=0;W=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[W&16383](t,13)|0;if((c[Q>>2]|0)==0){break}Q=c[N>>2]|0;c[u>>2]=9534384;N=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[N&16383](u,13,0)|0;if((Q|0)<1){break}gzL(T,0,13)|0}}while(0);T=c[3542091]|0;Q=T+1048575|0;N=T+2097150|0;T=0;while(1){a[N+1|0]=a[Q]&15;a[N]=(d[Q]|0)>>>4;W=T+1|0;if((W|0)<1048576){Q=Q-1|0;N=N-2|0;T=W}else{break}}T=c[3542092]|0;do{if((c[3542200]|0)!=0){N=r+108|0;c[N>>2]=0;Q=r+100|0;c[Q>>2]=0;W=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[W&16383](r,14)|0;if((c[N>>2]|0)==0){break}N=c[Q>>2]|0;c[s>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](s,14,0)|0;if((N|0)<1){break}gzL(T,0,14)|0}}while(0);T=c[3542092]|0;N=T+1048575|0;Q=T+2097150|0;T=0;while(1){a[Q+1|0]=a[N]&15;a[Q]=(d[N]|0)>>>4;W=T+1|0;if((W|0)<1048576){N=N-1|0;Q=Q-2|0;T=W}else{break}}T=c[3542093]|0;do{if((c[3542200]|0)!=0){Q=p+108|0;c[Q>>2]=0;N=p+100|0;c[N>>2]=0;W=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[W&16383](p,15)|0;if((c[Q>>2]|0)==0){break}Q=c[N>>2]|0;c[q>>2]=9534384;N=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[N&16383](q,15,0)|0;if((Q|0)<1){break}gzL(T,0,15)|0}}while(0);T=c[3542093]|0;Q=T+524287|0;N=T+1048574|0;T=0;while(1){a[N+1|0]=a[Q]&15;a[N]=(d[Q]|0)>>>4;W=T+1|0;if((W|0)<524288){Q=Q-1|0;N=N-2|0;T=W}else{break}}T=c[3541206]|0;do{if((c[3542200]|0)!=0){N=n+108|0;c[N>>2]=0;Q=n+100|0;c[Q>>2]=0;W=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[W&16383](n,16)|0;if((c[N>>2]|0)==0){break}N=c[Q>>2]|0;c[o>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](o,16,0)|0;if((N|0)<1){break}gzL(T,0,16)|0}}while(0);T=(c[3541206]|0)+2097152|0;do{if((c[3542200]|0)!=0){N=l+108|0;c[N>>2]=0;Q=l+100|0;c[Q>>2]=0;W=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[W&16383](l,17)|0;if((c[N>>2]|0)==0){break}N=c[Q>>2]|0;c[m>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](m,17,0)|0;if((N|0)<1){break}gzL(T,0,17)|0}}while(0);T=(c[3541206]|0)+4194304|0;do{if((c[3542200]|0)!=0){N=j+108|0;c[N>>2]=0;Q=j+100|0;c[Q>>2]=0;W=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[W&16383](j,18)|0;if((c[N>>2]|0)==0){break}N=c[Q>>2]|0;c[k>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](k,18,0)|0;if((N|0)<1){break}gzL(T,0,18)|0}}while(0);T=(c[3541206]|0)+6291456|0;do{if((c[3542200]|0)!=0){N=f+108|0;c[N>>2]=0;Q=f+100|0;c[Q>>2]=0;W=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[W&16383](f,19)|0;if((c[N>>2]|0)==0){break}N=c[Q>>2]|0;c[g>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](g,19,0)|0;if((N|0)<1){break}gzL(T,0,19)|0}}while(0);Tq(689896);fxU(0,425984);if((c[2394]|0)==0){$=c[2112932]|0}else{c[2394]=0;T=c[3532596]|0;c[2112932]=T;N=c[3532592]|0;if((N|0)!=0){gGC(9104152,N|0,280)|0}c[2113054]=c[2113060];$=T}T=c[2418142]|0;N=$|0;Q=0;while(1){W=T+Q|0;c[N>>2]=W;c[N+131072>>2]=W;W=Q+1024|0;if(W>>>0>2097151){break}else{N=N+4|0;Q=W}}Q=c[2418256]|0;N=$+16384|0;T=4194304;while(1){W=Q+(T-4194304)|0;c[N>>2]=W;c[N+65536>>2]=W;c[N+131072>>2]=W;W=T+1024|0;if(W>>>0>4259839){break}else{N=N+4|0;T=W}}T=c[3542096]|0;N=$+32768|0;W=8388608;while(1){S=T+(W-8388608)|0;c[N>>2]=S;c[N+65536>>2]=S;c[N+131072>>2]=S;S=W+1024|0;if(S>>>0>8421375){break}else{N=N+4|0;W=S}}W=c[3542094]|0;N=$+34816|0;T=8912896;while(1){S=W+(T-8912896)|0;c[N>>2]=S;c[N+65536>>2]=S;c[N+131072>>2]=S;S=T+1024|0;if(S>>>0>8945663){break}else{N=N+4|0;T=S}}T=c[3542095]|0;N=$+36864|0;W=9437184;while(1){S=T+(W-9437184)|0;c[N>>2]=S;c[N+65536>>2]=S;c[N+131072>>2]=S;S=W+1024|0;if(S>>>0>9469951){break}else{N=N+4|0;W=S}}W=c[3542097]|0;N=W+16384|0;c[$+38912>>2]=N;c[$+104448>>2]=N;c[$+169984>>2]=N;T=W+17408|0;c[$+38916>>2]=T;c[$+104452>>2]=T;c[$+169988>>2]=T;S=W+18432|0;c[$+38920>>2]=S;c[$+104456>>2]=S;c[$+169992>>2]=S;aa=W+19456|0;c[$+38924>>2]=aa;c[$+104460>>2]=aa;c[$+169996>>2]=aa;ab=W+20480|0;c[$+38928>>2]=ab;c[$+104464>>2]=ab;c[$+17e4>>2]=ab;ac=W+21504|0;c[$+38932>>2]=ac;c[$+104468>>2]=ac;c[$+170004>>2]=ac;ad=W+22528|0;c[$+38936>>2]=ad;c[$+104472>>2]=ad;c[$+170008>>2]=ad;ae=W+23552|0;c[$+38940>>2]=ae;c[$+104476>>2]=ae;c[$+170012>>2]=ae;af=W+24576|0;c[$+38944>>2]=af;c[$+104480>>2]=af;c[$+170016>>2]=af;ag=W+25600|0;c[$+38948>>2]=ag;c[$+104484>>2]=ag;c[$+170020>>2]=ag;ah=W+26624|0;c[$+38952>>2]=ah;c[$+104488>>2]=ah;c[$+170024>>2]=ah;ai=W+27648|0;c[$+38956>>2]=ai;c[$+104492>>2]=ai;c[$+170028>>2]=ai;aj=W+28672|0;c[$+38960>>2]=aj;c[$+104496>>2]=aj;c[$+170032>>2]=aj;ak=W+29696|0;c[$+38964>>2]=ak;c[$+104500>>2]=ak;c[$+170036>>2]=ak;al=W+30720|0;c[$+38968>>2]=al;c[$+104504>>2]=al;c[$+170040>>2]=al;am=W+31744|0;c[$+38972>>2]=am;c[$+104508>>2]=am;c[$+170044>>2]=am;c[$+38976>>2]=N;c[$+104512>>2]=N;c[$+170048>>2]=N;c[$+38980>>2]=T;c[$+104516>>2]=T;c[$+170052>>2]=T;c[$+38984>>2]=S;c[$+104520>>2]=S;c[$+170056>>2]=S;c[$+38988>>2]=aa;c[$+104524>>2]=aa;c[$+170060>>2]=aa;c[$+38992>>2]=ab;c[$+104528>>2]=ab;c[$+170064>>2]=ab;c[$+38996>>2]=ac;c[$+104532>>2]=ac;c[$+170068>>2]=ac;c[$+39e3>>2]=ad;c[$+104536>>2]=ad;c[$+170072>>2]=ad;c[$+39004>>2]=ae;c[$+104540>>2]=ae;c[$+170076>>2]=ae;c[$+39008>>2]=af;c[$+104544>>2]=af;c[$+170080>>2]=af;c[$+39012>>2]=ag;c[$+104548>>2]=ag;c[$+170084>>2]=ag;c[$+39016>>2]=ah;c[$+104552>>2]=ah;c[$+170088>>2]=ah;c[$+39020>>2]=ai;c[$+104556>>2]=ai;c[$+170092>>2]=ai;c[$+39024>>2]=aj;c[$+104560>>2]=aj;c[$+170096>>2]=aj;c[$+39028>>2]=ak;c[$+104564>>2]=ak;c[$+170100>>2]=ak;c[$+39032>>2]=al;c[$+104568>>2]=al;c[$+170104>>2]=al;c[$+39036>>2]=am;c[$+104572>>2]=am;c[$+170108>>2]=am;am=c[3542100]|0;al=$+40960|0;ak=10485760;while(1){aj=am+(ak-10485760)|0;c[al>>2]=aj;c[al+65536>>2]=aj;c[al+131072>>2]=aj;aj=ak+1024|0;if(aj>>>0>10518527){break}else{al=al+4|0;ak=aj}}ak=$+41088|0;al=10518528;while(1){am=Q+(al-10452992)|0;c[ak>>2]=am;c[ak+65536>>2]=am;c[ak+131072>>2]=am;am=al+1024|0;if(am>>>0>10616831){break}else{ak=ak+4|0;al=am}}al=c[3542108]|0;ak=$+61440|0;Q=15728640;while(1){am=al+(Q-15728640)|0;c[ak>>2]=am;c[ak+65536>>2]=am;c[ak+131072>>2]=am;am=Q+1024|0;if(am>>>0>15749119){break}else{ak=ak+4|0;Q=am}}c[$+196688>>2]=3548;c[$+196728>>2]=1036;c[$+196608>>2]=2988;c[$+196648>>2]=3334;Q=c[3532592]|0;if((Q|0)!=0){gGC(Q|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;aw$();Q=0;while(1){if((Q|0)>=1024){an=0;break}ao=9638528+(Q<<2)|0;if((c[ao>>2]|0)==0){P=14440;break}else{Q=Q+1|0}}do{if((P|0)==14440){Q=gGq(131072)|0;c[ao>>2]=Q;if((Q|0)==0){an=0;break}gGz(Q|0,0,131072);an=Q}}while(0);c[3542106]=an;gGz(an|0,0,131072);Q=0;while(1){if((Q|0)>=1024){ap=0;break}aq=9638528+(Q<<2)|0;if((c[aq>>2]|0)==0){P=14445;break}else{Q=Q+1|0}}do{if((P|0)==14445){Q=gGq(65536)|0;c[aq>>2]=Q;if((Q|0)==0){ap=0;break}gGz(Q|0,0,65536);ap=Q}}while(0);c[3527514]=ap;gGz(ap|0,0,65536);c[2112966]=c[3542106];c[3542078]=0;c[3542079]=0;c[3542080]=16;c[3542081]=0;c[3542082]=0;c[3542083]=16;c[3542084]=0;c[3542085]=0;c[3542086]=16;c[3542087]=0;c[3542088]=0;c[3542089]=16;c[2113284]=0;Q=c[642608+(c[2436]<<2)>>2]|0;if((c[Q+52>>2]&4|0)==0){ak=c[Q+128>>2]|0;c[2113280]=ak;ar=Q+132|0;as=ak}else{ak=c[Q+132>>2]|0;c[2113280]=ak;ar=Q+128|0;as=ak}ak=c[ar>>2]|0;c[2113276]=ak;c[2406716]=as-8;c[2394778]=as-16;c[2406714]=ak-8;c[2394776]=ak-16;c[3528974]=c[3564288+(((as|0)!=320)<<2)>>2];auH(3,29360128);axI(0,4194304,4,2048);axI(1,2097152,4,4096);axI(2,2097152,4,6144);axI(3,1048576,4,8192);c[2113294]=-112;c[2113292]=1;Vr(1,4e6,834,1942,6,0);c[2438228]=8e6;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=255;h[745419]=.8;a[3203368]=1;h[745418]=.4;a[3203360]=1;h[745417]=.4;a[3203352]=1;h[745416]=.4;a[3203344]=1;Ux(0,18181,1);Ux(1,18181,1);c[2407030]=205;c[2407068]=3;c[2407069]=256;c[2407107]=3;if((fa(c[c[642608+(c[2436]<<2)>>2]>>2]|0,230256)|0)==0){b[(c[2418142]|0)+54380>>1]=-11134}a[7072744]=1;aw3();at=0;i=e;return at|0}}while(0);c[2426686]=0;at=1;i=e;return at|0}function awQ(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;i=i+128|0;d=b|0;e=c[c[642608+(c[2436]<<2)>>2]>>2]|0;be(d|0,128,179600,(f=i,i=i+24|0,c[f>>2]=9374064,c[f+8>>2]=47,c[f+16>>2]=e,f)|0)|0;i=f;a[1040128]=0;f=c[2420380]|0;e=c[f>>2]|0;g=c[f+4>>2]|0;f=fw(d|0,389440)|0;if((f|0)!=0){d=g>>3<<e&1023;cj(14100392,d|0,1,f|0)|0;aY(f|0)|0}Uw(0);Uw(1);axH();f=c[2443764]|0;d=0;while(1){if((d|0)>=1024){break}h=9638528+(d<<2)|0;if((c[h>>2]|0)==(f|0)){j=14461;break}else{d=d+1|0}}if((j|0)==14461){gGr(f);c[h>>2]=0}c[2443764]=0;h=c[2394718]|0;f=0;while(1){if((f|0)>=1024){break}k=9638528+(f<<2)|0;if((c[k>>2]|0)==(h|0)){j=14465;break}else{f=f+1|0}}if((j|0)==14465){gGr(h);c[k>>2]=0}c[2394718]=0;a[7462192]=0;k=c[3542106]|0;h=0;while(1){if((h|0)>=1024){break}l=9638528+(h<<2)|0;if((c[l>>2]|0)==(k|0)){j=14469;break}else{h=h+1|0}}if((j|0)==14469){gGr(k);c[l>>2]=0}c[3542106]=0;l=c[3527514]|0;k=0;while(1){if((k|0)>=1024){break}m=9638528+(k<<2)|0;if((c[m>>2]|0)==(l|0)){j=14473;break}else{k=k+1|0}}if((j|0)==14473){gGr(l);c[m>>2]=0}c[3527514]=0;if((c[2392]|0)>=0){m=0;do{l=14130368+(m<<2)|0;k=c[l>>2]|0;if((k|0)!=0){gGr(k);c[l>>2]=0}l=14130384+(m<<2)|0;k=c[l>>2]|0;if((k|0)!=0){gGr(k);c[l>>2]=0}m=m+1|0;}while((m|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;fwZ();m=c[3541518]|0;if((m|0)!=0){gGr(m|0);c[3541518]=0}if((c[2385508]|0)>0){c[2113008]=0;c[2076598]=0;c[2383582]=0}c[2438228]=0;c[2433526]=0;c[2406676]=0;c[3528472]=0;m=c[2406680]|0;if((m|0)!=0){gGr(m);c[2406680]=0}c[2385508]=0;c[2432978]=0;a[64240]=0;c[3528930]=0;a[14117456]=0;c[3527358]=0;c[3527352]=0;m=c[2426686]|0;l=0;while(1){if((l|0)>=1024){j=14491;break}n=9638528+(l<<2)|0;if((c[n>>2]|0)==(m|0)){break}else{l=l+1|0}}if((j|0)==14491){c[2426686]=0;i=b;return 0}gGr(m);c[n>>2]=0;c[2426686]=0;i=b;return 0}function awR(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;if((a[9623864]|0)!=0){aw3()}b[4812800]=0;b[4812801]=0;d=0;f=0;g=0;do{f=((a[9632984+d|0]&1)<<d|f&65535)&65535;g=((a[9630856+d|0]&1)<<d|g&65535)&65535;d=d+1|0;}while((d|0)<11);b[4812800]=f;b[4812801]=g;if((f&3)==3){d=f&-4;b[4812800]=d;h=d}else{h=f}if((h&12)==12){b[4812800]=h&-13}if((g&3)==3){h=g&-4;b[4812801]=h;i=h}else{i=g}if((i&12)==12){b[4812801]=i&-13}i=c[2392]|0;if((i|0)>=0){gGz(8452240,0,((i|0)>0?(i<<2)+4|0:4)|0)}c[2113054]=0;i=c[2385548]|0;if((i|0)>0){gGz(9752472,0,((i|0)>1?i<<2:4)|0)}c[2433530]=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];i=c[3532592]|0;if((i|0)!=0){gGC(9104152,i|0,280)|0}c[2113054]=c[2113060]}i=c[2439330]|0;if((i|0)!=0){g=i;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;g=c[2438]|0;i=gGU(g,(g|0)<0|0?-1:0,16e6,0)|0;g=~~((+(i>>>0)+ +(K|0)*4294967296.0)/14732.965009208103);c[2440518]=g;a[6517968]=1;c[2444012]=0;i=g-~~(+(g*12|0|0)/271.5)|0;a[9627120]=0;h=1;f=g;g=1;while(1){d=(ag(h,f)|0)/100|0;do{if(g&(d|0)>(i|0)){j=c[2444012]|0;if((j|0)<(i|0)){k=i-j|0;c[2113056]=k;j=RG(k)|0;c[2113054]=(c[2113054]|0)+j;c[2276108]=-1;c[2113056]=-1;c[2444012]=(c[2444012]|0)+j}j=c[2112968]|0;do{if((j|0)!=0){avg(128);k=c[3542106]|0;l=0;m=c[3542108]|0;n=k;while(1){o=e[m>>1]|0;p=o>>>7&248;c[n>>2]=o>>>2<<8&63488|o&31|(p>>>5|p)<<3&2016;p=l+1|0;if((p|0)<10240){l=p;m=m+2|0;n=n+4|0}else{break}}n=c[k+130048>>2]|0;do{if((n|0)==0){gGz(j|0,0,ag(c[2113280]<<1,c[2113276]|0)|0)}else{m=n<<16|n;l=ag(c[2113276]|0,c[2113280]|0)|0;if((l|0)<=15){break}p=j;o=(l|0)/16|0;while(1){c[p>>2]=m;c[p+4>>2]=m;c[p+8>>2]=m;c[p+12>>2]=m;c[p+16>>2]=m;c[p+20>>2]=m;c[p+24>>2]=m;c[p+28>>2]=m;l=o-1|0;if((l|0)>0){p=p+32|0;o=l}else{break}}}}while(0);if(!(a[7072744]|0)){break}axE(1)}}while(0);a[9627120]=1;a[9541720]=0;c[8452200+(c[2394]<<2)>>2]=4097;c[2276080]=256;if((c[2276079]|0)>>>0>=256){break}RH(1)}}while(0);j=d-(c[2444012]|0)|0;c[2113056]=j;n=RG(j)|0;c[2113054]=(c[2113054]|0)+n;c[2276108]=-1;c[2113056]=-1;c[2444012]=(c[2444012]|0)+n;Sb(ag(a[6517968]|0?1390:0,h)|0);n=h+1|0;if((n|0)>=101){break}h=n;f=c[2440518]|0;g=(a[9627120]&1)==0}g=c[2394]|0;f=c[14130368+(g<<2)>>2]|0;if((f|0)!=0){gGC(f|0,9104152,280)|0}c[8452240+(g<<2)>>2]=c[2113054];c[2394]=-1;g=a[6517968]|0?139008:0;f=gGU(g,0,2048e6,0)|0;h=c[2438228]|0;i=gGS(f,K,h,(h|0)<0|0?-1:0)|0;h=i;Sb(g);g=c[2443830]|0;if((g|0)<1073676288){c[2443830]=g-h}g=c[2443831]|0;if((g|0)<1073676288){c[2443831]=g-h}g=(c[3528512]|0)-h|0;c[3528512]=(g|0)<0?0:g;g=c[2112964]|0;if((g|0)!=0){gg[c[3542122]&4095](g,a[9688]|0?534:0);g=c[2112964]|0;h=a[9688]|0?534:0;Uu(0,g,h);Uu(1,g,h)}h=c[1836236]|0;g=c[9757320+(h<<2)>>2]|0;if((g|0)==0){q=c[2433530]|0;r=9752472+(h<<2)|0;c[r>>2]=q;s=c[2076596]|0;t=14113936+(h<<2)|0;c[t>>2]=s;u=c[3541536]|0;v=9669104+(h<<2)|0;c[v>>2]=u;c[1836236]=-1;return 0}i=g;gGC(i|0,9706056,76)|0;q=c[2433530]|0;r=9752472+(h<<2)|0;c[r>>2]=q;s=c[2076596]|0;t=14113936+(h<<2)|0;c[t>>2]=s;u=c[3541536]|0;v=9669104+(h<<2)|0;c[v>>2]=u;c[1836236]=-1;return 0}function awS(){var b=0,d=0,f=0,g=0,h=0,i=0;avg(128);b=c[3542106]|0;d=0;f=c[3542108]|0;g=b;while(1){h=e[f>>1]|0;i=h>>>7&248;c[g>>2]=h>>>2<<8&63488|h&31|(i>>>5|i)<<3&2016;i=d+1|0;if((i|0)<10240){d=i;f=f+2|0;g=g+4|0}else{break}}g=c[b+130048>>2]|0;b=c[2112968]|0;do{if((g|0)==0){gGz(b|0,0,ag(c[2113280]<<1,c[2113276]|0)|0)}else{f=g<<16|g;d=ag(c[2113276]|0,c[2113280]|0)|0;if((d|0)<=15){break}i=b;h=(d|0)/16|0;while(1){c[i>>2]=f;c[i+4>>2]=f;c[i+8>>2]=f;c[i+12>>2]=f;c[i+16>>2]=f;c[i+20>>2]=f;c[i+24>>2]=f;c[i+28>>2]=f;d=h-1|0;if((d|0)>0){i=i+32|0;h=d}else{break}}}}while(0);if(!(a[7072744]|0)){return 0}axE(1);return 0}function awT(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;g=i;i=i+208|0;h=g|0;j=g+16|0;k=g+32|0;l=g+48|0;m=g+64|0;n=g+80|0;o=g+96|0;p=g+112|0;q=g+128|0;r=g+144|0;s=g+160|0;t=g+176|0;u=g+192|0;if((f|0)!=0){c[f>>2]=169753}Ts(e,f);if((e&96|0)==0){i=g;return 0}gGz(u|0,0,12);v=c[2405622]|0;c[u>>2]=v;c[u+4>>2]=(c[2411582]|0)-v;c[u+12>>2]=219592;gj[c[2076592]&4095](u)|0;u=k|0;do{if((e&64|0)!=0){gGz(j|0,0,16);c[2394]=-1;if((c[2392]|0)<0){break}v=k+9|0;w=h;x=h|0;y=h+4|0;z=h+12|0;A=j|0;B=j+4|0;C=j+12|0;D=0;do{gGC(u|0,614896,11)|0;a[v]=D+48&255;E=8452256+(D<<2)|0;gGz(w|0,0,12);c[x>>2]=E;c[y>>2]=4;c[z>>2]=164976;gj[c[2076592]&4095](h)|0;if((c[E>>2]|0)!=0){c[A>>2]=c[14130368+(D<<2)>>2];c[B>>2]=c[8452184+(D<<2)>>2];c[C>>2]=u;E=c[2076592]|0;gj[E&4095](j)|0}D=D+1|0;}while((D|0)<=(c[2392]|0))}}while(0);fw$(e);Vx(e,f);Ut(0);Ut(1);gGz(t|0,0,12);c[t>>2]=9541720;c[t+4>>2]=1;c[t+12>>2]=148144;gj[c[2076592]&4095](t)|0;gGz(s|0,0,12);c[s>>2]=9541952;c[s+4>>2]=1;c[s+12>>2]=118544;gj[c[2076592]&4095](s)|0;gGz(r|0,0,12);c[r>>2]=9775176;c[r+4>>2]=1;c[r+12>>2]=93520;gj[c[2076592]&4095](r)|0;gGz(q|0,0,12);c[q>>2]=9627120;c[q+4>>2]=1;c[q+12>>2]=490464;gj[c[2076592]&4095](q)|0;ayc();gGz(p|0,0,12);c[p>>2]=9625600;c[p+4>>2]=4;c[p+12>>2]=215728;gj[c[2076592]&4095](p)|0;gGz(o|0,0,12);c[o>>2]=14115720;c[o+4>>2]=4;c[o+12>>2]=361464;gj[c[2076592]&4095](o)|0;gGz(n|0,0,12);c[n>>2]=14117456;c[n+4>>2]=1;c[n+12>>2]=435944;gj[c[2076592]&4095](n)|0;gGz(m|0,0,12);c[m>>2]=14109432;c[m+4>>2]=4;c[m+12>>2]=533728;gj[c[2076592]&4095](m)|0;gGz(l|0,0,12);c[l>>2]=14109408;c[l+4>>2]=4;c[l+12>>2]=520224;gj[c[2076592]&4095](l)|0;if((e&2|0)==0){i=g;return 0}e=c[2439330]|0;l=(e|0)==0;if(!l){m=e;gGC(9706056,m|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];m=c[3528484]|0;c[2076596]=m;n=c[2417276]|0;c[3541536]=n;c[1836236]=0;o=c[2411298]|0;p=((d[14117456]|0)<<14)-32768|0;q=128;r=128;while(1){c[e+76+(r<<2)>>2]=o+(p+(r<<8));s=q+1&65535;if((s&65535)>191){F=128;G=128;break}else{q=s;r=s&65535}}while(1){r=o+(p+(G<<8))|0;c[e+76+(G+512<<2)>>2]=r;c[e+76+(G+768<<2)>>2]=r;r=F+1&65535;if((r&65535)>191){break}else{F=r;G=r&65535}}if(!l){l=e;gGC(l|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=m;c[2417276]=n;c[1836236]=-1;n=c[3541206]|0;m=n+((d[14109432]|0)<<16)|0;c[3541198]=m;c[3541190]=m;m=n+(((d[14109408]|0)<<16)+4194304)|0;c[3541202]=m;c[3541194]=m;m=(d[14109433]|0)<<16;c[3541199]=n+m;c[3541191]=n+(m|256);m=(d[14109409]|0)<<16;c[3541203]=n+(m+4194304);c[3541195]=n+(m+4194560);m=(d[14109434]|0)<<16;c[3541200]=n+m;c[3541192]=n+(m|512);m=(d[14109410]|0)<<16;c[3541204]=n+(m+4194304);c[3541196]=n+(m+4194816);m=(d[14109435]|0)<<16;c[3541201]=n+m;c[3541193]=n+(m|768);m=(d[14109411]|0)<<16;c[3541205]=n+(m+4194304);c[3541197]=n+(m+4195072);a[14168416]=1;i=g;return 0}function awU(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1430980+(b*112|0)>>2];c[a+104>>2]=c[1430984+(b*112|0)>>2];c[a+108>>2]=c[1430988+(b*112|0)>>2];d=0;return d|0}function awV(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=1430880+(b*112|0);e=0;return e|0}function awW(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2450660+(b*112|0)>>2];c[a+104>>2]=c[2450664+(b*112|0)>>2];c[a+108>>2]=c[2450668+(b*112|0)>>2];d=0;return d|0}function awX(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=2450560+(b*112|0);e=0;return e|0}function awY(){var b=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0;b=i;i=i+2040|0;e=b|0;f=b+112|0;g=b+120|0;j=b+232|0;k=b+240|0;l=b+352|0;m=b+360|0;n=b+472|0;o=b+480|0;p=b+592|0;q=b+600|0;r=b+712|0;s=b+720|0;t=b+832|0;u=b+840|0;v=b+952|0;w=b+960|0;x=b+1072|0;y=b+1080|0;z=b+1192|0;A=b+1200|0;B=b+1312|0;C=b+1320|0;D=b+1432|0;E=b+1440|0;F=b+1552|0;G=b+1560|0;H=b+1672|0;I=b+1680|0;J=b+1792|0;K=b+1800|0;L=b+1912|0;M=b+1920|0;N=b+2032|0;c[2424]=5755;c[2426686]=0;c[2418142]=0;c[2411298]=3145728;c[3542098]=3407872;c[3542090]=36962304;c[3542091]=41156608;c[3542092]=45350912;c[3542093]=49545216;c[3541206]=51642368;c[2405622]=60030976;c[2418256]=60030976;c[2411340]=60194816;c[3542094]=60203008;c[3542095]=60235776;c[3542096]=60268544;c[3542097]=60301312;c[3542100]=60334080;c[3542108]=60366848;c[2411582]=60387328;O=0;while(1){if((O|0)>=1024){break}P=9638528+(O<<2)|0;if((c[P>>2]|0)==0){Q=14607;break}else{O=O+1|0}}do{if((Q|0)==14607){O=gGq(60387328)|0;c[P>>2]=O;if((O|0)==0){break}c[2426686]=O;gGz(O|0,0,60387328);c[2418142]=O;c[2411298]=O+3145728;c[3542098]=O+3407872;c[3542090]=O+36962304;c[3542091]=O+41156608;c[3542092]=O+45350912;c[3542093]=O+49545216;c[3541206]=O+51642368;R=O+60030976|0;c[2405622]=R;c[2418256]=R;c[2411340]=O+60194816;c[3542094]=O+60203008;c[3542095]=O+60235776;c[3542096]=O+60268544;c[3542097]=O+60301312;c[3542100]=O+60334080;c[3542108]=O+60366848;R=O+60387328|0;c[2411582]=R;c[2414124]=R;R=O+1|0;R6(R,0,2)|0;R=c[2418142]|0;R6(R,1,2)|0;R=(c[2418142]|0)+1048577|0;R6(R,2,2)|0;R=(c[2418142]|0)+1048576|0;R6(R,3,2)|0;R=(c[2418142]|0)+2097153|0;R6(R,4,2)|0;R=(c[2418142]|0)+2097152|0;R6(R,5,2)|0;R=c[2411298]|0;do{if((c[3542200]|0)==0){S=0}else{O=M+108|0;c[O>>2]=0;T=M+100|0;c[T>>2]=0;U=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[U&16383](M,6)|0;if((c[O>>2]|0)==0){S=0;break}O=c[T>>2]|0;c[N>>2]=9534384;T=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[T&16383](N,6,0)|0;if((O|0)<1){S=0;break}gzL(R,0,6)|0;S=0}}while(0);while(1){if((S|0)>=1024){V=0;break}W=9638528+(S<<2)|0;if((c[W>>2]|0)==0){Q=14615;break}else{S=S+1|0}}do{if((Q|0)==14615){R=gGq(16777216)|0;c[W>>2]=R;if((R|0)==0){V=0;break}gGz(R|0,0,16777216);V=R}}while(0);do{if((c[3542200]|0)!=0){R=K+108|0;c[R>>2]=0;O=K+100|0;c[O>>2]=0;T=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[T&16383](K,7)|0;if((c[R>>2]|0)==0){break}R=c[O>>2]|0;c[L>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](L,7,0)|0;if((R|0)<1){break}gzL(V,0,7)|0}}while(0);R=V+2097152|0;do{if((c[3542200]|0)!=0){O=I+108|0;c[O>>2]=0;T=I+100|0;c[T>>2]=0;U=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[U&16383](I,8)|0;if((c[O>>2]|0)==0){break}O=c[T>>2]|0;c[J>>2]=9534384;T=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[T&16383](J,8,0)|0;if((O|0)<1){break}gzL(R,0,8)|0}}while(0);R=V+4194304|0;do{if((c[3542200]|0)!=0){O=G+108|0;c[O>>2]=0;T=G+100|0;c[T>>2]=0;U=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[U&16383](G,9)|0;if((c[O>>2]|0)==0){break}O=c[T>>2]|0;c[H>>2]=9534384;T=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[T&16383](H,9,0)|0;if((O|0)<1){break}gzL(R,0,9)|0}}while(0);R=V+6291456|0;do{if((c[3542200]|0)!=0){O=E+108|0;c[O>>2]=0;T=E+100|0;c[T>>2]=0;U=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[U&16383](E,10)|0;if((c[O>>2]|0)==0){break}O=c[T>>2]|0;c[F>>2]=9534384;T=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[T&16383](F,10,0)|0;if((O|0)<1){break}gzL(R,0,10)|0}}while(0);R=V+8388608|0;do{if((c[3542200]|0)!=0){O=C+108|0;c[O>>2]=0;T=C+100|0;c[T>>2]=0;U=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[U&16383](C,11)|0;if((c[O>>2]|0)==0){break}O=c[T>>2]|0;c[D>>2]=9534384;T=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[T&16383](D,11,0)|0;if((O|0)<1){break}gzL(R,0,11)|0}}while(0);R=V+10485760|0;do{if((c[3542200]|0)!=0){O=A+108|0;c[O>>2]=0;T=A+100|0;c[T>>2]=0;U=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[U&16383](A,12)|0;if((c[O>>2]|0)==0){break}O=c[T>>2]|0;c[B>>2]=9534384;T=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[T&16383](B,12,0)|0;if((O|0)<1){break}gzL(R,0,12)|0}}while(0);R=V+12582912|0;do{if((c[3542200]|0)!=0){O=y+108|0;c[O>>2]=0;T=y+100|0;c[T>>2]=0;U=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[U&16383](y,13)|0;if((c[O>>2]|0)==0){break}O=c[T>>2]|0;c[z>>2]=9534384;T=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[T&16383](z,13,0)|0;if((O|0)<1){break}gzL(R,0,13)|0}}while(0);R=V+14680064|0;do{if((c[3542200]|0)!=0){O=w+108|0;c[O>>2]=0;T=w+100|0;c[T>>2]=0;U=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[U&16383](w,14)|0;if((c[O>>2]|0)==0){break}O=c[T>>2]|0;c[x>>2]=9534384;T=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[T&16383](x,14,0)|0;if((O|0)<1){break}gzL(R,0,14)|0}}while(0);R=c[3542098]|0;O=0;while(1){T=O>>>2<<6&64|O&16777088|O>>>4<<5&32|O>>>6<<4&16|O>>>1<<3&8|O>>>5<<2&4|O>>>3<<1&2;U=T|O&1;X=T&6;if((X|0)==0|(X|0)==6){Y=U^6}else{Y=U}U=a[V+O|0]|0;a[R+(Y^7)|0]=(U&255)>>>4|U<<4;U=O+1|0;if((U|0)<16777216){O=U}else{Z=0;break}}while(1){if((Z|0)>=1024){_=R;break}$=9638528+(Z<<2)|0;if((c[$>>2]|0)==(V|0)){Q=14655;break}else{Z=Z+1|0}}if((Q|0)==14655){gGr(V);c[$>>2]=0;_=c[3542098]|0}R=_+16777215|0;O=_+33554430|0;U=0;while(1){a[O]=a[R]&15;a[O+1|0]=(d[R]|0)>>>4;X=U+1|0;if((X|0)<16777216){R=R-1|0;O=O-2|0;U=X}else{break}}U=c[3542090]|0;do{if((c[3542200]|0)!=0){O=u+108|0;c[O>>2]=0;R=u+100|0;c[R>>2]=0;X=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[X&16383](u,15)|0;if((c[O>>2]|0)==0){break}O=c[R>>2]|0;c[v>>2]=9534384;R=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[R&16383](v,15,0)|0;if((O|0)<1){break}gzL(U,0,15)|0}}while(0);U=c[3542090]|0;O=U+2097151|0;R=U+4194302|0;U=0;while(1){a[R+1|0]=a[O]&15;a[R]=(d[O]|0)>>>4;X=U+1|0;if((X|0)<2097152){O=O-1|0;R=R-2|0;U=X}else{break}}U=c[3542091]|0;do{if((c[3542200]|0)!=0){R=s+108|0;c[R>>2]=0;O=s+100|0;c[O>>2]=0;X=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[X&16383](s,16)|0;if((c[R>>2]|0)==0){break}R=c[O>>2]|0;c[t>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](t,16,0)|0;if((R|0)<1){break}gzL(U,0,16)|0}}while(0);U=c[3542091]|0;R=U+2097151|0;O=U+4194302|0;U=0;while(1){a[O+1|0]=a[R]&15;a[O]=(d[R]|0)>>>4;X=U+1|0;if((X|0)<2097152){R=R-1|0;O=O-2|0;U=X}else{break}}U=c[3542092]|0;do{if((c[3542200]|0)!=0){O=q+108|0;c[O>>2]=0;R=q+100|0;c[R>>2]=0;X=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[X&16383](q,17)|0;if((c[O>>2]|0)==0){break}O=c[R>>2]|0;c[r>>2]=9534384;R=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[R&16383](r,17,0)|0;if((O|0)<1){break}gzL(U,0,17)|0}}while(0);U=c[3542092]|0;O=U+2097151|0;R=U+4194302|0;U=0;while(1){a[R+1|0]=a[O]&15;a[R]=(d[O]|0)>>>4;X=U+1|0;if((X|0)<2097152){O=O-1|0;R=R-2|0;U=X}else{break}}U=c[3542093]|0;do{if((c[3542200]|0)!=0){R=o+108|0;c[R>>2]=0;O=o+100|0;c[O>>2]=0;X=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[X&16383](o,18)|0;if((c[R>>2]|0)==0){break}R=c[O>>2]|0;c[p>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](p,18,0)|0;if((R|0)<1){break}gzL(U,0,18)|0}}while(0);U=c[3542093]|0;R=U+524287|0;O=U+1048574|0;U=0;while(1){a[O+1|0]=a[R]&15;a[O]=(d[R]|0)>>>4;X=U+1|0;if((X|0)<524288){R=R-1|0;O=O-2|0;U=X}else{break}}U=c[3541206]|0;do{if((c[3542200]|0)!=0){O=m+108|0;c[O>>2]=0;R=m+100|0;c[R>>2]=0;X=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[X&16383](m,19)|0;if((c[O>>2]|0)==0){break}O=c[R>>2]|0;c[n>>2]=9534384;R=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[R&16383](n,19,0)|0;if((O|0)<1){break}gzL(U,0,19)|0}}while(0);U=(c[3541206]|0)+2097152|0;do{if((c[3542200]|0)!=0){O=k+108|0;c[O>>2]=0;R=k+100|0;c[R>>2]=0;X=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[X&16383](k,20)|0;if((c[O>>2]|0)==0){break}O=c[R>>2]|0;c[l>>2]=9534384;R=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[R&16383](l,20,0)|0;if((O|0)<1){break}gzL(U,0,20)|0}}while(0);U=(c[3541206]|0)+4194304|0;do{if((c[3542200]|0)!=0){O=g+108|0;c[O>>2]=0;R=g+100|0;c[R>>2]=0;X=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[X&16383](g,21)|0;if((c[O>>2]|0)==0){break}O=c[R>>2]|0;c[j>>2]=9534384;R=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[R&16383](j,21,0)|0;if((O|0)<1){break}gzL(U,0,21)|0}}while(0);U=(c[3541206]|0)+6291456|0;do{if((c[3542200]|0)!=0){O=e+108|0;c[O>>2]=0;R=e+100|0;c[R>>2]=0;X=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[X&16383](e,22)|0;if((c[O>>2]|0)==0){break}O=c[R>>2]|0;c[f>>2]=9534384;R=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[R&16383](f,22,0)|0;if((O|0)<1){break}gzL(U,0,22)|0}}while(0);Tq(689896);fxU(0,425984);if((c[2394]|0)==0){aa=c[2112932]|0}else{c[2394]=0;U=c[3532596]|0;c[2112932]=U;O=c[3532592]|0;if((O|0)!=0){gGC(9104152,O|0,280)|0}c[2113054]=c[2113060];aa=U}U=c[2418142]|0;O=aa|0;R=0;while(1){X=U+R|0;c[O>>2]=X;c[O+131072>>2]=X;X=R+1024|0;if(X>>>0>2097151){break}else{O=O+4|0;R=X}}R=c[2418256]|0;O=aa+16384|0;X=4194304;while(1){T=R+(X-4194304)|0;c[O>>2]=T;c[O+65536>>2]=T;c[O+131072>>2]=T;T=X+1024|0;if(T>>>0>4259839){break}else{O=O+4|0;X=T}}X=aa+24576|0;O=6291456;while(1){T=U+(O-4194304)|0;c[X>>2]=T;c[X+131072>>2]=T;T=O+1024|0;if(T>>>0>7340031){break}else{X=X+4|0;O=T}}O=c[3542096]|0;X=aa+32768|0;U=8388608;while(1){T=O+(U-8388608)|0;c[X>>2]=T;c[X+65536>>2]=T;c[X+131072>>2]=T;T=U+1024|0;if(T>>>0>8421375){break}else{X=X+4|0;U=T}}U=c[3542094]|0;X=aa+34816|0;O=8912896;while(1){T=U+(O-8912896)|0;c[X>>2]=T;c[X+65536>>2]=T;c[X+131072>>2]=T;T=O+1024|0;if(T>>>0>8945663){break}else{X=X+4|0;O=T}}O=c[3542095]|0;X=aa+36864|0;U=9437184;while(1){T=O+(U-9437184)|0;c[X>>2]=T;c[X+65536>>2]=T;c[X+131072>>2]=T;T=U+1024|0;if(T>>>0>9469951){break}else{X=X+4|0;U=T}}U=c[3542097]|0;X=U+16384|0;c[aa+38912>>2]=X;c[aa+104448>>2]=X;c[aa+169984>>2]=X;O=U+17408|0;c[aa+38916>>2]=O;c[aa+104452>>2]=O;c[aa+169988>>2]=O;T=U+18432|0;c[aa+38920>>2]=T;c[aa+104456>>2]=T;c[aa+169992>>2]=T;ab=U+19456|0;c[aa+38924>>2]=ab;c[aa+104460>>2]=ab;c[aa+169996>>2]=ab;ac=U+20480|0;c[aa+38928>>2]=ac;c[aa+104464>>2]=ac;c[aa+17e4>>2]=ac;ad=U+21504|0;c[aa+38932>>2]=ad;c[aa+104468>>2]=ad;c[aa+170004>>2]=ad;ae=U+22528|0;c[aa+38936>>2]=ae;c[aa+104472>>2]=ae;c[aa+170008>>2]=ae;af=U+23552|0;c[aa+38940>>2]=af;c[aa+104476>>2]=af;c[aa+170012>>2]=af;ag=U+24576|0;c[aa+38944>>2]=ag;c[aa+104480>>2]=ag;c[aa+170016>>2]=ag;ah=U+25600|0;c[aa+38948>>2]=ah;c[aa+104484>>2]=ah;c[aa+170020>>2]=ah;ai=U+26624|0;c[aa+38952>>2]=ai;c[aa+104488>>2]=ai;c[aa+170024>>2]=ai;aj=U+27648|0;c[aa+38956>>2]=aj;c[aa+104492>>2]=aj;c[aa+170028>>2]=aj;ak=U+28672|0;c[aa+38960>>2]=ak;c[aa+104496>>2]=ak;c[aa+170032>>2]=ak;al=U+29696|0;c[aa+38964>>2]=al;c[aa+104500>>2]=al;c[aa+170036>>2]=al;am=U+30720|0;c[aa+38968>>2]=am;c[aa+104504>>2]=am;c[aa+170040>>2]=am;an=U+31744|0;c[aa+38972>>2]=an;c[aa+104508>>2]=an;c[aa+170044>>2]=an;c[aa+38976>>2]=X;c[aa+104512>>2]=X;c[aa+170048>>2]=X;c[aa+38980>>2]=O;c[aa+104516>>2]=O;c[aa+170052>>2]=O;c[aa+38984>>2]=T;c[aa+104520>>2]=T;c[aa+170056>>2]=T;c[aa+38988>>2]=ab;c[aa+104524>>2]=ab;c[aa+170060>>2]=ab;c[aa+38992>>2]=ac;c[aa+104528>>2]=ac;c[aa+170064>>2]=ac;c[aa+38996>>2]=ad;c[aa+104532>>2]=ad;c[aa+170068>>2]=ad;c[aa+39e3>>2]=ae;c[aa+104536>>2]=ae;c[aa+170072>>2]=ae;c[aa+39004>>2]=af;c[aa+104540>>2]=af;c[aa+170076>>2]=af;c[aa+39008>>2]=ag;c[aa+104544>>2]=ag;c[aa+170080>>2]=ag;c[aa+39012>>2]=ah;c[aa+104548>>2]=ah;c[aa+170084>>2]=ah;c[aa+39016>>2]=ai;c[aa+104552>>2]=ai;c[aa+170088>>2]=ai;c[aa+39020>>2]=aj;c[aa+104556>>2]=aj;c[aa+170092>>2]=aj;c[aa+39024>>2]=ak;c[aa+104560>>2]=ak;c[aa+170096>>2]=ak;c[aa+39028>>2]=al;c[aa+104564>>2]=al;c[aa+170100>>2]=al;c[aa+39032>>2]=am;c[aa+104568>>2]=am;c[aa+170104>>2]=am;c[aa+39036>>2]=an;c[aa+104572>>2]=an;c[aa+170108>>2]=an;an=c[3542100]|0;am=aa+40960|0;al=10485760;while(1){ak=an+(al-10485760)|0;c[am>>2]=ak;c[am+65536>>2]=ak;c[am+131072>>2]=ak;ak=al+1024|0;if(ak>>>0>10518527){break}else{am=am+4|0;al=ak}}al=aa+41088|0;am=10518528;while(1){an=R+(am-10452992)|0;c[al>>2]=an;c[al+65536>>2]=an;c[al+131072>>2]=an;an=am+1024|0;if(an>>>0>10616831){break}else{al=al+4|0;am=an}}am=c[3542108]|0;al=aa+61440|0;R=15728640;while(1){an=am+(R-15728640)|0;c[al>>2]=an;c[al+65536>>2]=an;c[al+131072>>2]=an;an=R+1024|0;if(an>>>0>15749119){break}else{al=al+4|0;R=an}}c[aa+196688>>2]=3548;c[aa+196728>>2]=1036;c[aa+196608>>2]=2988;c[aa+196648>>2]=3334;R=c[3532592]|0;if((R|0)!=0){gGC(R|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;aw$();R=0;while(1){if((R|0)>=1024){ao=0;break}ap=9638528+(R<<2)|0;if((c[ap>>2]|0)==0){Q=14726;break}else{R=R+1|0}}do{if((Q|0)==14726){R=gGq(131072)|0;c[ap>>2]=R;if((R|0)==0){ao=0;break}gGz(R|0,0,131072);ao=R}}while(0);c[3542106]=ao;gGz(ao|0,0,131072);R=0;while(1){if((R|0)>=1024){aq=0;break}ar=9638528+(R<<2)|0;if((c[ar>>2]|0)==0){Q=14731;break}else{R=R+1|0}}do{if((Q|0)==14731){R=gGq(65536)|0;c[ar>>2]=R;if((R|0)==0){aq=0;break}gGz(R|0,0,65536);aq=R}}while(0);c[3527514]=aq;gGz(aq|0,0,65536);c[2112966]=c[3542106];c[3542078]=0;c[3542079]=0;c[3542080]=16;c[3542081]=0;c[3542082]=0;c[3542083]=16;c[3542084]=0;c[3542085]=0;c[3542086]=16;c[3542087]=0;c[3542088]=0;c[3542089]=16;c[2113284]=0;R=c[642608+(c[2436]<<2)>>2]|0;if((c[R+52>>2]&4|0)==0){al=c[R+128>>2]|0;c[2113280]=al;as=R+132|0;at=al}else{al=c[R+132>>2]|0;c[2113280]=al;as=R+128|0;at=al}al=c[as>>2]|0;c[2113276]=al;c[2406716]=at-8;c[2394778]=at-16;c[2406714]=al-8;c[2394776]=al-16;c[3528974]=c[3564288+(((at|0)!=320)<<2)>>2];auH(3,33554432);axI(0,4194304,4,2048);axI(1,4194304,4,4096);axI(2,4194304,4,6144);axI(3,1048576,4,8192);c[2113294]=-112;c[2113292]=1;Vr(1,4e6,834,1942,6,0);c[2438228]=8e6;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=255;h[745419]=.8;a[3203368]=1;h[745418]=.4;a[3203360]=1;h[745417]=.4;a[3203352]=1;h[745416]=.4;a[3203344]=1;Ux(0,18181,1);Ux(1,18181,1);c[2407030]=205;c[2407068]=3;c[2407069]=256;c[2407107]=3;a[7072744]=1;aw3();au=0;i=b;return au|0}}while(0);c[2426686]=0;au=1;i=b;return au|0}function awZ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1437124+(b*112|0)>>2];c[a+104>>2]=c[1437128+(b*112|0)>>2];c[a+108>>2]=c[1437132+(b*112|0)>>2];d=0;return d|0}function aw_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=1437024+(b*112|0);e=0;return e|0}function aw$(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;fwR(0);a=c[2439330]|0;d=(a|0)==0;if(!d){e=a;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];e=c[3528484]|0;c[2076596]=e;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;c[a+4172>>2]=1820;c[a+4176>>2]=626;c[a+4180>>2]=2616;c[a+4184>>2]=892;g=c[2411298]|0;h=0;i=0;while(1){c[a+76+(i<<2)>>2]=g+(i<<8);j=h+1&65535;if((j&65535)>127){k=0;l=0;break}else{h=j;i=j&65535}}while(1){i=g+(l<<8)|0;c[a+76+(l+512<<2)>>2]=i;c[a+76+(l+768<<2)>>2]=i;i=k+1&65535;if((i&65535)>127){m=128;n=128;break}else{k=i;l=i&65535}}while(1){c[a+76+(n<<2)>>2]=g+(n<<8);l=m+1&65535;if((l&65535)>191){o=128;p=128;break}else{m=l;n=l&65535}}while(1){n=g+(p<<8)|0;c[a+76+(p+512<<2)>>2]=n;c[a+76+(p+768<<2)>>2]=n;n=o+1&65535;if((n&65535)>191){break}else{o=n;p=n&65535}}p=c[2411340]|0;o=224;g=224;while(1){c[a+76+(g<<2)>>2]=p+((g<<8)-57344);n=o+1&65535;if((n&65535)>255){q=224;r=224;break}else{o=n;g=n&65535}}while(1){c[a+76+(r+256<<2)>>2]=p+((r<<8)-57344);g=q+1&65535;if((g&65535)>255){s=224;t=224;break}else{q=g;r=g&65535}}while(1){r=p+((t<<8)-57344)|0;c[a+76+(t+512<<2)>>2]=r;c[a+76+(t+768<<2)>>2]=r;r=s+1&65535;if((r&65535)>255){break}else{s=r;t=r&65535}}if(d){u=c[2433530]|0;c[2438118]=u;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}d=a;gGC(d|0,9706056,76)|0;u=c[2433530]|0;c[2438118]=u;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}function aw0(b,c){b=b|0;c=c|0;a[9706117]=c&1;return}function aw1(a){a=a|0;var b=0,d=0;b=(c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,8e6,0)|0;return a|0}function aw2(){return+(+((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)/8.0e6)}function aw3(){var b=0,d=0,e=0,f=0,g=0,i=0,j=0,k=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];b=c[3532592]|0;if((b|0)!=0){gGC(9104152,b|0,280)|0}c[2113054]=c[2113060]}RI();b=c[2394]|0;d=c[14130368+(b<<2)>>2]|0;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[8452240+(b<<2)>>2]=c[2113054];c[2394]=-1;b=c[2439330]|0;d=(b|0)==0;if(!d){e=b;gGC(9706056,e|0,76)|0}e=c[2438118]|0;c[2433530]=e;f=c[3528484]|0;c[2076596]=f;g=c[2417276]|0;c[3541536]=g;c[1836236]=0;gGz(9706056,0,76);if(!d){d=b;gGC(d|0,9706056,76)|0}c[2438118]=e;c[3528484]=f;c[2417276]=g;c[1836236]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){g=0;do{lN(g);mB(g);g=g+1|0;}while((g|0)<(c[2385508]|0))}c[2113156]=0;a[9628264]=0;c[2407033]=0;g=c[3541206]|0;c[3541190]=g;c[3541198]=g;gGz(c[2430118]|0,0,16384);c[2407041]=4;f=g+256|0;c[3541191]=f;e=g+65536|0;c[3541199]=e;gGz(c[2430119]|0,0,16384);c[2407049]=4;d=g+512|0;c[3541192]=d;b=g+131072|0;c[3541200]=b;gGz(c[2430120]|0,0,16384);c[2407057]=4;i=g+768|0;c[3541193]=i;j=g+196608|0;c[3541201]=j;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2113157]=0;a[9628420]=0;c[2407072]=0;k=g+1048576|0;c[3541194]=k;c[3541202]=k;gGz(c[2430122]|0,0,16384);c[2407080]=4;c[3541195]=g+1048832;c[3541203]=g+1114112;gGz(c[2430123]|0,0,16384);c[2407088]=4;c[3541196]=g+1049088;c[3541204]=g+1179648;gGz(c[2430124]|0,0,16384);c[2407096]=4;c[3541197]=g+1049344;c[3541205]=g+1245184;gGz(c[2430125]|0,0,16384);c[2407104]=4;c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];a[9541720]=1;a[9541952]=1;a[9775176]=1;c[3528930]=0;c[2433326]=12;gGz(9747264,0,192);c[2429478]=0;c[2430064]=-1;a[14117456]=0;c[3527358]=0;c[3527352]=0;c[3541190]=g;c[3541198]=g;c[3541191]=f;c[3541199]=e;c[3541192]=d;c[3541200]=b;c[3541193]=i;c[3541201]=j;j=g+4194304|0;c[3541194]=j;c[3541202]=j;c[3541195]=g+4194560;c[3541203]=g+4259840;c[3541196]=g+4194816;c[3541204]=g+4325376;c[3541197]=g+4195072;c[3541205]=g+4390912;return}function aw4(d){d=d|0;var f=0,g=0,h=0,i=0,j=0;if((d|0)==8388610|(d|0)==8388611){f=c[2113010]|0;c[2113010]=0;c[2430402]=0;g=c[3531294]|0;if((g|0)!=0){gf[g&2047](0)}h=f&255;return h|0}else if((d|0)==3145732|(d|0)==3145733){f=a[9775168]|0;g=f<<1|a[9541712];a[9541712]=1;i=(a[9541944]|0)==0|f<<24>>24==0;a[9775640]=i&1;f=8452200+(c[2394]<<2)|0;if(!i){c[f>>2]=0;c[2276080]=0;h=g;return h|0}c[f>>2]=4097;c[2276080]=256;if((c[2276079]|0)>>>0>=256){h=g;return h|0}RH(1);h=g;return h|0}else if((d|0)==3145734|(d|0)==3145735){g=a[9541712]|0;f=a[9775168]<<1|g;a[9775168]=1;i=g<<24>>24==0|(a[9541944]|0)==0;a[9775640]=i&1;g=8452200+(c[2394]<<2)|0;if(!i){c[g>>2]=0;c[2276080]=0;h=f;return h|0}c[g>>2]=4097;c[2276080]=256;if((c[2276079]|0)>>>0>=256){h=f;return h|0}RH(1);h=f;return h|0}else if((d|0)==3145728|(d|0)==3145729|(d|0)==3145730|(d|0)==3145731){h=a[9775168]<<1|a[9541712];return h|0}else if((d|0)==13631504){h=((e[4812788]|0)>>>8^255)&255;return h|0}else if((d|0)==13631505){h=~(b[4812788]&255);return h|0}else if((d|0)==13631506){h=((e[4812789]|0)>>>8^255)&255;return h|0}else if((d|0)==13631507){d=b[4812789]&127;do{if((c[2406632]|0)==0){f=c[2443744]|0;if((f|0)<=0){j=128;break}c[2443744]=f-1;j=0}else{j=(c[2432962]|0)>>>((c[(c[2420380]|0)+4>>2]|0)>>>0)<<7&128}}while(0);h=((j|d)^127)&255;return h|0}else{h=0;return h|0}return 0}function aw5(d){d=d|0;var f=0,g=0,h=0,i=0,j=0;if((d|0)==13631504){f=~b[4812788];return f|0}else if((d|0)==3145734){g=a[9541712]|0;h=a[9775168]<<1|g<<24>>24;a[9775168]=1;i=g<<24>>24==0|(a[9541944]|0)==0;a[9775640]=i&1;g=8452200+(c[2394]<<2)|0;if(!i){c[g>>2]=0;c[2276080]=0;f=h;return f|0}c[g>>2]=4097;c[2276080]=256;if((c[2276079]|0)>>>0>=256){f=h;return f|0}RH(1);f=h;return f|0}else if((d|0)==3145728|(d|0)==3145730){f=a[9775168]<<1|a[9541712];return f|0}else if((d|0)==3145732){h=a[9775168]|0;g=h<<24>>24<<1|a[9541712];a[9541712]=1;i=(a[9541944]|0)==0|h<<24>>24==0;a[9775640]=i&1;h=8452200+(c[2394]<<2)|0;if(!i){c[h>>2]=0;c[2276080]=0;f=g;return f|0}c[h>>2]=4097;c[2276080]=256;if((c[2276079]|0)>>>0>=256){f=g;return f|0}RH(1);f=g;return f|0}else if((d|0)==8388610){g=c[2113010]|0;c[2113010]=0;c[2430402]=0;h=c[3531294]|0;if((h|0)!=0){gf[h&2047](0)}f=g&65535;return f|0}else if((d|0)==13631506){d=e[4812789]|0;do{if((c[2406632]|0)==0){g=c[2443744]|0;if((g|0)<=0){j=128;break}c[2443744]=g-1;j=0}else{j=(c[2432962]|0)>>>((c[(c[2420380]|0)+4>>2]|0)>>>0)<<7&128}}while(0);f=((j|d)^65407)&65535;return f|0}else{f=0;return f|0}return 0}function aw6(a,b){a=a|0;b=b|0;var d=0,e=0;if((a|0)==13631505){d=b&255;c[2415256]=d&128;e=d>>>5&1;c[3528406]=e^1;if((e|0)==0){c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2]}Tr(d>>>6&1);return}else if((a|0)==8388608|(a|0)==8388609){c[2113012]=b&255;return}else if((a|0)==8388610|(a|0)==8388611){Ui(b);return}else{return}}function aw7(a,b){a=a|0;b=b|0;if((a|0)==10485760){c[3542081]=b&65535;return}else if((a|0)==10485762){c[3542082]=b&65535;return}else if((a|0)==9437188){c[3542080]=b&65535;return}else if((a|0)==8388610){Ui(b&255);return}else if((a|0)==8388608){c[2113012]=b&255;return}else if((a|0)==9437186){c[3542079]=b&65535;return}else if((a|0)==3145736){gD[c[3542102]&8191]()|0;c[2113288]=b&65535;return}else if((a|0)==3145728){c[2113282]=b&65535;return}else if((a|0)==9437184){c[3542078]=b&65535;return}else if((a|0)==3145730){c[2113278]=b&65535;return}else if((a|0)==10485764){c[3542083]=b&65535;return}else if((a|0)==11534336){c[3542084]=b&65535;return}else if((a|0)==11534338){c[3542085]=b&65535;return}else if((a|0)==11534340){c[3542086]=b&65535;return}else if((a|0)==13631504){a=b&65535;c[2415256]=a&128;b=a>>>5&1;c[3528406]=b^1;if((b|0)==0){c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2]}Tr(a>>>6&1);return}else{return}}function aw8(b,d){b=b|0;d=d|0;var f=0,g=0;f=b&65535^1;b=c[3542108]|0;a[b+f|0]=d;g=(c[3527514]|0)+(f<<1)|0;if((a[g]|0)==d<<24>>24){return}a[g]=d;d=e[b+(f&65534)>>1]|0;b=d>>>7&248;c[(c[3542106]|0)+(f>>>1<<2)>>2]=d>>>2<<8&63488|d&31|(b>>>5|b)<<3&2016;return}function aw9(a,d){a=a|0;d=d|0;var e=0;e=a>>>1&32767;b[(c[3542108]|0)+(e<<1)>>1]=d;a=(c[3527514]|0)+(e<<1)|0;if((b[a>>1]|0)==d<<16>>16){return}b[a>>1]=d;a=d&65535;d=a>>>7&248;c[(c[3542106]|0)+(e<<2)>>2]=a>>>2<<8&63488|a&31|(d>>>5|d)<<3&2016;return}function axa(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4679868+(b*112|0)>>2];c[a+104>>2]=c[4679872+(b*112|0)>>2];c[a+108>>2]=c[4679876+(b*112|0)>>2];d=0;return d|0}function axb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=4679768+(b*112|0);e=0;return e|0}function axc(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1530624+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function axd(){var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;d=i;i=i+600|0;e=d|0;f=d+112|0;g=d+120|0;j=d+232|0;k=d+240|0;l=d+352|0;m=d+360|0;n=d+472|0;o=d+480|0;p=d+592|0;c[2424]=5755;c[2426684]=0;c[2418140]=0;c[3542098]=1048576;c[3542090]=34603008;c[3542091]=42991616;c[3542092]=47185920;c[3531292]=51380224;c[2439996]=55574528;c[2405620]=55574656;c[2418254]=55574656;c[3542094]=55640192;c[3542095]=55672960;c[3542096]=55705728;c[3542100]=55738496;c[3542108]=55804032;c[2411570]=55869568;q=0;while(1){if((q|0)>=1024){break}r=9638528+(q<<2)|0;if((c[r>>2]|0)==0){s=14928;break}else{q=q+1|0}}do{if((s|0)==14928){q=gGq(55869568)|0;c[r>>2]=q;if((q|0)==0){break}c[2426684]=q;gGz(q|0,0,55869568);c[2418140]=q;c[3542098]=q+1048576;c[3542090]=q+34603008;c[3542091]=q+42991616;c[3542092]=q+47185920;c[3531292]=q+51380224;c[2439996]=q+55574528;t=q+55574656|0;c[2405620]=t;c[2418254]=t;c[3542094]=q+55640192;c[3542095]=q+55672960;c[3542096]=q+55705728;c[3542100]=q+55738496;c[3542108]=q+55804032;t=q+55869568|0;c[2411570]=t;c[2414106]=t;R6(q,1,2)|0;q=(c[2418140]|0)+1|0;R6(q,0,2)|0;q=c[3542098]|0;R6(q,2,2)|0;q=(c[3542098]|0)+1|0;R6(q,3,2)|0;q=(c[3542098]|0)+16777216|0;R6(q,4,2)|0;q=(c[3542098]|0)+16777217|0;R6(q,5,2)|0;q=0;t=c[3542098]|0;while(1){u=a[t]|0;v=t+1|0;w=a[v]|0;a[t]=w&15|u<<4;a[v]=(w&255)>>>4|u&-16;u=q+1|0;if((u|0)<12582912){q=u;t=t+2|0}else{x=0;break}}do{t=(cT()|0)&65535;q=t&257;u=(t&1)==0?q:q|255;q=(u&256)==0?u:u|-256;u=c[3542098]|0;b[u+25165824+(x<<1)>>1]=q;b[u+27262976+(x<<1)>>1]=q;b[u+29360128+(x<<1)>>1]=q;b[u+31457280+(x<<1)>>1]=q;x=x+1|0;}while((x|0)<1048576);q=c[3542090]|0;do{if((c[3542200]|0)!=0){u=o+108|0;c[u>>2]=0;t=o+100|0;c[t>>2]=0;w=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[w&16383](o,6)|0;if((c[u>>2]|0)==0){break}u=c[t>>2]|0;c[p>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](p,6,0)|0;if((u|0)<1){break}gzL(q,0,6)|0}}while(0);q=0;u=c[3542090]|0;while(1){t=a[u]|0;w=u+1|0;v=a[w]|0;a[w]=v<<4|t&15;a[u]=v&-16|(t&255)>>>4;t=q+1|0;if((t|0)<4194304){q=t;u=u+2|0}else{break}}u=c[3542091]|0;do{if((c[3542200]|0)!=0){q=m+108|0;c[q>>2]=0;t=m+100|0;c[t>>2]=0;v=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[v&16383](m,7)|0;if((c[q>>2]|0)==0){break}q=c[t>>2]|0;c[n>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](n,7,0)|0;if((q|0)<1){break}gzL(u,0,7)|0}}while(0);u=0;q=c[3542091]|0;while(1){t=a[q]|0;v=q+1|0;w=a[v]|0;a[v]=w<<4|t&15;a[q]=w&-16|(t&255)>>>4;t=u+1|0;if((t|0)<2097152){u=t;q=q+2|0}else{break}}q=c[3542092]|0;do{if((c[3542200]|0)!=0){u=k+108|0;c[u>>2]=0;t=k+100|0;c[t>>2]=0;w=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[w&16383](k,8)|0;if((c[u>>2]|0)==0){break}u=c[t>>2]|0;c[l>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](l,8,0)|0;if((u|0)<1){break}gzL(q,0,8)|0}}while(0);q=0;u=c[3542092]|0;while(1){t=a[u]|0;w=u+1|0;v=a[w]|0;a[w]=v<<4|t&15;a[u]=v&-16|(t&255)>>>4;t=q+1|0;if((t|0)<2097152){q=t;u=u+2|0}else{break}}u=c[3531292]|0;do{if((c[3542200]|0)!=0){q=g+108|0;c[q>>2]=0;t=g+100|0;c[t>>2]=0;v=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[v&16383](g,9)|0;if((c[q>>2]|0)==0){break}q=c[t>>2]|0;c[j>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](j,9,0)|0;if((q|0)<1){break}gzL(u,0,9)|0}}while(0);u=c[2439996]|0;do{if((c[3542200]|0)!=0){q=e+108|0;c[q>>2]=0;t=e+100|0;c[t>>2]=0;v=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[v&16383](e,14)|0;if((c[q>>2]|0)==0){break}q=c[t>>2]|0;c[f>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](f,14,0)|0;if((q|0)<1){break}gzL(u,0,14)|0}}while(0);Tq(689776);if(!(a[1040128]|0)){u=c[2439996]|0;gGC(14100392,u|0,128)|0}fxU(0,425984);if((c[2394]|0)==0){y=c[2112932]|0}else{c[2394]=0;u=c[3532596]|0;c[2112932]=u;q=c[3532592]|0;if((q|0)!=0){gGC(9104152,q|0,280)|0}c[2113054]=c[2113060];y=u}u=c[2418140]|0;q=y|0;t=0;while(1){v=u+t|0;c[q>>2]=v;c[q+131072>>2]=v;v=t+1024|0;if(v>>>0>1048575){break}else{q=q+4|0;t=v}}t=c[2418254]|0;q=y+8192|0;u=2097152;while(1){v=t+(u-2097152)|0;c[q>>2]=v;c[q+65536>>2]=v;c[q+131072>>2]=v;v=u+1024|0;if(v>>>0>2162687){break}else{q=q+4|0;u=v}}u=c[3542100]|0;q=y+16384|0;t=4194304;while(1){v=u+(t-4194304)|0;c[q>>2]=v;c[q+65536>>2]=v;c[q+131072>>2]=v;v=t+1024|0;if(v>>>0>4259839){break}else{q=q+4|0;t=v}}t=c[3542094]|0;q=y+20480|0;u=5242880;while(1){v=t+(u-5242880)|0;c[q>>2]=v;c[q+65536>>2]=v;c[q+131072>>2]=v;v=u+1024|0;if(v>>>0>5275647){break}else{q=q+4|0;u=v}}u=c[3542095]|0;q=y+24576|0;t=6291456;while(1){v=u+(t-6291456)|0;c[q>>2]=v;c[q+65536>>2]=v;c[q+131072>>2]=v;v=t+1024|0;if(v>>>0>6324223){break}else{q=q+4|0;t=v}}t=c[3542096]|0;q=y+28672|0;u=7340032;while(1){v=t+(u-7340032)|0;c[q>>2]=v;c[q+65536>>2]=v;c[q+131072>>2]=v;v=u+1024|0;if(v>>>0>7372799){break}else{q=q+4|0;u=v}}u=c[3542108]|0;q=y+49152|0;t=q;v=12582912;while(1){w=u+(v-12582912)|0;c[t>>2]=w;c[t+131072>>2]=w;w=v+1024|0;if(w>>>0>12648447){z=q;A=12582912;break}else{t=t+4|0;v=w}}while(1){c[z+65536>>2]=1;v=A+1024|0;if(v>>>0>12648447){break}else{z=z+4|0;A=v}}c[y+196688>>2]=2650;c[y+196608>>2]=3236;c[y+196728>>2]=3256;c[y+196648>>2]=1098;c[y+196732>>2]=668;c[y+196652>>2]=2784;v=c[3532592]|0;if((v|0)!=0){gGC(v|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;c[2113290]=2;v=0;while(1){if((v|0)>=1024){B=0;break}C=9638528+(v<<2)|0;if((c[C>>2]|0)==0){s=14986;break}else{v=v+1|0}}do{if((s|0)==14986){v=gGq(131072)|0;c[C>>2]=v;if((v|0)==0){B=0;break}gGz(v|0,0,131072);B=v}}while(0);c[3542106]=B;gGz(B|0,0,131072);v=0;while(1){if((v|0)>=1024){D=0;break}E=9638528+(v<<2)|0;if((c[E>>2]|0)==0){s=14991;break}else{v=v+1|0}}do{if((s|0)==14991){v=gGq(65536)|0;c[E>>2]=v;if((v|0)==0){D=0;break}gGz(v|0,0,65536);D=v}}while(0);c[3527514]=D;gGz(D|0,0,65536);c[2112966]=c[3542106];c[3542078]=0;c[3542079]=0;c[3542080]=16;c[3542081]=0;c[3542082]=0;c[3542083]=16;c[3542084]=0;c[3542085]=0;c[3542086]=16;c[3542087]=0;c[3542088]=0;c[3542089]=16;c[2113284]=0;v=c[642608+(c[2436]<<2)>>2]|0;if((c[v+52>>2]&4|0)==0){t=c[v+128>>2]|0;c[2113280]=t;F=v+132|0;G=t}else{t=c[v+132>>2]|0;c[2113280]=t;F=v+128|0;G=t}t=c[F>>2]|0;c[2113276]=t;c[2406716]=G-8;c[2394778]=G-16;c[2406714]=t-8;c[2394776]=t-16;c[3528974]=c[3564288+(((G|0)!=320)<<2)>>2];auH(1,33554432);axI(0,8388608,8,16384);axI(1,4194304,8,16384);axI(2,4194304,8,16384);Uf(16934400,782);h[607287]=1.0;c[2433116]=1;h[607286]=1.0;c[2433114]=2;a[7072736]=1;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];t=c[3532592]|0;if((t|0)!=0){gGC(9104152,t|0,280)|0}c[2113054]=c[2113060]}RI();t=c[2394]|0;v=c[14130368+(t<<2)>>2]|0;if((v|0)!=0){gGC(v|0,9104152,280)|0}c[8452240+(t<<2)>>2]=c[2113054];c[2394]=-1;c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];gGz(14125184,0,668);c[2433532]=0;c[2430402]=0;c[2113010]=0;a[9753304]=0;c[2433552]=0;gGz(c[2430036]|0,0,16384);c[3531316]=4;gGz(c[2430037]|0,0,16384);c[3531337]=4;gGz(c[2430038]|0,0,16384);c[3531358]=4;gGz(c[2430039]|0,0,16384);c[3531379]=4;gGz(c[2430040]|0,0,16384);c[3531400]=4;gGz(c[2430041]|0,0,16384);c[3531421]=4;gGz(c[2430042]|0,0,16384);c[3531442]=4;gGz(c[2430043]|0,0,16384);c[3531463]=4;a[9541712]=1;a[9541944]=1;a[9775168]=1;a[9775640]=0;H=0;i=d;return H|0}}while(0);c[2426684]=0;H=1;i=d;return H|0}function axe(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;i=i+128|0;d=c[2406694]|0;if((d|0)!=0){gGr(d);c[2406694]=0}c[3531294]=0;d=b|0;e=c[c[642608+(c[2436]<<2)>>2]>>2]|0;be(d|0,128,179600,(f=i,i=i+24|0,c[f>>2]=9374064,c[f+8>>2]=47,c[f+16>>2]=e,f)|0)|0;i=f;a[1040128]=0;f=c[2420380]|0;e=c[f>>2]|0;g=c[f+4>>2]|0;f=fw(d|0,389440)|0;if((f|0)!=0){d=g>>3<<e&1023;cj(14100392,d|0,1,f|0)|0;aY(f|0)|0}axH();f=c[2443764]|0;d=0;while(1){if((d|0)>=1024){break}h=9638528+(d<<2)|0;if((c[h>>2]|0)==(f|0)){j=15013;break}else{d=d+1|0}}if((j|0)==15013){gGr(f);c[h>>2]=0}c[2443764]=0;h=c[2394718]|0;f=0;while(1){if((f|0)>=1024){break}k=9638528+(f<<2)|0;if((c[k>>2]|0)==(h|0)){j=15017;break}else{f=f+1|0}}if((j|0)==15017){gGr(h);c[k>>2]=0}c[2394718]=0;a[7462192]=0;k=c[3542106]|0;h=0;while(1){if((h|0)>=1024){break}l=9638528+(h<<2)|0;if((c[l>>2]|0)==(k|0)){j=15021;break}else{h=h+1|0}}if((j|0)==15021){gGr(k);c[l>>2]=0}c[3542106]=0;l=c[3527514]|0;k=0;while(1){if((k|0)>=1024){break}m=9638528+(k<<2)|0;if((c[m>>2]|0)==(l|0)){j=15025;break}else{k=k+1|0}}if((j|0)==15025){gGr(l);c[m>>2]=0}c[3527514]=0;if((c[2392]|0)>=0){m=0;do{l=14130368+(m<<2)|0;k=c[l>>2]|0;if((k|0)!=0){gGr(k);c[l>>2]=0}l=14130384+(m<<2)|0;k=c[l>>2]|0;if((k|0)!=0){gGr(k);c[l>>2]=0}m=m+1|0;}while((m|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;m=c[2426684]|0;l=0;while(1){if((l|0)>=1024){j=15037;break}n=9638528+(l<<2)|0;if((c[n>>2]|0)==(m|0)){break}else{l=l+1|0}}if((j|0)==15037){c[2426684]=0;i=b;return 0}gGr(m);c[n>>2]=0;c[2426684]=0;i=b;return 0}function axf(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;if((a[9623816]|0)!=0){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];gGz(14125184,0,668);c[2433532]=0;c[2430402]=0;c[2113010]=0;a[9753304]=0;c[2433552]=0;gGz(c[2430036]|0,0,16384);c[3531316]=4;gGz(c[2430037]|0,0,16384);c[3531337]=4;gGz(c[2430038]|0,0,16384);c[3531358]=4;gGz(c[2430039]|0,0,16384);c[3531379]=4;gGz(c[2430040]|0,0,16384);c[3531400]=4;gGz(c[2430041]|0,0,16384);c[3531421]=4;gGz(c[2430042]|0,0,16384);c[3531442]=4;gGz(c[2430043]|0,0,16384);c[3531463]=4;a[9541712]=1;a[9541944]=1;a[9775168]=1;a[9775640]=0}b[4812788]=0;b[4812789]=0;d=0;e=0;f=0;do{g=(a[9632904+d|0]&1)<<d|e&65535;e=g&65535;f=((a[9630792+d|0]&1)<<d|f&65535)&65535;d=d+1|0;}while((d|0)<16);b[4812788]=e;b[4812789]=f;f=g&255;g=(e&65535)>>>8&255;if((f&6)==6){e=f&-7;a[9625576]=e;h=e}else{h=f}if((h&24)==24){a[9625576]=h&-25}if((g&6)==6){h=g&-7;a[9625577]=h;i=h}else{i=g}if((i&24)==24){a[9625577]=i&-25}i=c[2392]|0;if((i|0)>=0){gGz(8452240,0,((i|0)>0?(i<<2)+4|0:4)|0)}c[2113054]=0;i=c[2438]|0;g=gGU(i,(i|0)<0|0?-1:0,16e6,0)|0;i=~~((+(g>>>0)+ +(K|0)*4294967296.0)/14732.965009208103);c[2440514]=i;c[2444066]=0;g=i-~~(+(i*12|0|0)/271.5)|0;a[9627112]=0;if((c[2394]|0)==0){j=1;k=0}else{c[2394]=0;c[2112932]=c[3532596];i=c[3532592]|0;if((i|0)!=0){gGC(9104152,i|0,280)|0}c[2113054]=c[2113060];j=1;k=0}while(1){i=c[2112964]|0;if((j&1|0)==0&(i|0)!=0){h=(ag(a[9688]|0?534:0,j)|0)/8|0;Ug(i+(k<<1<<1)|0,h-k|0);l=h}else{l=k}a[7024744]=0;h=(ag(c[2440514]|0,j)|0)/8|0;if((a[9627112]&1)==0&(h|0)>(g|0)){i=c[2444066]|0;if((i|0)<(g|0)){f=g-i|0;c[2113056]=f;i=RG(f)|0;c[2113054]=(c[2113054]|0)+i;c[2276108]=-1;c[2113056]=-1;f=9776264+(a[7024744]<<31>>31<<2)|0;c[f>>2]=(c[f>>2]|0)+i}i=c[2112968]|0;do{if((i|0)!=0){if((a[14168416]|0)==0){m=c[3542106]|0}else{f=c[3527514]|0;e=c[3542106]|0;d=c[3542108]|0;n=0;while(1){o=n<<8;p=0;q=d;r=f+(o<<1)|0;s=e+(o<<2)|0;while(1){o=b[q>>1]|0;b[r>>1]=o;t=o&65535;o=t>>>7&248;c[s>>2]=t>>>2<<8&63488|t&31|(o>>>5|o)<<3&2016;o=p+1|0;if((o|0)<256){p=o;q=q+2|0;r=r+2|0;s=s+4|0}else{break}}s=n+1|0;if((s|0)<128){d=d+512|0;n=s}else{break}}a[14168416]=0;m=e}n=c[m+130048>>2]|0;do{if((n|0)==0){gGz(i|0,0,ag(c[2113280]<<1,c[2113276]|0)|0)}else{d=n<<16|n;f=ag(c[2113276]|0,c[2113280]|0)|0;if((f|0)<=15){break}s=i;r=(f|0)/16|0;while(1){c[s>>2]=d;c[s+4>>2]=d;c[s+8>>2]=d;c[s+12>>2]=d;c[s+16>>2]=d;c[s+20>>2]=d;c[s+24>>2]=d;c[s+28>>2]=d;f=r-1|0;if((f|0)>0){s=s+32|0;r=f}else{break}}}}while(0);if(!(a[7072736]|0)){break}axE(1)}}while(0);a[9627112]=1;a[9541712]=0;a[9775640]=1;c[8452200+(c[2394]<<2)>>2]=4097;c[2276080]=256;if((c[2276079]|0)>>>0<256){RH(1)}u=a[7024744]<<31>>31}else{u=0}i=h-(c[9776264+(u<<2)>>2]|0)|0;c[2113056]=i;n=RG(i)|0;c[2113054]=(c[2113054]|0)+n;c[2276108]=-1;c[2113056]=-1;i=9776264+(a[7024744]<<31>>31<<2)|0;c[i>>2]=(c[i>>2]|0)+n;a[7024744]=1;n=j+1|0;if((n|0)<9){j=n;k=l}else{break}}k=c[2112964]|0;do{if((k|0)!=0){j=a[9688]|0?534:0;if((j|0)==(l|0)){break}Ug(k+(l<<1<<1)|0,j-l|0)}}while(0);l=c[2394]|0;k=c[14130368+(l<<2)>>2]|0;if((k|0)==0){v=c[2113054]|0;w=8452240+(l<<2)|0;c[w>>2]=v;c[2394]=-1;return 0}gGC(k|0,9104152,280)|0;v=c[2113054]|0;w=8452240+(l<<2)|0;c[w>>2]=v;c[2394]=-1;return 0}function axg(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((a[14168416]|0)==0){d=c[3542106]|0}else{e=c[3527514]|0;f=c[3542106]|0;g=c[3542108]|0;h=0;while(1){i=h<<8;j=0;k=g;l=e+(i<<1)|0;m=f+(i<<2)|0;while(1){i=b[k>>1]|0;b[l>>1]=i;n=i&65535;i=n>>>7&248;c[m>>2]=n>>>2<<8&63488|n&31|(i>>>5|i)<<3&2016;i=j+1|0;if((i|0)<256){j=i;k=k+2|0;l=l+2|0;m=m+4|0}else{break}}m=h+1|0;if((m|0)<128){g=g+512|0;h=m}else{break}}a[14168416]=0;d=f}f=c[d+130048>>2]|0;d=c[2112968]|0;do{if((f|0)==0){gGz(d|0,0,ag(c[2113280]<<1,c[2113276]|0)|0)}else{h=f<<16|f;g=ag(c[2113276]|0,c[2113280]|0)|0;if((g|0)<=15){break}e=d;m=(g|0)/16|0;while(1){c[e>>2]=h;c[e+4>>2]=h;c[e+8>>2]=h;c[e+12>>2]=h;c[e+16>>2]=h;c[e+20>>2]=h;c[e+24>>2]=h;c[e+28>>2]=h;g=m-1|0;if((g|0)>0){e=e+32|0;m=g}else{break}}}}while(0);if(!(a[7072736]|0)){return 0}axE(1);return 0}function axh(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;e=i;i=i+144|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;l=e+80|0;m=e+96|0;n=e+112|0;o=e+128|0;if((d|0)!=0){c[d>>2]=133378}Ts(b,d);if((b&96|0)!=0){gGz(o|0,0,12);d=c[2405620]|0;c[o>>2]=d;c[o+4>>2]=(c[2411570]|0)-d;c[o+12>>2]=219592;d=c[2076592]|0;gj[d&4095](o)|0;o=h|0;do{if((b&64|0)!=0){gGz(g|0,0,16);c[2394]=-1;if((c[2392]|0)<0){break}d=h+9|0;p=f;q=f|0;r=f+4|0;s=f+12|0;t=g|0;u=g+4|0;v=g+12|0;w=0;do{gGC(o|0,614896,11)|0;a[d]=w+48&255;x=8452256+(w<<2)|0;gGz(p|0,0,12);c[q>>2]=x;c[r>>2]=4;c[s>>2]=164976;gj[c[2076592]&4095](f)|0;if((c[x>>2]|0)!=0){c[t>>2]=c[14130368+(w<<2)>>2];c[u>>2]=c[8452184+(w<<2)>>2];c[v>>2]=o;x=c[2076592]|0;gj[x&4095](g)|0}w=w+1|0;}while((w|0)<=(c[2392]|0))}}while(0);Ue();gGz(n|0,0,12);c[n>>2]=9541712;c[n+4>>2]=1;c[n+12>>2]=148144;g=c[2076592]|0;gj[g&4095](n)|0;gGz(m|0,0,12);c[m>>2]=9541944;c[m+4>>2]=1;c[m+12>>2]=118544;n=c[2076592]|0;gj[n&4095](m)|0;gGz(l|0,0,12);c[l>>2]=9775168;c[l+4>>2]=1;c[l+12>>2]=93520;m=c[2076592]|0;gj[m&4095](l)|0;gGz(k|0,0,12);c[k>>2]=9627112;c[k+4>>2]=1;c[k+12>>2]=490464;l=c[2076592]|0;gj[l&4095](k)|0;ayc();gGz(j|0,0,12);c[j>>2]=9625576;c[j+4>>2]=4;c[j+12>>2]=215728;k=c[2076592]|0;gj[k&4095](j)|0}if((b&2|0)==0){i=e;return 0}a[14168416]=1;i=e;return 0}function axi(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2784108+(b*112|0)>>2];c[a+104>>2]=c[2784112+(b*112|0)>>2];c[a+108>>2]=c[2784116+(b*112|0)>>2];d=0;return d|0}function axj(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=2784008+(b*112|0);e=0;return e|0}function axk(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=(b^1)&255;a[9541944]=d;do{if((a[9541712]|0)==0|d<<24>>24==0){a[9775640]=1;e=4096;f=1;g=15142}else{b=(a[9775168]|0)==0;h=b&1;a[9775640]=h;if(b){e=b?4096:0;f=h;g=15142;break}c[8452200+(c[2394]<<2)>>2]=0;c[2276080]=0;i=h}}while(0);do{if((g|0)==15142){c[8452200+(c[2394]<<2)>>2]=e|1;c[2276080]=256;if((c[2276079]|0)>>>0>=256){i=f;break}RH(1);i=a[9775640]|0}}while(0);if(!(i<<24>>24!=0&a[7024744])){return}c[2113056]=1024;i=RG(1024)|0;c[2113054]=(c[2113054]|0)+i;c[2276108]=-1;c[2113056]=-1;c[2444066]=(c[2444066]|0)+i;return}function axl(d){d=d|0;var f=0,g=0,h=0,i=0,j=0;if((d|0)==13631488){f=((e[4812784]|0)>>>8^255)&255;return f|0}else if((d|0)==8388612|(d|0)==8388613){g=a[9775160]|0;h=g<<1|a[9541704];a[9541704]=1;i=(a[9541936]|0)==0|g<<24>>24==0;a[9775632]=i&1;g=8452200+(c[2394]<<2)|0;if(!i){c[g>>2]=0;c[2276080]=0;f=h;return f|0}c[g>>2]=4097;c[2276080]=256;if((c[2276079]|0)>>>0>=256){f=h;return f|0}RH(1);f=h;return f|0}else if((d|0)==3145731){h=c[2113010]|0;c[2113010]=0;c[2430402]=0;g=c[3531294]|0;if((g|0)!=0){gf[g&2047](0)}f=h&255;return f|0}else if((d|0)==8388614|(d|0)==8388615){h=a[9541704]|0;g=a[9775160]<<1|h;a[9775160]=1;i=h<<24>>24==0|(a[9541936]|0)==0;a[9775632]=i&1;h=8452200+(c[2394]<<2)|0;if(!i){c[h>>2]=0;c[2276080]=0;f=g;return f|0}c[h>>2]=4097;c[2276080]=256;if((c[2276079]|0)>>>0>=256){f=g;return f|0}RH(1);f=g;return f|0}else if((d|0)==13631489){f=~(b[4812784]&255);return f|0}else if((d|0)==13631491){f=~(b[4812785]&255);return f|0}else if((d|0)==8388608|(d|0)==8388609|(d|0)==8388610|(d|0)==8388611){f=a[9775160]<<1|a[9541704];return f|0}else if((d|0)==13631490){d=(e[4812785]|0)>>>8;do{if((c[2406632]|0)==0){g=c[2443744]|0;if((g|0)<=0){j=8;break}c[2443744]=g-1;j=0}else{j=(c[2432962]|0)>>>((c[(c[2420380]|0)+4>>2]|0)>>>0)<<3&8}}while(0);f=((j|d)^247)&255;return f|0}else{f=0;return f|0}return 0}function axm(d){d=d|0;var f=0,g=0,h=0,i=0,j=0;if((d|0)==8388612){f=a[9775160]|0;g=f<<24>>24<<1|a[9541704];a[9541704]=1;h=(a[9541936]|0)==0|f<<24>>24==0;a[9775632]=h&1;f=8452200+(c[2394]<<2)|0;if(!h){c[f>>2]=0;c[2276080]=0;i=g;return i|0}c[f>>2]=4097;c[2276080]=256;if((c[2276079]|0)>>>0>=256){i=g;return i|0}RH(1);i=g;return i|0}else if((d|0)==3145730){g=c[2113010]|0;c[2113010]=0;c[2430402]=0;f=c[3531294]|0;if((f|0)!=0){gf[f&2047](0)}i=g&65535;return i|0}else if((d|0)==8388614){g=a[9541704]|0;f=a[9775160]<<1|g<<24>>24;a[9775160]=1;h=g<<24>>24==0|(a[9541936]|0)==0;a[9775632]=h&1;g=8452200+(c[2394]<<2)|0;if(!h){c[g>>2]=0;c[2276080]=0;i=f;return i|0}c[g>>2]=4097;c[2276080]=256;if((c[2276079]|0)>>>0>=256){i=f;return i|0}RH(1);i=f;return i|0}else if((d|0)==13631488){i=~b[4812784];return i|0}else if((d|0)==13631490){f=e[4812785]|0;do{if((c[2406632]|0)==0){g=c[2443744]|0;if((g|0)<=0){j=2048;break}c[2443744]=g-1;j=0}else{j=(c[2432962]|0)>>>((c[(c[2420380]|0)+4>>2]|0)>>>0)<<11&2048}}while(0);i=((j|f)^63487)&65535;return i|0}else if((d|0)==8388608|(d|0)==8388610){i=a[9775160]<<1|a[9541704];return i|0}else{i=0;return i|0}return 0}function axn(a,b){a=a|0;b=b|0;var d=0,e=0;if((a|0)==3145729){c[2113012]=b&255;return}else if((a|0)==14680064){d=b&255;c[2415256]=d&8;e=d>>>1&1;c[3528406]=e^1;if((e|0)==0){c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2]}Tr(d>>>2&1);return}else if((a|0)==3145731){Ui(b);return}else{return}}function axo(a,b){a=a|0;b=b|0;if((a|0)==9437184){c[3542078]=b&65535;return}else if((a|0)==8388616){gD[c[3542102]&8191]()|0;c[2113288]=b&65535;return}else if((a|0)==11534340){c[3542086]=b&65535;return}else if((a|0)==3145728){c[2113012]=b&255;return}else if((a|0)==9437186){c[3542079]=b&65535;return}else if((a|0)==3145730){Ui(b&255);return}else if((a|0)==8388608){c[2113282]=b&65535;return}else if((a|0)==10485764){c[3542083]=b&65535;return}else if((a|0)==9437188){c[3542080]=b&65535;return}else if((a|0)==11534336){c[3542084]=b&65535;return}else if((a|0)==11534338){c[3542085]=b&65535;return}else if((a|0)==8388610){c[2113278]=b&65535;return}else if((a|0)==10485762){c[3542082]=b&65535;return}else if((a|0)==10485760){c[3542081]=b&65535;return}else if((a|0)==14680064){a=(b&65535)>>>8&65535;c[2415256]=a&8;b=a>>>1&1;c[3528406]=b^1;if((b|0)==0){c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2]}Tr(a>>>2&1);return}else{return}}function axp(b,d){b=b|0;d=d|0;var f=0,g=0;f=b&65535^1;b=c[3542108]|0;a[b+f|0]=d;g=(c[3527514]|0)+(f<<1)|0;if((a[g]|0)==d<<24>>24){return}a[g]=d;d=e[b+(f&65534)>>1]|0;b=d>>>7&248;c[(c[3542106]|0)+(f>>>1<<2)>>2]=d>>>2<<8&63488|d&31|(b>>>5|b)<<3&2016;return}function axq(a,d){a=a|0;d=d|0;var e=0;e=a>>>1&32767;b[(c[3542108]|0)+(e<<1)>>1]=d;a=(c[3527514]|0)+(e<<1)|0;if((b[a>>1]|0)==d<<16>>16){return}b[a>>1]=d;a=d&65535;d=a>>>7&248;c[(c[3542106]|0)+(e<<2)>>2]=a>>>2<<8&63488|a&31|(d>>>5|d)<<3&2016;return}function axr(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4719676+(b*112|0)>>2];c[a+104>>2]=c[4719680+(b*112|0)>>2];c[a+108>>2]=c[4719684+(b*112|0)>>2];d=0;return d|0}function axs(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=4719576+(b*112|0);e=0;return e|0}function axt(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1557904+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function axu(){var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;b=i;i=i+840|0;d=b|0;e=b+112|0;f=b+120|0;g=b+232|0;j=b+240|0;k=b+352|0;l=b+360|0;m=b+472|0;n=b+480|0;o=b+592|0;p=b+600|0;q=b+712|0;r=b+720|0;s=b+832|0;c[2424]=5755;c[2426680]=0;c[2418138]=0;c[3542098]=1048576;c[3542090]=17825792;c[3542091]=26214400;c[3542092]=34603008;c[3531292]=38797312;c[2439994]=42991616;c[2405616]=42991744;c[2418252]=42991744;c[3542094]=43057280;c[3542095]=43090048;c[3542096]=43122816;c[3542100]=43155584;c[3542108]=43221120;c[2411556]=43286656;t=0;while(1){if((t|0)>=1024){break}u=9638528+(t<<2)|0;if((c[u>>2]|0)==0){v=15294;break}else{t=t+1|0}}do{if((v|0)==15294){t=gGq(43286656)|0;c[u>>2]=t;if((t|0)==0){break}c[2426680]=t;gGz(t|0,0,43286656);c[2418138]=t;c[3542098]=t+1048576;c[3542090]=t+17825792;c[3542091]=t+26214400;c[3542092]=t+34603008;c[3531292]=t+38797312;c[2439994]=t+42991616;w=t+42991744|0;c[2405616]=w;c[2418252]=w;c[3542094]=t+43057280;c[3542095]=t+43090048;c[3542096]=t+43122816;c[3542100]=t+43155584;c[3542108]=t+43221120;w=t+43286656|0;c[2411556]=w;c[2414096]=w;R6(t,1,2)|0;t=(c[2418138]|0)+1|0;R6(t,0,2)|0;t=c[3542098]|0;R6(t,2,2)|0;t=(c[3542098]|0)+1|0;R6(t,3,2)|0;t=(c[3542098]|0)+8388608|0;R6(t,4,2)|0;t=(c[3542098]|0)+8388609|0;R6(t,5,2)|0;t=0;w=c[3542098]|0;while(1){x=a[w]|0;y=w+1|0;z=a[y]|0;a[w]=z&15|x<<4;a[y]=(z&255)>>>4|x&-16;x=t+1|0;if((x|0)<8388608){t=x;w=w+2|0}else{break}}w=c[3542090]|0;do{if((c[3542200]|0)!=0){t=r+108|0;c[t>>2]=0;x=r+100|0;c[x>>2]=0;z=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[z&16383](r,6)|0;if((c[t>>2]|0)==0){break}t=c[x>>2]|0;c[s>>2]=9534384;x=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[x&16383](s,6,0)|0;if((t|0)<1){break}gzL(w,0,6)|0}}while(0);w=(c[3542090]|0)+4194304|0;do{if((c[3542200]|0)!=0){t=p+108|0;c[t>>2]=0;x=p+100|0;c[x>>2]=0;z=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[z&16383](p,7)|0;if((c[t>>2]|0)==0){break}t=c[x>>2]|0;c[q>>2]=9534384;x=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[x&16383](q,7,0)|0;if((t|0)<1){break}gzL(w,0,7)|0}}while(0);w=0;t=c[3542090]|0;while(1){x=a[t]|0;z=t+1|0;y=a[z]|0;a[z]=y<<4|x&15;a[t]=y&-16|(x&255)>>>4;x=w+1|0;if((x|0)<4194304){w=x;t=t+2|0}else{break}}t=c[3542091]|0;do{if((c[3542200]|0)!=0){w=n+108|0;c[w>>2]=0;x=n+100|0;c[x>>2]=0;y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[y&16383](n,8)|0;if((c[w>>2]|0)==0){break}w=c[x>>2]|0;c[o>>2]=9534384;x=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[x&16383](o,8,0)|0;if((w|0)<1){break}gzL(t,0,8)|0}}while(0);t=(c[3542091]|0)+4194304|0;do{if((c[3542200]|0)!=0){w=l+108|0;c[w>>2]=0;x=l+100|0;c[x>>2]=0;y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[y&16383](l,9)|0;if((c[w>>2]|0)==0){break}w=c[x>>2]|0;c[m>>2]=9534384;x=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[x&16383](m,9,0)|0;if((w|0)<1){break}gzL(t,0,9)|0}}while(0);t=0;w=c[3542091]|0;while(1){x=a[w]|0;y=w+1|0;z=a[y]|0;a[y]=z<<4|x&15;a[w]=z&-16|(x&255)>>>4;x=t+1|0;if((x|0)<4194304){t=x;w=w+2|0}else{break}}w=c[3542092]|0;do{if((c[3542200]|0)!=0){t=j+108|0;c[t>>2]=0;x=j+100|0;c[x>>2]=0;z=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[z&16383](j,10)|0;if((c[t>>2]|0)==0){break}t=c[x>>2]|0;c[k>>2]=9534384;x=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[x&16383](k,10,0)|0;if((t|0)<1){break}gzL(w,0,10)|0}}while(0);w=0;t=c[3542092]|0;while(1){x=a[t]|0;z=t+1|0;y=a[z]|0;a[z]=y<<4|x&15;a[t]=y&-16|(x&255)>>>4;x=w+1|0;if((x|0)<2097152){w=x;t=t+2|0}else{break}}t=c[3531292]|0;do{if((c[3542200]|0)!=0){w=f+108|0;c[w>>2]=0;x=f+100|0;c[x>>2]=0;y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[y&16383](f,11)|0;if((c[w>>2]|0)==0){break}w=c[x>>2]|0;c[g>>2]=9534384;x=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[x&16383](g,11,0)|0;if((w|0)<1){break}gzL(t,0,11)|0}}while(0);t=c[2439994]|0;do{if((c[3542200]|0)!=0){w=d+108|0;c[w>>2]=0;x=d+100|0;c[x>>2]=0;y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[y&16383](d,12)|0;if((c[w>>2]|0)==0){break}w=c[x>>2]|0;c[e>>2]=9534384;x=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[x&16383](e,12,0)|0;if((w|0)<1){break}gzL(t,0,12)|0}}while(0);Tq(689696);if(!(a[1040128]|0)){t=c[2439994]|0;gGC(14100392,t|0,128)|0}fxU(0,425984);if((c[2394]|0)==0){A=c[2112932]|0}else{c[2394]=0;t=c[3532596]|0;c[2112932]=t;w=c[3532592]|0;if((w|0)!=0){gGC(9104152,w|0,280)|0}c[2113054]=c[2113060];A=t}t=c[2418138]|0;w=A|0;x=0;while(1){y=t+x|0;c[w>>2]=y;c[w+131072>>2]=y;y=x+1024|0;if(y>>>0>1048575){break}else{w=w+4|0;x=y}}x=c[2418252]|0;w=A+4096|0;t=1048576;while(1){y=x+(t-1048576)|0;c[w>>2]=y;c[w+65536>>2]=y;c[w+131072>>2]=y;y=t+1024|0;if(y>>>0>1114111){break}else{w=w+4|0;t=y}}t=c[3542100]|0;w=A+16384|0;x=4194304;while(1){y=t+(x-4194304)|0;c[w>>2]=y;c[w+65536>>2]=y;c[w+131072>>2]=y;y=x+1024|0;if(y>>>0>4259839){break}else{w=w+4|0;x=y}}x=c[3542094]|0;w=A+20480|0;t=5242880;while(1){y=x+(t-5242880)|0;c[w>>2]=y;c[w+65536>>2]=y;c[w+131072>>2]=y;y=t+1024|0;if(y>>>0>5275647){break}else{w=w+4|0;t=y}}t=c[3542095]|0;w=A+24576|0;x=6291456;while(1){y=t+(x-6291456)|0;c[w>>2]=y;c[w+65536>>2]=y;c[w+131072>>2]=y;y=x+1024|0;if(y>>>0>6324223){break}else{w=w+4|0;x=y}}x=c[3542096]|0;w=A+28672|0;t=7340032;while(1){y=x+(t-7340032)|0;c[w>>2]=y;c[w+65536>>2]=y;c[w+131072>>2]=y;y=t+1024|0;if(y>>>0>7372799){break}else{w=w+4|0;t=y}}t=c[3542108]|0;w=A+49152|0;x=w;y=12582912;while(1){z=t+(y-12582912)|0;c[x>>2]=z;c[x+131072>>2]=z;z=y+1024|0;if(z>>>0>12648447){B=w;C=12582912;break}else{x=x+4|0;y=z}}while(1){c[B+65536>>2]=1;y=C+1024|0;if(y>>>0>12648447){break}else{B=B+4|0;C=y}}c[A+196688>>2]=2164;c[A+196608>>2]=2324;c[A+196728>>2]=390;c[A+196648>>2]=320;c[A+196732>>2]=2882;c[A+196652>>2]=816;y=c[3532592]|0;if((y|0)!=0){gGC(y|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;y=0;while(1){if((y|0)>=1024){D=0;break}E=9638528+(y<<2)|0;if((c[E>>2]|0)==0){v=15359;break}else{y=y+1|0}}do{if((v|0)==15359){y=gGq(131072)|0;c[E>>2]=y;if((y|0)==0){D=0;break}gGz(y|0,0,131072);D=y}}while(0);c[3542106]=D;gGz(D|0,0,131072);y=0;while(1){if((y|0)>=1024){F=0;break}G=9638528+(y<<2)|0;if((c[G>>2]|0)==0){v=15364;break}else{y=y+1|0}}do{if((v|0)==15364){y=gGq(65536)|0;c[G>>2]=y;if((y|0)==0){F=0;break}gGz(y|0,0,65536);F=y}}while(0);c[3527514]=F;gGz(F|0,0,65536);c[2112966]=c[3542106];c[3542078]=0;c[3542079]=0;c[3542080]=16;c[3542081]=0;c[3542082]=0;c[3542083]=16;c[3542084]=0;c[3542085]=0;c[3542086]=16;c[3542087]=0;c[3542088]=0;c[3542089]=16;c[2113284]=0;y=c[642608+(c[2436]<<2)>>2]|0;if((c[y+52>>2]&4|0)==0){x=c[y+128>>2]|0;c[2113280]=x;H=y+132|0;I=x}else{x=c[y+132>>2]|0;c[2113280]=x;H=y+128|0;I=x}x=c[H>>2]|0;c[2113276]=x;c[2406716]=I-8;c[2394778]=I-16;c[2406714]=x-8;c[2394776]=x-16;c[3528974]=c[3564288+(((I|0)!=320)<<2)>>2];auH(1,16777216);axI(0,8388608,8,16384);axI(1,8388608,8,16384);axI(2,4194304,8,16384);Uf(16934400,984);h[607287]=1.0;c[2433116]=1;h[607286]=1.0;c[2433114]=2;a[7072728]=1;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];x=c[3532592]|0;if((x|0)!=0){gGC(9104152,x|0,280)|0}c[2113054]=c[2113060]}RI();x=c[2394]|0;y=c[14130368+(x<<2)>>2]|0;if((y|0)!=0){gGC(y|0,9104152,280)|0}c[8452240+(x<<2)>>2]=c[2113054];c[2394]=-1;c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];a[9541704]=1;a[9541936]=1;a[9775160]=1;a[9775632]=0;gGz(14125184,0,668);c[2433532]=0;c[2430402]=0;c[2113010]=0;a[9753304]=0;c[2433552]=0;gGz(c[2430036]|0,0,16384);c[3531316]=4;gGz(c[2430037]|0,0,16384);c[3531337]=4;gGz(c[2430038]|0,0,16384);c[3531358]=4;gGz(c[2430039]|0,0,16384);c[3531379]=4;gGz(c[2430040]|0,0,16384);c[3531400]=4;gGz(c[2430041]|0,0,16384);c[3531421]=4;gGz(c[2430042]|0,0,16384);c[3531442]=4;gGz(c[2430043]|0,0,16384);c[3531463]=4;J=0;i=b;return J|0}}while(0);c[2426680]=0;J=1;i=b;return J|0}function axv(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;i=i+128|0;d=c[2406694]|0;if((d|0)!=0){gGr(d);c[2406694]=0}c[3531294]=0;d=b|0;e=c[c[642608+(c[2436]<<2)>>2]>>2]|0;be(d|0,128,179600,(f=i,i=i+24|0,c[f>>2]=9374064,c[f+8>>2]=47,c[f+16>>2]=e,f)|0)|0;i=f;a[1040128]=0;f=c[2420380]|0;e=c[f>>2]|0;g=c[f+4>>2]|0;f=fw(d|0,389440)|0;if((f|0)!=0){d=g>>3<<e&1023;cj(14100392,d|0,1,f|0)|0;aY(f|0)|0}axH();f=c[2443764]|0;d=0;while(1){if((d|0)>=1024){break}h=9638528+(d<<2)|0;if((c[h>>2]|0)==(f|0)){j=15386;break}else{d=d+1|0}}if((j|0)==15386){gGr(f);c[h>>2]=0}c[2443764]=0;h=c[2394718]|0;f=0;while(1){if((f|0)>=1024){break}k=9638528+(f<<2)|0;if((c[k>>2]|0)==(h|0)){j=15390;break}else{f=f+1|0}}if((j|0)==15390){gGr(h);c[k>>2]=0}c[2394718]=0;a[7462192]=0;k=c[3542106]|0;h=0;while(1){if((h|0)>=1024){break}l=9638528+(h<<2)|0;if((c[l>>2]|0)==(k|0)){j=15394;break}else{h=h+1|0}}if((j|0)==15394){gGr(k);c[l>>2]=0}c[3542106]=0;l=c[3527514]|0;k=0;while(1){if((k|0)>=1024){break}m=9638528+(k<<2)|0;if((c[m>>2]|0)==(l|0)){j=15398;break}else{k=k+1|0}}if((j|0)==15398){gGr(l);c[m>>2]=0}c[3527514]=0;if((c[2392]|0)>=0){m=0;do{l=14130368+(m<<2)|0;k=c[l>>2]|0;if((k|0)!=0){gGr(k);c[l>>2]=0}l=14130384+(m<<2)|0;k=c[l>>2]|0;if((k|0)!=0){gGr(k);c[l>>2]=0}m=m+1|0;}while((m|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;m=c[2426680]|0;l=0;while(1){if((l|0)>=1024){j=15410;break}n=9638528+(l<<2)|0;if((c[n>>2]|0)==(m|0)){break}else{l=l+1|0}}if((j|0)==15410){c[2426680]=0;i=b;return 0}gGr(m);c[n>>2]=0;c[2426680]=0;i=b;return 0}function axw(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;if((a[9623776]|0)!=0){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];a[9541704]=1;a[9541936]=1;a[9775160]=1;a[9775632]=0;gGz(14125184,0,668);c[2433532]=0;c[2430402]=0;c[2113010]=0;a[9753304]=0;c[2433552]=0;gGz(c[2430036]|0,0,16384);c[3531316]=4;gGz(c[2430037]|0,0,16384);c[3531337]=4;gGz(c[2430038]|0,0,16384);c[3531358]=4;gGz(c[2430039]|0,0,16384);c[3531379]=4;gGz(c[2430040]|0,0,16384);c[3531400]=4;gGz(c[2430041]|0,0,16384);c[3531421]=4;gGz(c[2430042]|0,0,16384);c[3531442]=4;gGz(c[2430043]|0,0,16384);c[3531463]=4}b[4812784]=0;b[4812785]=0;d=0;e=0;f=0;do{e=((a[9632832+d|0]&1)<<d|e&65535)&65535;f=((a[9630720+d|0]&1)<<d|f&65535)&65535;d=d+1|0;}while((d|0)<10);b[4812784]=e;b[4812785]=f;if((e&3)==3){d=e&-4;b[4812784]=d;g=d}else{g=e}if((g&12)==12){b[4812784]=g&-13}if((f&3)==3){g=f&-4;b[4812785]=g;h=g}else{h=f}if((h&12)==12){b[4812785]=h&-13}h=c[2392]|0;if((h|0)>=0){gGz(8452240,0,((h|0)>0?(h<<2)+4|0:4)|0)}c[2113054]=0;h=c[2438]|0;f=gGU(h,(h|0)<0|0?-1:0,16e6,0)|0;h=~~((+(f>>>0)+ +(K|0)*4294967296.0)/14732.965009208103);c[2440512]=h;c[2444062]=0;f=h-~~(+(h*12|0|0)/271.5)|0;a[9627104]=0;if((c[2394]|0)==0){i=1;j=0}else{c[2394]=0;c[2112932]=c[3532596];h=c[3532592]|0;if((h|0)!=0){gGC(9104152,h|0,280)|0}c[2113054]=c[2113060];i=1;j=0}while(1){h=c[2112964]|0;if((i&1|0)==0&(h|0)!=0){g=(ag(a[9688]|0?534:0,i)|0)/8|0;Ug(h+(j<<1<<1)|0,g-j|0);k=g}else{k=j}a[7024736]=0;g=(ag(c[2440512]|0,i)|0)/8|0;if((a[9627104]&1)==0&(g|0)>(f|0)){h=c[2444062]|0;if((h|0)<(f|0)){e=f-h|0;c[2113056]=e;h=RG(e)|0;c[2113054]=(c[2113054]|0)+h;c[2276108]=-1;c[2113056]=-1;e=9776248+(a[7024736]<<31>>31<<2)|0;c[e>>2]=(c[e>>2]|0)+h}h=c[2112968]|0;do{if((h|0)!=0){if((a[14168416]|0)==0){l=c[3542106]|0}else{e=c[3527514]|0;d=c[3542106]|0;m=c[3542108]|0;n=0;while(1){o=n<<8;p=0;q=m;r=e+(o<<1)|0;s=d+(o<<2)|0;while(1){o=b[q>>1]|0;b[r>>1]=o;t=o&65535;o=t>>>7&248;c[s>>2]=t>>>2<<8&63488|t&31|(o>>>5|o)<<3&2016;o=p+1|0;if((o|0)<256){p=o;q=q+2|0;r=r+2|0;s=s+4|0}else{break}}s=n+1|0;if((s|0)<128){m=m+512|0;n=s}else{break}}a[14168416]=0;l=d}n=c[l>>2]|0;do{if((n|0)==0){gGz(h|0,0,ag(c[2113280]<<1,c[2113276]|0)|0)}else{m=n<<16|n;e=ag(c[2113276]|0,c[2113280]|0)|0;if((e|0)<=15){break}s=h;r=(e|0)/16|0;while(1){c[s>>2]=m;c[s+4>>2]=m;c[s+8>>2]=m;c[s+12>>2]=m;c[s+16>>2]=m;c[s+20>>2]=m;c[s+24>>2]=m;c[s+28>>2]=m;e=r-1|0;if((e|0)>0){s=s+32|0;r=e}else{break}}}}while(0);if(!(a[7072728]|0)){break}axE(1)}}while(0);a[9627104]=1;a[9541704]=0;a[9775632]=1;c[8452200+(c[2394]<<2)>>2]=4097;c[2276080]=256;if((c[2276079]|0)>>>0<256){RH(1)}u=a[7024736]<<31>>31}else{u=0}h=g-(c[9776248+(u<<2)>>2]|0)|0;c[2113056]=h;n=RG(h)|0;c[2113054]=(c[2113054]|0)+n;c[2276108]=-1;c[2113056]=-1;h=9776248+(a[7024736]<<31>>31<<2)|0;c[h>>2]=(c[h>>2]|0)+n;a[7024736]=1;n=i+1|0;if((n|0)<9){i=n;j=k}else{break}}j=c[2112964]|0;do{if((j|0)!=0){i=a[9688]|0?534:0;if((i|0)==(k|0)){break}Ug(j+(k<<1<<1)|0,i-k|0)}}while(0);k=c[2394]|0;j=c[14130368+(k<<2)>>2]|0;if((j|0)==0){v=c[2113054]|0;w=8452240+(k<<2)|0;c[w>>2]=v;c[2394]=-1;return 0}gGC(j|0,9104152,280)|0;v=c[2113054]|0;w=8452240+(k<<2)|0;c[w>>2]=v;c[2394]=-1;return 0}function axx(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((a[14168416]|0)==0){d=c[3542106]|0}else{e=c[3527514]|0;f=c[3542106]|0;g=c[3542108]|0;h=0;while(1){i=h<<8;j=0;k=g;l=e+(i<<1)|0;m=f+(i<<2)|0;while(1){i=b[k>>1]|0;b[l>>1]=i;n=i&65535;i=n>>>7&248;c[m>>2]=n>>>2<<8&63488|n&31|(i>>>5|i)<<3&2016;i=j+1|0;if((i|0)<256){j=i;k=k+2|0;l=l+2|0;m=m+4|0}else{break}}m=h+1|0;if((m|0)<128){g=g+512|0;h=m}else{break}}a[14168416]=0;d=f}f=c[d>>2]|0;d=c[2112968]|0;do{if((f|0)==0){gGz(d|0,0,ag(c[2113280]<<1,c[2113276]|0)|0)}else{h=f<<16|f;g=ag(c[2113276]|0,c[2113280]|0)|0;if((g|0)<=15){break}e=d;m=(g|0)/16|0;while(1){c[e>>2]=h;c[e+4>>2]=h;c[e+8>>2]=h;c[e+12>>2]=h;c[e+16>>2]=h;c[e+20>>2]=h;c[e+24>>2]=h;c[e+28>>2]=h;g=m-1|0;if((g|0)>0){e=e+32|0;m=g}else{break}}}}while(0);if(!(a[7072728]|0)){return 0}axE(1);return 0}function axy(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;e=i;i=i+144|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;l=e+80|0;m=e+96|0;n=e+112|0;o=e+128|0;if((d|0)!=0){c[d>>2]=133378}Ts(b,d);if((b&96|0)!=0){gGz(o|0,0,12);d=c[2405616]|0;c[o>>2]=d;c[o+4>>2]=(c[2411556]|0)-d;c[o+12>>2]=219592;d=c[2076592]|0;gj[d&4095](o)|0;o=h|0;do{if((b&64|0)!=0){gGz(g|0,0,16);c[2394]=-1;if((c[2392]|0)<0){break}d=h+9|0;p=f;q=f|0;r=f+4|0;s=f+12|0;t=g|0;u=g+4|0;v=g+12|0;w=0;do{gGC(o|0,614896,11)|0;a[d]=w+48&255;x=8452256+(w<<2)|0;gGz(p|0,0,12);c[q>>2]=x;c[r>>2]=4;c[s>>2]=164976;gj[c[2076592]&4095](f)|0;if((c[x>>2]|0)!=0){c[t>>2]=c[14130368+(w<<2)>>2];c[u>>2]=c[8452184+(w<<2)>>2];c[v>>2]=o;x=c[2076592]|0;gj[x&4095](g)|0}w=w+1|0;}while((w|0)<=(c[2392]|0))}}while(0);Ue();gGz(n|0,0,12);c[n>>2]=9541704;c[n+4>>2]=1;c[n+12>>2]=148144;g=c[2076592]|0;gj[g&4095](n)|0;gGz(m|0,0,12);c[m>>2]=9541936;c[m+4>>2]=1;c[m+12>>2]=118544;n=c[2076592]|0;gj[n&4095](m)|0;gGz(l|0,0,12);c[l>>2]=9775160;c[l+4>>2]=1;c[l+12>>2]=93520;m=c[2076592]|0;gj[m&4095](l)|0;gGz(k|0,0,12);c[k>>2]=9627104;c[k+4>>2]=1;c[k+12>>2]=490464;l=c[2076592]|0;gj[l&4095](k)|0;ayc();gGz(j|0,0,12);c[j>>2]=9625568;c[j+4>>2]=4;c[j+12>>2]=215728;k=c[2076592]|0;gj[k&4095](j)|0}if((b&2|0)==0){i=e;return 0}a[14168416]=1;i=e;return 0}function axz(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2882228+(b*112|0)>>2];c[a+104>>2]=c[2882232+(b*112|0)>>2];c[a+108>>2]=c[2882236+(b*112|0)>>2];d=0;return d|0}function axA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=2882128+(b*112|0);e=0;return e|0}function axB(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1556548+(b*112|0)>>2];c[a+104>>2]=c[1556552+(b*112|0)>>2];c[a+108>>2]=c[1556556+(b*112|0)>>2];d=0;return d|0}function axC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=1556448+(b*112|0);e=0;return e|0}function axD(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=(b^1)&255;a[9541936]=d;do{if((a[9541704]|0)==0|d<<24>>24==0){a[9775632]=1;e=4096;f=1;g=15527}else{b=(a[9775160]|0)==0;h=b&1;a[9775632]=h;if(b){e=b?4096:0;f=h;g=15527;break}c[8452200+(c[2394]<<2)>>2]=0;c[2276080]=0;i=h}}while(0);do{if((g|0)==15527){c[8452200+(c[2394]<<2)>>2]=e|1;c[2276080]=256;if((c[2276079]|0)>>>0>=256){i=f;break}RH(1);i=a[9775632]|0}}while(0);if(!(i<<24>>24!=0&a[7024736])){return}c[2113056]=1024;i=RG(1024)|0;c[2113054]=(c[2113054]|0)+i;c[2276108]=-1;c[2113056]=-1;c[2444062]=(c[2444062]|0)+i;return}function axE(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0;gGz(9760096,0,16);gGz(14110040,0,16);g=18-(c[2113278]|0)-(c[2113292]|0)|0;c[2439204]=g;h=(f|0)!=0;f=c[2113294]|0;i=c[2113280]|0;j=i>>3<<2;k=(j|0)>-1;l=c[2113276]|0;m=i>>4<<2;n=(m|0)>-1;o=0;while(1){p=o-(c[2113282]|0)-f|0;c[9756824+(o<<2)>>2]=p;q=14168312+(o*12|0)|0;do{if((c[14168320+(o*12|0)>>2]&16|0)==0){r=c[9719096+(o<<2)>>2]|0;s=9760032+(o<<4)|0;c[s>>2]=r;t=r+12288|0;u=9760036+(o<<4)|0;c[u>>2]=t;v=r+24576|0;w=9760040+(o<<4)|0;c[w>>2]=v;x=r+36864|0;y=9760044+(o<<4)|0;c[y>>2]=x;L19320:do{if((8>>>(o>>>0)&255|0)!=0){z=c[14168316+(o*12|0)>>2]|0;if((z&8192|0)==0){do{if(h){A=c[q>>2]|0;if((A&16384|0)==0){B=A;break}c[3527510]=(c[3527510]|0)+291;c[3527511]=(c[3527511]|0)+291;c[3527512]=(c[3527512]|0)+291;c[3527513]=(c[3527513]|0)+291;break L19320}else{B=c[14168312+(o*12|0)>>2]|0}}while(0);A=c[14168376+(o<<2)>>2]|0;C=(c[2113284]|0)==0?0:262144;D=p+502+B|0;E=D>>>3<<2;F=D&7;D=g+z|0;G=D>>>3<<8;H=D&7;D=9541904+(o<<2)|0;I=9755456+(o<<2)|0;if(k){J=0}else{c[2385460]=240-H;break}do{K=J+G&16128;L=(J>>5)-H|0;if((L|0)>-8&(L|0)<(l|0)){M=c[D>>2]|0;N=c[I>>2]|0;O=L&65535;P=j;do{Q=P+E&252|K;R=e[A+(Q|16384)>>1]|0;S=e[A+(Q|16386)>>1]|C|R<<16;do{if((a[N+(S&M)|0]|0)==0){Q=(P<<1)-F|0;c[2385472]=Q;if(!((Q|0)>-8&(Q|0)<(i|0))){break}T=9760032+(o<<4)+(R>>>14<<2)|0;U=c[T>>2]|0;b[U>>1]=Q&65535;b[U+2>>1]=O;c[U+4>>2]=S;c[T>>2]=U+8}}while(0);P=P-4|0;}while((P|0)>-1)}J=J+256|0;}while((J|0)<7936);c[2385460]=L;break}else{do{if(h){F=c[q>>2]|0;if(((F|z)&16384|0)==0){V=F;break}c[3527510]=(c[3527510]|0)+291;c[3527511]=(c[3527511]|0)+291;c[3527512]=(c[3527512]|0)+291;c[3527513]=(c[3527513]|0)+291;break L19320}else{V=c[14168312+(o*12|0)>>2]|0}}while(0);F=c[14168376+(o<<2)>>2]|0;C=p+494+V|0;A=C>>>4<<2;E=C&15;C=g+z|0;I=C>>>4<<7;D=C&15;C=9755456+(o<<2)|0;H=9541904+(o<<2)|0;if(n){W=0}else{c[2385460]=240-D;break}do{G=W+I&3968;X=(W>>3)-D|0;if((X|0)>-16&(X|0)<(l|0)){P=c[C>>2]|0;O=c[H>>2]|0;M=X&65535;N=m;do{K=N+A&124|G;S=e[F+K>>1]|0;R=S<<16|e[F+(K|2)>>1];do{if((c[P+(R<<2&O)>>2]|0)!=16843009){K=(N<<2)-E|0;c[2385472]=K;if(!((K|0)>-16&(K|0)<(i|0))){break}U=9760032+(o<<4)+(S>>>14<<2)|0;T=c[U>>2]|0;b[T>>1]=K&65535;b[T+2>>1]=M;c[T+4>>2]=R;c[U>>2]=T+8}}while(0);N=N-4|0;}while((N|0)>-1)}W=W+128|0;}while((W|0)<2048);c[2385460]=X;break}}}while(0);b[c[s>>2]>>1]=9999;c[s>>2]=r;if((b[r>>1]|0)<9999){c[3527510]=(c[3527510]|0)+291}b[c[u>>2]>>1]=9999;c[u>>2]=t;if((b[t>>1]|0)<9999){c[3527511]=(c[3527511]|0)+291}b[c[w>>2]>>1]=9999;c[w>>2]=v;if((b[v>>1]|0)<9999){c[3527512]=(c[3527512]|0)+291}b[c[y>>2]>>1]=9999;c[y>>2]=x;if((b[x>>1]|0)>=9999){break}c[3527513]=(c[3527513]|0)+291}}while(0);p=o+1|0;if((p|0)<4){o=p}else{Y=0;Z=0;break}}while(1){o=(Z|0)==3;if((c[14110040+(Z<<2)>>2]|0)!=0|o){if((Y|0)==0){c[2415166]=-1;c[3528500]=-1;c[2384544]=9999;c[2384542]=9999;c[2384546]=-1;c[2384548]=-1}do{if((Z|0)<3){X=Z+1|0;if((X|0)<4){_=65536;$=X}else{aa=65536;break}while(1){X=c[9761872+($<<2)>>2]|0;W=(_|0)>(X|0)?X:_;X=$+1|0;if((X|0)<4){_=W;$=X}else{aa=W;break}}}else{aa=65536}}while(0);do{if((Y|0)<=(Z|0)){x=0;y=-1;v=65536;w=Y;do{t=c[9761872+(w<<2)>>2]|0;v=(v|0)>(t|0)?t:v;t=c[9775584+(w<<2)>>2]|0;y=(y|0)<(t|0)?t:y;x=x|8>>>(w>>>0);w=w+1|0;}while((w|0)<=(Z|0));w=x&255;if((w|0)==0){break}if((v|0)<=(y|0)){t=(c[2443764]|0)+(v<<5)|0;u=v;while(1){L19396:do{if((d[t+1|0]&w|0)!=0){r=c[t+4>>2]|0;c[2415168]=r;s=c[t+8>>2]|0;W=(c[3542098]|0)+(c[t+28>>2]<<8&c[2429856])|0;c[2443766]=W;c[2438094]=(c[3542106]|0)+(b[t+2>>1]<<2);X=c[t+12>>2]|0;c[2409618]=X;i=c[t+16>>2]|0;c[2409614]=i;m=c[t+20>>2]|0;do{if((m|0)==256){if((c[t+24>>2]|0)!=256){break}l=X>>2;c[2438140]=l;n=a[t|0]|0;if((n&1)==0){ab=l;ac=W}else{g=W+((ag(l,i-1|0)|0)<<2)|0;c[2443766]=g;V=-l|0;c[2438140]=V;ab=V;ac=g}g=(s|0)>511?s-1024|0:s;if((g|0)<0){V=ac+((ag(ab,-g|0)|0)<<2)|0;c[2443766]=V;l=i+g|0;c[2409614]=l;ad=0;ae=l;af=V}else{ad=g;ae=i;af=ac}g=c[2113276]|0;if((ad+ae|0)>(g|0)){V=g-ad|0;c[2409614]=V;ah=V}else{ah=ae}if((r|0)>511){V=r-1024|0;c[2415168]=V;ai=V}else{ai=r}if((ai|0)<0){V=-ai|0;if((n&2)==0){g=af+(V>>4<<2<<2)|0;c[2443766]=g;aj=g}else{aj=af}g=V&65520;V=X-g|0;c[2409618]=V;l=g+ai|0;c[2415168]=l;ak=l;al=V;am=aj}else{ak=ai;al=X;am=af}V=ak+al|0;l=c[2113280]|0;if((V|0)<(l|0)){an=al}else{g=V-l|0;if((n&2)!=0){c[2443766]=am+(g>>4<<2<<2)}l=al-(g&65520)|0;c[2409618]=l;an=l}l=c[2112968]|0;g=ag(c[2113300]|0,ad)|0;c[2420368]=l+((ag(c[2113308]|0,ak)|0)+g);g=(n&255)<<1&4;n=c[2384548]|0;do{if((c[3528500]|0)>(u|0)&(ak|0)<(n|0)){if(!((an+ak|0)>=(c[2384542]|0)&(ad|0)<(c[2384546]|0))){ao=g;break}ao=(ah+ad|0)>=(c[2384544]|0)|g}else{ao=g}}while(0);do{if((aa|0)<(u|0)){g=ao|2;if((ak|0)<(c[2384542]|0)){c[2384542]=ak}l=an+ak|0;if((l|0)>(n|0)){c[2384548]=l}if((ad|0)<(c[2384544]|0)){c[2384544]=ad}l=ah+ad|0;if((l|0)<=(c[2384546]|0)){ap=g;break}c[2384546]=l;ap=g}else{ap=ao}}while(0);if((ap&3|0)!=0){c[2415140]=(c[2394718]|0)+(ak+(ad*320|0)<<1);c[2415166]=(c[2394728]|0)+u}c[2409618]=an>>2;gu[c[(c[2442960]|0)+(ap<<2)>>2]&16383]();break L19396}}while(0);c[2432832]=16777216;W=(ag(m,X)|0)>>8;c[2409618]=W;if((W|0)<1){c[2409618]=1;aq=16777216;ar=1}else{n=16777216/(m|0)|0;c[2432832]=n;aq=n;ar=W}W=X<<16;if((aq|0)>(W|0)){c[2432832]=W;as=W}else{as=aq}n=as>>1;c[2438138]=n;g=a[t|0]|0;if((g&2)==0){at=r;au=as;av=n}else{l=X-ar+r|0;c[2415168]=l;V=W-n|0;c[2438138]=V;n=-as|0;c[2432832]=n;at=l;au=n;av=V}if((at|0)>511){V=at-1024|0;c[2415168]=V;aw=V}else{aw=at}if((aw|0)<0){V=aw+ar|0;if((V|0)<1){break}c[2438138]=av-(ag(aw,au)|0);c[2409618]=V;c[2415168]=0;ax=0;ay=V}else{ax=aw;ay=ar}V=c[2113280]|0;if((ax+ay|0)<(V|0)){az=ay}else{if((ax|0)>=(V|0)){break}n=V-ax|0;c[2409618]=n;az=n}c[2438140]=X;c[2432830]=16777216;n=c[t+24>>2]|0;l=(ag(n,i)|0)>>8;c[2409614]=l;if((l|0)<1){c[2409614]=1;aA=16777216;aB=1}else{W=16777216/(n|0)|0;c[2432830]=W;aA=W;aB=l}l=i<<16;if((aA|0)>(l|0)){c[2432830]=l;aC=l}else{aC=aA}W=aC>>1;c[2438134]=W;if((g&1)==0){aD=s;aE=aC;aF=W}else{g=l-W|0;c[2438134]=g;W=-aC|0;c[2432830]=W;aD=s-aB+i|0;aE=W;aF=g}g=(aD|0)>511?aD-1024|0:aD;if((g|0)<0){W=g+aB|0;if((W|0)<1){break}c[2438134]=aF-(ag(g,aE)|0);c[2409614]=W;aG=0;aH=W}else{aG=g;aH=aB}g=c[2113276]|0;if((aG+aH|0)<(g|0)){aI=aH}else{if((aG|0)>=(g|0)){break}W=g-aG|0;c[2409614]=W;aI=W}W=c[2112968]|0;g=ag(c[2113300]|0,aG)|0;c[2420368]=W+((ag(c[2113308]|0,ax)|0)+g);g=(m|0)>256|(n|0)>256?12:8;n=c[2384548]|0;do{if((c[3528500]|0)>(u|0)&(ax|0)<(n|0)){if(!((az+ax|0)>=(c[2384542]|0)&(aG|0)<(c[2384546]|0))){aJ=g;break}aJ=(aI+aG|0)>=(c[2384544]|0)|g}else{aJ=g}}while(0);do{if((aa|0)<(u|0)){g=aJ|2;if((ax|0)<(c[2384542]|0)){c[2384542]=ax}m=az+ax|0;if((m|0)>(n|0)){c[2384548]=m}if((aG|0)<(c[2384544]|0)){c[2384544]=aG}m=aI+aG|0;if((m|0)<=(c[2384546]|0)){aK=g;break}c[2384546]=m;aK=g}else{aK=aJ}}while(0);if((aK&3|0)!=0){n=c[2394718]|0;c[2415140]=n+((ag(aG,V)|0)+ax<<1);c[2415166]=(c[2394728]|0)+u}c[2409618]=az<<16;c[2409614]=aI<<16;gu[c[(c[2442960]|0)+(aK<<2)>>2]&16383]()}}while(0);n=u+1|0;if((n|0)>(y|0)){break}else{t=t+32|0;u=n}}}u=c[3528500]|0;if((y|0)>(u|0)){c[3528500]=y;aL=y}else{aL=u}if(!(o&(c[2415166]|0)>-1)){break}u=(c[2394728]|0)+aL|0;c[2394728]=u;if((u|0)<=64512){break}u=c[2394718]|0;gGz(u|0,0,ag(c[2113280]<<1,c[2113276]|0)|0);c[2394728]=0}}while(0);aM=Z+1|0}else{aM=Y}o=(Z|0)==0;u=0;do{t=0;do{w=c[14168320+(t*12|0)>>2]|0;do{if((w&3|0)==(u|0)&(w&16|0)==0){if((8>>>(t>>>0)&255|0)==0){break}v=c[14168316+(t*12|0)>>2]|0;if((v&8192|0)==0){if(!h){axG(t,Z);break}x=c[14168312+(t*12|0)>>2]|0;if((x&16384|0)==0){axG(t,Z);break}n=c[14168376+(t<<2)>>2]|0;g=c[3542106]|0;m=c[9752600+(t<<2)>>2]|0;i=24-(c[9761800+(t<<2)>>2]|0)|0;s=c[14113848+(t<<2)>>2]|0;X=9760096+(t<<2)|0;r=c[X>>2]|0;if((r|0)>1983){break}W=(c[2113284]|0)==0?0:262144;l=x+502+(c[9756824+(t<<2)>>2]|0)&511;x=(c[2439204]|0)+v|0;L=x>>>3<<8;J=x&7;do{if(o){x=v+18-(c[2113290]|0)|0;j=c[2113276]|0;if((j|0)>0){aN=0}else{break}do{c[s+(aN<<2)>>2]=(e[n+(x+aN<<2&2044|4096)>>1]|0)+l;aN=aN+1|0;}while((aN|0)<(j|0))}}while(0);l=9541904+(t<<2)|0;V=9755456+(t<<2)|0;j=14168360+(t<<2)|0;x=0;k=r;while(1){B=(x>>5)-J|0;c[2385460]=B;f=x+L&16128;c[2440378]=s+(B<<2);B=k;p=0;while(1){q=p|f;E=e[n+(q|16384)>>1]|0;L19539:do{if((E>>>14|0)==(Z|0)){F=E<<16;A=e[n+(q|16386)>>1]|0;c[2440394]=g+(((F&1056964608)>>>(i>>>0))+m<<2);H=(F|W|A)&c[l>>2];A=B+1|0;F=c[2385460]|0;if(!((F|0)>-8&(F|0)<(c[2113276]|0))){aO=A;break}if((c[(c[V>>2]|0)+H>>2]|0)!=0){aO=A;break}C=p<<1;c[2385472]=C;D=c[2112968]|0;c[2415156]=D+(ag(c[2113300]|0,F)|0);c[2385346]=(c[j>>2]|0)+(H<<6);do{if((F|0)>=0){if((F|0)>(c[2406714]|0)|(C|0)>(c[2406716]|0)){break}gu[c[(c[3528974]|0)+8>>2]&16383]();aO=A;break L19539}}while(0);gu[c[(c[3528974]|0)+12>>2]&16383]();aO=A}else{aO=B}}while(0);q=p+4|0;if((q|0)<256){B=aO;p=q}else{break}}p=x+256|0;if((p|0)<7936){x=p;k=aO}else{break}}if((aO|0)>1983){c[3527510]=(c[3527510]|0)-291;c[3527511]=(c[3527511]|0)-291;c[3527512]=(c[3527512]|0)-291;c[3527513]=(c[3527513]|0)-291}c[X>>2]=aO;break}if(!h){axF(t,Z);break}if((v&16384|0)!=0){k=c[14168376+(t<<2)>>2]|0;x=c[3542106]|0;j=c[9752600+(t<<2)>>2]|0;V=c[9761800+(t<<2)>>2]|0;l=24-V|0;W=(V|0)==6?251658240:1056964608;V=c[14113832+(t<<2)>>2]|0;m=c[14113848+(t<<2)>>2]|0;i=9760096+(t<<2)|0;g=c[i>>2]|0;n=c[2113280]>>4;s=c[2113276]|0;L=n+1|0;if((g|0)>=(ag(L,s)|0)){break}J=14168312+(t*12|0)|0;r=c[J>>2]|0;p=r+494+(c[9756824+(t<<2)>>2]|0)|0;B=p&511;do{if(o){f=v+18-(c[2113290]|0)|0;q=(s|0)>0;if((r&16384|0)==0){if(q){aP=0}else{aQ=g;aR=s;break}while(1){c[V+(aP<<2)>>2]=e[k+(aP+f<<2&2044|4098)>>1]|0;E=aP+1|0;if((E|0)<(s|0)){aP=E}else{aS=15675;break}}}else{if(q){aT=0}else{aQ=g;aR=s;break}while(1){E=aT+f<<2&2044;c[V+(aT<<2)>>2]=e[k+(E|4098)>>1]|0;c[m+(aT<<2)>>2]=(e[k+(E|4096)>>1]|0)+B;E=aT+1|0;if((E|0)<(s|0)){aT=E}else{aS=15675;break}}}}else{aS=15675}}while(0);do{if((aS|0)==15675){aS=0;if((s|0)<=0){aQ=g;aR=s;break}B=p&15;r=-B|0;X=(n|0)<0;f=p>>>4;q=9541904+(t<<2)|0;E=9755456+(t<<2)|0;C=14168360+(t<<2)|0;F=0;H=g;while(1){D=c[V+(F<<2)>>2]|0;I=D>>>4<<7&3968;c[2385460]=F;do{if((c[J>>2]&16384|0)==0){c[2385472]=r;z=c[2112968]|0;N=ag(c[2113300]|0,F)|0;M=c[2113308]|0;O=z+(N-(ag(M,B)|0))|0;c[2415156]=O;N=(D<<1&16|D&7)<<1;if(X){aU=H;break}z=N|16;P=H;G=0;R=r;S=M;M=O;while(1){O=G+f<<2&124|I;T=e[k+O>>1]|0;do{if((T>>>14|0)==(Z|0)){U=T<<16;K=e[k+(O|2)>>1]|U;c[2440394]=x+(((U&W)>>>(l>>>0))+j<<2);U=K&c[q>>2];K=P+1|0;if((c[(c[E>>2]|0)+(U<<2)>>2]|0)==16843009){Q=R+16|0;c[2385472]=Q;aV=M+(S<<4)|0;c[2415156]=aV;aW=K;aX=Q;aY=S;aZ=aV;break}aV=(c[C>>2]|0)+(U<<8)|0;c[2385346]=aV+(N<<2);U=c[3528974]|0;if((R|0)<0|(R|0)>(c[2406716]|0)){gu[c[U+20>>2]&16383]()}else{gu[c[U+16>>2]&16383]()}U=(c[2385472]|0)+8|0;c[2385472]=U;c[2415156]=(c[2415156]|0)+(c[2113308]<<3);c[2385346]=aV+(z<<2);aV=c[3528974]|0;if((U|0)<0|(U|0)>(c[2406716]|0)){gu[c[aV+20>>2]&16383]()}else{gu[c[aV+16>>2]&16383]()}aV=(c[2385472]|0)+8|0;c[2385472]=aV;U=c[2113308]|0;Q=(c[2415156]|0)+(U<<3)|0;c[2415156]=Q;aW=K;aX=aV;aY=U;aZ=Q}else{Q=R+16|0;c[2385472]=Q;U=M+(S<<4)|0;c[2415156]=U;aW=P;aX=Q;aY=S;aZ=U}}while(0);O=G+1|0;if((O|0)>(n|0)){aU=aW;break}else{P=aW;G=O;R=aX;S=aY;M=aZ}}}else{M=c[m+(F<<2)>>2]|0;S=(D<<1&16|D&7)<<1;if(X){aU=H;break}R=M>>>4;G=M&15;M=S|16;P=H;z=0;while(1){N=z+R<<2&124|I;A=e[k+N>>1]|0;do{if((A>>>14|0)==(Z|0)){O=A<<16;T=e[k+(N|2)>>1]|O;c[2440394]=x+(((O&W)>>>(l>>>0))+j<<2);O=T&c[q>>2];T=P+1|0;if((c[(c[E>>2]|0)+(O<<2)>>2]|0)==16843009){a_=T;break}U=(z<<4)-G|0;c[2385472]=U;if(!((U|0)>-16&(U|0)<(c[2113280]|0))){a_=T;break}Q=c[2112968]|0;aV=ag(c[2113300]|0,c[2385460]|0)|0;c[2415156]=Q+((ag(c[2113308]|0,U)|0)+aV);aV=(c[C>>2]|0)+(O<<8)|0;c[2385346]=aV+(S<<2);O=c[3528974]|0;if((U|0)<0|(U|0)>(c[2406716]|0)){gu[c[O+20>>2]&16383]()}else{gu[c[O+16>>2]&16383]()}O=(c[2385472]|0)+8|0;c[2385472]=O;c[2415156]=(c[2415156]|0)+(c[2113308]<<3);c[2385346]=aV+(M<<2);aV=c[3528974]|0;if((O|0)<0|(O|0)>(c[2394778]|0)){gu[c[aV+20>>2]&16383]();a_=T;break}else{gu[c[aV+16>>2]&16383]();a_=T;break}}else{a_=P}}while(0);N=z+1|0;if((N|0)>(n|0)){aU=a_;break}else{P=a_;z=N}}}}while(0);I=F+1|0;D=c[2113276]|0;if((I|0)<(D|0)){F=I;H=aU}else{aQ=aU;aR=D;break}}}}while(0);if((aQ|0)>=(ag(aR,L)|0)){c[3527510]=(c[3527510]|0)-291;c[3527511]=(c[3527511]|0)-291;c[3527512]=(c[3527512]|0)-291;c[3527513]=(c[3527513]|0)-291}c[i>>2]=aQ;break}n=c[14168312+(t*12|0)>>2]|0;if((n&16384|0)==0){axF(t,Z);break}j=c[14168376+(t<<2)>>2]|0;l=c[3542106]|0;W=c[9752600+(t<<2)>>2]|0;x=c[9761800+(t<<2)>>2]|0;k=24-x|0;m=(x|0)==6?251658240:1056964608;x=c[14113848+(t<<2)>>2]|0;J=9760096+(t<<2)|0;V=c[J>>2]|0;if((V|0)>511){break}g=n+494+(c[9756824+(t<<2)>>2]|0)&511;n=(c[2439204]|0)+v|0;p=n>>>4<<7;s=n&15;do{if(o){n=v+18-(c[2113290]|0)|0;H=c[2113276]|0;if((H|0)>0){a$=0}else{break}do{c[x+(a$<<2)>>2]=(e[j+(n+a$<<2&2044|4096)>>1]|0)+g;a$=a$+1|0;}while((a$|0)<(H|0))}}while(0);g=9541904+(t<<2)|0;v=9755456+(t<<2)|0;i=14168360+(t<<2)|0;L=0;H=V;while(1){n=L+p&3968;F=(L>>3)-s|0;c[2385460]=F;c[2440378]=x+(F<<2);C=H;E=0;q=F;while(1){F=E|n;X=e[j+F>>1]|0;do{if((X>>>14|0)==(Z|0)){f=X<<16;r=e[j+(F|2)>>1]|f;c[2440394]=l+(((f&m)>>>(k>>>0))+W<<2);f=r<<2&c[g>>2];r=C+1|0;B=c[(c[v>>2]|0)+f>>2]|0;if((B|0)==16843009){a0=r;a1=q;break}D=E<<2;c[2385472]=D;I=c[2112968]|0;c[2415156]=I+(ag(c[2113300]|0,q)|0);I=c[i>>2]|0;z=f<<6;f=I+z|0;P=(q|0)<0;M=(B&255|0)==0;do{if(P|(q|0)>(c[2394776]|0)){do{if(M){c[2385346]=f;if(!((q|0)>-8&(q|0)<(c[2113276]|0))){break}S=c[3528974]|0;if(P|(q|0)>(c[2406714]|0)){gu[c[S+12>>2]&16383]();break}else{gu[c[S+8>>2]&16383]();break}}}while(0);c[2385472]=(c[2385472]|0)+8;S=c[2385460]|0;do{if((B&65280|0)==0&(S|0)>-8&(S|0)<(c[2113276]|0)){c[2385346]=I+(z|64);G=c[3528974]|0;if((S|0)<0|(S|0)>(c[2406714]|0)){gu[c[G+12>>2]&16383]();break}else{gu[c[G+8>>2]&16383]();break}}}while(0);c[2385472]=(c[2385472]|0)-8;S=(c[2385460]|0)+8|0;c[2385460]=S;c[2440378]=(c[2440378]|0)+32;G=c[2112968]|0;c[2415156]=G+(ag(c[2113300]|0,S)|0);do{if((B&16711680|0)==0&(S|0)>-8&(S|0)<(c[2113276]|0)){c[2385346]=I+(z|128);G=c[3528974]|0;if((S|0)<0|(S|0)>(c[2406714]|0)){gu[c[G+12>>2]&16383]();break}else{gu[c[G+8>>2]&16383]();break}}}while(0);c[2385472]=(c[2385472]|0)+8;S=c[2385460]|0;if(!(B>>>0<16777216&(S|0)>-8&(S|0)<(c[2113276]|0))){break}c[2385346]=I+(z|192);G=c[3528974]|0;if((S|0)<0|(S|0)>(c[2406714]|0)){gu[c[G+12>>2]&16383]();break}else{gu[c[G+8>>2]&16383]();break}}else{if(M){c[2385346]=f;gu[c[(c[3528974]|0)+8>>2]&16383]();a2=c[2385472]|0}else{a2=D}G=a2+8|0;c[2385472]=G;if((B&65280|0)==0){c[2385346]=I+(z|64);gu[c[(c[3528974]|0)+8>>2]&16383]();a3=c[2385472]|0}else{a3=G}G=a3-8|0;c[2385472]=G;S=(c[2385460]|0)+8|0;c[2385460]=S;c[2440378]=(c[2440378]|0)+32;R=c[2112968]|0;c[2415156]=R+(ag(c[2113300]|0,S)|0);if((B&16711680|0)==0){c[2385346]=I+(z|128);gu[c[(c[3528974]|0)+8>>2]&16383]();a4=c[2385472]|0}else{a4=G}c[2385472]=a4+8;if(B>>>0>=16777216){break}c[2385346]=I+(z|192);gu[c[(c[3528974]|0)+8>>2]&16383]()}}while(0);z=(c[2385460]|0)-8|0;c[2385460]=z;c[2440378]=(c[2440378]|0)-32;a0=r;a1=z}else{a0=C;a1=q}}while(0);F=E+4|0;if((F|0)<128){C=a0;E=F;q=a1}else{break}}q=L+128|0;if((q|0)<2048){L=q;H=a0}else{break}}if((a0|0)>511){c[3527510]=(c[3527510]|0)-291;c[3527511]=(c[3527511]|0)-291;c[3527512]=(c[3527512]|0)-291;c[3527513]=(c[3527513]|0)-291}c[J>>2]=a0}}while(0);t=t+1|0;}while((t|0)<4);u=u+1|0;}while(u>>>0<4);u=Z+1|0;if(u>>>0<4){Y=aM;Z=u}else{break}}return}function axF(a,d){a=a|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;e=c[3542106]|0;f=c[9752600+(a<<2)>>2]|0;g=c[9761800+(a<<2)>>2]|0;h=24-g|0;i=(g|0)==6?251658240:1056964608;g=c[9760032+(a<<4)+(d<<2)>>2]|0;d=b[g>>1]|0;j=d<<16>>16;c[2385472]=j;if(d<<16>>16>=9999){return}d=9541904+(a<<2)|0;k=9755456+(a<<2)|0;l=14168360+(a<<2)|0;a=g;g=j;do{j=b[a+2>>1]|0;m=j<<16>>16;c[2385460]=m;n=c[a+4>>2]|0;c[2440394]=e+(((n&i)>>>(h>>>0))+f<<2);o=n<<2&c[d>>2];n=c[(c[k>>2]|0)+o>>2]|0;p=c[2112968]|0;q=ag(c[2113300]|0,m)|0;r=c[2113308]|0;s=p+((ag(r,g)|0)+q)|0;c[2415156]=s;q=c[l>>2]|0;p=o<<6;o=q+p|0;do{if((g|0)<0){t=15791}else{if((g|0)>(c[2394778]|0)|j<<16>>16<0|(m|0)>(c[2394776]|0)){t=15791;break}if((n&255|0)==0){c[2385346]=o;gu[c[c[3528974]>>2]&16383]();u=c[2385472]|0;v=c[2113308]|0;w=c[2415156]|0}else{u=g;v=r;w=s}x=u+8|0;c[2385472]=x;c[2415156]=w+(v<<3);if((n&65280|0)==0){c[2385346]=q+(p|64);gu[c[c[3528974]>>2]&16383]();y=c[2385472]|0;z=c[2113308]|0}else{y=x;z=v}x=y-8|0;c[2385472]=x;A=(c[2385460]|0)+8|0;c[2385460]=A;B=c[2112968]|0;C=ag(c[2113300]|0,A)|0;A=B+(C+(ag(x,z)|0))|0;c[2415156]=A;if((n&16711680|0)==0){c[2385346]=q+(p|128);gu[c[c[3528974]>>2]&16383]();D=c[2385472]|0;E=c[2113308]|0;F=c[2415156]|0}else{D=x;E=z;F=A}c[2385472]=D+8;c[2415156]=F+(E<<3);if(n>>>0>=16777216){break}c[2385346]=q+(p|192);gu[c[c[3528974]>>2]&16383]()}}while(0);L19698:do{if((t|0)==15791){t=0;L19700:do{if((n&255|0)==0){c[2385346]=o;if((g|0)<=-8){break}if(!((g|0)<(c[2113280]|0)&j<<16>>16>-8&(m|0)<(c[2113276]|0))){break}do{if((g|0)>-1){if(j<<16>>16<0|(g|0)>(c[2406716]|0)|(m|0)>(c[2406714]|0)){break}gu[c[c[3528974]>>2]&16383]();break L19700}}while(0);gu[c[(c[3528974]|0)+4>>2]&16383]()}}while(0);s=(c[2385472]|0)+8|0;c[2385472]=s;c[2415156]=(c[2415156]|0)+(c[2113308]<<3);L19709:do{if((n&65280|0)==0&(s|0)>-8){r=c[2385460]|0;if(!((s|0)<(c[2113280]|0)&(r|0)>-8&(r|0)<(c[2113276]|0))){break}c[2385346]=q+(p|64);do{if((s|0)>-1){if((r|0)<0|(s|0)>(c[2406716]|0)|(r|0)>(c[2406714]|0)){break}gu[c[c[3528974]>>2]&16383]();break L19709}}while(0);gu[c[(c[3528974]|0)+4>>2]&16383]()}}while(0);s=c[2385472]|0;r=s-8|0;c[2385472]=r;A=(c[2385460]|0)+8|0;c[2385460]=A;x=c[2112968]|0;C=ag(c[2113300]|0,A)|0;c[2415156]=x+((ag(c[2113308]|0,r)|0)+C);L19717:do{if((n&16711680|0)==0&(s|0)>0){if(!((r|0)<(c[2113280]|0)&(A|0)>-8&(A|0)<(c[2113276]|0))){break}c[2385346]=q+(p|128);do{if((r|0)>-1){if((A|0)<0|(r|0)>(c[2406716]|0)|(A|0)>(c[2406714]|0)){break}gu[c[c[3528974]>>2]&16383]();break L19717}}while(0);gu[c[(c[3528974]|0)+4>>2]&16383]()}}while(0);A=(c[2385472]|0)+8|0;c[2385472]=A;c[2415156]=(c[2415156]|0)+(c[2113308]<<3);if(!(n>>>0<16777216&(A|0)>-8)){break}r=c[2385460]|0;if(!((A|0)<(c[2113280]|0)&(r|0)>-8&(r|0)<(c[2113276]|0))){break}c[2385346]=q+(p|192);do{if((A|0)>-1){if((r|0)<0|(A|0)>(c[2406716]|0)|(r|0)>(c[2406714]|0)){break}gu[c[c[3528974]>>2]&16383]();break L19698}}while(0);gu[c[(c[3528974]|0)+4>>2]&16383]()}}while(0);a=a+8|0;p=b[a>>1]|0;g=p<<16>>16;c[2385472]=g;}while(p<<16>>16<9999);return}function axG(a,d){a=a|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=c[3542106]|0;f=c[9752600+(a<<2)>>2]|0;g=c[9761800+(a<<2)>>2]|0;h=(g|0)==6?251658240:1056964608;i=24-g|0;g=c[9760032+(a<<4)+(d<<2)>>2]|0;d=b[g>>1]|0;j=d<<16>>16;c[2385472]=j;if(d<<16>>16>=9999){return}d=9541904+(a<<2)|0;k=14168360+(a<<2)|0;a=g;g=j;do{j=b[a+2>>1]|0;l=j<<16>>16;c[2385460]=l;m=c[a+4>>2]|0;c[2440394]=e+(((m&h)>>>(i>>>0))+f<<2);n=c[d>>2]&m;m=c[2112968]|0;o=ag(c[2113300]|0,l)|0;c[2415156]=m+((ag(c[2113308]|0,g)|0)+o);c[2385346]=(c[k>>2]|0)+(n<<6);do{if(j<<16>>16<0){p=15832}else{if((l|0)>(c[2406714]|0)|(g|0)<0|(g|0)>(c[2406716]|0)){p=15832;break}gu[c[c[3528974]>>2]&16383]()}}while(0);if((p|0)==15832){p=0;gu[c[(c[3528974]|0)+4>>2]&16383]()}a=a+8|0;l=b[a>>1]|0;g=l<<16>>16;c[2385472]=g;}while(l<<16>>16<9999);return}function axH(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;a=c[2438864]|0;b=0;while(1){if((b|0)>=1024){break}d=9638528+(b<<2)|0;if((c[d>>2]|0)==(a|0)){e=15841;break}else{b=b+1|0}}if((e|0)==15841){gGr(a);c[d>>2]=0}c[2438864]=0;d=c[2429774]|0;a=0;while(1){if((a|0)>=1024){break}f=9638528+(a<<2)|0;if((c[f>>2]|0)==(d|0)){e=15845;break}else{a=a+1|0}}if((e|0)==15845){gGr(d);c[f>>2]=0}c[2429774]=0;f=c[3528462]|0;d=0;while(1){if((d|0)>=1024){break}g=9638528+(d<<2)|0;if((c[g>>2]|0)==(f|0)){e=15849;break}else{d=d+1|0}}if((e|0)==15849){gGr(f);c[g>>2]=0}c[3528462]=0;g=c[3528458]|0;f=0;while(1){if((f|0)>=1024){break}h=9638528+(f<<2)|0;if((c[h>>2]|0)==(g|0)){e=15853;break}else{f=f+1|0}}if((e|0)==15853){gGr(g);c[h>>2]=0}c[3528458]=0;h=c[2438865]|0;g=0;while(1){if((g|0)>=1024){break}i=9638528+(g<<2)|0;if((c[i>>2]|0)==(h|0)){e=15857;break}else{g=g+1|0}}if((e|0)==15857){gGr(h);c[i>>2]=0}c[2438865]=0;i=c[2429775]|0;h=0;while(1){if((h|0)>=1024){break}j=9638528+(h<<2)|0;if((c[j>>2]|0)==(i|0)){e=15861;break}else{h=h+1|0}}if((e|0)==15861){gGr(i);c[j>>2]=0}c[2429775]=0;j=c[3528463]|0;i=0;while(1){if((i|0)>=1024){break}k=9638528+(i<<2)|0;if((c[k>>2]|0)==(j|0)){e=15865;break}else{i=i+1|0}}if((e|0)==15865){gGr(j);c[k>>2]=0}c[3528463]=0;k=c[3528459]|0;j=0;while(1){if((j|0)>=1024){break}l=9638528+(j<<2)|0;if((c[l>>2]|0)==(k|0)){e=15869;break}else{j=j+1|0}}if((e|0)==15869){gGr(k);c[l>>2]=0}c[3528459]=0;l=c[2438866]|0;k=0;while(1){if((k|0)>=1024){break}m=9638528+(k<<2)|0;if((c[m>>2]|0)==(l|0)){e=15873;break}else{k=k+1|0}}if((e|0)==15873){gGr(l);c[m>>2]=0}c[2438866]=0;m=c[2429776]|0;l=0;while(1){if((l|0)>=1024){break}n=9638528+(l<<2)|0;if((c[n>>2]|0)==(m|0)){e=15877;break}else{l=l+1|0}}if((e|0)==15877){gGr(m);c[n>>2]=0}c[2429776]=0;n=c[3528464]|0;m=0;while(1){if((m|0)>=1024){break}o=9638528+(m<<2)|0;if((c[o>>2]|0)==(n|0)){e=15881;break}else{m=m+1|0}}if((e|0)==15881){gGr(n);c[o>>2]=0}c[3528464]=0;o=c[3528460]|0;n=0;while(1){if((n|0)>=1024){break}p=9638528+(n<<2)|0;if((c[p>>2]|0)==(o|0)){e=15885;break}else{n=n+1|0}}if((e|0)==15885){gGr(o);c[p>>2]=0}c[3528460]=0;p=c[2438867]|0;o=0;while(1){if((o|0)>=1024){break}q=9638528+(o<<2)|0;if((c[q>>2]|0)==(p|0)){e=15889;break}else{o=o+1|0}}if((e|0)==15889){gGr(p);c[q>>2]=0}c[2438867]=0;q=c[2429777]|0;p=0;while(1){if((p|0)>=1024){break}r=9638528+(p<<2)|0;if((c[r>>2]|0)==(q|0)){e=15893;break}else{p=p+1|0}}if((e|0)==15893){gGr(q);c[r>>2]=0}c[2429777]=0;r=c[3528465]|0;q=0;while(1){if((q|0)>=1024){break}s=9638528+(q<<2)|0;if((c[s>>2]|0)==(r|0)){e=15897;break}else{q=q+1|0}}if((e|0)==15897){gGr(r);c[s>>2]=0}c[3528465]=0;s=c[3528461]|0;r=0;while(1){if((r|0)>=1024){e=15903;break}t=9638528+(r<<2)|0;if((c[t>>2]|0)==(s|0)){break}else{r=r+1|0}}if((e|0)==15903){c[3528461]=0;c[2113278]=0;c[2113282]=0;c[2113290]=0;c[2113292]=0;c[2113294]=0;return}gGr(s);c[t>>2]=0;c[3528461]=0;c[2113278]=0;c[2113282]=0;c[2113290]=0;c[2113292]=0;c[2113294]=0;return}function axI(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;g=(d|0)/64|0;h=1;while(1){if((h|0)<(g|0)){h=h<<1}else{break}}i=9541904+(b<<2)|0;j=h-1|0;c[i>>2]=j;h=9755456+(b<<2)|0;k=c[h>>2]|0;if((k|0)==0){l=j}else{m=0;while(1){if((m|0)>=1024){n=j;break}o=9638528+(m<<2)|0;if((c[o>>2]|0)==(k|0)){p=15910;break}else{m=m+1|0}}if((p|0)==15910){gGr(k);c[o>>2]=0;n=c[i>>2]|0}c[h>>2]=0;l=n}n=l+1|0;l=0;while(1){if((l|0)>=1024){break}q=9638528+(l<<2)|0;if((c[q>>2]|0)==0){p=15915;break}else{l=l+1|0}}do{if((p|0)==15915){l=gGq(n)|0;c[q>>2]=l;if((l|0)==0){break}gGz(l|0,0,n|0);c[h>>2]=l;if((d|0)>63){o=14168360+(b<<2)|0;k=0;while(1){m=k+1|0;j=m<<6;r=k<<6;while(1){if((r|0)>=(j|0)){s=1;break}if((a[(c[o>>2]|0)+r|0]|0)==0){r=r+1|0}else{s=0;break}}a[l+k|0]=s;if((m|0)<(g|0)){k=m}else{break}}}k=c[i>>2]|0;if((g|0)<=(k|0)){o=g;do{a[l+o|0]=1;o=o+1|0;}while((o|0)<=(k|0))}k=9719096+(b<<2)|0;o=c[k>>2]|0;if((o|0)==0){t=0}else{l=o;o=0;while(1){if((o|0)>=1024){break}u=9638528+(o<<2)|0;if((c[u>>2]|0)==(l|0)){p=15929;break}else{o=o+1|0}}if((p|0)==15929){gGr(l);c[u>>2]=0}c[k>>2]=0;t=0}while(1){if((t|0)>=1024){break}v=9638528+(t<<2)|0;if((c[v>>2]|0)==0){p=15933;break}else{t=t+1|0}}do{if((p|0)==15933){l=gGq(49152)|0;c[v>>2]=l;if((l|0)==0){break}gGz(l|0,0,49152);c[k>>2]=l;l=14113848+(b<<2)|0;o=c[l>>2]|0;if((o|0)!=0){r=o;o=0;while(1){if((o|0)>=1024){break}w=9638528+(o<<2)|0;if((c[w>>2]|0)==(r|0)){p=15939;break}else{o=o+1|0}}if((p|0)==15939){gGr(r);c[w>>2]=0}c[l>>2]=0}o=c[2113276]<<2;m=0;while(1){if((m|0)>=1024){break}x=9638528+(m<<2)|0;if((c[x>>2]|0)==0){p=15944;break}else{m=m+1|0}}do{if((p|0)==15944){m=gGq(o)|0;c[x>>2]=m;if((m|0)==0){break}gGz(m|0,0,o|0);c[l>>2]=m;m=14113832+(b<<2)|0;r=c[m>>2]|0;if((r|0)!=0){j=r;r=0;while(1){if((r|0)>=1024){break}y=9638528+(r<<2)|0;if((c[y>>2]|0)==(j|0)){p=15950;break}else{r=r+1|0}}if((p|0)==15950){gGr(j);c[y>>2]=0}c[m>>2]=0}r=c[2113276]<<2;z=0;while(1){if((z|0)>=1024){break}A=9638528+(z<<2)|0;if((c[A>>2]|0)==0){p=15955;break}else{z=z+1|0}}do{if((p|0)==15955){z=gGq(r)|0;c[A>>2]=z;if((z|0)==0){break}gGz(z|0,0,r|0);c[m>>2]=z;c[9761800+(b<<2)>>2]=e;c[9752600+(b<<2)>>2]=f;c[14168320+(b*12|0)>>2]=0;return}}while(0);c[m>>2]=0;return}}while(0);c[l>>2]=0;return}}while(0);c[k>>2]=0;return}}while(0);c[h>>2]=0;return}function axJ(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0;a=c[2440394]|0;d=c[2415156]|0;e=1;f=c[2385346]|0;while(1){g=c[f>>2]|0;h=g&255;if((h|0)!=0){b[d>>1]=c[a+(h<<2)>>2]&65535}h=g>>>8&255;if((h|0)!=0){b[d+2>>1]=c[a+(h<<2)>>2]&65535}h=g>>>16&255;if((h|0)!=0){b[d+4>>1]=c[a+(h<<2)>>2]&65535}h=g>>>24;if((h|0)!=0){b[d+6>>1]=c[a+(h<<2)>>2]&65535}i=f+8|0;h=c[f+4>>2]|0;g=h&255;if((g|0)!=0){b[d+8>>1]=c[a+(g<<2)>>2]&65535}g=h>>>8&255;if((g|0)!=0){b[d+10>>1]=c[a+(g<<2)>>2]&65535}g=h>>>16&255;if((g|0)!=0){b[d+12>>1]=c[a+(g<<2)>>2]&65535}g=h>>>24;if((g|0)!=0){b[d+14>>1]=c[a+(g<<2)>>2]&65535}if((e|0)>=8){break}d=d+640|0;e=e+1|0;f=i}c[2385346]=i;return}function axK(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;a=c[2385460]|0;d=c[2113276]|0;e=c[2385472]|0;f=(e|0)<313;g=(e|0)<0;h=(e|0)<-3;i=-e|0;j=i<<3&24;k=i<<1;l=c[2440394]|0;m=(e|0)<320;n=c[2415156]|0;o=0;L19958:while(1){p=a+o|0;L19960:do{if((p|0)<0){q=c[2385346]|0}else{if((p|0)>=(d|0)){r=16040;break L19958}s=c[2385346]|0;t=c[s>>2]|0;if(!f){if(!m){q=s;break}u=t&255;if((u|0)!=0){b[n>>1]=c[l+(u<<2)>>2]&65535}if((e|0)>=319){q=s;break}u=t>>>8&255;if((u|0)!=0){b[n+2>>1]=c[l+(u<<2)>>2]&65535}if((e|0)>=318){q=s;break}u=t>>>16&255;if((u|0)!=0){b[n+4>>1]=c[l+(u<<2)>>2]&65535}if((e|0)>=317){q=s;break}u=t>>>24;if((u|0)!=0){b[n+6>>1]=c[l+(u<<2)>>2]&65535}u=c[s+4>>2]|0;if((e|0)>=316){q=s;break}v=u&255;if((v|0)!=0){b[n+8>>1]=c[l+(v<<2)>>2]&65535}if((e|0)>=315){q=s;break}v=u>>>8&255;if((v|0)!=0){b[n+10>>1]=c[l+(v<<2)>>2]&65535}if((e|0)>=314){q=s;break}v=u>>>16&255;if((v|0)==0){q=s;break}b[n+12>>1]=c[l+(v<<2)>>2]&65535;q=s;break}if(g){if(h){w=c[s+4>>2]|0}else{w=t}v=w>>j;u=n+k|0;switch(i|0){case 7:{x=v;y=u;break};case 1:{z=v;A=u;r=15996;break};case 3:{B=v;C=u;r=16002;break};case 0:{D=u;E=v;r=15993;break};case 2:{F=v;G=u;r=15999;break};case 5:{H=v;I=u;r=16008;break};case 4:{J=v;K=u;r=16005;break};case 6:{L=v;M=u;r=16011;break};default:{q=s;break L19960}}}else{D=n;E=t;r=15993}if((r|0)==15993){r=0;t=E&255;if((t|0)!=0){b[D>>1]=c[l+(t<<2)>>2]&65535}z=E>>8;A=D+2|0;r=15996}if((r|0)==15996){r=0;t=z&255;if((t|0)!=0){b[A>>1]=c[l+(t<<2)>>2]&65535}F=z>>8;G=A+2|0;r=15999}if((r|0)==15999){r=0;t=F&255;if((t|0)!=0){b[G>>1]=c[l+(t<<2)>>2]&65535}B=F>>8;C=G+2|0;r=16002}if((r|0)==16002){r=0;t=B&255;if((t|0)!=0){b[C>>1]=c[l+(t<<2)>>2]&65535}J=c[s+4>>2]|0;K=C+2|0;r=16005}if((r|0)==16005){r=0;t=J&255;if((t|0)!=0){b[K>>1]=c[l+(t<<2)>>2]&65535}H=J>>8;I=K+2|0;r=16008}if((r|0)==16008){r=0;t=H&255;if((t|0)!=0){b[I>>1]=c[l+(t<<2)>>2]&65535}L=H>>8;M=I+2|0;r=16011}if((r|0)==16011){r=0;t=L&255;if((t|0)!=0){b[M>>1]=c[l+(t<<2)>>2]&65535}x=L>>8;y=M+2|0}t=x&255;if((t|0)==0){q=s;break}b[y>>1]=c[l+(t<<2)>>2]&65535;q=s}}while(0);c[2385346]=q+8;p=o+1|0;if((p|0)>=8){r=16041;break}n=n+640|0;o=p}if((r|0)==16041){return}else if((r|0)==16040){return}}function axL(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;a=c[2385472]|0;d=c[2440378]|0;e=c[2440394]|0;f=c[2415156]|0;g=0;h=c[2385346]|0;while(1){i=a-(c[d+(g<<2)>>2]|0)|0;j=i&511;k=j>>>0>503;l=k?i|-512:j;L20043:do{if((l|0)<=319){j=l<<1;i=f+j|0;m=c[h>>2]|0;if((l|0)>=313){n=m&255;if((n|0)!=0){b[i>>1]=c[e+(n<<2)>>2]&65535}if((l|0)>=319){break}n=m>>>8&255;if((n|0)!=0){b[f+(j+2)>>1]=c[e+(n<<2)>>2]&65535}if((l|0)>=318){break}n=m>>>16&255;if((n|0)!=0){b[f+(j+4)>>1]=c[e+(n<<2)>>2]&65535}if((l|0)>=317){break}n=m>>>24;if((n|0)!=0){b[f+(j+6)>>1]=c[e+(n<<2)>>2]&65535}n=c[h+4>>2]|0;if((l|0)>=316){break}o=n&255;if((o|0)!=0){b[f+(j+8)>>1]=c[e+(o<<2)>>2]&65535}if((l|0)>=315){break}o=n>>>8&255;if((o|0)!=0){b[f+(j+10)>>1]=c[e+(o<<2)>>2]&65535}if((l|0)>=314){break}o=n>>>16&255;if((o|0)==0){break}b[f+(j+12)>>1]=c[e+(o<<2)>>2]&65535;break}if(k){if((l|0)<-3){p=c[h+4>>2]|0}else{p=m}o=-l|0;j=p>>(o<<3&24);switch(o|0){case 3:{q=j;r=f;s=16058;break};case 4:{t=j;u=f;s=16061;break};case 5:{v=j;w=f;s=16064;break};case 6:{x=j;y=f;s=16067;break};case 7:{z=j;A=f;break};case 1:{B=j;C=f;s=16052;break};case 2:{D=j;E=f;s=16055;break};case 0:{F=f;G=j;s=16049;break};default:{break L20043}}}else{F=i;G=m;s=16049}if((s|0)==16049){s=0;m=G&255;if((m|0)!=0){b[F>>1]=c[e+(m<<2)>>2]&65535}B=G>>8;C=F+2|0;s=16052}if((s|0)==16052){s=0;m=B&255;if((m|0)!=0){b[C>>1]=c[e+(m<<2)>>2]&65535}D=B>>8;E=C+2|0;s=16055}if((s|0)==16055){s=0;m=D&255;if((m|0)!=0){b[E>>1]=c[e+(m<<2)>>2]&65535}q=D>>8;r=E+2|0;s=16058}if((s|0)==16058){s=0;m=q&255;if((m|0)!=0){b[r>>1]=c[e+(m<<2)>>2]&65535}t=c[h+4>>2]|0;u=r+2|0;s=16061}if((s|0)==16061){s=0;m=t&255;if((m|0)!=0){b[u>>1]=c[e+(m<<2)>>2]&65535}v=t>>8;w=u+2|0;s=16064}if((s|0)==16064){s=0;m=v&255;if((m|0)!=0){b[w>>1]=c[e+(m<<2)>>2]&65535}x=v>>8;y=w+2|0;s=16067}if((s|0)==16067){s=0;m=x&255;if((m|0)!=0){b[y>>1]=c[e+(m<<2)>>2]&65535}z=x>>8;A=y+2|0}m=z&255;if((m|0)==0){break}b[A>>1]=c[e+(m<<2)>>2]&65535}}while(0);H=h+8|0;k=g+1|0;if((k|0)>=8){break}f=f+640|0;g=k;h=H}c[3528522]=l;c[2385346]=H;return}function axM(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;a=c[2385460]|0;d=c[2113276]|0;e=c[2385472]|0;f=c[2440378]|0;g=c[2440394]|0;h=c[2415156]|0;i=0;L20119:while(1){j=a+i|0;do{if((j|0)<0){c[2385346]=(c[2385346]|0)+8}else{if((j|0)>=(d|0)){k=16153;break L20119}l=e-(c[f+(i<<2)>>2]|0)|0;m=l&511;n=m>>>0>503;o=n?l|-512:m;c[3528522]=o;if((o|0)>319){c[2385346]=(c[2385346]|0)+8;break}m=o<<1;l=h+m|0;p=c[2385346]|0;q=c[p>>2]|0;L20127:do{if((o|0)<313){if(n){if((o|0)<-3){r=c[p+4>>2]|0}else{r=q}s=-o|0;t=r>>(s<<3&24);switch(s|0){case 7:{u=t;v=h;break};case 2:{w=t;x=h;k=16112;break};case 3:{y=t;z=h;k=16115;break};case 1:{A=t;B=h;k=16109;break};case 5:{C=t;D=h;k=16121;break};case 0:{E=h;F=t;k=16106;break};case 6:{G=t;H=h;k=16124;break};case 4:{I=t;J=h;k=16118;break};default:{break L20127}}}else{E=l;F=q;k=16106}if((k|0)==16106){k=0;t=F&255;if((t|0)!=0){b[E>>1]=c[g+(t<<2)>>2]&65535}A=F>>8;B=E+2|0;k=16109}if((k|0)==16109){k=0;t=A&255;if((t|0)!=0){b[B>>1]=c[g+(t<<2)>>2]&65535}w=A>>8;x=B+2|0;k=16112}if((k|0)==16112){k=0;t=w&255;if((t|0)!=0){b[x>>1]=c[g+(t<<2)>>2]&65535}y=w>>8;z=x+2|0;k=16115}if((k|0)==16115){k=0;t=y&255;if((t|0)!=0){b[z>>1]=c[g+(t<<2)>>2]&65535}I=c[p+4>>2]|0;J=z+2|0;k=16118}if((k|0)==16118){k=0;t=I&255;if((t|0)!=0){b[J>>1]=c[g+(t<<2)>>2]&65535}C=I>>8;D=J+2|0;k=16121}if((k|0)==16121){k=0;t=C&255;if((t|0)!=0){b[D>>1]=c[g+(t<<2)>>2]&65535}G=C>>8;H=D+2|0;k=16124}if((k|0)==16124){k=0;t=G&255;if((t|0)!=0){b[H>>1]=c[g+(t<<2)>>2]&65535}u=G>>8;v=H+2|0}t=u&255;if((t|0)==0){break}b[v>>1]=c[g+(t<<2)>>2]&65535}else{t=q&255;if((t|0)!=0){b[l>>1]=c[g+(t<<2)>>2]&65535}if((o|0)>=319){break}t=q>>>8&255;if((t|0)!=0){b[h+(m+2)>>1]=c[g+(t<<2)>>2]&65535}if((o|0)>=318){break}t=q>>>16&255;if((t|0)!=0){b[h+(m+4)>>1]=c[g+(t<<2)>>2]&65535}if((o|0)>=317){break}t=q>>>24;if((t|0)!=0){b[h+(m+6)>>1]=c[g+(t<<2)>>2]&65535}t=c[p+4>>2]|0;if((o|0)>=316){break}s=t&255;if((s|0)!=0){b[h+(m+8)>>1]=c[g+(s<<2)>>2]&65535}if((o|0)>=315){break}s=t>>>8&255;if((s|0)!=0){b[h+(m+10)>>1]=c[g+(s<<2)>>2]&65535}if((o|0)>=314){break}s=t>>>16&255;if((s|0)==0){break}b[h+(m+12)>>1]=c[g+(s<<2)>>2]&65535}}while(0);c[2385346]=p+8}}while(0);j=i+1|0;if((j|0)>=8){k=16154;break}h=h+640|0;i=j}if((k|0)==16153){return}else if((k|0)==16154){return}}function axN(){var a=0,d=0,e=0,f=0,g=0;a=c[2415156]|0;d=c[2385346]|0;e=d+4|0;c[2385346]=e;f=c[d>>2]|0;g=f&255;if((g|0)!=0){b[a>>1]=c[(c[2440394]|0)+(g<<2)>>2]&65535}g=f>>>8&255;if((g|0)!=0){b[a+2>>1]=c[(c[2440394]|0)+(g<<2)>>2]&65535}g=f>>>16&255;if((g|0)!=0){b[a+4>>1]=c[(c[2440394]|0)+(g<<2)>>2]&65535}g=f>>>24;if((g|0)!=0){b[a+6>>1]=c[(c[2440394]|0)+(g<<2)>>2]&65535}c[2385346]=d+8;d=c[e>>2]|0;e=d&255;if((e|0)!=0){b[a+8>>1]=c[(c[2440394]|0)+(e<<2)>>2]&65535}e=d>>>8&255;if((e|0)!=0){b[a+10>>1]=c[(c[2440394]|0)+(e<<2)>>2]&65535}e=d>>>16&255;if((e|0)!=0){b[a+12>>1]=c[(c[2440394]|0)+(e<<2)>>2]&65535}e=d>>>24;if((e|0)==0){return}b[a+14>>1]=c[(c[2440394]|0)+(e<<2)>>2]&65535;return}function axO(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;a=c[2415156]|0;d=c[2385346]|0;e=c[d>>2]|0;f=c[2385472]|0;if((f|0)<313){L20233:do{if((f|0)<0){if((f|0)<-3){g=c[d+4>>2]|0}else{g=e}h=-f|0;i=g>>(h<<3&24);j=a+(h<<1)|0;switch(h|0){case 0:{k=j;l=i;m=16179;break L20233;break};case 5:{n=i;o=j;m=16194;break L20233;break};case 3:{p=i;q=j;m=16188;break L20233;break};case 7:{r=i;s=j;break L20233;break};case 4:{t=i;u=j;m=16191;break L20233;break};case 2:{v=i;w=j;m=16185;break L20233;break};case 1:{x=i;y=j;m=16182;break L20233;break};case 6:{z=i;A=j;m=16197;break L20233;break};default:{}}B=d+8|0;c[2385346]=B;return}else{k=a;l=e;m=16179}}while(0);if((m|0)==16179){g=l&255;if((g|0)!=0){b[k>>1]=c[(c[2440394]|0)+(g<<2)>>2]&65535}x=l>>8;y=k+2|0;m=16182}if((m|0)==16182){k=x&255;if((k|0)!=0){b[y>>1]=c[(c[2440394]|0)+(k<<2)>>2]&65535}v=x>>8;w=y+2|0;m=16185}if((m|0)==16185){y=v&255;if((y|0)!=0){b[w>>1]=c[(c[2440394]|0)+(y<<2)>>2]&65535}p=v>>8;q=w+2|0;m=16188}if((m|0)==16188){w=p&255;if((w|0)!=0){b[q>>1]=c[(c[2440394]|0)+(w<<2)>>2]&65535}t=c[d+4>>2]|0;u=q+2|0;m=16191}if((m|0)==16191){q=t&255;if((q|0)!=0){b[u>>1]=c[(c[2440394]|0)+(q<<2)>>2]&65535}n=t>>8;o=u+2|0;m=16194}if((m|0)==16194){u=n&255;if((u|0)!=0){b[o>>1]=c[(c[2440394]|0)+(u<<2)>>2]&65535}z=n>>8;A=o+2|0;m=16197}if((m|0)==16197){m=z&255;if((m|0)!=0){b[A>>1]=c[(c[2440394]|0)+(m<<2)>>2]&65535}r=z>>8;s=A+2|0}A=r&255;if((A|0)==0){B=d+8|0;c[2385346]=B;return}b[s>>1]=c[(c[2440394]|0)+(A<<2)>>2]&65535;B=d+8|0;c[2385346]=B;return}else{if((f|0)>=320){B=d+8|0;c[2385346]=B;return}A=e&255;if((A|0)!=0){b[a>>1]=c[(c[2440394]|0)+(A<<2)>>2]&65535}if((f|0)>=319){B=d+8|0;c[2385346]=B;return}A=e>>>8&255;if((A|0)!=0){b[a+2>>1]=c[(c[2440394]|0)+(A<<2)>>2]&65535}if((f|0)>=318){B=d+8|0;c[2385346]=B;return}A=e>>>16&255;if((A|0)!=0){b[a+4>>1]=c[(c[2440394]|0)+(A<<2)>>2]&65535}if((f|0)>=317){B=d+8|0;c[2385346]=B;return}A=e>>>24;if((A|0)!=0){b[a+6>>1]=c[(c[2440394]|0)+(A<<2)>>2]&65535}A=c[d+4>>2]|0;if((f|0)>=316){B=d+8|0;c[2385346]=B;return}e=A&255;if((e|0)!=0){b[a+8>>1]=c[(c[2440394]|0)+(e<<2)>>2]&65535}if((f|0)>=315){B=d+8|0;c[2385346]=B;return}e=A>>>8&255;if((e|0)!=0){b[a+10>>1]=c[(c[2440394]|0)+(e<<2)>>2]&65535}if((f|0)>=314){B=d+8|0;c[2385346]=B;return}f=A>>>16&255;if((f|0)==0){B=d+8|0;c[2385346]=B;return}b[a+12>>1]=c[(c[2440394]|0)+(f<<2)>>2]&65535;B=d+8|0;c[2385346]=B;return}}function axP(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0;a=c[2440394]|0;d=c[2415156]|0;e=1;f=c[2385346]|0;while(1){g=c[f>>2]|0;h=g&255;if((h|0)!=0){b[d>>1]=c[a+(h<<2)>>2]&65535}h=g>>>8&255;if((h|0)!=0){b[d+2>>1]=c[a+(h<<2)>>2]&65535}h=g>>>16&255;if((h|0)!=0){b[d+4>>1]=c[a+(h<<2)>>2]&65535}h=g>>>24;if((h|0)!=0){b[d+6>>1]=c[a+(h<<2)>>2]&65535}i=f+8|0;h=c[f+4>>2]|0;g=h&255;if((g|0)!=0){b[d+8>>1]=c[a+(g<<2)>>2]&65535}g=h>>>8&255;if((g|0)!=0){b[d+10>>1]=c[a+(g<<2)>>2]&65535}g=h>>>16&255;if((g|0)!=0){b[d+12>>1]=c[a+(g<<2)>>2]&65535}g=h>>>24;if((g|0)!=0){b[d+14>>1]=c[a+(g<<2)>>2]&65535}if((e|0)>=8){break}d=d+768|0;e=e+1|0;f=i}c[2385346]=i;return}function axQ(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;a=c[2385460]|0;d=c[2113276]|0;e=c[2385472]|0;f=(e|0)<377;g=(e|0)<0;h=(e|0)<-3;i=-e|0;j=i<<3&24;k=i<<1;l=c[2440394]|0;m=(e|0)<384;n=c[2415156]|0;o=0;L20353:while(1){p=a+o|0;L20355:do{if((p|0)<0){q=c[2385346]|0}else{if((p|0)>=(d|0)){r=16312;break L20353}s=c[2385346]|0;t=c[s>>2]|0;if(!f){if(!m){q=s;break}u=t&255;if((u|0)!=0){b[n>>1]=c[l+(u<<2)>>2]&65535}if((e|0)>=383){q=s;break}u=t>>>8&255;if((u|0)!=0){b[n+2>>1]=c[l+(u<<2)>>2]&65535}if((e|0)>=382){q=s;break}u=t>>>16&255;if((u|0)!=0){b[n+4>>1]=c[l+(u<<2)>>2]&65535}if((e|0)>=381){q=s;break}u=t>>>24;if((u|0)!=0){b[n+6>>1]=c[l+(u<<2)>>2]&65535}u=c[s+4>>2]|0;if((e|0)>=380){q=s;break}v=u&255;if((v|0)!=0){b[n+8>>1]=c[l+(v<<2)>>2]&65535}if((e|0)>=379){q=s;break}v=u>>>8&255;if((v|0)!=0){b[n+10>>1]=c[l+(v<<2)>>2]&65535}if((e|0)>=378){q=s;break}v=u>>>16&255;if((v|0)==0){q=s;break}b[n+12>>1]=c[l+(v<<2)>>2]&65535;q=s;break}if(g){if(h){w=c[s+4>>2]|0}else{w=t}v=w>>j;u=n+k|0;switch(i|0){case 6:{x=v;y=u;r=16283;break};case 0:{z=u;A=v;r=16265;break};case 3:{B=v;C=u;r=16274;break};case 4:{D=v;E=u;r=16277;break};case 1:{F=v;G=u;r=16268;break};case 5:{H=v;I=u;r=16280;break};case 2:{J=v;K=u;r=16271;break};case 7:{L=v;M=u;break};default:{q=s;break L20355}}}else{z=n;A=t;r=16265}if((r|0)==16265){r=0;t=A&255;if((t|0)!=0){b[z>>1]=c[l+(t<<2)>>2]&65535}F=A>>8;G=z+2|0;r=16268}if((r|0)==16268){r=0;t=F&255;if((t|0)!=0){b[G>>1]=c[l+(t<<2)>>2]&65535}J=F>>8;K=G+2|0;r=16271}if((r|0)==16271){r=0;t=J&255;if((t|0)!=0){b[K>>1]=c[l+(t<<2)>>2]&65535}B=J>>8;C=K+2|0;r=16274}if((r|0)==16274){r=0;t=B&255;if((t|0)!=0){b[C>>1]=c[l+(t<<2)>>2]&65535}D=c[s+4>>2]|0;E=C+2|0;r=16277}if((r|0)==16277){r=0;t=D&255;if((t|0)!=0){b[E>>1]=c[l+(t<<2)>>2]&65535}H=D>>8;I=E+2|0;r=16280}if((r|0)==16280){r=0;t=H&255;if((t|0)!=0){b[I>>1]=c[l+(t<<2)>>2]&65535}x=H>>8;y=I+2|0;r=16283}if((r|0)==16283){r=0;t=x&255;if((t|0)!=0){b[y>>1]=c[l+(t<<2)>>2]&65535}L=x>>8;M=y+2|0}t=L&255;if((t|0)==0){q=s;break}b[M>>1]=c[l+(t<<2)>>2]&65535;q=s}}while(0);c[2385346]=q+8;p=o+1|0;if((p|0)>=8){r=16313;break}n=n+768|0;o=p}if((r|0)==16312){return}else if((r|0)==16313){return}}function axR(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;a=c[2385472]|0;d=c[2440378]|0;e=c[2440394]|0;f=c[2415156]|0;g=0;h=c[2385346]|0;while(1){i=a-(c[d+(g<<2)>>2]|0)|0;j=i&511;k=j>>>0>503;l=k?i|-512:j;L20438:do{if((l|0)<=383){j=l<<1;i=f+j|0;m=c[h>>2]|0;if((l|0)>=377){n=m&255;if((n|0)!=0){b[i>>1]=c[e+(n<<2)>>2]&65535}if((l|0)>=383){break}n=m>>>8&255;if((n|0)!=0){b[f+(j+2)>>1]=c[e+(n<<2)>>2]&65535}if((l|0)>=382){break}n=m>>>16&255;if((n|0)!=0){b[f+(j+4)>>1]=c[e+(n<<2)>>2]&65535}if((l|0)>=381){break}n=m>>>24;if((n|0)!=0){b[f+(j+6)>>1]=c[e+(n<<2)>>2]&65535}n=c[h+4>>2]|0;if((l|0)>=380){break}o=n&255;if((o|0)!=0){b[f+(j+8)>>1]=c[e+(o<<2)>>2]&65535}if((l|0)>=379){break}o=n>>>8&255;if((o|0)!=0){b[f+(j+10)>>1]=c[e+(o<<2)>>2]&65535}if((l|0)>=378){break}o=n>>>16&255;if((o|0)==0){break}b[f+(j+12)>>1]=c[e+(o<<2)>>2]&65535;break}if(k){if((l|0)<-3){p=c[h+4>>2]|0}else{p=m}o=-l|0;j=p>>(o<<3&24);switch(o|0){case 1:{q=j;r=f;s=16324;break};case 4:{t=j;u=f;s=16333;break};case 5:{v=j;w=f;s=16336;break};case 6:{x=j;y=f;s=16339;break};case 0:{z=f;A=j;s=16321;break};case 3:{B=j;C=f;s=16330;break};case 7:{D=j;E=f;break};case 2:{F=j;G=f;s=16327;break};default:{break L20438}}}else{z=i;A=m;s=16321}if((s|0)==16321){s=0;m=A&255;if((m|0)!=0){b[z>>1]=c[e+(m<<2)>>2]&65535}q=A>>8;r=z+2|0;s=16324}if((s|0)==16324){s=0;m=q&255;if((m|0)!=0){b[r>>1]=c[e+(m<<2)>>2]&65535}F=q>>8;G=r+2|0;s=16327}if((s|0)==16327){s=0;m=F&255;if((m|0)!=0){b[G>>1]=c[e+(m<<2)>>2]&65535}B=F>>8;C=G+2|0;s=16330}if((s|0)==16330){s=0;m=B&255;if((m|0)!=0){b[C>>1]=c[e+(m<<2)>>2]&65535}t=c[h+4>>2]|0;u=C+2|0;s=16333}if((s|0)==16333){s=0;m=t&255;if((m|0)!=0){b[u>>1]=c[e+(m<<2)>>2]&65535}v=t>>8;w=u+2|0;s=16336}if((s|0)==16336){s=0;m=v&255;if((m|0)!=0){b[w>>1]=c[e+(m<<2)>>2]&65535}x=v>>8;y=w+2|0;s=16339}if((s|0)==16339){s=0;m=x&255;if((m|0)!=0){b[y>>1]=c[e+(m<<2)>>2]&65535}D=x>>8;E=y+2|0}m=D&255;if((m|0)==0){break}b[E>>1]=c[e+(m<<2)>>2]&65535}}while(0);H=h+8|0;k=g+1|0;if((k|0)>=8){break}f=f+768|0;g=k;h=H}c[3528522]=l;c[2385346]=H;return}function axS(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;a=c[2385460]|0;d=c[2113276]|0;e=c[2385472]|0;f=c[2440378]|0;g=c[2440394]|0;h=c[2415156]|0;i=0;L20514:while(1){j=a+i|0;do{if((j|0)<0){c[2385346]=(c[2385346]|0)+8}else{if((j|0)>=(d|0)){k=16425;break L20514}l=e-(c[f+(i<<2)>>2]|0)|0;m=l&511;n=m>>>0>503;o=n?l|-512:m;c[3528522]=o;if((o|0)>383){c[2385346]=(c[2385346]|0)+8;break}m=o<<1;l=h+m|0;p=c[2385346]|0;q=c[p>>2]|0;L20522:do{if((o|0)<377){if(n){if((o|0)<-3){r=c[p+4>>2]|0}else{r=q}s=-o|0;t=r>>(s<<3&24);switch(s|0){case 2:{u=t;v=h;k=16384;break};case 3:{w=t;x=h;k=16387;break};case 4:{y=t;z=h;k=16390;break};case 5:{A=t;B=h;k=16393;break};case 1:{C=t;D=h;k=16381;break};case 0:{E=h;F=t;k=16378;break};case 6:{G=t;H=h;k=16396;break};case 7:{I=t;J=h;break};default:{break L20522}}}else{E=l;F=q;k=16378}if((k|0)==16378){k=0;t=F&255;if((t|0)!=0){b[E>>1]=c[g+(t<<2)>>2]&65535}C=F>>8;D=E+2|0;k=16381}if((k|0)==16381){k=0;t=C&255;if((t|0)!=0){b[D>>1]=c[g+(t<<2)>>2]&65535}u=C>>8;v=D+2|0;k=16384}if((k|0)==16384){k=0;t=u&255;if((t|0)!=0){b[v>>1]=c[g+(t<<2)>>2]&65535}w=u>>8;x=v+2|0;k=16387}if((k|0)==16387){k=0;t=w&255;if((t|0)!=0){b[x>>1]=c[g+(t<<2)>>2]&65535}y=c[p+4>>2]|0;z=x+2|0;k=16390}if((k|0)==16390){k=0;t=y&255;if((t|0)!=0){b[z>>1]=c[g+(t<<2)>>2]&65535}A=y>>8;B=z+2|0;k=16393}if((k|0)==16393){k=0;t=A&255;if((t|0)!=0){b[B>>1]=c[g+(t<<2)>>2]&65535}G=A>>8;H=B+2|0;k=16396}if((k|0)==16396){k=0;t=G&255;if((t|0)!=0){b[H>>1]=c[g+(t<<2)>>2]&65535}I=G>>8;J=H+2|0}t=I&255;if((t|0)==0){break}b[J>>1]=c[g+(t<<2)>>2]&65535}else{t=q&255;if((t|0)!=0){b[l>>1]=c[g+(t<<2)>>2]&65535}if((o|0)>=383){break}t=q>>>8&255;if((t|0)!=0){b[h+(m+2)>>1]=c[g+(t<<2)>>2]&65535}if((o|0)>=382){break}t=q>>>16&255;if((t|0)!=0){b[h+(m+4)>>1]=c[g+(t<<2)>>2]&65535}if((o|0)>=381){break}t=q>>>24;if((t|0)!=0){b[h+(m+6)>>1]=c[g+(t<<2)>>2]&65535}t=c[p+4>>2]|0;if((o|0)>=380){break}s=t&255;if((s|0)!=0){b[h+(m+8)>>1]=c[g+(s<<2)>>2]&65535}if((o|0)>=379){break}s=t>>>8&255;if((s|0)!=0){b[h+(m+10)>>1]=c[g+(s<<2)>>2]&65535}if((o|0)>=378){break}s=t>>>16&255;if((s|0)==0){break}b[h+(m+12)>>1]=c[g+(s<<2)>>2]&65535}}while(0);c[2385346]=p+8}}while(0);j=i+1|0;if((j|0)>=8){k=16426;break}h=h+768|0;i=j}if((k|0)==16425){return}else if((k|0)==16426){return}}function axT(){var a=0,d=0,e=0,f=0,g=0;a=c[2415156]|0;d=c[2385346]|0;e=d+4|0;c[2385346]=e;f=c[d>>2]|0;g=f&255;if((g|0)!=0){b[a>>1]=c[(c[2440394]|0)+(g<<2)>>2]&65535}g=f>>>8&255;if((g|0)!=0){b[a+2>>1]=c[(c[2440394]|0)+(g<<2)>>2]&65535}g=f>>>16&255;if((g|0)!=0){b[a+4>>1]=c[(c[2440394]|0)+(g<<2)>>2]&65535}g=f>>>24;if((g|0)!=0){b[a+6>>1]=c[(c[2440394]|0)+(g<<2)>>2]&65535}c[2385346]=d+8;d=c[e>>2]|0;e=d&255;if((e|0)!=0){b[a+8>>1]=c[(c[2440394]|0)+(e<<2)>>2]&65535}e=d>>>8&255;if((e|0)!=0){b[a+10>>1]=c[(c[2440394]|0)+(e<<2)>>2]&65535}e=d>>>16&255;if((e|0)!=0){b[a+12>>1]=c[(c[2440394]|0)+(e<<2)>>2]&65535}e=d>>>24;if((e|0)==0){return}b[a+14>>1]=c[(c[2440394]|0)+(e<<2)>>2]&65535;return}function axU(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;a=c[2415156]|0;d=c[2385346]|0;e=c[d>>2]|0;f=c[2385472]|0;if((f|0)<377){L20628:do{if((f|0)<0){if((f|0)<-3){g=c[d+4>>2]|0}else{g=e}h=-f|0;i=g>>(h<<3&24);j=a+(h<<1)|0;switch(h|0){case 7:{k=i;l=j;break L20628;break};case 5:{m=i;n=j;o=16466;break L20628;break};case 0:{p=j;q=i;o=16451;break L20628;break};case 2:{r=i;s=j;o=16457;break L20628;break};case 6:{t=i;u=j;o=16469;break L20628;break};case 1:{v=i;w=j;o=16454;break L20628;break};case 3:{x=i;y=j;o=16460;break L20628;break};case 4:{z=i;A=j;o=16463;break L20628;break};default:{}}B=d+8|0;c[2385346]=B;return}else{p=a;q=e;o=16451}}while(0);if((o|0)==16451){g=q&255;if((g|0)!=0){b[p>>1]=c[(c[2440394]|0)+(g<<2)>>2]&65535}v=q>>8;w=p+2|0;o=16454}if((o|0)==16454){p=v&255;if((p|0)!=0){b[w>>1]=c[(c[2440394]|0)+(p<<2)>>2]&65535}r=v>>8;s=w+2|0;o=16457}if((o|0)==16457){w=r&255;if((w|0)!=0){b[s>>1]=c[(c[2440394]|0)+(w<<2)>>2]&65535}x=r>>8;y=s+2|0;o=16460}if((o|0)==16460){s=x&255;if((s|0)!=0){b[y>>1]=c[(c[2440394]|0)+(s<<2)>>2]&65535}z=c[d+4>>2]|0;A=y+2|0;o=16463}if((o|0)==16463){y=z&255;if((y|0)!=0){b[A>>1]=c[(c[2440394]|0)+(y<<2)>>2]&65535}m=z>>8;n=A+2|0;o=16466}if((o|0)==16466){A=m&255;if((A|0)!=0){b[n>>1]=c[(c[2440394]|0)+(A<<2)>>2]&65535}t=m>>8;u=n+2|0;o=16469}if((o|0)==16469){o=t&255;if((o|0)!=0){b[u>>1]=c[(c[2440394]|0)+(o<<2)>>2]&65535}k=t>>8;l=u+2|0}u=k&255;if((u|0)==0){B=d+8|0;c[2385346]=B;return}b[l>>1]=c[(c[2440394]|0)+(u<<2)>>2]&65535;B=d+8|0;c[2385346]=B;return}else{if((f|0)>=384){B=d+8|0;c[2385346]=B;return}u=e&255;if((u|0)!=0){b[a>>1]=c[(c[2440394]|0)+(u<<2)>>2]&65535}if((f|0)>=383){B=d+8|0;c[2385346]=B;return}u=e>>>8&255;if((u|0)!=0){b[a+2>>1]=c[(c[2440394]|0)+(u<<2)>>2]&65535}if((f|0)>=382){B=d+8|0;c[2385346]=B;return}u=e>>>16&255;if((u|0)!=0){b[a+4>>1]=c[(c[2440394]|0)+(u<<2)>>2]&65535}if((f|0)>=381){B=d+8|0;c[2385346]=B;return}u=e>>>24;if((u|0)!=0){b[a+6>>1]=c[(c[2440394]|0)+(u<<2)>>2]&65535}u=c[d+4>>2]|0;if((f|0)>=380){B=d+8|0;c[2385346]=B;return}e=u&255;if((e|0)!=0){b[a+8>>1]=c[(c[2440394]|0)+(e<<2)>>2]&65535}if((f|0)>=379){B=d+8|0;c[2385346]=B;return}e=u>>>8&255;if((e|0)!=0){b[a+10>>1]=c[(c[2440394]|0)+(e<<2)>>2]&65535}if((f|0)>=378){B=d+8|0;c[2385346]=B;return}f=u>>>16&255;if((f|0)==0){B=d+8|0;c[2385346]=B;return}b[a+12>>1]=c[(c[2440394]|0)+(f<<2)>>2]&65535;B=d+8|0;c[2385346]=B;return}}function axV(a){a=a|0;var b=0,d=0,f=0;if((a|0)!=13107202){b=0;return b|0}a=(e[4812781]|0)>>>8;do{if((c[2406632]|0)==0){d=c[2443744]|0;if((d|0)<=0){f=8;break}c[2443744]=d-1;f=0}else{f=(c[2432962]|0)>>>((c[(c[2420380]|0)+4>>2]|0)>>>0)<<3&8}}while(0);b=((f|a)^247)&255;return b|0}function axW(a,b){a=a|0;b=b|0;if((a|0)!=13631488){return}a=b&255;c[2415256]=a&8;b=a>>>1&1;c[3528406]=b^1;if((b|0)==0){c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2]}Tr(a>>>2&1);return}function axX(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;if((d|0)==11010048|(d|0)==11010050){f=(a[9775152]<<1|a[9541696])&255;return f|0}else if((d|0)==11010054){g=a[9541696]|0;h=a[9775152]<<1|g;a[9775152]=1;i=8452200+(c[2394]<<2)|0;do{if(g<<24>>24==0|(a[9541928]|0)==0){c[i>>2]=4097;c[2276080]=256;if((c[2276079]|0)>>>0>=256){break}RH(1)}else{c[i>>2]=0;c[2276080]=0}}while(0);f=h&255;return f|0}else if((d|0)==13107202){h=e[4812781]|0;do{if((c[2406632]|0)==0){i=c[2443744]|0;if((i|0)<=0){j=2048;break}c[2443744]=i-1;j=0}else{j=(c[2432962]|0)>>>((c[(c[2420380]|0)+4>>2]|0)>>>0)<<11&2048}}while(0);f=((j|h)^63487)&65535;return f|0}else if((d|0)==11010052){h=a[9775152]|0;j=h<<1|a[9541696];a[9541696]=1;do{if((a[9541928]|0)==0){k=4096;l=16528}else{i=h<<24>>24==0;if(i){k=i?4096:0;l=16528;break}c[8452200+(c[2394]<<2)>>2]=0;c[2276080]=0}}while(0);do{if((l|0)==16528){c[8452200+(c[2394]<<2)>>2]=k|1;c[2276080]=256;if((c[2276079]|0)>>>0>=256){break}RH(1)}}while(0);f=j&255;return f|0}else if((d|0)==13107200){f=~b[4812780];return f|0}else{f=0;return f|0}return 0}function axY(d,e){d=d|0;e=e|0;var f=0,g=0;if((d|0)==11010056){f=c[3542102]|0;gD[f&8191]()|0;c[2113288]=e&65535;return}else if((d|0)==11534336){c[3542078]=e&65535;return}else if((d|0)==11010158){b[4879136]=e;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12;return}else if((d|0)==11534340){c[3542080]=e&65535;return}else if((d|0)==13631488){if((e&256)!=0){return}f=(e&65535)>>>8&65535;c[2415256]=f&8;g=f>>>1&1;c[3528406]=g^1;if((g|0)==0){c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2]}Tr(f>>>2&1);return}else if((d|0)==12582914){c[3542085]=e&65535;return}else if((d|0)==11534338){c[3542079]=e&65535;return}else if((d|0)==11010050){c[2113278]=e&65535;return}else if((d|0)==12058628){c[3542083]=e&65535;return}else if((d|0)==12058626){c[3542082]=e&65535;return}else if((d|0)==11010048){c[2113282]=e&65535;return}else if((d|0)==12058624){c[3542081]=e&65535;return}else if((d|0)==12582912){c[3542084]=e&65535;return}else if((d|0)==12582916){c[3542086]=e&65535;return}else{return}}function axZ(d){d=d|0;var f=0,g=0,i=0,j=0.0,k=0.0;f=d&255;if((f|0)==96){g=c[2113156]&255;return g|0}else if((f|0)==80){d=c[3541518]|0;i=d+296|0;j=+h[i>>3];do{if(j!=0.0){k=+h[6675];if(j-(k+ +gC[c[2429842]&255]())<=0.0){h[i>>3]=0.0;break}g=a[d+307|0]|-128;return g|0}}while(0);g=a[d+307|0]|0;return g|0}else if((f|0)==48){g=b[4879136]&255;return g|0}else if((f|0)==64){g=(e[4879136]|0)>>>8&255;return g|0}else{g=0;return g|0}return 0}function ax_(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;switch(b&255|0){case 80:{b=c[3541518]|0;e=b+256|0;a[b+304|0]=d;f=d&255;if((d&255)<16){c[14168912+((c[2383582]|0)*252|0)>>2]=f&15}if((d-45&255)>=3){return}if((f|0)==45){g=b+312|0;h=a[g]|2;a[g]=h;i=h}else if((f|0)==47){a[b+312|0]=0;i=0}else if((f|0)==0){a[b+312|0]=2;i=2}else if((f|0)==46){f=b+312|0;h=a[f]|1;a[f]=h;i=h}else{i=a[b+312|0]|0}b=i&3;i=c[7461744+(b<<2)>>2]|0;lI(e,i,i,c[7461728+(b<<2)>>2]|0);return};case 96:{Uv(0,d);return};case 81:{lS(0,1,d);return};case 0:{b=d&15;a[14117440]=b;i=c[2411296]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;h=((b&255)<<14)-16384|0;b=64;f=64;while(1){c[e+76+(f<<2)>>2]=i+(h+(f<<8));g=b+1&65535;if((g&65535)>127){j=64;k=64;break}else{b=g;f=g&65535}}while(1){f=i+(h+(k<<8))|0;c[e+76+(k+512<<2)>>2]=f;c[e+76+(k+768<<2)>>2]=f;f=j+1&65535;if((f&65535)>127){break}else{j=f;k=f&65535}}return};case 112:{k=d&3;a[14109424]=k;j=(d&255)>>>4&3;a[14109400]=j;d=c[3541206]|0;e=c[2439442]|0;h=e+((k&255)<<17)|0;gGC(d|0,h|0,131072)|0;h=d+131072|0;d=e+((j&255)<<17)|0;gGC(h|0,d|0,131072)|0;return};default:{return}}}function ax$(a){a=a|0;return 0}function ax0(a,b){a=a|0;b=b|0;return}function ax1(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2763156+(b*112|0)>>2];c[a+104>>2]=c[2763160+(b*112|0)>>2];c[a+108>>2]=c[2763164+(b*112|0)>>2];d=0;return d|0}function ax2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=2763056+(b*112|0);e=0;return e|0}function ax3(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1096248+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function ax4(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;e=i;i=i+960|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;c[2424]=5755;c[2426678]=0;c[2418136]=0;c[2411296]=1048576;c[3542098]=1310720;c[3542090]=9699328;c[3542091]=10747904;c[3542092]=11796480;c[3541206]=12845056;c[2439442]=13107200;c[2439992]=13631488;c[2405614]=13631616;c[2418250]=13631616;c[2411338]=13697152;c[3542094]=13705344;c[3542095]=13738112;c[3542096]=13770880;c[3542100]=13803648;c[3542108]=13869184;c[2411550]=13873280;x=0;while(1){if((x|0)>=1024){break}y=9638528+(x<<2)|0;if((c[y>>2]|0)==0){z=16652;break}else{x=x+1|0}}do{if((z|0)==16652){x=gGq(13873280)|0;c[y>>2]=x;if((x|0)==0){break}c[2426678]=x;gGz(x|0,0,13873280);c[2418136]=x;c[2411296]=x+1048576;c[3542098]=x+1310720;c[3542090]=x+9699328;c[3542091]=x+10747904;c[3542092]=x+11796480;c[3541206]=x+12845056;c[2439442]=x+13107200;c[2439992]=x+13631488;A=x+13631616|0;c[2405614]=A;c[2418250]=A;c[2411338]=x+13697152;c[3542094]=x+13705344;c[3542095]=x+13738112;c[3542096]=x+13770880;c[3542100]=x+13803648;c[3542108]=x+13869184;A=x+13873280|0;c[2411550]=A;c[2414088]=A;A=x+1|0;R6(A,0,2)|0;A=c[2418136]|0;R6(A,1,2)|0;A=c[2411296]|0;do{if((c[3542200]|0)!=0){x=v+108|0;c[x>>2]=0;B=v+100|0;c[B>>2]=0;C=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[C&16383](v,2)|0;if((c[x>>2]|0)==0){break}x=c[B>>2]|0;c[w>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](w,2,0)|0;if((x|0)<1){break}gzL(A,0,2)|0}}while(0);A=c[3542098]|0;do{if((c[3542200]|0)!=0){x=t+108|0;c[x>>2]=0;B=t+100|0;c[B>>2]=0;C=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[C&16383](t,3)|0;if((c[x>>2]|0)==0){break}x=c[B>>2]|0;c[u>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](u,3,0)|0;if((x|0)<1){break}gzL(A,0,3)|0}}while(0);A=(c[3542098]|0)+2097152|0;do{if((c[3542200]|0)!=0){x=r+108|0;c[x>>2]=0;B=r+100|0;c[B>>2]=0;C=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[C&16383](r,4)|0;if((c[x>>2]|0)==0){break}x=c[B>>2]|0;c[s>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](s,4,0)|0;if((x|0)<1){break}gzL(A,0,4)|0}}while(0);A=c[3542098]|0;x=A+4194303|0;B=A+8388606|0;A=0;while(1){a[B]=a[x]&15;a[B+1|0]=(d[x]|0)>>>4;C=A+1|0;if((C|0)<4194304){x=x-1|0;B=B-2|0;A=C}else{break}}A=c[3542090]|0;do{if((c[3542200]|0)!=0){B=p+108|0;c[B>>2]=0;x=p+100|0;c[x>>2]=0;C=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[C&16383](p,5)|0;if((c[B>>2]|0)==0){break}B=c[x>>2]|0;c[q>>2]=9534384;x=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[x&16383](q,5,0)|0;if((B|0)<1){break}gzL(A,0,5)|0}}while(0);A=c[3542090]|0;B=A+524287|0;x=A+1048574|0;A=0;while(1){a[x+1|0]=a[B]&15;a[x]=(d[B]|0)>>>4;C=A+1|0;if((C|0)<524288){B=B-1|0;x=x-2|0;A=C}else{break}}A=c[3542091]|0;do{if((c[3542200]|0)!=0){x=n+108|0;c[x>>2]=0;B=n+100|0;c[B>>2]=0;C=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[C&16383](n,6)|0;if((c[x>>2]|0)==0){break}x=c[B>>2]|0;c[o>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](o,6,0)|0;if((x|0)<1){break}gzL(A,0,6)|0}}while(0);A=c[3542091]|0;x=A+524287|0;B=A+1048574|0;A=0;while(1){a[B+1|0]=a[x]&15;a[B]=(d[x]|0)>>>4;C=A+1|0;if((C|0)<524288){x=x-1|0;B=B-2|0;A=C}else{break}}A=c[3542092]|0;do{if((c[3542200]|0)!=0){B=l+108|0;c[B>>2]=0;x=l+100|0;c[x>>2]=0;C=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[C&16383](l,7)|0;if((c[B>>2]|0)==0){break}B=c[x>>2]|0;c[m>>2]=9534384;x=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[x&16383](m,7,0)|0;if((B|0)<1){break}gzL(A,0,7)|0}}while(0);A=c[3542092]|0;B=A+524287|0;x=A+1048574|0;A=0;while(1){a[x+1|0]=a[B]&15;a[x]=(d[B]|0)>>>4;C=A+1|0;if((C|0)<524288){B=B-1|0;x=x-2|0;A=C}else{break}}A=c[2439442]|0;do{if((c[3542200]|0)!=0){x=j+108|0;c[x>>2]=0;B=j+100|0;c[B>>2]=0;C=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[C&16383](j,8)|0;if((c[x>>2]|0)==0){break}x=c[B>>2]|0;c[k>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](k,8,0)|0;if((x|0)<1){break}gzL(A,0,8)|0}}while(0);A=c[2439992]|0;do{if((c[3542200]|0)!=0){x=f+108|0;c[x>>2]=0;B=f+100|0;c[B>>2]=0;C=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[C&16383](f,9)|0;if((c[x>>2]|0)==0){break}x=c[B>>2]|0;c[g>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](g,9,0)|0;if((x|0)<1){break}gzL(A,0,9)|0}}while(0);Tq(689656);if(!(a[1040128]|0)){A=c[2439992]|0;gGC(14100392,A|0,128)|0}fxU(0,425984);if((c[2394]|0)==0){D=c[2112932]|0}else{c[2394]=0;A=c[3532596]|0;c[2112932]=A;x=c[3532592]|0;if((x|0)!=0){gGC(9104152,x|0,280)|0}c[2113054]=c[2113060];D=A}A=c[2418136]|0;x=D|0;B=0;while(1){C=A+B|0;c[x>>2]=C;c[x+131072>>2]=C;C=B+1024|0;if(C>>>0>1048575){break}else{x=x+4|0;B=C}}B=c[2418250]|0;x=D+12288|0;A=3145728;while(1){C=B+(A-3145728)|0;c[x>>2]=C;c[x+65536>>2]=C;c[x+131072>>2]=C;C=A+1024|0;if(C>>>0>3211263){break}else{x=x+4|0;A=C}}A=c[3542108]|0;c[D+16512>>2]=A;c[D+82048>>2]=A;c[D+147584>>2]=A;x=A+1024|0;c[D+16516>>2]=x;c[D+82052>>2]=x;c[D+147588>>2]=x;x=A+2048|0;c[D+16520>>2]=x;c[D+82056>>2]=x;c[D+147592>>2]=x;x=A+3072|0;c[D+16524>>2]=x;c[D+82060>>2]=x;c[D+147596>>2]=x;x=c[3542094]|0;A=D+34816|0;B=8912896;while(1){C=x+(B-8912896)|0;c[A>>2]=C;c[A+65536>>2]=C;c[A+131072>>2]=C;C=B+1024|0;if(C>>>0>8945663){break}else{A=A+4|0;B=C}}B=c[3542095]|0;A=D+36864|0;x=9437184;while(1){C=B+(x-9437184)|0;c[A>>2]=C;c[A+65536>>2]=C;c[A+131072>>2]=C;C=x+1024|0;if(C>>>0>9469951){break}else{A=A+4|0;x=C}}x=c[3542096]|0;A=D+38912|0;B=9961472;while(1){C=x+(B-9961472)|0;c[A>>2]=C;c[A+65536>>2]=C;c[A+131072>>2]=C;C=B+1024|0;if(C>>>0>9994239){break}else{A=A+4|0;B=C}}B=c[3542100]|0;A=D+61440|0;x=15728640;while(1){C=B+(x-15728640)|0;c[A>>2]=C;c[A+65536>>2]=C;c[A+131072>>2]=C;C=x+1024|0;if(C>>>0>15794175){break}else{A=A+4|0;x=C}}c[D+196608>>2]=3226;c[D+196648>>2]=622;c[D+196688>>2]=2228;c[D+196728>>2]=1934;x=c[3532592]|0;if((x|0)!=0){gGC(x|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);x=c[2439330]|0;A=(x|0)==0;if(!A){B=x;gGC(9706056,B|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];B=c[3528484]|0;c[2076596]=B;C=c[2417276]|0;c[3541536]=C;c[1836236]=0;c[x+4172>>2]=2470;c[x+4176>>2]=2092;c[x+4180>>2]=322;c[x+4184>>2]=894;E=c[2411296]|0;F=0;G=0;while(1){c[x+76+(G<<2)>>2]=E+(G<<8);H=F+1&65535;if((H&65535)>63){I=0;J=0;break}else{F=H;G=H&65535}}while(1){G=E+(J<<8)|0;c[x+76+(J+512<<2)>>2]=G;c[x+76+(J+768<<2)>>2]=G;G=I+1&65535;if((G&65535)>63){K=64;L=64;break}else{I=G;J=G&65535}}while(1){c[x+76+(L<<2)>>2]=E+(L<<8);G=K+1&65535;if((G&65535)>127){M=64;N=64;break}else{K=G;L=G&65535}}while(1){G=E+(N<<8)|0;c[x+76+(N+512<<2)>>2]=G;c[x+76+(N+768<<2)>>2]=G;G=M+1&65535;if((G&65535)>127){break}else{M=G;N=G&65535}}E=c[2411338]|0;G=224;F=224;while(1){c[x+76+(F<<2)>>2]=E+((F<<8)-57344);H=G+1&65535;if((H&65535)>255){O=224;P=224;break}else{G=H;F=H&65535}}while(1){c[x+76+(P+256<<2)>>2]=E+((P<<8)-57344);F=O+1&65535;if((F&65535)>255){Q=224;R=224;break}else{O=F;P=F&65535}}while(1){F=E+((R<<8)-57344)|0;c[x+76+(R+512<<2)>>2]=F;c[x+76+(R+768<<2)>>2]=F;F=Q+1&65535;if((F&65535)>255){break}else{Q=F;R=F&65535}}if(!A){E=x;gGC(E|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=B;c[2417276]=C;c[1836236]=-1;E=0;while(1){if((E|0)>=1024){S=0;break}T=9638528+(E<<2)|0;if((c[T>>2]|0)==0){z=16731;break}else{E=E+1|0}}do{if((z|0)==16731){E=gGq(131072)|0;c[T>>2]=E;if((E|0)==0){S=0;break}gGz(E|0,0,131072);S=E}}while(0);c[3542106]=S;gGz(S|0,0,131072);E=0;while(1){if((E|0)>=1024){U=0;break}V=9638528+(E<<2)|0;if((c[V>>2]|0)==0){z=16736;break}else{E=E+1|0}}do{if((z|0)==16736){E=gGq(65536)|0;c[V>>2]=E;if((E|0)==0){U=0;break}gGz(E|0,0,65536);U=E}}while(0);c[3527514]=U;gGz(U|0,0,65536);c[2112966]=c[3542106];c[3542078]=0;c[3542079]=0;c[3542080]=16;c[3542081]=0;c[3542082]=0;c[3542083]=16;c[3542084]=0;c[3542085]=0;c[3542086]=16;c[3542087]=0;c[3542088]=0;c[3542089]=16;c[2113284]=0;E=c[642608+(c[2436]<<2)>>2]|0;if((c[E+52>>2]&4|0)==0){C=c[E+128>>2]|0;c[2113280]=C;W=E+132|0;X=C}else{C=c[E+132>>2]|0;c[2113280]=C;W=E+128|0;X=C}C=c[W>>2]|0;c[2113276]=C;c[2406716]=X-8;c[2394778]=X-16;c[2406714]=C-8;c[2394776]=C-16;c[3528974]=c[3564288+(((X|0)!=320)<<2)>>2];auH(2,8388608);axI(0,1048576,8,0);axI(1,1048576,8,0);axI(2,1048576,8,0);c[2113294]=-32;c[2113292]=32;Vr(1,4e6,2630,940,32,0);c[2438228]=4e6;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=511;h[745419]=.8;a[3203368]=1;h[745418]=.2;a[3203360]=1;h[745417]=.2;a[3203352]=1;h[745416]=.2;a[3203344]=1;C=c[3541206]|0;E=c[2439442]|0;gGC(C|0,E|0,262144)|0;Ux(0,8e3,1);c[2407030]=256;c[2407068]=3;a[7072720]=1;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];E=c[3532592]|0;if((E|0)!=0){gGC(9104152,E|0,280)|0}c[2113054]=c[2113060]}RI();E=c[2394]|0;C=c[14130368+(E<<2)>>2]|0;if((C|0)!=0){gGC(C|0,9104152,280)|0}c[8452240+(E<<2)>>2]=c[2113054];c[2394]=-1;E=c[2439330]|0;C=(E|0)==0;if(!C){B=E;gGC(9706056,B|0,76)|0}B=c[2438118]|0;c[2433530]=B;x=c[3528484]|0;c[2076596]=x;A=c[2417276]|0;c[3541536]=A;c[1836236]=0;gGz(9706056,0,76);if(!C){C=E;gGC(C|0,9706056,76)|0}c[2438118]=B;c[3528484]=x;c[2417276]=A;c[1836236]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){A=0;do{lN(A);mB(A);A=A+1|0;}while((A|0)<(c[2385508]|0))}c[2113156]=0;a[9628264]=0;c[2407033]=0;A=c[3541206]|0;c[3541190]=A;c[3541198]=A;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=A+256;c[3541199]=A+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=A+512;c[3541200]=A+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=A+768;c[3541201]=A+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];a[9541696]=1;a[9541928]=1;a[9775152]=1;b[4879136]=0;a[14117440]=0;a[14109424]=0;a[14109400]=0;Y=0;i=e;return Y|0}}while(0);c[2426678]=0;Y=1;i=e;return Y|0}function ax5(){var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;d=i;i=i+128|0;e=d|0;f=c[c[642608+(c[2436]<<2)>>2]>>2]|0;be(e|0,128,179600,(g=i,i=i+24|0,c[g>>2]=9374064,c[g+8>>2]=47,c[g+16>>2]=f,g)|0)|0;i=g;a[1040128]=0;g=c[2420380]|0;f=c[g>>2]|0;h=c[g+4>>2]|0;g=fw(e|0,389440)|0;if((g|0)!=0){e=h>>3<<f&1023;cj(14100392,e|0,1,g|0)|0;aY(g|0)|0}Uw(0);axH();g=c[2443764]|0;e=0;while(1){if((e|0)>=1024){break}j=9638528+(e<<2)|0;if((c[j>>2]|0)==(g|0)){k=16762;break}else{e=e+1|0}}if((k|0)==16762){gGr(g);c[j>>2]=0}c[2443764]=0;j=c[2394718]|0;g=0;while(1){if((g|0)>=1024){break}l=9638528+(g<<2)|0;if((c[l>>2]|0)==(j|0)){k=16766;break}else{g=g+1|0}}if((k|0)==16766){gGr(j);c[l>>2]=0}c[2394718]=0;a[7462192]=0;l=c[3542106]|0;j=0;while(1){if((j|0)>=1024){break}m=9638528+(j<<2)|0;if((c[m>>2]|0)==(l|0)){k=16770;break}else{j=j+1|0}}if((k|0)==16770){gGr(l);c[m>>2]=0}c[3542106]=0;m=c[3527514]|0;l=0;while(1){if((l|0)>=1024){break}n=9638528+(l<<2)|0;if((c[n>>2]|0)==(m|0)){k=16774;break}else{l=l+1|0}}if((k|0)==16774){gGr(m);c[n>>2]=0}c[3527514]=0;if((c[2392]|0)>=0){n=0;do{m=14130368+(n<<2)|0;l=c[m>>2]|0;if((l|0)!=0){gGr(l);c[m>>2]=0}m=14130384+(n<<2)|0;l=c[m>>2]|0;if((l|0)!=0){gGr(l);c[m>>2]=0}n=n+1|0;}while((n|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;fwZ();n=c[3541518]|0;if((n|0)!=0){gGr(n|0);c[3541518]=0}if((c[2385508]|0)>0){c[2113008]=0;c[2076598]=0;c[2383582]=0}c[2438228]=0;c[2433526]=0;c[2406676]=0;c[3528472]=0;n=c[2406680]|0;if((n|0)!=0){gGr(n);c[2406680]=0}c[2385508]=0;c[2432978]=0;a[64240]=0;b[4879136]=0;a[14117440]=0;a[14109424]=0;a[14109400]=0;n=c[2426678]|0;m=0;while(1){if((m|0)>=1024){k=16792;break}o=9638528+(m<<2)|0;if((c[o>>2]|0)==(n|0)){break}else{m=m+1|0}}if((k|0)==16792){c[2426678]=0;i=d;return 0}gGr(n);c[o>>2]=0;c[2426678]=0;i=d;return 0}function ax6(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;if((a[9623752]|0)!=0){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=i;c[1836236]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){i=0;do{lN(i);mB(i);i=i+1|0;}while((i|0)<(c[2385508]|0))}c[2113156]=0;a[9628264]=0;c[2407033]=0;i=c[3541206]|0;c[3541190]=i;c[3541198]=i;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=i+256;c[3541199]=i+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=i+512;c[3541200]=i+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=i+768;c[3541201]=i+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];a[9541696]=1;a[9541928]=1;a[9775152]=1;b[4879136]=0;a[14117440]=0;a[14109424]=0;a[14109400]=0}b[4812780]=0;b[4812781]=0;i=0;g=0;f=0;do{g=((a[9632792+i|0]&1)<<i|g&65535)&65535;f=((a[9630688+i|0]&1)<<i|f&65535)&65535;i=i+1|0;}while((i|0)<10);b[4812780]=g;b[4812781]=f;if((g&3)==3){i=g&-4;b[4812780]=i;j=i}else{j=g}if((j&12)==12){b[4812780]=j&-13}if((f&3)==3){j=f&-4;b[4812781]=j;k=j}else{k=f}if((k&12)==12){b[4812781]=k&-13}k=c[2392]|0;if((k|0)>=0){gGz(8452240,0,((k|0)>0?(k<<2)+4|0:4)|0)}c[2113054]=0;k=c[2385548]|0;if((k|0)>0){gGz(9752472,0,((k|0)>1?k<<2:4)|0)}c[2433530]=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];k=c[3532592]|0;if((k|0)!=0){gGC(9104152,k|0,280)|0}c[2113054]=c[2113060]}k=c[2439330]|0;if((k|0)!=0){f=k;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;f=c[2438]|0;k=gGU(f,(f|0)<0|0?-1:0,16e6,0)|0;f=~~((+(k>>>0)+ +(K|0)*4294967296.0)/14732.965009208103);c[2440510]=f;a[6517944]=1;c[2444010]=0;k=f-~~(+(f*12|0|0)/271.5)|0;a[9627096]=0;j=1;g=f;f=1;while(1){i=(ag(j,g)|0)/80|0;do{if(f&(i|0)>(k|0)){e=c[2444010]|0;if((e|0)<(k|0)){d=k-e|0;c[2113056]=d;e=RG(d)|0;c[2113054]=(c[2113054]|0)+e;c[2276108]=-1;c[2113056]=-1;c[2444010]=(c[2444010]|0)+e}e=c[2112968]|0;do{if((e|0)!=0){avg(128);d=c[(c[3542106]|0)+64512>>2]|0;do{if((d|0)==0){gGz(e|0,0,ag(c[2113280]<<1,c[2113276]|0)|0)}else{l=d<<16|d;m=ag(c[2113276]|0,c[2113280]|0)|0;if((m|0)<=15){break}n=e;o=(m|0)/16|0;while(1){c[n>>2]=l;c[n+4>>2]=l;c[n+8>>2]=l;c[n+12>>2]=l;c[n+16>>2]=l;c[n+20>>2]=l;c[n+24>>2]=l;c[n+28>>2]=l;m=o-1|0;if((m|0)>0){n=n+32|0;o=m}else{break}}}}while(0);if(!(a[7072720]|0)){break}axE(1)}}while(0);e=c[3542102]|0;gD[e&8191]()|0;a[9627096]=1;a[9541696]=0;c[8452200+(c[2394]<<2)>>2]=4097;c[2276080]=256;if((c[2276079]|0)>>>0>=256){break}RH(1)}}while(0);e=i-(c[2444010]|0)|0;c[2113056]=e;d=RG(e)|0;c[2113054]=(c[2113054]|0)+d;c[2276108]=-1;c[2113056]=-1;c[2444010]=(c[2444010]|0)+d;Sb(ag(a[6517944]|0?868:0,j)|0);d=j+1|0;if((d|0)>=81){break}j=d;g=c[2440510]|0;f=(a[9627096]&1)==0}f=c[2394]|0;g=c[14130368+(f<<2)>>2]|0;if((g|0)!=0){gGC(g|0,9104152,280)|0}c[8452240+(f<<2)>>2]=c[2113054];c[2394]=-1;f=a[6517944]|0?69504:0;g=gGU(f,0,2048e6,0)|0;j=c[2438228]|0;k=gGS(g,K,j,(j|0)<0|0?-1:0)|0;j=k;Sb(f);f=c[2443830]|0;if((f|0)<1073676288){c[2443830]=f-j}f=c[2443831]|0;if((f|0)<1073676288){c[2443831]=f-j}f=(c[3528512]|0)-j|0;c[3528512]=(f|0)<0?0:f;f=c[2112964]|0;if((f|0)!=0){gg[c[3542122]&4095](f,a[9688]|0?534:0);Uu(0,c[2112964]|0,a[9688]|0?534:0)}f=c[1836236]|0;j=c[9757320+(f<<2)>>2]|0;if((j|0)==0){p=c[2433530]|0;q=9752472+(f<<2)|0;c[q>>2]=p;r=c[2076596]|0;s=14113936+(f<<2)|0;c[s>>2]=r;t=c[3541536]|0;u=9669104+(f<<2)|0;c[u>>2]=t;c[1836236]=-1;return 0}k=j;gGC(k|0,9706056,76)|0;p=c[2433530]|0;q=9752472+(f<<2)|0;c[q>>2]=p;r=c[2076596]|0;s=14113936+(f<<2)|0;c[s>>2]=r;t=c[3541536]|0;u=9669104+(f<<2)|0;c[u>>2]=t;c[1836236]=-1;return 0}function ax7(){var b=0,d=0,e=0,f=0,g=0,h=0;avg(128);b=c[(c[3542106]|0)+64512>>2]|0;d=c[2112968]|0;do{if((b|0)==0){gGz(d|0,0,ag(c[2113280]<<1,c[2113276]|0)|0)}else{e=b<<16|b;f=ag(c[2113276]|0,c[2113280]|0)|0;if((f|0)<=15){break}g=d;h=(f|0)/16|0;while(1){c[g>>2]=e;c[g+4>>2]=e;c[g+8>>2]=e;c[g+12>>2]=e;c[g+16>>2]=e;c[g+20>>2]=e;c[g+24>>2]=e;c[g+28>>2]=e;f=h-1|0;if((f|0)>0){g=g+32|0;h=f}else{break}}}}while(0);if(!(a[7072720]|0)){return 0}axE(1);return 0}function ax8(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;g=i;i=i+208|0;h=g|0;j=g+16|0;k=g+32|0;l=g+48|0;m=g+64|0;n=g+80|0;o=g+96|0;p=g+112|0;q=g+128|0;r=g+144|0;s=g+160|0;t=g+176|0;u=g+192|0;if((f|0)!=0){c[f>>2]=169753}Ts(e,f);if((e&96|0)==0){i=g;return 0}gGz(u|0,0,12);v=c[2405614]|0;c[u>>2]=v;c[u+4>>2]=(c[2411550]|0)-v;c[u+12>>2]=219592;gj[c[2076592]&4095](u)|0;u=k|0;do{if((e&64|0)!=0){gGz(j|0,0,16);c[2394]=-1;if((c[2392]|0)<0){break}v=k+9|0;w=h;x=h|0;y=h+4|0;z=h+12|0;A=j|0;B=j+4|0;C=j+12|0;D=0;do{gGC(u|0,614896,11)|0;a[v]=D+48&255;E=8452256+(D<<2)|0;gGz(w|0,0,12);c[x>>2]=E;c[y>>2]=4;c[z>>2]=164976;gj[c[2076592]&4095](h)|0;if((c[E>>2]|0)!=0){c[A>>2]=c[14130368+(D<<2)>>2];c[B>>2]=c[8452184+(D<<2)>>2];c[C>>2]=u;E=c[2076592]|0;gj[E&4095](j)|0}D=D+1|0;}while((D|0)<=(c[2392]|0))}}while(0);fw$(e);Vx(e,f);Ut(0);gGz(t|0,0,12);c[t>>2]=9541696;c[t+4>>2]=1;c[t+12>>2]=148144;gj[c[2076592]&4095](t)|0;gGz(s|0,0,12);c[s>>2]=9541928;c[s+4>>2]=1;c[s+12>>2]=118544;gj[c[2076592]&4095](s)|0;gGz(r|0,0,12);c[r>>2]=9775152;c[r+4>>2]=1;c[r+12>>2]=93520;gj[c[2076592]&4095](r)|0;gGz(q|0,0,12);c[q>>2]=9627096;c[q+4>>2]=1;c[q+12>>2]=490464;gj[c[2076592]&4095](q)|0;ayc();gGz(p|0,0,12);c[p>>2]=9625560;c[p+4>>2]=4;c[p+12>>2]=215728;gj[c[2076592]&4095](p)|0;gGz(o|0,0,12);c[o>>2]=9758272;c[o+4>>2]=2;c[o+12>>2]=497064;gj[c[2076592]&4095](o)|0;gGz(n|0,0,12);c[n>>2]=14117440;c[n+4>>2]=1;c[n+12>>2]=435944;gj[c[2076592]&4095](n)|0;gGz(m|0,0,12);c[m>>2]=14109424;c[m+4>>2]=1;c[m+12>>2]=533728;gj[c[2076592]&4095](m)|0;gGz(l|0,0,12);c[l>>2]=14109400;c[l+4>>2]=1;c[l+12>>2]=520224;gj[c[2076592]&4095](l)|0;if((e&2|0)==0){i=g;return 0}e=c[2439330]|0;l=(e|0)==0;if(!l){m=e;gGC(9706056,m|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];m=c[3528484]|0;c[2076596]=m;n=c[2417276]|0;c[3541536]=n;c[1836236]=0;o=c[2411296]|0;p=((d[14117440]|0)<<14)-16384|0;q=64;r=64;while(1){c[e+76+(r<<2)>>2]=o+(p+(r<<8));s=q+1&65535;if((s&65535)>127){F=64;G=64;break}else{q=s;r=s&65535}}while(1){r=o+(p+(G<<8))|0;c[e+76+(G+512<<2)>>2]=r;c[e+76+(G+768<<2)>>2]=r;r=F+1&65535;if((r&65535)>127){break}else{F=r;G=r&65535}}if(!l){l=e;gGC(l|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=m;c[2417276]=n;c[1836236]=-1;n=c[3541206]|0;m=c[2439442]|0;l=m+((d[14109424]|0)<<17)|0;gGC(n|0,l|0,131072)|0;l=n+131072|0;n=m+((d[14109400]|0)<<17)|0;gGC(l|0,n|0,131072)|0;a[14168416]=1;i=g;return 0}function ax9(b,c){b=b|0;c=c|0;a[9706117]=c&1;return}function aya(a){a=a|0;var b=0,d=0;b=(c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,4e6,0)|0;return a|0}function ayb(){return+(+((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)/4.0e6)}function ayc(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;a=i;i=i+128|0;b=a|0;d=a+16|0;e=a+32|0;f=a+48|0;g=a+64|0;h=a+80|0;j=a+96|0;k=a+112|0;gGz(k|0,0,12);c[k>>2]=8453128;c[k+4>>2]=4;c[k+12>>2]=211192;gj[c[2076592]&4095](k)|0;gGz(j|0,0,12);c[j>>2]=8453112;c[j+4>>2]=4;c[j+12>>2]=514456;gj[c[2076592]&4095](j)|0;gGz(h|0,0,12);c[h>>2]=8453136;c[h+4>>2]=4;c[h+12>>2]=397976;gj[c[2076592]&4095](h)|0;gGz(g|0,0,12);c[g>>2]=8453152;c[g+4>>2]=4;c[g+12>>2]=308464;gj[c[2076592]&4095](g)|0;gGz(f|0,0,12);c[f>>2]=8453144;c[f+4>>2]=4;c[f+12>>2]=235424;gj[c[2076592]&4095](f)|0;f=e;g=e|0;h=e+4|0;j=e+12|0;k=d;l=d|0;m=d+4|0;n=d+12|0;o=b;p=b|0;q=b+4|0;r=b+12|0;gGz(f|0,0,12);c[g>>2]=14168312;c[h>>2]=4;c[j>>2]=183424;gj[c[2076592]&4095](e)|0;gGz(k|0,0,12);c[l>>2]=14168316;c[m>>2]=4;c[n>>2]=147952;gj[c[2076592]&4095](d)|0;gGz(o|0,0,12);c[p>>2]=14168320;c[q>>2]=4;c[r>>2]=118352;gj[c[2076592]&4095](b)|0;gGz(f|0,0,12);c[g>>2]=14168324;c[h>>2]=4;c[j>>2]=183424;gj[c[2076592]&4095](e)|0;gGz(k|0,0,12);c[l>>2]=14168328;c[m>>2]=4;c[n>>2]=147952;gj[c[2076592]&4095](d)|0;gGz(o|0,0,12);c[p>>2]=14168332;c[q>>2]=4;c[r>>2]=118352;gj[c[2076592]&4095](b)|0;gGz(f|0,0,12);c[g>>2]=14168336;c[h>>2]=4;c[j>>2]=183424;gj[c[2076592]&4095](e)|0;gGz(k|0,0,12);c[l>>2]=14168340;c[m>>2]=4;c[n>>2]=147952;gj[c[2076592]&4095](d)|0;gGz(o|0,0,12);c[p>>2]=14168344;c[q>>2]=4;c[r>>2]=118352;gj[c[2076592]&4095](b)|0;gGz(f|0,0,12);c[g>>2]=14168348;c[h>>2]=4;c[j>>2]=183424;gj[c[2076592]&4095](e)|0;gGz(k|0,0,12);c[l>>2]=14168352;c[m>>2]=4;c[n>>2]=147952;gj[c[2076592]&4095](d)|0;gGz(o|0,0,12);c[p>>2]=14168356;c[q>>2]=4;c[r>>2]=118352;gj[c[2076592]&4095](b)|0;i=a;return}function ayd(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6483012+(b*112|0)>>2];c[a+104>>2]=c[6483016+(b*112|0)>>2];c[a+108>>2]=c[6483020+(b*112|0)>>2];d=0;return d|0}function aye(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=6482912+(b*112|0);e=0;return e|0}function ayf(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>27){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5932032+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function ayg(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=12){if((a|0)==0){d=0;return d|0}e=a;f=6485488+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}if((b|0)!=13){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;c[b>>2]=c[337668];c[b+4>>2]=c[337669];c[b+8>>2]=c[337670];d=0;return d|0}function ayh(){c[2383488]=-1241643714;c[2383486]=-66874790;a[61608]=0;c[2383494]=91828;c[2383490]=104652788;c[2383476]=33606764;c[2383478]=100665476;c[2383482]=130760;a[61600]=1;return az2()|0}function ayi(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5674236+(b*112|0)>>2];c[a+104>>2]=c[5674240+(b*112|0)>>2];c[a+108>>2]=c[5674244+(b*112|0)>>2];d=0;return d|0}function ayj(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=5674136+(b*112|0);e=0;return e|0}function ayk(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=12){if((a|0)==0){d=0;return d|0}e=a;f=6485488+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}if((b|0)!=13){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;c[b>>2]=c[235666];c[b+4>>2]=c[235667];c[b+8>>2]=c[235668];d=0;return d|0}function ayl(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5676812+(b*112|0)>>2];c[a+104>>2]=c[5676816+(b*112|0)>>2];c[a+108>>2]=c[5676820+(b*112|0)>>2];d=0;return d|0}function aym(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=5676712+(b*112|0);e=0;return e|0}function ayn(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=12){if((a|0)==0){d=0;return d|0}e=a;f=6485488+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}if((b|0)!=13){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;c[b>>2]=c[174580];c[b+4>>2]=c[174581];c[b+8>>2]=c[174582];d=0;return d|0}function ayo(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5671660+(b*112|0)>>2];c[a+104>>2]=c[5671664+(b*112|0)>>2];c[a+108>>2]=c[5671668+(b*112|0)>>2];d=0;return d|0}function ayp(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=5671560+(b*112|0);e=0;return e|0}function ayq(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=12){if((a|0)==0){d=0;return d|0}e=a;f=6485488+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}if((b|0)!=13){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;c[b>>2]=c[293004];c[b+4>>2]=c[293005];c[b+8>>2]=c[293006];d=0;return d|0}function ayr(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>32){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5683980+(b*112|0)>>2];c[a+104>>2]=c[5683984+(b*112|0)>>2];c[a+108>>2]=c[5683988+(b*112|0)>>2];d=0;return d|0}function ays(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<33&(d|0)==0)){e=1;return e|0}c[a>>2]=5683880+(b*112|0);e=0;return e|0}function ayt(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=9){if((a|0)==0){d=0;return d|0}e=a;f=5727456+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}if((b|0)!=10){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;c[b>>2]=c[337668];c[b+4>>2]=c[337669];c[b+8>>2]=c[337670];d=0;return d|0}function ayu(){c[2383488]=0;c[2383486]=0;a[61608]=1;c[2383494]=0;c[2383490]=0;c[2383476]=33611748;c[2383478]=100665476;c[2383482]=130760;a[61600]=1;return az2()|0}function ayv(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>32){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4414076+(b*112|0)>>2];c[a+104>>2]=c[4414080+(b*112|0)>>2];c[a+108>>2]=c[4414084+(b*112|0)>>2];d=0;return d|0}function ayw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<33&(d|0)==0)){e=1;return e|0}c[a>>2]=4413976+(b*112|0);e=0;return e|0}function ayx(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=9){if((a|0)==0){d=0;return d|0}e=a;f=5727456+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}if((b|0)!=10){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;c[b>>2]=c[235666];c[b+4>>2]=c[235667];c[b+8>>2]=c[235668];d=0;return d|0}function ayy(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>32){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4410380+(b*112|0)>>2];c[a+104>>2]=c[4410384+(b*112|0)>>2];c[a+108>>2]=c[4410388+(b*112|0)>>2];d=0;return d|0}function ayz(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<33&(d|0)==0)){e=1;return e|0}c[a>>2]=4410280+(b*112|0);e=0;return e|0}function ayA(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=9){if((a|0)==0){d=0;return d|0}e=a;f=5727456+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}if((b|0)!=10){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;c[b>>2]=c[293004];c[b+4>>2]=c[293005];c[b+8>>2]=c[293006];d=0;return d|0}function ayB(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>40){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5679388+(b*112|0)>>2];c[a+104>>2]=c[5679392+(b*112|0)>>2];c[a+108>>2]=c[5679396+(b*112|0)>>2];d=0;return d|0}function ayC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<41&(d|0)==0)){e=1;return e|0}c[a>>2]=5679288+(b*112|0);e=0;return e|0}function ayD(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=9){if((a|0)==0){d=0;return d|0}e=a;f=5727456+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}if((b|0)!=10){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;c[b>>2]=c[275744];c[b+4>>2]=c[275745];c[b+8>>2]=c[275746];d=0;return d|0}function ayE(){c[2383488]=-1521208652;c[2383486]=202545537;a[61608]=0;c[2383494]=72772;c[2383490]=101952328;c[2383476]=33609620;c[2383478]=100665476;c[2383482]=130760;a[61600]=1;return az2()|0}function ayF(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>40){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4401196+(b*112|0)>>2];c[a+104>>2]=c[4401200+(b*112|0)>>2];c[a+108>>2]=c[4401204+(b*112|0)>>2];d=0;return d|0}function ayG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<41&(d|0)==0)){e=1;return e|0}c[a>>2]=4401096+(b*112|0);e=0;return e|0}function ayH(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>40){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4405788+(b*112|0)>>2];c[a+104>>2]=c[4405792+(b*112|0)>>2];c[a+108>>2]=c[4405796+(b*112|0)>>2];d=0;return d|0}function ayI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<41&(d|0)==0)){e=1;return e|0}c[a>>2]=4405688+(b*112|0);e=0;return e|0}function ayJ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>40){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2297852+(b*112|0)>>2];c[a+104>>2]=c[2297856+(b*112|0)>>2];c[a+108>>2]=c[2297860+(b*112|0)>>2];d=0;return d|0}function ayK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<41&(d|0)==0)){e=1;return e|0}c[a>>2]=2297752+(b*112|0);e=0;return e|0}function ayL(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>40){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1394900+(b*112|0)>>2];c[a+104>>2]=c[1394904+(b*112|0)>>2];c[a+108>>2]=c[1394908+(b*112|0)>>2];d=0;return d|0}function ayM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<41&(d|0)==0)){e=1;return e|0}c[a>>2]=1394800+(b*112|0);e=0;return e|0}function ayN(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>40){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1399492+(b*112|0)>>2];c[a+104>>2]=c[1399496+(b*112|0)>>2];c[a+108>>2]=c[1399500+(b*112|0)>>2];d=0;return d|0}function ayO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<41&(d|0)==0)){e=1;return e|0}c[a>>2]=1399392+(b*112|0);e=0;return e|0}function ayP(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>26){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7040820+(b*112|0)>>2];c[a+104>>2]=c[7040824+(b*112|0)>>2];c[a+108>>2]=c[7040828+(b*112|0)>>2];d=0;return d|0}function ayQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<27&(d|0)==0)){e=1;return e|0}c[a>>2]=7040720+(b*112|0);e=0;return e|0}function ayR(){c[2383488]=35667683;c[2383486]=19929458;a[61608]=0;c[2383494]=72748;c[2383490]=102180200;c[2383476]=33694680;c[2383478]=100664924;c[2383482]=130760;a[61600]=1;return az2()|0}function ayS(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>26){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6557484+(b*112|0)>>2];c[a+104>>2]=c[6557488+(b*112|0)>>2];c[a+108>>2]=c[6557492+(b*112|0)>>2];d=0;return d|0}function ayT(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<27&(d|0)==0)){e=1;return e|0}c[a>>2]=6557384+(b*112|0);e=0;return e|0}function ayU(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>26){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6554460+(b*112|0)>>2];c[a+104>>2]=c[6554464+(b*112|0)>>2];c[a+108>>2]=c[6554468+(b*112|0)>>2];d=0;return d|0}function ayV(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<27&(d|0)==0)){e=1;return e|0}c[a>>2]=6554360+(b*112|0);e=0;return e|0}function ayW(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>26){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5850284+(b*112|0)>>2];c[a+104>>2]=c[5850288+(b*112|0)>>2];c[a+108>>2]=c[5850292+(b*112|0)>>2];d=0;return d|0}function ayX(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<27&(d|0)==0)){e=1;return e|0}c[a>>2]=5850184+(b*112|0);e=0;return e|0}function ayY(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>26){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4643180+(b*112|0)>>2];c[a+104>>2]=c[4643184+(b*112|0)>>2];c[a+108>>2]=c[4643188+(b*112|0)>>2];d=0;return d|0}function ayZ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<27&(d|0)==0)){e=1;return e|0}c[a>>2]=4643080+(b*112|0);e=0;return e|0}function ay_(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>26){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4637132+(b*112|0)>>2];c[a+104>>2]=c[4637136+(b*112|0)>>2];c[a+108>>2]=c[4637140+(b*112|0)>>2];d=0;return d|0}function ay$(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<27&(d|0)==0)){e=1;return e|0}c[a>>2]=4637032+(b*112|0);e=0;return e|0}function ay0(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>26){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5847260+(b*112|0)>>2];c[a+104>>2]=c[5847264+(b*112|0)>>2];c[a+108>>2]=c[5847268+(b*112|0)>>2];d=0;return d|0}function ay1(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<27&(d|0)==0)){e=1;return e|0}c[a>>2]=5847160+(b*112|0);e=0;return e|0}function ay2(){c[2383488]=35667683;c[2383486]=19929458;a[61608]=0;c[2383494]=72748;c[2383490]=102180200;c[2383476]=33694656;c[2383478]=100664924;c[2383482]=130760;a[61600]=1;return az2()|0}function ay3(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>26){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4640156+(b*112|0)>>2];c[a+104>>2]=c[4640160+(b*112|0)>>2];c[a+108>>2]=c[4640164+(b*112|0)>>2];d=0;return d|0}function ay4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<27&(d|0)==0)){e=1;return e|0}c[a>>2]=4640056+(b*112|0);e=0;return e|0}function ay5(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>26){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4634108+(b*112|0)>>2];c[a+104>>2]=c[4634112+(b*112|0)>>2];c[a+108>>2]=c[4634116+(b*112|0)>>2];d=0;return d|0}function ay6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<27&(d|0)==0)){e=1;return e|0}c[a>>2]=4634008+(b*112|0);e=0;return e|0}function ay7(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>32){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5853308+(b*112|0)>>2];c[a+104>>2]=c[5853312+(b*112|0)>>2];c[a+108>>2]=c[5853316+(b*112|0)>>2];d=0;return d|0}function ay8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<33&(d|0)==0)){e=1;return e|0}c[a>>2]=5853208+(b*112|0);e=0;return e|0}function ay9(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=9){if((a|0)==0){d=0;return d|0}e=a;f=801144+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}if((b|0)!=10){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;c[b>>2]=c[235666];c[b+4>>2]=c[235667];c[b+8>>2]=c[235668];d=0;return d|0}function aza(){c[2383488]=590495459;c[2383486]=50469234;a[61608]=0;c[2383494]=72848;c[2383490]=102516156;c[2383476]=33712092;c[2383478]=100664924;c[2383482]=130760;a[61600]=1;return az2()|0}function azb(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>32){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4646204+(b*112|0)>>2];c[a+104>>2]=c[4646208+(b*112|0)>>2];c[a+108>>2]=c[4646212+(b*112|0)>>2];d=0;return d|0}function azc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<33&(d|0)==0)){e=1;return e|0}c[a>>2]=4646104+(b*112|0);e=0;return e|0}function azd(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>32){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2736724+(b*112|0)>>2];c[a+104>>2]=c[2736728+(b*112|0)>>2];c[a+108>>2]=c[2736732+(b*112|0)>>2];d=0;return d|0}function aze(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<33&(d|0)==0)){e=1;return e|0}c[a>>2]=2736624+(b*112|0);e=0;return e|0}function azf(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=9){if((a|0)==0){d=0;return d|0}e=a;f=801144+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}if((b|0)!=10){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;c[b>>2]=c[275744];c[b+4>>2]=c[275745];c[b+8>>2]=c[275746];d=0;return d|0}function azg(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>32){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2733028+(b*112|0)>>2];c[a+104>>2]=c[2733032+(b*112|0)>>2];c[a+108>>2]=c[2733036+(b*112|0)>>2];d=0;return d|0}function azh(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<33&(d|0)==0)){e=1;return e|0}c[a>>2]=2732928+(b*112|0);e=0;return e|0}function azi(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>32){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1522652+(b*112|0)>>2];c[a+104>>2]=c[1522656+(b*112|0)>>2];c[a+108>>2]=c[1522660+(b*112|0)>>2];d=0;return d|0}function azj(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<33&(d|0)==0)){e=1;return e|0}c[a>>2]=1522552+(b*112|0);e=0;return e|0}function azk(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>32){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1091644+(b*112|0)>>2];c[a+104>>2]=c[1091648+(b*112|0)>>2];c[a+108>>2]=c[1091652+(b*112|0)>>2];d=0;return d|0}function azl(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<33&(d|0)==0)){e=1;return e|0}c[a>>2]=1091544+(b*112|0);e=0;return e|0}function azm(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2392612+(b*112|0)>>2];c[a+104>>2]=c[2392616+(b*112|0)>>2];c[a+108>>2]=c[2392620+(b*112|0)>>2];d=0;return d|0}function azn(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=2392512+(b*112|0);e=0;return e|0}function azo(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=9){if((a|0)==0){d=0;return d|0}e=a;f=692584+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}if((b|0)!=10){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;c[b>>2]=c[200346];c[b+4>>2]=c[200347];c[b+8>>2]=c[200348];d=0;return d|0}function azp(){c[2383488]=-1641018703;c[2383486]=-1586120660;a[61608]=0;c[2383494]=91440;c[2383490]=100730352;c[2383476]=33690476;c[2383478]=100669774;c[2383482]=130776;a[61600]=0;return az2()|0}function azq(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4315508+(b*112|0)>>2];c[a+104>>2]=c[4315512+(b*112|0)>>2];c[a+108>>2]=c[4315516+(b*112|0)>>2];d=0;return d|0}function azr(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=4315408+(b*112|0);e=0;return e|0}function azs(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=9){if((a|0)==0){d=0;return d|0}e=a;f=692584+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}if((b|0)!=10){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;c[b>>2]=c[200316];c[b+4>>2]=c[200317];c[b+8>>2]=c[200318];d=0;return d|0}function azt(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1024404+(b*112|0)>>2];c[a+104>>2]=c[1024408+(b*112|0)>>2];c[a+108>>2]=c[1024412+(b*112|0)>>2];d=0;return d|0}function azu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=1024304+(b*112|0);e=0;return e|0}function azv(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1340964+(b*112|0)>>2];c[a+104>>2]=c[1340968+(b*112|0)>>2];c[a+108>>2]=c[1340972+(b*112|0)>>2];d=0;return d|0}function azw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=1340864+(b*112|0);e=0;return e|0}function azx(a){a=a|0;return 0}function azy(a){a=a|0;var d=0,e=0;d=a&1023;if(d>>>0<512){e=b[(c[2420434]|0)+((d>>>5)*40|0)+((a>>>1&15)<<1)>>1]|0;return e|0}if((d|0)!=512){e=0;return e|0}e=b[(c[2420434]|0)+640>>1]|0;return e|0}function azz(a){a=a|0;return 0}function azA(a,b){a=a|0;b=b|0;return}function azB(a,d){a=a|0;d=d|0;var f=0,g=0,h=0,i=0;f=a&1023;if(f>>>0<512){b[(c[2420434]|0)+((f>>>5)*40|0)+((a>>>1&15)<<1)>>1]=d;return}if((f|0)!=512){return}f=d&65535;a=c[2420434]|0;g=a+640|0;h=0;do{i=1<<h;do{if((i&f|0)!=0){if(((e[g>>1]|0)&i|0)!=0){break}b[a+(h*40|0)+36>>1]=0;c[a+(h*40|0)+32>>2]=0}}while(0);h=h+1|0;}while((h|0)<16);b[g>>1]=d;return}function azC(a,b){a=a|0;b=b|0;return}function azD(a){a=a|0;return 0}function azE(a){a=a|0;var d=0,e=0;d=a&-939524097;do{if((d|0)==83886084){e=~b[4776659]}else if((d|0)==83886082){e=~b[4776656]}else if((d|0)==67895296|(d|0)==67895298|(d|0)==67895300|(d|0)==67895302|(d|0)==67895308|(d|0)==67895310|(d|0)==85196800|(d|0)==85196802){e=0}else if((d|0)==83886086){e=~b[4776658]}else if((d|0)==83886080){e=~b[4776657]}else{if((d-83888640|0)>>>0<32){e=-1;break}if((d-83890176|0)>>>0>=516){e=0;break}a=d-83890432|0;if(a>>>0<128){b[4854008]=b[(c[2414458]|0)+((a>>>1^1)<<1)>>1]|0;e=0;break}else{return((d|0)==83890690?b[4854008]|0:0)|0}}}while(0);return e|0}function azF(a){a=a|0;return((a&-939524097|0)==69206016?67415469:0)|0}function azG(a,b){a=a|0;b=b|0;switch(a&-939524097|0){case 84213795:{c[2440194]=c[2440194]&-256|b&255;return};case 84213796:{c[2443700]=c[2443700]&255|(b&255)<<8;return};case 84213797:{c[2443700]=c[2443700]&65280|b&255;return};case 84213794:{c[2440194]=c[2440194]&-65281|(b&255)<<8;return};case 84213792:{c[2440194]=c[2440194]&16777215|(b&255)<<24;return};case 84213793:{c[2440194]=c[2440194]&-16711681|(b&255)<<16;return};default:{return}}}function azH(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0;f=d&-939524097;if((f|0)==67895432){c[2439288]=(e&65535)-2;return}else if((f|0)==67895446){c[2438320]=e&65535;return}else if((f|0)==67895448){g=e&65535;if((g&64|0)==0){return}h=c[2438320]|g<<16&4128768;g=h+1|0;i=h+2|0;j=0;while(1){k=c[2406894]|0;l=c[k+(j+h<<2)>>2]|0;m=(c[k+(i+j<<2)>>2]<<1)-4194304|0;n=c[k+(g+j<<2)>>2]<<3;o=(l<<3&16777208)+8|0;if((l|0)==320017171|(l|0)==16777216){p=17585;break}q=l&14680064;if((q|0)==8388608){c[2429298]=m;ge$(10)}else if((q|0)==4194304){l=c[2406826]|0;c[2432924]=0;r=k;s=m;t=o;u=n;v=0;while(1){w=a[l+s|0]|0;x=s+1|0;if(w<<24>>24>-1){y=u&8388607;z=w&255;L21911:do{if((z&64|0)==0){a[r+y|0]=w;c[2432924]=z;A=1;B=w}else{C=v&63;D=(z&63)+1|0;E=0;F=t;while(1){if((D|0)==0){A=E;B=v;break L21911}a[r+(E+u&8388607)|0]=C;G=E+1|0;H=F-1|0;if((G+y|0)>>>0>8388607){A=H;B=v;break}else{D=D-1|0;E=G;F=H}}}}while(0);y=t-A|0;z=A+u|0;if(z>>>0>8388607){break}if((y|0)>0&(t|0)!=(A|0)){s=x;t=y;u=z;v=B;continue}else{break}}z=(w&127)<<1;y=a[l+((c[2429298]|0)+z)|0]|0;F=u&8388607;E=y&255;L21920:do{if((E&64|0)==0){a[r+F|0]=y;c[2432924]=E;I=1;J=y}else{D=v&63;C=(E&63)+1|0;H=0;G=t;while(1){if((C|0)==0){I=H;J=v;break L21920}a[r+(H+u&8388607)|0]=D;L=H+1|0;M=G-1|0;if((L+F|0)>>>0>8388607){I=M;J=v;break}else{C=C-1|0;H=L;G=M}}}}while(0);F=t-I|0;E=I+u|0;if(E>>>0>8388607|(F|0)<1){break}y=a[l+((c[2429298]|0)+(z|1))|0]|0;w=E&8388607;G=y&255;L21928:do{if((G&64|0)==0){a[r+w|0]=y;c[2432924]=G;N=1;O=y}else{H=J&63;C=(G&63)+1|0;D=0;M=F;while(1){if((C|0)==0){N=D;O=J;break L21928}a[r+(D+E&8388607)|0]=H;L=D+1|0;P=M-1|0;if((L+w|0)>>>0>8388607){N=P;O=J;break}else{C=C-1|0;D=L;M=P}}}}while(0);w=F-N|0;G=N+E|0;if(G>>>0>8388607){break}if((w|0)>0&(F|0)!=(N|0)){s=x;t=w;u=G;v=O}else{break}}ge$(10)}else if((q|0)==0){v=k+n|0;u=(c[2406826]|0)+m|0;gGC(v|0,u|0,o)|0;ge$(10)}else if((q|0)==6291456){u=c[2406826]|0;b[4830516]=-2;b[4821320]=-1;v=k;t=m;s=n;r=-2;l=-1;G=-2;w=-2;L21939:while(1){y=s;z=a[u+t|0]|0;M=0;D=t+1|0;C=r;H=l;P=G;L=w;while(1){Q=a[u+D|0]|0;if(z<<24>>24>-1){if(C<<16>>16==H<<16>>16){R=(Q&255)+1&255;if((R|0)==0){S=0}else{T=Q+1&255;U=T>>>0>1;V=H&255;a[v+(y&8388607)|0]=V;if(R>>>0>1){W=1;X=y;do{X=X+1|0;W=W+1|0;a[v+(X&8388607)|0]=V;}while((W|0)<(R|0))}S=U?T:1}b[4821320]=-1;Y=S;Z=H;_=-1;$=P;aa=L}else{b[4821320]=C;R=Q&255;b[4830516]=R;a[v+(y&8388607)|0]=Q;Y=1;Z=R;_=C;$=R;aa=R}ab=Y+y|0;ac=Z;ad=_;ae=$;af=aa}else{R=(Q&127)<<1;W=a[u+((c[2429298]|0)+R)|0]|0;if(P<<16>>16==H<<16>>16){V=(W&255)+1&255;if((V|0)==0){ah=0}else{X=W+1&255;ai=X>>>0>1;aj=P&255;a[v+(y&8388607)|0]=aj;if(V>>>0>1){ak=1;al=y;do{al=al+1|0;ak=ak+1|0;a[v+(al&8388607)|0]=aj;}while((ak|0)<(V|0))}ah=ai?X:1}b[4821320]=-1;am=ah;an=-1;ao=P;ap=L}else{b[4821320]=P;V=W&255;b[4830516]=V;a[v+(y&8388607)|0]=W;am=1;an=P;ao=V;ap=V}V=am+y|0;ak=a[u+((c[2429298]|0)+(R|1))|0]|0;if(ao<<16>>16==an<<16>>16){aj=(ak&255)+1&255;if((aj|0)==0){aq=0;ar=ao}else{al=ak+1&255;Q=al>>>0>1;a[v+(V&8388607)|0]=ao&255;if(aj>>>0>1){T=ap&255;U=1;as=V;while(1){at=as+1|0;au=U+1|0;a[v+(at&8388607)|0]=T;if((au|0)<(aj|0)){U=au;as=at}else{av=ap;break}}}else{av=ao}aq=Q?al:1;ar=av}b[4821320]=-1;aw=aq;ax=ar;ay=-1;az=ap}else{b[4821320]=ao;as=ak&255;b[4830516]=as;a[v+(V&8388607)|0]=ak;aw=1;ax=as;ay=ao;az=as}ab=aw+V|0;ac=ax;ad=ay;ae=ax;af=az}if((ab-n|0)>>>0>=o>>>0){break L21939}as=M+1|0;U=D+1|0;if((as|0)<8){y=ab;z=z<<1;M=as;D=U;C=ac;H=ad;P=ae;L=af}else{t=U;s=ab;r=ac;l=ad;G=ae;w=af;continue L21939}}}ge$(10)}w=j+3|0;if((w|0)<4096){j=w}else{p=17595;break}}if((p|0)==17585){return}else if((p|0)==17595){return}}else if((f|0)==67895458){c[2438934]=c[2438934]&-65536|e&65535;return}else if((f|0)==67895460){c[2443758]=c[2443758]&65535|(e&65535)<<16;return}else if((f|0)==67895462){c[2443758]=c[2443758]&-65536|e&65535;return}else if((f|0)==67895464){c[2443756]=c[2443756]&65535|(e&65535)<<16;return}else if((f|0)==67895466){c[2443756]=c[2443756]&-65536|e&65535;return}else if((f|0)==84213796){c[2443700]=e&65535;return}else if((f|0)==84934656){p=c[2424904]|0;j=p+272|0;if((a[j]|0)==0){return}a[j]=0;j=p+124|0;c[j>>2]=c[j>>2]&-4097;return}else if((f|0)==85000192){j=c[2424904]|0;p=j+270|0;if((a[p]|0)==0){return}a[p]=0;p=j+124|0;c[p>>2]=c[p>>2]&-1025;return}else if((f|0)==67895456){c[2438934]=c[2438934]&65535|(e&65535)<<16;return}else if((f|0)==67895428|(f|0)==69207380|(f|0)==69208746|(f|0)==84213798|(f|0)==85196800|(f|0)==85196802){return}else if((f|0)==67895468){c[2438936]=e&65535;return}else if((f|0)==67895470){if((e&2)==0){return}if((c[2438936]|0)!=0){p=c[2406826]|0;j=c[2411434]|0;af=c[3542046]|0;ae=0;do{ad=ga(b[p+(ae-2097152+(c[2438934]|0)<<1)>>1]|0)|0;ac=ad&65535;ab=ac&31;az=ac>>>5&31;ax=ac>>>10&31;ac=c[2443756]|0;if((ac|0)==0){aA=ax;aB=az;aC=ab;aD=ad}else{ad=ag(ac>>>24&63,ab)|0;ab=ad>>>0>1023?31:ad>>>5;ad=ag(az,ac>>>16&63)|0;az=ad>>>0>1023?31:ad>>>5;ad=ag(ax,ac&63)|0;ac=ad>>>0>1023?31:ad>>>5;aA=ac;aB=az;aC=ab;aD=(az<<5|ab|ac<<10)&65535}b[j+(((c[2443758]|0)+ae^1)<<1)>>1]=aD;b[af+((c[2443758]|0)+ae<<1)>>1]=(aB<<6&1984|aC<<11|aA&31)&65535;ae=ae+1|0;}while(ae>>>0<(c[2438936]|0)>>>0)}ge$(10);return}else if((f|0)==84213792){c[2440194]=c[2440194]&65535|(e&65535)<<16;return}else if((f|0)==84213794){c[2440194]=c[2440194]&-65536|e&65535;return}else if((f|0)==67895430){ae=e&65535;if((c[2385700]|0)==(ae|0)){return}aA=ae&7;c[2385700]=aA;ae=(c[2406894]|0)+(aA<<18<<2)|0;aA=(c[2406668]|0)+6572|0;aC=0;aB=68157440;while(1){af=ae+(aB-68157440)|0;c[aA>>2]=af;c[aA+262144>>2]=af;c[aA+524288>>2]=af;c[aA+8192>>2]=af;c[aA+16384>>2]=af;c[aA+24576>>2]=af;c[aA+32768>>2]=af;c[aA+40960>>2]=af;c[aA+49152>>2]=af;c[aA+57344>>2]=af;c[aA+270336>>2]=af;c[aA+278528>>2]=af;c[aA+286720>>2]=af;c[aA+294912>>2]=af;c[aA+303104>>2]=af;c[aA+311296>>2]=af;c[aA+319488>>2]=af;c[aA+532480>>2]=af;c[aA+540672>>2]=af;c[aA+548864>>2]=af;c[aA+557056>>2]=af;c[aA+565248>>2]=af;c[aA+573440>>2]=af;c[aA+581632>>2]=af;af=gGK(aB,aC,65536,0)|0;aD=K;j=0;if(aD>>>0>j>>>0|aD>>>0==j>>>0&af>>>0>69206015>>>0){break}else{aA=aA+4|0;aC=aD;aB=af}}return}else{if((f-67895296|0)>>>0<256){b[(c[2406862]|0)+((d>>>1&127^1)<<1)>>1]=e;return}if(!((f-83886080|0)>>>0>4095&(f-83890176|0)>>>0<516)){return}d=f-83890304|0;if(d>>>0>=128){return}b[(c[2414458]|0)+((d>>>1^1)<<1)>>1]=e;return}}function azI(a,b){a=a|0;b=b|0;return}function azJ(a,b){a=a|0;b=b|0;return}function azK(a,b){a=a|0;b=b|0;return}function azL(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;if(a>>>0>=3221226496){return}d=a&1023;c[(c[2406896]|0)+d>>2]=b;e=c[2383486]|0;f=c[2383488]^a;a=f^65535;g=a&65535;h=((g&65535)>>>14|g<<2)+g&65535;g=f>>>16^65535^(((h&65535)>>>12|h<<4)^h&((a^e)&65535))&65535;a=g&65535;h=((a&65535)>>>14|a<<2)+a&65535;a=(((h&65535)>>>12|h<<4)^h&((g^e>>>16)&65535))&65535^(f^e)&65535;c[(c[2385768]|0)+d>>2]=(a<<16|a)^b;return}function azM(b){b=b|0;return a[(c[2385742]|0)+(b&16777215^3)|0]|0}function azN(a){a=a|0;return b[(c[2385742]|0)+(a&16777215^2)>>1]|0}function azO(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3528568]|0;do{if((b|0)==12){d=c[3528570]^68;c[3528570]=d;e=d;f=17626}else if((b|0)==8|(b|0)==1){d=a&8388607;if((d|0)==4){g=-1381126739;break}else if((d|0)==8){g=0;break}else if((d|0)==0){g=67372036;break}else{g=0;break}}else if((b|0)==2){e=c[3528570]|0;f=17626}else{h=0;f=17627}}while(0);if((f|0)==17626){h=e<<8|e|e<<16|e<<24;f=17627}do{if((f|0)==17627){if((b|0)!=0){g=h;break}g=c[(c[2385742]|0)+(a&16777215)>>2]|0}}while(0);h=c[2424904]|0;f=c[h+100>>2]|0;if((f|0)==0){i=c[h+4>>2]|0}else{i=f}f=i&-939524097;do{if((f|0)==(c[2383494]|0)){if((b|0)==0){break}else{j=g}return j|0}else{if((f|0)==(c[2383490]|0)&(b|0)==0){break}else{j=g}return j|0}}while(0);j=c[(c[2406848]|0)+(a&16777215)>>2]|0;return j|0}function azP(a,b){a=a|0;b=b|0;return}function azQ(a,b){a=a|0;b=b|0;return}function azR(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=a&16777215;e=c[3528568]|0;L22088:do{switch(e|0){case 6:{do{if((a&65535|0)==2728){if((b&255|0)!=85){break}c[3528568]=7;return}}while(0);c[3528568]=0;break};case 7:{do{if((a&65535|0)==5460){f=b&255;if((f|0)==144){c[3528568]=8;return}else if((f|0)==128){c[3528568]=9;return}else if((f|0)==160){c[3528568]=13;return}else if((f|0)==240){c[3528568]=0;break L22088}else{break}}}while(0);c[3528568]=0;break};case 0:case 2:case 1:case 8:{L22109:do{switch(b&255|0){case 144:{c[3528568]=1;return};case 64:case 16:{c[3528568]=3;return};case 80:{c[3528570]=128;c[3528568]=2;return};case 32:{c[3528568]=4;return};case 96:{c[3528568]=5;return};case 112:{c[3528568]=2;return};case 170:{if((a&65535|0)!=5460){break L22109}c[3528568]=6;return};case 240:case 255:{c[3528568]=0;break L22088;break};default:{}}}while(0);if((e|0)==0){break L22088}return};default:{return}}}while(0);c[(c[2406848]|0)+d>>2]=b;e=c[2383486]|0;a=c[2383488]^(d|100663296);f=a^65535;g=f&65535;h=((g&65535)>>>14|g<<2)+g&65535;g=a>>>16^65535^(((h&65535)>>>12|h<<4)^h&((f^e)&65535))&65535;f=g&65535;h=((f&65535)>>>14|f<<2)+f&65535;f=(((h&65535)>>>12|h<<4)^h&((g^e>>>16)&65535))&65535^(a^e)&65535;c[(c[2385742]|0)+d>>2]=(f<<16|f)^b;return}function azS(b){b=b|0;return a[(c[2406848]|0)+(b&16777215^3)|0]|0}function azT(a){a=a|0;return b[(c[2406848]|0)+(a&16777215^2)>>1]|0}function azU(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=c[3528568]|0;do{if((b|0)==8|(b|0)==1){d=a&8388607;if((d|0)==8){e=0;break}else if((d|0)==0){e=67372036;break}else if((d|0)==4){e=-1381126739;break}else{e=0;break}}else if((b|0)==12){d=c[3528570]^68;c[3528570]=d;f=d;g=17689}else if((b|0)==2){f=c[3528570]|0;g=17689}else{h=0;g=17690}}while(0);if((g|0)==17689){h=f<<8|f|f<<16|f<<24;g=17690}do{if((g|0)==17690){if((b|0)!=0){e=h;break}e=c[(c[2406848]|0)+(a&16777215)>>2]|0}}while(0);return e|0}function azV(a){a=a|0;return 0}function azW(a){a=a|0;return 0}function azX(a){a=a|0;return 0}function azY(a,b){a=a|0;b=b|0;return}function azZ(a,d){a=a|0;d=d|0;var e=0;e=(a&-939524097)-67633152|0;if(e>>>0>=262144){return}a=e>>>1;b[(c[2411434]|0)+((a^1)<<1)>>1]=d;e=d&65535;d=e>>>2&248;b[(c[3542046]|0)+(a<<1)>>1]=(e>>>10&31|e<<11|(d>>>5|d)<<3&2016)&65535;return}function az_(a,b){a=a|0;b=b|0;return}function az$(b){b=b|0;var d=0,e=0,f=0;do{if((c[2383476]|0)==(b|0)){d=c[2424904]|0;e=c[d+100>>2]|0;if((e|0)==0){f=c[d+4>>2]|0}else{f=e}if((f&-939524097|0)!=(c[2383478]|0)){break}c[(c[2406668]|0)+789040>>2]=1}}while(0);return a[(c[2406892]|0)+(b&524287^3)|0]|0}function az0(a){a=a|0;var d=0,e=0,f=0;d=a&524287;do{if((d|0)==(c[2383476]|0)){a=c[2424904]|0;e=c[a+100>>2]|0;if((e|0)==0){f=c[a+4>>2]|0}else{f=e}if((f&-939524097|0)!=(c[2383478]|0)){break}c[(c[2406668]|0)+789040>>2]=1}}while(0);return b[(c[2406892]|0)+(d^2)>>1]|0}function az1(a){a=a|0;var b=0,d=0,e=0;do{if((c[2383476]|0)==(a|0)){b=c[2424904]|0;d=c[b+100>>2]|0;if((d|0)==0){e=c[b+4>>2]|0}else{e=d}if((e&-939524097|0)!=(c[2383478]|0)){break}c[(c[2406668]|0)+789040>>2]=1}}while(0);return c[(c[2406892]|0)+(a&524287)>>2]|0}function az2(){var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;b=i;i=i+232|0;d=b|0;e=b+112|0;f=b+120|0;c[2430034]=0;if((gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,0)|0)==0){g=f+108|0;j=f+100|0;k=0;do{if((c[g>>2]&6291456|0)!=0){c[2430034]=(c[2430034]|0)+(c[j>>2]|0)}k=k+1|0;}while((gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,k)|0)==0)}k=c[2430034]|0;if((k|0)==0){c[2430034]=83886080;l=83886080}else{l=k}c[2426670]=0;c[2406850]=0;c[2406826]=524288;k=l+524288|0;c[2405608]=k;c[2406848]=k;c[2385742]=l+17301504;c[2406896]=l+34078720;c[2385768]=l+34079744;c[2406892]=l+34080768;c[2411434]=l+34605056;c[2411374]=l+34867200;c[2406894]=l+35391488;c[2418168]=l+43780096;c[2406862]=l+43845632;c[2414458]=l+43845888;k=l+43846400|0;c[2411540]=k;c[3542046]=k;c[2385750]=l+44108546;k=l+46074626|0;c[2414080]=k;l=k;k=0;while(1){if((k|0)>=1024){break}m=9638528+(k<<2)|0;if((c[m>>2]|0)==0){n=17731;break}else{k=k+1|0}}do{if((n|0)==17731){k=gGq(l)|0;c[m>>2]=k;if((k|0)==0){break}gGz(k|0,0,l|0);c[2426670]=k;gGz(k|0,0,l|0);c[2406850]=k;c[2406826]=k+524288;j=c[2430034]|0;g=k+(j+524288)|0;c[2405608]=g;c[2406848]=g;c[2385742]=k+(j+17301504);c[2406896]=k+(j+34078720);c[2385768]=k+(j+34079744);c[2406892]=k+(j+34080768);c[2411434]=k+(j+34605056);c[2411374]=k+(j+34867200);c[2406894]=k+(j+35391488);c[2418168]=k+(j+43780096);c[2406862]=k+(j+43845632);c[2414458]=k+(j+43845888);g=k+(j+43846400)|0;c[2411540]=g;c[3542046]=g;c[2385750]=k+(j+44108546);c[2414080]=k+(j+46074626);L22199:do{if((gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,0)|0)==0){j=f+108|0;k=f+100|0;g=d+108|0;o=d+100|0;p=0;q=0;while(1){if((c[j>>2]&33554432|0)==0){r=q}else{s=(c[2406850]|0)+q|0;if((c[3542200]|0)==0){t=1;n=17801;break}c[g>>2]=0;c[o>>2]=0;u=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[u&16383](d,p)|0;if((c[g>>2]|0)!=0){u=c[o>>2]|0;c[e>>2]=9534384;v=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[v&16383](e,p,0)|0;if((u|0)<1){t=1;n=17797;break}if((gzL(s,0,p)|0)!=0){t=1;n=17798;break}}r=(c[k>>2]|0)+q|0}s=p+1|0;if((gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,s)|0)==0){p=s;q=r}else{break L22199}}if((n|0)==17797){i=b;return t|0}else if((n|0)==17798){i=b;return t|0}else if((n|0)==17801){i=b;return t|0}}}while(0);q=c[2406850]|0;p=q;k=0;while(1){o=a[p]|0;g=p+3|0;a[p]=a[g]|0;a[g]=o;o=p+1|0;g=a[o]|0;j=p+2|0;a[o]=a[j]|0;a[j]=g;g=k+4|0;if((g|0)<524288){p=p+4|0;k=g}else{break}}k=q;p=c[2383488]|0;g=c[2383486]|0;j=g>>>16;o=0;do{s=p^o;u=s^65535;v=u&65535;w=((v&65535)>>>14|v<<2)+v&65535;v=s>>>16^65535^(((w&65535)>>>12|w<<4)^w&((u^g)&65535))&65535;u=v&65535;w=((u&65535)>>>14|u<<2)+u&65535;u=(((w&65535)>>>12|w<<4)^w&((v^j)&65535))&65535^(s^g)&65535;if((o-130816|0)>>>0>107){s=k+(((o|0)/4|0)<<2)|0;c[s>>2]=c[s>>2]^(u<<16|u)}o=o+4|0;}while((o|0)<131072);o=f+108|0;k=f+100|0;g=0;j=0;L22225:while(1){p=j;while(1){if((gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,p)|0)!=0){n=17757;break L22225}x=p+1|0;if((c[o>>2]&1048576|0)==0){p=x}else{break}}if((R6((c[2406848]|0)+g|0,p,4)|0)!=0){t=1;n=17802;break}if((R6((c[2406848]|0)+(g|1)|0,x,4)|0)!=0){t=1;n=17794;break}if((R6((c[2406848]|0)+(g|2)|0,p+2|0,4)|0)!=0){t=1;n=17795;break}if((R6((c[2406848]|0)+(g|3)|0,p+3|0,4)|0)!=0){t=1;n=17799;break}g=(c[k>>2]<<2)+g|0;j=p+4|0}if((n|0)==17794){i=b;return t|0}else if((n|0)==17795){i=b;return t|0}else if((n|0)==17799){i=b;return t|0}else if((n|0)==17802){i=b;return t|0}else if((n|0)==17757){j=c[2406848]|0;g=j;q=0;while(1){u=a[g]|0;s=g+3|0;a[g]=a[s]|0;a[s]=u;u=g+1|0;s=a[u]|0;v=g+2|0;a[u]=a[v]|0;a[v]=s;s=q+4|0;if((s|0)<16777216){g=g+4|0;q=s}else{break}}q=j;g=c[2385742]|0;s=c[2383488]|0;v=c[2383486]|0;u=v>>>16;w=0;while(1){y=s^w+100663296;z=y^65535;A=z&65535;B=((A&65535)>>>14|A<<2)+A&65535;A=y>>>16^65535^(((B&65535)>>>12|B<<4)^B&((z^v)&65535))&65535;z=A&65535;B=((z&65535)>>>14|z<<2)+z&65535;z=(((B&65535)>>>12|B<<4)^B&((A^u)&65535))&65535^(y^v)&65535;y=(w|0)/4|0;c[g+(y<<2)>>2]=(z<<16|z)^c[q+(y<<2)>>2];y=w+4|0;if((y|0)<16777216){w=y}else{C=0;D=0;break}}L22246:while(1){w=D;while(1){if((gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,w)|0)!=0){break L22246}E=w+1|0;if((c[o>>2]&6291456|0)==0){w=E}else{break}}R6((c[2406826]|0)+C|0,w,2)|0;R6((c[2406826]|0)+(C|1)|0,E,2)|0;C=(c[k>>2]<<1)+C|0;D=w+2|0}geV();k=c[2411230]|0;c[2406668]=k;c[2424904]=k;o=c[2406850]|0;p=k+2412|0;q=0;g=0;while(1){v=o+g|0;c[p>>2]=v;c[p+524288>>2]=v;c[p+8192>>2]=v;c[p+16384>>2]=v;c[p+24576>>2]=v;c[p+32768>>2]=v;c[p+40960>>2]=v;c[p+49152>>2]=v;c[p+57344>>2]=v;c[p+532480>>2]=v;c[p+540672>>2]=v;c[p+548864>>2]=v;c[p+557056>>2]=v;c[p+565248>>2]=v;c[p+573440>>2]=v;c[p+581632>>2]=v;v=gGK(g,q,65536,0)|0;u=K;s=0;if(u>>>0>s>>>0|u>>>0==s>>>0&v>>>0>524287>>>0){break}else{p=p+4|0;q=u;g=v}}g=c[2406892]|0;q=k+4460|0;p=0;o=33554432;while(1){v=g+(o-33554432)|0;c[q>>2]=v;c[q+262144>>2]=v;c[q+524288>>2]=v;c[q+8192>>2]=v;c[q+16384>>2]=v;c[q+24576>>2]=v;c[q+32768>>2]=v;c[q+40960>>2]=v;c[q+49152>>2]=v;c[q+57344>>2]=v;c[q+270336>>2]=v;c[q+278528>>2]=v;c[q+286720>>2]=v;c[q+294912>>2]=v;c[q+303104>>2]=v;c[q+311296>>2]=v;c[q+319488>>2]=v;c[q+532480>>2]=v;c[q+540672>>2]=v;c[q+548864>>2]=v;c[q+557056>>2]=v;c[q+565248>>2]=v;c[q+573440>>2]=v;c[q+581632>>2]=v;v=gGK(o,p,65536,0)|0;u=K;s=0;if(u>>>0>s>>>0|u>>>0==s>>>0&v>>>0>34078719>>>0){break}else{q=q+4|0;p=u;o=v}}o=c[2411374]|0;p=k+6508|0;q=0;g=67108864;while(1){v=o+(g-67108864)|0;c[p>>2]=v;c[p+262144>>2]=v;c[p+524288>>2]=v;c[p+8192>>2]=v;c[p+16384>>2]=v;c[p+24576>>2]=v;c[p+32768>>2]=v;c[p+40960>>2]=v;c[p+49152>>2]=v;c[p+57344>>2]=v;c[p+270336>>2]=v;c[p+278528>>2]=v;c[p+286720>>2]=v;c[p+294912>>2]=v;c[p+303104>>2]=v;c[p+311296>>2]=v;c[p+319488>>2]=v;c[p+532480>>2]=v;c[p+540672>>2]=v;c[p+548864>>2]=v;c[p+557056>>2]=v;c[p+565248>>2]=v;c[p+573440>>2]=v;c[p+581632>>2]=v;v=gGK(g,q,65536,0)|0;u=K;s=0;if(u>>>0>s>>>0|u>>>0==s>>>0&v>>>0>67633151>>>0){break}else{p=p+4|0;q=u;g=v}}g=c[2418168]|0;c[k+7548>>2]=g;c[k+269692>>2]=g;c[k+531836>>2]=g;c[k+15740>>2]=g;c[k+23932>>2]=g;c[k+32124>>2]=g;c[k+40316>>2]=g;c[k+48508>>2]=g;c[k+56700>>2]=g;c[k+64892>>2]=g;c[k+277884>>2]=g;c[k+286076>>2]=g;c[k+294268>>2]=g;c[k+302460>>2]=g;c[k+310652>>2]=g;c[k+318844>>2]=g;c[k+327036>>2]=g;c[k+540028>>2]=g;c[k+548220>>2]=g;c[k+556412>>2]=g;c[k+564604>>2]=g;c[k+572796>>2]=g;c[k+580988>>2]=g;c[k+589180>>2]=g;c[k+788844>>2]=2652;c[k+788908>>2]=970;c[k+788972>>2]=152;c[k+788876>>2]=644;c[k+788940>>2]=1874;c[k+789004>>2]=2874;c[k+723308>>2]=c[2385768];c[k+199020>>2]=c[2406896];c[k+461164>>2]=1;c[k+788880>>2]=1852;c[k+788944>>2]=146;c[k+789008>>2]=1422;g=c[642608+(c[2436]<<2)>>2]|0;L22262:do{if((c[g+60>>2]|0)==0){if(!(a[61608]|0)){q=c[2385742]|0;p=k+8556|0;o=0;v=100663296;while(1){u=q+(v-100663296)|0;c[p>>2]=u;c[p+524288>>2]=u;c[p+8192>>2]=u;c[p+16384>>2]=u;c[p+24576>>2]=u;c[p+32768>>2]=u;c[p+40960>>2]=u;c[p+49152>>2]=u;c[p+57344>>2]=u;c[p+532480>>2]=u;c[p+540672>>2]=u;c[p+548864>>2]=u;c[p+557056>>2]=u;c[p+565248>>2]=u;c[p+573440>>2]=u;c[p+581632>>2]=u;u=gGK(v,o,65536,0)|0;s=K;j=0;if(s>>>0>j>>>0|s>>>0==j>>>0&u>>>0>117440511>>>0){break L22262}else{p=p+4|0;o=s;v=u}}}v=c[2406848]|0;o=k+8556|0;p=o;q=0;w=100663296;while(1){u=v+(w-100663296)|0;c[p>>2]=u;c[p+8192>>2]=u;c[p+16384>>2]=u;c[p+24576>>2]=u;c[p+32768>>2]=u;c[p+40960>>2]=u;c[p+49152>>2]=u;c[p+57344>>2]=u;u=gGK(w,q,65536,0)|0;s=K;j=0;if(s>>>0>j>>>0|s>>>0==j>>>0&u>>>0>117440511>>>0){break}else{p=p+4|0;q=s;w=u}}w=c[2385742]|0;q=o;p=0;v=100663296;while(1){u=w+(v-100663296)|0;c[q+524288>>2]=u;c[q+532480>>2]=u;c[q+540672>>2]=u;c[q+548864>>2]=u;c[q+557056>>2]=u;c[q+565248>>2]=u;c[q+573440>>2]=u;c[q+581632>>2]=u;u=gGK(v,p,65536,0)|0;s=K;j=0;if(s>>>0>j>>>0|s>>>0==j>>>0&u>>>0>117440511>>>0){break}else{q=q+4|0;p=s;v=u}}}else{v=c[2385742]|0;p=k+8556|0;q=p;w=0;o=100663296;while(1){u=v+(o-100663296)|0;c[q+524288>>2]=u;c[q+532480>>2]=u;c[q+540672>>2]=u;c[q+548864>>2]=u;c[q+557056>>2]=u;c[q+565248>>2]=u;c[q+573440>>2]=u;c[q+581632>>2]=u;u=gGK(o,w,65536,0)|0;s=K;j=0;if(s>>>0>j>>>0|s>>>0==j>>>0&u>>>0>117440511>>>0){F=p;G=0;H=100663296;break}else{q=q+4|0;w=s;o=u}}while(1){c[F>>2]=2;c[F+262144>>2]=2;c[F+8192>>2]=2;c[F+16384>>2]=2;c[F+24576>>2]=2;c[F+32768>>2]=2;c[F+40960>>2]=2;c[F+49152>>2]=2;c[F+57344>>2]=2;c[F+270336>>2]=2;c[F+278528>>2]=2;c[F+286720>>2]=2;c[F+294912>>2]=2;c[F+303104>>2]=2;c[F+311296>>2]=2;c[F+319488>>2]=2;o=gGK(H,G,65536,0)|0;w=K;q=0;if(w>>>0>q>>>0|w>>>0==q>>>0&o>>>0>117440511>>>0){break}else{F=F+4|0;G=w;H=o}}o=k+788852|0;if(a[61608]|0){c[o>>2]=1506;c[k+788916>>2]=1474;c[k+788980>>2]=1900;c[k+788884>>2]=558;c[k+788948>>2]=1654;c[k+789012>>2]=1496;break}else{c[o>>2]=1272;c[k+788916>>2]=2328;c[k+788980>>2]=1022;c[k+788884>>2]=558;c[k+788948>>2]=1654;c[k+789012>>2]=1496;break}}}while(0);c[k+6564>>2]=3;c[k+268708>>2]=3;c[k+530852>>2]=3;c[k+14756>>2]=3;c[k+22948>>2]=3;c[k+31140>>2]=3;c[k+39332>>2]=3;c[k+47524>>2]=3;c[k+55716>>2]=3;c[k+63908>>2]=3;c[k+276900>>2]=3;c[k+285092>>2]=3;c[k+293284>>2]=3;c[k+301476>>2]=3;c[k+309668>>2]=3;c[k+317860>>2]=3;c[k+326052>>2]=3;c[k+539044>>2]=3;c[k+547236>>2]=3;c[k+555428>>2]=3;c[k+563620>>2]=3;c[k+571812>>2]=3;c[k+580004>>2]=3;c[k+588196>>2]=3;c[k+788856>>2]=764;c[k+788920>>2]=2880;c[k+788984>>2]=2462;c[k+788888>>2]=2362;c[k+788952>>2]=2122;c[k+789016>>2]=1834;o=c[2411434]|0;w=o;c[k+6540>>2]=w;c[k+14732>>2]=w;c[k+22924>>2]=w;c[k+31116>>2]=w;c[k+39308>>2]=w;c[k+47500>>2]=w;c[k+55692>>2]=w;c[k+63884>>2]=w;w=o+65536|0;c[k+6544>>2]=w;c[k+14736>>2]=w;c[k+22928>>2]=w;c[k+31120>>2]=w;c[k+39312>>2]=w;c[k+47504>>2]=w;c[k+55696>>2]=w;c[k+63888>>2]=w;w=o+131072|0;c[k+6548>>2]=w;c[k+14740>>2]=w;c[k+22932>>2]=w;c[k+31124>>2]=w;c[k+39316>>2]=w;c[k+47508>>2]=w;c[k+55700>>2]=w;c[k+63892>>2]=w;w=o+196608|0;c[k+6552>>2]=w;c[k+14744>>2]=w;c[k+22936>>2]=w;c[k+31128>>2]=w;c[k+39320>>2]=w;c[k+47512>>2]=w;c[k+55704>>2]=w;c[k+63896>>2]=w;c[k+268684>>2]=4;c[k+276876>>2]=4;c[k+285068>>2]=4;c[k+293260>>2]=4;c[k+301452>>2]=4;c[k+309644>>2]=4;c[k+317836>>2]=4;c[k+326028>>2]=4;c[k+268688>>2]=4;c[k+276880>>2]=4;c[k+285072>>2]=4;c[k+293264>>2]=4;c[k+301456>>2]=4;c[k+309648>>2]=4;c[k+317840>>2]=4;c[k+326032>>2]=4;c[k+268692>>2]=4;c[k+276884>>2]=4;c[k+285076>>2]=4;c[k+293268>>2]=4;c[k+301460>>2]=4;c[k+309652>>2]=4;c[k+317844>>2]=4;c[k+326036>>2]=4;c[k+268696>>2]=4;c[k+276888>>2]=4;c[k+285080>>2]=4;c[k+293272>>2]=4;c[k+301464>>2]=4;c[k+309656>>2]=4;c[k+317848>>2]=4;c[k+326040>>2]=4;c[k+788860>>2]=3332;c[k+788924>>2]=3212;c[k+788988>>2]=1702;c[k+788892>>2]=1974;c[k+788956>>2]=970;c[k+789020>>2]=3184;w=c[2383476]&196608;o=w|33554432;q=w|33619967;w=q;p=0;if(o>>>0<=q>>>0){q=k+2412+(o>>>16<<2)|0;v=0;u=o;while(1){c[q>>2]=5;c[q+8192>>2]=5;c[q+16384>>2]=5;c[q+24576>>2]=5;c[q+32768>>2]=5;c[q+40960>>2]=5;c[q+49152>>2]=5;c[q+57344>>2]=5;o=gGK(u,v,65536,0)|0;s=K;if(s>>>0>p>>>0|s>>>0==p>>>0&o>>>0>w>>>0){break}else{q=q+4|0;v=s;u=o}}}c[k+788864>>2]=514;c[k+788928>>2]=892;c[k+788992>>2]=1640;c[2438308]=c[g+128>>2];c[2436758]=c[g+132>>2];c[2385750]=(c[2385750]|0)+65600;u=c[2406826]|0;v=0;while(1){I=9638528+(v<<2)|0;if((c[I>>2]|0)==0){break}else{v=v+1|0}}v=gGq(680)|0;c[I>>2]=v;c[2420434]=v;gGz(v|0,0,680);c[v+644>>2]=u;if(a[9680]|0){c[v+648>>2]=((37286/((c[2424]|0)/100|0|0)|0)<<12|0)/534|0}h[v+656>>3]=1.0;c[v+672>>2]=1;h[v+664>>3]=1.0;c[v+676>>2]=2;c[2112966]=c[3542046];az3();t=0;i=b;return t|0}}}while(0);c[2426670]=0;t=1;i=b;return t|0}function az3(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;c[2385700]=0;d=c[2406894]|0;e=c[2406668]|0;f=e+6572|0;g=0;h=68157440;while(1){i=d+(h-68157440)|0;c[f>>2]=i;c[f+262144>>2]=i;c[f+524288>>2]=i;c[f+8192>>2]=i;c[f+16384>>2]=i;c[f+24576>>2]=i;c[f+32768>>2]=i;c[f+40960>>2]=i;c[f+49152>>2]=i;c[f+57344>>2]=i;c[f+270336>>2]=i;c[f+278528>>2]=i;c[f+286720>>2]=i;c[f+294912>>2]=i;c[f+303104>>2]=i;c[f+311296>>2]=i;c[f+319488>>2]=i;c[f+532480>>2]=i;c[f+540672>>2]=i;c[f+548864>>2]=i;c[f+557056>>2]=i;c[f+565248>>2]=i;c[f+573440>>2]=i;c[f+581632>>2]=i;i=gGK(h,g,65536,0)|0;j=K;k=0;if(j>>>0>k>>>0|j>>>0==k>>>0&i>>>0>69206015>>>0){break}else{f=f+4|0;g=j;h=i}}h=c[2383482]|0;do{if((h|0)!=0){g=c[2406850]|0;f=g+h|0;a[f]=a[9533968]&127|a[f]&-16;if(!(a[61600]|0)){break}f=g+130767|0;g=a[f]|0;if((a[9533968]&16)==0){a[f]=g&-2;break}else{a[f]=g|1;break}}}while(0);do{if((c[(c[642608+(c[2436]<<2)>>2]|0)+60>>2]|0)==0){h=c[e+2412>>2]|0;if(h>>>0>7){l=c[h>>2]|0;m=e;n=h}else{g=gj[c[e+788972+(h<<2)>>2]&4095](0)|0;h=c[2406668]|0;l=g;m=h;n=c[h+2412>>2]|0}if(n>>>0>7){o=c[n+4>>2]|0;p=m}else{h=gj[c[m+788972+(n<<2)>>2]&4095](4)|0;o=h;p=c[2406668]|0}h=c[2424904]|0;gGz(h|0,0,2408);g=h+4|0;c[h+92>>2]=o;c[h+12>>2]=240;f=l&-939524097;c[g>>2]=f;d=c[p+2412+((f>>>16|131072)<<2)>>2]|0;f=p+789036|0;c[f>>2]=d;c[f>>2]=d+(-(c[g>>2]&-65536)|0);c[h+2348>>2]=-1}else{if(a[61608]|0){h=c[2406848]|0;g=c[h>>2]|0;d=c[h+4>>2]|0;h=c[2424904]|0;gGz(h|0,0,2408);f=h+4|0;c[h+92>>2]=d;c[h+12>>2]=240;d=g&-939524097;c[f>>2]=d;g=c[e+2412+((d>>>16|131072)<<2)>>2]|0;d=e+789036|0;c[d>>2]=g;c[d>>2]=g+(-(c[f>>2]&-65536)|0);c[h+2348>>2]=-1;c[h+20>>2]=100663296;break}else{h=c[2385742]|0;f=c[h>>2]|0;g=c[h+4>>2]|0;h=c[2424904]|0;gGz(h|0,0,2408);d=h+4|0;c[h+92>>2]=g;c[h+12>>2]=240;g=f&-939524097;c[d>>2]=g;f=c[e+2412+((g>>>16|131072)<<2)>>2]|0;g=e+789036|0;c[g>>2]=f;c[g>>2]=f+(-(c[d>>2]&-65536)|0);c[h+2348>>2]=-1;c[h+20>>2]=100663296;break}}}while(0);e=c[2414458]|0;p=e+34|0;l=b[p>>1]&255;if((a[9533968]|0)<0){b[p>>1]=(l|256)&65535;o=e+82|0;b[o>>1]=b[o>>1]&255|256;b[4854008]=0;a[9533920]=0;return}else{b[p>>1]=l&65535;l=e+82|0;b[l>>1]=b[l>>1]&255;b[4854008]=0;a[9533920]=0;return}}function az4(){var a=0,b=0,d=0,e=0,f=0;a=c[2411230]|0;if((a|0)!=0){gGr(a);c[2411230]=0}c[2406668]=0;a=c[2426670]|0;b=0;while(1){if((b|0)>=1024){break}d=9638528+(b<<2)|0;if((c[d>>2]|0)==(a|0)){e=17832;break}else{b=b+1|0}}if((e|0)==17832){gGr(a);c[d>>2]=0}c[2426670]=0;d=c[2420434]|0;a=0;while(1){if((a|0)>=1024){e=17838;break}f=9638528+(a<<2)|0;if((c[f>>2]|0)==(d|0)){break}else{a=a+1|0}}if((e|0)==17838){c[2420434]=0;return 0}gGr(d);c[f>>2]=0;c[2420434]=0;return 0}function az5(){var d=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0.0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0;d=i;i=i+16|0;f=d|0;if((a[9533920]|0)!=0){az3()}if((a[9533936]|0)!=0){g=c[2411434]|0;j=c[3542046]|0;k=0;do{l=e[g+((k^1)<<1)>>1]|0;m=l>>>2&248;b[j+(k<<1)>>1]=(l>>>10&31|l<<11|(m>>>5|m)<<3&2016)&65535;k=k+1|0;}while((k|0)<131072);a[9533936]=0}if((c[2429452]|0)==(c[2113222]|0)){k=c[642608+(c[2436]<<2)>>2]|0;c[2438308]=c[k+128>>2];c[2436758]=c[k+132>>2];c[2429452]=0}b[4776656]=0;b[4776657]=0;b[4776659]=0;k=0;j=0;g=0;m=0;do{j=((a[14168224+k|0]&1)<<k|j&65535)&65535;g=((a[14168208+k|0]&1)<<k|g&65535)&65535;m=((a[14168192+k|0]&1)<<k|m&65535)&65535;k=k+1|0;}while((k|0)<16);b[4776656]=j;b[4776657]=g;b[4776659]=m;if((j&3)==3){m=j&-4;b[4776656]=m;n=m}else{n=j}if((n&12)==12){b[4776656]=n&-13}if((g&3)==3){n=g&-4;b[4776657]=n;o=n}else{o=g}if((o&12)==12){b[4776657]=o&-13}geZ(104166)|0;o=c[2439300]|0;if((o|0)>1){c[2439300]=0;ge$(10)}else{c[2439300]=o+1}geZ(104166)|0;o=c[2439300]|0;if((o|0)>1){c[2439300]=0;ge$(10)}else{c[2439300]=o+1}geZ(104166)|0;o=c[2439300]|0;if((o|0)>1){c[2439300]=0;ge$(10)}else{c[2439300]=o+1}geZ(104166)|0;o=c[2439300]|0;if((o|0)>1){c[2439300]=0;ge$(10)}else{c[2439300]=o+1}ge$(12);o=c[2112964]|0;L22390:do{if((o|0)!=0){g=a[9688]|0;gGz(o|0,0,(g?2136:0)|0);n=c[2420434]|0;j=c[n+644>>2]|0;m=n+672|0;k=n+676|0;l=g?534:0;p=n+664|0;q=n+656|0;r=n+640|0;s=0;t=n|0;while(1){u=1<<s;if((e[r>>1]&u|0)!=0){v=e[t+6>>1]<<16|e[t+4>>1];w=v-4194304|0;x=(e[t+22>>1]<<16|e[t+20>>1])-4194304|0;y=(ag(e[t+12>>1]|0,c[n+648>>2]|0)|0)>>>12;z=b[t+30>>1]|0;A=b[t+28>>1]|0;B=t+32|0;C=c[B>>2]|0;D=t+36|0;E=b[D>>1]|0;do{if(g){F=t+10|0;G=(e[t+18>>1]<<16|e[t+14>>1])-v|0;H=C;I=E&65535;J=o;K=0;while(1){L=(I>>>12)+H|0;M=I&4095;if((L+w|0)>>>0<x>>>0){N=L}else{if((b[F>>1]|0)==0){O=18142;break}else{N=G}}P=a[j+(N+w^1)|0]|0;Q=M+y|0;R=c[m>>2]|0;if((R&1|0)==0){S=0}else{T=+((ag(P,z)|0)>>8|0);S=~~(T*+h[q>>3])}if((R&2|0)==0){U=0}else{T=+((ag(P,z)|0)>>8|0);U=~~(T*+h[q>>3])}R=c[k>>2]|0;if((R&1|0)==0){V=S}else{T=+((ag(P,A)|0)>>8|0);V=~~(T*+h[p>>3])+S|0}if((R&2|0)==0){W=U}else{T=+((ag(P,A)|0)>>8|0);W=~~(T*+h[p>>3])+U|0}P=J+2|0;R=(b[P>>1]|0)+V|0;if((R|0)<-32768){X=-32768}else{X=(R|0)>32767?32767:R&65535}R=(b[J>>1]|0)+W|0;if((R|0)<-32768){Y=-32768}else{Y=(R|0)>32767?32767:R&65535}b[J>>1]=Y;b[P>>1]=X;P=K+1|0;if((P|0)<(l|0)){H=N;I=Q;J=J+4|0;K=P}else{O=18156;break}}if((O|0)==18142){O=0;b[r>>1]=e[r>>1]&(u^65535)&65535;Z=M&65535;_=L;break}else if((O|0)==18156){O=0;Z=Q&65535;_=N;break}}else{Z=E;_=C}}while(0);c[B>>2]=_;b[D>>1]=Z}C=s+1|0;if((C|0)>=16){break L22390}s=C;t=t+40|0}}}while(0);Z=c[2112968]|0;if((Z|0)==0){i=d;return 0}gGz(f|0,0,16);_=c[2406862]|0;N=c[_+108>>2]&255;Q=c[642608+(c[2436]<<2)>>2]|0;O=Q+128|0;L=c[O>>2]|0;M=Q+132|0;do{if((c[_+100>>2]&-65536|0)==40173568){if((L|0)==496){break}if((c[Q+52>>2]&4|0)==0){c[O>>2]=496;c[M>>2]=224}else{c[M>>2]=496;c[O>>2]=224}c[Q+136>>2]=16;c[Q+140>>2]=9;c[2429452]=(c[2113222]|0)+1}else{if((L|0)==384){break}if((c[Q+52>>2]&4|0)==0){c[O>>2]=384;c[M>>2]=224}else{c[M>>2]=384;c[O>>2]=224}c[Q+136>>2]=4;c[Q+140>>2]=3;c[2429452]=(c[2113222]|0)+1}}while(0);Q=N>>>0>128?131072:N<<10;N=c[2438308]|0;O=((ag(N,Q)|0)>>>16)-1|0;c[2438312]=O;M=c[2436758]|0;L=(ag(M,Q)|0)>>>16;X=L-1|0;c[2438310]=X;Y=(O<<2)+4|0;if((X|0)>=0){W=0;V=c[2385750]|0;while(1){gGz(V|0,0,Y|0);U=W+1|0;if((U|0)>(X|0)){break}else{W=U;V=V+4096|0}}}V=c[2411374]|0;W=0;do{X=c[V+((W|1)<<2)>>2]|0;Y=c[V+(W<<2)>>2]|0;U=Y>>>14&2044;S=c[V+((W|2)<<2)>>2]|0;o=S>>>28;t=S>>>27;s=S&33554432;r=S>>>16;l=c[_+((Y>>>28&7)<<2)>>2]|0;p=Y>>>4<<6&131008;if((Y&-268435456|0)==-2147483648){break}if((U|0)!=0){Y=(X>>>16&1023)+1+(l>>>16)|0;k=2030-(X&1023)-l|0;l=(S&536870912|0)==0;X=(S&1073741824|0)==0;q=(S&67108864|0)!=0;S=q^1;m=(r&256|0)==0;j=0;do{g=j+p|0;n=c[V+(g<<2)>>2]|0;C=c[V+((g|1)<<2)>>2]|0;E=c[V+((g|2)<<2)>>2]|0;g=n>>>17;u=C>>>16&1023;A=C&1023;C=n>>>12;z=n>>>11;y=n&1024;w=n&512;x=E>>>24&127;v=E>>>16&127;K=E>>>2&3;J=E&3;L22457:do{if((K|0)!=0){if((J|0)!=0){I=c[591720+(K<<2)>>2]|0;H=c[591720+(J<<2)>>2]|0;G=v+1|0;F=H<<4;P=(G<<16|0)/(F|0)|0;R=x+1|0;$=I<<4;aa=(R<<16|0)/($|0)|0;ab=(C^o)&1;ac=(z^t)&1;ad=(ab|0)!=0;ae=G>>>1;G=(ad?-ae|0:ae)+u|0;ae=(R>>>1)+A|0;if(ad){af=((ag(F-16|0,P)|0)>>>16)+G|0}else{af=G-((ag(F,P)|0)>>>16)|0}F=(ac|0)!=0;if(F){ah=ae-((ag(aa,$-16|0)|0)>>>16)|0}else{ah=ae}ae=P<<4;$=Y+af|0;G=aa<<4;R=k-ah|0;ai=((X?w:s)|0)==0?8:6;aj=((l?n:r)&511)<<ai;ak=(y|0)==0&S;al=(I|0)>1?I:1;am=q?m?aj:aj&65535:aj;an=0;ao=0;while(1){ap=(ag(ae,an)|0)>>>16;aq=$+(ad?-ap|0:ap)|0;ap=(aq&512|0)==0?aq&1023:aq|-1024;if(F){aq=0;ar=ao;while(1){as=R-((ag(aq,G)|0)>>>16)|0;at=(as&512|0)==0?as&1023:as|-1024;as=ar+g|0;do{if((as|0)!=0){if(ak){az7(as,aj,ab,ac,ap,at,P,aa,0);break}else{az7(as,am,ab,ac,ap,at,P,aa,ai);break}}}while(0);at=aq+1|0;if((at|0)<(I|0)){aq=at;ar=ar+1|0}else{break}}}else{ar=0;aq=ao;while(1){at=((ag(ar,G)|0)>>>16)+R|0;as=(at&512|0)==0?at&1023:at|-1024;at=aq+g|0;do{if((at|0)!=0){if(ak){az7(at,aj,ab,0,ap,as,P,aa,0);break}else{az7(at,am,ab,0,ap,as,P,aa,ai);break}}}while(0);as=ar+1|0;if((as|0)<(I|0)){ar=as;aq=aq+1|0}else{break}}}aq=an+1|0;if((aq|0)<(H|0)){an=aq;ao=ao+al|0}else{break L22457}}}al=E>>>4&3;ao=al<<2;an=_+(ao+8<<2)|0;H=f+(al<<2)|0;L22489:do{if((c[H>>2]|0)==0){al=_+(ao+9<<2)|0;I=_+(ao+10<<2)|0;ai=L+3|0;aa=((O|0)/16|0)+2|0;P=(aa|0)>0;ab=c[2385750]|0;am=c[2406894]|0;aj=0;ak=1;while(1){R=aj>>>16;G=c[an>>2]|0;ac=R+4+G|0;F=c[al>>2]|0;do{if((F&32768|0)!=0){ad=c[I>>2]|0;$=G>>>16;if((F&16384|0)==0){au=$}else{au=((c[V+((ad>>>24<<10&130048|ac+12&1023)<<2)>>2]|0)>>>16&1023)+$|0}if(ai>>>0<R>>>0|P^1){break}$=(ad>>>16<<10&130048)+((ac>>>4<<6)+64&4032)|0;ad=(au|0)/16|0;ae=(au|0)%16|0;aq=R<<10;ar=ac<<4&240;ap=0;do{as=c[V+((ap+ad&63|$)<<2)>>2]|0;at=as>>>12&1;av=(as&511)<<(as>>>8&2^2)+6;aw=(ap<<4)-ae+aq|0;ax=ab+(aw<<2)|0;ay=as>>>17<<8|ar;do{if((as&2048|0)==0){az=a[am+ay|0]|0;aA=az<<24>>24!=0;if((at|0)==0){if(aA){c[ax>>2]=az&255|av}aB=a[am+(ay|1)|0]|0;if(aB<<24>>24!=0){c[ab+(aw+1<<2)>>2]=aB&255|av}aB=a[am+(ay|2)|0]|0;if(aB<<24>>24!=0){c[ab+(aw+2<<2)>>2]=aB&255|av}aB=a[am+(ay|3)|0]|0;if(aB<<24>>24!=0){c[ab+(aw+3<<2)>>2]=aB&255|av}aB=a[am+(ay|4)|0]|0;if(aB<<24>>24!=0){c[ab+(aw+4<<2)>>2]=aB&255|av}aB=a[am+(ay|5)|0]|0;if(aB<<24>>24!=0){c[ab+(aw+5<<2)>>2]=aB&255|av}aB=a[am+(ay|6)|0]|0;if(aB<<24>>24!=0){c[ab+(aw+6<<2)>>2]=aB&255|av}aB=a[am+(ay|7)|0]|0;if(aB<<24>>24!=0){c[ab+(aw+7<<2)>>2]=aB&255|av}aB=a[am+(ay|8)|0]|0;if(aB<<24>>24!=0){c[ab+(aw+8<<2)>>2]=aB&255|av}aB=a[am+(ay|9)|0]|0;if(aB<<24>>24!=0){c[ab+(aw+9<<2)>>2]=aB&255|av}aB=a[am+(ay|10)|0]|0;if(aB<<24>>24!=0){c[ab+(aw+10<<2)>>2]=aB&255|av}aB=a[am+(ay|11)|0]|0;if(aB<<24>>24!=0){c[ab+(aw+11<<2)>>2]=aB&255|av}aB=a[am+(ay|12)|0]|0;if(aB<<24>>24!=0){c[ab+(aw+12<<2)>>2]=aB&255|av}aB=a[am+(ay|13)|0]|0;if(aB<<24>>24!=0){c[ab+(aw+13<<2)>>2]=aB&255|av}aB=a[am+(ay|14)|0]|0;if(aB<<24>>24!=0){c[ab+(aw+14<<2)>>2]=aB&255|av}aB=a[am+(ay|15)|0]|0;if(aB<<24>>24==0){break}c[ab+(aw+15<<2)>>2]=aB&255|av;break}else{if(aA){c[ab+(aw+15<<2)>>2]=az&255|av}az=a[am+(ay|1)|0]|0;if(az<<24>>24!=0){c[ab+(aw+14<<2)>>2]=az&255|av}az=a[am+(ay|2)|0]|0;if(az<<24>>24!=0){c[ab+(aw+13<<2)>>2]=az&255|av}az=a[am+(ay|3)|0]|0;if(az<<24>>24!=0){c[ab+(aw+12<<2)>>2]=az&255|av}az=a[am+(ay|4)|0]|0;if(az<<24>>24!=0){c[ab+(aw+11<<2)>>2]=az&255|av}az=a[am+(ay|5)|0]|0;if(az<<24>>24!=0){c[ab+(aw+10<<2)>>2]=az&255|av}az=a[am+(ay|6)|0]|0;if(az<<24>>24!=0){c[ab+(aw+9<<2)>>2]=az&255|av}az=a[am+(ay|7)|0]|0;if(az<<24>>24!=0){c[ab+(aw+8<<2)>>2]=az&255|av}az=a[am+(ay|8)|0]|0;if(az<<24>>24!=0){c[ab+(aw+7<<2)>>2]=az&255|av}az=a[am+(ay|9)|0]|0;if(az<<24>>24!=0){c[ab+(aw+6<<2)>>2]=az&255|av}az=a[am+(ay|10)|0]|0;if(az<<24>>24!=0){c[ab+(aw+5<<2)>>2]=az&255|av}az=a[am+(ay|11)|0]|0;if(az<<24>>24!=0){c[ab+(aw+4<<2)>>2]=az&255|av}az=a[am+(ay|12)|0]|0;if(az<<24>>24!=0){c[ab+(aw+3<<2)>>2]=az&255|av}az=a[am+(ay|13)|0]|0;if(az<<24>>24!=0){c[ab+(aw+2<<2)>>2]=az&255|av}az=a[am+(ay|14)|0]|0;if(az<<24>>24!=0){c[ab+(aw+1<<2)>>2]=az&255|av}az=a[am+(ay|15)|0]|0;if(az<<24>>24==0){break}c[ax>>2]=az&255|av;break}}else{az=ay^240;aA=a[am+az|0]|0;aB=aA<<24>>24!=0;if((at|0)==0){if(aB){c[ax>>2]=aA&255|av}aC=a[am+(az|1)|0]|0;if(aC<<24>>24!=0){c[ab+(aw+1<<2)>>2]=aC&255|av}aC=a[am+(az|2)|0]|0;if(aC<<24>>24!=0){c[ab+(aw+2<<2)>>2]=aC&255|av}aC=a[am+(az|3)|0]|0;if(aC<<24>>24!=0){c[ab+(aw+3<<2)>>2]=aC&255|av}aC=a[am+(az|4)|0]|0;if(aC<<24>>24!=0){c[ab+(aw+4<<2)>>2]=aC&255|av}aC=a[am+(az|5)|0]|0;if(aC<<24>>24!=0){c[ab+(aw+5<<2)>>2]=aC&255|av}aC=a[am+(az|6)|0]|0;if(aC<<24>>24!=0){c[ab+(aw+6<<2)>>2]=aC&255|av}aC=a[am+(az|7)|0]|0;if(aC<<24>>24!=0){c[ab+(aw+7<<2)>>2]=aC&255|av}aC=a[am+(az|8)|0]|0;if(aC<<24>>24!=0){c[ab+(aw+8<<2)>>2]=aC&255|av}aC=a[am+(az|9)|0]|0;if(aC<<24>>24!=0){c[ab+(aw+9<<2)>>2]=aC&255|av}aC=a[am+(az|10)|0]|0;if(aC<<24>>24!=0){c[ab+(aw+10<<2)>>2]=aC&255|av}aC=a[am+(az|11)|0]|0;if(aC<<24>>24!=0){c[ab+(aw+11<<2)>>2]=aC&255|av}aC=a[am+(az|12)|0]|0;if(aC<<24>>24!=0){c[ab+(aw+12<<2)>>2]=aC&255|av}aC=a[am+(az|13)|0]|0;if(aC<<24>>24!=0){c[ab+(aw+13<<2)>>2]=aC&255|av}aC=a[am+(az|14)|0]|0;if(aC<<24>>24!=0){c[ab+(aw+14<<2)>>2]=aC&255|av}aC=a[am+(az|15)|0]|0;if(aC<<24>>24==0){break}c[ab+(aw+15<<2)>>2]=aC&255|av;break}else{if(aB){c[ab+(aw+15<<2)>>2]=aA&255|av}aA=a[am+(az|1)|0]|0;if(aA<<24>>24!=0){c[ab+(aw+14<<2)>>2]=aA&255|av}aA=a[am+(az|2)|0]|0;if(aA<<24>>24!=0){c[ab+(aw+13<<2)>>2]=aA&255|av}aA=a[am+(az|3)|0]|0;if(aA<<24>>24!=0){c[ab+(aw+12<<2)>>2]=aA&255|av}aA=a[am+(az|4)|0]|0;if(aA<<24>>24!=0){c[ab+(aw+11<<2)>>2]=aA&255|av}aA=a[am+(az|5)|0]|0;if(aA<<24>>24!=0){c[ab+(aw+10<<2)>>2]=aA&255|av}aA=a[am+(az|6)|0]|0;if(aA<<24>>24!=0){c[ab+(aw+9<<2)>>2]=aA&255|av}aA=a[am+(az|7)|0]|0;if(aA<<24>>24!=0){c[ab+(aw+8<<2)>>2]=aA&255|av}aA=a[am+(az|8)|0]|0;if(aA<<24>>24!=0){c[ab+(aw+7<<2)>>2]=aA&255|av}aA=a[am+(az|9)|0]|0;if(aA<<24>>24!=0){c[ab+(aw+6<<2)>>2]=aA&255|av}aA=a[am+(az|10)|0]|0;if(aA<<24>>24!=0){c[ab+(aw+5<<2)>>2]=aA&255|av}aA=a[am+(az|11)|0]|0;if(aA<<24>>24!=0){c[ab+(aw+4<<2)>>2]=aA&255|av}aA=a[am+(az|12)|0]|0;if(aA<<24>>24!=0){c[ab+(aw+3<<2)>>2]=aA&255|av}aA=a[am+(az|13)|0]|0;if(aA<<24>>24!=0){c[ab+(aw+2<<2)>>2]=aA&255|av}aA=a[am+(az|14)|0]|0;if(aA<<24>>24!=0){c[ab+(aw+1<<2)>>2]=aA&255|av}aA=a[am+(az|15)|0]|0;if(aA<<24>>24==0){break}c[ax>>2]=aA&255|av;break}}}while(0);ap=ap+1|0;}while((ap|0)<(aa|0))}}while(0);if((ak|0)>=224){break L22489}aj=aj+Q|0;ak=ak+1|0}}}while(0);c[H>>2]=1}}while(0);j=j+4|0;}while((j|0)<(U|0))}W=W+4|0;}while((W|0)<2048);W=Z;Z=c[2385750]|0;V=c[3542046]|0;au=0;O=W;L=1;while(1){_=au>>>16<<10;if((N|0)>0){f=0;ah=O;af=0;while(1){b[ah>>1]=b[V+(c[Z+((f>>>16)+_<<2)>>2]<<1)>>1]|0;U=af+1|0;j=ah+2|0;if((U|0)<(N|0)){f=f+Q|0;ah=j;af=U}else{aD=j;break}}}else{aD=O}if((L|0)>=224){break}au=au+Q|0;O=aD;L=L+1|0}L=c[2418168]|0;aD=M-8|0;M=-N|0;O=(c[2440194]|0)>>>13&2048^2048;Q=0;while(1){au=Q<<3;Z=(aD|0)<(au|0);af=O;ah=0;while(1){f=c[L+(af<<2)>>2]|0;_=f>>>16&511;do{if((_|0)!=0){j=f&128;U=ah<<3;if((N-8|0)<(U|0)|Z){break}m=(c[2443700]<<5|f>>>1&31)<<4;q=U+(ag(N,au)|0)|0;U=W+(q<<1)|0;S=L+((_<<4|8192)<<2)|0;if((f&64|0)==0){if((j|0)==0){r=S;l=U;s=0;while(1){X=r+2|0;k=a[X]|0;Y=k&15;if((Y|0)==0){aE=k}else{b[l>>1]=b[V+((Y|m)<<1)>>1]|0;aE=a[X]|0}X=(aE&255)>>>4;if((X|0)!=0){b[l+2>>1]=b[V+((X|m)<<1)>>1]|0}X=a[r]|0;Y=X&15;if((Y|0)==0){aF=X}else{b[l+4>>1]=b[V+((Y|m)<<1)>>1]|0;aF=a[r]|0}Y=(aF&255)>>>4;if((Y|0)!=0){b[l+6>>1]=b[V+((Y|m)<<1)>>1]|0}Y=r+6|0;X=a[Y]|0;k=X&15;if((k|0)==0){aG=X}else{b[l+8>>1]=b[V+((k|m)<<1)>>1]|0;aG=a[Y]|0}Y=(aG&255)>>>4;if((Y|0)!=0){b[l+10>>1]=b[V+((Y|m)<<1)>>1]|0}Y=r+4|0;k=a[Y]|0;X=k&15;if((X|0)==0){aH=k}else{b[l+12>>1]=b[V+((X|m)<<1)>>1]|0;aH=a[Y]|0}Y=(aH&255)>>>4;if((Y|0)!=0){b[l+14>>1]=b[V+((Y|m)<<1)>>1]|0}Y=s+1|0;if((Y|0)<8){r=r+8|0;l=l+(N<<1)|0;s=Y}else{break}}}else{s=S;l=U;r=0;while(1){H=s+2|0;Y=a[H]|0;X=Y&15;if((X|0)==0){aI=Y}else{b[l+14>>1]=b[V+((X|m)<<1)>>1]|0;aI=a[H]|0}H=(aI&255)>>>4;if((H|0)!=0){b[l+12>>1]=b[V+((H|m)<<1)>>1]|0}H=a[s]|0;X=H&15;if((X|0)==0){aJ=H}else{b[l+10>>1]=b[V+((X|m)<<1)>>1]|0;aJ=a[s]|0}X=(aJ&255)>>>4;if((X|0)!=0){b[l+8>>1]=b[V+((X|m)<<1)>>1]|0}X=s+6|0;H=a[X]|0;Y=H&15;if((Y|0)==0){aK=H}else{b[l+6>>1]=b[V+((Y|m)<<1)>>1]|0;aK=a[X]|0}X=(aK&255)>>>4;if((X|0)!=0){b[l+4>>1]=b[V+((X|m)<<1)>>1]|0}X=s+4|0;Y=a[X]|0;H=Y&15;if((H|0)==0){aL=Y}else{b[l+2>>1]=b[V+((H|m)<<1)>>1]|0;aL=a[X]|0}X=(aL&255)>>>4;if((X|0)!=0){b[l>>1]=b[V+((X|m)<<1)>>1]|0}X=r+1|0;if((X|0)<8){s=s+8|0;l=l+(N<<1)|0;r=X}else{break}}}}else{r=W+(q+(N*7|0)<<1)|0;if((j|0)==0){l=S;s=r;U=0;while(1){X=l+2|0;H=a[X]|0;Y=H&15;if((Y|0)==0){aM=H}else{b[s>>1]=b[V+((Y|m)<<1)>>1]|0;aM=a[X]|0}X=(aM&255)>>>4;if((X|0)!=0){b[s+2>>1]=b[V+((X|m)<<1)>>1]|0}X=a[l]|0;Y=X&15;if((Y|0)==0){aN=X}else{b[s+4>>1]=b[V+((Y|m)<<1)>>1]|0;aN=a[l]|0}Y=(aN&255)>>>4;if((Y|0)!=0){b[s+6>>1]=b[V+((Y|m)<<1)>>1]|0}Y=l+6|0;X=a[Y]|0;H=X&15;if((H|0)==0){aO=X}else{b[s+8>>1]=b[V+((H|m)<<1)>>1]|0;aO=a[Y]|0}Y=(aO&255)>>>4;if((Y|0)!=0){b[s+10>>1]=b[V+((Y|m)<<1)>>1]|0}Y=l+4|0;H=a[Y]|0;X=H&15;if((X|0)==0){aP=H}else{b[s+12>>1]=b[V+((X|m)<<1)>>1]|0;aP=a[Y]|0}Y=(aP&255)>>>4;if((Y|0)!=0){b[s+14>>1]=b[V+((Y|m)<<1)>>1]|0}Y=U+1|0;if((Y|0)<8){l=l+8|0;s=s+(M<<1)|0;U=Y}else{break}}}else{U=S;s=r;l=0;while(1){j=U+2|0;q=a[j]|0;Y=q&15;if((Y|0)==0){aQ=q}else{b[s+14>>1]=b[V+((Y|m)<<1)>>1]|0;aQ=a[j]|0}j=(aQ&255)>>>4;if((j|0)!=0){b[s+12>>1]=b[V+((j|m)<<1)>>1]|0}j=a[U]|0;Y=j&15;if((Y|0)==0){aR=j}else{b[s+10>>1]=b[V+((Y|m)<<1)>>1]|0;aR=a[U]|0}Y=(aR&255)>>>4;if((Y|0)!=0){b[s+8>>1]=b[V+((Y|m)<<1)>>1]|0}Y=U+6|0;j=a[Y]|0;q=j&15;if((q|0)==0){aS=j}else{b[s+6>>1]=b[V+((q|m)<<1)>>1]|0;aS=a[Y]|0}Y=(aS&255)>>>4;if((Y|0)!=0){b[s+4>>1]=b[V+((Y|m)<<1)>>1]|0}Y=U+4|0;q=a[Y]|0;j=q&15;if((j|0)==0){aT=q}else{b[s+2>>1]=b[V+((j|m)<<1)>>1]|0;aT=a[Y]|0}Y=(aT&255)>>>4;if((Y|0)!=0){b[s>>1]=b[V+((Y|m)<<1)>>1]|0}Y=l+1|0;if((Y|0)<8){U=U+8|0;s=s+(M<<1)|0;l=Y}else{break}}}}}}while(0);f=ah+1|0;if((f|0)<64){af=af+1|0;ah=f}else{break}}ah=Q+1|0;if((ah|0)<28){O=O+64|0;Q=ah}else{break}}i=d;return 0}function az6(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;e=i;i=i+256|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;l=e+80|0;m=e+96|0;n=e+112|0;o=e+128|0;p=e+144|0;q=e+160|0;r=e+176|0;s=e+192|0;t=e+208|0;u=e+224|0;v=e+240|0;if((d|0)!=0){c[d>>2]=169586}if((b&8|0)!=0){c[v>>2]=c[2414458];c[v+4>>2]=1024;c[v+8>>2]=0;c[v+12>>2]=195592;d=c[2076592]|0;gj[d&4095](v)|0}if((b&32|0)!=0){d=v|0;c[d>>2]=c[2406892];w=v+4|0;c[w>>2]=524288;x=v+8|0;c[x>>2]=0;y=v+12|0;c[y>>2]=510816;z=c[2076592]|0;gj[z&4095](v)|0;c[d>>2]=c[2411374];c[w>>2]=524288;c[x>>2]=0;c[y>>2]=392744;z=c[2076592]|0;gj[z&4095](v)|0;c[d>>2]=c[2418168];c[w>>2]=65536;c[x>>2]=0;c[y>>2]=306336;z=c[2076592]|0;gj[z&4095](v)|0;c[d>>2]=c[2406862];c[w>>2]=256;c[x>>2]=0;c[y>>2]=233512;z=c[2076592]|0;gj[z&4095](v)|0;c[d>>2]=c[2406896];c[w>>2]=2048;c[x>>2]=0;c[y>>2]=182152;z=c[2076592]|0;gj[z&4095](v)|0;c[d>>2]=c[2411434];c[w>>2]=262144;c[x>>2]=0;c[y>>2]=426800;z=c[2076592]|0;gj[z&4095](v)|0;c[d>>2]=c[2406894];c[w>>2]=8388608;c[x>>2]=0;c[y>>2]=117480;y=c[2076592]|0;gj[y&4095](v)|0}if((b&64|0)==0){i=e;return 0}ge4(b);v=c[2420434]|0;gGz(g|0,0,12);c[g>>2]=v;c[g+4>>2]=640;c[g+12>>2]=197912;gj[c[2076592]&4095](g)|0;g=(c[2420434]|0)+640|0;gGz(f|0,0,12);c[f>>2]=g;c[f+4>>2]=2;c[f+12>>2]=511320;gj[c[2076592]&4095](f)|0;gGz(u|0,0,12);c[u>>2]=9553312;c[u+4>>2]=8;c[u+12>>2]=92424;gj[c[2076592]&4095](u)|0;gGz(t|0,0,12);c[t>>2]=9760776;c[t+4>>2]=4;c[t+12>>2]=72344;gj[c[2076592]&4095](t)|0;gGz(s|0,0,12);c[s>>2]=9774800;c[s+4>>2]=4;c[s+12>>2]=580136;gj[c[2076592]&4095](s)|0;gGz(r|0,0,12);c[r>>2]=9542800;c[r+4>>2]=4;c[r+12>>2]=563232;gj[c[2076592]&4095](r)|0;gGz(q|0,0,12);c[q>>2]=9708016;c[q+4>>2]=2;c[q+12>>2]=547120;gj[c[2076592]&4095](q)|0;gGz(p|0,0,12);c[p>>2]=9757152;c[p+4>>2]=4;c[p+12>>2]=533176;gj[c[2076592]&4095](p)|0;gGz(o|0,0,12);c[o>>2]=9755736;c[o+4>>2]=4;c[o+12>>2]=519712;gj[c[2076592]&4095](o)|0;gGz(n|0,0,12);c[n>>2]=9775032;c[n+4>>2]=4;c[n+12>>2]=506168;gj[c[2076592]&4095](n)|0;gGz(m|0,0,12);c[m>>2]=9775024;c[m+4>>2]=4;c[m+12>>2]=494304;gj[c[2076592]&4095](m)|0;gGz(l|0,0,12);c[l>>2]=9755744;c[l+4>>2]=4;c[l+12>>2]=482184;gj[c[2076592]&4095](l)|0;gGz(k|0,0,12);c[k>>2]=9753280;c[k+4>>2]=4;c[k+12>>2]=469464;gj[c[2076592]&4095](k)|0;gGz(j|0,0,12);c[j>>2]=9717192;c[j+4>>2]=4;c[j+12>>2]=458160;gj[c[2076592]&4095](j)|0;gGz(h|0,0,12);c[h>>2]=9757200;c[h+4>>2]=4;c[h+12>>2]=448072;gj[c[2076592]&4095](h)|0;if((b&2|0)==0){i=e;return 0}a[9533936]=1;b=(c[2406894]|0)+(c[2385700]<<18<<2)|0;h=(c[2406668]|0)+6572|0;j=0;k=68157440;while(1){l=b+(k-68157440)|0;c[h>>2]=l;c[h+262144>>2]=l;c[h+524288>>2]=l;c[h+8192>>2]=l;c[h+16384>>2]=l;c[h+24576>>2]=l;c[h+32768>>2]=l;c[h+40960>>2]=l;c[h+49152>>2]=l;c[h+57344>>2]=l;c[h+270336>>2]=l;c[h+278528>>2]=l;c[h+286720>>2]=l;c[h+294912>>2]=l;c[h+303104>>2]=l;c[h+311296>>2]=l;c[h+319488>>2]=l;c[h+532480>>2]=l;c[h+540672>>2]=l;c[h+548864>>2]=l;c[h+557056>>2]=l;c[h+565248>>2]=l;c[h+573440>>2]=l;c[h+581632>>2]=l;l=gGK(k,j,65536,0)|0;m=K;n=0;if(m>>>0>n>>>0|m>>>0==n>>>0&l>>>0>69206015>>>0){break}else{h=h+4|0;j=m;k=l}}i=e;return 0}function az7(b,e,f,g,h,i,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;m=c[2406894]|0;n=b<<6;b=(k<<4)+32768>>16;k=(j<<4)+32768>>16;if((k|0)==0|(b|0)==0){return}j=1048576/(k|0)|0;o=1048576/(b|0)|0;p=k+h|0;q=b+i|0;if((f|0)==0){r=j;s=0}else{r=-j|0;s=ag(j,k-1|0)|0}if((g|0)==0){t=o;u=0}else{t=-o|0;u=ag(o,b-1|0)|0}if((h|0)<0){v=0;w=s-(ag(r,h)|0)|0}else{v=h;w=s}if((i|0)<0){x=0;y=u-(ag(t,i)|0)|0}else{x=i;y=u}u=(c[2438312]|0)+1|0;i=(p|0)>(u|0)?u:p;p=(c[2438310]|0)+1|0;u=(q|0)>(p|0)?p:q;if((i|0)<=(v|0)){return}if((l|0)==6){if((x|0)>=(u|0)){return}q=c[2385750]|0;p=y;s=x;while(1){h=m+((p>>16<<2)+n<<2)|0;b=s<<10;o=w;g=v;while(1){k=q+(g+b<<2)|0;c[k>>2]=d[h+(o>>16)|0]<<13&122880|c[k>>2];k=g+1|0;if((k|0)<(i|0)){o=o+r|0;g=k}else{break}}g=s+1|0;if((g|0)<(u|0)){p=p+t|0;s=g}else{break}}return}else if((l|0)==0){if((x|0)>=(u|0)){return}s=c[2385750]|0;p=x;q=y;while(1){g=m+((q>>16<<2)+n<<2)|0;o=p<<10;h=w;b=v;while(1){k=a[g+(h>>16)|0]|0;if(k<<24>>24!=0){c[s+(b+o<<2)>>2]=k&255|e}k=b+1|0;if((k|0)<(i|0)){h=h+r|0;b=k}else{break}}b=p+1|0;if((b|0)>=(u|0)){break}p=b;q=q+t|0}return}else if((l|0)==8){if((x|0)>=(u|0)){return}l=(e&65536|0)==0;e=c[2385750]|0;q=y;y=x;while(1){x=m+((q>>16<<2)+n<<2)|0;p=y<<10;if(l){s=w;b=v;while(1){if((a[x+(s>>16)|0]|0)!=0){h=e+(b+p<<2)|0;c[h>>2]=c[h>>2]|32768}h=b+1|0;if((h|0)<(i|0)){s=s+r|0;b=h}else{break}}}else{b=w;s=v;while(1){if((a[x+(b>>16)|0]|0)!=0){h=e+(s+p<<2)|0;c[h>>2]=c[h>>2]|98304}h=s+1|0;if((h|0)<(i|0)){b=b+r|0;s=h}else{break}}}s=y+1|0;if((s|0)>=(u|0)){break}q=q+t|0;y=s}return}else{return}}function az8(d,e){d=d|0;e=e|0;if((d&-16|0)==3145728){b[(c[2383434]|0)+((d>>>1&7)<<1)>>1]=e;return}if(!((d|0)==1048576|(d|0)==1703936)){return}c[2383412]=e&255;if((a[9661085]|0)==1){return}a[9661085]=1;if((a[9661088]|0)!=0){return}a[9661088]=2;return}function az9(b,d){b=b|0;d=d|0;if(!((b|0)==1048577|(b|0)==1703937)){return}c[2383412]=d&255;if((a[9661085]|0)==1){return}a[9661085]=1;if((a[9661088]|0)!=0){return}a[9661088]=2;return}function aAa(a){a=a|0;var e=0;if((a&-16|0)==3145728){e=b[(c[2383434]|0)+((a>>>1&7)<<1)>>1]|0;return e|0}if((a|0)==1572866){e=(d[9635761]|0)<<8|(d[9635760]|0);return e|0}else if((a|0)==1572872){e=(b[4775525]&65527|c[2383408]&8)&65535;return e|0}else if((a|0)==1572864){e=b[4775524]|0;return e|0}else{e=0;return e|0}return 0}function aAb(d){d=d|0;var f=0;switch(d|0){case 1572866:{f=a[9635760]|0;break};case 1572864:case 1572865:{f=(e[4775524]|0)>>>((d<<3&8^8)>>>0)&255;break};case 1572867:{f=a[9635761]|0;break};case 1572872:case 1572873:{f=(b[4775525]&247|c[2383408]&8)&255;break};default:{f=0}}return f|0}function aAc(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2194772+(b*112|0)>>2];c[a+104>>2]=c[2194776+(b*112|0)>>2];c[a+108>>2]=c[2194780+(b*112|0)>>2];d=0;return d|0}function aAd(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=2194672+(b*112|0);e=0;return e|0}function aAe(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1186504+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aAf(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>37){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3343920+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aAg(){return aAt(1)|0}function aAh(){var a=0,b=0,d=0,e=0,f=0;c[2113070]=0;c[2113068]=0;a=c[2112926]|0;if((a|0)!=0){gGr(a);c[2112926]=0}aE2();if((c[2392]|0)>=0){a=0;do{b=14130368+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}b=14130384+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}a=a+1|0;}while((a|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;aFe();a=c[2415120]|0;b=0;while(1){if((b|0)>=1024){e=18301;break}f=9638528+(b<<2)|0;if((c[f>>2]|0)==(a|0)){break}else{b=b+1|0}}if((e|0)==18301){c[2415120]=0;return 0}gGr(a);c[f>>2]=0;c[2415120]=0;return 0}function aAi(){var d=0,e=0,f=0,g=0,h=0,i=0;if((a[9623712]|0)!=0){d=c[2414828]|0;gGz(d|0,0,(c[2411538]|0)-d|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;aE7();gGz(c[2383428]|0,0,4096);gGz(c[2383426]|0,0,4096);d=c[2383424]|0;if((d|0)!=0){gGz(d|0,0,4096);gGz(c[2383422]|0,0,4096)}gGz(c[2383434]|0,0,16);gGz(c[2383435]|0,0,16);gGz(c[2383430]|0,0,8192);gGz(c[2383431]|0,0,8192);d=c[2383432]|0;if((d|0)!=0){gGz(d|0,0,8192);gGz(c[2383433]|0,0,8192)}b[4766836]=0;c[2426968]=0;c[3528794]=0;c[1765522]=65535;c[2429656]=0;c[2427042]=0;c[2429386]=0;c[2429384]=0;c[2429382]=0}c[2387762]=-1;d=0;e=-1;f=-1;do{e=((a[9632760+d|0]&1)<<d^e&65535)&65535;f=((a[9630656+d|0]&1)<<d^f&65535)&65535;d=d+1|0;}while((d|0)<16);b[4775524]=e;b[4775525]=f;c[(c[2391608]|0)+60>>2]=0;c[(c[2391608]|0)+60>>2]=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060]}c[2388530]=9554128;f=c[2391608]|0;if((f|0)!=0){e=f;gGC(9661040,e|0,68)|0}c[2382]=0;c[2383408]=0;e=0;f=0;while(1){c[2113056]=942;d=RG(942)|0;c[2113054]=(c[2113054]|0)+d;c[2276108]=-1;c[2113056]=-1;fy_(271)|0;if((e|0)==240){c[2383408]=8}d=c[2112964]|0;if((d|0)==0){g=f}else{h=a[9688]|0?2:0;i=d+(f<<1<<1)|0;if(a[801408]|0){gg[c[3542124]&4095](i,h)}if(a[801400]|0){Uu(0,i,h)}if((c[2429658]|0)!=0){Uu(1,i,h)}g=h+f|0}h=e+1|0;if((h|0)<256){e=h;f=g}else{break}}c[8452200+(c[2394]<<2)>>2]=8198;c[2276080]=1536;if((c[2276079]|0)>>>0<1536){RH(6)}f=c[2112964]|0;do{if((f|0)!=0){e=a[9688]|0?534:0;if((e|0)==(g|0)){break}h=e-g|0;e=f+(g<<1<<1)|0;if(a[801408]|0){gg[c[3542124]&4095](e,h)}if(a[801400]|0){Uu(0,e,h)}if((c[2429658]|0)==0){break}Uu(1,e,h)}}while(0);g=c[(c[2388530]|0)+12304>>2]|0;if((g|0)!=0){f=g;gGC(f|0,9661040,68)|0}c[2382]=-1;f=c[2394]|0;g=c[14130368+(f<<2)>>2]|0;if((g|0)!=0){gGC(g|0,9104152,280)|0}c[8452240+(f<<2)>>2]=c[2113054];c[2394]=-1;if((c[2112968]|0)==0){return 0}aAj()|0;return 0}function aAj(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;d=c[2387298]|0;f=c[3530214]|0;g=0;do{h=e[d+(g<<1)>>1]|0;i=h>>>8;j=h>>>4&15;c[f+(g<<2)>>2]=(i&8|i<<4)>>>3&31|(h&8|h<<4)<<8&63488|(j<<4|j)<<3&2016;g=g+1|0;}while((g|0)<1024);a[9548088]=0;aE3();g=ag(c[2113070]|0,c[2113068]|0)|0;f=c[2112926]|0;if((g|0)>0){d=0;while(1){b[f+(d<<1)>>1]=768;j=d+1|0;if((j|0)<(g|0)){d=j}else{k=f;break}}}else{k=f}aE0(1,k,65536);f=c[2386544]|0;d=c[3528670]|0;g=c[3530496]|0;j=(c[2113222]&1|0)==0;h=0;do{i=e[f+(h<<1)>>1]|0;l=e[f+((h|2)<<1)>>1]|0;do{if((i&4096|0)==0|j){m=l>>>9&31;n=i&8192;o=i&16384;p=1<<(i>>>9&3);q=p-1|0;r=l&511;s=i&511;t=r>>>0>319?l|-512:r;r=s>>>0>255?i|-512:s;s=((o|0)==0?q:0)+(-p&e[f+((h|1)<<1)>>1])|0;u=(o>>>13^2)-1|0;if((a[d]|0)==0){v=o;w=n;x=-16;y=304-t|0;z=240-r|0}else{v=o>>>14^1;w=n>>>13^1;x=16;y=t;z=r}if(!((y+15|0)>>>0<335&(p|0)>0)){break}p=z-8|0;r=(w|0)!=0;if((v|0)==0){if(r){t=q;while(1){n=s-(ag(t,u)|0)|0;SJ(k,n&16383,y,(ag(t,x)|0)+p|0,m,4,0,0,g);if((t|0)>0){t=t-1|0}else{break}}}else{t=q;while(1){n=s-(ag(t,u)|0)|0;SH(k,n&16383,y,(ag(t,x)|0)+p|0,m,4,0,0,g);if((t|0)>0){t=t-1|0}else{break}}}}else{if(r){t=q;while(1){n=(ag(t,x)|0)+p|0;SN(k,s-(ag(t,u)|0)&16383,y,n,m,4,0,0,g);if((t|0)>0){t=t-1|0}else{break}}}else{t=q;while(1){r=(ag(t,x)|0)+p|0;SL(k,s-(ag(t,u)|0)&16383,y,r,m,4,0,0,g);if((t|0)>0){t=t-1|0}else{break}}}}}}while(0);h=h+4|0;}while((h|0)<1024);aE0(0,k,0);R8(c[3530214]|0);return 0}function aAk(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=i;i=i+64|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;if((d|0)!=0){c[d>>2]=169762}if((b&32|0)!=0){gGz(j|0,0,12);k=c[2414828]|0;c[j>>2]=k;c[j+4>>2]=(c[2411538]|0)-k;c[j+12>>2]=162152;k=c[2076592]|0;gj[k&4095](j)|0}if((b&64|0)==0){i=e;return 0}j=h|0;gGz(g|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){k=h+9|0;h=f;l=f|0;m=f+4|0;n=f+12|0;o=g|0;p=g+4|0;q=g+12|0;r=0;do{gGC(j|0,614896,11)|0;a[k]=r+48&255;s=8452256+(r<<2)|0;gGz(h|0,0,12);c[l>>2]=s;c[m>>2]=4;c[n>>2]=164976;gj[c[2076592]&4095](f)|0;if((c[s>>2]|0)!=0){c[o>>2]=c[14130368+(r<<2)>>2];c[p>>2]=c[8452184+(r<<2)>>2];c[q>>2]=j;s=c[2076592]|0;gj[s&4095](g)|0}r=r+1|0;}while((r|0)<=(c[2392]|0))}aFf(b,d);aE6();i=e;return 0}function aAl(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1385284+(b*112|0)>>2];c[a+104>>2]=c[1385288+(b*112|0)>>2];c[a+108>>2]=c[1385292+(b*112|0)>>2];d=0;return d|0}function aAm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=1385184+(b*112|0);e=0;return e|0}function aAn(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1384500+(b*112|0)>>2];c[a+104>>2]=c[1384504+(b*112|0)>>2];c[a+108>>2]=c[1384508+(b*112|0)>>2];d=0;return d|0}function aAo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=1384400+(b*112|0);e=0;return e|0}function aAp(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3015844+(b*112|0)>>2];c[a+104>>2]=c[3015848+(b*112|0)>>2];c[a+108>>2]=c[3015852+(b*112|0)>>2];d=0;return d|0}function aAq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=3015744+(b*112|0);e=0;return e|0}function aAr(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>35){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4161648+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aAs(){return aAt(0)|0}function aAt(d){d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;e=i;i=i+360|0;f=e|0;g=e+112|0;h=e+120|0;j=e+232|0;k=e+240|0;l=e+352|0;c[2424]=5800;c[2415120]=0;c[2388192]=0;c[2387784]=262144;c[3530966]=327680;c[3530732]=1376256;c[3530496]=2424832;c[3541206]=4521984;c[2386710]=4521984;c[3530214]=4784128;c[2414828]=4788224;c[2388310]=4788224;c[2387806]=4804608;c[2386544]=4812800;c[2387298]=4814848;c[3528670]=4816896;c[2411538]=4816897;m=0;while(1){if((m|0)>=1024){break}n=9638528+(m<<2)|0;if((c[n>>2]|0)==0){o=18433;break}else{m=m+1|0}}do{if((o|0)==18433){m=gGq(4816897)|0;c[n>>2]=m;if((m|0)==0){break}c[2415120]=m;gGz(m|0,0,4816897);c[2388192]=m;c[2387784]=m+262144;c[3530966]=m+327680;c[3530732]=m+1376256;c[3530496]=m+2424832;p=m+4521984|0;c[3541206]=p;c[2386710]=p;c[3530214]=m+4784128;p=m+4788224|0;c[2414828]=p;c[2388310]=p;c[2387806]=m+4804608;c[2386544]=m+4812800;c[2387298]=m+4814848;c[3528670]=m+4816896;p=m+4816897|0;c[2411538]=p;c[2414078]=p;if((R6(m+1|0,0,2)|0)!=0){q=1;i=e;return q|0}if((R6(c[2388192]|0,1,2)|0)!=0){q=1;i=e;return q|0}m=c[2387784]|0;if((c[3542200]|0)==0){q=1;i=e;return q|0}p=k+108|0;c[p>>2]=0;r=k+100|0;c[r>>2]=0;s=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[s&16383](k,2)|0;do{if((c[p>>2]|0)!=0){s=c[r>>2]|0;c[l>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](l,2,0)|0;if((s|0)<1){q=1;i=e;return q|0}if((gzL(m,0,2)|0)==0){break}else{q=1}i=e;return q|0}}while(0);m=c[3530732]|0;if((c[3542200]|0)==0){q=1;i=e;return q|0}r=h+108|0;c[r>>2]=0;p=h+100|0;c[p>>2]=0;s=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[s&16383](h,3)|0;do{if((c[r>>2]|0)!=0){s=c[p>>2]|0;c[j>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](j,3,0)|0;if((s|0)<1){q=1;i=e;return q|0}if((gzL(m,0,3)|0)==0){break}else{q=1}i=e;return q|0}}while(0);if((R6((c[3530496]|0)+1|0,4,2)|0)!=0){q=1;i=e;return q|0}if((R6(c[3530496]|0,5,2)|0)!=0){q=1;i=e;return q|0}m=c[2386710]|0;if((c[3542200]|0)==0){q=1;i=e;return q|0}p=f+108|0;c[p>>2]=0;r=f+100|0;c[r>>2]=0;s=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[s&16383](f,6)|0;do{if((c[p>>2]|0)!=0){s=c[r>>2]|0;c[g>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](g,6,0)|0;if((s|0)<1){q=1;i=e;return q|0}if((gzL(m,0,6)|0)==0){break}else{q=1}i=e;return q|0}}while(0);aE_(c[3530732]|0,c[3530966]|0,524288,1);m=c[3530732]|0;aE_(m,m,524288,0);aE$(c[3530496]|0,1048576);aE1(1,0,1);m=c[3530732]|0;c[2383440]=c[3530966];c[2383441]=m;c[2383442]=0;c[2383436]=16383;c[2383437]=4095;c[2383438]=0;c[2429666]=256;c[2429667]=512;a[690376]=1;fxU(0,425984);if((c[2394]|0)==0){u=c[2112932]|0}else{c[2394]=0;m=c[3532596]|0;c[2112932]=m;r=c[3532592]|0;if((r|0)!=0){gGC(9104152,r|0,280)|0}c[2113054]=c[2113060];u=m}m=c[2388192]|0;r=u|0;p=0;while(1){s=m+p|0;c[r>>2]=s;c[r+131072>>2]=s;s=p+1024|0;if(s>>>0>262143){break}else{r=r+4|0;p=s}}p=c[2388310]|0;if((d|0)==0){c[u+6656>>2]=p;c[u+72192>>2]=p;c[u+137728>>2]=p;r=p+1024|0;c[u+6660>>2]=r;c[u+72196>>2]=r;c[u+137732>>2]=r;r=p+2048|0;c[u+6664>>2]=r;c[u+72200>>2]=r;c[u+137736>>2]=r;r=p+3072|0;c[u+6668>>2]=r;c[u+72204>>2]=r;c[u+137740>>2]=r;r=p+4096|0;c[u+6672>>2]=r;c[u+72208>>2]=r;c[u+137744>>2]=r;r=p+5120|0;c[u+6676>>2]=r;c[u+72212>>2]=r;c[u+137748>>2]=r;r=p+6144|0;c[u+6680>>2]=r;c[u+72216>>2]=r;c[u+137752>>2]=r;r=p+7168|0;c[u+6684>>2]=r;c[u+72220>>2]=r;c[u+137756>>2]=r;r=p+8192|0;c[u+6688>>2]=r;c[u+72224>>2]=r;c[u+137760>>2]=r;r=p+9216|0;c[u+6692>>2]=r;c[u+72228>>2]=r;c[u+137764>>2]=r;r=p+10240|0;c[u+6696>>2]=r;c[u+72232>>2]=r;c[u+137768>>2]=r;r=p+11264|0;c[u+6700>>2]=r;c[u+72236>>2]=r;c[u+137772>>2]=r;r=p+12288|0;c[u+6704>>2]=r;c[u+72240>>2]=r;c[u+137776>>2]=r;r=p+13312|0;c[u+6708>>2]=r;c[u+72244>>2]=r;c[u+137780>>2]=r;r=p+14336|0;c[u+6712>>2]=r;c[u+72248>>2]=r;c[u+137784>>2]=r;r=p+15360|0;c[u+6716>>2]=r;c[u+72252>>2]=r;c[u+137788>>2]=r}else{c[u+4096>>2]=p;c[u+69632>>2]=p;c[u+135168>>2]=p;r=p+1024|0;c[u+4100>>2]=r;c[u+69636>>2]=r;c[u+135172>>2]=r;r=p+2048|0;c[u+4104>>2]=r;c[u+69640>>2]=r;c[u+135176>>2]=r;r=p+3072|0;c[u+4108>>2]=r;c[u+69644>>2]=r;c[u+135180>>2]=r;r=p+4096|0;c[u+4112>>2]=r;c[u+69648>>2]=r;c[u+135184>>2]=r;r=p+5120|0;c[u+4116>>2]=r;c[u+69652>>2]=r;c[u+135188>>2]=r;r=p+6144|0;c[u+4120>>2]=r;c[u+69656>>2]=r;c[u+135192>>2]=r;r=p+7168|0;c[u+4124>>2]=r;c[u+69660>>2]=r;c[u+135196>>2]=r;r=p+8192|0;c[u+4128>>2]=r;c[u+69664>>2]=r;c[u+135200>>2]=r;r=p+9216|0;c[u+4132>>2]=r;c[u+69668>>2]=r;c[u+135204>>2]=r;r=p+10240|0;c[u+4136>>2]=r;c[u+69672>>2]=r;c[u+135208>>2]=r;r=p+11264|0;c[u+4140>>2]=r;c[u+69676>>2]=r;c[u+135212>>2]=r;r=p+12288|0;c[u+4144>>2]=r;c[u+69680>>2]=r;c[u+135216>>2]=r;r=p+13312|0;c[u+4148>>2]=r;c[u+69684>>2]=r;c[u+135220>>2]=r;r=p+14336|0;c[u+4152>>2]=r;c[u+69688>>2]=r;c[u+135224>>2]=r;r=p+15360|0;c[u+4156>>2]=r;c[u+69692>>2]=r;c[u+135228>>2]=r}r=c[2386544]|0;c[u+4608>>2]=r;c[u+70144>>2]=r;c[u+135680>>2]=r;p=r+1024|0;c[u+4612>>2]=p;c[u+70148>>2]=p;c[u+135684>>2]=p;p=c[2387298]|0;c[u+5120>>2]=p;c[u+70656>>2]=p;c[u+136192>>2]=p;r=p+1024|0;c[u+5124>>2]=r;c[u+70660>>2]=r;c[u+136196>>2]=r;r=c[2383430]|0;c[u+12800>>2]=r;c[u+78336>>2]=r;c[u+143872>>2]=r;p=r+1024|0;c[u+12804>>2]=p;c[u+78340>>2]=p;c[u+143876>>2]=p;p=r+2048|0;c[u+12808>>2]=p;c[u+78344>>2]=p;c[u+143880>>2]=p;p=r+3072|0;c[u+12812>>2]=p;c[u+78348>>2]=p;c[u+143884>>2]=p;p=r+4096|0;c[u+12816>>2]=p;c[u+78352>>2]=p;c[u+143888>>2]=p;p=r+5120|0;c[u+12820>>2]=p;c[u+78356>>2]=p;c[u+143892>>2]=p;p=r+6144|0;c[u+12824>>2]=p;c[u+78360>>2]=p;c[u+143896>>2]=p;p=r+7168|0;c[u+12828>>2]=p;c[u+78364>>2]=p;c[u+143900>>2]=p;p=c[2383431]|0;c[u+12832>>2]=p;c[u+78368>>2]=p;c[u+143904>>2]=p;r=p+1024|0;c[u+12836>>2]=r;c[u+78372>>2]=r;c[u+143908>>2]=r;r=p+2048|0;c[u+12840>>2]=r;c[u+78376>>2]=r;c[u+143912>>2]=r;r=p+3072|0;c[u+12844>>2]=r;c[u+78380>>2]=r;c[u+143916>>2]=r;r=p+4096|0;c[u+12848>>2]=r;c[u+78384>>2]=r;c[u+143920>>2]=r;r=p+5120|0;c[u+12852>>2]=r;c[u+78388>>2]=r;c[u+143924>>2]=r;r=p+6144|0;c[u+12856>>2]=r;c[u+78392>>2]=r;c[u+143928>>2]=r;r=p+7168|0;c[u+12860>>2]=r;c[u+78396>>2]=r;c[u+143932>>2]=r;r=c[2383428]|0;c[u+13312>>2]=r;c[u+78848>>2]=r;c[u+144384>>2]=r;p=r+1024|0;c[u+13316>>2]=p;c[u+78852>>2]=p;c[u+144388>>2]=p;p=r+2048|0;c[u+13320>>2]=p;c[u+78856>>2]=p;c[u+144392>>2]=p;p=c[2383426]|0;c[u+13344>>2]=p;c[u+78880>>2]=p;c[u+144416>>2]=p;r=p+1024|0;c[u+13348>>2]=r;c[u+78884>>2]=r;c[u+144420>>2]=r;r=p+2048|0;c[u+13352>>2]=r;c[u+78888>>2]=r;c[u+144424>>2]=r;c[u+196728>>2]=3316;c[u+196648>>2]=738;c[u+196688>>2]=3014;c[u+196608>>2]=524;r=c[3532592]|0;if((r|0)!=0){gGC(r|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;aE8(c[2387784]|0,c[2387806]|0,4027500,0,0,.45,1023924,.5,0,0.0);r=c[642608+(c[2436]<<2)>>2]|0;p=c[r+128>>2]|0;if((c[r+52>>2]&4|0)==0){c[2113068]=p;m=c[r+132>>2]|0;c[2113070]=m;c[2443814]=p;c[2440436]=m;v=p;w=m}else{c[2113070]=p;m=c[r+132>>2]|0;c[2113068]=m;c[2440436]=p;c[2443814]=m;v=m;w=p}p=ag(v<<1,w)|0;m=gGq(p)|0;c[2112926]=m;if((m|0)!=0){gGz(m|0,0,p|0)}p=c[2414828]|0;gGz(p|0,0,(c[2411538]|0)-p|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];p=c[3532592]|0;if((p|0)!=0){gGC(9104152,p|0,280)|0}c[2113054]=c[2113060]}RI();p=c[2394]|0;m=c[14130368+(p<<2)>>2]|0;if((m|0)!=0){gGC(m|0,9104152,280)|0}c[8452240+(p<<2)>>2]=c[2113054];c[2394]=-1;aE7();gGz(c[2383428]|0,0,4096);gGz(c[2383426]|0,0,4096);p=c[2383424]|0;if((p|0)!=0){gGz(p|0,0,4096);gGz(c[2383422]|0,0,4096)}gGz(c[2383434]|0,0,16);gGz(c[2383435]|0,0,16);gGz(c[2383430]|0,0,8192);gGz(c[2383431]|0,0,8192);p=c[2383432]|0;if((p|0)!=0){gGz(p|0,0,8192);gGz(c[2383433]|0,0,8192)}b[4766836]=0;c[2426968]=0;c[3528794]=0;c[1765522]=65535;c[2429656]=0;c[2427042]=0;c[2429386]=0;c[2429384]=0;c[2429382]=0;q=0;i=e;return q|0}}while(0);c[2415120]=0;q=1;i=e;return q|0}function aAu(b,d){b=b|0;d=d|0;var e=0;if((b&16777200|0)!=1572864){return}e=b&14;if((e|0)==8){c[2383412]=d&255;if((a[9661085]|0)==1){return}a[9661085]=1;if((a[9661088]|0)!=0){return}a[9661088]=2;return}else if((e|0)==6){e=c[2386592]|0;d=c[2386404]|0;gGC(e|0,d|0,2048)|0;return}else{return}}function aAv(d,e){d=d|0;e=e|0;var f=0,g=0,h=0;f=d&16777200;if((f|0)==2752512){b[(c[2439594]|0)+(d&14)>>1]=e;return}else if((f|0)==1572864){g=d&15;if((g|0)==8){c[2383412]=e&255;if((a[9661085]|0)==1){return}a[9661085]=1;if((a[9661088]|0)!=0){return}a[9661088]=2;return}else if((g|0)==6){g=c[2386592]|0;h=c[2386404]|0;gGC(g|0,h|0,2048)|0;return}else{return}}else if((f|0)==2359296){b[(c[2439596]|0)+(d&14)>>1]=e;return}else{return}}function aAw(d){d=d|0;var f=0;L23308:do{if((d&16777200|0)==1572864){switch(d&15|0){case 2:{f=(e[4775132]|0)>>>8&255;break L23308;break};case 1:{f=a[9657896]|0;break L23308;break};case 0:{f=a[9657897]|0;break L23308;break};case 5:{f=((e[4775133]|0)^c[2408984])&255;break L23308;break};case 3:{f=b[4775132]&255;break L23308;break};default:{f=-1;break L23308}}}else{f=0}}while(0);return f|0}function aAx(a){a=a|0;var f=0,g=0;do{if((a&16777200|0)==1572864){f=a&14;if((f|0)==2){g=b[4775132]|0;break}else if((f|0)==4){g=((e[4775133]|0)^c[2408984])&65535;break}else if((f|0)==0){g=(d[9657897]|0)<<8|(d[9657896]|0);break}else{g=-1;break}}else{g=0}}while(0);return g|0}function aAy(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2970596+(b*112|0)>>2];c[a+104>>2]=c[2970600+(b*112|0)>>2];c[a+108>>2]=c[2970604+(b*112|0)>>2];d=0;return d|0}function aAz(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=2970496+(b*112|0);e=0;return e|0}function aAA(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1285448+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aAB(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>43){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4102928+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aAC(){var b=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;b=i;i=i+1080|0;e=b|0;f=b+112|0;g=b+120|0;j=b+232|0;k=b+240|0;l=b+352|0;m=b+360|0;n=b+472|0;o=b+480|0;p=b+592|0;q=b+600|0;r=b+712|0;s=b+720|0;t=b+832|0;u=b+840|0;v=b+952|0;w=b+960|0;x=b+1072|0;c[2424]=5800;c[2414886]=0;c[2388094]=0;c[2387782]=524288;c[3530770]=589824;c[3530534]=851968;c[3530400]=1900544;c[3530364]=2949120;c[3541206]=5046272;c[3529918]=6356992;c[2414588]=6365184;c[2388224]=6365184;c[2387804]=6381568;c[2386404]=6389760;c[2386592]=6391808;c[2387126]=6393856;c[2387058]=6402048;c[2439600]=6410240;c[2439598]=6414336;c[2387068]=6418432;c[2387080]=6426624;c[2439596]=6434816;c[2439594]=6434832;c[2411532]=6434848;c[3527028]=6434848;y=(a[9688]|0?6436984:6434848)|0;c[2414072]=y;z=y;y=0;while(1){if((y|0)>=1024){break}A=9638528+(y<<2)|0;if((c[A>>2]|0)==0){B=18568;break}else{y=y+1|0}}do{if((B|0)==18568){y=gGq(z)|0;c[A>>2]=y;if((y|0)==0){break}gGz(y|0,0,z|0);c[2414886]=y;gGz(y|0,0,z|0);c[2388094]=y;c[2387782]=y+524288;c[3530770]=y+589824;c[3530534]=y+851968;c[3530400]=y+1900544;c[3530364]=y+2949120;c[3541206]=y+5046272;c[3529918]=y+6356992;C=y+6365184|0;c[2414588]=C;c[2388224]=C;c[2387804]=y+6381568;c[2386404]=y+6389760;c[2386592]=y+6391808;c[2387126]=y+6393856;c[2387058]=y+6402048;c[2439600]=y+6410240;c[2439598]=y+6414336;c[2387068]=y+6418432;c[2387080]=y+6426624;c[2439596]=y+6434816;c[2439594]=y+6434832;C=y+6434848|0;c[2411532]=C;c[3527028]=C;c[2414072]=y+(a[9688]|0?6436984:6434848);if((R6(y+1|0,0,2)|0)!=0){D=1;i=b;return D|0}if((R6(c[2388094]|0,1,2)|0)!=0){D=1;i=b;return D|0}if((R6((c[2388094]|0)+262145|0,2,2)|0)!=0){D=1;i=b;return D|0}if((R6((c[2388094]|0)+262144|0,3,2)|0)!=0){D=1;i=b;return D|0}y=c[2387782]|0;if((c[3542200]|0)==0){D=1;i=b;return D|0}C=w+108|0;c[C>>2]=0;E=w+100|0;c[E>>2]=0;F=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[F&16383](w,4)|0;do{if((c[C>>2]|0)!=0){F=c[E>>2]|0;c[x>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](x,4,0)|0;if((F|0)<1){D=1;i=b;return D|0}if((gzL(y,0,4)|0)==0){break}else{D=1}i=b;return D|0}}while(0);y=c[3530770]|0;if((c[3542200]|0)==0){D=1;i=b;return D|0}E=u+108|0;c[E>>2]=0;C=u+100|0;c[C>>2]=0;F=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[F&16383](u,5)|0;do{if((c[E>>2]|0)!=0){F=c[C>>2]|0;c[v>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](v,5,0)|0;if((F|0)<1){D=1;i=b;return D|0}if((gzL(y,0,5)|0)==0){break}else{D=1}i=b;return D|0}}while(0);y=(c[3530770]|0)+65536|0;if((c[3542200]|0)==0){D=1;i=b;return D|0}C=s+108|0;c[C>>2]=0;E=s+100|0;c[E>>2]=0;F=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[F&16383](s,6)|0;do{if((c[C>>2]|0)!=0){F=c[E>>2]|0;c[t>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](t,6,0)|0;if((F|0)<1){D=1;i=b;return D|0}if((gzL(y,0,6)|0)==0){break}else{D=1}i=b;return D|0}}while(0);y=c[3530534]|0;if((c[3542200]|0)==0){D=1;i=b;return D|0}E=q+108|0;c[E>>2]=0;C=q+100|0;c[C>>2]=0;F=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[F&16383](q,7)|0;do{if((c[E>>2]|0)!=0){F=c[C>>2]|0;c[r>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](r,7,0)|0;if((F|0)<1){D=1;i=b;return D|0}if((gzL(y,0,7)|0)==0){break}else{D=1}i=b;return D|0}}while(0);y=c[3530400]|0;if((c[3542200]|0)==0){D=1;i=b;return D|0}C=o+108|0;c[C>>2]=0;E=o+100|0;c[E>>2]=0;F=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[F&16383](o,8)|0;do{if((c[C>>2]|0)!=0){F=c[E>>2]|0;c[p>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](p,8,0)|0;if((F|0)<1){D=1;i=b;return D|0}if((gzL(y,0,8)|0)==0){break}else{D=1}i=b;return D|0}}while(0);y=c[3530364]|0;if((c[3542200]|0)==0){D=1;i=b;return D|0}E=m+108|0;c[E>>2]=0;C=m+100|0;c[C>>2]=0;F=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[F&16383](m,9)|0;do{if((c[E>>2]|0)!=0){F=c[C>>2]|0;c[n>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](n,9,0)|0;if((F|0)<1){D=1;i=b;return D|0}if((gzL(y,0,9)|0)==0){break}else{D=1}i=b;return D|0}}while(0);y=(c[3530364]|0)+524288|0;if((c[3542200]|0)==0){D=1;i=b;return D|0}C=k+108|0;c[C>>2]=0;E=k+100|0;c[E>>2]=0;F=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[F&16383](k,10)|0;do{if((c[C>>2]|0)!=0){F=c[E>>2]|0;c[l>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](l,10,0)|0;if((F|0)<1){D=1;i=b;return D|0}if((gzL(y,0,10)|0)==0){break}else{D=1}i=b;return D|0}}while(0);y=c[3541206]|0;if((c[3542200]|0)==0){D=1;i=b;return D|0}E=g+108|0;c[E>>2]=0;C=g+100|0;c[C>>2]=0;F=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[F&16383](g,11)|0;do{if((c[E>>2]|0)!=0){F=c[C>>2]|0;c[j>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](j,11,0)|0;if((F|0)<1){D=1;i=b;return D|0}if((gzL(y,0,11)|0)==0){break}else{D=1}i=b;return D|0}}while(0);y=(c[3541206]|0)+1048576|0;if((c[3542200]|0)==0){D=1;i=b;return D|0}C=e+108|0;c[C>>2]=0;E=e+100|0;c[E>>2]=0;F=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[F&16383](e,12)|0;do{if((c[C>>2]|0)!=0){F=c[E>>2]|0;c[f>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](f,12,0)|0;if((F|0)<1){D=1;i=b;return D|0}if((gzL(y,0,12)|0)==0){break}else{D=1}i=b;return D|0}}while(0);y=c[2388094]|0;E=0;while(1){C=y+E|0;F=a[C]|0;a[C]=(F&255)>>>1<<6&64|F&-67|(F&255)>>>6<<1&2;F=E+1|0;if((F|0)<524288){E=F}else{H=0;break}}while(1){if((H|0)>=1024){break}I=9638528+(H<<2)|0;if((c[I>>2]|0)==0){B=18614;break}else{H=H+1|0}}L23468:do{if((B|0)==18614){E=gGq(1048576)|0;c[I>>2]=E;if((E|0)==0){break}gGz(E|0,0,1048576);y=c[3530770]|0;gGC(E|0,y|0,131072)|0;F=0;do{C=F<<6;gGz(y+C|0,0,64);G=0;do{J=1<<3-G;K=(c[686408+(G<<2)>>2]|0)+C|0;L=0;do{M=K+(c[1238464+(L<<2)>>2]|0)|0;N=(L<<3)+C|0;O=0;do{P=M+(c[614800+(O<<2)>>2]|0)|0;if(((d[E+((P|0)/8|0)|0]|0)&128>>>((P&7)>>>0)|0)!=0){P=y+(N+O)|0;a[P]=(d[P]|0|J)&255}O=O+1|0;}while((O|0)<8);L=L+1|0;}while((L|0)<8);G=G+1|0;}while((G|0)<4);F=F+1|0;}while((F|0)<4096);F=c[3530534]|0;gGC(E|0,F|0,524288)|0;y=0;do{G=y<<8;gGz(F+G|0,0,256);C=y<<9;L=0;do{J=1<<3-L;K=(c[1658016+(L<<2)>>2]|0)+C|0;O=0;do{N=K+(c[608544+(O<<2)>>2]|0)|0;M=(O<<4)+G|0;P=0;do{Q=N+(c[613816+(P<<2)>>2]|0)|0;if(((d[E+((Q|0)/8|0)|0]|0)&128>>>((Q&7)>>>0)|0)!=0){Q=F+(M+P)|0;a[Q]=(d[Q]|0|J)&255}P=P+1|0;}while((P|0)<16);O=O+1|0;}while((O|0)<16);L=L+1|0;}while((L|0)<4);y=y+1|0;}while((y|0)<4096);y=c[3530400]|0;gGC(E|0,y|0,524288)|0;F=0;do{L=F<<8;gGz(y+L|0,0,256);G=F<<9;C=0;do{O=1<<3-C;J=(c[1658016+(C<<2)>>2]|0)+G|0;K=0;do{P=J+(c[608544+(K<<2)>>2]|0)|0;M=(K<<4)+L|0;N=0;do{Q=P+(c[613816+(N<<2)>>2]|0)|0;if(((d[E+((Q|0)/8|0)|0]|0)&128>>>((Q&7)>>>0)|0)!=0){Q=y+(M+N)|0;a[Q]=(d[Q]|0|O)&255}N=N+1|0;}while((N|0)<16);K=K+1|0;}while((K|0)<16);C=C+1|0;}while((C|0)<4);F=F+1|0;}while((F|0)<4096);F=c[3530364]|0;gGC(E|0,F|0,1048576)|0;y=0;while(1){C=y<<8;gGz(F+C|0,0,256);L=y<<9;G=0;do{K=1<<3-G;O=(c[597928+(G<<2)>>2]|0)+L|0;J=0;do{N=O+(c[608544+(J<<2)>>2]|0)|0;M=(J<<4)+C|0;P=0;do{Q=N+(c[613816+(P<<2)>>2]|0)|0;if(((d[E+((Q|0)/8|0)|0]|0)&128>>>((Q&7)>>>0)|0)!=0){Q=F+(M+P)|0;a[Q]=(d[Q]|0|K)&255}P=P+1|0;}while((P|0)<16);J=J+1|0;}while((J|0)<16);G=G+1|0;}while((G|0)<4);G=y+1|0;if((G|0)<8192){y=G}else{R=0;break}}while(1){if((R|0)>=1024){break L23468}S=9638528+(R<<2)|0;if((c[S>>2]|0)==(E|0)){break}else{R=R+1|0}}gGr(E);c[S>>2]=0}}while(0);fxU(0,425984);if((c[2394]|0)==0){T=c[2112932]|0}else{c[2394]=0;y=c[3532596]|0;c[2112932]=y;F=c[3532592]|0;if((F|0)!=0){gGC(9104152,F|0,280)|0}c[2113054]=c[2113060];T=y}y=c[2388094]|0;F=T|0;G=0;while(1){C=y+G|0;c[F>>2]=C;c[F+131072>>2]=C;C=G+1024|0;if(C>>>0>524287){break}else{F=F+4|0;G=C}}G=c[2388224]|0;c[T+4096>>2]=G;c[T+69632>>2]=G;c[T+135168>>2]=G;F=G+1024|0;c[T+4100>>2]=F;c[T+69636>>2]=F;c[T+135172>>2]=F;F=G+2048|0;c[T+4104>>2]=F;c[T+69640>>2]=F;c[T+135176>>2]=F;F=G+3072|0;c[T+4108>>2]=F;c[T+69644>>2]=F;c[T+135180>>2]=F;F=G+4096|0;c[T+4112>>2]=F;c[T+69648>>2]=F;c[T+135184>>2]=F;F=G+5120|0;c[T+4116>>2]=F;c[T+69652>>2]=F;c[T+135188>>2]=F;F=G+6144|0;c[T+4120>>2]=F;c[T+69656>>2]=F;c[T+135192>>2]=F;F=G+7168|0;c[T+4124>>2]=F;c[T+69660>>2]=F;c[T+135196>>2]=F;F=G+8192|0;c[T+4128>>2]=F;c[T+69664>>2]=F;c[T+135200>>2]=F;F=G+9216|0;c[T+4132>>2]=F;c[T+69668>>2]=F;c[T+135204>>2]=F;F=G+10240|0;c[T+4136>>2]=F;c[T+69672>>2]=F;c[T+135208>>2]=F;F=G+11264|0;c[T+4140>>2]=F;c[T+69676>>2]=F;c[T+135212>>2]=F;F=G+12288|0;c[T+4144>>2]=F;c[T+69680>>2]=F;c[T+135216>>2]=F;F=G+13312|0;c[T+4148>>2]=F;c[T+69684>>2]=F;c[T+135220>>2]=F;F=G+14336|0;c[T+4152>>2]=F;c[T+69688>>2]=F;c[T+135224>>2]=F;F=G+15360|0;c[T+4156>>2]=F;c[T+69692>>2]=F;c[T+135228>>2]=F;F=c[2386404]|0;c[T+4608>>2]=F;c[T+70144>>2]=F;c[T+135680>>2]=F;G=F+1024|0;c[T+4612>>2]=G;c[T+70148>>2]=G;c[T+135684>>2]=G;G=c[2387126]|0;c[T+5120>>2]=G;c[T+70656>>2]=G;c[T+136192>>2]=G;F=G+1024|0;c[T+5124>>2]=F;c[T+70660>>2]=F;c[T+136196>>2]=F;F=G+2048|0;c[T+5128>>2]=F;c[T+70664>>2]=F;c[T+136200>>2]=F;F=G+3072|0;c[T+5132>>2]=F;c[T+70668>>2]=F;c[T+136204>>2]=F;F=G+4096|0;c[T+5136>>2]=F;c[T+70672>>2]=F;c[T+136208>>2]=F;F=G+5120|0;c[T+5140>>2]=F;c[T+70676>>2]=F;c[T+136212>>2]=F;F=G+6144|0;c[T+5144>>2]=F;c[T+70680>>2]=F;c[T+136216>>2]=F;F=G+7168|0;c[T+5148>>2]=F;c[T+70684>>2]=F;c[T+136220>>2]=F;F=c[2387058]|0;G=F+4096|0;c[T+8192>>2]=G;c[T+73728>>2]=G;c[T+139264>>2]=G;y=F+5120|0;c[T+8196>>2]=y;c[T+73732>>2]=y;c[T+139268>>2]=y;C=F+6144|0;c[T+8200>>2]=C;c[T+73736>>2]=C;c[T+139272>>2]=C;L=F+7168|0;c[T+8204>>2]=L;c[T+73740>>2]=L;c[T+139276>>2]=L;c[T+8224>>2]=F;c[T+73760>>2]=F;c[T+139296>>2]=F;J=F+1024|0;c[T+8228>>2]=J;c[T+73764>>2]=J;c[T+139300>>2]=J;J=F+2048|0;c[T+8232>>2]=J;c[T+73768>>2]=J;c[T+139304>>2]=J;J=F+3072|0;c[T+8236>>2]=J;c[T+73772>>2]=J;c[T+139308>>2]=J;c[T+8240>>2]=G;c[T+73776>>2]=G;c[T+139312>>2]=G;c[T+8244>>2]=y;c[T+73780>>2]=y;c[T+139316>>2]=y;c[T+8248>>2]=C;c[T+73784>>2]=C;c[T+139320>>2]=C;c[T+8252>>2]=L;c[T+73788>>2]=L;c[T+139324>>2]=L;L=c[2439600]|0;c[T+8704>>2]=L;c[T+74240>>2]=L;c[T+139776>>2]=L;C=L+1024|0;c[T+8708>>2]=C;c[T+74244>>2]=C;c[T+139780>>2]=C;C=L+2048|0;c[T+8712>>2]=C;c[T+74248>>2]=C;c[T+139784>>2]=C;C=L+3072|0;c[T+8716>>2]=C;c[T+74252>>2]=C;c[T+139788>>2]=C;C=c[2439598]|0;c[T+8736>>2]=C;c[T+74272>>2]=C;c[T+139808>>2]=C;L=C+1024|0;c[T+8740>>2]=L;c[T+74276>>2]=L;c[T+139812>>2]=L;L=C+2048|0;c[T+8744>>2]=L;c[T+74280>>2]=L;c[T+139816>>2]=L;L=C+3072|0;c[T+8748>>2]=L;c[T+74284>>2]=L;c[T+139820>>2]=L;L=c[2387068]|0;c[T+9728>>2]=L;c[T+75264>>2]=L;c[T+140800>>2]=L;C=L+1024|0;c[T+9732>>2]=C;c[T+75268>>2]=C;c[T+140804>>2]=C;C=L+2048|0;c[T+9736>>2]=C;c[T+75272>>2]=C;c[T+140808>>2]=C;C=L+3072|0;c[T+9740>>2]=C;c[T+75276>>2]=C;c[T+140812>>2]=C;C=L+4096|0;c[T+9744>>2]=C;c[T+75280>>2]=C;c[T+140816>>2]=C;C=L+5120|0;c[T+9748>>2]=C;c[T+75284>>2]=C;c[T+140820>>2]=C;C=L+6144|0;c[T+9752>>2]=C;c[T+75288>>2]=C;c[T+140824>>2]=C;C=L+7168|0;c[T+9756>>2]=C;c[T+75292>>2]=C;c[T+140828>>2]=C;C=c[2387080]|0;c[T+9760>>2]=C;c[T+75296>>2]=C;c[T+140832>>2]=C;L=C+1024|0;c[T+9764>>2]=L;c[T+75300>>2]=L;c[T+140836>>2]=L;L=C+2048|0;c[T+9768>>2]=L;c[T+75304>>2]=L;c[T+140840>>2]=L;L=C+3072|0;c[T+9772>>2]=L;c[T+75308>>2]=L;c[T+140844>>2]=L;L=C+4096|0;c[T+9776>>2]=L;c[T+75312>>2]=L;c[T+140848>>2]=L;L=C+5120|0;c[T+9780>>2]=L;c[T+75316>>2]=L;c[T+140852>>2]=L;L=C+6144|0;c[T+9784>>2]=L;c[T+75320>>2]=L;c[T+140856>>2]=L;L=C+7168|0;c[T+9788>>2]=L;c[T+75324>>2]=L;c[T+140860>>2]=L;c[T+196728>>2]=788;c[T+196648>>2]=960;c[T+196688>>2]=3028;c[T+196608>>2]=1732;L=c[3532592]|0;if((L|0)!=0){gGC(L|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;aE8(c[2387782]|0,c[2387804]|0,8055e3,1,0,.55,1006875,1.0,2013750,.6);h[745419]=.45;a[3203368]=1;h[745418]=.45;a[3203360]=1;h[745417]=.45;a[3203352]=1;h[745416]=.45;a[3203344]=1;L=c[642608+(c[2436]<<2)>>2]|0;C=c[L+128>>2]|0;if((c[L+52>>2]&4|0)==0){c[2113068]=C;y=c[L+132>>2]|0;c[2113070]=y;c[2443814]=C;c[2440436]=y;U=C;V=y}else{c[2113070]=C;y=c[L+132>>2]|0;c[2113068]=y;c[2440436]=C;c[2443814]=y;U=y;V=C}C=ag(U<<1,V)|0;y=gGq(C)|0;c[2112926]=y;if((y|0)!=0){gGz(y|0,0,C|0)}a[9623688]=0;C=c[2414588]|0;gGz(C|0,0,(c[2411532]|0)-C|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];C=c[3532592]|0;if((C|0)!=0){gGC(9104152,C|0,280)|0}c[2113054]=c[2113060]}RI();C=c[2394]|0;y=c[14130368+(C<<2)>>2]|0;if((y|0)!=0){gGC(y|0,9104152,280)|0}c[8452240+(C<<2)>>2]=c[2113054];c[2394]=-1;aE7();D=0;i=b;return D|0}}while(0);c[2414886]=0;D=1;i=b;return D|0}function aAD(){var a=0,b=0,d=0,e=0,f=0;c[2113070]=0;c[2113068]=0;a=c[2112926]|0;if((a|0)!=0){gGr(a);c[2112926]=0}if((c[2392]|0)>=0){a=0;do{b=14130368+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}b=14130384+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}a=a+1|0;}while((a|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;aFe();a=c[2414886]|0;b=0;while(1){if((b|0)>=1024){e=18726;break}f=9638528+(b<<2)|0;if((c[f>>2]|0)==(a|0)){break}else{b=b+1|0}}if((e|0)==18726){c[2414886]=0;return 0}gGr(a);c[f>>2]=0;c[2414886]=0;return 0}function aAE(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((a[9623688]|0)!=0){a[9623688]=0;d=c[2414588]|0;gGz(d|0,0,(c[2411532]|0)-d|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;aE7()}c[2387566]=-1;d=0;e=-1;f=-1;do{e=((a[9632720+d|0]&1)<<d^e&65535)&65535;f=((a[9630616+d|0]&1)<<d^f&65535)&65535;d=d+1|0;}while((d|0)<16);b[4775132]=e;b[4775133]=f;c[(c[2391608]|0)+60>>2]=0;c[(c[2391608]|0)+60>>2]=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060]}c[2388530]=9554128;f=c[2391608]|0;if((f|0)!=0){e=f;gGC(9661040,e|0,68)|0}c[2382]=0;c[2408984]=8;e=0;f=0;do{c[2113056]=808;d=RG(808)|0;c[2113054]=(c[2113054]|0)+d;c[2276108]=-1;c[2113056]=-1;fy_(542)|0;if((e|0)==7){c[2408984]=0}else if((e|0)==247){c[2408984]=8}d=a[9688]|0?2:0;g=(c[3527028]|0)+(f<<1<<1)|0;if(a[801408]|0){gg[c[3542124]&4095](g,d)}if(a[801400]|0){Uu(0,g,d)}if((c[2429658]|0)!=0){Uu(1,g,d)}f=d+f|0;e=e+1|0;}while((e|0)<256);c[8452200+(c[2394]<<2)>>2]=8198;c[2276080]=1536;if((c[2276079]|0)>>>0<1536){RH(6)}e=c[2438228]|0;d=gGS(-1427243008,66222,e,(e|0)<0|0?-1:0)|0;e=d;Sb(138879);d=c[2443830]|0;if((d|0)<1073676288){c[2443830]=d-e}d=c[2443831]|0;if((d|0)<1073676288){c[2443831]=d-e}d=(c[3528512]|0)-e|0;c[3528512]=(d|0)<0?0:d;d=c[2112964]|0;do{if((d|0)!=0){gg[c[3542122]&4095](d,a[9688]|0?534:0);e=a[9688]|0;g=e?534:0;if((g|0)==(f|0)){h=f;i=e}else{e=g-f|0;g=(c[3527028]|0)+(f<<1<<1)|0;if(a[801408]|0){gg[c[3542124]&4095](g,e)}if(a[801400]|0){Uu(0,g,e)}if((c[2429658]|0)!=0){Uu(1,g,e)}e=a[9688]|0;h=e?534:0;i=e}if((h|0)<=0){break}e=c[3527028]|0;g=c[2112964]|0;j=i?534:0;k=0;do{l=k<<1;m=g+(l<<1)|0;b[m>>1]=(b[m>>1]|0)+(b[e+(l<<1)>>1]|0)&65535;m=l|1;l=g+(m<<1)|0;b[l>>1]=(b[l>>1]|0)+(b[e+(m<<1)>>1]|0)&65535;k=k+1|0;}while((k|0)<(j|0))}}while(0);i=c[(c[2388530]|0)+12304>>2]|0;if((i|0)!=0){h=i;gGC(h|0,9661040,68)|0}c[2382]=-1;h=c[2394]|0;i=c[14130368+(h<<2)>>2]|0;if((i|0)!=0){gGC(i|0,9104152,280)|0}c[8452240+(h<<2)>>2]=c[2113054];c[2394]=-1;if((c[2112968]|0)==0){return 0}aAF()|0;return 0}function aAF(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;if((a[9547168]|0)!=0){f=c[2387126]|0;g=c[3529918]|0;h=0;do{i=b[f+h>>1]|0;c[g+(((h|0)/2|0)<<2)>>2]=((i&65535)>>>8&65535)<<3&2016|(i&65535)<<8&63488|(b[f+(h+4096)>>1]&248)>>>3&31;h=h+2|0;}while((h|0)<4096)}h=c[2439596]|0;f=c[2439594]|0;g=b[h>>1]|0;if((b[h+12>>1]&16384)==0){aAP(c[2387058]|0,c[3530400]|0,1024,0,b[h+6>>1]&1023,b[h+8>>1]&1023);j=c[2112926]|0}else{i=e[h+6>>1]|0;k=i&1023;l=b[h+8>>1]&1023;h=c[2387058]|0;m=c[2439598]|0;n=c[2113068]|0;o=c[2112926]|0;p=c[3530400]|0;q=8;while(1){r=q+l|0;s=r>>4;t=e[m+(q+64<<1)>>1]|0;u=(t&1023)+k|0;v=ag(q-8|0,n)|0;w=t+i&15;t=s<<6&2048|s<<5&992;s=r<<4&240;r=0;do{x=(u+r|0)>>>4;y=r-w|0;z=(y|0)<-15?y+1024|0:y;y=(z|0)<0?z+16|0:z;z=b[h+((t|x&31|x<<5&1024)<<1)>>1]|0;x=y+16|0;if((y|0)<(((x|0)<(n|0)?x:n)|0)&(y|0)<(n|0)){A=(z&65535)>>>12<<4;B=((z&65535)<<8&1048320|s)-y|0;z=(x|0)<(n|0)?x:n;x=y;do{b[o+(x+v<<1)>>1]=A|d[p+(B+x)|0]|1024;x=x+1|0;}while((x|0)<(z|0)&(x|0)<(n|0))}r=r+16|0;}while((r|0)<272);r=q+1|0;if((r|0)<248){q=r}else{j=o;break}}}aAP(c[2387068]|0,c[3530534]|0,768,1,b[f+2>>1]&1023,b[f+4>>1]&1023);o=c[2386592]|0;q=c[2113222]|0;n=c[3530364]|0;p=0;do{h=b[o+((p|1)<<1)>>1]&8191;do{if((h|0)!=0){i=e[o+(p<<1)>>1]|0;k=e[o+((p|2)<<1)>>1]|0;if((i>>>12&1&q|0)!=0){break}m=(k>>>9&31)+16|0;l=1<<(i>>>9&3);r=l-1|0;v=k&511;s=i&511;t=240-(v>>>0>255?k|-512:v)|0;if((t|0)>256){break}v=i&16384;k=(v|0)!=0;w=(k?0:r)+(h&-l)|0;u=(v>>>13^2)-1|0;if((l|0)<=0){break}l=(i&8192|0)!=0;v=232-(s>>>0>255?i|-512:s)|0;s=r;while(1){r=w-(ag(s,u)|0)|0;i=(s*-16|0)+v|0;do{if(k){if(l){SN(j,r,t,i,m,4,0,0,n);break}else{SL(j,r,t,i,m,4,0,0,n);break}}else{if(l){SJ(j,r,t,i,m,4,0,0,n);break}else{SH(j,r,t,i,m,4,0,0,n);break}}}while(0);if((s|0)>0){s=s-1|0}else{break}}}}while(0);p=p+4|0;}while((p|0)<1024);p=b[f+6>>1]&511;n=c[2387080]|0;q=-8-(b[f+8>>1]&511)|0;f=c[3530770]|0;o=c[2113068]|0;h=0;do{s=(h<<3&504)-p|0;m=(s|0)<-7?s+512|0:s;s=(h>>6<<3)+q|0;t=(s|0)<-7?s+512|0:s;L23709:do{if((m|0)<(o|0)){s=c[2113070]|0;if((t|0)>=(s|0)){break}l=e[n+(h<<1)>>1]|0;k=l>>>12;v=l&4095;if((v|0)==0){break}do{if((t|m|0)>-1){if((t|0)>(s-8|0)){break}if((m|0)>(o-8|0)){break}Sq(j,v,m,t,k,4,0,0,f);break L23709}}while(0);Sr(j,v,m,t,k,4,0,0,f)}}while(0);h=h+1|0;}while((h|0)<4096);if((g&128)!=0){C=c[3529918]|0;R8(C);return 0}g=ag(c[2113070]|0,o)|0;o=(g|0)/2|0;if((g|0)<=1){C=c[3529918]|0;R8(C);return 0}h=g-1|0;g=0;do{f=j+(g<<1)|0;n=b[f>>1]|0;q=j+(h-g<<1)|0;b[f>>1]=b[q>>1]|0;b[q>>1]=n;g=g+1|0;}while((g|0)<(o|0));C=c[3529918]|0;R8(C);return 0}function aAG(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=i;i=i+80|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;if((d|0)!=0){c[d>>2]=169762}if((b&32|0)!=0){gGz(k|0,0,12);l=c[2414588]|0;c[k>>2]=l;c[k+4>>2]=(c[2411532]|0)-l;c[k+12>>2]=162152;l=c[2076592]|0;gj[l&4095](k)|0}if((b&64|0)==0){i=e;return 0}k=h|0;gGz(g|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){l=h+9|0;h=f;m=f|0;n=f+4|0;o=f+12|0;p=g|0;q=g+4|0;r=g+12|0;s=0;do{gGC(k|0,614896,11)|0;a[l]=s+48&255;t=8452256+(s<<2)|0;gGz(h|0,0,12);c[m>>2]=t;c[n>>2]=4;c[o>>2]=164976;gj[c[2076592]&4095](f)|0;if((c[t>>2]|0)!=0){c[p>>2]=c[14130368+(s<<2)>>2];c[q>>2]=c[8452184+(s<<2)>>2];c[r>>2]=k;t=c[2076592]|0;gj[t&4095](g)|0}s=s+1|0;}while((s|0)<=(c[2392]|0))}aFf(b,d);aE6();gGz(j|0,0,12);c[j>>2]=9635936;c[j+4>>2]=4;c[j+12>>2]=509304;gj[c[2076592]&4095](j)|0;i=e;return 0}function aAH(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2973508+(b*112|0)>>2];c[a+104>>2]=c[2973512+(b*112|0)>>2];c[a+108>>2]=c[2973516+(b*112|0)>>2];d=0;return d|0}function aAI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=2973408+(b*112|0);e=0;return e|0}function aAJ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2972052+(b*112|0)>>2];c[a+104>>2]=c[2972056+(b*112|0)>>2];c[a+108>>2]=c[2972060+(b*112|0)>>2];d=0;return d|0}function aAK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=2971952+(b*112|0);e=0;return e|0}function aAL(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2835116+(b*112|0)>>2];c[a+104>>2]=c[2835120+(b*112|0)>>2];c[a+108>>2]=c[2835124+(b*112|0)>>2];d=0;return d|0}function aAM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=2835016+(b*112|0);e=0;return e|0}function aAN(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2836572+(b*112|0)>>2];c[a+104>>2]=c[2836576+(b*112|0)>>2];c[a+108>>2]=c[2836580+(b*112|0)>>2];d=0;return d|0}function aAO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=2836472+(b*112|0);e=0;return e|0}function aAP(a,b,d,f,g,h){a=a|0;b=b|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;i=a;a=-8-h|0;h=c[2112926]|0;j=c[2113068]|0;k=c[2113070]|0;if((f|0)==0){f=0;do{l=f>>6;m=(f<<4&1008)-g|0;n=(m|0)<-15?m+1024|0:m;m=(l<<4)+a|0;o=(m|0)<-15?m+1024|0:m;L23804:do{if((n|0)<(j|0)&(o|0)<(k|0)){m=e[i+((f<<5&1024|f&31|l<<5&992|l<<6&2048)<<1)>>1]|0;p=m>>>12;q=m&4095;do{if((o|n|0)>-1){if((o|0)>(k-16|0)){break}if((n|0)>(j-16|0)){break}Sy(h,q,n,o,p,4,d,b);break L23804}}while(0);Sz(h,q,n,o,p,4,d,b)}}while(0);f=f+1|0;}while((f|0)<4096);return}else{r=0}do{f=r>>6;o=(r<<4&1008)-g|0;n=(o|0)<-15?o+1024|0:o;o=(f<<4)+a|0;l=(o|0)<-15?o+1024|0:o;L23815:do{if((n|0)<(j|0)&(l|0)<(k|0)){o=e[i+((r<<5&1024|r&31|f<<5&992|f<<6&2048)<<1)>>1]|0;m=o>>>12;s=o&4095;if((s|0)==0){break}do{if((l|n|0)>-1){if((l|0)>(k-16|0)){break}if((n|0)>(j-16|0)){break}SG(h,s,n,l,m,4,0,d,b);break L23815}}while(0);SH(h,s,n,l,m,4,0,d,b)}}while(0);r=r+1|0;}while((r|0)<4096);return}function aAQ(b){b=b|0;var d=0,e=0;d=b-2375680|0;if(d>>>0<8192){e=a[(c[3531060]|0)+(((a[9754968]&1)==0?d:b-2367488|0)^1)|0]|0;return e|0}d=b-2400256|0;if(d>>>0<2048){e=a[(c[2443370]|0)+((a[9754969]&1)==0?d:b-2392064|0)|0]|0;return e|0}d=b-2412544|0;if(d>>>0<2048){e=a[(c[2443364]|0)+((a[9754970]&1)==0?d:b-2404352|0)|0]|0;return e|0}if((b-3145728|0)>>>0<32){e=0;return e|0}switch(b|0){case 3194883:{e=((a[9545184]|0)!=0?-128:0)|127-(a[9625536]|0)&255;return e|0};case 3194884:{e=a[9657889]|0;return e|0};case 3194885:{e=a[9657888]|0;return e|0};case 3194881:{e=~a[9625552];return e|0};case 3194880:{e=~a[9625544];return e|0};default:{e=0;return e|0}}return 0}function aAR(b,d){b=b|0;d=d|0;var e=0;e=b-2375680|0;if(e>>>0<8192){a[(c[3531060]|0)+(((a[9754968]&1)==0?e:b-2367488|0)^1)|0]=d;return}e=b-2400256|0;if(e>>>0<2048){a[(c[2443370]|0)+((a[9754969]&1)==0?e:b-2392064|0)|0]=d;return}e=b-2412544|0;if(e>>>0<2048){a[(c[2443364]|0)+((a[9754970]&1)==0?e:b-2404352|0)|0]=d;return}if((b|0)==3194901){a[9758144]=d;gg[c[(c[2443776]|0)+64>>2]&4095](32,1);e=c[(c[2443776]|0)+52>>2]|0;gj[e&4095](0)|0;gg[c[(c[2443776]|0)+64>>2]&4095](32,0);e=c[(c[2443776]|0)+52>>2]|0;gj[e&4095](0)|0;return}else if((b|0)==3194911){c[2444194]=0;return}else if((b|0)==3194897){c[3527346]=d&255;return}else{return}}function aAS(e){e=e|0;var f=0,g=0,h=0;f=e-2375680|0;if(f>>>0<8192){g=f>>>1;h=b[(c[3531060]|0)+(((a[9754968]&1)==0?g:g+4096|0)<<1)>>1]|0;return h|0}g=e-2400256|0;if(g>>>0<2048){f=g>>>1;h=b[(c[2443370]|0)+(((a[9754969]&1)==0?f:f+4096|0)<<1)>>1]|0;return h|0}f=e-2412544|0;if(f>>>0<2048){g=f>>>1;h=b[(c[2443364]|0)+(((a[9754970]&1)==0?g:g+4096|0)<<1)>>1]|0;return h|0}if((e-3145728|0)>>>0<32){h=0;return h|0}if((e|0)==3194884){h=d[9657889]<<8|d[9657888];return h|0}else if((e|0)==3194888){h=c[2444194]&65535;return h|0}else if((e|0)==3194880){h=~(d[9625552]|d[9625544]<<8);return h|0}else if((e|0)==3194882){h=((a[9545184]|0)!=0?128:0)|-129-(d[9625536]|0)&65535;return h|0}else{h=0;return h|0}return 0}function aAT(d,e){d=d|0;e=e|0;var f=0,g=0,h=0;f=d-2375680|0;if(f>>>0<8192){g=f>>>1;b[(c[3531060]|0)+(((a[9754968]&1)==0?g:g+4096|0)<<1)>>1]=e;return}g=d-2400256|0;if(g>>>0<2048){f=g>>>1;b[(c[2443370]|0)+(((a[9754969]&1)==0?f:f+4096|0)<<1)>>1]=e;return}f=d-2412544|0;if(f>>>0<2048){g=f>>>1;b[(c[2443364]|0)+(((a[9754970]&1)==0?g:g+4096|0)<<1)>>1]=e;return}if((d-3260416|0)>>>0<2048|(d-16762880|0)>>>0<256){return}if((d|0)==2408464|(d|0)==2408466|(d|0)==2408468|(d|0)==2408470){b[(c[2432702]|0)+((d-2408464|0)>>>1<<1)>>1]=e;return}else if((d|0)==3194904){c[8452200+(c[2394]<<2)>>2]=0;c[2276080]=0;return}else if((d|0)==2408448|(d|0)==2408450|(d|0)==2408452|(d|0)==2408454){b[(c[2432704]|0)+((d-2408448|0)>>>1<<1)>>1]=e;if((d|0)!=2408452){return}a[9754970]=e&1;return}else if((d|0)==3194902){g=c[2406596]|0;L23928:do{if((g|0)==2){f=e&65535;switch(f>>>8|0){case 2:{c[2444194]=c[2384370];break};case 3:{c[2384370]=(c[2384370]|0)+1;c[2444194]=769;break};case 5:{c[2444194]=2875;c[2384370]=0;break};case 6:{c[2444194]=c[599208+(c[2384370]<<7)+((f&31)<<2)>>2];break};case 11:{c[2444194]=0;break};default:{c[2444194]=0}}if((e<<16>>16|0)==7){c[2444194]=49152;break}else if((e<<16>>16|0)==1279){c[2384368]=0;break}else if((e<<16>>16|0)==373){c[2444194]=1675;break}else if((e<<16>>16|0)==372){c[2444194]=1676;break}else{if((e-1024&65535)>=255){break}f=c[2384368]|0;c[2384368]=f+1;h=c[598448+(f<<2)>>2]|0;if((h|0)==0){c[2444194]=65534;break}if((f|0)==189){c[2444194]=65535;break}if((h|0)>4096){c[2444194]=(h&4095)+143;break}else{c[2444194]=h+8335;break}}}else if((g|0)==1){c[2444194]=0;switch(e&65535|0){case 1854:{c[2444194]=1804;break L23928;break};case 1832:{c[2444194]=1800;break L23928;break};case 1845:{c[2444194]=1801;break L23928;break};case 1883:{c[2444194]=1807;break L23928;break};case 1821:{c[2444194]=1802;break L23928;break};case 1825:{c[2444194]=1803;break L23928;break};case 1877:{c[2444194]=1796;break L23928;break};case 1826:{c[2444194]=1797;break L23928;break};case 1836:{c[2444194]=1794;break L23928;break};case 1855:{c[2444194]=1795;break L23928;break};case 1889:{c[2444194]=1805;break L23928;break};case 1875:{c[2444194]=1806;break L23928;break};case 1812:{c[2444194]=1792;break L23928;break};case 1851:{c[2444194]=1793;break L23928;break};case 1835:{c[2444194]=1798;break L23928;break};case 1828:{c[2444194]=1799;break L23928;break};default:{break L23928}}}}while(0);c[8452200+(c[2394]<<2)>>2]=8197;c[2276080]=1280;if((c[2276079]|0)>>>0>=1280){return}RH(5);return}else if((d|0)==2383888|(d|0)==2383890|(d|0)==2383892|(d|0)==2383894){b[(c[2432706]|0)+((d-2383888|0)>>>1<<1)>>1]=e;return}else if((d|0)==3194896){c[3527346]=e&65535;return}else if((d|0)==3194910){c[2444194]=0;return}else if((d|0)==2359312|(d|0)==2359314|(d|0)==2359316|(d|0)==2359318){b[(c[2437774]|0)+((d-2359312|0)>>>1<<1)>>1]=e;return}else if((d|0)==3194898){g=c[2429336]|0;h=c[2443440]|0;gGC(g|0,h|0,2048)|0;return}else if((d|0)==3194900){a[9758144]=e&255;gg[c[(c[2443776]|0)+64>>2]&4095](32,1);gj[c[(c[2443776]|0)+52>>2]&4095](0)|0;gg[c[(c[2443776]|0)+64>>2]&4095](32,0);gj[c[(c[2443776]|0)+52>>2]&4095](0)|0;return}else if((d|0)==2383872|(d|0)==2383874|(d|0)==2383876|(d|0)==2383878){b[(c[2432708]|0)+((d-2383872|0)>>>1<<1)>>1]=e;if((d|0)!=2383876){return}a[9754969]=e&1;return}else if((d|0)==2359296|(d|0)==2359298|(d|0)==2359300|(d|0)==2359302){b[(c[2437776]|0)+((d-2359296|0)>>>1<<1)>>1]=e;if((d|0)!=2359300){return}a[9754968]=e&1;return}else{return}}function aAU(b){b=b|0;var d=0,e=0;d=b&65535;if((d|0)==14336){e=c[2113156]&255}else if((d|0)==12288){e=a[9758144]|0}else{e=0}return e|0}function aAV(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0;f=b&65535;if((f|0)==14336){Uv(0,e);return}else if((f|0)==4097){b=c[3540984]|0;g=c[b+5876>>2]|0;if((g|0)!=0){gg[g&4095](c[b+5880>>2]|0,0)}lH(b,d[b+5885|0]|0,e&255);return}else if((f|0)==2049){lS(0,1,e);return}else if((f|0)==4096){a[(c[3540984]|0)+5885|0]=e;return}else if((f|0)==2048){f=c[3541518]|0;b=f+256|0;a[f+304|0]=e;g=e&255;if((e&255)<16){c[14168912+((c[2383582]|0)*252|0)>>2]=g&15}if((e-45&255)>=3){return}if((g|0)==45){e=f+312|0;h=a[e]|2;a[e]=h;i=h}else if((g|0)==46){h=f+312|0;e=a[h]|1;a[h]=e;i=e}else if((g|0)==0){a[f+312|0]=2;i=2}else if((g|0)==47){a[f+312|0]=0;i=0}else{i=a[f+312|0]|0}f=i&3;i=c[7461744+(f<<2)>>2]|0;lI(b,i,i,c[7461728+(f<<2)>>2]|0);return}else{return}}function aAW(b){b=b|0;return a[(c[2443452]|0)+((b-1572864|0)>>>1)|0]|0}function aAX(b,d){b=b|0;d=d|0;a[(c[2443452]|0)+((b-1572864|0)>>>1)|0]=d;return}function aAY(a){a=a|0;return d[(c[2443452]|0)+((a-1572864|0)>>>1)|0]|0|0}function aAZ(b,d){b=b|0;d=d|0;a[(c[2443452]|0)+((b-1572864|0)>>>1)|0]=d&255;return}function aA_(d){d=d|0;var e=0,f=0,g=0;e=d-1708032|0;if(e>>>0<2048){f=e^1;e=f>>1;g=b[(c[2443364]|0)+(((a[9754970]&1)==0?e:e+4096|0)<<1)>>1]|0;return((f&1|0)==0?(g&65535)>>>8:g)&255|0}else{return((d|0)==2094083?a[9545184]|0:0)|0}return 0}function aA$(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=d-1703936|0;if(f>>>0<8){g=c[2432704]|0;h=f>>1;i=e&255;if((f&1|0)==0){f=h&3;j=g+(f<<1)|0;b[j>>1]=b[j>>1]&-256|i;if((f|0)!=2){return}a[9754970]=e&1;return}else{f=h&3;h=g+(f<<1)|0;g=b[h>>1]|0;b[h>>1]=g&255|i<<8;if((f|0)!=2){return}a[9754970]=g&1;return}}g=d-1703952|0;if(g>>>0<16){f=g^1;g=c[2432702]|0;i=f>>1;if((f|0)>=4){h=g+((i&7)<<1)|0;b[h>>1]=b[h>>1]&-256|e&255;return}h=e&255;if((f&1|0)==0){f=g+((i&7)<<1)|0;b[f>>1]=b[f>>1]&255|h<<8;return}else{f=g+((i&7)<<1)|0;b[f>>1]=b[f>>1]&-256|h;return}}h=d-1708032|0;if(h>>>0<2048){f=h^1;h=c[2443364]|0;i=f>>1;g=e&255;if((f&1|0)==0){f=h+(((a[9754970]&1)==0?i:i+4096|0)<<1)|0;b[f>>1]=b[f>>1]&255|g<<8;return}else{f=h+(((a[9754970]&1)==0?i:i+4096|0)<<1)|0;b[f>>1]=b[f>>1]&-256|g;return}}g=d-2094080|0;if(g>>>0>=4){return}a[9661104]=e;d=g&3;if((d|0)==2){a[9661072]=e&7;if((a[9661088]|0)!=0){return}a[9661088]=2;return}else if((d|0)==3){if((a[9661087]|0)==0){return}a[9661087]=0;if((a[9661088]|0)!=0){return}a[9661088]=2;return}else{a[9661104]=e;return}}function aA0(b){b=b|0;return a[(c[2443452]|0)+((b-1572864|0)>>>1)|0]|0}function aA1(b,d){b=b|0;d=d|0;var e=0;e=(b-1572864|0)>>>1;a[(c[2443452]|0)+e|0]=d;if((e|0)!=2047){return}do{if((a[9661085]|0)!=1){a[9661085]=1;if((a[9661088]|0)!=0){break}a[9661088]=2}}while(0);fy_(10)|0;if((a[9661085]|0)==0){return}a[9661085]=0;if((a[9661088]|0)!=0){return}a[9661088]=2;return}function aA2(a){a=a|0;return d[(c[2443452]|0)+((a-1572864|0)>>>1)|0]|0|0}function aA3(b,d){b=b|0;d=d|0;var e=0;e=(b-1572864|0)>>>1;a[(c[2443452]|0)+e|0]=d&255;if((e|0)!=2047){return}do{if((a[9661085]|0)!=1){a[9661085]=1;if((a[9661088]|0)!=0){break}a[9661088]=2}}while(0);fy_(10)|0;if((a[9661085]|0)==0){return}a[9661085]=0;if((a[9661088]|0)!=0){return}a[9661088]=2;return}function aA4(a){a=a|0;return 0}function aA5(b,c){b=b|0;c=c|0;var d=0;d=b-2094080|0;if(d>>>0>=4){return}a[9661104]=c;b=d&3;if((b|0)==2){a[9661072]=c&7;if((a[9661088]|0)!=0){return}a[9661088]=2;return}else if((b|0)==3){if((a[9661087]|0)==0){return}a[9661087]=0;if((a[9661088]|0)!=0){return}a[9661088]=2;return}else{a[9661104]=c;return}}function aA6(b){b=b|0;var c=0,d=0,e=0;c=b-3260416|0;L24149:do{if(c>>>0<16){d=c&-2;if((d|0)==2){e=19;break}else if((d|0)==6){e=2;break}else{e=0;break}}else{switch(b|0){case 3227656:{e=a[9657889]|0;break L24149;break};case 3227658:{e=~a[9625544];break L24149;break};case 3227657:{e=a[9657888]|0;break L24149;break};case 3227659:{e=~a[9625552];break L24149;break};case 3227661:{e=((a[9545184]|0)!=0?8:0)|-9-(a[9625536]|0)&255;break L24149;break};default:{e=0;break L24149}}}}while(0);return e|0}function aA7(b,d){b=b|0;d=d|0;if((b|0)==3227649){a[9758144]=d;a[9661084]=1;if((a[9661088]|0)==0){a[9661088]=2}fy_(10)|0;return}else if((b|0)==3227651){c[3527346]=d&255;return}else if((b|0)==3145728|(b|0)==3145729|(b|0)==3145730|(b|0)==3145731|(b|0)==3145732|(b|0)==3145733|(b|0)==3145734|(b|0)==3145735){a[(c[2432704]|0)+(b-3145728^1)|0]=d;if((b|0)!=3145733){return}a[9754970]=d&1;return}else if((b|0)==3145744|(b|0)==3145745|(b|0)==3145746|(b|0)==3145747|(b|0)==3145748|(b|0)==3145749|(b|0)==3145750|(b|0)==3145751){a[(c[2432702]|0)+(b-3145744^1)|0]=d;return}else{return}}function aA8(b){b=b|0;var c=0,e=0,f=0;c=b-3260416|0;do{if(c>>>0<16){e=c&-2;if((e|0)==6){f=2;break}else if((e|0)==2){f=19;break}else{f=0;break}}else{if((b|0)==3227658){f=~(d[9625552]|d[9625544]<<8);break}else if((b|0)==3227660){f=247-(d[9625536]|0)&65535|((a[9545184]|0)!=0?8:0)|-256;break}else if((b|0)==3227656){f=d[9657889]<<8|d[9657888];break}else if((b|0)==2375680){e=(a[9720912]|0)+1&3;a[9720912]=e;aA9(e);f=0;break}else{f=0;break}}}while(0);return f|0}function aA9(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[2112932]|0;d=b+9216|0;e=2359296;while(1){c[d+65536>>2]=8;f=e+1024|0;if(f>>>0>2424831){break}else{d=d+4|0;e=f}}c[b+196680>>2]=1292;c[b+196760>>2]=1546;e=a&255;if((e|0)==0){c[b+74784>>2]=c[2429330];c[b+74788>>2]=c[2429328];a=c[2443370]|0;c[b+74848>>2]=a;c[b+74852>>2]=a+1024;c[b+74856>>2]=a+2048;c[b+74860>>2]=a+3072;c[b+74864>>2]=a+4096;c[b+74868>>2]=a+5120;c[b+74872>>2]=a+6144;c[b+74876>>2]=a+7168;c[b+74944>>2]=c[2429770];c[b+74948>>2]=c[2429768];a=c[3531060]|0;c[b+74976>>2]=a;c[b+74980>>2]=a+1024;c[b+74984>>2]=a+2048;c[b+74988>>2]=a+3072;c[b+74992>>2]=a+4096;c[b+74996>>2]=a+5120;c[b+75e3>>2]=a+6144;c[b+75004>>2]=a+7168;return}else if((e|0)==2){a=c[2443370]|0;c[b+74752>>2]=a;c[b+74756>>2]=a+1024;c[b+74760>>2]=a+2048;c[b+74764>>2]=a+3072;c[b+74768>>2]=a+4096;c[b+74772>>2]=a+5120;c[b+74776>>2]=a+6144;c[b+74780>>2]=a+7168;a=c[3531060]|0;c[b+74784>>2]=a;d=a+1024|0;c[b+74788>>2]=d;f=a+2048|0;c[b+74792>>2]=f;g=a+3072|0;c[b+74796>>2]=g;h=a+4096|0;c[b+74800>>2]=h;i=a+5120|0;c[b+74804>>2]=i;j=a+6144|0;c[b+74808>>2]=j;k=a+7168|0;c[b+74812>>2]=k;c[b+74976>>2]=a;c[b+74980>>2]=d;c[b+74984>>2]=f;c[b+74988>>2]=g;c[b+74992>>2]=h;c[b+74996>>2]=i;c[b+75e3>>2]=j;c[b+75004>>2]=k;return}else if((e|0)==1){k=c[3531060]|0;c[b+74880>>2]=k;c[b+74884>>2]=k+1024;c[b+74888>>2]=k+2048;c[b+74892>>2]=k+3072;c[b+74896>>2]=k+4096;c[b+74900>>2]=k+5120;c[b+74904>>2]=k+6144;c[b+74908>>2]=k+7168;k=c[2443370]|0;c[b+74944>>2]=k;c[b+74948>>2]=k+1024;c[b+74952>>2]=k+2048;c[b+74956>>2]=k+3072;c[b+74960>>2]=k+4096;c[b+74964>>2]=k+5120;c[b+74968>>2]=k+6144;c[b+74972>>2]=k+7168;return}else if((e|0)==3){e=c[3531060]|0;c[b+74752>>2]=e;c[b+74756>>2]=e+1024;c[b+74760>>2]=e+2048;c[b+74764>>2]=e+3072;c[b+74768>>2]=e+4096;c[b+74772>>2]=e+5120;c[b+74776>>2]=e+6144;c[b+74780>>2]=e+7168;e=c[2443370]|0;c[b+74880>>2]=e;c[b+74884>>2]=e+1024;c[b+74888>>2]=e+2048;c[b+74892>>2]=e+3072;c[b+74896>>2]=e+4096;c[b+74900>>2]=e+5120;c[b+74904>>2]=e+6144;c[b+74908>>2]=e+7168;return}else{return}}function aBa(d,e){d=d|0;e=e|0;if((d-3260416|0)>>>0<16){return}if((d|0)==3227650){c[3527346]=e&65535;return}else if((d|0)==3227648){a[9758144]=e&255;a[9661084]=1;if((a[9661088]|0)==0){a[9661088]=2}fy_(10)|0;return}else if((d|0)==3145728|(d|0)==3145730|(d|0)==3145732|(d|0)==3145734){b[(c[2432704]|0)+((d-3145728|0)>>>1<<1)>>1]=e;if((d|0)!=3145732){return}a[9754970]=e&1;return}else if((d|0)==3145744|(d|0)==3145746|(d|0)==3145748|(d|0)==3145750){b[(c[2432702]|0)+((d-3145744|0)>>>1<<1)>>1]=e;return}else if((d|0)==2400256){a[9720912]=0;aA9(0);return}else{return}}function aBb(b,d){b=b|0;d=d|0;if((b|0)==2359312|(b|0)==2359313|(b|0)==2359314|(b|0)==2359315|(b|0)==2359316|(b|0)==2359317|(b|0)==2359318|(b|0)==2359319){a[(c[2432706]|0)+(b-2359312^1)|0]=d;return}else if((b|0)==2392080|(b|0)==2392081|(b|0)==2392082|(b|0)==2392083|(b|0)==2392084|(b|0)==2392085|(b|0)==2392086|(b|0)==2392087){a[(c[2437774]|0)+(b-2392080^1)|0]=d;return}else if((b|0)==2392064|(b|0)==2392065|(b|0)==2392066|(b|0)==2392067|(b|0)==2392068|(b|0)==2392069|(b|0)==2392070|(b|0)==2392071){a[(c[2437776]|0)+(b-2392064^1)|0]=d;if((b|0)!=2392069){return}a[9754968]=d&1;return}else if((b|0)==2359296|(b|0)==2359297|(b|0)==2359298|(b|0)==2359299|(b|0)==2359300|(b|0)==2359301|(b|0)==2359302|(b|0)==2359303){a[(c[2432708]|0)+(b-2359296^1)|0]=d;if((b|0)!=2359301){return}a[9754969]=d&1;return}else{return}}function aBc(d,e){d=d|0;e=e|0;if((d|0)==2392080|(d|0)==2392082|(d|0)==2392084|(d|0)==2392086){b[(c[2437774]|0)+((d-2392080|0)>>>1<<1)>>1]=e;return}else if((d|0)==2400256){a[9720912]=0;aA9(0);return}else if((d|0)==2392064|(d|0)==2392066|(d|0)==2392068|(d|0)==2392070){b[(c[2437776]|0)+((d-2392064|0)>>>1<<1)>>1]=e;if((d|0)!=2392068){return}a[9754968]=e&1;return}else if((d|0)==2359312|(d|0)==2359314|(d|0)==2359316|(d|0)==2359318){b[(c[2432706]|0)+((d-2359312|0)>>>1<<1)>>1]=e;return}else if((d|0)==2359296|(d|0)==2359298|(d|0)==2359300|(d|0)==2359302){b[(c[2432708]|0)+((d-2359296|0)>>>1<<1)>>1]=e;if((d|0)!=2359300){return}a[9754969]=e&1;return}else{return}}function aBd(b){b=b|0;var d=0;if((b|0)==983040){d=a[9758144]|0}else if((b|0)==917504){d=c[2113156]&255}else{d=0}return d|0}function aBe(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;if((b|0)==589825){f=c[3540984]|0;g=c[f+5876>>2]|0;if((g|0)!=0){gg[g&4095](c[f+5880>>2]|0,0)}lH(f,d[f+5885|0]|0,e&255);return}else if((b|0)==720896){f=c[3541518]|0;g=f+256|0;a[f+304|0]=e;h=e&255;if((e&255)<16){c[14168912+((c[2383582]|0)*252|0)>>2]=h&15}if((e-45&255)>=3){return}if((h|0)==0){a[f+312|0]=2;i=2}else if((h|0)==45){j=f+312|0;k=a[j]|2;a[j]=k;i=k}else if((h|0)==46){k=f+312|0;j=a[k]|1;a[k]=j;i=j}else if((h|0)==47){a[f+312|0]=0;i=0}else{i=a[f+312|0]|0}f=i&3;i=c[7461744+(f<<2)>>2]|0;lI(g,i,i,c[7461728+(f<<2)>>2]|0);return}else if((b|0)==720897){lS(0,1,e);return}else if((b|0)==917504){Uv(0,e);return}else if((b|0)==589824){a[(c[3540984]|0)+5885|0]=e;return}else{f=b-2094080|0;if(f>>>0>=4){return}a[9661104]=e;b=f&3;if((b|0)==3){if((a[9661087]|0)==0){return}a[9661087]=0;if((a[9661088]|0)!=0){return}a[9661088]=2;return}else if((b|0)==2){a[9661072]=e&7;if((a[9661088]|0)!=0){return}a[9661088]=2;return}else{a[9661104]=e;return}}}function aBf(b){b=b|0;var d=0,e=0;d=b-2228224|0;if(d>>>0<2048){e=a[(c[2443370]|0)+(((a[9754969]&1)==0?d:b-2220032|0)^1)|0]|0;return e|0}d=b-2230272|0;if(d>>>0<2048){e=a[(c[2443370]|0)+(((a[9754969]&1)==0?d:b-2222080|0)^1)|0]|0;return e|0}d=b-2752512|0;if(d>>>0<2048){e=a[(c[2443364]|0)+(((a[9754970]&1)==0?d:b-2744320|0)^1)|0]|0;return e|0}d=b-3276800|0;if(d>>>0<8192){e=a[(c[3531060]|0)+(((a[9754968]&1)==0?d:b-3268608|0)^1)|0]|0;return e|0}if((b|0)!=1572873){e=0;return e|0}e=((a[9545184]|0)!=0?8:0)|-9-(a[9625536]|0)&255;return e|0}function aBg(b,d){b=b|0;d=d|0;var e=0;e=b-2228224|0;if(e>>>0<2048){a[(c[2443370]|0)+(((a[9754969]&1)==0?e:b-2220032|0)^1)|0]=d;return}e=b-2230272|0;if(e>>>0<2048){a[(c[2443370]|0)+(((a[9754969]&1)==0?e:b-2222080|0)^1)|0]=d;return}e=b-2752512|0;if(e>>>0<2048){a[(c[2443364]|0)+(((a[9754970]&1)==0?e:b-2744320|0)^1)|0]=d;return}e=b-3276800|0;if(e>>>0<8192){a[(c[3531060]|0)+(((a[9754968]&1)==0?e:b-3268608|0)^1)|0]=d;return}if((b|0)!=1703937){return}a[9758144]=d;a[9661084]=1;if((a[9661088]|0)==0){a[9661088]=2}fy_(10)|0;return}function aBh(e){e=e|0;var f=0,g=0,h=0;f=e-2228224|0;if(f>>>0<2048){g=f>>>1;h=b[(c[2443370]|0)+(((a[9754969]&1)==0?g:g+4096|0)<<1)>>1]|0;return h|0}g=e-2230272|0;if(g>>>0<2048){f=g>>>1;h=b[(c[2443370]|0)+(((a[9754969]&1)==0?f:f+4096|0)<<1)>>1]|0;return h|0}f=e-2752512|0;if(f>>>0<2048){g=f>>>1;h=b[(c[2443364]|0)+(((a[9754970]&1)==0?g:g+4096|0)<<1)>>1]|0;return h|0}g=e-3276800|0;if(g>>>0<8192){f=g>>>1;h=b[(c[3531060]|0)+(((a[9754968]&1)==0?f:f+4096|0)<<1)>>1]|0;return h|0}switch(e|0){case 1572868:{h=(1<<((d[9718112]|0)>>>4&255)^65535)&65535;return h|0};case 1572870:{h=(1<<((d[9718113]|0)>>>4&255)^65535)&65535;return h|0};case 1572872:{h=247-(d[9625536]|0)&65535|((a[9545184]|0)!=0?8:0)|-256;return h|0};case 1572864:{h=~(d[9625552]|d[9625544]<<8);return h|0};case 1572866:{h=d[9657889]<<8|d[9657888];return h|0};default:{h=0;return h|0}}return 0}function aBi(d,e){d=d|0;e=e|0;var f=0,g=0;f=d-2228224|0;if(f>>>0<2048){g=f>>>1;b[(c[2443370]|0)+(((a[9754969]&1)==0?g:g+4096|0)<<1)>>1]=e;return}g=d-2230272|0;if(g>>>0<2048){f=g>>>1;b[(c[2443370]|0)+(((a[9754969]&1)==0?f:f+4096|0)<<1)>>1]=e;return}f=d-2752512|0;if(f>>>0<2048){g=f>>>1;b[(c[2443364]|0)+(((a[9754970]&1)==0?g:g+4096|0)<<1)>>1]=e;return}g=d-3276800|0;if(g>>>0<8192){f=g>>>1;b[(c[3531060]|0)+(((a[9754968]&1)==0?f:f+4096|0)<<1)>>1]=e;return}if((d|0)==2621456|(d|0)==2621458|(d|0)==2621460|(d|0)==2621462){b[(c[2432702]|0)+((d-2621456|0)>>>1<<1)>>1]=e;return}else if((d|0)==1441792){c[3527346]=e&65535;return}else if((d|0)==2097168|(d|0)==2097170|(d|0)==2097172|(d|0)==2097174){b[(c[2432706]|0)+((d-2097168|0)>>>1<<1)>>1]=e;return}else if((d|0)==2621440|(d|0)==2621442|(d|0)==2621444|(d|0)==2621446){b[(c[2432704]|0)+((d-2621440|0)>>>1<<1)>>1]=e;if((d|0)!=2621444){return}a[9754970]=e&1;return}else if((d|0)==2097152|(d|0)==2097154|(d|0)==2097156|(d|0)==2097158){b[(c[2432708]|0)+((d-2097152|0)>>>1<<1)>>1]=e;if((d|0)!=2097156){return}a[9754969]=e&1;return}else if((d|0)==3145750|(d|0)==3145748|(d|0)==3145744|(d|0)==3145746){b[(c[2437774]|0)+((d-3145744|0)>>>1<<1)>>1]=e;return}else if((d|0)==3145728|(d|0)==3145730|(d|0)==3145732|(d|0)==3145734){b[(c[2437776]|0)+((d-3145728|0)>>>1<<1)>>1]=e;if((d|0)!=3145732){return}a[9754968]=e&1;return}else{return}}function aBj(b){b=b|0;var d=0;if((b|0)==1277952){d=a[9758144]|0}else if((b|0)==1245184){d=c[2113156]&255}else{d=0}return d|0}function aBk(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;if((b|0)==1146880){f=c[3541518]|0;g=f+256|0;a[f+304|0]=e;h=e&255;if((e&255)<16){c[14168912+((c[2383582]|0)*252|0)>>2]=h&15}if((e-45&255)>=3){return}if((h|0)==45){i=f+312|0;j=a[i]|2;a[i]=j;k=j}else if((h|0)==0){a[f+312|0]=2;k=2}else if((h|0)==47){a[f+312|0]=0;k=0}else if((h|0)==46){h=f+312|0;j=a[h]|1;a[h]=j;k=j}else{k=a[f+312|0]|0}f=k&3;k=c[7461744+(f<<2)>>2]|0;lI(g,k,k,c[7461728+(f<<2)>>2]|0);return}else if((b|0)==1245184){Uv(0,e);return}else if((b|0)==1081344){a[(c[3540984]|0)+5885|0]=e;return}else if((b|0)==1146881){lS(0,1,e);return}else if((b|0)==1081345){f=c[3540984]|0;k=c[f+5876>>2]|0;if((k|0)!=0){gg[k&4095](c[f+5880>>2]|0,0)}lH(f,d[f+5885|0]|0,e&255);return}else{f=b-2094080|0;if(f>>>0>=4){return}a[9661104]=e;b=f&3;if((b|0)==3){if((a[9661087]|0)==0){return}a[9661087]=0;if((a[9661088]|0)!=0){return}a[9661088]=2;return}else if((b|0)==2){a[9661072]=e&7;if((a[9661088]|0)!=0){return}a[9661088]=2;return}else{a[9661104]=e;return}}}function aBl(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4255020+(b*112|0)>>2];c[a+104>>2]=c[4255024+(b*112|0)>>2];c[a+108>>2]=c[4255028+(b*112|0)>>2];d=0;return d|0}function aBm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=4254920+(b*112|0);e=0;return e|0}function aBn(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>25){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6352664+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aBo(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>33){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4257496+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aBp(){var b=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;b=i;i=i+2160|0;e=b|0;f=b+112|0;g=b+120|0;j=b+232|0;k=b+240|0;l=b+352|0;m=b+360|0;n=b+472|0;o=b+480|0;p=b+592|0;q=b+600|0;r=b+712|0;s=b+720|0;t=b+832|0;u=b+840|0;v=b+952|0;w=b+960|0;x=b+1072|0;y=b+1080|0;z=b+1192|0;A=b+1200|0;B=b+1312|0;C=b+1320|0;D=b+1432|0;E=b+1440|0;F=b+1552|0;G=b+1560|0;H=b+1672|0;I=b+1680|0;J=b+1792|0;K=b+1800|0;L=b+1912|0;M=b+1920|0;N=b+2032|0;O=b+2040|0;P=b+2152|0;aCN();if((R6((c[2388040]|0)+1|0,0,2)|0)!=0){Q=1;i=b;return Q|0}if((R6(c[2388040]|0,1,2)|0)!=0){Q=1;i=b;return Q|0}if((R6((c[2388040]|0)+262145|0,2,2)|0)!=0){Q=1;i=b;return Q|0}if((R6((c[2388040]|0)+262144|0,3,2)|0)!=0){Q=1;i=b;return Q|0}R=c[3527426]|0;if((c[3542200]|0)==0){Q=1;i=b;return Q|0}S=O+108|0;c[S>>2]=0;T=O+100|0;c[T>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](O,4)|0;do{if((c[S>>2]|0)!=0){O=c[T>>2]|0;c[P>>2]=9534384;U=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[U&16383](P,4,0)|0;if((O|0)<1){Q=1;i=b;return Q|0}if((gzL(R,0,4)|0)==0){break}else{Q=1}i=b;return Q|0}}while(0);R=c[3529554]|0;if((c[3542200]|0)==0){Q=1;i=b;return Q|0}P=M+108|0;c[P>>2]=0;T=M+100|0;c[T>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](M,5)|0;do{if((c[P>>2]|0)!=0){M=c[T>>2]|0;c[N>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](N,5,0)|0;if((M|0)<1){Q=1;i=b;return Q|0}if((gzL(R,0,5)|0)==0){break}else{Q=1}i=b;return Q|0}}while(0);R=(c[3529554]|0)+32768|0;if((c[3542200]|0)==0){Q=1;i=b;return Q|0}N=K+108|0;c[N>>2]=0;T=K+100|0;c[T>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](K,6)|0;do{if((c[N>>2]|0)!=0){K=c[T>>2]|0;c[L>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](L,6,0)|0;if((K|0)<1){Q=1;i=b;return Q|0}if((gzL(R,0,6)|0)==0){break}else{Q=1}i=b;return Q|0}}while(0);R=c[3529554]|0;L=c[2406550]|0;T=0;do{N=T<<6;gGz(L+N|0,0,64);K=0;do{P=1<<3-K;M=(c[1983688+(K<<2)>>2]|0)+N|0;S=0;do{O=M+(c[1238464+(S<<2)>>2]|0)|0;U=(S<<3)+N|0;V=0;do{W=O+(c[614800+(V<<2)>>2]|0)|0;if((d[R+((W|0)/8|0)|0]&128>>>((W&7)>>>0)|0)!=0){W=L+(U+V)|0;a[W]=(d[W]|P)&255}V=V+1|0;}while((V|0)<8);S=S+1|0;}while((S|0)<8);K=K+1|0;}while((K|0)<4);T=T+1|0;}while((T|0)<2048);gGz(R|0,0,524288);if((c[3542200]|0)==0){Q=1;i=b;return Q|0}T=I+108|0;c[T>>2]=0;L=I+100|0;c[L>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](I,7)|0;do{if((c[T>>2]|0)!=0){I=c[L>>2]|0;c[J>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](J,7,0)|0;if((I|0)<1){Q=1;i=b;return Q|0}if((gzL(R,0,7)|0)==0){break}else{Q=1}i=b;return Q|0}}while(0);R=(c[3529554]|0)+65536|0;if((c[3542200]|0)==0){Q=1;i=b;return Q|0}J=G+108|0;c[J>>2]=0;L=G+100|0;c[L>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](G,8)|0;do{if((c[J>>2]|0)!=0){G=c[L>>2]|0;c[H>>2]=9534384;T=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[T&16383](H,8,0)|0;if((G|0)<1){Q=1;i=b;return Q|0}if((gzL(R,0,8)|0)==0){break}else{Q=1}i=b;return Q|0}}while(0);R=(c[3529554]|0)+131072|0;if((c[3542200]|0)==0){Q=1;i=b;return Q|0}H=E+108|0;c[H>>2]=0;L=E+100|0;c[L>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](E,9)|0;do{if((c[H>>2]|0)!=0){E=c[L>>2]|0;c[F>>2]=9534384;J=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[J&16383](F,9,0)|0;if((E|0)<1){Q=1;i=b;return Q|0}if((gzL(R,0,9)|0)==0){break}else{Q=1}i=b;return Q|0}}while(0);R=(c[3529554]|0)+196608|0;if((c[3542200]|0)==0){Q=1;i=b;return Q|0}F=C+108|0;c[F>>2]=0;L=C+100|0;c[L>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](C,10)|0;do{if((c[F>>2]|0)!=0){C=c[L>>2]|0;c[D>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](D,10,0)|0;if((C|0)<1){Q=1;i=b;return Q|0}if((gzL(R,0,10)|0)==0){break}else{Q=1}i=b;return Q|0}}while(0);R=c[3529554]|0;D=c[2386350]|0;L=0;do{F=L<<8;gGz(D+F|0,0,256);C=0;do{H=1<<3-C;E=(c[1179e3+(C<<2)>>2]|0)+F|0;J=0;do{G=E+(c[609008+(J<<2)>>2]|0)|0;T=(J<<4)+F|0;I=0;do{K=G+(c[612640+(I<<2)>>2]|0)|0;if((d[R+((K|0)/8|0)|0]&128>>>((K&7)>>>0)|0)!=0){K=D+(T+I)|0;a[K]=(d[K]|H)&255}I=I+1|0;}while((I|0)<16);J=J+1|0;}while((J|0)<16);C=C+1|0;}while((C|0)<4);L=L+1|0;}while((L|0)<2048);gGz(R|0,0,524288);L=R+131072|0;if((c[3542200]|0)==0){Q=1;i=b;return Q|0}R=A+108|0;c[R>>2]=0;D=A+100|0;c[D>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](A,11)|0;do{if((c[R>>2]|0)!=0){A=c[D>>2]|0;c[B>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](B,11,0)|0;if((A|0)<1){Q=1;i=b;return Q|0}if((gzL(L,0,11)|0)==0){break}else{Q=1}i=b;return Q|0}}while(0);L=(c[3529554]|0)+196608|0;if((c[3542200]|0)==0){Q=1;i=b;return Q|0}B=y+108|0;c[B>>2]=0;D=y+100|0;c[D>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](y,12)|0;do{if((c[B>>2]|0)!=0){y=c[D>>2]|0;c[z>>2]=9534384;R=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[R&16383](z,12,0)|0;if((y|0)<1){Q=1;i=b;return Q|0}if((gzL(L,0,12)|0)==0){break}else{Q=1}i=b;return Q|0}}while(0);L=c[3529554]|0;z=L+32768|0;D=L+131072|0;gGC(z|0,D|0,32768)|0;D=L+163840|0;gGC(L|0,D|0,32768)|0;D=L+98304|0;z=L+196608|0;gGC(D|0,z|0,32768)|0;z=L+65536|0;D=L+229376|0;gGC(z|0,D|0,32768)|0;D=c[2386348]|0;z=0;do{B=z<<8;gGz(D+B|0,0,256);y=0;do{R=1<<3-y;A=(c[611416+(y<<2)>>2]|0)+B|0;C=0;do{F=A+(c[609008+(C<<2)>>2]|0)|0;J=(C<<4)+B|0;H=0;do{E=F+(c[612640+(H<<2)>>2]|0)|0;if((d[L+((E|0)/8|0)|0]&128>>>((E&7)>>>0)|0)!=0){E=D+(J+H)|0;a[E]=(d[E]|R)&255}H=H+1|0;}while((H|0)<16);C=C+1|0;}while((C|0)<16);y=y+1|0;}while((y|0)<4);z=z+1|0;}while((z|0)<1024);gGz(L|0,0,524288);if((c[3542200]|0)==0){Q=1;i=b;return Q|0}z=w+108|0;c[z>>2]=0;D=w+100|0;c[D>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](w,13)|0;do{if((c[z>>2]|0)!=0){w=c[D>>2]|0;c[x>>2]=9534384;y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[y&16383](x,13,0)|0;if((w|0)<1){Q=1;i=b;return Q|0}if((gzL(L,0,13)|0)==0){break}else{Q=1}i=b;return Q|0}}while(0);L=(c[3529554]|0)+65536|0;if((c[3542200]|0)==0){Q=1;i=b;return Q|0}x=u+108|0;c[x>>2]=0;D=u+100|0;c[D>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](u,14)|0;do{if((c[x>>2]|0)!=0){u=c[D>>2]|0;c[v>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](v,14,0)|0;if((u|0)<1){Q=1;i=b;return Q|0}if((gzL(L,0,14)|0)==0){break}else{Q=1}i=b;return Q|0}}while(0);L=(c[3529554]|0)+131072|0;if((c[3542200]|0)==0){Q=1;i=b;return Q|0}v=s+108|0;c[v>>2]=0;D=s+100|0;c[D>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](s,15)|0;do{if((c[v>>2]|0)!=0){s=c[D>>2]|0;c[t>>2]=9534384;x=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[x&16383](t,15,0)|0;if((s|0)<1){Q=1;i=b;return Q|0}if((gzL(L,0,15)|0)==0){break}else{Q=1}i=b;return Q|0}}while(0);L=(c[3529554]|0)+196608|0;if((c[3542200]|0)==0){Q=1;i=b;return Q|0}t=q+108|0;c[t>>2]=0;D=q+100|0;c[D>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](q,16)|0;do{if((c[t>>2]|0)!=0){q=c[D>>2]|0;c[r>>2]=9534384;v=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[v&16383](r,16,0)|0;if((q|0)<1){Q=1;i=b;return Q|0}if((gzL(L,0,16)|0)==0){break}else{Q=1}i=b;return Q|0}}while(0);L=(c[3529554]|0)+262144|0;if((c[3542200]|0)==0){Q=1;i=b;return Q|0}r=o+108|0;c[r>>2]=0;D=o+100|0;c[D>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](o,17)|0;do{if((c[r>>2]|0)!=0){o=c[D>>2]|0;c[p>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](p,17,0)|0;if((o|0)<1){Q=1;i=b;return Q|0}if((gzL(L,0,17)|0)==0){break}else{Q=1}i=b;return Q|0}}while(0);L=(c[3529554]|0)+327680|0;if((c[3542200]|0)==0){Q=1;i=b;return Q|0}p=m+108|0;c[p>>2]=0;D=m+100|0;c[D>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,18)|0;do{if((c[p>>2]|0)!=0){m=c[D>>2]|0;c[n>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](n,18,0)|0;if((m|0)<1){Q=1;i=b;return Q|0}if((gzL(L,0,18)|0)==0){break}else{Q=1}i=b;return Q|0}}while(0);L=(c[3529554]|0)+393216|0;if((c[3542200]|0)==0){Q=1;i=b;return Q|0}n=k+108|0;c[n>>2]=0;D=k+100|0;c[D>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,19)|0;do{if((c[n>>2]|0)!=0){k=c[D>>2]|0;c[l>>2]=9534384;p=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[p&16383](l,19,0)|0;if((k|0)<1){Q=1;i=b;return Q|0}if((gzL(L,0,19)|0)==0){break}else{Q=1}i=b;return Q|0}}while(0);L=(c[3529554]|0)+458752|0;if((c[3542200]|0)==0){Q=1;i=b;return Q|0}l=g+108|0;c[l>>2]=0;D=g+100|0;c[D>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,20)|0;do{if((c[l>>2]|0)!=0){g=c[D>>2]|0;c[j>>2]=9534384;n=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[n&16383](j,20,0)|0;if((g|0)<1){Q=1;i=b;return Q|0}if((gzL(L,0,20)|0)==0){break}else{Q=1}i=b;return Q|0}}while(0);L=c[3529554]|0;j=c[3529604]|0;D=0;do{l=D<<8;gGz(j+l|0,0,256);g=0;do{n=1<<3-g;k=(c[961536+(g<<2)>>2]|0)+l|0;p=0;do{m=k+(c[609008+(p<<2)>>2]|0)|0;r=(p<<4)+l|0;o=0;do{t=m+(c[612640+(o<<2)>>2]|0)|0;if((d[L+((t|0)/8|0)|0]&128>>>((t&7)>>>0)|0)!=0){t=j+(r+o)|0;a[t]=(d[t]|n)&255}o=o+1|0;}while((o|0)<16);p=p+1|0;}while((p|0)<16);g=g+1|0;}while((g|0)<4);D=D+1|0;}while((D|0)<4096);D=c[3541206]|0;if((c[3542200]|0)==0){Q=1;i=b;return Q|0}j=e+108|0;c[j>>2]=0;L=e+100|0;c[L>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,21)|0;do{if((c[j>>2]|0)!=0){e=c[L>>2]|0;c[f>>2]=9534384;g=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[g&16383](f,21,0)|0;if((e|0)<1){Q=1;i=b;return Q|0}if((gzL(D,0,21)|0)==0){break}else{Q=1}i=b;return Q|0}}while(0);D=c[3529554]|0;f=0;while(1){if((f|0)>=1024){break}X=9638528+(f<<2)|0;if((c[X>>2]|0)==(D|0)){Y=19603;break}else{f=f+1|0}}if((Y|0)==19603){gGr(D);c[X>>2]=0}c[3529554]=0;c[2433476]=11484;c[2406596]=1;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];X=c[3532592]|0;if((X|0)!=0){gGC(9104152,X|0,280)|0}c[2113054]=c[2113060]}RI();X=c[2394]|0;D=c[14130368+(X<<2)>>2]|0;if((D|0)!=0){gGC(D|0,9104152,280)|0}c[8452240+(X<<2)>>2]=c[2113054];c[2394]=-1;c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;lw(c[3540984]|0);c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){X=0;do{lN(X);mB(X);X=X+1|0;}while((X|0)<(c[2385508]|0))}c[2113156]=0;a[9628264]=0;c[2407033]=0;X=c[3541206]|0;c[3541190]=X;c[3541198]=X;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=X+256;c[3541199]=X+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=X+512;c[3541200]=X+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=X+768;c[3541201]=X+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2444194]=0;a[9545184]=0;a[9758144]=0;a[9759752]=0;c[3527346]=0;gGz(9754968,0,3);a[9718113]=11;a[9718112]=11;c[3528556]=0;X=c[2433594]|0;c[2443776]=X;L24787:do{if((X|0)!=0){D=X|0;gGC(9660952,D|0,52)|0;switch(a[9660952]|0){case 0:{c[2309668]=638960;break L24787;break};case 1:{c[2309668]=634096;break L24787;break};case 3:{c[2309668]=639984;break L24787;break};case 4:{c[2309668]=7356016;break L24787;break};case 5:{c[2309668]=7354992;break L24787;break};case 2:{c[2309668]=638960;break L24787;break};default:{break L24787}}}}while(0);c[2113164]=c[2432850];gu[c[X+56>>2]&16383]();X=c[2443776]|0;if((X|0)!=0){D=X|0;gGC(D|0,9660952,52)|0}c[9731400+(c[3528556]<<2)>>2]=c[2113164];c[2443776]=0;c[3528556]=-1;Q=0;i=b;return Q|0}function aBq(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;fvR();if((c[2392]|0)>=0){b=0;do{d=14130368+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}d=14130384+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}b=b+1|0;}while((b|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;b=c[3541518]|0;if((b|0)!=0){gGr(b|0);c[3541518]=0}if((c[2385508]|0)>0){c[2113008]=0;c[2076598]=0;c[2383582]=0}c[2438228]=0;c[2433526]=0;c[2406676]=0;c[3528472]=0;b=c[2406680]|0;if((b|0)!=0){gGr(b);c[2406680]=0}c[2385508]=0;c[2432978]=0;a[64240]=0;b=a[7452584]|0;if(b){d=0;e=b&1;while(1){b=14163936+(d<<2)|0;f=c[b>>2]|0;g=c[2113006]|0;if((g|0)==0){h=19699}else{i=g-1|0;c[2113006]=i;if((i|0)==0){h=19699}}if((h|0)==19699){h=0;c[2383474]=0}if((f|0)==0){j=e}else{gGr(f);j=a[7452584]&1}c[b>>2]=0;b=d+1|0;if((b|0)<(j|0)){d=b;e=j}else{break}}}a[7452584]=0;c[2438224]=0;c[2433522]=0;c[2406672]=0;c[3528468]=0;j=c[2406688]|0;if((j|0)!=0){gGr(j);c[2406688]=0}c[2432972]=0;Uw(0);c[2113070]=0;c[2113068]=0;j=c[2112926]|0;if((j|0)!=0){gGr(j);c[2112926]=0}c[2444194]=0;a[9545184]=0;a[9758144]=0;a[9759752]=0;c[3527346]=0;c[2429766]=0;c[2429530]=0;c[2429518]=0;c[2429334]=0;c[2429516]=0;c[2429332]=0;gGz(9754968,0,3);a[9720912]=0;c[2433476]=0;c[2433366]=0;c[2406596]=0;a[1950800]=0;a[986968]=0;a[9718113]=0;a[9718112]=0;j=c[2426664]|0;e=0;while(1){if((e|0)>=1024){h=19712;break}k=9638528+(e<<2)|0;if((c[k>>2]|0)==(j|0)){break}else{e=e+1|0}}if((h|0)==19712){c[2426664]=0;return 0}gGr(j);c[k>>2]=0;c[2426664]=0;return 0}function aBr(){var b=0,d=0,e=0,f=0,g=0,i=0;if((a[9623568]|0)!=0){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];b=c[3532592]|0;if((b|0)!=0){gGC(9104152,b|0,280)|0}c[2113054]=c[2113060]}RI();b=c[2394]|0;d=c[14130368+(b<<2)>>2]|0;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[8452240+(b<<2)>>2]=c[2113054];c[2394]=-1;c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;lw(c[3540984]|0);c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){b=0;do{lN(b);mB(b);b=b+1|0;}while((b|0)<(c[2385508]|0))}c[2113156]=0;a[9628264]=0;c[2407033]=0;b=c[3541206]|0;c[3541190]=b;c[3541198]=b;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=b+256;c[3541199]=b+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=b+512;c[3541200]=b+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=b+768;c[3541201]=b+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2444194]=0;a[9545184]=0;a[9758144]=0;a[9759752]=0;c[3527346]=0;gGz(9754968,0,3);a[9718113]=11;a[9718112]=11;c[3528556]=0;b=c[2433594]|0;c[2443776]=b;L24863:do{if((b|0)!=0){d=b|0;gGC(9660952,d|0,52)|0;switch(a[9660952]|0){case 5:{c[2309668]=7354992;break L24863;break};case 4:{c[2309668]=7356016;break L24863;break};case 0:{c[2309668]=638960;break L24863;break};case 2:{c[2309668]=638960;break L24863;break};case 1:{c[2309668]=634096;break L24863;break};case 3:{c[2309668]=639984;break L24863;break};default:{break L24863}}}}while(0);c[2113164]=c[2432850];gu[c[b+56>>2]&16383]();b=c[2443776]|0;if((b|0)!=0){d=b|0;gGC(d|0,9660952,52)|0}c[9731400+(c[3528556]<<2)>>2]=c[2113164];c[2443776]=0;c[3528556]=-1}a[9625536]=0;a[9625544]=0;a[9625552]=0;d=0;b=0;e=0;f=0;do{b=((a[9759320+d|0]&1)<<d|b&255)&255;e=((a[9759128+d|0]&1)<<d|e&255)&255;f=((a[9758936+d|0]&1)<<d|f&255)&255;d=d+1|0;}while((d|0)<8);a[9625552]=b;a[9625544]=e;a[9625536]=f;if((b&3)==3){f=b&-4;a[9625552]=f;g=f}else{g=b}if((g&12)==12){a[9625552]=g&-13}if((e&3)==3){g=e&-4;a[9625544]=g;i=g}else{i=e}if((i&12)==12){a[9625544]=i&-13}a[6518368]=1;c[2440504]=26135;i=c[2392]|0;if((i|0)>=0){gGz(8452240,0,((i|0)>0?(i<<2)+4|0:4)|0)}c[2113054]=0;i=c[2113166]|0;if((i|0)>0){gGz(9731400,0,((i|0)>1?i<<2:4)|0)}c[2113164]=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];i=c[3532592]|0;if((i|0)!=0){gGC(9104152,i|0,280)|0}c[2113054]=c[2113060]}c[3528556]=0;i=c[2433594]|0;c[2443776]=i;L24904:do{if((i|0)!=0){e=i|0;gGC(9660952,e|0,52)|0;switch(a[9660952]|0){case 0:{c[2309668]=638960;break L24904;break};case 1:{c[2309668]=634096;break L24904;break};case 3:{c[2309668]=639984;break L24904;break};case 4:{c[2309668]=7356016;break L24904;break};case 5:{c[2309668]=7354992;break L24904;break};case 2:{c[2309668]=638960;break L24904;break};default:{break L24904}}}}while(0);c[2113164]=c[2432850];i=0;e=1;do{Sb(ag(e?659:0,i)|0);do{if((i|0)==8){a[9545184]=0}else if((i|0)==248){a[9545184]=1;c[8452200+(c[2394]<<2)>>2]=4102;c[2276080]=1536;if((c[2276079]|0)>>>0>=1536){break}RH(6)}}while(0);UF(ag((c[2440504]|0)/264|0,i)|0)|0;i=i+1|0;e=a[6518368]|0}while((i|0)<264);i=e?174239:0;e=gGU(i,0,2048e6,0)|0;g=c[2438228]|0;b=gGS(e,K,g,(g|0)<0|0?-1:0)|0;g=b;Sb(i);i=c[2443830]|0;if((i|0)<1073676288){c[2443830]=i-g}i=c[2443831]|0;if((i|0)<1073676288){c[2443831]=i-g}i=(c[3528512]|0)-g|0;c[3528512]=(i|0)<0?0:i;i=c[2440504]|0;g=gGU(i,(i|0)<0|0?-1:0,2048e6,0)|0;b=c[2438224]|0;e=gGS(g,K,b,(b|0)<0|0?-1:0)|0;b=e;UF(i)|0;i=c[2443826]|0;if((i|0)<1073676288){c[2443826]=i-b}i=c[2443827]|0;if((i|0)<1073676288){c[2443827]=i-b}i=(c[3528508]|0)-b|0;c[3528508]=(i|0)<0?0:i;i=c[2112964]|0;if((i|0)!=0){gg[c[3542122]&4095](i,a[9688]|0?534:0);gg[c[3542112]&4095](c[2112964]|0,a[9688]|0?534:0);Uu(0,c[2112964]|0,a[9688]|0?534:0)}i=c[2394]|0;b=c[14130368+(i<<2)>>2]|0;if((b|0)!=0){gGC(b|0,9104152,280)|0}c[8452240+(i<<2)>>2]=c[2113054];c[2394]=-1;i=c[2443776]|0;if((i|0)!=0){b=i|0;gGC(b|0,9660952,52)|0}c[9731400+(c[3528556]<<2)>>2]=c[2113164];c[2443776]=0;c[3528556]=-1;b=c[2433476]|0;if(!((c[2112968]|0)!=0&(b|0)!=0)){return 0}gu[b&16383]();return 0}function aBs(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;e=i;i=i+80|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;if((b&64|0)==0){aCU(b,d);i=e;return 0}l=k|0;if((c[2113166]|0)<=0){aCU(b,d);i=e;return 0}m=k+7|0;k=j|0;n=j+4|0;o=j+12|0;p=h;q=h|0;r=h+4|0;s=h+12|0;t=g;u=g|0;v=g+4|0;w=g+12|0;x=f;y=f|0;z=f+4|0;A=f+12|0;B=0;do{C=c[9734376+(B<<2)>>2]|0;D=C+36|0;E=c[D>>2]|0;gGC(l|0,614768,9)|0;a[m]=B+48&255;c[k>>2]=C;c[n>>2]=52;c[o>>2]=l;gj[c[2076592]&4095](j)|0;gGz(p|0,0,12);c[q>>2]=C+3172;c[r>>2]=4;c[s>>2]=165288;gj[c[2076592]&4095](h)|0;gGz(t|0,0,12);c[u>>2]=C+3176;c[v>>2]=4;c[w>>2]=501592;gj[c[2076592]&4095](g)|0;gGz(x|0,0,12);c[y>>2]=C+3180;c[z>>2]=4;c[A>>2]=386080;gj[c[2076592]&4095](f)|0;c[D>>2]=E;B=B+1|0;}while((B|0)<(c[2113166]|0));aCU(b,d);i=e;return 0}function aBt(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4045660+(b*112|0)>>2];c[a+104>>2]=c[4045664+(b*112|0)>>2];c[a+108>>2]=c[4045668+(b*112|0)>>2];d=0;return d|0}function aBu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=4045560+(b*112|0);e=0;return e|0}function aBv(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1951580+(b*112|0)>>2];c[a+104>>2]=c[1951584+(b*112|0)>>2];c[a+108>>2]=c[1951588+(b*112|0)>>2];d=0;return d|0}function aBw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=1951480+(b*112|0);e=0;return e|0}function aBx(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>24){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1277748+(b*112|0)>>2];c[a+104>>2]=c[1277752+(b*112|0)>>2];c[a+108>>2]=c[1277756+(b*112|0)>>2];d=0;return d|0}function aBy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<25&(d|0)==0)){e=1;return e|0}c[a>>2]=1277648+(b*112|0);e=0;return e|0}function aBz(){var b=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0;b=i;i=i+2400|0;e=b|0;f=b+112|0;g=b+120|0;j=b+232|0;k=b+240|0;l=b+352|0;m=b+360|0;n=b+472|0;o=b+480|0;p=b+592|0;q=b+600|0;r=b+712|0;s=b+720|0;t=b+832|0;u=b+840|0;v=b+952|0;w=b+960|0;x=b+1072|0;y=b+1080|0;z=b+1192|0;A=b+1200|0;B=b+1312|0;C=b+1320|0;D=b+1432|0;E=b+1440|0;F=b+1552|0;G=b+1560|0;H=b+1672|0;I=b+1680|0;J=b+1792|0;K=b+1800|0;L=b+1912|0;M=b+1920|0;N=b+2032|0;O=b+2040|0;P=b+2152|0;Q=b+2160|0;R=b+2272|0;S=b+2280|0;T=b+2392|0;aCN();if((R6((c[2388040]|0)+1|0,0,2)|0)!=0){U=1;i=b;return U|0}if((R6(c[2388040]|0,1,2)|0)!=0){U=1;i=b;return U|0}if((R6((c[2388040]|0)+262145|0,2,2)|0)!=0){U=1;i=b;return U|0}if((R6((c[2388040]|0)+262144|0,3,2)|0)!=0){U=1;i=b;return U|0}V=c[3527426]|0;if((c[3542200]|0)==0){U=1;i=b;return U|0}W=S+108|0;c[W>>2]=0;X=S+100|0;c[X>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](S,4)|0;do{if((c[W>>2]|0)!=0){S=c[X>>2]|0;c[T>>2]=9534384;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Y&16383](T,4,0)|0;if((S|0)<1){U=1;i=b;return U|0}if((gzL(V,0,4)|0)==0){break}else{U=1}i=b;return U|0}}while(0);V=c[3529554]|0;if((c[3542200]|0)==0){U=1;i=b;return U|0}T=Q+108|0;c[T>>2]=0;X=Q+100|0;c[X>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](Q,5)|0;do{if((c[T>>2]|0)!=0){Q=c[X>>2]|0;c[R>>2]=9534384;W=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[W&16383](R,5,0)|0;if((Q|0)<1){U=1;i=b;return U|0}if((gzL(V,0,5)|0)==0){break}else{U=1}i=b;return U|0}}while(0);V=(c[3529554]|0)+32768|0;if((c[3542200]|0)==0){U=1;i=b;return U|0}R=O+108|0;c[R>>2]=0;X=O+100|0;c[X>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](O,6)|0;do{if((c[R>>2]|0)!=0){O=c[X>>2]|0;c[P>>2]=9534384;T=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[T&16383](P,6,0)|0;if((O|0)<1){U=1;i=b;return U|0}if((gzL(V,0,6)|0)==0){break}else{U=1}i=b;return U|0}}while(0);V=c[3529554]|0;P=c[2406550]|0;X=0;do{R=X<<6;gGz(P+R|0,0,64);O=0;do{T=1<<3-O;Q=(c[1983688+(O<<2)>>2]|0)+R|0;W=0;do{S=Q+(c[1238464+(W<<2)>>2]|0)|0;Y=(W<<3)+R|0;Z=0;do{_=S+(c[614800+(Z<<2)>>2]|0)|0;if((d[V+((_|0)/8|0)|0]&128>>>((_&7)>>>0)|0)!=0){_=P+(Y+Z)|0;a[_]=(d[_]|T)&255}Z=Z+1|0;}while((Z|0)<8);W=W+1|0;}while((W|0)<8);O=O+1|0;}while((O|0)<4);X=X+1|0;}while((X|0)<2048);gGz(V|0,0,524288);if((c[3542200]|0)==0){U=1;i=b;return U|0}X=M+108|0;c[X>>2]=0;P=M+100|0;c[P>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](M,7)|0;do{if((c[X>>2]|0)!=0){M=c[P>>2]|0;c[N>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](N,7,0)|0;if((M|0)<1){U=1;i=b;return U|0}if((gzL(V,0,7)|0)==0){break}else{U=1}i=b;return U|0}}while(0);V=(c[3529554]|0)+65536|0;if((c[3542200]|0)==0){U=1;i=b;return U|0}N=K+108|0;c[N>>2]=0;P=K+100|0;c[P>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](K,8)|0;do{if((c[N>>2]|0)!=0){K=c[P>>2]|0;c[L>>2]=9534384;X=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[X&16383](L,8,0)|0;if((K|0)<1){U=1;i=b;return U|0}if((gzL(V,0,8)|0)==0){break}else{U=1}i=b;return U|0}}while(0);V=(c[3529554]|0)+131072|0;if((c[3542200]|0)==0){U=1;i=b;return U|0}L=I+108|0;c[L>>2]=0;P=I+100|0;c[P>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](I,9)|0;do{if((c[L>>2]|0)!=0){I=c[P>>2]|0;c[J>>2]=9534384;N=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[N&16383](J,9,0)|0;if((I|0)<1){U=1;i=b;return U|0}if((gzL(V,0,9)|0)==0){break}else{U=1}i=b;return U|0}}while(0);V=(c[3529554]|0)+196608|0;if((c[3542200]|0)==0){U=1;i=b;return U|0}J=G+108|0;c[J>>2]=0;P=G+100|0;c[P>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](G,10)|0;do{if((c[J>>2]|0)!=0){G=c[P>>2]|0;c[H>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](H,10,0)|0;if((G|0)<1){U=1;i=b;return U|0}if((gzL(V,0,10)|0)==0){break}else{U=1}i=b;return U|0}}while(0);V=c[3529554]|0;H=c[2386350]|0;P=0;do{J=P<<8;gGz(H+J|0,0,256);G=0;do{L=1<<3-G;I=(c[1179e3+(G<<2)>>2]|0)+J|0;N=0;do{K=I+(c[609008+(N<<2)>>2]|0)|0;X=(N<<4)+J|0;M=0;do{O=K+(c[612640+(M<<2)>>2]|0)|0;if((d[V+((O|0)/8|0)|0]&128>>>((O&7)>>>0)|0)!=0){O=H+(X+M)|0;a[O]=(d[O]|L)&255}M=M+1|0;}while((M|0)<16);N=N+1|0;}while((N|0)<16);G=G+1|0;}while((G|0)<4);P=P+1|0;}while((P|0)<2048);gGz(V|0,0,524288);P=V+32768|0;if((c[3542200]|0)==0){U=1;i=b;return U|0}V=E+108|0;c[V>>2]=0;H=E+100|0;c[H>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](E,11)|0;do{if((c[V>>2]|0)!=0){E=c[H>>2]|0;c[F>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](F,11,0)|0;if((E|0)<1){U=1;i=b;return U|0}if((gzL(P,0,11)|0)==0){break}else{U=1}i=b;return U|0}}while(0);P=c[3529554]|0;if((c[3542200]|0)==0){U=1;i=b;return U|0}F=C+108|0;c[F>>2]=0;H=C+100|0;c[H>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](C,12)|0;do{if((c[F>>2]|0)!=0){C=c[H>>2]|0;c[D>>2]=9534384;V=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[V&16383](D,12,0)|0;if((C|0)<1){U=1;i=b;return U|0}if((gzL(P,0,12)|0)==0){break}else{U=1}i=b;return U|0}}while(0);P=(c[3529554]|0)+98304|0;if((c[3542200]|0)==0){U=1;i=b;return U|0}D=A+108|0;c[D>>2]=0;H=A+100|0;c[H>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](A,13)|0;do{if((c[D>>2]|0)!=0){A=c[H>>2]|0;c[B>>2]=9534384;F=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[F&16383](B,13,0)|0;if((A|0)<1){U=1;i=b;return U|0}if((gzL(P,0,13)|0)==0){break}else{U=1}i=b;return U|0}}while(0);P=(c[3529554]|0)+65536|0;if((c[3542200]|0)==0){U=1;i=b;return U|0}B=y+108|0;c[B>>2]=0;H=y+100|0;c[H>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](y,14)|0;do{if((c[B>>2]|0)!=0){y=c[H>>2]|0;c[z>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](z,14,0)|0;if((y|0)<1){U=1;i=b;return U|0}if((gzL(P,0,14)|0)==0){break}else{U=1}i=b;return U|0}}while(0);P=c[3529554]|0;z=c[2386348]|0;H=0;do{B=H<<8;gGz(z+B|0,0,256);y=0;do{D=1<<3-y;A=(c[611416+(y<<2)>>2]|0)+B|0;F=0;do{C=A+(c[609008+(F<<2)>>2]|0)|0;V=(F<<4)+B|0;E=0;do{G=C+(c[612640+(E<<2)>>2]|0)|0;if((d[P+((G|0)/8|0)|0]&128>>>((G&7)>>>0)|0)!=0){G=z+(V+E)|0;a[G]=(d[G]|D)&255}E=E+1|0;}while((E|0)<16);F=F+1|0;}while((F|0)<16);y=y+1|0;}while((y|0)<4);H=H+1|0;}while((H|0)<1024);gGz(P|0,0,524288);if((c[3542200]|0)==0){U=1;i=b;return U|0}H=w+108|0;c[H>>2]=0;z=w+100|0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](w,15)|0;do{if((c[H>>2]|0)!=0){w=c[z>>2]|0;c[x>>2]=9534384;y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[y&16383](x,15,0)|0;if((w|0)<1){U=1;i=b;return U|0}if((gzL(P,0,15)|0)==0){break}else{U=1}i=b;return U|0}}while(0);P=(c[3529554]|0)+65536|0;if((c[3542200]|0)==0){U=1;i=b;return U|0}x=u+108|0;c[x>>2]=0;z=u+100|0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](u,16)|0;do{if((c[x>>2]|0)!=0){u=c[z>>2]|0;c[v>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](v,16,0)|0;if((u|0)<1){U=1;i=b;return U|0}if((gzL(P,0,16)|0)==0){break}else{U=1}i=b;return U|0}}while(0);P=(c[3529554]|0)+131072|0;if((c[3542200]|0)==0){U=1;i=b;return U|0}v=s+108|0;c[v>>2]=0;z=s+100|0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](s,17)|0;do{if((c[v>>2]|0)!=0){s=c[z>>2]|0;c[t>>2]=9534384;x=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[x&16383](t,17,0)|0;if((s|0)<1){U=1;i=b;return U|0}if((gzL(P,0,17)|0)==0){break}else{U=1}i=b;return U|0}}while(0);P=(c[3529554]|0)+196608|0;if((c[3542200]|0)==0){U=1;i=b;return U|0}t=q+108|0;c[t>>2]=0;z=q+100|0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](q,18)|0;do{if((c[t>>2]|0)!=0){q=c[z>>2]|0;c[r>>2]=9534384;v=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[v&16383](r,18,0)|0;if((q|0)<1){U=1;i=b;return U|0}if((gzL(P,0,18)|0)==0){break}else{U=1}i=b;return U|0}}while(0);P=(c[3529554]|0)+262144|0;if((c[3542200]|0)==0){U=1;i=b;return U|0}r=o+108|0;c[r>>2]=0;z=o+100|0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](o,19)|0;do{if((c[r>>2]|0)!=0){o=c[z>>2]|0;c[p>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](p,19,0)|0;if((o|0)<1){U=1;i=b;return U|0}if((gzL(P,0,19)|0)==0){break}else{U=1}i=b;return U|0}}while(0);P=(c[3529554]|0)+327680|0;if((c[3542200]|0)==0){U=1;i=b;return U|0}p=m+108|0;c[p>>2]=0;z=m+100|0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,20)|0;do{if((c[p>>2]|0)!=0){m=c[z>>2]|0;c[n>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](n,20,0)|0;if((m|0)<1){U=1;i=b;return U|0}if((gzL(P,0,20)|0)==0){break}else{U=1}i=b;return U|0}}while(0);P=(c[3529554]|0)+393216|0;if((c[3542200]|0)==0){U=1;i=b;return U|0}n=k+108|0;c[n>>2]=0;z=k+100|0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,21)|0;do{if((c[n>>2]|0)!=0){k=c[z>>2]|0;c[l>>2]=9534384;p=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[p&16383](l,21,0)|0;if((k|0)<1){U=1;i=b;return U|0}if((gzL(P,0,21)|0)==0){break}else{U=1}i=b;return U|0}}while(0);P=(c[3529554]|0)+458752|0;if((c[3542200]|0)==0){U=1;i=b;return U|0}l=g+108|0;c[l>>2]=0;z=g+100|0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,22)|0;do{if((c[l>>2]|0)!=0){g=c[z>>2]|0;c[j>>2]=9534384;n=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[n&16383](j,22,0)|0;if((g|0)<1){U=1;i=b;return U|0}if((gzL(P,0,22)|0)==0){break}else{U=1}i=b;return U|0}}while(0);P=c[3529554]|0;j=c[3529604]|0;z=0;do{l=z<<8;gGz(j+l|0,0,256);g=0;do{n=1<<3-g;k=(c[961536+(g<<2)>>2]|0)+l|0;p=0;do{m=k+(c[609008+(p<<2)>>2]|0)|0;r=(p<<4)+l|0;o=0;do{t=m+(c[612640+(o<<2)>>2]|0)|0;if((d[P+((t|0)/8|0)|0]&128>>>((t&7)>>>0)|0)!=0){t=j+(r+o)|0;a[t]=(d[t]|n)&255}o=o+1|0;}while((o|0)<16);p=p+1|0;}while((p|0)<16);g=g+1|0;}while((g|0)<4);z=z+1|0;}while((z|0)<4096);z=c[3541206]|0;if((c[3542200]|0)==0){U=1;i=b;return U|0}j=e+108|0;c[j>>2]=0;P=e+100|0;c[P>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,23)|0;do{if((c[j>>2]|0)!=0){e=c[P>>2]|0;c[f>>2]=9534384;g=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[g&16383](f,23,0)|0;if((e|0)<1){U=1;i=b;return U|0}if((gzL(z,0,23)|0)==0){break}else{U=1}i=b;return U|0}}while(0);z=c[3529554]|0;f=0;while(1){if((f|0)>=1024){break}$=9638528+(f<<2)|0;if((c[$>>2]|0)==(z|0)){aa=19956;break}else{f=f+1|0}}if((aa|0)==19956){gGr(z);c[$>>2]=0}c[3529554]=0;c[2433476]=11484;c[2406596]=1;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];$=c[3532592]|0;if(($|0)!=0){gGC(9104152,$|0,280)|0}c[2113054]=c[2113060]}RI();$=c[2394]|0;z=c[14130368+($<<2)>>2]|0;if((z|0)!=0){gGC(z|0,9104152,280)|0}c[8452240+($<<2)>>2]=c[2113054];c[2394]=-1;c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;lw(c[3540984]|0);c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){$=0;do{lN($);mB($);$=$+1|0;}while(($|0)<(c[2385508]|0))}c[2113156]=0;a[9628264]=0;c[2407033]=0;$=c[3541206]|0;c[3541190]=$;c[3541198]=$;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=$+256;c[3541199]=$+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=$+512;c[3541200]=$+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=$+768;c[3541201]=$+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2444194]=0;a[9545184]=0;a[9758144]=0;a[9759752]=0;c[3527346]=0;gGz(9754968,0,3);a[9718113]=11;a[9718112]=11;c[3528556]=0;$=c[2433594]|0;c[2443776]=$;L25288:do{if(($|0)!=0){z=$|0;gGC(9660952,z|0,52)|0;switch(a[9660952]|0){case 2:{c[2309668]=638960;break L25288;break};case 0:{c[2309668]=638960;break L25288;break};case 1:{c[2309668]=634096;break L25288;break};case 3:{c[2309668]=639984;break L25288;break};case 4:{c[2309668]=7356016;break L25288;break};case 5:{c[2309668]=7354992;break L25288;break};default:{break L25288}}}}while(0);c[2113164]=c[2432850];gu[c[$+56>>2]&16383]();$=c[2443776]|0;if(($|0)!=0){z=$|0;gGC(z|0,9660952,52)|0}c[9731400+(c[3528556]<<2)>>2]=c[2113164];c[2443776]=0;c[3528556]=-1;U=0;i=b;return U|0}function aBA(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4212092+(b*112|0)>>2];c[a+104>>2]=c[4212096+(b*112|0)>>2];c[a+108>>2]=c[4212100+(b*112|0)>>2];d=0;return d|0}function aBB(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=4211992+(b*112|0);e=0;return e|0}function aBC(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6352312+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aBD(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>44){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4214120+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aBE(){c[2433366]=3344;return aCy()|0}function aBF(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;fv9();if((c[2392]|0)>=0){b=0;do{d=14130368+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}d=14130384+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}b=b+1|0;}while((b|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;b=c[3541518]|0;if((b|0)!=0){gGr(b|0);c[3541518]=0}if((c[2385508]|0)>0){c[2113008]=0;c[2076598]=0;c[2383582]=0}c[2438228]=0;c[2433526]=0;c[2406676]=0;c[3528472]=0;b=c[2406680]|0;if((b|0)!=0){gGr(b);c[2406680]=0}c[2385508]=0;c[2432978]=0;a[64240]=0;b=a[7452584]|0;if(b){d=0;e=b&1;while(1){b=14163936+(d<<2)|0;f=c[b>>2]|0;g=c[2113006]|0;if((g|0)==0){h=20085}else{i=g-1|0;c[2113006]=i;if((i|0)==0){h=20085}}if((h|0)==20085){h=0;c[2383474]=0}if((f|0)==0){j=e}else{gGr(f);j=a[7452584]&1}c[b>>2]=0;b=d+1|0;if((b|0)<(j|0)){d=b;e=j}else{break}}}a[7452584]=0;c[2438224]=0;c[2433522]=0;c[2406672]=0;c[3528468]=0;j=c[2406688]|0;if((j|0)!=0){gGr(j);c[2406688]=0}c[2432972]=0;Uw(0);c[2113070]=0;c[2113068]=0;j=c[2112926]|0;if((j|0)!=0){gGr(j);c[2112926]=0}c[2444194]=0;a[9545184]=0;a[9758144]=0;a[9759752]=0;c[3527346]=0;c[2429766]=0;c[2429530]=0;c[2429518]=0;c[2429334]=0;c[2429516]=0;c[2429332]=0;gGz(9754968,0,3);a[9720912]=0;c[2433476]=0;c[2433366]=0;c[2406596]=0;a[1950800]=0;a[986968]=0;a[9718113]=0;a[9718112]=0;j=c[2426664]|0;e=0;while(1){if((e|0)>=1024){h=20099;break}k=9638528+(e<<2)|0;if((c[k>>2]|0)==(j|0)){break}else{e=e+1|0}}if((h|0)==20099){c[2426664]=0;return 0}gGr(j);c[k>>2]=0;c[2426664]=0;return 0}function aBG(){var b=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0;if((a[9623568]|0)!=0){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];b=c[3532592]|0;if((b|0)!=0){gGC(9104152,b|0,280)|0}c[2113054]=c[2113060]}RI();b=c[2394]|0;e=c[14130368+(b<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(b<<2)>>2]=c[2113054];c[2394]=-1;c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;lw(c[3540984]|0);c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){b=0;do{lN(b);mB(b);b=b+1|0;}while((b|0)<(c[2385508]|0))}c[2113156]=0;a[9628264]=0;c[2407033]=0;b=c[3541206]|0;c[3541190]=b;c[3541198]=b;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=b+256;c[3541199]=b+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=b+512;c[3541200]=b+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=b+768;c[3541201]=b+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2444194]=0;a[9545184]=0;a[9758144]=0;a[9759752]=0;c[3527346]=0;gGz(9754968,0,3);a[9718113]=11;a[9718112]=11;c[2388530]=9554128;b=c[2391608]|0;if((b|0)!=0){e=b;gGC(9661040,e|0,68)|0}c[2382]=0;e=c[2415273]|0;gGz(9661040,0,68);c[2415273]=e;a[9661063]=20;c[2415262]=511;e=c[2388539]|0;do{if((e|0)==0){b=c[2388532]|0;if((b|0)==0){f=0;g=8191;i=9554128;break}j=gj[b&4095](8190)|0;f=j;g=d[9661071]<<13|8191;i=c[2388530]|0}else{f=a[e+2046|0]|0;g=8191;i=9554128}}while(0);a[9661044]=f;f=c[i+16+(g>>>11<<2)>>2]|0;do{if((f|0)==0){e=c[i>>2]|0;if((e|0)==0){k=0;l=i;break}j=gj[e&4095](g)|0;k=j;l=c[2388530]|0}else{k=a[f+2047|0]|0;l=i}}while(0);a[9661045]=k;a[9661075]=4;a[9661073]=0;c[2415270]=131072;c[2415275]=0;gGz(9661084,0,5);k=c[l+12304>>2]|0;if((k|0)!=0){l=k;gGC(l|0,9661040,68)|0}c[2382]=-1}a[9625536]=0;a[9625544]=0;a[9625552]=0;l=0;k=0;i=0;f=0;do{k=((a[9759320+l|0]&1)<<l|k&255)&255;i=((a[9759128+l|0]&1)<<l|i&255)&255;f=((a[9758936+l|0]&1)<<l|f&255)&255;l=l+1|0;}while((l|0)<8);a[9625552]=k;a[9625544]=i;a[9625536]=f;if((k&3)==3){f=k&-4;a[9625552]=f;m=f}else{m=k}if((m&12)==12){a[9625552]=m&-13}if((i&3)==3){m=i&-4;a[9625544]=m;n=m}else{n=i}if((n&12)==12){a[9625544]=n&-13}if((a[9720920]|0)!=0){a[9718112]=(a[9718112]|0)+2&255}if((a[9720921]|0)!=0){a[9718112]=(a[9718112]|0)-2&255}if((a[9720922]|0)!=0){a[9718113]=(a[9718113]|0)+2&255}if((a[9720923]|0)!=0){a[9718113]=(a[9718113]|0)-2&255}a[6518368]=1;c[2440504]=34847;n=c[2392]|0;if((n|0)>=0){gGz(8452240,0,((n|0)>0?(n<<2)+4|0:4)|0)}c[2113054]=0;c[(c[2391608]|0)+60>>2]=0;c[(c[2391608]|0)+60>>2]=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];n=c[3532592]|0;if((n|0)!=0){gGC(9104152,n|0,280)|0}c[2113054]=c[2113060]}c[2388530]=9554128;n=c[2391608]|0;if((n|0)!=0){i=n;gGC(9661040,i|0,68)|0}c[2382]=0;i=0;n=1;do{Sb(ag(n?659:0,i)|0);do{if((i|0)==8){a[9545184]=0}else if((i|0)==248){a[9545184]=1;c[8452200+(c[2394]<<2)>>2]=8198;c[2276080]=1536;if((c[2276079]|0)>>>0>=1536){break}RH(6)}}while(0);UF(ag((c[2440504]|0)/264|0,i)|0)|0;i=i+1|0;n=a[6518368]|0}while((i|0)<264);i=n?174239:0;n=gGU(i,0,2048e6,0)|0;m=c[2438228]|0;k=gGS(n,K,m,(m|0)<0|0?-1:0)|0;m=k;Sb(i);i=c[2443830]|0;if((i|0)<1073676288){c[2443830]=i-m}i=c[2443831]|0;if((i|0)<1073676288){c[2443831]=i-m}i=(c[3528512]|0)-m|0;c[3528512]=(i|0)<0?0:i;i=c[2440504]|0;m=gGU(i,(i|0)<0|0?-1:0,2048e6,0)|0;k=c[2438224]|0;n=gGS(m,K,k,(k|0)<0|0?-1:0)|0;k=n;UF(i)|0;i=c[2443826]|0;if((i|0)<1073676288){c[2443826]=i-k}i=c[2443827]|0;if((i|0)<1073676288){c[2443827]=i-k}i=(c[3528508]|0)-k|0;c[3528508]=(i|0)<0?0:i;i=c[2112964]|0;if((i|0)!=0){gg[c[3542122]&4095](i,a[9688]|0?534:0);gg[c[3542112]&4095](c[2112964]|0,a[9688]|0?534:0);Uu(0,c[2112964]|0,a[9688]|0?534:0)}i=c[2394]|0;k=c[14130368+(i<<2)>>2]|0;if((k|0)!=0){gGC(k|0,9104152,280)|0}c[8452240+(i<<2)>>2]=c[2113054];c[2394]=-1;i=c[(c[2388530]|0)+12304>>2]|0;if((i|0)!=0){k=i;gGC(k|0,9661040,68)|0}c[2382]=-1;k=c[2433476]|0;if(!((c[2112968]|0)!=0&(k|0)!=0)){return 0}gu[k&16383]();return 0}function aBH(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;d=i;i=i+144|0;e=d|0;if((a&64|0)==0){aCU(a,b);i=d;return 0}f=e;g=d+16|0;h=e|0;j=e+4|0;k=e+12|0;l=c[2391608]|0;if((l|0)!=0){m=l+52|0;n=c[m>>2]|0;gGz(f|0,0,16);c[h>>2]=l;c[j>>2]=68;cC(g|0,165488,(o=i,i=i+8|0,c[o>>2]=0,o)|0)|0;i=o;c[k>>2]=g;l=c[2076592]|0;gj[l&4095](e)|0;c[m>>2]=n}n=c[2394685]|0;if((n|0)==0){aCU(a,b);i=d;return 0}m=n+52|0;l=c[m>>2]|0;gGz(f|0,0,16);c[h>>2]=n;c[j>>2]=68;cC(g|0,165488,(o=i,i=i+8|0,c[o>>2]=1,o)|0)|0;i=o;c[k>>2]=g;gj[c[2076592]&4095](e)|0;c[m>>2]=l;aCU(a,b);i=d;return 0}function aBI(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1998060+(b*112|0)>>2];c[a+104>>2]=c[1998064+(b*112|0)>>2];c[a+108>>2]=c[1998068+(b*112|0)>>2];d=0;return d|0}function aBJ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=1997960+(b*112|0);e=0;return e|0}function aBK(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>30){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5358636+(b*112|0)>>2];c[a+104>>2]=c[5358640+(b*112|0)>>2];c[a+108>>2]=c[5358644+(b*112|0)>>2];d=0;return d|0}function aBL(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<31&(d|0)==0)){e=1;return e|0}c[a>>2]=5358536+(b*112|0);e=0;return e|0}function aBM(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>38){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5362008+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aBN(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0;e=i;i=i+2880|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;B=e+1200|0;C=e+1312|0;D=e+1320|0;E=e+1432|0;F=e+1440|0;G=e+1552|0;H=e+1560|0;I=e+1672|0;J=e+1680|0;K=e+1792|0;L=e+1800|0;M=e+1912|0;N=e+1920|0;O=e+2032|0;P=e+2040|0;Q=e+2152|0;R=e+2160|0;S=e+2272|0;T=e+2280|0;U=e+2392|0;V=e+2400|0;W=e+2512|0;X=e+2520|0;Y=e+2632|0;Z=e+2640|0;_=e+2752|0;$=e+2760|0;aa=e+2872|0;aCN();if((R6((c[2388040]|0)+1|0,0,2)|0)!=0){ab=1;i=e;return ab|0}if((R6(c[2388040]|0,1,2)|0)!=0){ab=1;i=e;return ab|0}if((R6((c[2388040]|0)+131073|0,2,2)|0)!=0){ab=1;i=e;return ab|0}if((R6((c[2388040]|0)+131072|0,3,2)|0)!=0){ab=1;i=e;return ab|0}if((R6((c[2388040]|0)+262145|0,4,2)|0)!=0){ab=1;i=e;return ab|0}if((R6((c[2388040]|0)+262144|0,5,2)|0)!=0){ab=1;i=e;return ab|0}ac=c[3527426]|0;if((c[3542200]|0)==0){ab=1;i=e;return ab|0}ad=$+108|0;c[ad>>2]=0;ae=$+100|0;c[ae>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383]($,6)|0;do{if((c[ad>>2]|0)!=0){$=c[ae>>2]|0;c[aa>>2]=9534384;af=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[af&16383](aa,6,0)|0;if(($|0)<1){ab=1;i=e;return ab|0}if((gzL(ac,0,6)|0)==0){break}else{ab=1}i=e;return ab|0}}while(0);ac=c[3529554]|0;if((c[3542200]|0)==0){ab=1;i=e;return ab|0}aa=Z+108|0;c[aa>>2]=0;ae=Z+100|0;c[ae>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](Z,7)|0;do{if((c[aa>>2]|0)!=0){Z=c[ae>>2]|0;c[_>>2]=9534384;ad=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ad&16383](_,7,0)|0;if((Z|0)<1){ab=1;i=e;return ab|0}if((gzL(ac,0,7)|0)==0){break}else{ab=1}i=e;return ab|0}}while(0);ac=(c[3529554]|0)+65536|0;if((c[3542200]|0)==0){ab=1;i=e;return ab|0}_=X+108|0;c[_>>2]=0;ae=X+100|0;c[ae>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](X,8)|0;do{if((c[_>>2]|0)!=0){X=c[ae>>2]|0;c[Y>>2]=9534384;aa=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aa&16383](Y,8,0)|0;if((X|0)<1){ab=1;i=e;return ab|0}if((gzL(ac,0,8)|0)==0){break}else{ab=1}i=e;return ab|0}}while(0);ac=c[3529554]|0;Y=c[2406550]|0;ae=0;do{_=ae<<6;gGz(Y+_|0,0,64);X=0;do{aa=1<<3-X;Z=(c[686408+(X<<2)>>2]|0)+_|0;ad=0;do{$=Z+(c[1238464+(ad<<2)>>2]|0)|0;af=(ad<<3)+_|0;ag=0;do{ah=$+(c[614800+(ag<<2)>>2]|0)|0;if((d[ac+((ah|0)/8|0)|0]&128>>>((ah&7)>>>0)|0)!=0){ah=Y+(af+ag)|0;a[ah]=(d[ah]|aa)&255}ag=ag+1|0;}while((ag|0)<8);ad=ad+1|0;}while((ad|0)<8);X=X+1|0;}while((X|0)<4);ae=ae+1|0;}while((ae|0)<4096);gGz(ac|0,0,524288);if((c[3542200]|0)==0){ab=1;i=e;return ab|0}ae=V+108|0;c[ae>>2]=0;Y=V+100|0;c[Y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](V,9)|0;do{if((c[ae>>2]|0)!=0){V=c[Y>>2]|0;c[W>>2]=9534384;X=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[X&16383](W,9,0)|0;if((V|0)<1){ab=1;i=e;return ab|0}if((gzL(ac,0,9)|0)==0){break}else{ab=1}i=e;return ab|0}}while(0);ac=(c[3529554]|0)+65536|0;if((c[3542200]|0)==0){ab=1;i=e;return ab|0}W=T+108|0;c[W>>2]=0;Y=T+100|0;c[Y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](T,10)|0;do{if((c[W>>2]|0)!=0){T=c[Y>>2]|0;c[U>>2]=9534384;ae=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ae&16383](U,10,0)|0;if((T|0)<1){ab=1;i=e;return ab|0}if((gzL(ac,0,10)|0)==0){break}else{ab=1}i=e;return ab|0}}while(0);ac=(c[3529554]|0)+131072|0;if((c[3542200]|0)==0){ab=1;i=e;return ab|0}U=R+108|0;c[U>>2]=0;Y=R+100|0;c[Y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](R,11)|0;do{if((c[U>>2]|0)!=0){R=c[Y>>2]|0;c[S>>2]=9534384;W=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[W&16383](S,11,0)|0;if((R|0)<1){ab=1;i=e;return ab|0}if((gzL(ac,0,11)|0)==0){break}else{ab=1}i=e;return ab|0}}while(0);ac=(c[3529554]|0)+196608|0;if((c[3542200]|0)==0){ab=1;i=e;return ab|0}S=P+108|0;c[S>>2]=0;Y=P+100|0;c[Y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](P,12)|0;do{if((c[S>>2]|0)!=0){P=c[Y>>2]|0;c[Q>>2]=9534384;U=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[U&16383](Q,12,0)|0;if((P|0)<1){ab=1;i=e;return ab|0}if((gzL(ac,0,12)|0)==0){break}else{ab=1}i=e;return ab|0}}while(0);ac=(c[3529554]|0)+262144|0;if((c[3542200]|0)==0){ab=1;i=e;return ab|0}Q=N+108|0;c[Q>>2]=0;Y=N+100|0;c[Y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](N,13)|0;do{if((c[Q>>2]|0)!=0){N=c[Y>>2]|0;c[O>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](O,13,0)|0;if((N|0)<1){ab=1;i=e;return ab|0}if((gzL(ac,0,13)|0)==0){break}else{ab=1}i=e;return ab|0}}while(0);ac=(c[3529554]|0)+327680|0;if((c[3542200]|0)==0){ab=1;i=e;return ab|0}O=L+108|0;c[O>>2]=0;Y=L+100|0;c[Y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](L,14)|0;do{if((c[O>>2]|0)!=0){L=c[Y>>2]|0;c[M>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](M,14,0)|0;if((L|0)<1){ab=1;i=e;return ab|0}if((gzL(ac,0,14)|0)==0){break}else{ab=1}i=e;return ab|0}}while(0);ac=(c[3529554]|0)+393216|0;if((c[3542200]|0)==0){ab=1;i=e;return ab|0}M=J+108|0;c[M>>2]=0;Y=J+100|0;c[Y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](J,15)|0;do{if((c[M>>2]|0)!=0){J=c[Y>>2]|0;c[K>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](K,15,0)|0;if((J|0)<1){ab=1;i=e;return ab|0}if((gzL(ac,0,15)|0)==0){break}else{ab=1}i=e;return ab|0}}while(0);ac=(c[3529554]|0)+458752|0;if((c[3542200]|0)==0){ab=1;i=e;return ab|0}K=H+108|0;c[K>>2]=0;Y=H+100|0;c[Y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](H,16)|0;do{if((c[K>>2]|0)!=0){H=c[Y>>2]|0;c[I>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](I,16,0)|0;if((H|0)<1){ab=1;i=e;return ab|0}if((gzL(ac,0,16)|0)==0){break}else{ab=1}i=e;return ab|0}}while(0);ac=c[3529554]|0;I=c[2386350]|0;Y=0;do{K=Y<<8;gGz(I+K|0,0,256);H=0;do{M=1<<3-H;J=(c[961536+(H<<2)>>2]|0)+K|0;O=0;do{L=J+(c[609008+(O<<2)>>2]|0)|0;Q=(O<<4)+K|0;N=0;do{S=L+(c[612640+(N<<2)>>2]|0)|0;if((d[ac+((S|0)/8|0)|0]&128>>>((S&7)>>>0)|0)!=0){S=I+(Q+N)|0;a[S]=(d[S]|M)&255}N=N+1|0;}while((N|0)<16);O=O+1|0;}while((O|0)<16);H=H+1|0;}while((H|0)<4);Y=Y+1|0;}while((Y|0)<4096);gGz(ac|0,0,524288);if((c[3542200]|0)==0){ab=1;i=e;return ab|0}Y=F+108|0;c[Y>>2]=0;I=F+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](F,17)|0;do{if((c[Y>>2]|0)!=0){F=c[I>>2]|0;c[G>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](G,17,0)|0;if((F|0)<1){ab=1;i=e;return ab|0}if((gzL(ac,0,17)|0)==0){break}else{ab=1}i=e;return ab|0}}while(0);ac=(c[3529554]|0)+65536|0;if((c[3542200]|0)==0){ab=1;i=e;return ab|0}G=D+108|0;c[G>>2]=0;I=D+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](D,18)|0;do{if((c[G>>2]|0)!=0){D=c[I>>2]|0;c[E>>2]=9534384;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Y&16383](E,18,0)|0;if((D|0)<1){ab=1;i=e;return ab|0}if((gzL(ac,0,18)|0)==0){break}else{ab=1}i=e;return ab|0}}while(0);ac=(c[3529554]|0)+131072|0;if((c[3542200]|0)==0){ab=1;i=e;return ab|0}E=B+108|0;c[E>>2]=0;I=B+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](B,19)|0;do{if((c[E>>2]|0)!=0){B=c[I>>2]|0;c[C>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](C,19,0)|0;if((B|0)<1){ab=1;i=e;return ab|0}if((gzL(ac,0,19)|0)==0){break}else{ab=1}i=e;return ab|0}}while(0);ac=(c[3529554]|0)+196608|0;if((c[3542200]|0)==0){ab=1;i=e;return ab|0}C=z+108|0;c[C>>2]=0;I=z+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,20)|0;do{if((c[C>>2]|0)!=0){z=c[I>>2]|0;c[A>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](A,20,0)|0;if((z|0)<1){ab=1;i=e;return ab|0}if((gzL(ac,0,20)|0)==0){break}else{ab=1}i=e;return ab|0}}while(0);ac=c[3529554]|0;A=c[2386348]|0;I=0;do{C=I<<8;gGz(A+C|0,0,256);z=0;do{E=1<<3-z;B=(c[1179e3+(z<<2)>>2]|0)+C|0;G=0;do{D=B+(c[609008+(G<<2)>>2]|0)|0;Y=(G<<4)+C|0;F=0;do{H=D+(c[612640+(F<<2)>>2]|0)|0;if((d[ac+((H|0)/8|0)|0]&128>>>((H&7)>>>0)|0)!=0){H=A+(Y+F)|0;a[H]=(d[H]|E)&255}F=F+1|0;}while((F|0)<16);G=G+1|0;}while((G|0)<16);z=z+1|0;}while((z|0)<4);I=I+1|0;}while((I|0)<2048);gGz(ac|0,0,524288);if((c[3542200]|0)==0){ab=1;i=e;return ab|0}I=x+108|0;c[I>>2]=0;A=x+100|0;c[A>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,21)|0;do{if((c[I>>2]|0)!=0){x=c[A>>2]|0;c[y>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](y,21,0)|0;if((x|0)<1){ab=1;i=e;return ab|0}if((gzL(ac,0,21)|0)==0){break}else{ab=1}i=e;return ab|0}}while(0);ac=(c[3529554]|0)+65536|0;if((c[3542200]|0)==0){ab=1;i=e;return ab|0}y=v+108|0;c[y>>2]=0;A=v+100|0;c[A>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,22)|0;do{if((c[y>>2]|0)!=0){v=c[A>>2]|0;c[w>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](w,22,0)|0;if((v|0)<1){ab=1;i=e;return ab|0}if((gzL(ac,0,22)|0)==0){break}else{ab=1}i=e;return ab|0}}while(0);ac=(c[3529554]|0)+131072|0;if((c[3542200]|0)==0){ab=1;i=e;return ab|0}w=t+108|0;c[w>>2]=0;A=t+100|0;c[A>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,23)|0;do{if((c[w>>2]|0)!=0){t=c[A>>2]|0;c[u>>2]=9534384;y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[y&16383](u,23,0)|0;if((t|0)<1){ab=1;i=e;return ab|0}if((gzL(ac,0,23)|0)==0){break}else{ab=1}i=e;return ab|0}}while(0);ac=(c[3529554]|0)+196608|0;if((c[3542200]|0)==0){ab=1;i=e;return ab|0}u=r+108|0;c[u>>2]=0;A=r+100|0;c[A>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,24)|0;do{if((c[u>>2]|0)!=0){r=c[A>>2]|0;c[s>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](s,24,0)|0;if((r|0)<1){ab=1;i=e;return ab|0}if((gzL(ac,0,24)|0)==0){break}else{ab=1}i=e;return ab|0}}while(0);ac=(c[3529554]|0)+262144|0;if((c[3542200]|0)==0){ab=1;i=e;return ab|0}s=p+108|0;c[s>>2]=0;A=p+100|0;c[A>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,25)|0;do{if((c[s>>2]|0)!=0){p=c[A>>2]|0;c[q>>2]=9534384;u=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[u&16383](q,25,0)|0;if((p|0)<1){ab=1;i=e;return ab|0}if((gzL(ac,0,25)|0)==0){break}else{ab=1}i=e;return ab|0}}while(0);ac=(c[3529554]|0)+327680|0;if((c[3542200]|0)==0){ab=1;i=e;return ab|0}q=n+108|0;c[q>>2]=0;A=n+100|0;c[A>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,26)|0;do{if((c[q>>2]|0)!=0){n=c[A>>2]|0;c[o>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](o,26,0)|0;if((n|0)<1){ab=1;i=e;return ab|0}if((gzL(ac,0,26)|0)==0){break}else{ab=1}i=e;return ab|0}}while(0);ac=(c[3529554]|0)+393216|0;if((c[3542200]|0)==0){ab=1;i=e;return ab|0}o=l+108|0;c[o>>2]=0;A=l+100|0;c[A>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,27)|0;do{if((c[o>>2]|0)!=0){l=c[A>>2]|0;c[m>>2]=9534384;q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[q&16383](m,27,0)|0;if((l|0)<1){ab=1;i=e;return ab|0}if((gzL(ac,0,27)|0)==0){break}else{ab=1}i=e;return ab|0}}while(0);ac=(c[3529554]|0)+458752|0;if((c[3542200]|0)==0){ab=1;i=e;return ab|0}m=j+108|0;c[m>>2]=0;A=j+100|0;c[A>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,28)|0;do{if((c[m>>2]|0)!=0){j=c[A>>2]|0;c[k>>2]=9534384;o=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[o&16383](k,28,0)|0;if((j|0)<1){ab=1;i=e;return ab|0}if((gzL(ac,0,28)|0)==0){break}else{ab=1}i=e;return ab|0}}while(0);ac=c[3529554]|0;k=c[3529604]|0;A=0;do{m=A<<8;gGz(k+m|0,0,256);j=0;do{o=1<<3-j;l=(c[961536+(j<<2)>>2]|0)+m|0;q=0;do{n=l+(c[609008+(q<<2)>>2]|0)|0;s=(q<<4)+m|0;p=0;do{u=n+(c[612640+(p<<2)>>2]|0)|0;if((d[ac+((u|0)/8|0)|0]&128>>>((u&7)>>>0)|0)!=0){u=k+(s+p)|0;a[u]=(d[u]|o)&255}p=p+1|0;}while((p|0)<16);q=q+1|0;}while((q|0)<16);j=j+1|0;}while((j|0)<4);A=A+1|0;}while((A|0)<4096);A=c[3541206]|0;if((c[3542200]|0)==0){ab=1;i=e;return ab|0}k=f+108|0;c[k>>2]=0;ac=f+100|0;c[ac>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,29)|0;do{if((c[k>>2]|0)!=0){f=c[ac>>2]|0;c[g>>2]=9534384;j=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[j&16383](g,29,0)|0;if((f|0)<1){ab=1;i=e;return ab|0}if((gzL(A,0,29)|0)==0){break}else{ab=1}i=e;return ab|0}}while(0);A=c[3529554]|0;g=0;while(1){if((g|0)>=1024){break}ai=9638528+(g<<2)|0;if((c[ai>>2]|0)==(A|0)){aj=20358;break}else{g=g+1|0}}if((aj|0)==20358){gGr(A);c[ai>>2]=0}c[3529554]=0;c[2433476]=6790;c[2406596]=2;b[(c[2388040]|0)+2920>>1]=-32760;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];ai=c[3532592]|0;if((ai|0)!=0){gGC(9104152,ai|0,280)|0}c[2113054]=c[2113060]}RI();ai=c[2394]|0;A=c[14130368+(ai<<2)>>2]|0;if((A|0)!=0){gGC(A|0,9104152,280)|0}c[8452240+(ai<<2)>>2]=c[2113054];c[2394]=-1;c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;lw(c[3540984]|0);c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){ai=0;do{lN(ai);mB(ai);ai=ai+1|0;}while((ai|0)<(c[2385508]|0))}c[2113156]=0;a[9628264]=0;c[2407033]=0;ai=c[3541206]|0;c[3541190]=ai;c[3541198]=ai;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=ai+256;c[3541199]=ai+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=ai+512;c[3541200]=ai+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=ai+768;c[3541201]=ai+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2444194]=0;a[9545184]=0;a[9758144]=0;a[9759752]=0;c[3527346]=0;gGz(9754968,0,3);a[9718113]=11;a[9718112]=11;c[3528556]=0;ai=c[2433594]|0;c[2443776]=ai;L25866:do{if((ai|0)!=0){A=ai|0;gGC(9660952,A|0,52)|0;switch(a[9660952]|0){case 0:{c[2309668]=638960;break L25866;break};case 1:{c[2309668]=634096;break L25866;break};case 3:{c[2309668]=639984;break L25866;break};case 4:{c[2309668]=7356016;break L25866;break};case 5:{c[2309668]=7354992;break L25866;break};case 2:{c[2309668]=638960;break L25866;break};default:{break L25866}}}}while(0);c[2113164]=c[2432850];gu[c[ai+56>>2]&16383]();ai=c[2443776]|0;if((ai|0)!=0){A=ai|0;gGC(A|0,9660952,52)|0}c[9731400+(c[3528556]<<2)>>2]=c[2113164];c[2443776]=0;c[3528556]=-1;ab=0;i=e;return ab|0}function aBO(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>30){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3873684+(b*112|0)>>2];c[a+104>>2]=c[3873688+(b*112|0)>>2];c[a+108>>2]=c[3873692+(b*112|0)>>2];d=0;return d|0}function aBP(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<31&(d|0)==0)){e=1;return e|0}c[a>>2]=3873584+(b*112|0);e=0;return e|0}function aBQ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>24){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3869012+(b*112|0)>>2];c[a+104>>2]=c[3869016+(b*112|0)>>2];c[a+108>>2]=c[3869020+(b*112|0)>>2];d=0;return d|0}function aBR(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<25&(d|0)==0)){e=1;return e|0}c[a>>2]=3868912+(b*112|0);e=0;return e|0}function aBS(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>35){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3871712+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aBT(){var b=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0;b=i;i=i+2520|0;e=b|0;f=b+112|0;g=b+120|0;j=b+232|0;k=b+240|0;l=b+352|0;m=b+360|0;n=b+472|0;o=b+480|0;p=b+592|0;q=b+600|0;r=b+712|0;s=b+720|0;t=b+832|0;u=b+840|0;v=b+952|0;w=b+960|0;x=b+1072|0;y=b+1080|0;z=b+1192|0;A=b+1200|0;B=b+1312|0;C=b+1320|0;D=b+1432|0;E=b+1440|0;F=b+1552|0;G=b+1560|0;H=b+1672|0;I=b+1680|0;J=b+1792|0;K=b+1800|0;L=b+1912|0;M=b+1920|0;N=b+2032|0;O=b+2040|0;P=b+2152|0;Q=b+2160|0;R=b+2272|0;S=b+2280|0;T=b+2392|0;U=b+2400|0;V=b+2512|0;aCN();if((R6((c[2388040]|0)+1|0,0,2)|0)!=0){W=1;i=b;return W|0}if((R6(c[2388040]|0,1,2)|0)!=0){W=1;i=b;return W|0}if((R6((c[2388040]|0)+131073|0,2,2)|0)!=0){W=1;i=b;return W|0}if((R6((c[2388040]|0)+131072|0,3,2)|0)!=0){W=1;i=b;return W|0}X=c[3527426]|0;if((c[3542200]|0)==0){W=1;i=b;return W|0}Y=U+108|0;c[Y>>2]=0;Z=U+100|0;c[Z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](U,4)|0;do{if((c[Y>>2]|0)!=0){U=c[Z>>2]|0;c[V>>2]=9534384;_=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[_&16383](V,4,0)|0;if((U|0)<1){W=1;i=b;return W|0}if((gzL(X,0,4)|0)==0){break}else{W=1}i=b;return W|0}}while(0);X=c[3527450]|0;if((c[3542200]|0)==0){W=1;i=b;return W|0}V=S+108|0;c[V>>2]=0;Z=S+100|0;c[Z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](S,5)|0;do{if((c[V>>2]|0)!=0){S=c[Z>>2]|0;c[T>>2]=9534384;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Y&16383](T,5,0)|0;if((S|0)<1){W=1;i=b;return W|0}if((gzL(X,0,5)|0)==0){break}else{W=1}i=b;return W|0}}while(0);X=c[3529554]|0;if((c[3542200]|0)==0){W=1;i=b;return W|0}T=Q+108|0;c[T>>2]=0;Z=Q+100|0;c[Z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](Q,6)|0;do{if((c[T>>2]|0)!=0){Q=c[Z>>2]|0;c[R>>2]=9534384;V=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[V&16383](R,6,0)|0;if((Q|0)<1){W=1;i=b;return W|0}if((gzL(X,0,6)|0)==0){break}else{W=1}i=b;return W|0}}while(0);X=(c[3529554]|0)+65536|0;if((c[3542200]|0)==0){W=1;i=b;return W|0}R=O+108|0;c[R>>2]=0;Z=O+100|0;c[Z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](O,7)|0;do{if((c[R>>2]|0)!=0){O=c[Z>>2]|0;c[P>>2]=9534384;T=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[T&16383](P,7,0)|0;if((O|0)<1){W=1;i=b;return W|0}if((gzL(X,0,7)|0)==0){break}else{W=1}i=b;return W|0}}while(0);X=c[3529554]|0;P=c[2406550]|0;Z=0;do{R=Z<<6;gGz(P+R|0,0,64);O=0;do{T=1<<3-O;Q=(c[686408+(O<<2)>>2]|0)+R|0;V=0;do{S=Q+(c[1238464+(V<<2)>>2]|0)|0;Y=(V<<3)+R|0;U=0;do{_=S+(c[614800+(U<<2)>>2]|0)|0;if((d[X+((_|0)/8|0)|0]&128>>>((_&7)>>>0)|0)!=0){_=P+(Y+U)|0;a[_]=(d[_]|T)&255}U=U+1|0;}while((U|0)<8);V=V+1|0;}while((V|0)<8);O=O+1|0;}while((O|0)<4);Z=Z+1|0;}while((Z|0)<4096);gGz(X|0,0,524288);if((c[3542200]|0)==0){W=1;i=b;return W|0}Z=M+108|0;c[Z>>2]=0;P=M+100|0;c[P>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](M,8)|0;do{if((c[Z>>2]|0)!=0){M=c[P>>2]|0;c[N>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](N,8,0)|0;if((M|0)<1){W=1;i=b;return W|0}if((gzL(X,0,8)|0)==0){break}else{W=1}i=b;return W|0}}while(0);X=(c[3529554]|0)+32768|0;if((c[3542200]|0)==0){W=1;i=b;return W|0}N=K+108|0;c[N>>2]=0;P=K+100|0;c[P>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](K,9)|0;do{if((c[N>>2]|0)!=0){K=c[P>>2]|0;c[L>>2]=9534384;Z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Z&16383](L,9,0)|0;if((K|0)<1){W=1;i=b;return W|0}if((gzL(X,0,9)|0)==0){break}else{W=1}i=b;return W|0}}while(0);X=(c[3529554]|0)+65536|0;if((c[3542200]|0)==0){W=1;i=b;return W|0}L=I+108|0;c[L>>2]=0;P=I+100|0;c[P>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](I,10)|0;do{if((c[L>>2]|0)!=0){I=c[P>>2]|0;c[J>>2]=9534384;N=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[N&16383](J,10,0)|0;if((I|0)<1){W=1;i=b;return W|0}if((gzL(X,0,10)|0)==0){break}else{W=1}i=b;return W|0}}while(0);X=(c[3529554]|0)+98304|0;if((c[3542200]|0)==0){W=1;i=b;return W|0}J=G+108|0;c[J>>2]=0;P=G+100|0;c[P>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](G,11)|0;do{if((c[J>>2]|0)!=0){G=c[P>>2]|0;c[H>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](H,11,0)|0;if((G|0)<1){W=1;i=b;return W|0}if((gzL(X,0,11)|0)==0){break}else{W=1}i=b;return W|0}}while(0);X=c[3529554]|0;H=c[2386350]|0;P=0;do{J=P<<8;gGz(H+J|0,0,256);G=0;do{L=1<<3-G;I=(c[611416+(G<<2)>>2]|0)+J|0;N=0;do{K=I+(c[609008+(N<<2)>>2]|0)|0;Z=(N<<4)+J|0;M=0;do{O=K+(c[612640+(M<<2)>>2]|0)|0;if((d[X+((O|0)/8|0)|0]&128>>>((O&7)>>>0)|0)!=0){O=H+(Z+M)|0;a[O]=(d[O]|L)&255}M=M+1|0;}while((M|0)<16);N=N+1|0;}while((N|0)<16);G=G+1|0;}while((G|0)<4);P=P+1|0;}while((P|0)<1024);gGz(X|0,0,524288);if((c[3542200]|0)==0){W=1;i=b;return W|0}P=E+108|0;c[P>>2]=0;H=E+100|0;c[H>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](E,12)|0;do{if((c[P>>2]|0)!=0){E=c[H>>2]|0;c[F>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](F,12,0)|0;if((E|0)<1){W=1;i=b;return W|0}if((gzL(X,0,12)|0)==0){break}else{W=1}i=b;return W|0}}while(0);X=(c[3529554]|0)+32768|0;if((c[3542200]|0)==0){W=1;i=b;return W|0}F=C+108|0;c[F>>2]=0;H=C+100|0;c[H>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](C,13)|0;do{if((c[F>>2]|0)!=0){C=c[H>>2]|0;c[D>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](D,13,0)|0;if((C|0)<1){W=1;i=b;return W|0}if((gzL(X,0,13)|0)==0){break}else{W=1}i=b;return W|0}}while(0);X=(c[3529554]|0)+65536|0;if((c[3542200]|0)==0){W=1;i=b;return W|0}D=A+108|0;c[D>>2]=0;H=A+100|0;c[H>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](A,14)|0;do{if((c[D>>2]|0)!=0){A=c[H>>2]|0;c[B>>2]=9534384;F=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[F&16383](B,14,0)|0;if((A|0)<1){W=1;i=b;return W|0}if((gzL(X,0,14)|0)==0){break}else{W=1}i=b;return W|0}}while(0);X=(c[3529554]|0)+98304|0;if((c[3542200]|0)==0){W=1;i=b;return W|0}B=y+108|0;c[B>>2]=0;H=y+100|0;c[H>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](y,15)|0;do{if((c[B>>2]|0)!=0){y=c[H>>2]|0;c[z>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](z,15,0)|0;if((y|0)<1){W=1;i=b;return W|0}if((gzL(X,0,15)|0)==0){break}else{W=1}i=b;return W|0}}while(0);X=c[3529554]|0;z=c[2386348]|0;H=0;do{B=H<<8;gGz(z+B|0,0,256);y=0;do{D=1<<3-y;A=(c[611416+(y<<2)>>2]|0)+B|0;F=0;do{C=A+(c[609008+(F<<2)>>2]|0)|0;P=(F<<4)+B|0;E=0;do{G=C+(c[612640+(E<<2)>>2]|0)|0;if((d[X+((G|0)/8|0)|0]&128>>>((G&7)>>>0)|0)!=0){G=z+(P+E)|0;a[G]=(d[G]|D)&255}E=E+1|0;}while((E|0)<16);F=F+1|0;}while((F|0)<16);y=y+1|0;}while((y|0)<4);H=H+1|0;}while((H|0)<1024);gGz(X|0,0,524288);if((c[3542200]|0)==0){W=1;i=b;return W|0}H=w+108|0;c[H>>2]=0;z=w+100|0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](w,16)|0;do{if((c[H>>2]|0)!=0){w=c[z>>2]|0;c[x>>2]=9534384;y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[y&16383](x,16,0)|0;if((w|0)<1){W=1;i=b;return W|0}if((gzL(X,0,16)|0)==0){break}else{W=1}i=b;return W|0}}while(0);X=(c[3529554]|0)+65536|0;if((c[3542200]|0)==0){W=1;i=b;return W|0}x=u+108|0;c[x>>2]=0;z=u+100|0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](u,17)|0;do{if((c[x>>2]|0)!=0){u=c[z>>2]|0;c[v>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](v,17,0)|0;if((u|0)<1){W=1;i=b;return W|0}if((gzL(X,0,17)|0)==0){break}else{W=1}i=b;return W|0}}while(0);X=(c[3529554]|0)+131072|0;if((c[3542200]|0)==0){W=1;i=b;return W|0}v=s+108|0;c[v>>2]=0;z=s+100|0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](s,18)|0;do{if((c[v>>2]|0)!=0){s=c[z>>2]|0;c[t>>2]=9534384;x=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[x&16383](t,18,0)|0;if((s|0)<1){W=1;i=b;return W|0}if((gzL(X,0,18)|0)==0){break}else{W=1}i=b;return W|0}}while(0);X=(c[3529554]|0)+196608|0;if((c[3542200]|0)==0){W=1;i=b;return W|0}t=q+108|0;c[t>>2]=0;z=q+100|0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](q,19)|0;do{if((c[t>>2]|0)!=0){q=c[z>>2]|0;c[r>>2]=9534384;v=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[v&16383](r,19,0)|0;if((q|0)<1){W=1;i=b;return W|0}if((gzL(X,0,19)|0)==0){break}else{W=1}i=b;return W|0}}while(0);X=(c[3529554]|0)+262144|0;if((c[3542200]|0)==0){W=1;i=b;return W|0}r=o+108|0;c[r>>2]=0;z=o+100|0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](o,20)|0;do{if((c[r>>2]|0)!=0){o=c[z>>2]|0;c[p>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](p,20,0)|0;if((o|0)<1){W=1;i=b;return W|0}if((gzL(X,0,20)|0)==0){break}else{W=1}i=b;return W|0}}while(0);X=(c[3529554]|0)+327680|0;if((c[3542200]|0)==0){W=1;i=b;return W|0}p=m+108|0;c[p>>2]=0;z=m+100|0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,21)|0;do{if((c[p>>2]|0)!=0){m=c[z>>2]|0;c[n>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](n,21,0)|0;if((m|0)<1){W=1;i=b;return W|0}if((gzL(X,0,21)|0)==0){break}else{W=1}i=b;return W|0}}while(0);X=(c[3529554]|0)+393216|0;if((c[3542200]|0)==0){W=1;i=b;return W|0}n=k+108|0;c[n>>2]=0;z=k+100|0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,22)|0;do{if((c[n>>2]|0)!=0){k=c[z>>2]|0;c[l>>2]=9534384;p=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[p&16383](l,22,0)|0;if((k|0)<1){W=1;i=b;return W|0}if((gzL(X,0,22)|0)==0){break}else{W=1}i=b;return W|0}}while(0);X=(c[3529554]|0)+458752|0;if((c[3542200]|0)==0){W=1;i=b;return W|0}l=g+108|0;c[l>>2]=0;z=g+100|0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,23)|0;do{if((c[l>>2]|0)!=0){g=c[z>>2]|0;c[j>>2]=9534384;n=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[n&16383](j,23,0)|0;if((g|0)<1){W=1;i=b;return W|0}if((gzL(X,0,23)|0)==0){break}else{W=1}i=b;return W|0}}while(0);X=c[3529554]|0;j=c[3529604]|0;z=0;do{l=z<<8;gGz(j+l|0,0,256);g=0;do{n=1<<3-g;k=(c[961536+(g<<2)>>2]|0)+l|0;p=0;do{m=k+(c[609008+(p<<2)>>2]|0)|0;r=(p<<4)+l|0;o=0;do{t=m+(c[612640+(o<<2)>>2]|0)|0;if((d[X+((t|0)/8|0)|0]&128>>>((t&7)>>>0)|0)!=0){t=j+(r+o)|0;a[t]=(d[t]|n)&255}o=o+1|0;}while((o|0)<16);p=p+1|0;}while((p|0)<16);g=g+1|0;}while((g|0)<4);z=z+1|0;}while((z|0)<4096);z=c[3541206]|0;if((c[3542200]|0)==0){W=1;i=b;return W|0}j=e+108|0;c[j>>2]=0;X=e+100|0;c[X>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,24)|0;do{if((c[j>>2]|0)!=0){e=c[X>>2]|0;c[f>>2]=9534384;g=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[g&16383](f,24,0)|0;if((e|0)<1){W=1;i=b;return W|0}if((gzL(z,0,24)|0)==0){break}else{W=1}i=b;return W|0}}while(0);z=c[3529554]|0;f=0;while(1){if((f|0)>=1024){break}$=9638528+(f<<2)|0;if((c[$>>2]|0)==(z|0)){aa=20620;break}else{f=f+1|0}}if((aa|0)==20620){gGr(z);c[$>>2]=0}c[3529554]=0;$=c[3527450]|0;z=0;do{aa=$+z|0;f=a[aa]|0;a[aa]=f&126|f<<7|(f&255)>>>7;z=z+1|0;}while((z|0)<65536);a[$+393|0]=96;a[$+431|0]=96;a[$+475|0]=96;a[$+538|0]=96;c[2433476]=8456;if((c[2394]|0)==0){ab=c[2112932]|0;ac=c[3532592]|0}else{c[2394]=0;$=c[3532596]|0;c[2112932]=$;z=c[3532592]|0;if((z|0)!=0){gGC(9104152,z|0,280)|0}c[2113054]=c[2113060];ab=$;ac=z}c[ab+6144>>2]=1;c[ab+71680>>2]=1;c[ab+137216>>2]=1;c[ab+6148>>2]=1;c[ab+71684>>2]=1;c[ab+137220>>2]=1;c[ab+6152>>2]=1;c[ab+71688>>2]=1;c[ab+137224>>2]=1;c[ab+6156>>2]=1;c[ab+71692>>2]=1;c[ab+137228>>2]=1;c[ab+196612>>2]=912;c[ab+196652>>2]=746;c[ab+196692>>2]=1092;c[ab+196732>>2]=1690;if((ac|0)!=0){gGC(ac|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fv8();c[2388530]=9554128;ac=c[2391608]|0;if((ac|0)!=0){ab=ac;gGC(9661040,ab|0,68)|0}c[2382]=0;ab=c[3527450]|0;ac=0;do{z=ab+(ac<<11)|0;c[9554144+(ac<<2)>>2]=z;c[9562336+(ac<<2)>>2]=z;ac=ac+1|0;}while(ac>>>0<32);ac=c[2443452]|0;c[2389304]=ac;c[2390328]=ac;c[2391352]=ac;ac=c[3527452]|0;c[2389528]=ac;c[2390552]=ac;c[2391576]=ac;ab=ac+2048|0;c[2389529]=ab;c[2390553]=ab;c[2391577]=ab;ab=ac+4096|0;c[2389530]=ab;c[2390554]=ab;c[2391578]=ab;ab=ac+6144|0;c[2389531]=ab;c[2390555]=ab;c[2391579]=ab;c[2388532]=2658;c[2388533]=2326;ab=c[2391608]|0;if((ab|0)!=0){ac=ab;gGC(ac|0,9661040,68)|0}c[2382]=-1;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];ac=c[3532592]|0;if((ac|0)!=0){gGC(9104152,ac|0,280)|0}c[2113054]=c[2113060]}RI();ac=c[2394]|0;ab=c[14130368+(ac<<2)>>2]|0;if((ab|0)!=0){gGC(ab|0,9104152,280)|0}c[8452240+(ac<<2)>>2]=c[2113054];c[2394]=-1;c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;lw(c[3540984]|0);c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){ac=0;do{lN(ac);mB(ac);ac=ac+1|0;}while((ac|0)<(c[2385508]|0))}c[2113156]=0;a[9628264]=0;c[2407033]=0;ac=c[3541206]|0;c[3541190]=ac;c[3541198]=ac;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=ac+256;c[3541199]=ac+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=ac+512;c[3541200]=ac+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=ac+768;c[3541201]=ac+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2444194]=0;a[9545184]=0;a[9758144]=0;a[9759752]=0;c[3527346]=0;gGz(9754968,0,3);a[9718113]=11;a[9718112]=11;c[3528556]=0;ac=c[2433594]|0;c[2443776]=ac;L26238:do{if((ac|0)!=0){ab=ac|0;gGC(9660952,ab|0,52)|0;switch(a[9660952]|0){case 0:{c[2309668]=638960;break L26238;break};case 1:{c[2309668]=634096;break L26238;break};case 3:{c[2309668]=639984;break L26238;break};case 4:{c[2309668]=7356016;break L26238;break};case 5:{c[2309668]=7354992;break L26238;break};case 2:{c[2309668]=638960;break L26238;break};default:{break L26238}}}}while(0);c[2113164]=c[2432850];gu[c[ac+56>>2]&16383]();ac=c[2443776]|0;if((ac|0)!=0){ab=ac|0;gGC(ab|0,9660952,52)|0}c[9731400+(c[3528556]<<2)>>2]=c[2113164];c[2443776]=0;c[3528556]=-1;c[2388530]=9554128;ab=c[2391608]|0;if((ab|0)!=0){ac=ab;gGC(9661040,ac|0,68)|0}c[2382]=0;ac=c[2415273]|0;gGz(9661040,0,68);c[2415273]=ac;a[9661063]=20;c[2415262]=511;ac=c[2388539]|0;do{if((ac|0)==0){ab=c[2388532]|0;if((ab|0)==0){ad=0;ae=8191;af=9554128;break}z=gj[ab&4095](8190)|0;ad=z;ae=d[9661071]<<13|8191;af=c[2388530]|0}else{ad=a[ac+2046|0]|0;ae=8191;af=9554128}}while(0);a[9661044]=ad;ad=c[af+16+(ae>>>11<<2)>>2]|0;do{if((ad|0)==0){ac=c[af>>2]|0;if((ac|0)==0){ag=0;ah=af;break}z=gj[ac&4095](ae)|0;ag=z;ah=c[2388530]|0}else{ag=a[ad+2047|0]|0;ah=af}}while(0);a[9661045]=ag;a[9661075]=4;a[9661073]=0;c[2415270]=131072;c[2415275]=0;gGz(9661084,0,5);ag=c[ah+12304>>2]|0;if((ag|0)!=0){ah=ag;gGC(ah|0,9661040,68)|0}c[2382]=-1;W=0;i=b;return W|0}function aBU(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;fv9();fvR();if((c[2392]|0)>=0){b=0;do{d=14130368+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}d=14130384+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}b=b+1|0;}while((b|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;b=c[3541518]|0;if((b|0)!=0){gGr(b|0);c[3541518]=0}if((c[2385508]|0)>0){c[2113008]=0;c[2076598]=0;c[2383582]=0}c[2438228]=0;c[2433526]=0;c[2406676]=0;c[3528472]=0;b=c[2406680]|0;if((b|0)!=0){gGr(b);c[2406680]=0}c[2385508]=0;c[2432978]=0;a[64240]=0;b=a[7452584]|0;if(b){d=0;e=b&1;while(1){b=14163936+(d<<2)|0;f=c[b>>2]|0;g=c[2113006]|0;if((g|0)==0){h=20752}else{i=g-1|0;c[2113006]=i;if((i|0)==0){h=20752}}if((h|0)==20752){h=0;c[2383474]=0}if((f|0)==0){j=e}else{gGr(f);j=a[7452584]&1}c[b>>2]=0;b=d+1|0;if((b|0)<(j|0)){d=b;e=j}else{break}}}a[7452584]=0;c[2438224]=0;c[2433522]=0;c[2406672]=0;c[3528468]=0;j=c[2406688]|0;if((j|0)!=0){gGr(j);c[2406688]=0}c[2432972]=0;Uw(0);c[2113070]=0;c[2113068]=0;j=c[2112926]|0;if((j|0)!=0){gGr(j);c[2112926]=0}c[2444194]=0;a[9545184]=0;a[9758144]=0;a[9759752]=0;c[3527346]=0;c[2429766]=0;c[2429530]=0;c[2429518]=0;c[2429334]=0;c[2429516]=0;c[2429332]=0;gGz(9754968,0,3);a[9720912]=0;c[2433476]=0;c[2433366]=0;c[2406596]=0;a[1950800]=0;a[986968]=0;a[9718113]=0;a[9718112]=0;j=c[2426664]|0;e=0;while(1){if((e|0)>=1024){h=20765;break}k=9638528+(e<<2)|0;if((c[k>>2]|0)==(j|0)){break}else{e=e+1|0}}if((h|0)==20765){c[2426664]=0;return 0}gGr(j);c[k>>2]=0;c[2426664]=0;return 0}function aBV(){var b=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((a[9623568]|0)!=0){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];b=c[3532592]|0;if((b|0)!=0){gGC(9104152,b|0,280)|0}c[2113054]=c[2113060]}RI();b=c[2394]|0;e=c[14130368+(b<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(b<<2)>>2]=c[2113054];c[2394]=-1;c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;lw(c[3540984]|0);c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){b=0;do{lN(b);mB(b);b=b+1|0;}while((b|0)<(c[2385508]|0))}c[2113156]=0;a[9628264]=0;c[2407033]=0;b=c[3541206]|0;c[3541190]=b;c[3541198]=b;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=b+256;c[3541199]=b+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=b+512;c[3541200]=b+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=b+768;c[3541201]=b+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2444194]=0;a[9545184]=0;a[9758144]=0;a[9759752]=0;c[3527346]=0;gGz(9754968,0,3);a[9718113]=11;a[9718112]=11;c[3528556]=0;b=c[2433594]|0;c[2443776]=b;L26330:do{if((b|0)!=0){e=b|0;gGC(9660952,e|0,52)|0;switch(a[9660952]|0){case 3:{c[2309668]=639984;break L26330;break};case 5:{c[2309668]=7354992;break L26330;break};case 1:{c[2309668]=634096;break L26330;break};case 4:{c[2309668]=7356016;break L26330;break};case 0:{c[2309668]=638960;break L26330;break};case 2:{c[2309668]=638960;break L26330;break};default:{break L26330}}}}while(0);c[2113164]=c[2432850];gu[c[b+56>>2]&16383]();b=c[2443776]|0;if((b|0)!=0){e=b|0;gGC(e|0,9660952,52)|0}c[9731400+(c[3528556]<<2)>>2]=c[2113164];c[2443776]=0;c[3528556]=-1;c[2388530]=9554128;e=c[2391608]|0;if((e|0)!=0){b=e;gGC(9661040,b|0,68)|0}c[2382]=0;b=c[2415273]|0;gGz(9661040,0,68);c[2415273]=b;a[9661063]=20;c[2415262]=511;b=c[2388539]|0;do{if((b|0)==0){e=c[2388532]|0;if((e|0)==0){f=0;g=8191;i=9554128;break}j=gj[e&4095](8190)|0;f=j;g=d[9661071]<<13|8191;i=c[2388530]|0}else{f=a[b+2046|0]|0;g=8191;i=9554128}}while(0);a[9661044]=f;f=c[i+16+(g>>>11<<2)>>2]|0;do{if((f|0)==0){b=c[i>>2]|0;if((b|0)==0){k=0;l=i;break}j=gj[b&4095](g)|0;k=j;l=c[2388530]|0}else{k=a[f+2047|0]|0;l=i}}while(0);a[9661045]=k;a[9661075]=4;a[9661073]=0;c[2415270]=131072;c[2415275]=0;gGz(9661084,0,5);k=c[l+12304>>2]|0;if((k|0)!=0){l=k;gGC(l|0,9661040,68)|0}c[2382]=-1}a[9625536]=0;a[9625544]=0;a[9625552]=0;l=0;k=0;i=0;f=0;do{k=((a[9759320+l|0]&1)<<l|k&255)&255;i=((a[9759128+l|0]&1)<<l|i&255)&255;f=((a[9758936+l|0]&1)<<l|f&255)&255;l=l+1|0;}while((l|0)<8);a[9625552]=k;a[9625544]=i;a[9625536]=f;if((k&3)==3){f=k&-4;a[9625552]=f;m=f}else{m=k}if((m&12)==12){a[9625552]=m&-13}if((i&3)==3){m=i&-4;a[9625544]=m;n=m}else{n=i}if((n&12)==12){a[9625544]=n&-13}a[6518368]=1;c[2440504]=26135;a[6517920]=1;c[2443964]=0;n=c[2392]|0;if((n|0)>=0){gGz(8452240,0,((n|0)>0?(n<<2)+4|0:4)|0)}c[2113054]=0;n=c[2113166]|0;if((n|0)>0){gGz(9731400,0,((n|0)>1?n<<2:4)|0)}c[2113164]=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];n=c[3532592]|0;if((n|0)!=0){gGC(9104152,n|0,280)|0}c[2113054]=c[2113060]}c[3528556]=0;n=c[2433594]|0;c[2443776]=n;L26387:do{if((n|0)!=0){i=n|0;gGC(9660952,i|0,52)|0;switch(a[9660952]|0){case 0:{c[2309668]=638960;break L26387;break};case 1:{c[2309668]=634096;break L26387;break};case 3:{c[2309668]=639984;break L26387;break};case 2:{c[2309668]=638960;break L26387;break};case 4:{c[2309668]=7356016;break L26387;break};case 5:{c[2309668]=7354992;break L26387;break};default:{break L26387}}}}while(0);c[2113164]=c[2432850];c[2388530]=9554128;n=c[2391608]|0;if((n|0)!=0){i=n;gGC(9661040,i|0,68)|0}c[2382]=0;i=0;n=1;while(1){Sb(ag(n?659:0,i)|0);do{if((i|0)==8){a[9545184]=0}else if((i|0)==248){a[9545184]=1;c[8452200+(c[2394]<<2)>>2]=4102;c[2276080]=1536;if((c[2276079]|0)>>>0>=1536){break}RH(6)}}while(0);m=i+1|0;k=(ag(a[6517920]|0?23388:0,m)|0)/264|0;f=fy_(k-(c[2443964]|0)|0)|0;c[2443964]=(c[2443964]|0)+f;UF(ag((c[2440504]|0)/264|0,i)|0)|0;o=a[6518368]|0;if((m|0)<264){i=m;n=o}else{break}}n=o?174239:0;o=gGU(n,0,2048e6,0)|0;i=c[2438228]|0;m=gGS(o,K,i,(i|0)<0|0?-1:0)|0;i=m;Sb(n);n=c[2443830]|0;if((n|0)<1073676288){c[2443830]=n-i}n=c[2443831]|0;if((n|0)<1073676288){c[2443831]=n-i}n=(c[3528512]|0)-i|0;c[3528512]=(n|0)<0?0:n;n=c[2440504]|0;i=gGU(n,(n|0)<0|0?-1:0,2048e6,0)|0;m=c[2438224]|0;o=gGS(i,K,m,(m|0)<0|0?-1:0)|0;m=o;UF(n)|0;n=c[2443826]|0;if((n|0)<1073676288){c[2443826]=n-m}n=c[2443827]|0;if((n|0)<1073676288){c[2443827]=n-m}n=(c[3528508]|0)-m|0;c[3528508]=(n|0)<0?0:n;n=c[2112964]|0;if((n|0)!=0){gg[c[3542122]&4095](n,a[9688]|0?534:0);gg[c[3542112]&4095](c[2112964]|0,a[9688]|0?534:0);Uu(0,c[2112964]|0,a[9688]|0?534:0)}n=c[2394]|0;m=c[14130368+(n<<2)>>2]|0;if((m|0)!=0){gGC(m|0,9104152,280)|0}c[8452240+(n<<2)>>2]=c[2113054];c[2394]=-1;n=c[2443776]|0;if((n|0)!=0){m=n|0;gGC(m|0,9660952,52)|0}c[9731400+(c[3528556]<<2)>>2]=c[2113164];c[2443776]=0;c[3528556]=-1;m=c[(c[2388530]|0)+12304>>2]|0;if((m|0)!=0){n=m;gGC(n|0,9661040,68)|0}c[2382]=-1;n=c[2433476]|0;if(!((c[2112968]|0)!=0&(n|0)!=0)){return 0}gu[n&16383]();return 0}function aBW(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;e=i;i=i+224|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;l=e+80|0;if((b&64|0)==0){aCU(b,d);i=e;return 0}m=l;n=e+96|0;o=l|0;p=l+4|0;q=l+12|0;r=c[2391608]|0;if((r|0)!=0){s=r+52|0;t=c[s>>2]|0;gGz(m|0,0,16);c[o>>2]=r;c[p>>2]=68;cC(n|0,165488,(u=i,i=i+8|0,c[u>>2]=0,u)|0)|0;i=u;c[q>>2]=n;r=c[2076592]|0;gj[r&4095](l)|0;c[s>>2]=t}t=c[2394685]|0;if((t|0)!=0){s=t+52|0;r=c[s>>2]|0;gGz(m|0,0,16);c[o>>2]=t;c[p>>2]=68;cC(n|0,165488,(u=i,i=i+8|0,c[u>>2]=1,u)|0)|0;i=u;c[q>>2]=n;n=c[2076592]|0;gj[n&4095](l)|0;c[s>>2]=r}r=k|0;if((c[2113166]|0)<=0){aCU(b,d);i=e;return 0}s=k+7|0;k=j|0;l=j+4|0;n=j+12|0;q=h;u=h|0;p=h+4|0;t=h+12|0;o=g;m=g|0;v=g+4|0;w=g+12|0;x=f;y=f|0;z=f+4|0;A=f+12|0;B=0;do{C=c[9734376+(B<<2)>>2]|0;D=C+36|0;E=c[D>>2]|0;gGC(r|0,614768,9)|0;a[s]=B+48&255;c[k>>2]=C;c[l>>2]=52;c[n>>2]=r;gj[c[2076592]&4095](j)|0;gGz(q|0,0,12);c[u>>2]=C+3172;c[p>>2]=4;c[t>>2]=165288;gj[c[2076592]&4095](h)|0;gGz(o|0,0,12);c[m>>2]=C+3176;c[v>>2]=4;c[w>>2]=501592;gj[c[2076592]&4095](g)|0;gGz(x|0,0,12);c[y>>2]=C+3180;c[z>>2]=4;c[A>>2]=386080;gj[c[2076592]&4095](f)|0;c[D>>2]=E;B=B+1|0;}while((B|0)<(c[2113166]|0));aCU(b,d);i=e;return 0}function aBX(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>24){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3980020+(b*112|0)>>2];c[a+104>>2]=c[3980024+(b*112|0)>>2];c[a+108>>2]=c[3980028+(b*112|0)>>2];d=0;return d|0}function aBY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<25&(d|0)==0)){e=1;return e|0}c[a>>2]=3979920+(b*112|0);e=0;return e|0}function aBZ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>35){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3982720+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aB_(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>24){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1926564+(b*112|0)>>2];c[a+104>>2]=c[1926568+(b*112|0)>>2];c[a+108>>2]=c[1926572+(b*112|0)>>2];d=0;return d|0}function aB$(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<25&(d|0)==0)){e=1;return e|0}c[a>>2]=1926464+(b*112|0);e=0;return e|0}function aB0(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>24){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6230212+(b*112|0)>>2];c[a+104>>2]=c[6230216+(b*112|0)>>2];c[a+108>>2]=c[6230220+(b*112|0)>>2];d=0;return d|0}function aB1(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<25&(d|0)==0)){e=1;return e|0}c[a>>2]=6230112+(b*112|0);e=0;return e|0}function aB2(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>25){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3739736+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aB3(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>33){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6232912+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aB4(){var b=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0;b=i;i=i+1680|0;e=b|0;f=b+112|0;g=b+120|0;j=b+232|0;k=b+240|0;l=b+352|0;m=b+360|0;n=b+472|0;o=b+480|0;p=b+592|0;q=b+600|0;r=b+712|0;s=b+720|0;t=b+832|0;u=b+840|0;v=b+952|0;w=b+960|0;x=b+1072|0;y=b+1080|0;z=b+1192|0;A=b+1200|0;B=b+1312|0;C=b+1320|0;D=b+1432|0;E=b+1440|0;F=b+1552|0;G=b+1560|0;H=b+1672|0;c[2424]=5739;c[2426664]=0;c[2388040]=0;c[3527426]=393216;c[3527450]=425984;c[3541206]=491520;c[2405602]=753664;c[2388062]=753664;c[3527434]=776192;c[3527452]=777728;c[3531060]=785920;c[2437776]=802304;c[2437774]=802312;c[2429770]=802320;c[2429768]=802448;c[2443370]=803472;c[2432708]=819856;c[2432706]=819864;c[2429330]=819872;c[2429328]=82e4;c[2443364]=821024;c[2432704]=837408;c[2432702]=837416;c[2429326]=837424;c[2429324]=837552;c[2439630]=838576;c[2438782]=840624;c[2443440]=842672;c[2429336]=844720;c[2443452]=846768;c[2411514]=854960;c[2406550]=854960;c[2386350]=1117104;c[2386348]=2165680;c[3529604]=2689968;c[3529908]=3738544;c[2438096]=3742640;c[2433516]=4266928;c[2433514]=4791216;I=0;while(1){if((I|0)>=1024){break}J=9638528+(I<<2)|0;if((c[J>>2]|0)==0){K=20926;break}else{I=I+1|0}}do{if((K|0)==20926){I=gGq(5315504)|0;c[J>>2]=I;if((I|0)==0){break}c[2426664]=I;gGz(I|0,0,5315504);c[2388040]=I;c[3527426]=I+393216;c[3527450]=I+425984;c[3541206]=I+491520;L=I+753664|0;c[2405602]=L;c[2388062]=L;c[3527434]=I+776192;c[3527452]=I+777728;c[3531060]=I+785920;c[2437776]=I+802304;c[2437774]=I+802312;c[2429770]=I+802320;c[2429768]=I+802448;c[2443370]=I+803472;c[2432708]=I+819856;c[2432706]=I+819864;c[2429330]=I+819872;c[2429328]=I+82e4;c[2443364]=I+821024;c[2432704]=I+837408;c[2432702]=I+837416;c[2429326]=I+837424;c[2429324]=I+837552;c[2439630]=I+838576;c[2438782]=I+840624;c[2443440]=I+842672;c[2429336]=I+844720;c[2443452]=I+846768;L=I+854960|0;c[2411514]=L;c[2406550]=L;c[2386350]=I+1117104;c[2386348]=I+2165680;c[3529604]=I+2689968;c[3529908]=I+3738544;c[2438096]=I+3742640;c[2433516]=I+4266928;c[2433514]=I+4791216;c[2414054]=I+5315504;I=0;while(1){if((I|0)>=1024){M=0;break}N=9638528+(I<<2)|0;if((c[N>>2]|0)==0){K=20931;break}else{I=I+1|0}}do{if((K|0)==20931){I=gGq(524288)|0;c[N>>2]=I;if((I|0)==0){M=0;break}gGz(I|0,0,524288);M=I}}while(0);c[3529554]=M;if((R6((c[2388040]|0)+1|0,0,2)|0)!=0){O=1;i=b;return O|0}if((R6(c[2388040]|0,1,2)|0)!=0){O=1;i=b;return O|0}if((R6((c[2388040]|0)+262145|0,2,2)|0)!=0){O=1;i=b;return O|0}if((R6((c[2388040]|0)+262144|0,3,2)|0)!=0){O=1;i=b;return O|0}I=c[3527450]|0;if((c[3542200]|0)==0){O=1;i=b;return O|0}L=G+108|0;c[L>>2]=0;P=G+100|0;c[P>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](G,4)|0;do{if((c[L>>2]|0)!=0){Q=c[P>>2]|0;c[H>>2]=9534384;R=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[R&16383](H,4,0)|0;if((Q|0)<1){O=1;i=b;return O|0}if((gzL(I,0,4)|0)==0){break}else{O=1}i=b;return O|0}}while(0);I=(c[3529554]|0)+131072|0;if((c[3542200]|0)==0){O=1;i=b;return O|0}P=E+108|0;c[P>>2]=0;L=E+100|0;c[L>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](E,5)|0;do{if((c[P>>2]|0)!=0){Q=c[L>>2]|0;c[F>>2]=9534384;R=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[R&16383](F,5,0)|0;if((Q|0)<1){O=1;i=b;return O|0}if((gzL(I,0,5)|0)==0){break}else{O=1}i=b;return O|0}}while(0);I=(c[3529554]|0)+196608|0;if((c[3542200]|0)==0){O=1;i=b;return O|0}L=C+108|0;c[L>>2]=0;P=C+100|0;c[P>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](C,6)|0;do{if((c[L>>2]|0)!=0){Q=c[P>>2]|0;c[D>>2]=9534384;R=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[R&16383](D,6,0)|0;if((Q|0)<1){O=1;i=b;return O|0}if((gzL(I,0,6)|0)==0){break}else{O=1}i=b;return O|0}}while(0);I=c[3529554]|0;P=I+32768|0;L=I+131072|0;gGC(P|0,L|0,32768)|0;L=I+163840|0;gGC(I|0,L|0,32768)|0;L=I+98304|0;P=I+196608|0;gGC(L|0,P|0,32768)|0;P=I+65536|0;L=I+229376|0;gGC(P|0,L|0,32768)|0;L=c[2406550]|0;P=0;do{Q=P<<6;gGz(L+Q|0,0,64);R=0;do{S=1<<3-R;T=(c[686408+(R<<2)>>2]|0)+Q|0;U=0;do{V=T+(c[1238464+(U<<2)>>2]|0)|0;W=(U<<3)+Q|0;X=0;do{Y=V+(c[614800+(X<<2)>>2]|0)|0;if(((d[I+((Y|0)/8|0)|0]|0)&128>>>((Y&7)>>>0)|0)!=0){Y=L+(W+X)|0;a[Y]=(d[Y]|0|S)&255}X=X+1|0;}while((X|0)<8);U=U+1|0;}while((U|0)<8);R=R+1|0;}while((R|0)<4);P=P+1|0;}while((P|0)<4096);gGz(I|0,0,524288);if((c[3542200]|0)==0){O=1;i=b;return O|0}P=A+108|0;c[P>>2]=0;L=A+100|0;c[L>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](A,7)|0;do{if((c[P>>2]|0)!=0){R=c[L>>2]|0;c[B>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](B,7,0)|0;if((R|0)<1){O=1;i=b;return O|0}if((gzL(I,0,7)|0)==0){break}else{O=1}i=b;return O|0}}while(0);I=(c[3529554]|0)+131072|0;if((c[3542200]|0)==0){O=1;i=b;return O|0}L=y+108|0;c[L>>2]=0;P=y+100|0;c[P>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](y,8)|0;do{if((c[L>>2]|0)!=0){R=c[P>>2]|0;c[z>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](z,8,0)|0;if((R|0)<1){O=1;i=b;return O|0}if((gzL(I,0,8)|0)==0){break}else{O=1}i=b;return O|0}}while(0);I=(c[3529554]|0)+262144|0;if((c[3542200]|0)==0){O=1;i=b;return O|0}P=w+108|0;c[P>>2]=0;L=w+100|0;c[L>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](w,9)|0;do{if((c[P>>2]|0)!=0){R=c[L>>2]|0;c[x>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](x,9,0)|0;if((R|0)<1){O=1;i=b;return O|0}if((gzL(I,0,9)|0)==0){break}else{O=1}i=b;return O|0}}while(0);I=(c[3529554]|0)+393216|0;if((c[3542200]|0)==0){O=1;i=b;return O|0}L=u+108|0;c[L>>2]=0;P=u+100|0;c[P>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](u,10)|0;do{if((c[L>>2]|0)!=0){R=c[P>>2]|0;c[v>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](v,10,0)|0;if((R|0)<1){O=1;i=b;return O|0}if((gzL(I,0,10)|0)==0){break}else{O=1}i=b;return O|0}}while(0);I=c[3529554]|0;P=c[2386350]|0;L=0;do{R=L<<8;gGz(P+R|0,0,256);Q=0;do{U=1<<3-Q;S=(c[961536+(Q<<2)>>2]|0)+R|0;T=0;do{X=S+(c[609008+(T<<2)>>2]|0)|0;W=(T<<4)+R|0;V=0;do{Y=X+(c[612640+(V<<2)>>2]|0)|0;if(((d[I+((Y|0)/8|0)|0]|0)&128>>>((Y&7)>>>0)|0)!=0){Y=P+(W+V)|0;a[Y]=(d[Y]|0|U)&255}V=V+1|0;}while((V|0)<16);T=T+1|0;}while((T|0)<16);Q=Q+1|0;}while((Q|0)<4);L=L+1|0;}while((L|0)<4096);gGz(I|0,0,524288);if((c[3542200]|0)==0){O=1;i=b;return O|0}L=s+108|0;c[L>>2]=0;P=s+100|0;c[P>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](s,11)|0;do{if((c[L>>2]|0)!=0){Q=c[P>>2]|0;c[t>>2]=9534384;R=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[R&16383](t,11,0)|0;if((Q|0)<1){O=1;i=b;return O|0}if((gzL(I,0,11)|0)==0){break}else{O=1}i=b;return O|0}}while(0);I=(c[3529554]|0)+131072|0;if((c[3542200]|0)==0){O=1;i=b;return O|0}P=q+108|0;c[P>>2]=0;L=q+100|0;c[L>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](q,12)|0;do{if((c[P>>2]|0)!=0){Q=c[L>>2]|0;c[r>>2]=9534384;R=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[R&16383](r,12,0)|0;if((Q|0)<1){O=1;i=b;return O|0}if((gzL(I,0,12)|0)==0){break}else{O=1}i=b;return O|0}}while(0);I=c[3529554]|0;L=c[2386348]|0;P=0;do{Q=P<<8;gGz(L+Q|0,0,256);R=0;do{T=1<<3-R;U=(c[1179e3+(R<<2)>>2]|0)+Q|0;S=0;do{V=U+(c[609008+(S<<2)>>2]|0)|0;W=(S<<4)+Q|0;X=0;do{Y=V+(c[612640+(X<<2)>>2]|0)|0;if(((d[I+((Y|0)/8|0)|0]|0)&128>>>((Y&7)>>>0)|0)!=0){Y=L+(W+X)|0;a[Y]=(d[Y]|0|T)&255}X=X+1|0;}while((X|0)<16);S=S+1|0;}while((S|0)<16);R=R+1|0;}while((R|0)<4);P=P+1|0;}while((P|0)<2048);gGz(I|0,0,524288);if((c[3542200]|0)==0){O=1;i=b;return O|0}P=o+108|0;c[P>>2]=0;L=o+100|0;c[L>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](o,13)|0;do{if((c[P>>2]|0)!=0){R=c[L>>2]|0;c[p>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](p,13,0)|0;if((R|0)<1){O=1;i=b;return O|0}if((gzL(I,0,13)|0)==0){break}else{O=1}i=b;return O|0}}while(0);I=(c[3529554]|0)+131072|0;if((c[3542200]|0)==0){O=1;i=b;return O|0}L=m+108|0;c[L>>2]=0;P=m+100|0;c[P>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,14)|0;do{if((c[L>>2]|0)!=0){R=c[P>>2]|0;c[n>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](n,14,0)|0;if((R|0)<1){O=1;i=b;return O|0}if((gzL(I,0,14)|0)==0){break}else{O=1}i=b;return O|0}}while(0);I=(c[3529554]|0)+262144|0;if((c[3542200]|0)==0){O=1;i=b;return O|0}P=k+108|0;c[P>>2]=0;L=k+100|0;c[L>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,15)|0;do{if((c[P>>2]|0)!=0){R=c[L>>2]|0;c[l>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](l,15,0)|0;if((R|0)<1){O=1;i=b;return O|0}if((gzL(I,0,15)|0)==0){break}else{O=1}i=b;return O|0}}while(0);I=(c[3529554]|0)+393216|0;if((c[3542200]|0)==0){O=1;i=b;return O|0}L=g+108|0;c[L>>2]=0;P=g+100|0;c[P>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,16)|0;do{if((c[L>>2]|0)!=0){R=c[P>>2]|0;c[j>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](j,16,0)|0;if((R|0)<1){O=1;i=b;return O|0}if((gzL(I,0,16)|0)==0){break}else{O=1}i=b;return O|0}}while(0);I=c[3529554]|0;P=c[3529604]|0;L=0;do{R=L<<8;gGz(P+R|0,0,256);Q=0;do{S=1<<3-Q;T=(c[961536+(Q<<2)>>2]|0)+R|0;U=0;do{X=T+(c[609008+(U<<2)>>2]|0)|0;W=(U<<4)+R|0;V=0;do{Y=X+(c[612640+(V<<2)>>2]|0)|0;if(((d[I+((Y|0)/8|0)|0]|0)&128>>>((Y&7)>>>0)|0)!=0){Y=P+(W+V)|0;a[Y]=(d[Y]|0|S)&255}V=V+1|0;}while((V|0)<16);U=U+1|0;}while((U|0)<16);Q=Q+1|0;}while((Q|0)<4);L=L+1|0;}while((L|0)<4096);L=c[3541206]|0;if((c[3542200]|0)==0){O=1;i=b;return O|0}P=e+108|0;c[P>>2]=0;I=e+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,17)|0;do{if((c[P>>2]|0)!=0){Q=c[I>>2]|0;c[f>>2]=9534384;R=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[R&16383](f,17,0)|0;if((Q|0)<1){O=1;i=b;return O|0}if((gzL(L,0,17)|0)==0){break}else{O=1}i=b;return O|0}}while(0);L=c[3529554]|0;I=0;while(1){if((I|0)>=1024){break}Z=9638528+(I<<2)|0;if((c[Z>>2]|0)==(L|0)){K=21036;break}else{I=I+1|0}}if((K|0)==21036){gGr(L);c[Z>>2]=0}c[3529554]=0;fxU(0,425984);if((c[2394]|0)==0){_=c[2112932]|0}else{c[2394]=0;I=c[3532596]|0;c[2112932]=I;P=c[3532592]|0;if((P|0)!=0){gGC(9104152,P|0,280)|0}c[2113054]=c[2113060];_=I}I=c[2388040]|0;P=_|0;Q=0;while(1){R=I+Q|0;c[P>>2]=R;c[P+131072>>2]=R;R=Q+1024|0;if(R>>>0>524287){break}else{P=P+4|0;Q=R}}Q=c[2388062]|0;c[_+4096>>2]=Q;c[_+69632>>2]=Q;c[_+135168>>2]=Q;P=Q+1024|0;c[_+4100>>2]=P;c[_+69636>>2]=P;c[_+135172>>2]=P;P=Q+2048|0;c[_+4104>>2]=P;c[_+69640>>2]=P;c[_+135176>>2]=P;P=Q+3072|0;c[_+4108>>2]=P;c[_+69644>>2]=P;c[_+135180>>2]=P;P=Q+4096|0;c[_+4112>>2]=P;c[_+69648>>2]=P;c[_+135184>>2]=P;P=Q+5120|0;c[_+4116>>2]=P;c[_+69652>>2]=P;c[_+135188>>2]=P;P=Q+6144|0;c[_+4120>>2]=P;c[_+69656>>2]=P;c[_+135192>>2]=P;P=Q+7168|0;c[_+4124>>2]=P;c[_+69660>>2]=P;c[_+135196>>2]=P;P=Q+8192|0;c[_+4128>>2]=P;c[_+69664>>2]=P;c[_+135200>>2]=P;P=Q+9216|0;c[_+4132>>2]=P;c[_+69668>>2]=P;c[_+135204>>2]=P;P=Q+10240|0;c[_+4136>>2]=P;c[_+69672>>2]=P;c[_+135208>>2]=P;P=Q+11264|0;c[_+4140>>2]=P;c[_+69676>>2]=P;c[_+135212>>2]=P;P=Q+12288|0;c[_+4144>>2]=P;c[_+69680>>2]=P;c[_+135216>>2]=P;P=Q+13312|0;c[_+4148>>2]=P;c[_+69684>>2]=P;c[_+135220>>2]=P;P=Q+14336|0;c[_+4152>>2]=P;c[_+69688>>2]=P;c[_+135224>>2]=P;P=Q+15360|0;c[_+4156>>2]=P;c[_+69692>>2]=P;c[_+135228>>2]=P;P=c[2443440]|0;c[_+4608>>2]=P;c[_+70144>>2]=P;c[_+135680>>2]=P;Q=P+1024|0;c[_+4612>>2]=Q;c[_+70148>>2]=Q;c[_+135684>>2]=Q;Q=c[2439630]|0;c[_+5120>>2]=Q;c[_+70656>>2]=Q;c[_+136192>>2]=Q;P=Q+1024|0;c[_+5124>>2]=P;c[_+70660>>2]=P;c[_+136196>>2]=P;P=c[2429330]|0;c[_+9216>>2]=P;c[_+74752>>2]=P;c[_+140288>>2]=P;P=c[2429328]|0;c[_+9220>>2]=P;c[_+74756>>2]=P;c[_+140292>>2]=P;P=c[2429326]|0;c[_+11264>>2]=P;c[_+76800>>2]=P;c[_+142336>>2]=P;P=c[2429324]|0;c[_+11268>>2]=P;c[_+76804>>2]=P;c[_+142340>>2]=P;P=c[2429770]|0;c[_+13312>>2]=P;c[_+78848>>2]=P;c[_+144384>>2]=P;P=c[2429768]|0;c[_+13316>>2]=P;c[_+78852>>2]=P;c[_+144388>>2]=P;c[_+196608>>2]=3136;c[_+196648>>2]=3412;c[_+196688>>2]=2186;c[_+196728>>2]=1590;P=c[3532592]|0;if((P|0)!=0){gGC(P|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fv8();c[2388530]=9554128;P=c[2391608]|0;if((P|0)!=0){Q=P;gGC(9661040,Q|0,68)|0}c[2382]=0;Q=c[3527450]|0;P=0;do{I=Q+(P<<11)|0;c[9554144+(P<<2)>>2]=I;c[9562336+(P<<2)>>2]=I;P=P+1|0;}while(P>>>0<32);P=c[3527452]|0;c[2389528]=P;c[2390552]=P;c[2391576]=P;Q=P+2048|0;c[2389529]=Q;c[2390553]=Q;c[2391577]=Q;Q=P+4096|0;c[2389530]=Q;c[2390554]=Q;c[2391578]=Q;Q=P+6144|0;c[2389531]=Q;c[2390555]=Q;c[2391579]=Q;c[2388532]=1738;c[2388533]=3434;Q=c[2391608]|0;if((Q|0)!=0){P=Q;gGC(P|0,9661040,68)|0}c[2382]=-1;P=c[642608+(c[2436]<<2)>>2]|0;Q=c[P+128>>2]|0;if((c[P+52>>2]&4|0)==0){c[2113068]=Q;I=c[P+132>>2]|0;c[2113070]=I;c[2443814]=Q;c[2440436]=I;$=Q;aa=I}else{c[2113070]=Q;I=c[P+132>>2]|0;c[2113068]=I;c[2440436]=Q;c[2443814]=I;$=I;aa=Q}Q=ag($<<1,aa)|0;I=gGq(Q)|0;c[2112926]=I;if((I|0)!=0){gGz(I|0,0,Q|0)}UL(3e6,646,210,1);c[2438224]=2e6;c[2433522]=3406;c[2406672]=2246;c[3528468]=11080;c[2443842]=1023;h[745398]=.8;a[3203264]=1;Vr(1,15e5,0,2452,38,0);c[2438228]=1e7;c[2433526]=3248;c[2406676]=148;c[3528472]=444;c[2443846]=203;h[745419]=.35;a[3203368]=1;h[745418]=.9;a[3203360]=1;h[745417]=.9;a[3203352]=1;h[745416]=.9;a[3203344]=1;Ux(0,7575,1);c[2407030]=205;c[2407068]=3;c[2433476]=6822;c[2429336]=c[2443440];a[1950800]=1;a[986968]=1;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];Q=c[3532592]|0;if((Q|0)!=0){gGC(9104152,Q|0,280)|0}c[2113054]=c[2113060]}RI();Q=c[2394]|0;I=c[14130368+(Q<<2)>>2]|0;if((I|0)!=0){gGC(I|0,9104152,280)|0}c[8452240+(Q<<2)>>2]=c[2113054];c[2394]=-1;c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;lw(c[3540984]|0);c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){Q=0;do{lN(Q);mB(Q);Q=Q+1|0;}while((Q|0)<(c[2385508]|0))}c[2113156]=0;a[9628264]=0;c[2407033]=0;Q=c[3541206]|0;c[3541190]=Q;c[3541198]=Q;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=Q+256;c[3541199]=Q+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=Q+512;c[3541200]=Q+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=Q+768;c[3541201]=Q+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2444194]=0;a[9545184]=0;a[9758144]=0;a[9759752]=0;c[3527346]=0;gGz(9754968,0,3);a[9718113]=11;a[9718112]=11;c[2388530]=9554128;Q=c[2391608]|0;if((Q|0)!=0){I=Q;gGC(9661040,I|0,68)|0}c[2382]=0;I=c[2415273]|0;gGz(9661040,0,68);c[2415273]=I;a[9661063]=20;c[2415262]=511;I=c[2388539]|0;do{if((I|0)==0){Q=c[2388532]|0;if((Q|0)==0){ab=0;ac=8191;ad=9554128;break}P=gj[Q&4095](8190)|0;ab=P;ac=(d[9661071]|0)<<13|8191;ad=c[2388530]|0}else{ab=a[I+2046|0]|0;ac=8191;ad=9554128}}while(0);a[9661044]=ab;I=c[ad+16+(ac>>>11<<2)>>2]|0;do{if((I|0)==0){P=c[ad>>2]|0;if((P|0)==0){ae=0;af=ad;break}Q=gj[P&4095](ac)|0;ae=Q;af=c[2388530]|0}else{ae=a[I+2047|0]|0;af=ad}}while(0);a[9661045]=ae;a[9661075]=4;a[9661073]=0;c[2415270]=131072;c[2415275]=0;gGz(9661084,0,5);I=c[af+12304>>2]|0;if((I|0)!=0){Q=I;gGC(Q|0,9661040,68)|0}c[2382]=-1;O=0;i=b;return O|0}}while(0);c[2426664]=0;O=1;i=b;return O|0}function aB5(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>24){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5273028+(b*112|0)>>2];c[a+104>>2]=c[5273032+(b*112|0)>>2];c[a+108>>2]=c[5273036+(b*112|0)>>2];d=0;return d|0}function aB6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<25&(d|0)==0)){e=1;return e|0}c[a>>2]=5272928+(b*112|0);e=0;return e|0}function aB7(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>33){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5275728+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aB8(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>24){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5276236+(b*112|0)>>2];c[a+104>>2]=c[5276240+(b*112|0)>>2];c[a+108>>2]=c[5276244+(b*112|0)>>2];d=0;return d|0}function aB9(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<25&(d|0)==0)){e=1;return e|0}c[a>>2]=5276136+(b*112|0);e=0;return e|0}function aCa(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>26){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5096204+(b*112|0)>>2];c[a+104>>2]=c[5096208+(b*112|0)>>2];c[a+108>>2]=c[5096212+(b*112|0)>>2];d=0;return d|0}function aCb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<27&(d|0)==0)){e=1;return e|0}c[a>>2]=5096104+(b*112|0);e=0;return e|0}function aCc(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>39){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5099128+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aCd(){var b=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0;b=i;i=i+2520|0;e=b|0;f=b+112|0;g=b+120|0;j=b+232|0;k=b+240|0;l=b+352|0;m=b+360|0;n=b+472|0;o=b+480|0;p=b+592|0;q=b+600|0;r=b+712|0;s=b+720|0;t=b+832|0;u=b+840|0;v=b+952|0;w=b+960|0;x=b+1072|0;y=b+1080|0;z=b+1192|0;A=b+1200|0;B=b+1312|0;C=b+1320|0;D=b+1432|0;E=b+1440|0;F=b+1552|0;G=b+1560|0;H=b+1672|0;I=b+1680|0;J=b+1792|0;K=b+1800|0;L=b+1912|0;M=b+1920|0;N=b+2032|0;O=b+2040|0;P=b+2152|0;Q=b+2160|0;R=b+2272|0;S=b+2280|0;T=b+2392|0;U=b+2400|0;V=b+2512|0;aCN();if((R6((c[2388040]|0)+1|0,0,2)|0)!=0){W=1;i=b;return W|0}if((R6(c[2388040]|0,1,2)|0)!=0){W=1;i=b;return W|0}if((R6((c[2388040]|0)+131073|0,2,2)|0)!=0){W=1;i=b;return W|0}if((R6((c[2388040]|0)+131072|0,3,2)|0)!=0){W=1;i=b;return W|0}X=c[3527426]|0;if((c[3542200]|0)==0){W=1;i=b;return W|0}Y=U+108|0;c[Y>>2]=0;Z=U+100|0;c[Z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](U,4)|0;do{if((c[Y>>2]|0)!=0){U=c[Z>>2]|0;c[V>>2]=9534384;_=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[_&16383](V,4,0)|0;if((U|0)<1){W=1;i=b;return W|0}if((gzL(X,0,4)|0)==0){break}else{W=1}i=b;return W|0}}while(0);X=(c[3527450]|0)+7680|0;if((c[3542200]|0)==0){W=1;i=b;return W|0}V=S+108|0;c[V>>2]=0;Z=S+100|0;c[Z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](S,5)|0;do{if((c[V>>2]|0)!=0){S=c[Z>>2]|0;c[T>>2]=9534384;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Y&16383](T,5,0)|0;if((S|0)<1){W=1;i=b;return W|0}if((gzL(X,0,5)|0)==0){break}else{W=1}i=b;return W|0}}while(0);X=c[3529554]|0;if((c[3542200]|0)==0){W=1;i=b;return W|0}T=Q+108|0;c[T>>2]=0;Z=Q+100|0;c[Z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](Q,6)|0;do{if((c[T>>2]|0)!=0){Q=c[Z>>2]|0;c[R>>2]=9534384;V=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[V&16383](R,6,0)|0;if((Q|0)<1){W=1;i=b;return W|0}if((gzL(X,0,6)|0)==0){break}else{W=1}i=b;return W|0}}while(0);X=(c[3529554]|0)+65536|0;if((c[3542200]|0)==0){W=1;i=b;return W|0}R=O+108|0;c[R>>2]=0;Z=O+100|0;c[Z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](O,7)|0;do{if((c[R>>2]|0)!=0){O=c[Z>>2]|0;c[P>>2]=9534384;T=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[T&16383](P,7,0)|0;if((O|0)<1){W=1;i=b;return W|0}if((gzL(X,0,7)|0)==0){break}else{W=1}i=b;return W|0}}while(0);X=c[3529554]|0;P=c[2406550]|0;Z=0;do{R=Z<<6;gGz(P+R|0,0,64);O=0;do{T=1<<3-O;Q=(c[686408+(O<<2)>>2]|0)+R|0;V=0;do{S=Q+(c[1238464+(V<<2)>>2]|0)|0;Y=(V<<3)+R|0;U=0;do{_=S+(c[614800+(U<<2)>>2]|0)|0;if((d[X+((_|0)/8|0)|0]&128>>>((_&7)>>>0)|0)!=0){_=P+(Y+U)|0;a[_]=(d[_]|T)&255}U=U+1|0;}while((U|0)<8);V=V+1|0;}while((V|0)<8);O=O+1|0;}while((O|0)<4);Z=Z+1|0;}while((Z|0)<4096);gGz(X|0,0,524288);if((c[3542200]|0)==0){W=1;i=b;return W|0}Z=M+108|0;c[Z>>2]=0;P=M+100|0;c[P>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](M,8)|0;do{if((c[Z>>2]|0)!=0){M=c[P>>2]|0;c[N>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](N,8,0)|0;if((M|0)<1){W=1;i=b;return W|0}if((gzL(X,0,8)|0)==0){break}else{W=1}i=b;return W|0}}while(0);X=(c[3529554]|0)+65536|0;if((c[3542200]|0)==0){W=1;i=b;return W|0}N=K+108|0;c[N>>2]=0;P=K+100|0;c[P>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](K,9)|0;do{if((c[N>>2]|0)!=0){K=c[P>>2]|0;c[L>>2]=9534384;Z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Z&16383](L,9,0)|0;if((K|0)<1){W=1;i=b;return W|0}if((gzL(X,0,9)|0)==0){break}else{W=1}i=b;return W|0}}while(0);X=(c[3529554]|0)+131072|0;if((c[3542200]|0)==0){W=1;i=b;return W|0}L=I+108|0;c[L>>2]=0;P=I+100|0;c[P>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](I,10)|0;do{if((c[L>>2]|0)!=0){I=c[P>>2]|0;c[J>>2]=9534384;N=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[N&16383](J,10,0)|0;if((I|0)<1){W=1;i=b;return W|0}if((gzL(X,0,10)|0)==0){break}else{W=1}i=b;return W|0}}while(0);X=(c[3529554]|0)+196608|0;if((c[3542200]|0)==0){W=1;i=b;return W|0}J=G+108|0;c[J>>2]=0;P=G+100|0;c[P>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](G,11)|0;do{if((c[J>>2]|0)!=0){G=c[P>>2]|0;c[H>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](H,11,0)|0;if((G|0)<1){W=1;i=b;return W|0}if((gzL(X,0,11)|0)==0){break}else{W=1}i=b;return W|0}}while(0);X=c[3529554]|0;H=c[2386350]|0;P=0;do{J=P<<8;gGz(H+J|0,0,256);G=0;do{L=1<<3-G;I=(c[1179e3+(G<<2)>>2]|0)+J|0;N=0;do{K=I+(c[609008+(N<<2)>>2]|0)|0;Z=(N<<4)+J|0;M=0;do{O=K+(c[612640+(M<<2)>>2]|0)|0;if((d[X+((O|0)/8|0)|0]&128>>>((O&7)>>>0)|0)!=0){O=H+(Z+M)|0;a[O]=(d[O]|L)&255}M=M+1|0;}while((M|0)<16);N=N+1|0;}while((N|0)<16);G=G+1|0;}while((G|0)<4);P=P+1|0;}while((P|0)<2048);gGz(X|0,0,524288);if((c[3542200]|0)==0){W=1;i=b;return W|0}P=E+108|0;c[P>>2]=0;H=E+100|0;c[H>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](E,12)|0;do{if((c[P>>2]|0)!=0){E=c[H>>2]|0;c[F>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](F,12,0)|0;if((E|0)<1){W=1;i=b;return W|0}if((gzL(X,0,12)|0)==0){break}else{W=1}i=b;return W|0}}while(0);X=(c[3529554]|0)+32768|0;if((c[3542200]|0)==0){W=1;i=b;return W|0}F=C+108|0;c[F>>2]=0;H=C+100|0;c[H>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](C,13)|0;do{if((c[F>>2]|0)!=0){C=c[H>>2]|0;c[D>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](D,13,0)|0;if((C|0)<1){W=1;i=b;return W|0}if((gzL(X,0,13)|0)==0){break}else{W=1}i=b;return W|0}}while(0);X=(c[3529554]|0)+65536|0;if((c[3542200]|0)==0){W=1;i=b;return W|0}D=A+108|0;c[D>>2]=0;H=A+100|0;c[H>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](A,14)|0;do{if((c[D>>2]|0)!=0){A=c[H>>2]|0;c[B>>2]=9534384;F=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[F&16383](B,14,0)|0;if((A|0)<1){W=1;i=b;return W|0}if((gzL(X,0,14)|0)==0){break}else{W=1}i=b;return W|0}}while(0);X=(c[3529554]|0)+98304|0;if((c[3542200]|0)==0){W=1;i=b;return W|0}B=y+108|0;c[B>>2]=0;H=y+100|0;c[H>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](y,15)|0;do{if((c[B>>2]|0)!=0){y=c[H>>2]|0;c[z>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](z,15,0)|0;if((y|0)<1){W=1;i=b;return W|0}if((gzL(X,0,15)|0)==0){break}else{W=1}i=b;return W|0}}while(0);X=c[3529554]|0;z=c[2386348]|0;H=0;do{B=H<<8;gGz(z+B|0,0,256);y=0;do{D=1<<3-y;A=(c[611416+(y<<2)>>2]|0)+B|0;F=0;do{C=A+(c[609008+(F<<2)>>2]|0)|0;P=(F<<4)+B|0;E=0;do{G=C+(c[612640+(E<<2)>>2]|0)|0;if((d[X+((G|0)/8|0)|0]&128>>>((G&7)>>>0)|0)!=0){G=z+(P+E)|0;a[G]=(d[G]|D)&255}E=E+1|0;}while((E|0)<16);F=F+1|0;}while((F|0)<16);y=y+1|0;}while((y|0)<4);H=H+1|0;}while((H|0)<1024);gGz(X|0,0,524288);if((c[3542200]|0)==0){W=1;i=b;return W|0}H=w+108|0;c[H>>2]=0;z=w+100|0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](w,16)|0;do{if((c[H>>2]|0)!=0){w=c[z>>2]|0;c[x>>2]=9534384;y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[y&16383](x,16,0)|0;if((w|0)<1){W=1;i=b;return W|0}if((gzL(X,0,16)|0)==0){break}else{W=1}i=b;return W|0}}while(0);X=(c[3529554]|0)+65536|0;if((c[3542200]|0)==0){W=1;i=b;return W|0}x=u+108|0;c[x>>2]=0;z=u+100|0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](u,17)|0;do{if((c[x>>2]|0)!=0){u=c[z>>2]|0;c[v>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](v,17,0)|0;if((u|0)<1){W=1;i=b;return W|0}if((gzL(X,0,17)|0)==0){break}else{W=1}i=b;return W|0}}while(0);X=(c[3529554]|0)+131072|0;if((c[3542200]|0)==0){W=1;i=b;return W|0}v=s+108|0;c[v>>2]=0;z=s+100|0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](s,18)|0;do{if((c[v>>2]|0)!=0){s=c[z>>2]|0;c[t>>2]=9534384;x=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[x&16383](t,18,0)|0;if((s|0)<1){W=1;i=b;return W|0}if((gzL(X,0,18)|0)==0){break}else{W=1}i=b;return W|0}}while(0);X=(c[3529554]|0)+196608|0;if((c[3542200]|0)==0){W=1;i=b;return W|0}t=q+108|0;c[t>>2]=0;z=q+100|0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](q,19)|0;do{if((c[t>>2]|0)!=0){q=c[z>>2]|0;c[r>>2]=9534384;v=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[v&16383](r,19,0)|0;if((q|0)<1){W=1;i=b;return W|0}if((gzL(X,0,19)|0)==0){break}else{W=1}i=b;return W|0}}while(0);X=(c[3529554]|0)+262144|0;if((c[3542200]|0)==0){W=1;i=b;return W|0}r=o+108|0;c[r>>2]=0;z=o+100|0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](o,20)|0;do{if((c[r>>2]|0)!=0){o=c[z>>2]|0;c[p>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](p,20,0)|0;if((o|0)<1){W=1;i=b;return W|0}if((gzL(X,0,20)|0)==0){break}else{W=1}i=b;return W|0}}while(0);X=(c[3529554]|0)+327680|0;if((c[3542200]|0)==0){W=1;i=b;return W|0}p=m+108|0;c[p>>2]=0;z=m+100|0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,21)|0;do{if((c[p>>2]|0)!=0){m=c[z>>2]|0;c[n>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](n,21,0)|0;if((m|0)<1){W=1;i=b;return W|0}if((gzL(X,0,21)|0)==0){break}else{W=1}i=b;return W|0}}while(0);X=(c[3529554]|0)+393216|0;if((c[3542200]|0)==0){W=1;i=b;return W|0}n=k+108|0;c[n>>2]=0;z=k+100|0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,22)|0;do{if((c[n>>2]|0)!=0){k=c[z>>2]|0;c[l>>2]=9534384;p=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[p&16383](l,22,0)|0;if((k|0)<1){W=1;i=b;return W|0}if((gzL(X,0,22)|0)==0){break}else{W=1}i=b;return W|0}}while(0);X=(c[3529554]|0)+458752|0;if((c[3542200]|0)==0){W=1;i=b;return W|0}l=g+108|0;c[l>>2]=0;z=g+100|0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,23)|0;do{if((c[l>>2]|0)!=0){g=c[z>>2]|0;c[j>>2]=9534384;n=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[n&16383](j,23,0)|0;if((g|0)<1){W=1;i=b;return W|0}if((gzL(X,0,23)|0)==0){break}else{W=1}i=b;return W|0}}while(0);X=c[3529554]|0;j=c[3529604]|0;z=0;do{l=z<<8;gGz(j+l|0,0,256);g=0;do{n=1<<3-g;k=(c[961536+(g<<2)>>2]|0)+l|0;p=0;do{m=k+(c[609008+(p<<2)>>2]|0)|0;r=(p<<4)+l|0;o=0;do{t=m+(c[612640+(o<<2)>>2]|0)|0;if((d[X+((t|0)/8|0)|0]&128>>>((t&7)>>>0)|0)!=0){t=j+(r+o)|0;a[t]=(d[t]|n)&255}o=o+1|0;}while((o|0)<16);p=p+1|0;}while((p|0)<16);g=g+1|0;}while((g|0)<4);z=z+1|0;}while((z|0)<4096);z=c[3541206]|0;if((c[3542200]|0)==0){W=1;i=b;return W|0}j=e+108|0;c[j>>2]=0;X=e+100|0;c[X>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,24)|0;do{if((c[j>>2]|0)!=0){e=c[X>>2]|0;c[f>>2]=9534384;g=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[g&16383](f,24,0)|0;if((e|0)<1){W=1;i=b;return W|0}if((gzL(z,0,24)|0)==0){break}else{W=1}i=b;return W|0}}while(0);z=c[3529554]|0;f=0;while(1){if((f|0)>=1024){break}$=9638528+(f<<2)|0;if((c[$>>2]|0)==(z|0)){aa=21308;break}else{f=f+1|0}}if((aa|0)==21308){gGr(z);c[$>>2]=0}c[3529554]=0;c[2433476]=11710;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];$=c[3532592]|0;if(($|0)!=0){gGC(9104152,$|0,280)|0}c[2113054]=c[2113060]}$=c[2112932]|0;c[$+6144>>2]=1;c[$+71680>>2]=1;c[$+137216>>2]=1;c[$+6148>>2]=1;c[$+71684>>2]=1;c[$+137220>>2]=1;c[$+6152>>2]=1;c[$+71688>>2]=1;c[$+137224>>2]=1;c[$+6156>>2]=1;c[$+71692>>2]=1;c[$+137228>>2]=1;c[$+196612>>2]=1276;c[$+196652>>2]=2482;c[$+196692>>2]=2192;c[$+196732>>2]=2960;$=c[3532592]|0;if(($|0)!=0){gGC($|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fv8();c[2388530]=9554128;$=c[2391608]|0;if(($|0)!=0){z=$;gGC(9661040,z|0,68)|0}c[2382]=0;z=c[3527450]|0;$=0;do{aa=z+($<<11)|0;c[9554144+($<<2)>>2]=aa;c[9562336+($<<2)>>2]=aa;$=$+1|0;}while($>>>0<32);$=c[3527452]|0;c[2389528]=$;c[2390552]=$;c[2391576]=$;z=$+2048|0;c[2389529]=z;c[2390553]=z;c[2391577]=z;z=$+4096|0;c[2389530]=z;c[2390554]=z;c[2391578]=z;z=$+6144|0;c[2389531]=z;c[2390555]=z;c[2391579]=z;z=c[2443452]|0;c[2389532]=z;c[2390556]=z;c[2391580]=z;$=z+2048|0;c[2389533]=$;c[2390557]=$;c[2391581]=$;$=z+4096|0;c[2389534]=$;c[2390558]=$;c[2391582]=$;$=z+6144|0;c[2389535]=$;c[2390559]=$;c[2391583]=$;c[2388532]=1576;c[2388533]=592;$=c[2391608]|0;if(($|0)!=0){z=$;gGC(z|0,9661040,68)|0}c[2382]=-1;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];z=c[3532592]|0;if((z|0)!=0){gGC(9104152,z|0,280)|0}c[2113054]=c[2113060]}RI();z=c[2394]|0;$=c[14130368+(z<<2)>>2]|0;if(($|0)!=0){gGC($|0,9104152,280)|0}c[8452240+(z<<2)>>2]=c[2113054];c[2394]=-1;c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;lw(c[3540984]|0);c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){z=0;do{lN(z);mB(z);z=z+1|0;}while((z|0)<(c[2385508]|0))}c[2113156]=0;a[9628264]=0;c[2407033]=0;z=c[3541206]|0;c[3541190]=z;c[3541198]=z;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=z+256;c[3541199]=z+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=z+512;c[3541200]=z+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=z+768;c[3541201]=z+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2444194]=0;a[9545184]=0;a[9758144]=0;a[9759752]=0;c[3527346]=0;gGz(9754968,0,3);a[9718113]=11;a[9718112]=11;c[3528556]=0;z=c[2433594]|0;c[2443776]=z;L27183:do{if((z|0)!=0){$=z|0;gGC(9660952,$|0,52)|0;switch(a[9660952]|0){case 0:{c[2309668]=638960;break L27183;break};case 1:{c[2309668]=634096;break L27183;break};case 5:{c[2309668]=7354992;break L27183;break};case 2:{c[2309668]=638960;break L27183;break};case 3:{c[2309668]=639984;break L27183;break};case 4:{c[2309668]=7356016;break L27183;break};default:{break L27183}}}}while(0);c[2113164]=c[2432850];gu[c[z+56>>2]&16383]();z=c[2443776]|0;if((z|0)!=0){$=z|0;gGC($|0,9660952,52)|0}c[9731400+(c[3528556]<<2)>>2]=c[2113164];c[2443776]=0;c[3528556]=-1;c[2388530]=9554128;$=c[2391608]|0;if(($|0)!=0){z=$;gGC(9661040,z|0,68)|0}c[2382]=0;z=c[2415273]|0;gGz(9661040,0,68);c[2415273]=z;a[9661063]=20;c[2415262]=511;z=c[2388539]|0;do{if((z|0)==0){$=c[2388532]|0;if(($|0)==0){ab=0;ac=8191;ad=9554128;break}aa=gj[$&4095](8190)|0;ab=aa;ac=d[9661071]<<13|8191;ad=c[2388530]|0}else{ab=a[z+2046|0]|0;ac=8191;ad=9554128}}while(0);a[9661044]=ab;ab=c[ad+16+(ac>>>11<<2)>>2]|0;do{if((ab|0)==0){z=c[ad>>2]|0;if((z|0)==0){ae=0;af=ad;break}aa=gj[z&4095](ac)|0;ae=aa;af=c[2388530]|0}else{ae=a[ab+2047|0]|0;af=ad}}while(0);a[9661045]=ae;a[9661075]=4;a[9661073]=0;c[2415270]=131072;c[2415275]=0;gGz(9661084,0,5);ae=c[af+12304>>2]|0;if((ae|0)!=0){af=ae;gGC(af|0,9661040,68)|0}c[2382]=-1;W=0;i=b;return W|0}function aCe(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>24){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3540028+(b*112|0)>>2];c[a+104>>2]=c[3540032+(b*112|0)>>2];c[a+108>>2]=c[3540036+(b*112|0)>>2];d=0;return d|0}function aCf(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<25&(d|0)==0)){e=1;return e|0}c[a>>2]=3539928+(b*112|0);e=0;return e|0}function aCg(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>24){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3545628+(b*112|0)>>2];c[a+104>>2]=c[3545632+(b*112|0)>>2];c[a+108>>2]=c[3545636+(b*112|0)>>2];d=0;return d|0}function aCh(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<25&(d|0)==0)){e=1;return e|0}c[a>>2]=3545528+(b*112|0);e=0;return e|0}function aCi(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>24){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3542828+(b*112|0)>>2];c[a+104>>2]=c[3542832+(b*112|0)>>2];c[a+108>>2]=c[3542836+(b*112|0)>>2];d=0;return d|0}function aCj(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<25&(d|0)==0)){e=1;return e|0}c[a>>2]=3542728+(b*112|0);e=0;return e|0}function aCk(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>24){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1750468+(b*112|0)>>2];c[a+104>>2]=c[1750472+(b*112|0)>>2];c[a+108>>2]=c[1750476+(b*112|0)>>2];d=0;return d|0}function aCl(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<25&(d|0)==0)){e=1;return e|0}c[a>>2]=1750368+(b*112|0);e=0;return e|0}function aCm(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>23){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3548428+(b*112|0)>>2];c[a+104>>2]=c[3548432+(b*112|0)>>2];c[a+108>>2]=c[3548436+(b*112|0)>>2];d=0;return d|0}function aCn(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<24&(d|0)==0)){e=1;return e|0}c[a>>2]=3548328+(b*112|0);e=0;return e|0}function aCo(){var b=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0;b=i;i=i+2400|0;e=b|0;f=b+112|0;g=b+120|0;j=b+232|0;k=b+240|0;l=b+352|0;m=b+360|0;n=b+472|0;o=b+480|0;p=b+592|0;q=b+600|0;r=b+712|0;s=b+720|0;t=b+832|0;u=b+840|0;v=b+952|0;w=b+960|0;x=b+1072|0;y=b+1080|0;z=b+1192|0;A=b+1200|0;B=b+1312|0;C=b+1320|0;D=b+1432|0;E=b+1440|0;F=b+1552|0;G=b+1560|0;H=b+1672|0;I=b+1680|0;J=b+1792|0;K=b+1800|0;L=b+1912|0;M=b+1920|0;N=b+2032|0;O=b+2040|0;P=b+2152|0;Q=b+2160|0;R=b+2272|0;S=b+2280|0;T=b+2392|0;aCN();if((R6((c[2388040]|0)+1|0,0,2)|0)!=0){U=1;i=b;return U|0}if((R6(c[2388040]|0,1,2)|0)!=0){U=1;i=b;return U|0}if((R6((c[2388040]|0)+131073|0,2,2)|0)!=0){U=1;i=b;return U|0}if((R6((c[2388040]|0)+131072|0,3,2)|0)!=0){U=1;i=b;return U|0}V=c[3527426]|0;if((c[3542200]|0)==0){U=1;i=b;return U|0}W=S+108|0;c[W>>2]=0;X=S+100|0;c[X>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](S,4)|0;do{if((c[W>>2]|0)!=0){S=c[X>>2]|0;c[T>>2]=9534384;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Y&16383](T,4,0)|0;if((S|0)<1){U=1;i=b;return U|0}if((gzL(V,0,4)|0)==0){break}else{U=1}i=b;return U|0}}while(0);V=c[3529554]|0;if((c[3542200]|0)==0){U=1;i=b;return U|0}T=Q+108|0;c[T>>2]=0;X=Q+100|0;c[X>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](Q,5)|0;do{if((c[T>>2]|0)!=0){Q=c[X>>2]|0;c[R>>2]=9534384;W=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[W&16383](R,5,0)|0;if((Q|0)<1){U=1;i=b;return U|0}if((gzL(V,0,5)|0)==0){break}else{U=1}i=b;return U|0}}while(0);V=(c[3529554]|0)+65536|0;if((c[3542200]|0)==0){U=1;i=b;return U|0}R=O+108|0;c[R>>2]=0;X=O+100|0;c[X>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](O,6)|0;do{if((c[R>>2]|0)!=0){O=c[X>>2]|0;c[P>>2]=9534384;T=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[T&16383](P,6,0)|0;if((O|0)<1){U=1;i=b;return U|0}if((gzL(V,0,6)|0)==0){break}else{U=1}i=b;return U|0}}while(0);V=c[3529554]|0;P=c[2406550]|0;X=0;do{R=X<<6;gGz(P+R|0,0,64);O=0;do{T=1<<3-O;Q=(c[686408+(O<<2)>>2]|0)+R|0;W=0;do{S=Q+(c[1238464+(W<<2)>>2]|0)|0;Y=(W<<3)+R|0;Z=0;do{_=S+(c[614800+(Z<<2)>>2]|0)|0;if((d[V+((_|0)/8|0)|0]&128>>>((_&7)>>>0)|0)!=0){_=P+(Y+Z)|0;a[_]=(d[_]|T)&255}Z=Z+1|0;}while((Z|0)<8);W=W+1|0;}while((W|0)<8);O=O+1|0;}while((O|0)<4);X=X+1|0;}while((X|0)<4096);gGz(V|0,0,524288);if((c[3542200]|0)==0){U=1;i=b;return U|0}X=M+108|0;c[X>>2]=0;P=M+100|0;c[P>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](M,7)|0;do{if((c[X>>2]|0)!=0){M=c[P>>2]|0;c[N>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](N,7,0)|0;if((M|0)<1){U=1;i=b;return U|0}if((gzL(V,0,7)|0)==0){break}else{U=1}i=b;return U|0}}while(0);V=(c[3529554]|0)+65536|0;if((c[3542200]|0)==0){U=1;i=b;return U|0}N=K+108|0;c[N>>2]=0;P=K+100|0;c[P>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](K,8)|0;do{if((c[N>>2]|0)!=0){K=c[P>>2]|0;c[L>>2]=9534384;X=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[X&16383](L,8,0)|0;if((K|0)<1){U=1;i=b;return U|0}if((gzL(V,0,8)|0)==0){break}else{U=1}i=b;return U|0}}while(0);V=(c[3529554]|0)+131072|0;if((c[3542200]|0)==0){U=1;i=b;return U|0}L=I+108|0;c[L>>2]=0;P=I+100|0;c[P>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](I,9)|0;do{if((c[L>>2]|0)!=0){I=c[P>>2]|0;c[J>>2]=9534384;N=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[N&16383](J,9,0)|0;if((I|0)<1){U=1;i=b;return U|0}if((gzL(V,0,9)|0)==0){break}else{U=1}i=b;return U|0}}while(0);V=(c[3529554]|0)+196608|0;if((c[3542200]|0)==0){U=1;i=b;return U|0}J=G+108|0;c[J>>2]=0;P=G+100|0;c[P>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](G,10)|0;do{if((c[J>>2]|0)!=0){G=c[P>>2]|0;c[H>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](H,10,0)|0;if((G|0)<1){U=1;i=b;return U|0}if((gzL(V,0,10)|0)==0){break}else{U=1}i=b;return U|0}}while(0);V=c[3529554]|0;H=c[2386350]|0;P=0;do{J=P<<8;gGz(H+J|0,0,256);G=0;do{L=1<<3-G;I=(c[1179e3+(G<<2)>>2]|0)+J|0;N=0;do{K=I+(c[609008+(N<<2)>>2]|0)|0;X=(N<<4)+J|0;M=0;do{O=K+(c[612640+(M<<2)>>2]|0)|0;if((d[V+((O|0)/8|0)|0]&128>>>((O&7)>>>0)|0)!=0){O=H+(X+M)|0;a[O]=(d[O]|L)&255}M=M+1|0;}while((M|0)<16);N=N+1|0;}while((N|0)<16);G=G+1|0;}while((G|0)<4);P=P+1|0;}while((P|0)<2048);gGz(V|0,0,524288);if((c[3542200]|0)==0){U=1;i=b;return U|0}P=E+108|0;c[P>>2]=0;H=E+100|0;c[H>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](E,11)|0;do{if((c[P>>2]|0)!=0){E=c[H>>2]|0;c[F>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](F,11,0)|0;if((E|0)<1){U=1;i=b;return U|0}if((gzL(V,0,11)|0)==0){break}else{U=1}i=b;return U|0}}while(0);V=(c[3529554]|0)+32768|0;if((c[3542200]|0)==0){U=1;i=b;return U|0}F=C+108|0;c[F>>2]=0;H=C+100|0;c[H>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](C,12)|0;do{if((c[F>>2]|0)!=0){C=c[H>>2]|0;c[D>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](D,12,0)|0;if((C|0)<1){U=1;i=b;return U|0}if((gzL(V,0,12)|0)==0){break}else{U=1}i=b;return U|0}}while(0);V=(c[3529554]|0)+65536|0;if((c[3542200]|0)==0){U=1;i=b;return U|0}D=A+108|0;c[D>>2]=0;H=A+100|0;c[H>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](A,13)|0;do{if((c[D>>2]|0)!=0){A=c[H>>2]|0;c[B>>2]=9534384;F=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[F&16383](B,13,0)|0;if((A|0)<1){U=1;i=b;return U|0}if((gzL(V,0,13)|0)==0){break}else{U=1}i=b;return U|0}}while(0);V=(c[3529554]|0)+98304|0;if((c[3542200]|0)==0){U=1;i=b;return U|0}B=y+108|0;c[B>>2]=0;H=y+100|0;c[H>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](y,14)|0;do{if((c[B>>2]|0)!=0){y=c[H>>2]|0;c[z>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](z,14,0)|0;if((y|0)<1){U=1;i=b;return U|0}if((gzL(V,0,14)|0)==0){break}else{U=1}i=b;return U|0}}while(0);V=c[3529554]|0;z=c[2386348]|0;H=0;do{B=H<<8;gGz(z+B|0,0,256);y=0;do{D=1<<3-y;A=(c[611416+(y<<2)>>2]|0)+B|0;F=0;do{C=A+(c[609008+(F<<2)>>2]|0)|0;P=(F<<4)+B|0;E=0;do{G=C+(c[612640+(E<<2)>>2]|0)|0;if((d[V+((G|0)/8|0)|0]&128>>>((G&7)>>>0)|0)!=0){G=z+(P+E)|0;a[G]=(d[G]|D)&255}E=E+1|0;}while((E|0)<16);F=F+1|0;}while((F|0)<16);y=y+1|0;}while((y|0)<4);H=H+1|0;}while((H|0)<1024);gGz(V|0,0,524288);if((c[3542200]|0)==0){U=1;i=b;return U|0}H=w+108|0;c[H>>2]=0;z=w+100|0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](w,15)|0;do{if((c[H>>2]|0)!=0){w=c[z>>2]|0;c[x>>2]=9534384;y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[y&16383](x,15,0)|0;if((w|0)<1){U=1;i=b;return U|0}if((gzL(V,0,15)|0)==0){break}else{U=1}i=b;return U|0}}while(0);V=(c[3529554]|0)+65536|0;if((c[3542200]|0)==0){U=1;i=b;return U|0}x=u+108|0;c[x>>2]=0;z=u+100|0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](u,16)|0;do{if((c[x>>2]|0)!=0){u=c[z>>2]|0;c[v>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](v,16,0)|0;if((u|0)<1){U=1;i=b;return U|0}if((gzL(V,0,16)|0)==0){break}else{U=1}i=b;return U|0}}while(0);V=(c[3529554]|0)+131072|0;if((c[3542200]|0)==0){U=1;i=b;return U|0}v=s+108|0;c[v>>2]=0;z=s+100|0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](s,17)|0;do{if((c[v>>2]|0)!=0){s=c[z>>2]|0;c[t>>2]=9534384;x=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[x&16383](t,17,0)|0;if((s|0)<1){U=1;i=b;return U|0}if((gzL(V,0,17)|0)==0){break}else{U=1}i=b;return U|0}}while(0);V=(c[3529554]|0)+196608|0;if((c[3542200]|0)==0){U=1;i=b;return U|0}t=q+108|0;c[t>>2]=0;z=q+100|0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](q,18)|0;do{if((c[t>>2]|0)!=0){q=c[z>>2]|0;c[r>>2]=9534384;v=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[v&16383](r,18,0)|0;if((q|0)<1){U=1;i=b;return U|0}if((gzL(V,0,18)|0)==0){break}else{U=1}i=b;return U|0}}while(0);V=(c[3529554]|0)+262144|0;if((c[3542200]|0)==0){U=1;i=b;return U|0}r=o+108|0;c[r>>2]=0;z=o+100|0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](o,19)|0;do{if((c[r>>2]|0)!=0){o=c[z>>2]|0;c[p>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](p,19,0)|0;if((o|0)<1){U=1;i=b;return U|0}if((gzL(V,0,19)|0)==0){break}else{U=1}i=b;return U|0}}while(0);V=(c[3529554]|0)+327680|0;if((c[3542200]|0)==0){U=1;i=b;return U|0}p=m+108|0;c[p>>2]=0;z=m+100|0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,20)|0;do{if((c[p>>2]|0)!=0){m=c[z>>2]|0;c[n>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](n,20,0)|0;if((m|0)<1){U=1;i=b;return U|0}if((gzL(V,0,20)|0)==0){break}else{U=1}i=b;return U|0}}while(0);V=(c[3529554]|0)+393216|0;if((c[3542200]|0)==0){U=1;i=b;return U|0}n=k+108|0;c[n>>2]=0;z=k+100|0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,21)|0;do{if((c[n>>2]|0)!=0){k=c[z>>2]|0;c[l>>2]=9534384;p=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[p&16383](l,21,0)|0;if((k|0)<1){U=1;i=b;return U|0}if((gzL(V,0,21)|0)==0){break}else{U=1}i=b;return U|0}}while(0);V=(c[3529554]|0)+458752|0;if((c[3542200]|0)==0){U=1;i=b;return U|0}l=g+108|0;c[l>>2]=0;z=g+100|0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,22)|0;do{if((c[l>>2]|0)!=0){g=c[z>>2]|0;c[j>>2]=9534384;n=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[n&16383](j,22,0)|0;if((g|0)<1){U=1;i=b;return U|0}if((gzL(V,0,22)|0)==0){break}else{U=1}i=b;return U|0}}while(0);V=c[3529554]|0;j=c[3529604]|0;z=0;do{l=z<<8;gGz(j+l|0,0,256);g=0;do{n=1<<3-g;k=(c[961536+(g<<2)>>2]|0)+l|0;p=0;do{m=k+(c[609008+(p<<2)>>2]|0)|0;r=(p<<4)+l|0;o=0;do{t=m+(c[612640+(o<<2)>>2]|0)|0;if((d[V+((t|0)/8|0)|0]&128>>>((t&7)>>>0)|0)!=0){t=j+(r+o)|0;a[t]=(d[t]|n)&255}o=o+1|0;}while((o|0)<16);p=p+1|0;}while((p|0)<16);g=g+1|0;}while((g|0)<4);z=z+1|0;}while((z|0)<4096);z=c[3541206]|0;if((c[3542200]|0)==0){U=1;i=b;return U|0}j=e+108|0;c[j>>2]=0;V=e+100|0;c[V>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,23)|0;do{if((c[j>>2]|0)!=0){e=c[V>>2]|0;c[f>>2]=9534384;g=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[g&16383](f,23,0)|0;if((e|0)<1){U=1;i=b;return U|0}if((gzL(z,0,23)|0)==0){break}else{U=1}i=b;return U|0}}while(0);z=c[3529554]|0;f=0;while(1){if((f|0)>=1024){break}$=9638528+(f<<2)|0;if((c[$>>2]|0)==(z|0)){aa=21608;break}else{f=f+1|0}}if((aa|0)==21608){gGr(z);c[$>>2]=0}c[3529554]=0;c[2433476]=11710;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];$=c[3532592]|0;if(($|0)!=0){gGC(9104152,$|0,280)|0}c[2113054]=c[2113060]}RI();$=c[2394]|0;z=c[14130368+($<<2)>>2]|0;if((z|0)!=0){gGC(z|0,9104152,280)|0}c[8452240+($<<2)>>2]=c[2113054];c[2394]=-1;c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;lw(c[3540984]|0);c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){$=0;do{lN($);mB($);$=$+1|0;}while(($|0)<(c[2385508]|0))}c[2113156]=0;a[9628264]=0;c[2407033]=0;$=c[3541206]|0;c[3541190]=$;c[3541198]=$;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=$+256;c[3541199]=$+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=$+512;c[3541200]=$+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=$+768;c[3541201]=$+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2444194]=0;a[9545184]=0;a[9758144]=0;a[9759752]=0;c[3527346]=0;gGz(9754968,0,3);a[9718113]=11;a[9718112]=11;c[3528556]=0;$=c[2433594]|0;c[2443776]=$;L27570:do{if(($|0)!=0){z=$|0;gGC(9660952,z|0,52)|0;switch(a[9660952]|0){case 1:{c[2309668]=634096;break L27570;break};case 3:{c[2309668]=639984;break L27570;break};case 2:{c[2309668]=638960;break L27570;break};case 4:{c[2309668]=7356016;break L27570;break};case 5:{c[2309668]=7354992;break L27570;break};case 0:{c[2309668]=638960;break L27570;break};default:{break L27570}}}}while(0);c[2113164]=c[2432850];gu[c[$+56>>2]&16383]();$=c[2443776]|0;if(($|0)!=0){z=$|0;gGC(z|0,9660952,52)|0}c[9731400+(c[3528556]<<2)>>2]=c[2113164];c[2443776]=0;c[3528556]=-1;U=0;i=b;return U|0}function aCp(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6077420+(b*112|0)>>2];c[a+104>>2]=c[6077424+(b*112|0)>>2];c[a+108>>2]=c[6077428+(b*112|0)>>2];d=0;return d|0}function aCq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<21&(d|0)==0)){e=1;return e|0}c[a>>2]=6077320+(b*112|0);e=0;return e|0}function aCr(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>36){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6079672+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aCs(){c[2433366]=2106;return aCy()|0}function aCt(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4978980+(b*112|0)>>2];c[a+104>>2]=c[4978984+(b*112|0)>>2];c[a+108>>2]=c[4978988+(b*112|0)>>2];d=0;return d|0}function aCu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<21&(d|0)==0)){e=1;return e|0}c[a>>2]=4978880+(b*112|0);e=0;return e|0}function aCv(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3513260+(b*112|0)>>2];c[a+104>>2]=c[3513264+(b*112|0)>>2];c[a+108>>2]=c[3513268+(b*112|0)>>2];d=0;return d|0}function aCw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=3513160+(b*112|0);e=0;return e|0}function aCx(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;b=i;i=i+1440|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;l=b+360|0;m=b+472|0;n=b+480|0;o=b+592|0;p=b+600|0;q=b+712|0;r=b+720|0;s=b+832|0;t=b+840|0;u=b+952|0;v=b+960|0;w=b+1072|0;x=b+1080|0;y=b+1192|0;z=b+1200|0;A=b+1312|0;B=b+1320|0;C=b+1432|0;D=0;while(1){if((D|0)>=1024){E=0;break}F=9638528+(D<<2)|0;if((c[F>>2]|0)==0){G=21741;break}else{D=D+1|0}}do{if((G|0)==21741){D=gGq(524288)|0;c[F>>2]=D;if((D|0)==0){E=0;break}gGz(D|0,0,524288);E=D}}while(0);c[3529554]=E;if((R6((c[2388040]|0)+1|0,0,2)|0)!=0){H=1;i=b;return H|0}if((R6(c[2388040]|0,1,2)|0)!=0){H=1;i=b;return H|0}if((R6((c[2388040]|0)+131073|0,2,2)|0)!=0){H=1;i=b;return H|0}if((R6((c[2388040]|0)+131072|0,3,2)|0)!=0){H=1;i=b;return H|0}E=c[3527450]|0;if((c[3542200]|0)==0){H=1;i=b;return H|0}F=B+108|0;c[F>>2]=0;D=B+100|0;c[D>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](B,4)|0;do{if((c[F>>2]|0)!=0){B=c[D>>2]|0;c[C>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](C,4,0)|0;if((B|0)<1){H=1;i=b;return H|0}if((gzL(E,0,4)|0)==0){break}else{H=1}i=b;return H|0}}while(0);E=(c[3529554]|0)+65536|0;if((c[3542200]|0)==0){H=1;i=b;return H|0}C=z+108|0;c[C>>2]=0;D=z+100|0;c[D>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,5)|0;do{if((c[C>>2]|0)!=0){z=c[D>>2]|0;c[A>>2]=9534384;F=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[F&16383](A,5,0)|0;if((z|0)<1){H=1;i=b;return H|0}if((gzL(E,0,5)|0)==0){break}else{H=1}i=b;return H|0}}while(0);E=(c[3529554]|0)+98304|0;if((c[3542200]|0)==0){H=1;i=b;return H|0}A=x+108|0;c[A>>2]=0;D=x+100|0;c[D>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,6)|0;do{if((c[A>>2]|0)!=0){x=c[D>>2]|0;c[y>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](y,6,0)|0;if((x|0)<1){H=1;i=b;return H|0}if((gzL(E,0,6)|0)==0){break}else{H=1}i=b;return H|0}}while(0);E=c[3529554]|0;y=E+16384|0;D=E+65536|0;gGC(y|0,D|0,16384)|0;D=E+81920|0;gGC(E|0,D|0,16384)|0;D=E+49152|0;y=E+98304|0;gGC(D|0,y|0,16384)|0;y=E+32768|0;D=E+114688|0;gGC(y|0,D|0,16384)|0;D=c[2406550]|0;y=0;do{A=y<<6;gGz(D+A|0,0,64);x=0;do{C=1<<3-x;z=(c[1983688+(x<<2)>>2]|0)+A|0;F=0;do{B=z+(c[1238464+(F<<2)>>2]|0)|0;I=(F<<3)+A|0;J=0;do{K=B+(c[614800+(J<<2)>>2]|0)|0;if(((d[E+((K|0)/8|0)|0]|0)&128>>>((K&7)>>>0)|0)!=0){K=D+(I+J)|0;a[K]=(d[K]|0|C)&255}J=J+1|0;}while((J|0)<8);F=F+1|0;}while((F|0)<8);x=x+1|0;}while((x|0)<4);y=y+1|0;}while((y|0)<2048);gGz(E|0,0,524288);if((c[3542200]|0)==0){H=1;i=b;return H|0}y=v+108|0;c[y>>2]=0;D=v+100|0;c[D>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,7)|0;do{if((c[y>>2]|0)!=0){v=c[D>>2]|0;c[w>>2]=9534384;x=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[x&16383](w,7,0)|0;if((v|0)<1){H=1;i=b;return H|0}if((gzL(E,0,7)|0)==0){break}else{H=1}i=b;return H|0}}while(0);E=(c[3529554]|0)+65536|0;if((c[3542200]|0)==0){H=1;i=b;return H|0}w=t+108|0;c[w>>2]=0;D=t+100|0;c[D>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,8)|0;do{if((c[w>>2]|0)!=0){t=c[D>>2]|0;c[u>>2]=9534384;y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[y&16383](u,8,0)|0;if((t|0)<1){H=1;i=b;return H|0}if((gzL(E,0,8)|0)==0){break}else{H=1}i=b;return H|0}}while(0);E=c[3529554]|0;u=c[2386350]|0;D=0;do{w=D<<8;gGz(u+w|0,0,256);t=0;do{y=1<<3-t;v=(c[611416+(t<<2)>>2]|0)+w|0;x=0;do{A=v+(c[609008+(x<<2)>>2]|0)|0;F=(x<<4)+w|0;C=0;do{z=A+(c[612640+(C<<2)>>2]|0)|0;if(((d[E+((z|0)/8|0)|0]|0)&128>>>((z&7)>>>0)|0)!=0){z=u+(F+C)|0;a[z]=(d[z]|0|y)&255}C=C+1|0;}while((C|0)<16);x=x+1|0;}while((x|0)<16);t=t+1|0;}while((t|0)<4);D=D+1|0;}while((D|0)<1024);gGz(E|0,0,524288);if((c[3542200]|0)==0){H=1;i=b;return H|0}D=r+108|0;c[D>>2]=0;u=r+100|0;c[u>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,9)|0;do{if((c[D>>2]|0)!=0){r=c[u>>2]|0;c[s>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](s,9,0)|0;if((r|0)<1){H=1;i=b;return H|0}if((gzL(E,0,9)|0)==0){break}else{H=1}i=b;return H|0}}while(0);E=(c[3529554]|0)+131072|0;if((c[3542200]|0)==0){H=1;i=b;return H|0}s=p+108|0;c[s>>2]=0;u=p+100|0;c[u>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,10)|0;do{if((c[s>>2]|0)!=0){p=c[u>>2]|0;c[q>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](q,10,0)|0;if((p|0)<1){H=1;i=b;return H|0}if((gzL(E,0,10)|0)==0){break}else{H=1}i=b;return H|0}}while(0);E=c[3529554]|0;q=c[2386348]|0;u=0;do{s=u<<8;gGz(q+s|0,0,256);p=0;do{D=1<<3-p;r=(c[1179e3+(p<<2)>>2]|0)+s|0;t=0;do{w=r+(c[609008+(t<<2)>>2]|0)|0;x=(t<<4)+s|0;y=0;do{v=w+(c[612640+(y<<2)>>2]|0)|0;if(((d[E+((v|0)/8|0)|0]|0)&128>>>((v&7)>>>0)|0)!=0){v=q+(x+y)|0;a[v]=(d[v]|0|D)&255}y=y+1|0;}while((y|0)<16);t=t+1|0;}while((t|0)<16);p=p+1|0;}while((p|0)<4);u=u+1|0;}while((u|0)<2048);gGz(E|0,0,524288);if((c[3542200]|0)==0){H=1;i=b;return H|0}u=n+108|0;c[u>>2]=0;q=n+100|0;c[q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,11)|0;do{if((c[u>>2]|0)!=0){n=c[q>>2]|0;c[o>>2]=9534384;p=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[p&16383](o,11,0)|0;if((n|0)<1){H=1;i=b;return H|0}if((gzL(E,0,11)|0)==0){break}else{H=1}i=b;return H|0}}while(0);E=(c[3529554]|0)+131072|0;if((c[3542200]|0)==0){H=1;i=b;return H|0}o=l+108|0;c[o>>2]=0;q=l+100|0;c[q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,12)|0;do{if((c[o>>2]|0)!=0){l=c[q>>2]|0;c[m>>2]=9534384;u=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[u&16383](m,12,0)|0;if((l|0)<1){H=1;i=b;return H|0}if((gzL(E,0,12)|0)==0){break}else{H=1}i=b;return H|0}}while(0);E=(c[3529554]|0)+262144|0;if((c[3542200]|0)==0){H=1;i=b;return H|0}m=j+108|0;c[m>>2]=0;q=j+100|0;c[q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,13)|0;do{if((c[m>>2]|0)!=0){j=c[q>>2]|0;c[k>>2]=9534384;o=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[o&16383](k,13,0)|0;if((j|0)<1){H=1;i=b;return H|0}if((gzL(E,0,13)|0)==0){break}else{H=1}i=b;return H|0}}while(0);E=(c[3529554]|0)+393216|0;if((c[3542200]|0)==0){H=1;i=b;return H|0}k=g+108|0;c[k>>2]=0;q=g+100|0;c[q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,14)|0;do{if((c[k>>2]|0)!=0){g=c[q>>2]|0;c[h>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](h,14,0)|0;if((g|0)<1){H=1;i=b;return H|0}if((gzL(E,0,14)|0)==0){break}else{H=1}i=b;return H|0}}while(0);E=c[3529554]|0;h=c[3529604]|0;q=0;do{k=q<<8;gGz(h+k|0,0,256);g=0;do{m=1<<3-g;j=(c[961536+(g<<2)>>2]|0)+k|0;o=0;do{l=j+(c[609008+(o<<2)>>2]|0)|0;u=(o<<4)+k|0;n=0;do{p=l+(c[612640+(n<<2)>>2]|0)|0;if(((d[E+((p|0)/8|0)|0]|0)&128>>>((p&7)>>>0)|0)!=0){p=h+(u+n)|0;a[p]=(d[p]|0|m)&255}n=n+1|0;}while((n|0)<16);o=o+1|0;}while((o|0)<16);g=g+1|0;}while((g|0)<4);q=q+1|0;}while((q|0)<4096);q=c[3541206]|0;if((c[3542200]|0)==0){H=1;i=b;return H|0}h=e+108|0;c[h>>2]=0;E=e+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,15)|0;do{if((c[h>>2]|0)!=0){e=c[E>>2]|0;c[f>>2]=9534384;g=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[g&16383](f,15,0)|0;if((e|0)<1){H=1;i=b;return H|0}if((gzL(q,0,15)|0)==0){break}else{H=1}i=b;return H|0}}while(0);q=c[3529554]|0;f=0;while(1){if((f|0)>=1024){break}L=9638528+(f<<2)|0;if((c[L>>2]|0)==(q|0)){G=21838;break}else{f=f+1|0}}if((G|0)==21838){gGr(q);c[L>>2]=0}c[3529554]=0;H=0;i=b;return H|0}function aCy(){var b=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;c[2424]=5739;c[2426664]=0;c[2388040]=0;c[3527426]=393216;c[3527450]=425984;c[3541206]=491520;c[2405602]=753664;c[2388062]=753664;c[3527434]=776192;c[3527452]=777728;c[3531060]=785920;c[2437776]=802304;c[2437774]=802312;c[2429770]=802320;c[2429768]=802448;c[2443370]=803472;c[2432708]=819856;c[2432706]=819864;c[2429330]=819872;c[2429328]=82e4;c[2443364]=821024;c[2432704]=837408;c[2432702]=837416;c[2429326]=837424;c[2429324]=837552;c[2439630]=838576;c[2438782]=840624;c[2443440]=842672;c[2429336]=844720;c[2443452]=846768;c[2411514]=854960;c[2406550]=854960;c[2386350]=1117104;c[2386348]=2165680;c[3529604]=2689968;c[3529908]=3738544;c[2438096]=3742640;c[2433516]=4266928;c[2433514]=4791216;b=0;while(1){if((b|0)>=1024){break}e=9638528+(b<<2)|0;if((c[e>>2]|0)==0){f=21885;break}else{b=b+1|0}}do{if((f|0)==21885){b=gGq(5315504)|0;c[e>>2]=b;if((b|0)==0){break}c[2426664]=b;gGz(b|0,0,5315504);c[2388040]=b;c[3527426]=b+393216;c[3527450]=b+425984;c[3541206]=b+491520;g=b+753664|0;c[2405602]=g;c[2388062]=g;c[3527434]=b+776192;c[3527452]=b+777728;c[3531060]=b+785920;c[2437776]=b+802304;c[2437774]=b+802312;c[2429770]=b+802320;c[2429768]=b+802448;c[2443370]=b+803472;c[2432708]=b+819856;c[2432706]=b+819864;c[2429330]=b+819872;c[2429328]=b+82e4;c[2443364]=b+821024;c[2432704]=b+837408;c[2432702]=b+837416;c[2429326]=b+837424;c[2429324]=b+837552;c[2439630]=b+838576;c[2438782]=b+840624;c[2443440]=b+842672;c[2429336]=b+844720;c[2443452]=b+846768;g=b+854960|0;c[2411514]=g;c[2406550]=g;c[2386350]=b+1117104;c[2386348]=b+2165680;c[3529604]=b+2689968;c[3529908]=b+3738544;c[2438096]=b+3742640;c[2433516]=b+4266928;c[2433514]=b+4791216;c[2414054]=b+5315504;if((gD[c[2433366]&8191]()|0)!=0){i=1;return i|0}b=c[3527450]|0;g=0;do{j=b+g|0;k=a[j]|0;a[j]=k&126|k<<7|(k&255)>>>7;g=g+1|0;}while((g|0)<65536);a[b+3885|0]=-22;a[b+3886|0]=-22;fxU(0,425984);if((c[2394]|0)==0){l=c[2112932]|0}else{c[2394]=0;g=c[3532596]|0;c[2112932]=g;k=c[3532592]|0;if((k|0)!=0){gGC(9104152,k|0,280)|0}c[2113054]=c[2113060];l=g}g=c[2388040]|0;k=l|0;j=0;while(1){m=g+j|0;c[k>>2]=m;c[k+131072>>2]=m;m=j+1024|0;if(m>>>0>393215){break}else{k=k+4|0;j=m}}j=c[2429326]|0;c[l+12296>>2]=j;c[l+77832>>2]=j;c[l+143368>>2]=j;j=c[2429324]|0;c[l+12300>>2]=j;c[l+77836>>2]=j;c[l+143372>>2]=j;j=c[2443364]|0;c[l+12304>>2]=j;c[l+77840>>2]=j;c[l+143376>>2]=j;k=j+1024|0;c[l+12308>>2]=k;c[l+77844>>2]=k;c[l+143380>>2]=k;k=c[2388062]|0;c[l+12352>>2]=k;c[l+77888>>2]=k;c[l+143424>>2]=k;j=k+1024|0;c[l+12356>>2]=j;c[l+77892>>2]=j;c[l+143428>>2]=j;j=k+2048|0;c[l+12360>>2]=j;c[l+77896>>2]=j;c[l+143432>>2]=j;j=k+3072|0;c[l+12364>>2]=j;c[l+77900>>2]=j;c[l+143436>>2]=j;j=k+4096|0;c[l+12368>>2]=j;c[l+77904>>2]=j;c[l+143440>>2]=j;j=k+5120|0;c[l+12372>>2]=j;c[l+77908>>2]=j;c[l+143444>>2]=j;j=k+6144|0;c[l+12376>>2]=j;c[l+77912>>2]=j;c[l+143448>>2]=j;j=k+7168|0;c[l+12380>>2]=j;c[l+77916>>2]=j;c[l+143452>>2]=j;j=k+8192|0;c[l+12384>>2]=j;c[l+77920>>2]=j;c[l+143456>>2]=j;j=k+9216|0;c[l+12388>>2]=j;c[l+77924>>2]=j;c[l+143460>>2]=j;j=k+10240|0;c[l+12392>>2]=j;c[l+77928>>2]=j;c[l+143464>>2]=j;j=k+11264|0;c[l+12396>>2]=j;c[l+77932>>2]=j;c[l+143468>>2]=j;j=k+12288|0;c[l+12400>>2]=j;c[l+77936>>2]=j;c[l+143472>>2]=j;j=k+13312|0;c[l+12404>>2]=j;c[l+77940>>2]=j;c[l+143476>>2]=j;j=k+14336|0;c[l+12408>>2]=j;c[l+77944>>2]=j;c[l+143480>>2]=j;j=k+15360|0;c[l+12412>>2]=j;c[l+77948>>2]=j;c[l+143484>>2]=j;j=c[2443440]|0;c[l+12416>>2]=j;c[l+77952>>2]=j;c[l+143488>>2]=j;k=j+1024|0;c[l+12420>>2]=k;c[l+77956>>2]=k;c[l+143492>>2]=k;k=c[2439630]|0;c[l+12544>>2]=k;c[l+78080>>2]=k;c[l+143616>>2]=k;j=k+1024|0;c[l+12548>>2]=j;c[l+78084>>2]=j;c[l+143620>>2]=j;c[l+196608>>2]=1984;c[l+196648>>2]=2810;c[l+196688>>2]=218;c[l+196728>>2]=1006;j=c[3532592]|0;if((j|0)!=0){gGC(j|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fv8();c[2388530]=9554128;j=c[2391608]|0;if((j|0)!=0){k=j;gGC(9661040,k|0,68)|0}c[2382]=0;k=c[3527450]|0;j=0;do{g=k+(j<<11)|0;c[9554144+(j<<2)>>2]=g;c[9562336+(j<<2)>>2]=g;j=j+1|0;}while(j>>>0<32);j=c[3527452]|0;c[2389528]=j;c[2390552]=j;c[2391576]=j;k=j+2048|0;c[2389529]=k;c[2390553]=k;c[2391577]=k;k=j+4096|0;c[2389530]=k;c[2390554]=k;c[2391578]=k;k=j+6144|0;c[2389531]=k;c[2390555]=k;c[2391579]=k;c[2388532]=2404;c[2388533]=1588;k=c[2391608]|0;if((k|0)!=0){j=k;gGC(j|0,9661040,68)|0}c[2382]=-1;j=c[642608+(c[2436]<<2)>>2]|0;k=c[j+128>>2]|0;if((c[j+52>>2]&4|0)==0){c[2113068]=k;g=c[j+132>>2]|0;c[2113070]=g;c[2443814]=k;c[2440436]=g;n=k;o=g}else{c[2113070]=k;g=c[j+132>>2]|0;c[2113068]=g;c[2440436]=k;c[2443814]=g;n=g;o=k}k=ag(n<<1,o)|0;g=gGq(k)|0;c[2112926]=g;if((g|0)!=0){gGz(g|0,0,k|0)}UL(3e6,646,210,1);c[2438224]=2e6;c[2433522]=3406;c[2406672]=2246;c[3528468]=11080;c[2443842]=1023;h[745398]=.8;a[3203264]=1;Vr(1,15e5,0,2452,38,0);c[2438228]=1e7;c[2433526]=3248;c[2406676]=148;c[3528472]=444;c[2443846]=203;h[745419]=.35;a[3203368]=1;h[745418]=.9;a[3203360]=1;h[745417]=.9;a[3203352]=1;h[745416]=.9;a[3203344]=1;Ux(0,7575,1);c[2407030]=205;c[2407068]=3;c[2433476]=3562;c[2429336]=c[2443440];if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];k=c[3532592]|0;if((k|0)!=0){gGC(9104152,k|0,280)|0}c[2113054]=c[2113060]}RI();k=c[2394]|0;g=c[14130368+(k<<2)>>2]|0;if((g|0)!=0){gGC(g|0,9104152,280)|0}c[8452240+(k<<2)>>2]=c[2113054];c[2394]=-1;c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;lw(c[3540984]|0);c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){k=0;do{lN(k);mB(k);k=k+1|0;}while((k|0)<(c[2385508]|0))}c[2113156]=0;a[9628264]=0;c[2407033]=0;k=c[3541206]|0;c[3541190]=k;c[3541198]=k;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=k+256;c[3541199]=k+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=k+512;c[3541200]=k+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=k+768;c[3541201]=k+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2444194]=0;a[9545184]=0;a[9758144]=0;a[9759752]=0;c[3527346]=0;gGz(9754968,0,3);a[9718113]=11;a[9718112]=11;c[2388530]=9554128;k=c[2391608]|0;if((k|0)!=0){g=k;gGC(9661040,g|0,68)|0}c[2382]=0;g=c[2415273]|0;gGz(9661040,0,68);c[2415273]=g;a[9661063]=20;c[2415262]=511;g=c[2388539]|0;do{if((g|0)==0){k=c[2388532]|0;if((k|0)==0){p=0;q=8191;r=9554128;break}j=gj[k&4095](8190)|0;p=j;q=(d[9661071]|0)<<13|8191;r=c[2388530]|0}else{p=a[g+2046|0]|0;q=8191;r=9554128}}while(0);a[9661044]=p;g=c[r+16+(q>>>11<<2)>>2]|0;do{if((g|0)==0){j=c[r>>2]|0;if((j|0)==0){s=0;t=r;break}k=gj[j&4095](q)|0;s=k;t=c[2388530]|0}else{s=a[g+2047|0]|0;t=r}}while(0);a[9661045]=s;a[9661075]=4;a[9661073]=0;c[2415270]=131072;c[2415275]=0;gGz(9661084,0,5);g=c[t+12304>>2]|0;if((g|0)!=0){k=g;gGC(k|0,9661040,68)|0}c[2382]=-1;i=0;return i|0}}while(0);c[2426664]=0;i=1;return i|0}function aCz(b,c){b=b|0;c=c|0;b=a[9661086]|0;if((c|0)==0){if(b<<24>>24==0){return}a[9661086]=0;if((a[9661088]|0)!=0){return}a[9661088]=2;return}else{if(b<<24>>24==1){return}a[9661086]=1;if((a[9661088]|0)!=0){return}a[9661088]=2;return}}function aCA(a){a=a|0;var b=0,d=0;b=c[2415275]|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,2e6,0)|0;return a|0}function aCB(a){a=a|0;var b=0,d=0;b=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,1e7,0)|0;return a|0}function aCC(){return+(+((c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0)/1.0e7)}function aCD(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;a[9759752]=b[c[2437776]>>1]&255&-128;d=c[2112926]|0;gGz(d|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);d=c[2439630]|0;e=c[3529908]|0;f=0;do{g=b[d+(f<<1)>>1]|0;h=g&255;i=(g&65535)>>>4;j=(g&65535)>>>8;c[e+(f<<2)>>2]=((j<<4&255|j&8)&255)>>>3|((h<<4|h&8)&255)<<8&63488|((i<<4&255|i&12)&255)<<3&2016;f=f+1|0;}while((f|0)<1024);aCE(1,2);aCF(0,2);aCG(0,0);if((c[3527346]&128|0)==0){aCH();R8(e);return}aCF(0,1);aCH();R8(e);return}function aCE(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;f=c[2432704]|0;g=c[2443364]|0;h=b[f+6>>1]&3;do{if((h|0)==0){c[2429516]=1024;c[2429332]=256;i=2048;j=256;k=1024;l=21963}else if((h|0)==2){c[2429516]=256;c[2429332]=1024;i=512;j=1024;k=256;l=21963}else if((h|0)==1){c[2429516]=512;c[2429332]=512;i=1024;j=512;k=512;l=21963}else{m=c[2429516]|0;n=c[2429332]|0;o=c[2433514]|0;gGz(o|0,0,ag(m<<1,n)|0);if((n|0)>15){p=m;q=n;r=o;break}else{s=n;t=m;u=o}v=f;w=c[2432702]|0;x=w;y=c[2429324]|0;z=y;A=c[2429326]|0;B=A;C=b[v>>1]|0;aCI(u,C,x,z,B,t,s,d,e);return}}while(0);if((l|0)==21963){o=c[2433514]|0;gGz(o|0,0,ag(i,j)|0);p=k;q=j;r=o}o=(e|0)==2;j=(d|0)==0;k=q-1|0;i=c[2386348]|0;m=(p|0)/16|0;n=0;D=p;E=q;while(1){if((D|0)>15){F=n<<4;G=F&240;H=F&256;I=F&1008;J=k&240-F;K=0;L=D;while(1){M=K&15;N=M|G;O=K<<4;if((h|0)==2){P=M|I}else if((h|0)==1){P=N|H|K<<5&512}else{P=N|O&768}N=b[g+(((a[9754970]&1)==0?P:P+4096|0)<<1)>>1]|0;M=N&65535;Q=M&4095;R=M>>>12;if(o){l=21974}else{if(((N&65535)>>>15&65535|0)==(e|0)){l=21974}}do{if((l|0)==21974){l=0;N=(a[9759752]|0)!=0;if(j){if(N){aCL(r,Q,240-O&L-1,J,R,768,i,L);break}else{aCM(r,Q,O,F,R,768,i,L);break}}else{if(N){aCJ(r,Q,240-O&L-1,J,R,768,i,L);break}else{aCK(r,Q,O,F,R,768,i,L);break}}}}while(0);R=K+1|0;if((R|0)<(m|0)){K=R;L=p}else{S=p;T=q;break}}}else{S=D;T=E}L=n+1|0;if((L|0)<((T|0)/16|0|0)){n=L;D=S;E=T}else{s=T;t=S;u=r;break}}v=f;w=c[2432702]|0;x=w;y=c[2429324]|0;z=y;A=c[2429326]|0;B=A;C=b[v>>1]|0;aCI(u,C,x,z,B,t,s,d,e);return}function aCF(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;f=c[2432708]|0;g=c[2443370]|0;h=b[f+6>>1]&3;do{if((h|0)==0){c[2429518]=1024;c[2429334]=256;i=2048;j=256;k=1024;l=21990}else if((h|0)==2){c[2429518]=256;c[2429334]=1024;i=512;j=1024;k=256;l=21990}else if((h|0)==1){c[2429518]=512;c[2429334]=512;i=1024;j=512;k=512;l=21990}else{m=c[2429518]|0;n=c[2429334]|0;o=c[2433516]|0;gGz(o|0,0,ag(m<<1,n)|0);if((n|0)>15){p=m;q=n;r=o;break}else{s=n;t=m;u=o}v=f;w=c[2432706]|0;x=w;y=c[2429328]|0;z=y;A=c[2429330]|0;B=A;C=b[v>>1]|0;aCI(u,C,x,z,B,t,s,d,e);return}}while(0);if((l|0)==21990){o=c[2433516]|0;gGz(o|0,0,ag(i,j)|0);p=k;q=j;r=o}o=(e|0)==2;j=(d|0)==0;k=q-1|0;i=c[2386350]|0;m=(p|0)/16|0;n=0;D=p;E=q;while(1){if((D|0)>15){F=n<<4;G=F&240;H=F&256;I=F&1008;J=k&240-F;K=0;L=D;while(1){M=K&15;N=M|G;O=K<<4;if((h|0)==1){P=N|H|K<<5&512}else if((h|0)==2){P=M|I}else{P=N|O&768}N=b[g+(((a[9754969]&1)==0?P:P+4096|0)<<1)>>1]|0;M=N&65535;Q=M&4095;R=M>>>12;if(o){l=22001}else{if(((N&65535)>>>15&65535|0)==(e|0)){l=22001}}do{if((l|0)==22001){l=0;N=(a[9759752]|0)!=0;if(j){if(N){aCL(r,Q,240-O&L-1,J,R,512,i,L);break}else{aCM(r,Q,O,F,R,512,i,L);break}}else{if(N){aCJ(r,Q,240-O&L-1,J,R,512,i,L);break}else{aCK(r,Q,O,F,R,512,i,L);break}}}}while(0);R=K+1|0;if((R|0)<(m|0)){K=R;L=p}else{S=p;T=q;break}}}else{S=D;T=E}L=n+1|0;if((L|0)<((T|0)/16|0|0)){n=L;D=S;E=T}else{s=T;t=S;u=r;break}}v=f;w=c[2432706]|0;x=w;y=c[2429328]|0;z=y;A=c[2429330]|0;B=A;C=b[v>>1]|0;aCI(u,C,x,z,B,t,s,d,e);return}function aCG(b,d){b=b|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;f=c[2429336]|0;g=c[2112926]|0;h=a[986968]|0?0:256;i=c[3529604]|0;j=(c[2113222]&1|0)==0;k=0;do{l=e[f+(k<<1)>>1]|0;do{if((l&32768|0)!=0){m=e[f+((k|2)<<1)>>1]|0;n=m>>>12;if((n&b|0)!=(d|0)){break}if(!((m&2048|0)==0|j)){break}o=l&8192;p=l&16384;q=1<<(l>>>11&3);r=q-1|0;s=m&511;t=l&511;u=s>>>0>255?m|-512:s;s=t>>>0>255?l|-512:t;t=(-q&4095&e[f+((k|1)<<1)>>1])+((p|0)==0?r:0)|0;m=(p>>>13^2)-1|0;if((a[9759752]|0)==0){v=240-u|0;w=-16;x=240-s|0;y=p;z=o}else{v=u;w=16;x=s;y=p>>>14^1;z=o>>>13^1}if((q|0)<=0){break}q=x-8|0;o=(v|0)>16;p=(z|0)==0;s=(y|0)!=0;u=r;while(1){r=q+(ag(u,w)|0)|0;A=t-(ag(u,m)|0)|0;do{if(o){if(!((v|0)<((c[2113068]|0)-16|0)&(r|0)>16)){B=22031;break}if((r|0)>=((c[2113070]|0)-16|0)){B=22031;break}if(p){if(s){SK(g,A,v,r,n,4,0,h,i);break}else{SG(g,A,v,r,n,4,0,h,i);break}}else{if(s){SM(g,A,v,r,n,4,0,h,i);break}else{SI(g,A,v,r,n,4,0,h,i);break}}}else{B=22031}}while(0);do{if((B|0)==22031){B=0;if(p){if(s){SL(g,A,v,r,n,4,0,h,i);break}else{SH(g,A,v,r,n,4,0,h,i);break}}else{if(s){SN(g,A,v,r,n,4,0,h,i);break}else{SJ(g,A,v,r,n,4,0,h,i);break}}}}while(0);if((u|0)>0){u=u-1|0}else{break}}}}while(0);k=k+4|0;}while(k>>>0<1024);return}function aCH(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;d=c[2437776]|0;f=c[3531060]|0;g=b[d+6>>1]&3;do{if((g|0)==0){c[2429766]=1024;c[2429530]=256;h=2048;i=256;j=1024;k=22045}else if((g|0)==2){c[2429766]=256;c[2429530]=1024;h=512;i=1024;j=256;k=22045}else if((g|0)==1){c[2429766]=512;c[2429530]=512;h=1024;i=512;j=512;k=22045}else{l=c[2429766]|0;m=c[2429530]|0;n=c[2438096]|0;gGz(n|0,0,ag(l<<1,m)|0);if((m|0)>7){o=l;p=m;q=n;break}else{r=m;s=l;t=n}u=d;v=c[2437774]|0;w=v;x=c[2429768]|0;y=x;z=c[2429770]|0;A=z;B=b[u>>1]|0;aCI(t,B,w,y,A,s,r,0,2);return}}while(0);if((k|0)==22045){k=c[2438096]|0;gGz(k|0,0,ag(h,i)|0);o=j;p=i;q=k}k=a[1950800]|0?256:0;i=c[2406550]|0;j=(o|0)/8|0;h=p-1|0;n=0;l=o;m=p;while(1){if((l|0)>7){C=n<<5;D=C&992;E=n<<3;F=C&1024;G=C&4064;C=h&248-E|7;H=0;I=l;while(1){J=H&31;K=J|D;if((g|0)==1){L=K|F|H<<6&2048}else if((g|0)==2){L=J|G}else{L=K|H<<5&3072}K=e[f+(((a[9754968]&1)==0?L:L+4096|0)<<1)>>1]|0;J=K&4095;M=K>>>12;K=H<<3;if((a[9759752]|0)==0){N=i+(J<<6)|0;c[2112928]=N;O=k|M<<4;P=q+(K+(ag(I,E)|0)<<1)|0;Q=0;R=N;while(1){N=a[R]|0;if(N<<24>>24!=0){b[P>>1]=(N&255|O)&65535}N=a[R+1|0]|0;if(N<<24>>24!=0){b[P+2>>1]=(N&255|O)&65535}N=a[R+2|0]|0;if(N<<24>>24!=0){b[P+4>>1]=(N&255|O)&65535}N=a[R+3|0]|0;if(N<<24>>24!=0){b[P+6>>1]=(N&255|O)&65535}N=a[R+4|0]|0;if(N<<24>>24!=0){b[P+8>>1]=(N&255|O)&65535}N=a[R+5|0]|0;if(N<<24>>24!=0){b[P+10>>1]=(N&255|O)&65535}N=a[R+6|0]|0;if(N<<24>>24!=0){b[P+12>>1]=(N&255|O)&65535}N=a[R+7|0]|0;if(N<<24>>24!=0){b[P+14>>1]=(N&255|O)&65535}N=Q+1|0;S=R+8|0;if((N|0)<8){P=P+(I<<1)|0;Q=N;R=S}else{T=S;break}}}else{R=i+(J<<6)|0;c[2112928]=R;Q=-I|0;P=k|M<<4;O=q+((ag(C,I)|0)+(248-K&I-1)<<1)|0;S=7;N=R;while(1){R=a[N]|0;if(R<<24>>24!=0){b[O+14>>1]=(R&255|P)&65535}R=a[N+1|0]|0;if(R<<24>>24!=0){b[O+12>>1]=(R&255|P)&65535}R=a[N+2|0]|0;if(R<<24>>24!=0){b[O+10>>1]=(R&255|P)&65535}R=a[N+3|0]|0;if(R<<24>>24!=0){b[O+8>>1]=(R&255|P)&65535}R=a[N+4|0]|0;if(R<<24>>24!=0){b[O+6>>1]=(R&255|P)&65535}R=a[N+5|0]|0;if(R<<24>>24!=0){b[O+4>>1]=(R&255|P)&65535}R=a[N+6|0]|0;if(R<<24>>24!=0){b[O+2>>1]=(R&255|P)&65535}R=a[N+7|0]|0;if(R<<24>>24!=0){b[O>>1]=(R&255|P)&65535}R=N+8|0;if((S|0)>0){O=O+(Q<<1)|0;S=S-1|0;N=R}else{T=R;break}}}c[2112928]=T;N=H+1|0;if((N|0)<(j|0)){H=N;I=o}else{U=o;V=p;break}}}else{U=l;V=m}I=n+1|0;if((I|0)<((V|0)/8|0|0)){n=I;l=U;m=V}else{r=V;s=U;t=q;break}}u=d;v=c[2437774]|0;w=v;x=c[2429768]|0;y=x;z=c[2429770]|0;A=z;B=b[u>>1]|0;aCI(t,B,w,y,A,s,r,0,2);return}function aCI(d,f,g,h,i,j,k,l,m){d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;n=e[g>>1]|0;o=j-1|0;p=k-1|0;k=f&65535;f=c[2113070]|0;if((f|0)<=0){return}q=(k&4|0)==0;r=(a[9759752]|0)==0;s=(k&8|0)==0;k=(l|0)==0;l=(m|0)==1;m=g+4|0;t=g+6|0;u=c[2113068]|0;v=(u|0)>0;w=c[2112926]|0;x=0;y=(e[g+2>>1]|0)+8|0;g=0;while(1){if(q){z=n}else{A=b[t>>1]&15;z=(e[h+((y>>A&511>>>(A>>>0))<<1)>>1]|0)+n|0}A=z&o;B=r?A:-A|0;L28144:do{if(v){if(s){A=ag(x+y&p,j)|0;C=B;D=0;while(1){E=b[d+((C&o)+A<<1)>>1]|0;F=E&65535;G=C+1|0;if(k){if((F&15|0)!=0){H=22106}}else{H=22106}do{if((H|0)==22106){H=0;if(!l){b[w+((ag(u,g)|0)+D<<1)>>1]=E;break}if((F&136|0)!=136){break}b[w+((ag(u,g)|0)+D<<1)>>1]=E}}while(0);E=D+1|0;if((E|0)<(u|0)){C=G;D=E}else{I=x;break L28144}}}if(k){J=B;K=0}else{D=B;C=0;while(1){A=b[m>>1]&15;E=e[i+((D>>3>>A&63>>>(A>>>0))<<1)>>1]|0;A=b[d+((ag(E+y&p,j)|0)+(D&o)<<1)>>1]|0;F=D+1|0;do{if(l){if((A&136)!=136){break}b[w+((ag(u,g)|0)+C<<1)>>1]=A}else{b[w+((ag(u,g)|0)+C<<1)>>1]=A}}while(0);A=C+1|0;if((A|0)<(u|0)){D=F;C=A}else{I=E;break L28144}}}while(1){C=b[m>>1]&15;D=e[i+((J>>3>>C&63>>>(C>>>0))<<1)>>1]|0;C=b[d+((ag(D+y&p,j)|0)+(J&o)<<1)>>1]|0;A=C&65535;G=J+1|0;do{if((A&15|0)!=0){if(!l){b[w+((ag(u,g)|0)+K<<1)>>1]=C;break}if((A&136|0)!=136){break}b[w+((ag(u,g)|0)+K<<1)>>1]=C}}while(0);C=K+1|0;if((C|0)<(u|0)){J=G;K=C}else{I=D;break}}}else{I=x}}while(0);B=g+1|0;if((B|0)<(f|0)){x=I;y=y+1|0;g=B}else{break}}return}function aCJ(a,e,f,g,h,i,j,k){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0;l=j+(e<<8)|0;c[2112928]=l;e=h<<4|i;i=-k|0;h=a+((ag(g+15|0,k)|0)+f<<1)|0;f=15;k=l;while(1){b[h+30>>1]=(d[k]|0|e)&65535;b[h+28>>1]=(d[k+1|0]|0|e)&65535;b[h+26>>1]=(d[k+2|0]|0|e)&65535;b[h+24>>1]=(d[k+3|0]|0|e)&65535;b[h+22>>1]=(d[k+4|0]|0|e)&65535;b[h+20>>1]=(d[k+5|0]|0|e)&65535;b[h+18>>1]=(d[k+6|0]|0|e)&65535;b[h+16>>1]=(d[k+7|0]|0|e)&65535;b[h+14>>1]=(d[k+8|0]|0|e)&65535;b[h+12>>1]=(d[k+9|0]|0|e)&65535;b[h+10>>1]=(d[k+10|0]|0|e)&65535;b[h+8>>1]=(d[k+11|0]|0|e)&65535;b[h+6>>1]=(d[k+12|0]|0|e)&65535;b[h+4>>1]=(d[k+13|0]|0|e)&65535;b[h+2>>1]=(d[k+14|0]|0|e)&65535;b[h>>1]=(d[k+15|0]|0|e)&65535;m=k+16|0;if((f|0)>0){h=h+(i<<1)|0;f=f-1|0;k=m}else{break}}c[2112928]=m;return}function aCK(a,e,f,g,h,i,j,k){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0;l=j+(e<<8)|0;c[2112928]=l;e=h<<4|i;i=a+((ag(k,g)|0)+f<<1)|0;f=0;g=l;while(1){b[i>>1]=(d[g]|0|e)&65535;b[i+2>>1]=(d[g+1|0]|0|e)&65535;b[i+4>>1]=(d[g+2|0]|0|e)&65535;b[i+6>>1]=(d[g+3|0]|0|e)&65535;b[i+8>>1]=(d[g+4|0]|0|e)&65535;b[i+10>>1]=(d[g+5|0]|0|e)&65535;b[i+12>>1]=(d[g+6|0]|0|e)&65535;b[i+14>>1]=(d[g+7|0]|0|e)&65535;b[i+16>>1]=(d[g+8|0]|0|e)&65535;b[i+18>>1]=(d[g+9|0]|0|e)&65535;b[i+20>>1]=(d[g+10|0]|0|e)&65535;b[i+22>>1]=(d[g+11|0]|0|e)&65535;b[i+24>>1]=(d[g+12|0]|0|e)&65535;b[i+26>>1]=(d[g+13|0]|0|e)&65535;b[i+28>>1]=(d[g+14|0]|0|e)&65535;b[i+30>>1]=(d[g+15|0]|0|e)&65535;l=f+1|0;m=g+16|0;if((l|0)<16){i=i+(k<<1)|0;f=l;g=m}else{break}}c[2112928]=m;return}function aCL(d,e,f,g,h,i,j,k){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0;l=j+(e<<8)|0;c[2112928]=l;e=-k|0;j=h<<4|i;i=d+((ag(g+15|0,k)|0)+f<<1)|0;f=15;k=l;while(1){l=a[k]|0;if(l<<24>>24!=0){b[i+30>>1]=(l&255|j)&65535}l=a[k+1|0]|0;if(l<<24>>24!=0){b[i+28>>1]=(l&255|j)&65535}l=a[k+2|0]|0;if(l<<24>>24!=0){b[i+26>>1]=(l&255|j)&65535}l=a[k+3|0]|0;if(l<<24>>24!=0){b[i+24>>1]=(l&255|j)&65535}l=a[k+4|0]|0;if(l<<24>>24!=0){b[i+22>>1]=(l&255|j)&65535}l=a[k+5|0]|0;if(l<<24>>24!=0){b[i+20>>1]=(l&255|j)&65535}l=a[k+6|0]|0;if(l<<24>>24!=0){b[i+18>>1]=(l&255|j)&65535}l=a[k+7|0]|0;if(l<<24>>24!=0){b[i+16>>1]=(l&255|j)&65535}l=a[k+8|0]|0;if(l<<24>>24!=0){b[i+14>>1]=(l&255|j)&65535}l=a[k+9|0]|0;if(l<<24>>24!=0){b[i+12>>1]=(l&255|j)&65535}l=a[k+10|0]|0;if(l<<24>>24!=0){b[i+10>>1]=(l&255|j)&65535}l=a[k+11|0]|0;if(l<<24>>24!=0){b[i+8>>1]=(l&255|j)&65535}l=a[k+12|0]|0;if(l<<24>>24!=0){b[i+6>>1]=(l&255|j)&65535}l=a[k+13|0]|0;if(l<<24>>24!=0){b[i+4>>1]=(l&255|j)&65535}l=a[k+14|0]|0;if(l<<24>>24!=0){b[i+2>>1]=(l&255|j)&65535}l=a[k+15|0]|0;if(l<<24>>24!=0){b[i>>1]=(l&255|j)&65535}m=k+16|0;if((f|0)>0){i=i+(e<<1)|0;f=f-1|0;k=m}else{break}}c[2112928]=m;return}function aCM(d,e,f,g,h,i,j,k){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0;l=j+(e<<8)|0;c[2112928]=l;e=h<<4|i;i=d+((ag(k,g)|0)+f<<1)|0;f=0;g=l;while(1){l=a[g]|0;if(l<<24>>24!=0){b[i>>1]=(l&255|e)&65535}l=a[g+1|0]|0;if(l<<24>>24!=0){b[i+2>>1]=(l&255|e)&65535}l=a[g+2|0]|0;if(l<<24>>24!=0){b[i+4>>1]=(l&255|e)&65535}l=a[g+3|0]|0;if(l<<24>>24!=0){b[i+6>>1]=(l&255|e)&65535}l=a[g+4|0]|0;if(l<<24>>24!=0){b[i+8>>1]=(l&255|e)&65535}l=a[g+5|0]|0;if(l<<24>>24!=0){b[i+10>>1]=(l&255|e)&65535}l=a[g+6|0]|0;if(l<<24>>24!=0){b[i+12>>1]=(l&255|e)&65535}l=a[g+7|0]|0;if(l<<24>>24!=0){b[i+14>>1]=(l&255|e)&65535}l=a[g+8|0]|0;if(l<<24>>24!=0){b[i+16>>1]=(l&255|e)&65535}l=a[g+9|0]|0;if(l<<24>>24!=0){b[i+18>>1]=(l&255|e)&65535}l=a[g+10|0]|0;if(l<<24>>24!=0){b[i+20>>1]=(l&255|e)&65535}l=a[g+11|0]|0;if(l<<24>>24!=0){b[i+22>>1]=(l&255|e)&65535}l=a[g+12|0]|0;if(l<<24>>24!=0){b[i+24>>1]=(l&255|e)&65535}l=a[g+13|0]|0;if(l<<24>>24!=0){b[i+26>>1]=(l&255|e)&65535}l=a[g+14|0]|0;if(l<<24>>24!=0){b[i+28>>1]=(l&255|e)&65535}l=a[g+15|0]|0;if(l<<24>>24!=0){b[i+30>>1]=(l&255|e)&65535}l=f+1|0;m=g+16|0;if((l|0)<16){i=i+(k<<1)|0;f=l;g=m}else{break}}c[2112928]=m;return}function aCN(){var b=0,d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;c[2424]=5739;c[2426664]=0;c[2388040]=0;c[3527426]=393216;c[3527450]=425984;c[3541206]=491520;c[2405602]=753664;c[2388062]=753664;c[3527434]=776192;c[3527452]=777728;c[3531060]=785920;c[2437776]=802304;c[2437774]=802312;c[2429770]=802320;c[2429768]=802448;c[2443370]=803472;c[2432708]=819856;c[2432706]=819864;c[2429330]=819872;c[2429328]=82e4;c[2443364]=821024;c[2432704]=837408;c[2432702]=837416;c[2429326]=837424;c[2429324]=837552;c[2439630]=838576;c[2438782]=840624;c[2443440]=842672;c[2429336]=844720;c[2443452]=846768;c[2411514]=854960;c[2406550]=854960;c[2386350]=1117104;c[2386348]=2165680;c[3529604]=2689968;c[3529908]=3738544;c[2438096]=3742640;c[2433516]=4266928;c[2433514]=4791216;b=0;while(1){if((b|0)>=1024){break}d=9638528+(b<<2)|0;if((c[d>>2]|0)==0){e=22205;break}else{b=b+1|0}}do{if((e|0)==22205){b=gGq(5315504)|0;c[d>>2]=b;if((b|0)==0){break}c[2426664]=b;gGz(b|0,0,5315504);c[2388040]=b;c[3527426]=b+393216;c[3527450]=b+425984;c[3541206]=b+491520;f=b+753664|0;c[2405602]=f;c[2388062]=f;c[3527434]=b+776192;c[3527452]=b+777728;c[3531060]=b+785920;c[2437776]=b+802304;c[2437774]=b+802312;c[2429770]=b+802320;c[2429768]=b+802448;c[2443370]=b+803472;c[2432708]=b+819856;c[2432706]=b+819864;c[2429330]=b+819872;c[2429328]=b+82e4;c[2443364]=b+821024;c[2432704]=b+837408;c[2432702]=b+837416;c[2429326]=b+837424;c[2429324]=b+837552;c[2439630]=b+838576;c[2438782]=b+840624;c[2443440]=b+842672;c[2429336]=b+844720;c[2443452]=b+846768;f=b+854960|0;c[2411514]=f;c[2406550]=f;c[2386350]=b+1117104;c[2386348]=b+2165680;c[3529604]=b+2689968;c[3529908]=b+3738544;c[2438096]=b+3742640;c[2433516]=b+4266928;c[2433514]=b+4791216;c[2414054]=b+5315504;b=0;while(1){if((b|0)>=1024){g=0;break}i=9638528+(b<<2)|0;if((c[i>>2]|0)==0){e=22210;break}else{b=b+1|0}}do{if((e|0)==22210){b=gGq(524288)|0;c[i>>2]=b;if((b|0)==0){g=0;break}gGz(b|0,0,524288);g=b}}while(0);c[3529554]=g;fxU(0,425984);if((c[2394]|0)==0){j=c[2112932]|0}else{c[2394]=0;b=c[3532596]|0;c[2112932]=b;f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];j=b}b=c[2388040]|0;f=j|0;k=0;while(1){l=b+k|0;c[f>>2]=l;c[f+131072>>2]=l;l=k+1024|0;if(l>>>0>393215){break}else{f=f+4|0;k=l}}k=c[2429770]|0;c[j+9248>>2]=k;c[j+74784>>2]=k;c[j+140320>>2]=k;k=c[2429768]|0;c[j+9252>>2]=k;c[j+74788>>2]=k;c[j+140324>>2]=k;k=c[2388062]|0;f=k+16384|0;c[j+9256>>2]=f;c[j+74792>>2]=f;c[j+140328>>2]=f;f=k+17408|0;c[j+9260>>2]=f;c[j+74796>>2]=f;c[j+140332>>2]=f;f=k+18432|0;c[j+9264>>2]=f;c[j+74800>>2]=f;c[j+140336>>2]=f;f=k+19456|0;c[j+9268>>2]=f;c[j+74804>>2]=f;c[j+140340>>2]=f;f=k+20480|0;c[j+9272>>2]=f;c[j+74808>>2]=f;c[j+140344>>2]=f;f=k+21504|0;c[j+9276>>2]=f;c[j+74812>>2]=f;c[j+140348>>2]=f;f=c[2429330]|0;c[j+9344>>2]=f;c[j+74880>>2]=f;c[j+140416>>2]=f;f=c[2429328]|0;c[j+9348>>2]=f;c[j+74884>>2]=f;c[j+140420>>2]=f;f=c[2429326]|0;c[j+9416>>2]=f;c[j+74952>>2]=f;c[j+140488>>2]=f;f=c[2429324]|0;c[j+9420>>2]=f;c[j+74956>>2]=f;c[j+140492>>2]=f;f=c[2439630]|0;c[j+12544>>2]=f;c[j+78080>>2]=f;c[j+143616>>2]=f;b=f+1024|0;c[j+12548>>2]=b;c[j+78084>>2]=b;c[j+143620>>2]=b;b=c[2438782]|0;c[j+12608>>2]=b;c[j+78144>>2]=b;c[j+143680>>2]=b;f=b+1024|0;c[j+12612>>2]=f;c[j+78148>>2]=f;c[j+143684>>2]=f;c[j+65408>>2]=k;c[j+130944>>2]=k;c[j+196480>>2]=k;f=k+1024|0;c[j+65412>>2]=f;c[j+130948>>2]=f;c[j+196484>>2]=f;f=k+2048|0;c[j+65416>>2]=f;c[j+130952>>2]=f;c[j+196488>>2]=f;f=k+3072|0;c[j+65420>>2]=f;c[j+130956>>2]=f;c[j+196492>>2]=f;f=k+4096|0;c[j+65424>>2]=f;c[j+130960>>2]=f;c[j+196496>>2]=f;f=k+5120|0;c[j+65428>>2]=f;c[j+130964>>2]=f;c[j+196500>>2]=f;f=k+6144|0;c[j+65432>>2]=f;c[j+130968>>2]=f;c[j+196504>>2]=f;f=k+7168|0;c[j+65436>>2]=f;c[j+130972>>2]=f;c[j+196508>>2]=f;f=k+8192|0;c[j+65440>>2]=f;c[j+130976>>2]=f;c[j+196512>>2]=f;f=k+9216|0;c[j+65444>>2]=f;c[j+130980>>2]=f;c[j+196516>>2]=f;f=k+10240|0;c[j+65448>>2]=f;c[j+130984>>2]=f;c[j+196520>>2]=f;f=k+11264|0;c[j+65452>>2]=f;c[j+130988>>2]=f;c[j+196524>>2]=f;f=k+12288|0;c[j+65456>>2]=f;c[j+130992>>2]=f;c[j+196528>>2]=f;f=k+13312|0;c[j+65460>>2]=f;c[j+130996>>2]=f;c[j+196532>>2]=f;f=k+14336|0;c[j+65464>>2]=f;c[j+131e3>>2]=f;c[j+196536>>2]=f;f=k+15360|0;c[j+65468>>2]=f;c[j+131004>>2]=f;c[j+196540>>2]=f;f=c[2443440]|0;c[j+65472>>2]=f;c[j+131008>>2]=f;c[j+196544>>2]=f;k=f+1024|0;c[j+65476>>2]=k;c[j+131012>>2]=k;c[j+196548>>2]=k;c[j+196608>>2]=462;c[j+196648>>2]=398;c[j+196688>>2]=966;c[j+196728>>2]=94;k=c[3532592]|0;if((k|0)!=0){gGC(k|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fvI();c[3528556]=0;k=c[2433594]|0;c[2443776]=k;L28318:do{if((k|0)!=0){f=k|0;gGC(9660952,f|0,52)|0;switch(a[9660952]|0){case 3:{c[2309668]=639984;break L28318;break};case 0:{c[2309668]=638960;break L28318;break};case 1:{c[2309668]=634096;break L28318;break};case 4:{c[2309668]=7356016;break L28318;break};case 2:{c[2309668]=638960;break L28318;break};case 5:{c[2309668]=7354992;break L28318;break};default:{break L28318}}}}while(0);f=c[2432850]|0;c[2113164]=f;b=c[3527434]|0;c[k+68>>2]=b;c[k+1092>>2]=b;c[k+2116>>2]=b;l=b+256|0;c[k+72>>2]=l;c[k+1096>>2]=l;c[k+2120>>2]=l;l=b+512|0;c[k+76>>2]=l;c[k+1100>>2]=l;c[k+2124>>2]=l;l=b+768|0;c[k+80>>2]=l;c[k+1104>>2]=l;c[k+2128>>2]=l;l=b+1024|0;c[k+84>>2]=l;c[k+1108>>2]=l;c[k+2132>>2]=l;l=b+1280|0;c[k+88>>2]=l;c[k+1112>>2]=l;c[k+2136>>2]=l;l=c[3527426]|0;b=128;m=128;while(1){n=l+((m<<8)-32768)|0;c[k+68+(m<<2)>>2]=n;c[k+68+(m+512<<2)>>2]=n;n=b+1&65535;if((n&65535)>255){break}else{b=n;m=n&65535}}c[k+3148>>2]=3578;c[k+3152>>2]=2458;m=k|0;gGC(m|0,9660952,52)|0;c[2432850]=f;c[2443776]=0;c[3528556]=-1;m=c[642608+(c[2436]<<2)>>2]|0;b=c[m+128>>2]|0;if((c[m+52>>2]&4|0)==0){c[2113068]=b;l=c[m+132>>2]|0;c[2113070]=l;c[2443814]=b;c[2440436]=l;o=b;p=l}else{c[2113070]=b;l=c[m+132>>2]|0;c[2113068]=l;c[2440436]=b;c[2443814]=l;o=l;p=b}b=ag(o<<1,p)|0;l=gGq(b)|0;c[2112926]=l;if((l|0)!=0){gGz(l|0,0,b|0)}UL(3e6,2084,1606,1);c[2438224]=15e5;c[2433522]=3258;c[2406672]=2016;c[3528468]=6844;c[2443842]=1364;h[745398]=.8;a[3203264]=1;Vr(1,15e5,0,2452,38,0);c[2438228]=1e7;c[2433526]=3248;c[2406676]=148;c[3528472]=444;c[2443846]=203;h[745419]=.35;a[3203368]=1;h[745418]=.9;a[3203360]=1;h[745417]=.9;a[3203352]=1;h[745416]=.9;a[3203344]=1;Ux(0,7757,1);c[2407030]=205;c[2407068]=3;return}}while(0);c[2426664]=0;return}function aCO(){var d=0,f=0,g=0,h=0,i=0,j=0;a[9759752]=b[c[2437776]>>1]&255&-128;d=c[3527346]|0;f=c[2112926]|0;gGz(f|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);f=c[2439630]|0;g=c[2438782]|0;h=c[3529908]|0;i=0;do{j=e[f+(i<<1)>>1]|0;c[h+(i<<2)>>2]=j>>>8<<3&2016|j<<8&63488|(e[g+(i<<1)>>1]|0)>>>3&31;i=i+1|0;}while((i|0)<1024);i=d<<1&8;if((c[3527346]&1|0)==0){aCE(1,2);if((c[3527346]&2|0)!=0){aCG(8,i)}aCF(0,2)}else{aCF(0,0);if((c[3527346]&2|0)!=0){aCG(8,i)}aCE(1,2)}if((c[3527346]&2|0)==0){aCG(0,0);aCH();R8(h);return}else{aCG(8,i^8);aCH();R8(h);return}}function aCP(a,b){a=a|0;b=b|0;a=c[(c[2443776]|0)+64>>2]|0;if((b|0)==0){gg[a&4095](0,0);return}else{gg[a&4095](0,1);return}}function aCQ(a){a=a|0;var b=0,d=0;b=c[2113164]|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,15e5,0)|0;return a|0}function aCR(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;a[9759752]=b[c[2437776]>>1]&255&-128;d=c[3527346]<<1;e=c[2112926]|0;gGz(e|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);e=c[2439630]|0;f=c[3529908]|0;g=0;do{h=b[e+(g<<1)>>1]|0;i=h&255;j=(h&65535)>>>4;k=(h&65535)>>>8;c[f+(g<<2)>>2]=((k<<4&255|k&8)&255)>>>3|((i<<4|i&8)&255)<<8&63488|((j<<4&255|j&12)&255)<<3&2016;g=g+1|0;}while((g|0)<1024);g=d&8;d=g^8;if((c[3527346]&1|0)==0){aCE(1,2);if((c[3527346]&2|0)!=0){aCG(8,d)}aCF(0,2)}else{aCF(0,2);if((c[3527346]&2|0)!=0){aCG(8,d)}aCE(1,2)}if((c[3527346]&2|0)==0){aCG(0,0);aCH();R8(f);return}else{aCG(8,g);aCH();R8(f);return}}function aCS(){var d=0,f=0,g=0,h=0,i=0;a[9759752]=b[c[2437776]>>1]&255&-128;d=c[2112926]|0;gGz(d|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);d=c[2439630]|0;f=c[2438782]|0;g=c[3529908]|0;h=0;do{i=e[d+(h<<1)>>1]|0;c[g+(h<<2)>>2]=i>>>8<<3&2016|i<<8&63488|(e[f+(h<<1)>>1]|0)>>>3&31;h=h+1|0;}while((h|0)<1024);if((c[3527346]&1|0)==0){aCE(1,2);aCF(0,2);aCG(0,0);aCH();R8(g);return}else{aCF(0,2);aCE(1,2);aCG(0,0);aCH();R8(g);return}}function aCT(){var d=0,f=0,g=0,h=0,i=0;a[9759752]=b[c[2437776]>>1]&255&-128;d=c[2112926]|0;gGz(d|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);d=c[2439630]|0;f=c[2438782]|0;g=c[3529908]|0;h=0;do{i=e[d+(h<<1)>>1]|0;c[g+(h<<2)>>2]=i>>>8<<3&2016|i<<8&63488|(e[f+(h<<1)>>1]|0)>>>3&31;h=h+1|0;}while((h|0)<1024);aCE(1,2);aCG(8,8);aCF(0,2);aCG(8,0);aCH();R8(g);return}function aCU(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;e=i;i=i+192|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;l=e+80|0;m=e+96|0;n=e+112|0;o=e+128|0;p=e+144|0;q=e+160|0;r=e+176|0;if((d|0)!=0){c[d>>2]=169762}if((b&32|0)!=0){gGz(r|0,0,12);s=c[2405602]|0;c[r>>2]=s;c[r+4>>2]=(c[2411514]|0)-s;c[r+12>>2]=162152;s=c[2076592]|0;gj[s&4095](r)|0}if((b&64|0)==0){i=e;return}r=h|0;gGz(g|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){s=h+9|0;h=f;t=f|0;u=f+4|0;v=f+12|0;w=g|0;x=g+4|0;y=g+12|0;z=0;do{gGC(r|0,614896,11)|0;a[s]=z+48&255;A=8452256+(z<<2)|0;gGz(h|0,0,12);c[t>>2]=A;c[u>>2]=4;c[v>>2]=164976;gj[c[2076592]&4095](f)|0;if((c[A>>2]|0)!=0){c[w>>2]=c[14130368+(z<<2)>>2];c[x>>2]=c[8452184+(z<<2)>>2];c[y>>2]=r;A=c[2076592]|0;gj[A&4095](g)|0}z=z+1|0;}while((z|0)<=(c[2392]|0))}Vx(b,d);UQ(b,d);Ut(0);gGz(q|0,0,12);c[q>>2]=9776776;c[q+4>>2]=4;c[q+12>>2]=498400;gj[c[2076592]&4095](q)|0;gGz(p|0,0,12);c[p>>2]=9545184;c[p+4>>2]=1;c[p+12>>2]=449152;gj[c[2076592]&4095](p)|0;gGz(o|0,0,12);c[o>>2]=9758144;c[o+4>>2]=1;c[o+12>>2]=497064;gj[c[2076592]&4095](o)|0;gGz(n|0,0,12);c[n>>2]=9759752;c[n+4>>2]=1;c[n+12>>2]=503888;gj[c[2076592]&4095](n)|0;gGz(m|0,0,12);c[m>>2]=14109384;c[m+4>>2]=4;c[m+12>>2]=492792;gj[c[2076592]&4095](m)|0;gGz(l|0,0,12);c[l>>2]=9754968;c[l+4>>2]=3;c[l+12>>2]=491872;gj[c[2076592]&4095](l)|0;gGz(k|0,0,12);c[k>>2]=9720912;c[k+4>>2]=1;c[k+12>>2]=491136;gj[c[2076592]&4095](k)|0;gGz(j|0,0,12);c[j>>2]=9718112;c[j+4>>2]=2;c[j+12>>2]=490296;gj[c[2076592]&4095](j)|0;i=e;return}function aCV(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;b=i;i=i+1440|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;l=b+360|0;m=b+472|0;n=b+480|0;o=b+592|0;p=b+600|0;q=b+712|0;r=b+720|0;s=b+832|0;t=b+840|0;u=b+952|0;v=b+960|0;w=b+1072|0;x=b+1080|0;y=b+1192|0;z=b+1200|0;A=b+1312|0;B=b+1320|0;C=b+1432|0;D=0;while(1){if((D|0)>=1024){E=0;break}F=9638528+(D<<2)|0;if((c[F>>2]|0)==0){G=22305;break}else{D=D+1|0}}do{if((G|0)==22305){D=gGq(262144)|0;c[F>>2]=D;if((D|0)==0){E=0;break}gGz(D|0,0,262144);E=D}}while(0);c[3529554]=E;if((R6((c[2388040]|0)+1|0,0,2)|0)!=0){H=1;i=b;return H|0}if((R6(c[2388040]|0,1,2)|0)!=0){H=1;i=b;return H|0}if((R6((c[2388040]|0)+131073|0,2,2)|0)!=0){H=1;i=b;return H|0}if((R6((c[2388040]|0)+131072|0,3,2)|0)!=0){H=1;i=b;return H|0}if((R6((c[2388040]|0)+262145|0,4,2)|0)!=0){H=1;i=b;return H|0}if((R6((c[2388040]|0)+262144|0,5,2)|0)!=0){H=1;i=b;return H|0}E=c[3527450]|0;if((c[3542200]|0)==0){H=1;i=b;return H|0}F=B+108|0;c[F>>2]=0;D=B+100|0;c[D>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](B,6)|0;do{if((c[F>>2]|0)!=0){B=c[D>>2]|0;c[C>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](C,6,0)|0;if((B|0)<1){H=1;i=b;return H|0}if((gzL(E,0,6)|0)==0){break}else{H=1}i=b;return H|0}}while(0);E=(c[3529554]|0)+131072|0;if((c[3542200]|0)==0){H=1;i=b;return H|0}C=z+108|0;c[C>>2]=0;D=z+100|0;c[D>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,7)|0;do{if((c[C>>2]|0)!=0){z=c[D>>2]|0;c[A>>2]=9534384;F=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[F&16383](A,7,0)|0;if((z|0)<1){H=1;i=b;return H|0}if((gzL(E,0,7)|0)==0){break}else{H=1}i=b;return H|0}}while(0);E=(c[3529554]|0)+196608|0;if((c[3542200]|0)==0){H=1;i=b;return H|0}A=x+108|0;c[A>>2]=0;D=x+100|0;c[D>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,8)|0;do{if((c[A>>2]|0)!=0){x=c[D>>2]|0;c[y>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](y,8,0)|0;if((x|0)<1){H=1;i=b;return H|0}if((gzL(E,0,8)|0)==0){break}else{H=1}i=b;return H|0}}while(0);E=c[3529554]|0;y=E+32768|0;D=E+131072|0;gGC(y|0,D|0,32768)|0;D=E+163840|0;gGC(E|0,D|0,32768)|0;D=E+98304|0;y=E+196608|0;gGC(D|0,y|0,32768)|0;y=E+65536|0;D=E+229376|0;gGC(y|0,D|0,32768)|0;D=c[2406550]|0;y=0;do{A=y<<6;gGz(D+A|0,0,64);x=0;do{C=1<<3-x;z=(c[686408+(x<<2)>>2]|0)+A|0;F=0;do{B=z+(c[1238464+(F<<2)>>2]|0)|0;I=(F<<3)+A|0;J=0;do{K=B+(c[614800+(J<<2)>>2]|0)|0;if(((d[E+((K|0)/8|0)|0]|0)&128>>>((K&7)>>>0)|0)!=0){K=D+(I+J)|0;a[K]=(d[K]|0|C)&255}J=J+1|0;}while((J|0)<8);F=F+1|0;}while((F|0)<8);x=x+1|0;}while((x|0)<4);y=y+1|0;}while((y|0)<4096);gGz(E|0,0,262144);if((c[3542200]|0)==0){H=1;i=b;return H|0}y=v+108|0;c[y>>2]=0;D=v+100|0;c[D>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,9)|0;do{if((c[y>>2]|0)!=0){v=c[D>>2]|0;c[w>>2]=9534384;x=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[x&16383](w,9,0)|0;if((v|0)<1){H=1;i=b;return H|0}if((gzL(E,0,9)|0)==0){break}else{H=1}i=b;return H|0}}while(0);E=(c[3529554]|0)+65536|0;if((c[3542200]|0)==0){H=1;i=b;return H|0}w=t+108|0;c[w>>2]=0;D=t+100|0;c[D>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,10)|0;do{if((c[w>>2]|0)!=0){t=c[D>>2]|0;c[u>>2]=9534384;y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[y&16383](u,10,0)|0;if((t|0)<1){H=1;i=b;return H|0}if((gzL(E,0,10)|0)==0){break}else{H=1}i=b;return H|0}}while(0);E=c[3529554]|0;u=c[2386350]|0;D=0;do{w=D<<8;gGz(u+w|0,0,256);t=0;do{y=1<<3-t;v=(c[611416+(t<<2)>>2]|0)+w|0;x=0;do{A=v+(c[609008+(x<<2)>>2]|0)|0;F=(x<<4)+w|0;C=0;do{z=A+(c[612640+(C<<2)>>2]|0)|0;if(((d[E+((z|0)/8|0)|0]|0)&128>>>((z&7)>>>0)|0)!=0){z=u+(F+C)|0;a[z]=(d[z]|0|y)&255}C=C+1|0;}while((C|0)<16);x=x+1|0;}while((x|0)<16);t=t+1|0;}while((t|0)<4);D=D+1|0;}while((D|0)<1024);gGz(E|0,0,262144);if((c[3542200]|0)==0){H=1;i=b;return H|0}D=r+108|0;c[D>>2]=0;u=r+100|0;c[u>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,11)|0;do{if((c[D>>2]|0)!=0){r=c[u>>2]|0;c[s>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](s,11,0)|0;if((r|0)<1){H=1;i=b;return H|0}if((gzL(E,0,11)|0)==0){break}else{H=1}i=b;return H|0}}while(0);E=(c[3529554]|0)+131072|0;if((c[3542200]|0)==0){H=1;i=b;return H|0}s=p+108|0;c[s>>2]=0;u=p+100|0;c[u>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,12)|0;do{if((c[s>>2]|0)!=0){p=c[u>>2]|0;c[q>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](q,12,0)|0;if((p|0)<1){H=1;i=b;return H|0}if((gzL(E,0,12)|0)==0){break}else{H=1}i=b;return H|0}}while(0);E=c[3529554]|0;q=c[2386348]|0;u=0;do{s=u<<8;gGz(q+s|0,0,256);p=0;do{D=1<<3-p;r=(c[1179e3+(p<<2)>>2]|0)+s|0;t=0;do{w=r+(c[609008+(t<<2)>>2]|0)|0;x=(t<<4)+s|0;y=0;do{v=w+(c[612640+(y<<2)>>2]|0)|0;if(((d[E+((v|0)/8|0)|0]|0)&128>>>((v&7)>>>0)|0)!=0){v=q+(x+y)|0;a[v]=(d[v]|0|D)&255}y=y+1|0;}while((y|0)<16);t=t+1|0;}while((t|0)<16);p=p+1|0;}while((p|0)<4);u=u+1|0;}while((u|0)<2048);gGz(E|0,0,262144);if((c[3542200]|0)==0){H=1;i=b;return H|0}u=n+108|0;c[u>>2]=0;q=n+100|0;c[q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,13)|0;do{if((c[u>>2]|0)!=0){n=c[q>>2]|0;c[o>>2]=9534384;p=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[p&16383](o,13,0)|0;if((n|0)<1){H=1;i=b;return H|0}if((gzL(E,0,13)|0)==0){break}else{H=1}i=b;return H|0}}while(0);E=(c[3529554]|0)+65536|0;if((c[3542200]|0)==0){H=1;i=b;return H|0}o=l+108|0;c[o>>2]=0;q=l+100|0;c[q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,14)|0;do{if((c[o>>2]|0)!=0){l=c[q>>2]|0;c[m>>2]=9534384;u=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[u&16383](m,14,0)|0;if((l|0)<1){H=1;i=b;return H|0}if((gzL(E,0,14)|0)==0){break}else{H=1}i=b;return H|0}}while(0);E=(c[3529554]|0)+131072|0;if((c[3542200]|0)==0){H=1;i=b;return H|0}m=j+108|0;c[m>>2]=0;q=j+100|0;c[q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,15)|0;do{if((c[m>>2]|0)!=0){j=c[q>>2]|0;c[k>>2]=9534384;o=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[o&16383](k,15,0)|0;if((j|0)<1){H=1;i=b;return H|0}if((gzL(E,0,15)|0)==0){break}else{H=1}i=b;return H|0}}while(0);E=(c[3529554]|0)+196608|0;if((c[3542200]|0)==0){H=1;i=b;return H|0}k=g+108|0;c[k>>2]=0;q=g+100|0;c[q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,16)|0;do{if((c[k>>2]|0)!=0){g=c[q>>2]|0;c[h>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](h,16,0)|0;if((g|0)<1){H=1;i=b;return H|0}if((gzL(E,0,16)|0)==0){break}else{H=1}i=b;return H|0}}while(0);E=c[3529554]|0;h=c[3529604]|0;q=0;do{k=q<<8;gGz(h+k|0,0,256);g=0;do{m=1<<3-g;j=(c[1179e3+(g<<2)>>2]|0)+k|0;o=0;do{l=j+(c[609008+(o<<2)>>2]|0)|0;u=(o<<4)+k|0;n=0;do{p=l+(c[612640+(n<<2)>>2]|0)|0;if(((d[E+((p|0)/8|0)|0]|0)&128>>>((p&7)>>>0)|0)!=0){p=h+(u+n)|0;a[p]=(d[p]|0|m)&255}n=n+1|0;}while((n|0)<16);o=o+1|0;}while((o|0)<16);g=g+1|0;}while((g|0)<4);q=q+1|0;}while((q|0)<2048);q=c[3541206]|0;if((c[3542200]|0)==0){H=1;i=b;return H|0}h=e+108|0;c[h>>2]=0;E=e+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,17)|0;do{if((c[h>>2]|0)!=0){e=c[E>>2]|0;c[f>>2]=9534384;g=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[g&16383](f,17,0)|0;if((e|0)<1){H=1;i=b;return H|0}if((gzL(q,0,17)|0)==0){break}else{H=1}i=b;return H|0}}while(0);q=c[3529554]|0;f=0;while(1){if((f|0)>=1024){break}L=9638528+(f<<2)|0;if((c[L>>2]|0)==(q|0)){G=22404;break}else{f=f+1|0}}if((G|0)==22404){gGr(q);c[L>>2]=0}c[3529554]=0;H=0;i=b;return H|0}function aCW(){var d=0,f=0,g=0,h=0,i=0;a[9759752]=b[c[2437776]>>1]&255&-128;d=c[2112926]|0;gGz(d|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);d=c[2439630]|0;f=c[2438782]|0;g=c[3529908]|0;h=0;do{i=e[d+(h<<1)>>1]|0;c[g+(h<<2)>>2]=i>>>8<<3&2016|i<<8&63488|(e[f+(h<<1)>>1]|0)>>>3&31;h=h+1|0;}while((h|0)<1024);if((c[3527346]&1|0)==0){aCF(1,2);aCE(0,2);if((c[3527346]&2|0)!=0){aCF(0,1)}aCG(0,0);if((c[3527346]&4|0)==0){aCH();R8(g);return}aCE(0,1);aCH();R8(g);return}else{aCE(1,2);aCF(0,2);if((c[3527346]&2|0)!=0){aCE(0,1)}aCG(0,0);if((c[3527346]&4|0)==0){aCH();R8(g);return}aCF(0,1);aCH();R8(g);return}}function aCX(d,e){d=d|0;e=e|0;if((d&-16|0)==2097152){b[(c[2383434]|0)+((d>>>1&7)<<1)>>1]=e;return}if((d|0)!=3408768){return}c[2383412]=e&65535;if((a[9661085]|0)==1){return}a[9661085]=1;if((a[9661088]|0)!=0){return}a[9661088]=2;return}function aCY(b,d){b=b|0;d=d|0;if((b-3408768|0)>>>0>=2){return}c[2383412]=d&255;if((a[9661085]|0)==1){return}a[9661085]=1;if((a[9661088]|0)!=0){return}a[9661088]=2;return}function aCZ(a){a=a|0;var e=0;if((a|0)==3409158){e=(d[9634729]|0)<<8|(d[9634728]|0);return e|0}else if((a|0)==3408706){e=b[4775101]|0;return e|0}else if((a|0)==3408536){e=(b[4775100]&7|c[2383408]&8)&65535;return e|0}else{e=0;return e|0}return 0}function aC_(d){d=d|0;var f=0;switch(d|0){case 3409159:{f=a[9634728]|0;break};case 3409158:{f=a[9634729]|0;break};case 3408706:case 3408707:{f=(e[4775101]|0)>>>((d<<3&8^8)>>>0)&255;break};case 3408536:case 3408537:{f=(b[4775100]&7|c[2383408]&8)&255;break};default:{f=0}}return f|0}function aC$(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4746404+(b*112|0)>>2];c[a+104>>2]=c[4746408+(b*112|0)>>2];c[a+108>>2]=c[4746412+(b*112|0)>>2];d=0;return d|0}function aC0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=4746304+(b*112|0);e=0;return e|0}function aC1(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4066976+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aC2(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>38){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6351168+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aC3(){var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=i;i=i+360|0;e=d|0;f=d+112|0;g=d+120|0;h=d+232|0;j=d+240|0;k=d+352|0;c[2424]=5800;c[2414868]=0;c[2388086]=0;c[3531188]=524288;c[2387780]=1048576;c[3530764]=1114112;c[3530528]=3211264;c[3530396]=5308416;c[3541206]=9502720;c[2386600]=9502720;c[3529906]=10027008;c[2414570]=10030080;c[2388216]=10030080;c[2386394]=10095616;c[2387114]=10097664;c[2387802]=10100736;c[3528662]=10108929;c[2411492]=10108930;l=0;while(1){if((l|0)>=1024){break}m=9638528+(l<<2)|0;if((c[m>>2]|0)==0){n=22531;break}else{l=l+1|0}}do{if((n|0)==22531){l=gGq(10108930)|0;c[m>>2]=l;if((l|0)==0){break}c[2414868]=l;gGz(l|0,0,10108930);c[2388086]=l;c[3531188]=l+524288;c[2387780]=l+1048576;c[3530764]=l+1114112;c[3530528]=l+3211264;c[3530396]=l+5308416;o=l+9502720|0;c[3541206]=o;c[2386600]=o;c[3529906]=l+10027008;o=l+10030080|0;c[2414570]=o;c[2388216]=o;c[2386394]=l+10095616;c[2387114]=l+10097664;c[2387802]=l+10100736;c[3528386]=l+10108928;c[3528662]=l+10108929;o=l+10108930|0;c[2411492]=o;c[2414032]=o;if((R6(l,0,2)|0)!=0){p=1;i=d;return p|0}if((R6((c[2388086]|0)+1|0,1,2)|0)!=0){p=1;i=d;return p|0}l=c[2387780]|0;if((c[3542200]|0)==0){p=1;i=d;return p|0}o=j+108|0;c[o>>2]=0;q=j+100|0;c[q>>2]=0;r=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[r&16383](j,2)|0;do{if((c[o>>2]|0)!=0){r=c[q>>2]|0;c[k>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](k,2,0)|0;if((r|0)<1){p=1;i=d;return p|0}if((gzL(l,0,2)|0)==0){break}else{p=1}i=d;return p|0}}while(0);l=c[3530528]|0;if((c[3542200]|0)==0){p=1;i=d;return p|0}q=g+108|0;c[q>>2]=0;o=g+100|0;c[o>>2]=0;r=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[r&16383](g,3)|0;do{if((c[q>>2]|0)!=0){r=c[o>>2]|0;c[h>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](h,3,0)|0;if((r|0)<1){p=1;i=d;return p|0}if((gzL(l,0,3)|0)==0){break}else{p=1}i=d;return p|0}}while(0);if((R6(c[3530396]|0,4,2)|0)!=0){p=1;i=d;return p|0}if((R6((c[3530396]|0)+1|0,5,2)|0)!=0){p=1;i=d;return p|0}l=c[2386600]|0;if((c[3542200]|0)==0){p=1;i=d;return p|0}o=e+108|0;c[o>>2]=0;q=e+100|0;c[q>>2]=0;r=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[r&16383](e,6)|0;do{if((c[o>>2]|0)!=0){r=c[q>>2]|0;c[f>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](f,6,0)|0;if((r|0)<1){p=1;i=d;return p|0}if((gzL(l,0,6)|0)==0){break}else{p=1}i=d;return p|0}}while(0);aFh(c[2388086]|0,c[3531188]|0,524288,59834,1,25);aFg(c[3530528]|0,1048576,1574056,720536,1110256);aE_(c[3530528]|0,c[3530764]|0,1048576,1);l=c[3530528]|0;aE_(l,l,1048576,0);aE$(c[3530396]|0,2097152);aE1(1,0,1);l=c[3530528]|0;c[2383440]=c[3530764];c[2383441]=l;c[2383442]=0;c[2383436]=32767;c[2383437]=8191;c[2383438]=0;a[690376]=1;c[2429436]=1488;c[2429437]=1488;fxU(0,425984);if((c[2394]|0)==0){t=c[2112932]|0}else{c[2394]=0;l=c[3532596]|0;c[2112932]=l;q=c[3532592]|0;if((q|0)!=0){gGC(9104152,q|0,280)|0}c[2113054]=c[2113060];t=l}l=c[2388086]|0;q=t|0;o=q;r=0;while(1){c[o>>2]=l+r;s=r+1024|0;if(s>>>0>524287){break}else{o=o+4|0;r=s}}r=c[3531188]|0;o=q;l=0;while(1){c[o+131072>>2]=r+l;s=l+1024|0;if(s>>>0>524287){break}else{o=o+4|0;l=s}}l=c[2383430]|0;c[t+8448>>2]=l;c[t+73984>>2]=l;c[t+139520>>2]=l;o=l+1024|0;c[t+8452>>2]=o;c[t+73988>>2]=o;c[t+139524>>2]=o;o=l+2048|0;c[t+8456>>2]=o;c[t+73992>>2]=o;c[t+139528>>2]=o;o=l+3072|0;c[t+8460>>2]=o;c[t+73996>>2]=o;c[t+139532>>2]=o;o=l+4096|0;c[t+8464>>2]=o;c[t+74e3>>2]=o;c[t+139536>>2]=o;o=l+5120|0;c[t+8468>>2]=o;c[t+74004>>2]=o;c[t+139540>>2]=o;o=l+6144|0;c[t+8472>>2]=o;c[t+74008>>2]=o;c[t+139544>>2]=o;o=l+7168|0;c[t+8476>>2]=o;c[t+74012>>2]=o;c[t+139548>>2]=o;o=c[2383431]|0;c[t+8480>>2]=o;c[t+74016>>2]=o;c[t+139552>>2]=o;l=o+1024|0;c[t+8484>>2]=l;c[t+74020>>2]=l;c[t+139556>>2]=l;l=o+2048|0;c[t+8488>>2]=l;c[t+74024>>2]=l;c[t+139560>>2]=l;l=o+3072|0;c[t+8492>>2]=l;c[t+74028>>2]=l;c[t+139564>>2]=l;l=o+4096|0;c[t+8496>>2]=l;c[t+74032>>2]=l;c[t+139568>>2]=l;l=o+5120|0;c[t+8500>>2]=l;c[t+74036>>2]=l;c[t+139572>>2]=l;l=o+6144|0;c[t+8504>>2]=l;c[t+74040>>2]=l;c[t+139576>>2]=l;l=o+7168|0;c[t+8508>>2]=l;c[t+74044>>2]=l;c[t+139580>>2]=l;l=c[2383428]|0;c[t+8704>>2]=l;c[t+74240>>2]=l;c[t+139776>>2]=l;o=l+1024|0;c[t+8708>>2]=o;c[t+74244>>2]=o;c[t+139780>>2]=o;o=c[2383426]|0;c[t+8736>>2]=o;c[t+74272>>2]=o;c[t+139808>>2]=o;l=o+1024|0;c[t+8740>>2]=l;c[t+74276>>2]=l;c[t+139812>>2]=l;l=c[2386394]|0;c[t+10240>>2]=l;c[t+75776>>2]=l;c[t+141312>>2]=l;o=l+1024|0;c[t+10244>>2]=o;c[t+75780>>2]=o;c[t+141316>>2]=o;o=c[2387114]|0;c[t+12288>>2]=o;c[t+77824>>2]=o;c[t+143360>>2]=o;l=o+1024|0;c[t+12292>>2]=l;c[t+77828>>2]=l;c[t+143364>>2]=l;l=o+2048|0;c[t+12296>>2]=l;c[t+77832>>2]=l;c[t+143368>>2]=l;l=c[2388216]|0;o=t+14336|0;r=3670016;while(1){q=l+(r-3670016)|0;c[o>>2]=q;c[o+65536>>2]=q;c[o+131072>>2]=q;q=r+1024|0;if(q>>>0>3735551){break}else{o=o+4|0;r=q}}c[t+196728>>2]=232;c[t+196648>>2]=594;c[t+196688>>2]=3354;c[t+196608>>2]=2884;r=c[3532592]|0;if((r|0)!=0){gGC(r|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;aE8(c[2387780]|0,c[2387802]|0,2685e3,0,0,.45,1006875,.6,0,0.0);r=c[642608+(c[2436]<<2)>>2]|0;o=c[r+128>>2]|0;if((c[r+52>>2]&4|0)==0){c[2113068]=o;l=c[r+132>>2]|0;c[2113070]=l;c[2443814]=o;c[2440436]=l;u=o;v=l}else{c[2113070]=o;l=c[r+132>>2]|0;c[2113068]=l;c[2440436]=o;c[2443814]=l;u=l;v=o}o=ag(u<<1,v)|0;l=gGq(o)|0;c[2112926]=l;if((l|0)!=0){gGz(l|0,0,o|0)}o=c[2414570]|0;gGz(o|0,0,(c[2411492]|0)-o|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];o=c[3532592]|0;if((o|0)!=0){gGC(9104152,o|0,280)|0}c[2113054]=c[2113060]}RI();o=c[2394]|0;l=c[14130368+(o<<2)>>2]|0;if((l|0)!=0){gGC(l|0,9104152,280)|0}c[8452240+(o<<2)>>2]=c[2113054];c[2394]=-1;aE7();gGz(c[2383428]|0,0,4096);gGz(c[2383426]|0,0,4096);o=c[2383424]|0;if((o|0)!=0){gGz(o|0,0,4096);gGz(c[2383422]|0,0,4096)}gGz(c[2383434]|0,0,16);gGz(c[2383435]|0,0,16);gGz(c[2383430]|0,0,8192);gGz(c[2383431]|0,0,8192);o=c[2383432]|0;if((o|0)!=0){gGz(o|0,0,8192);gGz(c[2383433]|0,0,8192)}b[4766836]=0;c[2426968]=0;c[3528794]=0;c[1765522]=65535;c[2429656]=0;c[2427042]=0;c[2429386]=0;c[2429384]=0;c[2429382]=0;p=0;i=d;return p|0}}while(0);c[2414868]=0;p=1;i=d;return p|0}function aC4(){var a=0,b=0,d=0,e=0,f=0;c[2113070]=0;c[2113068]=0;a=c[2112926]|0;if((a|0)!=0){gGr(a);c[2112926]=0}aE2();aFe();if((c[2392]|0)>=0){a=0;do{b=14130368+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}b=14130384+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}a=a+1|0;}while((a|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;a=c[2414868]|0;b=0;while(1){if((b|0)>=1024){e=22607;break}f=9638528+(b<<2)|0;if((c[f>>2]|0)==(a|0)){break}else{b=b+1|0}}if((e|0)==22607){c[2414868]=0;return 0}gGr(a);c[f>>2]=0;c[2414868]=0;return 0}function aC5(){var d=0,e=0,f=0,g=0,h=0,i=0;if((a[9623528]|0)!=0){d=c[2414570]|0;gGz(d|0,0,(c[2411492]|0)-d|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;aE7();gGz(c[2383428]|0,0,4096);gGz(c[2383426]|0,0,4096);d=c[2383424]|0;if((d|0)!=0){gGz(d|0,0,4096);gGz(c[2383422]|0,0,4096)}gGz(c[2383434]|0,0,16);gGz(c[2383435]|0,0,16);gGz(c[2383430]|0,0,8192);gGz(c[2383431]|0,0,8192);d=c[2383432]|0;if((d|0)!=0){gGz(d|0,0,8192);gGz(c[2383433]|0,0,8192)}b[4766836]=0;c[2426968]=0;c[3528794]=0;c[1765522]=65535;c[2429656]=0;c[2427042]=0;c[2429386]=0;c[2429384]=0;c[2429382]=0}c[(c[2391608]|0)+60>>2]=0;c[(c[2391608]|0)+60>>2]=0;c[2387550]=-1;d=0;e=-1;f=-1;do{e=((a[9632560+d|0]&1)<<d^e&65535)&65535;f=((a[9630464+d|0]&1)<<d^f&65535)&65535;d=d+1|0;}while((d|0)<16);b[4775100]=e;b[4775101]=f;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060]}c[2388530]=9554128;f=c[2391608]|0;if((f|0)!=0){e=f;gGC(9661040,e|0,68)|0}c[2382]=0;c[2383408]=0;e=0;f=0;while(1){c[2113056]=942;d=RG(942)|0;c[2113054]=(c[2113054]|0)+d;c[2276108]=-1;c[2113056]=-1;fy_(180)|0;if((e|0)==240){c[2383408]=8}d=c[2112964]|0;if((d|0)==0){g=f}else{h=a[9688]|0?2:0;i=d+(f<<1<<1)|0;if(a[801408]|0){gg[c[3542124]&4095](i,h)}if(a[801400]|0){Uu(0,i,h)}if((c[2429658]|0)!=0){Uu(1,i,h)}g=h+f|0}h=e+1|0;if((h|0)<256){e=h;f=g}else{break}}c[8452200+(c[2394]<<2)>>2]=8198;c[2276080]=1536;if((c[2276079]|0)>>>0<1536){RH(6)}f=c[2112964]|0;do{if((f|0)!=0){e=a[9688]|0?534:0;if((e|0)==(g|0)){break}h=e-g|0;e=f+(g<<1<<1)|0;if(a[801408]|0){gg[c[3542124]&4095](e,h)}if(a[801400]|0){Uu(0,e,h)}if((c[2429658]|0)==0){break}Uu(1,e,h)}}while(0);g=c[(c[2388530]|0)+12304>>2]|0;if((g|0)!=0){f=g;gGC(f|0,9661040,68)|0}c[2382]=-1;f=c[2394]|0;g=c[14130368+(f<<2)>>2]|0;if((g|0)!=0){gGC(g|0,9104152,280)|0}c[8452240+(f<<2)>>2]=c[2113054];c[2394]=-1;if((c[2112968]|0)==0){return 0}aC6()|0;return 0}function aC6(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;d=c[3529906]|0;f=c[2387114]|0;g=(c[642608+(c[2436]<<2)>>2]|0)+124|0;if((c[g>>2]<<1|0)>0){h=0;do{i=e[f+((h|1)<<1)>>1]|0;c[d+(((h|0)/2|0)<<2)>>2]=i<<8&63488|(e[f+(h<<1)>>1]|0)>>>3&31|i>>>8<<3&2016;h=h+2|0;}while((h|0)<(c[g>>2]<<1|0))}a[9547128]=0;aE3();g=ag(c[2113070]|0,c[2113068]|0)|0;h=c[2112926]|0;if((g|0)>0){f=0;while(1){b[h+(f<<1)>>1]=256;d=f+1|0;if((d|0)<(g|0)){f=d}else{j=h;break}}}else{j=h}aE0(1,j,65536);aE0(0,j,0);h=c[2386394]|0;f=c[3528662]|0;g=c[3530396]|0;d=(c[2113222]&1|0)==0;i=0;do{k=b[h+((i|1)<<1)>>1]|0;do{if(k<<16>>16!=0){l=e[h+(i<<1)>>1]|0;m=e[h+((i|2)<<1)>>1]|0;if(!((l&4096|0)==0|d)){break}n=m>>>9&31;o=l&8192;p=l&16384;q=1<<(l>>>9&3);r=q-1|0;s=m&511;t=l&511;u=s>>>0>319?m|-512:s;s=t>>>0>255?l|-512:t;t=(p>>>13^2)-1|0;l=((p|0)==0?r:0)+(k&16383&-q)|0;if((a[f]|0)==0){v=p;w=o;x=304-u|0;y=240-s|0;z=-16}else{v=p>>>14^1;w=o>>>13^1;x=u;y=s;z=16}if(!((x+15|0)>>>0<335&(q|0)>0)){break}q=(w|0)!=0;s=y-8|0;if((v|0)==0){if(q){u=r;while(1){o=ag(u,z)|0;SJ(j,l-(ag(u,t)|0)|0,x,o+s|0,n,4,0,512,g);if((u|0)>0){u=u-1|0}else{break}}}else{u=r;while(1){o=ag(u,z)|0;SH(j,l-(ag(u,t)|0)|0,x,o+s|0,n,4,0,512,g);if((u|0)>0){u=u-1|0}else{break}}}}else{if(q){u=r;while(1){o=l-(ag(u,t)|0)|0;SN(j,o,x,(ag(u,z)|0)+s|0,n,4,0,512,g);if((u|0)>0){u=u-1|0}else{break}}}else{u=r;while(1){q=l-(ag(u,t)|0)|0;SL(j,q,x,(ag(u,z)|0)+s|0,n,4,0,512,g);if((u|0)>0){u=u-1|0}else{break}}}}}}while(0);i=i+4|0;}while((i|0)<1024);R8(c[3529906]|0);return 0}function aC7(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=i;i=i+64|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;if((d|0)!=0){c[d>>2]=169762}if((b&32|0)!=0){gGz(j|0,0,12);k=c[2414570]|0;c[j>>2]=k;c[j+4>>2]=(c[2411492]|0)-k;c[j+12>>2]=162152;k=c[2076592]|0;gj[k&4095](j)|0}if((b&64|0)==0){i=e;return 0}j=h|0;gGz(g|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){k=h+9|0;h=f;l=f|0;m=f+4|0;n=f+12|0;o=g|0;p=g+4|0;q=g+12|0;r=0;do{gGC(j|0,614896,11)|0;a[k]=r+48&255;s=8452256+(r<<2)|0;gGz(h|0,0,12);c[l>>2]=s;c[m>>2]=4;c[n>>2]=164976;gj[c[2076592]&4095](f)|0;if((c[s>>2]|0)!=0){c[o>>2]=c[14130368+(r<<2)>>2];c[p>>2]=c[8452184+(r<<2)>>2];c[q>>2]=j;s=c[2076592]|0;gj[s&4095](g)|0}r=r+1|0;}while((r|0)<=(c[2392]|0))}aFf(b,d);aE6();i=e;return 0}function aC8(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4748644+(b*112|0)>>2];c[a+104>>2]=c[4748648+(b*112|0)>>2];c[a+108>>2]=c[4748652+(b*112|0)>>2];d=0;return d|0}function aC9(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=4748544+(b*112|0);e=0;return e|0}function aDa(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5915100+(b*112|0)>>2];c[a+104>>2]=c[5915104+(b*112|0)>>2];c[a+108>>2]=c[5915108+(b*112|0)>>2];d=0;return d|0}function aDb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=5915e3+(b*112|0);e=0;return e|0}function aDc(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4747524+(b*112|0)>>2];c[a+104>>2]=c[4747528+(b*112|0)>>2];c[a+108>>2]=c[4747532+(b*112|0)>>2];d=0;return d|0}function aDd(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=4747424+(b*112|0);e=0;return e|0}function aDe(a){a=a|0;return a>>>4<<12&28672|0}function aDf(b,d){b=b|0;d=d|0;var e=0;e=b-1048576|0;if(e>>>0<32){if((b&2|0)!=0){return}a[(c[2383434]|0)+((e&-4|0)/2|0|e&1)|0]=d;return}e=b-1114112|0;if(e>>>0<8192){if((b&2|0)!=0){return}a[(c[2383430]|0)+((e&-4|0)/2|0|e&1)|0]=d;return}e=b-1130496|0;if(e>>>0<8192){if((b&2|0)!=0){return}a[(c[2383431]|0)+((e&-4|0)/2|0|e&1)|0]=d;return}e=b-1179648|0;if(e>>>0<4096){if((b&2|0)!=0){return}a[(c[2383428]|0)+((e&-4|0)/2|0|e&1)|0]=d;return}e=b-1196032|0;if(e>>>0<4096){if((b&2|0)!=0){return}a[(c[2383426]|0)+((e&-4|0)/2|0|e&1)|0]=d;return}e=b-1245184|0;if(e>>>0<32){if((b&2|0)!=0){return}a[(c[2383435]|0)+((e&-4|0)/2|0|e&1)|0]=d;return}e=b-1310720|0;if(e>>>0<8192){if((b&2|0)!=0){return}a[(c[2383432]|0)+((e&-4|0)/2|0|e&1)|0]=d;return}e=b-1327104|0;if(e>>>0<8192){if((b&2|0)!=0){return}a[(c[2383433]|0)+((e&-4|0)/2|0|e&1)|0]=d;return}e=b-1376256|0;if(e>>>0<4096){if((b&2|0)!=0){return}a[(c[2383424]|0)+((e&-4|0)/2|0|e&1)|0]=d;return}e=b-1392640|0;if(e>>>0<4096){if((b&2|0)!=0){return}a[(c[2383422]|0)+((e&-4|0)/2|0|e&1)|0]=d;return}if((b|0)==1835008){c[2113012]=d&255;return}else if((b|0)==1835012){Ui(d);return}else{return}}function aDg(a,d){a=a|0;d=d|0;var e=0;e=a-1048576|0;if(e>>>0<32){b[(c[2383434]|0)+(e>>>1&2147483646)>>1]=d&65535;return}e=a-1114112|0;if(e>>>0<8192){b[(c[2383430]|0)+(e>>>1&2147483646)>>1]=d&65535;return}e=a-1130496|0;if(e>>>0<8192){b[(c[2383431]|0)+(e>>>1&2147483646)>>1]=d&65535;return}e=a-1179648|0;if(e>>>0<4096){b[(c[2383428]|0)+(e>>>1&2147483646)>>1]=d&65535;return}e=a-1196032|0;if(e>>>0<4096){b[(c[2383426]|0)+(e>>>1&2147483646)>>1]=d&65535;return}e=a-1245184|0;if(e>>>0<32){b[(c[2383435]|0)+(e>>>1&2147483646)>>1]=d&65535;return}e=a-1310720|0;if(e>>>0<8192){b[(c[2383432]|0)+(e>>>1&2147483646)>>1]=d&65535;return}e=a-1327104|0;if(e>>>0<8192){b[(c[2383433]|0)+(e>>>1&2147483646)>>1]=d&65535;return}e=a-1376256|0;if(e>>>0<4096){b[(c[2383424]|0)+(e>>>1&2147483646)>>1]=d&65535;return}e=a-1392640|0;if(e>>>0<4096){b[(c[2383422]|0)+(e>>>1&2147483646)>>1]=d&65535;return}if((a|0)==1736704){c[c[2394704]>>2]=d;return}else if((a|0)==1720320){c[2415256]=d&1;e=d>>>2&1;c[3528406]=e^1;if((e|0)==0){c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2]}Tr(d>>>1&1);return}else if((a|0)==1835012){Ui(d&255);return}else if((a|0)==1753088){c[(c[2394704]|0)+4>>2]=d;return}else if((a|0)==1835008){c[2113012]=d&255;return}else{return}}function aDh(d){d=d|0;var e=0,f=0,g=0;e=d-1048576|0;if(e>>>0<32){if((d&2|0)!=0){f=-1;return f|0}f=a[(c[2383434]|0)+((e&-4|0)/2|0|e&1)|0]|0;return f|0}e=d-1114112|0;if(e>>>0<8192){if((d&2|0)!=0){f=-1;return f|0}f=a[(c[2383430]|0)+((e&-4|0)/2|0|e&1)|0]|0;return f|0}e=d-1130496|0;if(e>>>0<8192){if((d&2|0)!=0){f=-1;return f|0}f=a[(c[2383431]|0)+((e&-4|0)/2|0|e&1)|0]|0;return f|0}e=d-1179648|0;if(e>>>0<4096){if((d&2|0)!=0){f=-1;return f|0}f=a[(c[2383428]|0)+((e&-4|0)/2|0|e&1)|0]|0;return f|0}e=d-1196032|0;if(e>>>0<4096){if((d&2|0)!=0){f=-1;return f|0}f=a[(c[2383426]|0)+((e&-4|0)/2|0|e&1)|0]|0;return f|0}e=d-1245184|0;if(e>>>0<32){if((d&2|0)!=0){f=-1;return f|0}f=a[(c[2383435]|0)+((e&-4|0)/2|0|e&1)|0]|0;return f|0}e=d-1310720|0;if(e>>>0<8192){if((d&2|0)!=0){f=-1;return f|0}f=a[(c[2383432]|0)+((e&-4|0)/2|0|e&1)|0]|0;return f|0}e=d-1327104|0;if(e>>>0<8192){if((d&2|0)!=0){f=-1;return f|0}f=a[(c[2383433]|0)+((e&-4|0)/2|0|e&1)|0]|0;return f|0}e=d-1376256|0;if(e>>>0<4096){if((d&2|0)!=0){f=-1;return f|0}f=a[(c[2383424]|0)+((e&-4|0)/2|0|e&1)|0]|0;return f|0}e=d-1392640|0;if(e>>>0<4096){if((d&2|0)!=0){f=-1;return f|0}f=a[(c[2383422]|0)+((e&-4|0)/2|0|e&1)|0]|0;return f|0}if((d|0)==1654786){f=b[4774944]&255;return f|0}else if((d|0)==1835012){e=c[2113010]|0;c[2113010]=0;c[2430402]=0;g=c[3531294]|0;if((g|0)!=0){gf[g&2047](0)}f=e&255;return f|0}else if((d|0)==1638402){f=b[4774868]&255;return f|0}else if((d|0)==1638400){f=b[4775044]&255;return f|0}else{f=0;return f|0}return 0}function aDi(a){a=a|0;var b=0,d=0,f=0,g=0;b=a-1048576|0;if(b>>>0<32){d=e[(c[2383434]|0)+(b>>>1&2147483646)>>1]|0|-65536;return d|0}b=a-1114112|0;if(b>>>0<8192){d=e[(c[2383430]|0)+(b>>>1&2147483646)>>1]|0|-65536;return d|0}b=a-1130496|0;if(b>>>0<8192){d=e[(c[2383431]|0)+(b>>>1&2147483646)>>1]|0|-65536;return d|0}b=a-1179648|0;if(b>>>0<4096){d=e[(c[2383428]|0)+(b>>>1&2147483646)>>1]|0|-65536;return d|0}b=a-1196032|0;if(b>>>0<4096){d=e[(c[2383426]|0)+(b>>>1&2147483646)>>1]|0|-65536;return d|0}b=a-1245184|0;if(b>>>0<32){d=e[(c[2383435]|0)+(b>>>1&2147483646)>>1]|0|-65536;return d|0}b=a-1310720|0;if(b>>>0<8192){d=e[(c[2383432]|0)+(b>>>1&2147483646)>>1]|0|-65536;return d|0}b=a-1327104|0;if(b>>>0<8192){d=e[(c[2383433]|0)+(b>>>1&2147483646)>>1]|0|-65536;return d|0}b=a-1376256|0;if(b>>>0<4096){d=e[(c[2383424]|0)+(b>>>1&2147483646)>>1]|0|-65536;return d|0}b=a-1392640|0;if(b>>>0<4096){d=e[(c[2383422]|0)+(b>>>1&2147483646)>>1]|0|-65536;return d|0}if((a|0)==1654784){do{if((c[2406632]|0)==0){b=c[2443744]|0;if((b|0)<=0){f=16777216;break}c[2443744]=b-1;f=0}else{f=(c[2432962]|0)>>>((c[(c[2420380]|0)+4>>2]|0)>>>0)<<24&16777216}}while(0);b=e[4774944]|0;d=b|f|b<<16;return d|0}else if((a|0)==1835012){b=c[2113010]|0;c[2113010]=0;c[2430402]=0;f=c[3531294]|0;if((f|0)==0){d=b;return d|0}gf[f&2047](0);d=b;return d|0}else if((a|0)==1638400){do{if((c[2406632]|0)==0){a=c[2443744]|0;if((a|0)<=0){g=16842752;break}c[2443744]=a-1;g=65536}else{g=(c[2432962]|0)>>>((c[(c[2420380]|0)+4>>2]|0)>>>0)<<24&16777216|65536}}while(0);d=g|c[2383408]|(e[4774868]|0)<<16&12451840|(e[4775044]|0);return d|0}else{d=0;return d|0}return 0}function aDj(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3119988+(b*112|0)>>2];c[a+104>>2]=c[3119992+(b*112|0)>>2];c[a+108>>2]=c[3119996+(b*112|0)>>2];d=0;return d|0}function aDk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=3119888+(b*112|0);e=0;return e|0}function aDl(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>26){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1313488+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aDm(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4258376+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aDn(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;e=i;i=i+600|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=c[2414864]|0;c[2388004]=r;c[3530762]=r+1048576;c[3530526]=r+9437184;c[3530394]=r+17825792;c[3530314]=r+19922944;s=r+28311552|0;c[3531292]=s;c[2386598]=s;c[3529904]=r+32505856;s=r+32514048|0;c[2438738]=s;c[2439520]=s;c[2439518]=r+32667648;s=r+32821248|0;c[2414566]=s;c[2388008]=s;c[2387110]=r+32854016;c[3529660]=r+32862208;c[3529644]=r+32870400;c[2394704]=r+32878592;s=r+32878600|0;c[2411476]=s;c[2414016]=s;r=s;s=0;while(1){if((s|0)>=1024){break}t=9638528+(s<<2)|0;if((c[t>>2]|0)==0){u=22973;break}else{s=s+1|0}}do{if((u|0)==22973){s=gGq(r)|0;c[t>>2]=s;if((s|0)==0){break}gGz(s|0,0,r|0);c[2414864]=s;gGz(s|0,0,r|0);c[2388004]=s;c[3530762]=s+1048576;c[3530526]=s+9437184;c[3530394]=s+17825792;c[3530314]=s+19922944;v=s+28311552|0;c[3531292]=v;c[2386598]=v;c[3529904]=s+32505856;v=s+32514048|0;c[2438738]=v;c[2439520]=v;c[2439518]=s+32667648;v=s+32821248|0;c[2414566]=v;c[2388008]=v;c[2387110]=s+32854016;c[3529660]=s+32862208;c[3529644]=s+32870400;c[2394704]=s+32878592;v=s+32878600|0;c[2411476]=v;c[2414016]=v;if((R6(s+1|0,0,2)|0)!=0){w=1;i=e;return w|0}if((R6(c[2388004]|0,1,2)|0)!=0){w=1;i=e;return w|0}s=c[2388004]|0;v=0;do{x=v|1;y=s+x|0;z=a[y]|0;A=s+(x+1)|0;a[y]=a[A]|0;a[A]=z;v=v+4|0;}while((v|0)<1048576);v=c[3530526]|0;if((c[3542200]|0)==0){w=1;i=e;return w|0}s=p+108|0;c[s>>2]=0;z=p+100|0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,2)|0;do{if((c[s>>2]|0)!=0){A=c[z>>2]|0;c[q>>2]=9534384;y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[y&16383](q,2,0)|0;if((A|0)<1){w=1;i=e;return w|0}if((gzL(v,0,2)|0)==0){break}else{w=1}i=e;return w|0}}while(0);v=(c[3530526]|0)+2097152|0;if((c[3542200]|0)==0){w=1;i=e;return w|0}z=n+108|0;c[z>>2]=0;s=n+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,3)|0;do{if((c[z>>2]|0)!=0){A=c[s>>2]|0;c[o>>2]=9534384;y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[y&16383](o,3,0)|0;if((A|0)<1){w=1;i=e;return w|0}if((gzL(v,0,3)|0)==0){break}else{w=1}i=e;return w|0}}while(0);v=c[3530526]|0;s=c[3530762]|0;z=0;do{a[s+(z<<2&2097152|z&1572863|z>>>2&524288)|0]=a[v+z|0]|0;z=z+1|0;}while((z|0)<4194304);gGz(v|0,0,4194304);z=c[3530394]|0;if((c[3542200]|0)==0){w=1;i=e;return w|0}s=l+108|0;c[s>>2]=0;A=l+100|0;c[A>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,4)|0;do{if((c[s>>2]|0)!=0){y=c[A>>2]|0;c[m>>2]=9534384;x=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[x&16383](m,4,0)|0;if((y|0)<1){w=1;i=e;return w|0}if((gzL(z,0,4)|0)==0){break}else{w=1}i=e;return w|0}}while(0);if((R6((c[3530314]|0)+1|0,5,2)|0)!=0){w=1;i=e;return w|0}if((R6(c[3530314]|0,6,2)|0)!=0){w=1;i=e;return w|0}z=c[2386598]|0;gGz(z|0,-1|0,4194304);if((c[3542200]|0)==0){w=1;i=e;return w|0}A=j+108|0;c[A>>2]=0;s=j+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,9)|0;do{if((c[A>>2]|0)!=0){v=c[s>>2]|0;c[k>>2]=9534384;y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[y&16383](k,9,0)|0;if((v|0)<1){w=1;i=e;return w|0}if((gzL(z,0,9)|0)==0){break}else{w=1}i=e;return w|0}}while(0);z=(c[2386598]|0)+2097152|0;if((c[3542200]|0)==0){w=1;i=e;return w|0}s=f+108|0;c[s>>2]=0;A=f+100|0;c[A>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,10)|0;do{if((c[s>>2]|0)!=0){v=c[A>>2]|0;c[g>>2]=9534384;y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[y&16383](g,10,0)|0;if((v|0)<1){w=1;i=e;return w|0}if((gzL(z,0,10)|0)==0){break}else{w=1}i=e;return w|0}}while(0);aFj(c[2388004]|0,1048576);aFg(c[3530762]|0,4194304,1574056,720536,1110256);aFg(c[3530394]|0,1048576,1574056,720536,1110256);aE_(c[3530762]|0,c[3530526]|0,4194304,0);z=c[3530762]|0;aE_(z,z,4194304,1);z=c[3530394]|0;aE_(z,z,1048576,0);z=c[3530314]|0;A=0;while(1){if((A|0)>=1024){B=0;break}C=9638528+(A<<2)|0;if((c[C>>2]|0)==0){u=23006;break}else{A=A+1|0}}L29388:do{if((u|0)==23006){A=gGq(4194304)|0;c[C>>2]=A;if((A|0)==0){B=0;break}gGz(A|0,0,4194304);gGC(A|0,z|0,4194304)|0;s=0;while(1){v=s<<8;gGz(z+v|0,0,256);y=s<<10;x=0;do{D=1<<3-x;E=(c[606040+(x<<2)>>2]|0)+y|0;F=0;do{G=E+(c[611840+(F<<2)>>2]|0)|0;H=(F<<4)+v|0;I=0;do{J=G+(c[613752+(I<<2)>>2]|0)|0;if(((d[A+((J|0)/8|0)|0]|0)&128>>>((J&7)>>>0)|0)!=0){J=z+(H+I)|0;a[J]=(d[J]|0|D)&255}I=I+1|0;}while((I|0)<16);F=F+1|0;}while((F|0)<16);x=x+1|0;}while((x|0)<4);x=s+1|0;if((x|0)<32768){s=x}else{K=0;break}}while(1){if((K|0)>=1024){B=0;break L29388}L=9638528+(K<<2)|0;if((c[L>>2]|0)==(A|0)){break}else{K=K+1|0}}gGr(A);c[L>>2]=0;B=0}}while(0);while(1){if((B|0)>=1024){M=0;break}N=9638528+(B<<2)|0;if((c[N>>2]|0)==0){u=23022;break}else{B=B+1|0}}do{if((u|0)==23022){z=gGq(2097152)|0;c[N>>2]=z;if((z|0)==0){M=0;break}gGz(z|0,0,2097152);M=z}}while(0);z=c[2386598]|0;s=0;do{a[M+(s<<20&1048576|s>>1)|0]=a[z+s|0]|0;s=s+1|0;}while((s|0)<2097152);gGC(z|0,M|0,2097152)|0;s=0;while(1){if((s|0)>=1024){break}O=9638528+(s<<2)|0;if((c[O>>2]|0)==(M|0)){u=23029;break}else{s=s+1|0}}if((u|0)==23029){gGr(M);c[O>>2]=0}s=gGq(65536)|0;c[2406730]=s;gGz(s|0,0,65536);s=gGq(65536)|0;c[2406728]=s;gGz(s|0,0,65536);s=gGq(65536)|0;z=s;c[2406726]=z;gGz(s|0,0,65536);c[2430386]=0;c[2430390]=0;c[2432800]=0;c[2432804]=0;x=c[2427044]|0;c[9681616+(x<<3)>>2]=1314928;c[9681620+(x<<3)>>2]=0;c[2427044]=x+1;c[2427230]=0;c[3542218]=-1;x=c[2388004]|0;v=c[2406730]|0;y=0;do{F=x+(y<<12)|0;c[v+(y<<2)>>2]=F;c[z+(y<<2)>>2]=F;y=y+1|0;}while(y>>>0<256);y=c[2387110]|0;c[v+1408>>2]=y;z=c[2406728]|0;c[z+1408>>2]=y;c[s+1408>>2]=y;x=y+4096|0;c[v+1412>>2]=x;c[z+1412>>2]=x;c[s+1412>>2]=x;x=c[2388008]|0;c[v+1472>>2]=x;c[z+1472>>2]=x;c[s+1472>>2]=x;y=x+4096|0;c[v+1476>>2]=y;c[z+1476>>2]=y;c[s+1476>>2]=y;y=x+8192|0;c[v+1480>>2]=y;c[z+1480>>2]=y;c[s+1480>>2]=y;y=x+12288|0;c[v+1484>>2]=y;c[z+1484>>2]=y;c[s+1484>>2]=y;y=x+16384|0;c[v+1488>>2]=y;c[z+1488>>2]=y;c[s+1488>>2]=y;y=x+20480|0;c[v+1492>>2]=y;c[z+1492>>2]=y;c[s+1492>>2]=y;y=x+24576|0;c[v+1496>>2]=y;c[z+1496>>2]=y;c[s+1496>>2]=y;y=x+28672|0;c[v+1500>>2]=y;c[z+1500>>2]=y;c[s+1500>>2]=y;y=c[3529660]|0;c[v+1552>>2]=y;c[z+1552>>2]=y;c[s+1552>>2]=y;x=y+4096|0;c[v+1556>>2]=x;c[z+1556>>2]=x;c[s+1556>>2]=x;x=c[3529644]|0;c[v+1584>>2]=x;c[z+1584>>2]=x;c[s+1584>>2]=x;y=x+4096|0;c[v+1588>>2]=y;c[z+1588>>2]=y;c[s+1588>>2]=y;c[2430390]=2258;c[2430386]=1018;c[2432804]=1842;c[2432800]=3520;c[3542218]=52804;c[2427230]=2008;Tq(689616);Uf(14e6,0);h[607287]=1.0;c[2433116]=1;h[607286]=1.0;c[2433114]=2;aE1(0,0,1);c[2429436]=3172;c[2429437]=3172;c[2429438]=3172;c[2429439]=3172;c[2429667]=1024;c[2429668]=256;c[2429669]=1280;y=c[3530526]|0;z=c[3530394]|0;c[2383440]=c[3530762];c[2383441]=y;c[2383442]=z;c[2383436]=131071;c[2383437]=32767;c[2383438]=8191;a[690376]=1;z=c[642608+(c[2436]<<2)>>2]|0;y=c[z+128>>2]|0;if((c[z+52>>2]&4|0)==0){c[2113068]=y;x=c[z+132>>2]|0;c[2113070]=x;c[2443814]=y;c[2440436]=x;P=y;Q=x}else{c[2113070]=y;x=c[z+132>>2]|0;c[2113068]=x;c[2440436]=y;c[2443814]=x;P=x;Q=y}y=ag(P<<1,Q)|0;x=gGq(y)|0;c[2112926]=x;if((x|0)!=0){gGz(x|0,0,y|0)}c[2440448]=a[9634712]&128;y=c[2414566]|0;gGz(y|0,0,(c[2411476]|0)-y|0);gGz(9705864,0,184);c[2426481]=201326595;gGz(14125184,0,668);c[2433532]=0;c[2430402]=0;c[2113010]=0;a[9753304]=0;c[2433552]=0;gGz(c[2430036]|0,0,16384);c[3531316]=4;gGz(c[2430037]|0,0,16384);c[3531337]=4;gGz(c[2430038]|0,0,16384);c[3531358]=4;gGz(c[2430039]|0,0,16384);c[3531379]=4;gGz(c[2430040]|0,0,16384);c[3531400]=4;gGz(c[2430041]|0,0,16384);c[3531421]=4;gGz(c[2430042]|0,0,16384);c[3531442]=4;gGz(c[2430043]|0,0,16384);c[3531463]=4;c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];gGz(c[2383428]|0,0,4096);gGz(c[2383426]|0,0,4096);y=c[2383424]|0;if((y|0)!=0){gGz(y|0,0,4096);gGz(c[2383422]|0,0,4096)}gGz(c[2383434]|0,0,16);gGz(c[2383435]|0,0,16);gGz(c[2383430]|0,0,8192);gGz(c[2383431]|0,0,8192);y=c[2383432]|0;if((y|0)!=0){gGz(y|0,0,8192);gGz(c[2383433]|0,0,8192)}b[4766836]=0;c[2426968]=0;c[3528794]=0;c[1765522]=65535;c[2429656]=0;c[2427042]=0;c[2429386]=0;c[2429384]=0;c[2429382]=0;w=0;i=e;return w|0}}while(0);c[2414864]=0;w=1;i=e;return w|0}function aDo(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;i=i+128|0;d=b|0;e=c[c[642608+(c[2436]<<2)>>2]>>2]|0;be(d|0,128,179600,(f=i,i=i+24|0,c[f>>2]=9374064,c[f+8>>2]=47,c[f+16>>2]=e,f)|0)|0;i=f;a[1040128]=0;f=c[2420380]|0;e=c[f>>2]|0;g=c[f+4>>2]|0;f=fw(d|0,389440)|0;if((f|0)!=0){d=g>>3<<e&1023;cj(14100392,d|0,1,f|0)|0;aY(f|0)|0}f=c[2406730]|0;if((f|0)!=0){gGr(f);c[2406730]=0}f=c[2406728]|0;if((f|0)!=0){gGr(f);c[2406728]=0}f=c[2406726]|0;if((f|0)!=0){gGr(f);c[2406726]=0}f=c[2406694]|0;if((f|0)!=0){gGr(f);c[2406694]=0}c[3531294]=0;c[3531292]=0;c[2113070]=0;c[2113068]=0;f=c[2112926]|0;if((f|0)!=0){gGr(f);c[2112926]=0}aE2();f=c[2414864]|0;d=0;while(1){if((d|0)>=1024){h=23081;break}j=9638528+(d<<2)|0;if((c[j>>2]|0)==(f|0)){break}else{d=d+1|0}}if((h|0)==23081){c[2414864]=0;i=b;return 0}gGr(f);c[j>>2]=0;c[2414864]=0;i=b;return 0}function aDp(){var d=0,e=0,f=0,g=0;if((a[9623464]|0)!=0){d=c[2414566]|0;gGz(d|0,0,(c[2411476]|0)-d|0);gGz(9705864,0,184);c[2426481]=201326595;gGz(14125184,0,668);c[2433532]=0;c[2430402]=0;c[2113010]=0;a[9753304]=0;c[2433552]=0;gGz(c[2430036]|0,0,16384);c[3531316]=4;gGz(c[2430037]|0,0,16384);c[3531337]=4;gGz(c[2430038]|0,0,16384);c[3531358]=4;gGz(c[2430039]|0,0,16384);c[3531379]=4;gGz(c[2430040]|0,0,16384);c[3531400]=4;gGz(c[2430041]|0,0,16384);c[3531421]=4;gGz(c[2430042]|0,0,16384);c[3531442]=4;gGz(c[2430043]|0,0,16384);c[3531463]=4;c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];gGz(c[2383428]|0,0,4096);gGz(c[2383426]|0,0,4096);d=c[2383424]|0;if((d|0)!=0){gGz(d|0,0,4096);gGz(c[2383422]|0,0,4096)}gGz(c[2383434]|0,0,16);gGz(c[2383435]|0,0,16);gGz(c[2383430]|0,0,8192);gGz(c[2383431]|0,0,8192);d=c[2383432]|0;if((d|0)!=0){gGz(d|0,0,8192);gGz(c[2383433]|0,0,8192)}b[4766836]=0;c[2426968]=0;c[3528794]=0;c[1765522]=65535;c[2429656]=0;c[2427042]=0;c[2429386]=0;c[2429384]=0;c[2429382]=0}b[4775044]=255;b[4774944]=255;b[4774868]=-25;d=0;e=255;f=255;g=-25;do{e=((a[9632488+d|0]&1)<<d^e&65535)&65535;f=((a[9630400+d|0]&1)<<d^f&65535)&65535;g=((a[9630152+d|0]&1)<<d^g&65535)&65535;d=d+1|0;}while((d|0)<16);b[4775044]=e;b[4774944]=f;e=a[9634712]|0;b[4774868]=e&8|g;if(e<<24>>24<0){b[4774944]=f|128}c[2383408]=16;fyL(464426)|0;fx6();c[2383408]=0;fyL(2240)|0;f=c[2112964]|0;if((f|0)!=0){Ug(f,a[9688]|0?534:0)}if((c[2112968]|0)==0){return 0}aDq()|0;return 0}function aDq(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=a[9634712]&128;e=c[2440448]|0;do{if((d|0)!=0&(e|0)==0){c[2439520]=c[2112926];f=c[642608+(c[2436]<<2)>>2]|0;if((c[f+52>>2]&4|0)==0){c[f+128>>2]=320;c[f+132>>2]=240}else{c[f+132>>2]=320;c[f+128>>2]=240}c[f+136>>2]=4;c[f+140>>2]=3}else{if(!((d|0)==0&(e|0)==128)){break}c[2439520]=c[2438738];f=c[642608+(c[2436]<<2)>>2]|0;if((c[f+52>>2]&4|0)==0){c[f+128>>2]=640;c[f+132>>2]=240}else{c[f+132>>2]=640;c[f+128>>2]=240}c[f+136>>2]=8;c[f+140>>2]=3}}while(0);c[2440448]=d;d=c[2387110]|0;e=c[3529904]|0;f=0;do{g=c[d+(f<<2)>>2]|0;h=g>>>5&31;c[e+(f<<2)>>2]=g>>>10&31|g<<11&63488|(h<<3|h>>>2)<<3&2016;f=f+1|0;}while((f|0)<2048);aE3();aE5();f=(c[2440448]|0)==0;if(f){c[2113068]=320;i=320}else{i=c[2113068]|0}e=c[2113070]|0;d=ag(e,i)|0;i=(d|0)>0;if(i){h=c[2439520]|0;g=0;do{b[h+(g<<1)>>1]=256;g=g+1|0;}while((g|0)<(d|0))}g=c[2383420]|0;gGz(g|0,0,131072);h=c[2383410]|0;gGz(h|0,0,131072);j=c[2394704]|0;k=c[j>>2]|0;if((k|0)==0){l=c[2439520]|0;aE0(2,l,1);aE0(0,l,2);m=l}else if((k|0)==2){k=c[2439520]|0;aE0(0,k,2);aE0(2,k,4);m=k}else{m=c[2439520]|0}k=c[3530314]|0;aDu(m,c[3529660]|0,k,512);if(!f){n=c[3529904]|0;R8(n);return 0}if(i){i=c[2439518]|0;f=0;do{b[i+(f<<1)>>1]=1280;f=f+1|0;}while((f|0)<(d|0))}gGz(g|0,0,131072);gGz(h|0,0,131072);h=c[j+4>>2]|0;if((h|0)==0){j=c[2439518]|0;aE0(3,j,1);aE0(1,j,2);o=j}else if((h|0)==2){h=c[2439518]|0;aE0(1,h,2);aE0(3,h,4);o=h}else{o=c[2439518]|0}aDu(o,c[3529644]|0,k,1536);k=c[2112926]|0;if((e|0)>0){h=k;j=k+640|0;k=m;m=o;o=0;while(1){g=h;d=k;gGC(g|0,d|0,640)|0;d=j;g=m;gGC(d|0,g|0,640)|0;g=o+1|0;if((g|0)<(e|0)){h=h+1280|0;j=j+1280|0;k=k+640|0;m=m+640|0;o=g}else{break}}}c[2113068]=640;n=c[3529904]|0;R8(n);return 0}function aDr(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=i;i=i+48|0;e=d|0;f=d+16|0;g=d+32|0;if((b|0)!=0){c[b>>2]=169735}if((a&32|0)!=0){gGz(g|0,0,12);b=c[2414566]|0;c[g>>2]=b;c[g+4>>2]=(c[2411476]|0)-b;c[g+12>>2]=162152;b=c[2076592]|0;gj[b&4095](g)|0}if((a&64|0)==0){i=d;return 0}if((a&96|0)!=0){gGz(f|0,0,12);c[f>>2]=9705864;c[f+4>>2]=184;c[f+12>>2]=164440;a=c[2076592]|0;gj[a&4095](f)|0;gGz(e|0,0,12);c[e>>2]=14115384;c[e+4>>2]=4;c[e+12>>2]=501256;f=c[2076592]|0;gj[f&4095](e)|0}Ue();aE6();i=d;return 0}function aDs(){var a=0;a=c[3528846]|0;c[3528846]=(a|0)>1120?a-1120|0:0;return}function aDt(a){a=a|0;var b=0;b=a>>4;return(b>>>1&2|b&1|b<<1&4)<<12|0}function aDu(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=b;b=(c[2113222]&1|0)==0;g=1276;do{h=c[f+((g|1)<<2)>>2]&65535;i=c[f+(g<<2)>>2]|0;do{if((i&4096|0)==0|b){j=c[f+((g|2)<<2)>>2]|0;k=j>>>9;l=j&49152;if((l|0)==16384){m=240}else if((l|0)==32768){m=0}else if((l|0)==49152){m=240}else if((l|0)==0){m=0}else{m=l}l=1<<(i>>>9&3);n=l-1|0;o=j&511;p=i&511;q=o>>>0>319?j|-512:o;o=p>>>0>255?i|-512:p;if((304-q|0)>320){break}p=i&16384;j=((p|0)!=0?0:n)+(h&-l)|0;r=(p>>>13^2)-1|0;s=i>>>13&1^1;t=p>>>14^1;if((l|0)<=0){break}l=(k<<4&496)+e|0;k=n;while(1){aEY(a,d,j-(ag(k,r)|0)|0,l,q,(k<<4)+o|0,s,t,m,-1);if((k|0)>0){k=k-1|0}else{break}}}}while(0);g=g-4|0;}while((g|0)>-1);return}function aDv(d,e){d=d|0;e=e|0;var f=0,g=0;f=d&-16;if((f|0)==2359296){b[(c[2383435]|0)+((d>>>1&7)<<1)>>1]=e;return}else if((f|0)==2097152){b[(c[2383434]|0)+((d>>>1&7)<<1)>>1]=e;return}else{if((d|0)==3211274){f=c[2387302]|0;g=c[2387108]|0;gGC(f|0,g|0,8192)|0;return}else if((d|0)==3145728){g=c[3529668]|0;f=c[2386560]|0;gGC(g|0,f|0,2048)|0;g=c[2386390]|0;gGC(f|0,g|0,2048)|0;return}else if((d|0)==2621608){c[2383412]=e&255;if((a[9661085]|0)==1){return}a[9661085]=1;if((a[9661088]|0)!=0){return}a[9661088]=2;return}else if((d|0)==3281152){c[8452200+(c[2394]<<2)>>2]=0;c[2276080]=0;return}else if((d|0)==3284992){b[4766836]=e;return}else{if((d&268431360|0)!=2621440){return}g=d>>>1&1023;if((c[2426968]|0)==0){b[(c[2383414]|0)+(g<<1)>>1]=e}else{b[(c[2383444]|0)+(g<<1)>>1]=e}if((g|0)==33){c[3528794]=e&65535;return}else if((g|0)==119){c[1765522]=e&65535;return}else{return}}}}function aDw(d,f){d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;if((d|0)==3284992|(d|0)==3284993){b[4766836]=f&255;return}else if((d|0)==3145728|(d|0)==3145729){g=c[3529668]|0;h=c[2386560]|0;gGC(g|0,h|0,2048)|0;g=c[2386390]|0;gGC(h|0,g|0,2048)|0;return}else if((d|0)==3281152|(d|0)==3281153){c[8452200+(c[2394]<<2)>>2]=0;c[2276080]=0;return}else if((d|0)==2621609){c[2383412]=f&255;if((a[9661085]|0)==1){return}a[9661085]=1;if((a[9661088]|0)!=0){return}a[9661088]=2;return}else if((d|0)==3211274|(d|0)==3211275){g=c[2387302]|0;h=c[2387108]|0;gGC(g|0,h|0,8192)|0;return}else{if((d&268431360|0)!=2621440){return}h=f&255;g=255<<(d<<3&8);i=d>>>1&1023;d=(g|0)==65535;do{if((c[2426968]|0)==0){if(d){b[(c[2383414]|0)+(i<<1)>>1]=h;break}j=(c[2383414]|0)+(i<<1)|0;k=e[j>>1]&g;l=f&255;if((g|0)==65280){b[j>>1]=(k|l)&65535;break}else{b[j>>1]=(k|l<<8&(g^65535))&65535;break}}else{if(d){b[(c[2383444]|0)+(i<<1)>>1]=h;break}l=(c[2383444]|0)+(i<<1)|0;k=e[l>>1]&g;j=f&255;if((g|0)==65280){b[l>>1]=(k|j)&65535;break}else{b[l>>1]=(k|j<<8&(g^65535))&65535;break}}}while(0);if((i|0)==119){c[1765522]=f&255;return}else if((i|0)==33){c[3528794]=f&255;return}else{return}}}function aDx(a){a=a|0;var e=0;if((a|0)==2883584|(a|0)==3145728){e=d[9634706]|0;return e|0}else if((a|0)==3281152){c[8452200+(c[2394]<<2)>>2]=0;c[2276080]=0;e=0;return e|0}else if((a|0)==3211266){e=(b[4775093]&7|c[2383408]&8)&65535;return e|0}else{if((a&268431360|0)!=2621440){e=0;return e|0}e=aFn(a)|0;return e|0}return 0}function aDy(d){d=d|0;var e=0;if((d|0)==2883584|(d|0)==2883585|(d|0)==3145728|(d|0)==3145729){e=a[9634706]|0;return e|0}else if((d|0)==3281152|(d|0)==3281153){c[8452200+(c[2394]<<2)>>2]=0;c[2276080]=0;e=0;return e|0}else if((d|0)==3211266|(d|0)==3211267){e=(b[4775093]&7|c[2383408]&8)&255;return e|0}else{if((d&268431360|0)!=2621440){e=0;return e|0}e=((aFn(d)|0)&65535)>>>((d<<3&8^8)>>>0)&255;return e|0}return 0}function aDz(d,e){d=d|0;e=e|0;var f=0,g=0,h=0;f=d&-16;if((f|0)==3211264){b[(c[2383435]|0)+((d>>>1&7)<<1)>>1]=e;return}else if((f|0)==3145728){b[(c[2383434]|0)+((d>>>1&7)<<1)>>1]=e;return}else{if((d|0)==3276804){c[8452200+(c[2394]<<2)>>2]=0;c[2276080]=0;return}else if((d|0)==3670024){f=c[2387302]|0;g=c[2387108]|0;gGC(f|0,g|0,8192)|0;return}else if((d|0)==16662864|(d|0)==16728672|(d|0)==16730720){c[2383412]=e&255;if((a[9661085]|0)==1){return}a[9661085]=1;if((a[9661088]|0)!=0){return}a[9661088]=2;return}else if((d|0)==3473408){g=c[2386560]|0;f=c[2386390]|0;gGC(g|0,f|0,2048)|0;return}else if((d|0)==3276800){b[4766836]=e;return}else if((d|0)==3604480){f=c[3529668]|0;g=c[3529620]|0;gGC(f|0,g|0,2048)|0;return}else{g=d&268431360;if((g|0)==16728064){f=d&2046;h=e&65535;if((f|0)==832){c[3528794]=h}else if((f|0)==608){return}else if((f|0)==1728){c[1765522]=h}h=f>>>1;if((c[2426968]|0)==0){b[(c[2383414]|0)+(h<<1)>>1]=e;return}else{b[(c[2383444]|0)+(h<<1)>>1]=e;return}}else if((g|0)==16662528){b[(c[2383414]|0)+((d>>>1&1023)<<1)>>1]=e;return}else{return}}}}function aDA(d,f){d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((d|0)==3604480|(d|0)==3604481){g=c[3529668]|0;h=c[3529620]|0;gGC(g|0,h|0,2048)|0;return}else if((d|0)==3473408|(d|0)==3473409){h=c[2386560]|0;g=c[2386390]|0;gGC(h|0,g|0,2048)|0;return}else if((d|0)==3670024|(d|0)==3670025){g=c[2387302]|0;h=c[2387108]|0;gGC(g|0,h|0,8192)|0;return}else if((d|0)==3276804|(d|0)==3276805){c[8452200+(c[2394]<<2)>>2]=0;c[2276080]=0;return}else if((d|0)==16662865|(d|0)==16728673|(d|0)==16730721){c[2383412]=f&255;if((a[9661085]|0)==1){return}a[9661085]=1;if((a[9661088]|0)!=0){return}a[9661088]=2;return}else if((d|0)==3276800|(d|0)==3276801){b[4766836]=f&255;return}else{h=d&268431360;if((h|0)==16728064){g=255<<(d<<3&8);i=d&2046;j=f&255;if((i|0)==608){return}else if((i|0)==832){c[3528794]=j}else if((i|0)==1728){c[1765522]=j}k=i>>>1;i=(g|0)==65535;if((c[2426968]|0)==0){if(i){b[(c[2383414]|0)+(k<<1)>>1]=f&255;return}l=(c[2383414]|0)+(k<<1)|0;m=e[l>>1]&g;if((g|0)==65280){b[l>>1]=(m|j)&65535;return}else{b[l>>1]=(m|(g^65280)&j<<8)&65535;return}}else{if(i){b[(c[2383444]|0)+(k<<1)>>1]=f&255;return}i=(c[2383444]|0)+(k<<1)|0;k=e[i>>1]&g;if((g|0)==65280){b[i>>1]=(k|j)&65535;return}else{b[i>>1]=(k|(g^65280)&j<<8)&65535;return}}}else if((h|0)==16662528){a[(c[2387038]|0)+(d&2047^1)|0]=f;return}else{return}}}function aDB(a){a=a|0;var c=0;do{if((a|0)==3276800){c=b[4775094]|0}else{if((a&268433408|0)==16662528){c=aFo(a)|0;break}if((a&268431360|0)!=16728064){c=0;break}c=aFp(a&2046)|0}}while(0);return c|0}function aDC(a){a=a|0;var b=0;if((a-3276800|0)>>>0<2){b=(e[4775094]|0)>>>((a<<3&8^8)>>>0)&255;return b|0}if((a&268433408|0)==16662528){b=((aFo(a)|0)&65535)>>>((a<<3&8^8)>>>0)&255;return b|0}if((a&268431360|0)!=16728064){b=0;return b|0}b=((aFp(a&2046)|0)&65535)>>>((a<<3&8^8)>>>0)&255;return b|0}function aDD(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6492324+(b*112|0)>>2];c[a+104>>2]=c[6492328+(b*112|0)>>2];c[a+108>>2]=c[6492332+(b*112|0)>>2];d=0;return d|0}function aDE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=6492224+(b*112|0);e=0;return e|0}function aDF(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5095736+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aDG(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>55){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6810192+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aDH(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0;e=i;i=i+1560|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;B=e+1200|0;C=e+1312|0;D=e+1320|0;E=e+1432|0;F=e+1440|0;G=e+1552|0;c[2424]=5800;c[2414862]=0;c[2388082]=0;c[2387778]=2097152;c[3530760]=2162688;c[3530524]=2686976;c[3530392]=6881280;c[3530312]=11075584;c[3530298]=19464192;c[3541206]=20512768;c[3529780]=20512768;c[3529734]=21561344;c[2388468]=22347776;c[2388464]=22501376;c[3529902]=22654976;c[2414564]=22663168;c[2388212]=22663168;c[2387800]=22810624;c[3529620]=22818816;c[2386390]=22820864;c[3529668]=22822912;c[2386560]=22824960;c[2383414]=22827008;c[2387038]=22827008;c[2383444]=22829056;c[2387108]=22831104;c[2387302]=22839296;c[3528660]=22847488;c[2411464]=22847489;H=0;while(1){if((H|0)>=1024){break}I=9638528+(H<<2)|0;if((c[I>>2]|0)==0){J=23380;break}else{H=H+1|0}}do{if((J|0)==23380){H=gGq(22847489)|0;c[I>>2]=H;if((H|0)==0){break}c[2414862]=H;gGz(H|0,0,22847489);c[2388082]=H;c[2387778]=H+2097152;c[3530760]=H+2162688;c[3530524]=H+2686976;c[3530392]=H+6881280;c[3530312]=H+11075584;c[3530298]=H+19464192;K=H+20512768|0;c[3541206]=K;c[3529780]=K;c[3529734]=H+21561344;c[2388468]=H+22347776;c[2388464]=H+22501376;c[3529902]=H+22654976;K=H+22663168|0;c[2414564]=K;c[2388212]=K;c[2387800]=H+22810624;c[3529620]=H+22818816;c[2386390]=H+22820864;c[3529668]=H+22822912;c[2386560]=H+22824960;K=H+22827008|0;c[2383414]=K;c[2387038]=K;c[2383444]=H+22829056;c[2387108]=H+22831104;c[2387302]=H+22839296;c[3528660]=H+22847488;K=H+22847489|0;c[2411464]=K;c[2414004]=K;if((R6(H+1|0,0,2)|0)!=0){L=1;i=e;return L|0}if((R6(c[2388082]|0,1,2)|0)!=0){L=1;i=e;return L|0}if((R6((c[2388082]|0)+1048577|0,2,2)|0)!=0){L=1;i=e;return L|0}if((R6((c[2388082]|0)+1048576|0,3,2)|0)!=0){L=1;i=e;return L|0}H=c[2387778]|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}K=F+108|0;c[K>>2]=0;M=F+100|0;c[M>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](F,4)|0;do{if((c[K>>2]|0)!=0){N=c[M>>2]|0;c[G>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](G,4,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(H,0,4)|0)==0){break}else{L=1}i=e;return L|0}}while(0);if((R6(c[3530760]|0,5,2)|0)!=0){L=1;i=e;return L|0}if((R6((c[3530760]|0)+1|0,6,2)|0)!=0){L=1;i=e;return L|0}H=c[3530524]|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}M=D+108|0;c[M>>2]=0;K=D+100|0;c[K>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](D,7)|0;do{if((c[M>>2]|0)!=0){N=c[K>>2]|0;c[E>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](E,7,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(H,0,7)|0)==0){break}else{L=1}i=e;return L|0}}while(0);H=(c[3530524]|0)+524288|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}K=B+108|0;c[K>>2]=0;M=B+100|0;c[M>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](B,8)|0;do{if((c[K>>2]|0)!=0){N=c[M>>2]|0;c[C>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](C,8,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(H,0,8)|0)==0){break}else{L=1}i=e;return L|0}}while(0);H=c[3530392]|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}M=z+108|0;c[M>>2]=0;K=z+100|0;c[K>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](z,9)|0;do{if((c[M>>2]|0)!=0){N=c[K>>2]|0;c[A>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](A,9,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(H,0,9)|0)==0){break}else{L=1}i=e;return L|0}}while(0);H=(c[3530392]|0)+1048576|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}K=x+108|0;c[K>>2]=0;M=x+100|0;c[M>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](x,10)|0;do{if((c[K>>2]|0)!=0){N=c[M>>2]|0;c[y>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](y,10,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(H,0,10)|0)==0){break}else{L=1}i=e;return L|0}}while(0);H=c[3530312]|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}M=v+108|0;c[M>>2]=0;K=v+100|0;c[K>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](v,11)|0;do{if((c[M>>2]|0)!=0){N=c[K>>2]|0;c[w>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](w,11,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(H,0,11)|0)==0){break}else{L=1}i=e;return L|0}}while(0);H=(c[3530312]|0)+1048576|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}K=t+108|0;c[K>>2]=0;M=t+100|0;c[M>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](t,12)|0;do{if((c[K>>2]|0)!=0){N=c[M>>2]|0;c[u>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](u,12,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(H,0,12)|0)==0){break}else{L=1}i=e;return L|0}}while(0);H=(c[3530312]|0)+2097152|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}M=r+108|0;c[M>>2]=0;K=r+100|0;c[K>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](r,13)|0;do{if((c[M>>2]|0)!=0){N=c[K>>2]|0;c[s>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](s,13,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(H,0,13)|0)==0){break}else{L=1}i=e;return L|0}}while(0);H=(c[3530312]|0)+3145728|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}K=p+108|0;c[K>>2]=0;M=p+100|0;c[M>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](p,14)|0;do{if((c[K>>2]|0)!=0){N=c[M>>2]|0;c[q>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](q,14,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(H,0,14)|0)==0){break}else{L=1}i=e;return L|0}}while(0);H=(c[3530312]|0)+4194304|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}M=n+108|0;c[M>>2]=0;K=n+100|0;c[K>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](n,15)|0;do{if((c[M>>2]|0)!=0){N=c[K>>2]|0;c[o>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](o,15,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(H,0,15)|0)==0){break}else{L=1}i=e;return L|0}}while(0);H=(c[3530312]|0)+5242880|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}K=l+108|0;c[K>>2]=0;M=l+100|0;c[M>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](l,16)|0;do{if((c[K>>2]|0)!=0){N=c[M>>2]|0;c[m>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](m,16,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(H,0,16)|0)==0){break}else{L=1}i=e;return L|0}}while(0);H=(c[3529780]|0)+262144|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}M=j+108|0;c[M>>2]=0;K=j+100|0;c[K>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](j,17)|0;do{if((c[M>>2]|0)!=0){N=c[K>>2]|0;c[k>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](k,17,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(H,0,17)|0)==0){break}else{L=1}i=e;return L|0}}while(0);H=(c[3529734]|0)+262144|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}K=f+108|0;c[K>>2]=0;M=f+100|0;c[M>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](f,18)|0;do{if((c[K>>2]|0)!=0){N=c[M>>2]|0;c[g>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](g,18,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(H,0,18)|0)==0){break}else{L=1}i=e;return L|0}}while(0);aFg(c[3530760]|0,131072,1574056,720536,1110256);aFg(c[3530524]|0,1048576,1574056,720536,1110256);H=c[3530760]|0;aE_(H,H,131072,1);H=c[3530524]|0;aE_(H,H,1048576,0);H=c[3530392]|0;aE_(H,H,2097152,0);H=0;while(1){if((H|0)>=1024){break}P=9638528+(H<<2)|0;if((c[P>>2]|0)==0){J=23443;break}else{H=H+1|0}}L29987:do{if((J|0)==23443){H=gGq(6291456)|0;c[P>>2]=H;if((H|0)==0){break}gGz(H|0,0,6291456);M=c[3530312]|0;gGC(H|0,M|0,6291456)|0;K=0;while(1){N=K<<8;gGz(M+N|0,0,256);O=K<<9;Q=0;do{R=1<<5-Q;S=(c[602608+(Q<<2)>>2]|0)+O|0;T=0;do{U=S+(c[608752+(T<<2)>>2]|0)|0;V=(T<<4)+N|0;W=0;do{X=U+(c[598384+(W<<2)>>2]|0)|0;if(((d[H+((X|0)/8|0)|0]|0)&128>>>((X&7)>>>0)|0)!=0){X=M+(V+W)|0;a[X]=(d[X]|0|R)&255}W=W+1|0;}while((W|0)<16);T=T+1|0;}while((T|0)<16);Q=Q+1|0;}while((Q|0)<6);Q=K+1|0;if((Q|0)<32768){K=Q}else{Y=0;break}}while(1){if((Y|0)>=1024){break L29987}Z=9638528+(Y<<2)|0;if((c[Z>>2]|0)==(H|0)){break}else{Y=Y+1|0}}gGr(H);c[Z>>2]=0}}while(0);aE1(0,0,1);K=c[3530524]|0;M=c[3530392]|0;c[2383440]=c[3530760];c[2383441]=K;c[2383442]=M;c[2383436]=4095;c[2383437]=8191;c[2383438]=16383;c[2429668]=512;c[2429669]=768;a[690376]=1;c[2429436]=1840;c[2429437]=1840;c[2429438]=1840;c[2429439]=1840;fxU(0,425984);if((c[2394]|0)==0){_=c[2112932]|0}else{c[2394]=0;M=c[3532596]|0;c[2112932]=M;K=c[3532592]|0;if((K|0)!=0){gGC(9104152,K|0,280)|0}c[2113054]=c[2113060];_=M}M=c[2388082]|0;K=_|0;Q=0;while(1){N=M+Q|0;c[K>>2]=N;c[K+131072>>2]=N;N=Q+1024|0;if(N>>>0>2097151){break}else{K=K+4|0;Q=N}}Q=c[2383430]|0;c[_+15360>>2]=Q;c[_+80896>>2]=Q;c[_+146432>>2]=Q;K=Q+1024|0;c[_+15364>>2]=K;c[_+80900>>2]=K;c[_+146436>>2]=K;K=Q+2048|0;c[_+15368>>2]=K;c[_+80904>>2]=K;c[_+146440>>2]=K;K=Q+3072|0;c[_+15372>>2]=K;c[_+80908>>2]=K;c[_+146444>>2]=K;K=Q+4096|0;c[_+15376>>2]=K;c[_+80912>>2]=K;c[_+146448>>2]=K;K=Q+5120|0;c[_+15380>>2]=K;c[_+80916>>2]=K;c[_+146452>>2]=K;K=Q+6144|0;c[_+15384>>2]=K;c[_+80920>>2]=K;c[_+146456>>2]=K;K=Q+7168|0;c[_+15388>>2]=K;c[_+80924>>2]=K;c[_+146460>>2]=K;K=c[2383431]|0;c[_+15392>>2]=K;c[_+80928>>2]=K;c[_+146464>>2]=K;Q=K+1024|0;c[_+15396>>2]=Q;c[_+80932>>2]=Q;c[_+146468>>2]=Q;Q=K+2048|0;c[_+15400>>2]=Q;c[_+80936>>2]=Q;c[_+146472>>2]=Q;Q=K+3072|0;c[_+15404>>2]=Q;c[_+80940>>2]=Q;c[_+146476>>2]=Q;Q=c[2383432]|0;c[_+15424>>2]=Q;c[_+80960>>2]=Q;c[_+146496>>2]=Q;K=Q+1024|0;c[_+15428>>2]=K;c[_+80964>>2]=K;c[_+146500>>2]=K;K=Q+2048|0;c[_+15432>>2]=K;c[_+80968>>2]=K;c[_+146504>>2]=K;K=Q+3072|0;c[_+15436>>2]=K;c[_+80972>>2]=K;c[_+146508>>2]=K;K=c[2383433]|0;c[_+15456>>2]=K;c[_+80992>>2]=K;c[_+146528>>2]=K;Q=K+1024|0;c[_+15460>>2]=Q;c[_+80996>>2]=Q;c[_+146532>>2]=Q;Q=K+2048|0;c[_+15464>>2]=Q;c[_+81e3>>2]=Q;c[_+146536>>2]=Q;Q=K+3072|0;c[_+15468>>2]=Q;c[_+81004>>2]=Q;c[_+146540>>2]=Q;Q=c[2383428]|0;c[_+15488>>2]=Q;c[_+81024>>2]=Q;c[_+146560>>2]=Q;K=Q+1024|0;c[_+15492>>2]=K;c[_+81028>>2]=K;c[_+146564>>2]=K;M=Q+2048|0;c[_+15496>>2]=M;c[_+81032>>2]=M;c[_+146568>>2]=M;N=Q+3072|0;c[_+15500>>2]=N;c[_+81036>>2]=N;c[_+146572>>2]=N;c[_+15504>>2]=Q;c[_+81040>>2]=Q;c[_+146576>>2]=Q;c[_+15508>>2]=K;c[_+81044>>2]=K;c[_+146580>>2]=K;c[_+15512>>2]=M;c[_+81048>>2]=M;c[_+146584>>2]=M;c[_+15516>>2]=N;c[_+81052>>2]=N;c[_+146588>>2]=N;N=c[2383426]|0;c[_+15520>>2]=N;c[_+81056>>2]=N;c[_+146592>>2]=N;M=N+1024|0;c[_+15524>>2]=M;c[_+81060>>2]=M;c[_+146596>>2]=M;K=N+2048|0;c[_+15528>>2]=K;c[_+81064>>2]=K;c[_+146600>>2]=K;Q=N+3072|0;c[_+15532>>2]=Q;c[_+81068>>2]=Q;c[_+146604>>2]=Q;c[_+15536>>2]=N;c[_+81072>>2]=N;c[_+146608>>2]=N;c[_+15540>>2]=M;c[_+81076>>2]=M;c[_+146612>>2]=M;c[_+15544>>2]=K;c[_+81080>>2]=K;c[_+146616>>2]=K;c[_+15548>>2]=Q;c[_+81084>>2]=Q;c[_+146620>>2]=Q;Q=c[2383424]|0;c[_+15552>>2]=Q;c[_+81088>>2]=Q;c[_+146624>>2]=Q;K=Q+1024|0;c[_+15556>>2]=K;c[_+81092>>2]=K;c[_+146628>>2]=K;M=Q+2048|0;c[_+15560>>2]=M;c[_+81096>>2]=M;c[_+146632>>2]=M;N=Q+3072|0;c[_+15564>>2]=N;c[_+81100>>2]=N;c[_+146636>>2]=N;c[_+15568>>2]=Q;c[_+81104>>2]=Q;c[_+146640>>2]=Q;c[_+15572>>2]=K;c[_+81108>>2]=K;c[_+146644>>2]=K;c[_+15576>>2]=M;c[_+81112>>2]=M;c[_+146648>>2]=M;c[_+15580>>2]=N;c[_+81116>>2]=N;c[_+146652>>2]=N;N=c[2383422]|0;c[_+15584>>2]=N;c[_+81120>>2]=N;c[_+146656>>2]=N;M=N+1024|0;c[_+15588>>2]=M;c[_+81124>>2]=M;c[_+146660>>2]=M;K=N+2048|0;c[_+15592>>2]=K;c[_+81128>>2]=K;c[_+146664>>2]=K;Q=N+3072|0;c[_+15596>>2]=Q;c[_+81132>>2]=Q;c[_+146668>>2]=Q;c[_+15600>>2]=N;c[_+81136>>2]=N;c[_+146672>>2]=N;c[_+15604>>2]=M;c[_+81140>>2]=M;c[_+146676>>2]=M;c[_+15608>>2]=K;c[_+81144>>2]=K;c[_+146680>>2]=K;c[_+15612>>2]=Q;c[_+81148>>2]=Q;c[_+146684>>2]=Q;Q=c[2386390]|0;c[_+15616>>2]=Q;c[_+81152>>2]=Q;c[_+146688>>2]=Q;K=Q+1024|0;c[_+15620>>2]=K;c[_+81156>>2]=K;c[_+146692>>2]=K;K=c[2387108]|0;c[_+15872>>2]=K;c[_+81408>>2]=K;c[_+146944>>2]=K;Q=K+1024|0;c[_+15876>>2]=Q;c[_+81412>>2]=Q;c[_+146948>>2]=Q;Q=K+2048|0;c[_+15880>>2]=Q;c[_+81416>>2]=Q;c[_+146952>>2]=Q;Q=K+3072|0;c[_+15884>>2]=Q;c[_+81420>>2]=Q;c[_+146956>>2]=Q;Q=K+4096|0;c[_+15888>>2]=Q;c[_+81424>>2]=Q;c[_+146960>>2]=Q;Q=K+5120|0;c[_+15892>>2]=Q;c[_+81428>>2]=Q;c[_+146964>>2]=Q;Q=K+6144|0;c[_+15896>>2]=Q;c[_+81432>>2]=Q;c[_+146968>>2]=Q;Q=K+7168|0;c[_+15900>>2]=Q;c[_+81436>>2]=Q;c[_+146972>>2]=Q;Q=c[2388212]|0;c[_+16128>>2]=Q;c[_+81664>>2]=Q;c[_+147200>>2]=Q;K=Q+1024|0;c[_+16132>>2]=K;c[_+81668>>2]=K;c[_+147204>>2]=K;K=Q+2048|0;c[_+16136>>2]=K;c[_+81672>>2]=K;c[_+147208>>2]=K;K=Q+3072|0;c[_+16140>>2]=K;c[_+81676>>2]=K;c[_+147212>>2]=K;K=Q+4096|0;c[_+16144>>2]=K;c[_+81680>>2]=K;c[_+147216>>2]=K;K=Q+5120|0;c[_+16148>>2]=K;c[_+81684>>2]=K;c[_+147220>>2]=K;K=Q+6144|0;c[_+16152>>2]=K;c[_+81688>>2]=K;c[_+147224>>2]=K;K=Q+7168|0;c[_+16156>>2]=K;c[_+81692>>2]=K;c[_+147228>>2]=K;K=Q+8192|0;c[_+16160>>2]=K;c[_+81696>>2]=K;c[_+147232>>2]=K;K=Q+9216|0;c[_+16164>>2]=K;c[_+81700>>2]=K;c[_+147236>>2]=K;K=Q+10240|0;c[_+16168>>2]=K;c[_+81704>>2]=K;c[_+147240>>2]=K;K=Q+11264|0;c[_+16172>>2]=K;c[_+81708>>2]=K;c[_+147244>>2]=K;K=Q+12288|0;c[_+16176>>2]=K;c[_+81712>>2]=K;c[_+147248>>2]=K;K=Q+13312|0;c[_+16180>>2]=K;c[_+81716>>2]=K;c[_+147252>>2]=K;K=Q+14336|0;c[_+16184>>2]=K;c[_+81720>>2]=K;c[_+147256>>2]=K;K=Q+15360|0;c[_+16188>>2]=K;c[_+81724>>2]=K;c[_+147260>>2]=K;K=c[2112932]|0;c[K+196728>>2]=1042;c[K+196648>>2]=1908;c[K+196688>>2]=930;c[K+196608>>2]=910;K=c[2394]|0;Q=c[14130368+(K<<2)>>2]|0;if((Q|0)!=0){gGC(Q|0,9104152,280)|0}c[8452240+(K<<2)>>2]=c[2113054];c[2394]=-1;aE8(c[2387778]|0,c[2387800]|0,2685e3,0,2332,.78,1006875,1.0,2013750,.4);h[745421]=.78;c[2436794]=1;h[745420]=.78;c[2436792]=2;K=c[642608+(c[2436]<<2)>>2]|0;Q=c[K+128>>2]|0;if((c[K+52>>2]&4|0)==0){c[2113068]=Q;M=c[K+132>>2]|0;c[2113070]=M;c[2443814]=Q;c[2440436]=M;$=Q;aa=M}else{c[2113070]=Q;M=c[K+132>>2]|0;c[2113068]=M;c[2440436]=Q;c[2443814]=M;$=M;aa=Q}Q=ag($<<1,aa)|0;M=gGq(Q)|0;c[2112926]=M;if((M|0)!=0){gGz(M|0,0,Q|0)}Q=c[2414564]|0;gGz(Q|0,0,(c[2411464]|0)-Q|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];Q=c[3532592]|0;if((Q|0)!=0){gGC(9104152,Q|0,280)|0}c[2113054]=c[2113060]}RI();Q=c[2394]|0;M=c[14130368+(Q<<2)>>2]|0;if((M|0)!=0){gGC(M|0,9104152,280)|0}c[8452240+(Q<<2)>>2]=c[2113054];c[2394]=-1;aE7();gGz(c[2383428]|0,0,4096);gGz(c[2383426]|0,0,4096);Q=c[2383424]|0;if((Q|0)!=0){gGz(Q|0,0,4096);gGz(c[2383422]|0,0,4096)}gGz(c[2383434]|0,0,16);gGz(c[2383435]|0,0,16);gGz(c[2383430]|0,0,8192);gGz(c[2383431]|0,0,8192);Q=c[2383432]|0;if((Q|0)!=0){gGz(Q|0,0,8192);gGz(c[2383433]|0,0,8192)}b[4766836]=0;c[2426968]=0;c[3528794]=0;c[1765522]=65535;c[2429656]=0;c[2427042]=0;c[2429386]=0;c[2429384]=0;c[2429382]=0;c[3530258]=3;L=0;i=e;return L|0}}while(0);c[2414862]=0;L=1;i=e;return L|0}function aDI(){var a=0,b=0,d=0,e=0,f=0;c[2113070]=0;c[2113068]=0;a=c[2112926]|0;if((a|0)!=0){gGr(a);c[2112926]=0}aE2();if((c[2392]|0)>=0){a=0;do{b=14130368+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}b=14130384+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}a=a+1|0;}while((a|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;aFe();a=c[2414862]|0;b=0;while(1){if((b|0)>=1024){e=23543;break}f=9638528+(b<<2)|0;if((c[f>>2]|0)==(a|0)){break}else{b=b+1|0}}if((e|0)==23543){c[2414862]=0;return 0}gGr(a);c[f>>2]=0;c[2414862]=0;return 0}function aDJ(){var e=0,f=0,g=0,h=0,i=0,j=0;if((a[9623432]|0)!=0){e=c[2414564]|0;gGz(e|0,0,(c[2411464]|0)-e|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060]}RI();e=c[2394]|0;f=c[14130368+(e<<2)>>2]|0;if((f|0)!=0){gGC(f|0,9104152,280)|0}c[8452240+(e<<2)>>2]=c[2113054];c[2394]=-1;aE7();gGz(c[2383428]|0,0,4096);gGz(c[2383426]|0,0,4096);e=c[2383424]|0;if((e|0)!=0){gGz(e|0,0,4096);gGz(c[2383422]|0,0,4096)}gGz(c[2383434]|0,0,16);gGz(c[2383435]|0,0,16);gGz(c[2383430]|0,0,8192);gGz(c[2383431]|0,0,8192);e=c[2383432]|0;if((e|0)!=0){gGz(e|0,0,8192);gGz(c[2383433]|0,0,8192)}b[4766836]=0;c[2426968]=0;c[3528794]=0;c[1765522]=65535;c[2429656]=0;c[2427042]=0;c[2429386]=0;c[2429384]=0;c[2429382]=0;c[3530258]=3}c[2383416]=9550184;e=9550184;c[e>>2]=-1;c[e+4>>2]=-1;e=0;f=-1;g=-1;h=-1;do{f=((a[9632448+e|0]&1)<<e^f&65535)&65535;g=((a[9630360+e|0]&1)<<e^g&65535)&65535;h=((a[9629192+e|0]&1)<<e^h&65535)&65535;e=e+1|0;}while((e|0)<16);b[4775092]=f;b[4775093]=g;b[4775095]=h;b[4775094]=d[9634705]<<8|d[9634704];c[(c[2391608]|0)+60>>2]=0;c[(c[2391608]|0)+60>>2]=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];h=c[3532592]|0;if((h|0)!=0){gGC(9104152,h|0,280)|0}c[2113054]=c[2113060]}c[2388530]=9554128;h=c[2391608]|0;if((h|0)!=0){g=h;gGC(9661040,g|0,68)|0}c[2382]=0;c[2383408]=0;g=0;h=0;while(1){c[2113056]=942;f=RG(942)|0;c[2113054]=(c[2113054]|0)+f;c[2276108]=-1;c[2113056]=-1;fy_(180)|0;if((g|0)==240){c[2383408]=8}f=c[2112964]|0;if((f|0)==0){i=h}else{e=a[9688]|0?2:0;j=f+(h<<1<<1)|0;if(a[801408]|0){gg[c[3542124]&4095](j,e)}if(a[801400]|0){Uu(0,j,e)}if((c[2429658]|0)!=0){Uu(1,j,e)}i=e+h|0}e=g+1|0;if((e|0)<256){g=e;h=i}else{break}}c[8452200+(c[2394]<<2)>>2]=4102;c[2276080]=1536;if((c[2276079]|0)>>>0<1536){RH(6)}h=c[2112964]|0;do{if((h|0)!=0){g=a[9688]|0?534:0;if((g|0)==(i|0)){break}e=g-i|0;g=h+(i<<1<<1)|0;if(a[801408]|0){gg[c[3542124]&4095](g,e)}if(a[801400]|0){Uu(0,g,e)}if((c[2429658]|0)==0){break}Uu(1,g,e)}}while(0);i=c[(c[2388530]|0)+12304>>2]|0;if((i|0)!=0){h=i;gGC(h|0,9661040,68)|0}c[2382]=-1;h=c[2394]|0;i=c[14130368+(h<<2)>>2]|0;if((i|0)!=0){gGC(i|0,9104152,280)|0}c[8452240+(h<<2)>>2]=c[2113054];c[2394]=-1;if((c[2112968]|0)==0){return 0}h=c[(c[642608+(c[2436]<<2)>>2]|0)+112>>2]|0;if((h|0)==0){return 0}gD[h&8191]()|0;return 0}function aDK(){aEk(0);return 0}function aDL(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=i;i=i+80|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;if((d|0)!=0){c[d>>2]=169762}if((b&32|0)!=0){gGz(k|0,0,12);l=c[2414564]|0;c[k>>2]=l;c[k+4>>2]=(c[2411464]|0)-l;c[k+12>>2]=162152;l=c[2076592]|0;gj[l&4095](k)|0}if((b&64|0)==0){i=e;return 0}k=h|0;gGz(g|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){l=h+9|0;h=f;m=f|0;n=f+4|0;o=f+12|0;p=g|0;q=g+4|0;r=g+12|0;s=0;do{gGC(k|0,614896,11)|0;a[l]=s+48&255;t=8452256+(s<<2)|0;gGz(h|0,0,12);c[m>>2]=t;c[n>>2]=4;c[o>>2]=164976;gj[c[2076592]&4095](f)|0;if((c[t>>2]|0)!=0){c[p>>2]=c[14130368+(s<<2)>>2];c[q>>2]=c[8452184+(s<<2)>>2];c[r>>2]=k;t=c[2076592]|0;gj[t&4095](g)|0}s=s+1|0;}while((s|0)<=(c[2392]|0))}aFf(b,d);aE6();gGz(j|0,0,12);c[j>>2]=14121032;c[j+4>>2]=4;c[j+12>>2]=491248;gj[c[2076592]&4095](j)|0;j=c[3530258]|0;c[3530258]=-1;if((j&1|0)==0){d=c[3529780]|0;b=d+262144|0;gGC(d|0,b|0,262144)|0}if((j&2|0)==0){b=c[3529734]|0;d=b+262144|0;gGC(b|0,d|0,262144)|0}c[3530258]=j;i=e;return 0}function aDM(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5724308+(b*112|0)>>2];c[a+104>>2]=c[5724312+(b*112|0)>>2];c[a+108>>2]=c[5724316+(b*112|0)>>2];d=0;return d|0}function aDN(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=5724208+(b*112|0);e=0;return e|0}function aDO(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5722068+(b*112|0)>>2];c[a+104>>2]=c[5722072+(b*112|0)>>2];c[a+108>>2]=c[5722076+(b*112|0)>>2];d=0;return d|0}function aDP(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=5721968+(b*112|0);e=0;return e|0}function aDQ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5719828+(b*112|0)>>2];c[a+104>>2]=c[5719832+(b*112|0)>>2];c[a+108>>2]=c[5719836+(b*112|0)>>2];d=0;return d|0}function aDR(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=5719728+(b*112|0);e=0;return e|0}function aDS(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5717588+(b*112|0)>>2];c[a+104>>2]=c[5717592+(b*112|0)>>2];c[a+108>>2]=c[5717596+(b*112|0)>>2];d=0;return d|0}function aDT(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=5717488+(b*112|0);e=0;return e|0}function aDU(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2079764+(b*112|0)>>2];c[a+104>>2]=c[2079768+(b*112|0)>>2];c[a+108>>2]=c[2079772+(b*112|0)>>2];d=0;return d|0}function aDV(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=2079664+(b*112|0);e=0;return e|0}function aDW(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2085812+(b*112|0)>>2];c[a+104>>2]=c[2085816+(b*112|0)>>2];c[a+108>>2]=c[2085820+(b*112|0)>>2];d=0;return d|0}function aDX(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<22&(d|0)==0)){e=1;return e|0}c[a>>2]=2085712+(b*112|0);e=0;return e|0}function aDY(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1173648+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aDZ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>43){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3246720+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aD_(){var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;d=i;i=i+840|0;e=d|0;f=d+112|0;g=d+120|0;j=d+232|0;k=d+240|0;l=d+352|0;m=d+360|0;n=d+472|0;o=d+480|0;p=d+592|0;q=d+600|0;r=d+712|0;s=d+720|0;t=d+832|0;c[2424]=5800;c[2414862]=0;c[2388082]=0;c[2387778]=2097152;c[3530760]=2162688;c[3530524]=2686976;c[3530392]=6881280;c[3530312]=11075584;c[3530298]=19464192;c[3541206]=20512768;c[3529780]=20512768;c[3529734]=21561344;c[2388468]=22347776;c[2388464]=22501376;c[3529902]=22654976;c[2414564]=22663168;c[2388212]=22663168;c[2387800]=22810624;c[3529620]=22818816;c[2386390]=22820864;c[3529668]=22822912;c[2386560]=22824960;c[2383414]=22827008;c[2387038]=22827008;c[2383444]=22829056;c[2387108]=22831104;c[2387302]=22839296;c[3528660]=22847488;c[2411464]=22847489;u=0;while(1){if((u|0)>=1024){break}v=9638528+(u<<2)|0;if((c[v>>2]|0)==0){w=23706;break}else{u=u+1|0}}do{if((w|0)==23706){u=gGq(22847489)|0;c[v>>2]=u;if((u|0)==0){break}c[2414862]=u;gGz(u|0,0,22847489);c[2388082]=u;c[2387778]=u+2097152;c[3530760]=u+2162688;c[3530524]=u+2686976;c[3530392]=u+6881280;c[3530312]=u+11075584;c[3530298]=u+19464192;x=u+20512768|0;c[3541206]=x;c[3529780]=x;c[3529734]=u+21561344;c[2388468]=u+22347776;c[2388464]=u+22501376;c[3529902]=u+22654976;x=u+22663168|0;c[2414564]=x;c[2388212]=x;c[2387800]=u+22810624;c[3529620]=u+22818816;c[2386390]=u+22820864;c[3529668]=u+22822912;c[2386560]=u+22824960;x=u+22827008|0;c[2383414]=x;c[2387038]=x;c[2383444]=u+22829056;c[2387108]=u+22831104;c[2387302]=u+22839296;c[3528660]=u+22847488;x=u+22847489|0;c[2411464]=x;c[2414004]=x;if((R6(u+1|0,0,2)|0)!=0){y=1;i=d;return y|0}if((R6(c[2388082]|0,1,2)|0)!=0){y=1;i=d;return y|0}if((R6((c[2388082]|0)+262145|0,2,2)|0)!=0){y=1;i=d;return y|0}if((R6((c[2388082]|0)+262144|0,3,2)|0)!=0){y=1;i=d;return y|0}if((R6((c[2388082]|0)+524289|0,4,2)|0)!=0){y=1;i=d;return y|0}if((R6((c[2388082]|0)+524288|0,5,2)|0)!=0){y=1;i=d;return y|0}u=c[2387778]|0;if((c[3542200]|0)==0){y=1;i=d;return y|0}x=s+108|0;c[x>>2]=0;z=s+100|0;c[z>>2]=0;A=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[A&16383](s,6)|0;do{if((c[x>>2]|0)!=0){A=c[z>>2]|0;c[t>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](t,6,0)|0;if((A|0)<1){y=1;i=d;return y|0}if((gzL(u,0,6)|0)==0){break}else{y=1}i=d;return y|0}}while(0);if((R6(c[3530760]|0,7,2)|0)!=0){y=1;i=d;return y|0}if((R6((c[3530760]|0)+1|0,8,2)|0)!=0){y=1;i=d;return y|0}u=c[3530524]|0;if((c[3542200]|0)==0){y=1;i=d;return y|0}z=q+108|0;c[z>>2]=0;x=q+100|0;c[x>>2]=0;A=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[A&16383](q,9)|0;do{if((c[z>>2]|0)!=0){A=c[x>>2]|0;c[r>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](r,9,0)|0;if((A|0)<1){y=1;i=d;return y|0}if((gzL(u,0,9)|0)==0){break}else{y=1}i=d;return y|0}}while(0);u=(c[3530524]|0)+1048576|0;if((c[3542200]|0)==0){y=1;i=d;return y|0}x=o+108|0;c[x>>2]=0;z=o+100|0;c[z>>2]=0;A=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[A&16383](o,10)|0;do{if((c[x>>2]|0)!=0){A=c[z>>2]|0;c[p>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](p,10,0)|0;if((A|0)<1){y=1;i=d;return y|0}if((gzL(u,0,10)|0)==0){break}else{y=1}i=d;return y|0}}while(0);u=c[3530392]|0;if((c[3542200]|0)==0){y=1;i=d;return y|0}z=m+108|0;c[z>>2]=0;x=m+100|0;c[x>>2]=0;A=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[A&16383](m,11)|0;do{if((c[z>>2]|0)!=0){A=c[x>>2]|0;c[n>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](n,11,0)|0;if((A|0)<1){y=1;i=d;return y|0}if((gzL(u,0,11)|0)==0){break}else{y=1}i=d;return y|0}}while(0);u=(c[3530392]|0)+524288|0;if((c[3542200]|0)==0){y=1;i=d;return y|0}x=k+108|0;c[x>>2]=0;z=k+100|0;c[z>>2]=0;A=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[A&16383](k,12)|0;do{if((c[x>>2]|0)!=0){A=c[z>>2]|0;c[l>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](l,12,0)|0;if((A|0)<1){y=1;i=d;return y|0}if((gzL(u,0,12)|0)==0){break}else{y=1}i=d;return y|0}}while(0);if((R6(c[3530312]|0,13,2)|0)!=0){y=1;i=d;return y|0}if((R6((c[3530312]|0)+1|0,14,2)|0)!=0){y=1;i=d;return y|0}if((R6((c[3530312]|0)+2097152|0,15,2)|0)!=0){y=1;i=d;return y|0}if((R6((c[3530312]|0)+2097153|0,16,2)|0)!=0){y=1;i=d;return y|0}if((R6(c[3530298]|0,17,2)|0)!=0){y=1;i=d;return y|0}if((R6((c[3530298]|0)+1|0,18,2)|0)!=0){y=1;i=d;return y|0}u=(c[3529780]|0)+262144|0;if((c[3542200]|0)==0){y=1;i=d;return y|0}z=g+108|0;c[z>>2]=0;x=g+100|0;c[x>>2]=0;A=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[A&16383](g,19)|0;do{if((c[z>>2]|0)!=0){A=c[x>>2]|0;c[j>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](j,19,0)|0;if((A|0)<1){y=1;i=d;return y|0}if((gzL(u,0,19)|0)==0){break}else{y=1}i=d;return y|0}}while(0);u=(c[3529734]|0)+262144|0;if((c[3542200]|0)==0){y=1;i=d;return y|0}x=e+108|0;c[x>>2]=0;z=e+100|0;c[z>>2]=0;A=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[A&16383](e,20)|0;do{if((c[x>>2]|0)!=0){A=c[z>>2]|0;c[f>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](f,20,0)|0;if((A|0)<1){y=1;i=d;return y|0}if((gzL(u,0,20)|0)==0){break}else{y=1}i=d;return y|0}}while(0);aFg(c[3530760]|0,131072,1572008,716440,1108208);aFg(c[3530524]|0,2097152,1572008,716440,1108208);aFg(c[3530392]|0,1048576,1572008,716440,1108208);u=c[3530760]|0;aE_(u,u,131072,1);u=c[3530524]|0;aE_(u,u,2097152,0);u=c[3530392]|0;aE_(u,u,1048576,0);aE$(c[3530312]|0,4194304);aE$(c[3530298]|0,1048576);aE1(0,0,1);u=c[3530524]|0;z=c[3530392]|0;c[2383440]=c[3530760];c[2383441]=u;c[2383442]=z;c[2383436]=4095;c[2383437]=16383;c[2383438]=8191;c[2429668]=512;c[2429669]=768;a[690376]=1;c[2429436]=1840;c[2429437]=1840;c[2429438]=1840;c[2429439]=1840;fxU(0,425984);if((c[2394]|0)==0){C=c[2112932]|0}else{c[2394]=0;z=c[3532596]|0;c[2112932]=z;u=c[3532592]|0;if((u|0)!=0){gGC(9104152,u|0,280)|0}c[2113054]=c[2113060];C=z}z=c[2388082]|0;u=C|0;x=0;while(1){A=z+x|0;c[u>>2]=A;c[u+131072>>2]=A;A=x+1024|0;if(A>>>0>2097151){break}else{u=u+4|0;x=A}}x=c[2383430]|0;c[C+8192>>2]=x;c[C+73728>>2]=x;c[C+139264>>2]=x;u=x+1024|0;c[C+8196>>2]=u;c[C+73732>>2]=u;c[C+139268>>2]=u;u=x+2048|0;c[C+8200>>2]=u;c[C+73736>>2]=u;c[C+139272>>2]=u;u=x+3072|0;c[C+8204>>2]=u;c[C+73740>>2]=u;c[C+139276>>2]=u;u=c[2383431]|0;c[C+8224>>2]=u;c[C+73760>>2]=u;c[C+139296>>2]=u;x=u+1024|0;c[C+8228>>2]=x;c[C+73764>>2]=x;c[C+139300>>2]=x;x=u+2048|0;c[C+8232>>2]=x;c[C+73768>>2]=x;c[C+139304>>2]=x;x=u+3072|0;c[C+8236>>2]=x;c[C+73772>>2]=x;c[C+139308>>2]=x;x=c[2383432]|0;c[C+8320>>2]=x;c[C+73856>>2]=x;c[C+139392>>2]=x;u=x+1024|0;c[C+8324>>2]=u;c[C+73860>>2]=u;c[C+139396>>2]=u;u=x+2048|0;c[C+8328>>2]=u;c[C+73864>>2]=u;c[C+139400>>2]=u;u=x+3072|0;c[C+8332>>2]=u;c[C+73868>>2]=u;c[C+139404>>2]=u;u=c[2383433]|0;c[C+8352>>2]=u;c[C+73888>>2]=u;c[C+139424>>2]=u;x=u+1024|0;c[C+8356>>2]=x;c[C+73892>>2]=x;c[C+139428>>2]=x;x=u+2048|0;c[C+8360>>2]=x;c[C+73896>>2]=x;c[C+139432>>2]=x;x=u+3072|0;c[C+8364>>2]=x;c[C+73900>>2]=x;c[C+139436>>2]=x;x=c[2383424]|0;c[C+8384>>2]=x;c[C+73920>>2]=x;c[C+139456>>2]=x;u=x+1024|0;c[C+8388>>2]=u;c[C+73924>>2]=u;c[C+139460>>2]=u;u=c[2383422]|0;c[C+8416>>2]=u;c[C+73952>>2]=u;c[C+139488>>2]=u;x=u+1024|0;c[C+8420>>2]=x;c[C+73956>>2]=x;c[C+139492>>2]=x;x=c[2386390]|0;c[C+13312>>2]=x;c[C+78848>>2]=x;c[C+144384>>2]=x;u=x+1024|0;c[C+13316>>2]=u;c[C+78852>>2]=u;c[C+144388>>2]=u;u=c[3529620]|0;c[C+13824>>2]=u;c[C+79360>>2]=u;c[C+144896>>2]=u;x=u+1024|0;c[C+13828>>2]=x;c[C+79364>>2]=x;c[C+144900>>2]=x;x=c[2387108]|0;c[C+14336>>2]=x;c[C+79872>>2]=x;c[C+145408>>2]=x;u=x+1024|0;c[C+14340>>2]=u;c[C+79876>>2]=u;c[C+145412>>2]=u;u=x+2048|0;c[C+14344>>2]=u;c[C+79880>>2]=u;c[C+145416>>2]=u;u=x+3072|0;c[C+14348>>2]=u;c[C+79884>>2]=u;c[C+145420>>2]=u;u=x+4096|0;c[C+14352>>2]=u;c[C+79888>>2]=u;c[C+145424>>2]=u;u=x+5120|0;c[C+14356>>2]=u;c[C+79892>>2]=u;c[C+145428>>2]=u;u=x+6144|0;c[C+14360>>2]=u;c[C+79896>>2]=u;c[C+145432>>2]=u;u=x+7168|0;c[C+14364>>2]=u;c[C+79900>>2]=u;c[C+145436>>2]=u;u=c[2388212]|0;x=C+64960|0;z=16629760;while(1){A=u+(z-16629760)|0;c[x>>2]=A;c[x+65536>>2]=A;c[x+131072>>2]=A;A=z+1024|0;if(A>>>0>16662527){break}else{x=x+4|0;z=A}}z=C+65096|0;x=16664576;while(1){A=u+(x-16631808)|0;c[z>>2]=A;c[z+65536>>2]=A;c[z+131072>>2]=A;A=x+1024|0;if(A>>>0>16777215){break}else{z=z+4|0;x=A}}c[C+196728>>2]=850;c[C+196648>>2]=3022;c[C+196688>>2]=2644;c[C+196608>>2]=976;x=c[3532592]|0;if((x|0)!=0){gGC(x|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;aE8(c[2387778]|0,c[2387800]|0,2685e3,0,2332,.8,1006875,1.0,2013750,.4);h[745421]=.8;c[2436794]=1;h[745420]=.8;c[2436792]=2;x=c[642608+(c[2436]<<2)>>2]|0;z=c[x+128>>2]|0;if((c[x+52>>2]&4|0)==0){c[2113068]=z;u=c[x+132>>2]|0;c[2113070]=u;c[2443814]=z;c[2440436]=u;D=z;E=u}else{c[2113070]=z;u=c[x+132>>2]|0;c[2113068]=u;c[2440436]=z;c[2443814]=u;D=u;E=z}z=ag(D<<1,E)|0;u=gGq(z)|0;c[2112926]=u;if((u|0)!=0){gGz(u|0,0,z|0)}z=c[2414564]|0;gGz(z|0,0,(c[2411464]|0)-z|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];z=c[3532592]|0;if((z|0)!=0){gGC(9104152,z|0,280)|0}c[2113054]=c[2113060]}RI();z=c[2394]|0;u=c[14130368+(z<<2)>>2]|0;if((u|0)!=0){gGC(u|0,9104152,280)|0}c[8452240+(z<<2)>>2]=c[2113054];c[2394]=-1;aE7();gGz(c[2383428]|0,0,4096);gGz(c[2383426]|0,0,4096);z=c[2383424]|0;if((z|0)!=0){gGz(z|0,0,4096);gGz(c[2383422]|0,0,4096)}gGz(c[2383434]|0,0,16);gGz(c[2383435]|0,0,16);gGz(c[2383430]|0,0,8192);gGz(c[2383431]|0,0,8192);z=c[2383432]|0;if((z|0)!=0){gGz(z|0,0,8192);gGz(c[2383433]|0,0,8192)}b[4766836]=0;c[2426968]=0;c[3528794]=0;c[1765522]=65535;c[2429656]=0;c[2427042]=0;c[2429386]=0;c[2429384]=0;c[2429382]=0;c[3530258]=3;y=0;i=d;return y|0}}while(0);c[2414862]=0;y=1;i=d;return y|0}function aD$(){var d=0,f=0,g=0,h=0,i=0,j=0;d=c[3529902]|0;f=c[2387108]|0;g=(c[642608+(c[2436]<<2)>>2]|0)+124|0;if((c[g>>2]<<1|0)>0){h=0;do{i=e[f+((h|1)<<1)>>1]|0;c[d+(((h|0)/2|0)<<2)>>2]=i<<8&63488|(e[f+(h<<1)>>1]|0)>>>3&31|i>>>8<<3&2016;h=h+2|0;}while((h|0)<(c[g>>2]<<1|0))}a[9547112]=0;aE3();aE5();g=ag(c[2113070]|0,c[2113068]|0)|0;h=c[2112926]|0;if((g|0)>0){f=0;while(1){b[h+(f<<1)>>1]=512;d=f+1|0;if((d|0)<(g|0)){f=d}else{j=h;break}}}else{j=h}aE0(3,j,65536);h=c[2386560]|0;aEl(h,c[3530312]|0,1024,4,3);aE0(1,j,0);aEl(h,c[3530312]|0,1024,3,3);aE0(2,j,0);aEl(h,c[3530312]|0,1024,0,3);h=c[3529668]|0;aEl(h,c[3530298]|0,1536,2,4);aEl(h,c[3530298]|0,1536,1,4);aE0(0,j,0);R8(c[3529902]|0);return 0}function aD0(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1336916+(b*112|0)>>2];c[a+104>>2]=c[1336920+(b*112|0)>>2];c[a+108>>2]=c[1336924+(b*112|0)>>2];d=0;return d|0}function aD1(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<22&(d|0)==0)){e=1;return e|0}c[a>>2]=1336816+(b*112|0);e=0;return e|0}function aD2(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1585836+(b*112|0)>>2];c[a+104>>2]=c[1585840+(b*112|0)>>2];c[a+108>>2]=c[1585844+(b*112|0)>>2];d=0;return d|0}function aD3(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<22&(d|0)==0)){e=1;return e|0}c[a>>2]=1585736+(b*112|0);e=0;return e|0}function aD4(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2325740+(b*112|0)>>2];c[a+104>>2]=c[2325744+(b*112|0)>>2];c[a+108>>2]=c[2325748+(b*112|0)>>2];d=0;return d|0}function aD5(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=2325640+(b*112|0);e=0;return e|0}function aD6(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>32){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3525784+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aD7(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;e=i;i=i+1320|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;B=e+1200|0;C=e+1312|0;c[2424]=5800;c[2414862]=0;c[2388082]=0;c[2387778]=2097152;c[3530760]=2162688;c[3530524]=2686976;c[3530392]=6881280;c[3530312]=11075584;c[3530298]=19464192;c[3541206]=20512768;c[3529780]=20512768;c[3529734]=21561344;c[2388468]=22347776;c[2388464]=22501376;c[3529902]=22654976;c[2414564]=22663168;c[2388212]=22663168;c[2387800]=22810624;c[3529620]=22818816;c[2386390]=22820864;c[3529668]=22822912;c[2386560]=22824960;c[2383414]=22827008;c[2387038]=22827008;c[2383444]=22829056;c[2387108]=22831104;c[2387302]=22839296;c[3528660]=22847488;c[2411464]=22847489;D=0;while(1){if((D|0)>=1024){break}E=9638528+(D<<2)|0;if((c[E>>2]|0)==0){F=23868;break}else{D=D+1|0}}do{if((F|0)==23868){D=gGq(22847489)|0;c[E>>2]=D;if((D|0)==0){break}c[2414862]=D;gGz(D|0,0,22847489);c[2388082]=D;c[2387778]=D+2097152;c[3530760]=D+2162688;c[3530524]=D+2686976;c[3530392]=D+6881280;c[3530312]=D+11075584;c[3530298]=D+19464192;G=D+20512768|0;c[3541206]=G;c[3529780]=G;c[3529734]=D+21561344;c[2388468]=D+22347776;c[2388464]=D+22501376;c[3529902]=D+22654976;G=D+22663168|0;c[2414564]=G;c[2388212]=G;c[2387800]=D+22810624;c[3529620]=D+22818816;c[2386390]=D+22820864;c[3529668]=D+22822912;c[2386560]=D+22824960;G=D+22827008|0;c[2383414]=G;c[2387038]=G;c[2383444]=D+22829056;c[2387108]=D+22831104;c[2387302]=D+22839296;c[3528660]=D+22847488;G=D+22847489|0;c[2411464]=G;c[2414004]=G;if((R6(D+1|0,0,2)|0)!=0){H=1;i=e;return H|0}if((R6(c[2388082]|0,1,2)|0)!=0){H=1;i=e;return H|0}D=c[2387778]|0;if((c[3542200]|0)==0){H=1;i=e;return H|0}G=B+108|0;c[G>>2]=0;I=B+100|0;c[I>>2]=0;J=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[J&16383](B,2)|0;do{if((c[G>>2]|0)!=0){J=c[I>>2]|0;c[C>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](C,2,0)|0;if((J|0)<1){H=1;i=e;return H|0}if((gzL(D,0,2)|0)==0){break}else{H=1}i=e;return H|0}}while(0);D=c[3530524]|0;if((c[3542200]|0)==0){H=1;i=e;return H|0}I=z+108|0;c[I>>2]=0;G=z+100|0;c[G>>2]=0;J=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[J&16383](z,3)|0;do{if((c[I>>2]|0)!=0){J=c[G>>2]|0;c[A>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](A,3,0)|0;if((J|0)<1){H=1;i=e;return H|0}if((gzL(D,0,3)|0)==0){break}else{H=1}i=e;return H|0}}while(0);D=(c[3530524]|0)+524288|0;if((c[3542200]|0)==0){H=1;i=e;return H|0}G=x+108|0;c[G>>2]=0;I=x+100|0;c[I>>2]=0;J=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[J&16383](x,4)|0;do{if((c[G>>2]|0)!=0){J=c[I>>2]|0;c[y>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](y,4,0)|0;if((J|0)<1){H=1;i=e;return H|0}if((gzL(D,0,4)|0)==0){break}else{H=1}i=e;return H|0}}while(0);D=c[3530392]|0;if((c[3542200]|0)==0){H=1;i=e;return H|0}I=v+108|0;c[I>>2]=0;G=v+100|0;c[G>>2]=0;J=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[J&16383](v,5)|0;do{if((c[I>>2]|0)!=0){J=c[G>>2]|0;c[w>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](w,5,0)|0;if((J|0)<1){H=1;i=e;return H|0}if((gzL(D,0,5)|0)==0){break}else{H=1}i=e;return H|0}}while(0);D=(c[3530392]|0)+1048576|0;if((c[3542200]|0)==0){H=1;i=e;return H|0}G=t+108|0;c[G>>2]=0;I=t+100|0;c[I>>2]=0;J=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[J&16383](t,6)|0;do{if((c[G>>2]|0)!=0){J=c[I>>2]|0;c[u>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](u,6,0)|0;if((J|0)<1){H=1;i=e;return H|0}if((gzL(D,0,6)|0)==0){break}else{H=1}i=e;return H|0}}while(0);D=c[3530312]|0;if((c[3542200]|0)==0){H=1;i=e;return H|0}I=r+108|0;c[I>>2]=0;G=r+100|0;c[G>>2]=0;J=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[J&16383](r,7)|0;do{if((c[I>>2]|0)!=0){J=c[G>>2]|0;c[s>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](s,7,0)|0;if((J|0)<1){H=1;i=e;return H|0}if((gzL(D,0,7)|0)==0){break}else{H=1}i=e;return H|0}}while(0);D=(c[3530312]|0)+1048576|0;if((c[3542200]|0)==0){H=1;i=e;return H|0}G=p+108|0;c[G>>2]=0;I=p+100|0;c[I>>2]=0;J=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[J&16383](p,8)|0;do{if((c[G>>2]|0)!=0){J=c[I>>2]|0;c[q>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](q,8,0)|0;if((J|0)<1){H=1;i=e;return H|0}if((gzL(D,0,8)|0)==0){break}else{H=1}i=e;return H|0}}while(0);D=(c[3530312]|0)+2097152|0;if((c[3542200]|0)==0){H=1;i=e;return H|0}I=n+108|0;c[I>>2]=0;G=n+100|0;c[G>>2]=0;J=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[J&16383](n,9)|0;do{if((c[I>>2]|0)!=0){J=c[G>>2]|0;c[o>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](o,9,0)|0;if((J|0)<1){H=1;i=e;return H|0}if((gzL(D,0,9)|0)==0){break}else{H=1}i=e;return H|0}}while(0);D=(c[3530312]|0)+3145728|0;if((c[3542200]|0)==0){H=1;i=e;return H|0}G=l+108|0;c[G>>2]=0;I=l+100|0;c[I>>2]=0;J=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[J&16383](l,10)|0;do{if((c[G>>2]|0)!=0){J=c[I>>2]|0;c[m>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](m,10,0)|0;if((J|0)<1){H=1;i=e;return H|0}if((gzL(D,0,10)|0)==0){break}else{H=1}i=e;return H|0}}while(0);D=(c[3529780]|0)+262144|0;if((c[3542200]|0)==0){H=1;i=e;return H|0}I=j+108|0;c[I>>2]=0;G=j+100|0;c[G>>2]=0;J=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[J&16383](j,11)|0;do{if((c[I>>2]|0)!=0){J=c[G>>2]|0;c[k>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](k,11,0)|0;if((J|0)<1){H=1;i=e;return H|0}if((gzL(D,0,11)|0)==0){break}else{H=1}i=e;return H|0}}while(0);D=(c[3529734]|0)+262144|0;if((c[3542200]|0)==0){H=1;i=e;return H|0}G=f+108|0;c[G>>2]=0;I=f+100|0;c[I>>2]=0;J=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[J&16383](f,12)|0;do{if((c[G>>2]|0)!=0){J=c[I>>2]|0;c[g>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](g,12,0)|0;if((J|0)<1){H=1;i=e;return H|0}if((gzL(D,0,12)|0)==0){break}else{H=1}i=e;return H|0}}while(0);aFg(c[3530524]|0,1048576,1572008,716440,1108208);D=c[3530760]|0;I=c[3530524]|0;gGC(D|0,I|0,131072)|0;G=D+131072|0;J=I+524288|0;gGC(G|0,J|0,131072)|0;aE_(D,D,262144,1);D=c[3530524]|0;aE_(D,D,1048576,0);D=c[3530392]|0;aE_(D,D,2097152,0);D=0;while(1){if((D|0)>=1024){break}L=9638528+(D<<2)|0;if((c[L>>2]|0)==0){F=23919;break}else{D=D+1|0}}L30609:do{if((F|0)==23919){D=gGq(6291456)|0;c[L>>2]=D;if((D|0)==0){break}gGz(D|0,0,6291456);J=c[3530312]|0;gGC(D|0,J|0,6291456)|0;G=0;while(1){I=G<<8;gGz(J+I|0,0,256);K=G<<9;M=0;do{N=1<<5-M;O=(c[602608+(M<<2)>>2]|0)+K|0;P=0;do{Q=O+(c[608752+(P<<2)>>2]|0)|0;R=(P<<4)+I|0;S=0;do{T=Q+(c[598384+(S<<2)>>2]|0)|0;if(((d[D+((T|0)/8|0)|0]|0)&128>>>((T&7)>>>0)|0)!=0){T=J+(R+S)|0;a[T]=(d[T]|0|N)&255}S=S+1|0;}while((S|0)<16);P=P+1|0;}while((P|0)<16);M=M+1|0;}while((M|0)<6);M=G+1|0;if((M|0)<32768){G=M}else{U=0;break}}while(1){if((U|0)>=1024){break L30609}V=9638528+(U<<2)|0;if((c[V>>2]|0)==(D|0)){break}else{U=U+1|0}}gGr(D);c[V>>2]=0}}while(0);aE1(0,0,1);G=c[3530524]|0;J=c[3530392]|0;c[2383440]=c[3530760];c[2383441]=G;c[2383442]=J;c[2383436]=8191;c[2383437]=8191;c[2383438]=16383;c[2429668]=512;c[2429669]=768;a[690376]=1;c[2429436]=1840;c[2429437]=1840;c[2429438]=1840;c[2429439]=1840;fxU(0,425984);if((c[2394]|0)==0){W=c[2112932]|0}else{c[2394]=0;J=c[3532596]|0;c[2112932]=J;G=c[3532592]|0;if((G|0)!=0){gGC(9104152,G|0,280)|0}c[2113054]=c[2113060];W=J}J=c[2388082]|0;G=W|0;M=0;while(1){I=J+M|0;c[G>>2]=I;c[G+131072>>2]=I;I=M+1024|0;if(I>>>0>2097151){break}else{G=G+4|0;M=I}}M=c[2383430]|0;c[W+15360>>2]=M;c[W+80896>>2]=M;c[W+146432>>2]=M;G=M+1024|0;c[W+15364>>2]=G;c[W+80900>>2]=G;c[W+146436>>2]=G;G=M+2048|0;c[W+15368>>2]=G;c[W+80904>>2]=G;c[W+146440>>2]=G;G=M+3072|0;c[W+15372>>2]=G;c[W+80908>>2]=G;c[W+146444>>2]=G;G=M+4096|0;c[W+15376>>2]=G;c[W+80912>>2]=G;c[W+146448>>2]=G;G=M+5120|0;c[W+15380>>2]=G;c[W+80916>>2]=G;c[W+146452>>2]=G;G=M+6144|0;c[W+15384>>2]=G;c[W+80920>>2]=G;c[W+146456>>2]=G;G=M+7168|0;c[W+15388>>2]=G;c[W+80924>>2]=G;c[W+146460>>2]=G;G=c[2383431]|0;c[W+15392>>2]=G;c[W+80928>>2]=G;c[W+146464>>2]=G;M=G+1024|0;c[W+15396>>2]=M;c[W+80932>>2]=M;c[W+146468>>2]=M;M=G+2048|0;c[W+15400>>2]=M;c[W+80936>>2]=M;c[W+146472>>2]=M;M=G+3072|0;c[W+15404>>2]=M;c[W+80940>>2]=M;c[W+146476>>2]=M;M=c[2383432]|0;c[W+15424>>2]=M;c[W+80960>>2]=M;c[W+146496>>2]=M;G=M+1024|0;c[W+15428>>2]=G;c[W+80964>>2]=G;c[W+146500>>2]=G;G=M+2048|0;c[W+15432>>2]=G;c[W+80968>>2]=G;c[W+146504>>2]=G;G=M+3072|0;c[W+15436>>2]=G;c[W+80972>>2]=G;c[W+146508>>2]=G;G=c[2383433]|0;c[W+15456>>2]=G;c[W+80992>>2]=G;c[W+146528>>2]=G;M=G+1024|0;c[W+15460>>2]=M;c[W+80996>>2]=M;c[W+146532>>2]=M;M=G+2048|0;c[W+15464>>2]=M;c[W+81e3>>2]=M;c[W+146536>>2]=M;M=G+3072|0;c[W+15468>>2]=M;c[W+81004>>2]=M;c[W+146540>>2]=M;M=c[2383428]|0;c[W+15488>>2]=M;c[W+81024>>2]=M;c[W+146560>>2]=M;G=M+1024|0;c[W+15492>>2]=G;c[W+81028>>2]=G;c[W+146564>>2]=G;J=M+2048|0;c[W+15496>>2]=J;c[W+81032>>2]=J;c[W+146568>>2]=J;I=M+3072|0;c[W+15500>>2]=I;c[W+81036>>2]=I;c[W+146572>>2]=I;c[W+15504>>2]=M;c[W+81040>>2]=M;c[W+146576>>2]=M;c[W+15508>>2]=G;c[W+81044>>2]=G;c[W+146580>>2]=G;c[W+15512>>2]=J;c[W+81048>>2]=J;c[W+146584>>2]=J;c[W+15516>>2]=I;c[W+81052>>2]=I;c[W+146588>>2]=I;I=c[2383426]|0;c[W+15520>>2]=I;c[W+81056>>2]=I;c[W+146592>>2]=I;J=I+1024|0;c[W+15524>>2]=J;c[W+81060>>2]=J;c[W+146596>>2]=J;G=I+2048|0;c[W+15528>>2]=G;c[W+81064>>2]=G;c[W+146600>>2]=G;M=I+3072|0;c[W+15532>>2]=M;c[W+81068>>2]=M;c[W+146604>>2]=M;c[W+15536>>2]=I;c[W+81072>>2]=I;c[W+146608>>2]=I;c[W+15540>>2]=J;c[W+81076>>2]=J;c[W+146612>>2]=J;c[W+15544>>2]=G;c[W+81080>>2]=G;c[W+146616>>2]=G;c[W+15548>>2]=M;c[W+81084>>2]=M;c[W+146620>>2]=M;M=c[2383424]|0;c[W+15552>>2]=M;c[W+81088>>2]=M;c[W+146624>>2]=M;G=M+1024|0;c[W+15556>>2]=G;c[W+81092>>2]=G;c[W+146628>>2]=G;J=M+2048|0;c[W+15560>>2]=J;c[W+81096>>2]=J;c[W+146632>>2]=J;I=M+3072|0;c[W+15564>>2]=I;c[W+81100>>2]=I;c[W+146636>>2]=I;c[W+15568>>2]=M;c[W+81104>>2]=M;c[W+146640>>2]=M;c[W+15572>>2]=G;c[W+81108>>2]=G;c[W+146644>>2]=G;c[W+15576>>2]=J;c[W+81112>>2]=J;c[W+146648>>2]=J;c[W+15580>>2]=I;c[W+81116>>2]=I;c[W+146652>>2]=I;I=c[2383422]|0;c[W+15584>>2]=I;c[W+81120>>2]=I;c[W+146656>>2]=I;J=I+1024|0;c[W+15588>>2]=J;c[W+81124>>2]=J;c[W+146660>>2]=J;G=I+2048|0;c[W+15592>>2]=G;c[W+81128>>2]=G;c[W+146664>>2]=G;M=I+3072|0;c[W+15596>>2]=M;c[W+81132>>2]=M;c[W+146668>>2]=M;c[W+15600>>2]=I;c[W+81136>>2]=I;c[W+146672>>2]=I;c[W+15604>>2]=J;c[W+81140>>2]=J;c[W+146676>>2]=J;c[W+15608>>2]=G;c[W+81144>>2]=G;c[W+146680>>2]=G;c[W+15612>>2]=M;c[W+81148>>2]=M;c[W+146684>>2]=M;M=c[2386390]|0;c[W+15616>>2]=M;c[W+81152>>2]=M;c[W+146688>>2]=M;G=M+1024|0;c[W+15620>>2]=G;c[W+81156>>2]=G;c[W+146692>>2]=G;G=c[2387108]|0;c[W+15872>>2]=G;c[W+81408>>2]=G;c[W+146944>>2]=G;M=G+1024|0;c[W+15876>>2]=M;c[W+81412>>2]=M;c[W+146948>>2]=M;J=G+2048|0;c[W+15880>>2]=J;c[W+81416>>2]=J;c[W+146952>>2]=J;I=G+3072|0;c[W+15884>>2]=I;c[W+81420>>2]=I;c[W+146956>>2]=I;K=G+4096|0;c[W+15888>>2]=K;c[W+81424>>2]=K;c[W+146960>>2]=K;P=G+5120|0;c[W+15892>>2]=P;c[W+81428>>2]=P;c[W+146964>>2]=P;N=G+6144|0;c[W+15896>>2]=N;c[W+81432>>2]=N;c[W+146968>>2]=N;O=G+7168|0;c[W+15900>>2]=O;c[W+81436>>2]=O;c[W+146972>>2]=O;c[W+15904>>2]=G;c[W+81440>>2]=G;c[W+146976>>2]=G;c[W+15908>>2]=M;c[W+81444>>2]=M;c[W+146980>>2]=M;c[W+15912>>2]=J;c[W+81448>>2]=J;c[W+146984>>2]=J;c[W+15916>>2]=I;c[W+81452>>2]=I;c[W+146988>>2]=I;c[W+15920>>2]=K;c[W+81456>>2]=K;c[W+146992>>2]=K;c[W+15924>>2]=P;c[W+81460>>2]=P;c[W+146996>>2]=P;c[W+15928>>2]=N;c[W+81464>>2]=N;c[W+147e3>>2]=N;c[W+15932>>2]=O;c[W+81468>>2]=O;c[W+147004>>2]=O;O=c[2388212]|0;N=W+65280|0;P=16711680;while(1){K=O+(P-16711680)|0;c[N>>2]=K;c[N+65536>>2]=K;c[N+131072>>2]=K;K=P+1024|0;if(K>>>0>16744447){break}else{N=N+4|0;P=K}}c[W+196728>>2]=1042;c[W+196648>>2]=1908;c[W+196688>>2]=930;c[W+196608>>2]=910;P=c[3532592]|0;if((P|0)!=0){gGC(P|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;aE8(c[2387778]|0,c[2387800]|0,2685e3,0,2332,.8,1006875,1.0,2013750,.4);h[745421]=.8;c[2436794]=1;h[745420]=.8;c[2436792]=2;P=c[642608+(c[2436]<<2)>>2]|0;N=c[P+128>>2]|0;if((c[P+52>>2]&4|0)==0){c[2113068]=N;O=c[P+132>>2]|0;c[2113070]=O;c[2443814]=N;c[2440436]=O;X=N;Y=O}else{c[2113070]=N;O=c[P+132>>2]|0;c[2113068]=O;c[2440436]=N;c[2443814]=O;X=O;Y=N}N=ag(X<<1,Y)|0;O=gGq(N)|0;c[2112926]=O;if((O|0)!=0){gGz(O|0,0,N|0)}N=c[2414564]|0;gGz(N|0,0,(c[2411464]|0)-N|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];N=c[3532592]|0;if((N|0)!=0){gGC(9104152,N|0,280)|0}c[2113054]=c[2113060]}RI();N=c[2394]|0;O=c[14130368+(N<<2)>>2]|0;if((O|0)!=0){gGC(O|0,9104152,280)|0}c[8452240+(N<<2)>>2]=c[2113054];c[2394]=-1;aE7();gGz(c[2383428]|0,0,4096);gGz(c[2383426]|0,0,4096);N=c[2383424]|0;if((N|0)!=0){gGz(N|0,0,4096);gGz(c[2383422]|0,0,4096)}gGz(c[2383434]|0,0,16);gGz(c[2383435]|0,0,16);gGz(c[2383430]|0,0,8192);gGz(c[2383431]|0,0,8192);N=c[2383432]|0;if((N|0)!=0){gGz(N|0,0,8192);gGz(c[2383433]|0,0,8192)}b[4766836]=0;c[2426968]=0;c[3528794]=0;c[1765522]=65535;c[2429656]=0;c[2427042]=0;c[2429386]=0;c[2429384]=0;c[2429382]=0;c[3530258]=3;H=0;i=e;return H|0}}while(0);c[2414862]=0;H=1;i=e;return H|0}function aD8(){aEk(1);return 0}function aD9(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2502276+(b*112|0)>>2];c[a+104>>2]=c[2502280+(b*112|0)>>2];c[a+108>>2]=c[2502284+(b*112|0)>>2];d=0;return d|0}function aEa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<22&(d|0)==0)){e=1;return e|0}c[a>>2]=2502176+(b*112|0);e=0;return e|0}function aEb(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>26){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1224840+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aEc(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>47){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3660472+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aEd(){var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;d=i;i=i+840|0;e=d|0;f=d+112|0;g=d+120|0;j=d+232|0;k=d+240|0;l=d+352|0;m=d+360|0;n=d+472|0;o=d+480|0;p=d+592|0;q=d+600|0;r=d+712|0;s=d+720|0;t=d+832|0;c[2424]=5800;c[2414862]=0;c[2388082]=0;c[2387778]=2097152;c[3530760]=2162688;c[3530524]=2686976;c[3530392]=6881280;c[3530312]=11075584;c[3530298]=19464192;c[3541206]=20512768;c[3529780]=20512768;c[3529734]=21561344;c[2388468]=22347776;c[2388464]=22501376;c[3529902]=22654976;c[2414564]=22663168;c[2388212]=22663168;c[2387800]=22810624;c[3529620]=22818816;c[2386390]=22820864;c[3529668]=22822912;c[2386560]=22824960;c[2383414]=22827008;c[2387038]=22827008;c[2383444]=22829056;c[2387108]=22831104;c[2387302]=22839296;c[3528660]=22847488;c[2411464]=22847489;u=0;while(1){if((u|0)>=1024){break}v=9638528+(u<<2)|0;if((c[v>>2]|0)==0){w=24028;break}else{u=u+1|0}}do{if((w|0)==24028){u=gGq(22847489)|0;c[v>>2]=u;if((u|0)==0){break}c[2414862]=u;gGz(u|0,0,22847489);c[2388082]=u;c[2387778]=u+2097152;c[3530760]=u+2162688;c[3530524]=u+2686976;c[3530392]=u+6881280;c[3530312]=u+11075584;c[3530298]=u+19464192;x=u+20512768|0;c[3541206]=x;c[3529780]=x;c[3529734]=u+21561344;c[2388468]=u+22347776;c[2388464]=u+22501376;c[3529902]=u+22654976;x=u+22663168|0;c[2414564]=x;c[2388212]=x;c[2387800]=u+22810624;c[3529620]=u+22818816;c[2386390]=u+22820864;c[3529668]=u+22822912;c[2386560]=u+22824960;x=u+22827008|0;c[2383414]=x;c[2387038]=x;c[2383444]=u+22829056;c[2387108]=u+22831104;c[2387302]=u+22839296;c[3528660]=u+22847488;x=u+22847489|0;c[2411464]=x;c[2414004]=x;if((R6(u+1|0,0,2)|0)!=0){y=1;i=d;return y|0}if((R6(c[2388082]|0,1,2)|0)!=0){y=1;i=d;return y|0}if((R6((c[2388082]|0)+262145|0,2,2)|0)!=0){y=1;i=d;return y|0}if((R6((c[2388082]|0)+262144|0,3,2)|0)!=0){y=1;i=d;return y|0}if((R6((c[2388082]|0)+524289|0,4,2)|0)!=0){y=1;i=d;return y|0}if((R6((c[2388082]|0)+524288|0,5,2)|0)!=0){y=1;i=d;return y|0}u=c[2387778]|0;if((c[3542200]|0)==0){y=1;i=d;return y|0}x=s+108|0;c[x>>2]=0;z=s+100|0;c[z>>2]=0;A=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[A&16383](s,6)|0;do{if((c[x>>2]|0)!=0){A=c[z>>2]|0;c[t>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](t,6,0)|0;if((A|0)<1){y=1;i=d;return y|0}if((gzL(u,0,6)|0)==0){break}else{y=1}i=d;return y|0}}while(0);if((R6(c[3530760]|0,7,2)|0)!=0){y=1;i=d;return y|0}if((R6((c[3530760]|0)+1|0,8,2)|0)!=0){y=1;i=d;return y|0}u=c[3530524]|0;if((c[3542200]|0)==0){y=1;i=d;return y|0}z=q+108|0;c[z>>2]=0;x=q+100|0;c[x>>2]=0;A=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[A&16383](q,9)|0;do{if((c[z>>2]|0)!=0){A=c[x>>2]|0;c[r>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](r,9,0)|0;if((A|0)<1){y=1;i=d;return y|0}if((gzL(u,0,9)|0)==0){break}else{y=1}i=d;return y|0}}while(0);u=(c[3530524]|0)+524288|0;if((c[3542200]|0)==0){y=1;i=d;return y|0}x=o+108|0;c[x>>2]=0;z=o+100|0;c[z>>2]=0;A=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[A&16383](o,10)|0;do{if((c[x>>2]|0)!=0){A=c[z>>2]|0;c[p>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](p,10,0)|0;if((A|0)<1){y=1;i=d;return y|0}if((gzL(u,0,10)|0)==0){break}else{y=1}i=d;return y|0}}while(0);u=c[3530392]|0;if((c[3542200]|0)==0){y=1;i=d;return y|0}z=m+108|0;c[z>>2]=0;x=m+100|0;c[x>>2]=0;A=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[A&16383](m,11)|0;do{if((c[z>>2]|0)!=0){A=c[x>>2]|0;c[n>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](n,11,0)|0;if((A|0)<1){y=1;i=d;return y|0}if((gzL(u,0,11)|0)==0){break}else{y=1}i=d;return y|0}}while(0);u=(c[3530392]|0)+1048576|0;if((c[3542200]|0)==0){y=1;i=d;return y|0}x=k+108|0;c[x>>2]=0;z=k+100|0;c[z>>2]=0;A=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[A&16383](k,12)|0;do{if((c[x>>2]|0)!=0){A=c[z>>2]|0;c[l>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](l,12,0)|0;if((A|0)<1){y=1;i=d;return y|0}if((gzL(u,0,12)|0)==0){break}else{y=1}i=d;return y|0}}while(0);if((R6(c[3530312]|0,13,2)|0)!=0){y=1;i=d;return y|0}if((R6((c[3530312]|0)+1|0,14,2)|0)!=0){y=1;i=d;return y|0}if((R6((c[3530312]|0)+2097152|0,15,2)|0)!=0){y=1;i=d;return y|0}if((R6((c[3530312]|0)+2097153|0,16,2)|0)!=0){y=1;i=d;return y|0}u=0;z=c[3530312]|0;while(1){x=a[z]|0;A=z+1|0;a[z]=a[A]|0;a[A]=x;x=u+1|0;if((x|0)<2097152){u=x;z=z+2|0}else{break}}if((R6(c[3530298]|0,17,2)|0)!=0){y=1;i=d;return y|0}if((R6((c[3530298]|0)+1|0,18,2)|0)!=0){y=1;i=d;return y|0}z=0;u=c[3530298]|0;while(1){x=a[u]|0;A=u+1|0;a[u]=a[A]|0;a[A]=x;x=z+1|0;if((x|0)<262144){z=x;u=u+2|0}else{break}}u=(c[3529780]|0)+262144|0;if((c[3542200]|0)==0){y=1;i=d;return y|0}z=g+108|0;c[z>>2]=0;x=g+100|0;c[x>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,19)|0;do{if((c[z>>2]|0)!=0){A=c[x>>2]|0;c[j>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](j,19,0)|0;if((A|0)<1){y=1;i=d;return y|0}if((gzL(u,0,19)|0)==0){break}else{y=1}i=d;return y|0}}while(0);u=(c[3529734]|0)+262144|0;if((c[3542200]|0)==0){y=1;i=d;return y|0}x=e+108|0;c[x>>2]=0;z=e+100|0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,20)|0;do{if((c[x>>2]|0)!=0){A=c[z>>2]|0;c[f>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](f,20,0)|0;if((A|0)<1){y=1;i=d;return y|0}if((gzL(u,0,20)|0)==0){break}else{y=1}i=d;return y|0}}while(0);aFg(c[3530760]|0,131072,1574056,720536,1110256);aFg(c[3530524]|0,1048576,1574056,720536,1110256);aFg(c[3530392]|0,2097152,1572008,716440,1108208);u=c[3530760]|0;aE_(u,u,131072,1);u=c[3530524]|0;aE_(u,u,1048576,0);u=c[3530392]|0;aE_(u,u,2097152,0);aE$(c[3530312]|0,4194304);aE$(c[3530298]|0,524288);aE1(0,0,0);u=c[3530524]|0;z=c[3530392]|0;c[2383440]=c[3530760];c[2383441]=u;c[2383442]=z;c[2383436]=4095;c[2383437]=8191;c[2383438]=16383;c[2429668]=512;c[2429664]=0;c[2429669]=512;c[2429665]=0;a[690376]=1;c[2429436]=1840;c[2429437]=1840;c[2429438]=1840;c[2429439]=1840;fxU(0,425984);if((c[2394]|0)==0){C=c[2112932]|0}else{c[2394]=0;z=c[3532596]|0;c[2112932]=z;u=c[3532592]|0;if((u|0)!=0){gGC(9104152,u|0,280)|0}c[2113054]=c[2113060];C=z}z=c[2388082]|0;u=C|0;x=0;while(1){A=z+x|0;c[u>>2]=A;c[u+131072>>2]=A;A=x+1024|0;if(A>>>0>2097151){break}else{u=u+4|0;x=A}}x=c[2383430]|0;c[C+8192>>2]=x;c[C+73728>>2]=x;c[C+139264>>2]=x;u=x+1024|0;c[C+8196>>2]=u;c[C+73732>>2]=u;c[C+139268>>2]=u;z=x+2048|0;c[C+8200>>2]=z;c[C+73736>>2]=z;c[C+139272>>2]=z;A=x+3072|0;c[C+8204>>2]=A;c[C+73740>>2]=A;c[C+139276>>2]=A;c[C+8208>>2]=x;c[C+73744>>2]=x;c[C+139280>>2]=x;c[C+8212>>2]=u;c[C+73748>>2]=u;c[C+139284>>2]=u;c[C+8216>>2]=z;c[C+73752>>2]=z;c[C+139288>>2]=z;c[C+8220>>2]=A;c[C+73756>>2]=A;c[C+139292>>2]=A;A=c[2383431]|0;c[C+8224>>2]=A;c[C+73760>>2]=A;c[C+139296>>2]=A;z=A+1024|0;c[C+8228>>2]=z;c[C+73764>>2]=z;c[C+139300>>2]=z;c[C+8232>>2]=A;c[C+73768>>2]=A;c[C+139304>>2]=A;c[C+8236>>2]=z;c[C+73772>>2]=z;c[C+139308>>2]=z;z=c[2383432]|0;c[C+8320>>2]=z;c[C+73856>>2]=z;c[C+139392>>2]=z;A=z+1024|0;c[C+8324>>2]=A;c[C+73860>>2]=A;c[C+139396>>2]=A;c[C+8328>>2]=z;c[C+73864>>2]=z;c[C+139400>>2]=z;c[C+8332>>2]=A;c[C+73868>>2]=A;c[C+139404>>2]=A;A=c[2383433]|0;c[C+8352>>2]=A;c[C+73888>>2]=A;c[C+139424>>2]=A;z=A+1024|0;c[C+8356>>2]=z;c[C+73892>>2]=z;c[C+139428>>2]=z;c[C+8360>>2]=A;c[C+73896>>2]=A;c[C+139432>>2]=A;c[C+8364>>2]=z;c[C+73900>>2]=z;c[C+139436>>2]=z;z=c[2383428]|0;c[C+8256>>2]=z;c[C+73792>>2]=z;c[C+139328>>2]=z;A=z+1024|0;c[C+8260>>2]=A;c[C+73796>>2]=A;c[C+139332>>2]=A;A=c[2383426]|0;c[C+8288>>2]=A;c[C+73824>>2]=A;c[C+139360>>2]=A;z=A+1024|0;c[C+8292>>2]=z;c[C+73828>>2]=z;c[C+139364>>2]=z;z=c[2383424]|0;c[C+8384>>2]=z;c[C+73920>>2]=z;c[C+139456>>2]=z;A=z+1024|0;c[C+8388>>2]=A;c[C+73924>>2]=A;c[C+139460>>2]=A;A=c[2383422]|0;c[C+8416>>2]=A;c[C+73952>>2]=A;c[C+139488>>2]=A;z=A+1024|0;c[C+8420>>2]=z;c[C+73956>>2]=z;c[C+139492>>2]=z;z=c[2386390]|0;c[C+13312>>2]=z;c[C+78848>>2]=z;c[C+144384>>2]=z;A=z+1024|0;c[C+13316>>2]=A;c[C+78852>>2]=A;c[C+144388>>2]=A;A=c[3529620]|0;c[C+13824>>2]=A;c[C+79360>>2]=A;c[C+144896>>2]=A;z=A+1024|0;c[C+13828>>2]=z;c[C+79364>>2]=z;c[C+144900>>2]=z;z=c[2387108]|0;c[C+14336>>2]=z;c[C+79872>>2]=z;c[C+145408>>2]=z;A=z+1024|0;c[C+14340>>2]=A;c[C+79876>>2]=A;c[C+145412>>2]=A;A=z+2048|0;c[C+14344>>2]=A;c[C+79880>>2]=A;c[C+145416>>2]=A;A=z+3072|0;c[C+14348>>2]=A;c[C+79884>>2]=A;c[C+145420>>2]=A;A=z+4096|0;c[C+14352>>2]=A;c[C+79888>>2]=A;c[C+145424>>2]=A;A=z+5120|0;c[C+14356>>2]=A;c[C+79892>>2]=A;c[C+145428>>2]=A;A=z+6144|0;c[C+14360>>2]=A;c[C+79896>>2]=A;c[C+145432>>2]=A;A=z+7168|0;c[C+14364>>2]=A;c[C+79900>>2]=A;c[C+145436>>2]=A;A=c[2388212]|0;z=C+65216|0;u=16695296;while(1){x=A+(u-16695296)|0;c[z>>2]=x;c[z+65536>>2]=x;c[z+131072>>2]=x;x=u+1024|0;if(x>>>0>16728063){break}else{z=z+4|0;u=x}}u=C+65408|0;z=16744448;while(1){x=A+(z-16711680)|0;c[u>>2]=x;c[u+65536>>2]=x;c[u+131072>>2]=x;x=z+1024|0;if(x>>>0>16777215){break}else{u=u+4|0;z=x}}c[C+196728>>2]=850;c[C+196648>>2]=3022;c[C+196688>>2]=2644;c[C+196608>>2]=976;z=c[3532592]|0;if((z|0)!=0){gGC(z|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;aE8(c[2387778]|0,c[2387800]|0,2685e3,0,2332,.8,1006875,1.0,2013750,.4);h[745421]=.8;c[2436794]=1;h[745420]=.8;c[2436792]=2;z=c[642608+(c[2436]<<2)>>2]|0;u=c[z+128>>2]|0;if((c[z+52>>2]&4|0)==0){c[2113068]=u;A=c[z+132>>2]|0;c[2113070]=A;c[2443814]=u;c[2440436]=A;D=u;E=A}else{c[2113070]=u;A=c[z+132>>2]|0;c[2113068]=A;c[2440436]=u;c[2443814]=A;D=A;E=u}u=ag(D<<1,E)|0;A=gGq(u)|0;c[2112926]=A;if((A|0)!=0){gGz(A|0,0,u|0)}u=c[2414564]|0;gGz(u|0,0,(c[2411464]|0)-u|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];u=c[3532592]|0;if((u|0)!=0){gGC(9104152,u|0,280)|0}c[2113054]=c[2113060]}RI();u=c[2394]|0;A=c[14130368+(u<<2)>>2]|0;if((A|0)!=0){gGC(A|0,9104152,280)|0}c[8452240+(u<<2)>>2]=c[2113054];c[2394]=-1;aE7();gGz(c[2383428]|0,0,4096);gGz(c[2383426]|0,0,4096);u=c[2383424]|0;if((u|0)!=0){gGz(u|0,0,4096);gGz(c[2383422]|0,0,4096)}gGz(c[2383434]|0,0,16);gGz(c[2383435]|0,0,16);gGz(c[2383430]|0,0,8192);gGz(c[2383431]|0,0,8192);u=c[2383432]|0;if((u|0)!=0){gGz(u|0,0,8192);gGz(c[2383433]|0,0,8192)}b[4766836]=0;c[2426968]=0;c[3528794]=0;c[1765522]=65535;c[2429656]=0;c[2427042]=0;c[2429386]=0;c[2429384]=0;c[2429382]=0;c[3530258]=3;y=0;i=d;return y|0}}while(0);c[2414862]=0;y=1;i=d;return y|0}function aEe(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=c[3529902]|0;f=c[2387108]|0;g=(c[642608+(c[2436]<<2)>>2]|0)+124|0;if((c[g>>2]<<1|0)>0){h=0;do{i=e[f+((h|1)<<1)>>1]|0;c[d+(((h|0)/2|0)<<2)>>2]=i<<8&63488|(e[f+(h<<1)>>1]|0)>>>3&31|i>>>8<<3&2016;h=h+2|0;}while((h|0)<(c[g>>2]<<1|0))}a[9547112]=0;aE3();aE5();g=c[2113068]|0;h=c[2113070]|0;f=ag(h,g)|0;if((f|0)>0){d=c[2112926]|0;i=0;do{b[d+(i<<1)>>1]=512;i=i+1|0;}while((i|0)<(f|0))}f=c[2388468]|0;aE0(2,f,65536);i=c[2388464]|0;aE0(3,i,65536);d=c[2383420]|0;gGz(d|0,0,131072);gGz(c[2383410]|0,0,131072);j=c[2112926]|0;if((h|0)>0){k=f;l=i;m=j;n=d;o=0}else{p=j;aE0(3,p,65536);aE0(1,p,16);q=c[2386560]|0;aEh(q,3);r=c[3529668]|0;aEh(r,4);aE0(0,p,255);s=c[3529902]|0;R8(s);return 0}while(1){if((g|0)>0){d=0;do{b[m+(d<<1)>>1]=b[k+(d<<1)>>1]&15|b[l+(d<<1)>>1]<<4&240|512;a[n+d|0]=0;d=d+1|0;}while((d|0)<(g|0))}d=o+1|0;if((d|0)<(h|0)){k=k+(g<<1)|0;l=l+(g<<1)|0;m=m+(g<<1)|0;n=n+512|0;o=d}else{p=j;break}}aE0(3,p,65536);aE0(1,p,16);q=c[2386560]|0;aEh(q,3);r=c[3529668]|0;aEh(r,4);aE0(0,p,255);s=c[3529902]|0;R8(s);return 0}function aEf(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4685676+(b*112|0)>>2];c[a+104>>2]=c[4685680+(b*112|0)>>2];c[a+108>>2]=c[4685684+(b*112|0)>>2];d=0;return d|0}function aEg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<22&(d|0)==0)){e=1;return e|0}c[a>>2]=4685576+(b*112|0);e=0;return e|0}function aEh(d,f){d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;g=d;d=(f|0)==3;f=d?32767:4095;h=c[3528660]|0;i=c[2112926]|0;j=(c[2113222]&1|0)==0;k=1020;while(1){l=b[g+((k|3)<<1)>>1]|0;m=l&65535;do{if(l<<16>>16!=0){n=e[g+((k|1)<<1)>>1]|0;o=e[g+((k|2)<<1)>>1]|0;p=o>>>12;q=o>>>8&15;r=e[g+(k<<1)>>1]|0;if(!((r&8192|0)==0|j)){break}s=o&31;L30909:do{if(d){switch(o&224|0){case 128:{t=1024;u=1;v=32;w=14121248;x=s;break L30909;break};case 32:{t=1024;u=1;v=32;w=14121248;x=s;break L30909;break};case 0:{t=1024;u=1;v=128;w=14121248;x=s;break L30909;break};case 192:case 64:{t=1024;u=1;v=8;w=14121248;x=s;break L30909;break};case 160:{t=1024;u=1;v=32;w=14121248;x=s;break L30909;break};default:{t=1024;u=1;v=128;w=14121248;x=s;break L30909}}}else{t=1536;u=2;v=(b[4766836]|0)==0?64:8;w=14121192;x=(o&16|0)==0?s:o&15}}while(0);o=c[w>>2]|0;s=r&16384;y=r&32768;do{if((a[h]|0)==0){z=s>>>14;A=z^1;B=r>>>15;C=n&511;D=r&511;E=D>>>0>384?r|-512:D;D=(z|0)==1;z=D?16:-16;F=(D?-16:q<<4)+(C>>>0>384?n|-512:C)|0;if((B|0)==1){G=16;H=z;I=E-16|0;J=F;K=0;L=A;break}else{G=-16;H=z;I=E+(p<<4)|0;J=F;K=B^1;L=A;break}}else{A=304-((n&256|0)==0?n&511:n|-256)|0;B=240-((r&256|0)==0?r&511:r|-256)|0;F=(A|0)>431?A-512|0:A;A=(B|0)>383?B-512|0:B;if((s|0)==0){M=16;N=F-(q<<4)|0}else{M=-16;N=F+16|0}if((y|0)==0){G=16;H=M;I=A-(p<<4)|0;J=N;K=0;L=s;break}else{G=-16;H=M;I=A+16|0;J=N;K=y;L=s;break}}}while(0);s=m&f;if((q|0)==0){break}y=(p|0)==0;r=t|x<<4;n=0;do{if(!y){A=(ag(n,p)|0)+s|0;F=(ag(q-n|0,H)|0)+J|0;B=0;do{aEY(i,o,A+B|0,r,F,(ag(p-B|0,G)|0)+I|0,L,K,v,u);B=B+1|0;}while((B|0)<(p|0))}n=n+1|0;}while((n|0)<(q|0))}}while(0);if((k|0)==0){break}else{k=k-4|0}}return}function aEi(a){a=a|0;return a>>>4<<12&12288|0}function aEj(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;a=b&1;d=c[3530258]|0;if((a|0)!=(d&1|0)){e=c[3529780]|0;f=e+((a<<18)+262144)|0;gGC(e|0,f|0,262144)|0}f=b&2;if((f|0)==(d&2|0)){c[3530258]=b;return}d=c[3529734]|0;e=d+((f<<17)+262144)|0;gGC(d|0,e|0,262144)|0;c[3530258]=b;return}function aEk(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;f=c[3529902]|0;g=c[2387108]|0;h=(c[642608+(c[2436]<<2)>>2]|0)+124|0;if((c[h>>2]<<1|0)>0){i=0;do{j=e[g+((i|1)<<1)>>1]|0;c[f+(((i|0)/2|0)<<2)>>2]=j<<8&63488|(e[g+(i<<1)>>1]|0)>>>3&31|j>>>8<<3&2016;i=i+2|0;}while((i|0)<(c[h>>2]<<1|0))}a[9547112]=0;aE3();aE5();h=c[2113068]|0;i=c[2113070]|0;g=ag(i,h)|0;if((g|0)>0){f=c[2112926]|0;j=0;do{b[f+(j<<1)>>1]=768;j=j+1|0;}while((j|0)<(g|0))}g=b[4766836]|0;if((g&3)==0){aE0(2,c[2388468]|0,65536);aE0(3,c[2388464]|0,65536);k=b[4766836]|0}else{k=g}g=c[2383420]|0;gGz(g|0,0,131072);gGz(c[2383410]|0,0,131072);j=k&65535;k=j&3;if((k|0)==1){f=c[2112926]|0;aE0(3,f,65537);aE0(1,f,2);aE0(2,f,4)}else if((k|0)==2){f=c[2112926]|0;aE0(1,f,65537);aE0(3,f,2);aE0(2,f,4)}else if((k|0)==0){do{if((j&4|0)==0){k=c[2112926]|0;aE0(3,k,65537);aE0(2,k,2);l=k}else{k=c[2112926]|0;if((i|0)<=0){l=k;break}f=c[2388468]|0;m=c[2388464]|0;n=k;o=g;p=0;while(1){if((h|0)>0){q=0;do{b[n+(q<<1)>>1]=b[f+(q<<1)>>1]&15|b[m+(q<<1)>>1]<<4&240|768;a[o+q|0]=3;q=q+1|0;}while((q|0)<(h|0))}q=p+1|0;if((q|0)<(i|0)){f=f+(h<<1)|0;m=m+(h<<1)|0;n=n+(h<<1)|0;o=o+512|0;p=q}else{l=k;break}}}}while(0);aE0(1,l,4)}l=c[3529668]|0;h=c[3528660]|0;i=c[2112926]|0;g=(c[2113222]&1|0)==0;if((d|0)==0){d=1020;while(1){j=b[l+((d|1)<<1)>>1]|0;k=j&65535;do{if(j<<16>>16!=0){p=e[l+((d|2)<<1)>>1]|0;o=p&24576;if((o|0)==24576){r=252}else if((o|0)==16384){r=240}else{r=0}o=e[l+(d<<1)>>1]|0;if(!((o&4096|0)==0|g)){break}n=o&8192;m=o&16384;f=1<<(o>>>9&3);q=f-1|0;s=p&511;t=o&511;u=s>>>0>319?p|-512:s;s=t>>>0>255?o|-512:t;t=(m>>>13^2)-1|0;o=((m|0)!=0?0:q)+(k&-f)|0;if((a[h]|0)==0){v=m;w=n;x=s;y=u;z=16}else{v=m>>>14^1;w=n>>>13^1;x=240-s|0;y=304-u|0;z=-16}if((f|0)<=0){break}f=p>>>9<<6&960|1024;p=q;while(1){q=c[3530312]|0;u=o-(ag(p,t)|0)&32767;aEY(i,q,u,f,y,(ag(p,z)|0)+x|0,w,v,r,-1);if((p|0)>0){p=p-1|0}else{break}}}}while(0);k=d-4|0;if((k|0)>-1){d=k}else{A=i;break}}aE0(0,A,0);B=c[3529902]|0;R8(B);return}else{d=1020;while(1){r=b[l+((d|1)<<1)>>1]|0;v=r&65535;do{if(r<<16>>16!=0){w=e[l+((d|2)<<1)>>1]|0;x=w&24576;if((x|0)==24576){C=252}else if((x|0)==16384){C=240}else{C=0}x=e[l+(d<<1)>>1]|0;if(!((x&4096|0)==0|g)){break}z=x&8192;y=x&16384;k=1<<(x>>>9&3);j=k-1|0;p=w&511;f=x&511;t=p>>>0>319?w|-512:p;p=f>>>0>255?x|-512:f;f=(y>>>13^2)-1|0;x=((y|0)!=0?0:j)+(v&-k)|0;if((a[h]|0)==0){D=y;E=z;F=p;G=t;H=16}else{D=y>>>14^1;E=z>>>13^1;F=240-p|0;G=304-t|0;H=-16}if((k|0)<=0){break}k=w>>>15<<4|w>>>9<<6&960|1024;w=j;while(1){j=c[3530312]|0;t=x-(ag(w,f)|0)&32767;aEY(i,j,t,k,G,(ag(w,H)|0)+F|0,E,D,C,-1);if((w|0)>0){w=w-1|0}else{break}}}}while(0);v=d-4|0;if((v|0)>-1){d=v}else{A=i;break}}aE0(0,A,0);B=c[3529902]|0;R8(B);return}}function aEl(d,f,g,h,i){d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;j=d;d=(i|0)==4;k=(i|0)==3?32767:4095;i=c[3528660]|0;l=c[2112926]|0;m=a[690376]|0?8:0;n=c[2113070]|0;o=c[2113068]|0;p=c[2383420]|0;q=(c[2113222]&1|0)==0;r=0;do{s=b[j+((r|1)<<1)>>1]|0;t=s&65535;L31019:do{if(s<<16>>16!=0){u=e[j+((r|2)<<1)>>1]|0;if((h|0)==3){if((u&49152|0)!=32768){break}}else if((h|0)==2){if((u&32768|0)==0){break}}else if((h|0)==4){if((u&49152|0)!=49152){break}}else{if((u&32768|0)!=0){break}}v=e[j+(r<<1)>>1]|0;if(!((v&4096|0)==0|q)){break}w=u>>>9;x=w&31;if(d){y=(w&16|0)==0?x:w&15}else{y=x}x=v&8192;w=v&16384;z=1<<(v>>>9&3);A=z-1|0;B=u&511;C=v&511;D=B>>>0>319?u|-512:B;B=C>>>0>255?v|-512:C;C=(w>>>13^2)-1|0;if((a[i]|0)==0){E=w>>>14^1;F=x>>>13^1;G=B;H=D;I=16}else{E=w;F=x;G=240-B|0;H=304-D|0;I=-16}D=((w|0)==0?A:0)+(t&-z)&k;if((z|0)<=0){break}z=(y<<4)+g|0;w=(F|0)==0?0:15;B=(E|0)==0?w:w|240;w=A;while(1){A=D-(ag(w,C)|0)|0;x=A<<8;A=(ag(w,I)|0)+G-m|0;v=0;while(1){L31040:do{if((A|0)>-1&(A|0)<(n|0)){u=v<<4;J=A<<9;K=ag(o,A)|0;L=0;M=H;while(1){do{if((M|0)>-1&(M|0)<(o|0)){N=a[f+((L+u^B)+x)|0]|0;if(N<<24>>24==0){break}b[l+(K+M<<1)>>1]=(N&255|z)&65535;N=p+(M+J)|0;a[N]=a[N]|-128}}while(0);N=L+1|0;if((N|0)>=16){break L31040}L=N;M=M+1|0}}}while(0);M=v+1|0;if((M|0)>=16){break}A=A+1|0;v=M}if((w|0)<=0){break L31019}w=w-1|0}}}while(0);r=r+4|0;}while((r|0)<1024);return}function aEm(d,e){d=d|0;e=e|0;var f=0,g=0;do{if((d|0)==2416977){c[2383412]=e&255;if((a[9661085]|0)==1){break}a[9661085]=1;if((a[9661088]|0)!=0){break}a[9661088]=2}else if((d|0)==2359296|(d|0)==2359297){f=c[2386558]|0;g=c[2386388]|0;gGC(f|0,g|0,2048)|0;return}else if((d|0)==2375680|(d|0)==2375681){g=c[3529680]|0;f=c[3529628]|0;gGC(g|0,f|0,2048)|0;return}else if((d|0)==2629640|(d|0)==2629641){f=c[2387300]|0;g=c[2387106]|0;gGC(f|0,g|0,8192)|0;return}else if((d|0)==2228224|(d|0)==2228225){b[4766836]=e&255;return}else{if((d&268433408|0)==2416640){break}return}}while(0);a[(c[3529858]|0)+(d&2047^1)|0]=e;return}function aEn(d,e){d=d|0;e=e|0;var f=0,g=0;f=d&-16;if((f|0)==2555904){b[(c[2383435]|0)+((d>>>1&7)<<1)>>1]=e;return}else if((f|0)==2490368){b[(c[2383434]|0)+((d>>>1&7)<<1)>>1]=e;return}else{do{if((d|0)==2228224){b[4766836]=e;return}else if((d|0)==2629640){f=c[2387300]|0;g=c[2387106]|0;gGC(f|0,g|0,8192)|0;return}else if((d|0)==2416976){c[2383412]=e&255;if((a[9661085]|0)==1){break}a[9661085]=1;if((a[9661088]|0)!=0){break}a[9661088]=2}else if((d|0)==2359296){g=c[2386558]|0;f=c[2386388]|0;gGC(g|0,f|0,2048)|0;return}else if((d|0)==2375680){f=c[3529680]|0;g=c[3529628]|0;gGC(f|0,g|0,2048)|0;return}else{if((d&268433408|0)==2416640){break}return}}while(0);b[(c[3529858]|0)+(d&2046)>>1]=e;return}}function aEo(d){d=d|0;var f=0;switch(d|0){case 2418369:{f=a[9634696]|0;break};case 2416952:case 2416953:{f=(b[4775088]&7|c[2383408]&8)&255;break};case 2417477:{f=b[4775089]&255;break};case 2417476:{f=(e[4775089]|0)>>>8&255;break};case 2418368:{f=a[9634697]|0;break};default:{f=0}}return f|0}function aEp(a){a=a|0;var e=0;if((a|0)==2416952){e=(b[4775088]&7|c[2383408]&8)&65535;return e|0}else if((a|0)==2417476){e=b[4775089]|0;return e|0}else if((a|0)==2418368){e=(d[9634697]|0)<<8|(d[9634696]|0);return e|0}else{e=0;return e|0}return 0}function aEq(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3057428+(b*112|0)>>2];c[a+104>>2]=c[3057432+(b*112|0)>>2];c[a+108>>2]=c[3057436+(b*112|0)>>2];d=0;return d|0}function aEr(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=3057328+(b*112|0);e=0;return e|0}function aEs(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1307552+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aEt(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>44){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4214664+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aEu(){var f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0;f=i;i=i+840|0;g=f|0;j=f+112|0;k=f+120|0;l=f+232|0;m=f+240|0;n=f+352|0;o=f+360|0;p=f+472|0;q=f+480|0;r=f+592|0;s=f+600|0;t=f+712|0;u=f+720|0;v=f+832|0;c[2424]=5800;c[2414860]=0;c[2388080]=0;c[3531186]=1048576;c[2387776]=2097152;c[3530758]=2162688;c[3530522]=2424832;c[3530282]=6619136;c[3530390]=7667712;c[3530310]=11862016;c[3530288]=20250624;c[3541206]=28639232;c[3529746]=28639232;c[3529702]=29687808;c[3529900]=30474240;c[2388466]=30482432;c[2388462]=30636032;c[2414562]=30789632;c[2388210]=30789632;c[2387798]=30855168;c[2386388]=30863360;c[3529628]=30865408;c[2386558]=30867456;c[3529680]=30869504;c[2387106]=30871552;c[2387300]=30879744;c[3529858]=30887936;c[3528658]=30891008;c[2411462]=30891009;w=0;while(1){if((w|0)>=1024){break}x=9638528+(w<<2)|0;if((c[x>>2]|0)==0){y=24361;break}else{w=w+1|0}}do{if((y|0)==24361){w=gGq(30891009)|0;c[x>>2]=w;if((w|0)==0){break}c[2414860]=w;gGz(w|0,0,30891009);c[2388080]=w;c[3531186]=w+1048576;c[2387776]=w+2097152;c[3530758]=w+2162688;c[3530522]=w+2424832;c[3530282]=w+6619136;c[3530390]=w+7667712;c[3530310]=w+11862016;c[3530288]=w+20250624;z=w+28639232|0;c[3541206]=z;c[3529746]=z;c[3529702]=w+29687808;c[3529900]=w+30474240;c[2388466]=w+30482432;c[2388462]=w+30636032;z=w+30789632|0;c[2414562]=z;c[2388210]=z;c[2387798]=w+30855168;c[2386388]=w+30863360;c[3529628]=w+30865408;c[2386558]=w+30867456;c[3529680]=w+30869504;c[2387106]=w+30871552;c[2387300]=w+30879744;c[3529858]=w+30887936;c[2386318]=w+30889984;c[3528658]=w+30891008;z=w+30891009|0;c[2411462]=z;c[2414002]=z;if((R6(w+1|0,0,2)|0)!=0){A=1;i=f;return A|0}if((R6(c[2388080]|0,1,2)|0)!=0){A=1;i=f;return A|0}if((R6((c[2388080]|0)+524289|0,2,2)|0)!=0){A=1;i=f;return A|0}if((R6((c[2388080]|0)+524288|0,3,2)|0)!=0){A=1;i=f;return A|0}w=c[2387776]|0;if((c[3542200]|0)==0){A=1;i=f;return A|0}z=u+108|0;c[z>>2]=0;B=u+100|0;c[B>>2]=0;C=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[C&16383](u,4)|0;do{if((c[z>>2]|0)!=0){C=c[B>>2]|0;c[v>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](v,4,0)|0;if((C|0)<1){A=1;i=f;return A|0}if((gzL(w,0,4)|0)==0){break}else{A=1}i=f;return A|0}}while(0);if((R6(c[3530758]|0,5,2)|0)!=0){A=1;i=f;return A|0}if((R6((c[3530758]|0)+1|0,6,2)|0)!=0){A=1;i=f;return A|0}w=c[3530522]|0;if((c[3542200]|0)==0){A=1;i=f;return A|0}B=s+108|0;c[B>>2]=0;z=s+100|0;c[z>>2]=0;C=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[C&16383](s,7)|0;do{if((c[B>>2]|0)!=0){C=c[z>>2]|0;c[t>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](t,7,0)|0;if((C|0)<1){A=1;i=f;return A|0}if((gzL(w,0,7)|0)==0){break}else{A=1}i=f;return A|0}}while(0);w=(c[3530522]|0)+1048576|0;if((c[3542200]|0)==0){A=1;i=f;return A|0}z=q+108|0;c[z>>2]=0;B=q+100|0;c[B>>2]=0;C=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[C&16383](q,8)|0;do{if((c[z>>2]|0)!=0){C=c[B>>2]|0;c[r>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](r,8,0)|0;if((C|0)<1){A=1;i=f;return A|0}if((gzL(w,0,8)|0)==0){break}else{A=1}i=f;return A|0}}while(0);if((R6(c[3530282]|0,9,2)|0)!=0){A=1;i=f;return A|0}w=c[3530390]|0;if((c[3542200]|0)==0){A=1;i=f;return A|0}B=o+108|0;c[B>>2]=0;z=o+100|0;c[z>>2]=0;C=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[C&16383](o,10)|0;do{if((c[B>>2]|0)!=0){C=c[z>>2]|0;c[p>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](p,10,0)|0;if((C|0)<1){A=1;i=f;return A|0}if((gzL(w,0,10)|0)==0){break}else{A=1}i=f;return A|0}}while(0);w=(c[3530390]|0)+1048576|0;if((c[3542200]|0)==0){A=1;i=f;return A|0}z=m+108|0;c[z>>2]=0;B=m+100|0;c[B>>2]=0;C=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[C&16383](m,11)|0;do{if((c[z>>2]|0)!=0){C=c[B>>2]|0;c[n>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](n,11,0)|0;if((C|0)<1){A=1;i=f;return A|0}if((gzL(w,0,11)|0)==0){break}else{A=1}i=f;return A|0}}while(0);if((R6((c[3530310]|0)+1|0,12,2)|0)!=0){A=1;i=f;return A|0}if((R6(c[3530310]|0,13,2)|0)!=0){A=1;i=f;return A|0}if((R6((c[3530288]|0)+1|0,14,2)|0)!=0){A=1;i=f;return A|0}if((R6(c[3530288]|0,15,2)|0)!=0){A=1;i=f;return A|0}w=(c[3529746]|0)+262144|0;if((c[3542200]|0)==0){A=1;i=f;return A|0}B=k+108|0;c[B>>2]=0;z=k+100|0;c[z>>2]=0;C=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[C&16383](k,16)|0;do{if((c[B>>2]|0)!=0){C=c[z>>2]|0;c[l>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](l,16,0)|0;if((C|0)<1){A=1;i=f;return A|0}if((gzL(w,0,16)|0)==0){break}else{A=1}i=f;return A|0}}while(0);w=(c[3529702]|0)+262144|0;if((c[3542200]|0)==0){A=1;i=f;return A|0}z=g+108|0;c[z>>2]=0;B=g+100|0;c[B>>2]=0;C=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[C&16383](g,17)|0;do{if((c[z>>2]|0)!=0){C=c[B>>2]|0;c[j>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](j,17,0)|0;if((C|0)<1){A=1;i=f;return A|0}if((gzL(w,0,17)|0)==0){break}else{A=1}i=f;return A|0}}while(0);aFg(c[3530758]|0,131072,1574056,720536,1110256);aFg(c[3530522]|0,3145728,1574056,720536,1110256);aFg(c[3530390]|0,2097152,1574056,720536,1110256);w=c[3530282]|0;B=w;z=0;while(1){if((z|0)>=1024){E=0;break}F=9638528+(z<<2)|0;if((c[F>>2]|0)==0){y=24405;break}else{z=z+1|0}}do{if((y|0)==24405){z=gGq(1048576)|0;c[F>>2]=z;if((z|0)==0){E=0;break}gGz(z|0,0,1048576);E=z}}while(0);z=E;C=0;do{D=B+(C<<1)|0;b[D>>1]=ga(b[D>>1]|0)|0;C=C+1|0;}while((C|0)<524288);gGC(E|0,w|0,1048576)|0;C=0;while(1){b[B+(C<<1)>>1]=b[z+((e[720536+((C&2047)<<1)>>1]|0|C&-2048)<<1)>>1]|0;D=C+1|0;if((D|0)<524288){C=D}else{G=0;break}}while(1){if((G|0)>=1024){H=0;break}I=9638528+(G<<2)|0;if((c[I>>2]|0)==(E|0)){y=24413;break}else{G=G+1|0}}if((y|0)==24413){gGr(E);c[I>>2]=0;H=0}do{C=B+(H<<1)|0;b[C>>1]=ga(b[C>>1]|0)|0;H=H+1|0;}while((H|0)<524288);aFh(c[2388080]|0,c[3531186]|0,1048576,17082,0,24);B=c[3530758]|0;aE_(B,B,131072,1);B=c[3530390]|0;aE_(B,B,2097152,0);aE$(c[3530310]|0,4194304);aE$(c[3530288]|0,4194304);B=0;while(1){if((B|0)>=1024){break}J=9638528+(B<<2)|0;if((c[J>>2]|0)==0){y=24418;break}else{B=B+1|0}}L31274:do{if((y|0)==24418){B=gGq(4194304)|0;c[J>>2]=B;if((B|0)==0){break}gGz(B|0,0,4194304);C=c[3530522]|0;gGC(B|0,C|0,2097152)|0;z=B+2097152|0;gGz(z|0,0,2097152);w=c[3530282]|0;gGC(z|0,w|0,1048576)|0;w=0;while(1){z=w<<8;gGz(C+z|0,0,256);D=w<<9;K=0;do{L=1<<5-K;M=(c[601088+(K<<2)>>2]|0)+D|0;N=0;do{O=M+(c[608544+(N<<2)>>2]|0)|0;P=(N<<4)+z|0;Q=0;do{R=O+(c[613816+(Q<<2)>>2]|0)|0;if(((d[B+((R|0)/8|0)|0]|0)&128>>>((R&7)>>>0)|0)!=0){R=C+(P+Q)|0;a[R]=(d[R]|0|L)&255}Q=Q+1|0;}while((Q|0)<16);N=N+1|0;}while((N|0)<16);K=K+1|0;}while((K|0)<6);K=w+1|0;if((K|0)<16384){w=K}else{S=0;break}}while(1){w=C+S|0;a[w]=a[w]&31;w=S+1|0;if((w|0)<4194304){S=w}else{T=0;break}}while(1){if((T|0)>=1024){break L31274}U=9638528+(T<<2)|0;if((c[U>>2]|0)==(B|0)){break}else{T=T+1|0}}gGr(B);c[U>>2]=0}}while(0);aE1(0,0,1);C=c[3530522]|0;w=c[3530390]|0;c[2383440]=c[3530758];c[2383441]=C;c[2383442]=w;c[2383436]=4095;c[2383437]=16383;c[2383438]=16383;c[2429667]=256;c[2429668]=768;c[2429669]=1024;a[690376]=1;c[2429664]=31;c[2429665]=31;c[2429437]=3340;c[2429438]=50;c[2429439]=50;fxU(0,425984);if((c[2394]|0)==0){V=c[2112932]|0}else{c[2394]=0;w=c[3532596]|0;c[2112932]=w;C=c[3532592]|0;if((C|0)!=0){gGC(9104152,C|0,280)|0}c[2113054]=c[2113060];V=w}w=c[2388080]|0;C=V|0;K=C;z=0;while(1){c[K>>2]=w+z;D=z+1024|0;if(D>>>0>1048575){break}else{K=K+4|0;z=D}}z=c[3531186]|0;K=C;w=0;while(1){c[K+131072>>2]=z+w;D=w+1024|0;if(D>>>0>1048575){break}else{K=K+4|0;w=D}}w=c[2388210]|0;K=V+8192|0;z=2097152;while(1){C=w+(z-2097152)|0;c[K>>2]=C;c[K+65536>>2]=C;c[K+131072>>2]=C;C=z+1024|0;if(C>>>0>2162687){break}else{K=K+4|0;z=C}}z=c[2386388]|0;c[V+9248>>2]=z;c[V+74784>>2]=z;c[V+140320>>2]=z;K=z+1024|0;c[V+9252>>2]=K;c[V+74788>>2]=K;c[V+140324>>2]=K;K=c[3529628]|0;c[V+9312>>2]=K;c[V+74848>>2]=K;c[V+140384>>2]=K;z=K+1024|0;c[V+9316>>2]=z;c[V+74852>>2]=z;c[V+140388>>2]=z;z=c[2383430]|0;c[V+9792>>2]=z;c[V+75328>>2]=z;c[V+140864>>2]=z;K=z+1024|0;c[V+9796>>2]=K;c[V+75332>>2]=K;c[V+140868>>2]=K;K=z+2048|0;c[V+9800>>2]=K;c[V+75336>>2]=K;c[V+140872>>2]=K;K=z+3072|0;c[V+9804>>2]=K;c[V+75340>>2]=K;c[V+140876>>2]=K;K=z+4096|0;c[V+9808>>2]=K;c[V+75344>>2]=K;c[V+140880>>2]=K;K=z+5120|0;c[V+9812>>2]=K;c[V+75348>>2]=K;c[V+140884>>2]=K;K=z+6144|0;c[V+9816>>2]=K;c[V+75352>>2]=K;c[V+140888>>2]=K;K=z+7168|0;c[V+9820>>2]=K;c[V+75356>>2]=K;c[V+140892>>2]=K;K=c[2383431]|0;c[V+9824>>2]=K;c[V+75360>>2]=K;c[V+140896>>2]=K;z=K+1024|0;c[V+9828>>2]=z;c[V+75364>>2]=z;c[V+140900>>2]=z;z=K+2048|0;c[V+9832>>2]=z;c[V+75368>>2]=z;c[V+140904>>2]=z;z=K+3072|0;c[V+9836>>2]=z;c[V+75372>>2]=z;c[V+140908>>2]=z;z=K+4096|0;c[V+9840>>2]=z;c[V+75376>>2]=z;c[V+140912>>2]=z;z=K+5120|0;c[V+9844>>2]=z;c[V+75380>>2]=z;c[V+140916>>2]=z;z=K+6144|0;c[V+9848>>2]=z;c[V+75384>>2]=z;c[V+140920>>2]=z;z=K+7168|0;c[V+9852>>2]=z;c[V+75388>>2]=z;c[V+140924>>2]=z;z=c[2383428]|0;c[V+9856>>2]=z;c[V+75392>>2]=z;c[V+140928>>2]=z;K=z+1024|0;c[V+9860>>2]=K;c[V+75396>>2]=K;c[V+140932>>2]=K;K=z+2048|0;c[V+9864>>2]=K;c[V+75400>>2]=K;c[V+140936>>2]=K;K=z+3072|0;c[V+9868>>2]=K;c[V+75404>>2]=K;c[V+140940>>2]=K;K=c[2383426]|0;c[V+9888>>2]=K;c[V+75424>>2]=K;c[V+140960>>2]=K;z=K+1024|0;c[V+9892>>2]=z;c[V+75428>>2]=z;c[V+140964>>2]=z;z=K+2048|0;c[V+9896>>2]=z;c[V+75432>>2]=z;c[V+140968>>2]=z;z=K+3072|0;c[V+9900>>2]=z;c[V+75436>>2]=z;c[V+140972>>2]=z;z=c[2383432]|0;c[V+10048>>2]=z;c[V+75584>>2]=z;c[V+141120>>2]=z;K=z+1024|0;c[V+10052>>2]=K;c[V+75588>>2]=K;c[V+141124>>2]=K;K=z+2048|0;c[V+10056>>2]=K;c[V+75592>>2]=K;c[V+141128>>2]=K;K=z+3072|0;c[V+10060>>2]=K;c[V+75596>>2]=K;c[V+141132>>2]=K;K=z+4096|0;c[V+10064>>2]=K;c[V+75600>>2]=K;c[V+141136>>2]=K;K=z+5120|0;c[V+10068>>2]=K;c[V+75604>>2]=K;c[V+141140>>2]=K;K=z+6144|0;c[V+10072>>2]=K;c[V+75608>>2]=K;c[V+141144>>2]=K;K=z+7168|0;c[V+10076>>2]=K;c[V+75612>>2]=K;c[V+141148>>2]=K;K=c[2383433]|0;c[V+10080>>2]=K;c[V+75616>>2]=K;c[V+141152>>2]=K;z=K+1024|0;c[V+10084>>2]=z;c[V+75620>>2]=z;c[V+141156>>2]=z;z=K+2048|0;c[V+10088>>2]=z;c[V+75624>>2]=z;c[V+141160>>2]=z;z=K+3072|0;c[V+10092>>2]=z;c[V+75628>>2]=z;c[V+141164>>2]=z;z=K+4096|0;c[V+10096>>2]=z;c[V+75632>>2]=z;c[V+141168>>2]=z;z=K+5120|0;c[V+10100>>2]=z;c[V+75636>>2]=z;c[V+141172>>2]=z;z=K+6144|0;c[V+10104>>2]=z;c[V+75640>>2]=z;c[V+141176>>2]=z;z=K+7168|0;c[V+10108>>2]=z;c[V+75644>>2]=z;c[V+141180>>2]=z;z=c[2383424]|0;c[V+10112>>2]=z;c[V+75648>>2]=z;c[V+141184>>2]=z;K=z+1024|0;c[V+10116>>2]=K;c[V+75652>>2]=K;c[V+141188>>2]=K;K=z+2048|0;c[V+10120>>2]=K;c[V+75656>>2]=K;c[V+141192>>2]=K;K=z+3072|0;c[V+10124>>2]=K;c[V+75660>>2]=K;c[V+141196>>2]=K;K=c[2383422]|0;c[V+10144>>2]=K;c[V+75680>>2]=K;c[V+141216>>2]=K;z=K+1024|0;c[V+10148>>2]=z;c[V+75684>>2]=z;c[V+141220>>2]=z;z=K+2048|0;c[V+10152>>2]=z;c[V+75688>>2]=z;c[V+141224>>2]=z;z=K+3072|0;c[V+10156>>2]=z;c[V+75692>>2]=z;c[V+141228>>2]=z;z=c[2387106]|0;c[V+10304>>2]=z;c[V+75840>>2]=z;c[V+141376>>2]=z;K=z+1024|0;c[V+10308>>2]=K;c[V+75844>>2]=K;c[V+141380>>2]=K;K=z+2048|0;c[V+10312>>2]=K;c[V+75848>>2]=K;c[V+141384>>2]=K;K=z+3072|0;c[V+10316>>2]=K;c[V+75852>>2]=K;c[V+141388>>2]=K;K=z+4096|0;c[V+10320>>2]=K;c[V+75856>>2]=K;c[V+141392>>2]=K;K=z+5120|0;c[V+10324>>2]=K;c[V+75860>>2]=K;c[V+141396>>2]=K;K=z+6144|0;c[V+10328>>2]=K;c[V+75864>>2]=K;c[V+141400>>2]=K;K=z+7168|0;c[V+10332>>2]=K;c[V+75868>>2]=K;c[V+141404>>2]=K;c[V+196728>>2]=3142;c[V+196648>>2]=1374;c[V+196688>>2]=2312;c[V+196608>>2]=484;K=c[3532592]|0;if((K|0)!=0){gGC(K|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;aE8(c[2387776]|0,c[2387798]|0,8055e3,0,2378,.8,1006875,1.4,2013750,.3);h[745421]=.8;c[2436794]=1;h[745420]=.8;c[2436792]=2;K=c[642608+(c[2436]<<2)>>2]|0;z=c[K+128>>2]|0;if((c[K+52>>2]&4|0)==0){c[2113068]=z;w=c[K+132>>2]|0;c[2113070]=w;c[2443814]=z;c[2440436]=w;W=z;X=w}else{c[2113070]=z;w=c[K+132>>2]|0;c[2113068]=w;c[2440436]=z;c[2443814]=w;W=w;X=z}z=ag(W<<1,X)|0;w=gGq(z)|0;c[2112926]=w;if((w|0)!=0){gGz(w|0,0,z|0)}z=c[2414562]|0;gGz(z|0,0,(c[2411462]|0)-z|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];z=c[3532592]|0;if((z|0)!=0){gGC(9104152,z|0,280)|0}c[2113054]=c[2113060]}RI();z=c[2394]|0;w=c[14130368+(z<<2)>>2]|0;if((w|0)!=0){gGC(w|0,9104152,280)|0}c[8452240+(z<<2)>>2]=c[2113054];c[2394]=-1;aE7();z=c[3530240]|0;if((z&2|0)!=0){w=c[3529702]|0;K=w+262144|0;gGC(w|0,K|0,262144)|0}if((z&1|0)==0){z=c[3529746]|0;K=z+524288|0;gGC(z|0,K|0,262144)|0}c[3530240]=1;gGz(c[2383428]|0,0,4096);gGz(c[2383426]|0,0,4096);K=c[2383424]|0;if((K|0)!=0){gGz(K|0,0,4096);gGz(c[2383422]|0,0,4096)}gGz(c[2383434]|0,0,16);gGz(c[2383435]|0,0,16);gGz(c[2383430]|0,0,8192);gGz(c[2383431]|0,0,8192);K=c[2383432]|0;if((K|0)!=0){gGz(K|0,0,8192);gGz(c[2383433]|0,0,8192)}b[4766836]=0;c[2426968]=0;c[3528794]=0;c[1765522]=65535;c[2429656]=0;c[2427042]=0;c[2429386]=0;c[2429384]=0;c[2429382]=0;A=0;i=f;return A|0}}while(0);c[2414860]=0;A=1;i=f;return A|0}function aEv(){var a=0,b=0,d=0,e=0,f=0;c[2113070]=0;c[2113068]=0;a=c[2112926]|0;if((a|0)!=0){gGr(a);c[2112926]=0}aE2();aFe();if((c[2392]|0)>=0){a=0;do{b=14130368+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}b=14130384+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}a=a+1|0;}while((a|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;a=c[2414860]|0;b=0;while(1){if((b|0)>=1024){e=24514;break}f=9638528+(b<<2)|0;if((c[f>>2]|0)==(a|0)){break}else{b=b+1|0}}if((e|0)==24514){c[2414860]=0;return 0}gGr(a);c[f>>2]=0;c[2414860]=0;return 0}function aEw(){var d=0,e=0,f=0,g=0,h=0,i=0;if((a[9623424]|0)!=0){d=c[2414562]|0;gGz(d|0,0,(c[2411462]|0)-d|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;aE7();d=c[3530240]|0;if((d&2|0)!=0){e=c[3529702]|0;f=e+262144|0;gGC(e|0,f|0,262144)|0}if((d&1|0)==0){d=c[3529746]|0;f=d+524288|0;gGC(d|0,f|0,262144)|0}c[3530240]=1;gGz(c[2383428]|0,0,4096);gGz(c[2383426]|0,0,4096);f=c[2383424]|0;if((f|0)!=0){gGz(f|0,0,4096);gGz(c[2383422]|0,0,4096)}gGz(c[2383434]|0,0,16);gGz(c[2383435]|0,0,16);gGz(c[2383430]|0,0,8192);gGz(c[2383431]|0,0,8192);f=c[2383432]|0;if((f|0)!=0){gGz(f|0,0,8192);gGz(c[2383433]|0,0,8192)}b[4766836]=0;c[2426968]=0;c[3528794]=0;c[1765522]=65535;c[2429656]=0;c[2427042]=0;c[2429386]=0;c[2429384]=0;c[2429382]=0}c[2387544]=-1;f=0;d=-1;e=-1;do{d=((a[9632432+f|0]&1)<<f^d&65535)&65535;e=((a[9630344+f|0]&1)<<f^e&65535)&65535;f=f+1|0;}while((f|0)<16);b[4775088]=d;b[4775089]=e;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060]}c[2388530]=9554128;e=c[2391608]|0;if((e|0)!=0){d=e;gGC(9661040,d|0,68)|0}c[2382]=0;c[2383408]=0;d=0;e=0;while(1){c[2113056]=942;f=RG(942)|0;c[2113054]=(c[2113054]|0)+f;c[2276108]=-1;c[2113056]=-1;fy_(542)|0;if((d|0)==248){c[2383408]=8}f=c[2112964]|0;if((f|0)==0){g=e}else{h=a[9688]|0?2:0;i=f+(e<<1<<1)|0;if(a[801408]|0){gg[c[3542124]&4095](i,h)}if(a[801400]|0){Uu(0,i,h)}if((c[2429658]|0)!=0){Uu(1,i,h)}g=h+e|0}h=d+1|0;if((h|0)<256){d=h;e=g}else{break}}c[8452200+(c[2394]<<2)>>2]=8198;c[2276080]=1536;if((c[2276079]|0)>>>0<1536){RH(6)}e=c[2112964]|0;do{if((e|0)!=0){d=a[9688]|0?534:0;if((d|0)==(g|0)){break}h=d-g|0;d=e+(g<<1<<1)|0;if(a[801408]|0){gg[c[3542124]&4095](d,h)}if(a[801400]|0){Uu(0,d,h)}if((c[2429658]|0)==0){break}Uu(1,d,h)}}while(0);g=c[(c[2388530]|0)+12304>>2]|0;if((g|0)!=0){e=g;gGC(e|0,9661040,68)|0}c[2382]=-1;e=c[2394]|0;g=c[14130368+(e<<2)>>2]|0;if((g|0)!=0){gGC(g|0,9104152,280)|0}c[8452240+(e<<2)>>2]=c[2113054];c[2394]=-1;if((c[2112968]|0)==0){return 0}aEx()|0;return 0}function aEx(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=c[3529900]|0;f=c[2387300]|0;g=(c[642608+(c[2436]<<2)>>2]|0)+124|0;if((c[g>>2]<<1|0)>0){h=0;do{i=e[f+((h|1)<<1)>>1]|0;c[d+(((h|0)/2|0)<<2)>>2]=i<<8&63488|(e[f+(h<<1)>>1]|0)>>>3&31|i>>>8<<3&2016;h=h+2|0;}while((h|0)<(c[g>>2]<<1|0))}a[9547104]=0;aE3();aE5();g=c[2113068]|0;h=c[2113070]|0;f=ag(h,g)|0;if((f|0)>0){d=c[2112926]|0;i=0;do{b[d+(i<<1)>>1]=1024;i=i+1|0;}while((i|0)<(f|0))}f=b[4766836]|0;if((f&7)==5){aE0(2,c[2388466]|0,65536);aE0(3,c[2388462]|0,65536);j=b[4766836]|0}else{j=f}f=c[2383420]|0;gGz(f|0,0,131072);gGz(c[2383410]|0,0,131072);i=(c[2427e3]|0)==1;d=(c[2427001]|0)==1?2097152:0;L31461:do{switch(j&7|0){case 5:{k=c[2112926]|0;aE0(1,k,65536);if((h|0)<=0){l=k;break L31461}m=c[2388466]|0;n=c[2388462]|0;o=k;p=f;q=0;while(1){if((g|0)>0){r=0;do{b[o+(r<<1)>>1]=b[m+(r<<1)>>1]&15|b[n+(r<<1)>>1]<<4&240|768;a[p+r|0]=32;r=r+1|0;}while((r|0)<(g|0))}r=q+1|0;if((r|0)<(h|0)){m=m+(g<<1)|0;n=n+(g<<1)|0;o=o+(g<<1)|0;p=p+512|0;q=r}else{l=k;break}}break};case 3:{k=c[2112926]|0;aE0(3,k,65536);aE0(1,k,d|8);l=k;break};case 1:case 2:{k=c[2112926]|0;aE0(3,k,65536);aE0(1,k,d|8);aE0(2,k,32);l=k;break};case 0:case 4:case 6:case 7:{k=c[2112926]|0;aE0(3,k,65536);aE0(2,k,8);aE0(1,k,d|32);l=k;break};default:{l=c[2112926]|0}}}while(0);d=c[2386558]|0;g=c[3530310]|0;aEG(d,g,1280,3,0);h=c[3529680]|0;f=c[3530288]|0;aEG(h,f,1792,4,0);aE0(0,l,i?2097407:255);R8(c[3529900]|0);aEG(d,g,1280,3,4);aEG(h,f,1792,4,4);return 0}function aEy(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=i;i=i+80|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;if((d|0)!=0){c[d>>2]=169762}if((b&32|0)!=0){gGz(k|0,0,12);l=c[2414562]|0;c[k>>2]=l;c[k+4>>2]=(c[2411462]|0)-l;c[k+12>>2]=162152;l=c[2076592]|0;gj[l&4095](k)|0}if((b&64|0)==0){i=e;return 0}k=h|0;gGz(g|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){l=h+9|0;h=f;m=f|0;n=f+4|0;o=f+12|0;p=g|0;q=g+4|0;r=g+12|0;s=0;do{gGC(k|0,614896,11)|0;a[l]=s+48&255;t=8452256+(s<<2)|0;gGz(h|0,0,12);c[m>>2]=t;c[n>>2]=4;c[o>>2]=164976;gj[c[2076592]&4095](f)|0;if((c[t>>2]|0)!=0){c[p>>2]=c[14130368+(s<<2)>>2];c[q>>2]=c[8452184+(s<<2)>>2];c[r>>2]=k;t=c[2076592]|0;gj[t&4095](g)|0}s=s+1|0;}while((s|0)<=(c[2392]|0))}aFf(b,d);aE6();gGz(j|0,0,12);c[j>>2]=14120960;c[j+4>>2]=4;c[j+12>>2]=491248;gj[c[2076592]&4095](j)|0;j=c[3530240]|0;c[3530240]=-1;if((j&2|0)==0){d=c[3529702]|0;b=d+262144|0;gGC(d|0,b|0,262144)|0}if((j&1|0)==0){b=c[3529746]|0;d=b+262144|0;gGC(b|0,d|0,262144)|0}c[3530240]=j;i=e;return 0}function aEz(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1598956+(b*112|0)>>2];c[a+104>>2]=c[1598960+(b*112|0)>>2];c[a+108>>2]=c[1598964+(b*112|0)>>2];d=0;return d|0}function aEA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=1598856+(b*112|0);e=0;return e|0}function aEB(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4461316+(b*112|0)>>2];c[a+104>>2]=c[4461320+(b*112|0)>>2];c[a+108>>2]=c[4461324+(b*112|0)>>2];d=0;return d|0}function aEC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=4461216+(b*112|0);e=0;return e|0}function aED(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2401540+(b*112|0)>>2];c[a+104>>2]=c[2401544+(b*112|0)>>2];c[a+108>>2]=c[2401548+(b*112|0)>>2];d=0;return d|0}function aEE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=2401440+(b*112|0);e=0;return e|0}function aEF(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;a=b&2;d=c[3530240]|0;if((a|0)!=(d&2|0)){e=c[3529702]|0;f=e+((a<<17)+262144)|0;gGC(e|0,f|0,262144)|0}f=b&1;if((f|0)==(d&1|0)){c[3530240]=b;return}d=c[3529746]|0;e=d+((f<<18)+262144)|0;gGC(d|0,e|0,262144)|0;c[3530240]=b;return}function aEG(d,f,g,h,i){d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;if((c[2113308]&4|0)!=(i|0)){return}j=d;d=(h|0)==4;h=d?15:31;k=(a[c[3528658]|0]|0)==0;l=b[4766836]|0;m=l<<16>>16==2;n=(i|0)==0;i=l<<16>>16==1;l=c[3529900]|0;o=c[2112926]|0;p=(c[2113222]&1|0)==0;q=1020;do{r=b[j+((q|1)<<1)>>1]|0;s=r&65535;do{if(r<<16>>16!=0){t=e[j+(q<<1)>>1]|0;if(!((t&4096|0)==0|p)){break}u=b[j+((q|2)<<1)>>1]|0;v=u&65535;w=v>>>9&h;x=t&8192;y=t&16384;z=1<<(t>>>9&3);A=z-1|0;do{if(d){B=v&49152;if((B|0)==0){C=64}else if((B|0)==49152){C=4}else{C=16}D=(u&8192)==0?255:128;E=(v&32768|0)==0;if(!m){F=D;G=C;H=E?64:16;break}I=E?D:128;if((B|0)==49152){F=I;G=C;H=4;break}else if((B|0)==32768){F=I;G=C;H=16;break}else{F=I;G=C;H=64;break}}else{I=(v&32768|0)==0?32:8;B=v&49152;if(i){F=255;G=I;H=(B|0)==0?64:16;break}if((B|0)==49152){F=255;G=I;H=4;break}else if((B|0)==32768){F=255;G=I;H=16;break}else{F=255;G=I;H=64;break}}}while(0);u=v&511;I=t&511;B=u>>>0>319?v|-512:u;u=I>>>0>255?t|-512:I;I=(y>>>13^2)-1|0;D=((y|0)!=0?0:A)+(s&-z)|0;if(k){J=y>>>14^1;K=x>>>13^1;L=B;M=u;N=16}else{J=y;K=x;L=304-B|0;M=240-u|0;N=-16}if((z|0)<=0){break}u=(w<<4)+g|0;if(n){B=A;while(1){E=D-(ag(B,I)|0)|0;aEY(o,f,E,u,L,(ag(B,N)|0)+M|0,K,J,H,G);if((B|0)>0){B=B-1|0}else{break}}}else{B=A;while(1){w=D-(ag(B,I)|0)|0;aEZ(l,f,w,u,L,(ag(B,N)|0)+M|0,K,J,H,G,F);if((B|0)>0){B=B-1|0}else{break}}}}}while(0);q=q-4|0;}while((q|0)>-1);return}function aEH(a){a=a|0;return a>>>4<<12&28672|0}function aEI(a){a=a|0;var b=0;b=a>>>4<<12&28672;return((a&15|0)==10?b|2048:b)|0}function aEJ(d,e){d=d|0;e=e|0;if((d&-16|0)==3145728){b[(c[2383434]|0)+((d>>>1&7)<<1)>>1]=e;return}if((d|0)!=1048576){return}c[2383412]=e&65535;if((a[9661085]|0)==1){return}a[9661085]=1;if((a[9661088]|0)!=0){return}a[9661088]=2;return}function aEK(b,d){b=b|0;d=d|0;if((b-1048576|0)>>>0>=2){return}c[2383412]=d&255;if((a[9661085]|0)==1){return}a[9661085]=1;if((a[9661088]|0)!=0){return}a[9661088]=2;return}function aEL(a){a=a|0;var e=0;if((a|0)==1572872){e=(b[4775085]&65527|c[2383408]&8)&65535;return e|0}else if((a|0)==1572866){e=(d[9634689]|0)<<8|(d[9634688]|0);return e|0}else if((a|0)==1572864){e=b[4775084]|0;return e|0}else{e=0;return e|0}return 0}function aEM(d){d=d|0;var f=0;switch(d|0){case 1572872:case 1572873:{f=(b[4775085]&247|c[2383408]&8)&255;break};case 1572867:{f=a[9634689]|0;break};case 1572866:{f=a[9634688]|0;break};case 1572864:case 1572865:{f=(e[4775084]|0)>>>((d<<3&8^8)>>>0)&255;break};default:{f=0}}return f|0}function aEN(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4341188+(b*112|0)>>2];c[a+104>>2]=c[4341192+(b*112|0)>>2];c[a+108>>2]=c[4341196+(b*112|0)>>2];d=0;return d|0}function aEO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=4341088+(b*112|0);e=0;return e|0}function aEP(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1652688+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aEQ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>41){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4912896+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aER(){var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=i;i=i+360|0;e=d|0;f=d+112|0;g=d+120|0;j=d+232|0;k=d+240|0;l=d+352|0;c[2424]=5800;c[2414858]=0;c[2388078]=0;c[2387774]=524288;c[3530756]=589824;c[3530520]=1638400;c[3530388]=2686976;c[3541206]=4784128;c[2386596]=4784128;c[3529898]=5046272;c[2414560]=5050368;c[2388208]=5050368;c[2387796]=5066752;c[2386386]=5074944;c[2387104]=5076992;c[3528656]=5079040;c[2411460]=5079041;m=0;while(1){if((m|0)>=1024){break}n=9638528+(m<<2)|0;if((c[n>>2]|0)==0){o=24745;break}else{m=m+1|0}}do{if((o|0)==24745){m=gGq(5079041)|0;c[n>>2]=m;if((m|0)==0){break}c[2414858]=m;gGz(m|0,0,5079041);c[2388078]=m;c[2387774]=m+524288;c[3530756]=m+589824;c[3530520]=m+1638400;c[3530388]=m+2686976;p=m+4784128|0;c[3541206]=p;c[2386596]=p;c[3529898]=m+5046272;p=m+5050368|0;c[2414560]=p;c[2388208]=p;c[2387796]=m+5066752;c[2386386]=m+5074944;c[2387104]=m+5076992;c[3528656]=m+5079040;p=m+5079041|0;c[2411460]=p;c[2414e3]=p;if((R6(m+1|0,0,2)|0)!=0){q=1;i=d;return q|0}if((R6(c[2388078]|0,1,2)|0)!=0){q=1;i=d;return q|0}m=c[2387774]|0;if((c[3542200]|0)==0){q=1;i=d;return q|0}p=k+108|0;c[p>>2]=0;r=k+100|0;c[r>>2]=0;s=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[s&16383](k,2)|0;do{if((c[p>>2]|0)!=0){s=c[r>>2]|0;c[l>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](l,2,0)|0;if((s|0)<1){q=1;i=d;return q|0}if((gzL(m,0,2)|0)==0){break}else{q=1}i=d;return q|0}}while(0);m=c[3530520]|0;if((c[3542200]|0)==0){q=1;i=d;return q|0}r=g+108|0;c[r>>2]=0;p=g+100|0;c[p>>2]=0;s=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[s&16383](g,3)|0;do{if((c[r>>2]|0)!=0){s=c[p>>2]|0;c[j>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](j,3,0)|0;if((s|0)<1){q=1;i=d;return q|0}if((gzL(m,0,3)|0)==0){break}else{q=1}i=d;return q|0}}while(0);if((R6(c[3530388]|0,4,2)|0)!=0){q=1;i=d;return q|0}if((R6((c[3530388]|0)+1|0,5,2)|0)!=0){q=1;i=d;return q|0}m=c[2386596]|0;if((c[3542200]|0)==0){q=1;i=d;return q|0}p=e+108|0;c[p>>2]=0;r=e+100|0;c[r>>2]=0;s=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[s&16383](e,6)|0;do{if((c[p>>2]|0)!=0){s=c[r>>2]|0;c[f>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](f,6,0)|0;if((s|0)<1){q=1;i=d;return q|0}if((gzL(m,0,6)|0)==0){break}else{q=1}i=d;return q|0}}while(0);aFg(c[3530520]|0,524288,1574056,720536,1110256);aE_(c[3530520]|0,c[3530756]|0,524288,1);m=c[3530520]|0;aE_(m,m,524288,0);aE$(c[3530388]|0,1048576);aE1(1,0,1);m=c[3530520]|0;c[2383440]=c[3530756];c[2383441]=m;c[2383442]=0;c[2383436]=16383;c[2383437]=4095;c[2383438]=0;c[2429666]=256;c[2429667]=512;a[690376]=1;fxU(0,425984);if((c[2394]|0)==0){u=c[2112932]|0}else{c[2394]=0;m=c[3532596]|0;c[2112932]=m;r=c[3532592]|0;if((r|0)!=0){gGC(9104152,r|0,280)|0}c[2113054]=c[2113060];u=m}m=c[2388078]|0;r=u|0;p=0;while(1){s=m+p|0;c[r>>2]=s;c[r+65536>>2]=s;c[r+131072>>2]=s;s=p+1024|0;if(s>>>0>524287){break}else{r=r+4|0;p=s}}p=c[2388208]|0;c[u+4608>>2]=p;c[u+70144>>2]=p;c[u+135680>>2]=p;r=p+1024|0;c[u+4612>>2]=r;c[u+70148>>2]=r;c[u+135684>>2]=r;r=p+2048|0;c[u+4616>>2]=r;c[u+70152>>2]=r;c[u+135688>>2]=r;r=p+3072|0;c[u+4620>>2]=r;c[u+70156>>2]=r;c[u+135692>>2]=r;r=p+4096|0;c[u+4624>>2]=r;c[u+70160>>2]=r;c[u+135696>>2]=r;r=p+5120|0;c[u+4628>>2]=r;c[u+70164>>2]=r;c[u+135700>>2]=r;r=p+6144|0;c[u+4632>>2]=r;c[u+70168>>2]=r;c[u+135704>>2]=r;r=p+7168|0;c[u+4636>>2]=r;c[u+70172>>2]=r;c[u+135708>>2]=r;r=p+8192|0;c[u+4640>>2]=r;c[u+70176>>2]=r;c[u+135712>>2]=r;r=p+9216|0;c[u+4644>>2]=r;c[u+70180>>2]=r;c[u+135716>>2]=r;r=p+10240|0;c[u+4648>>2]=r;c[u+70184>>2]=r;c[u+135720>>2]=r;r=p+11264|0;c[u+4652>>2]=r;c[u+70188>>2]=r;c[u+135724>>2]=r;r=p+12288|0;c[u+4656>>2]=r;c[u+70192>>2]=r;c[u+135728>>2]=r;r=p+13312|0;c[u+4660>>2]=r;c[u+70196>>2]=r;c[u+135732>>2]=r;r=p+14336|0;c[u+4664>>2]=r;c[u+70200>>2]=r;c[u+135736>>2]=r;r=p+15360|0;c[u+4668>>2]=r;c[u+70204>>2]=r;c[u+135740>>2]=r;r=c[2387104]|0;c[u+5120>>2]=r;c[u+70656>>2]=r;c[u+136192>>2]=r;p=r+1024|0;c[u+5124>>2]=p;c[u+70660>>2]=p;c[u+136196>>2]=p;p=c[2386386]|0;c[u+6656>>2]=p;c[u+72192>>2]=p;c[u+137728>>2]=p;r=p+1024|0;c[u+6660>>2]=r;c[u+72196>>2]=r;c[u+137732>>2]=r;r=c[2383430]|0;c[u+12800>>2]=r;c[u+78336>>2]=r;c[u+143872>>2]=r;p=r+1024|0;c[u+12804>>2]=p;c[u+78340>>2]=p;c[u+143876>>2]=p;p=r+2048|0;c[u+12808>>2]=p;c[u+78344>>2]=p;c[u+143880>>2]=p;p=r+3072|0;c[u+12812>>2]=p;c[u+78348>>2]=p;c[u+143884>>2]=p;p=r+4096|0;c[u+12816>>2]=p;c[u+78352>>2]=p;c[u+143888>>2]=p;p=r+5120|0;c[u+12820>>2]=p;c[u+78356>>2]=p;c[u+143892>>2]=p;p=r+6144|0;c[u+12824>>2]=p;c[u+78360>>2]=p;c[u+143896>>2]=p;p=r+7168|0;c[u+12828>>2]=p;c[u+78364>>2]=p;c[u+143900>>2]=p;p=c[2383431]|0;c[u+12832>>2]=p;c[u+78368>>2]=p;c[u+143904>>2]=p;r=p+1024|0;c[u+12836>>2]=r;c[u+78372>>2]=r;c[u+143908>>2]=r;r=p+2048|0;c[u+12840>>2]=r;c[u+78376>>2]=r;c[u+143912>>2]=r;r=p+3072|0;c[u+12844>>2]=r;c[u+78380>>2]=r;c[u+143916>>2]=r;r=p+4096|0;c[u+12848>>2]=r;c[u+78384>>2]=r;c[u+143920>>2]=r;r=p+5120|0;c[u+12852>>2]=r;c[u+78388>>2]=r;c[u+143924>>2]=r;r=p+6144|0;c[u+12856>>2]=r;c[u+78392>>2]=r;c[u+143928>>2]=r;r=p+7168|0;c[u+12860>>2]=r;c[u+78396>>2]=r;c[u+143932>>2]=r;r=c[2383428]|0;c[u+13312>>2]=r;c[u+78848>>2]=r;c[u+144384>>2]=r;p=r+1024|0;c[u+13316>>2]=p;c[u+78852>>2]=p;c[u+144388>>2]=p;p=r+2048|0;c[u+13320>>2]=p;c[u+78856>>2]=p;c[u+144392>>2]=p;p=c[2383426]|0;c[u+13344>>2]=p;c[u+78880>>2]=p;c[u+144416>>2]=p;r=p+1024|0;c[u+13348>>2]=r;c[u+78884>>2]=r;c[u+144420>>2]=r;r=p+2048|0;c[u+13352>>2]=r;c[u+78888>>2]=r;c[u+144424>>2]=r;c[u+196728>>2]=1306;c[u+196648>>2]=2346;c[u+196688>>2]=2488;c[u+196608>>2]=196;r=c[3532592]|0;if((r|0)!=0){gGC(r|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;aE8(c[2387774]|0,c[2387796]|0,4027500,0,0,.45,1023924,.5,0,0.0);h[745421]=.45;c[2436794]=1;h[745420]=.45;c[2436792]=2;r=c[642608+(c[2436]<<2)>>2]|0;p=c[r+128>>2]|0;if((c[r+52>>2]&4|0)==0){c[2113068]=p;m=c[r+132>>2]|0;c[2113070]=m;c[2443814]=p;c[2440436]=m;v=p;w=m}else{c[2113070]=p;m=c[r+132>>2]|0;c[2113068]=m;c[2440436]=p;c[2443814]=m;v=m;w=p}p=ag(v<<1,w)|0;m=gGq(p)|0;c[2112926]=m;if((m|0)!=0){gGz(m|0,0,p|0)}p=c[2414560]|0;gGz(p|0,0,(c[2411460]|0)-p|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];p=c[3532592]|0;if((p|0)!=0){gGC(9104152,p|0,280)|0}c[2113054]=c[2113060]}RI();p=c[2394]|0;m=c[14130368+(p<<2)>>2]|0;if((m|0)!=0){gGC(m|0,9104152,280)|0}c[8452240+(p<<2)>>2]=c[2113054];c[2394]=-1;aE7();gGz(c[2383428]|0,0,4096);gGz(c[2383426]|0,0,4096);p=c[2383424]|0;if((p|0)!=0){gGz(p|0,0,4096);gGz(c[2383422]|0,0,4096)}gGz(c[2383434]|0,0,16);gGz(c[2383435]|0,0,16);gGz(c[2383430]|0,0,8192);gGz(c[2383431]|0,0,8192);p=c[2383432]|0;if((p|0)!=0){gGz(p|0,0,8192);gGz(c[2383433]|0,0,8192)}b[4766836]=0;c[2426968]=0;c[3528794]=0;c[1765522]=65535;c[2429656]=0;c[2427042]=0;c[2429386]=0;c[2429384]=0;c[2429382]=0;q=0;i=d;return q|0}}while(0);c[2414858]=0;q=1;i=d;return q|0}function aES(){var a=0,b=0,d=0,e=0,f=0;c[2113070]=0;c[2113068]=0;a=c[2112926]|0;if((a|0)!=0){gGr(a);c[2112926]=0}aE2();aFe();if((c[2392]|0)>=0){a=0;do{b=14130368+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}b=14130384+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}a=a+1|0;}while((a|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;a=c[2414858]|0;b=0;while(1){if((b|0)>=1024){e=24818;break}f=9638528+(b<<2)|0;if((c[f>>2]|0)==(a|0)){break}else{b=b+1|0}}if((e|0)==24818){c[2414858]=0;return 0}gGr(a);c[f>>2]=0;c[2414858]=0;return 0}function aET(){var d=0,e=0,f=0,g=0,h=0,i=0;if((a[9623416]|0)!=0){d=c[2414560]|0;gGz(d|0,0,(c[2411460]|0)-d|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;aE7();gGz(c[2383428]|0,0,4096);gGz(c[2383426]|0,0,4096);d=c[2383424]|0;if((d|0)!=0){gGz(d|0,0,4096);gGz(c[2383422]|0,0,4096)}gGz(c[2383434]|0,0,16);gGz(c[2383435]|0,0,16);gGz(c[2383430]|0,0,8192);gGz(c[2383431]|0,0,8192);d=c[2383432]|0;if((d|0)!=0){gGz(d|0,0,8192);gGz(c[2383433]|0,0,8192)}b[4766836]=0;c[2426968]=0;c[3528794]=0;c[1765522]=65535;c[2429656]=0;c[2427042]=0;c[2429386]=0;c[2429384]=0;c[2429382]=0}c[2387542]=-1;d=0;e=-1;f=-1;do{e=((a[9632416+d|0]&1)<<d^e&65535)&65535;f=((a[9630328+d|0]&1)<<d^f&65535)&65535;d=d+1|0;}while((d|0)<16);b[4775084]=e;b[4775085]=f;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060]}c[2388530]=9554128;f=c[2391608]|0;if((f|0)!=0){e=f;gGC(9661040,e|0,68)|0}c[2382]=0;c[2383408]=0;e=0;f=0;while(1){c[2113056]=942;d=RG(942)|0;c[2113054]=(c[2113054]|0)+d;c[2276108]=-1;c[2113056]=-1;fy_(271)|0;if((e|0)==240){c[2383408]=8}d=c[2112964]|0;if((d|0)==0){g=f}else{h=a[9688]|0?2:0;i=d+(f<<1<<1)|0;if(a[801408]|0){gg[c[3542124]&4095](i,h)}if(a[801400]|0){Uu(0,i,h)}if((c[2429658]|0)!=0){Uu(1,i,h)}g=h+f|0}h=e+1|0;if((h|0)<256){e=h;f=g}else{break}}c[8452200+(c[2394]<<2)>>2]=8198;c[2276080]=1536;if((c[2276079]|0)>>>0<1536){RH(6)}f=c[2112964]|0;do{if((f|0)!=0){e=a[9688]|0?534:0;if((e|0)==(g|0)){break}h=e-g|0;e=f+(g<<1<<1)|0;if(a[801408]|0){gg[c[3542124]&4095](e,h)}if(a[801400]|0){Uu(0,e,h)}if((c[2429658]|0)==0){break}Uu(1,e,h)}}while(0);g=c[(c[2388530]|0)+12304>>2]|0;if((g|0)!=0){f=g;gGC(f|0,9661040,68)|0}c[2382]=-1;f=c[2394]|0;g=c[14130368+(f<<2)>>2]|0;if((g|0)!=0){gGC(g|0,9104152,280)|0}c[8452240+(f<<2)>>2]=c[2113054];c[2394]=-1;if((c[2112968]|0)==0){return 0}aEU()|0;return 0}function aEU(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;d=c[2387104]|0;f=c[3529898]|0;g=0;do{h=e[d+(g<<1)>>1]|0;i=h>>>8;j=h>>>4&15;c[f+(g<<2)>>2]=(i&8|i<<4)>>>3&31|(h&8|h<<4)<<8&63488|(j<<4|j)<<3&2016;g=g+1|0;}while((g|0)<1024);a[9547096]=0;aE3();g=c[2113068]|0;f=c[2113070]|0;d=ag(f,g)|0;j=c[2112926]|0;if((d|0)>0){h=0;while(1){b[j+(h<<1)>>1]=256;i=h+1|0;if((i|0)<(d|0)){h=i}else{k=j;break}}}else{k=j}aE0(1,k,65536);aE0(0,k,0);j=c[2386386]|0;h=c[3528656]|0;d=c[3530388]|0;i=(c[2113222]&1|0)==0;l=0;do{m=e[j+(l<<1)>>1]|0;n=e[j+((l|2)<<1)>>1]|0;do{if((m&4096|0)==0|i){o=n>>>9&31;p=m&8192;q=m&16384;r=1<<(m>>>9&3);s=r-1|0;t=n&511;u=m&511;v=t>>>0>319?n|-512:t;t=u>>>0>255?m|-512:u;u=((q|0)==0?s:0)+(-r&e[j+((l|1)<<1)>>1])|0;w=(q>>>13^2)-1|0;if((a[h]|0)==0){x=q;y=p;z=-16;A=304-v|0;B=240-t|0}else{x=q>>>14^1;y=p>>>13^1;z=16;A=v;B=t}if(!((A+15|0)>>>0<335&(r|0)>0)){break}r=B-8|0;t=(y|0)!=0;if((x|0)==0){if(t){v=s;while(1){p=u-(ag(v,w)|0)|0;SJ(k,p&16383,A,(ag(v,z)|0)+r|0,o,4,0,0,d);if((v|0)>0){v=v-1|0}else{break}}}else{v=s;while(1){p=u-(ag(v,w)|0)|0;SH(k,p&16383,A,(ag(v,z)|0)+r|0,o,4,0,0,d);if((v|0)>0){v=v-1|0}else{break}}}}else{if(t){v=s;while(1){p=(ag(v,z)|0)+r|0;SN(k,u-(ag(v,w)|0)&16383,A,p,o,4,0,0,d);if((v|0)>0){v=v-1|0}else{break}}}else{v=s;while(1){t=(ag(v,z)|0)+r|0;SL(k,u-(ag(v,w)|0)&16383,A,t,o,4,0,0,d);if((v|0)>0){v=v-1|0}else{break}}}}}}while(0);l=l+4|0;}while((l|0)<1024);if((f|0)<=0){C=c[3529898]|0;R8(C);return 0}l=k+(g-2<<1)|0;k=0;while(1){b[l+2>>1]=b[l>>1]|0;d=k+1|0;if((d|0)<(f|0)){l=l+(g<<1)|0;k=d}else{break}}C=c[3529898]|0;R8(C);return 0}function aEV(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=i;i=i+64|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;if((d|0)!=0){c[d>>2]=169762}if((b&32|0)!=0){gGz(j|0,0,12);k=c[2414560]|0;c[j>>2]=k;c[j+4>>2]=(c[2411460]|0)-k;c[j+12>>2]=162152;k=c[2076592]|0;gj[k&4095](j)|0}if((b&64|0)==0){i=e;return 0}j=h|0;gGz(g|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){k=h+9|0;h=f;l=f|0;m=f+4|0;n=f+12|0;o=g|0;p=g+4|0;q=g+12|0;r=0;do{gGC(j|0,614896,11)|0;a[k]=r+48&255;s=8452256+(r<<2)|0;gGz(h|0,0,12);c[l>>2]=s;c[m>>2]=4;c[n>>2]=164976;gj[c[2076592]&4095](f)|0;if((c[s>>2]|0)!=0){c[o>>2]=c[14130368+(r<<2)>>2];c[p>>2]=c[8452184+(r<<2)>>2];c[q>>2]=j;s=c[2076592]|0;gj[s&4095](g)|0}r=r+1|0;}while((r|0)<=(c[2392]|0))}aFf(b,d);aE6();i=e;return 0}function aEW(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2120180+(b*112|0)>>2];c[a+104>>2]=c[2120184+(b*112|0)>>2];c[a+108>>2]=c[2120188+(b*112|0)>>2];d=0;return d|0}function aEX(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=2120080+(b*112|0);e=0;return e|0}function aEY(e,f,g,h,i,j,k,l,m,n){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;o=g<<8;g=(k|0)==0?0:15;k=(l|0)==0?g:g|240;g=(m|0)==-1;l=(n|0)==-1;p=n&255;q=m&255;r=c[2113070]|0;s=c[2113068]|0;t=c[2383420]|0;u=c[2383410]|0;v=j-(a[690376]|0?8:0)|0;j=0;while(1){L31913:do{if((v|0)>-1&(v|0)<(r|0)){w=j<<4;x=v<<9;y=ag(s,v)|0;if(g){z=0;A=i;while(1){do{if((A|0)>-1&(A|0)<(s|0)){B=a[f+((z+w^k)+o)|0]|0;if(B<<24>>24==0){break}b[e+(y+A<<1)>>1]=(B&255|h)&65535;B=t+(A+x)|0;a[B]=a[B]|-128}}while(0);B=z+1|0;if((B|0)>=16){break L31913}z=B;A=A+1|0}}else{C=0;D=i}while(1){do{if((D|0)>-1&(D|0)<(s|0)){A=a[f+((C+w^k)+o)|0]|0;z=A&255;if(A<<24>>24==0){break}A=D+x|0;B=t+A|0;E=a[B]|0;F=E&255;if(l){if((1<<(F&31)&m|0)!=0){break}if((F&128|0)!=0){break}G=E|-128}else{if((F|0)>=(m|0)){break}F=u+A|0;if((d[F]|0|0)>=(n|0)){break}a[F]=p;G=q}a[B]=G;b[e+(y+D<<1)>>1]=(z|h)&65535;a[B]=a[B]|-128}}while(0);B=C+1|0;if((B|0)>=16){break L31913}C=B;D=D+1|0}}}while(0);y=j+1|0;if((y|0)>=16){break}v=v+1|0;j=y}return}function aEZ(b,e,f,g,h,i,j,k,l,m,n){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;if((n|0)==0){return}o=f<<8;f=(j|0)==0?0:15;j=(k|0)==0?f:f|240;f=c[2112968]|0;k=(m|0)==-1;p=(n|0)==255;q=256-n|0;r=m&255;s=l&255;t=c[2113070]|0;u=c[2113068]|0;v=c[2383420]|0;w=c[2383410]|0;x=i-(a[690376]|0?8:0)|0;i=0;while(1){L31947:do{if((x|0)>-1&(x|0)<(t|0)){y=i<<4;z=x<<9;A=ag(u,x)|0;B=0;C=h;while(1){do{if((C|0)>-1&(C|0)<(u|0)){D=a[e+((B+y^j)+o)|0]|0;E=D&255;if(D<<24>>24==0){break}D=C+z|0;F=v+D|0;G=a[F]|0;H=G&255;if(k){if((1<<(H&31)&l|0)!=0){break}if((H&128|0)!=0){break}I=G|-128}else{if((H|0)>=(l|0)){break}H=w+D|0;if((d[H]|0|0)>=(m|0)){break}a[H]=r;I=s}a[F]=I;if(p){c[f+(A+C<<2)>>2]=c[b+((E|g)<<2)>>2];break}else{F=f+(A+C<<2)|0;H=c[F>>2]|0;D=c[b+((E|g)<<2)>>2]|0;E=ag(D&16711935,n)|0;G=E+(ag(H&16711935,q)|0)&-16711936;E=ag(D&65280,n)|0;c[F>>2]=(G|E+(ag(H&65280,q)|0)&16711680)>>>8;break}}}while(0);H=B+1|0;if((H|0)>=16){break L31947}B=H;C=C+1|0}}}while(0);C=i+1|0;if((C|0)>=16){break}x=x+1|0;i=C}return}function aE_(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;h=i;i=i+16|0;j=h|0;k=((f|0)/2|0)<<3;c[j>>2]=k+8;c[j+4>>2]=k;c[j+8>>2]=8;c[j+12>>2]=0;k=0;while(1){if((k|0)>=1024){l=25007;break}m=9638528+(k<<2)|0;if((c[m>>2]|0)==0){break}else{k=k+1|0}}if((l|0)==25007){i=h;return}k=gGq(f)|0;c[m>>2]=k;if((k|0)==0){i=h;return}gGz(k|0,0,f|0);gGC(k|0,b|0,f)|0;do{if((g|0)==2){b=0;while(1){m=b<<8;gGz(e+m|0,0,256);n=b<<9;o=0;do{p=1<<7-o;q=(c[616832+(o<<2)>>2]|0)+n|0;r=0;do{s=q+(c[608544+(r<<2)>>2]|0)|0;t=(r<<4)+m|0;u=0;do{v=s+(c[613816+(u<<2)>>2]|0)|0;if(((d[k+((v|0)/8|0)|0]|0)&128>>>((v&7)>>>0)|0)!=0){v=e+(t+u)|0;a[v]=(d[v]|0|p)&255}u=u+1|0;}while((u|0)<16);r=r+1|0;}while((r|0)<16);o=o+1|0;}while((o|0)<8);o=b+1|0;if((o|0)<4096){b=o}else{w=0;break}}}else{b=f<<1;if((g|0)==1){o=(b|0)/64|0;if((b|0)>63){x=0}else{w=0;break}while(1){m=x<<6;gGz(e+m|0,0,64);n=x<<7;r=0;do{p=1<<3-r;q=(c[j+(r<<2)>>2]|0)+n|0;u=0;do{t=q+(c[608544+(u<<2)>>2]|0)|0;s=(u<<3)+m|0;v=0;do{y=t+(c[613816+(v+8<<2)>>2]|0)|0;if(((d[k+((y|0)/8|0)|0]|0)&128>>>((y&7)>>>0)|0)!=0){y=e+(s+v)|0;a[y]=(d[y]|0|p)&255}v=v+1|0;}while((v|0)<8);u=u+1|0;}while((u|0)<8);r=r+1|0;}while((r|0)<4);r=x+1|0;if((r|0)<(o|0)){x=r}else{w=0;break}}}else{o=(b|0)/256|0;if((b|0)>255){z=0}else{w=0;break}while(1){r=z<<8;gGz(e+r|0,0,256);m=z<<9;n=0;do{u=1<<3-n;p=(c[j+(n<<2)>>2]|0)+m|0;q=0;do{v=p+(c[608544+(q<<2)>>2]|0)|0;s=(q<<4)+r|0;t=0;do{y=v+(c[613816+(t<<2)>>2]|0)|0;if(((d[k+((y|0)/8|0)|0]|0)&128>>>((y&7)>>>0)|0)!=0){y=e+(s+t)|0;a[y]=(d[y]|0|u)&255}t=t+1|0;}while((t|0)<16);q=q+1|0;}while((q|0)<16);n=n+1|0;}while((n|0)<4);n=z+1|0;if((n|0)<(o|0)){z=n}else{w=0;break}}}}}while(0);while(1){if((w|0)>=1024){l=25006;break}A=9638528+(w<<2)|0;if((c[A>>2]|0)==(k|0)){break}else{w=w+1|0}}if((l|0)==25006){i=h;return}gGr(k);c[A>>2]=0;i=h;return}function aE$(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=0;while(1){if((f|0)>=1024){g=25029;break}h=9638528+(f<<2)|0;if((c[h>>2]|0)==0){break}else{f=f+1|0}}if((g|0)==25029){return}f=gGq(e)|0;c[h>>2]=f;if((f|0)==0){return}gGz(f|0,0,e|0);gGC(f|0,b|0,e)|0;h=e<<1;e=(h|0)/256|0;if((h|0)>255){h=0;while(1){i=h<<8;gGz(b+i|0,0,256);j=h<<10;k=0;do{l=1<<3-k;m=(c[613152+(k<<2)>>2]|0)+j|0;n=0;do{o=m+(c[611840+(n<<2)>>2]|0)|0;p=(n<<4)+i|0;q=0;do{r=o+(c[613752+(q<<2)>>2]|0)|0;if(((d[f+((r|0)/8|0)|0]|0)&128>>>((r&7)>>>0)|0)!=0){r=b+(p+q)|0;a[r]=(d[r]|0|l)&255}q=q+1|0;}while((q|0)<16);n=n+1|0;}while((n|0)<16);k=k+1|0;}while((k|0)<4);k=h+1|0;if((k|0)<(e|0)){h=k}else{s=0;break}}}else{s=0}while(1){if((s|0)>=1024){g=25026;break}t=9638528+(s<<2)|0;if((c[t>>2]|0)==(f|0)){break}else{s=s+1|0}}if((g|0)==25026){return}gGr(f);c[t>>2]=0;return}function aE0(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;i=c[9708e3+(f<<2)>>2]|0;if((i|0)==-1){return}j=e[(c[9533736+(((f|0)/2|0)<<2)>>2]|0)+12>>1]|0;k=(f&1|0)==0?j:j>>>8;j=((f|0)<2?i:0)+(f&2)|0;l=(i|0)!=0;i=l?16:8;m=(h&2097152|0)==0?(h>>>18&4)+4|0:5;n=c[9533760+(j<<2)>>2]|0;o=c[9533744+(j<<2)>>2]|0;j=c[9533720+(f<<2)>>2]|0;p=(h&65536|0)==0?e[9540808+(f<<2)+((h>>>8&1)<<1)>>1]|0:0;q=c[9753216+(f<<2)>>2]|0;r=c[9718648+(f<<2)>>2]|0;s=c[9718664+(f<<2)>>2]>>m;t=(i<<5)-1|0;u=(ag(c[9721992+(f<<2)>>2]|0,i)|0)-1|0;v=(u>>>8&1)+5|0;w=i-1|0;x=c[2113070]|0;if((x|0)<=0){return}y=h&255;h=(k&3|0)==0;z=c[2113068]|0;A=h?0:(k&1|0)==0?0:w;B=h?0:(k&2|0)!=0?w:0;k=c[2383420]|0;C=z+i|0;D=0;do{E=(e[9742928+(f<<10)+(D<<1)>>1]|0)&u;if((z+i|0)>0){F=D<<9;G=ag(z,D)|0;H=0;do{I=((e[9734736+(f<<11)+(H<<1)>>1]|0)&t)+D&t;J=H+E&u;K=(J|0)/(i|0)|0;L=(I|0)/(i|0)|0;if(l){M=K<<5&1024|K&31|L<<5&992|L<<6&2048}else{M=L<<v|K}K=e[j+(M<<1)>>1]|0;L=K>>>12;if((L&8|0)==0){N=0;O=0;P=L}else{N=B;O=A;P=h?L:L&7}L=(P&r)+s<<m;Q=H-(J&w)|0;J=ag((N^I&w)+(ag((K&4095|q)&o,i)|0)|0,i)|0;K=Q+F|0;I=0;do{R=I+Q|0;do{if((R|0)>=0&(R|0)<(z|0)){S=d[n+((I^O)+J)|0]|0;if((1<<S&p|0)!=0){break}b[g+(G+R<<1)>>1]=(S|L)&65535;a[k+(K+I)|0]=y}}while(0);I=I+1|0;}while((I|0)<(i|0));H=H+i|0;}while((H|0)<(C|0))}D=D+1|0;}while((D|0)<(x|0));return}function aE1(d,e,f){d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;b[4770404]=1;b[4770405]=-1;b[4770406]=1;b[4770407]=-1;b[4770408]=1;b[4770409]=-1;b[4770410]=1;b[4770411]=-1;if((e|0)!=0){b[4770406]=-255;b[4770407]=255}gGz(9717680,0,64);e=0;while(1){if((e|0)>=1024){g=0;break}h=9638528+(e<<2)|0;if((c[h>>2]|0)==0){i=25056;break}else{e=e+1|0}}do{if((i|0)==25056){e=gGq(8192)|0;c[h>>2]=e;if((e|0)==0){g=0;break}gGz(e|0,0,8192);g=e}}while(0);c[2383430]=g;g=0;while(1){if((g|0)>=1024){j=0;break}k=9638528+(g<<2)|0;if((c[k>>2]|0)==0){i=25061;break}else{g=g+1|0}}do{if((i|0)==25061){g=gGq(8192)|0;c[k>>2]=g;if((g|0)==0){j=0;break}gGz(g|0,0,8192);j=g}}while(0);c[2383431]=j;j=0;while(1){if((j|0)>=1024){l=0;break}m=9638528+(j<<2)|0;if((c[m>>2]|0)==0){i=25066;break}else{j=j+1|0}}do{if((i|0)==25066){j=gGq(4096)|0;c[m>>2]=j;if((j|0)==0){l=0;break}gGz(j|0,0,4096);l=j}}while(0);c[2383428]=l;l=0;while(1){if((l|0)>=1024){n=0;break}o=9638528+(l<<2)|0;if((c[o>>2]|0)==0){i=25071;break}else{l=l+1|0}}do{if((i|0)==25071){l=gGq(4096)|0;c[o>>2]=l;if((l|0)==0){n=0;break}gGz(l|0,0,4096);n=l}}while(0);c[2383426]=n;n=0;while(1){if((n|0)>=1024){p=0;break}q=9638528+(n<<2)|0;if((c[q>>2]|0)==0){i=25076;break}else{n=n+1|0}}do{if((i|0)==25076){n=gGq(16)|0;c[q>>2]=n;if((n|0)==0){p=0;break}gGz(n|0,0,16);p=n}}while(0);c[2383434]=p;p=0;while(1){if((p|0)>=1024){r=0;break}s=9638528+(p<<2)|0;if((c[s>>2]|0)==0){i=25081;break}else{p=p+1|0}}do{if((i|0)==25081){p=gGq(16)|0;c[s>>2]=p;if((p|0)==0){r=0;break}gGz(p|0,0,16);r=p}}while(0);c[2383435]=r;if((d|0)==0){r=0;while(1){if((r|0)>=1024){t=0;break}u=9638528+(r<<2)|0;if((c[u>>2]|0)==0){i=25086;break}else{r=r+1|0}}do{if((i|0)==25086){r=gGq(8192)|0;c[u>>2]=r;if((r|0)==0){t=0;break}gGz(r|0,0,8192);t=r}}while(0);c[2383432]=t;t=0;while(1){if((t|0)>=1024){v=0;break}w=9638528+(t<<2)|0;if((c[w>>2]|0)==0){i=25091;break}else{t=t+1|0}}do{if((i|0)==25091){t=gGq(8192)|0;c[w>>2]=t;if((t|0)==0){v=0;break}gGz(t|0,0,8192);v=t}}while(0);c[2383433]=v;v=0;while(1){if((v|0)>=1024){x=0;break}y=9638528+(v<<2)|0;if((c[y>>2]|0)==0){i=25096;break}else{v=v+1|0}}do{if((i|0)==25096){v=gGq(4096)|0;c[y>>2]=v;if((v|0)==0){x=0;break}gGz(v|0,0,4096);x=v}}while(0);c[2383424]=x;x=0;while(1){if((x|0)>=1024){z=0;break}A=9638528+(x<<2)|0;if((c[A>>2]|0)==0){i=25101;break}else{x=x+1|0}}do{if((i|0)==25101){x=gGq(4096)|0;c[A>>2]=x;if((x|0)==0){z=0;break}gGz(x|0,0,4096);z=x}}while(0);c[2383422]=z;B=0}else{B=0}while(1){if((B|0)>=1024){C=0;break}D=9638528+(B<<2)|0;if((c[D>>2]|0)==0){i=25106;break}else{B=B+1|0}}do{if((i|0)==25106){B=gGq(131072)|0;c[D>>2]=B;if((B|0)==0){C=0;break}gGz(B|0,0,131072);C=B}}while(0);c[2383420]=C;C=0;while(1){if((C|0)>=1024){E=0;break}F=9638528+(C<<2)|0;if((c[F>>2]|0)==0){i=25111;break}else{C=C+1|0}}do{if((i|0)==25111){C=gGq(131072)|0;c[F>>2]=C;if((C|0)==0){E=0;break}gGz(C|0,0,131072);E=C}}while(0);c[2383410]=E;gGz(9717744,0,16);c[2430498]=64;E=(f|0)!=0?64:32;c[2430499]=E;f=(d|0)!=0?0:E;c[2430500]=f;c[2430501]=f;c[2429662]=15;c[2429663]=15;c[2429664]=15;c[2429665]=15;gGz(9753216,0,16);c[2429666]=0;c[2429667]=256;c[2429668]=0;c[2429669]=256;c[2427e3]=1;c[2427001]=1;c[2427002]=1;c[2427003]=1;a[690376]=0;b[4766836]=0;return}function aE2(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;a=c[2383420]|0;b=0;while(1){if((b|0)>=1024){break}d=9638528+(b<<2)|0;if((c[d>>2]|0)==(a|0)){e=25117;break}else{b=b+1|0}}if((e|0)==25117){gGr(a);c[d>>2]=0}c[2383420]=0;d=c[2383410]|0;a=0;while(1){if((a|0)>=1024){break}f=9638528+(a<<2)|0;if((c[f>>2]|0)==(d|0)){e=25121;break}else{a=a+1|0}}if((e|0)==25121){gGr(d);c[f>>2]=0}c[2383410]=0;f=c[2383428]|0;d=0;while(1){if((d|0)>=1024){break}g=9638528+(d<<2)|0;if((c[g>>2]|0)==(f|0)){e=25125;break}else{d=d+1|0}}if((e|0)==25125){gGr(f);c[g>>2]=0}c[2383428]=0;g=c[2383430]|0;f=0;while(1){if((f|0)>=1024){break}h=9638528+(f<<2)|0;if((c[h>>2]|0)==(g|0)){e=25129;break}else{f=f+1|0}}if((e|0)==25129){gGr(g);c[h>>2]=0}c[2383430]=0;h=c[2383426]|0;g=0;while(1){if((g|0)>=1024){break}i=9638528+(g<<2)|0;if((c[i>>2]|0)==(h|0)){e=25133;break}else{g=g+1|0}}if((e|0)==25133){gGr(h);c[i>>2]=0}c[2383426]=0;i=c[2383431]|0;h=0;while(1){if((h|0)>=1024){break}j=9638528+(h<<2)|0;if((c[j>>2]|0)==(i|0)){e=25137;break}else{h=h+1|0}}if((e|0)==25137){gGr(i);c[j>>2]=0}c[2383431]=0;j=c[2383424]|0;i=0;while(1){if((i|0)>=1024){break}k=9638528+(i<<2)|0;if((c[k>>2]|0)==(j|0)){e=25141;break}else{i=i+1|0}}if((e|0)==25141){gGr(j);c[k>>2]=0}c[2383424]=0;k=c[2383432]|0;j=0;while(1){if((j|0)>=1024){break}l=9638528+(j<<2)|0;if((c[l>>2]|0)==(k|0)){e=25145;break}else{j=j+1|0}}if((e|0)==25145){gGr(k);c[l>>2]=0}c[2383432]=0;l=c[2383422]|0;k=0;while(1){if((k|0)>=1024){break}m=9638528+(k<<2)|0;if((c[m>>2]|0)==(l|0)){e=25149;break}else{k=k+1|0}}if((e|0)==25149){gGr(l);c[m>>2]=0}c[2383422]=0;m=c[2383433]|0;l=0;while(1){if((l|0)>=1024){break}n=9638528+(l<<2)|0;if((c[n>>2]|0)==(m|0)){e=25153;break}else{l=l+1|0}}if((e|0)==25153){gGr(m);c[n>>2]=0}c[2383433]=0;n=c[2383434]|0;m=0;while(1){if((m|0)>=1024){break}o=9638528+(m<<2)|0;if((c[o>>2]|0)==(n|0)){e=25157;break}else{m=m+1|0}}if((e|0)==25157){gGr(n);c[o>>2]=0}c[2383434]=0;o=c[2383435]|0;n=0;while(1){if((n|0)>=1024){e=25163;break}p=9638528+(n<<2)|0;if((c[p>>2]|0)==(o|0)){break}else{n=n+1|0}}if((e|0)==25163){c[2383435]=0;return}gGr(o);c[p>>2]=0;c[2383435]=0;return}function aE3(){var a=0,d=0,f=0;a=c[2429436]|0;if((a|0)!=0){c[2438304]=gj[a&4095](b[(c[2383434]|0)+14>>1]&255)|0}a=c[2429437]|0;if((a|0)!=0){c[2438305]=gj[a&4095]((e[(c[2383434]|0)+14>>1]|0)>>>8)|0}a=c[2383434]|0;d=a+10|0;f=a+12|0;aE4(0,e[a+2>>1]|0,e[a+4>>1]|0,c[2383428]|0,b[d>>1]&255,b[f>>1]&255);aE4(1,e[a+6>>1]|0,e[a+8>>1]|0,c[2383426]|0,(e[d>>1]|0)>>>8,(e[f>>1]|0)>>>8);return}function aE4(d,f,g,h,i,j){d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;do{if((d&2|0)==0){k=i&128;if((j&128|0)==0){c[9708e3+(d<<2)>>2]=(k>>>6)-1;break}else{c[9708e3+(d<<2)>>2]=(k>>>7)-1;break}}}while(0);if((h|0)==0){return}k=(j&64|0)==0;do{if(k){if((j&32|0)==0){break}l=c[9708e3+(d<<2)>>2]|0;m=25189}else{n=c[9708e3+(d<<2)>>2]|0;o=(n|0)!=0;p=i>>>3&15;q=p>>>0<9?512>>>(p>>>0):1;if(o){r=q;s=512}else{r=(q+1|0)>>>0<3?1:(q|0)/2|0;s=256}q=(s|0)/(r|0)|0;p=(c[9717680+(d<<4)+((o&1)<<3)>>2]|0)+f|0;if((r|0)>0){o=(q|0)>0;t=a[690376]|0?8:0;u=0;do{v=ag(u,q)|0;w=v+q|0;if(o){x=p+(e[h+(u<<1)>>1]|0)&65535;y=v;do{b[9742928+(d<<10)+((y-t&511)<<1)>>1]=x;y=y+1|0;}while((y|0)<(w|0))}u=u+1|0;}while((u|0)<(r|0))}if((j&32|0)!=0){l=n;m=25189;break}u=(a[690376]|0?8:0)+g&65535;t=0;do{b[9734736+(d<<11)+(t<<1)>>1]=u;t=t+1|0;}while((t|0)<1024)}}while(0);do{if((m|0)==25189){r=(l|0)!=0;s=i&7;t=(64>>>(s>>>0))-1|0;u=(t|0)<0?0:t;t=1024>>>((s+3|0)>>>0);if(r){z=1024;A=t}else{z=512;A=(t+1|0)>>>0<3?1:(t|0)/2|0}t=(z|0)/(A|0)|0;if((A|0)>0){s=(t|0)>0;n=(a[690376]|0?8:0)+g|0;p=0;do{o=ag(p,t)|0;q=o+t|0;if(s){w=n+(e[h+((p&u)+512<<1)>>1]|0)&65535;y=o;do{b[9734736+(d<<11)+(y<<1)>>1]=w;y=y+1|0;}while((y|0)<(q|0))}p=p+1|0;}while((p|0)<(A|0))}if(!k){break}p=(c[9717680+(d<<4)+((r&1)<<3)>>2]|0)+f&65535;u=a[690376]|0?8:0;n=0;do{b[9742928+(d<<10)+((n-u&511)<<1)>>1]=p;n=n+1|0;}while((n|0)<512)}}while(0);if((j&96|0)!=0){return}j=c[9708e3+(d<<2)>>2]|0;k=a[690376]|0?8:0;A=k+g&65535;g=0;do{b[9734736+(d<<11)+(g<<1)>>1]=A;g=g+1|0;}while((g|0)<1024);g=(c[9717680+(d<<4)+(((j|0)!=0)<<3)>>2]|0)+f&65535;f=0;do{b[9742928+(d<<10)+((f-k&511)<<1)>>1]=g;f=f+1|0;}while((f|0)<512);return}function aE5(){var a=0,d=0,f=0;a=c[2429438]|0;if((a|0)!=0){c[2438306]=gj[a&4095](b[(c[2383435]|0)+14>>1]&255)|0}a=c[2429439]|0;if((a|0)!=0){c[2438307]=gj[a&4095]((e[(c[2383435]|0)+14>>1]|0)>>>8)|0}a=c[2383435]|0;d=a+10|0;f=a+12|0;aE4(2,e[a+2>>1]|0,e[a+4>>1]|0,c[2383424]|0,b[d>>1]&255,b[f>>1]&255);aE4(3,e[a+6>>1]|0,e[a+8>>1]|0,c[2383422]|0,(e[d>>1]|0)>>>8,(e[f>>1]|0)>>>8);return}function aE6(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;a=i;i=i+320|0;b=a|0;d=a+16|0;e=a+32|0;f=a+48|0;g=a+64|0;h=a+80|0;j=a+96|0;k=a+112|0;l=a+128|0;m=a+144|0;n=a+160|0;o=a+176|0;p=o|0;q=o+4|0;r=a+192|0;s=o+12|0;t=c[2383430]|0;if((t|0)!=0){c[p>>2]=t;c[q>>2]=8192;cC(r|0,150696,(u=i,i=i+8|0,c[u>>2]=0,u)|0)|0;i=u;c[s>>2]=r;t=c[2076592]|0;gj[t&4095](o)|0;c[p>>2]=c[2383428];c[q>>2]=4096;cC(r|0,496360,(u=i,i=i+8|0,c[u>>2]=0,u)|0)|0;i=u;c[s>>2]=r;t=c[2076592]|0;gj[t&4095](o)|0}t=c[2383431]|0;if((t|0)!=0){c[p>>2]=t;c[q>>2]=8192;cC(r|0,150696,(u=i,i=i+8|0,c[u>>2]=1,u)|0)|0;i=u;c[s>>2]=r;t=c[2076592]|0;gj[t&4095](o)|0;c[p>>2]=c[2383426];c[q>>2]=4096;cC(r|0,496360,(u=i,i=i+8|0,c[u>>2]=1,u)|0)|0;i=u;c[s>>2]=r;t=c[2076592]|0;gj[t&4095](o)|0}t=c[2383432]|0;if((t|0)!=0){c[p>>2]=t;c[q>>2]=8192;cC(r|0,150696,(u=i,i=i+8|0,c[u>>2]=2,u)|0)|0;i=u;c[s>>2]=r;t=c[2076592]|0;gj[t&4095](o)|0;c[p>>2]=c[2383424];c[q>>2]=4096;cC(r|0,496360,(u=i,i=i+8|0,c[u>>2]=2,u)|0)|0;i=u;c[s>>2]=r;t=c[2076592]|0;gj[t&4095](o)|0}t=c[2383433]|0;if((t|0)!=0){c[p>>2]=t;c[q>>2]=8192;cC(r|0,150696,(u=i,i=i+8|0,c[u>>2]=3,u)|0)|0;i=u;c[s>>2]=r;t=c[2076592]|0;gj[t&4095](o)|0;c[p>>2]=c[2383422];c[q>>2]=4096;cC(r|0,496360,(u=i,i=i+8|0,c[u>>2]=3,u)|0)|0;i=u;c[s>>2]=r;r=c[2076592]|0;gj[r&4095](o)|0}r=o;gGz(r|0,0,12);c[p>>2]=c[2383434];c[q>>2]=16;c[s>>2]=381504;gj[c[2076592]&4095](o)|0;gGz(r|0,0,12);c[p>>2]=c[2383435];c[q>>2]=16;c[s>>2]=296928;gj[c[2076592]&4095](o)|0;gGz(n|0,0,12);c[n>>2]=9533672;c[n+4>>2]=2;c[n+12>>2]=226528;gj[c[2076592]&4095](n)|0;gGz(m|0,0,12);c[m>>2]=9533632;c[m+4>>2]=4;c[m+12>>2]=177e3;gj[c[2076592]&4095](m)|0;gGz(l|0,0,12);c[l>>2]=9707872;c[l+4>>2]=4;c[l+12>>2]=114408;gj[c[2076592]&4095](l)|0;gGz(k|0,0,12);c[k>>2]=14115176;c[k+4>>2]=4;c[k+12>>2]=89400;gj[c[2076592]&4095](k)|0;gGz(j|0,0,12);c[j>>2]=7062088;c[j+4>>2]=4;c[j+12>>2]=69584;gj[c[2076592]&4095](j)|0;gGz(h|0,0,12);c[h>>2]=9718624;c[h+4>>2]=4;c[h+12>>2]=577592;gj[c[2076592]&4095](h)|0;gGz(g|0,0,12);c[g>>2]=9533632;c[g+4>>2]=4;c[g+12>>2]=177e3;gj[c[2076592]&4095](g)|0;gGz(f|0,0,12);c[f>>2]=9708168;c[f+4>>2]=4;c[f+12>>2]=561336;gj[c[2076592]&4095](f)|0;gGz(e|0,0,12);c[e>>2]=9717544;c[e+4>>2]=4;c[e+12>>2]=545296;gj[c[2076592]&4095](e)|0;gGz(d|0,0,12);c[d>>2]=9717536;c[d+4>>2]=4;c[d+12>>2]=531720;gj[c[2076592]&4095](d)|0;gGz(b|0,0,12);c[b>>2]=9717528;c[b+4>>2]=4;c[b+12>>2]=517936;gj[c[2076592]&4095](b)|0;i=a;return}function aE7(){var b=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0;c[2388530]=9554128;b=c[2391608]|0;if((b|0)!=0){e=b;gGC(9661040,e|0,68)|0}c[2382]=0;e=c[2415273]|0;gGz(9661040,0,68);c[2415273]=e;a[9661063]=20;c[2415262]=511;e=c[2388539]|0;do{if((e|0)==0){b=c[2388532]|0;if((b|0)==0){f=0;g=8191;i=9554128;break}j=gj[b&4095](8190)|0;f=j;g=(d[9661071]|0)<<13|8191;i=c[2388530]|0}else{f=a[e+2046|0]|0;g=8191;i=9554128}}while(0);a[9661044]=f;f=c[i+16+(g>>>11<<2)>>2]|0;do{if((f|0)==0){e=c[i>>2]|0;if((e|0)==0){k=0;l=i;break}j=gj[e&4095](g)|0;k=j;l=c[2388530]|0}else{k=a[f+2047|0]|0;l=i}}while(0);a[9661045]=k;a[9661075]=4;a[9661073]=0;c[2415270]=131072;c[2415275]=0;gGz(9661084,0,5);k=c[l+12304>>2]|0;if((k|0)!=0){l=k;gGC(l|0,9661040,68)|0}c[2382]=-1;if(a[801408]|0){mx(0)}do{if((c[2429660]|0)!=0){c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){m=0}else{break}do{lN(m);mB(m);m=m+1|0;}while((m|0)<(c[2385508]|0))}}while(0);if(a[801400]|0){c[2113156]=0;a[9628264]=0;c[2407033]=0;m=c[3541206]|0;c[3541190]=m;c[3541198]=m;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=m+256;c[3541199]=m+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=m+512;c[3541200]=m+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=m+768;c[3541201]=m+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4}if((c[2429658]|0)==0){c[2383412]=0;return}c[2113157]=0;a[9628420]=0;c[2407072]=0;m=c[3541206]|0;l=m+1048576|0;c[3541194]=l;c[3541202]=l;gGz(c[2430122]|0,0,16384);c[2407080]=4;c[3541195]=m+1048832;c[3541203]=m+1114112;gGz(c[2430123]|0,0,16384);c[2407088]=4;c[3541196]=m+1049088;c[3541204]=m+1179648;gGz(c[2430124]|0,0,16384);c[2407096]=4;c[3541197]=m+1049344;c[3541205]=m+1245184;gGz(c[2430125]|0,0,16384);c[2407104]=4;c[2383412]=0;return}function aE8(b,d,e,f,g,i,j,k,l,m){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;i=+i;j=j|0;k=+k;l=l|0;m=+m;var n=0,o=0,p=0,q=0;fv8();c[2388530]=9554128;n=c[2391608]|0;if((n|0)!=0){o=n;gGC(9661040,o|0,68)|0}c[2382]=0;o=0;do{n=b+(o<<11)|0;c[9554144+(o<<2)>>2]=n;c[9562336+(o<<2)>>2]=n;o=o+1|0;}while(o>>>0<32);c[2389528]=d;c[2390552]=d;c[2391576]=d;o=d+2048|0;c[2389529]=o;c[2390553]=o;c[2391577]=o;o=d+4096|0;c[2389530]=o;c[2390554]=o;c[2391578]=o;o=d+6144|0;c[2389531]=o;c[2390555]=o;c[2391579]=o;c[2388533]=1738;c[2388532]=310;o=c[2391608]|0;if((o|0)!=0){d=o;gGC(d|0,9661040,68)|0}c[2382]=-1;c[2429294]=e;a[801408]=1;e=(f|0)!=0;c[2429660]=e&1;a[801400]=1;f=(l|0)!=0;c[2429658]=f&1;d=a[9680]|0;o=d?32e3:0;if(d){if(a[9624]|0){d=o*3|0;b=55937;while(1){if((b|0)>(d|0)){b=b>>1}else{p=1222;q=b;break}}}else{p=2462;q=o}c[2429380]=q;c[3542124]=p;mw(358e4,q);q=gGq(262144)|0;c[2406684]=q;gGz(q|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(358e4,11025)}h[745421]=i;c[2436794]=3;h[745420]=i;c[2436792]=3;q=c[3531464]|0;c[q+44344>>2]=994;if((g|0)!=0){c[q+44348>>2]=g}if(e){Vr(1,4027500,0,2252,54,0);e=c[2429294]|0;c[2438228]=e;c[2433526]=3406;c[2406676]=2246;c[3528472]=11080;g=gGS(2048e6,0,e,(e|0)<0|0?-1:0)|0;e=gGK(g,K,-1,0)|0;c[2443846]=e}Ux(0,(j|0)/132|0,1);c[2407030]=~~(k*256.0+.5);c[2407068]=3;if(!f){return}Ux(1,(l|0)/132|0,1);c[2407069]=~~(m*256.0+.5);c[2407107]=3;return}function aE9(b,d){b=b|0;d=d|0;var e=0,f=0;if((b|0)==1179648|(b|0)==1179649){Uv(0,d);return}else if((b|0)==1114112){c[2113304]=d&255;return}else if((b|0)==2092032|(b|0)==2092033){e=b&1;a[9661104]=d;if((e|0)==0){f=((d&255)<<10&130048)+1024|0;c[2415269]=f;c[2415270]=f;return}else if((e|0)==1){e=d&1;if((e|0)!=0&(a[9661073]|0)==0){c[2415269]=c[2415270]}a[9661073]=e&255;return}else{return}}else if((b|0)==1245184|(b|0)==1245185){if((c[2429658]|0)==0){return}Uv(1,d);return}else if((b|0)==1114113){e=c[2113304]|0;a[14168504+e|0]=d;mv(0,e,d&255);return}else if((b|0)==1048576|(b|0)==1048577){if((c[2429660]|0)==0){return}lS(0,b&1,d);return}else if((b|0)==2094080|(b|0)==2094081|(b|0)==2094082|(b|0)==2094083){e=b&3;a[9661104]=d;if((e|0)==3){if((a[9661087]|0)==0){return}a[9661087]=0;if((a[9661088]|0)!=0){return}a[9661088]=2;return}else if((e|0)==2){a[9661072]=d&7;if((a[9661088]|0)!=0){return}a[9661088]=2;return}else{a[9661104]=d;return}}else{return}}function aFa(b){b=b|0;var e=0,f=0,g=0.0,i=0.0,j=0;if((b|0)==1245184|(b|0)==1245185){if((c[2429658]|0)==0){e=0;return e|0}e=c[2113157]&255;return e|0}else if((b|0)==1179648|(b|0)==1179649){e=c[2113156]&255;return e|0}else if((b|0)==1114113){e=c[(c[3531464]|0)+4240>>2]&255;return e|0}else if((b|0)==1114112){e=-1;return e|0}else if((b|0)==1310720|(b|0)==1310721){do{if((a[9661085]|0)!=0){a[9661085]=0;if((a[9661088]|0)!=0){break}a[9661088]=2}}while(0);e=c[2383412]&255;return e|0}else if((b|0)==1048576|(b|0)==1048577){if((c[2429660]|0)==0){e=0;return e|0}f=c[3541518]|0;if((b&1|0)==0){b=f+296|0;g=+h[b>>3];do{if(g!=0.0){i=+h[6675];if(g-(i+ +gC[c[2429842]&255]())<=0.0){h[b>>3]=0.0;break}e=a[f+307|0]|-128;return e|0}}while(0);e=a[f+307|0]|0;return e|0}if((d[f+304|0]|0)>=16){e=0;return e|0}f=c[2383582]|0;b=c[14168912+(f*252|0)>>2]|0;if((b|0)>15){e=0;return e|0}do{if((b|0)==14){j=c[14168896+(f*252|0)>>2]|0;if((j|0)==0){break}a[14168930+(f*252|0)|0]=gj[j&4095](0)|0}else if((b|0)==15){j=c[14168900+(f*252|0)>>2]|0;if((j|0)==0){break}a[14168931+(f*252|0)|0]=gj[j&4095](0)|0}}while(0);e=a[14168916+(f*252|0)+b|0]|0;return e|0}else{e=0;return e|0}return 0}function aFb(b){b=b|0;var c=0;c=(b|0)!=0;if((d[9661086]|0)==(c&1|0)){return}a[9661086]=c&1;if((a[9661088]|0)!=0){return}a[9661088]=2;return}function aFc(a){a=a|0;var b=0,d=0;b=c[2415275]|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=c[2429294]|0;b=gGS(d,K,a,(a|0)<0|0?-1:0)|0;return b|0}function aFd(){return+(+(c[2415275]|0)/+(c[2429294]|0))}function aFe(){var b=0;fv9();do{if(a[801408]|0){b=c[3531464]|0;c[b+44344>>2]=0;c[b+44348>>2]=0;if((b|0)!=0){gGr(b);c[3531464]=0}b=c[2406684]|0;if((b|0)==0){break}gGr(b);c[2406684]=0}}while(0);if((c[2429660]|0)!=0){b=c[3541518]|0;if((b|0)!=0){gGr(b|0);c[3541518]=0}if((c[2385508]|0)>0){c[2113008]=0;c[2076598]=0;c[2383582]=0}c[2438228]=0;c[2433526]=0;c[2406676]=0;c[3528472]=0;b=c[2406680]|0;if((b|0)!=0){gGr(b);c[2406680]=0}c[2385508]=0;c[2432978]=0;a[64240]=0}if(a[801400]|0){Uw(0)}if((c[2429658]|0)==0){c[3541206]=0;a[801408]=0;c[2429660]=0;a[801400]=0;c[2429658]=0;c[2429294]=0;return}Uw(1);c[3541206]=0;a[801408]=0;c[2429660]=0;a[801400]=0;c[2429658]=0;c[2429294]=0;return}function aFf(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+192|0;g=f|0;h=f+16|0;j=f+32|0;k=f+176|0;if((b&64|0)==0){i=f;return}l=j;m=f+48|0;n=j|0;o=j+4|0;p=j+12|0;q=c[2391608]|0;if((q|0)!=0){r=q+52|0;s=c[r>>2]|0;gGz(l|0,0,16);c[n>>2]=q;c[o>>2]=68;cC(m|0,165488,(t=i,i=i+8|0,c[t>>2]=0,t)|0)|0;i=t;c[p>>2]=m;q=c[2076592]|0;gj[q&4095](j)|0;c[r>>2]=s}s=c[2394685]|0;if((s|0)!=0){r=s+52|0;q=c[r>>2]|0;gGz(l|0,0,16);c[n>>2]=s;c[o>>2]=68;cC(m|0,165488,(t=i,i=i+8|0,c[t>>2]=1,t)|0)|0;i=t;c[p>>2]=m;m=c[2076592]|0;gj[m&4095](j)|0;c[r>>2]=q}gGz(k|0,0,12);c[k>>2]=9533648;c[k+4>>2]=4;c[k+12>>2]=142512;gj[c[2076592]&4095](k)|0;do{if(a[801408]|0){gGz(h|0,0,12);c[h>>2]=8453216;c[h+4>>2]=4;c[h+12>>2]=107480;k=c[2076592]|0;gj[k&4095](h)|0;gGz(g|0,0,12);c[g>>2]=14168504;c[g+4>>2]=256;c[g+12>>2]=476464;k=c[2076592]|0;gj[k&4095](g)|0;if((b&2|0)==0){break}else{u=0}do{mv(0,u,d[14168504+u|0]|0);u=u+1|0;}while((u|0)<256)}}while(0);if((c[2429660]|0)!=0){Vx(b,e)}if(a[801400]|0){Ut(0)}if((c[2429658]|0)==0){i=f;return}Ut(1);i=f;return}function aFg(a,f,g,h,i){a=a|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;j=a;k=(f|0)/2|0;l=k<<1;m=0;while(1){if((m|0)>=1024){n=0;break}o=9638528+(m<<2)|0;if((c[o>>2]|0)==0){p=25395;break}else{m=m+1|0}}do{if((p|0)==25395){m=gGq(l)|0;c[o>>2]=m;if((m|0)==0){n=0;break}gGz(m|0,0,l|0);n=m}}while(0);o=n;if((f|0)>1){q=0}else{gGC(n|0,a|0,l)|0;f=0;while(1){if((f|0)>=1024){p=25410;break}r=9638528+(f<<2)|0;if((c[r>>2]|0)==(n|0)){break}else{f=f+1|0}}if((p|0)==25410){return}gGr(n);c[r>>2]=0;return}do{r=j+(q<<1)|0;b[r>>1]=ga(b[r>>1]|0)|0;q=q+1|0;}while((q|0)<(k|0));gGC(n|0,a|0,l)|0;l=0;while(1){a=l&2047;q=e[h+(a<<1)>>1]|0;r=d[i+a|0]|0;a=(b[627128+((d[g+(q&2047)|0]|0)<<1)>>1]^b[o+((q|l&-2048)<<1)>>1])&65535;b[j+(l<<1)>>1]=(a>>>((d[5659633+(r<<4)|0]|0)>>>0)<<14&16384|a>>>((d[5659632+(r<<4)|0]|0)>>>0)<<15&32768|a>>>((d[5659634+(r<<4)|0]|0)>>>0)<<13&8192|a>>>((d[5659635+(r<<4)|0]|0)>>>0)<<12&4096|a>>>((d[5659636+(r<<4)|0]|0)>>>0)<<11&2048|a>>>((d[5659637+(r<<4)|0]|0)>>>0)<<10&1024|a>>>((d[5659638+(r<<4)|0]|0)>>>0)<<9&512|a>>>((d[5659639+(r<<4)|0]|0)>>>0)<<8&256|a>>>((d[5659640+(r<<4)|0]|0)>>>0)<<7&128|a>>>((d[5659641+(r<<4)|0]|0)>>>0)<<6&64|a>>>((d[5659642+(r<<4)|0]|0)>>>0)<<5&32|a>>>((d[5659643+(r<<4)|0]|0)>>>0)<<4&16|a>>>((d[5659644+(r<<4)|0]|0)>>>0)<<3&8|a>>>((d[5659645+(r<<4)|0]|0)>>>0)<<2&4|a>>>((d[5659646+(r<<4)|0]|0)>>>0)<<1&2|a>>>((d[5659647+(r<<4)|0]|0)>>>0)&1)&65535;r=l+1|0;if((r|0)<(k|0)){l=r}else{s=0;break}}while(1){if((s|0)>=1024){t=0;break}u=9638528+(s<<2)|0;if((c[u>>2]|0)==(n|0)){p=25407;break}else{s=s+1|0}}if((p|0)==25407){gGr(n);c[u>>2]=0;t=0}do{u=j+(t<<1)|0;b[u>>1]=ga(b[u>>1]|0)|0;t=t+1|0;}while((t|0)<(k|0));return}function aFh(a,d,e,f,g,h){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;i=a;j=d;d=0;while(1){if((d|0)>=1024){k=0;break}l=9638528+(d<<2)|0;if((c[l>>2]|0)==0){m=25416;break}else{d=d+1|0}}do{if((m|0)==25416){d=gGq(e)|0;c[l>>2]=d;if((d|0)==0){k=0;break}gGz(d|0,0,e|0);k=d}}while(0);l=k;gGC(k|0,a|0,e)|0;a=(e|0)/2|0;if((e|0)>1){e=0;while(1){d=e&983040;n=(e&1|0)==0?d:d|48651;d=(e&2|0)==0?n:n^22169;n=(e&4|0)==0?d:d^4898;d=(e&8|0)==0?n:n^4;n=(e&16|0)==0?d:d^2208;d=(e&32|0)==0?n:n^137;n=(e&64|0)==0?d:d^1032;d=(e&128|0)==0?n:n^4626;n=(e&256|0)==0?d:d^2272;d=(e&512|0)==0?n:n^21657;n=(e&1024|0)==0?d:d^39563;d=(e&2048|0)==0?n:n^4642;n=(e&4096|0)==0?d:d^4608;d=(e&8192|0)==0?n:n^8;n=(e&16384|0)==0?d:d^4624;d=l+((((e&32768|0)==0?n:n^224)^f)<<1)|0;b[i+(e<<1)>>1]=aFi(b[d>>1]|0,e,g)|0;b[j+(e<<1)>>1]=aFi(b[d>>1]|0,e,h)|0;d=e+1|0;if((d|0)<(a|0)){e=d}else{o=0;break}}}else{o=0}while(1){if((o|0)>=1024){m=25425;break}p=9638528+(o<<2)|0;if((c[p>>2]|0)==(k|0)){break}else{o=o+1|0}}if((m|0)==25425){return}gGr(k);c[p>>2]=0;return}function aFi(a,b,c){a=a|0;b=b|0;c=c|0;var f=0,g=0;f=c^b;c=f>>>4&15;g=(b&131072|0)==0?c:c^4;c=f&15;f=a&65535;return((f>>>((d[591265+(g<<4)|0]|0)>>>0)<<14&16384|f>>>((d[591264+(g<<4)|0]|0)>>>0)<<15&32768|f>>>((d[591266+(g<<4)|0]|0)>>>0)<<13&8192|f>>>((d[591267+(g<<4)|0]|0)>>>0)<<12&4096|f>>>((d[591268+(g<<4)|0]|0)>>>0)<<11&2048|f>>>((d[591269+(g<<4)|0]|0)>>>0)<<10&1024|f>>>((d[591270+(g<<4)|0]|0)>>>0)<<9&512|f>>>((d[591271+(g<<4)|0]|0)>>>0)<<8&256|f>>>((d[591272+(g<<4)|0]|0)>>>0)<<7&128|f>>>((d[591273+(g<<4)|0]|0)>>>0)<<6&64|f>>>((d[591274+(g<<4)|0]|0)>>>0)<<5&32|f>>>((d[591275+(g<<4)|0]|0)>>>0)<<4&16|f>>>((d[591276+(g<<4)|0]|0)>>>0)<<3&8|f>>>((d[591277+(g<<4)|0]|0)>>>0)<<2&4|f>>>((d[591278+(g<<4)|0]|0)>>>0)<<1&2|f>>>((d[591279+(g<<4)|0]|0)>>>0)&1)^(e[591520+(((b&262144|0)==0?c:c^2)<<1)>>1]|0))&65535|0}function aFj(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;d=a;e=0;while(1){if((e|0)>=1024){f=0;break}g=9638528+(e<<2)|0;if((c[g>>2]|0)==0){h=25430;break}else{e=e+1|0}}do{if((h|0)==25430){e=gGq(b)|0;c[g>>2]=e;if((e|0)==0){f=0;break}gGz(e|0,0,b|0);f=e}}while(0);g=f;gGC(f|0,a|0,b)|0;a=(b|0)/4|0;if((b|0)>3){b=0;while(1){e=((b&1|0)==0?37574:23692)|b&16711680;i=(b&2|0)==0?e:e^19890;e=(b&4|0)!=0;j=e?i^61280:i;i=(b&8|0)!=0;k=i?j^22327:j;j=(b&16|0)!=0;l=j?k^5084:k;k=(b&32|0)!=0;m=k?l^19417:l;l=(b&64|0)!=0;n=l?m^41481:m;m=(b&128|0)!=0;o=m?n^55702:n;n=(b&256|0)!=0;p=n?o^42752:o;o=(b&512|0)!=0;q=o?p^60576:p;p=(b&1024|0)!=0;r=p?q^29993:q;q=(b&2048|0)!=0;s=q?r^12544:r;r=(b&4096|0)!=0;t=r?s^13236:s;s=(b&8192|0)!=0;u=s?t^24929:t;t=(b&16384|0)!=0;v=t?u^7919:u;u=(b&32768|0)!=0;w=c[g+((u?v^62885:v)<<2)>>2]|0;v=e?w^71303168:w;w=i?v^1073741828:v;v=j?w^294912:w;w=k?v^640:v;v=l?w^2097216:w;w=m?v^150994944:v;v=n?w^4352:w;w=o?v^536879104:v;v=p?w^34:w;w=q?v^655360:v;v=r?w^268451840:w;w=s?v^66560:v;v=t?w^-2147483632:w;w=u?v^9:v;v=(b&65536|0)==0?w:w^34603008;w=(b&131072|0)==0?v:v^8390656;v=b&3;if((v|0)==1){u=w^1487250783;x=u>>>31<<15|u>>>14<<31|u<<10&1024|u>>>11&1|u>>>23<<30&1073741824|u>>>28<<29&536870912|u>>>29<<28&268435456|u>>>6<<27&134217728|u>>>24<<26&67108864|u>>>10<<25&33554432|u>>>1<<24&16777216|u>>>5<<23&8388608|u>>>16<<22&4194304|u>>>7<<21&2097152|u>>>2<<20&1048576|u>>>30<<19&524288|u>>>8<<18&262144|u>>>18<<17&131072|u>>>3<<16&65536|u>>>22<<14&16384|u>>>25<<13&8192|u>>>20<<12&4096|u>>>17<<11&2048|u>>>19<<9&512|u>>>27<<8&256|u>>>9<<7&128|u>>>12<<6&64|u>>>21<<5&32|u>>>15<<4&16|u>>>26<<3&8|u>>>13<<2&4|u>>>4<<1&2}else if((v|0)==0){u=w^-329049734;x=u>>>1<<31|u&268435456|u>>>31<<19|u<<8&256|u>>>3&1|u>>>4<<30&1073741824|u>>>7<<29&536870912|u>>>22<<27&134217728|u>>>18<<26&67108864|u>>>20<<25&33554432|u>>>9<<24&16777216|u>>>16<<23&8388608|u>>>10<<22&4194304|u>>>30<<21&2097152|u>>>2<<20&1048576|u>>>24<<18&262144|u>>>19<<17&131072|u>>>29<<16&65536|u>>>6<<15&32768|u>>>21<<14&16384|u>>>23<<13&8192|u>>>11<<12&4096|u>>>12<<11&2048|u>>>13<<10&1024|u>>>5<<9&512|u>>>8<<7&128|u>>>26<<6&64|u>>>27<<5&32|u>>>15<<4&16|u>>>14<<3&8|u>>>17<<2&4|u>>>25<<1&2}else if((v|0)==3){u=w^685324163;x=u>>>30<<31|u&128|u<<28&268435456|u>>>31<<27|u>>>12&1|u>>>6<<30&1073741824|u>>>15<<29&536870912|u>>>18<<26&67108864|u>>>26<<25&33554432|u>>>22<<24&16777216|u>>>14<<23&8388608|u>>>23<<22&4194304|u>>>19<<21&2097152|u>>>17<<20&1048576|u>>>10<<19&524288|u>>>8<<18&262144|u>>>11<<17&131072|u>>>20<<16&65536|u>>>1<<15&32768|u>>>28<<14&16384|u>>>2<<13&8192|u>>>4<<12&4096|u>>>9<<11&2048|u>>>24<<10&1024|u>>>25<<9&512|u>>>27<<8&256|u>>>21<<6&64|u>>>13<<5&32|u>>>29<<4&16|u>>>5<<3&8|u>>>3<<2&4|u>>>16<<1&2}else if((v|0)==2){v=w^-475635946;x=v>>>19<<31|v&1073872896|v<<20&1048576|v>>>31<<7|v>>>5&1|v>>>21<<29&536870912|v>>>4<<28&268435456|v>>>2<<27&134217728|v>>>18<<26&67108864|v>>>15<<25&33554432|v>>>1<<24&16777216|v>>>12<<23&8388608|v>>>25<<22&4194304|v>>>8<<21&2097152|v>>>24<<19&524288|v>>>20<<18&262144|v>>>23<<16&65536|v>>>22<<15&32768|v>>>26<<14&16384|v>>>28<<13&8192|v>>>16<<12&4096|v>>>9<<11&2048|v>>>27<<10&1024|v>>>6<<9&512|v>>>11<<8&256|v>>>10<<6&64|v>>>3<<5&32|v>>>13<<4&16|v>>>14<<3&8|v>>>7<<2&4|v>>>29<<1&2}else{x=w}c[d+(b<<2)>>2]=x;w=b+1|0;if((w|0)<(a|0)){b=w}else{y=0;break}}}else{y=0}while(1){if((y|0)>=1024){h=25443;break}z=9638528+(y<<2)|0;if((c[z>>2]|0)==(f|0)){break}else{y=y+1|0}}if((h|0)==25443){return}gGr(f);c[z>>2]=0;return}function aFk(a){a=a|0;var d=0,f=0,g=0,h=0,i=0;d=a>>>1&1023;L32634:do{if((d|0)==7){c[2429384]=10342;f=c[2429386]&65535}else{c[2429386]=2048;L32636:do{if((d|0)==53){g=c[2429384]&65535}else{c[2429384]=10342;switch(d<<1|0){case 1916:{h=b[(c[2383414]|0)+250>>1]|0;return h|0};case 1210:{h=b[(c[2383414]|0)+220>>1]|0;return h|0};case 1786:{h=b[(c[2383414]|0)+4>>1]|0;return h|0};case 1492:{h=b[(c[2383414]|0)+52>>1]|0;return h|0};case 1346:{a=c[2383414]|0;h=b[a+146>>1]<<8^b[a+44>>1];return h|0};case 176:{a=c[2383414]|0;i=b[a+12>>1]|0;h=((i&65535)>>>8|i<<12|i<<4&3840)^b[a+44>>1];return h|0};case 1092:{h=b[(c[2383414]|0)+176>>1]|0;return h|0};case 488:{h=b[(c[2383414]|0)+2>>1]|0;return h|0};case 246:{h=b[(c[2383414]|0)+66>>1]|0;return h|0};case 194:{h=b[(c[2383414]|0)+44>>1]^b[(c[2383416]|0)+4>>1];return h|0};case 1596:{h=b[(c[2383414]|0)+44>>1]^b[c[2383416]>>1];return h|0};case 72:{h=b[(c[2383414]|0)+54>>1]&6144^6144;return h|0};case 1524:{h=b[(c[2383414]|0)+24>>1]|0;return h|0};case 172:{h=b[(c[2383416]|0)+4>>1]|0;return h|0};case 1682:{h=b[(c[2383414]|0)+46>>1]|0;return h|0};case 170:{h=-16256;return h|0};case 1538:{h=b[(c[2383414]|0)+146>>1]|0;return h|0};case 30:{a=c[2383414]|0;h=b[a+44>>1]^b[a+244>>1];return h|0};case 398:{a=b[(c[2383414]|0)+30>>1]|0;h=a<<12|a&4080|(a&65535)>>>12;return h|0};case 1514:{h=b[(c[2383414]|0)+184>>1]|0;return h|0};case 122:{h=b[(c[2383414]|0)+14>>1]|0;return h|0};case 16:{h=b[(c[2383414]|0)+12>>1]|0;return h|0};case 1594:{h=b[(c[2383414]|0)+136>>1]|0;return h|0};case 80:{h=b[c[2383416]>>1]|0;return h|0};case 1382:{h=b[(c[2383414]|0)+164>>1]|0;return h|0};case 1462:{h=b[(c[2383414]|0)+228>>1]|0;return h|0};case 776:{h=b[(c[2383414]|0)+56>>1]|0;return h|0};case 486:{h=b[(c[2383414]|0)+30>>1]|0;return h|0};case 1650:{h=b[(c[2383414]|0)+114>>1]|0;return h|0};case 258:{h=b[(c[2383414]|0)+162>>1]|0;return h|0};case 456:{h=b[(c[2383414]|0)+106>>1]|0;return h|0};case 988:{h=b[(c[2383414]|0)+170>>1]|0;return h|0};case 106:{g=10342;break L32636;break};case 232:{a=c[2429382]|0;c[2429382]=9217;h=a&65535;return h|0};case 2024:{h=b[(c[2383414]|0)+88>>1]|0;return h|0};case 1574:{h=b[(c[2383414]|0)+244>>1]|0;return h|0};case 1890:{h=b[(c[2383414]|0)+130>>1]|0;return h|0};case 678:{h=b[(c[2383414]|0)+232>>1]|0;return h|0};case 1112:{h=b[(c[2383414]|0)+182>>1]|0;return h|0};case 70:{h=((e[(c[2383414]|0)+44>>1]|0)^(b[(c[2383416]|0)+2>>1]&7|c[2383408]&8))&65535;return h|0};case 130:{a=c[2383414]|0;h=(b[a+44>>1]^34)&~b[a+54>>1];return h|0};case 1590:{a=b[(c[2383414]|0)+24>>1]|0;h=(a&65535)>>>12|a<<8|(a&65535)>>>4&240;return h|0};case 2004:{a=b[(c[2383414]|0)+12>>1]|0;h=a<<4&-256|a<<2&48|a<<6&192;return h|0};case 1038:{h=b[(c[2383414]|0)+122>>1]|0;return h|0};case 66:{h=b[(c[2383414]|0)+44>>1]^21250;return h|0};case 12:{h=8192;return h|0};case 82:{h=b[(c[2383414]|0)+54>>1]&8584^8584;return h|0};case 4:{a=c[2383414]|0;i=b[a+24>>1]|0;h=(i<<8&-4096|i<<10&3072|i<<6&768)&~b[a+54>>1];return h|0};case 14:{f=2048;break L32634;break};default:{h=0;return h|0}}}}while(0);c[2429384]=10342;h=g;return h|0}}while(0);c[2429386]=2048;h=f;return h|0}function aFl(a){a=a|0;var d=0,e=0;switch(a&2046|0){case 856:{d=b[(c[2383414]|0)+186>>1]|0;return d|0};case 48:{d=b[(c[2383414]|0)+144>>1]|0;return d|0};case 988:{d=b[(c[2383414]|0)+170>>1]|0;return d|0};case 1066:{d=b[(c[2383414]|0)+140>>1]|0;return d|0};case 210:{d=b[(c[2383414]|0)+166>>1]|0;return d|0};case 1788:{d=b[(c[2383414]|0)+102>>1]|0;return d|0};case 1088:{d=b[(c[2383414]|0)+62>>1]|0;return d|0};case 1190:{d=b[(c[2383414]|0)+168>>1]|0;return d|0};case 1594:{d=b[(c[2383414]|0)+136>>1]|0;return d|0};case 672:{d=b[(c[2383414]|0)+172>>1]|0;return d|0};case 834:{d=b[(c[2383414]|0)+188>>1]|0;return d|0};case 1714:{d=b[(c[2383414]|0)+148>>1]|0;return d|0};case 228:{a=b[(c[2383414]|0)+4>>1]|0;d=a<<4&4080|a&-4096|(a&65535)>>>8&15;return d|0};case 896:{d=b[(c[2383414]|0)+132>>1]|0;return d|0};case 346:{d=b[(c[2383414]|0)+160>>1]|0;return d|0};case 258:{d=b[(c[2383414]|0)+162>>1]|0;return d|0};case 1786:{d=b[(c[2383414]|0)+4>>1]|0;return d|0};case 1622:{d=b[(c[2383414]|0)+192>>1]|0;return d|0};case 912:{d=b[(c[2383414]|0)+44>>1]|0;return d|0};case 1092:{d=b[(c[2383414]|0)+176>>1]|0;return d|0};case 946:{d=b[(c[2383414]|0)+60>>1]|0;return d|0};case 1382:{d=b[(c[2383414]|0)+164>>1]|0;return d|0};case 1514:{d=b[(c[2383414]|0)+184>>1]|0;return d|0};case 810:{d=b[(c[2383414]|0)+128>>1]|0;return d|0};case 396:{d=b[(c[2383414]|0)+194>>1]|0;return d|0};case 880:{d=b[(c[2383414]|0)+196>>1]|0;return d|0};case 1478:{d=b[(c[2383414]|0)+198>>1]|0;return d|0};case 584:{d=b[(c[2383414]|0)+208>>1]|0;return d|0};case 490:{d=b[(c[2383414]|0)+210>>1]|0;return d|0};case 1228:{d=b[(c[2383414]|0)+212>>1]|0;return d|0};case 1828:{d=b[(c[2383414]|0)+214>>1]|0;return d|0};case 1400:{d=b[(c[2383414]|0)+216>>1]|0;return d|0};case 1598:{d=b[(c[2383414]|0)+218>>1]|0;return d|0};case 1210:{d=b[(c[2383414]|0)+220>>1]|0;return d|0};case 26:{d=b[(c[2383414]|0)+222>>1]|0;return d|0};case 288:{d=b[(c[2383414]|0)+224>>1]|0;return d|0};case 1986:{d=b[(c[2383414]|0)+80>>1]|0;return d|0};case 814:{d=b[(c[2383414]|0)+8>>1]|0;return d|0};case 1752:{d=b[(c[2383414]|0)+10>>1]|0;return d|0};case 16:{d=b[(c[2383414]|0)+12>>1]|0;return d|0};case 122:{d=b[(c[2383414]|0)+14>>1]|0;return d|0};case 892:{d=b[(c[2383414]|0)+16>>1]|0;return d|0};case 592:{d=b[(c[2383414]|0)+18>>1]|0;return d|0};case 78:{d=b[(c[2383414]|0)+20>>1]|0;return d|0};case 1466:{d=b[(c[2383414]|0)+22>>1]|0;return d|0};case 1524:{d=b[(c[2383414]|0)+24>>1]|0;return d|0};case 908:{d=b[(c[2383414]|0)+26>>1]|0;return d|0};case 44:{d=b[(c[2383414]|0)+28>>1]|0;return d|0};case 486:{d=b[(c[2383414]|0)+30>>1]|0;return d|0};case 996:{d=b[(c[2383414]|0)+32>>1]|0;return d|0};case 372:{d=b[(c[2383414]|0)+34>>1]|0;return d|0};case 80:{d=b[c[2383416]>>1]|0;return d|0};case 1784:{d=ga(b[c[2383416]>>1]|0)|0;return d|0};case 92:{d=b[(c[2383414]|0)+118>>1]|0;return d|0};case 934:{d=b[(c[2383414]|0)+158>>1]|0;return d|0};case 198:{d=ga(b[(c[2383414]|0)+158>>1]|0)|0;return d|0};case 172:{d=b[(c[2383416]|0)+4>>1]|0;return d|0};case 194:{d=b[(c[2383414]|0)+44>>1]^b[(c[2383416]|0)+4>>1];return d|0};case 1492:{d=b[(c[2383414]|0)+52>>1]|0;return d|0};case 1980:{d=ga(b[(c[2383414]|0)+118>>1]|0)|0;return d|0};case 758:{a=c[2383414]|0;e=b[a>>1]|0;d=((e&65535)>>>2&3|e&-16|e<<2&12)&~b[a+54>>1];return d|0};case 1898:{d=(b[(c[2383416]|0)+2>>1]&7|c[2383408]&8)&65535;return d|0};case 644:{a=c[2383414]|0;e=b[a+64>>1]|0;d=(e<<1&14|e&-16|(e&65535)>>>3&1)&~b[a+54>>1];return d|0};case 1732:{a=c[2383414]|0;e=b[a+84>>1]|0;d=((e&65535)>>>4|e<<14|e<<10&12288)&~b[a+54>>1];return d|0};case 830:{a=c[2383414]|0;e=b[a+86>>1]|0;d=((e&65535)>>>4&15|e&-256|e<<4&240)&~b[a+54>>1];return d|0};case 342:{a=c[2383414]|0;e=b[a+88>>1]|0;d=(e<<15|(e&65535)>>>4|e<<11&28672)&~b[a+54>>1];return d|0};case 646:{a=c[2383414]|0;e=b[a+106>>1]|0;d=(e<<4&-256|e<<5&224|e<<1&16)&~b[a+54>>1];return d|0};case 2006:{d=b[(c[2383414]|0)+44>>1]^b[c[2383416]>>1];return d|0};case 1204:{a=b[(c[2383414]|0)+50>>1]|0;d=a<<8&-4096|a<<7&1792|a<<11&2048;return d|0};case 60:{d=b[(c[2383414]|0)+190>>1]|0;return d|0};case 914:{d=b[(c[2383414]|0)+174>>1]|0;return d|0};default:{d=0;return d|0}}return 0}function aFm(a){a=a|0;var d=0;switch(a>>>1&1023|0){case 626:{d=b[(c[2383414]|0)+1794>>1]|0;return d|0};case 201:{d=b[(c[2383414]|0)+1934>>1]&-4096;return d|0};case 689:{d=b[(c[2383414]|0)+398>>1]|0;return d|0};case 270:{d=b[(c[2383414]|0)+1284>>1]|0;return d|0};case 318:{a=b[(c[2383414]|0)+1806>>1]|0;d=(a&65535)>>>4|a<<15|a<<11&28672;return d|0};case 362:{d=b[(c[2383414]|0)+258>>1]|0;return d|0};case 237:{d=b[(c[2383414]|0)+256>>1]|0;return d|0};case 694:{d=b[(c[2383414]|0)+1292>>1]|0;return d|0};case 164:{d=b[(c[2383414]|0)+1806>>1]|0;return d|0};case 500:{d=~((e[(c[2383414]|0)+1292>>1]|0)>>>8);return d|0};case 836:{d=b[(c[2383414]|0)+768>>1]|0;return d|0};case 467:{d=b[(c[2383414]|0)+260>>1]|0;return d|0};case 741:{a=b[(c[2383414]|0)+1934>>1]|0;d=(a&65535)>>>4&3840|a&15|a<<8&-4096;return d|0};case 296:{d=b[(c[2383414]|0)+772>>1]|0;return d|0};case 294:{d=b[(c[2383414]|0)+1934>>1]|0;return d|0};case 468:{d=b[(c[2383414]|0)+1280>>1]|0;return d|0};case 956:{d=(b[(c[2383416]|0)+2>>1]&7|c[2383408]&8)&65535;return d|0};case 449:{d=b[(c[2383416]|0)+4>>1]|0;return d|0};case 95:{d=b[(c[2383414]|0)+262>>1]|0;return d|0};case 1002:{d=16;return d|0};case 364:{d=b[(c[2383414]|0)+1282>>1]|0;return d|0};case 275:{d=b[(c[2383414]|0)+1420>>1]|0;return d|0};case 6:{d=b[c[2383416]>>1]|0;return d|0};case 735:{a=b[(c[2383414]|0)+1806>>1]|0;d=a<<4&-256|a&15;return d|0};case 964:{d=b[(c[2383414]|0)+1792>>1]|0;return d|0};case 143:{d=b[(c[2383414]|0)+1280>>1]|0;return d|0};default:{d=-1;return d|0}}return 0}function aFn(a){a=a|0;var d=0,f=0,g=0,h=0,i=0;d=c[2426968]|0;f=(d|0)!=0?c[2383444]|0:c[2383414]|0;switch(a>>>1&1023|0){case 815:{g=b[f+156>>1]|0;return g|0};case 753:{a=b[f+132>>1]|0;g=a<<8&-4096|a<<7&1792|a<<9&512;return g|0};case 917:{a=e[f+134>>1]|0;g=((a<<14&49152|a>>>4|a<<10&12288)^c[3528794])&(c[1765522]^65535)&65535;return g|0};case 188:{a=e[f+136>>1]|0;g=(a<<8|a>>>8)&(c[1765522]^65535)&65535;return g|0};case 519:{a=e[f+138>>1]|0;g=((a<<4&4080|a&61440)^c[3528794])&(c[1765522]^65535)&65535;return g|0};case 292:{a=e[f+140>>1]|0;g=((a<<12|a>>>8|a<<4&3840)^c[3528794])&(c[1765522]^65535)&65535;return g|0};case 319:{g=((e[f+148>>1]|0)<<8&61440^c[3528794])&(c[1765522]^65535)&65535;return g|0};case 256:{a=b[f+160>>1]|0;g=(a&65535)>>>4|a<<13|a<<9&4096;return g|0};case 973:{a=e[f+200>>1]|0;g=((a<<13|a>>>4|a<<9&4096)^c[3528794])&65535;return g|0};case 974:{a=e[f+198>>1]|0;g=(a<<4&4080|a&61440|a>>>8&15)&(c[1765522]^65535)&65535;return g|0};case 786:{g=b[f+154>>1]|0;return g|0};case 15:{a=e[f+196>>1]|0;g=((a<<4&61440|a&255|a>>>4&3840)^c[3528794])&(c[1765522]^65535)&65535;return g|0};case 329:{g=b[(c[2383416]|0)+4>>1]|0;return g|0};case 939:{a=b[f+96>>1]|0;g=(a&65535)>>>4|a<<13|a<<9&4096;return g|0};case 550:{g=(c[2383408]<<9&4096|(e[(c[2383416]|0)+2>>1]|0)<<13)&65535;return g|0};case 456:{g=b[f+44>>1]|0;return g|0};case 622:{g=b[f+98>>1]<<8;return g|0};case 407:{a=e[f+70>>1]|0;g=(a<<4&4080|a&61440)&(c[1765522]^65535)&65535;return g|0};case 525:{a=e[f+132>>1]|0;h=a>>>8;g=((a<<8&61440|h&240|h&15|a<<10&3072|a<<6&768)^c[3528794])&65535;return g|0};case 180:{a=e[f+132>>1]|0;g=(a<<4&65280|a<<3&112|a<<5&32)&(c[1765522]^65535)&65535;return g|0};case 394:{a=b[f+132>>1]|0;g=a<<4&-256|a<<3&112|a<<5&32;return g|0};case 423:{a=b[f+222>>1]|0;g=(a&65535)>>>8&240|a&15|a<<4&-256;return g|0};case 385:{g=b[f+36>>1]|0;return g|0};case 438:{g=(b[(c[2383416]|0)+2>>1]&7|c[2383408]&8)&65535;return g|0};case 530:{a=b[f+96>>1]|0;g=a<<4&-4096|a&255|(a&65535)>>>4&3840;return g|0};case 462:{a=b[f+106>>1]|0;g=(a&65535)>>>4&3840|a&255|a<<4&-4096;return g|0};case 22:{a=e[f+130>>1]|0;g=(a>>>8&240|a&3855|a<<8&61440)&(c[1765522]^65535)&65535;return g|0};case 34:{g=((e[f+44>>1]|0)<<12^c[3528794])&(c[1765522]^65535)&65535;return g|0};case 913:{g=((e[f+220>>1]|0)<<4^c[3528794])&(c[1765522]^65535)&65535;return g|0};case 410:{g=b[f+48>>1]|0;return g|0};case 106:{a=b[f+110>>1]|0;g=a<<4&-256|a<<3&112|a<<7&128;return g|0};case 594:{a=e[f+206>>1]|0;g=((a&4080|a>>>12|a<<12)^c[3528794])&(c[1765522]^65535)&65535;return g|0};case 984:{g=b[f+128>>1]|0;return g|0};case 725:{a=e[f+152>>1]|0;g=((a<<8&61440|a>>>8|a<<7&1792|a<<11&2048)^c[3528794])&(c[1765522]^65535)&65535;return g|0};case 422:{g=b[f+60>>1]|0;return g|0};case 223:{a=e[f+194>>1]|0;g=((a<<4&65280|a<<6&192|a<<2&48)^c[3528794])&(c[1765522]^65535)&65535;return g|0};case 465:{a=e[f+148>>1]|0;g=((a<<8&61440|a>>>8|a<<7&1792|a<<11&2048)^c[3528794])&65535;return g|0};case 321:{g=(e[f+38>>1]|0)<<12&(c[1765522]^65535)&65535;return g|0};case 416:{a=e[f+144>>1]|0;g=((a<<1&14|a&65520|a>>>3&1)^c[3528794])&65535;return g|0};case 450:{a=b[f+220>>1]|0;g=a<<4&-256|(a&65535)>>>12|a<<2&48|a<<6&192;return g|0};case 901:{a=e[f+222>>1]|0;g=((a<<8&61440|a<<9&3584|a<<5&256)^c[3528794])&65535;return g|0};case 721:{a=e[f+36>>1]|0;g=(a>>>4&4080|a&15|a<<8&61440)&(c[1765522]^65535)&65535;return g|0};case 218:{a=b[f+204>>1]|0;g=a<<4&3840|a<<12;return g|0};case 999:{a=b[f+128>>1]|0;g=a<<11&28672|a<<15;return g|0};case 84:{a=e[f+222>>1]|0;g=(a>>>4&4080|a&15|a<<8&61440)&(c[1765522]^65535)&65535;return g|0};case 183:{g=b[f+106>>1]|0;return g|0};case 650:{a=e[f+50>>1]|0;g=(a<<4&65280|a<<2&48|a<<6&192)&(c[1765522]^65535)&65535;return g|0};case 698:{a=e[f+220>>1]|0;g=((a<<2&12|a&65520|a>>>2&3)^c[3528794])&(c[1765522]^65535)&65535;return g|0};case 727:{g=b[f+220>>1]|0;return g|0};case 520:{g=b[f+222>>1]|0;return g|0};case 976:{a=b[f+110>>1]|0;g=(a&65535)>>>4&3840|a&255|a<<4&-4096;return g|0};case 696:{a=e[f+36>>1]|0;g=((a<<8&3840|a&61680)^c[3528794])&65535;return g|0};case 299:{a=e[f+206>>1]|0;g=(a>>>12|a<<4)&(c[1765522]^65535)&65535;return g|0};case 528:{a=b[f+46>>1]|0;h=(a&65535)>>>4;i=a<<4;g=h&3840|i&-4096|h&15|i&240;return g|0};case 805:{i=e[f+222>>1]|0;g=(i<<14|i>>>4|i<<10&12288)&(c[1765522]^65535)&65535;return g|0};case 68:{g=b[c[2383416]>>1]|0;return g|0};case 298:{i=e[f+126>>1]|0;g=((i<<4&65280|i<<2&48|i<<6&192)^c[3528794])&65535;return g|0};case 193:{i=b[f+70>>1]|0;g=(i&65535)>>>8&15|i&-3856|i<<8&3840;return g|0};case 44:{g=b[f+70>>1]|0;return g|0};case 583:{i=b[f+70>>1]|0;g=i<<12|(i&65535)>>>12|(i&65535)>>>4&240|i<<4&3840;return g|0};case 605:{i=e[f+36>>1]|0;g=(i<<4&65280|i>>>12|i<<2&48|i<<6&192)&(c[1765522]^65535)&65535;return g|0};case 73:{i=b[f+60>>1]|0;g=i<<1&14|i&-16|(i&65535)>>>3&1;return g|0};case 248:{i=e[f+162>>1]|0;g=((i<<8|i>>>12|i>>>4&240)^c[3528794])&(c[1765522]^65535)&65535;return g|0};case 295:{i=e[f+70>>1]|0;g=((i<<12|i&3840|i>>>8&240|i>>>4&15)^c[3528794])&65535;return g|0};case 714:{i=e[f+64>>1]|0;g=((i<<8&61440|i<<6&768|i<<10&3072)^c[3528794])&65535;return g|0};case 1009:{i=e[f+150>>1]|0;h=i<<4;g=((h&3840|i&61440|h&240)^c[3528794])&65535;return g|0};case 198:{h=b[f+34>>1]|0;g=h<<15|(h&65535)>>>4|h<<11&28672;return g|0};case 253:{h=e[f+38>>1]|0;g=((h<<12|h&3840|h>>>8&240|h>>>4&15)^c[3528794])&65535;return g|0};case 903:{h=e[f+38>>1]|0;g=((h<<4&65280|h<<2&48|h<<6&192)^c[3528794])&65535;return g|0};case 413:{g=(c[1765522]^65535)&(e[f+96>>1]|0)&65535;return g|0};case 241:{h=b[f+208>>1]|0;g=h<<8|(h&65535)>>>12|(h&65535)>>>4&240;return g|0};case 506:{g=b[f+110>>1]<<4;return g|0};case 343:{h=b[f+156>>1]|0;g=(h&65535)>>>4&255|h&-4096|h<<8&3840;return g|0};case 75:{h=e[f+34>>1]|0;g=((h<<8&61440|h>>>8|h<<7&1792|h<<11&2048)^c[3528794])&(c[1765522]^65535)&65535;return g|0};case 415:{h=e[f>>1]|0;g=(h<<12|h>>>12|h>>>4&240|h<<4&3840)&(c[1765522]^65535)&65535;return g|0};case 866:{c[2426968]=d^1;h=e[f+102>>1]|0;g=(h<<8&3840|h&61680)&(c[1765522]^65535)&65535;return g|0};case 896:{c[2426968]=d^1;h=e[f+102>>1]|0;g=((h>>>4&3840|h<<8&61440)^c[3528794])&65535;return g|0};case 546:{c[2426968]=d^1;h=b[f+102>>1]|0;g=h<<8&-4096|h<<9&3584|h<<5&256;return g|0};case 360:{c[2426968]=d^1;h=e[f+102>>1]|0;g=((h>>>4&3840|h<<8&61440)^c[3528794])&65535;return g|0};case 348:{c[2426968]=d^1;g=((e[f+102>>1]|0)<<8&61440^c[3528794])&65535;return g|0};case 330:{c[2426968]=d^1;g=b[f+102>>1]<<12;return g|0};case 244:{c[2426968]=d^1;g=0;return g|0};case 590:{g=((e[f+108>>1]|0)<<8&61440^c[3528794])&(c[1765522]^65535)&65535;return g|0};case 551:{d=e[f+68>>1]|0;g=((d<<4&3840|d<<12)^c[3528794])&65535;return g|0};case 485:{d=e[f+30>>1]|0;g=((d>>>4|d<<14|d<<10&12288)^c[3528794])&65535;return g|0};case 342:{g=b[f+30>>1]|0;return g|0};case 30:{d=e[f+30>>1]|0;g=(d<<10&12288|d<<14)&(c[1765522]^65535)&65535;return g|0};case 186:{d=e[f+30>>1]|0;g=(d<<8&61440|d>>>8|d<<9&3584|d<<5&256)&(c[1765522]^65535)&65535;return g|0};case 421:{d=e[f+4>>1]|0;g=(d>>>4&15|d&65280|d<<4&240)&(c[1765522]^65535)&65535;return g|0};case 402:{d=b[f+6>>1]|0;g=d<<4&-256|(d&65535)>>>12|d<<5&224|d<<1&16;return g|0};case 418:{d=b[f+8>>1]|0;g=d<<12|(d&65535)>>>8|d<<4&3840;return g|0};case 177:{g=b[f+110>>1]|0;return g|0};case 175:{d=e[f+152>>1]|0;g=((d<<4&65280|d>>>12|d<<6&192|d<<2&48)^c[3528794])&65535;return g|0};case 882:{g=b[f+152>>1]|0;return g|0};case 285:{d=e[f+134>>1]|0;g=((d<<2&12|d&65520|d>>>2&3)^c[3528794])&65535;return g|0};case 55:{d=e[f+150>>1]|0;g=((d>>>8&240|d&3855|d<<8&61440)^c[3528794])&65535;return g|0};case 265:{d=e[f+110>>1]|0;g=((d<<8&61440|d&15|d>>>4&4080)^c[3528794])&65535;return g|0};case 171:{d=e[f+222>>1]|0;g=(d<<4&240|d&65280|d>>>4&15)&(c[1765522]^65535)&65535;return g|0};case 595:{d=b[f+140>>1]|0;g=(d&65535)>>>4&15|d&-256|d<<4&240;return g|0};case 817:{g=b[f+140>>1]|0;return g|0};case 278:{g=b[f+196>>1]<<8&-4096;return g|0};case 959:{d=b[f+98>>1]|0;g=(d&65535)>>>12|d&4080|d<<12;return g|0};case 6:{d=b[f+214>>1]|0;g=(d&65535)>>>12|d<<4;return g|0};case 72:{g=b[f+68>>1]|0;return g|0};case 291:{d=e[f+72>>1]|0;g=((d<<8&61440|d>>>8|d<<10&3072|d<<6&768)^c[3528794])&65535;return g|0};case 675:{d=e[f+98>>1]|0;g=(d<<8&3840|d&61680)&(c[1765522]^65535)&65535;return g|0};case 369:{d=b[f+198>>1]|0;g=d<<11&28672|d<<15;return g|0};case 480:{g=b[f+34>>1]|0;return g|0};case 604:{d=e[f+70>>1]|0;g=((d<<8|d>>>12|d>>>4&240)^c[3528794])&65535;return g|0};case 814:{d=e[f+68>>1]|0;g=((d>>>12|d<<4)^c[3528794])&(c[1765522]^65535)&65535;return g|0};case 405:{d=e[f+192>>1]|0;g=(d<<4&65280|d<<3&112|d<<7&128)&(c[1765522]^65535)&65535;return g|0};case 4:{d=e[f+148>>1]|0;g=(d>>>1&7|d&65520|d<<3&8)&(c[1765522]^65535)&65535;return g|0};case 555:{d=b[f+38>>1]|0;g=d<<1&14|d&-16|(d&65535)>>>3&1;return g|0};case 200:{d=e[f+68>>1]|0;g=(d<<4&4080|d&61440)&(c[1765522]^65535)&65535;return g|0};case 505:{d=e[f+72>>1]|0;g=(d<<4&3840|d<<12)&(c[1765522]^65535)&65535;return g|0};case 351:{g=b[f+64>>1]<<8;return g|0};case 207:{d=e[f+60>>1]|0;g=((d&240|d>>>12|d<<4&61440|d<<8&3840)^c[3528794])&(c[1765522]^65535)&65535;return g|0};case 337:{d=e[f+68>>1]|0;g=((d<<8&61440|d>>>8|d<<7&1792|d<<11&2048)^c[3528794])&(c[1765522]^65535)&65535;return g|0};case 932:{d=b[f+68>>1]|0;g=(d&65535)>>>1&7|d&-16|d<<3&8;return g|0};case 835:{d=b[f+70>>1]|0;g=(d&65535)>>>4&3840|(d&65535)>>>8&15|d<<8&-4096|d<<4&240;return g|0};case 610:{g=(e[f+60>>1]|0)<<12&(c[1765522]^65535)&65535;return g|0};case 668:{g=b[f+60>>1]<<12;return g|0};case 797:{g=b[f+60>>1]<<12;return g|0};case 420:{d=e[f+68>>1]|0;g=((d<<4&65280|d>>>12|d<<3&112|d<<7&128)^c[3528794])&65535;return g|0};case 57:{d=e[f+10>>1]|0;g=(d<<4&65280|d&15|d>>>8&240)&(c[1765522]^65535)&65535;return g|0};case 439:{d=e[f+12>>1]|0;g=(d>>>4&255|d&61440|d<<8&3840)&(c[1765522]^65535)&65535;return g|0};case 712:{d=e[f+14>>1]|0;g=((d<<15|d>>>4|d<<11&28672)^c[3528794])&65535;return g|0};case 987:{d=e[f+2>>1]|0;g=((d<<4&65280|d&15|d>>>8&240)^c[3528794])&(c[1765522]^65535)&65535;return g|0};case 708:{d=e[f+4>>1]|0;g=((d<<8&61440|d&15|d>>>4&4080)^c[3528794])&(c[1765522]^65535)&65535;return g|0};case 251:{d=e[f+6>>1]|0;g=((d<<4&65280|d>>>12|d<<5&224|d<<1&16)^c[3528794])&65535;return g|0};case 608:{d=e[f+8>>1]|0;h=d>>>4;i=d<<4;g=(h&3840|i&61440|h&15|i&240)&(c[1765522]^65535)&65535;return g|0};case 799:{i=b[f+10>>1]|0;g=i<<4&-256|(i&65535)>>>12|i<<6&192|i<<2&48;return g|0};case 998:{i=e[f+12>>1]|0;g=((i<<15|i>>>4|i<<11&28672)^c[3528794])&(c[1765522]^65535)&65535;return g|0};case 222:{i=e[f+14>>1]|0;g=(i<<8|i>>>12|i>>>4&240)&(c[1765522]^65535)&65535;return g|0};case 960:{g=b[f+184>>1]|0;return g|0};case 554:{i=e[f+130>>1]|0;g=((i<<12|i&3840|i>>>8&240|i>>>4&15)^c[3528794])&65535;return g|0};case 671:{i=b[f+158>>1]|0;g=i<<10&12288|i<<14;return g|0};case 296:{i=e[f+98>>1]|0;g=(i>>>8&15|i&61680|i<<8&3840)&(c[1765522]^65535)&65535;return g|0};case 168:{g=b[f+126>>1]|0;return g|0};case 135:{g=b[f+124>>1]|0;return g|0};case 693:{i=e[f+124>>1]|0;g=(i<<15|i>>>4|i<<11&28672)&(c[1765522]^65535)&65535;return g|0};case 461:{i=e[f+126>>1]|0;g=((i<<15|i>>>4|i<<11&28672)^c[3528794])&(c[1765522]^65535)&65535;return g|0};case 196:{i=c[1765522]|0;h=i<<4;g=(i<<6&192|i<<2&48|h&3840|h&61440)&(i^65535)&65535;return g|0};case 486:{g=c[1765522]&65535;return g|0};case 37:{g=(c[1765522]^65535)&(e[f+158>>1]|0)&65535;return g|0};case 1012:{g=((e[f+74>>1]|0)^c[3528794])&65535;return g|0};case 126:{g=b[f+74>>1]|0;return g|0};case 454:{g=b[f+40>>1]|0;return g|0};case 20:{g=b[f+88>>1]|0;return g|0};default:{g=0;return g|0}}return 0}function aFo(a){a=a|0;var d=0;switch(a&2046|0){case 758:{a=b[(c[2383414]|0)+640>>1]|0;d=a<<8&-4096|(a&65535)>>>8|a<<6&768|a<<10&3072;return d|0};case 612:{a=b[(c[2383414]|0)+272>>1]|0;d=a<<8&3840|a&240|a<<4&-4096;return d|0};case 1168:{a=b[(c[2383414]|0)+960>>1]|0;d=a<<1&14|a&-16|(a&65535)>>>3&1;return d|0};case 580:{d=b[c[2383414]>>1]|0;return d|0};case 554:{a=b[(c[2383414]|0)+1440>>1]|0;d=a<<8&-4096|(a&65535)>>>8|a<<11&2048|a<<7&1792;return d|0};case 370:{a=b[(c[2383414]|0)+272>>1]|0;d=a<<4&4080|a&-4096;return d|0};case 1630:{a=b[c[2383414]>>1]|0;d=((a&65535)>>>2&3|a<<2)<<12;return d|0};case 1562:{d=b[c[2383414]>>1]<<8;return d|0};case 190:{a=b[(c[2383414]|0)+880>>1]|0;d=(a&65535)>>>8&15|a&-4096|a<<4&4080;return d|0};case 1996:{a=b[c[2383414]>>1]|0;d=(a&65535)>>>12|a<<12|a<<4&3840|(a&65535)>>>4&240;return d|0};case 532:{d=b[(c[2383414]|0)+640>>1]|0;return d|0};case 1172:{d=b[(c[2383416]|0)+4>>1]|0;return d|0};case 936:{a=b[(c[2383414]|0)+640>>1]|0;d=a<<7&128|(a&65535)>>>12|a<<3&112|a<<4&-256;return d|0};case 1134:{a=b[(c[2383414]|0)+272>>1]|0;d=a<<1&14|a&-16|(a&65535)>>>3&1;return d|0};case 122:{a=b[(c[2383414]|0)+640>>1]|0;d=a<<8&3840|a&-3856|(a&65535)>>>8&15;return d|0};case 1196:{a=b[(c[2383414]|0)+1120>>1]|0;d=a<<9&4096|a<<13;return d|0};case 488:{d=ga(b[(c[2383414]|0)+272>>1]|0)|0;return d|0};case 1326:{a=b[(c[2383414]|0)+640>>1]|0;d=a<<8&3840|a&-3856|(a&65535)>>>8&15;return d|0};case 1486:{a=b[c[2383414]>>1]|0;d=a<<8&-4096|a<<7&1792|a<<11&2048;return d|0};case 392:{a=b[c[2383414]>>1]|0;d=((a&65535)>>>1&7|a<<3)<<12;return d|0};case 1212:{a=b[(c[2383414]|0)+272>>1]|0;d=a<<4&-256|a<<6&192|a<<2&48;return d|0};case 864:{a=b[(c[2383414]|0)+640>>1]|0;d=a<<8&3840|a&-3856|(a&65535)>>>8&15;return d|0};case 1334:{a=b[(c[2383414]|0)+688>>1]|0;d=(a&65535)>>>12|a&240|a<<8&3840|a<<4&-4096;return d|0};case 1034:{a=b[(c[2383414]|0)+272>>1]|0;d=a&3840|a<<12|(a&65535)>>>4&15|(a&65535)>>>8&240;return d|0};case 1808:{a=b[(c[2383414]|0)+1072>>1]|0;d=a<<1&14|a&-16|(a&65535)>>>3&1;return d|0};case 2020:{d=b[(c[2383414]|0)+656>>1]<<8&-4096;return d|0};case 876:case 820:{d=(b[(c[2383416]|0)+2>>1]&7|c[2383408]&8)&65535;return d|0};case 1574:{a=b[(c[2383414]|0)+1456>>1]|0;d=(a&65535)>>>12|a<<8|(a&65535)>>>4&240;return d|0};case 1092:{d=b[(c[2383414]|0)+1540>>1]|0;return d|0};case 1452:{a=b[(c[2383414]|0)+1760>>1]|0;d=(a&65535)>>>4|a<<13|a<<9&4096;return d|0};case 1616:{a=b[(c[2383414]|0)+2e3>>1]|0;d=(a&65535)>>>4|a<<12;return d|0};case 1174:{d=b[(c[2383414]|0)+272>>1]|0;return d|0};case 192:{a=b[c[2383414]>>1]|0;d=((a&65535)>>>1&7|a<<3)<<12;return d|0};case 272:{d=b[c[2383416]>>1]|0;return d|0};case 1244:{a=b[(c[2383414]|0)+640>>1]|0;d=a<<4&-256|a<<5&224|a<<1&16;return d|0};case 220:{d=(b[(c[2383416]|0)+2>>1]&7|c[2383408]&8)<<4&65535;return d|0};default:{d=0;return d|0}}return 0}function aFp(a){a=a|0;var d=0,f=0,g=0,h=0,i=0;d=c[2426968]|0;f=(d|0)!=0?c[2383444]|0:c[2383414]|0;switch(a|0){case 2016:{a=b[f+688>>1]|0;g=a<<2&12|a&-16|(a&65535)>>>2&3;return g|0};case 314:{a=b[f+400>>1]|0;g=a<<8&-4096|a<<10&3072|a<<6&768;return g|0};case 1338:{g=b[f+880>>1]|0;return g|0};case 1650:{g=b[(c[2383416]|0)+4>>1]|0;return g|0};case 1362:{a=b[f+576>>1]|0;g=a<<1&14|a&-16|(a&65535)>>>3&1;return g|0};case 302:{a=b[f+496>>1]|0;h=(a&65535)>>>4;i=a<<4;g=h&3840|i&-4096|h&15|i&240;return g|0};case 1270:{i=b[f+32>>1]|0;g=i<<8&-4096|i<<9&3584|i<<5&256;return g|0};case 1232:{i=b[f+32>>1]|0;g=i<<8&-4096|i<<9&3584|i<<5&256;return g|0};case 76:{g=(b[(c[2383416]|0)+2>>1]&7|c[2383408]&8)&65535;return g|0};case 1356:{g=b[f+752>>1]<<8;return g|0};case 478:{i=b[f+432>>1]|0;g=i<<4&-256|i<<3&112|i<<7&128;return g|0};case 1340:{i=b[f+48>>1]|0;g=i<<4&-256|(i&65535)>>>8&240;return g|0};case 234:{i=b[f+448>>1]|0;g=i<<4&4080|i&-4096;return g|0};case 354:{g=((e[f+224>>1]|0)<<4^c[3528794])&(c[1765522]^65535)&65535;return g|0};case 790:{i=b[f+656>>1]|0;g=i<<4&-4096|i&255|(i&65535)>>>4&3840;return g|0};case 108:{g=b[f+880>>1]<<8;return g|0};case 490:{i=b[f+1392>>1]|0;h=(i&65535)>>>8;g=((i<<10&3072|i<<6&768|i<<8&-4096|h&15|h&240)&65535^c[3528794])&65535;return g|0};case 10:{g=b[f+784>>1]<<4;return g|0};case 1498:{h=b[f+304>>1]|0;g=h<<8&-4096|h<<7&1792|h<<11&2048;return g|0};case 1802:{h=b[f+464>>1]|0;g=h<<4&-256|h<<6&192|h<<2&48;return g|0};case 966:{h=b[f+368>>1]|0;g=(h&65535)>>>1&7|h&-16|h<<3&8;return g|0};case 1726:{h=b[f+336>>1]|0;g=(h&65535)>>>12|h&4080|h<<12;return g|0};case 1410:{g=b[c[2383416]>>1]|0;return g|0};case 1974:{h=b[f>>1]|0;g=((h<<2&12|h&-16|(h&65535)>>>2&3)&65535^c[3528794])&(c[1765522]^65535)&65535;return g|0};case 28:{h=e[f>>1]|0;i=h>>>8;g=((i&240|h<<4&3840|(i|h<<12)&61455)^c[3528794])&65535;return g|0};case 480:{h=b[f>>1]|0;i=h<<4;g=((h<<7&128|(h&65535)>>>12|h<<3&112|i&3840|i&-4096)&65535^c[3528794])&65535;return g|0};case 468:{i=b[f>>1]|0;h=i<<4;g=h&3840|i&15|h&-4096|(i&65535)>>>8&240;return g|0};case 192:{i=b[f+640>>1]|0;h=i<<4;a=(i&65535)>>>4;g=((h&240|a&15|h&-4096|a&3840)&65535^c[3528794])&65535;return g|0};case 1940:{a=b[f+640>>1]|0;g=((a<<1&14|a&-16|(a&65535)>>>3&1)&65535^c[3528794])&65535;return g|0};case 48:{a=e[f+1504>>1]|0;g=((a<<9&4096|a<<13)^c[3528794])&65535;return g|0};case 1058:{a=b[f+976>>1]|0;g=((a<<1&14|a&-16|(a&65535)>>>3&1)&65535^c[3528794])&(c[1765522]^65535)&65535;return g|0};case 1368:{a=b[f+528>>1]|0;g=a<<8&-4096|a&3855|(a&65535)>>>8&240;return g|0};case 62:{a=b[f+528>>1]|0;h=a<<4;i=(a&65535)>>>4;g=(h&240|i&15|h&-4096|i&3840)&65535&(c[1765522]^65535)&65535;return g|0};case 808:{i=b[f+528>>1]|0;h=i<<4;g=((i<<7&128|(i&65535)>>>12|i<<3&112|h&3840|h&-4096)&65535^c[3528794])&65535;return g|0};case 1142:{h=b[f+528>>1]|0;g=h<<8&-4096|h&15|(h&65535)>>>4&4080;return g|0};case 1290:{h=b[f+528>>1]|0;g=h&3840|h<<12|(h&65535)>>>4&15|(h&65535)>>>8&240;return g|0};case 1454:{h=e[f+528>>1]|0;g=((h>>>8&240|h&3840|(h<<12|h>>>4)&61455)^c[3528794])&(c[1765522]^65535)&65535;return g|0};case 430:{h=e[f+976>>1]|0;g=((h<<4&3840|h<<12)^c[3528794])&(c[1765522]^65535)&65535;return g|0};case 1956:{h=b[f+1568>>1]|0;g=(h&65535)>>>8&15|h&-4096|h<<4&4080;return g|0};case 708:{h=e[f+1040>>1]|0;g=((h<<8|h>>>8)^c[3528794])&65535;return g|0};case 118:{h=e[f+672>>1]|0;i=h>>>8;g=((i&240|h<<4&3840|(i|h<<12)&61455)^c[3528794])&(c[1765522]^65535)&65535;return g|0};case 1812:{h=e[f+672>>1]|0;g=(h>>>4|h<<14|h<<10&12288)&(c[1765522]^65535)&65535;return g|0};case 1602:{h=b[f+672>>1]|0;g=(((h&65535)>>>4&3840|(h&65535)>>>8&15|h<<8&-4096|h<<4&240)&65535^c[3528794])&(c[1765522]^65535)&65535;return g|0};case 1178:{h=b[f+1408>>1]|0;g=((h&65535)>>>4&15|h&-256|h<<4&240)&65535&(c[1765522]^65535)&65535;return g|0};case 1180:{h=b[f+1408>>1]|0;g=((h<<7&1792|h<<8&-4096|h<<11&2048)&65535^c[3528794])&(c[1765522]^65535)&65535;return g|0};case 1412:{h=b[f+1408>>1]|0;g=(h<<8&-4096|(h&65535)>>>8|h<<5&256|h<<9&3584)&65535&(c[1765522]^65535)&65535;return g|0};case 1556:{h=e[f+1408>>1]|0;g=(h<<12|h>>>12|h<<4&3840|h>>>4&240)&(c[1765522]^65535)&65535;return g|0};case 24:{h=e[f+560>>1]|0;g=((h>>>4|h<<13|h<<9&4096)^c[3528794])&65535;return g|0};case 2038:{h=e[f+560>>1]|0;g=((h<<4&3840|h<<12)^c[3528794])&(c[1765522]^65535)&65535;return g|0};case 416:{h=b[f+560>>1]|0;g=(h<<8&-4096|(h&65535)>>>8|h<<10&3072|h<<6&768)&65535&(c[1765522]^65535)&65535;return g|0};case 1272:{g=b[f+720>>1]<<4;return g|0};case 470:{g=((e[f+160>>1]|0)<<4^c[3528794])&65535;return g|0};case 596:{h=b[f+800>>1]|0;g=(h<<4&-4096|h&240|h<<8&3840)&65535&(c[1765522]^65535)&65535;return g|0};case 746:{g=((e[f+800>>1]|0)<<8^c[3528794])&(c[1765522]^65535)&65535;return g|0};case 542:{h=b[f+752>>1]|0;g=((h<<1&14|h&-16|(h&65535)>>>3&1)&65535^c[3528794])&(c[1765522]^65535)&65535;return g|0};case 1968:{h=e[f+752>>1]|0;g=((h>>>4|h<<13|h<<9&4096)^c[3528794])&65535;return g|0};case 2010:{h=e[f+752>>1]|0;g=((h<<12&61440|h>>>8|h<<4&3840)^c[3528794])&(c[1765522]^65535)&65535;return g|0};case 640:{h=b[f+720>>1]|0;g=((h<<8|(h&65535)>>>12|(h&65535)>>>4&240)&65535^c[3528794])&65535;return g|0};case 1046:{h=b[f+736>>1]|0;i=(h&65535)>>>4;g=i&15|h&-4096|h<<8&3840|i&240;return g|0};case 172:{i=b[f+848>>1]|0;g=((i<<4&4080|i&-4096|(i&65535)>>>8&15)&65535^c[3528794])&(c[1765522]^65535)&65535;return g|0};case 706:{i=b[f+736>>1]|0;g=(i&65535)>>>4&255|i&-4096|i<<8&3840;return g|0};case 1104:{i=b[f+1088>>1]|0;g=i<<12|(i&65535)>>>8|i<<4&3840;return g|0};case 1284:{i=b[f+1088>>1]|0;g=((i<<2&48|i<<6&192|i<<4&-256)&65535^c[3528794])&65535;return g|0};case 254:{g=b[f+1088>>1]<<4;return g|0};case 448:{c[2426968]=d^1;g=0;return g|0};case 226:{c[2426968]=d^1;g=((e[f+1728>>1]|0)^c[3528794])&65535;return g|0};case 1092:{d=e[f+160>>1]|0;g=(d>>>4|d<<13|d<<9&4096)&(c[1765522]^65535)&65535;return g|0};case 1130:{d=b[f+16>>1]|0;g=d<<8&-4096|(d&65535)>>>8|d<<9&3584|d<<5&256;return g|0};case 128:{g=b[f+224>>1]|0;return g|0};case 178:{g=(b[f+640>>1]<<8&-4096&65535^c[3528794])&(c[1765522]^65535)&65535;return g|0};case 592:{d=b[f+352>>1]|0;i=d<<4;g=((i&-4096|(d&65535)>>>12|i&3840|d<<3&112|d<<7&128)&65535^c[3528794])&(c[1765522]^65535)&65535;return g|0};case 774:{d=b[f+352>>1]|0;g=((d<<8&-4096|(d&65535)>>>4&3840)&65535^c[3528794])&65535;return g|0};case 1544:{d=b[f+352>>1]|0;g=(d<<8&-4096|d&15|(d&65535)>>>4&4080)&65535&(c[1765522]^65535)&65535;return g|0};case 1326:{d=b[f+352>>1]|0;g=((d<<4&-4096|d&255|(d&65535)>>>4&3840)&65535^c[3528794])&(c[1765522]^65535)&65535;return g|0};case 1658:{d=b[f+912>>1]|0;g=d<<4&-256|d&15|(d&65535)>>>8&240;return g|0};case 1730:{d=b[f+912>>1]|0;g=((d<<8&-4096|d<<6&768|d<<10&3072)&65535^c[3528794])&(c[1765522]^65535)&65535;return g|0};case 984:{d=b[f+2016>>1]|0;g=(d<<4&-256|d&15|(d&65535)>>>8&240)&65535&(c[1765522]^65535)&65535;return g|0};case 580:{d=b[f+1888>>1]|0;g=((d<<4&-4096|d&240|d<<8&3840)&65535^c[3528794])&(c[1765522]^65535)&65535;return g|0};case 2024:{d=b[f+912>>1]|0;g=(((d&65535)>>>4&3840|d&255|d<<4&-4096)&65535^c[3528794])&65535;return g|0};case 630:{g=((e[f+2016>>1]|0)<<8^c[3528794])&(c[1765522]^65535)&65535;return g|0};case 1344:{d=b[f+1328>>1]|0;g=(d<<8&-4096|d<<9&3584|d<<5&256)&65535&(c[1765522]^65535)&65535;return g|0};case 1474:{d=b[f+2016>>1]|0;g=d<<4&-256|(d&65535)>>>12|d<<2&48|d<<6&192;return g|0};case 1128:{d=b[f+1392>>1]|0;i=d<<4;g=((d<<2&48|(d&65535)>>>12|d<<6&192|i&3840|i&-4096)&65535^c[3528794])&(c[1765522]^65535)&65535;return g|0};case 348:{i=b[f+560>>1]|0;g=((i<<4&240|i&-256|(i&65535)>>>4&15)&65535^c[3528794])&65535;return g|0};case 44:{g=(e[f+912>>1]|0)<<8&(c[1765522]^65535)&65535;return g|0};default:{g=0;return g|0}}return 0}function aFq(d,e){d=d|0;e=e|0;if((d&-16|0)==3145728){b[(c[2383434]|0)+((d>>>1&7)<<1)>>1]=e;return}do{if((d|0)==1573130){c[2383412]=e&255;if((a[9661085]|0)==1){break}a[9661085]=1;if((a[9661088]|0)!=0){break}a[9661088]=2}else{if((d&16775168|0)==1572864){break}return}}while(0);b[(c[2387036]|0)+(d&2046)>>1]=e;return}function aFr(b,d){b=b|0;d=d|0;do{if((b|0)==1573131){c[2383412]=d&255;if((a[9661085]|0)==1){break}a[9661085]=1;if((a[9661088]|0)!=0){break}a[9661088]=2}else{if((b&16775168|0)==1572864){break}return}}while(0);a[(c[2387036]|0)+(b&2047^1)|0]=d;return}function aFs(a){a=a|0;var b=0;if((a&16775168|0)!=1572864){b=0;return b|0}b=aFm(a)|0;return b|0}function aFt(a){a=a|0;var b=0;if((a&16775168|0)!=1572864){b=0;return b|0}b=((aFm(a)|0)&65535)>>>((a<<3&8^8)>>>0)&255;return b|0}function aFu(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2849116+(b*112|0)>>2];c[a+104>>2]=c[2849120+(b*112|0)>>2];c[a+108>>2]=c[2849124+(b*112|0)>>2];d=0;return d|0}function aFv(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=2849016+(b*112|0);e=0;return e|0}function aFw(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1263864+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aFx(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>47){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3938592+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aFy(){var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;d=i;i=i+600|0;e=d|0;f=d+112|0;g=d+120|0;j=d+232|0;k=d+240|0;l=d+352|0;m=d+360|0;n=d+472|0;o=d+480|0;p=d+592|0;c[2424]=5800;c[2414856]=0;c[2388076]=0;c[2387772]=524288;c[3530754]=589824;c[3530518]=1638400;c[3530386]=2686976;c[3541206]=4784128;c[2386594]=4784128;c[3529896]=5046272;c[2414558]=5050368;c[2388206]=5050368;c[2387794]=5066752;c[2386384]=5074944;c[2383414]=5076992;c[2387036]=5076992;c[2387102]=5079040;c[3528654]=5081088;c[2411458]=5081089;q=0;while(1){if((q|0)>=1024){break}r=9638528+(q<<2)|0;if((c[r>>2]|0)==0){s=26359;break}else{q=q+1|0}}do{if((s|0)==26359){q=gGq(5081089)|0;c[r>>2]=q;if((q|0)==0){break}c[2414856]=q;gGz(q|0,0,5081089);c[2388076]=q;c[2387772]=q+524288;c[3530754]=q+589824;c[3530518]=q+1638400;c[3530386]=q+2686976;t=q+4784128|0;c[3541206]=t;c[2386594]=t;c[3529896]=q+5046272;t=q+5050368|0;c[2414558]=t;c[2388206]=t;c[2387794]=q+5066752;c[2386384]=q+5074944;t=q+5076992|0;c[2383414]=t;c[2387036]=t;c[2387102]=q+5079040;c[3528654]=q+5081088;t=q+5081089|0;c[2411458]=t;c[2413998]=t;if((R6(q+1|0,0,2)|0)!=0){u=1;i=d;return u|0}if((R6(c[2388076]|0,1,2)|0)!=0){u=1;i=d;return u|0}q=c[2387772]|0;if((c[3542200]|0)==0){u=1;i=d;return u|0}t=o+108|0;c[t>>2]=0;v=o+100|0;c[v>>2]=0;w=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[w&16383](o,2)|0;do{if((c[t>>2]|0)!=0){w=c[v>>2]|0;c[p>>2]=9534384;x=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[x&16383](p,2,0)|0;if((w|0)<1){u=1;i=d;return u|0}if((gzL(q,0,2)|0)==0){break}else{u=1}i=d;return u|0}}while(0);q=c[3530518]|0;if((c[3542200]|0)==0){u=1;i=d;return u|0}v=m+108|0;c[v>>2]=0;t=m+100|0;c[t>>2]=0;w=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[w&16383](m,3)|0;do{if((c[v>>2]|0)!=0){w=c[t>>2]|0;c[n>>2]=9534384;x=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[x&16383](n,3,0)|0;if((w|0)<1){u=1;i=d;return u|0}if((gzL(q,0,3)|0)==0){break}else{u=1}i=d;return u|0}}while(0);q=c[3530386]|0;if((c[3542200]|0)==0){u=1;i=d;return u|0}t=k+108|0;c[t>>2]=0;v=k+100|0;c[v>>2]=0;w=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[w&16383](k,4)|0;do{if((c[t>>2]|0)!=0){w=c[v>>2]|0;c[l>>2]=9534384;x=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[x&16383](l,4,0)|0;if((w|0)<1){u=1;i=d;return u|0}if((gzL(q,0,4)|0)==0){break}else{u=1}i=d;return u|0}}while(0);q=(c[3530386]|0)+524288|0;if((c[3542200]|0)==0){u=1;i=d;return u|0}v=g+108|0;c[v>>2]=0;t=g+100|0;c[t>>2]=0;w=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[w&16383](g,5)|0;do{if((c[v>>2]|0)!=0){w=c[t>>2]|0;c[j>>2]=9534384;x=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[x&16383](j,5,0)|0;if((w|0)<1){u=1;i=d;return u|0}if((gzL(q,0,5)|0)==0){break}else{u=1}i=d;return u|0}}while(0);q=c[2386594]|0;if((c[3542200]|0)==0){u=1;i=d;return u|0}t=e+108|0;c[t>>2]=0;v=e+100|0;c[v>>2]=0;w=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[w&16383](e,6)|0;do{if((c[t>>2]|0)!=0){w=c[v>>2]|0;c[f>>2]=9534384;x=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[x&16383](f,6,0)|0;if((w|0)<1){u=1;i=d;return u|0}if((gzL(q,0,6)|0)==0){break}else{u=1}i=d;return u|0}}while(0);aFg(c[3530518]|0,524288,1572008,716440,1108208);aE_(c[3530518]|0,c[3530754]|0,524288,1);q=c[3530518]|0;aE_(q,q,524288,0);q=c[3530386]|0;aE_(q,q,1048576,0);aE1(1,0,1);q=c[3530518]|0;c[2383440]=c[3530754];c[2383441]=q;c[2383442]=0;c[2383436]=16383;c[2383437]=4095;c[2383438]=0;c[2429666]=256;c[2429667]=512;a[690376]=1;fxU(0,425984);if((c[2394]|0)==0){y=c[2112932]|0}else{c[2394]=0;q=c[3532596]|0;c[2112932]=q;v=c[3532592]|0;if((v|0)!=0){gGC(9104152,v|0,280)|0}c[2113054]=c[2113060];y=q}q=c[2388076]|0;v=y|0;t=0;while(1){w=q+t|0;c[v>>2]=w;c[v+131072>>2]=w;w=t+1024|0;if(w>>>0>524287){break}else{v=v+4|0;t=w}}t=c[2387102]|0;c[y+4608>>2]=t;c[y+70144>>2]=t;c[y+135680>>2]=t;v=t+1024|0;c[y+4612>>2]=v;c[y+70148>>2]=v;c[y+135684>>2]=v;v=c[2388206]|0;c[y+5120>>2]=v;c[y+70656>>2]=v;c[y+136192>>2]=v;t=v+1024|0;c[y+5124>>2]=t;c[y+70660>>2]=t;c[y+136196>>2]=t;t=v+2048|0;c[y+5128>>2]=t;c[y+70664>>2]=t;c[y+136200>>2]=t;t=v+3072|0;c[y+5132>>2]=t;c[y+70668>>2]=t;c[y+136204>>2]=t;t=v+4096|0;c[y+5136>>2]=t;c[y+70672>>2]=t;c[y+136208>>2]=t;t=v+5120|0;c[y+5140>>2]=t;c[y+70676>>2]=t;c[y+136212>>2]=t;t=v+6144|0;c[y+5144>>2]=t;c[y+70680>>2]=t;c[y+136216>>2]=t;t=v+7168|0;c[y+5148>>2]=t;c[y+70684>>2]=t;c[y+136220>>2]=t;t=v+8192|0;c[y+5152>>2]=t;c[y+70688>>2]=t;c[y+136224>>2]=t;t=v+9216|0;c[y+5156>>2]=t;c[y+70692>>2]=t;c[y+136228>>2]=t;t=v+10240|0;c[y+5160>>2]=t;c[y+70696>>2]=t;c[y+136232>>2]=t;t=v+11264|0;c[y+5164>>2]=t;c[y+70700>>2]=t;c[y+136236>>2]=t;t=v+12288|0;c[y+5168>>2]=t;c[y+70704>>2]=t;c[y+136240>>2]=t;t=v+13312|0;c[y+5172>>2]=t;c[y+70708>>2]=t;c[y+136244>>2]=t;t=v+14336|0;c[y+5176>>2]=t;c[y+70712>>2]=t;c[y+136248>>2]=t;t=v+15360|0;c[y+5180>>2]=t;c[y+70716>>2]=t;c[y+136252>>2]=t;t=c[2386384]|0;c[y+5632>>2]=t;c[y+71168>>2]=t;c[y+136704>>2]=t;v=t+1024|0;c[y+5636>>2]=v;c[y+71172>>2]=v;c[y+136708>>2]=v;v=c[2383430]|0;c[y+12800>>2]=v;c[y+78336>>2]=v;c[y+143872>>2]=v;t=v+1024|0;c[y+12804>>2]=t;c[y+78340>>2]=t;c[y+143876>>2]=t;t=v+2048|0;c[y+12808>>2]=t;c[y+78344>>2]=t;c[y+143880>>2]=t;t=v+3072|0;c[y+12812>>2]=t;c[y+78348>>2]=t;c[y+143884>>2]=t;t=v+4096|0;c[y+12816>>2]=t;c[y+78352>>2]=t;c[y+143888>>2]=t;t=v+5120|0;c[y+12820>>2]=t;c[y+78356>>2]=t;c[y+143892>>2]=t;t=v+6144|0;c[y+12824>>2]=t;c[y+78360>>2]=t;c[y+143896>>2]=t;t=v+7168|0;c[y+12828>>2]=t;c[y+78364>>2]=t;c[y+143900>>2]=t;t=c[2383431]|0;c[y+12832>>2]=t;c[y+78368>>2]=t;c[y+143904>>2]=t;v=t+1024|0;c[y+12836>>2]=v;c[y+78372>>2]=v;c[y+143908>>2]=v;v=t+2048|0;c[y+12840>>2]=v;c[y+78376>>2]=v;c[y+143912>>2]=v;v=t+3072|0;c[y+12844>>2]=v;c[y+78380>>2]=v;c[y+143916>>2]=v;v=t+4096|0;c[y+12848>>2]=v;c[y+78384>>2]=v;c[y+143920>>2]=v;v=t+5120|0;c[y+12852>>2]=v;c[y+78388>>2]=v;c[y+143924>>2]=v;v=t+6144|0;c[y+12856>>2]=v;c[y+78392>>2]=v;c[y+143928>>2]=v;v=t+7168|0;c[y+12860>>2]=v;c[y+78396>>2]=v;c[y+143932>>2]=v;v=c[2383428]|0;c[y+13312>>2]=v;c[y+78848>>2]=v;c[y+144384>>2]=v;t=v+1024|0;c[y+13316>>2]=t;c[y+78852>>2]=t;c[y+144388>>2]=t;t=v+2048|0;c[y+13320>>2]=t;c[y+78856>>2]=t;c[y+144392>>2]=t;t=c[2383426]|0;c[y+13344>>2]=t;c[y+78880>>2]=t;c[y+144416>>2]=t;v=t+1024|0;c[y+13348>>2]=v;c[y+78884>>2]=v;c[y+144420>>2]=v;v=t+2048|0;c[y+13352>>2]=v;c[y+78888>>2]=v;c[y+144424>>2]=v;c[y+196728>>2]=1370;c[y+196648>>2]=2448;c[y+196688>>2]=3508;c[y+196608>>2]=2924;v=c[3532592]|0;if((v|0)!=0){gGC(v|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;aE8(c[2387772]|0,c[2387794]|0,8055e3,0,0,.45,1e6,.5,0,0.0);h[745421]=.45;c[2436794]=1;h[745420]=.45;c[2436792]=2;v=c[642608+(c[2436]<<2)>>2]|0;t=c[v+128>>2]|0;if((c[v+52>>2]&4|0)==0){c[2113068]=t;q=c[v+132>>2]|0;c[2113070]=q;c[2443814]=t;c[2440436]=q;z=t;A=q}else{c[2113070]=t;q=c[v+132>>2]|0;c[2113068]=q;c[2440436]=t;c[2443814]=q;z=q;A=t}t=ag(z<<1,A)|0;q=gGq(t)|0;c[2112926]=q;if((q|0)!=0){gGz(q|0,0,t|0)}t=c[2414558]|0;gGz(t|0,0,(c[2411458]|0)-t|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];t=c[3532592]|0;if((t|0)!=0){gGC(9104152,t|0,280)|0}c[2113054]=c[2113060]}RI();t=c[2394]|0;q=c[14130368+(t<<2)>>2]|0;if((q|0)!=0){gGC(q|0,9104152,280)|0}c[8452240+(t<<2)>>2]=c[2113054];c[2394]=-1;aE7();gGz(c[2383428]|0,0,4096);gGz(c[2383426]|0,0,4096);t=c[2383424]|0;if((t|0)!=0){gGz(t|0,0,4096);gGz(c[2383422]|0,0,4096)}gGz(c[2383434]|0,0,16);gGz(c[2383435]|0,0,16);gGz(c[2383430]|0,0,8192);gGz(c[2383431]|0,0,8192);t=c[2383432]|0;if((t|0)!=0){gGz(t|0,0,8192);gGz(c[2383433]|0,0,8192)}b[4766836]=0;c[2426968]=0;c[3528794]=0;c[1765522]=65535;c[2429656]=0;c[2427042]=0;c[2429386]=0;c[2429384]=0;c[2429382]=0;u=0;i=d;return u|0}}while(0);c[2414856]=0;u=1;i=d;return u|0}function aFz(){var a=0,b=0,d=0,e=0,f=0;c[2113070]=0;c[2113068]=0;a=c[2112926]|0;if((a|0)!=0){gGr(a);c[2112926]=0}aE2();if((c[2392]|0)>=0){a=0;do{b=14130368+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}b=14130384+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}a=a+1|0;}while((a|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;aFe();a=c[2414856]|0;b=0;while(1){if((b|0)>=1024){e=26442;break}f=9638528+(b<<2)|0;if((c[f>>2]|0)==(a|0)){break}else{b=b+1|0}}if((e|0)==26442){c[2414856]=0;return 0}gGr(a);c[f>>2]=0;c[2414856]=0;return 0}function aFA(){var e=0,f=0,g=0,h=0,i=0,j=0;if((a[9623408]|0)!=0){e=c[2414558]|0;gGz(e|0,0,(c[2411458]|0)-e|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060]}RI();e=c[2394]|0;f=c[14130368+(e<<2)>>2]|0;if((f|0)!=0){gGC(f|0,9104152,280)|0}c[8452240+(e<<2)>>2]=c[2113054];c[2394]=-1;aE7();gGz(c[2383428]|0,0,4096);gGz(c[2383426]|0,0,4096);e=c[2383424]|0;if((e|0)!=0){gGz(e|0,0,4096);gGz(c[2383422]|0,0,4096)}gGz(c[2383434]|0,0,16);gGz(c[2383435]|0,0,16);gGz(c[2383430]|0,0,8192);gGz(c[2383431]|0,0,8192);e=c[2383432]|0;if((e|0)!=0){gGz(e|0,0,8192);gGz(c[2383433]|0,0,8192)}b[4766836]=0;c[2426968]=0;c[3528794]=0;c[1765522]=65535;c[2429656]=0;c[2427042]=0;c[2429386]=0;c[2429384]=0;c[2429382]=0}c[2383416]=9550160;c[2387540]=-1;e=0;f=-1;g=-1;do{f=((a[9632400+e|0]&1)<<e^f&65535)&65535;g=((a[9630312+e|0]&1)<<e^g&65535)&65535;e=e+1|0;}while((e|0)<16);b[4775080]=f;b[4775081]=g;b[4775082]=d[9634681]<<8|d[9634680];c[(c[2391608]|0)+60>>2]=0;c[(c[2391608]|0)+60>>2]=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060]}c[2388530]=9554128;g=c[2391608]|0;if((g|0)!=0){f=g;gGC(9661040,f|0,68)|0}c[2382]=0;c[2383408]=0;f=0;g=0;while(1){c[2113056]=942;e=RG(942)|0;c[2113054]=(c[2113054]|0)+e;c[2276108]=-1;c[2113056]=-1;fy_(542)|0;if((f|0)==248){c[2383408]=8}e=c[2112964]|0;if((e|0)==0){h=g}else{i=a[9688]|0?2:0;j=e+(g<<1<<1)|0;if(a[801408]|0){gg[c[3542124]&4095](j,i)}if(a[801400]|0){Uu(0,j,i)}if((c[2429658]|0)!=0){Uu(1,j,i)}h=i+g|0}i=f+1|0;if((i|0)<256){f=i;g=h}else{break}}c[8452200+(c[2394]<<2)>>2]=8198;c[2276080]=1536;if((c[2276079]|0)>>>0<1536){RH(6)}g=c[2112964]|0;do{if((g|0)!=0){f=a[9688]|0?534:0;if((f|0)==(h|0)){break}i=f-h|0;f=g+(h<<1<<1)|0;if(a[801408]|0){gg[c[3542124]&4095](f,i)}if(a[801400]|0){Uu(0,f,i)}if((c[2429658]|0)==0){break}Uu(1,f,i)}}while(0);h=c[(c[2388530]|0)+12304>>2]|0;if((h|0)!=0){g=h;gGC(g|0,9661040,68)|0}c[2382]=-1;g=c[2394]|0;h=c[14130368+(g<<2)>>2]|0;if((h|0)!=0){gGC(h|0,9104152,280)|0}c[8452240+(g<<2)>>2]=c[2113054];c[2394]=-1;if((c[2112968]|0)==0){return 0}aFB()|0;return 0}function aFB(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;d=c[2387102]|0;f=c[3529896]|0;g=0;do{h=e[d+(g<<1)>>1]|0;i=h>>>8;j=h>>>4&15;c[f+(g<<2)>>2]=(i&8|i<<4)>>>3&31|(h&8|h<<4)<<8&63488|(j<<4|j)<<3&2016;g=g+1|0;}while((g|0)<1024);a[9547088]=0;aE3();g=c[2113070]|0;f=ag(g,c[2113068]|0)|0;d=c[2112926]|0;if((f|0)>0){j=0;while(1){b[d+(j<<1)>>1]=768;h=j+1|0;if((h|0)<(f|0)){j=h}else{k=d;break}}}else{k=d}aE0(1,k,65536);aE0(0,k,0);d=c[2386384]|0;j=c[3528654]|0;f=c[3530386]|0;h=(c[2113222]&1|0)==0;i=0;do{l=e[d+(i<<1)>>1]|0;m=e[d+((i|2)<<1)>>1]|0;do{if((l&4096|0)==0|h){n=m>>>9&31;o=l&8192;p=l&16384;q=1<<(l>>>9&3);r=q-1|0;s=m&511;t=l&511;u=s>>>0>319?m|-512:s;s=t>>>0>255?l|-512:t;t=((p|0)==0?r:0)+(-q&e[d+((i|1)<<1)>>1])|0;v=(p>>>13^2)-1|0;if((a[j]|0)==0){w=p;x=o;y=-16;z=304-u|0;A=240-s|0}else{w=p>>>14^1;x=o>>>13^1;y=16;z=u;A=s}if(!((z+15|0)>>>0<335&(A|0)<(g|0)&(q|0)>0)){break}q=(x|0)!=0;if((w|0)==0){if(q){s=r;while(1){u=ag(s,y)|0;SJ(k,t-(ag(s,v)|0)&16383,z,(u+A&511)-8|0,n,4,0,0,f);if((s|0)>0){s=s-1|0}else{break}}}else{s=r;while(1){u=ag(s,y)|0;SH(k,t-(ag(s,v)|0)&16383,z,(u+A&511)-8|0,n,4,0,0,f);if((s|0)>0){s=s-1|0}else{break}}}}else{if(q){s=r;while(1){u=((ag(s,y)|0)+A&511)-8|0;SN(k,t-(ag(s,v)|0)&16383,z,u,n,4,0,0,f);if((s|0)>0){s=s-1|0}else{break}}}else{s=r;while(1){q=((ag(s,y)|0)+A&511)-8|0;SL(k,t-(ag(s,v)|0)&16383,z,q,n,4,0,0,f);if((s|0)>0){s=s-1|0}else{break}}}}}}while(0);i=i+4|0;}while((i|0)<1024);R8(c[3529896]|0);return 0}function aFC(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=i;i=i+64|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;if((d|0)!=0){c[d>>2]=169762}if((b&32|0)!=0){gGz(j|0,0,12);k=c[2414558]|0;c[j>>2]=k;c[j+4>>2]=(c[2411458]|0)-k;c[j+12>>2]=162152;k=c[2076592]|0;gj[k&4095](j)|0}if((b&64|0)==0){i=e;return 0}j=h|0;gGz(g|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){k=h+9|0;h=f;l=f|0;m=f+4|0;n=f+12|0;o=g|0;p=g+4|0;q=g+12|0;r=0;do{gGC(j|0,614896,11)|0;a[k]=r+48&255;s=8452256+(r<<2)|0;gGz(h|0,0,12);c[l>>2]=s;c[m>>2]=4;c[n>>2]=164976;gj[c[2076592]&4095](f)|0;if((c[s>>2]|0)!=0){c[o>>2]=c[14130368+(r<<2)>>2];c[p>>2]=c[8452184+(r<<2)>>2];c[q>>2]=j;s=c[2076592]|0;gj[s&4095](g)|0}r=r+1|0;}while((r|0)<=(c[2392]|0))}aFf(b,d);aE6();i=e;return 0}function aFD(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1547364+(b*112|0)>>2];c[a+104>>2]=c[1547368+(b*112|0)>>2];c[a+108>>2]=c[1547372+(b*112|0)>>2];d=0;return d|0}function aFE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=1547264+(b*112|0);e=0;return e|0}function aFF(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>47){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1913136+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aFG(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2251500+(b*112|0)>>2];c[a+104>>2]=c[2251504+(b*112|0)>>2];c[a+108>>2]=c[2251508+(b*112|0)>>2];d=0;return d|0}function aFH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=2251400+(b*112|0);e=0;return e|0}function aFI(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>44){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3409344+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aFJ(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=b&65535;if((e|0)==14400){b=(d&255)>>>4<<14;c[2406854]=b;f=c[3530266]|0;g=c[3528552]|0;h=c[2433426]|0;i=b+49152|0;b=64;j=64;while(1){k=f+(i+(j<<8))|0;c[h+(g*3160|0)+60+(j<<2)>>2]=k;c[h+(g*3160|0)+60+(j+512<<2)>>2]=k;k=b+1&65535;if((k&65535)>127){break}else{b=k;j=k&65535}}a[c[2432942]|0]=d&1;a[c[3528482]|0]=d&2;a[c[3528652]|0]=d&8;return}else if((e|0)==14432|(e|0)==14433){j=e&1;b=d&255;c[2440606]=0;if((j|0)==1){g=c[2444190]&65280|b;c[2444190]=g;l=g}else if((j|0)==0){j=c[2444190]&255|b<<8;c[2444190]=j;l=j}else{l=c[2444190]|0}if((l|0)==170){c[2440606]=1621;return}else if((l|0)==539){c[2440606]=1764;return}else if((l|0)==538){c[2440606]=1765;return}else{return}}else if((e|0)==14336){a[c[3528212]|0]=d;gg[c[(c[2443776]|0)+64>>2]&4095](32,1);gj[c[(c[2443776]|0)+52>>2]&4095](0)|0;gg[c[(c[2443776]|0)+64>>2]&4095](32,0);gj[c[(c[2443776]|0)+52>>2]&4095](0)|0;return}else{if((e&65504|0)!=14368){return}a[(c[3529872]|0)+(e&31)|0]=d;return}}function aFK(b){b=b|0;var d=0;switch(b&65535|0){case 14368:{d=a[9634673]|0;break};case 14337:{d=a[9550153]|0;break};case 14338:{d=a[9550154]|0;break};case 14400:{d=(c[2440606]|0)>>>8&255;break};case 14339:{d=(c[2408976]|a[9634672]&240|a[9550155]&7)&255;break};case 14432:{d=c[2440606]&255;break};case 14336:{d=a[9550152]|0;break};default:{d=0}}return d|0}function aFL(b,e){b=b|0;e=e|0;var f=0,g=0;f=b&65535;if((f|0)==16384|(f|0)==16385){b=c[3540984]|0;if((f&1|0)==0){a[b+5885|0]=e;return}g=c[b+5876>>2]|0;if((g|0)!=0){gg[g&4095](c[b+5880>>2]|0,0)}lH(b,d[b+5885|0]|0,e&255);return}else if((f|0)==8192|(f|0)==8193){lS(0,f&1,e);return}else{return}}function aFM(b){b=b|0;var d=0,e=0;d=b&65535;if(!((d|0)==12288|(d|0)==24576)){e=0;return e|0}e=a[c[3528212]|0]|0;return e|0}function aFN(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5881212+(b*112|0)>>2];c[a+104>>2]=c[5881216+(b*112|0)>>2];c[a+108>>2]=c[5881220+(b*112|0)>>2];d=0;return d|0}function aFO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<22&(d|0)==0)){e=1;return e|0}c[a>>2]=5881112+(b*112|0);e=0;return e|0}function aFP(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3912528+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aFQ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>28){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6295328+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aFR(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0;e=i;i=i+4800|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;B=e+1200|0;C=e+1312|0;D=e+1320|0;E=e+1432|0;F=e+1440|0;G=e+1552|0;H=e+1560|0;I=e+1672|0;J=e+1680|0;K=e+1792|0;L=e+1800|0;M=e+1912|0;N=e+1920|0;O=e+2032|0;P=e+2040|0;Q=e+2152|0;R=e+2160|0;S=e+2272|0;T=e+2280|0;U=e+2392|0;V=e+2400|0;W=e+2512|0;X=e+2520|0;Y=e+2632|0;Z=e+2640|0;_=e+2752|0;$=e+2760|0;aa=e+2872|0;ab=e+2880|0;ac=e+2992|0;ad=e+3e3|0;ae=e+3112|0;af=e+3120|0;ah=e+3232|0;ai=e+3240|0;aj=e+3352|0;ak=e+3360|0;al=e+3472|0;am=e+3480|0;an=e+3592|0;ao=e+3600|0;ap=e+3712|0;aq=e+3720|0;ar=e+3832|0;as=e+3840|0;at=e+3952|0;au=e+3960|0;av=e+4072|0;aw=e+4080|0;ax=e+4192|0;ay=e+4200|0;az=e+4312|0;aA=e+4320|0;aB=e+4432|0;aC=e+4440|0;aD=e+4552|0;aE=e+4560|0;aF=e+4672|0;aG=e+4680|0;aH=e+4792|0;c[2414854]=0;c[3530266]=0;c[2386358]=327680;c[3527436]=458752;c[3527440]=589824;c[3530752]=655360;c[3530516]=786432;c[3530384]=1835008;c[3530308]=2883584;c[3531056]=3932160;c[2407020]=3934208;c[3529894]=3938304;c[2414556]=3942400;c[3530268]=3942400;c[2386282]=3950592;c[2387082]=3952640;c[2387076]=3956736;c[3529872]=3960832;c[3529870]=3960864;c[2386744]=3960896;c[2386382]=3961920;c[2386556]=3963968;c[2387100]=3966016;c[3527438]=3968064;c[3528212]=3970112;c[3528482]=3970113;c[2432942]=3970114;c[3528652]=3970115;c[2411456]=3970116;aI=0;while(1){if((aI|0)>=1024){break}aJ=9638528+(aI<<2)|0;if((c[aJ>>2]|0)==0){aK=26644;break}else{aI=aI+1|0}}do{if((aK|0)==26644){aI=gGq(3970116)|0;c[aJ>>2]=aI;if((aI|0)==0){break}c[2414854]=aI;gGz(aI|0,0,3970116);c[3530266]=aI;c[2386358]=aI+327680;c[3527436]=aI+458752;c[3527440]=aI+589824;c[3530752]=aI+655360;c[3530516]=aI+786432;c[3530384]=aI+1835008;c[3530308]=aI+2883584;c[3531056]=aI+3932160;c[2407020]=aI+3934208;c[3529894]=aI+3938304;aL=aI+3942400|0;c[2414556]=aL;c[3530268]=aL;c[2386282]=aI+3950592;c[2387082]=aI+3952640;c[2387076]=aI+3956736;c[3529872]=aI+3960832;c[3529870]=aI+3960864;c[2386744]=aI+3960896;c[2386382]=aI+3961920;c[2386556]=aI+3963968;c[2387100]=aI+3966016;c[3527438]=aI+3968064;c[3528212]=aI+3970112;c[3528482]=aI+3970113;c[2432942]=aI+3970114;c[3528652]=aI+3970115;aL=aI+3970116|0;c[2411456]=aL;c[2413996]=aL;aL=c[642608+(c[2436]<<2)>>2]|0;aM=(dW(c[aL>>2]|0,142648,6)|0)==0;aN=aI+32768|0;do{if((c[3542200]|0)==0){aO=1}else{aI=aG+108|0;c[aI>>2]=0;aP=aG+100|0;c[aP>>2]=0;aQ=c[aL+76>>2]|0;gA[aQ&16383](aG,0)|0;if((c[aI>>2]|0)==0){aO=0;break}aI=c[aP>>2]|0;c[aH>>2]=9534384;aP=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aP&16383](aH,0,0)|0;if((aI|0)<1){aO=1;break}aO=(gzL(aN,0,0)|0)!=0}}while(0);if(aM){if(aO){aR=1;i=e;return aR|0}aN=(c[3530266]|0)+65536|0;if((c[3542200]|0)==0){aR=1;i=e;return aR|0}aL=aE+108|0;c[aL>>2]=0;aI=aE+100|0;c[aI>>2]=0;aP=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aP&16383](aE,1)|0;do{if((c[aL>>2]|0)!=0){aP=c[aI>>2]|0;c[aF>>2]=9534384;aQ=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aQ&16383](aF,1,0)|0;if((aP|0)<1){aR=1;i=e;return aR|0}if((gzL(aN,0,1)|0)==0){break}else{aR=1}i=e;return aR|0}}while(0);aN=(c[3530266]|0)+131072|0;if((c[3542200]|0)==0){aR=1;i=e;return aR|0}aI=aC+108|0;c[aI>>2]=0;aL=aC+100|0;c[aL>>2]=0;aM=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aM&16383](aC,2)|0;do{if((c[aI>>2]|0)!=0){aM=c[aL>>2]|0;c[aD>>2]=9534384;aP=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aP&16383](aD,2,0)|0;if((aM|0)<1){aR=1;i=e;return aR|0}if((gzL(aN,0,2)|0)==0){break}else{aR=1}i=e;return aR|0}}while(0);aN=(c[3530266]|0)+196608|0;if((c[3542200]|0)==0){aR=1;i=e;return aR|0}aL=aA+108|0;c[aL>>2]=0;aI=aA+100|0;c[aI>>2]=0;aM=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aM&16383](aA,3)|0;do{if((c[aL>>2]|0)!=0){aM=c[aI>>2]|0;c[aB>>2]=9534384;aP=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aP&16383](aB,3,0)|0;if((aM|0)<1){aR=1;i=e;return aR|0}if((gzL(aN,0,3)|0)==0){break}else{aR=1}i=e;return aR|0}}while(0);aN=(c[3530266]|0)+262144|0;if((c[3542200]|0)==0){aR=1;i=e;return aR|0}aI=ay+108|0;c[aI>>2]=0;aL=ay+100|0;c[aL>>2]=0;aM=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aM&16383](ay,4)|0;do{if((c[aI>>2]|0)!=0){aM=c[aL>>2]|0;c[az>>2]=9534384;aP=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aP&16383](az,4,0)|0;if((aM|0)<1){aR=1;i=e;return aR|0}if((gzL(aN,0,4)|0)==0){break}else{aR=1}i=e;return aR|0}}while(0);aN=(c[3527436]|0)+32768|0;if((c[3542200]|0)==0){aR=1;i=e;return aR|0}aL=aw+108|0;c[aL>>2]=0;aI=aw+100|0;c[aI>>2]=0;aM=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aM&16383](aw,5)|0;do{if((c[aL>>2]|0)!=0){aM=c[aI>>2]|0;c[ax>>2]=9534384;aP=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aP&16383](ax,5,0)|0;if((aM|0)<1){aR=1;i=e;return aR|0}if((gzL(aN,0,5)|0)==0){break}else{aR=1}i=e;return aR|0}}while(0);aN=c[3530752]|0;if((c[3542200]|0)==0){aR=1;i=e;return aR|0}aI=au+108|0;c[aI>>2]=0;aL=au+100|0;c[aL>>2]=0;aM=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aM&16383](au,6)|0;do{if((c[aI>>2]|0)!=0){aM=c[aL>>2]|0;c[av>>2]=9534384;aP=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aP&16383](av,6,0)|0;if((aM|0)<1){aR=1;i=e;return aR|0}if((gzL(aN,0,6)|0)==0){break}else{aR=1}i=e;return aR|0}}while(0);aN=c[3530516]|0;if((c[3542200]|0)==0){aR=1;i=e;return aR|0}aL=as+108|0;c[aL>>2]=0;aI=as+100|0;c[aI>>2]=0;aM=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aM&16383](as,7)|0;do{if((c[aL>>2]|0)!=0){aM=c[aI>>2]|0;c[at>>2]=9534384;aP=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aP&16383](at,7,0)|0;if((aM|0)<1){aR=1;i=e;return aR|0}if((gzL(aN,0,7)|0)==0){break}else{aR=1}i=e;return aR|0}}while(0);aN=(c[3530516]|0)+65536|0;if((c[3542200]|0)==0){aR=1;i=e;return aR|0}aI=aq+108|0;c[aI>>2]=0;aL=aq+100|0;c[aL>>2]=0;aM=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aM&16383](aq,8)|0;do{if((c[aI>>2]|0)!=0){aM=c[aL>>2]|0;c[ar>>2]=9534384;aP=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aP&16383](ar,8,0)|0;if((aM|0)<1){aR=1;i=e;return aR|0}if((gzL(aN,0,8)|0)==0){break}else{aR=1}i=e;return aR|0}}while(0);aN=(c[3530516]|0)+131072|0;if((c[3542200]|0)==0){aR=1;i=e;return aR|0}aL=ao+108|0;c[aL>>2]=0;aI=ao+100|0;c[aI>>2]=0;aM=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aM&16383](ao,9)|0;do{if((c[aL>>2]|0)!=0){aM=c[aI>>2]|0;c[ap>>2]=9534384;aP=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aP&16383](ap,9,0)|0;if((aM|0)<1){aR=1;i=e;return aR|0}if((gzL(aN,0,9)|0)==0){break}else{aR=1}i=e;return aR|0}}while(0);aN=(c[3530516]|0)+196608|0;if((c[3542200]|0)==0){aR=1;i=e;return aR|0}aI=am+108|0;c[aI>>2]=0;aL=am+100|0;c[aL>>2]=0;aM=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aM&16383](am,10)|0;do{if((c[aI>>2]|0)!=0){aM=c[aL>>2]|0;c[an>>2]=9534384;aP=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aP&16383](an,10,0)|0;if((aM|0)<1){aR=1;i=e;return aR|0}if((gzL(aN,0,10)|0)==0){break}else{aR=1}i=e;return aR|0}}while(0);aN=(c[3530516]|0)+262144|0;if((c[3542200]|0)==0){aR=1;i=e;return aR|0}aL=ak+108|0;c[aL>>2]=0;aI=ak+100|0;c[aI>>2]=0;aM=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aM&16383](ak,11)|0;do{if((c[aL>>2]|0)!=0){aM=c[aI>>2]|0;c[al>>2]=9534384;aP=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aP&16383](al,11,0)|0;if((aM|0)<1){aR=1;i=e;return aR|0}if((gzL(aN,0,11)|0)==0){break}else{aR=1}i=e;return aR|0}}while(0);aN=(c[3530516]|0)+327680|0;if((c[3542200]|0)==0){aR=1;i=e;return aR|0}aI=ai+108|0;c[aI>>2]=0;aL=ai+100|0;c[aL>>2]=0;aM=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aM&16383](ai,12)|0;do{if((c[aI>>2]|0)!=0){aM=c[aL>>2]|0;c[aj>>2]=9534384;aP=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aP&16383](aj,12,0)|0;if((aM|0)<1){aR=1;i=e;return aR|0}if((gzL(aN,0,12)|0)==0){break}else{aR=1}i=e;return aR|0}}while(0);aN=(c[3530516]|0)+393216|0;if((c[3542200]|0)==0){aR=1;i=e;return aR|0}aL=af+108|0;c[aL>>2]=0;aI=af+100|0;c[aI>>2]=0;aM=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aM&16383](af,13)|0;do{if((c[aL>>2]|0)!=0){aM=c[aI>>2]|0;c[ah>>2]=9534384;aP=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aP&16383](ah,13,0)|0;if((aM|0)<1){aR=1;i=e;return aR|0}if((gzL(aN,0,13)|0)==0){break}else{aR=1}i=e;return aR|0}}while(0);aN=(c[3530516]|0)+458752|0;if((c[3542200]|0)==0){aR=1;i=e;return aR|0}aI=ad+108|0;c[aI>>2]=0;aL=ad+100|0;c[aL>>2]=0;aM=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aM&16383](ad,14)|0;do{if((c[aI>>2]|0)!=0){aM=c[aL>>2]|0;c[ae>>2]=9534384;aP=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aP&16383](ae,14,0)|0;if((aM|0)<1){aR=1;i=e;return aR|0}if((gzL(aN,0,14)|0)==0){break}else{aR=1}i=e;return aR|0}}while(0);aN=c[3530384]|0;if((c[3542200]|0)==0){aR=1;i=e;return aR|0}aL=ab+108|0;c[aL>>2]=0;aI=ab+100|0;c[aI>>2]=0;aM=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aM&16383](ab,15)|0;do{if((c[aL>>2]|0)!=0){aM=c[aI>>2]|0;c[ac>>2]=9534384;aP=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aP&16383](ac,15,0)|0;if((aM|0)<1){aR=1;i=e;return aR|0}if((gzL(aN,0,15)|0)==0){break}else{aR=1}i=e;return aR|0}}while(0);aN=(c[3530384]|0)+65536|0;if((c[3542200]|0)==0){aR=1;i=e;return aR|0}aI=$+108|0;c[aI>>2]=0;aL=$+100|0;c[aL>>2]=0;aM=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aM&16383]($,16)|0;do{if((c[aI>>2]|0)!=0){aM=c[aL>>2]|0;c[aa>>2]=9534384;aP=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aP&16383](aa,16,0)|0;if((aM|0)<1){aR=1;i=e;return aR|0}if((gzL(aN,0,16)|0)==0){break}else{aR=1}i=e;return aR|0}}while(0);aN=(c[3530384]|0)+131072|0;if((c[3542200]|0)==0){aR=1;i=e;return aR|0}aL=Z+108|0;c[aL>>2]=0;aI=Z+100|0;c[aI>>2]=0;aM=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aM&16383](Z,17)|0;do{if((c[aL>>2]|0)!=0){aM=c[aI>>2]|0;c[_>>2]=9534384;aP=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aP&16383](_,17,0)|0;if((aM|0)<1){aR=1;i=e;return aR|0}if((gzL(aN,0,17)|0)==0){break}else{aR=1}i=e;return aR|0}}while(0);aN=(c[3530384]|0)+196608|0;if((c[3542200]|0)==0){aR=1;i=e;return aR|0}aI=X+108|0;c[aI>>2]=0;aL=X+100|0;c[aL>>2]=0;aM=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aM&16383](X,18)|0;do{if((c[aI>>2]|0)!=0){aM=c[aL>>2]|0;c[Y>>2]=9534384;aP=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aP&16383](Y,18,0)|0;if((aM|0)<1){aR=1;i=e;return aR|0}if((gzL(aN,0,18)|0)==0){break}else{aR=1}i=e;return aR|0}}while(0);aN=c[3531056]|0;if((c[3542200]|0)==0){aR=1;i=e;return aR|0}aL=V+108|0;c[aL>>2]=0;aI=V+100|0;c[aI>>2]=0;aM=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aM&16383](V,19)|0;do{if((c[aL>>2]|0)!=0){aM=c[aI>>2]|0;c[W>>2]=9534384;aP=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aP&16383](W,19,0)|0;if((aM|0)<1){aR=1;i=e;return aR|0}if((gzL(aN,0,19)|0)==0){break}else{aR=1}i=e;return aR|0}}while(0);aN=(c[3531056]|0)+1024|0;if((c[3542200]|0)==0){aR=1;i=e;return aR|0}aI=T+108|0;c[aI>>2]=0;aL=T+100|0;c[aL>>2]=0;aM=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aM&16383](T,20)|0;do{if((c[aI>>2]|0)!=0){aM=c[aL>>2]|0;c[U>>2]=9534384;aP=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aP&16383](U,20,0)|0;if((aM|0)<1){aR=1;i=e;return aR|0}if((gzL(aN,0,20)|0)==0){break}else{aR=1}i=e;return aR|0}}while(0);aN=c[3527436]|0;aL=c[3527440]|0;aI=32768;do{aM=a[aN+aI|0]|0;a[aL+aI|0]=aM<<1&64|aM&-97|(aM&255)>>>1&32;aI=aI+1|0;}while((aI|0)<65536)}else{if(aO){aR=1;i=e;return aR|0}aI=(c[3530266]|0)+65536|0;if((c[3542200]|0)==0){aR=1;i=e;return aR|0}aL=R+108|0;c[aL>>2]=0;aN=R+100|0;c[aN>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](R,1)|0;do{if((c[aL>>2]|0)!=0){aM=c[aN>>2]|0;c[S>>2]=9534384;aP=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aP&16383](S,1,0)|0;if((aM|0)<1){aR=1;i=e;return aR|0}if((gzL(aI,0,1)|0)==0){break}else{aR=1}i=e;return aR|0}}while(0);aI=(c[3530266]|0)+131072|0;if((c[3542200]|0)==0){aR=1;i=e;return aR|0}aN=P+108|0;c[aN>>2]=0;aL=P+100|0;c[aL>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](P,2)|0;do{if((c[aN>>2]|0)!=0){aM=c[aL>>2]|0;c[Q>>2]=9534384;aP=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aP&16383](Q,2,0)|0;if((aM|0)<1){aR=1;i=e;return aR|0}if((gzL(aI,0,2)|0)==0){break}else{aR=1}i=e;return aR|0}}while(0);aI=(c[3530266]|0)+196608|0;if((c[3542200]|0)==0){aR=1;i=e;return aR|0}aL=N+108|0;c[aL>>2]=0;aN=N+100|0;c[aN>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](N,3)|0;do{if((c[aL>>2]|0)!=0){aM=c[aN>>2]|0;c[O>>2]=9534384;aP=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aP&16383](O,3,0)|0;if((aM|0)<1){aR=1;i=e;return aR|0}if((gzL(aI,0,3)|0)==0){break}else{aR=1}i=e;return aR|0}}while(0);aI=(c[3527436]|0)+32768|0;if((c[3542200]|0)==0){aR=1;i=e;return aR|0}aN=L+108|0;c[aN>>2]=0;aL=L+100|0;c[aL>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](L,4)|0;do{if((c[aN>>2]|0)!=0){aM=c[aL>>2]|0;c[M>>2]=9534384;aP=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aP&16383](M,4,0)|0;if((aM|0)<1){aR=1;i=e;return aR|0}if((gzL(aI,0,4)|0)==0){break}else{aR=1}i=e;return aR|0}}while(0);aI=c[3530752]|0;if((c[3542200]|0)==0){aR=1;i=e;return aR|0}aL=J+108|0;c[aL>>2]=0;aN=J+100|0;c[aN>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](J,5)|0;do{if((c[aL>>2]|0)!=0){aM=c[aN>>2]|0;c[K>>2]=9534384;aP=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aP&16383](K,5,0)|0;if((aM|0)<1){aR=1;i=e;return aR|0}if((gzL(aI,0,5)|0)==0){break}else{aR=1}i=e;return aR|0}}while(0);aI=c[3530516]|0;if((c[3542200]|0)==0){aR=1;i=e;return aR|0}aN=H+108|0;c[aN>>2]=0;aL=H+100|0;c[aL>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](H,6)|0;do{if((c[aN>>2]|0)!=0){aM=c[aL>>2]|0;c[I>>2]=9534384;aP=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aP&16383](I,6,0)|0;if((aM|0)<1){aR=1;i=e;return aR|0}if((gzL(aI,0,6)|0)==0){break}else{aR=1}i=e;return aR|0}}while(0);aI=(c[3530516]|0)+65536|0;if((c[3542200]|0)==0){aR=1;i=e;return aR|0}aL=F+108|0;c[aL>>2]=0;aN=F+100|0;c[aN>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](F,7)|0;do{if((c[aL>>2]|0)!=0){aM=c[aN>>2]|0;c[G>>2]=9534384;aP=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aP&16383](G,7,0)|0;if((aM|0)<1){aR=1;i=e;return aR|0}if((gzL(aI,0,7)|0)==0){break}else{aR=1}i=e;return aR|0}}while(0);aI=(c[3530516]|0)+131072|0;if((c[3542200]|0)==0){aR=1;i=e;return aR|0}aN=D+108|0;c[aN>>2]=0;aL=D+100|0;c[aL>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](D,8)|0;do{if((c[aN>>2]|0)!=0){aM=c[aL>>2]|0;c[E>>2]=9534384;aP=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aP&16383](E,8,0)|0;if((aM|0)<1){aR=1;i=e;return aR|0}if((gzL(aI,0,8)|0)==0){break}else{aR=1}i=e;return aR|0}}while(0);aI=(c[3530516]|0)+196608|0;if((c[3542200]|0)==0){aR=1;i=e;return aR|0}aL=B+108|0;c[aL>>2]=0;aN=B+100|0;c[aN>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](B,9)|0;do{if((c[aL>>2]|0)!=0){aM=c[aN>>2]|0;c[C>>2]=9534384;aP=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aP&16383](C,9,0)|0;if((aM|0)<1){aR=1;i=e;return aR|0}if((gzL(aI,0,9)|0)==0){break}else{aR=1}i=e;return aR|0}}while(0);aI=(c[3530516]|0)+262144|0;if((c[3542200]|0)==0){aR=1;i=e;return aR|0}aN=z+108|0;c[aN>>2]=0;aL=z+100|0;c[aL>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,10)|0;do{if((c[aN>>2]|0)!=0){aM=c[aL>>2]|0;c[A>>2]=9534384;aP=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aP&16383](A,10,0)|0;if((aM|0)<1){aR=1;i=e;return aR|0}if((gzL(aI,0,10)|0)==0){break}else{aR=1}i=e;return aR|0}}while(0);aI=(c[3530516]|0)+327680|0;if((c[3542200]|0)==0){aR=1;i=e;return aR|0}aL=x+108|0;c[aL>>2]=0;aN=x+100|0;c[aN>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,11)|0;do{if((c[aL>>2]|0)!=0){aM=c[aN>>2]|0;c[y>>2]=9534384;aP=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aP&16383](y,11,0)|0;if((aM|0)<1){aR=1;i=e;return aR|0}if((gzL(aI,0,11)|0)==0){break}else{aR=1}i=e;return aR|0}}while(0);aI=(c[3530516]|0)+393216|0;if((c[3542200]|0)==0){aR=1;i=e;return aR|0}aN=v+108|0;c[aN>>2]=0;aL=v+100|0;c[aL>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,12)|0;do{if((c[aN>>2]|0)!=0){aM=c[aL>>2]|0;c[w>>2]=9534384;aP=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aP&16383](w,12,0)|0;if((aM|0)<1){aR=1;i=e;return aR|0}if((gzL(aI,0,12)|0)==0){break}else{aR=1}i=e;return aR|0}}while(0);aI=(c[3530516]|0)+458752|0;if((c[3542200]|0)==0){aR=1;i=e;return aR|0}aL=t+108|0;c[aL>>2]=0;aN=t+100|0;c[aN>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,13)|0;do{if((c[aL>>2]|0)!=0){aM=c[aN>>2]|0;c[u>>2]=9534384;aP=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aP&16383](u,13,0)|0;if((aM|0)<1){aR=1;i=e;return aR|0}if((gzL(aI,0,13)|0)==0){break}else{aR=1}i=e;return aR|0}}while(0);aI=c[3530384]|0;if((c[3542200]|0)==0){aR=1;i=e;return aR|0}aN=r+108|0;c[aN>>2]=0;aL=r+100|0;c[aL>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,14)|0;do{if((c[aN>>2]|0)!=0){aM=c[aL>>2]|0;c[s>>2]=9534384;aP=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aP&16383](s,14,0)|0;if((aM|0)<1){aR=1;i=e;return aR|0}if((gzL(aI,0,14)|0)==0){break}else{aR=1}i=e;return aR|0}}while(0);aI=(c[3530384]|0)+65536|0;if((c[3542200]|0)==0){aR=1;i=e;return aR|0}aL=p+108|0;c[aL>>2]=0;aN=p+100|0;c[aN>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,15)|0;do{if((c[aL>>2]|0)!=0){aM=c[aN>>2]|0;c[q>>2]=9534384;aP=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aP&16383](q,15,0)|0;if((aM|0)<1){aR=1;i=e;return aR|0}if((gzL(aI,0,15)|0)==0){break}else{aR=1}i=e;return aR|0}}while(0);aI=(c[3530384]|0)+131072|0;if((c[3542200]|0)==0){aR=1;i=e;return aR|0}aN=n+108|0;c[aN>>2]=0;aL=n+100|0;c[aL>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,16)|0;do{if((c[aN>>2]|0)!=0){aM=c[aL>>2]|0;c[o>>2]=9534384;aP=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aP&16383](o,16,0)|0;if((aM|0)<1){aR=1;i=e;return aR|0}if((gzL(aI,0,16)|0)==0){break}else{aR=1}i=e;return aR|0}}while(0);aI=(c[3530384]|0)+196608|0;if((c[3542200]|0)==0){aR=1;i=e;return aR|0}aL=l+108|0;c[aL>>2]=0;aN=l+100|0;c[aN>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,17)|0;do{if((c[aL>>2]|0)!=0){aM=c[aN>>2]|0;c[m>>2]=9534384;aP=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aP&16383](m,17,0)|0;if((aM|0)<1){aR=1;i=e;return aR|0}if((gzL(aI,0,17)|0)==0){break}else{aR=1}i=e;return aR|0}}while(0);aI=c[3531056]|0;if((c[3542200]|0)==0){aR=1;i=e;return aR|0}aN=j+108|0;c[aN>>2]=0;aL=j+100|0;c[aL>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,18)|0;do{if((c[aN>>2]|0)!=0){aM=c[aL>>2]|0;c[k>>2]=9534384;aP=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aP&16383](k,18,0)|0;if((aM|0)<1){aR=1;i=e;return aR|0}if((gzL(aI,0,18)|0)==0){break}else{aR=1}i=e;return aR|0}}while(0);aI=(c[3531056]|0)+1024|0;if((c[3542200]|0)==0){aR=1;i=e;return aR|0}aL=f+108|0;c[aL>>2]=0;aN=f+100|0;c[aN>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,19)|0;do{if((c[aL>>2]|0)!=0){aM=c[aN>>2]|0;c[g>>2]=9534384;aP=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aP&16383](g,19,0)|0;if((aM|0)<1){aR=1;i=e;return aR|0}if((gzL(aI,0,19)|0)==0){break}else{aR=1}i=e;return aR|0}}while(0);aI=(c[3527440]|0)+32768|0;aN=(c[3527436]|0)+32768|0;gGC(aI|0,aN|0,32768)|0}aN=c[3531056]|0;gGz(aN+32|0,0,224);aI=c[2407020]|0;aL=0;while(1){aM=d[aN+aL|0]|0;aP=d[aN+(aL+1024)|0]|0;c[aI+(aL<<2)>>2]=(-(aM>>>1&1)&31)+(-(aM&1)&14)+(-(aM>>>2&1)&67)+(-(aM>>>3&1)&143)<<16|(-(aM>>>5&1)&31)+(-(aM>>>7)&143)+(-(aM>>>4&1)&14)+(-(aM>>>6&1)&67)<<8|(-(aP>>>1&1)&31)+(-(aP&1)&14)+(-(aP>>>2&1)&67)+(-(aP>>>3&1)&143);aP=aL+1|0;if((aP|0)<1024){aL=aP}else{aS=0;break}}while(1){if((aS|0)>=1024){break}aT=9638528+(aS<<2)|0;if((c[aT>>2]|0)==0){aK=26816;break}else{aS=aS+1|0}}L34343:do{if((aK|0)==26816){aL=gGq(524288)|0;c[aT>>2]=aL;if((aL|0)==0){break}gGz(aL|0,0,524288);aI=c[3530752]|0;gGC(aL|0,aI|0,32768)|0;aN=0;do{aP=aN<<6;gGz(aI+aP|0,0,64);aM=aP+196608|0;aQ=0;do{aU=aM+(c[609008+(aQ<<2)>>2]|0)|0;aV=(aQ<<3)+aP|0;aW=0;do{aX=aU+(c[614800+(aW<<2)>>2]|0)|0;if((d[aL+((aX|0)/8|0)|0]&128>>>((aX&7)>>>0)|0)!=0){aX=aI+(aV+aW)|0;a[aX]=a[aX]|4}aW=aW+1|0;}while((aW|0)<8);aQ=aQ+1|0;}while((aQ|0)<8);aQ=aP+131072|0;aM=0;do{aW=aQ+(c[609008+(aM<<2)>>2]|0)|0;aV=(aM<<3)+aP|0;aU=0;do{aX=aW+(c[614800+(aU<<2)>>2]|0)|0;if((d[aL+((aX|0)/8|0)|0]&128>>>((aX&7)>>>0)|0)!=0){aX=aI+(aV+aU)|0;a[aX]=a[aX]|2}aU=aU+1|0;}while((aU|0)<8);aM=aM+1|0;}while((aM|0)<8);aM=aP+65536|0;aQ=0;do{aU=aM+(c[609008+(aQ<<2)>>2]|0)|0;aV=(aQ<<3)+aP|0;aW=0;do{aX=aU+(c[614800+(aW<<2)>>2]|0)|0;if((d[aL+((aX|0)/8|0)|0]&128>>>((aX&7)>>>0)|0)!=0){aX=aI+(aV+aW)|0;a[aX]=a[aX]|1}aW=aW+1|0;}while((aW|0)<8);aQ=aQ+1|0;}while((aQ|0)<8);aN=aN+1|0;}while((aN|0)<1024);aN=c[3530516]|0;gGC(aL|0,aN|0,524288)|0;aI=0;do{aQ=aI<<8;gGz(aN+aQ|0,0,256);aP=0;do{aM=1<<3-aP;aW=(c[704200+(aP<<2)>>2]|0)+aQ|0;aV=0;do{aU=aW+(c[609008+(aV<<2)>>2]|0)|0;aX=(aV<<4)+aQ|0;aY=0;do{aZ=aU+(c[612640+(aY<<2)>>2]|0)|0;if((d[aL+((aZ|0)/8|0)|0]&128>>>((aZ&7)>>>0)|0)!=0){aZ=aN+(aX+aY)|0;a[aZ]=(d[aZ]|aM)&255}aY=aY+1|0;}while((aY|0)<16);aV=aV+1|0;}while((aV|0)<16);aP=aP+1|0;}while((aP|0)<4);aI=aI+1|0;}while((aI|0)<4096);aI=c[3530384]|0;gGC(aL|0,aI|0,262144)|0;aN=0;while(1){aP=aN<<8;gGz(aI+aP|0,0,256);aQ=0;do{aV=1<<3-aQ;aM=(c[611136+(aQ<<2)>>2]|0)+aP|0;aW=0;do{aY=aM+(c[609008+(aW<<2)>>2]|0)|0;aX=(aW<<4)+aP|0;aU=0;do{aZ=aY+(c[610384+(aU<<2)>>2]|0)|0;if((d[aL+((aZ|0)/8|0)|0]&128>>>((aZ&7)>>>0)|0)!=0){aZ=aI+(aX+aU)|0;a[aZ]=(d[aZ]|aV)&255}aU=aU+1|0;}while((aU|0)<16);aW=aW+1|0;}while((aW|0)<16);aQ=aQ+1|0;}while((aQ|0)<4);aQ=aN+1|0;if((aQ|0)<2048){aN=aQ}else{a_=0;break}}while(1){if((a_|0)>=1024){break L34343}a$=9638528+(a_<<2)|0;if((c[a$>>2]|0)==(aL|0)){break}else{a_=a_+1|0}}gGr(aL);c[a$>>2]=0}}while(0);c[3528552]=-1;c[2113196]=1;aN=gGq(3160)|0;aI=aN;c[2433426]=aI;if((aN|0)==0){c[3528552]=0}else{gGz(aN|0,0,3160);c[aN+3132>>2]=2102;c[aN+3136>>2]=2420;c[aN+3140>>2]=1856;c[aN+3144>>2]=1450;c[2430450]=0;aQ=0;do{c[aI+60+(aQ<<2)>>2]=0;aQ=aQ+1|0;}while((aQ|0)<768);c[2113194]=0;aQ=c[2427044]|0;c[9681616+(aQ<<3)>>2]=726904;c[9681620+(aQ<<3)>>2]=0;c[2427044]=aQ+1;c[3528552]=0;gGC(9642704,aN|0,60)|0}b[4821352]=c[2410676]&65535;fC1();aQ=(a[9642745]&1)==0;c[2430032]=aQ?1595912:1595656;c[2429672]=aQ?1114752:1114496;c[2429670]=aQ?1114240:1113984;c[2444186]=aQ?4654424:4654168;aQ=c[3528552]|0;aI=9721800+(aQ<<2)|0;c[2113194]=c[aI>>2];aP=c[3530268]|0;aW=c[2433426]|0;aV=0;aM=0;while(1){aU=aP+(aM<<8)|0;c[aW+(aQ*3160|0)+60+(aM<<2)>>2]=aU;c[aW+(aQ*3160|0)+60+(aM+256<<2)>>2]=aU;c[aW+(aQ*3160|0)+60+(aM+512<<2)>>2]=aU;aU=aV+1&65535;if((aU&65535)>23){break}else{aV=aU;aM=aU&65535}}aM=c[2386282]|0;c[aW+(aQ*3160|0)+156>>2]=aM;c[aW+(aQ*3160|0)+1180>>2]=aM;c[aW+(aQ*3160|0)+2204>>2]=aM;aV=aM+256|0;c[aW+(aQ*3160|0)+160>>2]=aV;c[aW+(aQ*3160|0)+1184>>2]=aV;c[aW+(aQ*3160|0)+2208>>2]=aV;aV=aM+512|0;c[aW+(aQ*3160|0)+164>>2]=aV;c[aW+(aQ*3160|0)+1188>>2]=aV;c[aW+(aQ*3160|0)+2212>>2]=aV;aV=aM+768|0;c[aW+(aQ*3160|0)+168>>2]=aV;c[aW+(aQ*3160|0)+1192>>2]=aV;c[aW+(aQ*3160|0)+2216>>2]=aV;aV=aM+1024|0;c[aW+(aQ*3160|0)+172>>2]=aV;c[aW+(aQ*3160|0)+1196>>2]=aV;c[aW+(aQ*3160|0)+2220>>2]=aV;aV=aM+1280|0;c[aW+(aQ*3160|0)+176>>2]=aV;c[aW+(aQ*3160|0)+1200>>2]=aV;c[aW+(aQ*3160|0)+2224>>2]=aV;aV=aM+1536|0;c[aW+(aQ*3160|0)+180>>2]=aV;c[aW+(aQ*3160|0)+1204>>2]=aV;c[aW+(aQ*3160|0)+2228>>2]=aV;aV=aM+1792|0;c[aW+(aQ*3160|0)+184>>2]=aV;c[aW+(aQ*3160|0)+1208>>2]=aV;c[aW+(aQ*3160|0)+2232>>2]=aV;aV=c[2387082]|0;aM=32;aP=32;while(1){aN=aV+((aP<<8)-8192)|0;c[aW+(aQ*3160|0)+60+(aP<<2)>>2]=aN;c[aW+(aQ*3160|0)+60+(aP+256<<2)>>2]=aN;c[aW+(aQ*3160|0)+60+(aP+512<<2)>>2]=aN;aN=aM+1&65535;if((aN&65535)>43){break}else{aM=aN;aP=aN&65535}}aP=c[2386744]|0;c[aW+(aQ*3160|0)+236>>2]=aP;c[aW+(aQ*3160|0)+1260>>2]=aP;c[aW+(aQ*3160|0)+2284>>2]=aP;aM=aP+256|0;c[aW+(aQ*3160|0)+240>>2]=aM;c[aW+(aQ*3160|0)+1264>>2]=aM;c[aW+(aQ*3160|0)+2288>>2]=aM;aM=aP+512|0;c[aW+(aQ*3160|0)+244>>2]=aM;c[aW+(aQ*3160|0)+1268>>2]=aM;c[aW+(aQ*3160|0)+2292>>2]=aM;aM=aP+768|0;c[aW+(aQ*3160|0)+248>>2]=aM;c[aW+(aQ*3160|0)+1272>>2]=aM;c[aW+(aQ*3160|0)+2296>>2]=aM;aM=c[2386382]|0;c[aW+(aQ*3160|0)+252>>2]=aM;c[aW+(aQ*3160|0)+1276>>2]=aM;c[aW+(aQ*3160|0)+2300>>2]=aM;aP=aM+256|0;c[aW+(aQ*3160|0)+256>>2]=aP;c[aW+(aQ*3160|0)+1280>>2]=aP;c[aW+(aQ*3160|0)+2304>>2]=aP;aP=aM+512|0;c[aW+(aQ*3160|0)+260>>2]=aP;c[aW+(aQ*3160|0)+1284>>2]=aP;c[aW+(aQ*3160|0)+2308>>2]=aP;aP=aM+768|0;c[aW+(aQ*3160|0)+264>>2]=aP;c[aW+(aQ*3160|0)+1288>>2]=aP;c[aW+(aQ*3160|0)+2312>>2]=aP;aP=aM+1024|0;c[aW+(aQ*3160|0)+268>>2]=aP;c[aW+(aQ*3160|0)+1292>>2]=aP;c[aW+(aQ*3160|0)+2316>>2]=aP;aP=aM+1280|0;c[aW+(aQ*3160|0)+272>>2]=aP;c[aW+(aQ*3160|0)+1296>>2]=aP;c[aW+(aQ*3160|0)+2320>>2]=aP;aP=aM+1536|0;c[aW+(aQ*3160|0)+276>>2]=aP;c[aW+(aQ*3160|0)+1300>>2]=aP;c[aW+(aQ*3160|0)+2324>>2]=aP;aP=aM+1792|0;c[aW+(aQ*3160|0)+280>>2]=aP;c[aW+(aQ*3160|0)+1304>>2]=aP;c[aW+(aQ*3160|0)+2328>>2]=aP;aP=c[3530266]|0;aM=64;aV=64;while(1){aN=aP+((aV<<8)+49152)|0;c[aW+(aQ*3160|0)+60+(aV<<2)>>2]=aN;c[aW+(aQ*3160|0)+60+(aV+512<<2)>>2]=aN;aN=aM+1&65535;if((aN&65535)>127){a0=128;a1=128;break}else{aM=aN;aV=aN&65535}}while(1){aV=aP+(a1<<8)|0;c[aW+(aQ*3160|0)+60+(a1<<2)>>2]=aV;c[aW+(aQ*3160|0)+60+(a1+512<<2)>>2]=aV;aV=a0+1&65535;if((aV&65535)>255){break}else{a0=aV;a1=aV&65535}}c[aW+(aQ*3160|0)+3136>>2]=1490;c[aW+(aQ*3160|0)+3132>>2]=656;aP=aW+(aQ*3160|0)|0;if((aP|0)!=0){aV=aP;gGC(aV|0,9642704,60)|0}c[aI>>2]=c[2113194];c[3528552]=-1;fvI();c[3528556]=0;aV=c[2433594]|0;c[2443776]=aV;L34431:do{if((aV|0)!=0){aP=aV|0;gGC(9660952,aP|0,52)|0;switch(a[9660952]|0){case 0:{c[2309668]=638960;break L34431;break};case 1:{c[2309668]=634096;break L34431;break};case 3:{c[2309668]=639984;break L34431;break};case 4:{c[2309668]=7356016;break L34431;break};case 5:{c[2309668]=7354992;break L34431;break};case 2:{c[2309668]=638960;break L34431;break};default:{break L34431}}}}while(0);aI=c[2432850]|0;c[2113164]=aI;aQ=c[3527438]|0;c[aV+68>>2]=aQ;c[aV+1092>>2]=aQ;c[aV+2116>>2]=aQ;aW=aQ+256|0;c[aV+72>>2]=aW;c[aV+1096>>2]=aW;c[aV+2120>>2]=aW;aW=aQ+512|0;c[aV+76>>2]=aW;c[aV+1100>>2]=aW;c[aV+2124>>2]=aW;aW=aQ+768|0;c[aV+80>>2]=aW;c[aV+1104>>2]=aW;c[aV+2128>>2]=aW;aW=aQ+1024|0;c[aV+84>>2]=aW;c[aV+1108>>2]=aW;c[aV+2132>>2]=aW;aW=aQ+1280|0;c[aV+88>>2]=aW;c[aV+1112>>2]=aW;c[aV+2136>>2]=aW;aW=c[3527436]|0;aQ=128;aP=128;while(1){c[aV+68+(aP<<2)>>2]=aW+(aP<<8);aM=aQ+1&65535;if((aM&65535)>255){break}else{aQ=aM;aP=aM&65535}}aP=c[3527440]|0;aQ=128;aW=128;while(1){c[aV+68+(aW+512<<2)>>2]=aP+(aW<<8);aM=aQ+1&65535;if((aM&65535)>255){break}else{aQ=aM;aW=aM&65535}}c[aV+3148>>2]=406;c[aV+3152>>2]=1392;aW=aV|0;gGC(aW|0,9660952,52)|0;c[2432850]=aI;c[2443776]=0;c[3528556]=-1;c[2424]=5800;UL(3e6,1494,2124,0);c[2438224]=15e5;c[2433522]=3258;c[2406672]=2016;c[3528468]=6844;c[2443842]=1364;h[745398]=.7;a[3203264]=1;Vr(1,15e5,0,72,26,1);c[2438228]=12e6;c[2433526]=92;c[2406676]=958;c[3528472]=8304;c[2443846]=169;h[745419]=.2;a[3203368]=1;h[745418]=.23;a[3203360]=1;h[745417]=.23;a[3203352]=1;h[745416]=.23;a[3203344]=1;aW=c[642608+(c[2436]<<2)>>2]|0;aQ=c[aW+128>>2]|0;if((c[aW+52>>2]&4|0)==0){c[2113068]=aQ;aP=c[aW+132>>2]|0;c[2113070]=aP;c[2443814]=aQ;c[2440436]=aP;a2=aQ;a3=aP}else{c[2113070]=aQ;aP=c[aW+132>>2]|0;c[2113068]=aP;c[2440436]=aQ;c[2443814]=aP;a2=aP;a3=aQ}aQ=ag(a2<<1,a3)|0;aP=gGq(aQ)|0;c[2112926]=aP;if((aP|0)!=0){gGz(aP|0,0,aQ|0)}a[9623400]=0;aQ=c[2414556]|0;gGz(aQ|0,0,(c[2411456]|0)-aQ|0);c[3528552]=0;aQ=c[2433426]|0;if((aQ|0)!=0){aP=aQ;gGC(9642704,aP|0,60)|0}b[4821352]=c[2410676]&65535;fC1();aP=(a[9642745]&1)==0;c[2430032]=aP?1595912:1595656;c[2429672]=aP?1114752:1114496;c[2429670]=aP?1114240:1113984;c[2444186]=aP?4654424:4654168;c[2113194]=c[9721800+(c[3528552]<<2)>>2];fC2();aP=c[3528552]|0;aQ=(c[2433426]|0)+(aP*3160|0)|0;if((aQ|0)!=0){aW=aQ;gGC(aW|0,9642704,60)|0}c[9721800+(aP<<2)>>2]=c[2113194];c[3528552]=-1;c[3528556]=0;aP=c[2433594]|0;c[2443776]=aP;L34460:do{if((aP|0)!=0){aW=aP|0;gGC(9660952,aW|0,52)|0;switch(a[9660952]|0){case 0:{c[2309668]=638960;break L34460;break};case 1:{c[2309668]=634096;break L34460;break};case 3:{c[2309668]=639984;break L34460;break};case 4:{c[2309668]=7356016;break L34460;break};case 5:{c[2309668]=7354992;break L34460;break};case 2:{c[2309668]=638960;break L34460;break};default:{break L34460}}}}while(0);c[2113164]=c[2432850];gu[c[aP+56>>2]&16383]();aI=c[2443776]|0;if((aI|0)!=0){aV=aI|0;gGC(aV|0,9660952,52)|0}c[9731400+(c[3528556]<<2)>>2]=c[2113164];c[2443776]=0;c[3528556]=-1;c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;lw(c[3540984]|0);c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){aV=0;do{lN(aV);mB(aV);aV=aV+1|0;}while((aV|0)<(c[2385508]|0))}c[2440606]=0;c[2444190]=0;aR=0;i=e;return aR|0}}while(0);c[2414854]=0;aR=1;i=e;return aR|0}function aFS(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c[2113196]=0;b=c[2433426]|0;if((b|0)!=0){gGr(b);c[2433426]=0}b=a[7452584]|0;if(b){d=0;e=b&1;while(1){b=14163936+(d<<2)|0;f=c[b>>2]|0;g=c[2113006]|0;if((g|0)==0){h=27036}else{i=g-1|0;c[2113006]=i;if((i|0)==0){h=27036}}if((h|0)==27036){h=0;c[2383474]=0}if((f|0)==0){j=e}else{gGr(f);j=a[7452584]&1}c[b>>2]=0;b=d+1|0;if((b|0)<(j|0)){d=b;e=j}else{break}}}a[7452584]=0;c[2438224]=0;c[2433522]=0;c[2406672]=0;c[3528468]=0;j=c[2406688]|0;if((j|0)!=0){gGr(j);c[2406688]=0}c[2432972]=0;c[2113070]=0;c[2113068]=0;j=c[2112926]|0;if((j|0)!=0){gGr(j);c[2112926]=0}fvR();j=c[3541518]|0;if((j|0)!=0){gGr(j|0);c[3541518]=0}if((c[2385508]|0)>0){c[2113008]=0;c[2076598]=0;c[2383582]=0}c[2438228]=0;c[2433526]=0;c[2406676]=0;c[3528472]=0;j=c[2406680]|0;if((j|0)!=0){gGr(j);c[2406680]=0}c[2385508]=0;c[2432978]=0;a[64240]=0;j=c[2414854]|0;e=0;while(1){if((e|0)>=1024){h=27055;break}k=9638528+(e<<2)|0;if((c[k>>2]|0)==(j|0)){break}else{e=e+1|0}}if((h|0)==27055){c[2414854]=0;return 0}gGr(j);c[k>>2]=0;c[2414854]=0;return 0}function aFT(){var e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0;if((a[9623400]|0)!=0){a[9623400]=0;e=c[2414556]|0;gGz(e|0,0,(c[2411456]|0)-e|0);c[3528552]=0;e=c[2433426]|0;if((e|0)!=0){f=e;gGC(9642704,f|0,60)|0}b[4821352]=c[2410676]&65535;fC1();f=(a[9642745]&1)==0;c[2430032]=f?1595912:1595656;c[2429672]=f?1114752:1114496;c[2429670]=f?1114240:1113984;c[2444186]=f?4654424:4654168;c[2113194]=c[9721800+(c[3528552]<<2)>>2];fC2();f=c[3528552]|0;e=(c[2433426]|0)+(f*3160|0)|0;if((e|0)!=0){g=e;gGC(g|0,9642704,60)|0}c[9721800+(f<<2)>>2]=c[2113194];c[3528552]=-1;c[3528556]=0;f=c[2433594]|0;c[2443776]=f;L34528:do{if((f|0)!=0){g=f|0;gGC(9660952,g|0,52)|0;switch(a[9660952]|0){case 3:{c[2309668]=639984;break L34528;break};case 5:{c[2309668]=7354992;break L34528;break};case 1:{c[2309668]=634096;break L34528;break};case 4:{c[2309668]=7356016;break L34528;break};case 0:{c[2309668]=638960;break L34528;break};case 2:{c[2309668]=638960;break L34528;break};default:{break L34528}}}}while(0);c[2113164]=c[2432850];gu[c[f+56>>2]&16383]();f=c[2443776]|0;if((f|0)!=0){g=f|0;gGC(g|0,9660952,52)|0}c[9731400+(c[3528556]<<2)>>2]=c[2113164];c[2443776]=0;c[3528556]=-1;c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;lw(c[3540984]|0);c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){g=0;do{lN(g);mB(g);g=g+1|0;}while((g|0)<(c[2385508]|0))}c[2440606]=0;c[2444190]=0}g=c[2113196]|0;if((g|0)>0){gGz(9721800,0,((g|0)>1?g<<2:4)|0)}c[2113194]=0;g=c[2113166]|0;if((g|0)>0){gGz(9731400,0,((g|0)>1?g<<2:4)|0)}c[2113164]=0;gGz(9550152,-1|0,5);g=0;f=-1;e=-1;i=-1;j=-1;k=-1;do{f=((a[9632392+g|0]&1)<<g^f&255)&255;e=((a[9630304+g|0]&1)<<g^e&255)&255;i=((a[9629184+g|0]&1)<<g^i&255)&255;j=((a[9629136+g|0]&1)<<g^j&255)&255;k=((a[9628864+g|0]&1)<<g^k&255)&255;g=g+1|0;}while((g|0)<8);a[9550152]=f;a[9550153]=e;a[9550154]=i;a[9550155]=j;a[9550156]=k;c[3528556]=0;k=c[2433594]|0;c[2443776]=k;L34555:do{if((k|0)!=0){j=k|0;gGC(9660952,j|0,52)|0;switch(a[9660952]|0){case 5:{c[2309668]=7354992;break L34555;break};case 2:{c[2309668]=638960;break L34555;break};case 3:{c[2309668]=639984;break L34555;break};case 4:{c[2309668]=7356016;break L34555;break};case 0:{c[2309668]=638960;break L34555;break};case 1:{c[2309668]=634096;break L34555;break};default:{break L34555}}}}while(0);c[2113164]=c[2432850];c[3528552]=0;k=c[2433426]|0;if((k|0)!=0){j=k;gGC(9642704,j|0,60)|0}b[4821352]=c[2410676]&65535;fC1();j=(a[9642745]&1)==0;c[2430032]=j?1595912:1595656;c[2429672]=j?1114752:1114496;c[2429670]=j?1114240:1113984;c[2444186]=j?4654424:4654168;c[2113194]=c[9721800+(c[3528552]<<2)>>2];c[2408976]=8;j=0;do{do{if((j|0)==1){c[2408976]=0}else if((j|0)==31){c[2408976]=8;k=d[9550156]^15;i=(k&8|0)==0;if(!i){a[600400]=1}e=(k&4|0)==0;if(!e){a[600392]=1}f=(k&2|0)==0;if(!f){a[600384]=1}g=(k&1|0)==0;if(!g){a[600376]=1}if(i&a[600400]){a[600400]=0;if((a[c[2432942]|0]|0)!=0){a[9642747]=1;fC1();fC4(0)|0;a[9642747]=0;fC4(0)|0}c[2440606]=32769}if(e&a[600392]){a[600392]=0;if((a[c[2432942]|0]|0)!=0){a[9642747]=1;fC1();fC4(0)|0;a[9642747]=0;fC4(0)|0}c[2440606]=16385}if(f&a[600384]){a[600384]=0;if((a[c[2432942]|0]|0)!=0){a[9642747]=1;fC1();fC4(0)|0;a[9642747]=0;fC4(0)|0}c[2440606]=8193}if(g&a[600376]){a[600376]=0;if((a[c[2432942]|0]|0)!=0){a[9642747]=1;fC1();fC4(0)|0;a[9642747]=0;fC4(0)|0}c[2440606]=4097}if((a[c[3528482]|0]|0)==0){break}fC3();fC4(0)|0;if((a[9642761]|0)!=0){a[9642761]=0}fC4(0)|0}}while(0);Sb(j*6465|0);UF(j*808|0)|0;j=j+1|0;}while((j|0)<32);j=c[2438228]|0;g=gGS(-1285554176,98655,j,(j|0)<0|0?-1:0)|0;j=g;Sb(206896);g=c[2443830]|0;if((g|0)<1073676288){c[2443830]=g-j}g=c[2443831]|0;if((g|0)<1073676288){c[2443831]=g-j}g=(c[3528512]|0)-j|0;c[3528512]=(g|0)<0?0:g;g=c[2438224]|0;j=gGS(-160694272,12331,g,(g|0)<0|0?-1:0)|0;g=j;UF(25862)|0;j=c[2443826]|0;if((j|0)<1073676288){c[2443826]=j-g}j=c[2443827]|0;if((j|0)<1073676288){c[2443827]=j-g}j=(c[3528508]|0)-g|0;c[3528508]=(j|0)<0?0:j;j=c[2112964]|0;if((j|0)!=0){gg[c[3542112]&4095](j,a[9688]|0?534:0);gg[c[3542122]&4095](c[2112964]|0,a[9688]|0?534:0)}j=c[3528552]|0;g=(c[2433426]|0)+(j*3160|0)|0;if((g|0)!=0){f=g;gGC(f|0,9642704,60)|0}c[9721800+(j<<2)>>2]=c[2113194];c[3528552]=-1;j=c[2443776]|0;if((j|0)!=0){f=j|0;gGC(f|0,9660952,52)|0}c[9731400+(c[3528556]<<2)>>2]=c[2113164];c[2443776]=0;c[3528556]=-1;if((c[2112968]|0)==0){l=c[2386556]|0;m=c[2386382]|0;gGC(l|0,m|0,2048)|0;return 0}aFU()|0;l=c[2386556]|0;m=c[2386382]|0;gGC(l|0,m|0,2048)|0;return 0}function aFU(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((a[9547080]|0)!=0){b=c[2407020]|0;e=c[3529894]|0;f=0;do{g=c[b+(f<<2)>>2]|0;c[e+(f<<2)>>2]=g>>>8&2016|g&31|g>>16<<8&63488;f=f+1|0;}while((f|0)<1024)}aHK(c[2387082]|0,c[3529872]|0,c[3530384]|0,512,15,2047,0);aHH(0);f=c[2386282]|0;e=c[2113070]|0;b=c[2112926]|0;g=c[3530752]|0;h=0;do{i=h<<3&248;j=h<<1;k=d[f+j|0]|0;l=k>>>2&3;m=k<<8&768|d[f+(j|1)|0];do{if((m|0)!=0){j=(h>>5<<3)-8|0;if(!((j|0)>-1&(j|0)<(e|0))){break}Sq(b,m,i,j,l,3,0,0,g)}}while(0);h=h+1|0;}while((h|0)<1024);R8(c[3529894]|0);return 0}function aFV(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((d&64|0)==0){aHx(d,e);return 0}fyq(d);UQ(d,e);if((d&2|0)==0){aHx(d,e);return 0}c[3528552]=0;f=c[2433426]|0;if((f|0)!=0){g=f;gGC(9642704,g|0,60)|0}b[4821352]=c[2410676]&65535;fC1();g=(a[9642745]&1)==0;c[2430032]=g?1595912:1595656;c[2429672]=g?1114752:1114496;c[2429670]=g?1114240:1113984;c[2444186]=g?4654424:4654168;g=c[3528552]|0;f=9721800+(g<<2)|0;c[2113194]=c[f>>2];h=c[3530266]|0;i=c[2433426]|0;j=(c[2406854]|0)+49152|0;k=64;l=64;while(1){m=h+(j+(l<<8))|0;c[i+(g*3160|0)+60+(l<<2)>>2]=m;c[i+(g*3160|0)+60+(l+512<<2)>>2]=m;m=k+1&65535;if((m&65535)>127){break}else{k=m;l=m&65535}}l=i+(g*3160|0)|0;if((l|0)!=0){g=l;gGC(g|0,9642704,60)|0}c[f>>2]=c[2113194];c[3528552]=-1;aHx(d,e);return 0}function aFW(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4698660+(b*112|0)>>2];c[a+104>>2]=c[4698664+(b*112|0)>>2];c[a+108>>2]=c[4698668+(b*112|0)>>2];d=0;return d|0}function aFX(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<22&(d|0)==0)){e=1;return e|0}c[a>>2]=4698560+(b*112|0);e=0;return e|0}function aFY(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>26){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1891640+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aFZ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>28){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5382168+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aF_(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4542468+(b*112|0)>>2];c[a+104>>2]=c[4542472+(b*112|0)>>2];c[a+108>>2]=c[4542476+(b*112|0)>>2];d=0;return d|0}function aF$(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<21&(d|0)==0)){e=1;return e|0}c[a>>2]=4542368+(b*112|0);e=0;return e|0}function aF0(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2576916+(b*112|0)>>2];c[a+104>>2]=c[2576920+(b*112|0)>>2];c[a+108>>2]=c[2576924+(b*112|0)>>2];d=0;return d|0}function aF1(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<21&(d|0)==0)){e=1;return e|0}c[a>>2]=2576816+(b*112|0);e=0;return e|0}function aF2(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=b&65535;if((e|0)==15362){b=c[2386556]|0;f=c[2386382]|0;gGC(b|0,f|0,2048)|0;return}else if((e|0)==15360){f=(d&255)<<14&245760;c[2406854]=f;b=c[3530266]|0;g=c[3528554]|0;h=c[2433592]|0;i=f+49152|0;f=64;j=64;while(1){k=b+(i+(j<<8))|0;c[h+(g*3148|0)+48+(j<<2)>>2]=k;c[h+(g*3148|0)+48+(j+512<<2)>>2]=k;k=f+1&65535;if((k&65535)>127){break}else{f=k;j=k&65535}}return}else if((e|0)==15872){a[c[3528212]|0]=d;gg[c[(c[2443776]|0)+64>>2]&4095](32,1);gj[c[(c[2443776]|0)+52>>2]&4095](0)|0;gg[c[(c[2443776]|0)+64>>2]&4095](32,0);gj[c[(c[2443776]|0)+52>>2]&4095](0)|0;j=gj[c[(c[2443776]|0)+52>>2]&4095](500)|0;c[2113164]=(c[2113164]|0)+j;return}else{j=e&65504;if((j|0)==14848){a[(c[3529870]|0)+(e&31)|0]=d;return}else if((j|0)==14336){a[(c[3529872]|0)+(e&31)|0]=d;return}else{return}}}function aF3(b){b=b|0;var d=0;switch(b&65535|0){case 14338:{d=a[9634672]|0;break};case 14337:{d=a[9550153]|0;break};case 14848:{d=(a[9550154]&127|c[2408976])&255;break};case 14336:{d=a[9550152]|0;break};case 14339:{d=a[9634673]|0;break};default:{d=0}}return d|0}function aF4(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3007780+(b*112|0)>>2];c[a+104>>2]=c[3007784+(b*112|0)>>2];c[a+108>>2]=c[3007788+(b*112|0)>>2];d=0;return d|0}function aF5(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=3007680+(b*112|0);e=0;return e|0}function aF6(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1293048+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aF7(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>36){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4155344+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aF8(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0;e=i;i=i+3720|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;B=e+1200|0;C=e+1312|0;D=e+1320|0;E=e+1432|0;F=e+1440|0;G=e+1552|0;H=e+1560|0;I=e+1672|0;J=e+1680|0;K=e+1792|0;L=e+1800|0;M=e+1912|0;N=e+1920|0;O=e+2032|0;P=e+2040|0;Q=e+2152|0;R=e+2160|0;S=e+2272|0;T=e+2280|0;U=e+2392|0;V=e+2400|0;W=e+2512|0;X=e+2520|0;Y=e+2632|0;Z=e+2640|0;_=e+2752|0;$=e+2760|0;aa=e+2872|0;ab=e+2880|0;ac=e+2992|0;ad=e+3e3|0;ae=e+3112|0;af=e+3120|0;ah=e+3232|0;ai=e+3240|0;aj=e+3352|0;ak=e+3360|0;al=e+3472|0;am=e+3480|0;an=e+3592|0;ao=e+3600|0;ap=e+3712|0;c[2414854]=0;c[3530266]=0;c[2386358]=327680;c[3527436]=458752;c[3527440]=589824;c[3530752]=655360;c[3530516]=786432;c[3530384]=1835008;c[3530308]=2883584;c[3531056]=3932160;c[2407020]=3934208;c[3529894]=3938304;c[2414556]=3942400;c[3530268]=3942400;c[2386282]=3950592;c[2387082]=3952640;c[2387076]=3956736;c[3529872]=3960832;c[3529870]=3960864;c[2386744]=3960896;c[2386382]=3961920;c[2386556]=3963968;c[2387100]=3966016;c[3527438]=3968064;c[3528212]=3970112;c[3528482]=3970113;c[2432942]=3970114;c[3528652]=3970115;c[2411456]=3970116;aq=0;while(1){if((aq|0)>=1024){break}ar=9638528+(aq<<2)|0;if((c[ar>>2]|0)==0){as=27265;break}else{aq=aq+1|0}}do{if((as|0)==27265){aq=gGq(3970116)|0;c[ar>>2]=aq;if((aq|0)==0){break}c[2414854]=aq;gGz(aq|0,0,3970116);c[3530266]=aq;c[2386358]=aq+327680;c[3527436]=aq+458752;c[3527440]=aq+589824;c[3530752]=aq+655360;c[3530516]=aq+786432;c[3530384]=aq+1835008;c[3530308]=aq+2883584;c[3531056]=aq+3932160;c[2407020]=aq+3934208;c[3529894]=aq+3938304;at=aq+3942400|0;c[2414556]=at;c[3530268]=at;c[2386282]=aq+3950592;c[2387082]=aq+3952640;c[2387076]=aq+3956736;c[3529872]=aq+3960832;c[3529870]=aq+3960864;c[2386744]=aq+3960896;c[2386382]=aq+3961920;c[2386556]=aq+3963968;c[2387100]=aq+3966016;c[3527438]=aq+3968064;c[3528212]=aq+3970112;c[3528482]=aq+3970113;c[2432942]=aq+3970114;c[3528652]=aq+3970115;at=aq+3970116|0;c[2411456]=at;c[2413996]=at;at=c[642608+(c[2436]<<2)>>2]|0;au=(fa(c[at>>2]|0,456792)|0)==0;av=aq+32768|0;do{if((c[3542200]|0)==0){aw=1}else{aq=ao+108|0;c[aq>>2]=0;ax=ao+100|0;c[ax>>2]=0;ay=c[at+76>>2]|0;gA[ay&16383](ao,0)|0;if((c[aq>>2]|0)==0){aw=0;break}aq=c[ax>>2]|0;c[ap>>2]=9534384;ax=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ax&16383](ap,0,0)|0;if((aq|0)<1){aw=1;break}aw=(gzL(av,0,0)|0)!=0}}while(0);if(au){if(aw){az=1;i=e;return az|0}av=(c[3530266]|0)+65536|0;if((c[3542200]|0)==0){az=1;i=e;return az|0}at=am+108|0;c[at>>2]=0;aq=am+100|0;c[aq>>2]=0;ax=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ax&16383](am,1)|0;do{if((c[at>>2]|0)!=0){ax=c[aq>>2]|0;c[an>>2]=9534384;ay=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ay&16383](an,1,0)|0;if((ax|0)<1){az=1;i=e;return az|0}if((gzL(av,0,1)|0)==0){break}else{az=1}i=e;return az|0}}while(0);av=(c[3530266]|0)+131072|0;if((c[3542200]|0)==0){az=1;i=e;return az|0}aq=ak+108|0;c[aq>>2]=0;at=ak+100|0;c[at>>2]=0;au=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[au&16383](ak,2)|0;do{if((c[aq>>2]|0)!=0){au=c[at>>2]|0;c[al>>2]=9534384;ax=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ax&16383](al,2,0)|0;if((au|0)<1){az=1;i=e;return az|0}if((gzL(av,0,2)|0)==0){break}else{az=1}i=e;return az|0}}while(0);av=(c[3527436]|0)+32768|0;if((c[3542200]|0)==0){az=1;i=e;return az|0}at=ai+108|0;c[at>>2]=0;aq=ai+100|0;c[aq>>2]=0;au=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[au&16383](ai,3)|0;do{if((c[at>>2]|0)!=0){au=c[aq>>2]|0;c[aj>>2]=9534384;ax=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ax&16383](aj,3,0)|0;if((au|0)<1){az=1;i=e;return az|0}if((gzL(av,0,3)|0)==0){break}else{az=1}i=e;return az|0}}while(0);av=c[3530752]|0;if((c[3542200]|0)==0){az=1;i=e;return az|0}aq=af+108|0;c[aq>>2]=0;at=af+100|0;c[at>>2]=0;au=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[au&16383](af,4)|0;do{if((c[aq>>2]|0)!=0){au=c[at>>2]|0;c[ah>>2]=9534384;ax=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ax&16383](ah,4,0)|0;if((au|0)<1){az=1;i=e;return az|0}if((gzL(av,0,4)|0)==0){break}else{az=1}i=e;return az|0}}while(0);av=c[3530516]|0;if((c[3542200]|0)==0){az=1;i=e;return az|0}at=ad+108|0;c[at>>2]=0;aq=ad+100|0;c[aq>>2]=0;au=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[au&16383](ad,5)|0;do{if((c[at>>2]|0)!=0){au=c[aq>>2]|0;c[ae>>2]=9534384;ax=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ax&16383](ae,5,0)|0;if((au|0)<1){az=1;i=e;return az|0}if((gzL(av,0,5)|0)==0){break}else{az=1}i=e;return az|0}}while(0);av=(c[3530516]|0)+131072|0;if((c[3542200]|0)==0){az=1;i=e;return az|0}aq=ab+108|0;c[aq>>2]=0;at=ab+100|0;c[at>>2]=0;au=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[au&16383](ab,6)|0;do{if((c[aq>>2]|0)!=0){au=c[at>>2]|0;c[ac>>2]=9534384;ax=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ax&16383](ac,6,0)|0;if((au|0)<1){az=1;i=e;return az|0}if((gzL(av,0,6)|0)==0){break}else{az=1}i=e;return az|0}}while(0);av=(c[3530516]|0)+262144|0;if((c[3542200]|0)==0){az=1;i=e;return az|0}at=$+108|0;c[at>>2]=0;aq=$+100|0;c[aq>>2]=0;au=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[au&16383]($,7)|0;do{if((c[at>>2]|0)!=0){au=c[aq>>2]|0;c[aa>>2]=9534384;ax=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ax&16383](aa,7,0)|0;if((au|0)<1){az=1;i=e;return az|0}if((gzL(av,0,7)|0)==0){break}else{az=1}i=e;return az|0}}while(0);av=(c[3530516]|0)+393216|0;if((c[3542200]|0)==0){az=1;i=e;return az|0}aq=Z+108|0;c[aq>>2]=0;at=Z+100|0;c[at>>2]=0;au=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[au&16383](Z,8)|0;do{if((c[aq>>2]|0)!=0){au=c[at>>2]|0;c[_>>2]=9534384;ax=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ax&16383](_,8,0)|0;if((au|0)<1){az=1;i=e;return az|0}if((gzL(av,0,8)|0)==0){break}else{az=1}i=e;return az|0}}while(0);av=c[3530384]|0;if((c[3542200]|0)==0){az=1;i=e;return az|0}at=X+108|0;c[at>>2]=0;aq=X+100|0;c[aq>>2]=0;au=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[au&16383](X,9)|0;do{if((c[at>>2]|0)!=0){au=c[aq>>2]|0;c[Y>>2]=9534384;ax=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ax&16383](Y,9,0)|0;if((au|0)<1){az=1;i=e;return az|0}if((gzL(av,0,9)|0)==0){break}else{az=1}i=e;return az|0}}while(0);av=(c[3530384]|0)+262144|0;if((c[3542200]|0)==0){az=1;i=e;return az|0}aq=V+108|0;c[aq>>2]=0;at=V+100|0;c[at>>2]=0;au=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[au&16383](V,10)|0;do{if((c[aq>>2]|0)!=0){au=c[at>>2]|0;c[W>>2]=9534384;ax=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ax&16383](W,10,0)|0;if((au|0)<1){az=1;i=e;return az|0}if((gzL(av,0,10)|0)==0){break}else{az=1}i=e;return az|0}}while(0);av=(c[3530384]|0)+131072|0;if((c[3542200]|0)==0){az=1;i=e;return az|0}at=T+108|0;c[at>>2]=0;aq=T+100|0;c[aq>>2]=0;au=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[au&16383](T,11)|0;do{if((c[at>>2]|0)!=0){au=c[aq>>2]|0;c[U>>2]=9534384;ax=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ax&16383](U,11,0)|0;if((au|0)<1){az=1;i=e;return az|0}if((gzL(av,0,11)|0)==0){break}else{az=1}i=e;return az|0}}while(0);av=(c[3530384]|0)+393216|0;if((c[3542200]|0)==0){az=1;i=e;return az|0}aq=R+108|0;c[aq>>2]=0;at=R+100|0;c[at>>2]=0;au=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[au&16383](R,12)|0;do{if((c[aq>>2]|0)!=0){au=c[at>>2]|0;c[S>>2]=9534384;ax=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ax&16383](S,12,0)|0;if((au|0)<1){az=1;i=e;return az|0}if((gzL(av,0,12)|0)==0){break}else{az=1}i=e;return az|0}}while(0);av=c[3530308]|0;if((c[3542200]|0)==0){az=1;i=e;return az|0}at=P+108|0;c[at>>2]=0;aq=P+100|0;c[aq>>2]=0;au=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[au&16383](P,13)|0;do{if((c[at>>2]|0)!=0){au=c[aq>>2]|0;c[Q>>2]=9534384;ax=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ax&16383](Q,13,0)|0;if((au|0)<1){az=1;i=e;return az|0}if((gzL(av,0,13)|0)==0){break}else{az=1}i=e;return az|0}}while(0);av=(c[3530308]|0)+131072|0;if((c[3542200]|0)==0){az=1;i=e;return az|0}aq=N+108|0;c[aq>>2]=0;at=N+100|0;c[at>>2]=0;au=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[au&16383](N,14)|0;do{if((c[aq>>2]|0)!=0){au=c[at>>2]|0;c[O>>2]=9534384;ax=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ax&16383](O,14,0)|0;if((au|0)<1){az=1;i=e;return az|0}if((gzL(av,0,14)|0)==0){break}else{az=1}i=e;return az|0}}while(0);av=(c[3530308]|0)+262144|0;if((c[3542200]|0)==0){az=1;i=e;return az|0}at=L+108|0;c[at>>2]=0;aq=L+100|0;c[aq>>2]=0;au=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[au&16383](L,15)|0;do{if((c[at>>2]|0)!=0){au=c[aq>>2]|0;c[M>>2]=9534384;ax=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ax&16383](M,15,0)|0;if((au|0)<1){az=1;i=e;return az|0}if((gzL(av,0,15)|0)==0){break}else{az=1}i=e;return az|0}}while(0);av=(c[3530308]|0)+393216|0;if((c[3542200]|0)==0){az=1;i=e;return az|0}aq=J+108|0;c[aq>>2]=0;at=J+100|0;c[at>>2]=0;au=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[au&16383](J,16)|0;do{if((c[aq>>2]|0)!=0){au=c[at>>2]|0;c[K>>2]=9534384;ax=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ax&16383](K,16,0)|0;if((au|0)<1){az=1;i=e;return az|0}if((gzL(av,0,16)|0)==0){break}else{az=1}i=e;return az|0}}while(0);av=(c[3527440]|0)+32768|0;at=(c[3527436]|0)+32768|0;gGC(av|0,at|0,32768)|0;aA=0}else{if(aw){az=1;i=e;return az|0}at=(c[3530266]|0)+65536|0;if((c[3542200]|0)==0){az=1;i=e;return az|0}av=H+108|0;c[av>>2]=0;aq=H+100|0;c[aq>>2]=0;au=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[au&16383](H,1)|0;do{if((c[av>>2]|0)!=0){au=c[aq>>2]|0;c[I>>2]=9534384;ax=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ax&16383](I,1,0)|0;if((au|0)<1){az=1;i=e;return az|0}if((gzL(at,0,1)|0)==0){break}else{az=1}i=e;return az|0}}while(0);at=(c[3530266]|0)+131072|0;if((c[3542200]|0)==0){az=1;i=e;return az|0}aq=F+108|0;c[aq>>2]=0;av=F+100|0;c[av>>2]=0;au=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[au&16383](F,2)|0;do{if((c[aq>>2]|0)!=0){au=c[av>>2]|0;c[G>>2]=9534384;ax=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ax&16383](G,2,0)|0;if((au|0)<1){az=1;i=e;return az|0}if((gzL(at,0,2)|0)==0){break}else{az=1}i=e;return az|0}}while(0);at=(c[3527436]|0)+32768|0;if((c[3542200]|0)==0){az=1;i=e;return az|0}av=D+108|0;c[av>>2]=0;aq=D+100|0;c[aq>>2]=0;au=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[au&16383](D,3)|0;do{if((c[av>>2]|0)!=0){au=c[aq>>2]|0;c[E>>2]=9534384;ax=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ax&16383](E,3,0)|0;if((au|0)<1){az=1;i=e;return az|0}if((gzL(at,0,3)|0)==0){break}else{az=1}i=e;return az|0}}while(0);at=c[3530752]|0;if((c[3542200]|0)==0){az=1;i=e;return az|0}aq=B+108|0;c[aq>>2]=0;av=B+100|0;c[av>>2]=0;au=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[au&16383](B,4)|0;do{if((c[aq>>2]|0)!=0){au=c[av>>2]|0;c[C>>2]=9534384;ax=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ax&16383](C,4,0)|0;if((au|0)<1){az=1;i=e;return az|0}if((gzL(at,0,4)|0)==0){break}else{az=1}i=e;return az|0}}while(0);at=c[3530516]|0;if((c[3542200]|0)==0){az=1;i=e;return az|0}av=z+108|0;c[av>>2]=0;aq=z+100|0;c[aq>>2]=0;au=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[au&16383](z,5)|0;do{if((c[av>>2]|0)!=0){au=c[aq>>2]|0;c[A>>2]=9534384;ax=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ax&16383](A,5,0)|0;if((au|0)<1){az=1;i=e;return az|0}if((gzL(at,0,5)|0)==0){break}else{az=1}i=e;return az|0}}while(0);at=(c[3530516]|0)+131072|0;if((c[3542200]|0)==0){az=1;i=e;return az|0}aq=x+108|0;c[aq>>2]=0;av=x+100|0;c[av>>2]=0;au=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[au&16383](x,6)|0;do{if((c[aq>>2]|0)!=0){au=c[av>>2]|0;c[y>>2]=9534384;ax=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ax&16383](y,6,0)|0;if((au|0)<1){az=1;i=e;return az|0}if((gzL(at,0,6)|0)==0){break}else{az=1}i=e;return az|0}}while(0);at=(c[3530516]|0)+262144|0;if((c[3542200]|0)==0){az=1;i=e;return az|0}av=v+108|0;c[av>>2]=0;aq=v+100|0;c[aq>>2]=0;au=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[au&16383](v,7)|0;do{if((c[av>>2]|0)!=0){au=c[aq>>2]|0;c[w>>2]=9534384;ax=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ax&16383](w,7,0)|0;if((au|0)<1){az=1;i=e;return az|0}if((gzL(at,0,7)|0)==0){break}else{az=1}i=e;return az|0}}while(0);at=(c[3530516]|0)+393216|0;if((c[3542200]|0)==0){az=1;i=e;return az|0}aq=t+108|0;c[aq>>2]=0;av=t+100|0;c[av>>2]=0;au=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[au&16383](t,8)|0;do{if((c[aq>>2]|0)!=0){au=c[av>>2]|0;c[u>>2]=9534384;ax=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ax&16383](u,8,0)|0;if((au|0)<1){az=1;i=e;return az|0}if((gzL(at,0,8)|0)==0){break}else{az=1}i=e;return az|0}}while(0);at=c[3530384]|0;if((c[3542200]|0)==0){az=1;i=e;return az|0}av=r+108|0;c[av>>2]=0;aq=r+100|0;c[aq>>2]=0;au=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[au&16383](r,9)|0;do{if((c[av>>2]|0)!=0){au=c[aq>>2]|0;c[s>>2]=9534384;ax=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ax&16383](s,9,0)|0;if((au|0)<1){az=1;i=e;return az|0}if((gzL(at,0,9)|0)==0){break}else{az=1}i=e;return az|0}}while(0);at=c[3530384]|0;aq=at+262144|0;av=at+32768|0;gGC(aq|0,av|0,32768)|0;av=at+131072|0;if((c[3542200]|0)==0){az=1;i=e;return az|0}at=p+108|0;c[at>>2]=0;aq=p+100|0;c[aq>>2]=0;au=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[au&16383](p,10)|0;do{if((c[at>>2]|0)!=0){au=c[aq>>2]|0;c[q>>2]=9534384;ax=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ax&16383](q,10,0)|0;if((au|0)<1){az=1;i=e;return az|0}if((gzL(av,0,10)|0)==0){break}else{az=1}i=e;return az|0}}while(0);av=c[3530384]|0;aq=av+393216|0;at=av+163840|0;gGC(aq|0,at|0,32768)|0;at=c[3530308]|0;if((c[3542200]|0)==0){az=1;i=e;return az|0}aq=n+108|0;c[aq>>2]=0;av=n+100|0;c[av>>2]=0;au=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[au&16383](n,11)|0;do{if((c[aq>>2]|0)!=0){au=c[av>>2]|0;c[o>>2]=9534384;ax=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ax&16383](o,11,0)|0;if((au|0)<1){az=1;i=e;return az|0}if((gzL(at,0,11)|0)==0){break}else{az=1}i=e;return az|0}}while(0);at=(c[3530308]|0)+131072|0;if((c[3542200]|0)==0){az=1;i=e;return az|0}av=l+108|0;c[av>>2]=0;aq=l+100|0;c[aq>>2]=0;au=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[au&16383](l,12)|0;do{if((c[av>>2]|0)!=0){au=c[aq>>2]|0;c[m>>2]=9534384;ax=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ax&16383](m,12,0)|0;if((au|0)<1){az=1;i=e;return az|0}if((gzL(at,0,12)|0)==0){break}else{az=1}i=e;return az|0}}while(0);at=(c[3530308]|0)+262144|0;if((c[3542200]|0)==0){az=1;i=e;return az|0}aq=j+108|0;c[aq>>2]=0;av=j+100|0;c[av>>2]=0;au=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[au&16383](j,13)|0;do{if((c[aq>>2]|0)!=0){au=c[av>>2]|0;c[k>>2]=9534384;ax=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ax&16383](k,13,0)|0;if((au|0)<1){az=1;i=e;return az|0}if((gzL(at,0,13)|0)==0){break}else{az=1}i=e;return az|0}}while(0);at=(c[3530308]|0)+393216|0;if((c[3542200]|0)==0){az=1;i=e;return az|0}av=f+108|0;c[av>>2]=0;aq=f+100|0;c[aq>>2]=0;au=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[au&16383](f,14)|0;do{if((c[av>>2]|0)!=0){au=c[aq>>2]|0;c[g>>2]=9534384;ax=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ax&16383](g,14,0)|0;if((au|0)<1){az=1;i=e;return az|0}if((gzL(at,0,14)|0)==0){break}else{az=1}i=e;return az|0}}while(0);at=(c[3527440]|0)+32768|0;aq=(c[3527436]|0)+32768|0;gGC(at|0,aq|0,32768)|0;aA=0}while(1){if((aA|0)>=1024){break}aB=9638528+(aA<<2)|0;if((c[aB>>2]|0)==0){as=27398;break}else{aA=aA+1|0}}L35103:do{if((as|0)==27398){aq=gGq(524288)|0;c[aB>>2]=aq;if((aq|0)==0){break}gGz(aq|0,0,524288);at=c[3530752]|0;gGC(aq|0,at|0,32768)|0;av=0;do{au=av<<6;gGz(at+au|0,0,64);ax=au+131072|0;ay=0;while(1){aC=ax+(c[609008+(ay<<2)>>2]|0)|0;aD=(ay<<3)+au|0;aE=0;do{aF=aC+(c[614800+(aE<<2)>>2]|0)|0;if((d[aq+((aF|0)/8|0)|0]&128>>>((aF&7)>>>0)|0)!=0){aF=at+(aD+aE)|0;a[aF]=a[aF]|2}aE=aE+1|0;}while((aE|0)<8);aE=ay+1|0;if((aE|0)<8){ay=aE}else{aG=0;break}}do{ay=au+(c[609008+(aG<<2)>>2]|0)|0;ax=(aG<<3)+au|0;aE=0;do{aD=ay+(c[614800+(aE<<2)>>2]|0)|0;if((d[aq+((aD|0)/8|0)|0]&128>>>((aD&7)>>>0)|0)!=0){aD=at+(ax+aE)|0;a[aD]=a[aD]|1}aE=aE+1|0;}while((aE|0)<8);aG=aG+1|0;}while((aG|0)<8);av=av+1|0;}while((av|0)<1024);av=c[3530516]|0;gGC(aq|0,av|0,524288)|0;at=0;do{au=at<<8;gGz(av+au|0,0,256);aE=0;do{ax=1<<3-aE;ay=(c[704200+(aE<<2)>>2]|0)+au|0;aD=0;do{aC=ay+(c[609008+(aD<<2)>>2]|0)|0;aF=(aD<<4)+au|0;aH=0;do{aI=aC+(c[612640+(aH<<2)>>2]|0)|0;if((d[aq+((aI|0)/8|0)|0]&128>>>((aI&7)>>>0)|0)!=0){aI=av+(aF+aH)|0;a[aI]=(d[aI]|ax)&255}aH=aH+1|0;}while((aH|0)<16);aD=aD+1|0;}while((aD|0)<16);aE=aE+1|0;}while((aE|0)<4);at=at+1|0;}while((at|0)<4096);at=c[3530384]|0;gGC(aq|0,at|0,524288)|0;av=0;do{aE=av<<8;gGz(at+aE|0,0,256);au=0;do{aD=1<<3-au;ax=(c[704200+(au<<2)>>2]|0)+aE|0;ay=0;do{aH=ax+(c[609008+(ay<<2)>>2]|0)|0;aF=(ay<<4)+aE|0;aC=0;do{aI=aH+(c[612640+(aC<<2)>>2]|0)|0;if((d[aq+((aI|0)/8|0)|0]&128>>>((aI&7)>>>0)|0)!=0){aI=at+(aF+aC)|0;a[aI]=(d[aI]|aD)&255}aC=aC+1|0;}while((aC|0)<16);ay=ay+1|0;}while((ay|0)<16);au=au+1|0;}while((au|0)<4);av=av+1|0;}while((av|0)<4096);av=c[3530308]|0;gGC(aq|0,av|0,524288)|0;at=0;while(1){au=at<<8;gGz(av+au|0,0,256);aE=0;do{ay=1<<3-aE;aD=(c[704200+(aE<<2)>>2]|0)+au|0;ax=0;do{aC=aD+(c[609008+(ax<<2)>>2]|0)|0;aF=(ax<<4)+au|0;aH=0;do{aI=aC+(c[612640+(aH<<2)>>2]|0)|0;if((d[aq+((aI|0)/8|0)|0]&128>>>((aI&7)>>>0)|0)!=0){aI=av+(aF+aH)|0;a[aI]=(d[aI]|ay)&255}aH=aH+1|0;}while((aH|0)<16);ax=ax+1|0;}while((ax|0)<16);aE=aE+1|0;}while((aE|0)<4);aE=at+1|0;if((aE|0)<4096){at=aE}else{aJ=0;break}}while(1){if((aJ|0)>=1024){break L35103}aK=9638528+(aJ<<2)|0;if((c[aK>>2]|0)==(aq|0)){break}else{aJ=aJ+1|0}}gGr(aq);c[aK>>2]=0}}while(0);c[3528554]=-1;c[2113160]=1;at=gGq(3148)|0;av=at;c[2433592]=av;if((at|0)!=0){gGz(at|0,0,3148);c[at+3120>>2]=3128;c[at+3124>>2]=1840;c[at+3128>>2]=136;c[at+3132>>2]=1902;c[2432840]=0;aE=0;do{c[av+48+(aE<<2)>>2]=0;aE=aE+1|0;}while((aE|0)<768);c[2113158]=0;c[2415198]=0;aE=c[2427044]|0;c[9681616+(aE<<3)>>2]=809272;c[9681620+(aE<<3)>>2]=0;c[2427044]=aE+1}c[3528554]=0;f43(at);aE=c[3528554]|0;av=9731360+(aE<<2)|0;au=c[av>>2]|0;c[2113158]=au;ax=c[3530268]|0;ay=c[2433592]|0;c[ay+(aE*3148|0)+48>>2]=ax;c[ay+(aE*3148|0)+1072>>2]=ax;c[ay+(aE*3148|0)+2096>>2]=ax;aD=ax+256|0;c[ay+(aE*3148|0)+52>>2]=aD;c[ay+(aE*3148|0)+1076>>2]=aD;c[ay+(aE*3148|0)+2100>>2]=aD;aD=ax+512|0;c[ay+(aE*3148|0)+56>>2]=aD;c[ay+(aE*3148|0)+1080>>2]=aD;c[ay+(aE*3148|0)+2104>>2]=aD;aD=ax+768|0;c[ay+(aE*3148|0)+60>>2]=aD;c[ay+(aE*3148|0)+1084>>2]=aD;c[ay+(aE*3148|0)+2108>>2]=aD;aD=ax+1024|0;c[ay+(aE*3148|0)+64>>2]=aD;c[ay+(aE*3148|0)+1088>>2]=aD;c[ay+(aE*3148|0)+2112>>2]=aD;aD=ax+1280|0;c[ay+(aE*3148|0)+68>>2]=aD;c[ay+(aE*3148|0)+1092>>2]=aD;c[ay+(aE*3148|0)+2116>>2]=aD;aD=ax+1536|0;c[ay+(aE*3148|0)+72>>2]=aD;c[ay+(aE*3148|0)+1096>>2]=aD;c[ay+(aE*3148|0)+2120>>2]=aD;aD=ax+1792|0;c[ay+(aE*3148|0)+76>>2]=aD;c[ay+(aE*3148|0)+1100>>2]=aD;c[ay+(aE*3148|0)+2124>>2]=aD;aD=c[2387082]|0;c[ay+(aE*3148|0)+80>>2]=aD;c[ay+(aE*3148|0)+1104>>2]=aD;c[ay+(aE*3148|0)+2128>>2]=aD;ax=aD+256|0;c[ay+(aE*3148|0)+84>>2]=ax;c[ay+(aE*3148|0)+1108>>2]=ax;c[ay+(aE*3148|0)+2132>>2]=ax;ax=aD+512|0;c[ay+(aE*3148|0)+88>>2]=ax;c[ay+(aE*3148|0)+1112>>2]=ax;c[ay+(aE*3148|0)+2136>>2]=ax;ax=aD+768|0;c[ay+(aE*3148|0)+92>>2]=ax;c[ay+(aE*3148|0)+1116>>2]=ax;c[ay+(aE*3148|0)+2140>>2]=ax;ax=aD+1024|0;c[ay+(aE*3148|0)+96>>2]=ax;c[ay+(aE*3148|0)+1120>>2]=ax;c[ay+(aE*3148|0)+2144>>2]=ax;ax=aD+1280|0;c[ay+(aE*3148|0)+100>>2]=ax;c[ay+(aE*3148|0)+1124>>2]=ax;c[ay+(aE*3148|0)+2148>>2]=ax;ax=aD+1536|0;c[ay+(aE*3148|0)+104>>2]=ax;c[ay+(aE*3148|0)+1128>>2]=ax;c[ay+(aE*3148|0)+2152>>2]=ax;ax=aD+1792|0;c[ay+(aE*3148|0)+108>>2]=ax;c[ay+(aE*3148|0)+1132>>2]=ax;c[ay+(aE*3148|0)+2156>>2]=ax;ax=c[2387076]|0;aD=16;aH=16;while(1){aF=ax+((aH<<8)-4096)|0;c[ay+(aE*3148|0)+48+(aH<<2)>>2]=aF;c[ay+(aE*3148|0)+48+(aH+256<<2)>>2]=aF;c[ay+(aE*3148|0)+48+(aH+512<<2)>>2]=aF;aF=aD+1&65535;if((aF&65535)>31){break}else{aD=aF;aH=aF&65535}}aH=c[2386282]|0;c[ay+(aE*3148|0)+176>>2]=aH;c[ay+(aE*3148|0)+1200>>2]=aH;c[ay+(aE*3148|0)+2224>>2]=aH;aD=aH+256|0;c[ay+(aE*3148|0)+180>>2]=aD;c[ay+(aE*3148|0)+1204>>2]=aD;c[ay+(aE*3148|0)+2228>>2]=aD;aD=aH+512|0;c[ay+(aE*3148|0)+184>>2]=aD;c[ay+(aE*3148|0)+1208>>2]=aD;c[ay+(aE*3148|0)+2232>>2]=aD;aD=aH+768|0;c[ay+(aE*3148|0)+188>>2]=aD;c[ay+(aE*3148|0)+1212>>2]=aD;c[ay+(aE*3148|0)+2236>>2]=aD;aD=aH+1024|0;c[ay+(aE*3148|0)+192>>2]=aD;c[ay+(aE*3148|0)+1216>>2]=aD;c[ay+(aE*3148|0)+2240>>2]=aD;aD=aH+1280|0;c[ay+(aE*3148|0)+196>>2]=aD;c[ay+(aE*3148|0)+1220>>2]=aD;c[ay+(aE*3148|0)+2244>>2]=aD;aD=aH+1536|0;c[ay+(aE*3148|0)+200>>2]=aD;c[ay+(aE*3148|0)+1224>>2]=aD;c[ay+(aE*3148|0)+2248>>2]=aD;aD=aH+1792|0;c[ay+(aE*3148|0)+204>>2]=aD;c[ay+(aE*3148|0)+1228>>2]=aD;c[ay+(aE*3148|0)+2252>>2]=aD;aD=c[2386382]|0;c[ay+(aE*3148|0)+208>>2]=aD;c[ay+(aE*3148|0)+1232>>2]=aD;c[ay+(aE*3148|0)+2256>>2]=aD;aH=aD+256|0;c[ay+(aE*3148|0)+212>>2]=aH;c[ay+(aE*3148|0)+1236>>2]=aH;c[ay+(aE*3148|0)+2260>>2]=aH;aH=aD+512|0;c[ay+(aE*3148|0)+216>>2]=aH;c[ay+(aE*3148|0)+1240>>2]=aH;c[ay+(aE*3148|0)+2264>>2]=aH;aH=aD+768|0;c[ay+(aE*3148|0)+220>>2]=aH;c[ay+(aE*3148|0)+1244>>2]=aH;c[ay+(aE*3148|0)+2268>>2]=aH;aH=aD+1024|0;c[ay+(aE*3148|0)+224>>2]=aH;c[ay+(aE*3148|0)+1248>>2]=aH;c[ay+(aE*3148|0)+2272>>2]=aH;aH=aD+1280|0;c[ay+(aE*3148|0)+228>>2]=aH;c[ay+(aE*3148|0)+1252>>2]=aH;c[ay+(aE*3148|0)+2276>>2]=aH;aH=aD+1536|0;c[ay+(aE*3148|0)+232>>2]=aH;c[ay+(aE*3148|0)+1256>>2]=aH;c[ay+(aE*3148|0)+2280>>2]=aH;aH=aD+1792|0;c[ay+(aE*3148|0)+236>>2]=aH;c[ay+(aE*3148|0)+1260>>2]=aH;c[ay+(aE*3148|0)+2284>>2]=aH;aH=c[2387100]|0;c[ay+(aE*3148|0)+240>>2]=aH;c[ay+(aE*3148|0)+1264>>2]=aH;c[ay+(aE*3148|0)+2288>>2]=aH;aD=aH+256|0;c[ay+(aE*3148|0)+244>>2]=aD;c[ay+(aE*3148|0)+1268>>2]=aD;c[ay+(aE*3148|0)+2292>>2]=aD;aD=aH+512|0;c[ay+(aE*3148|0)+248>>2]=aD;c[ay+(aE*3148|0)+1272>>2]=aD;c[ay+(aE*3148|0)+2296>>2]=aD;aD=aH+768|0;c[ay+(aE*3148|0)+252>>2]=aD;c[ay+(aE*3148|0)+1276>>2]=aD;c[ay+(aE*3148|0)+2300>>2]=aD;aD=aH+1024|0;c[ay+(aE*3148|0)+256>>2]=aD;c[ay+(aE*3148|0)+1280>>2]=aD;c[ay+(aE*3148|0)+2304>>2]=aD;aD=aH+1280|0;c[ay+(aE*3148|0)+260>>2]=aD;c[ay+(aE*3148|0)+1284>>2]=aD;c[ay+(aE*3148|0)+2308>>2]=aD;aD=aH+1536|0;c[ay+(aE*3148|0)+264>>2]=aD;c[ay+(aE*3148|0)+1288>>2]=aD;c[ay+(aE*3148|0)+2312>>2]=aD;aD=aH+1792|0;c[ay+(aE*3148|0)+268>>2]=aD;c[ay+(aE*3148|0)+1292>>2]=aD;c[ay+(aE*3148|0)+2316>>2]=aD;aD=c[3530266]|0;aH=64;ax=64;while(1){at=aD+((ax<<8)+49152)|0;c[ay+(aE*3148|0)+48+(ax<<2)>>2]=at;c[ay+(aE*3148|0)+48+(ax+512<<2)>>2]=at;at=aH+1&65535;if((at&65535)>127){aL=128;aM=128;break}else{aH=at;ax=at&65535}}while(1){ax=aD+(aM<<8)|0;c[ay+(aE*3148|0)+48+(aM<<2)>>2]=ax;c[ay+(aE*3148|0)+48+(aM+512<<2)>>2]=ax;ax=aL+1&65535;if((ax&65535)>255){break}else{aL=ax;aM=ax&65535}}c[ay+(aE*3148|0)+3124>>2]=2788;c[ay+(aE*3148|0)+3120>>2]=3580;aD=ay+(aE*3148|0)|0;if((aD|0)!=0){ax=aD;gGC(ax|0,9660752,48)|0}c[av>>2]=au;c[3528554]=-1;fvI();c[3528556]=0;ax=c[2433594]|0;c[2443776]=ax;L35192:do{if((ax|0)!=0){aD=ax|0;gGC(9660952,aD|0,52)|0;switch(a[9660952]|0){case 0:{c[2309668]=638960;break L35192;break};case 1:{c[2309668]=634096;break L35192;break};case 3:{c[2309668]=639984;break L35192;break};case 4:{c[2309668]=7356016;break L35192;break};case 5:{c[2309668]=7354992;break L35192;break};case 2:{c[2309668]=638960;break L35192;break};default:{break L35192}}}}while(0);au=c[2432850]|0;c[2113164]=au;av=c[3527438]|0;c[ax+68>>2]=av;c[ax+1092>>2]=av;c[ax+2116>>2]=av;aE=av+256|0;c[ax+72>>2]=aE;c[ax+1096>>2]=aE;c[ax+2120>>2]=aE;aE=av+512|0;c[ax+76>>2]=aE;c[ax+1100>>2]=aE;c[ax+2124>>2]=aE;aE=av+768|0;c[ax+80>>2]=aE;c[ax+1104>>2]=aE;c[ax+2128>>2]=aE;aE=av+1024|0;c[ax+84>>2]=aE;c[ax+1108>>2]=aE;c[ax+2132>>2]=aE;aE=av+1280|0;c[ax+88>>2]=aE;c[ax+1112>>2]=aE;c[ax+2136>>2]=aE;aE=c[3527436]|0;av=128;ay=128;while(1){aD=aE+(ay<<8)|0;c[ax+68+(ay<<2)>>2]=aD;c[ax+68+(ay+512<<2)>>2]=aD;aD=av+1&65535;if((aD&65535)>255){break}else{av=aD;ay=aD&65535}}c[ax+3148>>2]=406;c[ax+3152>>2]=1392;ay=ax|0;gGC(ay|0,9660952,52)|0;c[2432850]=au;c[2443776]=0;c[3528556]=-1;c[2424]=5800;Vr(1,15e5,0,644,128,0);c[2438228]=2e6;c[2433526]=3068;c[2406676]=206;c[3528472]=4026;c[2443846]=1023;h[745419]=.5;a[3203368]=1;h[745418]=.53;a[3203360]=1;h[745417]=.53;a[3203352]=1;h[745416]=.53;a[3203344]=1;UL(3e6,1494,2124,1);c[2438224]=15e5;c[2433522]=3258;c[2406672]=2016;c[3528468]=6844;c[2443842]=1364;h[745398]=.7;a[3203264]=1;ay=c[642608+(c[2436]<<2)>>2]|0;av=c[ay+128>>2]|0;if((c[ay+52>>2]&4|0)==0){c[2113068]=av;aE=c[ay+132>>2]|0;c[2113070]=aE;c[2443814]=av;c[2440436]=aE;aN=av;aO=aE}else{c[2113070]=av;aE=c[ay+132>>2]|0;c[2113068]=aE;c[2440436]=av;c[2443814]=aE;aN=aE;aO=av}av=ag(aN<<1,aO)|0;aE=gGq(av)|0;c[2112926]=aE;if((aE|0)!=0){gGz(aE|0,0,av|0)}a[9623400]=0;av=c[2414556]|0;gGz(av|0,0,(c[2411456]|0)-av|0);c[3528554]=0;f43(c[2433592]|0);av=c[3528554]|0;c[2113158]=c[9731360+(av<<2)>>2];a[9660796]=0;a[9660797]=0;a[9660786]=0;a[9660787]=0;c[2415191]=0;a[9660784]=a[9660784]|80;aE=c[2433592]|0;ay=c[aE+(av*3148|0)+1068>>2]|0;do{if((ay|0)==0){aD=c[aE+(av*3148|0)+3120>>2]|0;if((aD|0)==0){aP=0;aQ=0;aR=av;aS=aE;break}aH=gj[aD&4095](-2)|0;aD=c[3528554]|0;at=c[2433592]|0;aF=c[at+(aD*3148|0)+1068>>2]|0;aC=(aH&255)<<8;if((aF|0)!=0){aT=aF;aU=aC;aV=aD;aW=at;as=27469;break}aF=c[at+(aD*3148|0)+3120>>2]|0;if((aF|0)==0){aP=0;aQ=aC;aR=aD;aS=at;break}at=gj[aF&4095](-1)|0;aP=at;aQ=aC;aR=c[3528554]|0;aS=c[2433592]|0}else{aT=ay;aU=d[ay+254|0]<<8;aV=av;aW=aE;as=27469}}while(0);if((as|0)==27469){aP=a[aT+255|0]|0;aQ=aU;aR=aV;aS=aW}aE=aP&255|aQ;c[2415188]=aE;b[4830376]=aE&65535;aE=aS+(aR*3148|0)|0;if((aE|0)!=0){av=aE;gGC(av|0,9660752,48)|0}c[9731360+(aR<<2)>>2]=c[2113158];c[3528554]=-1;c[3528556]=0;av=c[2433594]|0;c[2443776]=av;L35224:do{if((av|0)!=0){aE=av|0;gGC(9660952,aE|0,52)|0;switch(a[9660952]|0){case 0:{c[2309668]=638960;break L35224;break};case 1:{c[2309668]=634096;break L35224;break};case 3:{c[2309668]=639984;break L35224;break};case 4:{c[2309668]=7356016;break L35224;break};case 5:{c[2309668]=7354992;break L35224;break};case 2:{c[2309668]=638960;break L35224;break};default:{break L35224}}}}while(0);c[2113164]=c[2432850];gu[c[av+56>>2]&16383]();aE=c[2443776]|0;if((aE|0)!=0){ay=aE|0;gGC(ay|0,9660952,52)|0}c[9731400+(c[3528556]<<2)>>2]=c[2113164];c[2443776]=0;c[3528556]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){ay=0;do{lN(ay);mB(ay);ay=ay+1|0;}while((ay|0)<(c[2385508]|0))}c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;lw(c[3540984]|0);c[2440606]=0;c[2444190]=0;az=0;i=e;return az|0}}while(0);c[2414854]=0;az=1;i=e;return az|0}function aF9(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c[2113160]=0;b=c[2433592]|0;if((b|0)!=0){gGr(b);c[2433592]=0}b=a[7452584]|0;if(b){d=0;e=b&1;while(1){b=14163936+(d<<2)|0;f=c[b>>2]|0;g=c[2113006]|0;if((g|0)==0){h=27594}else{i=g-1|0;c[2113006]=i;if((i|0)==0){h=27594}}if((h|0)==27594){h=0;c[2383474]=0}if((f|0)==0){j=e}else{gGr(f);j=a[7452584]&1}c[b>>2]=0;b=d+1|0;if((b|0)<(j|0)){d=b;e=j}else{break}}}a[7452584]=0;c[2438224]=0;c[2433522]=0;c[2406672]=0;c[3528468]=0;j=c[2406688]|0;if((j|0)!=0){gGr(j);c[2406688]=0}c[2432972]=0;c[2113070]=0;c[2113068]=0;j=c[2112926]|0;if((j|0)!=0){gGr(j);c[2112926]=0}fvR();j=c[3541518]|0;if((j|0)!=0){gGr(j|0);c[3541518]=0}if((c[2385508]|0)>0){c[2113008]=0;c[2076598]=0;c[2383582]=0}c[2438228]=0;c[2433526]=0;c[2406676]=0;c[3528472]=0;j=c[2406680]|0;if((j|0)!=0){gGr(j);c[2406680]=0}c[2385508]=0;c[2432978]=0;a[64240]=0;j=c[2414854]|0;e=0;while(1){if((e|0)>=1024){h=27614;break}k=9638528+(e<<2)|0;if((c[k>>2]|0)==(j|0)){break}else{e=e+1|0}}if((h|0)==27614){c[2414854]=0;return 0}gGr(j);c[k>>2]=0;c[2414854]=0;return 0}function aGa(){var e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;if((a[9623400]|0)!=0){a[9623400]=0;e=c[2414556]|0;gGz(e|0,0,(c[2411456]|0)-e|0);c[3528554]=0;f43(c[2433592]|0);e=c[3528554]|0;c[2113158]=c[9731360+(e<<2)>>2];a[9660796]=0;a[9660797]=0;a[9660786]=0;a[9660787]=0;c[2415191]=0;a[9660784]=a[9660784]|80;f=c[2433592]|0;g=c[f+(e*3148|0)+1068>>2]|0;do{if((g|0)==0){i=c[f+(e*3148|0)+3120>>2]|0;if((i|0)==0){j=0;k=0;l=e;m=f;break}n=gj[i&4095](-2)|0;i=c[3528554]|0;o=c[2433592]|0;p=c[o+(i*3148|0)+1068>>2]|0;q=(n&255)<<8;if((p|0)!=0){r=p;s=q;t=i;u=o;v=27620;break}p=c[o+(i*3148|0)+3120>>2]|0;if((p|0)==0){j=0;k=q;l=i;m=o;break}o=gj[p&4095](-1)|0;j=o;k=q;l=c[3528554]|0;m=c[2433592]|0}else{r=g;s=d[g+254|0]<<8;t=e;u=f;v=27620}}while(0);if((v|0)==27620){j=a[r+255|0]|0;k=s;l=t;m=u}u=j&255|k;c[2415188]=u;b[4830376]=u&65535;u=m+(l*3148|0)|0;if((u|0)!=0){m=u;gGC(m|0,9660752,48)|0}c[9731360+(l<<2)>>2]=c[2113158];c[3528554]=-1;c[3528556]=0;l=c[2433594]|0;c[2443776]=l;L35298:do{if((l|0)!=0){m=l|0;gGC(9660952,m|0,52)|0;switch(a[9660952]|0){case 1:{c[2309668]=634096;break L35298;break};case 0:{c[2309668]=638960;break L35298;break};case 4:{c[2309668]=7356016;break L35298;break};case 5:{c[2309668]=7354992;break L35298;break};case 3:{c[2309668]=639984;break L35298;break};case 2:{c[2309668]=638960;break L35298;break};default:{break L35298}}}}while(0);c[2113164]=c[2432850];gu[c[l+56>>2]&16383]();l=c[2443776]|0;if((l|0)!=0){m=l|0;gGC(m|0,9660952,52)|0}c[9731400+(c[3528556]<<2)>>2]=c[2113164];c[2443776]=0;c[3528556]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){m=0;do{lN(m);mB(m);m=m+1|0;}while((m|0)<(c[2385508]|0))}c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;lw(c[3540984]|0);c[2440606]=0;c[2444190]=0}m=c[2113160]|0;if((m|0)>0){gGz(9731360,0,((m|0)>1?m<<2:4)|0)}c[2113158]=0;m=c[2113166]|0;if((m|0)>0){gGz(9731400,0,((m|0)>1?m<<2:4)|0)}c[2113164]=0;gGz(9550152,-1|0,5);m=0;l=-1;u=-1;k=-1;j=-1;t=-1;do{l=((a[9632392+m|0]&1)<<m^l&255)&255;u=((a[9630304+m|0]&1)<<m^u&255)&255;k=((a[9629184+m|0]&1)<<m^k&255)&255;j=((a[9629136+m|0]&1)<<m^j&255)&255;t=((a[9628864+m|0]&1)<<m^t&255)&255;m=m+1|0;}while((m|0)<8);a[9550152]=l;a[9550153]=u;a[9550154]=k;a[9550155]=j;a[9550156]=t;c[3528556]=0;t=c[2433594]|0;c[2443776]=t;L35325:do{if((t|0)!=0){j=t|0;gGC(9660952,j|0,52)|0;switch(a[9660952]|0){case 0:{c[2309668]=638960;break L35325;break};case 3:{c[2309668]=639984;break L35325;break};case 1:{c[2309668]=634096;break L35325;break};case 5:{c[2309668]=7354992;break L35325;break};case 2:{c[2309668]=638960;break L35325;break};case 4:{c[2309668]=7356016;break L35325;break};default:{break L35325}}}}while(0);c[2113164]=c[2432850];c[3528554]=0;f43(c[2433592]|0);c[2113158]=c[9731360+(c[3528554]<<2)>>2];c[2408976]=128;t=0;do{if((t|0)==1){c[2408976]=128}else if((t|0)==31){c[2408976]=0;f44(32);f45(0)|0;if((a[9660797]|0)!=0){a[9660797]=0}f45(0)|0}Sb(t*1077|0);UF(t*808|0)|0;t=t+1|0;}while((t|0)<32);t=c[2438228]|0;j=gGS(1283719168,16442,t,(t|0)<0|0?-1:0)|0;t=j;Sb(34482);j=c[2443830]|0;if((j|0)<1073676288){c[2443830]=j-t}j=c[2443831]|0;if((j|0)<1073676288){c[2443831]=j-t}j=(c[3528512]|0)-t|0;c[3528512]=(j|0)<0?0:j;j=c[2438224]|0;t=gGS(-160694272,12331,j,(j|0)<0|0?-1:0)|0;j=t;UF(25862)|0;t=c[2443826]|0;if((t|0)<1073676288){c[2443826]=t-j}t=c[2443827]|0;if((t|0)<1073676288){c[2443827]=t-j}t=(c[3528508]|0)-j|0;c[3528508]=(t|0)<0?0:t;t=c[2112964]|0;if((t|0)!=0){gg[c[3542122]&4095](t,a[9688]|0?534:0);gg[c[3542112]&4095](c[2112964]|0,a[9688]|0?534:0)}t=c[3528554]|0;j=(c[2433592]|0)+(t*3148|0)|0;if((j|0)!=0){k=j;gGC(k|0,9660752,48)|0}c[9731360+(t<<2)>>2]=c[2113158];c[3528554]=-1;t=c[2443776]|0;if((t|0)!=0){k=t|0;gGC(k|0,9660952,52)|0}c[9731400+(c[3528556]<<2)>>2]=c[2113164];c[2443776]=0;c[3528556]=-1;if((c[2112968]|0)==0){return 0}aGb()|0;return 0}function aGb(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((a[9547080]|0)!=0){b=c[2387100]|0;e=c[3529894]|0;f=0;do{g=a[b+f|0]|0;h=a[b+(f|1)|0]|0;i=(h&255)>>>4;c[e+(((f|0)/2|0)<<2)>>2]=((h&8|h<<4)&255)<<8&63488|((g&8|g<<4)&255)>>>3|((i<<4|i)&255)<<3&2016;f=f+2|0;}while((f|0)<512)}f=c[3529872]|0;a[f]=a[f]&-5;e=c[3529870]|0;b=e+1|0;a[b]=a[b]&-5;aHK(c[2387082]|0,f,c[3530384]|0,128,3,4095,0);aHL(3,1);aHK(c[2387076]|0,e,c[3530308]|0,192,3,4095,1);aHL(3,2);e=c[2386282]|0;f=c[2113070]|0;b=c[2112926]|0;i=c[3530752]|0;g=0;do{h=g<<3&248;j=g<<1;k=d[e+j|0]|0;l=k>>>5;m=k<<8&768|d[e+(j|1)|0];do{if((m|0)!=0){j=(g>>5<<3)-8|0;if(!((j|0)>-1&(j|0)<(f|0))){break}Sq(b,m,h,j,l,2,0,0,i)}}while(0);g=g+1|0;}while((g|0)<1024);R8(c[3529894]|0);return 0}function aGc(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;e=i;i=i+80|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;if((b&64|0)==0){aHx(b,d);i=e;return 0}l=k|0;if((c[2113160]|0)>0){m=k+7|0;k=j|0;n=j+4|0;o=j+12|0;p=h;q=h|0;r=h+4|0;s=h+12|0;t=g;u=g|0;v=g+4|0;w=g+12|0;x=f;y=f|0;z=f+4|0;A=f+12|0;B=0;do{C=c[2433592]|0;D=C+(B*3148|0)+40|0;E=c[D>>2]|0;gGC(l|0,614752,9)|0;a[m]=B+48&255;c[k>>2]=C+(B*3148|0);c[n>>2]=48;c[o>>2]=l;gj[c[2076592]&4095](j)|0;gGz(p|0,0,12);c[q>>2]=C+(B*3148|0)+3136;c[r>>2]=4;c[s>>2]=165288;gj[c[2076592]&4095](h)|0;gGz(t|0,0,12);c[u>>2]=C+(B*3148|0)+3140;c[v>>2]=4;c[w>>2]=501592;gj[c[2076592]&4095](g)|0;gGz(x|0,0,12);c[y>>2]=C+(B*3148|0)+3144;c[z>>2]=4;c[A>>2]=386080;gj[c[2076592]&4095](f)|0;c[D>>2]=E;B=B+1|0;}while((B|0)<(c[2113160]|0))}UQ(b,d);if((b&2|0)==0){aHx(b,d);i=e;return 0}c[3528554]=0;f43(c[2433592]|0);B=c[3528554]|0;f=9731360+(B<<2)|0;A=c[f>>2]|0;c[2113158]=A;z=c[3530266]|0;y=c[2433592]|0;x=(c[2406854]|0)+49152|0;g=64;w=64;while(1){v=z+(x+(w<<8))|0;c[y+(B*3148|0)+48+(w<<2)>>2]=v;c[y+(B*3148|0)+48+(w+512<<2)>>2]=v;v=g+1&65535;if((v&65535)>127){break}else{g=v;w=v&65535}}w=y+(B*3148|0)|0;if((w|0)!=0){B=w;gGC(B|0,9660752,48)|0}c[f>>2]=A;c[3528554]=-1;aHx(b,d);i=e;return 0}function aGd(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3009460+(b*112|0)>>2];c[a+104>>2]=c[3009464+(b*112|0)>>2];c[a+108>>2]=c[3009468+(b*112|0)>>2];d=0;return d|0}function aGe(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=3009360+(b*112|0);e=0;return e|0}function aGf(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1594076+(b*112|0)>>2];c[a+104>>2]=c[1594080+(b*112|0)>>2];c[a+108>>2]=c[1594084+(b*112|0)>>2];d=0;return d|0}function aGg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=1593976+(b*112|0);e=0;return e|0}function aGh(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1592172+(b*112|0)>>2];c[a+104>>2]=c[1592176+(b*112|0)>>2];c[a+108>>2]=c[1592180+(b*112|0)>>2];d=0;return d|0}function aGi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=1592072+(b*112|0);e=0;return e|0}function aGj(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=b&65535;switch(e|0){case 6150:{a[(c[3529872]|0)+17|0]=d;return};case 6149:{b=(d&255)>>>5<<14;c[2406854]=b;f=c[3530266]|0;g=c[3528554]|0;h=c[2433592]|0;i=b+49152|0;b=64;j=64;while(1){k=f+(i+(j<<8))|0;c[h+(g*3148|0)+48+(j<<2)>>2]=k;c[h+(g*3148|0)+48+(j+512<<2)>>2]=k;k=b+1&65535;if((k&65535)>127){break}else{b=k;j=k&65535}}a[(c[3529872]|0)+16|0]=d&1;return};case 6144:case 6145:{j=e&1;e=d&255;c[2440606]=0;if((j|0)==0){b=c[2444190]&255|e<<8;c[2444190]=b;l=b}else if((j|0)==1){j=c[2444190]&65280|e;c[2444190]=j;l=j}else{l=c[2444190]|0}do{if((l|0)==12395){c[2440606]=148;m=12395}else if((l|0)==12387){c[2440606]=156;m=12387}else if((l|0)==0){c[2440606]=0;c[2384380]=0;m=0}else{if((l&65280|0)==16384){c[2440606]=l}if((l|0)==20480){j=c[2384380]|0;c[2440606]=((j|0)/10|0)<<4|((j|0)%10|0);m=20480;break}else if((l|0)==24576){c[2444190]=-1;c[2384380]=(c[2384380]|0)-1;m=-1;break}else{m=l;break}}}while(0);do{if((a[9550156]&1)==0){if(!(a[600168]|0)){break}c[2384380]=(c[2384380]|0)+1;a[600168]=0}else{a[600168]=1}}while(0);switch(m|0){case 32770:{c[2440606]=62874;return};case 32778:{c[2440606]=62890;return};case 32768:{c[2440606]=62848;return};case 32772:{c[2440606]=62854;return};case 32771:{c[2440606]=62850;return};case 32774:{c[2440606]=62876;return};case 32777:{c[2440606]=62888;return};case 32769:{c[2440606]=62878;return};case 32773:{c[2440606]=62872;return};case 32775:{c[2440606]=62880;return};case 32776:{c[2440606]=62886;return};default:{return}}break};case 6146:{c[2444190]=0;return};case 8192:{a[c[3528212]|0]=d;gg[c[(c[2443776]|0)+64>>2]&4095](32,1);gj[c[(c[2443776]|0)+52>>2]&4095](0)|0;gg[c[(c[2443776]|0)+64>>2]&4095](32,0);gj[c[(c[2443776]|0)+52>>2]&4095](0)|0;return};case 8193:{a[c[3528652]|0]=d;return};case 6148:{d=c[2386556]|0;m=c[2386382]|0;gGC(d|0,m|0,512)|0;return};default:{return}}}function aGk(b){b=b|0;var d=0,e=0;d=b&65535;if((d|0)==14339){e=a[9634673]|0}else if((d|0)==14337){e=a[9550152]|0}else if((d|0)==14336){e=a[9634672]|0}else if((d|0)==14338){e=(a[9550153]&191|c[2408976])&255}else if((d|0)==8192){e=(c[2440606]|0)>>>8&255}else if((d|0)==8193){e=c[2440606]&255}else{e=0}return e|0}function aGl(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2228212+(b*112|0)>>2];c[a+104>>2]=c[2228216+(b*112|0)>>2];c[a+108>>2]=c[2228220+(b*112|0)>>2];d=0;return d|0}function aGm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=2228112+(b*112|0);e=0;return e|0}function aGn(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1188152+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aGo(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>33){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3383744+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aGp(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0;e=i;i=i+1440|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;B=e+1200|0;C=e+1312|0;D=e+1320|0;E=e+1432|0;c[2414854]=0;c[3530266]=0;c[2386358]=327680;c[3527436]=458752;c[3527440]=589824;c[3530752]=655360;c[3530516]=786432;c[3530384]=1835008;c[3530308]=2883584;c[3531056]=3932160;c[2407020]=3934208;c[3529894]=3938304;c[2414556]=3942400;c[3530268]=3942400;c[2386282]=3950592;c[2387082]=3952640;c[2387076]=3956736;c[3529872]=3960832;c[3529870]=3960864;c[2386744]=3960896;c[2386382]=3961920;c[2386556]=3963968;c[2387100]=3966016;c[3527438]=3968064;c[3528212]=3970112;c[3528482]=3970113;c[2432942]=3970114;c[3528652]=3970115;c[2411456]=3970116;F=0;while(1){if((F|0)>=1024){break}G=9638528+(F<<2)|0;if((c[G>>2]|0)==0){H=27832;break}else{F=F+1|0}}do{if((H|0)==27832){F=gGq(3970116)|0;c[G>>2]=F;if((F|0)==0){break}c[2414854]=F;gGz(F|0,0,3970116);c[3530266]=F;c[2386358]=F+327680;c[3527436]=F+458752;c[3527440]=F+589824;c[3530752]=F+655360;c[3530516]=F+786432;c[3530384]=F+1835008;c[3530308]=F+2883584;c[3531056]=F+3932160;c[2407020]=F+3934208;c[3529894]=F+3938304;I=F+3942400|0;c[2414556]=I;c[3530268]=I;c[2386282]=F+3950592;c[2387082]=F+3952640;c[2387076]=F+3956736;c[3529872]=F+3960832;c[3529870]=F+3960864;c[2386744]=F+3960896;c[2386382]=F+3961920;c[2386556]=F+3963968;c[2387100]=F+3966016;c[3527438]=F+3968064;c[3528212]=F+3970112;c[3528482]=F+3970113;c[2432942]=F+3970114;c[3528652]=F+3970115;I=F+3970116|0;c[2411456]=I;c[2413996]=I;I=F+131072|0;if((c[3542200]|0)==0){J=1;i=e;return J|0}F=D+108|0;c[F>>2]=0;K=D+100|0;c[K>>2]=0;L=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[L&16383](D,0)|0;do{if((c[F>>2]|0)!=0){L=c[K>>2]|0;c[E>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](E,0,0)|0;if((L|0)<1){J=1;i=e;return J|0}if((gzL(I,0,0)|0)==0){break}else{J=1}i=e;return J|0}}while(0);I=(c[3530266]|0)+65536|0;if((c[3542200]|0)==0){J=1;i=e;return J|0}K=B+108|0;c[K>>2]=0;F=B+100|0;c[F>>2]=0;L=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[L&16383](B,1)|0;do{if((c[K>>2]|0)!=0){L=c[F>>2]|0;c[C>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](C,1,0)|0;if((L|0)<1){J=1;i=e;return J|0}if((gzL(I,0,1)|0)==0){break}else{J=1}i=e;return J|0}}while(0);I=c[3530266]|0;F=I+32768|0;K=I+163840|0;gGC(F|0,K|0,32768)|0;K=(c[3527436]|0)+32768|0;if((c[3542200]|0)==0){J=1;i=e;return J|0}F=z+108|0;c[F>>2]=0;I=z+100|0;c[I>>2]=0;L=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[L&16383](z,2)|0;do{if((c[F>>2]|0)!=0){L=c[I>>2]|0;c[A>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](A,2,0)|0;if((L|0)<1){J=1;i=e;return J|0}if((gzL(K,0,2)|0)==0){break}else{J=1}i=e;return J|0}}while(0);K=c[3530752]|0;if((c[3542200]|0)==0){J=1;i=e;return J|0}I=x+108|0;c[I>>2]=0;F=x+100|0;c[F>>2]=0;L=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[L&16383](x,3)|0;do{if((c[I>>2]|0)!=0){L=c[F>>2]|0;c[y>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](y,3,0)|0;if((L|0)<1){J=1;i=e;return J|0}if((gzL(K,0,3)|0)==0){break}else{J=1}i=e;return J|0}}while(0);K=c[3530516]|0;if((c[3542200]|0)==0){J=1;i=e;return J|0}F=v+108|0;c[F>>2]=0;I=v+100|0;c[I>>2]=0;L=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[L&16383](v,4)|0;do{if((c[F>>2]|0)!=0){L=c[I>>2]|0;c[w>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](w,4,0)|0;if((L|0)<1){J=1;i=e;return J|0}if((gzL(K,0,4)|0)==0){break}else{J=1}i=e;return J|0}}while(0);K=(c[3530516]|0)+32768|0;if((c[3542200]|0)==0){J=1;i=e;return J|0}I=t+108|0;c[I>>2]=0;F=t+100|0;c[F>>2]=0;L=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[L&16383](t,5)|0;do{if((c[I>>2]|0)!=0){L=c[F>>2]|0;c[u>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](u,5,0)|0;if((L|0)<1){J=1;i=e;return J|0}if((gzL(K,0,5)|0)==0){break}else{J=1}i=e;return J|0}}while(0);K=(c[3530516]|0)+65536|0;if((c[3542200]|0)==0){J=1;i=e;return J|0}F=r+108|0;c[F>>2]=0;I=r+100|0;c[I>>2]=0;L=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[L&16383](r,6)|0;do{if((c[F>>2]|0)!=0){L=c[I>>2]|0;c[s>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](s,6,0)|0;if((L|0)<1){J=1;i=e;return J|0}if((gzL(K,0,6)|0)==0){break}else{J=1}i=e;return J|0}}while(0);K=(c[3530516]|0)+98304|0;if((c[3542200]|0)==0){J=1;i=e;return J|0}I=p+108|0;c[I>>2]=0;F=p+100|0;c[F>>2]=0;L=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[L&16383](p,7)|0;do{if((c[I>>2]|0)!=0){L=c[F>>2]|0;c[q>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](q,7,0)|0;if((L|0)<1){J=1;i=e;return J|0}if((gzL(K,0,7)|0)==0){break}else{J=1}i=e;return J|0}}while(0);K=(c[3530516]|0)+131072|0;if((c[3542200]|0)==0){J=1;i=e;return J|0}F=n+108|0;c[F>>2]=0;I=n+100|0;c[I>>2]=0;L=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[L&16383](n,8)|0;do{if((c[F>>2]|0)!=0){L=c[I>>2]|0;c[o>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](o,8,0)|0;if((L|0)<1){J=1;i=e;return J|0}if((gzL(K,0,8)|0)==0){break}else{J=1}i=e;return J|0}}while(0);K=(c[3530516]|0)+163840|0;if((c[3542200]|0)==0){J=1;i=e;return J|0}I=l+108|0;c[I>>2]=0;F=l+100|0;c[F>>2]=0;L=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[L&16383](l,9)|0;do{if((c[I>>2]|0)!=0){L=c[F>>2]|0;c[m>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](m,9,0)|0;if((L|0)<1){J=1;i=e;return J|0}if((gzL(K,0,9)|0)==0){break}else{J=1}i=e;return J|0}}while(0);K=c[3530308]|0;if((c[3542200]|0)==0){J=1;i=e;return J|0}F=j+108|0;c[F>>2]=0;I=j+100|0;c[I>>2]=0;L=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[L&16383](j,10)|0;do{if((c[F>>2]|0)!=0){L=c[I>>2]|0;c[k>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](k,10,0)|0;if((L|0)<1){J=1;i=e;return J|0}if((gzL(K,0,10)|0)==0){break}else{J=1}i=e;return J|0}}while(0);K=c[3530384]|0;I=c[3530308]|0;gGC(K|0,I|0,16384)|0;F=K+65536|0;L=I+16384|0;gGC(F|0,L|0,16384)|0;L=K+131072|0;F=I+32768|0;gGC(L|0,F|0,16384)|0;F=K+196608|0;K=I+49152|0;gGC(F|0,K|0,16384)|0;if((c[3542200]|0)==0){J=1;i=e;return J|0}K=f+108|0;c[K>>2]=0;F=f+100|0;c[F>>2]=0;L=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[L&16383](f,11)|0;do{if((c[K>>2]|0)!=0){L=c[F>>2]|0;c[g>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](g,11,0)|0;if((L|0)<1){J=1;i=e;return J|0}if((gzL(I,0,11)|0)==0){break}else{J=1}i=e;return J|0}}while(0);I=c[3530384]|0;F=I+16384|0;K=c[3530308]|0;gGC(F|0,K|0,16384)|0;F=I+81920|0;L=K+16384|0;gGC(F|0,L|0,16384)|0;L=I+147456|0;F=K+32768|0;gGC(L|0,F|0,16384)|0;F=I+212992|0;I=K+49152|0;gGC(F|0,I|0,16384)|0;I=c[3527440]|0;F=I+32768|0;K=c[3527436]|0;L=K+32768|0;gGC(F|0,L|0,32768)|0;M=a[L]|0;a[F]=M<<1&64|M&-97|(M&255)>>>1&32;M=32769;while(1){F=a[K+M|0]|0;a[I+M|0]=F<<1&64|F&-97|(F&255)>>>1&32;F=M+1|0;if((F|0)<65536){M=F}else{N=0;break}}while(1){if((N|0)>=1024){break}O=9638528+(N<<2)|0;if((c[O>>2]|0)==0){H=27886;break}else{N=N+1|0}}L35676:do{if((H|0)==27886){M=gGq(524288)|0;c[O>>2]=M;if((M|0)==0){break}gGz(M|0,0,524288);I=c[3530752]|0;gGC(M|0,I|0,32768)|0;K=0;do{F=K<<6;gGz(I+F|0,0,64);L=0;do{P=F+(c[609008+(L<<2)>>2]|0)|0;Q=(L<<3)+F|0;R=0;do{S=P+(c[598232+(R<<2)>>2]|0)|0;if((d[M+((S|0)/8|0)|0]&128>>>((S&7)>>>0)|0)!=0){S=I+(Q+R)|0;a[S]=a[S]|2}R=R+1|0;}while((R|0)<8);L=L+1|0;}while((L|0)<8);L=F|4;R=0;do{Q=L+(c[609008+(R<<2)>>2]|0)|0;P=(R<<3)+F|0;S=0;do{T=Q+(c[598232+(S<<2)>>2]|0)|0;if((d[M+((T|0)/8|0)|0]&128>>>((T&7)>>>0)|0)!=0){T=I+(P+S)|0;a[T]=a[T]|1}S=S+1|0;}while((S|0)<8);R=R+1|0;}while((R|0)<8);K=K+1|0;}while((K|0)<1024);K=c[3530516]|0;gGC(M|0,K|0,524288)|0;I=0;do{R=I<<8;gGz(K+R|0,0,256);F=R+524288|0;L=0;do{S=F+(c[609008+(L<<2)>>2]|0)|0;P=(L<<4)+R|0;Q=0;do{T=S+(c[612640+(Q<<2)>>2]|0)|0;if((d[M+((T|0)/8|0)|0]&128>>>((T&7)>>>0)|0)!=0){T=K+(P+Q)|0;a[T]=a[T]|4}Q=Q+1|0;}while((Q|0)<16);L=L+1|0;}while((L|0)<16);L=R+1048576|0;F=0;while(1){Q=L+(c[609008+(F<<2)>>2]|0)|0;P=(F<<4)+R|0;S=0;do{T=Q+(c[612640+(S<<2)>>2]|0)|0;if((d[M+((T|0)/8|0)|0]&128>>>((T&7)>>>0)|0)!=0){T=K+(P+S)|0;a[T]=a[T]|2}S=S+1|0;}while((S|0)<16);S=F+1|0;if((S|0)<16){F=S}else{U=0;break}}do{F=R+(c[609008+(U<<2)>>2]|0)|0;L=(U<<4)+R|0;S=0;do{P=F+(c[612640+(S<<2)>>2]|0)|0;if((d[M+((P|0)/8|0)|0]&128>>>((P&7)>>>0)|0)!=0){P=K+(L+S)|0;a[P]=a[P]|1}S=S+1|0;}while((S|0)<16);U=U+1|0;}while((U|0)<16);I=I+1|0;}while((I|0)<2048);I=c[3530384]|0;gGC(M|0,I|0,32768)|0;K=0;do{R=K<<8;gGz(I+R|0,0,256);S=0;do{L=1<<3-S;F=(c[598264+(S<<2)>>2]|0)+R|0;P=0;do{Q=F+(c[609008+(P<<2)>>2]|0)|0;T=(P<<4)+R|0;V=0;do{W=Q+(c[598168+(V<<2)>>2]|0)|0;if((d[M+((W|0)/8|0)|0]&128>>>((W&7)>>>0)|0)!=0){W=I+(T+V)|0;a[W]=(d[W]|L)&255}V=V+1|0;}while((V|0)<16);P=P+1|0;}while((P|0)<16);S=S+1|0;}while((S|0)<4);K=K+1|0;}while((K|0)<256);K=I+65536|0;gGC(M|0,K|0,32768)|0;K=0;do{S=K<<8;R=S+65536|0;gGz(I+R|0,0,256);P=0;do{L=1<<3-P;F=(c[598264+(P<<2)>>2]|0)+S|0;V=0;do{T=F+(c[609008+(V<<2)>>2]|0)|0;Q=R+(V<<4)|0;W=0;do{X=T+(c[598168+(W<<2)>>2]|0)|0;if((d[M+((X|0)/8|0)|0]&128>>>((X&7)>>>0)|0)!=0){X=I+(Q+W)|0;a[X]=(d[X]|L)&255}W=W+1|0;}while((W|0)<16);V=V+1|0;}while((V|0)<16);P=P+1|0;}while((P|0)<4);K=K+1|0;}while((K|0)<256);K=I+131072|0;gGC(M|0,K|0,32768)|0;K=0;do{P=K<<8;R=P+131072|0;gGz(I+R|0,0,256);S=0;do{V=1<<3-S;L=(c[598264+(S<<2)>>2]|0)+P|0;F=0;do{W=L+(c[609008+(F<<2)>>2]|0)|0;Q=R+(F<<4)|0;T=0;do{X=W+(c[598168+(T<<2)>>2]|0)|0;if((d[M+((X|0)/8|0)|0]&128>>>((X&7)>>>0)|0)!=0){X=I+(Q+T)|0;a[X]=(d[X]|V)&255}T=T+1|0;}while((T|0)<16);F=F+1|0;}while((F|0)<16);S=S+1|0;}while((S|0)<4);K=K+1|0;}while((K|0)<256);K=I+196608|0;gGC(M|0,K|0,32768)|0;K=0;while(1){S=K<<8;R=S+196608|0;gGz(I+R|0,0,256);P=0;do{F=1<<3-P;V=(c[598264+(P<<2)>>2]|0)+S|0;L=0;do{T=V+(c[609008+(L<<2)>>2]|0)|0;Q=R+(L<<4)|0;W=0;do{X=T+(c[598168+(W<<2)>>2]|0)|0;if((d[M+((X|0)/8|0)|0]&128>>>((X&7)>>>0)|0)!=0){X=I+(Q+W)|0;a[X]=(d[X]|F)&255}W=W+1|0;}while((W|0)<16);L=L+1|0;}while((L|0)<16);P=P+1|0;}while((P|0)<4);P=K+1|0;if((P|0)<256){K=P}else{Y=0;break}}while(1){if((Y|0)>=1024){break L35676}Z=9638528+(Y<<2)|0;if((c[Z>>2]|0)==(M|0)){break}else{Y=Y+1|0}}gGr(M);c[Z>>2]=0}}while(0);c[3528554]=-1;c[2113160]=1;K=gGq(3148)|0;I=K;c[2433592]=I;if((K|0)!=0){gGz(K|0,0,3148);c[K+3120>>2]=3128;c[K+3124>>2]=1840;c[K+3128>>2]=136;c[K+3132>>2]=1902;c[2432840]=0;P=0;do{c[I+48+(P<<2)>>2]=0;P=P+1|0;}while((P|0)<768);c[2113158]=0;c[2415198]=0;P=c[2427044]|0;c[9681616+(P<<3)>>2]=809272;c[9681620+(P<<3)>>2]=0;c[2427044]=P+1}c[3528554]=0;f43(K);P=c[3528554]|0;I=9731360+(P<<2)|0;R=c[I>>2]|0;c[2113158]=R;S=c[3530268]|0;L=c[2433592]|0;c[L+(P*3148|0)+48>>2]=S;c[L+(P*3148|0)+1072>>2]=S;c[L+(P*3148|0)+2096>>2]=S;F=S+256|0;c[L+(P*3148|0)+52>>2]=F;c[L+(P*3148|0)+1076>>2]=F;c[L+(P*3148|0)+2100>>2]=F;F=S+512|0;c[L+(P*3148|0)+56>>2]=F;c[L+(P*3148|0)+1080>>2]=F;c[L+(P*3148|0)+2104>>2]=F;F=S+768|0;c[L+(P*3148|0)+60>>2]=F;c[L+(P*3148|0)+1084>>2]=F;c[L+(P*3148|0)+2108>>2]=F;F=S+1024|0;c[L+(P*3148|0)+64>>2]=F;c[L+(P*3148|0)+1088>>2]=F;c[L+(P*3148|0)+2112>>2]=F;F=S+1280|0;c[L+(P*3148|0)+68>>2]=F;c[L+(P*3148|0)+1092>>2]=F;c[L+(P*3148|0)+2116>>2]=F;F=c[2386382]|0;c[L+(P*3148|0)+72>>2]=F;c[L+(P*3148|0)+1096>>2]=F;c[L+(P*3148|0)+2120>>2]=F;V=F+256|0;c[L+(P*3148|0)+76>>2]=V;c[L+(P*3148|0)+1100>>2]=V;c[L+(P*3148|0)+2124>>2]=V;V=c[2386282]|0;c[L+(P*3148|0)+80>>2]=V;c[L+(P*3148|0)+1104>>2]=V;c[L+(P*3148|0)+2128>>2]=V;F=V+256|0;c[L+(P*3148|0)+84>>2]=F;c[L+(P*3148|0)+1108>>2]=F;c[L+(P*3148|0)+2132>>2]=F;F=V+512|0;c[L+(P*3148|0)+88>>2]=F;c[L+(P*3148|0)+1112>>2]=F;c[L+(P*3148|0)+2136>>2]=F;F=V+768|0;c[L+(P*3148|0)+92>>2]=F;c[L+(P*3148|0)+1116>>2]=F;c[L+(P*3148|0)+2140>>2]=F;F=V+1024|0;c[L+(P*3148|0)+96>>2]=F;c[L+(P*3148|0)+1120>>2]=F;c[L+(P*3148|0)+2144>>2]=F;F=V+1280|0;c[L+(P*3148|0)+100>>2]=F;c[L+(P*3148|0)+1124>>2]=F;c[L+(P*3148|0)+2148>>2]=F;F=V+1536|0;c[L+(P*3148|0)+104>>2]=F;c[L+(P*3148|0)+1128>>2]=F;c[L+(P*3148|0)+2152>>2]=F;F=V+1792|0;c[L+(P*3148|0)+108>>2]=F;c[L+(P*3148|0)+1132>>2]=F;c[L+(P*3148|0)+2156>>2]=F;F=S+4096|0;c[L+(P*3148|0)+112>>2]=F;c[L+(P*3148|0)+1136>>2]=F;c[L+(P*3148|0)+2160>>2]=F;F=S+4352|0;c[L+(P*3148|0)+116>>2]=F;c[L+(P*3148|0)+1140>>2]=F;c[L+(P*3148|0)+2164>>2]=F;F=S+4608|0;c[L+(P*3148|0)+120>>2]=F;c[L+(P*3148|0)+1144>>2]=F;c[L+(P*3148|0)+2168>>2]=F;F=S+4864|0;c[L+(P*3148|0)+124>>2]=F;c[L+(P*3148|0)+1148>>2]=F;c[L+(P*3148|0)+2172>>2]=F;F=c[2387082]|0;c[L+(P*3148|0)+128>>2]=F;c[L+(P*3148|0)+1152>>2]=F;c[L+(P*3148|0)+2176>>2]=F;S=F+256|0;c[L+(P*3148|0)+132>>2]=S;c[L+(P*3148|0)+1156>>2]=S;c[L+(P*3148|0)+2180>>2]=S;S=F+512|0;c[L+(P*3148|0)+136>>2]=S;c[L+(P*3148|0)+1160>>2]=S;c[L+(P*3148|0)+2184>>2]=S;S=F+768|0;c[L+(P*3148|0)+140>>2]=S;c[L+(P*3148|0)+1164>>2]=S;c[L+(P*3148|0)+2188>>2]=S;S=c[2387100]|0;c[L+(P*3148|0)+208>>2]=S;c[L+(P*3148|0)+1232>>2]=S;c[L+(P*3148|0)+2256>>2]=S;F=S+256|0;c[L+(P*3148|0)+240>>2]=F;c[L+(P*3148|0)+1264>>2]=F;c[L+(P*3148|0)+2288>>2]=F;F=c[3530266]|0;S=64;V=64;while(1){W=F+((V<<8)+49152)|0;c[L+(P*3148|0)+48+(V<<2)>>2]=W;c[L+(P*3148|0)+48+(V+512<<2)>>2]=W;W=S+1&65535;if((W&65535)>127){_=128;$=128;break}else{S=W;V=W&65535}}while(1){V=F+($<<8)|0;c[L+(P*3148|0)+48+($<<2)>>2]=V;c[L+(P*3148|0)+48+($+512<<2)>>2]=V;V=_+1&65535;if((V&65535)>255){break}else{_=V;$=V&65535}}c[L+(P*3148|0)+3124>>2]=2978;c[L+(P*3148|0)+3120>>2]=3202;F=L+(P*3148|0)|0;if((F|0)!=0){V=F;gGC(V|0,9660752,48)|0}c[I>>2]=R;c[3528554]=-1;fvI();c[3528556]=0;V=c[2433594]|0;c[2443776]=V;L35807:do{if((V|0)!=0){F=V|0;gGC(9660952,F|0,52)|0;switch(a[9660952]|0){case 4:{c[2309668]=7356016;break L35807;break};case 5:{c[2309668]=7354992;break L35807;break};case 2:{c[2309668]=638960;break L35807;break};case 0:{c[2309668]=638960;break L35807;break};case 1:{c[2309668]=634096;break L35807;break};case 3:{c[2309668]=639984;break L35807;break};default:{break L35807}}}}while(0);R=c[2432850]|0;c[2113164]=R;I=c[3527438]|0;c[V+68>>2]=I;c[V+1092>>2]=I;c[V+2116>>2]=I;P=I+256|0;c[V+72>>2]=P;c[V+1096>>2]=P;c[V+2120>>2]=P;P=I+512|0;c[V+76>>2]=P;c[V+1100>>2]=P;c[V+2124>>2]=P;P=I+768|0;c[V+80>>2]=P;c[V+1104>>2]=P;c[V+2128>>2]=P;P=I+1024|0;c[V+84>>2]=P;c[V+1108>>2]=P;c[V+2132>>2]=P;P=I+1280|0;c[V+88>>2]=P;c[V+1112>>2]=P;c[V+2136>>2]=P;P=c[3527436]|0;I=128;L=128;while(1){c[V+68+(L<<2)>>2]=P+(L<<8);F=I+1&65535;if((F&65535)>255){break}else{I=F;L=F&65535}}L=c[3527440]|0;I=128;P=128;while(1){c[V+68+(P+512<<2)>>2]=L+(P<<8);F=I+1&65535;if((F&65535)>255){break}else{I=F;P=F&65535}}c[V+3148>>2]=406;c[V+3152>>2]=1392;P=V|0;gGC(P|0,9660952,52)|0;c[2432850]=R;c[2443776]=0;c[3528556]=-1;c[2424]=5800;Vr(1,15e5,0,644,128,0);c[2438228]=2e6;c[2433526]=3068;c[2406676]=206;c[3528472]=4026;c[2443846]=1023;h[745419]=.2;a[3203368]=1;h[745418]=.23;a[3203360]=1;h[745417]=.23;a[3203352]=1;h[745416]=.23;a[3203344]=1;UL(3e6,1494,2124,1);c[2438224]=15e5;c[2433522]=3258;c[2406672]=2016;c[3528468]=6844;c[2443842]=1364;h[745398]=.7;a[3203264]=1;P=c[642608+(c[2436]<<2)>>2]|0;I=c[P+128>>2]|0;if((c[P+52>>2]&4|0)==0){c[2113068]=I;L=c[P+132>>2]|0;c[2113070]=L;c[2443814]=I;c[2440436]=L;aa=I;ab=L}else{c[2113070]=I;L=c[P+132>>2]|0;c[2113068]=L;c[2440436]=I;c[2443814]=L;aa=L;ab=I}I=ag(aa<<1,ab)|0;L=gGq(I)|0;c[2112926]=L;if((L|0)!=0){gGz(L|0,0,I|0)}a[9623400]=0;I=c[2414556]|0;gGz(I|0,0,(c[2411456]|0)-I|0);c[3528554]=0;f43(c[2433592]|0);I=c[3528554]|0;c[2113158]=c[9731360+(I<<2)>>2];a[9660796]=0;a[9660797]=0;a[9660786]=0;a[9660787]=0;c[2415191]=0;a[9660784]=a[9660784]|80;L=c[2433592]|0;P=c[L+(I*3148|0)+1068>>2]|0;do{if((P|0)==0){F=c[L+(I*3148|0)+3120>>2]|0;if((F|0)==0){ac=0;ad=0;ae=I;af=L;break}S=gj[F&4095](-2)|0;F=c[3528554]|0;K=c[2433592]|0;W=c[K+(F*3148|0)+1068>>2]|0;Q=(S&255)<<8;if((W|0)!=0){ah=W;ai=Q;aj=F;ak=K;H=27976;break}W=c[K+(F*3148|0)+3120>>2]|0;if((W|0)==0){ac=0;ad=Q;ae=F;af=K;break}K=gj[W&4095](-1)|0;ac=K;ad=Q;ae=c[3528554]|0;af=c[2433592]|0}else{ah=P;ai=d[P+254|0]<<8;aj=I;ak=L;H=27976}}while(0);if((H|0)==27976){ac=a[ah+255|0]|0;ad=ai;ae=aj;af=ak}L=ac&255|ad;c[2415188]=L;b[4830376]=L&65535;L=af+(ae*3148|0)|0;if((L|0)!=0){I=L;gGC(I|0,9660752,48)|0}c[9731360+(ae<<2)>>2]=c[2113158];c[3528554]=-1;c[3528556]=0;I=c[2433594]|0;c[2443776]=I;L35842:do{if((I|0)!=0){L=I|0;gGC(9660952,L|0,52)|0;switch(a[9660952]|0){case 1:{c[2309668]=634096;break L35842;break};case 3:{c[2309668]=639984;break L35842;break};case 4:{c[2309668]=7356016;break L35842;break};case 5:{c[2309668]=7354992;break L35842;break};case 2:{c[2309668]=638960;break L35842;break};case 0:{c[2309668]=638960;break L35842;break};default:{break L35842}}}}while(0);c[2113164]=c[2432850];gu[c[I+56>>2]&16383]();L=c[2443776]|0;if((L|0)!=0){P=L|0;gGC(P|0,9660952,52)|0}c[9731400+(c[3528556]<<2)>>2]=c[2113164];c[2443776]=0;c[3528556]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){P=0;do{lN(P);mB(P);P=P+1|0;}while((P|0)<(c[2385508]|0))}c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;lw(c[3540984]|0);c[2440606]=0;c[2444190]=0;J=0;i=e;return J|0}}while(0);c[2414854]=0;J=1;i=e;return J|0}function aGq(){var e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;if((a[9623400]|0)!=0){a[9623400]=0;e=c[2414556]|0;gGz(e|0,0,(c[2411456]|0)-e|0);c[3528554]=0;f43(c[2433592]|0);e=c[3528554]|0;c[2113158]=c[9731360+(e<<2)>>2];a[9660796]=0;a[9660797]=0;a[9660786]=0;a[9660787]=0;c[2415191]=0;a[9660784]=a[9660784]|80;f=c[2433592]|0;g=c[f+(e*3148|0)+1068>>2]|0;do{if((g|0)==0){i=c[f+(e*3148|0)+3120>>2]|0;if((i|0)==0){j=0;k=0;l=e;m=f;break}n=gj[i&4095](-2)|0;i=c[3528554]|0;o=c[2433592]|0;p=c[o+(i*3148|0)+1068>>2]|0;q=(n&255)<<8;if((p|0)!=0){r=p;s=q;t=i;u=o;v=28055;break}p=c[o+(i*3148|0)+3120>>2]|0;if((p|0)==0){j=0;k=q;l=i;m=o;break}o=gj[p&4095](-1)|0;j=o;k=q;l=c[3528554]|0;m=c[2433592]|0}else{r=g;s=d[g+254|0]<<8;t=e;u=f;v=28055}}while(0);if((v|0)==28055){j=a[r+255|0]|0;k=s;l=t;m=u}u=j&255|k;c[2415188]=u;b[4830376]=u&65535;u=m+(l*3148|0)|0;if((u|0)!=0){m=u;gGC(m|0,9660752,48)|0}c[9731360+(l<<2)>>2]=c[2113158];c[3528554]=-1;c[3528556]=0;l=c[2433594]|0;c[2443776]=l;L35877:do{if((l|0)!=0){m=l|0;gGC(9660952,m|0,52)|0;switch(a[9660952]|0){case 4:{c[2309668]=7356016;break L35877;break};case 1:{c[2309668]=634096;break L35877;break};case 3:{c[2309668]=639984;break L35877;break};case 5:{c[2309668]=7354992;break L35877;break};case 2:{c[2309668]=638960;break L35877;break};case 0:{c[2309668]=638960;break L35877;break};default:{break L35877}}}}while(0);c[2113164]=c[2432850];gu[c[l+56>>2]&16383]();l=c[2443776]|0;if((l|0)!=0){m=l|0;gGC(m|0,9660952,52)|0}c[9731400+(c[3528556]<<2)>>2]=c[2113164];c[2443776]=0;c[3528556]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){m=0;do{lN(m);mB(m);m=m+1|0;}while((m|0)<(c[2385508]|0))}c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;lw(c[3540984]|0);c[2440606]=0;c[2444190]=0}m=c[2113160]|0;if((m|0)>0){gGz(9731360,0,((m|0)>1?m<<2:4)|0)}c[2113158]=0;m=c[2113166]|0;if((m|0)>0){gGz(9731400,0,((m|0)>1?m<<2:4)|0)}c[2113164]=0;c[2387538]=-1;m=0;l=-1;u=-1;do{l=((a[9632392+m|0]&1)<<m^l&255)&255;u=((a[9630304+m|0]&1)<<m^u&255)&255;m=m+1|0;}while((m|0)<8);a[9550152]=l;a[9550153]=u;a[9550156]=a[9628864]&1;c[3528556]=0;u=c[2433594]|0;c[2443776]=u;L35904:do{if((u|0)!=0){l=u|0;gGC(9660952,l|0,52)|0;switch(a[9660952]|0){case 0:{c[2309668]=638960;break L35904;break};case 1:{c[2309668]=634096;break L35904;break};case 3:{c[2309668]=639984;break L35904;break};case 4:{c[2309668]=7356016;break L35904;break};case 5:{c[2309668]=7354992;break L35904;break};case 2:{c[2309668]=638960;break L35904;break};default:{break L35904}}}}while(0);c[2113164]=c[2432850];c[3528554]=0;f43(c[2433592]|0);c[2113158]=c[9731360+(c[3528554]<<2)>>2];c[2408976]=64;u=0;do{if((u|0)==1){c[2408976]=64}else if((u|0)==31){c[2408976]=0;f44(32);f45(0)|0;if((a[9660797]|0)!=0){a[9660797]=0}f45(0)|0}Sb(u*1077|0);UF(u*808|0)|0;u=u+1|0;}while((u|0)<32);u=c[2438228]|0;l=gGS(1283719168,16442,u,(u|0)<0|0?-1:0)|0;u=l;Sb(34482);l=c[2443830]|0;if((l|0)<1073676288){c[2443830]=l-u}l=c[2443831]|0;if((l|0)<1073676288){c[2443831]=l-u}l=(c[3528512]|0)-u|0;c[3528512]=(l|0)<0?0:l;l=c[2438224]|0;u=gGS(-160694272,12331,l,(l|0)<0|0?-1:0)|0;l=u;UF(25862)|0;u=c[2443826]|0;if((u|0)<1073676288){c[2443826]=u-l}u=c[2443827]|0;if((u|0)<1073676288){c[2443827]=u-l}u=(c[3528508]|0)-l|0;c[3528508]=(u|0)<0?0:u;u=c[2112964]|0;if((u|0)!=0){gg[c[3542122]&4095](u,a[9688]|0?534:0);gg[c[3542112]&4095](c[2112964]|0,a[9688]|0?534:0)}u=c[3528554]|0;l=(c[2433592]|0)+(u*3148|0)|0;if((l|0)!=0){m=l;gGC(m|0,9660752,48)|0}c[9731360+(u<<2)>>2]=c[2113158];c[3528554]=-1;u=c[2443776]|0;if((u|0)!=0){m=u|0;gGC(m|0,9660952,52)|0}c[9731400+(c[3528556]<<2)>>2]=c[2113164];c[2443776]=0;c[3528556]=-1;if((c[2112968]|0)==0){return 0}aGr()|0;return 0}function aGr(){var b=0,e=0,f=0,g=0,h=0,i=0;if((a[9547080]|0)!=0){b=c[2387100]|0;e=c[3529894]|0;f=0;do{g=a[b+f|0]|0;h=a[b+(f+256)|0]|0;i=(g&255)>>>4;c[e+(f<<2)>>2]=((h&8|h<<4)&255)>>>3|((g&8|g<<4)&255)<<8&63488|((i<<4|i)&255)<<3&2016;f=f+1|0;}while((f|0)<256)}aHR(1);aHS(0);aHR(0);aHS(1);f=c[2113070]|0;e=c[2386282]|0;b=c[2112926]|0;i=c[3530752]|0;g=0;do{h=(g>>5<<3)-8|0;if((h|0)>-1&(h|0)<(f|0)){Sq(b,d[e+g|0]|0,g<<3&248,h,0,2,0,128,i)}g=g+1|0;}while((g|0)<1024);R8(c[3529894]|0);return 0}function aGs(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2226644+(b*112|0)>>2];c[a+104>>2]=c[2226648+(b*112|0)>>2];c[a+108>>2]=c[2226652+(b*112|0)>>2];d=0;return d|0}function aGt(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=2226544+(b*112|0);e=0;return e|0}function aGu(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=b&65535;switch(e|0){case 14392:case 14393:{b=e&1;c[2440606]=0;f=a[9550156]^-4;if((b|0)==0){c[2444190]=c[2444190]&255|(d&255)<<8}else if((b|0)==1){c[2444190]=c[2444190]&65280|d&255}g=f&255;if((g&3|0)==3){a[595608]=1;h=1}else{h=a[595608]|0}do{if((g&1|0)==0&h){c[2384312]=(c[2384312]|0)+1;a[595608]=0}else{if(!((g&2|0)==0&h)){break}c[2384310]=(c[2384310]|0)+1;a[595608]=0}}while(0);h=c[2444190]|0;if(h>>>0<256){c[2440606]=0;c[2384310]=0;c[2384312]=0}g=h&-256;if((g|0)==256){c[2440606]=1434;return}else if((g|0)==1024){c[2440606]=h;return}else if((g|0)==1280){h=c[2384312]|0;c[2440606]=((h|0)/10|0)<<4|((h|0)%10|0);return}else{h=c[2384312]|0;if(!((g|0)==1536&(h|0)!=0&(b|0)==0)){return}c[2440606]=1536;c[2384312]=h-1;return}break};case 14376:{h=c[3529872]|0;a[h+16|0]=d&1;a[h+18|0]=(d&255)>>>1&1;return};case 14384:{h=(d&255)>>>4<<14;c[2406854]=h;b=c[3530266]|0;g=c[3528552]|0;f=c[2433426]|0;i=h+49152|0;h=64;j=64;while(1){k=b+(i+(j<<8))|0;c[f+(g*3160|0)+60+(j<<2)>>2]=k;c[f+(g*3160|0)+60+(j+512<<2)>>2]=k;k=h+1&65535;if((k&65535)>127){break}else{h=k;j=k&65535}}a[c[2432942]|0]=d&1;a[c[3528482]|0]=d&2;a[c[3528652]|0]=d&8;return};case 14360:{a[(c[3529872]|0)+17|0]=d;return};case 14352:{a[c[3528212]|0]=d;gg[c[(c[2443776]|0)+64>>2]&4095](32,1);gj[c[(c[2443776]|0)+52>>2]&4095](0)|0;gg[c[(c[2443776]|0)+64>>2]&4095](32,0);gj[c[(c[2443776]|0)+52>>2]&4095](0)|0;return};case 14394:case 14395:{j=e&1;c[2440606]=0;e=a[9550156]^-4;do{if((j|0)==1){c[2444190]=c[2444190]&65280|d&255}else if((j|0)==0){c[2444190]=c[2444190]&255|(d&255)<<8;if((a[c[2432942]|0]|0)==0){break}a[9642747]=1;fC1();fC4(0)|0;a[9642747]=0;fC4(0)|0}}while(0);h=e&255;if((h&3|0)==3){a[598072]=1;l=1}else{l=a[598072]|0}do{if((h&1|0)==0&l){c[2384364]=(c[2384364]|0)+1;a[598080]=1;a[598072]=0}else{if(!((h&2|0)==0&l)){break}c[2384362]=(c[2384362]|0)+1;a[598080]=1;a[598072]=0}}while(0);l=c[2444190]|0;do{if((l|0)==907){c[2440606]=884;return}else if((l|0)==0){c[2440606]=0;a[598080]=0;c[2384362]=0;c[2384364]=0;m=28174}else if((l|0)==906){c[2440606]=885;m=28174}else{h=l&-256;if((h|0)!=1024){n=h;break}c[2440606]=1039;return}}while(0);if((m|0)==28174){n=l&-256}l=c[2384364]|0;if((n|0)==1280){c[2440606]=(l|0)%10|0|((l|0)/10|0)<<4|1280;return}m=(j|0)==0;if((n|0)==1536&(l|0)!=0&m){c[2440606]=1536;c[2384364]=l-1}l=c[2384362]|0;if((n|0)==1792){c[2440606]=(l|0)%10|0|((l|0)/10|0)<<4|1792;return}if((n|0)==2048&(l|0)!=0&m){c[2440606]=2048;c[2384362]=l-1}if((n|0)!=2560){return}n=a[598080]|0;c[2440606]=n&1|2560;if(!n){return}a[598080]=0;return};case 14368:{a[(c[3529872]|0)+19|0]=d;return};default:{return}}}function aGv(b){b=b|0;var d=0;switch(b&65535|0){case 14351:{d=a[9550154]|0;break};case 14393:{d=c[2440606]&255;break};case 14350:{d=(a[9550155]&127|c[2408976])&255;break};case 14336:{d=a[9634672]|0;break};case 14337:{d=a[9634673]|0;break};case 14347:{d=127;break};case 14349:{d=127;break};case 14392:{d=(c[2440606]|0)>>>8&255;break};case 14346:case 14348:{d=-1;break};default:{d=0}}return d|0}function aGw(b){b=b|0;var d=0;switch(b&65535|0){case 14337:{d=a[9634673]|0;break};case 14346:{d=(a[9550153]&127|c[2408976])&255;break};case 14394:{d=(c[2440606]|0)>>>8&255;break};case 14336:{d=a[9634672]|0;break};case 14395:{d=c[2440606]&255;break};case 14347:{d=a[9550152]|0;break};default:{d=0}}return d|0}function aGx(b,e){b=b|0;e=e|0;var f=0,g=0;f=b&65535;if((f|0)==4096|(f|0)==4097|(f|0)==16384|(f|0)==16385){b=c[3540986]|0;if((f&1|0)==0){a[b+5885|0]=e;return}g=c[b+5876>>2]|0;if((g|0)!=0){gg[g&4095](c[b+5880>>2]|0,0)}lH(b,d[b+5885|0]|0,e&255);return}else if((f|0)==2048|(f|0)==2049|(f|0)==8192|(f|0)==8193){lS(0,f&1,e);return}else{return}}function aGy(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0;e=i;i=i+5280|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;B=e+1200|0;C=e+1312|0;D=e+1320|0;E=e+1432|0;F=e+1440|0;G=e+1552|0;H=e+1560|0;I=e+1672|0;J=e+1680|0;K=e+1792|0;L=e+1800|0;M=e+1912|0;N=e+1920|0;O=e+2032|0;P=e+2040|0;Q=e+2152|0;R=e+2160|0;S=e+2272|0;T=e+2280|0;U=e+2392|0;V=e+2400|0;W=e+2512|0;X=e+2520|0;Y=e+2632|0;Z=e+2640|0;_=e+2752|0;$=e+2760|0;aa=e+2872|0;ab=e+2880|0;ac=e+2992|0;ad=e+3e3|0;ae=e+3112|0;af=e+3120|0;ah=e+3232|0;ai=e+3240|0;aj=e+3352|0;ak=e+3360|0;al=e+3472|0;am=e+3480|0;an=e+3592|0;ao=e+3600|0;ap=e+3712|0;aq=e+3720|0;ar=e+3832|0;as=e+3840|0;at=e+3952|0;au=e+3960|0;av=e+4072|0;aw=e+4080|0;ax=e+4192|0;ay=e+4200|0;az=e+4312|0;aA=e+4320|0;aB=e+4432|0;aC=e+4440|0;aD=e+4552|0;aE=e+4560|0;aF=e+4672|0;aG=e+4680|0;aH=e+4792|0;aI=e+4800|0;aJ=e+4912|0;aK=e+4920|0;aL=e+5032|0;aM=e+5040|0;aN=e+5152|0;aO=e+5160|0;aP=e+5272|0;c[2414854]=0;c[3530266]=0;c[2386358]=327680;c[3527436]=458752;c[3527440]=589824;c[3530752]=655360;c[3530516]=786432;c[3530384]=1835008;c[3530308]=2883584;c[3531056]=3932160;c[2407020]=3934208;c[3529894]=3938304;c[2414556]=3942400;c[3530268]=3942400;c[2386282]=3950592;c[2387082]=3952640;c[2387076]=3956736;c[3529872]=3960832;c[3529870]=3960864;c[2386744]=3960896;c[2386382]=3961920;c[2386556]=3963968;c[2387100]=3966016;c[3527438]=3968064;c[3528212]=3970112;c[3528482]=3970113;c[2432942]=3970114;c[3528652]=3970115;c[2411456]=3970116;aQ=0;while(1){if((aQ|0)>=1024){break}aR=9638528+(aQ<<2)|0;if((c[aR>>2]|0)==0){aS=28241;break}else{aQ=aQ+1|0}}do{if((aS|0)==28241){aQ=gGq(3970116)|0;c[aR>>2]=aQ;if((aQ|0)==0){break}c[2414854]=aQ;gGz(aQ|0,0,3970116);c[3530266]=aQ;c[2386358]=aQ+327680;c[3527436]=aQ+458752;c[3527440]=aQ+589824;c[3530752]=aQ+655360;c[3530516]=aQ+786432;c[3530384]=aQ+1835008;c[3530308]=aQ+2883584;c[3531056]=aQ+3932160;c[2407020]=aQ+3934208;c[3529894]=aQ+3938304;aT=aQ+3942400|0;c[2414556]=aT;c[3530268]=aT;c[2386282]=aQ+3950592;c[2387082]=aQ+3952640;c[2387076]=aQ+3956736;c[3529872]=aQ+3960832;c[3529870]=aQ+3960864;c[2386744]=aQ+3960896;c[2386382]=aQ+3961920;c[2386556]=aQ+3963968;c[2387100]=aQ+3966016;c[3527438]=aQ+3968064;c[3528212]=aQ+3970112;c[3528482]=aQ+3970113;c[2432942]=aQ+3970114;c[3528652]=aQ+3970115;aT=aQ+3970116|0;c[2411456]=aT;c[2413996]=aT;aT=c[642608+(c[2436]<<2)>>2]|0;aU=(fa(c[aT>>2]|0,336512)|0)==0;aV=aQ+32768|0;do{if((c[3542200]|0)==0){aW=1}else{aQ=aO+108|0;c[aQ>>2]=0;aX=aO+100|0;c[aX>>2]=0;aY=c[aT+76>>2]|0;gA[aY&16383](aO,0)|0;if((c[aQ>>2]|0)==0){aW=0;break}aQ=c[aX>>2]|0;c[aP>>2]=9534384;aX=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aX&16383](aP,0,0)|0;if((aQ|0)<1){aW=1;break}aW=(gzL(aV,0,0)|0)!=0}}while(0);do{if(aU){if(aW){aZ=1;i=e;return aZ|0}aV=(c[3530266]|0)+65536|0;if((c[3542200]|0)==0){aZ=1;i=e;return aZ|0}aT=aM+108|0;c[aT>>2]=0;aQ=aM+100|0;c[aQ>>2]=0;aX=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aX&16383](aM,1)|0;do{if((c[aT>>2]|0)!=0){aX=c[aQ>>2]|0;c[aN>>2]=9534384;aY=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aY&16383](aN,1,0)|0;if((aX|0)<1){aZ=1;i=e;return aZ|0}if((gzL(aV,0,1)|0)==0){break}else{aZ=1}i=e;return aZ|0}}while(0);aV=(c[3530266]|0)+131072|0;if((c[3542200]|0)==0){aZ=1;i=e;return aZ|0}aQ=aK+108|0;c[aQ>>2]=0;aT=aK+100|0;c[aT>>2]=0;aX=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aX&16383](aK,2)|0;do{if((c[aQ>>2]|0)!=0){aX=c[aT>>2]|0;c[aL>>2]=9534384;aY=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aY&16383](aL,2,0)|0;if((aX|0)<1){aZ=1;i=e;return aZ|0}if((gzL(aV,0,2)|0)==0){break}else{aZ=1}i=e;return aZ|0}}while(0);aV=(c[3530266]|0)+196608|0;if((c[3542200]|0)==0){aZ=1;i=e;return aZ|0}aT=aI+108|0;c[aT>>2]=0;aQ=aI+100|0;c[aQ>>2]=0;aX=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aX&16383](aI,3)|0;do{if((c[aT>>2]|0)!=0){aX=c[aQ>>2]|0;c[aJ>>2]=9534384;aY=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aY&16383](aJ,3,0)|0;if((aX|0)<1){aZ=1;i=e;return aZ|0}if((gzL(aV,0,3)|0)==0){break}else{aZ=1}i=e;return aZ|0}}while(0);aV=(c[3530266]|0)+262144|0;if((c[3542200]|0)==0){aZ=1;i=e;return aZ|0}aQ=aG+108|0;c[aQ>>2]=0;aT=aG+100|0;c[aT>>2]=0;aX=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aX&16383](aG,4)|0;do{if((c[aQ>>2]|0)!=0){aX=c[aT>>2]|0;c[aH>>2]=9534384;aY=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aY&16383](aH,4,0)|0;if((aX|0)<1){aZ=1;i=e;return aZ|0}if((gzL(aV,0,4)|0)==0){break}else{aZ=1}i=e;return aZ|0}}while(0);aV=(c[3527436]|0)+32768|0;if((c[3542200]|0)==0){aZ=1;i=e;return aZ|0}aT=aE+108|0;c[aT>>2]=0;aQ=aE+100|0;c[aQ>>2]=0;aX=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aX&16383](aE,5)|0;do{if((c[aT>>2]|0)!=0){aX=c[aQ>>2]|0;c[aF>>2]=9534384;aY=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aY&16383](aF,5,0)|0;if((aX|0)<1){aZ=1;i=e;return aZ|0}if((gzL(aV,0,5)|0)==0){break}else{aZ=1}i=e;return aZ|0}}while(0);aV=c[3530752]|0;if((c[3542200]|0)==0){aZ=1;i=e;return aZ|0}aQ=aC+108|0;c[aQ>>2]=0;aT=aC+100|0;c[aT>>2]=0;aX=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aX&16383](aC,6)|0;do{if((c[aQ>>2]|0)!=0){aX=c[aT>>2]|0;c[aD>>2]=9534384;aY=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aY&16383](aD,6,0)|0;if((aX|0)<1){aZ=1;i=e;return aZ|0}if((gzL(aV,0,6)|0)==0){break}else{aZ=1}i=e;return aZ|0}}while(0);aV=c[3530516]|0;if((c[3542200]|0)==0){aZ=1;i=e;return aZ|0}aT=aA+108|0;c[aT>>2]=0;aQ=aA+100|0;c[aQ>>2]=0;aX=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aX&16383](aA,7)|0;do{if((c[aT>>2]|0)!=0){aX=c[aQ>>2]|0;c[aB>>2]=9534384;aY=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aY&16383](aB,7,0)|0;if((aX|0)<1){aZ=1;i=e;return aZ|0}if((gzL(aV,0,7)|0)==0){break}else{aZ=1}i=e;return aZ|0}}while(0);aV=(c[3530516]|0)+65536|0;if((c[3542200]|0)==0){aZ=1;i=e;return aZ|0}aQ=ay+108|0;c[aQ>>2]=0;aT=ay+100|0;c[aT>>2]=0;aX=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aX&16383](ay,8)|0;do{if((c[aQ>>2]|0)!=0){aX=c[aT>>2]|0;c[az>>2]=9534384;aY=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aY&16383](az,8,0)|0;if((aX|0)<1){aZ=1;i=e;return aZ|0}if((gzL(aV,0,8)|0)==0){break}else{aZ=1}i=e;return aZ|0}}while(0);aV=(c[3530516]|0)+131072|0;if((c[3542200]|0)==0){aZ=1;i=e;return aZ|0}aT=aw+108|0;c[aT>>2]=0;aQ=aw+100|0;c[aQ>>2]=0;aX=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aX&16383](aw,9)|0;do{if((c[aT>>2]|0)!=0){aX=c[aQ>>2]|0;c[ax>>2]=9534384;aY=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aY&16383](ax,9,0)|0;if((aX|0)<1){aZ=1;i=e;return aZ|0}if((gzL(aV,0,9)|0)==0){break}else{aZ=1}i=e;return aZ|0}}while(0);aV=(c[3530516]|0)+196608|0;if((c[3542200]|0)==0){aZ=1;i=e;return aZ|0}aQ=au+108|0;c[aQ>>2]=0;aT=au+100|0;c[aT>>2]=0;aX=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aX&16383](au,10)|0;do{if((c[aQ>>2]|0)!=0){aX=c[aT>>2]|0;c[av>>2]=9534384;aY=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aY&16383](av,10,0)|0;if((aX|0)<1){aZ=1;i=e;return aZ|0}if((gzL(aV,0,10)|0)==0){break}else{aZ=1}i=e;return aZ|0}}while(0);aV=(c[3530516]|0)+262144|0;if((c[3542200]|0)==0){aZ=1;i=e;return aZ|0}aT=as+108|0;c[aT>>2]=0;aQ=as+100|0;c[aQ>>2]=0;aX=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aX&16383](as,11)|0;do{if((c[aT>>2]|0)!=0){aX=c[aQ>>2]|0;c[at>>2]=9534384;aY=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aY&16383](at,11,0)|0;if((aX|0)<1){aZ=1;i=e;return aZ|0}if((gzL(aV,0,11)|0)==0){break}else{aZ=1}i=e;return aZ|0}}while(0);aV=(c[3530516]|0)+327680|0;if((c[3542200]|0)==0){aZ=1;i=e;return aZ|0}aQ=aq+108|0;c[aQ>>2]=0;aT=aq+100|0;c[aT>>2]=0;aX=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aX&16383](aq,12)|0;do{if((c[aQ>>2]|0)!=0){aX=c[aT>>2]|0;c[ar>>2]=9534384;aY=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aY&16383](ar,12,0)|0;if((aX|0)<1){aZ=1;i=e;return aZ|0}if((gzL(aV,0,12)|0)==0){break}else{aZ=1}i=e;return aZ|0}}while(0);aV=(c[3530516]|0)+393216|0;if((c[3542200]|0)==0){aZ=1;i=e;return aZ|0}aT=ao+108|0;c[aT>>2]=0;aQ=ao+100|0;c[aQ>>2]=0;aX=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aX&16383](ao,13)|0;do{if((c[aT>>2]|0)!=0){aX=c[aQ>>2]|0;c[ap>>2]=9534384;aY=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aY&16383](ap,13,0)|0;if((aX|0)<1){aZ=1;i=e;return aZ|0}if((gzL(aV,0,13)|0)==0){break}else{aZ=1}i=e;return aZ|0}}while(0);aV=(c[3530516]|0)+458752|0;if((c[3542200]|0)==0){aZ=1;i=e;return aZ|0}aQ=am+108|0;c[aQ>>2]=0;aT=am+100|0;c[aT>>2]=0;aX=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aX&16383](am,14)|0;do{if((c[aQ>>2]|0)!=0){aX=c[aT>>2]|0;c[an>>2]=9534384;aY=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aY&16383](an,14,0)|0;if((aX|0)<1){aZ=1;i=e;return aZ|0}if((gzL(aV,0,14)|0)==0){break}else{aZ=1}i=e;return aZ|0}}while(0);aV=c[3530308]|0;if((c[3542200]|0)==0){aZ=1;i=e;return aZ|0}aT=ak+108|0;c[aT>>2]=0;aQ=ak+100|0;c[aQ>>2]=0;aX=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aX&16383](ak,15)|0;do{if((c[aT>>2]|0)!=0){aX=c[aQ>>2]|0;c[al>>2]=9534384;aY=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aY&16383](al,15,0)|0;if((aX|0)<1){aZ=1;i=e;return aZ|0}if((gzL(aV,0,15)|0)==0){break}else{aZ=1}i=e;return aZ|0}}while(0);aV=c[3530384]|0;aQ=c[3530308]|0;gGC(aV|0,aQ|0,32768)|0;aT=aV+65536|0;aV=aQ+32768|0;gGC(aT|0,aV|0,32768)|0;if((c[3542200]|0)==0){aZ=1;i=e;return aZ|0}aV=ai+108|0;c[aV>>2]=0;aT=ai+100|0;c[aT>>2]=0;aX=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aX&16383](ai,16)|0;do{if((c[aV>>2]|0)!=0){aX=c[aT>>2]|0;c[aj>>2]=9534384;aY=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aY&16383](aj,16,0)|0;if((aX|0)<1){aZ=1;i=e;return aZ|0}if((gzL(aQ,0,16)|0)==0){break}else{aZ=1}i=e;return aZ|0}}while(0);aQ=c[3530384]|0;aT=aQ+32768|0;aV=c[3530308]|0;gGC(aT|0,aV|0,32768)|0;aT=aQ+98304|0;aQ=aV+32768|0;gGC(aT|0,aQ|0,32768)|0;if((c[3542200]|0)==0){aZ=1;i=e;return aZ|0}aQ=af+108|0;c[aQ>>2]=0;aT=af+100|0;c[aT>>2]=0;aX=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aX&16383](af,17)|0;do{if((c[aQ>>2]|0)!=0){aX=c[aT>>2]|0;c[ah>>2]=9534384;aY=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aY&16383](ah,17,0)|0;if((aX|0)<1){aZ=1;i=e;return aZ|0}if((gzL(aV,0,17)|0)==0){break}else{aZ=1}i=e;return aZ|0}}while(0);aV=c[3530384]|0;aT=aV+131072|0;aQ=c[3530308]|0;gGC(aT|0,aQ|0,32768)|0;aT=aV+196608|0;aV=aQ+32768|0;gGC(aT|0,aV|0,32768)|0;if((c[3542200]|0)==0){aZ=1;i=e;return aZ|0}aV=ad+108|0;c[aV>>2]=0;aT=ad+100|0;c[aT>>2]=0;aX=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aX&16383](ad,18)|0;do{if((c[aV>>2]|0)!=0){aX=c[aT>>2]|0;c[ae>>2]=9534384;aY=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aY&16383](ae,18,0)|0;if((aX|0)<1){aZ=1;i=e;return aZ|0}if((gzL(aQ,0,18)|0)==0){break}else{aZ=1}i=e;return aZ|0}}while(0);aQ=c[3530384]|0;aT=aQ+163840|0;aV=c[3530308]|0;gGC(aT|0,aV|0,32768)|0;aT=aQ+229376|0;aQ=aV+32768|0;gGC(aT|0,aQ|0,32768)|0;if((c[3542200]|0)==0){aZ=1;i=e;return aZ|0}aQ=ab+108|0;c[aQ>>2]=0;aT=ab+100|0;c[aT>>2]=0;aX=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aX&16383](ab,19)|0;do{if((c[aQ>>2]|0)!=0){aX=c[aT>>2]|0;c[ac>>2]=9534384;aY=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aY&16383](ac,19,0)|0;if((aX|0)<1){aZ=1;i=e;return aZ|0}if((gzL(aV,0,19)|0)==0){break}else{aZ=1}i=e;return aZ|0}}while(0);aV=c[3530384]|0;aT=aV+262144|0;aQ=c[3530308]|0;gGC(aT|0,aQ|0,32768)|0;aT=aV+327680|0;aV=aQ+32768|0;gGC(aT|0,aV|0,32768)|0;if((c[3542200]|0)==0){aZ=1;i=e;return aZ|0}aV=$+108|0;c[aV>>2]=0;aT=$+100|0;c[aT>>2]=0;aX=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aX&16383]($,20)|0;do{if((c[aV>>2]|0)!=0){aX=c[aT>>2]|0;c[aa>>2]=9534384;aY=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aY&16383](aa,20,0)|0;if((aX|0)<1){aZ=1;i=e;return aZ|0}if((gzL(aQ,0,20)|0)==0){break}else{aZ=1}i=e;return aZ|0}}while(0);aQ=c[3530384]|0;aT=aQ+294912|0;aV=c[3530308]|0;gGC(aT|0,aV|0,32768)|0;aT=aQ+360448|0;aQ=aV+32768|0;gGC(aT|0,aQ|0,32768)|0;if((c[3542200]|0)==0){aZ=1;i=e;return aZ|0}aQ=Z+108|0;c[aQ>>2]=0;aT=Z+100|0;c[aT>>2]=0;aX=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aX&16383](Z,21)|0;do{if((c[aQ>>2]|0)!=0){aX=c[aT>>2]|0;c[_>>2]=9534384;aY=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aY&16383](_,21,0)|0;if((aX|0)<1){aZ=1;i=e;return aZ|0}if((gzL(aV,0,21)|0)==0){break}else{aZ=1}i=e;return aZ|0}}while(0);aV=c[3530384]|0;aT=aV+393216|0;aQ=c[3530308]|0;gGC(aT|0,aQ|0,32768)|0;aT=aV+458752|0;aV=aQ+32768|0;gGC(aT|0,aV|0,32768)|0;if((c[3542200]|0)==0){aZ=1;i=e;return aZ|0}aV=X+108|0;c[aV>>2]=0;aT=X+100|0;c[aT>>2]=0;aX=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aX&16383](X,22)|0;do{if((c[aV>>2]|0)!=0){aX=c[aT>>2]|0;c[Y>>2]=9534384;aY=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aY&16383](Y,22,0)|0;if((aX|0)<1){aZ=1;i=e;return aZ|0}if((gzL(aQ,0,22)|0)==0){break}else{aZ=1}i=e;return aZ|0}}while(0);aQ=c[3530384]|0;aT=aQ+425984|0;aV=c[3530308]|0;gGC(aT|0,aV|0,32768)|0;aT=aQ+491520|0;aQ=aV+32768|0;gGC(aT|0,aQ|0,32768)|0;a_=0}else{if(aW){aZ=1;i=e;return aZ|0}aQ=(c[3530266]|0)+65536|0;if((c[3542200]|0)==0){aZ=1;i=e;return aZ|0}aT=V+108|0;c[aT>>2]=0;aV=V+100|0;c[aV>>2]=0;aX=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aX&16383](V,1)|0;do{if((c[aT>>2]|0)!=0){aX=c[aV>>2]|0;c[W>>2]=9534384;aY=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aY&16383](W,1,0)|0;if((aX|0)<1){aZ=1;i=e;return aZ|0}if((gzL(aQ,0,1)|0)==0){break}else{aZ=1}i=e;return aZ|0}}while(0);aQ=(c[3530266]|0)+131072|0;if((c[3542200]|0)==0){aZ=1;i=e;return aZ|0}aV=T+108|0;c[aV>>2]=0;aT=T+100|0;c[aT>>2]=0;aX=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aX&16383](T,2)|0;do{if((c[aV>>2]|0)!=0){aX=c[aT>>2]|0;c[U>>2]=9534384;aY=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aY&16383](U,2,0)|0;if((aX|0)<1){aZ=1;i=e;return aZ|0}if((gzL(aQ,0,2)|0)==0){break}else{aZ=1}i=e;return aZ|0}}while(0);aQ=(c[3530266]|0)+196608|0;if((c[3542200]|0)==0){aZ=1;i=e;return aZ|0}aT=R+108|0;c[aT>>2]=0;aV=R+100|0;c[aV>>2]=0;aX=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aX&16383](R,3)|0;do{if((c[aT>>2]|0)!=0){aX=c[aV>>2]|0;c[S>>2]=9534384;aY=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aY&16383](S,3,0)|0;if((aX|0)<1){aZ=1;i=e;return aZ|0}if((gzL(aQ,0,3)|0)==0){break}else{aZ=1}i=e;return aZ|0}}while(0);aQ=(c[3527436]|0)+32768|0;if((c[3542200]|0)==0){aZ=1;i=e;return aZ|0}aV=P+108|0;c[aV>>2]=0;aT=P+100|0;c[aT>>2]=0;aX=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aX&16383](P,4)|0;do{if((c[aV>>2]|0)!=0){aX=c[aT>>2]|0;c[Q>>2]=9534384;aY=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aY&16383](Q,4,0)|0;if((aX|0)<1){aZ=1;i=e;return aZ|0}if((gzL(aQ,0,4)|0)==0){break}else{aZ=1}i=e;return aZ|0}}while(0);aQ=c[3530752]|0;if((c[3542200]|0)==0){aZ=1;i=e;return aZ|0}aT=N+108|0;c[aT>>2]=0;aV=N+100|0;c[aV>>2]=0;aX=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aX&16383](N,5)|0;do{if((c[aT>>2]|0)!=0){aX=c[aV>>2]|0;c[O>>2]=9534384;aY=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aY&16383](O,5,0)|0;if((aX|0)<1){aZ=1;i=e;return aZ|0}if((gzL(aQ,0,5)|0)==0){break}else{aZ=1}i=e;return aZ|0}}while(0);aQ=c[3530516]|0;if((c[3542200]|0)==0){aZ=1;i=e;return aZ|0}aV=L+108|0;c[aV>>2]=0;aT=L+100|0;c[aT>>2]=0;aX=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aX&16383](L,6)|0;do{if((c[aV>>2]|0)!=0){aX=c[aT>>2]|0;c[M>>2]=9534384;aY=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aY&16383](M,6,0)|0;if((aX|0)<1){aZ=1;i=e;return aZ|0}if((gzL(aQ,0,6)|0)==0){break}else{aZ=1}i=e;return aZ|0}}while(0);aQ=(c[3530516]|0)+65536|0;if((c[3542200]|0)==0){aZ=1;i=e;return aZ|0}aT=J+108|0;c[aT>>2]=0;aV=J+100|0;c[aV>>2]=0;aX=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aX&16383](J,7)|0;do{if((c[aT>>2]|0)!=0){aX=c[aV>>2]|0;c[K>>2]=9534384;aY=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aY&16383](K,7,0)|0;if((aX|0)<1){aZ=1;i=e;return aZ|0}if((gzL(aQ,0,7)|0)==0){break}else{aZ=1}i=e;return aZ|0}}while(0);aQ=(c[3530516]|0)+131072|0;if((c[3542200]|0)==0){aZ=1;i=e;return aZ|0}aV=H+108|0;c[aV>>2]=0;aT=H+100|0;c[aT>>2]=0;aX=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aX&16383](H,8)|0;do{if((c[aV>>2]|0)!=0){aX=c[aT>>2]|0;c[I>>2]=9534384;aY=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aY&16383](I,8,0)|0;if((aX|0)<1){aZ=1;i=e;return aZ|0}if((gzL(aQ,0,8)|0)==0){break}else{aZ=1}i=e;return aZ|0}}while(0);aQ=(c[3530516]|0)+196608|0;if((c[3542200]|0)==0){aZ=1;i=e;return aZ|0}aT=F+108|0;c[aT>>2]=0;aV=F+100|0;c[aV>>2]=0;aX=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aX&16383](F,9)|0;do{if((c[aT>>2]|0)!=0){aX=c[aV>>2]|0;c[G>>2]=9534384;aY=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aY&16383](G,9,0)|0;if((aX|0)<1){aZ=1;i=e;return aZ|0}if((gzL(aQ,0,9)|0)==0){break}else{aZ=1}i=e;return aZ|0}}while(0);aQ=(c[3530516]|0)+262144|0;if((c[3542200]|0)==0){aZ=1;i=e;return aZ|0}aV=D+108|0;c[aV>>2]=0;aT=D+100|0;c[aT>>2]=0;aX=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aX&16383](D,10)|0;do{if((c[aV>>2]|0)!=0){aX=c[aT>>2]|0;c[E>>2]=9534384;aY=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aY&16383](E,10,0)|0;if((aX|0)<1){aZ=1;i=e;return aZ|0}if((gzL(aQ,0,10)|0)==0){break}else{aZ=1}i=e;return aZ|0}}while(0);aQ=(c[3530516]|0)+327680|0;if((c[3542200]|0)==0){aZ=1;i=e;return aZ|0}aT=B+108|0;c[aT>>2]=0;aV=B+100|0;c[aV>>2]=0;aX=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aX&16383](B,11)|0;do{if((c[aT>>2]|0)!=0){aX=c[aV>>2]|0;c[C>>2]=9534384;aY=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aY&16383](C,11,0)|0;if((aX|0)<1){aZ=1;i=e;return aZ|0}if((gzL(aQ,0,11)|0)==0){break}else{aZ=1}i=e;return aZ|0}}while(0);aQ=(c[3530516]|0)+393216|0;if((c[3542200]|0)==0){aZ=1;i=e;return aZ|0}aV=z+108|0;c[aV>>2]=0;aT=z+100|0;c[aT>>2]=0;aX=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aX&16383](z,12)|0;do{if((c[aV>>2]|0)!=0){aX=c[aT>>2]|0;c[A>>2]=9534384;aY=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aY&16383](A,12,0)|0;if((aX|0)<1){aZ=1;i=e;return aZ|0}if((gzL(aQ,0,12)|0)==0){break}else{aZ=1}i=e;return aZ|0}}while(0);aQ=(c[3530516]|0)+458752|0;if((c[3542200]|0)==0){aZ=1;i=e;return aZ|0}aT=x+108|0;c[aT>>2]=0;aV=x+100|0;c[aV>>2]=0;aX=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aX&16383](x,13)|0;do{if((c[aT>>2]|0)!=0){aX=c[aV>>2]|0;c[y>>2]=9534384;aY=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aY&16383](y,13,0)|0;if((aX|0)<1){aZ=1;i=e;return aZ|0}if((gzL(aQ,0,13)|0)==0){break}else{aZ=1}i=e;return aZ|0}}while(0);aQ=c[3530308]|0;if((c[3542200]|0)==0){aZ=1;i=e;return aZ|0}aV=v+108|0;c[aV>>2]=0;aT=v+100|0;c[aT>>2]=0;aX=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aX&16383](v,14)|0;do{if((c[aV>>2]|0)!=0){aX=c[aT>>2]|0;c[w>>2]=9534384;aY=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aY&16383](w,14,0)|0;if((aX|0)<1){aZ=1;i=e;return aZ|0}if((gzL(aQ,0,14)|0)==0){break}else{aZ=1}i=e;return aZ|0}}while(0);aQ=c[3530384]|0;aT=c[3530308]|0;gGC(aQ|0,aT|0,32768)|0;aV=aQ+65536|0;aX=aT+32768|0;gGC(aV|0,aX|0,32768)|0;aX=aQ+32768|0;if((c[3542200]|0)==0){aZ=1;i=e;return aZ|0}aQ=t+108|0;c[aQ>>2]=0;aV=t+100|0;c[aV>>2]=0;aT=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aT&16383](t,15)|0;do{if((c[aQ>>2]|0)!=0){aT=c[aV>>2]|0;c[u>>2]=9534384;aY=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aY&16383](u,15,0)|0;if((aT|0)<1){aZ=1;i=e;return aZ|0}if((gzL(aX,0,15)|0)==0){break}else{aZ=1}i=e;return aZ|0}}while(0);aX=c[3530308]|0;if((c[3542200]|0)==0){aZ=1;i=e;return aZ|0}aV=r+108|0;c[aV>>2]=0;aQ=r+100|0;c[aQ>>2]=0;aT=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aT&16383](r,16)|0;do{if((c[aV>>2]|0)!=0){aT=c[aQ>>2]|0;c[s>>2]=9534384;aY=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aY&16383](s,16,0)|0;if((aT|0)<1){aZ=1;i=e;return aZ|0}if((gzL(aX,0,16)|0)==0){break}else{aZ=1}i=e;return aZ|0}}while(0);aX=c[3530384]|0;aQ=aX+131072|0;aV=c[3530308]|0;gGC(aQ|0,aV|0,32768)|0;aQ=aX+196608|0;aT=aV+32768|0;gGC(aQ|0,aT|0,32768)|0;aT=aX+163840|0;if((c[3542200]|0)==0){aZ=1;i=e;return aZ|0}aX=p+108|0;c[aX>>2]=0;aQ=p+100|0;c[aQ>>2]=0;aV=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aV&16383](p,17)|0;do{if((c[aX>>2]|0)!=0){aV=c[aQ>>2]|0;c[q>>2]=9534384;aY=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aY&16383](q,17,0)|0;if((aV|0)<1){aZ=1;i=e;return aZ|0}if((gzL(aT,0,17)|0)==0){break}else{aZ=1}i=e;return aZ|0}}while(0);aT=c[3530308]|0;if((c[3542200]|0)==0){aZ=1;i=e;return aZ|0}aQ=n+108|0;c[aQ>>2]=0;aX=n+100|0;c[aX>>2]=0;aV=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aV&16383](n,18)|0;do{if((c[aQ>>2]|0)!=0){aV=c[aX>>2]|0;c[o>>2]=9534384;aY=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aY&16383](o,18,0)|0;if((aV|0)<1){aZ=1;i=e;return aZ|0}if((gzL(aT,0,18)|0)==0){break}else{aZ=1}i=e;return aZ|0}}while(0);aT=c[3530384]|0;aX=aT+262144|0;aQ=c[3530308]|0;gGC(aX|0,aQ|0,32768)|0;aX=aT+327680|0;aV=aQ+32768|0;gGC(aX|0,aV|0,32768)|0;aV=aT+294912|0;if((c[3542200]|0)==0){aZ=1;i=e;return aZ|0}aT=l+108|0;c[aT>>2]=0;aX=l+100|0;c[aX>>2]=0;aQ=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aQ&16383](l,19)|0;do{if((c[aT>>2]|0)!=0){aQ=c[aX>>2]|0;c[m>>2]=9534384;aY=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aY&16383](m,19,0)|0;if((aQ|0)<1){aZ=1;i=e;return aZ|0}if((gzL(aV,0,19)|0)==0){break}else{aZ=1}i=e;return aZ|0}}while(0);aV=c[3530308]|0;if((c[3542200]|0)==0){aZ=1;i=e;return aZ|0}aX=j+108|0;c[aX>>2]=0;aT=j+100|0;c[aT>>2]=0;aQ=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aQ&16383](j,20)|0;do{if((c[aX>>2]|0)!=0){aQ=c[aT>>2]|0;c[k>>2]=9534384;aY=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aY&16383](k,20,0)|0;if((aQ|0)<1){aZ=1;i=e;return aZ|0}if((gzL(aV,0,20)|0)==0){break}else{aZ=1}i=e;return aZ|0}}while(0);aV=c[3530384]|0;aT=aV+393216|0;aX=c[3530308]|0;gGC(aT|0,aX|0,32768)|0;aT=aV+458752|0;aQ=aX+32768|0;gGC(aT|0,aQ|0,32768)|0;aQ=aV+425984|0;if((c[3542200]|0)==0){aZ=1;i=e;return aZ|0}aV=f+108|0;c[aV>>2]=0;aT=f+100|0;c[aT>>2]=0;aX=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aX&16383](f,21)|0;if((c[aV>>2]|0)==0){a_=0;break}aV=c[aT>>2]|0;c[g>>2]=9534384;aT=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aT&16383](g,21,0)|0;if((aV|0)<1){aZ=1;i=e;return aZ|0}if((gzL(aQ,0,21)|0)==0){a_=0;break}else{aZ=1}i=e;return aZ|0}}while(0);while(1){if((a_|0)>=1024){break}a$=9638528+(a_<<2)|0;if((c[a$>>2]|0)==0){aS=28425;break}else{a_=a_+1|0}}L36553:do{if((aS|0)==28425){aU=gGq(524288)|0;c[a$>>2]=aU;if((aU|0)==0){break}gGz(aU|0,0,524288);aQ=c[3530752]|0;gGC(aU|0,aQ|0,32768)|0;aV=0;do{aT=aV<<6;gGz(aQ+aT|0,0,64);aX=aT+196608|0;aY=0;do{a0=aX+(c[609008+(aY<<2)>>2]|0)|0;a1=(aY<<3)+aT|0;a2=0;do{a3=a0+(c[614800+(a2<<2)>>2]|0)|0;if((d[aU+((a3|0)/8|0)|0]&128>>>((a3&7)>>>0)|0)!=0){a3=aQ+(a1+a2)|0;a[a3]=a[a3]|4}a2=a2+1|0;}while((a2|0)<8);aY=aY+1|0;}while((aY|0)<8);aY=aT+131072|0;aX=0;do{a2=aY+(c[609008+(aX<<2)>>2]|0)|0;a1=(aX<<3)+aT|0;a0=0;do{a3=a2+(c[614800+(a0<<2)>>2]|0)|0;if((d[aU+((a3|0)/8|0)|0]&128>>>((a3&7)>>>0)|0)!=0){a3=aQ+(a1+a0)|0;a[a3]=a[a3]|2}a0=a0+1|0;}while((a0|0)<8);aX=aX+1|0;}while((aX|0)<8);aX=aT+65536|0;aY=0;do{a0=aX+(c[609008+(aY<<2)>>2]|0)|0;a1=(aY<<3)+aT|0;a2=0;do{a3=a0+(c[614800+(a2<<2)>>2]|0)|0;if((d[aU+((a3|0)/8|0)|0]&128>>>((a3&7)>>>0)|0)!=0){a3=aQ+(a1+a2)|0;a[a3]=a[a3]|1}a2=a2+1|0;}while((a2|0)<8);aY=aY+1|0;}while((aY|0)<8);aV=aV+1|0;}while((aV|0)<1024);aV=c[3530516]|0;gGC(aU|0,aV|0,524288)|0;aQ=0;do{aY=aQ<<8;gGz(aV+aY|0,0,256);aT=0;do{aX=1<<3-aT;a2=(c[704200+(aT<<2)>>2]|0)+aY|0;a1=0;do{a0=a2+(c[609008+(a1<<2)>>2]|0)|0;a3=(a1<<4)+aY|0;a4=0;do{a5=a0+(c[612640+(a4<<2)>>2]|0)|0;if((d[aU+((a5|0)/8|0)|0]&128>>>((a5&7)>>>0)|0)!=0){a5=aV+(a3+a4)|0;a[a5]=(d[a5]|aX)&255}a4=a4+1|0;}while((a4|0)<16);a1=a1+1|0;}while((a1|0)<16);aT=aT+1|0;}while((aT|0)<4);aQ=aQ+1|0;}while((aQ|0)<4096);aQ=c[3530384]|0;gGC(aU|0,aQ|0,524288)|0;aV=0;while(1){aT=aV<<8;gGz(aQ+aT|0,0,256);aY=0;do{a1=1<<3-aY;aX=(c[704200+(aY<<2)>>2]|0)+aT|0;a2=0;do{a4=aX+(c[609008+(a2<<2)>>2]|0)|0;a3=(a2<<4)+aT|0;a0=0;do{a5=a4+(c[612640+(a0<<2)>>2]|0)|0;if((d[aU+((a5|0)/8|0)|0]&128>>>((a5&7)>>>0)|0)!=0){a5=aQ+(a3+a0)|0;a[a5]=(d[a5]|a1)&255}a0=a0+1|0;}while((a0|0)<16);a2=a2+1|0;}while((a2|0)<16);aY=aY+1|0;}while((aY|0)<4);aY=aV+1|0;if((aY|0)<4096){aV=aY}else{a6=0;break}}while(1){if((a6|0)>=1024){break L36553}a7=9638528+(a6<<2)|0;if((c[a7>>2]|0)==(aU|0)){break}else{a6=a6+1|0}}gGr(aU);c[a7>>2]=0}}while(0);c[3528552]=-1;c[2113196]=1;aV=gGq(3160)|0;aQ=aV;c[2433426]=aQ;if((aV|0)==0){c[3528552]=0}else{gGz(aV|0,0,3160);c[aV+3132>>2]=2102;c[aV+3136>>2]=2420;c[aV+3140>>2]=1856;c[aV+3144>>2]=1450;c[2430450]=0;aY=0;do{c[aQ+60+(aY<<2)>>2]=0;aY=aY+1|0;}while((aY|0)<768);c[2113194]=0;aY=c[2427044]|0;c[9681616+(aY<<3)>>2]=726904;c[9681620+(aY<<3)>>2]=0;c[2427044]=aY+1;c[3528552]=0;gGC(9642704,aV|0,60)|0}b[4821352]=c[2410676]&65535;fC1();aY=(a[9642745]&1)==0;c[2430032]=aY?1595912:1595656;c[2429672]=aY?1114752:1114496;c[2429670]=aY?1114240:1113984;c[2444186]=aY?4654424:4654168;aY=c[3528552]|0;aQ=9721800+(aY<<2)|0;c[2113194]=c[aQ>>2];aT=c[3530268]|0;a2=c[2433426]|0;a1=0;aX=0;while(1){a0=aT+(aX<<8)|0;c[a2+(aY*3160|0)+60+(aX<<2)>>2]=a0;c[a2+(aY*3160|0)+60+(aX+256<<2)>>2]=a0;c[a2+(aY*3160|0)+60+(aX+512<<2)>>2]=a0;a0=a1+1&65535;if((a0&65535)>23){break}else{a1=a0;aX=a0&65535}}aX=c[2386282]|0;c[a2+(aY*3160|0)+156>>2]=aX;c[a2+(aY*3160|0)+1180>>2]=aX;c[a2+(aY*3160|0)+2204>>2]=aX;a1=aX+256|0;c[a2+(aY*3160|0)+160>>2]=a1;c[a2+(aY*3160|0)+1184>>2]=a1;c[a2+(aY*3160|0)+2208>>2]=a1;a1=aX+512|0;c[a2+(aY*3160|0)+164>>2]=a1;c[a2+(aY*3160|0)+1188>>2]=a1;c[a2+(aY*3160|0)+2212>>2]=a1;a1=aX+768|0;c[a2+(aY*3160|0)+168>>2]=a1;c[a2+(aY*3160|0)+1192>>2]=a1;c[a2+(aY*3160|0)+2216>>2]=a1;a1=aX+1024|0;c[a2+(aY*3160|0)+172>>2]=a1;c[a2+(aY*3160|0)+1196>>2]=a1;c[a2+(aY*3160|0)+2220>>2]=a1;a1=aX+1280|0;c[a2+(aY*3160|0)+176>>2]=a1;c[a2+(aY*3160|0)+1200>>2]=a1;c[a2+(aY*3160|0)+2224>>2]=a1;a1=aX+1536|0;c[a2+(aY*3160|0)+180>>2]=a1;c[a2+(aY*3160|0)+1204>>2]=a1;c[a2+(aY*3160|0)+2228>>2]=a1;a1=aX+1792|0;c[a2+(aY*3160|0)+184>>2]=a1;c[a2+(aY*3160|0)+1208>>2]=a1;c[a2+(aY*3160|0)+2232>>2]=a1;a1=c[2387082]|0;c[a2+(aY*3160|0)+188>>2]=a1;c[a2+(aY*3160|0)+1212>>2]=a1;c[a2+(aY*3160|0)+2236>>2]=a1;aX=a1+256|0;c[a2+(aY*3160|0)+192>>2]=aX;c[a2+(aY*3160|0)+1216>>2]=aX;c[a2+(aY*3160|0)+2240>>2]=aX;aX=a1+512|0;c[a2+(aY*3160|0)+196>>2]=aX;c[a2+(aY*3160|0)+1220>>2]=aX;c[a2+(aY*3160|0)+2244>>2]=aX;aX=a1+768|0;c[a2+(aY*3160|0)+200>>2]=aX;c[a2+(aY*3160|0)+1224>>2]=aX;c[a2+(aY*3160|0)+2248>>2]=aX;aX=a1+1024|0;c[a2+(aY*3160|0)+204>>2]=aX;c[a2+(aY*3160|0)+1228>>2]=aX;c[a2+(aY*3160|0)+2252>>2]=aX;aX=a1+1280|0;c[a2+(aY*3160|0)+208>>2]=aX;c[a2+(aY*3160|0)+1232>>2]=aX;c[a2+(aY*3160|0)+2256>>2]=aX;aX=a1+1536|0;c[a2+(aY*3160|0)+212>>2]=aX;c[a2+(aY*3160|0)+1236>>2]=aX;c[a2+(aY*3160|0)+2260>>2]=aX;aX=a1+1792|0;c[a2+(aY*3160|0)+216>>2]=aX;c[a2+(aY*3160|0)+1240>>2]=aX;c[a2+(aY*3160|0)+2264>>2]=aX;aX=c[2387100]|0;c[a2+(aY*3160|0)+220>>2]=aX;c[a2+(aY*3160|0)+1244>>2]=aX;c[a2+(aY*3160|0)+2268>>2]=aX;a1=aX+256|0;c[a2+(aY*3160|0)+224>>2]=a1;c[a2+(aY*3160|0)+1248>>2]=a1;c[a2+(aY*3160|0)+2272>>2]=a1;a1=aX+512|0;c[a2+(aY*3160|0)+228>>2]=a1;c[a2+(aY*3160|0)+1252>>2]=a1;c[a2+(aY*3160|0)+2276>>2]=a1;a1=aX+768|0;c[a2+(aY*3160|0)+232>>2]=a1;c[a2+(aY*3160|0)+1256>>2]=a1;c[a2+(aY*3160|0)+2280>>2]=a1;a1=aX+1024|0;c[a2+(aY*3160|0)+236>>2]=a1;c[a2+(aY*3160|0)+1260>>2]=a1;c[a2+(aY*3160|0)+2284>>2]=a1;a1=aX+1280|0;c[a2+(aY*3160|0)+240>>2]=a1;c[a2+(aY*3160|0)+1264>>2]=a1;c[a2+(aY*3160|0)+2288>>2]=a1;a1=aX+1536|0;c[a2+(aY*3160|0)+244>>2]=a1;c[a2+(aY*3160|0)+1268>>2]=a1;c[a2+(aY*3160|0)+2292>>2]=a1;a1=aX+1792|0;c[a2+(aY*3160|0)+248>>2]=a1;c[a2+(aY*3160|0)+1272>>2]=a1;c[a2+(aY*3160|0)+2296>>2]=a1;a1=c[2386382]|0;c[a2+(aY*3160|0)+252>>2]=a1;c[a2+(aY*3160|0)+1276>>2]=a1;c[a2+(aY*3160|0)+2300>>2]=a1;aX=a1+256|0;c[a2+(aY*3160|0)+256>>2]=aX;c[a2+(aY*3160|0)+1280>>2]=aX;c[a2+(aY*3160|0)+2304>>2]=aX;aX=a1+512|0;c[a2+(aY*3160|0)+260>>2]=aX;c[a2+(aY*3160|0)+1284>>2]=aX;c[a2+(aY*3160|0)+2308>>2]=aX;aX=a1+768|0;c[a2+(aY*3160|0)+264>>2]=aX;c[a2+(aY*3160|0)+1288>>2]=aX;c[a2+(aY*3160|0)+2312>>2]=aX;aX=a1+1024|0;c[a2+(aY*3160|0)+268>>2]=aX;c[a2+(aY*3160|0)+1292>>2]=aX;c[a2+(aY*3160|0)+2316>>2]=aX;aX=a1+1280|0;c[a2+(aY*3160|0)+272>>2]=aX;c[a2+(aY*3160|0)+1296>>2]=aX;c[a2+(aY*3160|0)+2320>>2]=aX;aX=a1+1536|0;c[a2+(aY*3160|0)+276>>2]=aX;c[a2+(aY*3160|0)+1300>>2]=aX;c[a2+(aY*3160|0)+2324>>2]=aX;aX=a1+1792|0;c[a2+(aY*3160|0)+280>>2]=aX;c[a2+(aY*3160|0)+1304>>2]=aX;c[a2+(aY*3160|0)+2328>>2]=aX;aX=c[3530266]|0;a1=64;aT=64;while(1){aV=aX+((aT<<8)+49152)|0;c[a2+(aY*3160|0)+60+(aT<<2)>>2]=aV;c[a2+(aY*3160|0)+60+(aT+512<<2)>>2]=aV;aV=a1+1&65535;if((aV&65535)>127){a8=128;a9=128;break}else{a1=aV;aT=aV&65535}}while(1){aT=aX+(a9<<8)|0;c[a2+(aY*3160|0)+60+(a9<<2)>>2]=aT;c[a2+(aY*3160|0)+60+(a9+512<<2)>>2]=aT;aT=a8+1&65535;if((aT&65535)>255){break}else{a8=aT;a9=aT&65535}}c[a2+(aY*3160|0)+3136>>2]=2432;aX=(fa(c[c[642608+(c[2436]<<2)>>2]>>2]|0,336512)|0)==0;c[a2+(aY*3160|0)+3132>>2]=aX?3056:3262;aX=a2+(aY*3160|0)|0;if((aX|0)!=0){aT=aX;gGC(aT|0,9642704,60)|0}c[aQ>>2]=c[2113194];c[3528552]=-1;fvI();c[3528556]=0;aT=c[2433594]|0;c[2443776]=aT;L36638:do{if((aT|0)!=0){aX=aT|0;gGC(9660952,aX|0,52)|0;switch(a[9660952]|0){case 0:{c[2309668]=638960;break L36638;break};case 1:{c[2309668]=634096;break L36638;break};case 3:{c[2309668]=639984;break L36638;break};case 4:{c[2309668]=7356016;break L36638;break};case 5:{c[2309668]=7354992;break L36638;break};case 2:{c[2309668]=638960;break L36638;break};default:{break L36638}}}}while(0);aQ=c[2432850]|0;c[2113164]=aQ;aY=c[3527438]|0;c[aT+68>>2]=aY;c[aT+1092>>2]=aY;c[aT+2116>>2]=aY;a2=aY+256|0;c[aT+72>>2]=a2;c[aT+1096>>2]=a2;c[aT+2120>>2]=a2;a2=aY+512|0;c[aT+76>>2]=a2;c[aT+1100>>2]=a2;c[aT+2124>>2]=a2;a2=aY+768|0;c[aT+80>>2]=a2;c[aT+1104>>2]=a2;c[aT+2128>>2]=a2;a2=aY+1024|0;c[aT+84>>2]=a2;c[aT+1108>>2]=a2;c[aT+2132>>2]=a2;a2=aY+1280|0;c[aT+88>>2]=a2;c[aT+1112>>2]=a2;c[aT+2136>>2]=a2;a2=c[3527436]|0;aY=128;aX=128;while(1){a1=a2+(aX<<8)|0;c[aT+68+(aX<<2)>>2]=a1;c[aT+68+(aX+512<<2)>>2]=a1;a1=aY+1&65535;if((a1&65535)>255){break}else{aY=a1;aX=a1&65535}}c[aT+3148>>2]=406;c[aT+3152>>2]=3306;aX=aT|0;gGC(aX|0,9660952,52)|0;c[2432850]=aQ;c[2443776]=0;c[3528556]=-1;c[2424]=5800;U6(3e6,1494,2124,0);c[2438222]=15e5;c[2433520]=2448;c[2406670]=2016;c[3528466]=6844;c[2443840]=1364;h[745399]=.7;a[3203272]=1;Vr(1,15e5,0,72,26,1);c[2438228]=12e5;c[2433526]=92;c[2406676]=958;c[3528472]=8304;c[2443846]=1705;h[745419]=.2;a[3203368]=1;h[745418]=.23;a[3203360]=1;h[745417]=.23;a[3203352]=1;h[745416]=.23;a[3203344]=1;aX=c[642608+(c[2436]<<2)>>2]|0;aY=c[aX+128>>2]|0;if((c[aX+52>>2]&4|0)==0){c[2113068]=aY;a2=c[aX+132>>2]|0;c[2113070]=a2;c[2443814]=aY;c[2440436]=a2;ba=aY;bb=a2}else{c[2113070]=aY;a2=c[aX+132>>2]|0;c[2113068]=a2;c[2440436]=aY;c[2443814]=a2;ba=a2;bb=aY}aY=ag(ba<<1,bb)|0;a2=gGq(aY)|0;c[2112926]=a2;if((a2|0)!=0){gGz(a2|0,0,aY|0)}a[9623400]=0;aY=c[2414556]|0;gGz(aY|0,0,(c[2411456]|0)-aY|0);c[3528552]=0;aY=c[2433426]|0;if((aY|0)!=0){a2=aY;gGC(9642704,a2|0,60)|0}b[4821352]=c[2410676]&65535;fC1();a2=(a[9642745]&1)==0;c[2430032]=a2?1595912:1595656;c[2429672]=a2?1114752:1114496;c[2429670]=a2?1114240:1113984;c[2444186]=a2?4654424:4654168;c[2113194]=c[9721800+(c[3528552]<<2)>>2];fC2();a2=c[3528552]|0;aY=(c[2433426]|0)+(a2*3160|0)|0;if((aY|0)!=0){aX=aY;gGC(aX|0,9642704,60)|0}c[9721800+(a2<<2)>>2]=c[2113194];c[3528552]=-1;c[3528556]=0;a2=c[2433594]|0;c[2443776]=a2;L36664:do{if((a2|0)!=0){aX=a2|0;gGC(9660952,aX|0,52)|0;switch(a[9660952]|0){case 0:{c[2309668]=638960;break L36664;break};case 1:{c[2309668]=634096;break L36664;break};case 3:{c[2309668]=639984;break L36664;break};case 4:{c[2309668]=7356016;break L36664;break};case 5:{c[2309668]=7354992;break L36664;break};case 2:{c[2309668]=638960;break L36664;break};default:{break L36664}}}}while(0);c[2113164]=c[2432850];gu[c[a2+56>>2]&16383]();aQ=c[2443776]|0;if((aQ|0)!=0){aT=aQ|0;gGC(aT|0,9660952,52)|0}c[9731400+(c[3528556]<<2)>>2]=c[2113164];c[2443776]=0;c[3528556]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){aT=0;do{lN(aT);mB(aT);aT=aT+1|0;}while((aT|0)<(c[2385508]|0))}c[2443825]=1073676288;c[2443824]=1073676288;c[2443817]=1073676288;c[2443816]=1073676288;h[883199]=0.0;c[3528506]=0;lw(c[3540986]|0);c[2440606]=0;c[2444190]=0;aZ=0;i=e;return aZ|0}}while(0);c[2414854]=0;aZ=1;i=e;return aZ|0}function aGz(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c[2113196]=0;b=c[2433426]|0;if((b|0)!=0){gGr(b);c[2433426]=0}b=a[7452592]|0;if(b){d=0;e=b&1;while(1){b=14163944+(d<<2)|0;f=c[b>>2]|0;g=c[2113006]|0;if((g|0)==0){h=28653}else{i=g-1|0;c[2113006]=i;if((i|0)==0){h=28653}}if((h|0)==28653){h=0;c[2383474]=0}if((f|0)==0){j=e}else{gGr(f);j=a[7452592]&1}c[b>>2]=0;b=d+1|0;if((b|0)<(j|0)){d=b;e=j}else{break}}}a[7452592]=0;c[2438222]=0;c[2433520]=0;c[2406670]=0;c[3528466]=0;j=c[2406686]|0;if((j|0)!=0){gGr(j);c[2406686]=0}c[2432974]=0;c[2113070]=0;c[2113068]=0;j=c[2112926]|0;if((j|0)!=0){gGr(j);c[2112926]=0}fvR();j=c[3541518]|0;if((j|0)!=0){gGr(j|0);c[3541518]=0}if((c[2385508]|0)>0){c[2113008]=0;c[2076598]=0;c[2383582]=0}c[2438228]=0;c[2433526]=0;c[2406676]=0;c[3528472]=0;j=c[2406680]|0;if((j|0)!=0){gGr(j);c[2406680]=0}c[2385508]=0;c[2432978]=0;a[64240]=0;j=c[2414854]|0;e=0;while(1){if((e|0)>=1024){h=28672;break}k=9638528+(e<<2)|0;if((c[k>>2]|0)==(j|0)){break}else{e=e+1|0}}if((h|0)==28672){c[2414854]=0;return 0}gGr(j);c[k>>2]=0;c[2414854]=0;return 0}function aGA(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0;if((a[9623400]|0)!=0){a[9623400]=0;d=c[2414556]|0;gGz(d|0,0,(c[2411456]|0)-d|0);c[3528552]=0;d=c[2433426]|0;if((d|0)!=0){e=d;gGC(9642704,e|0,60)|0}b[4821352]=c[2410676]&65535;fC1();e=(a[9642745]&1)==0;c[2430032]=e?1595912:1595656;c[2429672]=e?1114752:1114496;c[2429670]=e?1114240:1113984;c[2444186]=e?4654424:4654168;c[2113194]=c[9721800+(c[3528552]<<2)>>2];fC2();e=c[3528552]|0;d=(c[2433426]|0)+(e*3160|0)|0;if((d|0)!=0){f=d;gGC(f|0,9642704,60)|0}c[9721800+(e<<2)>>2]=c[2113194];c[3528552]=-1;c[3528556]=0;e=c[2433594]|0;c[2443776]=e;L36732:do{if((e|0)!=0){f=e|0;gGC(9660952,f|0,52)|0;switch(a[9660952]|0){case 4:{c[2309668]=7356016;break L36732;break};case 2:{c[2309668]=638960;break L36732;break};case 0:{c[2309668]=638960;break L36732;break};case 1:{c[2309668]=634096;break L36732;break};case 5:{c[2309668]=7354992;break L36732;break};case 3:{c[2309668]=639984;break L36732;break};default:{break L36732}}}}while(0);c[2113164]=c[2432850];gu[c[e+56>>2]&16383]();e=c[2443776]|0;if((e|0)!=0){f=e|0;gGC(f|0,9660952,52)|0}c[9731400+(c[3528556]<<2)>>2]=c[2113164];c[2443776]=0;c[3528556]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){f=0;do{lN(f);mB(f);f=f+1|0;}while((f|0)<(c[2385508]|0))}c[2443825]=1073676288;c[2443824]=1073676288;c[2443817]=1073676288;c[2443816]=1073676288;h[883199]=0.0;c[3528506]=0;lw(c[3540986]|0);c[2440606]=0;c[2444190]=0}f=c[2113196]|0;if((f|0)>0){gGz(9721800,0,((f|0)>1?f<<2:4)|0)}c[2113194]=0;f=c[2113166]|0;if((f|0)>0){gGz(9731400,0,((f|0)>1?f<<2:4)|0)}c[2113164]=0;gGz(9550152,-1|0,5);f=0;e=-1;d=-1;g=-1;i=-1;j=-1;do{e=((a[9632392+f|0]&1)<<f^e&255)&255;d=((a[9630304+f|0]&1)<<f^d&255)&255;g=((a[9629184+f|0]&1)<<f^g&255)&255;i=((a[9629136+f|0]&1)<<f^i&255)&255;j=((a[9628864+f|0]&1)<<f^j&255)&255;f=f+1|0;}while((f|0)<8);a[9550152]=e;a[9550153]=d;a[9550154]=g;a[9550155]=i;a[9550156]=j;c[3528556]=0;j=c[2433594]|0;c[2443776]=j;L36759:do{if((j|0)!=0){i=j|0;gGC(9660952,i|0,52)|0;switch(a[9660952]|0){case 5:{c[2309668]=7354992;break L36759;break};case 2:{c[2309668]=638960;break L36759;break};case 3:{c[2309668]=639984;break L36759;break};case 1:{c[2309668]=634096;break L36759;break};case 4:{c[2309668]=7356016;break L36759;break};case 0:{c[2309668]=638960;break L36759;break};default:{break L36759}}}}while(0);c[2113164]=c[2432850];c[3528552]=0;j=c[2433426]|0;if((j|0)!=0){i=j;gGC(9642704,i|0,60)|0}b[4821352]=c[2410676]&65535;fC1();i=(a[9642745]&1)==0;c[2430032]=i?1595912:1595656;c[2429672]=i?1114752:1114496;c[2429670]=i?1114240:1113984;c[2444186]=i?4654424:4654168;c[2113194]=c[9721800+(c[3528552]<<2)>>2];c[2408976]=128;i=0;do{do{if((i|0)==31){c[2408976]=128;if((a[c[3528482]|0]|0)==0){break}fC3();fC4(0)|0;if((a[9642761]|0)!=0){a[9642761]=0}fC4(0)|0}else if((i|0)==1){c[2408976]=0}}while(0);Sb(i*6465|0);U1(i*808|0);i=i+1|0;}while((i|0)<32);i=c[2438228]|0;j=gGS(-1285554176,98655,i,(i|0)<0|0?-1:0)|0;i=j;Sb(206896);j=c[2443830]|0;if((j|0)<1073676288){c[2443830]=j-i}j=c[2443831]|0;if((j|0)<1073676288){c[2443831]=j-i}j=(c[3528512]|0)-i|0;c[3528512]=(j|0)<0?0:j;j=c[2438222]|0;i=gGS(-160694272,12331,j,(j|0)<0|0?-1:0)|0;j=i;U1(25862);i=c[2443824]|0;if((i|0)<1073676288){c[2443824]=i-j}i=c[2443825]|0;if((i|0)<1073676288){c[2443825]=i-j}i=(c[3528506]|0)-j|0;c[3528506]=(i|0)<0?0:i;i=c[2112964]|0;if((i|0)!=0){gg[c[3542114]&4095](i,a[9688]|0?534:0);gg[c[3542122]&4095](c[2112964]|0,a[9688]|0?534:0)}i=c[3528552]|0;j=(c[2433426]|0)+(i*3160|0)|0;if((j|0)!=0){g=j;gGC(g|0,9642704,60)|0}c[9721800+(i<<2)>>2]=c[2113194];c[3528552]=-1;i=c[2443776]|0;if((i|0)!=0){g=i|0;gGC(g|0,9660952,52)|0}c[9731400+(c[3528556]<<2)>>2]=c[2113164];c[2443776]=0;c[3528556]=-1;if((c[2112968]|0)==0){k=c[2386556]|0;l=c[2386382]|0;gGC(k|0,l|0,2048)|0;return 0}g=c[(c[642608+(c[2436]<<2)>>2]|0)+112>>2]|0;if((g|0)==0){k=c[2386556]|0;l=c[2386382]|0;gGC(k|0,l|0,2048)|0;return 0}gD[g&8191]()|0;k=c[2386556]|0;l=c[2386382]|0;gGC(k|0,l|0,2048)|0;return 0}function aGB(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((d&64|0)==0){aHx(d,e);return 0}fyq(d);Vb(d,e);if((d&2|0)==0){aHx(d,e);return 0}c[3528552]=0;f=c[2433426]|0;if((f|0)!=0){g=f;gGC(9642704,g|0,60)|0}b[4821352]=c[2410676]&65535;fC1();g=(a[9642745]&1)==0;c[2430032]=g?1595912:1595656;c[2429672]=g?1114752:1114496;c[2429670]=g?1114240:1113984;c[2444186]=g?4654424:4654168;g=c[3528552]|0;f=9721800+(g<<2)|0;c[2113194]=c[f>>2];h=c[3530266]|0;i=c[2433426]|0;j=(c[2406854]|0)+49152|0;k=64;l=64;while(1){m=h+(j+(l<<8))|0;c[i+(g*3160|0)+60+(l<<2)>>2]=m;c[i+(g*3160|0)+60+(l+512<<2)>>2]=m;m=k+1&65535;if((m&65535)>127){break}else{k=m;l=m&65535}}l=i+(g*3160|0)|0;if((l|0)!=0){g=l;gGC(g|0,9642704,60)|0}c[f>>2]=c[2113194];c[3528552]=-1;aHx(d,e);return 0}function aGC(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>23){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2838028+(b*112|0)>>2];c[a+104>>2]=c[2838032+(b*112|0)>>2];c[a+108>>2]=c[2838036+(b*112|0)>>2];d=0;return d|0}function aGD(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<24&(d|0)==0)){e=1;return e|0}c[a>>2]=2837928+(b*112|0);e=0;return e|0}function aGE(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1259600+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aGF(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>28){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3925312+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aGG(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if((a[9547080]|0)!=0){b=c[2387100]|0;e=c[3529894]|0;f=0;do{g=a[b+f|0]|0;h=a[b+(f+1024)|0]|0;i=(g&255)>>>4;c[e+(f<<2)>>2]=((h&8|h<<4)&255)>>>3|((g&8|g<<4)&255)<<8&63488|((i<<4|i)&255)<<3&2016;f=f+1|0;}while((f|0)<1024)}aHO(0,1);aHO(0,0);aHH(0);aHO(1,1);aHO(1,0);f=c[2386282]|0;e=c[2112926]|0;b=c[3530752]|0;i=c[2113068]|0;g=0;do{h=(g>>5<<3)-8|0;if((h|0)>-1&(h|0)<(i|0)){j=g<<1;k=d[f+j|0]|0;Sr(e,k<<8&3840|d[f+(j|1)|0],g<<3&248,h,k>>>4&7,3,0,0,b)}g=g+1|0;}while((g|0)<1024);R8(c[3529894]|0);return 0}function aGH(b){b=b|0;var d=0;switch(b&65535|0){case 15364:{d=a[9634673]|0;break};case 15363:{d=a[9634672]|0;break};case 15361:{d=a[9550153]|0;break};case 15360:{d=a[9550152]|0;break};case 15362:{d=(a[9550154]&127|c[2408976])&255;break};default:{d=0}}return d|0}function aGI(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=d&65535;switch(f|0){case 16003:{d=c[3528552]|0;g=c[2433426]|0;h=g+(d*3160|0)|0;if((h|0)!=0){i=h;gGC(i|0,9642704,60)|0}c[9721800+(d<<2)>>2]=c[2113194];c[3528552]=1;d=g+3160|0;if((d|0)!=0){g=d;gGC(9642704,g|0,60)|0}b[4821352]=c[2410676]&65535;fC1();g=(a[9642745]&1)==0;c[2430032]=g?1595912:1595656;c[2429672]=g?1114752:1114496;c[2429670]=g?1114240:1113984;c[2444186]=g?4654424:4654168;g=c[3528552]|0;d=9721800+(g<<2)|0;i=c[d>>2]|0;c[2113194]=i;a[9642747]=0;h=c[2433426]|0;j=h+(g*3160|0)|0;if((j|0)==0){c[d>>2]=i;c[3528552]=0;if((h|0)!=0){k=28814}}else{g=j;gGC(g|0,9642704,60)|0;c[d>>2]=i;c[3528552]=0;k=28814}if((k|0)==28814){i=h;gGC(9642704,i|0,60)|0}b[4821352]=c[2410676]&65535;fC1();i=(a[9642745]&1)==0;c[2430032]=i?1595912:1595656;c[2429672]=i?1114752:1114496;c[2429670]=i?1114240:1113984;c[2444186]=i?4654424:4654168;c[2113194]=c[9721800+(c[3528552]<<2)>>2];return};case 15616:{i=(e&255)<<14&245760;c[2406854]=i;h=c[3530266]|0;d=c[3528552]|0;g=c[2433426]|0;j=i+49152|0;i=64;l=64;while(1){m=h+(j+(l<<8))|0;c[g+(d*3160|0)+60+(l<<2)>>2]=m;c[g+(d*3160|0)+60+(l+512<<2)>>2]=m;m=i+1&65535;if((m&65535)>127){break}else{i=m;l=m&65535}}return};case 16e3:{l=c[3528552]|0;i=c[2433426]|0;d=i+(l*3160|0)|0;if((d|0)!=0){g=d;gGC(g|0,9642704,60)|0}c[9721800+(l<<2)>>2]=c[2113194];c[3528552]=1;l=i+3160|0;if((l|0)!=0){i=l;gGC(9642704,i|0,60)|0}b[4821352]=c[2410676]&65535;fC1();i=(a[9642745]&1)==0;c[2430032]=i?1595912:1595656;c[2429672]=i?1114752:1114496;c[2429670]=i?1114240:1113984;c[2444186]=i?4654424:4654168;c[2113194]=c[9721800+(c[3528552]<<2)>>2];a[9642747]=1;fC1();i=c[3528552]|0;l=c[2433426]|0;g=l+(i*3160|0)|0;if((g|0)==0){c[9721800+(i<<2)>>2]=c[2113194];c[3528552]=0;if((l|0)!=0){k=28803}}else{d=g;gGC(d|0,9642704,60)|0;c[9721800+(i<<2)>>2]=c[2113194];c[3528552]=0;k=28803}if((k|0)==28803){k=l;gGC(9642704,k|0,60)|0}b[4821352]=c[2410676]&65535;fC1();k=(a[9642745]&1)==0;c[2430032]=k?1595912:1595656;c[2429672]=k?1114752:1114496;c[2429670]=k?1114240:1113984;c[2444186]=k?4654424:4654168;c[2113194]=c[9721800+(c[3528552]<<2)>>2];return};case 15488:{k=c[2386556]|0;l=c[2386382]|0;gGC(k|0,l|0,2048)|0;return};case 15744:{a[c[3528212]|0]=e;gg[c[(c[2443776]|0)+64>>2]&4095](32,1);gj[c[(c[2443776]|0)+52>>2]&4095](0)|0;gg[c[(c[2443776]|0)+64>>2]&4095](32,0);gj[c[(c[2443776]|0)+52>>2]&4095](0)|0;return};case 16002:{a[9642747]=1;fC1();return};case 16001:{a[9642747]=0;return};default:{if((f&65504|0)!=15360){return}a[(c[3529872]|0)+(f&31)|0]=e;return}}}function aGJ(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;e=d&65535;if((e|0)==16001){d=c[3528552]|0;f=c[2433426]|0;g=f+(d*3160|0)|0;if((g|0)==0){c[9721800+(d<<2)>>2]=c[2113194];c[3528552]=0;if((f|0)!=0){h=28837}}else{i=g;gGC(i|0,9642704,60)|0;c[9721800+(d<<2)>>2]=c[2113194];c[3528552]=0;h=28837}if((h|0)==28837){d=f;gGC(9642704,d|0,60)|0}b[4821352]=c[2410676]&65535;fC1();d=(a[9642745]&1)==0;c[2430032]=d?1595912:1595656;c[2429672]=d?1114752:1114496;c[2429670]=d?1114240:1113984;c[2444186]=d?4654424:4654168;d=c[3528552]|0;f=9721800+(d<<2)|0;i=c[f>>2]|0;c[2113194]=i;a[9642747]=0;g=c[2433426]|0;j=g+(d*3160|0)|0;if((j|0)!=0){d=j;gGC(d|0,9642704,60)|0}c[f>>2]=i;c[3528552]=1;i=g+3160|0;if((i|0)!=0){g=i;gGC(9642704,g|0,60)|0}b[4821352]=c[2410676]&65535;fC1();g=(a[9642745]&1)==0;c[2430032]=g?1595912:1595656;c[2429672]=g?1114752:1114496;c[2429670]=g?1114240:1113984;c[2444186]=g?4654424:4654168;c[2113194]=c[9721800+(c[3528552]<<2)>>2];return}else if((e|0)==16003){a[9642747]=0;return}else if((e|0)==16e3){a[9642747]=1;fC1();g=c[3528552]|0;i=c[2433426]|0;f=i+(g*3160|0)|0;if((f|0)==0){c[9721800+(g<<2)>>2]=c[2113194];c[3528552]=0;if((i|0)!=0){h=28832}}else{d=f;gGC(d|0,9642704,60)|0;c[9721800+(g<<2)>>2]=c[2113194];c[3528552]=0;h=28832}if((h|0)==28832){g=i;gGC(9642704,g|0,60)|0}b[4821352]=c[2410676]&65535;fC1();g=(a[9642745]&1)==0;c[2430032]=g?1595912:1595656;c[2429672]=g?1114752:1114496;c[2429670]=g?1114240:1113984;c[2444186]=g?4654424:4654168;c[2113194]=c[9721800+(c[3528552]<<2)>>2];return}else if((e|0)==16002){e=c[3528552]|0;g=c[2433426]|0;i=g+(e*3160|0)|0;if((i|0)==0){c[9721800+(e<<2)>>2]=c[2113194];c[3528552]=0;if((g|0)!=0){h=28846}}else{d=i;gGC(d|0,9642704,60)|0;c[9721800+(e<<2)>>2]=c[2113194];c[3528552]=0;h=28846}if((h|0)==28846){h=g;gGC(9642704,h|0,60)|0}b[4821352]=c[2410676]&65535;fC1();h=(a[9642745]&1)==0;c[2430032]=h?1595912:1595656;c[2429672]=h?1114752:1114496;c[2429670]=h?1114240:1113984;c[2444186]=h?4654424:4654168;c[2113194]=c[9721800+(c[3528552]<<2)>>2];a[9642747]=1;fC1();h=c[3528552]|0;g=c[2433426]|0;e=g+(h*3160|0)|0;if((e|0)!=0){d=e;gGC(d|0,9642704,60)|0}c[9721800+(h<<2)>>2]=c[2113194];c[3528552]=1;h=g+3160|0;if((h|0)!=0){g=h;gGC(9642704,g|0,60)|0}b[4821352]=c[2410676]&65535;fC1();g=(a[9642745]&1)==0;c[2430032]=g?1595912:1595656;c[2429672]=g?1114752:1114496;c[2429670]=g?1114240:1113984;c[2444186]=g?4654424:4654168;c[2113194]=c[9721800+(c[3528552]<<2)>>2];return}else{return}}function aGK(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6508972+(b*112|0)>>2];c[a+104>>2]=c[6508976+(b*112|0)>>2];c[a+108>>2]=c[6508980+(b*112|0)>>2];d=0;return d|0}function aGL(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=6508872+(b*112|0);e=0;return e|0}function aGM(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5187392+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aGN(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>44){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6822200+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aGO(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0;e=i;i=i+1560|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;B=e+1200|0;C=e+1312|0;D=e+1320|0;E=e+1432|0;F=e+1440|0;G=e+1552|0;c[2414854]=0;c[3530266]=0;c[2386358]=327680;c[3527436]=458752;c[3527440]=589824;c[3530752]=655360;c[3530516]=786432;c[3530384]=1835008;c[3530308]=2883584;c[3531056]=3932160;c[2407020]=3934208;c[3529894]=3938304;c[2414556]=3942400;c[3530268]=3942400;c[2386282]=3950592;c[2387082]=3952640;c[2387076]=3956736;c[3529872]=3960832;c[3529870]=3960864;c[2386744]=3960896;c[2386382]=3961920;c[2386556]=3963968;c[2387100]=3966016;c[3527438]=3968064;c[3528212]=3970112;c[3528482]=3970113;c[2432942]=3970114;c[3528652]=3970115;c[2411456]=3970116;H=0;while(1){if((H|0)>=1024){break}I=9638528+(H<<2)|0;if((c[I>>2]|0)==0){J=28888;break}else{H=H+1|0}}do{if((J|0)==28888){H=gGq(3970116)|0;c[I>>2]=H;if((H|0)==0){break}c[2414854]=H;gGz(H|0,0,3970116);c[3530266]=H;c[2386358]=H+327680;c[3527436]=H+458752;c[3527440]=H+589824;c[3530752]=H+655360;c[3530516]=H+786432;c[3530384]=H+1835008;c[3530308]=H+2883584;c[3531056]=H+3932160;c[2407020]=H+3934208;c[3529894]=H+3938304;K=H+3942400|0;c[2414556]=K;c[3530268]=K;c[2386282]=H+3950592;c[2387082]=H+3952640;c[2387076]=H+3956736;c[3529872]=H+3960832;c[3529870]=H+3960864;c[2386744]=H+3960896;c[2386382]=H+3961920;c[2386556]=H+3963968;c[2387100]=H+3966016;c[3527438]=H+3968064;c[3528212]=H+3970112;c[3528482]=H+3970113;c[2432942]=H+3970114;c[3528652]=H+3970115;K=H+3970116|0;c[2411456]=K;c[2413996]=K;K=H+32768|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}H=F+108|0;c[H>>2]=0;M=F+100|0;c[M>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](F,0)|0;do{if((c[H>>2]|0)!=0){N=c[M>>2]|0;c[G>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](G,0,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(K,0,0)|0)==0){break}else{L=1}i=e;return L|0}}while(0);K=(c[3530266]|0)+65536|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}M=D+108|0;c[M>>2]=0;H=D+100|0;c[H>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](D,1)|0;do{if((c[M>>2]|0)!=0){N=c[H>>2]|0;c[E>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](E,1,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(K,0,1)|0)==0){break}else{L=1}i=e;return L|0}}while(0);K=c[2386358]|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}H=B+108|0;c[H>>2]=0;M=B+100|0;c[M>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](B,2)|0;do{if((c[H>>2]|0)!=0){N=c[M>>2]|0;c[C>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](C,2,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(K,0,2)|0)==0){break}else{L=1}i=e;return L|0}}while(0);K=(c[3527436]|0)+32768|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}M=z+108|0;c[M>>2]=0;H=z+100|0;c[H>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](z,3)|0;do{if((c[M>>2]|0)!=0){N=c[H>>2]|0;c[A>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](A,3,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(K,0,3)|0)==0){break}else{L=1}i=e;return L|0}}while(0);K=c[3530752]|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}H=x+108|0;c[H>>2]=0;M=x+100|0;c[M>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](x,4)|0;do{if((c[H>>2]|0)!=0){N=c[M>>2]|0;c[y>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](y,4,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(K,0,4)|0)==0){break}else{L=1}i=e;return L|0}}while(0);K=c[3530516]|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}M=v+108|0;c[M>>2]=0;H=v+100|0;c[H>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](v,5)|0;do{if((c[M>>2]|0)!=0){N=c[H>>2]|0;c[w>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](w,5,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(K,0,5)|0)==0){break}else{L=1}i=e;return L|0}}while(0);K=(c[3530516]|0)+131072|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}H=t+108|0;c[H>>2]=0;M=t+100|0;c[M>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](t,6)|0;do{if((c[H>>2]|0)!=0){N=c[M>>2]|0;c[u>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](u,6,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(K,0,6)|0)==0){break}else{L=1}i=e;return L|0}}while(0);K=(c[3530516]|0)+262144|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}M=r+108|0;c[M>>2]=0;H=r+100|0;c[H>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](r,7)|0;do{if((c[M>>2]|0)!=0){N=c[H>>2]|0;c[s>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](s,7,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(K,0,7)|0)==0){break}else{L=1}i=e;return L|0}}while(0);K=(c[3530516]|0)+393216|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}H=p+108|0;c[H>>2]=0;M=p+100|0;c[M>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](p,8)|0;do{if((c[H>>2]|0)!=0){N=c[M>>2]|0;c[q>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](q,8,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(K,0,8)|0)==0){break}else{L=1}i=e;return L|0}}while(0);K=c[3530384]|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}M=n+108|0;c[M>>2]=0;H=n+100|0;c[H>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](n,9)|0;do{if((c[M>>2]|0)!=0){N=c[H>>2]|0;c[o>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](o,9,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(K,0,9)|0)==0){break}else{L=1}i=e;return L|0}}while(0);K=(c[3530384]|0)+131072|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}H=l+108|0;c[H>>2]=0;M=l+100|0;c[M>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](l,10)|0;do{if((c[H>>2]|0)!=0){N=c[M>>2]|0;c[m>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](m,10,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(K,0,10)|0)==0){break}else{L=1}i=e;return L|0}}while(0);K=(c[3530384]|0)+262144|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}M=j+108|0;c[M>>2]=0;H=j+100|0;c[H>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](j,11)|0;do{if((c[M>>2]|0)!=0){N=c[H>>2]|0;c[k>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](k,11,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(K,0,11)|0)==0){break}else{L=1}i=e;return L|0}}while(0);K=(c[3530384]|0)+393216|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}H=f+108|0;c[H>>2]=0;M=f+100|0;c[M>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](f,12)|0;do{if((c[H>>2]|0)!=0){N=c[M>>2]|0;c[g>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](g,12,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(K,0,12)|0)==0){break}else{L=1}i=e;return L|0}}while(0);K=c[3527436]|0;M=c[3527440]|0;H=32768;while(1){N=a[K+H|0]|0;a[M+H|0]=N<<1&64|N&-97|(N&255)>>>1&32;N=H+1|0;if((N|0)<65536){H=N}else{P=0;break}}while(1){if((P|0)>=1024){break}Q=9638528+(P<<2)|0;if((c[Q>>2]|0)==0){J=28946;break}else{P=P+1|0}}L37136:do{if((J|0)==28946){H=gGq(524288)|0;c[Q>>2]=H;if((H|0)==0){break}gGz(H|0,0,524288);M=c[3530752]|0;gGC(H|0,M|0,32768)|0;K=0;do{N=K<<6;gGz(M+N|0,0,64);O=N+98304|0;R=0;do{S=O+(c[609008+(R<<2)>>2]|0)|0;T=(R<<3)+N|0;U=0;do{V=S+(c[614800+(U<<2)>>2]|0)|0;if((d[H+((V|0)/8|0)|0]&128>>>((V&7)>>>0)|0)!=0){V=M+(T+U)|0;a[V]=a[V]|4}U=U+1|0;}while((U|0)<8);R=R+1|0;}while((R|0)<8);R=N+65536|0;O=0;do{U=R+(c[609008+(O<<2)>>2]|0)|0;T=(O<<3)+N|0;S=0;do{V=U+(c[614800+(S<<2)>>2]|0)|0;if((d[H+((V|0)/8|0)|0]&128>>>((V&7)>>>0)|0)!=0){V=M+(T+S)|0;a[V]=a[V]|2}S=S+1|0;}while((S|0)<8);O=O+1|0;}while((O|0)<8);O=N+32768|0;R=0;do{S=O+(c[609008+(R<<2)>>2]|0)|0;T=(R<<3)+N|0;U=0;do{V=S+(c[614800+(U<<2)>>2]|0)|0;if((d[H+((V|0)/8|0)|0]&128>>>((V&7)>>>0)|0)!=0){V=M+(T+U)|0;a[V]=a[V]|1}U=U+1|0;}while((U|0)<8);R=R+1|0;}while((R|0)<8);K=K+1|0;}while((K|0)<1024);K=c[3530516]|0;gGC(H|0,K|0,524288)|0;M=0;do{R=M<<8;gGz(K+R|0,0,256);N=0;do{O=1<<3-N;U=(c[704200+(N<<2)>>2]|0)+R|0;T=0;do{S=U+(c[609008+(T<<2)>>2]|0)|0;V=(T<<4)+R|0;W=0;do{X=S+(c[612640+(W<<2)>>2]|0)|0;if((d[H+((X|0)/8|0)|0]&128>>>((X&7)>>>0)|0)!=0){X=K+(V+W)|0;a[X]=(d[X]|O)&255}W=W+1|0;}while((W|0)<16);T=T+1|0;}while((T|0)<16);N=N+1|0;}while((N|0)<4);M=M+1|0;}while((M|0)<4096);M=c[3530384]|0;gGC(H|0,M|0,524288)|0;K=0;while(1){N=K<<8;gGz(M+N|0,0,256);R=0;do{T=1<<3-R;O=(c[704200+(R<<2)>>2]|0)+N|0;U=0;do{W=O+(c[609008+(U<<2)>>2]|0)|0;V=(U<<4)+N|0;S=0;do{X=W+(c[612640+(S<<2)>>2]|0)|0;if((d[H+((X|0)/8|0)|0]&128>>>((X&7)>>>0)|0)!=0){X=M+(V+S)|0;a[X]=(d[X]|T)&255}S=S+1|0;}while((S|0)<16);U=U+1|0;}while((U|0)<16);R=R+1|0;}while((R|0)<4);R=K+1|0;if((R|0)<4096){K=R}else{Y=0;break}}while(1){if((Y|0)>=1024){break L37136}Z=9638528+(Y<<2)|0;if((c[Z>>2]|0)==(H|0)){break}else{Y=Y+1|0}}gGr(H);c[Z>>2]=0}}while(0);c[3528552]=-1;c[2113196]=2;K=gGq(6320)|0;M=K;c[2433426]=M;do{if((K|0)==0){c[3528552]=0}else{gGz(K|0,0,6320);R=0;do{c[M+(R*3160|0)+3132>>2]=2102;c[M+(R*3160|0)+3136>>2]=2420;c[M+(R*3160|0)+3140>>2]=1856;c[M+(R*3160|0)+3144>>2]=1450;c[9721800+(R<<2)>>2]=0;N=0;do{c[M+(R*3160|0)+60+(N<<2)>>2]=0;N=N+1|0;}while((N|0)<768);R=R+1|0;}while((R|0)<2);c[2113194]=0;R=c[2427044]|0;c[9681616+(R<<3)>>2]=726904;c[9681620+(R<<3)>>2]=0;H=R+1|0;c[9681616+(H<<3)>>2]=726904;c[9681620+(H<<3)>>2]=1;c[2427044]=R+2;c[3528552]=0;if((K|0)==0){break}gGC(9642704,K|0,60)|0}}while(0);b[4821352]=c[2410676]&65535;fC1();K=(a[9642745]&1)==0;c[2430032]=K?1595912:1595656;c[2429672]=K?1114752:1114496;c[2429670]=K?1114240:1113984;c[2444186]=K?4654424:4654168;K=c[3528552]|0;M=9721800+(K<<2)|0;c[2113194]=c[M>>2];R=c[3530268]|0;H=c[2433426]|0;N=0;U=0;while(1){T=R+(U<<8)|0;c[H+(K*3160|0)+60+(U<<2)>>2]=T;c[H+(K*3160|0)+60+(U+256<<2)>>2]=T;c[H+(K*3160|0)+60+(U+512<<2)>>2]=T;T=N+1&65535;if((T&65535)>31){break}else{N=T;U=T&65535}}U=c[2386282]|0;c[H+(K*3160|0)+188>>2]=U;c[H+(K*3160|0)+1212>>2]=U;c[H+(K*3160|0)+2236>>2]=U;N=U+256|0;c[H+(K*3160|0)+192>>2]=N;c[H+(K*3160|0)+1216>>2]=N;c[H+(K*3160|0)+2240>>2]=N;N=U+512|0;c[H+(K*3160|0)+196>>2]=N;c[H+(K*3160|0)+1220>>2]=N;c[H+(K*3160|0)+2244>>2]=N;N=U+768|0;c[H+(K*3160|0)+200>>2]=N;c[H+(K*3160|0)+1224>>2]=N;c[H+(K*3160|0)+2248>>2]=N;N=U+1024|0;c[H+(K*3160|0)+204>>2]=N;c[H+(K*3160|0)+1228>>2]=N;c[H+(K*3160|0)+2252>>2]=N;N=U+1280|0;c[H+(K*3160|0)+208>>2]=N;c[H+(K*3160|0)+1232>>2]=N;c[H+(K*3160|0)+2256>>2]=N;N=U+1536|0;c[H+(K*3160|0)+212>>2]=N;c[H+(K*3160|0)+1236>>2]=N;c[H+(K*3160|0)+2260>>2]=N;N=U+1792|0;c[H+(K*3160|0)+216>>2]=N;c[H+(K*3160|0)+1240>>2]=N;c[H+(K*3160|0)+2264>>2]=N;N=c[2387082]|0;c[H+(K*3160|0)+220>>2]=N;c[H+(K*3160|0)+1244>>2]=N;c[H+(K*3160|0)+2268>>2]=N;U=N+256|0;c[H+(K*3160|0)+224>>2]=U;c[H+(K*3160|0)+1248>>2]=U;c[H+(K*3160|0)+2272>>2]=U;U=N+512|0;c[H+(K*3160|0)+228>>2]=U;c[H+(K*3160|0)+1252>>2]=U;c[H+(K*3160|0)+2276>>2]=U;U=N+768|0;c[H+(K*3160|0)+232>>2]=U;c[H+(K*3160|0)+1256>>2]=U;c[H+(K*3160|0)+2280>>2]=U;U=N+1024|0;c[H+(K*3160|0)+236>>2]=U;c[H+(K*3160|0)+1260>>2]=U;c[H+(K*3160|0)+2284>>2]=U;U=N+1280|0;c[H+(K*3160|0)+240>>2]=U;c[H+(K*3160|0)+1264>>2]=U;c[H+(K*3160|0)+2288>>2]=U;U=N+1536|0;c[H+(K*3160|0)+244>>2]=U;c[H+(K*3160|0)+1268>>2]=U;c[H+(K*3160|0)+2292>>2]=U;U=N+1792|0;c[H+(K*3160|0)+248>>2]=U;c[H+(K*3160|0)+1272>>2]=U;c[H+(K*3160|0)+2296>>2]=U;U=c[2386382]|0;c[H+(K*3160|0)+252>>2]=U;c[H+(K*3160|0)+1276>>2]=U;c[H+(K*3160|0)+2300>>2]=U;N=U+256|0;c[H+(K*3160|0)+256>>2]=N;c[H+(K*3160|0)+1280>>2]=N;c[H+(K*3160|0)+2304>>2]=N;N=U+512|0;c[H+(K*3160|0)+260>>2]=N;c[H+(K*3160|0)+1284>>2]=N;c[H+(K*3160|0)+2308>>2]=N;N=U+768|0;c[H+(K*3160|0)+264>>2]=N;c[H+(K*3160|0)+1288>>2]=N;c[H+(K*3160|0)+2312>>2]=N;N=U+1024|0;c[H+(K*3160|0)+268>>2]=N;c[H+(K*3160|0)+1292>>2]=N;c[H+(K*3160|0)+2316>>2]=N;N=U+1280|0;c[H+(K*3160|0)+272>>2]=N;c[H+(K*3160|0)+1296>>2]=N;c[H+(K*3160|0)+2320>>2]=N;N=U+1536|0;c[H+(K*3160|0)+276>>2]=N;c[H+(K*3160|0)+1300>>2]=N;c[H+(K*3160|0)+2324>>2]=N;N=U+1792|0;c[H+(K*3160|0)+280>>2]=N;c[H+(K*3160|0)+1304>>2]=N;c[H+(K*3160|0)+2328>>2]=N;N=c[2387100]|0;c[H+(K*3160|0)+284>>2]=N;c[H+(K*3160|0)+1308>>2]=N;c[H+(K*3160|0)+2332>>2]=N;U=N+256|0;c[H+(K*3160|0)+288>>2]=U;c[H+(K*3160|0)+1312>>2]=U;c[H+(K*3160|0)+2336>>2]=U;U=N+512|0;c[H+(K*3160|0)+292>>2]=U;c[H+(K*3160|0)+1316>>2]=U;c[H+(K*3160|0)+2340>>2]=U;U=N+768|0;c[H+(K*3160|0)+296>>2]=U;c[H+(K*3160|0)+1320>>2]=U;c[H+(K*3160|0)+2344>>2]=U;U=c[3530266]|0;N=64;R=64;while(1){T=U+((R<<8)+49152)|0;c[H+(K*3160|0)+60+(R<<2)>>2]=T;c[H+(K*3160|0)+60+(R+512<<2)>>2]=T;T=N+1&65535;if((T&65535)>127){_=128;$=128;break}else{N=T;R=T&65535}}while(1){R=U+($<<8)|0;c[H+(K*3160|0)+60+($<<2)>>2]=R;c[H+(K*3160|0)+60+($+512<<2)>>2]=R;R=_+1&65535;if((R&65535)>255){break}else{_=R;$=R&65535}}c[H+(K*3160|0)+3136>>2]=1790;c[H+(K*3160|0)+3132>>2]=2316;U=H+(K*3160|0)|0;if((U|0)!=0){R=U;gGC(R|0,9642704,60)|0}c[M>>2]=c[2113194];c[3528552]=1;R=H+3160|0;if((R|0)!=0){U=R;gGC(9642704,U|0,60)|0}b[4821352]=c[2410676]&65535;fC1();U=(a[9642745]&1)==0;c[2430032]=U?1595912:1595656;c[2429672]=U?1114752:1114496;c[2429670]=U?1114240:1113984;c[2444186]=U?4654424:4654168;U=c[3528552]|0;R=9721800+(U<<2)|0;c[2113194]=c[R>>2];N=c[3530268]|0;T=c[2433426]|0;O=0;S=0;while(1){V=N+(S<<8)|0;c[T+(U*3160|0)+60+(S<<2)>>2]=V;c[T+(U*3160|0)+60+(S+256<<2)>>2]=V;c[T+(U*3160|0)+60+(S+512<<2)>>2]=V;V=O+1&65535;if((V&65535)>14){break}else{O=V;S=V&65535}}S=(c[2387100]|0)+1024|0;c[T+(U*3160|0)+120>>2]=S;c[T+(U*3160|0)+1144>>2]=S;c[T+(U*3160|0)+2168>>2]=S;S=16;O=16;while(1){H=N+(O<<8)|0;c[T+(U*3160|0)+60+(O<<2)>>2]=H;c[T+(U*3160|0)+60+(O+256<<2)>>2]=H;c[T+(U*3160|0)+60+(O+512<<2)>>2]=H;H=S+1&65535;if((H&65535)>31){break}else{S=H;O=H&65535}}O=c[2386358]|0;S=64;N=64;while(1){H=O+(N<<8)|0;c[T+(U*3160|0)+60+(N<<2)>>2]=H;c[T+(U*3160|0)+60+(N+512<<2)>>2]=H;H=S+1&65535;if((H&65535)>255){break}else{S=H;N=H&65535}}c[T+(U*3160|0)+3136>>2]=3410;N=T+(U*3160|0)|0;if((N|0)!=0){S=N;gGC(S|0,9642704,60)|0}c[R>>2]=c[2113194];c[3528552]=-1;fvI();c[3528556]=0;S=c[2433594]|0;c[2443776]=S;L37240:do{if((S|0)!=0){N=S|0;gGC(9660952,N|0,52)|0;switch(a[9660952]|0){case 4:{c[2309668]=7356016;break L37240;break};case 5:{c[2309668]=7354992;break L37240;break};case 2:{c[2309668]=638960;break L37240;break};case 0:{c[2309668]=638960;break L37240;break};case 1:{c[2309668]=634096;break L37240;break};case 3:{c[2309668]=639984;break L37240;break};default:{break L37240}}}}while(0);R=c[2432850]|0;c[2113164]=R;U=c[3527438]|0;c[S+68>>2]=U;c[S+1092>>2]=U;c[S+2116>>2]=U;T=U+256|0;c[S+72>>2]=T;c[S+1096>>2]=T;c[S+2120>>2]=T;T=U+512|0;c[S+76>>2]=T;c[S+1100>>2]=T;c[S+2124>>2]=T;T=U+768|0;c[S+80>>2]=T;c[S+1104>>2]=T;c[S+2128>>2]=T;T=U+1024|0;c[S+84>>2]=T;c[S+1108>>2]=T;c[S+2132>>2]=T;T=U+1280|0;c[S+88>>2]=T;c[S+1112>>2]=T;c[S+2136>>2]=T;T=c[3527436]|0;U=128;N=128;while(1){c[S+68+(N<<2)>>2]=T+(N<<8);O=U+1&65535;if((O&65535)>255){break}else{U=O;N=O&65535}}N=c[3527440]|0;U=128;T=128;while(1){c[S+68+(T+512<<2)>>2]=N+(T<<8);O=U+1&65535;if((O&65535)>255){break}else{U=O;T=O&65535}}c[S+3148>>2]=406;c[S+3152>>2]=3306;T=S|0;gGC(T|0,9660952,52)|0;c[2432850]=R;c[2443776]=0;c[3528556]=-1;c[2424]=5800;U6(3e6,1494,2124,0);c[2438222]=15e5;c[2433520]=2448;c[2406670]=2016;c[3528466]=6844;c[2443840]=1364;h[745399]=.7;a[3203272]=1;Vr(1,15e5,0,2008,2,1);c[2438228]=6e6;c[2433526]=92;c[2406676]=958;c[3528472]=8304;c[2443846]=340;h[745419]=.2;a[3203368]=1;h[745418]=.23;a[3203360]=1;h[745417]=.23;a[3203352]=1;h[745416]=.23;a[3203344]=1;T=c[642608+(c[2436]<<2)>>2]|0;U=c[T+128>>2]|0;if((c[T+52>>2]&4|0)==0){c[2113068]=U;N=c[T+132>>2]|0;c[2113070]=N;c[2443814]=U;c[2440436]=N;aa=U;ab=N}else{c[2113070]=U;N=c[T+132>>2]|0;c[2113068]=N;c[2440436]=U;c[2443814]=N;aa=N;ab=U}U=ag(aa<<1,ab)|0;N=gGq(U)|0;c[2112926]=N;if((N|0)!=0){gGz(N|0,0,U|0)}a[9623400]=0;U=c[2414556]|0;gGz(U|0,0,(c[2411456]|0)-U|0);c[3528552]=0;U=c[2433426]|0;if((U|0)!=0){N=U;gGC(9642704,N|0,60)|0}b[4821352]=c[2410676]&65535;fC1();N=(a[9642745]&1)==0;c[2430032]=N?1595912:1595656;c[2429672]=N?1114752:1114496;c[2429670]=N?1114240:1113984;c[2444186]=N?4654424:4654168;c[2113194]=c[9721800+(c[3528552]<<2)>>2];fC2();N=c[3528552]|0;U=c[2433426]|0;T=U+(N*3160|0)|0;if((T|0)!=0){O=T;gGC(O|0,9642704,60)|0}c[9721800+(N<<2)>>2]=c[2113194];c[3528552]=1;N=U+3160|0;if((N|0)!=0){U=N;gGC(9642704,U|0,60)|0}b[4821352]=c[2410676]&65535;fC1();U=(a[9642745]&1)==0;c[2430032]=U?1595912:1595656;c[2429672]=U?1114752:1114496;c[2429670]=U?1114240:1113984;c[2444186]=U?4654424:4654168;c[2113194]=c[9721800+(c[3528552]<<2)>>2];fC2();U=c[3528552]|0;N=(c[2433426]|0)+(U*3160|0)|0;if((N|0)!=0){O=N;gGC(O|0,9642704,60)|0}c[9721800+(U<<2)>>2]=c[2113194];c[3528552]=-1;c[3528556]=0;U=c[2433594]|0;c[2443776]=U;L37275:do{if((U|0)!=0){O=U|0;gGC(9660952,O|0,52)|0;switch(a[9660952]|0){case 0:{c[2309668]=638960;break L37275;break};case 4:{c[2309668]=7356016;break L37275;break};case 5:{c[2309668]=7354992;break L37275;break};case 2:{c[2309668]=638960;break L37275;break};case 1:{c[2309668]=634096;break L37275;break};case 3:{c[2309668]=639984;break L37275;break};default:{break L37275}}}}while(0);c[2113164]=c[2432850];gu[c[U+56>>2]&16383]();R=c[2443776]|0;if((R|0)!=0){S=R|0;gGC(S|0,9660952,52)|0}c[9731400+(c[3528556]<<2)>>2]=c[2113164];c[2443776]=0;c[3528556]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){S=0;do{lN(S);mB(S);S=S+1|0;}while((S|0)<(c[2385508]|0))}c[2443825]=1073676288;c[2443824]=1073676288;c[2443817]=1073676288;c[2443816]=1073676288;h[883199]=0.0;c[3528506]=0;lw(c[3540986]|0);c[2440606]=0;c[2444190]=0;L=0;i=e;return L|0}}while(0);c[2414854]=0;L=1;i=e;return L|0}function aGP(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0;if((a[9623400]|0)!=0){a[9623400]=0;d=c[2414556]|0;gGz(d|0,0,(c[2411456]|0)-d|0);c[3528552]=0;d=c[2433426]|0;if((d|0)!=0){e=d;gGC(9642704,e|0,60)|0}b[4821352]=c[2410676]&65535;fC1();e=(a[9642745]&1)==0;c[2430032]=e?1595912:1595656;c[2429672]=e?1114752:1114496;c[2429670]=e?1114240:1113984;c[2444186]=e?4654424:4654168;c[2113194]=c[9721800+(c[3528552]<<2)>>2];fC2();e=c[3528552]|0;d=c[2433426]|0;f=d+(e*3160|0)|0;if((f|0)!=0){g=f;gGC(g|0,9642704,60)|0}c[9721800+(e<<2)>>2]=c[2113194];c[3528552]=1;e=d+3160|0;if((e|0)!=0){d=e;gGC(9642704,d|0,60)|0}b[4821352]=c[2410676]&65535;fC1();d=(a[9642745]&1)==0;c[2430032]=d?1595912:1595656;c[2429672]=d?1114752:1114496;c[2429670]=d?1114240:1113984;c[2444186]=d?4654424:4654168;c[2113194]=c[9721800+(c[3528552]<<2)>>2];fC2();d=c[3528552]|0;e=(c[2433426]|0)+(d*3160|0)|0;if((e|0)!=0){g=e;gGC(g|0,9642704,60)|0}c[9721800+(d<<2)>>2]=c[2113194];c[3528552]=-1;c[3528556]=0;d=c[2433594]|0;c[2443776]=d;L37310:do{if((d|0)!=0){g=d|0;gGC(9660952,g|0,52)|0;switch(a[9660952]|0){case 0:{c[2309668]=638960;break L37310;break};case 1:{c[2309668]=634096;break L37310;break};case 3:{c[2309668]=639984;break L37310;break};case 5:{c[2309668]=7354992;break L37310;break};case 4:{c[2309668]=7356016;break L37310;break};case 2:{c[2309668]=638960;break L37310;break};default:{break L37310}}}}while(0);c[2113164]=c[2432850];gu[c[d+56>>2]&16383]();d=c[2443776]|0;if((d|0)!=0){g=d|0;gGC(g|0,9660952,52)|0}c[9731400+(c[3528556]<<2)>>2]=c[2113164];c[2443776]=0;c[3528556]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){g=0;do{lN(g);mB(g);g=g+1|0;}while((g|0)<(c[2385508]|0))}c[2443825]=1073676288;c[2443824]=1073676288;c[2443817]=1073676288;c[2443816]=1073676288;h[883199]=0.0;c[3528506]=0;lw(c[3540986]|0);c[2440606]=0;c[2444190]=0}g=c[2113196]|0;if((g|0)>0){gGz(9721800,0,((g|0)>1?g<<2:4)|0)}c[2113194]=0;g=c[2113166]|0;if((g|0)>0){gGz(9731400,0,((g|0)>1?g<<2:4)|0)}c[2113164]=0;gGz(9550152,-1|0,5);g=0;d=-1;e=-1;f=-1;i=-1;j=-1;do{d=((a[9632392+g|0]&1)<<g^d&255)&255;e=((a[9630304+g|0]&1)<<g^e&255)&255;f=((a[9629184+g|0]&1)<<g^f&255)&255;i=((a[9629136+g|0]&1)<<g^i&255)&255;j=((a[9628864+g|0]&1)<<g^j&255)&255;g=g+1|0;}while((g|0)<8);a[9550152]=d;a[9550153]=e;a[9550154]=f;a[9550155]=i;a[9550156]=j;c[3528556]=0;j=c[2433594]|0;c[2443776]=j;L37337:do{if((j|0)!=0){i=j|0;gGC(9660952,i|0,52)|0;switch(a[9660952]|0){case 3:{c[2309668]=639984;break L37337;break};case 1:{c[2309668]=634096;break L37337;break};case 0:{c[2309668]=638960;break L37337;break};case 2:{c[2309668]=638960;break L37337;break};case 4:{c[2309668]=7356016;break L37337;break};case 5:{c[2309668]=7354992;break L37337;break};default:{break L37337}}}}while(0);c[2113164]=c[2432850];c[2408976]=128;j=0;i=0;while(1){if((i|0)==8){c[2408976]=0}c[3528552]=0;f=c[2433426]|0;if((f|0)!=0){e=f;gGC(9642704,e|0,60)|0}b[4821352]=c[2410676]&65535;fC1();e=(a[9642745]&1)==0;c[2430032]=e?1595912:1595656;c[2429672]=e?1114752:1114496;c[2429670]=e?1114240:1113984;c[2444186]=e?4654424:4654168;c[2113194]=c[9721800+(c[3528552]<<2)>>2];e=i+1|0;f=fC4((e*404|0)-j|0)|0;c[2113194]=(c[2113194]|0)+f;d=f+j|0;if((i|0)==247){do{if((a[9550154]&7)==7){a[614640]=0}else{if(a[614640]|0){break}a[614640]=1;fC3();fC4(0)|0;if((a[9642761]|0)!=0){a[9642761]=0}fC4(0)|0}}while(0);c[2408976]=128}f=c[3528552]|0;g=c[2433426]|0;k=g+(f*3160|0)|0;if((k|0)!=0){l=k;gGC(l|0,9642704,60)|0}c[9721800+(f<<2)>>2]=c[2113194];c[3528552]=1;f=g+3160|0;if((f|0)!=0){g=f;gGC(9642704,g|0,60)|0}b[4821352]=c[2410676]&65535;fC1();g=(a[9642745]&1)==0;c[2430032]=g?1595912:1595656;c[2429672]=g?1114752:1114496;c[2429670]=g?1114240:1113984;c[2444186]=g?4654424:4654168;c[2113194]=c[9721800+(c[3528552]<<2)>>2];Sb(i*404|0);g=c[3528552]|0;f=(c[2433426]|0)+(g*3160|0)|0;if((f|0)!=0){l=f;gGC(l|0,9642704,60)|0}c[9721800+(g<<2)>>2]=c[2113194];c[3528552]=-1;U1(i*101|0);if((e|0)<256){j=d;i=e}else{break}}c[3528552]=1;i=(c[2433426]|0)+3160|0;if((i|0)!=0){j=i;gGC(9642704,j|0,60)|0}b[4821352]=c[2410676]&65535;fC1();j=(a[9642745]&1)==0;c[2430032]=j?1595912:1595656;c[2429672]=j?1114752:1114496;c[2429670]=j?1114240:1113984;c[2444186]=j?4654424:4654168;c[2113194]=c[9721800+(c[3528552]<<2)>>2];j=c[2438228]|0;i=gGS(-642777088,49327,j,(j|0)<0|0?-1:0)|0;j=i;Sb(103448);i=c[2443830]|0;if((i|0)<1073676288){c[2443830]=i-j}i=c[2443831]|0;if((i|0)<1073676288){c[2443831]=i-j}i=(c[3528512]|0)-j|0;c[3528512]=(i|0)<0?0:i;i=c[2438222]|0;j=gGS(-160694272,12331,i,(i|0)<0|0?-1:0)|0;i=j;U1(25862);j=c[2443824]|0;if((j|0)<1073676288){c[2443824]=j-i}j=c[2443825]|0;if((j|0)<1073676288){c[2443825]=j-i}j=(c[3528506]|0)-i|0;c[3528506]=(j|0)<0?0:j;j=c[2112964]|0;if((j|0)!=0){gg[c[3542114]&4095](j,a[9688]|0?534:0);gg[c[3542122]&4095](c[2112964]|0,a[9688]|0?534:0)}j=c[2443776]|0;if((j|0)!=0){i=j|0;gGC(i|0,9660952,52)|0}c[9731400+(c[3528556]<<2)>>2]=c[2113164];c[2443776]=0;c[3528556]=-1;i=c[3528552]|0;j=(c[2433426]|0)+(i*3160|0)|0;if((j|0)!=0){g=j;gGC(g|0,9642704,60)|0}c[9721800+(i<<2)>>2]=c[2113194];c[3528552]=-1;if((c[2112968]|0)==0){return 0}aGQ()|0;return 0}function aGQ(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if((a[9547080]|0)!=0){b=c[2387100]|0;e=c[3529894]|0;f=0;do{g=a[b+f|0]|0;h=a[b+(f|1)|0]|0;i=(h&255)>>>4;c[e+(((f|0)/2|0)<<2)>>2]=((h&8|h<<4)&255)<<8&63488|((g&8|g<<4)&255)>>>3|((i<<4|i)&255)<<3&2016;f=f+2|0;}while((f|0)<1024)}f=c[2387082]|0;e=c[3529872]|0;b=c[3530384]|0;aHK(f,e,b,384,7,2047,0);aHL(15,0);aHK(f,e,b,384,7,2047,255);b=c[2113070]|0;e=c[2386282]|0;f=c[2112926]|0;i=c[3530752]|0;g=0;do{h=(g>>5<<3)-8|0;if((h|0)>-1&(h|0)<(b|0)){j=g<<1;k=d[e+j|0]|0;Sq(f,k<<8&768|d[e+(j|1)|0],g<<3&248,h,k>>>6,3,0,256,i)}g=g+1|0;}while((g|0)<1024);R8(c[3529894]|0);return 0}function aGR(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5749212+(b*112|0)>>2];c[a+104>>2]=c[5749216+(b*112|0)>>2];c[a+108>>2]=c[5749220+(b*112|0)>>2];d=0;return d|0}function aGS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=5749112+(b*112|0);e=0;return e|0}function aGT(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>44){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6187928+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aGU(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4503412+(b*112|0)>>2];c[a+104>>2]=c[4503416+(b*112|0)>>2];c[a+108>>2]=c[4503420+(b*112|0)>>2];d=0;return d|0}function aGV(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=4503312+(b*112|0);e=0;return e|0}function aGW(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4501732+(b*112|0)>>2];c[a+104>>2]=c[4501736+(b*112|0)>>2];c[a+108>>2]=c[4501740+(b*112|0)>>2];d=0;return d|0}function aGX(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=4501632+(b*112|0);e=0;return e|0}function aGY(e,f){e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;g=e&65535;switch(g|0){case 6158:case 6159:{e=a[632376]|0;if((c[3528554]|0)!=0){if(e){return}h=g&1;i=f&255;c[2440606]=0;j=d[9550154]|0;if((h|0)==1){c[2444190]=c[2444190]&65280|i}else if((h|0)==0){c[2444190]=c[2444190]&255|i<<8;f44(1);f45(0)|0;a[9660787]=0;f45(0)|0}if(!(a[595352]|0)){a[595352]=1;a[595360]=0;a[595368]=0}do{if((j&1|0)==0){a[595368]=1;a[595352]=0}else{if((j&2|0)!=0){break}a[595360]=1;a[595352]=0}}while(0);j=c[2444190]|0;if((j|0)==81){c[2440606]=0;return}else if((j|0)==80){c[2440606]=0;return}else if((j|0)==258){c[2440606]=0;return}else if((j|0)==257){c[2440606]=0;return}else if((j|0)==33025){c[2440606]=(((a[595368]&1)>>>0)%10|0)<<8|(((a[595360]&1)>>>0)%10|0);return}else{return}}if(!e){return}e=g&1;g=f&255;c[2440606]=0;if((e|0)==0){j=a[9550154]|0;c[2444190]=c[2444190]&255|g<<8;f44(1);f45(0)|0;a[9660787]=0;f45(0)|0;i=(j&3)!=3;j=a[595592]|0;if(i|j){k=j}else{a[595592]=1;k=1}if(i&k){c[2384308]=(c[2384308]|0)+1;a[595592]=0;a[595600]=1;c[2440606]=1024;return}k=c[2444190]|0;L37508:do{switch(k|0){case 1025:{c[2440606]=388;return};case 123:{l=388;m=29275;break};case 1:{a[595600]=0;c[2384308]=0;m=29274;break};case 122:{l=389;m=29275;break};case 0:{c[2440606]=388;m=29274;break};default:{i=k&-256;if((i|0)!=256){n=i;break L37508}c[2440606]=388;return}}}while(0);if((m|0)==29274){n=k&-256}else if((m|0)==29275){c[2440606]=l;n=k&-256}if((n|0)==512){k=c[2384308]|0;c[2440606]=((k|0)/10|0)<<4|(a[595600]|0?1024:0)|((k|0)%10|0);a[595600]=0;return}k=c[2384308]|0;if(!((n|0)==768&(k|0)!=0)){return}c[2440606]=0;c[2384308]=k-1;return}else if((e|0)==1){c[2444190]=c[2444190]&65280|g;return}else{return}break};case 6157:{do{if((c[3528554]|0)==0){g=f&255;e=g<<14&245760;c[2406854]=e;k=c[3530266]|0;n=c[2433592]|0;l=e+49152|0;e=64;i=64;while(1){j=k+(l+(i<<8))|0;c[n+48+(i<<2)>>2]=j;c[n+48+(i+512<<2)>>2]=j;j=e+1&65535;if((j&65535)>127){break}else{e=j;i=j&65535}}if(!((g&128|0)==0&a[632376])){c[3528196]=0;break}if((n|0)!=0){i=n;gGC(i|0,9660752,48)|0}c[2432840]=c[2113158];c[3528554]=1;f43(n+3148|0);i=c[3528554]|0;c[2113158]=c[9731360+(i<<2)>>2];a[9660796]=0;a[9660797]=0;a[9660786]=0;a[9660787]=0;c[2415191]=0;a[9660784]=a[9660784]|80;e=c[2433592]|0;l=c[e+(i*3148|0)+1068>>2]|0;do{if((l|0)==0){k=c[e+(i*3148|0)+3120>>2]|0;if((k|0)==0){o=0;p=0;q=i;r=e;break}j=gj[k&4095](-2)|0;k=c[3528554]|0;h=c[2433592]|0;s=c[h+(k*3148|0)+1068>>2]|0;t=(j&255)<<8;if((s|0)!=0){u=s;v=t;w=k;x=h;m=29253;break}s=c[h+(k*3148|0)+3120>>2]|0;if((s|0)==0){o=0;p=t;q=k;r=h;break}h=gj[s&4095](-1)|0;o=h;p=t;q=c[3528554]|0;r=c[2433592]|0}else{u=l;v=(d[l+254|0]|0)<<8;w=i;x=e;m=29253}}while(0);if((m|0)==29253){o=a[u+255|0]|0;p=v;q=w;r=x}e=o&255|p;c[2415188]=e;b[4830376]=e&65535;e=r+(q*3148|0)|0;if((e|0)!=0){i=e;gGC(i|0,9660752,48)|0}c[9731360+(q<<2)>>2]=c[2113158];c[3528554]=0;f43(r);c[2113158]=c[9731360+(c[3528554]<<2)>>2];c[3528196]=1}}while(0);r=c[3529872]|0;a[r+16|0]=(f&255)>>>5&1;a[r+18|0]=(f&255)>>>6&1;return};case 6151:{a[c[3528652]|0]=f;return};case 6153:{a[(c[3529872]|0)+17|0]=f;return};case 6148:{if((c[3528554]|0)!=0){f44(0);f45(0)|0;a[9660786]=0;f45(0)|0;return}r=c[2433592]|0;if((r|0)!=0){q=r;gGC(q|0,9660752,48)|0}c[2432840]=c[2113158];c[3528554]=1;f43(r+3148|0);c[2113158]=c[9731360+(c[3528554]<<2)>>2];f44(0);f45(0)|0;a[9660786]=0;f45(0)|0;r=c[3528554]|0;q=c[2433592]|0;p=q+(r*3148|0)|0;if((p|0)!=0){o=p;gGC(o|0,9660752,48)|0}c[9731360+(r<<2)>>2]=c[2113158];c[3528554]=0;f43(q);c[2113158]=c[9731360+(c[3528554]<<2)>>2];return};case 6156:{a[c[3528212]|0]=f;gg[c[(c[2443776]|0)+64>>2]&4095](32,1);gj[c[(c[2443776]|0)+52>>2]&4095](0)|0;gg[c[(c[2443776]|0)+64>>2]&4095](32,0);gj[c[(c[2443776]|0)+52>>2]&4095](0)|0;return};case 6147:{q=c[3528554]|0;if((q|0)==0){f44(0);f45(0)|0;a[9660786]=0;f45(0)|0;return}r=c[2433592]|0;o=r+(q*3148|0)|0;if((o|0)!=0){p=o;gGC(p|0,9660752,48)|0}c[9731360+(q<<2)>>2]=c[2113158];c[3528554]=0;f43(r);c[2113158]=c[9731360+(c[3528554]<<2)>>2];f44(0);f45(0)|0;a[9660786]=0;f45(0)|0;r=c[3528554]|0;q=c[2433592]|0;p=q+(r*3148|0)|0;if((p|0)!=0){o=p;gGC(o|0,9660752,48)|0}c[9731360+(r<<2)>>2]=c[2113158];c[3528554]=1;f43(q+3148|0);c[2113158]=c[9731360+(c[3528554]<<2)>>2];return};case 6155:{a[(c[3529872]|0)+19|0]=f;return};case 6149:{f=c[2386556]|0;q=c[2386382]|0;gGC(f|0,q|0,2048)|0;return};default:{return}}}function aGZ(b){b=b|0;var d=0;switch(b&65535|0){case 6151:{d=c[2440606]&255;break};case 6145:{d=a[9550153]|0;break};case 6144:{d=a[9550152]|0;break};case 6146:{d=(a[9550154]&127|c[2408976])&255;break};case 6147:{d=a[9634672]|0;break};case 6150:{d=(c[2440606]|0)>>>8&255;break};case 6148:{d=a[9634673]|0;break};default:{d=0}}return d|0}function aG_(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2652220+(b*112|0)>>2];c[a+104>>2]=c[2652224+(b*112|0)>>2];c[a+108>>2]=c[2652228+(b*112|0)>>2];d=0;return d|0}function aG$(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=2652120+(b*112|0);e=0;return e|0}function aG0(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1236032+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aG1(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>39){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3806816+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aG2(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0;e=i;i=i+3840|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;B=e+1200|0;C=e+1312|0;D=e+1320|0;E=e+1432|0;F=e+1440|0;G=e+1552|0;H=e+1560|0;I=e+1672|0;J=e+1680|0;K=e+1792|0;L=e+1800|0;M=e+1912|0;N=e+1920|0;O=e+2032|0;P=e+2040|0;Q=e+2152|0;R=e+2160|0;S=e+2272|0;T=e+2280|0;U=e+2392|0;V=e+2400|0;W=e+2512|0;X=e+2520|0;Y=e+2632|0;Z=e+2640|0;_=e+2752|0;$=e+2760|0;aa=e+2872|0;ab=e+2880|0;ac=e+2992|0;ad=e+3e3|0;ae=e+3112|0;af=e+3120|0;ah=e+3232|0;ai=e+3240|0;aj=e+3352|0;ak=e+3360|0;al=e+3472|0;am=e+3480|0;an=e+3592|0;ao=e+3600|0;ap=e+3712|0;aq=e+3720|0;ar=e+3832|0;c[2414854]=0;c[3530266]=0;c[2386358]=327680;c[3527436]=458752;c[3527440]=589824;c[3530752]=655360;c[3530516]=786432;c[3530384]=1835008;c[3530308]=2883584;c[3531056]=3932160;c[2407020]=3934208;c[3529894]=3938304;c[2414556]=3942400;c[3530268]=3942400;c[2386282]=3950592;c[2387082]=3952640;c[2387076]=3956736;c[3529872]=3960832;c[3529870]=3960864;c[2386744]=3960896;c[2386382]=3961920;c[2386556]=3963968;c[2387100]=3966016;c[3527438]=3968064;c[3528212]=3970112;c[3528482]=3970113;c[2432942]=3970114;c[3528652]=3970115;c[2411456]=3970116;as=0;while(1){if((as|0)>=1024){break}at=9638528+(as<<2)|0;if((c[at>>2]|0)==0){au=29364;break}else{as=as+1|0}}do{if((au|0)==29364){as=gGq(3970116)|0;c[at>>2]=as;if((as|0)==0){break}c[2414854]=as;gGz(as|0,0,3970116);c[3530266]=as;c[2386358]=as+327680;c[3527436]=as+458752;c[3527440]=as+589824;c[3530752]=as+655360;c[3530516]=as+786432;c[3530384]=as+1835008;c[3530308]=as+2883584;c[3531056]=as+3932160;c[2407020]=as+3934208;c[3529894]=as+3938304;av=as+3942400|0;c[2414556]=av;c[3530268]=av;c[2386282]=as+3950592;c[2387082]=as+3952640;c[2387076]=as+3956736;c[3529872]=as+3960832;c[3529870]=as+3960864;c[2386744]=as+3960896;c[2386382]=as+3961920;c[2386556]=as+3963968;c[2387100]=as+3966016;c[3527438]=as+3968064;c[3528212]=as+3970112;c[3528482]=as+3970113;c[2432942]=as+3970114;c[3528652]=as+3970115;av=as+3970116|0;c[2411456]=av;c[2413996]=av;av=c[642608+(c[2436]<<2)>>2]|0;aw=(dW(c[av>>2]|0,505656,5)|0)==0;ax=as+32768|0;do{if((c[3542200]|0)==0){ay=1}else{as=aq+108|0;c[as>>2]=0;az=aq+100|0;c[az>>2]=0;aA=c[av+76>>2]|0;gA[aA&16383](aq,0)|0;if((c[as>>2]|0)==0){ay=0;break}as=c[az>>2]|0;c[ar>>2]=9534384;az=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[az&16383](ar,0,0)|0;if((as|0)<1){ay=1;break}ay=(gzL(ax,0,0)|0)!=0}}while(0);do{if(aw){if(ay){aB=1;i=e;return aB|0}ax=(c[3530266]|0)+65536|0;if((c[3542200]|0)==0){aB=1;i=e;return aB|0}av=ao+108|0;c[av>>2]=0;as=ao+100|0;c[as>>2]=0;az=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[az&16383](ao,1)|0;do{if((c[av>>2]|0)!=0){az=c[as>>2]|0;c[ap>>2]=9534384;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aA&16383](ap,1,0)|0;if((az|0)<1){aB=1;i=e;return aB|0}if((gzL(ax,0,1)|0)==0){break}else{aB=1}i=e;return aB|0}}while(0);ax=c[2386358]|0;if((c[3542200]|0)==0){aB=1;i=e;return aB|0}as=am+108|0;c[as>>2]=0;av=am+100|0;c[av>>2]=0;az=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[az&16383](am,2)|0;do{if((c[as>>2]|0)!=0){az=c[av>>2]|0;c[an>>2]=9534384;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aA&16383](an,2,0)|0;if((az|0)<1){aB=1;i=e;return aB|0}if((gzL(ax,0,2)|0)==0){break}else{aB=1}i=e;return aB|0}}while(0);ax=(c[3527436]|0)+32768|0;if((c[3542200]|0)==0){aB=1;i=e;return aB|0}av=ak+108|0;c[av>>2]=0;as=ak+100|0;c[as>>2]=0;az=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[az&16383](ak,3)|0;do{if((c[av>>2]|0)!=0){az=c[as>>2]|0;c[al>>2]=9534384;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aA&16383](al,3,0)|0;if((az|0)<1){aB=1;i=e;return aB|0}if((gzL(ax,0,3)|0)==0){break}else{aB=1}i=e;return aB|0}}while(0);ax=c[3530308]|0;if((c[3542200]|0)==0){aB=1;i=e;return aB|0}as=ai+108|0;c[as>>2]=0;av=ai+100|0;c[av>>2]=0;az=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[az&16383](ai,4)|0;do{if((c[as>>2]|0)!=0){az=c[av>>2]|0;c[aj>>2]=9534384;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aA&16383](aj,4,0)|0;if((az|0)<1){aB=1;i=e;return aB|0}if((gzL(ax,0,4)|0)==0){break}else{aB=1}i=e;return aB|0}}while(0);ax=c[3530752]|0;av=c[3530308]|0;gGC(ax|0,av|0,8192)|0;as=ax+24576|0;az=av+8192|0;gGC(as|0,az|0,8192)|0;az=ax+16384|0;as=av+16384|0;gGC(az|0,as|0,8192)|0;as=ax+8192|0;ax=av+24576|0;gGC(as|0,ax|0,8192)|0;ax=c[3530516]|0;if((c[3542200]|0)==0){aB=1;i=e;return aB|0}as=af+108|0;c[as>>2]=0;av=af+100|0;c[av>>2]=0;az=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[az&16383](af,5)|0;do{if((c[as>>2]|0)!=0){az=c[av>>2]|0;c[ah>>2]=9534384;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aA&16383](ah,5,0)|0;if((az|0)<1){aB=1;i=e;return aB|0}if((gzL(ax,0,5)|0)==0){break}else{aB=1}i=e;return aB|0}}while(0);ax=(c[3530516]|0)+131072|0;if((c[3542200]|0)==0){aB=1;i=e;return aB|0}av=ad+108|0;c[av>>2]=0;as=ad+100|0;c[as>>2]=0;az=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[az&16383](ad,6)|0;do{if((c[av>>2]|0)!=0){az=c[as>>2]|0;c[ae>>2]=9534384;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aA&16383](ae,6,0)|0;if((az|0)<1){aB=1;i=e;return aB|0}if((gzL(ax,0,6)|0)==0){break}else{aB=1}i=e;return aB|0}}while(0);ax=(c[3530516]|0)+262144|0;if((c[3542200]|0)==0){aB=1;i=e;return aB|0}as=ab+108|0;c[as>>2]=0;av=ab+100|0;c[av>>2]=0;az=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[az&16383](ab,7)|0;do{if((c[as>>2]|0)!=0){az=c[av>>2]|0;c[ac>>2]=9534384;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aA&16383](ac,7,0)|0;if((az|0)<1){aB=1;i=e;return aB|0}if((gzL(ax,0,7)|0)==0){break}else{aB=1}i=e;return aB|0}}while(0);ax=(c[3530516]|0)+393216|0;if((c[3542200]|0)==0){aB=1;i=e;return aB|0}av=$+108|0;c[av>>2]=0;as=$+100|0;c[as>>2]=0;az=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[az&16383]($,8)|0;do{if((c[av>>2]|0)!=0){az=c[as>>2]|0;c[aa>>2]=9534384;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aA&16383](aa,8,0)|0;if((az|0)<1){aB=1;i=e;return aB|0}if((gzL(ax,0,8)|0)==0){break}else{aB=1}i=e;return aB|0}}while(0);ax=c[3530384]|0;if((c[3542200]|0)==0){aB=1;i=e;return aB|0}as=Z+108|0;c[as>>2]=0;av=Z+100|0;c[av>>2]=0;az=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[az&16383](Z,9)|0;do{if((c[as>>2]|0)!=0){az=c[av>>2]|0;c[_>>2]=9534384;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aA&16383](_,9,0)|0;if((az|0)<1){aB=1;i=e;return aB|0}if((gzL(ax,0,9)|0)==0){break}else{aB=1}i=e;return aB|0}}while(0);ax=(c[3530384]|0)+131072|0;if((c[3542200]|0)==0){aB=1;i=e;return aB|0}av=X+108|0;c[av>>2]=0;as=X+100|0;c[as>>2]=0;az=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[az&16383](X,10)|0;do{if((c[av>>2]|0)!=0){az=c[as>>2]|0;c[Y>>2]=9534384;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aA&16383](Y,10,0)|0;if((az|0)<1){aB=1;i=e;return aB|0}if((gzL(ax,0,10)|0)==0){break}else{aB=1}i=e;return aB|0}}while(0);ax=(c[3530384]|0)+262144|0;if((c[3542200]|0)==0){aB=1;i=e;return aB|0}as=V+108|0;c[as>>2]=0;av=V+100|0;c[av>>2]=0;az=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[az&16383](V,11)|0;do{if((c[as>>2]|0)!=0){az=c[av>>2]|0;c[W>>2]=9534384;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aA&16383](W,11,0)|0;if((az|0)<1){aB=1;i=e;return aB|0}if((gzL(ax,0,11)|0)==0){break}else{aB=1}i=e;return aB|0}}while(0);ax=(c[3530384]|0)+393216|0;if((c[3542200]|0)==0){aB=1;i=e;return aB|0}av=T+108|0;c[av>>2]=0;as=T+100|0;c[as>>2]=0;az=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[az&16383](T,12)|0;do{if((c[av>>2]|0)!=0){az=c[as>>2]|0;c[U>>2]=9534384;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aA&16383](U,12,0)|0;if((az|0)<1){aB=1;i=e;return aB|0}if((gzL(ax,0,12)|0)==0){break}else{aB=1}i=e;return aB|0}}while(0);a[632376]=1}else{if(ay){aB=1;i=e;return aB|0}ax=(c[3530266]|0)+65536|0;if((c[3542200]|0)==0){aB=1;i=e;return aB|0}as=R+108|0;c[as>>2]=0;av=R+100|0;c[av>>2]=0;az=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[az&16383](R,1)|0;do{if((c[as>>2]|0)!=0){az=c[av>>2]|0;c[S>>2]=9534384;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aA&16383](S,1,0)|0;if((az|0)<1){aB=1;i=e;return aB|0}if((gzL(ax,0,1)|0)==0){break}else{aB=1}i=e;return aB|0}}while(0);ax=(c[3530266]|0)+131072|0;if((c[3542200]|0)==0){aB=1;i=e;return aB|0}av=P+108|0;c[av>>2]=0;as=P+100|0;c[as>>2]=0;az=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[az&16383](P,2)|0;do{if((c[av>>2]|0)!=0){az=c[as>>2]|0;c[Q>>2]=9534384;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aA&16383](Q,2,0)|0;if((az|0)<1){aB=1;i=e;return aB|0}if((gzL(ax,0,2)|0)==0){break}else{aB=1}i=e;return aB|0}}while(0);ax=(c[3530266]|0)+196608|0;if((c[3542200]|0)==0){aB=1;i=e;return aB|0}as=N+108|0;c[as>>2]=0;av=N+100|0;c[av>>2]=0;az=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[az&16383](N,3)|0;do{if((c[as>>2]|0)!=0){az=c[av>>2]|0;c[O>>2]=9534384;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aA&16383](O,3,0)|0;if((az|0)<1){aB=1;i=e;return aB|0}if((gzL(ax,0,3)|0)==0){break}else{aB=1}i=e;return aB|0}}while(0);ax=(c[3530266]|0)+262144|0;if((c[3542200]|0)==0){aB=1;i=e;return aB|0}av=L+108|0;c[av>>2]=0;as=L+100|0;c[as>>2]=0;az=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[az&16383](L,4)|0;do{if((c[av>>2]|0)!=0){az=c[as>>2]|0;c[M>>2]=9534384;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aA&16383](M,4,0)|0;if((az|0)<1){aB=1;i=e;return aB|0}if((gzL(ax,0,4)|0)==0){break}else{aB=1}i=e;return aB|0}}while(0);ax=c[2386358]|0;if((c[3542200]|0)==0){aB=1;i=e;return aB|0}as=J+108|0;c[as>>2]=0;av=J+100|0;c[av>>2]=0;az=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[az&16383](J,5)|0;do{if((c[as>>2]|0)!=0){az=c[av>>2]|0;c[K>>2]=9534384;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aA&16383](K,5,0)|0;if((az|0)<1){aB=1;i=e;return aB|0}if((gzL(ax,0,5)|0)==0){break}else{aB=1}i=e;return aB|0}}while(0);ax=(c[3527436]|0)+32768|0;if((c[3542200]|0)==0){aB=1;i=e;return aB|0}av=H+108|0;c[av>>2]=0;as=H+100|0;c[as>>2]=0;az=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[az&16383](H,6)|0;do{if((c[av>>2]|0)!=0){az=c[as>>2]|0;c[I>>2]=9534384;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aA&16383](I,6,0)|0;if((az|0)<1){aB=1;i=e;return aB|0}if((gzL(ax,0,6)|0)==0){break}else{aB=1}i=e;return aB|0}}while(0);ax=c[3530752]|0;if((c[3542200]|0)==0){aB=1;i=e;return aB|0}as=F+108|0;c[as>>2]=0;av=F+100|0;c[av>>2]=0;az=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[az&16383](F,7)|0;do{if((c[as>>2]|0)!=0){az=c[av>>2]|0;c[G>>2]=9534384;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aA&16383](G,7,0)|0;if((az|0)<1){aB=1;i=e;return aB|0}if((gzL(ax,0,7)|0)==0){break}else{aB=1}i=e;return aB|0}}while(0);ax=c[3530516]|0;if((c[3542200]|0)==0){aB=1;i=e;return aB|0}av=D+108|0;c[av>>2]=0;as=D+100|0;c[as>>2]=0;az=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[az&16383](D,8)|0;do{if((c[av>>2]|0)!=0){az=c[as>>2]|0;c[E>>2]=9534384;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aA&16383](E,8,0)|0;if((az|0)<1){aB=1;i=e;return aB|0}if((gzL(ax,0,8)|0)==0){break}else{aB=1}i=e;return aB|0}}while(0);ax=(c[3530516]|0)+65536|0;if((c[3542200]|0)==0){aB=1;i=e;return aB|0}as=B+108|0;c[as>>2]=0;av=B+100|0;c[av>>2]=0;az=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[az&16383](B,9)|0;do{if((c[as>>2]|0)!=0){az=c[av>>2]|0;c[C>>2]=9534384;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aA&16383](C,9,0)|0;if((az|0)<1){aB=1;i=e;return aB|0}if((gzL(ax,0,9)|0)==0){break}else{aB=1}i=e;return aB|0}}while(0);ax=(c[3530516]|0)+131072|0;if((c[3542200]|0)==0){aB=1;i=e;return aB|0}av=z+108|0;c[av>>2]=0;as=z+100|0;c[as>>2]=0;az=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[az&16383](z,10)|0;do{if((c[av>>2]|0)!=0){az=c[as>>2]|0;c[A>>2]=9534384;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aA&16383](A,10,0)|0;if((az|0)<1){aB=1;i=e;return aB|0}if((gzL(ax,0,10)|0)==0){break}else{aB=1}i=e;return aB|0}}while(0);ax=(c[3530516]|0)+196608|0;if((c[3542200]|0)==0){aB=1;i=e;return aB|0}as=x+108|0;c[as>>2]=0;av=x+100|0;c[av>>2]=0;az=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[az&16383](x,11)|0;do{if((c[as>>2]|0)!=0){az=c[av>>2]|0;c[y>>2]=9534384;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aA&16383](y,11,0)|0;if((az|0)<1){aB=1;i=e;return aB|0}if((gzL(ax,0,11)|0)==0){break}else{aB=1}i=e;return aB|0}}while(0);ax=(c[3530516]|0)+262144|0;if((c[3542200]|0)==0){aB=1;i=e;return aB|0}av=v+108|0;c[av>>2]=0;as=v+100|0;c[as>>2]=0;az=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[az&16383](v,12)|0;do{if((c[av>>2]|0)!=0){az=c[as>>2]|0;c[w>>2]=9534384;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aA&16383](w,12,0)|0;if((az|0)<1){aB=1;i=e;return aB|0}if((gzL(ax,0,12)|0)==0){break}else{aB=1}i=e;return aB|0}}while(0);ax=(c[3530516]|0)+327680|0;if((c[3542200]|0)==0){aB=1;i=e;return aB|0}as=t+108|0;c[as>>2]=0;av=t+100|0;c[av>>2]=0;az=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[az&16383](t,13)|0;do{if((c[as>>2]|0)!=0){az=c[av>>2]|0;c[u>>2]=9534384;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aA&16383](u,13,0)|0;if((az|0)<1){aB=1;i=e;return aB|0}if((gzL(ax,0,13)|0)==0){break}else{aB=1}i=e;return aB|0}}while(0);ax=(c[3530516]|0)+393216|0;if((c[3542200]|0)==0){aB=1;i=e;return aB|0}av=r+108|0;c[av>>2]=0;as=r+100|0;c[as>>2]=0;az=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[az&16383](r,14)|0;do{if((c[av>>2]|0)!=0){az=c[as>>2]|0;c[s>>2]=9534384;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aA&16383](s,14,0)|0;if((az|0)<1){aB=1;i=e;return aB|0}if((gzL(ax,0,14)|0)==0){break}else{aB=1}i=e;return aB|0}}while(0);ax=(c[3530516]|0)+458752|0;if((c[3542200]|0)==0){aB=1;i=e;return aB|0}as=p+108|0;c[as>>2]=0;av=p+100|0;c[av>>2]=0;az=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[az&16383](p,15)|0;do{if((c[as>>2]|0)!=0){az=c[av>>2]|0;c[q>>2]=9534384;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aA&16383](q,15,0)|0;if((az|0)<1){aB=1;i=e;return aB|0}if((gzL(ax,0,15)|0)==0){break}else{aB=1}i=e;return aB|0}}while(0);ax=c[3530384]|0;if((c[3542200]|0)==0){aB=1;i=e;return aB|0}av=n+108|0;c[av>>2]=0;as=n+100|0;c[as>>2]=0;az=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[az&16383](n,16)|0;do{if((c[av>>2]|0)!=0){az=c[as>>2]|0;c[o>>2]=9534384;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aA&16383](o,16,0)|0;if((az|0)<1){aB=1;i=e;return aB|0}if((gzL(ax,0,16)|0)==0){break}else{aB=1}i=e;return aB|0}}while(0);ax=(c[3530384]|0)+131072|0;if((c[3542200]|0)==0){aB=1;i=e;return aB|0}as=l+108|0;c[as>>2]=0;av=l+100|0;c[av>>2]=0;az=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[az&16383](l,17)|0;do{if((c[as>>2]|0)!=0){az=c[av>>2]|0;c[m>>2]=9534384;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aA&16383](m,17,0)|0;if((az|0)<1){aB=1;i=e;return aB|0}if((gzL(ax,0,17)|0)==0){break}else{aB=1}i=e;return aB|0}}while(0);ax=(c[3530384]|0)+262144|0;if((c[3542200]|0)==0){aB=1;i=e;return aB|0}av=j+108|0;c[av>>2]=0;as=j+100|0;c[as>>2]=0;az=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[az&16383](j,18)|0;do{if((c[av>>2]|0)!=0){az=c[as>>2]|0;c[k>>2]=9534384;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aA&16383](k,18,0)|0;if((az|0)<1){aB=1;i=e;return aB|0}if((gzL(ax,0,18)|0)==0){break}else{aB=1}i=e;return aB|0}}while(0);ax=(c[3530384]|0)+393216|0;if((c[3542200]|0)==0){aB=1;i=e;return aB|0}as=f+108|0;c[as>>2]=0;av=f+100|0;c[av>>2]=0;az=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[az&16383](f,19)|0;if((c[as>>2]|0)==0){break}as=c[av>>2]|0;c[g>>2]=9534384;av=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[av&16383](g,19,0)|0;if((as|0)<1){aB=1;i=e;return aB|0}if((gzL(ax,0,19)|0)==0){break}else{aB=1}i=e;return aB|0}}while(0);aHz();c[3528554]=-1;c[2113160]=2;aw=gGq(6296)|0;ax=aw;c[2433592]=ax;if((aw|0)!=0){gGz(aw|0,0,6296);as=0;do{c[ax+(as*3148|0)+3120>>2]=3128;c[ax+(as*3148|0)+3124>>2]=1840;c[ax+(as*3148|0)+3128>>2]=136;c[ax+(as*3148|0)+3132>>2]=1902;c[9731360+(as<<2)>>2]=0;av=0;do{c[ax+(as*3148|0)+48+(av<<2)>>2]=0;av=av+1|0;}while((av|0)<768);as=as+1|0;}while((as|0)<2);c[2113158]=0;c[2415198]=0;as=c[2427044]|0;c[9681616+(as<<3)>>2]=809272;c[9681620+(as<<3)>>2]=0;ax=as+1|0;c[9681616+(ax<<3)>>2]=809272;c[9681620+(ax<<3)>>2]=1;c[2427044]=as+2}c[3528554]=0;f43(aw);as=c[3528554]|0;ax=9731360+(as<<2)|0;av=c[ax>>2]|0;c[2113158]=av;az=c[3530268]|0;aA=c[2433592]|0;aC=0;aD=0;while(1){aE=az+(aD<<8)|0;c[aA+(as*3148|0)+48+(aD<<2)>>2]=aE;c[aA+(as*3148|0)+48+(aD+256<<2)>>2]=aE;c[aA+(as*3148|0)+48+(aD+512<<2)>>2]=aE;aE=aC+1&65535;if((aE&65535)>15){break}else{aC=aE;aD=aE&65535}}aD=c[2387100]|0;c[aA+(as*3148|0)+112>>2]=aD;c[aA+(as*3148|0)+1136>>2]=aD;c[aA+(as*3148|0)+2160>>2]=aD;aC=aD+256|0;c[aA+(as*3148|0)+116>>2]=aC;c[aA+(as*3148|0)+1140>>2]=aC;c[aA+(as*3148|0)+2164>>2]=aC;aC=aD+512|0;c[aA+(as*3148|0)+120>>2]=aC;c[aA+(as*3148|0)+1144>>2]=aC;c[aA+(as*3148|0)+2168>>2]=aC;aC=aD+768|0;c[aA+(as*3148|0)+124>>2]=aC;c[aA+(as*3148|0)+1148>>2]=aC;c[aA+(as*3148|0)+2172>>2]=aC;aC=aD+1024|0;c[aA+(as*3148|0)+128>>2]=aC;c[aA+(as*3148|0)+1152>>2]=aC;c[aA+(as*3148|0)+2176>>2]=aC;aC=aD+1280|0;c[aA+(as*3148|0)+132>>2]=aC;c[aA+(as*3148|0)+1156>>2]=aC;c[aA+(as*3148|0)+2180>>2]=aC;aC=aD+1536|0;c[aA+(as*3148|0)+136>>2]=aC;c[aA+(as*3148|0)+1160>>2]=aC;c[aA+(as*3148|0)+2184>>2]=aC;aC=aD+1792|0;c[aA+(as*3148|0)+140>>2]=aC;c[aA+(as*3148|0)+1164>>2]=aC;c[aA+(as*3148|0)+2188>>2]=aC;aC=c[2386282]|0;c[aA+(as*3148|0)+176>>2]=aC;c[aA+(as*3148|0)+1200>>2]=aC;c[aA+(as*3148|0)+2224>>2]=aC;aD=aC+256|0;c[aA+(as*3148|0)+180>>2]=aD;c[aA+(as*3148|0)+1204>>2]=aD;c[aA+(as*3148|0)+2228>>2]=aD;aD=aC+512|0;c[aA+(as*3148|0)+184>>2]=aD;c[aA+(as*3148|0)+1208>>2]=aD;c[aA+(as*3148|0)+2232>>2]=aD;aD=aC+768|0;c[aA+(as*3148|0)+188>>2]=aD;c[aA+(as*3148|0)+1212>>2]=aD;c[aA+(as*3148|0)+2236>>2]=aD;aD=aC+1024|0;c[aA+(as*3148|0)+192>>2]=aD;c[aA+(as*3148|0)+1216>>2]=aD;c[aA+(as*3148|0)+2240>>2]=aD;aD=aC+1280|0;c[aA+(as*3148|0)+196>>2]=aD;c[aA+(as*3148|0)+1220>>2]=aD;c[aA+(as*3148|0)+2244>>2]=aD;aD=aC+1536|0;c[aA+(as*3148|0)+200>>2]=aD;c[aA+(as*3148|0)+1224>>2]=aD;c[aA+(as*3148|0)+2248>>2]=aD;aD=aC+1792|0;c[aA+(as*3148|0)+204>>2]=aD;c[aA+(as*3148|0)+1228>>2]=aD;c[aA+(as*3148|0)+2252>>2]=aD;aD=c[2386382]|0;c[aA+(as*3148|0)+208>>2]=aD;c[aA+(as*3148|0)+1232>>2]=aD;c[aA+(as*3148|0)+2256>>2]=aD;aC=aD+256|0;c[aA+(as*3148|0)+212>>2]=aC;c[aA+(as*3148|0)+1236>>2]=aC;c[aA+(as*3148|0)+2260>>2]=aC;aC=aD+512|0;c[aA+(as*3148|0)+216>>2]=aC;c[aA+(as*3148|0)+1240>>2]=aC;c[aA+(as*3148|0)+2264>>2]=aC;aC=aD+768|0;c[aA+(as*3148|0)+220>>2]=aC;c[aA+(as*3148|0)+1244>>2]=aC;c[aA+(as*3148|0)+2268>>2]=aC;aC=aD+1024|0;c[aA+(as*3148|0)+224>>2]=aC;c[aA+(as*3148|0)+1248>>2]=aC;c[aA+(as*3148|0)+2272>>2]=aC;aC=aD+1280|0;c[aA+(as*3148|0)+228>>2]=aC;c[aA+(as*3148|0)+1252>>2]=aC;c[aA+(as*3148|0)+2276>>2]=aC;aC=aD+1536|0;c[aA+(as*3148|0)+232>>2]=aC;c[aA+(as*3148|0)+1256>>2]=aC;c[aA+(as*3148|0)+2280>>2]=aC;aC=aD+1792|0;c[aA+(as*3148|0)+236>>2]=aC;c[aA+(as*3148|0)+1260>>2]=aC;c[aA+(as*3148|0)+2284>>2]=aC;aC=az+4096|0;c[aA+(as*3148|0)+240>>2]=aC;c[aA+(as*3148|0)+1264>>2]=aC;c[aA+(as*3148|0)+2288>>2]=aC;aC=az+4352|0;c[aA+(as*3148|0)+244>>2]=aC;c[aA+(as*3148|0)+1268>>2]=aC;c[aA+(as*3148|0)+2292>>2]=aC;aC=az+4608|0;c[aA+(as*3148|0)+248>>2]=aC;c[aA+(as*3148|0)+1272>>2]=aC;c[aA+(as*3148|0)+2296>>2]=aC;aC=az+4864|0;c[aA+(as*3148|0)+252>>2]=aC;c[aA+(as*3148|0)+1276>>2]=aC;c[aA+(as*3148|0)+2300>>2]=aC;aC=az+5120|0;c[aA+(as*3148|0)+256>>2]=aC;c[aA+(as*3148|0)+1280>>2]=aC;c[aA+(as*3148|0)+2304>>2]=aC;aC=az+5376|0;c[aA+(as*3148|0)+260>>2]=aC;c[aA+(as*3148|0)+1284>>2]=aC;c[aA+(as*3148|0)+2308>>2]=aC;aC=az+5632|0;c[aA+(as*3148|0)+264>>2]=aC;c[aA+(as*3148|0)+1288>>2]=aC;c[aA+(as*3148|0)+2312>>2]=aC;aC=az+5888|0;c[aA+(as*3148|0)+268>>2]=aC;c[aA+(as*3148|0)+1292>>2]=aC;c[aA+(as*3148|0)+2316>>2]=aC;aC=c[2387082]|0;c[aA+(as*3148|0)+272>>2]=aC;c[aA+(as*3148|0)+1296>>2]=aC;c[aA+(as*3148|0)+2320>>2]=aC;aD=aC+256|0;c[aA+(as*3148|0)+276>>2]=aD;c[aA+(as*3148|0)+1300>>2]=aD;c[aA+(as*3148|0)+2324>>2]=aD;aD=aC+512|0;c[aA+(as*3148|0)+280>>2]=aD;c[aA+(as*3148|0)+1304>>2]=aD;c[aA+(as*3148|0)+2328>>2]=aD;aD=aC+768|0;c[aA+(as*3148|0)+284>>2]=aD;c[aA+(as*3148|0)+1308>>2]=aD;c[aA+(as*3148|0)+2332>>2]=aD;aD=aC+1024|0;c[aA+(as*3148|0)+288>>2]=aD;c[aA+(as*3148|0)+1312>>2]=aD;c[aA+(as*3148|0)+2336>>2]=aD;aD=aC+1280|0;c[aA+(as*3148|0)+292>>2]=aD;c[aA+(as*3148|0)+1316>>2]=aD;c[aA+(as*3148|0)+2340>>2]=aD;aD=aC+1536|0;c[aA+(as*3148|0)+296>>2]=aD;c[aA+(as*3148|0)+1320>>2]=aD;c[aA+(as*3148|0)+2344>>2]=aD;aD=aC+1792|0;c[aA+(as*3148|0)+300>>2]=aD;c[aA+(as*3148|0)+1324>>2]=aD;c[aA+(as*3148|0)+2348>>2]=aD;aD=c[3530266]|0;aC=64;aw=64;while(1){aE=aD+((aw<<8)+49152)|0;c[aA+(as*3148|0)+48+(aw<<2)>>2]=aE;c[aA+(as*3148|0)+48+(aw+512<<2)>>2]=aE;aE=aC+1&65535;if((aE&65535)>127){aF=128;aG=128;break}else{aC=aE;aw=aE&65535}}while(1){aw=aD+(aG<<8)|0;c[aA+(as*3148|0)+48+(aG<<2)>>2]=aw;c[aA+(as*3148|0)+48+(aG+512<<2)>>2]=aw;aw=aF+1&65535;if((aw&65535)>255){break}else{aF=aw;aG=aw&65535}}c[aA+(as*3148|0)+3124>>2]=1148;c[aA+(as*3148|0)+3120>>2]=2874;aD=aA+(as*3148|0)|0;if((aD|0)!=0){aw=aD;gGC(aw|0,9660752,48)|0}c[ax>>2]=av;c[3528554]=1;f43(aA+3148|0);aw=c[3528554]|0;aD=9731360+(aw<<2)|0;aC=c[aD>>2]|0;c[2113158]=aC;az=c[3530268]|0;aE=c[2433592]|0;aH=0;aI=0;while(1){aJ=az+(aI<<8)|0;c[aE+(aw*3148|0)+48+(aI<<2)>>2]=aJ;c[aE+(aw*3148|0)+48+(aI+256<<2)>>2]=aJ;c[aE+(aw*3148|0)+48+(aI+512<<2)>>2]=aJ;aJ=aH+1&65535;if((aJ&65535)>15){break}else{aH=aJ;aI=aJ&65535}}aI=c[2387100]|0;c[aE+(aw*3148|0)+112>>2]=aI;c[aE+(aw*3148|0)+1136>>2]=aI;c[aE+(aw*3148|0)+2160>>2]=aI;aH=aI+256|0;c[aE+(aw*3148|0)+116>>2]=aH;c[aE+(aw*3148|0)+1140>>2]=aH;c[aE+(aw*3148|0)+2164>>2]=aH;aH=aI+512|0;c[aE+(aw*3148|0)+120>>2]=aH;c[aE+(aw*3148|0)+1144>>2]=aH;c[aE+(aw*3148|0)+2168>>2]=aH;aH=aI+768|0;c[aE+(aw*3148|0)+124>>2]=aH;c[aE+(aw*3148|0)+1148>>2]=aH;c[aE+(aw*3148|0)+2172>>2]=aH;aH=aI+1024|0;c[aE+(aw*3148|0)+128>>2]=aH;c[aE+(aw*3148|0)+1152>>2]=aH;c[aE+(aw*3148|0)+2176>>2]=aH;aH=aI+1280|0;c[aE+(aw*3148|0)+132>>2]=aH;c[aE+(aw*3148|0)+1156>>2]=aH;c[aE+(aw*3148|0)+2180>>2]=aH;aH=aI+1536|0;c[aE+(aw*3148|0)+136>>2]=aH;c[aE+(aw*3148|0)+1160>>2]=aH;c[aE+(aw*3148|0)+2184>>2]=aH;aH=aI+1792|0;c[aE+(aw*3148|0)+140>>2]=aH;c[aE+(aw*3148|0)+1164>>2]=aH;c[aE+(aw*3148|0)+2188>>2]=aH;aH=c[2386282]|0;c[aE+(aw*3148|0)+176>>2]=aH;c[aE+(aw*3148|0)+1200>>2]=aH;c[aE+(aw*3148|0)+2224>>2]=aH;aI=aH+256|0;c[aE+(aw*3148|0)+180>>2]=aI;c[aE+(aw*3148|0)+1204>>2]=aI;c[aE+(aw*3148|0)+2228>>2]=aI;aI=aH+512|0;c[aE+(aw*3148|0)+184>>2]=aI;c[aE+(aw*3148|0)+1208>>2]=aI;c[aE+(aw*3148|0)+2232>>2]=aI;aI=aH+768|0;c[aE+(aw*3148|0)+188>>2]=aI;c[aE+(aw*3148|0)+1212>>2]=aI;c[aE+(aw*3148|0)+2236>>2]=aI;aI=aH+1024|0;c[aE+(aw*3148|0)+192>>2]=aI;c[aE+(aw*3148|0)+1216>>2]=aI;c[aE+(aw*3148|0)+2240>>2]=aI;aI=aH+1280|0;c[aE+(aw*3148|0)+196>>2]=aI;c[aE+(aw*3148|0)+1220>>2]=aI;c[aE+(aw*3148|0)+2244>>2]=aI;aI=aH+1536|0;c[aE+(aw*3148|0)+200>>2]=aI;c[aE+(aw*3148|0)+1224>>2]=aI;c[aE+(aw*3148|0)+2248>>2]=aI;aI=aH+1792|0;c[aE+(aw*3148|0)+204>>2]=aI;c[aE+(aw*3148|0)+1228>>2]=aI;c[aE+(aw*3148|0)+2252>>2]=aI;aI=c[2386382]|0;c[aE+(aw*3148|0)+208>>2]=aI;c[aE+(aw*3148|0)+1232>>2]=aI;c[aE+(aw*3148|0)+2256>>2]=aI;aH=aI+256|0;c[aE+(aw*3148|0)+212>>2]=aH;c[aE+(aw*3148|0)+1236>>2]=aH;c[aE+(aw*3148|0)+2260>>2]=aH;aH=aI+512|0;c[aE+(aw*3148|0)+216>>2]=aH;c[aE+(aw*3148|0)+1240>>2]=aH;c[aE+(aw*3148|0)+2264>>2]=aH;aH=aI+768|0;c[aE+(aw*3148|0)+220>>2]=aH;c[aE+(aw*3148|0)+1244>>2]=aH;c[aE+(aw*3148|0)+2268>>2]=aH;aH=aI+1024|0;c[aE+(aw*3148|0)+224>>2]=aH;c[aE+(aw*3148|0)+1248>>2]=aH;c[aE+(aw*3148|0)+2272>>2]=aH;aH=aI+1280|0;c[aE+(aw*3148|0)+228>>2]=aH;c[aE+(aw*3148|0)+1252>>2]=aH;c[aE+(aw*3148|0)+2276>>2]=aH;aH=aI+1536|0;c[aE+(aw*3148|0)+232>>2]=aH;c[aE+(aw*3148|0)+1256>>2]=aH;c[aE+(aw*3148|0)+2280>>2]=aH;aH=aI+1792|0;c[aE+(aw*3148|0)+236>>2]=aH;c[aE+(aw*3148|0)+1260>>2]=aH;c[aE+(aw*3148|0)+2284>>2]=aH;aH=az+4096|0;c[aE+(aw*3148|0)+240>>2]=aH;c[aE+(aw*3148|0)+1264>>2]=aH;c[aE+(aw*3148|0)+2288>>2]=aH;aH=az+4352|0;c[aE+(aw*3148|0)+244>>2]=aH;c[aE+(aw*3148|0)+1268>>2]=aH;c[aE+(aw*3148|0)+2292>>2]=aH;aH=az+4608|0;c[aE+(aw*3148|0)+248>>2]=aH;c[aE+(aw*3148|0)+1272>>2]=aH;c[aE+(aw*3148|0)+2296>>2]=aH;aH=az+4864|0;c[aE+(aw*3148|0)+252>>2]=aH;c[aE+(aw*3148|0)+1276>>2]=aH;c[aE+(aw*3148|0)+2300>>2]=aH;aH=az+5120|0;c[aE+(aw*3148|0)+256>>2]=aH;c[aE+(aw*3148|0)+1280>>2]=aH;c[aE+(aw*3148|0)+2304>>2]=aH;aH=az+5376|0;c[aE+(aw*3148|0)+260>>2]=aH;c[aE+(aw*3148|0)+1284>>2]=aH;c[aE+(aw*3148|0)+2308>>2]=aH;aH=az+5632|0;c[aE+(aw*3148|0)+264>>2]=aH;c[aE+(aw*3148|0)+1288>>2]=aH;c[aE+(aw*3148|0)+2312>>2]=aH;aH=az+5888|0;c[aE+(aw*3148|0)+268>>2]=aH;c[aE+(aw*3148|0)+1292>>2]=aH;c[aE+(aw*3148|0)+2316>>2]=aH;aH=c[2387082]|0;c[aE+(aw*3148|0)+272>>2]=aH;c[aE+(aw*3148|0)+1296>>2]=aH;c[aE+(aw*3148|0)+2320>>2]=aH;aI=aH+256|0;c[aE+(aw*3148|0)+276>>2]=aI;c[aE+(aw*3148|0)+1300>>2]=aI;c[aE+(aw*3148|0)+2324>>2]=aI;aI=aH+512|0;c[aE+(aw*3148|0)+280>>2]=aI;c[aE+(aw*3148|0)+1304>>2]=aI;c[aE+(aw*3148|0)+2328>>2]=aI;aI=aH+768|0;c[aE+(aw*3148|0)+284>>2]=aI;c[aE+(aw*3148|0)+1308>>2]=aI;c[aE+(aw*3148|0)+2332>>2]=aI;aI=aH+1024|0;c[aE+(aw*3148|0)+288>>2]=aI;c[aE+(aw*3148|0)+1312>>2]=aI;c[aE+(aw*3148|0)+2336>>2]=aI;aI=aH+1280|0;c[aE+(aw*3148|0)+292>>2]=aI;c[aE+(aw*3148|0)+1316>>2]=aI;c[aE+(aw*3148|0)+2340>>2]=aI;aI=aH+1536|0;c[aE+(aw*3148|0)+296>>2]=aI;c[aE+(aw*3148|0)+1320>>2]=aI;c[aE+(aw*3148|0)+2344>>2]=aI;aI=aH+1792|0;c[aE+(aw*3148|0)+300>>2]=aI;c[aE+(aw*3148|0)+1324>>2]=aI;c[aE+(aw*3148|0)+2348>>2]=aI;aI=c[2386358]|0;aH=64;aA=64;while(1){av=aI+(aA<<8)|0;c[aE+(aw*3148|0)+48+(aA<<2)>>2]=av;c[aE+(aw*3148|0)+48+(aA+512<<2)>>2]=av;av=aH+1&65535;if((av&65535)>255){break}else{aH=av;aA=av&65535}}c[aE+(aw*3148|0)+3124>>2]=1148;c[aE+(aw*3148|0)+3120>>2]=2874;aA=aE+(aw*3148|0)|0;if((aA|0)!=0){aH=aA;gGC(aH|0,9660752,48)|0}c[aD>>2]=aC;c[3528554]=-1;fvI();c[3528556]=0;aH=c[2433594]|0;c[2443776]=aH;L37991:do{if((aH|0)!=0){aA=aH|0;gGC(9660952,aA|0,52)|0;switch(a[9660952]|0){case 0:{c[2309668]=638960;break L37991;break};case 1:{c[2309668]=634096;break L37991;break};case 5:{c[2309668]=7354992;break L37991;break};case 2:{c[2309668]=638960;break L37991;break};case 3:{c[2309668]=639984;break L37991;break};case 4:{c[2309668]=7356016;break L37991;break};default:{break L37991}}}}while(0);aC=c[2432850]|0;c[2113164]=aC;aD=c[3527438]|0;c[aH+68>>2]=aD;c[aH+1092>>2]=aD;c[aH+2116>>2]=aD;aw=aD+256|0;c[aH+72>>2]=aw;c[aH+1096>>2]=aw;c[aH+2120>>2]=aw;aw=aD+512|0;c[aH+76>>2]=aw;c[aH+1100>>2]=aw;c[aH+2124>>2]=aw;aw=aD+768|0;c[aH+80>>2]=aw;c[aH+1104>>2]=aw;c[aH+2128>>2]=aw;aw=aD+1024|0;c[aH+84>>2]=aw;c[aH+1108>>2]=aw;c[aH+2132>>2]=aw;aw=aD+1280|0;c[aH+88>>2]=aw;c[aH+1112>>2]=aw;c[aH+2136>>2]=aw;aw=c[3527436]|0;aD=128;aE=128;while(1){aA=aw+(aE<<8)|0;c[aH+68+(aE<<2)>>2]=aA;c[aH+68+(aE+512<<2)>>2]=aA;aA=aD+1&65535;if((aA&65535)>255){break}else{aD=aA;aE=aA&65535}}c[aH+3148>>2]=406;c[aH+3152>>2]=3306;aE=aH|0;gGC(aE|0,9660952,52)|0;c[2432850]=aC;c[2443776]=0;c[3528556]=-1;c[2424]=5800;U6(3e6,1494,2124,0);c[2438222]=15e5;c[2433520]=2448;c[2406670]=2016;c[3528466]=6844;c[2443840]=1364;h[745399]=.7;a[3203272]=1;Vr(1,15e5,0,644,128,1);c[2438228]=2e6;c[2433526]=3068;c[2406676]=206;c[3528472]=4026;c[2443846]=1023;h[745419]=.2;a[3203368]=1;h[745418]=.23;a[3203360]=1;h[745417]=.23;a[3203352]=1;h[745416]=.23;a[3203344]=1;aE=c[642608+(c[2436]<<2)>>2]|0;aD=c[aE+128>>2]|0;if((c[aE+52>>2]&4|0)==0){c[2113068]=aD;aw=c[aE+132>>2]|0;c[2113070]=aw;c[2443814]=aD;c[2440436]=aw;aK=aD;aL=aw}else{c[2113070]=aD;aw=c[aE+132>>2]|0;c[2113068]=aw;c[2440436]=aD;c[2443814]=aw;aK=aw;aL=aD}aD=ag(aK<<1,aL)|0;aw=gGq(aD)|0;c[2112926]=aw;if((aw|0)!=0){gGz(aw|0,0,aD|0)}a[9623400]=0;aD=c[2414556]|0;gGz(aD|0,0,(c[2411456]|0)-aD|0);c[3528554]=0;f43(c[2433592]|0);aD=c[3528554]|0;c[2113158]=c[9731360+(aD<<2)>>2];a[9660796]=0;a[9660797]=0;a[9660786]=0;a[9660787]=0;c[2415191]=0;a[9660784]=a[9660784]|80;aw=c[2433592]|0;aE=c[aw+(aD*3148|0)+1068>>2]|0;do{if((aE|0)==0){aA=c[aw+(aD*3148|0)+3120>>2]|0;if((aA|0)==0){aM=0;aN=0;aO=aD;aP=aw;break}aI=gj[aA&4095](-2)|0;aA=c[3528554]|0;az=c[2433592]|0;av=c[az+(aA*3148|0)+1068>>2]|0;ax=(aI&255)<<8;if((av|0)!=0){aQ=av;aR=ax;aS=aA;aT=az;au=29536;break}av=c[az+(aA*3148|0)+3120>>2]|0;if((av|0)==0){aM=0;aN=ax;aO=aA;aP=az;break}az=gj[av&4095](-1)|0;aM=az;aN=ax;aO=c[3528554]|0;aP=c[2433592]|0}else{aQ=aE;aR=d[aE+254|0]<<8;aS=aD;aT=aw;au=29536}}while(0);if((au|0)==29536){aM=a[aQ+255|0]|0;aN=aR;aO=aS;aP=aT}aw=aM&255|aN;c[2415188]=aw;b[4830376]=aw&65535;aw=aP+(aO*3148|0)|0;if((aw|0)!=0){aD=aw;gGC(aD|0,9660752,48)|0}c[9731360+(aO<<2)>>2]=c[2113158];c[3528554]=1;f43(aP+3148|0);aD=c[3528554]|0;c[2113158]=c[9731360+(aD<<2)>>2];a[9660796]=0;a[9660797]=0;a[9660786]=0;a[9660787]=0;c[2415191]=0;a[9660784]=a[9660784]|80;aw=c[2433592]|0;aE=c[aw+(aD*3148|0)+1068>>2]|0;do{if((aE|0)==0){aC=c[aw+(aD*3148|0)+3120>>2]|0;if((aC|0)==0){aU=0;aV=0;aW=aD;aX=aw;break}aH=gj[aC&4095](-2)|0;aC=c[3528554]|0;ax=c[2433592]|0;az=c[ax+(aC*3148|0)+1068>>2]|0;av=(aH&255)<<8;if((az|0)!=0){aY=az;aZ=av;a_=aC;a$=ax;au=29545;break}az=c[ax+(aC*3148|0)+3120>>2]|0;if((az|0)==0){aU=0;aV=av;aW=aC;aX=ax;break}ax=gj[az&4095](-1)|0;aU=ax;aV=av;aW=c[3528554]|0;aX=c[2433592]|0}else{aY=aE;aZ=d[aE+254|0]<<8;a_=aD;a$=aw;au=29545}}while(0);if((au|0)==29545){aU=a[aY+255|0]|0;aV=aZ;aW=a_;aX=a$}aw=aU&255|aV;c[2415188]=aw;b[4830376]=aw&65535;aw=aX+(aW*3148|0)|0;if((aw|0)!=0){aD=aw;gGC(aD|0,9660752,48)|0}c[9731360+(aW<<2)>>2]=c[2113158];c[3528554]=-1;c[3528556]=0;aD=c[2433594]|0;c[2443776]=aD;L38035:do{if((aD|0)!=0){aw=aD|0;gGC(9660952,aw|0,52)|0;switch(a[9660952]|0){case 3:{c[2309668]=639984;break L38035;break};case 4:{c[2309668]=7356016;break L38035;break};case 5:{c[2309668]=7354992;break L38035;break};case 0:{c[2309668]=638960;break L38035;break};case 2:{c[2309668]=638960;break L38035;break};case 1:{c[2309668]=634096;break L38035;break};default:{break L38035}}}}while(0);c[2113164]=c[2432850];gu[c[aD+56>>2]&16383]();aw=c[2443776]|0;if((aw|0)!=0){aE=aw|0;gGC(aE|0,9660952,52)|0}c[9731400+(c[3528556]<<2)>>2]=c[2113164];c[2443776]=0;c[3528556]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){aE=0;do{lN(aE);mB(aE);aE=aE+1|0;}while((aE|0)<(c[2385508]|0))}c[2443825]=1073676288;c[2443824]=1073676288;c[2443817]=1073676288;c[2443816]=1073676288;h[883199]=0.0;c[3528506]=0;lw(c[3540986]|0);c[2440606]=0;c[2444190]=0;c[3528196]=0;aB=0;i=e;return aB|0}}while(0);c[2414854]=0;aB=1;i=e;return aB|0}function aG3(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c[2113160]=0;b=c[2433592]|0;if((b|0)!=0){gGr(b);c[2433592]=0}b=a[7452592]|0;if(b){d=0;e=b&1;while(1){b=14163944+(d<<2)|0;f=c[b>>2]|0;g=c[2113006]|0;if((g|0)==0){h=29667}else{i=g-1|0;c[2113006]=i;if((i|0)==0){h=29667}}if((h|0)==29667){h=0;c[2383474]=0}if((f|0)==0){j=e}else{gGr(f);j=a[7452592]&1}c[b>>2]=0;b=d+1|0;if((b|0)<(j|0)){d=b;e=j}else{break}}}a[7452592]=0;c[2438222]=0;c[2433520]=0;c[2406670]=0;c[3528466]=0;j=c[2406686]|0;if((j|0)!=0){gGr(j);c[2406686]=0}c[2432974]=0;a[632376]=0;c[2113070]=0;c[2113068]=0;j=c[2112926]|0;if((j|0)!=0){gGr(j);c[2112926]=0}fvR();j=c[3541518]|0;if((j|0)!=0){gGr(j|0);c[3541518]=0}if((c[2385508]|0)>0){c[2113008]=0;c[2076598]=0;c[2383582]=0}c[2438228]=0;c[2433526]=0;c[2406676]=0;c[3528472]=0;j=c[2406680]|0;if((j|0)!=0){gGr(j);c[2406680]=0}c[2385508]=0;c[2432978]=0;a[64240]=0;j=c[2414854]|0;e=0;while(1){if((e|0)>=1024){h=29687;break}k=9638528+(e<<2)|0;if((c[k>>2]|0)==(j|0)){break}else{e=e+1|0}}if((h|0)==29687){c[2414854]=0;return 0}gGr(j);c[k>>2]=0;c[2414854]=0;return 0}function aG4(){var e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;if((a[9623400]|0)!=0){a[9623400]=0;e=c[2414556]|0;gGz(e|0,0,(c[2411456]|0)-e|0);c[3528554]=0;f43(c[2433592]|0);e=c[3528554]|0;c[2113158]=c[9731360+(e<<2)>>2];a[9660796]=0;a[9660797]=0;a[9660786]=0;a[9660787]=0;c[2415191]=0;a[9660784]=a[9660784]|80;f=c[2433592]|0;g=c[f+(e*3148|0)+1068>>2]|0;do{if((g|0)==0){i=c[f+(e*3148|0)+3120>>2]|0;if((i|0)==0){j=0;k=0;l=e;m=f;break}n=gj[i&4095](-2)|0;i=c[3528554]|0;o=c[2433592]|0;p=c[o+(i*3148|0)+1068>>2]|0;q=(n&255)<<8;if((p|0)!=0){r=p;s=q;t=i;u=o;v=29693;break}p=c[o+(i*3148|0)+3120>>2]|0;if((p|0)==0){j=0;k=q;l=i;m=o;break}o=gj[p&4095](-1)|0;j=o;k=q;l=c[3528554]|0;m=c[2433592]|0}else{r=g;s=d[g+254|0]<<8;t=e;u=f;v=29693}}while(0);if((v|0)==29693){j=a[r+255|0]|0;k=s;l=t;m=u}u=j&255|k;c[2415188]=u;b[4830376]=u&65535;u=m+(l*3148|0)|0;if((u|0)!=0){k=u;gGC(k|0,9660752,48)|0}c[9731360+(l<<2)>>2]=c[2113158];c[3528554]=1;f43(m+3148|0);m=c[3528554]|0;c[2113158]=c[9731360+(m<<2)>>2];a[9660796]=0;a[9660797]=0;a[9660786]=0;a[9660787]=0;c[2415191]=0;a[9660784]=a[9660784]|80;l=c[2433592]|0;k=c[l+(m*3148|0)+1068>>2]|0;do{if((k|0)==0){u=c[l+(m*3148|0)+3120>>2]|0;if((u|0)==0){w=0;x=0;y=m;z=l;break}j=gj[u&4095](-2)|0;u=c[3528554]|0;t=c[2433592]|0;s=c[t+(u*3148|0)+1068>>2]|0;r=(j&255)<<8;if((s|0)!=0){A=s;B=r;C=u;D=t;v=29702;break}s=c[t+(u*3148|0)+3120>>2]|0;if((s|0)==0){w=0;x=r;y=u;z=t;break}t=gj[s&4095](-1)|0;w=t;x=r;y=c[3528554]|0;z=c[2433592]|0}else{A=k;B=d[k+254|0]<<8;C=m;D=l;v=29702}}while(0);if((v|0)==29702){w=a[A+255|0]|0;x=B;y=C;z=D}D=w&255|x;c[2415188]=D;b[4830376]=D&65535;D=z+(y*3148|0)|0;if((D|0)!=0){z=D;gGC(z|0,9660752,48)|0}c[9731360+(y<<2)>>2]=c[2113158];c[3528554]=-1;c[3528556]=0;y=c[2433594]|0;c[2443776]=y;L38121:do{if((y|0)!=0){z=y|0;gGC(9660952,z|0,52)|0;switch(a[9660952]|0){case 0:{c[2309668]=638960;break L38121;break};case 4:{c[2309668]=7356016;break L38121;break};case 1:{c[2309668]=634096;break L38121;break};case 5:{c[2309668]=7354992;break L38121;break};case 3:{c[2309668]=639984;break L38121;break};case 2:{c[2309668]=638960;break L38121;break};default:{break L38121}}}}while(0);c[2113164]=c[2432850];gu[c[y+56>>2]&16383]();y=c[2443776]|0;if((y|0)!=0){z=y|0;gGC(z|0,9660952,52)|0}c[9731400+(c[3528556]<<2)>>2]=c[2113164];c[2443776]=0;c[3528556]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){z=0;do{lN(z);mB(z);z=z+1|0;}while((z|0)<(c[2385508]|0))}c[2443825]=1073676288;c[2443824]=1073676288;c[2443817]=1073676288;c[2443816]=1073676288;h[883199]=0.0;c[3528506]=0;lw(c[3540986]|0);c[2440606]=0;c[2444190]=0;c[3528196]=0}z=c[2113160]|0;if((z|0)>0){gGz(9731360,0,((z|0)>1?z<<2:4)|0)}c[2113158]=0;z=c[2113166]|0;if((z|0)>0){gGz(9731400,0,((z|0)>1?z<<2:4)|0)}c[2113164]=0;gGz(9550152,-1|0,5);z=0;y=-1;D=-1;x=-1;w=-1;C=-1;do{y=((a[9632392+z|0]&1)<<z^y&255)&255;D=((a[9630304+z|0]&1)<<z^D&255)&255;x=((a[9629184+z|0]&1)<<z^x&255)&255;w=((a[9629136+z|0]&1)<<z^w&255)&255;C=((a[9628864+z|0]&1)<<z^C&255)&255;z=z+1|0;}while((z|0)<8);a[9550152]=y;a[9550153]=D;a[9550154]=x;a[9550155]=w;a[9550156]=C;c[3528556]=0;C=c[2433594]|0;c[2443776]=C;L38148:do{if((C|0)!=0){w=C|0;gGC(9660952,w|0,52)|0;switch(a[9660952]|0){case 0:{c[2309668]=638960;break L38148;break};case 1:{c[2309668]=634096;break L38148;break};case 3:{c[2309668]=639984;break L38148;break};case 5:{c[2309668]=7354992;break L38148;break};case 2:{c[2309668]=638960;break L38148;break};case 4:{c[2309668]=7356016;break L38148;break};default:{break L38148}}}}while(0);c[2113164]=c[2432850];c[2408976]=128;C=0;w=0;while(1){if((w|0)==2480){c[2408976]=0}else if((w|0)==80){c[2408976]=128}c[3528554]=0;f43(c[2433592]|0);c[2113158]=c[9731360+(c[3528554]<<2)>>2];Sb(w*13|0);x=c[3528554]|0;D=c[2433592]|0;y=D+(x*3148|0)|0;if((y|0)!=0){z=y;gGC(z|0,9660752,48)|0}c[9731360+(x<<2)>>2]=c[2113158];c[3528554]=1;f43(D+3148|0);D=c[3528554]|0;x=c[9731360+(D<<2)>>2]|0;c[2113158]=x;z=w+1|0;y=z*13|0;if((c[3528196]|0)==0){B=f45(y-C|0)|0;A=(c[2113158]|0)+B|0;c[2113158]=A;E=B+C|0;F=c[3528554]|0;G=A}else{E=y;F=D;G=x}x=(c[2433592]|0)+(F*3148|0)|0;if((x|0)!=0){D=x;gGC(D|0,9660752,48)|0}c[9731360+(F<<2)>>2]=G;c[3528554]=-1;U1(w*10|0);if((z|0)<2560){C=E;w=z}else{break}}c[3528554]=0;f43(c[2433592]|0);c[2113158]=c[9731360+(c[3528554]<<2)>>2];w=c[2438228]|0;E=gGS(1283719168,16442,w,(w|0)<0|0?-1:0)|0;w=E;Sb(34482);E=c[2443830]|0;if((E|0)<1073676288){c[2443830]=E-w}E=c[2443831]|0;if((E|0)<1073676288){c[2443831]=E-w}E=(c[3528512]|0)-w|0;c[3528512]=(E|0)<0?0:E;E=c[2438222]|0;w=gGS(-160694272,12331,E,(E|0)<0|0?-1:0)|0;E=w;U1(25862);w=c[2443824]|0;if((w|0)<1073676288){c[2443824]=w-E}w=c[2443825]|0;if((w|0)<1073676288){c[2443825]=w-E}w=(c[3528506]|0)-E|0;c[3528506]=(w|0)<0?0:w;w=c[2112964]|0;if((w|0)!=0){gg[c[3542114]&4095](w,a[9688]|0?534:0);gg[c[3542122]&4095](c[2112964]|0,a[9688]|0?534:0)}w=c[2443776]|0;if((w|0)!=0){E=w|0;gGC(E|0,9660952,52)|0}c[9731400+(c[3528556]<<2)>>2]=c[2113164];c[2443776]=0;c[3528556]=-1;E=c[3528554]|0;w=(c[2433592]|0)+(E*3148|0)|0;if((w|0)!=0){C=w;gGC(C|0,9660752,48)|0}c[9731360+(E<<2)>>2]=c[2113158];c[3528554]=-1;if((c[2112968]|0)==0){return 0}E=c[(c[642608+(c[2436]<<2)>>2]|0)+112>>2]|0;if((E|0)==0){return 0}gD[E&8191]()|0;return 0}function aG5(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if((a[9547080]|0)!=0){b=c[2387100]|0;e=c[3529894]|0;f=0;do{g=a[b+f|0]|0;h=a[b+(f+1024)|0]|0;i=(g&255)>>>4;c[e+(f<<2)>>2]=((h&8|h<<4)&255)>>>3|((g&8|g<<4)&255)<<8&63488|((i<<4|i)&255)<<3&2016;f=f+1|0;}while((f|0)<1024)}aHG(0,0);aHH(0);f=c[2113070]|0;e=c[2386282]|0;b=c[2112926]|0;i=c[3530752]|0;g=0;do{h=(g>>5<<3)-8|0;if((h|0)>-1&(h|0)<(f|0)){j=g<<1;k=d[e+j|0]|0;Sq(b,k<<8&3840|d[e+(j|1)|0],g<<3&248,h,k>>>6,3,0,0,i)}g=g+1|0;}while((g|0)<1024);R8(c[3529894]|0);return 0}function aG6(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;e=i;i=i+96|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;l=e+80|0;if((b&64|0)==0){aHx(b,d);i=e;return 0}m=k|0;if((c[2113160]|0)>0){n=k+7|0;k=j|0;o=j+4|0;p=j+12|0;q=h;r=h|0;s=h+4|0;t=h+12|0;u=g;v=g|0;w=g+4|0;x=g+12|0;y=f;z=f|0;A=f+4|0;B=f+12|0;C=0;do{D=c[2433592]|0;E=D+(C*3148|0)+40|0;F=c[E>>2]|0;gGC(m|0,614752,9)|0;a[n]=C+48&255;c[k>>2]=D+(C*3148|0);c[o>>2]=48;c[p>>2]=m;gj[c[2076592]&4095](j)|0;gGz(q|0,0,12);c[r>>2]=D+(C*3148|0)+3136;c[s>>2]=4;c[t>>2]=165288;gj[c[2076592]&4095](h)|0;gGz(u|0,0,12);c[v>>2]=D+(C*3148|0)+3140;c[w>>2]=4;c[x>>2]=501592;gj[c[2076592]&4095](g)|0;gGz(y|0,0,12);c[z>>2]=D+(C*3148|0)+3144;c[A>>2]=4;c[B>>2]=386080;gj[c[2076592]&4095](f)|0;c[E>>2]=F;C=C+1|0;}while((C|0)<(c[2113160]|0))}Vb(b,d);gGz(l|0,0,12);c[l>>2]=14112784;c[l+4>>2]=4;c[l+12>>2]=507296;gj[c[2076592]&4095](l)|0;if((b&2|0)==0){aHx(b,d);i=e;return 0}c[3528554]=0;f43(c[2433592]|0);l=c[3528554]|0;C=9731360+(l<<2)|0;f=c[C>>2]|0;c[2113158]=f;B=c[3530266]|0;A=c[2433592]|0;z=(c[2406854]|0)+49152|0;y=64;g=64;while(1){x=B+(z+(g<<8))|0;c[A+(l*3148|0)+48+(g<<2)>>2]=x;c[A+(l*3148|0)+48+(g+512<<2)>>2]=x;x=y+1&65535;if((x&65535)>127){break}else{y=x;g=x&65535}}g=A+(l*3148|0)|0;if((g|0)!=0){l=g;gGC(l|0,9660752,48)|0}c[C>>2]=f;c[3528554]=-1;aHx(b,d);i=e;return 0}function aG7(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2648860+(b*112|0)>>2];c[a+104>>2]=c[2648864+(b*112|0)>>2];c[a+108>>2]=c[2648868+(b*112|0)>>2];d=0;return d|0}function aG8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=2648760+(b*112|0);e=0;return e|0}function aG9(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2650540+(b*112|0)>>2];c[a+104>>2]=c[2650544+(b*112|0)>>2];c[a+108>>2]=c[2650548+(b*112|0)>>2];d=0;return d|0}function aHa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=2650440+(b*112|0);e=0;return e|0}function aHb(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>36){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3806368+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aHc(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2295276+(b*112|0)>>2];c[a+104>>2]=c[2295280+(b*112|0)>>2];c[a+108>>2]=c[2295284+(b*112|0)>>2];d=0;return d|0}function aHd(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<22&(d|0)==0)){e=1;return e|0}c[a>>2]=2295176+(b*112|0);e=0;return e|0}function aHe(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1196328+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aHf(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>35){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3476560+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aHg(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if((a[9547080]|0)!=0){b=c[2387100]|0;e=c[3529894]|0;f=0;do{g=a[b+f|0]|0;h=a[b+(f+1024)|0]|0;i=(g&255)>>>4;c[e+(f<<2)>>2]=((h&8|h<<4)&255)>>>3|((g&8|g<<4)&255)<<8&63488|((i<<4|i)&255)<<3&2016;f=f+1|0;}while((f|0)<1024)}aHG(0,65520);aHG(0,15);aHG(1,65520);aHG(1,15);aHH(0);f=c[2113070]|0;e=c[2386282]|0;b=c[2112926]|0;i=c[3530752]|0;g=0;do{h=(g>>5<<3)-8|0;if((h|0)>-1&(h|0)<(f|0)){j=g<<1;k=d[e+j|0]|0;Sq(b,k<<8&3840|d[e+(j|1)|0],g<<3&248,h,k>>>6,3,0,0,i)}g=g+1|0;}while((g|0)<1024);R8(c[3529894]|0);return 0}function aHh(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3048468+(b*112|0)>>2];c[a+104>>2]=c[3048472+(b*112|0)>>2];c[a+108>>2]=c[3048476+(b*112|0)>>2];d=0;return d|0}function aHi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<22&(d|0)==0)){e=1;return e|0}c[a>>2]=3048368+(b*112|0);e=0;return e|0}function aHj(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=b&65535;switch(e|0){case 6156:{a[c[3528212]|0]=d;gg[c[(c[2443776]|0)+64>>2]&4095](32,1);gj[c[(c[2443776]|0)+52>>2]&4095](0)|0;gg[c[(c[2443776]|0)+64>>2]&4095](32,0);gj[c[(c[2443776]|0)+52>>2]&4095](0)|0;return};case 6151:{a[c[3528652]|0]=d;return};case 6152:case 6153:case 6154:case 6155:{a[(c[3529872]|0)+(e&3|16)|0]=d;return};case 6149:{gGC(c[2386556]|0,c[2386382]|0,2048)|0;return};case 6158:case 6159:{if((c[3528554]|0)!=0){return}b=e&1;c[2440606]=0;if((b|0)==0){e=a[9550154]|0;c[2444190]=c[2444190]&255|(d&255)<<8;f44(1);f45(0)|0;a[9660787]=0;f45(0)|0;f=(e&3)!=3;e=a[596872]|0;if(f|e){g=e}else{a[596872]=1;g=1}if(f&g){c[2384334]=(c[2384334]|0)+1;a[596872]=0;a[596880]=1;c[2440606]=4608;return}g=c[2444190]|0;do{if((g|0)==1354){h=-75;i=29896}else if((g|0)==1356){h=-77;i=29896}else{f=g&-256;if((f|0)!=256){j=f;break}c[2440606]=0;return}}while(0);if((i|0)==29896){c[2440606]=h;c[2384334]=0;a[596880]=0;j=g&-256}if((j|0)==512){c[2440606]=(a[596880]|0?4608:0)|c[2384334];a[596880]=0;return}g=c[2384334]|0;if(!((j|0)==768&(g|0)!=0)){return}c[2440606]=0;c[2384334]=g-1;return}else if((b|0)==1){c[2444190]=c[2444190]&65280|d&255;return}else{return}break};case 6147:{b=c[3528554]|0;if((b|0)==0){f44(0);f45(0)|0;a[9660786]=0;f45(0)|0;return}g=c[2433592]|0;j=g+(b*3148|0)|0;if((j|0)!=0){h=j;gGC(h|0,9660752,48)|0}c[9731360+(b<<2)>>2]=c[2113158];c[3528554]=0;f43(g);c[2113158]=c[9731360+(c[3528554]<<2)>>2];f44(0);f45(0)|0;a[9660786]=0;f45(0)|0;g=c[3528554]|0;b=c[2433592]|0;h=b+(g*3148|0)|0;if((h|0)!=0){j=h;gGC(j|0,9660752,48)|0}c[9731360+(g<<2)>>2]=c[2113158];c[3528554]=1;f43(b+3148|0);c[2113158]=c[9731360+(c[3528554]<<2)>>2];return};case 6157:{if((c[3528554]|0)!=0){return}b=(d&255)<<14&245760;c[2406854]=b;d=c[3530266]|0;g=c[2433592]|0;j=b+49152|0;b=64;h=64;while(1){i=d+(j+(h<<8))|0;c[g+48+(h<<2)>>2]=i;c[g+48+(h+512<<2)>>2]=i;i=b+1&65535;if((i&65535)>127){break}else{b=i;h=i&65535}}return};case 6148:{if((c[3528554]|0)!=0){f44(0);f45(0)|0;a[9660786]=0;f45(0)|0;return}h=c[2433592]|0;if((h|0)!=0){b=h;gGC(b|0,9660752,48)|0}c[2432840]=c[2113158];c[3528554]=1;f43(h+3148|0);c[2113158]=c[9731360+(c[3528554]<<2)>>2];f44(0);f45(0)|0;a[9660786]=0;f45(0)|0;h=c[3528554]|0;b=c[2433592]|0;g=b+(h*3148|0)|0;if((g|0)!=0){j=g;gGC(j|0,9660752,48)|0}c[9731360+(h<<2)>>2]=c[2113158];c[3528554]=0;f43(b);c[2113158]=c[9731360+(c[3528554]<<2)>>2];return};default:{return}}}function aHk(b){b=b|0;var d=0;switch(b&65535|0){case 7680:{d=c[2440606]&255;break};case 7168:{d=(c[2440606]|0)>>>8&255;break};case 6144:{d=a[9550153]|0;break};case 6148:{d=a[9634673]|0;break};case 6149:{d=a[9634672]|0;break};case 6147:{d=(a[9550154]&127|c[2408976])&255;break};case 6145:{d=a[9550152]|0;break};default:{d=0}}return d|0}function aHl(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=b&65535;switch(f|0){case 8192:{b=(e&255)>>>3&1;c[3528942]=b;g=c[3527436]|0;h=c[2443776]|0;i=(b<<14|65536)-16384|0;b=64;j=64;while(1){k=g+(i+(j<<8))|0;c[h+68+(j<<2)>>2]=k;c[h+68+(j+512<<2)>>2]=k;k=b+1&65535;if((k&65535)>127){break}else{b=k;j=k&65535}}return};case 4096:case 4097:{j=c[3540986]|0;if((f&1|0)==0){a[j+5885|0]=e;return}b=c[j+5876>>2]|0;if((b|0)!=0){gg[b&4095](c[j+5880>>2]|0,0)}lH(j,d[j+5885|0]|0,e&255);return};case 2048:case 2049:{lS(0,f&1,e);return};case 6144:{c[3527068]=e&255;return};default:{return}}}function aHm(b){b=b|0;var d=0,e=0;d=b&65535;if((d|0)==12288){e=a[c[3528212]|0]|0}else if((d|0)==13312){c[2415126]=9662152;c[2415540]=0;e=0}else{e=0}return e|0}function aHn(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4764420+(b*112|0)>>2];c[a+104>>2]=c[4764424+(b*112|0)>>2];c[a+108>>2]=c[4764428+(b*112|0)>>2];d=0;return d|0}function aHo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=4764320+(b*112|0);e=0;return e|0}function aHp(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1196328+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aHq(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>33){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5517448+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aHr(){var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0;b=i;i=i+1800|0;d=b|0;e=b+112|0;f=b+120|0;g=b+232|0;j=b+240|0;k=b+352|0;l=b+360|0;m=b+472|0;n=b+480|0;o=b+592|0;p=b+600|0;q=b+712|0;r=b+720|0;s=b+832|0;t=b+840|0;u=b+952|0;v=b+960|0;w=b+1072|0;x=b+1080|0;y=b+1192|0;z=b+1200|0;A=b+1312|0;B=b+1320|0;C=b+1432|0;D=b+1440|0;E=b+1552|0;F=b+1560|0;G=b+1672|0;H=b+1680|0;I=b+1792|0;c[2414854]=0;c[3530266]=0;c[2386358]=327680;c[3527436]=458752;c[3527440]=589824;c[3530752]=655360;c[3530516]=786432;c[3530384]=1835008;c[3530308]=2883584;c[3531056]=3932160;c[2407020]=3934208;c[3529894]=3938304;c[2414556]=3942400;c[3530268]=3942400;c[2386282]=3950592;c[2387082]=3952640;c[2387076]=3956736;c[3529872]=3960832;c[3529870]=3960864;c[2386744]=3960896;c[2386382]=3961920;c[2386556]=3963968;c[2387100]=3966016;c[3527438]=3968064;c[3528212]=3970112;c[3528482]=3970113;c[2432942]=3970114;c[3528652]=3970115;c[2411456]=3970116;J=0;while(1){if((J|0)>=1024){break}K=9638528+(J<<2)|0;if((c[K>>2]|0)==0){L=29982;break}else{J=J+1|0}}do{if((L|0)==29982){J=gGq(3970116)|0;c[K>>2]=J;if((J|0)==0){break}c[2414854]=J;gGz(J|0,0,3970116);c[3530266]=J;c[2386358]=J+327680;c[3527436]=J+458752;c[3527440]=J+589824;c[3530752]=J+655360;c[3530516]=J+786432;c[3530384]=J+1835008;c[3530308]=J+2883584;c[3531056]=J+3932160;c[2407020]=J+3934208;c[3529894]=J+3938304;M=J+3942400|0;c[2414556]=M;c[3530268]=M;c[2386282]=J+3950592;c[2387082]=J+3952640;c[2387076]=J+3956736;c[3529872]=J+3960832;c[3529870]=J+3960864;c[2386744]=J+3960896;c[2386382]=J+3961920;c[2386556]=J+3963968;c[2387100]=J+3966016;c[3527438]=J+3968064;c[3528212]=J+3970112;c[3528482]=J+3970113;c[2432942]=J+3970114;c[3528652]=J+3970115;M=J+3970116|0;c[2411456]=M;c[2413996]=M;M=J+32768|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}J=H+108|0;c[J>>2]=0;O=H+100|0;c[O>>2]=0;P=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[P&16383](H,0)|0;do{if((c[J>>2]|0)!=0){P=c[O>>2]|0;c[I>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](I,0,0)|0;if((P|0)<1){N=1;i=b;return N|0}if((gzL(M,0,0)|0)==0){break}else{N=1}i=b;return N|0}}while(0);M=(c[3530266]|0)+65536|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}O=F+108|0;c[O>>2]=0;J=F+100|0;c[J>>2]=0;P=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[P&16383](F,1)|0;do{if((c[O>>2]|0)!=0){P=c[J>>2]|0;c[G>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](G,1,0)|0;if((P|0)<1){N=1;i=b;return N|0}if((gzL(M,0,1)|0)==0){break}else{N=1}i=b;return N|0}}while(0);M=(c[3530266]|0)+131072|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}J=D+108|0;c[J>>2]=0;O=D+100|0;c[O>>2]=0;P=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[P&16383](D,2)|0;do{if((c[J>>2]|0)!=0){P=c[O>>2]|0;c[E>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](E,2,0)|0;if((P|0)<1){N=1;i=b;return N|0}if((gzL(M,0,2)|0)==0){break}else{N=1}i=b;return N|0}}while(0);M=c[2386358]|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}O=B+108|0;c[O>>2]=0;J=B+100|0;c[J>>2]=0;P=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[P&16383](B,3)|0;do{if((c[O>>2]|0)!=0){P=c[J>>2]|0;c[C>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](C,3,0)|0;if((P|0)<1){N=1;i=b;return N|0}if((gzL(M,0,3)|0)==0){break}else{N=1}i=b;return N|0}}while(0);M=c[3527436]|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}J=z+108|0;c[J>>2]=0;O=z+100|0;c[O>>2]=0;P=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[P&16383](z,4)|0;do{if((c[J>>2]|0)!=0){P=c[O>>2]|0;c[A>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](A,4,0)|0;if((P|0)<1){N=1;i=b;return N|0}if((gzL(M,0,4)|0)==0){break}else{N=1}i=b;return N|0}}while(0);M=c[3527436]|0;O=M+65536|0;gGC(O|0,M|0,32768)|0;M=c[3530752]|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}O=x+108|0;c[O>>2]=0;J=x+100|0;c[J>>2]=0;P=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[P&16383](x,5)|0;do{if((c[O>>2]|0)!=0){P=c[J>>2]|0;c[y>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](y,5,0)|0;if((P|0)<1){N=1;i=b;return N|0}if((gzL(M,0,5)|0)==0){break}else{N=1}i=b;return N|0}}while(0);M=c[3530516]|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}J=v+108|0;c[J>>2]=0;O=v+100|0;c[O>>2]=0;P=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[P&16383](v,6)|0;do{if((c[J>>2]|0)!=0){P=c[O>>2]|0;c[w>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](w,6,0)|0;if((P|0)<1){N=1;i=b;return N|0}if((gzL(M,0,6)|0)==0){break}else{N=1}i=b;return N|0}}while(0);M=(c[3530516]|0)+131072|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}O=t+108|0;c[O>>2]=0;J=t+100|0;c[J>>2]=0;P=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[P&16383](t,7)|0;do{if((c[O>>2]|0)!=0){P=c[J>>2]|0;c[u>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](u,7,0)|0;if((P|0)<1){N=1;i=b;return N|0}if((gzL(M,0,7)|0)==0){break}else{N=1}i=b;return N|0}}while(0);M=(c[3530516]|0)+262144|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}J=r+108|0;c[J>>2]=0;O=r+100|0;c[O>>2]=0;P=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[P&16383](r,8)|0;do{if((c[J>>2]|0)!=0){P=c[O>>2]|0;c[s>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](s,8,0)|0;if((P|0)<1){N=1;i=b;return N|0}if((gzL(M,0,8)|0)==0){break}else{N=1}i=b;return N|0}}while(0);M=c[3530384]|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}O=p+108|0;c[O>>2]=0;J=p+100|0;c[J>>2]=0;P=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[P&16383](p,9)|0;do{if((c[O>>2]|0)!=0){P=c[J>>2]|0;c[q>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](q,9,0)|0;if((P|0)<1){N=1;i=b;return N|0}if((gzL(M,0,9)|0)==0){break}else{N=1}i=b;return N|0}}while(0);M=(c[3530384]|0)+65536|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}J=n+108|0;c[J>>2]=0;O=n+100|0;c[O>>2]=0;P=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[P&16383](n,10)|0;do{if((c[J>>2]|0)!=0){P=c[O>>2]|0;c[o>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](o,10,0)|0;if((P|0)<1){N=1;i=b;return N|0}if((gzL(M,0,10)|0)==0){break}else{N=1}i=b;return N|0}}while(0);M=(c[3530384]|0)+131072|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}O=l+108|0;c[O>>2]=0;J=l+100|0;c[J>>2]=0;P=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[P&16383](l,11)|0;do{if((c[O>>2]|0)!=0){P=c[J>>2]|0;c[m>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](m,11,0)|0;if((P|0)<1){N=1;i=b;return N|0}if((gzL(M,0,11)|0)==0){break}else{N=1}i=b;return N|0}}while(0);M=(c[3530384]|0)+196608|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}J=j+108|0;c[J>>2]=0;O=j+100|0;c[O>>2]=0;P=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[P&16383](j,12)|0;do{if((c[J>>2]|0)!=0){P=c[O>>2]|0;c[k>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](k,12,0)|0;if((P|0)<1){N=1;i=b;return N|0}if((gzL(M,0,12)|0)==0){break}else{N=1}i=b;return N|0}}while(0);M=(c[3530384]|0)+262144|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}O=f+108|0;c[O>>2]=0;J=f+100|0;c[J>>2]=0;P=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[P&16383](f,13)|0;do{if((c[O>>2]|0)!=0){P=c[J>>2]|0;c[g>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](g,13,0)|0;if((P|0)<1){N=1;i=b;return N|0}if((gzL(M,0,13)|0)==0){break}else{N=1}i=b;return N|0}}while(0);M=(c[3530384]|0)+327680|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}J=d+108|0;c[J>>2]=0;O=d+100|0;c[O>>2]=0;P=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[P&16383](d,14)|0;do{if((c[J>>2]|0)!=0){P=c[O>>2]|0;c[e>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](e,14,0)|0;if((P|0)<1){N=1;i=b;return N|0}if((gzL(M,0,14)|0)==0){break}else{N=1}i=b;return N|0}}while(0);aHz();c[3528554]=-1;c[2113160]=2;M=gGq(6296)|0;O=M;c[2433592]=O;if((M|0)!=0){gGz(M|0,0,6296);J=0;do{c[O+(J*3148|0)+3120>>2]=3128;c[O+(J*3148|0)+3124>>2]=1840;c[O+(J*3148|0)+3128>>2]=136;c[O+(J*3148|0)+3132>>2]=1902;c[9731360+(J<<2)>>2]=0;P=0;do{c[O+(J*3148|0)+48+(P<<2)>>2]=0;P=P+1|0;}while((P|0)<768);J=J+1|0;}while((J|0)<2);c[2113158]=0;c[2415198]=0;J=c[2427044]|0;c[9681616+(J<<3)>>2]=809272;c[9681620+(J<<3)>>2]=0;O=J+1|0;c[9681616+(O<<3)>>2]=809272;c[9681620+(O<<3)>>2]=1;c[2427044]=J+2}c[3528554]=0;f43(M);J=c[3528554]|0;O=9731360+(J<<2)|0;P=c[O>>2]|0;c[2113158]=P;Q=c[3530268]|0;R=c[2433592]|0;S=0;T=0;while(1){U=Q+(T<<8)|0;c[R+(J*3148|0)+48+(T<<2)>>2]=U;c[R+(J*3148|0)+48+(T+256<<2)>>2]=U;c[R+(J*3148|0)+48+(T+512<<2)>>2]=U;U=S+1&65535;if((U&65535)>15){break}else{S=U;T=U&65535}}T=c[2387100]|0;c[R+(J*3148|0)+112>>2]=T;c[R+(J*3148|0)+1136>>2]=T;c[R+(J*3148|0)+2160>>2]=T;S=T+256|0;c[R+(J*3148|0)+116>>2]=S;c[R+(J*3148|0)+1140>>2]=S;c[R+(J*3148|0)+2164>>2]=S;S=T+512|0;c[R+(J*3148|0)+120>>2]=S;c[R+(J*3148|0)+1144>>2]=S;c[R+(J*3148|0)+2168>>2]=S;S=T+768|0;c[R+(J*3148|0)+124>>2]=S;c[R+(J*3148|0)+1148>>2]=S;c[R+(J*3148|0)+2172>>2]=S;S=T+1024|0;c[R+(J*3148|0)+128>>2]=S;c[R+(J*3148|0)+1152>>2]=S;c[R+(J*3148|0)+2176>>2]=S;S=T+1280|0;c[R+(J*3148|0)+132>>2]=S;c[R+(J*3148|0)+1156>>2]=S;c[R+(J*3148|0)+2180>>2]=S;S=T+1536|0;c[R+(J*3148|0)+136>>2]=S;c[R+(J*3148|0)+1160>>2]=S;c[R+(J*3148|0)+2184>>2]=S;S=T+1792|0;c[R+(J*3148|0)+140>>2]=S;c[R+(J*3148|0)+1164>>2]=S;c[R+(J*3148|0)+2188>>2]=S;S=c[2386282]|0;c[R+(J*3148|0)+176>>2]=S;c[R+(J*3148|0)+1200>>2]=S;c[R+(J*3148|0)+2224>>2]=S;T=S+256|0;c[R+(J*3148|0)+180>>2]=T;c[R+(J*3148|0)+1204>>2]=T;c[R+(J*3148|0)+2228>>2]=T;T=S+512|0;c[R+(J*3148|0)+184>>2]=T;c[R+(J*3148|0)+1208>>2]=T;c[R+(J*3148|0)+2232>>2]=T;T=S+768|0;c[R+(J*3148|0)+188>>2]=T;c[R+(J*3148|0)+1212>>2]=T;c[R+(J*3148|0)+2236>>2]=T;T=S+1024|0;c[R+(J*3148|0)+192>>2]=T;c[R+(J*3148|0)+1216>>2]=T;c[R+(J*3148|0)+2240>>2]=T;T=S+1280|0;c[R+(J*3148|0)+196>>2]=T;c[R+(J*3148|0)+1220>>2]=T;c[R+(J*3148|0)+2244>>2]=T;T=S+1536|0;c[R+(J*3148|0)+200>>2]=T;c[R+(J*3148|0)+1224>>2]=T;c[R+(J*3148|0)+2248>>2]=T;T=S+1792|0;c[R+(J*3148|0)+204>>2]=T;c[R+(J*3148|0)+1228>>2]=T;c[R+(J*3148|0)+2252>>2]=T;T=c[2386382]|0;c[R+(J*3148|0)+208>>2]=T;c[R+(J*3148|0)+1232>>2]=T;c[R+(J*3148|0)+2256>>2]=T;S=T+256|0;c[R+(J*3148|0)+212>>2]=S;c[R+(J*3148|0)+1236>>2]=S;c[R+(J*3148|0)+2260>>2]=S;S=T+512|0;c[R+(J*3148|0)+216>>2]=S;c[R+(J*3148|0)+1240>>2]=S;c[R+(J*3148|0)+2264>>2]=S;S=T+768|0;c[R+(J*3148|0)+220>>2]=S;c[R+(J*3148|0)+1244>>2]=S;c[R+(J*3148|0)+2268>>2]=S;S=T+1024|0;c[R+(J*3148|0)+224>>2]=S;c[R+(J*3148|0)+1248>>2]=S;c[R+(J*3148|0)+2272>>2]=S;S=T+1280|0;c[R+(J*3148|0)+228>>2]=S;c[R+(J*3148|0)+1252>>2]=S;c[R+(J*3148|0)+2276>>2]=S;S=T+1536|0;c[R+(J*3148|0)+232>>2]=S;c[R+(J*3148|0)+1256>>2]=S;c[R+(J*3148|0)+2280>>2]=S;S=T+1792|0;c[R+(J*3148|0)+236>>2]=S;c[R+(J*3148|0)+1260>>2]=S;c[R+(J*3148|0)+2284>>2]=S;S=Q+4096|0;c[R+(J*3148|0)+240>>2]=S;c[R+(J*3148|0)+1264>>2]=S;c[R+(J*3148|0)+2288>>2]=S;S=Q+4352|0;c[R+(J*3148|0)+244>>2]=S;c[R+(J*3148|0)+1268>>2]=S;c[R+(J*3148|0)+2292>>2]=S;S=Q+4608|0;c[R+(J*3148|0)+248>>2]=S;c[R+(J*3148|0)+1272>>2]=S;c[R+(J*3148|0)+2296>>2]=S;S=Q+4864|0;c[R+(J*3148|0)+252>>2]=S;c[R+(J*3148|0)+1276>>2]=S;c[R+(J*3148|0)+2300>>2]=S;S=Q+5120|0;c[R+(J*3148|0)+256>>2]=S;c[R+(J*3148|0)+1280>>2]=S;c[R+(J*3148|0)+2304>>2]=S;S=Q+5376|0;c[R+(J*3148|0)+260>>2]=S;c[R+(J*3148|0)+1284>>2]=S;c[R+(J*3148|0)+2308>>2]=S;S=Q+5632|0;c[R+(J*3148|0)+264>>2]=S;c[R+(J*3148|0)+1288>>2]=S;c[R+(J*3148|0)+2312>>2]=S;S=Q+5888|0;c[R+(J*3148|0)+268>>2]=S;c[R+(J*3148|0)+1292>>2]=S;c[R+(J*3148|0)+2316>>2]=S;S=c[2387082]|0;c[R+(J*3148|0)+272>>2]=S;c[R+(J*3148|0)+1296>>2]=S;c[R+(J*3148|0)+2320>>2]=S;T=S+256|0;c[R+(J*3148|0)+276>>2]=T;c[R+(J*3148|0)+1300>>2]=T;c[R+(J*3148|0)+2324>>2]=T;T=S+512|0;c[R+(J*3148|0)+280>>2]=T;c[R+(J*3148|0)+1304>>2]=T;c[R+(J*3148|0)+2328>>2]=T;T=S+768|0;c[R+(J*3148|0)+284>>2]=T;c[R+(J*3148|0)+1308>>2]=T;c[R+(J*3148|0)+2332>>2]=T;T=S+1024|0;c[R+(J*3148|0)+288>>2]=T;c[R+(J*3148|0)+1312>>2]=T;c[R+(J*3148|0)+2336>>2]=T;T=S+1280|0;c[R+(J*3148|0)+292>>2]=T;c[R+(J*3148|0)+1316>>2]=T;c[R+(J*3148|0)+2340>>2]=T;T=S+1536|0;c[R+(J*3148|0)+296>>2]=T;c[R+(J*3148|0)+1320>>2]=T;c[R+(J*3148|0)+2344>>2]=T;T=S+1792|0;c[R+(J*3148|0)+300>>2]=T;c[R+(J*3148|0)+1324>>2]=T;c[R+(J*3148|0)+2348>>2]=T;T=c[3530266]|0;S=64;M=64;while(1){U=T+((M<<8)+49152)|0;c[R+(J*3148|0)+48+(M<<2)>>2]=U;c[R+(J*3148|0)+48+(M+256<<2)>>2]=U;c[R+(J*3148|0)+48+(M+512<<2)>>2]=U;U=S+1&65535;if((U&65535)>127){V=128;W=128;break}else{S=U;M=U&65535}}while(1){M=T+(W<<8)|0;c[R+(J*3148|0)+48+(W<<2)>>2]=M;c[R+(J*3148|0)+48+(W+256<<2)>>2]=M;c[R+(J*3148|0)+48+(W+512<<2)>>2]=M;M=V+1&65535;if((M&65535)>255){break}else{V=M;W=M&65535}}c[R+(J*3148|0)+3124>>2]=1076;c[R+(J*3148|0)+3120>>2]=1812;T=R+(J*3148|0)|0;if((T|0)!=0){M=T;gGC(M|0,9660752,48)|0}c[O>>2]=P;c[3528554]=1;f43(R+3148|0);M=c[3528554]|0;T=9731360+(M<<2)|0;S=c[T>>2]|0;c[2113158]=S;Q=c[3530268]|0;U=c[2433592]|0;X=0;Y=0;while(1){Z=Q+(Y<<8)|0;c[U+(M*3148|0)+48+(Y<<2)>>2]=Z;c[U+(M*3148|0)+48+(Y+256<<2)>>2]=Z;c[U+(M*3148|0)+48+(Y+512<<2)>>2]=Z;Z=X+1&65535;if((Z&65535)>15){break}else{X=Z;Y=Z&65535}}Y=c[2387100]|0;c[U+(M*3148|0)+112>>2]=Y;c[U+(M*3148|0)+1136>>2]=Y;c[U+(M*3148|0)+2160>>2]=Y;X=Y+256|0;c[U+(M*3148|0)+116>>2]=X;c[U+(M*3148|0)+1140>>2]=X;c[U+(M*3148|0)+2164>>2]=X;X=Y+512|0;c[U+(M*3148|0)+120>>2]=X;c[U+(M*3148|0)+1144>>2]=X;c[U+(M*3148|0)+2168>>2]=X;X=Y+768|0;c[U+(M*3148|0)+124>>2]=X;c[U+(M*3148|0)+1148>>2]=X;c[U+(M*3148|0)+2172>>2]=X;X=Y+1024|0;c[U+(M*3148|0)+128>>2]=X;c[U+(M*3148|0)+1152>>2]=X;c[U+(M*3148|0)+2176>>2]=X;X=Y+1280|0;c[U+(M*3148|0)+132>>2]=X;c[U+(M*3148|0)+1156>>2]=X;c[U+(M*3148|0)+2180>>2]=X;X=Y+1536|0;c[U+(M*3148|0)+136>>2]=X;c[U+(M*3148|0)+1160>>2]=X;c[U+(M*3148|0)+2184>>2]=X;X=Y+1792|0;c[U+(M*3148|0)+140>>2]=X;c[U+(M*3148|0)+1164>>2]=X;c[U+(M*3148|0)+2188>>2]=X;X=c[2386282]|0;c[U+(M*3148|0)+176>>2]=X;c[U+(M*3148|0)+1200>>2]=X;c[U+(M*3148|0)+2224>>2]=X;Y=X+256|0;c[U+(M*3148|0)+180>>2]=Y;c[U+(M*3148|0)+1204>>2]=Y;c[U+(M*3148|0)+2228>>2]=Y;Y=X+512|0;c[U+(M*3148|0)+184>>2]=Y;c[U+(M*3148|0)+1208>>2]=Y;c[U+(M*3148|0)+2232>>2]=Y;Y=X+768|0;c[U+(M*3148|0)+188>>2]=Y;c[U+(M*3148|0)+1212>>2]=Y;c[U+(M*3148|0)+2236>>2]=Y;Y=X+1024|0;c[U+(M*3148|0)+192>>2]=Y;c[U+(M*3148|0)+1216>>2]=Y;c[U+(M*3148|0)+2240>>2]=Y;Y=X+1280|0;c[U+(M*3148|0)+196>>2]=Y;c[U+(M*3148|0)+1220>>2]=Y;c[U+(M*3148|0)+2244>>2]=Y;Y=X+1536|0;c[U+(M*3148|0)+200>>2]=Y;c[U+(M*3148|0)+1224>>2]=Y;c[U+(M*3148|0)+2248>>2]=Y;Y=X+1792|0;c[U+(M*3148|0)+204>>2]=Y;c[U+(M*3148|0)+1228>>2]=Y;c[U+(M*3148|0)+2252>>2]=Y;Y=c[2386382]|0;c[U+(M*3148|0)+208>>2]=Y;c[U+(M*3148|0)+1232>>2]=Y;c[U+(M*3148|0)+2256>>2]=Y;X=Y+256|0;c[U+(M*3148|0)+212>>2]=X;c[U+(M*3148|0)+1236>>2]=X;c[U+(M*3148|0)+2260>>2]=X;X=Y+512|0;c[U+(M*3148|0)+216>>2]=X;c[U+(M*3148|0)+1240>>2]=X;c[U+(M*3148|0)+2264>>2]=X;X=Y+768|0;c[U+(M*3148|0)+220>>2]=X;c[U+(M*3148|0)+1244>>2]=X;c[U+(M*3148|0)+2268>>2]=X;X=Y+1024|0;c[U+(M*3148|0)+224>>2]=X;c[U+(M*3148|0)+1248>>2]=X;c[U+(M*3148|0)+2272>>2]=X;X=Y+1280|0;c[U+(M*3148|0)+228>>2]=X;c[U+(M*3148|0)+1252>>2]=X;c[U+(M*3148|0)+2276>>2]=X;X=Y+1536|0;c[U+(M*3148|0)+232>>2]=X;c[U+(M*3148|0)+1256>>2]=X;c[U+(M*3148|0)+2280>>2]=X;X=Y+1792|0;c[U+(M*3148|0)+236>>2]=X;c[U+(M*3148|0)+1260>>2]=X;c[U+(M*3148|0)+2284>>2]=X;X=Q+4096|0;c[U+(M*3148|0)+240>>2]=X;c[U+(M*3148|0)+1264>>2]=X;c[U+(M*3148|0)+2288>>2]=X;X=Q+4352|0;c[U+(M*3148|0)+244>>2]=X;c[U+(M*3148|0)+1268>>2]=X;c[U+(M*3148|0)+2292>>2]=X;X=Q+4608|0;c[U+(M*3148|0)+248>>2]=X;c[U+(M*3148|0)+1272>>2]=X;c[U+(M*3148|0)+2296>>2]=X;X=Q+4864|0;c[U+(M*3148|0)+252>>2]=X;c[U+(M*3148|0)+1276>>2]=X;c[U+(M*3148|0)+2300>>2]=X;X=Q+5120|0;c[U+(M*3148|0)+256>>2]=X;c[U+(M*3148|0)+1280>>2]=X;c[U+(M*3148|0)+2304>>2]=X;X=Q+5376|0;c[U+(M*3148|0)+260>>2]=X;c[U+(M*3148|0)+1284>>2]=X;c[U+(M*3148|0)+2308>>2]=X;X=Q+5632|0;c[U+(M*3148|0)+264>>2]=X;c[U+(M*3148|0)+1288>>2]=X;c[U+(M*3148|0)+2312>>2]=X;X=Q+5888|0;c[U+(M*3148|0)+268>>2]=X;c[U+(M*3148|0)+1292>>2]=X;c[U+(M*3148|0)+2316>>2]=X;X=c[2387082]|0;c[U+(M*3148|0)+272>>2]=X;c[U+(M*3148|0)+1296>>2]=X;c[U+(M*3148|0)+2320>>2]=X;Y=X+256|0;c[U+(M*3148|0)+276>>2]=Y;c[U+(M*3148|0)+1300>>2]=Y;c[U+(M*3148|0)+2324>>2]=Y;Y=X+512|0;c[U+(M*3148|0)+280>>2]=Y;c[U+(M*3148|0)+1304>>2]=Y;c[U+(M*3148|0)+2328>>2]=Y;Y=X+768|0;c[U+(M*3148|0)+284>>2]=Y;c[U+(M*3148|0)+1308>>2]=Y;c[U+(M*3148|0)+2332>>2]=Y;Y=X+1024|0;c[U+(M*3148|0)+288>>2]=Y;c[U+(M*3148|0)+1312>>2]=Y;c[U+(M*3148|0)+2336>>2]=Y;Y=X+1280|0;c[U+(M*3148|0)+292>>2]=Y;c[U+(M*3148|0)+1316>>2]=Y;c[U+(M*3148|0)+2340>>2]=Y;Y=X+1536|0;c[U+(M*3148|0)+296>>2]=Y;c[U+(M*3148|0)+1320>>2]=Y;c[U+(M*3148|0)+2344>>2]=Y;Y=X+1792|0;c[U+(M*3148|0)+300>>2]=Y;c[U+(M*3148|0)+1324>>2]=Y;c[U+(M*3148|0)+2348>>2]=Y;Y=c[2386358]|0;X=64;R=64;while(1){P=Y+(R<<8)|0;c[U+(M*3148|0)+48+(R<<2)>>2]=P;c[U+(M*3148|0)+48+(R+256<<2)>>2]=P;c[U+(M*3148|0)+48+(R+512<<2)>>2]=P;P=X+1&65535;if((P&65535)>255){break}else{X=P;R=P&65535}}c[U+(M*3148|0)+3124>>2]=1076;c[U+(M*3148|0)+3120>>2]=1812;R=U+(M*3148|0)|0;if((R|0)!=0){X=R;gGC(X|0,9660752,48)|0}c[T>>2]=S;c[3528554]=-1;fvI();c[3528556]=0;X=c[2433594]|0;c[2443776]=X;R=(X|0)==0;L38645:do{if(!R){Y=X|0;gGC(9660952,Y|0,52)|0;switch(a[9660952]|0){case 3:{c[2309668]=639984;break L38645;break};case 4:{c[2309668]=7356016;break L38645;break};case 5:{c[2309668]=7354992;break L38645;break};case 1:{c[2309668]=634096;break L38645;break};case 0:{c[2309668]=638960;break L38645;break};case 2:{c[2309668]=638960;break L38645;break};default:{break L38645}}}}while(0);S=c[2432850]|0;c[2113164]=S;T=c[3527438]|0;c[X+68>>2]=T;c[X+1092>>2]=T;c[X+2116>>2]=T;M=T+256|0;c[X+72>>2]=M;c[X+1096>>2]=M;c[X+2120>>2]=M;M=T+512|0;c[X+76>>2]=M;c[X+1100>>2]=M;c[X+2124>>2]=M;M=T+768|0;c[X+80>>2]=M;c[X+1104>>2]=M;c[X+2128>>2]=M;M=T+1024|0;c[X+84>>2]=M;c[X+1108>>2]=M;c[X+2132>>2]=M;M=T+1280|0;c[X+88>>2]=M;c[X+1112>>2]=M;c[X+2136>>2]=M;M=T+1536|0;c[X+92>>2]=M;c[X+1116>>2]=M;c[X+2140>>2]=M;M=T+1792|0;c[X+96>>2]=M;c[X+1120>>2]=M;c[X+2144>>2]=M;M=c[3527436]|0;T=64;U=64;while(1){Y=M+(U<<8)|0;c[X+68+(U<<2)>>2]=Y;c[X+68+(U+512<<2)>>2]=Y;Y=T+1&65535;if((Y&65535)>127){_=128;$=128;break}else{T=Y;U=Y&65535}}while(1){U=M+($<<8)|0;c[X+68+($<<2)>>2]=U;c[X+68+($+512<<2)>>2]=U;U=_+1&65535;if((U&65535)>255){break}else{_=U;$=U&65535}}c[X+3148>>2]=2932;c[X+3152>>2]=486;if(!R){M=X|0;gGC(M|0,9660952,52)|0}c[2432850]=S;c[2443776]=0;c[3528556]=-1;c[2424]=5800;U6(3e6,1494,2124,0);c[2438222]=15e5;c[2433520]=2448;c[2406670]=2016;c[3528466]=6844;c[2443840]=1364;h[745399]=.7;a[3203272]=1;Vr(1,15e5,0,164,84,1);c[2438228]=15e5;c[2433526]=3068;c[2406676]=206;c[3528472]=4026;c[2443846]=1364;h[745419]=.2;a[3203368]=1;h[745418]=.23;a[3203360]=1;h[745417]=.23;a[3203352]=1;h[745416]=.23;a[3203344]=1;UB(0,2800,384e3,1800,5);c[2415126]=9662152;h[1207773]=.88;c[2415548]=3;M=c[642608+(c[2436]<<2)>>2]|0;U=c[M+128>>2]|0;if((c[M+52>>2]&4|0)==0){c[2113068]=U;T=c[M+132>>2]|0;c[2113070]=T;c[2443814]=U;c[2440436]=T;aa=U;ab=T}else{c[2113070]=U;T=c[M+132>>2]|0;c[2113068]=T;c[2440436]=U;c[2443814]=T;aa=T;ab=U}U=ag(aa<<1,ab)|0;T=gGq(U)|0;c[2112926]=T;if((T|0)!=0){gGz(T|0,0,U|0)}aHy();N=0;i=b;return N|0}}while(0);c[2414854]=0;N=1;i=b;return N|0}function aHs(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c[2415126]=9662152;b=c[2408988]|0;if((b|0)!=0){gGz(9662152,0,3224);d=b;b=0;while(1){if((b|0)>=1024){break}e=9638528+(b<<2)|0;if((c[e>>2]|0)==(d|0)){f=30134;break}else{b=b+1|0}}if((f|0)==30134){gGr(d);c[e>>2]=0}c[2408988]=0}c[2415126]=9665376;e=c[2408989]|0;if((e|0)!=0){gGz(9665376,0,3224);d=e;e=0;while(1){if((e|0)>=1024){break}g=9638528+(e<<2)|0;if((c[g>>2]|0)==(d|0)){f=30140;break}else{e=e+1|0}}if((f|0)==30140){gGr(d);c[g>>2]=0}c[2408989]=0}c[3527068]=0;c[2411222]=0;c[2113160]=0;g=c[2433592]|0;if((g|0)!=0){gGr(g);c[2433592]=0}g=a[7452592]|0;if(g){d=0;e=g&1;while(1){g=14163944+(d<<2)|0;b=c[g>>2]|0;h=c[2113006]|0;if((h|0)==0){f=30148}else{i=h-1|0;c[2113006]=i;if((i|0)==0){f=30148}}if((f|0)==30148){f=0;c[2383474]=0}if((b|0)==0){j=e}else{gGr(b);j=a[7452592]&1}c[g>>2]=0;g=d+1|0;if((g|0)<(j|0)){d=g;e=j}else{break}}}a[7452592]=0;c[2438222]=0;c[2433520]=0;c[2406670]=0;c[3528466]=0;j=c[2406686]|0;if((j|0)!=0){gGr(j);c[2406686]=0}c[2432974]=0;a[632376]=0;c[2113070]=0;c[2113068]=0;j=c[2112926]|0;if((j|0)!=0){gGr(j);c[2112926]=0}fvR();j=c[3541518]|0;if((j|0)!=0){gGr(j|0);c[3541518]=0}if((c[2385508]|0)>0){c[2113008]=0;c[2076598]=0;c[2383582]=0}c[2438228]=0;c[2433526]=0;c[2406676]=0;c[3528472]=0;j=c[2406680]|0;if((j|0)!=0){gGr(j);c[2406680]=0}c[2385508]=0;c[2432978]=0;a[64240]=0;j=c[2414854]|0;e=0;while(1){if((e|0)>=1024){f=30167;break}k=9638528+(e<<2)|0;if((c[k>>2]|0)==(j|0)){break}else{e=e+1|0}}if((f|0)==30167){c[2414854]=0;return 0}gGr(j);c[k>>2]=0;c[2414854]=0;return 0}function aHt(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0.0,k=0,l=0,m=0,n=0;if((a[9623400]|0)!=0){aHy()}b=c[2113160]|0;if((b|0)>0){gGz(9731360,0,((b|0)>1?b<<2:4)|0)}c[2113158]=0;b=c[2113166]|0;if((b|0)>0){gGz(9731400,0,((b|0)>1?b<<2:4)|0)}c[2113164]=0;gGz(9550152,-1|0,5);b=0;d=-1;e=-1;f=-1;g=-1;h=-1;do{d=((a[9632392+b|0]&1)<<b^d&255)&255;e=((a[9630304+b|0]&1)<<b^e&255)&255;f=((a[9629184+b|0]&1)<<b^f&255)&255;g=((a[9629136+b|0]&1)<<b^g&255)&255;h=((a[9628864+b|0]&1)<<b^h&255)&255;b=b+1|0;}while((b|0)<8);a[9550152]=d;a[9550153]=e;a[9550154]=f;a[9550155]=g;a[9550156]=h;c[2415126]=9662152;h=c[2415557]|0;g=h&3;if((g|0)==3){i=133}else{i=(15e5/(15e5/((c[2415554]|0)/(c[600992+((h>>>3&1)<<4)+(g<<2)>>2]|0)|0|0)|0|0)|0|0)/((c[2424]|0)/100|0|0)|0}c[3528556]=0;g=c[2433594]|0;c[2443776]=g;L38746:do{if((g|0)!=0){h=g|0;gGC(9660952,h|0,52)|0;switch(a[9660952]|0){case 1:{c[2309668]=634096;break L38746;break};case 3:{c[2309668]=639984;break L38746;break};case 5:{c[2309668]=7354992;break L38746;break};case 4:{c[2309668]=7356016;break L38746;break};case 0:{c[2309668]=638960;break L38746;break};case 2:{c[2309668]=638960;break L38746;break};default:{break L38746}}}}while(0);c[2113164]=c[2432850];c[2408976]=128;j=+(i|0);g=~~(j*.03);h=~~(j*.97);if((i|0)>0){f=0;e=0;while(1){if((e|0)==(g|0)){c[2408976]=128}c[3528554]=0;f43(c[2433592]|0);c[2113158]=c[9731360+(c[3528554]<<2)>>2];d=25862/(i|0)|0;b=ag(d,e)|0;Sb(b);k=c[3528554]|0;l=c[2433592]|0;m=l+(k*3148|0)|0;if((m|0)!=0){n=m;gGC(n|0,9660752,48)|0}c[9731360+(k<<2)>>2]=c[2113158];c[3528554]=1;f43(l+3148|0);c[2113158]=c[9731360+(c[3528554]<<2)>>2];l=e+1|0;k=f45((ag(d,l)|0)-f|0)|0;c[2113158]=(c[2113158]|0)+k;d=k+f|0;if((e|0)==(h|0)){c[2408976]=0;f44(32);f45(0)|0;if((a[9660797]|0)!=0){a[9660797]=0}f45(0)|0}UD();k=c[3528554]|0;n=(c[2433592]|0)+(k*3148|0)|0;if((n|0)!=0){m=n;gGC(m|0,9660752,48)|0}c[9731360+(k<<2)>>2]=c[2113158];c[3528554]=-1;U1(b);if((l|0)<(i|0)){f=d;e=l}else{break}}}c[3528554]=0;f43(c[2433592]|0);c[2113158]=c[9731360+(c[3528554]<<2)>>2];e=c[2438228]|0;f=gGS(-160694272,12331,e,(e|0)<0|0?-1:0)|0;e=f;Sb(25862);f=c[2443830]|0;if((f|0)<1073676288){c[2443830]=f-e}f=c[2443831]|0;if((f|0)<1073676288){c[2443831]=f-e}f=(c[3528512]|0)-e|0;c[3528512]=(f|0)<0?0:f;f=c[2438222]|0;e=gGS(-160694272,12331,f,(f|0)<0|0?-1:0)|0;f=e;U1(25862);e=c[2443824]|0;if((e|0)<1073676288){c[2443824]=e-f}e=c[2443825]|0;if((e|0)<1073676288){c[2443825]=e-f}e=(c[3528506]|0)-f|0;c[3528506]=(e|0)<0?0:e;e=c[2112964]|0;if((e|0)!=0){gg[c[3542114]&4095](e,a[9688]|0?534:0);gg[c[3542122]&4095](c[2112964]|0,a[9688]|0?534:0);Uz(0,c[2112964]|0,a[9688]|0?534:0)}e=c[2443776]|0;if((e|0)!=0){f=e|0;gGC(f|0,9660952,52)|0}c[9731400+(c[3528556]<<2)>>2]=c[2113164];c[2443776]=0;c[3528556]=-1;f=c[3528554]|0;e=(c[2433592]|0)+(f*3148|0)|0;if((e|0)!=0){i=e;gGC(i|0,9660752,48)|0}c[9731360+(f<<2)>>2]=c[2113158];c[3528554]=-1;if((c[2112968]|0)==0){return 0}f=c[(c[642608+(c[2436]<<2)>>2]|0)+112>>2]|0;if((f|0)==0){return 0}gD[f&8191]()|0;return 0}function aHu(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;e=i;i=i+128|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;l=e+80|0;m=e+96|0;n=e+112|0;if((b&64|0)==0){aHx(b,d);i=e;return 0}o=k|0;if((c[2113160]|0)>0){p=k+7|0;k=j|0;q=j+4|0;r=j+12|0;s=h;t=h|0;u=h+4|0;v=h+12|0;w=g;x=g|0;y=g+4|0;z=g+12|0;A=f;B=f|0;C=f+4|0;D=f+12|0;E=0;do{F=c[2433592]|0;G=F+(E*3148|0)+40|0;H=c[G>>2]|0;gGC(o|0,614752,9)|0;a[p]=E+48&255;c[k>>2]=F+(E*3148|0);c[q>>2]=48;c[r>>2]=o;gj[c[2076592]&4095](j)|0;gGz(s|0,0,12);c[t>>2]=F+(E*3148|0)+3136;c[u>>2]=4;c[v>>2]=165288;gj[c[2076592]&4095](h)|0;gGz(w|0,0,12);c[x>>2]=F+(E*3148|0)+3140;c[y>>2]=4;c[z>>2]=501592;gj[c[2076592]&4095](g)|0;gGz(A|0,0,12);c[B>>2]=F+(E*3148|0)+3144;c[C>>2]=4;c[D>>2]=386080;gj[c[2076592]&4095](f)|0;c[G>>2]=H;E=E+1|0;}while((E|0)<(c[2113160]|0))}Vb(b,d);UE(b,d);gGz(n|0,0,12);c[n>>2]=14108272;c[n+4>>2]=4;c[n+12>>2]=175736;gj[c[2076592]&4095](n)|0;gGz(m|0,0,12);c[m>>2]=9644888;c[m+4>>2]=4;c[m+12>>2]=171992;gj[c[2076592]&4095](m)|0;gGz(l|0,0,12);c[l>>2]=14115768;c[l+4>>2]=4;c[l+12>>2]=168656;gj[c[2076592]&4095](l)|0;if((b&2|0)==0){aHx(b,d);i=e;return 0}c[3528554]=0;f43(c[2433592]|0);l=c[3528554]|0;m=9731360+(l<<2)|0;n=c[m>>2]|0;c[2113158]=n;E=c[3530266]|0;f=c[2433592]|0;D=(c[2406854]|0)+49152|0;C=64;B=64;while(1){A=E+(D+(B<<8))|0;c[f+(l*3148|0)+48+(B<<2)>>2]=A;c[f+(l*3148|0)+48+(B+512<<2)>>2]=A;A=C+1&65535;if((A&65535)>127){break}else{C=A;B=A&65535}}B=f+(l*3148|0)|0;if((B|0)!=0){l=B;gGC(l|0,9660752,48)|0}c[m>>2]=n;c[3528554]=-1;c[3528556]=0;n=c[2433594]|0;c[2443776]=n;L38821:do{if((n|0)!=0){m=n|0;gGC(9660952,m|0,52)|0;switch(a[9660952]|0){case 5:{c[2309668]=7354992;break L38821;break};case 2:{c[2309668]=638960;break L38821;break};case 3:{c[2309668]=639984;break L38821;break};case 0:{c[2309668]=638960;break L38821;break};case 4:{c[2309668]=7356016;break L38821;break};case 1:{c[2309668]=634096;break L38821;break};default:{break L38821}}}}while(0);m=c[2432850]|0;c[2113164]=m;l=c[3527436]|0;B=(c[3528942]<<14)+49152|0;f=64;C=64;while(1){D=l+(B+(C<<8))|0;c[n+68+(C<<2)>>2]=D;c[n+68+(C+512<<2)>>2]=D;D=f+1&65535;if((D&65535)>127){break}else{f=D;C=D&65535}}C=n|0;gGC(C|0,9660952,52)|0;c[2432850]=m;c[2443776]=0;c[3528556]=-1;aHx(b,d);i=e;return 0}function aHv(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2989748+(b*112|0)>>2];c[a+104>>2]=c[2989752+(b*112|0)>>2];c[a+108>>2]=c[2989756+(b*112|0)>>2];d=0;return d|0}function aHw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=2989648+(b*112|0);e=0;return e|0}function aHx(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;e=i;i=i+160|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;l=e+80|0;m=e+96|0;n=e+112|0;o=e+128|0;p=e+144|0;if((d|0)!=0){c[d>>2]=169762}if((b&32|0)!=0){gGz(p|0,0,12);q=c[2414556]|0;c[p>>2]=q;c[p+4>>2]=(c[2411456]|0)-q;c[p+12>>2]=162152;q=c[2076592]|0;gj[q&4095](p)|0}if((b&64|0)==0){i=e;return}p=k|0;if((c[2113166]|0)>0){q=k+7|0;k=j|0;r=j+4|0;s=j+12|0;t=h;u=h|0;v=h+4|0;w=h+12|0;x=g;y=g|0;z=g+4|0;A=g+12|0;B=f;C=f|0;D=f+4|0;E=f+12|0;F=0;do{G=c[9734376+(F<<2)>>2]|0;H=G+36|0;I=c[H>>2]|0;gGC(p|0,614768,9)|0;a[q]=F+48&255;c[k>>2]=G;c[r>>2]=52;c[s>>2]=p;gj[c[2076592]&4095](j)|0;gGz(t|0,0,12);c[u>>2]=G+3172;c[v>>2]=4;c[w>>2]=165288;gj[c[2076592]&4095](h)|0;gGz(x|0,0,12);c[y>>2]=G+3176;c[z>>2]=4;c[A>>2]=501592;gj[c[2076592]&4095](g)|0;gGz(B|0,0,12);c[C>>2]=G+3180;c[D>>2]=4;c[E>>2]=386080;gj[c[2076592]&4095](f)|0;c[H>>2]=I;F=F+1|0;}while((F|0)<(c[2113166]|0))}Vx(b,d);gGz(o|0,0,12);c[o>>2]=9762424;c[o+4>>2]=4;c[o+12>>2]=69208;gj[c[2076592]&4095](o)|0;gGz(n|0,0,12);c[n>>2]=9776760;c[n+4>>2]=4;c[n+12>>2]=158728;gj[c[2076592]&4095](n)|0;gGz(m|0,0,12);c[m>>2]=9635904;c[m+4>>2]=4;c[m+12>>2]=509304;gj[c[2076592]&4095](m)|0;gGz(l|0,0,12);c[l>>2]=9627416;c[l+4>>2]=4;c[l+12>>2]=151872;gj[c[2076592]&4095](l)|0;i=e;return}function aHy(){var e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;a[9623400]=0;e=c[2414556]|0;gGz(e|0,0,(c[2411456]|0)-e|0);c[3528554]=0;f43(c[2433592]|0);e=c[3528554]|0;c[2113158]=c[9731360+(e<<2)>>2];a[9660796]=0;a[9660797]=0;a[9660786]=0;a[9660787]=0;c[2415191]=0;a[9660784]=a[9660784]|80;f=c[2433592]|0;g=c[f+(e*3148|0)+1068>>2]|0;do{if((g|0)==0){i=c[f+(e*3148|0)+3120>>2]|0;if((i|0)==0){j=0;k=0;l=e;m=f;break}n=gj[i&4095](-2)|0;i=c[3528554]|0;o=c[2433592]|0;p=c[o+(i*3148|0)+1068>>2]|0;q=(n&255)<<8;if((p|0)!=0){r=p;s=q;t=i;u=o;v=30272;break}p=c[o+(i*3148|0)+3120>>2]|0;if((p|0)==0){j=0;k=q;l=i;m=o;break}o=gj[p&4095](-1)|0;j=o;k=q;l=c[3528554]|0;m=c[2433592]|0}else{r=g;s=d[g+254|0]<<8;t=e;u=f;v=30272}}while(0);if((v|0)==30272){j=a[r+255|0]|0;k=s;l=t;m=u}u=j&255|k;c[2415188]=u;b[4830376]=u&65535;u=m+(l*3148|0)|0;if((u|0)!=0){k=u;gGC(k|0,9660752,48)|0}c[9731360+(l<<2)>>2]=c[2113158];c[3528554]=1;f43(m+3148|0);m=c[3528554]|0;c[2113158]=c[9731360+(m<<2)>>2];a[9660796]=0;a[9660797]=0;a[9660786]=0;a[9660787]=0;c[2415191]=0;a[9660784]=a[9660784]|80;l=c[2433592]|0;k=c[l+(m*3148|0)+1068>>2]|0;do{if((k|0)==0){u=c[l+(m*3148|0)+3120>>2]|0;if((u|0)==0){w=0;x=0;y=m;z=l;break}j=gj[u&4095](-2)|0;u=c[3528554]|0;t=c[2433592]|0;s=c[t+(u*3148|0)+1068>>2]|0;r=(j&255)<<8;if((s|0)!=0){A=s;B=r;C=u;D=t;v=30281;break}s=c[t+(u*3148|0)+3120>>2]|0;if((s|0)==0){w=0;x=r;y=u;z=t;break}t=gj[s&4095](-1)|0;w=t;x=r;y=c[3528554]|0;z=c[2433592]|0}else{A=k;B=d[k+254|0]<<8;C=m;D=l;v=30281}}while(0);if((v|0)==30281){w=a[A+255|0]|0;x=B;y=C;z=D}D=w&255|x;c[2415188]=D;b[4830376]=D&65535;D=z+(y*3148|0)|0;if((D|0)!=0){z=D;gGC(z|0,9660752,48)|0}c[9731360+(y<<2)>>2]=c[2113158];c[3528554]=-1;c[3528556]=0;y=c[2433594]|0;c[2443776]=y;L38889:do{if((y|0)!=0){z=y|0;gGC(9660952,z|0,52)|0;switch(a[9660952]|0){case 1:{c[2309668]=634096;break L38889;break};case 5:{c[2309668]=7354992;break L38889;break};case 3:{c[2309668]=639984;break L38889;break};case 2:{c[2309668]=638960;break L38889;break};case 4:{c[2309668]=7356016;break L38889;break};case 0:{c[2309668]=638960;break L38889;break};default:{break L38889}}}}while(0);c[2113164]=c[2432850];gu[c[y+56>>2]&16383]();y=c[2443776]|0;if((y|0)!=0){z=y|0;gGC(z|0,9660952,52)|0}c[9731400+(c[3528556]<<2)>>2]=c[2113164];c[2443776]=0;c[3528556]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){E=0}else{c[2443825]=1073676288;c[2443824]=1073676288;c[2443817]=1073676288;c[2443816]=1073676288;h[883199]=0.0;c[3528506]=0;F=c[3540986]|0;lw(F);c[2440606]=0;c[2444190]=0;c[3528196]=0;UA();return}do{lN(E);mB(E);E=E+1|0;}while((E|0)<(c[2385508]|0));c[2443825]=1073676288;c[2443824]=1073676288;c[2443817]=1073676288;c[2443816]=1073676288;h[883199]=0.0;c[3528506]=0;F=c[3540986]|0;lw(F);c[2440606]=0;c[2444190]=0;c[3528196]=0;UA();return}function aHz(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=0;while(1){if((b|0)>=1024){e=30349;break}f=9638528+(b<<2)|0;if((c[f>>2]|0)==0){break}else{b=b+1|0}}if((e|0)==30349){return}b=gGq(524288)|0;c[f>>2]=b;if((b|0)==0){return}gGz(b|0,0,524288);f=c[3530752]|0;gGC(b|0,f|0,32768)|0;g=0;do{h=g<<6;gGz(f+h|0,0,64);i=h+196608|0;j=0;do{k=i+(c[609008+(j<<2)>>2]|0)|0;l=(j<<3)+h|0;m=0;do{n=k+(c[614800+(m<<2)>>2]|0)|0;if(((d[b+((n|0)/8|0)|0]|0)&128>>>((n&7)>>>0)|0)!=0){n=f+(l+m)|0;a[n]=a[n]|4}m=m+1|0;}while((m|0)<8);j=j+1|0;}while((j|0)<8);j=h+131072|0;i=0;do{m=j+(c[609008+(i<<2)>>2]|0)|0;l=(i<<3)+h|0;k=0;do{n=m+(c[614800+(k<<2)>>2]|0)|0;if(((d[b+((n|0)/8|0)|0]|0)&128>>>((n&7)>>>0)|0)!=0){n=f+(l+k)|0;a[n]=a[n]|2}k=k+1|0;}while((k|0)<8);i=i+1|0;}while((i|0)<8);i=h+65536|0;j=0;do{k=i+(c[609008+(j<<2)>>2]|0)|0;l=(j<<3)+h|0;m=0;do{n=k+(c[614800+(m<<2)>>2]|0)|0;if(((d[b+((n|0)/8|0)|0]|0)&128>>>((n&7)>>>0)|0)!=0){n=f+(l+m)|0;a[n]=a[n]|1}m=m+1|0;}while((m|0)<8);j=j+1|0;}while((j|0)<8);g=g+1|0;}while((g|0)<1024);g=c[3530516]|0;gGC(b|0,g|0,524288)|0;f=0;do{j=f<<8;gGz(g+j|0,0,256);h=0;do{i=1<<3-h;m=(c[704200+(h<<2)>>2]|0)+j|0;l=0;do{k=m+(c[609008+(l<<2)>>2]|0)|0;n=(l<<4)+j|0;o=0;do{p=k+(c[612640+(o<<2)>>2]|0)|0;if(((d[b+((p|0)/8|0)|0]|0)&128>>>((p&7)>>>0)|0)!=0){p=g+(n+o)|0;a[p]=(d[p]|0|i)&255}o=o+1|0;}while((o|0)<16);l=l+1|0;}while((l|0)<16);h=h+1|0;}while((h|0)<4);f=f+1|0;}while((f|0)<4096);f=c[3530384]|0;gGC(b|0,f|0,524288)|0;g=0;while(1){h=g<<8;gGz(f+h|0,0,256);j=0;do{l=1<<3-j;i=(c[704200+(j<<2)>>2]|0)+h|0;m=0;do{o=i+(c[609008+(m<<2)>>2]|0)|0;n=(m<<4)+h|0;k=0;do{p=o+(c[612640+(k<<2)>>2]|0)|0;if(((d[b+((p|0)/8|0)|0]|0)&128>>>((p&7)>>>0)|0)!=0){p=f+(n+k)|0;a[p]=(d[p]|0|l)&255}k=k+1|0;}while((k|0)<16);m=m+1|0;}while((m|0)<16);j=j+1|0;}while((j|0)<4);j=g+1|0;if((j|0)<4096){g=j}else{q=0;break}}while(1){if((q|0)>=1024){e=30351;break}r=9638528+(q<<2)|0;if((c[r>>2]|0)==(b|0)){break}else{q=q+1|0}}if((e|0)==30351){return}gGr(b);c[r>>2]=0;return}function aHA(a,b){a=a|0;b=b|0;a=c[(c[2443776]|0)+64>>2]|0;if((b|0)==0){gg[a&4095](0,0);return}else{gg[a&4095](0,1);return}}function aHB(a){a=a|0;var b=0,d=0;b=c[2113164]|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,15e5,0)|0;return a|0}function aHC(a){a=a|0;var b=0,d=0;b=c[2113158]|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,15e5,0)|0;return a|0}function aHD(){return+(+(c[2113158]|0)/15.0e5)}function aHE(a){a=a|0;var b=0.0;b=+(a|0)*+(c[2113158]|0)/15.0e5;+V(b)>=1.0?b>0.0?(al(+U(b/4294967296.0),4294967295.0)|0)>>>0:~~+af((b- +(~~b>>>0))/4294967296.0)>>>0:0;return~~b>>>0|0}function aHF(){var a=0,b=0,d=0,e=0;a=c[2411222]|0;c[2411222]=a^1;if((a|0)!=1){gg[c[(c[2443776]|0)+64>>2]&4095](0,1);a=c[(c[2443776]|0)+52>>2]|0;gj[a&4095](0)|0;gg[c[(c[2443776]|0)+64>>2]&4095](0,0);a=c[(c[2443776]|0)+52>>2]|0;gj[a&4095](0)|0}a=c[3527068]|0;b=a>>4;c[2415126]=9662152;if((c[2415542]|0)==4){d=b&15;c[2415538]=d;e=a<<4;c[3527068]=e;return}else{d=b<<1&14;c[2415538]=d;e=a<<4;c[3527068]=e;return}}function aHG(e,f){e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;g=c[3529872]|0;h=((d[g+18|0]|0)<<8|(d[g+19|0]|0))+8&511;i=(d[g+16|0]|0)<<8&256|(d[g+17|0]|0);g=(e|0)!=0;e=c[2113068]|0;j=c[2113070]|0;k=c[2387082]|0;l=c[3530384]|0;m=c[2112926]|0;n=0;do{o=n<<4;p=(o&496)-i|0;q=(p|0)<-15?p+512|0:p;p=(n>>5<<4)-h|0;r=(p|0)<-15?p+512|0:p;L39005:do{if((q|0)<(e|0)&(r|0)<(j|0)){p=(n>>>1&240|n&527|o&256)<<1;s=a[k+p|0]|0;t=s&255;if(g&s<<24>>24>-1){break}s=t&240;u=r;v=l+((d[k+(p|1)|0]|0|t<<8&3840)<<8)|0;t=1;while(1){if((u|0)>-1&(u|0)<(j|0)){p=ag(e,u)|0;w=q;x=0;while(1){y=d[v+x|0]|0;do{if((1<<y&f|0)==0){if((w|0)>=(e|0)|(w|0)<0){break}b[m+(w+p<<1)>>1]=(s|y|768)&65535}}while(0);y=x+1|0;if((y|0)<16){w=w+1|0;x=y}else{break}}}if((t|0)>=16){break L39005}u=u+1|0;v=v+16|0;t=t+1|0}}}while(0);n=n+1|0;}while((n|0)<1024);return}function aHH(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;e=c[2386556]|0;f=c[3528652]|0;g=c[2112926]|0;h=c[3530516]|0;i=0;do{j=d[e+i|0]<<8;k=j|d[e+(i|1)|0];do{if((j&32768|0)!=0){l=d[e+(i|3)|0]|0;if((l&1|0)==0){break}m=d[e+(i|5)|0]|0;n=d[e+(i|4)|0]<<8;o=l&16;p=l&2;q=d[e+(i|6)|0]|0;r=q>>>4;s=q<<8&3840|d[e+(i|7)|0];if((b|0)==1){if((r&8|0)!=0){break}}else if((b|0)==2){if((r&8|0)==0){break}}q=(o|0)!=0;if(q){t=s&4094;u=k+16|0}else{t=s;u=k}s=256-((n|m)+16&511)|0;m=256-(u+16&511)|0;n=l&4;if((a[f]|0)==0){v=p;w=m;x=s;y=n}else{l=240-m|0;v=p>>>1^1;w=q?l-16|0:l;x=240-s|0;y=n>>>2^1}n=(v|0)==0|q^1;s=t+1|0;l=n?s:t;p=w-8|0;m=(v|0)!=0;o=(y|0)!=0;z=(n?t:s)&4095;do{if(m){if(o){SN(g,z,x,p,r,4,0,256,h);break}else{SL(g,z,x,p,r,4,0,256,h);break}}else{if(o){SJ(g,z,x,p,r,4,0,256,h);break}else{SH(g,z,x,p,r,4,0,256,h);break}}}while(0);if(!q){break}p=l&4095;z=w+8|0;if(m){if(o){SN(g,p,x,z,r,4,0,256,h);break}else{SL(g,p,x,z,r,4,0,256,h);break}}else{if(o){SJ(g,p,x,z,r,4,0,256,h);break}else{SH(g,p,x,z,r,4,0,256,h);break}}}}while(0);i=i+8|0;}while((i|0)<2048);return}function aHI(a){a=a|0;var b=0,d=0;b=c[2113158]|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,2e6,0)|0;return a|0}function aHJ(){return+(+(c[2113158]|0)/2.0e6)}function aHK(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;m=i;i=i+1024|0;n=m|0;o=((d[f+18|0]|0)<<8|(d[f+19|0]|0))+8&511;p=(d[f+16|0]|0)<<8&256|(d[f+17|0]|0);q=(a[f]&4)!=0;if(!(q|(l|0)>1)){f=c[2112926]|0;r=c[2113068]|0;s=c[2113070]|0;if((l|0)==0){t=0;do{u=(t<<4&496)-p|0;v=(t>>5<<4)-o|0;w=(u|0)<-15?u+512|0:u;u=(v|0)<-15?v+512|0:v;if((w|0)<(r|0)&(u|0)<(s|0)){v=(t>>>1&496|t&15|t<<5&512)<<1;x=d[e+v|0]|0;Sz(f,(x<<8|(d[e+(v|1)|0]|0))&k,w,u,x>>>4&j,4,h,g)}t=t+1|0;}while((t|0)<1024);i=m;return}else{t=0;do{x=(t<<4&496)-p|0;u=(t>>5<<4)-o|0;w=(x|0)<-15?x+512|0:x;x=(u|0)<-15?u+512|0:u;if((w|0)<(r|0)&(x|0)<(s|0)){u=(t>>>1&496|t&15|t<<5&512)<<1;v=d[e+u|0]|0;SH(f,(v<<8|(d[e+(u|1)|0]|0))&k,w,x,v>>>4&j,4,0,h,g)}t=t+1|0;}while((t|0)<1024);i=m;return}}t=c[2386744]|0;f=0;do{s=f<<1;c[n+(f<<2)>>2]=(d[t+s|0]|0)<<8&256|(d[t+(s|1)|0]|0);f=f+1|0;}while((f|0)<256);f=j<<4;j=(l|0)==0;t=c[2113070]|0;s=c[2113068]|0;r=c[2112926]|0;v=0;do{x=(v>>5<<4)-o|0;w=(x|0)<-15?x+512|0:x;x=(v<<4&496)-p|0;u=(x|0)<-15?x+512|0:x;L39084:do{if((w|0)<(t|0)&(u|0)<(s|0)){x=(v>>>1&496|v&15|v<<5&512)<<1;y=d[e+x|0]|0;z=(y&f)+h|0;A=g+(((y<<8|(d[e+(x|1)|0]|0))&k)<<8)|0;if(q){B=A;C=1;D=w}else{x=A;A=1;y=w;while(1){L39089:do{if((y|0)>-1&(y|0)<(t|0)){E=ag(s,y)|0;if(j){F=u;G=0;while(1){if((F|0)>-1&(F|0)<(s|0)){b[r+(F+E<<1)>>1]=(d[x+G|0]|0|z)&65535}H=G+1|0;if((H|0)>=16){break L39089}F=F+1|0;G=H}}else{G=u;F=0;while(1){H=d[x+F|0]|0;if((G|0)>-1&(1<<H&l|0)==0&(G|0)<(s|0)){b[r+(G+E<<1)>>1]=(H|z)&65535}H=F+1|0;if((H|0)>=16){break L39089}G=G+1|0;F=H}}}}while(0);if((A|0)>=16){break L39084}x=x+16|0;A=A+1|0;y=y+1|0}}while(1){L39108:do{if((D|0)>-1&(D|0)<(t|0)){y=ag(s,D)|0;A=u-(c[n+(D<<2)>>2]|0)|0;x=(A|0)<-15?A+512|0:A;if((x|0)>=(s|0)){break}if(j){A=x;F=0;while(1){if((A|0)>-1&(A|0)<(s|0)){b[r+(A+y<<1)>>1]=(d[B+F|0]|0|z)&65535}G=F+1|0;if((G|0)>=16){break L39108}A=A+1|0;F=G}}else{F=x;A=0;while(1){G=d[B+A|0]|0;if((F|0)>-1&(1<<G&l|0)==0&(F|0)<(s|0)){b[r+(F+y<<1)>>1]=(G|z)&65535}G=A+1|0;if((G|0)>=16){break L39108}F=F+1|0;A=G}}}}while(0);if((C|0)>=16){break L39084}B=B+16|0;C=C+1|0;D=D+1|0}}}while(0);v=v+1|0;}while((v|0)<1024);i=m;return}function aHL(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;f=c[2386556]|0;g=c[3528652]|0;h=c[2112926]|0;i=c[3530516]|0;j=(c[2113222]&1|0)==0;k=0;do{l=d[f+(k|1)|0]|0;m=d[f+k|0]|0;n=m<<8;do{if((n&32768|0)!=0){o=d[f+(k|5)|0]|0;p=d[f+(k|4)|0]|0;q=p<<8;r=p>>>4;if(!((q&2048|0)==0|j)){break}if((e|0)==2){if((r&4|0)==0){break}}else if((e|0)==1){if((r&4|0)!=0){break}}p=(r&b)+4|0;r=n&8192;s=n&16384;t=1<<(m>>>3&3);u=t-1|0;v=q&256|o;o=n&256|l;q=v>>>0>255?v|-512:v;v=o>>>0>255?o|-512:o;o=((d[f+(k|2)|0]<<8&3840|d[f+(k|3)|0])&-t)+((s|0)!=0?0:u)|0;w=(s>>>13^2)-1|0;if((a[g]|0)==0){x=-16;y=s;z=r;A=240-q|0;B=240-v|0}else{x=16;y=s>>>14^1;z=r>>>13^1;A=q;B=v}v=B-8|0;if((t|0)<=0){break}t=(y|0)==0;q=(z|0)!=0;r=u;while(1){u=o-(ag(r,w)|0)&4095;s=v+(ag(r,x)|0)|0;do{if(t){if(q){SJ(h,u,A,s,p,4,0,0,i);break}else{SH(h,u,A,s,p,4,0,0,i);break}}else{if(q){SN(h,u,A,s,p,4,0,0,i);break}else{SL(h,u,A,s,p,4,0,0,i);break}}}while(0);if((r|0)>0){r=r-1|0}else{break}}}}while(0);k=k+8|0;}while((k|0)<2048);return}function aHM(a){a=a|0;var b=0,d=0;b=c[2113194]|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,6e6,0)|0;return a|0}function aHN(){return+(+(c[2113194]|0)/6.0e6)}function aHO(e,f){e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;g=c[3529872]|0;h=((d[g+18|0]|0)<<8|(d[g+19|0]|0))+8&511;i=(d[g+16|0]|0)<<8|(d[g+17|0]|0);g=(e|0)!=0;e=(f|0)!=0?255:65280;f=c[2113068]|0;j=c[2387082]|0;k=c[3530384]|0;l=c[2113070]|0;m=c[2112926]|0;n=0;do{o=(n<<4&496)-i|0;p=(o|0)<-15?o+512|0:o;o=(n>>5<<4)-h|0;q=(o|0)<-15?o+512|0:o;L39161:do{if((p|0)<(f|0)&(q|0)<(f|0)){o=n<<1;r=a[j+o|0]|0;s=r&255;if(g&r<<24>>24>-1){break}r=s&240;t=q;u=k+((d[j+(o|1)|0]|0|s<<8&3840)<<8)|0;s=1;while(1){L39166:do{if((t|0)>-1&(t|0)<(l|0)){o=ag(f,t)|0;v=p;w=0;while(1){do{if((v|0)>-1&(v|0)<(f|0)){x=d[u+w|0]|0;if((1<<x&e|0)!=0){break}b[m+(v+o<<1)>>1]=(r|x|768)&65535}}while(0);x=w+1|0;if((x|0)>=16){break L39166}v=v+1|0;w=x}}}while(0);if((s|0)>=16){break L39161}t=t+1|0;u=u+16|0;s=s+1|0}}}while(0);n=n+1|0;}while((n|0)<1024);return}function aHP(a){a=a|0;var b=0,d=0;b=c[2113194]|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,12e5,0)|0;return a|0}function aHQ(){return+(+(c[2113194]|0)/12.0e5)}function aHR(a){a=a|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;f=i;i=i+16|0;g=f|0;h=f+8|0;j=c[3529872]|0;k=(d[j+16|0]|0)<<8|(d[j+17|0]|0);c[g>>2]=-16777216;c[g+4>>2]=-256;c[h>>2]=16777215;c[h+4>>2]=255;j=(a|0)!=0?h:g;g=c[2113070]|0;h=c[2113068]|0;a=c[2387082]|0;l=c[3530384]|0;m=c[2112926]|0;n=0;do{o=(n>>5<<4)-8|0;L39184:do{if((o|0)<(g|0)){p=(n<<4&496)-k|0;q=(p|0)<-15?p+512|0:p;if((q|0)>=(h|0)){break}p=n<<1;r=d[a+p|0]|0;s=r&48;t=e[j+(s>>>4<<1)>>1]|0;u=o;v=l+((r<<8&768|(d[a+(p|1)|0]|0))<<8)|0;p=1;while(1){L39189:do{if((u|0)>-1&(u|0)<(g|0)){r=ag(h,u)|0;w=q;x=0;while(1){y=d[v+x|0]|0;if((w|0)>-1&(1<<y&t|0)==0&(w|0)<(h|0)){b[m+(w+r<<1)>>1]=(y|s)&65535}y=x+1|0;if((y|0)>=16){break L39189}w=w+1|0;x=y}}}while(0);if((p|0)>=16){break L39184}u=u+1|0;v=v+16|0;p=p+1|0}}}while(0);n=n+1|0;}while((n|0)<1024);i=f;return}function aHS(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;e=(b|0)!=0;f=(b|0)==1;b=c[2386556]|0;g=c[3528652]|0;h=c[2112926]|0;i=c[3530516]|0;j=0;do{k=d[b+(j|1)|0]|0;l=k>>>1&4|k&3;m=(l|0)==0;do{if(!(f&m|(e|m)^1)){n=d[b+(j|3)|0]|k<<3&1792;if((n|0)==0){break}o=a[b+j|0]|0;p=o&255;if(o<<24>>24==-8){break}o=241-(d[b+(j|2)|0]|0)|0;q=k&4;r=k&16;do{if((a[g]|0)==0){s=p-8|0;t=p+8|0;if((q|0)==0){SH(h,n,o,s,l,3,0,64,i);u=o;v=t;w=0;break}else{SJ(h,n,o,s,l,3,0,64,i);u=o;v=t;w=1;break}}else{t=240-p|0;s=240-o|0;x=t-8|0;y=t-24|0;if((q|0)==0){SN(h,n,s,x,l,3,0,64,i);u=s;v=y;w=1;break}else{SL(h,n,s,x,l,3,0,64,i);u=s;v=y;w=0;break}}}while(0);if((r|0)==0){break}q=n+1|0;if((a[g]|0)==0){if(w){SJ(h,q,u,v,l,3,0,64,i);break}else{SH(h,q,u,v,l,3,0,64,i);break}}else{if(w){SN(h,q,u,v,l,3,0,64,i);break}else{SL(h,q,u,v,l,3,0,64,i);break}}}}while(0);j=j+4|0;}while((j|0)<512);return}function aHT(a,d){a=a|0;d=d|0;if((a&16775168|0)==661504){b[(c[2406288]|0)+((a>>>1<<5&992|a>>>6&31)<<1)>>1]=d;return}if((a&16777200|0)!=786432){return}aHU(a>>>1&7,d&65535);return}function aHU(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;switch(d<<1|0){case 2:{a[c[3528210]|0]=e&255;gg[c[(c[2443776]|0)+64>>2]&4095](32,1);gj[c[(c[2443776]|0)+52>>2]&4095](0)|0;gg[c[(c[2443776]|0)+64>>2]&4095](32,0);gj[c[(c[2443776]|0)+52>>2]&4095](0)|0;return};case 0:{d=8452200+(c[2394]<<2)|0;c[d>>2]=0;c[2276080]=0;if((b[4867336]|0)==0){return}f=b[4860032]|0;if(f<<16>>16==0){g=b[4859268]|0;b[4867336]=0;if(g<<16>>16==0){return}else{aHU(3,g&65535);b[4859268]=0;return}}b[4881208]=f;c[d>>2]=8198;c[2276080]=1536;if((c[2276079]|0)>>>0<1536){RH(6)}b[4860032]=0;return};case 8:{b[c[2386728]>>1]=e&65535;a[c[3528650]|0]=e>>>15&255;return};case 10:{b[(c[2386728]|0)+2>>1]=e&65535;return};case 6:{d=c[2429906]|0;do{if(d>>>0<2){if((b[4867336]|0)!=0){b[4859268]=e&65535;h=d;break}f=(e|0)==256;if((e&3840|0)==768){i=((e&255)*18|0)&65535}else{i=f&(d|0)==0?1387:f&(d|0)==1?1386:0}b[4881208]=i;switch(e|0){case 1029:{b[4881208]=16770;break};case 1027:{b[4881208]=16468;break};case 1025:{b[4881208]=16696;break};case 1028:{b[4881208]=16606;break};case 1031:{b[4881208]=16926;break};case 1030:{b[4881208]=16842;break};case 1032:{b[4881208]=17014;break};case 1024:{b[4881208]=16384;break};case 1026:{b[4881208]=16550;break};default:{}}c[8452200+(c[2394]<<2)>>2]=8198;c[2276080]=1536;if((c[2276079]|0)>>>0<1536){RH(6);j=c[2429906]|0}else{j=d}b[4867336]=1;h=j}else{h=d}}while(0);do{if((h-2|0)>>>0<3){if((b[4867336]|0)!=0){b[4859268]=e&65535;k=h;break}d=(e|0)==512;j=(h|0)==3;i=(h|0)==2;f=(h|0)==4;g=(e|0)==256;b[4881208]=(e-24576|0)>>>0<8192?1:g&f?1820:g&i?1819:g&j?1818:d&f?30518:d&i?30782:d&j?30516:0;j=e&61440;L39290:do{if((j|0)==12288){d=e&255;switch(c[2444192]|0){case 2:{if(d>>>0<3){b[4881208]=0;break L39290}if(d>>>0<9){b[4881208]=1;break L39290}if(d>>>0<17){b[4881208]=2;break L39290}if(d>>>0<27){b[4881208]=3;break L39290}if(d>>>0<33){b[4881208]=4;break L39290}if(d>>>0<40){b[4881208]=5;break L39290}else{b[4881208]=6;break L39290}break};case 6:{if(d>>>0<3){b[4881208]=0;break L39290}if(d>>>0<11){b[4881208]=1;break L39290}if(d>>>0<17){b[4881208]=2;break L39290}if(d>>>0<23){b[4881208]=3;break L39290}if(d>>>0<29){b[4881208]=4;break L39290}if(d>>>0<36){b[4881208]=5;break L39290}else{b[4881208]=6;break L39290}break};case 1:{if(i){if(d>>>0<2){b[4881208]=0;break L39290}if(d>>>0<6){b[4881208]=1;break L39290}if(d>>>0<11){b[4881208]=2;break L39290}if(d>>>0<15){b[4881208]=3;break L39290}if(d>>>0<19){b[4881208]=4;break L39290}else{b[4881208]=5;break L39290}}if(d>>>0<3){b[4881208]=0;break L39290}if(d>>>0<8){b[4881208]=1;break L39290}if(d>>>0<12){b[4881208]=2;break L39290}if(d>>>0<16){b[4881208]=3;break L39290}if(d>>>0<25){b[4881208]=4;break L39290}if(d>>>0<27){b[4881208]=5;break L39290}if(d>>>0<34){b[4881208]=6;break L39290}if(d>>>0<40){b[4881208]=7;break L39290}else{b[4881208]=8;break L39290}break};case 3:{if(d>>>0<5){b[4881208]=0;break L39290}if(d>>>0<9){b[4881208]=1;break L39290}if(d>>>0<13){b[4881208]=2;break L39290}if(d>>>0<17){b[4881208]=3;break L39290}if(d>>>0<27){b[4881208]=4;break L39290}if(d>>>0<28){b[4881208]=5;break L39290}if(d>>>0<34){b[4881208]=6;break L39290}if(d>>>0<39){b[4881208]=7;break L39290}else{b[4881208]=8;break L39290}break};case 7:{if(d>>>0<5){b[4881208]=0;break L39290}if(d>>>0<11){b[4881208]=1;break L39290}if(d>>>0<17){b[4881208]=2;break L39290}if(d>>>0<26){b[4881208]=3;break L39290}if(d>>>0<33){b[4881208]=4;break L39290}if(d>>>0<39){b[4881208]=5;break L39290}else{b[4881208]=6;break L39290}break};case 4:{if(d>>>0<4){b[4881208]=0;break L39290}if(d>>>0<12){b[4881208]=1;break L39290}if(d>>>0<15){b[4881208]=2;break L39290}if(d>>>0<25){b[4881208]=3;break L39290}if(d>>>0<28){b[4881208]=4;break L39290}if(d>>>0<34){b[4881208]=5;break L39290}if(d>>>0<41){b[4881208]=6;break L39290}else{b[4881208]=7;break L39290}break};case 5:{if(d>>>0<7){b[4881208]=0;break L39290}if(d>>>0<14){b[4881208]=1;break L39290}if(d>>>0<20){b[4881208]=2;break L39290}if(d>>>0<26){b[4881208]=3;break L39290}if(d>>>0<35){b[4881208]=4;break L39290}if(d>>>0<39){b[4881208]=5;break L39290}else{b[4881208]=6;break L39290}break};default:{break L39290}}}else if((j|0)==4096){c[2444192]=1}else if((j|0)==8192){c[2444192]=(c[2444192]|0)+1}}while(0);c[8452200+(c[2394]<<2)>>2]=8198;c[2276080]=1536;if((c[2276079]|0)>>>0<1536){RH(6);l=c[2429906]|0}else{l=h}b[4867336]=1;k=l}else{k=h}}while(0);if((k|0)!=5){return}if((b[4867336]|0)!=0){b[4859268]=e&65535;return}b[4881208]=(e|0)==768?23:(e|0)==512?532:(e|0)==256?1658:0;do{if((e&1536|0)==1536){k=e&24;if((k|0)==0){b[4881208]=19795;break}else if((k|0)==24){b[4881208]=21313;break}else if((k|0)==8){b[4881208]=19284;break}else if((k|0)==16){b[4881208]=21587;break}else{break}}}while(0);switch(e|0){case 1292:{b[4881208]=5116;break};case 1029:{b[4881208]=1700;break};case 1030:{b[4881208]=1700;break};case 1024:{b[4881208]=1428;break};case 1025:{b[4881208]=1514;break};case 1287:{b[4881208]=6;break};case 1026:{b[4881208]=1576;break};case 1027:{b[4881208]=1644;break};case 1288:{b[4881208]=19001;break};case 1028:{b[4881208]=1700;break};case 1280:{b[4881208]=20085;break};case 1281:{b[4881208]=27640;break};case 1291:{b[4881208]=255;break};case 1290:{b[4881208]=6;break};case 1289:{b[4881208]=0;break};case 1282:{b[4881208]=3;break};case 1283:{b[4881208]=12;break};case 1286:{b[4881208]=0;break};case 1285:{b[4881208]=26360;break};case 1284:{b[4881208]=19001;break};default:{}}c[8452200+(c[2394]<<2)>>2]=8198;c[2276080]=1536;if((c[2276079]|0)>>>0<1536){RH(6)}b[4867336]=1;return};case 12:{b[4867336]=0;b[4860032]=0;b[4859268]=0;b[4881208]=0;return};case 14:{c[8452200+(c[2394]<<2)>>2]=0;c[2276080]=0;return};case 4:{gGC(c[2386554]|0,c[2386380]|0,4096)|0;return};default:{return}}}function aHV(b,d){b=b|0;d=d|0;if((b&16775168|0)==661504){a[(c[2406288]|0)+(((b>>>1<<5&992|b>>>6&31)<<1|b&1)^1)|0]=d;return}if((b&16777200|0)!=786432){return}aHU(b>>>1&7,d&255);return}function aHW(c){c=c|0;var e=0,f=0;do{if((c&16777200|0)==786432){e=c&14;if((e|0)==4){f=(d[9657881]|0)<<8|(d[9657880]|0);break}else if((e|0)==6){f=b[4881208]|0;break}else if((e|0)==0){f=b[4812688]|0;break}else if((e|0)==2){f=(a[672648]|0?128:0)^b[4812689];break}else{f=-1;break}}else{f=0}}while(0);return f|0}function aHX(c){c=c|0;var e=0,f=0,g=0;if((c&16777200|0)!=786432){e=0;return e|0}f=c&14;if((f|0)==2){g=(a[672648]|0?128:0)^b[4812689]}else if((f|0)==0){g=b[4812688]|0}else if((f|0)==6){g=b[4881208]|0}else if((f|0)==4){g=(d[9657881]|0)<<8|(d[9657880]|0)}else{g=-1}e=(g&65535)>>>((c<<3&8^8)>>>0)&255;return e|0}function aHY(b,e){b=b|0;e=e|0;var f=0;f=b&65535;if((f|0)==4096|(f|0)==4097){lS(0,f&1,e);return}else if((f|0)==6144|(f|0)==6145){b=c[3540986]|0;if((f&1|0)==0){a[b+5885|0]=e;return}f=c[b+5876>>2]|0;if((f|0)!=0){gg[f&4095](c[b+5880>>2]|0,0)}lH(b,d[b+5885|0]|0,e&255);return}else{return}}function aHZ(b){b=b|0;var d=0;if(b<<16>>16!=2048){d=0;return d|0}d=a[c[3528210]|0]|0;return d|0}function aH_(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5834252+(b*112|0)>>2];c[a+104>>2]=c[5834256+(b*112|0)>>2];c[a+108>>2]=c[5834260+(b*112|0)>>2];d=0;return d|0}function aH$(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=5834152+(b*112|0);e=0;return e|0}function aH0(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3836896+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aH1(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>38){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6269672+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aH2(){c[2429906]=0;a[635120]=0;return aIs()|0}function aH3(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}if((c[2392]|0)>=0){b=0;do{d=14130368+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}d=14130384+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}b=b+1|0;}while((b|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;fvR();b=a[7452592]|0;if(b){d=0;e=b&1;while(1){b=14163944+(d<<2)|0;f=c[b>>2]|0;g=c[2113006]|0;if((g|0)==0){h=30822}else{i=g-1|0;c[2113006]=i;if((i|0)==0){h=30822}}if((h|0)==30822){h=0;c[2383474]=0}if((f|0)==0){j=e}else{gGr(f);j=a[7452592]&1}c[b>>2]=0;b=d+1|0;if((b|0)<(j|0)){d=b;e=j}else{break}}}a[7452592]=0;c[2438222]=0;c[2433520]=0;c[2406670]=0;c[3528466]=0;j=c[2406686]|0;if((j|0)!=0){gGr(j);c[2406686]=0}c[2432974]=0;j=c[3541518]|0;if((j|0)!=0){gGr(j|0);c[3541518]=0}if((c[2385508]|0)>0){c[2113008]=0;c[2076598]=0;c[2383582]=0}c[2438228]=0;c[2433526]=0;c[2406676]=0;c[3528472]=0;j=c[2406680]|0;if((j|0)!=0){gGr(j);c[2406680]=0}c[2385508]=0;c[2432978]=0;a[64240]=0;j=c[2414852]|0;e=0;while(1){if((e|0)>=1024){h=30840;break}k=9638528+(e<<2)|0;if((c[k>>2]|0)==(j|0)){break}else{e=e+1|0}}if((h|0)==30840){c[2414852]=0;return 0}gGr(j);c[k>>2]=0;c[2414852]=0;return 0}function aH4(){var d=0,e=0,f=0,g=0,i=0,j=0;if((a[9623392]|0)!=0){a[9623392]=0;d=c[2414554]|0;gGz(d|0,0,(c[2411454]|0)-d|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;c[3528556]=0;d=c[2433594]|0;c[2443776]=d;L39650:do{if((d|0)!=0){e=d|0;gGC(9660952,e|0,52)|0;switch(a[9660952]|0){case 1:{c[2309668]=634096;break L39650;break};case 0:{c[2309668]=638960;break L39650;break};case 4:{c[2309668]=7356016;break L39650;break};case 2:{c[2309668]=638960;break L39650;break};case 5:{c[2309668]=7354992;break L39650;break};case 3:{c[2309668]=639984;break L39650;break};default:{break L39650}}}}while(0);c[2113164]=c[2432850];gu[c[d+56>>2]&16383]();d=c[2443776]|0;if((d|0)!=0){e=d|0;gGC(e|0,9660952,52)|0}c[9731400+(c[3528556]<<2)>>2]=c[2113164];c[2443776]=0;c[3528556]=-1;c[2443825]=1073676288;c[2443824]=1073676288;c[2443817]=1073676288;c[2443816]=1073676288;h[883199]=0.0;c[3528506]=0;lw(c[3540986]|0);c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){e=0;do{lN(e);mB(e);e=e+1|0;}while((e|0)<(c[2385508]|0))}b[4881208]=0;b[4867336]=0;b[4860032]=0;b[4859268]=0;c[2444192]=0}e=c[2392]|0;if((e|0)>=0){gGz(8452240,0,((e|0)>0?(e<<2)+4|0:4)|0)}c[2113054]=0;e=c[2113166]|0;if((e|0)>0){gGz(9731400,0,((e|0)>1?e<<2:4)|0)}c[2113164]=0;c[2406344]=-1;e=a[635120]|0?224:0;b[4812690]=e;d=0;f=-1;g=-1;i=e;do{f=((a[9632376+d|0]&1)<<d^f&65535)&65535;g=((a[9630288+d|0]&1)<<d^g&65535)&65535;i=((a[9629168+d|0]&1)<<d^i&65535)&65535;d=d+1|0;}while((d|0)<16);b[4812688]=f;b[4812689]=g;b[4812690]=i;c[3528556]=0;i=c[2433594]|0;c[2443776]=i;L39677:do{if((i|0)!=0){g=i|0;gGC(9660952,g|0,52)|0;switch(a[9660952]|0){case 1:{c[2309668]=634096;break L39677;break};case 5:{c[2309668]=7354992;break L39677;break};case 3:{c[2309668]=639984;break L39677;break};case 0:{c[2309668]=638960;break L39677;break};case 4:{c[2309668]=7356016;break L39677;break};case 2:{c[2309668]=638960;break L39677;break};default:{break L39677}}}}while(0);c[2113164]=c[2432850];if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];i=c[3532592]|0;if((i|0)!=0){gGC(9104152,i|0,280)|0}c[2113054]=c[2113060]}a[672648]=1;i=0;do{do{if((i|0)==31){a[672648]=0;g=b[4812690]|0;f=g&65535;d=a[635120]|0?224:0;if((f|0)==(d|0)){a[608512]=1;j=1}else{j=a[608512]|0}if((f|0)!=(d|0)&j){d=g|-32768;if((b[4867336]|0)==0){b[4881208]=d;c[8452200+(c[2394]<<2)>>2]=8198;c[2276080]=1536;if((c[2276079]|0)>>>0<1536){RH(6)}b[4867336]=1}else{b[4860032]=d}a[608512]=0}c[8452200+(c[2394]<<2)>>2]=8199;d=c[2276080]|0;c[2276080]=1792;if((d|0)!=1792){RH(7);break}if((c[2276079]|0)>>>0>=1792){break}RH(7)}else if((i|0)==1){a[672648]=1}}while(0);Sb(i*5208|0);U1(i*781|0);i=i+1|0;}while((i|0)<32);i=c[2438228]|0;j=gGS(-1967915008,79472,i,(i|0)<0|0?-1:0)|0;i=j;Sb(166666);j=c[2443830]|0;if((j|0)<1073676288){c[2443830]=j-i}j=c[2443831]|0;if((j|0)<1073676288){c[2443831]=j-i}j=(c[3528512]|0)-i|0;c[3528512]=(j|0)<0?0:j;j=c[2438222]|0;i=gGS(-305135616,11920,j,(j|0)<0|0?-1:0)|0;j=i;U1(25e3);i=c[2443824]|0;if((i|0)<1073676288){c[2443824]=i-j}i=c[2443825]|0;if((i|0)<1073676288){c[2443825]=i-j}i=(c[3528506]|0)-j|0;c[3528506]=(i|0)<0?0:i;i=c[2112964]|0;if((i|0)!=0){gg[c[3542114]&4095](i,a[9688]|0?534:0);gg[c[3542122]&4095](c[2112964]|0,a[9688]|0?534:0)}i=c[2394]|0;j=c[14130368+(i<<2)>>2]|0;if((j|0)!=0){gGC(j|0,9104152,280)|0}c[8452240+(i<<2)>>2]=c[2113054];c[2394]=-1;i=c[2443776]|0;if((i|0)!=0){j=i|0;gGC(j|0,9660952,52)|0}c[9731400+(c[3528556]<<2)>>2]=c[2113164];c[2443776]=0;c[3528556]=-1;if((c[2112968]|0)==0){return 0}aH5()|0;return 0}function aH5(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;if((a[9547072]|0)!=0){d=c[2406906]|0;f=c[3529892]|0;g=0;do{h=c[d+(g<<2)>>2]|0;c[f+(g<<2)>>2]=h>>>8<<3&2016|h>>>3&31|h>>>16<<8&63488;g=g+1|0;}while((g|0)<768);a[9547072]=0}g=c[2386728]|0;f=b[g>>1]&511;d=b[g+2>>1]&511;g=c[2406288]|0;h=c[3528650]|0;i=c[2112926]|0;j=c[3530514]|0;k=c[2113068]|0;l=c[2113070]|0;m=0;do{n=(m>>5<<4)-d|0;o=(n|0)<-15?n+512|0:n;n=(m<<4&496)-f|0;p=(n|0)<-15?n+512|0:n;do{if((p|0)<(k|0)&(o|0)<(l|0)){n=e[g+(m<<1)>>1]|0;q=n&2047;r=n>>>12;if((a[h]|0)==0){Sz(i,q,p,o,r,4,512,j);break}else{SF(i,q,240-p|0,232-o|0,r,4,512,j);break}}}while(0);m=m+1|0;}while((m|0)<1024);m=c[2386554]|0;j=0;do{g=e[m+(j<<1)>>1]|0;do{if((g&32768|0)!=0){l=e[m+((j|3)<<1)>>1]|0;k=l>>>12;f=l&4095;l=e[m+((j|1)<<1)>>1]|0;d=l&2;o=l&16;p=l&4;l=256-((e[m+((j|2)<<1)>>1]|0)+16&511)|0;r=256-(g+16+o&511)|0;if((a[h]|0)==0){s=d;t=p;u=r;v=l}else{q=240-r|0;s=d^2;t=p^4;u=((o|0)==0?q:q-16|0)-8|0;v=240-l|0}l=f+1|0;q=(o|0)!=0;o=(s|0)==0|q^1;aIx(o?f:l,v,u,k,s,t);if(!q){break}aIx(o?l:f,v,u+16|0,k,s,t)}}while(0);j=j+4|0;}while((j|0)<2048);j=c[2386186]|0;t=c[3530750]|0;if((c[2429906]|0)==5){s=32;do{u=s<<3&248;v=s>>5<<3;m=(a[h]|0)==0;if(m){w=v;x=u}else{w=v^248;x=u^248}u=x-8|0;v=e[j+(s<<1)>>1]|0;g=v&4095;k=v>>>14;do{if((g|0)!=0){if(m){Sq(i,g,w,u,k,3,0,0,t);break}else{Sw(i,g,w,u,k,3,0,0,t);break}}}while(0);s=s+1|0;}while((s|0)<992);y=c[3529892]|0;R8(y);return 0}else{s=32;do{w=s<<3&248;x=s>>5<<3;k=(a[h]|0)==0;if(k){z=w;A=x}else{z=w^248;A=x^248}x=A-8|0;w=e[j+(s<<1)>>1]|0;u=w&4095;g=w>>>14;do{if((u|0)!=0){if(k){Sq(i,u,z,x,g,3,0,0,t);break}else{Sw(i,u,z,x,g,3,0,0,t);break}}}while(0);s=s+1|0;}while((s|0)<992);y=c[3529892]|0;R8(y);return 0}return 0}function aH6(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;e=i;i=i+224|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;l=e+80|0;m=e+96|0;n=e+112|0;o=e+128|0;p=e+144|0;q=e+160|0;r=e+176|0;s=e+192|0;t=e+208|0;if((d|0)!=0){c[d>>2]=169735}if((b&32|0)!=0){gGz(t|0,0,12);u=c[2414554]|0;c[t>>2]=u;c[t+4>>2]=(c[2411454]|0)-u;c[t+12>>2]=162152;u=c[2076592]|0;gj[u&4095](t)|0}if((b&64|0)==0){i=e;return 0}t=n|0;gGz(m|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){u=n+9|0;n=l;v=l|0;w=l+4|0;x=l+12|0;y=m|0;z=m+4|0;A=m+12|0;B=0;do{gGC(t|0,614896,11)|0;a[u]=B+48&255;C=8452256+(B<<2)|0;gGz(n|0,0,12);c[v>>2]=C;c[w>>2]=4;c[x>>2]=164976;gj[c[2076592]&4095](l)|0;if((c[C>>2]|0)!=0){c[y>>2]=c[14130368+(B<<2)>>2];c[z>>2]=c[8452184+(B<<2)>>2];c[A>>2]=t;C=c[2076592]|0;gj[C&4095](m)|0}B=B+1|0;}while((B|0)<=(c[2392]|0))}B=k|0;if((c[2113166]|0)>0){m=k+7|0;k=j|0;t=j+4|0;A=j+12|0;z=h;y=h|0;l=h+4|0;x=h+12|0;w=g;v=g|0;n=g+4|0;u=g+12|0;C=f;D=f|0;E=f+4|0;F=f+12|0;G=0;do{H=c[9734376+(G<<2)>>2]|0;I=H+36|0;J=c[I>>2]|0;gGC(B|0,614768,9)|0;a[m]=G+48&255;c[k>>2]=H;c[t>>2]=52;c[A>>2]=B;gj[c[2076592]&4095](j)|0;gGz(z|0,0,12);c[y>>2]=H+3172;c[l>>2]=4;c[x>>2]=165288;gj[c[2076592]&4095](h)|0;gGz(w|0,0,12);c[v>>2]=H+3176;c[n>>2]=4;c[u>>2]=501592;gj[c[2076592]&4095](g)|0;gGz(C|0,0,12);c[D>>2]=H+3180;c[E>>2]=4;c[F>>2]=386080;gj[c[2076592]&4095](f)|0;c[I>>2]=J;G=G+1|0;}while((G|0)<(c[2113166]|0))}Vb(b,d);Vx(b,d);gGz(s|0,0,12);c[s>>2]=9762416;c[s+4>>2]=2;c[s+12>>2]=69208;gj[c[2076592]&4095](s)|0;gGz(r|0,0,12);c[r>>2]=9734672;c[r+4>>2]=2;c[r+12>>2]=67928;gj[c[2076592]&4095](r)|0;gGz(q|0,0,12);c[q>>2]=9720064;c[q+4>>2]=2;c[q+12>>2]=66408;gj[c[2076592]&4095](q)|0;gGz(p|0,0,12);c[p>>2]=9718536;c[p+4>>2]=2;c[p+12>>2]=65128;gj[c[2076592]&4095](p)|0;gGz(o|0,0,12);c[o>>2]=9776768;c[o+4>>2]=4;c[o+12>>2]=588648;gj[c[2076592]&4095](o)|0;i=e;return 0}function aH7(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4627388+(b*112|0)>>2];c[a+104>>2]=c[4627392+(b*112|0)>>2];c[a+108>>2]=c[4627396+(b*112|0)>>2];d=0;return d|0}function aH8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=4627288+(b*112|0);e=0;return e|0}function aH9(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4624812+(b*112|0)>>2];c[a+104>>2]=c[4624816+(b*112|0)>>2];c[a+108>>2]=c[4624820+(b*112|0)>>2];d=0;return d|0}function aIa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=4624712+(b*112|0);e=0;return e|0}function aIb(){c[2429906]=1;a[635120]=0;return aIs()|0}function aIc(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2082004+(b*112|0)>>2];c[a+104>>2]=c[2082008+(b*112|0)>>2];c[a+108>>2]=c[2082012+(b*112|0)>>2];d=0;return d|0}function aId(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=2081904+(b*112|0);e=0;return e|0}function aIe(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>33){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3245880+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aIf(){c[2429906]=5;a[635120]=0;return aIs()|0}function aIg(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4781828+(b*112|0)>>2];c[a+104>>2]=c[4781832+(b*112|0)>>2];c[a+108>>2]=c[4781836+(b*112|0)>>2];d=0;return d|0}function aIh(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=4781728+(b*112|0);e=0;return e|0}function aIi(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1981992+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aIj(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>36){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5534992+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aIk(){var d=0,e=0;c[2429906]=4;a[635120]=1;d=aIs()|0;if((d|0)!=0){return d|0}e=c[2388074]|0;b[e+2598>>1]=20081;b[e+1578>>1]=20081;return d|0}function aIl(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3016628+(b*112|0)>>2];c[a+104>>2]=c[3016632+(b*112|0)>>2];c[a+108>>2]=c[3016636+(b*112|0)>>2];d=0;return d|0}function aIm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=3016528+(b*112|0);e=0;return e|0}function aIn(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>36){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4162080+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aIo(){var d=0,e=0;c[2429906]=2;a[635120]=1;d=aIs()|0;if((d|0)!=0){return d|0}e=c[2388074]|0;b[e+2598>>1]=20081;b[e+1578>>1]=20081;return d|0}function aIp(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3018756+(b*112|0)>>2];c[a+104>>2]=c[3018760+(b*112|0)>>2];c[a+108>>2]=c[3018764+(b*112|0)>>2];d=0;return d|0}function aIq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=3018656+(b*112|0);e=0;return e|0}function aIr(){var d=0,e=0;c[2429906]=3;a[635120]=1;d=aIs()|0;if((d|0)!=0){return d|0}e=c[2388074]|0;b[e+2606>>1]=20081;b[e+1578>>1]=20081;return d|0}function aIs(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0;e=i;i=i+2520|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;B=e+1200|0;C=e+1312|0;D=e+1320|0;E=e+1432|0;F=e+1440|0;G=e+1552|0;H=e+1560|0;I=e+1672|0;J=e+1680|0;K=e+1792|0;L=e+1800|0;M=e+1912|0;N=e+1920|0;O=e+2032|0;P=e+2040|0;Q=e+2152|0;R=e+2160|0;S=e+2272|0;T=e+2280|0;U=e+2392|0;V=e+2400|0;W=e+2512|0;c[2414852]=0;c[2388074]=0;c[3531202]=393216;c[3530750]=458752;c[3530514]=589824;c[3530382]=1114112;c[3530988]=2162688;c[2406906]=2164736;c[3529892]=2167808;c[2414554]=2170880;c[2388204]=2170880;c[2406288]=2187264;c[3531212]=2189312;c[2386186]=2191360;c[2386380]=2193408;c[2386554]=2197504;c[3528210]=2201600;c[3528650]=2201601;c[2386728]=2201602;c[2411454]=2201606;X=0;while(1){if((X|0)>=1024){break}Y=9638528+(X<<2)|0;if((c[Y>>2]|0)==0){Z=31088;break}else{X=X+1|0}}do{if((Z|0)==31088){X=gGq(2201606)|0;c[Y>>2]=X;if((X|0)==0){break}c[2414852]=X;gGz(X|0,0,2201606);c[2388074]=X;c[3531202]=X+393216;c[3530750]=X+458752;c[3530514]=X+589824;c[3530382]=X+1114112;c[3530988]=X+2162688;c[2406906]=X+2164736;c[3529892]=X+2167808;_=X+2170880|0;c[2414554]=_;c[2388204]=_;c[2406288]=X+2187264;c[3531212]=X+2189312;c[2386186]=X+2191360;c[2386380]=X+2193408;c[2386554]=X+2197504;c[3528210]=X+2201600;c[3528650]=X+2201601;c[2386728]=X+2201602;_=X+2201606|0;c[2411454]=_;c[2413994]=_;if((R6(X+1|0,0,2)|0)!=0){$=1;i=e;return $|0}if((R6(c[2388074]|0,1,2)|0)!=0){$=1;i=e;return $|0}if((R6((c[2388074]|0)+131073|0,2,2)|0)!=0){$=1;i=e;return $|0}if((R6((c[2388074]|0)+131072|0,3,2)|0)!=0){$=1;i=e;return $|0}if((R6((c[2388074]|0)+262145|0,4,2)|0)!=0){$=1;i=e;return $|0}if((R6((c[2388074]|0)+262144|0,5,2)|0)!=0){$=1;i=e;return $|0}X=(c[3531202]|0)+32768|0;if((c[3542200]|0)==0){$=1;i=e;return $|0}_=V+108|0;c[_>>2]=0;aa=V+100|0;c[aa>>2]=0;ab=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ab&16383](V,6)|0;do{if((c[_>>2]|0)!=0){ab=c[aa>>2]|0;c[W>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](W,6,0)|0;if((ab|0)<1){$=1;i=e;return $|0}if((gzL(X,0,6)|0)==0){break}else{$=1}i=e;return $|0}}while(0);X=c[3530750]|0;if((c[3542200]|0)==0){$=1;i=e;return $|0}aa=T+108|0;c[aa>>2]=0;_=T+100|0;c[_>>2]=0;ab=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ab&16383](T,7)|0;do{if((c[aa>>2]|0)!=0){ab=c[_>>2]|0;c[U>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](U,7,0)|0;if((ab|0)<1){$=1;i=e;return $|0}if((gzL(X,0,7)|0)==0){break}else{$=1}i=e;return $|0}}while(0);X=c[3530514]|0;if((c[3542200]|0)==0){$=1;i=e;return $|0}_=R+108|0;c[_>>2]=0;aa=R+100|0;c[aa>>2]=0;ab=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ab&16383](R,8)|0;do{if((c[_>>2]|0)!=0){ab=c[aa>>2]|0;c[S>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](S,8,0)|0;if((ab|0)<1){$=1;i=e;return $|0}if((gzL(X,0,8)|0)==0){break}else{$=1}i=e;return $|0}}while(0);X=(c[3530514]|0)+131072|0;if((c[3542200]|0)==0){$=1;i=e;return $|0}aa=P+108|0;c[aa>>2]=0;_=P+100|0;c[_>>2]=0;ab=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ab&16383](P,9)|0;do{if((c[aa>>2]|0)!=0){ab=c[_>>2]|0;c[Q>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](Q,9,0)|0;if((ab|0)<1){$=1;i=e;return $|0}if((gzL(X,0,9)|0)==0){break}else{$=1}i=e;return $|0}}while(0);X=(c[3530514]|0)+262144|0;if((c[3542200]|0)==0){$=1;i=e;return $|0}_=N+108|0;c[_>>2]=0;aa=N+100|0;c[aa>>2]=0;ab=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ab&16383](N,10)|0;do{if((c[_>>2]|0)!=0){ab=c[aa>>2]|0;c[O>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](O,10,0)|0;if((ab|0)<1){$=1;i=e;return $|0}if((gzL(X,0,10)|0)==0){break}else{$=1}i=e;return $|0}}while(0);X=(c[3530514]|0)+393216|0;if((c[3542200]|0)==0){$=1;i=e;return $|0}aa=L+108|0;c[aa>>2]=0;_=L+100|0;c[_>>2]=0;ab=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ab&16383](L,11)|0;do{if((c[aa>>2]|0)!=0){ab=c[_>>2]|0;c[M>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](M,11,0)|0;if((ab|0)<1){$=1;i=e;return $|0}if((gzL(X,0,11)|0)==0){break}else{$=1}i=e;return $|0}}while(0);X=c[2429906]|0;_=(X-3|0)>>>0<2|(X|0)==2;X=c[3530382]|0;do{if((c[3542200]|0)==0){ad=1}else{aa=J+108|0;c[aa>>2]=0;ab=J+100|0;c[ab>>2]=0;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ac&16383](J,12)|0;if((c[aa>>2]|0)==0){ad=0;break}aa=c[ab>>2]|0;c[K>>2]=9534384;ab=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ab&16383](K,12,0)|0;if((aa|0)<1){ad=1;break}ad=(gzL(X,0,12)|0)!=0}}while(0);do{if(_){if(ad){$=1;i=e;return $|0}X=(c[3530382]|0)+131072|0;if((c[3542200]|0)==0){$=1;i=e;return $|0}aa=H+108|0;c[aa>>2]=0;ab=H+100|0;c[ab>>2]=0;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ac&16383](H,13)|0;do{if((c[aa>>2]|0)!=0){ac=c[ab>>2]|0;c[I>>2]=9534384;ae=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ae&16383](I,13,0)|0;if((ac|0)<1){$=1;i=e;return $|0}if((gzL(X,0,13)|0)==0){break}else{$=1}i=e;return $|0}}while(0);X=(c[3530382]|0)+262144|0;if((c[3542200]|0)==0){$=1;i=e;return $|0}ab=F+108|0;c[ab>>2]=0;aa=F+100|0;c[aa>>2]=0;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ac&16383](F,14)|0;do{if((c[ab>>2]|0)!=0){ac=c[aa>>2]|0;c[G>>2]=9534384;ae=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ae&16383](G,14,0)|0;if((ac|0)<1){$=1;i=e;return $|0}if((gzL(X,0,14)|0)==0){break}else{$=1}i=e;return $|0}}while(0);X=(c[3530382]|0)+393216|0;if((c[3542200]|0)==0){$=1;i=e;return $|0}aa=D+108|0;c[aa>>2]=0;ab=D+100|0;c[ab>>2]=0;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ac&16383](D,15)|0;do{if((c[aa>>2]|0)!=0){ac=c[ab>>2]|0;c[E>>2]=9534384;ae=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ae&16383](E,15,0)|0;if((ac|0)<1){$=1;i=e;return $|0}if((gzL(X,0,15)|0)==0){break}else{$=1}i=e;return $|0}}while(0);X=c[3530988]|0;if((c[3542200]|0)==0){$=1;i=e;return $|0}ab=B+108|0;c[ab>>2]=0;aa=B+100|0;c[aa>>2]=0;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ac&16383](B,16)|0;do{if((c[ab>>2]|0)!=0){ac=c[aa>>2]|0;c[C>>2]=9534384;ae=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ae&16383](C,16,0)|0;if((ac|0)<1){$=1;i=e;return $|0}if((gzL(X,0,16)|0)==0){break}else{$=1}i=e;return $|0}}while(0);X=(c[3530988]|0)+1024|0;if((c[3542200]|0)==0){$=1;i=e;return $|0}aa=z+108|0;c[aa>>2]=0;ab=z+100|0;c[ab>>2]=0;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ac&16383](z,17)|0;if((c[aa>>2]|0)==0){break}aa=c[ab>>2]|0;c[A>>2]=9534384;ab=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ab&16383](A,17,0)|0;if((aa|0)<1){$=1;i=e;return $|0}if((gzL(X,0,17)|0)==0){break}else{$=1}i=e;return $|0}else{if(ad){$=1;i=e;return $|0}X=(c[3530382]|0)+65536|0;if((c[3542200]|0)==0){$=1;i=e;return $|0}aa=x+108|0;c[aa>>2]=0;ab=x+100|0;c[ab>>2]=0;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ac&16383](x,13)|0;do{if((c[aa>>2]|0)!=0){ac=c[ab>>2]|0;c[y>>2]=9534384;ae=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ae&16383](y,13,0)|0;if((ac|0)<1){$=1;i=e;return $|0}if((gzL(X,0,13)|0)==0){break}else{$=1}i=e;return $|0}}while(0);X=(c[3530382]|0)+131072|0;if((c[3542200]|0)==0){$=1;i=e;return $|0}ab=v+108|0;c[ab>>2]=0;aa=v+100|0;c[aa>>2]=0;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ac&16383](v,14)|0;do{if((c[ab>>2]|0)!=0){ac=c[aa>>2]|0;c[w>>2]=9534384;ae=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ae&16383](w,14,0)|0;if((ac|0)<1){$=1;i=e;return $|0}if((gzL(X,0,14)|0)==0){break}else{$=1}i=e;return $|0}}while(0);X=(c[3530382]|0)+196608|0;if((c[3542200]|0)==0){$=1;i=e;return $|0}aa=t+108|0;c[aa>>2]=0;ab=t+100|0;c[ab>>2]=0;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ac&16383](t,15)|0;do{if((c[aa>>2]|0)!=0){ac=c[ab>>2]|0;c[u>>2]=9534384;ae=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ae&16383](u,15,0)|0;if((ac|0)<1){$=1;i=e;return $|0}if((gzL(X,0,15)|0)==0){break}else{$=1}i=e;return $|0}}while(0);X=(c[3530382]|0)+262144|0;if((c[3542200]|0)==0){$=1;i=e;return $|0}ab=r+108|0;c[ab>>2]=0;aa=r+100|0;c[aa>>2]=0;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ac&16383](r,16)|0;do{if((c[ab>>2]|0)!=0){ac=c[aa>>2]|0;c[s>>2]=9534384;ae=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ae&16383](s,16,0)|0;if((ac|0)<1){$=1;i=e;return $|0}if((gzL(X,0,16)|0)==0){break}else{$=1}i=e;return $|0}}while(0);X=(c[3530382]|0)+327680|0;if((c[3542200]|0)==0){$=1;i=e;return $|0}aa=p+108|0;c[aa>>2]=0;ab=p+100|0;c[ab>>2]=0;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ac&16383](p,17)|0;do{if((c[aa>>2]|0)!=0){ac=c[ab>>2]|0;c[q>>2]=9534384;ae=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ae&16383](q,17,0)|0;if((ac|0)<1){$=1;i=e;return $|0}if((gzL(X,0,17)|0)==0){break}else{$=1}i=e;return $|0}}while(0);X=(c[3530382]|0)+393216|0;if((c[3542200]|0)==0){$=1;i=e;return $|0}ab=n+108|0;c[ab>>2]=0;aa=n+100|0;c[aa>>2]=0;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ac&16383](n,18)|0;do{if((c[ab>>2]|0)!=0){ac=c[aa>>2]|0;c[o>>2]=9534384;ae=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ae&16383](o,18,0)|0;if((ac|0)<1){$=1;i=e;return $|0}if((gzL(X,0,18)|0)==0){break}else{$=1}i=e;return $|0}}while(0);X=(c[3530382]|0)+458752|0;if((c[3542200]|0)==0){$=1;i=e;return $|0}aa=l+108|0;c[aa>>2]=0;ab=l+100|0;c[ab>>2]=0;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ac&16383](l,19)|0;do{if((c[aa>>2]|0)!=0){ac=c[ab>>2]|0;c[m>>2]=9534384;ae=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ae&16383](m,19,0)|0;if((ac|0)<1){$=1;i=e;return $|0}if((gzL(X,0,19)|0)==0){break}else{$=1}i=e;return $|0}}while(0);X=c[3530988]|0;if((c[3542200]|0)==0){$=1;i=e;return $|0}ab=j+108|0;c[ab>>2]=0;aa=j+100|0;c[aa>>2]=0;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ac&16383](j,20)|0;do{if((c[ab>>2]|0)!=0){ac=c[aa>>2]|0;c[k>>2]=9534384;ae=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ae&16383](k,20,0)|0;if((ac|0)<1){$=1;i=e;return $|0}if((gzL(X,0,20)|0)==0){break}else{$=1}i=e;return $|0}}while(0);X=(c[3530988]|0)+1024|0;if((c[3542200]|0)==0){$=1;i=e;return $|0}aa=f+108|0;c[aa>>2]=0;ab=f+100|0;c[ab>>2]=0;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ac&16383](f,21)|0;if((c[aa>>2]|0)==0){break}aa=c[ab>>2]|0;c[g>>2]=9534384;ab=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ab&16383](g,21,0)|0;if((aa|0)<1){$=1;i=e;return $|0}if((gzL(X,0,21)|0)==0){break}else{$=1}i=e;return $|0}}while(0);_=c[3530988]|0;X=c[2406906]|0;aa=c[3529892]|0;ab=0;while(1){ac=d[_+ab|0]|0;ae=(-(ac>>>1&1)&31)+(-(ac&1)&14)+(-(ac>>>2&1)&67)+(-(ac>>>3&1)&143)|0;af=(-(ac>>>5&1)&31)+(-(ac>>>7)&143)+(-(ac>>>4&1)&14)+(-(ac>>>6&1)&67)|0;ac=d[_+(ab+1024)|0]|0;ah=(-(ac>>>1&1)&31)+(-(ac&1)&14)+(-(ac>>>2&1)&67)+(-(ac>>>3&1)&143)|0;c[X+(ab<<2)>>2]=ae<<16|af<<8|ah;c[aa+(ab<<2)>>2]=ae<<8&63488|af<<3&2016|ah>>>3&31;ah=ab+1|0;if((ah|0)<768){ab=ah}else{ai=0;break}}while(1){if((ai|0)>=1024){break}aj=9638528+(ai<<2)|0;if((c[aj>>2]|0)==0){Z=31187;break}else{ai=ai+1|0}}L40186:do{if((Z|0)==31187){ab=gGq(524288)|0;c[aj>>2]=ab;if((ab|0)==0){break}gGz(ab|0,0,524288);aa=c[3530750]|0;gGC(ab|0,aa|0,32768)|0;X=0;do{_=X<<6;gGz(aa+_|0,0,64);ah=_+196608|0;af=0;do{ae=ah+(c[609008+(af<<2)>>2]|0)|0;ac=(af<<3)+_|0;ak=0;do{al=ae+(c[612640+(ak+8<<2)>>2]|0)|0;if((d[ab+((al|0)/8|0)|0]&128>>>((al&7)>>>0)|0)!=0){al=aa+(ac+ak)|0;a[al]=a[al]|4}ak=ak+1|0;}while((ak|0)<8);af=af+1|0;}while((af|0)<8);af=_+131072|0;ah=0;do{ak=af+(c[609008+(ah<<2)>>2]|0)|0;ac=(ah<<3)+_|0;ae=0;do{al=ak+(c[612640+(ae+8<<2)>>2]|0)|0;if((d[ab+((al|0)/8|0)|0]&128>>>((al&7)>>>0)|0)!=0){al=aa+(ac+ae)|0;a[al]=a[al]|2}ae=ae+1|0;}while((ae|0)<8);ah=ah+1|0;}while((ah|0)<8);ah=_+65536|0;af=0;do{ae=ah+(c[609008+(af<<2)>>2]|0)|0;ac=(af<<3)+_|0;ak=0;do{al=ae+(c[612640+(ak+8<<2)>>2]|0)|0;if((d[ab+((al|0)/8|0)|0]&128>>>((al&7)>>>0)|0)!=0){al=aa+(ac+ak)|0;a[al]=a[al]|1}ak=ak+1|0;}while((ak|0)<8);af=af+1|0;}while((af|0)<8);X=X+1|0;}while((X|0)<1024);X=c[3530514]|0;gGC(ab|0,X|0,524288)|0;aa=0;do{af=aa<<8;gGz(X+af|0,0,256);_=0;do{ah=1<<3-_;ak=(c[611200+(_<<2)>>2]|0)+af|0;ac=0;do{ae=ak+(c[609008+(ac<<2)>>2]|0)|0;al=(ac<<4)+af|0;am=0;do{an=ae+(c[612640+(am<<2)>>2]|0)|0;if((d[ab+((an|0)/8|0)|0]&128>>>((an&7)>>>0)|0)!=0){an=X+(al+am)|0;a[an]=(d[an]|ah)&255}am=am+1|0;}while((am|0)<16);ac=ac+1|0;}while((ac|0)<16);_=_+1|0;}while((_|0)<4);aa=aa+1|0;}while((aa|0)<2048);aa=c[3530382]|0;gGC(ab|0,aa|0,524288)|0;X=0;while(1){_=X<<8;gGz(aa+_|0,0,256);af=0;do{ac=1<<3-af;ah=(c[611200+(af<<2)>>2]|0)+_|0;ak=0;do{am=ah+(c[609008+(ak<<2)>>2]|0)|0;al=(ak<<4)+_|0;ae=0;do{an=am+(c[612640+(ae<<2)>>2]|0)|0;if((d[ab+((an|0)/8|0)|0]&128>>>((an&7)>>>0)|0)!=0){an=aa+(al+ae)|0;a[an]=(d[an]|ac)&255}ae=ae+1|0;}while((ae|0)<16);ak=ak+1|0;}while((ak|0)<16);af=af+1|0;}while((af|0)<4);af=X+1|0;if((af|0)<4096){X=af}else{ao=0;break}}while(1){if((ao|0)>=1024){break L40186}ap=9638528+(ao<<2)|0;if((c[ap>>2]|0)==(ab|0)){break}else{ao=ao+1|0}}gGr(ab);c[ap>>2]=0}}while(0);fxU(0,425984);if((c[2394]|0)==0){aq=c[2112932]|0}else{c[2394]=0;X=c[3532596]|0;c[2112932]=X;aa=c[3532592]|0;if((aa|0)!=0){gGC(9104152,aa|0,280)|0}c[2113054]=c[2113060];aq=X}X=c[2388074]|0;aa=aq|0;af=0;while(1){_=X+af|0;c[aa>>2]=_;c[aa+131072>>2]=_;_=af+1024|0;if(_>>>0>393215){break}else{aa=aa+4|0;af=_}}af=c[2388204]|0;c[aq+1536>>2]=af;c[aq+67072>>2]=af;c[aq+132608>>2]=af;aa=af+1024|0;c[aq+1540>>2]=aa;c[aq+67076>>2]=aa;c[aq+132612>>2]=aa;aa=af+2048|0;c[aq+1544>>2]=aa;c[aq+67080>>2]=aa;c[aq+132616>>2]=aa;aa=af+3072|0;c[aq+1548>>2]=aa;c[aq+67084>>2]=aa;c[aq+132620>>2]=aa;aa=af+4096|0;c[aq+1552>>2]=aa;c[aq+67088>>2]=aa;c[aq+132624>>2]=aa;aa=af+5120|0;c[aq+1556>>2]=aa;c[aq+67092>>2]=aa;c[aq+132628>>2]=aa;aa=af+6144|0;c[aq+1560>>2]=aa;c[aq+67096>>2]=aa;c[aq+132632>>2]=aa;aa=af+7168|0;c[aq+1564>>2]=aa;c[aq+67100>>2]=aa;c[aq+132636>>2]=aa;aa=af+8192|0;c[aq+1568>>2]=aa;c[aq+67104>>2]=aa;c[aq+132640>>2]=aa;aa=af+9216|0;c[aq+1572>>2]=aa;c[aq+67108>>2]=aa;c[aq+132644>>2]=aa;aa=af+10240|0;c[aq+1576>>2]=aa;c[aq+67112>>2]=aa;c[aq+132648>>2]=aa;aa=af+11264|0;c[aq+1580>>2]=aa;c[aq+67116>>2]=aa;c[aq+132652>>2]=aa;aa=af+12288|0;c[aq+1584>>2]=aa;c[aq+67120>>2]=aa;c[aq+132656>>2]=aa;aa=af+13312|0;c[aq+1588>>2]=aa;c[aq+67124>>2]=aa;c[aq+132660>>2]=aa;aa=af+14336|0;c[aq+1592>>2]=aa;c[aq+67128>>2]=aa;c[aq+132664>>2]=aa;aa=af+15360|0;c[aq+1596>>2]=aa;c[aq+67132>>2]=aa;c[aq+132668>>2]=aa;aa=c[2386380]|0;c[aq+2048>>2]=aa;c[aq+67584>>2]=aa;c[aq+133120>>2]=aa;af=aa+1024|0;c[aq+2052>>2]=af;c[aq+67588>>2]=af;c[aq+133124>>2]=af;af=aa+2048|0;c[aq+2056>>2]=af;c[aq+67592>>2]=af;c[aq+133128>>2]=af;af=aa+3072|0;c[aq+2060>>2]=af;c[aq+67596>>2]=af;c[aq+133132>>2]=af;af=c[2386186]|0;c[aq+2560>>2]=af;c[aq+68096>>2]=af;c[aq+133632>>2]=af;aa=af+1024|0;c[aq+2564>>2]=aa;c[aq+68100>>2]=aa;c[aq+133636>>2]=aa;c[aq+2568>>2]=af;c[aq+68104>>2]=af;c[aq+133640>>2]=af;c[aq+2572>>2]=aa;c[aq+68108>>2]=aa;c[aq+133644>>2]=aa;aa=c[2406288]|0;c[aq+68112>>2]=aa;c[aq+68116>>2]=aa+1024;c[aq+196728>>2]=2984;c[aq+196648>>2]=2914;c[aq+196688>>2]=2414;c[aq+196608>>2]=1348;aa=c[3532592]|0;if((aa|0)!=0){gGC(aa|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fvI();c[3528556]=0;aa=c[2433594]|0;c[2443776]=aa;L40266:do{if((aa|0)!=0){af=aa|0;gGC(9660952,af|0,52)|0;switch(a[9660952]|0){case 0:{c[2309668]=638960;break L40266;break};case 1:{c[2309668]=634096;break L40266;break};case 3:{c[2309668]=639984;break L40266;break};case 4:{c[2309668]=7356016;break L40266;break};case 5:{c[2309668]=7354992;break L40266;break};case 2:{c[2309668]=638960;break L40266;break};default:{break L40266}}}}while(0);af=c[2432850]|0;c[2113164]=af;X=c[3531212]|0;c[aa+68>>2]=X;c[aa+1092>>2]=X;c[aa+2116>>2]=X;_=X+256|0;c[aa+72>>2]=_;c[aa+1096>>2]=_;c[aa+2120>>2]=_;_=X+512|0;c[aa+76>>2]=_;c[aa+1100>>2]=_;c[aa+2124>>2]=_;_=X+768|0;c[aa+80>>2]=_;c[aa+1104>>2]=_;c[aa+2128>>2]=_;_=X+1024|0;c[aa+84>>2]=_;c[aa+1108>>2]=_;c[aa+2132>>2]=_;_=X+1280|0;c[aa+88>>2]=_;c[aa+1112>>2]=_;c[aa+2136>>2]=_;_=c[3531202]|0;X=128;ak=128;while(1){ac=_+(ak<<8)|0;c[aa+68+(ak<<2)>>2]=ac;c[aa+68+(ak+512<<2)>>2]=ac;ac=X+1&65535;if((ac&65535)>255){break}else{X=ac;ak=ac&65535}}c[aa+3148>>2]=1020;c[aa+3152>>2]=2392;ak=aa|0;gGC(ak|0,9660952,52)|0;c[2432850]=af;c[2443776]=0;c[3528556]=-1;U6(3e6,2046,2300,0);c[2438222]=15e5;c[2433520]=2448;c[2406670]=2016;c[3528466]=6844;c[2443840]=1364;h[745399]=1.0;a[3203272]=1;Vr(1,15e5,0,3068,122,1);c[2438228]=1e7;c[2433526]=3248;c[2406676]=148;c[3528472]=444;c[2443846]=203;h[745419]=.25;a[3203368]=1;h[745418]=.25;a[3203360]=1;h[745417]=.25;a[3203352]=1;h[745416]=.25;a[3203344]=1;ak=c[642608+(c[2436]<<2)>>2]|0;X=c[ak+128>>2]|0;if((c[ak+52>>2]&4|0)==0){c[2113068]=X;_=c[ak+132>>2]|0;c[2113070]=_;c[2443814]=X;c[2440436]=_;ar=X;as=_}else{c[2113070]=X;_=c[ak+132>>2]|0;c[2113068]=_;c[2440436]=X;c[2443814]=_;ar=_;as=X}X=ag(ar<<1,as)|0;_=gGq(X)|0;c[2112926]=_;if((_|0)!=0){gGz(_|0,0,X|0)}a[9623392]=0;X=c[2414554]|0;gGz(X|0,0,(c[2411454]|0)-X|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];X=c[3532592]|0;if((X|0)!=0){gGC(9104152,X|0,280)|0}c[2113054]=c[2113060]}RI();X=c[2394]|0;_=c[14130368+(X<<2)>>2]|0;if((_|0)!=0){gGC(_|0,9104152,280)|0}c[8452240+(X<<2)>>2]=c[2113054];c[2394]=-1;c[3528556]=0;X=c[2433594]|0;c[2443776]=X;L40295:do{if((X|0)!=0){_=X|0;gGC(9660952,_|0,52)|0;switch(a[9660952]|0){case 3:{c[2309668]=639984;break L40295;break};case 4:{c[2309668]=7356016;break L40295;break};case 5:{c[2309668]=7354992;break L40295;break};case 2:{c[2309668]=638960;break L40295;break};case 0:{c[2309668]=638960;break L40295;break};case 1:{c[2309668]=634096;break L40295;break};default:{break L40295}}}}while(0);c[2113164]=c[2432850];gu[c[X+56>>2]&16383]();af=c[2443776]|0;if((af|0)!=0){aa=af|0;gGC(aa|0,9660952,52)|0}c[9731400+(c[3528556]<<2)>>2]=c[2113164];c[2443776]=0;c[3528556]=-1;c[2443825]=1073676288;c[2443824]=1073676288;c[2443817]=1073676288;c[2443816]=1073676288;h[883199]=0.0;c[3528506]=0;lw(c[3540986]|0);c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){aa=0;do{lN(aa);mB(aa);aa=aa+1|0;}while((aa|0)<(c[2385508]|0))}b[4881208]=0;b[4867336]=0;b[4860032]=0;b[4859268]=0;c[2444192]=0;$=0;i=e;return $|0}}while(0);c[2414852]=0;$=1;i=e;return $|0}function aIt(a,b){a=a|0;b=b|0;a=c[(c[2443776]|0)+64>>2]|0;if((b|0)==0){gg[a&4095](0,0);return}else{gg[a&4095](0,1);return}}function aIu(a){a=a|0;var b=0,d=0;b=c[2113164]|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,15e5,0)|0;return a|0}function aIv(a){a=a|0;var b=0,d=0;b=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,1e7,0)|0;return a|0}function aIw(){return+(+((c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0)/1.0e7)}function aIx(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=(g|0)!=0;g=c[2112926]|0;i=c[3530382]|0;if((f|0)==0){if(h){SJ(g,a,b,d,e,4,0,256,i);return}else{SH(g,a,b,d,e,4,0,256,i);return}}else{if(h){SN(g,a,b,d,e,4,0,256,i);return}else{SL(g,a,b,d,e,4,0,256,i);return}}}function aIy(a,d){a=a|0;d=d|0;var e=0;e=a&16777200;if((e|0)==1310720){Uv(0,d&255);return}else if((e|0)==1441792){Uv(1,d&255);return}else{if((a&-16|0)==1447936){b[(c[2383434]|0)+((a>>>1&7)<<1)>>1]=d;return}if((e|0)!=1460224){return}e=(c[3529744]|0)+1048576|0;a=(c[3529700]|0)+((d&65535)<<18&786432)|0;gGC(e|0,a|0,262144)|0;return}}function aIz(a,d){a=a|0;d=d|0;var e=0;e=a&16777200;if((e|0)==1310720){Uv(0,d);return}else if((e|0)==1441792){Uv(1,d);return}else{if((a&-16|0)==1447936){b[(c[2383434]|0)+((a>>>1&7)<<1)>>1]=d&255;return}if((e|0)!=1460224){return}e=(c[3529744]|0)+1048576|0;a=(c[3529700]|0)+((d&255)<<18&786432)|0;gGC(e|0,a|0,262144)|0;return}}function aIA(a){a=a|0;var e=0;if((a|0)==1473612){e=(d[9634665]|0)<<8|(d[9634664]|0)}else if((a|0)==1310726){e=c[2113156]&65535}else if((a|0)==1473970){e=(b[4775072]&65527|c[2383408]&8)&65535}else if((a|0)==1472578){e=b[4775073]|0}else if((a|0)==1376262){e=c[2113157]&65535}else if((a|0)==1473818){e=b[(c[3529852]|0)+2>>1]|0}else if((a|0)==1473808){e=b[c[3529852]>>1]|0}else{e=0}return e|0}function aIB(d){d=d|0;var f=0;if((d|0)==1310726|(d|0)==1310727){f=c[2113156]&255}else if((d|0)==1473818|(d|0)==1473819){f=a[(c[3529852]|0)+(d&1^3)|0]|0}else if((d|0)==1376262|(d|0)==1376263){f=c[2113157]&255}else if((d|0)==1473612){f=a[9634665]|0}else if((d|0)==1473808|(d|0)==1473809){f=a[(c[3529852]|0)+(d&1^1)|0]|0}else if((d|0)==1472578){f=(e[4775073]|0)>>>8&255}else if((d|0)==1473970|(d|0)==1473971){f=(b[4775072]&247|c[2383408]&8)&255}else if((d|0)==1472579){f=b[4775073]&255}else if((d|0)==1473613){f=a[9634664]|0}else{f=0}return f|0}function aIC(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>5){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2454132+(b*112|0)>>2];c[a+104>>2]=c[2454136+(b*112|0)>>2];c[a+108>>2]=c[2454140+(b*112|0)>>2];d=0;return d|0}function aID(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<6&(d|0)==0)){e=1;return e|0}c[a>>2]=2454032+(b*112|0);e=0;return e|0}function aIE(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1215744+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aIF(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>41){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3619400+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aIG(){var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=i;i=i+480|0;e=d|0;f=d+112|0;g=d+120|0;h=d+232|0;j=d+240|0;k=d+352|0;l=d+360|0;m=d+472|0;c[2424]=5800;c[2414850]=0;c[2388072]=0;c[3531184]=524288;c[3530748]=1048576;c[3530512]=3145728;c[3530380]=5242880;c[3541206]=7340032;c[3529744]=7340032;c[3529700]=8650752;c[3529890]=9699328;c[2414552]=9703424;c[2388202]=9703424;c[2386378]=9768960;c[2387098]=9771008;c[3529852]=9775104;c[3528648]=9777152;c[2411452]=9777153;n=0;while(1){if((n|0)>=1024){break}o=9638528+(n<<2)|0;if((c[o>>2]|0)==0){p=31441;break}else{n=n+1|0}}do{if((p|0)==31441){n=gGq(9777153)|0;c[o>>2]=n;if((n|0)==0){break}c[2414850]=n;gGz(n|0,0,9777153);c[2388072]=n;c[3531184]=n+524288;c[3530748]=n+1048576;c[3530512]=n+3145728;c[3530380]=n+5242880;q=n+7340032|0;c[3541206]=q;c[3529744]=q;c[3529700]=n+8650752;c[3529890]=n+9699328;q=n+9703424|0;c[2414552]=q;c[2388202]=q;c[2386378]=n+9768960;c[2387098]=n+9771008;c[3529852]=n+9775104;c[3528648]=n+9777152;q=n+9777153|0;c[2411452]=q;c[2413992]=q;if((c[3542200]|0)==0){r=1;i=d;return r|0}q=l+108|0;c[q>>2]=0;s=l+100|0;c[s>>2]=0;t=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[t&16383](l,0)|0;do{if((c[q>>2]|0)!=0){t=c[s>>2]|0;c[m>>2]=9534384;u=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[u&16383](m,0,0)|0;if((t|0)<1){r=1;i=d;return r|0}if((gzL(n,0,0)|0)==0){break}else{r=1}i=d;return r|0}}while(0);n=c[3530512]|0;if((c[3542200]|0)==0){r=1;i=d;return r|0}s=j+108|0;c[s>>2]=0;q=j+100|0;c[q>>2]=0;t=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[t&16383](j,1)|0;do{if((c[s>>2]|0)!=0){t=c[q>>2]|0;c[k>>2]=9534384;u=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[u&16383](k,1,0)|0;if((t|0)<1){r=1;i=d;return r|0}if((gzL(n,0,1)|0)==0){break}else{r=1}i=d;return r|0}}while(0);if((R6(c[3530380]|0,2,2)|0)!=0){r=1;i=d;return r|0}if((R6((c[3530380]|0)+1|0,3,2)|0)!=0){r=1;i=d;return r|0}n=c[3529744]|0;if((c[3542200]|0)==0){r=1;i=d;return r|0}q=g+108|0;c[q>>2]=0;s=g+100|0;c[s>>2]=0;t=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[t&16383](g,4)|0;do{if((c[q>>2]|0)!=0){t=c[s>>2]|0;c[h>>2]=9534384;u=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[u&16383](h,4,0)|0;if((t|0)<1){r=1;i=d;return r|0}if((gzL(n,0,4)|0)==0){break}else{r=1}i=d;return r|0}}while(0);n=c[3529700]|0;if((c[3542200]|0)==0){r=1;i=d;return r|0}s=e+108|0;c[s>>2]=0;q=e+100|0;c[q>>2]=0;t=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[t&16383](e,5)|0;do{if((c[s>>2]|0)!=0){t=c[q>>2]|0;c[f>>2]=9534384;u=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[u&16383](f,5,0)|0;if((t|0)<1){r=1;i=d;return r|0}if((gzL(n,0,5)|0)==0){break}else{r=1}i=d;return r|0}}while(0);aFh(c[2388072]|0,c[3531184]|0,524288,17082,0,0);aFg(c[3530512]|0,1048576,1574056,720536,1110256);aE_(c[3530512]|0,c[3530748]|0,1048576,1);n=c[3530512]|0;aE_(n,n,1048576,0);aE$(c[3530380]|0,1048576);aE1(1,0,1);n=c[3530512]|0;c[2383440]=c[3530748];c[2383441]=n;c[2383442]=0;c[2383436]=32767;c[2383437]=8191;c[2383438]=0;a[690376]=1;c[2429437]=2136;fxU(0,425984);if((c[2394]|0)==0){v=c[2112932]|0}else{c[2394]=0;n=c[3532596]|0;c[2112932]=n;q=c[3532592]|0;if((q|0)!=0){gGC(9104152,q|0,280)|0}c[2113054]=c[2113060];v=n}n=c[2388072]|0;q=v|0;s=q;t=0;while(1){c[s>>2]=n+t;u=t+1024|0;if(u>>>0>524287){break}else{s=s+4|0;t=u}}t=c[3531184]|0;s=q;n=0;while(1){c[s+131072>>2]=t+n;u=n+1024|0;if(u>>>0>524287){break}else{s=s+4|0;n=u}}n=c[2383430]|0;c[v+4096>>2]=n;c[v+69632>>2]=n;c[v+135168>>2]=n;s=n+1024|0;c[v+4100>>2]=s;c[v+69636>>2]=s;c[v+135172>>2]=s;s=n+2048|0;c[v+4104>>2]=s;c[v+69640>>2]=s;c[v+135176>>2]=s;s=n+3072|0;c[v+4108>>2]=s;c[v+69644>>2]=s;c[v+135180>>2]=s;s=c[2383431]|0;c[v+4128>>2]=s;c[v+69664>>2]=s;c[v+135200>>2]=s;n=s+1024|0;c[v+4132>>2]=n;c[v+69668>>2]=n;c[v+135204>>2]=n;n=s+2048|0;c[v+4136>>2]=n;c[v+69672>>2]=n;c[v+135208>>2]=n;n=s+3072|0;c[v+4140>>2]=n;c[v+69676>>2]=n;c[v+135212>>2]=n;n=c[2383428]|0;c[v+4352>>2]=n;c[v+69888>>2]=n;c[v+135424>>2]=n;s=n+1024|0;c[v+4356>>2]=s;c[v+69892>>2]=s;c[v+135428>>2]=s;s=c[2383426]|0;c[v+4384>>2]=s;c[v+69920>>2]=s;c[v+135456>>2]=s;n=s+1024|0;c[v+4388>>2]=n;c[v+69924>>2]=n;c[v+135460>>2]=n;n=c[2386378]|0;c[v+4608>>2]=n;c[v+70144>>2]=n;c[v+135680>>2]=n;s=n+1024|0;c[v+4612>>2]=s;c[v+70148>>2]=s;c[v+135684>>2]=s;s=c[2387098]|0;c[v+4864>>2]=s;c[v+70400>>2]=s;c[v+135936>>2]=s;n=s+1024|0;c[v+4868>>2]=n;c[v+70404>>2]=n;c[v+135940>>2]=n;n=s+2048|0;c[v+4872>>2]=n;c[v+70408>>2]=n;c[v+135944>>2]=n;n=s+3072|0;c[v+4876>>2]=n;c[v+70412>>2]=n;c[v+135948>>2]=n;n=c[3529852]|0;c[v+71288>>2]=n;c[v+71292>>2]=n+1024;n=c[2388202]|0;s=v+5888|0;t=1507328;while(1){q=n+(t-1507328)|0;c[s>>2]=q;c[s+65536>>2]=q;c[s+131072>>2]=q;q=t+1024|0;if(q>>>0>1572863){break}else{s=s+4|0;t=q}}c[v+196728>>2]=716;c[v+196648>>2]=2974;c[v+196688>>2]=2476;c[v+196608>>2]=2116;t=c[3532592]|0;if((t|0)!=0){gGC(t|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;Ux(0,7627,1);Ux(1,15255,1);c[2407030]=192;c[2407068]=3;c[2407069]=154;c[2407107]=3;t=c[642608+(c[2436]<<2)>>2]|0;s=c[t+128>>2]|0;if((c[t+52>>2]&4|0)==0){c[2113068]=s;n=c[t+132>>2]|0;c[2113070]=n;c[2443814]=s;c[2440436]=n;w=s;x=n}else{c[2113070]=s;n=c[t+132>>2]|0;c[2113068]=n;c[2440436]=s;c[2443814]=n;w=n;x=s}s=ag(w<<1,x)|0;n=gGq(s)|0;c[2112926]=n;if((n|0)!=0){gGz(n|0,0,s|0)}s=c[2414552]|0;gGz(s|0,0,(c[2411452]|0)-s|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];s=c[3532592]|0;if((s|0)!=0){gGC(9104152,s|0,280)|0}c[2113054]=c[2113060]}RI();s=c[2394]|0;n=c[14130368+(s<<2)>>2]|0;if((n|0)!=0){gGC(n|0,9104152,280)|0}c[8452240+(s<<2)>>2]=c[2113054];c[2394]=-1;c[2113156]=0;a[9628264]=0;c[2407033]=0;s=c[3541206]|0;c[3541190]=s;c[3541198]=s;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=s+256;c[3541199]=s+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=s+512;c[3541200]=s+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=s+768;c[3541201]=s+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2113157]=0;a[9628420]=0;c[2407072]=0;n=s+1048576|0;c[3541194]=n;c[3541202]=n;gGz(c[2430122]|0,0,16384);c[2407080]=4;c[3541195]=s+1048832;c[3541203]=s+1114112;gGz(c[2430123]|0,0,16384);c[2407088]=4;c[3541196]=s+1049088;c[3541204]=s+1179648;gGz(c[2430124]|0,0,16384);c[2407096]=4;c[3541197]=s+1049344;c[3541205]=s+1245184;gGz(c[2430125]|0,0,16384);c[2407104]=4;gGz(c[2383428]|0,0,4096);gGz(c[2383426]|0,0,4096);s=c[2383424]|0;if((s|0)!=0){gGz(s|0,0,4096);gGz(c[2383422]|0,0,4096)}gGz(c[2383434]|0,0,16);gGz(c[2383435]|0,0,16);gGz(c[2383430]|0,0,8192);gGz(c[2383431]|0,0,8192);s=c[2383432]|0;if((s|0)!=0){gGz(s|0,0,8192);gGz(c[2383433]|0,0,8192)}b[4766836]=0;c[2426968]=0;c[3528794]=0;c[1765522]=65535;c[2429656]=0;c[2427042]=0;c[2429386]=0;c[2429384]=0;c[2429382]=0;r=0;i=d;return r|0}}while(0);c[2414850]=0;r=1;i=d;return r|0}function aIH(){var a=0,b=0,d=0,e=0,f=0;c[2113070]=0;c[2113068]=0;a=c[2112926]|0;if((a|0)!=0){gGr(a);c[2112926]=0}aE2();Uw(0);Uw(1);if((c[2392]|0)>=0){a=0;do{b=14130368+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}b=14130384+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}a=a+1|0;}while((a|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;a=c[2414850]|0;b=0;while(1){if((b|0)>=1024){e=31520;break}f=9638528+(b<<2)|0;if((c[f>>2]|0)==(a|0)){break}else{b=b+1|0}}if((e|0)==31520){c[2414850]=0;c[3541206]=0;return 0}gGr(a);c[f>>2]=0;c[2414850]=0;c[3541206]=0;return 0}function aII(){var d=0,e=0,f=0,g=0;if((a[9623384]|0)!=0){d=c[2414552]|0;gGz(d|0,0,(c[2411452]|0)-d|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;c[2113156]=0;a[9628264]=0;c[2407033]=0;d=c[3541206]|0;c[3541190]=d;c[3541198]=d;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=d+256;c[3541199]=d+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=d+512;c[3541200]=d+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=d+768;c[3541201]=d+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2113157]=0;a[9628420]=0;c[2407072]=0;e=d+1048576|0;c[3541194]=e;c[3541202]=e;gGz(c[2430122]|0,0,16384);c[2407080]=4;c[3541195]=d+1048832;c[3541203]=d+1114112;gGz(c[2430123]|0,0,16384);c[2407088]=4;c[3541196]=d+1049088;c[3541204]=d+1179648;gGz(c[2430124]|0,0,16384);c[2407096]=4;c[3541197]=d+1049344;c[3541205]=d+1245184;gGz(c[2430125]|0,0,16384);c[2407104]=4;gGz(c[2383428]|0,0,4096);gGz(c[2383426]|0,0,4096);d=c[2383424]|0;if((d|0)!=0){gGz(d|0,0,4096);gGz(c[2383422]|0,0,4096)}gGz(c[2383434]|0,0,16);gGz(c[2383435]|0,0,16);gGz(c[2383430]|0,0,8192);gGz(c[2383431]|0,0,8192);d=c[2383432]|0;if((d|0)!=0){gGz(d|0,0,8192);gGz(c[2383433]|0,0,8192)}b[4766836]=0;c[2426968]=0;c[3528794]=0;c[1765522]=65535;c[2429656]=0;c[2427042]=0;c[2429386]=0;c[2429384]=0;c[2429382]=0}c[2387536]=-1;d=0;e=-1;f=-1;do{e=((a[9632360+d|0]&1)<<d^e&65535)&65535;f=((a[9630272+d|0]&1)<<d^f&65535)&65535;d=d+1|0;}while((d|0)<16);b[4775072]=e;b[4775073]=f;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060]}c[2383408]=0;f=0;while(1){c[2113056]=942;e=RG(942)|0;c[2113054]=(c[2113054]|0)+e;c[2276108]=-1;c[2113056]=-1;if((f|0)==240){c[2383408]=8;f=241;continue}else{e=f+1|0;if((e|0)<256){f=e;continue}else{break}}}f=c[2394]|0;c[8452200+(f<<2)>>2]=8198;c[2276080]=1536;if((c[2276079]|0)>>>0<1536){RH(6);g=c[2394]|0}else{g=f}f=c[14130368+(g<<2)>>2]|0;if((f|0)!=0){gGC(f|0,9104152,280)|0}c[8452240+(g<<2)>>2]=c[2113054];c[2394]=-1;g=c[2112964]|0;if((g|0)!=0){f=a[9688]|0;gGz(g|0,0,(f?2136:0)|0);e=f?534:0;Uu(1,g,e);Uu(0,g,e)}if((c[2112968]|0)==0){return 0}aIJ()|0;return 0}function aIJ(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;d=c[3529890]|0;f=c[2387098]|0;g=(c[642608+(c[2436]<<2)>>2]|0)+124|0;if((c[g>>2]<<1|0)>0){h=0;do{i=e[f+((h|1)<<1)>>1]|0;c[d+(((h|0)/2|0)<<2)>>2]=i<<8&63488|(e[f+(h<<1)>>1]|0)>>>3&31|i>>>8<<3&2016;h=h+2|0;}while((h|0)<(c[g>>2]<<1|0))}a[9547064]=0;aE3();g=ag(c[2113070]|0,c[2113068]|0)|0;h=c[2112926]|0;if((g|0)>0){f=0;while(1){b[h+(f<<1)>>1]=0;d=f+1|0;if((d|0)<(g|0)){f=d}else{j=h;break}}}else{j=h}aE0(1,j,0);h=c[2386378]|0;f=c[3528648]|0;g=c[3530380]|0;d=(c[2113222]&1|0)==0;i=0;do{k=b[h+((i|1)<<1)>>1]|0;l=k&65535;do{if(k<<16>>16!=0){m=e[h+(i<<1)>>1]|0;if(!((m&4096|0)==0|d)){break}n=e[h+((i|2)<<1)>>1]|0;o=n>>>9&31;p=m&8192;q=m&16384;r=1<<(m>>>9&3);s=r-1|0;t=n&511;u=m&511;v=t>>>0>319?n|-512:t;t=u>>>0>255?m|-512:u;u=304-v|0;if((u|0)>320){break}m=(q>>>13^2)-1|0;n=((q|0)!=0?0:s)+(l&-r)|0;if((a[f]|0)==0){w=q>>>14^1;x=p>>>13^1;y=v;z=t;A=16}else{w=q;x=p;y=u;z=240-t|0;A=-16}if((r|0)<=0){break}r=(x|0)!=0;t=z-8|0;if((w|0)==0){if(r){u=s;while(1){p=ag(u,A)|0;SJ(j,n-(ag(u,m)|0)|0,y,p+t|0,o,4,0,512,g);if((u|0)>0){u=u-1|0}else{break}}}else{u=s;while(1){p=ag(u,A)|0;SH(j,n-(ag(u,m)|0)|0,y,p+t|0,o,4,0,512,g);if((u|0)>0){u=u-1|0}else{break}}}}else{if(r){u=s;while(1){p=n-(ag(u,m)|0)|0;SN(j,p,y,(ag(u,A)|0)+t|0,o,4,0,512,g);if((u|0)>0){u=u-1|0}else{break}}}else{u=s;while(1){r=n-(ag(u,m)|0)|0;SL(j,r,y,(ag(u,A)|0)+t|0,o,4,0,512,g);if((u|0)>0){u=u-1|0}else{break}}}}}}while(0);i=i+4|0;}while((i|0)<1024);aE0(0,j,0);R8(c[3529890]|0);return 0}function aIK(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=i;i=i+64|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;if((d|0)!=0){c[d>>2]=169602}if((b&32|0)!=0){gGz(j|0,0,12);d=c[2414552]|0;c[j>>2]=d;c[j+4>>2]=(c[2411452]|0)-d;c[j+12>>2]=162152;d=c[2076592]|0;gj[d&4095](j)|0}if((b&64|0)==0){i=e;return 0}b=h|0;gGz(g|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){j=h+9|0;h=f;d=f|0;k=f+4|0;l=f+12|0;m=g|0;n=g+4|0;o=g+12|0;p=0;do{gGC(b|0,614896,11)|0;a[j]=p+48&255;q=8452256+(p<<2)|0;gGz(h|0,0,12);c[d>>2]=q;c[k>>2]=4;c[l>>2]=164976;gj[c[2076592]&4095](f)|0;if((c[q>>2]|0)!=0){c[m>>2]=c[14130368+(p<<2)>>2];c[n>>2]=c[8452184+(p<<2)>>2];c[o>>2]=b;q=c[2076592]|0;gj[q&4095](g)|0}p=p+1|0;}while((p|0)<=(c[2392]|0))}aE6();Ut(0);Ut(1);i=e;return 0}function aIL(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>5){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1439700+(b*112|0)>>2];c[a+104>>2]=c[1439704+(b*112|0)>>2];c[a+108>>2]=c[1439708+(b*112|0)>>2];d=0;return d|0}function aIM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<6&(d|0)==0)){e=1;return e|0}c[a>>2]=1439600+(b*112|0);e=0;return e|0}function aIN(a){a=a|0;return a>>>4<<12&28672|0}function aIO(d,e){d=d|0;e=e|0;var f=0;f=d&-16;if((f|0)==2228224){b[(c[2383434]|0)+((d>>>1&7)<<1)>>1]=e;return}else if((f|0)==2490368){b[(c[2383435]|0)+((d>>>1&7)<<1)>>1]=e;return}else{if((d|0)==1572864){c[2383412]=e&255;if((a[9661085]|0)==1){return}a[9661085]=1;if((a[9661088]|0)!=0){return}a[9661088]=2;return}else if((d|0)==1835020|(d|0)==1835021){d=c[3529674]|0;e=c[3529626]|0;gGC(d|0,e|0,4096)|0;return}else{return}}}function aIP(d,e){d=d|0;e=e|0;if((d|0)==1572865){c[2383412]=e&255;if((a[9661085]|0)==1){return}a[9661085]=1;if((a[9661088]|0)!=0){return}a[9661088]=2;return}else if((d|0)==1835019){b[4766836]=e&255;return}else if((d|0)==1835020|(d|0)==1835021){d=c[3529674]|0;e=c[3529626]|0;gGC(d|0,e|0,4096)|0;return}else{return}}function aIQ(a){a=a|0;var e=0;switch(a|0){case 1835014:{e=d[9634657]|0;break};case 1835010:{e=b[4775069]|0;break};case 1835008:{e=b[4775068]|0;break};case 1835018:case 1835020:case 1835022:{e=-1;break};case 1835012:{e=d[9634656]|0;break};case 1835016:{e=(b[4775070]&247|c[2383408]&8)&65535;break};default:{e=0}}return e|0}function aIR(d){d=d|0;var f=0;switch(d|0){case 1835014:case 1835015:{f=a[9634657]|0;break};case 1835010:{f=(e[4775069]|0)>>>8&255;break};case 1835008:{f=(e[4775068]|0)>>>8&255;break};case 1835018:case 1835019:case 1835020:case 1835021:case 1835022:case 1835023:{f=-1;break};case 1835016:case 1835017:{f=(b[4775070]&247|c[2383408]&8)&255;break};case 1835011:{f=b[4775069]&255;break};case 1835009:{f=b[4775068]&255;break};case 1835012:case 1835013:{f=a[9634656]|0;break};default:{f=0}}return f|0}function aIS(a){a=a|0;var b=0;if((a-1048580|0)>>>0>=2){b=0;return b|0}b=((c[2383408]|0)!=0)<<31>>31;return b|0}function aIT(a){a=a|0;var b=0;if((a-1048580|0)>>>0>=2){b=0;return b|0}b=((c[2383408]|0)!=0)<<31>>31;return b|0}function aIU(a,b){a=a|0;b=b|0;if((a-1048576|0)>>>0>=2){return}a=c[3529686]|0;b=c[3529648]|0;gGC(a|0,b|0,4096)|0;return}function aIV(a,b){a=a|0;b=b|0;if((a-1048576|0)>>>0>=2){return}a=c[3529686]|0;b=c[3529648]|0;gGC(a|0,b|0,4096)|0;return}function aIW(a,d){a=a|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;do{if((a&268435452|0)==4190204){e=c[2394]|0;if((a&2|0)==0){if((e|0)==0){c[2113050]=4101;c[2276080]=1280;if((c[2276079]|0)>>>0>=1280){break}RH(5);break}f=c[14130368+(e<<2)>>2]|0;if((f|0)!=0){gGC(f|0,9104152,280)|0}c[8452240+(e<<2)>>2]=c[2113054];c[2394]=0;c[2112932]=c[3532596];f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];c[2113050]=4101;c[2276080]=1280;if((c[2276079]|0)>>>0<1280){RH(5);g=c[2394]|0;h=g;i=c[14130368+(g<<2)>>2]|0}else{h=0;i=f}if((i|0)!=0){gGC(i|0,9104152,280)|0}c[8452240+(h<<2)>>2]=c[2113054];c[2394]=1;c[2112932]=c[3532597];f=c[3532593]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113061];break}else{if((e|0)==1){c[2113051]=4102;c[2276080]=1536;if((c[2276079]|0)>>>0>=1536){break}RH(6);break}f=c[14130368+(e<<2)>>2]|0;if((f|0)!=0){gGC(f|0,9104152,280)|0}c[8452240+(e<<2)>>2]=c[2113054];c[2394]=1;c[2112932]=c[3532597];e=c[3532593]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113061];c[2113051]=4102;c[2276080]=1536;if((c[2276079]|0)>>>0<1536){RH(6);f=c[2394]|0;j=f;k=c[14130368+(f<<2)>>2]|0}else{j=1;k=e}if((k|0)!=0){gGC(k|0,9104152,280)|0}c[8452240+(j<<2)>>2]=c[2113054];c[2394]=0;c[2112932]=c[3532596];e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060];break}}}while(0);b[(c[3527324]|0)+(a&4094)>>1]=d;return}function aIX(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;do{if((b&268435452|0)==4190204){e=c[2394]|0;if((b&2|0)==0){if((e|0)==0){c[2113050]=4101;c[2276080]=1280;if((c[2276079]|0)>>>0>=1280){break}RH(5);break}f=c[14130368+(e<<2)>>2]|0;if((f|0)!=0){gGC(f|0,9104152,280)|0}c[8452240+(e<<2)>>2]=c[2113054];c[2394]=0;c[2112932]=c[3532596];f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];c[2113050]=4101;c[2276080]=1280;if((c[2276079]|0)>>>0<1280){RH(5);g=c[2394]|0;h=g;i=c[14130368+(g<<2)>>2]|0}else{h=0;i=f}if((i|0)!=0){gGC(i|0,9104152,280)|0}c[8452240+(h<<2)>>2]=c[2113054];c[2394]=1;c[2112932]=c[3532597];f=c[3532593]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113061];break}else{if((e|0)==1){c[2113051]=4102;c[2276080]=1536;if((c[2276079]|0)>>>0>=1536){break}RH(6);break}f=c[14130368+(e<<2)>>2]|0;if((f|0)!=0){gGC(f|0,9104152,280)|0}c[8452240+(e<<2)>>2]=c[2113054];c[2394]=1;c[2112932]=c[3532597];e=c[3532593]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113061];c[2113051]=4102;c[2276080]=1536;if((c[2276079]|0)>>>0<1536){RH(6);f=c[2394]|0;j=f;k=c[14130368+(f<<2)>>2]|0}else{j=1;k=e}if((k|0)!=0){gGC(k|0,9104152,280)|0}c[8452240+(j<<2)>>2]=c[2113054];c[2394]=0;c[2112932]=c[3532596];e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060];break}}}while(0);a[(c[3527324]|0)+(b&4095^1)|0]=d;return}function aIY(a){a=a|0;var d=0,e=0,f=0,g=0,h=0;do{if((a&268435452|0)==4190204){d=c[2394]|0;if((a&2|0)==0){if((d|0)==0){c[2113050]=0;c[2276080]=0;break}e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=0;c[2112932]=c[3532596];e=c[3532592]|0;if((e|0)==0){f=c[2113060]|0;c[2113054]=f;c[2113050]=0;c[2276080]=0;g=f}else{gGC(9104152,e|0,280)|0;f=c[2113060]|0;c[2113054]=f;c[2113050]=0;c[2276080]=0;gGC(e|0,9104152,280)|0;g=f}c[2113060]=g;c[2394]=1;c[2112932]=c[3532597];f=c[3532593]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113061];break}else{if((d|0)==1){c[2113051]=0;c[2276080]=0;break}f=c[14130368+(d<<2)>>2]|0;if((f|0)!=0){gGC(f|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=1;c[2112932]=c[3532597];d=c[3532593]|0;if((d|0)==0){f=c[2113061]|0;c[2113054]=f;c[2113051]=0;c[2276080]=0;h=f}else{gGC(9104152,d|0,280)|0;f=c[2113061]|0;c[2113054]=f;c[2113051]=0;c[2276080]=0;gGC(d|0,9104152,280)|0;h=f}c[2113061]=h;c[2394]=0;c[2112932]=c[3532596];f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];break}}}while(0);return b[(c[3527324]|0)+(a&4094)>>1]|0}function aIZ(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;do{if((c[2276056]|0)==4428){if((a[c[3527324]|0]|0)>=0){break}if((b&-2|0)!=4186112){break}c[2226884]=(c[2226884]|0)-(c[2276108]|0);c[2276108]=0}}while(0);if((b&268435452|0)!=4190204){d=b&4095;e=d^1;f=c[3527324]|0;g=f+e|0;h=a[g]|0;return h|0}i=c[2394]|0;if((b&2|0)==0){if((i|0)==0){c[2113050]=0;c[2276080]=0;d=b&4095;e=d^1;f=c[3527324]|0;g=f+e|0;h=a[g]|0;return h|0}j=c[14130368+(i<<2)>>2]|0;if((j|0)!=0){gGC(j|0,9104152,280)|0}c[8452240+(i<<2)>>2]=c[2113054];c[2394]=0;c[2112932]=c[3532596];j=c[3532592]|0;if((j|0)==0){k=c[2113060]|0;c[2113054]=k;c[2113050]=0;c[2276080]=0;l=k}else{gGC(9104152,j|0,280)|0;k=c[2113060]|0;c[2113054]=k;c[2113050]=0;c[2276080]=0;gGC(j|0,9104152,280)|0;l=k}c[2113060]=l;c[2394]=1;c[2112932]=c[3532597];l=c[3532593]|0;if((l|0)!=0){gGC(9104152,l|0,280)|0}c[2113054]=c[2113061];d=b&4095;e=d^1;f=c[3527324]|0;g=f+e|0;h=a[g]|0;return h|0}else{if((i|0)==1){c[2113051]=0;c[2276080]=0;d=b&4095;e=d^1;f=c[3527324]|0;g=f+e|0;h=a[g]|0;return h|0}l=c[14130368+(i<<2)>>2]|0;if((l|0)!=0){gGC(l|0,9104152,280)|0}c[8452240+(i<<2)>>2]=c[2113054];c[2394]=1;c[2112932]=c[3532597];i=c[3532593]|0;if((i|0)==0){l=c[2113061]|0;c[2113054]=l;c[2113051]=0;c[2276080]=0;m=l}else{gGC(9104152,i|0,280)|0;l=c[2113061]|0;c[2113054]=l;c[2113051]=0;c[2276080]=0;gGC(i|0,9104152,280)|0;m=l}c[2113061]=m;c[2394]=0;c[2112932]=c[3532596];m=c[3532592]|0;if((m|0)!=0){gGC(9104152,m|0,280)|0}c[2113054]=c[2113060];d=b&4095;e=d^1;f=c[3527324]|0;g=f+e|0;h=a[g]|0;return h|0}return 0}function aI_(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>37){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2155932+(b*112|0)>>2];c[a+104>>2]=c[2155936+(b*112|0)>>2];c[a+108>>2]=c[2155940+(b*112|0)>>2];d=0;return d|0}function aI$(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<38&(d|0)==0)){e=1;return e|0}c[a>>2]=2155832+(b*112|0);e=0;return e|0}function aI0(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>33){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1180024+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aI1(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>36){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3314536+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aI2(){var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;d=i;i=i+1680|0;e=d|0;f=d+112|0;g=d+120|0;j=d+232|0;k=d+240|0;l=d+352|0;m=d+360|0;n=d+472|0;o=d+480|0;p=d+592|0;q=d+600|0;r=d+712|0;s=d+720|0;t=d+832|0;u=d+840|0;v=d+952|0;w=d+960|0;x=d+1072|0;y=d+1080|0;z=d+1192|0;A=d+1200|0;B=d+1312|0;C=d+1320|0;D=d+1432|0;E=d+1440|0;F=d+1552|0;G=d+1560|0;H=d+1672|0;c[2414848]=0;c[3531130]=0;c[3531118]=524288;c[2387770]=1048576;c[3530746]=1114112;c[3530510]=4259840;c[3530378]=7405568;c[3530306]=11599872;c[3530286]=19988480;c[3541206]=21037056;c[3529742]=21037056;c[3529698]=22085632;c[3529888]=22872064;c[2414550]=22888448;c[3531182]=22888448;c[3531160]=22904832;c[2387792]=22921216;c[3529648]=22929408;c[3529626]=22933504;c[3529686]=22937600;c[3529674]=22941696;c[3527324]=22945792;c[2387096]=22949888;c[3528646]=22966272;c[2411450]=22966273;c[3527026]=22966273;I=(a[9688]|0?22968409:22966273)|0;c[2413990]=I;J=I;I=0;while(1){if((I|0)>=1024){break}K=9638528+(I<<2)|0;if((c[K>>2]|0)==0){L=31815;break}else{I=I+1|0}}do{if((L|0)==31815){I=gGq(J)|0;c[K>>2]=I;if((I|0)==0){break}gGz(I|0,0,J|0);c[2414848]=I;gGz(I|0,0,J|0);c[3531130]=I;c[3531118]=I+524288;c[2387770]=I+1048576;c[3530746]=I+1114112;c[3530510]=I+4259840;c[3530378]=I+7405568;c[3530306]=I+11599872;c[3530286]=I+19988480;M=I+21037056|0;c[3541206]=M;c[3529742]=M;c[3529698]=I+22085632;c[3529888]=I+22872064;M=I+22888448|0;c[2414550]=M;c[3531182]=M;c[3531160]=I+22904832;c[2387792]=I+22921216;c[3529648]=I+22929408;c[3529626]=I+22933504;c[3529686]=I+22937600;c[3529674]=I+22941696;c[3527324]=I+22945792;c[2387096]=I+22949888;c[3528646]=I+22966272;M=I+22966273|0;c[2411450]=M;c[3527026]=M;c[2413990]=I+(a[9688]|0?22968409:22966273);if((R6(I+1|0,0,2)|0)!=0){N=1;i=d;return N|0}if((R6(c[3531130]|0,1,2)|0)!=0){N=1;i=d;return N|0}if((R6((c[3531130]|0)+262145|0,2,2)|0)!=0){N=1;i=d;return N|0}if((R6((c[3531130]|0)+262144|0,3,2)|0)!=0){N=1;i=d;return N|0}if((R6((c[3531118]|0)+1|0,4,2)|0)!=0){N=1;i=d;return N|0}if((R6(c[3531118]|0,5,2)|0)!=0){N=1;i=d;return N|0}if((R6((c[3531118]|0)+262145|0,6,2)|0)!=0){N=1;i=d;return N|0}if((R6((c[3531118]|0)+262144|0,7,2)|0)!=0){N=1;i=d;return N|0}I=c[2387770]|0;if((c[3542200]|0)==0){N=1;i=d;return N|0}M=G+108|0;c[M>>2]=0;O=G+100|0;c[O>>2]=0;P=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[P&16383](G,8)|0;do{if((c[M>>2]|0)!=0){P=c[O>>2]|0;c[H>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](H,8,0)|0;if((P|0)<1){N=1;i=d;return N|0}if((gzL(I,0,8)|0)==0){break}else{N=1}i=d;return N|0}}while(0);if((R6(c[3530746]|0,9,2)|0)!=0){N=1;i=d;return N|0}if((R6((c[3530746]|0)+1|0,10,2)|0)!=0){N=1;i=d;return N|0}I=c[3530510]|0;if((c[3542200]|0)==0){N=1;i=d;return N|0}O=E+108|0;c[O>>2]=0;M=E+100|0;c[M>>2]=0;P=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[P&16383](E,11)|0;do{if((c[O>>2]|0)!=0){P=c[M>>2]|0;c[F>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](F,11,0)|0;if((P|0)<1){N=1;i=d;return N|0}if((gzL(I,0,11)|0)==0){break}else{N=1}i=d;return N|0}}while(0);I=c[3530306]|0;M=c[3530510]|0;O=M+524288|0;gGC(I|0,O|0,524288)|0;gGG(M+589824|0,O|0,524288);P=c[3530746]|0;gGC(O|0,P|0,65536)|0;O=M+1114112|0;M=P+65536|0;gGC(O|0,M|0,65536)|0;gGz(I|0,0,2097152);I=c[3530378]|0;if((c[3542200]|0)==0){N=1;i=d;return N|0}M=C+108|0;c[M>>2]=0;O=C+100|0;c[O>>2]=0;P=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[P&16383](C,12)|0;do{if((c[M>>2]|0)!=0){P=c[O>>2]|0;c[D>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](D,12,0)|0;if((P|0)<1){N=1;i=d;return N|0}if((gzL(I,0,12)|0)==0){break}else{N=1}i=d;return N|0}}while(0);I=(c[3530378]|0)+1048576|0;if((c[3542200]|0)==0){N=1;i=d;return N|0}O=A+108|0;c[O>>2]=0;M=A+100|0;c[M>>2]=0;P=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[P&16383](A,13)|0;do{if((c[O>>2]|0)!=0){P=c[M>>2]|0;c[B>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](B,13,0)|0;if((P|0)<1){N=1;i=d;return N|0}if((gzL(I,0,13)|0)==0){break}else{N=1}i=d;return N|0}}while(0);I=c[3530306]|0;if((c[3542200]|0)==0){N=1;i=d;return N|0}M=y+108|0;c[M>>2]=0;O=y+100|0;c[O>>2]=0;P=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[P&16383](y,14)|0;do{if((c[M>>2]|0)!=0){P=c[O>>2]|0;c[z>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](z,14,0)|0;if((P|0)<1){N=1;i=d;return N|0}if((gzL(I,0,14)|0)==0){break}else{N=1}i=d;return N|0}}while(0);I=(c[3530306]|0)+524288|0;if((c[3542200]|0)==0){N=1;i=d;return N|0}O=w+108|0;c[O>>2]=0;M=w+100|0;c[M>>2]=0;P=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[P&16383](w,15)|0;do{if((c[O>>2]|0)!=0){P=c[M>>2]|0;c[x>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](x,15,0)|0;if((P|0)<1){N=1;i=d;return N|0}if((gzL(I,0,15)|0)==0){break}else{N=1}i=d;return N|0}}while(0);I=(c[3530306]|0)+1048576|0;if((c[3542200]|0)==0){N=1;i=d;return N|0}M=u+108|0;c[M>>2]=0;O=u+100|0;c[O>>2]=0;P=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[P&16383](u,16)|0;do{if((c[M>>2]|0)!=0){P=c[O>>2]|0;c[v>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](v,16,0)|0;if((P|0)<1){N=1;i=d;return N|0}if((gzL(I,0,16)|0)==0){break}else{N=1}i=d;return N|0}}while(0);I=(c[3530306]|0)+1572864|0;if((c[3542200]|0)==0){N=1;i=d;return N|0}O=s+108|0;c[O>>2]=0;M=s+100|0;c[M>>2]=0;P=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[P&16383](s,17)|0;do{if((c[O>>2]|0)!=0){P=c[M>>2]|0;c[t>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](t,17,0)|0;if((P|0)<1){N=1;i=d;return N|0}if((gzL(I,0,17)|0)==0){break}else{N=1}i=d;return N|0}}while(0);I=(c[3530306]|0)+2097152|0;if((c[3542200]|0)==0){N=1;i=d;return N|0}M=q+108|0;c[M>>2]=0;O=q+100|0;c[O>>2]=0;P=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[P&16383](q,18)|0;do{if((c[M>>2]|0)!=0){P=c[O>>2]|0;c[r>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](r,18,0)|0;if((P|0)<1){N=1;i=d;return N|0}if((gzL(I,0,18)|0)==0){break}else{N=1}i=d;return N|0}}while(0);I=(c[3530306]|0)+2621440|0;if((c[3542200]|0)==0){N=1;i=d;return N|0}O=o+108|0;c[O>>2]=0;M=o+100|0;c[M>>2]=0;P=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[P&16383](o,19)|0;do{if((c[O>>2]|0)!=0){P=c[M>>2]|0;c[p>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](p,19,0)|0;if((P|0)<1){N=1;i=d;return N|0}if((gzL(I,0,19)|0)==0){break}else{N=1}i=d;return N|0}}while(0);I=(c[3530306]|0)+3145728|0;if((c[3542200]|0)==0){N=1;i=d;return N|0}M=m+108|0;c[M>>2]=0;O=m+100|0;c[O>>2]=0;P=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[P&16383](m,20)|0;do{if((c[M>>2]|0)!=0){P=c[O>>2]|0;c[n>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](n,20,0)|0;if((P|0)<1){N=1;i=d;return N|0}if((gzL(I,0,20)|0)==0){break}else{N=1}i=d;return N|0}}while(0);I=(c[3530306]|0)+3670016|0;if((c[3542200]|0)==0){N=1;i=d;return N|0}O=k+108|0;c[O>>2]=0;M=k+100|0;c[M>>2]=0;P=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[P&16383](k,21)|0;do{if((c[O>>2]|0)!=0){P=c[M>>2]|0;c[l>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](l,21,0)|0;if((P|0)<1){N=1;i=d;return N|0}if((gzL(I,0,21)|0)==0){break}else{N=1}i=d;return N|0}}while(0);if((R6(c[3530286]|0,22,2)|0)!=0){N=1;i=d;return N|0}if((R6((c[3530286]|0)+1|0,23,2)|0)!=0){N=1;i=d;return N|0}if((R6((c[3530286]|0)+262144|0,24,2)|0)!=0){N=1;i=d;return N|0}if((R6((c[3530286]|0)+262145|0,25,2)|0)!=0){N=1;i=d;return N|0}I=c[3529742]|0;if((c[3542200]|0)==0){N=1;i=d;return N|0}M=g+108|0;c[M>>2]=0;O=g+100|0;c[O>>2]=0;P=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[P&16383](g,26)|0;do{if((c[M>>2]|0)!=0){P=c[O>>2]|0;c[j>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](j,26,0)|0;if((P|0)<1){N=1;i=d;return N|0}if((gzL(I,0,26)|0)==0){break}else{N=1}i=d;return N|0}}while(0);I=(c[3529698]|0)+262144|0;if((c[3542200]|0)==0){N=1;i=d;return N|0}O=e+108|0;c[O>>2]=0;M=e+100|0;c[M>>2]=0;P=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[P&16383](e,27)|0;do{if((c[O>>2]|0)!=0){P=c[M>>2]|0;c[f>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](f,27,0)|0;if((P|0)<1){N=1;i=d;return N|0}if((gzL(I,0,27)|0)==0){break}else{N=1}i=d;return N|0}}while(0);aE_(c[3530510]|0,c[3530746]|0,1179648,1);I=c[3530510]|0;aE_(I,I,1179648,0);I=c[3530378]|0;aE_(I,I,2097152,0);I=c[3530306]|0;aE_(I,I,4194304,0);I=c[3530286]|0;aE_(I,I,524288,0);aE1(0,0,1);I=c[3530510]|0;M=c[3530378]|0;c[2383440]=c[3530746];c[2383441]=I;c[2383442]=M;c[2383436]=65535;c[2383437]=16383;c[2383438]=16383;a[690376]=1;c[2429668]=512;c[2429669]=768;c[2429436]=2108;c[2429437]=2108;c[2429438]=2108;c[2429439]=2108;fxU(0,425984);if((c[2394]|0)==0){R=c[2112932]|0}else{c[2394]=0;M=c[3532596]|0;c[2112932]=M;I=c[3532592]|0;if((I|0)!=0){gGC(9104152,I|0,280)|0}c[2113054]=c[2113060];R=M}M=c[3531130]|0;I=R|0;O=0;while(1){P=M+O|0;c[I>>2]=P;c[I+131072>>2]=P;P=O+1024|0;if(P>>>0>524287){break}else{I=I+4|0;O=P}}O=c[2387096]|0;c[R+4096>>2]=O;c[R+69632>>2]=O;c[R+135168>>2]=O;I=O+1024|0;c[R+4100>>2]=I;c[R+69636>>2]=I;c[R+135172>>2]=I;I=O+2048|0;c[R+4104>>2]=I;c[R+69640>>2]=I;c[R+135176>>2]=I;I=O+3072|0;c[R+4108>>2]=I;c[R+69644>>2]=I;c[R+135180>>2]=I;I=O+4096|0;c[R+4112>>2]=I;c[R+69648>>2]=I;c[R+135184>>2]=I;I=O+5120|0;c[R+4116>>2]=I;c[R+69652>>2]=I;c[R+135188>>2]=I;I=O+6144|0;c[R+4120>>2]=I;c[R+69656>>2]=I;c[R+135192>>2]=I;I=O+7168|0;c[R+4124>>2]=I;c[R+69660>>2]=I;c[R+135196>>2]=I;I=O+8192|0;c[R+4128>>2]=I;c[R+69664>>2]=I;c[R+135200>>2]=I;I=O+9216|0;c[R+4132>>2]=I;c[R+69668>>2]=I;c[R+135204>>2]=I;I=O+10240|0;c[R+4136>>2]=I;c[R+69672>>2]=I;c[R+135208>>2]=I;I=O+11264|0;c[R+4140>>2]=I;c[R+69676>>2]=I;c[R+135212>>2]=I;I=O+12288|0;c[R+4144>>2]=I;c[R+69680>>2]=I;c[R+135216>>2]=I;I=O+13312|0;c[R+4148>>2]=I;c[R+69684>>2]=I;c[R+135220>>2]=I;I=O+14336|0;c[R+4152>>2]=I;c[R+69688>>2]=I;c[R+135224>>2]=I;I=O+15360|0;c[R+4156>>2]=I;c[R+69692>>2]=I;c[R+135228>>2]=I;I=c[2383430]|0;c[R+8192>>2]=I;c[R+73728>>2]=I;c[R+139264>>2]=I;O=I+1024|0;c[R+8196>>2]=O;c[R+73732>>2]=O;c[R+139268>>2]=O;O=I+2048|0;c[R+8200>>2]=O;c[R+73736>>2]=O;c[R+139272>>2]=O;O=I+3072|0;c[R+8204>>2]=O;c[R+73740>>2]=O;c[R+139276>>2]=O;O=I+4096|0;c[R+8208>>2]=O;c[R+73744>>2]=O;c[R+139280>>2]=O;O=I+5120|0;c[R+8212>>2]=O;c[R+73748>>2]=O;c[R+139284>>2]=O;O=I+6144|0;c[R+8216>>2]=O;c[R+73752>>2]=O;c[R+139288>>2]=O;O=I+7168|0;c[R+8220>>2]=O;c[R+73756>>2]=O;c[R+139292>>2]=O;O=c[2383431]|0;c[R+8224>>2]=O;c[R+73760>>2]=O;c[R+139296>>2]=O;I=O+1024|0;c[R+8228>>2]=I;c[R+73764>>2]=I;c[R+139300>>2]=I;I=O+2048|0;c[R+8232>>2]=I;c[R+73768>>2]=I;c[R+139304>>2]=I;I=O+3072|0;c[R+8236>>2]=I;c[R+73772>>2]=I;c[R+139308>>2]=I;I=O+4096|0;c[R+8240>>2]=I;c[R+73776>>2]=I;c[R+139312>>2]=I;I=O+5120|0;c[R+8244>>2]=I;c[R+73780>>2]=I;c[R+139316>>2]=I;I=O+6144|0;c[R+8248>>2]=I;c[R+73784>>2]=I;c[R+139320>>2]=I;I=O+7168|0;c[R+8252>>2]=I;c[R+73788>>2]=I;c[R+139324>>2]=I;I=c[2383426]|0;c[R+74016>>2]=I;c[R+74020>>2]=I+1024;c[R+74024>>2]=I+2048;c[R+74028>>2]=I+3072;I=c[2383432]|0;c[R+9216>>2]=I;c[R+74752>>2]=I;c[R+140288>>2]=I;O=I+1024|0;c[R+9220>>2]=O;c[R+74756>>2]=O;c[R+140292>>2]=O;O=I+2048|0;c[R+9224>>2]=O;c[R+74760>>2]=O;c[R+140296>>2]=O;O=I+3072|0;c[R+9228>>2]=O;c[R+74764>>2]=O;c[R+140300>>2]=O;O=c[2383433]|0;c[R+9248>>2]=O;c[R+74784>>2]=O;c[R+140320>>2]=O;I=O+1024|0;c[R+9252>>2]=I;c[R+74788>>2]=I;c[R+140324>>2]=I;I=O+2048|0;c[R+9256>>2]=I;c[R+74792>>2]=I;c[R+140328>>2]=I;I=O+3072|0;c[R+9260>>2]=I;c[R+74796>>2]=I;c[R+140332>>2]=I;I=c[2383422]|0;c[R+75040>>2]=I;c[R+75044>>2]=I+1024;c[R+75048>>2]=I+2048;c[R+75052>>2]=I+3072;I=c[3531182]|0;c[R+16256>>2]=I;c[R+81792>>2]=I;c[R+147328>>2]=I;O=I+1024|0;c[R+16260>>2]=O;c[R+81796>>2]=O;c[R+147332>>2]=O;O=I+2048|0;c[R+16264>>2]=O;c[R+81800>>2]=O;c[R+147336>>2]=O;O=I+3072|0;c[R+16268>>2]=O;c[R+81804>>2]=O;c[R+147340>>2]=O;O=I+4096|0;c[R+16272>>2]=O;c[R+81808>>2]=O;c[R+147344>>2]=O;O=I+5120|0;c[R+16276>>2]=O;c[R+81812>>2]=O;c[R+147348>>2]=O;O=I+6144|0;c[R+16280>>2]=O;c[R+81816>>2]=O;c[R+147352>>2]=O;O=I+7168|0;c[R+16284>>2]=O;c[R+81820>>2]=O;c[R+147356>>2]=O;O=I+8192|0;c[R+16288>>2]=O;c[R+81824>>2]=O;c[R+147360>>2]=O;O=I+9216|0;c[R+16292>>2]=O;c[R+81828>>2]=O;c[R+147364>>2]=O;O=I+10240|0;c[R+16296>>2]=O;c[R+81832>>2]=O;c[R+147368>>2]=O;O=I+11264|0;c[R+16300>>2]=O;c[R+81836>>2]=O;c[R+147372>>2]=O;O=I+12288|0;c[R+16304>>2]=O;c[R+81840>>2]=O;c[R+147376>>2]=O;O=I+13312|0;c[R+16308>>2]=O;c[R+81844>>2]=O;c[R+147380>>2]=O;O=I+14336|0;c[R+16312>>2]=O;c[R+81848>>2]=O;c[R+147384>>2]=O;O=I+15360|0;c[R+16316>>2]=O;c[R+81852>>2]=O;c[R+147388>>2]=O;O=c[3529626]|0;c[R+16320>>2]=O;c[R+81856>>2]=O;c[R+147392>>2]=O;I=O+1024|0;c[R+16324>>2]=I;c[R+81860>>2]=I;c[R+147396>>2]=I;I=O+2048|0;c[R+16328>>2]=I;c[R+81864>>2]=I;c[R+147400>>2]=I;I=O+3072|0;c[R+16332>>2]=I;c[R+81868>>2]=I;c[R+147404>>2]=I;I=c[3527324]|0;c[R+147424>>2]=I;c[R+147428>>2]=I+1024;c[R+147432>>2]=I+2048;c[R+147436>>2]=I+3072;c[R+196728>>2]=3400;c[R+196648>>2]=194;c[R+196688>>2]=2276;c[R+196608>>2]=3408;c[R+16352>>2]=1;c[R+81888>>2]=1;c[R+16356>>2]=1;c[R+81892>>2]=1;c[R+16360>>2]=1;c[R+81896>>2]=1;c[R+16364>>2]=1;c[R+81900>>2]=1;c[R+196732>>2]=228;c[R+196652>>2]=2270;c[R+196692>>2]=1432;c[R+196612>>2]=1288;I=c[3532592]|0;if((I|0)!=0){gGC(I|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fxU(1,425984);if((c[2394]|0)==1){S=c[2112932]|0}else{c[2394]=1;I=c[3532597]|0;c[2112932]=I;O=c[3532593]|0;if((O|0)!=0){gGC(9104152,O|0,280)|0}c[2113054]=c[2113061];S=I}I=c[3531118]|0;O=S|0;M=0;while(1){P=I+M|0;c[O>>2]=P;c[O+131072>>2]=P;P=M+1024|0;if(P>>>0>524287){break}else{O=O+4|0;M=P}}M=c[3531160]|0;c[S+16256>>2]=M;c[S+81792>>2]=M;c[S+147328>>2]=M;O=M+1024|0;c[S+16260>>2]=O;c[S+81796>>2]=O;c[S+147332>>2]=O;O=M+2048|0;c[S+16264>>2]=O;c[S+81800>>2]=O;c[S+147336>>2]=O;O=M+3072|0;c[S+16268>>2]=O;c[S+81804>>2]=O;c[S+147340>>2]=O;O=M+4096|0;c[S+16272>>2]=O;c[S+81808>>2]=O;c[S+147344>>2]=O;O=M+5120|0;c[S+16276>>2]=O;c[S+81812>>2]=O;c[S+147348>>2]=O;O=M+6144|0;c[S+16280>>2]=O;c[S+81816>>2]=O;c[S+147352>>2]=O;O=M+7168|0;c[S+16284>>2]=O;c[S+81820>>2]=O;c[S+147356>>2]=O;O=M+8192|0;c[S+16288>>2]=O;c[S+81824>>2]=O;c[S+147360>>2]=O;O=M+9216|0;c[S+16292>>2]=O;c[S+81828>>2]=O;c[S+147364>>2]=O;O=M+10240|0;c[S+16296>>2]=O;c[S+81832>>2]=O;c[S+147368>>2]=O;O=M+11264|0;c[S+16300>>2]=O;c[S+81836>>2]=O;c[S+147372>>2]=O;O=M+12288|0;c[S+16304>>2]=O;c[S+81840>>2]=O;c[S+147376>>2]=O;O=M+13312|0;c[S+16308>>2]=O;c[S+81844>>2]=O;c[S+147380>>2]=O;O=M+14336|0;c[S+16312>>2]=O;c[S+81848>>2]=O;c[S+147384>>2]=O;O=M+15360|0;c[S+16316>>2]=O;c[S+81852>>2]=O;c[S+147388>>2]=O;O=c[3529648]|0;c[S+16320>>2]=O;c[S+81856>>2]=O;c[S+147392>>2]=O;M=O+1024|0;c[S+16324>>2]=M;c[S+81860>>2]=M;c[S+147396>>2]=M;M=O+2048|0;c[S+16328>>2]=M;c[S+81864>>2]=M;c[S+147400>>2]=M;M=O+3072|0;c[S+16332>>2]=M;c[S+81868>>2]=M;c[S+147404>>2]=M;M=c[3527324]|0;c[S+147424>>2]=M;c[S+147428>>2]=M+1024;c[S+147432>>2]=M+2048;c[S+147436>>2]=M+3072;c[S+196728>>2]=368;c[S+196648>>2]=3122;c[S+196688>>2]=934;c[S+196608>>2]=2012;c[S+16352>>2]=1;c[S+81888>>2]=1;c[S+16356>>2]=1;c[S+81892>>2]=1;c[S+16360>>2]=1;c[S+81896>>2]=1;c[S+16364>>2]=1;c[S+81900>>2]=1;c[S+196732>>2]=228;c[S+196652>>2]=2270;c[S+196692>>2]=1432;c[S+196612>>2]=1288;M=c[3532593]|0;if((M|0)!=0){gGC(M|0,9104152,280)|0}c[2113061]=c[2113054];c[2394]=-1;aE8(c[2387770]|0,c[2387792]|0,8055e3,1,726,.45,1006875,.5,2013750,.25);h[745419]=.4;a[3203368]=1;h[745418]=.4;a[3203360]=1;h[745417]=.4;a[3203352]=1;h[745416]=.4;a[3203344]=1;h[745421]=.45;c[2436794]=1;h[745420]=.45;c[2436792]=2;M=c[642608+(c[2436]<<2)>>2]|0;O=c[M+128>>2]|0;if((c[M+52>>2]&4|0)==0){c[2113068]=O;I=c[M+132>>2]|0;c[2113070]=I;c[2443814]=O;c[2440436]=I;T=O;U=I}else{c[2113070]=O;I=c[M+132>>2]|0;c[2113068]=I;c[2440436]=O;c[2443814]=I;T=I;U=O}O=ag(T<<1,U)|0;I=gGq(O)|0;c[2112926]=I;if((I|0)!=0){gGz(I|0,0,O|0)}O=c[2414550]|0;gGz(O|0,0,(c[2411450]|0)-O|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];O=c[3532592]|0;if((O|0)!=0){gGC(9104152,O|0,280)|0}c[2113054]=c[2113060]}RI();O=c[2394]|0;I=c[14130368+(O<<2)>>2]|0;if((I|0)!=0){gGC(I|0,9104152,280)|0}c[8452240+(O<<2)>>2]=c[2113054];c[2394]=1;c[2112932]=c[3532597];O=c[3532593]|0;if((O|0)!=0){gGC(9104152,O|0,280)|0}c[2113054]=c[2113061];RI();O=c[2394]|0;I=c[14130368+(O<<2)>>2]|0;if((I|0)!=0){gGC(I|0,9104152,280)|0}c[8452240+(O<<2)>>2]=c[2113054];c[2394]=-1;aE7();c[3530238]=0;O=c[3529698]|0;I=O+262144|0;gGC(O|0,I|0,262144)|0;gGz(c[2383428]|0,0,4096);gGz(c[2383426]|0,0,4096);I=c[2383424]|0;if((I|0)!=0){gGz(I|0,0,4096);gGz(c[2383422]|0,0,4096)}gGz(c[2383434]|0,0,16);gGz(c[2383435]|0,0,16);gGz(c[2383430]|0,0,8192);gGz(c[2383431]|0,0,8192);I=c[2383432]|0;if((I|0)!=0){gGz(I|0,0,8192);gGz(c[2383433]|0,0,8192)}b[4766836]=0;c[2426968]=0;c[3528794]=0;c[1765522]=65535;c[2429656]=0;c[2427042]=0;c[2429386]=0;c[2429384]=0;c[2429382]=0;N=0;i=d;return N|0}}while(0);c[2414848]=0;N=1;i=d;return N|0}function aI3(){var a=0,b=0,d=0,e=0,f=0;c[2113070]=0;c[2113068]=0;a=c[2112926]|0;if((a|0)!=0){gGr(a);c[2112926]=0}aE2();if((c[2392]|0)>=0){a=0;do{b=14130368+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}b=14130384+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}a=a+1|0;}while((a|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;aFe();a=c[2414848]|0;b=0;while(1){if((b|0)>=1024){e=31998;break}f=9638528+(b<<2)|0;if((c[f>>2]|0)==(a|0)){break}else{b=b+1|0}}if((e|0)==31998){c[2414848]=0;return 0}gGr(a);c[f>>2]=0;c[2414848]=0;return 0}function aI4(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((a[9623376]|0)!=0){d=c[2414550]|0;gGz(d|0,0,(c[2411450]|0)-d|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=1;c[2112932]=c[3532597];d=c[3532593]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113061];RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;aE7();c[3530238]=0;d=c[3529698]|0;e=d+262144|0;gGC(d|0,e|0,262144)|0;gGz(c[2383428]|0,0,4096);gGz(c[2383426]|0,0,4096);e=c[2383424]|0;if((e|0)!=0){gGz(e|0,0,4096);gGz(c[2383422]|0,0,4096)}gGz(c[2383434]|0,0,16);gGz(c[2383435]|0,0,16);gGz(c[2383430]|0,0,8192);gGz(c[2383431]|0,0,8192);e=c[2383432]|0;if((e|0)!=0){gGz(e|0,0,8192);gGz(c[2383433]|0,0,8192)}b[4766836]=0;c[2426968]=0;c[3528794]=0;c[1765522]=65535;c[2429656]=0;c[2427042]=0;c[2429386]=0;c[2429384]=0;c[2429382]=0}gGz(9550136,-1|0,6);e=0;d=-1;f=-1;g=-1;do{d=((a[9632344+e|0]&1)<<e^d&65535)&65535;f=((a[9630256+e|0]&1)<<e^f&65535)&65535;g=((a[9629152+e|0]&1)<<e^g&65535)&65535;e=e+1|0;}while((e|0)<16);b[4775068]=d;b[4775069]=f;b[4775070]=g;c[(c[2391608]|0)+60>>2]=0;c[(c[2391608]|0)+60>>2]=0;c[2388530]=9554128;g=c[2391608]|0;if((g|0)!=0){f=g;gGC(9661040,f|0,68)|0}c[2382]=0;c[2383408]=0;f=0;g=0;d=0;e=0;do{if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];h=c[3532592]|0;if((h|0)!=0){gGC(9104152,h|0,280)|0}c[2113054]=c[2113060]}c[2113056]=911;h=RG(911)|0;c[2113054]=(c[2113054]|0)+h;c[2276108]=-1;c[2113056]=-1;g=h+g|0;h=(f|0)==255;do{if(h){c[8452200+(c[2394]<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0>=1024){break}RH(4)}}while(0);i=c[2394]|0;j=c[14130368+(i<<2)>>2]|0;if((j|0)!=0){gGC(j|0,9104152,280)|0}c[8452240+(i<<2)>>2]=c[2113054];c[2394]=1;c[2112932]=c[3532597];i=c[3532593]|0;if((i|0)!=0){gGC(9104152,i|0,280)|0}c[2113054]=c[2113061];i=g-d|0;c[2113056]=i;j=RG(i)|0;c[2113054]=(c[2113054]|0)+j;c[2276108]=-1;c[2113056]=-1;i=j+d|0;do{if(h){c[8452200+(c[2394]<<2)>>2]=8197;c[2276080]=1280;if((c[2276079]|0)>>>0>=1280){break}RH(5)}}while(0);h=c[2394]|0;j=c[14130368+(h<<2)>>2]|0;if((j|0)!=0){gGC(j|0,9104152,280)|0}c[8452240+(h<<2)>>2]=c[2113054];c[2394]=-1;d=i+(fy_(262)|0)|0;if((f|0)==248){c[2383408]=8}h=a[9688]|0?2:0;j=(c[3527026]|0)+(e<<1<<1)|0;if(a[801408]|0){gg[c[3542124]&4095](j,h)}if(a[801400]|0){Uu(0,j,h)}if((c[2429658]|0)!=0){Uu(1,j,h)}e=h+e|0;f=f+1|0;}while((f|0)<256);f=c[2438228]|0;d=gGS(-1313210368,32007,f,(f|0)<0|0?-1:0)|0;f=d;Sb(67125);d=c[2443830]|0;if((d|0)<1073676288){c[2443830]=d-f}d=c[2443831]|0;if((d|0)<1073676288){c[2443831]=d-f}d=(c[3528512]|0)-f|0;c[3528512]=(d|0)<0?0:d;d=c[2112964]|0;do{if((d|0)!=0){gg[c[3542122]&4095](d,a[9688]|0?534:0);f=a[9688]|0;g=f?534:0;if((g|0)==(e|0)){k=e;l=f}else{f=g-e|0;g=(c[3527026]|0)+(e<<1<<1)|0;if(a[801408]|0){gg[c[3542124]&4095](g,f)}if(a[801400]|0){Uu(0,g,f)}if((c[2429658]|0)!=0){Uu(1,g,f)}f=a[9688]|0;k=f?534:0;l=f}if((k|0)<=0){break}f=c[3527026]|0;g=c[2112964]|0;h=l?534:0;j=0;do{m=j<<1;n=g+(m<<1)|0;b[n>>1]=(b[n>>1]|0)+(b[f+(m<<1)>>1]|0)&65535;n=m|1;m=g+(n<<1)|0;b[m>>1]=(b[m>>1]|0)+(b[f+(n<<1)>>1]|0)&65535;j=j+1|0;}while((j|0)<(h|0))}}while(0);l=c[(c[2388530]|0)+12304>>2]|0;if((l|0)!=0){k=l;gGC(k|0,9661040,68)|0}c[2382]=-1;if((c[2112968]|0)==0){return 0}aI5()|0;return 0}function aI5(){var d=0,f=0,g=0,h=0,i=0,j=0;d=c[3529888]|0;f=c[2387096]|0;g=(c[642608+(c[2436]<<2)>>2]|0)+124|0;if((c[g>>2]<<1|0)>0){h=0;do{i=e[f+((h|1)<<1)>>1]|0;c[d+(((h|0)/2|0)<<2)>>2]=i<<8&63488|(e[f+(h<<1)>>1]|0)>>>3&31|i>>>8<<3&2016;h=h+2|0;}while((h|0)<(c[g>>2]<<1|0))}a[9547056]=0;aE3();aE5();g=ag(c[2113070]|0,c[2113068]|0)|0;h=c[2112926]|0;if((g|0)>0){f=0;while(1){b[h+(f<<1)>>1]=3072;d=f+1|0;if((d|0)<(g|0)){f=d}else{j=h;break}}}else{j=h}gGz(c[2383420]|0,0,131072);gGz(c[2383410]|0,0,131072);aE0(3,j,65536);h=b[4766836]&3;if((h|0)==3){aE0(2,j,2);aE0(1,j,16)}else if((h|0)==0){aE0(1,j,2);aE0(2,j,16)}else if((h|0)==1){aE0(2,j,2);aE0(1,j,64)}aJk(0);aE0(0,j,255);R8(c[3529888]|0);aJk(4);return 0}function aI6(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=i;i=i+80|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;if((d|0)!=0){c[d>>2]=169762}if((b&32|0)!=0){gGz(k|0,0,12);l=c[2414550]|0;c[k>>2]=l;c[k+4>>2]=(c[2411450]|0)-l;c[k+12>>2]=162152;l=c[2076592]|0;gj[l&4095](k)|0}if((b&64|0)==0){i=e;return 0}k=h|0;gGz(g|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){l=h+9|0;h=f;m=f|0;n=f+4|0;o=f+12|0;p=g|0;q=g+4|0;r=g+12|0;s=0;do{gGC(k|0,614896,11)|0;a[l]=s+48&255;t=8452256+(s<<2)|0;gGz(h|0,0,12);c[m>>2]=t;c[n>>2]=4;c[o>>2]=164976;gj[c[2076592]&4095](f)|0;if((c[t>>2]|0)!=0){c[p>>2]=c[14130368+(s<<2)>>2];c[q>>2]=c[8452184+(s<<2)>>2];c[r>>2]=k;t=c[2076592]|0;gj[t&4095](g)|0}s=s+1|0;}while((s|0)<=(c[2392]|0))}aFf(b,d);aE6();gGz(j|0,0,12);c[j>>2]=14120952;c[j+4>>2]=4;c[j+12>>2]=491248;gj[c[2076592]&4095](j)|0;j=c[3530238]&1;c[3530238]=j;d=c[3529698]|0;b=d+((j<<18)+262144)|0;gGC(d|0,b|0,262144)|0;i=e;return 0}function aI7(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>39){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1369156+(b*112|0)>>2];c[a+104>>2]=c[1369160+(b*112|0)>>2];c[a+108>>2]=c[1369164+(b*112|0)>>2];d=0;return d|0}function aI8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<40&(d|0)==0)){e=1;return e|0}c[a>>2]=1369056+(b*112|0);e=0;return e|0}function aI9(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>39){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1373636+(b*112|0)>>2];c[a+104>>2]=c[1373640+(b*112|0)>>2];c[a+108>>2]=c[1373644+(b*112|0)>>2];d=0;return d|0}function aJa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<40&(d|0)==0)){e=1;return e|0}c[a>>2]=1373536+(b*112|0);e=0;return e|0}function aJb(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>44){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1364116+(b*112|0)>>2];c[a+104>>2]=c[1364120+(b*112|0)>>2];c[a+108>>2]=c[1364124+(b*112|0)>>2];d=0;return d|0}function aJc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<45&(d|0)==0)){e=1;return e|0}c[a>>2]=1364016+(b*112|0);e=0;return e|0}function aJd(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>39){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2966116+(b*112|0)>>2];c[a+104>>2]=c[2966120+(b*112|0)>>2];c[a+108>>2]=c[2966124+(b*112|0)>>2];d=0;return d|0}function aJe(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<40&(d|0)==0)){e=1;return e|0}c[a>>2]=2966016+(b*112|0);e=0;return e|0}function aJf(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>37){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4099464+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aJg(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>39){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1581356+(b*112|0)>>2];c[a+104>>2]=c[1581360+(b*112|0)>>2];c[a+108>>2]=c[1581364+(b*112|0)>>2];d=0;return d|0}function aJh(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<40&(d|0)==0)){e=1;return e|0}c[a>>2]=1581256+(b*112|0);e=0;return e|0}function aJi(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>24){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1963600+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aJj(a,b){a=a|0;b=b|0;var d=0;a=b&1;c[3530238]=a;b=c[3529698]|0;d=b+((a<<18)+262144)|0;gGC(b|0,d|0,262144)|0;return}function aJk(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;if((c[2113308]&4|0)!=(d|0)){return}f=(d|0)==0;d=c[3529686]|0;g=c[3529674]|0;h=c[3530306]|0;i=c[3530286]|0;j=c[3528646]|0;k=c[3529888]|0;l=c[2112926]|0;m=(c[2113222]&1|0)==0;n=0;do{o=(n|0)==0;p=o?1024:2048;q=1<<n;r=o?d:g;s=o?h:i;t=2044;do{u=b[r+((t|1)<<1)>>1]&32767;do{if((u|0)!=0){v=e[r+((t|2)<<1)>>1]|0;w=e[r+(t<<1)>>1]|0;if(!((w&4096|0)==0|m)){break}x=w>>>10&32|v>>>9&31;y=w&8192;z=w&16384;A=1<<(w>>>9&3);B=A-1|0;do{if(o){C=v&49152;if((C|0)==16384){D=32;E=255;break}else if((C|0)==49152){D=1;E=255;break}else if((C|0)==0){D=128;E=255;break}else if((C|0)==32768){D=8;E=255;break}else{D=0;E=255;break}}else{C=b[4766836]&3;if((C|0)==2|(C|0)==3|(C|0)==0){F=64}else if((C|0)==1){F=16}else{F=0}D=F;E=(v&49152|0)==0?255:128}}while(0);C=v&511;G=w&511;H=C>>>0>319?v|-512:C;C=G>>>0>255?w|-512:G;G=304-H|0;if((G|0)>320){break}I=((z|0)==0?B:0)+(u&-A)|0;J=(z>>>13^2)-1|0;if((a[j]|0)==0){K=-16;L=z;M=y;N=240-C|0;O=G}else{K=16;L=z>>>14^1;M=y>>>13^1;N=C;O=H}if((A|0)<=0){break}H=x<<4|p;if(f){C=B;while(1){G=I-(ag(C,J)|0)|0;aEY(l,s,G,H,O,(ag(C,K)|0)+N|0,M,L,D,q);if((C|0)>0){C=C-1|0}else{break}}}else{C=B;while(1){x=I-(ag(C,J)|0)|0;aEZ(k,s,x,H,O,(ag(C,K)|0)+N|0,M,L,D,q,E);if((C|0)>0){C=C-1|0}else{break}}}}}while(0);t=t-4|0;}while((t|0)>-1);n=n+1|0;}while((n|0)<2);return}function aJl(a){a=a|0;return a>>>4<<12&61440|0}function aJm(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2643596+(b*112|0)>>2];c[a+104>>2]=c[2643600+(b*112|0)>>2];c[a+108>>2]=c[2643604+(b*112|0)>>2];d=0;return d|0}function aJn(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=2643496+(b*112|0);e=0;return e|0}function aJo(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1235360+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aJp(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>41){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3800152+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aJq(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0;e=i;i=i+960|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;c[2414846]=0;c[2388070]=0;c[3527406]=1048576;c[3530744]=1114112;c[3530508]=1638400;c[3541206]=2162688;c[3529886]=2424832;c[2414548]=2428932;c[2388200]=2428932;c[2387094]=2494468;c[3529850]=2498564;c[3529848]=3022852;c[2386184]=3153924;c[3529646]=3166212;c[3529624]=3168260;c[3529682]=3170308;c[3529672]=3172356;c[3527264]=3174404;c[3527262]=3176452;c[3527418]=3178500;c[3528208]=3180548;c[3530984]=3180549;c[3530376]=3180565;c[2385354]=3311637;c[2411448]=5408789;x=0;while(1){if((x|0)>=1024){break}y=9638528+(x<<2)|0;if((c[y>>2]|0)==0){z=32223;break}else{x=x+1|0}}do{if((z|0)==32223){x=gGq(5408789)|0;c[y>>2]=x;if((x|0)==0){break}c[2414846]=x;gGz(x|0,0,5408789);c[2388070]=x;c[3527406]=x+1048576;c[3530744]=x+1114112;c[3530508]=x+1638400;c[3541206]=x+2162688;c[3529886]=x+2424832;A=x+2428932|0;c[2414548]=A;c[2388200]=A;c[2387094]=x+2494468;c[3529850]=x+2498564;c[3529848]=x+3022852;c[2386184]=x+3153924;c[3529646]=x+3166212;c[3529624]=x+3168260;c[3529682]=x+3170308;c[3529672]=x+3172356;c[3527264]=x+3174404;c[3527262]=x+3176452;c[3527418]=x+3178500;c[3528208]=x+3180548;c[3530984]=x+3180549;c[3530376]=x+3180565;c[2385354]=x+3311637;A=x+5408789|0;c[2411448]=A;c[2413988]=A;if((R6(x+1|0,0,2)|0)!=0){B=1;i=e;return B|0}if((R6(c[2388070]|0,1,2)|0)!=0){B=1;i=e;return B|0}if((R6((c[2388070]|0)+262145|0,2,2)|0)!=0){B=1;i=e;return B|0}if((R6((c[2388070]|0)+262144|0,3,2)|0)!=0){B=1;i=e;return B|0}if((R6((c[2388070]|0)+524289|0,4,2)|0)!=0){B=1;i=e;return B|0}if((R6((c[2388070]|0)+524288|0,5,2)|0)!=0){B=1;i=e;return B|0}if((R6((c[2388070]|0)+786433|0,6,2)|0)!=0){B=1;i=e;return B|0}if((R6((c[2388070]|0)+786432|0,7,2)|0)!=0){B=1;i=e;return B|0}x=c[3527406]|0;if((c[3542200]|0)==0){B=1;i=e;return B|0}A=v+108|0;c[A>>2]=0;C=v+100|0;c[C>>2]=0;D=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[D&16383](v,8)|0;do{if((c[A>>2]|0)!=0){D=c[C>>2]|0;c[w>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](w,8,0)|0;if((D|0)<1){B=1;i=e;return B|0}if((gzL(x,0,8)|0)==0){break}else{B=1}i=e;return B|0}}while(0);x=c[3530744]|0;if((c[3542200]|0)==0){B=1;i=e;return B|0}C=t+108|0;c[C>>2]=0;A=t+100|0;c[A>>2]=0;D=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[D&16383](t,9)|0;do{if((c[C>>2]|0)!=0){D=c[A>>2]|0;c[u>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](u,9,0)|0;if((D|0)<1){B=1;i=e;return B|0}if((gzL(x,0,9)|0)==0){break}else{B=1}i=e;return B|0}}while(0);x=(c[3530744]|0)+65536|0;if((c[3542200]|0)==0){B=1;i=e;return B|0}A=r+108|0;c[A>>2]=0;C=r+100|0;c[C>>2]=0;D=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[D&16383](r,10)|0;do{if((c[A>>2]|0)!=0){D=c[C>>2]|0;c[s>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](s,10,0)|0;if((D|0)<1){B=1;i=e;return B|0}if((gzL(x,0,10)|0)==0){break}else{B=1}i=e;return B|0}}while(0);x=(c[3530744]|0)+131072|0;if((c[3542200]|0)==0){B=1;i=e;return B|0}C=p+108|0;c[C>>2]=0;A=p+100|0;c[A>>2]=0;D=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[D&16383](p,11)|0;do{if((c[C>>2]|0)!=0){D=c[A>>2]|0;c[q>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](q,11,0)|0;if((D|0)<1){B=1;i=e;return B|0}if((gzL(x,0,11)|0)==0){break}else{B=1}i=e;return B|0}}while(0);x=c[3530508]|0;if((c[3542200]|0)==0){B=1;i=e;return B|0}A=n+108|0;c[A>>2]=0;C=n+100|0;c[C>>2]=0;D=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[D&16383](n,12)|0;do{if((c[A>>2]|0)!=0){D=c[C>>2]|0;c[o>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](o,12,0)|0;if((D|0)<1){B=1;i=e;return B|0}if((gzL(x,0,12)|0)==0){break}else{B=1}i=e;return B|0}}while(0);x=(c[3530508]|0)+65536|0;if((c[3542200]|0)==0){B=1;i=e;return B|0}C=l+108|0;c[C>>2]=0;A=l+100|0;c[A>>2]=0;D=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[D&16383](l,13)|0;do{if((c[C>>2]|0)!=0){D=c[A>>2]|0;c[m>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](m,13,0)|0;if((D|0)<1){B=1;i=e;return B|0}if((gzL(x,0,13)|0)==0){break}else{B=1}i=e;return B|0}}while(0);x=(c[3530508]|0)+131072|0;if((c[3542200]|0)==0){B=1;i=e;return B|0}A=j+108|0;c[A>>2]=0;C=j+100|0;c[C>>2]=0;D=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[D&16383](j,14)|0;do{if((c[A>>2]|0)!=0){D=c[C>>2]|0;c[k>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](k,14,0)|0;if((D|0)<1){B=1;i=e;return B|0}if((gzL(x,0,14)|0)==0){break}else{B=1}i=e;return B|0}}while(0);x=c[3541206]|0;if((c[3542200]|0)==0){B=1;i=e;return B|0}C=f+108|0;c[C>>2]=0;A=f+100|0;c[A>>2]=0;D=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[D&16383](f,15)|0;do{if((c[C>>2]|0)==0){F=0}else{D=c[A>>2]|0;c[g>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](g,15,0)|0;if((D|0)<1){B=1;i=e;return B|0}if((gzL(x,0,15)|0)==0){F=0;break}else{B=1}i=e;return B|0}}while(0);while(1){if((F|0)>=1024){break}G=9638528+(F<<2)|0;if((c[G>>2]|0)==0){z=32267;break}else{F=F+1|0}}L41581:do{if((z|0)==32267){x=gGq(196608)|0;c[G>>2]=x;if((x|0)==0){break}gGz(x|0,0,196608);A=c[3530744]|0;gGC(x|0,A|0,196608)|0;C=0;do{D=C<<8;gGz(A+D|0,0,256);E=D+1048576|0;H=0;do{I=E+(c[611648+(H<<2)>>2]|0)|0;J=(H<<4)+D|0;K=0;do{L=I+(c[610384+(K<<2)>>2]|0)|0;if(((d[x+((L|0)/8|0)|0]|0)&128>>>((L&7)>>>0)|0)!=0){L=A+(J+K)|0;a[L]=a[L]|4}K=K+1|0;}while((K|0)<16);H=H+1|0;}while((H|0)<16);H=D+524288|0;E=0;while(1){K=H+(c[611648+(E<<2)>>2]|0)|0;J=(E<<4)+D|0;I=0;do{L=K+(c[610384+(I<<2)>>2]|0)|0;if(((d[x+((L|0)/8|0)|0]|0)&128>>>((L&7)>>>0)|0)!=0){L=A+(J+I)|0;a[L]=a[L]|2}I=I+1|0;}while((I|0)<16);I=E+1|0;if((I|0)<16){E=I}else{M=0;break}}do{E=D+(c[611648+(M<<2)>>2]|0)|0;H=(M<<4)+D|0;I=0;do{J=E+(c[610384+(I<<2)>>2]|0)|0;if(((d[x+((J|0)/8|0)|0]|0)&128>>>((J&7)>>>0)|0)!=0){J=A+(H+I)|0;a[J]=a[J]|1}I=I+1|0;}while((I|0)<16);M=M+1|0;}while((M|0)<16);C=C+1|0;}while((C|0)<2048);C=c[3530508]|0;gGC(x|0,C|0,196608)|0;A=0;while(1){D=A<<8;gGz(C+D|0,0,256);I=D+1048576|0;H=0;do{E=I+(c[611648+(H<<2)>>2]|0)|0;J=(H<<4)+D|0;K=0;do{L=E+(c[610384+(K<<2)>>2]|0)|0;if(((d[x+((L|0)/8|0)|0]|0)&128>>>((L&7)>>>0)|0)!=0){L=C+(J+K)|0;a[L]=a[L]|4}K=K+1|0;}while((K|0)<16);H=H+1|0;}while((H|0)<16);H=D+524288|0;I=0;while(1){K=H+(c[611648+(I<<2)>>2]|0)|0;J=(I<<4)+D|0;E=0;do{L=K+(c[610384+(E<<2)>>2]|0)|0;if(((d[x+((L|0)/8|0)|0]|0)&128>>>((L&7)>>>0)|0)!=0){L=C+(J+E)|0;a[L]=a[L]|2}E=E+1|0;}while((E|0)<16);E=I+1|0;if((E|0)<16){I=E}else{N=0;break}}do{I=D+(c[611648+(N<<2)>>2]|0)|0;H=(N<<4)+D|0;E=0;do{J=I+(c[610384+(E<<2)>>2]|0)|0;if(((d[x+((J|0)/8|0)|0]|0)&128>>>((J&7)>>>0)|0)!=0){J=C+(H+E)|0;a[J]=a[J]|1}E=E+1|0;}while((E|0)<16);N=N+1|0;}while((N|0)<16);D=A+1|0;if((D|0)<2048){A=D}else{O=0;break}}while(1){if((O|0)>=1024){break L41581}P=9638528+(O<<2)|0;if((c[P>>2]|0)==(x|0)){break}else{O=O+1|0}}gGr(x);c[P>>2]=0}}while(0);fxU(0,425984);if((c[2394]|0)==0){Q=c[2112932]|0}else{c[2394]=0;A=c[3532596]|0;c[2112932]=A;C=c[3532592]|0;if((C|0)!=0){gGC(9104152,C|0,280)|0}c[2113054]=c[2113060];Q=A}A=c[2388070]|0;C=Q|0;D=0;while(1){E=A+D|0;c[C>>2]=E;c[C+131072>>2]=E;E=D+1024|0;if(E>>>0>1048575){break}else{C=C+4|0;D=E}}D=c[2388200]|0;C=Q+4096|0;A=1048576;while(1){E=D+(A-1048576)|0;c[C>>2]=E;c[C+65536>>2]=E;c[C+131072>>2]=E;E=A+1024|0;if(E>>>0>1114111){break}else{C=C+4|0;A=E}}A=c[3529646]|0;c[Q+4608>>2]=A;c[Q+70144>>2]=A;c[Q+135680>>2]=A;C=A+1024|0;c[Q+4612>>2]=C;c[Q+70148>>2]=C;c[Q+135684>>2]=C;C=c[3529624]|0;c[Q+5120>>2]=C;c[Q+70656>>2]=C;c[Q+136192>>2]=C;A=C+1024|0;c[Q+5124>>2]=A;c[Q+70660>>2]=A;c[Q+136196>>2]=A;A=c[2387094]|0;c[Q+5632>>2]=A;c[Q+136704>>2]=A;C=A+1024|0;c[Q+5636>>2]=C;c[Q+136708>>2]=C;C=A+2048|0;c[Q+5640>>2]=C;c[Q+136712>>2]=C;C=A+3072|0;c[Q+5644>>2]=C;c[Q+136716>>2]=C;C=c[2386184]|0;c[Q+8192>>2]=C;c[Q+73728>>2]=C;c[Q+139264>>2]=C;A=C+1024|0;c[Q+8196>>2]=A;c[Q+73732>>2]=A;c[Q+139268>>2]=A;A=C+2048|0;c[Q+8200>>2]=A;c[Q+73736>>2]=A;c[Q+139272>>2]=A;A=C+3072|0;c[Q+8204>>2]=A;c[Q+73740>>2]=A;c[Q+139276>>2]=A;A=C+4096|0;c[Q+8208>>2]=A;c[Q+73744>>2]=A;c[Q+139280>>2]=A;A=C+5120|0;c[Q+8212>>2]=A;c[Q+73748>>2]=A;c[Q+139284>>2]=A;A=C+6144|0;c[Q+8216>>2]=A;c[Q+73752>>2]=A;c[Q+139288>>2]=A;A=C+7168|0;c[Q+8220>>2]=A;c[Q+73756>>2]=A;c[Q+139292>>2]=A;A=C+8192|0;c[Q+8224>>2]=A;c[Q+73760>>2]=A;c[Q+139296>>2]=A;A=C+9216|0;c[Q+8228>>2]=A;c[Q+73764>>2]=A;c[Q+139300>>2]=A;A=C+10240|0;c[Q+8232>>2]=A;c[Q+73768>>2]=A;c[Q+139304>>2]=A;A=C+11264|0;c[Q+8236>>2]=A;c[Q+73772>>2]=A;c[Q+139308>>2]=A;A=c[3529850]|0;C=Q+12288|0;D=3145728;while(1){E=A+(D-3145728)|0;c[C>>2]=E;c[C+131072>>2]=E;E=D+1024|0;if(E>>>0>3670015){break}else{C=C+4|0;D=E}}D=c[3529848]|0;C=Q+14336|0;A=3670016;while(1){E=D+(A-3670016)|0;c[C>>2]=E;c[C+131072>>2]=E;E=A+1024|0;if(E>>>0>3801087){break}else{C=C+4|0;A=E}}c[Q+196728>>2]=3208;c[Q+196648>>2]=1508;c[Q+196688>>2]=2112;c[Q+196608>>2]=2662;A=c[3532592]|0;if((A|0)!=0){gGC(A|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;c[3528554]=-1;c[2113160]=1;A=gGq(3148)|0;C=A;c[2433592]=C;if((A|0)!=0){gGz(A|0,0,3148);c[A+3120>>2]=3128;c[A+3124>>2]=1840;c[A+3128>>2]=136;c[A+3132>>2]=1902;c[2432840]=0;D=0;do{c[C+48+(D<<2)>>2]=0;D=D+1|0;}while((D|0)<768);c[2113158]=0;c[2415198]=0;D=c[2427044]|0;c[9681616+(D<<3)>>2]=809272;c[9681620+(D<<3)>>2]=0;c[2427044]=D+1}c[3528554]=0;f43(A);D=c[3528554]|0;C=9731360+(D<<2)|0;E=c[C>>2]|0;c[2113158]=E;H=c[3527418]|0;I=c[2433592]|0;c[I+(D*3148|0)+48>>2]=H;c[I+(D*3148|0)+1072>>2]=H;c[I+(D*3148|0)+2096>>2]=H;J=H+256|0;c[I+(D*3148|0)+52>>2]=J;c[I+(D*3148|0)+1076>>2]=J;c[I+(D*3148|0)+2100>>2]=J;J=H+512|0;c[I+(D*3148|0)+56>>2]=J;c[I+(D*3148|0)+1080>>2]=J;c[I+(D*3148|0)+2104>>2]=J;J=H+768|0;c[I+(D*3148|0)+60>>2]=J;c[I+(D*3148|0)+1084>>2]=J;c[I+(D*3148|0)+2108>>2]=J;J=H+1024|0;c[I+(D*3148|0)+64>>2]=J;c[I+(D*3148|0)+1088>>2]=J;c[I+(D*3148|0)+2112>>2]=J;J=H+1280|0;c[I+(D*3148|0)+68>>2]=J;c[I+(D*3148|0)+1092>>2]=J;c[I+(D*3148|0)+2116>>2]=J;J=H+1536|0;c[I+(D*3148|0)+72>>2]=J;c[I+(D*3148|0)+1096>>2]=J;c[I+(D*3148|0)+2120>>2]=J;J=H+1792|0;c[I+(D*3148|0)+76>>2]=J;c[I+(D*3148|0)+1100>>2]=J;c[I+(D*3148|0)+2124>>2]=J;J=c[3527406]|0;H=128;K=128;while(1){L=J+(K<<8)|0;c[I+(D*3148|0)+48+(K<<2)>>2]=L;c[I+(D*3148|0)+48+(K+512<<2)>>2]=L;L=H+1&65535;if((L&65535)>255){break}else{H=L;K=L&65535}}c[I+(D*3148|0)+3124>>2]=1380;c[I+(D*3148|0)+3120>>2]=1534;K=I+(D*3148|0)|0;if((K|0)!=0){H=K;gGC(H|0,9660752,48)|0}c[C>>2]=E;c[3528554]=-1;H=a[9680]|0;K=H?32e3:0;if(H){if(a[9624]|0){H=K*3|0;J=55937;while(1){if((J|0)>(H|0)){J=J>>1}else{R=1222;S=J;break}}}else{R=2462;S=K}c[2429380]=S;c[3542124]=R;mw(358e4,S);J=gGq(262144)|0;c[2406684]=J;gGz(J|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(358e4,11025)}c[(c[3531464]|0)+44344>>2]=46;h[745421]=.45;c[2436794]=1;h[745420]=.45;c[2436792]=2;Ux(0,7757,1);c[2407030]=128;c[2407068]=3;J=c[642608+(c[2436]<<2)>>2]|0;H=c[J+128>>2]|0;if((c[J+52>>2]&4|0)==0){c[2113068]=H;E=c[J+132>>2]|0;c[2113070]=E;c[2443814]=H;c[2440436]=E;T=H;U=E}else{c[2113070]=H;E=c[J+132>>2]|0;c[2113068]=E;c[2440436]=H;c[2443814]=E;T=E;U=H}H=ag(T<<1,U)|0;E=gGq(H)|0;c[2112926]=E;if((E|0)!=0){gGz(E|0,0,H|0)}H=c[2414548]|0;gGz(H|0,0,(c[2411448]|0)-H|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];H=c[3532592]|0;if((H|0)!=0){gGC(9104152,H|0,280)|0}c[2113054]=c[2113060]}RI();H=c[2394]|0;E=c[14130368+(H<<2)>>2]|0;if((E|0)!=0){gGC(E|0,9104152,280)|0}c[8452240+(H<<2)>>2]=c[2113054];c[2394]=-1;c[3528554]=0;f43(c[2433592]|0);H=c[3528554]|0;c[2113158]=c[9731360+(H<<2)>>2];a[9660796]=0;a[9660797]=0;a[9660786]=0;a[9660787]=0;c[2415191]=0;a[9660784]=a[9660784]|80;E=c[2433592]|0;J=c[E+(H*3148|0)+1068>>2]|0;do{if((J|0)==0){C=c[E+(H*3148|0)+3120>>2]|0;if((C|0)==0){V=0;W=0;X=H;Y=E;break}D=gj[C&4095](-2)|0;C=c[3528554]|0;I=c[2433592]|0;A=c[I+(C*3148|0)+1068>>2]|0;L=(D&255)<<8;if((A|0)!=0){Z=A;_=L;$=C;aa=I;z=32331;break}A=c[I+(C*3148|0)+3120>>2]|0;if((A|0)==0){V=0;W=L;X=C;Y=I;break}I=gj[A&4095](-1)|0;V=I;W=L;X=c[3528554]|0;Y=c[2433592]|0}else{Z=J;_=(d[J+254|0]|0)<<8;$=H;aa=E;z=32331}}while(0);if((z|0)==32331){V=a[Z+255|0]|0;W=_;X=$;Y=aa}E=V&255|W;c[2415188]=E;b[4830376]=E&65535;E=Y+(X*3148|0)|0;if((E|0)!=0){H=E;gGC(H|0,9660752,48)|0}c[9731360+(X<<2)>>2]=c[2113158];c[3528554]=-1;c[2113156]=0;a[9628264]=0;c[2407033]=0;H=c[3541206]|0;c[3541190]=H;c[3541198]=H;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=H+256;c[3541199]=H+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=H+512;c[3541200]=H+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=H+768;c[3541201]=H+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;mx(0);a[9754889]=-1;a[9754888]=-1;a[9754881]=0;a[9754880]=0;B=0;i=e;return B|0}}while(0);c[2414846]=0;B=1;i=e;return B|0}function aJr(){var a=0,b=0,d=0,e=0,f=0;c[2113070]=0;c[2113068]=0;a=c[2112926]|0;if((a|0)!=0){gGr(a);c[2112926]=0}a=c[3531464]|0;c[a+44344>>2]=0;c[a+44348>>2]=0;if((a|0)!=0){gGr(a);c[3531464]=0}a=c[2406684]|0;if((a|0)!=0){gGr(a);c[2406684]=0}Uw(0);c[3541206]=0;if((c[2392]|0)>=0){a=0;do{b=14130368+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}b=14130384+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}a=a+1|0;}while((a|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;c[2113160]=0;a=c[2433592]|0;if((a|0)!=0){gGr(a);c[2433592]=0}a=c[2414846]|0;b=0;while(1){if((b|0)>=1024){e=32414;break}f=9638528+(b<<2)|0;if((c[f>>2]|0)==(a|0)){break}else{b=b+1|0}}if((e|0)==32414){c[2414846]=0;return 0}gGr(a);c[f>>2]=0;c[2414846]=0;return 0}function aJs(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;if((a[9623368]|0)!=0){e=c[2414548]|0;gGz(e|0,0,(c[2411448]|0)-e|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060]}RI();e=c[2394]|0;f=c[14130368+(e<<2)>>2]|0;if((f|0)!=0){gGC(f|0,9104152,280)|0}c[8452240+(e<<2)>>2]=c[2113054];c[2394]=-1;c[3528554]=0;f43(c[2433592]|0);e=c[3528554]|0;c[2113158]=c[9731360+(e<<2)>>2];a[9660796]=0;a[9660797]=0;a[9660786]=0;a[9660787]=0;c[2415191]=0;a[9660784]=a[9660784]|80;f=c[2433592]|0;g=c[f+(e*3148|0)+1068>>2]|0;do{if((g|0)==0){h=c[f+(e*3148|0)+3120>>2]|0;if((h|0)==0){i=0;j=0;k=e;l=f;break}m=gj[h&4095](-2)|0;h=c[3528554]|0;n=c[2433592]|0;o=c[n+(h*3148|0)+1068>>2]|0;p=(m&255)<<8;if((o|0)!=0){q=o;r=p;s=h;t=n;u=32426;break}o=c[n+(h*3148|0)+3120>>2]|0;if((o|0)==0){i=0;j=p;k=h;l=n;break}n=gj[o&4095](-1)|0;i=n;j=p;k=c[3528554]|0;l=c[2433592]|0}else{q=g;r=d[g+254|0]<<8;s=e;t=f;u=32426}}while(0);if((u|0)==32426){i=a[q+255|0]|0;j=r;k=s;l=t}t=i&255|j;c[2415188]=t;b[4830376]=t&65535;t=l+(k*3148|0)|0;if((t|0)!=0){l=t;gGC(l|0,9660752,48)|0}c[9731360+(k<<2)>>2]=c[2113158];c[3528554]=-1;c[2113156]=0;a[9628264]=0;c[2407033]=0;k=c[3541206]|0;c[3541190]=k;c[3541198]=k;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=k+256;c[3541199]=k+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=k+512;c[3541200]=k+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=k+768;c[3541201]=k+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;mx(0);a[9754889]=-1;a[9754888]=-1;a[9754881]=0;a[9754880]=0}k=c[2113160]|0;if((k|0)>0){gGz(9731360,0,((k|0)>1?k<<2:4)|0)}c[2113158]=0;c[2387532]=-1;k=0;l=-1;t=-1;do{l=((a[9632328+k|0]&1)<<k^l&65535)&65535;t=((a[9630240+k|0]&1)<<k^t&65535)&65535;k=k+1|0;}while((k|0)<16);b[4775064]=l;b[4775065]=t;if((a[9543320]|0)!=0){a[9754880]=(a[9754880]|0)-4&255}if((a[9543321]|0)!=0){a[9754880]=(a[9754880]|0)+4&255}if((a[9543322]|0)!=0){a[9754888]=(a[9754888]|0)+4&255}if((a[9543323]|0)!=0){a[9754888]=(a[9754888]|0)-4&255}if((a[9543324]|0)!=0){a[9754881]=(a[9754881]|0)-4&255}if((a[9543325]|0)!=0){a[9754881]=(a[9754881]|0)+4&255}if((a[9543326]|0)!=0){a[9754889]=(a[9754889]|0)+4&255}if((a[9543327]|0)!=0){a[9754889]=(a[9754889]|0)-4&255}if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];t=c[3532592]|0;if((t|0)!=0){gGC(9104152,t|0,280)|0}c[2113054]=c[2113060]}c[3528554]=0;f43(c[2433592]|0);c[2113158]=c[9731360+(c[3528554]<<2)>>2];t=0;l=0;k=0;j=0;while(1){i=233333-k|0;c[2113056]=i;s=RG(i)|0;c[2113054]=(c[2113054]|0)+s;c[2276108]=-1;c[2113056]=-1;i=f45(67125-l|0)|0;c[2113158]=(c[2113158]|0)+i;r=c[2112964]|0;if((r|0)==0){v=t;w=0}else{q=a[9688]|0?2:0;u=t<<1;gg[c[3542124]&4095](r+(u<<1)|0,q);r=c[2112964]|0;Uu(0,r+(u<<1)|0,q);v=q+t|0;w=r}r=j+1|0;if((r|0)<256){t=v;l=i+l|0;k=s+k|0;j=r}else{break}}c[8452200+(c[2394]<<2)>>2]=8198;c[2276080]=1536;if((c[2276079]|0)>>>0<1536){RH(6);x=c[2112964]|0}else{x=w}do{if((x|0)!=0){w=(a[9688]|0?534:0)-v|0;if((w|0)<=0){break}j=v<<1;gg[c[3542124]&4095](x+(j<<1)|0,w);Uu(0,(c[2112964]|0)+(j<<1)|0,w)}}while(0);x=c[3528554]|0;v=(c[2433592]|0)+(x*3148|0)|0;if((v|0)!=0){w=v;gGC(w|0,9660752,48)|0}c[9731360+(x<<2)>>2]=c[2113158];c[3528554]=-1;x=c[2394]|0;w=c[14130368+(x<<2)>>2]|0;if((w|0)!=0){gGC(w|0,9104152,280)|0}c[8452240+(x<<2)>>2]=c[2113054];c[2394]=-1;if((c[2112968]|0)==0){y=c[3527264]|0;z=c[3529682]|0;gGC(y|0,z|0,2048)|0;A=c[3527262]|0;B=c[3529672]|0;gGC(A|0,B|0,2048)|0;return 0}aJt()|0;y=c[3527264]|0;z=c[3529682]|0;gGC(y|0,z|0,2048)|0;A=c[3527262]|0;B=c[3529672]|0;gGC(A|0,B|0,2048)|0;return 0}function aJt(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;if((a[9547048]|0)!=0){d=c[2387094]|0;f=c[3529886]|0;g=0;do{h=g>>>1;i=e[d+((h|1)<<1)>>1]|0;c[f+(g>>>2<<2)>>2]=i>>>8<<3&2016|i<<8&63488|(e[d+(h<<1)>>1]|0)>>>3&31;g=g+4|0;}while((g|0)<4096);c[f+4096>>2]=0;a[9547048]=0}f=c[2113068]|0;g=c[2113070]|0;d=ag(g,f)|0;h=c[2112926]|0;if((d|0)>0){i=0;while(1){b[h+(i<<1)>>1]=1024;j=i+1|0;if((j|0)<(d|0)){i=j}else{k=h;break}}}else{k=h}h=c[3527262]|0;i=c[3530508]|0;aJv(h,i,768,0);d=c[3530984]|0;j=e[d+4>>1]|0;l=e[d>>1]|0;m=(c[2385354]|0)+65536|0;n=(g|0)>0;do{if((b[d+12>>1]&2)==0){if(n){o=k;p=0;q=m}else{break}while(1){if((f|0)>0){r=0;do{s=b[q+((r+l&2047)<<1)>>1]|0;if(s<<16>>16!=256){b[o+(r<<1)>>1]=s}r=r+1|0;}while((r|0)<(f|0))}r=p+1|0;if((r|0)<(g|0)){o=o+(f<<1)|0;p=r;q=q+4096|0}else{break}}}else{if(!n){break}r=l+160|0;s=k;t=0;u=m;while(1){v=0;do{w=b[u+((v+j&2047)<<1)>>1]|0;if(w<<16>>16!=256){b[s+(v<<1)>>1]=w}w=b[u+((r+v&2047)<<1)>>1]|0;if(w<<16>>16!=256){b[s+(v+160<<1)>>1]=w}v=v+1|0;}while((v|0)<160);v=t+1|0;if((v|0)<(g|0)){s=s+(f<<1)|0;t=v;u=u+4096|0}else{break}}}}while(0);j=c[3527264]|0;m=c[3530744]|0;aJv(j,m,512,0);aJv(h,i,768,8192);i=c[2386184]|0;h=c[3530376]|0;l=0;do{n=(l<<3&248)-16|0;q=((l|0)/32|0)<<3;p=e[i+(l<<1)>>1]|0;if((n|0)<(g|0)&(q|0)<(f|0)){Sr(k,p&2047,q,n,p>>>12,4,0,0,h)}l=l+1|0;}while((l|0)<2048);aJv(j,m,512,8192);R8(c[3529886]|0);return 0}function aJu(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=i;i=i+128|0;g=f|0;h=f+16|0;j=f+32|0;k=f+48|0;l=f+64|0;m=f+80|0;n=f+96|0;o=f+112|0;if((e|0)!=0){c[e>>2]=169762}if((b&32|0)!=0){gGz(o|0,0,12);e=c[2414548]|0;c[o>>2]=e;c[o+4>>2]=(c[2411448]|0)-e;c[o+12>>2]=162152;e=c[2076592]|0;gj[e&4095](o)|0}if((b&64|0)==0){i=f;return 0}o=l|0;gGz(k|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){e=l+9|0;l=j;p=j|0;q=j+4|0;r=j+12|0;s=k|0;t=k+4|0;u=k+12|0;v=0;do{gGC(o|0,614896,11)|0;a[e]=v+48&255;w=8452256+(v<<2)|0;gGz(l|0,0,12);c[p>>2]=w;c[q>>2]=4;c[r>>2]=164976;gj[c[2076592]&4095](j)|0;if((c[w>>2]|0)!=0){c[s>>2]=c[14130368+(v<<2)>>2];c[t>>2]=c[8452184+(v<<2)>>2];c[u>>2]=o;w=c[2076592]|0;gj[w&4095](k)|0}v=v+1|0;}while((v|0)<=(c[2392]|0))}gGz(h|0,0,12);c[h>>2]=8453216;c[h+4>>2]=4;c[h+12>>2]=107480;gj[c[2076592]&4095](h)|0;gGz(g|0,0,12);c[g>>2]=14168504;c[g+4>>2]=256;c[g+12>>2]=476464;gj[c[2076592]&4095](g)|0;if((b&2|0)!=0){b=0;do{mv(0,b,d[14168504+b|0]|0);b=b+1|0;}while((b|0)<256)}Ut(0);gGz(n|0,0,12);c[n>>2]=9754888;c[n+4>>2]=2;c[n+12>>2]=139672;gj[c[2076592]&4095](n)|0;gGz(m|0,0,12);c[m>>2]=9754880;c[m+4>>2]=2;c[m+12>>2]=112640;gj[c[2076592]&4095](m)|0;i=f;return 0}function aJv(a,b,d,f){a=a|0;b=b|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=a;a=c[2112926]|0;h=(c[2113222]&1|0)==0;i=0;do{j=e[g+((i|2)<<1)>>1]|0;L41902:do{if((j&8192|0)==(f|0)){k=e[g+(i<<1)>>1]|0;if(!((k&4096|0)==0|h)){break}l=j>>>9&15;m=1<<(k>>>9&3);n=m-1|0;o=j&511;p=k&511;q=p-16|0;r=o>>>0>319?j|-512:o;o=(q|0)>255?p-528|0:q;if((r+16|0)>>>0>336){break}q=k&16384;p=(q|0)!=0;s=(-m&16383&(e[g+((i|1)<<1)>>1]|0))+(p?0:n)|0;t=(q>>>13)-1|0;if((m|0)<=0){break}m=(k&8192|0)!=0;if(p){u=n}else{if(m){p=n;while(1){SJ(a,s-(ag(p,t)|0)&2047,r,(p*-16|0)+o|0,l,4,0,d,b);if((p|0)>0){p=p-1|0}else{break L41902}}}else{p=n;while(1){SH(a,s-(ag(p,t)|0)&2047,r,(p*-16|0)+o|0,l,4,0,d,b);if((p|0)>0){p=p-1|0}else{break L41902}}}}while(1){p=s-(ag(u,t)|0)&2047;n=(u*-16|0)+o|0;if(m){SN(a,p,r,n,l,4,0,d,b)}else{SL(a,p,r,n,l,4,0,d,b)}if((u|0)>0){u=u-1|0}else{break}}}}while(0);i=i+4|0;}while((i|0)<1024);return}function aJw(d,f){d=d|0;f=f|0;var g=0,h=0,i=0;if((d&16773120|0)==1441792){g=c[2387094]|0;b[g+(d&4094)>>1]=f;h=g;g=d>>>1&2046;i=e[h+((g|1)<<1)>>1]|0;c[(c[3529886]|0)+(g>>>1<<2)>>2]=i>>>8<<3&2016|i<<8&63488|(e[h+(g<<1)>>1]|0)>>>3&31;return}if((d&16777200|0)==1507328){b[(c[3530984]|0)+(d&14)>>1]=f;return}if((d&16252928|0)==3145728){g=d&524286;b[(c[3529850]|0)+g>>1]=f;h=c[2385354]|0;b[h+(g<<1)>>1]=(f&65535)>>>8&15|256;b[h+((g|1)<<1)>>1]=f&15|256;return}if((d&16646144|0)==3670016){g=d&131070;b[(c[3529848]|0)+g>>1]=f;h=d>>>9<<3&56|d&6|(g>>>3<<5&2016|g>>>12)<<6;g=c[3530376]|0;a[g+h|0]=(f&65535)>>>8&15;a[g+(h|1)|0]=f&15;return}if((d|0)==1966080){h=c[3529672]|0;g=c[3529624]|0;gGC(h|0,g|0,2048)|0;return}else if((d|0)==1835008){g=c[3529682]|0;h=c[3529646]|0;gGC(g|0,h|0,2048)|0;return}else if((d|0)==1704036){a[c[3528208]|0]=f&255;f44(1);return}else{return}}function aJx(d,e){d=d|0;e=e|0;var f=0,g=0,h=0;if((d&16252928|0)==3145728){f=c[3529850]|0;a[f+(d&524287^1)|0]=e;g=d&524286;h=b[f+g>>1]|0;f=c[2385354]|0;b[f+(g<<1)>>1]=(h&65535)>>>8&15|256;b[f+((g|1)<<1)>>1]=h&15|256;return}if((d&16646144|0)!=3670016){return}h=c[3529848]|0;a[h+(d&131071^1)|0]=e;e=d&131070;g=b[h+e>>1]|0;h=d>>>9<<3&56|d&6|(e>>>3<<5&2016|e>>>12)<<6;e=c[3530376]|0;a[e+h|0]=(g&65535)>>>8&15;a[e+(h|1)|0]=g&15;return}function aJy(c){c=c|0;var e=0;if((c|0)==1704736){e=a[9634648]&4|b[4775065]&-5}else if((c|0)==1638408){e=d[9754889]|0}else if((c|0)==1638410){e=d[9754881]|0}else if((c|0)==1638400){e=d[9754888]|0}else if((c|0)==1638402){e=d[9754880]|0}else if((c|0)==1704986){e=b[4775064]|0}else{e=0}return e|0}function aJz(d){d=d|0;var e=0,f=0;if((d|0)==1705190){e=a[9634650]|0;return e|0}else if((d|0)==1704737){f=c[2384302]^8;c[2384302]=f;e=(b[4775065]&243|f|a[9634648]&4)&255;return e|0}else if((d|0)==1705191){e=a[9634649]|0;return e|0}else{e=0;return e|0}return 0}function aJA(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((e|0)==2049){b=c[2113304]|0;a[14168504+b|0]=d;mv(0,b,d&255);return}else if((e|0)==2048){c[2113304]=d&255;return}else if((e|0)==4096){Uv(0,d);return}else if((e|0)==6144){a[9660787]=0;return}else{return}}function aJB(b){b=b|0;var d=0,e=0;d=b&65535;if((d|0)==6144){e=a[c[3528208]|0]|0}else if((d|0)==2048|(d|0)==2049){e=c[(c[3531464]|0)+4240>>2]&255}else if((d|0)==4096){e=c[2113156]&255}else{e=0}return e|0}function aJC(b){b=b|0;var d=0;d=(b|0)!=0|0;if((d|0)==0){a[9660786]=0}else if((d|0)==1){f44(0)}d=f45(1e3)|0;c[2113158]=(c[2113158]|0)+d;return}function aJD(d,e){d=d|0;e=e|0;var f=0,g=0;f=d&-16;if((f|0)==2359296){b[(c[2383435]|0)+((d>>>1&7)<<1)>>1]=e;return}else if((f|0)==2883584){b[(c[2383434]|0)+((d>>>1&7)<<1)>>1]=e;return}else{if((d|0)==1048582){c[2383412]=e&255;if((a[9661085]|0)==1){return}a[9661085]=1;if((a[9661088]|0)!=0){return}a[9661088]=2;return}else if((d|0)==3194880){f=c[2386552]|0;g=c[2386376]|0;gGC(f|0,g|0,2048)|0;return}else if((d|0)==1048576|(d|0)==1048578){b[(c[2394694]|0)+((d>>>1&1)<<1)>>1]=e;return}else{return}}}function aJE(d,e){d=d|0;e=e|0;if((d|0)==1048576|(d|0)==1048577|(d|0)==1048578|(d|0)==1048579){b[(c[2394694]|0)+((d>>>1&1)<<1)>>1]=e&255;return}else if((d|0)==1048583){c[2383412]=e&255;if((a[9661085]|0)==1){return}a[9661085]=1;if((a[9661088]|0)!=0){return}a[9661088]=2;return}else if((d|0)==3194880|(d|0)==3194881){d=c[2386552]|0;e=c[2386376]|0;gGC(d|0,e|0,2048)|0;return}else{return}}function aJF(a){a=a|0;var e=0;switch(a|0){case 1048582:case 1048584:case 1048586:case 1048588:case 1048590:{e=-1;break};case 1048576:{e=b[4775060]|0;break};case 1048578:{e=(b[4775061]&65527|c[2383408]&8)&65535;break};case 1048580:{e=(d[9634641]|0)<<8|(d[9634640]|0);break};default:{e=0}}return e|0}function aJG(d){d=d|0;var f=0;switch(d|0){case 1048577:{f=b[4775060]&255;break};case 1048576:{f=(e[4775060]|0)>>>8&255;break};case 1048581:{f=a[9634640]|0;break};case 1048580:{f=a[9634641]|0;break};case 1048582:case 1048583:case 1048584:case 1048585:case 1048586:case 1048587:case 1048588:case 1048589:case 1048590:case 1048591:{f=-1;break};case 1048578:case 1048579:{f=(b[4775061]&247|c[2383408]&8)&255;break};default:{f=0}}return f|0}function aJH(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2099020+(b*112|0)>>2];c[a+104>>2]=c[2099024+(b*112|0)>>2];c[a+108>>2]=c[2099028+(b*112|0)>>2];d=0;return d|0}function aJI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=2098920+(b*112|0);e=0;return e|0}function aJJ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1176456+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aJK(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>46){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3269824+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aJL(){return aJX(0)|0}function aJM(){var a=0,b=0,d=0,e=0,f=0;c[2113070]=0;c[2113068]=0;a=c[2112926]|0;if((a|0)!=0){gGr(a);c[2112926]=0}aE2();if((c[2392]|0)>=0){a=0;do{b=14130368+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}b=14130384+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}a=a+1|0;}while((a|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;aFe();a=c[2414844]|0;b=0;while(1){if((b|0)>=1024){e=32684;break}f=9638528+(b<<2)|0;if((c[f>>2]|0)==(a|0)){break}else{b=b+1|0}}if((e|0)==32684){c[2414844]=0;return 0}gGr(a);c[f>>2]=0;c[2414844]=0;return 0}function aJN(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((a[9623360]|0)!=0){d=c[2414546]|0;gGz(d|0,0,(c[2411446]|0)-d|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;aE7();gGz(c[2383428]|0,0,4096);gGz(c[2383426]|0,0,4096);d=c[2383424]|0;if((d|0)!=0){gGz(d|0,0,4096);gGz(c[2383422]|0,0,4096)}gGz(c[2383434]|0,0,16);gGz(c[2383435]|0,0,16);gGz(c[2383430]|0,0,8192);gGz(c[2383431]|0,0,8192);d=c[2383432]|0;if((d|0)!=0){gGz(d|0,0,8192);gGz(c[2383433]|0,0,8192)}b[4766836]=0;c[2426968]=0;c[3528794]=0;c[1765522]=65535;c[2429656]=0;c[2427042]=0;c[2429386]=0;c[2429384]=0;c[2429382]=0}c[2387530]=-1;d=0;e=-1;f=-1;do{e=((a[9632312+d|0]&1)<<d^e&65535)&65535;f=((a[9630224+d|0]&1)<<d^f&65535)&65535;d=d+1|0;}while((d|0)<16);b[4775060]=e;b[4775061]=f;c[(c[2391608]|0)+60>>2]=0;c[(c[2391608]|0)+60>>2]=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060]}c[2388530]=9554128;f=c[2391608]|0;if((f|0)!=0){e=f;gGC(9661040,e|0,68)|0}c[2382]=0;c[2383408]=0;e=0;f=0;do{c[2113056]=808;d=RG(808)|0;c[2113054]=(c[2113054]|0)+d;c[2276108]=-1;c[2113056]=-1;fy_(542)|0;if((e|0)==248){c[2383408]=8}d=a[9688]|0?2:0;g=(c[3527024]|0)+(f<<1<<1)|0;if(a[801408]|0){gg[c[3542124]&4095](g,d)}if(a[801400]|0){Uu(0,g,d)}if((c[2429658]|0)!=0){Uu(1,g,d)}f=d+f|0;e=e+1|0;}while((e|0)<256);c[8452200+(c[2394]<<2)>>2]=8198;c[2276080]=1536;if((c[2276079]|0)>>>0<1536){RH(6)}e=c[2438228]|0;d=gGS(-1427243008,66222,e,(e|0)<0|0?-1:0)|0;e=d;Sb(138879);d=c[2443830]|0;if((d|0)<1073676288){c[2443830]=d-e}d=c[2443831]|0;if((d|0)<1073676288){c[2443831]=d-e}d=(c[3528512]|0)-e|0;c[3528512]=(d|0)<0?0:d;d=c[2112964]|0;do{if((d|0)!=0){gg[c[3542122]&4095](d,a[9688]|0?534:0);e=a[9688]|0;g=e?534:0;if((g|0)==(f|0)){h=f;i=e}else{e=g-f|0;g=(c[3527024]|0)+(f<<1<<1)|0;if(a[801408]|0){gg[c[3542124]&4095](g,e)}if(a[801400]|0){Uu(0,g,e)}if((c[2429658]|0)!=0){Uu(1,g,e)}e=a[9688]|0;h=e?534:0;i=e}if((h|0)<=0){break}e=c[3527024]|0;g=c[2112964]|0;j=i?534:0;k=0;do{l=k<<1;m=g+(l<<1)|0;b[m>>1]=(b[m>>1]|0)+(b[e+(l<<1)>>1]|0)&65535;m=l|1;l=g+(m<<1)|0;b[l>>1]=(b[l>>1]|0)+(b[e+(m<<1)>>1]|0)&65535;k=k+1|0;}while((k|0)<(j|0))}}while(0);i=c[(c[2388530]|0)+12304>>2]|0;if((i|0)!=0){h=i;gGC(h|0,9661040,68)|0}c[2382]=-1;h=c[2394]|0;i=c[14130368+(h<<2)>>2]|0;if((i|0)!=0){gGC(i|0,9104152,280)|0}c[8452240+(h<<2)>>2]=c[2113054];c[2394]=-1;if((c[2112968]|0)==0){return 0}aJO()|0;return 0}function aJO(){var d=0,f=0,g=0,h=0,i=0;d=c[3530232]|0;f=c[3530228]|0;g=c[3529884]|0;h=0;do{i=e[d+(h<<1)>>1]|0;c[g+(h<<2)>>2]=b[f+(h<<1)>>1]&31|i&63488|i>>>8<<3&2016;h=h+1|0;}while((h|0)<1280);a[9547040]=0;aE3();aE5();h=b[c[2394694]>>1]&3;f=c[2112926]|0;aE0(c[591656+(h<<4)>>2]|0,f,65536);aE0(c[591660+(h<<4)>>2]|0,f,0);aJZ(0);aE0(c[591664+(h<<4)>>2]|0,f,0);aJZ(1);aE0(c[591668+(h<<4)>>2]|0,f,0);R8(c[3529884]|0);return 0}function aJP(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=i;i=i+64|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;if((d|0)!=0){c[d>>2]=169762}if((b&32|0)!=0){gGz(j|0,0,12);k=c[2414546]|0;c[j>>2]=k;c[j+4>>2]=(c[2411446]|0)-k;c[j+12>>2]=162152;k=c[2076592]|0;gj[k&4095](j)|0}if((b&64|0)==0){i=e;return 0}j=h|0;gGz(g|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){k=h+9|0;h=f;l=f|0;m=f+4|0;n=f+12|0;o=g|0;p=g+4|0;q=g+12|0;r=0;do{gGC(j|0,614896,11)|0;a[k]=r+48&255;s=8452256+(r<<2)|0;gGz(h|0,0,12);c[l>>2]=s;c[m>>2]=4;c[n>>2]=164976;gj[c[2076592]&4095](f)|0;if((c[s>>2]|0)!=0){c[o>>2]=c[14130368+(r<<2)>>2];c[p>>2]=c[8452184+(r<<2)>>2];c[q>>2]=j;s=c[2076592]|0;gj[s&4095](g)|0}r=r+1|0;}while((r|0)<=(c[2392]|0))}aFf(b,d);aE6();i=e;return 0}function aJQ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[994964+(b*112|0)>>2];c[a+104>>2]=c[994968+(b*112|0)>>2];c[a+108>>2]=c[994972+(b*112|0)>>2];d=0;return d|0}function aJR(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<21&(d|0)==0)){e=1;return e|0}c[a>>2]=994864+(b*112|0);e=0;return e|0}function aJS(){return aJX(1)|0}function aJT(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1348468+(b*112|0)>>2];c[a+104>>2]=c[1348472+(b*112|0)>>2];c[a+108>>2]=c[1348476+(b*112|0)>>2];d=0;return d|0}function aJU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=1348368+(b*112|0);e=0;return e|0}function aJV(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6533764+(b*112|0)>>2];c[a+104>>2]=c[6533768+(b*112|0)>>2];c[a+108>>2]=c[6533772+(b*112|0)>>2];d=0;return d|0}function aJW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=6533664+(b*112|0);e=0;return e|0}function aJX(d){d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;e=i;i=i+1680|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;B=e+1200|0;C=e+1312|0;D=e+1320|0;E=e+1432|0;F=e+1440|0;G=e+1552|0;H=e+1560|0;I=e+1672|0;c[2424]=5800;c[2414844]=0;c[2388068]=0;c[2387768]=524288;c[3530742]=589824;c[3530506]=1638400;c[3530374]=2686976;c[3530304]=4784128;c[3541206]=6881280;c[3529740]=6881280;c[3529696]=7929856;c[3529884]=8192e3;c[2414546]=8197120;c[2388198]=8197120;c[2387790]=8213504;c[2386376]=8221696;c[2386552]=8223744;c[3530232]=8225792;c[3530228]=8228352;c[3528644]=8230912;c[2394694]=8230913;c[2411446]=8230917;c[3527024]=8230917;J=(a[9688]|0?8233053:8230917)|0;c[2413986]=J;K=J;J=0;while(1){if((J|0)>=1024){break}L=9638528+(J<<2)|0;if((c[L>>2]|0)==0){M=32799;break}else{J=J+1|0}}do{if((M|0)==32799){J=gGq(K)|0;c[L>>2]=J;if((J|0)==0){break}gGz(J|0,0,K|0);c[2414844]=J;gGz(J|0,0,K|0);c[2388068]=J;c[2387768]=J+524288;c[3530742]=J+589824;c[3530506]=J+1638400;c[3530374]=J+2686976;c[3530304]=J+4784128;N=J+6881280|0;c[3541206]=N;c[3529740]=N;c[3529696]=J+7929856;c[3529884]=J+8192e3;N=J+8197120|0;c[2414546]=N;c[2388198]=N;c[2387790]=J+8213504;c[2386376]=J+8221696;c[2386552]=J+8223744;c[3530232]=J+8225792;c[3530228]=J+8228352;c[3528644]=J+8230912;c[2394694]=J+8230913;N=J+8230917|0;c[2411446]=N;c[3527024]=N;c[2413986]=J+(a[9688]|0?8233053:8230917);if((R6(J+1|0,0,2)|0)!=0){O=1;i=e;return O|0}if((R6(c[2388068]|0,1,2)|0)!=0){O=1;i=e;return O|0}if((R6((c[2388068]|0)+262145|0,2,2)|0)!=0){O=1;i=e;return O|0}if((R6((c[2388068]|0)+262144|0,3,2)|0)!=0){O=1;i=e;return O|0}J=c[2388068]|0;N=0;do{P=J+N|0;Q=a[P]|0;a[P]=Q&126|Q<<7|(Q&255)>>>7;N=N+1|0;}while((N|0)<524288);N=c[2387768]|0;if((c[3542200]|0)==0){O=1;i=e;return O|0}J=H+108|0;c[J>>2]=0;Q=H+100|0;c[Q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](H,4)|0;do{if((c[J>>2]|0)!=0){P=c[Q>>2]|0;c[I>>2]=9534384;R=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[R&16383](I,4,0)|0;if((P|0)<1){O=1;i=e;return O|0}if((gzL(N,0,4)|0)==0){break}else{O=1}i=e;return O|0}}while(0);N=c[3530742]|0;do{if((d|0)==0){if((c[3542200]|0)==0){O=1;i=e;return O|0}Q=t+108|0;c[Q>>2]=0;J=t+100|0;c[J>>2]=0;P=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[P&16383](t,5)|0;do{if((c[Q>>2]|0)!=0){P=c[J>>2]|0;c[u>>2]=9534384;R=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[R&16383](u,5,0)|0;if((P|0)<1){O=1;i=e;return O|0}if((gzL(N,0,5)|0)==0){break}else{O=1}i=e;return O|0}}while(0);J=c[3530374]|0;if((c[3542200]|0)==0){O=1;i=e;return O|0}Q=r+108|0;c[Q>>2]=0;P=r+100|0;c[P>>2]=0;R=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[R&16383](r,6)|0;do{if((c[Q>>2]|0)!=0){R=c[P>>2]|0;c[s>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](s,6,0)|0;if((R|0)<1){O=1;i=e;return O|0}if((gzL(J,0,6)|0)==0){break}else{O=1}i=e;return O|0}}while(0);J=(c[3530374]|0)+524288|0;if((c[3542200]|0)==0){O=1;i=e;return O|0}P=p+108|0;c[P>>2]=0;Q=p+100|0;c[Q>>2]=0;R=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[R&16383](p,7)|0;do{if((c[P>>2]|0)!=0){R=c[Q>>2]|0;c[q>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](q,7,0)|0;if((R|0)<1){O=1;i=e;return O|0}if((gzL(J,0,7)|0)==0){break}else{O=1}i=e;return O|0}}while(0);J=c[3530304]|0;if((c[3542200]|0)==0){O=1;i=e;return O|0}Q=n+108|0;c[Q>>2]=0;P=n+100|0;c[P>>2]=0;R=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[R&16383](n,8)|0;do{if((c[Q>>2]|0)!=0){R=c[P>>2]|0;c[o>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](o,8,0)|0;if((R|0)<1){O=1;i=e;return O|0}if((gzL(J,0,8)|0)==0){break}else{O=1}i=e;return O|0}}while(0);J=(c[3530304]|0)+524288|0;if((c[3542200]|0)==0){O=1;i=e;return O|0}P=l+108|0;c[P>>2]=0;Q=l+100|0;c[Q>>2]=0;R=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[R&16383](l,9)|0;do{if((c[P>>2]|0)!=0){R=c[Q>>2]|0;c[m>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](m,9,0)|0;if((R|0)<1){O=1;i=e;return O|0}if((gzL(J,0,9)|0)==0){break}else{O=1}i=e;return O|0}}while(0);J=c[3529740]|0;if((c[3542200]|0)==0){O=1;i=e;return O|0}Q=j+108|0;c[Q>>2]=0;P=j+100|0;c[P>>2]=0;R=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[R&16383](j,10)|0;do{if((c[Q>>2]|0)!=0){R=c[P>>2]|0;c[k>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](k,10,0)|0;if((R|0)<1){O=1;i=e;return O|0}if((gzL(J,0,10)|0)==0){break}else{O=1}i=e;return O|0}}while(0);J=c[3529696]|0;if((c[3542200]|0)==0){O=1;i=e;return O|0}P=f+108|0;c[P>>2]=0;Q=f+100|0;c[Q>>2]=0;R=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[R&16383](f,11)|0;if((c[P>>2]|0)==0){break}P=c[Q>>2]|0;c[g>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](g,11,0)|0;if((P|0)<1){O=1;i=e;return O|0}if((gzL(J,0,11)|0)==0){break}else{O=1}i=e;return O|0}else{if((R6(N,5,2)|0)!=0){O=1;i=e;return O|0}if((R6((c[3530742]|0)+1|0,6,2)|0)!=0){O=1;i=e;return O|0}if((R6((c[3530742]|0)+262144|0,7,2)|0)!=0){O=1;i=e;return O|0}if((R6((c[3530742]|0)+262145|0,8,2)|0)!=0){O=1;i=e;return O|0}J=c[3530374]|0;if((c[3542200]|0)==0){O=1;i=e;return O|0}P=F+108|0;c[P>>2]=0;Q=F+100|0;c[Q>>2]=0;R=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[R&16383](F,9)|0;do{if((c[P>>2]|0)!=0){R=c[Q>>2]|0;c[G>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](G,9,0)|0;if((R|0)<1){O=1;i=e;return O|0}if((gzL(J,0,9)|0)==0){break}else{O=1}i=e;return O|0}}while(0);J=(c[3530374]|0)+524288|0;if((c[3542200]|0)==0){O=1;i=e;return O|0}Q=D+108|0;c[Q>>2]=0;P=D+100|0;c[P>>2]=0;R=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[R&16383](D,10)|0;do{if((c[Q>>2]|0)!=0){R=c[P>>2]|0;c[E>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](E,10,0)|0;if((R|0)<1){O=1;i=e;return O|0}if((gzL(J,0,10)|0)==0){break}else{O=1}i=e;return O|0}}while(0);J=c[3530304]|0;if((c[3542200]|0)==0){O=1;i=e;return O|0}P=B+108|0;c[P>>2]=0;Q=B+100|0;c[Q>>2]=0;R=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[R&16383](B,11)|0;do{if((c[P>>2]|0)!=0){R=c[Q>>2]|0;c[C>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](C,11,0)|0;if((R|0)<1){O=1;i=e;return O|0}if((gzL(J,0,11)|0)==0){break}else{O=1}i=e;return O|0}}while(0);J=(c[3530304]|0)+524288|0;if((c[3542200]|0)==0){O=1;i=e;return O|0}Q=z+108|0;c[Q>>2]=0;P=z+100|0;c[P>>2]=0;R=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[R&16383](z,12)|0;do{if((c[Q>>2]|0)!=0){R=c[P>>2]|0;c[A>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](A,12,0)|0;if((R|0)<1){O=1;i=e;return O|0}if((gzL(J,0,12)|0)==0){break}else{O=1}i=e;return O|0}}while(0);J=c[3529740]|0;if((c[3542200]|0)==0){O=1;i=e;return O|0}P=x+108|0;c[P>>2]=0;Q=x+100|0;c[Q>>2]=0;R=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[R&16383](x,13)|0;do{if((c[P>>2]|0)!=0){R=c[Q>>2]|0;c[y>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](y,13,0)|0;if((R|0)<1){O=1;i=e;return O|0}if((gzL(J,0,13)|0)==0){break}else{O=1}i=e;return O|0}}while(0);J=c[3529696]|0;if((c[3542200]|0)==0){O=1;i=e;return O|0}Q=v+108|0;c[Q>>2]=0;P=v+100|0;c[P>>2]=0;R=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[R&16383](v,14)|0;if((c[Q>>2]|0)==0){break}Q=c[P>>2]|0;c[w>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](w,14,0)|0;if((Q|0)<1){O=1;i=e;return O|0}if((gzL(J,0,14)|0)==0){break}else{O=1}i=e;return O|0}}while(0);N=c[3530506]|0;J=N+262144|0;Q=c[3530742]|0;gGC(J|0,Q|0,262144)|0;J=Q+262144|0;gGC(N|0,J|0,262144)|0;aE_(N,Q,524288,1);Q=c[3530506]|0;aE_(Q,Q,524288,0);Q=c[3530374]|0;aE_(Q,Q,1048576,0);Q=c[3530304]|0;aE_(Q,Q,1048576,0);aE1(0,0,1);Q=c[3530506]|0;N=c[3530374]|0;c[2383440]=c[3530742];c[2383441]=Q;c[2383442]=N;c[2383436]=16383;c[2383437]=4095;c[2383438]=8191;c[2429666]=0;c[2429667]=512;c[2429668]=768;c[2429669]=1024;c[2429436]=3554;c[2429437]=3554;c[2429438]=3554;c[2429439]=3554;fxU(0,425984);if((c[2394]|0)==0){T=c[2112932]|0}else{c[2394]=0;N=c[3532596]|0;c[2112932]=N;Q=c[3532592]|0;if((Q|0)!=0){gGC(9104152,Q|0,280)|0}c[2113054]=c[2113060];T=N}N=c[2388068]|0;Q=T|0;J=0;while(1){P=N+J|0;c[Q>>2]=P;c[Q+131072>>2]=P;P=J+1024|0;if(P>>>0>524287){break}else{Q=Q+4|0;J=P}}J=c[2383432]|0;c[T+8192>>2]=J;c[T+73728>>2]=J;c[T+139264>>2]=J;Q=J+1024|0;c[T+8196>>2]=Q;c[T+73732>>2]=Q;c[T+139268>>2]=Q;Q=J+2048|0;c[T+8200>>2]=Q;c[T+73736>>2]=Q;c[T+139272>>2]=Q;Q=J+3072|0;c[T+8204>>2]=Q;c[T+73740>>2]=Q;c[T+139276>>2]=Q;Q=J+4096|0;c[T+8208>>2]=Q;c[T+73744>>2]=Q;c[T+139280>>2]=Q;Q=J+5120|0;c[T+8212>>2]=Q;c[T+73748>>2]=Q;c[T+139284>>2]=Q;Q=J+6144|0;c[T+8216>>2]=Q;c[T+73752>>2]=Q;c[T+139288>>2]=Q;Q=J+7168|0;c[T+8220>>2]=Q;c[T+73756>>2]=Q;c[T+139292>>2]=Q;Q=c[2383433]|0;c[T+8224>>2]=Q;c[T+73760>>2]=Q;c[T+139296>>2]=Q;J=Q+1024|0;c[T+8228>>2]=J;c[T+73764>>2]=J;c[T+139300>>2]=J;J=Q+2048|0;c[T+8232>>2]=J;c[T+73768>>2]=J;c[T+139304>>2]=J;J=Q+3072|0;c[T+8236>>2]=J;c[T+73772>>2]=J;c[T+139308>>2]=J;J=Q+4096|0;c[T+8240>>2]=J;c[T+73776>>2]=J;c[T+139312>>2]=J;J=Q+5120|0;c[T+8244>>2]=J;c[T+73780>>2]=J;c[T+139316>>2]=J;J=Q+6144|0;c[T+8248>>2]=J;c[T+73784>>2]=J;c[T+139320>>2]=J;J=Q+7168|0;c[T+8252>>2]=J;c[T+73788>>2]=J;c[T+139324>>2]=J;J=c[2383430]|0;c[T+10240>>2]=J;c[T+75776>>2]=J;c[T+141312>>2]=J;Q=J+1024|0;c[T+10244>>2]=Q;c[T+75780>>2]=Q;c[T+141316>>2]=Q;Q=J+2048|0;c[T+10248>>2]=Q;c[T+75784>>2]=Q;c[T+141320>>2]=Q;Q=J+3072|0;c[T+10252>>2]=Q;c[T+75788>>2]=Q;c[T+141324>>2]=Q;Q=J+4096|0;c[T+10256>>2]=Q;c[T+75792>>2]=Q;c[T+141328>>2]=Q;Q=J+5120|0;c[T+10260>>2]=Q;c[T+75796>>2]=Q;c[T+141332>>2]=Q;Q=J+6144|0;c[T+10264>>2]=Q;c[T+75800>>2]=Q;c[T+141336>>2]=Q;Q=J+7168|0;c[T+10268>>2]=Q;c[T+75804>>2]=Q;c[T+141340>>2]=Q;Q=c[2383431]|0;c[T+10272>>2]=Q;c[T+75808>>2]=Q;c[T+141344>>2]=Q;J=Q+1024|0;c[T+10276>>2]=J;c[T+75812>>2]=J;c[T+141348>>2]=J;J=Q+2048|0;c[T+10280>>2]=J;c[T+75816>>2]=J;c[T+141352>>2]=J;J=Q+3072|0;c[T+10284>>2]=J;c[T+75820>>2]=J;c[T+141356>>2]=J;J=Q+4096|0;c[T+10288>>2]=J;c[T+75824>>2]=J;c[T+141360>>2]=J;J=Q+5120|0;c[T+10292>>2]=J;c[T+75828>>2]=J;c[T+141364>>2]=J;J=Q+6144|0;c[T+10296>>2]=J;c[T+75832>>2]=J;c[T+141368>>2]=J;J=Q+7168|0;c[T+10300>>2]=J;c[T+75836>>2]=J;c[T+141372>>2]=J;J=c[3530232]|0;c[T+12288>>2]=J;c[T+77824>>2]=J;c[T+143360>>2]=J;Q=J+1024|0;c[T+12292>>2]=Q;c[T+77828>>2]=Q;c[T+143364>>2]=Q;Q=J+2048|0;c[T+12296>>2]=Q;c[T+77832>>2]=Q;c[T+143368>>2]=Q;Q=c[3530228]|0;c[T+12352>>2]=Q;c[T+77888>>2]=Q;c[T+143424>>2]=Q;J=Q+1024|0;c[T+12356>>2]=J;c[T+77892>>2]=J;c[T+143428>>2]=J;J=Q+2048|0;c[T+12360>>2]=J;c[T+77896>>2]=J;c[T+143432>>2]=J;J=c[2386376]|0;c[T+65408>>2]=J;c[T+130944>>2]=J;c[T+196480>>2]=J;Q=J+1024|0;c[T+65412>>2]=Q;c[T+130948>>2]=Q;c[T+196484>>2]=Q;Q=c[2388198]|0;c[T+65472>>2]=Q;c[T+131008>>2]=Q;c[T+196544>>2]=Q;J=Q+1024|0;c[T+65476>>2]=J;c[T+131012>>2]=J;c[T+196548>>2]=J;J=Q+2048|0;c[T+65480>>2]=J;c[T+131016>>2]=J;c[T+196552>>2]=J;J=Q+3072|0;c[T+65484>>2]=J;c[T+131020>>2]=J;c[T+196556>>2]=J;J=Q+4096|0;c[T+65488>>2]=J;c[T+131024>>2]=J;c[T+196560>>2]=J;J=Q+5120|0;c[T+65492>>2]=J;c[T+131028>>2]=J;c[T+196564>>2]=J;J=Q+6144|0;c[T+65496>>2]=J;c[T+131032>>2]=J;c[T+196568>>2]=J;J=Q+7168|0;c[T+65500>>2]=J;c[T+131036>>2]=J;c[T+196572>>2]=J;J=Q+8192|0;c[T+65504>>2]=J;c[T+131040>>2]=J;c[T+196576>>2]=J;J=Q+9216|0;c[T+65508>>2]=J;c[T+131044>>2]=J;c[T+196580>>2]=J;J=Q+10240|0;c[T+65512>>2]=J;c[T+131048>>2]=J;c[T+196584>>2]=J;J=Q+11264|0;c[T+65516>>2]=J;c[T+131052>>2]=J;c[T+196588>>2]=J;J=Q+12288|0;c[T+65520>>2]=J;c[T+131056>>2]=J;c[T+196592>>2]=J;J=Q+13312|0;c[T+65524>>2]=J;c[T+131060>>2]=J;c[T+196596>>2]=J;J=Q+14336|0;c[T+65528>>2]=J;c[T+131064>>2]=J;c[T+196600>>2]=J;J=Q+15360|0;c[T+65532>>2]=J;c[T+131068>>2]=J;c[T+196604>>2]=J;c[T+196728>>2]=550;c[T+196648>>2]=248;c[T+196688>>2]=1444;c[T+196608>>2]=2744;J=c[3532592]|0;if((J|0)!=0){gGC(J|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;aE8(c[2387768]|0,c[2387790]|0,8055e3,1,0,.6,1006875,.75,2013750,.6);h[745419]=.6;a[3203368]=1;h[745418]=.6;a[3203360]=1;h[745417]=.6;a[3203352]=1;h[745416]=.6;a[3203344]=1;J=c[642608+(c[2436]<<2)>>2]|0;Q=c[J+128>>2]|0;if((c[J+52>>2]&4|0)==0){c[2113068]=Q;N=c[J+132>>2]|0;c[2113070]=N;c[2443814]=Q;c[2440436]=N;U=Q;V=N}else{c[2113070]=Q;N=c[J+132>>2]|0;c[2113068]=N;c[2440436]=Q;c[2443814]=N;U=N;V=Q}Q=ag(U<<1,V)|0;N=gGq(Q)|0;c[2112926]=N;if((N|0)!=0){gGz(N|0,0,Q|0)}Q=c[2414546]|0;gGz(Q|0,0,(c[2411446]|0)-Q|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];Q=c[3532592]|0;if((Q|0)!=0){gGC(9104152,Q|0,280)|0}c[2113054]=c[2113060]}RI();Q=c[2394]|0;N=c[14130368+(Q<<2)>>2]|0;if((N|0)!=0){gGC(N|0,9104152,280)|0}c[8452240+(Q<<2)>>2]=c[2113054];c[2394]=-1;aE7();gGz(c[2383428]|0,0,4096);gGz(c[2383426]|0,0,4096);Q=c[2383424]|0;if((Q|0)!=0){gGz(Q|0,0,4096);gGz(c[2383422]|0,0,4096)}gGz(c[2383434]|0,0,16);gGz(c[2383435]|0,0,16);gGz(c[2383430]|0,0,8192);gGz(c[2383431]|0,0,8192);Q=c[2383432]|0;if((Q|0)!=0){gGz(Q|0,0,8192);gGz(c[2383433]|0,0,8192)}b[4766836]=0;c[2426968]=0;c[3528794]=0;c[1765522]=65535;c[2429656]=0;c[2427042]=0;c[2429386]=0;c[2429384]=0;c[2429382]=0;O=0;i=e;return O|0}}while(0);c[2414844]=0;O=1;i=e;return O|0}function aJY(a){a=a|0;return a>>>4<<12&28672|0}function aJZ(b){b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;d=c[2386552]|0;f=e[(c[2394694]|0)+2>>1]|0;g=(b|0)==0;b=c[3528644]|0;h=c[2112926]|0;i=c[3530304]|0;j=(c[2113222]&1|0)==0;k=0;do{l=e[d+(k<<1)>>1]|0;L42461:do{if((l&32768|0)!=0){m=e[d+((k|2)<<1)>>1]|0;n=m>>>12;o=n>>>0<f>>>0;if(g&o|(g|o)^1){break}if(!((m&2048|0)==0|j)){break}o=l&8192;p=l&16384;q=1<<(l>>>11&3);r=q-1|0;s=m&511;t=l&511;u=s>>>0>255?m|-512:s;s=t>>>0>255?l|-512:t;t=240-u|0;if((t|0)>256){break}m=(p>>>13^2)-1|0;v=(-q&8191&e[d+((k|1)<<1)>>1])+((p|0)!=0?0:r)|0;if((a[b]|0)==0){w=p;x=o;y=t;z=240-s|0;A=-16}else{w=p>>>14^1;x=o>>>13^1;y=u;z=s;A=16}if((q|0)<=0){break}q=(x|0)!=0;s=z-8|0;if((w|0)==0){B=r}else{if(q){u=r;while(1){o=v-(ag(u,m)|0)|0;SN(h,o,y,(ag(u,A)|0)+s|0,n,4,0,256,i);if((u|0)>0){u=u-1|0}else{break L42461}}}else{u=r;while(1){o=v-(ag(u,m)|0)|0;SL(h,o,y,(ag(u,A)|0)+s|0,n,4,0,256,i);if((u|0)>0){u=u-1|0}else{break L42461}}}}while(1){u=v-(ag(B,m)|0)|0;r=(ag(B,A)|0)+s|0;if(q){SJ(h,u,y,r,n,4,0,256,i)}else{SH(h,u,y,r,n,4,0,256,i)}if((B|0)>0){B=B-1|0}else{break}}}}while(0);k=k+4|0;}while((k|0)<1024);return}function aJ_(d,e){d=d|0;e=e|0;var f=0,g=0;f=d&-16;if((f|0)==741376){b[(c[2383434]|0)+((d>>>1&7)<<1)>>1]=e;return}else if((f|0)==745472){b[(c[2383435]|0)+((d>>>1&7)<<1)>>1]=e;return}else{if((d|0)==770048|(d|0)==770049){f=c[2386550]|0;g=c[2386374]|0;gGC(f|0,g|0,2048)|0;return}else if((d|0)==770050){c[2383412]=e&255;if((a[9661085]|0)==1){return}a[9661085]=1;if((a[9661088]|0)!=0){return}a[9661088]=2;return}else{return}}}function aJ$(d,e){d=d|0;e=e|0;switch(d|0){case 770048:case 770049:{gGC(c[2386550]|0,c[2386374]|0,2048)|0;return};case 770051:{c[2383412]=e&255;if((a[9661085]|0)==1){return}a[9661085]=1;if((a[9661088]|0)!=0){return}a[9661088]=2;return};case 770053:{switch(e<<24>>24){case 85:{c[2385316]=30;return};case-64:{c[2385316]=62;b[4766836]=0;return};case-1:{c[2385316]=118;b[4766836]=1;return};case-102:{c[2385316]=14;return};case-128:{c[2385316]=46;b[4766836]=1;return};case-86:{c[2385316]=116;return};case 14:{c[2385316]=14;b[4766836]=0;return};case 0:{c[2385316]=14;b[4766836]=0;return};case 64:{c[2385316]=30;b[4766836]=1;return};case-15:{c[2385316]=54;b[4766836]=1;return};default:{return}}break};case 770052:{if((e<<24>>24|0)==0){c[2385316]=14;b[4766836]=0;return}else if((e<<24>>24|0)==(-102|0)){c[2385316]=0;return}else if((e<<24>>24|0)==2){c[2385316]=25344;return}else{return}break};default:{return}}}function aJ0(a){a=a|0;var e=0;switch(a|0){case 770048:case 770049:{e=b[4775056]|0;break};case 770050:case 770051:{e=(d[9634633]|0)<<8|(d[9634632]|0);break};case 770052:{e=c[2385316]&65535;break};case 770054:case 770055:{e=(b[4775057]&247|c[2383408]&8)&65535;break};default:{e=0}}return e|0}function aJ1(d){d=d|0;var f=0;switch(d|0){case 770048:{f=(e[4775056]|0)>>>8&255;break};case 770054:case 770055:{f=(b[4775057]&247|c[2383408]&8)&255;break};case 770051:{f=a[9634632]|0;break};case 770050:{f=a[9634633]|0;break};case 770049:{f=b[4775056]&255;break};case 770052:{f=(c[2385316]|0)>>>8&255;break};case 770053:{f=c[2385316]&255;break};default:{f=0}}return f|0}function aJ2(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4783956+(b*112|0)>>2];c[a+104>>2]=c[4783960+(b*112|0)>>2];c[a+108>>2]=c[4783964+(b*112|0)>>2];d=0;return d|0}function aJ3(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=4783856+(b*112|0);e=0;return e|0}function aJ4(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1983704+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aJ5(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>38){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5541920+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aJ6(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0;e=i;i=i+1464|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;B=e+1200|0;C=e+1312|0;D=e+1320|0;E=e+1336|0;F=e+1400|0;c[2424]=5800;c[2414842]=0;c[2388066]=0;c[2387766]=524288;c[3530740]=589824;c[3530504]=2686976;c[3530372]=4784128;c[3530302]=5832704;c[3541206]=10027008;c[3529882]=11337728;c[2414544]=11345920;c[2388196]=11345920;c[2387788]=11362304;c[2386374]=11370496;c[2386550]=11372544;c[3530230]=11374592;c[3530226]=11378688;c[3528642]=11382784;c[2411444]=11382785;c[3527022]=11382785;G=(a[9688]|0?11384921:11382785)|0;c[2413984]=G;H=G;G=0;while(1){if((G|0)>=1024){break}I=9638528+(G<<2)|0;if((c[I>>2]|0)==0){J=33066;break}else{G=G+1|0}}do{if((J|0)==33066){G=gGq(H)|0;c[I>>2]=G;if((G|0)==0){break}gGz(G|0,0,H|0);c[2414842]=G;gGz(G|0,0,H|0);c[2388066]=G;c[2387766]=G+524288;c[3530740]=G+589824;c[3530504]=G+2686976;c[3530372]=G+4784128;c[3530302]=G+5832704;c[3541206]=G+10027008;c[3529882]=G+11337728;K=G+11345920|0;c[2414544]=K;c[2388196]=K;c[2387788]=G+11362304;c[2386374]=G+11370496;c[2386550]=G+11372544;c[3530230]=G+11374592;c[3530226]=G+11378688;c[3528642]=G+11382784;K=G+11382785|0;c[2411444]=K;c[3527022]=K;c[2413984]=G+(a[9688]|0?11384921:11382785);if((R6(G+1|0,0,2)|0)!=0){L=1;i=e;return L|0}if((R6(c[2388066]|0,1,2)|0)!=0){L=1;i=e;return L|0}if((R6((c[2388066]|0)+262145|0,2,2)|0)!=0){L=1;i=e;return L|0}if((R6((c[2388066]|0)+262144|0,3,2)|0)!=0){L=1;i=e;return L|0}G=c[2387766]|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}K=B+108|0;c[K>>2]=0;M=B+100|0;c[M>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](B,4)|0;do{if((c[K>>2]|0)!=0){N=c[M>>2]|0;c[C>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](C,4,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(G,0,4)|0)==0){break}else{L=1}i=e;return L|0}}while(0);G=c[3530504]|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}M=z+108|0;c[M>>2]=0;K=z+100|0;c[K>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](z,5)|0;do{if((c[M>>2]|0)!=0){N=c[K>>2]|0;c[A>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](A,5,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(G,0,5)|0)==0){break}else{L=1}i=e;return L|0}}while(0);if((R6((c[3530504]|0)+524288|0,6,2)|0)!=0){L=1;i=e;return L|0}if((R6((c[3530504]|0)+524289|0,7,2)|0)!=0){L=1;i=e;return L|0}G=c[3530372]|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}K=x+108|0;c[K>>2]=0;M=x+100|0;c[M>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](x,8)|0;do{if((c[K>>2]|0)!=0){N=c[M>>2]|0;c[y>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](y,8,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(G,0,8)|0)==0){break}else{L=1}i=e;return L|0}}while(0);G=c[3530302]|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}M=v+108|0;c[M>>2]=0;K=v+100|0;c[K>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](v,9)|0;do{if((c[M>>2]|0)!=0){N=c[K>>2]|0;c[w>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](w,9,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(G,0,9)|0)==0){break}else{L=1}i=e;return L|0}}while(0);G=(c[3530302]|0)+655360|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}K=t+108|0;c[K>>2]=0;M=t+100|0;c[M>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](t,10)|0;do{if((c[K>>2]|0)!=0){N=c[M>>2]|0;c[u>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](u,10,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(G,0,10)|0)==0){break}else{L=1}i=e;return L|0}}while(0);G=(c[3530302]|0)+1310720|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}M=r+108|0;c[M>>2]=0;K=r+100|0;c[K>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](r,11)|0;do{if((c[M>>2]|0)!=0){N=c[K>>2]|0;c[s>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](s,11,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(G,0,11)|0)==0){break}else{L=1}i=e;return L|0}}while(0);G=(c[3530302]|0)+1376256|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}K=p+108|0;c[K>>2]=0;M=p+100|0;c[M>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](p,12)|0;do{if((c[K>>2]|0)!=0){N=c[M>>2]|0;c[q>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](q,12,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(G,0,12)|0)==0){break}else{L=1}i=e;return L|0}}while(0);G=(c[3530302]|0)+1441792|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}M=n+108|0;c[M>>2]=0;K=n+100|0;c[K>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](n,13)|0;do{if((c[M>>2]|0)!=0){N=c[K>>2]|0;c[o>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](o,13,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(G,0,13)|0)==0){break}else{L=1}i=e;return L|0}}while(0);G=(c[3530302]|0)+1507328|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}K=l+108|0;c[K>>2]=0;M=l+100|0;c[M>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](l,14)|0;do{if((c[K>>2]|0)!=0){N=c[M>>2]|0;c[m>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](m,14,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(G,0,14)|0)==0){break}else{L=1}i=e;return L|0}}while(0);G=c[3541206]|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}M=j+108|0;c[M>>2]=0;K=j+100|0;c[K>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](j,15)|0;do{if((c[M>>2]|0)!=0){N=c[K>>2]|0;c[k>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](k,15,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(G,0,15)|0)==0){break}else{L=1}i=e;return L|0}}while(0);G=(c[3541206]|0)+1048576|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}K=f+108|0;c[K>>2]=0;M=f+100|0;c[M>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](f,16)|0;do{if((c[K>>2]|0)!=0){N=c[M>>2]|0;c[g>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](g,16,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(G,0,16)|0)==0){break}else{L=1}i=e;return L|0}}while(0);G=c[2388066]|0;M=0;do{K=G+(M|1)|0;N=a[K]|0;a[K]=(N&255)>>>4<<7|N&79|(N&255)>>>7<<5|(N&255)>>>5<<4&16;N=G+M|0;K=a[N]|0;a[N]=(K&255)>>>1<<6&64|K&-75|(K&255)>>>6<<3&8|(K&255)>>>3<<1&2;M=M+2|0;}while((M|0)<524288);M=c[3530302]|0;G=0;do{K=(G|0)/2|0;N=G+524288|0;O=(G|32)+524288|0;P=(G|1)+524288|0;Q=(G|33)+524288|0;R=G+1179648|0;S=G+1179680|0;T=G+1179649|0;U=G+1179681|0;V=K+1310720|0;W=K+1310736|0;X=K+1376256|0;Y=K+1376272|0;Z=K+1441792|0;_=K+1441808|0;$=K+1507328|0;aa=K+1507344|0;K=0;do{ab=K<<1;a[M+(N+ab)|0]=a[M+(V+K)|0]|0;a[M+(O+ab)|0]=a[M+(W+K)|0]|0;a[M+(P+ab)|0]=a[M+(X+K)|0]|0;a[M+(Q+ab)|0]=a[M+(Y+K)|0]|0;a[M+(R+ab)|0]=a[M+(Z+K)|0]|0;a[M+(S+ab)|0]=a[M+(_+K)|0]|0;a[M+(T+ab)|0]=a[M+($+K)|0]|0;a[M+(U+ab)|0]=a[M+(aa+K)|0]|0;K=K+1|0;}while((K|0)<16);G=G+64|0;}while((G|0)<131072);G=c[3530740]|0;M=c[3530504]|0;gGC(G|0,M|0,1048576)|0;M=D;K=E;aa=F;c[M>>2]=c[152908];c[M+4>>2]=c[152909];c[M+8>>2]=c[152910];c[M+12>>2]=c[152911];gGC(K|0,613752,64)|0;gGC(aa|0,611840,64)|0;U=0;while(1){if((U|0)>=1024){break}ac=9638528+(U<<2)|0;if((c[ac>>2]|0)==0){J=33127;break}else{U=U+1|0}}L42742:do{if((J|0)==33127){U=gGq(1048576)|0;c[ac>>2]=U;if((U|0)==0){break}gGz(U|0,0,1048576);gGC(U|0,G|0,1048576)|0;$=0;while(1){T=$<<6;gGz(G+T|0,0,64);_=$<<8;S=0;do{Z=1<<3-S;R=(c[D+(S<<2)>>2]|0)+_|0;Y=0;do{Q=R+(c[F+(Y<<2)>>2]|0)|0;X=(Y<<3)+T|0;P=0;do{W=Q+(c[E+(P+8<<2)>>2]|0)|0;if(((d[U+((W|0)/8|0)|0]|0)&128>>>((W&7)>>>0)|0)!=0){W=G+(X+P)|0;a[W]=(d[W]|0|Z)&255}P=P+1|0;}while((P|0)<8);Y=Y+1|0;}while((Y|0)<8);S=S+1|0;}while((S|0)<4);S=$+1|0;if((S|0)<32768){$=S}else{ad=0;break}}while(1){if((ad|0)>=1024){break L42742}ae=9638528+(ad<<2)|0;if((c[ae>>2]|0)==(U|0)){break}else{ad=ad+1|0}}gGr(U);c[ae>>2]=0}}while(0);G=c[3530504]|0;c[M>>2]=c[152908];c[M+4>>2]=c[152909];c[M+8>>2]=c[152910];c[M+12>>2]=c[152911];gGC(K|0,613752,64)|0;gGC(aa|0,611840,64)|0;$=0;while(1){if(($|0)>=1024){break}af=9638528+($<<2)|0;if((c[af>>2]|0)==0){J=33144;break}else{$=$+1|0}}L42767:do{if((J|0)==33144){$=gGq(1048576)|0;c[af>>2]=$;if(($|0)==0){break}gGz($|0,0,1048576);gGC($|0,G|0,1048576)|0;S=0;while(1){T=S<<8;gGz(G+T|0,0,256);_=S<<10;Y=0;do{Z=1<<3-Y;R=(c[D+(Y<<2)>>2]|0)+_|0;P=0;do{X=R+(c[F+(P<<2)>>2]|0)|0;Q=(P<<4)+T|0;W=0;do{O=X+(c[E+(W<<2)>>2]|0)|0;if(((d[$+((O|0)/8|0)|0]|0)&128>>>((O&7)>>>0)|0)!=0){O=G+(Q+W)|0;a[O]=(d[O]|0|Z)&255}W=W+1|0;}while((W|0)<16);P=P+1|0;}while((P|0)<16);Y=Y+1|0;}while((Y|0)<4);Y=S+1|0;if((Y|0)<8192){S=Y}else{ah=0;break}}while(1){if((ah|0)>=1024){break L42767}ai=9638528+(ah<<2)|0;if((c[ai>>2]|0)==($|0)){break}else{ah=ah+1|0}}gGr($);c[ai>>2]=0}}while(0);G=c[3530372]|0;c[M>>2]=c[152908];c[M+4>>2]=c[152909];c[M+8>>2]=c[152910];c[M+12>>2]=c[152911];gGC(K|0,613752,64)|0;gGC(aa|0,611840,64)|0;S=0;while(1){if((S|0)>=1024){break}aj=9638528+(S<<2)|0;if((c[aj>>2]|0)==0){J=33161;break}else{S=S+1|0}}L42792:do{if((J|0)==33161){S=gGq(524288)|0;c[aj>>2]=S;if((S|0)==0){break}gGz(S|0,0,524288);gGC(S|0,G|0,524288)|0;aa=0;while(1){K=aa<<8;gGz(G+K|0,0,256);M=aa<<10;U=0;do{Y=1<<3-U;T=(c[D+(U<<2)>>2]|0)+M|0;_=0;do{P=T+(c[F+(_<<2)>>2]|0)|0;Z=(_<<4)+K|0;R=0;do{W=P+(c[E+(R<<2)>>2]|0)|0;if(((d[S+((W|0)/8|0)|0]|0)&128>>>((W&7)>>>0)|0)!=0){W=G+(Z+R)|0;a[W]=(d[W]|0|Y)&255}R=R+1|0;}while((R|0)<16);_=_+1|0;}while((_|0)<16);U=U+1|0;}while((U|0)<4);U=aa+1|0;if((U|0)<4096){aa=U}else{ak=0;break}}while(1){if((ak|0)>=1024){break L42792}al=9638528+(ak<<2)|0;if((c[al>>2]|0)==(S|0)){break}else{ak=ak+1|0}}gGr(S);c[al>>2]=0}}while(0);G=c[3530302]|0;aE_(G,G,1310720,0);aE1(0,0,1);a[690376]=1;G=c[3530504]|0;aa=c[3530372]|0;c[2383440]=c[3530740];c[2383441]=G;c[2383442]=aa;c[2383436]=32767;c[2383437]=8191;c[2383438]=4095;c[2429436]=506;c[2429437]=506;c[2429438]=506;c[2429439]=506;c[2429666]=0;c[2429667]=512;c[2429668]=768;c[2429669]=1024;fxU(0,425984);if((c[2394]|0)==0){am=c[2112932]|0}else{c[2394]=0;aa=c[3532596]|0;c[2112932]=aa;G=c[3532592]|0;if((G|0)!=0){gGC(9104152,G|0,280)|0}c[2113054]=c[2113060];am=aa}aa=c[2388066]|0;G=am|0;$=0;while(1){U=aa+$|0;c[G>>2]=U;c[G+131072>>2]=U;U=$+1024|0;if(U>>>0>524287){break}else{G=G+4|0;$=U}}$=c[2388196]|0;c[am+2048>>2]=$;c[am+67584>>2]=$;c[am+133120>>2]=$;G=$+1024|0;c[am+2052>>2]=G;c[am+67588>>2]=G;c[am+133124>>2]=G;G=$+2048|0;c[am+2056>>2]=G;c[am+67592>>2]=G;c[am+133128>>2]=G;G=$+3072|0;c[am+2060>>2]=G;c[am+67596>>2]=G;c[am+133132>>2]=G;G=$+4096|0;c[am+2064>>2]=G;c[am+67600>>2]=G;c[am+133136>>2]=G;G=$+5120|0;c[am+2068>>2]=G;c[am+67604>>2]=G;c[am+133140>>2]=G;G=$+6144|0;c[am+2072>>2]=G;c[am+67608>>2]=G;c[am+133144>>2]=G;G=$+7168|0;c[am+2076>>2]=G;c[am+67612>>2]=G;c[am+133148>>2]=G;G=$+8192|0;c[am+2080>>2]=G;c[am+67616>>2]=G;c[am+133152>>2]=G;G=$+9216|0;c[am+2084>>2]=G;c[am+67620>>2]=G;c[am+133156>>2]=G;G=$+10240|0;c[am+2088>>2]=G;c[am+67624>>2]=G;c[am+133160>>2]=G;G=$+11264|0;c[am+2092>>2]=G;c[am+67628>>2]=G;c[am+133164>>2]=G;G=$+12288|0;c[am+2096>>2]=G;c[am+67632>>2]=G;c[am+133168>>2]=G;G=$+13312|0;c[am+2100>>2]=G;c[am+67636>>2]=G;c[am+133172>>2]=G;G=$+14336|0;c[am+2104>>2]=G;c[am+67640>>2]=G;c[am+133176>>2]=G;G=$+15360|0;c[am+2108>>2]=G;c[am+67644>>2]=G;c[am+133180>>2]=G;G=c[2383430]|0;c[am+2560>>2]=G;c[am+68096>>2]=G;c[am+133632>>2]=G;$=G+1024|0;c[am+2564>>2]=$;c[am+68100>>2]=$;c[am+133636>>2]=$;$=G+2048|0;c[am+2568>>2]=$;c[am+68104>>2]=$;c[am+133640>>2]=$;$=G+3072|0;c[am+2572>>2]=$;c[am+68108>>2]=$;c[am+133644>>2]=$;$=G+4096|0;c[am+2576>>2]=$;c[am+68112>>2]=$;c[am+133648>>2]=$;$=G+5120|0;c[am+2580>>2]=$;c[am+68116>>2]=$;c[am+133652>>2]=$;$=G+6144|0;c[am+2584>>2]=$;c[am+68120>>2]=$;c[am+133656>>2]=$;$=G+7168|0;c[am+2588>>2]=$;c[am+68124>>2]=$;c[am+133660>>2]=$;$=c[2383431]|0;c[am+2592>>2]=$;c[am+68128>>2]=$;c[am+133664>>2]=$;G=$+1024|0;c[am+2596>>2]=G;c[am+68132>>2]=G;c[am+133668>>2]=G;G=$+2048|0;c[am+2600>>2]=G;c[am+68136>>2]=G;c[am+133672>>2]=G;G=$+3072|0;c[am+2604>>2]=G;c[am+68140>>2]=G;c[am+133676>>2]=G;G=c[2383428]|0;c[am+2624>>2]=G;c[am+68160>>2]=G;c[am+133696>>2]=G;$=G+1024|0;c[am+2628>>2]=$;c[am+68164>>2]=$;c[am+133700>>2]=$;$=c[2383426]|0;c[am+2656>>2]=$;c[am+68192>>2]=$;c[am+133728>>2]=$;G=$+1024|0;c[am+2660>>2]=G;c[am+68196>>2]=G;c[am+133732>>2]=G;G=c[2383432]|0;c[am+2688>>2]=G;c[am+68224>>2]=G;c[am+133760>>2]=G;$=G+1024|0;c[am+2692>>2]=$;c[am+68228>>2]=$;c[am+133764>>2]=$;$=G+2048|0;c[am+2696>>2]=$;c[am+68232>>2]=$;c[am+133768>>2]=$;$=G+3072|0;c[am+2700>>2]=$;c[am+68236>>2]=$;c[am+133772>>2]=$;$=c[2383433]|0;c[am+2720>>2]=$;c[am+68256>>2]=$;c[am+133792>>2]=$;G=$+1024|0;c[am+2724>>2]=G;c[am+68260>>2]=G;c[am+133796>>2]=G;G=$+2048|0;c[am+2728>>2]=G;c[am+68264>>2]=G;c[am+133800>>2]=G;G=$+3072|0;c[am+2732>>2]=G;c[am+68268>>2]=G;c[am+133804>>2]=G;G=$+4096|0;c[am+2736>>2]=G;c[am+68272>>2]=G;c[am+133808>>2]=G;G=$+5120|0;c[am+2740>>2]=G;c[am+68276>>2]=G;c[am+133812>>2]=G;G=$+6144|0;c[am+2744>>2]=G;c[am+68280>>2]=G;c[am+133816>>2]=G;G=$+7168|0;c[am+2748>>2]=G;c[am+68284>>2]=G;c[am+133820>>2]=G;G=c[2383424]|0;c[am+2752>>2]=G;c[am+68288>>2]=G;c[am+133824>>2]=G;$=G+1024|0;c[am+2756>>2]=$;c[am+68292>>2]=$;c[am+133828>>2]=$;$=c[2383422]|0;c[am+2784>>2]=$;c[am+68320>>2]=$;c[am+133856>>2]=$;G=$+1024|0;c[am+2788>>2]=G;c[am+68324>>2]=G;c[am+133860>>2]=G;G=c[2386374]|0;c[am+2816>>2]=G;c[am+68352>>2]=G;c[am+133888>>2]=G;$=G+1024|0;c[am+2820>>2]=$;c[am+68356>>2]=$;c[am+133892>>2]=$;$=c[3530230]|0;c[am+2944>>2]=$;c[am+68480>>2]=$;c[am+134016>>2]=$;G=$+1024|0;c[am+2948>>2]=G;c[am+68484>>2]=G;c[am+134020>>2]=G;G=$+2048|0;c[am+2952>>2]=G;c[am+68488>>2]=G;c[am+134024>>2]=G;G=$+3072|0;c[am+2956>>2]=G;c[am+68492>>2]=G;c[am+134028>>2]=G;G=c[3530226]|0;c[am+2960>>2]=G;c[am+68496>>2]=G;c[am+134032>>2]=G;$=G+1024|0;c[am+2964>>2]=$;c[am+68500>>2]=$;c[am+134036>>2]=$;$=G+2048|0;c[am+2968>>2]=$;c[am+68504>>2]=$;c[am+134040>>2]=$;$=G+3072|0;c[am+2972>>2]=$;c[am+68508>>2]=$;c[am+134044>>2]=$;c[am+196728>>2]=1966;c[am+196648>>2]=2968;c[am+196688>>2]=3222;c[am+196608>>2]=2534;$=c[3532592]|0;if(($|0)!=0){gGC($|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;aE8(c[2387766]|0,c[2387788]|0,8055e3,1,0,.45,1006875,.75,2013750,.6);h[745419]=.6;a[3203368]=1;h[745418]=.6;a[3203360]=1;h[745417]=.6;a[3203352]=1;h[745416]=.6;a[3203344]=1;$=c[642608+(c[2436]<<2)>>2]|0;G=c[$+128>>2]|0;if((c[$+52>>2]&4|0)==0){c[2113068]=G;aa=c[$+132>>2]|0;c[2113070]=aa;c[2443814]=G;c[2440436]=aa;an=G;ao=aa}else{c[2113070]=G;aa=c[$+132>>2]|0;c[2113068]=aa;c[2440436]=G;c[2443814]=aa;an=aa;ao=G}G=ag(an<<1,ao)|0;aa=gGq(G)|0;c[2112926]=aa;if((aa|0)!=0){gGz(aa|0,0,G|0)}G=c[2414544]|0;gGz(G|0,0,(c[2411444]|0)-G|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];G=c[3532592]|0;if((G|0)!=0){gGC(9104152,G|0,280)|0}c[2113054]=c[2113060]}RI();G=c[2394]|0;aa=c[14130368+(G<<2)>>2]|0;if((aa|0)!=0){gGC(aa|0,9104152,280)|0}c[8452240+(G<<2)>>2]=c[2113054];c[2394]=-1;aE7();gGz(c[2383428]|0,0,4096);gGz(c[2383426]|0,0,4096);G=c[2383424]|0;if((G|0)!=0){gGz(G|0,0,4096);gGz(c[2383422]|0,0,4096)}gGz(c[2383434]|0,0,16);gGz(c[2383435]|0,0,16);gGz(c[2383430]|0,0,8192);gGz(c[2383431]|0,0,8192);G=c[2383432]|0;if((G|0)!=0){gGz(G|0,0,8192);gGz(c[2383433]|0,0,8192)}b[4766836]=0;c[2426968]=0;c[3528794]=0;c[1765522]=65535;c[2429656]=0;c[2427042]=0;c[2429386]=0;c[2429384]=0;c[2429382]=0;L=0;i=e;return L|0}}while(0);c[2414842]=0;L=1;i=e;return L|0}function aJ7(){var a=0,b=0,d=0,e=0,f=0;c[2113070]=0;c[2113068]=0;a=c[2112926]|0;if((a|0)!=0){gGr(a);c[2112926]=0}aE2();if((c[2392]|0)>=0){a=0;do{b=14130368+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}b=14130384+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}a=a+1|0;}while((a|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;aFe();a=c[2414842]|0;b=0;while(1){if((b|0)>=1024){e=33256;break}f=9638528+(b<<2)|0;if((c[f>>2]|0)==(a|0)){break}else{b=b+1|0}}if((e|0)==33256){c[2414842]=0;return 0}gGr(a);c[f>>2]=0;c[2414842]=0;return 0}function aJ8(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((a[9623352]|0)!=0){d=c[2414544]|0;gGz(d|0,0,(c[2411444]|0)-d|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;aE7();gGz(c[2383428]|0,0,4096);gGz(c[2383426]|0,0,4096);d=c[2383424]|0;if((d|0)!=0){gGz(d|0,0,4096);gGz(c[2383422]|0,0,4096)}gGz(c[2383434]|0,0,16);gGz(c[2383435]|0,0,16);gGz(c[2383430]|0,0,8192);gGz(c[2383431]|0,0,8192);d=c[2383432]|0;if((d|0)!=0){gGz(d|0,0,8192);gGz(c[2383433]|0,0,8192)}b[4766836]=0;c[2426968]=0;c[3528794]=0;c[1765522]=65535;c[2429656]=0;c[2427042]=0;c[2429386]=0;c[2429384]=0;c[2429382]=0}c[2387528]=-1;d=0;e=-1;f=-1;do{e=((a[9632296+d|0]&1)<<d^e&65535)&65535;f=((a[9630208+d|0]&1)<<d^f&65535)&65535;d=d+1|0;}while((d|0)<16);b[4775056]=e;b[4775057]=f;c[(c[2391608]|0)+60>>2]=0;c[(c[2391608]|0)+60>>2]=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060]}c[2388530]=9554128;f=c[2391608]|0;if((f|0)!=0){e=f;gGC(9661040,e|0,68)|0}c[2382]=0;c[2383408]=0;e=0;f=0;do{c[2113056]=808;d=RG(808)|0;c[2113054]=(c[2113054]|0)+d;c[2276108]=-1;c[2113056]=-1;fy_(542)|0;if((e|0)==240){c[2383408]=8}d=a[9688]|0?2:0;g=(c[3527022]|0)+(f<<1<<1)|0;if(a[801408]|0){gg[c[3542124]&4095](g,d)}if(a[801400]|0){Uu(0,g,d)}if((c[2429658]|0)!=0){Uu(1,g,d)}f=d+f|0;e=e+1|0;}while((e|0)<256);c[8452200+(c[2394]<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0<1024){RH(4)}e=c[2438228]|0;d=gGS(-1427243008,66222,e,(e|0)<0|0?-1:0)|0;e=d;Sb(138879);d=c[2443830]|0;if((d|0)<1073676288){c[2443830]=d-e}d=c[2443831]|0;if((d|0)<1073676288){c[2443831]=d-e}d=(c[3528512]|0)-e|0;c[3528512]=(d|0)<0?0:d;d=c[2112964]|0;do{if((d|0)!=0){gg[c[3542122]&4095](d,a[9688]|0?534:0);e=a[9688]|0;g=e?534:0;if((g|0)==(f|0)){h=f;i=e}else{e=g-f|0;g=(c[3527022]|0)+(f<<1<<1)|0;if(a[801408]|0){gg[c[3542124]&4095](g,e)}if(a[801400]|0){Uu(0,g,e)}if((c[2429658]|0)!=0){Uu(1,g,e)}e=a[9688]|0;h=e?534:0;i=e}if((h|0)<=0){break}e=c[3527022]|0;g=c[2112964]|0;j=i?534:0;k=0;do{l=k<<1;m=g+(l<<1)|0;b[m>>1]=(b[m>>1]|0)+(b[e+(l<<1)>>1]|0)&65535;m=l|1;l=g+(m<<1)|0;b[l>>1]=(b[l>>1]|0)+(b[e+(m<<1)>>1]|0)&65535;k=k+1|0;}while((k|0)<(j|0))}}while(0);i=c[(c[2388530]|0)+12304>>2]|0;if((i|0)!=0){h=i;gGC(h|0,9661040,68)|0}c[2382]=-1;h=c[2394]|0;i=c[14130368+(h<<2)>>2]|0;if((i|0)!=0){gGC(i|0,9104152,280)|0}c[8452240+(h<<2)>>2]=c[2113054];c[2394]=-1;if((c[2112968]|0)==0){return 0}aJ9()|0;return 0}function aJ9(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[3530230]|0;f=c[3530226]|0;g=(c[642608+(c[2436]<<2)>>2]|0)+124|0;if((c[g>>2]|0)>0){h=c[3529882]|0;i=0;do{j=e[d+(i<<1)>>1]|0;c[h+(i<<2)>>2]=((((j>>>8)*175|0)>>>0)/100|0)<<3&2016|((((j&255)*175|0)>>>0)/100|0)<<8&63488|((((b[f+(i<<1)>>1]&255)*175|0)>>>0)/100|0)>>>3&31;i=i+1|0;}while((i|0)<(c[g>>2]|0))}a[9547032]=0;aE3();aE5();g=ag(c[2113070]|0,c[2113068]|0)|0;i=c[2112926]|0;if((g|0)>0){f=0;while(1){b[i+(f<<1)>>1]=256;h=f+1|0;if((h|0)<(g|0)){f=h}else{k=i;break}}}else{k=i}aE0(3,k,65536);aKh(0);if((b[4766836]|0)==0){aE0(2,k,0);aE0(1,k,0);aKh(1);aE0(0,k,0);l=c[3529882]|0;R8(l);return 0}else{aE0(1,k,0);aE0(2,k,0);aKh(1);aE0(0,k,0);l=c[3529882]|0;R8(l);return 0}return 0}function aKa(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=i;i=i+64|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;if((d|0)!=0){c[d>>2]=169762}if((b&32|0)!=0){gGz(j|0,0,12);k=c[2414544]|0;c[j>>2]=k;c[j+4>>2]=(c[2411444]|0)-k;c[j+12>>2]=162152;k=c[2076592]|0;gj[k&4095](j)|0}if((b&64|0)==0){i=e;return 0}j=h|0;gGz(g|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){k=h+9|0;h=f;l=f|0;m=f+4|0;n=f+12|0;o=g|0;p=g+4|0;q=g+12|0;r=0;do{gGC(j|0,614896,11)|0;a[k]=r+48&255;s=8452256+(r<<2)|0;gGz(h|0,0,12);c[l>>2]=s;c[m>>2]=4;c[n>>2]=164976;gj[c[2076592]&4095](f)|0;if((c[s>>2]|0)!=0){c[o>>2]=c[14130368+(r<<2)>>2];c[p>>2]=c[8452184+(r<<2)>>2];c[q>>2]=j;s=c[2076592]|0;gj[s&4095](g)|0}r=r+1|0;}while((r|0)<=(c[2392]|0))}aFf(b,d);aE6();i=e;return 0}function aKb(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3027940+(b*112|0)>>2];c[a+104>>2]=c[3027944+(b*112|0)>>2];c[a+108>>2]=c[3027948+(b*112|0)>>2];d=0;return d|0}function aKc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=3027840+(b*112|0);e=0;return e|0}function aKd(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3029956+(b*112|0)>>2];c[a+104>>2]=c[3029960+(b*112|0)>>2];c[a+108>>2]=c[3029964+(b*112|0)>>2];d=0;return d|0}function aKe(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=3029856+(b*112|0);e=0;return e|0}function aKf(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2110692+(b*112|0)>>2];c[a+104>>2]=c[2110696+(b*112|0)>>2];c[a+108>>2]=c[2110700+(b*112|0)>>2];d=0;return d|0}function aKg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=2110592+(b*112|0);e=0;return e|0}function aKh(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;f=c[2386550]|0;g=(d|0)==1;h=(d|0)==0;d=c[3528642]|0;i=c[2112926]|0;j=c[3530302]|0;k=(c[2113222]&1|0)==0;l=0;do{m=b[f+((l|1)<<1)>>1]&32767;L43032:do{if((m|0)!=0){n=e[f+(l<<1)>>1]|0;o=e[f+((l|2)<<1)>>1]|0;p=(n&32768|0)!=0;if(p&g|h&(p^1)){break}p=o>>>9&15;q=((o&8192|0)==0?p:p|64)|16;if(!((n&4096|0)==0|k)){break}p=n&8192;r=n&16384;s=1<<(n>>>9&3);t=s-1|0;u=o&511;v=n&511;w=u>>>0>255?o|-512:u;u=v>>>0>255?n|-512:v;v=240-w|0;if((v|0)>256){break}n=((r|0)!=0?0:t)+(m&-s)|0;o=(r>>>13^2)-1|0;if((a[d]|0)==0){x=v;y=-16;z=240-u|0;A=r;B=p}else{x=w;y=16;z=u;A=r>>>14^1;B=p>>>13^1}if((s|0)<=0){break}s=z-8|0;p=(B|0)!=0;if((A|0)==0){C=t}else{if(p){r=t;while(1){u=(ag(r,y)|0)+s|0;SN(i,n-(ag(r,o)|0)|0,x,u,q,4,0,0,j);if((r|0)>0){r=r-1|0}else{break L43032}}}else{r=t;while(1){u=(ag(r,y)|0)+s|0;SL(i,n-(ag(r,o)|0)|0,x,u,q,4,0,0,j);if((r|0)>0){r=r-1|0}else{break L43032}}}}while(1){r=(ag(C,y)|0)+s|0;t=n-(ag(C,o)|0)|0;if(p){SJ(i,t,x,r,q,4,0,0,j)}else{SH(i,t,x,r,q,4,0,0,j)}if((C|0)>0){C=C-1|0}else{break}}}}while(0);l=l+4|0;}while((l|0)<1024);return}function aKi(a){a=a|0;return a>>>4<<12&28672|0}function aKj(b){b=b|0;var d=0;switch(b&65535|0){case 12288:{d=a[9625328]|0;break};case 12291:{d=(a[642504]|0?64:0)|a[9657873];break};case 12290:{d=a[9657872]|0;break};case 12308:{d=c[3527160]&255;break};case 12289:{d=a[9625280]|0;break};default:{d=0}}return d|0}function aKk(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((e|0)==12292){a[9758136]=d;gg[c[(c[2443776]|0)+64>>2]&4095](32,1);b=c[(c[2443776]|0)+52>>2]|0;gj[b&4095](0)|0;gg[c[(c[2443776]|0)+64>>2]&4095](32,0);b=c[(c[2443776]|0)+52>>2]|0;gj[b&4095](0)|0;return}else if((e|0)==12312){e=c[2430192]|0;if((e|0)==0){return}gf[e&2047](d);return}else{return}}function aKl(b){b=b|0;return(b<<16>>16==12288?a[9758136]|0:0)|0}function aKm(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=b&65535;if((f|0)==4096){b=c[3541518]|0;g=b+256|0;a[b+304|0]=e;h=e&255;if((e&255)<16){c[14168912+((c[2383582]|0)*252|0)>>2]=h&15}if((e-45&255)>=3){return}if((h|0)==47){a[b+312|0]=0;i=0}else if((h|0)==45){j=b+312|0;k=a[j]|2;a[j]=k;i=k}else if((h|0)==46){k=b+312|0;j=a[k]|1;a[k]=j;i=j}else if((h|0)==0){a[b+312|0]=2;i=2}else{i=a[b+312|0]|0}b=i&3;i=c[7461744+(b<<2)>>2]|0;lI(g,i,i,c[7461728+(b<<2)>>2]|0);return}else if((f|0)==8192){a[(c[3540986]|0)+5885|0]=e;return}else if((f|0)==8193){b=c[3540986]|0;i=c[b+5876>>2]|0;if((i|0)!=0){gg[i&4095](c[b+5880>>2]|0,0)}lH(b,d[b+5885|0]|0,e&255);return}else if((f|0)==4097){lS(0,1,e);return}else{return}}function aKn(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7432724+(b*112|0)>>2];c[a+104>>2]=c[7432728+(b*112|0)>>2];c[a+108>>2]=c[7432732+(b*112|0)>>2];d=0;return d|0}function aKo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=7432624+(b*112|0);e=0;return e|0}function aKp(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6939392+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aKq(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>29){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7451216+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aKr(){c[2430192]=222;c[2433362]=4502;return aKG()|0}function aKs(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c[2113160]=0;b=c[2433592]|0;if((b|0)!=0){gGr(b);c[2433592]=0}fvR();b=c[3541518]|0;if((b|0)!=0){gGr(b|0);c[3541518]=0}if((c[2385508]|0)>0){c[2113008]=0;c[2076598]=0;c[2383582]=0}c[2438228]=0;c[2433526]=0;c[2406676]=0;c[3528472]=0;b=c[2406680]|0;if((b|0)!=0){gGr(b);c[2406680]=0}c[2385508]=0;c[2432978]=0;a[64240]=0;b=a[7452592]|0;if(b){d=0;e=b&1;while(1){b=14163944+(d<<2)|0;f=c[b>>2]|0;g=c[2113006]|0;if((g|0)==0){h=33473}else{i=g-1|0;c[2113006]=i;if((i|0)==0){h=33473}}if((h|0)==33473){h=0;c[2383474]=0}if((f|0)==0){j=e}else{gGr(f);j=a[7452592]&1}c[b>>2]=0;b=d+1|0;if((b|0)<(j|0)){d=b;e=j}else{break}}}a[7452592]=0;c[2438222]=0;c[2433520]=0;c[2406670]=0;c[3528466]=0;j=c[2406686]|0;if((j|0)!=0){gGr(j);c[2406686]=0}c[2432974]=0;c[2113070]=0;c[2113068]=0;j=c[2112926]|0;if((j|0)!=0){gGr(j);c[2112926]=0}j=c[2426624]|0;e=0;while(1){if((e|0)>=1024){h=33486;break}k=9638528+(e<<2)|0;if((c[k>>2]|0)==(j|0)){break}else{e=e+1|0}}if((h|0)==33486){c[2426624]=0;c[3527160]=0;c[3531226]=0;c[2443646]=0;c[2414454]=0;c[2385794]=0;a[9758136]=0;c[2430192]=0;c[2433362]=0;return 0}gGr(j);c[k>>2]=0;c[2426624]=0;c[3527160]=0;c[3531226]=0;c[2443646]=0;c[2414454]=0;c[2385794]=0;a[9758136]=0;c[2430192]=0;c[2433362]=0;return 0}function aKt(){var e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if((a[9623344]|0)!=0){c[3528554]=0;f43(c[2433592]|0);e=c[3528554]|0;c[2113158]=c[9731360+(e<<2)>>2];a[9660796]=0;a[9660797]=0;a[9660786]=0;a[9660787]=0;c[2415191]=0;a[9660784]=a[9660784]|80;f=c[2433592]|0;g=c[f+(e*3148|0)+1068>>2]|0;do{if((g|0)==0){i=c[f+(e*3148|0)+3120>>2]|0;if((i|0)==0){j=0;k=0;break}l=gj[i&4095](-2)|0;i=c[3528554]|0;m=c[2433592]|0;n=c[m+(i*3148|0)+1068>>2]|0;o=(l&255)<<8;if((n|0)!=0){p=n;q=o;r=33493;break}n=c[m+(i*3148|0)+3120>>2]|0;if((n|0)==0){j=0;k=o;break}j=gj[n&4095](-1)|0;k=o}else{p=g;q=d[g+254|0]<<8;r=33493}}while(0);if((r|0)==33493){j=a[p+255|0]|0;k=q}q=j&255|k;c[2415188]=q;b[4830376]=q&65535;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){q=0;do{lN(q);mB(q);q=q+1|0;}while((q|0)<(c[2385508]|0))}q=c[3528554]|0;k=(c[2433592]|0)+(q*3148|0)|0;if((k|0)!=0){j=k;gGC(j|0,9660752,48)|0}c[9731360+(q<<2)>>2]=c[2113158];c[3528554]=-1;c[3528556]=0;q=c[2433594]|0;c[2443776]=q;L43191:do{if((q|0)!=0){j=q|0;gGC(9660952,j|0,52)|0;switch(a[9660952]|0){case 0:{c[2309668]=638960;break L43191;break};case 2:{c[2309668]=638960;break L43191;break};case 5:{c[2309668]=7354992;break L43191;break};case 4:{c[2309668]=7356016;break L43191;break};case 3:{c[2309668]=639984;break L43191;break};case 1:{c[2309668]=634096;break L43191;break};default:{break L43191}}}}while(0);c[2113164]=c[2432850];gu[c[q+56>>2]&16383]();c[2443825]=1073676288;c[2443824]=1073676288;c[2443817]=1073676288;c[2443816]=1073676288;h[883199]=0.0;c[3528506]=0;lw(c[3540986]|0);q=c[2443776]|0;if((q|0)!=0){j=q|0;gGC(j|0,9660952,52)|0}c[9731400+(c[3528556]<<2)>>2]=c[2113164];c[2443776]=0;c[3528556]=-1;c[3527160]=0;c[3531226]=0;c[2443646]=0;c[2414454]=0;c[2385794]=0;a[9758136]=0}a[9625280]=-1;a[9625328]=-1;a[642504]=1;j=0;q=-1;k=-1;do{q=(q&255)-((a[9759136+j|0]&1)<<j)&255;k=(k&255)-((a[9758944+j|0]&1)<<j)&255;j=j+1|0;}while((j|0)<8);a[9625328]=q;a[9625280]=k;if((a[9758774]|0)!=0){a[642504]=0}k=c[2113160]|0;if((k|0)>0){gGz(9731360,0,((k|0)>1?k<<2:4)|0)}c[2113158]=0;k=c[2113166]|0;if((k|0)>0){gGz(9731400,0,((k|0)>1?k<<2:4)|0)}c[2113164]=0;c[3528554]=0;f43(c[2433592]|0);c[2113158]=c[9731360+(c[3528554]<<2)>>2];c[3528556]=0;k=c[2433594]|0;c[2443776]=k;L43217:do{if((k|0)!=0){q=k|0;gGC(9660952,q|0,52)|0;switch(a[9660952]|0){case 0:{c[2309668]=638960;break L43217;break};case 4:{c[2309668]=7356016;break L43217;break};case 5:{c[2309668]=7354992;break L43217;break};case 3:{c[2309668]=639984;break L43217;break};case 2:{c[2309668]=638960;break L43217;break};case 1:{c[2309668]=634096;break L43217;break};default:{break L43217}}}}while(0);c[2113164]=c[2432850];k=0;while(1){q=k+1|0;Sb((q*34482|0|0)/100|0);if((k|0)==99){f44(32);f45(0)|0;if((a[9660797]|0)!=0){a[9660797]=0}f45(0)|0}U1((q*25862|0|0)/100|0);if((q|0)<100){k=q}else{break}}k=c[2438228]|0;q=gGS(1283719168,16442,k,(k|0)<0|0?-1:0)|0;k=q;Sb(34482);q=c[2443830]|0;if((q|0)<1073676288){c[2443830]=q-k}q=c[2443831]|0;if((q|0)<1073676288){c[2443831]=q-k}q=(c[3528512]|0)-k|0;c[3528512]=(q|0)<0?0:q;q=c[2438222]|0;k=gGS(-160694272,12331,q,(q|0)<0|0?-1:0)|0;q=k;U1(25862);k=c[2443824]|0;if((k|0)<1073676288){c[2443824]=k-q}k=c[2443825]|0;if((k|0)<1073676288){c[2443825]=k-q}k=(c[3528506]|0)-q|0;c[3528506]=(k|0)<0?0:k;k=c[2112964]|0;if((k|0)!=0){gg[c[3542122]&4095](k,a[9688]|0?534:0);gg[c[3542114]&4095](c[2112964]|0,a[9688]|0?534:0)}k=c[3528554]|0;q=(c[2433592]|0)+(k*3148|0)|0;if((q|0)!=0){j=q;gGC(j|0,9660752,48)|0}c[9731360+(k<<2)>>2]=c[2113158];c[3528554]=-1;k=c[2443776]|0;if((k|0)!=0){j=k|0;gGC(j|0,9660952,52)|0}c[9731400+(c[3528556]<<2)>>2]=c[2113164];c[2443776]=0;c[3528556]=-1;if((c[2112968]|0)==0){return 0}j=c[2112926]|0;gGz(j|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);k=c[2407134]|0;q=c[3529880]|0;p=0;do{r=d[k+p|0]|0;g=d[k+(p+256)|0]|0;c[q+(p<<2)>>2]=(-(r>>>5&1)&31)+(-(r>>>7)&143)+(-(r>>>4&1)&14)+(-(r>>>6&1)&67)<<8&63488|(-(r>>>1&1)&31)+(-(r&1)&14)+(-(r>>>2&1)&67)+(-(r>>>3&1)&143)<<3&2016|((-(g>>>1&1)&31)+(-(g&1)&14)+(-(g>>>2&1)&67)+(-(g>>>3&1)&143)|0)>>>3&31;p=p+1|0;}while((p|0)<256);aKN(0);p=c[2443402]|0;k=c[3529564]|0;g=0;do{r=d[p+(g|1)|0]|0;e=r<<8&768|d[p+(g|3)|0];f=r>>>4;o=d[p+(g|2)|0]|0;n=o-2|0;i=(d[p+g|0]|0)-16|0;m=(r&4|0)!=0;do{if((r&8|0)==0){if(m){SL(j,e,n,i,f,3,0,0,k);SL(j,e,o-258|0,i,f,3,0,0,k);break}else{SH(j,e,n,i,f,3,0,0,k);SH(j,e,o-258|0,i,f,3,0,0,k);break}}else{if(m){SN(j,e,n,i,f,3,0,0,k);SN(j,e,o-258|0,i,f,3,0,0,k);break}else{SJ(j,e,n,i,f,3,0,0,k);SJ(j,e,o-258|0,i,f,3,0,0,k);break}}}while(0);g=g+4|0;}while((g|0)<256);aKN(1);R8(q);return 0}function aKu(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;e=i;i=i+256|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;l=e+80|0;m=e+96|0;n=e+112|0;o=e+128|0;p=e+144|0;q=e+160|0;r=e+176|0;s=e+192|0;t=e+208|0;u=e+224|0;v=e+240|0;if((d|0)!=0){c[d>>2]=169753}if((b&32|0)!=0){gGz(v|0,0,12);w=c[2405562]|0;c[v>>2]=w;c[v+4>>2]=(c[2411442]|0)-w;c[v+12>>2]=162152;w=c[2076592]|0;gj[w&4095](v)|0}if((b&64|0)==0){i=e;return 0}v=o|0;if((c[2113160]|0)>0){w=o+7|0;x=n|0;y=n+4|0;z=n+12|0;A=m;B=m|0;C=m+4|0;D=m+12|0;E=l;F=l|0;G=l+4|0;H=l+12|0;I=k;J=k|0;K=k+4|0;L=k+12|0;M=0;do{N=c[2433592]|0;O=N+(M*3148|0)+40|0;P=c[O>>2]|0;gGC(v|0,614752,9)|0;a[w]=M+48&255;c[x>>2]=N+(M*3148|0);c[y>>2]=48;c[z>>2]=v;gj[c[2076592]&4095](n)|0;gGz(A|0,0,12);c[B>>2]=N+(M*3148|0)+3136;c[C>>2]=4;c[D>>2]=165288;gj[c[2076592]&4095](m)|0;gGz(E|0,0,12);c[F>>2]=N+(M*3148|0)+3140;c[G>>2]=4;c[H>>2]=501592;gj[c[2076592]&4095](l)|0;gGz(I|0,0,12);c[J>>2]=N+(M*3148|0)+3144;c[K>>2]=4;c[L>>2]=386080;gj[c[2076592]&4095](k)|0;c[O>>2]=P;M=M+1|0;}while((M|0)<(c[2113160]|0))}if((c[2113166]|0)>0){M=o+7|0;o=j|0;k=j+4|0;L=j+12|0;K=h;J=h|0;I=h+4|0;l=h+12|0;H=g;G=g|0;F=g+4|0;E=g+12|0;m=f;D=f|0;C=f+4|0;B=f+12|0;A=0;do{n=c[9734376+(A<<2)>>2]|0;z=n+36|0;y=c[z>>2]|0;gGC(v|0,614768,9)|0;a[M]=A+48&255;c[o>>2]=n;c[k>>2]=52;c[L>>2]=v;gj[c[2076592]&4095](j)|0;gGz(K|0,0,12);c[J>>2]=n+3172;c[I>>2]=4;c[l>>2]=165288;gj[c[2076592]&4095](h)|0;gGz(H|0,0,12);c[G>>2]=n+3176;c[F>>2]=4;c[E>>2]=501592;gj[c[2076592]&4095](g)|0;gGz(m|0,0,12);c[D>>2]=n+3180;c[C>>2]=4;c[B>>2]=386080;gj[c[2076592]&4095](f)|0;c[z>>2]=y;A=A+1|0;}while((A|0)<(c[2113166]|0))}Vx(b,d);Vb(b,d);gGz(u|0,0,12);c[u>>2]=14108640;c[u+4>>2]=4;c[u+12>>2]=258224;gj[c[2076592]&4095](u)|0;gGz(t|0,0,12);c[t>>2]=14124904;c[t+4>>2]=4;c[t+12>>2]=249848;gj[c[2076592]&4095](t)|0;gGz(s|0,0,12);c[s>>2]=9774584;c[s+4>>2]=4;c[s+12>>2]=242864;gj[c[2076592]&4095](s)|0;gGz(r|0,0,12);c[r>>2]=9657816;c[r+4>>2]=4;c[r+12>>2]=236640;gj[c[2076592]&4095](r)|0;gGz(q|0,0,12);c[q>>2]=9543176;c[q+4>>2]=4;c[q+12>>2]=230136;gj[c[2076592]&4095](q)|0;gGz(p|0,0,12);c[p>>2]=9758136;c[p+4>>2]=1;c[p+12>>2]=497064;gj[c[2076592]&4095](p)|0;i=e;return 0}function aKv(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7267828+(b*112|0)>>2];c[a+104>>2]=c[7267832+(b*112|0)>>2];c[a+108>>2]=c[7267836+(b*112|0)>>2];d=0;return d|0}function aKw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=7267728+(b*112|0);e=0;return e|0}function aKx(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>29){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7269584+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aKy(){c[2430192]=776;c[2433362]=4502;return aKG()|0}function aKz(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7292220+(b*112|0)>>2];c[a+104>>2]=c[7292224+(b*112|0)>>2];c[a+108>>2]=c[7292228+(b*112|0)>>2];d=0;return d|0}function aKA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=7292120+(b*112|0);e=0;return e|0}function aKB(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>24){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7293808+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aKC(){c[2433362]=2886;return aKG()|0}function aKD(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6922308+(b*112|0)>>2];c[a+104>>2]=c[6922312+(b*112|0)>>2];c[a+108>>2]=c[6922316+(b*112|0)>>2];d=0;return d|0}function aKE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=6922208+(b*112|0);e=0;return e|0}function aKF(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;b=i;i=i+1320|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;l=b+360|0;m=b+472|0;n=b+480|0;o=b+592|0;p=b+600|0;q=b+712|0;r=b+720|0;s=b+832|0;t=b+840|0;u=b+952|0;v=b+960|0;w=b+1072|0;x=b+1080|0;y=b+1192|0;z=b+1200|0;A=b+1312|0;B=(c[3527380]|0)+16384|0;if((c[3542200]|0)==0){C=1;i=b;return C|0}D=z+108|0;c[D>>2]=0;E=z+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,0)|0;do{if((c[D>>2]|0)!=0){z=c[E>>2]|0;c[A>>2]=9534384;F=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[F&16383](A,0,0)|0;if((z|0)<1){C=1;i=b;return C|0}if((gzL(B,0,0)|0)==0){break}else{C=1}i=b;return C|0}}while(0);B=(c[3527380]|0)+32768|0;if((c[3542200]|0)==0){C=1;i=b;return C|0}A=x+108|0;c[A>>2]=0;E=x+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,1)|0;do{if((c[A>>2]|0)!=0){x=c[E>>2]|0;c[y>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](y,1,0)|0;if((x|0)<1){C=1;i=b;return C|0}if((gzL(B,0,1)|0)==0){break}else{C=1}i=b;return C|0}}while(0);B=c[3527420]|0;if((c[3542200]|0)==0){C=1;i=b;return C|0}y=v+108|0;c[y>>2]=0;E=v+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,2)|0;do{if((c[y>>2]|0)!=0){v=c[E>>2]|0;c[w>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](w,2,0)|0;if((v|0)<1){C=1;i=b;return C|0}if((gzL(B,0,2)|0)==0){break}else{C=1}i=b;return C|0}}while(0);B=c[3529512]|0;if((c[3542200]|0)==0){C=1;i=b;return C|0}w=t+108|0;c[w>>2]=0;E=t+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,3)|0;do{if((c[w>>2]|0)!=0){t=c[E>>2]|0;c[u>>2]=9534384;y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[y&16383](u,3,0)|0;if((t|0)<1){C=1;i=b;return C|0}if((gzL(B,0,3)|0)==0){break}else{C=1}i=b;return C|0}}while(0);B=(c[3529512]|0)+32768|0;if((c[3542200]|0)==0){C=1;i=b;return C|0}u=r+108|0;c[u>>2]=0;E=r+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,4)|0;do{if((c[u>>2]|0)!=0){r=c[E>>2]|0;c[s>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](s,4,0)|0;if((r|0)<1){C=1;i=b;return C|0}if((gzL(B,0,4)|0)==0){break}else{C=1}i=b;return C|0}}while(0);B=(c[3529512]|0)+65536|0;if((c[3542200]|0)==0){C=1;i=b;return C|0}s=p+108|0;c[s>>2]=0;E=p+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,5)|0;do{if((c[s>>2]|0)!=0){p=c[E>>2]|0;c[q>>2]=9534384;u=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[u&16383](q,5,0)|0;if((p|0)<1){C=1;i=b;return C|0}if((gzL(B,0,5)|0)==0){break}else{C=1}i=b;return C|0}}while(0);B=c[3529512]|0;q=c[2406516]|0;E=0;do{s=E<<6;gGz(q+s|0,0,64);p=0;do{u=s+(c[1238464+(p<<2)>>2]|0)|0;r=(p<<3)+s|0;w=0;do{t=u+(c[614800+(w<<2)>>2]|0)|0;if(((d[B+((t|0)/8|0)|0]|0)&128>>>((t&7)>>>0)|0)!=0){t=q+(r+w)|0;a[t]=a[t]|4}w=w+1|0;}while((w|0)<8);p=p+1|0;}while((p|0)<8);p=s+262144|0;w=0;do{r=p+(c[1238464+(w<<2)>>2]|0)|0;u=(w<<3)+s|0;t=0;do{y=r+(c[614800+(t<<2)>>2]|0)|0;if(((d[B+((y|0)/8|0)|0]|0)&128>>>((y&7)>>>0)|0)!=0){y=q+(u+t)|0;a[y]=a[y]|2}t=t+1|0;}while((t|0)<8);w=w+1|0;}while((w|0)<8);w=s+524288|0;p=0;do{t=w+(c[1238464+(p<<2)>>2]|0)|0;u=(p<<3)+s|0;r=0;do{y=t+(c[614800+(r<<2)>>2]|0)|0;if(((d[B+((y|0)/8|0)|0]|0)&128>>>((y&7)>>>0)|0)!=0){y=q+(u+r)|0;a[y]=a[y]|1}r=r+1|0;}while((r|0)<8);p=p+1|0;}while((p|0)<8);E=E+1|0;}while((E|0)<2048);gGz(B|0,0,98304);if((c[3542200]|0)==0){C=1;i=b;return C|0}E=n+108|0;c[E>>2]=0;q=n+100|0;c[q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,6)|0;do{if((c[E>>2]|0)!=0){n=c[q>>2]|0;c[o>>2]=9534384;p=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[p&16383](o,6,0)|0;if((n|0)<1){C=1;i=b;return C|0}if((gzL(B,0,6)|0)==0){break}else{C=1}i=b;return C|0}}while(0);B=(c[3529512]|0)+32768|0;if((c[3542200]|0)==0){C=1;i=b;return C|0}o=l+108|0;c[o>>2]=0;q=l+100|0;c[q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,7)|0;do{if((c[o>>2]|0)!=0){l=c[q>>2]|0;c[m>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](m,7,0)|0;if((l|0)<1){C=1;i=b;return C|0}if((gzL(B,0,7)|0)==0){break}else{C=1}i=b;return C|0}}while(0);B=(c[3529512]|0)+65536|0;if((c[3542200]|0)==0){C=1;i=b;return C|0}m=j+108|0;c[m>>2]=0;q=j+100|0;c[q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,8)|0;do{if((c[m>>2]|0)!=0){j=c[q>>2]|0;c[k>>2]=9534384;o=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[o&16383](k,8,0)|0;if((j|0)<1){C=1;i=b;return C|0}if((gzL(B,0,8)|0)==0){break}else{C=1}i=b;return C|0}}while(0);B=c[3529512]|0;k=c[3529564]|0;q=0;do{m=q<<8;gGz(k+m|0,0,256);j=0;do{o=m+(c[609008+(j<<2)>>2]|0)|0;l=(j<<4)+m|0;E=0;do{n=o+(c[612640+(E<<2)>>2]|0)|0;if(((d[B+((n|0)/8|0)|0]|0)&128>>>((n&7)>>>0)|0)!=0){n=k+(l+E)|0;a[n]=a[n]|4}E=E+1|0;}while((E|0)<16);j=j+1|0;}while((j|0)<16);j=m+262144|0;E=0;do{l=j+(c[609008+(E<<2)>>2]|0)|0;o=(E<<4)+m|0;n=0;do{p=l+(c[612640+(n<<2)>>2]|0)|0;if(((d[B+((p|0)/8|0)|0]|0)&128>>>((p&7)>>>0)|0)!=0){p=k+(o+n)|0;a[p]=a[p]|2}n=n+1|0;}while((n|0)<16);E=E+1|0;}while((E|0)<16);E=m+524288|0;j=0;do{n=E+(c[609008+(j<<2)>>2]|0)|0;o=(j<<4)+m|0;l=0;do{p=n+(c[612640+(l<<2)>>2]|0)|0;if(((d[B+((p|0)/8|0)|0]|0)&128>>>((p&7)>>>0)|0)!=0){p=k+(o+l)|0;a[p]=a[p]|1}l=l+1|0;}while((l|0)<16);j=j+1|0;}while((j|0)<16);q=q+1|0;}while((q|0)<1024);q=c[2407134]|0;if((c[3542200]|0)==0){C=1;i=b;return C|0}k=g+108|0;c[k>>2]=0;B=g+100|0;c[B>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,9)|0;do{if((c[k>>2]|0)!=0){g=c[B>>2]|0;c[h>>2]=9534384;j=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[j&16383](h,9,0)|0;if((g|0)<1){C=1;i=b;return C|0}if((gzL(q,0,9)|0)==0){break}else{C=1}i=b;return C|0}}while(0);q=(c[2407134]|0)+256|0;if((c[3542200]|0)==0){C=1;i=b;return C|0}h=e+108|0;c[h>>2]=0;B=e+100|0;c[B>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,10)|0;if((c[h>>2]|0)==0){C=0;i=b;return C|0}h=c[B>>2]|0;c[f>>2]=9534384;gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](f,10,0)|0;if((h|0)<1){C=1;i=b;return C|0}C=(gzL(q,0,10)|0)!=0|0;i=b;return C|0}function aKG(){var e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;c[2424]=5800;c[2426624]=0;c[3527380]=0;c[3527420]=65536;c[2407134]=98304;c[2405562]=98816;c[3527386]=98816;c[3527428]=105984;c[3527230]=110080;c[2443578]=111104;c[2443402]=112128;c[2411442]=112384;c[2406516]=112384;c[3529564]=243456;c[3529880]=505600;e=0;while(1){if((e|0)>=1024){break}f=9638528+(e<<2)|0;if((c[f>>2]|0)==0){g=33752;break}else{e=e+1|0}}do{if((g|0)==33752){e=gGq(506624)|0;c[f>>2]=e;if((e|0)==0){break}c[2426624]=e;gGz(e|0,0,506624);c[3527380]=e;c[3527420]=e+65536;c[2407134]=e+98304;i=e+98816|0;c[2405562]=i;c[3527386]=i;c[3527428]=e+105984;c[3527230]=e+110080;c[2443578]=e+111104;c[2443402]=e+112128;i=e+112384|0;c[2411442]=i;c[2406516]=i;c[3529564]=e+243456;c[3529880]=e+505600;c[2413982]=e+506624;e=0;while(1){if((e|0)>=1024){j=0;break}k=9638528+(e<<2)|0;if((c[k>>2]|0)==0){g=33757;break}else{e=e+1|0}}do{if((g|0)==33757){e=gGq(98304)|0;c[k>>2]=e;if((e|0)==0){j=0;break}gGz(e|0,0,98304);j=e}}while(0);c[3529512]=j;if((gD[c[2433362]&8191]()|0)!=0){l=1;return l|0}e=c[3529512]|0;i=0;while(1){if((i|0)>=1024){break}m=9638528+(i<<2)|0;if((c[m>>2]|0)==(e|0)){g=33763;break}else{i=i+1|0}}if((g|0)==33763){gGr(e);c[m>>2]=0}c[3529512]=0;c[3528554]=-1;c[2113160]=1;i=gGq(3148)|0;n=i;c[2433592]=n;if((i|0)!=0){gGz(i|0,0,3148);c[i+3120>>2]=3128;c[i+3124>>2]=1840;c[i+3128>>2]=136;c[i+3132>>2]=1902;c[2432840]=0;o=0;do{c[n+48+(o<<2)>>2]=0;o=o+1|0;}while((o|0)<768);c[2113158]=0;c[2415198]=0;o=c[2427044]|0;c[9681616+(o<<3)>>2]=809272;c[9681620+(o<<3)>>2]=0;c[2427044]=o+1}c[3528554]=0;f43(i);o=c[3528554]|0;n=9731360+(o<<2)|0;e=c[n>>2]|0;c[2113158]=e;p=c[3527386]|0;q=c[2433592]|0;r=0;s=0;while(1){t=p+(s<<8)|0;c[q+(o*3148|0)+48+(s<<2)>>2]=t;c[q+(o*3148|0)+48+(s+256<<2)>>2]=t;c[q+(o*3148|0)+48+(s+512<<2)>>2]=t;t=r+1&65535;if((t&65535)>15){break}else{r=t;s=t&65535}}s=c[3527230]|0;c[q+(o*3148|0)+112>>2]=s;c[q+(o*3148|0)+1136>>2]=s;c[q+(o*3148|0)+2160>>2]=s;r=s+256|0;c[q+(o*3148|0)+116>>2]=r;c[q+(o*3148|0)+1140>>2]=r;c[q+(o*3148|0)+2164>>2]=r;r=s+512|0;c[q+(o*3148|0)+120>>2]=r;c[q+(o*3148|0)+1144>>2]=r;c[q+(o*3148|0)+2168>>2]=r;r=s+768|0;c[q+(o*3148|0)+124>>2]=r;c[q+(o*3148|0)+1148>>2]=r;c[q+(o*3148|0)+2172>>2]=r;r=p+4096|0;c[q+(o*3148|0)+128>>2]=r;c[q+(o*3148|0)+1152>>2]=r;c[q+(o*3148|0)+2176>>2]=r;r=p+4352|0;c[q+(o*3148|0)+132>>2]=r;c[q+(o*3148|0)+1156>>2]=r;c[q+(o*3148|0)+2180>>2]=r;r=p+4608|0;c[q+(o*3148|0)+136>>2]=r;c[q+(o*3148|0)+1160>>2]=r;c[q+(o*3148|0)+2184>>2]=r;r=p+4864|0;c[q+(o*3148|0)+140>>2]=r;c[q+(o*3148|0)+1164>>2]=r;c[q+(o*3148|0)+2188>>2]=r;r=c[2443578]|0;c[q+(o*3148|0)+144>>2]=r;c[q+(o*3148|0)+1168>>2]=r;c[q+(o*3148|0)+2192>>2]=r;s=r+256|0;c[q+(o*3148|0)+148>>2]=s;c[q+(o*3148|0)+1172>>2]=s;c[q+(o*3148|0)+2196>>2]=s;s=r+512|0;c[q+(o*3148|0)+152>>2]=s;c[q+(o*3148|0)+1176>>2]=s;c[q+(o*3148|0)+2200>>2]=s;s=r+768|0;c[q+(o*3148|0)+156>>2]=s;c[q+(o*3148|0)+1180>>2]=s;c[q+(o*3148|0)+2204>>2]=s;s=p+5120|0;c[q+(o*3148|0)+160>>2]=s;c[q+(o*3148|0)+1184>>2]=s;c[q+(o*3148|0)+2208>>2]=s;s=p+5376|0;c[q+(o*3148|0)+164>>2]=s;c[q+(o*3148|0)+1188>>2]=s;c[q+(o*3148|0)+2212>>2]=s;s=p+5632|0;c[q+(o*3148|0)+168>>2]=s;c[q+(o*3148|0)+1192>>2]=s;c[q+(o*3148|0)+2216>>2]=s;s=p+5888|0;c[q+(o*3148|0)+172>>2]=s;c[q+(o*3148|0)+1196>>2]=s;c[q+(o*3148|0)+2220>>2]=s;s=c[2443402]|0;c[q+(o*3148|0)+176>>2]=s;c[q+(o*3148|0)+1200>>2]=s;c[q+(o*3148|0)+2224>>2]=s;s=p+6144|0;c[q+(o*3148|0)+180>>2]=s;c[q+(o*3148|0)+1204>>2]=s;c[q+(o*3148|0)+2228>>2]=s;s=p+6400|0;c[q+(o*3148|0)+184>>2]=s;c[q+(o*3148|0)+1208>>2]=s;c[q+(o*3148|0)+2232>>2]=s;s=p+6656|0;c[q+(o*3148|0)+188>>2]=s;c[q+(o*3148|0)+1212>>2]=s;c[q+(o*3148|0)+2236>>2]=s;s=p+6912|0;c[q+(o*3148|0)+192>>2]=s;c[q+(o*3148|0)+1216>>2]=s;c[q+(o*3148|0)+2240>>2]=s;s=c[3527380]|0;r=64;i=64;while(1){t=s+(i<<8)|0;c[q+(o*3148|0)+48+(i<<2)>>2]=t;c[q+(o*3148|0)+48+(i+512<<2)>>2]=t;t=r+1&65535;if((t&65535)>255){break}else{r=t;i=t&65535}}c[q+(o*3148|0)+3120>>2]=3036;c[q+(o*3148|0)+3124>>2]=3398;i=q+(o*3148|0)|0;if((i|0)!=0){r=i;gGC(r|0,9660752,48)|0}c[n>>2]=e;c[3528554]=-1;fvI();c[3528556]=0;r=c[2433594]|0;c[2443776]=r;L43564:do{if((r|0)!=0){i=r|0;gGC(9660952,i|0,52)|0;switch(a[9660952]|0){case 0:{c[2309668]=638960;break L43564;break};case 5:{c[2309668]=7354992;break L43564;break};case 1:{c[2309668]=634096;break L43564;break};case 4:{c[2309668]=7356016;break L43564;break};case 3:{c[2309668]=639984;break L43564;break};case 2:{c[2309668]=638960;break L43564;break};default:{break L43564}}}}while(0);e=c[2432850]|0;c[2113164]=e;n=c[3527428]|0;o=0;q=0;while(1){i=n+(q<<8)|0;c[r+68+(q<<2)>>2]=i;c[r+68+(q+256<<2)>>2]=i;c[r+68+(q+512<<2)>>2]=i;i=o+1&65535;if((i&65535)>15){break}else{o=i;q=i&65535}}q=c[3527420]|0;o=128;n=128;while(1){i=q+((n<<8)-32768)|0;c[r+68+(n<<2)>>2]=i;c[r+68+(n+512<<2)>>2]=i;i=o+1&65535;if((i&65535)>255){break}else{o=i;n=i&65535}}c[r+3148>>2]=1690;c[r+3152>>2]=28;n=r|0;gGC(n|0,9660952,52)|0;c[2432850]=e;c[2443776]=0;c[3528556]=-1;Vr(1,15e5,0,168,64,0);c[2438228]=2e6;c[2433526]=3068;c[2406676]=206;c[3528472]=4026;c[2443846]=1023;h[745419]=.25;a[3203368]=1;h[745418]=.25;a[3203360]=1;h[745417]=.25;a[3203352]=1;h[745416]=.25;a[3203344]=1;U6(3e6,1900,1638,1);c[2438222]=15e5;c[2433520]=2448;c[2406670]=2016;c[3528466]=6844;c[2443840]=1364;h[745399]=1.0;a[3203272]=1;n=c[642608+(c[2436]<<2)>>2]|0;o=c[n+128>>2]|0;if((c[n+52>>2]&4|0)==0){c[2113068]=o;q=c[n+132>>2]|0;c[2113070]=q;c[2443814]=o;c[2440436]=q;u=o;v=q}else{c[2113070]=o;q=c[n+132>>2]|0;c[2113068]=q;c[2440436]=o;c[2443814]=q;u=q;v=o}o=ag(u<<1,v)|0;q=gGq(o)|0;c[2112926]=q;if((q|0)!=0){gGz(q|0,0,o|0)}c[3528554]=0;f43(c[2433592]|0);o=c[3528554]|0;c[2113158]=c[9731360+(o<<2)>>2];a[9660796]=0;a[9660797]=0;a[9660786]=0;a[9660787]=0;c[2415191]=0;a[9660784]=a[9660784]|80;q=c[2433592]|0;n=c[q+(o*3148|0)+1068>>2]|0;do{if((n|0)==0){i=c[q+(o*3148|0)+3120>>2]|0;if((i|0)==0){w=0;x=0;break}s=gj[i&4095](-2)|0;i=c[3528554]|0;p=c[2433592]|0;t=c[p+(i*3148|0)+1068>>2]|0;y=(s&255)<<8;if((t|0)!=0){z=t;A=y;g=33795;break}t=c[p+(i*3148|0)+3120>>2]|0;if((t|0)==0){w=0;x=y;break}w=gj[t&4095](-1)|0;x=y}else{z=n;A=d[n+254|0]<<8;g=33795}}while(0);if((g|0)==33795){w=a[z+255|0]|0;x=A}n=w&255|x;c[2415188]=n;b[4830376]=n&65535;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){n=0;do{lN(n);mB(n);n=n+1|0;}while((n|0)<(c[2385508]|0))}n=c[3528554]|0;o=(c[2433592]|0)+(n*3148|0)|0;if((o|0)!=0){q=o;gGC(q|0,9660752,48)|0}c[9731360+(n<<2)>>2]=c[2113158];c[3528554]=-1;c[3528556]=0;n=c[2433594]|0;c[2443776]=n;L43603:do{if((n|0)!=0){q=n|0;gGC(9660952,q|0,52)|0;switch(a[9660952]|0){case 0:{c[2309668]=638960;break L43603;break};case 4:{c[2309668]=7356016;break L43603;break};case 1:{c[2309668]=634096;break L43603;break};case 5:{c[2309668]=7354992;break L43603;break};case 2:{c[2309668]=638960;break L43603;break};case 3:{c[2309668]=639984;break L43603;break};default:{break L43603}}}}while(0);c[2113164]=c[2432850];gu[c[n+56>>2]&16383]();c[2443825]=1073676288;c[2443824]=1073676288;c[2443817]=1073676288;c[2443816]=1073676288;h[883199]=0.0;c[3528506]=0;lw(c[3540986]|0);q=c[2443776]|0;if((q|0)!=0){o=q|0;gGC(o|0,9660952,52)|0}c[9731400+(c[3528556]<<2)>>2]=c[2113164];c[2443776]=0;c[3528556]=-1;c[3527160]=0;c[3531226]=0;c[2443646]=0;c[2414454]=0;c[2385794]=0;a[9758136]=0;l=0;return l|0}}while(0);c[2426624]=0;l=1;return l|0}function aKH(a){a=a|0;return(ag(c[2113158]|0,a)|0)/2e6|0|0}function aKI(){return+(+(c[2113158]|0)/2.0e6)}function aKJ(a,b){a=a|0;b=b|0;a=c[(c[2443776]|0)+64>>2]|0;if((b|0)==0){gg[a&4095](0,0);return}else{gg[a&4095](0,1);return}}function aKK(a){a=a|0;var b=0,d=0;b=c[2113164]|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,15e5,0)|0;return a|0}function aKL(b){b=b|0;var d=0,e=0;f44(1);f45(0)|0;a[9660787]=0;f45(0)|0;d=c[2414454]|0;if((d|0)==1){c[2414454]=2;e=b&255;c[2385794]=e;c[3527160]=e;return}else if((d|0)==2){c[2414454]=0;c[3527160]=(c[2385794]|0)/(b&255|0)|0;return}else{switch(b&255|0){case 2:{c[2443646]=2;c[3531226]=1;c[3527160]=142;return};case 3:{c[2443646]=3;c[3531226]=1;c[3527160]=189;return};case 6:{b=c[2443646]|0;if((b|0)==2){d=c[3531226]|0;c[3531226]=d+1;c[3527160]=c[595680+(d<<2)>>2];return}else if((b|0)==3){d=c[3531226]|0;c[3531226]=d+1;c[3527160]=c[595616+(d<<2)>>2];return}else if((b|0)==1){b=c[3531226]|0;c[3531226]=b+1;c[3527160]=c[595744+(b<<2)>>2];return}else{return}break};case 1:{c[2443646]=1;c[3531226]=1;c[3527160]=5;return};case 4:{c[2414454]=1;c[3527160]=4;return};default:{return}}}}function aKM(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;b=i;i=i+1200|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;l=b+360|0;m=b+472|0;n=b+480|0;o=b+592|0;p=b+600|0;q=b+712|0;r=b+720|0;s=b+832|0;t=b+840|0;u=b+952|0;v=b+960|0;w=b+1072|0;x=b+1080|0;y=b+1192|0;z=c[3527380]|0;if((c[3542200]|0)==0){A=1;i=b;return A|0}B=x+108|0;c[B>>2]=0;C=x+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,0)|0;do{if((c[B>>2]|0)!=0){x=c[C>>2]|0;c[y>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](y,0,0)|0;if((x|0)<1){A=1;i=b;return A|0}if((gzL(z,0,0)|0)==0){break}else{A=1}i=b;return A|0}}while(0);z=c[3527420]|0;if((c[3542200]|0)==0){A=1;i=b;return A|0}y=v+108|0;c[y>>2]=0;C=v+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,1)|0;do{if((c[y>>2]|0)!=0){v=c[C>>2]|0;c[w>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](w,1,0)|0;if((v|0)<1){A=1;i=b;return A|0}if((gzL(z,0,1)|0)==0){break}else{A=1}i=b;return A|0}}while(0);z=c[3529512]|0;if((c[3542200]|0)==0){A=1;i=b;return A|0}w=t+108|0;c[w>>2]=0;C=t+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,3)|0;do{if((c[w>>2]|0)!=0){t=c[C>>2]|0;c[u>>2]=9534384;y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[y&16383](u,3,0)|0;if((t|0)<1){A=1;i=b;return A|0}if((gzL(z,0,3)|0)==0){break}else{A=1}i=b;return A|0}}while(0);z=(c[3529512]|0)+32768|0;if((c[3542200]|0)==0){A=1;i=b;return A|0}u=r+108|0;c[u>>2]=0;C=r+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,4)|0;do{if((c[u>>2]|0)!=0){r=c[C>>2]|0;c[s>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](s,4,0)|0;if((r|0)<1){A=1;i=b;return A|0}if((gzL(z,0,4)|0)==0){break}else{A=1}i=b;return A|0}}while(0);z=(c[3529512]|0)+65536|0;if((c[3542200]|0)==0){A=1;i=b;return A|0}s=p+108|0;c[s>>2]=0;C=p+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,5)|0;do{if((c[s>>2]|0)!=0){p=c[C>>2]|0;c[q>>2]=9534384;u=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[u&16383](q,5,0)|0;if((p|0)<1){A=1;i=b;return A|0}if((gzL(z,0,5)|0)==0){break}else{A=1}i=b;return A|0}}while(0);z=c[3529512]|0;q=c[2406516]|0;C=0;do{s=C<<6;gGz(q+s|0,0,64);p=0;do{u=s+(c[1238464+(p<<2)>>2]|0)|0;r=(p<<3)+s|0;w=0;do{t=u+(c[614800+(w<<2)>>2]|0)|0;if(((d[z+((t|0)/8|0)|0]|0)&128>>>((t&7)>>>0)|0)!=0){t=q+(r+w)|0;a[t]=a[t]|4}w=w+1|0;}while((w|0)<8);p=p+1|0;}while((p|0)<8);p=s+262144|0;w=0;do{r=p+(c[1238464+(w<<2)>>2]|0)|0;u=(w<<3)+s|0;t=0;do{y=r+(c[614800+(t<<2)>>2]|0)|0;if(((d[z+((y|0)/8|0)|0]|0)&128>>>((y&7)>>>0)|0)!=0){y=q+(u+t)|0;a[y]=a[y]|2}t=t+1|0;}while((t|0)<8);w=w+1|0;}while((w|0)<8);w=s+524288|0;p=0;do{t=w+(c[1238464+(p<<2)>>2]|0)|0;u=(p<<3)+s|0;r=0;do{y=t+(c[614800+(r<<2)>>2]|0)|0;if(((d[z+((y|0)/8|0)|0]|0)&128>>>((y&7)>>>0)|0)!=0){y=q+(u+r)|0;a[y]=a[y]|1}r=r+1|0;}while((r|0)<8);p=p+1|0;}while((p|0)<8);C=C+1|0;}while((C|0)<2048);gGz(z|0,0,98304);if((c[3542200]|0)==0){A=1;i=b;return A|0}C=n+108|0;c[C>>2]=0;q=n+100|0;c[q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,6)|0;do{if((c[C>>2]|0)!=0){n=c[q>>2]|0;c[o>>2]=9534384;p=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[p&16383](o,6,0)|0;if((n|0)<1){A=1;i=b;return A|0}if((gzL(z,0,6)|0)==0){break}else{A=1}i=b;return A|0}}while(0);z=(c[3529512]|0)+32768|0;if((c[3542200]|0)==0){A=1;i=b;return A|0}o=l+108|0;c[o>>2]=0;q=l+100|0;c[q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,7)|0;do{if((c[o>>2]|0)!=0){l=c[q>>2]|0;c[m>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](m,7,0)|0;if((l|0)<1){A=1;i=b;return A|0}if((gzL(z,0,7)|0)==0){break}else{A=1}i=b;return A|0}}while(0);z=(c[3529512]|0)+65536|0;if((c[3542200]|0)==0){A=1;i=b;return A|0}m=j+108|0;c[m>>2]=0;q=j+100|0;c[q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,8)|0;do{if((c[m>>2]|0)!=0){j=c[q>>2]|0;c[k>>2]=9534384;o=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[o&16383](k,8,0)|0;if((j|0)<1){A=1;i=b;return A|0}if((gzL(z,0,8)|0)==0){break}else{A=1}i=b;return A|0}}while(0);z=c[3529512]|0;k=c[3529564]|0;q=0;do{m=q<<8;gGz(k+m|0,0,256);j=0;do{o=m+(c[609008+(j<<2)>>2]|0)|0;l=(j<<4)+m|0;C=0;do{n=o+(c[612640+(C<<2)>>2]|0)|0;if(((d[z+((n|0)/8|0)|0]|0)&128>>>((n&7)>>>0)|0)!=0){n=k+(l+C)|0;a[n]=a[n]|4}C=C+1|0;}while((C|0)<16);j=j+1|0;}while((j|0)<16);j=m+262144|0;C=0;do{l=j+(c[609008+(C<<2)>>2]|0)|0;o=(C<<4)+m|0;n=0;do{p=l+(c[612640+(n<<2)>>2]|0)|0;if(((d[z+((p|0)/8|0)|0]|0)&128>>>((p&7)>>>0)|0)!=0){p=k+(o+n)|0;a[p]=a[p]|2}n=n+1|0;}while((n|0)<16);C=C+1|0;}while((C|0)<16);C=m+524288|0;j=0;do{n=C+(c[609008+(j<<2)>>2]|0)|0;o=(j<<4)+m|0;l=0;do{p=n+(c[612640+(l<<2)>>2]|0)|0;if(((d[z+((p|0)/8|0)|0]|0)&128>>>((p&7)>>>0)|0)!=0){p=k+(o+l)|0;a[p]=a[p]|1}l=l+1|0;}while((l|0)<16);j=j+1|0;}while((j|0)<16);q=q+1|0;}while((q|0)<1024);q=c[2407134]|0;if((c[3542200]|0)==0){A=1;i=b;return A|0}k=g+108|0;c[k>>2]=0;z=g+100|0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,9)|0;do{if((c[k>>2]|0)!=0){g=c[z>>2]|0;c[h>>2]=9534384;j=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[j&16383](h,9,0)|0;if((g|0)<1){A=1;i=b;return A|0}if((gzL(q,0,9)|0)==0){break}else{A=1}i=b;return A|0}}while(0);q=(c[2407134]|0)+256|0;if((c[3542200]|0)==0){A=1;i=b;return A|0}h=e+108|0;c[h>>2]=0;z=e+100|0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,10)|0;if((c[h>>2]|0)==0){A=0;i=b;return A|0}h=c[z>>2]|0;c[f>>2]=9534384;gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](f,10,0)|0;if((h|0)<1){A=1;i=b;return A|0}A=(gzL(q,0,10)|0)!=0|0;i=b;return A|0}function aKN(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=(a|0)==0;e=c[2443578]|0;f=c[3527230]|0;g=c[2112926]|0;h=c[2406516]|0;i=0;j=0;while(1){k=i<<3;l=k-16|0;m=(k-25|0)>>>0>206;L43818:do{if(b){k=j;n=0;while(1){o=d[e+k|0]|0;p=d[f+k|0]|0|o<<8&1792;q=o>>>3&2|o>>>5&1;do{if((o&128|0)==0){r=n<<3;s=248-r|0;if((r|0)<1|(s|0)<9|m){Sj(g,p,s,l,q,3,128,h);break}else{Si(g,p,s,l,q,3,128,h);break}}}while(0);q=n+1|0;if((q|0)>=32){break L43818}k=k+1|0;n=q}}else{n=j;k=0;while(1){q=d[e+n|0]|0;p=d[f+n|0]|0|q<<8&1792;o=q>>>3&2|q>>>5&1;do{if((q>>>7|0)==(a|0)){s=k<<3;r=248-s|0;if((s|0)<1|(r|0)<9|m){Sr(g,p,r,l,o,3,0,128,h);break}else{Sq(g,p,r,l,o,3,0,128,h);break}}}while(0);o=k+1|0;if((o|0)>=32){break L43818}n=n+1|0;k=o}}}while(0);l=i+1|0;if((l|0)<32){i=l;j=j+32|0}else{break}}return}function aKO(b){b=b|0;var d=0,e=0;f44(1);f45(0)|0;a[9660787]=0;f45(0)|0;d=c[2414454]|0;if((d|0)==1){c[2414454]=2;e=b&255;c[2385794]=e;c[3527160]=e;return}else if((d|0)==2){c[2414454]=0;c[3527160]=(c[2385794]|0)/(b&255|0)|0;return}else{switch(b&255|0){case 3:{c[2443646]=3;c[3531226]=1;c[3527160]=189;return};case 4:{c[2414454]=1;c[3527160]=4;return};case 1:{c[2443646]=1;c[3531226]=1;c[3527160]=5;return};case 2:{c[2443646]=2;c[3531226]=1;c[3527160]=142;return};case 6:{b=c[2443646]|0;if((b|0)==2){d=c[3531226]|0;c[3531226]=d+1;c[3527160]=c[597016+(d<<2)>>2];return}else if((b|0)==1){d=c[3531226]|0;c[3531226]=d+1;c[3527160]=c[597080+(d<<2)>>2];return}else if((b|0)==3){b=c[3531226]|0;c[3531226]=b+1;c[3527160]=c[596952+(b<<2)>>2];return}else{return}break};default:{return}}}}function aKP(b,d){b=b|0;d=d|0;var e=0,f=0;e=b&16777184;if((e|0)==393216){a[(c[2387056]|0)+(b&31)|0]=d;return}else if((e|0)==458752){a[(c[2387054]|0)+(b&31)|0]=d;return}else{if((b&16775168|0)==1179648){a[(c[2387092]|0)+(b&2047)|0]=d;c[(c[3529878]|0)+((b>>>1&1023)<<2)>>2]=65535;return}if((b|0)==1114112){e=c[2386548]|0;f=c[2386372]|0;gGC(e|0,f|0,2048)|0;return}else if((b|0)==1376256){a[c[3528206]|0]=d;gg[c[(c[2443776]|0)+64>>2]&4095](32,1);gj[c[(c[2443776]|0)+52>>2]&4095](0)|0;gg[c[(c[2443776]|0)+64>>2]&4095](32,0);gj[c[(c[2443776]|0)+52>>2]&4095](0)|0;return}else{return}}}function aKQ(b){b=b|0;var c=0;if((b|0)==1245184|(b|0)==1245185){c=a[9550104+(b&1)|0]|0}else if((b|0)==1310720|(b|0)==1310721){c=(a[672552]|0?-128:0)|a[9550106]&127}else if((b|0)==1245186|(b|0)==1245187){c=a[9634624+(b&1)|0]|0}else{c=0}return c|0}function aKR(b,d){b=b|0;d=d|0;var e=0,f=0;e=b&16777184;if((e|0)==393216){a[(c[2387056]|0)+(b&31)|0]=d;return}else if((e|0)==262144){a[(c[2387054]|0)+(b&31)|0]=d;return}else{if((b&16775168|0)==1245184){a[(c[2387092]|0)+(b&2047)|0]=d;c[(c[3529878]|0)+((b>>>1&1023)<<2)>>2]=65535;return}if((b|0)==2093056|(b|0)==2093057){a[9753256]=d;return}else if((b|0)==2094080|(b|0)==2094081|(b|0)==2094082|(b|0)==2094083){e=b&3;a[9661104]=d;if((e|0)==3){if((a[9661087]|0)==0){return}a[9661087]=0;if((a[9661088]|0)!=0){return}a[9661088]=2;return}else if((e|0)==2){a[9661072]=d&7;if((a[9661088]|0)!=0){return}a[9661088]=2;return}else{a[9661104]=d;return}}else if((b|0)==1114112){e=c[2386548]|0;f=c[2386372]|0;gGC(e|0,f|0,2048)|0;return}else if((b|0)==1048576){a[c[3528206]|0]=d;gg[c[(c[2443776]|0)+64>>2]&4095](32,1);gj[c[(c[2443776]|0)+52>>2]&4095](0)|0;gg[c[(c[2443776]|0)+64>>2]&4095](32,0);gj[c[(c[2443776]|0)+52>>2]&4095](0)|0;return}else{return}}}function aKS(b){b=b|0;var c=0;L43925:do{if((b-2093056|0)>>>0<2){switch(d[9753256]|0|0){case 1:{c=a[9550105]|0;break L43925;break};case 3:{c=a[9634625]|0;break L43925;break};case 2:{c=a[9634624]|0;break L43925;break};case 4:{c=(a[672552]|0?-128:0)|a[9550106]&127;break L43925;break};case 0:{c=a[9550104]|0;break L43925;break};default:{c=-1;break L43925}}}else{c=0}}while(0);return c|0}function aKT(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3183772+(b*112|0)>>2];c[a+104>>2]=c[3183776+(b*112|0)>>2];c[a+108>>2]=c[3183780+(b*112|0)>>2];d=0;return d|0}function aKU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=3183672+(b*112|0);e=0;return e|0}function aKV(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1326664+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aKW(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>27){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4300752+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aKX(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0;e=i;i=i+2280|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;B=e+1200|0;C=e+1312|0;D=e+1320|0;E=e+1432|0;F=e+1440|0;G=e+1552|0;H=e+1560|0;I=e+1672|0;J=e+1680|0;K=e+1792|0;L=e+1800|0;M=e+1912|0;N=e+1920|0;O=e+2032|0;P=e+2040|0;Q=e+2152|0;R=e+2160|0;S=e+2272|0;c[3531214]=0;c[3531194]=262144;c[3530738]=327680;c[3530502]=589824;c[3530370]=1376256;c[3541206]=1900544;c[3529878]=2162688;c[2414542]=2166784;c[3531216]=2166784;c[3531204]=2183168;c[2386372]=2185216;c[2387092]=2187264;c[2386548]=2189312;c[3528206]=2191360;c[2387074]=2191362;c[2387064]=2199554;c[2387070]=2207746;c[2387060]=2209794;c[2387056]=2211842;c[2387054]=2211874;c[2411440]=2211906;T=gGq(2211906)|0;c[2414840]=T;if((T|0)==0){U=1;i=e;return U|0}gGz(T|0,0,2211906);c[3531214]=T;c[3531194]=T+262144;c[3530738]=T+327680;c[3530502]=T+589824;c[3530370]=T+1376256;c[3541206]=T+1900544;c[3529878]=T+2162688;V=T+2166784|0;c[2414542]=V;c[3531216]=V;c[3531204]=T+2183168;c[2386372]=T+2185216;c[2387092]=T+2187264;c[2386548]=T+2189312;c[3528206]=T+2191360;c[3528640]=T+2191361;c[2387074]=T+2191362;c[2387064]=T+2199554;c[2387070]=T+2207746;c[2387060]=T+2209794;c[2387056]=T+2211842;c[2387054]=T+2211874;V=T+2211906|0;c[2411440]=V;c[2413980]=V;if((c[3542200]|0)==0){U=1;i=e;return U|0}V=R+108|0;c[V>>2]=0;W=R+100|0;c[W>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](R,0)|0;do{if((c[V>>2]|0)!=0){R=c[W>>2]|0;c[S>>2]=9534384;X=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[X&16383](S,0,0)|0;if((R|0)<1){U=1;i=e;return U|0}if((gzL(T,0,0)|0)==0){break}else{U=1}i=e;return U|0}}while(0);T=(c[3531214]|0)+65536|0;if((c[3542200]|0)==0){U=1;i=e;return U|0}S=P+108|0;c[S>>2]=0;W=P+100|0;c[W>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](P,1)|0;do{if((c[S>>2]|0)!=0){P=c[W>>2]|0;c[Q>>2]=9534384;V=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[V&16383](Q,1,0)|0;if((P|0)<1){U=1;i=e;return U|0}if((gzL(T,0,1)|0)==0){break}else{U=1}i=e;return U|0}}while(0);T=(c[3531214]|0)+131072|0;if((c[3542200]|0)==0){U=1;i=e;return U|0}Q=N+108|0;c[Q>>2]=0;W=N+100|0;c[W>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](N,2)|0;do{if((c[Q>>2]|0)!=0){N=c[W>>2]|0;c[O>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](O,2,0)|0;if((N|0)<1){U=1;i=e;return U|0}if((gzL(T,0,2)|0)==0){break}else{U=1}i=e;return U|0}}while(0);T=(c[3531194]|0)+32768|0;if((c[3542200]|0)==0){U=1;i=e;return U|0}O=L+108|0;c[O>>2]=0;W=L+100|0;c[W>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](L,3)|0;do{if((c[O>>2]|0)!=0){L=c[W>>2]|0;c[M>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](M,3,0)|0;if((L|0)<1){U=1;i=e;return U|0}if((gzL(T,0,3)|0)==0){break}else{U=1}i=e;return U|0}}while(0);T=c[3530738]|0;if((c[3542200]|0)==0){U=1;i=e;return U|0}M=J+108|0;c[M>>2]=0;W=J+100|0;c[W>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](J,4)|0;do{if((c[M>>2]|0)!=0){J=c[W>>2]|0;c[K>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](K,4,0)|0;if((J|0)<1){U=1;i=e;return U|0}if((gzL(T,0,4)|0)==0){break}else{U=1}i=e;return U|0}}while(0);T=(c[3530738]|0)+65536|0;if((c[3542200]|0)==0){U=1;i=e;return U|0}K=H+108|0;c[K>>2]=0;W=H+100|0;c[W>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](H,5)|0;do{if((c[K>>2]|0)!=0){H=c[W>>2]|0;c[I>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](I,5,0)|0;if((H|0)<1){U=1;i=e;return U|0}if((gzL(T,0,5)|0)==0){break}else{U=1}i=e;return U|0}}while(0);T=c[3530502]|0;if((c[3542200]|0)==0){U=1;i=e;return U|0}I=F+108|0;c[I>>2]=0;W=F+100|0;c[W>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](F,6)|0;do{if((c[I>>2]|0)!=0){F=c[W>>2]|0;c[G>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](G,6,0)|0;if((F|0)<1){U=1;i=e;return U|0}if((gzL(T,0,6)|0)==0){break}else{U=1}i=e;return U|0}}while(0);T=(c[3530502]|0)+65536|0;if((c[3542200]|0)==0){U=1;i=e;return U|0}G=D+108|0;c[G>>2]=0;W=D+100|0;c[W>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](D,7)|0;do{if((c[G>>2]|0)!=0){D=c[W>>2]|0;c[E>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](E,7,0)|0;if((D|0)<1){U=1;i=e;return U|0}if((gzL(T,0,7)|0)==0){break}else{U=1}i=e;return U|0}}while(0);T=(c[3530502]|0)+98304|0;if((c[3542200]|0)==0){U=1;i=e;return U|0}E=B+108|0;c[E>>2]=0;W=B+100|0;c[W>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](B,8)|0;do{if((c[E>>2]|0)!=0){B=c[W>>2]|0;c[C>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](C,8,0)|0;if((B|0)<1){U=1;i=e;return U|0}if((gzL(T,0,8)|0)==0){break}else{U=1}i=e;return U|0}}while(0);T=(c[3530502]|0)+163840|0;if((c[3542200]|0)==0){U=1;i=e;return U|0}C=z+108|0;c[C>>2]=0;W=z+100|0;c[W>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,9)|0;do{if((c[C>>2]|0)!=0){z=c[W>>2]|0;c[A>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](A,9,0)|0;if((z|0)<1){U=1;i=e;return U|0}if((gzL(T,0,9)|0)==0){break}else{U=1}i=e;return U|0}}while(0);T=(c[3530502]|0)+196608|0;if((c[3542200]|0)==0){U=1;i=e;return U|0}A=x+108|0;c[A>>2]=0;W=x+100|0;c[W>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,10)|0;do{if((c[A>>2]|0)!=0){x=c[W>>2]|0;c[y>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](y,10,0)|0;if((x|0)<1){U=1;i=e;return U|0}if((gzL(T,0,10)|0)==0){break}else{U=1}i=e;return U|0}}while(0);T=(c[3530502]|0)+262144|0;if((c[3542200]|0)==0){U=1;i=e;return U|0}y=v+108|0;c[y>>2]=0;W=v+100|0;c[W>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,11)|0;do{if((c[y>>2]|0)!=0){v=c[W>>2]|0;c[w>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](w,11,0)|0;if((v|0)<1){U=1;i=e;return U|0}if((gzL(T,0,11)|0)==0){break}else{U=1}i=e;return U|0}}while(0);T=(c[3530502]|0)+294912|0;if((c[3542200]|0)==0){U=1;i=e;return U|0}w=t+108|0;c[w>>2]=0;W=t+100|0;c[W>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,12)|0;do{if((c[w>>2]|0)!=0){t=c[W>>2]|0;c[u>>2]=9534384;y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[y&16383](u,12,0)|0;if((t|0)<1){U=1;i=e;return U|0}if((gzL(T,0,12)|0)==0){break}else{U=1}i=e;return U|0}}while(0);T=(c[3530502]|0)+360448|0;if((c[3542200]|0)==0){U=1;i=e;return U|0}u=r+108|0;c[u>>2]=0;W=r+100|0;c[W>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,13)|0;do{if((c[u>>2]|0)!=0){r=c[W>>2]|0;c[s>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](s,13,0)|0;if((r|0)<1){U=1;i=e;return U|0}if((gzL(T,0,13)|0)==0){break}else{U=1}i=e;return U|0}}while(0);T=c[3530370]|0;if((c[3542200]|0)==0){U=1;i=e;return U|0}s=p+108|0;c[s>>2]=0;W=p+100|0;c[W>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,14)|0;do{if((c[s>>2]|0)!=0){p=c[W>>2]|0;c[q>>2]=9534384;u=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[u&16383](q,14,0)|0;if((p|0)<1){U=1;i=e;return U|0}if((gzL(T,0,14)|0)==0){break}else{U=1}i=e;return U|0}}while(0);T=(c[3530370]|0)+65536|0;if((c[3542200]|0)==0){U=1;i=e;return U|0}q=n+108|0;c[q>>2]=0;W=n+100|0;c[W>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,15)|0;do{if((c[q>>2]|0)!=0){n=c[W>>2]|0;c[o>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](o,15,0)|0;if((n|0)<1){U=1;i=e;return U|0}if((gzL(T,0,15)|0)==0){break}else{U=1}i=e;return U|0}}while(0);T=(c[3530370]|0)+131072|0;if((c[3542200]|0)==0){U=1;i=e;return U|0}o=l+108|0;c[o>>2]=0;W=l+100|0;c[W>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,16)|0;do{if((c[o>>2]|0)!=0){l=c[W>>2]|0;c[m>>2]=9534384;q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[q&16383](m,16,0)|0;if((l|0)<1){U=1;i=e;return U|0}if((gzL(T,0,16)|0)==0){break}else{U=1}i=e;return U|0}}while(0);T=(c[3530370]|0)+196608|0;if((c[3542200]|0)==0){U=1;i=e;return U|0}m=j+108|0;c[m>>2]=0;W=j+100|0;c[W>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,17)|0;do{if((c[m>>2]|0)!=0){j=c[W>>2]|0;c[k>>2]=9534384;o=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[o&16383](k,17,0)|0;if((j|0)<1){U=1;i=e;return U|0}if((gzL(T,0,17)|0)==0){break}else{U=1}i=e;return U|0}}while(0);T=c[3541206]|0;if((c[3542200]|0)==0){U=1;i=e;return U|0}k=f+108|0;c[k>>2]=0;W=f+100|0;c[W>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,18)|0;do{if((c[k>>2]|0)!=0){f=c[W>>2]|0;c[g>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](g,18,0)|0;if((f|0)<1){U=1;i=e;return U|0}if((gzL(T,0,18)|0)==0){break}else{U=1}i=e;return U|0}}while(0);if((aLb()|0)!=0){U=1;i=e;return U|0}fv8();c[2388530]=9554128;T=c[2391608]|0;if((T|0)!=0){g=T;gGC(9661040,g|0,68)|0}c[2382]=0;g=c[3531214]|0;T=0;do{W=g+(T<<11)|0;c[9554144+(T<<2)>>2]=W;c[9562336+(T<<2)>>2]=W;T=T+1|0;}while(T>>>0<128);T=c[2387074]|0;c[2388732]=T;c[2389756]=T;c[2390780]=T;g=T+2048|0;c[2388733]=g;c[2389757]=g;c[2390781]=g;g=T+4096|0;c[2388734]=g;c[2389758]=g;c[2390782]=g;g=T+6144|0;c[2388735]=g;c[2389759]=g;c[2390783]=g;g=c[2387064]|0;c[2388764]=g;c[2389788]=g;c[2390812]=g;T=g+2048|0;c[2388765]=T;c[2389789]=T;c[2390813]=T;T=g+4096|0;c[2388766]=T;c[2389790]=T;c[2390814]=T;T=g+6144|0;c[2388767]=T;c[2389791]=T;c[2390815]=T;T=c[2386372]|0;c[2389048]=T;c[2390072]=T;c[2391096]=T;T=c[2387092]|0;c[2389112]=T;c[2391160]=T;T=c[3531216]|0;c[2389528]=T;c[2390552]=T;c[2391576]=T;g=T+2048|0;c[2389529]=g;c[2390553]=g;c[2391577]=g;g=T+4096|0;c[2389530]=g;c[2390554]=g;c[2391578]=g;g=T+6144|0;c[2389531]=g;c[2390555]=g;c[2391579]=g;g=T+8192|0;c[2389532]=g;c[2390556]=g;c[2391580]=g;g=T+10240|0;c[2389533]=g;c[2390557]=g;c[2391581]=g;g=T+12288|0;c[2389534]=g;c[2390558]=g;c[2391582]=g;g=T+14336|0;c[2389535]=g;c[2390559]=g;c[2391583]=g;c[2388533]=1526;c[2388532]=1246;g=c[2391608]|0;if((g|0)!=0){T=g;gGC(T|0,9661040,68)|0}c[2382]=-1;aLc();b[7057272]=512;b[7057268]=256;a[7358064]=1;T=c[642608+(c[2436]<<2)>>2]|0;g=c[T+128>>2]|0;if((c[T+52>>2]&4|0)==0){c[2113068]=g;W=c[T+132>>2]|0;c[2113070]=W;c[2443814]=g;c[2440436]=W;Y=g;Z=W}else{c[2113070]=g;W=c[T+132>>2]|0;c[2113068]=W;c[2440436]=g;c[2443814]=W;Y=W;Z=g}g=ag(Y<<1,Z)|0;Z=gGq(g)|0;c[2112926]=Z;if((Z|0)!=0){gGz(Z|0,0,g|0)}g=c[2414542]|0;gGz(g|0,0,(c[2411440]|0)-g|0);c[2388530]=9554128;g=c[2391608]|0;if((g|0)!=0){Z=g;gGC(9661040,Z|0,68)|0}c[2382]=0;Z=c[2415273]|0;gGz(9661040,0,68);c[2415273]=Z;a[9661063]=20;c[2415262]=511;Z=c[2388539]|0;do{if((Z|0)==0){g=c[2388532]|0;if((g|0)==0){_=0;$=8191;aa=9554128;break}Y=gj[g&4095](8190)|0;_=Y;$=d[9661071]<<13|8191;aa=c[2388530]|0}else{_=a[Z+2046|0]|0;$=8191;aa=9554128}}while(0);a[9661044]=_;_=c[aa+16+($>>>11<<2)>>2]|0;do{if((_|0)==0){Z=c[aa>>2]|0;if((Z|0)==0){ab=0;ac=aa;break}Y=gj[Z&4095]($)|0;ab=Y;ac=c[2388530]|0}else{ab=a[_+2047|0]|0;ac=aa}}while(0);a[9661045]=ab;a[9661075]=4;a[9661073]=0;c[2415270]=131072;c[2415275]=0;gGz(9661084,0,5);ab=c[ac+12304>>2]|0;if((ab|0)!=0){ac=ab;gGC(ac|0,9661040,68)|0}c[2382]=-1;c[3528556]=0;ac=c[2433594]|0;c[2443776]=ac;L44192:do{if((ac|0)!=0){ab=ac|0;gGC(9660952,ab|0,52)|0;switch(a[9660952]|0){case 5:{c[2309668]=7354992;break L44192;break};case 2:{c[2309668]=638960;break L44192;break};case 0:{c[2309668]=638960;break L44192;break};case 1:{c[2309668]=634096;break L44192;break};case 3:{c[2309668]=639984;break L44192;break};case 4:{c[2309668]=7356016;break L44192;break};default:{break L44192}}}}while(0);c[2113164]=c[2432850];gu[c[ac+56>>2]&16383]();ac=c[2443776]|0;if((ac|0)!=0){ab=ac|0;gGC(ab|0,9660952,52)|0}c[9731400+(c[3528556]<<2)>>2]=c[2113164];c[2443776]=0;c[3528556]=-1;c[2113156]=0;a[9628264]=0;c[2407033]=0;ab=c[3541206]|0;c[3541190]=ab;c[3541198]=ab;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=ab+256;c[3541199]=ab+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=ab+512;c[3541200]=ab+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=ab+768;c[3541201]=ab+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){ab=0;do{lN(ab);mB(ab);ab=ab+1|0;}while((ab|0)<(c[2385508]|0))}c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;lw(c[3540984]|0);a[9753256]=0;U=0;i=e;return U|0}function aKY(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}b=c[3541518]|0;if((b|0)!=0){gGr(b|0);c[3541518]=0}if((c[2385508]|0)>0){c[2113008]=0;c[2076598]=0;c[2383582]=0}c[2438228]=0;c[2433526]=0;c[2406676]=0;c[3528472]=0;b=c[2406680]|0;if((b|0)!=0){gGr(b);c[2406680]=0}c[2385508]=0;c[2432978]=0;a[64240]=0;b=a[7452584]|0;if(b){d=0;e=b&1;while(1){b=14163936+(d<<2)|0;f=c[b>>2]|0;g=c[2113006]|0;if((g|0)==0){h=34273}else{i=g-1|0;c[2113006]=i;if((i|0)==0){h=34273}}if((h|0)==34273){h=0;c[2383474]=0}if((f|0)==0){j=e}else{gGr(f);j=a[7452584]&1}c[b>>2]=0;b=d+1|0;if((b|0)<(j|0)){d=b;e=j}else{break}}}a[7452584]=0;c[2438224]=0;c[2433522]=0;c[2406672]=0;c[3528468]=0;j=c[2406688]|0;if((j|0)==0){c[2432972]=0;Uw(0);fv9();fvR();k=c[2414840]|0;gGr(k);c[2414840]=0;return 0}gGr(j);c[2406688]=0;c[2432972]=0;Uw(0);fv9();fvR();k=c[2414840]|0;gGr(k);c[2414840]=0;return 0}function aKZ(){var b=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0;if((a[9623336]|0)!=0){b=c[2414542]|0;gGz(b|0,0,(c[2411440]|0)-b|0);c[2388530]=9554128;b=c[2391608]|0;if((b|0)!=0){e=b;gGC(9661040,e|0,68)|0}c[2382]=0;e=c[2415273]|0;gGz(9661040,0,68);c[2415273]=e;a[9661063]=20;c[2415262]=511;e=c[2388539]|0;do{if((e|0)==0){b=c[2388532]|0;if((b|0)==0){f=0;g=8191;i=9554128;break}j=gj[b&4095](8190)|0;f=j;g=d[9661071]<<13|8191;i=c[2388530]|0}else{f=a[e+2046|0]|0;g=8191;i=9554128}}while(0);a[9661044]=f;f=c[i+16+(g>>>11<<2)>>2]|0;do{if((f|0)==0){e=c[i>>2]|0;if((e|0)==0){k=0;l=i;break}j=gj[e&4095](g)|0;k=j;l=c[2388530]|0}else{k=a[f+2047|0]|0;l=i}}while(0);a[9661045]=k;a[9661075]=4;a[9661073]=0;c[2415270]=131072;c[2415275]=0;gGz(9661084,0,5);k=c[l+12304>>2]|0;if((k|0)!=0){l=k;gGC(l|0,9661040,68)|0}c[2382]=-1;c[3528556]=0;l=c[2433594]|0;c[2443776]=l;L44259:do{if((l|0)!=0){k=l|0;gGC(9660952,k|0,52)|0;switch(a[9660952]|0){case 5:{c[2309668]=7354992;break L44259;break};case 1:{c[2309668]=634096;break L44259;break};case 2:{c[2309668]=638960;break L44259;break};case 4:{c[2309668]=7356016;break L44259;break};case 0:{c[2309668]=638960;break L44259;break};case 3:{c[2309668]=639984;break L44259;break};default:{break L44259}}}}while(0);c[2113164]=c[2432850];gu[c[l+56>>2]&16383]();l=c[2443776]|0;if((l|0)!=0){k=l|0;gGC(k|0,9660952,52)|0}c[9731400+(c[3528556]<<2)>>2]=c[2113164];c[2443776]=0;c[3528556]=-1;c[2113156]=0;a[9628264]=0;c[2407033]=0;k=c[3541206]|0;c[3541190]=k;c[3541198]=k;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=k+256;c[3541199]=k+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=k+512;c[3541200]=k+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=k+768;c[3541201]=k+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){k=0;do{lN(k);mB(k);k=k+1|0;}while((k|0)<(c[2385508]|0))}c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;lw(c[3540984]|0);a[9753256]=0}c[(c[2391608]|0)+60>>2]=0;c[(c[2391608]|0)+60>>2]=0;k=c[2113166]|0;if((k|0)>0){gGz(9731400,0,((k|0)>1?k<<2:4)|0)}c[2113164]=0;gGz(9550104,-1|0,3);k=0;l=-1;i=-1;f=-1;do{l=((a[9632288+k|0]&1)<<k^l&255)&255;i=((a[9630200+k|0]&1)<<k^i&255)&255;f=((a[9629144+k|0]&1)<<k^f&255)&255;k=k+1|0;}while((k|0)<8);a[9550104]=l;a[9550105]=i;a[9550106]=f;if((l&3)==0){f=l|3;a[9550104]=f;m=f}else{m=l}if((m&12)==0){a[9550104]=m|12}if((i&3)==0){m=i|3;a[9550105]=m;n=m}else{n=i}if((n&12)==0){a[9550105]=n|12}c[2388530]=9554128;n=c[2391608]|0;if((n|0)!=0){i=n;gGC(9661040,i|0,68)|0}c[2382]=0;c[3528556]=0;i=c[2433594]|0;c[2443776]=i;L44298:do{if((i|0)!=0){n=i|0;gGC(9660952,n|0,52)|0;switch(a[9660952]|0){case 0:{c[2309668]=638960;break L44298;break};case 1:{c[2309668]=634096;break L44298;break};case 2:{c[2309668]=638960;break L44298;break};case 5:{c[2309668]=7354992;break L44298;break};case 3:{c[2309668]=639984;break L44298;break};case 4:{c[2309668]=7356016;break L44298;break};default:{break L44298}}}}while(0);c[2113164]=c[2432850];a[672552]=1;i=0;do{Sb(i*3728|0);do{if((i|0)==1){a[672552]=0}else if((i|0)==30){a[672552]=1;do{if((a[9661085]|0)!=1){a[9661085]=1;if((a[9661088]|0)!=0){break}a[9661088]=2}}while(0);fy_(10)|0;if((a[9661085]|0)==0){break}a[9661085]=0;if((a[9661088]|0)!=0){break}a[9661088]=2}}while(0);UF(i*781|0)|0;i=i+1|0;}while((i|0)<32);i=c[2438228]|0;n=gGS(-948305920,56894,i,(i|0)<0|0?-1:0)|0;i=n;Sb(119317);n=c[2443830]|0;if((n|0)<1073676288){c[2443830]=n-i}n=c[2443831]|0;if((n|0)<1073676288){c[2443831]=n-i}n=(c[3528512]|0)-i|0;c[3528512]=(n|0)<0?0:n;n=c[2438224]|0;i=gGS(-305135616,11920,n,(n|0)<0|0?-1:0)|0;n=i;UF(25e3)|0;i=c[2443826]|0;if((i|0)<1073676288){c[2443826]=i-n}i=c[2443827]|0;if((i|0)<1073676288){c[2443827]=i-n}i=(c[3528508]|0)-n|0;c[3528508]=(i|0)<0?0:i;i=c[2112964]|0;if((i|0)!=0){gg[c[3542122]&4095](i,a[9688]|0?534:0);gg[c[3542112]&4095](c[2112964]|0,a[9688]|0?534:0);Uu(0,c[2112964]|0,a[9688]|0?534:0)}i=c[2443776]|0;if((i|0)!=0){n=i|0;gGC(n|0,9660952,52)|0}c[9731400+(c[3528556]<<2)>>2]=c[2113164];c[2443776]=0;c[3528556]=-1;n=c[(c[2388530]|0)+12304>>2]|0;if((n|0)!=0){i=n;gGC(i|0,9661040,68)|0}c[2382]=-1;if((c[2112968]|0)==0){return 0}aK_()|0;return 0}function aK_(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;if((a[9547024]|0)!=0){f=c[3529878]|0;g=0;do{c[f+(g>>>1<<2)>>2]=65535;g=g+2|0;}while((g|0)<1536);a[9547024]=0}g=a[7358064]|0?2:0;f=c[2387056]|0;h=a[f+6|0]&3;i=c[603760+(g<<5)+(h<<3)>>2]|0;j=c[603760+(g<<5)+(h<<3)+4>>2]|0;g=i<<4;k=g-1|0;l=(d[f+17|0]<<8|d[f+16|0])&k;m=j<<4;n=m-1|0;o=(d[f+19|0]<<8|d[f+18|0])&n;do{if((a[f]&4)==0){p=ag(j,i)|0;if((p|0)<=0){break}q=h|4;r=-8-o|0;s=c[2387074]|0;t=c[2112926]|0;u=e[7057268]|0;v=c[3530370]|0;w=c[2113070]|0;x=0;do{y=(x|0)%(i|0)|0;z=(((x|0)/(i|0)|0|0)%(j|0)|0)<<4;A=(z|y&15)+((y&496)<<q)|0;B=(y<<4)-l|0;y=((B|0)<-15?g:0)+B|0;B=z+r|0;z=((B|0)<-15?m:0)+B|0;L44379:do{if((z|0)<(w|0)){B=c[2113068]|0;if((y|0)>=(B|0)){break}C=A<<1;D=d[s+(C|1)|0]|0;E=D<<8|d[s+C|0];do{if((y|0)>-1){if(!((y|0)<=(B-16|0)&(z|0)>-1)){break}if((z|0)>(w-16|0)){break}Sy(t,E&4095,y,z,D>>>4,4,u,v);break L44379}}while(0);Sz(t,E&4095,y,z,D>>>4,4,u,v)}}while(0);x=x+1|0;}while((x|0)<(p|0))}else{p=c[2113070]|0;if((p|0)<=0){break}x=o+8|0;v=h|4;u=c[2113068]|0;t=c[2112926]|0;w=c[2387070]|0;s=c[2387074]|0;r=c[3530370]|0;q=e[7057268]|0;z=u+16|0;y=0;do{A=ag(y,u)|0;B=x+y|0;C=B&n;F=(C&511)>>>((a[f+23|0]&15)>>>0)<<1;G=(d[w+(F+1024)|0]|0)+l+(d[w+(F+1025)|0]<<8)|0;F=G&k;if((u+16|0)>0){H=C&1008;C=B<<4&240;B=G&15;G=0;do{I=(G+F&k|0)/16|0;J=(I&15|H)+((I&496)<<v)<<1;I=(d[s+(J|1)|0]<<8|d[s+J|0])&65535;J=I<<8&1048320|C;K=(I>>>12<<4)+q|0;I=G-B|0;do{if((I|0)>-1){if((I|0)>(u-16|0)){L=I;M=0;N=34382;break}else{O=I;P=0}while(1){b[t+(O+A<<1)>>1]=(d[r+(P+J)|0]|0)+K&65535;Q=P+1|0;if((Q|0)<16){O=O+1|0;P=Q}else{break}}}else{L=I;M=0;N=34382}}while(0);L44366:do{if((N|0)==34382){while(1){N=0;if((L|0)>-1&(L|0)<(u|0)){b[t+(L+A<<1)>>1]=(d[r+(M+J)|0]|0)+K&65535}I=M+1|0;if((I|0)>=16){break L44366}L=L+1|0;M=I;N=34382}}}while(0);G=G+16|0;}while((G|0)<(z|0))}y=y+1|0;}while((y|0)<(p|0))}}while(0);N=c[2386548]|0;M=c[3530502]|0;L=e[7057272]|0;P=c[2112926]|0;O=(c[2113222]&1|0)==0;k=0;L44389:while(1){l=d[N+(k+1)|0]|0;f=l<<8;n=d[N+(k+5)|0]|0;h=n<<8;o=n>>>4;n=f&16384;m=1<<(l>>>3&3);g=1<<(l>>>1&3);l=h&256|d[N+(k+4)|0];j=f&256|d[N+k|0];i=240-(l>>>0>255?l|-512:l)|0;l=(f&32768|0)==0;p=(h&2048|0)==0;h=-m|0;y=(n|0)!=0;z=(m|0)>0;r=(f&8192|0)!=0;f=232-(j>>>0>255?j|-512:j)|0;j=(n>>>13^2)-1|0;n=y?0:m-1|0;t=0;u=k;while(1){if((t|0)>=(g|0)){break}do{if(!l){if(!(p|O^1)){break}q=((((d[N+(u+3)|0]<<8|d[N+(u+2)|0])&h)>>>0)%3072|0)+n|0;if(!z){break}s=(t*-16|0)+i|0;if(y){if(r){v=0;do{SN(P,q-(ag(v,j)|0)|0,s,(v*-16|0)+f|0,o,4,0,L,M);v=v+1|0;}while((v|0)<(m|0))}else{v=0;do{SL(P,q-(ag(v,j)|0)|0,s,(v*-16|0)+f|0,o,4,0,L,M);v=v+1|0;}while((v|0)<(m|0))}}else{if(r){v=0;do{SJ(P,q-(ag(v,j)|0)|0,s,(v*-16|0)+f|0,o,4,0,L,M);v=v+1|0;}while((v|0)<(m|0))}else{v=0;do{SH(P,q-(ag(v,j)|0)|0,s,(v*-16|0)+f|0,o,4,0,L,M);v=v+1|0;}while((v|0)<(m|0))}}}}while(0);v=u+8|0;if((v|0)>2047){break L44389}else{t=t+1|0;u=v}}if((u|0)<2048){k=u}else{break}}k=c[2387064]|0;M=c[3530738]|0;L=32;do{N=L<<1;O=d[k+(N|1)|0]|0;t=O<<8|d[k+N|0];if((t|0)!=0){Sq(P,t&4095,L<<3&248,(L>>5<<3)-8|0,O>>>4,4,0,0,M)}L=L+1|0;}while((L|0)<992);R8(c[3529878]|0);return 0}function aK$(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;e=i;i=i+256|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;l=e+80|0;m=e+224|0;n=e+240|0;if((d|0)!=0){c[d>>2]=169761}if((b&32|0)!=0){gGz(n|0,0,12);o=c[2414542]|0;c[n>>2]=o;c[n+4>>2]=(c[2411440]|0)-o;c[n+12>>2]=162152;o=c[2076592]|0;gj[o&4095](n)|0}if((b&64|0)==0){i=e;return 0}n=l;o=e+96|0;p=l|0;q=l+4|0;r=l+12|0;s=c[2391608]|0;if((s|0)!=0){t=s+52|0;u=c[t>>2]|0;gGz(n|0,0,16);c[p>>2]=s;c[q>>2]=68;cC(o|0,165488,(v=i,i=i+8|0,c[v>>2]=0,v)|0)|0;i=v;c[r>>2]=o;s=c[2076592]|0;gj[s&4095](l)|0;c[t>>2]=u}u=c[2394685]|0;if((u|0)!=0){t=u+52|0;s=c[t>>2]|0;gGz(n|0,0,16);c[p>>2]=u;c[q>>2]=68;cC(o|0,165488,(v=i,i=i+8|0,c[v>>2]=1,v)|0)|0;i=v;c[r>>2]=o;o=c[2076592]|0;gj[o&4095](l)|0;c[t>>2]=s}s=k|0;if((c[2113166]|0)>0){t=k+7|0;k=j|0;l=j+4|0;o=j+12|0;r=h;v=h|0;q=h+4|0;u=h+12|0;p=g;n=g|0;w=g+4|0;x=g+12|0;y=f;z=f|0;A=f+4|0;B=f+12|0;C=0;do{D=c[9734376+(C<<2)>>2]|0;E=D+36|0;F=c[E>>2]|0;gGC(s|0,614768,9)|0;a[t]=C+48&255;c[k>>2]=D;c[l>>2]=52;c[o>>2]=s;gj[c[2076592]&4095](j)|0;gGz(r|0,0,12);c[v>>2]=D+3172;c[q>>2]=4;c[u>>2]=165288;gj[c[2076592]&4095](h)|0;gGz(p|0,0,12);c[n>>2]=D+3176;c[w>>2]=4;c[x>>2]=501592;gj[c[2076592]&4095](g)|0;gGz(y|0,0,12);c[z>>2]=D+3180;c[A>>2]=4;c[B>>2]=386080;gj[c[2076592]&4095](f)|0;c[E>>2]=F;C=C+1|0;}while((C|0)<(c[2113166]|0))}Vx(b,d);UQ(b,d);Ut(0);gGz(m|0,0,12);c[m>>2]=9753256;c[m+4>>2]=1;c[m+12>>2]=108184;gj[c[2076592]&4095](m)|0;i=e;return 0}function aK0(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1629108+(b*112|0)>>2];c[a+104>>2]=c[1629112+(b*112|0)>>2];c[a+108>>2]=c[1629116+(b*112|0)>>2];d=0;return d|0}function aK1(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=1629008+(b*112|0);e=0;return e|0}function aK2(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1626980+(b*112|0)>>2];c[a+104>>2]=c[1626984+(b*112|0)>>2];c[a+108>>2]=c[1626988+(b*112|0)>>2];d=0;return d|0}function aK3(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=1626880+(b*112|0);e=0;return e|0}function aK4(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2125804+(b*112|0)>>2];c[a+104>>2]=c[2125808+(b*112|0)>>2];c[a+108>>2]=c[2125812+(b*112|0)>>2];d=0;return d|0}function aK5(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=2125704+(b*112|0);e=0;return e|0}function aK6(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1177832+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aK7(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>27){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3281488+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aK8(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0;e=i;i=i+2280|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;B=e+1200|0;C=e+1312|0;D=e+1320|0;E=e+1432|0;F=e+1440|0;G=e+1552|0;H=e+1560|0;I=e+1672|0;J=e+1680|0;K=e+1792|0;L=e+1800|0;M=e+1912|0;N=e+1920|0;O=e+2032|0;P=e+2040|0;Q=e+2152|0;R=e+2160|0;S=e+2272|0;c[3531214]=0;c[3531194]=262144;c[3530738]=327680;c[3530502]=589824;c[3530370]=1376256;c[3541206]=1900544;c[3529878]=2162688;c[2414542]=2166784;c[3531216]=2166784;c[3531204]=2183168;c[2386372]=2185216;c[2387092]=2187264;c[2386548]=2189312;c[3528206]=2191360;c[2387074]=2191362;c[2387064]=2199554;c[2387070]=2207746;c[2387060]=2209794;c[2387056]=2211842;c[2387054]=2211874;c[2411440]=2211906;T=gGq(2211906)|0;c[2414840]=T;if((T|0)==0){U=1;i=e;return U|0}gGz(T|0,0,2211906);c[3531214]=T;c[3531194]=T+262144;c[3530738]=T+327680;c[3530502]=T+589824;c[3530370]=T+1376256;c[3541206]=T+1900544;c[3529878]=T+2162688;V=T+2166784|0;c[2414542]=V;c[3531216]=V;c[3531204]=T+2183168;c[2386372]=T+2185216;c[2387092]=T+2187264;c[2386548]=T+2189312;c[3528206]=T+2191360;c[3528640]=T+2191361;c[2387074]=T+2191362;c[2387064]=T+2199554;c[2387070]=T+2207746;c[2387060]=T+2209794;c[2387056]=T+2211842;c[2387054]=T+2211874;V=T+2211906|0;c[2411440]=V;c[2413980]=V;if((c[3542200]|0)==0){U=1;i=e;return U|0}V=R+108|0;c[V>>2]=0;W=R+100|0;c[W>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](R,0)|0;do{if((c[V>>2]|0)!=0){R=c[W>>2]|0;c[S>>2]=9534384;X=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[X&16383](S,0,0)|0;if((R|0)<1){U=1;i=e;return U|0}if((gzL(T,0,0)|0)==0){break}else{U=1}i=e;return U|0}}while(0);T=(c[3531214]|0)+131072|0;if((c[3542200]|0)==0){U=1;i=e;return U|0}S=P+108|0;c[S>>2]=0;W=P+100|0;c[W>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](P,1)|0;do{if((c[S>>2]|0)!=0){P=c[W>>2]|0;c[Q>>2]=9534384;V=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[V&16383](Q,1,0)|0;if((P|0)<1){U=1;i=e;return U|0}if((gzL(T,0,1)|0)==0){break}else{U=1}i=e;return U|0}}while(0);T=(c[3531214]|0)+196608|0;if((c[3542200]|0)==0){U=1;i=e;return U|0}Q=N+108|0;c[Q>>2]=0;W=N+100|0;c[W>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](N,2)|0;do{if((c[Q>>2]|0)!=0){N=c[W>>2]|0;c[O>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](O,2,0)|0;if((N|0)<1){U=1;i=e;return U|0}if((gzL(T,0,2)|0)==0){break}else{U=1}i=e;return U|0}}while(0);T=c[3531194]|0;if((c[3542200]|0)==0){U=1;i=e;return U|0}O=L+108|0;c[O>>2]=0;W=L+100|0;c[W>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](L,3)|0;do{if((c[O>>2]|0)!=0){L=c[W>>2]|0;c[M>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](M,3,0)|0;if((L|0)<1){U=1;i=e;return U|0}if((gzL(T,0,3)|0)==0){break}else{U=1}i=e;return U|0}}while(0);T=c[3530738]|0;if((c[3542200]|0)==0){U=1;i=e;return U|0}M=J+108|0;c[M>>2]=0;W=J+100|0;c[W>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](J,4)|0;do{if((c[M>>2]|0)!=0){J=c[W>>2]|0;c[K>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](K,4,0)|0;if((J|0)<1){U=1;i=e;return U|0}if((gzL(T,0,4)|0)==0){break}else{U=1}i=e;return U|0}}while(0);T=(c[3530738]|0)+65536|0;if((c[3542200]|0)==0){U=1;i=e;return U|0}K=H+108|0;c[K>>2]=0;W=H+100|0;c[W>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](H,5)|0;do{if((c[K>>2]|0)!=0){H=c[W>>2]|0;c[I>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](I,5,0)|0;if((H|0)<1){U=1;i=e;return U|0}if((gzL(T,0,5)|0)==0){break}else{U=1}i=e;return U|0}}while(0);T=c[3530502]|0;if((c[3542200]|0)==0){U=1;i=e;return U|0}I=F+108|0;c[I>>2]=0;W=F+100|0;c[W>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](F,6)|0;do{if((c[I>>2]|0)!=0){F=c[W>>2]|0;c[G>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](G,6,0)|0;if((F|0)<1){U=1;i=e;return U|0}if((gzL(T,0,6)|0)==0){break}else{U=1}i=e;return U|0}}while(0);T=(c[3530502]|0)+65536|0;if((c[3542200]|0)==0){U=1;i=e;return U|0}G=D+108|0;c[G>>2]=0;W=D+100|0;c[W>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](D,7)|0;do{if((c[G>>2]|0)!=0){D=c[W>>2]|0;c[E>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](E,7,0)|0;if((D|0)<1){U=1;i=e;return U|0}if((gzL(T,0,7)|0)==0){break}else{U=1}i=e;return U|0}}while(0);T=(c[3530502]|0)+98304|0;if((c[3542200]|0)==0){U=1;i=e;return U|0}E=B+108|0;c[E>>2]=0;W=B+100|0;c[W>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](B,8)|0;do{if((c[E>>2]|0)!=0){B=c[W>>2]|0;c[C>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](C,8,0)|0;if((B|0)<1){U=1;i=e;return U|0}if((gzL(T,0,8)|0)==0){break}else{U=1}i=e;return U|0}}while(0);T=(c[3530502]|0)+163840|0;if((c[3542200]|0)==0){U=1;i=e;return U|0}C=z+108|0;c[C>>2]=0;W=z+100|0;c[W>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,9)|0;do{if((c[C>>2]|0)!=0){z=c[W>>2]|0;c[A>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](A,9,0)|0;if((z|0)<1){U=1;i=e;return U|0}if((gzL(T,0,9)|0)==0){break}else{U=1}i=e;return U|0}}while(0);T=(c[3530502]|0)+196608|0;if((c[3542200]|0)==0){U=1;i=e;return U|0}A=x+108|0;c[A>>2]=0;W=x+100|0;c[W>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,10)|0;do{if((c[A>>2]|0)!=0){x=c[W>>2]|0;c[y>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](y,10,0)|0;if((x|0)<1){U=1;i=e;return U|0}if((gzL(T,0,10)|0)==0){break}else{U=1}i=e;return U|0}}while(0);T=(c[3530502]|0)+262144|0;if((c[3542200]|0)==0){U=1;i=e;return U|0}y=v+108|0;c[y>>2]=0;W=v+100|0;c[W>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,11)|0;do{if((c[y>>2]|0)!=0){v=c[W>>2]|0;c[w>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](w,11,0)|0;if((v|0)<1){U=1;i=e;return U|0}if((gzL(T,0,11)|0)==0){break}else{U=1}i=e;return U|0}}while(0);T=(c[3530502]|0)+294912|0;if((c[3542200]|0)==0){U=1;i=e;return U|0}w=t+108|0;c[w>>2]=0;W=t+100|0;c[W>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,12)|0;do{if((c[w>>2]|0)!=0){t=c[W>>2]|0;c[u>>2]=9534384;y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[y&16383](u,12,0)|0;if((t|0)<1){U=1;i=e;return U|0}if((gzL(T,0,12)|0)==0){break}else{U=1}i=e;return U|0}}while(0);T=(c[3530502]|0)+360448|0;if((c[3542200]|0)==0){U=1;i=e;return U|0}u=r+108|0;c[u>>2]=0;W=r+100|0;c[W>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,13)|0;do{if((c[u>>2]|0)!=0){r=c[W>>2]|0;c[s>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](s,13,0)|0;if((r|0)<1){U=1;i=e;return U|0}if((gzL(T,0,13)|0)==0){break}else{U=1}i=e;return U|0}}while(0);T=c[3530370]|0;if((c[3542200]|0)==0){U=1;i=e;return U|0}s=p+108|0;c[s>>2]=0;W=p+100|0;c[W>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,14)|0;do{if((c[s>>2]|0)!=0){p=c[W>>2]|0;c[q>>2]=9534384;u=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[u&16383](q,14,0)|0;if((p|0)<1){U=1;i=e;return U|0}if((gzL(T,0,14)|0)==0){break}else{U=1}i=e;return U|0}}while(0);T=(c[3530370]|0)+65536|0;if((c[3542200]|0)==0){U=1;i=e;return U|0}q=n+108|0;c[q>>2]=0;W=n+100|0;c[W>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,15)|0;do{if((c[q>>2]|0)!=0){n=c[W>>2]|0;c[o>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](o,15,0)|0;if((n|0)<1){U=1;i=e;return U|0}if((gzL(T,0,15)|0)==0){break}else{U=1}i=e;return U|0}}while(0);T=(c[3530370]|0)+131072|0;if((c[3542200]|0)==0){U=1;i=e;return U|0}o=l+108|0;c[o>>2]=0;W=l+100|0;c[W>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,16)|0;do{if((c[o>>2]|0)!=0){l=c[W>>2]|0;c[m>>2]=9534384;q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[q&16383](m,16,0)|0;if((l|0)<1){U=1;i=e;return U|0}if((gzL(T,0,16)|0)==0){break}else{U=1}i=e;return U|0}}while(0);T=(c[3530370]|0)+196608|0;if((c[3542200]|0)==0){U=1;i=e;return U|0}m=j+108|0;c[m>>2]=0;W=j+100|0;c[W>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,17)|0;do{if((c[m>>2]|0)!=0){j=c[W>>2]|0;c[k>>2]=9534384;o=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[o&16383](k,17,0)|0;if((j|0)<1){U=1;i=e;return U|0}if((gzL(T,0,17)|0)==0){break}else{U=1}i=e;return U|0}}while(0);T=c[3541206]|0;if((c[3542200]|0)==0){U=1;i=e;return U|0}k=f+108|0;c[k>>2]=0;W=f+100|0;c[W>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,18)|0;do{if((c[k>>2]|0)!=0){f=c[W>>2]|0;c[g>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](g,18,0)|0;if((f|0)<1){U=1;i=e;return U|0}if((gzL(T,0,18)|0)==0){break}else{U=1}i=e;return U|0}}while(0);if((aLb()|0)!=0){U=1;i=e;return U|0}fv8();c[2388530]=9554128;T=c[2391608]|0;if((T|0)!=0){g=T;gGC(9661040,g|0,68)|0}c[2382]=0;g=c[3531214]|0;T=0;do{W=g+(T<<11)|0;c[9554144+(T<<2)>>2]=W;c[9562336+(T<<2)>>2]=W;T=T+1|0;}while(T>>>0<128);T=c[2387064]|0;c[2388672]=T;c[2389696]=T;c[2390720]=T;g=T+2048|0;c[2388673]=g;c[2389697]=g;c[2390721]=g;g=T+4096|0;c[2388674]=g;c[2389698]=g;c[2390722]=g;g=T+6144|0;c[2388675]=g;c[2389699]=g;c[2390723]=g;g=c[2387060]|0;c[2388676]=g;c[2389700]=g;c[2390724]=g;g=c[2387074]|0;c[2388736]=g;c[2389760]=g;c[2390784]=g;g=c[2387070]|0;c[2388740]=g;c[2389764]=g;c[2390788]=g;g=c[2386372]|0;c[2389112]=g;c[2390136]=g;c[2391160]=g;g=c[2387092]|0;c[2389144]=g;c[2391192]=g;g=c[3531216]|0;c[2389528]=g;c[2390552]=g;c[2391576]=g;T=g+2048|0;c[2389529]=T;c[2390553]=T;c[2391577]=T;T=g+4096|0;c[2389530]=T;c[2390554]=T;c[2391578]=T;T=g+6144|0;c[2389531]=T;c[2390555]=T;c[2391579]=T;T=g+8192|0;c[2389532]=T;c[2390556]=T;c[2391580]=T;T=g+10240|0;c[2389533]=T;c[2390557]=T;c[2391581]=T;T=g+12288|0;c[2389534]=T;c[2390558]=T;c[2391582]=T;T=g+14336|0;c[2389535]=T;c[2390559]=T;c[2391583]=T;c[2388533]=3166;c[2388532]=2724;T=c[2391608]|0;if((T|0)!=0){g=T;gGC(g|0,9661040,68)|0}c[2382]=-1;aLc();b[7057272]=256;b[7057268]=512;a[7358064]=0;g=c[642608+(c[2436]<<2)>>2]|0;T=c[g+128>>2]|0;if((c[g+52>>2]&4|0)==0){c[2113068]=T;W=c[g+132>>2]|0;c[2113070]=W;c[2443814]=T;c[2440436]=W;Y=T;Z=W}else{c[2113070]=T;W=c[g+132>>2]|0;c[2113068]=W;c[2440436]=T;c[2443814]=W;Y=W;Z=T}T=ag(Y<<1,Z)|0;Z=gGq(T)|0;c[2112926]=Z;if((Z|0)!=0){gGz(Z|0,0,T|0)}T=c[2414542]|0;gGz(T|0,0,(c[2411440]|0)-T|0);c[2388530]=9554128;T=c[2391608]|0;if((T|0)!=0){Z=T;gGC(9661040,Z|0,68)|0}c[2382]=0;Z=c[2415273]|0;gGz(9661040,0,68);c[2415273]=Z;a[9661063]=20;c[2415262]=511;Z=c[2388539]|0;do{if((Z|0)==0){T=c[2388532]|0;if((T|0)==0){_=0;$=8191;aa=9554128;break}Y=gj[T&4095](8190)|0;_=Y;$=d[9661071]<<13|8191;aa=c[2388530]|0}else{_=a[Z+2046|0]|0;$=8191;aa=9554128}}while(0);a[9661044]=_;_=c[aa+16+($>>>11<<2)>>2]|0;do{if((_|0)==0){Z=c[aa>>2]|0;if((Z|0)==0){ab=0;ac=aa;break}Y=gj[Z&4095]($)|0;ab=Y;ac=c[2388530]|0}else{ab=a[_+2047|0]|0;ac=aa}}while(0);a[9661045]=ab;a[9661075]=4;a[9661073]=0;c[2415270]=131072;c[2415275]=0;gGz(9661084,0,5);ab=c[ac+12304>>2]|0;if((ab|0)!=0){ac=ab;gGC(ac|0,9661040,68)|0}c[2382]=-1;c[3528556]=0;ac=c[2433594]|0;c[2443776]=ac;L44726:do{if((ac|0)!=0){ab=ac|0;gGC(9660952,ab|0,52)|0;switch(a[9660952]|0){case 2:{c[2309668]=638960;break L44726;break};case 0:{c[2309668]=638960;break L44726;break};case 1:{c[2309668]=634096;break L44726;break};case 3:{c[2309668]=639984;break L44726;break};case 4:{c[2309668]=7356016;break L44726;break};case 5:{c[2309668]=7354992;break L44726;break};default:{break L44726}}}}while(0);c[2113164]=c[2432850];gu[c[ac+56>>2]&16383]();ac=c[2443776]|0;if((ac|0)!=0){ab=ac|0;gGC(ab|0,9660952,52)|0}c[9731400+(c[3528556]<<2)>>2]=c[2113164];c[2443776]=0;c[3528556]=-1;c[2113156]=0;a[9628264]=0;c[2407033]=0;ab=c[3541206]|0;c[3541190]=ab;c[3541198]=ab;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=ab+256;c[3541199]=ab+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=ab+512;c[3541200]=ab+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=ab+768;c[3541201]=ab+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){ab=0;do{lN(ab);mB(ab);ab=ab+1|0;}while((ab|0)<(c[2385508]|0))}c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;lw(c[3540984]|0);a[9753256]=0;U=0;i=e;return U|0}function aK9(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1351124+(b*112|0)>>2];c[a+104>>2]=c[1351128+(b*112|0)>>2];c[a+108>>2]=c[1351132+(b*112|0)>>2];d=0;return d|0}function aLa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=1351024+(b*112|0);e=0;return e|0}function aLb(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=gGq(393216)|0;if((b|0)==0){e=1;return e|0}f=c[3530738]|0;gGC(b|0,f|0,131072)|0;g=0;do{h=g<<6;gGz(f+h|0,0,64);i=0;do{j=1<<3-i;k=(c[611416+(i<<2)>>2]|0)+h|0;l=0;do{m=k+(c[609008+(l<<2)>>2]|0)|0;n=(l<<3)+h|0;o=0;do{p=m+(c[612640+(o+8<<2)>>2]|0)|0;if(((d[b+((p|0)/8|0)|0]|0)&128>>>((p&7)>>>0)|0)!=0){p=f+(n+o)|0;a[p]=(d[p]|0|j)&255}o=o+1|0;}while((o|0)<8);l=l+1|0;}while((l|0)<8);i=i+1|0;}while((i|0)<4);g=g+1|0;}while((g|0)<4096);g=c[3530502]|0;gGC(b|0,g|0,393216)|0;f=0;do{i=f<<8;gGz(g+i|0,0,256);h=0;do{l=1<<3-h;j=(c[611184+(h<<2)>>2]|0)+i|0;k=0;do{o=j+(c[609008+(k<<2)>>2]|0)|0;n=(k<<4)+i|0;m=0;do{p=o+(c[612640+(m<<2)>>2]|0)|0;if(((d[b+((p|0)/8|0)|0]|0)&128>>>((p&7)>>>0)|0)!=0){p=g+(n+m)|0;a[p]=(d[p]|0|l)&255}m=m+1|0;}while((m|0)<16);k=k+1|0;}while((k|0)<16);h=h+1|0;}while((h|0)<4);f=f+1|0;}while((f|0)<3072);f=c[3530370]|0;gGC(b|0,f|0,262144)|0;g=0;do{h=g<<8;gGz(f+h|0,0,256);i=0;do{k=1<<3-i;l=(c[611312+(i<<2)>>2]|0)+h|0;j=0;do{m=l+(c[609008+(j<<2)>>2]|0)|0;n=(j<<4)+h|0;o=0;do{p=m+(c[612640+(o<<2)>>2]|0)|0;if(((d[b+((p|0)/8|0)|0]|0)&128>>>((p&7)>>>0)|0)!=0){p=f+(n+o)|0;a[p]=(d[p]|0|k)&255}o=o+1|0;}while((o|0)<16);j=j+1|0;}while((j|0)<16);i=i+1|0;}while((i|0)<4);g=g+1|0;}while((g|0)<2048);gGr(b);e=0;return e|0}function aLc(){var b=0,d=0,e=0,f=0,g=0,i=0;fvI();c[3528556]=0;b=c[2433594]|0;c[2443776]=b;L44808:do{if((b|0)!=0){d=b|0;gGC(9660952,d|0,52)|0;switch(a[9660952]|0){case 1:{c[2309668]=634096;break L44808;break};case 3:{c[2309668]=639984;break L44808;break};case 5:{c[2309668]=7354992;break L44808;break};case 4:{c[2309668]=7356016;break L44808;break};case 0:{c[2309668]=638960;break L44808;break};case 2:{c[2309668]=638960;break L44808;break};default:{break L44808}}}}while(0);d=c[2432850]|0;c[2113164]=d;e=c[3531204]|0;c[b+68>>2]=e;c[b+1092>>2]=e;c[b+2116>>2]=e;f=e+256|0;c[b+72>>2]=f;c[b+1096>>2]=f;c[b+2120>>2]=f;f=e+512|0;c[b+76>>2]=f;c[b+1100>>2]=f;c[b+2124>>2]=f;f=e+768|0;c[b+80>>2]=f;c[b+1104>>2]=f;c[b+2128>>2]=f;f=e+1024|0;c[b+84>>2]=f;c[b+1108>>2]=f;c[b+2132>>2]=f;f=e+1280|0;c[b+88>>2]=f;c[b+1112>>2]=f;c[b+2136>>2]=f;f=e+1536|0;c[b+92>>2]=f;c[b+1116>>2]=f;c[b+2140>>2]=f;f=e+1792|0;c[b+96>>2]=f;c[b+1120>>2]=f;c[b+2144>>2]=f;f=c[3531194]|0;e=64;g=64;while(1){i=f+(g<<8)|0;c[b+68+(g<<2)>>2]=i;c[b+68+(g+512<<2)>>2]=i;i=e+1&65535;if((i&65535)>255){break}else{e=i;g=i&65535}}c[b+3152>>2]=784;c[b+3148>>2]=1750;g=b|0;gGC(g|0,9660952,52)|0;c[2432850]=d;c[2443776]=0;c[3528556]=-1;Vr(1,15e5,0,2986,114,0);c[2438228]=7159066;c[2433526]=3406;c[2406676]=2246;c[3528472]=11080;c[2443846]=285;h[745419]=.5;a[3203368]=1;h[745418]=.9;a[3203360]=1;h[745417]=.9;a[3203352]=1;h[745416]=.9;a[3203344]=1;UL(3e6,3070,978,1);c[2438224]=15e5;c[2433522]=3258;c[2406672]=2016;c[3528468]=6844;c[2443842]=1364;h[745398]=.9;a[3203264]=1;Ux(0,7759,1);c[2407030]=218;c[2407068]=3;return}function aLd(b,e){b=b|0;e=e|0;var f=0;f=b&65535;if((f|0)==2048|(f|0)==2049){lS(0,f&1,e);return}else if((f|0)==14336){Uv(0,e);return}else if((f|0)==4096|(f|0)==4097){b=c[3540984]|0;if((f&1|0)==0){a[b+5885|0]=e;return}f=c[b+5876>>2]|0;if((f|0)!=0){gg[f&4095](c[b+5880>>2]|0,0)}lH(b,d[b+5885|0]|0,e&255);return}else{return}}function aLe(b){b=b|0;var d=0,e=0;d=b&65535;if((d|0)==12288){gg[c[(c[2443776]|0)+64>>2]&4095](32,0);e=a[c[3528206]|0]|0;return e|0}else if((d|0)==14336){e=c[2113156]&255;return e|0}else{e=0;return e|0}return 0}function aLf(a){a=a|0;var b=0,d=0;b=c[2415275]|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,7159066,0)|0;return a|0}function aLg(){return+(+(c[2415275]|0)/7159066.0)}function aLh(a,b){a=a|0;b=b|0;a=c[(c[2443776]|0)+64>>2]|0;if((b|0)==0){gg[a&4095](0,0);return}else{gg[a&4095](0,1);return}}function aLi(a){a=a|0;var b=0,d=0;b=c[2113164]|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,15e5,0)|0;return a|0}function aLj(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0;do{if((b&16252928|0)==(c[2444158]|0)){e=b&524287;if(e>>>0<32768){if((b&2|0)!=0){break}a[(c[2388006]|0)+(b>>>1&262142|b&1)|0]=d;break}f=e-65536|0;if(f>>>0<8192){if((b&2|0)!=0){break}a[(c[2386370]|0)+((f&-4|0)/2|0|b&1)|0]=d;break}f=e-131072|0;if(f>>>0<4096){if((b&2|0)!=0){break}a[(c[2387090]|0)+((f&-4|0)/2|0|b&1)|0]=d;break}f=e-262144|0;if(f>>>0<32){if((b&2|0)!=0){break}a[(c[2383434]|0)+((f&-4|0)/2|0|b&1)|0]=d;break}f=e-327680|0;if(f>>>0<8192){if((b&2|0)!=0){break}a[(c[2383430]|0)+((f&-4|0)/2|0|b&1)|0]=d;break}f=e-335872|0;if(f>>>0<8192){if((b&2|0)!=0){break}a[(c[2383430]|0)+((f&-4|0)/2|0|b&1)|0]=d;break}f=e-344064|0;if(f>>>0<8192){if((b&2|0)!=0){break}a[(c[2383431]|0)+((f&-4|0)/2|0|b&1)|0]=d;break}f=e-393216|0;if(f>>>0<8192){if((b&2|0)!=0){break}a[(c[2383428]|0)+((f&-4|0)/2|0|b&1)|0]=d;break}f=e-409600|0;if(f>>>0<8192){if((b&2|0)!=0){break}a[(c[2383426]|0)+((f&-4|0)/2|0|b&1)|0]=d;break}if((b&524284|0)!=196608){break}f=d&255;e=f&7;if((c[3530236]|0)!=(e|0)){c[3530236]=e;g=(c[3529738]|0)+1048576|0;h=(c[3529694]|0)+(e<<18)|0;gGC(g|0,h|0,262144)|0}c[2415256]=f&16;h=f>>>6&1;c[3528406]=h^1;if((h|0)==0){c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2]}Tr(f>>>5&1)}}while(0);f=b&-4;if((f|0)==(c[2444156]|0)){Uv(0,d);return}if((f|0)!=(c[2444154]|0)){return}Uv(1,d);return}function aLk(a,d){a=a|0;d=d|0;var e=0,f=0,g=0;do{if((a&16252928|0)==(c[2444158]|0)){e=a&524287;if(e>>>0<32768){b[(c[2388006]|0)+(a>>>1&262142)>>1]=d&65535;break}f=e-65536|0;if(f>>>0<8192){b[(c[2386370]|0)+((f&-4|0)/2|0)>>1]=d&65535;break}f=e-131072|0;if(f>>>0<4096){b[(c[2387090]|0)+((f&-4|0)/2|0)>>1]=d&65535;break}f=e-262144|0;if(f>>>0<32){b[(c[2383434]|0)+((f&-4|0)/2|0)>>1]=d&65535;break}f=e-327680|0;if(f>>>0<8192){b[(c[2383430]|0)+((f&-4|0)/2|0)>>1]=d&65535;break}f=e-335872|0;if(f>>>0<8192){b[(c[2383430]|0)+((f&-4|0)/2|0)>>1]=d&65535;break}f=e-344064|0;if(f>>>0<8192){b[(c[2383431]|0)+((f&-4|0)/2|0)>>1]=d&65535;break}f=e-393216|0;if(f>>>0<8192){b[(c[2383428]|0)+((f&-4|0)/2|0)>>1]=d&65535;break}f=e-409600|0;if(f>>>0<8192){b[(c[2383426]|0)+((f&-4|0)/2|0)>>1]=d&65535;break}if((e|0)!=196608){break}e=d&7;if((c[3530236]|0)!=(e|0)){c[3530236]=e;f=(c[3529738]|0)+1048576|0;g=(c[3529694]|0)+(e<<18)|0;gGC(f|0,g|0,262144)|0}c[2415256]=d&16;g=d>>>6&1;c[3528406]=g^1;if((g|0)==0){c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2]}Tr(d>>>5&1)}}while(0);if((c[2444156]|0)==(a|0)){Uv(0,d&255);return}if((c[2444154]|0)!=(a|0)){return}Uv(1,d&255);return}function aLl(b){b=b|0;var d=0,e=0,f=0;if((b&16252928|0)!=(c[2444158]|0)){d=b&-4;if((d|0)==2097152){e=-1;return e|0}if((d|0)==(c[2444156]|0)){e=c[2113156]&255;return e|0}if((d|0)!=(c[2444154]|0)){e=0;return e|0}e=c[2113157]&255;return e|0}d=b&524287;if(d>>>0<32768){if((b&2|0)!=0){e=-1;return e|0}e=a[(c[2388006]|0)+(b>>>1&262142|b&1)|0]|0;return e|0}f=d-65536|0;if(f>>>0<8192){if((b&2|0)!=0){e=-1;return e|0}e=a[(c[2386370]|0)+((f&-4|0)/2|0|b&1)|0]|0;return e|0}f=d-131072|0;if(f>>>0<4096){if((b&2|0)!=0){e=-1;return e|0}e=a[(c[2387090]|0)+((f&-4|0)/2|0|b&1)|0]|0;return e|0}f=d-262144|0;if(f>>>0<32){if((b&2|0)!=0){e=-1;return e|0}e=a[(c[2383434]|0)+((f&-4|0)/2|0|b&1)|0]|0;return e|0}f=d-327680|0;if(f>>>0<8192){if((b&2|0)!=0){e=-1;return e|0}e=a[(c[2383430]|0)+((f&-4|0)/2|0|b&1)|0]|0;return e|0}f=d-335872|0;if(f>>>0<8192){if((b&2|0)!=0){e=-1;return e|0}e=a[(c[2383430]|0)+((f&-4|0)/2|0|b&1)|0]|0;return e|0}f=d-344064|0;if(f>>>0<8192){if((b&2|0)!=0){e=-1;return e|0}e=a[(c[2383431]|0)+((f&-4|0)/2|0|b&1)|0]|0;return e|0}f=d-393216|0;if(f>>>0<8192){if((b&2|0)!=0){e=-1;return e|0}e=a[(c[2383428]|0)+((f&-4|0)/2|0|b&1)|0]|0;return e|0}f=d-409600|0;if(f>>>0>=8192){e=((d-196608|0)>>>0<4)<<31>>31;return e|0}if((b&2|0)!=0){e=-1;return e|0}e=a[(c[2383426]|0)+((f&-4|0)/2|0|b&1)|0]|0;return e|0}function aLm(a){a=a|0;var b=0,d=0,f=0;if((a&16252928|0)!=(c[2444158]|0)){if((a|0)!=2097152){if((c[2444156]|0)!=(a|0)){return((c[2444154]|0)==(a|0)?c[2113157]|0:0)|0}b=c[2113156]|0;return b|0}do{if((c[2406632]|0)==0){d=c[2443744]|0;if((d|0)<=0){f=-65280;break}c[2443744]=d-1;f=-65536}else{f=(c[2432962]|0)>>>((c[(c[2420380]|0)+4>>2]|0)>>>0)<<8&256|-65536}}while(0);b=f|(e[4774948]|0)|c[2383408];return b|0}f=a&524287;if(f>>>0<32768){b=e[(c[2388006]|0)+(a>>>1&262142)>>1]|0|-65536;return b|0}a=f-65536|0;if(a>>>0<8192){b=e[(c[2386370]|0)+((a&-4|0)/2|0)>>1]|0|-65536;return b|0}a=f-131072|0;if(a>>>0<4096){b=e[(c[2387090]|0)+((a&-4|0)/2|0)>>1]|0|-65536;return b|0}a=f-262144|0;if(a>>>0<32){b=e[(c[2383434]|0)+((a&-4|0)/2|0)>>1]|0|-65536;return b|0}a=f-327680|0;if(a>>>0<8192){b=e[(c[2383430]|0)+((a&-4|0)/2|0)>>1]|0|-65536;return b|0}a=f-335872|0;if(a>>>0<8192){b=e[(c[2383430]|0)+((a&-4|0)/2|0)>>1]|0|-65536;return b|0}a=f-344064|0;if(a>>>0<8192){b=e[(c[2383431]|0)+((a&-4|0)/2|0)>>1]|0|-65536;return b|0}a=f-393216|0;if(a>>>0<8192){b=e[(c[2383428]|0)+((a&-4|0)/2|0)>>1]|0|-65536;return b|0}a=f-409600|0;if(a>>>0<8192){b=e[(c[2383426]|0)+((a&-4|0)/2|0)>>1]|0|-65536;return b|0}if((f|0)!=196608){b=0;return b|0}b=e[4774872]|0;return b|0}function aLn(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4649900+(b*112|0)>>2];c[a+104>>2]=c[4649904+(b*112|0)>>2];c[a+108>>2]=c[4649908+(b*112|0)>>2];d=0;return d|0}function aLo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=4649800+(b*112|0);e=0;return e|0}function aLp(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1195416+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aLq(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>3){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3445960+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aLr(){return aLV(2962,5412,1,644)|0}function aLs(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;i=i+128|0;d=b|0;e=c[c[642608+(c[2436]<<2)>>2]>>2]|0;be(d|0,128,179600,(f=i,i=i+24|0,c[f>>2]=9374064,c[f+8>>2]=47,c[f+16>>2]=e,f)|0)|0;i=f;a[1040128]=0;f=c[2420380]|0;e=c[f>>2]|0;g=c[f+4>>2]|0;f=fw(d|0,389440)|0;if((f|0)!=0){d=g>>3<<e&1023;cj(14100392,d|0,1,f|0)|0;aY(f|0)|0}f=c[2406730]|0;if((f|0)!=0){gGr(f);c[2406730]=0}f=c[2406728]|0;if((f|0)!=0){gGr(f);c[2406728]=0}f=c[2406726]|0;if((f|0)!=0){gGr(f);c[2406726]=0}Uw(0);Uw(1);c[3541206]=0;c[2113070]=0;c[2113068]=0;f=c[2112926]|0;if((f|0)!=0){gGr(f);c[2112926]=0}aE2();f=c[2414838]|0;d=0;while(1){if((d|0)>=1024){h=34955;break}j=9638528+(d<<2)|0;if((c[j>>2]|0)==(f|0)){break}else{d=d+1|0}}if((h|0)==34955){c[2414838]=0;i=b;return 0}gGr(f);c[j>>2]=0;c[2414838]=0;i=b;return 0}function aLt(){var d=0,e=0,f=0;if((a[9623328]|0)!=0){aL_()}d=a[9634616]&8|7;b[4774948]=d;b[4774872]=-1;e=0;f=d;d=-1;do{f=((a[9632272+e|0]&1)<<e^f&65535)&65535;d=((a[9630184+e|0]&1)<<e^d&65535)&65535;e=e+1|0;}while((e|0)<16);b[4774948]=f;b[4774872]=d;c[2383408]=240;fyL(480518)|0;fx6();c[2383408]=0;fyL(2240)|0;d=c[2112964]|0;if((d|0)!=0){f=a[9688]|0;gGz(d|0,0,(f?2136:0)|0);e=f?534:0;Uu(0,d,e);Uu(1,d,e)}if((c[2112968]|0)==0){return 0}aLu()|0;return 0}function aLu(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;a=c[2387090]|0;d=c[3529876]|0;f=0;do{g=e[a+(f<<1)>>1]|0;h=g>>>5&31;c[d+(f<<2)>>2]=g>>>10&31|g<<11&63488|(h<<3|h>>>2)<<3&2016;f=f+1|0;}while((f|0)<1024);aE3();gGz(c[2383420]|0,0,131072);gGz(c[2383410]|0,0,131072);f=ag(c[2113070]|0,c[2113068]|0)|0;d=c[2112926]|0;if((f|0)>0){a=0;do{b[d+(a<<1)>>1]=256;a=a+1|0;}while((a|0)<(f|0))}aE0(1,d,2);aE0(0,d,4);f=c[2386370]|0;a=c[3530368]|0;h=(c[2113222]&1|0)==0;g=1276;do{i=e[f+(g<<1)>>1]|0;do{if((i&4096|0)==0|h){j=e[f+((g|1)<<1)>>1]|0;k=e[f+((g|2)<<1)>>1]|0;l=k>>>9;m=k&49152;n=i&16384;o=1<<(i>>>9&3);p=o-1|0;if((m|0)==32768|(m|0)==49152){q=252}else if((m|0)==16384){q=240}else if((m|0)==0){q=0}else{q=m}m=k&511;r=i&511;s=m>>>0>319?k|-512:m;m=r>>>0>255?i|-512:r;if((304-s|0)>320){break}r=(n>>>13^2)-1|0;k=(j&-o)+((n|0)==0?p:0)|0;j=i>>>13&1^1;t=n>>>14^1;if((o|0)<=0){break}o=l<<4&496|512;l=p;while(1){aEY(d,a,k-(ag(l,r)|0)|0,o,s,(l<<4)+m|0,j,t,q,-1);if((l|0)>0){l=l-1|0}else{break}}}}while(0);g=g-4|0;}while((g|0)>-1);R8(c[3529876]|0);return 0}function aLv(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=i;i=i+64|0;e=d|0;f=d+16|0;g=d+32|0;h=d+48|0;if((b|0)!=0){c[b>>2]=169762}if((a&32|0)!=0){gGz(h|0,0,12);b=c[2414540]|0;c[h>>2]=b;c[h+4>>2]=(c[2411438]|0)-b;c[h+12>>2]=162152;b=c[2076592]|0;gj[b&4095](h)|0}if((a&64|0)==0){i=d;return 0}if((a&96|0)!=0){gGz(f|0,0,12);c[f>>2]=9705864;c[f+4>>2]=184;c[f+12>>2]=164440;h=c[2076592]|0;gj[h&4095](f)|0;gGz(e|0,0,12);c[e>>2]=14115384;c[e+4>>2]=4;c[e+12>>2]=501256;f=c[2076592]|0;gj[f&4095](e)|0}Ut(0);Ut(1);aE6();gGz(g|0,0,12);c[g>>2]=14120944;c[g+4>>2]=4;c[g+12>>2]=491248;gj[c[2076592]&4095](g)|0;if((a&2|0)==0){i=d;return 0}a=c[3530236]&7;c[3530236]=a;g=(c[3529738]|0)+1048576|0;e=(c[3529694]|0)+(a<<18)|0;gGC(g|0,e|0,262144)|0;i=d;return 0}function aLw(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>5){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2740420+(b*112|0)>>2];c[a+104>>2]=c[2740424+(b*112|0)>>2];c[a+108>>2]=c[2740428+(b*112|0)>>2];d=0;return d|0}function aLx(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<6&(d|0)==0)){e=1;return e|0}c[a>>2]=2740320+(b*112|0);e=0;return e|0}function aLy(){return aLV(8404,5412,1,644)|0}function aLz(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3022900+(b*112|0)>>2];c[a+104>>2]=c[3022904+(b*112|0)>>2];c[a+108>>2]=c[3022908+(b*112|0)>>2];d=0;return d|0}function aLA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=3022800+(b*112|0);e=0;return e|0}function aLB(){return aLV(8750,12946,1,724)|0}function aLC(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4564748+(b*112|0)>>2];c[a+104>>2]=c[4564752+(b*112|0)>>2];c[a+108>>2]=c[4564756+(b*112|0)>>2];d=0;return d|0}function aLD(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=4564648+(b*112|0);e=0;return e|0}function aLE(){return aLV(16030,11972,1,724)|0}function aLF(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2629036+(b*112|0)>>2];c[a+104>>2]=c[2629040+(b*112|0)>>2];c[a+108>>2]=c[2629044+(b*112|0)>>2];d=0;return d|0}function aLG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=2628936+(b*112|0);e=0;return e|0}function aLH(){return aLV(16030,7076,1,724)|0}function aLI(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>5){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3020884+(b*112|0)>>2];c[a+104>>2]=c[3020888+(b*112|0)>>2];c[a+108>>2]=c[3020892+(b*112|0)>>2];d=0;return d|0}function aLJ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<6&(d|0)==0)){e=1;return e|0}c[a>>2]=3020784+(b*112|0);e=0;return e|0}function aLK(){return aLV(14744,10290,2,51400)|0}function aLL(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2432340+(b*112|0)>>2];c[a+104>>2]=c[2432344+(b*112|0)>>2];c[a+108>>2]=c[2432348+(b*112|0)>>2];d=0;return d|0}function aLM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=2432240+(b*112|0);e=0;return e|0}function aLN(){return aLV(14890,10290,2,1264)|0}function aLO(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2840716+(b*112|0)>>2];c[a+104>>2]=c[2840720+(b*112|0)>>2];c[a+108>>2]=c[2840724+(b*112|0)>>2];d=0;return d|0}function aLP(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=2840616+(b*112|0);e=0;return e|0}function aLQ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6507964+(b*112|0)>>2];c[a+104>>2]=c[6507968+(b*112|0)>>2];c[a+108>>2]=c[6507972+(b*112|0)>>2];d=0;return d|0}function aLR(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=6507864+(b*112|0);e=0;return e|0}function aLS(){return aLV(14890,10290,2,22900)|0}function aLT(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3035076+(b*112|0)>>2];c[a+104>>2]=c[3035080+(b*112|0)>>2];c[a+108>>2]=c[3035084+(b*112|0)>>2];d=0;return d|0}function aLU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=3034976+(b*112|0);e=0;return e|0}function aLV(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;g=i;i=i+16|0;h=g|0;j=g+8|0;c[2424]=5800;k=c[2414838]|0;c[2388002]=k;c[3530736]=k+524288;c[3530500]=k+4718592;c[3530368]=k+8912896;l=k+25690112|0;c[3541206]=l;c[3529738]=l;c[3529694]=k+27262976;c[3529876]=k+29360128;c[2387862]=k+29364224;l=k+29364352|0;c[2414540]=l;c[2388006]=l;c[2386354]=k+29380736;c[2387090]=k+29388928;c[2386370]=k+29393024;l=k+29397120|0;c[2411438]=l;c[2413978]=l;k=l;l=0;while(1){if((l|0)>=1024){break}m=9638528+(l<<2)|0;if((c[m>>2]|0)==0){n=35115;break}else{l=l+1|0}}do{if((n|0)==35115){l=gGq(k)|0;c[m>>2]=l;if((l|0)==0){break}gGz(l|0,0,k|0);c[2414838]=l;gGz(l|0,0,k|0);c[2388002]=l;c[3530736]=l+524288;c[3530500]=l+4718592;c[3530368]=l+8912896;o=l+25690112|0;c[3541206]=o;c[3529738]=o;c[3529694]=l+27262976;c[3529876]=l+29360128;c[2387862]=l+29364224;o=l+29364352|0;c[2414540]=o;c[2388006]=o;c[2386354]=l+29380736;c[2387090]=l+29388928;c[2386370]=l+29393024;o=l+29397120|0;c[2411438]=o;c[2413978]=o;L45328:do{if((b|0)!=0){if((gA[b&16383](h,j)|0)!=0){p=1;i=g;return p|0}aFj(c[2388002]|0,524288);aFg(c[3530736]|0,c[h>>2]|0,1574056,720536,1110256);aE_(c[3530736]|0,c[3530500]|0,c[h>>2]|0,0);o=c[3530736]|0;aE_(o,o,c[h>>2]|0,1);aE$(c[3530368]|0,c[j>>2]|0);o=0;while(1){if((o|0)>=1024){q=0;break}r=9638528+(o<<2)|0;if((c[r>>2]|0)==0){n=35122;break}else{o=o+1|0}}do{if((n|0)==35122){o=gGq(2097152)|0;c[r>>2]=o;if((o|0)==0){q=0;break}gGz(o|0,0,2097152);q=o}}while(0);o=c[3529694]|0;l=0;do{a[q+(l<<20&1048576|l>>1)|0]=a[o+l|0]|0;l=l+1|0;}while((l|0)<2097152);gGC(o|0,q|0,2097152)|0;l=0;while(1){if((l|0)>=1024){break L45328}s=9638528+(l<<2)|0;if((c[s>>2]|0)==(q|0)){break}else{l=l+1|0}}gGr(q);c[s>>2]=0}}while(0);if((d|0)!=0){gu[d&16383]()}c[3542218]=(f|0)!=0?f:-1;c[2427230]=11726;Tq(689536);Ux(0,7627,1);Ux(1,15255/(e|0)|0,1);c[2407030]=154;c[2407068]=3;c[2407069]=51;c[2407107]=3;aE1(1,0,1);c[2429436]=826;c[2429437]=826;l=c[h>>2]<<1;o=c[3530500]|0;c[2383440]=c[3530736];c[2383441]=o;c[2383442]=0;o=((l|0)/64|0)-1|0;t=1;while(1){if((t|0)<(o|0)){t=t<<1}else{break}}c[2383436]=t-1;o=((l|0)/256|0)-1|0;u=1;while(1){if((u|0)<(o|0)){u=u<<1}else{break}}c[2383437]=u-1;c[2383438]=0;a[690376]=1;o=c[642608+(c[2436]<<2)>>2]|0;l=c[o+128>>2]|0;if((c[o+52>>2]&4|0)==0){c[2113068]=l;t=c[o+132>>2]|0;c[2113070]=t;c[2443814]=l;c[2440436]=t;v=l;w=t}else{c[2113070]=l;t=c[o+132>>2]|0;c[2113068]=t;c[2440436]=l;c[2443814]=t;v=t;w=l}l=ag(v<<1,w)|0;t=gGq(l)|0;c[2112926]=t;if((t|0)!=0){gGz(t|0,0,l|0)}aL_();p=0;i=g;return p|0}}while(0);c[2414838]=0;p=1;i=g;return p|0}function aLW(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=i;i=i+600|0;f=e|0;g=e+112|0;h=e+120|0;j=e+232|0;k=e+240|0;l=e+352|0;m=e+360|0;n=e+472|0;o=e+480|0;p=e+592|0;q=c[2388002]|0;if((c[3542200]|0)==0){r=1;i=e;return r|0}s=o+108|0;c[s>>2]=0;t=o+100|0;c[t>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](o,0)|0;do{if((c[s>>2]|0)!=0){o=c[t>>2]|0;c[p>>2]=9534384;u=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[u&16383](p,0,0)|0;if((o|0)<1){r=1;i=e;return r|0}if((gzL(q,0,0)|0)==0){break}else{r=1}i=e;return r|0}}while(0);q=c[3530736]|0;if((c[3542200]|0)==0){r=1;i=e;return r|0}p=m+108|0;c[p>>2]=0;t=m+100|0;c[t>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,1)|0;do{if((c[p>>2]|0)!=0){m=c[t>>2]|0;c[n>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](n,1,0)|0;if((m|0)<1){r=1;i=e;return r|0}if((gzL(q,0,1)|0)==0){break}else{r=1}i=e;return r|0}}while(0);q=c[3530736]|0;n=0;do{t=q+(n+524288)|0;p=a[t]|0;m=q+(n+1048576)|0;a[t]=a[m]|0;a[m]=p;n=n+1|0;}while((n|0)<524288);if((R6((c[3530368]|0)+1|0,2,2)|0)!=0){r=1;i=e;return r|0}if((R6(c[3530368]|0,3,2)|0)!=0){r=1;i=e;return r|0}if((R6((c[3530368]|0)+4194305|0,4,2)|0)!=0){r=1;i=e;return r|0}if((R6((c[3530368]|0)+4194304|0,5,2)|0)!=0){r=1;i=e;return r|0}n=c[3529738]|0;if((c[3542200]|0)==0){r=1;i=e;return r|0}q=k+108|0;c[q>>2]=0;p=k+100|0;c[p>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,6)|0;do{if((c[q>>2]|0)!=0){k=c[p>>2]|0;c[l>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](l,6,0)|0;if((k|0)<1){r=1;i=e;return r|0}if((gzL(n,0,6)|0)==0){break}else{r=1}i=e;return r|0}}while(0);n=c[3529694]|0;if((c[3542200]|0)==0){r=1;i=e;return r|0}l=h+108|0;c[l>>2]=0;p=h+100|0;c[p>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](h,7)|0;do{if((c[l>>2]|0)!=0){h=c[p>>2]|0;c[j>>2]=9534384;q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[q&16383](j,7,0)|0;if((h|0)<1){r=1;i=e;return r|0}if((gzL(n,0,7)|0)==0){break}else{r=1}i=e;return r|0}}while(0);n=c[2387862]|0;if((c[3542200]|0)==0){r=1;i=e;return r|0}j=f+108|0;c[j>>2]=0;p=f+100|0;c[p>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,8)|0;do{if((c[j>>2]|0)!=0){f=c[p>>2]|0;c[g>>2]=9534384;l=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[l&16383](g,8,0)|0;if((f|0)<1){r=1;i=e;return r|0}if((gzL(n,0,8)|0)==0){break}else{r=1}i=e;return r|0}}while(0);c[b>>2]=2097152;c[d>>2]=8388608;r=0;i=e;return r|0}function aLX(){var a=0,b=0,d=0,e=0,f=0,g=0;c[2444158]=1572864;c[2444156]=1048576;c[2444154]=1310720;a=gGq(65536)|0;c[2406730]=a;gGz(a|0,0,65536);a=gGq(65536)|0;c[2406728]=a;gGz(a|0,0,65536);a=gGq(65536)|0;b=a;c[2406726]=b;gGz(a|0,0,65536);c[2430386]=0;c[2430390]=0;c[2432800]=0;c[2432804]=0;d=c[2427044]|0;c[9681616+(d<<3)>>2]=1314928;c[9681620+(d<<3)>>2]=0;c[2427044]=d+1;c[2427230]=0;c[3542218]=-1;d=c[2388002]|0;e=c[2406730]|0;f=0;do{g=d+(f<<12)|0;c[e+(f<<2)>>2]=g;c[b+(f<<2)>>2]=g;f=f+1|0;}while(f>>>0<128);f=c[2386354]|0;c[e+2052>>2]=f;c[(c[2406728]|0)+2052>>2]=f;c[a+2052>>2]=f;c[2430390]=2738;c[2430386]=1356;c[2432804]=2910;c[2432800]=1418;return}function aLY(){var a=0;a=c[3528846]|0;c[3528846]=(a|0)>1120?a-1120|0:0;return}function aLZ(a){a=a|0;return a>>>4<<12&28672|0}function aL_(){var d=0,e=0,f=0,g=0,h=0;d=c[2414540]|0;gGz(d|0,0,(c[2411438]|0)-d|0);gGz(9705864,0,184);c[2426481]=201326595;c[2113156]=0;a[9628264]=0;c[2407033]=0;d=c[3541206]|0;c[3541190]=d;c[3541198]=d;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=d+256;c[3541199]=d+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=d+512;c[3541200]=d+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=d+768;c[3541201]=d+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2113157]=0;a[9628420]=0;c[2407072]=0;e=d+1048576|0;c[3541194]=e;c[3541202]=e;gGz(c[2430122]|0,0,16384);c[2407080]=4;c[3541195]=d+1048832;c[3541203]=d+1114112;gGz(c[2430123]|0,0,16384);c[2407088]=4;c[3541196]=d+1049088;c[3541204]=d+1179648;gGz(c[2430124]|0,0,16384);c[2407096]=4;c[3541197]=d+1049344;c[3541205]=d+1245184;gGz(c[2430125]|0,0,16384);c[2407104]=4;c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];if(!(a[1040128]|0)){d=c[2387862]|0;gGC(14100392,d|0,128)|0}gGz(c[2383428]|0,0,4096);gGz(c[2383426]|0,0,4096);d=c[2383424]|0;if((d|0)!=0){gGz(d|0,0,4096);gGz(c[2383422]|0,0,4096)}gGz(c[2383434]|0,0,16);gGz(c[2383435]|0,0,16);gGz(c[2383430]|0,0,8192);gGz(c[2383431]|0,0,8192);d=c[2383432]|0;if((d|0)==0){b[4766836]=0;c[2426968]=0;c[3528794]=0;c[1765522]=65535;c[2429656]=0;c[2427042]=0;c[2429386]=0;c[2429384]=0;c[2429382]=0;c[3530236]=0;f=c[3529738]|0;g=f+1048576|0;h=c[3529694]|0;gGC(g|0,h|0,262144)|0;return}gGz(d|0,0,8192);gGz(c[2383433]|0,0,8192);b[4766836]=0;c[2426968]=0;c[3528794]=0;c[1765522]=65535;c[2429656]=0;c[2427042]=0;c[2429386]=0;c[2429384]=0;c[2429382]=0;c[3530236]=0;f=c[3529738]|0;g=f+1048576|0;h=c[3529694]|0;gGC(g|0,h|0,262144)|0;return}function aL$(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=i;i=i+480|0;f=e|0;g=e+112|0;h=e+120|0;j=e+232|0;k=e+240|0;l=e+352|0;m=e+360|0;n=e+472|0;o=c[2388002]|0;if((c[3542200]|0)==0){p=1;i=e;return p|0}q=m+108|0;c[q>>2]=0;r=m+100|0;c[r>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,0)|0;do{if((c[q>>2]|0)!=0){m=c[r>>2]|0;c[n>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](n,0,0)|0;if((m|0)<1){p=1;i=e;return p|0}if((gzL(o,0,0)|0)==0){break}else{p=1}i=e;return p|0}}while(0);o=c[3530736]|0;if((c[3542200]|0)==0){p=1;i=e;return p|0}n=k+108|0;c[n>>2]=0;r=k+100|0;c[r>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,1)|0;do{if((c[n>>2]|0)!=0){k=c[r>>2]|0;c[l>>2]=9534384;q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[q&16383](l,1,0)|0;if((k|0)<1){p=1;i=e;return p|0}if((gzL(o,0,1)|0)==0){break}else{p=1}i=e;return p|0}}while(0);o=c[3530736]|0;l=0;do{r=o+(l+524288)|0;n=a[r]|0;k=o+(l+1048576)|0;a[r]=a[k]|0;a[k]=n;l=l+1|0;}while((l|0)<524288);if((R6((c[3530368]|0)+1|0,2,2)|0)!=0){p=1;i=e;return p|0}if((R6(c[3530368]|0,3,2)|0)!=0){p=1;i=e;return p|0}l=c[3529738]|0;if((c[3542200]|0)==0){p=1;i=e;return p|0}o=h+108|0;c[o>>2]=0;n=h+100|0;c[n>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](h,4)|0;do{if((c[o>>2]|0)!=0){h=c[n>>2]|0;c[j>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](j,4,0)|0;if((h|0)<1){p=1;i=e;return p|0}if((gzL(l,0,4)|0)==0){break}else{p=1}i=e;return p|0}}while(0);l=c[3529694]|0;if((c[3542200]|0)==0){p=1;i=e;return p|0}j=f+108|0;c[j>>2]=0;n=f+100|0;c[n>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,5)|0;do{if((c[j>>2]|0)!=0){f=c[n>>2]|0;c[g>>2]=9534384;o=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[o&16383](g,5,0)|0;if((f|0)<1){p=1;i=e;return p|0}if((gzL(l,0,5)|0)==0){break}else{p=1}i=e;return p|0}}while(0);c[b>>2]=2097152;c[d>>2]=2097152;p=0;i=e;return p|0}function aL0(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=i;i=i+600|0;e=d|0;f=d+112|0;g=d+120|0;h=d+232|0;j=d+240|0;k=d+352|0;l=d+360|0;m=d+472|0;n=d+480|0;o=d+592|0;p=c[2388002]|0;if((c[3542200]|0)==0){q=1;i=d;return q|0}r=n+108|0;c[r>>2]=0;s=n+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,0)|0;do{if((c[r>>2]|0)!=0){n=c[s>>2]|0;c[o>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](o,0,0)|0;if((n|0)<1){q=1;i=d;return q|0}if((gzL(p,0,0)|0)==0){break}else{q=1}i=d;return q|0}}while(0);p=c[3530736]|0;if((c[3542200]|0)==0){q=1;i=d;return q|0}o=l+108|0;c[o>>2]=0;s=l+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,1)|0;do{if((c[o>>2]|0)!=0){l=c[s>>2]|0;c[m>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](m,1,0)|0;if((l|0)<1){q=1;i=d;return q|0}if((gzL(p,0,1)|0)==0){break}else{q=1}i=d;return q|0}}while(0);if((R6((c[3530368]|0)+1|0,2,2)|0)!=0){q=1;i=d;return q|0}if((R6(c[3530368]|0,3,2)|0)!=0){q=1;i=d;return q|0}p=c[3529738]|0;if((c[3542200]|0)==0){q=1;i=d;return q|0}m=j+108|0;c[m>>2]=0;s=j+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,4)|0;do{if((c[m>>2]|0)!=0){j=c[s>>2]|0;c[k>>2]=9534384;o=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[o&16383](k,4,0)|0;if((j|0)<1){q=1;i=d;return q|0}if((gzL(p,0,4)|0)==0){break}else{q=1}i=d;return q|0}}while(0);p=c[3529694]|0;if((c[3542200]|0)==0){q=1;i=d;return q|0}k=g+108|0;c[k>>2]=0;s=g+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,5)|0;do{if((c[k>>2]|0)!=0){g=c[s>>2]|0;c[h>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](h,5,0)|0;if((g|0)<1){q=1;i=d;return q|0}if((gzL(p,0,5)|0)==0){break}else{q=1}i=d;return q|0}}while(0);p=c[2387862]|0;if((c[3542200]|0)==0){q=1;i=d;return q|0}h=e+108|0;c[h>>2]=0;s=e+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,6)|0;do{if((c[h>>2]|0)!=0){e=c[s>>2]|0;c[f>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](f,6,0)|0;if((e|0)<1){q=1;i=d;return q|0}if((gzL(p,0,6)|0)==0){break}else{q=1}i=d;return q|0}}while(0);c[a>>2]=1048576;c[b>>2]=2097152;q=0;i=d;return q|0}function aL1(){var a=0,b=0,d=0,e=0,f=0,g=0;c[2444158]=6815744;c[2444156]=7864320;c[2444154]=4980736;a=gGq(65536)|0;c[2406730]=a;gGz(a|0,0,65536);a=gGq(65536)|0;c[2406728]=a;gGz(a|0,0,65536);a=gGq(65536)|0;b=a;c[2406726]=b;gGz(a|0,0,65536);c[2430386]=0;c[2430390]=0;c[2432800]=0;c[2432804]=0;d=c[2427044]|0;c[9681616+(d<<3)>>2]=1314928;c[9681620+(d<<3)>>2]=0;c[2427044]=d+1;c[2427230]=0;c[3542218]=-1;d=c[2388002]|0;e=c[2406730]|0;f=0;do{g=d+(f<<12)|0;c[e+(f<<2)>>2]=g;c[b+(f<<2)>>2]=g;f=f+1|0;}while(f>>>0<128);f=c[2386354]|0;c[e+2052>>2]=f;c[(c[2406728]|0)+2052>>2]=f;c[a+2052>>2]=f;c[2430390]=2738;c[2430386]=1356;c[2432804]=2910;c[2432800]=1418;return}function aL2(){var a=0,b=0,d=0,e=0,f=0,g=0;c[2444158]=3670016;c[2444156]=4194304;c[2444154]=3407872;a=gGq(65536)|0;c[2406730]=a;gGz(a|0,0,65536);a=gGq(65536)|0;c[2406728]=a;gGz(a|0,0,65536);a=gGq(65536)|0;b=a;c[2406726]=b;gGz(a|0,0,65536);c[2430386]=0;c[2430390]=0;c[2432800]=0;c[2432804]=0;d=c[2427044]|0;c[9681616+(d<<3)>>2]=1314928;c[9681620+(d<<3)>>2]=0;c[2427044]=d+1;c[2427230]=0;c[3542218]=-1;d=c[2388002]|0;e=c[2406730]|0;f=0;do{g=d+(f<<12)|0;c[e+(f<<2)>>2]=g;c[b+(f<<2)>>2]=g;f=f+1|0;}while(f>>>0<128);f=c[2386354]|0;c[e+2052>>2]=f;c[(c[2406728]|0)+2052>>2]=f;c[a+2052>>2]=f;c[2430390]=2738;c[2430386]=1356;c[2432804]=2910;c[2432800]=1418;return}function aL3(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=i;i=i+600|0;e=d|0;f=d+112|0;g=d+120|0;h=d+232|0;j=d+240|0;k=d+352|0;l=d+360|0;m=d+472|0;n=d+480|0;o=d+592|0;p=c[2388002]|0;if((c[3542200]|0)==0){q=1;i=d;return q|0}r=n+108|0;c[r>>2]=0;s=n+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,0)|0;do{if((c[r>>2]|0)!=0){n=c[s>>2]|0;c[o>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](o,0,0)|0;if((n|0)<1){q=1;i=d;return q|0}if((gzL(p,0,0)|0)==0){break}else{q=1}i=d;return q|0}}while(0);p=c[3530736]|0;if((c[3542200]|0)==0){q=1;i=d;return q|0}o=l+108|0;c[o>>2]=0;s=l+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,1)|0;do{if((c[o>>2]|0)!=0){l=c[s>>2]|0;c[m>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](m,1,0)|0;if((l|0)<1){q=1;i=d;return q|0}if((gzL(p,0,1)|0)==0){break}else{q=1}i=d;return q|0}}while(0);if((R6(c[3530368]|0,2,4)|0)!=0){q=1;i=d;return q|0}if((R6((c[3530368]|0)+2|0,3,4)|0)!=0){q=1;i=d;return q|0}if((R6((c[3530368]|0)+1|0,4,4)|0)!=0){q=1;i=d;return q|0}if((R6((c[3530368]|0)+3|0,5,4)|0)!=0){q=1;i=d;return q|0}p=c[3529738]|0;if((c[3542200]|0)==0){q=1;i=d;return q|0}m=j+108|0;c[m>>2]=0;s=j+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,6)|0;do{if((c[m>>2]|0)!=0){j=c[s>>2]|0;c[k>>2]=9534384;o=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[o&16383](k,6,0)|0;if((j|0)<1){q=1;i=d;return q|0}if((gzL(p,0,6)|0)==0){break}else{q=1}i=d;return q|0}}while(0);p=c[3529694]|0;if((c[3542200]|0)==0){q=1;i=d;return q|0}k=g+108|0;c[k>>2]=0;s=g+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,7)|0;do{if((c[k>>2]|0)!=0){g=c[s>>2]|0;c[h>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](h,7,0)|0;if((g|0)<1){q=1;i=d;return q|0}if((gzL(p,0,7)|0)==0){break}else{q=1}i=d;return q|0}}while(0);p=c[2387862]|0;if((c[3542200]|0)==0){q=1;i=d;return q|0}h=e+108|0;c[h>>2]=0;s=e+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,8)|0;do{if((c[h>>2]|0)!=0){e=c[s>>2]|0;c[f>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](f,8,0)|0;if((e|0)<1){q=1;i=d;return q|0}if((gzL(p,0,8)|0)==0){break}else{q=1}i=d;return q|0}}while(0);c[a>>2]=1048576;c[b>>2]=2097152;q=0;i=d;return q|0}function aL4(){var a=0,b=0,d=0,e=0,f=0,g=0;c[2444158]=4194304;c[2444156]=4718592;c[2444154]=3932160;a=gGq(65536)|0;c[2406730]=a;gGz(a|0,0,65536);a=gGq(65536)|0;c[2406728]=a;gGz(a|0,0,65536);a=gGq(65536)|0;b=a;c[2406726]=b;gGz(a|0,0,65536);c[2430386]=0;c[2430390]=0;c[2432800]=0;c[2432804]=0;d=c[2427044]|0;c[9681616+(d<<3)>>2]=1314928;c[9681620+(d<<3)>>2]=0;c[2427044]=d+1;c[2427230]=0;c[3542218]=-1;d=c[2388002]|0;e=c[2406730]|0;f=0;do{g=d+(f<<12)|0;c[e+(f<<2)>>2]=g;c[b+(f<<2)>>2]=g;f=f+1|0;}while(f>>>0<128);f=c[2386354]|0;c[e+2052>>2]=f;c[(c[2406728]|0)+2052>>2]=f;c[a+2052>>2]=f;c[2430390]=2738;c[2430386]=1356;c[2432804]=2910;c[2432800]=1418;return}function aL5(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=i;i=i+480|0;e=d|0;f=d+112|0;g=d+120|0;h=d+232|0;j=d+240|0;k=d+352|0;l=d+360|0;m=d+472|0;n=c[2388002]|0;if((c[3542200]|0)==0){o=1;i=d;return o|0}p=l+108|0;c[p>>2]=0;q=l+100|0;c[q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,0)|0;do{if((c[p>>2]|0)!=0){l=c[q>>2]|0;c[m>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](m,0,0)|0;if((l|0)<1){o=1;i=d;return o|0}if((gzL(n,0,0)|0)==0){break}else{o=1}i=d;return o|0}}while(0);n=c[3530736]|0;if((c[3542200]|0)==0){o=1;i=d;return o|0}m=j+108|0;c[m>>2]=0;q=j+100|0;c[q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,1)|0;do{if((c[m>>2]|0)!=0){j=c[q>>2]|0;c[k>>2]=9534384;p=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[p&16383](k,1,0)|0;if((j|0)<1){o=1;i=d;return o|0}if((gzL(n,0,1)|0)==0){break}else{o=1}i=d;return o|0}}while(0);if((R6((c[3530368]|0)+1|0,2,2)|0)!=0){o=1;i=d;return o|0}if((R6(c[3530368]|0,3,2)|0)!=0){o=1;i=d;return o|0}n=c[3529738]|0;if((c[3542200]|0)==0){o=1;i=d;return o|0}k=g+108|0;c[k>>2]=0;q=g+100|0;c[q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,4)|0;do{if((c[k>>2]|0)!=0){g=c[q>>2]|0;c[h>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](h,4,0)|0;if((g|0)<1){o=1;i=d;return o|0}if((gzL(n,0,4)|0)==0){break}else{o=1}i=d;return o|0}}while(0);n=c[3529694]|0;if((c[3542200]|0)==0){o=1;i=d;return o|0}h=e+108|0;c[h>>2]=0;q=e+100|0;c[q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,5)|0;do{if((c[h>>2]|0)!=0){e=c[q>>2]|0;c[f>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](f,5,0)|0;if((e|0)<1){o=1;i=d;return o|0}if((gzL(n,0,5)|0)==0){break}else{o=1}i=d;return o|0}}while(0);c[a>>2]=1048576;c[b>>2]=2097152;o=0;i=d;return o|0}function aL6(){var a=0,b=0,d=0,e=0,f=0,g=0;c[2444158]=1048576;c[2444156]=1572864;c[2444154]=1835008;a=gGq(65536)|0;c[2406730]=a;gGz(a|0,0,65536);a=gGq(65536)|0;c[2406728]=a;gGz(a|0,0,65536);a=gGq(65536)|0;b=a;c[2406726]=b;gGz(a|0,0,65536);c[2430386]=0;c[2430390]=0;c[2432800]=0;c[2432804]=0;d=c[2427044]|0;c[9681616+(d<<3)>>2]=1314928;c[9681620+(d<<3)>>2]=0;c[2427044]=d+1;c[2427230]=0;c[3542218]=-1;d=c[2388002]|0;e=c[2406730]|0;f=0;do{g=d+(f<<12)|0;c[e+(f<<2)>>2]=g;c[b+(f<<2)>>2]=g;f=f+1|0;}while(f>>>0<128);f=c[2386354]|0;c[e+2052>>2]=f;c[(c[2406728]|0)+2052>>2]=f;c[a+2052>>2]=f;c[2430390]=2738;c[2430386]=1356;c[2432804]=2910;c[2432800]=1418;return}function aL7(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=i;i=i+600|0;e=d|0;f=d+112|0;g=d+120|0;h=d+232|0;j=d+240|0;k=d+352|0;l=d+360|0;m=d+472|0;n=d+480|0;o=d+592|0;p=c[2388002]|0;if((c[3542200]|0)==0){q=1;i=d;return q|0}r=n+108|0;c[r>>2]=0;s=n+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,0)|0;do{if((c[r>>2]|0)!=0){n=c[s>>2]|0;c[o>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](o,0,0)|0;if((n|0)<1){q=1;i=d;return q|0}if((gzL(p,0,0)|0)==0){break}else{q=1}i=d;return q|0}}while(0);p=c[3530736]|0;if((c[3542200]|0)==0){q=1;i=d;return q|0}o=l+108|0;c[o>>2]=0;s=l+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,1)|0;do{if((c[o>>2]|0)!=0){l=c[s>>2]|0;c[m>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](m,1,0)|0;if((l|0)<1){q=1;i=d;return q|0}if((gzL(p,0,1)|0)==0){break}else{q=1}i=d;return q|0}}while(0);p=(c[3530736]|0)+524288|0;if((c[3542200]|0)==0){q=1;i=d;return q|0}m=j+108|0;c[m>>2]=0;s=j+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,2)|0;do{if((c[m>>2]|0)!=0){j=c[s>>2]|0;c[k>>2]=9534384;o=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[o&16383](k,2,0)|0;if((j|0)<1){q=1;i=d;return q|0}if((gzL(p,0,2)|0)==0){break}else{q=1}i=d;return q|0}}while(0);if((R6((c[3530368]|0)+1|0,3,2)|0)!=0){q=1;i=d;return q|0}if((R6(c[3530368]|0,4,2)|0)!=0){q=1;i=d;return q|0}p=c[3529738]|0;if((c[3542200]|0)==0){q=1;i=d;return q|0}k=g+108|0;c[k>>2]=0;s=g+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,5)|0;do{if((c[k>>2]|0)!=0){g=c[s>>2]|0;c[h>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](h,5,0)|0;if((g|0)<1){q=1;i=d;return q|0}if((gzL(p,0,5)|0)==0){break}else{q=1}i=d;return q|0}}while(0);p=c[3529694]|0;if((c[3542200]|0)==0){q=1;i=d;return q|0}h=e+108|0;c[h>>2]=0;s=e+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,6)|0;do{if((c[h>>2]|0)!=0){e=c[s>>2]|0;c[f>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](f,6,0)|0;if((e|0)<1){q=1;i=d;return q|0}if((gzL(p,0,6)|0)==0){break}else{q=1}i=d;return q|0}}while(0);c[a>>2]=1048576;c[b>>2]=2097152;q=0;i=d;return q|0}function aL8(d,e){d=d|0;e=e|0;var f=0,g=0;f=d&-16;if((f|0)==1310720){b[(c[2383434]|0)+((d>>>1&7)<<1)>>1]=e;return}else if((f|0)==1376256){b[(c[2383435]|0)+((d>>>1&7)<<1)>>1]=e;return}else{do{if((d|0)==1572650|(d|0)==1671268|(d|0)==1818792){if(a[668920]|0){a[c[3528204]|0]=e&255;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12;break}else{c[2383412]=e&255;if((a[9661085]|0)==1){break}a[9661085]=1;if((a[9661088]|0)!=0){break}a[9661088]=2;break}}else if((d|0)==1638402|(d|0)==1720322){f=e&65535;g=f&255;c[2388528]=g;if((f&2|0)==0&(g|0)!=0&g>>>0<240){c[2385602]=g;return}else{c[2385602]=-1;return}}else if((d|0)==1638400|(d|0)==1720320){c[2405090]=e&255;return}else if((d|0)==1753088|(d|0)==1785856){g=c[2386546]|0;f=c[2386368]|0;gGC(g|0,f|0,2048)|0;return}}while(0);if((d&-2048|0)==1671168){f=d>>>1&1023;b[(c[2383414]|0)+(f<<1)>>1]=e;g=e&65535;c[2429386]=(f|0)==7?g:2048;c[2429384]=(f|0)==53?g:10342;c[2429382]=(f|0)==116?g:9217;return}if((d&-256|0)!=1818624){return}b[(c[2383414]|0)+((d-1818624|0)>>>1<<1)>>1]=e;return}}function aL9(d,f){d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;do{if((d|0)==1638401|(d|0)==1720321){c[2405090]=f&255;return}else if((d|0)==1638403|(d|0)==1720323){g=f&255;c[2388528]=g;if((c[2405090]&2|0)==0&f<<24>>24!=0&(f&255)<240){c[2385602]=g;return}else{c[2385602]=-1;return}}else if((d|0)==1753089|(d|0)==1785857){g=c[2386546]|0;h=c[2386368]|0;gGC(g|0,h|0,2048)|0;return}else if((d|0)==1671269|(d|0)==1818793){if(a[668920]|0){a[c[3528204]|0]=f;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12;break}else{c[2383412]=f&255;if((a[9661085]|0)==1){break}a[9661085]=1;if((a[9661088]|0)!=0){break}a[9661088]=2;break}}}while(0);if((d&-2048|0)!=1671168){if((d&-256|0)!=1818624){return}a[(c[2387034]|0)+(d&255^1)|0]=f;return}h=255<<(d<<3&8);g=d>>>1&1023;do{if((h|0)==65535){b[(c[2383414]|0)+(g<<1)>>1]=f&255;i=f&255}else{d=(c[2383414]|0)+(g<<1)|0;j=e[d>>1]&h;k=f&255;if((h|0)==65280){b[d>>1]=(j|k)&65535;i=k;break}else{b[d>>1]=(j|(h^65280)&k<<8)&65535;i=k;break}}}while(0);c[2429386]=(g|0)==7?i:2048;c[2429384]=(g|0)==53?i:10342;c[2429382]=(g|0)==116?i:9217;return}function aMa(a){a=a|0;var e=0;L45820:do{if((a|0)==1572642){e=(d[9634609]|0)<<8|(d[9634608]|0)}else if((a|0)==1720322|(a|0)==1638402){e=c[2388528]&65535}else if((a|0)==1572652){e=b[4775048]|0}else if((a|0)==1572648){e=(b[4775049]&7|c[2383408]&8)&65535}else if((a|0)==1720324|(a|0)==1638404){c[8452200+(c[2394]<<2)>>2]=0;c[2276080]=0;e=0}else{if((a&-1024|0)!=1818624){if((a&-2048|0)!=1671168){e=0;break}e=aFl(a)|0;break}switch(a&1022|0){case 556:{e=b[c[2383416]>>1]|0;break L45820;break};case 134:{e=b[(c[2383414]|0)+6>>1]|0;break L45820;break};case 230:{e=b[(c[2383414]|0)+4>>1]|0;break L45820;break};case 32:{e=b[(c[2383414]|0)+20>>1]|0;break L45820;break};case 54:{e=b[(c[2383416]|0)+4>>1]|0;break L45820;break};case 90:{e=b[(c[2383414]|0)+16>>1]|0;break L45820;break};case 456:{e=(b[(c[2383416]|0)+2>>1]&7|c[2383408]&8)&65535;break L45820;break};case 132:{e=b[(c[2383414]|0)+18>>1]|0;break L45820;break};case 114:{e=b[(c[2383414]|0)+22>>1]|0;break L45820;break};case 108:{e=b[(c[2383414]|0)+28>>1]|0;break L45820;break};case 128:{e=b[c[2383414]>>1]|0;break L45820;break};case 222:{e=b[(c[2383414]|0)+2>>1]|0;break L45820;break};case 110:{e=b[(c[2383414]|0)+26>>1]|0;break L45820;break};case 8:{e=b[(c[2383414]|0)+30>>1]|0;break L45820;break};case 220:{e=b[(c[2383414]|0)+24>>1]|0;break L45820;break};default:{e=-1;break L45820}}}}while(0);return e|0}function aMb(d){d=d|0;var f=0,g=0;if((d|0)==1572652){f=(e[4775048]|0)>>>8&255;return f|0}else if((d|0)==1572642){f=a[9634609]|0;return f|0}else if((d|0)==1572643){f=a[9634608]|0;return f|0}else if((d|0)==1572649){f=(b[4775049]&7|c[2383408]&8)&255;return f|0}else if((d|0)==1572653){f=b[4775048]&255;return f|0}else if((d|0)==1720325|(d|0)==1638405){c[8452200+(c[2394]<<2)>>2]=0;c[2276080]=0;f=0;return f|0}else if((d|0)==1720323|(d|0)==1638403){f=c[2388528]&255;return f|0}else{if((d&-2048|0)==1671168){f=((aFl(d)|0)&65535)>>>((d<<3&8^8)>>>0)&255;return f|0}if((d&-1024|0)!=1818624){f=0;return f|0}switch(d&1022|0){case 556:{g=b[c[2383416]>>1]|0;break};case 456:{g=(b[(c[2383416]|0)+2>>1]&7|c[2383408]&8)&65535;break};case 222:{g=b[(c[2383414]|0)+2>>1]|0;break};case 230:{g=b[(c[2383414]|0)+4>>1]|0;break};case 32:{g=b[(c[2383414]|0)+20>>1]|0;break};case 132:{g=b[(c[2383414]|0)+18>>1]|0;break};case 108:{g=b[(c[2383414]|0)+28>>1]|0;break};case 110:{g=b[(c[2383414]|0)+26>>1]|0;break};case 8:{g=b[(c[2383414]|0)+30>>1]|0;break};case 54:{g=b[(c[2383416]|0)+4>>1]|0;break};case 128:{g=b[c[2383414]>>1]|0;break};case 90:{g=b[(c[2383414]|0)+16>>1]|0;break};case 134:{g=b[(c[2383414]|0)+6>>1]|0;break};case 114:{g=b[(c[2383414]|0)+22>>1]|0;break};case 220:{g=b[(c[2383414]|0)+24>>1]|0;break};default:{g=-1}}f=(g&65535)>>>((d<<3&8^8)>>>0)&255;return f|0}return 0}function aMc(d,e){d=d|0;e=e|0;var f=0,g=0,h=0;f=d&-16;if((f|0)==3145728){b[(c[2383434]|0)+((d>>>1&7)<<1)>>1]=e;return}else if((f|0)==3211264){b[(c[2383435]|0)+((d>>>1&7)<<1)>>1]=e;return}else{do{if((d|0)==1704036){f=e&65535;c[2383412]=f&255;if((a[9661085]|0)==1){g=f;break}a[9661085]=1;if((a[9661088]|0)!=0){g=f;break}a[9661088]=2;g=f}else if((d|0)==1572864){b[4766836]=e;return}else if((d|0)==1966080){f=c[3529670]|0;h=c[3529622]|0;gGC(f|0,h|0,2048)|0;return}else if((d|0)==1835008){h=c[2386546]|0;f=c[2386368]|0;gGC(h|0,f|0,2048)|0;return}else{if((d&-2048|0)==1703936){g=e&65535;break}else{return}}}while(0);f=d>>>1&1023;b[(c[2383414]|0)+(f<<1)>>1]=e;c[2429386]=(f|0)==7?g:2048;c[2429384]=(f|0)==53?g:10342;c[2429382]=(f|0)==116?g:9217;return}}function aMd(d,f){d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;do{if((d|0)==1572864|(d|0)==1572865){b[4766836]=f&255;return}else if((d|0)==1835008|(d|0)==1835009){g=c[2386546]|0;h=c[2386368]|0;gGC(g|0,h|0,2048)|0;return}else if((d|0)==1704037){c[2383412]=f&255;if((a[9661085]|0)==1){break}a[9661085]=1;if((a[9661088]|0)!=0){break}a[9661088]=2}else if((d|0)==1966080|(d|0)==1966081){h=c[3529670]|0;g=c[3529622]|0;gGC(h|0,g|0,2048)|0;return}else{if((d&-2048|0)==1703936){break}return}}while(0);g=255<<(d<<3&8);h=d>>>1&1023;do{if((g|0)==65535){b[(c[2383414]|0)+(h<<1)>>1]=f&255;i=f&255}else{d=(c[2383414]|0)+(h<<1)|0;j=e[d>>1]&g;k=f&255;if((g|0)==65280){b[d>>1]=(j|k)&65535;i=k;break}else{b[d>>1]=(j|(g^65280)&k<<8)&65535;i=k;break}}}while(0);c[2429386]=(h|0)==7?i:2048;c[2429384]=(h|0)==53?i:10342;c[2429382]=(h|0)==116?i:9217;return}function aMe(a){a=a|0;var b=0;if((a&-2048|0)!=1703936){b=0;return b|0}b=aFk(a)|0;return b|0}function aMf(a){a=a|0;var b=0;if((a|0)==1835009){b=-1;return b|0}if((a&-2048|0)!=1703936){b=0;return b|0}b=((aFk(a)|0)&65535)>>>((a<<3&8^8)>>>0)&255;return b|0}function aMg(d,e){d=d|0;e=e|0;var f=0,g=0;f=d&-16;if((f|0)==1310720){b[(c[2383434]|0)+((d>>>1&7)<<1)>>1]=e;return}else if((f|0)==1376256){b[(c[2383435]|0)+((d>>>1&7)<<1)>>1]=e;return}else{if((d|0)==1622116){c[2383412]=e&255;if((a[9661085]|0)==1){return}a[9661085]=1;if((a[9661088]|0)!=0){return}a[9661088]=2;return}else if((d|0)==1769474){f=e&65535;g=f&255;c[2388528]=g;if((f&2|0)==0&(g|0)!=0&g>>>0<240){c[2385602]=g;return}else{c[2385602]=-1;return}}else if((d|0)==2031616){b[4766836]=e;return}else if((d|0)==1769472){c[2405090]=e&255;return}else if((d|0)==1671168){d=c[2386546]|0;e=c[2386368]|0;gGC(d|0,e|0,2048)|0;return}else{return}}}function aMh(d,e){d=d|0;e=e|0;var f=0,g=0;if((d|0)==1769472|(d|0)==1769473){c[2405090]=e&255;return}else if((d|0)==1622117){c[2383412]=e&255;if((a[9661085]|0)==1){return}a[9661085]=1;if((a[9661088]|0)!=0){return}a[9661088]=2;return}else if((d|0)==1671168|(d|0)==1671169){f=c[2386546]|0;g=c[2386368]|0;gGC(f|0,g|0,2048)|0;return}else if((d|0)==1769474|(d|0)==1769475){g=e&255;c[2388528]=g;if((c[2405090]&2|0)==0&e<<24>>24!=0&(e&255)<240){c[2385602]=g;return}else{c[2385602]=-1;return}}else if((d|0)==2031616|(d|0)==2031617){b[4766836]=e&255;return}else{return}}function aMi(a){a=a|0;var e=0;if((a|0)==1622816){e=(b[4775049]&7|c[2383408]&8)&65535}else if((a|0)==1623270){e=(d[9634609]|0)<<8|(d[9634608]|0)}else if((a|0)==1623066){e=b[4775048]|0}else if((a|0)==1623300){e=132}else if((a|0)==1769476){c[8452200+(c[2394]<<2)>>2]=0;c[2276080]=0;e=0}else if((a|0)==2064384){e=d[9634610]|0}else if((a|0)==1769474){e=c[2388528]&65535}else{e=0}return e|0}function aMj(d){d=d|0;var f=0;if((d|0)==1623066){f=(e[4775048]|0)>>>8&255}else if((d|0)==1769476|(d|0)==1769477){c[8452200+(c[2394]<<2)>>2]=0;c[2276080]=0;f=0}else if((d|0)==1622816|(d|0)==1622817){f=(b[4775049]&7|c[2383408]&8)&255}else if((d|0)==2064384|(d|0)==2064385){f=a[9634610]|0}else if((d|0)==1623271){f=a[9634609]|0}else if((d|0)==1623067){f=b[4775048]&255}else if((d|0)==1623270){f=a[9634608]|0}else if((d|0)==1623300|(d|0)==1623301){f=-124}else if((d|0)==1769474|(d|0)==1769475){f=c[2388528]&255}else{f=0}return f|0}function aMk(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((e|0)==34816){c[2113304]=d&255;return}else if((e|0)==38912){Uv(0,d);return}else if((e|0)==34817){e=c[2113304]|0;a[14168504+e|0]=d;mv(0,e,d&255);return}else{return}}function aMl(b){b=b|0;var d=0,e=0;d=b&65535;if((d|0)==40960){a[9706117]=0;e=a[c[3528204]|0]|0}else if((d|0)==34816|(d|0)==34817){e=c[(c[3531464]|0)+4240>>2]&255}else if((d|0)==38912){e=c[2113156]&255}else{e=0}return e|0}function aMm(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5933924+(b*112|0)>>2];c[a+104>>2]=c[5933928+(b*112|0)>>2];c[a+108>>2]=c[5933932+(b*112|0)>>2];d=0;return d|0}function aMn(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=5933824+(b*112|0);e=0;return e|0}function aMo(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6923472+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function aMp(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>38){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6397400+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aMq(){var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;d=i;i=i+720|0;e=d|0;f=d+112|0;g=d+120|0;j=d+232|0;k=d+240|0;l=d+352|0;m=d+360|0;n=d+472|0;o=d+480|0;p=d+592|0;q=d+600|0;r=d+712|0;c[2424]=5800;c[2414836]=0;c[2388064]=0;c[2386024]=1048576;c[2387764]=1048576;c[3530734]=1114112;c[3530498]=3211264;c[3530366]=5308416;c[3530300]=8454144;c[3530284]=18939904;c[3541206]=19988480;c[3529736]=19988480;c[3529692]=21037056;c[3529874]=21823488;c[2414538]=21831680;c[2388194]=21831680;c[2387786]=21864448;c[2386368]=21872640;c[2386546]=21874688;c[3529622]=21876736;c[3529670]=21878784;c[2387088]=21880832;c[2383414]=21889024;c[2387034]=21889024;c[2386174]=21891072;c[3528204]=21893120;c[3528638]=21893121;c[2411436]=21893122;c[3527020]=21893122;s=(a[9688]|0?21895258:21893122)|0;c[2413976]=s;t=s;s=0;while(1){if((s|0)>=1024){break}u=9638528+(s<<2)|0;if((c[u>>2]|0)==0){v=35708;break}else{s=s+1|0}}do{if((v|0)==35708){s=gGq(t)|0;c[u>>2]=s;if((s|0)==0){break}gGz(s|0,0,t|0);c[2414836]=s;gGz(s|0,0,t|0);c[2388064]=s;w=s+1048576|0;c[2386024]=w;c[2387764]=w;c[3530734]=s+1114112;c[3530498]=s+3211264;c[3530366]=s+5308416;c[3530300]=s+8454144;c[3530284]=s+18939904;w=s+19988480|0;c[3541206]=w;c[3529736]=w;c[3529692]=s+21037056;c[3529874]=s+21823488;w=s+21831680|0;c[2414538]=w;c[2388194]=w;c[2387786]=s+21864448;c[2386368]=s+21872640;c[2386546]=s+21874688;c[3529622]=s+21876736;c[3529670]=s+21878784;c[2387088]=s+21880832;w=s+21889024|0;c[2383414]=w;c[2387034]=w;c[2386174]=s+21891072;c[3528204]=s+21893120;c[3528638]=s+21893121;w=s+21893122|0;c[2411436]=w;c[3527020]=w;c[2413976]=s+(a[9688]|0?21895258:21893122);if((R6(s+1|0,0,2)|0)!=0){x=1;i=d;return x|0}if((R6(c[2388064]|0,1,2)|0)!=0){x=1;i=d;return x|0}if((R6((c[2388064]|0)+262145|0,2,2)|0)!=0){x=1;i=d;return x|0}if((R6((c[2388064]|0)+262144|0,3,2)|0)!=0){x=1;i=d;return x|0}if((R6((c[2388064]|0)+524289|0,4,2)|0)!=0){x=1;i=d;return x|0}if((R6((c[2388064]|0)+524288|0,5,2)|0)!=0){x=1;i=d;return x|0}s=c[2387764]|0;if((c[3542200]|0)==0){x=1;i=d;return x|0}w=q+108|0;c[w>>2]=0;y=q+100|0;c[y>>2]=0;z=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[z&16383](q,6)|0;do{if((c[w>>2]|0)!=0){z=c[y>>2]|0;c[r>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](r,6,0)|0;if((z|0)<1){x=1;i=d;return x|0}if((gzL(s,0,6)|0)==0){break}else{x=1}i=d;return x|0}}while(0);if((R6((c[3530734]|0)+1|0,7,2)|0)!=0){x=1;i=d;return x|0}if((R6(c[3530734]|0,8,2)|0)!=0){x=1;i=d;return x|0}s=c[3530498]|0;if((c[3542200]|0)==0){x=1;i=d;return x|0}y=o+108|0;c[y>>2]=0;w=o+100|0;c[w>>2]=0;z=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[z&16383](o,9)|0;do{if((c[y>>2]|0)!=0){z=c[w>>2]|0;c[p>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](p,9,0)|0;if((z|0)<1){x=1;i=d;return x|0}if((gzL(s,0,9)|0)==0){break}else{x=1}i=d;return x|0}}while(0);s=c[3530366]|0;if((c[3542200]|0)==0){x=1;i=d;return x|0}w=m+108|0;c[w>>2]=0;y=m+100|0;c[y>>2]=0;z=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[z&16383](m,10)|0;do{if((c[w>>2]|0)!=0){z=c[y>>2]|0;c[n>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](n,10,0)|0;if((z|0)<1){x=1;i=d;return x|0}if((gzL(s,0,10)|0)==0){break}else{x=1}i=d;return x|0}}while(0);s=(c[3530366]|0)+524288|0;if((c[3542200]|0)==0){x=1;i=d;return x|0}y=k+108|0;c[y>>2]=0;w=k+100|0;c[w>>2]=0;z=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[z&16383](k,11)|0;do{if((c[y>>2]|0)!=0){z=c[w>>2]|0;c[l>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](l,11,0)|0;if((z|0)<1){x=1;i=d;return x|0}if((gzL(s,0,11)|0)==0){break}else{x=1}i=d;return x|0}}while(0);s=c[3530366]|0;w=0;do{y=s+(w+262144)|0;z=a[y]|0;A=s+(w+524288)|0;a[y]=a[A]|0;a[A]=z;w=w+1|0;}while((w|0)<262144);if((R6(c[3530300]|0,12,2)|0)!=0){x=1;i=d;return x|0}if((R6((c[3530300]|0)+1|0,13,2)|0)!=0){x=1;i=d;return x|0}if((R6((c[3530300]|0)+1048576|0,14,2)|0)!=0){x=1;i=d;return x|0}if((R6((c[3530300]|0)+1048577|0,15,2)|0)!=0){x=1;i=d;return x|0}w=0;s=c[3530300]|0;while(1){z=a[s]|0;A=s+1|0;a[s]=a[A]|0;a[A]=z;z=w+1|0;if((z|0)<1048576){w=z;s=s+2|0}else{break}}s=c[3529736]|0;if((c[3542200]|0)==0){x=1;i=d;return x|0}w=g+108|0;c[w>>2]=0;z=g+100|0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,16)|0;do{if((c[w>>2]|0)!=0){A=c[z>>2]|0;c[j>>2]=9534384;y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[y&16383](j,16,0)|0;if((A|0)<1){x=1;i=d;return x|0}if((gzL(s,0,16)|0)==0){break}else{x=1}i=d;return x|0}}while(0);s=(c[3529692]|0)+262144|0;if((c[3542200]|0)==0){x=1;i=d;return x|0}z=e+108|0;c[z>>2]=0;w=e+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,17)|0;do{if((c[z>>2]|0)!=0){A=c[w>>2]|0;c[f>>2]=9534384;y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[y&16383](f,17,0)|0;if((A|0)<1){x=1;i=d;return x|0}if((gzL(s,0,17)|0)==0){break}else{x=1}i=d;return x|0}}while(0);s=c[3530734]|0;aE_(s,s,131072,1);s=c[3530498]|0;aE_(s,s,524288,0);s=c[3530366]|0;aE_(s,s,1048576,0);aE$(c[3530300]|0,2097152);s=c[2388064]|0;w=0;do{z=s+(w<<1)|0;A=b[z>>1]|0;do{if((A<<16>>16|0)==26367|(A<<16>>16|0)==26623){y=s+(w-4<<1)|0;B=b[y>>1]|0;if(!((B<<16>>16|0)==3129|(B<<16>>16|0)==2105)){break}b[z>>1]=20081;b[s+(w-1<<1)>>1]=20081;b[s+(w-2<<1)>>1]=20081;b[s+(w-3<<1)>>1]=20081;b[y>>1]=20081}}while(0);w=w+1|0;}while((w|0)<262144);aE1(0,1,1);w=c[3530498]|0;s=c[3530366]|0;c[2383440]=c[3530734];c[2383441]=w;c[2383442]=s;c[2383436]=4095;c[2383437]=4095;c[2383438]=8191;a[690376]=1;c[2429668]=512;c[2429669]=1280;c[2429438]=1670;c[2429439]=1670;fxU(0,425984);if((c[2394]|0)==0){C=c[2112932]|0}else{c[2394]=0;s=c[3532596]|0;c[2112932]=s;w=c[3532592]|0;if((w|0)!=0){gGC(9104152,w|0,280)|0}c[2113054]=c[2113060];C=s}s=c[2388064]|0;w=C|0;z=0;while(1){A=s+z|0;c[w>>2]=A;c[w+131072>>2]=A;A=z+1024|0;if(A>>>0>786431){break}else{w=w+4|0;z=A}}z=c[2383430]|0;c[C+5184>>2]=z;c[C+70720>>2]=z;c[C+136256>>2]=z;w=z+1024|0;c[C+5188>>2]=w;c[C+70724>>2]=w;c[C+136260>>2]=w;w=z+2048|0;c[C+5192>>2]=w;c[C+70728>>2]=w;c[C+136264>>2]=w;w=z+3072|0;c[C+5196>>2]=w;c[C+70732>>2]=w;c[C+136268>>2]=w;w=c[2383431]|0;c[C+5216>>2]=w;c[C+70752>>2]=w;c[C+136288>>2]=w;z=w+1024|0;c[C+5220>>2]=z;c[C+70756>>2]=z;c[C+136292>>2]=z;z=w+2048|0;c[C+5224>>2]=z;c[C+70760>>2]=z;c[C+136296>>2]=z;z=w+3072|0;c[C+5228>>2]=z;c[C+70764>>2]=z;c[C+136300>>2]=z;z=c[2383428]|0;c[C+5312>>2]=z;c[C+70848>>2]=z;c[C+136384>>2]=z;w=z+1024|0;c[C+5316>>2]=w;c[C+70852>>2]=w;c[C+136388>>2]=w;w=c[2383426]|0;c[C+5344>>2]=w;c[C+70880>>2]=w;c[C+136416>>2]=w;z=w+1024|0;c[C+5348>>2]=z;c[C+70884>>2]=z;c[C+136420>>2]=z;z=c[2383432]|0;c[C+5440>>2]=z;c[C+70976>>2]=z;c[C+136512>>2]=z;w=z+1024|0;c[C+5444>>2]=w;c[C+70980>>2]=w;c[C+136516>>2]=w;w=z+2048|0;c[C+5448>>2]=w;c[C+70984>>2]=w;c[C+136520>>2]=w;w=z+3072|0;c[C+5452>>2]=w;c[C+70988>>2]=w;c[C+136524>>2]=w;w=c[2383433]|0;c[C+5472>>2]=w;c[C+71008>>2]=w;c[C+136544>>2]=w;z=w+1024|0;c[C+5476>>2]=z;c[C+71012>>2]=z;c[C+136548>>2]=z;z=w+2048|0;c[C+5480>>2]=z;c[C+71016>>2]=z;c[C+136552>>2]=z;z=w+3072|0;c[C+5484>>2]=z;c[C+71020>>2]=z;c[C+136556>>2]=z;z=c[2383424]|0;c[C+5568>>2]=z;c[C+71104>>2]=z;c[C+136640>>2]=z;w=z+1024|0;c[C+5572>>2]=w;c[C+71108>>2]=w;c[C+136644>>2]=w;w=c[2383422]|0;c[C+5600>>2]=w;c[C+71136>>2]=w;c[C+136672>>2]=w;z=w+1024|0;c[C+5604>>2]=z;c[C+71140>>2]=z;c[C+136676>>2]=z;z=c[2388194]|0;c[C+6208>>2]=z;c[C+71744>>2]=z;c[C+137280>>2]=z;w=z+1024|0;c[C+6212>>2]=w;c[C+71748>>2]=w;c[C+137284>>2]=w;w=z+2048|0;c[C+6216>>2]=w;c[C+71752>>2]=w;c[C+137288>>2]=w;w=z+3072|0;c[C+6220>>2]=w;c[C+71756>>2]=w;c[C+137292>>2]=w;w=z+4096|0;c[C+6224>>2]=w;c[C+71760>>2]=w;c[C+137296>>2]=w;w=z+5120|0;c[C+6228>>2]=w;c[C+71764>>2]=w;c[C+137300>>2]=w;w=z+6144|0;c[C+6232>>2]=w;c[C+71768>>2]=w;c[C+137304>>2]=w;w=z+7168|0;c[C+6236>>2]=w;c[C+71772>>2]=w;c[C+137308>>2]=w;w=z+8192|0;c[C+6240>>2]=w;c[C+71776>>2]=w;c[C+137312>>2]=w;w=z+9216|0;c[C+6244>>2]=w;c[C+71780>>2]=w;c[C+137316>>2]=w;w=z+10240|0;c[C+6248>>2]=w;c[C+71784>>2]=w;c[C+137320>>2]=w;w=z+11264|0;c[C+6252>>2]=w;c[C+71788>>2]=w;c[C+137324>>2]=w;w=z+12288|0;c[C+6256>>2]=w;c[C+71792>>2]=w;c[C+137328>>2]=w;w=z+13312|0;c[C+6260>>2]=w;c[C+71796>>2]=w;c[C+137332>>2]=w;w=z+14336|0;c[C+6264>>2]=w;c[C+71800>>2]=w;c[C+137336>>2]=w;w=z+15360|0;c[C+6268>>2]=w;c[C+71804>>2]=w;c[C+137340>>2]=w;w=c[2387088]|0;c[C+6592>>2]=w;c[C+72128>>2]=w;c[C+137664>>2]=w;z=w+1024|0;c[C+6596>>2]=z;c[C+72132>>2]=z;c[C+137668>>2]=z;z=w+2048|0;c[C+6600>>2]=z;c[C+72136>>2]=z;c[C+137672>>2]=z;z=w+3072|0;c[C+6604>>2]=z;c[C+72140>>2]=z;c[C+137676>>2]=z;z=w+4096|0;c[C+6608>>2]=z;c[C+72144>>2]=z;c[C+137680>>2]=z;z=w+5120|0;c[C+6612>>2]=z;c[C+72148>>2]=z;c[C+137684>>2]=z;z=w+6144|0;c[C+6616>>2]=z;c[C+72152>>2]=z;c[C+137688>>2]=z;z=w+7168|0;c[C+6620>>2]=z;c[C+72156>>2]=z;c[C+137692>>2]=z;z=c[2386368]|0;c[C+6720>>2]=z;c[C+72256>>2]=z;c[C+137792>>2]=z;w=z+1024|0;c[C+6724>>2]=w;c[C+72260>>2]=w;c[C+137796>>2]=w;c[C+196728>>2]=796;c[C+196648>>2]=562;c[C+196688>>2]=3406;c[C+196608>>2]=368;w=c[3532592]|0;if((w|0)!=0){gGC(w|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;aE8(c[2387764]|0,c[2387786]|0,8055e3,1,1894,.45,1006875,.75,2013750,.6);h[745419]=.6;a[3203368]=1;h[745418]=.6;a[3203360]=1;h[745417]=.6;a[3203352]=1;h[745416]=.6;a[3203344]=1;w=c[642608+(c[2436]<<2)>>2]|0;z=c[w+128>>2]|0;if((c[w+52>>2]&4|0)==0){c[2113068]=z;s=c[w+132>>2]|0;c[2113070]=s;c[2443814]=z;c[2440436]=s;D=z;E=s}else{c[2113070]=z;s=c[w+132>>2]|0;c[2113068]=s;c[2440436]=z;c[2443814]=s;D=s;E=z}z=ag(D<<1,E)|0;s=gGq(z)|0;c[2112926]=s;if((s|0)!=0){gGz(s|0,0,z|0)}aNk();x=0;i=d;return x|0}}while(0);c[2414836]=0;x=1;i=d;return x|0}function aMr(){var b=0,d=0,e=0,f=0,g=0;c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}aE2();if((c[2392]|0)>=0){b=0;do{d=14130368+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}d=14130384+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}b=b+1|0;}while((b|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;do{if(a[668920]|0){fwZ();a[668920]=0;Uw(0);Uw(1);b=c[3531464]|0;c[b+44344>>2]=0;c[b+44348>>2]=0;if((b|0)!=0){gGr(b);c[3531464]=0}b=c[2406684]|0;if((b|0)==0){break}gGr(b);c[2406684]=0}else{aFe()}}while(0);b=c[2414836]|0;d=0;while(1){if((d|0)>=1024){f=35823;break}g=9638528+(d<<2)|0;if((c[g>>2]|0)==(b|0)){break}else{d=d+1|0}}if((f|0)==35823){c[2414836]=0;c[3541206]=0;return 0}gGr(b);c[g>>2]=0;c[2414836]=0;c[3541206]=0;return 0}function aMs(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((a[9623320]|0)!=0){aNk()}c[2383416]=9550096;c[2387524]=-1;e=0;f=-1;g=-1;do{f=((a[9632256+e|0]&1)<<e^f&65535)&65535;g=((a[9630168+e|0]&1)<<e^g&65535)&65535;e=e+1|0;}while((e|0)<16);b[4775048]=f;b[4775049]=g;b[4775050]=d[9634609]<<8|d[9634608];c[(c[2391608]|0)+60>>2]=0;c[(c[2391608]|0)+60>>2]=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060]}c[2388530]=9554128;g=c[2391608]|0;if((g|0)!=0){f=g;gGC(9661040,f|0,68)|0}c[2382]=0;c[2383408]=0;f=0;g=0;do{c[2113056]=808;e=RG(808)|0;c[2113054]=(c[2113054]|0)+e;c[2276108]=-1;c[2113056]=-1;fy_(542)|0;if((c[2385602]|0)==(f|0)){e=4-((c[2405090]|0)>>>4&1)|0;c[8452200+(c[2394]<<2)>>2]=e|4096;h=c[2276080]|0;i=e<<8;c[2276080]=i;do{if((h|0)!=1792&(e|0)==7){RH(7)}else{if(i>>>0<=(c[2276079]|0)>>>0){break}RH(e)}}while(0);c[2385602]=-1}if((f|0)==248){c[2383408]=8}e=a[9688]|0?2:0;i=(c[3527020]|0)+(g<<1<<1)|0;if(a[801408]|0){gg[c[3542124]&4095](i,e)}if(a[801400]|0){Uu(0,i,e)}if((c[2429658]|0)!=0){Uu(1,i,e)}g=e+g|0;f=f+1|0;}while((f|0)<256);c[8452200+(c[2394]<<2)>>2]=8197;c[2276080]=1280;if((c[2276079]|0)>>>0<1280){RH(5)}f=c[2438228]|0;e=gGS(-1427243008,66222,f,(f|0)<0|0?-1:0)|0;f=e;Sb(138879);e=c[2443830]|0;if((e|0)<1073676288){c[2443830]=e-f}e=c[2443831]|0;if((e|0)<1073676288){c[2443831]=e-f}e=(c[3528512]|0)-f|0;c[3528512]=(e|0)<0?0:e;e=c[2112964]|0;do{if((e|0)!=0){gg[c[3542122]&4095](e,a[9688]|0?534:0);f=a[9688]|0;i=f?534:0;if((i|0)==(g|0)){j=g;k=f}else{f=i-g|0;i=(c[3527020]|0)+(g<<1<<1)|0;if(a[801408]|0){gg[c[3542124]&4095](i,f)}if(a[801400]|0){Uu(0,i,f)}if((c[2429658]|0)!=0){Uu(1,i,f)}f=a[9688]|0;j=f?534:0;k=f}if((j|0)<=0){break}f=c[3527020]|0;i=c[2112964]|0;h=k?534:0;l=0;do{m=l<<1;n=i+(m<<1)|0;b[n>>1]=(b[n>>1]|0)+(b[f+(m<<1)>>1]|0)&65535;n=m|1;m=i+(n<<1)|0;b[m>>1]=(b[m>>1]|0)+(b[f+(n<<1)>>1]|0)&65535;l=l+1|0;}while((l|0)<(h|0))}}while(0);k=c[(c[2388530]|0)+12304>>2]|0;if((k|0)!=0){j=k;gGC(j|0,9661040,68)|0}c[2382]=-1;j=c[2394]|0;k=c[14130368+(j<<2)>>2]|0;if((k|0)!=0){gGC(k|0,9104152,280)|0}c[8452240+(j<<2)>>2]=c[2113054];c[2394]=-1;if((c[2112968]|0)==0){return 0}j=c[(c[642608+(c[2436]<<2)>>2]|0)+112>>2]|0;if((j|0)==0){return 0}gD[j&8191]()|0;return 0}function aMt(){var d=0,f=0,g=0,h=0,i=0,j=0;d=c[3529874]|0;f=c[2387088]|0;g=(c[642608+(c[2436]<<2)>>2]|0)+124|0;if((c[g>>2]<<1|0)>0){h=0;do{i=e[f+((h|1)<<1)>>1]|0;c[d+(((h|0)/2|0)<<2)>>2]=i<<8&63488|(e[f+(h<<1)>>1]|0)>>>3&31|i>>>8<<3&2016;h=h+2|0;}while((h|0)<(c[g>>2]<<1|0))}a[9547008]=0;aE3();aE5();g=ag(c[2113070]|0,c[2113068]|0)|0;h=c[2112926]|0;if((g|0)>0){f=0;while(1){b[h+(f<<1)>>1]=512;d=f+1|0;if((d|0)<(g|0)){f=d}else{j=h;break}}}else{j=h}gGz(c[2383420]|0,0,131072);gGz(c[2383410]|0,0,131072);aE0(3,j,65537);aE0(2,j,2);aE0(1,j,2);aE0(1,j,260);aNh();aE0(0,j,0);R8(c[3529874]|0);return 0}function aMu(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;e=i;i=i+128|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;l=e+80|0;m=e+96|0;n=e+112|0;if((d|0)!=0){c[d>>2]=169762}if((b&32|0)!=0){gGz(n|0,0,12);o=c[2414538]|0;c[n>>2]=o;c[n+4>>2]=(c[2411436]|0)-o;c[n+12>>2]=162152;o=c[2076592]|0;gj[o&4095](n)|0}if((b&64|0)==0){i=e;return 0}n=h|0;gGz(g|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){o=h+9|0;h=f;p=f|0;q=f+4|0;r=f+12|0;s=g|0;t=g+4|0;u=g+12|0;v=0;do{gGC(n|0,614896,11)|0;a[o]=v+48&255;w=8452256+(v<<2)|0;gGz(h|0,0,12);c[p>>2]=w;c[q>>2]=4;c[r>>2]=164976;gj[c[2076592]&4095](f)|0;if((c[w>>2]|0)!=0){c[s>>2]=c[14130368+(v<<2)>>2];c[t>>2]=c[8452184+(v<<2)>>2];c[u>>2]=n;w=c[2076592]|0;gj[w&4095](g)|0}v=v+1|0;}while((v|0)<=(c[2392]|0))}aFf(b,d);aE6();gGz(m|0,0,12);c[m>>2]=9554112;c[m+4>>2]=4;c[m+12>>2]=522544;gj[c[2076592]&4095](m)|0;gGz(l|0,0,12);c[l>>2]=9620360;c[l+4>>2]=4;c[l+12>>2]=520376;gj[c[2076592]&4095](l)|0;gGz(k|0,0,12);c[k>>2]=9542408;c[k+4>>2]=4;c[k+12>>2]=518872;gj[c[2076592]&4095](k)|0;gGz(j|0,0,12);c[j>>2]=14120936;c[j+4>>2]=4;c[j+12>>2]=491248;gj[c[2076592]&4095](j)|0;j=c[3530234]&1;c[3530234]=j;k=c[3529692]|0;l=k+((j<<18)+262144)|0;gGC(k|0,l|0,262144)|0;i=e;return 0}function aMv(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4779700+(b*112|0)>>2];c[a+104>>2]=c[4779704+(b*112|0)>>2];c[a+108>>2]=c[4779708+(b*112|0)>>2];d=0;return d|0}function aMw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=4779600+(b*112|0);e=0;return e|0}function aMx(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4777572+(b*112|0)>>2];c[a+104>>2]=c[4777576+(b*112|0)>>2];c[a+108>>2]=c[4777580+(b*112|0)>>2];d=0;return d|0}function aMy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=4777472+(b*112|0);e=0;return e|0}function aMz(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>41){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5532432+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function aMA(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5858012+(b*112|0)>>2];c[a+104>>2]=c[5858016+(b*112|0)>>2];c[a+108>>2]=c[5858020+(b*112|0)>>2];d=0;return d|0}function aMB(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=5857912+(b*112|0);e=0;return e|0}function aMC(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2204804+(b*112|0)>>2];c[a+104>>2]=c[2204808+(b*112|0)>>2];c[a+108>>2]=c[2204812+(b*112|0)>>2];d=0;return d|0}function aMD(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=2204704+(b*112|0);e=0;return e|0}function aME(){var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;d=i;i=i+600|0;e=d|0;f=d+112|0;g=d+120|0;j=d+232|0;k=d+240|0;l=d+352|0;m=d+360|0;n=d+472|0;o=d+480|0;p=d+592|0;c[2424]=5800;c[2414836]=0;c[2388064]=0;c[2386024]=1048576;c[2387764]=1048576;c[3530734]=1114112;c[3530498]=3211264;c[3530366]=5308416;c[3530300]=8454144;c[3530284]=18939904;c[3541206]=19988480;c[3529736]=19988480;c[3529692]=21037056;c[3529874]=21823488;c[2414538]=21831680;c[2388194]=21831680;c[2387786]=21864448;c[2386368]=21872640;c[2386546]=21874688;c[3529622]=21876736;c[3529670]=21878784;c[2387088]=21880832;c[2383414]=21889024;c[2387034]=21889024;c[2386174]=21891072;c[3528204]=21893120;c[3528638]=21893121;c[2411436]=21893122;c[3527020]=21893122;q=(a[9688]|0?21895258:21893122)|0;c[2413976]=q;r=q;q=0;while(1){if((q|0)>=1024){break}s=9638528+(q<<2)|0;if((c[s>>2]|0)==0){t=35956;break}else{q=q+1|0}}do{if((t|0)==35956){q=gGq(r)|0;c[s>>2]=q;if((q|0)==0){break}gGz(q|0,0,r|0);c[2414836]=q;gGz(q|0,0,r|0);c[2388064]=q;u=q+1048576|0;c[2386024]=u;c[2387764]=u;c[3530734]=q+1114112;c[3530498]=q+3211264;c[3530366]=q+5308416;c[3530300]=q+8454144;c[3530284]=q+18939904;u=q+19988480|0;c[3541206]=u;c[3529736]=u;c[3529692]=q+21037056;c[3529874]=q+21823488;u=q+21831680|0;c[2414538]=u;c[2388194]=u;c[2387786]=q+21864448;c[2386368]=q+21872640;c[2386546]=q+21874688;c[3529622]=q+21876736;c[3529670]=q+21878784;c[2387088]=q+21880832;u=q+21889024|0;c[2383414]=u;c[2387034]=u;c[2386174]=q+21891072;c[3528204]=q+21893120;c[3528638]=q+21893121;u=q+21893122|0;c[2411436]=u;c[3527020]=u;c[2413976]=q+(a[9688]|0?21895258:21893122);if((R6(q+1|0,0,2)|0)!=0){v=1;i=d;return v|0}if((R6(c[2388064]|0,1,2)|0)!=0){v=1;i=d;return v|0}if((R6((c[2388064]|0)+262145|0,2,2)|0)!=0){v=1;i=d;return v|0}if((R6((c[2388064]|0)+262144|0,3,2)|0)!=0){v=1;i=d;return v|0}if((R6((c[2388064]|0)+524289|0,4,2)|0)!=0){v=1;i=d;return v|0}if((R6((c[2388064]|0)+524288|0,5,2)|0)!=0){v=1;i=d;return v|0}q=c[2386024]|0;if((c[3542200]|0)==0){v=1;i=d;return v|0}u=o+108|0;c[u>>2]=0;w=o+100|0;c[w>>2]=0;x=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[x&16383](o,6)|0;do{if((c[u>>2]|0)!=0){x=c[w>>2]|0;c[p>>2]=9534384;y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[y&16383](p,6,0)|0;if((x|0)<1){v=1;i=d;return v|0}if((gzL(q,0,6)|0)==0){break}else{v=1}i=d;return v|0}}while(0);if((R6((c[3530734]|0)+1|0,7,2)|0)!=0){v=1;i=d;return v|0}if((R6(c[3530734]|0,8,2)|0)!=0){v=1;i=d;return v|0}q=c[3530498]|0;if((c[3542200]|0)==0){v=1;i=d;return v|0}w=m+108|0;c[w>>2]=0;u=m+100|0;c[u>>2]=0;x=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[x&16383](m,9)|0;do{if((c[w>>2]|0)!=0){x=c[u>>2]|0;c[n>>2]=9534384;y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[y&16383](n,9,0)|0;if((x|0)<1){v=1;i=d;return v|0}if((gzL(q,0,9)|0)==0){break}else{v=1}i=d;return v|0}}while(0);q=c[3530366]|0;if((c[3542200]|0)==0){v=1;i=d;return v|0}u=k+108|0;c[u>>2]=0;w=k+100|0;c[w>>2]=0;x=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[x&16383](k,10)|0;do{if((c[u>>2]|0)!=0){x=c[w>>2]|0;c[l>>2]=9534384;y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[y&16383](l,10,0)|0;if((x|0)<1){v=1;i=d;return v|0}if((gzL(q,0,10)|0)==0){break}else{v=1}i=d;return v|0}}while(0);q=(c[3530366]|0)+524288|0;if((c[3542200]|0)==0){v=1;i=d;return v|0}w=g+108|0;c[w>>2]=0;u=g+100|0;c[u>>2]=0;x=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[x&16383](g,11)|0;do{if((c[w>>2]|0)!=0){x=c[u>>2]|0;c[j>>2]=9534384;y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[y&16383](j,11,0)|0;if((x|0)<1){v=1;i=d;return v|0}if((gzL(q,0,11)|0)==0){break}else{v=1}i=d;return v|0}}while(0);q=c[3530366]|0;u=0;do{w=q+(u+262144)|0;x=a[w]|0;y=q+(u+524288)|0;a[w]=a[y]|0;a[y]=x;u=u+1|0;}while((u|0)<262144);if((R6(c[3530300]|0,12,2)|0)!=0){v=1;i=d;return v|0}if((R6((c[3530300]|0)+1|0,13,2)|0)!=0){v=1;i=d;return v|0}if((R6((c[3530300]|0)+1048576|0,14,2)|0)!=0){v=1;i=d;return v|0}if((R6((c[3530300]|0)+1048577|0,15,2)|0)!=0){v=1;i=d;return v|0}u=0;q=c[3530300]|0;while(1){x=a[q]|0;y=q+1|0;a[q]=a[y]|0;a[y]=x;x=u+1|0;if((x|0)<1048576){u=x;q=q+2|0}else{break}}q=c[3529736]|0;if((c[3542200]|0)==0){v=1;i=d;return v|0}u=e+108|0;c[u>>2]=0;x=e+100|0;c[x>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,16)|0;do{if((c[u>>2]|0)!=0){y=c[x>>2]|0;c[f>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](f,16,0)|0;if((y|0)<1){v=1;i=d;return v|0}if((gzL(q,0,16)|0)==0){break}else{v=1}i=d;return v|0}}while(0);gGz(c[3529692]|0,-1|0,524288);q=c[3530734]|0;aE_(q,q,131072,1);q=c[3530498]|0;aE_(q,q,524288,0);q=c[3530366]|0;aE_(q,q,1048576,0);aE$(c[3530300]|0,2097152);aE1(0,1,1);q=c[3530498]|0;x=c[3530366]|0;c[2383440]=c[3530734];c[2383441]=q;c[2383442]=x;c[2383436]=4095;c[2383437]=4095;c[2383438]=8191;a[690376]=1;c[2429434]=10;c[2429435]=0;c[2429426]=10;c[2429427]=0;c[2429422]=-2;c[2429423]=0;c[2429668]=512;c[2429669]=1280;c[2429438]=1670;c[2429439]=1670;fxU(0,425984);if((c[2394]|0)==0){z=c[2112932]|0}else{c[2394]=0;x=c[3532596]|0;c[2112932]=x;q=c[3532592]|0;if((q|0)!=0){gGC(9104152,q|0,280)|0}c[2113054]=c[2113060];z=x}x=c[2388064]|0;q=z|0;u=0;while(1){y=x+u|0;c[q>>2]=y;c[q+131072>>2]=y;y=u+1024|0;if(y>>>0>786431){break}else{q=q+4|0;u=y}}u=c[2383430]|0;c[z+5184>>2]=u;c[z+70720>>2]=u;c[z+136256>>2]=u;q=u+1024|0;c[z+5188>>2]=q;c[z+70724>>2]=q;c[z+136260>>2]=q;q=u+2048|0;c[z+5192>>2]=q;c[z+70728>>2]=q;c[z+136264>>2]=q;q=u+3072|0;c[z+5196>>2]=q;c[z+70732>>2]=q;c[z+136268>>2]=q;q=c[2383431]|0;c[z+5216>>2]=q;c[z+70752>>2]=q;c[z+136288>>2]=q;u=q+1024|0;c[z+5220>>2]=u;c[z+70756>>2]=u;c[z+136292>>2]=u;u=q+2048|0;c[z+5224>>2]=u;c[z+70760>>2]=u;c[z+136296>>2]=u;u=q+3072|0;c[z+5228>>2]=u;c[z+70764>>2]=u;c[z+136300>>2]=u;u=c[2383428]|0;c[z+5312>>2]=u;c[z+70848>>2]=u;c[z+136384>>2]=u;q=u+1024|0;c[z+5316>>2]=q;c[z+70852>>2]=q;c[z+136388>>2]=q;q=c[2383426]|0;c[z+5344>>2]=q;c[z+70880>>2]=q;c[z+136416>>2]=q;u=q+1024|0;c[z+5348>>2]=u;c[z+70884>>2]=u;c[z+136420>>2]=u;u=c[2383432]|0;c[z+5440>>2]=u;c[z+70976>>2]=u;c[z+136512>>2]=u;q=u+1024|0;c[z+5444>>2]=q;c[z+70980>>2]=q;c[z+136516>>2]=q;q=u+2048|0;c[z+5448>>2]=q;c[z+70984>>2]=q;c[z+136520>>2]=q;q=u+3072|0;c[z+5452>>2]=q;c[z+70988>>2]=q;c[z+136524>>2]=q;q=c[2383433]|0;c[z+5472>>2]=q;c[z+71008>>2]=q;c[z+136544>>2]=q;u=q+1024|0;c[z+5476>>2]=u;c[z+71012>>2]=u;c[z+136548>>2]=u;u=q+2048|0;c[z+5480>>2]=u;c[z+71016>>2]=u;c[z+136552>>2]=u;u=q+3072|0;c[z+5484>>2]=u;c[z+71020>>2]=u;c[z+136556>>2]=u;u=c[2383424]|0;c[z+5568>>2]=u;c[z+71104>>2]=u;c[z+136640>>2]=u;q=u+1024|0;c[z+5572>>2]=q;c[z+71108>>2]=q;c[z+136644>>2]=q;q=c[2383422]|0;c[z+5600>>2]=q;c[z+71136>>2]=q;c[z+136672>>2]=q;u=q+1024|0;c[z+5604>>2]=u;c[z+71140>>2]=u;c[z+136676>>2]=u;u=c[2388194]|0;c[z+6208>>2]=u;c[z+71744>>2]=u;c[z+137280>>2]=u;q=u+1024|0;c[z+6212>>2]=q;c[z+71748>>2]=q;c[z+137284>>2]=q;q=u+2048|0;c[z+6216>>2]=q;c[z+71752>>2]=q;c[z+137288>>2]=q;q=u+3072|0;c[z+6220>>2]=q;c[z+71756>>2]=q;c[z+137292>>2]=q;q=u+4096|0;c[z+6224>>2]=q;c[z+71760>>2]=q;c[z+137296>>2]=q;q=u+5120|0;c[z+6228>>2]=q;c[z+71764>>2]=q;c[z+137300>>2]=q;q=u+6144|0;c[z+6232>>2]=q;c[z+71768>>2]=q;c[z+137304>>2]=q;q=u+7168|0;c[z+6236>>2]=q;c[z+71772>>2]=q;c[z+137308>>2]=q;q=u+8192|0;c[z+6240>>2]=q;c[z+71776>>2]=q;c[z+137312>>2]=q;q=u+9216|0;c[z+6244>>2]=q;c[z+71780>>2]=q;c[z+137316>>2]=q;q=u+10240|0;c[z+6248>>2]=q;c[z+71784>>2]=q;c[z+137320>>2]=q;q=u+11264|0;c[z+6252>>2]=q;c[z+71788>>2]=q;c[z+137324>>2]=q;q=u+12288|0;c[z+6256>>2]=q;c[z+71792>>2]=q;c[z+137328>>2]=q;q=u+13312|0;c[z+6260>>2]=q;c[z+71796>>2]=q;c[z+137332>>2]=q;q=u+14336|0;c[z+6264>>2]=q;c[z+71800>>2]=q;c[z+137336>>2]=q;q=u+15360|0;c[z+6268>>2]=q;c[z+71804>>2]=q;c[z+137340>>2]=q;q=c[2387088]|0;c[z+6592>>2]=q;c[z+72128>>2]=q;c[z+137664>>2]=q;u=q+1024|0;c[z+6596>>2]=u;c[z+72132>>2]=u;c[z+137668>>2]=u;u=q+2048|0;c[z+6600>>2]=u;c[z+72136>>2]=u;c[z+137672>>2]=u;u=q+3072|0;c[z+6604>>2]=u;c[z+72140>>2]=u;c[z+137676>>2]=u;u=q+4096|0;c[z+6608>>2]=u;c[z+72144>>2]=u;c[z+137680>>2]=u;u=q+5120|0;c[z+6612>>2]=u;c[z+72148>>2]=u;c[z+137684>>2]=u;u=q+6144|0;c[z+6616>>2]=u;c[z+72152>>2]=u;c[z+137688>>2]=u;u=q+7168|0;c[z+6620>>2]=u;c[z+72156>>2]=u;c[z+137692>>2]=u;u=c[2386368]|0;c[z+6720>>2]=u;c[z+72256>>2]=u;c[z+137792>>2]=u;q=u+1024|0;c[z+6724>>2]=q;c[z+72260>>2]=q;c[z+137796>>2]=q;c[z+196728>>2]=796;c[z+196648>>2]=562;c[z+196688>>2]=3406;c[z+196608>>2]=368;q=c[3532592]|0;if((q|0)!=0){gGC(q|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;a[668920]=1;fwR(0);q=c[2439330]|0;u=(q|0)==0;if(!u){x=q;gGC(9706056,x|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];x=c[3528484]|0;c[2076596]=x;y=c[2417276]|0;c[3541536]=y;c[1836236]=0;w=c[2386024]|0;A=0;B=0;while(1){c[q+76+(B<<2)>>2]=w+(B<<8);C=A+1&65535;if((C&65535)>127){D=0;E=0;break}else{A=C;B=C&65535}}while(1){B=w+(E<<8)|0;c[q+76+(E+512<<2)>>2]=B;c[q+76+(E+768<<2)>>2]=B;B=D+1&65535;if((B&65535)>127){break}else{D=B;E=B&65535}}w=c[2386174]|0;c[q+588>>2]=w;B=w+256|0;c[q+592>>2]=B;A=w+512|0;c[q+596>>2]=A;C=w+768|0;c[q+600>>2]=C;F=w+1024|0;c[q+604>>2]=F;G=w+1280|0;c[q+608>>2]=G;H=w+1536|0;c[q+612>>2]=H;I=w+1792|0;c[q+616>>2]=I;c[q+1612>>2]=w;c[q+1616>>2]=B;c[q+1620>>2]=A;c[q+1624>>2]=C;c[q+1628>>2]=F;c[q+1632>>2]=G;c[q+1636>>2]=H;c[q+1640>>2]=I;c[q+2636>>2]=w;c[q+3660>>2]=w;c[q+2640>>2]=B;c[q+3664>>2]=B;c[q+2644>>2]=A;c[q+3668>>2]=A;c[q+2648>>2]=C;c[q+3672>>2]=C;c[q+2652>>2]=F;c[q+3676>>2]=F;c[q+2656>>2]=G;c[q+3680>>2]=G;c[q+2660>>2]=H;c[q+3684>>2]=H;c[q+2664>>2]=I;c[q+3688>>2]=I;c[q+4184>>2]=2866;c[q+4180>>2]=2090;if(!u){I=q;gGC(I|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=x;c[2417276]=y;c[1836236]=-1;Ux(0,7627,1);Ux(1,15255,1);c[2407030]=192;c[2407068]=3;c[2407069]=154;c[2407107]=3;I=a[9680]|0;H=I?32e3:0;if(I){if(a[9624]|0){I=H*3|0;G=55937;while(1){if((G|0)>(I|0)){G=G>>1}else{J=1222;K=G;break}}}else{J=2462;K=H}c[2429380]=K;c[3542124]=J;mw(358e4,K);G=gGq(262144)|0;c[2406684]=G;gGz(G|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(358e4,11025)}h[745421]=.45;c[2436794]=3;h[745420]=.45;c[2436792]=3;c[(c[3531464]|0)+44344>>2]=884;G=c[642608+(c[2436]<<2)>>2]|0;I=c[G+128>>2]|0;if((c[G+52>>2]&4|0)==0){c[2113068]=I;y=c[G+132>>2]|0;c[2113070]=y;c[2443814]=I;c[2440436]=y;L=I;M=y}else{c[2113070]=I;y=c[G+132>>2]|0;c[2113068]=y;c[2440436]=I;c[2443814]=y;L=y;M=I}I=ag(L<<1,M)|0;y=gGq(I)|0;c[2112926]=y;if((y|0)!=0){gGz(y|0,0,I|0)}aNk();v=0;i=d;return v|0}}while(0);c[2414836]=0;v=1;i=d;return v|0}function aMF(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;if((a[9623320]|0)!=0){aNk()}c[2383416]=9550096;c[2387524]=-1;e=0;f=-1;g=-1;do{f=((a[9632256+e|0]&1)<<e^f&65535)&65535;g=((a[9630168+e|0]&1)<<e^g&65535)&65535;e=e+1|0;}while((e|0)<16);b[4775048]=f;b[4775049]=g;b[4775050]=d[9634609]<<8|d[9634608];if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060]}g=c[2439330]|0;if((g|0)!=0){f=g;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;c[2383408]=0;f=0;g=0;while(1){c[2113056]=808;e=RG(808)|0;c[2113054]=(c[2113054]|0)+e;c[2276108]=-1;c[2113056]=-1;if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){e=gfc(241)|0;h=(c[2433530]|0)+e|0}else{h=(c[2433530]|0)+241|0}c[2433530]=h;if((c[2385602]|0)==(f|0)){e=4-((c[2405090]|0)>>>4&1)|0;c[8452200+(c[2394]<<2)>>2]=e|4096;i=c[2276080]|0;j=e<<8;c[2276080]=j;do{if((i|0)!=1792&(e|0)==7){RH(7)}else{if(j>>>0<=(c[2276079]|0)>>>0){break}RH(e)}}while(0);c[2385602]=-1}if((f|0)==248){c[2383408]=8}e=c[2112964]|0;if((e|0)==0){k=g}else{j=a[9688]|0?2:0;i=e+(g<<1<<1)|0;gg[c[3542124]&4095](i,j);Uu(0,i,j);Uu(1,i,j);k=j+g|0}j=f+1|0;if((j|0)<256){f=j;g=k}else{break}}c[8452200+(c[2394]<<2)>>2]=8197;c[2276080]=1280;if((c[2276079]|0)>>>0<1280){RH(5)}g=c[2112964]|0;do{if((g|0)!=0){f=a[9688]|0?534:0;h=f-k|0;j=g+(k<<1<<1)|0;if((f|0)==(k|0)){break}gg[c[3542124]&4095](j,h);Uu(0,j,h);Uu(1,j,h)}}while(0);k=c[1836236]|0;g=c[9757320+(k<<2)>>2]|0;if((g|0)!=0){h=g;gGC(h|0,9706056,76)|0}c[9752472+(k<<2)>>2]=c[2433530];c[14113936+(k<<2)>>2]=c[2076596];c[9669104+(k<<2)>>2]=c[3541536];c[1836236]=-1;k=c[2394]|0;h=c[14130368+(k<<2)>>2]|0;if((h|0)!=0){gGC(h|0,9104152,280)|0}c[8452240+(k<<2)>>2]=c[2113054];c[2394]=-1;if((c[2112968]|0)==0){return 0}k=c[(c[642608+(c[2436]<<2)>>2]|0)+112>>2]|0;if((k|0)==0){return 0}gD[k&8191]()|0;return 0}function aMG(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;f=i;i=i+160|0;g=f|0;h=f+16|0;j=f+32|0;k=f+48|0;l=f+64|0;m=f+80|0;n=f+96|0;o=f+112|0;p=f+128|0;q=f+144|0;if((e|0)!=0){c[e>>2]=169762}if((b&32|0)!=0){gGz(q|0,0,12);e=c[2414538]|0;c[q>>2]=e;c[q+4>>2]=(c[2411436]|0)-e;c[q+12>>2]=162152;e=c[2076592]|0;gj[e&4095](q)|0}if((b&64|0)==0){i=f;return 0}q=l|0;gGz(k|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){e=l+9|0;l=j;r=j|0;s=j+4|0;t=j+12|0;u=k|0;v=k+4|0;w=k+12|0;x=0;do{gGC(q|0,614896,11)|0;a[e]=x+48&255;y=8452256+(x<<2)|0;gGz(l|0,0,12);c[r>>2]=y;c[s>>2]=4;c[t>>2]=164976;gj[c[2076592]&4095](j)|0;if((c[y>>2]|0)!=0){c[u>>2]=c[14130368+(x<<2)>>2];c[v>>2]=c[8452184+(x<<2)>>2];c[w>>2]=q;y=c[2076592]|0;gj[y&4095](k)|0}x=x+1|0;}while((x|0)<=(c[2392]|0))}fw$(b);gGz(h|0,0,12);c[h>>2]=8453216;c[h+4>>2]=4;c[h+12>>2]=107480;gj[c[2076592]&4095](h)|0;gGz(g|0,0,12);c[g>>2]=14168504;c[g+4>>2]=256;c[g+12>>2]=476464;gj[c[2076592]&4095](g)|0;if((b&2|0)!=0){b=0;do{mv(0,b,d[14168504+b|0]|0);b=b+1|0;}while((b|0)<256)}Ut(0);Ut(1);aE6();gGz(p|0,0,12);c[p>>2]=9554112;c[p+4>>2]=4;c[p+12>>2]=522544;gj[c[2076592]&4095](p)|0;gGz(o|0,0,12);c[o>>2]=9620360;c[o+4>>2]=4;c[o+12>>2]=520376;gj[c[2076592]&4095](o)|0;gGz(n|0,0,12);c[n>>2]=9542408;c[n+4>>2]=4;c[n+12>>2]=518872;gj[c[2076592]&4095](n)|0;gGz(m|0,0,12);c[m>>2]=14120936;c[m+4>>2]=4;c[m+12>>2]=491248;gj[c[2076592]&4095](m)|0;i=f;return 0}function aMH(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>5){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3011140+(b*112|0)>>2];c[a+104>>2]=c[3011144+(b*112|0)>>2];c[a+108>>2]=c[3011148+(b*112|0)>>2];d=0;return d|0}function aMI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<6&(d|0)==0)){e=1;return e|0}c[a>>2]=3011040+(b*112|0);e=0;return e|0}
function fFa(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c[2426872]=c[2410680];d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;l=f;m=g;break}n=gj[i&4095](e)|0;j=n;k=b[4821352]|0;l=c[3528552]|0;m=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=e;l=f;m=g}}while(0);a[9707488]=j;b[4821352]=k+1&65535;k=c[2426872]|0;j=k&65535;g=c[m+(l*3160|0)+60+((k>>>8&255)<<2)>>2]|0;do{if((g|0)==0){f=c[m+(l*3160|0)+3132>>2]|0;if((f|0)==0){o=0;break}o=gj[f&4095](j)|0}else{o=a[g+(k&255)|0]|0}}while(0);k=a[9642713]&o;o=(k&255)>>>4&8|a[9642744]&-15;a[9642744]=k<<24>>24==0?o|4:o;return}function fFb(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c[2426872]=c[2410680];d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;l=f;m=g;break}n=gj[i&4095](e)|0;j=n;k=b[4821352]|0;l=c[3528552]|0;m=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=e;l=f;m=g}}while(0);a[9707488]=j;b[4821352]=k+1&65535;k=c[2426872]|0;j=k&65535;g=c[m+(l*3160|0)+60+((k>>>8&255)<<2)>>2]|0;do{if((g|0)==0){f=c[m+(l*3160|0)+3132>>2]|0;if((f|0)==0){o=0;break}o=gj[f&4095](j)|0}else{o=a[g+(k&255)|0]|0}}while(0);a[9642713]=o;k=(o&255)>>>4&8|a[9642744]&-15;a[9642744]=o<<24>>24==0?k|4:k;return}function fFc(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=a[9642713]|0;e=(d&255)>>>4&8|a[9642744]&-15;a[9642744]=d<<24>>24==0?e|4:e;c[2426872]=c[2410680];e=c[2410676]|0;f=e&65535;g=c[3528552]|0;h=c[2433426]|0;i=c[h+(g*3160|0)+60+((e>>>8&255|512)<<2)>>2]|0;do{if((i|0)==0){j=c[h+(g*3160|0)+3144>>2]|0;if((j|0)==0){k=0;l=f;m=d;n=g;o=h;break}p=gj[j&4095](f)|0;k=p;l=b[4821352]|0;m=a[9642713]|0;n=c[3528552]|0;o=c[2433426]|0}else{k=a[i+(e&255)|0]|0;l=f;m=d;n=g;o=h}}while(0);a[9707488]=k;b[4821352]=l+1&65535;l=c[2426872]|0;k=c[o+(n*3160|0)+60+((l>>>8&255|256)<<2)>>2]|0;if((k|0)!=0){a[k+(l&255)|0]=m;return}k=c[o+(n*3160|0)+3136>>2]|0;if((k|0)==0){return}gg[k&4095](l&65535,m);return}function fFd(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c[2426872]=c[2410680];d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;l=f;m=g;break}n=gj[i&4095](e)|0;j=n;k=b[4821352]|0;l=c[3528552]|0;m=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=e;l=f;m=g}}while(0);a[9707488]=j;b[4821352]=k+1&65535;k=c[2426872]|0;j=k&65535;g=c[m+(l*3160|0)+60+((k>>>8&255)<<2)>>2]|0;do{if((g|0)==0){f=c[m+(l*3160|0)+3132>>2]|0;if((f|0)==0){o=0;break}o=gj[f&4095](j)|0}else{o=a[g+(k&255)|0]|0}}while(0);k=a[9642713]|0;g=k^o;a[9642713]=g;j=(g&255)>>>4&8|a[9642744]&-15;a[9642744]=k<<24>>24==o<<24>>24?j|4:j;return}function fFe(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c[2426872]=c[2410680];d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;l=f;m=g;break}n=gj[i&4095](e)|0;j=n;k=b[4821352]|0;l=c[3528552]|0;m=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=e;l=f;m=g}}while(0);a[9707488]=j;b[4821352]=k+1&65535;k=c[2426872]|0;j=k&65535;g=c[m+(l*3160|0)+60+((k>>>8&255)<<2)>>2]|0;do{if((g|0)==0){f=c[m+(l*3160|0)+3132>>2]|0;if((f|0)==0){o=0;break}o=gj[f&4095](j)|0}else{o=a[g+(k&255)|0]|0}}while(0);k=a[9642713]|0;g=a[9642744]|0;j=(k&255)+(o&255)+(g&1)|0;l=(j>>>4&8|g&-48&255)&255;g=j&255;m=j^(k^o)&255;a[9642744]=(m<<1&32|j>>>8&1|(m^j>>>1)>>>6&2|(g<<24>>24==0?l|4:l)&255)&255;a[9642713]=g;return}function fFf(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c[2426872]=c[2410680];d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;l=f;m=g;break}n=gj[i&4095](e)|0;j=n;k=b[4821352]|0;l=c[3528552]|0;m=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=e;l=f;m=g}}while(0);a[9707488]=j;b[4821352]=k+1&65535;k=c[2426872]|0;j=k&65535;g=c[m+(l*3160|0)+60+((k>>>8&255)<<2)>>2]|0;do{if((g|0)==0){f=c[m+(l*3160|0)+3132>>2]|0;if((f|0)==0){o=0;break}o=gj[f&4095](j)|0}else{o=a[g+(k&255)|0]|0}}while(0);k=a[9642713]|o;a[9642713]=k;o=(k&255)>>>4&8|a[9642744]&-15;a[9642744]=k<<24>>24==0?o|4:o;return}function fFg(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c[2426872]=c[2410680];d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;l=f;m=g;break}n=gj[i&4095](e)|0;j=n;k=b[4821352]|0;l=c[3528552]|0;m=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=e;l=f;m=g}}while(0);a[9707488]=j;b[4821352]=k+1&65535;k=c[2426872]|0;j=k&65535;g=c[m+(l*3160|0)+60+((k>>>8&255)<<2)>>2]|0;do{if((g|0)==0){f=c[m+(l*3160|0)+3132>>2]|0;if((f|0)==0){o=0;break}o=gj[f&4095](j)|0}else{o=a[g+(k&255)|0]|0}}while(0);k=a[9642713]|0;g=(k&255)+(o&255)|0;j=(g>>>4&8|a[9642744]&-48&255)&255;l=g&255;m=(k^o)&255^g;a[9642744]=(m<<1&32|g>>>8&1|(m^g>>>1)>>>6&2|(l<<24>>24==0?j|4:j)&255)&255;a[9642713]=l;return}function fFh(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;c[2426872]=c[2410680];d=c[2410676]|0;f=d&65535;g=c[3528552]|0;h=c[2433426]|0;i=c[h+(g*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((i|0)==0){j=c[h+(g*3160|0)+3144>>2]|0;if((j|0)==0){k=0;l=f;m=g;n=h;break}o=gj[j&4095](f)|0;k=o;l=b[4821352]|0;m=c[3528552]|0;n=c[2433426]|0}else{k=a[i+(d&255)|0]|0;l=f;m=g;n=h}}while(0);a[9707488]=k;b[4821352]=l+1&65535;l=c[2426872]|0;k=l&65535;h=c[n+(m*3160|0)+60+((l>>>8&255)<<2)>>2]|0;do{if((h|0)==0){g=c[n+(m*3160|0)+3132>>2]|0;if((g|0)==0){p=0;q=m;r=n;break}f=gj[g&4095](k)|0;p=f;q=c[3528552]|0;r=c[2433426]|0}else{p=a[h+(l&255)|0]|0;q=m;r=n}}while(0);n=(p&255)<<8;p=l+1|0;l=p&65535;m=c[r+(q*3160|0)+60+((p>>>8&255)<<2)>>2]|0;do{if((m|0)==0){h=c[r+(q*3160|0)+3132>>2]|0;if((h|0)==0){s=0;break}s=gj[h&4095](l)|0}else{s=a[m+(p&255)|0]|0}}while(0);p=e[4821366]|0;m=p-(s&255|n)|0;s=(m>>>12&8|a[9642744]&-16&255)&255;a[9642744]=((p^n^m^m>>>1)>>>14&2|m>>>16&1|((m&65535)<<16>>16==0?s|4:s)&255)&255;return}function fFi(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;c[2426872]=c[2410680];d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;l=f;m=g;break}n=gj[i&4095](e)|0;j=n;k=b[4821352]|0;l=c[3528552]|0;m=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=e;l=f;m=g}}while(0);a[9707488]=j;j=k+1&65535;b[4821352]=j;b[4821364]=(b[4821364]|0)-1&65535;k=c[2410682]|0;g=k&65535;f=j&255;j=c[m+(l*3160|0)+60+((k>>>8&255|256)<<2)>>2]|0;do{if((j|0)==0){e=c[m+(l*3160|0)+3136>>2]|0;if((e|0)==0){o=l;p=m;break}gg[e&4095](g,f);o=c[3528552]|0;p=c[2433426]|0}else{a[j+(k&255)|0]=f;o=l;p=m}}while(0);b[4821364]=(b[4821364]|0)-1&65535;m=c[2410682]|0;l=a[9642705]|0;f=c[p+(o*3160|0)+60+((m>>>8&255|256)<<2)>>2]|0;if((f|0)!=0){a[f+(m&255)|0]=l;q=c[2426872]|0;c[2410676]=q;r=q&65535;b[4821352]=r;return}f=c[p+(o*3160|0)+3136>>2]|0;if((f|0)==0){q=c[2426872]|0;c[2410676]=q;r=q&65535;b[4821352]=r;return}gg[f&4095](m&65535,l);q=c[2426872]|0;c[2410676]=q;r=q&65535;b[4821352]=r;return}function fFj(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;c[2426872]=c[2410680];d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;l=f;m=g;break}n=gj[i&4095](e)|0;j=n;k=b[4821352]|0;l=c[3528552]|0;m=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=e;l=f;m=g}}while(0);a[9707488]=j;b[4821352]=k+1&65535;k=c[2426872]|0;j=k&65535;g=c[m+(l*3160|0)+60+((k>>>8&255)<<2)>>2]|0;do{if((g|0)==0){f=c[m+(l*3160|0)+3132>>2]|0;if((f|0)==0){o=0;p=l;q=m;break}e=gj[f&4095](j)|0;o=e;p=c[3528552]|0;q=c[2433426]|0}else{o=a[g+(k&255)|0]|0;p=l;q=m}}while(0);m=o&255;o=m<<8;l=k+1|0;k=l&65535;g=c[q+(p*3160|0)+60+((l>>>8&255)<<2)>>2]|0;do{if((g|0)==0){j=c[q+(p*3160|0)+3132>>2]|0;if((j|0)==0){r=0;break}r=gj[j&4095](k)|0}else{r=a[g+(l&255)|0]|0}}while(0);l=r&255|o;c[2410683]=l;o=a[9642744]&-15;a[9642744]=o;r=o&255|m>>>4&8;if((l|0)!=0){s=r&255;a[9642744]=s;return}s=(r|4)&255;a[9642744]=s;return}function fFk(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=a[9642744]&-15;a[9642744]=d;e=b[4821366]|0;f=(e&65535)>>>12&8|d&255;if(e<<16>>16==0){g=(f|4)&255}else{g=f&255}a[9642744]=g;c[2426872]=c[2410680];g=c[2410676]|0;f=g&65535;e=c[3528552]|0;d=c[2433426]|0;h=c[d+(e*3160|0)+60+((g>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[d+(e*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=f;l=e;m=d;break}n=gj[i&4095](f)|0;j=n;k=b[4821352]|0;l=c[3528552]|0;m=c[2433426]|0}else{j=a[h+(g&255)|0]|0;k=f;l=e;m=d}}while(0);a[9707488]=j;b[4821352]=k+1&65535;k=c[2426872]|0;j=k&65535;d=a[9642733]|0;e=c[m+(l*3160|0)+60+((k>>>8&255|256)<<2)>>2]|0;do{if((e|0)==0){f=c[m+(l*3160|0)+3136>>2]|0;if((f|0)==0){o=l;p=m;break}gg[f&4095](j,d);o=c[3528552]|0;p=c[2433426]|0}else{a[e+(k&255)|0]=d;o=l;p=m}}while(0);m=k+1|0;k=a[9642732]|0;l=c[p+(o*3160|0)+60+((m>>>8&255|256)<<2)>>2]|0;if((l|0)!=0){a[l+(m&255)|0]=k;return}l=c[p+(o*3160|0)+3136>>2]|0;if((l|0)==0){return}gg[l&4095](m&65535,k);return}function fFl(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;fGP();b=c[2426872]|0;d=b&65535;e=c[3528552]|0;f=c[2433426]|0;g=c[f+(e*3160|0)+60+((b>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[f+(e*3160|0)+3132>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(b&255)|0]|0}}while(0);b=a[9642713]|0;g=(b&255)-(i&255)|0;d=(g>>>4&8|a[9642744]&-16&255)&255;e=g&255;a[9642744]=(((b^i)&255^g^g>>>1)>>>6&2|g>>>8&1|(e<<24>>24==0?d|4:d)&255)&255;a[9642713]=e;return}function fFm(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;fGP();b=c[2426872]|0;d=b&65535;e=c[3528552]|0;f=c[2433426]|0;g=c[f+(e*3160|0)+60+((b>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[f+(e*3160|0)+3132>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(b&255)|0]|0}}while(0);b=a[9642713]|0;g=(b&255)-(i&255)|0;d=(g>>>4&8|a[9642744]&-16&255)&255;a[9642744]=(((b^i)&255^g^g>>>1)>>>6&2|g>>>8&1|((g&255)<<24>>24==0?d|4:d)&255)&255;return}function fFn(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;fGP();b=c[2426872]|0;d=b&65535;e=c[3528552]|0;f=c[2433426]|0;g=c[f+(e*3160|0)+60+((b>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[f+(e*3160|0)+3132>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(b&255)|0]|0}}while(0);b=a[9642713]|0;g=a[9642744]|0;d=(b&255)-(i&255)-(g&1)|0;e=(d>>>4&8|g&-16&255)&255;g=d&255;a[9642744]=((d^(b^i)&255^d>>>1)>>>6&2|d>>>8&1|(g<<24>>24==0?e|4:e)&255)&255;a[9642713]=g;return}function fFo(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;fGP();d=c[2426872]|0;f=d&65535;g=c[3528552]|0;h=c[2433426]|0;i=c[h+(g*3160|0)+60+((d>>>8&255)<<2)>>2]|0;do{if((i|0)==0){j=c[h+(g*3160|0)+3132>>2]|0;if((j|0)==0){k=0;l=g;m=h;break}n=gj[j&4095](f)|0;k=n;l=c[3528552]|0;m=c[2433426]|0}else{k=a[i+(d&255)|0]|0;l=g;m=h}}while(0);h=(k&255)<<8;k=d+1|0;d=k&65535;g=c[m+(l*3160|0)+60+((k>>>8&255)<<2)>>2]|0;do{if((g|0)==0){i=c[m+(l*3160|0)+3132>>2]|0;if((i|0)==0){o=0;break}o=gj[i&4095](d)|0}else{o=a[g+(k&255)|0]|0}}while(0);k=e[4821356]|0;g=k-(o&255|h)|0;o=(g>>>12&8|a[9642744]&-16&255)&255;d=g&65535;a[9642744]=((k^h^g^g>>>1)>>>14&2|g>>>16&1|(d<<16>>16==0?o|4:o)&255)&255;b[4821356]=d;return}function fFp(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;fGP();b=c[2426872]|0;d=b&65535;e=c[3528552]|0;f=c[2433426]|0;g=c[f+(e*3160|0)+60+((b>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[f+(e*3160|0)+3132>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(b&255)|0]|0}}while(0);b=a[9642713]&i;a[9642713]=b;i=(b&255)>>>4&8|a[9642744]&-15;a[9642744]=b<<24>>24==0?i|4:i;return}function fFq(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;fGP();b=a[9642713]|0;d=c[2426872]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3132>>2]|0;if((i|0)==0){j=0;break}j=gj[i&4095](e)|0}else{j=a[h+(d&255)|0]|0}}while(0);d=j&b;b=(d&255)>>>4&8|a[9642744]&-15;a[9642744]=d<<24>>24==0?b|4:b;return}function fFr(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;fGP();b=c[2426872]|0;d=b&65535;e=c[3528552]|0;f=c[2433426]|0;g=c[f+(e*3160|0)+60+((b>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[f+(e*3160|0)+3132>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(b&255)|0]|0}}while(0);a[9642713]=i;b=(i&255)>>>4&8|a[9642744]&-15;a[9642744]=i<<24>>24==0?b|4:b;return}function fFs(){var b=0,d=0,e=0,f=0,g=0;fGP();b=a[9642713]|0;d=(b&255)>>>4&8|a[9642744]&-15;a[9642744]=b<<24>>24==0?d|4:d;d=c[2426872]|0;e=c[3528552]|0;f=c[2433426]|0;g=c[f+(e*3160|0)+60+((d>>>8&255|256)<<2)>>2]|0;if((g|0)!=0){a[g+(d&255)|0]=b;return}g=c[f+(e*3160|0)+3136>>2]|0;if((g|0)==0){return}gg[g&4095](d&65535,b);return}function fFt(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;fGP();b=c[2426872]|0;d=b&65535;e=c[3528552]|0;f=c[2433426]|0;g=c[f+(e*3160|0)+60+((b>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[f+(e*3160|0)+3132>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(b&255)|0]|0}}while(0);b=a[9642713]|0;g=b^i;a[9642713]=g;d=(g&255)>>>4&8|a[9642744]&-15;a[9642744]=b<<24>>24==i<<24>>24?d|4:d;return}function fFu(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;fGP();b=c[2426872]|0;d=b&65535;e=c[3528552]|0;f=c[2433426]|0;g=c[f+(e*3160|0)+60+((b>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[f+(e*3160|0)+3132>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(b&255)|0]|0}}while(0);b=a[9642713]|0;g=a[9642744]|0;d=(b&255)+(i&255)+(g&1)|0;e=(d>>>4&8|g&-48&255)&255;g=d&255;f=d^(b^i)&255;a[9642744]=(f<<1&32|d>>>8&1|(f^d>>>1)>>>6&2|(g<<24>>24==0?e|4:e)&255)&255;a[9642713]=g;return}function fFv(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;fGP();b=c[2426872]|0;d=b&65535;e=c[3528552]|0;f=c[2433426]|0;g=c[f+(e*3160|0)+60+((b>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[f+(e*3160|0)+3132>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(b&255)|0]|0}}while(0);b=a[9642713]|i;a[9642713]=b;i=(b&255)>>>4&8|a[9642744]&-15;a[9642744]=b<<24>>24==0?i|4:i;return}function fFw(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;fGP();b=c[2426872]|0;d=b&65535;e=c[3528552]|0;f=c[2433426]|0;g=c[f+(e*3160|0)+60+((b>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[f+(e*3160|0)+3132>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(b&255)|0]|0}}while(0);b=a[9642713]|0;g=(b&255)+(i&255)|0;d=(g>>>4&8|a[9642744]&-48&255)&255;e=g&255;f=(b^i)&255^g;a[9642744]=(f<<1&32|g>>>8&1|(f^g>>>1)>>>6&2|(e<<24>>24==0?d|4:d)&255)&255;a[9642713]=e;return}function fFx(){var b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;fGP();b=c[2426872]|0;d=b&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((b>>>8&255)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3132>>2]|0;if((i|0)==0){j=0;k=f;l=g;break}m=gj[i&4095](d)|0;j=m;k=c[3528552]|0;l=c[2433426]|0}else{j=a[h+(b&255)|0]|0;k=f;l=g}}while(0);g=(j&255)<<8;j=b+1|0;b=j&65535;f=c[l+(k*3160|0)+60+((j>>>8&255)<<2)>>2]|0;do{if((f|0)==0){h=c[l+(k*3160|0)+3132>>2]|0;if((h|0)==0){n=0;break}n=gj[h&4095](b)|0}else{n=a[f+(j&255)|0]|0}}while(0);j=e[4821366]|0;f=j-(n&255|g)|0;n=(f>>>12&8|a[9642744]&-16&255)&255;a[9642744]=((j^g^f^f>>>1)>>>14&2|f>>>16&1|((f&65535)<<16>>16==0?n|4:n)&255)&255;return}function fFy(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;fGP();b[4821364]=(b[4821364]|0)-1&65535;d=c[2410682]|0;e=d&65535;f=a[9642704]|0;g=c[3528552]|0;h=c[2433426]|0;i=c[h+(g*3160|0)+60+((d>>>8&255|256)<<2)>>2]|0;do{if((i|0)==0){j=c[h+(g*3160|0)+3136>>2]|0;if((j|0)==0){k=g;l=h;break}gg[j&4095](e,f);k=c[3528552]|0;l=c[2433426]|0}else{a[i+(d&255)|0]=f;k=g;l=h}}while(0);b[4821364]=(b[4821364]|0)-1&65535;h=c[2410682]|0;g=a[9642705]|0;f=c[l+(k*3160|0)+60+((h>>>8&255|256)<<2)>>2]|0;if((f|0)!=0){a[f+(h&255)|0]=g;m=c[2426872]|0;c[2410676]=m;n=m&65535;b[4821352]=n;return}f=c[l+(k*3160|0)+3136>>2]|0;if((f|0)==0){m=c[2426872]|0;c[2410676]=m;n=m&65535;b[4821352]=n;return}gg[f&4095](h&65535,g);m=c[2426872]|0;c[2410676]=m;n=m&65535;b[4821352]=n;return}function fFz(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;fGP();d=c[2426872]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3132>>2]|0;if((i|0)==0){j=0;k=f;l=g;break}m=gj[i&4095](e)|0;j=m;k=c[3528552]|0;l=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=f;l=g}}while(0);g=(j&255)<<8;j=d+1|0;d=j&65535;f=c[l+(k*3160|0)+60+((j>>>8&255)<<2)>>2]|0;do{if((f|0)==0){h=c[l+(k*3160|0)+3132>>2]|0;if((h|0)==0){n=0;break}n=gj[h&4095](d)|0}else{n=a[f+(j&255)|0]|0}}while(0);j=n&255|g;b[4821366]=j;n=a[9642744]&-15;a[9642744]=n;f=n&255|(g&65535)>>>12&8;if(j<<16>>16!=0){o=f&255;a[9642744]=o;return}o=(f|4)&255;a[9642744]=o;return}function fFA(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;fGP();d=a[9642744]&-15;a[9642744]=d;e=b[4821366]|0;f=(e&65535)>>>12&8|d&255;if(e<<16>>16==0){g=(f|4)&255}else{g=f&255}a[9642744]=g;g=c[2426872]|0;f=g&65535;e=a[9642733]|0;d=c[3528552]|0;h=c[2433426]|0;i=c[h+(d*3160|0)+60+((g>>>8&255|256)<<2)>>2]|0;do{if((i|0)==0){j=c[h+(d*3160|0)+3136>>2]|0;if((j|0)==0){k=d;l=h;break}gg[j&4095](f,e);k=c[3528552]|0;l=c[2433426]|0}else{a[i+(g&255)|0]=e;k=d;l=h}}while(0);h=g+1|0;g=a[9642732]|0;d=c[l+(k*3160|0)+60+((h>>>8&255|256)<<2)>>2]|0;if((d|0)!=0){a[d+(h&255)|0]=g;return}d=c[l+(k*3160|0)+3136>>2]|0;if((d|0)==0){return}gg[d&4095](h&65535,g);return}function fFB(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=j&255;j=e<<8;g=k+1|0;k=g&65535;f=c[m+(l*3160|0)+60+((g>>>8&255|512)<<2)>>2]|0;do{if((f|0)==0){d=c[m+(l*3160|0)+3144>>2]|0;if((d|0)==0){p=0;q=n;r=l;s=m;break}h=gj[d&4095](k)|0;p=h;q=b[4821352]|0;r=c[3528552]|0;s=c[2433426]|0}else{p=a[f+(g&255)|0]|0;q=n;r=l;s=m}}while(0);m=p&255;p=m|j;c[2426872]=p;b[4821352]=q+2&65535;q=p&65535;p=c[s+(r*3160|0)+60+(e<<2)>>2]|0;do{if((p|0)==0){e=c[s+(r*3160|0)+3132>>2]|0;if((e|0)==0){t=0;break}t=gj[e&4095](q)|0}else{t=a[p+m|0]|0}}while(0);m=a[9642713]|0;p=(m&255)-(t&255)|0;q=(p>>>4&8|a[9642744]&-16&255)&255;r=p&255;a[9642744]=(((m^t)&255^p^p>>>1)>>>6&2|p>>>8&1|(r<<24>>24==0?q|4:q)&255)&255;a[9642713]=r;return}function fFC(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=j&255;j=e<<8;g=k+1|0;k=g&65535;f=c[m+(l*3160|0)+60+((g>>>8&255|512)<<2)>>2]|0;do{if((f|0)==0){d=c[m+(l*3160|0)+3144>>2]|0;if((d|0)==0){p=0;q=n;r=l;s=m;break}h=gj[d&4095](k)|0;p=h;q=b[4821352]|0;r=c[3528552]|0;s=c[2433426]|0}else{p=a[f+(g&255)|0]|0;q=n;r=l;s=m}}while(0);m=p&255;p=m|j;c[2426872]=p;b[4821352]=q+2&65535;q=p&65535;p=c[s+(r*3160|0)+60+(e<<2)>>2]|0;do{if((p|0)==0){e=c[s+(r*3160|0)+3132>>2]|0;if((e|0)==0){t=0;break}t=gj[e&4095](q)|0}else{t=a[p+m|0]|0}}while(0);m=a[9642713]|0;p=(m&255)-(t&255)|0;q=(p>>>4&8|a[9642744]&-16&255)&255;a[9642744]=(((m^t)&255^p^p>>>1)>>>6&2|p>>>8&1|((p&255)<<24>>24==0?q|4:q)&255)&255;return}function fFD(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=j&255;j=e<<8;g=k+1|0;k=g&65535;f=c[m+(l*3160|0)+60+((g>>>8&255|512)<<2)>>2]|0;do{if((f|0)==0){d=c[m+(l*3160|0)+3144>>2]|0;if((d|0)==0){p=0;q=n;r=l;s=m;break}h=gj[d&4095](k)|0;p=h;q=b[4821352]|0;r=c[3528552]|0;s=c[2433426]|0}else{p=a[f+(g&255)|0]|0;q=n;r=l;s=m}}while(0);m=p&255;p=m|j;c[2426872]=p;b[4821352]=q+2&65535;q=p&65535;p=c[s+(r*3160|0)+60+(e<<2)>>2]|0;do{if((p|0)==0){e=c[s+(r*3160|0)+3132>>2]|0;if((e|0)==0){t=0;break}t=gj[e&4095](q)|0}else{t=a[p+m|0]|0}}while(0);m=a[9642713]|0;p=a[9642744]|0;q=(m&255)-(t&255)-(p&1)|0;r=(q>>>4&8|p&-16&255)&255;p=q&255;a[9642744]=((q^(m^t)&255^q>>>1)>>>6&2|q>>>8&1|(p<<24>>24==0?r|4:r)&255)&255;a[9642713]=p;return}function fFE(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=c[2410676]|0;f=d&65535;g=c[3528552]|0;h=c[2433426]|0;i=c[h+(g*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((i|0)==0){j=c[h+(g*3160|0)+3144>>2]|0;if((j|0)==0){k=0;l=d;m=g;n=h;o=f;break}p=gj[j&4095](f)|0;j=c[2410676]|0;k=p;l=j;m=c[3528552]|0;n=c[2433426]|0;o=j&65535}else{k=a[i+(d&255)|0]|0;l=d;m=g;n=h;o=f}}while(0);f=k&255;k=f<<8;h=l+1|0;l=h&65535;g=c[n+(m*3160|0)+60+((h>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){d=c[n+(m*3160|0)+3144>>2]|0;if((d|0)==0){q=0;r=o;s=m;t=n;break}i=gj[d&4095](l)|0;q=i;r=b[4821352]|0;s=c[3528552]|0;t=c[2433426]|0}else{q=a[g+(h&255)|0]|0;r=o;s=m;t=n}}while(0);n=q&255;q=n|k;c[2426872]=q;b[4821352]=r+2&65535;r=q&65535;k=c[t+(s*3160|0)+60+(f<<2)>>2]|0;do{if((k|0)==0){f=c[t+(s*3160|0)+3132>>2]|0;if((f|0)==0){u=0;v=s;w=t;break}m=gj[f&4095](r)|0;u=m;v=c[3528552]|0;w=c[2433426]|0}else{u=a[k+n|0]|0;v=s;w=t}}while(0);t=(u&255)<<8;u=q+1|0;q=u&65535;s=c[w+(v*3160|0)+60+((u>>>8&255)<<2)>>2]|0;do{if((s|0)==0){n=c[w+(v*3160|0)+3132>>2]|0;if((n|0)==0){x=0;break}x=gj[n&4095](q)|0}else{x=a[s+(u&255)|0]|0}}while(0);u=e[4821356]|0;s=u-(x&255|t)|0;x=(s>>>12&8|a[9642744]&-16&255)&255;q=s&65535;a[9642744]=((u^t^s^s>>>1)>>>14&2|s>>>16&1|(q<<16>>16==0?x|4:x)&255)&255;b[4821356]=q;return}function fFF(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=j&255;j=e<<8;g=k+1|0;k=g&65535;f=c[m+(l*3160|0)+60+((g>>>8&255|512)<<2)>>2]|0;do{if((f|0)==0){d=c[m+(l*3160|0)+3144>>2]|0;if((d|0)==0){p=0;q=n;r=l;s=m;break}h=gj[d&4095](k)|0;p=h;q=b[4821352]|0;r=c[3528552]|0;s=c[2433426]|0}else{p=a[f+(g&255)|0]|0;q=n;r=l;s=m}}while(0);m=p&255;p=m|j;c[2426872]=p;b[4821352]=q+2&65535;q=p&65535;p=c[s+(r*3160|0)+60+(e<<2)>>2]|0;do{if((p|0)==0){e=c[s+(r*3160|0)+3132>>2]|0;if((e|0)==0){t=0;break}t=gj[e&4095](q)|0}else{t=a[p+m|0]|0}}while(0);m=a[9642713]&t;a[9642713]=m;t=(m&255)>>>4&8|a[9642744]&-15;a[9642744]=m<<24>>24==0?t|4:t;return}function fFG(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=j&255;j=e<<8;g=k+1|0;k=g&65535;f=c[m+(l*3160|0)+60+((g>>>8&255|512)<<2)>>2]|0;do{if((f|0)==0){d=c[m+(l*3160|0)+3144>>2]|0;if((d|0)==0){p=0;q=n;r=l;s=m;break}h=gj[d&4095](k)|0;p=h;q=b[4821352]|0;r=c[3528552]|0;s=c[2433426]|0}else{p=a[f+(g&255)|0]|0;q=n;r=l;s=m}}while(0);m=p&255;p=m|j;c[2426872]=p;b[4821352]=q+2&65535;q=p&65535;p=c[s+(r*3160|0)+60+(e<<2)>>2]|0;do{if((p|0)==0){e=c[s+(r*3160|0)+3132>>2]|0;if((e|0)==0){t=0;break}t=gj[e&4095](q)|0}else{t=a[p+m|0]|0}}while(0);m=a[9642713]&t;t=(m&255)>>>4&8|a[9642744]&-15;a[9642744]=m<<24>>24==0?t|4:t;return}function fFH(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=j&255;j=e<<8;g=k+1|0;k=g&65535;f=c[m+(l*3160|0)+60+((g>>>8&255|512)<<2)>>2]|0;do{if((f|0)==0){d=c[m+(l*3160|0)+3144>>2]|0;if((d|0)==0){p=0;q=n;r=l;s=m;break}h=gj[d&4095](k)|0;p=h;q=b[4821352]|0;r=c[3528552]|0;s=c[2433426]|0}else{p=a[f+(g&255)|0]|0;q=n;r=l;s=m}}while(0);m=p&255;p=m|j;c[2426872]=p;b[4821352]=q+2&65535;q=p&65535;p=c[s+(r*3160|0)+60+(e<<2)>>2]|0;do{if((p|0)==0){e=c[s+(r*3160|0)+3132>>2]|0;if((e|0)==0){t=0;break}t=gj[e&4095](q)|0}else{t=a[p+m|0]|0}}while(0);a[9642713]=t;m=(t&255)>>>4&8|a[9642744]&-15;a[9642744]=t<<24>>24==0?m|4:m;return}function fFI(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=a[9642713]|0;e=(d&255)>>>4&8|a[9642744]&-15;a[9642744]=d<<24>>24==0?e|4:e;e=c[2410676]|0;d=e&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((e>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;l=f;m=g;n=d;break}o=gj[i&4095](d)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(e&255)|0]|0;k=e;l=f;m=g;n=d}}while(0);d=j&255;j=d<<8;g=k+1|0;k=g&65535;f=c[m+(l*3160|0)+60+((g>>>8&255|512)<<2)>>2]|0;do{if((f|0)==0){e=c[m+(l*3160|0)+3144>>2]|0;if((e|0)==0){p=0;q=n;r=l;s=m;break}h=gj[e&4095](k)|0;p=h;q=b[4821352]|0;r=c[3528552]|0;s=c[2433426]|0}else{p=a[f+(g&255)|0]|0;q=n;r=l;s=m}}while(0);m=p&255;p=m|j;c[2426872]=p;b[4821352]=q+2&65535;q=a[9642713]|0;j=c[s+(r*3160|0)+60+((d|256)<<2)>>2]|0;if((j|0)!=0){a[j+m|0]=q;return}m=c[s+(r*3160|0)+3136>>2]|0;if((m|0)==0){return}gg[m&4095](p&65535,q);return}function fFJ(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=j&255;j=e<<8;g=k+1|0;k=g&65535;f=c[m+(l*3160|0)+60+((g>>>8&255|512)<<2)>>2]|0;do{if((f|0)==0){d=c[m+(l*3160|0)+3144>>2]|0;if((d|0)==0){p=0;q=n;r=l;s=m;break}h=gj[d&4095](k)|0;p=h;q=b[4821352]|0;r=c[3528552]|0;s=c[2433426]|0}else{p=a[f+(g&255)|0]|0;q=n;r=l;s=m}}while(0);m=p&255;p=m|j;c[2426872]=p;b[4821352]=q+2&65535;q=p&65535;p=c[s+(r*3160|0)+60+(e<<2)>>2]|0;do{if((p|0)==0){e=c[s+(r*3160|0)+3132>>2]|0;if((e|0)==0){t=0;break}t=gj[e&4095](q)|0}else{t=a[p+m|0]|0}}while(0);m=a[9642713]|0;p=m^t;a[9642713]=p;q=(p&255)>>>4&8|a[9642744]&-15;a[9642744]=m<<24>>24==t<<24>>24?q|4:q;return}function fFK(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=j&255;j=e<<8;g=k+1|0;k=g&65535;f=c[m+(l*3160|0)+60+((g>>>8&255|512)<<2)>>2]|0;do{if((f|0)==0){d=c[m+(l*3160|0)+3144>>2]|0;if((d|0)==0){p=0;q=n;r=l;s=m;break}h=gj[d&4095](k)|0;p=h;q=b[4821352]|0;r=c[3528552]|0;s=c[2433426]|0}else{p=a[f+(g&255)|0]|0;q=n;r=l;s=m}}while(0);m=p&255;p=m|j;c[2426872]=p;b[4821352]=q+2&65535;q=p&65535;p=c[s+(r*3160|0)+60+(e<<2)>>2]|0;do{if((p|0)==0){e=c[s+(r*3160|0)+3132>>2]|0;if((e|0)==0){t=0;break}t=gj[e&4095](q)|0}else{t=a[p+m|0]|0}}while(0);m=a[9642713]|0;p=a[9642744]|0;q=(m&255)+(t&255)+(p&1)|0;r=(q>>>4&8|p&-48&255)&255;p=q&255;s=q^(m^t)&255;a[9642744]=(s<<1&32|q>>>8&1|(s^q>>>1)>>>6&2|(p<<24>>24==0?r|4:r)&255)&255;a[9642713]=p;return}function fFL(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=j&255;j=e<<8;g=k+1|0;k=g&65535;f=c[m+(l*3160|0)+60+((g>>>8&255|512)<<2)>>2]|0;do{if((f|0)==0){d=c[m+(l*3160|0)+3144>>2]|0;if((d|0)==0){p=0;q=n;r=l;s=m;break}h=gj[d&4095](k)|0;p=h;q=b[4821352]|0;r=c[3528552]|0;s=c[2433426]|0}else{p=a[f+(g&255)|0]|0;q=n;r=l;s=m}}while(0);m=p&255;p=m|j;c[2426872]=p;b[4821352]=q+2&65535;q=p&65535;p=c[s+(r*3160|0)+60+(e<<2)>>2]|0;do{if((p|0)==0){e=c[s+(r*3160|0)+3132>>2]|0;if((e|0)==0){t=0;break}t=gj[e&4095](q)|0}else{t=a[p+m|0]|0}}while(0);m=a[9642713]|t;a[9642713]=m;t=(m&255)>>>4&8|a[9642744]&-15;a[9642744]=m<<24>>24==0?t|4:t;return}function fFM(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=j&255;j=e<<8;g=k+1|0;k=g&65535;f=c[m+(l*3160|0)+60+((g>>>8&255|512)<<2)>>2]|0;do{if((f|0)==0){d=c[m+(l*3160|0)+3144>>2]|0;if((d|0)==0){p=0;q=n;r=l;s=m;break}h=gj[d&4095](k)|0;p=h;q=b[4821352]|0;r=c[3528552]|0;s=c[2433426]|0}else{p=a[f+(g&255)|0]|0;q=n;r=l;s=m}}while(0);m=p&255;p=m|j;c[2426872]=p;b[4821352]=q+2&65535;q=p&65535;p=c[s+(r*3160|0)+60+(e<<2)>>2]|0;do{if((p|0)==0){e=c[s+(r*3160|0)+3132>>2]|0;if((e|0)==0){t=0;break}t=gj[e&4095](q)|0}else{t=a[p+m|0]|0}}while(0);m=a[9642713]|0;p=(m&255)+(t&255)|0;q=(p>>>4&8|a[9642744]&-48&255)&255;r=p&255;s=(m^t)&255^p;a[9642744]=(s<<1&32|p>>>8&1|(s^p>>>1)>>>6&2|(r<<24>>24==0?q|4:q)&255)&255;a[9642713]=r;return}function fFN(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=c[2410676]|0;f=d&65535;g=c[3528552]|0;h=c[2433426]|0;i=c[h+(g*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((i|0)==0){j=c[h+(g*3160|0)+3144>>2]|0;if((j|0)==0){k=0;l=d;m=g;n=h;o=f;break}p=gj[j&4095](f)|0;j=c[2410676]|0;k=p;l=j;m=c[3528552]|0;n=c[2433426]|0;o=j&65535}else{k=a[i+(d&255)|0]|0;l=d;m=g;n=h;o=f}}while(0);f=k&255;k=f<<8;h=l+1|0;l=h&65535;g=c[n+(m*3160|0)+60+((h>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){d=c[n+(m*3160|0)+3144>>2]|0;if((d|0)==0){q=0;r=o;s=m;t=n;break}i=gj[d&4095](l)|0;q=i;r=b[4821352]|0;s=c[3528552]|0;t=c[2433426]|0}else{q=a[g+(h&255)|0]|0;r=o;s=m;t=n}}while(0);n=q&255;q=n|k;c[2426872]=q;b[4821352]=r+2&65535;r=q&65535;k=c[t+(s*3160|0)+60+(f<<2)>>2]|0;do{if((k|0)==0){f=c[t+(s*3160|0)+3132>>2]|0;if((f|0)==0){u=0;v=s;w=t;break}m=gj[f&4095](r)|0;u=m;v=c[3528552]|0;w=c[2433426]|0}else{u=a[k+n|0]|0;v=s;w=t}}while(0);t=(u&255)<<8;u=q+1|0;q=u&65535;s=c[w+(v*3160|0)+60+((u>>>8&255)<<2)>>2]|0;do{if((s|0)==0){n=c[w+(v*3160|0)+3132>>2]|0;if((n|0)==0){x=0;break}x=gj[n&4095](q)|0}else{x=a[s+(u&255)|0]|0}}while(0);u=e[4821366]|0;s=u-(x&255|t)|0;x=(s>>>12&8|a[9642744]&-16&255)&255;a[9642744]=((u^t^s^s>>>1)>>>14&2|s>>>16&1|((s&65535)<<16>>16==0?x|4:x)&255)&255;return}function fFO(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=(j&255)<<8;j=k+1|0;k=j&65535;g=c[m+(l*3160|0)+60+((j>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){f=c[m+(l*3160|0)+3144>>2]|0;if((f|0)==0){p=0;q=n;r=l;s=m;break}d=gj[f&4095](k)|0;p=d;q=b[4821352]|0;r=c[3528552]|0;s=c[2433426]|0}else{p=a[g+(j&255)|0]|0;q=n;r=l;s=m}}while(0);c[2426872]=p&255|e;e=q+2&65535;b[4821352]=e;b[4821364]=(b[4821364]|0)-1&65535;q=c[2410682]|0;p=q&65535;m=e&255;e=c[s+(r*3160|0)+60+((q>>>8&255|256)<<2)>>2]|0;do{if((e|0)==0){l=c[s+(r*3160|0)+3136>>2]|0;if((l|0)==0){t=r;u=s;break}gg[l&4095](p,m);t=c[3528552]|0;u=c[2433426]|0}else{a[e+(q&255)|0]=m;t=r;u=s}}while(0);b[4821364]=(b[4821364]|0)-1&65535;s=c[2410682]|0;r=a[9642705]|0;m=c[u+(t*3160|0)+60+((s>>>8&255|256)<<2)>>2]|0;if((m|0)!=0){a[m+(s&255)|0]=r;v=c[2426872]|0;c[2410676]=v;w=v&65535;b[4821352]=w;return}m=c[u+(t*3160|0)+3136>>2]|0;if((m|0)==0){v=c[2426872]|0;c[2410676]=v;w=v&65535;b[4821352]=w;return}gg[m&4095](s&65535,r);v=c[2426872]|0;c[2410676]=v;w=v&65535;b[4821352]=w;return}function fFP(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=j&255;j=e<<8;g=k+1|0;k=g&65535;f=c[m+(l*3160|0)+60+((g>>>8&255|512)<<2)>>2]|0;do{if((f|0)==0){d=c[m+(l*3160|0)+3144>>2]|0;if((d|0)==0){p=0;q=n;r=l;s=m;break}h=gj[d&4095](k)|0;p=h;q=b[4821352]|0;r=c[3528552]|0;s=c[2433426]|0}else{p=a[f+(g&255)|0]|0;q=n;r=l;s=m}}while(0);m=p&255;p=m|j;c[2426872]=p;b[4821352]=q+2&65535;q=p&65535;j=c[s+(r*3160|0)+60+(e<<2)>>2]|0;do{if((j|0)==0){e=c[s+(r*3160|0)+3132>>2]|0;if((e|0)==0){t=0;u=r;v=s;break}l=gj[e&4095](q)|0;t=l;u=c[3528552]|0;v=c[2433426]|0}else{t=a[j+m|0]|0;u=r;v=s}}while(0);s=t&255;t=s<<8;r=p+1|0;p=r&65535;m=c[v+(u*3160|0)+60+((r>>>8&255)<<2)>>2]|0;do{if((m|0)==0){j=c[v+(u*3160|0)+3132>>2]|0;if((j|0)==0){w=0;break}w=gj[j&4095](p)|0}else{w=a[m+(r&255)|0]|0}}while(0);r=w&255|t;c[2410683]=r;t=a[9642744]&-15;a[9642744]=t;w=t&255|s>>>4&8;if((r|0)!=0){x=w&255;a[9642744]=x;return}x=(w|4)&255;a[9642744]=x;return}function fFQ(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;d=a[9642744]&-15;a[9642744]=d;e=b[4821366]|0;f=(e&65535)>>>12&8|d&255;if(e<<16>>16==0){g=(f|4)&255}else{g=f&255}a[9642744]=g;g=c[2410676]|0;f=g&65535;e=c[3528552]|0;d=c[2433426]|0;h=c[d+(e*3160|0)+60+((g>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[d+(e*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=g;l=e;m=d;n=f;break}o=gj[i&4095](f)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(g&255)|0]|0;k=g;l=e;m=d;n=f}}while(0);f=j&255;j=f<<8;d=k+1|0;k=d&65535;e=c[m+(l*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((e|0)==0){g=c[m+(l*3160|0)+3144>>2]|0;if((g|0)==0){p=0;q=n;r=l;s=m;break}h=gj[g&4095](k)|0;p=h;q=b[4821352]|0;r=c[3528552]|0;s=c[2433426]|0}else{p=a[e+(d&255)|0]|0;q=n;r=l;s=m}}while(0);m=p&255;p=m|j;c[2426872]=p;b[4821352]=q+2&65535;q=p&65535;j=a[9642733]|0;l=c[s+(r*3160|0)+60+((f|256)<<2)>>2]|0;do{if((l|0)==0){f=c[s+(r*3160|0)+3136>>2]|0;if((f|0)==0){t=r;u=s;break}gg[f&4095](q,j);t=c[3528552]|0;u=c[2433426]|0}else{a[l+m|0]=j;t=r;u=s}}while(0);s=p+1|0;p=a[9642732]|0;r=c[u+(t*3160|0)+60+((s>>>8&255|256)<<2)>>2]|0;if((r|0)!=0){a[r+(s&255)|0]=p;return}r=c[u+(t*3160|0)+3136>>2]|0;if((r|0)==0){return}gg[r&4095](s&65535,p);return}function fFR(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;break}l=gj[i&4095](e)|0;j=l;k=b[4821352]|0}else{j=a[h+(d&255)|0]|0;k=e}}while(0);b[4821352]=k+1&65535;k=a[9642712]|0;e=(k&255)-(j&255)|0;d=(e>>>4&8|a[9642744]&-16&255)&255;h=e&255;a[9642744]=(((k^j)&255^e^e>>>1)>>>6&2|e>>>8&1|(h<<24>>24==0?d|4:d)&255)&255;a[9642712]=h;return}function fFS(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;break}l=gj[i&4095](e)|0;j=l;k=b[4821352]|0}else{j=a[h+(d&255)|0]|0;k=e}}while(0);b[4821352]=k+1&65535;k=a[9642712]|0;e=(k&255)-(j&255)|0;d=(e>>>4&8|a[9642744]&-16&255)&255;a[9642744]=(((k^j)&255^e^e>>>1)>>>6&2|e>>>8&1|((e&255)<<24>>24==0?d|4:d)&255)&255;return}function fFT(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;break}l=gj[i&4095](e)|0;j=l;k=b[4821352]|0}else{j=a[h+(d&255)|0]|0;k=e}}while(0);b[4821352]=k+1&65535;k=a[9642712]|0;e=a[9642744]|0;d=(k&255)-(j&255)-(e&1)|0;h=(d>>>4&8|e&-16&255)&255;e=d&255;a[9642744]=((d^(k^j)&255^d>>>1)>>>6&2|d>>>8&1|(e<<24>>24==0?h|4:h)&255)&255;a[9642712]=e;return}function fFU(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=c[2410676]|0;f=d&65535;g=c[3528552]|0;h=c[2433426]|0;i=c[h+(g*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((i|0)==0){j=c[h+(g*3160|0)+3144>>2]|0;if((j|0)==0){k=0;l=d;m=g;n=h;o=f;break}p=gj[j&4095](f)|0;j=c[2410676]|0;k=p;l=j;m=c[3528552]|0;n=c[2433426]|0;o=j&65535}else{k=a[i+(d&255)|0]|0;l=d;m=g;n=h;o=f}}while(0);f=(k&255)<<8;k=l+1|0;l=k&65535;h=c[n+(m*3160|0)+60+((k>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){g=c[n+(m*3160|0)+3144>>2]|0;if((g|0)==0){q=0;r=o;break}d=gj[g&4095](l)|0;q=d;r=b[4821352]|0}else{q=a[h+(k&255)|0]|0;r=o}}while(0);b[4821352]=r+2&65535;r=e[4821356]|0;o=r+(q&255|f)|0;q=(o>>>12&8|a[9642744]&-16&255)&255;k=o&65535;a[9642744]=((r^f^o^o>>>1)>>>14&2|o>>>16&1|(k<<16>>16==0?q|4:q)&255)&255;b[4821356]=k;return}function fFV(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;break}l=gj[i&4095](e)|0;j=l;k=b[4821352]|0}else{j=a[h+(d&255)|0]|0;k=e}}while(0);b[4821352]=k+1&65535;k=a[9642712]&j;a[9642712]=k;j=(k&255)>>>4&8|a[9642744]&-15;a[9642744]=k<<24>>24==0?j|4:j;return}function fFW(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;break}l=gj[i&4095](e)|0;j=l;k=b[4821352]|0}else{j=a[h+(d&255)|0]|0;k=e}}while(0);b[4821352]=k+1&65535;k=a[9642712]&j;j=(k&255)>>>4&8|a[9642744]&-15;a[9642744]=k<<24>>24==0?j|4:j;return}function fFX(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;break}l=gj[i&4095](e)|0;j=l;k=b[4821352]|0}else{j=a[h+(d&255)|0]|0;k=e}}while(0);a[9642712]=j;b[4821352]=k+1&65535;k=a[9642744]&-15|(j&255)>>>4&8;a[9642744]=j<<24>>24==0?k|4:k;return}function fFY(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;break}l=gj[i&4095](e)|0;j=l;k=b[4821352]|0}else{j=a[h+(d&255)|0]|0;k=e}}while(0);b[4821352]=k+1&65535;k=a[9642712]|0;e=k^j;a[9642712]=e;d=(e&255)>>>4&8|a[9642744]&-15;a[9642744]=k<<24>>24==j<<24>>24?d|4:d;return}function fFZ(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;break}l=gj[i&4095](e)|0;j=l;k=b[4821352]|0}else{j=a[h+(d&255)|0]|0;k=e}}while(0);b[4821352]=k+1&65535;k=a[9642712]|0;e=a[9642744]|0;d=(k&255)+(j&255)+(e&1)|0;h=(d>>>4&8|e&-48&255)&255;e=d&255;f=d^(k^j)&255;a[9642744]=(f<<1&32|d>>>8&1|(f^d>>>1)>>>6&2|(e<<24>>24==0?h|4:h)&255)&255;a[9642712]=e;return}function fF_(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;break}l=gj[i&4095](e)|0;j=l;k=b[4821352]|0}else{j=a[h+(d&255)|0]|0;k=e}}while(0);b[4821352]=k+1&65535;k=a[9642712]|j;a[9642712]=k;j=(k&255)>>>4&8|a[9642744]&-15;a[9642744]=k<<24>>24==0?j|4:j;return}function fF$(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;break}l=gj[i&4095](e)|0;j=l;k=b[4821352]|0}else{j=a[h+(d&255)|0]|0;k=e}}while(0);b[4821352]=k+1&65535;k=a[9642712]|0;e=(k&255)+(j&255)|0;d=(e>>>4&8|a[9642744]&-48&255)&255;h=e&255;f=(k^j)&255^e;a[9642744]=(f<<1&32|e>>>8&1|(f^e>>>1)>>>6&2|(h<<24>>24==0?d|4:d)&255)&255;a[9642712]=h;return}function fF0(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=(j&255)<<8;j=k+1|0;k=j&65535;g=c[m+(l*3160|0)+60+((j>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){f=c[m+(l*3160|0)+3144>>2]|0;if((f|0)==0){p=0;q=n;break}d=gj[f&4095](k)|0;p=d;q=b[4821352]|0}else{p=a[g+(j&255)|0]|0;q=n}}while(0);n=p&255|e;b[4821352]=q+2&65535;b[4821356]=n;q=a[9642744]&-15;a[9642744]=q;p=q&255|(e&65535)>>>12&8;if(n<<16>>16!=0){r=p&255;a[9642744]=r;return}r=(p|4)&255;a[9642744]=r;return}function fF1(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=(j&255)<<24;g=k+1|0;f=g&65535;d=c[m+(l*3160|0)+60+((g>>>8&255|512)<<2)>>2]|0;do{if((d|0)==0){h=c[m+(l*3160|0)+3144>>2]|0;if((h|0)==0){p=0;q=k;r=l;s=m;t=n;break}i=gj[h&4095](f)|0;h=c[2410676]|0;p=i;q=h;r=c[3528552]|0;s=c[2433426]|0;t=h&65535}else{p=a[d+(g&255)|0]|0;q=k;r=l;s=m;t=n}}while(0);n=(p&255)<<16|e;e=q+2|0;p=e&65535;m=c[s+(r*3160|0)+60+((e>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){l=c[s+(r*3160|0)+3144>>2]|0;if((l|0)==0){u=0;v=q;w=r;x=s;y=t;break}k=gj[l&4095](p)|0;l=c[2410676]|0;u=k;v=l;w=c[3528552]|0;x=c[2433426]|0;y=l&65535}else{u=a[m+(e&255)|0]|0;v=q;w=r;x=s;y=t}}while(0);t=(u&255)<<8|n;u=v+3|0;v=u&65535;s=c[x+(w*3160|0)+60+((u>>>8&255|512)<<2)>>2]|0;do{if((s|0)==0){r=c[x+(w*3160|0)+3144>>2]|0;if((r|0)==0){z=0;A=y;break}q=gj[r&4095](v)|0;z=q;A=b[4821352]|0}else{z=a[s+(u&255)|0]|0;A=y}}while(0);y=t|z&255;b[4821352]=A+4&65535;b[4821356]=n>>>16&65535;b[4821358]=y&65535;A=a[9642744]&-15|(j&255)>>>4&8;a[9642744]=(y&65535|n|0)==0?A|4:A;return}function fF2(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=j&255;j=e<<8;g=k+1|0;k=g&65535;f=c[m+(l*3160|0)+60+((g>>>8&255|512)<<2)>>2]|0;do{if((f|0)==0){d=c[m+(l*3160|0)+3144>>2]|0;if((d|0)==0){p=0;q=n;break}h=gj[d&4095](k)|0;p=h;q=b[4821352]|0}else{p=a[f+(g&255)|0]|0;q=n}}while(0);n=p&255|j;c[2410681]=n;b[4821352]=q+2&65535;q=a[9642744]&-15;a[9642744]=q;j=q&255|e>>>4&8;if((n|0)!=0){r=j&255;a[9642744]=r;return}r=(j|4)&255;a[9642744]=r;return}function fF3(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c[2426872]=c[2410680];d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;l=f;m=g;break}n=gj[i&4095](e)|0;j=n;k=b[4821352]|0;l=c[3528552]|0;m=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=e;l=f;m=g}}while(0);a[9707488]=j;b[4821352]=k+1&65535;k=c[2426872]|0;j=k&65535;g=c[m+(l*3160|0)+60+((k>>>8&255)<<2)>>2]|0;do{if((g|0)==0){f=c[m+(l*3160|0)+3132>>2]|0;if((f|0)==0){o=0;break}o=gj[f&4095](j)|0}else{o=a[g+(k&255)|0]|0}}while(0);k=a[9642712]|0;g=(k&255)-(o&255)|0;j=(g>>>4&8|a[9642744]&-16&255)&255;l=g&255;a[9642744]=(((k^o)&255^g^g>>>1)>>>6&2|g>>>8&1|(l<<24>>24==0?j|4:j)&255)&255;a[9642712]=l;return}function fF4(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c[2426872]=c[2410680];d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;l=f;m=g;break}n=gj[i&4095](e)|0;j=n;k=b[4821352]|0;l=c[3528552]|0;m=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=e;l=f;m=g}}while(0);a[9707488]=j;b[4821352]=k+1&65535;k=c[2426872]|0;j=k&65535;g=c[m+(l*3160|0)+60+((k>>>8&255)<<2)>>2]|0;do{if((g|0)==0){f=c[m+(l*3160|0)+3132>>2]|0;if((f|0)==0){o=0;break}o=gj[f&4095](j)|0}else{o=a[g+(k&255)|0]|0}}while(0);k=a[9642712]|0;g=(k&255)-(o&255)|0;j=(g>>>4&8|a[9642744]&-16&255)&255;a[9642744]=(((k^o)&255^g^g>>>1)>>>6&2|g>>>8&1|((g&255)<<24>>24==0?j|4:j)&255)&255;return}function fF5(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c[2426872]=c[2410680];d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;l=f;m=g;break}n=gj[i&4095](e)|0;j=n;k=b[4821352]|0;l=c[3528552]|0;m=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=e;l=f;m=g}}while(0);a[9707488]=j;b[4821352]=k+1&65535;k=c[2426872]|0;j=k&65535;g=c[m+(l*3160|0)+60+((k>>>8&255)<<2)>>2]|0;do{if((g|0)==0){f=c[m+(l*3160|0)+3132>>2]|0;if((f|0)==0){o=0;break}o=gj[f&4095](j)|0}else{o=a[g+(k&255)|0]|0}}while(0);k=a[9642712]|0;g=a[9642744]|0;j=(k&255)-(o&255)-(g&1)|0;l=(j>>>4&8|g&-16&255)&255;g=j&255;a[9642744]=((j^(k^o)&255^j>>>1)>>>6&2|j>>>8&1|(g<<24>>24==0?l|4:l)&255)&255;a[9642712]=g;return}function fF6(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;c[2426872]=c[2410680];d=c[2410676]|0;f=d&65535;g=c[3528552]|0;h=c[2433426]|0;i=c[h+(g*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((i|0)==0){j=c[h+(g*3160|0)+3144>>2]|0;if((j|0)==0){k=0;l=f;m=g;n=h;break}o=gj[j&4095](f)|0;k=o;l=b[4821352]|0;m=c[3528552]|0;n=c[2433426]|0}else{k=a[i+(d&255)|0]|0;l=f;m=g;n=h}}while(0);a[9707488]=k;b[4821352]=l+1&65535;l=c[2426872]|0;k=l&65535;h=c[n+(m*3160|0)+60+((l>>>8&255)<<2)>>2]|0;do{if((h|0)==0){g=c[n+(m*3160|0)+3132>>2]|0;if((g|0)==0){p=0;q=m;r=n;break}f=gj[g&4095](k)|0;p=f;q=c[3528552]|0;r=c[2433426]|0}else{p=a[h+(l&255)|0]|0;q=m;r=n}}while(0);n=(p&255)<<8;p=l+1|0;l=p&65535;m=c[r+(q*3160|0)+60+((p>>>8&255)<<2)>>2]|0;do{if((m|0)==0){h=c[r+(q*3160|0)+3132>>2]|0;if((h|0)==0){s=0;break}s=gj[h&4095](l)|0}else{s=a[m+(p&255)|0]|0}}while(0);p=e[4821356]|0;m=p+(s&255|n)|0;s=(m>>>12&8|a[9642744]&-16&255)&255;l=m&65535;a[9642744]=((p^n^m^m>>>1)>>>14&2|m>>>16&1|(l<<16>>16==0?s|4:s)&255)&255;b[4821356]=l;return}function fF7(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c[2426872]=c[2410680];d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;l=f;m=g;break}n=gj[i&4095](e)|0;j=n;k=b[4821352]|0;l=c[3528552]|0;m=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=e;l=f;m=g}}while(0);a[9707488]=j;b[4821352]=k+1&65535;k=c[2426872]|0;j=k&65535;g=c[m+(l*3160|0)+60+((k>>>8&255)<<2)>>2]|0;do{if((g|0)==0){f=c[m+(l*3160|0)+3132>>2]|0;if((f|0)==0){o=0;break}o=gj[f&4095](j)|0}else{o=a[g+(k&255)|0]|0}}while(0);k=a[9642712]&o;a[9642712]=k;o=(k&255)>>>4&8|a[9642744]&-15;a[9642744]=k<<24>>24==0?o|4:o;return}function fF8(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c[2426872]=c[2410680];d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;l=f;m=g;break}n=gj[i&4095](e)|0;j=n;k=b[4821352]|0;l=c[3528552]|0;m=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=e;l=f;m=g}}while(0);a[9707488]=j;b[4821352]=k+1&65535;k=c[2426872]|0;j=k&65535;g=c[m+(l*3160|0)+60+((k>>>8&255)<<2)>>2]|0;do{if((g|0)==0){f=c[m+(l*3160|0)+3132>>2]|0;if((f|0)==0){o=0;break}o=gj[f&4095](j)|0}else{o=a[g+(k&255)|0]|0}}while(0);k=a[9642712]&o;o=(k&255)>>>4&8|a[9642744]&-15;a[9642744]=k<<24>>24==0?o|4:o;return}function fF9(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c[2426872]=c[2410680];d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;l=f;m=g;break}n=gj[i&4095](e)|0;j=n;k=b[4821352]|0;l=c[3528552]|0;m=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=e;l=f;m=g}}while(0);a[9707488]=j;b[4821352]=k+1&65535;k=c[2426872]|0;j=k&65535;g=c[m+(l*3160|0)+60+((k>>>8&255)<<2)>>2]|0;do{if((g|0)==0){f=c[m+(l*3160|0)+3132>>2]|0;if((f|0)==0){o=0;break}o=gj[f&4095](j)|0}else{o=a[g+(k&255)|0]|0}}while(0);a[9642712]=o;k=(o&255)>>>4&8|a[9642744]&-15;a[9642744]=o<<24>>24==0?k|4:k;return}function fGa(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=a[9642712]|0;e=(d&255)>>>4&8|a[9642744]&-15;a[9642744]=d<<24>>24==0?e|4:e;c[2426872]=c[2410680];e=c[2410676]|0;f=e&65535;g=c[3528552]|0;h=c[2433426]|0;i=c[h+(g*3160|0)+60+((e>>>8&255|512)<<2)>>2]|0;do{if((i|0)==0){j=c[h+(g*3160|0)+3144>>2]|0;if((j|0)==0){k=0;l=f;m=d;n=g;o=h;break}p=gj[j&4095](f)|0;k=p;l=b[4821352]|0;m=a[9642712]|0;n=c[3528552]|0;o=c[2433426]|0}else{k=a[i+(e&255)|0]|0;l=f;m=d;n=g;o=h}}while(0);a[9707488]=k;b[4821352]=l+1&65535;l=c[2426872]|0;k=c[o+(n*3160|0)+60+((l>>>8&255|256)<<2)>>2]|0;if((k|0)!=0){a[k+(l&255)|0]=m;return}k=c[o+(n*3160|0)+3136>>2]|0;if((k|0)==0){return}gg[k&4095](l&65535,m);return}function fGb(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c[2426872]=c[2410680];d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;l=f;m=g;break}n=gj[i&4095](e)|0;j=n;k=b[4821352]|0;l=c[3528552]|0;m=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=e;l=f;m=g}}while(0);a[9707488]=j;b[4821352]=k+1&65535;k=c[2426872]|0;j=k&65535;g=c[m+(l*3160|0)+60+((k>>>8&255)<<2)>>2]|0;do{if((g|0)==0){f=c[m+(l*3160|0)+3132>>2]|0;if((f|0)==0){o=0;break}o=gj[f&4095](j)|0}else{o=a[g+(k&255)|0]|0}}while(0);k=a[9642712]|0;g=k^o;a[9642712]=g;j=(g&255)>>>4&8|a[9642744]&-15;a[9642744]=k<<24>>24==o<<24>>24?j|4:j;return}function fGc(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c[2426872]=c[2410680];d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;l=f;m=g;break}n=gj[i&4095](e)|0;j=n;k=b[4821352]|0;l=c[3528552]|0;m=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=e;l=f;m=g}}while(0);a[9707488]=j;b[4821352]=k+1&65535;k=c[2426872]|0;j=k&65535;g=c[m+(l*3160|0)+60+((k>>>8&255)<<2)>>2]|0;do{if((g|0)==0){f=c[m+(l*3160|0)+3132>>2]|0;if((f|0)==0){o=0;break}o=gj[f&4095](j)|0}else{o=a[g+(k&255)|0]|0}}while(0);k=a[9642712]|0;g=a[9642744]|0;j=(k&255)+(o&255)+(g&1)|0;l=(j>>>4&8|g&-48&255)&255;g=j&255;m=j^(k^o)&255;a[9642744]=(m<<1&32|j>>>8&1|(m^j>>>1)>>>6&2|(g<<24>>24==0?l|4:l)&255)&255;a[9642712]=g;return}function fGd(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c[2426872]=c[2410680];d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;l=f;m=g;break}n=gj[i&4095](e)|0;j=n;k=b[4821352]|0;l=c[3528552]|0;m=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=e;l=f;m=g}}while(0);a[9707488]=j;b[4821352]=k+1&65535;k=c[2426872]|0;j=k&65535;g=c[m+(l*3160|0)+60+((k>>>8&255)<<2)>>2]|0;do{if((g|0)==0){f=c[m+(l*3160|0)+3132>>2]|0;if((f|0)==0){o=0;break}o=gj[f&4095](j)|0}else{o=a[g+(k&255)|0]|0}}while(0);k=a[9642712]|o;a[9642712]=k;o=(k&255)>>>4&8|a[9642744]&-15;a[9642744]=k<<24>>24==0?o|4:o;return}function fGe(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c[2426872]=c[2410680];d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;l=f;m=g;break}n=gj[i&4095](e)|0;j=n;k=b[4821352]|0;l=c[3528552]|0;m=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=e;l=f;m=g}}while(0);a[9707488]=j;b[4821352]=k+1&65535;k=c[2426872]|0;j=k&65535;g=c[m+(l*3160|0)+60+((k>>>8&255)<<2)>>2]|0;do{if((g|0)==0){f=c[m+(l*3160|0)+3132>>2]|0;if((f|0)==0){o=0;break}o=gj[f&4095](j)|0}else{o=a[g+(k&255)|0]|0}}while(0);k=a[9642712]|0;g=(k&255)+(o&255)|0;j=(g>>>4&8|a[9642744]&-48&255)&255;l=g&255;m=(k^o)&255^g;a[9642744]=(m<<1&32|g>>>8&1|(m^g>>>1)>>>6&2|(l<<24>>24==0?j|4:j)&255)&255;a[9642712]=l;return}function fGf(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;c[2426872]=c[2410680];d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;l=f;m=g;break}n=gj[i&4095](e)|0;j=n;k=b[4821352]|0;l=c[3528552]|0;m=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=e;l=f;m=g}}while(0);a[9707488]=j;b[4821352]=k+1&65535;k=c[2426872]|0;j=k&65535;g=c[m+(l*3160|0)+60+((k>>>8&255)<<2)>>2]|0;do{if((g|0)==0){f=c[m+(l*3160|0)+3132>>2]|0;if((f|0)==0){o=0;p=l;q=m;break}e=gj[f&4095](j)|0;o=e;p=c[3528552]|0;q=c[2433426]|0}else{o=a[g+(k&255)|0]|0;p=l;q=m}}while(0);m=(o&255)<<8;o=k+1|0;k=o&65535;l=c[q+(p*3160|0)+60+((o>>>8&255)<<2)>>2]|0;do{if((l|0)==0){g=c[q+(p*3160|0)+3132>>2]|0;if((g|0)==0){r=0;break}r=gj[g&4095](k)|0}else{r=a[l+(o&255)|0]|0}}while(0);o=r&255|m;b[4821356]=o;r=a[9642744]&-15;a[9642744]=r;l=r&255|(m&65535)>>>12&8;if(o<<16>>16!=0){s=l&255;a[9642744]=s;return}s=(l|4)&255;a[9642744]=s;return}function fGg(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=a[9642744]&-15;a[9642744]=d;e=b[4821356]|0;f=(e&65535)>>>12&8|d&255;if(e<<16>>16==0){g=(f|4)&255}else{g=f&255}a[9642744]=g;c[2426872]=c[2410680];g=c[2410676]|0;f=g&65535;e=c[3528552]|0;d=c[2433426]|0;h=c[d+(e*3160|0)+60+((g>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[d+(e*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=f;l=e;m=d;break}n=gj[i&4095](f)|0;j=n;k=b[4821352]|0;l=c[3528552]|0;m=c[2433426]|0}else{j=a[h+(g&255)|0]|0;k=f;l=e;m=d}}while(0);a[9707488]=j;b[4821352]=k+1&65535;k=c[2426872]|0;j=k&65535;d=a[9642713]|0;e=c[m+(l*3160|0)+60+((k>>>8&255|256)<<2)>>2]|0;do{if((e|0)==0){f=c[m+(l*3160|0)+3136>>2]|0;if((f|0)==0){o=l;p=m;break}gg[f&4095](j,d);o=c[3528552]|0;p=c[2433426]|0}else{a[e+(k&255)|0]=d;o=l;p=m}}while(0);m=k+1|0;k=a[9642712]|0;l=c[p+(o*3160|0)+60+((m>>>8&255|256)<<2)>>2]|0;if((l|0)!=0){a[l+(m&255)|0]=k;return}l=c[p+(o*3160|0)+3136>>2]|0;if((l|0)==0){return}gg[l&4095](m&65535,k);return}function fGh(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;c[2426872]=c[2410680];d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;l=f;m=g;break}n=gj[i&4095](e)|0;j=n;k=b[4821352]|0;l=c[3528552]|0;m=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=e;l=f;m=g}}while(0);a[9707488]=j;b[4821352]=k+1&65535;k=c[2426872]|0;j=k&65535;g=c[m+(l*3160|0)+60+((k>>>8&255)<<2)>>2]|0;do{if((g|0)==0){f=c[m+(l*3160|0)+3132>>2]|0;if((f|0)==0){o=0;p=l;q=m;break}e=gj[f&4095](j)|0;o=e;p=c[3528552]|0;q=c[2433426]|0}else{o=a[g+(k&255)|0]|0;p=l;q=m}}while(0);m=o&255;o=m<<8;l=k+1|0;k=l&65535;g=c[q+(p*3160|0)+60+((l>>>8&255)<<2)>>2]|0;do{if((g|0)==0){j=c[q+(p*3160|0)+3132>>2]|0;if((j|0)==0){r=0;break}r=gj[j&4095](k)|0}else{r=a[g+(l&255)|0]|0}}while(0);l=r&255|o;c[2410681]=l;o=a[9642744]&-15;a[9642744]=o;r=o&255|m>>>4&8;if((l|0)!=0){s=r&255;a[9642744]=s;return}s=(r|4)&255;a[9642744]=s;return}function fGi(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=a[9642744]&-15;a[9642744]=d;e=b[4821362]|0;f=(e&65535)>>>12&8|d&255;if(e<<16>>16==0){g=(f|4)&255}else{g=f&255}a[9642744]=g;c[2426872]=c[2410680];g=c[2410676]|0;f=g&65535;e=c[3528552]|0;d=c[2433426]|0;h=c[d+(e*3160|0)+60+((g>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[d+(e*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=f;l=e;m=d;break}n=gj[i&4095](f)|0;j=n;k=b[4821352]|0;l=c[3528552]|0;m=c[2433426]|0}else{j=a[h+(g&255)|0]|0;k=f;l=e;m=d}}while(0);a[9707488]=j;b[4821352]=k+1&65535;k=c[2426872]|0;j=k&65535;d=a[9642725]|0;e=c[m+(l*3160|0)+60+((k>>>8&255|256)<<2)>>2]|0;do{if((e|0)==0){f=c[m+(l*3160|0)+3136>>2]|0;if((f|0)==0){o=l;p=m;break}gg[f&4095](j,d);o=c[3528552]|0;p=c[2433426]|0}else{a[e+(k&255)|0]=d;o=l;p=m}}while(0);m=k+1|0;k=a[9642724]|0;l=c[p+(o*3160|0)+60+((m>>>8&255|256)<<2)>>2]|0;if((l|0)!=0){a[l+(m&255)|0]=k;return}l=c[p+(o*3160|0)+3136>>2]|0;if((l|0)==0){return}gg[l&4095](m&65535,k);return}function fGj(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;fGP();b=c[2426872]|0;d=b&65535;e=c[3528552]|0;f=c[2433426]|0;g=c[f+(e*3160|0)+60+((b>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[f+(e*3160|0)+3132>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(b&255)|0]|0}}while(0);b=a[9642712]|0;g=(b&255)-(i&255)|0;d=(g>>>4&8|a[9642744]&-16&255)&255;e=g&255;a[9642744]=(((b^i)&255^g^g>>>1)>>>6&2|g>>>8&1|(e<<24>>24==0?d|4:d)&255)&255;a[9642712]=e;return}function fGk(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;fGP();b=c[2426872]|0;d=b&65535;e=c[3528552]|0;f=c[2433426]|0;g=c[f+(e*3160|0)+60+((b>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[f+(e*3160|0)+3132>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(b&255)|0]|0}}while(0);b=a[9642712]|0;g=(b&255)-(i&255)|0;d=(g>>>4&8|a[9642744]&-16&255)&255;a[9642744]=(((b^i)&255^g^g>>>1)>>>6&2|g>>>8&1|((g&255)<<24>>24==0?d|4:d)&255)&255;return}function fGl(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;fGP();b=c[2426872]|0;d=b&65535;e=c[3528552]|0;f=c[2433426]|0;g=c[f+(e*3160|0)+60+((b>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[f+(e*3160|0)+3132>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(b&255)|0]|0}}while(0);b=a[9642712]|0;g=a[9642744]|0;d=(b&255)-(i&255)-(g&1)|0;e=(d>>>4&8|g&-16&255)&255;g=d&255;a[9642744]=((d^(b^i)&255^d>>>1)>>>6&2|d>>>8&1|(g<<24>>24==0?e|4:e)&255)&255;a[9642712]=g;return}function fGm(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;fGP();d=c[2426872]|0;f=d&65535;g=c[3528552]|0;h=c[2433426]|0;i=c[h+(g*3160|0)+60+((d>>>8&255)<<2)>>2]|0;do{if((i|0)==0){j=c[h+(g*3160|0)+3132>>2]|0;if((j|0)==0){k=0;l=g;m=h;break}n=gj[j&4095](f)|0;k=n;l=c[3528552]|0;m=c[2433426]|0}else{k=a[i+(d&255)|0]|0;l=g;m=h}}while(0);h=(k&255)<<8;k=d+1|0;d=k&65535;g=c[m+(l*3160|0)+60+((k>>>8&255)<<2)>>2]|0;do{if((g|0)==0){i=c[m+(l*3160|0)+3132>>2]|0;if((i|0)==0){o=0;break}o=gj[i&4095](d)|0}else{o=a[g+(k&255)|0]|0}}while(0);k=e[4821356]|0;g=k+(o&255|h)|0;o=(g>>>12&8|a[9642744]&-16&255)&255;d=g&65535;a[9642744]=((k^h^g^g>>>1)>>>14&2|g>>>16&1|(d<<16>>16==0?o|4:o)&255)&255;b[4821356]=d;return}function fGn(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;fGP();b=c[2426872]|0;d=b&65535;e=c[3528552]|0;f=c[2433426]|0;g=c[f+(e*3160|0)+60+((b>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[f+(e*3160|0)+3132>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(b&255)|0]|0}}while(0);b=a[9642712]&i;a[9642712]=b;i=(b&255)>>>4&8|a[9642744]&-15;a[9642744]=b<<24>>24==0?i|4:i;return}function fGo(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;fGP();b=a[9642712]|0;d=c[2426872]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3132>>2]|0;if((i|0)==0){j=0;break}j=gj[i&4095](e)|0}else{j=a[h+(d&255)|0]|0}}while(0);d=j&b;b=(d&255)>>>4&8|a[9642744]&-15;a[9642744]=d<<24>>24==0?b|4:b;return}function fGp(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;fGP();b=c[2426872]|0;d=b&65535;e=c[3528552]|0;f=c[2433426]|0;g=c[f+(e*3160|0)+60+((b>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[f+(e*3160|0)+3132>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(b&255)|0]|0}}while(0);a[9642712]=i;b=(i&255)>>>4&8|a[9642744]&-15;a[9642744]=i<<24>>24==0?b|4:b;return}function fGq(){var b=0,d=0,e=0,f=0,g=0;fGP();b=a[9642712]|0;d=(b&255)>>>4&8|a[9642744]&-15;a[9642744]=b<<24>>24==0?d|4:d;d=c[2426872]|0;e=c[3528552]|0;f=c[2433426]|0;g=c[f+(e*3160|0)+60+((d>>>8&255|256)<<2)>>2]|0;if((g|0)!=0){a[g+(d&255)|0]=b;return}g=c[f+(e*3160|0)+3136>>2]|0;if((g|0)==0){return}gg[g&4095](d&65535,b);return}function fGr(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;fGP();b=c[2426872]|0;d=b&65535;e=c[3528552]|0;f=c[2433426]|0;g=c[f+(e*3160|0)+60+((b>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[f+(e*3160|0)+3132>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(b&255)|0]|0}}while(0);b=a[9642712]|0;g=b^i;a[9642712]=g;d=(g&255)>>>4&8|a[9642744]&-15;a[9642744]=b<<24>>24==i<<24>>24?d|4:d;return}function fGs(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;fGP();b=c[2426872]|0;d=b&65535;e=c[3528552]|0;f=c[2433426]|0;g=c[f+(e*3160|0)+60+((b>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[f+(e*3160|0)+3132>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(b&255)|0]|0}}while(0);b=a[9642712]|0;g=a[9642744]|0;d=(b&255)+(i&255)+(g&1)|0;e=(d>>>4&8|g&-48&255)&255;g=d&255;f=d^(b^i)&255;a[9642744]=(f<<1&32|d>>>8&1|(f^d>>>1)>>>6&2|(g<<24>>24==0?e|4:e)&255)&255;a[9642712]=g;return}function fGt(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;fGP();b=c[2426872]|0;d=b&65535;e=c[3528552]|0;f=c[2433426]|0;g=c[f+(e*3160|0)+60+((b>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[f+(e*3160|0)+3132>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(b&255)|0]|0}}while(0);b=a[9642712]|i;a[9642712]=b;i=(b&255)>>>4&8|a[9642744]&-15;a[9642744]=b<<24>>24==0?i|4:i;return}function fGu(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;fGP();b=c[2426872]|0;d=b&65535;e=c[3528552]|0;f=c[2433426]|0;g=c[f+(e*3160|0)+60+((b>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[f+(e*3160|0)+3132>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(b&255)|0]|0}}while(0);b=a[9642712]|0;g=(b&255)+(i&255)|0;d=(g>>>4&8|a[9642744]&-48&255)&255;e=g&255;f=(b^i)&255^g;a[9642744]=(f<<1&32|g>>>8&1|(f^g>>>1)>>>6&2|(e<<24>>24==0?d|4:d)&255)&255;a[9642712]=e;return}function fGv(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;fGP();d=c[2426872]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3132>>2]|0;if((i|0)==0){j=0;k=f;l=g;break}m=gj[i&4095](e)|0;j=m;k=c[3528552]|0;l=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=f;l=g}}while(0);g=(j&255)<<8;j=d+1|0;d=j&65535;f=c[l+(k*3160|0)+60+((j>>>8&255)<<2)>>2]|0;do{if((f|0)==0){h=c[l+(k*3160|0)+3132>>2]|0;if((h|0)==0){n=0;break}n=gj[h&4095](d)|0}else{n=a[f+(j&255)|0]|0}}while(0);j=n&255|g;b[4821356]=j;n=a[9642744]&-15;a[9642744]=n;f=n&255|(g&65535)>>>12&8;if(j<<16>>16!=0){o=f&255;a[9642744]=o;return}o=(f|4)&255;a[9642744]=o;return}function fGw(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;fGP();d=a[9642744]&-15;a[9642744]=d;e=b[4821356]|0;f=(e&65535)>>>12&8|d&255;if(e<<16>>16==0){g=(f|4)&255}else{g=f&255}a[9642744]=g;g=c[2426872]|0;f=g&65535;e=a[9642713]|0;d=c[3528552]|0;h=c[2433426]|0;i=c[h+(d*3160|0)+60+((g>>>8&255|256)<<2)>>2]|0;do{if((i|0)==0){j=c[h+(d*3160|0)+3136>>2]|0;if((j|0)==0){k=d;l=h;break}gg[j&4095](f,e);k=c[3528552]|0;l=c[2433426]|0}else{a[i+(g&255)|0]=e;k=d;l=h}}while(0);h=g+1|0;g=a[9642712]|0;d=c[l+(k*3160|0)+60+((h>>>8&255|256)<<2)>>2]|0;if((d|0)!=0){a[d+(h&255)|0]=g;return}d=c[l+(k*3160|0)+3136>>2]|0;if((d|0)==0){return}gg[d&4095](h&65535,g);return}function fGx(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;fGP();d=c[2426872]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3132>>2]|0;if((i|0)==0){j=0;k=f;l=g;break}m=gj[i&4095](e)|0;j=m;k=c[3528552]|0;l=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=f;l=g}}while(0);g=(j&255)<<8;j=d+1|0;d=j&65535;f=c[l+(k*3160|0)+60+((j>>>8&255)<<2)>>2]|0;do{if((f|0)==0){h=c[l+(k*3160|0)+3132>>2]|0;if((h|0)==0){n=0;break}n=gj[h&4095](d)|0}else{n=a[f+(j&255)|0]|0}}while(0);j=n&255|g;b[4821362]=j;n=a[9642744]&-15;a[9642744]=n;f=n&255|(g&65535)>>>12&8;if(j<<16>>16!=0){o=f&255;a[9642744]=o;return}o=(f|4)&255;a[9642744]=o;return}function fGy(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;fGP();d=a[9642744]&-15;a[9642744]=d;e=b[4821362]|0;f=(e&65535)>>>12&8|d&255;if(e<<16>>16==0){g=(f|4)&255}else{g=f&255}a[9642744]=g;g=c[2426872]|0;f=g&65535;e=a[9642725]|0;d=c[3528552]|0;h=c[2433426]|0;i=c[h+(d*3160|0)+60+((g>>>8&255|256)<<2)>>2]|0;do{if((i|0)==0){j=c[h+(d*3160|0)+3136>>2]|0;if((j|0)==0){k=d;l=h;break}gg[j&4095](f,e);k=c[3528552]|0;l=c[2433426]|0}else{a[i+(g&255)|0]=e;k=d;l=h}}while(0);h=g+1|0;g=a[9642724]|0;d=c[l+(k*3160|0)+60+((h>>>8&255|256)<<2)>>2]|0;if((d|0)!=0){a[d+(h&255)|0]=g;return}d=c[l+(k*3160|0)+3136>>2]|0;if((d|0)==0){return}gg[d&4095](h&65535,g);return}function fGz(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=j&255;j=e<<8;g=k+1|0;k=g&65535;f=c[m+(l*3160|0)+60+((g>>>8&255|512)<<2)>>2]|0;do{if((f|0)==0){d=c[m+(l*3160|0)+3144>>2]|0;if((d|0)==0){p=0;q=n;r=l;s=m;break}h=gj[d&4095](k)|0;p=h;q=b[4821352]|0;r=c[3528552]|0;s=c[2433426]|0}else{p=a[f+(g&255)|0]|0;q=n;r=l;s=m}}while(0);m=p&255;p=m|j;c[2426872]=p;b[4821352]=q+2&65535;q=p&65535;p=c[s+(r*3160|0)+60+(e<<2)>>2]|0;do{if((p|0)==0){e=c[s+(r*3160|0)+3132>>2]|0;if((e|0)==0){t=0;break}t=gj[e&4095](q)|0}else{t=a[p+m|0]|0}}while(0);m=a[9642712]|0;p=(m&255)-(t&255)|0;q=(p>>>4&8|a[9642744]&-16&255)&255;r=p&255;a[9642744]=(((m^t)&255^p^p>>>1)>>>6&2|p>>>8&1|(r<<24>>24==0?q|4:q)&255)&255;a[9642712]=r;return}function fGA(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=j&255;j=e<<8;g=k+1|0;k=g&65535;f=c[m+(l*3160|0)+60+((g>>>8&255|512)<<2)>>2]|0;do{if((f|0)==0){d=c[m+(l*3160|0)+3144>>2]|0;if((d|0)==0){p=0;q=n;r=l;s=m;break}h=gj[d&4095](k)|0;p=h;q=b[4821352]|0;r=c[3528552]|0;s=c[2433426]|0}else{p=a[f+(g&255)|0]|0;q=n;r=l;s=m}}while(0);m=p&255;p=m|j;c[2426872]=p;b[4821352]=q+2&65535;q=p&65535;p=c[s+(r*3160|0)+60+(e<<2)>>2]|0;do{if((p|0)==0){e=c[s+(r*3160|0)+3132>>2]|0;if((e|0)==0){t=0;break}t=gj[e&4095](q)|0}else{t=a[p+m|0]|0}}while(0);m=a[9642712]|0;p=(m&255)-(t&255)|0;q=(p>>>4&8|a[9642744]&-16&255)&255;a[9642744]=(((m^t)&255^p^p>>>1)>>>6&2|p>>>8&1|((p&255)<<24>>24==0?q|4:q)&255)&255;return}function fGB(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=j&255;j=e<<8;g=k+1|0;k=g&65535;f=c[m+(l*3160|0)+60+((g>>>8&255|512)<<2)>>2]|0;do{if((f|0)==0){d=c[m+(l*3160|0)+3144>>2]|0;if((d|0)==0){p=0;q=n;r=l;s=m;break}h=gj[d&4095](k)|0;p=h;q=b[4821352]|0;r=c[3528552]|0;s=c[2433426]|0}else{p=a[f+(g&255)|0]|0;q=n;r=l;s=m}}while(0);m=p&255;p=m|j;c[2426872]=p;b[4821352]=q+2&65535;q=p&65535;p=c[s+(r*3160|0)+60+(e<<2)>>2]|0;do{if((p|0)==0){e=c[s+(r*3160|0)+3132>>2]|0;if((e|0)==0){t=0;break}t=gj[e&4095](q)|0}else{t=a[p+m|0]|0}}while(0);m=a[9642712]|0;p=a[9642744]|0;q=(m&255)-(t&255)-(p&1)|0;r=(q>>>4&8|p&-16&255)&255;p=q&255;a[9642744]=((q^(m^t)&255^q>>>1)>>>6&2|q>>>8&1|(p<<24>>24==0?r|4:r)&255)&255;a[9642712]=p;return}function fGC(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=c[2410676]|0;f=d&65535;g=c[3528552]|0;h=c[2433426]|0;i=c[h+(g*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((i|0)==0){j=c[h+(g*3160|0)+3144>>2]|0;if((j|0)==0){k=0;l=d;m=g;n=h;o=f;break}p=gj[j&4095](f)|0;j=c[2410676]|0;k=p;l=j;m=c[3528552]|0;n=c[2433426]|0;o=j&65535}else{k=a[i+(d&255)|0]|0;l=d;m=g;n=h;o=f}}while(0);f=k&255;k=f<<8;h=l+1|0;l=h&65535;g=c[n+(m*3160|0)+60+((h>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){d=c[n+(m*3160|0)+3144>>2]|0;if((d|0)==0){q=0;r=o;s=m;t=n;break}i=gj[d&4095](l)|0;q=i;r=b[4821352]|0;s=c[3528552]|0;t=c[2433426]|0}else{q=a[g+(h&255)|0]|0;r=o;s=m;t=n}}while(0);n=q&255;q=n|k;c[2426872]=q;b[4821352]=r+2&65535;r=q&65535;k=c[t+(s*3160|0)+60+(f<<2)>>2]|0;do{if((k|0)==0){f=c[t+(s*3160|0)+3132>>2]|0;if((f|0)==0){u=0;v=s;w=t;break}m=gj[f&4095](r)|0;u=m;v=c[3528552]|0;w=c[2433426]|0}else{u=a[k+n|0]|0;v=s;w=t}}while(0);t=(u&255)<<8;u=q+1|0;q=u&65535;s=c[w+(v*3160|0)+60+((u>>>8&255)<<2)>>2]|0;do{if((s|0)==0){n=c[w+(v*3160|0)+3132>>2]|0;if((n|0)==0){x=0;break}x=gj[n&4095](q)|0}else{x=a[s+(u&255)|0]|0}}while(0);u=e[4821356]|0;s=u+(x&255|t)|0;x=(s>>>12&8|a[9642744]&-16&255)&255;q=s&65535;a[9642744]=((u^t^s^s>>>1)>>>14&2|s>>>16&1|(q<<16>>16==0?x|4:x)&255)&255;b[4821356]=q;return}function fGD(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=j&255;j=e<<8;g=k+1|0;k=g&65535;f=c[m+(l*3160|0)+60+((g>>>8&255|512)<<2)>>2]|0;do{if((f|0)==0){d=c[m+(l*3160|0)+3144>>2]|0;if((d|0)==0){p=0;q=n;r=l;s=m;break}h=gj[d&4095](k)|0;p=h;q=b[4821352]|0;r=c[3528552]|0;s=c[2433426]|0}else{p=a[f+(g&255)|0]|0;q=n;r=l;s=m}}while(0);m=p&255;p=m|j;c[2426872]=p;b[4821352]=q+2&65535;q=p&65535;p=c[s+(r*3160|0)+60+(e<<2)>>2]|0;do{if((p|0)==0){e=c[s+(r*3160|0)+3132>>2]|0;if((e|0)==0){t=0;break}t=gj[e&4095](q)|0}else{t=a[p+m|0]|0}}while(0);m=a[9642712]&t;a[9642712]=m;t=(m&255)>>>4&8|a[9642744]&-15;a[9642744]=m<<24>>24==0?t|4:t;return}function fGE(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=j&255;j=e<<8;g=k+1|0;k=g&65535;f=c[m+(l*3160|0)+60+((g>>>8&255|512)<<2)>>2]|0;do{if((f|0)==0){d=c[m+(l*3160|0)+3144>>2]|0;if((d|0)==0){p=0;q=n;r=l;s=m;break}h=gj[d&4095](k)|0;p=h;q=b[4821352]|0;r=c[3528552]|0;s=c[2433426]|0}else{p=a[f+(g&255)|0]|0;q=n;r=l;s=m}}while(0);m=p&255;p=m|j;c[2426872]=p;b[4821352]=q+2&65535;q=p&65535;p=c[s+(r*3160|0)+60+(e<<2)>>2]|0;do{if((p|0)==0){e=c[s+(r*3160|0)+3132>>2]|0;if((e|0)==0){t=0;break}t=gj[e&4095](q)|0}else{t=a[p+m|0]|0}}while(0);m=a[9642712]&t;t=(m&255)>>>4&8|a[9642744]&-15;a[9642744]=m<<24>>24==0?t|4:t;return}function fGF(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=j&255;j=e<<8;g=k+1|0;k=g&65535;f=c[m+(l*3160|0)+60+((g>>>8&255|512)<<2)>>2]|0;do{if((f|0)==0){d=c[m+(l*3160|0)+3144>>2]|0;if((d|0)==0){p=0;q=n;r=l;s=m;break}h=gj[d&4095](k)|0;p=h;q=b[4821352]|0;r=c[3528552]|0;s=c[2433426]|0}else{p=a[f+(g&255)|0]|0;q=n;r=l;s=m}}while(0);m=p&255;p=m|j;c[2426872]=p;b[4821352]=q+2&65535;q=p&65535;p=c[s+(r*3160|0)+60+(e<<2)>>2]|0;do{if((p|0)==0){e=c[s+(r*3160|0)+3132>>2]|0;if((e|0)==0){t=0;break}t=gj[e&4095](q)|0}else{t=a[p+m|0]|0}}while(0);a[9642712]=t;m=(t&255)>>>4&8|a[9642744]&-15;a[9642744]=t<<24>>24==0?m|4:m;return}function fGG(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=a[9642712]|0;e=(d&255)>>>4&8|a[9642744]&-15;a[9642744]=d<<24>>24==0?e|4:e;e=c[2410676]|0;d=e&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((e>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;l=f;m=g;n=d;break}o=gj[i&4095](d)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(e&255)|0]|0;k=e;l=f;m=g;n=d}}while(0);d=j&255;j=d<<8;g=k+1|0;k=g&65535;f=c[m+(l*3160|0)+60+((g>>>8&255|512)<<2)>>2]|0;do{if((f|0)==0){e=c[m+(l*3160|0)+3144>>2]|0;if((e|0)==0){p=0;q=n;r=l;s=m;break}h=gj[e&4095](k)|0;p=h;q=b[4821352]|0;r=c[3528552]|0;s=c[2433426]|0}else{p=a[f+(g&255)|0]|0;q=n;r=l;s=m}}while(0);m=p&255;p=m|j;c[2426872]=p;b[4821352]=q+2&65535;q=a[9642712]|0;j=c[s+(r*3160|0)+60+((d|256)<<2)>>2]|0;if((j|0)!=0){a[j+m|0]=q;return}m=c[s+(r*3160|0)+3136>>2]|0;if((m|0)==0){return}gg[m&4095](p&65535,q);return}function fGH(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=j&255;j=e<<8;g=k+1|0;k=g&65535;f=c[m+(l*3160|0)+60+((g>>>8&255|512)<<2)>>2]|0;do{if((f|0)==0){d=c[m+(l*3160|0)+3144>>2]|0;if((d|0)==0){p=0;q=n;r=l;s=m;break}h=gj[d&4095](k)|0;p=h;q=b[4821352]|0;r=c[3528552]|0;s=c[2433426]|0}else{p=a[f+(g&255)|0]|0;q=n;r=l;s=m}}while(0);m=p&255;p=m|j;c[2426872]=p;b[4821352]=q+2&65535;q=p&65535;p=c[s+(r*3160|0)+60+(e<<2)>>2]|0;do{if((p|0)==0){e=c[s+(r*3160|0)+3132>>2]|0;if((e|0)==0){t=0;break}t=gj[e&4095](q)|0}else{t=a[p+m|0]|0}}while(0);m=a[9642712]|0;p=m^t;a[9642712]=p;q=(p&255)>>>4&8|a[9642744]&-15;a[9642744]=m<<24>>24==t<<24>>24?q|4:q;return}function fGI(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=j&255;j=e<<8;g=k+1|0;k=g&65535;f=c[m+(l*3160|0)+60+((g>>>8&255|512)<<2)>>2]|0;do{if((f|0)==0){d=c[m+(l*3160|0)+3144>>2]|0;if((d|0)==0){p=0;q=n;r=l;s=m;break}h=gj[d&4095](k)|0;p=h;q=b[4821352]|0;r=c[3528552]|0;s=c[2433426]|0}else{p=a[f+(g&255)|0]|0;q=n;r=l;s=m}}while(0);m=p&255;p=m|j;c[2426872]=p;b[4821352]=q+2&65535;q=p&65535;p=c[s+(r*3160|0)+60+(e<<2)>>2]|0;do{if((p|0)==0){e=c[s+(r*3160|0)+3132>>2]|0;if((e|0)==0){t=0;break}t=gj[e&4095](q)|0}else{t=a[p+m|0]|0}}while(0);m=a[9642712]|0;p=a[9642744]|0;q=(m&255)+(t&255)+(p&1)|0;r=(q>>>4&8|p&-48&255)&255;p=q&255;s=q^(m^t)&255;a[9642744]=(s<<1&32|q>>>8&1|(s^q>>>1)>>>6&2|(p<<24>>24==0?r|4:r)&255)&255;a[9642712]=p;return}function fGJ(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=j&255;j=e<<8;g=k+1|0;k=g&65535;f=c[m+(l*3160|0)+60+((g>>>8&255|512)<<2)>>2]|0;do{if((f|0)==0){d=c[m+(l*3160|0)+3144>>2]|0;if((d|0)==0){p=0;q=n;r=l;s=m;break}h=gj[d&4095](k)|0;p=h;q=b[4821352]|0;r=c[3528552]|0;s=c[2433426]|0}else{p=a[f+(g&255)|0]|0;q=n;r=l;s=m}}while(0);m=p&255;p=m|j;c[2426872]=p;b[4821352]=q+2&65535;q=p&65535;p=c[s+(r*3160|0)+60+(e<<2)>>2]|0;do{if((p|0)==0){e=c[s+(r*3160|0)+3132>>2]|0;if((e|0)==0){t=0;break}t=gj[e&4095](q)|0}else{t=a[p+m|0]|0}}while(0);m=a[9642712]|t;a[9642712]=m;t=(m&255)>>>4&8|a[9642744]&-15;a[9642744]=m<<24>>24==0?t|4:t;return}function fGK(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=j&255;j=e<<8;g=k+1|0;k=g&65535;f=c[m+(l*3160|0)+60+((g>>>8&255|512)<<2)>>2]|0;do{if((f|0)==0){d=c[m+(l*3160|0)+3144>>2]|0;if((d|0)==0){p=0;q=n;r=l;s=m;break}h=gj[d&4095](k)|0;p=h;q=b[4821352]|0;r=c[3528552]|0;s=c[2433426]|0}else{p=a[f+(g&255)|0]|0;q=n;r=l;s=m}}while(0);m=p&255;p=m|j;c[2426872]=p;b[4821352]=q+2&65535;q=p&65535;p=c[s+(r*3160|0)+60+(e<<2)>>2]|0;do{if((p|0)==0){e=c[s+(r*3160|0)+3132>>2]|0;if((e|0)==0){t=0;break}t=gj[e&4095](q)|0}else{t=a[p+m|0]|0}}while(0);m=a[9642712]|0;p=(m&255)+(t&255)|0;q=(p>>>4&8|a[9642744]&-48&255)&255;r=p&255;s=(m^t)&255^p;a[9642744]=(s<<1&32|p>>>8&1|(s^p>>>1)>>>6&2|(r<<24>>24==0?q|4:q)&255)&255;a[9642712]=r;return}function fGL(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=j&255;j=e<<8;g=k+1|0;k=g&65535;f=c[m+(l*3160|0)+60+((g>>>8&255|512)<<2)>>2]|0;do{if((f|0)==0){d=c[m+(l*3160|0)+3144>>2]|0;if((d|0)==0){p=0;q=n;r=l;s=m;break}h=gj[d&4095](k)|0;p=h;q=b[4821352]|0;r=c[3528552]|0;s=c[2433426]|0}else{p=a[f+(g&255)|0]|0;q=n;r=l;s=m}}while(0);m=p&255;p=m|j;c[2426872]=p;b[4821352]=q+2&65535;q=p&65535;j=c[s+(r*3160|0)+60+(e<<2)>>2]|0;do{if((j|0)==0){e=c[s+(r*3160|0)+3132>>2]|0;if((e|0)==0){t=0;u=r;v=s;break}l=gj[e&4095](q)|0;t=l;u=c[3528552]|0;v=c[2433426]|0}else{t=a[j+m|0]|0;u=r;v=s}}while(0);s=t&255;t=s<<8;r=p+1|0;p=r&65535;m=c[v+(u*3160|0)+60+((r>>>8&255)<<2)>>2]|0;do{if((m|0)==0){j=c[v+(u*3160|0)+3132>>2]|0;if((j|0)==0){w=0;break}w=gj[j&4095](p)|0}else{w=a[m+(r&255)|0]|0}}while(0);r=w&255|t;c[2410678]=r;t=a[9642744]&-15;a[9642744]=t;w=t&255|s>>>4&8;if((r|0)!=0){x=w&255;a[9642744]=x;return}x=(w|4)&255;a[9642744]=x;return}function fGM(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;d=a[9642744]&-15;a[9642744]=d;e=b[4821356]|0;f=(e&65535)>>>12&8|d&255;if(e<<16>>16==0){g=(f|4)&255}else{g=f&255}a[9642744]=g;g=c[2410676]|0;f=g&65535;e=c[3528552]|0;d=c[2433426]|0;h=c[d+(e*3160|0)+60+((g>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[d+(e*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=g;l=e;m=d;n=f;break}o=gj[i&4095](f)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(g&255)|0]|0;k=g;l=e;m=d;n=f}}while(0);f=j&255;j=f<<8;d=k+1|0;k=d&65535;e=c[m+(l*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((e|0)==0){g=c[m+(l*3160|0)+3144>>2]|0;if((g|0)==0){p=0;q=n;r=l;s=m;break}h=gj[g&4095](k)|0;p=h;q=b[4821352]|0;r=c[3528552]|0;s=c[2433426]|0}else{p=a[e+(d&255)|0]|0;q=n;r=l;s=m}}while(0);m=p&255;p=m|j;c[2426872]=p;b[4821352]=q+2&65535;q=p&65535;j=a[9642713]|0;l=c[s+(r*3160|0)+60+((f|256)<<2)>>2]|0;do{if((l|0)==0){f=c[s+(r*3160|0)+3136>>2]|0;if((f|0)==0){t=r;u=s;break}gg[f&4095](q,j);t=c[3528552]|0;u=c[2433426]|0}else{a[l+m|0]=j;t=r;u=s}}while(0);s=p+1|0;p=a[9642712]|0;r=c[u+(t*3160|0)+60+((s>>>8&255|256)<<2)>>2]|0;if((r|0)!=0){a[r+(s&255)|0]=p;return}r=c[u+(t*3160|0)+3136>>2]|0;if((r|0)==0){return}gg[r&4095](s&65535,p);return}function fGN(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=j&255;j=e<<8;g=k+1|0;k=g&65535;f=c[m+(l*3160|0)+60+((g>>>8&255|512)<<2)>>2]|0;do{if((f|0)==0){d=c[m+(l*3160|0)+3144>>2]|0;if((d|0)==0){p=0;q=n;r=l;s=m;break}h=gj[d&4095](k)|0;p=h;q=b[4821352]|0;r=c[3528552]|0;s=c[2433426]|0}else{p=a[f+(g&255)|0]|0;q=n;r=l;s=m}}while(0);m=p&255;p=m|j;c[2426872]=p;b[4821352]=q+2&65535;q=p&65535;j=c[s+(r*3160|0)+60+(e<<2)>>2]|0;do{if((j|0)==0){e=c[s+(r*3160|0)+3132>>2]|0;if((e|0)==0){t=0;u=r;v=s;break}l=gj[e&4095](q)|0;t=l;u=c[3528552]|0;v=c[2433426]|0}else{t=a[j+m|0]|0;u=r;v=s}}while(0);s=t&255;t=s<<8;r=p+1|0;p=r&65535;m=c[v+(u*3160|0)+60+((r>>>8&255)<<2)>>2]|0;do{if((m|0)==0){j=c[v+(u*3160|0)+3132>>2]|0;if((j|0)==0){w=0;break}w=gj[j&4095](p)|0}else{w=a[m+(r&255)|0]|0}}while(0);r=w&255|t;c[2410681]=r;t=a[9642744]&-15;a[9642744]=t;w=t&255|s>>>4&8;if((r|0)!=0){x=w&255;a[9642744]=x;return}x=(w|4)&255;a[9642744]=x;return}function fGO(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;d=a[9642744]&-15;a[9642744]=d;e=b[4821362]|0;f=(e&65535)>>>12&8|d&255;if(e<<16>>16==0){g=(f|4)&255}else{g=f&255}a[9642744]=g;g=c[2410676]|0;f=g&65535;e=c[3528552]|0;d=c[2433426]|0;h=c[d+(e*3160|0)+60+((g>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[d+(e*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=g;l=e;m=d;n=f;break}o=gj[i&4095](f)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(g&255)|0]|0;k=g;l=e;m=d;n=f}}while(0);f=j&255;j=f<<8;d=k+1|0;k=d&65535;e=c[m+(l*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((e|0)==0){g=c[m+(l*3160|0)+3144>>2]|0;if((g|0)==0){p=0;q=n;r=l;s=m;break}h=gj[g&4095](k)|0;p=h;q=b[4821352]|0;r=c[3528552]|0;s=c[2433426]|0}else{p=a[e+(d&255)|0]|0;q=n;r=l;s=m}}while(0);m=p&255;p=m|j;c[2426872]=p;b[4821352]=q+2&65535;q=p&65535;j=a[9642725]|0;l=c[s+(r*3160|0)+60+((f|256)<<2)>>2]|0;do{if((l|0)==0){f=c[s+(r*3160|0)+3136>>2]|0;if((f|0)==0){t=r;u=s;break}gg[f&4095](q,j);t=c[3528552]|0;u=c[2433426]|0}else{a[l+m|0]=j;t=r;u=s}}while(0);s=p+1|0;p=a[9642724]|0;r=c[u+(t*3160|0)+60+((s>>>8&255|256)<<2)>>2]|0;if((r|0)!=0){a[r+(s&255)|0]=p;return}r=c[u+(t*3160|0)+3136>>2]|0;if((r|0)==0){return}gg[r&4095](s&65535,p);return}function fGP(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0,cf=0,cg=0,ch=0,ci=0,cj=0,ck=0,cl=0,cm=0,cn=0,co=0,cp=0,cq=0,cr=0,cs=0,ct=0,cu=0,cv=0,cw=0,cx=0,cy=0,cz=0,cA=0,cB=0,cC=0,cD=0,cE=0,cF=0,cG=0,cH=0,cI=0,cJ=0,cK=0,cL=0,cM=0,cN=0,cO=0,cP=0,cQ=0,cR=0,cS=0,cT=0,cU=0,cV=0,cW=0,cX=0,cY=0,cZ=0,c_=0,c$=0,c0=0,c1=0,c2=0,c3=0,c4=0,c5=0,c6=0,c7=0,c8=0,c9=0,da=0,db=0,dc=0,dd=0,de=0,df=0,dg=0,dh=0,di=0,dj=0,dk=0,dl=0,dm=0,dn=0,dp=0,dq=0,dr=0,ds=0,dt=0,du=0,dv=0,dw=0,dx=0,dy=0,dz=0,dA=0,dB=0,dC=0,dD=0,dE=0,dF=0,dG=0,dH=0,dI=0,dJ=0,dK=0,dL=0,dM=0,dN=0,dO=0,dP=0,dQ=0,dR=0,dS=0,dT=0,dU=0,dV=0,dW=0,dX=0,dY=0,dZ=0,d_=0,d$=0,d0=0,d1=0,d2=0,d3=0,d4=0,d5=0,d6=0,d7=0,d8=0,d9=0,ea=0,eb=0,ec=0,ed=0,ee=0,ef=0,eg=0,eh=0,ei=0,ej=0,ek=0,el=0,em=0,en=0,eo=0,ep=0,eq=0,er=0,es=0,et=0,eu=0,ev=0,ew=0,ex=0,ey=0,ez=0,eA=0,eB=0,eC=0,eD=0,eE=0,eF=0,eG=0,eH=0,eI=0,eJ=0,eK=0,eL=0,eM=0,eN=0,eO=0,eP=0,eQ=0,eR=0,eS=0,eT=0,eU=0,eV=0,eW=0,eX=0,eY=0,eZ=0,e_=0,e$=0,e0=0,e1=0,e2=0,e3=0,e4=0,e5=0,e6=0,e7=0,e8=0,e9=0,fa=0,fb=0,fc=0,fd=0,fe=0,ff=0,fg=0,fh=0,fi=0,fj=0,fk=0,fl=0,fm=0,fn=0,fo=0,fp=0,fq=0,fr=0,fs=0,ft=0,fu=0,fv=0,fw=0,fx=0,fy=0,fz=0,fA=0,fB=0,fC=0,fD=0,fE=0,fF=0,fG=0,fH=0,fI=0,fJ=0,fK=0,fL=0,fM=0,fN=0,fO=0,fP=0,fQ=0,fR=0,fS=0,fT=0,fU=0,fV=0,fW=0,fX=0,fY=0,fZ=0,f_=0,f$=0,f0=0,f1=0,f2=0,f3=0,f4=0,f5=0,f6=0,f7=0,f8=0,f9=0,ga=0,gb=0,gc=0,gd=0,ge=0,gf=0;f=c[2410676]|0;g=f&65535;h=c[3528552]|0;i=c[2433426]|0;j=c[i+(h*3160|0)+60+((f>>>8&255|512)<<2)>>2]|0;do{if((j|0)==0){k=c[i+(h*3160|0)+3144>>2]|0;if((k|0)==0){l=0;m=g;break}n=gj[k&4095](g)|0;l=n;m=b[4821352]|0}else{l=a[j+(f&255)|0]|0;m=g}}while(0);b[4821352]=m+1&65535;m=l&255;switch(m|0){case 2:{b[4853744]=(b[4821366]|0)+2&65535;break};case 14:{b[4853744]=(b[4821366]|0)+14&65535;break};case 0:{b[4853744]=b[4821366]|0;break};case 7:{b[4853744]=(b[4821366]|0)+7&65535;break};case 18:{b[4853744]=(b[4821366]|0)-14&65535;break};case 20:{b[4853744]=(b[4821366]|0)-12&65535;break};case 1:{b[4853744]=(b[4821366]|0)+1&65535;break};case 10:{b[4853744]=(b[4821366]|0)+10&65535;break};case 11:{b[4853744]=(b[4821366]|0)+11&65535;break};case 12:{b[4853744]=(b[4821366]|0)+12&65535;break};case 3:{b[4853744]=(b[4821366]|0)+3&65535;break};case 25:{b[4853744]=(b[4821366]|0)-7&65535;break};case 26:{b[4853744]=(b[4821366]|0)-6&65535;break};case 27:{b[4853744]=(b[4821366]|0)-5&65535;break};case 38:{b[4853744]=(b[4821368]|0)+6&65535;break};case 39:{b[4853744]=(b[4821368]|0)+7&65535;break};case 54:{b[4853744]=(b[4821368]|0)-10&65535;break};case 55:{b[4853744]=(b[4821368]|0)-9&65535;break};case 56:{b[4853744]=(b[4821368]|0)-8&65535;break};case 57:{b[4853744]=(b[4821368]|0)-7&65535;break};case 58:{b[4853744]=(b[4821368]|0)-6&65535;break};case 19:{b[4853744]=(b[4821366]|0)-13&65535;break};case 32:{b[4853744]=b[4821368]|0;break};case 33:{b[4853744]=(b[4821368]|0)+1&65535;break};case 34:{b[4853744]=(b[4821368]|0)+2&65535;break};case 35:{b[4853744]=(b[4821368]|0)+3&65535;break};case 63:{b[4853744]=(b[4821368]|0)-1&65535;break};case 64:{b[4853744]=b[4821362]|0;break};case 65:{b[4853744]=(b[4821362]|0)+1&65535;break};case 66:{b[4853744]=(b[4821362]|0)+2&65535;break};case 67:{b[4853744]=(b[4821362]|0)+3&65535;break};case 78:{b[4853744]=(b[4821362]|0)+14&65535;break};case 79:{b[4853744]=(b[4821362]|0)+15&65535;break};case 80:{b[4853744]=(b[4821362]|0)-16&65535;break};case 81:{b[4853744]=(b[4821362]|0)-15&65535;break};case 82:{b[4853744]=(b[4821362]|0)-14&65535;break};case 9:{b[4853744]=(b[4821366]|0)+9&65535;break};case 29:{b[4853744]=(b[4821366]|0)-3&65535;break};case 13:{b[4853744]=(b[4821366]|0)+13&65535;break};case 17:{b[4853744]=(b[4821366]|0)-15&65535;break};case 5:{b[4853744]=(b[4821366]|0)+5&65535;break};case 40:{b[4853744]=(b[4821368]|0)+8&65535;break};case 41:{b[4853744]=(b[4821368]|0)+9&65535;break};case 42:{b[4853744]=(b[4821368]|0)+10&65535;break};case 21:{b[4853744]=(b[4821366]|0)-11&65535;break};case 22:{b[4853744]=(b[4821366]|0)-10&65535;break};case 15:{b[4853744]=(b[4821366]|0)+15&65535;break};case 30:{b[4853744]=(b[4821366]|0)-2&65535;break};case 31:{b[4853744]=(b[4821366]|0)-1&65535;break};case 4:{b[4853744]=(b[4821366]|0)+4&65535;break};case 36:{b[4853744]=(b[4821368]|0)+4&65535;break};case 37:{b[4853744]=(b[4821368]|0)+5&65535;break};case 28:{b[4853744]=(b[4821366]|0)-4&65535;break};case 8:{b[4853744]=(b[4821366]|0)+8&65535;break};case 73:{b[4853744]=(b[4821362]|0)+9&65535;break};case 74:{b[4853744]=(b[4821362]|0)+10&65535;break};case 75:{b[4853744]=(b[4821362]|0)+11&65535;break};case 76:{b[4853744]=(b[4821362]|0)+12&65535;break};case 77:{b[4853744]=(b[4821362]|0)+13&65535;break};case 68:{b[4853744]=(b[4821362]|0)+4&65535;break};case 69:{b[4853744]=(b[4821362]|0)+5&65535;break};case 70:{b[4853744]=(b[4821362]|0)+6&65535;break};case 71:{b[4853744]=(b[4821362]|0)+7&65535;break};case 72:{b[4853744]=(b[4821362]|0)+8&65535;break};case 50:{b[4853744]=(b[4821368]|0)-14&65535;break};case 51:{b[4853744]=(b[4821368]|0)-13&65535;break};case 52:{b[4853744]=(b[4821368]|0)-12&65535;break};case 53:{b[4853744]=(b[4821368]|0)-11&65535;break};case 16:{b[4853744]=(b[4821366]|0)-16&65535;break};case 6:{b[4853744]=(b[4821366]|0)+6&65535;break};case 43:{b[4853744]=(b[4821368]|0)+11&65535;break};case 44:{b[4853744]=(b[4821368]|0)+12&65535;break};case 45:{b[4853744]=(b[4821368]|0)+13&65535;break};case 46:{b[4853744]=(b[4821368]|0)+14&65535;break};case 59:{b[4853744]=(b[4821368]|0)-5&65535;break};case 60:{b[4853744]=(b[4821368]|0)-4&65535;break};case 61:{b[4853744]=(b[4821368]|0)-3&65535;break};case 62:{b[4853744]=(b[4821368]|0)-2&65535;break};case 141:{l=c[2410676]|0;g=l&65535;f=c[3528552]|0;j=c[2433426]|0;h=c[j+(f*3160|0)+60+((l>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[j+(f*3160|0)+3144>>2]|0;if((i|0)==0){o=0;p=l;q=f;r=j;s=g;break}n=gj[i&4095](g)|0;i=c[2410676]|0;o=n;p=i;q=c[3528552]|0;r=c[2433426]|0;s=i&65535}else{o=a[h+(l&255)|0]|0;p=l;q=f;r=j;s=g}}while(0);g=(o&255)<<8;o=p+1|0;p=o&65535;j=c[r+(q*3160|0)+60+((o>>>8&255|512)<<2)>>2]|0;do{if((j|0)==0){f=c[r+(q*3160|0)+3144>>2]|0;if((f|0)==0){t=0;u=s;break}l=gj[f&4095](p)|0;t=l;u=b[4821352]|0}else{t=a[j+(o&255)|0]|0;u=s}}while(0);s=t&255|g;c[2426872]=s;g=u+2&65535;b[4821352]=g;b[4853744]=(s&65535)+g&65535;break};case 142:{b[4853744]=(b[4821358]|0)+(b[4821366]|0)&65535;break};case 143:{b[4853744]=b[4821358]|0;break};case 144:{b[4853744]=b[4821358]|0;g=c[2426872]|0;s=g&65535;u=c[3528552]|0;t=c[2433426]|0;o=c[t+(u*3160|0)+60+((g>>>8&255)<<2)>>2]|0;do{if((o|0)==0){j=c[t+(u*3160|0)+3132>>2]|0;if((j|0)==0){v=0;w=u;x=t;break}p=gj[j&4095](s)|0;v=p;w=c[3528552]|0;x=c[2433426]|0}else{v=a[o+(g&255)|0]|0;w=u;x=t}}while(0);t=(v&255)<<8;v=g+1|0;g=v&65535;u=c[x+(w*3160|0)+60+((v>>>8&255)<<2)>>2]|0;do{if((u|0)==0){o=c[x+(w*3160|0)+3132>>2]|0;if((o|0)==0){y=0;break}y=gj[o&4095](g)|0}else{y=a[u+(v&255)|0]|0}}while(0);c[2426872]=y&255|t;break};case 145:{t=b[4821366]|0;b[4853744]=t;b[4821366]=t+2&65535;t=c[2426872]|0;y=t&65535;v=c[3528552]|0;u=c[2433426]|0;g=c[u+(v*3160|0)+60+((t>>>8&255)<<2)>>2]|0;do{if((g|0)==0){w=c[u+(v*3160|0)+3132>>2]|0;if((w|0)==0){z=0;A=v;B=u;break}x=gj[w&4095](y)|0;z=x;A=c[3528552]|0;B=c[2433426]|0}else{z=a[g+(t&255)|0]|0;A=v;B=u}}while(0);u=(z&255)<<8;z=t+1|0;t=z&65535;v=c[B+(A*3160|0)+60+((z>>>8&255)<<2)>>2]|0;do{if((v|0)==0){g=c[B+(A*3160|0)+3132>>2]|0;if((g|0)==0){C=0;break}C=gj[g&4095](t)|0}else{C=a[v+(z&255)|0]|0}}while(0);c[2426872]=C&255|u;break};case 146:{a[9642745]=a[9642745]|64;fGQ();break};case 147:{u=(b[4821366]|0)-2&65535;b[4821366]=u;b[4853744]=u;u=c[2426872]|0;C=u&65535;z=c[3528552]|0;v=c[2433426]|0;t=c[v+(z*3160|0)+60+((u>>>8&255)<<2)>>2]|0;do{if((t|0)==0){A=c[v+(z*3160|0)+3132>>2]|0;if((A|0)==0){D=0;E=z;F=v;break}B=gj[A&4095](C)|0;D=B;E=c[3528552]|0;F=c[2433426]|0}else{D=a[t+(u&255)|0]|0;E=z;F=v}}while(0);v=(D&255)<<8;D=u+1|0;u=D&65535;z=c[F+(E*3160|0)+60+((D>>>8&255)<<2)>>2]|0;do{if((z|0)==0){t=c[F+(E*3160|0)+3132>>2]|0;if((t|0)==0){G=0;break}G=gj[t&4095](u)|0}else{G=a[z+(D&255)|0]|0}}while(0);c[2426872]=G&255|v;break};case 148:{b[4853744]=b[4821366]|0;v=c[2426872]|0;G=v&65535;D=c[3528552]|0;z=c[2433426]|0;u=c[z+(D*3160|0)+60+((v>>>8&255)<<2)>>2]|0;do{if((u|0)==0){E=c[z+(D*3160|0)+3132>>2]|0;if((E|0)==0){H=0;I=D;J=z;break}F=gj[E&4095](G)|0;H=F;I=c[3528552]|0;J=c[2433426]|0}else{H=a[u+(v&255)|0]|0;I=D;J=z}}while(0);z=(H&255)<<8;H=v+1|0;v=H&65535;D=c[J+(I*3160|0)+60+((H>>>8&255)<<2)>>2]|0;do{if((D|0)==0){u=c[J+(I*3160|0)+3132>>2]|0;if((u|0)==0){K=0;break}K=gj[u&4095](v)|0}else{K=a[D+(H&255)|0]|0}}while(0);c[2426872]=K&255|z;break};case 149:{z=d[9642712]|0;b[4853744]=((z&128|0)!=0?z|65280:z)+(e[4821366]|0)&65535;z=c[2426872]|0;K=z&65535;H=c[3528552]|0;D=c[2433426]|0;v=c[D+(H*3160|0)+60+((z>>>8&255)<<2)>>2]|0;do{if((v|0)==0){I=c[D+(H*3160|0)+3132>>2]|0;if((I|0)==0){L=0;M=H;N=D;break}J=gj[I&4095](K)|0;L=J;M=c[3528552]|0;N=c[2433426]|0}else{L=a[v+(z&255)|0]|0;M=H;N=D}}while(0);D=(L&255)<<8;L=z+1|0;z=L&65535;H=c[N+(M*3160|0)+60+((L>>>8&255)<<2)>>2]|0;do{if((H|0)==0){v=c[N+(M*3160|0)+3132>>2]|0;if((v|0)==0){O=0;break}O=gj[v&4095](z)|0}else{O=a[H+(L&255)|0]|0}}while(0);c[2426872]=O&255|D;break};case 83:{b[4853744]=(b[4821362]|0)-13&65535;break};case 84:{b[4853744]=(b[4821362]|0)-12&65535;break};case 85:{b[4853744]=(b[4821362]|0)-11&65535;break};case 86:{b[4853744]=(b[4821362]|0)-10&65535;break};case 87:{b[4853744]=(b[4821362]|0)-9&65535;break};case 88:{b[4853744]=(b[4821362]|0)-8&65535;break};case 89:{b[4853744]=(b[4821362]|0)-7&65535;break};case 90:{b[4853744]=(b[4821362]|0)-6&65535;break};case 91:{b[4853744]=(b[4821362]|0)-5&65535;break};case 92:{b[4853744]=(b[4821362]|0)-4&65535;break};case 93:{b[4853744]=(b[4821362]|0)-3&65535;break};case 94:{b[4853744]=(b[4821362]|0)-2&65535;break};case 95:{b[4853744]=(b[4821362]|0)-1&65535;break};case 96:{b[4853744]=b[4821364]|0;break};case 97:{b[4853744]=(b[4821364]|0)+1&65535;break};case 98:{b[4853744]=(b[4821364]|0)+2&65535;break};case 99:{b[4853744]=(b[4821364]|0)+3&65535;break};case 100:{b[4853744]=(b[4821364]|0)+4&65535;break};case 23:{b[4853744]=(b[4821366]|0)-9&65535;break};case 24:{b[4853744]=(b[4821366]|0)-8&65535;break};case 47:{b[4853744]=(b[4821368]|0)+15&65535;break};case 48:{b[4853744]=(b[4821368]|0)-16&65535;break};case 49:{b[4853744]=(b[4821368]|0)-15&65535;break};case 101:{b[4853744]=(b[4821364]|0)+5&65535;break};case 102:{b[4853744]=(b[4821364]|0)+6&65535;break};case 103:{b[4853744]=(b[4821364]|0)+7&65535;break};case 104:{b[4853744]=(b[4821364]|0)+8&65535;break};case 105:{b[4853744]=(b[4821364]|0)+9&65535;break};case 106:{b[4853744]=(b[4821364]|0)+10&65535;break};case 107:{b[4853744]=(b[4821364]|0)+11&65535;break};case 108:{b[4853744]=(b[4821364]|0)+12&65535;break};case 109:{b[4853744]=(b[4821364]|0)+13&65535;break};case 110:{b[4853744]=(b[4821364]|0)+14&65535;break};case 111:{b[4853744]=(b[4821364]|0)+15&65535;break};case 112:{b[4853744]=(b[4821364]|0)-16&65535;break};case 113:{b[4853744]=(b[4821364]|0)-15&65535;break};case 114:{b[4853744]=(b[4821364]|0)-14&65535;break};case 115:{b[4853744]=(b[4821364]|0)-13&65535;break};case 116:{b[4853744]=(b[4821364]|0)-12&65535;break};case 117:{b[4853744]=(b[4821364]|0)-11&65535;break};case 118:{b[4853744]=(b[4821364]|0)-10&65535;break};case 119:{b[4853744]=(b[4821364]|0)-9&65535;break};case 120:{b[4853744]=(b[4821364]|0)-8&65535;break};case 121:{b[4853744]=(b[4821364]|0)-7&65535;break};case 122:{b[4853744]=(b[4821364]|0)-6&65535;break};case 123:{b[4853744]=(b[4821364]|0)-5&65535;break};case 124:{b[4853744]=(b[4821364]|0)-4&65535;break};case 125:{b[4853744]=(b[4821364]|0)-3&65535;break};case 126:{b[4853744]=(b[4821364]|0)-2&65535;break};case 127:{b[4853744]=(b[4821364]|0)-1&65535;break};case 128:{D=b[4821366]|0;b[4853744]=D;b[4821366]=D+1&65535;break};case 129:{D=b[4821366]|0;b[4853744]=D;b[4821366]=D+2&65535;break};case 130:{D=(b[4821366]|0)-1&65535;b[4821366]=D;b[4853744]=D;break};case 131:{D=(b[4821366]|0)-2&65535;b[4821366]=D;b[4853744]=D;break};case 132:{b[4853744]=b[4821366]|0;break};case 133:{D=d[9642712]|0;b[4853744]=((D&128|0)!=0?D|65280:D)+(e[4821366]|0)&65535;break};case 134:{D=d[9642713]|0;b[4853744]=((D&128|0)!=0?D|65280:D)+(e[4821366]|0)&65535;break};case 135:{D=d[9642717]|0;b[4853744]=((D&128|0)!=0?D|65280:D)+(e[4821366]|0)&65535;break};case 136:{D=c[2410676]|0;O=D&65535;L=c[3528552]|0;H=c[2433426]|0;z=c[H+(L*3160|0)+60+((D>>>8&255|512)<<2)>>2]|0;do{if((z|0)==0){M=c[H+(L*3160|0)+3144>>2]|0;if((M|0)==0){P=0;Q=O;break}N=gj[M&4095](O)|0;P=N;Q=b[4821352]|0}else{P=a[z+(D&255)|0]|0;Q=O}}while(0);O=P&255;b[4821352]=Q+1&65535;b[4853744]=((O&128)!=0?O|-256:O)+(b[4821366]|0)&65535;break};case 137:{O=c[2410676]|0;Q=O&65535;P=c[3528552]|0;D=c[2433426]|0;z=c[D+(P*3160|0)+60+((O>>>8&255|512)<<2)>>2]|0;do{if((z|0)==0){L=c[D+(P*3160|0)+3144>>2]|0;if((L|0)==0){R=0;S=O;T=P;U=D;V=Q;break}H=gj[L&4095](Q)|0;L=c[2410676]|0;R=H;S=L;T=c[3528552]|0;U=c[2433426]|0;V=L&65535}else{R=a[z+(O&255)|0]|0;S=O;T=P;U=D;V=Q}}while(0);Q=(R&255)<<8;R=S+1|0;S=R&65535;D=c[U+(T*3160|0)+60+((R>>>8&255|512)<<2)>>2]|0;do{if((D|0)==0){P=c[U+(T*3160|0)+3144>>2]|0;if((P|0)==0){W=0;X=V;break}O=gj[P&4095](S)|0;W=O;X=b[4821352]|0}else{W=a[D+(R&255)|0]|0;X=V}}while(0);V=W&255|Q;c[2426872]=V;b[4821352]=X+2&65535;b[4853744]=(V&65535)+(b[4821366]|0)&65535;break};case 138:{V=d[9642716]|0;b[4853744]=((V&128|0)!=0?V|65280:V)+(e[4821366]|0)&65535;break};case 139:{b[4853744]=(b[4821356]|0)+(b[4821366]|0)&65535;break};case 140:{V=c[2410676]|0;X=V&65535;Q=c[3528552]|0;W=c[2433426]|0;R=c[W+(Q*3160|0)+60+((V>>>8&255|512)<<2)>>2]|0;do{if((R|0)==0){D=c[W+(Q*3160|0)+3144>>2]|0;if((D|0)==0){Y=0;Z=X;break}S=gj[D&4095](X)|0;Y=S;Z=b[4821352]|0}else{Y=a[R+(V&255)|0]|0;Z=X}}while(0);X=Y&255;Y=Z+1&65535;b[4821352]=Y;b[4853744]=((X&128)!=0?X|-256:X)+Y&65535;break};case 150:{Y=d[9642713]|0;b[4853744]=((Y&128|0)!=0?Y|65280:Y)+(e[4821366]|0)&65535;Y=c[2426872]|0;X=Y&65535;Z=c[3528552]|0;V=c[2433426]|0;R=c[V+(Z*3160|0)+60+((Y>>>8&255)<<2)>>2]|0;do{if((R|0)==0){Q=c[V+(Z*3160|0)+3132>>2]|0;if((Q|0)==0){_=0;$=Z;aa=V;break}W=gj[Q&4095](X)|0;_=W;$=c[3528552]|0;aa=c[2433426]|0}else{_=a[R+(Y&255)|0]|0;$=Z;aa=V}}while(0);V=(_&255)<<8;_=Y+1|0;Y=_&65535;Z=c[aa+($*3160|0)+60+((_>>>8&255)<<2)>>2]|0;do{if((Z|0)==0){R=c[aa+($*3160|0)+3132>>2]|0;if((R|0)==0){ab=0;break}ab=gj[R&4095](Y)|0}else{ab=a[Z+(_&255)|0]|0}}while(0);c[2426872]=ab&255|V;break};case 151:{V=d[9642717]|0;b[4853744]=((V&128|0)!=0?V|65280:V)+(e[4821366]|0)&65535;V=c[2426872]|0;ab=V&65535;_=c[3528552]|0;Z=c[2433426]|0;Y=c[Z+(_*3160|0)+60+((V>>>8&255)<<2)>>2]|0;do{if((Y|0)==0){$=c[Z+(_*3160|0)+3132>>2]|0;if(($|0)==0){ac=0;ad=_;ae=Z;break}aa=gj[$&4095](ab)|0;ac=aa;ad=c[3528552]|0;ae=c[2433426]|0}else{ac=a[Y+(V&255)|0]|0;ad=_;ae=Z}}while(0);Z=(ac&255)<<8;ac=V+1|0;V=ac&65535;_=c[ae+(ad*3160|0)+60+((ac>>>8&255)<<2)>>2]|0;do{if((_|0)==0){Y=c[ae+(ad*3160|0)+3132>>2]|0;if((Y|0)==0){af=0;break}af=gj[Y&4095](V)|0}else{af=a[_+(ac&255)|0]|0}}while(0);c[2426872]=af&255|Z;break};case 152:{Z=c[2410676]|0;af=Z&65535;ac=c[3528552]|0;_=c[2433426]|0;V=c[_+(ac*3160|0)+60+((Z>>>8&255|512)<<2)>>2]|0;do{if((V|0)==0){ad=c[_+(ac*3160|0)+3144>>2]|0;if((ad|0)==0){ag=0;ah=af;ai=ac;aj=_;break}ae=gj[ad&4095](af)|0;ag=ae;ah=b[4821352]|0;ai=c[3528552]|0;aj=c[2433426]|0}else{ag=a[V+(Z&255)|0]|0;ah=af;ai=ac;aj=_}}while(0);_=ag&255;b[4821352]=ah+1&65535;b[4853744]=((_&128)!=0?_|-256:_)+(b[4821366]|0)&65535;_=c[2426872]|0;ah=_&65535;ag=c[aj+(ai*3160|0)+60+((_>>>8&255)<<2)>>2]|0;do{if((ag|0)==0){ac=c[aj+(ai*3160|0)+3132>>2]|0;if((ac|0)==0){ak=0;al=ai;am=aj;break}af=gj[ac&4095](ah)|0;ak=af;al=c[3528552]|0;am=c[2433426]|0}else{ak=a[ag+(_&255)|0]|0;al=ai;am=aj}}while(0);aj=(ak&255)<<8;ak=_+1|0;_=ak&65535;ai=c[am+(al*3160|0)+60+((ak>>>8&255)<<2)>>2]|0;do{if((ai|0)==0){ag=c[am+(al*3160|0)+3132>>2]|0;if((ag|0)==0){an=0;break}an=gj[ag&4095](_)|0}else{an=a[ai+(ak&255)|0]|0}}while(0);c[2426872]=an&255|aj;break};case 153:{aj=c[2410676]|0;an=aj&65535;ak=c[3528552]|0;ai=c[2433426]|0;_=c[ai+(ak*3160|0)+60+((aj>>>8&255|512)<<2)>>2]|0;do{if((_|0)==0){al=c[ai+(ak*3160|0)+3144>>2]|0;if((al|0)==0){ao=0;ap=aj;aq=ak;ar=ai;as=an;break}am=gj[al&4095](an)|0;al=c[2410676]|0;ao=am;ap=al;aq=c[3528552]|0;ar=c[2433426]|0;as=al&65535}else{ao=a[_+(aj&255)|0]|0;ap=aj;aq=ak;ar=ai;as=an}}while(0);an=(ao&255)<<8;ao=ap+1|0;ap=ao&65535;ai=c[ar+(aq*3160|0)+60+((ao>>>8&255|512)<<2)>>2]|0;do{if((ai|0)==0){ak=c[ar+(aq*3160|0)+3144>>2]|0;if((ak|0)==0){at=0;au=as;av=aq;aw=ar;break}aj=gj[ak&4095](ap)|0;at=aj;au=b[4821352]|0;av=c[3528552]|0;aw=c[2433426]|0}else{at=a[ai+(ao&255)|0]|0;au=as;av=aq;aw=ar}}while(0);ar=at&255|an;c[2426872]=ar;b[4821352]=au+2&65535;b[4853744]=(ar&65535)+(b[4821366]|0)&65535;ar=c[2426872]|0;au=ar&65535;an=c[aw+(av*3160|0)+60+((ar>>>8&255)<<2)>>2]|0;do{if((an|0)==0){at=c[aw+(av*3160|0)+3132>>2]|0;if((at|0)==0){ax=0;ay=av;az=aw;break}aq=gj[at&4095](au)|0;ax=aq;ay=c[3528552]|0;az=c[2433426]|0}else{ax=a[an+(ar&255)|0]|0;ay=av;az=aw}}while(0);aw=(ax&255)<<8;ax=ar+1|0;ar=ax&65535;av=c[az+(ay*3160|0)+60+((ax>>>8&255)<<2)>>2]|0;do{if((av|0)==0){an=c[az+(ay*3160|0)+3132>>2]|0;if((an|0)==0){aA=0;break}aA=gj[an&4095](ar)|0}else{aA=a[av+(ax&255)|0]|0}}while(0);c[2426872]=aA&255|aw;break};case 154:{aw=d[9642716]|0;b[4853744]=((aw&128|0)!=0?aw|65280:aw)+(e[4821366]|0)&65535;aw=c[2426872]|0;aA=aw&65535;ax=c[3528552]|0;av=c[2433426]|0;ar=c[av+(ax*3160|0)+60+((aw>>>8&255)<<2)>>2]|0;do{if((ar|0)==0){ay=c[av+(ax*3160|0)+3132>>2]|0;if((ay|0)==0){aB=0;aC=ax;aD=av;break}az=gj[ay&4095](aA)|0;aB=az;aC=c[3528552]|0;aD=c[2433426]|0}else{aB=a[ar+(aw&255)|0]|0;aC=ax;aD=av}}while(0);av=(aB&255)<<8;aB=aw+1|0;aw=aB&65535;ax=c[aD+(aC*3160|0)+60+((aB>>>8&255)<<2)>>2]|0;do{if((ax|0)==0){ar=c[aD+(aC*3160|0)+3132>>2]|0;if((ar|0)==0){aE=0;break}aE=gj[ar&4095](aw)|0}else{aE=a[ax+(aB&255)|0]|0}}while(0);c[2426872]=aE&255|av;break};case 155:{b[4853744]=(b[4821356]|0)+(b[4821366]|0)&65535;av=c[2426872]|0;aE=av&65535;aB=c[3528552]|0;ax=c[2433426]|0;aw=c[ax+(aB*3160|0)+60+((av>>>8&255)<<2)>>2]|0;do{if((aw|0)==0){aC=c[ax+(aB*3160|0)+3132>>2]|0;if((aC|0)==0){aF=0;aG=aB;aH=ax;break}aD=gj[aC&4095](aE)|0;aF=aD;aG=c[3528552]|0;aH=c[2433426]|0}else{aF=a[aw+(av&255)|0]|0;aG=aB;aH=ax}}while(0);ax=(aF&255)<<8;aF=av+1|0;av=aF&65535;aB=c[aH+(aG*3160|0)+60+((aF>>>8&255)<<2)>>2]|0;do{if((aB|0)==0){aw=c[aH+(aG*3160|0)+3132>>2]|0;if((aw|0)==0){aI=0;break}aI=gj[aw&4095](av)|0}else{aI=a[aB+(aF&255)|0]|0}}while(0);c[2426872]=aI&255|ax;break};case 156:{ax=c[2410676]|0;aI=ax&65535;aF=c[3528552]|0;aB=c[2433426]|0;av=c[aB+(aF*3160|0)+60+((ax>>>8&255|512)<<2)>>2]|0;do{if((av|0)==0){aG=c[aB+(aF*3160|0)+3144>>2]|0;if((aG|0)==0){aJ=0;aK=aI;aL=aF;aM=aB;break}aH=gj[aG&4095](aI)|0;aJ=aH;aK=b[4821352]|0;aL=c[3528552]|0;aM=c[2433426]|0}else{aJ=a[av+(ax&255)|0]|0;aK=aI;aL=aF;aM=aB}}while(0);aB=aJ&255;aJ=aK+1&65535;b[4821352]=aJ;b[4853744]=((aB&128)!=0?aB|-256:aB)+aJ&65535;aJ=c[2426872]|0;aB=aJ&65535;aK=c[aM+(aL*3160|0)+60+((aJ>>>8&255)<<2)>>2]|0;do{if((aK|0)==0){aF=c[aM+(aL*3160|0)+3132>>2]|0;if((aF|0)==0){aN=0;aO=aL;aP=aM;break}aI=gj[aF&4095](aB)|0;aN=aI;aO=c[3528552]|0;aP=c[2433426]|0}else{aN=a[aK+(aJ&255)|0]|0;aO=aL;aP=aM}}while(0);aM=(aN&255)<<8;aN=aJ+1|0;aJ=aN&65535;aL=c[aP+(aO*3160|0)+60+((aN>>>8&255)<<2)>>2]|0;do{if((aL|0)==0){aK=c[aP+(aO*3160|0)+3132>>2]|0;if((aK|0)==0){aQ=0;break}aQ=gj[aK&4095](aJ)|0}else{aQ=a[aL+(aN&255)|0]|0}}while(0);c[2426872]=aQ&255|aM;break};case 157:{aM=c[2410676]|0;aQ=aM&65535;aN=c[3528552]|0;aL=c[2433426]|0;aJ=c[aL+(aN*3160|0)+60+((aM>>>8&255|512)<<2)>>2]|0;do{if((aJ|0)==0){aO=c[aL+(aN*3160|0)+3144>>2]|0;if((aO|0)==0){aR=0;aS=aM;aT=aN;aU=aL;aV=aQ;break}aP=gj[aO&4095](aQ)|0;aO=c[2410676]|0;aR=aP;aS=aO;aT=c[3528552]|0;aU=c[2433426]|0;aV=aO&65535}else{aR=a[aJ+(aM&255)|0]|0;aS=aM;aT=aN;aU=aL;aV=aQ}}while(0);aQ=(aR&255)<<8;aR=aS+1|0;aS=aR&65535;aL=c[aU+(aT*3160|0)+60+((aR>>>8&255|512)<<2)>>2]|0;do{if((aL|0)==0){aN=c[aU+(aT*3160|0)+3144>>2]|0;if((aN|0)==0){aW=0;aX=aV;aY=aT;aZ=aU;break}aM=gj[aN&4095](aS)|0;aW=aM;aX=b[4821352]|0;aY=c[3528552]|0;aZ=c[2433426]|0}else{aW=a[aL+(aR&255)|0]|0;aX=aV;aY=aT;aZ=aU}}while(0);aU=aW&255|aQ;c[2426872]=aU;aQ=aX+2&65535;b[4821352]=aQ;b[4853744]=(aU&65535)+aQ&65535;aQ=c[2426872]|0;aU=aQ&65535;aX=c[aZ+(aY*3160|0)+60+((aQ>>>8&255)<<2)>>2]|0;do{if((aX|0)==0){aW=c[aZ+(aY*3160|0)+3132>>2]|0;if((aW|0)==0){a_=0;a$=aY;a0=aZ;break}aT=gj[aW&4095](aU)|0;a_=aT;a$=c[3528552]|0;a0=c[2433426]|0}else{a_=a[aX+(aQ&255)|0]|0;a$=aY;a0=aZ}}while(0);aZ=(a_&255)<<8;a_=aQ+1|0;aQ=a_&65535;aY=c[a0+(a$*3160|0)+60+((a_>>>8&255)<<2)>>2]|0;do{if((aY|0)==0){aX=c[a0+(a$*3160|0)+3132>>2]|0;if((aX|0)==0){a1=0;break}a1=gj[aX&4095](aQ)|0}else{a1=a[aY+(a_&255)|0]|0}}while(0);c[2426872]=a1&255|aZ;break};case 158:{b[4853744]=(b[4821358]|0)+(b[4821366]|0)&65535;aZ=c[2426872]|0;a1=aZ&65535;a_=c[3528552]|0;aY=c[2433426]|0;aQ=c[aY+(a_*3160|0)+60+((aZ>>>8&255)<<2)>>2]|0;do{if((aQ|0)==0){a$=c[aY+(a_*3160|0)+3132>>2]|0;if((a$|0)==0){a2=0;a3=a_;a4=aY;break}a0=gj[a$&4095](a1)|0;a2=a0;a3=c[3528552]|0;a4=c[2433426]|0}else{a2=a[aQ+(aZ&255)|0]|0;a3=a_;a4=aY}}while(0);aY=(a2&255)<<8;a2=aZ+1|0;aZ=a2&65535;a_=c[a4+(a3*3160|0)+60+((a2>>>8&255)<<2)>>2]|0;do{if((a_|0)==0){aQ=c[a4+(a3*3160|0)+3132>>2]|0;if((aQ|0)==0){a5=0;break}a5=gj[aQ&4095](aZ)|0}else{a5=a[a_+(a2&255)|0]|0}}while(0);c[2426872]=a5&255|aY;break};case 159:{aY=c[2410676]|0;a5=aY&65535;a2=c[3528552]|0;a_=c[2433426]|0;aZ=c[a_+(a2*3160|0)+60+((aY>>>8&255|512)<<2)>>2]|0;do{if((aZ|0)==0){a3=c[a_+(a2*3160|0)+3144>>2]|0;if((a3|0)==0){a6=0;a7=aY;a8=a2;a9=a_;ba=a5;break}a4=gj[a3&4095](a5)|0;a3=c[2410676]|0;a6=a4;a7=a3;a8=c[3528552]|0;a9=c[2433426]|0;ba=a3&65535}else{a6=a[aZ+(aY&255)|0]|0;a7=aY;a8=a2;a9=a_;ba=a5}}while(0);a5=a6&255;a6=a5<<8;a_=a7+1|0;a7=a_&65535;a2=c[a9+(a8*3160|0)+60+((a_>>>8&255|512)<<2)>>2]|0;do{if((a2|0)==0){aY=c[a9+(a8*3160|0)+3144>>2]|0;if((aY|0)==0){bb=0;bc=ba;bd=a8;be=a9;break}aZ=gj[aY&4095](a7)|0;bb=aZ;bc=b[4821352]|0;bd=c[3528552]|0;be=c[2433426]|0}else{bb=a[a2+(a_&255)|0]|0;bc=ba;bd=a8;be=a9}}while(0);a9=bb&255;bb=a9|a6;c[2426872]=bb;b[4821352]=bc+2&65535;bc=bb&65535;a6=c[be+(bd*3160|0)+60+(a5<<2)>>2]|0;do{if((a6|0)==0){a5=c[be+(bd*3160|0)+3132>>2]|0;if((a5|0)==0){bf=0;bg=bd;bh=be;break}a8=gj[a5&4095](bc)|0;bf=a8;bg=c[3528552]|0;bh=c[2433426]|0}else{bf=a[a6+a9|0]|0;bg=bd;bh=be}}while(0);be=(bf&255)<<8;bf=bb+1|0;bb=bf&65535;bd=c[bh+(bg*3160|0)+60+((bf>>>8&255)<<2)>>2]|0;do{if((bd|0)==0){a9=c[bh+(bg*3160|0)+3132>>2]|0;if((a9|0)==0){bi=0;break}bi=gj[a9&4095](bb)|0}else{bi=a[bd+(bf&255)|0]|0}}while(0);c[2426872]=bi&255|be;break};case 160:{be=b[4821368]|0;b[4853744]=be;b[4821368]=be+1&65535;break};case 161:{be=b[4821368]|0;b[4853744]=be;b[4821368]=be+2&65535;break};case 162:{be=(b[4821368]|0)-1&65535;b[4821368]=be;b[4853744]=be;break};case 163:{be=(b[4821368]|0)-2&65535;b[4821368]=be;b[4853744]=be;break};case 164:{b[4853744]=b[4821368]|0;break};case 165:{be=d[9642712]|0;b[4853744]=((be&128|0)!=0?be|65280:be)+(e[4821368]|0)&65535;break};case 166:{be=d[9642713]|0;b[4853744]=((be&128|0)!=0?be|65280:be)+(e[4821368]|0)&65535;break};case 167:{be=d[9642717]|0;b[4853744]=((be&128|0)!=0?be|65280:be)+(e[4821368]|0)&65535;break};case 168:{be=c[2410676]|0;bi=be&65535;bf=c[3528552]|0;bd=c[2433426]|0;bb=c[bd+(bf*3160|0)+60+((be>>>8&255|512)<<2)>>2]|0;do{if((bb|0)==0){bg=c[bd+(bf*3160|0)+3144>>2]|0;if((bg|0)==0){bj=0;bk=bi;break}bh=gj[bg&4095](bi)|0;bj=bh;bk=b[4821352]|0}else{bj=a[bb+(be&255)|0]|0;bk=bi}}while(0);bi=bj&255;b[4821352]=bk+1&65535;b[4853744]=((bi&128)!=0?bi|-256:bi)+(b[4821368]|0)&65535;break};case 169:{bi=c[2410676]|0;bk=bi&65535;bj=c[3528552]|0;be=c[2433426]|0;bb=c[be+(bj*3160|0)+60+((bi>>>8&255|512)<<2)>>2]|0;do{if((bb|0)==0){bf=c[be+(bj*3160|0)+3144>>2]|0;if((bf|0)==0){bl=0;bm=bi;bn=bj;bo=be;bp=bk;break}bd=gj[bf&4095](bk)|0;bf=c[2410676]|0;bl=bd;bm=bf;bn=c[3528552]|0;bo=c[2433426]|0;bp=bf&65535}else{bl=a[bb+(bi&255)|0]|0;bm=bi;bn=bj;bo=be;bp=bk}}while(0);bk=(bl&255)<<8;bl=bm+1|0;bm=bl&65535;be=c[bo+(bn*3160|0)+60+((bl>>>8&255|512)<<2)>>2]|0;do{if((be|0)==0){bj=c[bo+(bn*3160|0)+3144>>2]|0;if((bj|0)==0){bq=0;br=bp;break}bi=gj[bj&4095](bm)|0;bq=bi;br=b[4821352]|0}else{bq=a[be+(bl&255)|0]|0;br=bp}}while(0);bp=bq&255|bk;c[2426872]=bp;b[4821352]=br+2&65535;b[4853744]=(bp&65535)+(b[4821368]|0)&65535;break};case 170:{bp=d[9642716]|0;b[4853744]=((bp&128|0)!=0?bp|65280:bp)+(e[4821368]|0)&65535;break};case 171:{b[4853744]=(b[4821356]|0)+(b[4821368]|0)&65535;break};case 172:{bp=c[2410676]|0;br=bp&65535;bk=c[3528552]|0;bq=c[2433426]|0;bl=c[bq+(bk*3160|0)+60+((bp>>>8&255|512)<<2)>>2]|0;do{if((bl|0)==0){be=c[bq+(bk*3160|0)+3144>>2]|0;if((be|0)==0){bs=0;bt=br;break}bm=gj[be&4095](br)|0;bs=bm;bt=b[4821352]|0}else{bs=a[bl+(bp&255)|0]|0;bt=br}}while(0);br=bs&255;bs=bt+1&65535;b[4821352]=bs;b[4853744]=((br&128)!=0?br|-256:br)+bs&65535;break};case 173:{bs=c[2410676]|0;br=bs&65535;bt=c[3528552]|0;bp=c[2433426]|0;bl=c[bp+(bt*3160|0)+60+((bs>>>8&255|512)<<2)>>2]|0;do{if((bl|0)==0){bk=c[bp+(bt*3160|0)+3144>>2]|0;if((bk|0)==0){bu=0;bv=bs;bw=bt;bx=bp;by=br;break}bq=gj[bk&4095](br)|0;bk=c[2410676]|0;bu=bq;bv=bk;bw=c[3528552]|0;bx=c[2433426]|0;by=bk&65535}else{bu=a[bl+(bs&255)|0]|0;bv=bs;bw=bt;bx=bp;by=br}}while(0);br=(bu&255)<<8;bu=bv+1|0;bv=bu&65535;bp=c[bx+(bw*3160|0)+60+((bu>>>8&255|512)<<2)>>2]|0;do{if((bp|0)==0){bt=c[bx+(bw*3160|0)+3144>>2]|0;if((bt|0)==0){bz=0;bA=by;break}bs=gj[bt&4095](bv)|0;bz=bs;bA=b[4821352]|0}else{bz=a[bp+(bu&255)|0]|0;bA=by}}while(0);by=bz&255|br;c[2426872]=by;br=bA+2&65535;b[4821352]=br;b[4853744]=(by&65535)+br&65535;break};case 174:{b[4853744]=(b[4821358]|0)+(b[4821368]|0)&65535;break};case 175:{br=c[2410676]|0;by=br&65535;bA=c[3528552]|0;bz=c[2433426]|0;bu=c[bz+(bA*3160|0)+60+((br>>>8&255|512)<<2)>>2]|0;do{if((bu|0)==0){bp=c[bz+(bA*3160|0)+3144>>2]|0;if((bp|0)==0){bB=0;bC=br;bD=bA;bE=bz;bF=by;break}bv=gj[bp&4095](by)|0;bp=c[2410676]|0;bB=bv;bC=bp;bD=c[3528552]|0;bE=c[2433426]|0;bF=bp&65535}else{bB=a[bu+(br&255)|0]|0;bC=br;bD=bA;bE=bz;bF=by}}while(0);by=(bB&255)<<8;bB=bC+1|0;bC=bB&65535;bz=c[bE+(bD*3160|0)+60+((bB>>>8&255|512)<<2)>>2]|0;do{if((bz|0)==0){bA=c[bE+(bD*3160|0)+3144>>2]|0;if((bA|0)==0){bG=0;bH=bF;break}br=gj[bA&4095](bC)|0;bG=br;bH=b[4821352]|0}else{bG=a[bz+(bB&255)|0]|0;bH=bF}}while(0);bF=bG&255|by;c[2426872]=bF;b[4821352]=bH+2&65535;b[4853744]=(bF&65535)+(b[4821358]|0)&65535;break};case 176:{bF=c[2410676]|0;bH=bF&65535;by=c[3528552]|0;bG=c[2433426]|0;bB=c[bG+(by*3160|0)+60+((bF>>>8&255|512)<<2)>>2]|0;do{if((bB|0)==0){bz=c[bG+(by*3160|0)+3144>>2]|0;if((bz|0)==0){bI=0;bJ=bF;bK=by;bL=bG;bM=bH;break}bC=gj[bz&4095](bH)|0;bz=c[2410676]|0;bI=bC;bJ=bz;bK=c[3528552]|0;bL=c[2433426]|0;bM=bz&65535}else{bI=a[bB+(bF&255)|0]|0;bJ=bF;bK=by;bL=bG;bM=bH}}while(0);bH=(bI&255)<<8;bI=bJ+1|0;bJ=bI&65535;bG=c[bL+(bK*3160|0)+60+((bI>>>8&255|512)<<2)>>2]|0;do{if((bG|0)==0){by=c[bL+(bK*3160|0)+3144>>2]|0;if((by|0)==0){bN=0;bO=bM;bP=bK;bQ=bL;break}bF=gj[by&4095](bJ)|0;bN=bF;bO=b[4821352]|0;bP=c[3528552]|0;bQ=c[2433426]|0}else{bN=a[bG+(bI&255)|0]|0;bO=bM;bP=bK;bQ=bL}}while(0);bL=bN&255|bH;c[2426872]=bL;b[4821352]=bO+2&65535;b[4853744]=(bL&65535)+(b[4821358]|0)&65535;bL=c[2426872]|0;bO=bL&65535;bH=c[bQ+(bP*3160|0)+60+((bL>>>8&255)<<2)>>2]|0;do{if((bH|0)==0){bN=c[bQ+(bP*3160|0)+3132>>2]|0;if((bN|0)==0){bR=0;bS=bP;bT=bQ;break}bK=gj[bN&4095](bO)|0;bR=bK;bS=c[3528552]|0;bT=c[2433426]|0}else{bR=a[bH+(bL&255)|0]|0;bS=bP;bT=bQ}}while(0);bQ=(bR&255)<<8;bR=bL+1|0;bL=bR&65535;bP=c[bT+(bS*3160|0)+60+((bR>>>8&255)<<2)>>2]|0;do{if((bP|0)==0){bH=c[bT+(bS*3160|0)+3132>>2]|0;if((bH|0)==0){bU=0;break}bU=gj[bH&4095](bL)|0}else{bU=a[bP+(bR&255)|0]|0}}while(0);c[2426872]=bU&255|bQ;break};case 177:{bQ=b[4821368]|0;b[4853744]=bQ;b[4821368]=bQ+2&65535;bQ=c[2426872]|0;bU=bQ&65535;bR=c[3528552]|0;bP=c[2433426]|0;bL=c[bP+(bR*3160|0)+60+((bQ>>>8&255)<<2)>>2]|0;do{if((bL|0)==0){bS=c[bP+(bR*3160|0)+3132>>2]|0;if((bS|0)==0){bV=0;bW=bR;bX=bP;break}bT=gj[bS&4095](bU)|0;bV=bT;bW=c[3528552]|0;bX=c[2433426]|0}else{bV=a[bL+(bQ&255)|0]|0;bW=bR;bX=bP}}while(0);bP=(bV&255)<<8;bV=bQ+1|0;bQ=bV&65535;bR=c[bX+(bW*3160|0)+60+((bV>>>8&255)<<2)>>2]|0;do{if((bR|0)==0){bL=c[bX+(bW*3160|0)+3132>>2]|0;if((bL|0)==0){bY=0;break}bY=gj[bL&4095](bQ)|0}else{bY=a[bR+(bV&255)|0]|0}}while(0);c[2426872]=bY&255|bP;break};case 178:{a[9642745]=a[9642745]|64;fGQ();break};case 179:{bP=(b[4821368]|0)-2&65535;b[4821368]=bP;b[4853744]=bP;bP=c[2426872]|0;bY=bP&65535;bV=c[3528552]|0;bR=c[2433426]|0;bQ=c[bR+(bV*3160|0)+60+((bP>>>8&255)<<2)>>2]|0;do{if((bQ|0)==0){bW=c[bR+(bV*3160|0)+3132>>2]|0;if((bW|0)==0){bZ=0;b_=bV;b$=bR;break}bX=gj[bW&4095](bY)|0;bZ=bX;b_=c[3528552]|0;b$=c[2433426]|0}else{bZ=a[bQ+(bP&255)|0]|0;b_=bV;b$=bR}}while(0);bR=(bZ&255)<<8;bZ=bP+1|0;bP=bZ&65535;bV=c[b$+(b_*3160|0)+60+((bZ>>>8&255)<<2)>>2]|0;do{if((bV|0)==0){bQ=c[b$+(b_*3160|0)+3132>>2]|0;if((bQ|0)==0){b0=0;break}b0=gj[bQ&4095](bP)|0}else{b0=a[bV+(bZ&255)|0]|0}}while(0);c[2426872]=b0&255|bR;break};case 180:{b[4853744]=b[4821368]|0;bR=c[2426872]|0;b0=bR&65535;bZ=c[3528552]|0;bV=c[2433426]|0;bP=c[bV+(bZ*3160|0)+60+((bR>>>8&255)<<2)>>2]|0;do{if((bP|0)==0){b_=c[bV+(bZ*3160|0)+3132>>2]|0;if((b_|0)==0){b1=0;b2=bZ;b3=bV;break}b$=gj[b_&4095](b0)|0;b1=b$;b2=c[3528552]|0;b3=c[2433426]|0}else{b1=a[bP+(bR&255)|0]|0;b2=bZ;b3=bV}}while(0);bV=(b1&255)<<8;b1=bR+1|0;bR=b1&65535;bZ=c[b3+(b2*3160|0)+60+((b1>>>8&255)<<2)>>2]|0;do{if((bZ|0)==0){bP=c[b3+(b2*3160|0)+3132>>2]|0;if((bP|0)==0){b4=0;break}b4=gj[bP&4095](bR)|0}else{b4=a[bZ+(b1&255)|0]|0}}while(0);c[2426872]=b4&255|bV;break};case 181:{bV=d[9642712]|0;b[4853744]=((bV&128|0)!=0?bV|65280:bV)+(e[4821368]|0)&65535;bV=c[2426872]|0;b4=bV&65535;b1=c[3528552]|0;bZ=c[2433426]|0;bR=c[bZ+(b1*3160|0)+60+((bV>>>8&255)<<2)>>2]|0;do{if((bR|0)==0){b2=c[bZ+(b1*3160|0)+3132>>2]|0;if((b2|0)==0){b5=0;b6=b1;b7=bZ;break}b3=gj[b2&4095](b4)|0;b5=b3;b6=c[3528552]|0;b7=c[2433426]|0}else{b5=a[bR+(bV&255)|0]|0;b6=b1;b7=bZ}}while(0);bZ=(b5&255)<<8;b5=bV+1|0;bV=b5&65535;b1=c[b7+(b6*3160|0)+60+((b5>>>8&255)<<2)>>2]|0;do{if((b1|0)==0){bR=c[b7+(b6*3160|0)+3132>>2]|0;if((bR|0)==0){b8=0;break}b8=gj[bR&4095](bV)|0}else{b8=a[b1+(b5&255)|0]|0}}while(0);c[2426872]=b8&255|bZ;break};case 182:{bZ=d[9642713]|0;b[4853744]=((bZ&128|0)!=0?bZ|65280:bZ)+(e[4821368]|0)&65535;bZ=c[2426872]|0;b8=bZ&65535;b5=c[3528552]|0;b1=c[2433426]|0;bV=c[b1+(b5*3160|0)+60+((bZ>>>8&255)<<2)>>2]|0;do{if((bV|0)==0){b6=c[b1+(b5*3160|0)+3132>>2]|0;if((b6|0)==0){b9=0;ca=b5;cb=b1;break}b7=gj[b6&4095](b8)|0;b9=b7;ca=c[3528552]|0;cb=c[2433426]|0}else{b9=a[bV+(bZ&255)|0]|0;ca=b5;cb=b1}}while(0);b1=(b9&255)<<8;b9=bZ+1|0;bZ=b9&65535;b5=c[cb+(ca*3160|0)+60+((b9>>>8&255)<<2)>>2]|0;do{if((b5|0)==0){bV=c[cb+(ca*3160|0)+3132>>2]|0;if((bV|0)==0){cc=0;break}cc=gj[bV&4095](bZ)|0}else{cc=a[b5+(b9&255)|0]|0}}while(0);c[2426872]=cc&255|b1;break};case 183:{b1=d[9642717]|0;b[4853744]=((b1&128|0)!=0?b1|65280:b1)+(e[4821368]|0)&65535;b1=c[2426872]|0;cc=b1&65535;b9=c[3528552]|0;b5=c[2433426]|0;bZ=c[b5+(b9*3160|0)+60+((b1>>>8&255)<<2)>>2]|0;do{if((bZ|0)==0){ca=c[b5+(b9*3160|0)+3132>>2]|0;if((ca|0)==0){cd=0;ce=b9;cf=b5;break}cb=gj[ca&4095](cc)|0;cd=cb;ce=c[3528552]|0;cf=c[2433426]|0}else{cd=a[bZ+(b1&255)|0]|0;ce=b9;cf=b5}}while(0);b5=(cd&255)<<8;cd=b1+1|0;b1=cd&65535;b9=c[cf+(ce*3160|0)+60+((cd>>>8&255)<<2)>>2]|0;do{if((b9|0)==0){bZ=c[cf+(ce*3160|0)+3132>>2]|0;if((bZ|0)==0){cg=0;break}cg=gj[bZ&4095](b1)|0}else{cg=a[b9+(cd&255)|0]|0}}while(0);c[2426872]=cg&255|b5;break};case 184:{b5=c[2410676]|0;cg=b5&65535;cd=c[3528552]|0;b9=c[2433426]|0;b1=c[b9+(cd*3160|0)+60+((b5>>>8&255|512)<<2)>>2]|0;do{if((b1|0)==0){ce=c[b9+(cd*3160|0)+3144>>2]|0;if((ce|0)==0){ch=0;ci=cg;cj=cd;ck=b9;break}cf=gj[ce&4095](cg)|0;ch=cf;ci=b[4821352]|0;cj=c[3528552]|0;ck=c[2433426]|0}else{ch=a[b1+(b5&255)|0]|0;ci=cg;cj=cd;ck=b9}}while(0);b9=ch&255;b[4821352]=ci+1&65535;b[4853744]=((b9&128)!=0?b9|-256:b9)+(b[4821368]|0)&65535;b9=c[2426872]|0;ci=b9&65535;ch=c[ck+(cj*3160|0)+60+((b9>>>8&255)<<2)>>2]|0;do{if((ch|0)==0){cd=c[ck+(cj*3160|0)+3132>>2]|0;if((cd|0)==0){cl=0;cm=cj;cn=ck;break}cg=gj[cd&4095](ci)|0;cl=cg;cm=c[3528552]|0;cn=c[2433426]|0}else{cl=a[ch+(b9&255)|0]|0;cm=cj;cn=ck}}while(0);ck=(cl&255)<<8;cl=b9+1|0;b9=cl&65535;cj=c[cn+(cm*3160|0)+60+((cl>>>8&255)<<2)>>2]|0;do{if((cj|0)==0){ch=c[cn+(cm*3160|0)+3132>>2]|0;if((ch|0)==0){co=0;break}co=gj[ch&4095](b9)|0}else{co=a[cj+(cl&255)|0]|0}}while(0);c[2426872]=co&255|ck;break};case 185:{ck=c[2410676]|0;co=ck&65535;cl=c[3528552]|0;cj=c[2433426]|0;b9=c[cj+(cl*3160|0)+60+((ck>>>8&255|512)<<2)>>2]|0;do{if((b9|0)==0){cm=c[cj+(cl*3160|0)+3144>>2]|0;if((cm|0)==0){cp=0;cq=ck;cr=cl;cs=cj;ct=co;break}cn=gj[cm&4095](co)|0;cm=c[2410676]|0;cp=cn;cq=cm;cr=c[3528552]|0;cs=c[2433426]|0;ct=cm&65535}else{cp=a[b9+(ck&255)|0]|0;cq=ck;cr=cl;cs=cj;ct=co}}while(0);co=(cp&255)<<8;cp=cq+1|0;cq=cp&65535;cj=c[cs+(cr*3160|0)+60+((cp>>>8&255|512)<<2)>>2]|0;do{if((cj|0)==0){cl=c[cs+(cr*3160|0)+3144>>2]|0;if((cl|0)==0){cu=0;cv=ct;cw=cr;cx=cs;break}ck=gj[cl&4095](cq)|0;cu=ck;cv=b[4821352]|0;cw=c[3528552]|0;cx=c[2433426]|0}else{cu=a[cj+(cp&255)|0]|0;cv=ct;cw=cr;cx=cs}}while(0);cs=cu&255|co;c[2426872]=cs;b[4821352]=cv+2&65535;b[4853744]=(cs&65535)+(b[4821368]|0)&65535;cs=c[2426872]|0;cv=cs&65535;co=c[cx+(cw*3160|0)+60+((cs>>>8&255)<<2)>>2]|0;do{if((co|0)==0){cu=c[cx+(cw*3160|0)+3132>>2]|0;if((cu|0)==0){cy=0;cz=cw;cA=cx;break}cr=gj[cu&4095](cv)|0;cy=cr;cz=c[3528552]|0;cA=c[2433426]|0}else{cy=a[co+(cs&255)|0]|0;cz=cw;cA=cx}}while(0);cx=(cy&255)<<8;cy=cs+1|0;cs=cy&65535;cw=c[cA+(cz*3160|0)+60+((cy>>>8&255)<<2)>>2]|0;do{if((cw|0)==0){co=c[cA+(cz*3160|0)+3132>>2]|0;if((co|0)==0){cB=0;break}cB=gj[co&4095](cs)|0}else{cB=a[cw+(cy&255)|0]|0}}while(0);c[2426872]=cB&255|cx;break};case 186:{cx=d[9642716]|0;b[4853744]=((cx&128|0)!=0?cx|65280:cx)+(e[4821368]|0)&65535;cx=c[2426872]|0;cB=cx&65535;cy=c[3528552]|0;cw=c[2433426]|0;cs=c[cw+(cy*3160|0)+60+((cx>>>8&255)<<2)>>2]|0;do{if((cs|0)==0){cz=c[cw+(cy*3160|0)+3132>>2]|0;if((cz|0)==0){cC=0;cD=cy;cE=cw;break}cA=gj[cz&4095](cB)|0;cC=cA;cD=c[3528552]|0;cE=c[2433426]|0}else{cC=a[cs+(cx&255)|0]|0;cD=cy;cE=cw}}while(0);cw=(cC&255)<<8;cC=cx+1|0;cx=cC&65535;cy=c[cE+(cD*3160|0)+60+((cC>>>8&255)<<2)>>2]|0;do{if((cy|0)==0){cs=c[cE+(cD*3160|0)+3132>>2]|0;if((cs|0)==0){cF=0;break}cF=gj[cs&4095](cx)|0}else{cF=a[cy+(cC&255)|0]|0}}while(0);c[2426872]=cF&255|cw;break};case 187:{b[4853744]=(b[4821356]|0)+(b[4821368]|0)&65535;cw=c[2426872]|0;cF=cw&65535;cC=c[3528552]|0;cy=c[2433426]|0;cx=c[cy+(cC*3160|0)+60+((cw>>>8&255)<<2)>>2]|0;do{if((cx|0)==0){cD=c[cy+(cC*3160|0)+3132>>2]|0;if((cD|0)==0){cG=0;cH=cC;cI=cy;break}cE=gj[cD&4095](cF)|0;cG=cE;cH=c[3528552]|0;cI=c[2433426]|0}else{cG=a[cx+(cw&255)|0]|0;cH=cC;cI=cy}}while(0);cy=(cG&255)<<8;cG=cw+1|0;cw=cG&65535;cC=c[cI+(cH*3160|0)+60+((cG>>>8&255)<<2)>>2]|0;do{if((cC|0)==0){cx=c[cI+(cH*3160|0)+3132>>2]|0;if((cx|0)==0){cJ=0;break}cJ=gj[cx&4095](cw)|0}else{cJ=a[cC+(cG&255)|0]|0}}while(0);c[2426872]=cJ&255|cy;break};case 188:{cy=c[2410676]|0;cJ=cy&65535;cG=c[3528552]|0;cC=c[2433426]|0;cw=c[cC+(cG*3160|0)+60+((cy>>>8&255|512)<<2)>>2]|0;do{if((cw|0)==0){cH=c[cC+(cG*3160|0)+3144>>2]|0;if((cH|0)==0){cK=0;cL=cJ;cM=cG;cN=cC;break}cI=gj[cH&4095](cJ)|0;cK=cI;cL=b[4821352]|0;cM=c[3528552]|0;cN=c[2433426]|0}else{cK=a[cw+(cy&255)|0]|0;cL=cJ;cM=cG;cN=cC}}while(0);cC=cK&255;cK=cL+1&65535;b[4821352]=cK;b[4853744]=((cC&128)!=0?cC|-256:cC)+cK&65535;cK=c[2426872]|0;cC=cK&65535;cL=c[cN+(cM*3160|0)+60+((cK>>>8&255)<<2)>>2]|0;do{if((cL|0)==0){cG=c[cN+(cM*3160|0)+3132>>2]|0;if((cG|0)==0){cO=0;cP=cM;cQ=cN;break}cJ=gj[cG&4095](cC)|0;cO=cJ;cP=c[3528552]|0;cQ=c[2433426]|0}else{cO=a[cL+(cK&255)|0]|0;cP=cM;cQ=cN}}while(0);cN=(cO&255)<<8;cO=cK+1|0;cK=cO&65535;cM=c[cQ+(cP*3160|0)+60+((cO>>>8&255)<<2)>>2]|0;do{if((cM|0)==0){cL=c[cQ+(cP*3160|0)+3132>>2]|0;if((cL|0)==0){cR=0;break}cR=gj[cL&4095](cK)|0}else{cR=a[cM+(cO&255)|0]|0}}while(0);c[2426872]=cR&255|cN;break};case 189:{cN=c[2410676]|0;cR=cN&65535;cO=c[3528552]|0;cM=c[2433426]|0;cK=c[cM+(cO*3160|0)+60+((cN>>>8&255|512)<<2)>>2]|0;do{if((cK|0)==0){cP=c[cM+(cO*3160|0)+3144>>2]|0;if((cP|0)==0){cS=0;cT=cN;cU=cO;cV=cM;cW=cR;break}cQ=gj[cP&4095](cR)|0;cP=c[2410676]|0;cS=cQ;cT=cP;cU=c[3528552]|0;cV=c[2433426]|0;cW=cP&65535}else{cS=a[cK+(cN&255)|0]|0;cT=cN;cU=cO;cV=cM;cW=cR}}while(0);cR=(cS&255)<<8;cS=cT+1|0;cT=cS&65535;cM=c[cV+(cU*3160|0)+60+((cS>>>8&255|512)<<2)>>2]|0;do{if((cM|0)==0){cO=c[cV+(cU*3160|0)+3144>>2]|0;if((cO|0)==0){cX=0;cY=cW;cZ=cU;c_=cV;break}cN=gj[cO&4095](cT)|0;cX=cN;cY=b[4821352]|0;cZ=c[3528552]|0;c_=c[2433426]|0}else{cX=a[cM+(cS&255)|0]|0;cY=cW;cZ=cU;c_=cV}}while(0);cV=cX&255|cR;c[2426872]=cV;cR=cY+2&65535;b[4821352]=cR;b[4853744]=(cV&65535)+cR&65535;cR=c[2426872]|0;cV=cR&65535;cY=c[c_+(cZ*3160|0)+60+((cR>>>8&255)<<2)>>2]|0;do{if((cY|0)==0){cX=c[c_+(cZ*3160|0)+3132>>2]|0;if((cX|0)==0){c$=0;c0=cZ;c1=c_;break}cU=gj[cX&4095](cV)|0;c$=cU;c0=c[3528552]|0;c1=c[2433426]|0}else{c$=a[cY+(cR&255)|0]|0;c0=cZ;c1=c_}}while(0);c_=(c$&255)<<8;c$=cR+1|0;cR=c$&65535;cZ=c[c1+(c0*3160|0)+60+((c$>>>8&255)<<2)>>2]|0;do{if((cZ|0)==0){cY=c[c1+(c0*3160|0)+3132>>2]|0;if((cY|0)==0){c2=0;break}c2=gj[cY&4095](cR)|0}else{c2=a[cZ+(c$&255)|0]|0}}while(0);c[2426872]=c2&255|c_;break};case 190:{b[4853744]=(b[4821358]|0)+(b[4821368]|0)&65535;c_=c[2426872]|0;c2=c_&65535;c$=c[3528552]|0;cZ=c[2433426]|0;cR=c[cZ+(c$*3160|0)+60+((c_>>>8&255)<<2)>>2]|0;do{if((cR|0)==0){c0=c[cZ+(c$*3160|0)+3132>>2]|0;if((c0|0)==0){c3=0;c4=c$;c5=cZ;break}c1=gj[c0&4095](c2)|0;c3=c1;c4=c[3528552]|0;c5=c[2433426]|0}else{c3=a[cR+(c_&255)|0]|0;c4=c$;c5=cZ}}while(0);cZ=(c3&255)<<8;c3=c_+1|0;c_=c3&65535;c$=c[c5+(c4*3160|0)+60+((c3>>>8&255)<<2)>>2]|0;do{if((c$|0)==0){cR=c[c5+(c4*3160|0)+3132>>2]|0;if((cR|0)==0){c6=0;break}c6=gj[cR&4095](c_)|0}else{c6=a[c$+(c3&255)|0]|0}}while(0);c[2426872]=c6&255|cZ;break};case 191:{a[9642745]=a[9642745]|64;fGQ();break};case 192:{cZ=b[4821362]|0;b[4853744]=cZ;b[4821362]=cZ+1&65535;break};case 193:{cZ=b[4821362]|0;b[4853744]=cZ;b[4821362]=cZ+2&65535;break};case 194:{cZ=(b[4821362]|0)-1&65535;b[4821362]=cZ;b[4853744]=cZ;break};case 195:{cZ=(b[4821362]|0)-2&65535;b[4821362]=cZ;b[4853744]=cZ;break};case 196:{b[4853744]=b[4821362]|0;break};case 197:{cZ=d[9642712]|0;b[4853744]=((cZ&128|0)!=0?cZ|65280:cZ)+(e[4821362]|0)&65535;break};case 198:{cZ=d[9642713]|0;b[4853744]=((cZ&128|0)!=0?cZ|65280:cZ)+(e[4821362]|0)&65535;break};case 199:{cZ=d[9642717]|0;b[4853744]=((cZ&128|0)!=0?cZ|65280:cZ)+(e[4821362]|0)&65535;break};case 200:{cZ=c[2410676]|0;c6=cZ&65535;c3=c[3528552]|0;c$=c[2433426]|0;c_=c[c$+(c3*3160|0)+60+((cZ>>>8&255|512)<<2)>>2]|0;do{if((c_|0)==0){c4=c[c$+(c3*3160|0)+3144>>2]|0;if((c4|0)==0){c7=0;c8=c6;break}c5=gj[c4&4095](c6)|0;c7=c5;c8=b[4821352]|0}else{c7=a[c_+(cZ&255)|0]|0;c8=c6}}while(0);c6=c7&255;b[4821352]=c8+1&65535;b[4853744]=((c6&128)!=0?c6|-256:c6)+(b[4821362]|0)&65535;break};case 201:{c6=c[2410676]|0;c8=c6&65535;c7=c[3528552]|0;cZ=c[2433426]|0;c_=c[cZ+(c7*3160|0)+60+((c6>>>8&255|512)<<2)>>2]|0;do{if((c_|0)==0){c3=c[cZ+(c7*3160|0)+3144>>2]|0;if((c3|0)==0){c9=0;da=c6;db=c7;dc=cZ;dd=c8;break}c$=gj[c3&4095](c8)|0;c3=c[2410676]|0;c9=c$;da=c3;db=c[3528552]|0;dc=c[2433426]|0;dd=c3&65535}else{c9=a[c_+(c6&255)|0]|0;da=c6;db=c7;dc=cZ;dd=c8}}while(0);c8=(c9&255)<<8;c9=da+1|0;da=c9&65535;cZ=c[dc+(db*3160|0)+60+((c9>>>8&255|512)<<2)>>2]|0;do{if((cZ|0)==0){c7=c[dc+(db*3160|0)+3144>>2]|0;if((c7|0)==0){de=0;df=dd;break}c6=gj[c7&4095](da)|0;de=c6;df=b[4821352]|0}else{de=a[cZ+(c9&255)|0]|0;df=dd}}while(0);dd=de&255|c8;c[2426872]=dd;b[4821352]=df+2&65535;b[4853744]=(dd&65535)+(b[4821362]|0)&65535;break};case 202:{dd=d[9642716]|0;b[4853744]=((dd&128|0)!=0?dd|65280:dd)+(e[4821362]|0)&65535;break};case 203:{b[4853744]=(b[4821356]|0)+(b[4821362]|0)&65535;break};case 204:{dd=c[2410676]|0;df=dd&65535;c8=c[3528552]|0;de=c[2433426]|0;c9=c[de+(c8*3160|0)+60+((dd>>>8&255|512)<<2)>>2]|0;do{if((c9|0)==0){cZ=c[de+(c8*3160|0)+3144>>2]|0;if((cZ|0)==0){dg=0;dh=df;break}da=gj[cZ&4095](df)|0;dg=da;dh=b[4821352]|0}else{dg=a[c9+(dd&255)|0]|0;dh=df}}while(0);df=dg&255;dg=dh+1&65535;b[4821352]=dg;b[4853744]=((df&128)!=0?df|-256:df)+dg&65535;break};case 205:{dg=c[2410676]|0;df=dg&65535;dh=c[3528552]|0;dd=c[2433426]|0;c9=c[dd+(dh*3160|0)+60+((dg>>>8&255|512)<<2)>>2]|0;do{if((c9|0)==0){c8=c[dd+(dh*3160|0)+3144>>2]|0;if((c8|0)==0){di=0;dj=dg;dk=dh;dl=dd;dm=df;break}de=gj[c8&4095](df)|0;c8=c[2410676]|0;di=de;dj=c8;dk=c[3528552]|0;dl=c[2433426]|0;dm=c8&65535}else{di=a[c9+(dg&255)|0]|0;dj=dg;dk=dh;dl=dd;dm=df}}while(0);df=(di&255)<<8;di=dj+1|0;dj=di&65535;dd=c[dl+(dk*3160|0)+60+((di>>>8&255|512)<<2)>>2]|0;do{if((dd|0)==0){dh=c[dl+(dk*3160|0)+3144>>2]|0;if((dh|0)==0){dn=0;dp=dm;break}dg=gj[dh&4095](dj)|0;dn=dg;dp=b[4821352]|0}else{dn=a[dd+(di&255)|0]|0;dp=dm}}while(0);dm=dn&255|df;c[2426872]=dm;df=dp+2&65535;b[4821352]=df;b[4853744]=(dm&65535)+df&65535;break};case 206:{b[4853744]=(b[4821358]|0)+(b[4821362]|0)&65535;break};case 207:{df=b[4821358]|0;b[4853744]=df;b[4821358]=df+2&65535;break};case 208:{df=b[4821358]|0;b[4853744]=df;b[4821358]=df+2&65535;df=c[2426872]|0;dm=df&65535;dp=c[3528552]|0;dn=c[2433426]|0;di=c[dn+(dp*3160|0)+60+((df>>>8&255)<<2)>>2]|0;do{if((di|0)==0){dd=c[dn+(dp*3160|0)+3132>>2]|0;if((dd|0)==0){dq=0;dr=dp;ds=dn;break}dj=gj[dd&4095](dm)|0;dq=dj;dr=c[3528552]|0;ds=c[2433426]|0}else{dq=a[di+(df&255)|0]|0;dr=dp;ds=dn}}while(0);dn=(dq&255)<<8;dq=df+1|0;df=dq&65535;dp=c[ds+(dr*3160|0)+60+((dq>>>8&255)<<2)>>2]|0;do{if((dp|0)==0){di=c[ds+(dr*3160|0)+3132>>2]|0;if((di|0)==0){dt=0;break}dt=gj[di&4095](df)|0}else{dt=a[dp+(dq&255)|0]|0}}while(0);c[2426872]=dt&255|dn;break};case 209:{dn=b[4821362]|0;b[4853744]=dn;b[4821362]=dn+2&65535;dn=c[2426872]|0;dt=dn&65535;dq=c[3528552]|0;dp=c[2433426]|0;df=c[dp+(dq*3160|0)+60+((dn>>>8&255)<<2)>>2]|0;do{if((df|0)==0){dr=c[dp+(dq*3160|0)+3132>>2]|0;if((dr|0)==0){du=0;dv=dq;dw=dp;break}ds=gj[dr&4095](dt)|0;du=ds;dv=c[3528552]|0;dw=c[2433426]|0}else{du=a[df+(dn&255)|0]|0;dv=dq;dw=dp}}while(0);dp=(du&255)<<8;du=dn+1|0;dn=du&65535;dq=c[dw+(dv*3160|0)+60+((du>>>8&255)<<2)>>2]|0;do{if((dq|0)==0){df=c[dw+(dv*3160|0)+3132>>2]|0;if((df|0)==0){dx=0;break}dx=gj[df&4095](dn)|0}else{dx=a[dq+(du&255)|0]|0}}while(0);c[2426872]=dx&255|dp;break};case 210:{a[9642745]=a[9642745]|64;fGQ();break};case 211:{dp=(b[4821362]|0)-2&65535;b[4821362]=dp;b[4853744]=dp;dp=c[2426872]|0;dx=dp&65535;du=c[3528552]|0;dq=c[2433426]|0;dn=c[dq+(du*3160|0)+60+((dp>>>8&255)<<2)>>2]|0;do{if((dn|0)==0){dv=c[dq+(du*3160|0)+3132>>2]|0;if((dv|0)==0){dy=0;dz=du;dA=dq;break}dw=gj[dv&4095](dx)|0;dy=dw;dz=c[3528552]|0;dA=c[2433426]|0}else{dy=a[dn+(dp&255)|0]|0;dz=du;dA=dq}}while(0);dq=(dy&255)<<8;dy=dp+1|0;dp=dy&65535;du=c[dA+(dz*3160|0)+60+((dy>>>8&255)<<2)>>2]|0;do{if((du|0)==0){dn=c[dA+(dz*3160|0)+3132>>2]|0;if((dn|0)==0){dB=0;break}dB=gj[dn&4095](dp)|0}else{dB=a[du+(dy&255)|0]|0}}while(0);c[2426872]=dB&255|dq;break};case 212:{b[4853744]=b[4821362]|0;dq=c[2426872]|0;dB=dq&65535;dy=c[3528552]|0;du=c[2433426]|0;dp=c[du+(dy*3160|0)+60+((dq>>>8&255)<<2)>>2]|0;do{if((dp|0)==0){dz=c[du+(dy*3160|0)+3132>>2]|0;if((dz|0)==0){dC=0;dD=dy;dE=du;break}dA=gj[dz&4095](dB)|0;dC=dA;dD=c[3528552]|0;dE=c[2433426]|0}else{dC=a[dp+(dq&255)|0]|0;dD=dy;dE=du}}while(0);du=(dC&255)<<8;dC=dq+1|0;dq=dC&65535;dy=c[dE+(dD*3160|0)+60+((dC>>>8&255)<<2)>>2]|0;do{if((dy|0)==0){dp=c[dE+(dD*3160|0)+3132>>2]|0;if((dp|0)==0){dF=0;break}dF=gj[dp&4095](dq)|0}else{dF=a[dy+(dC&255)|0]|0}}while(0);c[2426872]=dF&255|du;break};case 213:{du=d[9642712]|0;b[4853744]=((du&128|0)!=0?du|65280:du)+(e[4821362]|0)&65535;du=c[2426872]|0;dF=du&65535;dC=c[3528552]|0;dy=c[2433426]|0;dq=c[dy+(dC*3160|0)+60+((du>>>8&255)<<2)>>2]|0;do{if((dq|0)==0){dD=c[dy+(dC*3160|0)+3132>>2]|0;if((dD|0)==0){dG=0;dH=dC;dI=dy;break}dE=gj[dD&4095](dF)|0;dG=dE;dH=c[3528552]|0;dI=c[2433426]|0}else{dG=a[dq+(du&255)|0]|0;dH=dC;dI=dy}}while(0);dy=(dG&255)<<8;dG=du+1|0;du=dG&65535;dC=c[dI+(dH*3160|0)+60+((dG>>>8&255)<<2)>>2]|0;do{if((dC|0)==0){dq=c[dI+(dH*3160|0)+3132>>2]|0;if((dq|0)==0){dJ=0;break}dJ=gj[dq&4095](du)|0}else{dJ=a[dC+(dG&255)|0]|0}}while(0);c[2426872]=dJ&255|dy;break};case 214:{dy=d[9642713]|0;b[4853744]=((dy&128|0)!=0?dy|65280:dy)+(e[4821362]|0)&65535;dy=c[2426872]|0;dJ=dy&65535;dG=c[3528552]|0;dC=c[2433426]|0;du=c[dC+(dG*3160|0)+60+((dy>>>8&255)<<2)>>2]|0;do{if((du|0)==0){dH=c[dC+(dG*3160|0)+3132>>2]|0;if((dH|0)==0){dK=0;dL=dG;dM=dC;break}dI=gj[dH&4095](dJ)|0;dK=dI;dL=c[3528552]|0;dM=c[2433426]|0}else{dK=a[du+(dy&255)|0]|0;dL=dG;dM=dC}}while(0);dC=(dK&255)<<8;dK=dy+1|0;dy=dK&65535;dG=c[dM+(dL*3160|0)+60+((dK>>>8&255)<<2)>>2]|0;do{if((dG|0)==0){du=c[dM+(dL*3160|0)+3132>>2]|0;if((du|0)==0){dN=0;break}dN=gj[du&4095](dy)|0}else{dN=a[dG+(dK&255)|0]|0}}while(0);c[2426872]=dN&255|dC;break};case 215:{dC=d[9642717]|0;b[4853744]=((dC&128|0)!=0?dC|65280:dC)+(e[4821362]|0)&65535;dC=c[2426872]|0;dN=dC&65535;dK=c[3528552]|0;dG=c[2433426]|0;dy=c[dG+(dK*3160|0)+60+((dC>>>8&255)<<2)>>2]|0;do{if((dy|0)==0){dL=c[dG+(dK*3160|0)+3132>>2]|0;if((dL|0)==0){dO=0;dP=dK;dQ=dG;break}dM=gj[dL&4095](dN)|0;dO=dM;dP=c[3528552]|0;dQ=c[2433426]|0}else{dO=a[dy+(dC&255)|0]|0;dP=dK;dQ=dG}}while(0);dG=(dO&255)<<8;dO=dC+1|0;dC=dO&65535;dK=c[dQ+(dP*3160|0)+60+((dO>>>8&255)<<2)>>2]|0;do{if((dK|0)==0){dy=c[dQ+(dP*3160|0)+3132>>2]|0;if((dy|0)==0){dR=0;break}dR=gj[dy&4095](dC)|0}else{dR=a[dK+(dO&255)|0]|0}}while(0);c[2426872]=dR&255|dG;break};case 216:{dG=c[2410676]|0;dR=dG&65535;dO=c[3528552]|0;dK=c[2433426]|0;dC=c[dK+(dO*3160|0)+60+((dG>>>8&255|512)<<2)>>2]|0;do{if((dC|0)==0){dP=c[dK+(dO*3160|0)+3144>>2]|0;if((dP|0)==0){dS=0;dT=dR;dU=dO;dV=dK;break}dQ=gj[dP&4095](dR)|0;dS=dQ;dT=b[4821352]|0;dU=c[3528552]|0;dV=c[2433426]|0}else{dS=a[dC+(dG&255)|0]|0;dT=dR;dU=dO;dV=dK}}while(0);dK=dS&255;b[4821352]=dT+1&65535;b[4853744]=((dK&128)!=0?dK|-256:dK)+(b[4821362]|0)&65535;dK=c[2426872]|0;dT=dK&65535;dS=c[dV+(dU*3160|0)+60+((dK>>>8&255)<<2)>>2]|0;do{if((dS|0)==0){dO=c[dV+(dU*3160|0)+3132>>2]|0;if((dO|0)==0){dW=0;dX=dU;dY=dV;break}dR=gj[dO&4095](dT)|0;dW=dR;dX=c[3528552]|0;dY=c[2433426]|0}else{dW=a[dS+(dK&255)|0]|0;dX=dU;dY=dV}}while(0);dV=(dW&255)<<8;dW=dK+1|0;dK=dW&65535;dU=c[dY+(dX*3160|0)+60+((dW>>>8&255)<<2)>>2]|0;do{if((dU|0)==0){dS=c[dY+(dX*3160|0)+3132>>2]|0;if((dS|0)==0){dZ=0;break}dZ=gj[dS&4095](dK)|0}else{dZ=a[dU+(dW&255)|0]|0}}while(0);c[2426872]=dZ&255|dV;break};case 217:{dV=c[2410676]|0;dZ=dV&65535;dW=c[3528552]|0;dU=c[2433426]|0;dK=c[dU+(dW*3160|0)+60+((dV>>>8&255|512)<<2)>>2]|0;do{if((dK|0)==0){dX=c[dU+(dW*3160|0)+3144>>2]|0;if((dX|0)==0){d_=0;d$=dV;d0=dW;d1=dU;d2=dZ;break}dY=gj[dX&4095](dZ)|0;dX=c[2410676]|0;d_=dY;d$=dX;d0=c[3528552]|0;d1=c[2433426]|0;d2=dX&65535}else{d_=a[dK+(dV&255)|0]|0;d$=dV;d0=dW;d1=dU;d2=dZ}}while(0);dZ=(d_&255)<<8;d_=d$+1|0;d$=d_&65535;dU=c[d1+(d0*3160|0)+60+((d_>>>8&255|512)<<2)>>2]|0;do{if((dU|0)==0){dW=c[d1+(d0*3160|0)+3144>>2]|0;if((dW|0)==0){d3=0;d4=d2;d5=d0;d6=d1;break}dV=gj[dW&4095](d$)|0;d3=dV;d4=b[4821352]|0;d5=c[3528552]|0;d6=c[2433426]|0}else{d3=a[dU+(d_&255)|0]|0;d4=d2;d5=d0;d6=d1}}while(0);d1=d3&255|dZ;c[2426872]=d1;b[4821352]=d4+2&65535;b[4853744]=(d1&65535)+(b[4821362]|0)&65535;d1=c[2426872]|0;d4=d1&65535;dZ=c[d6+(d5*3160|0)+60+((d1>>>8&255)<<2)>>2]|0;do{if((dZ|0)==0){d3=c[d6+(d5*3160|0)+3132>>2]|0;if((d3|0)==0){d7=0;d8=d5;d9=d6;break}d0=gj[d3&4095](d4)|0;d7=d0;d8=c[3528552]|0;d9=c[2433426]|0}else{d7=a[dZ+(d1&255)|0]|0;d8=d5;d9=d6}}while(0);d6=(d7&255)<<8;d7=d1+1|0;d1=d7&65535;d5=c[d9+(d8*3160|0)+60+((d7>>>8&255)<<2)>>2]|0;do{if((d5|0)==0){dZ=c[d9+(d8*3160|0)+3132>>2]|0;if((dZ|0)==0){ea=0;break}ea=gj[dZ&4095](d1)|0}else{ea=a[d5+(d7&255)|0]|0}}while(0);c[2426872]=ea&255|d6;break};case 218:{d6=d[9642716]|0;b[4853744]=((d6&128|0)!=0?d6|65280:d6)+(e[4821362]|0)&65535;d6=c[2426872]|0;ea=d6&65535;d7=c[3528552]|0;d5=c[2433426]|0;d1=c[d5+(d7*3160|0)+60+((d6>>>8&255)<<2)>>2]|0;do{if((d1|0)==0){d8=c[d5+(d7*3160|0)+3132>>2]|0;if((d8|0)==0){eb=0;ec=d7;ed=d5;break}d9=gj[d8&4095](ea)|0;eb=d9;ec=c[3528552]|0;ed=c[2433426]|0}else{eb=a[d1+(d6&255)|0]|0;ec=d7;ed=d5}}while(0);d5=(eb&255)<<8;eb=d6+1|0;d6=eb&65535;d7=c[ed+(ec*3160|0)+60+((eb>>>8&255)<<2)>>2]|0;do{if((d7|0)==0){d1=c[ed+(ec*3160|0)+3132>>2]|0;if((d1|0)==0){ee=0;break}ee=gj[d1&4095](d6)|0}else{ee=a[d7+(eb&255)|0]|0}}while(0);c[2426872]=ee&255|d5;break};case 219:{b[4853744]=(b[4821356]|0)+(b[4821362]|0)&65535;d5=c[2426872]|0;ee=d5&65535;eb=c[3528552]|0;d7=c[2433426]|0;d6=c[d7+(eb*3160|0)+60+((d5>>>8&255)<<2)>>2]|0;do{if((d6|0)==0){ec=c[d7+(eb*3160|0)+3132>>2]|0;if((ec|0)==0){ef=0;eg=eb;eh=d7;break}ed=gj[ec&4095](ee)|0;ef=ed;eg=c[3528552]|0;eh=c[2433426]|0}else{ef=a[d6+(d5&255)|0]|0;eg=eb;eh=d7}}while(0);d7=(ef&255)<<8;ef=d5+1|0;d5=ef&65535;eb=c[eh+(eg*3160|0)+60+((ef>>>8&255)<<2)>>2]|0;do{if((eb|0)==0){d6=c[eh+(eg*3160|0)+3132>>2]|0;if((d6|0)==0){ei=0;break}ei=gj[d6&4095](d5)|0}else{ei=a[eb+(ef&255)|0]|0}}while(0);c[2426872]=ei&255|d7;break};case 220:{d7=c[2410676]|0;ei=d7&65535;ef=c[3528552]|0;eb=c[2433426]|0;d5=c[eb+(ef*3160|0)+60+((d7>>>8&255|512)<<2)>>2]|0;do{if((d5|0)==0){eg=c[eb+(ef*3160|0)+3144>>2]|0;if((eg|0)==0){ej=0;ek=ei;el=ef;em=eb;break}eh=gj[eg&4095](ei)|0;ej=eh;ek=b[4821352]|0;el=c[3528552]|0;em=c[2433426]|0}else{ej=a[d5+(d7&255)|0]|0;ek=ei;el=ef;em=eb}}while(0);eb=ej&255;ej=ek+1&65535;b[4821352]=ej;b[4853744]=((eb&128)!=0?eb|-256:eb)+ej&65535;ej=c[2426872]|0;eb=ej&65535;ek=c[em+(el*3160|0)+60+((ej>>>8&255)<<2)>>2]|0;do{if((ek|0)==0){ef=c[em+(el*3160|0)+3132>>2]|0;if((ef|0)==0){en=0;eo=el;ep=em;break}ei=gj[ef&4095](eb)|0;en=ei;eo=c[3528552]|0;ep=c[2433426]|0}else{en=a[ek+(ej&255)|0]|0;eo=el;ep=em}}while(0);em=(en&255)<<8;en=ej+1|0;ej=en&65535;el=c[ep+(eo*3160|0)+60+((en>>>8&255)<<2)>>2]|0;do{if((el|0)==0){ek=c[ep+(eo*3160|0)+3132>>2]|0;if((ek|0)==0){eq=0;break}eq=gj[ek&4095](ej)|0}else{eq=a[el+(en&255)|0]|0}}while(0);c[2426872]=eq&255|em;break};case 221:{em=c[2410676]|0;eq=em&65535;en=c[3528552]|0;el=c[2433426]|0;ej=c[el+(en*3160|0)+60+((em>>>8&255|512)<<2)>>2]|0;do{if((ej|0)==0){eo=c[el+(en*3160|0)+3144>>2]|0;if((eo|0)==0){er=0;es=em;et=en;eu=el;ev=eq;break}ep=gj[eo&4095](eq)|0;eo=c[2410676]|0;er=ep;es=eo;et=c[3528552]|0;eu=c[2433426]|0;ev=eo&65535}else{er=a[ej+(em&255)|0]|0;es=em;et=en;eu=el;ev=eq}}while(0);eq=(er&255)<<8;er=es+1|0;es=er&65535;el=c[eu+(et*3160|0)+60+((er>>>8&255|512)<<2)>>2]|0;do{if((el|0)==0){en=c[eu+(et*3160|0)+3144>>2]|0;if((en|0)==0){ew=0;ex=ev;ey=et;ez=eu;break}em=gj[en&4095](es)|0;ew=em;ex=b[4821352]|0;ey=c[3528552]|0;ez=c[2433426]|0}else{ew=a[el+(er&255)|0]|0;ex=ev;ey=et;ez=eu}}while(0);eu=ew&255|eq;c[2426872]=eu;eq=ex+2&65535;b[4821352]=eq;b[4853744]=(eu&65535)+eq&65535;eq=c[2426872]|0;eu=eq&65535;ex=c[ez+(ey*3160|0)+60+((eq>>>8&255)<<2)>>2]|0;do{if((ex|0)==0){ew=c[ez+(ey*3160|0)+3132>>2]|0;if((ew|0)==0){eA=0;eB=ey;eC=ez;break}et=gj[ew&4095](eu)|0;eA=et;eB=c[3528552]|0;eC=c[2433426]|0}else{eA=a[ex+(eq&255)|0]|0;eB=ey;eC=ez}}while(0);ez=(eA&255)<<8;eA=eq+1|0;eq=eA&65535;ey=c[eC+(eB*3160|0)+60+((eA>>>8&255)<<2)>>2]|0;do{if((ey|0)==0){ex=c[eC+(eB*3160|0)+3132>>2]|0;if((ex|0)==0){eD=0;break}eD=gj[ex&4095](eq)|0}else{eD=a[ey+(eA&255)|0]|0}}while(0);c[2426872]=eD&255|ez;break};case 222:{b[4853744]=(b[4821358]|0)+(b[4821362]|0)&65535;ez=c[2426872]|0;eD=ez&65535;eA=c[3528552]|0;ey=c[2433426]|0;eq=c[ey+(eA*3160|0)+60+((ez>>>8&255)<<2)>>2]|0;do{if((eq|0)==0){eB=c[ey+(eA*3160|0)+3132>>2]|0;if((eB|0)==0){eE=0;eF=eA;eG=ey;break}eC=gj[eB&4095](eD)|0;eE=eC;eF=c[3528552]|0;eG=c[2433426]|0}else{eE=a[eq+(ez&255)|0]|0;eF=eA;eG=ey}}while(0);ey=(eE&255)<<8;eE=ez+1|0;ez=eE&65535;eA=c[eG+(eF*3160|0)+60+((eE>>>8&255)<<2)>>2]|0;do{if((eA|0)==0){eq=c[eG+(eF*3160|0)+3132>>2]|0;if((eq|0)==0){eH=0;break}eH=gj[eq&4095](ez)|0}else{eH=a[eA+(eE&255)|0]|0}}while(0);c[2426872]=eH&255|ey;break};case 223:{a[9642745]=a[9642745]|64;fGQ();break};case 224:{ey=b[4821364]|0;b[4853744]=ey;b[4821364]=ey+1&65535;break};case 225:{ey=b[4821364]|0;b[4853744]=ey;b[4821364]=ey+2&65535;break};case 226:{ey=(b[4821364]|0)-1&65535;b[4821364]=ey;b[4853744]=ey;break};case 227:{ey=(b[4821364]|0)-2&65535;b[4821364]=ey;b[4853744]=ey;break};case 228:{b[4853744]=b[4821364]|0;break};case 229:{ey=d[9642712]|0;b[4853744]=((ey&128|0)!=0?ey|65280:ey)+(e[4821364]|0)&65535;break};case 230:{ey=d[9642713]|0;b[4853744]=((ey&128|0)!=0?ey|65280:ey)+(e[4821364]|0)&65535;break};case 231:{ey=d[9642717]|0;b[4853744]=((ey&128|0)!=0?ey|65280:ey)+(e[4821364]|0)&65535;break};case 232:{ey=c[2410676]|0;eH=ey&65535;eE=c[3528552]|0;eA=c[2433426]|0;ez=c[eA+(eE*3160|0)+60+((ey>>>8&255|512)<<2)>>2]|0;do{if((ez|0)==0){eF=c[eA+(eE*3160|0)+3144>>2]|0;if((eF|0)==0){eI=0;eJ=eH;break}eG=gj[eF&4095](eH)|0;eI=eG;eJ=b[4821352]|0}else{eI=a[ez+(ey&255)|0]|0;eJ=eH}}while(0);eH=eI&255;b[4821352]=eJ+1&65535;b[4853744]=((eH&128)!=0?eH|-256:eH)+(b[4821364]|0)&65535;break};case 233:{eH=c[2410676]|0;eJ=eH&65535;eI=c[3528552]|0;ey=c[2433426]|0;ez=c[ey+(eI*3160|0)+60+((eH>>>8&255|512)<<2)>>2]|0;do{if((ez|0)==0){eE=c[ey+(eI*3160|0)+3144>>2]|0;if((eE|0)==0){eK=0;eL=eH;eM=eI;eN=ey;eO=eJ;break}eA=gj[eE&4095](eJ)|0;eE=c[2410676]|0;eK=eA;eL=eE;eM=c[3528552]|0;eN=c[2433426]|0;eO=eE&65535}else{eK=a[ez+(eH&255)|0]|0;eL=eH;eM=eI;eN=ey;eO=eJ}}while(0);eJ=(eK&255)<<8;eK=eL+1|0;eL=eK&65535;ey=c[eN+(eM*3160|0)+60+((eK>>>8&255|512)<<2)>>2]|0;do{if((ey|0)==0){eI=c[eN+(eM*3160|0)+3144>>2]|0;if((eI|0)==0){eP=0;eQ=eO;break}eH=gj[eI&4095](eL)|0;eP=eH;eQ=b[4821352]|0}else{eP=a[ey+(eK&255)|0]|0;eQ=eO}}while(0);eO=eP&255|eJ;c[2426872]=eO;b[4821352]=eQ+2&65535;b[4853744]=(eO&65535)+(b[4821364]|0)&65535;break};case 234:{eO=d[9642716]|0;b[4853744]=((eO&128|0)!=0?eO|65280:eO)+(e[4821364]|0)&65535;break};case 235:{b[4853744]=(b[4821356]|0)+(b[4821364]|0)&65535;break};case 236:{eO=c[2410676]|0;eQ=eO&65535;eJ=c[3528552]|0;eP=c[2433426]|0;eK=c[eP+(eJ*3160|0)+60+((eO>>>8&255|512)<<2)>>2]|0;do{if((eK|0)==0){ey=c[eP+(eJ*3160|0)+3144>>2]|0;if((ey|0)==0){eR=0;eS=eQ;break}eL=gj[ey&4095](eQ)|0;eR=eL;eS=b[4821352]|0}else{eR=a[eK+(eO&255)|0]|0;eS=eQ}}while(0);eQ=eR&255;eR=eS+1&65535;b[4821352]=eR;b[4853744]=((eQ&128)!=0?eQ|-256:eQ)+eR&65535;break};case 237:{eR=c[2410676]|0;eQ=eR&65535;eS=c[3528552]|0;eO=c[2433426]|0;eK=c[eO+(eS*3160|0)+60+((eR>>>8&255|512)<<2)>>2]|0;do{if((eK|0)==0){eJ=c[eO+(eS*3160|0)+3144>>2]|0;if((eJ|0)==0){eT=0;eU=eR;eV=eS;eW=eO;eX=eQ;break}eP=gj[eJ&4095](eQ)|0;eJ=c[2410676]|0;eT=eP;eU=eJ;eV=c[3528552]|0;eW=c[2433426]|0;eX=eJ&65535}else{eT=a[eK+(eR&255)|0]|0;eU=eR;eV=eS;eW=eO;eX=eQ}}while(0);eQ=(eT&255)<<8;eT=eU+1|0;eU=eT&65535;eO=c[eW+(eV*3160|0)+60+((eT>>>8&255|512)<<2)>>2]|0;do{if((eO|0)==0){eS=c[eW+(eV*3160|0)+3144>>2]|0;if((eS|0)==0){eY=0;eZ=eX;break}eR=gj[eS&4095](eU)|0;eY=eR;eZ=b[4821352]|0}else{eY=a[eO+(eT&255)|0]|0;eZ=eX}}while(0);eX=eY&255|eQ;c[2426872]=eX;eQ=eZ+2&65535;b[4821352]=eQ;b[4853744]=(eX&65535)+eQ&65535;break};case 238:{b[4853744]=(b[4821358]|0)+(b[4821364]|0)&65535;break};case 239:{eQ=(b[4821358]|0)-2&65535;b[4821358]=eQ;b[4853744]=eQ;break};case 240:{eQ=(b[4821358]|0)-2&65535;b[4821358]=eQ;b[4853744]=eQ;eQ=c[2426872]|0;eX=eQ&65535;eZ=c[3528552]|0;eY=c[2433426]|0;eT=c[eY+(eZ*3160|0)+60+((eQ>>>8&255)<<2)>>2]|0;do{if((eT|0)==0){eO=c[eY+(eZ*3160|0)+3132>>2]|0;if((eO|0)==0){e_=0;e$=eZ;e0=eY;break}eU=gj[eO&4095](eX)|0;e_=eU;e$=c[3528552]|0;e0=c[2433426]|0}else{e_=a[eT+(eQ&255)|0]|0;e$=eZ;e0=eY}}while(0);eY=(e_&255)<<8;e_=eQ+1|0;eQ=e_&65535;eZ=c[e0+(e$*3160|0)+60+((e_>>>8&255)<<2)>>2]|0;do{if((eZ|0)==0){eT=c[e0+(e$*3160|0)+3132>>2]|0;if((eT|0)==0){e1=0;break}e1=gj[eT&4095](eQ)|0}else{e1=a[eZ+(e_&255)|0]|0}}while(0);c[2426872]=e1&255|eY;break};case 241:{eY=b[4821364]|0;b[4853744]=eY;b[4821364]=eY+2&65535;eY=c[2426872]|0;e1=eY&65535;e_=c[3528552]|0;eZ=c[2433426]|0;eQ=c[eZ+(e_*3160|0)+60+((eY>>>8&255)<<2)>>2]|0;do{if((eQ|0)==0){e$=c[eZ+(e_*3160|0)+3132>>2]|0;if((e$|0)==0){e2=0;e3=e_;e4=eZ;break}e0=gj[e$&4095](e1)|0;e2=e0;e3=c[3528552]|0;e4=c[2433426]|0}else{e2=a[eQ+(eY&255)|0]|0;e3=e_;e4=eZ}}while(0);eZ=(e2&255)<<8;e2=eY+1|0;eY=e2&65535;e_=c[e4+(e3*3160|0)+60+((e2>>>8&255)<<2)>>2]|0;do{if((e_|0)==0){eQ=c[e4+(e3*3160|0)+3132>>2]|0;if((eQ|0)==0){e5=0;break}e5=gj[eQ&4095](eY)|0}else{e5=a[e_+(e2&255)|0]|0}}while(0);c[2426872]=e5&255|eZ;break};case 242:{a[9642745]=a[9642745]|64;fGQ();break};case 243:{eZ=(b[4821364]|0)-2&65535;b[4821364]=eZ;b[4853744]=eZ;eZ=c[2426872]|0;e5=eZ&65535;e2=c[3528552]|0;e_=c[2433426]|0;eY=c[e_+(e2*3160|0)+60+((eZ>>>8&255)<<2)>>2]|0;do{if((eY|0)==0){e3=c[e_+(e2*3160|0)+3132>>2]|0;if((e3|0)==0){e6=0;e7=e2;e8=e_;break}e4=gj[e3&4095](e5)|0;e6=e4;e7=c[3528552]|0;e8=c[2433426]|0}else{e6=a[eY+(eZ&255)|0]|0;e7=e2;e8=e_}}while(0);e_=(e6&255)<<8;e6=eZ+1|0;eZ=e6&65535;e2=c[e8+(e7*3160|0)+60+((e6>>>8&255)<<2)>>2]|0;do{if((e2|0)==0){eY=c[e8+(e7*3160|0)+3132>>2]|0;if((eY|0)==0){e9=0;break}e9=gj[eY&4095](eZ)|0}else{e9=a[e2+(e6&255)|0]|0}}while(0);c[2426872]=e9&255|e_;break};case 244:{b[4853744]=b[4821364]|0;e_=c[2426872]|0;e9=e_&65535;e6=c[3528552]|0;e2=c[2433426]|0;eZ=c[e2+(e6*3160|0)+60+((e_>>>8&255)<<2)>>2]|0;do{if((eZ|0)==0){e7=c[e2+(e6*3160|0)+3132>>2]|0;if((e7|0)==0){fa=0;fb=e6;fc=e2;break}e8=gj[e7&4095](e9)|0;fa=e8;fb=c[3528552]|0;fc=c[2433426]|0}else{fa=a[eZ+(e_&255)|0]|0;fb=e6;fc=e2}}while(0);e2=(fa&255)<<8;fa=e_+1|0;e_=fa&65535;e6=c[fc+(fb*3160|0)+60+((fa>>>8&255)<<2)>>2]|0;do{if((e6|0)==0){eZ=c[fc+(fb*3160|0)+3132>>2]|0;if((eZ|0)==0){fd=0;break}fd=gj[eZ&4095](e_)|0}else{fd=a[e6+(fa&255)|0]|0}}while(0);c[2426872]=fd&255|e2;break};case 245:{e2=d[9642712]|0;b[4853744]=((e2&128|0)!=0?e2|65280:e2)+(e[4821364]|0)&65535;e2=c[2426872]|0;fd=e2&65535;fa=c[3528552]|0;e6=c[2433426]|0;e_=c[e6+(fa*3160|0)+60+((e2>>>8&255)<<2)>>2]|0;do{if((e_|0)==0){fb=c[e6+(fa*3160|0)+3132>>2]|0;if((fb|0)==0){fe=0;ff=fa;fg=e6;break}fc=gj[fb&4095](fd)|0;fe=fc;ff=c[3528552]|0;fg=c[2433426]|0}else{fe=a[e_+(e2&255)|0]|0;ff=fa;fg=e6}}while(0);e6=(fe&255)<<8;fe=e2+1|0;e2=fe&65535;fa=c[fg+(ff*3160|0)+60+((fe>>>8&255)<<2)>>2]|0;do{if((fa|0)==0){e_=c[fg+(ff*3160|0)+3132>>2]|0;if((e_|0)==0){fh=0;break}fh=gj[e_&4095](e2)|0}else{fh=a[fa+(fe&255)|0]|0}}while(0);c[2426872]=fh&255|e6;break};case 246:{e6=d[9642713]|0;b[4853744]=((e6&128|0)!=0?e6|65280:e6)+(e[4821364]|0)&65535;e6=c[2426872]|0;fh=e6&65535;fe=c[3528552]|0;fa=c[2433426]|0;e2=c[fa+(fe*3160|0)+60+((e6>>>8&255)<<2)>>2]|0;do{if((e2|0)==0){ff=c[fa+(fe*3160|0)+3132>>2]|0;if((ff|0)==0){fi=0;fj=fe;fk=fa;break}fg=gj[ff&4095](fh)|0;fi=fg;fj=c[3528552]|0;fk=c[2433426]|0}else{fi=a[e2+(e6&255)|0]|0;fj=fe;fk=fa}}while(0);fa=(fi&255)<<8;fi=e6+1|0;e6=fi&65535;fe=c[fk+(fj*3160|0)+60+((fi>>>8&255)<<2)>>2]|0;do{if((fe|0)==0){e2=c[fk+(fj*3160|0)+3132>>2]|0;if((e2|0)==0){fl=0;break}fl=gj[e2&4095](e6)|0}else{fl=a[fe+(fi&255)|0]|0}}while(0);c[2426872]=fl&255|fa;break};case 247:{fa=d[9642717]|0;b[4853744]=((fa&128|0)!=0?fa|65280:fa)+(e[4821364]|0)&65535;fa=c[2426872]|0;fl=fa&65535;fi=c[3528552]|0;fe=c[2433426]|0;e6=c[fe+(fi*3160|0)+60+((fa>>>8&255)<<2)>>2]|0;do{if((e6|0)==0){fj=c[fe+(fi*3160|0)+3132>>2]|0;if((fj|0)==0){fm=0;fn=fi;fo=fe;break}fk=gj[fj&4095](fl)|0;fm=fk;fn=c[3528552]|0;fo=c[2433426]|0}else{fm=a[e6+(fa&255)|0]|0;fn=fi;fo=fe}}while(0);fe=(fm&255)<<8;fm=fa+1|0;fa=fm&65535;fi=c[fo+(fn*3160|0)+60+((fm>>>8&255)<<2)>>2]|0;do{if((fi|0)==0){e6=c[fo+(fn*3160|0)+3132>>2]|0;if((e6|0)==0){fp=0;break}fp=gj[e6&4095](fa)|0}else{fp=a[fi+(fm&255)|0]|0}}while(0);c[2426872]=fp&255|fe;break};case 248:{fe=c[2410676]|0;fp=fe&65535;fm=c[3528552]|0;fi=c[2433426]|0;fa=c[fi+(fm*3160|0)+60+((fe>>>8&255|512)<<2)>>2]|0;do{if((fa|0)==0){fn=c[fi+(fm*3160|0)+3144>>2]|0;if((fn|0)==0){fq=0;fr=fp;fs=fm;ft=fi;break}fo=gj[fn&4095](fp)|0;fq=fo;fr=b[4821352]|0;fs=c[3528552]|0;ft=c[2433426]|0}else{fq=a[fa+(fe&255)|0]|0;fr=fp;fs=fm;ft=fi}}while(0);fi=fq&255;b[4821352]=fr+1&65535;b[4853744]=((fi&128)!=0?fi|-256:fi)+(b[4821364]|0)&65535;fi=c[2426872]|0;fr=fi&65535;fq=c[ft+(fs*3160|0)+60+((fi>>>8&255)<<2)>>2]|0;do{if((fq|0)==0){fm=c[ft+(fs*3160|0)+3132>>2]|0;if((fm|0)==0){fu=0;fv=fs;fw=ft;break}fp=gj[fm&4095](fr)|0;fu=fp;fv=c[3528552]|0;fw=c[2433426]|0}else{fu=a[fq+(fi&255)|0]|0;fv=fs;fw=ft}}while(0);ft=(fu&255)<<8;fu=fi+1|0;fi=fu&65535;fs=c[fw+(fv*3160|0)+60+((fu>>>8&255)<<2)>>2]|0;do{if((fs|0)==0){fq=c[fw+(fv*3160|0)+3132>>2]|0;if((fq|0)==0){fx=0;break}fx=gj[fq&4095](fi)|0}else{fx=a[fs+(fu&255)|0]|0}}while(0);c[2426872]=fx&255|ft;break};case 249:{ft=c[2410676]|0;fx=ft&65535;fu=c[3528552]|0;fs=c[2433426]|0;fi=c[fs+(fu*3160|0)+60+((ft>>>8&255|512)<<2)>>2]|0;do{if((fi|0)==0){fv=c[fs+(fu*3160|0)+3144>>2]|0;if((fv|0)==0){fy=0;fz=ft;fA=fu;fB=fs;fC=fx;break}fw=gj[fv&4095](fx)|0;fv=c[2410676]|0;fy=fw;fz=fv;fA=c[3528552]|0;fB=c[2433426]|0;fC=fv&65535}else{fy=a[fi+(ft&255)|0]|0;fz=ft;fA=fu;fB=fs;fC=fx}}while(0);fx=(fy&255)<<8;fy=fz+1|0;fz=fy&65535;fs=c[fB+(fA*3160|0)+60+((fy>>>8&255|512)<<2)>>2]|0;do{if((fs|0)==0){fu=c[fB+(fA*3160|0)+3144>>2]|0;if((fu|0)==0){fD=0;fE=fC;fF=fA;fG=fB;break}ft=gj[fu&4095](fz)|0;fD=ft;fE=b[4821352]|0;fF=c[3528552]|0;fG=c[2433426]|0}else{fD=a[fs+(fy&255)|0]|0;fE=fC;fF=fA;fG=fB}}while(0);fB=fD&255|fx;c[2426872]=fB;b[4821352]=fE+2&65535;b[4853744]=(fB&65535)+(b[4821364]|0)&65535;fB=c[2426872]|0;fE=fB&65535;fx=c[fG+(fF*3160|0)+60+((fB>>>8&255)<<2)>>2]|0;do{if((fx|0)==0){fD=c[fG+(fF*3160|0)+3132>>2]|0;if((fD|0)==0){fH=0;fI=fF;fJ=fG;break}fA=gj[fD&4095](fE)|0;fH=fA;fI=c[3528552]|0;fJ=c[2433426]|0}else{fH=a[fx+(fB&255)|0]|0;fI=fF;fJ=fG}}while(0);fG=(fH&255)<<8;fH=fB+1|0;fB=fH&65535;fF=c[fJ+(fI*3160|0)+60+((fH>>>8&255)<<2)>>2]|0;do{if((fF|0)==0){fx=c[fJ+(fI*3160|0)+3132>>2]|0;if((fx|0)==0){fK=0;break}fK=gj[fx&4095](fB)|0}else{fK=a[fF+(fH&255)|0]|0}}while(0);c[2426872]=fK&255|fG;break};case 250:{fG=d[9642716]|0;b[4853744]=((fG&128|0)!=0?fG|65280:fG)+(e[4821364]|0)&65535;fG=c[2426872]|0;fK=fG&65535;fH=c[3528552]|0;fF=c[2433426]|0;fB=c[fF+(fH*3160|0)+60+((fG>>>8&255)<<2)>>2]|0;do{if((fB|0)==0){fI=c[fF+(fH*3160|0)+3132>>2]|0;if((fI|0)==0){fL=0;fM=fH;fN=fF;break}fJ=gj[fI&4095](fK)|0;fL=fJ;fM=c[3528552]|0;fN=c[2433426]|0}else{fL=a[fB+(fG&255)|0]|0;fM=fH;fN=fF}}while(0);fF=(fL&255)<<8;fL=fG+1|0;fG=fL&65535;fH=c[fN+(fM*3160|0)+60+((fL>>>8&255)<<2)>>2]|0;do{if((fH|0)==0){fB=c[fN+(fM*3160|0)+3132>>2]|0;if((fB|0)==0){fO=0;break}fO=gj[fB&4095](fG)|0}else{fO=a[fH+(fL&255)|0]|0}}while(0);c[2426872]=fO&255|fF;break};case 251:{b[4853744]=(b[4821356]|0)+(b[4821364]|0)&65535;fF=c[2426872]|0;fO=fF&65535;fL=c[3528552]|0;fH=c[2433426]|0;fG=c[fH+(fL*3160|0)+60+((fF>>>8&255)<<2)>>2]|0;do{if((fG|0)==0){fM=c[fH+(fL*3160|0)+3132>>2]|0;if((fM|0)==0){fP=0;fQ=fL;fR=fH;break}fN=gj[fM&4095](fO)|0;fP=fN;fQ=c[3528552]|0;fR=c[2433426]|0}else{fP=a[fG+(fF&255)|0]|0;fQ=fL;fR=fH}}while(0);fH=(fP&255)<<8;fP=fF+1|0;fF=fP&65535;fL=c[fR+(fQ*3160|0)+60+((fP>>>8&255)<<2)>>2]|0;do{if((fL|0)==0){fG=c[fR+(fQ*3160|0)+3132>>2]|0;if((fG|0)==0){fS=0;break}fS=gj[fG&4095](fF)|0}else{fS=a[fL+(fP&255)|0]|0}}while(0);c[2426872]=fS&255|fH;break};case 252:{fH=c[2410676]|0;fS=fH&65535;fP=c[3528552]|0;fL=c[2433426]|0;fF=c[fL+(fP*3160|0)+60+((fH>>>8&255|512)<<2)>>2]|0;do{if((fF|0)==0){fQ=c[fL+(fP*3160|0)+3144>>2]|0;if((fQ|0)==0){fT=0;fU=fS;fV=fP;fW=fL;break}fR=gj[fQ&4095](fS)|0;fT=fR;fU=b[4821352]|0;fV=c[3528552]|0;fW=c[2433426]|0}else{fT=a[fF+(fH&255)|0]|0;fU=fS;fV=fP;fW=fL}}while(0);fL=fT&255;fT=fU+1&65535;b[4821352]=fT;b[4853744]=((fL&128)!=0?fL|-256:fL)+fT&65535;fT=c[2426872]|0;fL=fT&65535;fU=c[fW+(fV*3160|0)+60+((fT>>>8&255)<<2)>>2]|0;do{if((fU|0)==0){fP=c[fW+(fV*3160|0)+3132>>2]|0;if((fP|0)==0){fX=0;fY=fV;fZ=fW;break}fS=gj[fP&4095](fL)|0;fX=fS;fY=c[3528552]|0;fZ=c[2433426]|0}else{fX=a[fU+(fT&255)|0]|0;fY=fV;fZ=fW}}while(0);fW=(fX&255)<<8;fX=fT+1|0;fT=fX&65535;fV=c[fZ+(fY*3160|0)+60+((fX>>>8&255)<<2)>>2]|0;do{if((fV|0)==0){fU=c[fZ+(fY*3160|0)+3132>>2]|0;if((fU|0)==0){f_=0;break}f_=gj[fU&4095](fT)|0}else{f_=a[fV+(fX&255)|0]|0}}while(0);c[2426872]=f_&255|fW;break};case 253:{fW=c[2410676]|0;f_=fW&65535;fX=c[3528552]|0;fV=c[2433426]|0;fT=c[fV+(fX*3160|0)+60+((fW>>>8&255|512)<<2)>>2]|0;do{if((fT|0)==0){fY=c[fV+(fX*3160|0)+3144>>2]|0;if((fY|0)==0){f$=0;f0=fW;f1=fX;f2=fV;f3=f_;break}fZ=gj[fY&4095](f_)|0;fY=c[2410676]|0;f$=fZ;f0=fY;f1=c[3528552]|0;f2=c[2433426]|0;f3=fY&65535}else{f$=a[fT+(fW&255)|0]|0;f0=fW;f1=fX;f2=fV;f3=f_}}while(0);f_=(f$&255)<<8;f$=f0+1|0;f0=f$&65535;fV=c[f2+(f1*3160|0)+60+((f$>>>8&255|512)<<2)>>2]|0;do{if((fV|0)==0){fX=c[f2+(f1*3160|0)+3144>>2]|0;if((fX|0)==0){f4=0;f5=f3;f6=f1;f7=f2;break}fW=gj[fX&4095](f0)|0;f4=fW;f5=b[4821352]|0;f6=c[3528552]|0;f7=c[2433426]|0}else{f4=a[fV+(f$&255)|0]|0;f5=f3;f6=f1;f7=f2}}while(0);f2=f4&255|f_;c[2426872]=f2;f_=f5+2&65535;b[4821352]=f_;b[4853744]=(f2&65535)+f_&65535;f_=c[2426872]|0;f2=f_&65535;f5=c[f7+(f6*3160|0)+60+((f_>>>8&255)<<2)>>2]|0;do{if((f5|0)==0){f4=c[f7+(f6*3160|0)+3132>>2]|0;if((f4|0)==0){f8=0;f9=f6;ga=f7;break}f1=gj[f4&4095](f2)|0;f8=f1;f9=c[3528552]|0;ga=c[2433426]|0}else{f8=a[f5+(f_&255)|0]|0;f9=f6;ga=f7}}while(0);f7=(f8&255)<<8;f8=f_+1|0;f_=f8&65535;f6=c[ga+(f9*3160|0)+60+((f8>>>8&255)<<2)>>2]|0;do{if((f6|0)==0){f5=c[ga+(f9*3160|0)+3132>>2]|0;if((f5|0)==0){gb=0;break}gb=gj[f5&4095](f_)|0}else{gb=a[f6+(f8&255)|0]|0}}while(0);c[2426872]=gb&255|f7;break};case 254:{b[4853744]=(b[4821358]|0)+(b[4821364]|0)&65535;f7=c[2426872]|0;gb=f7&65535;f8=c[3528552]|0;f6=c[2433426]|0;f_=c[f6+(f8*3160|0)+60+((f7>>>8&255)<<2)>>2]|0;do{if((f_|0)==0){f9=c[f6+(f8*3160|0)+3132>>2]|0;if((f9|0)==0){gc=0;gd=f8;ge=f6;break}ga=gj[f9&4095](gb)|0;gc=ga;gd=c[3528552]|0;ge=c[2433426]|0}else{gc=a[f_+(f7&255)|0]|0;gd=f8;ge=f6}}while(0);f6=(gc&255)<<8;gc=f7+1|0;f7=gc&65535;f8=c[ge+(gd*3160|0)+60+((gc>>>8&255)<<2)>>2]|0;do{if((f8|0)==0){f_=c[ge+(gd*3160|0)+3132>>2]|0;if((f_|0)==0){gf=0;break}gf=gj[f_&4095](f7)|0}else{gf=a[f8+(gc&255)|0]|0}}while(0);c[2426872]=gf&255|f6;break};case 255:{a[9642745]=a[9642745]|64;fGQ();break};default:{}}c[2439272]=(c[2439272]|0)-(d[(c[2444186]|0)+m|0]|0);return}function fGQ(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;a[9642744]=a[9642744]|-128;b[4821364]=(b[4821364]|0)-1&65535;e=c[2410682]|0;f=e&65535;g=a[9642704]|0;h=c[3528552]|0;i=c[2433426]|0;j=c[i+(h*3160|0)+60+((e>>>8&255|256)<<2)>>2]|0;do{if((j|0)==0){k=c[i+(h*3160|0)+3136>>2]|0;if((k|0)==0){l=h;m=i;break}gg[k&4095](f,g);l=c[3528552]|0;m=c[2433426]|0}else{a[j+(e&255)|0]=g;l=h;m=i}}while(0);b[4821364]=(b[4821364]|0)-1&65535;i=c[2410682]|0;h=i&65535;g=a[9642705]|0;e=c[m+(l*3160|0)+60+((i>>>8&255|256)<<2)>>2]|0;do{if((e|0)==0){j=c[m+(l*3160|0)+3136>>2]|0;if((j|0)==0){n=l;o=m;break}gg[j&4095](h,g);n=c[3528552]|0;o=c[2433426]|0}else{a[e+(i&255)|0]=g;n=l;o=m}}while(0);b[4821364]=(b[4821364]|0)-1&65535;m=c[2410682]|0;l=m&65535;g=a[9642724]|0;i=c[o+(n*3160|0)+60+((m>>>8&255|256)<<2)>>2]|0;do{if((i|0)==0){e=c[o+(n*3160|0)+3136>>2]|0;if((e|0)==0){p=n;q=o;break}gg[e&4095](l,g);p=c[3528552]|0;q=c[2433426]|0}else{a[i+(m&255)|0]=g;p=n;q=o}}while(0);b[4821364]=(b[4821364]|0)-1&65535;o=c[2410682]|0;n=o&65535;g=a[9642725]|0;m=c[q+(p*3160|0)+60+((o>>>8&255|256)<<2)>>2]|0;do{if((m|0)==0){i=c[q+(p*3160|0)+3136>>2]|0;if((i|0)==0){r=p;s=q;break}gg[i&4095](n,g);r=c[3528552]|0;s=c[2433426]|0}else{a[m+(o&255)|0]=g;r=p;s=q}}while(0);b[4821364]=(b[4821364]|0)-1&65535;q=c[2410682]|0;p=q&65535;g=a[9642736]|0;o=c[s+(r*3160|0)+60+((q>>>8&255|256)<<2)>>2]|0;do{if((o|0)==0){m=c[s+(r*3160|0)+3136>>2]|0;if((m|0)==0){t=r;u=s;break}gg[m&4095](p,g);t=c[3528552]|0;u=c[2433426]|0}else{a[o+(q&255)|0]=g;t=r;u=s}}while(0);b[4821364]=(b[4821364]|0)-1&65535;s=c[2410682]|0;r=s&65535;g=a[9642737]|0;q=c[u+(t*3160|0)+60+((s>>>8&255|256)<<2)>>2]|0;do{if((q|0)==0){o=c[u+(t*3160|0)+3136>>2]|0;if((o|0)==0){v=t;w=u;break}gg[o&4095](r,g);v=c[3528552]|0;w=c[2433426]|0}else{a[q+(s&255)|0]=g;v=t;w=u}}while(0);b[4821364]=(b[4821364]|0)-1&65535;u=c[2410682]|0;t=u&65535;g=a[9642732]|0;s=c[w+(v*3160|0)+60+((u>>>8&255|256)<<2)>>2]|0;do{if((s|0)==0){q=c[w+(v*3160|0)+3136>>2]|0;if((q|0)==0){x=v;y=w;break}gg[q&4095](t,g);x=c[3528552]|0;y=c[2433426]|0}else{a[s+(u&255)|0]=g;x=v;y=w}}while(0);b[4821364]=(b[4821364]|0)-1&65535;w=c[2410682]|0;v=w&65535;g=a[9642733]|0;u=c[y+(x*3160|0)+60+((w>>>8&255|256)<<2)>>2]|0;do{if((u|0)==0){s=c[y+(x*3160|0)+3136>>2]|0;if((s|0)==0){z=x;A=y;break}gg[s&4095](v,g);z=c[3528552]|0;A=c[2433426]|0}else{a[u+(w&255)|0]=g;z=x;A=y}}while(0);b[4821364]=(b[4821364]|0)-1&65535;y=c[2410682]|0;x=y&65535;g=a[9642721]|0;w=c[A+(z*3160|0)+60+((y>>>8&255|256)<<2)>>2]|0;do{if((w|0)==0){u=c[A+(z*3160|0)+3136>>2]|0;if((u|0)==0){break}gg[u&4095](x,g)}else{a[w+(y&255)|0]=g}}while(0);if((a[9642745]&1)!=0){b[4821364]=(b[4821364]|0)-1&65535;g=c[2410682]|0;y=g&65535;w=a[9642716]|0;x=c[3528552]|0;z=c[2433426]|0;A=c[z+(x*3160|0)+60+((g>>>8&255|256)<<2)>>2]|0;do{if((A|0)==0){u=c[z+(x*3160|0)+3136>>2]|0;if((u|0)==0){B=x;C=z;break}gg[u&4095](y,w);B=c[3528552]|0;C=c[2433426]|0}else{a[A+(g&255)|0]=w;B=x;C=z}}while(0);b[4821364]=(b[4821364]|0)-1&65535;z=c[2410682]|0;x=z&65535;w=a[9642717]|0;g=c[C+(B*3160|0)+60+((z>>>8&255|256)<<2)>>2]|0;do{if((g|0)==0){A=c[C+(B*3160|0)+3136>>2]|0;if((A|0)==0){break}gg[A&4095](x,w)}else{a[g+(z&255)|0]=w}}while(0);c[2439272]=(c[2439272]|0)-2}b[4821364]=(b[4821364]|0)-1&65535;w=c[2410682]|0;z=w&65535;g=a[9642712]|0;x=c[3528552]|0;B=c[2433426]|0;C=c[B+(x*3160|0)+60+((w>>>8&255|256)<<2)>>2]|0;do{if((C|0)==0){A=c[B+(x*3160|0)+3136>>2]|0;if((A|0)==0){D=x;E=B;break}gg[A&4095](z,g);D=c[3528552]|0;E=c[2433426]|0}else{a[C+(w&255)|0]=g;D=x;E=B}}while(0);b[4821364]=(b[4821364]|0)-1&65535;B=c[2410682]|0;x=B&65535;g=a[9642713]|0;w=c[E+(D*3160|0)+60+((B>>>8&255|256)<<2)>>2]|0;do{if((w|0)==0){C=c[E+(D*3160|0)+3136>>2]|0;if((C|0)==0){F=D;G=E;break}gg[C&4095](x,g);F=c[3528552]|0;G=c[2433426]|0}else{a[w+(B&255)|0]=g;F=D;G=E}}while(0);b[4821364]=(b[4821364]|0)-1&65535;E=c[2410682]|0;D=E&65535;g=a[9642744]|0;B=c[G+(F*3160|0)+60+((E>>>8&255|256)<<2)>>2]|0;do{if((B|0)==0){w=c[G+(F*3160|0)+3136>>2]|0;if((w|0)==0){H=F;I=G;break}gg[w&4095](D,g);H=c[3528552]|0;I=c[2433426]|0}else{a[B+(E&255)|0]=g;H=F;I=G}}while(0);G=c[I+(H*3160|0)+1080>>2]|0;do{if((G|0)==0){F=c[I+(H*3160|0)+3132>>2]|0;if((F|0)==0){J=0;K=0;L=J&255;M=L|K;c[2410676]=M;N=M&65535;b[4821352]=N;return}g=gj[F&4095](-16)|0;F=c[3528552]|0;E=c[2433426]|0;B=c[E+(F*3160|0)+1080>>2]|0;D=(g&255)<<8;if((B|0)!=0){O=B;P=D;break}B=c[E+(F*3160|0)+3132>>2]|0;if((B|0)==0){J=0;K=D;L=J&255;M=L|K;c[2410676]=M;N=M&65535;b[4821352]=N;return}J=gj[B&4095](-15)|0;K=D;L=J&255;M=L|K;c[2410676]=M;N=M&65535;b[4821352]=N;return}else{O=G;P=(d[G+240|0]|0)<<8}}while(0);J=a[O+241|0]|0;K=P;L=J&255;M=L|K;c[2410676]=M;N=M&65535;b[4821352]=N;return}function fGR(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;l=f;m=g;break}n=gj[i&4095](e)|0;j=n;k=b[4821352]|0;l=c[3528552]|0;m=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=e;l=f;m=g}}while(0);b[4821352]=k+1&65535;c[2426872]=c[2410680];k=c[2410676]|0;g=k&65535;f=c[m+(l*3160|0)+60+((k>>>8&255|512)<<2)>>2]|0;do{if((f|0)==0){e=c[m+(l*3160|0)+3144>>2]|0;if((e|0)==0){o=0;p=g;q=l;r=m;break}d=gj[e&4095](g)|0;o=d;p=b[4821352]|0;q=c[3528552]|0;r=c[2433426]|0}else{o=a[f+(k&255)|0]|0;p=g;q=l;r=m}}while(0);a[9707488]=o;b[4821352]=p+1&65535;p=c[2426872]|0;o=p&65535;m=c[r+(q*3160|0)+60+((p>>>8&255)<<2)>>2]|0;do{if((m|0)==0){l=c[r+(q*3160|0)+3132>>2]|0;if((l|0)==0){s=0;break}s=gj[l&4095](o)|0}else{s=a[m+(p&255)|0]|0}}while(0);p=j&255;j=c[638616+(p>>>6<<2)>>2]|0;m=a[j]|0;o=a[641784+(p&7)|0]|0;do{if((o&m)<<24>>24!=0){if((a[641784+(p>>>3&7)|0]&s)<<24>>24==0){break}t=o|m;a[j]=t;return}}while(0);t=m&~o;a[j]=t;return}function fGS(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=c[2410676]|0;f=e&65535;g=c[3528552]|0;h=c[2433426]|0;i=c[h+(g*3160|0)+60+((e>>>8&255|512)<<2)>>2]|0;do{if((i|0)==0){j=c[h+(g*3160|0)+3144>>2]|0;if((j|0)==0){k=0;l=f;m=g;n=h;break}o=gj[j&4095](f)|0;k=o;l=b[4821352]|0;m=c[3528552]|0;n=c[2433426]|0}else{k=a[i+(e&255)|0]|0;l=f;m=g;n=h}}while(0);b[4821352]=l+1&65535;c[2426872]=c[2410680];l=c[2410676]|0;h=l&65535;g=c[n+(m*3160|0)+60+((l>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){f=c[n+(m*3160|0)+3144>>2]|0;if((f|0)==0){p=0;q=h;r=m;s=n;break}e=gj[f&4095](h)|0;p=e;q=b[4821352]|0;r=c[3528552]|0;s=c[2433426]|0}else{p=a[g+(l&255)|0]|0;q=h;r=m;s=n}}while(0);a[9707488]=p;b[4821352]=q+1&65535;q=c[2426872]|0;p=q&65535;n=c[s+(r*3160|0)+60+((q>>>8&255)<<2)>>2]|0;do{if((n|0)==0){m=c[s+(r*3160|0)+3132>>2]|0;if((m|0)==0){t=0;break}t=gj[m&4095](p)|0}else{t=a[n+(q&255)|0]|0}}while(0);q=k&255;k=c[638616+(q>>>6<<2)>>2]|0;n=a[k]|0;p=a[641784+(q&7)|0]|0;do{if((p&n)<<24>>24!=0){if(((d[641784+(q>>>3&7)|0]|0)&~(t&255)|0)==0){break}u=p|n;a[k]=u;return}}while(0);u=n&~p;a[k]=u;return}function fGT(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;l=f;m=g;break}n=gj[i&4095](e)|0;j=n;k=b[4821352]|0;l=c[3528552]|0;m=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=e;l=f;m=g}}while(0);b[4821352]=k+1&65535;c[2426872]=c[2410680];k=c[2410676]|0;g=k&65535;f=c[m+(l*3160|0)+60+((k>>>8&255|512)<<2)>>2]|0;do{if((f|0)==0){e=c[m+(l*3160|0)+3144>>2]|0;if((e|0)==0){o=0;p=g;q=l;r=m;break}d=gj[e&4095](g)|0;o=d;p=b[4821352]|0;q=c[3528552]|0;r=c[2433426]|0}else{o=a[f+(k&255)|0]|0;p=g;q=l;r=m}}while(0);a[9707488]=o;b[4821352]=p+1&65535;p=c[2426872]|0;o=p&65535;m=c[r+(q*3160|0)+60+((p>>>8&255)<<2)>>2]|0;do{if((m|0)==0){l=c[r+(q*3160|0)+3132>>2]|0;if((l|0)==0){s=0;break}s=gj[l&4095](o)|0}else{s=a[m+(p&255)|0]|0}}while(0);p=j&255;j=c[638616+(p>>>6<<2)>>2]|0;m=a[j]|0;o=a[641784+(p&7)|0]|0;do{if((o&m)<<24>>24==0){if((a[641784+(p>>>3&7)|0]&s)<<24>>24!=0){break}t=m&~o;a[j]=t;return}}while(0);t=o|m;a[j]=t;return}function fGU(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=c[2410676]|0;f=e&65535;g=c[3528552]|0;h=c[2433426]|0;i=c[h+(g*3160|0)+60+((e>>>8&255|512)<<2)>>2]|0;do{if((i|0)==0){j=c[h+(g*3160|0)+3144>>2]|0;if((j|0)==0){k=0;l=f;m=g;n=h;break}o=gj[j&4095](f)|0;k=o;l=b[4821352]|0;m=c[3528552]|0;n=c[2433426]|0}else{k=a[i+(e&255)|0]|0;l=f;m=g;n=h}}while(0);b[4821352]=l+1&65535;c[2426872]=c[2410680];l=c[2410676]|0;h=l&65535;g=c[n+(m*3160|0)+60+((l>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){f=c[n+(m*3160|0)+3144>>2]|0;if((f|0)==0){p=0;q=h;r=m;s=n;break}e=gj[f&4095](h)|0;p=e;q=b[4821352]|0;r=c[3528552]|0;s=c[2433426]|0}else{p=a[g+(l&255)|0]|0;q=h;r=m;s=n}}while(0);a[9707488]=p;b[4821352]=q+1&65535;q=c[2426872]|0;p=q&65535;n=c[s+(r*3160|0)+60+((q>>>8&255)<<2)>>2]|0;do{if((n|0)==0){m=c[s+(r*3160|0)+3132>>2]|0;if((m|0)==0){t=0;break}t=gj[m&4095](p)|0}else{t=a[n+(q&255)|0]|0}}while(0);q=k&255;k=c[638616+(q>>>6<<2)>>2]|0;n=a[k]|0;p=a[641784+(q&7)|0]|0;do{if((p&n)<<24>>24==0){if(((d[641784+(q>>>3&7)|0]|0)&~(t&255)|0)!=0){break}u=n&~p;a[k]=u;return}}while(0);u=p|n;a[k]=u;return}function fGV(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;l=f;m=g;break}n=gj[i&4095](e)|0;j=n;k=b[4821352]|0;l=c[3528552]|0;m=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=e;l=f;m=g}}while(0);b[4821352]=k+1&65535;c[2426872]=c[2410680];k=c[2410676]|0;g=k&65535;f=c[m+(l*3160|0)+60+((k>>>8&255|512)<<2)>>2]|0;do{if((f|0)==0){e=c[m+(l*3160|0)+3144>>2]|0;if((e|0)==0){o=0;p=g;q=l;r=m;break}d=gj[e&4095](g)|0;o=d;p=b[4821352]|0;q=c[3528552]|0;r=c[2433426]|0}else{o=a[f+(k&255)|0]|0;p=g;q=l;r=m}}while(0);a[9707488]=o;b[4821352]=p+1&65535;p=c[2426872]|0;o=p&65535;m=c[r+(q*3160|0)+60+((p>>>8&255)<<2)>>2]|0;do{if((m|0)==0){l=c[r+(q*3160|0)+3132>>2]|0;if((l|0)==0){s=0;break}s=gj[l&4095](o)|0}else{s=a[m+(p&255)|0]|0}}while(0);p=j&255;j=c[638616+(p>>>6<<2)>>2]|0;m=a[j]|0;o=a[641784+(p&7)|0]|0;q=o&m;r=a[641784+(p>>>3&7)|0]&s;if((r|q)<<24>>24!=0&(q<<24>>24==0|r<<24>>24==0)){t=o|m;a[j]=t;return}else{t=m&~o;a[j]=t;return}}function fGW(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;l=f;m=g;break}n=gj[i&4095](e)|0;j=n;k=b[4821352]|0;l=c[3528552]|0;m=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=e;l=f;m=g}}while(0);b[4821352]=k+1&65535;c[2426872]=c[2410680];k=c[2410676]|0;g=k&65535;f=c[m+(l*3160|0)+60+((k>>>8&255|512)<<2)>>2]|0;do{if((f|0)==0){e=c[m+(l*3160|0)+3144>>2]|0;if((e|0)==0){o=0;p=g;q=l;r=m;break}d=gj[e&4095](g)|0;o=d;p=b[4821352]|0;q=c[3528552]|0;r=c[2433426]|0}else{o=a[f+(k&255)|0]|0;p=g;q=l;r=m}}while(0);a[9707488]=o;b[4821352]=p+1&65535;p=c[2426872]|0;o=p&65535;m=c[r+(q*3160|0)+60+((p>>>8&255)<<2)>>2]|0;do{if((m|0)==0){l=c[r+(q*3160|0)+3132>>2]|0;if((l|0)==0){s=0;break}s=gj[l&4095](o)|0}else{s=a[m+(p&255)|0]|0}}while(0);p=j&255;j=c[638616+(p>>>6<<2)>>2]|0;m=a[j]|0;o=a[641784+(p&7)|0]|0;q=o&m;r=a[641784+(p>>>3&7)|0]&~s;if((r|q)<<24>>24!=0&(q<<24>>24==0|r<<24>>24==0)){t=o|m;a[j]=t;return}else{t=m&~o;a[j]=t;return}}function fGX(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;l=f;m=g;break}n=gj[i&4095](e)|0;j=n;k=b[4821352]|0;l=c[3528552]|0;m=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=e;l=f;m=g}}while(0);b[4821352]=k+1&65535;c[2426872]=c[2410680];k=c[2410676]|0;g=k&65535;f=c[m+(l*3160|0)+60+((k>>>8&255|512)<<2)>>2]|0;do{if((f|0)==0){e=c[m+(l*3160|0)+3144>>2]|0;if((e|0)==0){o=0;p=g;q=l;r=m;break}d=gj[e&4095](g)|0;o=d;p=b[4821352]|0;q=c[3528552]|0;r=c[2433426]|0}else{o=a[f+(k&255)|0]|0;p=g;q=l;r=m}}while(0);a[9707488]=o;b[4821352]=p+1&65535;p=c[2426872]|0;o=p&65535;m=c[r+(q*3160|0)+60+((p>>>8&255)<<2)>>2]|0;do{if((m|0)==0){l=c[r+(q*3160|0)+3132>>2]|0;if((l|0)==0){s=0;break}s=gj[l&4095](o)|0}else{s=a[m+(p&255)|0]|0}}while(0);p=j&255;j=a[641784+(p&7)|0]|0;if((a[641784+(p>>>3&7)|0]&s)<<24>>24==0){s=c[638616+(p>>>6<<2)>>2]|0;a[s]=a[s]&~j;return}else{s=c[638616+(p>>>6<<2)>>2]|0;a[s]=a[s]|j;return}}function fGY(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;l=f;m=g;break}n=gj[i&4095](e)|0;j=n;k=b[4821352]|0;l=c[3528552]|0;m=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=e;l=f;m=g}}while(0);b[4821352]=k+1&65535;c[2426872]=c[2410680];k=c[2410676]|0;g=k&65535;f=c[m+(l*3160|0)+60+((k>>>8&255|512)<<2)>>2]|0;do{if((f|0)==0){e=c[m+(l*3160|0)+3144>>2]|0;if((e|0)==0){o=0;p=g;q=l;r=m;break}d=gj[e&4095](g)|0;o=d;p=b[4821352]|0;q=c[3528552]|0;r=c[2433426]|0}else{o=a[f+(k&255)|0]|0;p=g;q=l;r=m}}while(0);a[9707488]=o;b[4821352]=p+1&65535;p=c[2426872]|0;o=p&65535;m=c[r+(q*3160|0)+60+((p>>>8&255)<<2)>>2]|0;do{if((m|0)==0){l=c[r+(q*3160|0)+3132>>2]|0;if((l|0)==0){s=0;t=p;break}g=gj[l&4095](o)|0;s=g;t=c[2426872]|0}else{s=a[m+(p&255)|0]|0;t=p}}while(0);p=j&255;j=t&65535;m=a[641784+(p>>>3&7)|0]|0;if((a[641784+(p&7)|0]&a[c[638616+(p>>>6<<2)>>2]|0])<<24>>24==0){p=s&~m;o=c[3528552]|0;q=c[2433426]|0;r=c[q+(o*3160|0)+60+((t>>>8&255|256)<<2)>>2]|0;if((r|0)!=0){a[r+(t&255)|0]=p;return}r=c[q+(o*3160|0)+3136>>2]|0;if((r|0)==0){return}gg[r&4095](j,p);return}else{p=m|s;s=c[3528552]|0;m=c[2433426]|0;r=c[m+(s*3160|0)+60+((t>>>8&255|256)<<2)>>2]|0;if((r|0)!=0){a[r+(t&255)|0]=p;return}t=c[m+(s*3160|0)+3136>>2]|0;if((t|0)==0){return}gg[t&4095](j,p);return}}function fGZ(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;break}l=gj[i&4095](e)|0;j=l;k=b[4821352]|0}else{j=a[h+(d&255)|0]|0;k=e}}while(0);b[4821352]=k+1&65535;if((b[4821358]|0)==0){c[2439272]=(c[2439272]|0)-6;return}k=j&255;L13404:do{switch(k>>>4|0){case 0:{j=b[4821356]|0;b[4821356]=j+1&65535;e=j&65535;d=c[3528552]|0;h=c[2433426]|0;f=c[h+(d*3160|0)+60+(e>>>8<<2)>>2]|0;if((f|0)!=0){m=a[f+(e&255)|0]|0;break L13404}e=c[h+(d*3160|0)+3132>>2]|0;if((e|0)==0){m=0;break L13404}m=gj[e&4095](j)|0;break};case 4:{j=b[4821364]|0;b[4821364]=j+1&65535;e=j&65535;d=c[3528552]|0;h=c[2433426]|0;f=c[h+(d*3160|0)+60+(e>>>8<<2)>>2]|0;if((f|0)!=0){m=a[f+(e&255)|0]|0;break L13404}e=c[h+(d*3160|0)+3132>>2]|0;if((e|0)==0){m=0;break L13404}m=gj[e&4095](j)|0;break};case 1:{j=b[4821366]|0;b[4821366]=j+1&65535;e=j&65535;d=c[3528552]|0;h=c[2433426]|0;f=c[h+(d*3160|0)+60+(e>>>8<<2)>>2]|0;if((f|0)!=0){m=a[f+(e&255)|0]|0;break L13404}e=c[h+(d*3160|0)+3132>>2]|0;if((e|0)==0){m=0;break L13404}m=gj[e&4095](j)|0;break};case 2:{j=b[4821368]|0;b[4821368]=j+1&65535;e=j&65535;d=c[3528552]|0;h=c[2433426]|0;f=c[h+(d*3160|0)+60+(e>>>8<<2)>>2]|0;if((f|0)!=0){m=a[f+(e&255)|0]|0;break L13404}e=c[h+(d*3160|0)+3132>>2]|0;if((e|0)==0){m=0;break L13404}m=gj[e&4095](j)|0;break};case 3:{j=b[4821362]|0;b[4821362]=j+1&65535;e=j&65535;d=c[3528552]|0;h=c[2433426]|0;f=c[h+(d*3160|0)+60+(e>>>8<<2)>>2]|0;if((f|0)!=0){m=a[f+(e&255)|0]|0;break L13404}e=c[h+(d*3160|0)+3132>>2]|0;if((e|0)==0){m=0;break L13404}m=gj[e&4095](j)|0;break};default:{a[9642745]=a[9642745]|64;fGQ();return}}}while(0);L13433:do{switch(k&15|0){case 0:{j=b[4821356]|0;b[4821356]=j+1&65535;e=j&65535;d=c[3528552]|0;h=c[2433426]|0;f=c[h+(d*3160|0)+60+((e>>>8|256)<<2)>>2]|0;if((f|0)!=0){a[f+(e&255)|0]=m;break L13433}e=c[h+(d*3160|0)+3136>>2]|0;if((e|0)==0){break L13433}gg[e&4095](j,m);break};case 2:{j=b[4821368]|0;b[4821368]=j+1&65535;e=j&65535;d=c[3528552]|0;h=c[2433426]|0;f=c[h+(d*3160|0)+60+((e>>>8|256)<<2)>>2]|0;if((f|0)!=0){a[f+(e&255)|0]=m;break L13433}e=c[h+(d*3160|0)+3136>>2]|0;if((e|0)==0){break L13433}gg[e&4095](j,m);break};case 3:{j=b[4821362]|0;b[4821362]=j+1&65535;e=j&65535;d=c[3528552]|0;h=c[2433426]|0;f=c[h+(d*3160|0)+60+((e>>>8|256)<<2)>>2]|0;if((f|0)!=0){a[f+(e&255)|0]=m;break L13433}e=c[h+(d*3160|0)+3136>>2]|0;if((e|0)==0){break L13433}gg[e&4095](j,m);break};case 4:{j=b[4821364]|0;b[4821364]=j+1&65535;e=j&65535;d=c[3528552]|0;h=c[2433426]|0;f=c[h+(d*3160|0)+60+((e>>>8|256)<<2)>>2]|0;if((f|0)!=0){a[f+(e&255)|0]=m;break L13433}e=c[h+(d*3160|0)+3136>>2]|0;if((e|0)==0){break L13433}gg[e&4095](j,m);break};case 1:{j=b[4821366]|0;b[4821366]=j+1&65535;e=j&65535;d=c[3528552]|0;h=c[2433426]|0;f=c[h+(d*3160|0)+60+((e>>>8|256)<<2)>>2]|0;if((f|0)!=0){a[f+(e&255)|0]=m;break L13433}e=c[h+(d*3160|0)+3136>>2]|0;if((e|0)==0){break L13433}gg[e&4095](j,m);break};default:{a[9642745]=a[9642745]|64;fGQ();return}}}while(0);m=(c[2410676]|0)-3|0;c[2410676]=m;b[4821352]=m&65535;b[4821358]=(b[4821358]|0)-1&65535;return}function fG_(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;break}l=gj[i&4095](e)|0;j=l;k=b[4821352]|0}else{j=a[h+(d&255)|0]|0;k=e}}while(0);b[4821352]=k+1&65535;if((b[4821358]|0)==0){c[2439272]=(c[2439272]|0)-6;return}k=j&255;L13473:do{switch(k>>>4|0){case 0:{j=b[4821356]|0;b[4821356]=j-1&65535;e=j&65535;d=c[3528552]|0;h=c[2433426]|0;f=c[h+(d*3160|0)+60+(e>>>8<<2)>>2]|0;if((f|0)!=0){m=a[f+(e&255)|0]|0;break L13473}e=c[h+(d*3160|0)+3132>>2]|0;if((e|0)==0){m=0;break L13473}m=gj[e&4095](j)|0;break};case 1:{j=b[4821366]|0;b[4821366]=j-1&65535;e=j&65535;d=c[3528552]|0;h=c[2433426]|0;f=c[h+(d*3160|0)+60+(e>>>8<<2)>>2]|0;if((f|0)!=0){m=a[f+(e&255)|0]|0;break L13473}e=c[h+(d*3160|0)+3132>>2]|0;if((e|0)==0){m=0;break L13473}m=gj[e&4095](j)|0;break};case 2:{j=b[4821368]|0;b[4821368]=j-1&65535;e=j&65535;d=c[3528552]|0;h=c[2433426]|0;f=c[h+(d*3160|0)+60+(e>>>8<<2)>>2]|0;if((f|0)!=0){m=a[f+(e&255)|0]|0;break L13473}e=c[h+(d*3160|0)+3132>>2]|0;if((e|0)==0){m=0;break L13473}m=gj[e&4095](j)|0;break};case 3:{j=b[4821362]|0;b[4821362]=j-1&65535;e=j&65535;d=c[3528552]|0;h=c[2433426]|0;f=c[h+(d*3160|0)+60+(e>>>8<<2)>>2]|0;if((f|0)!=0){m=a[f+(e&255)|0]|0;break L13473}e=c[h+(d*3160|0)+3132>>2]|0;if((e|0)==0){m=0;break L13473}m=gj[e&4095](j)|0;break};case 4:{j=b[4821364]|0;b[4821364]=j-1&65535;e=j&65535;d=c[3528552]|0;h=c[2433426]|0;f=c[h+(d*3160|0)+60+(e>>>8<<2)>>2]|0;if((f|0)!=0){m=a[f+(e&255)|0]|0;break L13473}e=c[h+(d*3160|0)+3132>>2]|0;if((e|0)==0){m=0;break L13473}m=gj[e&4095](j)|0;break};default:{a[9642745]=a[9642745]|64;fGQ();return}}}while(0);L13502:do{switch(k&15|0){case 4:{j=b[4821364]|0;b[4821364]=j-1&65535;e=j&65535;d=c[3528552]|0;h=c[2433426]|0;f=c[h+(d*3160|0)+60+((e>>>8|256)<<2)>>2]|0;if((f|0)!=0){a[f+(e&255)|0]=m;break L13502}e=c[h+(d*3160|0)+3136>>2]|0;if((e|0)==0){break L13502}gg[e&4095](j,m);break};case 3:{j=b[4821362]|0;b[4821362]=j-1&65535;e=j&65535;d=c[3528552]|0;h=c[2433426]|0;f=c[h+(d*3160|0)+60+((e>>>8|256)<<2)>>2]|0;if((f|0)!=0){a[f+(e&255)|0]=m;break L13502}e=c[h+(d*3160|0)+3136>>2]|0;if((e|0)==0){break L13502}gg[e&4095](j,m);break};case 2:{j=b[4821368]|0;b[4821368]=j-1&65535;e=j&65535;d=c[3528552]|0;h=c[2433426]|0;f=c[h+(d*3160|0)+60+((e>>>8|256)<<2)>>2]|0;if((f|0)!=0){a[f+(e&255)|0]=m;break L13502}e=c[h+(d*3160|0)+3136>>2]|0;if((e|0)==0){break L13502}gg[e&4095](j,m);break};case 0:{j=b[4821356]|0;b[4821356]=j-1&65535;e=j&65535;d=c[3528552]|0;h=c[2433426]|0;f=c[h+(d*3160|0)+60+((e>>>8|256)<<2)>>2]|0;if((f|0)!=0){a[f+(e&255)|0]=m;break L13502}e=c[h+(d*3160|0)+3136>>2]|0;if((e|0)==0){break L13502}gg[e&4095](j,m);break};case 1:{j=b[4821366]|0;b[4821366]=j-1&65535;e=j&65535;d=c[3528552]|0;h=c[2433426]|0;f=c[h+(d*3160|0)+60+((e>>>8|256)<<2)>>2]|0;if((f|0)!=0){a[f+(e&255)|0]=m;break L13502}e=c[h+(d*3160|0)+3136>>2]|0;if((e|0)==0){break L13502}gg[e&4095](j,m);break};default:{a[9642745]=a[9642745]|64;fGQ();return}}}while(0);m=(c[2410676]|0)-3|0;c[2410676]=m;b[4821352]=m&65535;b[4821358]=(b[4821358]|0)-1&65535;return}function fG$(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;break}l=gj[i&4095](e)|0;j=l;k=b[4821352]|0}else{j=a[h+(d&255)|0]|0;k=e}}while(0);b[4821352]=k+1&65535;if((b[4821358]|0)==0){c[2439272]=(c[2439272]|0)-6;return}k=j&255;L13542:do{switch(k>>>4|0){case 0:{j=b[4821356]|0;b[4821356]=j+1&65535;e=j&65535;d=c[3528552]|0;h=c[2433426]|0;f=c[h+(d*3160|0)+60+(e>>>8<<2)>>2]|0;if((f|0)!=0){m=a[f+(e&255)|0]|0;break L13542}e=c[h+(d*3160|0)+3132>>2]|0;if((e|0)==0){m=0;break L13542}m=gj[e&4095](j)|0;break};case 4:{j=b[4821364]|0;b[4821364]=j+1&65535;e=j&65535;d=c[3528552]|0;h=c[2433426]|0;f=c[h+(d*3160|0)+60+(e>>>8<<2)>>2]|0;if((f|0)!=0){m=a[f+(e&255)|0]|0;break L13542}e=c[h+(d*3160|0)+3132>>2]|0;if((e|0)==0){m=0;break L13542}m=gj[e&4095](j)|0;break};case 1:{j=b[4821366]|0;b[4821366]=j+1&65535;e=j&65535;d=c[3528552]|0;h=c[2433426]|0;f=c[h+(d*3160|0)+60+(e>>>8<<2)>>2]|0;if((f|0)!=0){m=a[f+(e&255)|0]|0;break L13542}e=c[h+(d*3160|0)+3132>>2]|0;if((e|0)==0){m=0;break L13542}m=gj[e&4095](j)|0;break};case 2:{j=b[4821368]|0;b[4821368]=j+1&65535;e=j&65535;d=c[3528552]|0;h=c[2433426]|0;f=c[h+(d*3160|0)+60+(e>>>8<<2)>>2]|0;if((f|0)!=0){m=a[f+(e&255)|0]|0;break L13542}e=c[h+(d*3160|0)+3132>>2]|0;if((e|0)==0){m=0;break L13542}m=gj[e&4095](j)|0;break};case 3:{j=b[4821362]|0;b[4821362]=j+1&65535;e=j&65535;d=c[3528552]|0;h=c[2433426]|0;f=c[h+(d*3160|0)+60+(e>>>8<<2)>>2]|0;if((f|0)!=0){m=a[f+(e&255)|0]|0;break L13542}e=c[h+(d*3160|0)+3132>>2]|0;if((e|0)==0){m=0;break L13542}m=gj[e&4095](j)|0;break};default:{a[9642745]=a[9642745]|64;fGQ();return}}}while(0);L13571:do{switch(k&15|0){case 0:{j=b[4821356]|0;e=j&65535;d=c[3528552]|0;h=c[2433426]|0;f=c[h+(d*3160|0)+60+((e>>>8|256)<<2)>>2]|0;if((f|0)!=0){a[f+(e&255)|0]=m;break L13571}e=c[h+(d*3160|0)+3136>>2]|0;if((e|0)==0){break L13571}gg[e&4095](j,m);break};case 4:{j=b[4821364]|0;e=j&65535;d=c[3528552]|0;h=c[2433426]|0;f=c[h+(d*3160|0)+60+((e>>>8|256)<<2)>>2]|0;if((f|0)!=0){a[f+(e&255)|0]=m;break L13571}e=c[h+(d*3160|0)+3136>>2]|0;if((e|0)==0){break L13571}gg[e&4095](j,m);break};case 3:{j=b[4821362]|0;e=j&65535;d=c[3528552]|0;h=c[2433426]|0;f=c[h+(d*3160|0)+60+((e>>>8|256)<<2)>>2]|0;if((f|0)!=0){a[f+(e&255)|0]=m;break L13571}e=c[h+(d*3160|0)+3136>>2]|0;if((e|0)==0){break L13571}gg[e&4095](j,m);break};case 2:{j=b[4821368]|0;e=j&65535;d=c[3528552]|0;h=c[2433426]|0;f=c[h+(d*3160|0)+60+((e>>>8|256)<<2)>>2]|0;if((f|0)!=0){a[f+(e&255)|0]=m;break L13571}e=c[h+(d*3160|0)+3136>>2]|0;if((e|0)==0){break L13571}gg[e&4095](j,m);break};case 1:{j=b[4821366]|0;e=j&65535;d=c[3528552]|0;h=c[2433426]|0;f=c[h+(d*3160|0)+60+((e>>>8|256)<<2)>>2]|0;if((f|0)!=0){a[f+(e&255)|0]=m;break L13571}e=c[h+(d*3160|0)+3136>>2]|0;if((e|0)==0){break L13571}gg[e&4095](j,m);break};default:{a[9642745]=a[9642745]|64;fGQ();return}}}while(0);m=(c[2410676]|0)-3|0;c[2410676]=m;b[4821352]=m&65535;b[4821358]=(b[4821358]|0)-1&65535;return}function fG0(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;break}l=gj[i&4095](e)|0;j=l;k=b[4821352]|0}else{j=a[h+(d&255)|0]|0;k=e}}while(0);b[4821352]=k+1&65535;if((b[4821358]|0)==0){c[2439272]=(c[2439272]|0)-6;return}k=j&255;L13611:do{switch(k>>>4|0){case 0:{j=b[4821356]|0;e=j&65535;d=c[3528552]|0;h=c[2433426]|0;f=c[h+(d*3160|0)+60+(e>>>8<<2)>>2]|0;if((f|0)!=0){m=a[f+(e&255)|0]|0;break L13611}e=c[h+(d*3160|0)+3132>>2]|0;if((e|0)==0){m=0;break L13611}m=gj[e&4095](j)|0;break};case 1:{j=b[4821366]|0;e=j&65535;d=c[3528552]|0;h=c[2433426]|0;f=c[h+(d*3160|0)+60+(e>>>8<<2)>>2]|0;if((f|0)!=0){m=a[f+(e&255)|0]|0;break L13611}e=c[h+(d*3160|0)+3132>>2]|0;if((e|0)==0){m=0;break L13611}m=gj[e&4095](j)|0;break};case 2:{j=b[4821368]|0;e=j&65535;d=c[3528552]|0;h=c[2433426]|0;f=c[h+(d*3160|0)+60+(e>>>8<<2)>>2]|0;if((f|0)!=0){m=a[f+(e&255)|0]|0;break L13611}e=c[h+(d*3160|0)+3132>>2]|0;if((e|0)==0){m=0;break L13611}m=gj[e&4095](j)|0;break};case 3:{j=b[4821362]|0;e=j&65535;d=c[3528552]|0;h=c[2433426]|0;f=c[h+(d*3160|0)+60+(e>>>8<<2)>>2]|0;if((f|0)!=0){m=a[f+(e&255)|0]|0;break L13611}e=c[h+(d*3160|0)+3132>>2]|0;if((e|0)==0){m=0;break L13611}m=gj[e&4095](j)|0;break};case 4:{j=b[4821364]|0;e=j&65535;d=c[3528552]|0;h=c[2433426]|0;f=c[h+(d*3160|0)+60+(e>>>8<<2)>>2]|0;if((f|0)!=0){m=a[f+(e&255)|0]|0;break L13611}e=c[h+(d*3160|0)+3132>>2]|0;if((e|0)==0){m=0;break L13611}m=gj[e&4095](j)|0;break};default:{a[9642745]=a[9642745]|64;fGQ();return}}}while(0);L13640:do{switch(k&15|0){case 1:{j=b[4821366]|0;b[4821366]=j+1&65535;e=j&65535;d=c[3528552]|0;h=c[2433426]|0;f=c[h+(d*3160|0)+60+((e>>>8|256)<<2)>>2]|0;if((f|0)!=0){a[f+(e&255)|0]=m;break L13640}e=c[h+(d*3160|0)+3136>>2]|0;if((e|0)==0){break L13640}gg[e&4095](j,m);break};case 4:{j=b[4821364]|0;b[4821364]=j+1&65535;e=j&65535;d=c[3528552]|0;h=c[2433426]|0;f=c[h+(d*3160|0)+60+((e>>>8|256)<<2)>>2]|0;if((f|0)!=0){a[f+(e&255)|0]=m;break L13640}e=c[h+(d*3160|0)+3136>>2]|0;if((e|0)==0){break L13640}gg[e&4095](j,m);break};case 3:{j=b[4821362]|0;b[4821362]=j+1&65535;e=j&65535;d=c[3528552]|0;h=c[2433426]|0;f=c[h+(d*3160|0)+60+((e>>>8|256)<<2)>>2]|0;if((f|0)!=0){a[f+(e&255)|0]=m;break L13640}e=c[h+(d*3160|0)+3136>>2]|0;if((e|0)==0){break L13640}gg[e&4095](j,m);break};case 2:{j=b[4821368]|0;b[4821368]=j+1&65535;e=j&65535;d=c[3528552]|0;h=c[2433426]|0;f=c[h+(d*3160|0)+60+((e>>>8|256)<<2)>>2]|0;if((f|0)!=0){a[f+(e&255)|0]=m;break L13640}e=c[h+(d*3160|0)+3136>>2]|0;if((e|0)==0){break L13640}gg[e&4095](j,m);break};case 0:{j=b[4821356]|0;b[4821356]=j+1&65535;e=j&65535;d=c[3528552]|0;h=c[2433426]|0;f=c[h+(d*3160|0)+60+((e>>>8|256)<<2)>>2]|0;if((f|0)!=0){a[f+(e&255)|0]=m;break L13640}e=c[h+(d*3160|0)+3136>>2]|0;if((e|0)==0){break L13640}gg[e&4095](j,m);break};default:{a[9642745]=a[9642745]|64;fGQ();return}}}while(0);m=(c[2410676]|0)-3|0;c[2410676]=m;b[4821352]=m&65535;b[4821358]=(b[4821358]|0)-1&65535;return}function fG1(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;break}l=gj[i&4095](e)|0;j=l;k=b[4821352]|0}else{j=a[h+(d&255)|0]|0;k=e}}while(0);b[4821352]=k+1&65535;k=a[9642745]|0;e=k&j;j=a[9642744]|0;a[9642744]=e<<24>>24==0?j|4:j&-5;a[9642745]=((e|63)^-64)&k;return}function fG2(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;break}l=gj[i&4095](e)|0;j=l;k=b[4821352]|0}else{j=a[h+(d&255)|0]|0;k=e}}while(0);a[9642745]=j;b[4821352]=k+1&65535;k=(j&1)==0;c[2430032]=k?1595912:1595656;c[2429672]=k?1114752:1114496;c[2429670]=k?1114240:1113984;c[2444186]=k?4654424:4654168;return}function fG3(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;a[9642744]=a[9642744]|-128;b[4821364]=(b[4821364]|0)-1&65535;e=c[2410682]|0;f=e&65535;g=a[9642704]|0;h=c[3528552]|0;i=c[2433426]|0;j=c[i+(h*3160|0)+60+((e>>>8&255|256)<<2)>>2]|0;do{if((j|0)==0){k=c[i+(h*3160|0)+3136>>2]|0;if((k|0)==0){l=h;m=i;break}gg[k&4095](f,g);l=c[3528552]|0;m=c[2433426]|0}else{a[j+(e&255)|0]=g;l=h;m=i}}while(0);b[4821364]=(b[4821364]|0)-1&65535;i=c[2410682]|0;h=i&65535;g=a[9642705]|0;e=c[m+(l*3160|0)+60+((i>>>8&255|256)<<2)>>2]|0;do{if((e|0)==0){j=c[m+(l*3160|0)+3136>>2]|0;if((j|0)==0){n=l;o=m;break}gg[j&4095](h,g);n=c[3528552]|0;o=c[2433426]|0}else{a[e+(i&255)|0]=g;n=l;o=m}}while(0);b[4821364]=(b[4821364]|0)-1&65535;m=c[2410682]|0;l=m&65535;g=a[9642724]|0;i=c[o+(n*3160|0)+60+((m>>>8&255|256)<<2)>>2]|0;do{if((i|0)==0){e=c[o+(n*3160|0)+3136>>2]|0;if((e|0)==0){p=n;q=o;break}gg[e&4095](l,g);p=c[3528552]|0;q=c[2433426]|0}else{a[i+(m&255)|0]=g;p=n;q=o}}while(0);b[4821364]=(b[4821364]|0)-1&65535;o=c[2410682]|0;n=o&65535;g=a[9642725]|0;m=c[q+(p*3160|0)+60+((o>>>8&255|256)<<2)>>2]|0;do{if((m|0)==0){i=c[q+(p*3160|0)+3136>>2]|0;if((i|0)==0){r=p;s=q;break}gg[i&4095](n,g);r=c[3528552]|0;s=c[2433426]|0}else{a[m+(o&255)|0]=g;r=p;s=q}}while(0);b[4821364]=(b[4821364]|0)-1&65535;q=c[2410682]|0;p=q&65535;g=a[9642736]|0;o=c[s+(r*3160|0)+60+((q>>>8&255|256)<<2)>>2]|0;do{if((o|0)==0){m=c[s+(r*3160|0)+3136>>2]|0;if((m|0)==0){t=r;u=s;break}gg[m&4095](p,g);t=c[3528552]|0;u=c[2433426]|0}else{a[o+(q&255)|0]=g;t=r;u=s}}while(0);b[4821364]=(b[4821364]|0)-1&65535;s=c[2410682]|0;r=s&65535;g=a[9642737]|0;q=c[u+(t*3160|0)+60+((s>>>8&255|256)<<2)>>2]|0;do{if((q|0)==0){o=c[u+(t*3160|0)+3136>>2]|0;if((o|0)==0){v=t;w=u;break}gg[o&4095](r,g);v=c[3528552]|0;w=c[2433426]|0}else{a[q+(s&255)|0]=g;v=t;w=u}}while(0);b[4821364]=(b[4821364]|0)-1&65535;u=c[2410682]|0;t=u&65535;g=a[9642732]|0;s=c[w+(v*3160|0)+60+((u>>>8&255|256)<<2)>>2]|0;do{if((s|0)==0){q=c[w+(v*3160|0)+3136>>2]|0;if((q|0)==0){x=v;y=w;break}gg[q&4095](t,g);x=c[3528552]|0;y=c[2433426]|0}else{a[s+(u&255)|0]=g;x=v;y=w}}while(0);b[4821364]=(b[4821364]|0)-1&65535;w=c[2410682]|0;v=w&65535;g=a[9642733]|0;u=c[y+(x*3160|0)+60+((w>>>8&255|256)<<2)>>2]|0;do{if((u|0)==0){s=c[y+(x*3160|0)+3136>>2]|0;if((s|0)==0){z=x;A=y;break}gg[s&4095](v,g);z=c[3528552]|0;A=c[2433426]|0}else{a[u+(w&255)|0]=g;z=x;A=y}}while(0);b[4821364]=(b[4821364]|0)-1&65535;y=c[2410682]|0;x=y&65535;g=a[9642721]|0;w=c[A+(z*3160|0)+60+((y>>>8&255|256)<<2)>>2]|0;do{if((w|0)==0){u=c[A+(z*3160|0)+3136>>2]|0;if((u|0)==0){break}gg[u&4095](x,g)}else{a[w+(y&255)|0]=g}}while(0);do{if((a[9642745]&1)!=0){b[4821364]=(b[4821364]|0)-1&65535;g=c[2410682]|0;y=g&65535;w=a[9642716]|0;x=c[3528552]|0;z=c[2433426]|0;A=c[z+(x*3160|0)+60+((g>>>8&255|256)<<2)>>2]|0;do{if((A|0)==0){u=c[z+(x*3160|0)+3136>>2]|0;if((u|0)==0){B=x;C=z;break}gg[u&4095](y,w);B=c[3528552]|0;C=c[2433426]|0}else{a[A+(g&255)|0]=w;B=x;C=z}}while(0);b[4821364]=(b[4821364]|0)-1&65535;z=c[2410682]|0;x=a[9642717]|0;w=c[C+(B*3160|0)+60+((z>>>8&255|256)<<2)>>2]|0;if((w|0)!=0){a[w+(z&255)|0]=x;break}w=c[C+(B*3160|0)+3136>>2]|0;if((w|0)==0){break}gg[w&4095](z&65535,x)}}while(0);b[4821364]=(b[4821364]|0)-1&65535;B=c[2410682]|0;C=B&65535;x=a[9642712]|0;z=c[3528552]|0;w=c[2433426]|0;g=c[w+(z*3160|0)+60+((B>>>8&255|256)<<2)>>2]|0;do{if((g|0)==0){A=c[w+(z*3160|0)+3136>>2]|0;if((A|0)==0){D=z;E=w;break}gg[A&4095](C,x);D=c[3528552]|0;E=c[2433426]|0}else{a[g+(B&255)|0]=x;D=z;E=w}}while(0);b[4821364]=(b[4821364]|0)-1&65535;w=c[2410682]|0;z=w&65535;x=a[9642713]|0;B=c[E+(D*3160|0)+60+((w>>>8&255|256)<<2)>>2]|0;do{if((B|0)==0){g=c[E+(D*3160|0)+3136>>2]|0;if((g|0)==0){F=D;G=E;break}gg[g&4095](z,x);F=c[3528552]|0;G=c[2433426]|0}else{a[B+(w&255)|0]=x;F=D;G=E}}while(0);b[4821364]=(b[4821364]|0)-1&65535;E=c[2410682]|0;D=E&65535;x=a[9642744]|0;w=c[G+(F*3160|0)+60+((E>>>8&255|256)<<2)>>2]|0;do{if((w|0)==0){B=c[G+(F*3160|0)+3136>>2]|0;if((B|0)==0){H=F;I=G;break}gg[B&4095](D,x);H=c[3528552]|0;I=c[2433426]|0}else{a[w+(E&255)|0]=x;H=F;I=G}}while(0);G=c[I+(H*3160|0)+1080>>2]|0;do{if((G|0)==0){F=c[I+(H*3160|0)+3132>>2]|0;if((F|0)==0){J=0;K=0;L=J&255;M=L|K;c[2410676]=M;N=M&65535;b[4821352]=N;return}x=gj[F&4095](-14)|0;F=c[3528552]|0;E=c[2433426]|0;w=c[E+(F*3160|0)+1080>>2]|0;D=(x&255)<<8;if((w|0)!=0){O=w;P=D;break}w=c[E+(F*3160|0)+3132>>2]|0;if((w|0)==0){J=0;K=D;L=J&255;M=L|K;c[2410676]=M;N=M&65535;b[4821352]=N;return}J=gj[w&4095](-13)|0;K=D;L=J&255;M=L|K;c[2410676]=M;N=M&65535;b[4821352]=N;return}else{O=G;P=(d[G+242|0]|0)<<8}}while(0);J=a[O+243|0]|0;K=P;L=J&255;M=L|K;c[2410676]=M;N=M&65535;b[4821352]=N;return}function fG4(){var b=0,c=0,d=0;b=a[9642717]|0;c=~b;a[9642717]=c;d=(c&255)>>>4&8|a[9642744]&-15;a[9642744]=(b<<24>>24==-1?d|4:d)|1;return}function fG5(){var b=0;b=(a[9642717]|0)-1&255;a[9642717]=b;a[9642744]=a[669184+(b&255)|0]|a[9642744]&-15;return}function fG6(){var b=0;b=(a[9642717]|0)+1&255;a[9642717]=b;a[9642744]=a[668928+(b&255)|0]|a[9642744]&-15;return}function fG7(){var b=0,c=0;b=a[9642717]|0;c=(b&255)>>>4&8|a[9642744]&-15;a[9642744]=b<<24>>24==0?c|4:c;return}function fG8(){a[9642717]=0;a[9642744]=a[9642744]&-16|4;return}function fG9(){var b=0,c=0,d=0;b=a[9642716]|0;c=~b;a[9642716]=c;d=(c&255)>>>4&8|a[9642744]&-15;a[9642744]=(b<<24>>24==-1?d|4:d)|1;return}function fHa(){var b=0;b=(a[9642716]|0)-1&255;a[9642716]=b;a[9642744]=a[669184+(b&255)|0]|a[9642744]&-15;return}function fHb(){var b=0;b=(a[9642716]|0)+1&255;a[9642716]=b;a[9642744]=a[668928+(b&255)|0]|a[9642744]&-15;return}function fHc(){var b=0,c=0;b=a[9642716]|0;c=(b&255)>>>4&8|a[9642744]&-15;a[9642744]=b<<24>>24==0?c|4:c;return}function fHd(){a[9642716]=0;a[9642744]=a[9642744]&-16|4;return}function fHe(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;break}l=gj[i&4095](e)|0;j=l;k=b[4821352]|0}else{j=a[h+(d&255)|0]|0;k=e}}while(0);b[4821352]=k+1&65535;k=a[9642717]|0;e=(k&255)-(j&255)|0;d=(e>>>4&8|a[9642744]&-16&255)&255;h=e&255;a[9642744]=(((k^j)&255^e^e>>>1)>>>6&2|e>>>8&1|(h<<24>>24==0?d|4:d)&255)&255;a[9642717]=h;return}function fHf(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;break}l=gj[i&4095](e)|0;j=l;k=b[4821352]|0}else{j=a[h+(d&255)|0]|0;k=e}}while(0);b[4821352]=k+1&65535;k=a[9642717]|0;e=(k&255)-(j&255)|0;d=(e>>>4&8|a[9642744]&-16&255)&255;a[9642744]=(((k^j)&255^e^e>>>1)>>>6&2|e>>>8&1|((e&255)<<24>>24==0?d|4:d)&255)&255;return}function fHg(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=c[2410676]|0;f=d&65535;g=c[3528552]|0;h=c[2433426]|0;i=c[h+(g*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((i|0)==0){j=c[h+(g*3160|0)+3144>>2]|0;if((j|0)==0){k=0;l=d;m=g;n=h;o=f;break}p=gj[j&4095](f)|0;j=c[2410676]|0;k=p;l=j;m=c[3528552]|0;n=c[2433426]|0;o=j&65535}else{k=a[i+(d&255)|0]|0;l=d;m=g;n=h;o=f}}while(0);f=(k&255)<<8;k=l+1|0;l=k&65535;h=c[n+(m*3160|0)+60+((k>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){g=c[n+(m*3160|0)+3144>>2]|0;if((g|0)==0){q=0;r=o;break}d=gj[g&4095](l)|0;q=d;r=b[4821352]|0}else{q=a[h+(k&255)|0]|0;r=o}}while(0);b[4821352]=r+2&65535;r=e[4821362]|0;o=r-(q&255|f)|0;q=(o>>>12&8|a[9642744]&-16&255)&255;a[9642744]=((r^f^o^o>>>1)>>>14&2|o>>>16&1|((o&65535)<<16>>16==0?q|4:q)&255)&255;return}function fHh(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;break}l=gj[i&4095](e)|0;j=l;k=b[4821352]|0}else{j=a[h+(d&255)|0]|0;k=e}}while(0);a[9642717]=j;b[4821352]=k+1&65535;k=a[9642744]&-15|(j&255)>>>4&8;a[9642744]=j<<24>>24==0?k|4:k;return}function fHi(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;break}l=gj[i&4095](e)|0;j=l;k=b[4821352]|0}else{j=a[h+(d&255)|0]|0;k=e}}while(0);b[4821352]=k+1&65535;k=a[9642717]|0;e=(k&255)+(j&255)|0;d=(e>>>4&8|a[9642744]&-48&255)&255;h=e&255;f=(k^j)&255^e;a[9642744]=(f<<1&32|e>>>8&1|(f^e>>>1)>>>6&2|(h<<24>>24==0?d|4:d)&255)&255;a[9642717]=h;return}function fHj(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=c[2410676]|0;f=d&65535;g=c[3528552]|0;h=c[2433426]|0;i=c[h+(g*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((i|0)==0){j=c[h+(g*3160|0)+3144>>2]|0;if((j|0)==0){k=0;l=d;m=g;n=h;o=f;break}p=gj[j&4095](f)|0;j=c[2410676]|0;k=p;l=j;m=c[3528552]|0;n=c[2433426]|0;o=j&65535}else{k=a[i+(d&255)|0]|0;l=d;m=g;n=h;o=f}}while(0);f=(k&255)<<8;k=l+1|0;l=k&65535;h=c[n+(m*3160|0)+60+((k>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){g=c[n+(m*3160|0)+3144>>2]|0;if((g|0)==0){q=0;r=o;break}d=gj[g&4095](l)|0;q=d;r=b[4821352]|0}else{q=a[h+(k&255)|0]|0;r=o}}while(0);b[4821352]=r+2&65535;r=e[4821364]|0;o=r-(q&255|f)|0;q=(o>>>12&8|a[9642744]&-16&255)&255;a[9642744]=((r^f^o^o>>>1)>>>14&2|o>>>16&1|((o&65535)<<16>>16==0?q|4:q)&255)&255;return}function fHk(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){b[4821352]=e+1&65535;break}else{j=gj[i&4095](e)|0;k=j;l=b[4821352]|0;m=11251;break}}else{k=a[h+(d&255)|0]|0;l=e;m=11251}}while(0);do{if((m|0)==11251){b[4821352]=l+1&65535;if(k<<24>>24==0){break}e=b[4821356]|0;d=e<<16>>16;h=k<<24>>24;f=(d|0)/(h|0)|0;a[9642713]=((d|0)%(h|0)|0)&255;h=f&255;a[9642712]=h;g=(h&255)>>>4&8|a[9642744]&-16;if(h<<24>>24==0){n=g|4}else{n=g|h&1}a[9642744]=n;if((b[4821356]|0)<0){h=n|8;a[9642744]=h;o=h}else{o=n}h=f<<16;if((h+8388608|0)>>>0<=16711680){return}f=o|2;a[9642744]=f;if((h+16777216|0)>>>0<=33488896){return}h=f&255|d>>>12&8;if(e<<16>>16==0){p=(h|4)&255}else{p=h&255}a[9642744]=p;b[4821356]=e<<16>>16>-1?e:-e&65535;return}}while(0);c[2439272]=(c[2439272]|0)-8;a[9642745]=a[9642745]|-128;fGQ();return}function fHl(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=(j&255)<<8;j=k+1|0;k=j&65535;g=c[m+(l*3160|0)+60+((j>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){f=c[m+(l*3160|0)+3144>>2]|0;if((f|0)==0){p=0;q=n;break}d=gj[f&4095](k)|0;p=d;q=b[4821352]|0}else{p=a[g+(j&255)|0]|0;q=n}}while(0);n=p&255|e;b[4821352]=q+2&65535;q=b[4821356]|0;e=b[4821358]|0;if(n<<16>>16==0){a[9642745]=a[9642745]|-128;fGQ();return}p=(q&65535)<<16|e&65535;j=n<<16>>16;n=(p|0)/(j|0)|0;b[4821356]=((p|0)%(j|0)|0)&65535;j=n&65535;b[4821358]=j;g=a[9642744]&-16;a[9642744]=g;k=g&255|n>>>12&8;if(j<<16>>16==0){r=(k|4)&255}else{r=k&255|n&1}a[9642744]=r;if((n+32767|0)>>>0<=65535){return}a[9642744]=r|2;if((n+65535|0)>>>0<=131071){return}do{if((p|0)<0){a[9642744]=r|10}else{if((p|0)!=0){break}a[9642744]=r|6}}while(0);b[4821356]=q;b[4821358]=e;return}function fHm(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=(j&255)<<8;j=k+1|0;k=j&65535;g=c[m+(l*3160|0)+60+((j>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){f=c[m+(l*3160|0)+3144>>2]|0;if((f|0)==0){p=0;q=n;break}d=gj[f&4095](k)|0;p=d;q=b[4821352]|0}else{p=a[g+(j&255)|0]|0;q=n}}while(0);b[4821352]=q+2&65535;q=ag(b[4821356]|0,(p&255|e)<<16>>16)|0;e=q>>>16&65535;b[4821356]=e;b[4821358]=q&65535;p=q>>>28&8|a[9642744]&-16&255;if(e<<16>>16!=0){r=p&255;a[9642744]=r;return}r=(p|4)&255;a[9642744]=r;return}function fHn(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c[2426872]=c[2410680];d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;l=f;m=g;break}n=gj[i&4095](e)|0;j=n;k=b[4821352]|0;l=c[3528552]|0;m=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=e;l=f;m=g}}while(0);a[9707488]=j;b[4821352]=k+1&65535;k=c[2426872]|0;j=k&65535;g=c[m+(l*3160|0)+60+((k>>>8&255)<<2)>>2]|0;do{if((g|0)==0){f=c[m+(l*3160|0)+3132>>2]|0;if((f|0)==0){o=0;break}o=gj[f&4095](j)|0}else{o=a[g+(k&255)|0]|0}}while(0);k=a[9642717]|0;g=(k&255)-(o&255)|0;j=(g>>>4&8|a[9642744]&-16&255)&255;l=g&255;a[9642744]=(((k^o)&255^g^g>>>1)>>>6&2|g>>>8&1|(l<<24>>24==0?j|4:j)&255)&255;a[9642717]=l;return}function fHo(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c[2426872]=c[2410680];d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;l=f;m=g;break}n=gj[i&4095](e)|0;j=n;k=b[4821352]|0;l=c[3528552]|0;m=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=e;l=f;m=g}}while(0);a[9707488]=j;b[4821352]=k+1&65535;k=c[2426872]|0;j=k&65535;g=c[m+(l*3160|0)+60+((k>>>8&255)<<2)>>2]|0;do{if((g|0)==0){f=c[m+(l*3160|0)+3132>>2]|0;if((f|0)==0){o=0;break}o=gj[f&4095](j)|0}else{o=a[g+(k&255)|0]|0}}while(0);k=a[9642717]|0;g=(k&255)-(o&255)|0;j=(g>>>4&8|a[9642744]&-16&255)&255;a[9642744]=(((k^o)&255^g^g>>>1)>>>6&2|g>>>8&1|((g&255)<<24>>24==0?j|4:j)&255)&255;return}function fHp(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;c[2426872]=c[2410680];d=c[2410676]|0;f=d&65535;g=c[3528552]|0;h=c[2433426]|0;i=c[h+(g*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((i|0)==0){j=c[h+(g*3160|0)+3144>>2]|0;if((j|0)==0){k=0;l=f;m=g;n=h;break}o=gj[j&4095](f)|0;k=o;l=b[4821352]|0;m=c[3528552]|0;n=c[2433426]|0}else{k=a[i+(d&255)|0]|0;l=f;m=g;n=h}}while(0);a[9707488]=k;b[4821352]=l+1&65535;l=c[2426872]|0;k=l&65535;h=c[n+(m*3160|0)+60+((l>>>8&255)<<2)>>2]|0;do{if((h|0)==0){g=c[n+(m*3160|0)+3132>>2]|0;if((g|0)==0){p=0;q=m;r=n;break}f=gj[g&4095](k)|0;p=f;q=c[3528552]|0;r=c[2433426]|0}else{p=a[h+(l&255)|0]|0;q=m;r=n}}while(0);n=(p&255)<<8;p=l+1|0;l=p&65535;m=c[r+(q*3160|0)+60+((p>>>8&255)<<2)>>2]|0;do{if((m|0)==0){h=c[r+(q*3160|0)+3132>>2]|0;if((h|0)==0){s=0;break}s=gj[h&4095](l)|0}else{s=a[m+(p&255)|0]|0}}while(0);p=e[4821362]|0;m=p-(s&255|n)|0;s=(m>>>12&8|a[9642744]&-16&255)&255;a[9642744]=((p^n^m^m>>>1)>>>14&2|m>>>16&1|((m&65535)<<16>>16==0?s|4:s)&255)&255;return}function fHq(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c[2426872]=c[2410680];d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;l=f;m=g;break}n=gj[i&4095](e)|0;j=n;k=b[4821352]|0;l=c[3528552]|0;m=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=e;l=f;m=g}}while(0);a[9707488]=j;b[4821352]=k+1&65535;k=c[2426872]|0;j=k&65535;g=c[m+(l*3160|0)+60+((k>>>8&255)<<2)>>2]|0;do{if((g|0)==0){f=c[m+(l*3160|0)+3132>>2]|0;if((f|0)==0){o=0;break}o=gj[f&4095](j)|0}else{o=a[g+(k&255)|0]|0}}while(0);a[9642717]=o;k=(o&255)>>>4&8|a[9642744]&-15;a[9642744]=o<<24>>24==0?k|4:k;return}function fHr(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=a[9642717]|0;e=(d&255)>>>4&8|a[9642744]&-15;a[9642744]=d<<24>>24==0?e|4:e;c[2426872]=c[2410680];e=c[2410676]|0;f=e&65535;g=c[3528552]|0;h=c[2433426]|0;i=c[h+(g*3160|0)+60+((e>>>8&255|512)<<2)>>2]|0;do{if((i|0)==0){j=c[h+(g*3160|0)+3144>>2]|0;if((j|0)==0){k=0;l=f;m=d;n=g;o=h;break}p=gj[j&4095](f)|0;k=p;l=b[4821352]|0;m=a[9642717]|0;n=c[3528552]|0;o=c[2433426]|0}else{k=a[i+(e&255)|0]|0;l=f;m=d;n=g;o=h}}while(0);a[9707488]=k;b[4821352]=l+1&65535;l=c[2426872]|0;k=c[o+(n*3160|0)+60+((l>>>8&255|256)<<2)>>2]|0;if((k|0)!=0){a[k+(l&255)|0]=m;return}k=c[o+(n*3160|0)+3136>>2]|0;if((k|0)==0){return}gg[k&4095](l&65535,m);return}function fHs(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c[2426872]=c[2410680];d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;l=f;m=g;break}n=gj[i&4095](e)|0;j=n;k=b[4821352]|0;l=c[3528552]|0;m=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=e;l=f;m=g}}while(0);a[9707488]=j;b[4821352]=k+1&65535;k=c[2426872]|0;j=k&65535;g=c[m+(l*3160|0)+60+((k>>>8&255)<<2)>>2]|0;do{if((g|0)==0){f=c[m+(l*3160|0)+3132>>2]|0;if((f|0)==0){o=0;break}o=gj[f&4095](j)|0}else{o=a[g+(k&255)|0]|0}}while(0);k=a[9642717]|0;g=(k&255)+(o&255)|0;j=(g>>>4&8|a[9642744]&-48&255)&255;l=g&255;m=(k^o)&255^g;a[9642744]=(m<<1&32|g>>>8&1|(m^g>>>1)>>>6&2|(l<<24>>24==0?j|4:j)&255)&255;a[9642717]=l;return}function fHt(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;c[2426872]=c[2410680];d=c[2410676]|0;f=d&65535;g=c[3528552]|0;h=c[2433426]|0;i=c[h+(g*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((i|0)==0){j=c[h+(g*3160|0)+3144>>2]|0;if((j|0)==0){k=0;l=f;m=g;n=h;break}o=gj[j&4095](f)|0;k=o;l=b[4821352]|0;m=c[3528552]|0;n=c[2433426]|0}else{k=a[i+(d&255)|0]|0;l=f;m=g;n=h}}while(0);a[9707488]=k;b[4821352]=l+1&65535;l=c[2426872]|0;k=l&65535;h=c[n+(m*3160|0)+60+((l>>>8&255)<<2)>>2]|0;do{if((h|0)==0){g=c[n+(m*3160|0)+3132>>2]|0;if((g|0)==0){p=0;q=m;r=n;break}f=gj[g&4095](k)|0;p=f;q=c[3528552]|0;r=c[2433426]|0}else{p=a[h+(l&255)|0]|0;q=m;r=n}}while(0);n=(p&255)<<8;p=l+1|0;l=p&65535;m=c[r+(q*3160|0)+60+((p>>>8&255)<<2)>>2]|0;do{if((m|0)==0){h=c[r+(q*3160|0)+3132>>2]|0;if((h|0)==0){s=0;break}s=gj[h&4095](l)|0}else{s=a[m+(p&255)|0]|0}}while(0);p=e[4821364]|0;m=p-(s&255|n)|0;s=(m>>>12&8|a[9642744]&-16&255)&255;a[9642744]=((p^n^m^m>>>1)>>>14&2|m>>>16&1|((m&65535)<<16>>16==0?s|4:s)&255)&255;return}function fHu(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;c[2426872]=c[2410680];d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;l=f;m=g;break}n=gj[i&4095](e)|0;j=n;k=b[4821352]|0;l=c[3528552]|0;m=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=e;l=f;m=g}}while(0);a[9707488]=j;b[4821352]=k+1&65535;k=c[2426872]|0;j=k&65535;g=c[m+(l*3160|0)+60+((k>>>8&255)<<2)>>2]|0;do{if((g|0)==0){f=c[m+(l*3160|0)+3132>>2]|0;if((f|0)==0){break}o=gj[f&4095](j)|0;p=11388}else{o=a[g+(k&255)|0]|0;p=11388}}while(0);do{if((p|0)==11388){if(o<<24>>24==0){break}k=b[4821356]|0;g=k<<16>>16;j=o<<24>>24;l=(g|0)/(j|0)|0;a[9642713]=((g|0)%(j|0)|0)&255;j=l&255;a[9642712]=j;m=(j&255)>>>4&8|a[9642744]&-16;if(j<<24>>24==0){q=m|4}else{q=m|j&1}a[9642744]=q;if((b[4821356]|0)<0){j=q|8;a[9642744]=j;r=j}else{r=q}j=l<<16;if((j+8388608|0)>>>0<=16711680){return}l=r|2;a[9642744]=l;if((j+16777216|0)>>>0<=33488896){return}j=l&255|g>>>12&8;if(k<<16>>16==0){s=(j|4)&255}else{s=j&255}a[9642744]=s;b[4821356]=k<<16>>16>-1?k:-k&65535;return}}while(0);c[2439272]=(c[2439272]|0)-8;a[9642745]=a[9642745]|-128;fGQ();return}function fHv(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;c[2426872]=c[2410680];d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;l=f;m=g;break}n=gj[i&4095](e)|0;j=n;k=b[4821352]|0;l=c[3528552]|0;m=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=e;l=f;m=g}}while(0);a[9707488]=j;b[4821352]=k+1&65535;k=c[2426872]|0;j=k&65535;g=c[m+(l*3160|0)+60+((k>>>8&255)<<2)>>2]|0;do{if((g|0)==0){f=c[m+(l*3160|0)+3132>>2]|0;if((f|0)==0){o=0;p=l;q=m;break}e=gj[f&4095](j)|0;o=e;p=c[3528552]|0;q=c[2433426]|0}else{o=a[g+(k&255)|0]|0;p=l;q=m}}while(0);m=(o&255)<<8;o=k+1|0;k=o&65535;l=c[q+(p*3160|0)+60+((o>>>8&255)<<2)>>2]|0;do{if((l|0)==0){g=c[q+(p*3160|0)+3132>>2]|0;if((g|0)==0){r=0;break}r=gj[g&4095](k)|0}else{r=a[l+(o&255)|0]|0}}while(0);o=r&255|m;m=b[4821356]|0;r=b[4821358]|0;if((o|0)==0){a[9642745]=a[9642745]|-128;fGQ();return}l=(m&65535)<<16|r&65535;k=o<<16>>16;o=(l|0)/(k|0)|0;b[4821356]=((l|0)%(k|0)|0)&65535;k=o&65535;b[4821358]=k;p=a[9642744]&-16;a[9642744]=p;q=p&255|o>>>12&8;if(k<<16>>16==0){s=(q|4)&255}else{s=q&255|o&1}a[9642744]=s;if((o+32768|0)>>>0<=65535){return}a[9642744]=s|2;if((o+65536|0)>>>0<=131071){return}do{if((l|0)<0){a[9642744]=s|10}else{if((l|0)!=0){break}a[9642744]=s|6}}while(0);b[4821356]=m;b[4821358]=r;return}function fHw(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;c[2426872]=c[2410680];d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;l=f;m=g;break}n=gj[i&4095](e)|0;j=n;k=b[4821352]|0;l=c[3528552]|0;m=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=e;l=f;m=g}}while(0);a[9707488]=j;b[4821352]=k+1&65535;k=c[2426872]|0;j=k&65535;g=c[m+(l*3160|0)+60+((k>>>8&255)<<2)>>2]|0;do{if((g|0)==0){f=c[m+(l*3160|0)+3132>>2]|0;if((f|0)==0){o=0;p=l;q=m;break}e=gj[f&4095](j)|0;o=e;p=c[3528552]|0;q=c[2433426]|0}else{o=a[g+(k&255)|0]|0;p=l;q=m}}while(0);m=(o&255)<<8;o=k+1|0;k=o&65535;l=c[q+(p*3160|0)+60+((o>>>8&255)<<2)>>2]|0;do{if((l|0)==0){g=c[q+(p*3160|0)+3132>>2]|0;if((g|0)==0){r=0;break}r=gj[g&4095](k)|0}else{r=a[l+(o&255)|0]|0}}while(0);o=ag((r&255|m)<<16>>16,b[4821356]|0)|0;m=o>>>16&65535;b[4821356]=m;b[4821358]=o&65535;r=o>>>28&8|a[9642744]&-16&255;if(m<<16>>16!=0){s=r&255;a[9642744]=s;return}s=(r|4)&255;a[9642744]=s;return}function fHx(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;fGP();b=c[2426872]|0;d=b&65535;e=c[3528552]|0;f=c[2433426]|0;g=c[f+(e*3160|0)+60+((b>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[f+(e*3160|0)+3132>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(b&255)|0]|0}}while(0);b=a[9642717]|0;g=(b&255)-(i&255)|0;d=(g>>>4&8|a[9642744]&-16&255)&255;e=g&255;a[9642744]=(((b^i)&255^g^g>>>1)>>>6&2|g>>>8&1|(e<<24>>24==0?d|4:d)&255)&255;a[9642717]=e;return}function fHy(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;fGP();b=c[2426872]|0;d=b&65535;e=c[3528552]|0;f=c[2433426]|0;g=c[f+(e*3160|0)+60+((b>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[f+(e*3160|0)+3132>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(b&255)|0]|0}}while(0);b=a[9642717]|0;g=(b&255)-(i&255)|0;d=(g>>>4&8|a[9642744]&-16&255)&255;a[9642744]=(((b^i)&255^g^g>>>1)>>>6&2|g>>>8&1|((g&255)<<24>>24==0?d|4:d)&255)&255;return}function fHz(){var b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;fGP();b=c[2426872]|0;d=b&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((b>>>8&255)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3132>>2]|0;if((i|0)==0){j=0;k=f;l=g;break}m=gj[i&4095](d)|0;j=m;k=c[3528552]|0;l=c[2433426]|0}else{j=a[h+(b&255)|0]|0;k=f;l=g}}while(0);g=(j&255)<<8;j=b+1|0;b=j&65535;f=c[l+(k*3160|0)+60+((j>>>8&255)<<2)>>2]|0;do{if((f|0)==0){h=c[l+(k*3160|0)+3132>>2]|0;if((h|0)==0){n=0;break}n=gj[h&4095](b)|0}else{n=a[f+(j&255)|0]|0}}while(0);j=e[4821362]|0;f=j-(n&255|g)|0;n=(f>>>12&8|a[9642744]&-16&255)&255;a[9642744]=((j^g^f^f>>>1)>>>14&2|f>>>16&1|((f&65535)<<16>>16==0?n|4:n)&255)&255;return}function fHA(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;fGP();b=c[2426872]|0;d=b&65535;e=c[3528552]|0;f=c[2433426]|0;g=c[f+(e*3160|0)+60+((b>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[f+(e*3160|0)+3132>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(b&255)|0]|0}}while(0);a[9642717]=i;b=(i&255)>>>4&8|a[9642744]&-15;a[9642744]=i<<24>>24==0?b|4:b;return}function fHB(){var b=0,d=0,e=0,f=0,g=0;fGP();b=a[9642717]|0;d=(b&255)>>>4&8|a[9642744]&-15;a[9642744]=b<<24>>24==0?d|4:d;d=c[2426872]|0;e=c[3528552]|0;f=c[2433426]|0;g=c[f+(e*3160|0)+60+((d>>>8&255|256)<<2)>>2]|0;if((g|0)!=0){a[g+(d&255)|0]=b;return}g=c[f+(e*3160|0)+3136>>2]|0;if((g|0)==0){return}gg[g&4095](d&65535,b);return}function fHC(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;fGP();b=c[2426872]|0;d=b&65535;e=c[3528552]|0;f=c[2433426]|0;g=c[f+(e*3160|0)+60+((b>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[f+(e*3160|0)+3132>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(b&255)|0]|0}}while(0);b=a[9642717]|0;g=(b&255)+(i&255)|0;d=(g>>>4&8|a[9642744]&-48&255)&255;e=g&255;f=(b^i)&255^g;a[9642744]=(f<<1&32|g>>>8&1|(f^g>>>1)>>>6&2|(e<<24>>24==0?d|4:d)&255)&255;a[9642717]=e;return}function fHD(){var b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;fGP();b=c[2426872]|0;d=b&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((b>>>8&255)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3132>>2]|0;if((i|0)==0){j=0;k=f;l=g;break}m=gj[i&4095](d)|0;j=m;k=c[3528552]|0;l=c[2433426]|0}else{j=a[h+(b&255)|0]|0;k=f;l=g}}while(0);g=(j&255)<<8;j=b+1|0;b=j&65535;f=c[l+(k*3160|0)+60+((j>>>8&255)<<2)>>2]|0;do{if((f|0)==0){h=c[l+(k*3160|0)+3132>>2]|0;if((h|0)==0){n=0;break}n=gj[h&4095](b)|0}else{n=a[f+(j&255)|0]|0}}while(0);j=e[4821364]|0;f=j-(n&255|g)|0;n=(f>>>12&8|a[9642744]&-16&255)&255;a[9642744]=((j^g^f^f>>>1)>>>14&2|f>>>16&1|((f&65535)<<16>>16==0?n|4:n)&255)&255;return}function fHE(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;fGP();d=c[2426872]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3132>>2]|0;if((i|0)==0){break}j=gj[i&4095](e)|0;k=11501}else{j=a[h+(d&255)|0]|0;k=11501}}while(0);do{if((k|0)==11501){if(j<<24>>24==0){break}d=b[4821356]|0;h=d<<16>>16;e=j<<24>>24;f=(h|0)/(e|0)|0;a[9642713]=((h|0)%(e|0)|0)&255;e=f&255;a[9642712]=e;g=(e&255)>>>4&8|a[9642744]&-16;if(e<<24>>24==0){l=g|4}else{l=g|e&1}a[9642744]=l;if((b[4821356]|0)<0){e=l|8;a[9642744]=e;m=e}else{m=l}e=f<<16;if((e+8388608|0)>>>0<=16711680){return}f=m|2;a[9642744]=f;if((e+16777216|0)>>>0<=33488896){return}e=f&255|h>>>12&8;if(d<<16>>16==0){n=(e|4)&255}else{n=e&255}a[9642744]=n;b[4821356]=d<<16>>16>-1?d:-d&65535;return}}while(0);c[2439272]=(c[2439272]|0)-8;a[9642745]=a[9642745]|-128;fGQ();return}function fHF(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;fGP();d=c[2426872]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3132>>2]|0;if((i|0)==0){j=0;k=f;l=g;break}m=gj[i&4095](e)|0;j=m;k=c[3528552]|0;l=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=f;l=g}}while(0);g=(j&255)<<8;j=d+1|0;d=j&65535;f=c[l+(k*3160|0)+60+((j>>>8&255)<<2)>>2]|0;do{if((f|0)==0){h=c[l+(k*3160|0)+3132>>2]|0;if((h|0)==0){n=0;break}n=gj[h&4095](d)|0}else{n=a[f+(j&255)|0]|0}}while(0);j=n&255|g;g=b[4821356]|0;n=b[4821358]|0;if((j|0)==0){a[9642745]=a[9642745]|-128;fGQ();return}f=(g&65535)<<16|n&65535;d=j<<16>>16;j=(f|0)/(d|0)|0;b[4821356]=((f|0)%(d|0)|0)&65535;d=j&65535;b[4821358]=d;k=a[9642744]&-16;a[9642744]=k;l=k&255|j>>>12&8;if(d<<16>>16==0){o=(l|4)&255}else{o=l&255|j&1}a[9642744]=o;if((j+32768|0)>>>0<=65535){return}a[9642744]=o|2;if((j+65536|0)>>>0<=131071){return}do{if((f|0)<0){a[9642744]=o|10}else{if((f|0)!=0){break}a[9642744]=o|6}}while(0);b[4821356]=g;b[4821358]=n;return}function fHG(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;fGP();d=c[2426872]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3132>>2]|0;if((i|0)==0){j=0;k=f;l=g;break}m=gj[i&4095](e)|0;j=m;k=c[3528552]|0;l=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=f;l=g}}while(0);g=(j&255)<<8;j=d+1|0;d=j&65535;f=c[l+(k*3160|0)+60+((j>>>8&255)<<2)>>2]|0;do{if((f|0)==0){h=c[l+(k*3160|0)+3132>>2]|0;if((h|0)==0){n=0;break}n=gj[h&4095](d)|0}else{n=a[f+(j&255)|0]|0}}while(0);j=ag((n&255|g)<<16>>16,b[4821356]|0)|0;g=j>>>16&65535;b[4821356]=g;b[4821358]=j&65535;n=j>>>28&8|a[9642744]&-16&255;if(g<<16>>16!=0){o=n&255;a[9642744]=o;return}o=(n|4)&255;a[9642744]=o;return}function fHH(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=j&255;j=e<<8;g=k+1|0;k=g&65535;f=c[m+(l*3160|0)+60+((g>>>8&255|512)<<2)>>2]|0;do{if((f|0)==0){d=c[m+(l*3160|0)+3144>>2]|0;if((d|0)==0){p=0;q=n;r=l;s=m;break}h=gj[d&4095](k)|0;p=h;q=b[4821352]|0;r=c[3528552]|0;s=c[2433426]|0}else{p=a[f+(g&255)|0]|0;q=n;r=l;s=m}}while(0);m=p&255;p=m|j;c[2426872]=p;b[4821352]=q+2&65535;q=p&65535;p=c[s+(r*3160|0)+60+(e<<2)>>2]|0;do{if((p|0)==0){e=c[s+(r*3160|0)+3132>>2]|0;if((e|0)==0){t=0;break}t=gj[e&4095](q)|0}else{t=a[p+m|0]|0}}while(0);m=a[9642717]|0;p=(m&255)-(t&255)|0;q=(p>>>4&8|a[9642744]&-16&255)&255;r=p&255;a[9642744]=(((m^t)&255^p^p>>>1)>>>6&2|p>>>8&1|(r<<24>>24==0?q|4:q)&255)&255;a[9642717]=r;return}function fHI(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=j&255;j=e<<8;g=k+1|0;k=g&65535;f=c[m+(l*3160|0)+60+((g>>>8&255|512)<<2)>>2]|0;do{if((f|0)==0){d=c[m+(l*3160|0)+3144>>2]|0;if((d|0)==0){p=0;q=n;r=l;s=m;break}h=gj[d&4095](k)|0;p=h;q=b[4821352]|0;r=c[3528552]|0;s=c[2433426]|0}else{p=a[f+(g&255)|0]|0;q=n;r=l;s=m}}while(0);m=p&255;p=m|j;c[2426872]=p;b[4821352]=q+2&65535;q=p&65535;p=c[s+(r*3160|0)+60+(e<<2)>>2]|0;do{if((p|0)==0){e=c[s+(r*3160|0)+3132>>2]|0;if((e|0)==0){t=0;break}t=gj[e&4095](q)|0}else{t=a[p+m|0]|0}}while(0);m=a[9642717]|0;p=(m&255)-(t&255)|0;q=(p>>>4&8|a[9642744]&-16&255)&255;a[9642744]=(((m^t)&255^p^p>>>1)>>>6&2|p>>>8&1|((p&255)<<24>>24==0?q|4:q)&255)&255;return}function fHJ(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=c[2410676]|0;f=d&65535;g=c[3528552]|0;h=c[2433426]|0;i=c[h+(g*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((i|0)==0){j=c[h+(g*3160|0)+3144>>2]|0;if((j|0)==0){k=0;l=d;m=g;n=h;o=f;break}p=gj[j&4095](f)|0;j=c[2410676]|0;k=p;l=j;m=c[3528552]|0;n=c[2433426]|0;o=j&65535}else{k=a[i+(d&255)|0]|0;l=d;m=g;n=h;o=f}}while(0);f=k&255;k=f<<8;h=l+1|0;l=h&65535;g=c[n+(m*3160|0)+60+((h>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){d=c[n+(m*3160|0)+3144>>2]|0;if((d|0)==0){q=0;r=o;s=m;t=n;break}i=gj[d&4095](l)|0;q=i;r=b[4821352]|0;s=c[3528552]|0;t=c[2433426]|0}else{q=a[g+(h&255)|0]|0;r=o;s=m;t=n}}while(0);n=q&255;q=n|k;c[2426872]=q;b[4821352]=r+2&65535;r=q&65535;k=c[t+(s*3160|0)+60+(f<<2)>>2]|0;do{if((k|0)==0){f=c[t+(s*3160|0)+3132>>2]|0;if((f|0)==0){u=0;v=s;w=t;break}m=gj[f&4095](r)|0;u=m;v=c[3528552]|0;w=c[2433426]|0}else{u=a[k+n|0]|0;v=s;w=t}}while(0);t=(u&255)<<8;u=q+1|0;q=u&65535;s=c[w+(v*3160|0)+60+((u>>>8&255)<<2)>>2]|0;do{if((s|0)==0){n=c[w+(v*3160|0)+3132>>2]|0;if((n|0)==0){x=0;break}x=gj[n&4095](q)|0}else{x=a[s+(u&255)|0]|0}}while(0);u=e[4821362]|0;s=u-(x&255|t)|0;x=(s>>>12&8|a[9642744]&-16&255)&255;a[9642744]=((u^t^s^s>>>1)>>>14&2|s>>>16&1|((s&65535)<<16>>16==0?x|4:x)&255)&255;return}function fHK(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=j&255;j=e<<8;g=k+1|0;k=g&65535;f=c[m+(l*3160|0)+60+((g>>>8&255|512)<<2)>>2]|0;do{if((f|0)==0){d=c[m+(l*3160|0)+3144>>2]|0;if((d|0)==0){p=0;q=n;r=l;s=m;break}h=gj[d&4095](k)|0;p=h;q=b[4821352]|0;r=c[3528552]|0;s=c[2433426]|0}else{p=a[f+(g&255)|0]|0;q=n;r=l;s=m}}while(0);m=p&255;p=m|j;c[2426872]=p;b[4821352]=q+2&65535;q=p&65535;p=c[s+(r*3160|0)+60+(e<<2)>>2]|0;do{if((p|0)==0){e=c[s+(r*3160|0)+3132>>2]|0;if((e|0)==0){t=0;break}t=gj[e&4095](q)|0}else{t=a[p+m|0]|0}}while(0);a[9642717]=t;m=(t&255)>>>4&8|a[9642744]&-15;a[9642744]=t<<24>>24==0?m|4:m;return}function fHL(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=a[9642717]|0;e=(d&255)>>>4&8|a[9642744]&-15;a[9642744]=d<<24>>24==0?e|4:e;e=c[2410676]|0;d=e&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((e>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;l=f;m=g;n=d;break}o=gj[i&4095](d)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(e&255)|0]|0;k=e;l=f;m=g;n=d}}while(0);d=j&255;j=d<<8;g=k+1|0;k=g&65535;f=c[m+(l*3160|0)+60+((g>>>8&255|512)<<2)>>2]|0;do{if((f|0)==0){e=c[m+(l*3160|0)+3144>>2]|0;if((e|0)==0){p=0;q=n;r=l;s=m;break}h=gj[e&4095](k)|0;p=h;q=b[4821352]|0;r=c[3528552]|0;s=c[2433426]|0}else{p=a[f+(g&255)|0]|0;q=n;r=l;s=m}}while(0);m=p&255;p=m|j;c[2426872]=p;b[4821352]=q+2&65535;q=a[9642717]|0;j=c[s+(r*3160|0)+60+((d|256)<<2)>>2]|0;if((j|0)!=0){a[j+m|0]=q;return}m=c[s+(r*3160|0)+3136>>2]|0;if((m|0)==0){return}gg[m&4095](p&65535,q);return}function fHM(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=j&255;j=e<<8;g=k+1|0;k=g&65535;f=c[m+(l*3160|0)+60+((g>>>8&255|512)<<2)>>2]|0;do{if((f|0)==0){d=c[m+(l*3160|0)+3144>>2]|0;if((d|0)==0){p=0;q=n;r=l;s=m;break}h=gj[d&4095](k)|0;p=h;q=b[4821352]|0;r=c[3528552]|0;s=c[2433426]|0}else{p=a[f+(g&255)|0]|0;q=n;r=l;s=m}}while(0);m=p&255;p=m|j;c[2426872]=p;b[4821352]=q+2&65535;q=p&65535;p=c[s+(r*3160|0)+60+(e<<2)>>2]|0;do{if((p|0)==0){e=c[s+(r*3160|0)+3132>>2]|0;if((e|0)==0){t=0;break}t=gj[e&4095](q)|0}else{t=a[p+m|0]|0}}while(0);m=a[9642717]|0;p=(m&255)+(t&255)|0;q=(p>>>4&8|a[9642744]&-48&255)&255;r=p&255;s=(m^t)&255^p;a[9642744]=(s<<1&32|p>>>8&1|(s^p>>>1)>>>6&2|(r<<24>>24==0?q|4:q)&255)&255;a[9642717]=r;return}function fHN(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=c[2410676]|0;f=d&65535;g=c[3528552]|0;h=c[2433426]|0;i=c[h+(g*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((i|0)==0){j=c[h+(g*3160|0)+3144>>2]|0;if((j|0)==0){k=0;l=d;m=g;n=h;o=f;break}p=gj[j&4095](f)|0;j=c[2410676]|0;k=p;l=j;m=c[3528552]|0;n=c[2433426]|0;o=j&65535}else{k=a[i+(d&255)|0]|0;l=d;m=g;n=h;o=f}}while(0);f=k&255;k=f<<8;h=l+1|0;l=h&65535;g=c[n+(m*3160|0)+60+((h>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){d=c[n+(m*3160|0)+3144>>2]|0;if((d|0)==0){q=0;r=o;s=m;t=n;break}i=gj[d&4095](l)|0;q=i;r=b[4821352]|0;s=c[3528552]|0;t=c[2433426]|0}else{q=a[g+(h&255)|0]|0;r=o;s=m;t=n}}while(0);n=q&255;q=n|k;c[2426872]=q;b[4821352]=r+2&65535;r=q&65535;k=c[t+(s*3160|0)+60+(f<<2)>>2]|0;do{if((k|0)==0){f=c[t+(s*3160|0)+3132>>2]|0;if((f|0)==0){u=0;v=s;w=t;break}m=gj[f&4095](r)|0;u=m;v=c[3528552]|0;w=c[2433426]|0}else{u=a[k+n|0]|0;v=s;w=t}}while(0);t=(u&255)<<8;u=q+1|0;q=u&65535;s=c[w+(v*3160|0)+60+((u>>>8&255)<<2)>>2]|0;do{if((s|0)==0){n=c[w+(v*3160|0)+3132>>2]|0;if((n|0)==0){x=0;break}x=gj[n&4095](q)|0}else{x=a[s+(u&255)|0]|0}}while(0);u=e[4821364]|0;s=u-(x&255|t)|0;x=(s>>>12&8|a[9642744]&-16&255)&255;a[9642744]=((u^t^s^s>>>1)>>>14&2|s>>>16&1|((s&65535)<<16>>16==0?x|4:x)&255)&255;return}function fHO(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=j&255;j=e<<8;g=k+1|0;k=g&65535;f=c[m+(l*3160|0)+60+((g>>>8&255|512)<<2)>>2]|0;do{if((f|0)==0){d=c[m+(l*3160|0)+3144>>2]|0;if((d|0)==0){p=0;q=n;r=l;s=m;break}h=gj[d&4095](k)|0;p=h;q=b[4821352]|0;r=c[3528552]|0;s=c[2433426]|0}else{p=a[f+(g&255)|0]|0;q=n;r=l;s=m}}while(0);m=p&255;p=m|j;c[2426872]=p;b[4821352]=q+2&65535;q=p&65535;p=c[s+(r*3160|0)+60+(e<<2)>>2]|0;do{if((p|0)==0){e=c[s+(r*3160|0)+3132>>2]|0;if((e|0)==0){break}t=gj[e&4095](q)|0;u=11670}else{t=a[p+m|0]|0;u=11670}}while(0);do{if((u|0)==11670){if(t<<24>>24==0){break}m=b[4821356]|0;p=m<<16>>16;q=t<<24>>24;r=(p|0)/(q|0)|0;a[9642713]=((p|0)%(q|0)|0)&255;q=r&255;a[9642712]=q;s=(q&255)>>>4&8|a[9642744]&-16;if(q<<24>>24==0){v=s|4}else{v=s|q&1}a[9642744]=v;if((b[4821356]|0)<0){q=v|8;a[9642744]=q;w=q}else{w=v}q=r<<16;if((q+8388608|0)>>>0<=16711680){return}r=w|2;a[9642744]=r;if((q+16777216|0)>>>0<=33488896){return}q=r&255|p>>>12&8;if(m<<16>>16==0){x=(q|4)&255}else{x=q&255}a[9642744]=x;b[4821356]=m<<16>>16>-1?m:-m&65535;return}}while(0);c[2439272]=(c[2439272]|0)-8;a[9642745]=a[9642745]|-128;fGQ();return}function fHP(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=j&255;j=e<<8;g=k+1|0;k=g&65535;f=c[m+(l*3160|0)+60+((g>>>8&255|512)<<2)>>2]|0;do{if((f|0)==0){d=c[m+(l*3160|0)+3144>>2]|0;if((d|0)==0){p=0;q=n;r=l;s=m;break}h=gj[d&4095](k)|0;p=h;q=b[4821352]|0;r=c[3528552]|0;s=c[2433426]|0}else{p=a[f+(g&255)|0]|0;q=n;r=l;s=m}}while(0);m=p&255;p=m|j;c[2426872]=p;b[4821352]=q+2&65535;q=p&65535;j=c[s+(r*3160|0)+60+(e<<2)>>2]|0;do{if((j|0)==0){e=c[s+(r*3160|0)+3132>>2]|0;if((e|0)==0){t=0;u=r;v=s;break}l=gj[e&4095](q)|0;t=l;u=c[3528552]|0;v=c[2433426]|0}else{t=a[j+m|0]|0;u=r;v=s}}while(0);s=(t&255)<<8;t=p+1|0;p=t&65535;r=c[v+(u*3160|0)+60+((t>>>8&255)<<2)>>2]|0;do{if((r|0)==0){m=c[v+(u*3160|0)+3132>>2]|0;if((m|0)==0){w=0;break}w=gj[m&4095](p)|0}else{w=a[r+(t&255)|0]|0}}while(0);t=w&255|s;s=b[4821356]|0;w=b[4821358]|0;if((t|0)==0){a[9642745]=a[9642745]|-128;fGQ();return}r=(s&65535)<<16|w&65535;p=t<<16>>16;t=(r|0)/(p|0)|0;b[4821356]=((r|0)%(p|0)|0)&65535;p=t&65535;b[4821358]=p;u=a[9642744]&-16;a[9642744]=u;v=u&255|t>>>12&8;if(p<<16>>16==0){x=(v|4)&255}else{x=v&255|t&1}a[9642744]=x;if((t+32768|0)>>>0<=65535){return}a[9642744]=x|2;if((t+65536|0)>>>0<=131071){return}do{if((r|0)<0){a[9642744]=x|10}else{if((r|0)!=0){break}a[9642744]=x|6}}while(0);b[4821356]=s;b[4821358]=w;return}function fHQ(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=j&255;j=e<<8;g=k+1|0;k=g&65535;f=c[m+(l*3160|0)+60+((g>>>8&255|512)<<2)>>2]|0;do{if((f|0)==0){d=c[m+(l*3160|0)+3144>>2]|0;if((d|0)==0){p=0;q=n;r=l;s=m;break}h=gj[d&4095](k)|0;p=h;q=b[4821352]|0;r=c[3528552]|0;s=c[2433426]|0}else{p=a[f+(g&255)|0]|0;q=n;r=l;s=m}}while(0);m=p&255;p=m|j;c[2426872]=p;b[4821352]=q+2&65535;q=p&65535;j=c[s+(r*3160|0)+60+(e<<2)>>2]|0;do{if((j|0)==0){e=c[s+(r*3160|0)+3132>>2]|0;if((e|0)==0){t=0;u=r;v=s;break}l=gj[e&4095](q)|0;t=l;u=c[3528552]|0;v=c[2433426]|0}else{t=a[j+m|0]|0;u=r;v=s}}while(0);s=(t&255)<<8;t=p+1|0;p=t&65535;r=c[v+(u*3160|0)+60+((t>>>8&255)<<2)>>2]|0;do{if((r|0)==0){m=c[v+(u*3160|0)+3132>>2]|0;if((m|0)==0){w=0;break}w=gj[m&4095](p)|0}else{w=a[r+(t&255)|0]|0}}while(0);t=ag((w&255|s)<<16>>16,b[4821356]|0)|0;s=t>>>16&65535;b[4821356]=s;b[4821358]=t&65535;w=t>>>28&8|a[9642744]&-16&255;if(s<<16>>16!=0){x=w&255;a[9642744]=x;return}x=(w|4)&255;a[9642744]=x;return}function fHR(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;break}l=gj[i&4095](e)|0;j=l;k=b[4821352]|0}else{j=a[h+(d&255)|0]|0;k=e}}while(0);b[4821352]=k+1&65535;k=a[9642716]|0;e=(k&255)-(j&255)|0;d=(e>>>4&8|a[9642744]&-16&255)&255;h=e&255;a[9642744]=(((k^j)&255^e^e>>>1)>>>6&2|e>>>8&1|(h<<24>>24==0?d|4:d)&255)&255;a[9642716]=h;return}function fHS(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;break}l=gj[i&4095](e)|0;j=l;k=b[4821352]|0}else{j=a[h+(d&255)|0]|0;k=e}}while(0);b[4821352]=k+1&65535;k=a[9642716]|0;e=(k&255)-(j&255)|0;d=(e>>>4&8|a[9642744]&-16&255)&255;a[9642744]=(((k^j)&255^e^e>>>1)>>>6&2|e>>>8&1|((e&255)<<24>>24==0?d|4:d)&255)&255;return}function fHT(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;break}l=gj[i&4095](e)|0;j=l;k=b[4821352]|0}else{j=a[h+(d&255)|0]|0;k=e}}while(0);a[9642716]=j;b[4821352]=k+1&65535;k=a[9642744]&-15|(j&255)>>>4&8;a[9642744]=j<<24>>24==0?k|4:k;return}function fHU(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;break}l=gj[i&4095](e)|0;j=l;k=b[4821352]|0}else{j=a[h+(d&255)|0]|0;k=e}}while(0);b[4821352]=k+1&65535;k=a[9642716]|0;e=(k&255)+(j&255)|0;d=(e>>>4&8|a[9642744]&-48&255)&255;h=e&255;f=(k^j)&255^e;a[9642744]=(f<<1&32|e>>>8&1|(f^e>>>1)>>>6&2|(h<<24>>24==0?d|4:d)&255)&255;a[9642716]=h;return}function fHV(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c[2426872]=c[2410680];d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;l=f;m=g;break}n=gj[i&4095](e)|0;j=n;k=b[4821352]|0;l=c[3528552]|0;m=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=e;l=f;m=g}}while(0);a[9707488]=j;b[4821352]=k+1&65535;k=c[2426872]|0;j=k&65535;g=c[m+(l*3160|0)+60+((k>>>8&255)<<2)>>2]|0;do{if((g|0)==0){f=c[m+(l*3160|0)+3132>>2]|0;if((f|0)==0){o=0;break}o=gj[f&4095](j)|0}else{o=a[g+(k&255)|0]|0}}while(0);k=a[9642716]|0;g=(k&255)-(o&255)|0;j=(g>>>4&8|a[9642744]&-16&255)&255;l=g&255;a[9642744]=(((k^o)&255^g^g>>>1)>>>6&2|g>>>8&1|(l<<24>>24==0?j|4:j)&255)&255;a[9642716]=l;return}function fHW(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c[2426872]=c[2410680];d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;l=f;m=g;break}n=gj[i&4095](e)|0;j=n;k=b[4821352]|0;l=c[3528552]|0;m=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=e;l=f;m=g}}while(0);a[9707488]=j;b[4821352]=k+1&65535;k=c[2426872]|0;j=k&65535;g=c[m+(l*3160|0)+60+((k>>>8&255)<<2)>>2]|0;do{if((g|0)==0){f=c[m+(l*3160|0)+3132>>2]|0;if((f|0)==0){o=0;break}o=gj[f&4095](j)|0}else{o=a[g+(k&255)|0]|0}}while(0);k=a[9642716]|0;g=(k&255)-(o&255)|0;j=(g>>>4&8|a[9642744]&-16&255)&255;a[9642744]=(((k^o)&255^g^g>>>1)>>>6&2|g>>>8&1|((g&255)<<24>>24==0?j|4:j)&255)&255;return}function fHX(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c[2426872]=c[2410680];d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;l=f;m=g;break}n=gj[i&4095](e)|0;j=n;k=b[4821352]|0;l=c[3528552]|0;m=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=e;l=f;m=g}}while(0);a[9707488]=j;b[4821352]=k+1&65535;k=c[2426872]|0;j=k&65535;g=c[m+(l*3160|0)+60+((k>>>8&255)<<2)>>2]|0;do{if((g|0)==0){f=c[m+(l*3160|0)+3132>>2]|0;if((f|0)==0){o=0;break}o=gj[f&4095](j)|0}else{o=a[g+(k&255)|0]|0}}while(0);a[9642716]=o;k=(o&255)>>>4&8|a[9642744]&-15;a[9642744]=o<<24>>24==0?k|4:k;return}function fHY(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=a[9642716]|0;e=(d&255)>>>4&8|a[9642744]&-15;a[9642744]=d<<24>>24==0?e|4:e;c[2426872]=c[2410680];e=c[2410676]|0;f=e&65535;g=c[3528552]|0;h=c[2433426]|0;i=c[h+(g*3160|0)+60+((e>>>8&255|512)<<2)>>2]|0;do{if((i|0)==0){j=c[h+(g*3160|0)+3144>>2]|0;if((j|0)==0){k=0;l=f;m=d;n=g;o=h;break}p=gj[j&4095](f)|0;k=p;l=b[4821352]|0;m=a[9642716]|0;n=c[3528552]|0;o=c[2433426]|0}else{k=a[i+(e&255)|0]|0;l=f;m=d;n=g;o=h}}while(0);a[9707488]=k;b[4821352]=l+1&65535;l=c[2426872]|0;k=c[o+(n*3160|0)+60+((l>>>8&255|256)<<2)>>2]|0;if((k|0)!=0){a[k+(l&255)|0]=m;return}k=c[o+(n*3160|0)+3136>>2]|0;if((k|0)==0){return}gg[k&4095](l&65535,m);return}function fHZ(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c[2426872]=c[2410680];d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;l=f;m=g;break}n=gj[i&4095](e)|0;j=n;k=b[4821352]|0;l=c[3528552]|0;m=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=e;l=f;m=g}}while(0);a[9707488]=j;b[4821352]=k+1&65535;k=c[2426872]|0;j=k&65535;g=c[m+(l*3160|0)+60+((k>>>8&255)<<2)>>2]|0;do{if((g|0)==0){f=c[m+(l*3160|0)+3132>>2]|0;if((f|0)==0){o=0;break}o=gj[f&4095](j)|0}else{o=a[g+(k&255)|0]|0}}while(0);k=a[9642716]|0;g=(k&255)+(o&255)|0;j=(g>>>4&8|a[9642744]&-48&255)&255;l=g&255;m=(k^o)&255^g;a[9642744]=(m<<1&32|g>>>8&1|(m^g>>>1)>>>6&2|(l<<24>>24==0?j|4:j)&255)&255;a[9642716]=l;return}function fH_(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;fGP();b=c[2426872]|0;d=b&65535;e=c[3528552]|0;f=c[2433426]|0;g=c[f+(e*3160|0)+60+((b>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[f+(e*3160|0)+3132>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(b&255)|0]|0}}while(0);b=a[9642716]|0;g=(b&255)-(i&255)|0;d=(g>>>4&8|a[9642744]&-16&255)&255;e=g&255;a[9642744]=(((b^i)&255^g^g>>>1)>>>6&2|g>>>8&1|(e<<24>>24==0?d|4:d)&255)&255;a[9642716]=e;return}function fH$(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;fGP();b=c[2426872]|0;d=b&65535;e=c[3528552]|0;f=c[2433426]|0;g=c[f+(e*3160|0)+60+((b>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[f+(e*3160|0)+3132>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(b&255)|0]|0}}while(0);b=a[9642716]|0;g=(b&255)-(i&255)|0;d=(g>>>4&8|a[9642744]&-16&255)&255;a[9642744]=(((b^i)&255^g^g>>>1)>>>6&2|g>>>8&1|((g&255)<<24>>24==0?d|4:d)&255)&255;return}function fH0(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;fGP();b=c[2426872]|0;d=b&65535;e=c[3528552]|0;f=c[2433426]|0;g=c[f+(e*3160|0)+60+((b>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[f+(e*3160|0)+3132>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(b&255)|0]|0}}while(0);a[9642716]=i;b=(i&255)>>>4&8|a[9642744]&-15;a[9642744]=i<<24>>24==0?b|4:b;return}function fH1(){var b=0,d=0,e=0,f=0,g=0;fGP();b=a[9642716]|0;d=(b&255)>>>4&8|a[9642744]&-15;a[9642744]=b<<24>>24==0?d|4:d;d=c[2426872]|0;e=c[3528552]|0;f=c[2433426]|0;g=c[f+(e*3160|0)+60+((d>>>8&255|256)<<2)>>2]|0;if((g|0)!=0){a[g+(d&255)|0]=b;return}g=c[f+(e*3160|0)+3136>>2]|0;if((g|0)==0){return}gg[g&4095](d&65535,b);return}function fH2(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;fGP();b=c[2426872]|0;d=b&65535;e=c[3528552]|0;f=c[2433426]|0;g=c[f+(e*3160|0)+60+((b>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[f+(e*3160|0)+3132>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(b&255)|0]|0}}while(0);b=a[9642716]|0;g=(b&255)+(i&255)|0;d=(g>>>4&8|a[9642744]&-48&255)&255;e=g&255;f=(b^i)&255^g;a[9642744]=(f<<1&32|g>>>8&1|(f^g>>>1)>>>6&2|(e<<24>>24==0?d|4:d)&255)&255;a[9642716]=e;return}function fH3(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=j&255;j=e<<8;g=k+1|0;k=g&65535;f=c[m+(l*3160|0)+60+((g>>>8&255|512)<<2)>>2]|0;do{if((f|0)==0){d=c[m+(l*3160|0)+3144>>2]|0;if((d|0)==0){p=0;q=n;r=l;s=m;break}h=gj[d&4095](k)|0;p=h;q=b[4821352]|0;r=c[3528552]|0;s=c[2433426]|0}else{p=a[f+(g&255)|0]|0;q=n;r=l;s=m}}while(0);m=p&255;p=m|j;c[2426872]=p;b[4821352]=q+2&65535;q=p&65535;p=c[s+(r*3160|0)+60+(e<<2)>>2]|0;do{if((p|0)==0){e=c[s+(r*3160|0)+3132>>2]|0;if((e|0)==0){t=0;break}t=gj[e&4095](q)|0}else{t=a[p+m|0]|0}}while(0);m=a[9642716]|0;p=(m&255)-(t&255)|0;q=(p>>>4&8|a[9642744]&-16&255)&255;r=p&255;a[9642744]=(((m^t)&255^p^p>>>1)>>>6&2|p>>>8&1|(r<<24>>24==0?q|4:q)&255)&255;a[9642716]=r;return}function fH4(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=j&255;j=e<<8;g=k+1|0;k=g&65535;f=c[m+(l*3160|0)+60+((g>>>8&255|512)<<2)>>2]|0;do{if((f|0)==0){d=c[m+(l*3160|0)+3144>>2]|0;if((d|0)==0){p=0;q=n;r=l;s=m;break}h=gj[d&4095](k)|0;p=h;q=b[4821352]|0;r=c[3528552]|0;s=c[2433426]|0}else{p=a[f+(g&255)|0]|0;q=n;r=l;s=m}}while(0);m=p&255;p=m|j;c[2426872]=p;b[4821352]=q+2&65535;q=p&65535;p=c[s+(r*3160|0)+60+(e<<2)>>2]|0;do{if((p|0)==0){e=c[s+(r*3160|0)+3132>>2]|0;if((e|0)==0){t=0;break}t=gj[e&4095](q)|0}else{t=a[p+m|0]|0}}while(0);m=a[9642716]|0;p=(m&255)-(t&255)|0;q=(p>>>4&8|a[9642744]&-16&255)&255;a[9642744]=(((m^t)&255^p^p>>>1)>>>6&2|p>>>8&1|((p&255)<<24>>24==0?q|4:q)&255)&255;return}function fH5(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=j&255;j=e<<8;g=k+1|0;k=g&65535;f=c[m+(l*3160|0)+60+((g>>>8&255|512)<<2)>>2]|0;do{if((f|0)==0){d=c[m+(l*3160|0)+3144>>2]|0;if((d|0)==0){p=0;q=n;r=l;s=m;break}h=gj[d&4095](k)|0;p=h;q=b[4821352]|0;r=c[3528552]|0;s=c[2433426]|0}else{p=a[f+(g&255)|0]|0;q=n;r=l;s=m}}while(0);m=p&255;p=m|j;c[2426872]=p;b[4821352]=q+2&65535;q=p&65535;p=c[s+(r*3160|0)+60+(e<<2)>>2]|0;do{if((p|0)==0){e=c[s+(r*3160|0)+3132>>2]|0;if((e|0)==0){t=0;break}t=gj[e&4095](q)|0}else{t=a[p+m|0]|0}}while(0);a[9642716]=t;m=(t&255)>>>4&8|a[9642744]&-15;a[9642744]=t<<24>>24==0?m|4:m;return}function fH6(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=a[9642716]|0;e=(d&255)>>>4&8|a[9642744]&-15;a[9642744]=d<<24>>24==0?e|4:e;e=c[2410676]|0;d=e&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((e>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;l=f;m=g;n=d;break}o=gj[i&4095](d)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(e&255)|0]|0;k=e;l=f;m=g;n=d}}while(0);d=j&255;j=d<<8;g=k+1|0;k=g&65535;f=c[m+(l*3160|0)+60+((g>>>8&255|512)<<2)>>2]|0;do{if((f|0)==0){e=c[m+(l*3160|0)+3144>>2]|0;if((e|0)==0){p=0;q=n;r=l;s=m;break}h=gj[e&4095](k)|0;p=h;q=b[4821352]|0;r=c[3528552]|0;s=c[2433426]|0}else{p=a[f+(g&255)|0]|0;q=n;r=l;s=m}}while(0);m=p&255;p=m|j;c[2426872]=p;b[4821352]=q+2&65535;q=a[9642716]|0;j=c[s+(r*3160|0)+60+((d|256)<<2)>>2]|0;if((j|0)!=0){a[j+m|0]=q;return}m=c[s+(r*3160|0)+3136>>2]|0;if((m|0)==0){return}gg[m&4095](p&65535,q);return}function fH7(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=j&255;j=e<<8;g=k+1|0;k=g&65535;f=c[m+(l*3160|0)+60+((g>>>8&255|512)<<2)>>2]|0;do{if((f|0)==0){d=c[m+(l*3160|0)+3144>>2]|0;if((d|0)==0){p=0;q=n;r=l;s=m;break}h=gj[d&4095](k)|0;p=h;q=b[4821352]|0;r=c[3528552]|0;s=c[2433426]|0}else{p=a[f+(g&255)|0]|0;q=n;r=l;s=m}}while(0);m=p&255;p=m|j;c[2426872]=p;b[4821352]=q+2&65535;q=p&65535;p=c[s+(r*3160|0)+60+(e<<2)>>2]|0;do{if((p|0)==0){e=c[s+(r*3160|0)+3132>>2]|0;if((e|0)==0){t=0;break}t=gj[e&4095](q)|0}else{t=a[p+m|0]|0}}while(0);m=a[9642716]|0;p=(m&255)+(t&255)|0;q=(p>>>4&8|a[9642744]&-48&255)&255;r=p&255;s=(m^t)&255^p;a[9642744]=(s<<1&32|p>>>8&1|(s^p>>>1)>>>6&2|(r<<24>>24==0?q|4:q)&255)&255;a[9642716]=r;return}function fH8(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=(j&255)<<8;j=k+1|0;k=j&65535;g=c[m+(l*3160|0)+60+((j>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){f=c[m+(l*3160|0)+3144>>2]|0;if((f|0)==0){p=0;q=n;break}d=gj[f&4095](k)|0;p=d;q=b[4821352]|0}else{p=a[g+(j&255)|0]|0;q=n}}while(0);c[2426872]=p&255|e;b[4821352]=q+2&65535;return}function fH9(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=(j&255)<<8;j=k+1|0;k=j&65535;g=c[m+(l*3160|0)+60+((j>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){f=c[m+(l*3160|0)+3144>>2]|0;if((f|0)==0){p=0;q=n;break}d=gj[f&4095](k)|0;p=d;q=b[4821352]|0}else{p=a[g+(j&255)|0]|0;q=n}}while(0);n=q+2&65535;b[4821352]=n;if((a[9642744]&5)!=0){return}if((a[9642745]&1)==0){c[2439272]=(c[2439272]|0)-1}b[4821352]=n+(p&255|e)&65535;b[4821352]=c[2410676]&65535;return}function fIa(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=(j&255)<<8;j=k+1|0;k=j&65535;g=c[m+(l*3160|0)+60+((j>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){f=c[m+(l*3160|0)+3144>>2]|0;if((f|0)==0){p=0;q=n;break}d=gj[f&4095](k)|0;p=d;q=b[4821352]|0}else{p=a[g+(j&255)|0]|0;q=n}}while(0);n=q+2&65535;b[4821352]=n;if((a[9642744]&5)==0){return}if((a[9642745]&1)==0){c[2439272]=(c[2439272]|0)-1}b[4821352]=n+(p&255|e)&65535;b[4821352]=c[2410676]&65535;return}function fIb(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=(j&255)<<8;j=k+1|0;k=j&65535;g=c[m+(l*3160|0)+60+((j>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){f=c[m+(l*3160|0)+3144>>2]|0;if((f|0)==0){p=0;q=n;break}d=gj[f&4095](k)|0;p=d;q=b[4821352]|0}else{p=a[g+(j&255)|0]|0;q=n}}while(0);n=q+2&65535;b[4821352]=n;if((a[9642744]&1)!=0){return}if((a[9642745]&1)==0){c[2439272]=(c[2439272]|0)-1}b[4821352]=n+(p&255|e)&65535;b[4821352]=c[2410676]&65535;return}function fIc(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=(j&255)<<8;j=k+1|0;k=j&65535;g=c[m+(l*3160|0)+60+((j>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){f=c[m+(l*3160|0)+3144>>2]|0;if((f|0)==0){p=0;q=n;break}d=gj[f&4095](k)|0;p=d;q=b[4821352]|0}else{p=a[g+(j&255)|0]|0;q=n}}while(0);n=q+2&65535;b[4821352]=n;if((a[9642744]&1)==0){return}if((a[9642745]&1)==0){c[2439272]=(c[2439272]|0)-1}b[4821352]=n+(p&255|e)&65535;b[4821352]=c[2410676]&65535;return}function fId(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=(j&255)<<8;j=k+1|0;k=j&65535;g=c[m+(l*3160|0)+60+((j>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){f=c[m+(l*3160|0)+3144>>2]|0;if((f|0)==0){p=0;q=n;break}d=gj[f&4095](k)|0;p=d;q=b[4821352]|0}else{p=a[g+(j&255)|0]|0;q=n}}while(0);n=q+2&65535;b[4821352]=n;if((a[9642744]&4)!=0){return}if((a[9642745]&1)==0){c[2439272]=(c[2439272]|0)-1}b[4821352]=n+(p&255|e)&65535;b[4821352]=c[2410676]&65535;return}function fIe(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=(j&255)<<8;j=k+1|0;k=j&65535;g=c[m+(l*3160|0)+60+((j>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){f=c[m+(l*3160|0)+3144>>2]|0;if((f|0)==0){p=0;q=n;break}d=gj[f&4095](k)|0;p=d;q=b[4821352]|0}else{p=a[g+(j&255)|0]|0;q=n}}while(0);n=q+2&65535;b[4821352]=n;if((a[9642744]&4)==0){return}if((a[9642745]&1)==0){c[2439272]=(c[2439272]|0)-1}b[4821352]=n+(p&255|e)&65535;b[4821352]=c[2410676]&65535;return}function fIf(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=(j&255)<<8;j=k+1|0;k=j&65535;g=c[m+(l*3160|0)+60+((j>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){f=c[m+(l*3160|0)+3144>>2]|0;if((f|0)==0){p=0;q=n;break}d=gj[f&4095](k)|0;p=d;q=b[4821352]|0}else{p=a[g+(j&255)|0]|0;q=n}}while(0);n=q+2&65535;b[4821352]=n;if((a[9642744]&2)!=0){return}if((a[9642745]&1)==0){c[2439272]=(c[2439272]|0)-1}b[4821352]=n+(p&255|e)&65535;b[4821352]=c[2410676]&65535;return}function fIg(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=(j&255)<<8;j=k+1|0;k=j&65535;g=c[m+(l*3160|0)+60+((j>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){f=c[m+(l*3160|0)+3144>>2]|0;if((f|0)==0){p=0;q=n;break}d=gj[f&4095](k)|0;p=d;q=b[4821352]|0}else{p=a[g+(j&255)|0]|0;q=n}}while(0);n=q+2&65535;b[4821352]=n;if((a[9642744]&2)==0){return}if((a[9642745]&1)==0){c[2439272]=(c[2439272]|0)-1}b[4821352]=n+(p&255|e)&65535;b[4821352]=c[2410676]&65535;return}function fIh(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=(j&255)<<8;j=k+1|0;k=j&65535;g=c[m+(l*3160|0)+60+((j>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){f=c[m+(l*3160|0)+3144>>2]|0;if((f|0)==0){p=0;q=n;break}d=gj[f&4095](k)|0;p=d;q=b[4821352]|0}else{p=a[g+(j&255)|0]|0;q=n}}while(0);n=q+2&65535;b[4821352]=n;if((a[9642744]&8)!=0){return}if((a[9642745]&1)==0){c[2439272]=(c[2439272]|0)-1}b[4821352]=n+(p&255|e)&65535;b[4821352]=c[2410676]&65535;return}function fIi(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=(j&255)<<8;j=k+1|0;k=j&65535;g=c[m+(l*3160|0)+60+((j>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){f=c[m+(l*3160|0)+3144>>2]|0;if((f|0)==0){p=0;q=n;break}d=gj[f&4095](k)|0;p=d;q=b[4821352]|0}else{p=a[g+(j&255)|0]|0;q=n}}while(0);n=q+2&65535;b[4821352]=n;if((a[9642744]&8)==0){return}if((a[9642745]&1)==0){c[2439272]=(c[2439272]|0)-1}b[4821352]=n+(p&255|e)&65535;b[4821352]=c[2410676]&65535;return}function fIj(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=c[2410676]|0;f=e&65535;g=c[3528552]|0;h=c[2433426]|0;i=c[h+(g*3160|0)+60+((e>>>8&255|512)<<2)>>2]|0;do{if((i|0)==0){j=c[h+(g*3160|0)+3144>>2]|0;if((j|0)==0){k=0;l=e;m=g;n=h;o=f;break}p=gj[j&4095](f)|0;j=c[2410676]|0;k=p;l=j;m=c[3528552]|0;n=c[2433426]|0;o=j&65535}else{k=a[i+(e&255)|0]|0;l=e;m=g;n=h;o=f}}while(0);f=(k&255)<<8;k=l+1|0;l=k&65535;h=c[n+(m*3160|0)+60+((k>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){g=c[n+(m*3160|0)+3144>>2]|0;if((g|0)==0){q=0;r=o;break}e=gj[g&4095](l)|0;q=e;r=b[4821352]|0}else{q=a[h+(k&255)|0]|0;r=o}}while(0);o=r+2&65535;b[4821352]=o;r=d[9642744]|0;if(((r<<2^r)&8|0)!=0){return}if((a[9642745]&1)==0){c[2439272]=(c[2439272]|0)-1}b[4821352]=o+(q&255|f)&65535;b[4821352]=c[2410676]&65535;return}function fIk(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=c[2410676]|0;f=e&65535;g=c[3528552]|0;h=c[2433426]|0;i=c[h+(g*3160|0)+60+((e>>>8&255|512)<<2)>>2]|0;do{if((i|0)==0){j=c[h+(g*3160|0)+3144>>2]|0;if((j|0)==0){k=0;l=e;m=g;n=h;o=f;break}p=gj[j&4095](f)|0;j=c[2410676]|0;k=p;l=j;m=c[3528552]|0;n=c[2433426]|0;o=j&65535}else{k=a[i+(e&255)|0]|0;l=e;m=g;n=h;o=f}}while(0);f=(k&255)<<8;k=l+1|0;l=k&65535;h=c[n+(m*3160|0)+60+((k>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){g=c[n+(m*3160|0)+3144>>2]|0;if((g|0)==0){q=0;r=o;break}e=gj[g&4095](l)|0;q=e;r=b[4821352]|0}else{q=a[h+(k&255)|0]|0;r=o}}while(0);o=r+2&65535;b[4821352]=o;r=d[9642744]|0;if(((r<<2^r)&8|0)==0){return}if((a[9642745]&1)==0){c[2439272]=(c[2439272]|0)-1}b[4821352]=o+(q&255|f)&65535;b[4821352]=c[2410676]&65535;return}function fIl(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=c[2410676]|0;f=e&65535;g=c[3528552]|0;h=c[2433426]|0;i=c[h+(g*3160|0)+60+((e>>>8&255|512)<<2)>>2]|0;do{if((i|0)==0){j=c[h+(g*3160|0)+3144>>2]|0;if((j|0)==0){k=0;l=e;m=g;n=h;o=f;break}p=gj[j&4095](f)|0;j=c[2410676]|0;k=p;l=j;m=c[3528552]|0;n=c[2433426]|0;o=j&65535}else{k=a[i+(e&255)|0]|0;l=e;m=g;n=h;o=f}}while(0);f=(k&255)<<8;k=l+1|0;l=k&65535;h=c[n+(m*3160|0)+60+((k>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){g=c[n+(m*3160|0)+3144>>2]|0;if((g|0)==0){q=0;r=o;break}e=gj[g&4095](l)|0;q=e;r=b[4821352]|0}else{q=a[h+(k&255)|0]|0;r=o}}while(0);o=r+2&65535;b[4821352]=o;r=d[9642744]|0;if(((r<<2^r)&8|r&4|0)!=0){return}if((a[9642745]&1)==0){c[2439272]=(c[2439272]|0)-1}b[4821352]=o+(q&255|f)&65535;b[4821352]=c[2410676]&65535;return}function fIm(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=c[2410676]|0;f=e&65535;g=c[3528552]|0;h=c[2433426]|0;i=c[h+(g*3160|0)+60+((e>>>8&255|512)<<2)>>2]|0;do{if((i|0)==0){j=c[h+(g*3160|0)+3144>>2]|0;if((j|0)==0){k=0;l=e;m=g;n=h;o=f;break}p=gj[j&4095](f)|0;j=c[2410676]|0;k=p;l=j;m=c[3528552]|0;n=c[2433426]|0;o=j&65535}else{k=a[i+(e&255)|0]|0;l=e;m=g;n=h;o=f}}while(0);f=(k&255)<<8;k=l+1|0;l=k&65535;h=c[n+(m*3160|0)+60+((k>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){g=c[n+(m*3160|0)+3144>>2]|0;if((g|0)==0){q=0;r=o;break}e=gj[g&4095](l)|0;q=e;r=b[4821352]|0}else{q=a[h+(k&255)|0]|0;r=o}}while(0);o=r+2&65535;b[4821352]=o;r=d[9642744]|0;if(((r<<2^r)&8|r&4|0)==0){return}if((a[9642745]&1)==0){c[2439272]=(c[2439272]|0)-1}b[4821352]=o+(q&255|f)&65535;b[4821352]=c[2410676]&65535;return}function fIn(){var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;f=i;i=i+16|0;g=f|0;h=f+8|0;a[g]=0;b[h>>1]=0;j=c[2410676]|0;k=j&65535;l=c[3528552]|0;m=c[2433426]|0;n=c[m+(l*3160|0)+60+((j>>>8&255|512)<<2)>>2]|0;do{if((n|0)==0){o=c[m+(l*3160|0)+3144>>2]|0;if((o|0)==0){p=0;q=k;break}r=gj[o&4095](k)|0;p=r;q=b[4821352]|0}else{p=a[n+(j&255)|0]|0;q=k}}while(0);b[4821352]=q+1&65535;q=p&255;p=q>>>4;k=((p^q)&8|0)==0;switch(p|0){case 2:{s=1;t=9642736;u=0;break};case 5:{s=1;t=9642704;u=0;break};case 9:{s=0;t=k?0:9642712;u=k?9642712:0;break};case 13:{s=0;t=k?0:h;u=k?g:0;break};case 3:{s=1;t=9642724;u=0;break};case 1:{s=1;t=9642732;u=0;break};case 4:{s=1;t=9642728;u=0;break};case 12:{s=0;t=k?0:h;u=k?g:0;break};case 6:{s=1;t=9642716;u=0;break};case 10:{s=0;t=k?0:h;u=k?9642744:0;break};case 14:{s=0;t=k?0:9642716;u=k?9642717:0;break};case 7:{s=1;t=9642740;u=0;break};case 11:{s=0;t=k?0:h;u=k?9642721:0;break};case 8:{s=0;t=k?0:9642712;u=k?9642713:0;break};case 0:{s=1;t=9642712;u=0;break};default:{s=0;t=k?0:9642716;u=k?9642716:0}}p=q&15;switch(p|0){case 9:{v=k?0:9642712;w=k?9642712:0;x=12160;break};case 2:{y=9642736;break};case 0:{y=9642712;break};case 5:{y=9642704;break};case 8:{v=k?0:9642712;w=k?9642713:0;x=12160;break};case 6:{y=9642716;break};case 10:{v=k?0:h;w=k?9642744:0;x=12160;break};case 12:{v=k?0:h;w=k?g:0;x=12160;break};case 13:{v=k?0:h;w=k?g:0;x=12160;break};case 3:{y=9642724;break};case 1:{y=9642732;break};case 7:{y=9642740;break};case 4:{y=9642728;break};case 14:{v=k?0:9642716;w=k?9642717:0;x=12160;break};case 11:{v=k?0:h;w=k?9642721:0;x=12160;break};default:{v=k?0:9642716;w=k?9642716:0;x=12160}}do{if((x|0)==12160){if((s|0)!=0){y=v;break}k=(d[w]|0)+(d[u]|0)&65535;a[9642744]=a[9642744]&-16;h=k&255;a[w]=h;g=k&65535;k=g>>>4&8|(d[9642744]|0);if(h<<24>>24==0){z=(k|4)&255}else{z=k&255}a[9642744]=z;a[9642744]=(z&255|g>>>8&1|(g>>>1^g^(a[w]^a[u])&255)>>>6&2)&255;i=f;return}}while(0);u=(e[y>>1]|0)+(e[t>>1]|0)|0;a[9642744]=a[9642744]&-16;w=u&65535;b[y>>1]=w;z=u>>>12&8|(d[9642744]|0);if(w<<16>>16==0){A=(z|4)&255}else{A=z&255}a[9642744]=A;a[9642744]=(A&255|u>>>16&1|(u>>>1^u^(b[y>>1]^b[t>>1])&65535)>>>14&2)&255;if((p|0)!=5){i=f;return}b[4821352]=c[2410676]&65535;i=f;return}function fIo(){var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;f=i;i=i+16|0;g=f|0;h=f+8|0;a[g]=0;b[h>>1]=0;j=c[2410676]|0;k=j&65535;l=c[3528552]|0;m=c[2433426]|0;n=c[m+(l*3160|0)+60+((j>>>8&255|512)<<2)>>2]|0;do{if((n|0)==0){o=c[m+(l*3160|0)+3144>>2]|0;if((o|0)==0){p=0;q=k;break}r=gj[o&4095](k)|0;p=r;q=b[4821352]|0}else{p=a[n+(j&255)|0]|0;q=k}}while(0);b[4821352]=q+1&65535;q=p&255;p=q>>>4;k=((p^q)&8|0)==0;switch(p|0){case 8:{s=0;t=k?0:9642712;u=k?9642713:0;break};case 4:{s=1;t=9642728;u=0;break};case 1:{s=1;t=9642732;u=0;break};case 12:{s=0;t=k?0:h;u=k?g:0;break};case 3:{s=1;t=9642724;u=0;break};case 5:{s=1;t=9642704;u=0;break};case 2:{s=1;t=9642736;u=0;break};case 6:{s=1;t=9642716;u=0;break};case 0:{s=1;t=9642712;u=0;break};case 7:{s=1;t=9642740;u=0;break};case 13:{s=0;t=k?0:h;u=k?g:0;break};case 10:{s=0;t=k?0:h;u=k?9642744:0;break};case 9:{s=0;t=k?0:9642712;u=k?9642712:0;break};case 11:{s=0;t=k?0:h;u=k?9642721:0;break};case 14:{s=0;t=k?0:9642716;u=k?9642717:0;break};default:{s=0;t=k?0:9642716;u=k?9642716:0}}p=q&15;switch(p|0){case 7:{v=9642740;break};case 1:{v=9642732;break};case 9:{w=k?0:9642712;x=k?9642712:0;y=12208;break};case 2:{v=9642736;break};case 14:{w=k?0:9642716;x=k?9642717:0;y=12208;break};case 5:{v=9642704;break};case 8:{w=k?0:9642712;x=k?9642713:0;y=12208;break};case 10:{w=k?0:h;x=k?9642744:0;y=12208;break};case 12:{w=k?0:h;x=k?g:0;y=12208;break};case 13:{w=k?0:h;x=k?g:0;y=12208;break};case 3:{v=9642724;break};case 6:{v=9642716;break};case 4:{v=9642728;break};case 0:{v=9642712;break};case 11:{w=k?0:h;x=k?9642721:0;y=12208;break};default:{w=k?0:9642716;x=k?9642716:0;y=12208}}do{if((y|0)==12208){if((s|0)!=0){v=w;break}k=a[9642744]|0;h=(d[x]|0)+(d[u]|0)+(k&1)|0;a[9642744]=k&-16;k=h&255;a[x]=k;g=h>>>4&8|(d[9642744]|0);if(k<<24>>24==0){z=(g|4)&255}else{z=g&255}a[9642744]=z;a[9642744]=(z&255|h>>>8&1|(h>>>1^h^(a[x]^a[u])&255)>>>6&2)&255;i=f;return}}while(0);u=a[9642744]|0;x=(e[v>>1]|0)+(e[t>>1]|0)+(u&1)|0;a[9642744]=u&-16;u=x&65535;b[v>>1]=u;z=x>>>12&8|(d[9642744]|0);if(u<<16>>16==0){A=(z|4)&255}else{A=z&255}a[9642744]=A;a[9642744]=(A&255|x>>>16&1|(x>>>1^x^(b[v>>1]^b[t>>1])&65535)>>>14&2)&255;if((p|0)!=5){i=f;return}b[4821352]=c[2410676]&65535;i=f;return}function fIp(){var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;f=i;i=i+16|0;g=f|0;h=f+8|0;a[g]=0;b[h>>1]=0;j=c[2410676]|0;k=j&65535;l=c[3528552]|0;m=c[2433426]|0;n=c[m+(l*3160|0)+60+((j>>>8&255|512)<<2)>>2]|0;do{if((n|0)==0){o=c[m+(l*3160|0)+3144>>2]|0;if((o|0)==0){p=0;q=k;break}r=gj[o&4095](k)|0;p=r;q=b[4821352]|0}else{p=a[n+(j&255)|0]|0;q=k}}while(0);b[4821352]=q+1&65535;q=p&255;p=q>>>4;k=((p^q)&8|0)==0;switch(p|0){case 3:{s=1;t=9642724;u=0;break};case 6:{s=1;t=9642716;u=0;break};case 10:{s=0;t=k?0:h;u=k?9642744:0;break};case 14:{s=0;t=k?0:9642716;u=k?9642717:0;break};case 4:{s=1;t=9642728;u=0;break};case 2:{s=1;t=9642736;u=0;break};case 5:{s=1;t=9642704;u=0;break};case 1:{s=1;t=9642732;u=0;break};case 13:{s=0;t=k?0:h;u=k?g:0;break};case 7:{s=1;t=9642740;u=0;break};case 11:{s=0;t=k?0:h;u=k?9642721:0;break};case 8:{s=0;t=k?0:9642712;u=k?9642713:0;break};case 12:{s=0;t=k?0:h;u=k?g:0;break};case 9:{s=0;t=k?0:9642712;u=k?9642712:0;break};case 0:{s=1;t=9642712;u=0;break};default:{s=0;t=k?0:9642716;u=k?9642716:0}}p=q&15;switch(p|0){case 1:{v=9642732;break};case 2:{v=9642736;break};case 3:{v=9642724;break};case 4:{v=9642728;break};case 5:{v=9642704;break};case 6:{v=9642716;break};case 7:{v=9642740;break};case 8:{w=k?0:9642712;x=k?9642713:0;y=12256;break};case 9:{w=k?0:9642712;x=k?9642712:0;y=12256;break};case 10:{w=k?0:h;x=k?9642744:0;y=12256;break};case 11:{w=k?0:h;x=k?9642721:0;y=12256;break};case 12:{w=k?0:h;x=k?g:0;y=12256;break};case 13:{w=k?0:h;x=k?g:0;y=12256;break};case 14:{w=k?0:9642716;x=k?9642717:0;y=12256;break};case 0:{v=9642712;break};default:{w=k?0:9642716;x=k?9642716:0;y=12256}}do{if((y|0)==12256){if((s|0)!=0){v=w;break}k=(d[x]|0)-(d[u]|0)&65535;a[9642744]=a[9642744]&-16;g=k&255;a[x]=g;h=k&65535;k=h>>>4&8|(d[9642744]|0);if(g<<24>>24==0){z=(k|4)&255}else{z=k&255}a[9642744]=z;a[9642744]=(z&255|h>>>8&1|(h>>>1^h^(a[u]^a[x])&255)>>>6&2)&255;i=f;return}}while(0);x=(e[v>>1]|0)-(e[t>>1]|0)|0;a[9642744]=a[9642744]&-16;u=x&65535;b[v>>1]=u;z=x>>>12&8|(d[9642744]|0);if(u<<16>>16==0){A=(z|4)&255}else{A=z&255}a[9642744]=A;a[9642744]=(A&255|x>>>16&1|(x>>>1^x^(b[t>>1]^b[v>>1])&65535)>>>14&2)&255;if((p|0)!=5){i=f;return}b[4821352]=c[2410676]&65535;i=f;return}function fIq(){var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;f=i;i=i+16|0;g=f|0;h=f+8|0;a[g]=0;b[h>>1]=0;j=c[2410676]|0;k=j&65535;l=c[3528552]|0;m=c[2433426]|0;n=c[m+(l*3160|0)+60+((j>>>8&255|512)<<2)>>2]|0;do{if((n|0)==0){o=c[m+(l*3160|0)+3144>>2]|0;if((o|0)==0){p=0;q=k;break}r=gj[o&4095](k)|0;p=r;q=b[4821352]|0}else{p=a[n+(j&255)|0]|0;q=k}}while(0);b[4821352]=q+1&65535;q=p&255;p=q>>>4;k=((p^q)&8|0)==0;switch(p|0){case 8:{s=0;t=k?0:9642712;u=k?9642713:0;break};case 4:{s=1;t=9642728;u=0;break};case 1:{s=1;t=9642732;u=0;break};case 14:{s=0;t=k?0:9642716;u=k?9642717:0;break};case 12:{s=0;t=k?0:h;u=k?g:0;break};case 3:{s=1;t=9642724;u=0;break};case 5:{s=1;t=9642704;u=0;break};case 2:{s=1;t=9642736;u=0;break};case 6:{s=1;t=9642716;u=0;break};case 7:{s=1;t=9642740;u=0;break};case 10:{s=0;t=k?0:h;u=k?9642744:0;break};case 9:{s=0;t=k?0:9642712;u=k?9642712:0;break};case 13:{s=0;t=k?0:h;u=k?g:0;break};case 0:{s=1;t=9642712;u=0;break};case 11:{s=0;t=k?0:h;u=k?9642721:0;break};default:{s=0;t=k?0:9642716;u=k?9642716:0}}p=q&15;switch(p|0){case 12:{v=k?0:h;w=k?g:0;x=12304;break};case 6:{y=9642716;break};case 10:{v=k?0:h;w=k?9642744:0;x=12304;break};case 11:{v=k?0:h;w=k?9642721:0;x=12304;break};case 14:{v=k?0:9642716;w=k?9642717:0;x=12304;break};case 8:{v=k?0:9642712;w=k?9642713:0;x=12304;break};case 0:{y=9642712;break};case 13:{v=k?0:h;w=k?g:0;x=12304;break};case 1:{y=9642732;break};case 2:{y=9642736;break};case 3:{y=9642724;break};case 4:{y=9642728;break};case 5:{y=9642704;break};case 7:{y=9642740;break};case 9:{v=k?0:9642712;w=k?9642712:0;x=12304;break};default:{v=k?0:9642716;w=k?9642716:0;x=12304}}do{if((x|0)==12304){if((s|0)!=0){y=v;break}k=a[9642744]|0;g=(d[w]|0)-(d[u]|0)-(k&1)|0;a[9642744]=k&-16;k=g&255;a[w]=k;h=g>>>4&8|(d[9642744]|0);if(k<<24>>24==0){z=(h|4)&255}else{z=h&255}a[9642744]=z;a[9642744]=(z&255|g>>>8&1|(g>>>1^g^(a[u]^a[w])&255)>>>6&2)&255;i=f;return}}while(0);w=a[9642744]|0;u=(e[y>>1]|0)-(e[t>>1]|0)-(w&1)|0;a[9642744]=w&-16;w=u&65535;b[y>>1]=w;z=u>>>12&8|(d[9642744]|0);if(w<<16>>16==0){A=(z|4)&255}else{A=z&255}a[9642744]=A;a[9642744]=(A&255|u>>>16&1|(u>>>1^u^(b[t>>1]^b[y>>1])&65535)>>>14&2)&255;if((p|0)!=5){i=f;return}b[4821352]=c[2410676]&65535;i=f;return}function fIr(){var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;e=i;i=i+16|0;f=e|0;g=e+8|0;a[f]=0;b[g>>1]=0;h=c[2410676]|0;j=h&65535;k=c[3528552]|0;l=c[2433426]|0;m=c[l+(k*3160|0)+60+((h>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){n=c[l+(k*3160|0)+3144>>2]|0;if((n|0)==0){o=0;p=j;break}q=gj[n&4095](j)|0;o=q;p=b[4821352]|0}else{o=a[m+(h&255)|0]|0;p=j}}while(0);b[4821352]=p+1&65535;p=o&255;o=p>>>4;j=((o^p)&8|0)==0;switch(o|0){case 3:{r=1;s=9642724;t=0;break};case 6:{r=1;s=9642716;t=0;break};case 10:{r=0;s=j?0:g;t=j?9642744:0;break};case 14:{r=0;s=j?0:9642716;t=j?9642717:0;break};case 0:{r=1;s=9642712;t=0;break};case 4:{r=1;s=9642728;t=0;break};case 2:{r=1;s=9642736;t=0;break};case 5:{r=1;s=9642704;t=0;break};case 1:{r=1;s=9642732;t=0;break};case 13:{r=0;s=j?0:g;t=j?f:0;break};case 7:{r=1;s=9642740;t=0;break};case 11:{r=0;s=j?0:g;t=j?9642721:0;break};case 8:{r=0;s=j?0:9642712;t=j?9642713:0;break};case 12:{r=0;s=j?0:g;t=j?f:0;break};case 9:{r=0;s=j?0:9642712;t=j?9642712:0;break};default:{r=0;s=j?0:9642716;t=j?9642716:0}}o=p&15;switch(o|0){case 0:{u=9642712;break};case 13:{v=j?0:g;w=j?f:0;x=12352;break};case 14:{v=j?0:9642716;w=j?9642717:0;x=12352;break};case 12:{v=j?0:g;w=j?f:0;x=12352;break};case 1:{u=9642732;break};case 2:{u=9642736;break};case 3:{u=9642724;break};case 4:{u=9642728;break};case 5:{u=9642704;break};case 6:{u=9642716;break};case 7:{u=9642740;break};case 8:{v=j?0:9642712;w=j?9642713:0;x=12352;break};case 9:{v=j?0:9642712;w=j?9642712:0;x=12352;break};case 10:{v=j?0:g;w=j?9642744:0;x=12352;break};case 11:{v=j?0:g;w=j?9642721:0;x=12352;break};default:{v=j?0:9642716;w=j?9642716:0;x=12352}}do{if((x|0)==12352){if((r|0)!=0){u=v;break}j=a[w]&a[t];a[9642744]=a[9642744]&-15;a[w]=j;g=(j&255)>>>4&8|a[9642744];a[9642744]=g;if(j<<24>>24!=0){i=e;return}a[9642744]=g|4;i=e;return}}while(0);w=b[u>>1]&b[s>>1];a[9642744]=a[9642744]&-15;b[u>>1]=w;u=(w&65535)>>>12&8|(d[9642744]|0);if(w<<16>>16==0){y=(u|4)&255}else{y=u&255}a[9642744]=y;if((o|0)!=5){i=e;return}b[4821352]=c[2410676]&65535;i=e;return}function fIs(){var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;e=i;i=i+16|0;f=e|0;g=e+8|0;a[f]=0;b[g>>1]=0;h=c[2410676]|0;j=h&65535;k=c[3528552]|0;l=c[2433426]|0;m=c[l+(k*3160|0)+60+((h>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){n=c[l+(k*3160|0)+3144>>2]|0;if((n|0)==0){o=0;p=j;break}q=gj[n&4095](j)|0;o=q;p=b[4821352]|0}else{o=a[m+(h&255)|0]|0;p=j}}while(0);b[4821352]=p+1&65535;p=o&255;o=p>>>4;j=((o^p)&8|0)==0;switch(o|0){case 8:{r=0;s=j?0:9642712;t=j?9642713:0;break};case 4:{r=1;s=9642728;t=0;break};case 1:{r=1;s=9642732;t=0;break};case 14:{r=0;s=j?0:9642716;t=j?9642717:0;break};case 12:{r=0;s=j?0:g;t=j?f:0;break};case 3:{r=1;s=9642724;t=0;break};case 5:{r=1;s=9642704;t=0;break};case 2:{r=1;s=9642736;t=0;break};case 6:{r=1;s=9642716;t=0;break};case 7:{r=1;s=9642740;t=0;break};case 10:{r=0;s=j?0:g;t=j?9642744:0;break};case 9:{r=0;s=j?0:9642712;t=j?9642712:0;break};case 13:{r=0;s=j?0:g;t=j?f:0;break};case 0:{r=1;s=9642712;t=0;break};case 11:{r=0;s=j?0:g;t=j?9642721:0;break};default:{r=0;s=j?0:9642716;t=j?9642716:0}}o=p&15;switch(o|0){case 1:{u=9642732;break};case 2:{u=9642736;break};case 3:{u=9642724;break};case 4:{u=9642728;break};case 5:{u=9642704;break};case 6:{u=9642716;break};case 7:{u=9642740;break};case 8:{v=j?0:9642712;w=j?9642713:0;x=12400;break};case 9:{v=j?0:9642712;w=j?9642712:0;x=12400;break};case 10:{v=j?0:g;w=j?9642744:0;x=12400;break};case 11:{v=j?0:g;w=j?9642721:0;x=12400;break};case 12:{v=j?0:g;w=j?f:0;x=12400;break};case 13:{v=j?0:g;w=j?f:0;x=12400;break};case 14:{v=j?0:9642716;w=j?9642717:0;x=12400;break};case 0:{u=9642712;break};default:{v=j?0:9642716;w=j?9642716:0;x=12400}}do{if((x|0)==12400){if((r|0)!=0){u=v;break}j=a[w]|a[t];a[9642744]=a[9642744]&-15;a[w]=j;f=(j&255)>>>4&8|a[9642744];a[9642744]=f;if(j<<24>>24!=0){i=e;return}a[9642744]=f|4;i=e;return}}while(0);w=b[u>>1]|b[s>>1];a[9642744]=a[9642744]&-15;b[u>>1]=w;u=(w&65535)>>>12&8|(d[9642744]|0);if(w<<16>>16==0){y=(u|4)&255}else{y=u&255}a[9642744]=y;if((o|0)!=5){i=e;return}b[4821352]=c[2410676]&65535;i=e;return}function fIt(){var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;e=i;i=i+16|0;f=e|0;g=e+8|0;a[f]=0;b[g>>1]=0;h=c[2410676]|0;j=h&65535;k=c[3528552]|0;l=c[2433426]|0;m=c[l+(k*3160|0)+60+((h>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){n=c[l+(k*3160|0)+3144>>2]|0;if((n|0)==0){o=0;p=j;break}q=gj[n&4095](j)|0;o=q;p=b[4821352]|0}else{o=a[m+(h&255)|0]|0;p=j}}while(0);b[4821352]=p+1&65535;p=o&255;o=p>>>4;j=((o^p)&8|0)==0;switch(o|0){case 3:{r=1;s=9642724;t=0;break};case 6:{r=1;s=9642716;t=0;break};case 10:{r=0;s=j?0:g;t=j?9642744:0;break};case 4:{r=1;s=9642728;t=0;break};case 2:{r=1;s=9642736;t=0;break};case 5:{r=1;s=9642704;t=0;break};case 1:{r=1;s=9642732;t=0;break};case 14:{r=0;s=j?0:9642716;t=j?9642717:0;break};case 7:{r=1;s=9642740;t=0;break};case 11:{r=0;s=j?0:g;t=j?9642721:0;break};case 0:{r=1;s=9642712;t=0;break};case 8:{r=0;s=j?0:9642712;t=j?9642713:0;break};case 13:{r=0;s=j?0:g;t=j?f:0;break};case 9:{r=0;s=j?0:9642712;t=j?9642712:0;break};case 12:{r=0;s=j?0:g;t=j?f:0;break};default:{r=0;s=j?0:9642716;t=j?9642716:0}}o=p&15;switch(o|0){case 1:{u=9642732;break};case 2:{u=9642736;break};case 3:{u=9642724;break};case 4:{u=9642728;break};case 5:{u=9642704;break};case 6:{u=9642716;break};case 7:{u=9642740;break};case 8:{v=j?0:9642712;w=j?9642713:0;x=12448;break};case 9:{v=j?0:9642712;w=j?9642712:0;x=12448;break};case 10:{v=j?0:g;w=j?9642744:0;x=12448;break};case 12:{v=j?0:g;w=j?f:0;x=12448;break};case 0:{u=9642712;break};case 14:{v=j?0:9642716;w=j?9642717:0;x=12448;break};case 13:{v=j?0:g;w=j?f:0;x=12448;break};case 11:{v=j?0:g;w=j?9642721:0;x=12448;break};default:{v=j?0:9642716;w=j?9642716:0;x=12448}}do{if((x|0)==12448){if((r|0)!=0){u=v;break}j=a[t]|0;g=a[w]|0;f=g^j;a[9642744]=a[9642744]&-15;a[w]=f;p=(f&255)>>>4&8|a[9642744];a[9642744]=p;if(j<<24>>24!=g<<24>>24){i=e;return}a[9642744]=p|4;i=e;return}}while(0);w=b[s>>1]|0;s=b[u>>1]|0;t=s^w;a[9642744]=a[9642744]&-15;b[u>>1]=t;u=(t&65535)>>>12&8|(d[9642744]|0);if(w<<16>>16==s<<16>>16){y=(u|4)&255}else{y=u&255}a[9642744]=y;if((o|0)!=5){i=e;return}b[4821352]=c[2410676]&65535;i=e;return}function fIu(){var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;f=i;i=i+16|0;g=f|0;h=f+8|0;a[g]=0;b[h>>1]=0;j=c[2410676]|0;k=j&65535;l=c[3528552]|0;m=c[2433426]|0;n=c[m+(l*3160|0)+60+((j>>>8&255|512)<<2)>>2]|0;do{if((n|0)==0){o=c[m+(l*3160|0)+3144>>2]|0;if((o|0)==0){p=0;q=k;break}r=gj[o&4095](k)|0;p=r;q=b[4821352]|0}else{p=a[n+(j&255)|0]|0;q=k}}while(0);b[4821352]=q+1&65535;q=p&255;p=q>>>4;k=((p^q)&8|0)==0;switch(p|0){case 8:{s=0;t=k?0:9642712;u=k?9642713:0;break};case 4:{s=1;t=9642728;u=0;break};case 1:{s=1;t=9642732;u=0;break};case 14:{s=0;t=k?0:9642716;u=k?9642717:0;break};case 12:{s=0;t=k?0:h;u=k?g:0;break};case 3:{s=1;t=9642724;u=0;break};case 5:{s=1;t=9642704;u=0;break};case 2:{s=1;t=9642736;u=0;break};case 6:{s=1;t=9642716;u=0;break};case 7:{s=1;t=9642740;u=0;break};case 10:{s=0;t=k?0:h;u=k?9642744:0;break};case 9:{s=0;t=k?0:9642712;u=k?9642712:0;break};case 13:{s=0;t=k?0:h;u=k?g:0;break};case 0:{s=1;t=9642712;u=0;break};case 11:{s=0;t=k?0:h;u=k?9642721:0;break};default:{s=0;t=k?0:9642716;u=k?9642716:0}}switch(q&15|0){case 10:{v=k?0:h;w=k?9642744:0;x=12496;break};case 7:{y=9642740;break};case 4:{y=9642728;break};case 13:{v=k?0:h;w=k?g:0;x=12496;break};case 14:{v=k?0:9642716;w=k?9642717:0;x=12496;break};case 6:{y=9642716;break};case 12:{v=k?0:h;w=k?g:0;x=12496;break};case 3:{y=9642724;break};case 11:{v=k?0:h;w=k?9642721:0;x=12496;break};case 0:{y=9642712;break};case 9:{v=k?0:9642712;w=k?9642712:0;x=12496;break};case 2:{y=9642736;break};case 1:{y=9642732;break};case 5:{y=9642704;break};case 8:{v=k?0:9642712;w=k?9642713:0;x=12496;break};default:{v=k?0:9642716;w=k?9642716:0;x=12496}}do{if((x|0)==12496){if((s|0)!=0){y=v;break}k=(d[w]|0)-(d[u]|0)&65535;h=k&65535;g=(h>>>4&8|a[9642744]&-16&255)&255;q=(k&255)<<24>>24==0?g|4:g;a[9642744]=q;z=(h>>>1^h^(a[u]^a[w])&255)>>>6&2|h>>>8&1|q&255;A=z&255;a[9642744]=A;i=f;return}}while(0);w=b[t>>1]|0;t=(e[y>>1]|0)-(w&65535)|0;u=(t>>>12&8|a[9642744]&-16&255)&255;v=(t&65535)<<16>>16==0?u|4:u;a[9642744]=v;z=(t>>>1^t^(b[y>>1]^w)&65535)>>>14&2|t>>>16&1|v&255;A=z&255;a[9642744]=A;i=f;return}function fIv(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b[4821364]=(b[4821364]|0)-1&65535;d=c[2410682]|0;e=d&65535;f=a[9642716]|0;g=c[3528552]|0;h=c[2433426]|0;i=c[h+(g*3160|0)+60+((d>>>8&255|256)<<2)>>2]|0;do{if((i|0)==0){j=c[h+(g*3160|0)+3136>>2]|0;if((j|0)==0){k=g;l=h;break}gg[j&4095](e,f);k=c[3528552]|0;l=c[2433426]|0}else{a[i+(d&255)|0]=f;k=g;l=h}}while(0);b[4821364]=(b[4821364]|0)-1&65535;h=c[2410682]|0;g=a[9642717]|0;f=c[l+(k*3160|0)+60+((h>>>8&255|256)<<2)>>2]|0;if((f|0)!=0){a[f+(h&255)|0]=g;return}f=c[l+(k*3160|0)+3136>>2]|0;if((f|0)==0){return}gg[f&4095](h&65535,g);return}function fIw(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=c[2410682]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3132>>2]|0;if((i|0)==0){j=0;k=e;l=f;m=g;break}n=gj[i&4095](e)|0;j=n;k=b[4821364]|0;l=c[3528552]|0;m=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=e;l=f;m=g}}while(0);g=(j&255)<<8;b[4821358]=g;b[4821364]=k+1&65535;k=c[2410682]|0;j=k&65535;f=c[m+(l*3160|0)+60+((k>>>8&255)<<2)>>2]|0;do{if((f|0)==0){e=c[m+(l*3160|0)+3132>>2]|0;if((e|0)==0){o=0;p=g;q=j;break}d=gj[e&4095](j)|0;o=d;p=b[4821358]|0;q=b[4821364]|0}else{o=a[f+(k&255)|0]|0;p=g;q=j}}while(0);b[4821358]=p|o&255;b[4821364]=q+1&65535;return}function fIx(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b[4821362]=(b[4821362]|0)-1&65535;d=c[2410681]|0;e=d&65535;f=a[9642716]|0;g=c[3528552]|0;h=c[2433426]|0;i=c[h+(g*3160|0)+60+((d>>>8&255|256)<<2)>>2]|0;do{if((i|0)==0){j=c[h+(g*3160|0)+3136>>2]|0;if((j|0)==0){k=g;l=h;break}gg[j&4095](e,f);k=c[3528552]|0;l=c[2433426]|0}else{a[i+(d&255)|0]=f;k=g;l=h}}while(0);b[4821362]=(b[4821362]|0)-1&65535;h=c[2410681]|0;g=a[9642717]|0;f=c[l+(k*3160|0)+60+((h>>>8&255|256)<<2)>>2]|0;if((f|0)!=0){a[f+(h&255)|0]=g;return}f=c[l+(k*3160|0)+3136>>2]|0;if((f|0)==0){return}gg[f&4095](h&65535,g);return}function fIy(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=c[2410681]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3132>>2]|0;if((i|0)==0){j=0;k=e;l=f;m=g;break}n=gj[i&4095](e)|0;j=n;k=b[4821362]|0;l=c[3528552]|0;m=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=e;l=f;m=g}}while(0);g=(j&255)<<8;b[4821358]=g;b[4821362]=k+1&65535;k=c[2410681]|0;j=k&65535;f=c[m+(l*3160|0)+60+((k>>>8&255)<<2)>>2]|0;do{if((f|0)==0){e=c[m+(l*3160|0)+3132>>2]|0;if((e|0)==0){o=0;p=g;q=j;break}d=gj[e&4095](j)|0;o=d;p=b[4821358]|0;q=b[4821362]|0}else{o=a[f+(k&255)|0]|0;p=g;q=j}}while(0);b[4821358]=p|o&255;b[4821362]=q+1&65535;return}function fIz(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;a[9642744]=a[9642744]|-128;b[4821364]=(b[4821364]|0)-1&65535;e=c[2410682]|0;f=e&65535;g=a[9642704]|0;h=c[3528552]|0;i=c[2433426]|0;j=c[i+(h*3160|0)+60+((e>>>8&255|256)<<2)>>2]|0;do{if((j|0)==0){k=c[i+(h*3160|0)+3136>>2]|0;if((k|0)==0){l=h;m=i;break}gg[k&4095](f,g);l=c[3528552]|0;m=c[2433426]|0}else{a[j+(e&255)|0]=g;l=h;m=i}}while(0);b[4821364]=(b[4821364]|0)-1&65535;i=c[2410682]|0;h=i&65535;g=a[9642705]|0;e=c[m+(l*3160|0)+60+((i>>>8&255|256)<<2)>>2]|0;do{if((e|0)==0){j=c[m+(l*3160|0)+3136>>2]|0;if((j|0)==0){n=l;o=m;break}gg[j&4095](h,g);n=c[3528552]|0;o=c[2433426]|0}else{a[e+(i&255)|0]=g;n=l;o=m}}while(0);b[4821364]=(b[4821364]|0)-1&65535;m=c[2410682]|0;l=m&65535;g=a[9642724]|0;i=c[o+(n*3160|0)+60+((m>>>8&255|256)<<2)>>2]|0;do{if((i|0)==0){e=c[o+(n*3160|0)+3136>>2]|0;if((e|0)==0){p=n;q=o;break}gg[e&4095](l,g);p=c[3528552]|0;q=c[2433426]|0}else{a[i+(m&255)|0]=g;p=n;q=o}}while(0);b[4821364]=(b[4821364]|0)-1&65535;o=c[2410682]|0;n=o&65535;g=a[9642725]|0;m=c[q+(p*3160|0)+60+((o>>>8&255|256)<<2)>>2]|0;do{if((m|0)==0){i=c[q+(p*3160|0)+3136>>2]|0;if((i|0)==0){r=p;s=q;break}gg[i&4095](n,g);r=c[3528552]|0;s=c[2433426]|0}else{a[m+(o&255)|0]=g;r=p;s=q}}while(0);b[4821364]=(b[4821364]|0)-1&65535;q=c[2410682]|0;p=q&65535;g=a[9642736]|0;o=c[s+(r*3160|0)+60+((q>>>8&255|256)<<2)>>2]|0;do{if((o|0)==0){m=c[s+(r*3160|0)+3136>>2]|0;if((m|0)==0){t=r;u=s;break}gg[m&4095](p,g);t=c[3528552]|0;u=c[2433426]|0}else{a[o+(q&255)|0]=g;t=r;u=s}}while(0);b[4821364]=(b[4821364]|0)-1&65535;s=c[2410682]|0;r=s&65535;g=a[9642737]|0;q=c[u+(t*3160|0)+60+((s>>>8&255|256)<<2)>>2]|0;do{if((q|0)==0){o=c[u+(t*3160|0)+3136>>2]|0;if((o|0)==0){v=t;w=u;break}gg[o&4095](r,g);v=c[3528552]|0;w=c[2433426]|0}else{a[q+(s&255)|0]=g;v=t;w=u}}while(0);b[4821364]=(b[4821364]|0)-1&65535;u=c[2410682]|0;t=u&65535;g=a[9642732]|0;s=c[w+(v*3160|0)+60+((u>>>8&255|256)<<2)>>2]|0;do{if((s|0)==0){q=c[w+(v*3160|0)+3136>>2]|0;if((q|0)==0){x=v;y=w;break}gg[q&4095](t,g);x=c[3528552]|0;y=c[2433426]|0}else{a[s+(u&255)|0]=g;x=v;y=w}}while(0);b[4821364]=(b[4821364]|0)-1&65535;w=c[2410682]|0;v=w&65535;g=a[9642733]|0;u=c[y+(x*3160|0)+60+((w>>>8&255|256)<<2)>>2]|0;do{if((u|0)==0){s=c[y+(x*3160|0)+3136>>2]|0;if((s|0)==0){z=x;A=y;break}gg[s&4095](v,g);z=c[3528552]|0;A=c[2433426]|0}else{a[u+(w&255)|0]=g;z=x;A=y}}while(0);b[4821364]=(b[4821364]|0)-1&65535;y=c[2410682]|0;x=y&65535;g=a[9642721]|0;w=c[A+(z*3160|0)+60+((y>>>8&255|256)<<2)>>2]|0;do{if((w|0)==0){u=c[A+(z*3160|0)+3136>>2]|0;if((u|0)==0){break}gg[u&4095](x,g)}else{a[w+(y&255)|0]=g}}while(0);do{if((a[9642745]&1)!=0){b[4821364]=(b[4821364]|0)-1&65535;g=c[2410682]|0;y=g&65535;w=a[9642716]|0;x=c[3528552]|0;z=c[2433426]|0;A=c[z+(x*3160|0)+60+((g>>>8&255|256)<<2)>>2]|0;do{if((A|0)==0){u=c[z+(x*3160|0)+3136>>2]|0;if((u|0)==0){B=x;C=z;break}gg[u&4095](y,w);B=c[3528552]|0;C=c[2433426]|0}else{a[A+(g&255)|0]=w;B=x;C=z}}while(0);b[4821364]=(b[4821364]|0)-1&65535;z=c[2410682]|0;x=a[9642717]|0;w=c[C+(B*3160|0)+60+((z>>>8&255|256)<<2)>>2]|0;if((w|0)!=0){a[w+(z&255)|0]=x;break}w=c[C+(B*3160|0)+3136>>2]|0;if((w|0)==0){break}gg[w&4095](z&65535,x)}}while(0);b[4821364]=(b[4821364]|0)-1&65535;B=c[2410682]|0;C=B&65535;x=a[9642712]|0;z=c[3528552]|0;w=c[2433426]|0;g=c[w+(z*3160|0)+60+((B>>>8&255|256)<<2)>>2]|0;do{if((g|0)==0){A=c[w+(z*3160|0)+3136>>2]|0;if((A|0)==0){D=z;E=w;break}gg[A&4095](C,x);D=c[3528552]|0;E=c[2433426]|0}else{a[g+(B&255)|0]=x;D=z;E=w}}while(0);b[4821364]=(b[4821364]|0)-1&65535;w=c[2410682]|0;z=w&65535;x=a[9642713]|0;B=c[E+(D*3160|0)+60+((w>>>8&255|256)<<2)>>2]|0;do{if((B|0)==0){g=c[E+(D*3160|0)+3136>>2]|0;if((g|0)==0){F=D;G=E;break}gg[g&4095](z,x);F=c[3528552]|0;G=c[2433426]|0}else{a[B+(w&255)|0]=x;F=D;G=E}}while(0);b[4821364]=(b[4821364]|0)-1&65535;E=c[2410682]|0;D=E&65535;x=a[9642744]|0;w=c[G+(F*3160|0)+60+((E>>>8&255|256)<<2)>>2]|0;do{if((w|0)==0){B=c[G+(F*3160|0)+3136>>2]|0;if((B|0)==0){H=F;I=G;break}gg[B&4095](D,x);H=c[3528552]|0;I=c[2433426]|0}else{a[w+(E&255)|0]=x;H=F;I=G}}while(0);G=c[I+(H*3160|0)+1080>>2]|0;do{if((G|0)==0){F=c[I+(H*3160|0)+3132>>2]|0;if((F|0)==0){J=0;K=0;L=J&255;M=L|K;c[2410676]=M;N=M&65535;b[4821352]=N;return}x=gj[F&4095](-12)|0;F=c[3528552]|0;E=c[2433426]|0;w=c[E+(F*3160|0)+1080>>2]|0;D=(x&255)<<8;if((w|0)!=0){O=w;P=D;break}w=c[E+(F*3160|0)+3132>>2]|0;if((w|0)==0){J=0;K=D;L=J&255;M=L|K;c[2410676]=M;N=M&65535;b[4821352]=N;return}J=gj[w&4095](-11)|0;K=D;L=J&255;M=L|K;c[2410676]=M;N=M&65535;b[4821352]=N;return}else{O=G;P=(d[G+244|0]|0)<<8}}while(0);J=a[O+245|0]|0;K=P;L=J&255;M=L|K;c[2410676]=M;N=M&65535;b[4821352]=N;return}function fIA(){var c=0,d=0,f=0,g=0;c=e[4821356]|0;d=-c|0;f=(a[9642744]&-16&255|d>>>12&8)&255;g=d&65535;a[9642744]=((c^d^d>>>1)>>>14&2|d>>>16&1|(g<<16>>16==0?f|4:f)&255)&255;b[4821356]=g;return}function fIB(){var c=0,d=0,e=0,f=0,g=0,h=0;c=b[4821356]|0;d=~c;b[4821356]=d;e=a[9642744]&-15;a[9642744]=e;f=(d&65535)>>>12&8|e&255;if(c<<16>>16!=-1){g=f&255;h=g|1;a[9642744]=h;return}g=(f|4)&255;h=g|1;a[9642744]=h;return}function fIC(){var c=0,d=0;c=a[9642712]&1|a[9642744]&-14;a[9642744]=c;d=(e[4821356]|0)>>>1;b[4821356]=d;if(d<<16>>16!=0){return}a[9642744]=c|4;return}function fID(){var c=0,d=0,e=0,f=0;c=a[9642744]|0;d=b[4821356]|0;e=(d&65535)>>>1|(c&255)<<15;f=c<<3&8|c&-14|d&1;a[9642744]=e<<16>>16==0?f|4:f;b[4821356]=e;return}function fIE(){var c=0,d=0,e=0,f=0,g=0;c=b[4821356]|0;d=c&1|a[9642744]&-14;a[9642744]=d;e=c&-32768|(c&65535)>>>1;b[4821356]=e;f=d&255|(c&65535)>>>12&8;if(e<<16>>16!=0){g=f&255;a[9642744]=g;return}g=(f|4)&255;a[9642744]=g;return}function fIF(){var c=0,d=0,f=0,g=0;c=e[4821356]|0;d=c<<1;f=(a[9642744]&-16&255|c>>>11&8)&255;g=d&65535;a[9642744]=((d^c)>>>14&2|c>>>15|(g<<16>>16==0?f|4:f)&255)&255;b[4821356]=g;return}function fIG(){var c=0,d=0,f=0,g=0,h=0;c=e[4821356]|0;d=a[9642744]|0;f=c<<1;g=(d&-16&255|c>>>11&8)&255;h=(d&1|f)&65535;a[9642744]=((f^c)>>>14&2|c>>>15|(h<<16>>16==0?g|4:g)&255)&255;b[4821356]=h;return}function fIH(){var c=0,d=0,f=0;c=(e[4821356]|0)-1|0;d=(c>>>12&8|a[9642744]&-16&255)&255;f=c&65535;a[9642744]=((c>>>1^c)>>>14&2|c>>>16&1|(f<<16>>16==0?d|4:d)&255)&255;b[4821356]=f;return}function fII(){var c=0,d=0,f=0;c=(e[4821356]|0)+1|0;d=(c>>>12&8|a[9642744]&-16&255)&255;f=c&65535;a[9642744]=((c>>>1^c)>>>14&2|c>>>16&1|(f<<16>>16==0?d|4:d)&255)&255;b[4821356]=f;return}function fIJ(){var c=0,d=0,e=0,f=0;c=a[9642744]&-15;a[9642744]=c;d=b[4821356]|0;e=(d&65535)>>>12&8|c&255;if(d<<16>>16!=0){f=e&255;a[9642744]=f;return}f=(e|4)&255;a[9642744]=f;return}function fIK(){b[4821356]=0;a[9642744]=a[9642744]&-16|4;return}function fIL(){var c=0,d=0,e=0,f=0,g=0,h=0;c=b[4821358]|0;d=~c;b[4821358]=d;e=a[9642744]&-15;a[9642744]=e;f=(d&65535)>>>12&8|e&255;if(c<<16>>16!=-1){g=f&255;h=g|1;a[9642744]=h;return}g=(f|4)&255;h=g|1;a[9642744]=h;return}function fIM(){var c=0,d=0;c=a[9642716]&1|a[9642744]&-14;a[9642744]=c;d=(e[4821358]|0)>>>1;b[4821358]=d;if(d<<16>>16!=0){return}a[9642744]=c|4;return}function fIN(){var c=0,d=0,e=0,f=0;c=a[9642744]|0;d=b[4821358]|0;e=(d&65535)>>>1|(c&255)<<15;f=c<<3&8|c&-14|d&1;a[9642744]=e<<16>>16==0?f|4:f;b[4821358]=e;return}function fIO(){var c=0,d=0,f=0,g=0,h=0;c=e[4821358]|0;d=a[9642744]|0;f=c<<1;g=(d&-16&255|c>>>11&8)&255;h=(d&1|f)&65535;a[9642744]=((f^c)>>>14&2|c>>>15|(h<<16>>16==0?g|4:g)&255)&255;b[4821358]=h;return}function fIP(){var c=0,d=0,f=0;c=(e[4821358]|0)-1|0;d=(c>>>12&8|a[9642744]&-16&255)&255;f=c&65535;a[9642744]=((c>>>1^c)>>>14&2|c>>>16&1|(f<<16>>16==0?d|4:d)&255)&255;b[4821358]=f;return}function fIQ(){var c=0,d=0,f=0;c=(e[4821358]|0)+1|0;d=(c>>>12&8|a[9642744]&-16&255)&255;f=c&65535;a[9642744]=((c>>>1^c)>>>14&2|c>>>16&1|(f<<16>>16==0?d|4:d)&255)&255;b[4821358]=f;return}function fIR(){var c=0,d=0,e=0,f=0;c=a[9642744]&-15;a[9642744]=c;d=b[4821358]|0;e=(d&65535)>>>12&8|c&255;if(d<<16>>16!=0){f=e&255;a[9642744]=f;return}f=(e|4)&255;a[9642744]=f;return}function fIS(){b[4821358]=0;a[9642744]=a[9642744]&-16|4;return}function fIT(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=c[2410676]|0;f=d&65535;g=c[3528552]|0;h=c[2433426]|0;i=c[h+(g*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((i|0)==0){j=c[h+(g*3160|0)+3144>>2]|0;if((j|0)==0){k=0;l=d;m=g;n=h;o=f;break}p=gj[j&4095](f)|0;j=c[2410676]|0;k=p;l=j;m=c[3528552]|0;n=c[2433426]|0;o=j&65535}else{k=a[i+(d&255)|0]|0;l=d;m=g;n=h;o=f}}while(0);f=(k&255)<<8;k=l+1|0;l=k&65535;h=c[n+(m*3160|0)+60+((k>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){g=c[n+(m*3160|0)+3144>>2]|0;if((g|0)==0){q=0;r=o;break}d=gj[g&4095](l)|0;q=d;r=b[4821352]|0}else{q=a[h+(k&255)|0]|0;r=o}}while(0);b[4821352]=r+2&65535;r=e[4821358]|0;o=r-(q&255|f)|0;q=(o>>>12&8|a[9642744]&-16&255)&255;k=o&65535;a[9642744]=((r^f^o^o>>>1)>>>14&2|o>>>16&1|(k<<16>>16==0?q|4:q)&255)&255;b[4821358]=k;return}function fIU(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=c[2410676]|0;f=d&65535;g=c[3528552]|0;h=c[2433426]|0;i=c[h+(g*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((i|0)==0){j=c[h+(g*3160|0)+3144>>2]|0;if((j|0)==0){k=0;l=d;m=g;n=h;o=f;break}p=gj[j&4095](f)|0;j=c[2410676]|0;k=p;l=j;m=c[3528552]|0;n=c[2433426]|0;o=j&65535}else{k=a[i+(d&255)|0]|0;l=d;m=g;n=h;o=f}}while(0);f=(k&255)<<8;k=l+1|0;l=k&65535;h=c[n+(m*3160|0)+60+((k>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){g=c[n+(m*3160|0)+3144>>2]|0;if((g|0)==0){q=0;r=o;break}d=gj[g&4095](l)|0;q=d;r=b[4821352]|0}else{q=a[h+(k&255)|0]|0;r=o}}while(0);b[4821352]=r+2&65535;r=e[4821358]|0;o=r-(q&255|f)|0;q=(o>>>12&8|a[9642744]&-16&255)&255;a[9642744]=((r^f^o^o>>>1)>>>14&2|o>>>16&1|((o&65535)<<16>>16==0?q|4:q)&255)&255;return}function fIV(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=(j&255)<<8;j=k+1|0;k=j&65535;g=c[m+(l*3160|0)+60+((j>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){f=c[m+(l*3160|0)+3144>>2]|0;if((f|0)==0){p=0;q=n;break}d=gj[f&4095](k)|0;p=d;q=b[4821352]|0}else{p=a[g+(j&255)|0]|0;q=n}}while(0);n=p&255|e;b[4821352]=q+2&65535;q=b[4821356]|0;e=a[9642744]|0;p=(q&65535)-(n&65535)-(e&1)|0;j=(p>>>12&8|e&-16&255)&255;e=p&65535;a[9642744]=((p^(q^n)&65535^p>>>1)>>>14&2|p>>>16&1|(e<<16>>16==0?j|4:j)&255)&255;b[4821356]=e;return}function fIW(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=c[2410676]|0;f=d&65535;g=c[3528552]|0;h=c[2433426]|0;i=c[h+(g*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((i|0)==0){j=c[h+(g*3160|0)+3144>>2]|0;if((j|0)==0){k=0;l=d;m=g;n=h;o=f;break}p=gj[j&4095](f)|0;j=c[2410676]|0;k=p;l=j;m=c[3528552]|0;n=c[2433426]|0;o=j&65535}else{k=a[i+(d&255)|0]|0;l=d;m=g;n=h;o=f}}while(0);f=(k&255)<<8;k=l+1|0;l=k&65535;h=c[n+(m*3160|0)+60+((k>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){g=c[n+(m*3160|0)+3144>>2]|0;if((g|0)==0){q=0;r=o;break}d=gj[g&4095](l)|0;q=d;r=b[4821352]|0}else{q=a[h+(k&255)|0]|0;r=o}}while(0);b[4821352]=r+2&65535;r=e[4821356]|0;o=r-(q&255|f)|0;q=(o>>>12&8|a[9642744]&-16&255)&255;a[9642744]=((r^f^o^o>>>1)>>>14&2|o>>>16&1|((o&65535)<<16>>16==0?q|4:q)&255)&255;return}function fIX(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=(j&255)<<8;j=k+1|0;k=j&65535;g=c[m+(l*3160|0)+60+((j>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){f=c[m+(l*3160|0)+3144>>2]|0;if((f|0)==0){p=0;q=n;break}d=gj[f&4095](k)|0;p=d;q=b[4821352]|0}else{p=a[g+(j&255)|0]|0;q=n}}while(0);b[4821352]=q+2&65535;q=b[4821356]&(p&255|e);b[4821356]=q;e=a[9642744]&-15;a[9642744]=e;p=(q&65535)>>>12&8|e&255;if(q<<16>>16!=0){r=p&255;a[9642744]=r;return}r=(p|4)&255;a[9642744]=r;return}function fIY(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=c[2410676]|0;f=e&65535;g=c[3528552]|0;h=c[2433426]|0;i=c[h+(g*3160|0)+60+((e>>>8&255|512)<<2)>>2]|0;do{if((i|0)==0){j=c[h+(g*3160|0)+3144>>2]|0;if((j|0)==0){k=0;l=e;m=g;n=h;o=f;break}p=gj[j&4095](f)|0;j=c[2410676]|0;k=p;l=j;m=c[3528552]|0;n=c[2433426]|0;o=j&65535}else{k=a[i+(e&255)|0]|0;l=e;m=g;n=h;o=f}}while(0);f=(k&255)<<8;k=l+1|0;l=k&65535;h=c[n+(m*3160|0)+60+((k>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){g=c[n+(m*3160|0)+3144>>2]|0;if((g|0)==0){q=0;r=o;break}e=gj[g&4095](l)|0;q=e;r=b[4821352]|0}else{q=a[h+(k&255)|0]|0;r=o}}while(0);b[4821352]=r+2&65535;r=a[9642744]&-15;a[9642744]=((d[9642712]|0)&(q&255|f))<<16>>16==0?r|4:r;return}function fIZ(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=(j&255)<<8;j=k+1|0;k=j&65535;g=c[m+(l*3160|0)+60+((j>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){f=c[m+(l*3160|0)+3144>>2]|0;if((f|0)==0){p=0;q=n;break}d=gj[f&4095](k)|0;p=d;q=b[4821352]|0}else{p=a[g+(j&255)|0]|0;q=n}}while(0);n=p&255|e;b[4821352]=q+2&65535;b[4821358]=n;q=a[9642744]&-15;a[9642744]=q;p=q&255|(e&65535)>>>12&8;if(n<<16>>16!=0){r=p&255;a[9642744]=r;return}r=(p|4)&255;a[9642744]=r;return}function fI_(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=(j&255)<<8;j=k+1|0;k=j&65535;g=c[m+(l*3160|0)+60+((j>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){f=c[m+(l*3160|0)+3144>>2]|0;if((f|0)==0){p=0;q=n;break}d=gj[f&4095](k)|0;p=d;q=b[4821352]|0}else{p=a[g+(j&255)|0]|0;q=n}}while(0);n=p&255|e;b[4821352]=q+2&65535;q=b[4821356]|0;e=q^n;b[4821356]=e;p=a[9642744]&-15;a[9642744]=p;j=(e&65535)>>>12&8|p&255;if(q<<16>>16!=n<<16>>16){r=j&255;a[9642744]=r;return}r=(j|4)&255;a[9642744]=r;return}function fI$(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=(j&255)<<8;j=k+1|0;k=j&65535;g=c[m+(l*3160|0)+60+((j>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){f=c[m+(l*3160|0)+3144>>2]|0;if((f|0)==0){p=0;q=n;break}d=gj[f&4095](k)|0;p=d;q=b[4821352]|0}else{p=a[g+(j&255)|0]|0;q=n}}while(0);n=p&255|e;b[4821352]=q+2&65535;q=b[4821356]|0;e=a[9642744]|0;p=(q&65535)+(n&65535)+(e&1)|0;j=(p>>>12&8|e&-16&255)&255;e=p&65535;a[9642744]=((p^(q^n)&65535^p>>>1)>>>14&2|p>>>16&1|(e<<16>>16==0?j|4:j)&255)&255;b[4821356]=e;return}function fI0(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=(j&255)<<8;j=k+1|0;k=j&65535;g=c[m+(l*3160|0)+60+((j>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){f=c[m+(l*3160|0)+3144>>2]|0;if((f|0)==0){p=0;q=n;break}d=gj[f&4095](k)|0;p=d;q=b[4821352]|0}else{p=a[g+(j&255)|0]|0;q=n}}while(0);b[4821352]=q+2&65535;q=p&255|e|b[4821356];b[4821356]=q;e=a[9642744]&-15;a[9642744]=e;p=(q&65535)>>>12&8|e&255;if(q<<16>>16!=0){r=p&255;a[9642744]=r;return}r=(p|4)&255;a[9642744]=r;return}function fI1(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=c[2410676]|0;f=d&65535;g=c[3528552]|0;h=c[2433426]|0;i=c[h+(g*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((i|0)==0){j=c[h+(g*3160|0)+3144>>2]|0;if((j|0)==0){k=0;l=d;m=g;n=h;o=f;break}p=gj[j&4095](f)|0;j=c[2410676]|0;k=p;l=j;m=c[3528552]|0;n=c[2433426]|0;o=j&65535}else{k=a[i+(d&255)|0]|0;l=d;m=g;n=h;o=f}}while(0);f=(k&255)<<8;k=l+1|0;l=k&65535;h=c[n+(m*3160|0)+60+((k>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){g=c[n+(m*3160|0)+3144>>2]|0;if((g|0)==0){q=0;r=o;break}d=gj[g&4095](l)|0;q=d;r=b[4821352]|0}else{q=a[h+(k&255)|0]|0;r=o}}while(0);b[4821352]=r+2&65535;r=e[4821358]|0;o=r+(q&255|f)|0;q=(o>>>12&8|a[9642744]&-16&255)&255;k=o&65535;a[9642744]=((r^f^o^o>>>1)>>>14&2|o>>>16&1|(k<<16>>16==0?q|4:q)&255)&255;b[4821358]=k;return}function fI2(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=c[2410676]|0;f=d&65535;g=c[3528552]|0;h=c[2433426]|0;i=c[h+(g*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((i|0)==0){j=c[h+(g*3160|0)+3144>>2]|0;if((j|0)==0){k=0;l=d;m=g;n=h;o=f;break}p=gj[j&4095](f)|0;j=c[2410676]|0;k=p;l=j;m=c[3528552]|0;n=c[2433426]|0;o=j&65535}else{k=a[i+(d&255)|0]|0;l=d;m=g;n=h;o=f}}while(0);f=(k&255)<<8;k=l+1|0;l=k&65535;h=c[n+(m*3160|0)+60+((k>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){g=c[n+(m*3160|0)+3144>>2]|0;if((g|0)==0){q=0;r=o;break}d=gj[g&4095](l)|0;q=d;r=b[4821352]|0}else{q=a[h+(k&255)|0]|0;r=o}}while(0);b[4821352]=r+2&65535;r=e[4821368]|0;o=r-(q&255|f)|0;q=(o>>>12&8|a[9642744]&-16&255)&255;a[9642744]=((r^f^o^o>>>1)>>>14&2|o>>>16&1|((o&65535)<<16>>16==0?q|4:q)&255)&255;return}function fI3(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=j&255;j=e<<8;g=k+1|0;k=g&65535;f=c[m+(l*3160|0)+60+((g>>>8&255|512)<<2)>>2]|0;do{if((f|0)==0){d=c[m+(l*3160|0)+3144>>2]|0;if((d|0)==0){p=0;q=n;break}h=gj[d&4095](k)|0;p=h;q=b[4821352]|0}else{p=a[f+(g&255)|0]|0;q=n}}while(0);n=p&255|j;c[2410684]=n;b[4821352]=q+2&65535;q=a[9642744]&-15;a[9642744]=q;j=q&255|e>>>4&8;if((n|0)!=0){r=j&255;a[9642744]=r;return}r=(j|4)&255;a[9642744]=r;return}function fI4(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;c[2426872]=c[2410680];d=c[2410676]|0;f=d&65535;g=c[3528552]|0;h=c[2433426]|0;i=c[h+(g*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((i|0)==0){j=c[h+(g*3160|0)+3144>>2]|0;if((j|0)==0){k=0;l=f;m=g;n=h;break}o=gj[j&4095](f)|0;k=o;l=b[4821352]|0;m=c[3528552]|0;n=c[2433426]|0}else{k=a[i+(d&255)|0]|0;l=f;m=g;n=h}}while(0);a[9707488]=k;b[4821352]=l+1&65535;l=c[2426872]|0;k=l&65535;h=c[n+(m*3160|0)+60+((l>>>8&255)<<2)>>2]|0;do{if((h|0)==0){g=c[n+(m*3160|0)+3132>>2]|0;if((g|0)==0){p=0;q=m;r=n;break}f=gj[g&4095](k)|0;p=f;q=c[3528552]|0;r=c[2433426]|0}else{p=a[h+(l&255)|0]|0;q=m;r=n}}while(0);n=(p&255)<<8;p=l+1|0;l=p&65535;m=c[r+(q*3160|0)+60+((p>>>8&255)<<2)>>2]|0;do{if((m|0)==0){h=c[r+(q*3160|0)+3132>>2]|0;if((h|0)==0){s=0;break}s=gj[h&4095](l)|0}else{s=a[m+(p&255)|0]|0}}while(0);p=e[4821358]|0;m=p-(s&255|n)|0;s=(m>>>12&8|a[9642744]&-16&255)&255;l=m&65535;a[9642744]=((p^n^m^m>>>1)>>>14&2|m>>>16&1|(l<<16>>16==0?s|4:s)&255)&255;b[4821358]=l;return}function fI5(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;c[2426872]=c[2410680];d=c[2410676]|0;f=d&65535;g=c[3528552]|0;h=c[2433426]|0;i=c[h+(g*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((i|0)==0){j=c[h+(g*3160|0)+3144>>2]|0;if((j|0)==0){k=0;l=f;m=g;n=h;break}o=gj[j&4095](f)|0;k=o;l=b[4821352]|0;m=c[3528552]|0;n=c[2433426]|0}else{k=a[i+(d&255)|0]|0;l=f;m=g;n=h}}while(0);a[9707488]=k;b[4821352]=l+1&65535;l=c[2426872]|0;k=l&65535;h=c[n+(m*3160|0)+60+((l>>>8&255)<<2)>>2]|0;do{if((h|0)==0){g=c[n+(m*3160|0)+3132>>2]|0;if((g|0)==0){p=0;q=m;r=n;break}f=gj[g&4095](k)|0;p=f;q=c[3528552]|0;r=c[2433426]|0}else{p=a[h+(l&255)|0]|0;q=m;r=n}}while(0);n=(p&255)<<8;p=l+1|0;l=p&65535;m=c[r+(q*3160|0)+60+((p>>>8&255)<<2)>>2]|0;do{if((m|0)==0){h=c[r+(q*3160|0)+3132>>2]|0;if((h|0)==0){s=0;break}s=gj[h&4095](l)|0}else{s=a[m+(p&255)|0]|0}}while(0);p=e[4821358]|0;m=p-(s&255|n)|0;s=(m>>>12&8|a[9642744]&-16&255)&255;a[9642744]=((p^n^m^m>>>1)>>>14&2|m>>>16&1|((m&65535)<<16>>16==0?s|4:s)&255)&255;return}function fI6(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;c[2426872]=c[2410680];d=c[2410676]|0;f=d&65535;g=c[3528552]|0;h=c[2433426]|0;i=c[h+(g*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((i|0)==0){j=c[h+(g*3160|0)+3144>>2]|0;if((j|0)==0){k=0;l=f;m=g;n=h;break}o=gj[j&4095](f)|0;k=o;l=b[4821352]|0;m=c[3528552]|0;n=c[2433426]|0}else{k=a[i+(d&255)|0]|0;l=f;m=g;n=h}}while(0);a[9707488]=k;b[4821352]=l+1&65535;l=c[2426872]|0;k=l&65535;h=c[n+(m*3160|0)+60+((l>>>8&255)<<2)>>2]|0;do{if((h|0)==0){g=c[n+(m*3160|0)+3132>>2]|0;if((g|0)==0){p=0;q=m;r=n;break}f=gj[g&4095](k)|0;p=f;q=c[3528552]|0;r=c[2433426]|0}else{p=a[h+(l&255)|0]|0;q=m;r=n}}while(0);n=(p&255)<<8;p=l+1|0;l=p&65535;m=c[r+(q*3160|0)+60+((p>>>8&255)<<2)>>2]|0;do{if((m|0)==0){h=c[r+(q*3160|0)+3132>>2]|0;if((h|0)==0){s=0;break}s=gj[h&4095](l)|0}else{s=a[m+(p&255)|0]|0}}while(0);p=e[4821356]|0;m=a[9642744]|0;l=p-(s&255|n)-(m&1)|0;s=(l>>>12&8|m&-16&255)&255;m=l&65535;a[9642744]=((p^n^l^l>>>1)>>>14&2|l>>>16&1|(m<<16>>16==0?s|4:s)&255)&255;b[4821356]=m;return}function fI7(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;c[2426872]=c[2410680];d=c[2410676]|0;f=d&65535;g=c[3528552]|0;h=c[2433426]|0;i=c[h+(g*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((i|0)==0){j=c[h+(g*3160|0)+3144>>2]|0;if((j|0)==0){k=0;l=f;m=g;n=h;break}o=gj[j&4095](f)|0;k=o;l=b[4821352]|0;m=c[3528552]|0;n=c[2433426]|0}else{k=a[i+(d&255)|0]|0;l=f;m=g;n=h}}while(0);a[9707488]=k;b[4821352]=l+1&65535;l=c[2426872]|0;k=l&65535;h=c[n+(m*3160|0)+60+((l>>>8&255)<<2)>>2]|0;do{if((h|0)==0){g=c[n+(m*3160|0)+3132>>2]|0;if((g|0)==0){p=0;q=m;r=n;break}f=gj[g&4095](k)|0;p=f;q=c[3528552]|0;r=c[2433426]|0}else{p=a[h+(l&255)|0]|0;q=m;r=n}}while(0);n=(p&255)<<8;p=l+1|0;l=p&65535;m=c[r+(q*3160|0)+60+((p>>>8&255)<<2)>>2]|0;do{if((m|0)==0){h=c[r+(q*3160|0)+3132>>2]|0;if((h|0)==0){s=0;break}s=gj[h&4095](l)|0}else{s=a[m+(p&255)|0]|0}}while(0);p=e[4821356]|0;m=p-(s&255|n)|0;s=(m>>>12&8|a[9642744]&-16&255)&255;a[9642744]=((p^n^m^m>>>1)>>>14&2|m>>>16&1|((m&65535)<<16>>16==0?s|4:s)&255)&255;return}function fI8(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;c[2426872]=c[2410680];d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;l=f;m=g;break}n=gj[i&4095](e)|0;j=n;k=b[4821352]|0;l=c[3528552]|0;m=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=e;l=f;m=g}}while(0);a[9707488]=j;b[4821352]=k+1&65535;k=c[2426872]|0;j=k&65535;g=c[m+(l*3160|0)+60+((k>>>8&255)<<2)>>2]|0;do{if((g|0)==0){f=c[m+(l*3160|0)+3132>>2]|0;if((f|0)==0){o=0;p=l;q=m;break}e=gj[f&4095](j)|0;o=e;p=c[3528552]|0;q=c[2433426]|0}else{o=a[g+(k&255)|0]|0;p=l;q=m}}while(0);m=(o&255)<<8;o=k+1|0;k=o&65535;l=c[q+(p*3160|0)+60+((o>>>8&255)<<2)>>2]|0;do{if((l|0)==0){g=c[q+(p*3160|0)+3132>>2]|0;if((g|0)==0){r=0;break}r=gj[g&4095](k)|0}else{r=a[l+(o&255)|0]|0}}while(0);o=(r&255|m)&b[4821356];b[4821356]=o;m=a[9642744]&-15;a[9642744]=m;r=(o&65535)>>>12&8|m&255;if(o<<16>>16!=0){s=r&255;a[9642744]=s;return}s=(r|4)&255;a[9642744]=s;return}function fI9(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;c[2426872]=c[2410680];e=c[2410676]|0;f=e&65535;g=c[3528552]|0;h=c[2433426]|0;i=c[h+(g*3160|0)+60+((e>>>8&255|512)<<2)>>2]|0;do{if((i|0)==0){j=c[h+(g*3160|0)+3144>>2]|0;if((j|0)==0){k=0;l=f;m=g;n=h;break}o=gj[j&4095](f)|0;k=o;l=b[4821352]|0;m=c[3528552]|0;n=c[2433426]|0}else{k=a[i+(e&255)|0]|0;l=f;m=g;n=h}}while(0);a[9707488]=k;b[4821352]=l+1&65535;l=c[2426872]|0;k=l&65535;h=c[n+(m*3160|0)+60+((l>>>8&255)<<2)>>2]|0;do{if((h|0)==0){g=c[n+(m*3160|0)+3132>>2]|0;if((g|0)==0){p=0;q=m;r=n;break}f=gj[g&4095](k)|0;p=f;q=c[3528552]|0;r=c[2433426]|0}else{p=a[h+(l&255)|0]|0;q=m;r=n}}while(0);n=(p&255)<<8;p=l+1|0;l=p&65535;m=c[r+(q*3160|0)+60+((p>>>8&255)<<2)>>2]|0;do{if((m|0)==0){h=c[r+(q*3160|0)+3132>>2]|0;if((h|0)==0){s=0;break}s=gj[h&4095](l)|0}else{s=a[m+(p&255)|0]|0}}while(0);p=a[9642744]&-15;a[9642744]=((d[9642712]|0)&(s&255|n)|0)==0?p|4:p;return}function fJa(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;c[2426872]=c[2410680];d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;l=f;m=g;break}n=gj[i&4095](e)|0;j=n;k=b[4821352]|0;l=c[3528552]|0;m=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=e;l=f;m=g}}while(0);a[9707488]=j;b[4821352]=k+1&65535;k=c[2426872]|0;j=k&65535;g=c[m+(l*3160|0)+60+((k>>>8&255)<<2)>>2]|0;do{if((g|0)==0){f=c[m+(l*3160|0)+3132>>2]|0;if((f|0)==0){o=0;p=l;q=m;break}e=gj[f&4095](j)|0;o=e;p=c[3528552]|0;q=c[2433426]|0}else{o=a[g+(k&255)|0]|0;p=l;q=m}}while(0);m=(o&255)<<8;o=k+1|0;k=o&65535;l=c[q+(p*3160|0)+60+((o>>>8&255)<<2)>>2]|0;do{if((l|0)==0){g=c[q+(p*3160|0)+3132>>2]|0;if((g|0)==0){r=0;break}r=gj[g&4095](k)|0}else{r=a[l+(o&255)|0]|0}}while(0);o=r&255|m;b[4821358]=o;r=a[9642744]&-15;a[9642744]=r;l=r&255|(m&65535)>>>12&8;if(o<<16>>16!=0){s=l&255;a[9642744]=s;return}s=(l|4)&255;a[9642744]=s;return}function fJb(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=a[9642744]&-15;a[9642744]=d;e=b[4821358]|0;f=(e&65535)>>>12&8|d&255;if(e<<16>>16==0){g=(f|4)&255}else{g=f&255}a[9642744]=g;c[2426872]=c[2410680];g=c[2410676]|0;f=g&65535;e=c[3528552]|0;d=c[2433426]|0;h=c[d+(e*3160|0)+60+((g>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[d+(e*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=f;l=e;m=d;break}n=gj[i&4095](f)|0;j=n;k=b[4821352]|0;l=c[3528552]|0;m=c[2433426]|0}else{j=a[h+(g&255)|0]|0;k=f;l=e;m=d}}while(0);a[9707488]=j;b[4821352]=k+1&65535;k=c[2426872]|0;j=k&65535;d=a[9642717]|0;e=c[m+(l*3160|0)+60+((k>>>8&255|256)<<2)>>2]|0;do{if((e|0)==0){f=c[m+(l*3160|0)+3136>>2]|0;if((f|0)==0){o=l;p=m;break}gg[f&4095](j,d);o=c[3528552]|0;p=c[2433426]|0}else{a[e+(k&255)|0]=d;o=l;p=m}}while(0);m=k+1|0;k=a[9642716]|0;l=c[p+(o*3160|0)+60+((m>>>8&255|256)<<2)>>2]|0;if((l|0)!=0){a[l+(m&255)|0]=k;return}l=c[p+(o*3160|0)+3136>>2]|0;if((l|0)==0){return}gg[l&4095](m&65535,k);return}function fJc(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;c[2426872]=c[2410680];d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;l=f;m=g;break}n=gj[i&4095](e)|0;j=n;k=b[4821352]|0;l=c[3528552]|0;m=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=e;l=f;m=g}}while(0);a[9707488]=j;b[4821352]=k+1&65535;k=c[2426872]|0;j=k&65535;g=c[m+(l*3160|0)+60+((k>>>8&255)<<2)>>2]|0;do{if((g|0)==0){f=c[m+(l*3160|0)+3132>>2]|0;if((f|0)==0){o=0;p=l;q=m;break}e=gj[f&4095](j)|0;o=e;p=c[3528552]|0;q=c[2433426]|0}else{o=a[g+(k&255)|0]|0;p=l;q=m}}while(0);m=(o&255)<<8;o=k+1|0;k=o&65535;l=c[q+(p*3160|0)+60+((o>>>8&255)<<2)>>2]|0;do{if((l|0)==0){g=c[q+(p*3160|0)+3132>>2]|0;if((g|0)==0){r=0;break}r=gj[g&4095](k)|0}else{r=a[l+(o&255)|0]|0}}while(0);o=r&255|m;m=b[4821356]|0;r=o^m;b[4821356]=r;l=a[9642744]&-15;a[9642744]=l;k=(r&65535)>>>12&8|l&255;if(o<<16>>16!=m<<16>>16){s=k&255;a[9642744]=s;return}s=(k|4)&255;a[9642744]=s;return}function fJd(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;c[2426872]=c[2410680];d=c[2410676]|0;f=d&65535;g=c[3528552]|0;h=c[2433426]|0;i=c[h+(g*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((i|0)==0){j=c[h+(g*3160|0)+3144>>2]|0;if((j|0)==0){k=0;l=f;m=g;n=h;break}o=gj[j&4095](f)|0;k=o;l=b[4821352]|0;m=c[3528552]|0;n=c[2433426]|0}else{k=a[i+(d&255)|0]|0;l=f;m=g;n=h}}while(0);a[9707488]=k;b[4821352]=l+1&65535;l=c[2426872]|0;k=l&65535;h=c[n+(m*3160|0)+60+((l>>>8&255)<<2)>>2]|0;do{if((h|0)==0){g=c[n+(m*3160|0)+3132>>2]|0;if((g|0)==0){p=0;q=m;r=n;break}f=gj[g&4095](k)|0;p=f;q=c[3528552]|0;r=c[2433426]|0}else{p=a[h+(l&255)|0]|0;q=m;r=n}}while(0);n=(p&255)<<8;p=l+1|0;l=p&65535;m=c[r+(q*3160|0)+60+((p>>>8&255)<<2)>>2]|0;do{if((m|0)==0){h=c[r+(q*3160|0)+3132>>2]|0;if((h|0)==0){s=0;break}s=gj[h&4095](l)|0}else{s=a[m+(p&255)|0]|0}}while(0);p=e[4821356]|0;m=a[9642744]|0;l=p+(s&255|n)+(m&1)|0;s=(l>>>12&8|m&-16&255)&255;m=l&65535;a[9642744]=((p^n^l^l>>>1)>>>14&2|l>>>16&1|(m<<16>>16==0?s|4:s)&255)&255;b[4821356]=m;return}function fJe(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;c[2426872]=c[2410680];d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;l=f;m=g;break}n=gj[i&4095](e)|0;j=n;k=b[4821352]|0;l=c[3528552]|0;m=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=e;l=f;m=g}}while(0);a[9707488]=j;b[4821352]=k+1&65535;k=c[2426872]|0;j=k&65535;g=c[m+(l*3160|0)+60+((k>>>8&255)<<2)>>2]|0;do{if((g|0)==0){f=c[m+(l*3160|0)+3132>>2]|0;if((f|0)==0){o=0;p=l;q=m;break}e=gj[f&4095](j)|0;o=e;p=c[3528552]|0;q=c[2433426]|0}else{o=a[g+(k&255)|0]|0;p=l;q=m}}while(0);m=(o&255)<<8;o=k+1|0;k=o&65535;l=c[q+(p*3160|0)+60+((o>>>8&255)<<2)>>2]|0;do{if((l|0)==0){g=c[q+(p*3160|0)+3132>>2]|0;if((g|0)==0){r=0;break}r=gj[g&4095](k)|0}else{r=a[l+(o&255)|0]|0}}while(0);o=r&255|m|b[4821356];b[4821356]=o;m=a[9642744]&-15;a[9642744]=m;r=(o&65535)>>>12&8|m&255;if(o<<16>>16!=0){s=r&255;a[9642744]=s;return}s=(r|4)&255;a[9642744]=s;return}function fJf(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;c[2426872]=c[2410680];d=c[2410676]|0;f=d&65535;g=c[3528552]|0;h=c[2433426]|0;i=c[h+(g*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((i|0)==0){j=c[h+(g*3160|0)+3144>>2]|0;if((j|0)==0){k=0;l=f;m=g;n=h;break}o=gj[j&4095](f)|0;k=o;l=b[4821352]|0;m=c[3528552]|0;n=c[2433426]|0}else{k=a[i+(d&255)|0]|0;l=f;m=g;n=h}}while(0);a[9707488]=k;b[4821352]=l+1&65535;l=c[2426872]|0;k=l&65535;h=c[n+(m*3160|0)+60+((l>>>8&255)<<2)>>2]|0;do{if((h|0)==0){g=c[n+(m*3160|0)+3132>>2]|0;if((g|0)==0){p=0;q=m;r=n;break}f=gj[g&4095](k)|0;p=f;q=c[3528552]|0;r=c[2433426]|0}else{p=a[h+(l&255)|0]|0;q=m;r=n}}while(0);n=(p&255)<<8;p=l+1|0;l=p&65535;m=c[r+(q*3160|0)+60+((p>>>8&255)<<2)>>2]|0;do{if((m|0)==0){h=c[r+(q*3160|0)+3132>>2]|0;if((h|0)==0){s=0;break}s=gj[h&4095](l)|0}else{s=a[m+(p&255)|0]|0}}while(0);p=e[4821358]|0;m=p+(s&255|n)|0;s=(m>>>12&8|a[9642744]&-16&255)&255;l=m&65535;a[9642744]=((p^n^m^m>>>1)>>>14&2|m>>>16&1|(l<<16>>16==0?s|4:s)&255)&255;b[4821358]=l;return}function fJg(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;c[2426872]=c[2410680];d=c[2410676]|0;f=d&65535;g=c[3528552]|0;h=c[2433426]|0;i=c[h+(g*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((i|0)==0){j=c[h+(g*3160|0)+3144>>2]|0;if((j|0)==0){k=0;l=f;m=g;n=h;break}o=gj[j&4095](f)|0;k=o;l=b[4821352]|0;m=c[3528552]|0;n=c[2433426]|0}else{k=a[i+(d&255)|0]|0;l=f;m=g;n=h}}while(0);a[9707488]=k;b[4821352]=l+1&65535;l=c[2426872]|0;k=l&65535;h=c[n+(m*3160|0)+60+((l>>>8&255)<<2)>>2]|0;do{if((h|0)==0){g=c[n+(m*3160|0)+3132>>2]|0;if((g|0)==0){p=0;q=m;r=n;break}f=gj[g&4095](k)|0;p=f;q=c[3528552]|0;r=c[2433426]|0}else{p=a[h+(l&255)|0]|0;q=m;r=n}}while(0);n=(p&255)<<8;p=l+1|0;l=p&65535;m=c[r+(q*3160|0)+60+((p>>>8&255)<<2)>>2]|0;do{if((m|0)==0){h=c[r+(q*3160|0)+3132>>2]|0;if((h|0)==0){s=0;break}s=gj[h&4095](l)|0}else{s=a[m+(p&255)|0]|0}}while(0);p=e[4821368]|0;m=p-(s&255|n)|0;s=(m>>>12&8|a[9642744]&-16&255)&255;a[9642744]=((p^n^m^m>>>1)>>>14&2|m>>>16&1|((m&65535)<<16>>16==0?s|4:s)&255)&255;return}function fJh(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;c[2426872]=c[2410680];d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;l=f;m=g;break}n=gj[i&4095](e)|0;j=n;k=b[4821352]|0;l=c[3528552]|0;m=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=e;l=f;m=g}}while(0);a[9707488]=j;b[4821352]=k+1&65535;k=c[2426872]|0;j=k&65535;g=c[m+(l*3160|0)+60+((k>>>8&255)<<2)>>2]|0;do{if((g|0)==0){f=c[m+(l*3160|0)+3132>>2]|0;if((f|0)==0){o=0;p=l;q=m;break}e=gj[f&4095](j)|0;o=e;p=c[3528552]|0;q=c[2433426]|0}else{o=a[g+(k&255)|0]|0;p=l;q=m}}while(0);m=o&255;o=m<<8;l=k+1|0;k=l&65535;g=c[q+(p*3160|0)+60+((l>>>8&255)<<2)>>2]|0;do{if((g|0)==0){j=c[q+(p*3160|0)+3132>>2]|0;if((j|0)==0){r=0;break}r=gj[j&4095](k)|0}else{r=a[g+(l&255)|0]|0}}while(0);l=r&255|o;c[2410684]=l;o=a[9642744]&-15;a[9642744]=o;r=o&255|m>>>4&8;if((l|0)!=0){s=r&255;a[9642744]=s;return}s=(r|4)&255;a[9642744]=s;return}function fJi(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=a[9642744]&-15;a[9642744]=d;e=b[4821368]|0;f=(e&65535)>>>12&8|d&255;if(e<<16>>16==0){g=(f|4)&255}else{g=f&255}a[9642744]=g;c[2426872]=c[2410680];g=c[2410676]|0;f=g&65535;e=c[3528552]|0;d=c[2433426]|0;h=c[d+(e*3160|0)+60+((g>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[d+(e*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=f;l=e;m=d;break}n=gj[i&4095](f)|0;j=n;k=b[4821352]|0;l=c[3528552]|0;m=c[2433426]|0}else{j=a[h+(g&255)|0]|0;k=f;l=e;m=d}}while(0);a[9707488]=j;b[4821352]=k+1&65535;k=c[2426872]|0;j=k&65535;d=a[9642737]|0;e=c[m+(l*3160|0)+60+((k>>>8&255|256)<<2)>>2]|0;do{if((e|0)==0){f=c[m+(l*3160|0)+3136>>2]|0;if((f|0)==0){o=l;p=m;break}gg[f&4095](j,d);o=c[3528552]|0;p=c[2433426]|0}else{a[e+(k&255)|0]=d;o=l;p=m}}while(0);m=k+1|0;k=a[9642736]|0;l=c[p+(o*3160|0)+60+((m>>>8&255|256)<<2)>>2]|0;if((l|0)!=0){a[l+(m&255)|0]=k;return}l=c[p+(o*3160|0)+3136>>2]|0;if((l|0)==0){return}gg[l&4095](m&65535,k);return}function fJj(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;fGP();d=c[2426872]|0;f=d&65535;g=c[3528552]|0;h=c[2433426]|0;i=c[h+(g*3160|0)+60+((d>>>8&255)<<2)>>2]|0;do{if((i|0)==0){j=c[h+(g*3160|0)+3132>>2]|0;if((j|0)==0){k=0;l=g;m=h;break}n=gj[j&4095](f)|0;k=n;l=c[3528552]|0;m=c[2433426]|0}else{k=a[i+(d&255)|0]|0;l=g;m=h}}while(0);h=(k&255)<<8;k=d+1|0;d=k&65535;g=c[m+(l*3160|0)+60+((k>>>8&255)<<2)>>2]|0;do{if((g|0)==0){i=c[m+(l*3160|0)+3132>>2]|0;if((i|0)==0){o=0;break}o=gj[i&4095](d)|0}else{o=a[g+(k&255)|0]|0}}while(0);k=e[4821358]|0;g=k-(o&255|h)|0;o=(g>>>12&8|a[9642744]&-16&255)&255;d=g&65535;a[9642744]=((k^h^g^g>>>1)>>>14&2|g>>>16&1|(d<<16>>16==0?o|4:o)&255)&255;b[4821358]=d;return}function fJk(){var b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;fGP();b=c[2426872]|0;d=b&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((b>>>8&255)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3132>>2]|0;if((i|0)==0){j=0;k=f;l=g;break}m=gj[i&4095](d)|0;j=m;k=c[3528552]|0;l=c[2433426]|0}else{j=a[h+(b&255)|0]|0;k=f;l=g}}while(0);g=(j&255)<<8;j=b+1|0;b=j&65535;f=c[l+(k*3160|0)+60+((j>>>8&255)<<2)>>2]|0;do{if((f|0)==0){h=c[l+(k*3160|0)+3132>>2]|0;if((h|0)==0){n=0;break}n=gj[h&4095](b)|0}else{n=a[f+(j&255)|0]|0}}while(0);j=e[4821358]|0;f=j-(n&255|g)|0;n=(f>>>12&8|a[9642744]&-16&255)&255;a[9642744]=((j^g^f^f>>>1)>>>14&2|f>>>16&1|((f&65535)<<16>>16==0?n|4:n)&255)&255;return}function fJl(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;fGP();d=c[2426872]|0;f=d&65535;g=c[3528552]|0;h=c[2433426]|0;i=c[h+(g*3160|0)+60+((d>>>8&255)<<2)>>2]|0;do{if((i|0)==0){j=c[h+(g*3160|0)+3132>>2]|0;if((j|0)==0){k=0;l=g;m=h;break}n=gj[j&4095](f)|0;k=n;l=c[3528552]|0;m=c[2433426]|0}else{k=a[i+(d&255)|0]|0;l=g;m=h}}while(0);h=(k&255)<<8;k=d+1|0;d=k&65535;g=c[m+(l*3160|0)+60+((k>>>8&255)<<2)>>2]|0;do{if((g|0)==0){i=c[m+(l*3160|0)+3132>>2]|0;if((i|0)==0){o=0;break}o=gj[i&4095](d)|0}else{o=a[g+(k&255)|0]|0}}while(0);k=e[4821356]|0;g=a[9642744]|0;d=k-(o&255|h)-(g&1)|0;o=(d>>>12&8|g&-16&255)&255;g=d&65535;a[9642744]=((k^h^d^d>>>1)>>>14&2|d>>>16&1|(g<<16>>16==0?o|4:o)&255)&255;b[4821356]=g;return}function fJm(){var b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;fGP();b=c[2426872]|0;d=b&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((b>>>8&255)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3132>>2]|0;if((i|0)==0){j=0;k=f;l=g;break}m=gj[i&4095](d)|0;j=m;k=c[3528552]|0;l=c[2433426]|0}else{j=a[h+(b&255)|0]|0;k=f;l=g}}while(0);g=(j&255)<<8;j=b+1|0;b=j&65535;f=c[l+(k*3160|0)+60+((j>>>8&255)<<2)>>2]|0;do{if((f|0)==0){h=c[l+(k*3160|0)+3132>>2]|0;if((h|0)==0){n=0;break}n=gj[h&4095](b)|0}else{n=a[f+(j&255)|0]|0}}while(0);j=e[4821356]|0;f=j-(n&255|g)|0;n=(f>>>12&8|a[9642744]&-16&255)&255;a[9642744]=((j^g^f^f>>>1)>>>14&2|f>>>16&1|((f&65535)<<16>>16==0?n|4:n)&255)&255;return}function fJn(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;fGP();d=c[2426872]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3132>>2]|0;if((i|0)==0){j=0;k=f;l=g;break}m=gj[i&4095](e)|0;j=m;k=c[3528552]|0;l=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=f;l=g}}while(0);g=(j&255)<<8;j=d+1|0;d=j&65535;f=c[l+(k*3160|0)+60+((j>>>8&255)<<2)>>2]|0;do{if((f|0)==0){h=c[l+(k*3160|0)+3132>>2]|0;if((h|0)==0){n=0;break}n=gj[h&4095](d)|0}else{n=a[f+(j&255)|0]|0}}while(0);j=(n&255|g)&b[4821356];b[4821356]=j;g=a[9642744]&-15;a[9642744]=g;n=(j&65535)>>>12&8|g&255;if(j<<16>>16!=0){o=n&255;a[9642744]=o;return}o=(n|4)&255;a[9642744]=o;return}function fJo(){var b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;fGP();b=e[4821356]|0;d=c[2426872]|0;f=d&65535;g=c[3528552]|0;h=c[2433426]|0;i=c[h+(g*3160|0)+60+((d>>>8&255)<<2)>>2]|0;do{if((i|0)==0){j=c[h+(g*3160|0)+3132>>2]|0;if((j|0)==0){k=0;l=g;m=h;break}n=gj[j&4095](f)|0;k=n;l=c[3528552]|0;m=c[2433426]|0}else{k=a[i+(d&255)|0]|0;l=g;m=h}}while(0);h=(k&255)<<8;k=d+1|0;d=k&65535;g=c[m+(l*3160|0)+60+((k>>>8&255)<<2)>>2]|0;do{if((g|0)==0){i=c[m+(l*3160|0)+3132>>2]|0;if((i|0)==0){o=0;break}o=gj[i&4095](d)|0}else{o=a[g+(k&255)|0]|0}}while(0);k=(o&255|h)&b;b=(k>>>12&8|a[9642744]&-15&255)&255;a[9642744]=(k|0)==0?b|4:b;return}function fJp(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;fGP();d=c[2426872]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3132>>2]|0;if((i|0)==0){j=0;k=f;l=g;break}m=gj[i&4095](e)|0;j=m;k=c[3528552]|0;l=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=f;l=g}}while(0);g=(j&255)<<8;j=d+1|0;d=j&65535;f=c[l+(k*3160|0)+60+((j>>>8&255)<<2)>>2]|0;do{if((f|0)==0){h=c[l+(k*3160|0)+3132>>2]|0;if((h|0)==0){n=0;break}n=gj[h&4095](d)|0}else{n=a[f+(j&255)|0]|0}}while(0);j=n&255|g;b[4821358]=j;n=a[9642744]&-15;a[9642744]=n;f=n&255|(g&65535)>>>12&8;if(j<<16>>16!=0){o=f&255;a[9642744]=o;return}o=(f|4)&255;a[9642744]=o;return}function fJq(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;fGP();d=a[9642744]&-15;a[9642744]=d;e=b[4821358]|0;f=(e&65535)>>>12&8|d&255;if(e<<16>>16==0){g=(f|4)&255}else{g=f&255}a[9642744]=g;g=c[2426872]|0;f=g&65535;e=a[9642717]|0;d=c[3528552]|0;h=c[2433426]|0;i=c[h+(d*3160|0)+60+((g>>>8&255|256)<<2)>>2]|0;do{if((i|0)==0){j=c[h+(d*3160|0)+3136>>2]|0;if((j|0)==0){k=d;l=h;break}gg[j&4095](f,e);k=c[3528552]|0;l=c[2433426]|0}else{a[i+(g&255)|0]=e;k=d;l=h}}while(0);h=g+1|0;g=a[9642716]|0;d=c[l+(k*3160|0)+60+((h>>>8&255|256)<<2)>>2]|0;if((d|0)!=0){a[d+(h&255)|0]=g;return}d=c[l+(k*3160|0)+3136>>2]|0;if((d|0)==0){return}gg[d&4095](h&65535,g);return}function fJr(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;fGP();d=c[2426872]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3132>>2]|0;if((i|0)==0){j=0;k=f;l=g;break}m=gj[i&4095](e)|0;j=m;k=c[3528552]|0;l=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=f;l=g}}while(0);g=(j&255)<<8;j=d+1|0;d=j&65535;f=c[l+(k*3160|0)+60+((j>>>8&255)<<2)>>2]|0;do{if((f|0)==0){h=c[l+(k*3160|0)+3132>>2]|0;if((h|0)==0){n=0;break}n=gj[h&4095](d)|0}else{n=a[f+(j&255)|0]|0}}while(0);j=n&255|g;g=b[4821356]|0;n=j^g;b[4821356]=n;f=a[9642744]&-15;a[9642744]=f;d=(n&65535)>>>12&8|f&255;if(j<<16>>16!=g<<16>>16){o=d&255;a[9642744]=o;return}o=(d|4)&255;a[9642744]=o;return}function fJs(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;fGP();d=c[2426872]|0;f=d&65535;g=c[3528552]|0;h=c[2433426]|0;i=c[h+(g*3160|0)+60+((d>>>8&255)<<2)>>2]|0;do{if((i|0)==0){j=c[h+(g*3160|0)+3132>>2]|0;if((j|0)==0){k=0;l=g;m=h;break}n=gj[j&4095](f)|0;k=n;l=c[3528552]|0;m=c[2433426]|0}else{k=a[i+(d&255)|0]|0;l=g;m=h}}while(0);h=(k&255)<<8;k=d+1|0;d=k&65535;g=c[m+(l*3160|0)+60+((k>>>8&255)<<2)>>2]|0;do{if((g|0)==0){i=c[m+(l*3160|0)+3132>>2]|0;if((i|0)==0){o=0;break}o=gj[i&4095](d)|0}else{o=a[g+(k&255)|0]|0}}while(0);k=e[4821356]|0;g=a[9642744]|0;d=k+(o&255|h)+(g&1)|0;o=(d>>>12&8|g&-16&255)&255;g=d&65535;a[9642744]=((k^h^d^d>>>1)>>>14&2|d>>>16&1|(g<<16>>16==0?o|4:o)&255)&255;b[4821356]=g;return}function fJt(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;fGP();d=c[2426872]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3132>>2]|0;if((i|0)==0){j=0;k=f;l=g;break}m=gj[i&4095](e)|0;j=m;k=c[3528552]|0;l=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=f;l=g}}while(0);g=(j&255)<<8;j=d+1|0;d=j&65535;f=c[l+(k*3160|0)+60+((j>>>8&255)<<2)>>2]|0;do{if((f|0)==0){h=c[l+(k*3160|0)+3132>>2]|0;if((h|0)==0){n=0;break}n=gj[h&4095](d)|0}else{n=a[f+(j&255)|0]|0}}while(0);j=n&255|g|b[4821356];b[4821356]=j;g=a[9642744]&-15;a[9642744]=g;n=(j&65535)>>>12&8|g&255;if(j<<16>>16!=0){o=n&255;a[9642744]=o;return}o=(n|4)&255;a[9642744]=o;return}function fJu(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;fGP();d=c[2426872]|0;f=d&65535;g=c[3528552]|0;h=c[2433426]|0;i=c[h+(g*3160|0)+60+((d>>>8&255)<<2)>>2]|0;do{if((i|0)==0){j=c[h+(g*3160|0)+3132>>2]|0;if((j|0)==0){k=0;l=g;m=h;break}n=gj[j&4095](f)|0;k=n;l=c[3528552]|0;m=c[2433426]|0}else{k=a[i+(d&255)|0]|0;l=g;m=h}}while(0);h=(k&255)<<8;k=d+1|0;d=k&65535;g=c[m+(l*3160|0)+60+((k>>>8&255)<<2)>>2]|0;do{if((g|0)==0){i=c[m+(l*3160|0)+3132>>2]|0;if((i|0)==0){o=0;break}o=gj[i&4095](d)|0}else{o=a[g+(k&255)|0]|0}}while(0);k=e[4821358]|0;g=k+(o&255|h)|0;o=(g>>>12&8|a[9642744]&-16&255)&255;d=g&65535;a[9642744]=((k^h^g^g>>>1)>>>14&2|g>>>16&1|(d<<16>>16==0?o|4:o)&255)&255;b[4821358]=d;return}function fJv(){var b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;fGP();b=c[2426872]|0;d=b&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((b>>>8&255)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3132>>2]|0;if((i|0)==0){j=0;k=f;l=g;break}m=gj[i&4095](d)|0;j=m;k=c[3528552]|0;l=c[2433426]|0}else{j=a[h+(b&255)|0]|0;k=f;l=g}}while(0);g=(j&255)<<8;j=b+1|0;b=j&65535;f=c[l+(k*3160|0)+60+((j>>>8&255)<<2)>>2]|0;do{if((f|0)==0){h=c[l+(k*3160|0)+3132>>2]|0;if((h|0)==0){n=0;break}n=gj[h&4095](b)|0}else{n=a[f+(j&255)|0]|0}}while(0);j=e[4821368]|0;f=j-(n&255|g)|0;n=(f>>>12&8|a[9642744]&-16&255)&255;a[9642744]=((j^g^f^f>>>1)>>>14&2|f>>>16&1|((f&65535)<<16>>16==0?n|4:n)&255)&255;return}function fJw(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;fGP();d=c[2426872]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3132>>2]|0;if((i|0)==0){j=0;k=f;l=g;break}m=gj[i&4095](e)|0;j=m;k=c[3528552]|0;l=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=f;l=g}}while(0);g=(j&255)<<8;j=d+1|0;d=j&65535;f=c[l+(k*3160|0)+60+((j>>>8&255)<<2)>>2]|0;do{if((f|0)==0){h=c[l+(k*3160|0)+3132>>2]|0;if((h|0)==0){n=0;break}n=gj[h&4095](d)|0}else{n=a[f+(j&255)|0]|0}}while(0);j=n&255|g;b[4821368]=j;n=a[9642744]&-15;a[9642744]=n;f=n&255|(g&65535)>>>12&8;if(j<<16>>16!=0){o=f&255;a[9642744]=o;return}o=(f|4)&255;a[9642744]=o;return}function fJx(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;fGP();d=a[9642744]&-15;a[9642744]=d;e=b[4821368]|0;f=(e&65535)>>>12&8|d&255;if(e<<16>>16==0){g=(f|4)&255}else{g=f&255}a[9642744]=g;g=c[2426872]|0;f=g&65535;e=a[9642737]|0;d=c[3528552]|0;h=c[2433426]|0;i=c[h+(d*3160|0)+60+((g>>>8&255|256)<<2)>>2]|0;do{if((i|0)==0){j=c[h+(d*3160|0)+3136>>2]|0;if((j|0)==0){k=d;l=h;break}gg[j&4095](f,e);k=c[3528552]|0;l=c[2433426]|0}else{a[i+(g&255)|0]=e;k=d;l=h}}while(0);h=g+1|0;g=a[9642736]|0;d=c[l+(k*3160|0)+60+((h>>>8&255|256)<<2)>>2]|0;if((d|0)!=0){a[d+(h&255)|0]=g;return}d=c[l+(k*3160|0)+3136>>2]|0;if((d|0)==0){return}gg[d&4095](h&65535,g);return}function fJy(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=c[2410676]|0;f=d&65535;g=c[3528552]|0;h=c[2433426]|0;i=c[h+(g*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((i|0)==0){j=c[h+(g*3160|0)+3144>>2]|0;if((j|0)==0){k=0;l=d;m=g;n=h;o=f;break}p=gj[j&4095](f)|0;j=c[2410676]|0;k=p;l=j;m=c[3528552]|0;n=c[2433426]|0;o=j&65535}else{k=a[i+(d&255)|0]|0;l=d;m=g;n=h;o=f}}while(0);f=k&255;k=f<<8;h=l+1|0;l=h&65535;g=c[n+(m*3160|0)+60+((h>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){d=c[n+(m*3160|0)+3144>>2]|0;if((d|0)==0){q=0;r=o;s=m;t=n;break}i=gj[d&4095](l)|0;q=i;r=b[4821352]|0;s=c[3528552]|0;t=c[2433426]|0}else{q=a[g+(h&255)|0]|0;r=o;s=m;t=n}}while(0);n=q&255;q=n|k;c[2426872]=q;b[4821352]=r+2&65535;r=q&65535;k=c[t+(s*3160|0)+60+(f<<2)>>2]|0;do{if((k|0)==0){f=c[t+(s*3160|0)+3132>>2]|0;if((f|0)==0){u=0;v=s;w=t;break}m=gj[f&4095](r)|0;u=m;v=c[3528552]|0;w=c[2433426]|0}else{u=a[k+n|0]|0;v=s;w=t}}while(0);t=(u&255)<<8;u=q+1|0;q=u&65535;s=c[w+(v*3160|0)+60+((u>>>8&255)<<2)>>2]|0;do{if((s|0)==0){n=c[w+(v*3160|0)+3132>>2]|0;if((n|0)==0){x=0;break}x=gj[n&4095](q)|0}else{x=a[s+(u&255)|0]|0}}while(0);u=e[4821358]|0;s=u-(x&255|t)|0;x=(s>>>12&8|a[9642744]&-16&255)&255;q=s&65535;a[9642744]=((u^t^s^s>>>1)>>>14&2|s>>>16&1|(q<<16>>16==0?x|4:x)&255)&255;b[4821358]=q;return}function fJz(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=c[2410676]|0;f=d&65535;g=c[3528552]|0;h=c[2433426]|0;i=c[h+(g*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((i|0)==0){j=c[h+(g*3160|0)+3144>>2]|0;if((j|0)==0){k=0;l=d;m=g;n=h;o=f;break}p=gj[j&4095](f)|0;j=c[2410676]|0;k=p;l=j;m=c[3528552]|0;n=c[2433426]|0;o=j&65535}else{k=a[i+(d&255)|0]|0;l=d;m=g;n=h;o=f}}while(0);f=k&255;k=f<<8;h=l+1|0;l=h&65535;g=c[n+(m*3160|0)+60+((h>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){d=c[n+(m*3160|0)+3144>>2]|0;if((d|0)==0){q=0;r=o;s=m;t=n;break}i=gj[d&4095](l)|0;q=i;r=b[4821352]|0;s=c[3528552]|0;t=c[2433426]|0}else{q=a[g+(h&255)|0]|0;r=o;s=m;t=n}}while(0);n=q&255;q=n|k;c[2426872]=q;b[4821352]=r+2&65535;r=q&65535;k=c[t+(s*3160|0)+60+(f<<2)>>2]|0;do{if((k|0)==0){f=c[t+(s*3160|0)+3132>>2]|0;if((f|0)==0){u=0;v=s;w=t;break}m=gj[f&4095](r)|0;u=m;v=c[3528552]|0;w=c[2433426]|0}else{u=a[k+n|0]|0;v=s;w=t}}while(0);t=(u&255)<<8;u=q+1|0;q=u&65535;s=c[w+(v*3160|0)+60+((u>>>8&255)<<2)>>2]|0;do{if((s|0)==0){n=c[w+(v*3160|0)+3132>>2]|0;if((n|0)==0){x=0;break}x=gj[n&4095](q)|0}else{x=a[s+(u&255)|0]|0}}while(0);u=e[4821358]|0;s=u-(x&255|t)|0;x=(s>>>12&8|a[9642744]&-16&255)&255;a[9642744]=((u^t^s^s>>>1)>>>14&2|s>>>16&1|((s&65535)<<16>>16==0?x|4:x)&255)&255;return}function fJA(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=c[2410676]|0;f=d&65535;g=c[3528552]|0;h=c[2433426]|0;i=c[h+(g*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((i|0)==0){j=c[h+(g*3160|0)+3144>>2]|0;if((j|0)==0){k=0;l=d;m=g;n=h;o=f;break}p=gj[j&4095](f)|0;j=c[2410676]|0;k=p;l=j;m=c[3528552]|0;n=c[2433426]|0;o=j&65535}else{k=a[i+(d&255)|0]|0;l=d;m=g;n=h;o=f}}while(0);f=k&255;k=f<<8;h=l+1|0;l=h&65535;g=c[n+(m*3160|0)+60+((h>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){d=c[n+(m*3160|0)+3144>>2]|0;if((d|0)==0){q=0;r=o;s=m;t=n;break}i=gj[d&4095](l)|0;q=i;r=b[4821352]|0;s=c[3528552]|0;t=c[2433426]|0}else{q=a[g+(h&255)|0]|0;r=o;s=m;t=n}}while(0);n=q&255;q=n|k;c[2426872]=q;b[4821352]=r+2&65535;r=q&65535;k=c[t+(s*3160|0)+60+(f<<2)>>2]|0;do{if((k|0)==0){f=c[t+(s*3160|0)+3132>>2]|0;if((f|0)==0){u=0;v=s;w=t;break}m=gj[f&4095](r)|0;u=m;v=c[3528552]|0;w=c[2433426]|0}else{u=a[k+n|0]|0;v=s;w=t}}while(0);t=(u&255)<<8;u=q+1|0;q=u&65535;s=c[w+(v*3160|0)+60+((u>>>8&255)<<2)>>2]|0;do{if((s|0)==0){n=c[w+(v*3160|0)+3132>>2]|0;if((n|0)==0){x=0;break}x=gj[n&4095](q)|0}else{x=a[s+(u&255)|0]|0}}while(0);u=e[4821356]|0;s=a[9642744]|0;q=u-(x&255|t)-(s&1)|0;x=(q>>>12&8|s&-16&255)&255;s=q&65535;a[9642744]=((u^t^q^q>>>1)>>>14&2|q>>>16&1|(s<<16>>16==0?x|4:x)&255)&255;b[4821356]=s;return}function fJB(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=c[2410676]|0;f=d&65535;g=c[3528552]|0;h=c[2433426]|0;i=c[h+(g*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((i|0)==0){j=c[h+(g*3160|0)+3144>>2]|0;if((j|0)==0){k=0;l=d;m=g;n=h;o=f;break}p=gj[j&4095](f)|0;j=c[2410676]|0;k=p;l=j;m=c[3528552]|0;n=c[2433426]|0;o=j&65535}else{k=a[i+(d&255)|0]|0;l=d;m=g;n=h;o=f}}while(0);f=k&255;k=f<<8;h=l+1|0;l=h&65535;g=c[n+(m*3160|0)+60+((h>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){d=c[n+(m*3160|0)+3144>>2]|0;if((d|0)==0){q=0;r=o;s=m;t=n;break}i=gj[d&4095](l)|0;q=i;r=b[4821352]|0;s=c[3528552]|0;t=c[2433426]|0}else{q=a[g+(h&255)|0]|0;r=o;s=m;t=n}}while(0);n=q&255;q=n|k;c[2426872]=q;b[4821352]=r+2&65535;r=q&65535;k=c[t+(s*3160|0)+60+(f<<2)>>2]|0;do{if((k|0)==0){f=c[t+(s*3160|0)+3132>>2]|0;if((f|0)==0){u=0;v=s;w=t;break}m=gj[f&4095](r)|0;u=m;v=c[3528552]|0;w=c[2433426]|0}else{u=a[k+n|0]|0;v=s;w=t}}while(0);t=(u&255)<<8;u=q+1|0;q=u&65535;s=c[w+(v*3160|0)+60+((u>>>8&255)<<2)>>2]|0;do{if((s|0)==0){n=c[w+(v*3160|0)+3132>>2]|0;if((n|0)==0){x=0;break}x=gj[n&4095](q)|0}else{x=a[s+(u&255)|0]|0}}while(0);u=e[4821356]|0;s=u-(x&255|t)|0;x=(s>>>12&8|a[9642744]&-16&255)&255;a[9642744]=((u^t^s^s>>>1)>>>14&2|s>>>16&1|((s&65535)<<16>>16==0?x|4:x)&255)&255;return}function fJC(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=j&255;j=e<<8;g=k+1|0;k=g&65535;f=c[m+(l*3160|0)+60+((g>>>8&255|512)<<2)>>2]|0;do{if((f|0)==0){d=c[m+(l*3160|0)+3144>>2]|0;if((d|0)==0){p=0;q=n;r=l;s=m;break}h=gj[d&4095](k)|0;p=h;q=b[4821352]|0;r=c[3528552]|0;s=c[2433426]|0}else{p=a[f+(g&255)|0]|0;q=n;r=l;s=m}}while(0);m=p&255;p=m|j;c[2426872]=p;b[4821352]=q+2&65535;q=p&65535;j=c[s+(r*3160|0)+60+(e<<2)>>2]|0;do{if((j|0)==0){e=c[s+(r*3160|0)+3132>>2]|0;if((e|0)==0){t=0;u=r;v=s;break}l=gj[e&4095](q)|0;t=l;u=c[3528552]|0;v=c[2433426]|0}else{t=a[j+m|0]|0;u=r;v=s}}while(0);s=(t&255)<<8;t=p+1|0;p=t&65535;r=c[v+(u*3160|0)+60+((t>>>8&255)<<2)>>2]|0;do{if((r|0)==0){m=c[v+(u*3160|0)+3132>>2]|0;if((m|0)==0){w=0;break}w=gj[m&4095](p)|0}else{w=a[r+(t&255)|0]|0}}while(0);t=(w&255|s)&b[4821356];b[4821356]=t;s=a[9642744]&-15;a[9642744]=s;w=(t&65535)>>>12&8|s&255;if(t<<16>>16!=0){x=w&255;a[9642744]=x;return}x=(w|4)&255;a[9642744]=x;return}function fJD(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;e=c[2410676]|0;f=e&65535;g=c[3528552]|0;h=c[2433426]|0;i=c[h+(g*3160|0)+60+((e>>>8&255|512)<<2)>>2]|0;do{if((i|0)==0){j=c[h+(g*3160|0)+3144>>2]|0;if((j|0)==0){k=0;l=e;m=g;n=h;o=f;break}p=gj[j&4095](f)|0;j=c[2410676]|0;k=p;l=j;m=c[3528552]|0;n=c[2433426]|0;o=j&65535}else{k=a[i+(e&255)|0]|0;l=e;m=g;n=h;o=f}}while(0);f=k&255;k=f<<8;h=l+1|0;l=h&65535;g=c[n+(m*3160|0)+60+((h>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){e=c[n+(m*3160|0)+3144>>2]|0;if((e|0)==0){q=0;r=o;s=m;t=n;break}i=gj[e&4095](l)|0;q=i;r=b[4821352]|0;s=c[3528552]|0;t=c[2433426]|0}else{q=a[g+(h&255)|0]|0;r=o;s=m;t=n}}while(0);n=q&255;q=n|k;c[2426872]=q;b[4821352]=r+2&65535;r=q&65535;k=c[t+(s*3160|0)+60+(f<<2)>>2]|0;do{if((k|0)==0){f=c[t+(s*3160|0)+3132>>2]|0;if((f|0)==0){u=0;v=s;w=t;break}m=gj[f&4095](r)|0;u=m;v=c[3528552]|0;w=c[2433426]|0}else{u=a[k+n|0]|0;v=s;w=t}}while(0);t=(u&255)<<8;u=q+1|0;q=u&65535;s=c[w+(v*3160|0)+60+((u>>>8&255)<<2)>>2]|0;do{if((s|0)==0){n=c[w+(v*3160|0)+3132>>2]|0;if((n|0)==0){x=0;break}x=gj[n&4095](q)|0}else{x=a[s+(u&255)|0]|0}}while(0);u=a[9642744]&-15;a[9642744]=((d[9642712]|0)&(x&255|t)|0)==0?u|4:u;return}function fJE(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=j&255;j=e<<8;g=k+1|0;k=g&65535;f=c[m+(l*3160|0)+60+((g>>>8&255|512)<<2)>>2]|0;do{if((f|0)==0){d=c[m+(l*3160|0)+3144>>2]|0;if((d|0)==0){p=0;q=n;r=l;s=m;break}h=gj[d&4095](k)|0;p=h;q=b[4821352]|0;r=c[3528552]|0;s=c[2433426]|0}else{p=a[f+(g&255)|0]|0;q=n;r=l;s=m}}while(0);m=p&255;p=m|j;c[2426872]=p;b[4821352]=q+2&65535;q=p&65535;j=c[s+(r*3160|0)+60+(e<<2)>>2]|0;do{if((j|0)==0){e=c[s+(r*3160|0)+3132>>2]|0;if((e|0)==0){t=0;u=r;v=s;break}l=gj[e&4095](q)|0;t=l;u=c[3528552]|0;v=c[2433426]|0}else{t=a[j+m|0]|0;u=r;v=s}}while(0);s=t&255;t=s<<8;r=p+1|0;p=r&65535;m=c[v+(u*3160|0)+60+((r>>>8&255)<<2)>>2]|0;do{if((m|0)==0){j=c[v+(u*3160|0)+3132>>2]|0;if((j|0)==0){w=0;break}w=gj[j&4095](p)|0}else{w=a[m+(r&255)|0]|0}}while(0);r=w&255|t;c[2410679]=r;t=a[9642744]&-15;a[9642744]=t;w=t&255|s>>>4&8;if((r|0)!=0){x=w&255;a[9642744]=x;return}x=(w|4)&255;a[9642744]=x;return}function fJF(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;d=a[9642744]&-15;a[9642744]=d;e=b[4821358]|0;f=(e&65535)>>>12&8|d&255;if(e<<16>>16==0){g=(f|4)&255}else{g=f&255}a[9642744]=g;g=c[2410676]|0;f=g&65535;e=c[3528552]|0;d=c[2433426]|0;h=c[d+(e*3160|0)+60+((g>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[d+(e*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=g;l=e;m=d;n=f;break}o=gj[i&4095](f)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(g&255)|0]|0;k=g;l=e;m=d;n=f}}while(0);f=j&255;j=f<<8;d=k+1|0;k=d&65535;e=c[m+(l*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((e|0)==0){g=c[m+(l*3160|0)+3144>>2]|0;if((g|0)==0){p=0;q=n;r=l;s=m;break}h=gj[g&4095](k)|0;p=h;q=b[4821352]|0;r=c[3528552]|0;s=c[2433426]|0}else{p=a[e+(d&255)|0]|0;q=n;r=l;s=m}}while(0);m=p&255;p=m|j;c[2426872]=p;b[4821352]=q+2&65535;q=p&65535;j=a[9642717]|0;l=c[s+(r*3160|0)+60+((f|256)<<2)>>2]|0;do{if((l|0)==0){f=c[s+(r*3160|0)+3136>>2]|0;if((f|0)==0){t=r;u=s;break}gg[f&4095](q,j);t=c[3528552]|0;u=c[2433426]|0}else{a[l+m|0]=j;t=r;u=s}}while(0);s=p+1|0;p=a[9642716]|0;r=c[u+(t*3160|0)+60+((s>>>8&255|256)<<2)>>2]|0;if((r|0)!=0){a[r+(s&255)|0]=p;return}r=c[u+(t*3160|0)+3136>>2]|0;if((r|0)==0){return}gg[r&4095](s&65535,p);return}function fJG(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=j&255;j=e<<8;g=k+1|0;k=g&65535;f=c[m+(l*3160|0)+60+((g>>>8&255|512)<<2)>>2]|0;do{if((f|0)==0){d=c[m+(l*3160|0)+3144>>2]|0;if((d|0)==0){p=0;q=n;r=l;s=m;break}h=gj[d&4095](k)|0;p=h;q=b[4821352]|0;r=c[3528552]|0;s=c[2433426]|0}else{p=a[f+(g&255)|0]|0;q=n;r=l;s=m}}while(0);m=p&255;p=m|j;c[2426872]=p;b[4821352]=q+2&65535;q=p&65535;j=c[s+(r*3160|0)+60+(e<<2)>>2]|0;do{if((j|0)==0){e=c[s+(r*3160|0)+3132>>2]|0;if((e|0)==0){t=0;u=r;v=s;break}l=gj[e&4095](q)|0;t=l;u=c[3528552]|0;v=c[2433426]|0}else{t=a[j+m|0]|0;u=r;v=s}}while(0);s=(t&255)<<8;t=p+1|0;p=t&65535;r=c[v+(u*3160|0)+60+((t>>>8&255)<<2)>>2]|0;do{if((r|0)==0){m=c[v+(u*3160|0)+3132>>2]|0;if((m|0)==0){w=0;break}w=gj[m&4095](p)|0}else{w=a[r+(t&255)|0]|0}}while(0);t=w&255|s;s=b[4821356]|0;w=t^s;b[4821356]=w;r=a[9642744]&-15;a[9642744]=r;p=(w&65535)>>>12&8|r&255;if(t<<16>>16!=s<<16>>16){x=p&255;a[9642744]=x;return}x=(p|4)&255;a[9642744]=x;return}function fJH(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=c[2410676]|0;f=d&65535;g=c[3528552]|0;h=c[2433426]|0;i=c[h+(g*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((i|0)==0){j=c[h+(g*3160|0)+3144>>2]|0;if((j|0)==0){k=0;l=d;m=g;n=h;o=f;break}p=gj[j&4095](f)|0;j=c[2410676]|0;k=p;l=j;m=c[3528552]|0;n=c[2433426]|0;o=j&65535}else{k=a[i+(d&255)|0]|0;l=d;m=g;n=h;o=f}}while(0);f=k&255;k=f<<8;h=l+1|0;l=h&65535;g=c[n+(m*3160|0)+60+((h>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){d=c[n+(m*3160|0)+3144>>2]|0;if((d|0)==0){q=0;r=o;s=m;t=n;break}i=gj[d&4095](l)|0;q=i;r=b[4821352]|0;s=c[3528552]|0;t=c[2433426]|0}else{q=a[g+(h&255)|0]|0;r=o;s=m;t=n}}while(0);n=q&255;q=n|k;c[2426872]=q;b[4821352]=r+2&65535;r=q&65535;k=c[t+(s*3160|0)+60+(f<<2)>>2]|0;do{if((k|0)==0){f=c[t+(s*3160|0)+3132>>2]|0;if((f|0)==0){u=0;v=s;w=t;break}m=gj[f&4095](r)|0;u=m;v=c[3528552]|0;w=c[2433426]|0}else{u=a[k+n|0]|0;v=s;w=t}}while(0);t=(u&255)<<8;u=q+1|0;q=u&65535;s=c[w+(v*3160|0)+60+((u>>>8&255)<<2)>>2]|0;do{if((s|0)==0){n=c[w+(v*3160|0)+3132>>2]|0;if((n|0)==0){x=0;break}x=gj[n&4095](q)|0}else{x=a[s+(u&255)|0]|0}}while(0);u=e[4821356]|0;s=a[9642744]|0;q=u+(x&255|t)+(s&1)|0;x=(q>>>12&8|s&-16&255)&255;s=q&65535;a[9642744]=((u^t^q^q>>>1)>>>14&2|q>>>16&1|(s<<16>>16==0?x|4:x)&255)&255;b[4821356]=s;return}function fJI(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=j&255;j=e<<8;g=k+1|0;k=g&65535;f=c[m+(l*3160|0)+60+((g>>>8&255|512)<<2)>>2]|0;do{if((f|0)==0){d=c[m+(l*3160|0)+3144>>2]|0;if((d|0)==0){p=0;q=n;r=l;s=m;break}h=gj[d&4095](k)|0;p=h;q=b[4821352]|0;r=c[3528552]|0;s=c[2433426]|0}else{p=a[f+(g&255)|0]|0;q=n;r=l;s=m}}while(0);m=p&255;p=m|j;c[2426872]=p;b[4821352]=q+2&65535;q=p&65535;j=c[s+(r*3160|0)+60+(e<<2)>>2]|0;do{if((j|0)==0){e=c[s+(r*3160|0)+3132>>2]|0;if((e|0)==0){t=0;u=r;v=s;break}l=gj[e&4095](q)|0;t=l;u=c[3528552]|0;v=c[2433426]|0}else{t=a[j+m|0]|0;u=r;v=s}}while(0);s=(t&255)<<8;t=p+1|0;p=t&65535;r=c[v+(u*3160|0)+60+((t>>>8&255)<<2)>>2]|0;do{if((r|0)==0){m=c[v+(u*3160|0)+3132>>2]|0;if((m|0)==0){w=0;break}w=gj[m&4095](p)|0}else{w=a[r+(t&255)|0]|0}}while(0);t=w&255|s|b[4821356];b[4821356]=t;s=a[9642744]&-15;a[9642744]=s;w=(t&65535)>>>4&8|s&255;if(t<<16>>16!=0){x=w&255;a[9642744]=x;return}x=(w|4)&255;a[9642744]=x;return}function fJJ(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=c[2410676]|0;f=d&65535;g=c[3528552]|0;h=c[2433426]|0;i=c[h+(g*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((i|0)==0){j=c[h+(g*3160|0)+3144>>2]|0;if((j|0)==0){k=0;l=d;m=g;n=h;o=f;break}p=gj[j&4095](f)|0;j=c[2410676]|0;k=p;l=j;m=c[3528552]|0;n=c[2433426]|0;o=j&65535}else{k=a[i+(d&255)|0]|0;l=d;m=g;n=h;o=f}}while(0);f=k&255;k=f<<8;h=l+1|0;l=h&65535;g=c[n+(m*3160|0)+60+((h>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){d=c[n+(m*3160|0)+3144>>2]|0;if((d|0)==0){q=0;r=o;s=m;t=n;break}i=gj[d&4095](l)|0;q=i;r=b[4821352]|0;s=c[3528552]|0;t=c[2433426]|0}else{q=a[g+(h&255)|0]|0;r=o;s=m;t=n}}while(0);n=q&255;q=n|k;c[2426872]=q;b[4821352]=r+2&65535;r=q&65535;k=c[t+(s*3160|0)+60+(f<<2)>>2]|0;do{if((k|0)==0){f=c[t+(s*3160|0)+3132>>2]|0;if((f|0)==0){u=0;v=s;w=t;break}m=gj[f&4095](r)|0;u=m;v=c[3528552]|0;w=c[2433426]|0}else{u=a[k+n|0]|0;v=s;w=t}}while(0);t=(u&255)<<8;u=q+1|0;q=u&65535;s=c[w+(v*3160|0)+60+((u>>>8&255)<<2)>>2]|0;do{if((s|0)==0){n=c[w+(v*3160|0)+3132>>2]|0;if((n|0)==0){x=0;break}x=gj[n&4095](q)|0}else{x=a[s+(u&255)|0]|0}}while(0);u=e[4821358]|0;s=u+(x&255|t)|0;x=(s>>>12&8|a[9642744]&-16&255)&255;q=s&65535;a[9642744]=((u^t^s^s>>>1)>>>14&2|s>>>16&1|(q<<16>>16==0?x|4:x)&255)&255;b[4821358]=q;return}function fJK(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=c[2410676]|0;f=d&65535;g=c[3528552]|0;h=c[2433426]|0;i=c[h+(g*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((i|0)==0){j=c[h+(g*3160|0)+3144>>2]|0;if((j|0)==0){k=0;l=d;m=g;n=h;o=f;break}p=gj[j&4095](f)|0;j=c[2410676]|0;k=p;l=j;m=c[3528552]|0;n=c[2433426]|0;o=j&65535}else{k=a[i+(d&255)|0]|0;l=d;m=g;n=h;o=f}}while(0);f=k&255;k=f<<8;h=l+1|0;l=h&65535;g=c[n+(m*3160|0)+60+((h>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){d=c[n+(m*3160|0)+3144>>2]|0;if((d|0)==0){q=0;r=o;s=m;t=n;break}i=gj[d&4095](l)|0;q=i;r=b[4821352]|0;s=c[3528552]|0;t=c[2433426]|0}else{q=a[g+(h&255)|0]|0;r=o;s=m;t=n}}while(0);n=q&255;q=n|k;c[2426872]=q;b[4821352]=r+2&65535;r=q&65535;k=c[t+(s*3160|0)+60+(f<<2)>>2]|0;do{if((k|0)==0){f=c[t+(s*3160|0)+3132>>2]|0;if((f|0)==0){u=0;v=s;w=t;break}m=gj[f&4095](r)|0;u=m;v=c[3528552]|0;w=c[2433426]|0}else{u=a[k+n|0]|0;v=s;w=t}}while(0);t=(u&255)<<8;u=q+1|0;q=u&65535;s=c[w+(v*3160|0)+60+((u>>>8&255)<<2)>>2]|0;do{if((s|0)==0){n=c[w+(v*3160|0)+3132>>2]|0;if((n|0)==0){x=0;break}x=gj[n&4095](q)|0}else{x=a[s+(u&255)|0]|0}}while(0);u=e[4821368]|0;s=u-(x&255|t)|0;x=(s>>>12&8|a[9642744]&-16&255)&255;a[9642744]=((u^t^s^s>>>1)>>>14&2|s>>>16&1|((s&65535)<<16>>16==0?x|4:x)&255)&255;return}function fJL(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=j&255;j=e<<8;g=k+1|0;k=g&65535;f=c[m+(l*3160|0)+60+((g>>>8&255|512)<<2)>>2]|0;do{if((f|0)==0){d=c[m+(l*3160|0)+3144>>2]|0;if((d|0)==0){p=0;q=n;r=l;s=m;break}h=gj[d&4095](k)|0;p=h;q=b[4821352]|0;r=c[3528552]|0;s=c[2433426]|0}else{p=a[f+(g&255)|0]|0;q=n;r=l;s=m}}while(0);m=p&255;p=m|j;c[2426872]=p;b[4821352]=q+2&65535;q=p&65535;j=c[s+(r*3160|0)+60+(e<<2)>>2]|0;do{if((j|0)==0){e=c[s+(r*3160|0)+3132>>2]|0;if((e|0)==0){t=0;u=r;v=s;break}l=gj[e&4095](q)|0;t=l;u=c[3528552]|0;v=c[2433426]|0}else{t=a[j+m|0]|0;u=r;v=s}}while(0);s=t&255;t=s<<8;r=p+1|0;p=r&65535;m=c[v+(u*3160|0)+60+((r>>>8&255)<<2)>>2]|0;do{if((m|0)==0){j=c[v+(u*3160|0)+3132>>2]|0;if((j|0)==0){w=0;break}w=gj[j&4095](p)|0}else{w=a[m+(r&255)|0]|0}}while(0);r=w&255|t;c[2410684]=r;t=a[9642744]&-15;a[9642744]=t;w=t&255|s>>>4&8;if((r|0)!=0){x=w&255;a[9642744]=x;return}x=(w|4)&255;a[9642744]=x;return}function fJM(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;d=a[9642744]&-15;a[9642744]=d;e=b[4821368]|0;f=(e&65535)>>>12&8|d&255;if(e<<16>>16==0){g=(f|4)&255}else{g=f&255}a[9642744]=g;g=c[2410676]|0;f=g&65535;e=c[3528552]|0;d=c[2433426]|0;h=c[d+(e*3160|0)+60+((g>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[d+(e*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=g;l=e;m=d;n=f;break}o=gj[i&4095](f)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(g&255)|0]|0;k=g;l=e;m=d;n=f}}while(0);f=j&255;j=f<<8;d=k+1|0;k=d&65535;e=c[m+(l*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((e|0)==0){g=c[m+(l*3160|0)+3144>>2]|0;if((g|0)==0){p=0;q=n;r=l;s=m;break}h=gj[g&4095](k)|0;p=h;q=b[4821352]|0;r=c[3528552]|0;s=c[2433426]|0}else{p=a[e+(d&255)|0]|0;q=n;r=l;s=m}}while(0);m=p&255;p=m|j;c[2426872]=p;b[4821352]=q+2&65535;q=p&65535;j=a[9642737]|0;l=c[s+(r*3160|0)+60+((f|256)<<2)>>2]|0;do{if((l|0)==0){f=c[s+(r*3160|0)+3136>>2]|0;if((f|0)==0){t=r;u=s;break}gg[f&4095](q,j);t=c[3528552]|0;u=c[2433426]|0}else{a[l+m|0]=j;t=r;u=s}}while(0);s=p+1|0;p=a[9642736]|0;r=c[u+(t*3160|0)+60+((s>>>8&255|256)<<2)>>2]|0;if((r|0)!=0){a[r+(s&255)|0]=p;return}r=c[u+(t*3160|0)+3136>>2]|0;if((r|0)==0){return}gg[r&4095](s&65535,p);return}function fJN(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=j&255;j=e<<8;g=k+1|0;k=g&65535;f=c[m+(l*3160|0)+60+((g>>>8&255|512)<<2)>>2]|0;do{if((f|0)==0){d=c[m+(l*3160|0)+3144>>2]|0;if((d|0)==0){p=0;q=n;break}h=gj[d&4095](k)|0;p=h;q=b[4821352]|0}else{p=a[f+(g&255)|0]|0;q=n}}while(0);n=p&255|j;c[2410682]=n;b[4821352]=q+2&65535;q=a[9642744]&-15;a[9642744]=q;j=q&255|e>>>4&8;if((n|0)!=0){r=j&255;a[9642744]=r;s=a[9642760]|0;t=s|32;a[9642760]=t;return}r=(j|4)&255;a[9642744]=r;s=a[9642760]|0;t=s|32;a[9642760]=t;return}function fJO(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;c[2426872]=c[2410680];d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;l=f;m=g;break}n=gj[i&4095](e)|0;j=n;k=b[4821352]|0;l=c[3528552]|0;m=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=e;l=f;m=g}}while(0);a[9707488]=j;b[4821352]=k+1&65535;k=c[2426872]|0;j=k&65535;g=c[m+(l*3160|0)+60+((k>>>8&255)<<2)>>2]|0;do{if((g|0)==0){f=c[m+(l*3160|0)+3132>>2]|0;if((f|0)==0){o=0;p=l;q=m;break}e=gj[f&4095](j)|0;o=e;p=c[3528552]|0;q=c[2433426]|0}else{o=a[g+(k&255)|0]|0;p=l;q=m}}while(0);m=(o&255)<<8;o=k+1|0;k=o&65535;l=c[q+(p*3160|0)+60+((o>>>8&255)<<2)>>2]|0;do{if((l|0)==0){g=c[q+(p*3160|0)+3132>>2]|0;if((g|0)==0){r=0;s=p;t=q;break}j=gj[g&4095](k)|0;r=j;s=c[3528552]|0;t=c[2433426]|0}else{r=a[l+(o&255)|0]|0;s=p;t=q}}while(0);q=r&255|m;m=q&65535;r=c[2426872]|0;p=r+2|0;o=p&65535;l=c[t+(s*3160|0)+60+((p>>>8&255)<<2)>>2]|0;do{if((l|0)==0){k=c[t+(s*3160|0)+3132>>2]|0;if((k|0)==0){u=0;v=s;w=t;break}j=gj[k&4095](o)|0;u=j;v=c[3528552]|0;w=c[2433426]|0}else{u=a[l+(p&255)|0]|0;v=s;w=t}}while(0);t=(u&255)<<8;u=r+3|0;r=u&65535;s=c[w+(v*3160|0)+60+((u>>>8&255)<<2)>>2]|0;do{if((s|0)==0){p=c[w+(v*3160|0)+3132>>2]|0;if((p|0)==0){x=0;break}x=gj[p&4095](r)|0}else{x=a[s+(u&255)|0]|0}}while(0);u=x&255|t;b[4821356]=m;b[4821358]=u&65535;t=a[9642744]&-15|(m&65535)>>>12&8;a[9642744]=(u|q<<16|0)==0?t|4:t;return}function fJP(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;e=b[4821356]|0;f=b[4821358]|0;c[2426872]=c[2410680];g=c[2410676]|0;h=g&65535;i=c[3528552]|0;j=c[2433426]|0;k=c[j+(i*3160|0)+60+((g>>>8&255|512)<<2)>>2]|0;do{if((k|0)==0){l=c[j+(i*3160|0)+3144>>2]|0;if((l|0)==0){m=0;n=h;o=i;p=j;break}q=gj[l&4095](h)|0;m=q;n=b[4821352]|0;o=c[3528552]|0;p=c[2433426]|0}else{m=a[k+(g&255)|0]|0;n=h;o=i;p=j}}while(0);a[9707488]=m;b[4821352]=n+1&65535;n=c[2426872]|0;m=n&65535;j=(e&65535)>>>8&255;i=c[p+(o*3160|0)+60+((n>>>8&255|256)<<2)>>2]|0;do{if((i|0)==0){h=c[p+(o*3160|0)+3136>>2]|0;if((h|0)==0){r=o;s=p;break}gg[h&4095](m,j);r=c[3528552]|0;s=c[2433426]|0}else{a[i+(n&255)|0]=j;r=o;s=p}}while(0);p=n+1|0;o=p&65535;j=e&255;i=c[s+(r*3160|0)+60+((p>>>8&255|256)<<2)>>2]|0;do{if((i|0)==0){m=c[s+(r*3160|0)+3136>>2]|0;if((m|0)==0){t=r;u=s;break}gg[m&4095](o,j);t=c[3528552]|0;u=c[2433426]|0}else{a[i+(p&255)|0]=j;t=r;u=s}}while(0);s=n+2|0;r=s&65535;j=(f&65535)>>>8&255;p=c[u+(t*3160|0)+60+((s>>>8&255|256)<<2)>>2]|0;do{if((p|0)==0){i=c[u+(t*3160|0)+3136>>2]|0;if((i|0)==0){v=t;w=u;break}gg[i&4095](r,j);v=c[3528552]|0;w=c[2433426]|0}else{a[p+(s&255)|0]=j;v=t;w=u}}while(0);u=n+3|0;n=u&65535;t=f&255;j=c[w+(v*3160|0)+60+((u>>>8&255|256)<<2)>>2]|0;do{if((j|0)==0){s=c[w+(v*3160|0)+3136>>2]|0;if((s|0)==0){break}gg[s&4095](n,t)}else{a[j+(u&255)|0]=t}}while(0);t=(d[9642713]|0)>>>4&8|a[9642744]&-15;a[9642744]=((e&65535)<<16|f&65535|0)==0?t|4:t;return}function fJQ(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;c[2426872]=c[2410680];d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=e;l=f;m=g;break}n=gj[i&4095](e)|0;j=n;k=b[4821352]|0;l=c[3528552]|0;m=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=e;l=f;m=g}}while(0);a[9707488]=j;b[4821352]=k+1&65535;k=c[2426872]|0;j=k&65535;g=c[m+(l*3160|0)+60+((k>>>8&255)<<2)>>2]|0;do{if((g|0)==0){f=c[m+(l*3160|0)+3132>>2]|0;if((f|0)==0){o=0;p=l;q=m;break}e=gj[f&4095](j)|0;o=e;p=c[3528552]|0;q=c[2433426]|0}else{o=a[g+(k&255)|0]|0;p=l;q=m}}while(0);m=o&255;o=m<<8;l=k+1|0;k=l&65535;g=c[q+(p*3160|0)+60+((l>>>8&255)<<2)>>2]|0;do{if((g|0)==0){j=c[q+(p*3160|0)+3132>>2]|0;if((j|0)==0){r=0;break}r=gj[j&4095](k)|0}else{r=a[g+(l&255)|0]|0}}while(0);l=r&255|o;c[2410682]=l;o=a[9642744]&-15;a[9642744]=o;r=o&255|m>>>4&8;if((l|0)!=0){s=r&255;a[9642744]=s;t=a[9642760]|0;u=t|32;a[9642760]=u;return}s=(r|4)&255;a[9642744]=s;t=a[9642760]|0;u=t|32;a[9642760]=u;return}function fJR(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=a[9642744]&-15;a[9642744]=d;e=b[4821364]|0;f=(e&65535)>>>12&8|d&255;if(e<<16>>16==0){g=(f|4)&255}else{g=f&255}a[9642744]=g;c[2426872]=c[2410680];g=c[2410676]|0;f=g&65535;e=c[3528552]|0;d=c[2433426]|0;h=c[d+(e*3160|0)+60+((g>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[d+(e*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=f;l=e;m=d;break}n=gj[i&4095](f)|0;j=n;k=b[4821352]|0;l=c[3528552]|0;m=c[2433426]|0}else{j=a[h+(g&255)|0]|0;k=f;l=e;m=d}}while(0);a[9707488]=j;b[4821352]=k+1&65535;k=c[2426872]|0;j=k&65535;d=a[9642729]|0;e=c[m+(l*3160|0)+60+((k>>>8&255|256)<<2)>>2]|0;do{if((e|0)==0){f=c[m+(l*3160|0)+3136>>2]|0;if((f|0)==0){o=l;p=m;break}gg[f&4095](j,d);o=c[3528552]|0;p=c[2433426]|0}else{a[e+(k&255)|0]=d;o=l;p=m}}while(0);m=k+1|0;k=a[9642728]|0;l=c[p+(o*3160|0)+60+((m>>>8&255|256)<<2)>>2]|0;if((l|0)!=0){a[l+(m&255)|0]=k;return}l=c[p+(o*3160|0)+3136>>2]|0;if((l|0)==0){return}gg[l&4095](m&65535,k);return}function fJS(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;fGP();d=c[2426872]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3132>>2]|0;if((i|0)==0){j=0;k=f;l=g;break}m=gj[i&4095](e)|0;j=m;k=c[3528552]|0;l=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=f;l=g}}while(0);g=(j&255)<<24;f=d+1|0;h=f&65535;e=c[l+(k*3160|0)+60+((f>>>8&255)<<2)>>2]|0;do{if((e|0)==0){m=c[l+(k*3160|0)+3132>>2]|0;if((m|0)==0){n=0;o=k;p=l;break}i=gj[m&4095](h)|0;n=i;o=c[3528552]|0;p=c[2433426]|0}else{n=a[e+(f&255)|0]|0;o=k;p=l}}while(0);l=(n&255)<<16|g;g=d+2|0;n=g&65535;k=c[p+(o*3160|0)+60+((g>>>8&255)<<2)>>2]|0;do{if((k|0)==0){f=c[p+(o*3160|0)+3132>>2]|0;if((f|0)==0){q=0;r=o;s=p;break}e=gj[f&4095](n)|0;q=e;r=c[3528552]|0;s=c[2433426]|0}else{q=a[k+(g&255)|0]|0;r=o;s=p}}while(0);p=(q&255)<<8|l;q=d+3|0;d=q&65535;o=c[s+(r*3160|0)+60+((q>>>8&255)<<2)>>2]|0;do{if((o|0)==0){g=c[s+(r*3160|0)+3132>>2]|0;if((g|0)==0){t=0;break}t=gj[g&4095](d)|0}else{t=a[o+(q&255)|0]|0}}while(0);q=p|t&255;b[4821356]=l>>>16&65535;b[4821358]=q&65535;t=a[9642744]&-15|(j&255)>>>4&8;a[9642744]=(q&65535|l|0)==0?t|4:t;return}function fJT(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=b[4821356]|0;f=b[4821358]|0;fGP();g=c[2426872]|0;h=g&65535;i=(e&65535)>>>8&255;j=c[3528552]|0;k=c[2433426]|0;l=c[k+(j*3160|0)+60+((g>>>8&255|256)<<2)>>2]|0;do{if((l|0)==0){m=c[k+(j*3160|0)+3136>>2]|0;if((m|0)==0){n=j;o=k;break}gg[m&4095](h,i);n=c[3528552]|0;o=c[2433426]|0}else{a[l+(g&255)|0]=i;n=j;o=k}}while(0);k=g+1|0;j=k&65535;i=e&255;l=c[o+(n*3160|0)+60+((k>>>8&255|256)<<2)>>2]|0;do{if((l|0)==0){h=c[o+(n*3160|0)+3136>>2]|0;if((h|0)==0){p=n;q=o;break}gg[h&4095](j,i);p=c[3528552]|0;q=c[2433426]|0}else{a[l+(k&255)|0]=i;p=n;q=o}}while(0);o=g+2|0;n=o&65535;i=(f&65535)>>>8&255;k=c[q+(p*3160|0)+60+((o>>>8&255|256)<<2)>>2]|0;do{if((k|0)==0){l=c[q+(p*3160|0)+3136>>2]|0;if((l|0)==0){r=p;s=q;break}gg[l&4095](n,i);r=c[3528552]|0;s=c[2433426]|0}else{a[k+(o&255)|0]=i;r=p;s=q}}while(0);q=g+3|0;g=q&65535;p=f&255;i=c[s+(r*3160|0)+60+((q>>>8&255|256)<<2)>>2]|0;do{if((i|0)==0){o=c[s+(r*3160|0)+3136>>2]|0;if((o|0)==0){break}gg[o&4095](g,p)}else{a[i+(q&255)|0]=p}}while(0);p=(d[9642713]|0)>>>4&8|a[9642744]&-15;a[9642744]=((e&65535)<<16|f&65535|0)==0?p|4:p;return}function fJU(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;fGP();d=c[2426872]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3132>>2]|0;if((i|0)==0){j=0;k=f;l=g;break}m=gj[i&4095](e)|0;j=m;k=c[3528552]|0;l=c[2433426]|0}else{j=a[h+(d&255)|0]|0;k=f;l=g}}while(0);g=(j&255)<<8;j=d+1|0;d=j&65535;f=c[l+(k*3160|0)+60+((j>>>8&255)<<2)>>2]|0;do{if((f|0)==0){h=c[l+(k*3160|0)+3132>>2]|0;if((h|0)==0){n=0;break}n=gj[h&4095](d)|0}else{n=a[f+(j&255)|0]|0}}while(0);j=n&255|g;b[4821364]=j;n=a[9642744]&-15;a[9642744]=n;f=n&255|(g&65535)>>>12&8;if(j<<16>>16!=0){o=f&255;a[9642744]=o;p=a[9642760]|0;q=p|32;a[9642760]=q;return}o=(f|4)&255;a[9642744]=o;p=a[9642760]|0;q=p|32;a[9642760]=q;return}function fJV(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;fGP();d=a[9642744]&-15;a[9642744]=d;e=b[4821364]|0;f=(e&65535)>>>12&8|d&255;if(e<<16>>16==0){g=(f|4)&255}else{g=f&255}a[9642744]=g;g=c[2426872]|0;f=g&65535;e=a[9642729]|0;d=c[3528552]|0;h=c[2433426]|0;i=c[h+(d*3160|0)+60+((g>>>8&255|256)<<2)>>2]|0;do{if((i|0)==0){j=c[h+(d*3160|0)+3136>>2]|0;if((j|0)==0){k=d;l=h;break}gg[j&4095](f,e);k=c[3528552]|0;l=c[2433426]|0}else{a[i+(g&255)|0]=e;k=d;l=h}}while(0);h=g+1|0;g=a[9642728]|0;d=c[l+(k*3160|0)+60+((h>>>8&255|256)<<2)>>2]|0;if((d|0)!=0){a[d+(h&255)|0]=g;return}d=c[l+(k*3160|0)+3136>>2]|0;if((d|0)==0){return}gg[d&4095](h&65535,g);return}function fJW(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=j&255;j=e<<8;g=k+1|0;k=g&65535;f=c[m+(l*3160|0)+60+((g>>>8&255|512)<<2)>>2]|0;do{if((f|0)==0){d=c[m+(l*3160|0)+3144>>2]|0;if((d|0)==0){p=0;q=n;r=l;s=m;break}h=gj[d&4095](k)|0;p=h;q=b[4821352]|0;r=c[3528552]|0;s=c[2433426]|0}else{p=a[f+(g&255)|0]|0;q=n;r=l;s=m}}while(0);m=p&255;p=m|j;c[2426872]=p;b[4821352]=q+2&65535;q=p&65535;j=c[s+(r*3160|0)+60+(e<<2)>>2]|0;do{if((j|0)==0){e=c[s+(r*3160|0)+3132>>2]|0;if((e|0)==0){t=0;u=r;v=s;break}l=gj[e&4095](q)|0;t=l;u=c[3528552]|0;v=c[2433426]|0}else{t=a[j+m|0]|0;u=r;v=s}}while(0);s=(t&255)<<8;t=p+1|0;p=t&65535;r=c[v+(u*3160|0)+60+((t>>>8&255)<<2)>>2]|0;do{if((r|0)==0){m=c[v+(u*3160|0)+3132>>2]|0;if((m|0)==0){w=0;x=u;y=v;break}j=gj[m&4095](p)|0;w=j;x=c[3528552]|0;y=c[2433426]|0}else{w=a[r+(t&255)|0]|0;x=u;y=v}}while(0);v=w&255|s;s=v&65535;w=c[2426872]|0;u=w+2|0;t=u&65535;r=c[y+(x*3160|0)+60+((u>>>8&255)<<2)>>2]|0;do{if((r|0)==0){p=c[y+(x*3160|0)+3132>>2]|0;if((p|0)==0){z=0;A=x;B=y;break}j=gj[p&4095](t)|0;z=j;A=c[3528552]|0;B=c[2433426]|0}else{z=a[r+(u&255)|0]|0;A=x;B=y}}while(0);y=(z&255)<<8;z=w+3|0;w=z&65535;x=c[B+(A*3160|0)+60+((z>>>8&255)<<2)>>2]|0;do{if((x|0)==0){u=c[B+(A*3160|0)+3132>>2]|0;if((u|0)==0){C=0;break}C=gj[u&4095](w)|0}else{C=a[x+(z&255)|0]|0}}while(0);z=C&255|y;b[4821356]=s;b[4821358]=z&65535;y=a[9642744]&-15|(s&65535)>>>12&8;a[9642744]=(z|v<<16|0)==0?y|4:y;return}function fJX(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;e=b[4821356]|0;f=b[4821358]|0;g=c[2410676]|0;h=g&65535;i=c[3528552]|0;j=c[2433426]|0;k=c[j+(i*3160|0)+60+((g>>>8&255|512)<<2)>>2]|0;do{if((k|0)==0){l=c[j+(i*3160|0)+3144>>2]|0;if((l|0)==0){m=0;n=g;o=i;p=j;q=h;break}r=gj[l&4095](h)|0;l=c[2410676]|0;m=r;n=l;o=c[3528552]|0;p=c[2433426]|0;q=l&65535}else{m=a[k+(g&255)|0]|0;n=g;o=i;p=j;q=h}}while(0);h=m&255;m=h<<8;j=n+1|0;n=j&65535;i=c[p+(o*3160|0)+60+((j>>>8&255|512)<<2)>>2]|0;do{if((i|0)==0){g=c[p+(o*3160|0)+3144>>2]|0;if((g|0)==0){s=0;t=q;u=o;v=p;break}k=gj[g&4095](n)|0;s=k;t=b[4821352]|0;u=c[3528552]|0;v=c[2433426]|0}else{s=a[i+(j&255)|0]|0;t=q;u=o;v=p}}while(0);p=s&255;s=p|m;c[2426872]=s;b[4821352]=t+2&65535;t=s&65535;m=(e&65535)>>>8&255;o=c[v+(u*3160|0)+60+((h|256)<<2)>>2]|0;do{if((o|0)==0){h=c[v+(u*3160|0)+3136>>2]|0;if((h|0)==0){w=u;x=v;break}gg[h&4095](t,m);w=c[3528552]|0;x=c[2433426]|0}else{a[o+p|0]=m;w=u;x=v}}while(0);v=s+1|0;u=v&65535;m=e&255;p=c[x+(w*3160|0)+60+((v>>>8&255|256)<<2)>>2]|0;do{if((p|0)==0){o=c[x+(w*3160|0)+3136>>2]|0;if((o|0)==0){y=w;z=x;break}gg[o&4095](u,m);y=c[3528552]|0;z=c[2433426]|0}else{a[p+(v&255)|0]=m;y=w;z=x}}while(0);x=s+2|0;w=x&65535;m=(f&65535)>>>8&255;v=c[z+(y*3160|0)+60+((x>>>8&255|256)<<2)>>2]|0;do{if((v|0)==0){p=c[z+(y*3160|0)+3136>>2]|0;if((p|0)==0){A=y;B=z;break}gg[p&4095](w,m);A=c[3528552]|0;B=c[2433426]|0}else{a[v+(x&255)|0]=m;A=y;B=z}}while(0);z=s+3|0;s=z&65535;y=f&255;m=c[B+(A*3160|0)+60+((z>>>8&255|256)<<2)>>2]|0;do{if((m|0)==0){x=c[B+(A*3160|0)+3136>>2]|0;if((x|0)==0){break}gg[x&4095](s,y)}else{a[m+(z&255)|0]=y}}while(0);y=(d[9642713]|0)>>>4&8|a[9642744]&-15;a[9642744]=((e&65535)<<16|f&65535|0)==0?y|4:y;return}function fJY(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;d=c[2410676]|0;e=d&65535;f=c[3528552]|0;g=c[2433426]|0;h=c[g+(f*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+(f*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=d;l=f;m=g;n=e;break}o=gj[i&4095](e)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=f;m=g;n=e}}while(0);e=j&255;j=e<<8;g=k+1|0;k=g&65535;f=c[m+(l*3160|0)+60+((g>>>8&255|512)<<2)>>2]|0;do{if((f|0)==0){d=c[m+(l*3160|0)+3144>>2]|0;if((d|0)==0){p=0;q=n;r=l;s=m;break}h=gj[d&4095](k)|0;p=h;q=b[4821352]|0;r=c[3528552]|0;s=c[2433426]|0}else{p=a[f+(g&255)|0]|0;q=n;r=l;s=m}}while(0);m=p&255;p=m|j;c[2426872]=p;b[4821352]=q+2&65535;q=p&65535;j=c[s+(r*3160|0)+60+(e<<2)>>2]|0;do{if((j|0)==0){e=c[s+(r*3160|0)+3132>>2]|0;if((e|0)==0){t=0;u=r;v=s;break}l=gj[e&4095](q)|0;t=l;u=c[3528552]|0;v=c[2433426]|0}else{t=a[j+m|0]|0;u=r;v=s}}while(0);s=t&255;t=s<<8;r=p+1|0;p=r&65535;m=c[v+(u*3160|0)+60+((r>>>8&255)<<2)>>2]|0;do{if((m|0)==0){j=c[v+(u*3160|0)+3132>>2]|0;if((j|0)==0){w=0;break}w=gj[j&4095](p)|0}else{w=a[m+(r&255)|0]|0}}while(0);r=w&255|t;c[2410682]=r;t=a[9642744]&-15;a[9642744]=t;w=t&255|s>>>4&8;if((r|0)!=0){x=w&255;a[9642744]=x;y=a[9642760]|0;z=y|32;a[9642760]=z;return}x=(w|4)&255;a[9642744]=x;y=a[9642760]|0;z=y|32;a[9642760]=z;return}function fJZ(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;d=a[9642744]&-15;a[9642744]=d;e=b[4821364]|0;f=(e&65535)>>>12&8|d&255;if(e<<16>>16==0){g=(f|4)&255}else{g=f&255}a[9642744]=g;g=c[2410676]|0;f=g&65535;e=c[3528552]|0;d=c[2433426]|0;h=c[d+(e*3160|0)+60+((g>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[d+(e*3160|0)+3144>>2]|0;if((i|0)==0){j=0;k=g;l=e;m=d;n=f;break}o=gj[i&4095](f)|0;i=c[2410676]|0;j=o;k=i;l=c[3528552]|0;m=c[2433426]|0;n=i&65535}else{j=a[h+(g&255)|0]|0;k=g;l=e;m=d;n=f}}while(0);f=j&255;j=f<<8;d=k+1|0;k=d&65535;e=c[m+(l*3160|0)+60+((d>>>8&255|512)<<2)>>2]|0;do{if((e|0)==0){g=c[m+(l*3160|0)+3144>>2]|0;if((g|0)==0){p=0;q=n;r=l;s=m;break}h=gj[g&4095](k)|0;p=h;q=b[4821352]|0;r=c[3528552]|0;s=c[2433426]|0}else{p=a[e+(d&255)|0]|0;q=n;r=l;s=m}}while(0);m=p&255;p=m|j;c[2426872]=p;b[4821352]=q+2&65535;q=p&65535;j=a[9642729]|0;l=c[s+(r*3160|0)+60+((f|256)<<2)>>2]|0;do{if((l|0)==0){f=c[s+(r*3160|0)+3136>>2]|0;if((f|0)==0){t=r;u=s;break}gg[f&4095](q,j);t=c[3528552]|0;u=c[2433426]|0}else{a[l+m|0]=j;t=r;u=s}}while(0);s=p+1|0;p=a[9642728]|0;r=c[u+(t*3160|0)+60+((s>>>8&255|256)<<2)>>2]|0;if((r|0)!=0){a[r+(s&255)|0]=p;return}r=c[u+(t*3160|0)+3136>>2]|0;if((r|0)==0){return}gg[r&4095](s&65535,p);return}function fJ_(f){f=f|0;var g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;c[2429636]=f;c[2440608]=f-(d[9718249]|0);a[9718249]=0;do{g=c[2429555]|0;c[2429554]=g;i=g&65535;if((a[9718232]&1)!=0&(e[4859117]|0)>(g&65535)){g=gj[c[3541286]&4095](274)|0;a[9718231]=g;if(g<<24>>24==0){j=0}else{k=13719}}else{k=13719}if((k|0)==13719){k=0;j=(gj[c[3541290]&4095](i)|0)&255}b[4859110]=(b[4859110]|0)+1&65535;i=c[7015680+(j<<3)>>2]|0;c[2429564]=i;gu[c[7015684+(j<<3)>>2]&16383]();g=c[2429564]|0;c[2440608]=(c[2440608]|0)-g;if((a[9718243]|0)!=0&(g|0)>0){g=0;while(1){l=gj[c[3541286]&4095](273)|0;if(((l&255)-(d[9718260]|0)|0)>0){m=(a[9718241]|0)+1&255;a[9718241]=m;n=m<<24>>24==0?1:g}else{n=g}a[9718260]=l;l=(c[2429564]|0)-1|0;c[2429564]=l;if((l|0)>0){g=n}else{o=n;break}}}else{o=0}do{if((a[9718242]|0)==0){p=o}else{g=(d[9718238]|0)+i|0;a[9718238]=g&255;if((g&224)>>>0<=31){p=o;break}a[9718238]=g+224&255;g=(a[9718241]|0)+1&255;a[9718241]=g;p=g<<24>>24==0?1:o}}while(0);if((p|0)==0){q=c[2440608]|0}else{do{if((a[9718245]|0)==0){r=0}else{i=a[9718237]|0;if((i<<24>>24|0)==1){a[9718236]=a[9718236]|2;r=0;break}else if((i<<24>>24|0)!=0){r=0;break}a[9718237]=2;a[9718236]=a[9718236]&-3;i=a[9718220]|0;g=a[9718225]|0;a[9718225]=g+1&255;l=c[2426620]|0;a[l+((g&255)+8)|0]=i;i=a[9718225]&15;g=a[9718226]|0;a[9718226]=(i&255)>>>1|g&-8;m=a[9718221]&15|g&-16;a[9718225]=i+1&255;a[l+((i&255)+8)|0]=m;m=a[9718225]&15;a[9718225]=m;a[9718226]=(m&255)>>>1|a[9718226]&-8;b[4859110]=7;if((a[9718242]|0)==0){r=2;break}a[9718238]=(a[9718238]|0)+2&255;r=2}}while(0);a[9718240]=1;m=(c[2440608]|0)-r|0;c[2440608]=m;q=m}}while((q|0)>0);r=q-(d[9718249]|0)|0;c[2440608]=r;q=f-r|0;h[1214783]=+h[1214783]+ +(q|0);a[9718249]=0;return q|0}function fJ$(d){d=d|0;var e=0,f=0,g=0,h=0;if((d|0)==0){a[9718248]=0;return}a[9718248]=1;do{if((a[9718244]|0)!=0&(a[9718237]|0)==0){a[9718237]=1;d=a[9718220]|0;e=a[9718225]|0;a[9718225]=e+1&255;f=c[2426620]|0;a[f+((e&255)+8)|0]=d;d=a[9718225]&15;e=a[9718226]|0;a[9718226]=(d&255)>>>1|e&-8;g=a[9718221]&15|e&-16;a[9718225]=d+1&255;a[f+((d&255)+8)|0]=g;g=a[9718225]&15;a[9718225]=g;a[9718226]=(g&255)>>>1|a[9718226]&-8;b[4859110]=3;if((a[9718242]|0)!=0){a[9718238]=(a[9718238]|0)+2&255}g=c[2429563]|0;if((g|0)==0){h=2;break}gj[g&4095](0)|0;h=2}else{h=0}}while(0);a[9718249]=(a[9718249]|0)+h&255;return}function fJ0(){return}function fJ1(){return}function fJ2(){gg[c[3541284]&4095](288,a[9718224]|0);return}function fJ3(){var f=0,g=0,h=0,i=0,j=0,k=0;f=b[4859110]|0;g=f&65535;if((a[9718232]&1)!=0&(e[4859117]|0)>(f&65535)){f=gj[c[3541286]&4095](274)|0;a[9718231]=f;if(f<<24>>24==0){h=0}else{i=13753}}else{i=13753}if((i|0)==13753){h=(gj[c[3541288]&4095](g)|0)&255}b[4859110]=(b[4859110]|0)+1&65535;g=a[9718226]&63;a[9718226]=g;i=d[9718224]|0;if(((i&15)+(h&15)|0)>15){f=g|64;a[9718226]=f;j=f}else{j=g}g=i+h|0;if((g&65280)>>>0<=255){k=g&255;a[9718224]=k;return}a[9718226]=j|-128;k=g&255;a[9718224]=k;return}function fJ4(){var d=0,f=0,g=0,h=0,i=0;d=b[4859110]|0;f=d&65535;if((a[9718232]&1)!=0&(e[4859117]|0)>(d&65535)){d=gj[c[3541286]&4095](274)|0;a[9718231]=d;if(d<<24>>24==0){g=0}else{h=13763}}else{h=13763}if((h|0)==13763){g=(gj[c[3541290]&4095](f)|0)&255}f=(b[4859110]|0)-1&65535;d=((a[9718237]|0)==0?b[4859123]|0:0)|g;b[4859110]=d;g=d&65535;if(d<<16>>16==f<<16>>16){if((c[2440608]|0)<=0){return}c[2440608]=0;return}if((g|0)!=((f&65535)-1|0)){return}if((a[9718232]&1)!=0&(e[4859117]|0)>(d&65535)){d=gj[c[3541286]&4095](274)|0;a[9718231]=d;if(d<<24>>24==0){i=1}else{h=13770}}else{h=13770}if((h|0)==13770){i=(gj[c[3541290]&4095](g)|0)<<24>>24==0}if(!(i&(c[2440608]|0)>0)){return}c[2440608]=0;return}function fJ5(){var d=0,e=0,f=0,g=0,h=0;a[9718244]=1;if((a[9718248]|0)!=1){return}do{if((a[9718237]|0)==0){a[9718237]=1;d=a[9718220]|0;e=a[9718225]|0;a[9718225]=e+1&255;f=c[2426620]|0;a[f+((e&255)+8)|0]=d;d=a[9718225]&15;e=a[9718226]|0;a[9718226]=(d&255)>>>1|e&-8;g=a[9718221]&15|e&-16;a[9718225]=d+1&255;a[f+((d&255)+8)|0]=g;g=a[9718225]&15;a[9718225]=g;a[9718226]=(g&255)>>>1|a[9718226]&-8;b[4859110]=3;if((a[9718242]|0)!=0){a[9718238]=(a[9718238]|0)+2&255}g=c[2429563]|0;if((g|0)==0){h=2;break}gj[g&4095](0)|0;h=2}else{h=0}}while(0);a[9718249]=(a[9718249]|0)+h&255;return}function fJ6(){a[9718224]=(a[9718224]|0)-1&255;return}function fJ7(){a[9718224]=gj[c[3541286]&4095](288)|0;return}function fJ8(){var b=0;b=gj[c[3541286]&4095](257)|0;a[9718224]=a[9718229]&b;return}function fJ9(){var b=0;b=gj[c[3541286]&4095](258)|0;a[9718224]=a[9718230]&b;return}function fKa(){a[9718224]=(gj[c[3541286]&4095](260)|0)&15;return}function fKb(){a[9718224]=(gj[c[3541286]&4095](261)|0)&15;return}function fKc(){a[9718224]=(gj[c[3541286]&4095](262)|0)&15;return}function fKd(){a[9718224]=(gj[c[3541286]&4095](263)|0)&15;return}function fKe(){var b=0,e=0;b=c[2426620]|0;e=b+(a[9718233]&a[b+(d[9718239]|0)|0]&255)|0;a[e]=(a[e]|0)+1&255;return}function fKf(){var b=0,e=0;b=c[2426620]|0;e=b+(a[9718233]&a[b+((d[9718239]|0)+1)|0]&255)|0;a[e]=(a[e]|0)+1&255;return}function fKg(){var d=0,f=0,g=0,h=0;d=b[4859110]|0;f=d&65535;if((a[9718232]&1)!=0&(e[4859117]|0)>(d&65535)){d=gj[c[3541286]&4095](274)|0;a[9718231]=d;if(d<<24>>24==0){g=0}else{h=13801}}else{h=13801}if((h|0)==13801){g=(gj[c[3541288]&4095](f)|0)&255}f=b[4859110]|0;b[4859110]=f+1&65535;if((a[9718224]&1)==0){return}b[4859110]=f&3840|g;return}function fKh(){var f=0,g=0,h=0,i=0,j=0,k=0;f=b[4859110]|0;g=f&65535;if((a[9718232]&1)!=0&(e[4859117]|0)>(f&65535)){f=gj[c[3541286]&4095](274)|0;a[9718231]=f;if(f<<24>>24==0){h=0}else{i=13809}}else{i=13809}if((i|0)==13809){h=(gj[c[3541288]&4095](g)|0)&255}b[4859110]=(b[4859110]|0)+1&65535;g=a[9718226]|0;i=g&-65;a[9718226]=i;f=d[9718224]|0;if((((g&255)>>>7)+(h&15)+(f&15)|0)>15){j=g|64;a[9718226]=j;k=j}else{k=i}i=f+h+((k&255)>>>7)|0;a[9718226]=(i&65280)>>>0>255?k|-128:k&127;a[9718224]=i&255;return}function fKi(){var d=0,f=0,g=0,h=0,i=0;d=b[4859110]|0;f=d&65535;if((a[9718232]&1)!=0&(e[4859117]|0)>(d&65535)){d=gj[c[3541286]&4095](274)|0;a[9718231]=d;if(d<<24>>24==0){g=0}else{h=13815}}else{h=13815}if((h|0)==13815){g=(gj[c[3541288]&4095](f)|0)&255}f=(b[4859110]|0)+1&65535;b[4859110]=f;h=((a[9718237]|0)==0?b[4859123]|0:0)|g;g=a[9718225]|0;a[9718225]=g+1&255;d=c[2426620]|0;a[d+((g&255)+8)|0]=f&255;f=a[9718225]&15;g=a[9718226]|0;a[9718226]=(f&255)>>>1|g&-8;i=a[9718221]&15|g&-16;a[9718225]=f+1&255;a[d+((f&255)+8)|0]=i;i=a[9718225]&15;a[9718225]=i;a[9718226]=(i&255)>>>1|a[9718226]&-8;b[4859110]=h;return}function fKj(){a[9718244]=0;return}function fKk(){var d=0,f=0,g=0,h=0;d=b[4859110]|0;f=d&65535;if((a[9718232]&1)!=0&(e[4859117]|0)>(d&65535)){d=gj[c[3541286]&4095](274)|0;a[9718231]=d;if(d<<24>>24==0){g=0}else{h=13820}}else{h=13820}if((h|0)==13820){g=(gj[c[3541288]&4095](f)|0)&255}f=b[4859110]|0;b[4859110]=f+1&65535;if((a[9718240]|0)==0){return}b[4859110]=f&3840|g;a[9718240]=0;return}function fKl(){a[9718224]=(a[9718224]|0)+1&255;return}function fKm(){var b=0;b=(c[2426620]|0)+(d[9718239]|0)|0;a[b]=(a[b]|0)+1&255;return}function fKn(){var b=0;b=(c[2426620]|0)+((d[9718239]|0)+1)|0;a[b]=(a[b]|0)+1&255;return}function fKo(){var b=0;b=(c[2426620]|0)+((d[9718239]|0)+2)|0;a[b]=(a[b]|0)+1&255;return}function fKp(){var b=0;b=(c[2426620]|0)+((d[9718239]|0)+3)|0;a[b]=(a[b]|0)+1&255;return}function fKq(){var b=0;b=(c[2426620]|0)+((d[9718239]|0)+4)|0;a[b]=(a[b]|0)+1&255;return}function fKr(){var b=0;b=(c[2426620]|0)+((d[9718239]|0)+5)|0;a[b]=(a[b]|0)+1&255;return}function fKs(){var b=0;b=(c[2426620]|0)+((d[9718239]|0)+6)|0;a[b]=(a[b]|0)+1&255;return}function fKt(){var b=0;b=(c[2426620]|0)+((d[9718239]|0)+7)|0;a[b]=(a[b]|0)+1&255;return}function fKu(){var b=0,e=0,f=0,g=0;b=a[9718224]|0;e=c[2426620]|0;f=e+(d[9718239]|0)|0;g=a[9718233]|0;a[9718224]=a[e+(g&a[f]&255)|0]|0;a[e+(a[f]&g&255)|0]=b;return}function fKv(){var b=0,e=0,f=0,g=0;b=a[9718224]|0;e=c[2426620]|0;f=e+((d[9718239]|0)+1)|0;g=a[9718233]|0;a[9718224]=a[e+(g&a[f]&255)|0]|0;a[e+(a[f]&g&255)|0]=b;return}function fKw(){var d=0,f=0,g=0,h=0;d=b[4859110]|0;f=d&65535;if((a[9718232]&1)!=0&(e[4859117]|0)>(d&65535)){d=gj[c[3541286]&4095](274)|0;a[9718231]=d;if(d<<24>>24==0){g=0}else{h=13839}}else{h=13839}if((h|0)==13839){g=gj[c[3541288]&4095](f)|0}b[4859110]=(b[4859110]|0)+1&65535;a[9718224]=g;return}function fKx(){var d=0,f=0,g=0,h=0;d=b[4859110]|0;f=d&65535;if((a[9718232]&1)!=0&(e[4859117]|0)>(d&65535)){d=gj[c[3541286]&4095](274)|0;a[9718231]=d;if(d<<24>>24==0){g=256}else{h=13843}}else{h=13843}if((h|0)==13843){g=(gj[c[3541290]&4095](f)|0)&255|256}b[4859110]=((a[9718237]|0)==0?b[4859123]|0:0)|g;return}function fKy(){a[9718245]=1;return}function fKz(){var d=0,f=0,g=0,h=0;d=b[4859110]|0;f=d&65535;if((a[9718232]&1)!=0&(e[4859117]|0)>(d&65535)){d=gj[c[3541286]&4095](274)|0;a[9718231]=d;if(d<<24>>24==0){g=0}else{h=13848}}else{h=13848}if((h|0)==13848){g=(gj[c[3541288]&4095](f)|0)&255}b[4859110]=(b[4859110]|0)+1&65535;if((gj[c[3541286]&4095](272)|0)<<24>>24!=0){return}b[4859110]=(b[4859110]|0)+4095&3840|g;return}function fKA(){a[9718224]=0;return}function fKB(){var b=0,e=0;b=a[9718224]|0;e=(c[2426620]|0)+(d[9718239]|0)|0;a[9718224]=a[e]|0;a[e]=b;return}function fKC(){var b=0,e=0;b=a[9718224]|0;e=(c[2426620]|0)+((d[9718239]|0)+1)|0;a[9718224]=a[e]|0;a[e]=b;return}function fKD(){var b=0,e=0;b=a[9718224]|0;e=(c[2426620]|0)+((d[9718239]|0)+2)|0;a[9718224]=a[e]|0;a[e]=b;return}function fKE(){var b=0,e=0;b=a[9718224]|0;e=(c[2426620]|0)+((d[9718239]|0)+3)|0;a[9718224]=a[e]|0;a[e]=b;return}function fKF(){var b=0,e=0;b=a[9718224]|0;e=(c[2426620]|0)+((d[9718239]|0)+4)|0;a[9718224]=a[e]|0;a[e]=b;return}function fKG(){var b=0,e=0;b=a[9718224]|0;e=(c[2426620]|0)+((d[9718239]|0)+5)|0;a[9718224]=a[e]|0;a[e]=b;return}function fKH(){var b=0,e=0;b=a[9718224]|0;e=(c[2426620]|0)+((d[9718239]|0)+6)|0;a[9718224]=a[e]|0;a[e]=b;return}function fKI(){var b=0,e=0;b=a[9718224]|0;e=(c[2426620]|0)+((d[9718239]|0)+7)|0;a[9718224]=a[e]|0;a[e]=b;return}function fKJ(){var b=0,e=0,f=0;b=c[2426620]|0;e=a[9718224]|0;f=b+(a[9718233]&a[b+(d[9718239]|0)|0]&255)|0;b=a[f]|0;a[9718224]=b&15|e&-16;a[f]=b&-16|e&15;return}function fKK(){var b=0,e=0,f=0;b=c[2426620]|0;e=a[9718224]|0;f=b+(a[9718233]&a[b+((d[9718239]|0)+1)|0]&255)|0;b=a[f]|0;a[9718224]=b&15|e&-16;a[f]=b&-16|e&15;return}function fKL(){var d=0,f=0,g=0,h=0;d=b[4859110]|0;f=d&65535;if((a[9718232]&1)!=0&(e[4859117]|0)>(d&65535)){d=gj[c[3541286]&4095](274)|0;a[9718231]=d;if(d<<24>>24==0){g=0}else{h=13867}}else{h=13867}if((h|0)==13867){g=(gj[c[3541288]&4095](f)|0)&255}f=b[4859110]|0;b[4859110]=f+1&65535;if((a[9718224]&2)==0){return}b[4859110]=f&3840|g;return}function fKM(){var d=0,f=0,g=0,h=0,i=0;d=b[4859110]|0;f=d&65535;if((a[9718232]&1)!=0&(e[4859117]|0)>(d&65535)){d=gj[c[3541286]&4095](274)|0;a[9718231]=d;if(d<<24>>24==0){g=256}else{h=13875}}else{h=13875}if((h|0)==13875){g=(gj[c[3541288]&4095](f)|0)&255|256}f=(b[4859110]|0)+1&65535;b[4859110]=f;h=((a[9718237]|0)==0?b[4859123]|0:0)|g;g=a[9718225]|0;a[9718225]=g+1&255;d=c[2426620]|0;a[d+((g&255)+8)|0]=f&255;f=a[9718225]&15;g=a[9718226]|0;a[9718226]=(f&255)>>>1|g&-8;i=a[9718221]&15|g&-16;a[9718225]=f+1&255;a[d+((f&255)+8)|0]=i;i=a[9718225]&15;a[9718225]=i;a[9718226]=(i&255)>>>1|a[9718226]&-8;b[4859110]=h;return}function fKN(){a[9718245]=0;a[9718236]=a[9718236]&-3;return}function fKO(){var d=0,f=0,g=0,h=0;d=b[4859110]|0;f=d&65535;if((a[9718232]&1)!=0&(e[4859117]|0)>(d&65535)){d=gj[c[3541286]&4095](274)|0;a[9718231]=d;if(d<<24>>24==0){g=0}else{h=13880}}else{h=13880}if((h|0)==13880){g=(gj[c[3541288]&4095](f)|0)&255}b[4859110]=(b[4859110]|0)+1&65535;if((gj[c[3541286]&4095](272)|0)<<24>>24==0){return}b[4859110]=(b[4859110]|0)+4095&3840|g;return}function fKP(){a[9718224]=~a[9718224];return}function fKQ(){gg[c[3541284]&4095](257,a[9718224]|0);a[9718229]=a[9718224]|0;return}function fKR(){gg[c[3541284]&4095](258,a[9718224]|0);a[9718230]=a[9718224]|0;return}function fKS(){gg[c[3541284]&4095](260,a[9718224]&15);return}function fKT(){gg[c[3541284]&4095](261,a[9718224]&15);return}function fKU(){gg[c[3541284]&4095](262,a[9718224]&15);return}function fKV(){gg[c[3541284]&4095](263,a[9718224]&15);return}function fKW(){var b=0;b=c[2426620]|0;a[9718224]=a[9718224]|a[b+(a[9718233]&a[b+(d[9718239]|0)|0]&255)|0];return}function fKX(){var b=0;b=c[2426620]|0;a[9718224]=a[9718224]|a[b+(a[9718233]&a[b+((d[9718239]|0)+1)|0]&255)|0];return}function fKY(){a[9718224]=a[9718241]|0;return}function fKZ(){var d=0,f=0,g=0,h=0;d=b[4859110]|0;f=d&65535;if((a[9718232]&1)!=0&(e[4859117]|0)>(d&65535)){d=gj[c[3541286]&4095](274)|0;a[9718231]=d;if(d<<24>>24==0){g=0}else{h=13898}}else{h=13898}if((h|0)==13898){g=gj[c[3541288]&4095](f)|0}b[4859110]=(b[4859110]|0)+1&65535;a[9718224]=a[9718224]|g;return}function fK_(){var d=0,f=0,g=0,h=0;d=b[4859110]|0;f=d&65535;if((a[9718232]&1)!=0&(e[4859117]|0)>(d&65535)){d=gj[c[3541286]&4095](274)|0;a[9718231]=d;if(d<<24>>24==0){g=512}else{h=13902}}else{h=13902}if((h|0)==13902){g=(gj[c[3541290]&4095](f)|0)&255|512}b[4859110]=((a[9718237]|0)==0?b[4859123]|0:0)|g;return}function fK$(){a[9718243]=1;a[9718242]=0;a[9718260]=gj[c[3541286]&4095](273)|0;return}function fK0(){var d=0,f=0,g=0,h=0;d=b[4859110]|0;f=d&65535;if((a[9718232]&1)!=0&(e[4859117]|0)>(d&65535)){d=gj[c[3541286]&4095](274)|0;a[9718231]=d;if(d<<24>>24==0){g=0}else{h=13907}}else{h=13907}if((h|0)==13907){g=(gj[c[3541288]&4095](f)|0)&255}b[4859110]=(b[4859110]|0)+1&65535;if((gj[c[3541286]&4095](273)|0)<<24>>24!=0){return}b[4859110]=(b[4859110]|0)+4095&3840|g;return}function fK1(){var b=0;b=a[9718224]|0;a[9718224]=b<<4|(b&255)>>>4;return}function fK2(){a[9718224]=a[9718224]|a[(c[2426620]|0)+(d[9718239]|0)|0];return}function fK3(){a[9718224]=a[9718224]|a[(c[2426620]|0)+((d[9718239]|0)+1)|0];return}function fK4(){a[9718224]=a[9718224]|a[(c[2426620]|0)+((d[9718239]|0)+2)|0];return}function fK5(){a[9718224]=a[9718224]|a[(c[2426620]|0)+((d[9718239]|0)+3)|0];return}function fK6(){a[9718224]=a[9718224]|a[(c[2426620]|0)+((d[9718239]|0)+4)|0];return}function fK7(){a[9718224]=a[9718224]|a[(c[2426620]|0)+((d[9718239]|0)+5)|0];return}function fK8(){a[9718224]=a[9718224]|a[(c[2426620]|0)+((d[9718239]|0)+6)|0];return}function fK9(){a[9718224]=a[9718224]|a[(c[2426620]|0)+((d[9718239]|0)+7)|0];return}function fLa(){var b=0;b=c[2426620]|0;a[9718224]=a[9718224]&a[b+(a[9718233]&a[b+(d[9718239]|0)|0]&255)|0];return}function fLb(){var b=0;b=c[2426620]|0;a[9718224]=a[9718224]&a[b+(a[9718233]&a[b+((d[9718239]|0)+1)|0]&255)|0];return}function fLc(){var d=0,f=0,g=0,h=0;d=b[4859110]|0;f=d&65535;if((a[9718232]&1)!=0&(e[4859117]|0)>(d&65535)){d=gj[c[3541286]&4095](274)|0;a[9718231]=d;if(d<<24>>24==0){g=0}else{h=13926}}else{h=13926}if((h|0)==13926){g=(gj[c[3541288]&4095](f)|0)&255}f=b[4859110]|0;b[4859110]=f+1&65535;if((a[9718224]&4)==0){return}b[4859110]=f&3840|g;return}function fLd(){var d=0,f=0,g=0,h=0;d=b[4859110]|0;f=d&65535;if((a[9718232]&1)!=0&(e[4859117]|0)>(d&65535)){d=gj[c[3541286]&4095](274)|0;a[9718231]=d;if(d<<24>>24==0){g=0}else{h=13934}}else{h=13934}if((h|0)==13934){g=gj[c[3541288]&4095](f)|0}b[4859110]=(b[4859110]|0)+1&65535;a[9718224]=a[9718224]&g;return}function fLe(){var d=0,f=0,g=0,h=0,i=0;d=b[4859110]|0;f=d&65535;if((a[9718232]&1)!=0&(e[4859117]|0)>(d&65535)){d=gj[c[3541286]&4095](274)|0;a[9718231]=d;if(d<<24>>24==0){g=512}else{h=13938}}else{h=13938}if((h|0)==13938){g=(gj[c[3541288]&4095](f)|0)&255|512}f=(b[4859110]|0)+1&65535;b[4859110]=f;h=((a[9718237]|0)==0?b[4859123]|0:0)|g;g=a[9718225]|0;a[9718225]=g+1&255;d=c[2426620]|0;a[d+((g&255)+8)|0]=f&255;f=a[9718225]&15;g=a[9718226]|0;a[9718226]=(f&255)>>>1|g&-8;i=a[9718221]&15|g&-16;a[9718225]=f+1&255;a[d+((f&255)+8)|0]=i;i=a[9718225]&15;a[9718225]=i;a[9718226]=(i&255)>>>1|a[9718226]&-8;b[4859110]=h;return}function fLf(){a[9718242]=1;a[9718243]=0;a[9718238]=0;return}function fLg(){var d=0,f=0,g=0,h=0;d=b[4859110]|0;f=d&65535;if((a[9718232]&1)!=0&(e[4859117]|0)>(d&65535)){d=gj[c[3541286]&4095](274)|0;a[9718231]=d;if(d<<24>>24==0){g=0}else{h=13943}}else{h=13943}if((h|0)==13943){g=(gj[c[3541288]&4095](f)|0)&255}b[4859110]=(b[4859110]|0)+1&65535;if((gj[c[3541286]&4095](273)|0)<<24>>24==0){return}b[4859110]=(b[4859110]|0)+4095&3840|g;return}function fLh(){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a[9718224]|0;c=a[9718226]|0;if((b&14)>>>0>9){d=13951}else{if((c&64)==0){e=b;d=13953}else{d=13951}}do{if((d|0)==13951){f=b+6&255;a[9718224]=f;if((f&255)>15){e=f;d=13953;break}g=c|-128;a[9718226]=g;h=g;i=f}}while(0);do{if((d|0)==13953){if((e&240)>>>0>144|c<<24>>24<0){h=c;i=e;break}j=c&127;a[9718226]=j;return}}while(0);a[9718224]=i+96&255;j=h|-128;a[9718226]=j;return}function fLi(){a[9718224]=a[9718224]&a[(c[2426620]|0)+(d[9718239]|0)|0];return}function fLj(){a[9718224]=a[9718224]&a[(c[2426620]|0)+((d[9718239]|0)+1)|0];return}function fLk(){a[9718224]=a[9718224]&a[(c[2426620]|0)+((d[9718239]|0)+2)|0];return}function fLl(){a[9718224]=a[9718224]&a[(c[2426620]|0)+((d[9718239]|0)+3)|0];return}function fLm(){a[9718224]=a[9718224]&a[(c[2426620]|0)+((d[9718239]|0)+4)|0];return}function fLn(){a[9718224]=a[9718224]&a[(c[2426620]|0)+((d[9718239]|0)+5)|0];return}function fLo(){a[9718224]=a[9718224]&a[(c[2426620]|0)+((d[9718239]|0)+6)|0];return}function fLp(){a[9718224]=a[9718224]&a[(c[2426620]|0)+((d[9718239]|0)+7)|0];return}function fLq(){var b=0,e=0,f=0,g=0,h=0,i=0;b=c[2426620]|0;e=a[b+(a[9718233]&a[b+(d[9718239]|0)|0]&255)|0]|0;b=a[9718226]&63;a[9718226]=b;f=d[9718224]|0;g=e&255;if(((f&15)+(g&15)|0)>15){e=b|64;a[9718226]=e;h=e}else{h=b}b=f+g|0;if((b&65280)>>>0<=255){i=b&255;a[9718224]=i;return}a[9718226]=h|-128;i=b&255;a[9718224]=i;return}function fLr(){var b=0,e=0,f=0,g=0,h=0,i=0;b=c[2426620]|0;e=a[b+(a[9718233]&a[b+((d[9718239]|0)+1)|0]&255)|0]|0;b=a[9718226]&63;a[9718226]=b;f=d[9718224]|0;g=e&255;if(((f&15)+(g&15)|0)>15){e=b|64;a[9718226]=e;h=e}else{h=b}b=f+g|0;if((b&65280)>>>0<=255){i=b&255;a[9718224]=i;return}a[9718226]=h|-128;i=b&255;a[9718224]=i;return}function fLs(){a[9718241]=a[9718224]|0;return}function fLt(){var d=0,f=0,g=0,h=0;d=b[4859110]|0;f=d&65535;if((a[9718232]&1)!=0&(e[4859117]|0)>(d&65535)){d=gj[c[3541286]&4095](274)|0;a[9718231]=d;if(d<<24>>24==0){g=768}else{h=13984}}else{h=13984}if((h|0)==13984){g=(gj[c[3541290]&4095](f)|0)&255|768}b[4859110]=((a[9718237]|0)==0?b[4859123]|0:0)|g;return}function fLu(){a[9718243]=0;a[9718242]=0;return}function fLv(){var b=0,c=0,d=0;b=a[9718226]|0;c=a[9718224]|0;a[9718226]=(c&1)==0?b&127:b|-128;d=(c&255)>>>1;a[9718224]=b<<24>>24<0?d|-128:d;return}function fLw(){var b=0,e=0,f=0,g=0,h=0,i=0;b=a[(c[2426620]|0)+(d[9718239]|0)|0]|0;e=a[9718226]&63;a[9718226]=e;f=d[9718224]|0;g=b&255;if(((f&15)+(g&15)|0)>15){b=e|64;a[9718226]=b;h=b}else{h=e}e=f+g|0;if((e&65280)>>>0<=255){i=e&255;a[9718224]=i;return}a[9718226]=h|-128;i=e&255;a[9718224]=i;return}function fLx(){var b=0,e=0,f=0,g=0,h=0,i=0;b=a[(c[2426620]|0)+((d[9718239]|0)+1)|0]|0;e=a[9718226]&63;a[9718226]=e;f=d[9718224]|0;g=b&255;if(((f&15)+(g&15)|0)>15){b=e|64;a[9718226]=b;h=b}else{h=e}e=f+g|0;if((e&65280)>>>0<=255){i=e&255;a[9718224]=i;return}a[9718226]=h|-128;i=e&255;a[9718224]=i;return}function fLy(){var b=0,e=0,f=0,g=0,h=0,i=0;b=a[(c[2426620]|0)+((d[9718239]|0)+2)|0]|0;e=a[9718226]&63;a[9718226]=e;f=d[9718224]|0;g=b&255;if(((f&15)+(g&15)|0)>15){b=e|64;a[9718226]=b;h=b}else{h=e}e=f+g|0;if((e&65280)>>>0<=255){i=e&255;a[9718224]=i;return}a[9718226]=h|-128;i=e&255;a[9718224]=i;return}function fLz(){var b=0,e=0,f=0,g=0,h=0,i=0;b=a[(c[2426620]|0)+((d[9718239]|0)+3)|0]|0;e=a[9718226]&63;a[9718226]=e;f=d[9718224]|0;g=b&255;if(((f&15)+(g&15)|0)>15){b=e|64;a[9718226]=b;h=b}else{h=e}e=f+g|0;if((e&65280)>>>0<=255){i=e&255;a[9718224]=i;return}a[9718226]=h|-128;i=e&255;a[9718224]=i;return}function fLA(){var b=0,e=0,f=0,g=0,h=0,i=0;b=a[(c[2426620]|0)+((d[9718239]|0)+4)|0]|0;e=a[9718226]&63;a[9718226]=e;f=d[9718224]|0;g=b&255;if(((f&15)+(g&15)|0)>15){b=e|64;a[9718226]=b;h=b}else{h=e}e=f+g|0;if((e&65280)>>>0<=255){i=e&255;a[9718224]=i;return}a[9718226]=h|-128;i=e&255;a[9718224]=i;return}function fLB(){var b=0,e=0,f=0,g=0,h=0,i=0;b=a[(c[2426620]|0)+((d[9718239]|0)+5)|0]|0;e=a[9718226]&63;a[9718226]=e;f=d[9718224]|0;g=b&255;if(((f&15)+(g&15)|0)>15){b=e|64;a[9718226]=b;h=b}else{h=e}e=f+g|0;if((e&65280)>>>0<=255){i=e&255;a[9718224]=i;return}a[9718226]=h|-128;i=e&255;a[9718224]=i;return}function fLC(){var b=0,e=0,f=0,g=0,h=0,i=0;b=a[(c[2426620]|0)+((d[9718239]|0)+6)|0]|0;e=a[9718226]&63;a[9718226]=e;f=d[9718224]|0;g=b&255;if(((f&15)+(g&15)|0)>15){b=e|64;a[9718226]=b;h=b}else{h=e}e=f+g|0;if((e&65280)>>>0<=255){i=e&255;a[9718224]=i;return}a[9718226]=h|-128;i=e&255;a[9718224]=i;return}function fLD(){var b=0,e=0,f=0,g=0,h=0,i=0;b=a[(c[2426620]|0)+((d[9718239]|0)+7)|0]|0;e=a[9718226]&63;a[9718226]=e;f=d[9718224]|0;g=b&255;if(((f&15)+(g&15)|0)>15){b=e|64;a[9718226]=b;h=b}else{h=e}e=f+g|0;if((e&65280)>>>0<=255){i=e&255;a[9718224]=i;return}a[9718226]=h|-128;i=e&255;a[9718224]=i;return}function fLE(){var b=0,e=0,f=0,g=0,h=0,i=0;b=c[2426620]|0;e=a[b+(a[9718233]&a[b+(d[9718239]|0)|0]&255)|0]|0;b=a[9718226]|0;f=b&-65;a[9718226]=f;g=d[9718224]|0;h=e&255;if((((b&255)>>>7)+(h&15)+(g&15)|0)>15){e=b|64;a[9718226]=e;i=e}else{i=f}f=g+h+((i&255)>>>7)|0;a[9718226]=(f&65280)>>>0>255?i|-128:i&127;a[9718224]=f&255;return}function fLF(){var b=0,e=0,f=0,g=0,h=0,i=0;b=c[2426620]|0;e=a[b+(a[9718233]&a[b+((d[9718239]|0)+1)|0]&255)|0]|0;b=a[9718226]|0;f=b&-65;a[9718226]=f;g=d[9718224]|0;h=e&255;if((((b&255)>>>7)+(h&15)+(g&15)|0)>15){e=b|64;a[9718226]=e;i=e}else{i=f}f=g+h+((i&255)>>>7)|0;a[9718226]=(f&65280)>>>0>255?i|-128:i&127;a[9718224]=f&255;return}function fLG(){var d=0,f=0,g=0,h=0;d=b[4859110]|0;f=d&65535;if((a[9718232]&1)!=0&(e[4859117]|0)>(d&65535)){d=gj[c[3541286]&4095](274)|0;a[9718231]=d;if(d<<24>>24==0){g=0}else{h=14052}}else{h=14052}if((h|0)==14052){g=(gj[c[3541288]&4095](f)|0)&255}f=b[4859110]|0;b[4859110]=f+1&65535;if((a[9718224]&8)==0){return}b[4859110]=f&3840|g;return}function fLH(){var d=0,f=0,g=0,h=0,i=0;d=b[4859110]|0;f=d&65535;if((a[9718232]&1)!=0&(e[4859117]|0)>(d&65535)){d=gj[c[3541286]&4095](274)|0;a[9718231]=d;if(d<<24>>24==0){g=768}else{h=14060}}else{h=14060}if((h|0)==14060){g=(gj[c[3541288]&4095](f)|0)&255|768}f=(b[4859110]|0)+1&65535;b[4859110]=f;h=((a[9718237]|0)==0?b[4859123]|0:0)|g;g=a[9718225]|0;a[9718225]=g+1&255;d=c[2426620]|0;a[d+((g&255)+8)|0]=f&255;f=a[9718225]&15;g=a[9718226]|0;a[9718226]=(f&255)>>>1|g&-8;i=a[9718221]&15|g&-16;a[9718225]=f+1&255;a[d+((f&255)+8)|0]=i;i=a[9718225]&15;a[9718225]=i;a[9718226]=(i&255)>>>1|a[9718226]&-8;b[4859110]=h;return}function fLI(){return}function fLJ(){var d=0,f=0,g=0,h=0;d=b[4859110]|0;f=d&65535;if((a[9718232]&1)!=0&(e[4859117]|0)>(d&65535)){d=gj[c[3541286]&4095](274)|0;a[9718231]=d;if(d<<24>>24==0){g=0}else{h=14065}}else{h=14065}if((h|0)==14065){g=(gj[c[3541288]&4095](f)|0)&255}f=b[4859110]|0;b[4859110]=f+1&65535;if((a[9718228]|0)==0){return}b[4859110]=f&3840|g;return}function fLK(){var b=0,c=0;b=a[9718224]|0;c=(b&255)>>>1;a[9718224]=(b&1)==0?c:c|-128;return}function fLL(){var b=0,e=0,f=0,g=0,h=0,i=0;b=a[(c[2426620]|0)+(d[9718239]|0)|0]|0;e=a[9718226]|0;f=e&-65;a[9718226]=f;g=d[9718224]|0;h=b&255;if((((e&255)>>>7)+(h&15)+(g&15)|0)>15){b=e|64;a[9718226]=b;i=b}else{i=f}f=g+h+((i&255)>>>7)|0;a[9718226]=(f&65280)>>>0>255?i|-128:i&127;a[9718224]=f&255;return}function fLM(){var b=0,e=0,f=0,g=0,h=0,i=0;b=a[(c[2426620]|0)+((d[9718239]|0)+1)|0]|0;e=a[9718226]|0;f=e&-65;a[9718226]=f;g=d[9718224]|0;h=b&255;if((((e&255)>>>7)+(h&15)+(g&15)|0)>15){b=e|64;a[9718226]=b;i=b}else{i=f}f=g+h+((i&255)>>>7)|0;a[9718226]=(f&65280)>>>0>255?i|-128:i&127;a[9718224]=f&255;return}function fLN(){var b=0,e=0,f=0,g=0,h=0,i=0;b=a[(c[2426620]|0)+((d[9718239]|0)+2)|0]|0;e=a[9718226]|0;f=e&-65;a[9718226]=f;g=d[9718224]|0;h=b&255;if((((e&255)>>>7)+(h&15)+(g&15)|0)>15){b=e|64;a[9718226]=b;i=b}else{i=f}f=g+h+((i&255)>>>7)|0;a[9718226]=(f&65280)>>>0>255?i|-128:i&127;a[9718224]=f&255;return}function fLO(){var b=0,e=0,f=0,g=0,h=0,i=0;b=a[(c[2426620]|0)+((d[9718239]|0)+3)|0]|0;e=a[9718226]|0;f=e&-65;a[9718226]=f;g=d[9718224]|0;h=b&255;if((((e&255)>>>7)+(h&15)+(g&15)|0)>15){b=e|64;a[9718226]=b;i=b}else{i=f}f=g+h+((i&255)>>>7)|0;a[9718226]=(f&65280)>>>0>255?i|-128:i&127;a[9718224]=f&255;return}function fLP(){var b=0,e=0,f=0,g=0,h=0,i=0;b=a[(c[2426620]|0)+((d[9718239]|0)+4)|0]|0;e=a[9718226]|0;f=e&-65;a[9718226]=f;g=d[9718224]|0;h=b&255;if((((e&255)>>>7)+(h&15)+(g&15)|0)>15){b=e|64;a[9718226]=b;i=b}else{i=f}f=g+h+((i&255)>>>7)|0;a[9718226]=(f&65280)>>>0>255?i|-128:i&127;a[9718224]=f&255;return}function fLQ(){var b=0,e=0,f=0,g=0,h=0,i=0;b=a[(c[2426620]|0)+((d[9718239]|0)+5)|0]|0;e=a[9718226]|0;f=e&-65;a[9718226]=f;g=d[9718224]|0;h=b&255;if((((e&255)>>>7)+(h&15)+(g&15)|0)>15){b=e|64;a[9718226]=b;i=b}else{i=f}f=g+h+((i&255)>>>7)|0;a[9718226]=(f&65280)>>>0>255?i|-128:i&127;a[9718224]=f&255;return}function fLR(){var b=0,e=0,f=0,g=0,h=0,i=0;b=a[(c[2426620]|0)+((d[9718239]|0)+6)|0]|0;e=a[9718226]|0;f=e&-65;a[9718226]=f;g=d[9718224]|0;h=b&255;if((((e&255)>>>7)+(h&15)+(g&15)|0)>15){b=e|64;a[9718226]=b;i=b}else{i=f}f=g+h+((i&255)>>>7)|0;a[9718226]=(f&65280)>>>0>255?i|-128:i&127;a[9718224]=f&255;return}function fLS(){var b=0,e=0,f=0,g=0,h=0,i=0;b=a[(c[2426620]|0)+((d[9718239]|0)+7)|0]|0;e=a[9718226]|0;f=e&-65;a[9718226]=f;g=d[9718224]|0;h=b&255;if((((e&255)>>>7)+(h&15)+(g&15)|0)>15){b=e|64;a[9718226]=b;i=b}else{i=f}f=g+h+((i&255)>>>7)|0;a[9718226]=(f&65280)>>>0>255?i|-128:i&127;a[9718224]=f&255;return}function fLT(){a[9718224]=gj[c[3541286]&4095](d[(c[2426620]|0)+(d[9718239]|0)|0]|0)|0;return}function fLU(){a[9718224]=gj[c[3541286]&4095](d[(c[2426620]|0)+((d[9718239]|0)+1)|0]|0)|0;return}function fLV(){var e=0,f=0,g=0,h=0,i=0;e=a[9718225]|0;f=e+15&15;a[9718225]=f;g=a[9718226]&-8;a[9718226]=(f&255)>>>1|g;h=c[2426620]|0;i=(d[h+((f&255)+8)|0]|0)<<8&3840;b[4859110]=i;f=e+14&15;a[9718225]=f;a[9718226]=(f&255)>>>1|g;b[4859110]=i|(d[h+((f&255)+8)|0]|0);return}function fLW(){var d=0,f=0,g=0,h=0;d=b[4859110]|0;f=d&65535;if((a[9718232]&1)!=0&(e[4859117]|0)>(d&65535)){d=gj[c[3541286]&4095](274)|0;a[9718231]=d;if(d<<24>>24==0){g=1024}else{h=14101}}else{h=14101}if((h|0)==14101){g=(gj[c[3541290]&4095](f)|0)&255|1024}b[4859110]=((a[9718237]|0)==0?b[4859123]|0:0)|g;return}function fLX(){a[9718226]=a[9718226]&-33;return}function fLY(){var d=0,f=0,g=0,h=0;d=b[4859110]|0;f=d&65535;if((a[9718232]&1)!=0&(e[4859117]|0)>(d&65535)){d=gj[c[3541286]&4095](274)|0;a[9718231]=d;if(d<<24>>24==0){g=0}else{h=14106}}else{h=14106}if((h|0)==14106){g=(gj[c[3541288]&4095](f)|0)&255}f=b[4859110]|0;b[4859110]=f+1&65535;if((a[9718248]|0)!=1){return}b[4859110]=f&3840|g;return}function fLZ(){var d=0,f=0,g=0,h=0,i=0,j=0;d=c[3541284]|0;f=gj[c[3541286]&4095](288)|0;g=b[4859110]|0;h=g&65535;if((a[9718232]&1)!=0&(e[4859117]|0)>(g&65535)){g=gj[c[3541286]&4095](274)|0;a[9718231]=g;if(g<<24>>24==0){i=0}else{j=14114}}else{j=14114}if((j|0)==14114){i=gj[c[3541288]&4095](h)|0}b[4859110]=(b[4859110]|0)+1&65535;gg[d&4095](288,i|f);return}function fL_(){var d=0,f=0,g=0,h=0;d=b[4859110]|0;f=d&65535;if((a[9718232]&1)!=0&(e[4859117]|0)>(d&65535)){d=gj[c[3541286]&4095](274)|0;a[9718231]=d;if(d<<24>>24==0){g=0}else{h=14118}}else{h=14118}if((h|0)==14118){g=gj[c[3541288]&4095](f)|0}b[4859110]=(b[4859110]|0)+1&65535;f=a[9718229]|g;a[9718229]=f;gg[c[3541284]&4095](257,f);return}function fL$(){var d=0,f=0,g=0,h=0;d=b[4859110]|0;f=d&65535;if((a[9718232]&1)!=0&(e[4859117]|0)>(d&65535)){d=gj[c[3541286]&4095](274)|0;a[9718231]=d;if(d<<24>>24==0){g=0}else{h=14122}}else{h=14122}if((h|0)==14122){g=gj[c[3541288]&4095](f)|0}b[4859110]=(b[4859110]|0)+1&65535;f=a[9718230]|g;a[9718230]=f;gg[c[3541284]&4095](258,f);return}function fL0(){var b=0,d=0;b=c[3541284]|0;d=gj[c[3541286]&4095](260)|0;gg[b&4095](260,a[9718224]|d);return}function fL1(){var b=0,d=0;b=c[3541284]|0;d=gj[c[3541286]&4095](261)|0;gg[b&4095](261,a[9718224]|d);return}function fL2(){var b=0,d=0;b=c[3541284]|0;d=gj[c[3541286]&4095](262)|0;gg[b&4095](262,a[9718224]|d);return}function fL3(){var b=0,d=0;b=c[3541284]|0;d=gj[c[3541286]&4095](263)|0;gg[b&4095](263,a[9718224]|d);return}function fL4(){gg[c[3541284]&4095](d[(c[2426620]|0)+(d[9718239]|0)|0]|0,a[9718224]|0);return}function fL5(){gg[c[3541284]&4095](d[(c[2426620]|0)+((d[9718239]|0)+1)|0]|0,a[9718224]|0);return}function fL6(){var d=0,f=0,g=0,h=0;d=b[4859110]|0;f=d&65535;if((a[9718232]&1)!=0&(e[4859117]|0)>(d&65535)){d=gj[c[3541286]&4095](274)|0;a[9718231]=d;if(d<<24>>24==0){g=0}else{h=14132}}else{h=14132}if((h|0)==14132){g=(gj[c[3541288]&4095](f)|0)&255}f=b[4859110]|0;b[4859110]=f+1&65535;if((a[9718224]&16)==0){return}b[4859110]=f&3840|g;return}function fL7(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=a[9718225]|0;e=d+15&15;a[9718225]=e;f=a[9718226]&-8;a[9718226]=(e&255)>>>1|f;g=c[2426620]|0;h=a[g+((e&255)+8)|0]|0;e=d+14&15;a[9718225]=e;d=(e&255)>>>1|f;a[9718226]=d;f=g+((e&255)+8)|0;i=a[f]|0;b[4859110]=(h&255)<<8&3840|i&255;a[9718226]=d&15|h&-16;a[9718239]=(h&16)!=0?24:0;a[9718237]=0;if((a[9718248]|0)==1){do{if((a[9718244]|0)==0){j=0}else{a[9718237]=1;a[9718225]=e+1&255;a[f]=i;h=a[9718225]&15;d=a[9718226]|0;a[9718226]=(h&255)>>>1|d&-8;k=a[9718221]&15|d&-16;a[9718225]=h+1&255;a[g+((h&255)+8)|0]=k;k=a[9718225]&15;a[9718225]=k;a[9718226]=(k&255)>>>1|a[9718226]&-8;b[4859110]=3;if((a[9718242]|0)!=0){a[9718238]=(a[9718238]|0)+2&255}k=c[2429563]|0;if((k|0)==0){j=2;break}gj[k&4095](0)|0;j=2}}while(0);a[9718249]=(a[9718249]|0)+j&255;return}else{if((a[9718236]|0)!=2){return}do{if((a[9718245]|0)==0){l=0}else{a[9718237]=2;a[9718236]=0;a[9718225]=e+1&255;a[f]=i;j=a[9718225]&15;k=a[9718226]|0;a[9718226]=(j&255)>>>1|k&-8;h=a[9718221]&15|k&-16;a[9718225]=j+1&255;a[g+((j&255)+8)|0]=h;h=a[9718225]&15;a[9718225]=h;a[9718226]=(h&255)>>>1|a[9718226]&-8;b[4859110]=7;if((a[9718242]|0)==0){l=2;break}a[9718238]=(a[9718238]|0)+2&255;l=2}}while(0);a[9718240]=1;a[9718249]=(a[9718249]|0)+l&255;return}}function fL8(){var d=0,f=0,g=0,h=0,i=0;d=b[4859110]|0;f=d&65535;if((a[9718232]&1)!=0&(e[4859117]|0)>(d&65535)){d=gj[c[3541286]&4095](274)|0;a[9718231]=d;if(d<<24>>24==0){g=1024}else{h=14156}}else{h=14156}if((h|0)==14156){g=(gj[c[3541288]&4095](f)|0)&255|1024}f=(b[4859110]|0)+1&65535;b[4859110]=f;h=((a[9718237]|0)==0?b[4859123]|0:0)|g;g=a[9718225]|0;a[9718225]=g+1&255;d=c[2426620]|0;a[d+((g&255)+8)|0]=f&255;f=a[9718225]&15;g=a[9718226]|0;a[9718226]=(f&255)>>>1|g&-8;i=a[9718221]&15|g&-16;a[9718225]=f+1&255;a[d+((f&255)+8)|0]=i;i=a[9718225]&15;a[9718225]=i;a[9718226]=(i&255)>>>1|a[9718226]&-8;b[4859110]=h;return}function fL9(){a[9718226]=a[9718226]^32;return}function fMa(){var d=0,f=0,g=0,h=0;d=b[4859110]|0;f=d&65535;if((a[9718232]&1)!=0&(e[4859117]|0)>(d&65535)){d=gj[c[3541286]&4095](274)|0;a[9718231]=d;if(d<<24>>24==0){g=0}else{h=14161}}else{h=14161}if((h|0)==14161){g=(gj[c[3541288]&4095](f)|0)&255}f=b[4859110]|0;b[4859110]=f+1&65535;if((a[9718224]|0)==0){return}b[4859110]=f&3840|g;return}function fMb(){a[9718226]=a[9718226]&127;return}function fMc(){var d=0,f=0,g=0,h=0,i=0,j=0;d=c[3541284]|0;f=gj[c[3541286]&4095](288)|0;g=b[4859110]|0;h=g&65535;if((a[9718232]&1)!=0&(e[4859117]|0)>(g&65535)){g=gj[c[3541286]&4095](274)|0;a[9718231]=g;if(g<<24>>24==0){i=0}else{j=14170}}else{j=14170}if((j|0)==14170){i=gj[c[3541288]&4095](h)|0}b[4859110]=(b[4859110]|0)+1&65535;gg[d&4095](288,i&f);return}function fMd(){var d=0,f=0,g=0,h=0;d=b[4859110]|0;f=d&65535;if((a[9718232]&1)!=0&(e[4859117]|0)>(d&65535)){d=gj[c[3541286]&4095](274)|0;a[9718231]=d;if(d<<24>>24==0){g=0}else{h=14174}}else{h=14174}if((h|0)==14174){g=gj[c[3541288]&4095](f)|0}b[4859110]=(b[4859110]|0)+1&65535;f=a[9718229]&g;a[9718229]=f;gg[c[3541284]&4095](257,f);return}function fMe(){var d=0,f=0,g=0,h=0;d=b[4859110]|0;f=d&65535;if((a[9718232]&1)!=0&(e[4859117]|0)>(d&65535)){d=gj[c[3541286]&4095](274)|0;a[9718231]=d;if(d<<24>>24==0){g=0}else{h=14178}}else{h=14178}if((h|0)==14178){g=gj[c[3541288]&4095](f)|0}b[4859110]=(b[4859110]|0)+1&65535;f=a[9718230]&g;a[9718230]=f;gg[c[3541284]&4095](258,f);return}function fMf(){var d=0,f=0,g=0,h=0,i=0,j=0;d=c[3541284]|0;f=gj[c[3541286]&4095](260)|0;g=b[4859110]|0;h=g&65535;if((a[9718232]&1)!=0&(e[4859117]|0)>(g&65535)){g=gj[c[3541286]&4095](274)|0;a[9718231]=g;if(g<<24>>24==0){i=0}else{j=14182}}else{j=14182}if((j|0)==14182){i=gj[c[3541288]&4095](h)|0}b[4859110]=(b[4859110]|0)+1&65535;gg[d&4095](260,f&15&i);return}function fMg(){var d=0,f=0,g=0,h=0,i=0,j=0;d=c[3541284]|0;f=gj[c[3541286]&4095](261)|0;g=b[4859110]|0;h=g&65535;if((a[9718232]&1)!=0&(e[4859117]|0)>(g&65535)){g=gj[c[3541286]&4095](274)|0;a[9718231]=g;if(g<<24>>24==0){i=0}else{j=14186}}else{j=14186}if((j|0)==14186){i=gj[c[3541288]&4095](h)|0}b[4859110]=(b[4859110]|0)+1&65535;gg[d&4095](261,f&15&i);return}function fMh(){var d=0,f=0,g=0,h=0,i=0,j=0;d=c[3541284]|0;f=gj[c[3541286]&4095](262)|0;g=b[4859110]|0;h=g&65535;if((a[9718232]&1)!=0&(e[4859117]|0)>(g&65535)){g=gj[c[3541286]&4095](274)|0;a[9718231]=g;if(g<<24>>24==0){i=0}else{j=14190}}else{j=14190}if((j|0)==14190){i=gj[c[3541288]&4095](h)|0}b[4859110]=(b[4859110]|0)+1&65535;gg[d&4095](262,f&15&i);return}function fMi(){var d=0,f=0,g=0,h=0,i=0,j=0;d=c[3541284]|0;f=gj[c[3541286]&4095](263)|0;g=b[4859110]|0;h=g&65535;if((a[9718232]&1)!=0&(e[4859117]|0)>(g&65535)){g=gj[c[3541286]&4095](274)|0;a[9718231]=g;if(g<<24>>24==0){i=0}else{j=14194}}else{j=14194}if((j|0)==14194){i=gj[c[3541288]&4095](h)|0}b[4859110]=(b[4859110]|0)+1&65535;gg[d&4095](263,f&15&i);return}function fMj(){var b=0;b=c[2426620]|0;a[b+(a[9718233]&a[b+(d[9718239]|0)|0]&255)|0]=a[9718224]|0;return}function fMk(){var b=0;b=c[2426620]|0;a[b+(a[9718233]&a[b+((d[9718239]|0)+1)|0]&255)|0]=a[9718224]|0;return}function fMl(){a[9718224]=gj[c[3541282]&4095](b[4859110]&3840|(d[9718224]|0))|0;return}function fMm(){var d=0,f=0,g=0,h=0;d=b[4859110]|0;f=d&65535;if((a[9718232]&1)!=0&(e[4859117]|0)>(d&65535)){d=gj[c[3541286]&4095](274)|0;a[9718231]=d;if(d<<24>>24==0){g=1280}else{h=14201}}else{h=14201}if((h|0)==14201){g=(gj[c[3541290]&4095](f)|0)&255|1280}b[4859110]=((a[9718237]|0)==0?b[4859123]|0:0)|g;return}function fMn(){a[9718228]=0;return}function fMo(){a[9718226]=a[9718226]^-128;return}function fMp(){a[(c[2426620]|0)+(d[9718239]|0)|0]=a[9718224]|0;return}function fMq(){a[(c[2426620]|0)+((d[9718239]|0)+1)|0]=a[9718224]|0;return}function fMr(){a[(c[2426620]|0)+((d[9718239]|0)+2)|0]=a[9718224]|0;return}function fMs(){a[(c[2426620]|0)+((d[9718239]|0)+3)|0]=a[9718224]|0;return}function fMt(){a[(c[2426620]|0)+((d[9718239]|0)+4)|0]=a[9718224]|0;return}function fMu(){a[(c[2426620]|0)+((d[9718239]|0)+5)|0]=a[9718224]|0;return}function fMv(){a[(c[2426620]|0)+((d[9718239]|0)+6)|0]=a[9718224]|0;return}function fMw(){a[(c[2426620]|0)+((d[9718239]|0)+7)|0]=a[9718224]|0;return}function fMx(){var f=0,g=0,h=0,i=0;f=b[4859110]|0;g=f&65535;if((a[9718232]&1)!=0&(e[4859117]|0)>(f&65535)){f=gj[c[3541286]&4095](274)|0;a[9718231]=f;if(f<<24>>24==0){h=0}else{i=14215}}else{i=14215}if((i|0)==14215){h=gj[c[3541288]&4095](g)|0}b[4859110]=(b[4859110]|0)+1&65535;g=c[2426620]|0;a[g+(a[9718233]&a[g+(d[9718239]|0)|0]&255)|0]=h;return}function fMy(){var f=0,g=0,h=0,i=0;f=b[4859110]|0;g=f&65535;if((a[9718232]&1)!=0&(e[4859117]|0)>(f&65535)){f=gj[c[3541286]&4095](274)|0;a[9718231]=f;if(f<<24>>24==0){h=0}else{i=14219}}else{i=14219}if((i|0)==14219){h=gj[c[3541288]&4095](g)|0}b[4859110]=(b[4859110]|0)+1&65535;g=c[2426620]|0;a[g+(a[9718233]&a[g+((d[9718239]|0)+1)|0]&255)|0]=h;return}function fMz(){var d=0,f=0,g=0,h=0;d=b[4859110]|0;f=d&65535;if((a[9718232]&1)!=0&(e[4859117]|0)>(d&65535)){d=gj[c[3541286]&4095](274)|0;a[9718231]=d;if(d<<24>>24==0){g=0}else{h=14223}}else{h=14223}if((h|0)==14223){g=(gj[c[3541288]&4095](f)|0)&255}f=b[4859110]|0;b[4859110]=f+1&65535;if((a[9718224]&32)==0){return}b[4859110]=f&3840|g;return}function fMA(){var a=0;a=b[4859110]&3840;b[4859110]=((gj[c[3541282]&4095](a|(d[9718224]|0))|0)&255|a)&65535;return}function fMB(){var d=0,f=0,g=0,h=0,i=0;d=b[4859110]|0;f=d&65535;if((a[9718232]&1)!=0&(e[4859117]|0)>(d&65535)){d=gj[c[3541286]&4095](274)|0;a[9718231]=d;if(d<<24>>24==0){g=1280}else{h=14232}}else{h=14232}if((h|0)==14232){g=(gj[c[3541288]&4095](f)|0)&255|1280}f=(b[4859110]|0)+1&65535;b[4859110]=f;h=((a[9718237]|0)==0?b[4859123]|0:0)|g;g=a[9718225]|0;a[9718225]=g+1&255;d=c[2426620]|0;a[d+((g&255)+8)|0]=f&255;f=a[9718225]&15;g=a[9718226]|0;a[9718226]=(f&255)>>>1|g&-8;i=a[9718221]&15|g&-16;a[9718225]=f+1&255;a[d+((f&255)+8)|0]=i;i=a[9718225]&15;a[9718225]=i;a[9718226]=(i&255)>>>1|a[9718226]&-8;b[4859110]=h;return}function fMC(){a[9718228]=a[9718228]^1;return}function fMD(){var d=0,f=0,g=0,h=0;d=b[4859110]|0;f=d&65535;if((a[9718232]&1)!=0&(e[4859117]|0)>(d&65535)){d=gj[c[3541286]&4095](274)|0;a[9718231]=d;if(d<<24>>24==0){g=0}else{h=14237}}else{h=14237}if((h|0)==14237){g=(gj[c[3541288]&4095](f)|0)&255}f=b[4859110]|0;b[4859110]=f+1&65535;if((a[9718226]&32)==0){return}b[4859110]=f&3840|g;return}function fME(){var f=0,g=0,h=0,i=0;f=b[4859110]|0;g=f&65535;if((a[9718232]&1)!=0&(e[4859117]|0)>(f&65535)){f=gj[c[3541286]&4095](274)|0;a[9718231]=f;if(f<<24>>24==0){h=0}else{i=14245}}else{i=14245}if((i|0)==14245){h=gj[c[3541288]&4095](g)|0}b[4859110]=(b[4859110]|0)+1&65535;a[(c[2426620]|0)+(d[9718239]|0)|0]=h;return}function fMF(){var f=0,g=0,h=0,i=0;f=b[4859110]|0;g=f&65535;if((a[9718232]&1)!=0&(e[4859117]|0)>(f&65535)){f=gj[c[3541286]&4095](274)|0;a[9718231]=f;if(f<<24>>24==0){h=0}else{i=14249}}else{i=14249}if((i|0)==14249){h=gj[c[3541288]&4095](g)|0}b[4859110]=(b[4859110]|0)+1&65535;a[(c[2426620]|0)+((d[9718239]|0)+1)|0]=h;return}function fMG(){var f=0,g=0,h=0,i=0;f=b[4859110]|0;g=f&65535;if((a[9718232]&1)!=0&(e[4859117]|0)>(f&65535)){f=gj[c[3541286]&4095](274)|0;a[9718231]=f;if(f<<24>>24==0){h=0}else{i=14253}}else{i=14253}if((i|0)==14253){h=gj[c[3541288]&4095](g)|0}b[4859110]=(b[4859110]|0)+1&65535;a[(c[2426620]|0)+((d[9718239]|0)+2)|0]=h;return}function fMH(){var f=0,g=0,h=0,i=0;f=b[4859110]|0;g=f&65535;if((a[9718232]&1)!=0&(e[4859117]|0)>(f&65535)){f=gj[c[3541286]&4095](274)|0;a[9718231]=f;if(f<<24>>24==0){h=0}else{i=14257}}else{i=14257}if((i|0)==14257){h=gj[c[3541288]&4095](g)|0}b[4859110]=(b[4859110]|0)+1&65535;a[(c[2426620]|0)+((d[9718239]|0)+3)|0]=h;return}function fMI(){var f=0,g=0,h=0,i=0;f=b[4859110]|0;g=f&65535;if((a[9718232]&1)!=0&(e[4859117]|0)>(f&65535)){f=gj[c[3541286]&4095](274)|0;a[9718231]=f;if(f<<24>>24==0){h=0}else{i=14261}}else{i=14261}if((i|0)==14261){h=gj[c[3541288]&4095](g)|0}b[4859110]=(b[4859110]|0)+1&65535;a[(c[2426620]|0)+((d[9718239]|0)+4)|0]=h;return}function fMJ(){var f=0,g=0,h=0,i=0;f=b[4859110]|0;g=f&65535;if((a[9718232]&1)!=0&(e[4859117]|0)>(f&65535)){f=gj[c[3541286]&4095](274)|0;a[9718231]=f;if(f<<24>>24==0){h=0}else{i=14265}}else{i=14265}if((i|0)==14265){h=gj[c[3541288]&4095](g)|0}b[4859110]=(b[4859110]|0)+1&65535;a[(c[2426620]|0)+((d[9718239]|0)+5)|0]=h;return}function fMK(){var f=0,g=0,h=0,i=0;f=b[4859110]|0;g=f&65535;if((a[9718232]&1)!=0&(e[4859117]|0)>(f&65535)){f=gj[c[3541286]&4095](274)|0;a[9718231]=f;if(f<<24>>24==0){h=0}else{i=14269}}else{i=14269}if((i|0)==14269){h=gj[c[3541288]&4095](g)|0}b[4859110]=(b[4859110]|0)+1&65535;a[(c[2426620]|0)+((d[9718239]|0)+6)|0]=h;return}function fML(){var f=0,g=0,h=0,i=0;f=b[4859110]|0;g=f&65535;if((a[9718232]&1)!=0&(e[4859117]|0)>(f&65535)){f=gj[c[3541286]&4095](274)|0;a[9718231]=f;if(f<<24>>24==0){h=0}else{i=14273}}else{i=14273}if((i|0)==14273){h=gj[c[3541288]&4095](g)|0}b[4859110]=(b[4859110]|0)+1&65535;a[(c[2426620]|0)+((d[9718239]|0)+7)|0]=h;return}function fMM(){var d=0,f=0,g=0,h=0;d=b[4859110]|0;f=d&65535;if((a[9718232]&1)!=0&(e[4859117]|0)>(d&65535)){d=gj[c[3541286]&4095](274)|0;a[9718231]=d;if(d<<24>>24==0){g=1536}else{h=14277}}else{h=14277}if((h|0)==14277){g=(gj[c[3541290]&4095](f)|0)&255|1536}b[4859110]=((a[9718237]|0)==0?b[4859123]|0:0)|g;return}function fMN(){a[9718226]=a[9718226]&-17;a[9718239]=0;return}function fMO(){var d=0,f=0,g=0,h=0;d=b[4859110]|0;f=d&65535;if((a[9718232]&1)!=0&(e[4859117]|0)>(d&65535)){d=gj[c[3541286]&4095](274)|0;a[9718231]=d;if(d<<24>>24==0){g=0}else{h=14282}}else{h=14282}if((h|0)==14282){g=(gj[c[3541288]&4095](f)|0)&255}f=b[4859110]|0;b[4859110]=f+1&65535;if((a[9718224]|0)!=0){return}b[4859110]=f&3840|g;return}function fMP(){a[9718224]=a[9718226]|0;return}function fMQ(){var b=0;b=(c[2426620]|0)+(d[9718239]|0)|0;a[b]=(a[b]|0)-1&255;return}function fMR(){var b=0;b=(c[2426620]|0)+((d[9718239]|0)+1)|0;a[b]=(a[b]|0)-1&255;return}function fMS(){var b=0;b=(c[2426620]|0)+((d[9718239]|0)+2)|0;a[b]=(a[b]|0)-1&255;return}function fMT(){var b=0;b=(c[2426620]|0)+((d[9718239]|0)+3)|0;a[b]=(a[b]|0)-1&255;return}function fMU(){var b=0;b=(c[2426620]|0)+((d[9718239]|0)+4)|0;a[b]=(a[b]|0)-1&255;return}function fMV(){var b=0;b=(c[2426620]|0)+((d[9718239]|0)+5)|0;a[b]=(a[b]|0)-1&255;return}function fMW(){var b=0;b=(c[2426620]|0)+((d[9718239]|0)+6)|0;a[b]=(a[b]|0)-1&255;return}function fMX(){var b=0;b=(c[2426620]|0)+((d[9718239]|0)+7)|0;a[b]=(a[b]|0)-1&255;return}function fMY(){var b=0;b=c[2426620]|0;a[9718224]=a[9718224]^a[b+(a[9718233]&a[b+(d[9718239]|0)|0]&255)|0];return}function fMZ(){var b=0;b=c[2426620]|0;a[9718224]=a[9718224]^a[b+(a[9718233]&a[b+((d[9718239]|0)+1)|0]&255)|0];return}function fM_(){var d=0,f=0,g=0,h=0;d=b[4859110]|0;f=d&65535;if((a[9718232]&1)!=0&(e[4859117]|0)>(d&65535)){d=gj[c[3541286]&4095](274)|0;a[9718231]=d;if(d<<24>>24==0){g=0}else{h=14301}}else{h=14301}if((h|0)==14301){g=(gj[c[3541288]&4095](f)|0)&255}f=b[4859110]|0;b[4859110]=f+1&65535;if((a[9718224]&64)==0){return}b[4859110]=f&3840|g;return}function fM$(){var d=0,f=0,g=0,h=0;d=b[4859110]|0;f=d&65535;if((a[9718232]&1)!=0&(e[4859117]|0)>(d&65535)){d=gj[c[3541286]&4095](274)|0;a[9718231]=d;if(d<<24>>24==0){g=0}else{h=14309}}else{h=14309}if((h|0)==14309){g=gj[c[3541288]&4095](f)|0}b[4859110]=(b[4859110]|0)+1&65535;a[9718224]=a[9718224]^g;return}function fM0(){var d=0,f=0,g=0,h=0,i=0;d=b[4859110]|0;f=d&65535;if((a[9718232]&1)!=0&(e[4859117]|0)>(d&65535)){d=gj[c[3541286]&4095](274)|0;a[9718231]=d;if(d<<24>>24==0){g=1536}else{h=14313}}else{h=14313}if((h|0)==14313){g=(gj[c[3541288]&4095](f)|0)&255|1536}f=(b[4859110]|0)+1&65535;b[4859110]=f;h=((a[9718237]|0)==0?b[4859123]|0:0)|g;g=a[9718225]|0;a[9718225]=g+1&255;d=c[2426620]|0;a[d+((g&255)+8)|0]=f&255;f=a[9718225]&15;g=a[9718226]|0;a[9718226]=(f&255)>>>1|g&-8;i=a[9718221]&15|g&-16;a[9718225]=f+1&255;a[d+((f&255)+8)|0]=i;i=a[9718225]&15;a[9718225]=i;a[9718226]=(i&255)>>>1|a[9718226]&-8;b[4859110]=h;return}function fM1(){a[9718226]=a[9718226]|16;a[9718239]=24;return}function fM2(){var b=0;b=a[9718224]|0;a[9718226]=b;a[9718239]=(b&16)!=0?24:0;a[9718225]=b<<1&14;return}function fM3(){a[9718224]=a[9718224]^a[(c[2426620]|0)+(d[9718239]|0)|0];return}function fM4(){a[9718224]=a[9718224]^a[(c[2426620]|0)+((d[9718239]|0)+1)|0];return}function fM5(){a[9718224]=a[9718224]^a[(c[2426620]|0)+((d[9718239]|0)+2)|0];return}function fM6(){a[9718224]=a[9718224]^a[(c[2426620]|0)+((d[9718239]|0)+3)|0];return}function fM7(){a[9718224]=a[9718224]^a[(c[2426620]|0)+((d[9718239]|0)+4)|0];return}function fM8(){a[9718224]=a[9718224]^a[(c[2426620]|0)+((d[9718239]|0)+5)|0];return}function fM9(){a[9718224]=a[9718224]^a[(c[2426620]|0)+((d[9718239]|0)+6)|0];return}function fNa(){a[9718224]=a[9718224]^a[(c[2426620]|0)+((d[9718239]|0)+7)|0];return}function fNb(){a[9718224]=gj[c[3541282]&4095](d[9718224]|0|768)|0;return}function fNc(){var d=0,f=0,g=0,h=0;d=b[4859110]|0;f=d&65535;if((a[9718232]&1)!=0&(e[4859117]|0)>(d&65535)){d=gj[c[3541286]&4095](274)|0;a[9718231]=d;if(d<<24>>24==0){g=1792}else{h=14328}}else{h=14328}if((h|0)==14328){g=(gj[c[3541290]&4095](f)|0)&255|1792}b[4859110]=((a[9718237]|0)==0?b[4859123]|0:0)|g;return}function fNd(){b[4859123]=0;return}function fNe(){var d=0,f=0,g=0,h=0;d=b[4859110]|0;f=d&65535;if((a[9718232]&1)!=0&(e[4859117]|0)>(d&65535)){d=gj[c[3541286]&4095](274)|0;a[9718231]=d;if(d<<24>>24==0){g=0}else{h=14333}}else{h=14333}if((h|0)==14333){g=(gj[c[3541288]&4095](f)|0)&255}f=b[4859110]|0;b[4859110]=f+1&65535;if((a[9718226]|0)<=-1){return}b[4859110]=f&3840|g;return}function fNf(){var b=0;b=a[9718224]|0;a[9718224]=b<<1|(b&255)>>>7;return}function fNg(){var f=0,g=0,h=0,i=0;f=b[4859110]|0;g=f&65535;if((a[9718232]&1)!=0&(e[4859117]|0)>(f&65535)){f=gj[c[3541286]&4095](274)|0;a[9718231]=f;if(f<<24>>24==0){h=0}else{i=14342}}else{i=14342}if((i|0)==14342){h=(gj[c[3541288]&4095](g)|0)&255}b[4859110]=(b[4859110]|0)+1&65535;g=c[2426620]|0;i=g+(d[9718239]|0)|0;a[i]=(a[i]|0)-1&255;if((a[g+(d[9718239]|0)|0]|0)==0){return}b[4859110]=(b[4859110]|0)+4095&3840|h;return}function fNh(){var f=0,g=0,h=0,i=0;f=b[4859110]|0;g=f&65535;if((a[9718232]&1)!=0&(e[4859117]|0)>(f&65535)){f=gj[c[3541286]&4095](274)|0;a[9718231]=f;if(f<<24>>24==0){h=0}else{i=14350}}else{i=14350}if((i|0)==14350){h=(gj[c[3541288]&4095](g)|0)&255}b[4859110]=(b[4859110]|0)+1&65535;g=c[2426620]|0;i=g+((d[9718239]|0)+1)|0;a[i]=(a[i]|0)-1&255;if((a[g+((d[9718239]|0)+1)|0]|0)==0){return}b[4859110]=(b[4859110]|0)+4095&3840|h;return}function fNi(){var f=0,g=0,h=0,i=0;f=b[4859110]|0;g=f&65535;if((a[9718232]&1)!=0&(e[4859117]|0)>(f&65535)){f=gj[c[3541286]&4095](274)|0;a[9718231]=f;if(f<<24>>24==0){h=0}else{i=14358}}else{i=14358}if((i|0)==14358){h=(gj[c[3541288]&4095](g)|0)&255}b[4859110]=(b[4859110]|0)+1&65535;g=c[2426620]|0;i=g+((d[9718239]|0)+2)|0;a[i]=(a[i]|0)-1&255;if((a[g+((d[9718239]|0)+2)|0]|0)==0){return}b[4859110]=(b[4859110]|0)+4095&3840|h;return}function fNj(){var f=0,g=0,h=0,i=0;f=b[4859110]|0;g=f&65535;if((a[9718232]&1)!=0&(e[4859117]|0)>(f&65535)){f=gj[c[3541286]&4095](274)|0;a[9718231]=f;if(f<<24>>24==0){h=0}else{i=14366}}else{i=14366}if((i|0)==14366){h=(gj[c[3541288]&4095](g)|0)&255}b[4859110]=(b[4859110]|0)+1&65535;g=c[2426620]|0;i=g+((d[9718239]|0)+3)|0;a[i]=(a[i]|0)-1&255;if((a[g+((d[9718239]|0)+3)|0]|0)==0){return}b[4859110]=(b[4859110]|0)+4095&3840|h;return}function fNk(){var f=0,g=0,h=0,i=0;f=b[4859110]|0;g=f&65535;if((a[9718232]&1)!=0&(e[4859117]|0)>(f&65535)){f=gj[c[3541286]&4095](274)|0;a[9718231]=f;if(f<<24>>24==0){h=0}else{i=14374}}else{i=14374}if((i|0)==14374){h=(gj[c[3541288]&4095](g)|0)&255}b[4859110]=(b[4859110]|0)+1&65535;g=c[2426620]|0;i=g+((d[9718239]|0)+4)|0;a[i]=(a[i]|0)-1&255;if((a[g+((d[9718239]|0)+4)|0]|0)==0){return}b[4859110]=(b[4859110]|0)+4095&3840|h;return}function fNl(){var f=0,g=0,h=0,i=0;f=b[4859110]|0;g=f&65535;if((a[9718232]&1)!=0&(e[4859117]|0)>(f&65535)){f=gj[c[3541286]&4095](274)|0;a[9718231]=f;if(f<<24>>24==0){h=0}else{i=14382}}else{i=14382}if((i|0)==14382){h=(gj[c[3541288]&4095](g)|0)&255}b[4859110]=(b[4859110]|0)+1&65535;g=c[2426620]|0;i=g+((d[9718239]|0)+5)|0;a[i]=(a[i]|0)-1&255;if((a[g+((d[9718239]|0)+5)|0]|0)==0){return}b[4859110]=(b[4859110]|0)+4095&3840|h;return}function fNm(){var f=0,g=0,h=0,i=0;f=b[4859110]|0;g=f&65535;if((a[9718232]&1)!=0&(e[4859117]|0)>(f&65535)){f=gj[c[3541286]&4095](274)|0;a[9718231]=f;if(f<<24>>24==0){h=0}else{i=14390}}else{i=14390}if((i|0)==14390){h=(gj[c[3541288]&4095](g)|0)&255}b[4859110]=(b[4859110]|0)+1&65535;g=c[2426620]|0;i=g+((d[9718239]|0)+6)|0;a[i]=(a[i]|0)-1&255;if((a[g+((d[9718239]|0)+6)|0]|0)==0){return}b[4859110]=(b[4859110]|0)+4095&3840|h;return}function fNn(){var f=0,g=0,h=0,i=0;f=b[4859110]|0;g=f&65535;if((a[9718232]&1)!=0&(e[4859117]|0)>(f&65535)){f=gj[c[3541286]&4095](274)|0;a[9718231]=f;if(f<<24>>24==0){h=0}else{i=14398}}else{i=14398}if((i|0)==14398){h=(gj[c[3541288]&4095](g)|0)&255}b[4859110]=(b[4859110]|0)+1&65535;g=c[2426620]|0;i=g+((d[9718239]|0)+7)|0;a[i]=(a[i]|0)-1&255;if((a[g+((d[9718239]|0)+7)|0]|0)==0){return}b[4859110]=(b[4859110]|0)+4095&3840|h;return}function fNo(){var b=0;b=c[2426620]|0;a[9718224]=a[b+(a[9718233]&a[b+(d[9718239]|0)|0]&255)|0]|0;return}function fNp(){var b=0;b=c[2426620]|0;a[9718224]=a[b+(a[9718233]&a[b+((d[9718239]|0)+1)|0]&255)|0]|0;return}function fNq(){var d=0,f=0,g=0,h=0;d=b[4859110]|0;f=d&65535;if((a[9718232]&1)!=0&(e[4859117]|0)>(d&65535)){d=gj[c[3541286]&4095](274)|0;a[9718231]=d;if(d<<24>>24==0){g=0}else{h=14408}}else{h=14408}if((h|0)==14408){g=(gj[c[3541288]&4095](f)|0)&255}f=b[4859110]|0;b[4859110]=f+1&65535;if((a[9718224]|0)>=0){return}b[4859110]=f&3840|g;return}function fNr(){var d=0,f=0,g=0,h=0,i=0;d=b[4859110]|0;f=d&65535;if((a[9718232]&1)!=0&(e[4859117]|0)>(d&65535)){d=gj[c[3541286]&4095](274)|0;a[9718231]=d;if(d<<24>>24==0){g=1792}else{h=14416}}else{h=14416}if((h|0)==14416){g=(gj[c[3541288]&4095](f)|0)&255|1792}f=(b[4859110]|0)+1&65535;b[4859110]=f;h=((a[9718237]|0)==0?b[4859123]|0:0)|g;g=a[9718225]|0;a[9718225]=g+1&255;d=c[2426620]|0;a[d+((g&255)+8)|0]=f&255;f=a[9718225]&15;g=a[9718226]|0;a[9718226]=(f&255)>>>1|g&-8;i=a[9718221]&15|g&-16;a[9718225]=f+1&255;a[d+((f&255)+8)|0]=i;i=a[9718225]&15;a[9718225]=i;a[9718226]=(i&255)>>>1|a[9718226]&-8;b[4859110]=h;return}function fNs(){b[4859123]=2048;return}function fNt(){var d=0,f=0,g=0,h=0;d=b[4859110]|0;f=d&65535;if((a[9718232]&1)!=0&(e[4859117]|0)>(d&65535)){d=gj[c[3541286]&4095](274)|0;a[9718231]=d;if(d<<24>>24==0){g=0}else{h=14421}}else{h=14421}if((h|0)==14421){g=(gj[c[3541288]&4095](f)|0)&255}f=b[4859110]|0;b[4859110]=f+1&65535;if((a[9718226]|0)>-1){return}b[4859110]=f&3840|g;return}function fNu(){var b=0,c=0;b=a[9718226]|0;c=a[9718224]|0;a[9718226]=c<<24>>24<0?b|-128:b&127;a[9718224]=c<<1|(b&255)>>>7;return}function fNv(){a[9718224]=a[(c[2426620]|0)+(d[9718239]|0)|0]|0;return}function fNw(){a[9718224]=a[(c[2426620]|0)+((d[9718239]|0)+1)|0]|0;return}function fNx(){a[9718224]=a[(c[2426620]|0)+((d[9718239]|0)+2)|0]|0;return}function fNy(){a[9718224]=a[(c[2426620]|0)+((d[9718239]|0)+3)|0]|0;return}function fNz(){a[9718224]=a[(c[2426620]|0)+((d[9718239]|0)+4)|0]|0;return}function fNA(){a[9718224]=a[(c[2426620]|0)+((d[9718239]|0)+5)|0]|0;return}function fNB(){a[9718224]=a[(c[2426620]|0)+((d[9718239]|0)+6)|0]|0;return}function fNC(){a[9718224]=a[(c[2426620]|0)+((d[9718239]|0)+7)|0]|0;return}function fND(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c[2410673]=0;a[9642688]=0;a[9642689]=0;a[9642682]=0;a[9642683]=0;c[2410665]=0;a[9642680]=a[9642680]|80;b=c[2425163]|0;do{if((b|0)==0){e=c[3528598]|0;if((e|0)==0){f=0;g=0;break}h=gj[e&4095](-2)|0;e=c[2425163]|0;i=(h&255)<<8;if((e|0)!=0){j=e;k=i;l=14440;break}e=c[3528598]|0;if((e|0)==0){f=0;g=i;break}f=gj[e&4095](-1)|0;g=i}else{j=b;k=(d[b+254|0]|0)<<8;l=14440}}while(0);if((l|0)==14440){f=a[j+255|0]|0;g=k}c[2410662]=f&255|g;return}function fNE(e,f){e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;if((e|0)==2){if((d[9642689]|0|0)==(f|0)){return}a[9642689]=f&255;if((f|0)==0){return}g=a[9642688]|0;if((g&32)==0){return}a[9642688]=g&-17;if((g&8)==0){a[9642680]=a[9642680]|-128;b[4821334]=(b[4821334]|0)-1&65535;h=c[2410667]|0;i=h&65535;j=a[9642648]|0;k=c[9700656+((h>>>8&255)<<2)>>2]|0;do{if((k|0)==0){l=c[2444172]|0;if((l|0)==0){break}gg[l&4095](i,j)}else{a[k+(h&255)|0]=j}}while(0);b[4821334]=(b[4821334]|0)-1&65535;j=c[2410667]|0;h=j&65535;k=a[9642649]|0;i=c[9700656+((j>>>8&255)<<2)>>2]|0;do{if((i|0)==0){l=c[2444172]|0;if((l|0)==0){break}gg[l&4095](h,k)}else{a[i+(j&255)|0]=k}}while(0);b[4821334]=(b[4821334]|0)-1&65535;k=c[2410667]|0;j=k&65535;i=a[9642664]|0;h=c[9700656+((k>>>8&255)<<2)>>2]|0;do{if((h|0)==0){l=c[2444172]|0;if((l|0)==0){break}gg[l&4095](j,i)}else{a[h+(k&255)|0]=i}}while(0);b[4821334]=(b[4821334]|0)-1&65535;i=c[2410667]|0;k=i&65535;h=a[9642665]|0;j=c[9700656+((i>>>8&255)<<2)>>2]|0;do{if((j|0)==0){l=c[2444172]|0;if((l|0)==0){break}gg[l&4095](k,h)}else{a[j+(i&255)|0]=h}}while(0);b[4821334]=(b[4821334]|0)-1&65535;h=c[2410667]|0;i=h&65535;j=a[9642676]|0;k=c[9700656+((h>>>8&255)<<2)>>2]|0;do{if((k|0)==0){l=c[2444172]|0;if((l|0)==0){break}gg[l&4095](i,j)}else{a[k+(h&255)|0]=j}}while(0);b[4821334]=(b[4821334]|0)-1&65535;j=c[2410667]|0;h=j&65535;k=a[9642677]|0;i=c[9700656+((j>>>8&255)<<2)>>2]|0;do{if((i|0)==0){l=c[2444172]|0;if((l|0)==0){break}gg[l&4095](h,k)}else{a[i+(j&255)|0]=k}}while(0);b[4821334]=(b[4821334]|0)-1&65535;k=c[2410667]|0;j=k&65535;i=a[9642672]|0;h=c[9700656+((k>>>8&255)<<2)>>2]|0;do{if((h|0)==0){l=c[2444172]|0;if((l|0)==0){break}gg[l&4095](j,i)}else{a[h+(k&255)|0]=i}}while(0);b[4821334]=(b[4821334]|0)-1&65535;i=c[2410667]|0;k=i&65535;h=a[9642673]|0;j=c[9700656+((i>>>8&255)<<2)>>2]|0;do{if((j|0)==0){l=c[2444172]|0;if((l|0)==0){break}gg[l&4095](k,h)}else{a[j+(i&255)|0]=h}}while(0);b[4821334]=(b[4821334]|0)-1&65535;h=c[2410667]|0;i=h&65535;j=a[9642661]|0;k=c[9700656+((h>>>8&255)<<2)>>2]|0;do{if((k|0)==0){l=c[2444172]|0;if((l|0)==0){break}gg[l&4095](i,j)}else{a[k+(h&255)|0]=j}}while(0);b[4821334]=(b[4821334]|0)-1&65535;j=c[2410667]|0;h=j&65535;k=a[9642656]|0;i=c[9700656+((j>>>8&255)<<2)>>2]|0;do{if((i|0)==0){l=c[2444172]|0;if((l|0)==0){break}gg[l&4095](h,k)}else{a[i+(j&255)|0]=k}}while(0);b[4821334]=(b[4821334]|0)-1&65535;k=c[2410667]|0;j=k&65535;i=a[9642657]|0;h=c[9700656+((k>>>8&255)<<2)>>2]|0;do{if((h|0)==0){l=c[2444172]|0;if((l|0)==0){break}gg[l&4095](j,i)}else{a[h+(k&255)|0]=i}}while(0);b[4821334]=(b[4821334]|0)-1&65535;i=c[2410667]|0;k=i&65535;h=a[9642680]|0;j=c[9700656+((i>>>8&255)<<2)>>2]|0;do{if((j|0)==0){l=c[2444172]|0;if((l|0)==0){break}gg[l&4095](k,h)}else{a[j+(i&255)|0]=h}}while(0);m=(c[2410671]|0)+19|0}else{a[9642688]=g&-25;m=(c[2410671]|0)+7|0}c[2410671]=m;a[9642680]=a[9642680]|80;m=c[2425163]|0;do{if((m|0)==0){g=c[3528598]|0;if((g|0)==0){n=0;o=0;break}h=gj[g&4095](-4)|0;g=c[2425163]|0;i=(h&255)<<8;if((g|0)!=0){p=g;q=i;r=14503;break}g=c[3528598]|0;if((g|0)==0){n=0;o=i;break}n=gj[g&4095](-3)|0;o=i}else{p=m;q=(d[m+252|0]|0)<<8;r=14503}}while(0);if((r|0)==14503){n=a[p+253|0]|0;o=q}c[2410662]=n&255|o;return}if((e|0)>=2){return}a[9642682+e|0]=f&255;if((f|0)==0){return}f=a[9642682]|0;e=a[9642683]|0;if((e|f)<<24>>24!=0){a[9642688]=a[9642688]&-17}do{if(e<<24>>24!=0){o=a[9642680]|0;if((o&64)!=0){break}n=a[9642688]|0;if((n&8)==0){a[9642680]=o&127;b[4821334]=(b[4821334]|0)-1&65535;q=c[2410667]|0;p=q&65535;m=a[9642648]|0;i=c[9700656+((q>>>8&255)<<2)>>2]|0;do{if((i|0)==0){g=c[2444172]|0;if((g|0)==0){break}gg[g&4095](p,m)}else{a[i+(q&255)|0]=m}}while(0);b[4821334]=(b[4821334]|0)-1&65535;m=c[2410667]|0;q=m&65535;i=a[9642649]|0;p=c[9700656+((m>>>8&255)<<2)>>2]|0;do{if((p|0)==0){g=c[2444172]|0;if((g|0)==0){break}gg[g&4095](q,i)}else{a[p+(m&255)|0]=i}}while(0);b[4821334]=(b[4821334]|0)-1&65535;i=c[2410667]|0;m=i&65535;p=a[9642680]|0;q=c[9700656+((i>>>8&255)<<2)>>2]|0;do{if((q|0)==0){g=c[2444172]|0;if((g|0)==0){break}gg[g&4095](m,p)}else{a[q+(i&255)|0]=p}}while(0);s=(c[2410671]|0)+10|0;t=a[9642680]|0}else{a[9642688]=n&-9;s=(c[2410671]|0)+7|0;t=o}c[2410671]=s;a[9642680]=t|80;p=c[2425163]|0;do{if((p|0)==0){i=c[3528598]|0;if((i|0)==0){u=0;v=0;break}q=gj[i&4095](-10)|0;i=c[2425163]|0;m=(q&255)<<8;if((i|0)!=0){w=i;x=m;r=14532;break}i=c[3528598]|0;if((i|0)==0){u=0;v=m;break}u=gj[i&4095](-9)|0;v=m}else{w=p;x=(d[p+246|0]|0)<<8;r=14532}}while(0);if((r|0)==14532){u=a[w+247|0]|0;v=x}c[2410662]=u&255|v;p=c[2410674]|0;gj[p&4095](1)|0;return}}while(0);if(f<<24>>24==0){return}f=a[9642680]|0;if((f&16)!=0){return}v=a[9642688]|0;if((v&8)==0){a[9642680]=f|-128;b[4821334]=(b[4821334]|0)-1&65535;u=c[2410667]|0;x=u&65535;w=a[9642648]|0;t=c[9700656+((u>>>8&255)<<2)>>2]|0;do{if((t|0)==0){s=c[2444172]|0;if((s|0)==0){break}gg[s&4095](x,w)}else{a[t+(u&255)|0]=w}}while(0);b[4821334]=(b[4821334]|0)-1&65535;w=c[2410667]|0;u=w&65535;t=a[9642649]|0;x=c[9700656+((w>>>8&255)<<2)>>2]|0;do{if((x|0)==0){s=c[2444172]|0;if((s|0)==0){break}gg[s&4095](u,t)}else{a[x+(w&255)|0]=t}}while(0);b[4821334]=(b[4821334]|0)-1&65535;t=c[2410667]|0;w=t&65535;x=a[9642664]|0;u=c[9700656+((t>>>8&255)<<2)>>2]|0;do{if((u|0)==0){s=c[2444172]|0;if((s|0)==0){break}gg[s&4095](w,x)}else{a[u+(t&255)|0]=x}}while(0);b[4821334]=(b[4821334]|0)-1&65535;x=c[2410667]|0;t=x&65535;u=a[9642665]|0;w=c[9700656+((x>>>8&255)<<2)>>2]|0;do{if((w|0)==0){s=c[2444172]|0;if((s|0)==0){break}gg[s&4095](t,u)}else{a[w+(x&255)|0]=u}}while(0);b[4821334]=(b[4821334]|0)-1&65535;u=c[2410667]|0;x=u&65535;w=a[9642676]|0;t=c[9700656+((u>>>8&255)<<2)>>2]|0;do{if((t|0)==0){s=c[2444172]|0;if((s|0)==0){break}gg[s&4095](x,w)}else{a[t+(u&255)|0]=w}}while(0);b[4821334]=(b[4821334]|0)-1&65535;w=c[2410667]|0;u=w&65535;t=a[9642677]|0;x=c[9700656+((w>>>8&255)<<2)>>2]|0;do{if((x|0)==0){s=c[2444172]|0;if((s|0)==0){break}gg[s&4095](u,t)}else{a[x+(w&255)|0]=t}}while(0);b[4821334]=(b[4821334]|0)-1&65535;t=c[2410667]|0;w=t&65535;x=a[9642672]|0;u=c[9700656+((t>>>8&255)<<2)>>2]|0;do{if((u|0)==0){s=c[2444172]|0;if((s|0)==0){break}gg[s&4095](w,x)}else{a[u+(t&255)|0]=x}}while(0);b[4821334]=(b[4821334]|0)-1&65535;x=c[2410667]|0;t=x&65535;u=a[9642673]|0;w=c[9700656+((x>>>8&255)<<2)>>2]|0;do{if((w|0)==0){s=c[2444172]|0;if((s|0)==0){break}gg[s&4095](t,u)}else{a[w+(x&255)|0]=u}}while(0);b[4821334]=(b[4821334]|0)-1&65535;u=c[2410667]|0;x=u&65535;w=a[9642661]|0;t=c[9700656+((u>>>8&255)<<2)>>2]|0;do{if((t|0)==0){s=c[2444172]|0;if((s|0)==0){break}gg[s&4095](x,w)}else{a[t+(u&255)|0]=w}}while(0);b[4821334]=(b[4821334]|0)-1&65535;w=c[2410667]|0;u=w&65535;t=a[9642656]|0;x=c[9700656+((w>>>8&255)<<2)>>2]|0;do{if((x|0)==0){s=c[2444172]|0;if((s|0)==0){break}gg[s&4095](u,t)}else{a[x+(w&255)|0]=t}}while(0);b[4821334]=(b[4821334]|0)-1&65535;t=c[2410667]|0;w=t&65535;x=a[9642657]|0;u=c[9700656+((t>>>8&255)<<2)>>2]|0;do{if((u|0)==0){s=c[2444172]|0;if((s|0)==0){break}gg[s&4095](w,x)}else{a[u+(t&255)|0]=x}}while(0);b[4821334]=(b[4821334]|0)-1&65535;x=c[2410667]|0;t=x&65535;u=a[9642680]|0;w=c[9700656+((x>>>8&255)<<2)>>2]|0;do{if((w|0)==0){s=c[2444172]|0;if((s|0)==0){break}gg[s&4095](t,u)}else{a[w+(x&255)|0]=u}}while(0);y=(c[2410671]|0)+19|0;z=a[9642680]|0}else{a[9642688]=v&-9;y=(c[2410671]|0)+7|0;z=f}c[2410671]=y;a[9642680]=z|16;z=c[2425163]|0;do{if((z|0)==0){y=c[3528598]|0;if((y|0)==0){A=0;B=0;break}f=gj[y&4095](-8)|0;y=c[2425163]|0;v=(f&255)<<8;if((y|0)!=0){C=y;D=v;r=14593;break}y=c[3528598]|0;if((y|0)==0){A=0;B=v;break}A=gj[y&4095](-7)|0;B=v}else{C=z;D=(d[z+248|0]|0)<<8;r=14593}}while(0);if((r|0)==14593){A=a[C+249|0]|0;B=D}c[2410662]=A&255|B;gj[c[2410674]&4095](0)|0;return}function fNF(e){e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;c[2439268]=e-(c[2410671]|0);c[2410671]=0;if((a[9642688]&24)!=0){c[2439268]=0;f=0;g=e-f|0;h=c[2410673]|0;i=g+h|0;c[2410673]=i;return g|0}do{j=c[2410662]|0;c[2410663]=j;k=j&65535;l=c[9701680+((j>>>8&255)<<2)>>2]|0;do{if((l|0)==0){m=c[3528598]|0;if((m|0)==0){n=0;o=k;break}p=gj[m&4095](k)|0;n=p;o=b[4821324]|0}else{n=a[l+(j&255)|0]|0;o=k}}while(0);a[9642681]=n;b[4821324]=o+1&65535;gu[c[7036448+((n&255)<<2)>>2]&16383]();q=(c[2439268]|0)-(d[669968+(d[9642681]|0)|0]|0)|0;c[2439268]=q;}while((q|0)>0);n=q-(c[2410671]|0)|0;c[2439268]=n;c[2410671]=0;f=n;g=e-f|0;h=c[2410673]|0;i=g+h|0;c[2410673]=i;return g|0}function fNG(){return c[2410673]|0}function fNH(){c[2410673]=0;return}function fNI(){var a=0,b=0;a=i;bw(178256,(b=i,i=i+8|0,c[b>>2]=e[4821324]|0,b)|0)|0;i=b;i=a;return}function fNJ(){var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0,cf=0,cg=0,ch=0,ci=0,cj=0,ck=0,cl=0;d=i;e=c[2410662]|0;f=e&65535;g=c[9701680+((e>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[3528598]|0;if((h|0)==0){j=0;k=f;break}l=gj[h&4095](f)|0;j=l;k=b[4821324]|0}else{j=a[g+(e&255)|0]|0;k=f}}while(0);f=k+1&65535;b[4821324]=f;switch(j&255|0){case 15:{j=c[2410662]|0;e=j&65535;g=c[9701680+((j>>>8&255)<<2)>>2]|0;do{if((g|0)==0){l=c[3528598]|0;if((l|0)==0){m=0;n=j;o=e;break}h=gj[l&4095](e)|0;l=c[2410662]|0;m=h;n=l;o=l&65535}else{m=a[g+(j&255)|0]|0;n=j;o=e}}while(0);e=m&255;m=e<<8;j=n+1|0;n=j&65535;g=c[9701680+((j>>>8&255)<<2)>>2]|0;do{if((g|0)==0){l=c[3528598]|0;if((l|0)==0){p=0;q=o;break}h=gj[l&4095](n)|0;p=h;q=b[4821324]|0}else{p=a[g+(j&255)|0]|0;q=o}}while(0);o=p&255;p=o|m;c[2426870]=p;b[4821324]=q+2&65535;q=p&65535;m=c[9699632+(e<<2)>>2]|0;do{if((m|0)==0){e=c[3528598]|0;if((e|0)==0){r=0;break}r=gj[e&4095](q)|0}else{r=a[m+o|0]|0}}while(0);o=(r&255)<<8;r=p+1|0;p=r&65535;m=c[9699632+((r>>>8&255)<<2)>>2]|0;do{if((m|0)==0){q=c[3528598]|0;if((q|0)==0){s=0;break}s=gj[q&4095](p)|0}else{s=a[m+(r&255)|0]|0}}while(0);b[4853740]=s&255|o;c[2439268]=(c[2439268]|0)-4;break};case 38:{b[4853740]=b[4821336]|0;break};case 35:{o=(b[4821336]|0)-2&65535;b[4821336]=o;b[4853740]=o;c[2439268]=(c[2439268]|0)-3;break};case 36:{o=c[2410662]|0;s=o&65535;r=c[9701680+((o>>>8&255)<<2)>>2]|0;do{if((r|0)==0){m=c[3528598]|0;if((m|0)==0){t=0;u=s;break}p=gj[m&4095](s)|0;t=p;u=b[4821324]|0}else{t=a[r+(o&255)|0]|0;u=s}}while(0);b[4821324]=u+1&65535;b[4853740]=(b[4821336]|0)+(t<<24>>24)&65535;c[2439268]=(c[2439268]|0)-2;break};case 7:{c[2426870]=0;gu[c[2674880+((a[9642681]&255)<<2)>>2]&16383]();c[2439268]=(c[2439268]|0)-2;i=d;return};case 40:{t=b[4821336]|0;b[4853740]=t;b[4821336]=t+1&65535;t=c[2426870]|0;u=t&65535;s=c[9699632+((t>>>8&255)<<2)>>2]|0;do{if((s|0)==0){o=c[3528598]|0;if((o|0)==0){v=0;break}v=gj[o&4095](u)|0}else{v=a[s+(t&255)|0]|0}}while(0);s=(v&255)<<8;v=t+1|0;t=v&65535;u=c[9699632+((v>>>8&255)<<2)>>2]|0;do{if((u|0)==0){o=c[3528598]|0;if((o|0)==0){w=0;break}w=gj[o&4095](t)|0}else{w=a[u+(v&255)|0]|0}}while(0);b[4853740]=w&255|s;c[2439268]=(c[2439268]|0)-5;break};case 37:{s=c[2410662]|0;w=s&65535;v=c[9701680+((s>>>8&255)<<2)>>2]|0;do{if((v|0)==0){u=c[3528598]|0;if((u|0)==0){x=0;y=s;z=w;break}t=gj[u&4095](w)|0;u=c[2410662]|0;x=t;y=u;z=u&65535}else{x=a[v+(s&255)|0]|0;y=s;z=w}}while(0);w=(x&255)<<8;x=y+1|0;y=x&65535;s=c[9701680+((x>>>8&255)<<2)>>2]|0;do{if((s|0)==0){v=c[3528598]|0;if((v|0)==0){A=0;B=z;break}u=gj[v&4095](y)|0;A=u;B=b[4821324]|0}else{A=a[s+(x&255)|0]|0;B=z}}while(0);z=A&255|w;c[2426870]=z;b[4821324]=B+2&65535;b[4853740]=(z&65535)+(b[4821336]|0)&65535;c[2439268]=(c[2439268]|0)-4;break};case 32:{z=b[4821336]|0;b[4853740]=z;b[4821336]=z+1&65535;c[2439268]=(c[2439268]|0)-2;break};case 57:{z=b[4821338]|0;b[4853740]=z;b[4821338]=z+2&65535;z=c[2426870]|0;B=z&65535;w=c[9699632+((z>>>8&255)<<2)>>2]|0;do{if((w|0)==0){A=c[3528598]|0;if((A|0)==0){C=0;break}C=gj[A&4095](B)|0}else{C=a[w+(z&255)|0]|0}}while(0);w=(C&255)<<8;C=z+1|0;z=C&65535;B=c[9699632+((C>>>8&255)<<2)>>2]|0;do{if((B|0)==0){A=c[3528598]|0;if((A|0)==0){D=0;break}D=gj[A&4095](z)|0}else{D=a[B+(C&255)|0]|0}}while(0);b[4853740]=D&255|w;c[2439268]=(c[2439268]|0)-6;break};case 58:{w=(b[4821338]|0)-1&65535;b[4821338]=w;b[4853740]=w;w=c[2426870]|0;D=w&65535;C=c[9699632+((w>>>8&255)<<2)>>2]|0;do{if((C|0)==0){B=c[3528598]|0;if((B|0)==0){E=0;break}E=gj[B&4095](D)|0}else{E=a[C+(w&255)|0]|0}}while(0);C=(E&255)<<8;E=w+1|0;w=E&65535;D=c[9699632+((E>>>8&255)<<2)>>2]|0;do{if((D|0)==0){B=c[3528598]|0;if((B|0)==0){F=0;break}F=gj[B&4095](w)|0}else{F=a[D+(E&255)|0]|0}}while(0);b[4853740]=F&255|C;c[2439268]=(c[2439268]|0)-5;break};case 59:{C=(b[4821338]|0)-2&65535;b[4821338]=C;b[4853740]=C;C=c[2426870]|0;F=C&65535;E=c[9699632+((C>>>8&255)<<2)>>2]|0;do{if((E|0)==0){D=c[3528598]|0;if((D|0)==0){G=0;break}G=gj[D&4095](F)|0}else{G=a[E+(C&255)|0]|0}}while(0);E=(G&255)<<8;G=C+1|0;C=G&65535;F=c[9699632+((G>>>8&255)<<2)>>2]|0;do{if((F|0)==0){D=c[3528598]|0;if((D|0)==0){H=0;break}H=gj[D&4095](C)|0}else{H=a[F+(G&255)|0]|0}}while(0);b[4853740]=H&255|E;c[2439268]=(c[2439268]|0)-6;break};case 60:{E=c[2410662]|0;H=E&65535;G=c[9701680+((E>>>8&255)<<2)>>2]|0;do{if((G|0)==0){F=c[3528598]|0;if((F|0)==0){I=0;J=H;break}C=gj[F&4095](H)|0;I=C;J=b[4821324]|0}else{I=a[G+(E&255)|0]|0;J=H}}while(0);b[4821324]=J+1&65535;b[4853740]=(b[4821338]|0)+(I<<24>>24)&65535;I=c[2426870]|0;J=I&65535;H=c[9699632+((I>>>8&255)<<2)>>2]|0;do{if((H|0)==0){E=c[3528598]|0;if((E|0)==0){K=0;break}K=gj[E&4095](J)|0}else{K=a[H+(I&255)|0]|0}}while(0);H=(K&255)<<8;K=I+1|0;I=K&65535;J=c[9699632+((K>>>8&255)<<2)>>2]|0;do{if((J|0)==0){E=c[3528598]|0;if((E|0)==0){L=0;break}L=gj[E&4095](I)|0}else{L=a[J+(K&255)|0]|0}}while(0);b[4853740]=L&255|H;c[2439268]=(c[2439268]|0)-4;break};case 33:{H=b[4821336]|0;b[4853740]=H;b[4821336]=H+2&65535;c[2439268]=(c[2439268]|0)-3;break};case 34:{H=(b[4821336]|0)-1&65535;b[4821336]=H;b[4853740]=H;c[2439268]=(c[2439268]|0)-2;break};case 43:{H=(b[4821336]|0)-2&65535;b[4821336]=H;b[4853740]=H;H=c[2426870]|0;L=H&65535;K=c[9699632+((H>>>8&255)<<2)>>2]|0;do{if((K|0)==0){J=c[3528598]|0;if((J|0)==0){M=0;break}M=gj[J&4095](L)|0}else{M=a[K+(H&255)|0]|0}}while(0);K=(M&255)<<8;M=H+1|0;H=M&65535;L=c[9699632+((M>>>8&255)<<2)>>2]|0;do{if((L|0)==0){J=c[3528598]|0;if((J|0)==0){N=0;break}N=gj[J&4095](H)|0}else{N=a[L+(M&255)|0]|0}}while(0);b[4853740]=N&255|K;c[2439268]=(c[2439268]|0)-6;break};case 42:{K=(b[4821336]|0)-1&65535;b[4821336]=K;b[4853740]=K;K=c[2426870]|0;N=K&65535;M=c[9699632+((K>>>8&255)<<2)>>2]|0;do{if((M|0)==0){L=c[3528598]|0;if((L|0)==0){O=0;break}O=gj[L&4095](N)|0}else{O=a[M+(K&255)|0]|0}}while(0);M=(O&255)<<8;O=K+1|0;K=O&65535;N=c[9699632+((O>>>8&255)<<2)>>2]|0;do{if((N|0)==0){L=c[3528598]|0;if((L|0)==0){P=0;break}P=gj[L&4095](K)|0}else{P=a[N+(O&255)|0]|0}}while(0);b[4853740]=P&255|M;c[2439268]=(c[2439268]|0)-5;break};case 41:{M=b[4821336]|0;b[4853740]=M;b[4821336]=M+2&65535;M=c[2426870]|0;P=M&65535;O=c[9699632+((M>>>8&255)<<2)>>2]|0;do{if((O|0)==0){N=c[3528598]|0;if((N|0)==0){Q=0;break}Q=gj[N&4095](P)|0}else{Q=a[O+(M&255)|0]|0}}while(0);O=(Q&255)<<8;Q=M+1|0;M=Q&65535;P=c[9699632+((Q>>>8&255)<<2)>>2]|0;do{if((P|0)==0){N=c[3528598]|0;if((N|0)==0){R=0;break}R=gj[N&4095](M)|0}else{R=a[P+(Q&255)|0]|0}}while(0);b[4853740]=R&255|O;c[2439268]=(c[2439268]|0)-6;break};case 61:{O=c[2410662]|0;R=O&65535;Q=c[9701680+((O>>>8&255)<<2)>>2]|0;do{if((Q|0)==0){P=c[3528598]|0;if((P|0)==0){S=0;T=O;U=R;break}M=gj[P&4095](R)|0;P=c[2410662]|0;S=M;T=P;U=P&65535}else{S=a[Q+(O&255)|0]|0;T=O;U=R}}while(0);R=(S&255)<<8;S=T+1|0;T=S&65535;O=c[9701680+((S>>>8&255)<<2)>>2]|0;do{if((O|0)==0){Q=c[3528598]|0;if((Q|0)==0){V=0;W=U;break}P=gj[Q&4095](T)|0;V=P;W=b[4821324]|0}else{V=a[O+(S&255)|0]|0;W=U}}while(0);U=V&255|R;c[2426870]=U;b[4821324]=W+2&65535;b[4853740]=(U&65535)+(b[4821338]|0)&65535;U=c[2426870]|0;W=U&65535;R=c[9699632+((U>>>8&255)<<2)>>2]|0;do{if((R|0)==0){V=c[3528598]|0;if((V|0)==0){X=0;break}X=gj[V&4095](W)|0}else{X=a[R+(U&255)|0]|0}}while(0);R=(X&255)<<8;X=U+1|0;U=X&65535;W=c[9699632+((X>>>8&255)<<2)>>2]|0;do{if((W|0)==0){V=c[3528598]|0;if((V|0)==0){Y=0;break}Y=gj[V&4095](U)|0}else{Y=a[W+(X&255)|0]|0}}while(0);b[4853740]=Y&255|R;c[2439268]=(c[2439268]|0)-7;break};case 62:{b[4853740]=b[4821338]|0;R=c[2426870]|0;Y=R&65535;X=c[9699632+((R>>>8&255)<<2)>>2]|0;do{if((X|0)==0){W=c[3528598]|0;if((W|0)==0){Z=0;break}Z=gj[W&4095](Y)|0}else{Z=a[X+(R&255)|0]|0}}while(0);X=(Z&255)<<8;Z=R+1|0;R=Z&65535;Y=c[9699632+((Z>>>8&255)<<2)>>2]|0;do{if((Y|0)==0){W=c[3528598]|0;if((W|0)==0){_=0;break}_=gj[W&4095](R)|0}else{_=a[Y+(Z&255)|0]|0}}while(0);b[4853740]=_&255|X;c[2439268]=(c[2439268]|0)-3;break};case 80:{X=b[4821332]|0;b[4853740]=X;b[4821332]=X+1&65535;c[2439268]=(c[2439268]|0)-2;break};case 81:{X=b[4821332]|0;b[4853740]=X;b[4821332]=X+2&65535;c[2439268]=(c[2439268]|0)-3;break};case 82:{X=(b[4821332]|0)-1&65535;b[4821332]=X;b[4853740]=X;c[2439268]=(c[2439268]|0)-2;break};case 83:{X=(b[4821332]|0)-2&65535;b[4821332]=X;b[4853740]=X;c[2439268]=(c[2439268]|0)-3;break};case 84:{X=c[2410662]|0;_=X&65535;Z=c[9701680+((X>>>8&255)<<2)>>2]|0;do{if((Z|0)==0){Y=c[3528598]|0;if((Y|0)==0){$=0;aa=_;break}R=gj[Y&4095](_)|0;$=R;aa=b[4821324]|0}else{$=a[Z+(X&255)|0]|0;aa=_}}while(0);b[4821324]=aa+1&65535;b[4853740]=(b[4821332]|0)+($<<24>>24)&65535;c[2439268]=(c[2439268]|0)-2;break};case 45:{$=c[2410662]|0;aa=$&65535;_=c[9701680+(($>>>8&255)<<2)>>2]|0;do{if((_|0)==0){X=c[3528598]|0;if((X|0)==0){ab=0;ac=$;ad=aa;break}Z=gj[X&4095](aa)|0;X=c[2410662]|0;ab=Z;ac=X;ad=X&65535}else{ab=a[_+($&255)|0]|0;ac=$;ad=aa}}while(0);aa=(ab&255)<<8;ab=ac+1|0;ac=ab&65535;$=c[9701680+((ab>>>8&255)<<2)>>2]|0;do{if(($|0)==0){_=c[3528598]|0;if((_|0)==0){ae=0;af=ad;break}X=gj[_&4095](ac)|0;ae=X;af=b[4821324]|0}else{ae=a[$+(ab&255)|0]|0;af=ad}}while(0);ad=ae&255|aa;c[2426870]=ad;b[4821324]=af+2&65535;b[4853740]=(ad&65535)+(b[4821336]|0)&65535;ad=c[2426870]|0;af=ad&65535;aa=c[9699632+((ad>>>8&255)<<2)>>2]|0;do{if((aa|0)==0){ae=c[3528598]|0;if((ae|0)==0){ag=0;break}ag=gj[ae&4095](af)|0}else{ag=a[aa+(ad&255)|0]|0}}while(0);aa=(ag&255)<<8;ag=ad+1|0;ad=ag&65535;af=c[9699632+((ag>>>8&255)<<2)>>2]|0;do{if((af|0)==0){ae=c[3528598]|0;if((ae|0)==0){ah=0;break}ah=gj[ae&4095](ad)|0}else{ah=a[af+(ag&255)|0]|0}}while(0);b[4853740]=ah&255|aa;c[2439268]=(c[2439268]|0)-7;break};case 46:{b[4853740]=b[4821336]|0;aa=c[2426870]|0;ah=aa&65535;ag=c[9699632+((aa>>>8&255)<<2)>>2]|0;do{if((ag|0)==0){af=c[3528598]|0;if((af|0)==0){ai=0;break}ai=gj[af&4095](ah)|0}else{ai=a[ag+(aa&255)|0]|0}}while(0);ag=(ai&255)<<8;ai=aa+1|0;aa=ai&65535;ah=c[9699632+((ai>>>8&255)<<2)>>2]|0;do{if((ah|0)==0){af=c[3528598]|0;if((af|0)==0){aj=0;break}aj=gj[af&4095](aa)|0}else{aj=a[ah+(ai&255)|0]|0}}while(0);b[4853740]=aj&255|ag;c[2439268]=(c[2439268]|0)-3;break};case 44:{ag=c[2410662]|0;aj=ag&65535;ai=c[9701680+((ag>>>8&255)<<2)>>2]|0;do{if((ai|0)==0){ah=c[3528598]|0;if((ah|0)==0){ak=0;al=aj;break}aa=gj[ah&4095](aj)|0;ak=aa;al=b[4821324]|0}else{ak=a[ai+(ag&255)|0]|0;al=aj}}while(0);b[4821324]=al+1&65535;b[4853740]=(b[4821336]|0)+(ak<<24>>24)&65535;ak=c[2426870]|0;al=ak&65535;aj=c[9699632+((ak>>>8&255)<<2)>>2]|0;do{if((aj|0)==0){ag=c[3528598]|0;if((ag|0)==0){am=0;break}am=gj[ag&4095](al)|0}else{am=a[aj+(ak&255)|0]|0}}while(0);aj=(am&255)<<8;am=ak+1|0;ak=am&65535;al=c[9699632+((am>>>8&255)<<2)>>2]|0;do{if((al|0)==0){ag=c[3528598]|0;if((ag|0)==0){an=0;break}an=gj[ag&4095](ak)|0}else{an=a[al+(am&255)|0]|0}}while(0);b[4853740]=an&255|aj;c[2439268]=(c[2439268]|0)-4;break};case 48:{aj=b[4821338]|0;b[4853740]=aj;b[4821338]=aj+1&65535;c[2439268]=(c[2439268]|0)-2;break};case 49:{aj=b[4821338]|0;b[4853740]=aj;b[4821338]=aj+2&65535;c[2439268]=(c[2439268]|0)-3;break};case 50:{aj=(b[4821338]|0)-1&65535;b[4821338]=aj;b[4853740]=aj;c[2439268]=(c[2439268]|0)-2;break};case 51:{aj=(b[4821338]|0)-2&65535;b[4821338]=aj;b[4853740]=aj;c[2439268]=(c[2439268]|0)-3;break};case 52:{aj=c[2410662]|0;an=aj&65535;am=c[9701680+((aj>>>8&255)<<2)>>2]|0;do{if((am|0)==0){al=c[3528598]|0;if((al|0)==0){ao=0;ap=an;break}ak=gj[al&4095](an)|0;ao=ak;ap=b[4821324]|0}else{ao=a[am+(aj&255)|0]|0;ap=an}}while(0);b[4821324]=ap+1&65535;b[4853740]=(b[4821338]|0)+(ao<<24>>24)&65535;c[2439268]=(c[2439268]|0)-2;break};case 53:{ao=c[2410662]|0;ap=ao&65535;an=c[9701680+((ao>>>8&255)<<2)>>2]|0;do{if((an|0)==0){aj=c[3528598]|0;if((aj|0)==0){aq=0;ar=ao;as=ap;break}am=gj[aj&4095](ap)|0;aj=c[2410662]|0;aq=am;ar=aj;as=aj&65535}else{aq=a[an+(ao&255)|0]|0;ar=ao;as=ap}}while(0);ap=(aq&255)<<8;aq=ar+1|0;ar=aq&65535;ao=c[9701680+((aq>>>8&255)<<2)>>2]|0;do{if((ao|0)==0){an=c[3528598]|0;if((an|0)==0){at=0;au=as;break}aj=gj[an&4095](ar)|0;at=aj;au=b[4821324]|0}else{at=a[ao+(aq&255)|0]|0;au=as}}while(0);as=at&255|ap;c[2426870]=as;b[4821324]=au+2&65535;b[4853740]=(as&65535)+(b[4821338]|0)&65535;c[2439268]=(c[2439268]|0)-4;break};case 54:{b[4853740]=b[4821338]|0;break};case 56:{as=b[4821338]|0;b[4853740]=as;b[4821338]=as+1&65535;as=c[2426870]|0;au=as&65535;ap=c[9699632+((as>>>8&255)<<2)>>2]|0;do{if((ap|0)==0){at=c[3528598]|0;if((at|0)==0){av=0;break}av=gj[at&4095](au)|0}else{av=a[ap+(as&255)|0]|0}}while(0);ap=(av&255)<<8;av=as+1|0;as=av&65535;au=c[9699632+((av>>>8&255)<<2)>>2]|0;do{if((au|0)==0){at=c[3528598]|0;if((at|0)==0){aw=0;break}aw=gj[at&4095](as)|0}else{aw=a[au+(av&255)|0]|0}}while(0);b[4853740]=aw&255|ap;c[2439268]=(c[2439268]|0)-5;break};case 85:{ap=c[2410662]|0;aw=ap&65535;av=c[9701680+((ap>>>8&255)<<2)>>2]|0;do{if((av|0)==0){au=c[3528598]|0;if((au|0)==0){ax=0;ay=ap;az=aw;break}as=gj[au&4095](aw)|0;au=c[2410662]|0;ax=as;ay=au;az=au&65535}else{ax=a[av+(ap&255)|0]|0;ay=ap;az=aw}}while(0);aw=(ax&255)<<8;ax=ay+1|0;ay=ax&65535;ap=c[9701680+((ax>>>8&255)<<2)>>2]|0;do{if((ap|0)==0){av=c[3528598]|0;if((av|0)==0){aA=0;aB=az;break}au=gj[av&4095](ay)|0;aA=au;aB=b[4821324]|0}else{aA=a[ap+(ax&255)|0]|0;aB=az}}while(0);az=aA&255|aw;c[2426870]=az;b[4821324]=aB+2&65535;b[4853740]=(az&65535)+(b[4821332]|0)&65535;c[2439268]=(c[2439268]|0)-4;break};case 86:{b[4853740]=b[4821332]|0;break};case 88:{az=b[4821332]|0;b[4853740]=az;b[4821332]=az+1&65535;az=c[2426870]|0;aB=az&65535;aw=c[9699632+((az>>>8&255)<<2)>>2]|0;do{if((aw|0)==0){aA=c[3528598]|0;if((aA|0)==0){aC=0;break}aC=gj[aA&4095](aB)|0}else{aC=a[aw+(az&255)|0]|0}}while(0);aw=(aC&255)<<8;aC=az+1|0;az=aC&65535;aB=c[9699632+((aC>>>8&255)<<2)>>2]|0;do{if((aB|0)==0){aA=c[3528598]|0;if((aA|0)==0){aD=0;break}aD=gj[aA&4095](az)|0}else{aD=a[aB+(aC&255)|0]|0}}while(0);b[4853740]=aD&255|aw;c[2439268]=(c[2439268]|0)-5;break};case 89:{aw=b[4821332]|0;b[4853740]=aw;b[4821332]=aw+2&65535;aw=c[2426870]|0;aD=aw&65535;aC=c[9699632+((aw>>>8&255)<<2)>>2]|0;do{if((aC|0)==0){aB=c[3528598]|0;if((aB|0)==0){aE=0;break}aE=gj[aB&4095](aD)|0}else{aE=a[aC+(aw&255)|0]|0}}while(0);aC=(aE&255)<<8;aE=aw+1|0;aw=aE&65535;aD=c[9699632+((aE>>>8&255)<<2)>>2]|0;do{if((aD|0)==0){aB=c[3528598]|0;if((aB|0)==0){aF=0;break}aF=gj[aB&4095](aw)|0}else{aF=a[aD+(aE&255)|0]|0}}while(0);b[4853740]=aF&255|aC;c[2439268]=(c[2439268]|0)-6;break};case 90:{aC=(b[4821332]|0)-1&65535;b[4821332]=aC;b[4853740]=aC;aC=c[2426870]|0;aF=aC&65535;aE=c[9699632+((aC>>>8&255)<<2)>>2]|0;do{if((aE|0)==0){aD=c[3528598]|0;if((aD|0)==0){aG=0;break}aG=gj[aD&4095](aF)|0}else{aG=a[aE+(aC&255)|0]|0}}while(0);aE=(aG&255)<<8;aG=aC+1|0;aC=aG&65535;aF=c[9699632+((aG>>>8&255)<<2)>>2]|0;do{if((aF|0)==0){aD=c[3528598]|0;if((aD|0)==0){aH=0;break}aH=gj[aD&4095](aC)|0}else{aH=a[aF+(aG&255)|0]|0}}while(0);b[4853740]=aH&255|aE;c[2439268]=(c[2439268]|0)-5;break};case 91:{aE=(b[4821332]|0)-2&65535;b[4821332]=aE;b[4853740]=aE;aE=c[2426870]|0;aH=aE&65535;aG=c[9699632+((aE>>>8&255)<<2)>>2]|0;do{if((aG|0)==0){aF=c[3528598]|0;if((aF|0)==0){aI=0;break}aI=gj[aF&4095](aH)|0}else{aI=a[aG+(aE&255)|0]|0}}while(0);aG=(aI&255)<<8;aI=aE+1|0;aE=aI&65535;aH=c[9699632+((aI>>>8&255)<<2)>>2]|0;do{if((aH|0)==0){aF=c[3528598]|0;if((aF|0)==0){aJ=0;break}aJ=gj[aF&4095](aE)|0}else{aJ=a[aH+(aI&255)|0]|0}}while(0);b[4853740]=aJ&255|aG;c[2439268]=(c[2439268]|0)-6;break};case 92:{aG=c[2410662]|0;aJ=aG&65535;aI=c[9701680+((aG>>>8&255)<<2)>>2]|0;do{if((aI|0)==0){aH=c[3528598]|0;if((aH|0)==0){aK=0;aL=aJ;break}aE=gj[aH&4095](aJ)|0;aK=aE;aL=b[4821324]|0}else{aK=a[aI+(aG&255)|0]|0;aL=aJ}}while(0);b[4821324]=aL+1&65535;b[4853740]=(b[4821332]|0)+(aK<<24>>24)&65535;aK=c[2426870]|0;aL=aK&65535;aJ=c[9699632+((aK>>>8&255)<<2)>>2]|0;do{if((aJ|0)==0){aG=c[3528598]|0;if((aG|0)==0){aM=0;break}aM=gj[aG&4095](aL)|0}else{aM=a[aJ+(aK&255)|0]|0}}while(0);aJ=(aM&255)<<8;aM=aK+1|0;aK=aM&65535;aL=c[9699632+((aM>>>8&255)<<2)>>2]|0;do{if((aL|0)==0){aG=c[3528598]|0;if((aG|0)==0){aN=0;break}aN=gj[aG&4095](aK)|0}else{aN=a[aL+(aM&255)|0]|0}}while(0);b[4853740]=aN&255|aJ;c[2439268]=(c[2439268]|0)-4;break};case 93:{aJ=c[2410662]|0;aN=aJ&65535;aM=c[9701680+((aJ>>>8&255)<<2)>>2]|0;do{if((aM|0)==0){aL=c[3528598]|0;if((aL|0)==0){aO=0;aP=aJ;aQ=aN;break}aK=gj[aL&4095](aN)|0;aL=c[2410662]|0;aO=aK;aP=aL;aQ=aL&65535}else{aO=a[aM+(aJ&255)|0]|0;aP=aJ;aQ=aN}}while(0);aN=(aO&255)<<8;aO=aP+1|0;aP=aO&65535;aJ=c[9701680+((aO>>>8&255)<<2)>>2]|0;do{if((aJ|0)==0){aM=c[3528598]|0;if((aM|0)==0){aR=0;aS=aQ;break}aL=gj[aM&4095](aP)|0;aR=aL;aS=b[4821324]|0}else{aR=a[aJ+(aO&255)|0]|0;aS=aQ}}while(0);aQ=aR&255|aN;c[2426870]=aQ;b[4821324]=aS+2&65535;b[4853740]=(aQ&65535)+(b[4821332]|0)&65535;aQ=c[2426870]|0;aS=aQ&65535;aN=c[9699632+((aQ>>>8&255)<<2)>>2]|0;do{if((aN|0)==0){aR=c[3528598]|0;if((aR|0)==0){aT=0;break}aT=gj[aR&4095](aS)|0}else{aT=a[aN+(aQ&255)|0]|0}}while(0);aN=(aT&255)<<8;aT=aQ+1|0;aQ=aT&65535;aS=c[9699632+((aT>>>8&255)<<2)>>2]|0;do{if((aS|0)==0){aR=c[3528598]|0;if((aR|0)==0){aU=0;break}aU=gj[aR&4095](aQ)|0}else{aU=a[aS+(aT&255)|0]|0}}while(0);b[4853740]=aU&255|aN;c[2439268]=(c[2439268]|0)-7;break};case 94:{b[4853740]=b[4821332]|0;aN=c[2426870]|0;aU=aN&65535;aT=c[9699632+((aN>>>8&255)<<2)>>2]|0;do{if((aT|0)==0){aS=c[3528598]|0;if((aS|0)==0){aV=0;break}aV=gj[aS&4095](aU)|0}else{aV=a[aT+(aN&255)|0]|0}}while(0);aT=(aV&255)<<8;aV=aN+1|0;aN=aV&65535;aU=c[9699632+((aV>>>8&255)<<2)>>2]|0;do{if((aU|0)==0){aS=c[3528598]|0;if((aS|0)==0){aW=0;break}aW=gj[aS&4095](aN)|0}else{aW=a[aU+(aV&255)|0]|0}}while(0);b[4853740]=aW&255|aT;c[2439268]=(c[2439268]|0)-3;break};case 96:{aT=c[2410667]|0;c[2426870]=aT;b[4821334]=(aT&65535)+1&65535;c[2439268]=(c[2439268]|0)-2;break};case 97:{aT=c[2410667]|0;c[2426870]=aT;b[4821334]=(aT&65535)+2&65535;c[2439268]=(c[2439268]|0)-3;break};case 98:{b[4821334]=(b[4821334]|0)-1&65535;c[2426870]=c[2410667];c[2439268]=(c[2439268]|0)-2;break};case 99:{b[4821334]=(b[4821334]|0)-2&65535;c[2426870]=c[2410667];c[2439268]=(c[2439268]|0)-3;break};case 100:{aT=c[2410662]|0;aW=aT&65535;aV=c[9701680+((aT>>>8&255)<<2)>>2]|0;do{if((aV|0)==0){aU=c[3528598]|0;if((aU|0)==0){aX=0;aY=aW;break}aN=gj[aU&4095](aW)|0;aX=aN;aY=b[4821324]|0}else{aX=a[aV+(aT&255)|0]|0;aY=aW}}while(0);b[4821324]=aY+1&65535;b[4853740]=(b[4821334]|0)+(aX<<24>>24)&65535;c[2439268]=(c[2439268]|0)-2;break};case 101:{aX=c[2410662]|0;aY=aX&65535;aW=c[9701680+((aX>>>8&255)<<2)>>2]|0;do{if((aW|0)==0){aT=c[3528598]|0;if((aT|0)==0){aZ=0;a_=aX;a$=aY;break}aV=gj[aT&4095](aY)|0;aT=c[2410662]|0;aZ=aV;a_=aT;a$=aT&65535}else{aZ=a[aW+(aX&255)|0]|0;a_=aX;a$=aY}}while(0);aY=(aZ&255)<<8;aZ=a_+1|0;a_=aZ&65535;aX=c[9701680+((aZ>>>8&255)<<2)>>2]|0;do{if((aX|0)==0){aW=c[3528598]|0;if((aW|0)==0){a0=0;a1=a$;break}aT=gj[aW&4095](a_)|0;a0=aT;a1=b[4821324]|0}else{a0=a[aX+(aZ&255)|0]|0;a1=a$}}while(0);a$=a0&255|aY;c[2426870]=a$;b[4821324]=a1+2&65535;b[4853740]=(a$&65535)+(b[4821334]|0)&65535;c[2439268]=(c[2439268]|0)-4;break};case 102:{c[2426870]=c[2410667];break};case 104:{a$=c[2410667]|0;c[2426870]=a$;a1=a$&65535;b[4821334]=a1+1&65535;aY=c[9699632+((a$>>>8&255)<<2)>>2]|0;do{if((aY|0)==0){a0=c[3528598]|0;if((a0|0)==0){a2=0;break}a2=gj[a0&4095](a1)|0}else{a2=a[aY+(a$&255)|0]|0}}while(0);aY=(a2&255)<<8;a2=a$+1|0;a$=a2&65535;a1=c[9699632+((a2>>>8&255)<<2)>>2]|0;do{if((a1|0)==0){a0=c[3528598]|0;if((a0|0)==0){a3=0;break}a3=gj[a0&4095](a$)|0}else{a3=a[a1+(a2&255)|0]|0}}while(0);b[4853740]=a3&255|aY;c[2439268]=(c[2439268]|0)-5;break};case 105:{aY=c[2410667]|0;c[2426870]=aY;a3=aY&65535;b[4821334]=a3+2&65535;a2=c[9699632+((aY>>>8&255)<<2)>>2]|0;do{if((a2|0)==0){a1=c[3528598]|0;if((a1|0)==0){a4=0;break}a4=gj[a1&4095](a3)|0}else{a4=a[a2+(aY&255)|0]|0}}while(0);a2=(a4&255)<<8;a4=aY+1|0;aY=a4&65535;a3=c[9699632+((a4>>>8&255)<<2)>>2]|0;do{if((a3|0)==0){a1=c[3528598]|0;if((a1|0)==0){a5=0;break}a5=gj[a1&4095](aY)|0}else{a5=a[a3+(a4&255)|0]|0}}while(0);b[4853740]=a5&255|a2;c[2439268]=(c[2439268]|0)-6;break};case 106:{b[4821334]=(b[4821334]|0)-1&65535;a2=c[2410667]|0;c[2426870]=a2;a5=a2&65535;a4=c[9699632+((a2>>>8&255)<<2)>>2]|0;do{if((a4|0)==0){a3=c[3528598]|0;if((a3|0)==0){a6=0;break}a6=gj[a3&4095](a5)|0}else{a6=a[a4+(a2&255)|0]|0}}while(0);a4=(a6&255)<<8;a6=a2+1|0;a2=a6&65535;a5=c[9699632+((a6>>>8&255)<<2)>>2]|0;do{if((a5|0)==0){a3=c[3528598]|0;if((a3|0)==0){a7=0;break}a7=gj[a3&4095](a2)|0}else{a7=a[a5+(a6&255)|0]|0}}while(0);b[4853740]=a7&255|a4;c[2439268]=(c[2439268]|0)-5;break};case 107:{b[4821334]=(b[4821334]|0)-2&65535;a4=c[2410667]|0;c[2426870]=a4;a7=a4&65535;a6=c[9699632+((a4>>>8&255)<<2)>>2]|0;do{if((a6|0)==0){a5=c[3528598]|0;if((a5|0)==0){a8=0;break}a8=gj[a5&4095](a7)|0}else{a8=a[a6+(a4&255)|0]|0}}while(0);a6=(a8&255)<<8;a8=a4+1|0;a4=a8&65535;a7=c[9699632+((a8>>>8&255)<<2)>>2]|0;do{if((a7|0)==0){a5=c[3528598]|0;if((a5|0)==0){a9=0;break}a9=gj[a5&4095](a4)|0}else{a9=a[a7+(a8&255)|0]|0}}while(0);b[4853740]=a9&255|a6;c[2439268]=(c[2439268]|0)-6;break};case 108:{a6=c[2410662]|0;a9=a6&65535;a8=c[9701680+((a6>>>8&255)<<2)>>2]|0;do{if((a8|0)==0){a7=c[3528598]|0;if((a7|0)==0){ba=0;bb=a9;break}a4=gj[a7&4095](a9)|0;ba=a4;bb=b[4821324]|0}else{ba=a[a8+(a6&255)|0]|0;bb=a9}}while(0);b[4821324]=bb+1&65535;b[4853740]=(b[4821334]|0)+(ba<<24>>24)&65535;ba=c[2426870]|0;bb=ba&65535;a9=c[9699632+((ba>>>8&255)<<2)>>2]|0;do{if((a9|0)==0){a6=c[3528598]|0;if((a6|0)==0){bc=0;break}bc=gj[a6&4095](bb)|0}else{bc=a[a9+(ba&255)|0]|0}}while(0);a9=(bc&255)<<8;bc=ba+1|0;ba=bc&65535;bb=c[9699632+((bc>>>8&255)<<2)>>2]|0;do{if((bb|0)==0){a6=c[3528598]|0;if((a6|0)==0){bd=0;break}bd=gj[a6&4095](ba)|0}else{bd=a[bb+(bc&255)|0]|0}}while(0);b[4853740]=bd&255|a9;c[2439268]=(c[2439268]|0)-4;break};case 109:{a9=c[2410662]|0;bd=a9&65535;bc=c[9701680+((a9>>>8&255)<<2)>>2]|0;do{if((bc|0)==0){bb=c[3528598]|0;if((bb|0)==0){be=0;bf=a9;bg=bd;break}ba=gj[bb&4095](bd)|0;bb=c[2410662]|0;be=ba;bf=bb;bg=bb&65535}else{be=a[bc+(a9&255)|0]|0;bf=a9;bg=bd}}while(0);bd=(be&255)<<8;be=bf+1|0;bf=be&65535;a9=c[9701680+((be>>>8&255)<<2)>>2]|0;do{if((a9|0)==0){bc=c[3528598]|0;if((bc|0)==0){bh=0;bi=bg;break}bb=gj[bc&4095](bf)|0;bh=bb;bi=b[4821324]|0}else{bh=a[a9+(be&255)|0]|0;bi=bg}}while(0);bg=bh&255|bd;c[2426870]=bg;b[4821324]=bi+2&65535;b[4853740]=(bg&65535)+(b[4821334]|0)&65535;bg=c[2426870]|0;bi=bg&65535;bd=c[9699632+((bg>>>8&255)<<2)>>2]|0;do{if((bd|0)==0){bh=c[3528598]|0;if((bh|0)==0){bj=0;break}bj=gj[bh&4095](bi)|0}else{bj=a[bd+(bg&255)|0]|0}}while(0);bd=(bj&255)<<8;bj=bg+1|0;bg=bj&65535;bi=c[9699632+((bj>>>8&255)<<2)>>2]|0;do{if((bi|0)==0){bh=c[3528598]|0;if((bh|0)==0){bk=0;break}bk=gj[bh&4095](bg)|0}else{bk=a[bi+(bj&255)|0]|0}}while(0);b[4853740]=bk&255|bd;c[2439268]=(c[2439268]|0)-7;break};case 110:{bd=c[2410667]|0;c[2426870]=bd;bk=bd&65535;bj=c[9699632+((bd>>>8&255)<<2)>>2]|0;do{if((bj|0)==0){bi=c[3528598]|0;if((bi|0)==0){bl=0;break}bl=gj[bi&4095](bk)|0}else{bl=a[bj+(bd&255)|0]|0}}while(0);bj=(bl&255)<<8;bl=bd+1|0;bd=bl&65535;bk=c[9699632+((bl>>>8&255)<<2)>>2]|0;do{if((bk|0)==0){bi=c[3528598]|0;if((bi|0)==0){bm=0;break}bm=gj[bi&4095](bd)|0}else{bm=a[bk+(bl&255)|0]|0}}while(0);b[4853740]=bm&255|bj;c[2439268]=(c[2439268]|0)-3;break};case 112:{bj=c[2410662]|0;c[2426870]=bj;b[4821324]=(bj&65535)+1&65535;c[2439268]=(c[2439268]|0)-2;break};case 113:{bj=c[2410662]|0;c[2426870]=bj;b[4821324]=(bj&65535)+2&65535;c[2439268]=(c[2439268]|0)-3;break};case 114:{b[4821324]=k;c[2426870]=c[2410662];c[2439268]=(c[2439268]|0)-2;break};case 115:{b[4821324]=k-1&65535;c[2426870]=c[2410662];c[2439268]=(c[2439268]|0)-3;break};case 116:{bj=c[2410662]|0;bm=bj&65535;bl=c[9701680+((bj>>>8&255)<<2)>>2]|0;do{if((bl|0)==0){bk=c[3528598]|0;if((bk|0)==0){bn=0;bo=bm;break}bd=gj[bk&4095](bm)|0;bn=bd;bo=b[4821324]|0}else{bn=a[bl+(bj&255)|0]|0;bo=bm}}while(0);b[4821324]=bo+1&65535;b[4853740]=(bn<<24>>24)+bo&65535;c[2439268]=(c[2439268]|0)-2;break};case 117:{bo=c[2410662]|0;bn=bo&65535;bm=c[9701680+((bo>>>8&255)<<2)>>2]|0;do{if((bm|0)==0){bj=c[3528598]|0;if((bj|0)==0){bp=0;bq=bo;br=bn;break}bl=gj[bj&4095](bn)|0;bj=c[2410662]|0;bp=bl;bq=bj;br=bj&65535}else{bp=a[bm+(bo&255)|0]|0;bq=bo;br=bn}}while(0);bn=(bp&255)<<8;bp=bq+1|0;bq=bp&65535;bo=c[9701680+((bp>>>8&255)<<2)>>2]|0;do{if((bo|0)==0){bm=c[3528598]|0;if((bm|0)==0){bs=0;bt=br;break}bj=gj[bm&4095](bq)|0;bs=bj;bt=b[4821324]|0}else{bs=a[bo+(bp&255)|0]|0;bt=br}}while(0);br=bs&255|bn;c[2426870]=br;b[4821324]=bt+2&65535;b[4853740]=(br&65535)+bt&65535;c[2439268]=(c[2439268]|0)-4;break};case 118:{c[2426870]=c[2410662];break};case 120:{bt=c[2410662]|0;c[2426870]=bt;br=bt&65535;b[4821324]=br+1&65535;bn=c[9699632+((bt>>>8&255)<<2)>>2]|0;do{if((bn|0)==0){bs=c[3528598]|0;if((bs|0)==0){bu=0;break}bu=gj[bs&4095](br)|0}else{bu=a[bn+(bt&255)|0]|0}}while(0);bn=(bu&255)<<8;bu=bt+1|0;bt=bu&65535;br=c[9699632+((bu>>>8&255)<<2)>>2]|0;do{if((br|0)==0){bs=c[3528598]|0;if((bs|0)==0){bv=0;break}bv=gj[bs&4095](bt)|0}else{bv=a[br+(bu&255)|0]|0}}while(0);b[4853740]=bv&255|bn;c[2439268]=(c[2439268]|0)-5;break};case 121:{bn=c[2410662]|0;c[2426870]=bn;bv=bn&65535;b[4821324]=bv+2&65535;bu=c[9699632+((bn>>>8&255)<<2)>>2]|0;do{if((bu|0)==0){br=c[3528598]|0;if((br|0)==0){bx=0;break}bx=gj[br&4095](bv)|0}else{bx=a[bu+(bn&255)|0]|0}}while(0);bu=(bx&255)<<8;bx=bn+1|0;bn=bx&65535;bv=c[9699632+((bx>>>8&255)<<2)>>2]|0;do{if((bv|0)==0){br=c[3528598]|0;if((br|0)==0){by=0;break}by=gj[br&4095](bn)|0}else{by=a[bv+(bx&255)|0]|0}}while(0);b[4853740]=by&255|bu;c[2439268]=(c[2439268]|0)-6;break};case 122:{b[4821324]=k;bu=c[2410662]|0;c[2426870]=bu;by=bu&65535;bx=c[9699632+((bu>>>8&255)<<2)>>2]|0;do{if((bx|0)==0){bv=c[3528598]|0;if((bv|0)==0){bz=0;break}bz=gj[bv&4095](by)|0}else{bz=a[bx+(bu&255)|0]|0}}while(0);bx=(bz&255)<<8;bz=bu+1|0;bu=bz&65535;by=c[9699632+((bz>>>8&255)<<2)>>2]|0;do{if((by|0)==0){bv=c[3528598]|0;if((bv|0)==0){bA=0;break}bA=gj[bv&4095](bu)|0}else{bA=a[by+(bz&255)|0]|0}}while(0);b[4853740]=bA&255|bx;c[2439268]=(c[2439268]|0)-5;break};case 123:{b[4821324]=k-1&65535;k=c[2410662]|0;c[2426870]=k;bx=k&65535;bA=c[9699632+((k>>>8&255)<<2)>>2]|0;do{if((bA|0)==0){bz=c[3528598]|0;if((bz|0)==0){bB=0;break}bB=gj[bz&4095](bx)|0}else{bB=a[bA+(k&255)|0]|0}}while(0);bA=(bB&255)<<8;bB=k+1|0;k=bB&65535;bx=c[9699632+((bB>>>8&255)<<2)>>2]|0;do{if((bx|0)==0){bz=c[3528598]|0;if((bz|0)==0){bC=0;break}bC=gj[bz&4095](k)|0}else{bC=a[bx+(bB&255)|0]|0}}while(0);b[4853740]=bC&255|bA;c[2439268]=(c[2439268]|0)-6;break};case 124:{bA=c[2410662]|0;bC=bA&65535;bB=c[9701680+((bA>>>8&255)<<2)>>2]|0;do{if((bB|0)==0){bx=c[3528598]|0;if((bx|0)==0){bD=0;bE=bC;break}k=gj[bx&4095](bC)|0;bD=k;bE=b[4821324]|0}else{bD=a[bB+(bA&255)|0]|0;bE=bC}}while(0);b[4821324]=bE+1&65535;b[4853740]=(bD<<24>>24)+bE&65535;bE=c[2426870]|0;bD=bE&65535;bC=c[9699632+((bE>>>8&255)<<2)>>2]|0;do{if((bC|0)==0){bA=c[3528598]|0;if((bA|0)==0){bF=0;break}bF=gj[bA&4095](bD)|0}else{bF=a[bC+(bE&255)|0]|0}}while(0);bC=(bF&255)<<8;bF=bE+1|0;bE=bF&65535;bD=c[9699632+((bF>>>8&255)<<2)>>2]|0;do{if((bD|0)==0){bA=c[3528598]|0;if((bA|0)==0){bG=0;break}bG=gj[bA&4095](bE)|0}else{bG=a[bD+(bF&255)|0]|0}}while(0);b[4853740]=bG&255|bC;c[2439268]=(c[2439268]|0)-4;break};case 125:{bC=c[2410662]|0;bG=bC&65535;bF=c[9701680+((bC>>>8&255)<<2)>>2]|0;do{if((bF|0)==0){bD=c[3528598]|0;if((bD|0)==0){bH=0;bI=bC;bJ=bG;break}bE=gj[bD&4095](bG)|0;bD=c[2410662]|0;bH=bE;bI=bD;bJ=bD&65535}else{bH=a[bF+(bC&255)|0]|0;bI=bC;bJ=bG}}while(0);bG=(bH&255)<<8;bH=bI+1|0;bI=bH&65535;bC=c[9701680+((bH>>>8&255)<<2)>>2]|0;do{if((bC|0)==0){bF=c[3528598]|0;if((bF|0)==0){bK=0;bL=bJ;break}bD=gj[bF&4095](bI)|0;bK=bD;bL=b[4821324]|0}else{bK=a[bC+(bH&255)|0]|0;bL=bJ}}while(0);bJ=bK&255|bG;c[2426870]=bJ;b[4821324]=bL+2&65535;b[4853740]=(bJ&65535)+bL&65535;bL=c[2426870]|0;bJ=bL&65535;bG=c[9699632+((bL>>>8&255)<<2)>>2]|0;do{if((bG|0)==0){bK=c[3528598]|0;if((bK|0)==0){bM=0;break}bM=gj[bK&4095](bJ)|0}else{bM=a[bG+(bL&255)|0]|0}}while(0);bG=(bM&255)<<8;bM=bL+1|0;bL=bM&65535;bJ=c[9699632+((bM>>>8&255)<<2)>>2]|0;do{if((bJ|0)==0){bK=c[3528598]|0;if((bK|0)==0){bN=0;break}bN=gj[bK&4095](bL)|0}else{bN=a[bJ+(bM&255)|0]|0}}while(0);b[4853740]=bN&255|bG;c[2439268]=(c[2439268]|0)-7;break};case 126:{bG=c[2410662]|0;c[2426870]=bG;bN=bG&65535;bM=c[9699632+((bG>>>8&255)<<2)>>2]|0;do{if((bM|0)==0){bJ=c[3528598]|0;if((bJ|0)==0){bO=0;break}bO=gj[bJ&4095](bN)|0}else{bO=a[bM+(bG&255)|0]|0}}while(0);bM=(bO&255)<<8;bO=bG+1|0;bG=bO&65535;bN=c[9699632+((bO>>>8&255)<<2)>>2]|0;do{if((bN|0)==0){bJ=c[3528598]|0;if((bJ|0)==0){bP=0;break}bP=gj[bJ&4095](bG)|0}else{bP=a[bN+(bO&255)|0]|0}}while(0);b[4853740]=bP&255|bM;c[2439268]=(c[2439268]|0)-3;break};case 160:{b[4853740]=(a[9642657]|0)+(b[4821336]|0)&65535;c[2439268]=(c[2439268]|0)-1;break};case 161:{b[4853740]=(a[9642656]|0)+(b[4821336]|0)&65535;c[2439268]=(c[2439268]|0)-1;break};case 167:{b[4853740]=(b[4821328]|0)+(b[4821336]|0)&65535;c[2439268]=(c[2439268]|0)-4;break};case 168:{b[4853740]=(a[9642657]|0)+(b[4821336]|0)&65535;bM=c[2426870]|0;bP=bM&65535;bO=c[9699632+((bM>>>8&255)<<2)>>2]|0;do{if((bO|0)==0){bN=c[3528598]|0;if((bN|0)==0){bQ=0;break}bQ=gj[bN&4095](bP)|0}else{bQ=a[bO+(bM&255)|0]|0}}while(0);bO=(bQ&255)<<8;bQ=bM+1|0;bM=bQ&65535;bP=c[9699632+((bQ>>>8&255)<<2)>>2]|0;do{if((bP|0)==0){bN=c[3528598]|0;if((bN|0)==0){bR=0;break}bR=gj[bN&4095](bM)|0}else{bR=a[bP+(bQ&255)|0]|0}}while(0);b[4853740]=bR&255|bO;c[2439268]=(c[2439268]|0)-4;break};case 169:{b[4853740]=(a[9642656]|0)+(b[4821336]|0)&65535;bO=c[2426870]|0;bR=bO&65535;bQ=c[9699632+((bO>>>8&255)<<2)>>2]|0;do{if((bQ|0)==0){bP=c[3528598]|0;if((bP|0)==0){bS=0;break}bS=gj[bP&4095](bR)|0}else{bS=a[bQ+(bO&255)|0]|0}}while(0);bQ=(bS&255)<<8;bS=bO+1|0;bO=bS&65535;bR=c[9699632+((bS>>>8&255)<<2)>>2]|0;do{if((bR|0)==0){bP=c[3528598]|0;if((bP|0)==0){bT=0;break}bT=gj[bP&4095](bO)|0}else{bT=a[bR+(bS&255)|0]|0}}while(0);b[4853740]=bT&255|bQ;c[2439268]=(c[2439268]|0)-4;break};case 175:{b[4853740]=(b[4821328]|0)+(b[4821336]|0)&65535;bQ=c[2426870]|0;bT=bQ&65535;bS=c[9699632+((bQ>>>8&255)<<2)>>2]|0;do{if((bS|0)==0){bR=c[3528598]|0;if((bR|0)==0){bU=0;break}bU=gj[bR&4095](bT)|0}else{bU=a[bS+(bQ&255)|0]|0}}while(0);bS=(bU&255)<<8;bU=bQ+1|0;bQ=bU&65535;bT=c[9699632+((bU>>>8&255)<<2)>>2]|0;do{if((bT|0)==0){bR=c[3528598]|0;if((bR|0)==0){bV=0;break}bV=gj[bR&4095](bQ)|0}else{bV=a[bT+(bU&255)|0]|0}}while(0);b[4853740]=bV&255|bS;c[2439268]=(c[2439268]|0)-7;break};case 176:{b[4853740]=(a[9642657]|0)+(b[4821338]|0)&65535;c[2439268]=(c[2439268]|0)-1;break};case 177:{b[4853740]=(a[9642656]|0)+(b[4821338]|0)&65535;c[2439268]=(c[2439268]|0)-1;break};case 183:{b[4853740]=(b[4821328]|0)+(b[4821338]|0)&65535;c[2439268]=(c[2439268]|0)-4;break};case 184:{b[4853740]=(a[9642657]|0)+(b[4821338]|0)&65535;bS=c[2426870]|0;bV=bS&65535;bU=c[9699632+((bS>>>8&255)<<2)>>2]|0;do{if((bU|0)==0){bT=c[3528598]|0;if((bT|0)==0){bW=0;break}bW=gj[bT&4095](bV)|0}else{bW=a[bU+(bS&255)|0]|0}}while(0);bU=(bW&255)<<8;bW=bS+1|0;bS=bW&65535;bV=c[9699632+((bW>>>8&255)<<2)>>2]|0;do{if((bV|0)==0){bT=c[3528598]|0;if((bT|0)==0){bX=0;break}bX=gj[bT&4095](bS)|0}else{bX=a[bV+(bW&255)|0]|0}}while(0);b[4853740]=bX&255|bU;c[2439268]=(c[2439268]|0)-4;break};case 185:{b[4853740]=(a[9642656]|0)+(b[4821338]|0)&65535;bU=c[2426870]|0;bX=bU&65535;bW=c[9699632+((bU>>>8&255)<<2)>>2]|0;do{if((bW|0)==0){bV=c[3528598]|0;if((bV|0)==0){bY=0;break}bY=gj[bV&4095](bX)|0}else{bY=a[bW+(bU&255)|0]|0}}while(0);bW=(bY&255)<<8;bY=bU+1|0;bU=bY&65535;bX=c[9699632+((bY>>>8&255)<<2)>>2]|0;do{if((bX|0)==0){bV=c[3528598]|0;if((bV|0)==0){bZ=0;break}bZ=gj[bV&4095](bU)|0}else{bZ=a[bX+(bY&255)|0]|0}}while(0);b[4853740]=bZ&255|bW;c[2439268]=(c[2439268]|0)-4;break};case 191:{b[4853740]=(b[4821328]|0)+(b[4821338]|0)&65535;bW=c[2426870]|0;bZ=bW&65535;bY=c[9699632+((bW>>>8&255)<<2)>>2]|0;do{if((bY|0)==0){bX=c[3528598]|0;if((bX|0)==0){b_=0;break}b_=gj[bX&4095](bZ)|0}else{b_=a[bY+(bW&255)|0]|0}}while(0);bY=(b_&255)<<8;b_=bW+1|0;bW=b_&65535;bZ=c[9699632+((b_>>>8&255)<<2)>>2]|0;do{if((bZ|0)==0){bX=c[3528598]|0;if((bX|0)==0){b$=0;break}b$=gj[bX&4095](bW)|0}else{b$=a[bZ+(b_&255)|0]|0}}while(0);b[4853740]=b$&255|bY;c[2439268]=(c[2439268]|0)-7;break};case 196:{c[2426870]=0;gu[c[5812856+((a[9642681]&255)<<2)>>2]&16383]();c[2439268]=(c[2439268]|0)-1;i=d;return};case 204:{c[2426870]=c[2410665];bY=c[2410662]|0;b$=bY&65535;b_=c[9701680+((bY>>>8&255)<<2)>>2]|0;do{if((b_|0)==0){bZ=c[3528598]|0;if((bZ|0)==0){b0=0;b1=b$;break}bW=gj[bZ&4095](b$)|0;b0=bW;b1=b[4821324]|0}else{b0=a[b_+(bY&255)|0]|0;b1=b$}}while(0);a[9707480]=b0;b[4821324]=b1+1&65535;b1=c[2426870]|0;b0=b1&65535;b$=c[9699632+((b1>>>8&255)<<2)>>2]|0;do{if((b$|0)==0){bY=c[3528598]|0;if((bY|0)==0){b2=0;break}b2=gj[bY&4095](b0)|0}else{b2=a[b$+(b1&255)|0]|0}}while(0);b$=(b2&255)<<8;b2=b1+1|0;b1=b2&65535;b0=c[9699632+((b2>>>8&255)<<2)>>2]|0;do{if((b0|0)==0){bY=c[3528598]|0;if((bY|0)==0){b3=0;break}b3=gj[bY&4095](b1)|0}else{b3=a[b0+(b2&255)|0]|0}}while(0);c[2426870]=b3&255|b$;c[2439268]=(c[2439268]|0)-4;break};case 208:{b[4853740]=(a[9642657]|0)+(b[4821332]|0)&65535;c[2439268]=(c[2439268]|0)-1;break};case 209:{b[4853740]=(a[9642656]|0)+(b[4821332]|0)&65535;c[2439268]=(c[2439268]|0)-1;break};case 215:{b[4853740]=(b[4821328]|0)+(b[4821332]|0)&65535;c[2439268]=(c[2439268]|0)-4;break};case 216:{b[4853740]=(a[9642657]|0)+(b[4821332]|0)&65535;b$=c[2426870]|0;b3=b$&65535;b2=c[9699632+((b$>>>8&255)<<2)>>2]|0;do{if((b2|0)==0){b0=c[3528598]|0;if((b0|0)==0){b4=0;break}b4=gj[b0&4095](b3)|0}else{b4=a[b2+(b$&255)|0]|0}}while(0);b2=(b4&255)<<8;b4=b$+1|0;b$=b4&65535;b3=c[9699632+((b4>>>8&255)<<2)>>2]|0;do{if((b3|0)==0){b0=c[3528598]|0;if((b0|0)==0){b5=0;break}b5=gj[b0&4095](b$)|0}else{b5=a[b3+(b4&255)|0]|0}}while(0);b[4853740]=b5&255|b2;c[2439268]=(c[2439268]|0)-4;break};case 217:{b[4853740]=(a[9642656]|0)+(b[4821332]|0)&65535;b2=c[2426870]|0;b5=b2&65535;b4=c[9699632+((b2>>>8&255)<<2)>>2]|0;do{if((b4|0)==0){b3=c[3528598]|0;if((b3|0)==0){b6=0;break}b6=gj[b3&4095](b5)|0}else{b6=a[b4+(b2&255)|0]|0}}while(0);b4=(b6&255)<<8;b6=b2+1|0;b2=b6&65535;b5=c[9699632+((b6>>>8&255)<<2)>>2]|0;do{if((b5|0)==0){b3=c[3528598]|0;if((b3|0)==0){b7=0;break}b7=gj[b3&4095](b2)|0}else{b7=a[b5+(b6&255)|0]|0}}while(0);b[4853740]=b7&255|b4;c[2439268]=(c[2439268]|0)-4;break};case 223:{b[4853740]=(b[4821328]|0)+(b[4821332]|0)&65535;b4=c[2426870]|0;b7=b4&65535;b6=c[9699632+((b4>>>8&255)<<2)>>2]|0;do{if((b6|0)==0){b5=c[3528598]|0;if((b5|0)==0){b8=0;break}b8=gj[b5&4095](b7)|0}else{b8=a[b6+(b4&255)|0]|0}}while(0);b6=(b8&255)<<8;b8=b4+1|0;b4=b8&65535;b7=c[9699632+((b8>>>8&255)<<2)>>2]|0;do{if((b7|0)==0){b5=c[3528598]|0;if((b5|0)==0){b9=0;break}b9=gj[b5&4095](b4)|0}else{b9=a[b7+(b8&255)|0]|0}}while(0);b[4853740]=b9&255|b6;c[2439268]=(c[2439268]|0)-7;break};case 224:{b[4853740]=(a[9642657]|0)+(b[4821334]|0)&65535;c[2439268]=(c[2439268]|0)-1;break};case 225:{b[4853740]=(a[9642656]|0)+(b[4821334]|0)&65535;c[2439268]=(c[2439268]|0)-1;break};case 231:{b[4853740]=(b[4821328]|0)+(b[4821334]|0)&65535;c[2439268]=(c[2439268]|0)-4;break};case 232:{b[4853740]=(a[9642657]|0)+(b[4821334]|0)&65535;b6=c[2426870]|0;b9=b6&65535;b8=c[9699632+((b6>>>8&255)<<2)>>2]|0;do{if((b8|0)==0){b7=c[3528598]|0;if((b7|0)==0){ca=0;break}ca=gj[b7&4095](b9)|0}else{ca=a[b8+(b6&255)|0]|0}}while(0);b8=(ca&255)<<8;ca=b6+1|0;b6=ca&65535;b9=c[9699632+((ca>>>8&255)<<2)>>2]|0;do{if((b9|0)==0){b7=c[3528598]|0;if((b7|0)==0){cb=0;break}cb=gj[b7&4095](b6)|0}else{cb=a[b9+(ca&255)|0]|0}}while(0);b[4853740]=cb&255|b8;c[2439268]=(c[2439268]|0)-4;break};case 233:{b[4853740]=(a[9642656]|0)+(b[4821334]|0)&65535;b8=c[2426870]|0;cb=b8&65535;ca=c[9699632+((b8>>>8&255)<<2)>>2]|0;do{if((ca|0)==0){b9=c[3528598]|0;if((b9|0)==0){cc=0;break}cc=gj[b9&4095](cb)|0}else{cc=a[ca+(b8&255)|0]|0}}while(0);ca=(cc&255)<<8;cc=b8+1|0;b8=cc&65535;cb=c[9699632+((cc>>>8&255)<<2)>>2]|0;do{if((cb|0)==0){b9=c[3528598]|0;if((b9|0)==0){cd=0;break}cd=gj[b9&4095](b8)|0}else{cd=a[cb+(cc&255)|0]|0}}while(0);b[4853740]=cd&255|ca;c[2439268]=(c[2439268]|0)-4;break};case 239:{b[4853740]=(b[4821328]|0)+(b[4821334]|0)&65535;ca=c[2426870]|0;cd=ca&65535;cc=c[9699632+((ca>>>8&255)<<2)>>2]|0;do{if((cc|0)==0){cb=c[3528598]|0;if((cb|0)==0){ce=0;break}ce=gj[cb&4095](cd)|0}else{ce=a[cc+(ca&255)|0]|0}}while(0);cc=(ce&255)<<8;ce=ca+1|0;ca=ce&65535;cd=c[9699632+((ce>>>8&255)<<2)>>2]|0;do{if((cd|0)==0){cb=c[3528598]|0;if((cb|0)==0){cf=0;break}cf=gj[cb&4095](ca)|0}else{cf=a[cd+(ce&255)|0]|0}}while(0);b[4853740]=cf&255|cc;c[2439268]=(c[2439268]|0)-7;break};case 240:{b[4853740]=(a[9642657]|0)+f&65535;c[2439268]=(c[2439268]|0)-1;break};case 241:{b[4853740]=(a[9642656]|0)+f&65535;c[2439268]=(c[2439268]|0)-1;break};case 247:{b[4853740]=(b[4821328]|0)+f&65535;c[2439268]=(c[2439268]|0)-4;break};case 248:{b[4853740]=(a[9642657]|0)+f&65535;cc=c[2426870]|0;cf=cc&65535;ce=c[9699632+((cc>>>8&255)<<2)>>2]|0;do{if((ce|0)==0){cd=c[3528598]|0;if((cd|0)==0){cg=0;break}cg=gj[cd&4095](cf)|0}else{cg=a[ce+(cc&255)|0]|0}}while(0);ce=(cg&255)<<8;cg=cc+1|0;cc=cg&65535;cf=c[9699632+((cg>>>8&255)<<2)>>2]|0;do{if((cf|0)==0){cd=c[3528598]|0;if((cd|0)==0){ch=0;break}ch=gj[cd&4095](cc)|0}else{ch=a[cf+(cg&255)|0]|0}}while(0);b[4853740]=ch&255|ce;c[2439268]=(c[2439268]|0)-4;break};case 249:{b[4853740]=(a[9642656]|0)+f&65535;ce=c[2426870]|0;ch=ce&65535;cg=c[9699632+((ce>>>8&255)<<2)>>2]|0;do{if((cg|0)==0){cf=c[3528598]|0;if((cf|0)==0){ci=0;break}ci=gj[cf&4095](ch)|0}else{ci=a[cg+(ce&255)|0]|0}}while(0);cg=(ci&255)<<8;ci=ce+1|0;ce=ci&65535;ch=c[9699632+((ci>>>8&255)<<2)>>2]|0;do{if((ch|0)==0){cf=c[3528598]|0;if((cf|0)==0){cj=0;break}cj=gj[cf&4095](ce)|0}else{cj=a[ch+(ci&255)|0]|0}}while(0);b[4853740]=cj&255|cg;c[2439268]=(c[2439268]|0)-4;break};case 255:{b[4853740]=(b[4821328]|0)+f&65535;cg=c[2426870]|0;cj=cg&65535;ci=c[9699632+((cg>>>8&255)<<2)>>2]|0;do{if((ci|0)==0){ch=c[3528598]|0;if((ch|0)==0){ck=0;break}ck=gj[ch&4095](cj)|0}else{ck=a[ci+(cg&255)|0]|0}}while(0);ci=(ck&255)<<8;ck=cg+1|0;cg=ck&65535;cj=c[9699632+((ck>>>8&255)<<2)>>2]|0;do{if((cj|0)==0){ch=c[3528598]|0;if((ch|0)==0){cl=0;break}cl=gj[ch&4095](cg)|0}else{cl=a[cj+(ck&255)|0]|0}}while(0);b[4853740]=cl&255|ci;c[2439268]=(c[2439268]|0)-7;break};default:{bw(228680,(ci=i,i=i+8|0,c[ci>>2]=(f&65535)-1,ci)|0)|0;i=ci;c[2426870]=0}}gu[c[4590072+((a[9642681]&255)<<2)>>2]&16383]();i=d;return}function fNK(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);e=i+1&65535;b[4821324]=e;i=h&255;if((i&128|0)!=0){h=e&255;b[4821334]=(b[4821334]|0)-1&65535;e=c[2410667]|0;d=e&65535;f=c[9700656+((e>>>8&255)<<2)>>2]|0;do{if((f|0)==0){j=c[2444172]|0;if((j|0)==0){break}gg[j&4095](d,h)}else{a[f+(e&255)|0]=h}}while(0);b[4821334]=(b[4821334]|0)-1&65535;h=c[2410667]|0;e=h&65535;f=a[9642649]|0;d=c[9700656+((h>>>8&255)<<2)>>2]|0;do{if((d|0)==0){j=c[2444172]|0;if((j|0)==0){break}gg[j&4095](e,f)}else{a[d+(h&255)|0]=f}}while(0);c[2439268]=(c[2439268]|0)-2}if((i&64|0)!=0){b[4821334]=(b[4821334]|0)-1&65535;f=c[2410667]|0;h=f&65535;d=a[9642664]|0;e=c[9700656+((f>>>8&255)<<2)>>2]|0;do{if((e|0)==0){j=c[2444172]|0;if((j|0)==0){break}gg[j&4095](h,d)}else{a[e+(f&255)|0]=d}}while(0);b[4821334]=(b[4821334]|0)-1&65535;d=c[2410667]|0;f=d&65535;e=a[9642665]|0;h=c[9700656+((d>>>8&255)<<2)>>2]|0;do{if((h|0)==0){j=c[2444172]|0;if((j|0)==0){break}gg[j&4095](f,e)}else{a[h+(d&255)|0]=e}}while(0);c[2439268]=(c[2439268]|0)-2}if((i&32|0)!=0){b[4821334]=(b[4821334]|0)-1&65535;e=c[2410667]|0;d=e&65535;h=a[9642676]|0;f=c[9700656+((e>>>8&255)<<2)>>2]|0;do{if((f|0)==0){j=c[2444172]|0;if((j|0)==0){break}gg[j&4095](d,h)}else{a[f+(e&255)|0]=h}}while(0);b[4821334]=(b[4821334]|0)-1&65535;h=c[2410667]|0;e=h&65535;f=a[9642677]|0;d=c[9700656+((h>>>8&255)<<2)>>2]|0;do{if((d|0)==0){j=c[2444172]|0;if((j|0)==0){break}gg[j&4095](e,f)}else{a[d+(h&255)|0]=f}}while(0);c[2439268]=(c[2439268]|0)-2}if((i&16|0)!=0){b[4821334]=(b[4821334]|0)-1&65535;f=c[2410667]|0;h=f&65535;d=a[9642672]|0;e=c[9700656+((f>>>8&255)<<2)>>2]|0;do{if((e|0)==0){j=c[2444172]|0;if((j|0)==0){break}gg[j&4095](h,d)}else{a[e+(f&255)|0]=d}}while(0);b[4821334]=(b[4821334]|0)-1&65535;d=c[2410667]|0;f=d&65535;e=a[9642673]|0;h=c[9700656+((d>>>8&255)<<2)>>2]|0;do{if((h|0)==0){j=c[2444172]|0;if((j|0)==0){break}gg[j&4095](f,e)}else{a[h+(d&255)|0]=e}}while(0);c[2439268]=(c[2439268]|0)-2}if((i&8|0)!=0){b[4821334]=(b[4821334]|0)-1&65535;e=c[2410667]|0;d=e&65535;h=a[9642661]|0;f=c[9700656+((e>>>8&255)<<2)>>2]|0;do{if((f|0)==0){j=c[2444172]|0;if((j|0)==0){break}gg[j&4095](d,h)}else{a[f+(e&255)|0]=h}}while(0);c[2439268]=(c[2439268]|0)-1}if((i&4|0)!=0){b[4821334]=(b[4821334]|0)-1&65535;h=c[2410667]|0;e=h&65535;f=a[9642656]|0;d=c[9700656+((h>>>8&255)<<2)>>2]|0;do{if((d|0)==0){j=c[2444172]|0;if((j|0)==0){break}gg[j&4095](e,f)}else{a[d+(h&255)|0]=f}}while(0);c[2439268]=(c[2439268]|0)-1}if((i&2|0)!=0){b[4821334]=(b[4821334]|0)-1&65535;f=c[2410667]|0;h=f&65535;d=a[9642657]|0;e=c[9700656+((f>>>8&255)<<2)>>2]|0;do{if((e|0)==0){j=c[2444172]|0;if((j|0)==0){break}gg[j&4095](h,d)}else{a[e+(f&255)|0]=d}}while(0);c[2439268]=(c[2439268]|0)-1}if((i&1|0)==0){return}b[4821334]=(b[4821334]|0)-1&65535;i=c[2410667]|0;d=i&65535;f=a[9642680]|0;e=c[9700656+((i>>>8&255)<<2)>>2]|0;do{if((e|0)==0){h=c[2444172]|0;if((h|0)==0){break}gg[h&4095](d,f)}else{a[e+(i&255)|0]=f}}while(0);c[2439268]=(c[2439268]|0)-1;return}function fNL(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);e=i+1&65535;b[4821324]=e;i=h&255;if((i&128|0)!=0){h=e&255;b[4821332]=(b[4821332]|0)-1&65535;e=c[2410666]|0;d=e&65535;f=c[9700656+((e>>>8&255)<<2)>>2]|0;do{if((f|0)==0){j=c[2444172]|0;if((j|0)==0){break}gg[j&4095](d,h)}else{a[f+(e&255)|0]=h}}while(0);b[4821332]=(b[4821332]|0)-1&65535;h=c[2410666]|0;e=h&65535;f=a[9642649]|0;d=c[9700656+((h>>>8&255)<<2)>>2]|0;do{if((d|0)==0){j=c[2444172]|0;if((j|0)==0){break}gg[j&4095](e,f)}else{a[d+(h&255)|0]=f}}while(0);c[2439268]=(c[2439268]|0)-2}if((i&64|0)!=0){b[4821332]=(b[4821332]|0)-1&65535;f=c[2410666]|0;h=f&65535;d=a[9642668]|0;e=c[9700656+((f>>>8&255)<<2)>>2]|0;do{if((e|0)==0){j=c[2444172]|0;if((j|0)==0){break}gg[j&4095](h,d)}else{a[e+(f&255)|0]=d}}while(0);b[4821332]=(b[4821332]|0)-1&65535;d=c[2410666]|0;f=d&65535;e=a[9642669]|0;h=c[9700656+((d>>>8&255)<<2)>>2]|0;do{if((h|0)==0){j=c[2444172]|0;if((j|0)==0){break}gg[j&4095](f,e)}else{a[h+(d&255)|0]=e}}while(0);c[2439268]=(c[2439268]|0)-2}if((i&32|0)!=0){b[4821332]=(b[4821332]|0)-1&65535;e=c[2410666]|0;d=e&65535;h=a[9642676]|0;f=c[9700656+((e>>>8&255)<<2)>>2]|0;do{if((f|0)==0){j=c[2444172]|0;if((j|0)==0){break}gg[j&4095](d,h)}else{a[f+(e&255)|0]=h}}while(0);b[4821332]=(b[4821332]|0)-1&65535;h=c[2410666]|0;e=h&65535;f=a[9642677]|0;d=c[9700656+((h>>>8&255)<<2)>>2]|0;do{if((d|0)==0){j=c[2444172]|0;if((j|0)==0){break}gg[j&4095](e,f)}else{a[d+(h&255)|0]=f}}while(0);c[2439268]=(c[2439268]|0)-2}if((i&16|0)!=0){b[4821332]=(b[4821332]|0)-1&65535;f=c[2410666]|0;h=f&65535;d=a[9642672]|0;e=c[9700656+((f>>>8&255)<<2)>>2]|0;do{if((e|0)==0){j=c[2444172]|0;if((j|0)==0){break}gg[j&4095](h,d)}else{a[e+(f&255)|0]=d}}while(0);b[4821332]=(b[4821332]|0)-1&65535;d=c[2410666]|0;f=d&65535;e=a[9642673]|0;h=c[9700656+((d>>>8&255)<<2)>>2]|0;do{if((h|0)==0){j=c[2444172]|0;if((j|0)==0){break}gg[j&4095](f,e)}else{a[h+(d&255)|0]=e}}while(0);c[2439268]=(c[2439268]|0)-2}if((i&8|0)!=0){b[4821332]=(b[4821332]|0)-1&65535;e=c[2410666]|0;d=e&65535;h=a[9642661]|0;f=c[9700656+((e>>>8&255)<<2)>>2]|0;do{if((f|0)==0){j=c[2444172]|0;if((j|0)==0){break}gg[j&4095](d,h)}else{a[f+(e&255)|0]=h}}while(0);c[2439268]=(c[2439268]|0)-1}if((i&4|0)!=0){b[4821332]=(b[4821332]|0)-1&65535;h=c[2410666]|0;e=h&65535;f=a[9642656]|0;d=c[9700656+((h>>>8&255)<<2)>>2]|0;do{if((d|0)==0){j=c[2444172]|0;if((j|0)==0){break}gg[j&4095](e,f)}else{a[d+(h&255)|0]=f}}while(0);c[2439268]=(c[2439268]|0)-1}if((i&2|0)!=0){b[4821332]=(b[4821332]|0)-1&65535;f=c[2410666]|0;h=f&65535;d=a[9642657]|0;e=c[9700656+((f>>>8&255)<<2)>>2]|0;do{if((e|0)==0){j=c[2444172]|0;if((j|0)==0){break}gg[j&4095](h,d)}else{a[e+(f&255)|0]=d}}while(0);c[2439268]=(c[2439268]|0)-1}if((i&1|0)==0){return}b[4821332]=(b[4821332]|0)-1&65535;i=c[2410666]|0;d=i&65535;f=a[9642680]|0;e=c[9700656+((i>>>8&255)<<2)>>2]|0;do{if((e|0)==0){h=c[2444172]|0;if((h|0)==0){break}gg[h&4095](d,f)}else{a[e+(i&255)|0]=f}}while(0);c[2439268]=(c[2439268]|0)-1;return}function fNM(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;e=c[2410662]|0;f=e&65535;g=c[9701680+((e>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[3528598]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](f)|0;i=k;j=b[4821324]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);b[4821324]=j+1&65535;j=i&255;i=(j&1|0)!=0;if(i){f=c[2410667]|0;e=f&65535;g=c[9699632+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){k=c[3528598]|0;if((k|0)==0){l=0;m=e;break}h=gj[k&4095](e)|0;l=h;m=b[4821334]|0}else{l=a[g+(f&255)|0]|0;m=e}}while(0);a[9642680]=l;b[4821334]=m+1&65535;c[2439268]=(c[2439268]|0)-1}if((j&2|0)!=0){m=c[2410667]|0;l=m&65535;e=c[9699632+((m>>>8&255)<<2)>>2]|0;do{if((e|0)==0){f=c[3528598]|0;if((f|0)==0){n=0;o=l;break}g=gj[f&4095](l)|0;n=g;o=b[4821334]|0}else{n=a[e+(m&255)|0]|0;o=l}}while(0);a[9642657]=n;b[4821334]=o+1&65535;c[2439268]=(c[2439268]|0)-1}if((j&4|0)!=0){o=c[2410667]|0;n=o&65535;l=c[9699632+((o>>>8&255)<<2)>>2]|0;do{if((l|0)==0){m=c[3528598]|0;if((m|0)==0){p=0;q=n;break}e=gj[m&4095](n)|0;p=e;q=b[4821334]|0}else{p=a[l+(o&255)|0]|0;q=n}}while(0);a[9642656]=p;b[4821334]=q+1&65535;c[2439268]=(c[2439268]|0)-1}if((j&8|0)!=0){q=c[2410667]|0;p=q&65535;n=c[9699632+((q>>>8&255)<<2)>>2]|0;do{if((n|0)==0){o=c[3528598]|0;if((o|0)==0){r=0;s=p;break}l=gj[o&4095](p)|0;r=l;s=b[4821334]|0}else{r=a[n+(q&255)|0]|0;s=p}}while(0);a[9642661]=r;b[4821334]=s+1&65535;c[2439268]=(c[2439268]|0)-1}if((j&16|0)!=0){s=c[2410667]|0;r=s&65535;p=c[9699632+((s>>>8&255)<<2)>>2]|0;do{if((p|0)==0){q=c[3528598]|0;if((q|0)==0){t=0;u=r;break}n=gj[q&4095](r)|0;t=n;u=b[4821334]|0}else{t=a[p+(s&255)|0]|0;u=r}}while(0);r=(t&255)<<8;c[2410668]=r;b[4821334]=u+1&65535;u=c[2410667]|0;t=u&65535;s=c[9699632+((u>>>8&255)<<2)>>2]|0;do{if((s|0)==0){p=c[3528598]|0;if((p|0)==0){v=0;w=r;x=t;break}n=gj[p&4095](t)|0;v=n;w=c[2410668]|0;x=b[4821334]|0}else{v=a[s+(u&255)|0]|0;w=r;x=t}}while(0);c[2410668]=w|v&255;b[4821334]=x+1&65535;c[2439268]=(c[2439268]|0)-2}if((j&32|0)!=0){x=c[2410667]|0;v=x&65535;w=c[9699632+((x>>>8&255)<<2)>>2]|0;do{if((w|0)==0){t=c[3528598]|0;if((t|0)==0){y=0;z=v;break}r=gj[t&4095](v)|0;y=r;z=b[4821334]|0}else{y=a[w+(x&255)|0]|0;z=v}}while(0);v=(y&255)<<8;c[2410669]=v;b[4821334]=z+1&65535;z=c[2410667]|0;y=z&65535;x=c[9699632+((z>>>8&255)<<2)>>2]|0;do{if((x|0)==0){w=c[3528598]|0;if((w|0)==0){A=0;B=v;C=y;break}r=gj[w&4095](y)|0;A=r;B=c[2410669]|0;C=b[4821334]|0}else{A=a[x+(z&255)|0]|0;B=v;C=y}}while(0);c[2410669]=B|A&255;b[4821334]=C+1&65535;c[2439268]=(c[2439268]|0)-2}if((j&64|0)!=0){C=c[2410667]|0;A=C&65535;B=c[9699632+((C>>>8&255)<<2)>>2]|0;do{if((B|0)==0){y=c[3528598]|0;if((y|0)==0){D=0;E=A;break}v=gj[y&4095](A)|0;D=v;E=b[4821334]|0}else{D=a[B+(C&255)|0]|0;E=A}}while(0);A=(D&255)<<8;c[2410666]=A;b[4821334]=E+1&65535;E=c[2410667]|0;D=E&65535;C=c[9699632+((E>>>8&255)<<2)>>2]|0;do{if((C|0)==0){B=c[3528598]|0;if((B|0)==0){F=0;G=A;H=D;break}v=gj[B&4095](D)|0;F=v;G=c[2410666]|0;H=b[4821334]|0}else{F=a[C+(E&255)|0]|0;G=A;H=D}}while(0);c[2410666]=G|F&255;b[4821334]=H+1&65535;c[2439268]=(c[2439268]|0)-2}if((j&128|0)!=0){j=c[2410667]|0;H=j&65535;F=c[9699632+((j>>>8&255)<<2)>>2]|0;do{if((F|0)==0){G=c[3528598]|0;if((G|0)==0){I=0;J=H;break}D=gj[G&4095](H)|0;I=D;J=b[4821334]|0}else{I=a[F+(j&255)|0]|0;J=H}}while(0);H=(I&255)<<8;c[2410662]=H;b[4821334]=J+1&65535;J=c[2410667]|0;I=J&65535;j=c[9699632+((J>>>8&255)<<2)>>2]|0;do{if((j|0)==0){F=c[3528598]|0;if((F|0)==0){K=0;L=H;M=I;break}D=gj[F&4095](I)|0;K=D;L=c[2410662]|0;M=b[4821334]|0}else{K=a[j+(J&255)|0]|0;L=H;M=I}}while(0);I=L|K&255;c[2410662]=I;b[4821334]=M+1&65535;b[4821324]=I&65535;c[2439268]=(c[2439268]|0)-2}if(!i){return}i=a[9642682]|0;I=a[9642683]|0;if((I|i)<<24>>24!=0){a[9642688]=a[9642688]&-17}do{if(I<<24>>24!=0){M=a[9642680]|0;if((M&64)!=0){break}K=a[9642688]|0;if((K&8)==0){a[9642680]=M&127;b[4821334]=(b[4821334]|0)-1&65535;L=c[2410667]|0;H=L&65535;J=a[9642648]|0;j=c[9700656+((L>>>8&255)<<2)>>2]|0;do{if((j|0)==0){D=c[2444172]|0;if((D|0)==0){break}gg[D&4095](H,J)}else{a[j+(L&255)|0]=J}}while(0);b[4821334]=(b[4821334]|0)-1&65535;J=c[2410667]|0;L=J&65535;j=a[9642649]|0;H=c[9700656+((J>>>8&255)<<2)>>2]|0;do{if((H|0)==0){D=c[2444172]|0;if((D|0)==0){break}gg[D&4095](L,j)}else{a[H+(J&255)|0]=j}}while(0);b[4821334]=(b[4821334]|0)-1&65535;j=c[2410667]|0;J=j&65535;H=a[9642680]|0;L=c[9700656+((j>>>8&255)<<2)>>2]|0;do{if((L|0)==0){D=c[2444172]|0;if((D|0)==0){break}gg[D&4095](J,H)}else{a[L+(j&255)|0]=H}}while(0);N=(c[2410671]|0)+10|0;O=a[9642680]|0}else{a[9642688]=K&-9;N=(c[2410671]|0)+7|0;O=M}c[2410671]=N;a[9642680]=O|80;H=c[2425163]|0;do{if((H|0)==0){j=c[3528598]|0;if((j|0)==0){P=0;Q=0;break}L=gj[j&4095](-10)|0;j=c[2425163]|0;J=(L&255)<<8;if((j|0)!=0){R=j;S=J;T=15519;break}j=c[3528598]|0;if((j|0)==0){P=0;Q=J;break}P=gj[j&4095](-9)|0;Q=J}else{R=H;S=(d[H+246|0]|0)<<8;T=15519}}while(0);if((T|0)==15519){P=a[R+247|0]|0;Q=S}c[2410662]=P&255|Q;H=c[2410674]|0;gj[H&4095](1)|0;return}}while(0);if(i<<24>>24==0){return}i=a[9642680]|0;if((i&16)!=0){return}Q=a[9642688]|0;if((Q&8)==0){a[9642680]=i|-128;b[4821334]=(b[4821334]|0)-1&65535;P=c[2410667]|0;S=P&65535;R=a[9642648]|0;O=c[9700656+((P>>>8&255)<<2)>>2]|0;do{if((O|0)==0){N=c[2444172]|0;if((N|0)==0){break}gg[N&4095](S,R)}else{a[O+(P&255)|0]=R}}while(0);b[4821334]=(b[4821334]|0)-1&65535;R=c[2410667]|0;P=R&65535;O=a[9642649]|0;S=c[9700656+((R>>>8&255)<<2)>>2]|0;do{if((S|0)==0){N=c[2444172]|0;if((N|0)==0){break}gg[N&4095](P,O)}else{a[S+(R&255)|0]=O}}while(0);b[4821334]=(b[4821334]|0)-1&65535;O=c[2410667]|0;R=O&65535;S=a[9642664]|0;P=c[9700656+((O>>>8&255)<<2)>>2]|0;do{if((P|0)==0){N=c[2444172]|0;if((N|0)==0){break}gg[N&4095](R,S)}else{a[P+(O&255)|0]=S}}while(0);b[4821334]=(b[4821334]|0)-1&65535;S=c[2410667]|0;O=S&65535;P=a[9642665]|0;R=c[9700656+((S>>>8&255)<<2)>>2]|0;do{if((R|0)==0){N=c[2444172]|0;if((N|0)==0){break}gg[N&4095](O,P)}else{a[R+(S&255)|0]=P}}while(0);b[4821334]=(b[4821334]|0)-1&65535;P=c[2410667]|0;S=P&65535;R=a[9642676]|0;O=c[9700656+((P>>>8&255)<<2)>>2]|0;do{if((O|0)==0){N=c[2444172]|0;if((N|0)==0){break}gg[N&4095](S,R)}else{a[O+(P&255)|0]=R}}while(0);b[4821334]=(b[4821334]|0)-1&65535;R=c[2410667]|0;P=R&65535;O=a[9642677]|0;S=c[9700656+((R>>>8&255)<<2)>>2]|0;do{if((S|0)==0){N=c[2444172]|0;if((N|0)==0){break}gg[N&4095](P,O)}else{a[S+(R&255)|0]=O}}while(0);b[4821334]=(b[4821334]|0)-1&65535;O=c[2410667]|0;R=O&65535;S=a[9642672]|0;P=c[9700656+((O>>>8&255)<<2)>>2]|0;do{if((P|0)==0){N=c[2444172]|0;if((N|0)==0){break}gg[N&4095](R,S)}else{a[P+(O&255)|0]=S}}while(0);b[4821334]=(b[4821334]|0)-1&65535;S=c[2410667]|0;O=S&65535;P=a[9642673]|0;R=c[9700656+((S>>>8&255)<<2)>>2]|0;do{if((R|0)==0){N=c[2444172]|0;if((N|0)==0){break}gg[N&4095](O,P)}else{a[R+(S&255)|0]=P}}while(0);b[4821334]=(b[4821334]|0)-1&65535;P=c[2410667]|0;S=P&65535;R=a[9642661]|0;O=c[9700656+((P>>>8&255)<<2)>>2]|0;do{if((O|0)==0){N=c[2444172]|0;if((N|0)==0){break}gg[N&4095](S,R)}else{a[O+(P&255)|0]=R}}while(0);b[4821334]=(b[4821334]|0)-1&65535;R=c[2410667]|0;P=R&65535;O=a[9642656]|0;S=c[9700656+((R>>>8&255)<<2)>>2]|0;do{if((S|0)==0){N=c[2444172]|0;if((N|0)==0){break}gg[N&4095](P,O)}else{a[S+(R&255)|0]=O}}while(0);b[4821334]=(b[4821334]|0)-1&65535;O=c[2410667]|0;R=O&65535;S=a[9642657]|0;P=c[9700656+((O>>>8&255)<<2)>>2]|0;do{if((P|0)==0){N=c[2444172]|0;if((N|0)==0){break}gg[N&4095](R,S)}else{a[P+(O&255)|0]=S}}while(0);b[4821334]=(b[4821334]|0)-1&65535;S=c[2410667]|0;O=S&65535;P=a[9642680]|0;R=c[9700656+((S>>>8&255)<<2)>>2]|0;do{if((R|0)==0){N=c[2444172]|0;if((N|0)==0){break}gg[N&4095](O,P)}else{a[R+(S&255)|0]=P}}while(0);U=(c[2410671]|0)+19|0;V=a[9642680]|0}else{a[9642688]=Q&-9;U=(c[2410671]|0)+7|0;V=i}c[2410671]=U;a[9642680]=V|16;V=c[2425163]|0;do{if((V|0)==0){U=c[3528598]|0;if((U|0)==0){W=0;X=0;break}i=gj[U&4095](-8)|0;U=c[2425163]|0;Q=(i&255)<<8;if((U|0)!=0){Y=U;Z=Q;T=15580;break}U=c[3528598]|0;if((U|0)==0){W=0;X=Q;break}W=gj[U&4095](-7)|0;X=Q}else{Y=V;Z=(d[V+248|0]|0)<<8;T=15580}}while(0);if((T|0)==15580){W=a[Y+249|0]|0;X=Z}c[2410662]=W&255|X;gj[c[2410674]&4095](0)|0;return}function fNN(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;e=c[2410662]|0;f=e&65535;g=c[9701680+((e>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[3528598]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](f)|0;i=k;j=b[4821324]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);b[4821324]=j+1&65535;j=i&255;i=(j&1|0)!=0;if(i){f=c[2410666]|0;e=f&65535;g=c[9699632+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){k=c[3528598]|0;if((k|0)==0){l=0;m=e;break}h=gj[k&4095](e)|0;l=h;m=b[4821332]|0}else{l=a[g+(f&255)|0]|0;m=e}}while(0);a[9642680]=l;b[4821332]=m+1&65535;c[2439268]=(c[2439268]|0)-1}if((j&2|0)!=0){m=c[2410666]|0;l=m&65535;e=c[9699632+((m>>>8&255)<<2)>>2]|0;do{if((e|0)==0){f=c[3528598]|0;if((f|0)==0){n=0;o=l;break}g=gj[f&4095](l)|0;n=g;o=b[4821332]|0}else{n=a[e+(m&255)|0]|0;o=l}}while(0);a[9642657]=n;b[4821332]=o+1&65535;c[2439268]=(c[2439268]|0)-1}if((j&4|0)!=0){o=c[2410666]|0;n=o&65535;l=c[9699632+((o>>>8&255)<<2)>>2]|0;do{if((l|0)==0){m=c[3528598]|0;if((m|0)==0){p=0;q=n;break}e=gj[m&4095](n)|0;p=e;q=b[4821332]|0}else{p=a[l+(o&255)|0]|0;q=n}}while(0);a[9642656]=p;b[4821332]=q+1&65535;c[2439268]=(c[2439268]|0)-1}if((j&8|0)!=0){q=c[2410666]|0;p=q&65535;n=c[9699632+((q>>>8&255)<<2)>>2]|0;do{if((n|0)==0){o=c[3528598]|0;if((o|0)==0){r=0;s=p;break}l=gj[o&4095](p)|0;r=l;s=b[4821332]|0}else{r=a[n+(q&255)|0]|0;s=p}}while(0);a[9642661]=r;b[4821332]=s+1&65535;c[2439268]=(c[2439268]|0)-1}if((j&16|0)!=0){s=c[2410666]|0;r=s&65535;p=c[9699632+((s>>>8&255)<<2)>>2]|0;do{if((p|0)==0){q=c[3528598]|0;if((q|0)==0){t=0;u=r;break}n=gj[q&4095](r)|0;t=n;u=b[4821332]|0}else{t=a[p+(s&255)|0]|0;u=r}}while(0);r=(t&255)<<8;c[2410668]=r;b[4821332]=u+1&65535;u=c[2410666]|0;t=u&65535;s=c[9699632+((u>>>8&255)<<2)>>2]|0;do{if((s|0)==0){p=c[3528598]|0;if((p|0)==0){v=0;w=r;x=t;break}n=gj[p&4095](t)|0;v=n;w=c[2410668]|0;x=b[4821332]|0}else{v=a[s+(u&255)|0]|0;w=r;x=t}}while(0);c[2410668]=w|v&255;b[4821332]=x+1&65535;c[2439268]=(c[2439268]|0)-2}if((j&32|0)!=0){x=c[2410666]|0;v=x&65535;w=c[9699632+((x>>>8&255)<<2)>>2]|0;do{if((w|0)==0){t=c[3528598]|0;if((t|0)==0){y=0;z=v;break}r=gj[t&4095](v)|0;y=r;z=b[4821332]|0}else{y=a[w+(x&255)|0]|0;z=v}}while(0);v=(y&255)<<8;c[2410669]=v;b[4821332]=z+1&65535;z=c[2410666]|0;y=z&65535;x=c[9699632+((z>>>8&255)<<2)>>2]|0;do{if((x|0)==0){w=c[3528598]|0;if((w|0)==0){A=0;B=v;C=y;break}r=gj[w&4095](y)|0;A=r;B=c[2410669]|0;C=b[4821332]|0}else{A=a[x+(z&255)|0]|0;B=v;C=y}}while(0);c[2410669]=B|A&255;b[4821332]=C+1&65535;c[2439268]=(c[2439268]|0)-2}if((j&64|0)!=0){C=c[2410666]|0;A=C&65535;B=c[9699632+((C>>>8&255)<<2)>>2]|0;do{if((B|0)==0){y=c[3528598]|0;if((y|0)==0){D=0;E=A;break}v=gj[y&4095](A)|0;D=v;E=b[4821332]|0}else{D=a[B+(C&255)|0]|0;E=A}}while(0);A=(D&255)<<8;c[2410667]=A;b[4821332]=E+1&65535;E=c[2410666]|0;D=E&65535;C=c[9699632+((E>>>8&255)<<2)>>2]|0;do{if((C|0)==0){B=c[3528598]|0;if((B|0)==0){F=0;G=A;H=D;break}v=gj[B&4095](D)|0;F=v;G=c[2410667]|0;H=b[4821332]|0}else{F=a[C+(E&255)|0]|0;G=A;H=D}}while(0);c[2410667]=G|F&255;b[4821332]=H+1&65535;c[2439268]=(c[2439268]|0)-2}if((j&128|0)!=0){j=c[2410666]|0;H=j&65535;F=c[9699632+((j>>>8&255)<<2)>>2]|0;do{if((F|0)==0){G=c[3528598]|0;if((G|0)==0){I=0;J=H;break}D=gj[G&4095](H)|0;I=D;J=b[4821332]|0}else{I=a[F+(j&255)|0]|0;J=H}}while(0);H=(I&255)<<8;c[2410662]=H;b[4821332]=J+1&65535;J=c[2410666]|0;I=J&65535;j=c[9699632+((J>>>8&255)<<2)>>2]|0;do{if((j|0)==0){F=c[3528598]|0;if((F|0)==0){K=0;L=H;M=I;break}D=gj[F&4095](I)|0;K=D;L=c[2410662]|0;M=b[4821332]|0}else{K=a[j+(J&255)|0]|0;L=H;M=I}}while(0);I=L|K&255;c[2410662]=I;b[4821332]=M+1&65535;b[4821324]=I&65535;c[2439268]=(c[2439268]|0)-2}if(!i){return}i=a[9642682]|0;I=a[9642683]|0;if((I|i)<<24>>24!=0){a[9642688]=a[9642688]&-17}do{if(I<<24>>24!=0){M=a[9642680]|0;if((M&64)!=0){break}K=a[9642688]|0;if((K&8)==0){a[9642680]=M&127;b[4821334]=(b[4821334]|0)-1&65535;L=c[2410667]|0;H=L&65535;J=a[9642648]|0;j=c[9700656+((L>>>8&255)<<2)>>2]|0;do{if((j|0)==0){D=c[2444172]|0;if((D|0)==0){break}gg[D&4095](H,J)}else{a[j+(L&255)|0]=J}}while(0);b[4821334]=(b[4821334]|0)-1&65535;J=c[2410667]|0;L=J&65535;j=a[9642649]|0;H=c[9700656+((J>>>8&255)<<2)>>2]|0;do{if((H|0)==0){D=c[2444172]|0;if((D|0)==0){break}gg[D&4095](L,j)}else{a[H+(J&255)|0]=j}}while(0);b[4821334]=(b[4821334]|0)-1&65535;j=c[2410667]|0;J=j&65535;H=a[9642680]|0;L=c[9700656+((j>>>8&255)<<2)>>2]|0;do{if((L|0)==0){D=c[2444172]|0;if((D|0)==0){break}gg[D&4095](J,H)}else{a[L+(j&255)|0]=H}}while(0);N=(c[2410671]|0)+10|0;O=a[9642680]|0}else{a[9642688]=K&-9;N=(c[2410671]|0)+7|0;O=M}c[2410671]=N;a[9642680]=O|80;H=c[2425163]|0;do{if((H|0)==0){j=c[3528598]|0;if((j|0)==0){P=0;Q=0;break}L=gj[j&4095](-10)|0;j=c[2425163]|0;J=(L&255)<<8;if((j|0)!=0){R=j;S=J;T=15682;break}j=c[3528598]|0;if((j|0)==0){P=0;Q=J;break}P=gj[j&4095](-9)|0;Q=J}else{R=H;S=(d[H+246|0]|0)<<8;T=15682}}while(0);if((T|0)==15682){P=a[R+247|0]|0;Q=S}c[2410662]=P&255|Q;H=c[2410674]|0;gj[H&4095](1)|0;return}}while(0);if(i<<24>>24==0){return}i=a[9642680]|0;if((i&16)!=0){return}Q=a[9642688]|0;if((Q&8)==0){a[9642680]=i|-128;b[4821334]=(b[4821334]|0)-1&65535;P=c[2410667]|0;S=P&65535;R=a[9642648]|0;O=c[9700656+((P>>>8&255)<<2)>>2]|0;do{if((O|0)==0){N=c[2444172]|0;if((N|0)==0){break}gg[N&4095](S,R)}else{a[O+(P&255)|0]=R}}while(0);b[4821334]=(b[4821334]|0)-1&65535;R=c[2410667]|0;P=R&65535;O=a[9642649]|0;S=c[9700656+((R>>>8&255)<<2)>>2]|0;do{if((S|0)==0){N=c[2444172]|0;if((N|0)==0){break}gg[N&4095](P,O)}else{a[S+(R&255)|0]=O}}while(0);b[4821334]=(b[4821334]|0)-1&65535;O=c[2410667]|0;R=O&65535;S=a[9642664]|0;P=c[9700656+((O>>>8&255)<<2)>>2]|0;do{if((P|0)==0){N=c[2444172]|0;if((N|0)==0){break}gg[N&4095](R,S)}else{a[P+(O&255)|0]=S}}while(0);b[4821334]=(b[4821334]|0)-1&65535;S=c[2410667]|0;O=S&65535;P=a[9642665]|0;R=c[9700656+((S>>>8&255)<<2)>>2]|0;do{if((R|0)==0){N=c[2444172]|0;if((N|0)==0){break}gg[N&4095](O,P)}else{a[R+(S&255)|0]=P}}while(0);b[4821334]=(b[4821334]|0)-1&65535;P=c[2410667]|0;S=P&65535;R=a[9642676]|0;O=c[9700656+((P>>>8&255)<<2)>>2]|0;do{if((O|0)==0){N=c[2444172]|0;if((N|0)==0){break}gg[N&4095](S,R)}else{a[O+(P&255)|0]=R}}while(0);b[4821334]=(b[4821334]|0)-1&65535;R=c[2410667]|0;P=R&65535;O=a[9642677]|0;S=c[9700656+((R>>>8&255)<<2)>>2]|0;do{if((S|0)==0){N=c[2444172]|0;if((N|0)==0){break}gg[N&4095](P,O)}else{a[S+(R&255)|0]=O}}while(0);b[4821334]=(b[4821334]|0)-1&65535;O=c[2410667]|0;R=O&65535;S=a[9642672]|0;P=c[9700656+((O>>>8&255)<<2)>>2]|0;do{if((P|0)==0){N=c[2444172]|0;if((N|0)==0){break}gg[N&4095](R,S)}else{a[P+(O&255)|0]=S}}while(0);b[4821334]=(b[4821334]|0)-1&65535;S=c[2410667]|0;O=S&65535;P=a[9642673]|0;R=c[9700656+((S>>>8&255)<<2)>>2]|0;do{if((R|0)==0){N=c[2444172]|0;if((N|0)==0){break}gg[N&4095](O,P)}else{a[R+(S&255)|0]=P}}while(0);b[4821334]=(b[4821334]|0)-1&65535;P=c[2410667]|0;S=P&65535;R=a[9642661]|0;O=c[9700656+((P>>>8&255)<<2)>>2]|0;do{if((O|0)==0){N=c[2444172]|0;if((N|0)==0){break}gg[N&4095](S,R)}else{a[O+(P&255)|0]=R}}while(0);b[4821334]=(b[4821334]|0)-1&65535;R=c[2410667]|0;P=R&65535;O=a[9642656]|0;S=c[9700656+((R>>>8&255)<<2)>>2]|0;do{if((S|0)==0){N=c[2444172]|0;if((N|0)==0){break}gg[N&4095](P,O)}else{a[S+(R&255)|0]=O}}while(0);b[4821334]=(b[4821334]|0)-1&65535;O=c[2410667]|0;R=O&65535;S=a[9642657]|0;P=c[9700656+((O>>>8&255)<<2)>>2]|0;do{if((P|0)==0){N=c[2444172]|0;if((N|0)==0){break}gg[N&4095](R,S)}else{a[P+(O&255)|0]=S}}while(0);b[4821334]=(b[4821334]|0)-1&65535;S=c[2410667]|0;O=S&65535;P=a[9642680]|0;R=c[9700656+((S>>>8&255)<<2)>>2]|0;do{if((R|0)==0){N=c[2444172]|0;if((N|0)==0){break}gg[N&4095](O,P)}else{a[R+(S&255)|0]=P}}while(0);U=(c[2410671]|0)+19|0;V=a[9642680]|0}else{a[9642688]=Q&-9;U=(c[2410671]|0)+7|0;V=i}c[2410671]=U;a[9642680]=V|16;V=c[2425163]|0;do{if((V|0)==0){U=c[3528598]|0;if((U|0)==0){W=0;X=0;break}i=gj[U&4095](-8)|0;U=c[2425163]|0;Q=(i&255)<<8;if((U|0)!=0){Y=U;Z=Q;T=15743;break}U=c[3528598]|0;if((U|0)==0){W=0;X=Q;break}W=gj[U&4095](-7)|0;X=Q}else{Y=V;Z=(d[V+248|0]|0)<<8;T=15743}}while(0);if((T|0)==15743){W=a[Y+249|0]|0;X=Z}c[2410662]=W&255|X;gj[c[2410674]&4095](0)|0;return}function fNO(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9642657]=h;b[4821324]=i+1&65535;i=a[9642680]&-15|(h&255)>>>4&8;a[9642680]=h<<24>>24==0?i|4:i;return}function fNP(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9642656]=h;b[4821324]=i+1&65535;i=a[9642680]&-15|(h&255)>>>4&8;a[9642680]=h<<24>>24==0?i|4:i;return}function fNQ(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);b[4821324]=i+1&65535;i=a[9642657]|0;e=(i&255)+(h&255)|0;d=(e>>>4&8|a[9642680]&-48&255)&255;f=e&255;j=(i^h)&255^e;a[9642680]=(j<<1&32|e>>>8&1|(j^e>>>1)>>>6&2|(f<<24>>24==0?d|4:d)&255)&255;a[9642657]=f;return}function fNR(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);b[4821324]=i+1&65535;i=a[9642656]|0;e=(i&255)+(h&255)|0;d=(e>>>4&8|a[9642680]&-48&255)&255;f=e&255;j=(i^h)&255^e;a[9642680]=(j<<1&32|e>>>8&1|(j^e>>>1)>>>6&2|(f<<24>>24==0?d|4:d)&255)&255;a[9642656]=f;return}function fNS(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);b[4821324]=i+1&65535;i=a[9642657]|0;e=a[9642680]|0;d=(i&255)+(h&255)+(e&1)|0;f=(d>>>4&8|e&-48&255)&255;e=d&255;j=d^(i^h)&255;a[9642680]=(j<<1&32|d>>>8&1|(j^d>>>1)>>>6&2|(e<<24>>24==0?f|4:f)&255)&255;a[9642657]=e;return}function fNT(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);b[4821324]=i+1&65535;i=a[9642656]|0;e=a[9642680]|0;d=(i&255)+(h&255)+(e&1)|0;f=(d>>>4&8|e&-48&255)&255;e=d&255;j=d^(i^h)&255;a[9642680]=(j<<1&32|d>>>8&1|(j^d>>>1)>>>6&2|(e<<24>>24==0?f|4:f)&255)&255;a[9642656]=e;return}function fNU(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);b[4821324]=i+1&65535;i=a[9642657]|0;e=(i&255)-(h&255)|0;d=(e>>>4&8|a[9642680]&-16&255)&255;f=e&255;a[9642680]=(((i^h)&255^e^e>>>1)>>>6&2|e>>>8&1|(f<<24>>24==0?d|4:d)&255)&255;a[9642657]=f;return}function fNV(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);b[4821324]=i+1&65535;i=a[9642656]|0;e=(i&255)-(h&255)|0;d=(e>>>4&8|a[9642680]&-16&255)&255;f=e&255;a[9642680]=(((i^h)&255^e^e>>>1)>>>6&2|e>>>8&1|(f<<24>>24==0?d|4:d)&255)&255;a[9642656]=f;return}function fNW(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);b[4821324]=i+1&65535;i=a[9642657]|0;e=a[9642680]|0;d=(i&255)-(h&255)-(e&1)|0;f=(d>>>4&8|e&-16&255)&255;e=d&255;a[9642680]=((d^(i^h)&255^d>>>1)>>>6&2|d>>>8&1|(e<<24>>24==0?f|4:f)&255)&255;a[9642657]=e;return}function fNX(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);b[4821324]=i+1&65535;i=a[9642656]|0;e=a[9642680]|0;d=(i&255)-(h&255)-(e&1)|0;f=(d>>>4&8|e&-16&255)&255;e=d&255;a[9642680]=((d^(i^h)&255^d>>>1)>>>6&2|d>>>8&1|(e<<24>>24==0?f|4:f)&255)&255;a[9642656]=e;return}function fNY(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);b[4821324]=i+1&65535;i=a[9642657]&h;a[9642657]=i;h=(i&255)>>>4&8|a[9642680]&-15;a[9642680]=i<<24>>24==0?h|4:h;return}function fNZ(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);b[4821324]=i+1&65535;i=a[9642656]&h;a[9642656]=i;h=(i&255)>>>4&8|a[9642680]&-15;a[9642680]=i<<24>>24==0?h|4:h;return}function fN_(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);b[4821324]=i+1&65535;i=a[9642657]&h;h=(i&255)>>>4&8|a[9642680]&-15;a[9642680]=i<<24>>24==0?h|4:h;return}function fN$(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);b[4821324]=i+1&65535;i=a[9642656]&h;h=(i&255)>>>4&8|a[9642680]&-15;a[9642680]=i<<24>>24==0?h|4:h;return}function fN0(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);b[4821324]=i+1&65535;i=a[9642657]|0;e=i^h;a[9642657]=e;d=(e&255)>>>4&8|a[9642680]&-15;a[9642680]=i<<24>>24==h<<24>>24?d|4:d;return}function fN1(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);b[4821324]=i+1&65535;i=a[9642656]|0;e=i^h;a[9642656]=e;d=(e&255)>>>4&8|a[9642680]&-15;a[9642680]=i<<24>>24==h<<24>>24?d|4:d;return}function fN2(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);b[4821324]=i+1&65535;i=a[9642657]|h;a[9642657]=i;h=(i&255)>>>4&8|a[9642680]&-15;a[9642680]=i<<24>>24==0?h|4:h;return}function fN3(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);b[4821324]=i+1&65535;i=a[9642656]|h;a[9642656]=i;h=(i&255)>>>4&8|a[9642680]&-15;a[9642680]=i<<24>>24==0?h|4:h;return}function fN4(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);b[4821324]=i+1&65535;i=a[9642657]|0;e=(i&255)-(h&255)|0;d=(e>>>4&8|a[9642680]&-16&255)&255;a[9642680]=(((i^h)&255^e^e>>>1)>>>6&2|e>>>8&1|((e&255)<<24>>24==0?d|4:d)&255)&255;return}function fN5(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);b[4821324]=i+1&65535;i=a[9642656]|0;e=(i&255)-(h&255)|0;d=(e>>>4&8|a[9642680]&-16&255)&255;a[9642680]=(((i^h)&255^e^e>>>1)>>>6&2|e>>>8&1|((e&255)<<24>>24==0?d|4:d)&255)&255;return}function fN6(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);b[4821324]=i+1&65535;i=c[2410675]|0;if((i|0)==0){return}gf[i&2047](h&255);return}function fN7(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;e=c[2410662]|0;f=e&65535;g=c[9701680+((e>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[3528598]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](f)|0;i=k;j=b[4821324]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);f=j+1&65535;b[4821324]=f;j=a[9642680]&i;a[9642680]=j;i=a[9642682]|0;e=a[9642683]|0;g=f&255;if((e|i)<<24>>24!=0){a[9642688]=a[9642688]&-17}do{if(e<<24>>24!=0){if((j&64)!=0){break}f=a[9642688]|0;if((f&8)==0){a[9642680]=j&127;b[4821334]=(b[4821334]|0)-1&65535;k=c[2410667]|0;h=k&65535;l=c[9700656+((k>>>8&255)<<2)>>2]|0;do{if((l|0)==0){m=c[2444172]|0;if((m|0)==0){break}gg[m&4095](h,g)}else{a[l+(k&255)|0]=g}}while(0);b[4821334]=(b[4821334]|0)-1&65535;k=c[2410667]|0;l=k&65535;h=a[9642649]|0;m=c[9700656+((k>>>8&255)<<2)>>2]|0;do{if((m|0)==0){n=c[2444172]|0;if((n|0)==0){break}gg[n&4095](l,h)}else{a[m+(k&255)|0]=h}}while(0);b[4821334]=(b[4821334]|0)-1&65535;h=c[2410667]|0;k=h&65535;m=a[9642680]|0;l=c[9700656+((h>>>8&255)<<2)>>2]|0;do{if((l|0)==0){n=c[2444172]|0;if((n|0)==0){break}gg[n&4095](k,m)}else{a[l+(h&255)|0]=m}}while(0);o=(c[2410671]|0)+10|0;p=a[9642680]|0}else{a[9642688]=f&-9;o=(c[2410671]|0)+7|0;p=j}c[2410671]=o;a[9642680]=p|80;m=c[2425163]|0;do{if((m|0)==0){h=c[3528598]|0;if((h|0)==0){q=0;r=0;break}l=gj[h&4095](-10)|0;h=c[2425163]|0;k=(l&255)<<8;if((h|0)!=0){s=h;t=k;u=15889;break}h=c[3528598]|0;if((h|0)==0){q=0;r=k;break}q=gj[h&4095](-9)|0;r=k}else{s=m;t=(d[m+246|0]|0)<<8;u=15889}}while(0);if((u|0)==15889){q=a[s+247|0]|0;r=t}c[2410662]=q&255|r;m=c[2410674]|0;gj[m&4095](1)|0;return}}while(0);if(i<<24>>24==0){return}if((j&16)!=0){return}i=a[9642688]|0;if((i&8)==0){a[9642680]=j|-128;b[4821334]=(b[4821334]|0)-1&65535;r=c[2410667]|0;q=r&65535;t=c[9700656+((r>>>8&255)<<2)>>2]|0;do{if((t|0)==0){s=c[2444172]|0;if((s|0)==0){break}gg[s&4095](q,g)}else{a[t+(r&255)|0]=g}}while(0);b[4821334]=(b[4821334]|0)-1&65535;g=c[2410667]|0;r=g&65535;t=a[9642649]|0;q=c[9700656+((g>>>8&255)<<2)>>2]|0;do{if((q|0)==0){s=c[2444172]|0;if((s|0)==0){break}gg[s&4095](r,t)}else{a[q+(g&255)|0]=t}}while(0);b[4821334]=(b[4821334]|0)-1&65535;t=c[2410667]|0;g=t&65535;q=a[9642664]|0;r=c[9700656+((t>>>8&255)<<2)>>2]|0;do{if((r|0)==0){s=c[2444172]|0;if((s|0)==0){break}gg[s&4095](g,q)}else{a[r+(t&255)|0]=q}}while(0);b[4821334]=(b[4821334]|0)-1&65535;q=c[2410667]|0;t=q&65535;r=a[9642665]|0;g=c[9700656+((q>>>8&255)<<2)>>2]|0;do{if((g|0)==0){s=c[2444172]|0;if((s|0)==0){break}gg[s&4095](t,r)}else{a[g+(q&255)|0]=r}}while(0);b[4821334]=(b[4821334]|0)-1&65535;r=c[2410667]|0;q=r&65535;g=a[9642676]|0;t=c[9700656+((r>>>8&255)<<2)>>2]|0;do{if((t|0)==0){s=c[2444172]|0;if((s|0)==0){break}gg[s&4095](q,g)}else{a[t+(r&255)|0]=g}}while(0);b[4821334]=(b[4821334]|0)-1&65535;g=c[2410667]|0;r=g&65535;t=a[9642677]|0;q=c[9700656+((g>>>8&255)<<2)>>2]|0;do{if((q|0)==0){s=c[2444172]|0;if((s|0)==0){break}gg[s&4095](r,t)}else{a[q+(g&255)|0]=t}}while(0);b[4821334]=(b[4821334]|0)-1&65535;t=c[2410667]|0;g=t&65535;q=a[9642672]|0;r=c[9700656+((t>>>8&255)<<2)>>2]|0;do{if((r|0)==0){s=c[2444172]|0;if((s|0)==0){break}gg[s&4095](g,q)}else{a[r+(t&255)|0]=q}}while(0);b[4821334]=(b[4821334]|0)-1&65535;q=c[2410667]|0;t=q&65535;r=a[9642673]|0;g=c[9700656+((q>>>8&255)<<2)>>2]|0;do{if((g|0)==0){s=c[2444172]|0;if((s|0)==0){break}gg[s&4095](t,r)}else{a[g+(q&255)|0]=r}}while(0);b[4821334]=(b[4821334]|0)-1&65535;r=c[2410667]|0;q=r&65535;g=a[9642661]|0;t=c[9700656+((r>>>8&255)<<2)>>2]|0;do{if((t|0)==0){s=c[2444172]|0;if((s|0)==0){break}gg[s&4095](q,g)}else{a[t+(r&255)|0]=g}}while(0);b[4821334]=(b[4821334]|0)-1&65535;g=c[2410667]|0;r=g&65535;t=a[9642656]|0;q=c[9700656+((g>>>8&255)<<2)>>2]|0;do{if((q|0)==0){s=c[2444172]|0;if((s|0)==0){break}gg[s&4095](r,t)}else{a[q+(g&255)|0]=t}}while(0);b[4821334]=(b[4821334]|0)-1&65535;t=c[2410667]|0;g=t&65535;q=a[9642657]|0;r=c[9700656+((t>>>8&255)<<2)>>2]|0;do{if((r|0)==0){s=c[2444172]|0;if((s|0)==0){break}gg[s&4095](g,q)}else{a[r+(t&255)|0]=q}}while(0);b[4821334]=(b[4821334]|0)-1&65535;q=c[2410667]|0;t=q&65535;r=a[9642680]|0;g=c[9700656+((q>>>8&255)<<2)>>2]|0;do{if((g|0)==0){s=c[2444172]|0;if((s|0)==0){break}gg[s&4095](t,r)}else{a[g+(q&255)|0]=r}}while(0);v=(c[2410671]|0)+19|0;w=a[9642680]|0}else{a[9642688]=i&-9;v=(c[2410671]|0)+7|0;w=j}c[2410671]=v;a[9642680]=w|16;w=c[2425163]|0;do{if((w|0)==0){v=c[3528598]|0;if((v|0)==0){x=0;y=0;break}j=gj[v&4095](-8)|0;v=c[2425163]|0;i=(j&255)<<8;if((v|0)!=0){z=v;A=i;u=15950;break}v=c[3528598]|0;if((v|0)==0){x=0;y=i;break}x=gj[v&4095](-7)|0;y=i}else{z=w;A=(d[w+248|0]|0)<<8;u=15950}}while(0);if((u|0)==15950){x=a[z+249|0]|0;y=A}c[2410662]=x&255|y;gj[c[2410674]&4095](0)|0;return}function fN8(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;e=c[2410662]|0;f=e&65535;g=c[9701680+((e>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[3528598]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](f)|0;i=k;j=b[4821324]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);f=j+1&65535;b[4821324]=f;j=a[9642680]|i;a[9642680]=j;i=a[9642682]|0;e=a[9642683]|0;g=f&255;if((e|i)<<24>>24!=0){a[9642688]=a[9642688]&-17}do{if(e<<24>>24!=0){if((j&64)!=0){break}f=a[9642688]|0;if((f&8)==0){a[9642680]=j&127;b[4821334]=(b[4821334]|0)-1&65535;k=c[2410667]|0;h=k&65535;l=c[9700656+((k>>>8&255)<<2)>>2]|0;do{if((l|0)==0){m=c[2444172]|0;if((m|0)==0){break}gg[m&4095](h,g)}else{a[l+(k&255)|0]=g}}while(0);b[4821334]=(b[4821334]|0)-1&65535;k=c[2410667]|0;l=k&65535;h=a[9642649]|0;m=c[9700656+((k>>>8&255)<<2)>>2]|0;do{if((m|0)==0){n=c[2444172]|0;if((n|0)==0){break}gg[n&4095](l,h)}else{a[m+(k&255)|0]=h}}while(0);b[4821334]=(b[4821334]|0)-1&65535;h=c[2410667]|0;k=h&65535;m=a[9642680]|0;l=c[9700656+((h>>>8&255)<<2)>>2]|0;do{if((l|0)==0){n=c[2444172]|0;if((n|0)==0){break}gg[n&4095](k,m)}else{a[l+(h&255)|0]=m}}while(0);o=(c[2410671]|0)+10|0;p=a[9642680]|0}else{a[9642688]=f&-9;o=(c[2410671]|0)+7|0;p=j}c[2410671]=o;a[9642680]=p|80;m=c[2425163]|0;do{if((m|0)==0){h=c[3528598]|0;if((h|0)==0){q=0;r=0;break}l=gj[h&4095](-10)|0;h=c[2425163]|0;k=(l&255)<<8;if((h|0)!=0){s=h;t=k;u=15986;break}h=c[3528598]|0;if((h|0)==0){q=0;r=k;break}q=gj[h&4095](-9)|0;r=k}else{s=m;t=(d[m+246|0]|0)<<8;u=15986}}while(0);if((u|0)==15986){q=a[s+247|0]|0;r=t}c[2410662]=q&255|r;m=c[2410674]|0;gj[m&4095](1)|0;return}}while(0);if(i<<24>>24==0){return}if((j&16)!=0){return}i=a[9642688]|0;if((i&8)==0){a[9642680]=j|-128;b[4821334]=(b[4821334]|0)-1&65535;r=c[2410667]|0;q=r&65535;t=c[9700656+((r>>>8&255)<<2)>>2]|0;do{if((t|0)==0){s=c[2444172]|0;if((s|0)==0){break}gg[s&4095](q,g)}else{a[t+(r&255)|0]=g}}while(0);b[4821334]=(b[4821334]|0)-1&65535;g=c[2410667]|0;r=g&65535;t=a[9642649]|0;q=c[9700656+((g>>>8&255)<<2)>>2]|0;do{if((q|0)==0){s=c[2444172]|0;if((s|0)==0){break}gg[s&4095](r,t)}else{a[q+(g&255)|0]=t}}while(0);b[4821334]=(b[4821334]|0)-1&65535;t=c[2410667]|0;g=t&65535;q=a[9642664]|0;r=c[9700656+((t>>>8&255)<<2)>>2]|0;do{if((r|0)==0){s=c[2444172]|0;if((s|0)==0){break}gg[s&4095](g,q)}else{a[r+(t&255)|0]=q}}while(0);b[4821334]=(b[4821334]|0)-1&65535;q=c[2410667]|0;t=q&65535;r=a[9642665]|0;g=c[9700656+((q>>>8&255)<<2)>>2]|0;do{if((g|0)==0){s=c[2444172]|0;if((s|0)==0){break}gg[s&4095](t,r)}else{a[g+(q&255)|0]=r}}while(0);b[4821334]=(b[4821334]|0)-1&65535;r=c[2410667]|0;q=r&65535;g=a[9642676]|0;t=c[9700656+((r>>>8&255)<<2)>>2]|0;do{if((t|0)==0){s=c[2444172]|0;if((s|0)==0){break}gg[s&4095](q,g)}else{a[t+(r&255)|0]=g}}while(0);b[4821334]=(b[4821334]|0)-1&65535;g=c[2410667]|0;r=g&65535;t=a[9642677]|0;q=c[9700656+((g>>>8&255)<<2)>>2]|0;do{if((q|0)==0){s=c[2444172]|0;if((s|0)==0){break}gg[s&4095](r,t)}else{a[q+(g&255)|0]=t}}while(0);b[4821334]=(b[4821334]|0)-1&65535;t=c[2410667]|0;g=t&65535;q=a[9642672]|0;r=c[9700656+((t>>>8&255)<<2)>>2]|0;do{if((r|0)==0){s=c[2444172]|0;if((s|0)==0){break}gg[s&4095](g,q)}else{a[r+(t&255)|0]=q}}while(0);b[4821334]=(b[4821334]|0)-1&65535;q=c[2410667]|0;t=q&65535;r=a[9642673]|0;g=c[9700656+((q>>>8&255)<<2)>>2]|0;do{if((g|0)==0){s=c[2444172]|0;if((s|0)==0){break}gg[s&4095](t,r)}else{a[g+(q&255)|0]=r}}while(0);b[4821334]=(b[4821334]|0)-1&65535;r=c[2410667]|0;q=r&65535;g=a[9642661]|0;t=c[9700656+((r>>>8&255)<<2)>>2]|0;do{if((t|0)==0){s=c[2444172]|0;if((s|0)==0){break}gg[s&4095](q,g)}else{a[t+(r&255)|0]=g}}while(0);b[4821334]=(b[4821334]|0)-1&65535;g=c[2410667]|0;r=g&65535;t=a[9642656]|0;q=c[9700656+((g>>>8&255)<<2)>>2]|0;do{if((q|0)==0){s=c[2444172]|0;if((s|0)==0){break}gg[s&4095](r,t)}else{a[q+(g&255)|0]=t}}while(0);b[4821334]=(b[4821334]|0)-1&65535;t=c[2410667]|0;g=t&65535;q=a[9642657]|0;r=c[9700656+((t>>>8&255)<<2)>>2]|0;do{if((r|0)==0){s=c[2444172]|0;if((s|0)==0){break}gg[s&4095](g,q)}else{a[r+(t&255)|0]=q}}while(0);b[4821334]=(b[4821334]|0)-1&65535;q=c[2410667]|0;t=q&65535;r=a[9642680]|0;g=c[9700656+((q>>>8&255)<<2)>>2]|0;do{if((g|0)==0){s=c[2444172]|0;if((s|0)==0){break}gg[s&4095](t,r)}else{a[g+(q&255)|0]=r}}while(0);v=(c[2410671]|0)+19|0;w=a[9642680]|0}else{a[9642688]=i&-9;v=(c[2410671]|0)+7|0;w=j}c[2410671]=v;a[9642680]=w|16;w=c[2425163]|0;do{if((w|0)==0){v=c[3528598]|0;if((v|0)==0){x=0;y=0;break}j=gj[v&4095](-8)|0;v=c[2425163]|0;i=(j&255)<<8;if((v|0)!=0){z=v;A=i;u=16047;break}v=c[3528598]|0;if((v|0)==0){x=0;y=i;break}x=gj[v&4095](-7)|0;y=i}else{z=w;A=(d[w+248|0]|0)<<8;u=16047}}while(0);if((u|0)==16047){x=a[z+249|0]|0;y=A}c[2410662]=x&255|y;gj[c[2410674]&4095](0)|0;return}function fN9(){var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;g=c[2410662]|0;h=g&65535;j=c[9701680+((g>>>8&255)<<2)>>2]|0;do{if((j|0)==0){k=c[3528598]|0;if((k|0)==0){l=0;m=h;break}n=gj[k&4095](h)|0;l=n;m=b[4821324]|0}else{l=a[j+(g&255)|0]|0;m=h}}while(0);h=m+1&65535;b[4821324]=h;m=l&255;l=m>>>4;switch(l|0){case 3:{o=b[4821338]|0;break};case 0:{o=d[9642657]|0;break};case 2:{o=b[4821336]|0;break};case 4:{o=b[4821334]|0;break};case 1:{o=d[9642656]|0;break};case 5:{o=b[4821332]|0;break};default:{bw(300128,(p=i,i=i+8|0,c[p>>2]=h&65535,p)|0)|0;i=p;o=255}}h=m&15;switch(h|0){case 0:{q=d[9642657]|0;break};case 1:{q=d[9642656]|0;break};case 2:{q=b[4821336]|0;break};case 3:{q=b[4821338]|0;break};case 4:{q=b[4821334]|0;break};case 5:{q=b[4821332]|0;break};default:{bw(300128,(p=i,i=i+8|0,c[p>>2]=e[4821324]|0,p)|0)|0;i=p;q=255}}switch(l|0){case 0:{a[9642657]=q&255;break};case 1:{a[9642656]=q&255;break};case 2:{b[4821336]=q;break};case 3:{b[4821338]=q;break};case 4:{b[4821334]=q;break};case 5:{b[4821332]=q;break};default:{bw(300128,(p=i,i=i+8|0,c[p>>2]=e[4821324]|0,p)|0)|0;i=p}}switch(h|0){case 0:{a[9642657]=o&255;i=f;return};case 1:{a[9642656]=o&255;i=f;return};case 2:{b[4821336]=o;i=f;return};case 3:{b[4821338]=o;i=f;return};case 4:{b[4821334]=o;i=f;return};case 5:{b[4821332]=o;i=f;return};default:{bw(300128,(p=i,i=i+8|0,c[p>>2]=e[4821324]|0,p)|0)|0;i=p;i=f;return}}}function fOa(){var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;g=c[2410662]|0;h=g&65535;j=c[9701680+((g>>>8&255)<<2)>>2]|0;do{if((j|0)==0){k=c[3528598]|0;if((k|0)==0){l=0;m=h;break}n=gj[k&4095](h)|0;l=n;m=b[4821324]|0}else{l=a[j+(g&255)|0]|0;m=h}}while(0);h=m+1&65535;b[4821324]=h;m=l&255;switch(m&15|0){case 5:{o=b[4821332]|0;break};case 2:{o=b[4821336]|0;break};case 3:{o=b[4821338]|0;break};case 1:{o=d[9642656]|0;break};case 0:{o=d[9642657]|0;break};case 4:{o=b[4821334]|0;break};default:{bw(300128,(p=i,i=i+8|0,c[p>>2]=h&65535,p)|0)|0;i=p;o=255}}switch(m>>>4&7|0){case 5:{b[4821332]=o;i=f;return};case 4:{b[4821334]=o;i=f;return};case 2:{b[4821336]=o;i=f;return};case 3:{b[4821338]=o;i=f;return};case 0:{a[9642657]=o&255;i=f;return};case 1:{a[9642656]=o&255;i=f;return};default:{bw(300128,(p=i,i=i+8|0,c[p>>2]=e[4821324]|0,p)|0)|0;i=p;i=f;return}}}function fOb(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=d;j=e;break}k=gj[g&4095](e)|0;g=c[2410662]|0;h=k;i=g;j=g&65535}else{h=a[f+(d&255)|0]|0;i=d;j=e}}while(0);e=h&255;h=e<<8;d=i+1|0;i=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){l=0;m=j;break}k=gj[g&4095](i)|0;l=k;m=b[4821324]|0}else{l=a[f+(d&255)|0]|0;m=j}}while(0);j=l&255|h;c[2410664]=j;b[4821324]=m+2&65535;m=a[9642680]&-15;a[9642680]=m;h=m&255|e>>>4&8;if((j|0)!=0){n=h&255;a[9642680]=n;return}n=(h|4)&255;a[9642680]=n;return}function fOc(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=d;j=e;break}k=gj[g&4095](e)|0;g=c[2410662]|0;h=k;i=g;j=g&65535}else{h=a[f+(d&255)|0]|0;i=d;j=e}}while(0);e=h&255;h=e<<8;d=i+1|0;i=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){l=0;m=j;break}k=gj[g&4095](i)|0;l=k;m=b[4821324]|0}else{l=a[f+(d&255)|0]|0;m=j}}while(0);j=l&255|h;c[2410668]=j;b[4821324]=m+2&65535;m=a[9642680]&-15;a[9642680]=m;h=m&255|e>>>4&8;if((j|0)!=0){n=h&255;a[9642680]=n;return}n=(h|4)&255;a[9642680]=n;return}function fOd(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=d;j=e;break}k=gj[g&4095](e)|0;g=c[2410662]|0;h=k;i=g;j=g&65535}else{h=a[f+(d&255)|0]|0;i=d;j=e}}while(0);e=h&255;h=e<<8;d=i+1|0;i=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){l=0;m=j;break}k=gj[g&4095](i)|0;l=k;m=b[4821324]|0}else{l=a[f+(d&255)|0]|0;m=j}}while(0);j=l&255|h;c[2410669]=j;b[4821324]=m+2&65535;m=a[9642680]&-15;a[9642680]=m;h=m&255|e>>>4&8;if((j|0)!=0){n=h&255;a[9642680]=n;return}n=(h|4)&255;a[9642680]=n;return}function fOe(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=d;j=e;break}k=gj[g&4095](e)|0;g=c[2410662]|0;h=k;i=g;j=g&65535}else{h=a[f+(d&255)|0]|0;i=d;j=e}}while(0);e=h&255;h=e<<8;d=i+1|0;i=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){l=0;m=j;break}k=gj[g&4095](i)|0;l=k;m=b[4821324]|0}else{l=a[f+(d&255)|0]|0;m=j}}while(0);j=l&255|h;c[2410666]=j;b[4821324]=m+2&65535;m=a[9642680]&-15;a[9642680]=m;h=m&255|e>>>4&8;if((j|0)!=0){n=h&255;a[9642680]=n;return}n=(h|4)&255;a[9642680]=n;return}function fOf(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=d;j=e;break}k=gj[g&4095](e)|0;g=c[2410662]|0;h=k;i=g;j=g&65535}else{h=a[f+(d&255)|0]|0;i=d;j=e}}while(0);e=h&255;h=e<<8;d=i+1|0;i=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){l=0;m=j;break}k=gj[g&4095](i)|0;l=k;m=b[4821324]|0}else{l=a[f+(d&255)|0]|0;m=j}}while(0);j=l&255|h;c[2410667]=j;b[4821324]=m+2&65535;m=a[9642680]&-15;a[9642680]=m;h=m&255|e>>>4&8;if((j|0)!=0){n=h&255;a[9642680]=n;o=a[9642688]|0;p=o|32;a[9642688]=p;return}n=(h|4)&255;a[9642680]=n;o=a[9642688]|0;p=o|32;a[9642688]=p;return}function fOg(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=c[2410662]|0;f=d&65535;g=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[3528598]|0;if((h|0)==0){i=0;j=d;k=f;break}l=gj[h&4095](f)|0;h=c[2410662]|0;i=l;j=h;k=h&65535}else{i=a[g+(d&255)|0]|0;j=d;k=f}}while(0);f=(i&255)<<8;i=j+1|0;j=i&65535;d=c[9701680+((i>>>8&255)<<2)>>2]|0;do{if((d|0)==0){g=c[3528598]|0;if((g|0)==0){m=0;n=k;break}h=gj[g&4095](j)|0;m=h;n=b[4821324]|0}else{m=a[d+(i&255)|0]|0;n=k}}while(0);b[4821324]=n+2&65535;n=e[4821328]|0;k=n-(m&255|f)|0;m=(k>>>12&8|a[9642680]&-16&255)&255;a[9642680]=((n^f^k^k>>>1)>>>14&2|k>>>16&1|((k&65535)<<16>>16==0?m|4:m)&255)&255;return}function fOh(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=c[2410662]|0;f=d&65535;g=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[3528598]|0;if((h|0)==0){i=0;j=d;k=f;break}l=gj[h&4095](f)|0;h=c[2410662]|0;i=l;j=h;k=h&65535}else{i=a[g+(d&255)|0]|0;j=d;k=f}}while(0);f=(i&255)<<8;i=j+1|0;j=i&65535;d=c[9701680+((i>>>8&255)<<2)>>2]|0;do{if((d|0)==0){g=c[3528598]|0;if((g|0)==0){m=0;n=k;break}h=gj[g&4095](j)|0;m=h;n=b[4821324]|0}else{m=a[d+(i&255)|0]|0;n=k}}while(0);b[4821324]=n+2&65535;n=e[4821336]|0;k=n-(m&255|f)|0;m=(k>>>12&8|a[9642680]&-16&255)&255;a[9642680]=((n^f^k^k>>>1)>>>14&2|k>>>16&1|((k&65535)<<16>>16==0?m|4:m)&255)&255;return}function fOi(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=c[2410662]|0;f=d&65535;g=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[3528598]|0;if((h|0)==0){i=0;j=d;k=f;break}l=gj[h&4095](f)|0;h=c[2410662]|0;i=l;j=h;k=h&65535}else{i=a[g+(d&255)|0]|0;j=d;k=f}}while(0);f=(i&255)<<8;i=j+1|0;j=i&65535;d=c[9701680+((i>>>8&255)<<2)>>2]|0;do{if((d|0)==0){g=c[3528598]|0;if((g|0)==0){m=0;n=k;break}h=gj[g&4095](j)|0;m=h;n=b[4821324]|0}else{m=a[d+(i&255)|0]|0;n=k}}while(0);b[4821324]=n+2&65535;n=e[4821338]|0;k=n-(m&255|f)|0;m=(k>>>12&8|a[9642680]&-16&255)&255;a[9642680]=((n^f^k^k>>>1)>>>14&2|k>>>16&1|((k&65535)<<16>>16==0?m|4:m)&255)&255;return}function fOj(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=c[2410662]|0;f=d&65535;g=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[3528598]|0;if((h|0)==0){i=0;j=d;k=f;break}l=gj[h&4095](f)|0;h=c[2410662]|0;i=l;j=h;k=h&65535}else{i=a[g+(d&255)|0]|0;j=d;k=f}}while(0);f=(i&255)<<8;i=j+1|0;j=i&65535;d=c[9701680+((i>>>8&255)<<2)>>2]|0;do{if((d|0)==0){g=c[3528598]|0;if((g|0)==0){m=0;n=k;break}h=gj[g&4095](j)|0;m=h;n=b[4821324]|0}else{m=a[d+(i&255)|0]|0;n=k}}while(0);b[4821324]=n+2&65535;n=e[4821332]|0;k=n-(m&255|f)|0;m=(k>>>12&8|a[9642680]&-16&255)&255;a[9642680]=((n^f^k^k>>>1)>>>14&2|k>>>16&1|((k&65535)<<16>>16==0?m|4:m)&255)&255;return}function fOk(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=c[2410662]|0;f=d&65535;g=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[3528598]|0;if((h|0)==0){i=0;j=d;k=f;break}l=gj[h&4095](f)|0;h=c[2410662]|0;i=l;j=h;k=h&65535}else{i=a[g+(d&255)|0]|0;j=d;k=f}}while(0);f=(i&255)<<8;i=j+1|0;j=i&65535;d=c[9701680+((i>>>8&255)<<2)>>2]|0;do{if((d|0)==0){g=c[3528598]|0;if((g|0)==0){m=0;n=k;break}h=gj[g&4095](j)|0;m=h;n=b[4821324]|0}else{m=a[d+(i&255)|0]|0;n=k}}while(0);b[4821324]=n+2&65535;n=e[4821334]|0;k=n-(m&255|f)|0;m=(k>>>12&8|a[9642680]&-16&255)&255;a[9642680]=((n^f^k^k>>>1)>>>14&2|k>>>16&1|((k&65535)<<16>>16==0?m|4:m)&255)&255;return}function fOl(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=c[2410662]|0;f=d&65535;g=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[3528598]|0;if((h|0)==0){i=0;j=d;k=f;break}l=gj[h&4095](f)|0;h=c[2410662]|0;i=l;j=h;k=h&65535}else{i=a[g+(d&255)|0]|0;j=d;k=f}}while(0);f=(i&255)<<8;i=j+1|0;j=i&65535;d=c[9701680+((i>>>8&255)<<2)>>2]|0;do{if((d|0)==0){g=c[3528598]|0;if((g|0)==0){m=0;n=k;break}h=gj[g&4095](j)|0;m=h;n=b[4821324]|0}else{m=a[d+(i&255)|0]|0;n=k}}while(0);b[4821324]=n+2&65535;n=e[4821328]|0;k=n+(m&255|f)|0;m=(k>>>12&8|a[9642680]&-16&255)&255;i=k&65535;a[9642680]=((n^f^k^k>>>1)>>>14&2|k>>>16&1|(i<<16>>16==0?m|4:m)&255)&255;b[4821328]=i;return}function fOm(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=c[2410662]|0;f=d&65535;g=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[3528598]|0;if((h|0)==0){i=0;j=d;k=f;break}l=gj[h&4095](f)|0;h=c[2410662]|0;i=l;j=h;k=h&65535}else{i=a[g+(d&255)|0]|0;j=d;k=f}}while(0);f=(i&255)<<8;i=j+1|0;j=i&65535;d=c[9701680+((i>>>8&255)<<2)>>2]|0;do{if((d|0)==0){g=c[3528598]|0;if((g|0)==0){m=0;n=k;break}h=gj[g&4095](j)|0;m=h;n=b[4821324]|0}else{m=a[d+(i&255)|0]|0;n=k}}while(0);b[4821324]=n+2&65535;n=e[4821328]|0;k=n-(m&255|f)|0;m=(k>>>12&8|a[9642680]&-16&255)&255;i=k&65535;a[9642680]=((n^f^k^k>>>1)>>>14&2|k>>>16&1|(i<<16>>16==0?m|4:m)&255)&255;b[4821328]=i;return}function fOn(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);b[4821324]=(i+1&65535)+(h<<24>>24)&65535;b[4821324]=c[2410662]&65535;if(!(h<<24>>24==-2&(c[2439268]|0)>0)){return}c[2439268]=0;return}function fOo(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);e=i+1&65535;b[4821324]=e;if((a[9642680]&5)!=0){return}b[4821324]=e+(h<<24>>24)&65535;return}function fOp(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);e=i+1&65535;b[4821324]=e;if((a[9642680]&1)!=0){return}b[4821324]=e+(h<<24>>24)&65535;return}function fOq(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);e=i+1&65535;b[4821324]=e;if((a[9642680]&4)!=0){return}b[4821324]=e+(h<<24>>24)&65535;return}function fOr(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);e=i+1&65535;b[4821324]=e;if((a[9642680]&2)!=0){return}b[4821324]=e+(h<<24>>24)&65535;return}function fOs(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);e=i+1&65535;b[4821324]=e;if((a[9642680]&8)!=0){return}b[4821324]=e+(h<<24>>24)&65535;return}function fOt(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=c[2410662]|0;f=e&65535;g=c[9701680+((e>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[3528598]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](f)|0;i=k;j=b[4821324]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);f=j+1&65535;b[4821324]=f;j=d[9642680]|0;if(((j<<2^j)&8|0)!=0){return}b[4821324]=f+(i<<24>>24)&65535;return}function fOu(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=c[2410662]|0;f=e&65535;g=c[9701680+((e>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[3528598]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](f)|0;i=k;j=b[4821324]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);f=j+1&65535;b[4821324]=f;j=d[9642680]|0;if(((j<<2^j)&8|j&4|0)!=0){return}b[4821324]=f+(i<<24>>24)&65535;return}function fOv(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=d;j=e;break}k=gj[g&4095](e)|0;g=c[2410662]|0;h=k;i=g;j=g&65535}else{h=a[f+(d&255)|0]|0;i=d;j=e}}while(0);e=(h&255)<<8;h=i+1|0;i=h&65535;d=c[9701680+((h>>>8&255)<<2)>>2]|0;do{if((d|0)==0){f=c[3528598]|0;if((f|0)==0){l=0;m=j;break}g=gj[f&4095](i)|0;l=g;m=b[4821324]|0}else{l=a[d+(h&255)|0]|0;m=j}}while(0);j=l&255|e;c[2426870]=j;e=j&65535;b[4821324]=(m+2&65535)+e&65535;b[4821324]=c[2410662]&65535;if(!(e<<16>>16==-3&(c[2439268]|0)>0)){return}c[2439268]=0;return}function fOw(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=d;j=e;break}k=gj[g&4095](e)|0;g=c[2410662]|0;h=k;i=g;j=g&65535}else{h=a[f+(d&255)|0]|0;i=d;j=e}}while(0);e=i+1|0;i=e&65535;d=c[9701680+((e>>>8&255)<<2)>>2]|0;do{if((d|0)==0){f=c[3528598]|0;if((f|0)==0){l=0;m=j;break}g=gj[f&4095](i)|0;l=g;m=b[4821324]|0}else{l=a[d+(e&255)|0]|0;m=j}}while(0);j=m+2&65535;b[4821324]=j;if((a[9642680]&5)!=0){return}c[2439268]=(c[2439268]|0)-1;b[4821324]=j+(l&255|(h&255)<<8)&65535;return}function fOx(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=d;j=e;break}k=gj[g&4095](e)|0;g=c[2410662]|0;h=k;i=g;j=g&65535}else{h=a[f+(d&255)|0]|0;i=d;j=e}}while(0);e=i+1|0;i=e&65535;d=c[9701680+((e>>>8&255)<<2)>>2]|0;do{if((d|0)==0){f=c[3528598]|0;if((f|0)==0){l=0;m=j;break}g=gj[f&4095](i)|0;l=g;m=b[4821324]|0}else{l=a[d+(e&255)|0]|0;m=j}}while(0);j=m+2&65535;b[4821324]=j;if((a[9642680]&1)!=0){return}c[2439268]=(c[2439268]|0)-1;b[4821324]=j+(l&255|(h&255)<<8)&65535;return}function fOy(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=d;j=e;break}k=gj[g&4095](e)|0;g=c[2410662]|0;h=k;i=g;j=g&65535}else{h=a[f+(d&255)|0]|0;i=d;j=e}}while(0);e=i+1|0;i=e&65535;d=c[9701680+((e>>>8&255)<<2)>>2]|0;do{if((d|0)==0){f=c[3528598]|0;if((f|0)==0){l=0;m=j;break}g=gj[f&4095](i)|0;l=g;m=b[4821324]|0}else{l=a[d+(e&255)|0]|0;m=j}}while(0);j=m+2&65535;b[4821324]=j;if((a[9642680]&4)!=0){return}c[2439268]=(c[2439268]|0)-1;b[4821324]=j+(l&255|(h&255)<<8)&65535;return}function fOz(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=d;j=e;break}k=gj[g&4095](e)|0;g=c[2410662]|0;h=k;i=g;j=g&65535}else{h=a[f+(d&255)|0]|0;i=d;j=e}}while(0);e=i+1|0;i=e&65535;d=c[9701680+((e>>>8&255)<<2)>>2]|0;do{if((d|0)==0){f=c[3528598]|0;if((f|0)==0){l=0;m=j;break}g=gj[f&4095](i)|0;l=g;m=b[4821324]|0}else{l=a[d+(e&255)|0]|0;m=j}}while(0);j=m+2&65535;b[4821324]=j;if((a[9642680]&2)!=0){return}c[2439268]=(c[2439268]|0)-1;b[4821324]=j+(l&255|(h&255)<<8)&65535;return}function fOA(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=d;j=e;break}k=gj[g&4095](e)|0;g=c[2410662]|0;h=k;i=g;j=g&65535}else{h=a[f+(d&255)|0]|0;i=d;j=e}}while(0);e=i+1|0;i=e&65535;d=c[9701680+((e>>>8&255)<<2)>>2]|0;do{if((d|0)==0){f=c[3528598]|0;if((f|0)==0){l=0;m=j;break}g=gj[f&4095](i)|0;l=g;m=b[4821324]|0}else{l=a[d+(e&255)|0]|0;m=j}}while(0);j=m+2&65535;b[4821324]=j;if((a[9642680]&8)!=0){return}c[2439268]=(c[2439268]|0)-1;b[4821324]=j+(l&255|(h&255)<<8)&65535;return}function fOB(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=c[2410662]|0;f=e&65535;g=c[9701680+((e>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[3528598]|0;if((h|0)==0){i=0;j=e;k=f;break}l=gj[h&4095](f)|0;h=c[2410662]|0;i=l;j=h;k=h&65535}else{i=a[g+(e&255)|0]|0;j=e;k=f}}while(0);f=j+1|0;j=f&65535;e=c[9701680+((f>>>8&255)<<2)>>2]|0;do{if((e|0)==0){g=c[3528598]|0;if((g|0)==0){m=0;n=k;break}h=gj[g&4095](j)|0;m=h;n=b[4821324]|0}else{m=a[e+(f&255)|0]|0;n=k}}while(0);k=n+2&65535;b[4821324]=k;n=d[9642680]|0;if(((n<<2^n)&8|0)!=0){return}c[2439268]=(c[2439268]|0)-1;b[4821324]=k+(m&255|(i&255)<<8)&65535;return}function fOC(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=c[2410662]|0;f=e&65535;g=c[9701680+((e>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[3528598]|0;if((h|0)==0){i=0;j=e;k=f;break}l=gj[h&4095](f)|0;h=c[2410662]|0;i=l;j=h;k=h&65535}else{i=a[g+(e&255)|0]|0;j=e;k=f}}while(0);f=j+1|0;j=f&65535;e=c[9701680+((f>>>8&255)<<2)>>2]|0;do{if((e|0)==0){g=c[3528598]|0;if((g|0)==0){m=0;n=k;break}h=gj[g&4095](j)|0;m=h;n=b[4821324]|0}else{m=a[e+(f&255)|0]|0;n=k}}while(0);k=n+2&65535;b[4821324]=k;n=d[9642680]|0;if(((n<<2^n)&8|n&4|0)!=0){return}c[2439268]=(c[2439268]|0)-1;b[4821324]=k+(m&255|(i&255)<<8)&65535;return}function fOD(){var a=0,d=0,e=0,f=0;a=c[2410662]|0;d=a&65535;do{if((c[9701680+((a>>>8&255)<<2)>>2]|0)==0){e=c[3528598]|0;if((e|0)==0){f=d;break}gj[e&4095](d)|0;f=b[4821324]|0}else{f=d}}while(0);b[4821324]=f+1&65535;return}function fOE(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);e=i+1&65535;b[4821324]=e;if((a[9642680]&5)==0){return}b[4821324]=e+(h<<24>>24)&65535;return}function fOF(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);e=i+1&65535;b[4821324]=e;if((a[9642680]&1)==0){return}b[4821324]=e+(h<<24>>24)&65535;return}function fOG(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);e=i+1&65535;b[4821324]=e;if((a[9642680]&4)==0){return}b[4821324]=e+(h<<24>>24)&65535;return}function fOH(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);e=i+1&65535;b[4821324]=e;if((a[9642680]&2)==0){return}b[4821324]=e+(h<<24>>24)&65535;return}function fOI(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);e=i+1&65535;b[4821324]=e;if((a[9642680]&8)==0){return}b[4821324]=e+(h<<24>>24)&65535;return}function fOJ(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=c[2410662]|0;f=e&65535;g=c[9701680+((e>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[3528598]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](f)|0;i=k;j=b[4821324]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);f=j+1&65535;b[4821324]=f;j=d[9642680]|0;if(((j<<2^j)&8|0)==0){return}b[4821324]=f+(i<<24>>24)&65535;return}function fOK(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=c[2410662]|0;f=e&65535;g=c[9701680+((e>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[3528598]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](f)|0;i=k;j=b[4821324]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);f=j+1&65535;b[4821324]=f;j=d[9642680]|0;if(((j<<2^j)&8|j&4|0)==0){return}b[4821324]=f+(i<<24>>24)&65535;return}function fOL(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=d;j=e;break}k=gj[g&4095](e)|0;g=c[2410662]|0;h=k;i=g;j=g&65535}else{h=a[f+(d&255)|0]|0;i=d;j=e}}while(0);e=(h&255)<<8;h=i+1|0;i=h&65535;d=c[9701680+((h>>>8&255)<<2)>>2]|0;do{if((d|0)==0){f=c[3528598]|0;if((f|0)==0){l=0;m=j;break}g=gj[f&4095](i)|0;l=g;m=b[4821324]|0}else{l=a[d+(h&255)|0]|0;m=j}}while(0);c[2426870]=l&255|e;b[4821324]=m+2&65535;return}function fOM(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=d;j=e;break}k=gj[g&4095](e)|0;g=c[2410662]|0;h=k;i=g;j=g&65535}else{h=a[f+(d&255)|0]|0;i=d;j=e}}while(0);e=i+1|0;i=e&65535;d=c[9701680+((e>>>8&255)<<2)>>2]|0;do{if((d|0)==0){f=c[3528598]|0;if((f|0)==0){l=0;m=j;break}g=gj[f&4095](i)|0;l=g;m=b[4821324]|0}else{l=a[d+(e&255)|0]|0;m=j}}while(0);j=m+2&65535;b[4821324]=j;if((a[9642680]&5)==0){return}c[2439268]=(c[2439268]|0)-1;b[4821324]=j+(l&255|(h&255)<<8)&65535;return}function fON(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=d;j=e;break}k=gj[g&4095](e)|0;g=c[2410662]|0;h=k;i=g;j=g&65535}else{h=a[f+(d&255)|0]|0;i=d;j=e}}while(0);e=i+1|0;i=e&65535;d=c[9701680+((e>>>8&255)<<2)>>2]|0;do{if((d|0)==0){f=c[3528598]|0;if((f|0)==0){l=0;m=j;break}g=gj[f&4095](i)|0;l=g;m=b[4821324]|0}else{l=a[d+(e&255)|0]|0;m=j}}while(0);j=m+2&65535;b[4821324]=j;if((a[9642680]&1)==0){return}c[2439268]=(c[2439268]|0)-1;b[4821324]=j+(l&255|(h&255)<<8)&65535;return}function fOO(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=d;j=e;break}k=gj[g&4095](e)|0;g=c[2410662]|0;h=k;i=g;j=g&65535}else{h=a[f+(d&255)|0]|0;i=d;j=e}}while(0);e=i+1|0;i=e&65535;d=c[9701680+((e>>>8&255)<<2)>>2]|0;do{if((d|0)==0){f=c[3528598]|0;if((f|0)==0){l=0;m=j;break}g=gj[f&4095](i)|0;l=g;m=b[4821324]|0}else{l=a[d+(e&255)|0]|0;m=j}}while(0);j=m+2&65535;b[4821324]=j;if((a[9642680]&4)==0){return}c[2439268]=(c[2439268]|0)-1;b[4821324]=j+(l&255|(h&255)<<8)&65535;return}function fOP(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=d;j=e;break}k=gj[g&4095](e)|0;g=c[2410662]|0;h=k;i=g;j=g&65535}else{h=a[f+(d&255)|0]|0;i=d;j=e}}while(0);e=i+1|0;i=e&65535;d=c[9701680+((e>>>8&255)<<2)>>2]|0;do{if((d|0)==0){f=c[3528598]|0;if((f|0)==0){l=0;m=j;break}g=gj[f&4095](i)|0;l=g;m=b[4821324]|0}else{l=a[d+(e&255)|0]|0;m=j}}while(0);j=m+2&65535;b[4821324]=j;if((a[9642680]&2)==0){return}c[2439268]=(c[2439268]|0)-1;b[4821324]=j+(l&255|(h&255)<<8)&65535;return}function fOQ(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=d;j=e;break}k=gj[g&4095](e)|0;g=c[2410662]|0;h=k;i=g;j=g&65535}else{h=a[f+(d&255)|0]|0;i=d;j=e}}while(0);e=i+1|0;i=e&65535;d=c[9701680+((e>>>8&255)<<2)>>2]|0;do{if((d|0)==0){f=c[3528598]|0;if((f|0)==0){l=0;m=j;break}g=gj[f&4095](i)|0;l=g;m=b[4821324]|0}else{l=a[d+(e&255)|0]|0;m=j}}while(0);j=m+2&65535;b[4821324]=j;if((a[9642680]&8)==0){return}c[2439268]=(c[2439268]|0)-1;b[4821324]=j+(l&255|(h&255)<<8)&65535;return}function fOR(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=c[2410662]|0;f=e&65535;g=c[9701680+((e>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[3528598]|0;if((h|0)==0){i=0;j=e;k=f;break}l=gj[h&4095](f)|0;h=c[2410662]|0;i=l;j=h;k=h&65535}else{i=a[g+(e&255)|0]|0;j=e;k=f}}while(0);f=j+1|0;j=f&65535;e=c[9701680+((f>>>8&255)<<2)>>2]|0;do{if((e|0)==0){g=c[3528598]|0;if((g|0)==0){m=0;n=k;break}h=gj[g&4095](j)|0;m=h;n=b[4821324]|0}else{m=a[e+(f&255)|0]|0;n=k}}while(0);k=n+2&65535;b[4821324]=k;n=d[9642680]|0;if(((n<<2^n)&8|0)==0){return}c[2439268]=(c[2439268]|0)-1;b[4821324]=k+(m&255|(i&255)<<8)&65535;return}function fOS(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=c[2410662]|0;f=e&65535;g=c[9701680+((e>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[3528598]|0;if((h|0)==0){i=0;j=e;k=f;break}l=gj[h&4095](f)|0;h=c[2410662]|0;i=l;j=h;k=h&65535}else{i=a[g+(e&255)|0]|0;j=e;k=f}}while(0);f=j+1|0;j=f&65535;e=c[9701680+((f>>>8&255)<<2)>>2]|0;do{if((e|0)==0){g=c[3528598]|0;if((g|0)==0){m=0;n=k;break}h=gj[g&4095](j)|0;m=h;n=b[4821324]|0}else{m=a[e+(f&255)|0]|0;n=k}}while(0);k=n+2&65535;b[4821324]=k;n=d[9642680]|0;if(((n<<2^n)&8|n&4|0)==0){return}c[2439268]=(c[2439268]|0)-1;b[4821324]=k+(m&255|(i&255)<<8)&65535;return}function fOT(){a[9642657]=0;a[9642680]=a[9642680]&-16|4;return}function fOU(){a[9642656]=0;a[9642680]=a[9642680]&-16|4;return}function fOV(){var b=0,c=0,d=0;b=a[9642657]|0;c=~b;a[9642657]=c;d=(c&255)>>>4&8|a[9642680]&-15;a[9642680]=(b<<24>>24==-1?d|4:d)|1;return}function fOW(){var b=0,c=0,d=0;b=a[9642656]|0;c=~b;a[9642656]=c;d=(c&255)>>>4&8|a[9642680]&-15;a[9642680]=(b<<24>>24==-1?d|4:d)|1;return}function fOX(){var b=0,c=0,d=0,e=0,f=0;b=a[9642657]|0;c=-(b&255)&65535;d=c&65535;e=(d>>>4&8|a[9642680]&-16&255)&255;f=c&255;a[9642680]=((d^b&255^d>>>1)>>>6&2|d>>>8&1|(f<<24>>24==0?e|4:e)&255)&255;a[9642657]=f;return}function fOY(){var b=0,c=0,d=0,e=0,f=0;b=a[9642656]|0;c=-(b&255)&65535;d=c&65535;e=(d>>>4&8|a[9642680]&-16&255)&255;f=c&255;a[9642680]=((d^b&255^d>>>1)>>>6&2|d>>>8&1|(f<<24>>24==0?e|4:e)&255)&255;a[9642656]=f;return}function fOZ(){var b=0;b=(a[9642657]|0)+1&255;a[9642657]=b;a[9642680]=a[668928+(b&255)|0]|a[9642680]&-15;return}function fO_(){var b=0;b=(a[9642656]|0)+1&255;a[9642656]=b;a[9642680]=a[668928+(b&255)|0]|a[9642680]&-15;return}function fO$(){var b=0;b=(a[9642657]|0)-1&255;a[9642657]=b;a[9642680]=a[669184+(b&255)|0]|a[9642680]&-15;return}function fO0(){var b=0;b=(a[9642656]|0)-1&255;a[9642656]=b;a[9642680]=a[669184+(b&255)|0]|a[9642680]&-15;return}function fO1(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=c[2410667]|0;e=d&65535;f=c[9699632+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821334]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);e=(h&255)<<8;c[2410662]=e;b[4821334]=i+1&65535;i=c[2410667]|0;h=i&65535;d=c[9699632+((i>>>8&255)<<2)>>2]|0;do{if((d|0)==0){f=c[3528598]|0;if((f|0)==0){k=0;l=e;m=h;break}j=gj[f&4095](h)|0;k=j;l=c[2410662]|0;m=b[4821334]|0}else{k=a[d+(i&255)|0]|0;l=e;m=h}}while(0);h=l|k&255;c[2410662]=h;b[4821334]=m+1&65535;b[4821324]=h&65535;return}function fO2(){var b=0,c=0;b=a[9642657]|0;c=(b&255)>>>4&8|a[9642680]&-15;a[9642680]=b<<24>>24==0?c|4:c;return}function fO3(){var b=0,c=0;b=a[9642656]|0;c=(b&255)>>>4&8|a[9642680]&-15;a[9642680]=b<<24>>24==0?c|4:c;return}function fO4(){var b=0,c=0,d=0;b=a[9642657]|0;c=b&1|a[9642680]&-14;a[9642680]=c;d=(b&255)>>>1;a[9642657]=d;if(d<<24>>24!=0){return}a[9642680]=c|4;return}function fO5(){var b=0,c=0,d=0;b=a[9642656]|0;c=b&1|a[9642680]&-14;a[9642680]=c;d=(b&255)>>>1;a[9642656]=d;if(d<<24>>24!=0){return}a[9642680]=c|4;return}function fO6(){var b=0,c=0,d=0,e=0;b=a[9642680]|0;c=a[9642657]|0;d=(c&255)>>>1|b<<7;e=c&1|b&-14|b<<3&8;a[9642680]=d<<24>>24==0?e|4:e;a[9642657]=d;return}function fO7(){var b=0,c=0,d=0,e=0;b=a[9642680]|0;c=a[9642656]|0;d=(c&255)>>>1|b<<7;e=c&1|b&-14|b<<3&8;a[9642680]=d<<24>>24==0?e|4:e;a[9642656]=d;return}function fO8(){var b=0,c=0,d=0,e=0;b=a[9642657]|0;c=b&1|a[9642680]&-14;d=b&-128|(b&255)>>>1;a[9642657]=d;e=(b&255)>>>4&8|c;a[9642680]=d<<24>>24==0?e|4:e;return}function fO9(){var b=0,c=0,d=0,e=0;b=a[9642656]|0;c=b&1|a[9642680]&-14;d=b&-128|(b&255)>>>1;a[9642656]=d;e=(b&255)>>>4&8|c;a[9642680]=d<<24>>24==0?e|4:e;return}function fPa(){var b=0,c=0,e=0,f=0;b=(d[9642657]|0)<<1;c=b&65535;e=(c>>>4&8|a[9642680]&-16&255)&255;f=b&255;a[9642680]=((c>>>1^c)>>>6&2|c>>>8|(f<<24>>24==0?e|4:e)&255)&255;a[9642657]=f;return}function fPb(){var b=0,c=0,e=0,f=0;b=(d[9642656]|0)<<1;c=b&65535;e=(c>>>4&8|a[9642680]&-16&255)&255;f=b&255;a[9642680]=((c>>>1^c)>>>6&2|c>>>8|(f<<24>>24==0?e|4:e)&255)&255;a[9642656]=f;return}function fPc(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;e=c[2410667]|0;f=e&65535;g=c[9699632+((e>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[3528598]|0;if((h|0)==0){a[9642680]=0;b[4821334]=f+1&65535;break}else{i=gj[h&4095](f)|0;j=i;k=b[4821334]|0;l=16641;break}}else{j=a[g+(e&255)|0]|0;k=f;l=16641}}while(0);do{if((l|0)==16641){a[9642680]=j;b[4821334]=k+1&65535;if(j<<24>>24>=0){break}c[2439268]=(c[2439268]|0)-9;f=c[2410667]|0;e=f&65535;g=c[9699632+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){i=c[3528598]|0;if((i|0)==0){m=0;n=e;break}h=gj[i&4095](e)|0;m=h;n=b[4821334]|0}else{m=a[g+(f&255)|0]|0;n=e}}while(0);a[9642657]=m;b[4821334]=n+1&65535;e=c[2410667]|0;f=e&65535;g=c[9699632+((e>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[3528598]|0;if((h|0)==0){o=0;p=f;break}i=gj[h&4095](f)|0;o=i;p=b[4821334]|0}else{o=a[g+(e&255)|0]|0;p=f}}while(0);a[9642656]=o;b[4821334]=p+1&65535;f=c[2410667]|0;e=f&65535;g=c[9699632+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){i=c[3528598]|0;if((i|0)==0){q=0;r=e;break}h=gj[i&4095](e)|0;q=h;r=b[4821334]|0}else{q=a[g+(f&255)|0]|0;r=e}}while(0);a[9642661]=q;b[4821334]=r+1&65535;e=c[2410667]|0;f=e&65535;g=c[9699632+((e>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[3528598]|0;if((h|0)==0){s=0;t=f;break}i=gj[h&4095](f)|0;s=i;t=b[4821334]|0}else{s=a[g+(e&255)|0]|0;t=f}}while(0);f=(s&255)<<8;c[2410668]=f;b[4821334]=t+1&65535;e=c[2410667]|0;g=e&65535;i=c[9699632+((e>>>8&255)<<2)>>2]|0;do{if((i|0)==0){h=c[3528598]|0;if((h|0)==0){u=0;v=f;w=g;break}x=gj[h&4095](g)|0;u=x;v=c[2410668]|0;w=b[4821334]|0}else{u=a[i+(e&255)|0]|0;v=f;w=g}}while(0);c[2410668]=v|u&255;b[4821334]=w+1&65535;g=c[2410667]|0;f=g&65535;e=c[9699632+((g>>>8&255)<<2)>>2]|0;do{if((e|0)==0){i=c[3528598]|0;if((i|0)==0){y=0;z=f;break}x=gj[i&4095](f)|0;y=x;z=b[4821334]|0}else{y=a[e+(g&255)|0]|0;z=f}}while(0);f=(y&255)<<8;c[2410669]=f;b[4821334]=z+1&65535;g=c[2410667]|0;e=g&65535;x=c[9699632+((g>>>8&255)<<2)>>2]|0;do{if((x|0)==0){i=c[3528598]|0;if((i|0)==0){A=0;B=f;C=e;break}h=gj[i&4095](e)|0;A=h;B=c[2410669]|0;C=b[4821334]|0}else{A=a[x+(g&255)|0]|0;B=f;C=e}}while(0);c[2410669]=B|A&255;b[4821334]=C+1&65535;e=c[2410667]|0;f=e&65535;g=c[9699632+((e>>>8&255)<<2)>>2]|0;do{if((g|0)==0){x=c[3528598]|0;if((x|0)==0){D=0;E=f;break}h=gj[x&4095](f)|0;D=h;E=b[4821334]|0}else{D=a[g+(e&255)|0]|0;E=f}}while(0);f=(D&255)<<8;c[2410666]=f;b[4821334]=E+1&65535;e=c[2410667]|0;g=e&65535;h=c[9699632+((e>>>8&255)<<2)>>2]|0;do{if((h|0)==0){x=c[3528598]|0;if((x|0)==0){F=0;G=f;H=g;break}i=gj[x&4095](g)|0;F=i;G=c[2410666]|0;H=b[4821334]|0}else{F=a[h+(e&255)|0]|0;G=f;H=g}}while(0);c[2410666]=G|F&255;b[4821334]=H+1&65535}}while(0);H=c[2410667]|0;F=H&65535;G=c[9699632+((H>>>8&255)<<2)>>2]|0;do{if((G|0)==0){E=c[3528598]|0;if((E|0)==0){I=0;J=F;break}D=gj[E&4095](F)|0;I=D;J=b[4821334]|0}else{I=a[G+(H&255)|0]|0;J=F}}while(0);F=(I&255)<<8;c[2410662]=F;b[4821334]=J+1&65535;J=c[2410667]|0;I=J&65535;H=c[9699632+((J>>>8&255)<<2)>>2]|0;do{if((H|0)==0){G=c[3528598]|0;if((G|0)==0){K=0;L=F;M=I;break}D=gj[G&4095](I)|0;K=D;L=c[2410662]|0;M=b[4821334]|0}else{K=a[H+(J&255)|0]|0;L=F;M=I}}while(0);I=L|K&255;c[2410662]=I;b[4821334]=M+1&65535;b[4821324]=I&65535;K=a[9642682]|0;L=a[9642683]|0;F=I&255;if((L|K)<<24>>24!=0){a[9642688]=a[9642688]&-17}do{if(L<<24>>24!=0){I=a[9642680]|0;if((I&64)!=0){break}J=a[9642688]|0;if((J&8)==0){a[9642680]=I&127;b[4821334]=M;H=c[2410667]|0;D=H&65535;G=c[9700656+((H>>>8&255)<<2)>>2]|0;do{if((G|0)==0){E=c[2444172]|0;if((E|0)==0){break}gg[E&4095](D,F)}else{a[G+(H&255)|0]=F}}while(0);b[4821334]=(b[4821334]|0)-1&65535;H=c[2410667]|0;G=H&65535;D=a[9642649]|0;E=c[9700656+((H>>>8&255)<<2)>>2]|0;do{if((E|0)==0){C=c[2444172]|0;if((C|0)==0){break}gg[C&4095](G,D)}else{a[E+(H&255)|0]=D}}while(0);b[4821334]=(b[4821334]|0)-1&65535;D=c[2410667]|0;H=D&65535;E=a[9642680]|0;G=c[9700656+((D>>>8&255)<<2)>>2]|0;do{if((G|0)==0){C=c[2444172]|0;if((C|0)==0){break}gg[C&4095](H,E)}else{a[G+(D&255)|0]=E}}while(0);N=(c[2410671]|0)+10|0;O=a[9642680]|0}else{a[9642688]=J&-9;N=(c[2410671]|0)+7|0;O=I}c[2410671]=N;a[9642680]=O|80;E=c[2425163]|0;do{if((E|0)==0){D=c[3528598]|0;if((D|0)==0){P=0;Q=0;break}G=gj[D&4095](-10)|0;D=c[2425163]|0;H=(G&255)<<8;if((D|0)!=0){R=D;S=H;l=16710;break}D=c[3528598]|0;if((D|0)==0){P=0;Q=H;break}P=gj[D&4095](-9)|0;Q=H}else{R=E;S=(d[E+246|0]|0)<<8;l=16710}}while(0);if((l|0)==16710){P=a[R+247|0]|0;Q=S}c[2410662]=P&255|Q;E=c[2410674]|0;gj[E&4095](1)|0;return}}while(0);if(K<<24>>24==0){return}K=a[9642680]|0;if((K&16)!=0){return}Q=a[9642688]|0;if((Q&8)==0){a[9642680]=K|-128;b[4821334]=M;M=c[2410667]|0;P=M&65535;S=c[9700656+((M>>>8&255)<<2)>>2]|0;do{if((S|0)==0){R=c[2444172]|0;if((R|0)==0){break}gg[R&4095](P,F)}else{a[S+(M&255)|0]=F}}while(0);b[4821334]=(b[4821334]|0)-1&65535;F=c[2410667]|0;M=F&65535;S=a[9642649]|0;P=c[9700656+((F>>>8&255)<<2)>>2]|0;do{if((P|0)==0){R=c[2444172]|0;if((R|0)==0){break}gg[R&4095](M,S)}else{a[P+(F&255)|0]=S}}while(0);b[4821334]=(b[4821334]|0)-1&65535;S=c[2410667]|0;F=S&65535;P=a[9642664]|0;M=c[9700656+((S>>>8&255)<<2)>>2]|0;do{if((M|0)==0){R=c[2444172]|0;if((R|0)==0){break}gg[R&4095](F,P)}else{a[M+(S&255)|0]=P}}while(0);b[4821334]=(b[4821334]|0)-1&65535;P=c[2410667]|0;S=P&65535;M=a[9642665]|0;F=c[9700656+((P>>>8&255)<<2)>>2]|0;do{if((F|0)==0){R=c[2444172]|0;if((R|0)==0){break}gg[R&4095](S,M)}else{a[F+(P&255)|0]=M}}while(0);b[4821334]=(b[4821334]|0)-1&65535;M=c[2410667]|0;P=M&65535;F=a[9642676]|0;S=c[9700656+((M>>>8&255)<<2)>>2]|0;do{if((S|0)==0){R=c[2444172]|0;if((R|0)==0){break}gg[R&4095](P,F)}else{a[S+(M&255)|0]=F}}while(0);b[4821334]=(b[4821334]|0)-1&65535;F=c[2410667]|0;M=F&65535;S=a[9642677]|0;P=c[9700656+((F>>>8&255)<<2)>>2]|0;do{if((P|0)==0){R=c[2444172]|0;if((R|0)==0){break}gg[R&4095](M,S)}else{a[P+(F&255)|0]=S}}while(0);b[4821334]=(b[4821334]|0)-1&65535;S=c[2410667]|0;F=S&65535;P=a[9642672]|0;M=c[9700656+((S>>>8&255)<<2)>>2]|0;do{if((M|0)==0){R=c[2444172]|0;if((R|0)==0){break}gg[R&4095](F,P)}else{a[M+(S&255)|0]=P}}while(0);b[4821334]=(b[4821334]|0)-1&65535;P=c[2410667]|0;S=P&65535;M=a[9642673]|0;F=c[9700656+((P>>>8&255)<<2)>>2]|0;do{if((F|0)==0){R=c[2444172]|0;if((R|0)==0){break}gg[R&4095](S,M)}else{a[F+(P&255)|0]=M}}while(0);b[4821334]=(b[4821334]|0)-1&65535;M=c[2410667]|0;P=M&65535;F=a[9642661]|0;S=c[9700656+((M>>>8&255)<<2)>>2]|0;do{if((S|0)==0){R=c[2444172]|0;if((R|0)==0){break}gg[R&4095](P,F)}else{a[S+(M&255)|0]=F}}while(0);b[4821334]=(b[4821334]|0)-1&65535;F=c[2410667]|0;M=F&65535;S=a[9642656]|0;P=c[9700656+((F>>>8&255)<<2)>>2]|0;do{if((P|0)==0){R=c[2444172]|0;if((R|0)==0){break}gg[R&4095](M,S)}else{a[P+(F&255)|0]=S}}while(0);b[4821334]=(b[4821334]|0)-1&65535;S=c[2410667]|0;F=S&65535;P=a[9642657]|0;M=c[9700656+((S>>>8&255)<<2)>>2]|0;do{if((M|0)==0){R=c[2444172]|0;if((R|0)==0){break}gg[R&4095](F,P)}else{a[M+(S&255)|0]=P}}while(0);b[4821334]=(b[4821334]|0)-1&65535;P=c[2410667]|0;S=P&65535;M=a[9642680]|0;F=c[9700656+((P>>>8&255)<<2)>>2]|0;do{if((F|0)==0){R=c[2444172]|0;if((R|0)==0){break}gg[R&4095](S,M)}else{a[F+(P&255)|0]=M}}while(0);T=(c[2410671]|0)+19|0;U=a[9642680]|0}else{a[9642688]=Q&-9;T=(c[2410671]|0)+7|0;U=K}c[2410671]=T;a[9642680]=U|16;U=c[2425163]|0;do{if((U|0)==0){T=c[3528598]|0;if((T|0)==0){V=0;W=0;break}K=gj[T&4095](-8)|0;T=c[2425163]|0;Q=(K&255)<<8;if((T|0)!=0){X=T;Y=Q;l=16771;break}T=c[3528598]|0;if((T|0)==0){V=0;W=Q;break}V=gj[T&4095](-7)|0;W=Q}else{X=U;Y=(d[U+248|0]|0)<<8;l=16771}}while(0);if((l|0)==16771){V=a[X+249|0]|0;W=Y}c[2410662]=V&255|W;gj[c[2410674]&4095](0)|0;return}function fPd(){var b=0,c=0,d=0,e=0,f=0;b=a[9642657]|0;c=a[9642680]|0;d=b&255;e=d<<1;f=c&-16|(b&255)>>>3&8;b=(c&1|e)&255;a[9642680]=((e^d)>>>6&2|d>>>7|(b<<24>>24==0?f|4:f)&255)&255;a[9642657]=b;return}function fPe(){var b=0,c=0,e=0,f=0;b=a[9642680]|0;c=b&1|(d[9642656]|0)<<1;e=c&65535;f=(e>>>4&8|b&-16&255)&255;b=c&255;a[9642680]=((e>>>1^e)>>>6&2|e>>>8|(b<<24>>24==0?f|4:f)&255)&255;a[9642656]=b;return}function fPf(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);e=i+1&65535;b[4821324]=e;b[4821334]=(b[4821334]|0)-1&65535;i=c[2410667]|0;d=i&65535;f=e&255;e=c[9700656+((i>>>8&255)<<2)>>2]|0;do{if((e|0)==0){j=c[2444172]|0;if((j|0)==0){break}gg[j&4095](d,f)}else{a[e+(i&255)|0]=f}}while(0);b[4821334]=(b[4821334]|0)-1&65535;f=c[2410667]|0;i=f&65535;e=a[9642649]|0;d=c[9700656+((f>>>8&255)<<2)>>2]|0;do{if((d|0)==0){j=c[2444172]|0;if((j|0)==0){break}gg[j&4095](i,e)}else{a[d+(f&255)|0]=e}}while(0);b[4821324]=(b[4821324]|0)+(h<<24>>24)&65535;b[4821324]=c[2410662]&65535;return}function fPg(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=d;j=e;break}k=gj[g&4095](e)|0;g=c[2410662]|0;h=k;i=g;j=g&65535}else{h=a[f+(d&255)|0]|0;i=d;j=e}}while(0);e=(h&255)<<8;h=i+1|0;i=h&65535;d=c[9701680+((h>>>8&255)<<2)>>2]|0;do{if((d|0)==0){f=c[3528598]|0;if((f|0)==0){l=0;m=j;break}g=gj[f&4095](i)|0;l=g;m=b[4821324]|0}else{l=a[d+(h&255)|0]|0;m=j}}while(0);c[2426870]=l&255|e;e=m+2&65535;b[4821324]=e;b[4821334]=(b[4821334]|0)-1&65535;m=c[2410667]|0;l=m&65535;j=e&255;e=c[9700656+((m>>>8&255)<<2)>>2]|0;do{if((e|0)==0){h=c[2444172]|0;if((h|0)==0){break}gg[h&4095](l,j)}else{a[e+(m&255)|0]=j}}while(0);b[4821334]=(b[4821334]|0)-1&65535;j=c[2410667]|0;m=j&65535;e=a[9642649]|0;l=c[9700656+((j>>>8&255)<<2)>>2]|0;do{if((l|0)==0){h=c[2444172]|0;if((h|0)==0){break}gg[h&4095](m,e)}else{a[l+(j&255)|0]=e}}while(0);b[4821324]=(b[4821324]|0)+(b[4853740]|0)&65535;b[4821324]=c[2410662]&65535;return}function fPh(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=(a[9642656]|0)-1&255;a[9642656]=d;e=a[669184+(d&255)|0]|a[9642680]&-15;a[9642680]=e;d=c[2410662]|0;f=d&65535;g=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[3528598]|0;if((h|0)==0){i=0;j=f;k=e;break}l=gj[h&4095](f)|0;i=l;j=b[4821324]|0;k=a[9642680]|0}else{i=a[g+(d&255)|0]|0;j=f;k=e}}while(0);e=j+1&65535;if((k&4)!=0){m=e;b[4821324]=m;return}m=e+(i<<24>>24)&65535;b[4821324]=m;return}function fPi(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=(b[4821336]|0)-1&65535;b[4821336]=d;e=a[9642680]&-15;a[9642680]=e;f=(d&65535)>>>12&8|e&255;if(d<<16>>16==0){g=(f|4)&255}else{g=f&255}a[9642680]=g;f=c[2410662]|0;d=f&65535;e=c[9701680+((f>>>8&255)<<2)>>2]|0;do{if((e|0)==0){h=c[3528598]|0;if((h|0)==0){i=0;j=d;k=g;break}l=gj[h&4095](d)|0;i=l;j=b[4821324]|0;k=a[9642680]|0}else{i=a[e+(f&255)|0]|0;j=d;k=g}}while(0);g=j+1&65535;if((k&4)!=0){m=g;b[4821324]=m;return}m=g+(i<<24>>24)&65535;b[4821324]=m;return}function fPj(){return}function fPk(){b[4821336]=(b[4821336]|0)+(d[9642656]|0)&65535;return}function fPl(){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=a[9642657]|0;c=b&-16;d=(b&14)>9;if(d){e=16836}else{if((a[9642680]&32)==0){f=0}else{e=16836}}if((e|0)==16836){f=6}do{if((c&255)>128){g=d?f|96:f;if((c&255)<=144){h=g;e=16840;break}i=g;j=a[9642680]|0;e=16841}else{h=f;e=16840}}while(0);if((e|0)==16840){f=a[9642680]|0;if((f&1)==0){k=h;l=f}else{i=h;j=f;e=16841}}if((e|0)==16841){k=i|96;l=j}j=k+(b&255)&65535;b=j&255;k=j&65535;j=(k>>>4&8|l&-15&255)&255;a[9642680]=((b<<24>>24==0?j|4:j)&255|k>>>8&1)&255;a[9642657]=b;return}function fPm(){var c=0,d=0,e=0;c=a[9642656]|0;d=c<<24>>24;b[4821328]=d;e=((d&65535)>>>12&8|a[9642680]&-13&255)&255;a[9642680]=c<<24>>24==0?e|4:e;return}function fPn(){var c=0,e=0;c=ag(d[9642656]|0,d[9642657]|0)|0;e=a[9642680]&-6;a[9642680]=(c&65535)>>>7&1|(c<<16>>16==0?e|4:e);b[4821328]=c;return}function fPo(){var c=0,d=0;c=ag(e[4821338]|0,e[4821336]|0)|0;b[4821336]=c>>>16&65535;b[4821338]=c&65535;d=a[9642680]&-6;a[9642680]=c>>>15&1|((c|0)==0?d|4:d);return}function fPp(){var c=0,d=0,f=0,g=0;c=a[9642656]|0;d=c&255;if(c<<24>>24==0){f=0;g=0}else{c=e[4821336]|0;f=((c>>>0)%(d>>>0)|0)&255;g=((c>>>0)/(d>>>0)|0)&65535}d=a[9642680]&-6;a[9642680]=(g<<16>>16==0?d|4:d)|(g&65535)>>>7&1;b[4821336]=g;a[9642656]=f;return}function fPq(){var d=0,e=0,f=0,g=0,h=0,i=0;if((b[4821332]|0)==0){return}d=b[4821338]|0;do{e=d&65535;f=c[9699632+(e>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;break}h=gj[g&4095](d)|0}else{h=a[f+(e&255)|0]|0}}while(0);e=b[4821336]|0;f=e&65535;g=c[9700656+(f>>>8<<2)>>2]|0;do{if((g|0)==0){i=c[2444172]|0;if((i|0)==0){break}gg[i&4095](e,h)}else{a[g+(f&255)|0]=h}}while(0);d=(b[4821338]|0)+1&65535;b[4821338]=d;b[4821336]=(b[4821336]|0)+1&65535;f=(b[4821332]|0)-1&65535;b[4821332]=f;c[2439268]=(c[2439268]|0)-2;}while(f<<16>>16!=0);return}function fPr(){var d=0,e=0,f=0,g=0,h=0;d=b[4821338]|0;e=d&65535;f=c[9699632+(e>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;break}h=gj[g&4095](d)|0}else{h=a[f+(e&255)|0]|0}}while(0);e=b[4821336]|0;f=e&65535;d=c[9700656+(f>>>8<<2)>>2]|0;do{if((d|0)==0){g=c[2444172]|0;if((g|0)==0){break}gg[g&4095](e,h)}else{a[d+(f&255)|0]=h}}while(0);b[4821338]=(b[4821338]|0)+1&65535;b[4821336]=(b[4821336]|0)+1&65535;b[4821332]=(b[4821332]|0)-1&65535;return}function fPs(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)!=0){h=gj[g&4095](e)|0;i=h;j=b[4821324]|0;break}b[4821324]=e+1&65535;return}else{i=a[f+(d&255)|0]|0;j=e}}while(0);b[4821324]=j+1&65535;if(i<<24>>24==0){return}j=i;i=a[9642680]|0;e=b[4821328]|0;do{j=j-1&255;d=e&1|i&-14;e=(e&65535)>>>1;i=e<<16>>16==0?d|4:d;}while(j<<24>>24!=0);a[9642680]=i;b[4821328]=e;return}function fPt(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)!=0){h=gj[g&4095](e)|0;i=h;j=b[4821324]|0;break}b[4821324]=e+1&65535;return}else{i=a[f+(d&255)|0]|0;j=e}}while(0);b[4821324]=j+1&65535;if(i<<24>>24==0){return}j=i;i=a[9642680]|0;e=b[4821328]|0;while(1){d=j-1&255;k=(i&255)<<15|(e&65535)>>>1;f=e&1|i&-14|i<<3&8;l=k<<16>>16==0?f|4:f;if(d<<24>>24==0){break}else{j=d;i=l;e=k}}a[9642680]=l;b[4821328]=k;return}function fPu(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)!=0){h=gj[g&4095](e)|0;i=h;j=b[4821324]|0;break}b[4821324]=e+1&65535;return}else{i=a[f+(d&255)|0]|0;j=e}}while(0);b[4821324]=j+1&65535;if(i<<24>>24==0){return}j=i;i=a[9642680]|0;e=b[4821328]|0;while(1){d=j-1&255;k=e&-32768|(e&65535)>>>1;f=(e&1|i&-14)&255|(e&65535)>>>12&8;if(k<<16>>16==0){l=(f|4)&255}else{l=f&255}if(d<<24>>24==0){break}else{j=d;i=l;e=k}}a[9642680]=l;b[4821328]=k;return}function fPv(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)!=0){h=gj[g&4095](e)|0;i=h;j=b[4821324]|0;break}b[4821324]=e+1&65535;return}else{i=a[f+(d&255)|0]|0;j=e}}while(0);b[4821324]=j+1&65535;if(i<<24>>24==0){return}j=i;i=b[4821328]|0;e=a[9642680]|0;do{j=j-1&255;d=i&65535;f=d<<1;h=(d>>>11&8|e&-16&255)&255;i=f&65535;e=((f^d)>>>14&2|d>>>15|(i<<16>>16==0?h|4:h)&255)&255;}while(j<<24>>24!=0);b[4821328]=i;a[9642680]=e;return}function fPw(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)!=0){h=gj[g&4095](e)|0;i=h;j=b[4821324]|0;break}b[4821324]=e+1&65535;return}else{i=a[f+(d&255)|0]|0;j=e}}while(0);b[4821324]=j+1&65535;if(i<<24>>24==0){return}j=i;i=a[9642680]|0;e=b[4821328]|0;while(1){d=j-1&255;f=(e&65535)>>>15;h=e<<1;k=f|h;g=(h&65535)>>>12&8|(i&-14|f&255)&255;if(k<<16>>16==0){l=(g|4)&255}else{l=g&255}if(d<<24>>24==0){break}else{j=d;i=l;e=k}}a[9642680]=l;b[4821328]=k;return}function fPx(){b[4821328]=0;a[9642680]=a[9642680]&-16|4;return}function fPy(){var c=0,d=0,f=0,g=0;c=e[4821328]|0;d=-c|0;f=(a[9642680]&-16&255|d>>>12&8)&255;g=d&65535;a[9642680]=((c^d^d>>>1)>>>14&2|d>>>16&1|(g<<16>>16==0?f|4:f)&255)&255;b[4821328]=g;return}function fPz(){var c=0,d=0,f=0;c=(e[4821328]|0)+1|0;d=(c>>>12&8|a[9642680]&-15&255)&255;f=c&65535;a[9642680]=((c>>>1^c)>>>14&2|c>>>16&1|(f<<16>>16==0?d|4:d)&255)&255;b[4821328]=f;return}function fPA(){var c=0,d=0,f=0;c=(e[4821328]|0)-1|0;d=(c>>>12&8|a[9642680]&-15&255)&255;f=c&65535;a[9642680]=((c>>>1^c)>>>14&2|c>>>16&1|(f<<16>>16==0?d|4:d)&255)&255;b[4821328]=f;return}function fPB(){var c=0,d=0,e=0,f=0;c=a[9642680]&-15;a[9642680]=c;d=b[4821328]|0;e=(d&65535)>>>12&8|c&255;if(d<<16>>16!=0){f=e&255;a[9642680]=f;return}f=(e|4)&255;a[9642680]=f;return}function fPC(){var b=0,c=0,d=0,e=0,f=0;b=a[9642657]|0;c=b&255;if((c&128|0)==0){d=b&255}else{d=-c&65535}b=d&65535;e=(a[9642680]&-16&255|b>>>4&8)&255;f=d&255;a[9642680]=((b^c^b>>>1)>>>6&2|b>>>8&1|(f<<24>>24==0?e|4:e)&255)&255;a[9642657]=f;return}function fPD(){var b=0,c=0,d=0,e=0,f=0;b=a[9642656]|0;c=b&255;if((c&128|0)==0){d=b&255}else{d=-c&65535}b=d&65535;e=(a[9642680]&-16&255|b>>>4&8)&255;f=d&255;a[9642680]=((b^c^b>>>1)>>>6&2|b>>>8&1|(f<<24>>24==0?e|4:e)&255)&255;a[9642656]=f;return}function fPE(){var c=0,d=0,f=0,g=0;c=e[4821328]|0;d=(c&32768|0)==0?c:-c|0;f=(d>>>12&8|a[9642680]&-16&255)&255;g=d&65535;a[9642680]=((d^c^d>>>1)>>>14&2|d>>>16&1|(g<<16>>16==0?f|4:f)&255)&255;b[4821328]=g;return}function fPF(){var d=0,e=0,f=0,g=0,h=0;if((b[4821332]|0)==0){return}do{d=a[9642657]|0;e=c[2410668]|0;f=e&65535;g=c[9700656+((e>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[2444172]|0;if((h|0)==0){break}gg[h&4095](f,d)}else{a[g+(e&255)|0]=d}}while(0);b[4821336]=(b[4821336]|0)+1&65535;d=(b[4821332]|0)-1&65535;b[4821332]=d;c[2439268]=(c[2439268]|0)-2;}while(d<<16>>16!=0);return}function fPG(){var d=0,e=0,f=0,g=0,h=0,i=0;if((b[4821332]|0)==0){return}do{d=c[2410668]|0;e=d&65535;f=a[9642657]|0;g=c[9700656+((d>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[2444172]|0;if((h|0)==0){break}gg[h&4095](e,f)}else{a[g+(d&255)|0]=f}}while(0);f=d+1|0;g=f&65535;e=a[9642656]|0;h=c[9700656+((f>>>8&255)<<2)>>2]|0;do{if((h|0)==0){i=c[2444172]|0;if((i|0)==0){break}gg[i&4095](g,e)}else{a[h+(f&255)|0]=e}}while(0);b[4821336]=(b[4821336]|0)+2&65535;e=(b[4821332]|0)-1&65535;b[4821332]=e;c[2439268]=(c[2439268]|0)-3;}while(e<<16>>16!=0);return}function fPH(){var c=0,d=0;c=b[4853740]|0;b[4821336]=c;d=a[9642680]|0;a[9642680]=c<<16>>16==0?d|4:d&-5;return}function fPI(){var c=0,d=0;c=b[4853740]|0;b[4821338]=c;d=a[9642680]|0;a[9642680]=c<<16>>16==0?d|4:d&-5;return}function fPJ(){b[4821332]=b[4853740]|0;return}function fPK(){b[4821334]=b[4853740]|0;a[9642688]=a[9642688]|32;return}function fPL(){var b=0,d=0,e=0,f=0,g=0;b=c[2426870]|0;d=b&65535;e=c[9699632+((b>>>8&255)<<2)>>2]|0;do{if((e|0)==0){f=c[3528598]|0;if((f|0)==0){g=0;break}g=gj[f&4095](d)|0}else{g=a[e+(b&255)|0]|0}}while(0);a[9642657]=g;b=(g&255)>>>4&8|a[9642680]&-15;a[9642680]=g<<24>>24==0?b|4:b;return}function fPM(){var b=0,d=0,e=0,f=0,g=0;b=c[2426870]|0;d=b&65535;e=c[9699632+((b>>>8&255)<<2)>>2]|0;do{if((e|0)==0){f=c[3528598]|0;if((f|0)==0){g=0;break}g=gj[f&4095](d)|0}else{g=a[e+(b&255)|0]|0}}while(0);a[9642656]=g;b=(g&255)>>>4&8|a[9642680]&-15;a[9642680]=g<<24>>24==0?b|4:b;return}function fPN(){var b=0,d=0,e=0,f=0,g=0,h=0;b=c[2426870]|0;d=b&65535;e=c[9699632+((b>>>8&255)<<2)>>2]|0;do{if((e|0)==0){f=c[3528598]|0;if((f|0)==0){g=0;break}g=gj[f&4095](d)|0}else{g=a[e+(b&255)|0]|0}}while(0);b=a[9642657]|0;e=(b&255)+(g&255)|0;d=(e>>>4&8|a[9642680]&-48&255)&255;f=e&255;h=(b^g)&255^e;a[9642680]=(h<<1&32|e>>>8&1|(h^e>>>1)>>>6&2|(f<<24>>24==0?d|4:d)&255)&255;a[9642657]=f;return}function fPO(){var b=0,d=0,e=0,f=0,g=0,h=0;b=c[2426870]|0;d=b&65535;e=c[9699632+((b>>>8&255)<<2)>>2]|0;do{if((e|0)==0){f=c[3528598]|0;if((f|0)==0){g=0;break}g=gj[f&4095](d)|0}else{g=a[e+(b&255)|0]|0}}while(0);b=a[9642656]|0;e=(b&255)+(g&255)|0;d=(e>>>4&8|a[9642680]&-48&255)&255;f=e&255;h=(b^g)&255^e;a[9642680]=(h<<1&32|e>>>8&1|(h^e>>>1)>>>6&2|(f<<24>>24==0?d|4:d)&255)&255;a[9642656]=f;return}function fPP(){var b=0,d=0,e=0,f=0,g=0,h=0;b=c[2426870]|0;d=b&65535;e=c[9699632+((b>>>8&255)<<2)>>2]|0;do{if((e|0)==0){f=c[3528598]|0;if((f|0)==0){g=0;break}g=gj[f&4095](d)|0}else{g=a[e+(b&255)|0]|0}}while(0);b=a[9642657]|0;e=a[9642680]|0;d=(b&255)+(g&255)+(e&1)|0;f=(d>>>4&8|e&-48&255)&255;e=d&255;h=d^(b^g)&255;a[9642680]=(h<<1&32|d>>>8&1|(h^d>>>1)>>>6&2|(e<<24>>24==0?f|4:f)&255)&255;a[9642657]=e;return}function fPQ(){var b=0,d=0,e=0,f=0,g=0,h=0;b=c[2426870]|0;d=b&65535;e=c[9699632+((b>>>8&255)<<2)>>2]|0;do{if((e|0)==0){f=c[3528598]|0;if((f|0)==0){g=0;break}g=gj[f&4095](d)|0}else{g=a[e+(b&255)|0]|0}}while(0);b=a[9642656]|0;e=a[9642680]|0;d=(b&255)+(g&255)+(e&1)|0;f=(d>>>4&8|e&-48&255)&255;e=d&255;h=d^(b^g)&255;a[9642680]=(h<<1&32|d>>>8&1|(h^d>>>1)>>>6&2|(e<<24>>24==0?f|4:f)&255)&255;a[9642656]=e;return}function fPR(){var b=0,d=0,e=0,f=0,g=0;b=c[2426870]|0;d=b&65535;e=c[9699632+((b>>>8&255)<<2)>>2]|0;do{if((e|0)==0){f=c[3528598]|0;if((f|0)==0){g=0;break}g=gj[f&4095](d)|0}else{g=a[e+(b&255)|0]|0}}while(0);b=a[9642657]|0;e=(b&255)-(g&255)|0;d=(e>>>4&8|a[9642680]&-16&255)&255;f=e&255;a[9642680]=(((b^g)&255^e^e>>>1)>>>6&2|e>>>8&1|(f<<24>>24==0?d|4:d)&255)&255;a[9642657]=f;return}function fPS(){var b=0,d=0,e=0,f=0,g=0;b=c[2426870]|0;d=b&65535;e=c[9699632+((b>>>8&255)<<2)>>2]|0;do{if((e|0)==0){f=c[3528598]|0;if((f|0)==0){g=0;break}g=gj[f&4095](d)|0}else{g=a[e+(b&255)|0]|0}}while(0);b=a[9642656]|0;e=(b&255)-(g&255)|0;d=(e>>>4&8|a[9642680]&-16&255)&255;f=e&255;a[9642680]=(((b^g)&255^e^e>>>1)>>>6&2|e>>>8&1|(f<<24>>24==0?d|4:d)&255)&255;a[9642656]=f;return}function fPT(){var b=0,d=0,e=0,f=0,g=0;b=c[2426870]|0;d=b&65535;e=c[9699632+((b>>>8&255)<<2)>>2]|0;do{if((e|0)==0){f=c[3528598]|0;if((f|0)==0){g=0;break}g=gj[f&4095](d)|0}else{g=a[e+(b&255)|0]|0}}while(0);b=a[9642657]|0;e=a[9642680]|0;d=(b&255)-(g&255)-(e&1)|0;f=(d>>>4&8|e&-16&255)&255;e=d&255;a[9642680]=((d^(b^g)&255^d>>>1)>>>6&2|d>>>8&1|(e<<24>>24==0?f|4:f)&255)&255;a[9642657]=e;return}function fPU(){var b=0,d=0,e=0,f=0,g=0;b=c[2426870]|0;d=b&65535;e=c[9699632+((b>>>8&255)<<2)>>2]|0;do{if((e|0)==0){f=c[3528598]|0;if((f|0)==0){g=0;break}g=gj[f&4095](d)|0}else{g=a[e+(b&255)|0]|0}}while(0);b=a[9642656]|0;e=a[9642680]|0;d=(b&255)-(g&255)-(e&1)|0;f=(d>>>4&8|e&-16&255)&255;e=d&255;a[9642680]=((d^(b^g)&255^d>>>1)>>>6&2|d>>>8&1|(e<<24>>24==0?f|4:f)&255)&255;a[9642656]=e;return}function fPV(){var b=0,d=0,e=0,f=0,g=0;b=c[2426870]|0;d=b&65535;e=c[9699632+((b>>>8&255)<<2)>>2]|0;do{if((e|0)==0){f=c[3528598]|0;if((f|0)==0){g=0;break}g=gj[f&4095](d)|0}else{g=a[e+(b&255)|0]|0}}while(0);b=a[9642657]&g;a[9642657]=b;g=(b&255)>>>4&8|a[9642680]&-15;a[9642680]=b<<24>>24==0?g|4:g;return}function fPW(){var b=0,d=0,e=0,f=0,g=0;b=c[2426870]|0;d=b&65535;e=c[9699632+((b>>>8&255)<<2)>>2]|0;do{if((e|0)==0){f=c[3528598]|0;if((f|0)==0){g=0;break}g=gj[f&4095](d)|0}else{g=a[e+(b&255)|0]|0}}while(0);b=a[9642656]&g;a[9642656]=b;g=(b&255)>>>4&8|a[9642680]&-15;a[9642680]=b<<24>>24==0?g|4:g;return}function fPX(){var b=0,d=0,e=0,f=0,g=0,h=0;b=a[9642657]|0;d=c[2426870]|0;e=d&65535;f=c[9699632+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;break}h=gj[g&4095](e)|0}else{h=a[f+(d&255)|0]|0}}while(0);d=h&b;b=(d&255)>>>4&8|a[9642680]&-15;a[9642680]=d<<24>>24==0?b|4:b;return}function fPY(){var b=0,d=0,e=0,f=0,g=0,h=0;b=a[9642656]|0;d=c[2426870]|0;e=d&65535;f=c[9699632+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;break}h=gj[g&4095](e)|0}else{h=a[f+(d&255)|0]|0}}while(0);d=h&b;b=(d&255)>>>4&8|a[9642680]&-15;a[9642680]=d<<24>>24==0?b|4:b;return}function fPZ(){var b=0,d=0,e=0,f=0,g=0;b=c[2426870]|0;d=b&65535;e=c[9699632+((b>>>8&255)<<2)>>2]|0;do{if((e|0)==0){f=c[3528598]|0;if((f|0)==0){g=0;break}g=gj[f&4095](d)|0}else{g=a[e+(b&255)|0]|0}}while(0);b=a[9642657]|0;e=b^g;a[9642657]=e;d=(e&255)>>>4&8|a[9642680]&-15;a[9642680]=b<<24>>24==g<<24>>24?d|4:d;return}function fP_(){var b=0,d=0,e=0,f=0,g=0;b=c[2426870]|0;d=b&65535;e=c[9699632+((b>>>8&255)<<2)>>2]|0;do{if((e|0)==0){f=c[3528598]|0;if((f|0)==0){g=0;break}g=gj[f&4095](d)|0}else{g=a[e+(b&255)|0]|0}}while(0);b=a[9642656]|0;e=b^g;a[9642656]=e;d=(e&255)>>>4&8|a[9642680]&-15;a[9642680]=b<<24>>24==g<<24>>24?d|4:d;return}function fP$(){var b=0,d=0,e=0,f=0,g=0;b=c[2426870]|0;d=b&65535;e=c[9699632+((b>>>8&255)<<2)>>2]|0;do{if((e|0)==0){f=c[3528598]|0;if((f|0)==0){g=0;break}g=gj[f&4095](d)|0}else{g=a[e+(b&255)|0]|0}}while(0);b=a[9642657]|g;a[9642657]=b;g=(b&255)>>>4&8|a[9642680]&-15;a[9642680]=b<<24>>24==0?g|4:g;return}function fP0(){var b=0,d=0,e=0,f=0,g=0;b=c[2426870]|0;d=b&65535;e=c[9699632+((b>>>8&255)<<2)>>2]|0;do{if((e|0)==0){f=c[3528598]|0;if((f|0)==0){g=0;break}g=gj[f&4095](d)|0}else{g=a[e+(b&255)|0]|0}}while(0);b=a[9642656]|g;a[9642656]=b;g=(b&255)>>>4&8|a[9642680]&-15;a[9642680]=b<<24>>24==0?g|4:g;return}function fP1(){var b=0,d=0,e=0,f=0,g=0;b=c[2426870]|0;d=b&65535;e=c[9699632+((b>>>8&255)<<2)>>2]|0;do{if((e|0)==0){f=c[3528598]|0;if((f|0)==0){g=0;break}g=gj[f&4095](d)|0}else{g=a[e+(b&255)|0]|0}}while(0);b=a[9642657]|0;e=(b&255)-(g&255)|0;d=(e>>>4&8|a[9642680]&-16&255)&255;a[9642680]=(((b^g)&255^e^e>>>1)>>>6&2|e>>>8&1|((e&255)<<24>>24==0?d|4:d)&255)&255;return}function fP2(){var b=0,d=0,e=0,f=0,g=0;b=c[2426870]|0;d=b&65535;e=c[9699632+((b>>>8&255)<<2)>>2]|0;do{if((e|0)==0){f=c[3528598]|0;if((f|0)==0){g=0;break}g=gj[f&4095](d)|0}else{g=a[e+(b&255)|0]|0}}while(0);b=a[9642656]|0;e=(b&255)-(g&255)|0;d=(e>>>4&8|a[9642680]&-16&255)&255;a[9642680]=(((b^g)&255^e^e>>>1)>>>6&2|e>>>8&1|((e&255)<<24>>24==0?d|4:d)&255)&255;return}function fP3(){var d=0,e=0,f=0,g=0,h=0;d=b[4853740]|0;e=d&65535;f=c[9699632+(e>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;break}h=gj[g&4095](d)|0}else{h=a[f+(e&255)|0]|0}}while(0);e=c[2410675]|0;if((e|0)==0){return}gf[e&2047](h&255);return}function fP4(){var b=0,d=0,e=0;b=a[9642657]|0;d=(b&255)>>>4&8|a[9642680]&-15;a[9642680]=b<<24>>24==0?d|4:d;d=c[2426870]|0;e=c[9700656+((d>>>8&255)<<2)>>2]|0;if((e|0)!=0){a[e+(d&255)|0]=b;return}e=c[2444172]|0;if((e|0)==0){return}gg[e&4095](d&65535,b);return}function fP5(){var b=0,d=0,e=0;b=a[9642656]|0;d=(b&255)>>>4&8|a[9642680]&-15;a[9642680]=b<<24>>24==0?d|4:d;d=c[2426870]|0;e=c[9700656+((d>>>8&255)<<2)>>2]|0;if((e|0)!=0){a[e+(d&255)|0]=b;return}e=c[2444172]|0;if((e|0)==0){return}gg[e&4095](d&65535,b);return}function fP6(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=c[2426870]|0;e=d&65535;f=c[9699632+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;break}h=gj[g&4095](e)|0}else{h=a[f+(d&255)|0]|0}}while(0);f=(h&255)<<8;h=d+1|0;d=h&65535;e=c[9699632+((h>>>8&255)<<2)>>2]|0;do{if((e|0)==0){g=c[3528598]|0;if((g|0)==0){i=0;break}i=gj[g&4095](d)|0}else{i=a[e+(h&255)|0]|0}}while(0);h=i&255|f;b[4821328]=h;i=a[9642680]&-15;a[9642680]=i;e=i&255|(f&65535)>>>12&8;if(h<<16>>16!=0){j=e&255;a[9642680]=j;return}j=(e|4)&255;a[9642680]=j;return}function fP7(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=c[2426870]|0;e=d&65535;f=c[9699632+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;break}h=gj[g&4095](e)|0}else{h=a[f+(d&255)|0]|0}}while(0);f=(h&255)<<8;h=d+1|0;d=h&65535;e=c[9699632+((h>>>8&255)<<2)>>2]|0;do{if((e|0)==0){g=c[3528598]|0;if((g|0)==0){i=0;break}i=gj[g&4095](d)|0}else{i=a[e+(h&255)|0]|0}}while(0);h=i&255|f;b[4821336]=h;i=a[9642680]&-15;a[9642680]=i;e=i&255|(f&65535)>>>12&8;if(h<<16>>16!=0){j=e&255;a[9642680]=j;return}j=(e|4)&255;a[9642680]=j;return}function fP8(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=c[2426870]|0;e=d&65535;f=c[9699632+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;break}h=gj[g&4095](e)|0}else{h=a[f+(d&255)|0]|0}}while(0);f=(h&255)<<8;h=d+1|0;d=h&65535;e=c[9699632+((h>>>8&255)<<2)>>2]|0;do{if((e|0)==0){g=c[3528598]|0;if((g|0)==0){i=0;break}i=gj[g&4095](d)|0}else{i=a[e+(h&255)|0]|0}}while(0);h=i&255|f;b[4821338]=h;i=a[9642680]&-15;a[9642680]=i;e=i&255|(f&65535)>>>12&8;if(h<<16>>16!=0){j=e&255;a[9642680]=j;return}j=(e|4)&255;a[9642680]=j;return}function fP9(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=c[2426870]|0;e=d&65535;f=c[9699632+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;break}h=gj[g&4095](e)|0}else{h=a[f+(d&255)|0]|0}}while(0);f=(h&255)<<8;h=d+1|0;d=h&65535;e=c[9699632+((h>>>8&255)<<2)>>2]|0;do{if((e|0)==0){g=c[3528598]|0;if((g|0)==0){i=0;break}i=gj[g&4095](d)|0}else{i=a[e+(h&255)|0]|0}}while(0);h=i&255|f;b[4821332]=h;i=a[9642680]&-15;a[9642680]=i;e=i&255|(f&65535)>>>12&8;if(h<<16>>16!=0){j=e&255;a[9642680]=j;return}j=(e|4)&255;a[9642680]=j;return}function fQa(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[2426870]|0;e=d&65535;f=c[9699632+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;break}h=gj[g&4095](e)|0}else{h=a[f+(d&255)|0]|0}}while(0);f=(h&255)<<8;h=d+1|0;d=h&65535;e=c[9699632+((h>>>8&255)<<2)>>2]|0;do{if((e|0)==0){g=c[3528598]|0;if((g|0)==0){i=0;break}i=gj[g&4095](d)|0}else{i=a[e+(h&255)|0]|0}}while(0);h=i&255|f;b[4821334]=h;i=a[9642680]&-15;a[9642680]=i;e=i&255|(f&65535)>>>12&8;if(h<<16>>16!=0){j=e&255;a[9642680]=j;k=a[9642688]|0;l=k|32;a[9642688]=l;return}j=(e|4)&255;a[9642680]=j;k=a[9642688]|0;l=k|32;a[9642688]=l;return}function fQb(){var b=0,d=0,f=0,g=0,h=0,i=0;b=c[2426870]|0;d=b&65535;f=c[9699632+((b>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;break}h=gj[g&4095](d)|0}else{h=a[f+(b&255)|0]|0}}while(0);f=(h&255)<<8;h=b+1|0;b=h&65535;d=c[9699632+((h>>>8&255)<<2)>>2]|0;do{if((d|0)==0){g=c[3528598]|0;if((g|0)==0){i=0;break}i=gj[g&4095](b)|0}else{i=a[d+(h&255)|0]|0}}while(0);h=e[4821328]|0;d=h-(i&255|f)|0;i=(d>>>12&8|a[9642680]&-16&255)&255;a[9642680]=((h^f^d^d>>>1)>>>14&2|d>>>16&1|((d&65535)<<16>>16==0?i|4:i)&255)&255;return}function fQc(){var b=0,d=0,f=0,g=0,h=0,i=0;b=c[2426870]|0;d=b&65535;f=c[9699632+((b>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;break}h=gj[g&4095](d)|0}else{h=a[f+(b&255)|0]|0}}while(0);f=(h&255)<<8;h=b+1|0;b=h&65535;d=c[9699632+((h>>>8&255)<<2)>>2]|0;do{if((d|0)==0){g=c[3528598]|0;if((g|0)==0){i=0;break}i=gj[g&4095](b)|0}else{i=a[d+(h&255)|0]|0}}while(0);h=e[4821336]|0;d=h-(i&255|f)|0;i=(d>>>12&8|a[9642680]&-16&255)&255;a[9642680]=((h^f^d^d>>>1)>>>14&2|d>>>16&1|((d&65535)<<16>>16==0?i|4:i)&255)&255;return}function fQd(){var b=0,d=0,f=0,g=0,h=0,i=0;b=c[2426870]|0;d=b&65535;f=c[9699632+((b>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;break}h=gj[g&4095](d)|0}else{h=a[f+(b&255)|0]|0}}while(0);f=(h&255)<<8;h=b+1|0;b=h&65535;d=c[9699632+((h>>>8&255)<<2)>>2]|0;do{if((d|0)==0){g=c[3528598]|0;if((g|0)==0){i=0;break}i=gj[g&4095](b)|0}else{i=a[d+(h&255)|0]|0}}while(0);h=e[4821338]|0;d=h-(i&255|f)|0;i=(d>>>12&8|a[9642680]&-16&255)&255;a[9642680]=((h^f^d^d>>>1)>>>14&2|d>>>16&1|((d&65535)<<16>>16==0?i|4:i)&255)&255;return}function fQe(){var b=0,d=0,f=0,g=0,h=0,i=0;b=c[2426870]|0;d=b&65535;f=c[9699632+((b>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;break}h=gj[g&4095](d)|0}else{h=a[f+(b&255)|0]|0}}while(0);f=(h&255)<<8;h=b+1|0;b=h&65535;d=c[9699632+((h>>>8&255)<<2)>>2]|0;do{if((d|0)==0){g=c[3528598]|0;if((g|0)==0){i=0;break}i=gj[g&4095](b)|0}else{i=a[d+(h&255)|0]|0}}while(0);h=e[4821332]|0;d=h-(i&255|f)|0;i=(d>>>12&8|a[9642680]&-16&255)&255;a[9642680]=((h^f^d^d>>>1)>>>14&2|d>>>16&1|((d&65535)<<16>>16==0?i|4:i)&255)&255;return}function fQf(){var b=0,d=0,f=0,g=0,h=0,i=0;b=c[2426870]|0;d=b&65535;f=c[9699632+((b>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;break}h=gj[g&4095](d)|0}else{h=a[f+(b&255)|0]|0}}while(0);f=(h&255)<<8;h=b+1|0;b=h&65535;d=c[9699632+((h>>>8&255)<<2)>>2]|0;do{if((d|0)==0){g=c[3528598]|0;if((g|0)==0){i=0;break}i=gj[g&4095](b)|0}else{i=a[d+(h&255)|0]|0}}while(0);h=e[4821334]|0;d=h-(i&255|f)|0;i=(d>>>12&8|a[9642680]&-16&255)&255;a[9642680]=((h^f^d^d>>>1)>>>14&2|d>>>16&1|((d&65535)<<16>>16==0?i|4:i)&255)&255;return}function fQg(){var d=0,f=0,g=0,h=0,i=0,j=0;d=c[2426870]|0;f=d&65535;g=c[9699632+((d>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[3528598]|0;if((h|0)==0){i=0;break}i=gj[h&4095](f)|0}else{i=a[g+(d&255)|0]|0}}while(0);g=(i&255)<<8;i=d+1|0;d=i&65535;f=c[9699632+((i>>>8&255)<<2)>>2]|0;do{if((f|0)==0){h=c[3528598]|0;if((h|0)==0){j=0;break}j=gj[h&4095](d)|0}else{j=a[f+(i&255)|0]|0}}while(0);i=e[4821328]|0;f=i+(j&255|g)|0;j=(f>>>12&8|a[9642680]&-16&255)&255;d=f&65535;a[9642680]=((i^g^f^f>>>1)>>>14&2|f>>>16&1|(d<<16>>16==0?j|4:j)&255)&255;b[4821328]=d;return}function fQh(){var d=0,f=0,g=0,h=0,i=0,j=0;d=c[2426870]|0;f=d&65535;g=c[9699632+((d>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[3528598]|0;if((h|0)==0){i=0;break}i=gj[h&4095](f)|0}else{i=a[g+(d&255)|0]|0}}while(0);g=(i&255)<<8;i=d+1|0;d=i&65535;f=c[9699632+((i>>>8&255)<<2)>>2]|0;do{if((f|0)==0){h=c[3528598]|0;if((h|0)==0){j=0;break}j=gj[h&4095](d)|0}else{j=a[f+(i&255)|0]|0}}while(0);i=e[4821328]|0;f=i-(j&255|g)|0;j=(f>>>12&8|a[9642680]&-16&255)&255;d=f&65535;a[9642680]=((i^g^f^f>>>1)>>>14&2|f>>>16&1|(d<<16>>16==0?j|4:j)&255)&255;b[4821328]=d;return}function fQi(){var d=0,e=0,f=0,g=0,h=0;d=a[9642680]&-15;a[9642680]=d;e=b[4821328]|0;f=(e&65535)>>>12&8|d&255;if(e<<16>>16==0){g=(f|4)&255}else{g=f&255}a[9642680]=g;g=c[2426870]|0;f=g&65535;e=a[9642657]|0;d=c[9700656+((g>>>8&255)<<2)>>2]|0;do{if((d|0)==0){h=c[2444172]|0;if((h|0)==0){break}gg[h&4095](f,e)}else{a[d+(g&255)|0]=e}}while(0);e=g+1|0;g=a[9642656]|0;d=c[9700656+((e>>>8&255)<<2)>>2]|0;if((d|0)!=0){a[d+(e&255)|0]=g;return}d=c[2444172]|0;if((d|0)==0){return}gg[d&4095](e&65535,g);return}function fQj(){var d=0,e=0,f=0,g=0,h=0;d=a[9642680]&-15;a[9642680]=d;e=b[4821336]|0;f=(e&65535)>>>12&8|d&255;if(e<<16>>16==0){g=(f|4)&255}else{g=f&255}a[9642680]=g;g=c[2426870]|0;f=g&65535;e=a[9642673]|0;d=c[9700656+((g>>>8&255)<<2)>>2]|0;do{if((d|0)==0){h=c[2444172]|0;if((h|0)==0){break}gg[h&4095](f,e)}else{a[d+(g&255)|0]=e}}while(0);e=g+1|0;g=a[9642672]|0;d=c[9700656+((e>>>8&255)<<2)>>2]|0;if((d|0)!=0){a[d+(e&255)|0]=g;return}d=c[2444172]|0;if((d|0)==0){return}gg[d&4095](e&65535,g);return}function fQk(){var d=0,e=0,f=0,g=0,h=0;d=a[9642680]&-15;a[9642680]=d;e=b[4821338]|0;f=(e&65535)>>>12&8|d&255;if(e<<16>>16==0){g=(f|4)&255}else{g=f&255}a[9642680]=g;g=c[2426870]|0;f=g&65535;e=a[9642677]|0;d=c[9700656+((g>>>8&255)<<2)>>2]|0;do{if((d|0)==0){h=c[2444172]|0;if((h|0)==0){break}gg[h&4095](f,e)}else{a[d+(g&255)|0]=e}}while(0);e=g+1|0;g=a[9642676]|0;d=c[9700656+((e>>>8&255)<<2)>>2]|0;if((d|0)!=0){a[d+(e&255)|0]=g;return}d=c[2444172]|0;if((d|0)==0){return}gg[d&4095](e&65535,g);return}function fQl(){var d=0,e=0,f=0,g=0,h=0;d=a[9642680]&-15;a[9642680]=d;e=b[4821332]|0;f=(e&65535)>>>12&8|d&255;if(e<<16>>16==0){g=(f|4)&255}else{g=f&255}a[9642680]=g;g=c[2426870]|0;f=g&65535;e=a[9642665]|0;d=c[9700656+((g>>>8&255)<<2)>>2]|0;do{if((d|0)==0){h=c[2444172]|0;if((h|0)==0){break}gg[h&4095](f,e)}else{a[d+(g&255)|0]=e}}while(0);e=g+1|0;g=a[9642664]|0;d=c[9700656+((e>>>8&255)<<2)>>2]|0;if((d|0)!=0){a[d+(e&255)|0]=g;return}d=c[2444172]|0;if((d|0)==0){return}gg[d&4095](e&65535,g);return}function fQm(){var d=0,e=0,f=0,g=0,h=0;d=a[9642680]&-15;a[9642680]=d;e=b[4821334]|0;f=(e&65535)>>>12&8|d&255;if(e<<16>>16==0){g=(f|4)&255}else{g=f&255}a[9642680]=g;g=c[2426870]|0;f=g&65535;e=a[9642669]|0;d=c[9700656+((g>>>8&255)<<2)>>2]|0;do{if((d|0)==0){h=c[2444172]|0;if((h|0)==0){break}gg[h&4095](f,e)}else{a[d+(g&255)|0]=e}}while(0);e=g+1|0;g=a[9642668]|0;d=c[9700656+((e>>>8&255)<<2)>>2]|0;if((d|0)!=0){a[d+(e&255)|0]=g;return}d=c[2444172]|0;if((d|0)==0){return}gg[d&4095](e&65535,g);return}function fQn(){var b=0,d=0,e=0,f=0;b=c[2426870]|0;d=b&65535;e=c[9700656+((b>>>8&255)<<2)>>2]|0;do{if((e|0)==0){f=c[2444172]|0;if((f|0)==0){break}gg[f&4095](d,0)}else{a[e+(b&255)|0]=0}}while(0);a[9642680]=a[9642680]&-16|4;return}function fQo(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=c[2426870]|0;d=b&65535;e=c[9699632+((b>>>8&255)<<2)>>2]|0;do{if((e|0)==0){f=c[3528598]|0;if((f|0)==0){g=0;h=b;break}i=gj[f&4095](d)|0;g=i;h=c[2426870]|0}else{g=a[e+(b&255)|0]|0;h=b}}while(0);b=~g;e=a[9642680]&-15|(b&255)>>>4&8;a[9642680]=(g<<24>>24==-1?e|4:e)|1;e=c[9700656+((h>>>8&255)<<2)>>2]|0;if((e|0)!=0){a[e+(h&255)|0]=b;return}e=c[2444172]|0;if((e|0)==0){return}gg[e&4095](h&65535,b);return}function fQp(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=c[2426870]|0;d=b&65535;e=c[9699632+((b>>>8&255)<<2)>>2]|0;do{if((e|0)==0){f=c[3528598]|0;if((f|0)==0){g=0;h=b;break}i=gj[f&4095](d)|0;g=i;h=c[2426870]|0}else{g=a[e+(b&255)|0]|0;h=b}}while(0);b=g&255;g=-b|0;e=(a[9642680]&-16&255|g>>>4&8)&255;d=g&255;a[9642680]=((b^g^g>>>1)>>>6&2|g>>>8&1|(d<<24>>24==0?e|4:e)&255)&255;e=c[9700656+((h>>>8&255)<<2)>>2]|0;if((e|0)!=0){a[e+(h&255)|0]=d;return}e=c[2444172]|0;if((e|0)==0){return}gg[e&4095](h&65535,d);return}function fQq(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=c[2426870]|0;d=b&65535;e=c[9699632+((b>>>8&255)<<2)>>2]|0;do{if((e|0)==0){f=c[3528598]|0;if((f|0)==0){g=0;h=b;break}i=gj[f&4095](d)|0;g=i;h=c[2426870]|0}else{g=a[e+(b&255)|0]|0;h=b}}while(0);b=g+1&255;a[9642680]=a[9642680]&-15|a[668928+(b&255)|0];g=c[9700656+((h>>>8&255)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=b;return}g=c[2444172]|0;if((g|0)==0){return}gg[g&4095](h&65535,b);return}function fQr(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=c[2426870]|0;d=b&65535;e=c[9699632+((b>>>8&255)<<2)>>2]|0;do{if((e|0)==0){f=c[3528598]|0;if((f|0)==0){g=0;h=b;break}i=gj[f&4095](d)|0;g=i;h=c[2426870]|0}else{g=a[e+(b&255)|0]|0;h=b}}while(0);b=g-1&255;a[9642680]=a[9642680]&-15|a[669184+(b&255)|0];g=c[9700656+((h>>>8&255)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=b;return}g=c[2444172]|0;if((g|0)==0){return}gg[g&4095](h&65535,b);return}function fQs(){var b=0,d=0,e=0,f=0,g=0;b=c[2426870]|0;d=b&65535;e=c[9699632+((b>>>8&255)<<2)>>2]|0;do{if((e|0)==0){f=c[3528598]|0;if((f|0)==0){g=0;break}g=gj[f&4095](d)|0}else{g=a[e+(b&255)|0]|0}}while(0);b=a[9642680]&-15|(g&255)>>>4&8;a[9642680]=g<<24>>24==0?b|4:b;return}function fQt(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=c[2426870]|0;d=b&65535;e=c[9699632+((b>>>8&255)<<2)>>2]|0;do{if((e|0)==0){f=c[3528598]|0;if((f|0)==0){g=0;h=b;break}i=gj[f&4095](d)|0;g=i;h=c[2426870]|0}else{g=a[e+(b&255)|0]|0;h=b}}while(0);b=a[9642680]&-14|g&1;e=(g&255)>>>1;a[9642680]=e<<24>>24==0?b|4:b;b=c[9700656+((h>>>8&255)<<2)>>2]|0;if((b|0)!=0){a[b+(h&255)|0]=e;return}b=c[2444172]|0;if((b|0)==0){return}gg[b&4095](h&65535,e);return}function fQu(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=c[2426870]|0;d=b&65535;e=c[9699632+((b>>>8&255)<<2)>>2]|0;do{if((e|0)==0){f=c[3528598]|0;if((f|0)==0){g=0;h=b;break}i=gj[f&4095](d)|0;g=i;h=c[2426870]|0}else{g=a[e+(b&255)|0]|0;h=b}}while(0);b=a[9642680]|0;e=b<<7|(g&255)>>>1;d=b&-14|g&1|b<<3&8;a[9642680]=e<<24>>24==0?d|4:d;d=c[9700656+((h>>>8&255)<<2)>>2]|0;if((d|0)!=0){a[d+(h&255)|0]=e;return}d=c[2444172]|0;if((d|0)==0){return}gg[d&4095](h&65535,e);return}function fQv(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=c[2426870]|0;d=b&65535;e=c[9699632+((b>>>8&255)<<2)>>2]|0;do{if((e|0)==0){f=c[3528598]|0;if((f|0)==0){g=0;h=b;break}i=gj[f&4095](d)|0;g=i;h=c[2426870]|0}else{g=a[e+(b&255)|0]|0;h=b}}while(0);b=g&-128|(g&255)>>>1;e=a[9642680]&-14|g&1|(g&255)>>>4&8;a[9642680]=b<<24>>24==0?e|4:e;e=c[9700656+((h>>>8&255)<<2)>>2]|0;if((e|0)!=0){a[e+(h&255)|0]=b;return}e=c[2444172]|0;if((e|0)==0){return}gg[e&4095](h&65535,b);return}function fQw(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=c[2426870]|0;d=b&65535;e=c[9699632+((b>>>8&255)<<2)>>2]|0;do{if((e|0)==0){f=c[3528598]|0;if((f|0)==0){g=0;h=b;break}i=gj[f&4095](d)|0;g=i;h=c[2426870]|0}else{g=a[e+(b&255)|0]|0;h=b}}while(0);b=(g&255)<<1;g=b&65535;e=(g>>>4&8|a[9642680]&-16&255)&255;d=b&255;a[9642680]=((g>>>1^g)>>>6&2|g>>>8|(d<<24>>24==0?e|4:e)&255)&255;e=c[9700656+((h>>>8&255)<<2)>>2]|0;if((e|0)!=0){a[e+(h&255)|0]=d;return}e=c[2444172]|0;if((e|0)==0){return}gg[e&4095](h&65535,d);return}function fQx(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=c[2426870]|0;d=b&65535;e=c[9699632+((b>>>8&255)<<2)>>2]|0;do{if((e|0)==0){f=c[3528598]|0;if((f|0)==0){g=0;h=b;break}i=gj[f&4095](d)|0;g=i;h=c[2426870]|0}else{g=a[e+(b&255)|0]|0;h=b}}while(0);b=a[9642680]|0;e=b&1|(g&255)<<1;g=e&65535;d=(g>>>4&8|b&-16&255)&255;b=e&255;a[9642680]=((g>>>1^g)>>>6&2|g>>>8|(b<<24>>24==0?d|4:d)&255)&255;d=c[9700656+((h>>>8&255)<<2)>>2]|0;if((d|0)!=0){a[d+(h&255)|0]=b;return}d=c[2444172]|0;if((d|0)==0){return}gg[d&4095](h&65535,b);return}function fQy(){var b=0,d=0,e=0,f=0,g=0,h=0;b=c[2426870]|0;d=b&65535;e=c[9699632+((b>>>8&255)<<2)>>2]|0;do{if((e|0)==0){f=c[3528598]|0;if((f|0)==0){g=0;break}g=gj[f&4095](d)|0}else{g=a[e+(b&255)|0]|0}}while(0);e=b+1|0;b=e&65535;d=c[9699632+((e>>>8&255)<<2)>>2]|0;do{if((d|0)==0){f=c[3528598]|0;if((f|0)==0){h=0;break}h=gj[f&4095](b)|0}else{h=a[d+(e&255)|0]|0}}while(0);e=a[9642680]&-14|h&1;d=(h&255|(g&255)<<8)>>>1;h=d&255;b=(g&255)>>>1;a[9642680]=(d|0)==0?e|4:e;e=c[2426870]|0;d=e&65535;g=c[9700656+((e>>>8&255)<<2)>>2]|0;do{if((g|0)==0){f=c[2444172]|0;if((f|0)==0){break}gg[f&4095](d,b)}else{a[g+(e&255)|0]=b}}while(0);b=e+1|0;e=c[9700656+((b>>>8&255)<<2)>>2]|0;if((e|0)!=0){a[e+(b&255)|0]=h;return}e=c[2444172]|0;if((e|0)==0){return}gg[e&4095](b&65535,h);return}function fQz(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[2426870]|0;d=b&65535;e=c[9699632+((b>>>8&255)<<2)>>2]|0;do{if((e|0)==0){f=c[3528598]|0;if((f|0)==0){g=0;break}g=gj[f&4095](d)|0}else{g=a[e+(b&255)|0]|0}}while(0);e=(g&255)<<8;g=b+1|0;b=g&65535;d=c[9699632+((g>>>8&255)<<2)>>2]|0;do{if((d|0)==0){f=c[3528598]|0;if((f|0)==0){h=0;break}h=gj[f&4095](b)|0}else{h=a[d+(g&255)|0]|0}}while(0);g=a[9642680]|0;d=(h&255|e)>>>1;e=(g&255)<<15&32768|d;b=d&255;f=e>>>8;i=f&255;j=e>>>12&8|(g&-14|h&1)&255;a[9642680]=((f<<8&65280|d&255|0)==0?j|4:j)&255;j=c[2426870]|0;d=j&65535;f=c[9700656+((j>>>8&255)<<2)>>2]|0;do{if((f|0)==0){h=c[2444172]|0;if((h|0)==0){break}gg[h&4095](d,i)}else{a[f+(j&255)|0]=i}}while(0);i=j+1|0;j=c[9700656+((i>>>8&255)<<2)>>2]|0;if((j|0)!=0){a[j+(i&255)|0]=b;return}j=c[2444172]|0;if((j|0)==0){return}gg[j&4095](i&65535,b);return}function fQA(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=c[2426870]|0;d=b&65535;e=c[9699632+((b>>>8&255)<<2)>>2]|0;do{if((e|0)==0){f=c[3528598]|0;if((f|0)==0){g=0;break}g=gj[f&4095](d)|0}else{g=a[e+(b&255)|0]|0}}while(0);e=b+1|0;b=e&65535;d=c[9699632+((e>>>8&255)<<2)>>2]|0;do{if((d|0)==0){f=c[3528598]|0;if((f|0)==0){h=0;break}h=gj[f&4095](b)|0}else{h=a[d+(e&255)|0]|0}}while(0);e=(g&255)<<8;g=(h&255|e)>>>1;d=g|e&32768;e=g&255;b=d>>>8;f=b&255;i=d>>>12&8|(a[9642680]&-14|h&1)&255;a[9642680]=((b<<8&65280|g&255|0)==0?i|4:i)&255;i=c[2426870]|0;g=i&65535;b=c[9700656+((i>>>8&255)<<2)>>2]|0;do{if((b|0)==0){h=c[2444172]|0;if((h|0)==0){break}gg[h&4095](g,f)}else{a[b+(i&255)|0]=f}}while(0);f=i+1|0;i=c[9700656+((f>>>8&255)<<2)>>2]|0;if((i|0)!=0){a[i+(f&255)|0]=e;return}i=c[2444172]|0;if((i|0)==0){return}gg[i&4095](f&65535,e);return}function fQB(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[2426870]|0;d=b&65535;e=c[9699632+((b>>>8&255)<<2)>>2]|0;do{if((e|0)==0){f=c[3528598]|0;if((f|0)==0){g=0;break}g=gj[f&4095](d)|0}else{g=a[e+(b&255)|0]|0}}while(0);e=g&255;d=e<<8;f=b+1|0;b=f&65535;h=c[9699632+((f>>>8&255)<<2)>>2]|0;do{if((h|0)==0){i=c[3528598]|0;if((i|0)==0){j=0;break}j=gj[i&4095](b)|0}else{j=a[h+(f&255)|0]|0}}while(0);f=j&255|d;d=f<<1;j=d&255;h=f>>>7;f=h&255;b=(g&255)>>>7&255;g=h<<8;h=a[9642680]&-16&255|e>>>3&8;a[9642680]=((g^b<<15)>>>14&2|b|(((g|d&254)&65535)<<16>>16==0?h|4:h)&252)&255;h=c[2426870]|0;d=h&65535;g=c[9700656+((h>>>8&255)<<2)>>2]|0;do{if((g|0)==0){b=c[2444172]|0;if((b|0)==0){break}gg[b&4095](d,f)}else{a[g+(h&255)|0]=f}}while(0);f=h+1|0;h=c[9700656+((f>>>8&255)<<2)>>2]|0;if((h|0)!=0){a[h+(f&255)|0]=j;return}h=c[2444172]|0;if((h|0)==0){return}gg[h&4095](f&65535,j);return}function fQC(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[2426870]|0;d=b&65535;e=c[9699632+((b>>>8&255)<<2)>>2]|0;do{if((e|0)==0){f=c[3528598]|0;if((f|0)==0){g=0;break}g=gj[f&4095](d)|0}else{g=a[e+(b&255)|0]|0}}while(0);e=g&255;d=e<<8;f=b+1|0;b=f&65535;h=c[9699632+((f>>>8&255)<<2)>>2]|0;do{if((h|0)==0){i=c[3528598]|0;if((i|0)==0){j=0;break}j=gj[i&4095](b)|0}else{j=a[h+(f&255)|0]|0}}while(0);f=j&255|d;d=a[9642680]|0;j=d&1|f<<1;h=j&255;b=f>>>7;f=b&255;i=(g&255)>>>7&255;g=b<<8;b=d&-16&255|e>>>3&8;a[9642680]=((g^i<<15)>>>14&2|i|(((j&255|g)&65535)<<16>>16==0?b|4:b)&252)&255;b=c[2426870]|0;g=b&65535;j=c[9700656+((b>>>8&255)<<2)>>2]|0;do{if((j|0)==0){i=c[2444172]|0;if((i|0)==0){break}gg[i&4095](g,f)}else{a[j+(b&255)|0]=f}}while(0);f=b+1|0;b=c[9700656+((f>>>8&255)<<2)>>2]|0;if((b|0)!=0){a[b+(f&255)|0]=h;return}b=c[2444172]|0;if((b|0)==0){return}gg[b&4095](f&65535,h);return}function fQD(){var a=0;a=c[2426870]|0;c[2410662]=a;b[4821324]=a&65535;return}function fQE(){var d=0,e=0,f=0,g=0,h=0;b[4821334]=(b[4821334]|0)-1&65535;d=c[2410667]|0;e=d&65535;f=a[9642648]|0;g=c[9700656+((d>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[2444172]|0;if((h|0)==0){break}gg[h&4095](e,f)}else{a[g+(d&255)|0]=f}}while(0);b[4821334]=(b[4821334]|0)-1&65535;f=c[2410667]|0;d=f&65535;g=a[9642649]|0;e=c[9700656+((f>>>8&255)<<2)>>2]|0;do{if((e|0)==0){h=c[2444172]|0;if((h|0)==0){break}gg[h&4095](d,g)}else{a[e+(f&255)|0]=g}}while(0);g=c[2426870]|0;c[2410662]=g;b[4821324]=g&65535;return}function fQF(){var d=0,e=0,f=0,g=0,h=0;d=b[4853740]|0;e=d&65535;f=c[9699632+(e>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){return}else{h=gj[g&4095](d)|0;break}}else{h=a[f+(e&255)|0]|0}}while(0);if(h<<24>>24==0){return}e=h;h=a[9642680]|0;f=b[4821328]|0;do{e=e-1&255;d=f&1|h&-14;f=(f&65535)>>>1;h=f<<16>>16==0?d|4:d;}while(e<<24>>24!=0);a[9642680]=h;b[4821328]=f;return}function fQG(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=b[4853740]|0;e=d&65535;f=c[9699632+(e>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){return}else{h=gj[g&4095](d)|0;break}}else{h=a[f+(e&255)|0]|0}}while(0);if(h<<24>>24==0){return}e=h;h=a[9642680]|0;f=b[4821328]|0;while(1){d=e-1&255;i=(h&255)<<15|(f&65535)>>>1;g=f&1|h&-14|h<<3&8;j=i<<16>>16==0?g|4:g;if(d<<24>>24==0){break}else{e=d;h=j;f=i}}a[9642680]=j;b[4821328]=i;return}function fQH(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=b[4853740]|0;e=d&65535;f=c[9699632+(e>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){return}else{h=gj[g&4095](d)|0;break}}else{h=a[f+(e&255)|0]|0}}while(0);if(h<<24>>24==0){return}e=h;h=a[9642680]|0;f=b[4821328]|0;while(1){d=e-1&255;i=f&-32768|(f&65535)>>>1;g=(f&1|h&-14)&255|(f&65535)>>>12&8;if(i<<16>>16==0){j=(g|4)&255}else{j=g&255}if(d<<24>>24==0){break}else{e=d;h=j;f=i}}a[9642680]=j;b[4821328]=i;return}function fQI(){var d=0,e=0,f=0,g=0,h=0,i=0;d=b[4853740]|0;e=d&65535;f=c[9699632+(e>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){return}else{h=gj[g&4095](d)|0;break}}else{h=a[f+(e&255)|0]|0}}while(0);if(h<<24>>24==0){return}e=h;h=b[4821328]|0;f=a[9642680]|0;do{e=e-1&255;d=h&65535;g=d<<1;i=(d>>>11&8|f&-16&255)&255;h=g&65535;f=((g^d)>>>14&2|d>>>15|(h<<16>>16==0?i|4:i)&255)&255;}while(e<<24>>24!=0);b[4821328]=h;a[9642680]=f;return}function fQJ(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[4853740]|0;e=d&65535;f=c[9699632+(e>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){return}else{h=gj[g&4095](d)|0;break}}else{h=a[f+(e&255)|0]|0}}while(0);if(h<<24>>24==0){return}e=h;h=a[9642680]|0;f=b[4821328]|0;while(1){d=e-1&255;g=(f&65535)>>>15;i=f<<1;j=g|i;k=(i&65535)>>>12&8|(h&-14|g&255)&255;if(j<<16>>16==0){l=(k|4)&255}else{l=k&255}if(d<<24>>24==0){break}else{e=d;h=l;f=j}}a[9642680]=l;b[4821328]=j;return}function fQK(){var b=0,d=0,e=0,f=0;b=c[2426870]|0;d=b&65535;e=c[9700656+((b>>>8&255)<<2)>>2]|0;do{if((e|0)==0){f=c[2444172]|0;if((f|0)==0){break}gg[f&4095](d,0)}else{a[e+(b&255)|0]=0}}while(0);e=b+1|0;b=e&65535;d=c[9700656+((e>>>8&255)<<2)>>2]|0;do{if((d|0)==0){f=c[2444172]|0;if((f|0)==0){break}gg[f&4095](b,0)}else{a[d+(e&255)|0]=0}}while(0);a[9642680]=a[9642680]&-16|4;return}function fQL(){var b=0,d=0,e=0,f=0,g=0,h=0;b=c[2426870]|0;d=b&65535;e=c[9699632+((b>>>8&255)<<2)>>2]|0;do{if((e|0)==0){f=c[3528598]|0;if((f|0)==0){g=0;break}g=gj[f&4095](d)|0}else{g=a[e+(b&255)|0]|0}}while(0);e=(g&255)<<8;g=b+1|0;b=g&65535;d=c[9699632+((g>>>8&255)<<2)>>2]|0;do{if((d|0)==0){f=c[3528598]|0;if((f|0)==0){h=0;break}h=gj[f&4095](b)|0}else{h=a[d+(g&255)|0]|0}}while(0);g=-(h&255|e)|0;h=g&255;d=g>>>8;b=d&255;f=d<<8;d=g>>>12&8|a[9642680]&-16&255;a[9642680]=((g>>>1^e^f)>>>14&2|g>>>16&1|(((f|g&255)&65535)<<16>>16==0?d|4:d)&252)&255;d=c[2426870]|0;g=d&65535;f=c[9700656+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){e=c[2444172]|0;if((e|0)==0){break}gg[e&4095](g,b)}else{a[f+(d&255)|0]=b}}while(0);b=d+1|0;d=c[9700656+((b>>>8&255)<<2)>>2]|0;if((d|0)!=0){a[d+(b&255)|0]=h;return}d=c[2444172]|0;if((d|0)==0){return}gg[d&4095](b&65535,h);return}function fQM(){var b=0,d=0,e=0,f=0,g=0,h=0;b=c[2426870]|0;d=b&65535;e=c[9699632+((b>>>8&255)<<2)>>2]|0;do{if((e|0)==0){f=c[3528598]|0;if((f|0)==0){g=0;break}g=gj[f&4095](d)|0}else{g=a[e+(b&255)|0]|0}}while(0);e=(g&255)<<8;g=b+1|0;b=g&65535;d=c[9699632+((g>>>8&255)<<2)>>2]|0;do{if((d|0)==0){f=c[3528598]|0;if((f|0)==0){h=0;break}h=gj[f&4095](b)|0}else{h=a[d+(g&255)|0]|0}}while(0);g=(h&255|e)+1|0;e=g&255;h=g>>>8;d=h&255;b=h<<8;h=g>>>12&8|a[9642680]&-15&255;a[9642680]=((b^g>>>1)>>>14&2|g>>>16&1|(((b|g&255)&65535)<<16>>16==0?h|4:h)&253)&255;h=c[2426870]|0;g=h&65535;b=c[9700656+((h>>>8&255)<<2)>>2]|0;do{if((b|0)==0){f=c[2444172]|0;if((f|0)==0){break}gg[f&4095](g,d)}else{a[b+(h&255)|0]=d}}while(0);d=h+1|0;h=c[9700656+((d>>>8&255)<<2)>>2]|0;if((h|0)!=0){a[h+(d&255)|0]=e;return}h=c[2444172]|0;if((h|0)==0){return}gg[h&4095](d&65535,e);return}function fQN(){var b=0,d=0,e=0,f=0,g=0,h=0;b=c[2426870]|0;d=b&65535;e=c[9699632+((b>>>8&255)<<2)>>2]|0;do{if((e|0)==0){f=c[3528598]|0;if((f|0)==0){g=0;break}g=gj[f&4095](d)|0}else{g=a[e+(b&255)|0]|0}}while(0);e=(g&255)<<8;g=b+1|0;b=g&65535;d=c[9699632+((g>>>8&255)<<2)>>2]|0;do{if((d|0)==0){f=c[3528598]|0;if((f|0)==0){h=0;break}h=gj[f&4095](b)|0}else{h=a[d+(g&255)|0]|0}}while(0);g=(h&255|e)-1|0;e=g&255;h=g>>>8;d=h&255;b=h<<8;h=g>>>12&8|a[9642680]&-15&255;a[9642680]=((b^g>>>1)>>>14&2|g>>>16&1|(((b|g&255)&65535)<<16>>16==0?h|4:h)&253)&255;h=c[2426870]|0;g=h&65535;b=c[9700656+((h>>>8&255)<<2)>>2]|0;do{if((b|0)==0){f=c[2444172]|0;if((f|0)==0){break}gg[f&4095](g,d)}else{a[b+(h&255)|0]=d}}while(0);d=h+1|0;h=c[9700656+((d>>>8&255)<<2)>>2]|0;if((h|0)!=0){a[h+(d&255)|0]=e;return}h=c[2444172]|0;if((h|0)==0){return}gg[h&4095](d&65535,e);return}function fQO(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;a[9642680]=a[9642680]&-15;b=c[2426870]|0;e=b&65535;f=c[9699632+((b>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;break}h=gj[g&4095](e)|0}else{h=a[f+(b&255)|0]|0}}while(0);f=h&255;h=f<<8;e=b+1|0;b=e&65535;g=c[9699632+((e>>>8&255)<<2)>>2]|0;do{if((g|0)==0){i=c[3528598]|0;if((i|0)==0){j=0;break}j=gj[i&4095](b)|0}else{j=a[g+(e&255)|0]|0}}while(0);e=d[9642680]|0|f>>>4&8;if((j&255|h|0)!=0){k=e&255;a[9642680]=k;return}k=(e|4)&255;a[9642680]=k;return}function fQP(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c[2426870]=c[2410665];d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9707480]=h;b[4821324]=i+1&65535;i=c[2426870]|0;h=i&65535;e=c[9699632+((i>>>8&255)<<2)>>2]|0;do{if((e|0)==0){d=c[3528598]|0;if((d|0)==0){k=0;break}k=gj[d&4095](h)|0}else{k=a[e+(i&255)|0]|0}}while(0);a[9642657]=k;i=(k&255)>>>4&8|a[9642680]&-15;a[9642680]=k<<24>>24==0?i|4:i;return}function fQQ(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c[2426870]=c[2410665];d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9707480]=h;b[4821324]=i+1&65535;i=c[2426870]|0;h=i&65535;e=c[9699632+((i>>>8&255)<<2)>>2]|0;do{if((e|0)==0){d=c[3528598]|0;if((d|0)==0){k=0;break}k=gj[d&4095](h)|0}else{k=a[e+(i&255)|0]|0}}while(0);a[9642656]=k;i=(k&255)>>>4&8|a[9642680]&-15;a[9642680]=k<<24>>24==0?i|4:i;return}function fQR(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c[2426870]=c[2410665];d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9707480]=h;b[4821324]=i+1&65535;i=c[2426870]|0;h=i&65535;e=c[9699632+((i>>>8&255)<<2)>>2]|0;do{if((e|0)==0){d=c[3528598]|0;if((d|0)==0){k=0;break}k=gj[d&4095](h)|0}else{k=a[e+(i&255)|0]|0}}while(0);i=a[9642657]|0;e=(i&255)+(k&255)|0;h=(e>>>4&8|a[9642680]&-48&255)&255;d=e&255;f=(i^k)&255^e;a[9642680]=(f<<1&32|e>>>8&1|(f^e>>>1)>>>6&2|(d<<24>>24==0?h|4:h)&255)&255;a[9642657]=d;return}function fQS(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c[2426870]=c[2410665];d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9707480]=h;b[4821324]=i+1&65535;i=c[2426870]|0;h=i&65535;e=c[9699632+((i>>>8&255)<<2)>>2]|0;do{if((e|0)==0){d=c[3528598]|0;if((d|0)==0){k=0;break}k=gj[d&4095](h)|0}else{k=a[e+(i&255)|0]|0}}while(0);i=a[9642656]|0;e=(i&255)+(k&255)|0;h=(e>>>4&8|a[9642680]&-48&255)&255;d=e&255;f=(i^k)&255^e;a[9642680]=(f<<1&32|e>>>8&1|(f^e>>>1)>>>6&2|(d<<24>>24==0?h|4:h)&255)&255;a[9642656]=d;return}function fQT(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c[2426870]=c[2410665];d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9707480]=h;b[4821324]=i+1&65535;i=c[2426870]|0;h=i&65535;e=c[9699632+((i>>>8&255)<<2)>>2]|0;do{if((e|0)==0){d=c[3528598]|0;if((d|0)==0){k=0;break}k=gj[d&4095](h)|0}else{k=a[e+(i&255)|0]|0}}while(0);i=a[9642657]|0;e=a[9642680]|0;h=(i&255)+(k&255)+(e&1)|0;d=(h>>>4&8|e&-48&255)&255;e=h&255;f=h^(i^k)&255;a[9642680]=(f<<1&32|h>>>8&1|(f^h>>>1)>>>6&2|(e<<24>>24==0?d|4:d)&255)&255;a[9642657]=e;return}function fQU(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c[2426870]=c[2410665];d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9707480]=h;b[4821324]=i+1&65535;i=c[2426870]|0;h=i&65535;e=c[9699632+((i>>>8&255)<<2)>>2]|0;do{if((e|0)==0){d=c[3528598]|0;if((d|0)==0){k=0;break}k=gj[d&4095](h)|0}else{k=a[e+(i&255)|0]|0}}while(0);i=a[9642656]|0;e=a[9642680]|0;h=(i&255)+(k&255)+(e&1)|0;d=(h>>>4&8|e&-48&255)&255;e=h&255;f=h^(i^k)&255;a[9642680]=(f<<1&32|h>>>8&1|(f^h>>>1)>>>6&2|(e<<24>>24==0?d|4:d)&255)&255;a[9642656]=e;return}function fQV(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c[2426870]=c[2410665];d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9707480]=h;b[4821324]=i+1&65535;i=c[2426870]|0;h=i&65535;e=c[9699632+((i>>>8&255)<<2)>>2]|0;do{if((e|0)==0){d=c[3528598]|0;if((d|0)==0){k=0;break}k=gj[d&4095](h)|0}else{k=a[e+(i&255)|0]|0}}while(0);i=a[9642657]|0;e=(i&255)-(k&255)|0;h=(e>>>4&8|a[9642680]&-16&255)&255;d=e&255;a[9642680]=(((i^k)&255^e^e>>>1)>>>6&2|e>>>8&1|(d<<24>>24==0?h|4:h)&255)&255;a[9642657]=d;return}function fQW(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c[2426870]=c[2410665];d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9707480]=h;b[4821324]=i+1&65535;i=c[2426870]|0;h=i&65535;e=c[9699632+((i>>>8&255)<<2)>>2]|0;do{if((e|0)==0){d=c[3528598]|0;if((d|0)==0){k=0;break}k=gj[d&4095](h)|0}else{k=a[e+(i&255)|0]|0}}while(0);i=a[9642656]|0;e=(i&255)-(k&255)|0;h=(e>>>4&8|a[9642680]&-16&255)&255;d=e&255;a[9642680]=(((i^k)&255^e^e>>>1)>>>6&2|e>>>8&1|(d<<24>>24==0?h|4:h)&255)&255;a[9642656]=d;return}function fQX(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c[2426870]=c[2410665];d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9707480]=h;b[4821324]=i+1&65535;i=c[2426870]|0;h=i&65535;e=c[9699632+((i>>>8&255)<<2)>>2]|0;do{if((e|0)==0){d=c[3528598]|0;if((d|0)==0){k=0;break}k=gj[d&4095](h)|0}else{k=a[e+(i&255)|0]|0}}while(0);i=a[9642657]|0;e=a[9642680]|0;h=(i&255)-(k&255)-(e&1)|0;d=(h>>>4&8|e&-16&255)&255;e=h&255;a[9642680]=((h^(i^k)&255^h>>>1)>>>6&2|h>>>8&1|(e<<24>>24==0?d|4:d)&255)&255;a[9642657]=e;return}function fQY(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c[2426870]=c[2410665];d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9707480]=h;b[4821324]=i+1&65535;i=c[2426870]|0;h=i&65535;e=c[9699632+((i>>>8&255)<<2)>>2]|0;do{if((e|0)==0){d=c[3528598]|0;if((d|0)==0){k=0;break}k=gj[d&4095](h)|0}else{k=a[e+(i&255)|0]|0}}while(0);i=a[9642656]|0;e=a[9642680]|0;h=(i&255)-(k&255)-(e&1)|0;d=(h>>>4&8|e&-16&255)&255;e=h&255;a[9642680]=((h^(i^k)&255^h>>>1)>>>6&2|h>>>8&1|(e<<24>>24==0?d|4:d)&255)&255;a[9642656]=e;return}function fQZ(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c[2426870]=c[2410665];d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9707480]=h;b[4821324]=i+1&65535;i=c[2426870]|0;h=i&65535;e=c[9699632+((i>>>8&255)<<2)>>2]|0;do{if((e|0)==0){d=c[3528598]|0;if((d|0)==0){k=0;break}k=gj[d&4095](h)|0}else{k=a[e+(i&255)|0]|0}}while(0);i=a[9642657]&k;a[9642657]=i;k=(i&255)>>>4&8|a[9642680]&-15;a[9642680]=i<<24>>24==0?k|4:k;return}function fQ_(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c[2426870]=c[2410665];d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9707480]=h;b[4821324]=i+1&65535;i=c[2426870]|0;h=i&65535;e=c[9699632+((i>>>8&255)<<2)>>2]|0;do{if((e|0)==0){d=c[3528598]|0;if((d|0)==0){k=0;break}k=gj[d&4095](h)|0}else{k=a[e+(i&255)|0]|0}}while(0);i=a[9642656]&k;a[9642656]=i;k=(i&255)>>>4&8|a[9642680]&-15;a[9642680]=i<<24>>24==0?k|4:k;return}function fQ$(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c[2426870]=c[2410665];d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9707480]=h;b[4821324]=i+1&65535;i=c[2426870]|0;h=i&65535;e=c[9699632+((i>>>8&255)<<2)>>2]|0;do{if((e|0)==0){d=c[3528598]|0;if((d|0)==0){k=0;break}k=gj[d&4095](h)|0}else{k=a[e+(i&255)|0]|0}}while(0);i=a[9642657]&k;k=(i&255)>>>4&8|a[9642680]&-15;a[9642680]=i<<24>>24==0?k|4:k;return}function fQ0(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c[2426870]=c[2410665];d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9707480]=h;b[4821324]=i+1&65535;i=c[2426870]|0;h=i&65535;e=c[9699632+((i>>>8&255)<<2)>>2]|0;do{if((e|0)==0){d=c[3528598]|0;if((d|0)==0){k=0;break}k=gj[d&4095](h)|0}else{k=a[e+(i&255)|0]|0}}while(0);i=a[9642656]&k;k=(i&255)>>>4&8|a[9642680]&-15;a[9642680]=i<<24>>24==0?k|4:k;return}function fQ1(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c[2426870]=c[2410665];d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9707480]=h;b[4821324]=i+1&65535;i=c[2426870]|0;h=i&65535;e=c[9699632+((i>>>8&255)<<2)>>2]|0;do{if((e|0)==0){d=c[3528598]|0;if((d|0)==0){k=0;break}k=gj[d&4095](h)|0}else{k=a[e+(i&255)|0]|0}}while(0);i=a[9642657]|0;e=i^k;a[9642657]=e;h=(e&255)>>>4&8|a[9642680]&-15;a[9642680]=i<<24>>24==k<<24>>24?h|4:h;return}function fQ2(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c[2426870]=c[2410665];d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9707480]=h;b[4821324]=i+1&65535;i=c[2426870]|0;h=i&65535;e=c[9699632+((i>>>8&255)<<2)>>2]|0;do{if((e|0)==0){d=c[3528598]|0;if((d|0)==0){k=0;break}k=gj[d&4095](h)|0}else{k=a[e+(i&255)|0]|0}}while(0);i=a[9642656]|0;e=i^k;a[9642656]=e;h=(e&255)>>>4&8|a[9642680]&-15;a[9642680]=i<<24>>24==k<<24>>24?h|4:h;return}function fQ3(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c[2426870]=c[2410665];d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9707480]=h;b[4821324]=i+1&65535;i=c[2426870]|0;h=i&65535;e=c[9699632+((i>>>8&255)<<2)>>2]|0;do{if((e|0)==0){d=c[3528598]|0;if((d|0)==0){k=0;break}k=gj[d&4095](h)|0}else{k=a[e+(i&255)|0]|0}}while(0);i=a[9642657]|k;a[9642657]=i;k=(i&255)>>>4&8|a[9642680]&-15;a[9642680]=i<<24>>24==0?k|4:k;return}function fQ4(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c[2426870]=c[2410665];d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9707480]=h;b[4821324]=i+1&65535;i=c[2426870]|0;h=i&65535;e=c[9699632+((i>>>8&255)<<2)>>2]|0;do{if((e|0)==0){d=c[3528598]|0;if((d|0)==0){k=0;break}k=gj[d&4095](h)|0}else{k=a[e+(i&255)|0]|0}}while(0);i=a[9642656]|k;a[9642656]=i;k=(i&255)>>>4&8|a[9642680]&-15;a[9642680]=i<<24>>24==0?k|4:k;return}function fQ5(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c[2426870]=c[2410665];d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9707480]=h;b[4821324]=i+1&65535;i=c[2426870]|0;h=i&65535;e=c[9699632+((i>>>8&255)<<2)>>2]|0;do{if((e|0)==0){d=c[3528598]|0;if((d|0)==0){k=0;break}k=gj[d&4095](h)|0}else{k=a[e+(i&255)|0]|0}}while(0);i=a[9642657]|0;e=(i&255)-(k&255)|0;h=(e>>>4&8|a[9642680]&-16&255)&255;a[9642680]=(((i^k)&255^e^e>>>1)>>>6&2|e>>>8&1|((e&255)<<24>>24==0?h|4:h)&255)&255;return}function fQ6(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c[2426870]=c[2410665];d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9707480]=h;b[4821324]=i+1&65535;i=c[2426870]|0;h=i&65535;e=c[9699632+((i>>>8&255)<<2)>>2]|0;do{if((e|0)==0){d=c[3528598]|0;if((d|0)==0){k=0;break}k=gj[d&4095](h)|0}else{k=a[e+(i&255)|0]|0}}while(0);i=a[9642656]|0;e=(i&255)-(k&255)|0;h=(e>>>4&8|a[9642680]&-16&255)&255;a[9642680]=(((i^k)&255^e^e>>>1)>>>6&2|e>>>8&1|((e&255)<<24>>24==0?h|4:h)&255)&255;return}function fQ7(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c[2426870]=c[2410665];d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9707480]=h;b[4821324]=i+1&65535;i=c[2426870]|0;h=i&65535;e=c[9699632+((i>>>8&255)<<2)>>2]|0;do{if((e|0)==0){d=c[3528598]|0;if((d|0)==0){k=0;break}k=gj[d&4095](h)|0}else{k=a[e+(i&255)|0]|0}}while(0);i=c[2410675]|0;if((i|0)==0){return}gf[i&2047](k&255);return}function fQ8(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=a[9642657]|0;e=(d&255)>>>4&8|a[9642680]&-15;a[9642680]=d<<24>>24==0?e|4:e;c[2426870]=c[2410665];e=c[2410662]|0;f=e&65535;g=c[9701680+((e>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[3528598]|0;if((h|0)==0){i=0;j=f;k=d;break}l=gj[h&4095](f)|0;i=l;j=b[4821324]|0;k=a[9642657]|0}else{i=a[g+(e&255)|0]|0;j=f;k=d}}while(0);a[9707480]=i;b[4821324]=j+1&65535;j=c[2426870]|0;i=c[9700656+((j>>>8&255)<<2)>>2]|0;if((i|0)!=0){a[i+(j&255)|0]=k;return}i=c[2444172]|0;if((i|0)==0){return}gg[i&4095](j&65535,k);return}function fQ9(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=a[9642656]|0;e=(d&255)>>>4&8|a[9642680]&-15;a[9642680]=d<<24>>24==0?e|4:e;c[2426870]=c[2410665];e=c[2410662]|0;f=e&65535;g=c[9701680+((e>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[3528598]|0;if((h|0)==0){i=0;j=f;k=d;break}l=gj[h&4095](f)|0;i=l;j=b[4821324]|0;k=a[9642656]|0}else{i=a[g+(e&255)|0]|0;j=f;k=d}}while(0);a[9707480]=i;b[4821324]=j+1&65535;j=c[2426870]|0;i=c[9700656+((j>>>8&255)<<2)>>2]|0;if((i|0)!=0){a[i+(j&255)|0]=k;return}i=c[2444172]|0;if((i|0)==0){return}gg[i&4095](j&65535,k);return}function fRa(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c[2426870]=c[2410665];d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9707480]=h;b[4821324]=i+1&65535;i=c[2426870]|0;h=i&65535;e=c[9699632+((i>>>8&255)<<2)>>2]|0;do{if((e|0)==0){d=c[3528598]|0;if((d|0)==0){k=0;break}k=gj[d&4095](h)|0}else{k=a[e+(i&255)|0]|0}}while(0);e=k&255;k=e<<8;h=i+1|0;i=h&65535;d=c[9699632+((h>>>8&255)<<2)>>2]|0;do{if((d|0)==0){f=c[3528598]|0;if((f|0)==0){l=0;break}l=gj[f&4095](i)|0}else{l=a[d+(h&255)|0]|0}}while(0);h=l&255|k;c[2410664]=h;k=a[9642680]&-15;a[9642680]=k;l=k&255|e>>>4&8;if((h|0)!=0){m=l&255;a[9642680]=m;return}m=(l|4)&255;a[9642680]=m;return}function fRb(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c[2426870]=c[2410665];d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9707480]=h;b[4821324]=i+1&65535;i=c[2426870]|0;h=i&65535;e=c[9699632+((i>>>8&255)<<2)>>2]|0;do{if((e|0)==0){d=c[3528598]|0;if((d|0)==0){k=0;break}k=gj[d&4095](h)|0}else{k=a[e+(i&255)|0]|0}}while(0);e=k&255;k=e<<8;h=i+1|0;i=h&65535;d=c[9699632+((h>>>8&255)<<2)>>2]|0;do{if((d|0)==0){f=c[3528598]|0;if((f|0)==0){l=0;break}l=gj[f&4095](i)|0}else{l=a[d+(h&255)|0]|0}}while(0);h=l&255|k;c[2410668]=h;k=a[9642680]&-15;a[9642680]=k;l=k&255|e>>>4&8;if((h|0)!=0){m=l&255;a[9642680]=m;return}m=(l|4)&255;a[9642680]=m;return}function fRc(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c[2426870]=c[2410665];d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9707480]=h;b[4821324]=i+1&65535;i=c[2426870]|0;h=i&65535;e=c[9699632+((i>>>8&255)<<2)>>2]|0;do{if((e|0)==0){d=c[3528598]|0;if((d|0)==0){k=0;break}k=gj[d&4095](h)|0}else{k=a[e+(i&255)|0]|0}}while(0);e=k&255;k=e<<8;h=i+1|0;i=h&65535;d=c[9699632+((h>>>8&255)<<2)>>2]|0;do{if((d|0)==0){f=c[3528598]|0;if((f|0)==0){l=0;break}l=gj[f&4095](i)|0}else{l=a[d+(h&255)|0]|0}}while(0);h=l&255|k;c[2410669]=h;k=a[9642680]&-15;a[9642680]=k;l=k&255|e>>>4&8;if((h|0)!=0){m=l&255;a[9642680]=m;return}m=(l|4)&255;a[9642680]=m;return}function fRd(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c[2426870]=c[2410665];d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9707480]=h;b[4821324]=i+1&65535;i=c[2426870]|0;h=i&65535;e=c[9699632+((i>>>8&255)<<2)>>2]|0;do{if((e|0)==0){d=c[3528598]|0;if((d|0)==0){k=0;break}k=gj[d&4095](h)|0}else{k=a[e+(i&255)|0]|0}}while(0);e=k&255;k=e<<8;h=i+1|0;i=h&65535;d=c[9699632+((h>>>8&255)<<2)>>2]|0;do{if((d|0)==0){f=c[3528598]|0;if((f|0)==0){l=0;break}l=gj[f&4095](i)|0}else{l=a[d+(h&255)|0]|0}}while(0);h=l&255|k;c[2410666]=h;k=a[9642680]&-15;a[9642680]=k;l=k&255|e>>>4&8;if((h|0)!=0){m=l&255;a[9642680]=m;return}m=(l|4)&255;a[9642680]=m;return}function fRe(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c[2426870]=c[2410665];d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9707480]=h;b[4821324]=i+1&65535;i=c[2426870]|0;h=i&65535;e=c[9699632+((i>>>8&255)<<2)>>2]|0;do{if((e|0)==0){d=c[3528598]|0;if((d|0)==0){k=0;break}k=gj[d&4095](h)|0}else{k=a[e+(i&255)|0]|0}}while(0);e=k&255;k=e<<8;h=i+1|0;i=h&65535;d=c[9699632+((h>>>8&255)<<2)>>2]|0;do{if((d|0)==0){f=c[3528598]|0;if((f|0)==0){l=0;break}l=gj[f&4095](i)|0}else{l=a[d+(h&255)|0]|0}}while(0);h=l&255|k;c[2410667]=h;k=a[9642680]&-15;a[9642680]=k;l=k&255|e>>>4&8;if((h|0)!=0){m=l&255;a[9642680]=m;n=a[9642688]|0;o=n|32;a[9642688]=o;return}m=(l|4)&255;a[9642680]=m;n=a[9642688]|0;o=n|32;a[9642688]=o;return}function fRf(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c[2426870]=c[2410665];d=c[2410662]|0;f=d&65535;g=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[3528598]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](f)|0;i=k;j=b[4821324]|0}else{i=a[g+(d&255)|0]|0;j=f}}while(0);a[9707480]=i;b[4821324]=j+1&65535;j=c[2426870]|0;i=j&65535;f=c[9699632+((j>>>8&255)<<2)>>2]|0;do{if((f|0)==0){d=c[3528598]|0;if((d|0)==0){l=0;break}l=gj[d&4095](i)|0}else{l=a[f+(j&255)|0]|0}}while(0);f=(l&255)<<8;l=j+1|0;j=l&65535;i=c[9699632+((l>>>8&255)<<2)>>2]|0;do{if((i|0)==0){d=c[3528598]|0;if((d|0)==0){m=0;break}m=gj[d&4095](j)|0}else{m=a[i+(l&255)|0]|0}}while(0);l=e[4821328]|0;i=l-(m&255|f)|0;m=(i>>>12&8|a[9642680]&-16&255)&255;a[9642680]=((l^f^i^i>>>1)>>>14&2|i>>>16&1|((i&65535)<<16>>16==0?m|4:m)&255)&255;return}function fRg(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c[2426870]=c[2410665];d=c[2410662]|0;f=d&65535;g=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[3528598]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](f)|0;i=k;j=b[4821324]|0}else{i=a[g+(d&255)|0]|0;j=f}}while(0);a[9707480]=i;b[4821324]=j+1&65535;j=c[2426870]|0;i=j&65535;f=c[9699632+((j>>>8&255)<<2)>>2]|0;do{if((f|0)==0){d=c[3528598]|0;if((d|0)==0){l=0;break}l=gj[d&4095](i)|0}else{l=a[f+(j&255)|0]|0}}while(0);f=(l&255)<<8;l=j+1|0;j=l&65535;i=c[9699632+((l>>>8&255)<<2)>>2]|0;do{if((i|0)==0){d=c[3528598]|0;if((d|0)==0){m=0;break}m=gj[d&4095](j)|0}else{m=a[i+(l&255)|0]|0}}while(0);l=e[4821336]|0;i=l-(m&255|f)|0;m=(i>>>12&8|a[9642680]&-16&255)&255;a[9642680]=((l^f^i^i>>>1)>>>14&2|i>>>16&1|((i&65535)<<16>>16==0?m|4:m)&255)&255;return}function fRh(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c[2426870]=c[2410665];d=c[2410662]|0;f=d&65535;g=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[3528598]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](f)|0;i=k;j=b[4821324]|0}else{i=a[g+(d&255)|0]|0;j=f}}while(0);a[9707480]=i;b[4821324]=j+1&65535;j=c[2426870]|0;i=j&65535;f=c[9699632+((j>>>8&255)<<2)>>2]|0;do{if((f|0)==0){d=c[3528598]|0;if((d|0)==0){l=0;break}l=gj[d&4095](i)|0}else{l=a[f+(j&255)|0]|0}}while(0);f=(l&255)<<8;l=j+1|0;j=l&65535;i=c[9699632+((l>>>8&255)<<2)>>2]|0;do{if((i|0)==0){d=c[3528598]|0;if((d|0)==0){m=0;break}m=gj[d&4095](j)|0}else{m=a[i+(l&255)|0]|0}}while(0);l=e[4821338]|0;i=l-(m&255|f)|0;m=(i>>>12&8|a[9642680]&-16&255)&255;a[9642680]=((l^f^i^i>>>1)>>>14&2|i>>>16&1|((i&65535)<<16>>16==0?m|4:m)&255)&255;return}function fRi(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c[2426870]=c[2410665];d=c[2410662]|0;f=d&65535;g=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[3528598]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](f)|0;i=k;j=b[4821324]|0}else{i=a[g+(d&255)|0]|0;j=f}}while(0);a[9707480]=i;b[4821324]=j+1&65535;j=c[2426870]|0;i=j&65535;f=c[9699632+((j>>>8&255)<<2)>>2]|0;do{if((f|0)==0){d=c[3528598]|0;if((d|0)==0){l=0;break}l=gj[d&4095](i)|0}else{l=a[f+(j&255)|0]|0}}while(0);f=(l&255)<<8;l=j+1|0;j=l&65535;i=c[9699632+((l>>>8&255)<<2)>>2]|0;do{if((i|0)==0){d=c[3528598]|0;if((d|0)==0){m=0;break}m=gj[d&4095](j)|0}else{m=a[i+(l&255)|0]|0}}while(0);l=e[4821332]|0;i=l-(m&255|f)|0;m=(i>>>12&8|a[9642680]&-16&255)&255;a[9642680]=((l^f^i^i>>>1)>>>14&2|i>>>16&1|((i&65535)<<16>>16==0?m|4:m)&255)&255;return}function fRj(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c[2426870]=c[2410665];d=c[2410662]|0;f=d&65535;g=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[3528598]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](f)|0;i=k;j=b[4821324]|0}else{i=a[g+(d&255)|0]|0;j=f}}while(0);a[9707480]=i;b[4821324]=j+1&65535;j=c[2426870]|0;i=j&65535;f=c[9699632+((j>>>8&255)<<2)>>2]|0;do{if((f|0)==0){d=c[3528598]|0;if((d|0)==0){l=0;break}l=gj[d&4095](i)|0}else{l=a[f+(j&255)|0]|0}}while(0);f=(l&255)<<8;l=j+1|0;j=l&65535;i=c[9699632+((l>>>8&255)<<2)>>2]|0;do{if((i|0)==0){d=c[3528598]|0;if((d|0)==0){m=0;break}m=gj[d&4095](j)|0}else{m=a[i+(l&255)|0]|0}}while(0);l=e[4821334]|0;i=l-(m&255|f)|0;m=(i>>>12&8|a[9642680]&-16&255)&255;a[9642680]=((l^f^i^i>>>1)>>>14&2|i>>>16&1|((i&65535)<<16>>16==0?m|4:m)&255)&255;return}function fRk(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c[2426870]=c[2410665];d=c[2410662]|0;f=d&65535;g=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[3528598]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](f)|0;i=k;j=b[4821324]|0}else{i=a[g+(d&255)|0]|0;j=f}}while(0);a[9707480]=i;b[4821324]=j+1&65535;j=c[2426870]|0;i=j&65535;f=c[9699632+((j>>>8&255)<<2)>>2]|0;do{if((f|0)==0){d=c[3528598]|0;if((d|0)==0){l=0;break}l=gj[d&4095](i)|0}else{l=a[f+(j&255)|0]|0}}while(0);f=(l&255)<<8;l=j+1|0;j=l&65535;i=c[9699632+((l>>>8&255)<<2)>>2]|0;do{if((i|0)==0){d=c[3528598]|0;if((d|0)==0){m=0;break}m=gj[d&4095](j)|0}else{m=a[i+(l&255)|0]|0}}while(0);l=e[4821328]|0;i=l+(m&255|f)|0;m=(i>>>12&8|a[9642680]&-16&255)&255;j=i&65535;a[9642680]=((l^f^i^i>>>1)>>>14&2|i>>>16&1|(j<<16>>16==0?m|4:m)&255)&255;b[4821328]=j;return}function fRl(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c[2426870]=c[2410665];d=c[2410662]|0;f=d&65535;g=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[3528598]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](f)|0;i=k;j=b[4821324]|0}else{i=a[g+(d&255)|0]|0;j=f}}while(0);a[9707480]=i;b[4821324]=j+1&65535;j=c[2426870]|0;i=j&65535;f=c[9699632+((j>>>8&255)<<2)>>2]|0;do{if((f|0)==0){d=c[3528598]|0;if((d|0)==0){l=0;break}l=gj[d&4095](i)|0}else{l=a[f+(j&255)|0]|0}}while(0);f=(l&255)<<8;l=j+1|0;j=l&65535;i=c[9699632+((l>>>8&255)<<2)>>2]|0;do{if((i|0)==0){d=c[3528598]|0;if((d|0)==0){m=0;break}m=gj[d&4095](j)|0}else{m=a[i+(l&255)|0]|0}}while(0);l=e[4821328]|0;i=l-(m&255|f)|0;m=(i>>>12&8|a[9642680]&-16&255)&255;j=i&65535;a[9642680]=((l^f^i^i>>>1)>>>14&2|i>>>16&1|(j<<16>>16==0?m|4:m)&255)&255;b[4821328]=j;return}function fRm(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=a[9642680]&-15;a[9642680]=d;e=b[4821328]|0;f=(e&65535)>>>12&8|d&255;if(e<<16>>16==0){g=(f|4)&255}else{g=f&255}a[9642680]=g;c[2426870]=c[2410665];g=c[2410662]|0;f=g&65535;e=c[9701680+((g>>>8&255)<<2)>>2]|0;do{if((e|0)==0){d=c[3528598]|0;if((d|0)==0){h=0;i=f;break}j=gj[d&4095](f)|0;h=j;i=b[4821324]|0}else{h=a[e+(g&255)|0]|0;i=f}}while(0);a[9707480]=h;b[4821324]=i+1&65535;i=c[2426870]|0;h=i&65535;f=a[9642657]|0;g=c[9700656+((i>>>8&255)<<2)>>2]|0;do{if((g|0)==0){e=c[2444172]|0;if((e|0)==0){break}gg[e&4095](h,f)}else{a[g+(i&255)|0]=f}}while(0);f=i+1|0;i=a[9642656]|0;g=c[9700656+((f>>>8&255)<<2)>>2]|0;if((g|0)!=0){a[g+(f&255)|0]=i;return}g=c[2444172]|0;if((g|0)==0){return}gg[g&4095](f&65535,i);return}function fRn(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=a[9642680]&-15;a[9642680]=d;e=b[4821336]|0;f=(e&65535)>>>12&8|d&255;if(e<<16>>16==0){g=(f|4)&255}else{g=f&255}a[9642680]=g;c[2426870]=c[2410665];g=c[2410662]|0;f=g&65535;e=c[9701680+((g>>>8&255)<<2)>>2]|0;do{if((e|0)==0){d=c[3528598]|0;if((d|0)==0){h=0;i=f;break}j=gj[d&4095](f)|0;h=j;i=b[4821324]|0}else{h=a[e+(g&255)|0]|0;i=f}}while(0);a[9707480]=h;b[4821324]=i+1&65535;i=c[2426870]|0;h=i&65535;f=a[9642673]|0;g=c[9700656+((i>>>8&255)<<2)>>2]|0;do{if((g|0)==0){e=c[2444172]|0;if((e|0)==0){break}gg[e&4095](h,f)}else{a[g+(i&255)|0]=f}}while(0);f=i+1|0;i=a[9642672]|0;g=c[9700656+((f>>>8&255)<<2)>>2]|0;if((g|0)!=0){a[g+(f&255)|0]=i;return}g=c[2444172]|0;if((g|0)==0){return}gg[g&4095](f&65535,i);return}function fRo(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=a[9642680]&-15;a[9642680]=d;e=b[4821338]|0;f=(e&65535)>>>12&8|d&255;if(e<<16>>16==0){g=(f|4)&255}else{g=f&255}a[9642680]=g;c[2426870]=c[2410665];g=c[2410662]|0;f=g&65535;e=c[9701680+((g>>>8&255)<<2)>>2]|0;do{if((e|0)==0){d=c[3528598]|0;if((d|0)==0){h=0;i=f;break}j=gj[d&4095](f)|0;h=j;i=b[4821324]|0}else{h=a[e+(g&255)|0]|0;i=f}}while(0);a[9707480]=h;b[4821324]=i+1&65535;i=c[2426870]|0;h=i&65535;f=a[9642677]|0;g=c[9700656+((i>>>8&255)<<2)>>2]|0;do{if((g|0)==0){e=c[2444172]|0;if((e|0)==0){break}gg[e&4095](h,f)}else{a[g+(i&255)|0]=f}}while(0);f=i+1|0;i=a[9642676]|0;g=c[9700656+((f>>>8&255)<<2)>>2]|0;if((g|0)!=0){a[g+(f&255)|0]=i;return}g=c[2444172]|0;if((g|0)==0){return}gg[g&4095](f&65535,i);return}function fRp(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=a[9642680]&-15;a[9642680]=d;e=b[4821332]|0;f=(e&65535)>>>12&8|d&255;if(e<<16>>16==0){g=(f|4)&255}else{g=f&255}a[9642680]=g;c[2426870]=c[2410665];g=c[2410662]|0;f=g&65535;e=c[9701680+((g>>>8&255)<<2)>>2]|0;do{if((e|0)==0){d=c[3528598]|0;if((d|0)==0){h=0;i=f;break}j=gj[d&4095](f)|0;h=j;i=b[4821324]|0}else{h=a[e+(g&255)|0]|0;i=f}}while(0);a[9707480]=h;b[4821324]=i+1&65535;i=c[2426870]|0;h=i&65535;f=a[9642665]|0;g=c[9700656+((i>>>8&255)<<2)>>2]|0;do{if((g|0)==0){e=c[2444172]|0;if((e|0)==0){break}gg[e&4095](h,f)}else{a[g+(i&255)|0]=f}}while(0);f=i+1|0;i=a[9642664]|0;g=c[9700656+((f>>>8&255)<<2)>>2]|0;if((g|0)!=0){a[g+(f&255)|0]=i;return}g=c[2444172]|0;if((g|0)==0){return}gg[g&4095](f&65535,i);return}function fRq(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=a[9642680]&-15;a[9642680]=d;e=b[4821334]|0;f=(e&65535)>>>12&8|d&255;if(e<<16>>16==0){g=(f|4)&255}else{g=f&255}a[9642680]=g;c[2426870]=c[2410665];g=c[2410662]|0;f=g&65535;e=c[9701680+((g>>>8&255)<<2)>>2]|0;do{if((e|0)==0){d=c[3528598]|0;if((d|0)==0){h=0;i=f;break}j=gj[d&4095](f)|0;h=j;i=b[4821324]|0}else{h=a[e+(g&255)|0]|0;i=f}}while(0);a[9707480]=h;b[4821324]=i+1&65535;i=c[2426870]|0;h=i&65535;f=a[9642669]|0;g=c[9700656+((i>>>8&255)<<2)>>2]|0;do{if((g|0)==0){e=c[2444172]|0;if((e|0)==0){break}gg[e&4095](h,f)}else{a[g+(i&255)|0]=f}}while(0);f=i+1|0;i=a[9642668]|0;g=c[9700656+((f>>>8&255)<<2)>>2]|0;if((g|0)!=0){a[g+(f&255)|0]=i;return}g=c[2444172]|0;if((g|0)==0){return}gg[g&4095](f&65535,i);return}function fRr(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c[2426870]=c[2410665];d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9707480]=h;b[4821324]=i+1&65535;i=c[2426870]|0;h=c[9700656+((i>>>8&255)<<2)>>2]|0;if((h|0)!=0){a[h+(i&255)|0]=0;k=a[9642680]|0;l=k&-16;m=l|4;a[9642680]=m;return}h=c[2444172]|0;if((h|0)==0){k=a[9642680]|0;l=k&-16;m=l|4;a[9642680]=m;return}gg[h&4095](i&65535,0);k=a[9642680]|0;l=k&-16;m=l|4;a[9642680]=m;return}function fRs(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c[2426870]=c[2410665];d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9707480]=h;b[4821324]=i+1&65535;i=c[2426870]|0;h=i&65535;e=c[9699632+((i>>>8&255)<<2)>>2]|0;do{if((e|0)==0){d=c[3528598]|0;if((d|0)==0){k=0;l=i;break}f=gj[d&4095](h)|0;k=f;l=c[2426870]|0}else{k=a[e+(i&255)|0]|0;l=i}}while(0);i=~k;e=a[9642680]&-15|(i&255)>>>4&8;a[9642680]=(k<<24>>24==-1?e|4:e)|1;e=c[9700656+((l>>>8&255)<<2)>>2]|0;if((e|0)!=0){a[e+(l&255)|0]=i;return}e=c[2444172]|0;if((e|0)==0){return}gg[e&4095](l&65535,i);return}function fRt(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c[2426870]=c[2410665];d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9707480]=h;b[4821324]=i+1&65535;i=c[2426870]|0;h=i&65535;e=c[9699632+((i>>>8&255)<<2)>>2]|0;do{if((e|0)==0){d=c[3528598]|0;if((d|0)==0){k=0;l=i;break}f=gj[d&4095](h)|0;k=f;l=c[2426870]|0}else{k=a[e+(i&255)|0]|0;l=i}}while(0);i=k&255;k=-i|0;e=(a[9642680]&-16&255|k>>>4&8)&255;h=k&255;a[9642680]=((i^k^k>>>1)>>>6&2|k>>>8&1|(h<<24>>24==0?e|4:e)&255)&255;e=c[9700656+((l>>>8&255)<<2)>>2]|0;if((e|0)!=0){a[e+(l&255)|0]=h;return}e=c[2444172]|0;if((e|0)==0){return}gg[e&4095](l&65535,h);return}function fRu(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c[2426870]=c[2410665];d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9707480]=h;b[4821324]=i+1&65535;i=c[2426870]|0;h=i&65535;e=c[9699632+((i>>>8&255)<<2)>>2]|0;do{if((e|0)==0){d=c[3528598]|0;if((d|0)==0){k=0;l=i;break}f=gj[d&4095](h)|0;k=f;l=c[2426870]|0}else{k=a[e+(i&255)|0]|0;l=i}}while(0);i=k+1&255;a[9642680]=a[9642680]&-15|a[668928+(i&255)|0];k=c[9700656+((l>>>8&255)<<2)>>2]|0;if((k|0)!=0){a[k+(l&255)|0]=i;return}k=c[2444172]|0;if((k|0)==0){return}gg[k&4095](l&65535,i);return}function fRv(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c[2426870]=c[2410665];d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9707480]=h;b[4821324]=i+1&65535;i=c[2426870]|0;h=i&65535;e=c[9699632+((i>>>8&255)<<2)>>2]|0;do{if((e|0)==0){d=c[3528598]|0;if((d|0)==0){k=0;l=i;break}f=gj[d&4095](h)|0;k=f;l=c[2426870]|0}else{k=a[e+(i&255)|0]|0;l=i}}while(0);i=k-1&255;a[9642680]=a[9642680]&-15|a[669184+(i&255)|0];k=c[9700656+((l>>>8&255)<<2)>>2]|0;if((k|0)!=0){a[k+(l&255)|0]=i;return}k=c[2444172]|0;if((k|0)==0){return}gg[k&4095](l&65535,i);return}function fRw(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c[2426870]=c[2410665];d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9707480]=h;b[4821324]=i+1&65535;i=c[2426870]|0;h=i&65535;e=c[9699632+((i>>>8&255)<<2)>>2]|0;do{if((e|0)==0){d=c[3528598]|0;if((d|0)==0){k=0;break}k=gj[d&4095](h)|0}else{k=a[e+(i&255)|0]|0}}while(0);i=a[9642680]&-15|(k&255)>>>4&8;a[9642680]=k<<24>>24==0?i|4:i;return}function fRx(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c[2426870]=c[2410665];d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9707480]=h;b[4821324]=i+1&65535;i=c[2426870]|0;h=i&65535;e=c[9699632+((i>>>8&255)<<2)>>2]|0;do{if((e|0)==0){d=c[3528598]|0;if((d|0)==0){k=0;l=i;break}f=gj[d&4095](h)|0;k=f;l=c[2426870]|0}else{k=a[e+(i&255)|0]|0;l=i}}while(0);i=a[9642680]&-14|k&1;e=(k&255)>>>1;a[9642680]=e<<24>>24==0?i|4:i;i=c[9700656+((l>>>8&255)<<2)>>2]|0;if((i|0)!=0){a[i+(l&255)|0]=e;return}i=c[2444172]|0;if((i|0)==0){return}gg[i&4095](l&65535,e);return}function fRy(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c[2426870]=c[2410665];d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9707480]=h;b[4821324]=i+1&65535;i=c[2426870]|0;h=i&65535;e=c[9699632+((i>>>8&255)<<2)>>2]|0;do{if((e|0)==0){d=c[3528598]|0;if((d|0)==0){k=0;l=i;break}f=gj[d&4095](h)|0;k=f;l=c[2426870]|0}else{k=a[e+(i&255)|0]|0;l=i}}while(0);i=a[9642680]|0;e=i<<7|(k&255)>>>1;h=i&-14|k&1|i<<3&8;a[9642680]=e<<24>>24==0?h|4:h;h=c[9700656+((l>>>8&255)<<2)>>2]|0;if((h|0)!=0){a[h+(l&255)|0]=e;return}h=c[2444172]|0;if((h|0)==0){return}gg[h&4095](l&65535,e);return}function fRz(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c[2426870]=c[2410665];d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9707480]=h;b[4821324]=i+1&65535;i=c[2426870]|0;h=i&65535;e=c[9699632+((i>>>8&255)<<2)>>2]|0;do{if((e|0)==0){d=c[3528598]|0;if((d|0)==0){k=0;l=i;break}f=gj[d&4095](h)|0;k=f;l=c[2426870]|0}else{k=a[e+(i&255)|0]|0;l=i}}while(0);i=k&-128|(k&255)>>>1;e=a[9642680]&-14|k&1|(k&255)>>>4&8;a[9642680]=i<<24>>24==0?e|4:e;e=c[9700656+((l>>>8&255)<<2)>>2]|0;if((e|0)!=0){a[e+(l&255)|0]=i;return}e=c[2444172]|0;if((e|0)==0){return}gg[e&4095](l&65535,i);return}function fRA(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c[2426870]=c[2410665];d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9707480]=h;b[4821324]=i+1&65535;i=c[2426870]|0;h=i&65535;e=c[9699632+((i>>>8&255)<<2)>>2]|0;do{if((e|0)==0){d=c[3528598]|0;if((d|0)==0){k=0;l=i;break}f=gj[d&4095](h)|0;k=f;l=c[2426870]|0}else{k=a[e+(i&255)|0]|0;l=i}}while(0);i=(k&255)<<1;k=i&65535;e=(k>>>4&8|a[9642680]&-16&255)&255;h=i&255;a[9642680]=((k>>>1^k)>>>6&2|k>>>8|(h<<24>>24==0?e|4:e)&255)&255;e=c[9700656+((l>>>8&255)<<2)>>2]|0;if((e|0)!=0){a[e+(l&255)|0]=h;return}e=c[2444172]|0;if((e|0)==0){return}gg[e&4095](l&65535,h);return}function fRB(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c[2426870]=c[2410665];d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9707480]=h;b[4821324]=i+1&65535;i=c[2426870]|0;h=i&65535;e=c[9699632+((i>>>8&255)<<2)>>2]|0;do{if((e|0)==0){d=c[3528598]|0;if((d|0)==0){k=0;l=i;break}f=gj[d&4095](h)|0;k=f;l=c[2426870]|0}else{k=a[e+(i&255)|0]|0;l=i}}while(0);i=a[9642680]|0;e=k&255;h=e<<1;f=i&-16|(k&255)>>>3&8;k=(i&1|h)&255;a[9642680]=((h^e)>>>6&2|e>>>7|(k<<24>>24==0?f|4:f)&255)&255;f=c[9700656+((l>>>8&255)<<2)>>2]|0;if((f|0)!=0){a[f+(l&255)|0]=k;return}f=c[2444172]|0;if((f|0)==0){return}gg[f&4095](l&65535,k);return}function fRC(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c[2426870]=c[2410665];d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9707480]=h;b[4821324]=i+1&65535;i=c[2426870]|0;h=i&65535;e=c[9699632+((i>>>8&255)<<2)>>2]|0;do{if((e|0)==0){d=c[3528598]|0;if((d|0)==0){k=0;break}k=gj[d&4095](h)|0}else{k=a[e+(i&255)|0]|0}}while(0);e=i+1|0;i=e&65535;h=c[9699632+((e>>>8&255)<<2)>>2]|0;do{if((h|0)==0){d=c[3528598]|0;if((d|0)==0){l=0;break}l=gj[d&4095](i)|0}else{l=a[h+(e&255)|0]|0}}while(0);e=a[9642680]&-14|l&1;h=(l&255|(k&255)<<8)>>>1;l=h&255;i=(k&255)>>>1;a[9642680]=(h|0)==0?e|4:e;e=c[2426870]|0;h=e&65535;k=c[9700656+((e>>>8&255)<<2)>>2]|0;do{if((k|0)==0){d=c[2444172]|0;if((d|0)==0){break}gg[d&4095](h,i)}else{a[k+(e&255)|0]=i}}while(0);i=e+1|0;e=c[9700656+((i>>>8&255)<<2)>>2]|0;if((e|0)!=0){a[e+(i&255)|0]=l;return}e=c[2444172]|0;if((e|0)==0){return}gg[e&4095](i&65535,l);return}function fRD(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c[2426870]=c[2410665];d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9707480]=h;b[4821324]=i+1&65535;i=c[2426870]|0;h=i&65535;e=c[9699632+((i>>>8&255)<<2)>>2]|0;do{if((e|0)==0){d=c[3528598]|0;if((d|0)==0){k=0;break}k=gj[d&4095](h)|0}else{k=a[e+(i&255)|0]|0}}while(0);e=(k&255)<<8;k=i+1|0;i=k&65535;h=c[9699632+((k>>>8&255)<<2)>>2]|0;do{if((h|0)==0){d=c[3528598]|0;if((d|0)==0){l=0;break}l=gj[d&4095](i)|0}else{l=a[h+(k&255)|0]|0}}while(0);k=a[9642680]|0;h=(l&255|e)>>>1;e=(k&255)<<15&32768|h;i=h&255;d=e>>>8;f=d&255;j=e>>>12&8|(k&-14|l&1)&255;a[9642680]=((d<<8&65280|h&255|0)==0?j|4:j)&255;j=c[2426870]|0;h=j&65535;d=c[9700656+((j>>>8&255)<<2)>>2]|0;do{if((d|0)==0){l=c[2444172]|0;if((l|0)==0){break}gg[l&4095](h,f)}else{a[d+(j&255)|0]=f}}while(0);f=j+1|0;j=c[9700656+((f>>>8&255)<<2)>>2]|0;if((j|0)!=0){a[j+(f&255)|0]=i;return}j=c[2444172]|0;if((j|0)==0){return}gg[j&4095](f&65535,i);return}function fRE(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c[2426870]=c[2410665];d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9707480]=h;b[4821324]=i+1&65535;i=c[2426870]|0;h=i&65535;e=c[9699632+((i>>>8&255)<<2)>>2]|0;do{if((e|0)==0){d=c[3528598]|0;if((d|0)==0){k=0;break}k=gj[d&4095](h)|0}else{k=a[e+(i&255)|0]|0}}while(0);e=i+1|0;i=e&65535;h=c[9699632+((e>>>8&255)<<2)>>2]|0;do{if((h|0)==0){d=c[3528598]|0;if((d|0)==0){l=0;break}l=gj[d&4095](i)|0}else{l=a[h+(e&255)|0]|0}}while(0);e=(k&255)<<8;k=(l&255|e)>>>1;h=k|e&32768;e=k&255;i=h>>>8;d=i&255;f=h>>>12&8|(a[9642680]&-14|l&1)&255;a[9642680]=((i<<8&65280|k&255|0)==0?f|4:f)&255;f=c[2426870]|0;k=f&65535;i=c[9700656+((f>>>8&255)<<2)>>2]|0;do{if((i|0)==0){l=c[2444172]|0;if((l|0)==0){break}gg[l&4095](k,d)}else{a[i+(f&255)|0]=d}}while(0);d=f+1|0;f=c[9700656+((d>>>8&255)<<2)>>2]|0;if((f|0)!=0){a[f+(d&255)|0]=e;return}f=c[2444172]|0;if((f|0)==0){return}gg[f&4095](d&65535,e);return}function fRF(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c[2426870]=c[2410665];d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9707480]=h;b[4821324]=i+1&65535;i=c[2426870]|0;h=i&65535;e=c[9699632+((i>>>8&255)<<2)>>2]|0;do{if((e|0)==0){d=c[3528598]|0;if((d|0)==0){k=0;break}k=gj[d&4095](h)|0}else{k=a[e+(i&255)|0]|0}}while(0);e=k&255;h=e<<8;d=i+1|0;i=d&65535;f=c[9699632+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){j=c[3528598]|0;if((j|0)==0){l=0;break}l=gj[j&4095](i)|0}else{l=a[f+(d&255)|0]|0}}while(0);d=l&255|h;h=d<<1;l=h&255;f=d>>>7;d=f&255;i=(k&255)>>>7&255;k=f<<8;f=a[9642680]&-16&255|e>>>3&8;a[9642680]=((k^i<<15)>>>14&2|i|(((k|h&254)&65535)<<16>>16==0?f|4:f)&252)&255;f=c[2426870]|0;h=f&65535;k=c[9700656+((f>>>8&255)<<2)>>2]|0;do{if((k|0)==0){i=c[2444172]|0;if((i|0)==0){break}gg[i&4095](h,d)}else{a[k+(f&255)|0]=d}}while(0);d=f+1|0;f=c[9700656+((d>>>8&255)<<2)>>2]|0;if((f|0)!=0){a[f+(d&255)|0]=l;return}f=c[2444172]|0;if((f|0)==0){return}gg[f&4095](d&65535,l);return}function fRG(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c[2426870]=c[2410665];d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9707480]=h;b[4821324]=i+1&65535;i=c[2426870]|0;h=i&65535;e=c[9699632+((i>>>8&255)<<2)>>2]|0;do{if((e|0)==0){d=c[3528598]|0;if((d|0)==0){k=0;break}k=gj[d&4095](h)|0}else{k=a[e+(i&255)|0]|0}}while(0);e=k&255;h=e<<8;d=i+1|0;i=d&65535;f=c[9699632+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){j=c[3528598]|0;if((j|0)==0){l=0;break}l=gj[j&4095](i)|0}else{l=a[f+(d&255)|0]|0}}while(0);d=l&255|h;h=a[9642680]|0;l=h&1|d<<1;f=l&255;i=d>>>7;d=i&255;j=(k&255)>>>7&255;k=i<<8;i=h&-16&255|e>>>3&8;a[9642680]=((k^j<<15)>>>14&2|j|(((l&255|k)&65535)<<16>>16==0?i|4:i)&252)&255;i=c[2426870]|0;k=i&65535;l=c[9700656+((i>>>8&255)<<2)>>2]|0;do{if((l|0)==0){j=c[2444172]|0;if((j|0)==0){break}gg[j&4095](k,d)}else{a[l+(i&255)|0]=d}}while(0);d=i+1|0;i=c[9700656+((d>>>8&255)<<2)>>2]|0;if((i|0)!=0){a[i+(d&255)|0]=f;return}i=c[2444172]|0;if((i|0)==0){return}gg[i&4095](d&65535,f);return}function fRH(){var d=0,e=0,f=0,g=0,h=0;c[2426870]=c[2410665];d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;break}h=gj[g&4095](e)|0}else{h=a[f+(d&255)|0]|0}}while(0);a[9707480]=h;h=c[2426870]|0;c[2410662]=h;b[4821324]=h&65535;return}function fRI(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c[2426870]=c[2410665];d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9707480]=h;h=i+1&65535;b[4821324]=h;b[4821334]=(b[4821334]|0)-1&65535;i=c[2410667]|0;e=i&65535;d=h&255;h=c[9700656+((i>>>8&255)<<2)>>2]|0;do{if((h|0)==0){f=c[2444172]|0;if((f|0)==0){break}gg[f&4095](e,d)}else{a[h+(i&255)|0]=d}}while(0);b[4821334]=(b[4821334]|0)-1&65535;d=c[2410667]|0;i=a[9642649]|0;h=c[9700656+((d>>>8&255)<<2)>>2]|0;if((h|0)!=0){a[h+(d&255)|0]=i;k=c[2426870]|0;c[2410662]=k;l=k&65535;b[4821324]=l;return}h=c[2444172]|0;if((h|0)==0){k=c[2426870]|0;c[2410662]=k;l=k&65535;b[4821324]=l;return}gg[h&4095](d&65535,i);k=c[2426870]|0;c[2410662]=k;l=k&65535;b[4821324]=l;return}function fRJ(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c[2426870]=c[2410665];d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9707480]=h;b[4821324]=i+1&65535;i=c[2426870]|0;h=i&65535;e=c[9699632+((i>>>8&255)<<2)>>2]|0;do{if((e|0)==0){d=c[3528598]|0;if((d|0)==0){return}else{k=gj[d&4095](h)|0;break}}else{k=a[e+(i&255)|0]|0}}while(0);if(k<<24>>24==0){return}i=k;k=a[9642680]|0;e=b[4821328]|0;do{i=i-1&255;h=e&1|k&-14;e=(e&65535)>>>1;k=e<<16>>16==0?h|4:h;}while(i<<24>>24!=0);a[9642680]=k;b[4821328]=e;return}function fRK(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c[2426870]=c[2410665];d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9707480]=h;b[4821324]=i+1&65535;i=c[2426870]|0;h=i&65535;e=c[9699632+((i>>>8&255)<<2)>>2]|0;do{if((e|0)==0){d=c[3528598]|0;if((d|0)==0){return}else{k=gj[d&4095](h)|0;break}}else{k=a[e+(i&255)|0]|0}}while(0);if(k<<24>>24==0){return}i=k;k=a[9642680]|0;e=b[4821328]|0;while(1){h=i-1&255;l=(k&255)<<15|(e&65535)>>>1;d=e&1|k&-14|k<<3&8;m=l<<16>>16==0?d|4:d;if(h<<24>>24==0){break}else{i=h;k=m;e=l}}a[9642680]=m;b[4821328]=l;return}function fRL(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c[2426870]=c[2410665];d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9707480]=h;b[4821324]=i+1&65535;i=c[2426870]|0;h=i&65535;e=c[9699632+((i>>>8&255)<<2)>>2]|0;do{if((e|0)==0){d=c[3528598]|0;if((d|0)==0){return}else{k=gj[d&4095](h)|0;break}}else{k=a[e+(i&255)|0]|0}}while(0);if(k<<24>>24==0){return}i=k;k=a[9642680]|0;e=b[4821328]|0;while(1){h=i-1&255;l=e&-32768|(e&65535)>>>1;d=(e&1|k&-14)&255|(e&65535)>>>12&8;if(l<<16>>16==0){m=(d|4)&255}else{m=d&255}if(h<<24>>24==0){break}else{i=h;k=m;e=l}}a[9642680]=m;b[4821328]=l;return}function fRM(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c[2426870]=c[2410665];d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9707480]=h;b[4821324]=i+1&65535;i=c[2426870]|0;h=i&65535;e=c[9699632+((i>>>8&255)<<2)>>2]|0;do{if((e|0)==0){d=c[3528598]|0;if((d|0)==0){return}else{k=gj[d&4095](h)|0;break}}else{k=a[e+(i&255)|0]|0}}while(0);if(k<<24>>24==0){return}i=k;k=b[4821328]|0;e=a[9642680]|0;do{i=i-1&255;h=k&65535;d=h<<1;f=(h>>>11&8|e&-16&255)&255;k=d&65535;e=((d^h)>>>14&2|h>>>15|(k<<16>>16==0?f|4:f)&255)&255;}while(i<<24>>24!=0);b[4821328]=k;a[9642680]=e;return}function fRN(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c[2426870]=c[2410665];d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9707480]=h;b[4821324]=i+1&65535;i=c[2426870]|0;h=i&65535;e=c[9699632+((i>>>8&255)<<2)>>2]|0;do{if((e|0)==0){d=c[3528598]|0;if((d|0)==0){return}else{k=gj[d&4095](h)|0;break}}else{k=a[e+(i&255)|0]|0}}while(0);if(k<<24>>24==0){return}i=k;k=a[9642680]|0;e=b[4821328]|0;while(1){h=i-1&255;d=(e&65535)>>>15;f=e<<1;l=d|f;j=(f&65535)>>>12&8|(k&-14|d&255)&255;if(l<<16>>16==0){m=(j|4)&255}else{m=j&255}if(h<<24>>24==0){break}else{i=h;k=m;e=l}}a[9642680]=m;b[4821328]=l;return}function fRO(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c[2426870]=c[2410665];d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9707480]=h;b[4821324]=i+1&65535;i=c[2426870]|0;h=i&65535;e=c[9700656+((i>>>8&255)<<2)>>2]|0;do{if((e|0)==0){d=c[2444172]|0;if((d|0)==0){break}gg[d&4095](h,0)}else{a[e+(i&255)|0]=0}}while(0);e=i+1|0;i=c[9700656+((e>>>8&255)<<2)>>2]|0;if((i|0)!=0){a[i+(e&255)|0]=0;k=a[9642680]|0;l=k&-16;m=l|4;a[9642680]=m;return}i=c[2444172]|0;if((i|0)==0){k=a[9642680]|0;l=k&-16;m=l|4;a[9642680]=m;return}gg[i&4095](e&65535,0);k=a[9642680]|0;l=k&-16;m=l|4;a[9642680]=m;return}function fRP(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c[2426870]=c[2410665];d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9707480]=h;b[4821324]=i+1&65535;i=c[2426870]|0;h=i&65535;e=c[9699632+((i>>>8&255)<<2)>>2]|0;do{if((e|0)==0){d=c[3528598]|0;if((d|0)==0){k=0;break}k=gj[d&4095](h)|0}else{k=a[e+(i&255)|0]|0}}while(0);e=(k&255)<<8;k=i+1|0;i=k&65535;h=c[9699632+((k>>>8&255)<<2)>>2]|0;do{if((h|0)==0){d=c[3528598]|0;if((d|0)==0){l=0;break}l=gj[d&4095](i)|0}else{l=a[h+(k&255)|0]|0}}while(0);k=-(l&255|e)|0;l=k&255;h=k>>>8;i=h&255;d=h<<8;h=k>>>12&8|a[9642680]&-16&255;a[9642680]=((k>>>1^e^d)>>>14&2|k>>>16&1|(((d|k&255)&65535)<<16>>16==0?h|4:h)&252)&255;h=c[2426870]|0;k=h&65535;d=c[9700656+((h>>>8&255)<<2)>>2]|0;do{if((d|0)==0){e=c[2444172]|0;if((e|0)==0){break}gg[e&4095](k,i)}else{a[d+(h&255)|0]=i}}while(0);i=h+1|0;h=c[9700656+((i>>>8&255)<<2)>>2]|0;if((h|0)!=0){a[h+(i&255)|0]=l;return}h=c[2444172]|0;if((h|0)==0){return}gg[h&4095](i&65535,l);return}function fRQ(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c[2426870]=c[2410665];d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9707480]=h;b[4821324]=i+1&65535;i=c[2426870]|0;h=i&65535;e=c[9699632+((i>>>8&255)<<2)>>2]|0;do{if((e|0)==0){d=c[3528598]|0;if((d|0)==0){k=0;break}k=gj[d&4095](h)|0}else{k=a[e+(i&255)|0]|0}}while(0);e=(k&255)<<8;k=i+1|0;i=k&65535;h=c[9699632+((k>>>8&255)<<2)>>2]|0;do{if((h|0)==0){d=c[3528598]|0;if((d|0)==0){l=0;break}l=gj[d&4095](i)|0}else{l=a[h+(k&255)|0]|0}}while(0);k=(l&255|e)+1|0;e=k&255;l=k>>>8;h=l&255;i=l<<8;l=k>>>12&8|a[9642680]&-15&255;a[9642680]=((i^k>>>1)>>>14&2|k>>>16&1|(((i|k&255)&65535)<<16>>16==0?l|4:l)&253)&255;l=c[2426870]|0;k=l&65535;i=c[9700656+((l>>>8&255)<<2)>>2]|0;do{if((i|0)==0){d=c[2444172]|0;if((d|0)==0){break}gg[d&4095](k,h)}else{a[i+(l&255)|0]=h}}while(0);h=l+1|0;l=c[9700656+((h>>>8&255)<<2)>>2]|0;if((l|0)!=0){a[l+(h&255)|0]=e;return}l=c[2444172]|0;if((l|0)==0){return}gg[l&4095](h&65535,e);return}function fRR(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c[2426870]=c[2410665];d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](e)|0;h=j;i=b[4821324]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9707480]=h;b[4821324]=i+1&65535;i=c[2426870]|0;h=i&65535;e=c[9699632+((i>>>8&255)<<2)>>2]|0;do{if((e|0)==0){d=c[3528598]|0;if((d|0)==0){k=0;break}k=gj[d&4095](h)|0}else{k=a[e+(i&255)|0]|0}}while(0);e=(k&255)<<8;k=i+1|0;i=k&65535;h=c[9699632+((k>>>8&255)<<2)>>2]|0;do{if((h|0)==0){d=c[3528598]|0;if((d|0)==0){l=0;break}l=gj[d&4095](i)|0}else{l=a[h+(k&255)|0]|0}}while(0);k=(l&255|e)-1|0;e=k&255;l=k>>>8;h=l&255;i=l<<8;l=k>>>12&8|a[9642680]&-15&255;a[9642680]=((i^k>>>1)>>>14&2|k>>>16&1|(((i|k&255)&65535)<<16>>16==0?l|4:l)&253)&255;l=c[2426870]|0;k=l&65535;i=c[9700656+((l>>>8&255)<<2)>>2]|0;do{if((i|0)==0){d=c[2444172]|0;if((d|0)==0){break}gg[d&4095](k,h)}else{a[i+(l&255)|0]=h}}while(0);h=l+1|0;l=c[9700656+((h>>>8&255)<<2)>>2]|0;if((l|0)!=0){a[l+(h&255)|0]=e;return}l=c[2444172]|0;if((l|0)==0){return}gg[l&4095](h&65535,e);return}function fRS(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a[9642680]=a[9642680]&-15;c[2426870]=c[2410665];e=c[2410662]|0;f=e&65535;g=c[9701680+((e>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[3528598]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](f)|0;i=k;j=b[4821324]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9707480]=i;b[4821324]=j+1&65535;j=c[2426870]|0;i=j&65535;f=c[9699632+((j>>>8&255)<<2)>>2]|0;do{if((f|0)==0){e=c[3528598]|0;if((e|0)==0){l=0;break}l=gj[e&4095](i)|0}else{l=a[f+(j&255)|0]|0}}while(0);f=l&255;l=f<<8;i=j+1|0;j=i&65535;e=c[9699632+((i>>>8&255)<<2)>>2]|0;do{if((e|0)==0){g=c[3528598]|0;if((g|0)==0){m=0;break}m=gj[g&4095](j)|0}else{m=a[e+(i&255)|0]|0}}while(0);i=d[9642680]|0|f>>>4&8;if((m&255|l|0)!=0){n=i&255;a[9642680]=n;return}n=(i|4)&255;a[9642680]=n;return}function fRT(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=d;j=e;break}k=gj[g&4095](e)|0;g=c[2410662]|0;h=k;i=g;j=g&65535}else{h=a[f+(d&255)|0]|0;i=d;j=e}}while(0);e=h&255;h=e<<8;d=i+1|0;i=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){l=0;m=j;break}k=gj[g&4095](i)|0;l=k;m=b[4821324]|0}else{l=a[f+(d&255)|0]|0;m=j}}while(0);j=l&255;l=j|h;c[2426870]=l;b[4821324]=m+2&65535;m=l&65535;l=c[9699632+(e<<2)>>2]|0;do{if((l|0)==0){e=c[3528598]|0;if((e|0)==0){n=0;break}n=gj[e&4095](m)|0}else{n=a[l+j|0]|0}}while(0);a[9642657]=n;j=(n&255)>>>4&8|a[9642680]&-15;a[9642680]=n<<24>>24==0?j|4:j;return}function fRU(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=d;j=e;break}k=gj[g&4095](e)|0;g=c[2410662]|0;h=k;i=g;j=g&65535}else{h=a[f+(d&255)|0]|0;i=d;j=e}}while(0);e=h&255;h=e<<8;d=i+1|0;i=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){l=0;m=j;break}k=gj[g&4095](i)|0;l=k;m=b[4821324]|0}else{l=a[f+(d&255)|0]|0;m=j}}while(0);j=l&255;l=j|h;c[2426870]=l;b[4821324]=m+2&65535;m=l&65535;l=c[9699632+(e<<2)>>2]|0;do{if((l|0)==0){e=c[3528598]|0;if((e|0)==0){n=0;break}n=gj[e&4095](m)|0}else{n=a[l+j|0]|0}}while(0);a[9642656]=n;j=(n&255)>>>4&8|a[9642680]&-15;a[9642680]=n<<24>>24==0?j|4:j;return}function fRV(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=d;j=e;break}k=gj[g&4095](e)|0;g=c[2410662]|0;h=k;i=g;j=g&65535}else{h=a[f+(d&255)|0]|0;i=d;j=e}}while(0);e=h&255;h=e<<8;d=i+1|0;i=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){l=0;m=j;break}k=gj[g&4095](i)|0;l=k;m=b[4821324]|0}else{l=a[f+(d&255)|0]|0;m=j}}while(0);j=l&255;l=j|h;c[2426870]=l;b[4821324]=m+2&65535;m=l&65535;l=c[9699632+(e<<2)>>2]|0;do{if((l|0)==0){e=c[3528598]|0;if((e|0)==0){n=0;break}n=gj[e&4095](m)|0}else{n=a[l+j|0]|0}}while(0);j=a[9642657]|0;l=(j&255)+(n&255)|0;m=(l>>>4&8|a[9642680]&-48&255)&255;e=l&255;h=(j^n)&255^l;a[9642680]=(h<<1&32|l>>>8&1|(h^l>>>1)>>>6&2|(e<<24>>24==0?m|4:m)&255)&255;a[9642657]=e;return}function fRW(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=d;j=e;break}k=gj[g&4095](e)|0;g=c[2410662]|0;h=k;i=g;j=g&65535}else{h=a[f+(d&255)|0]|0;i=d;j=e}}while(0);e=h&255;h=e<<8;d=i+1|0;i=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){l=0;m=j;break}k=gj[g&4095](i)|0;l=k;m=b[4821324]|0}else{l=a[f+(d&255)|0]|0;m=j}}while(0);j=l&255;l=j|h;c[2426870]=l;b[4821324]=m+2&65535;m=l&65535;l=c[9699632+(e<<2)>>2]|0;do{if((l|0)==0){e=c[3528598]|0;if((e|0)==0){n=0;break}n=gj[e&4095](m)|0}else{n=a[l+j|0]|0}}while(0);j=a[9642656]|0;l=(j&255)+(n&255)|0;m=(l>>>4&8|a[9642680]&-48&255)&255;e=l&255;h=(j^n)&255^l;a[9642680]=(h<<1&32|l>>>8&1|(h^l>>>1)>>>6&2|(e<<24>>24==0?m|4:m)&255)&255;a[9642656]=e;return}function fRX(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=d;j=e;break}k=gj[g&4095](e)|0;g=c[2410662]|0;h=k;i=g;j=g&65535}else{h=a[f+(d&255)|0]|0;i=d;j=e}}while(0);e=h&255;h=e<<8;d=i+1|0;i=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){l=0;m=j;break}k=gj[g&4095](i)|0;l=k;m=b[4821324]|0}else{l=a[f+(d&255)|0]|0;m=j}}while(0);j=l&255;l=j|h;c[2426870]=l;b[4821324]=m+2&65535;m=l&65535;l=c[9699632+(e<<2)>>2]|0;do{if((l|0)==0){e=c[3528598]|0;if((e|0)==0){n=0;break}n=gj[e&4095](m)|0}else{n=a[l+j|0]|0}}while(0);j=a[9642657]|0;l=a[9642680]|0;m=(j&255)+(n&255)+(l&1)|0;e=(m>>>4&8|l&-48&255)&255;l=m&255;h=m^(j^n)&255;a[9642680]=(h<<1&32|m>>>8&1|(h^m>>>1)>>>6&2|(l<<24>>24==0?e|4:e)&255)&255;a[9642657]=l;return}function fRY(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=d;j=e;break}k=gj[g&4095](e)|0;g=c[2410662]|0;h=k;i=g;j=g&65535}else{h=a[f+(d&255)|0]|0;i=d;j=e}}while(0);e=h&255;h=e<<8;d=i+1|0;i=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){l=0;m=j;break}k=gj[g&4095](i)|0;l=k;m=b[4821324]|0}else{l=a[f+(d&255)|0]|0;m=j}}while(0);j=l&255;l=j|h;c[2426870]=l;b[4821324]=m+2&65535;m=l&65535;l=c[9699632+(e<<2)>>2]|0;do{if((l|0)==0){e=c[3528598]|0;if((e|0)==0){n=0;break}n=gj[e&4095](m)|0}else{n=a[l+j|0]|0}}while(0);j=a[9642656]|0;l=a[9642680]|0;m=(j&255)+(n&255)+(l&1)|0;e=(m>>>4&8|l&-48&255)&255;l=m&255;h=m^(j^n)&255;a[9642680]=(h<<1&32|m>>>8&1|(h^m>>>1)>>>6&2|(l<<24>>24==0?e|4:e)&255)&255;a[9642656]=l;return}function fRZ(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=d;j=e;break}k=gj[g&4095](e)|0;g=c[2410662]|0;h=k;i=g;j=g&65535}else{h=a[f+(d&255)|0]|0;i=d;j=e}}while(0);e=h&255;h=e<<8;d=i+1|0;i=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){l=0;m=j;break}k=gj[g&4095](i)|0;l=k;m=b[4821324]|0}else{l=a[f+(d&255)|0]|0;m=j}}while(0);j=l&255;l=j|h;c[2426870]=l;b[4821324]=m+2&65535;m=l&65535;l=c[9699632+(e<<2)>>2]|0;do{if((l|0)==0){e=c[3528598]|0;if((e|0)==0){n=0;break}n=gj[e&4095](m)|0}else{n=a[l+j|0]|0}}while(0);j=a[9642657]|0;l=(j&255)-(n&255)|0;m=(l>>>4&8|a[9642680]&-16&255)&255;e=l&255;a[9642680]=(((j^n)&255^l^l>>>1)>>>6&2|l>>>8&1|(e<<24>>24==0?m|4:m)&255)&255;a[9642657]=e;return}function fR_(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=d;j=e;break}k=gj[g&4095](e)|0;g=c[2410662]|0;h=k;i=g;j=g&65535}else{h=a[f+(d&255)|0]|0;i=d;j=e}}while(0);e=h&255;h=e<<8;d=i+1|0;i=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){l=0;m=j;break}k=gj[g&4095](i)|0;l=k;m=b[4821324]|0}else{l=a[f+(d&255)|0]|0;m=j}}while(0);j=l&255;l=j|h;c[2426870]=l;b[4821324]=m+2&65535;m=l&65535;l=c[9699632+(e<<2)>>2]|0;do{if((l|0)==0){e=c[3528598]|0;if((e|0)==0){n=0;break}n=gj[e&4095](m)|0}else{n=a[l+j|0]|0}}while(0);j=a[9642656]|0;l=(j&255)-(n&255)|0;m=(l>>>4&8|a[9642680]&-16&255)&255;e=l&255;a[9642680]=(((j^n)&255^l^l>>>1)>>>6&2|l>>>8&1|(e<<24>>24==0?m|4:m)&255)&255;a[9642656]=e;return}function fR$(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=d;j=e;break}k=gj[g&4095](e)|0;g=c[2410662]|0;h=k;i=g;j=g&65535}else{h=a[f+(d&255)|0]|0;i=d;j=e}}while(0);e=h&255;h=e<<8;d=i+1|0;i=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){l=0;m=j;break}k=gj[g&4095](i)|0;l=k;m=b[4821324]|0}else{l=a[f+(d&255)|0]|0;m=j}}while(0);j=l&255;l=j|h;c[2426870]=l;b[4821324]=m+2&65535;m=l&65535;l=c[9699632+(e<<2)>>2]|0;do{if((l|0)==0){e=c[3528598]|0;if((e|0)==0){n=0;break}n=gj[e&4095](m)|0}else{n=a[l+j|0]|0}}while(0);j=a[9642657]|0;l=a[9642680]|0;m=(j&255)-(n&255)-(l&1)|0;e=(m>>>4&8|l&-16&255)&255;l=m&255;a[9642680]=((m^(j^n)&255^m>>>1)>>>6&2|m>>>8&1|(l<<24>>24==0?e|4:e)&255)&255;a[9642657]=l;return}function fR0(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=d;j=e;break}k=gj[g&4095](e)|0;g=c[2410662]|0;h=k;i=g;j=g&65535}else{h=a[f+(d&255)|0]|0;i=d;j=e}}while(0);e=h&255;h=e<<8;d=i+1|0;i=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){l=0;m=j;break}k=gj[g&4095](i)|0;l=k;m=b[4821324]|0}else{l=a[f+(d&255)|0]|0;m=j}}while(0);j=l&255;l=j|h;c[2426870]=l;b[4821324]=m+2&65535;m=l&65535;l=c[9699632+(e<<2)>>2]|0;do{if((l|0)==0){e=c[3528598]|0;if((e|0)==0){n=0;break}n=gj[e&4095](m)|0}else{n=a[l+j|0]|0}}while(0);j=a[9642656]|0;l=a[9642680]|0;m=(j&255)-(n&255)-(l&1)|0;e=(m>>>4&8|l&-16&255)&255;l=m&255;a[9642680]=((m^(j^n)&255^m>>>1)>>>6&2|m>>>8&1|(l<<24>>24==0?e|4:e)&255)&255;a[9642656]=l;return}function fR1(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=d;j=e;break}k=gj[g&4095](e)|0;g=c[2410662]|0;h=k;i=g;j=g&65535}else{h=a[f+(d&255)|0]|0;i=d;j=e}}while(0);e=h&255;h=e<<8;d=i+1|0;i=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){l=0;m=j;break}k=gj[g&4095](i)|0;l=k;m=b[4821324]|0}else{l=a[f+(d&255)|0]|0;m=j}}while(0);j=l&255;l=j|h;c[2426870]=l;b[4821324]=m+2&65535;m=l&65535;l=c[9699632+(e<<2)>>2]|0;do{if((l|0)==0){e=c[3528598]|0;if((e|0)==0){n=0;break}n=gj[e&4095](m)|0}else{n=a[l+j|0]|0}}while(0);j=a[9642657]&n;a[9642657]=j;n=(j&255)>>>4&8|a[9642680]&-15;a[9642680]=j<<24>>24==0?n|4:n;return}function fR2(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=d;j=e;break}k=gj[g&4095](e)|0;g=c[2410662]|0;h=k;i=g;j=g&65535}else{h=a[f+(d&255)|0]|0;i=d;j=e}}while(0);e=h&255;h=e<<8;d=i+1|0;i=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){l=0;m=j;break}k=gj[g&4095](i)|0;l=k;m=b[4821324]|0}else{l=a[f+(d&255)|0]|0;m=j}}while(0);j=l&255;l=j|h;c[2426870]=l;b[4821324]=m+2&65535;m=l&65535;l=c[9699632+(e<<2)>>2]|0;do{if((l|0)==0){e=c[3528598]|0;if((e|0)==0){n=0;break}n=gj[e&4095](m)|0}else{n=a[l+j|0]|0}}while(0);j=a[9642656]&n;a[9642656]=j;n=(j&255)>>>4&8|a[9642680]&-15;a[9642680]=j<<24>>24==0?n|4:n;return}function fR3(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=d;j=e;break}k=gj[g&4095](e)|0;g=c[2410662]|0;h=k;i=g;j=g&65535}else{h=a[f+(d&255)|0]|0;i=d;j=e}}while(0);e=h&255;h=e<<8;d=i+1|0;i=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){l=0;m=j;break}k=gj[g&4095](i)|0;l=k;m=b[4821324]|0}else{l=a[f+(d&255)|0]|0;m=j}}while(0);j=l&255;l=j|h;c[2426870]=l;b[4821324]=m+2&65535;m=l&65535;l=c[9699632+(e<<2)>>2]|0;do{if((l|0)==0){e=c[3528598]|0;if((e|0)==0){n=0;break}n=gj[e&4095](m)|0}else{n=a[l+j|0]|0}}while(0);j=a[9642657]&n;n=(j&255)>>>4&8|a[9642680]&-15;a[9642680]=j<<24>>24==0?n|4:n;return}function fR4(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=d;j=e;break}k=gj[g&4095](e)|0;g=c[2410662]|0;h=k;i=g;j=g&65535}else{h=a[f+(d&255)|0]|0;i=d;j=e}}while(0);e=h&255;h=e<<8;d=i+1|0;i=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){l=0;m=j;break}k=gj[g&4095](i)|0;l=k;m=b[4821324]|0}else{l=a[f+(d&255)|0]|0;m=j}}while(0);j=l&255;l=j|h;c[2426870]=l;b[4821324]=m+2&65535;m=l&65535;l=c[9699632+(e<<2)>>2]|0;do{if((l|0)==0){e=c[3528598]|0;if((e|0)==0){n=0;break}n=gj[e&4095](m)|0}else{n=a[l+j|0]|0}}while(0);j=a[9642656]&n;n=(j&255)>>>4&8|a[9642680]&-15;a[9642680]=j<<24>>24==0?n|4:n;return}function fR5(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=d;j=e;break}k=gj[g&4095](e)|0;g=c[2410662]|0;h=k;i=g;j=g&65535}else{h=a[f+(d&255)|0]|0;i=d;j=e}}while(0);e=h&255;h=e<<8;d=i+1|0;i=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){l=0;m=j;break}k=gj[g&4095](i)|0;l=k;m=b[4821324]|0}else{l=a[f+(d&255)|0]|0;m=j}}while(0);j=l&255;l=j|h;c[2426870]=l;b[4821324]=m+2&65535;m=l&65535;l=c[9699632+(e<<2)>>2]|0;do{if((l|0)==0){e=c[3528598]|0;if((e|0)==0){n=0;break}n=gj[e&4095](m)|0}else{n=a[l+j|0]|0}}while(0);j=a[9642657]|0;l=j^n;a[9642657]=l;m=(l&255)>>>4&8|a[9642680]&-15;a[9642680]=j<<24>>24==n<<24>>24?m|4:m;return}function fR6(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=d;j=e;break}k=gj[g&4095](e)|0;g=c[2410662]|0;h=k;i=g;j=g&65535}else{h=a[f+(d&255)|0]|0;i=d;j=e}}while(0);e=h&255;h=e<<8;d=i+1|0;i=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){l=0;m=j;break}k=gj[g&4095](i)|0;l=k;m=b[4821324]|0}else{l=a[f+(d&255)|0]|0;m=j}}while(0);j=l&255;l=j|h;c[2426870]=l;b[4821324]=m+2&65535;m=l&65535;l=c[9699632+(e<<2)>>2]|0;do{if((l|0)==0){e=c[3528598]|0;if((e|0)==0){n=0;break}n=gj[e&4095](m)|0}else{n=a[l+j|0]|0}}while(0);j=a[9642656]|0;l=j^n;a[9642656]=l;m=(l&255)>>>4&8|a[9642680]&-15;a[9642680]=j<<24>>24==n<<24>>24?m|4:m;return}function fR7(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=d;j=e;break}k=gj[g&4095](e)|0;g=c[2410662]|0;h=k;i=g;j=g&65535}else{h=a[f+(d&255)|0]|0;i=d;j=e}}while(0);e=h&255;h=e<<8;d=i+1|0;i=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){l=0;m=j;break}k=gj[g&4095](i)|0;l=k;m=b[4821324]|0}else{l=a[f+(d&255)|0]|0;m=j}}while(0);j=l&255;l=j|h;c[2426870]=l;b[4821324]=m+2&65535;m=l&65535;l=c[9699632+(e<<2)>>2]|0;do{if((l|0)==0){e=c[3528598]|0;if((e|0)==0){n=0;break}n=gj[e&4095](m)|0}else{n=a[l+j|0]|0}}while(0);j=a[9642657]|n;a[9642657]=j;n=(j&255)>>>4&8|a[9642680]&-15;a[9642680]=j<<24>>24==0?n|4:n;return}function fR8(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=d;j=e;break}k=gj[g&4095](e)|0;g=c[2410662]|0;h=k;i=g;j=g&65535}else{h=a[f+(d&255)|0]|0;i=d;j=e}}while(0);e=h&255;h=e<<8;d=i+1|0;i=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){l=0;m=j;break}k=gj[g&4095](i)|0;l=k;m=b[4821324]|0}else{l=a[f+(d&255)|0]|0;m=j}}while(0);j=l&255;l=j|h;c[2426870]=l;b[4821324]=m+2&65535;m=l&65535;l=c[9699632+(e<<2)>>2]|0;do{if((l|0)==0){e=c[3528598]|0;if((e|0)==0){n=0;break}n=gj[e&4095](m)|0}else{n=a[l+j|0]|0}}while(0);j=a[9642656]|n;a[9642656]=j;n=(j&255)>>>4&8|a[9642680]&-15;a[9642680]=j<<24>>24==0?n|4:n;return}function fR9(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=d;j=e;break}k=gj[g&4095](e)|0;g=c[2410662]|0;h=k;i=g;j=g&65535}else{h=a[f+(d&255)|0]|0;i=d;j=e}}while(0);e=h&255;h=e<<8;d=i+1|0;i=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){l=0;m=j;break}k=gj[g&4095](i)|0;l=k;m=b[4821324]|0}else{l=a[f+(d&255)|0]|0;m=j}}while(0);j=l&255;l=j|h;c[2426870]=l;b[4821324]=m+2&65535;m=l&65535;l=c[9699632+(e<<2)>>2]|0;do{if((l|0)==0){e=c[3528598]|0;if((e|0)==0){n=0;break}n=gj[e&4095](m)|0}else{n=a[l+j|0]|0}}while(0);j=a[9642657]|0;l=(j&255)-(n&255)|0;m=(l>>>4&8|a[9642680]&-16&255)&255;a[9642680]=(((j^n)&255^l^l>>>1)>>>6&2|l>>>8&1|((l&255)<<24>>24==0?m|4:m)&255)&255;return}function fSa(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=d;j=e;break}k=gj[g&4095](e)|0;g=c[2410662]|0;h=k;i=g;j=g&65535}else{h=a[f+(d&255)|0]|0;i=d;j=e}}while(0);e=h&255;h=e<<8;d=i+1|0;i=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){l=0;m=j;break}k=gj[g&4095](i)|0;l=k;m=b[4821324]|0}else{l=a[f+(d&255)|0]|0;m=j}}while(0);j=l&255;l=j|h;c[2426870]=l;b[4821324]=m+2&65535;m=l&65535;l=c[9699632+(e<<2)>>2]|0;do{if((l|0)==0){e=c[3528598]|0;if((e|0)==0){n=0;break}n=gj[e&4095](m)|0}else{n=a[l+j|0]|0}}while(0);j=a[9642656]|0;l=(j&255)-(n&255)|0;m=(l>>>4&8|a[9642680]&-16&255)&255;a[9642680]=(((j^n)&255^l^l>>>1)>>>6&2|l>>>8&1|((l&255)<<24>>24==0?m|4:m)&255)&255;return}function fSb(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=d;j=e;break}k=gj[g&4095](e)|0;g=c[2410662]|0;h=k;i=g;j=g&65535}else{h=a[f+(d&255)|0]|0;i=d;j=e}}while(0);e=h&255;h=e<<8;d=i+1|0;i=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){l=0;m=j;break}k=gj[g&4095](i)|0;l=k;m=b[4821324]|0}else{l=a[f+(d&255)|0]|0;m=j}}while(0);j=l&255;l=j|h;c[2426870]=l;b[4821324]=m+2&65535;m=l&65535;l=c[9699632+(e<<2)>>2]|0;do{if((l|0)==0){e=c[3528598]|0;if((e|0)==0){n=0;break}n=gj[e&4095](m)|0}else{n=a[l+j|0]|0}}while(0);j=c[2410675]|0;if((j|0)==0){return}gf[j&2047](n&255);return}function fSc(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=a[9642657]|0;e=(d&255)>>>4&8|a[9642680]&-15;a[9642680]=d<<24>>24==0?e|4:e;e=c[2410662]|0;d=e&65535;f=c[9701680+((e>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;j=d;break}k=gj[g&4095](d)|0;g=c[2410662]|0;h=k;i=g;j=g&65535}else{h=a[f+(e&255)|0]|0;i=e;j=d}}while(0);d=h&255;h=d<<8;e=i+1|0;i=e&65535;f=c[9701680+((e>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){l=0;m=j;break}k=gj[g&4095](i)|0;l=k;m=b[4821324]|0}else{l=a[f+(e&255)|0]|0;m=j}}while(0);j=l&255;l=j|h;c[2426870]=l;b[4821324]=m+2&65535;m=a[9642657]|0;h=c[9700656+(d<<2)>>2]|0;if((h|0)!=0){a[h+j|0]=m;return}j=c[2444172]|0;if((j|0)==0){return}gg[j&4095](l&65535,m);return}function fSd(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=a[9642656]|0;e=(d&255)>>>4&8|a[9642680]&-15;a[9642680]=d<<24>>24==0?e|4:e;e=c[2410662]|0;d=e&65535;f=c[9701680+((e>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=e;j=d;break}k=gj[g&4095](d)|0;g=c[2410662]|0;h=k;i=g;j=g&65535}else{h=a[f+(e&255)|0]|0;i=e;j=d}}while(0);d=h&255;h=d<<8;e=i+1|0;i=e&65535;f=c[9701680+((e>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){l=0;m=j;break}k=gj[g&4095](i)|0;l=k;m=b[4821324]|0}else{l=a[f+(e&255)|0]|0;m=j}}while(0);j=l&255;l=j|h;c[2426870]=l;b[4821324]=m+2&65535;m=a[9642656]|0;h=c[9700656+(d<<2)>>2]|0;if((h|0)!=0){a[h+j|0]=m;return}j=c[2444172]|0;if((j|0)==0){return}gg[j&4095](l&65535,m);return}function fSe(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=d;j=e;break}k=gj[g&4095](e)|0;g=c[2410662]|0;h=k;i=g;j=g&65535}else{h=a[f+(d&255)|0]|0;i=d;j=e}}while(0);e=h&255;h=e<<8;d=i+1|0;i=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){l=0;m=j;break}k=gj[g&4095](i)|0;l=k;m=b[4821324]|0}else{l=a[f+(d&255)|0]|0;m=j}}while(0);j=l&255;l=j|h;c[2426870]=l;b[4821324]=m+2&65535;m=l&65535;h=c[9699632+(e<<2)>>2]|0;do{if((h|0)==0){e=c[3528598]|0;if((e|0)==0){n=0;break}n=gj[e&4095](m)|0}else{n=a[h+j|0]|0}}while(0);j=n&255;n=j<<8;h=l+1|0;l=h&65535;m=c[9699632+((h>>>8&255)<<2)>>2]|0;do{if((m|0)==0){e=c[3528598]|0;if((e|0)==0){o=0;break}o=gj[e&4095](l)|0}else{o=a[m+(h&255)|0]|0}}while(0);h=o&255|n;c[2410664]=h;n=a[9642680]&-15;a[9642680]=n;o=n&255|j>>>4&8;if((h|0)!=0){p=o&255;a[9642680]=p;return}p=(o|4)&255;a[9642680]=p;return}function fSf(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=d;j=e;break}k=gj[g&4095](e)|0;g=c[2410662]|0;h=k;i=g;j=g&65535}else{h=a[f+(d&255)|0]|0;i=d;j=e}}while(0);e=h&255;h=e<<8;d=i+1|0;i=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){l=0;m=j;break}k=gj[g&4095](i)|0;l=k;m=b[4821324]|0}else{l=a[f+(d&255)|0]|0;m=j}}while(0);j=l&255;l=j|h;c[2426870]=l;b[4821324]=m+2&65535;m=l&65535;h=c[9699632+(e<<2)>>2]|0;do{if((h|0)==0){e=c[3528598]|0;if((e|0)==0){n=0;break}n=gj[e&4095](m)|0}else{n=a[h+j|0]|0}}while(0);j=n&255;n=j<<8;h=l+1|0;l=h&65535;m=c[9699632+((h>>>8&255)<<2)>>2]|0;do{if((m|0)==0){e=c[3528598]|0;if((e|0)==0){o=0;break}o=gj[e&4095](l)|0}else{o=a[m+(h&255)|0]|0}}while(0);h=o&255|n;c[2410668]=h;n=a[9642680]&-15;a[9642680]=n;o=n&255|j>>>4&8;if((h|0)!=0){p=o&255;a[9642680]=p;return}p=(o|4)&255;a[9642680]=p;return}function fSg(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=d;j=e;break}k=gj[g&4095](e)|0;g=c[2410662]|0;h=k;i=g;j=g&65535}else{h=a[f+(d&255)|0]|0;i=d;j=e}}while(0);e=h&255;h=e<<8;d=i+1|0;i=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){l=0;m=j;break}k=gj[g&4095](i)|0;l=k;m=b[4821324]|0}else{l=a[f+(d&255)|0]|0;m=j}}while(0);j=l&255;l=j|h;c[2426870]=l;b[4821324]=m+2&65535;m=l&65535;h=c[9699632+(e<<2)>>2]|0;do{if((h|0)==0){e=c[3528598]|0;if((e|0)==0){n=0;break}n=gj[e&4095](m)|0}else{n=a[h+j|0]|0}}while(0);j=n&255;n=j<<8;h=l+1|0;l=h&65535;m=c[9699632+((h>>>8&255)<<2)>>2]|0;do{if((m|0)==0){e=c[3528598]|0;if((e|0)==0){o=0;break}o=gj[e&4095](l)|0}else{o=a[m+(h&255)|0]|0}}while(0);h=o&255|n;c[2410669]=h;n=a[9642680]&-15;a[9642680]=n;o=n&255|j>>>4&8;if((h|0)!=0){p=o&255;a[9642680]=p;return}p=(o|4)&255;a[9642680]=p;return}function fSh(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=d;j=e;break}k=gj[g&4095](e)|0;g=c[2410662]|0;h=k;i=g;j=g&65535}else{h=a[f+(d&255)|0]|0;i=d;j=e}}while(0);e=h&255;h=e<<8;d=i+1|0;i=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){l=0;m=j;break}k=gj[g&4095](i)|0;l=k;m=b[4821324]|0}else{l=a[f+(d&255)|0]|0;m=j}}while(0);j=l&255;l=j|h;c[2426870]=l;b[4821324]=m+2&65535;m=l&65535;h=c[9699632+(e<<2)>>2]|0;do{if((h|0)==0){e=c[3528598]|0;if((e|0)==0){n=0;break}n=gj[e&4095](m)|0}else{n=a[h+j|0]|0}}while(0);j=n&255;n=j<<8;h=l+1|0;l=h&65535;m=c[9699632+((h>>>8&255)<<2)>>2]|0;do{if((m|0)==0){e=c[3528598]|0;if((e|0)==0){o=0;break}o=gj[e&4095](l)|0}else{o=a[m+(h&255)|0]|0}}while(0);h=o&255|n;c[2410666]=h;n=a[9642680]&-15;a[9642680]=n;o=n&255|j>>>4&8;if((h|0)!=0){p=o&255;a[9642680]=p;return}p=(o|4)&255;a[9642680]=p;return}function fSi(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=d;j=e;break}k=gj[g&4095](e)|0;g=c[2410662]|0;h=k;i=g;j=g&65535}else{h=a[f+(d&255)|0]|0;i=d;j=e}}while(0);e=h&255;h=e<<8;d=i+1|0;i=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){l=0;m=j;break}k=gj[g&4095](i)|0;l=k;m=b[4821324]|0}else{l=a[f+(d&255)|0]|0;m=j}}while(0);j=l&255;l=j|h;c[2426870]=l;b[4821324]=m+2&65535;m=l&65535;h=c[9699632+(e<<2)>>2]|0;do{if((h|0)==0){e=c[3528598]|0;if((e|0)==0){n=0;break}n=gj[e&4095](m)|0}else{n=a[h+j|0]|0}}while(0);j=n&255;n=j<<8;h=l+1|0;l=h&65535;m=c[9699632+((h>>>8&255)<<2)>>2]|0;do{if((m|0)==0){e=c[3528598]|0;if((e|0)==0){o=0;break}o=gj[e&4095](l)|0}else{o=a[m+(h&255)|0]|0}}while(0);h=o&255|n;c[2410667]=h;n=a[9642680]&-15;a[9642680]=n;o=n&255|j>>>4&8;if((h|0)!=0){p=o&255;a[9642680]=p;q=a[9642688]|0;r=q|32;a[9642688]=r;return}p=(o|4)&255;a[9642680]=p;q=a[9642688]|0;r=q|32;a[9642688]=r;return}function fSj(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=c[2410662]|0;f=d&65535;g=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[3528598]|0;if((h|0)==0){i=0;j=d;k=f;break}l=gj[h&4095](f)|0;h=c[2410662]|0;i=l;j=h;k=h&65535}else{i=a[g+(d&255)|0]|0;j=d;k=f}}while(0);f=i&255;i=f<<8;d=j+1|0;j=d&65535;g=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[3528598]|0;if((h|0)==0){m=0;n=k;break}l=gj[h&4095](j)|0;m=l;n=b[4821324]|0}else{m=a[g+(d&255)|0]|0;n=k}}while(0);k=m&255;m=k|i;c[2426870]=m;b[4821324]=n+2&65535;n=m&65535;i=c[9699632+(f<<2)>>2]|0;do{if((i|0)==0){f=c[3528598]|0;if((f|0)==0){o=0;break}o=gj[f&4095](n)|0}else{o=a[i+k|0]|0}}while(0);k=(o&255)<<8;o=m+1|0;m=o&65535;i=c[9699632+((o>>>8&255)<<2)>>2]|0;do{if((i|0)==0){n=c[3528598]|0;if((n|0)==0){p=0;break}p=gj[n&4095](m)|0}else{p=a[i+(o&255)|0]|0}}while(0);o=e[4821328]|0;i=o-(p&255|k)|0;p=(i>>>12&8|a[9642680]&-16&255)&255;a[9642680]=((o^k^i^i>>>1)>>>14&2|i>>>16&1|((i&65535)<<16>>16==0?p|4:p)&255)&255;return}function fSk(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=c[2410662]|0;f=d&65535;g=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[3528598]|0;if((h|0)==0){i=0;j=d;k=f;break}l=gj[h&4095](f)|0;h=c[2410662]|0;i=l;j=h;k=h&65535}else{i=a[g+(d&255)|0]|0;j=d;k=f}}while(0);f=i&255;i=f<<8;d=j+1|0;j=d&65535;g=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[3528598]|0;if((h|0)==0){m=0;n=k;break}l=gj[h&4095](j)|0;m=l;n=b[4821324]|0}else{m=a[g+(d&255)|0]|0;n=k}}while(0);k=m&255;m=k|i;c[2426870]=m;b[4821324]=n+2&65535;n=m&65535;i=c[9699632+(f<<2)>>2]|0;do{if((i|0)==0){f=c[3528598]|0;if((f|0)==0){o=0;break}o=gj[f&4095](n)|0}else{o=a[i+k|0]|0}}while(0);k=(o&255)<<8;o=m+1|0;m=o&65535;i=c[9699632+((o>>>8&255)<<2)>>2]|0;do{if((i|0)==0){n=c[3528598]|0;if((n|0)==0){p=0;break}p=gj[n&4095](m)|0}else{p=a[i+(o&255)|0]|0}}while(0);o=e[4821336]|0;i=o-(p&255|k)|0;p=(i>>>12&8|a[9642680]&-16&255)&255;a[9642680]=((o^k^i^i>>>1)>>>14&2|i>>>16&1|((i&65535)<<16>>16==0?p|4:p)&255)&255;return}function fSl(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=c[2410662]|0;f=d&65535;g=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[3528598]|0;if((h|0)==0){i=0;j=d;k=f;break}l=gj[h&4095](f)|0;h=c[2410662]|0;i=l;j=h;k=h&65535}else{i=a[g+(d&255)|0]|0;j=d;k=f}}while(0);f=i&255;i=f<<8;d=j+1|0;j=d&65535;g=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[3528598]|0;if((h|0)==0){m=0;n=k;break}l=gj[h&4095](j)|0;m=l;n=b[4821324]|0}else{m=a[g+(d&255)|0]|0;n=k}}while(0);k=m&255;m=k|i;c[2426870]=m;b[4821324]=n+2&65535;n=m&65535;i=c[9699632+(f<<2)>>2]|0;do{if((i|0)==0){f=c[3528598]|0;if((f|0)==0){o=0;break}o=gj[f&4095](n)|0}else{o=a[i+k|0]|0}}while(0);k=(o&255)<<8;o=m+1|0;m=o&65535;i=c[9699632+((o>>>8&255)<<2)>>2]|0;do{if((i|0)==0){n=c[3528598]|0;if((n|0)==0){p=0;break}p=gj[n&4095](m)|0}else{p=a[i+(o&255)|0]|0}}while(0);o=e[4821338]|0;i=o-(p&255|k)|0;p=(i>>>12&8|a[9642680]&-16&255)&255;a[9642680]=((o^k^i^i>>>1)>>>14&2|i>>>16&1|((i&65535)<<16>>16==0?p|4:p)&255)&255;return}function fSm(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=c[2410662]|0;f=d&65535;g=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[3528598]|0;if((h|0)==0){i=0;j=d;k=f;break}l=gj[h&4095](f)|0;h=c[2410662]|0;i=l;j=h;k=h&65535}else{i=a[g+(d&255)|0]|0;j=d;k=f}}while(0);f=i&255;i=f<<8;d=j+1|0;j=d&65535;g=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[3528598]|0;if((h|0)==0){m=0;n=k;break}l=gj[h&4095](j)|0;m=l;n=b[4821324]|0}else{m=a[g+(d&255)|0]|0;n=k}}while(0);k=m&255;m=k|i;c[2426870]=m;b[4821324]=n+2&65535;n=m&65535;i=c[9699632+(f<<2)>>2]|0;do{if((i|0)==0){f=c[3528598]|0;if((f|0)==0){o=0;break}o=gj[f&4095](n)|0}else{o=a[i+k|0]|0}}while(0);k=(o&255)<<8;o=m+1|0;m=o&65535;i=c[9699632+((o>>>8&255)<<2)>>2]|0;do{if((i|0)==0){n=c[3528598]|0;if((n|0)==0){p=0;break}p=gj[n&4095](m)|0}else{p=a[i+(o&255)|0]|0}}while(0);o=e[4821332]|0;i=o-(p&255|k)|0;p=(i>>>12&8|a[9642680]&-16&255)&255;a[9642680]=((o^k^i^i>>>1)>>>14&2|i>>>16&1|((i&65535)<<16>>16==0?p|4:p)&255)&255;return}function fSn(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=c[2410662]|0;f=d&65535;g=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[3528598]|0;if((h|0)==0){i=0;j=d;k=f;break}l=gj[h&4095](f)|0;h=c[2410662]|0;i=l;j=h;k=h&65535}else{i=a[g+(d&255)|0]|0;j=d;k=f}}while(0);f=i&255;i=f<<8;d=j+1|0;j=d&65535;g=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[3528598]|0;if((h|0)==0){m=0;n=k;break}l=gj[h&4095](j)|0;m=l;n=b[4821324]|0}else{m=a[g+(d&255)|0]|0;n=k}}while(0);k=m&255;m=k|i;c[2426870]=m;b[4821324]=n+2&65535;n=m&65535;i=c[9699632+(f<<2)>>2]|0;do{if((i|0)==0){f=c[3528598]|0;if((f|0)==0){o=0;break}o=gj[f&4095](n)|0}else{o=a[i+k|0]|0}}while(0);k=(o&255)<<8;o=m+1|0;m=o&65535;i=c[9699632+((o>>>8&255)<<2)>>2]|0;do{if((i|0)==0){n=c[3528598]|0;if((n|0)==0){p=0;break}p=gj[n&4095](m)|0}else{p=a[i+(o&255)|0]|0}}while(0);o=e[4821334]|0;i=o-(p&255|k)|0;p=(i>>>12&8|a[9642680]&-16&255)&255;a[9642680]=((o^k^i^i>>>1)>>>14&2|i>>>16&1|((i&65535)<<16>>16==0?p|4:p)&255)&255;return}function fSo(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=c[2410662]|0;f=d&65535;g=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[3528598]|0;if((h|0)==0){i=0;j=d;k=f;break}l=gj[h&4095](f)|0;h=c[2410662]|0;i=l;j=h;k=h&65535}else{i=a[g+(d&255)|0]|0;j=d;k=f}}while(0);f=i&255;i=f<<8;d=j+1|0;j=d&65535;g=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[3528598]|0;if((h|0)==0){m=0;n=k;break}l=gj[h&4095](j)|0;m=l;n=b[4821324]|0}else{m=a[g+(d&255)|0]|0;n=k}}while(0);k=m&255;m=k|i;c[2426870]=m;b[4821324]=n+2&65535;n=m&65535;i=c[9699632+(f<<2)>>2]|0;do{if((i|0)==0){f=c[3528598]|0;if((f|0)==0){o=0;break}o=gj[f&4095](n)|0}else{o=a[i+k|0]|0}}while(0);k=(o&255)<<8;o=m+1|0;m=o&65535;i=c[9699632+((o>>>8&255)<<2)>>2]|0;do{if((i|0)==0){n=c[3528598]|0;if((n|0)==0){p=0;break}p=gj[n&4095](m)|0}else{p=a[i+(o&255)|0]|0}}while(0);o=e[4821328]|0;i=o+(p&255|k)|0;p=(i>>>12&8|a[9642680]&-16&255)&255;m=i&65535;a[9642680]=((o^k^i^i>>>1)>>>14&2|i>>>16&1|(m<<16>>16==0?p|4:p)&255)&255;b[4821328]=m;return}function fSp(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=c[2410662]|0;f=d&65535;g=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[3528598]|0;if((h|0)==0){i=0;j=d;k=f;break}l=gj[h&4095](f)|0;h=c[2410662]|0;i=l;j=h;k=h&65535}else{i=a[g+(d&255)|0]|0;j=d;k=f}}while(0);f=i&255;i=f<<8;d=j+1|0;j=d&65535;g=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[3528598]|0;if((h|0)==0){m=0;n=k;break}l=gj[h&4095](j)|0;m=l;n=b[4821324]|0}else{m=a[g+(d&255)|0]|0;n=k}}while(0);k=m&255;m=k|i;c[2426870]=m;b[4821324]=n+2&65535;n=m&65535;i=c[9699632+(f<<2)>>2]|0;do{if((i|0)==0){f=c[3528598]|0;if((f|0)==0){o=0;break}o=gj[f&4095](n)|0}else{o=a[i+k|0]|0}}while(0);k=(o&255)<<8;o=m+1|0;m=o&65535;i=c[9699632+((o>>>8&255)<<2)>>2]|0;do{if((i|0)==0){n=c[3528598]|0;if((n|0)==0){p=0;break}p=gj[n&4095](m)|0}else{p=a[i+(o&255)|0]|0}}while(0);o=e[4821328]|0;i=o-(p&255|k)|0;p=(i>>>12&8|a[9642680]&-16&255)&255;m=i&65535;a[9642680]=((o^k^i^i>>>1)>>>14&2|i>>>16&1|(m<<16>>16==0?p|4:p)&255)&255;b[4821328]=m;return}function fSq(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=a[9642680]&-15;a[9642680]=d;e=b[4821328]|0;f=(e&65535)>>>12&8|d&255;if(e<<16>>16==0){g=(f|4)&255}else{g=f&255}a[9642680]=g;g=c[2410662]|0;f=g&65535;e=c[9701680+((g>>>8&255)<<2)>>2]|0;do{if((e|0)==0){d=c[3528598]|0;if((d|0)==0){h=0;i=g;j=f;break}k=gj[d&4095](f)|0;d=c[2410662]|0;h=k;i=d;j=d&65535}else{h=a[e+(g&255)|0]|0;i=g;j=f}}while(0);f=h&255;h=f<<8;g=i+1|0;i=g&65535;e=c[9701680+((g>>>8&255)<<2)>>2]|0;do{if((e|0)==0){d=c[3528598]|0;if((d|0)==0){l=0;m=j;break}k=gj[d&4095](i)|0;l=k;m=b[4821324]|0}else{l=a[e+(g&255)|0]|0;m=j}}while(0);j=l&255;l=j|h;c[2426870]=l;b[4821324]=m+2&65535;m=l&65535;h=a[9642657]|0;g=c[9700656+(f<<2)>>2]|0;do{if((g|0)==0){f=c[2444172]|0;if((f|0)==0){break}gg[f&4095](m,h)}else{a[g+j|0]=h}}while(0);h=l+1|0;l=a[9642656]|0;j=c[9700656+((h>>>8&255)<<2)>>2]|0;if((j|0)!=0){a[j+(h&255)|0]=l;return}j=c[2444172]|0;if((j|0)==0){return}gg[j&4095](h&65535,l);return}function fSr(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=a[9642680]&-15;a[9642680]=d;e=b[4821336]|0;f=(e&65535)>>>12&8|d&255;if(e<<16>>16==0){g=(f|4)&255}else{g=f&255}a[9642680]=g;g=c[2410662]|0;f=g&65535;e=c[9701680+((g>>>8&255)<<2)>>2]|0;do{if((e|0)==0){d=c[3528598]|0;if((d|0)==0){h=0;i=g;j=f;break}k=gj[d&4095](f)|0;d=c[2410662]|0;h=k;i=d;j=d&65535}else{h=a[e+(g&255)|0]|0;i=g;j=f}}while(0);f=h&255;h=f<<8;g=i+1|0;i=g&65535;e=c[9701680+((g>>>8&255)<<2)>>2]|0;do{if((e|0)==0){d=c[3528598]|0;if((d|0)==0){l=0;m=j;break}k=gj[d&4095](i)|0;l=k;m=b[4821324]|0}else{l=a[e+(g&255)|0]|0;m=j}}while(0);j=l&255;l=j|h;c[2426870]=l;b[4821324]=m+2&65535;m=l&65535;h=a[9642673]|0;g=c[9700656+(f<<2)>>2]|0;do{if((g|0)==0){f=c[2444172]|0;if((f|0)==0){break}gg[f&4095](m,h)}else{a[g+j|0]=h}}while(0);h=l+1|0;l=a[9642672]|0;j=c[9700656+((h>>>8&255)<<2)>>2]|0;if((j|0)!=0){a[j+(h&255)|0]=l;return}j=c[2444172]|0;if((j|0)==0){return}gg[j&4095](h&65535,l);return}function fSs(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=a[9642680]&-15;a[9642680]=d;e=b[4821338]|0;f=(e&65535)>>>12&8|d&255;if(e<<16>>16==0){g=(f|4)&255}else{g=f&255}a[9642680]=g;g=c[2410662]|0;f=g&65535;e=c[9701680+((g>>>8&255)<<2)>>2]|0;do{if((e|0)==0){d=c[3528598]|0;if((d|0)==0){h=0;i=g;j=f;break}k=gj[d&4095](f)|0;d=c[2410662]|0;h=k;i=d;j=d&65535}else{h=a[e+(g&255)|0]|0;i=g;j=f}}while(0);f=h&255;h=f<<8;g=i+1|0;i=g&65535;e=c[9701680+((g>>>8&255)<<2)>>2]|0;do{if((e|0)==0){d=c[3528598]|0;if((d|0)==0){l=0;m=j;break}k=gj[d&4095](i)|0;l=k;m=b[4821324]|0}else{l=a[e+(g&255)|0]|0;m=j}}while(0);j=l&255;l=j|h;c[2426870]=l;b[4821324]=m+2&65535;m=l&65535;h=a[9642677]|0;g=c[9700656+(f<<2)>>2]|0;do{if((g|0)==0){f=c[2444172]|0;if((f|0)==0){break}gg[f&4095](m,h)}else{a[g+j|0]=h}}while(0);h=l+1|0;l=a[9642676]|0;j=c[9700656+((h>>>8&255)<<2)>>2]|0;if((j|0)!=0){a[j+(h&255)|0]=l;return}j=c[2444172]|0;if((j|0)==0){return}gg[j&4095](h&65535,l);return}function fSt(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=a[9642680]&-15;a[9642680]=d;e=b[4821332]|0;f=(e&65535)>>>12&8|d&255;if(e<<16>>16==0){g=(f|4)&255}else{g=f&255}a[9642680]=g;g=c[2410662]|0;f=g&65535;e=c[9701680+((g>>>8&255)<<2)>>2]|0;do{if((e|0)==0){d=c[3528598]|0;if((d|0)==0){h=0;i=g;j=f;break}k=gj[d&4095](f)|0;d=c[2410662]|0;h=k;i=d;j=d&65535}else{h=a[e+(g&255)|0]|0;i=g;j=f}}while(0);f=h&255;h=f<<8;g=i+1|0;i=g&65535;e=c[9701680+((g>>>8&255)<<2)>>2]|0;do{if((e|0)==0){d=c[3528598]|0;if((d|0)==0){l=0;m=j;break}k=gj[d&4095](i)|0;l=k;m=b[4821324]|0}else{l=a[e+(g&255)|0]|0;m=j}}while(0);j=l&255;l=j|h;c[2426870]=l;b[4821324]=m+2&65535;m=l&65535;h=a[9642665]|0;g=c[9700656+(f<<2)>>2]|0;do{if((g|0)==0){f=c[2444172]|0;if((f|0)==0){break}gg[f&4095](m,h)}else{a[g+j|0]=h}}while(0);h=l+1|0;l=a[9642664]|0;j=c[9700656+((h>>>8&255)<<2)>>2]|0;if((j|0)!=0){a[j+(h&255)|0]=l;return}j=c[2444172]|0;if((j|0)==0){return}gg[j&4095](h&65535,l);return}function fSu(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=a[9642680]&-15;a[9642680]=d;e=b[4821334]|0;f=(e&65535)>>>12&8|d&255;if(e<<16>>16==0){g=(f|4)&255}else{g=f&255}a[9642680]=g;g=c[2410662]|0;f=g&65535;e=c[9701680+((g>>>8&255)<<2)>>2]|0;do{if((e|0)==0){d=c[3528598]|0;if((d|0)==0){h=0;i=g;j=f;break}k=gj[d&4095](f)|0;d=c[2410662]|0;h=k;i=d;j=d&65535}else{h=a[e+(g&255)|0]|0;i=g;j=f}}while(0);f=h&255;h=f<<8;g=i+1|0;i=g&65535;e=c[9701680+((g>>>8&255)<<2)>>2]|0;do{if((e|0)==0){d=c[3528598]|0;if((d|0)==0){l=0;m=j;break}k=gj[d&4095](i)|0;l=k;m=b[4821324]|0}else{l=a[e+(g&255)|0]|0;m=j}}while(0);j=l&255;l=j|h;c[2426870]=l;b[4821324]=m+2&65535;m=l&65535;h=a[9642669]|0;g=c[9700656+(f<<2)>>2]|0;do{if((g|0)==0){f=c[2444172]|0;if((f|0)==0){break}gg[f&4095](m,h)}else{a[g+j|0]=h}}while(0);h=l+1|0;l=a[9642668]|0;j=c[9700656+((h>>>8&255)<<2)>>2]|0;if((j|0)!=0){a[j+(h&255)|0]=l;return}j=c[2444172]|0;if((j|0)==0){return}gg[j&4095](h&65535,l);return}function fSv(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=d;j=e;break}k=gj[g&4095](e)|0;g=c[2410662]|0;h=k;i=g;j=g&65535}else{h=a[f+(d&255)|0]|0;i=d;j=e}}while(0);e=h&255;h=e<<8;d=i+1|0;i=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){l=0;m=j;break}k=gj[g&4095](i)|0;l=k;m=b[4821324]|0}else{l=a[f+(d&255)|0]|0;m=j}}while(0);j=l&255;l=j|h;c[2426870]=l;b[4821324]=m+2&65535;m=c[9700656+(e<<2)>>2]|0;if((m|0)!=0){a[m+j|0]=0;n=a[9642680]|0;o=n&-16;p=o|4;a[9642680]=p;return}j=c[2444172]|0;if((j|0)==0){n=a[9642680]|0;o=n&-16;p=o|4;a[9642680]=p;return}gg[j&4095](l&65535,0);n=a[9642680]|0;o=n&-16;p=o|4;a[9642680]=p;return}function fSw(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=d;j=e;break}k=gj[g&4095](e)|0;g=c[2410662]|0;h=k;i=g;j=g&65535}else{h=a[f+(d&255)|0]|0;i=d;j=e}}while(0);e=h&255;h=e<<8;d=i+1|0;i=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){l=0;m=j;break}k=gj[g&4095](i)|0;l=k;m=b[4821324]|0}else{l=a[f+(d&255)|0]|0;m=j}}while(0);j=l&255;l=j|h;c[2426870]=l;b[4821324]=m+2&65535;m=l&65535;h=c[9699632+(e<<2)>>2]|0;do{if((h|0)==0){e=c[3528598]|0;if((e|0)==0){n=0;o=l;break}d=gj[e&4095](m)|0;n=d;o=c[2426870]|0}else{n=a[h+j|0]|0;o=l}}while(0);l=~n;j=a[9642680]&-15|(l&255)>>>4&8;a[9642680]=(n<<24>>24==-1?j|4:j)|1;j=c[9700656+((o>>>8&255)<<2)>>2]|0;if((j|0)!=0){a[j+(o&255)|0]=l;return}j=c[2444172]|0;if((j|0)==0){return}gg[j&4095](o&65535,l);return}function fSx(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=d;j=e;break}k=gj[g&4095](e)|0;g=c[2410662]|0;h=k;i=g;j=g&65535}else{h=a[f+(d&255)|0]|0;i=d;j=e}}while(0);e=h&255;h=e<<8;d=i+1|0;i=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){l=0;m=j;break}k=gj[g&4095](i)|0;l=k;m=b[4821324]|0}else{l=a[f+(d&255)|0]|0;m=j}}while(0);j=l&255;l=j|h;c[2426870]=l;b[4821324]=m+2&65535;m=l&65535;h=c[9699632+(e<<2)>>2]|0;do{if((h|0)==0){e=c[3528598]|0;if((e|0)==0){n=0;o=l;break}d=gj[e&4095](m)|0;n=d;o=c[2426870]|0}else{n=a[h+j|0]|0;o=l}}while(0);l=n&255;n=-l|0;j=(a[9642680]&-16&255|n>>>4&8)&255;h=n&255;a[9642680]=((l^n^n>>>1)>>>6&2|n>>>8&1|(h<<24>>24==0?j|4:j)&255)&255;j=c[9700656+((o>>>8&255)<<2)>>2]|0;if((j|0)!=0){a[j+(o&255)|0]=h;return}j=c[2444172]|0;if((j|0)==0){return}gg[j&4095](o&65535,h);return}function fSy(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=d;j=e;break}k=gj[g&4095](e)|0;g=c[2410662]|0;h=k;i=g;j=g&65535}else{h=a[f+(d&255)|0]|0;i=d;j=e}}while(0);e=h&255;h=e<<8;d=i+1|0;i=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){l=0;m=j;break}k=gj[g&4095](i)|0;l=k;m=b[4821324]|0}else{l=a[f+(d&255)|0]|0;m=j}}while(0);j=l&255;l=j|h;c[2426870]=l;b[4821324]=m+2&65535;m=l&65535;h=c[9699632+(e<<2)>>2]|0;do{if((h|0)==0){e=c[3528598]|0;if((e|0)==0){n=0;o=l;break}d=gj[e&4095](m)|0;n=d;o=c[2426870]|0}else{n=a[h+j|0]|0;o=l}}while(0);l=n+1&255;a[9642680]=a[9642680]&-15|a[668928+(l&255)|0];n=c[9700656+((o>>>8&255)<<2)>>2]|0;if((n|0)!=0){a[n+(o&255)|0]=l;return}n=c[2444172]|0;if((n|0)==0){return}gg[n&4095](o&65535,l);return}function fSz(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=d;j=e;break}k=gj[g&4095](e)|0;g=c[2410662]|0;h=k;i=g;j=g&65535}else{h=a[f+(d&255)|0]|0;i=d;j=e}}while(0);e=h&255;h=e<<8;d=i+1|0;i=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){l=0;m=j;break}k=gj[g&4095](i)|0;l=k;m=b[4821324]|0}else{l=a[f+(d&255)|0]|0;m=j}}while(0);j=l&255;l=j|h;c[2426870]=l;b[4821324]=m+2&65535;m=l&65535;h=c[9699632+(e<<2)>>2]|0;do{if((h|0)==0){e=c[3528598]|0;if((e|0)==0){n=0;o=l;break}d=gj[e&4095](m)|0;n=d;o=c[2426870]|0}else{n=a[h+j|0]|0;o=l}}while(0);l=n-1&255;a[9642680]=a[9642680]&-15|a[669184+(l&255)|0];n=c[9700656+((o>>>8&255)<<2)>>2]|0;if((n|0)!=0){a[n+(o&255)|0]=l;return}n=c[2444172]|0;if((n|0)==0){return}gg[n&4095](o&65535,l);return}function fSA(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=d;j=e;break}k=gj[g&4095](e)|0;g=c[2410662]|0;h=k;i=g;j=g&65535}else{h=a[f+(d&255)|0]|0;i=d;j=e}}while(0);e=h&255;h=e<<8;d=i+1|0;i=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){l=0;m=j;break}k=gj[g&4095](i)|0;l=k;m=b[4821324]|0}else{l=a[f+(d&255)|0]|0;m=j}}while(0);j=l&255;l=j|h;c[2426870]=l;b[4821324]=m+2&65535;m=l&65535;l=c[9699632+(e<<2)>>2]|0;do{if((l|0)==0){e=c[3528598]|0;if((e|0)==0){n=0;break}n=gj[e&4095](m)|0}else{n=a[l+j|0]|0}}while(0);j=a[9642680]&-15|(n&255)>>>4&8;a[9642680]=n<<24>>24==0?j|4:j;return}function fSB(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=d;j=e;break}k=gj[g&4095](e)|0;g=c[2410662]|0;h=k;i=g;j=g&65535}else{h=a[f+(d&255)|0]|0;i=d;j=e}}while(0);e=h&255;h=e<<8;d=i+1|0;i=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){l=0;m=j;break}k=gj[g&4095](i)|0;l=k;m=b[4821324]|0}else{l=a[f+(d&255)|0]|0;m=j}}while(0);j=l&255;l=j|h;c[2426870]=l;b[4821324]=m+2&65535;m=l&65535;h=c[9699632+(e<<2)>>2]|0;do{if((h|0)==0){e=c[3528598]|0;if((e|0)==0){n=0;o=l;break}d=gj[e&4095](m)|0;n=d;o=c[2426870]|0}else{n=a[h+j|0]|0;o=l}}while(0);l=a[9642680]&-14|n&1;j=(n&255)>>>1;a[9642680]=j<<24>>24==0?l|4:l;l=c[9700656+((o>>>8&255)<<2)>>2]|0;if((l|0)!=0){a[l+(o&255)|0]=j;return}l=c[2444172]|0;if((l|0)==0){return}gg[l&4095](o&65535,j);return}function fSC(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=d;j=e;break}k=gj[g&4095](e)|0;g=c[2410662]|0;h=k;i=g;j=g&65535}else{h=a[f+(d&255)|0]|0;i=d;j=e}}while(0);e=h&255;h=e<<8;d=i+1|0;i=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){l=0;m=j;break}k=gj[g&4095](i)|0;l=k;m=b[4821324]|0}else{l=a[f+(d&255)|0]|0;m=j}}while(0);j=l&255;l=j|h;c[2426870]=l;b[4821324]=m+2&65535;m=l&65535;h=c[9699632+(e<<2)>>2]|0;do{if((h|0)==0){e=c[3528598]|0;if((e|0)==0){n=0;o=l;break}d=gj[e&4095](m)|0;n=d;o=c[2426870]|0}else{n=a[h+j|0]|0;o=l}}while(0);l=a[9642680]|0;j=l<<7|(n&255)>>>1;h=l&-14|n&1|l<<3&8;a[9642680]=j<<24>>24==0?h|4:h;h=c[9700656+((o>>>8&255)<<2)>>2]|0;if((h|0)!=0){a[h+(o&255)|0]=j;return}h=c[2444172]|0;if((h|0)==0){return}gg[h&4095](o&65535,j);return}function fSD(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=d;j=e;break}k=gj[g&4095](e)|0;g=c[2410662]|0;h=k;i=g;j=g&65535}else{h=a[f+(d&255)|0]|0;i=d;j=e}}while(0);e=h&255;h=e<<8;d=i+1|0;i=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){l=0;m=j;break}k=gj[g&4095](i)|0;l=k;m=b[4821324]|0}else{l=a[f+(d&255)|0]|0;m=j}}while(0);j=l&255;l=j|h;c[2426870]=l;b[4821324]=m+2&65535;m=l&65535;h=c[9699632+(e<<2)>>2]|0;do{if((h|0)==0){e=c[3528598]|0;if((e|0)==0){n=0;o=l;break}d=gj[e&4095](m)|0;n=d;o=c[2426870]|0}else{n=a[h+j|0]|0;o=l}}while(0);l=n&-128|(n&255)>>>1;j=a[9642680]&-14|n&1|(n&255)>>>4&8;a[9642680]=l<<24>>24==0?j|4:j;j=c[9700656+((o>>>8&255)<<2)>>2]|0;if((j|0)!=0){a[j+(o&255)|0]=l;return}j=c[2444172]|0;if((j|0)==0){return}gg[j&4095](o&65535,l);return}function fSE(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=d;j=e;break}k=gj[g&4095](e)|0;g=c[2410662]|0;h=k;i=g;j=g&65535}else{h=a[f+(d&255)|0]|0;i=d;j=e}}while(0);e=h&255;h=e<<8;d=i+1|0;i=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){l=0;m=j;break}k=gj[g&4095](i)|0;l=k;m=b[4821324]|0}else{l=a[f+(d&255)|0]|0;m=j}}while(0);j=l&255;l=j|h;c[2426870]=l;b[4821324]=m+2&65535;m=l&65535;h=c[9699632+(e<<2)>>2]|0;do{if((h|0)==0){e=c[3528598]|0;if((e|0)==0){n=0;o=l;break}d=gj[e&4095](m)|0;n=d;o=c[2426870]|0}else{n=a[h+j|0]|0;o=l}}while(0);l=(n&255)<<1;n=l&65535;j=(n>>>4&8|a[9642680]&-16&255)&255;h=l&255;a[9642680]=((n>>>1^n)>>>6&2|n>>>8|(h<<24>>24==0?j|4:j)&255)&255;j=c[9700656+((o>>>8&255)<<2)>>2]|0;if((j|0)!=0){a[j+(o&255)|0]=h;return}j=c[2444172]|0;if((j|0)==0){return}gg[j&4095](o&65535,h);return}function fSF(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=d;j=e;break}k=gj[g&4095](e)|0;g=c[2410662]|0;h=k;i=g;j=g&65535}else{h=a[f+(d&255)|0]|0;i=d;j=e}}while(0);e=h&255;h=e<<8;d=i+1|0;i=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){l=0;m=j;break}k=gj[g&4095](i)|0;l=k;m=b[4821324]|0}else{l=a[f+(d&255)|0]|0;m=j}}while(0);j=l&255;l=j|h;c[2426870]=l;b[4821324]=m+2&65535;m=l&65535;h=c[9699632+(e<<2)>>2]|0;do{if((h|0)==0){e=c[3528598]|0;if((e|0)==0){n=0;o=l;break}d=gj[e&4095](m)|0;n=d;o=c[2426870]|0}else{n=a[h+j|0]|0;o=l}}while(0);l=a[9642680]|0;j=n&255;h=j<<1;m=l&-16|(n&255)>>>3&8;n=(l&1|h)&255;a[9642680]=((h^j)>>>6&2|j>>>7|(n<<24>>24==0?m|4:m)&255)&255;m=c[9700656+((o>>>8&255)<<2)>>2]|0;if((m|0)!=0){a[m+(o&255)|0]=n;return}m=c[2444172]|0;if((m|0)==0){return}gg[m&4095](o&65535,n);return}function fSG(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=d;j=e;break}k=gj[g&4095](e)|0;g=c[2410662]|0;h=k;i=g;j=g&65535}else{h=a[f+(d&255)|0]|0;i=d;j=e}}while(0);e=h&255;h=e<<8;d=i+1|0;i=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){l=0;m=j;break}k=gj[g&4095](i)|0;l=k;m=b[4821324]|0}else{l=a[f+(d&255)|0]|0;m=j}}while(0);j=l&255;l=j|h;c[2426870]=l;b[4821324]=m+2&65535;m=l&65535;h=c[9699632+(e<<2)>>2]|0;do{if((h|0)==0){e=c[3528598]|0;if((e|0)==0){n=0;break}n=gj[e&4095](m)|0}else{n=a[h+j|0]|0}}while(0);j=l+1|0;l=j&65535;h=c[9699632+((j>>>8&255)<<2)>>2]|0;do{if((h|0)==0){m=c[3528598]|0;if((m|0)==0){o=0;break}o=gj[m&4095](l)|0}else{o=a[h+(j&255)|0]|0}}while(0);j=a[9642680]&-14|o&1;h=(o&255|(n&255)<<8)>>>1;o=h&255;l=(n&255)>>>1;a[9642680]=(h|0)==0?j|4:j;j=c[2426870]|0;h=j&65535;n=c[9700656+((j>>>8&255)<<2)>>2]|0;do{if((n|0)==0){m=c[2444172]|0;if((m|0)==0){break}gg[m&4095](h,l)}else{a[n+(j&255)|0]=l}}while(0);l=j+1|0;j=c[9700656+((l>>>8&255)<<2)>>2]|0;if((j|0)!=0){a[j+(l&255)|0]=o;return}j=c[2444172]|0;if((j|0)==0){return}gg[j&4095](l&65535,o);return}function fSH(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=d;j=e;break}k=gj[g&4095](e)|0;g=c[2410662]|0;h=k;i=g;j=g&65535}else{h=a[f+(d&255)|0]|0;i=d;j=e}}while(0);e=h&255;h=e<<8;d=i+1|0;i=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){l=0;m=j;break}k=gj[g&4095](i)|0;l=k;m=b[4821324]|0}else{l=a[f+(d&255)|0]|0;m=j}}while(0);j=l&255;l=j|h;c[2426870]=l;b[4821324]=m+2&65535;m=l&65535;h=c[9699632+(e<<2)>>2]|0;do{if((h|0)==0){e=c[3528598]|0;if((e|0)==0){n=0;break}n=gj[e&4095](m)|0}else{n=a[h+j|0]|0}}while(0);j=(n&255)<<8;n=l+1|0;l=n&65535;h=c[9699632+((n>>>8&255)<<2)>>2]|0;do{if((h|0)==0){m=c[3528598]|0;if((m|0)==0){o=0;break}o=gj[m&4095](l)|0}else{o=a[h+(n&255)|0]|0}}while(0);n=a[9642680]|0;h=(o&255|j)>>>1;j=(n&255)<<15&32768|h;l=h&255;m=j>>>8;e=m&255;d=j>>>12&8|(n&-14|o&1)&255;a[9642680]=((m<<8&65280|h&255|0)==0?d|4:d)&255;d=c[2426870]|0;h=d&65535;m=c[9700656+((d>>>8&255)<<2)>>2]|0;do{if((m|0)==0){o=c[2444172]|0;if((o|0)==0){break}gg[o&4095](h,e)}else{a[m+(d&255)|0]=e}}while(0);e=d+1|0;d=c[9700656+((e>>>8&255)<<2)>>2]|0;if((d|0)!=0){a[d+(e&255)|0]=l;return}d=c[2444172]|0;if((d|0)==0){return}gg[d&4095](e&65535,l);return}function fSI(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=d;j=e;break}k=gj[g&4095](e)|0;g=c[2410662]|0;h=k;i=g;j=g&65535}else{h=a[f+(d&255)|0]|0;i=d;j=e}}while(0);e=h&255;h=e<<8;d=i+1|0;i=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){l=0;m=j;break}k=gj[g&4095](i)|0;l=k;m=b[4821324]|0}else{l=a[f+(d&255)|0]|0;m=j}}while(0);j=l&255;l=j|h;c[2426870]=l;b[4821324]=m+2&65535;m=l&65535;h=c[9699632+(e<<2)>>2]|0;do{if((h|0)==0){e=c[3528598]|0;if((e|0)==0){n=0;break}n=gj[e&4095](m)|0}else{n=a[h+j|0]|0}}while(0);j=l+1|0;l=j&65535;h=c[9699632+((j>>>8&255)<<2)>>2]|0;do{if((h|0)==0){m=c[3528598]|0;if((m|0)==0){o=0;break}o=gj[m&4095](l)|0}else{o=a[h+(j&255)|0]|0}}while(0);j=(n&255)<<8;n=(o&255|j)>>>1;h=n|j&32768;j=n&255;l=h>>>8;m=l&255;e=h>>>12&8|(a[9642680]&-14|o&1)&255;a[9642680]=((l<<8&65280|n&255|0)==0?e|4:e)&255;e=c[2426870]|0;n=e&65535;l=c[9700656+((e>>>8&255)<<2)>>2]|0;do{if((l|0)==0){o=c[2444172]|0;if((o|0)==0){break}gg[o&4095](n,m)}else{a[l+(e&255)|0]=m}}while(0);m=e+1|0;e=c[9700656+((m>>>8&255)<<2)>>2]|0;if((e|0)!=0){a[e+(m&255)|0]=j;return}e=c[2444172]|0;if((e|0)==0){return}gg[e&4095](m&65535,j);return}function fSJ(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=d;j=e;break}k=gj[g&4095](e)|0;g=c[2410662]|0;h=k;i=g;j=g&65535}else{h=a[f+(d&255)|0]|0;i=d;j=e}}while(0);e=h&255;h=e<<8;d=i+1|0;i=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){l=0;m=j;break}k=gj[g&4095](i)|0;l=k;m=b[4821324]|0}else{l=a[f+(d&255)|0]|0;m=j}}while(0);j=l&255;l=j|h;c[2426870]=l;b[4821324]=m+2&65535;m=l&65535;h=c[9699632+(e<<2)>>2]|0;do{if((h|0)==0){e=c[3528598]|0;if((e|0)==0){n=0;break}n=gj[e&4095](m)|0}else{n=a[h+j|0]|0}}while(0);j=n&255;h=j<<8;m=l+1|0;l=m&65535;e=c[9699632+((m>>>8&255)<<2)>>2]|0;do{if((e|0)==0){d=c[3528598]|0;if((d|0)==0){o=0;break}o=gj[d&4095](l)|0}else{o=a[e+(m&255)|0]|0}}while(0);m=o&255|h;h=m<<1;o=h&255;e=m>>>7;m=e&255;l=(n&255)>>>7&255;n=e<<8;e=a[9642680]&-16&255|j>>>3&8;a[9642680]=((n^l<<15)>>>14&2|l|(((n|h&254)&65535)<<16>>16==0?e|4:e)&252)&255;e=c[2426870]|0;h=e&65535;n=c[9700656+((e>>>8&255)<<2)>>2]|0;do{if((n|0)==0){l=c[2444172]|0;if((l|0)==0){break}gg[l&4095](h,m)}else{a[n+(e&255)|0]=m}}while(0);m=e+1|0;e=c[9700656+((m>>>8&255)<<2)>>2]|0;if((e|0)!=0){a[e+(m&255)|0]=o;return}e=c[2444172]|0;if((e|0)==0){return}gg[e&4095](m&65535,o);return}function fSK(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=d;j=e;break}k=gj[g&4095](e)|0;g=c[2410662]|0;h=k;i=g;j=g&65535}else{h=a[f+(d&255)|0]|0;i=d;j=e}}while(0);e=h&255;h=e<<8;d=i+1|0;i=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){l=0;m=j;break}k=gj[g&4095](i)|0;l=k;m=b[4821324]|0}else{l=a[f+(d&255)|0]|0;m=j}}while(0);j=l&255;l=j|h;c[2426870]=l;b[4821324]=m+2&65535;m=l&65535;h=c[9699632+(e<<2)>>2]|0;do{if((h|0)==0){e=c[3528598]|0;if((e|0)==0){n=0;break}n=gj[e&4095](m)|0}else{n=a[h+j|0]|0}}while(0);j=n&255;h=j<<8;m=l+1|0;l=m&65535;e=c[9699632+((m>>>8&255)<<2)>>2]|0;do{if((e|0)==0){d=c[3528598]|0;if((d|0)==0){o=0;break}o=gj[d&4095](l)|0}else{o=a[e+(m&255)|0]|0}}while(0);m=o&255|h;h=a[9642680]|0;o=h&1|m<<1;e=o&255;l=m>>>7;m=l&255;d=(n&255)>>>7&255;n=l<<8;l=h&-16&255|j>>>3&8;a[9642680]=((n^d<<15)>>>14&2|d|(((o&255|n)&65535)<<16>>16==0?l|4:l)&252)&255;l=c[2426870]|0;n=l&65535;o=c[9700656+((l>>>8&255)<<2)>>2]|0;do{if((o|0)==0){d=c[2444172]|0;if((d|0)==0){break}gg[d&4095](n,m)}else{a[o+(l&255)|0]=m}}while(0);m=l+1|0;l=c[9700656+((m>>>8&255)<<2)>>2]|0;if((l|0)!=0){a[l+(m&255)|0]=e;return}l=c[2444172]|0;if((l|0)==0){return}gg[l&4095](m&65535,e);return}function fSL(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=d;break}j=gj[g&4095](e)|0;h=j;i=c[2410662]|0}else{h=a[f+(d&255)|0]|0;i=d}}while(0);d=(h&255)<<8;h=i+1|0;i=h&65535;f=c[9701680+((h>>>8&255)<<2)>>2]|0;do{if((f|0)==0){e=c[3528598]|0;if((e|0)==0){k=0;break}k=gj[e&4095](i)|0}else{k=a[f+(h&255)|0]|0}}while(0);h=k&255|d;c[2426870]=h;c[2410662]=h;b[4821324]=h&65535;return}function fSM(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=d;j=e;break}k=gj[g&4095](e)|0;g=c[2410662]|0;h=k;i=g;j=g&65535}else{h=a[f+(d&255)|0]|0;i=d;j=e}}while(0);e=(h&255)<<8;h=i+1|0;i=h&65535;d=c[9701680+((h>>>8&255)<<2)>>2]|0;do{if((d|0)==0){f=c[3528598]|0;if((f|0)==0){l=0;m=j;break}g=gj[f&4095](i)|0;l=g;m=b[4821324]|0}else{l=a[d+(h&255)|0]|0;m=j}}while(0);c[2426870]=l&255|e;e=m+2&65535;b[4821324]=e;b[4821334]=(b[4821334]|0)-1&65535;m=c[2410667]|0;l=m&65535;j=e&255;e=c[9700656+((m>>>8&255)<<2)>>2]|0;do{if((e|0)==0){h=c[2444172]|0;if((h|0)==0){break}gg[h&4095](l,j)}else{a[e+(m&255)|0]=j}}while(0);b[4821334]=(b[4821334]|0)-1&65535;j=c[2410667]|0;m=a[9642649]|0;e=c[9700656+((j>>>8&255)<<2)>>2]|0;if((e|0)!=0){a[e+(j&255)|0]=m;n=c[2426870]|0;c[2410662]=n;o=n&65535;b[4821324]=o;return}e=c[2444172]|0;if((e|0)==0){n=c[2426870]|0;c[2410662]=n;o=n&65535;b[4821324]=o;return}gg[e&4095](j&65535,m);n=c[2426870]|0;c[2410662]=n;o=n&65535;b[4821324]=o;return}function fSN(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=d;j=e;break}k=gj[g&4095](e)|0;g=c[2410662]|0;h=k;i=g;j=g&65535}else{h=a[f+(d&255)|0]|0;i=d;j=e}}while(0);e=h&255;h=e<<8;d=i+1|0;i=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){l=0;m=j;break}k=gj[g&4095](i)|0;l=k;m=b[4821324]|0}else{l=a[f+(d&255)|0]|0;m=j}}while(0);j=l&255;l=j|h;c[2426870]=l;b[4821324]=m+2&65535;m=l&65535;l=c[9699632+(e<<2)>>2]|0;do{if((l|0)==0){e=c[3528598]|0;if((e|0)==0){return}else{n=gj[e&4095](m)|0;break}}else{n=a[l+j|0]|0}}while(0);if(n<<24>>24==0){return}j=n;n=a[9642680]|0;l=b[4821328]|0;do{j=j-1&255;m=l&1|n&-14;l=(l&65535)>>>1;n=l<<16>>16==0?m|4:m;}while(j<<24>>24!=0);a[9642680]=n;b[4821328]=l;return}function fSO(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=d;j=e;break}k=gj[g&4095](e)|0;g=c[2410662]|0;h=k;i=g;j=g&65535}else{h=a[f+(d&255)|0]|0;i=d;j=e}}while(0);e=h&255;h=e<<8;d=i+1|0;i=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){l=0;m=j;break}k=gj[g&4095](i)|0;l=k;m=b[4821324]|0}else{l=a[f+(d&255)|0]|0;m=j}}while(0);j=l&255;l=j|h;c[2426870]=l;b[4821324]=m+2&65535;m=l&65535;l=c[9699632+(e<<2)>>2]|0;do{if((l|0)==0){e=c[3528598]|0;if((e|0)==0){return}else{n=gj[e&4095](m)|0;break}}else{n=a[l+j|0]|0}}while(0);if(n<<24>>24==0){return}j=n;n=a[9642680]|0;l=b[4821328]|0;while(1){m=j-1&255;o=(n&255)<<15|(l&65535)>>>1;e=l&1|n&-14|n<<3&8;p=o<<16>>16==0?e|4:e;if(m<<24>>24==0){break}else{j=m;n=p;l=o}}a[9642680]=p;b[4821328]=o;return}function fSP(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=d;j=e;break}k=gj[g&4095](e)|0;g=c[2410662]|0;h=k;i=g;j=g&65535}else{h=a[f+(d&255)|0]|0;i=d;j=e}}while(0);e=h&255;h=e<<8;d=i+1|0;i=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){l=0;m=j;break}k=gj[g&4095](i)|0;l=k;m=b[4821324]|0}else{l=a[f+(d&255)|0]|0;m=j}}while(0);j=l&255;l=j|h;c[2426870]=l;b[4821324]=m+2&65535;m=l&65535;l=c[9699632+(e<<2)>>2]|0;do{if((l|0)==0){e=c[3528598]|0;if((e|0)==0){return}else{n=gj[e&4095](m)|0;break}}else{n=a[l+j|0]|0}}while(0);if(n<<24>>24==0){return}j=n;n=a[9642680]|0;l=b[4821328]|0;while(1){m=j-1&255;o=l&-32768|(l&65535)>>>1;e=(l&1|n&-14)&255|(l&65535)>>>12&8;if(o<<16>>16==0){p=(e|4)&255}else{p=e&255}if(m<<24>>24==0){break}else{j=m;n=p;l=o}}a[9642680]=p;b[4821328]=o;return}function fSQ(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=d;j=e;break}k=gj[g&4095](e)|0;g=c[2410662]|0;h=k;i=g;j=g&65535}else{h=a[f+(d&255)|0]|0;i=d;j=e}}while(0);e=h&255;h=e<<8;d=i+1|0;i=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){l=0;m=j;break}k=gj[g&4095](i)|0;l=k;m=b[4821324]|0}else{l=a[f+(d&255)|0]|0;m=j}}while(0);j=l&255;l=j|h;c[2426870]=l;b[4821324]=m+2&65535;m=l&65535;l=c[9699632+(e<<2)>>2]|0;do{if((l|0)==0){e=c[3528598]|0;if((e|0)==0){return}else{n=gj[e&4095](m)|0;break}}else{n=a[l+j|0]|0}}while(0);if(n<<24>>24==0){return}j=n;n=b[4821328]|0;l=a[9642680]|0;do{j=j-1&255;m=n&65535;e=m<<1;h=(m>>>11&8|l&-16&255)&255;n=e&65535;l=((e^m)>>>14&2|m>>>15|(n<<16>>16==0?h|4:h)&255)&255;}while(j<<24>>24!=0);b[4821328]=n;a[9642680]=l;return}function fSR(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=d;j=e;break}k=gj[g&4095](e)|0;g=c[2410662]|0;h=k;i=g;j=g&65535}else{h=a[f+(d&255)|0]|0;i=d;j=e}}while(0);e=h&255;h=e<<8;d=i+1|0;i=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){l=0;m=j;break}k=gj[g&4095](i)|0;l=k;m=b[4821324]|0}else{l=a[f+(d&255)|0]|0;m=j}}while(0);j=l&255;l=j|h;c[2426870]=l;b[4821324]=m+2&65535;m=l&65535;l=c[9699632+(e<<2)>>2]|0;do{if((l|0)==0){e=c[3528598]|0;if((e|0)==0){return}else{n=gj[e&4095](m)|0;break}}else{n=a[l+j|0]|0}}while(0);if(n<<24>>24==0){return}j=n;n=a[9642680]|0;l=b[4821328]|0;while(1){m=j-1&255;e=(l&65535)>>>15;h=l<<1;o=e|h;d=(h&65535)>>>12&8|(n&-14|e&255)&255;if(o<<16>>16==0){p=(d|4)&255}else{p=d&255}if(m<<24>>24==0){break}else{j=m;n=p;l=o}}a[9642680]=p;b[4821328]=o;return}function fSS(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=d;j=e;break}k=gj[g&4095](e)|0;g=c[2410662]|0;h=k;i=g;j=g&65535}else{h=a[f+(d&255)|0]|0;i=d;j=e}}while(0);e=h&255;h=e<<8;d=i+1|0;i=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){l=0;m=j;break}k=gj[g&4095](i)|0;l=k;m=b[4821324]|0}else{l=a[f+(d&255)|0]|0;m=j}}while(0);j=l&255;l=j|h;c[2426870]=l;b[4821324]=m+2&65535;m=l&65535;h=c[9700656+(e<<2)>>2]|0;do{if((h|0)==0){e=c[2444172]|0;if((e|0)==0){break}gg[e&4095](m,0)}else{a[h+j|0]=0}}while(0);j=l+1|0;l=c[9700656+((j>>>8&255)<<2)>>2]|0;if((l|0)!=0){a[l+(j&255)|0]=0;n=a[9642680]|0;o=n&-16;p=o|4;a[9642680]=p;return}l=c[2444172]|0;if((l|0)==0){n=a[9642680]|0;o=n&-16;p=o|4;a[9642680]=p;return}gg[l&4095](j&65535,0);n=a[9642680]|0;o=n&-16;p=o|4;a[9642680]=p;return}function fST(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=d;j=e;break}k=gj[g&4095](e)|0;g=c[2410662]|0;h=k;i=g;j=g&65535}else{h=a[f+(d&255)|0]|0;i=d;j=e}}while(0);e=h&255;h=e<<8;d=i+1|0;i=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){l=0;m=j;break}k=gj[g&4095](i)|0;l=k;m=b[4821324]|0}else{l=a[f+(d&255)|0]|0;m=j}}while(0);j=l&255;l=j|h;c[2426870]=l;b[4821324]=m+2&65535;m=l&65535;h=c[9699632+(e<<2)>>2]|0;do{if((h|0)==0){e=c[3528598]|0;if((e|0)==0){n=0;break}n=gj[e&4095](m)|0}else{n=a[h+j|0]|0}}while(0);j=(n&255)<<8;n=l+1|0;l=n&65535;h=c[9699632+((n>>>8&255)<<2)>>2]|0;do{if((h|0)==0){m=c[3528598]|0;if((m|0)==0){o=0;break}o=gj[m&4095](l)|0}else{o=a[h+(n&255)|0]|0}}while(0);n=-(o&255|j)|0;o=n&255;h=n>>>8;l=h&255;m=h<<8;h=n>>>12&8|a[9642680]&-16&255;a[9642680]=((n>>>1^j^m)>>>14&2|n>>>16&1|(((m|n&255)&65535)<<16>>16==0?h|4:h)&252)&255;h=c[2426870]|0;n=h&65535;m=c[9700656+((h>>>8&255)<<2)>>2]|0;do{if((m|0)==0){j=c[2444172]|0;if((j|0)==0){break}gg[j&4095](n,l)}else{a[m+(h&255)|0]=l}}while(0);l=h+1|0;h=c[9700656+((l>>>8&255)<<2)>>2]|0;if((h|0)!=0){a[h+(l&255)|0]=o;return}h=c[2444172]|0;if((h|0)==0){return}gg[h&4095](l&65535,o);return}function fSU(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=d;j=e;break}k=gj[g&4095](e)|0;g=c[2410662]|0;h=k;i=g;j=g&65535}else{h=a[f+(d&255)|0]|0;i=d;j=e}}while(0);e=h&255;h=e<<8;d=i+1|0;i=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){l=0;m=j;break}k=gj[g&4095](i)|0;l=k;m=b[4821324]|0}else{l=a[f+(d&255)|0]|0;m=j}}while(0);j=l&255;l=j|h;c[2426870]=l;b[4821324]=m+2&65535;m=l&65535;h=c[9699632+(e<<2)>>2]|0;do{if((h|0)==0){e=c[3528598]|0;if((e|0)==0){n=0;break}n=gj[e&4095](m)|0}else{n=a[h+j|0]|0}}while(0);j=(n&255)<<8;n=l+1|0;l=n&65535;h=c[9699632+((n>>>8&255)<<2)>>2]|0;do{if((h|0)==0){m=c[3528598]|0;if((m|0)==0){o=0;break}o=gj[m&4095](l)|0}else{o=a[h+(n&255)|0]|0}}while(0);n=(o&255|j)+1|0;j=n&255;o=n>>>8;h=o&255;l=o<<8;o=n>>>12&8|a[9642680]&-15&255;a[9642680]=((l^n>>>1)>>>14&2|n>>>16&1|(((l|n&255)&65535)<<16>>16==0?o|4:o)&253)&255;o=c[2426870]|0;n=o&65535;l=c[9700656+((o>>>8&255)<<2)>>2]|0;do{if((l|0)==0){m=c[2444172]|0;if((m|0)==0){break}gg[m&4095](n,h)}else{a[l+(o&255)|0]=h}}while(0);h=o+1|0;o=c[9700656+((h>>>8&255)<<2)>>2]|0;if((o|0)!=0){a[o+(h&255)|0]=j;return}o=c[2444172]|0;if((o|0)==0){return}gg[o&4095](h&65535,j);return}function fSV(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=c[2410662]|0;e=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){h=0;i=d;j=e;break}k=gj[g&4095](e)|0;g=c[2410662]|0;h=k;i=g;j=g&65535}else{h=a[f+(d&255)|0]|0;i=d;j=e}}while(0);e=h&255;h=e<<8;d=i+1|0;i=d&65535;f=c[9701680+((d>>>8&255)<<2)>>2]|0;do{if((f|0)==0){g=c[3528598]|0;if((g|0)==0){l=0;m=j;break}k=gj[g&4095](i)|0;l=k;m=b[4821324]|0}else{l=a[f+(d&255)|0]|0;m=j}}while(0);j=l&255;l=j|h;c[2426870]=l;b[4821324]=m+2&65535;m=l&65535;h=c[9699632+(e<<2)>>2]|0;do{if((h|0)==0){e=c[3528598]|0;if((e|0)==0){n=0;break}n=gj[e&4095](m)|0}else{n=a[h+j|0]|0}}while(0);j=(n&255)<<8;n=l+1|0;l=n&65535;h=c[9699632+((n>>>8&255)<<2)>>2]|0;do{if((h|0)==0){m=c[3528598]|0;if((m|0)==0){o=0;break}o=gj[m&4095](l)|0}else{o=a[h+(n&255)|0]|0}}while(0);n=(o&255|j)-1|0;j=n&255;o=n>>>8;h=o&255;l=o<<8;o=n>>>12&8|a[9642680]&-15&255;a[9642680]=((l^n>>>1)>>>14&2|n>>>16&1|(((l|n&255)&65535)<<16>>16==0?o|4:o)&253)&255;o=c[2426870]|0;n=o&65535;l=c[9700656+((o>>>8&255)<<2)>>2]|0;do{if((l|0)==0){m=c[2444172]|0;if((m|0)==0){break}gg[m&4095](n,h)}else{a[l+(o&255)|0]=h}}while(0);h=o+1|0;o=c[9700656+((h>>>8&255)<<2)>>2]|0;if((o|0)!=0){a[o+(h&255)|0]=j;return}o=c[2444172]|0;if((o|0)==0){return}gg[o&4095](h&65535,j);return}function fSW(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;a[9642680]=a[9642680]&-15;e=c[2410662]|0;f=e&65535;g=c[9701680+((e>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[3528598]|0;if((h|0)==0){i=0;j=e;k=f;break}l=gj[h&4095](f)|0;h=c[2410662]|0;i=l;j=h;k=h&65535}else{i=a[g+(e&255)|0]|0;j=e;k=f}}while(0);f=i&255;i=f<<8;e=j+1|0;j=e&65535;g=c[9701680+((e>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[3528598]|0;if((h|0)==0){m=0;n=k;break}l=gj[h&4095](j)|0;m=l;n=b[4821324]|0}else{m=a[g+(e&255)|0]|0;n=k}}while(0);k=m&255;m=k|i;c[2426870]=m;b[4821324]=n+2&65535;n=m&65535;i=c[9699632+(f<<2)>>2]|0;do{if((i|0)==0){f=c[3528598]|0;if((f|0)==0){o=0;break}o=gj[f&4095](n)|0}else{o=a[i+k|0]|0}}while(0);k=o&255;o=k<<8;i=m+1|0;m=i&65535;n=c[9699632+((i>>>8&255)<<2)>>2]|0;do{if((n|0)==0){f=c[3528598]|0;if((f|0)==0){p=0;break}p=gj[f&4095](m)|0}else{p=a[n+(i&255)|0]|0}}while(0);i=d[9642680]|0|k>>>4&8;if((p&255|o|0)!=0){q=i&255;a[9642680]=q;return}q=(i|4)&255;a[9642680]=q;return}function fSX(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=c[2443776]|0;g=(e&65535)>>>8&255;do{if((c[f+68+((d&65535)>>>8<<2)>>2]|0)==0){e=c[f+3168>>2]|0;if((e|0)==0){h=g;i=f;break}gj[e&4095](d)|0;h=a[9660961]|0;i=c[2443776]|0}else{h=g;i=f}}while(0);f=(c[2440596]|0)-1|0;c[2440596]=f;g=c[2415241]|0;d=g&65535;e=c[i+68+((g>>>8&255|256)<<2)>>2]|0;do{if((e|0)==0){j=c[i+3152>>2]|0;if((j|0)==0){k=f;l=i;break}gg[j&4095](d,h);k=c[2440596]|0;l=c[2443776]|0}else{a[e+(g&255)|0]=h;k=f;l=i}}while(0);i=k-1|0;c[2440596]=i;a[9660964]=(a[9660964]|0)-1&255;k=c[2415241]|0;f=k&65535;h=a[9660960]|0;g=c[l+68+((k>>>8&255|256)<<2)>>2]|0;do{if((g|0)==0){e=c[l+3152>>2]|0;if((e|0)==0){m=i;n=l;break}gg[e&4095](f,h);m=c[2440596]|0;n=c[2443776]|0}else{a[g+(k&255)|0]=h;m=i;n=l}}while(0);l=m-1|0;c[2440596]=l;a[9660964]=(a[9660964]|0)-1&255;m=c[2415241]|0;i=m&65535;h=a[9660979]|16;k=c[n+68+((m>>>8&255|256)<<2)>>2]|0;do{if((k|0)==0){g=c[n+3152>>2]|0;if((g|0)==0){o=l;p=n;break}gg[g&4095](i,h);o=c[2440596]|0;p=c[2443776]|0}else{a[k+(m&255)|0]=h;o=l;p=n}}while(0);n=o-1|0;c[2440596]=n;a[9660964]=(a[9660964]|0)-1&255;a[9660979]=a[9660979]|4;o=c[p+1088>>2]|0;do{if((o|0)==0){l=c[p+3148>>2]|0;if((l|0)==0){q=0;r=n;s=p;break}h=gj[l&4095](-2)|0;q=h;r=c[2440596]|0;s=c[2443776]|0}else{q=a[o+254|0]|0;r=n;s=p}}while(0);a[9660960]=q;q=r-1|0;c[2440596]=q;r=c[s+1088>>2]|0;if((r|0)!=0){t=a[r+255|0]|0;u=q;a[9660961]=t;v=u-1|0;c[2440596]=v;return}r=c[s+3148>>2]|0;if((r|0)==0){t=0;u=q;a[9660961]=t;v=u-1|0;c[2440596]=v;return}q=gj[r&4095](-1)|0;t=q;u=c[2440596]|0;a[9660961]=t;v=u-1|0;c[2440596]=v;return}function fSY(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660972]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415241]|0;e=f&65535;do{if((c[j+68+((f>>>8&255)<<2)>>2]|0)==0){g=c[j+3148>>2]|0;if((g|0)==0){l=i;m=f;n=j;break}gj[g&4095](e)|0;l=c[2440596]|0;m=c[2415241]|0;n=c[2443776]|0}else{l=i;m=f;n=j}}while(0);j=l-1|0;c[2440596]=j;l=m&65535;f=a[9660961]|0;i=c[n+68+((m>>>8&255|256)<<2)>>2]|0;do{if((i|0)==0){e=c[n+3152>>2]|0;if((e|0)==0){o=j;p=n;break}gg[e&4095](l,f);o=c[2440596]|0;p=c[2443776]|0}else{a[i+(m&255)|0]=f;o=j;p=n}}while(0);n=o-1|0;c[2440596]=n;a[9660964]=(a[9660964]|0)-1&255;o=c[2415241]|0;j=o&65535;f=a[9660960]|0;m=c[p+68+((o>>>8&255|256)<<2)>>2]|0;do{if((m|0)==0){i=c[p+3152>>2]|0;if((i|0)==0){q=n;r=p;break}gg[i&4095](j,f);q=c[2440596]|0;r=c[2443776]|0}else{a[m+(o&255)|0]=f;q=n;r=p}}while(0);p=q-1|0;c[2440596]=p;a[9660964]=(a[9660964]|0)-1&255;q=b[4830480]|0;b[4830480]=q+1&65535;n=q&65535;f=c[r+68+(n>>>8<<2)>>2]|0;if((f|0)!=0){s=a[f+(n&255)|0]|0;t=p;a[9660973]=s;u=t-1|0;c[2440596]=u;v=c[2415243]|0;c[2415240]=v;return}n=c[r+3168>>2]|0;if((n|0)==0){s=0;t=p;a[9660973]=s;u=t-1|0;c[2440596]=u;v=c[2415243]|0;c[2415240]=v;return}p=gj[n&4095](q)|0;s=p;t=c[2440596]|0;a[9660973]=s;u=t-1|0;c[2440596]=u;v=c[2415243]|0;c[2415240]=v;return}function fSZ(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=c[2443776]|0;do{if((c[e+68+((d&65535)>>>8<<2)>>2]|0)==0){f=c[e+3168>>2]|0;if((f|0)==0){g=e;break}gj[f&4095](d)|0;g=c[2443776]|0}else{g=e}}while(0);e=(c[2440596]|0)-1|0;c[2440596]=e;d=c[2415241]|0;f=d&65535;h=d&255;do{if((c[g+68+((d>>>8&255)<<2)>>2]|0)==0){i=c[g+3148>>2]|0;if((i|0)==0){j=e;k=h;l=g;break}gj[i&4095](f)|0;j=c[2440596]|0;k=a[9660964]|0;l=c[2443776]|0}else{j=e;k=h;l=g}}while(0);g=j-1|0;c[2440596]=g;a[9660964]=k+1&255;k=c[2415241]|0;j=k&65535;h=c[l+68+((k>>>8&255)<<2)>>2]|0;e=k&255;do{if((h|0)==0){f=c[l+3148>>2]|0;if((f|0)==0){m=0;n=g;o=e;p=l;break}d=gj[f&4095](j)|0;m=d;n=c[2440596]|0;o=a[9660964]|0;p=c[2443776]|0}else{m=a[h+(k&255)|0]|0;n=g;o=e;p=l}}while(0);a[9660979]=m;m=n-1|0;c[2440596]=m;a[9660964]=o+1&255;o=c[2415241]|0;n=o&65535;l=c[p+68+((o>>>8&255)<<2)>>2]|0;e=o&255;do{if((l|0)==0){g=c[p+3148>>2]|0;if((g|0)==0){q=0;r=m;s=e;t=p;break}k=gj[g&4095](n)|0;q=k;r=c[2440596]|0;s=a[9660964]|0;t=c[2443776]|0}else{q=a[l+(o&255)|0]|0;r=m;s=e;t=p}}while(0);a[9660960]=q;q=r-1|0;c[2440596]=q;a[9660964]=s+1&255;s=c[2415241]|0;r=s&65535;p=c[t+68+((s>>>8&255)<<2)>>2]|0;do{if((p|0)==0){e=c[t+3148>>2]|0;if((e|0)==0){u=0;v=q;break}m=gj[e&4095](r)|0;u=m;v=c[2440596]|0}else{u=a[p+(s&255)|0]|0;v=q}}while(0);a[9660961]=u;c[2440596]=v-1;v=a[9660979]|0;a[9660979]=v|48;if((a[9660983]|0)==0){return}if((v&4)!=0){return}a[9660981]=1;return}function fS_(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=c[2443776]|0;do{if((c[e+68+((d&65535)>>>8<<2)>>2]|0)==0){f=c[e+3168>>2]|0;if((f|0)==0){g=e;break}gj[f&4095](d)|0;g=c[2443776]|0}else{g=e}}while(0);e=(c[2440596]|0)-1|0;c[2440596]=e;d=c[2415241]|0;f=d&65535;h=d&255;do{if((c[g+68+((d>>>8&255)<<2)>>2]|0)==0){i=c[g+3148>>2]|0;if((i|0)==0){j=e;k=h;l=g;break}gj[i&4095](f)|0;j=c[2440596]|0;k=a[9660964]|0;l=c[2443776]|0}else{j=e;k=h;l=g}}while(0);g=j-1|0;c[2440596]=g;a[9660964]=k+1&255;k=c[2415241]|0;j=k&65535;h=c[l+68+((k>>>8&255)<<2)>>2]|0;e=k&255;do{if((h|0)==0){f=c[l+3148>>2]|0;if((f|0)==0){m=0;n=g;o=e;p=l;break}d=gj[f&4095](j)|0;m=d;n=c[2440596]|0;o=a[9660964]|0;p=c[2443776]|0}else{m=a[h+(k&255)|0]|0;n=g;o=e;p=l}}while(0);a[9660960]=m;m=n-1|0;c[2440596]=m;a[9660964]=o+1&255;o=c[2415241]|0;n=o&65535;l=c[p+68+((o>>>8&255)<<2)>>2]|0;do{if((l|0)==0){e=c[p+3148>>2]|0;if((e|0)==0){q=0;r=m;s=p;break}g=gj[e&4095](n)|0;q=g;r=c[2440596]|0;s=c[2443776]|0}else{q=a[l+(o&255)|0]|0;r=m;s=p}}while(0);a[9660961]=q;q=r-1|0;c[2440596]=q;r=b[4830480]|0;if((c[s+68+((r&65535)>>>8<<2)>>2]|0)!=0){t=q;u=r;v=t-1|0;c[2440596]=v;w=u+1&65535;b[4830480]=w;return}p=c[s+3148>>2]|0;if((p|0)==0){t=q;u=r;v=t-1|0;c[2440596]=v;w=u+1&65535;b[4830480]=w;return}gj[p&4095](r)|0;t=c[2440596]|0;u=b[4830480]|0;v=t-1|0;c[2440596]=v;w=u+1&65535;b[4830480]=w;return}function fS$(){var a=0,d=0,e=0;a=b[4830480]|0;b[4830480]=a+1&65535;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3168>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function fS0(){var d=0,e=0,f=0,g=0,h=0,i=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(e&255)|0]|0}}while(0);c[2440596]=(c[2440596]|0)-1;a[9660978]=i;a[9660979]=a[9660979]&125|(i<<24>>24==0?2:i&-128);return}function fS1(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(e&255)|0]|0}}while(0);c[2440596]=(c[2440596]|0)-1;e=a[9660979]|0;g=e&-2;a[9660979]=g;d=a[9660978]|0;if((d&255)<(i&255)){j=g}else{g=e|1;a[9660979]=g;j=g}if(d<<24>>24==i<<24>>24){k=j&125|2;a[9660979]=k;return}else{k=j&125|d-i&255&-128;a[9660979]=k;return}}function fS2(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(e&255)|0]|0}}while(0);c[2440596]=(c[2440596]|0)-1;e=a[9660979]|0;g=e&-2;a[9660979]=g;d=a[9660977]|0;if((d&255)<(i&255)){j=g}else{g=e|1;a[9660979]=g;j=g}if(d<<24>>24==i<<24>>24){k=j&125|2;a[9660979]=k;return}else{k=j&125|d-i&255&-128;a[9660979]=k;return}}function fS3(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(e&255)|0]|0}}while(0);e=(c[2440596]|0)-1|0;c[2440596]=e;if((a[9660979]|0)<0){return}g=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((g&65535)>>>8<<2)>>2]|0)==0){f=c[d+3148>>2]|0;if((f|0)==0){j=e;k=g;break}gj[f&4095](g)|0;j=c[2440596]|0;k=b[4830480]|0}else{j=e;k=g}}while(0);g=j-1|0;c[2440596]=g;j=k+(i<<24>>24)&65535;b[4830486]=j;i=a[9660961]|0;if(((j&65535)>>>8&255)<<24>>24!=i<<24>>24){k=(i&255)<<8;i=k|j&255;j=c[2443776]|0;do{if((c[j+68+((k&65535)>>>8<<2)>>2]|0)==0){e=c[j+3148>>2]|0;if((e|0)==0){l=g;break}gj[e&4095](i)|0;l=c[2440596]|0}else{l=g}}while(0);c[2440596]=l-1}c[2415240]=c[2415243];return}function fS4(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(e&255)|0]|0}}while(0);e=(c[2440596]|0)-1|0;c[2440596]=e;if((a[9660979]|0)>=0){return}g=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((g&65535)>>>8<<2)>>2]|0)==0){f=c[d+3148>>2]|0;if((f|0)==0){j=e;k=g;break}gj[f&4095](g)|0;j=c[2440596]|0;k=b[4830480]|0}else{j=e;k=g}}while(0);g=j-1|0;c[2440596]=g;j=k+(i<<24>>24)&65535;b[4830486]=j;i=a[9660961]|0;if(((j&65535)>>>8&255)<<24>>24!=i<<24>>24){k=(i&255)<<8;i=k|j&255;j=c[2443776]|0;do{if((c[j+68+((k&65535)>>>8<<2)>>2]|0)==0){e=c[j+3148>>2]|0;if((e|0)==0){l=g;break}gj[e&4095](i)|0;l=c[2440596]|0}else{l=g}}while(0);c[2440596]=l-1}c[2415240]=c[2415243];return}function fS5(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(e&255)|0]|0}}while(0);e=(c[2440596]|0)-1|0;c[2440596]=e;if((a[9660979]&64)!=0){return}g=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((g&65535)>>>8<<2)>>2]|0)==0){f=c[d+3148>>2]|0;if((f|0)==0){j=e;k=g;break}gj[f&4095](g)|0;j=c[2440596]|0;k=b[4830480]|0}else{j=e;k=g}}while(0);g=j-1|0;c[2440596]=g;j=k+(i<<24>>24)&65535;b[4830486]=j;i=a[9660961]|0;if(((j&65535)>>>8&255)<<24>>24!=i<<24>>24){k=(i&255)<<8;i=k|j&255;j=c[2443776]|0;do{if((c[j+68+((k&65535)>>>8<<2)>>2]|0)==0){e=c[j+3148>>2]|0;if((e|0)==0){l=g;break}gj[e&4095](i)|0;l=c[2440596]|0}else{l=g}}while(0);c[2440596]=l-1}c[2415240]=c[2415243];return}function fS6(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(e&255)|0]|0}}while(0);e=(c[2440596]|0)-1|0;c[2440596]=e;if((a[9660979]&64)==0){return}g=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((g&65535)>>>8<<2)>>2]|0)==0){f=c[d+3148>>2]|0;if((f|0)==0){j=e;k=g;break}gj[f&4095](g)|0;j=c[2440596]|0;k=b[4830480]|0}else{j=e;k=g}}while(0);g=j-1|0;c[2440596]=g;j=k+(i<<24>>24)&65535;b[4830486]=j;i=a[9660961]|0;if(((j&65535)>>>8&255)<<24>>24!=i<<24>>24){k=(i&255)<<8;i=k|j&255;j=c[2443776]|0;do{if((c[j+68+((k&65535)>>>8<<2)>>2]|0)==0){e=c[j+3148>>2]|0;if((e|0)==0){l=g;break}gj[e&4095](i)|0;l=c[2440596]|0}else{l=g}}while(0);c[2440596]=l-1}c[2415240]=c[2415243];return}function fS7(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(e&255)|0]|0}}while(0);e=(c[2440596]|0)-1|0;c[2440596]=e;if((a[9660979]&1)!=0){return}g=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((g&65535)>>>8<<2)>>2]|0)==0){f=c[d+3148>>2]|0;if((f|0)==0){j=e;k=g;break}gj[f&4095](g)|0;j=c[2440596]|0;k=b[4830480]|0}else{j=e;k=g}}while(0);g=j-1|0;c[2440596]=g;j=k+(i<<24>>24)&65535;b[4830486]=j;i=a[9660961]|0;if(((j&65535)>>>8&255)<<24>>24!=i<<24>>24){k=(i&255)<<8;i=k|j&255;j=c[2443776]|0;do{if((c[j+68+((k&65535)>>>8<<2)>>2]|0)==0){e=c[j+3148>>2]|0;if((e|0)==0){l=g;break}gj[e&4095](i)|0;l=c[2440596]|0}else{l=g}}while(0);c[2440596]=l-1}c[2415240]=c[2415243];return}function fS8(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(e&255)|0]|0}}while(0);e=(c[2440596]|0)-1|0;c[2440596]=e;if((a[9660979]&1)==0){return}g=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((g&65535)>>>8<<2)>>2]|0)==0){f=c[d+3148>>2]|0;if((f|0)==0){j=e;k=g;break}gj[f&4095](g)|0;j=c[2440596]|0;k=b[4830480]|0}else{j=e;k=g}}while(0);g=j-1|0;c[2440596]=g;j=k+(i<<24>>24)&65535;b[4830486]=j;i=a[9660961]|0;if(((j&65535)>>>8&255)<<24>>24!=i<<24>>24){k=(i&255)<<8;i=k|j&255;j=c[2443776]|0;do{if((c[j+68+((k&65535)>>>8<<2)>>2]|0)==0){e=c[j+3148>>2]|0;if((e|0)==0){l=g;break}gj[e&4095](i)|0;l=c[2440596]|0}else{l=g}}while(0);c[2440596]=l-1}c[2415240]=c[2415243];return}function fS9(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(e&255)|0]|0}}while(0);e=(c[2440596]|0)-1|0;c[2440596]=e;if((a[9660979]&2)!=0){return}g=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((g&65535)>>>8<<2)>>2]|0)==0){f=c[d+3148>>2]|0;if((f|0)==0){j=e;k=g;break}gj[f&4095](g)|0;j=c[2440596]|0;k=b[4830480]|0}else{j=e;k=g}}while(0);g=j-1|0;c[2440596]=g;j=k+(i<<24>>24)&65535;b[4830486]=j;i=a[9660961]|0;if(((j&65535)>>>8&255)<<24>>24!=i<<24>>24){k=(i&255)<<8;i=k|j&255;j=c[2443776]|0;do{if((c[j+68+((k&65535)>>>8<<2)>>2]|0)==0){e=c[j+3148>>2]|0;if((e|0)==0){l=g;break}gj[e&4095](i)|0;l=c[2440596]|0}else{l=g}}while(0);c[2440596]=l-1}c[2415240]=c[2415243];return}function fTa(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(e&255)|0]|0}}while(0);e=(c[2440596]|0)-1|0;c[2440596]=e;if((a[9660979]&2)==0){return}g=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((g&65535)>>>8<<2)>>2]|0)==0){f=c[d+3148>>2]|0;if((f|0)==0){j=e;k=g;break}gj[f&4095](g)|0;j=c[2440596]|0;k=b[4830480]|0}else{j=e;k=g}}while(0);g=j-1|0;c[2440596]=g;j=k+(i<<24>>24)&65535;b[4830486]=j;i=a[9660961]|0;if(((j&65535)>>>8&255)<<24>>24!=i<<24>>24){k=(i&255)<<8;i=k|j&255;j=c[2443776]|0;do{if((c[j+68+((k&65535)>>>8<<2)>>2]|0)==0){e=c[j+3148>>2]|0;if((e|0)==0){l=g;break}gj[e&4095](i)|0;l=c[2440596]|0}else{l=g}}while(0);c[2440596]=l-1}c[2415240]=c[2415243];return}function fTb(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=f&255;do{if((c[j+68+((f>>>8&255)<<2)>>2]|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=i;m=g;n=j;break}gj[d&4095](e)|0;l=c[2440596]|0;m=a[9660968]|0;n=c[2443776]|0}else{l=i;m=g;n=j}}while(0);j=l-1|0;c[2440596]=j;a[9660968]=(a[9660977]|0)+m&255;m=c[2415242]|0;l=m&65535;g=c[n+68+((m>>>8&255)<<2)>>2]|0;i=m&255;do{if((g|0)==0){e=c[n+3148>>2]|0;if((e|0)==0){o=0;p=j;q=i;r=n;break}f=gj[e&4095](l)|0;o=f;p=c[2440596]|0;q=a[9660968]|0;r=c[2443776]|0}else{o=a[g+(m&255)|0]|0;p=j;q=i;r=n}}while(0);a[9660972]=o;o=p-1|0;c[2440596]=o;a[9660968]=q+1&255;q=c[2415242]|0;p=q&65535;n=c[r+68+((q>>>8&255)<<2)>>2]|0;do{if((n|0)==0){i=c[r+3148>>2]|0;if((i|0)==0){s=0;t=o;u=r;break}j=gj[i&4095](p)|0;s=j;t=c[2440596]|0;u=c[2443776]|0}else{s=a[n+(q&255)|0]|0;t=o;u=r}}while(0);a[9660973]=s;s=t-1|0;c[2440596]=s;t=c[2415243]|0;r=t&65535;o=c[u+68+((t>>>8&255)<<2)>>2]|0;do{if((o|0)==0){q=c[u+3156>>2]|0;if((q|0)==0){v=0;w=s;break}n=gj[q&4095](r)|0;v=n;w=c[2440596]|0}else{v=a[o+(t&255)|0]|0;w=s}}while(0);c[2440596]=w-1;w=a[9660976]|v;a[9660976]=w;a[9660979]=(w<<24>>24==0?2:w&-128)|a[9660979]&125;return}function fTc(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=f&255;do{if((c[j+68+((f>>>8&255)<<2)>>2]|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=i;m=g;n=j;break}gj[d&4095](e)|0;l=c[2440596]|0;m=a[9660968]|0;n=c[2443776]|0}else{l=i;m=g;n=j}}while(0);j=l-1|0;c[2440596]=j;a[9660968]=(a[9660977]|0)+m&255;m=c[2415242]|0;l=m&65535;g=c[n+68+((m>>>8&255)<<2)>>2]|0;i=m&255;do{if((g|0)==0){e=c[n+3148>>2]|0;if((e|0)==0){o=0;p=j;q=i;r=n;break}f=gj[e&4095](l)|0;o=f;p=c[2440596]|0;q=a[9660968]|0;r=c[2443776]|0}else{o=a[g+(m&255)|0]|0;p=j;q=i;r=n}}while(0);a[9660972]=o;o=p-1|0;c[2440596]=o;a[9660968]=q+1&255;q=c[2415242]|0;p=q&65535;n=c[r+68+((q>>>8&255)<<2)>>2]|0;do{if((n|0)==0){i=c[r+3148>>2]|0;if((i|0)==0){s=0;t=o;u=r;break}j=gj[i&4095](p)|0;s=j;t=c[2440596]|0;u=c[2443776]|0}else{s=a[n+(q&255)|0]|0;t=o;u=r}}while(0);a[9660973]=s;s=t-1|0;c[2440596]=s;t=c[2415243]|0;r=t&65535;o=c[u+68+((t>>>8&255)<<2)>>2]|0;do{if((o|0)==0){q=c[u+3156>>2]|0;if((q|0)==0){v=0;w=s;break}n=gj[q&4095](r)|0;v=n;w=c[2440596]|0}else{v=a[o+(t&255)|0]|0;w=s}}while(0);c[2440596]=w-1;w=a[9660976]&v;a[9660976]=w;a[9660979]=(w<<24>>24==0?2:w&-128)|a[9660979]&125;return}function fTd(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=f&255;do{if((c[j+68+((f>>>8&255)<<2)>>2]|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=i;m=g;n=j;break}gj[d&4095](e)|0;l=c[2440596]|0;m=a[9660968]|0;n=c[2443776]|0}else{l=i;m=g;n=j}}while(0);j=l-1|0;c[2440596]=j;a[9660968]=(a[9660977]|0)+m&255;m=c[2415242]|0;l=m&65535;g=c[n+68+((m>>>8&255)<<2)>>2]|0;i=m&255;do{if((g|0)==0){e=c[n+3148>>2]|0;if((e|0)==0){o=0;p=j;q=i;r=n;break}f=gj[e&4095](l)|0;o=f;p=c[2440596]|0;q=a[9660968]|0;r=c[2443776]|0}else{o=a[g+(m&255)|0]|0;p=j;q=i;r=n}}while(0);a[9660972]=o;o=p-1|0;c[2440596]=o;a[9660968]=q+1&255;q=c[2415242]|0;p=q&65535;n=c[r+68+((q>>>8&255)<<2)>>2]|0;do{if((n|0)==0){i=c[r+3148>>2]|0;if((i|0)==0){s=0;t=o;u=r;break}j=gj[i&4095](p)|0;s=j;t=c[2440596]|0;u=c[2443776]|0}else{s=a[n+(q&255)|0]|0;t=o;u=r}}while(0);a[9660973]=s;s=t-1|0;c[2440596]=s;t=c[2415243]|0;r=t&65535;o=c[u+68+((t>>>8&255)<<2)>>2]|0;do{if((o|0)==0){q=c[u+3156>>2]|0;if((q|0)==0){v=0;w=s;break}n=gj[q&4095](r)|0;v=n;w=c[2440596]|0}else{v=a[o+(t&255)|0]|0;w=s}}while(0);c[2440596]=w-1;w=a[9660976]|0;s=w^v;a[9660976]=s;a[9660979]=(w<<24>>24==v<<24>>24?2:s&-128)|a[9660979]&125;return}function fTe(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=f&255;do{if((c[j+68+((f>>>8&255)<<2)>>2]|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=i;m=g;n=j;break}gj[d&4095](e)|0;l=c[2440596]|0;m=a[9660968]|0;n=c[2443776]|0}else{l=i;m=g;n=j}}while(0);j=l-1|0;c[2440596]=j;a[9660968]=(a[9660977]|0)+m&255;m=c[2415242]|0;l=m&65535;g=c[n+68+((m>>>8&255)<<2)>>2]|0;i=m&255;do{if((g|0)==0){e=c[n+3148>>2]|0;if((e|0)==0){o=0;p=j;q=i;r=n;break}f=gj[e&4095](l)|0;o=f;p=c[2440596]|0;q=a[9660968]|0;r=c[2443776]|0}else{o=a[g+(m&255)|0]|0;p=j;q=i;r=n}}while(0);a[9660972]=o;o=p-1|0;c[2440596]=o;a[9660968]=q+1&255;q=c[2415242]|0;p=q&65535;n=c[r+68+((q>>>8&255)<<2)>>2]|0;do{if((n|0)==0){i=c[r+3148>>2]|0;if((i|0)==0){s=0;t=o;u=r;break}j=gj[i&4095](p)|0;s=j;t=c[2440596]|0;u=c[2443776]|0}else{s=a[n+(q&255)|0]|0;t=o;u=r}}while(0);a[9660973]=s;s=t-1|0;c[2440596]=s;t=c[2415243]|0;r=t&65535;o=c[u+68+((t>>>8&255)<<2)>>2]|0;do{if((o|0)==0){q=c[u+3156>>2]|0;if((q|0)==0){v=0;w=s;break}n=gj[q&4095](r)|0;v=n;w=c[2440596]|0}else{v=a[o+(t&255)|0]|0;w=s}}while(0);s=v&255;c[2440596]=w-1;w=a[9660979]|0;t=w&255;o=t&1;r=a[9660976]|0;u=r&255;if((t&8|0)==0){t=u+s+o|0;n=w&-66;q=((((r^v)&128^128)&(t^u)|0)==0?n:n|64)|(t&65280|0)!=0;a[9660979]=q;a[9660976]=t&255;if((t&255|0)==0){a[9660979]=q&125|2;return}else{a[9660979]=(q&125|t&128)&255;return}}t=o+(s&15)+(u&15)|0;o=(u&240)+(s&240)|0;s=w&60;w=(t+o&255|0)==0?s|2:s;a[9660979]=w;if((t|0)>9){x=t+6|0;y=o+16|0}else{x=t;y=o}if((y&128|0)==0){z=w}else{o=w|-128;a[9660979]=o;z=o}if((((r^v)&128^128)&(y^u)|0)==0){A=z}else{u=z|64;a[9660979]=u;A=u}u=(y|0)>144?y+96|0:y;if((u&65280|0)!=0){a[9660979]=A|1}a[9660976]=(u&240|x&15)&255;return}function fTf(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=a[9660976]|0;e=b[4830480]|0;b[4830480]=e+1&65535;f=e&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](e)|0;j=l;k=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=g}}while(0);a[9660968]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;g=c[2415242]|0;f=g&65535;h=g&255;do{if((c[k+68+((g>>>8&255)<<2)>>2]|0)==0){e=c[k+3148>>2]|0;if((e|0)==0){m=j;n=h;o=k;break}gj[e&4095](f)|0;m=c[2440596]|0;n=a[9660968]|0;o=c[2443776]|0}else{m=j;n=h;o=k}}while(0);k=m-1|0;c[2440596]=k;a[9660968]=(a[9660977]|0)+n&255;n=c[2415242]|0;m=n&65535;h=c[o+68+((n>>>8&255)<<2)>>2]|0;j=n&255;do{if((h|0)==0){f=c[o+3148>>2]|0;if((f|0)==0){p=0;q=k;r=j;s=o;break}g=gj[f&4095](m)|0;p=g;q=c[2440596]|0;r=a[9660968]|0;s=c[2443776]|0}else{p=a[h+(n&255)|0]|0;q=k;r=j;s=o}}while(0);a[9660972]=p;p=q-1|0;c[2440596]=p;a[9660968]=r+1&255;r=c[2415242]|0;q=r&65535;o=c[s+68+((r>>>8&255)<<2)>>2]|0;do{if((o|0)==0){j=c[s+3148>>2]|0;if((j|0)==0){t=0;u=p;v=s;break}k=gj[j&4095](q)|0;t=k;u=c[2440596]|0;v=c[2443776]|0}else{t=a[o+(r&255)|0]|0;u=p;v=s}}while(0);a[9660973]=t;t=u-1|0;c[2440596]=t;u=c[2415243]|0;s=c[v+68+((u>>>8&255|256)<<2)>>2]|0;if((s|0)!=0){a[s+(u&255)|0]=d;w=t;x=w-1|0;c[2440596]=x;return}s=c[v+3160>>2]|0;if((s|0)==0){w=t;x=w-1|0;c[2440596]=x;return}gg[s&4095](u&65535,d);w=c[2440596]|0;x=w-1|0;c[2440596]=x;return}function fTg(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=f&255;do{if((c[j+68+((f>>>8&255)<<2)>>2]|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=i;m=g;n=j;break}gj[d&4095](e)|0;l=c[2440596]|0;m=a[9660968]|0;n=c[2443776]|0}else{l=i;m=g;n=j}}while(0);j=l-1|0;c[2440596]=j;a[9660968]=(a[9660977]|0)+m&255;m=c[2415242]|0;l=m&65535;g=c[n+68+((m>>>8&255)<<2)>>2]|0;i=m&255;do{if((g|0)==0){e=c[n+3148>>2]|0;if((e|0)==0){o=0;p=j;q=i;r=n;break}f=gj[e&4095](l)|0;o=f;p=c[2440596]|0;q=a[9660968]|0;r=c[2443776]|0}else{o=a[g+(m&255)|0]|0;p=j;q=i;r=n}}while(0);a[9660972]=o;o=p-1|0;c[2440596]=o;a[9660968]=q+1&255;q=c[2415242]|0;p=q&65535;n=c[r+68+((q>>>8&255)<<2)>>2]|0;do{if((n|0)==0){i=c[r+3148>>2]|0;if((i|0)==0){s=0;t=o;u=r;break}j=gj[i&4095](p)|0;s=j;t=c[2440596]|0;u=c[2443776]|0}else{s=a[n+(q&255)|0]|0;t=o;u=r}}while(0);a[9660973]=s;s=t-1|0;c[2440596]=s;t=c[2415243]|0;r=c[u+68+((t>>>8&255)<<2)>>2]|0;if((r|0)!=0){v=a[r+(t&255)|0]|0;w=s;x=w-1|0;c[2440596]=x;a[9660976]=v;y=v<<24>>24==0;z=a[9660979]|0;A=z&125;B=v&-128;C=y?2:B;D=A|C;a[9660979]=D;return}r=c[u+3156>>2]|0;if((r|0)==0){v=0;w=s;x=w-1|0;c[2440596]=x;a[9660976]=v;y=v<<24>>24==0;z=a[9660979]|0;A=z&125;B=v&-128;C=y?2:B;D=A|C;a[9660979]=D;return}s=gj[r&4095](t&65535)|0;v=s;w=c[2440596]|0;x=w-1|0;c[2440596]=x;a[9660976]=v;y=v<<24>>24==0;z=a[9660979]|0;A=z&125;B=v&-128;C=y?2:B;D=A|C;a[9660979]=D;return}function fTh(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=f&255;do{if((c[j+68+((f>>>8&255)<<2)>>2]|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=i;m=g;n=j;break}gj[d&4095](e)|0;l=c[2440596]|0;m=a[9660968]|0;n=c[2443776]|0}else{l=i;m=g;n=j}}while(0);j=l-1|0;c[2440596]=j;a[9660968]=(a[9660977]|0)+m&255;m=c[2415242]|0;l=m&65535;g=c[n+68+((m>>>8&255)<<2)>>2]|0;i=m&255;do{if((g|0)==0){e=c[n+3148>>2]|0;if((e|0)==0){o=0;p=j;q=i;r=n;break}f=gj[e&4095](l)|0;o=f;p=c[2440596]|0;q=a[9660968]|0;r=c[2443776]|0}else{o=a[g+(m&255)|0]|0;p=j;q=i;r=n}}while(0);a[9660972]=o;o=p-1|0;c[2440596]=o;a[9660968]=q+1&255;q=c[2415242]|0;p=q&65535;n=c[r+68+((q>>>8&255)<<2)>>2]|0;do{if((n|0)==0){i=c[r+3148>>2]|0;if((i|0)==0){s=0;t=o;u=r;break}j=gj[i&4095](p)|0;s=j;t=c[2440596]|0;u=c[2443776]|0}else{s=a[n+(q&255)|0]|0;t=o;u=r}}while(0);a[9660973]=s;s=t-1|0;c[2440596]=s;t=c[2415243]|0;r=t&65535;o=c[u+68+((t>>>8&255)<<2)>>2]|0;do{if((o|0)==0){q=c[u+3156>>2]|0;if((q|0)==0){v=0;w=s;break}n=gj[q&4095](r)|0;v=n;w=c[2440596]|0}else{v=a[o+(t&255)|0]|0;w=s}}while(0);c[2440596]=w-1;w=a[9660979]|0;s=w&-2;a[9660979]=s;t=a[9660976]|0;if((t&255)<(v&255)){x=s}else{s=w|1;a[9660979]=s;x=s}if(t<<24>>24==v<<24>>24){y=x&125|2;a[9660979]=y;return}else{y=x&125|t-v&255&-128;a[9660979]=y;return}}function fTi(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=f&255;do{if((c[j+68+((f>>>8&255)<<2)>>2]|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=i;m=g;n=j;break}gj[d&4095](e)|0;l=c[2440596]|0;m=a[9660968]|0;n=c[2443776]|0}else{l=i;m=g;n=j}}while(0);j=l-1|0;c[2440596]=j;a[9660968]=(a[9660977]|0)+m&255;m=c[2415242]|0;l=m&65535;g=c[n+68+((m>>>8&255)<<2)>>2]|0;i=m&255;do{if((g|0)==0){e=c[n+3148>>2]|0;if((e|0)==0){o=0;p=j;q=i;r=n;break}f=gj[e&4095](l)|0;o=f;p=c[2440596]|0;q=a[9660968]|0;r=c[2443776]|0}else{o=a[g+(m&255)|0]|0;p=j;q=i;r=n}}while(0);a[9660972]=o;o=p-1|0;c[2440596]=o;a[9660968]=q+1&255;q=c[2415242]|0;p=q&65535;n=c[r+68+((q>>>8&255)<<2)>>2]|0;do{if((n|0)==0){i=c[r+3148>>2]|0;if((i|0)==0){s=0;t=o;u=r;break}j=gj[i&4095](p)|0;s=j;t=c[2440596]|0;u=c[2443776]|0}else{s=a[n+(q&255)|0]|0;t=o;u=r}}while(0);a[9660973]=s;s=t-1|0;c[2440596]=s;t=c[2415243]|0;r=t&65535;o=c[u+68+((t>>>8&255)<<2)>>2]|0;do{if((o|0)==0){q=c[u+3156>>2]|0;if((q|0)==0){v=0;w=s;break}n=gj[q&4095](r)|0;v=n;w=c[2440596]|0}else{v=a[o+(t&255)|0]|0;w=s}}while(0);s=v&255;c[2440596]=w-1;w=a[9660979]|0;t=w&255;o=t&1^1;r=a[9660976]|0;u=r&255;n=u-s-o|0;if((t&8|0)!=0){t=(u&15)-(s&15)-o|0;o=(u&240)-(s&240)|0;if((t&16|0)==0){x=t;y=o}else{x=t-6|0;y=o-1|0}o=w&60;t=(((r^v)&128&(n^u)|0)==0?o:o|64)|(n&65280|0)==0;o=(n&255|0)==0?t|2:t;a[9660979]=(n&128|0)==0?o:o|-128;a[9660976]=(((y&256|0)==0?y:y+160|0)&240|x&15)&255;return}x=w&-66;w=(((r^v)&128&(n^u)|0)==0?x:x|64)|(n&65280|0)==0;a[9660979]=w;a[9660976]=n&255;if((n&255|0)==0){a[9660979]=w&125|2;return}else{a[9660979]=(w&125|n&128)&255;return}}function fTj(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;d=f&255;do{if((g|0)==0){k=c[j+3148>>2]|0;if((k|0)==0){l=0;m=i;n=d;o=j;break}h=gj[k&4095](e)|0;l=h;m=c[2440596]|0;n=a[9660968]|0;o=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=d;o=j}}while(0);a[9660972]=l;j=m-1|0;c[2440596]=j;a[9660968]=n+1&255;n=c[2415242]|0;m=n&65535;d=c[o+68+((n>>>8&255)<<2)>>2]|0;do{if((d|0)==0){i=c[o+3148>>2]|0;if((i|0)==0){p=0;q=j;r=l;break}f=gj[i&4095](m)|0;p=f;q=c[2440596]|0;r=a[9660972]|0}else{p=a[d+(n&255)|0]|0;q=j;r=l}}while(0);a[9660973]=p;l=q-1|0;c[2440596]=l;q=a[9660978]|0;j=(q&255)+(r&255)|0;if((j|0)>255){r=p&255;p=(j&255|r<<8)&65535;j=c[2443776]|0;do{if((c[j+68+(r<<2)>>2]|0)==0){n=c[j+3148>>2]|0;if((n|0)==0){s=l;t=q;break}gj[n&4095](p)|0;s=c[2440596]|0;t=a[9660978]|0}else{s=l;t=q}}while(0);p=s-1|0;c[2440596]=p;u=t;v=p}else{u=q;v=l}b[4830486]=(b[4830486]|0)+(u&255)&65535;u=c[2415243]|0;l=c[2443776]|0;q=c[l+68+((u>>>8&255)<<2)>>2]|0;if((q|0)!=0){w=a[q+(u&255)|0]|0;x=v;y=x-1|0;c[2440596]=y;z=a[9660976]|0;A=z|w;a[9660976]=A;B=A<<24>>24==0;C=a[9660979]|0;D=C&125;E=A&-128;F=B?2:E;G=F|D;a[9660979]=G;return}q=c[l+3156>>2]|0;if((q|0)==0){w=0;x=v;y=x-1|0;c[2440596]=y;z=a[9660976]|0;A=z|w;a[9660976]=A;B=A<<24>>24==0;C=a[9660979]|0;D=C&125;E=A&-128;F=B?2:E;G=F|D;a[9660979]=G;return}v=gj[q&4095](u&65535)|0;w=v;x=c[2440596]|0;y=x-1|0;c[2440596]=y;z=a[9660976]|0;A=z|w;a[9660976]=A;B=A<<24>>24==0;C=a[9660979]|0;D=C&125;E=A&-128;F=B?2:E;G=F|D;a[9660979]=G;return}function fTk(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;d=f&255;do{if((g|0)==0){k=c[j+3148>>2]|0;if((k|0)==0){l=0;m=i;n=d;o=j;break}h=gj[k&4095](e)|0;l=h;m=c[2440596]|0;n=a[9660968]|0;o=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=d;o=j}}while(0);a[9660972]=l;j=m-1|0;c[2440596]=j;a[9660968]=n+1&255;n=c[2415242]|0;m=n&65535;d=c[o+68+((n>>>8&255)<<2)>>2]|0;do{if((d|0)==0){i=c[o+3148>>2]|0;if((i|0)==0){p=0;q=j;r=l;break}f=gj[i&4095](m)|0;p=f;q=c[2440596]|0;r=a[9660972]|0}else{p=a[d+(n&255)|0]|0;q=j;r=l}}while(0);a[9660973]=p;l=q-1|0;c[2440596]=l;q=a[9660978]|0;j=(q&255)+(r&255)|0;if((j|0)>255){r=p&255;p=(j&255|r<<8)&65535;j=c[2443776]|0;do{if((c[j+68+(r<<2)>>2]|0)==0){n=c[j+3148>>2]|0;if((n|0)==0){s=l;t=q;break}gj[n&4095](p)|0;s=c[2440596]|0;t=a[9660978]|0}else{s=l;t=q}}while(0);p=s-1|0;c[2440596]=p;u=t;v=p}else{u=q;v=l}b[4830486]=(b[4830486]|0)+(u&255)&65535;u=c[2415243]|0;l=c[2443776]|0;q=c[l+68+((u>>>8&255)<<2)>>2]|0;if((q|0)!=0){w=a[q+(u&255)|0]|0;x=v;y=x-1|0;c[2440596]=y;z=a[9660976]|0;A=z&w;a[9660976]=A;B=A<<24>>24==0;C=a[9660979]|0;D=C&125;E=A&-128;F=B?2:E;G=F|D;a[9660979]=G;return}q=c[l+3156>>2]|0;if((q|0)==0){w=0;x=v;y=x-1|0;c[2440596]=y;z=a[9660976]|0;A=z&w;a[9660976]=A;B=A<<24>>24==0;C=a[9660979]|0;D=C&125;E=A&-128;F=B?2:E;G=F|D;a[9660979]=G;return}v=gj[q&4095](u&65535)|0;w=v;x=c[2440596]|0;y=x-1|0;c[2440596]=y;z=a[9660976]|0;A=z&w;a[9660976]=A;B=A<<24>>24==0;C=a[9660979]|0;D=C&125;E=A&-128;F=B?2:E;G=F|D;a[9660979]=G;return}function fTl(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;d=f&255;do{if((g|0)==0){k=c[j+3148>>2]|0;if((k|0)==0){l=0;m=i;n=d;o=j;break}h=gj[k&4095](e)|0;l=h;m=c[2440596]|0;n=a[9660968]|0;o=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=d;o=j}}while(0);a[9660972]=l;j=m-1|0;c[2440596]=j;a[9660968]=n+1&255;n=c[2415242]|0;m=n&65535;d=c[o+68+((n>>>8&255)<<2)>>2]|0;do{if((d|0)==0){i=c[o+3148>>2]|0;if((i|0)==0){p=0;q=j;r=l;break}f=gj[i&4095](m)|0;p=f;q=c[2440596]|0;r=a[9660972]|0}else{p=a[d+(n&255)|0]|0;q=j;r=l}}while(0);a[9660973]=p;l=q-1|0;c[2440596]=l;q=a[9660978]|0;j=(q&255)+(r&255)|0;if((j|0)>255){r=p&255;p=(j&255|r<<8)&65535;j=c[2443776]|0;do{if((c[j+68+(r<<2)>>2]|0)==0){n=c[j+3148>>2]|0;if((n|0)==0){s=l;t=q;break}gj[n&4095](p)|0;s=c[2440596]|0;t=a[9660978]|0}else{s=l;t=q}}while(0);p=s-1|0;c[2440596]=p;u=t;v=p}else{u=q;v=l}b[4830486]=(b[4830486]|0)+(u&255)&65535;u=c[2415243]|0;l=u&65535;q=c[2443776]|0;p=c[q+68+((u>>>8&255)<<2)>>2]|0;do{if((p|0)==0){t=c[q+3156>>2]|0;if((t|0)==0){w=0;x=v;break}s=gj[t&4095](l)|0;w=s;x=c[2440596]|0}else{w=a[p+(u&255)|0]|0;x=v}}while(0);c[2440596]=x-1;x=a[9660976]|0;v=x^w;a[9660976]=v;a[9660979]=(x<<24>>24==w<<24>>24?2:v&-128)|a[9660979]&125;return}function fTm(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;d=f&255;do{if((g|0)==0){k=c[j+3148>>2]|0;if((k|0)==0){l=0;m=i;n=d;o=j;break}h=gj[k&4095](e)|0;l=h;m=c[2440596]|0;n=a[9660968]|0;o=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=d;o=j}}while(0);a[9660972]=l;j=m-1|0;c[2440596]=j;a[9660968]=n+1&255;n=c[2415242]|0;m=n&65535;d=c[o+68+((n>>>8&255)<<2)>>2]|0;do{if((d|0)==0){i=c[o+3148>>2]|0;if((i|0)==0){p=0;q=j;r=l;break}f=gj[i&4095](m)|0;p=f;q=c[2440596]|0;r=a[9660972]|0}else{p=a[d+(n&255)|0]|0;q=j;r=l}}while(0);a[9660973]=p;l=q-1|0;c[2440596]=l;q=a[9660978]|0;j=(q&255)+(r&255)|0;if((j|0)>255){r=p&255;p=(j&255|r<<8)&65535;j=c[2443776]|0;do{if((c[j+68+(r<<2)>>2]|0)==0){n=c[j+3148>>2]|0;if((n|0)==0){s=l;t=q;break}gj[n&4095](p)|0;s=c[2440596]|0;t=a[9660978]|0}else{s=l;t=q}}while(0);p=s-1|0;c[2440596]=p;u=t;v=p}else{u=q;v=l}b[4830486]=(b[4830486]|0)+(u&255)&65535;u=c[2415243]|0;l=u&65535;q=c[2443776]|0;p=c[q+68+((u>>>8&255)<<2)>>2]|0;do{if((p|0)==0){t=c[q+3156>>2]|0;if((t|0)==0){w=0;x=v;break}s=gj[t&4095](l)|0;w=s;x=c[2440596]|0}else{w=a[p+(u&255)|0]|0;x=v}}while(0);v=w&255;c[2440596]=x-1;x=a[9660979]|0;u=x&255;p=u&1;l=a[9660976]|0;q=l&255;if((u&8|0)==0){u=q+v+p|0;s=x&-66;t=((((l^w)&128^128)&(u^q)|0)==0?s:s|64)|(u&65280|0)!=0;a[9660979]=t;a[9660976]=u&255;if((u&255|0)==0){a[9660979]=t&125|2;return}else{a[9660979]=(t&125|u&128)&255;return}}u=p+(v&15)+(q&15)|0;p=(q&240)+(v&240)|0;v=x&60;x=(u+p&255|0)==0?v|2:v;a[9660979]=x;if((u|0)>9){y=u+6|0;z=p+16|0}else{y=u;z=p}if((z&128|0)==0){A=x}else{p=x|-128;a[9660979]=p;A=p}if((((l^w)&128^128)&(z^q)|0)==0){B=A}else{q=A|64;a[9660979]=q;B=q}q=(z|0)>144?z+96|0:z;if((q&65280|0)!=0){a[9660979]=B|1}a[9660976]=(q&240|y&15)&255;return}function fTn(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;d=a[9660976]|0;e=b[4830480]|0;b[4830480]=e+1&65535;f=e&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](e)|0;j=l;k=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=g}}while(0);a[9660968]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;g=c[2415242]|0;f=g&65535;h=c[k+68+((g>>>8&255)<<2)>>2]|0;e=g&255;do{if((h|0)==0){l=c[k+3148>>2]|0;if((l|0)==0){m=0;n=j;o=e;p=k;break}i=gj[l&4095](f)|0;m=i;n=c[2440596]|0;o=a[9660968]|0;p=c[2443776]|0}else{m=a[h+(g&255)|0]|0;n=j;o=e;p=k}}while(0);a[9660972]=m;k=n-1|0;c[2440596]=k;a[9660968]=o+1&255;o=c[2415242]|0;n=o&65535;e=c[p+68+((o>>>8&255)<<2)>>2]|0;do{if((e|0)==0){j=c[p+3148>>2]|0;if((j|0)==0){q=0;r=k;s=m;t=p;break}g=gj[j&4095](n)|0;q=g;r=c[2440596]|0;s=a[9660972]|0;t=c[2443776]|0}else{q=a[e+(o&255)|0]|0;r=k;s=m;t=p}}while(0);a[9660973]=q;p=r-1|0;c[2440596]=p;r=(q&255)<<8;q=a[9660978]|0;m=(q&255)+(s&255)&255|r;do{if((c[t+68+((r&65535)>>>8<<2)>>2]|0)==0){s=c[t+3148>>2]|0;if((s|0)==0){u=p;v=q;w=t;break}gj[s&4095](m)|0;u=c[2440596]|0;v=a[9660978]|0;w=c[2443776]|0}else{u=p;v=q;w=t}}while(0);t=u-1|0;c[2440596]=t;b[4830486]=(b[4830486]|0)+(v&255)&65535;v=c[2415243]|0;u=c[w+68+((v>>>8&255|256)<<2)>>2]|0;if((u|0)!=0){a[u+(v&255)|0]=d;x=t;y=x-1|0;c[2440596]=y;return}u=c[w+3160>>2]|0;if((u|0)==0){x=t;y=x-1|0;c[2440596]=y;return}gg[u&4095](v&65535,d);x=c[2440596]|0;y=x-1|0;c[2440596]=y;return}function fTo(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;d=f&255;do{if((g|0)==0){k=c[j+3148>>2]|0;if((k|0)==0){l=0;m=i;n=d;o=j;break}h=gj[k&4095](e)|0;l=h;m=c[2440596]|0;n=a[9660968]|0;o=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=d;o=j}}while(0);a[9660972]=l;j=m-1|0;c[2440596]=j;a[9660968]=n+1&255;n=c[2415242]|0;m=n&65535;d=c[o+68+((n>>>8&255)<<2)>>2]|0;do{if((d|0)==0){i=c[o+3148>>2]|0;if((i|0)==0){p=0;q=j;r=l;break}f=gj[i&4095](m)|0;p=f;q=c[2440596]|0;r=a[9660972]|0}else{p=a[d+(n&255)|0]|0;q=j;r=l}}while(0);a[9660973]=p;l=q-1|0;c[2440596]=l;q=a[9660978]|0;j=(q&255)+(r&255)|0;if((j|0)>255){r=p&255;p=(j&255|r<<8)&65535;j=c[2443776]|0;do{if((c[j+68+(r<<2)>>2]|0)==0){n=c[j+3148>>2]|0;if((n|0)==0){s=l;t=q;break}gj[n&4095](p)|0;s=c[2440596]|0;t=a[9660978]|0}else{s=l;t=q}}while(0);p=s-1|0;c[2440596]=p;u=t;v=p}else{u=q;v=l}b[4830486]=(b[4830486]|0)+(u&255)&65535;u=c[2415243]|0;l=c[2443776]|0;q=c[l+68+((u>>>8&255)<<2)>>2]|0;if((q|0)!=0){w=a[q+(u&255)|0]|0;x=v;y=x-1|0;c[2440596]=y;a[9660976]=w;z=w<<24>>24==0;A=a[9660979]|0;B=A&125;C=w&-128;D=z?2:C;E=B|D;a[9660979]=E;return}q=c[l+3156>>2]|0;if((q|0)==0){w=0;x=v;y=x-1|0;c[2440596]=y;a[9660976]=w;z=w<<24>>24==0;A=a[9660979]|0;B=A&125;C=w&-128;D=z?2:C;E=B|D;a[9660979]=E;return}v=gj[q&4095](u&65535)|0;w=v;x=c[2440596]|0;y=x-1|0;c[2440596]=y;a[9660976]=w;z=w<<24>>24==0;A=a[9660979]|0;B=A&125;C=w&-128;D=z?2:C;E=B|D;a[9660979]=E;return}function fTp(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;d=f&255;do{if((g|0)==0){k=c[j+3148>>2]|0;if((k|0)==0){l=0;m=i;n=d;o=j;break}h=gj[k&4095](e)|0;l=h;m=c[2440596]|0;n=a[9660968]|0;o=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=d;o=j}}while(0);a[9660972]=l;j=m-1|0;c[2440596]=j;a[9660968]=n+1&255;n=c[2415242]|0;m=n&65535;d=c[o+68+((n>>>8&255)<<2)>>2]|0;do{if((d|0)==0){i=c[o+3148>>2]|0;if((i|0)==0){p=0;q=j;r=l;break}f=gj[i&4095](m)|0;p=f;q=c[2440596]|0;r=a[9660972]|0}else{p=a[d+(n&255)|0]|0;q=j;r=l}}while(0);a[9660973]=p;l=q-1|0;c[2440596]=l;q=a[9660978]|0;j=(q&255)+(r&255)|0;if((j|0)>255){r=p&255;p=(j&255|r<<8)&65535;j=c[2443776]|0;do{if((c[j+68+(r<<2)>>2]|0)==0){n=c[j+3148>>2]|0;if((n|0)==0){s=l;t=q;break}gj[n&4095](p)|0;s=c[2440596]|0;t=a[9660978]|0}else{s=l;t=q}}while(0);p=s-1|0;c[2440596]=p;u=t;v=p}else{u=q;v=l}b[4830486]=(b[4830486]|0)+(u&255)&65535;u=c[2415243]|0;l=u&65535;q=c[2443776]|0;p=c[q+68+((u>>>8&255)<<2)>>2]|0;do{if((p|0)==0){t=c[q+3156>>2]|0;if((t|0)==0){w=0;x=v;break}s=gj[t&4095](l)|0;w=s;x=c[2440596]|0}else{w=a[p+(u&255)|0]|0;x=v}}while(0);c[2440596]=x-1;x=a[9660979]|0;v=x&-2;a[9660979]=v;u=a[9660976]|0;if((u&255)<(w&255)){y=v}else{v=x|1;a[9660979]=v;y=v}if(u<<24>>24==w<<24>>24){z=y&125|2;a[9660979]=z;return}else{z=y&125|u-w&255&-128;a[9660979]=z;return}}function fTq(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;d=f&255;do{if((g|0)==0){k=c[j+3148>>2]|0;if((k|0)==0){l=0;m=i;n=d;o=j;break}h=gj[k&4095](e)|0;l=h;m=c[2440596]|0;n=a[9660968]|0;o=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=d;o=j}}while(0);a[9660972]=l;j=m-1|0;c[2440596]=j;a[9660968]=n+1&255;n=c[2415242]|0;m=n&65535;d=c[o+68+((n>>>8&255)<<2)>>2]|0;do{if((d|0)==0){i=c[o+3148>>2]|0;if((i|0)==0){p=0;q=j;r=l;break}f=gj[i&4095](m)|0;p=f;q=c[2440596]|0;r=a[9660972]|0}else{p=a[d+(n&255)|0]|0;q=j;r=l}}while(0);a[9660973]=p;l=q-1|0;c[2440596]=l;q=a[9660978]|0;j=(q&255)+(r&255)|0;if((j|0)>255){r=p&255;p=(j&255|r<<8)&65535;j=c[2443776]|0;do{if((c[j+68+(r<<2)>>2]|0)==0){n=c[j+3148>>2]|0;if((n|0)==0){s=l;t=q;break}gj[n&4095](p)|0;s=c[2440596]|0;t=a[9660978]|0}else{s=l;t=q}}while(0);p=s-1|0;c[2440596]=p;u=t;v=p}else{u=q;v=l}b[4830486]=(b[4830486]|0)+(u&255)&65535;u=c[2415243]|0;l=u&65535;q=c[2443776]|0;p=c[q+68+((u>>>8&255)<<2)>>2]|0;do{if((p|0)==0){t=c[q+3156>>2]|0;if((t|0)==0){w=0;x=v;break}s=gj[t&4095](l)|0;w=s;x=c[2440596]|0}else{w=a[p+(u&255)|0]|0;x=v}}while(0);v=w&255;c[2440596]=x-1;x=a[9660979]|0;u=x&255;p=u&1^1;l=a[9660976]|0;q=l&255;s=q-v-p|0;if((u&8|0)!=0){u=(q&15)-(v&15)-p|0;p=(q&240)-(v&240)|0;if((u&16|0)==0){y=u;z=p}else{y=u-6|0;z=p-1|0}p=x&60;u=(((l^w)&128&(s^q)|0)==0?p:p|64)|(s&65280|0)==0;p=(s&255|0)==0?u|2:u;a[9660979]=(s&128|0)==0?p:p|-128;a[9660976]=(((z&256|0)==0?z:z+160|0)&240|y&15)&255;return}y=x&-66;x=(((l^w)&128&(s^q)|0)==0?y:y|64)|(s&65280|0)==0;a[9660979]=x;a[9660976]=s&255;if((s&255|0)==0){a[9660979]=x&125|2;return}else{a[9660979]=(x&125|s&128)&255;return}}function fTr(){b[4830480]=(b[4830480]|0)-1&65535;return}function fTs(){b[4830480]=(b[4830480]|0)-1&65535;return}function fTt(){b[4830480]=(b[4830480]|0)-1&65535;return}function fTu(){b[4830480]=(b[4830480]|0)-1&65535;return}function fTv(){var a=0,d=0,e=0;a=b[4830480]|0;b[4830480]=a+1&65535;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3168>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function fTw(){var d=0,e=0,f=0,g=0,h=0,i=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(e&255)|0]|0}}while(0);c[2440596]=(c[2440596]|0)-1;a[9660977]=i;a[9660979]=a[9660979]&125|(i<<24>>24==0?2:i&-128);return}function fTx(){var a=0,d=0,e=0;a=b[4830480]|0;b[4830480]=a+1&65535;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3168>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function fTy(){var a=0,d=0,e=0;a=b[4830480]|0;b[4830480]=a+1&65535;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3168>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function fTz(){b[4830480]=(b[4830480]|0)-1&65535;return}function fTA(){b[4830480]=(b[4830480]|0)-1&65535;return}function fTB(){b[4830480]=(b[4830480]|0)-1&65535;return}function fTC(){b[4830480]=(b[4830480]|0)-1&65535;return}function fTD(){b[4830480]=(b[4830480]|0)-1&65535;return}function fTE(){b[4830480]=(b[4830480]|0)-1&65535;return}function fTF(){b[4830480]=(b[4830480]|0)-1&65535;return}function fTG(){b[4830480]=(b[4830480]|0)-1&65535;return}function fTH(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=f&255;do{if((c[j+68+((f>>>8&255)<<2)>>2]|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=i;m=g;n=j;break}gj[d&4095](e)|0;l=c[2440596]|0;m=a[9660968]|0;n=c[2443776]|0}else{l=i;m=g;n=j}}while(0);j=l-1|0;c[2440596]=j;a[9660968]=(a[9660977]|0)+m&255;m=c[2415242]|0;l=m&65535;g=c[n+68+((m>>>8&255)<<2)>>2]|0;i=m&255;do{if((g|0)==0){e=c[n+3148>>2]|0;if((e|0)==0){o=0;p=j;q=i;r=n;break}f=gj[e&4095](l)|0;o=f;p=c[2440596]|0;q=a[9660968]|0;r=c[2443776]|0}else{o=a[g+(m&255)|0]|0;p=j;q=i;r=n}}while(0);a[9660972]=o;o=p-1|0;c[2440596]=o;a[9660968]=q+1&255;q=c[2415242]|0;p=q&65535;n=c[r+68+((q>>>8&255)<<2)>>2]|0;do{if((n|0)==0){i=c[r+3148>>2]|0;if((i|0)==0){s=0;t=o;u=r;break}j=gj[i&4095](p)|0;s=j;t=c[2440596]|0;u=c[2443776]|0}else{s=a[n+(q&255)|0]|0;t=o;u=r}}while(0);a[9660973]=s;s=t-1|0;c[2440596]=s;t=c[2415243]|0;r=t&65535;o=c[u+68+((t>>>8&255)<<2)>>2]|0;do{if((o|0)==0){q=c[u+3156>>2]|0;if((q|0)==0){v=0;w=s;x=t;y=u;break}n=gj[q&4095](r)|0;v=n;w=c[2440596]|0;x=c[2415243]|0;y=c[2443776]|0}else{v=a[o+(t&255)|0]|0;w=s;x=t;y=u}}while(0);u=w-1|0;c[2440596]=u;w=x&65535;t=c[y+68+((x>>>8&255|256)<<2)>>2]|0;do{if((t|0)==0){s=c[y+3152>>2]|0;if((s|0)==0){z=u;A=y;break}gg[s&4095](w,v);z=c[2440596]|0;A=c[2443776]|0}else{a[t+(x&255)|0]=v;z=u;A=y}}while(0);y=z-1|0;c[2440596]=y;z=a[9660979]&124;u=v<<1;x=a[9660976]|u;a[9660976]=x;a[9660979]=z|(v&255)>>>7|(x<<24>>24==0?2:x&-128);x=c[2415243]|0;v=c[A+68+((x>>>8&255|256)<<2)>>2]|0;if((v|0)!=0){a[v+(x&255)|0]=u;B=y;C=B-1|0;c[2440596]=C;return}v=c[A+3152>>2]|0;if((v|0)==0){B=y;C=B-1|0;c[2440596]=C;return}gg[v&4095](x&65535,u);B=c[2440596]|0;C=B-1|0;c[2440596]=C;return}function fTI(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=f&255;do{if((c[j+68+((f>>>8&255)<<2)>>2]|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=i;m=g;n=j;break}gj[d&4095](e)|0;l=c[2440596]|0;m=a[9660968]|0;n=c[2443776]|0}else{l=i;m=g;n=j}}while(0);j=l-1|0;c[2440596]=j;a[9660968]=(a[9660977]|0)+m&255;m=c[2415242]|0;l=m&65535;g=c[n+68+((m>>>8&255)<<2)>>2]|0;i=m&255;do{if((g|0)==0){e=c[n+3148>>2]|0;if((e|0)==0){o=0;p=j;q=i;r=n;break}f=gj[e&4095](l)|0;o=f;p=c[2440596]|0;q=a[9660968]|0;r=c[2443776]|0}else{o=a[g+(m&255)|0]|0;p=j;q=i;r=n}}while(0);a[9660972]=o;o=p-1|0;c[2440596]=o;a[9660968]=q+1&255;q=c[2415242]|0;p=q&65535;n=c[r+68+((q>>>8&255)<<2)>>2]|0;do{if((n|0)==0){i=c[r+3148>>2]|0;if((i|0)==0){s=0;t=o;u=r;break}j=gj[i&4095](p)|0;s=j;t=c[2440596]|0;u=c[2443776]|0}else{s=a[n+(q&255)|0]|0;t=o;u=r}}while(0);a[9660973]=s;s=t-1|0;c[2440596]=s;t=c[2415243]|0;r=t&65535;o=c[u+68+((t>>>8&255)<<2)>>2]|0;do{if((o|0)==0){q=c[u+3156>>2]|0;if((q|0)==0){v=0;w=s;x=t;y=u;break}n=gj[q&4095](r)|0;v=n;w=c[2440596]|0;x=c[2415243]|0;y=c[2443776]|0}else{v=a[o+(t&255)|0]|0;w=s;x=t;y=u}}while(0);u=w-1|0;c[2440596]=u;w=x&65535;t=c[y+68+((x>>>8&255|256)<<2)>>2]|0;do{if((t|0)==0){s=c[y+3152>>2]|0;if((s|0)==0){z=u;A=y;break}gg[s&4095](w,v);z=c[2440596]|0;A=c[2443776]|0}else{a[t+(x&255)|0]=v;z=u;A=y}}while(0);y=z-1|0;c[2440596]=y;z=a[9660979]|0;u=z&1|v<<1;x=u&a[9660976];a[9660976]=x;a[9660979]=z&124|(v&255)>>>7|(x<<24>>24==0?2:x&-128);x=c[2415243]|0;v=c[A+68+((x>>>8&255|256)<<2)>>2]|0;if((v|0)!=0){a[v+(x&255)|0]=u;B=y;C=B-1|0;c[2440596]=C;return}v=c[A+3152>>2]|0;if((v|0)==0){B=y;C=B-1|0;c[2440596]=C;return}gg[v&4095](x&65535,u);B=c[2440596]|0;C=B-1|0;c[2440596]=C;return}function fTJ(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;e=b[4830480]|0;b[4830480]=e+1&65535;f=e&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](e)|0;j=l;k=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=g}}while(0);a[9660968]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;g=c[2415242]|0;f=g&65535;h=g&255;do{if((c[k+68+((g>>>8&255)<<2)>>2]|0)==0){e=c[k+3148>>2]|0;if((e|0)==0){m=j;n=h;o=k;break}gj[e&4095](f)|0;m=c[2440596]|0;n=a[9660968]|0;o=c[2443776]|0}else{m=j;n=h;o=k}}while(0);k=m-1|0;c[2440596]=k;a[9660968]=(a[9660977]|0)+n&255;n=c[2415242]|0;m=n&65535;h=c[o+68+((n>>>8&255)<<2)>>2]|0;j=n&255;do{if((h|0)==0){f=c[o+3148>>2]|0;if((f|0)==0){p=0;q=k;r=j;s=o;break}g=gj[f&4095](m)|0;p=g;q=c[2440596]|0;r=a[9660968]|0;s=c[2443776]|0}else{p=a[h+(n&255)|0]|0;q=k;r=j;s=o}}while(0);a[9660972]=p;p=q-1|0;c[2440596]=p;a[9660968]=r+1&255;r=c[2415242]|0;q=r&65535;o=c[s+68+((r>>>8&255)<<2)>>2]|0;do{if((o|0)==0){j=c[s+3148>>2]|0;if((j|0)==0){t=0;u=p;v=s;break}k=gj[j&4095](q)|0;t=k;u=c[2440596]|0;v=c[2443776]|0}else{t=a[o+(r&255)|0]|0;u=p;v=s}}while(0);a[9660973]=t;t=u-1|0;c[2440596]=t;u=c[2415243]|0;s=u&65535;p=c[v+68+((u>>>8&255)<<2)>>2]|0;do{if((p|0)==0){r=c[v+3156>>2]|0;if((r|0)==0){w=0;x=t;y=u;z=v;break}o=gj[r&4095](s)|0;w=o;x=c[2440596]|0;y=c[2415243]|0;z=c[2443776]|0}else{w=a[p+(u&255)|0]|0;x=t;y=u;z=v}}while(0);v=x-1|0;c[2440596]=v;x=y&65535;u=c[z+68+((y>>>8&255|256)<<2)>>2]|0;do{if((u|0)==0){t=c[z+3152>>2]|0;if((t|0)==0){A=v;break}gg[t&4095](x,w);A=c[2440596]|0}else{a[u+(y&255)|0]=w;A=v}}while(0);v=A-1|0;c[2440596]=v;A=a[9660979]&-2|w&1;a[9660979]=A;y=(w&255)>>>1;w=d[9660976]|0;u=w^y;a[9660976]=u&255;if((w|0)==(y|0)){B=A&125|2}else{B=(A&125|u&128)&255}a[9660979]=B;B=c[2415243]|0;u=y&255;y=c[2443776]|0;A=c[y+68+((B>>>8&255|256)<<2)>>2]|0;if((A|0)!=0){a[A+(B&255)|0]=u;C=v;D=C-1|0;c[2440596]=D;return}A=c[y+3152>>2]|0;if((A|0)==0){C=v;D=C-1|0;c[2440596]=D;return}gg[A&4095](B&65535,u);C=c[2440596]|0;D=C-1|0;c[2440596]=D;return}function fTK(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;e=b[4830480]|0;b[4830480]=e+1&65535;f=e&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](e)|0;j=l;k=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=g}}while(0);a[9660968]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;g=c[2415242]|0;f=g&65535;h=g&255;do{if((c[k+68+((g>>>8&255)<<2)>>2]|0)==0){e=c[k+3148>>2]|0;if((e|0)==0){m=j;n=h;o=k;break}gj[e&4095](f)|0;m=c[2440596]|0;n=a[9660968]|0;o=c[2443776]|0}else{m=j;n=h;o=k}}while(0);k=m-1|0;c[2440596]=k;a[9660968]=(a[9660977]|0)+n&255;n=c[2415242]|0;m=n&65535;h=c[o+68+((n>>>8&255)<<2)>>2]|0;j=n&255;do{if((h|0)==0){f=c[o+3148>>2]|0;if((f|0)==0){p=0;q=k;r=j;s=o;break}g=gj[f&4095](m)|0;p=g;q=c[2440596]|0;r=a[9660968]|0;s=c[2443776]|0}else{p=a[h+(n&255)|0]|0;q=k;r=j;s=o}}while(0);a[9660972]=p;p=q-1|0;c[2440596]=p;a[9660968]=r+1&255;r=c[2415242]|0;q=r&65535;o=c[s+68+((r>>>8&255)<<2)>>2]|0;do{if((o|0)==0){j=c[s+3148>>2]|0;if((j|0)==0){t=0;u=p;v=s;break}k=gj[j&4095](q)|0;t=k;u=c[2440596]|0;v=c[2443776]|0}else{t=a[o+(r&255)|0]|0;u=p;v=s}}while(0);a[9660973]=t;t=u-1|0;c[2440596]=t;u=c[2415243]|0;s=u&65535;p=c[v+68+((u>>>8&255)<<2)>>2]|0;do{if((p|0)==0){r=c[v+3156>>2]|0;if((r|0)==0){w=0;x=t;y=u;z=v;break}o=gj[r&4095](s)|0;w=o;x=c[2440596]|0;y=c[2415243]|0;z=c[2443776]|0}else{w=a[p+(u&255)|0]|0;x=t;y=u;z=v}}while(0);v=w&255;u=x-1|0;c[2440596]=u;x=y&65535;t=c[z+68+((y>>>8&255|256)<<2)>>2]|0;do{if((t|0)==0){p=c[z+3152>>2]|0;if((p|0)==0){A=u;break}gg[p&4095](x,w);A=c[2440596]|0}else{a[t+(y&255)|0]=w;A=u}}while(0);u=A-1|0;c[2440596]=u;A=a[9660979]|0;y=A&-2|w&1;a[9660979]=y;w=((A&255)<<8|v)>>>1;v=y&255;y=v&1;do{if((v&8|0)==0){t=d[9660976]|0;x=(w&255)+y+t|0;z=A&-66;p=(((w^128^t)&128&(x^t)|0)==0?z:z|64)|(x&65280|0)!=0;a[9660979]=p;a[9660976]=x&255;if((x&255|0)==0){a[9660979]=p&125|2;break}else{a[9660979]=(p&125|x&128)&255;break}}else{x=d[9660976]|0;p=(w&15)+y+(x&15)|0;z=(x&240)+(w&240)|0;t=A&60;s=(p+z&255|0)==0?t|2:t;a[9660979]=s;if((p|0)>9){B=p+6|0;C=z+16|0}else{B=p;C=z}if((C&128|0)==0){D=s}else{z=s|-128;a[9660979]=z;D=z}if(((w^128^x)&128&(C^x)|0)==0){E=D}else{x=D|64;a[9660979]=x;E=x}x=(C|0)>144?C+96|0:C;if((x&65280|0)!=0){a[9660979]=E|1}a[9660976]=(x&240|B&15)&255}}while(0);B=c[2415243]|0;E=w&255;w=c[2443776]|0;C=c[w+68+((B>>>8&255|256)<<2)>>2]|0;if((C|0)!=0){a[C+(B&255)|0]=E;F=u;G=F-1|0;c[2440596]=G;return}C=c[w+3152>>2]|0;if((C|0)==0){F=u;G=F-1|0;c[2440596]=G;return}gg[C&4095](B&65535,E);F=c[2440596]|0;G=F-1|0;c[2440596]=G;return}function fTL(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=a[9660977]&a[9660976];e=b[4830480]|0;b[4830480]=e+1&65535;f=e&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](e)|0;j=l;k=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=g}}while(0);a[9660968]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;g=c[2415242]|0;f=g&65535;h=g&255;do{if((c[k+68+((g>>>8&255)<<2)>>2]|0)==0){e=c[k+3148>>2]|0;if((e|0)==0){m=j;n=h;o=k;break}gj[e&4095](f)|0;m=c[2440596]|0;n=a[9660968]|0;o=c[2443776]|0}else{m=j;n=h;o=k}}while(0);k=m-1|0;c[2440596]=k;a[9660968]=(a[9660977]|0)+n&255;n=c[2415242]|0;m=n&65535;h=c[o+68+((n>>>8&255)<<2)>>2]|0;j=n&255;do{if((h|0)==0){f=c[o+3148>>2]|0;if((f|0)==0){p=0;q=k;r=j;s=o;break}g=gj[f&4095](m)|0;p=g;q=c[2440596]|0;r=a[9660968]|0;s=c[2443776]|0}else{p=a[h+(n&255)|0]|0;q=k;r=j;s=o}}while(0);a[9660972]=p;p=q-1|0;c[2440596]=p;a[9660968]=r+1&255;r=c[2415242]|0;q=r&65535;o=c[s+68+((r>>>8&255)<<2)>>2]|0;do{if((o|0)==0){j=c[s+3148>>2]|0;if((j|0)==0){t=0;u=p;v=s;break}k=gj[j&4095](q)|0;t=k;u=c[2440596]|0;v=c[2443776]|0}else{t=a[o+(r&255)|0]|0;u=p;v=s}}while(0);a[9660973]=t;t=u-1|0;c[2440596]=t;u=c[2415243]|0;s=c[v+68+((u>>>8&255|256)<<2)>>2]|0;if((s|0)!=0){a[s+(u&255)|0]=d;w=t;x=w-1|0;c[2440596]=x;return}s=c[v+3160>>2]|0;if((s|0)==0){w=t;x=w-1|0;c[2440596]=x;return}gg[s&4095](u&65535,d);w=c[2440596]|0;x=w-1|0;c[2440596]=x;return}function fTM(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=f&255;do{if((c[j+68+((f>>>8&255)<<2)>>2]|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=i;m=g;n=j;break}gj[d&4095](e)|0;l=c[2440596]|0;m=a[9660968]|0;n=c[2443776]|0}else{l=i;m=g;n=j}}while(0);j=l-1|0;c[2440596]=j;a[9660968]=(a[9660977]|0)+m&255;m=c[2415242]|0;l=m&65535;g=c[n+68+((m>>>8&255)<<2)>>2]|0;i=m&255;do{if((g|0)==0){e=c[n+3148>>2]|0;if((e|0)==0){o=0;p=j;q=i;r=n;break}f=gj[e&4095](l)|0;o=f;p=c[2440596]|0;q=a[9660968]|0;r=c[2443776]|0}else{o=a[g+(m&255)|0]|0;p=j;q=i;r=n}}while(0);a[9660972]=o;o=p-1|0;c[2440596]=o;a[9660968]=q+1&255;q=c[2415242]|0;p=q&65535;n=c[r+68+((q>>>8&255)<<2)>>2]|0;do{if((n|0)==0){i=c[r+3148>>2]|0;if((i|0)==0){s=0;t=o;u=r;break}j=gj[i&4095](p)|0;s=j;t=c[2440596]|0;u=c[2443776]|0}else{s=a[n+(q&255)|0]|0;t=o;u=r}}while(0);a[9660973]=s;s=t-1|0;c[2440596]=s;t=c[2415243]|0;r=c[u+68+((t>>>8&255)<<2)>>2]|0;if((r|0)!=0){v=a[r+(t&255)|0]|0;w=s;x=w-1|0;c[2440596]=x;a[9660977]=v;a[9660976]=v;y=v<<24>>24==0;z=a[9660979]|0;A=z&125;B=v&-128;C=y?2:B;D=A|C;a[9660979]=D;return}r=c[u+3156>>2]|0;if((r|0)==0){v=0;w=s;x=w-1|0;c[2440596]=x;a[9660977]=v;a[9660976]=v;y=v<<24>>24==0;z=a[9660979]|0;A=z&125;B=v&-128;C=y?2:B;D=A|C;a[9660979]=D;return}s=gj[r&4095](t&65535)|0;v=s;w=c[2440596]|0;x=w-1|0;c[2440596]=x;a[9660977]=v;a[9660976]=v;y=v<<24>>24==0;z=a[9660979]|0;A=z&125;B=v&-128;C=y?2:B;D=A|C;a[9660979]=D;return}function fTN(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=f&255;do{if((c[j+68+((f>>>8&255)<<2)>>2]|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=i;m=g;n=j;break}gj[d&4095](e)|0;l=c[2440596]|0;m=a[9660968]|0;n=c[2443776]|0}else{l=i;m=g;n=j}}while(0);j=l-1|0;c[2440596]=j;a[9660968]=(a[9660977]|0)+m&255;m=c[2415242]|0;l=m&65535;g=c[n+68+((m>>>8&255)<<2)>>2]|0;i=m&255;do{if((g|0)==0){e=c[n+3148>>2]|0;if((e|0)==0){o=0;p=j;q=i;r=n;break}f=gj[e&4095](l)|0;o=f;p=c[2440596]|0;q=a[9660968]|0;r=c[2443776]|0}else{o=a[g+(m&255)|0]|0;p=j;q=i;r=n}}while(0);a[9660972]=o;o=p-1|0;c[2440596]=o;a[9660968]=q+1&255;q=c[2415242]|0;p=q&65535;n=c[r+68+((q>>>8&255)<<2)>>2]|0;do{if((n|0)==0){i=c[r+3148>>2]|0;if((i|0)==0){s=0;t=o;u=r;break}j=gj[i&4095](p)|0;s=j;t=c[2440596]|0;u=c[2443776]|0}else{s=a[n+(q&255)|0]|0;t=o;u=r}}while(0);a[9660973]=s;s=t-1|0;c[2440596]=s;t=c[2415243]|0;r=t&65535;o=c[u+68+((t>>>8&255)<<2)>>2]|0;do{if((o|0)==0){q=c[u+3156>>2]|0;if((q|0)==0){v=0;w=s;x=t;y=u;break}n=gj[q&4095](r)|0;v=n;w=c[2440596]|0;x=c[2415243]|0;y=c[2443776]|0}else{v=a[o+(t&255)|0]|0;w=s;x=t;y=u}}while(0);u=w-1|0;c[2440596]=u;w=x&65535;t=c[y+68+((x>>>8&255|256)<<2)>>2]|0;do{if((t|0)==0){s=c[y+3152>>2]|0;if((s|0)==0){z=u;break}gg[s&4095](w,v);z=c[2440596]|0}else{a[t+(x&255)|0]=v;z=u}}while(0);u=z-1|0;c[2440596]=u;z=v-1&255;v=a[9660979]|0;x=v&-2;a[9660979]=x;t=a[9660976]|0;if((t&255)<(z&255)){A=x}else{x=v|1;a[9660979]=x;A=x}if(t<<24>>24==z<<24>>24){B=A&125|2}else{B=A&125|t-z&255&-128}a[9660979]=B;B=c[2415243]|0;t=c[2443776]|0;A=c[t+68+((B>>>8&255|256)<<2)>>2]|0;if((A|0)!=0){a[A+(B&255)|0]=z;C=u;D=C-1|0;c[2440596]=D;return}A=c[t+3152>>2]|0;if((A|0)==0){C=u;D=C-1|0;c[2440596]=D;return}gg[A&4095](B&65535,z);C=c[2440596]|0;D=C-1|0;c[2440596]=D;return}function fTO(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=f&255;do{if((c[j+68+((f>>>8&255)<<2)>>2]|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=i;m=g;n=j;break}gj[d&4095](e)|0;l=c[2440596]|0;m=a[9660968]|0;n=c[2443776]|0}else{l=i;m=g;n=j}}while(0);j=l-1|0;c[2440596]=j;a[9660968]=(a[9660977]|0)+m&255;m=c[2415242]|0;l=m&65535;g=c[n+68+((m>>>8&255)<<2)>>2]|0;i=m&255;do{if((g|0)==0){e=c[n+3148>>2]|0;if((e|0)==0){o=0;p=j;q=i;r=n;break}f=gj[e&4095](l)|0;o=f;p=c[2440596]|0;q=a[9660968]|0;r=c[2443776]|0}else{o=a[g+(m&255)|0]|0;p=j;q=i;r=n}}while(0);a[9660972]=o;o=p-1|0;c[2440596]=o;a[9660968]=q+1&255;q=c[2415242]|0;p=q&65535;n=c[r+68+((q>>>8&255)<<2)>>2]|0;do{if((n|0)==0){i=c[r+3148>>2]|0;if((i|0)==0){s=0;t=o;u=r;break}j=gj[i&4095](p)|0;s=j;t=c[2440596]|0;u=c[2443776]|0}else{s=a[n+(q&255)|0]|0;t=o;u=r}}while(0);a[9660973]=s;s=t-1|0;c[2440596]=s;t=c[2415243]|0;r=t&65535;o=c[u+68+((t>>>8&255)<<2)>>2]|0;do{if((o|0)==0){q=c[u+3156>>2]|0;if((q|0)==0){v=0;w=s;x=t;y=u;break}n=gj[q&4095](r)|0;v=n;w=c[2440596]|0;x=c[2415243]|0;y=c[2443776]|0}else{v=a[o+(t&255)|0]|0;w=s;x=t;y=u}}while(0);u=w-1|0;c[2440596]=u;w=x&65535;t=c[y+68+((x>>>8&255|256)<<2)>>2]|0;do{if((t|0)==0){s=c[y+3152>>2]|0;if((s|0)==0){z=u;break}gg[s&4095](w,v);z=c[2440596]|0}else{a[t+(x&255)|0]=v;z=u}}while(0);u=z-1|0;c[2440596]=u;z=v+1&255;v=z&255;x=a[9660979]|0;t=x&255;w=t&1^1;y=a[9660976]|0;s=y&255;o=s-v-w|0;do{if((t&8|0)==0){r=x&-66;n=(((y^z)&128&(o^s)|0)==0?r:r|64)|(o&65280|0)==0;a[9660979]=n;a[9660976]=o&255;if((o&255|0)==0){a[9660979]=n&125|2;break}else{a[9660979]=(n&125|o&128)&255;break}}else{n=(s&15)-(v&15)-w|0;r=(s&240)-(v&240)|0;if((n&16|0)==0){A=n;B=r}else{A=n-6|0;B=r-1|0}r=x&60;n=(((y^z)&128&(o^s)|0)==0?r:r|64)|(o&65280|0)==0;r=(o&255|0)==0?n|2:n;a[9660979]=(o&128|0)==0?r:r|-128;a[9660976]=(((B&256|0)==0?B:B+160|0)&240|A&15)&255}}while(0);A=c[2415243]|0;B=c[2443776]|0;o=c[B+68+((A>>>8&255|256)<<2)>>2]|0;if((o|0)!=0){a[o+(A&255)|0]=z;C=u;D=C-1|0;c[2440596]=D;return}o=c[B+3152>>2]|0;if((o|0)==0){C=u;D=C-1|0;c[2440596]=D;return}gg[o&4095](A&65535,z);C=c[2440596]|0;D=C-1|0;c[2440596]=D;return}function fTP(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;d=f&255;do{if((g|0)==0){k=c[j+3148>>2]|0;if((k|0)==0){l=0;m=i;n=d;o=j;break}h=gj[k&4095](e)|0;l=h;m=c[2440596]|0;n=a[9660968]|0;o=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=d;o=j}}while(0);a[9660972]=l;j=m-1|0;c[2440596]=j;a[9660968]=n+1&255;n=c[2415242]|0;m=n&65535;d=c[o+68+((n>>>8&255)<<2)>>2]|0;do{if((d|0)==0){i=c[o+3148>>2]|0;if((i|0)==0){p=0;q=j;r=l;s=o;break}f=gj[i&4095](m)|0;p=f;q=c[2440596]|0;r=a[9660972]|0;s=c[2443776]|0}else{p=a[d+(n&255)|0]|0;q=j;r=l;s=o}}while(0);a[9660973]=p;o=q-1|0;c[2440596]=o;q=(p&255)<<8;p=a[9660978]|0;l=(p&255)+(r&255)&255|q;do{if((c[s+68+((q&65535)>>>8<<2)>>2]|0)==0){r=c[s+3148>>2]|0;if((r|0)==0){t=o;u=p;v=s;break}gj[r&4095](l)|0;t=c[2440596]|0;u=a[9660978]|0;v=c[2443776]|0}else{t=o;u=p;v=s}}while(0);s=t-1|0;c[2440596]=s;b[4830486]=(b[4830486]|0)+(u&255)&65535;u=c[2415243]|0;t=u&65535;p=c[v+68+((u>>>8&255)<<2)>>2]|0;do{if((p|0)==0){o=c[v+3156>>2]|0;if((o|0)==0){w=0;x=s;y=u;z=v;break}l=gj[o&4095](t)|0;w=l;x=c[2440596]|0;y=c[2415243]|0;z=c[2443776]|0}else{w=a[p+(u&255)|0]|0;x=s;y=u;z=v}}while(0);v=x-1|0;c[2440596]=v;x=y&65535;u=c[z+68+((y>>>8&255|256)<<2)>>2]|0;do{if((u|0)==0){s=c[z+3152>>2]|0;if((s|0)==0){A=v;B=z;break}gg[s&4095](x,w);A=c[2440596]|0;B=c[2443776]|0}else{a[u+(y&255)|0]=w;A=v;B=z}}while(0);z=A-1|0;c[2440596]=z;A=a[9660979]&124;v=w<<1;y=a[9660976]|v;a[9660976]=y;a[9660979]=A|(w&255)>>>7|(y<<24>>24==0?2:y&-128);y=c[2415243]|0;w=c[B+68+((y>>>8&255|256)<<2)>>2]|0;if((w|0)!=0){a[w+(y&255)|0]=v;C=z;D=C-1|0;c[2440596]=D;return}w=c[B+3152>>2]|0;if((w|0)==0){C=z;D=C-1|0;c[2440596]=D;return}gg[w&4095](y&65535,v);C=c[2440596]|0;D=C-1|0;c[2440596]=D;return}function fTQ(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;d=f&255;do{if((g|0)==0){k=c[j+3148>>2]|0;if((k|0)==0){l=0;m=i;n=d;o=j;break}h=gj[k&4095](e)|0;l=h;m=c[2440596]|0;n=a[9660968]|0;o=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=d;o=j}}while(0);a[9660972]=l;j=m-1|0;c[2440596]=j;a[9660968]=n+1&255;n=c[2415242]|0;m=n&65535;d=c[o+68+((n>>>8&255)<<2)>>2]|0;do{if((d|0)==0){i=c[o+3148>>2]|0;if((i|0)==0){p=0;q=j;r=l;s=o;break}f=gj[i&4095](m)|0;p=f;q=c[2440596]|0;r=a[9660972]|0;s=c[2443776]|0}else{p=a[d+(n&255)|0]|0;q=j;r=l;s=o}}while(0);a[9660973]=p;o=q-1|0;c[2440596]=o;q=(p&255)<<8;p=a[9660978]|0;l=(p&255)+(r&255)&255|q;do{if((c[s+68+((q&65535)>>>8<<2)>>2]|0)==0){r=c[s+3148>>2]|0;if((r|0)==0){t=o;u=p;v=s;break}gj[r&4095](l)|0;t=c[2440596]|0;u=a[9660978]|0;v=c[2443776]|0}else{t=o;u=p;v=s}}while(0);s=t-1|0;c[2440596]=s;b[4830486]=(b[4830486]|0)+(u&255)&65535;u=c[2415243]|0;t=u&65535;p=c[v+68+((u>>>8&255)<<2)>>2]|0;do{if((p|0)==0){o=c[v+3156>>2]|0;if((o|0)==0){w=0;x=s;y=u;z=v;break}l=gj[o&4095](t)|0;w=l;x=c[2440596]|0;y=c[2415243]|0;z=c[2443776]|0}else{w=a[p+(u&255)|0]|0;x=s;y=u;z=v}}while(0);v=x-1|0;c[2440596]=v;x=y&65535;u=c[z+68+((y>>>8&255|256)<<2)>>2]|0;do{if((u|0)==0){s=c[z+3152>>2]|0;if((s|0)==0){A=v;B=z;break}gg[s&4095](x,w);A=c[2440596]|0;B=c[2443776]|0}else{a[u+(y&255)|0]=w;A=v;B=z}}while(0);z=A-1|0;c[2440596]=z;A=a[9660979]|0;v=A&1|w<<1;y=v&a[9660976];a[9660976]=y;a[9660979]=A&124|(w&255)>>>7|(y<<24>>24==0?2:y&-128);y=c[2415243]|0;w=c[B+68+((y>>>8&255|256)<<2)>>2]|0;if((w|0)!=0){a[w+(y&255)|0]=v;C=z;D=C-1|0;c[2440596]=D;return}w=c[B+3152>>2]|0;if((w|0)==0){C=z;D=C-1|0;c[2440596]=D;return}gg[w&4095](y&65535,v);C=c[2440596]|0;D=C-1|0;c[2440596]=D;return}function fTR(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;e=b[4830480]|0;b[4830480]=e+1&65535;f=e&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](e)|0;j=l;k=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=g}}while(0);a[9660968]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;g=c[2415242]|0;f=g&65535;h=c[k+68+((g>>>8&255)<<2)>>2]|0;e=g&255;do{if((h|0)==0){l=c[k+3148>>2]|0;if((l|0)==0){m=0;n=j;o=e;p=k;break}i=gj[l&4095](f)|0;m=i;n=c[2440596]|0;o=a[9660968]|0;p=c[2443776]|0}else{m=a[h+(g&255)|0]|0;n=j;o=e;p=k}}while(0);a[9660972]=m;k=n-1|0;c[2440596]=k;a[9660968]=o+1&255;o=c[2415242]|0;n=o&65535;e=c[p+68+((o>>>8&255)<<2)>>2]|0;do{if((e|0)==0){j=c[p+3148>>2]|0;if((j|0)==0){q=0;r=k;s=m;t=p;break}g=gj[j&4095](n)|0;q=g;r=c[2440596]|0;s=a[9660972]|0;t=c[2443776]|0}else{q=a[e+(o&255)|0]|0;r=k;s=m;t=p}}while(0);a[9660973]=q;p=r-1|0;c[2440596]=p;r=(q&255)<<8;q=a[9660978]|0;m=(q&255)+(s&255)&255|r;do{if((c[t+68+((r&65535)>>>8<<2)>>2]|0)==0){s=c[t+3148>>2]|0;if((s|0)==0){u=p;v=q;w=t;break}gj[s&4095](m)|0;u=c[2440596]|0;v=a[9660978]|0;w=c[2443776]|0}else{u=p;v=q;w=t}}while(0);t=u-1|0;c[2440596]=t;b[4830486]=(b[4830486]|0)+(v&255)&65535;v=c[2415243]|0;u=v&65535;q=c[w+68+((v>>>8&255)<<2)>>2]|0;do{if((q|0)==0){p=c[w+3156>>2]|0;if((p|0)==0){x=0;y=t;z=v;A=w;break}m=gj[p&4095](u)|0;x=m;y=c[2440596]|0;z=c[2415243]|0;A=c[2443776]|0}else{x=a[q+(v&255)|0]|0;y=t;z=v;A=w}}while(0);w=y-1|0;c[2440596]=w;y=z&65535;v=c[A+68+((z>>>8&255|256)<<2)>>2]|0;do{if((v|0)==0){t=c[A+3152>>2]|0;if((t|0)==0){B=w;break}gg[t&4095](y,x);B=c[2440596]|0}else{a[v+(z&255)|0]=x;B=w}}while(0);w=B-1|0;c[2440596]=w;B=a[9660979]&-2|x&1;a[9660979]=B;z=(x&255)>>>1;x=d[9660976]|0;v=x^z;a[9660976]=v&255;if((x|0)==(z|0)){C=B&125|2}else{C=(B&125|v&128)&255}a[9660979]=C;C=c[2415243]|0;v=z&255;z=c[2443776]|0;B=c[z+68+((C>>>8&255|256)<<2)>>2]|0;if((B|0)!=0){a[B+(C&255)|0]=v;D=w;E=D-1|0;c[2440596]=E;return}B=c[z+3152>>2]|0;if((B|0)==0){D=w;E=D-1|0;c[2440596]=E;return}gg[B&4095](C&65535,v);D=c[2440596]|0;E=D-1|0;c[2440596]=E;return}function fTS(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;e=b[4830480]|0;b[4830480]=e+1&65535;f=e&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](e)|0;j=l;k=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=g}}while(0);a[9660968]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;g=c[2415242]|0;f=g&65535;h=c[k+68+((g>>>8&255)<<2)>>2]|0;e=g&255;do{if((h|0)==0){l=c[k+3148>>2]|0;if((l|0)==0){m=0;n=j;o=e;p=k;break}i=gj[l&4095](f)|0;m=i;n=c[2440596]|0;o=a[9660968]|0;p=c[2443776]|0}else{m=a[h+(g&255)|0]|0;n=j;o=e;p=k}}while(0);a[9660972]=m;k=n-1|0;c[2440596]=k;a[9660968]=o+1&255;o=c[2415242]|0;n=o&65535;e=c[p+68+((o>>>8&255)<<2)>>2]|0;do{if((e|0)==0){j=c[p+3148>>2]|0;if((j|0)==0){q=0;r=k;s=m;t=p;break}g=gj[j&4095](n)|0;q=g;r=c[2440596]|0;s=a[9660972]|0;t=c[2443776]|0}else{q=a[e+(o&255)|0]|0;r=k;s=m;t=p}}while(0);a[9660973]=q;p=r-1|0;c[2440596]=p;r=(q&255)<<8;q=a[9660978]|0;m=(q&255)+(s&255)&255|r;do{if((c[t+68+((r&65535)>>>8<<2)>>2]|0)==0){s=c[t+3148>>2]|0;if((s|0)==0){u=p;v=q;w=t;break}gj[s&4095](m)|0;u=c[2440596]|0;v=a[9660978]|0;w=c[2443776]|0}else{u=p;v=q;w=t}}while(0);t=u-1|0;c[2440596]=t;b[4830486]=(b[4830486]|0)+(v&255)&65535;v=c[2415243]|0;u=v&65535;q=c[w+68+((v>>>8&255)<<2)>>2]|0;do{if((q|0)==0){p=c[w+3156>>2]|0;if((p|0)==0){x=0;y=t;z=v;A=w;break}m=gj[p&4095](u)|0;x=m;y=c[2440596]|0;z=c[2415243]|0;A=c[2443776]|0}else{x=a[q+(v&255)|0]|0;y=t;z=v;A=w}}while(0);w=x&255;v=y-1|0;c[2440596]=v;y=z&65535;t=c[A+68+((z>>>8&255|256)<<2)>>2]|0;do{if((t|0)==0){q=c[A+3152>>2]|0;if((q|0)==0){B=v;break}gg[q&4095](y,x);B=c[2440596]|0}else{a[t+(z&255)|0]=x;B=v}}while(0);v=B-1|0;c[2440596]=v;B=a[9660979]|0;z=B&-2|x&1;a[9660979]=z;x=((B&255)<<8|w)>>>1;w=z&255;z=w&1;do{if((w&8|0)==0){t=d[9660976]|0;y=(x&255)+z+t|0;A=B&-66;q=(((x^128^t)&128&(y^t)|0)==0?A:A|64)|(y&65280|0)!=0;a[9660979]=q;a[9660976]=y&255;if((y&255|0)==0){a[9660979]=q&125|2;break}else{a[9660979]=(q&125|y&128)&255;break}}else{y=d[9660976]|0;q=(x&15)+z+(y&15)|0;A=(y&240)+(x&240)|0;t=B&60;u=(q+A&255|0)==0?t|2:t;a[9660979]=u;if((q|0)>9){C=q+6|0;D=A+16|0}else{C=q;D=A}if((D&128|0)==0){E=u}else{A=u|-128;a[9660979]=A;E=A}if(((x^128^y)&128&(D^y)|0)==0){F=E}else{y=E|64;a[9660979]=y;F=y}y=(D|0)>144?D+96|0:D;if((y&65280|0)!=0){a[9660979]=F|1}a[9660976]=(y&240|C&15)&255}}while(0);C=c[2415243]|0;F=x&255;x=c[2443776]|0;D=c[x+68+((C>>>8&255|256)<<2)>>2]|0;if((D|0)!=0){a[D+(C&255)|0]=F;G=v;H=G-1|0;c[2440596]=H;return}D=c[x+3152>>2]|0;if((D|0)==0){G=v;H=G-1|0;c[2440596]=H;return}gg[D&4095](C&65535,F);G=c[2440596]|0;H=G-1|0;c[2440596]=H;return}function fTT(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;d=f&255;do{if((g|0)==0){k=c[j+3148>>2]|0;if((k|0)==0){l=0;m=i;n=d;o=j;break}h=gj[k&4095](e)|0;l=h;m=c[2440596]|0;n=a[9660968]|0;o=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=d;o=j}}while(0);a[9660972]=l;j=m-1|0;c[2440596]=j;a[9660968]=n+1&255;n=c[2415242]|0;m=n&65535;d=c[o+68+((n>>>8&255)<<2)>>2]|0;do{if((d|0)==0){i=c[o+3148>>2]|0;if((i|0)==0){p=0;q=j;r=l;s=o;break}f=gj[i&4095](m)|0;p=f;q=c[2440596]|0;r=a[9660972]|0;s=c[2443776]|0}else{p=a[d+(n&255)|0]|0;q=j;r=l;s=o}}while(0);a[9660973]=p;o=q-1|0;c[2440596]=o;q=(p&255)<<8;p=a[9660978]|0;l=(p&255)+(r&255)&255|q;do{if((c[s+68+((q&65535)>>>8<<2)>>2]|0)==0){r=c[s+3148>>2]|0;if((r|0)==0){t=o;u=p;v=s;break}gj[r&4095](l)|0;t=c[2440596]|0;u=a[9660978]|0;v=c[2443776]|0}else{t=o;u=p;v=s}}while(0);s=t-1|0;c[2440596]=s;t=(b[4830486]|0)+(u&255)&65535;b[4830486]=t;u=a[9660977]&a[9660976]&(((t&65535)>>>8&255)+1&255);t=c[2415243]|0;p=c[v+68+((t>>>8&255|256)<<2)>>2]|0;if((p|0)!=0){a[p+(t&255)|0]=u;w=s;x=w-1|0;c[2440596]=x;return}p=c[v+3152>>2]|0;if((p|0)==0){w=s;x=w-1|0;c[2440596]=x;return}gg[p&4095](t&65535,u);w=c[2440596]|0;x=w-1|0;c[2440596]=x;return}function fTU(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;d=f&255;do{if((g|0)==0){k=c[j+3148>>2]|0;if((k|0)==0){l=0;m=i;n=d;o=j;break}h=gj[k&4095](e)|0;l=h;m=c[2440596]|0;n=a[9660968]|0;o=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=d;o=j}}while(0);a[9660972]=l;j=m-1|0;c[2440596]=j;a[9660968]=n+1&255;n=c[2415242]|0;m=n&65535;d=c[o+68+((n>>>8&255)<<2)>>2]|0;do{if((d|0)==0){i=c[o+3148>>2]|0;if((i|0)==0){p=0;q=j;r=l;break}f=gj[i&4095](m)|0;p=f;q=c[2440596]|0;r=a[9660972]|0}else{p=a[d+(n&255)|0]|0;q=j;r=l}}while(0);a[9660973]=p;l=q-1|0;c[2440596]=l;q=a[9660978]|0;j=(q&255)+(r&255)|0;if((j|0)>255){r=p&255;p=(j&255|r<<8)&65535;j=c[2443776]|0;do{if((c[j+68+(r<<2)>>2]|0)==0){n=c[j+3148>>2]|0;if((n|0)==0){s=l;t=q;break}gj[n&4095](p)|0;s=c[2440596]|0;t=a[9660978]|0}else{s=l;t=q}}while(0);p=s-1|0;c[2440596]=p;u=t;v=p}else{u=q;v=l}b[4830486]=(b[4830486]|0)+(u&255)&65535;u=c[2415243]|0;l=c[2443776]|0;q=c[l+68+((u>>>8&255)<<2)>>2]|0;if((q|0)!=0){w=a[q+(u&255)|0]|0;x=v;y=x-1|0;c[2440596]=y;a[9660977]=w;a[9660976]=w;z=w<<24>>24==0;A=a[9660979]|0;B=A&125;C=w&-128;D=z?2:C;E=B|D;a[9660979]=E;return}q=c[l+3156>>2]|0;if((q|0)==0){w=0;x=v;y=x-1|0;c[2440596]=y;a[9660977]=w;a[9660976]=w;z=w<<24>>24==0;A=a[9660979]|0;B=A&125;C=w&-128;D=z?2:C;E=B|D;a[9660979]=E;return}v=gj[q&4095](u&65535)|0;w=v;x=c[2440596]|0;y=x-1|0;c[2440596]=y;a[9660977]=w;a[9660976]=w;z=w<<24>>24==0;A=a[9660979]|0;B=A&125;C=w&-128;D=z?2:C;E=B|D;a[9660979]=E;return}function fTV(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;d=f&255;do{if((g|0)==0){k=c[j+3148>>2]|0;if((k|0)==0){l=0;m=i;n=d;o=j;break}h=gj[k&4095](e)|0;l=h;m=c[2440596]|0;n=a[9660968]|0;o=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=d;o=j}}while(0);a[9660972]=l;j=m-1|0;c[2440596]=j;a[9660968]=n+1&255;n=c[2415242]|0;m=n&65535;d=c[o+68+((n>>>8&255)<<2)>>2]|0;do{if((d|0)==0){i=c[o+3148>>2]|0;if((i|0)==0){p=0;q=j;r=l;s=o;break}f=gj[i&4095](m)|0;p=f;q=c[2440596]|0;r=a[9660972]|0;s=c[2443776]|0}else{p=a[d+(n&255)|0]|0;q=j;r=l;s=o}}while(0);a[9660973]=p;o=q-1|0;c[2440596]=o;q=(p&255)<<8;p=a[9660978]|0;l=(p&255)+(r&255)&255|q;do{if((c[s+68+((q&65535)>>>8<<2)>>2]|0)==0){r=c[s+3148>>2]|0;if((r|0)==0){t=o;u=p;v=s;break}gj[r&4095](l)|0;t=c[2440596]|0;u=a[9660978]|0;v=c[2443776]|0}else{t=o;u=p;v=s}}while(0);s=t-1|0;c[2440596]=s;b[4830486]=(b[4830486]|0)+(u&255)&65535;u=c[2415243]|0;t=u&65535;p=c[v+68+((u>>>8&255)<<2)>>2]|0;do{if((p|0)==0){o=c[v+3156>>2]|0;if((o|0)==0){w=0;x=s;y=u;z=v;break}l=gj[o&4095](t)|0;w=l;x=c[2440596]|0;y=c[2415243]|0;z=c[2443776]|0}else{w=a[p+(u&255)|0]|0;x=s;y=u;z=v}}while(0);v=x-1|0;c[2440596]=v;x=y&65535;u=c[z+68+((y>>>8&255|256)<<2)>>2]|0;do{if((u|0)==0){s=c[z+3152>>2]|0;if((s|0)==0){A=v;break}gg[s&4095](x,w);A=c[2440596]|0}else{a[u+(y&255)|0]=w;A=v}}while(0);v=A-1|0;c[2440596]=v;A=w-1&255;w=a[9660979]|0;y=w&-2;a[9660979]=y;u=a[9660976]|0;if((u&255)<(A&255)){B=y}else{y=w|1;a[9660979]=y;B=y}if(u<<24>>24==A<<24>>24){C=B&125|2}else{C=B&125|u-A&255&-128}a[9660979]=C;C=c[2415243]|0;u=c[2443776]|0;B=c[u+68+((C>>>8&255|256)<<2)>>2]|0;if((B|0)!=0){a[B+(C&255)|0]=A;D=v;E=D-1|0;c[2440596]=E;return}B=c[u+3152>>2]|0;if((B|0)==0){D=v;E=D-1|0;c[2440596]=E;return}gg[B&4095](C&65535,A);D=c[2440596]|0;E=D-1|0;c[2440596]=E;return}function fTW(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;d=f&255;do{if((g|0)==0){k=c[j+3148>>2]|0;if((k|0)==0){l=0;m=i;n=d;o=j;break}h=gj[k&4095](e)|0;l=h;m=c[2440596]|0;n=a[9660968]|0;o=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=d;o=j}}while(0);a[9660972]=l;j=m-1|0;c[2440596]=j;a[9660968]=n+1&255;n=c[2415242]|0;m=n&65535;d=c[o+68+((n>>>8&255)<<2)>>2]|0;do{if((d|0)==0){i=c[o+3148>>2]|0;if((i|0)==0){p=0;q=j;r=l;s=o;break}f=gj[i&4095](m)|0;p=f;q=c[2440596]|0;r=a[9660972]|0;s=c[2443776]|0}else{p=a[d+(n&255)|0]|0;q=j;r=l;s=o}}while(0);a[9660973]=p;o=q-1|0;c[2440596]=o;q=(p&255)<<8;p=a[9660978]|0;l=(p&255)+(r&255)&255|q;do{if((c[s+68+((q&65535)>>>8<<2)>>2]|0)==0){r=c[s+3148>>2]|0;if((r|0)==0){t=o;u=p;v=s;break}gj[r&4095](l)|0;t=c[2440596]|0;u=a[9660978]|0;v=c[2443776]|0}else{t=o;u=p;v=s}}while(0);s=t-1|0;c[2440596]=s;b[4830486]=(b[4830486]|0)+(u&255)&65535;u=c[2415243]|0;t=u&65535;p=c[v+68+((u>>>8&255)<<2)>>2]|0;do{if((p|0)==0){o=c[v+3156>>2]|0;if((o|0)==0){w=0;x=s;y=u;z=v;break}l=gj[o&4095](t)|0;w=l;x=c[2440596]|0;y=c[2415243]|0;z=c[2443776]|0}else{w=a[p+(u&255)|0]|0;x=s;y=u;z=v}}while(0);v=x-1|0;c[2440596]=v;x=y&65535;u=c[z+68+((y>>>8&255|256)<<2)>>2]|0;do{if((u|0)==0){s=c[z+3152>>2]|0;if((s|0)==0){A=v;break}gg[s&4095](x,w);A=c[2440596]|0}else{a[u+(y&255)|0]=w;A=v}}while(0);v=A-1|0;c[2440596]=v;A=w+1&255;w=A&255;y=a[9660979]|0;u=y&255;x=u&1^1;z=a[9660976]|0;s=z&255;p=s-w-x|0;do{if((u&8|0)==0){t=y&-66;l=(((z^A)&128&(p^s)|0)==0?t:t|64)|(p&65280|0)==0;a[9660979]=l;a[9660976]=p&255;if((p&255|0)==0){a[9660979]=l&125|2;break}else{a[9660979]=(l&125|p&128)&255;break}}else{l=(s&15)-(w&15)-x|0;t=(s&240)-(w&240)|0;if((l&16|0)==0){B=l;C=t}else{B=l-6|0;C=t-1|0}t=y&60;l=(((z^A)&128&(p^s)|0)==0?t:t|64)|(p&65280|0)==0;t=(p&255|0)==0?l|2:l;a[9660979]=(p&128|0)==0?t:t|-128;a[9660976]=(((C&256|0)==0?C:C+160|0)&240|B&15)&255}}while(0);B=c[2415243]|0;C=c[2443776]|0;p=c[C+68+((B>>>8&255|256)<<2)>>2]|0;if((p|0)!=0){a[p+(B&255)|0]=A;D=v;E=D-1|0;c[2440596]=E;return}p=c[C+3152>>2]|0;if((p|0)==0){D=v;E=D-1|0;c[2440596]=E;return}gg[p&4095](B&65535,A);D=c[2440596]|0;E=D-1|0;c[2440596]=E;return}function fTX(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;if((c[j+68+((f>>>8&255)<<2)>>2]|0)!=0){l=i;m=l-1|0;c[2440596]=m;return}e=c[j+3148>>2]|0;if((e|0)==0){l=i;m=l-1|0;c[2440596]=m;return}gj[e&4095](f&65535)|0;l=c[2440596]|0;m=l-1|0;c[2440596]=m;return}function fTY(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=0;m=i;break}k=gj[d&4095](e)|0;l=k;m=c[2440596]|0}else{l=a[g+(f&255)|0]|0;m=i}}while(0);c[2440596]=m-1;m=a[9660979]&61|l&-64;a[9660979]=m;if((a[9660976]&l)<<24>>24!=0){return}a[9660979]=m|2;return}function fTZ(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;if((c[j+68+((f>>>8&255)<<2)>>2]|0)!=0){l=i;m=l-1|0;c[2440596]=m;return}e=c[j+3148>>2]|0;if((e|0)==0){l=i;m=l-1|0;c[2440596]=m;return}gj[e&4095](f&65535)|0;l=c[2440596]|0;m=l-1|0;c[2440596]=m;return}function fT_(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;if((c[j+68+((f>>>8&255)<<2)>>2]|0)!=0){l=i;m=l-1|0;c[2440596]=m;return}e=c[j+3148>>2]|0;if((e|0)==0){l=i;m=l-1|0;c[2440596]=m;return}gj[e&4095](f&65535)|0;l=c[2440596]|0;m=l-1|0;c[2440596]=m;return}function fT$(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=a[9660978]|0;e=b[4830480]|0;b[4830480]=e+1&65535;f=e&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](e)|0;j=l;k=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=g}}while(0);a[9660968]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;g=c[2415242]|0;c[2415243]=g;f=c[k+68+((g>>>8&255|256)<<2)>>2]|0;if((f|0)!=0){a[f+(g&255)|0]=d;m=j;n=m-1|0;c[2440596]=n;return}f=c[k+3152>>2]|0;if((f|0)==0){m=j;n=m-1|0;c[2440596]=n;return}gg[f&4095](g&65535,d);m=c[2440596]|0;n=m-1|0;c[2440596]=n;return}function fT0(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=0;m=i;break}k=gj[d&4095](e)|0;l=k;m=c[2440596]|0}else{l=a[g+(f&255)|0]|0;m=i}}while(0);c[2440596]=m-1;a[9660978]=l;a[9660979]=a[9660979]&125|(l<<24>>24==0?2:l&-128);return}function fT1(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=0;m=i;break}k=gj[d&4095](e)|0;l=k;m=c[2440596]|0}else{l=a[g+(f&255)|0]|0;m=i}}while(0);c[2440596]=m-1;m=a[9660979]|0;i=m&-2;a[9660979]=i;f=a[9660978]|0;if((f&255)<(l&255)){n=i}else{i=m|1;a[9660979]=i;n=i}if(f<<24>>24==l<<24>>24){o=n&125|2;a[9660979]=o;return}else{o=n&125|f-l&255&-128;a[9660979]=o;return}}function fT2(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=0;m=i;break}k=gj[d&4095](e)|0;l=k;m=c[2440596]|0}else{l=a[g+(f&255)|0]|0;m=i}}while(0);c[2440596]=m-1;m=a[9660979]|0;i=m&-2;a[9660979]=i;f=a[9660977]|0;if((f&255)<(l&255)){n=i}else{i=m|1;a[9660979]=i;n=i}if(f<<24>>24==l<<24>>24){o=n&125|2;a[9660979]=o;return}else{o=n&125|f-l&255&-128;a[9660979]=o;return}}function fT3(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=f&255;do{if((c[j+68+((f>>>8&255)<<2)>>2]|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=i;m=g;n=j;break}gj[d&4095](e)|0;l=c[2440596]|0;m=a[9660968]|0;n=c[2443776]|0}else{l=i;m=g;n=j}}while(0);j=l-1|0;c[2440596]=j;a[9660968]=m+(a[9660977]|0)&255;m=c[2415242]|0;c[2415243]=m;if((c[n+68+((m>>>8&255)<<2)>>2]|0)!=0){o=j;p=o-1|0;c[2440596]=p;return}l=c[n+3148>>2]|0;if((l|0)==0){o=j;p=o-1|0;c[2440596]=p;return}gj[l&4095](m&65535)|0;o=c[2440596]|0;p=o-1|0;c[2440596]=p;return}function fT4(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=f&255;do{if((c[j+68+((f>>>8&255)<<2)>>2]|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=i;m=g;n=j;break}gj[d&4095](e)|0;l=c[2440596]|0;m=a[9660968]|0;n=c[2443776]|0}else{l=i;m=g;n=j}}while(0);j=l-1|0;c[2440596]=j;a[9660968]=m+(a[9660977]|0)&255;m=c[2415242]|0;c[2415243]=m;if((c[n+68+((m>>>8&255)<<2)>>2]|0)!=0){o=j;p=o-1|0;c[2440596]=p;return}l=c[n+3148>>2]|0;if((l|0)==0){o=j;p=o-1|0;c[2440596]=p;return}gj[l&4095](m&65535)|0;o=c[2440596]|0;p=o-1|0;c[2440596]=p;return}function fT5(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=f&255;do{if((c[j+68+((f>>>8&255)<<2)>>2]|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=i;m=g;n=j;break}gj[d&4095](e)|0;l=c[2440596]|0;m=a[9660968]|0;n=c[2443776]|0}else{l=i;m=g;n=j}}while(0);j=l-1|0;c[2440596]=j;a[9660968]=m+(a[9660977]|0)&255;m=c[2415242]|0;c[2415243]=m;if((c[n+68+((m>>>8&255)<<2)>>2]|0)!=0){o=j;p=o-1|0;c[2440596]=p;return}l=c[n+3148>>2]|0;if((l|0)==0){o=j;p=o-1|0;c[2440596]=p;return}gj[l&4095](m&65535)|0;o=c[2440596]|0;p=o-1|0;c[2440596]=p;return}function fT6(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=f&255;do{if((c[j+68+((f>>>8&255)<<2)>>2]|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=i;m=g;n=j;break}gj[d&4095](e)|0;l=c[2440596]|0;m=a[9660968]|0;n=c[2443776]|0}else{l=i;m=g;n=j}}while(0);j=l-1|0;c[2440596]=j;a[9660968]=m+(a[9660977]|0)&255;m=c[2415242]|0;c[2415243]=m;if((c[n+68+((m>>>8&255)<<2)>>2]|0)!=0){o=j;p=o-1|0;c[2440596]=p;return}l=c[n+3148>>2]|0;if((l|0)==0){o=j;p=o-1|0;c[2440596]=p;return}gj[l&4095](m&65535)|0;o=c[2440596]|0;p=o-1|0;c[2440596]=p;return}function fT7(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=a[9660978]|0;e=b[4830480]|0;b[4830480]=e+1&65535;f=e&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](e)|0;j=l;k=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=g}}while(0);a[9660968]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;g=c[2415242]|0;f=g&65535;h=g&255;do{if((c[k+68+((g>>>8&255)<<2)>>2]|0)==0){e=c[k+3148>>2]|0;if((e|0)==0){m=j;n=h;o=k;break}gj[e&4095](f)|0;m=c[2440596]|0;n=a[9660968]|0;o=c[2443776]|0}else{m=j;n=h;o=k}}while(0);k=m-1|0;c[2440596]=k;a[9660968]=n+(a[9660977]|0)&255;n=c[2415242]|0;c[2415243]=n;m=c[o+68+((n>>>8&255|256)<<2)>>2]|0;if((m|0)!=0){a[m+(n&255)|0]=d;p=k;q=p-1|0;c[2440596]=q;return}m=c[o+3152>>2]|0;if((m|0)==0){p=k;q=p-1|0;c[2440596]=q;return}gg[m&4095](n&65535,d);p=c[2440596]|0;q=p-1|0;c[2440596]=q;return}function fT8(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=f&255;do{if((c[j+68+((f>>>8&255)<<2)>>2]|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=i;m=g;n=j;break}gj[d&4095](e)|0;l=c[2440596]|0;m=a[9660968]|0;n=c[2443776]|0}else{l=i;m=g;n=j}}while(0);j=l-1|0;c[2440596]=j;a[9660968]=m+(a[9660977]|0)&255;m=c[2415242]|0;c[2415243]=m;l=m&65535;g=c[n+68+((m>>>8&255)<<2)>>2]|0;do{if((g|0)==0){i=c[n+3148>>2]|0;if((i|0)==0){o=0;p=j;break}e=gj[i&4095](l)|0;o=e;p=c[2440596]|0}else{o=a[g+(m&255)|0]|0;p=j}}while(0);c[2440596]=p-1;a[9660978]=o;a[9660979]=a[9660979]&125|(o<<24>>24==0?2:o&-128);return}function fT9(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=f&255;do{if((c[j+68+((f>>>8&255)<<2)>>2]|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=i;m=g;n=j;break}gj[d&4095](e)|0;l=c[2440596]|0;m=a[9660968]|0;n=c[2443776]|0}else{l=i;m=g;n=j}}while(0);j=l-1|0;c[2440596]=j;a[9660968]=m+(a[9660977]|0)&255;m=c[2415242]|0;c[2415243]=m;if((c[n+68+((m>>>8&255)<<2)>>2]|0)!=0){o=j;p=o-1|0;c[2440596]=p;return}l=c[n+3148>>2]|0;if((l|0)==0){o=j;p=o-1|0;c[2440596]=p;return}gj[l&4095](m&65535)|0;o=c[2440596]|0;p=o-1|0;c[2440596]=p;return}function fUa(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=f&255;do{if((c[j+68+((f>>>8&255)<<2)>>2]|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=i;m=g;n=j;break}gj[d&4095](e)|0;l=c[2440596]|0;m=a[9660968]|0;n=c[2443776]|0}else{l=i;m=g;n=j}}while(0);j=l-1|0;c[2440596]=j;a[9660968]=m+(a[9660977]|0)&255;m=c[2415242]|0;c[2415243]=m;if((c[n+68+((m>>>8&255)<<2)>>2]|0)!=0){o=j;p=o-1|0;c[2440596]=p;return}l=c[n+3148>>2]|0;if((l|0)==0){o=j;p=o-1|0;c[2440596]=p;return}gj[l&4095](m&65535)|0;o=c[2440596]|0;p=o-1|0;c[2440596]=p;return}function fUb(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=0;m=i;break}k=gj[d&4095](e)|0;l=k;m=c[2440596]|0}else{l=a[g+(f&255)|0]|0;m=i}}while(0);c[2440596]=m-1;m=a[9660976]|l;a[9660976]=m;a[9660979]=(m<<24>>24==0?2:m&-128)|a[9660979]&125;return}function fUc(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=0;m=i;break}k=gj[d&4095](e)|0;l=k;m=c[2440596]|0}else{l=a[g+(f&255)|0]|0;m=i}}while(0);c[2440596]=m-1;m=a[9660976]&l;a[9660976]=m;a[9660979]=(m<<24>>24==0?2:m&-128)|a[9660979]&125;return}function fUd(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=0;m=i;break}k=gj[d&4095](e)|0;l=k;m=c[2440596]|0}else{l=a[g+(f&255)|0]|0;m=i}}while(0);c[2440596]=m-1;m=a[9660976]|0;i=m^l;a[9660976]=i;a[9660979]=(m<<24>>24==l<<24>>24?2:i&-128)|a[9660979]&125;return}function fUe(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=0;m=i;break}k=gj[d&4095](e)|0;l=k;m=c[2440596]|0}else{l=a[g+(f&255)|0]|0;m=i}}while(0);i=l&255;c[2440596]=m-1;m=a[9660979]|0;f=m&255;g=f&1;e=a[9660976]|0;j=e&255;if((f&8|0)==0){f=j+i+g|0;k=m&-66;d=((((e^l)&128^128)&(f^j)|0)==0?k:k|64)|(f&65280|0)!=0;a[9660979]=d;a[9660976]=f&255;if((f&255|0)==0){a[9660979]=d&125|2;return}else{a[9660979]=(d&125|f&128)&255;return}}f=g+(i&15)+(j&15)|0;g=(j&240)+(i&240)|0;i=m&60;m=(f+g&255|0)==0?i|2:i;a[9660979]=m;if((f|0)>9){n=f+6|0;o=g+16|0}else{n=f;o=g}if((o&128|0)==0){p=m}else{g=m|-128;a[9660979]=g;p=g}if((((e^l)&128^128)&(o^j)|0)==0){q=p}else{j=p|64;a[9660979]=j;q=j}j=(o|0)>144?o+96|0:o;if((j&65280|0)!=0){a[9660979]=q|1}a[9660976]=(j&240|n&15)&255;return}function fUf(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=a[9660976]|0;e=b[4830480]|0;b[4830480]=e+1&65535;f=e&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](e)|0;j=l;k=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=g}}while(0);a[9660968]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;g=c[2415242]|0;c[2415243]=g;f=c[k+68+((g>>>8&255|256)<<2)>>2]|0;if((f|0)!=0){a[f+(g&255)|0]=d;m=j;n=m-1|0;c[2440596]=n;return}f=c[k+3152>>2]|0;if((f|0)==0){m=j;n=m-1|0;c[2440596]=n;return}gg[f&4095](g&65535,d);m=c[2440596]|0;n=m-1|0;c[2440596]=n;return}function fUg(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=0;m=i;break}k=gj[d&4095](e)|0;l=k;m=c[2440596]|0}else{l=a[g+(f&255)|0]|0;m=i}}while(0);c[2440596]=m-1;a[9660976]=l;a[9660979]=a[9660979]&125|(l<<24>>24==0?2:l&-128);return}function fUh(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=0;m=i;break}k=gj[d&4095](e)|0;l=k;m=c[2440596]|0}else{l=a[g+(f&255)|0]|0;m=i}}while(0);c[2440596]=m-1;m=a[9660979]|0;i=m&-2;a[9660979]=i;f=a[9660976]|0;if((f&255)<(l&255)){n=i}else{i=m|1;a[9660979]=i;n=i}if(f<<24>>24==l<<24>>24){o=n&125|2;a[9660979]=o;return}else{o=n&125|f-l&255&-128;a[9660979]=o;return}}function fUi(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=0;m=i;break}k=gj[d&4095](e)|0;l=k;m=c[2440596]|0}else{l=a[g+(f&255)|0]|0;m=i}}while(0);i=l&255;c[2440596]=m-1;m=a[9660979]|0;f=m&255;g=f&1^1;e=a[9660976]|0;j=e&255;k=j-i-g|0;if((f&8|0)!=0){f=(j&15)-(i&15)-g|0;g=(j&240)-(i&240)|0;if((f&16|0)==0){n=f;o=g}else{n=f-6|0;o=g-1|0}g=m&60;f=(((e^l)&128&(k^j)|0)==0?g:g|64)|(k&65280|0)==0;g=(k&255|0)==0?f|2:f;a[9660979]=(k&128|0)==0?g:g|-128;a[9660976]=(((o&256|0)==0?o:o+160|0)&240|n&15)&255;return}n=m&-66;m=(((e^l)&128&(k^j)|0)==0?n:n|64)|(k&65280|0)==0;a[9660979]=m;a[9660976]=k&255;if((k&255|0)==0){a[9660979]=m&125|2;return}else{a[9660979]=(m&125|k&128)&255;return}}function fUj(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=f&255;do{if((c[j+68+((f>>>8&255)<<2)>>2]|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=i;m=g;n=j;break}gj[d&4095](e)|0;l=c[2440596]|0;m=a[9660968]|0;n=c[2443776]|0}else{l=i;m=g;n=j}}while(0);j=l-1|0;c[2440596]=j;a[9660968]=m+(a[9660977]|0)&255;m=c[2415242]|0;c[2415243]=m;l=m&65535;g=c[n+68+((m>>>8&255)<<2)>>2]|0;do{if((g|0)==0){i=c[n+3148>>2]|0;if((i|0)==0){o=0;p=j;break}e=gj[i&4095](l)|0;o=e;p=c[2440596]|0}else{o=a[g+(m&255)|0]|0;p=j}}while(0);c[2440596]=p-1;p=a[9660976]|o;a[9660976]=p;a[9660979]=(p<<24>>24==0?2:p&-128)|a[9660979]&125;return}function fUk(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=f&255;do{if((c[j+68+((f>>>8&255)<<2)>>2]|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=i;m=g;n=j;break}gj[d&4095](e)|0;l=c[2440596]|0;m=a[9660968]|0;n=c[2443776]|0}else{l=i;m=g;n=j}}while(0);j=l-1|0;c[2440596]=j;a[9660968]=m+(a[9660977]|0)&255;m=c[2415242]|0;c[2415243]=m;l=m&65535;g=c[n+68+((m>>>8&255)<<2)>>2]|0;do{if((g|0)==0){i=c[n+3148>>2]|0;if((i|0)==0){o=0;p=j;break}e=gj[i&4095](l)|0;o=e;p=c[2440596]|0}else{o=a[g+(m&255)|0]|0;p=j}}while(0);c[2440596]=p-1;p=a[9660976]&o;a[9660976]=p;a[9660979]=(p<<24>>24==0?2:p&-128)|a[9660979]&125;return}function fUl(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=f&255;do{if((c[j+68+((f>>>8&255)<<2)>>2]|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=i;m=g;n=j;break}gj[d&4095](e)|0;l=c[2440596]|0;m=a[9660968]|0;n=c[2443776]|0}else{l=i;m=g;n=j}}while(0);j=l-1|0;c[2440596]=j;a[9660968]=m+(a[9660977]|0)&255;m=c[2415242]|0;c[2415243]=m;l=m&65535;g=c[n+68+((m>>>8&255)<<2)>>2]|0;do{if((g|0)==0){i=c[n+3148>>2]|0;if((i|0)==0){o=0;p=j;break}e=gj[i&4095](l)|0;o=e;p=c[2440596]|0}else{o=a[g+(m&255)|0]|0;p=j}}while(0);c[2440596]=p-1;p=a[9660976]|0;j=p^o;a[9660976]=j;a[9660979]=(p<<24>>24==o<<24>>24?2:j&-128)|a[9660979]&125;return}function fUm(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=f&255;do{if((c[j+68+((f>>>8&255)<<2)>>2]|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=i;m=g;n=j;break}gj[d&4095](e)|0;l=c[2440596]|0;m=a[9660968]|0;n=c[2443776]|0}else{l=i;m=g;n=j}}while(0);j=l-1|0;c[2440596]=j;a[9660968]=m+(a[9660977]|0)&255;m=c[2415242]|0;c[2415243]=m;l=m&65535;g=c[n+68+((m>>>8&255)<<2)>>2]|0;do{if((g|0)==0){i=c[n+3148>>2]|0;if((i|0)==0){o=0;p=j;break}e=gj[i&4095](l)|0;o=e;p=c[2440596]|0}else{o=a[g+(m&255)|0]|0;p=j}}while(0);j=o&255;c[2440596]=p-1;p=a[9660979]|0;m=p&255;g=m&1;l=a[9660976]|0;n=l&255;if((m&8|0)==0){m=n+j+g|0;e=p&-66;i=((((l^o)&128^128)&(m^n)|0)==0?e:e|64)|(m&65280|0)!=0;a[9660979]=i;a[9660976]=m&255;if((m&255|0)==0){a[9660979]=i&125|2;return}else{a[9660979]=(i&125|m&128)&255;return}}m=g+(j&15)+(n&15)|0;g=(n&240)+(j&240)|0;j=p&60;p=(m+g&255|0)==0?j|2:j;a[9660979]=p;if((m|0)>9){q=m+6|0;r=g+16|0}else{q=m;r=g}if((r&128|0)==0){s=p}else{g=p|-128;a[9660979]=g;s=g}if((((l^o)&128^128)&(r^n)|0)==0){t=s}else{n=s|64;a[9660979]=n;t=n}n=(r|0)>144?r+96|0:r;if((n&65280|0)!=0){a[9660979]=t|1}a[9660976]=(n&240|q&15)&255;return}function fUn(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=a[9660976]|0;e=b[4830480]|0;b[4830480]=e+1&65535;f=e&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](e)|0;j=l;k=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=g}}while(0);a[9660968]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;g=c[2415242]|0;f=g&65535;h=g&255;do{if((c[k+68+((g>>>8&255)<<2)>>2]|0)==0){e=c[k+3148>>2]|0;if((e|0)==0){m=j;n=h;o=k;break}gj[e&4095](f)|0;m=c[2440596]|0;n=a[9660968]|0;o=c[2443776]|0}else{m=j;n=h;o=k}}while(0);k=m-1|0;c[2440596]=k;a[9660968]=n+(a[9660977]|0)&255;n=c[2415242]|0;c[2415243]=n;m=c[o+68+((n>>>8&255|256)<<2)>>2]|0;if((m|0)!=0){a[m+(n&255)|0]=d;p=k;q=p-1|0;c[2440596]=q;return}m=c[o+3152>>2]|0;if((m|0)==0){p=k;q=p-1|0;c[2440596]=q;return}gg[m&4095](n&65535,d);p=c[2440596]|0;q=p-1|0;c[2440596]=q;return}function fUo(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=f&255;do{if((c[j+68+((f>>>8&255)<<2)>>2]|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=i;m=g;n=j;break}gj[d&4095](e)|0;l=c[2440596]|0;m=a[9660968]|0;n=c[2443776]|0}else{l=i;m=g;n=j}}while(0);j=l-1|0;c[2440596]=j;a[9660968]=m+(a[9660977]|0)&255;m=c[2415242]|0;c[2415243]=m;l=m&65535;g=c[n+68+((m>>>8&255)<<2)>>2]|0;do{if((g|0)==0){i=c[n+3148>>2]|0;if((i|0)==0){o=0;p=j;break}e=gj[i&4095](l)|0;o=e;p=c[2440596]|0}else{o=a[g+(m&255)|0]|0;p=j}}while(0);c[2440596]=p-1;a[9660976]=o;a[9660979]=a[9660979]&125|(o<<24>>24==0?2:o&-128);return}function fUp(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=f&255;do{if((c[j+68+((f>>>8&255)<<2)>>2]|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=i;m=g;n=j;break}gj[d&4095](e)|0;l=c[2440596]|0;m=a[9660968]|0;n=c[2443776]|0}else{l=i;m=g;n=j}}while(0);j=l-1|0;c[2440596]=j;a[9660968]=m+(a[9660977]|0)&255;m=c[2415242]|0;c[2415243]=m;l=m&65535;g=c[n+68+((m>>>8&255)<<2)>>2]|0;do{if((g|0)==0){i=c[n+3148>>2]|0;if((i|0)==0){o=0;p=j;break}e=gj[i&4095](l)|0;o=e;p=c[2440596]|0}else{o=a[g+(m&255)|0]|0;p=j}}while(0);c[2440596]=p-1;p=a[9660979]|0;j=p&-2;a[9660979]=j;m=a[9660976]|0;if((m&255)<(o&255)){q=j}else{j=p|1;a[9660979]=j;q=j}if(m<<24>>24==o<<24>>24){r=q&125|2;a[9660979]=r;return}else{r=q&125|m-o&255&-128;a[9660979]=r;return}}function fUq(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=f&255;do{if((c[j+68+((f>>>8&255)<<2)>>2]|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=i;m=g;n=j;break}gj[d&4095](e)|0;l=c[2440596]|0;m=a[9660968]|0;n=c[2443776]|0}else{l=i;m=g;n=j}}while(0);j=l-1|0;c[2440596]=j;a[9660968]=m+(a[9660977]|0)&255;m=c[2415242]|0;c[2415243]=m;l=m&65535;g=c[n+68+((m>>>8&255)<<2)>>2]|0;do{if((g|0)==0){i=c[n+3148>>2]|0;if((i|0)==0){o=0;p=j;break}e=gj[i&4095](l)|0;o=e;p=c[2440596]|0}else{o=a[g+(m&255)|0]|0;p=j}}while(0);j=o&255;c[2440596]=p-1;p=a[9660979]|0;m=p&255;g=m&1^1;l=a[9660976]|0;n=l&255;e=n-j-g|0;if((m&8|0)!=0){m=(n&15)-(j&15)-g|0;g=(n&240)-(j&240)|0;if((m&16|0)==0){q=m;r=g}else{q=m-6|0;r=g-1|0}g=p&60;m=(((l^o)&128&(e^n)|0)==0?g:g|64)|(e&65280|0)==0;g=(e&255|0)==0?m|2:m;a[9660979]=(e&128|0)==0?g:g|-128;a[9660976]=(((r&256|0)==0?r:r+160|0)&240|q&15)&255;return}q=p&-66;p=(((l^o)&128&(e^n)|0)==0?q:q|64)|(e&65280|0)==0;a[9660979]=p;a[9660976]=e&255;if((e&255|0)==0){a[9660979]=p&125|2;return}else{a[9660979]=(p&125|e&128)&255;return}}function fUr(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=0;m=i;n=f;o=j;break}k=gj[d&4095](e)|0;l=k;m=c[2440596]|0;n=c[2415243]|0;o=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=f;o=j}}while(0);j=m-1|0;c[2440596]=j;m=n&65535;f=c[o+68+((n>>>8&255|256)<<2)>>2]|0;do{if((f|0)==0){i=c[o+3152>>2]|0;if((i|0)==0){p=j;q=o;break}gg[i&4095](m,l);p=c[2440596]|0;q=c[2443776]|0}else{a[f+(n&255)|0]=l;p=j;q=o}}while(0);o=p-1|0;c[2440596]=o;p=l<<1;a[9660979]=(p<<24>>24==0?2:p&-128)|(l&255)>>>7|a[9660979]&124;l=c[2415243]|0;j=c[q+68+((l>>>8&255|256)<<2)>>2]|0;if((j|0)!=0){a[j+(l&255)|0]=p;r=o;s=r-1|0;c[2440596]=s;return}j=c[q+3152>>2]|0;if((j|0)==0){r=o;s=r-1|0;c[2440596]=s;return}gg[j&4095](l&65535,p);r=c[2440596]|0;s=r-1|0;c[2440596]=s;return}function fUs(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=0;m=i;n=f;o=j;break}k=gj[d&4095](e)|0;l=k;m=c[2440596]|0;n=c[2415243]|0;o=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=f;o=j}}while(0);j=m-1|0;c[2440596]=j;m=n&65535;f=c[o+68+((n>>>8&255|256)<<2)>>2]|0;do{if((f|0)==0){i=c[o+3152>>2]|0;if((i|0)==0){p=j;q=o;break}gg[i&4095](m,l);p=c[2440596]|0;q=c[2443776]|0}else{a[f+(n&255)|0]=l;p=j;q=o}}while(0);o=p-1|0;c[2440596]=o;p=l<<1;j=a[9660979]|0;n=j&1|p;a[9660979]=j&124|(l&255)>>>7|(n<<24>>24==0?2:p&-128);p=c[2415243]|0;l=c[q+68+((p>>>8&255|256)<<2)>>2]|0;if((l|0)!=0){a[l+(p&255)|0]=n;r=o;s=r-1|0;c[2440596]=s;return}l=c[q+3152>>2]|0;if((l|0)==0){r=o;s=r-1|0;c[2440596]=s;return}gg[l&4095](p&65535,n);r=c[2440596]|0;s=r-1|0;c[2440596]=s;return}function fUt(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=0;m=i;n=f;o=j;break}k=gj[d&4095](e)|0;l=k;m=c[2440596]|0;n=c[2415243]|0;o=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=f;o=j}}while(0);j=m-1|0;c[2440596]=j;m=n&65535;f=c[o+68+((n>>>8&255|256)<<2)>>2]|0;do{if((f|0)==0){i=c[o+3152>>2]|0;if((i|0)==0){p=j;q=o;break}gg[i&4095](m,l);p=c[2440596]|0;q=c[2443776]|0}else{a[f+(n&255)|0]=l;p=j;q=o}}while(0);o=p-1|0;c[2440596]=o;p=a[9660979]&124|l&1;j=(l&255)>>>1;a[9660979]=(j|0)==0?p|2:p;p=c[2415243]|0;l=j&255;j=c[q+68+((p>>>8&255|256)<<2)>>2]|0;if((j|0)!=0){a[j+(p&255)|0]=l;r=o;s=r-1|0;c[2440596]=s;return}j=c[q+3152>>2]|0;if((j|0)==0){r=o;s=r-1|0;c[2440596]=s;return}gg[j&4095](p&65535,l);r=c[2440596]|0;s=r-1|0;c[2440596]=s;return}function fUu(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=0;m=i;n=f;o=j;break}k=gj[d&4095](e)|0;l=k;m=c[2440596]|0;n=c[2415243]|0;o=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=f;o=j}}while(0);j=l&255;f=m-1|0;c[2440596]=f;m=n&65535;i=c[o+68+((n>>>8&255|256)<<2)>>2]|0;do{if((i|0)==0){g=c[o+3152>>2]|0;if((g|0)==0){p=f;break}gg[g&4095](m,l);p=c[2440596]|0}else{a[i+(n&255)|0]=l;p=f}}while(0);f=p-1|0;c[2440596]=f;p=a[9660979]|0;n=p&-2|l&1;a[9660979]=n;l=((p&255)<<8|j)>>>1;if((l&255|0)==0){q=n&125|2}else{q=(l&128|n&125)&255}a[9660979]=q;q=c[2415243]|0;n=l&255;l=c[2443776]|0;j=c[l+68+((q>>>8&255|256)<<2)>>2]|0;if((j|0)!=0){a[j+(q&255)|0]=n;r=f;s=r-1|0;c[2440596]=s;return}j=c[l+3152>>2]|0;if((j|0)==0){r=f;s=r-1|0;c[2440596]=s;return}gg[j&4095](q&65535,n);r=c[2440596]|0;s=r-1|0;c[2440596]=s;return}function fUv(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=a[9660977]|0;e=b[4830480]|0;b[4830480]=e+1&65535;f=e&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](e)|0;j=l;k=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=g}}while(0);a[9660968]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;g=c[2415242]|0;c[2415243]=g;f=c[k+68+((g>>>8&255|256)<<2)>>2]|0;if((f|0)!=0){a[f+(g&255)|0]=d;m=j;n=m-1|0;c[2440596]=n;return}f=c[k+3152>>2]|0;if((f|0)==0){m=j;n=m-1|0;c[2440596]=n;return}gg[f&4095](g&65535,d);m=c[2440596]|0;n=m-1|0;c[2440596]=n;return}function fUw(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=0;m=i;break}k=gj[d&4095](e)|0;l=k;m=c[2440596]|0}else{l=a[g+(f&255)|0]|0;m=i}}while(0);c[2440596]=m-1;a[9660977]=l;a[9660979]=a[9660979]&125|(l<<24>>24==0?2:l&-128);return}function fUx(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=0;m=i;n=f;o=j;break}k=gj[d&4095](e)|0;l=k;m=c[2440596]|0;n=c[2415243]|0;o=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=f;o=j}}while(0);j=m-1|0;c[2440596]=j;m=n&65535;f=c[o+68+((n>>>8&255|256)<<2)>>2]|0;do{if((f|0)==0){i=c[o+3152>>2]|0;if((i|0)==0){p=j;q=o;break}gg[i&4095](m,l);p=c[2440596]|0;q=c[2443776]|0}else{a[f+(n&255)|0]=l;p=j;q=o}}while(0);o=p-1|0;c[2440596]=o;p=l-1&255;a[9660979]=a[9660979]&125|(p<<24>>24==0?2:p&-128);l=c[2415243]|0;j=c[q+68+((l>>>8&255|256)<<2)>>2]|0;if((j|0)!=0){a[j+(l&255)|0]=p;r=o;s=r-1|0;c[2440596]=s;return}j=c[q+3152>>2]|0;if((j|0)==0){r=o;s=r-1|0;c[2440596]=s;return}gg[j&4095](l&65535,p);r=c[2440596]|0;s=r-1|0;c[2440596]=s;return}function fUy(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=0;m=i;n=f;o=j;break}k=gj[d&4095](e)|0;l=k;m=c[2440596]|0;n=c[2415243]|0;o=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=f;o=j}}while(0);j=m-1|0;c[2440596]=j;m=n&65535;f=c[o+68+((n>>>8&255|256)<<2)>>2]|0;do{if((f|0)==0){i=c[o+3152>>2]|0;if((i|0)==0){p=j;q=o;break}gg[i&4095](m,l);p=c[2440596]|0;q=c[2443776]|0}else{a[f+(n&255)|0]=l;p=j;q=o}}while(0);o=p-1|0;c[2440596]=o;p=l+1&255;a[9660979]=a[9660979]&125|(p<<24>>24==0?2:p&-128);l=c[2415243]|0;j=c[q+68+((l>>>8&255|256)<<2)>>2]|0;if((j|0)!=0){a[j+(l&255)|0]=p;r=o;s=r-1|0;c[2440596]=s;return}j=c[q+3152>>2]|0;if((j|0)==0){r=o;s=r-1|0;c[2440596]=s;return}gg[j&4095](l&65535,p);r=c[2440596]|0;s=r-1|0;c[2440596]=s;return}function fUz(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=f&255;do{if((c[j+68+((f>>>8&255)<<2)>>2]|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=i;m=g;n=j;break}gj[d&4095](e)|0;l=c[2440596]|0;m=a[9660968]|0;n=c[2443776]|0}else{l=i;m=g;n=j}}while(0);j=l-1|0;c[2440596]=j;a[9660968]=m+(a[9660977]|0)&255;m=c[2415242]|0;c[2415243]=m;l=m&65535;g=c[n+68+((m>>>8&255)<<2)>>2]|0;do{if((g|0)==0){i=c[n+3148>>2]|0;if((i|0)==0){o=0;p=j;q=m;r=n;break}e=gj[i&4095](l)|0;o=e;p=c[2440596]|0;q=c[2415243]|0;r=c[2443776]|0}else{o=a[g+(m&255)|0]|0;p=j;q=m;r=n}}while(0);n=p-1|0;c[2440596]=n;p=q&65535;m=c[r+68+((q>>>8&255|256)<<2)>>2]|0;do{if((m|0)==0){j=c[r+3152>>2]|0;if((j|0)==0){s=n;t=r;break}gg[j&4095](p,o);s=c[2440596]|0;t=c[2443776]|0}else{a[m+(q&255)|0]=o;s=n;t=r}}while(0);r=s-1|0;c[2440596]=r;s=o<<1;a[9660979]=(s<<24>>24==0?2:s&-128)|(o&255)>>>7|a[9660979]&124;o=c[2415243]|0;n=c[t+68+((o>>>8&255|256)<<2)>>2]|0;if((n|0)!=0){a[n+(o&255)|0]=s;u=r;v=u-1|0;c[2440596]=v;return}n=c[t+3152>>2]|0;if((n|0)==0){u=r;v=u-1|0;c[2440596]=v;return}gg[n&4095](o&65535,s);u=c[2440596]|0;v=u-1|0;c[2440596]=v;return}function fUA(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=f&255;do{if((c[j+68+((f>>>8&255)<<2)>>2]|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=i;m=g;n=j;break}gj[d&4095](e)|0;l=c[2440596]|0;m=a[9660968]|0;n=c[2443776]|0}else{l=i;m=g;n=j}}while(0);j=l-1|0;c[2440596]=j;a[9660968]=m+(a[9660977]|0)&255;m=c[2415242]|0;c[2415243]=m;l=m&65535;g=c[n+68+((m>>>8&255)<<2)>>2]|0;do{if((g|0)==0){i=c[n+3148>>2]|0;if((i|0)==0){o=0;p=j;q=m;r=n;break}e=gj[i&4095](l)|0;o=e;p=c[2440596]|0;q=c[2415243]|0;r=c[2443776]|0}else{o=a[g+(m&255)|0]|0;p=j;q=m;r=n}}while(0);n=p-1|0;c[2440596]=n;p=q&65535;m=c[r+68+((q>>>8&255|256)<<2)>>2]|0;do{if((m|0)==0){j=c[r+3152>>2]|0;if((j|0)==0){s=n;t=r;break}gg[j&4095](p,o);s=c[2440596]|0;t=c[2443776]|0}else{a[m+(q&255)|0]=o;s=n;t=r}}while(0);r=s-1|0;c[2440596]=r;s=o<<1;n=a[9660979]|0;q=n&1|s;a[9660979]=n&124|(o&255)>>>7|(q<<24>>24==0?2:s&-128);s=c[2415243]|0;o=c[t+68+((s>>>8&255|256)<<2)>>2]|0;if((o|0)!=0){a[o+(s&255)|0]=q;u=r;v=u-1|0;c[2440596]=v;return}o=c[t+3152>>2]|0;if((o|0)==0){u=r;v=u-1|0;c[2440596]=v;return}gg[o&4095](s&65535,q);u=c[2440596]|0;v=u-1|0;c[2440596]=v;return}function fUB(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=f&255;do{if((c[j+68+((f>>>8&255)<<2)>>2]|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=i;m=g;n=j;break}gj[d&4095](e)|0;l=c[2440596]|0;m=a[9660968]|0;n=c[2443776]|0}else{l=i;m=g;n=j}}while(0);j=l-1|0;c[2440596]=j;a[9660968]=m+(a[9660977]|0)&255;m=c[2415242]|0;c[2415243]=m;l=m&65535;g=c[n+68+((m>>>8&255)<<2)>>2]|0;do{if((g|0)==0){i=c[n+3148>>2]|0;if((i|0)==0){o=0;p=j;q=m;r=n;break}e=gj[i&4095](l)|0;o=e;p=c[2440596]|0;q=c[2415243]|0;r=c[2443776]|0}else{o=a[g+(m&255)|0]|0;p=j;q=m;r=n}}while(0);n=p-1|0;c[2440596]=n;p=q&65535;m=c[r+68+((q>>>8&255|256)<<2)>>2]|0;do{if((m|0)==0){j=c[r+3152>>2]|0;if((j|0)==0){s=n;t=r;break}gg[j&4095](p,o);s=c[2440596]|0;t=c[2443776]|0}else{a[m+(q&255)|0]=o;s=n;t=r}}while(0);r=s-1|0;c[2440596]=r;s=a[9660979]&124|o&1;n=(o&255)>>>1;a[9660979]=(n|0)==0?s|2:s;s=c[2415243]|0;o=n&255;n=c[t+68+((s>>>8&255|256)<<2)>>2]|0;if((n|0)!=0){a[n+(s&255)|0]=o;u=r;v=u-1|0;c[2440596]=v;return}n=c[t+3152>>2]|0;if((n|0)==0){u=r;v=u-1|0;c[2440596]=v;return}gg[n&4095](s&65535,o);u=c[2440596]|0;v=u-1|0;c[2440596]=v;return}function fUC(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=f&255;do{if((c[j+68+((f>>>8&255)<<2)>>2]|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=i;m=g;n=j;break}gj[d&4095](e)|0;l=c[2440596]|0;m=a[9660968]|0;n=c[2443776]|0}else{l=i;m=g;n=j}}while(0);j=l-1|0;c[2440596]=j;a[9660968]=m+(a[9660977]|0)&255;m=c[2415242]|0;c[2415243]=m;l=m&65535;g=c[n+68+((m>>>8&255)<<2)>>2]|0;do{if((g|0)==0){i=c[n+3148>>2]|0;if((i|0)==0){o=0;p=j;q=m;r=n;break}e=gj[i&4095](l)|0;o=e;p=c[2440596]|0;q=c[2415243]|0;r=c[2443776]|0}else{o=a[g+(m&255)|0]|0;p=j;q=m;r=n}}while(0);n=o&255;m=p-1|0;c[2440596]=m;p=q&65535;j=c[r+68+((q>>>8&255|256)<<2)>>2]|0;do{if((j|0)==0){g=c[r+3152>>2]|0;if((g|0)==0){s=m;break}gg[g&4095](p,o);s=c[2440596]|0}else{a[j+(q&255)|0]=o;s=m}}while(0);m=s-1|0;c[2440596]=m;s=a[9660979]|0;q=s&-2|o&1;a[9660979]=q;o=((s&255)<<8|n)>>>1;if((o&255|0)==0){t=q&125|2}else{t=(o&128|q&125)&255}a[9660979]=t;t=c[2415243]|0;q=o&255;o=c[2443776]|0;n=c[o+68+((t>>>8&255|256)<<2)>>2]|0;if((n|0)!=0){a[n+(t&255)|0]=q;u=m;v=u-1|0;c[2440596]=v;return}n=c[o+3152>>2]|0;if((n|0)==0){u=m;v=u-1|0;c[2440596]=v;return}gg[n&4095](t&65535,q);u=c[2440596]|0;v=u-1|0;c[2440596]=v;return}function fUD(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=a[9660977]|0;e=b[4830480]|0;b[4830480]=e+1&65535;f=e&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](e)|0;j=l;k=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=g}}while(0);a[9660968]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;g=c[2415242]|0;f=g&65535;h=g&255;do{if((c[k+68+((g>>>8&255)<<2)>>2]|0)==0){e=c[k+3148>>2]|0;if((e|0)==0){m=j;n=h;o=k;break}gj[e&4095](f)|0;m=c[2440596]|0;n=a[9660968]|0;o=c[2443776]|0}else{m=j;n=h;o=k}}while(0);k=m-1|0;c[2440596]=k;a[9660968]=n+(a[9660978]|0)&255;n=c[2415242]|0;c[2415243]=n;m=c[o+68+((n>>>8&255|256)<<2)>>2]|0;if((m|0)!=0){a[m+(n&255)|0]=d;p=k;q=p-1|0;c[2440596]=q;return}m=c[o+3152>>2]|0;if((m|0)==0){p=k;q=p-1|0;c[2440596]=q;return}gg[m&4095](n&65535,d);p=c[2440596]|0;q=p-1|0;c[2440596]=q;return}function fUE(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=f&255;do{if((c[j+68+((f>>>8&255)<<2)>>2]|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=i;m=g;n=j;break}gj[d&4095](e)|0;l=c[2440596]|0;m=a[9660968]|0;n=c[2443776]|0}else{l=i;m=g;n=j}}while(0);j=l-1|0;c[2440596]=j;a[9660968]=m+(a[9660978]|0)&255;m=c[2415242]|0;c[2415243]=m;l=m&65535;g=c[n+68+((m>>>8&255)<<2)>>2]|0;do{if((g|0)==0){i=c[n+3148>>2]|0;if((i|0)==0){o=0;p=j;break}e=gj[i&4095](l)|0;o=e;p=c[2440596]|0}else{o=a[g+(m&255)|0]|0;p=j}}while(0);c[2440596]=p-1;a[9660977]=o;a[9660979]=a[9660979]&125|(o<<24>>24==0?2:o&-128);return}function fUF(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=f&255;do{if((c[j+68+((f>>>8&255)<<2)>>2]|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=i;m=g;n=j;break}gj[d&4095](e)|0;l=c[2440596]|0;m=a[9660968]|0;n=c[2443776]|0}else{l=i;m=g;n=j}}while(0);j=l-1|0;c[2440596]=j;a[9660968]=m+(a[9660977]|0)&255;m=c[2415242]|0;c[2415243]=m;l=m&65535;g=c[n+68+((m>>>8&255)<<2)>>2]|0;do{if((g|0)==0){i=c[n+3148>>2]|0;if((i|0)==0){o=0;p=j;q=m;r=n;break}e=gj[i&4095](l)|0;o=e;p=c[2440596]|0;q=c[2415243]|0;r=c[2443776]|0}else{o=a[g+(m&255)|0]|0;p=j;q=m;r=n}}while(0);n=p-1|0;c[2440596]=n;p=q&65535;m=c[r+68+((q>>>8&255|256)<<2)>>2]|0;do{if((m|0)==0){j=c[r+3152>>2]|0;if((j|0)==0){s=n;t=r;break}gg[j&4095](p,o);s=c[2440596]|0;t=c[2443776]|0}else{a[m+(q&255)|0]=o;s=n;t=r}}while(0);r=s-1|0;c[2440596]=r;s=o-1&255;a[9660979]=a[9660979]&125|(s<<24>>24==0?2:s&-128);o=c[2415243]|0;n=c[t+68+((o>>>8&255|256)<<2)>>2]|0;if((n|0)!=0){a[n+(o&255)|0]=s;u=r;v=u-1|0;c[2440596]=v;return}n=c[t+3152>>2]|0;if((n|0)==0){u=r;v=u-1|0;c[2440596]=v;return}gg[n&4095](o&65535,s);u=c[2440596]|0;v=u-1|0;c[2440596]=v;return}function fUG(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=f&255;do{if((c[j+68+((f>>>8&255)<<2)>>2]|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=i;m=g;n=j;break}gj[d&4095](e)|0;l=c[2440596]|0;m=a[9660968]|0;n=c[2443776]|0}else{l=i;m=g;n=j}}while(0);j=l-1|0;c[2440596]=j;a[9660968]=m+(a[9660977]|0)&255;m=c[2415242]|0;c[2415243]=m;l=m&65535;g=c[n+68+((m>>>8&255)<<2)>>2]|0;do{if((g|0)==0){i=c[n+3148>>2]|0;if((i|0)==0){o=0;p=j;q=m;r=n;break}e=gj[i&4095](l)|0;o=e;p=c[2440596]|0;q=c[2415243]|0;r=c[2443776]|0}else{o=a[g+(m&255)|0]|0;p=j;q=m;r=n}}while(0);n=p-1|0;c[2440596]=n;p=q&65535;m=c[r+68+((q>>>8&255|256)<<2)>>2]|0;do{if((m|0)==0){j=c[r+3152>>2]|0;if((j|0)==0){s=n;t=r;break}gg[j&4095](p,o);s=c[2440596]|0;t=c[2443776]|0}else{a[m+(q&255)|0]=o;s=n;t=r}}while(0);r=s-1|0;c[2440596]=r;s=o+1&255;a[9660979]=a[9660979]&125|(s<<24>>24==0?2:s&-128);o=c[2415243]|0;n=c[t+68+((o>>>8&255|256)<<2)>>2]|0;if((n|0)!=0){a[n+(o&255)|0]=s;u=r;v=u-1|0;c[2440596]=v;return}n=c[t+3152>>2]|0;if((n|0)==0){u=r;v=u-1|0;c[2440596]=v;return}gg[n&4095](o&65535,s);u=c[2440596]|0;v=u-1|0;c[2440596]=v;return}function fUH(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=0;m=i;n=f;o=j;break}k=gj[d&4095](e)|0;l=k;m=c[2440596]|0;n=c[2415243]|0;o=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=f;o=j}}while(0);j=m-1|0;c[2440596]=j;m=n&65535;f=c[o+68+((n>>>8&255|256)<<2)>>2]|0;do{if((f|0)==0){i=c[o+3152>>2]|0;if((i|0)==0){p=j;q=o;break}gg[i&4095](m,l);p=c[2440596]|0;q=c[2443776]|0}else{a[f+(n&255)|0]=l;p=j;q=o}}while(0);o=p-1|0;c[2440596]=o;p=a[9660979]&124;j=l<<1;n=a[9660976]|j;a[9660976]=n;a[9660979]=p|(l&255)>>>7|(n<<24>>24==0?2:n&-128);n=c[2415243]|0;l=c[q+68+((n>>>8&255|256)<<2)>>2]|0;if((l|0)!=0){a[l+(n&255)|0]=j;r=o;s=r-1|0;c[2440596]=s;return}l=c[q+3152>>2]|0;if((l|0)==0){r=o;s=r-1|0;c[2440596]=s;return}gg[l&4095](n&65535,j);r=c[2440596]|0;s=r-1|0;c[2440596]=s;return}function fUI(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=0;m=i;n=f;o=j;break}k=gj[d&4095](e)|0;l=k;m=c[2440596]|0;n=c[2415243]|0;o=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=f;o=j}}while(0);j=m-1|0;c[2440596]=j;m=n&65535;f=c[o+68+((n>>>8&255|256)<<2)>>2]|0;do{if((f|0)==0){i=c[o+3152>>2]|0;if((i|0)==0){p=j;q=o;break}gg[i&4095](m,l);p=c[2440596]|0;q=c[2443776]|0}else{a[f+(n&255)|0]=l;p=j;q=o}}while(0);o=p-1|0;c[2440596]=o;p=a[9660979]|0;j=p&1|l<<1;n=j&a[9660976];a[9660976]=n;a[9660979]=p&124|(l&255)>>>7|(n<<24>>24==0?2:n&-128);n=c[2415243]|0;l=c[q+68+((n>>>8&255|256)<<2)>>2]|0;if((l|0)!=0){a[l+(n&255)|0]=j;r=o;s=r-1|0;c[2440596]=s;return}l=c[q+3152>>2]|0;if((l|0)==0){r=o;s=r-1|0;c[2440596]=s;return}gg[l&4095](n&65535,j);r=c[2440596]|0;s=r-1|0;c[2440596]=s;return}function fUJ(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=b[4830480]|0;b[4830480]=e+1&65535;f=e&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](e)|0;j=l;k=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=g}}while(0);a[9660968]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;g=c[2415242]|0;c[2415243]=g;f=g&65535;h=c[k+68+((g>>>8&255)<<2)>>2]|0;do{if((h|0)==0){e=c[k+3148>>2]|0;if((e|0)==0){m=0;n=j;o=g;p=k;break}l=gj[e&4095](f)|0;m=l;n=c[2440596]|0;o=c[2415243]|0;p=c[2443776]|0}else{m=a[h+(g&255)|0]|0;n=j;o=g;p=k}}while(0);k=n-1|0;c[2440596]=k;n=o&65535;g=c[p+68+((o>>>8&255|256)<<2)>>2]|0;do{if((g|0)==0){j=c[p+3152>>2]|0;if((j|0)==0){q=k;break}gg[j&4095](n,m);q=c[2440596]|0}else{a[g+(o&255)|0]=m;q=k}}while(0);k=q-1|0;c[2440596]=k;q=a[9660979]&-2|m&1;a[9660979]=q;o=(m&255)>>>1;m=d[9660976]|0;g=m^o;a[9660976]=g&255;if((m|0)==(o|0)){r=q&125|2}else{r=(q&125|g&128)&255}a[9660979]=r;r=c[2415243]|0;g=o&255;o=c[2443776]|0;q=c[o+68+((r>>>8&255|256)<<2)>>2]|0;if((q|0)!=0){a[q+(r&255)|0]=g;s=k;t=s-1|0;c[2440596]=t;return}q=c[o+3152>>2]|0;if((q|0)==0){s=k;t=s-1|0;c[2440596]=t;return}gg[q&4095](r&65535,g);s=c[2440596]|0;t=s-1|0;c[2440596]=t;return}function fUK(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;e=b[4830480]|0;b[4830480]=e+1&65535;f=e&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](e)|0;j=l;k=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=g}}while(0);a[9660968]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;g=c[2415242]|0;c[2415243]=g;f=g&65535;h=c[k+68+((g>>>8&255)<<2)>>2]|0;do{if((h|0)==0){e=c[k+3148>>2]|0;if((e|0)==0){m=0;n=j;o=g;p=k;break}l=gj[e&4095](f)|0;m=l;n=c[2440596]|0;o=c[2415243]|0;p=c[2443776]|0}else{m=a[h+(g&255)|0]|0;n=j;o=g;p=k}}while(0);k=m&255;g=n-1|0;c[2440596]=g;n=o&65535;j=c[p+68+((o>>>8&255|256)<<2)>>2]|0;do{if((j|0)==0){h=c[p+3152>>2]|0;if((h|0)==0){q=g;break}gg[h&4095](n,m);q=c[2440596]|0}else{a[j+(o&255)|0]=m;q=g}}while(0);g=q-1|0;c[2440596]=g;q=a[9660979]|0;o=q&-2|m&1;a[9660979]=o;m=((q&255)<<8|k)>>>1;k=o&255;o=k&1;do{if((k&8|0)==0){j=d[9660976]|0;n=(m&255)+o+j|0;p=q&-66;h=(((m^128^j)&128&(n^j)|0)==0?p:p|64)|(n&65280|0)!=0;a[9660979]=h;a[9660976]=n&255;if((n&255|0)==0){a[9660979]=h&125|2;break}else{a[9660979]=(h&125|n&128)&255;break}}else{n=d[9660976]|0;h=(m&15)+o+(n&15)|0;p=(n&240)+(m&240)|0;j=q&60;f=(h+p&255|0)==0?j|2:j;a[9660979]=f;if((h|0)>9){r=h+6|0;s=p+16|0}else{r=h;s=p}if((s&128|0)==0){t=f}else{p=f|-128;a[9660979]=p;t=p}if(((m^128^n)&128&(s^n)|0)==0){u=t}else{n=t|64;a[9660979]=n;u=n}n=(s|0)>144?s+96|0:s;if((n&65280|0)!=0){a[9660979]=u|1}a[9660976]=(n&240|r&15)&255}}while(0);r=c[2415243]|0;u=m&255;m=c[2443776]|0;s=c[m+68+((r>>>8&255|256)<<2)>>2]|0;if((s|0)!=0){a[s+(r&255)|0]=u;v=g;w=v-1|0;c[2440596]=w;return}s=c[m+3152>>2]|0;if((s|0)==0){v=g;w=v-1|0;c[2440596]=w;return}gg[s&4095](r&65535,u);v=c[2440596]|0;w=v-1|0;c[2440596]=w;return}function fUL(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=a[9660977]&a[9660976];e=b[4830480]|0;b[4830480]=e+1&65535;f=e&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](e)|0;j=l;k=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=g}}while(0);a[9660968]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;g=c[2415242]|0;c[2415243]=g;f=c[k+68+((g>>>8&255|256)<<2)>>2]|0;if((f|0)!=0){a[f+(g&255)|0]=d;m=j;n=m-1|0;c[2440596]=n;return}f=c[k+3152>>2]|0;if((f|0)==0){m=j;n=m-1|0;c[2440596]=n;return}gg[f&4095](g&65535,d);m=c[2440596]|0;n=m-1|0;c[2440596]=n;return}function fUM(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=0;m=i;break}k=gj[d&4095](e)|0;l=k;m=c[2440596]|0}else{l=a[g+(f&255)|0]|0;m=i}}while(0);c[2440596]=m-1;a[9660977]=l;a[9660976]=l;a[9660979]=a[9660979]&125|(l<<24>>24==0?2:l&-128);return}function fUN(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=0;m=i;n=f;o=j;break}k=gj[d&4095](e)|0;l=k;m=c[2440596]|0;n=c[2415243]|0;o=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=f;o=j}}while(0);j=m-1|0;c[2440596]=j;m=n&65535;f=c[o+68+((n>>>8&255|256)<<2)>>2]|0;do{if((f|0)==0){i=c[o+3152>>2]|0;if((i|0)==0){p=j;break}gg[i&4095](m,l);p=c[2440596]|0}else{a[f+(n&255)|0]=l;p=j}}while(0);j=p-1|0;c[2440596]=j;p=l-1&255;l=a[9660979]|0;n=l&-2;a[9660979]=n;f=a[9660976]|0;if((f&255)<(p&255)){q=n}else{n=l|1;a[9660979]=n;q=n}if(f<<24>>24==p<<24>>24){r=q&125|2}else{r=q&125|f-p&255&-128}a[9660979]=r;r=c[2415243]|0;f=c[2443776]|0;q=c[f+68+((r>>>8&255|256)<<2)>>2]|0;if((q|0)!=0){a[q+(r&255)|0]=p;s=j;t=s-1|0;c[2440596]=t;return}q=c[f+3152>>2]|0;if((q|0)==0){s=j;t=s-1|0;c[2440596]=t;return}gg[q&4095](r&65535,p);s=c[2440596]|0;t=s-1|0;c[2440596]=t;return}function fUO(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=0;m=i;n=f;o=j;break}k=gj[d&4095](e)|0;l=k;m=c[2440596]|0;n=c[2415243]|0;o=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=f;o=j}}while(0);j=m-1|0;c[2440596]=j;m=n&65535;f=c[o+68+((n>>>8&255|256)<<2)>>2]|0;do{if((f|0)==0){i=c[o+3152>>2]|0;if((i|0)==0){p=j;break}gg[i&4095](m,l);p=c[2440596]|0}else{a[f+(n&255)|0]=l;p=j}}while(0);j=p-1|0;c[2440596]=j;p=l+1&255;l=p&255;n=a[9660979]|0;f=n&255;m=f&1^1;o=a[9660976]|0;i=o&255;g=i-l-m|0;do{if((f&8|0)==0){e=n&-66;k=(((o^p)&128&(g^i)|0)==0?e:e|64)|(g&65280|0)==0;a[9660979]=k;a[9660976]=g&255;if((g&255|0)==0){a[9660979]=k&125|2;break}else{a[9660979]=(k&125|g&128)&255;break}}else{k=(i&15)-(l&15)-m|0;e=(i&240)-(l&240)|0;if((k&16|0)==0){q=k;r=e}else{q=k-6|0;r=e-1|0}e=n&60;k=(((o^p)&128&(g^i)|0)==0?e:e|64)|(g&65280|0)==0;e=(g&255|0)==0?k|2:k;a[9660979]=(g&128|0)==0?e:e|-128;a[9660976]=(((r&256|0)==0?r:r+160|0)&240|q&15)&255}}while(0);q=c[2415243]|0;r=c[2443776]|0;g=c[r+68+((q>>>8&255|256)<<2)>>2]|0;if((g|0)!=0){a[g+(q&255)|0]=p;s=j;t=s-1|0;c[2440596]=t;return}g=c[r+3152>>2]|0;if((g|0)==0){s=j;t=s-1|0;c[2440596]=t;return}gg[g&4095](q&65535,p);s=c[2440596]|0;t=s-1|0;c[2440596]=t;return}function fUP(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=f&255;do{if((c[j+68+((f>>>8&255)<<2)>>2]|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=i;m=g;n=j;break}gj[d&4095](e)|0;l=c[2440596]|0;m=a[9660968]|0;n=c[2443776]|0}else{l=i;m=g;n=j}}while(0);j=l-1|0;c[2440596]=j;a[9660968]=m+(a[9660977]|0)&255;m=c[2415242]|0;c[2415243]=m;l=m&65535;g=c[n+68+((m>>>8&255)<<2)>>2]|0;do{if((g|0)==0){i=c[n+3148>>2]|0;if((i|0)==0){o=0;p=j;q=m;r=n;break}e=gj[i&4095](l)|0;o=e;p=c[2440596]|0;q=c[2415243]|0;r=c[2443776]|0}else{o=a[g+(m&255)|0]|0;p=j;q=m;r=n}}while(0);n=p-1|0;c[2440596]=n;p=q&65535;m=c[r+68+((q>>>8&255|256)<<2)>>2]|0;do{if((m|0)==0){j=c[r+3152>>2]|0;if((j|0)==0){s=n;t=r;break}gg[j&4095](p,o);s=c[2440596]|0;t=c[2443776]|0}else{a[m+(q&255)|0]=o;s=n;t=r}}while(0);r=s-1|0;c[2440596]=r;s=a[9660979]&124;n=o<<1;q=a[9660976]|n;a[9660976]=q;a[9660979]=s|(o&255)>>>7|(q<<24>>24==0?2:q&-128);q=c[2415243]|0;o=c[t+68+((q>>>8&255|256)<<2)>>2]|0;if((o|0)!=0){a[o+(q&255)|0]=n;u=r;v=u-1|0;c[2440596]=v;return}o=c[t+3152>>2]|0;if((o|0)==0){u=r;v=u-1|0;c[2440596]=v;return}gg[o&4095](q&65535,n);u=c[2440596]|0;v=u-1|0;c[2440596]=v;return}function fUQ(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=f&255;do{if((c[j+68+((f>>>8&255)<<2)>>2]|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=i;m=g;n=j;break}gj[d&4095](e)|0;l=c[2440596]|0;m=a[9660968]|0;n=c[2443776]|0}else{l=i;m=g;n=j}}while(0);j=l-1|0;c[2440596]=j;a[9660968]=m+(a[9660977]|0)&255;m=c[2415242]|0;c[2415243]=m;l=m&65535;g=c[n+68+((m>>>8&255)<<2)>>2]|0;do{if((g|0)==0){i=c[n+3148>>2]|0;if((i|0)==0){o=0;p=j;q=m;r=n;break}e=gj[i&4095](l)|0;o=e;p=c[2440596]|0;q=c[2415243]|0;r=c[2443776]|0}else{o=a[g+(m&255)|0]|0;p=j;q=m;r=n}}while(0);n=p-1|0;c[2440596]=n;p=q&65535;m=c[r+68+((q>>>8&255|256)<<2)>>2]|0;do{if((m|0)==0){j=c[r+3152>>2]|0;if((j|0)==0){s=n;t=r;break}gg[j&4095](p,o);s=c[2440596]|0;t=c[2443776]|0}else{a[m+(q&255)|0]=o;s=n;t=r}}while(0);r=s-1|0;c[2440596]=r;s=a[9660979]|0;n=s&1|o<<1;q=n&a[9660976];a[9660976]=q;a[9660979]=s&124|(o&255)>>>7|(q<<24>>24==0?2:q&-128);q=c[2415243]|0;o=c[t+68+((q>>>8&255|256)<<2)>>2]|0;if((o|0)!=0){a[o+(q&255)|0]=n;u=r;v=u-1|0;c[2440596]=v;return}o=c[t+3152>>2]|0;if((o|0)==0){u=r;v=u-1|0;c[2440596]=v;return}gg[o&4095](q&65535,n);u=c[2440596]|0;v=u-1|0;c[2440596]=v;return}function fUR(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;e=b[4830480]|0;b[4830480]=e+1&65535;f=e&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](e)|0;j=l;k=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=g}}while(0);a[9660968]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;g=c[2415242]|0;f=g&65535;h=g&255;do{if((c[k+68+((g>>>8&255)<<2)>>2]|0)==0){e=c[k+3148>>2]|0;if((e|0)==0){m=j;n=h;o=k;break}gj[e&4095](f)|0;m=c[2440596]|0;n=a[9660968]|0;o=c[2443776]|0}else{m=j;n=h;o=k}}while(0);k=m-1|0;c[2440596]=k;a[9660968]=n+(a[9660977]|0)&255;n=c[2415242]|0;c[2415243]=n;m=n&65535;h=c[o+68+((n>>>8&255)<<2)>>2]|0;do{if((h|0)==0){j=c[o+3148>>2]|0;if((j|0)==0){p=0;q=k;r=n;s=o;break}f=gj[j&4095](m)|0;p=f;q=c[2440596]|0;r=c[2415243]|0;s=c[2443776]|0}else{p=a[h+(n&255)|0]|0;q=k;r=n;s=o}}while(0);o=q-1|0;c[2440596]=o;q=r&65535;n=c[s+68+((r>>>8&255|256)<<2)>>2]|0;do{if((n|0)==0){k=c[s+3152>>2]|0;if((k|0)==0){t=o;break}gg[k&4095](q,p);t=c[2440596]|0}else{a[n+(r&255)|0]=p;t=o}}while(0);o=t-1|0;c[2440596]=o;t=a[9660979]&-2|p&1;a[9660979]=t;r=(p&255)>>>1;p=d[9660976]|0;n=p^r;a[9660976]=n&255;if((p|0)==(r|0)){u=t&125|2}else{u=(t&125|n&128)&255}a[9660979]=u;u=c[2415243]|0;n=r&255;r=c[2443776]|0;t=c[r+68+((u>>>8&255|256)<<2)>>2]|0;if((t|0)!=0){a[t+(u&255)|0]=n;v=o;w=v-1|0;c[2440596]=w;return}t=c[r+3152>>2]|0;if((t|0)==0){v=o;w=v-1|0;c[2440596]=w;return}gg[t&4095](u&65535,n);v=c[2440596]|0;w=v-1|0;c[2440596]=w;return}function fUS(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;e=b[4830480]|0;b[4830480]=e+1&65535;f=e&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](e)|0;j=l;k=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=g}}while(0);a[9660968]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;g=c[2415242]|0;f=g&65535;h=g&255;do{if((c[k+68+((g>>>8&255)<<2)>>2]|0)==0){e=c[k+3148>>2]|0;if((e|0)==0){m=j;n=h;o=k;break}gj[e&4095](f)|0;m=c[2440596]|0;n=a[9660968]|0;o=c[2443776]|0}else{m=j;n=h;o=k}}while(0);k=m-1|0;c[2440596]=k;a[9660968]=n+(a[9660977]|0)&255;n=c[2415242]|0;c[2415243]=n;m=n&65535;h=c[o+68+((n>>>8&255)<<2)>>2]|0;do{if((h|0)==0){j=c[o+3148>>2]|0;if((j|0)==0){p=0;q=k;r=n;s=o;break}f=gj[j&4095](m)|0;p=f;q=c[2440596]|0;r=c[2415243]|0;s=c[2443776]|0}else{p=a[h+(n&255)|0]|0;q=k;r=n;s=o}}while(0);o=p&255;n=q-1|0;c[2440596]=n;q=r&65535;k=c[s+68+((r>>>8&255|256)<<2)>>2]|0;do{if((k|0)==0){h=c[s+3152>>2]|0;if((h|0)==0){t=n;break}gg[h&4095](q,p);t=c[2440596]|0}else{a[k+(r&255)|0]=p;t=n}}while(0);n=t-1|0;c[2440596]=n;t=a[9660979]|0;r=t&-2|p&1;a[9660979]=r;p=((t&255)<<8|o)>>>1;o=r&255;r=o&1;do{if((o&8|0)==0){k=d[9660976]|0;q=(p&255)+r+k|0;s=t&-66;h=(((p^128^k)&128&(q^k)|0)==0?s:s|64)|(q&65280|0)!=0;a[9660979]=h;a[9660976]=q&255;if((q&255|0)==0){a[9660979]=h&125|2;break}else{a[9660979]=(h&125|q&128)&255;break}}else{q=d[9660976]|0;h=(p&15)+r+(q&15)|0;s=(q&240)+(p&240)|0;k=t&60;m=(h+s&255|0)==0?k|2:k;a[9660979]=m;if((h|0)>9){u=h+6|0;v=s+16|0}else{u=h;v=s}if((v&128|0)==0){w=m}else{s=m|-128;a[9660979]=s;w=s}if(((p^128^q)&128&(v^q)|0)==0){x=w}else{q=w|64;a[9660979]=q;x=q}q=(v|0)>144?v+96|0:v;if((q&65280|0)!=0){a[9660979]=x|1}a[9660976]=(q&240|u&15)&255}}while(0);u=c[2415243]|0;x=p&255;p=c[2443776]|0;v=c[p+68+((u>>>8&255|256)<<2)>>2]|0;if((v|0)!=0){a[v+(u&255)|0]=x;y=n;z=y-1|0;c[2440596]=z;return}v=c[p+3152>>2]|0;if((v|0)==0){y=n;z=y-1|0;c[2440596]=z;return}gg[v&4095](u&65535,x);y=c[2440596]|0;z=y-1|0;c[2440596]=z;return}function fUT(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=a[9660977]&a[9660976];e=b[4830480]|0;b[4830480]=e+1&65535;f=e&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](e)|0;j=l;k=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=g}}while(0);a[9660968]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;g=c[2415242]|0;f=g&65535;h=g&255;do{if((c[k+68+((g>>>8&255)<<2)>>2]|0)==0){e=c[k+3148>>2]|0;if((e|0)==0){m=j;n=h;o=k;break}gj[e&4095](f)|0;m=c[2440596]|0;n=a[9660968]|0;o=c[2443776]|0}else{m=j;n=h;o=k}}while(0);k=m-1|0;c[2440596]=k;a[9660968]=n+(a[9660978]|0)&255;n=c[2415242]|0;c[2415243]=n;m=c[o+68+((n>>>8&255|256)<<2)>>2]|0;if((m|0)!=0){a[m+(n&255)|0]=d;p=k;q=p-1|0;c[2440596]=q;return}m=c[o+3152>>2]|0;if((m|0)==0){p=k;q=p-1|0;c[2440596]=q;return}gg[m&4095](n&65535,d);p=c[2440596]|0;q=p-1|0;c[2440596]=q;return}function fUU(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=f&255;do{if((c[j+68+((f>>>8&255)<<2)>>2]|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=i;m=g;n=j;break}gj[d&4095](e)|0;l=c[2440596]|0;m=a[9660968]|0;n=c[2443776]|0}else{l=i;m=g;n=j}}while(0);j=l-1|0;c[2440596]=j;a[9660968]=m+(a[9660978]|0)&255;m=c[2415242]|0;c[2415243]=m;l=m&65535;g=c[n+68+((m>>>8&255)<<2)>>2]|0;do{if((g|0)==0){i=c[n+3148>>2]|0;if((i|0)==0){o=0;p=j;break}e=gj[i&4095](l)|0;o=e;p=c[2440596]|0}else{o=a[g+(m&255)|0]|0;p=j}}while(0);c[2440596]=p-1;a[9660977]=o;a[9660976]=o;a[9660979]=a[9660979]&125|(o<<24>>24==0?2:o&-128);return}function fUV(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=f&255;do{if((c[j+68+((f>>>8&255)<<2)>>2]|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=i;m=g;n=j;break}gj[d&4095](e)|0;l=c[2440596]|0;m=a[9660968]|0;n=c[2443776]|0}else{l=i;m=g;n=j}}while(0);j=l-1|0;c[2440596]=j;a[9660968]=m+(a[9660977]|0)&255;m=c[2415242]|0;c[2415243]=m;l=m&65535;g=c[n+68+((m>>>8&255)<<2)>>2]|0;do{if((g|0)==0){i=c[n+3148>>2]|0;if((i|0)==0){o=0;p=j;q=m;r=n;break}e=gj[i&4095](l)|0;o=e;p=c[2440596]|0;q=c[2415243]|0;r=c[2443776]|0}else{o=a[g+(m&255)|0]|0;p=j;q=m;r=n}}while(0);n=p-1|0;c[2440596]=n;p=q&65535;m=c[r+68+((q>>>8&255|256)<<2)>>2]|0;do{if((m|0)==0){j=c[r+3152>>2]|0;if((j|0)==0){s=n;break}gg[j&4095](p,o);s=c[2440596]|0}else{a[m+(q&255)|0]=o;s=n}}while(0);n=s-1|0;c[2440596]=n;s=o-1&255;o=a[9660979]|0;q=o&-2;a[9660979]=q;m=a[9660976]|0;if((m&255)<(s&255)){t=q}else{q=o|1;a[9660979]=q;t=q}if(m<<24>>24==s<<24>>24){u=t&125|2}else{u=t&125|m-s&255&-128}a[9660979]=u;u=c[2415243]|0;m=c[2443776]|0;t=c[m+68+((u>>>8&255|256)<<2)>>2]|0;if((t|0)!=0){a[t+(u&255)|0]=s;v=n;w=v-1|0;c[2440596]=w;return}t=c[m+3152>>2]|0;if((t|0)==0){v=n;w=v-1|0;c[2440596]=w;return}gg[t&4095](u&65535,s);v=c[2440596]|0;w=v-1|0;c[2440596]=w;return}function fUW(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=f&255;do{if((c[j+68+((f>>>8&255)<<2)>>2]|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=i;m=g;n=j;break}gj[d&4095](e)|0;l=c[2440596]|0;m=a[9660968]|0;n=c[2443776]|0}else{l=i;m=g;n=j}}while(0);j=l-1|0;c[2440596]=j;a[9660968]=m+(a[9660977]|0)&255;m=c[2415242]|0;c[2415243]=m;l=m&65535;g=c[n+68+((m>>>8&255)<<2)>>2]|0;do{if((g|0)==0){i=c[n+3148>>2]|0;if((i|0)==0){o=0;p=j;q=m;r=n;break}e=gj[i&4095](l)|0;o=e;p=c[2440596]|0;q=c[2415243]|0;r=c[2443776]|0}else{o=a[g+(m&255)|0]|0;p=j;q=m;r=n}}while(0);n=p-1|0;c[2440596]=n;p=q&65535;m=c[r+68+((q>>>8&255|256)<<2)>>2]|0;do{if((m|0)==0){j=c[r+3152>>2]|0;if((j|0)==0){s=n;break}gg[j&4095](p,o);s=c[2440596]|0}else{a[m+(q&255)|0]=o;s=n}}while(0);n=s-1|0;c[2440596]=n;s=o+1&255;o=s&255;q=a[9660979]|0;m=q&255;p=m&1^1;r=a[9660976]|0;j=r&255;g=j-o-p|0;do{if((m&8|0)==0){l=q&-66;e=(((r^s)&128&(g^j)|0)==0?l:l|64)|(g&65280|0)==0;a[9660979]=e;a[9660976]=g&255;if((g&255|0)==0){a[9660979]=e&125|2;break}else{a[9660979]=(e&125|g&128)&255;break}}else{e=(j&15)-(o&15)-p|0;l=(j&240)-(o&240)|0;if((e&16|0)==0){t=e;u=l}else{t=e-6|0;u=l-1|0}l=q&60;e=(((r^s)&128&(g^j)|0)==0?l:l|64)|(g&65280|0)==0;l=(g&255|0)==0?e|2:e;a[9660979]=(g&128|0)==0?l:l|-128;a[9660976]=(((u&256|0)==0?u:u+160|0)&240|t&15)&255}}while(0);t=c[2415243]|0;u=c[2443776]|0;g=c[u+68+((t>>>8&255|256)<<2)>>2]|0;if((g|0)!=0){a[g+(t&255)|0]=s;v=n;w=v-1|0;c[2440596]=w;return}g=c[u+3152>>2]|0;if((g|0)==0){v=n;w=v-1|0;c[2440596]=w;return}gg[g&4095](t&65535,s);v=c[2440596]|0;w=v-1|0;c[2440596]=w;return}function fUX(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=b[4830480]|0;e=c[2443776]|0;do{if((c[e+68+((d&65535)>>>8<<2)>>2]|0)==0){f=c[e+3148>>2]|0;if((f|0)==0){g=e;break}gj[f&4095](d)|0;g=c[2443776]|0}else{g=e}}while(0);e=(c[2440596]|0)-1|0;c[2440596]=e;d=c[2415241]|0;f=d&65535;h=a[9660979]|0;i=c[g+68+((d>>>8&255|256)<<2)>>2]|0;do{if((i|0)==0){j=c[g+3152>>2]|0;if((j|0)==0){k=e;break}gg[j&4095](f,h);k=c[2440596]|0}else{a[i+(d&255)|0]=h;k=e}}while(0);c[2440596]=k-1;a[9660964]=(a[9660964]|0)-1&255;return}function fUY(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=b[4830480]|0;e=c[2443776]|0;do{if((c[e+68+((d&65535)>>>8<<2)>>2]|0)==0){f=c[e+3148>>2]|0;if((f|0)==0){g=e;break}gj[f&4095](d)|0;g=c[2443776]|0}else{g=e}}while(0);e=(c[2440596]|0)-1|0;c[2440596]=e;d=c[2415241]|0;f=d&65535;h=d&255;do{if((c[g+68+((d>>>8&255)<<2)>>2]|0)==0){i=c[g+3148>>2]|0;if((i|0)==0){j=e;k=h;l=g;break}gj[i&4095](f)|0;j=c[2440596]|0;k=a[9660964]|0;l=c[2443776]|0}else{j=e;k=h;l=g}}while(0);g=j-1|0;c[2440596]=g;j=(a[9660979]&4)==0;a[9660964]=k+1&255;k=c[2415241]|0;h=k&65535;e=c[l+68+((k>>>8&255)<<2)>>2]|0;do{if((e|0)==0){f=c[l+3148>>2]|0;if((f|0)==0){m=0;n=g;break}d=gj[f&4095](h)|0;m=d;n=c[2440596]|0}else{m=a[e+(k&255)|0]|0;n=g}}while(0);a[9660979]=m;c[2440596]=n-1;if(j|(a[9660983]|0)==0){o=m|48;a[9660979]=o;return}if((m&4)!=0){o=m|48;a[9660979]=o;return}a[9660981]=1;o=m|48;a[9660979]=o;return}function fUZ(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=b[4830480]|0;e=c[2443776]|0;do{if((c[e+68+((d&65535)>>>8<<2)>>2]|0)==0){f=c[e+3148>>2]|0;if((f|0)==0){g=e;break}gj[f&4095](d)|0;g=c[2443776]|0}else{g=e}}while(0);e=(c[2440596]|0)-1|0;c[2440596]=e;d=c[2415241]|0;f=d&65535;h=a[9660976]|0;i=c[g+68+((d>>>8&255|256)<<2)>>2]|0;do{if((i|0)==0){j=c[g+3152>>2]|0;if((j|0)==0){k=e;break}gg[j&4095](f,h);k=c[2440596]|0}else{a[i+(d&255)|0]=h;k=e}}while(0);c[2440596]=k-1;a[9660964]=(a[9660964]|0)-1&255;return}function fU_(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=b[4830480]|0;e=c[2443776]|0;do{if((c[e+68+((d&65535)>>>8<<2)>>2]|0)==0){f=c[e+3148>>2]|0;if((f|0)==0){g=e;break}gj[f&4095](d)|0;g=c[2443776]|0}else{g=e}}while(0);e=(c[2440596]|0)-1|0;c[2440596]=e;d=c[2415241]|0;f=d&65535;h=d&255;do{if((c[g+68+((d>>>8&255)<<2)>>2]|0)==0){i=c[g+3148>>2]|0;if((i|0)==0){j=e;k=h;l=g;break}gj[i&4095](f)|0;j=c[2440596]|0;k=a[9660964]|0;l=c[2443776]|0}else{j=e;k=h;l=g}}while(0);g=j-1|0;c[2440596]=g;a[9660964]=k+1&255;k=c[2415241]|0;j=k&65535;h=c[l+68+((k>>>8&255)<<2)>>2]|0;do{if((h|0)==0){e=c[l+3148>>2]|0;if((e|0)==0){m=0;n=g;break}f=gj[e&4095](j)|0;m=f;n=c[2440596]|0}else{m=a[h+(k&255)|0]|0;n=g}}while(0);a[9660976]=m;c[2440596]=n-1;a[9660979]=a[9660979]&125|(m<<24>>24==0?2:m&-128);return}function fU$(){var d=0,e=0,f=0;d=b[4830480]|0;e=c[2443776]|0;do{if((c[e+68+((d&65535)>>>8<<2)>>2]|0)==0){f=c[e+3148>>2]|0;if((f|0)==0){break}gj[f&4095](d)|0}}while(0);c[2440596]=(c[2440596]|0)-1;d=(a[9660978]|0)-1&255;a[9660978]=d;a[9660979]=(d<<24>>24==0?2:d&-128)|a[9660979]&125;return}function fU0(){var d=0,e=0,f=0;d=b[4830480]|0;e=c[2443776]|0;do{if((c[e+68+((d&65535)>>>8<<2)>>2]|0)==0){f=c[e+3148>>2]|0;if((f|0)==0){break}gj[f&4095](d)|0}}while(0);c[2440596]=(c[2440596]|0)-1;d=a[9660976]|0;a[9660978]=d;a[9660979]=a[9660979]&125|(d<<24>>24==0?2:d&-128);return}function fU1(){var d=0,e=0,f=0;d=b[4830480]|0;e=c[2443776]|0;do{if((c[e+68+((d&65535)>>>8<<2)>>2]|0)==0){f=c[e+3148>>2]|0;if((f|0)==0){break}gj[f&4095](d)|0}}while(0);c[2440596]=(c[2440596]|0)-1;d=(a[9660978]|0)+1&255;a[9660978]=d;a[9660979]=(d<<24>>24==0?2:d&-128)|a[9660979]&125;return}function fU2(){var d=0,e=0,f=0;d=b[4830480]|0;e=c[2443776]|0;do{if((c[e+68+((d&65535)>>>8<<2)>>2]|0)==0){f=c[e+3148>>2]|0;if((f|0)==0){break}gj[f&4095](d)|0}}while(0);c[2440596]=(c[2440596]|0)-1;d=(a[9660977]|0)+1&255;a[9660977]=d;a[9660979]=(d<<24>>24==0?2:d&-128)|a[9660979]&125;return}function fU3(){var d=0,e=0,f=0;d=b[4830480]|0;e=c[2443776]|0;do{if((c[e+68+((d&65535)>>>8<<2)>>2]|0)==0){f=c[e+3148>>2]|0;if((f|0)==0){break}gj[f&4095](d)|0}}while(0);c[2440596]=(c[2440596]|0)-1;a[9660979]=a[9660979]&-2;return}function fU4(){var d=0,e=0,f=0;d=b[4830480]|0;e=c[2443776]|0;do{if((c[e+68+((d&65535)>>>8<<2)>>2]|0)==0){f=c[e+3148>>2]|0;if((f|0)==0){break}gj[f&4095](d)|0}}while(0);c[2440596]=(c[2440596]|0)-1;a[9660979]=a[9660979]|1;return}function fU5(){var d=0,e=0,f=0,g=0;d=b[4830480]|0;e=c[2443776]|0;do{if((c[e+68+((d&65535)>>>8<<2)>>2]|0)==0){f=c[e+3148>>2]|0;if((f|0)==0){break}gj[f&4095](d)|0}}while(0);c[2440596]=(c[2440596]|0)-1;d=a[9660979]|0;if((a[9660983]|0)==0){g=d&-5;a[9660979]=g;return}if((d&4)==0){g=d&-5;a[9660979]=g;return}a[9660981]=1;g=d&-5;a[9660979]=g;return}function fU6(){var d=0,e=0,f=0;d=b[4830480]|0;e=c[2443776]|0;do{if((c[e+68+((d&65535)>>>8<<2)>>2]|0)==0){f=c[e+3148>>2]|0;if((f|0)==0){break}gj[f&4095](d)|0}}while(0);c[2440596]=(c[2440596]|0)-1;a[9660979]=a[9660979]|4;return}function fU7(){var d=0,e=0,f=0;d=b[4830480]|0;e=c[2443776]|0;do{if((c[e+68+((d&65535)>>>8<<2)>>2]|0)==0){f=c[e+3148>>2]|0;if((f|0)==0){break}gj[f&4095](d)|0}}while(0);c[2440596]=(c[2440596]|0)-1;d=a[9660978]|0;a[9660976]=d;a[9660979]=a[9660979]&125|(d<<24>>24==0?2:d&-128);return}function fU8(){var d=0,e=0,f=0;d=b[4830480]|0;e=c[2443776]|0;do{if((c[e+68+((d&65535)>>>8<<2)>>2]|0)==0){f=c[e+3148>>2]|0;if((f|0)==0){break}gj[f&4095](d)|0}}while(0);c[2440596]=(c[2440596]|0)-1;a[9660979]=a[9660979]&-65;return}function fU9(){var d=0,e=0,f=0;d=b[4830480]|0;e=c[2443776]|0;do{if((c[e+68+((d&65535)>>>8<<2)>>2]|0)==0){f=c[e+3148>>2]|0;if((f|0)==0){break}gj[f&4095](d)|0}}while(0);c[2440596]=(c[2440596]|0)-1;a[9660979]=a[9660979]&-9;return}function fVa(){var d=0,e=0,f=0;d=b[4830480]|0;e=c[2443776]|0;do{if((c[e+68+((d&65535)>>>8<<2)>>2]|0)==0){f=c[e+3148>>2]|0;if((f|0)==0){break}gj[f&4095](d)|0}}while(0);c[2440596]=(c[2440596]|0)-1;a[9660979]=a[9660979]|8;return}function fVb(){var d=0,e=0,f=0,g=0,h=0,i=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(e&255)|0]|0}}while(0);c[2440596]=(c[2440596]|0)-1;e=a[9660976]|i;a[9660976]=e;a[9660979]=(e<<24>>24==0?2:e&-128)|a[9660979]&125;return}function fVc(){var d=0,e=0,f=0,g=0,h=0,i=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(e&255)|0]|0}}while(0);c[2440596]=(c[2440596]|0)-1;e=a[9660976]&i;a[9660976]=e;a[9660979]=(e<<24>>24==0?2:e&-128)|a[9660979]&125;return}function fVd(){var d=0,e=0,f=0,g=0,h=0,i=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(e&255)|0]|0}}while(0);c[2440596]=(c[2440596]|0)-1;e=a[9660976]|0;g=e^i;a[9660976]=g;a[9660979]=(e<<24>>24==i<<24>>24?2:g&-128)|a[9660979]&125;return}function fVe(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(e&255)|0]|0}}while(0);e=i&255;c[2440596]=(c[2440596]|0)-1;g=a[9660979]|0;d=g&255;f=d&1;h=a[9660976]|0;j=h&255;if((d&8|0)==0){d=j+e+f|0;k=g&-66;l=((((h^i)&128^128)&(d^j)|0)==0?k:k|64)|(d&65280|0)!=0;a[9660979]=l;a[9660976]=d&255;if((d&255|0)==0){a[9660979]=l&125|2;return}else{a[9660979]=(l&125|d&128)&255;return}}d=f+(e&15)+(j&15)|0;f=(j&240)+(e&240)|0;e=g&60;g=(d+f&255|0)==0?e|2:e;a[9660979]=g;if((d|0)>9){m=d+6|0;n=f+16|0}else{m=d;n=f}if((n&128|0)==0){o=g}else{f=g|-128;a[9660979]=f;o=f}if((((h^i)&128^128)&(n^j)|0)==0){p=o}else{j=o|64;a[9660979]=j;p=j}j=(n|0)>144?n+96|0:n;if((j&65280|0)!=0){a[9660979]=p|1}a[9660976]=(j&240|m&15)&255;return}function fVf(){var a=0,d=0,e=0;a=b[4830480]|0;b[4830480]=a+1&65535;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3168>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function fVg(){var d=0,e=0,f=0,g=0,h=0,i=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(e&255)|0]|0}}while(0);c[2440596]=(c[2440596]|0)-1;a[9660976]=i;a[9660979]=a[9660979]&125|(i<<24>>24==0?2:i&-128);return}function fVh(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(e&255)|0]|0}}while(0);c[2440596]=(c[2440596]|0)-1;e=a[9660979]|0;g=e&-2;a[9660979]=g;d=a[9660976]|0;if((d&255)<(i&255)){j=g}else{g=e|1;a[9660979]=g;j=g}if(d<<24>>24==i<<24>>24){k=j&125|2;a[9660979]=k;return}else{k=j&125|d-i&255&-128;a[9660979]=k;return}}function fVi(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(e&255)|0]|0}}while(0);e=i&255;c[2440596]=(c[2440596]|0)-1;g=a[9660979]|0;d=g&255;f=d&1^1;h=a[9660976]|0;j=h&255;k=j-e-f|0;if((d&8|0)!=0){d=(j&15)-(e&15)-f|0;f=(j&240)-(e&240)|0;if((d&16|0)==0){l=d;m=f}else{l=d-6|0;m=f-1|0}f=g&60;d=(((h^i)&128&(k^j)|0)==0?f:f|64)|(k&65280|0)==0;f=(k&255|0)==0?d|2:d;a[9660979]=(k&128|0)==0?f:f|-128;a[9660976]=(((m&256|0)==0?m:m+160|0)&240|l&15)&255;return}l=g&-66;g=(((h^i)&128&(k^j)|0)==0?l:l|64)|(k&65280|0)==0;a[9660979]=g;a[9660976]=k&255;if((k&255|0)==0){a[9660979]=g&125|2;return}else{a[9660979]=(g&125|k&128)&255;return}}function fVj(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;g=(c[2440596]|0)-1|0;c[2440596]=g;b[4830480]=k+1&65535;e=k&65535;f=c[l+68+(e>>>8<<2)>>2]|0;do{if((f|0)==0){h=c[l+3168>>2]|0;if((h|0)==0){n=0;o=g;p=j;break}d=gj[h&4095](k)|0;n=d;o=c[2440596]|0;p=a[9660972]|0}else{n=a[f+(e&255)|0]|0;o=g;p=j}}while(0);a[9660973]=n;j=o-1|0;c[2440596]=j;o=a[9660978]|0;g=(o&255)+(p&255)|0;if((g|0)>255){p=n&255;n=(g&255|p<<8)&65535;g=c[2443776]|0;do{if((c[g+68+(p<<2)>>2]|0)==0){e=c[g+3148>>2]|0;if((e|0)==0){q=j;r=o;break}gj[e&4095](n)|0;q=c[2440596]|0;r=a[9660978]|0}else{q=j;r=o}}while(0);n=q-1|0;c[2440596]=n;s=r;t=n}else{s=o;t=j}b[4830486]=(b[4830486]|0)+(s&255)&65535;s=c[2415243]|0;j=s&65535;o=c[2443776]|0;n=c[o+68+((s>>>8&255)<<2)>>2]|0;do{if((n|0)==0){r=c[o+3148>>2]|0;if((r|0)==0){u=0;v=t;break}q=gj[r&4095](j)|0;u=q;v=c[2440596]|0}else{u=a[n+(s&255)|0]|0;v=t}}while(0);c[2440596]=v-1;v=a[9660976]|u;a[9660976]=v;a[9660979]=(v<<24>>24==0?2:v&-128)|a[9660979]&125;return}function fVk(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;g=(c[2440596]|0)-1|0;c[2440596]=g;b[4830480]=k+1&65535;e=k&65535;f=c[l+68+(e>>>8<<2)>>2]|0;do{if((f|0)==0){h=c[l+3168>>2]|0;if((h|0)==0){n=0;o=g;p=j;break}d=gj[h&4095](k)|0;n=d;o=c[2440596]|0;p=a[9660972]|0}else{n=a[f+(e&255)|0]|0;o=g;p=j}}while(0);a[9660973]=n;j=o-1|0;c[2440596]=j;o=a[9660978]|0;g=(o&255)+(p&255)|0;if((g|0)>255){p=n&255;n=(g&255|p<<8)&65535;g=c[2443776]|0;do{if((c[g+68+(p<<2)>>2]|0)==0){e=c[g+3148>>2]|0;if((e|0)==0){q=j;r=o;break}gj[e&4095](n)|0;q=c[2440596]|0;r=a[9660978]|0}else{q=j;r=o}}while(0);n=q-1|0;c[2440596]=n;s=r;t=n}else{s=o;t=j}b[4830486]=(b[4830486]|0)+(s&255)&65535;s=c[2415243]|0;j=s&65535;o=c[2443776]|0;n=c[o+68+((s>>>8&255)<<2)>>2]|0;do{if((n|0)==0){r=c[o+3148>>2]|0;if((r|0)==0){u=0;v=t;break}q=gj[r&4095](j)|0;u=q;v=c[2440596]|0}else{u=a[n+(s&255)|0]|0;v=t}}while(0);c[2440596]=v-1;v=a[9660976]&u;a[9660976]=v;a[9660979]=(v<<24>>24==0?2:v&-128)|a[9660979]&125;return}function fVl(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;g=(c[2440596]|0)-1|0;c[2440596]=g;b[4830480]=k+1&65535;e=k&65535;f=c[l+68+(e>>>8<<2)>>2]|0;do{if((f|0)==0){h=c[l+3168>>2]|0;if((h|0)==0){n=0;o=g;p=j;break}d=gj[h&4095](k)|0;n=d;o=c[2440596]|0;p=a[9660972]|0}else{n=a[f+(e&255)|0]|0;o=g;p=j}}while(0);a[9660973]=n;j=o-1|0;c[2440596]=j;o=a[9660978]|0;g=(o&255)+(p&255)|0;if((g|0)>255){p=n&255;n=(g&255|p<<8)&65535;g=c[2443776]|0;do{if((c[g+68+(p<<2)>>2]|0)==0){e=c[g+3148>>2]|0;if((e|0)==0){q=j;r=o;break}gj[e&4095](n)|0;q=c[2440596]|0;r=a[9660978]|0}else{q=j;r=o}}while(0);n=q-1|0;c[2440596]=n;s=r;t=n}else{s=o;t=j}b[4830486]=(b[4830486]|0)+(s&255)&65535;s=c[2415243]|0;j=s&65535;o=c[2443776]|0;n=c[o+68+((s>>>8&255)<<2)>>2]|0;do{if((n|0)==0){r=c[o+3148>>2]|0;if((r|0)==0){u=0;v=t;break}q=gj[r&4095](j)|0;u=q;v=c[2440596]|0}else{u=a[n+(s&255)|0]|0;v=t}}while(0);c[2440596]=v-1;v=a[9660976]|0;t=v^u;a[9660976]=t;a[9660979]=(v<<24>>24==u<<24>>24?2:t&-128)|a[9660979]&125;return}function fVm(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;g=(c[2440596]|0)-1|0;c[2440596]=g;b[4830480]=k+1&65535;e=k&65535;f=c[l+68+(e>>>8<<2)>>2]|0;do{if((f|0)==0){h=c[l+3168>>2]|0;if((h|0)==0){n=0;o=g;p=j;break}d=gj[h&4095](k)|0;n=d;o=c[2440596]|0;p=a[9660972]|0}else{n=a[f+(e&255)|0]|0;o=g;p=j}}while(0);a[9660973]=n;j=o-1|0;c[2440596]=j;o=a[9660978]|0;g=(o&255)+(p&255)|0;if((g|0)>255){p=n&255;n=(g&255|p<<8)&65535;g=c[2443776]|0;do{if((c[g+68+(p<<2)>>2]|0)==0){e=c[g+3148>>2]|0;if((e|0)==0){q=j;r=o;break}gj[e&4095](n)|0;q=c[2440596]|0;r=a[9660978]|0}else{q=j;r=o}}while(0);n=q-1|0;c[2440596]=n;s=r;t=n}else{s=o;t=j}b[4830486]=(b[4830486]|0)+(s&255)&65535;s=c[2415243]|0;j=s&65535;o=c[2443776]|0;n=c[o+68+((s>>>8&255)<<2)>>2]|0;do{if((n|0)==0){r=c[o+3148>>2]|0;if((r|0)==0){u=0;v=t;break}q=gj[r&4095](j)|0;u=q;v=c[2440596]|0}else{u=a[n+(s&255)|0]|0;v=t}}while(0);t=u&255;c[2440596]=v-1;v=a[9660979]|0;s=v&255;n=s&1;j=a[9660976]|0;o=j&255;if((s&8|0)==0){s=o+t+n|0;q=v&-66;r=((((j^u)&128^128)&(s^o)|0)==0?q:q|64)|(s&65280|0)!=0;a[9660979]=r;a[9660976]=s&255;if((s&255|0)==0){a[9660979]=r&125|2;return}else{a[9660979]=(r&125|s&128)&255;return}}s=n+(t&15)+(o&15)|0;n=(o&240)+(t&240)|0;t=v&60;v=(s+n&255|0)==0?t|2:t;a[9660979]=v;if((s|0)>9){w=s+6|0;x=n+16|0}else{w=s;x=n}if((x&128|0)==0){y=v}else{n=v|-128;a[9660979]=n;y=n}if((((j^u)&128^128)&(x^o)|0)==0){z=y}else{o=y|64;a[9660979]=o;z=o}o=(x|0)>144?x+96|0:x;if((o&65280|0)!=0){a[9660979]=z|1}a[9660976]=(o&240|w&15)&255;return}function fVn(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=a[9660976]|0;e=b[4830480]|0;f=e+1&65535;b[4830480]=f;g=e&65535;h=c[2443776]|0;i=c[h+68+(g>>>8<<2)>>2]|0;do{if((i|0)==0){j=c[h+3168>>2]|0;if((j|0)==0){k=0;l=f;m=h;break}n=gj[j&4095](e)|0;k=n;l=b[4830480]|0;m=c[2443776]|0}else{k=a[i+(g&255)|0]|0;l=f;m=h}}while(0);a[9660972]=k;h=(c[2440596]|0)-1|0;c[2440596]=h;b[4830480]=l+1&65535;f=l&65535;g=c[m+68+(f>>>8<<2)>>2]|0;do{if((g|0)==0){i=c[m+3168>>2]|0;if((i|0)==0){o=0;p=h;q=k;r=m;break}e=gj[i&4095](l)|0;o=e;p=c[2440596]|0;q=a[9660972]|0;r=c[2443776]|0}else{o=a[g+(f&255)|0]|0;p=h;q=k;r=m}}while(0);a[9660973]=o;m=p-1|0;c[2440596]=m;p=(o&255)<<8;o=a[9660978]|0;k=(o&255)+(q&255)&255|p;do{if((c[r+68+((p&65535)>>>8<<2)>>2]|0)==0){q=c[r+3148>>2]|0;if((q|0)==0){s=m;t=o;u=r;break}gj[q&4095](k)|0;s=c[2440596]|0;t=a[9660978]|0;u=c[2443776]|0}else{s=m;t=o;u=r}}while(0);r=s-1|0;c[2440596]=r;b[4830486]=(b[4830486]|0)+(t&255)&65535;t=c[2415243]|0;s=c[u+68+((t>>>8&255|256)<<2)>>2]|0;if((s|0)!=0){a[s+(t&255)|0]=d;v=r;w=v-1|0;c[2440596]=w;return}s=c[u+3152>>2]|0;if((s|0)==0){v=r;w=v-1|0;c[2440596]=w;return}gg[s&4095](t&65535,d);v=c[2440596]|0;w=v-1|0;c[2440596]=w;return}function fVo(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;g=(c[2440596]|0)-1|0;c[2440596]=g;b[4830480]=k+1&65535;e=k&65535;f=c[l+68+(e>>>8<<2)>>2]|0;do{if((f|0)==0){h=c[l+3168>>2]|0;if((h|0)==0){n=0;o=g;p=j;break}d=gj[h&4095](k)|0;n=d;o=c[2440596]|0;p=a[9660972]|0}else{n=a[f+(e&255)|0]|0;o=g;p=j}}while(0);a[9660973]=n;j=o-1|0;c[2440596]=j;o=a[9660978]|0;g=(o&255)+(p&255)|0;if((g|0)>255){p=n&255;n=(g&255|p<<8)&65535;g=c[2443776]|0;do{if((c[g+68+(p<<2)>>2]|0)==0){e=c[g+3148>>2]|0;if((e|0)==0){q=j;r=o;break}gj[e&4095](n)|0;q=c[2440596]|0;r=a[9660978]|0}else{q=j;r=o}}while(0);n=q-1|0;c[2440596]=n;s=r;t=n}else{s=o;t=j}b[4830486]=(b[4830486]|0)+(s&255)&65535;s=c[2415243]|0;j=s&65535;o=c[2443776]|0;n=c[o+68+((s>>>8&255)<<2)>>2]|0;do{if((n|0)==0){r=c[o+3148>>2]|0;if((r|0)==0){u=0;v=t;break}q=gj[r&4095](j)|0;u=q;v=c[2440596]|0}else{u=a[n+(s&255)|0]|0;v=t}}while(0);c[2440596]=v-1;a[9660976]=u;a[9660979]=a[9660979]&125|(u<<24>>24==0?2:u&-128);return}function fVp(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;g=(c[2440596]|0)-1|0;c[2440596]=g;b[4830480]=k+1&65535;e=k&65535;f=c[l+68+(e>>>8<<2)>>2]|0;do{if((f|0)==0){h=c[l+3168>>2]|0;if((h|0)==0){n=0;o=g;p=j;break}d=gj[h&4095](k)|0;n=d;o=c[2440596]|0;p=a[9660972]|0}else{n=a[f+(e&255)|0]|0;o=g;p=j}}while(0);a[9660973]=n;j=o-1|0;c[2440596]=j;o=a[9660978]|0;g=(o&255)+(p&255)|0;if((g|0)>255){p=n&255;n=(g&255|p<<8)&65535;g=c[2443776]|0;do{if((c[g+68+(p<<2)>>2]|0)==0){e=c[g+3148>>2]|0;if((e|0)==0){q=j;r=o;break}gj[e&4095](n)|0;q=c[2440596]|0;r=a[9660978]|0}else{q=j;r=o}}while(0);n=q-1|0;c[2440596]=n;s=r;t=n}else{s=o;t=j}b[4830486]=(b[4830486]|0)+(s&255)&65535;s=c[2415243]|0;j=s&65535;o=c[2443776]|0;n=c[o+68+((s>>>8&255)<<2)>>2]|0;do{if((n|0)==0){r=c[o+3148>>2]|0;if((r|0)==0){u=0;v=t;break}q=gj[r&4095](j)|0;u=q;v=c[2440596]|0}else{u=a[n+(s&255)|0]|0;v=t}}while(0);c[2440596]=v-1;v=a[9660979]|0;t=v&-2;a[9660979]=t;s=a[9660976]|0;if((s&255)<(u&255)){w=t}else{t=v|1;a[9660979]=t;w=t}if(s<<24>>24==u<<24>>24){x=w&125|2;a[9660979]=x;return}else{x=w&125|s-u&255&-128;a[9660979]=x;return}}function fVq(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;g=(c[2440596]|0)-1|0;c[2440596]=g;b[4830480]=k+1&65535;e=k&65535;f=c[l+68+(e>>>8<<2)>>2]|0;do{if((f|0)==0){h=c[l+3168>>2]|0;if((h|0)==0){n=0;o=g;p=j;break}d=gj[h&4095](k)|0;n=d;o=c[2440596]|0;p=a[9660972]|0}else{n=a[f+(e&255)|0]|0;o=g;p=j}}while(0);a[9660973]=n;j=o-1|0;c[2440596]=j;o=a[9660978]|0;g=(o&255)+(p&255)|0;if((g|0)>255){p=n&255;n=(g&255|p<<8)&65535;g=c[2443776]|0;do{if((c[g+68+(p<<2)>>2]|0)==0){e=c[g+3148>>2]|0;if((e|0)==0){q=j;r=o;break}gj[e&4095](n)|0;q=c[2440596]|0;r=a[9660978]|0}else{q=j;r=o}}while(0);n=q-1|0;c[2440596]=n;s=r;t=n}else{s=o;t=j}b[4830486]=(b[4830486]|0)+(s&255)&65535;s=c[2415243]|0;j=s&65535;o=c[2443776]|0;n=c[o+68+((s>>>8&255)<<2)>>2]|0;do{if((n|0)==0){r=c[o+3148>>2]|0;if((r|0)==0){u=0;v=t;break}q=gj[r&4095](j)|0;u=q;v=c[2440596]|0}else{u=a[n+(s&255)|0]|0;v=t}}while(0);t=u&255;c[2440596]=v-1;v=a[9660979]|0;s=v&255;n=s&1^1;j=a[9660976]|0;o=j&255;q=o-t-n|0;if((s&8|0)!=0){s=(o&15)-(t&15)-n|0;n=(o&240)-(t&240)|0;if((s&16|0)==0){w=s;x=n}else{w=s-6|0;x=n-1|0}n=v&60;s=(((j^u)&128&(q^o)|0)==0?n:n|64)|(q&65280|0)==0;n=(q&255|0)==0?s|2:s;a[9660979]=(q&128|0)==0?n:n|-128;a[9660976]=(((x&256|0)==0?x:x+160|0)&240|w&15)&255;return}w=v&-66;v=(((j^u)&128&(q^o)|0)==0?w:w|64)|(q&65280|0)==0;a[9660979]=v;a[9660976]=q&255;if((q&255|0)==0){a[9660979]=v&125|2;return}else{a[9660979]=(v&125|q&128)&255;return}}function fVr(){var d=0,e=0,f=0;d=b[4830480]|0;e=c[2443776]|0;do{if((c[e+68+((d&65535)>>>8<<2)>>2]|0)==0){f=c[e+3148>>2]|0;if((f|0)==0){break}gj[f&4095](d)|0}}while(0);c[2440596]=(c[2440596]|0)-1;d=a[9660976]|0;e=d<<1;a[9660979]=a[9660979]&124|(d&255)>>>7|(e<<24>>24==0?2:e&-128);a[9660976]=e;return}function fVs(){var d=0,e=0,f=0,g=0;d=b[4830480]|0;e=c[2443776]|0;do{if((c[e+68+((d&65535)>>>8<<2)>>2]|0)==0){f=c[e+3148>>2]|0;if((f|0)==0){break}gj[f&4095](d)|0}}while(0);c[2440596]=(c[2440596]|0)-1;d=a[9660976]|0;e=d<<1;f=a[9660979]|0;g=f&1|e;a[9660979]=f&124|(d&255)>>>7|(g<<24>>24==0?2:e&-128);a[9660976]=g;return}function fVt(){var d=0,e=0,f=0;d=b[4830480]|0;e=c[2443776]|0;do{if((c[e+68+((d&65535)>>>8<<2)>>2]|0)==0){f=c[e+3148>>2]|0;if((f|0)==0){break}gj[f&4095](d)|0}}while(0);c[2440596]=(c[2440596]|0)-1;d=a[9660976]|0;e=a[9660979]&124|d&1;f=(d&255)>>>1;a[9660979]=(f|0)==0?e|2:e;a[9660976]=f&255;return}function fVu(){var d=0,e=0,f=0,g=0,h=0,i=0;d=b[4830480]|0;e=c[2443776]|0;do{if((c[e+68+((d&65535)>>>8<<2)>>2]|0)==0){f=c[e+3148>>2]|0;if((f|0)==0){break}gj[f&4095](d)|0}}while(0);c[2440596]=(c[2440596]|0)-1;d=a[9660976]|0;e=a[9660979]|0;f=e&-2|d&1;a[9660979]=f;g=((e&255)<<8|d&255)>>>1;if((g&255|0)==0){h=f&125|2;a[9660979]=h;i=g&255;a[9660976]=i;return}else{h=(g&128|f&125)&255;a[9660979]=h;i=g&255;a[9660976]=i;return}}function fVv(){var d=0,e=0,f=0;d=b[4830480]|0;e=c[2443776]|0;do{if((c[e+68+((d&65535)>>>8<<2)>>2]|0)==0){f=c[e+3148>>2]|0;if((f|0)==0){break}gj[f&4095](d)|0}}while(0);c[2440596]=(c[2440596]|0)-1;d=a[9660977]|0;a[9660976]=d;a[9660979]=a[9660979]&125|(d<<24>>24==0?2:d&-128);return}function fVw(){var d=0,e=0,f=0;d=b[4830480]|0;e=c[2443776]|0;do{if((c[e+68+((d&65535)>>>8<<2)>>2]|0)==0){f=c[e+3148>>2]|0;if((f|0)==0){break}gj[f&4095](d)|0}}while(0);c[2440596]=(c[2440596]|0)-1;d=a[9660976]|0;a[9660977]=d;a[9660979]=a[9660979]&125|(d<<24>>24==0?2:d&-128);return}function fVx(){var d=0,e=0,f=0;d=b[4830480]|0;e=c[2443776]|0;do{if((c[e+68+((d&65535)>>>8<<2)>>2]|0)==0){f=c[e+3148>>2]|0;if((f|0)==0){break}gj[f&4095](d)|0}}while(0);c[2440596]=(c[2440596]|0)-1;d=(a[9660977]|0)-1&255;a[9660977]=d;a[9660979]=(d<<24>>24==0?2:d&-128)|a[9660979]&125;return}function fVy(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function fVz(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function fVA(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function fVB(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function fVC(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function fVD(){var d=0,e=0,f=0;d=b[4830480]|0;e=c[2443776]|0;do{if((c[e+68+((d&65535)>>>8<<2)>>2]|0)==0){f=c[e+3148>>2]|0;if((f|0)==0){break}gj[f&4095](d)|0}}while(0);c[2440596]=(c[2440596]|0)-1;a[9660964]=a[9660977]|0;return}function fVE(){var d=0,e=0,f=0;d=b[4830480]|0;e=c[2443776]|0;do{if((c[e+68+((d&65535)>>>8<<2)>>2]|0)==0){f=c[e+3148>>2]|0;if((f|0)==0){break}gj[f&4095](d)|0}}while(0);c[2440596]=(c[2440596]|0)-1;d=a[9660964]|0;a[9660977]=d;a[9660979]=a[9660979]&125|(d<<24>>24==0?2:d&-128);return}function fVF(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function fVG(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function fVH(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(e&255)|0]|0}}while(0);c[2440596]=(c[2440596]|0)-1;e=a[9660979]|0;g=e&-2;a[9660979]=g;d=a[9660976]&i;a[9660976]=d;if(d<<24>>24>=0){j=g;k=d<<24>>24==0;l=j&125;m=d&-128;n=k?2:m;o=l|n;a[9660979]=o;return}g=e|1;a[9660979]=g;j=g;k=d<<24>>24==0;l=j&125;m=d&-128;n=k?2:m;o=l|n;a[9660979]=o;return}function fVI(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(e&255)|0]|0}}while(0);c[2440596]=(c[2440596]|0)-1;e=a[9660979]|0;g=e&-2;a[9660979]=g;d=a[9660976]&i;a[9660976]=d;if(d<<24>>24>=0){j=g;k=d<<24>>24==0;l=j&125;m=d&-128;n=k?2:m;o=l|n;a[9660979]=o;return}g=e|1;a[9660979]=g;j=g;k=d<<24>>24==0;l=j&125;m=d&-128;n=k?2:m;o=l|n;a[9660979]=o;return}function fVJ(){var d=0,e=0,f=0,g=0,h=0,i=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(e&255)|0]|0}}while(0);c[2440596]=(c[2440596]|0)-1;e=a[9660976]&i;i=a[9660979]&124|e&1;g=(e&255)>>>1;a[9660979]=(g|0)==0?i|2:i;a[9660976]=g&255;return}function fVK(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(e&255)|0]|0}}while(0);c[2440596]=(c[2440596]|0)-1;e=a[9660979]|0;g=e&255;d=a[9660976]&i;i=d&255;if((g&8|0)==0){f=d&1|e&-2;a[9660979]=f;h=(i|g<<8)>>>1;if((h&255|0)==0){j=f&125|2}else{j=(f&125|h&128)&255}f=j&-66|(d&255)>>>7;a[9660979]=f;d=h&96;do{if((d|0)==32){k=h&255}else{j=h&255;if((d|0)==64){k=j;break}else{l=j}a[9660976]=l;return}}while(0);a[9660979]=f|64;l=k;a[9660976]=l;return}k=i>>>1;if((g&1|0)==0){m=k;n=e&127}else{m=k|128;n=e|-128}e=(m|0)==0?n|2:n&-3;n=((m^i)&64|0)==0?e&-65:e|64;a[9660979]=n;if(((i&15)+(i&1)|0)>5){o=m+6&15|m&240}else{o=m}if(((i&240)+(i&16)|0)>80){a[9660979]=n|1;l=o+96&255;a[9660976]=l;return}else{a[9660979]=n&-2;l=o&255;a[9660976]=l;return}}function fVL(){var d=0,e=0,f=0,g=0,h=0,i=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(e&255)|0]|0}}while(0);c[2440596]=(c[2440596]|0)-1;e=a[9660977]&i;i=e&(a[9660976]|-18);a[9660976]=i;a[9660979]=(i<<24>>24==0?2:e&-128)|a[9660979]&125;return}function fVM(){var d=0,e=0,f=0,g=0,h=0,i=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(e&255)|0]|0}}while(0);c[2440596]=(c[2440596]|0)-1;e=(a[9660976]|-18)&i;a[9660977]=e;a[9660976]=e;a[9660979]=(e<<24>>24==0?2:i&-128)|a[9660979]&125;return}function fVN(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(e&255)|0]|0}}while(0);c[2440596]=(c[2440596]|0)-1;e=a[9660979]|0;g=e&-2;a[9660979]=g;d=a[9660977]&a[9660976];a[9660977]=d;if((d&255)<(i&255)){j=g}else{g=e|1;a[9660979]=g;j=g}g=d-i&255;a[9660977]=g;a[9660979]=j&125|(d<<24>>24==i<<24>>24?2:g&-128);return}function fVO(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(e&255)|0]|0}}while(0);e=i&255;c[2440596]=(c[2440596]|0)-1;g=a[9660979]|0;d=g&255;f=d&1^1;h=a[9660976]|0;j=h&255;k=j-e-f|0;if((d&8|0)!=0){d=(j&15)-(e&15)-f|0;f=(j&240)-(e&240)|0;if((d&16|0)==0){l=d;m=f}else{l=d-6|0;m=f-1|0}f=g&60;d=(((h^i)&128&(k^j)|0)==0?f:f|64)|(k&65280|0)==0;f=(k&255|0)==0?d|2:d;a[9660979]=(k&128|0)==0?f:f|-128;a[9660976]=(((m&256|0)==0?m:m+160|0)&240|l&15)&255;return}l=g&-66;g=(((h^i)&128&(k^j)|0)==0?l:l|64)|(k&65280|0)==0;a[9660979]=g;a[9660976]=k&255;if((k&255|0)==0){a[9660979]=g&125|2;return}else{a[9660979]=(g&125|k&128)&255;return}}function fVP(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;g=(c[2440596]|0)-1|0;c[2440596]=g;b[4830480]=k+1&65535;e=k&65535;f=c[l+68+(e>>>8<<2)>>2]|0;do{if((f|0)==0){h=c[l+3168>>2]|0;if((h|0)==0){n=0;o=g;p=j;q=l;break}d=gj[h&4095](k)|0;n=d;o=c[2440596]|0;p=a[9660972]|0;q=c[2443776]|0}else{n=a[f+(e&255)|0]|0;o=g;p=j;q=l}}while(0);a[9660973]=n;l=o-1|0;c[2440596]=l;o=(n&255)<<8;n=a[9660978]|0;j=(n&255)+(p&255)&255|o;do{if((c[q+68+((o&65535)>>>8<<2)>>2]|0)==0){p=c[q+3148>>2]|0;if((p|0)==0){r=l;s=n;t=q;break}gj[p&4095](j)|0;r=c[2440596]|0;s=a[9660978]|0;t=c[2443776]|0}else{r=l;s=n;t=q}}while(0);q=r-1|0;c[2440596]=q;b[4830486]=(b[4830486]|0)+(s&255)&65535;s=c[2415243]|0;r=s&65535;n=c[t+68+((s>>>8&255)<<2)>>2]|0;do{if((n|0)==0){l=c[t+3148>>2]|0;if((l|0)==0){u=0;v=q;w=s;x=t;break}j=gj[l&4095](r)|0;u=j;v=c[2440596]|0;w=c[2415243]|0;x=c[2443776]|0}else{u=a[n+(s&255)|0]|0;v=q;w=s;x=t}}while(0);t=v-1|0;c[2440596]=t;v=w&65535;s=c[x+68+((w>>>8&255|256)<<2)>>2]|0;do{if((s|0)==0){q=c[x+3152>>2]|0;if((q|0)==0){y=t;z=x;break}gg[q&4095](v,u);y=c[2440596]|0;z=c[2443776]|0}else{a[s+(w&255)|0]=u;y=t;z=x}}while(0);x=y-1|0;c[2440596]=x;y=a[9660979]&124;t=u<<1;w=a[9660976]|t;a[9660976]=w;a[9660979]=y|(u&255)>>>7|(w<<24>>24==0?2:w&-128);w=c[2415243]|0;u=c[z+68+((w>>>8&255|256)<<2)>>2]|0;if((u|0)!=0){a[u+(w&255)|0]=t;A=x;B=A-1|0;c[2440596]=B;return}u=c[z+3152>>2]|0;if((u|0)==0){A=x;B=A-1|0;c[2440596]=B;return}gg[u&4095](w&65535,t);A=c[2440596]|0;B=A-1|0;c[2440596]=B;return}function fVQ(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;g=(c[2440596]|0)-1|0;c[2440596]=g;b[4830480]=k+1&65535;e=k&65535;f=c[l+68+(e>>>8<<2)>>2]|0;do{if((f|0)==0){h=c[l+3168>>2]|0;if((h|0)==0){n=0;o=g;p=j;q=l;break}d=gj[h&4095](k)|0;n=d;o=c[2440596]|0;p=a[9660972]|0;q=c[2443776]|0}else{n=a[f+(e&255)|0]|0;o=g;p=j;q=l}}while(0);a[9660973]=n;l=o-1|0;c[2440596]=l;o=(n&255)<<8;n=a[9660978]|0;j=(n&255)+(p&255)&255|o;do{if((c[q+68+((o&65535)>>>8<<2)>>2]|0)==0){p=c[q+3148>>2]|0;if((p|0)==0){r=l;s=n;t=q;break}gj[p&4095](j)|0;r=c[2440596]|0;s=a[9660978]|0;t=c[2443776]|0}else{r=l;s=n;t=q}}while(0);q=r-1|0;c[2440596]=q;b[4830486]=(b[4830486]|0)+(s&255)&65535;s=c[2415243]|0;r=s&65535;n=c[t+68+((s>>>8&255)<<2)>>2]|0;do{if((n|0)==0){l=c[t+3148>>2]|0;if((l|0)==0){u=0;v=q;w=s;x=t;break}j=gj[l&4095](r)|0;u=j;v=c[2440596]|0;w=c[2415243]|0;x=c[2443776]|0}else{u=a[n+(s&255)|0]|0;v=q;w=s;x=t}}while(0);t=v-1|0;c[2440596]=t;v=w&65535;s=c[x+68+((w>>>8&255|256)<<2)>>2]|0;do{if((s|0)==0){q=c[x+3152>>2]|0;if((q|0)==0){y=t;z=x;break}gg[q&4095](v,u);y=c[2440596]|0;z=c[2443776]|0}else{a[s+(w&255)|0]=u;y=t;z=x}}while(0);x=y-1|0;c[2440596]=x;y=a[9660979]|0;t=y&1|u<<1;w=t&a[9660976];a[9660976]=w;a[9660979]=y&124|(u&255)>>>7|(w<<24>>24==0?2:w&-128);w=c[2415243]|0;u=c[z+68+((w>>>8&255|256)<<2)>>2]|0;if((u|0)!=0){a[u+(w&255)|0]=t;A=x;B=A-1|0;c[2440596]=B;return}u=c[z+3152>>2]|0;if((u|0)==0){A=x;B=A-1|0;c[2440596]=B;return}gg[u&4095](w&65535,t);A=c[2440596]|0;B=A-1|0;c[2440596]=B;return}function fVR(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;e=b[4830480]|0;f=e+1&65535;b[4830480]=f;g=e&65535;h=c[2443776]|0;i=c[h+68+(g>>>8<<2)>>2]|0;do{if((i|0)==0){j=c[h+3168>>2]|0;if((j|0)==0){k=0;l=f;m=h;break}n=gj[j&4095](e)|0;k=n;l=b[4830480]|0;m=c[2443776]|0}else{k=a[i+(g&255)|0]|0;l=f;m=h}}while(0);a[9660972]=k;h=(c[2440596]|0)-1|0;c[2440596]=h;b[4830480]=l+1&65535;f=l&65535;g=c[m+68+(f>>>8<<2)>>2]|0;do{if((g|0)==0){i=c[m+3168>>2]|0;if((i|0)==0){o=0;p=h;q=k;r=m;break}e=gj[i&4095](l)|0;o=e;p=c[2440596]|0;q=a[9660972]|0;r=c[2443776]|0}else{o=a[g+(f&255)|0]|0;p=h;q=k;r=m}}while(0);a[9660973]=o;m=p-1|0;c[2440596]=m;p=(o&255)<<8;o=a[9660978]|0;k=(o&255)+(q&255)&255|p;do{if((c[r+68+((p&65535)>>>8<<2)>>2]|0)==0){q=c[r+3148>>2]|0;if((q|0)==0){s=m;t=o;u=r;break}gj[q&4095](k)|0;s=c[2440596]|0;t=a[9660978]|0;u=c[2443776]|0}else{s=m;t=o;u=r}}while(0);r=s-1|0;c[2440596]=r;b[4830486]=(b[4830486]|0)+(t&255)&65535;t=c[2415243]|0;s=t&65535;o=c[u+68+((t>>>8&255)<<2)>>2]|0;do{if((o|0)==0){m=c[u+3148>>2]|0;if((m|0)==0){v=0;w=r;x=t;y=u;break}k=gj[m&4095](s)|0;v=k;w=c[2440596]|0;x=c[2415243]|0;y=c[2443776]|0}else{v=a[o+(t&255)|0]|0;w=r;x=t;y=u}}while(0);u=w-1|0;c[2440596]=u;w=x&65535;t=c[y+68+((x>>>8&255|256)<<2)>>2]|0;do{if((t|0)==0){r=c[y+3152>>2]|0;if((r|0)==0){z=u;break}gg[r&4095](w,v);z=c[2440596]|0}else{a[t+(x&255)|0]=v;z=u}}while(0);u=z-1|0;c[2440596]=u;z=a[9660979]&-2|v&1;a[9660979]=z;x=(v&255)>>>1;v=d[9660976]|0;t=v^x;a[9660976]=t&255;if((v|0)==(x|0)){A=z&125|2}else{A=(z&125|t&128)&255}a[9660979]=A;A=c[2415243]|0;t=x&255;x=c[2443776]|0;z=c[x+68+((A>>>8&255|256)<<2)>>2]|0;if((z|0)!=0){a[z+(A&255)|0]=t;B=u;C=B-1|0;c[2440596]=C;return}z=c[x+3152>>2]|0;if((z|0)==0){B=u;C=B-1|0;c[2440596]=C;return}gg[z&4095](A&65535,t);B=c[2440596]|0;C=B-1|0;c[2440596]=C;return}function fVS(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;e=b[4830480]|0;f=e+1&65535;b[4830480]=f;g=e&65535;h=c[2443776]|0;i=c[h+68+(g>>>8<<2)>>2]|0;do{if((i|0)==0){j=c[h+3168>>2]|0;if((j|0)==0){k=0;l=f;m=h;break}n=gj[j&4095](e)|0;k=n;l=b[4830480]|0;m=c[2443776]|0}else{k=a[i+(g&255)|0]|0;l=f;m=h}}while(0);a[9660972]=k;h=(c[2440596]|0)-1|0;c[2440596]=h;b[4830480]=l+1&65535;f=l&65535;g=c[m+68+(f>>>8<<2)>>2]|0;do{if((g|0)==0){i=c[m+3168>>2]|0;if((i|0)==0){o=0;p=h;q=k;r=m;break}e=gj[i&4095](l)|0;o=e;p=c[2440596]|0;q=a[9660972]|0;r=c[2443776]|0}else{o=a[g+(f&255)|0]|0;p=h;q=k;r=m}}while(0);a[9660973]=o;m=p-1|0;c[2440596]=m;p=(o&255)<<8;o=a[9660978]|0;k=(o&255)+(q&255)&255|p;do{if((c[r+68+((p&65535)>>>8<<2)>>2]|0)==0){q=c[r+3148>>2]|0;if((q|0)==0){s=m;t=o;u=r;break}gj[q&4095](k)|0;s=c[2440596]|0;t=a[9660978]|0;u=c[2443776]|0}else{s=m;t=o;u=r}}while(0);r=s-1|0;c[2440596]=r;b[4830486]=(b[4830486]|0)+(t&255)&65535;t=c[2415243]|0;s=t&65535;o=c[u+68+((t>>>8&255)<<2)>>2]|0;do{if((o|0)==0){m=c[u+3148>>2]|0;if((m|0)==0){v=0;w=r;x=t;y=u;break}k=gj[m&4095](s)|0;v=k;w=c[2440596]|0;x=c[2415243]|0;y=c[2443776]|0}else{v=a[o+(t&255)|0]|0;w=r;x=t;y=u}}while(0);u=v&255;t=w-1|0;c[2440596]=t;w=x&65535;r=c[y+68+((x>>>8&255|256)<<2)>>2]|0;do{if((r|0)==0){o=c[y+3152>>2]|0;if((o|0)==0){z=t;break}gg[o&4095](w,v);z=c[2440596]|0}else{a[r+(x&255)|0]=v;z=t}}while(0);t=z-1|0;c[2440596]=t;z=a[9660979]|0;x=z&-2|v&1;a[9660979]=x;v=((z&255)<<8|u)>>>1;u=x&255;x=u&1;do{if((u&8|0)==0){r=d[9660976]|0;w=(v&255)+x+r|0;y=z&-66;o=(((v^128^r)&128&(w^r)|0)==0?y:y|64)|(w&65280|0)!=0;a[9660979]=o;a[9660976]=w&255;if((w&255|0)==0){a[9660979]=o&125|2;break}else{a[9660979]=(o&125|w&128)&255;break}}else{w=d[9660976]|0;o=(v&15)+x+(w&15)|0;y=(w&240)+(v&240)|0;r=z&60;s=(o+y&255|0)==0?r|2:r;a[9660979]=s;if((o|0)>9){A=o+6|0;B=y+16|0}else{A=o;B=y}if((B&128|0)==0){C=s}else{y=s|-128;a[9660979]=y;C=y}if(((v^128^w)&128&(B^w)|0)==0){D=C}else{w=C|64;a[9660979]=w;D=w}w=(B|0)>144?B+96|0:B;if((w&65280|0)!=0){a[9660979]=D|1}a[9660976]=(w&240|A&15)&255}}while(0);A=c[2415243]|0;D=v&255;v=c[2443776]|0;B=c[v+68+((A>>>8&255|256)<<2)>>2]|0;if((B|0)!=0){a[B+(A&255)|0]=D;E=t;F=E-1|0;c[2440596]=F;return}B=c[v+3152>>2]|0;if((B|0)==0){E=t;F=E-1|0;c[2440596]=F;return}gg[B&4095](A&65535,D);E=c[2440596]|0;F=E-1|0;c[2440596]=F;return}function fVT(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;g=(c[2440596]|0)-1|0;c[2440596]=g;b[4830480]=k+1&65535;e=k&65535;f=c[l+68+(e>>>8<<2)>>2]|0;do{if((f|0)==0){h=c[l+3168>>2]|0;if((h|0)==0){n=0;o=g;p=j;q=l;break}d=gj[h&4095](k)|0;n=d;o=c[2440596]|0;p=a[9660972]|0;q=c[2443776]|0}else{n=a[f+(e&255)|0]|0;o=g;p=j;q=l}}while(0);a[9660973]=n;l=o-1|0;c[2440596]=l;o=(n&255)<<8;n=a[9660978]|0;j=(n&255)+(p&255)&255|o;do{if((c[q+68+((o&65535)>>>8<<2)>>2]|0)==0){p=c[q+3148>>2]|0;if((p|0)==0){r=l;s=n;t=q;break}gj[p&4095](j)|0;r=c[2440596]|0;s=a[9660978]|0;t=c[2443776]|0}else{r=l;s=n;t=q}}while(0);q=r-1|0;c[2440596]=q;r=(b[4830486]|0)+(s&255)&65535;b[4830486]=r;s=a[9660977]&a[9660976];a[9660964]=s;n=((r&65535)>>>8&255)+1&255&s;s=c[2415243]|0;r=c[t+68+((s>>>8&255|256)<<2)>>2]|0;if((r|0)!=0){a[r+(s&255)|0]=n;u=q;v=u-1|0;c[2440596]=v;return}r=c[t+3152>>2]|0;if((r|0)==0){u=q;v=u-1|0;c[2440596]=v;return}gg[r&4095](s&65535,n);u=c[2440596]|0;v=u-1|0;c[2440596]=v;return}function fVU(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;g=(c[2440596]|0)-1|0;c[2440596]=g;b[4830480]=k+1&65535;e=k&65535;f=c[l+68+(e>>>8<<2)>>2]|0;do{if((f|0)==0){h=c[l+3168>>2]|0;if((h|0)==0){n=0;o=g;p=j;break}d=gj[h&4095](k)|0;n=d;o=c[2440596]|0;p=a[9660972]|0}else{n=a[f+(e&255)|0]|0;o=g;p=j}}while(0);a[9660973]=n;j=o-1|0;c[2440596]=j;o=a[9660978]|0;g=(o&255)+(p&255)|0;if((g|0)>255){p=n&255;n=(g&255|p<<8)&65535;g=c[2443776]|0;do{if((c[g+68+(p<<2)>>2]|0)==0){e=c[g+3148>>2]|0;if((e|0)==0){q=j;r=o;break}gj[e&4095](n)|0;q=c[2440596]|0;r=a[9660978]|0}else{q=j;r=o}}while(0);n=q-1|0;c[2440596]=n;s=r;t=n}else{s=o;t=j}b[4830486]=(b[4830486]|0)+(s&255)&65535;s=c[2415243]|0;j=s&65535;o=c[2443776]|0;n=c[o+68+((s>>>8&255)<<2)>>2]|0;do{if((n|0)==0){r=c[o+3148>>2]|0;if((r|0)==0){u=0;v=t;break}q=gj[r&4095](j)|0;u=q;v=c[2440596]|0}else{u=a[n+(s&255)|0]|0;v=t}}while(0);c[2440596]=v-1;v=a[9660964]&u;a[9660964]=v;a[9660977]=v;a[9660976]=v;a[9660979]=(v<<24>>24==0?2:v&-128)|a[9660979]&125;return}function fVV(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;g=(c[2440596]|0)-1|0;c[2440596]=g;b[4830480]=k+1&65535;e=k&65535;f=c[l+68+(e>>>8<<2)>>2]|0;do{if((f|0)==0){h=c[l+3168>>2]|0;if((h|0)==0){n=0;o=g;p=j;q=l;break}d=gj[h&4095](k)|0;n=d;o=c[2440596]|0;p=a[9660972]|0;q=c[2443776]|0}else{n=a[f+(e&255)|0]|0;o=g;p=j;q=l}}while(0);a[9660973]=n;l=o-1|0;c[2440596]=l;o=(n&255)<<8;n=a[9660978]|0;j=(n&255)+(p&255)&255|o;do{if((c[q+68+((o&65535)>>>8<<2)>>2]|0)==0){p=c[q+3148>>2]|0;if((p|0)==0){r=l;s=n;t=q;break}gj[p&4095](j)|0;r=c[2440596]|0;s=a[9660978]|0;t=c[2443776]|0}else{r=l;s=n;t=q}}while(0);q=r-1|0;c[2440596]=q;b[4830486]=(b[4830486]|0)+(s&255)&65535;s=c[2415243]|0;r=s&65535;n=c[t+68+((s>>>8&255)<<2)>>2]|0;do{if((n|0)==0){l=c[t+3148>>2]|0;if((l|0)==0){u=0;v=q;w=s;x=t;break}j=gj[l&4095](r)|0;u=j;v=c[2440596]|0;w=c[2415243]|0;x=c[2443776]|0}else{u=a[n+(s&255)|0]|0;v=q;w=s;x=t}}while(0);t=v-1|0;c[2440596]=t;v=w&65535;s=c[x+68+((w>>>8&255|256)<<2)>>2]|0;do{if((s|0)==0){q=c[x+3152>>2]|0;if((q|0)==0){y=t;break}gg[q&4095](v,u);y=c[2440596]|0}else{a[s+(w&255)|0]=u;y=t}}while(0);t=y-1|0;c[2440596]=t;y=u-1&255;u=a[9660979]|0;w=u&-2;a[9660979]=w;s=a[9660976]|0;if((s&255)<(y&255)){z=w}else{w=u|1;a[9660979]=w;z=w}if(s<<24>>24==y<<24>>24){A=z&125|2}else{A=z&125|s-y&255&-128}a[9660979]=A;A=c[2415243]|0;s=c[2443776]|0;z=c[s+68+((A>>>8&255|256)<<2)>>2]|0;if((z|0)!=0){a[z+(A&255)|0]=y;B=t;C=B-1|0;c[2440596]=C;return}z=c[s+3152>>2]|0;if((z|0)==0){B=t;C=B-1|0;c[2440596]=C;return}gg[z&4095](A&65535,y);B=c[2440596]|0;C=B-1|0;c[2440596]=C;return}function fVW(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;g=(c[2440596]|0)-1|0;c[2440596]=g;b[4830480]=k+1&65535;e=k&65535;f=c[l+68+(e>>>8<<2)>>2]|0;do{if((f|0)==0){h=c[l+3168>>2]|0;if((h|0)==0){n=0;o=g;p=j;q=l;break}d=gj[h&4095](k)|0;n=d;o=c[2440596]|0;p=a[9660972]|0;q=c[2443776]|0}else{n=a[f+(e&255)|0]|0;o=g;p=j;q=l}}while(0);a[9660973]=n;l=o-1|0;c[2440596]=l;o=(n&255)<<8;n=a[9660978]|0;j=(n&255)+(p&255)&255|o;do{if((c[q+68+((o&65535)>>>8<<2)>>2]|0)==0){p=c[q+3148>>2]|0;if((p|0)==0){r=l;s=n;t=q;break}gj[p&4095](j)|0;r=c[2440596]|0;s=a[9660978]|0;t=c[2443776]|0}else{r=l;s=n;t=q}}while(0);q=r-1|0;c[2440596]=q;b[4830486]=(b[4830486]|0)+(s&255)&65535;s=c[2415243]|0;r=s&65535;n=c[t+68+((s>>>8&255)<<2)>>2]|0;do{if((n|0)==0){l=c[t+3148>>2]|0;if((l|0)==0){u=0;v=q;w=s;x=t;break}j=gj[l&4095](r)|0;u=j;v=c[2440596]|0;w=c[2415243]|0;x=c[2443776]|0}else{u=a[n+(s&255)|0]|0;v=q;w=s;x=t}}while(0);t=v-1|0;c[2440596]=t;v=w&65535;s=c[x+68+((w>>>8&255|256)<<2)>>2]|0;do{if((s|0)==0){q=c[x+3152>>2]|0;if((q|0)==0){y=t;break}gg[q&4095](v,u);y=c[2440596]|0}else{a[s+(w&255)|0]=u;y=t}}while(0);t=y-1|0;c[2440596]=t;y=u+1&255;u=y&255;w=a[9660979]|0;s=w&255;v=s&1^1;x=a[9660976]|0;q=x&255;n=q-u-v|0;do{if((s&8|0)==0){r=w&-66;j=(((x^y)&128&(n^q)|0)==0?r:r|64)|(n&65280|0)==0;a[9660979]=j;a[9660976]=n&255;if((n&255|0)==0){a[9660979]=j&125|2;break}else{a[9660979]=(j&125|n&128)&255;break}}else{j=(q&15)-(u&15)-v|0;r=(q&240)-(u&240)|0;if((j&16|0)==0){z=j;A=r}else{z=j-6|0;A=r-1|0}r=w&60;j=(((x^y)&128&(n^q)|0)==0?r:r|64)|(n&65280|0)==0;r=(n&255|0)==0?j|2:j;a[9660979]=(n&128|0)==0?r:r|-128;a[9660976]=(((A&256|0)==0?A:A+160|0)&240|z&15)&255}}while(0);z=c[2415243]|0;A=c[2443776]|0;n=c[A+68+((z>>>8&255|256)<<2)>>2]|0;if((n|0)!=0){a[n+(z&255)|0]=y;B=t;C=B-1|0;c[2440596]=C;return}n=c[A+3152>>2]|0;if((n|0)==0){B=t;C=B-1|0;c[2440596]=C;return}gg[n&4095](z&65535,y);B=c[2440596]|0;C=B-1|0;c[2440596]=C;return}function fVX(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;b[4830480]=k+1&65535;g=k&65535;e=c[l+68+(g>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[l+3168>>2]|0;if((f|0)==0){n=0;o=j;p=l;break}h=gj[f&4095](k)|0;n=h;o=c[2440596]|0;p=c[2443776]|0}else{n=a[e+(g&255)|0]|0;o=j;p=l}}while(0);a[9660973]=n;n=o-1|0;c[2440596]=n;o=c[2415243]|0;if((c[p+68+((o>>>8&255)<<2)>>2]|0)!=0){q=n;r=q-1|0;c[2440596]=r;return}l=c[p+3148>>2]|0;if((l|0)==0){q=n;r=q-1|0;c[2440596]=r;return}gj[l&4095](o&65535)|0;q=c[2440596]|0;r=q-1|0;c[2440596]=r;return}function fVY(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;b[4830480]=k+1&65535;g=k&65535;e=c[l+68+(g>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[l+3168>>2]|0;if((f|0)==0){n=0;o=j;p=l;break}h=gj[f&4095](k)|0;n=h;o=c[2440596]|0;p=c[2443776]|0}else{n=a[e+(g&255)|0]|0;o=j;p=l}}while(0);a[9660973]=n;n=o-1|0;c[2440596]=n;o=c[2415243]|0;l=o&65535;j=c[p+68+((o>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[p+3148>>2]|0;if((g|0)==0){q=0;r=n;break}e=gj[g&4095](l)|0;q=e;r=c[2440596]|0}else{q=a[j+(o&255)|0]|0;r=n}}while(0);c[2440596]=r-1;r=a[9660979]&61|q&-64;a[9660979]=r;if((a[9660976]&q)<<24>>24!=0){return}a[9660979]=r|2;return}function fVZ(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;b[4830480]=k+1&65535;g=k&65535;e=c[l+68+(g>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[l+3168>>2]|0;if((f|0)==0){n=0;o=j;break}h=gj[f&4095](k)|0;n=h;o=c[2440596]|0}else{n=a[e+(g&255)|0]|0;o=j}}while(0);a[9660973]=n;n=o-1|0;c[2440596]=n;o=c[2415243]|0;if(!((n|0)>0&(((o|0)!=(c[2415239]|0)|(a[9660980]|0)!=0|(a[9660981]|0)!=0)^1))){c[2415240]=o;return}c[2440596]=0;c[2415240]=o;return}function fV_(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;b[4830480]=k+1&65535;g=k&65535;e=c[l+68+(g>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[l+3168>>2]|0;if((f|0)==0){n=0;o=j;p=l;break}h=gj[f&4095](k)|0;n=h;o=c[2440596]|0;p=c[2443776]|0}else{n=a[e+(g&255)|0]|0;o=j;p=l}}while(0);a[9660973]=n;n=o-1|0;c[2440596]=n;o=c[2415243]|0;l=o&65535;j=c[p+68+((o>>>8&255)<<2)>>2]|0;g=o&255;do{if((j|0)==0){e=c[p+3148>>2]|0;if((e|0)==0){q=0;r=n;s=g;t=p;break}k=gj[e&4095](l)|0;q=k;r=c[2440596]|0;s=a[9660972]|0;t=c[2443776]|0}else{q=a[j+(o&255)|0]|0;r=n;s=g;t=p}}while(0);p=r-1|0;c[2440596]=p;a[9660972]=s+1&255;s=c[2415243]|0;r=s&65535;g=c[t+68+((s>>>8&255)<<2)>>2]|0;do{if((g|0)==0){n=c[t+3148>>2]|0;if((n|0)==0){u=0;v=p;break}o=gj[n&4095](r)|0;u=o;v=c[2440596]|0}else{u=a[g+(s&255)|0]|0;v=p}}while(0);a[9660973]=u;u=v-1|0;c[2440596]=u;a[9660972]=q;q=c[2415243]|0;if(!((u|0)>0&(((q|0)!=(c[2415239]|0)|(a[9660980]|0)!=0|(a[9660981]|0)!=0)^1))){c[2415240]=q;return}c[2440596]=0;c[2415240]=q;return}function fV$(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=a[9660978]|0;e=b[4830480]|0;f=e+1&65535;b[4830480]=f;g=e&65535;h=c[2443776]|0;i=c[h+68+(g>>>8<<2)>>2]|0;do{if((i|0)==0){j=c[h+3168>>2]|0;if((j|0)==0){k=0;l=f;m=h;break}n=gj[j&4095](e)|0;k=n;l=b[4830480]|0;m=c[2443776]|0}else{k=a[i+(g&255)|0]|0;l=f;m=h}}while(0);a[9660972]=k;k=(c[2440596]|0)-1|0;c[2440596]=k;b[4830480]=l+1&65535;h=l&65535;f=c[m+68+(h>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[m+3168>>2]|0;if((g|0)==0){o=0;p=k;q=m;break}i=gj[g&4095](l)|0;o=i;p=c[2440596]|0;q=c[2443776]|0}else{o=a[f+(h&255)|0]|0;p=k;q=m}}while(0);a[9660973]=o;o=p-1|0;c[2440596]=o;p=c[2415243]|0;m=c[q+68+((p>>>8&255|256)<<2)>>2]|0;if((m|0)!=0){a[m+(p&255)|0]=d;r=o;s=r-1|0;c[2440596]=s;return}m=c[q+3152>>2]|0;if((m|0)==0){r=o;s=r-1|0;c[2440596]=s;return}gg[m&4095](p&65535,d);r=c[2440596]|0;s=r-1|0;c[2440596]=s;return}function fV0(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;b[4830480]=k+1&65535;g=k&65535;e=c[l+68+(g>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[l+3168>>2]|0;if((f|0)==0){n=0;o=j;p=l;break}h=gj[f&4095](k)|0;n=h;o=c[2440596]|0;p=c[2443776]|0}else{n=a[e+(g&255)|0]|0;o=j;p=l}}while(0);a[9660973]=n;n=o-1|0;c[2440596]=n;o=c[2415243]|0;l=o&65535;j=c[p+68+((o>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[p+3148>>2]|0;if((g|0)==0){q=0;r=n;break}e=gj[g&4095](l)|0;q=e;r=c[2440596]|0}else{q=a[j+(o&255)|0]|0;r=n}}while(0);c[2440596]=r-1;a[9660978]=q;a[9660979]=a[9660979]&125|(q<<24>>24==0?2:q&-128);return}function fV1(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;b[4830480]=k+1&65535;g=k&65535;e=c[l+68+(g>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[l+3168>>2]|0;if((f|0)==0){n=0;o=j;p=l;break}h=gj[f&4095](k)|0;n=h;o=c[2440596]|0;p=c[2443776]|0}else{n=a[e+(g&255)|0]|0;o=j;p=l}}while(0);a[9660973]=n;n=o-1|0;c[2440596]=n;o=c[2415243]|0;l=o&65535;j=c[p+68+((o>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[p+3148>>2]|0;if((g|0)==0){q=0;r=n;break}e=gj[g&4095](l)|0;q=e;r=c[2440596]|0}else{q=a[j+(o&255)|0]|0;r=n}}while(0);c[2440596]=r-1;r=a[9660979]|0;n=r&-2;a[9660979]=n;o=a[9660978]|0;if((o&255)<(q&255)){s=n}else{n=r|1;a[9660979]=n;s=n}if(o<<24>>24==q<<24>>24){t=s&125|2;a[9660979]=t;return}else{t=s&125|o-q&255&-128;a[9660979]=t;return}}function fV2(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;b[4830480]=k+1&65535;g=k&65535;e=c[l+68+(g>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[l+3168>>2]|0;if((f|0)==0){n=0;o=j;p=l;break}h=gj[f&4095](k)|0;n=h;o=c[2440596]|0;p=c[2443776]|0}else{n=a[e+(g&255)|0]|0;o=j;p=l}}while(0);a[9660973]=n;n=o-1|0;c[2440596]=n;o=c[2415243]|0;l=o&65535;j=c[p+68+((o>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[p+3148>>2]|0;if((g|0)==0){q=0;r=n;break}e=gj[g&4095](l)|0;q=e;r=c[2440596]|0}else{q=a[j+(o&255)|0]|0;r=n}}while(0);c[2440596]=r-1;r=a[9660979]|0;n=r&-2;a[9660979]=n;o=a[9660977]|0;if((o&255)<(q&255)){s=n}else{n=r|1;a[9660979]=n;s=n}if(o<<24>>24==q<<24>>24){t=s&125|2;a[9660979]=t;return}else{t=s&125|o-q&255&-128;a[9660979]=t;return}}function fV3(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;g=(c[2440596]|0)-1|0;c[2440596]=g;b[4830480]=k+1&65535;e=k&65535;f=c[l+68+(e>>>8<<2)>>2]|0;do{if((f|0)==0){h=c[l+3168>>2]|0;if((h|0)==0){n=0;o=g;p=j;break}d=gj[h&4095](k)|0;n=d;o=c[2440596]|0;p=a[9660972]|0}else{n=a[f+(e&255)|0]|0;o=g;p=j}}while(0);a[9660973]=n;j=o-1|0;c[2440596]=j;o=a[9660977]|0;g=(o&255)+(p&255)|0;if((g|0)>255){p=n&255;n=(g&255|p<<8)&65535;g=c[2443776]|0;do{if((c[g+68+(p<<2)>>2]|0)==0){e=c[g+3148>>2]|0;if((e|0)==0){q=j;r=o;break}gj[e&4095](n)|0;q=c[2440596]|0;r=a[9660977]|0}else{q=j;r=o}}while(0);n=q-1|0;c[2440596]=n;s=r;t=n}else{s=o;t=j}b[4830486]=(b[4830486]|0)+(s&255)&65535;s=c[2415243]|0;j=c[2443776]|0;if((c[j+68+((s>>>8&255)<<2)>>2]|0)!=0){u=t;v=u-1|0;c[2440596]=v;return}o=c[j+3148>>2]|0;if((o|0)==0){u=t;v=u-1|0;c[2440596]=v;return}gj[o&4095](s&65535)|0;u=c[2440596]|0;v=u-1|0;c[2440596]=v;return}function fV4(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;g=(c[2440596]|0)-1|0;c[2440596]=g;b[4830480]=k+1&65535;e=k&65535;f=c[l+68+(e>>>8<<2)>>2]|0;do{if((f|0)==0){h=c[l+3168>>2]|0;if((h|0)==0){n=0;o=g;p=j;break}d=gj[h&4095](k)|0;n=d;o=c[2440596]|0;p=a[9660972]|0}else{n=a[f+(e&255)|0]|0;o=g;p=j}}while(0);a[9660973]=n;j=o-1|0;c[2440596]=j;o=a[9660977]|0;g=(o&255)+(p&255)|0;if((g|0)>255){p=n&255;n=(g&255|p<<8)&65535;g=c[2443776]|0;do{if((c[g+68+(p<<2)>>2]|0)==0){e=c[g+3148>>2]|0;if((e|0)==0){q=j;r=o;break}gj[e&4095](n)|0;q=c[2440596]|0;r=a[9660977]|0}else{q=j;r=o}}while(0);n=q-1|0;c[2440596]=n;s=r;t=n}else{s=o;t=j}b[4830486]=(b[4830486]|0)+(s&255)&65535;s=c[2415243]|0;j=c[2443776]|0;if((c[j+68+((s>>>8&255)<<2)>>2]|0)!=0){u=t;v=u-1|0;c[2440596]=v;return}o=c[j+3148>>2]|0;if((o|0)==0){u=t;v=u-1|0;c[2440596]=v;return}gj[o&4095](s&65535)|0;u=c[2440596]|0;v=u-1|0;c[2440596]=v;return}function fV5(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;g=(c[2440596]|0)-1|0;c[2440596]=g;b[4830480]=k+1&65535;e=k&65535;f=c[l+68+(e>>>8<<2)>>2]|0;do{if((f|0)==0){h=c[l+3168>>2]|0;if((h|0)==0){n=0;o=g;p=j;break}d=gj[h&4095](k)|0;n=d;o=c[2440596]|0;p=a[9660972]|0}else{n=a[f+(e&255)|0]|0;o=g;p=j}}while(0);a[9660973]=n;j=o-1|0;c[2440596]=j;o=a[9660977]|0;g=(o&255)+(p&255)|0;if((g|0)>255){p=n&255;n=(g&255|p<<8)&65535;g=c[2443776]|0;do{if((c[g+68+(p<<2)>>2]|0)==0){e=c[g+3148>>2]|0;if((e|0)==0){q=j;r=o;break}gj[e&4095](n)|0;q=c[2440596]|0;r=a[9660977]|0}else{q=j;r=o}}while(0);n=q-1|0;c[2440596]=n;s=r;t=n}else{s=o;t=j}b[4830486]=(b[4830486]|0)+(s&255)&65535;s=c[2415243]|0;j=c[2443776]|0;if((c[j+68+((s>>>8&255)<<2)>>2]|0)!=0){u=t;v=u-1|0;c[2440596]=v;return}o=c[j+3148>>2]|0;if((o|0)==0){u=t;v=u-1|0;c[2440596]=v;return}gj[o&4095](s&65535)|0;u=c[2440596]|0;v=u-1|0;c[2440596]=v;return}function fV6(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;g=(c[2440596]|0)-1|0;c[2440596]=g;b[4830480]=k+1&65535;e=k&65535;f=c[l+68+(e>>>8<<2)>>2]|0;do{if((f|0)==0){h=c[l+3168>>2]|0;if((h|0)==0){n=0;o=g;p=j;break}d=gj[h&4095](k)|0;n=d;o=c[2440596]|0;p=a[9660972]|0}else{n=a[f+(e&255)|0]|0;o=g;p=j}}while(0);a[9660973]=n;j=o-1|0;c[2440596]=j;o=a[9660977]|0;g=(o&255)+(p&255)|0;if((g|0)>255){p=n&255;n=(g&255|p<<8)&65535;g=c[2443776]|0;do{if((c[g+68+(p<<2)>>2]|0)==0){e=c[g+3148>>2]|0;if((e|0)==0){q=j;r=o;break}gj[e&4095](n)|0;q=c[2440596]|0;r=a[9660977]|0}else{q=j;r=o}}while(0);n=q-1|0;c[2440596]=n;s=r;t=n}else{s=o;t=j}b[4830486]=(b[4830486]|0)+(s&255)&65535;s=c[2415243]|0;j=c[2443776]|0;if((c[j+68+((s>>>8&255)<<2)>>2]|0)!=0){u=t;v=u-1|0;c[2440596]=v;return}o=c[j+3148>>2]|0;if((o|0)==0){u=t;v=u-1|0;c[2440596]=v;return}gj[o&4095](s&65535)|0;u=c[2440596]|0;v=u-1|0;c[2440596]=v;return}function fV7(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;g=(c[2440596]|0)-1|0;c[2440596]=g;b[4830480]=k+1&65535;e=k&65535;f=c[l+68+(e>>>8<<2)>>2]|0;do{if((f|0)==0){h=c[l+3168>>2]|0;if((h|0)==0){n=0;o=g;p=j;q=l;break}d=gj[h&4095](k)|0;n=d;o=c[2440596]|0;p=a[9660972]|0;q=c[2443776]|0}else{n=a[f+(e&255)|0]|0;o=g;p=j;q=l}}while(0);a[9660973]=n;l=o-1|0;c[2440596]=l;o=(n&255)<<8;n=a[9660977]|0;j=(n&255)+(p&255)&255|o;do{if((c[q+68+((o&65535)>>>8<<2)>>2]|0)==0){p=c[q+3148>>2]|0;if((p|0)==0){r=l;s=n;t=q;break}gj[p&4095](j)|0;r=c[2440596]|0;s=a[9660977]|0;t=c[2443776]|0}else{r=l;s=n;t=q}}while(0);q=r-1|0;c[2440596]=q;r=(b[4830486]|0)+(s&255)&65535;b[4830486]=r;s=((r&65535)>>>8&255)+1&255&a[9660978];r=c[2415243]|0;n=c[t+68+((r>>>8&255|256)<<2)>>2]|0;if((n|0)!=0){a[n+(r&255)|0]=s;u=q;v=u-1|0;c[2440596]=v;return}n=c[t+3152>>2]|0;if((n|0)==0){u=q;v=u-1|0;c[2440596]=v;return}gg[n&4095](r&65535,s);u=c[2440596]|0;v=u-1|0;c[2440596]=v;return}function fV8(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;g=(c[2440596]|0)-1|0;c[2440596]=g;b[4830480]=k+1&65535;e=k&65535;f=c[l+68+(e>>>8<<2)>>2]|0;do{if((f|0)==0){h=c[l+3168>>2]|0;if((h|0)==0){n=0;o=g;p=j;break}d=gj[h&4095](k)|0;n=d;o=c[2440596]|0;p=a[9660972]|0}else{n=a[f+(e&255)|0]|0;o=g;p=j}}while(0);a[9660973]=n;j=o-1|0;c[2440596]=j;o=a[9660977]|0;g=(o&255)+(p&255)|0;if((g|0)>255){p=n&255;n=(g&255|p<<8)&65535;g=c[2443776]|0;do{if((c[g+68+(p<<2)>>2]|0)==0){e=c[g+3148>>2]|0;if((e|0)==0){q=j;r=o;break}gj[e&4095](n)|0;q=c[2440596]|0;r=a[9660977]|0}else{q=j;r=o}}while(0);n=q-1|0;c[2440596]=n;s=r;t=n}else{s=o;t=j}b[4830486]=(b[4830486]|0)+(s&255)&65535;s=c[2415243]|0;j=s&65535;o=c[2443776]|0;n=c[o+68+((s>>>8&255)<<2)>>2]|0;do{if((n|0)==0){r=c[o+3148>>2]|0;if((r|0)==0){u=0;v=t;break}q=gj[r&4095](j)|0;u=q;v=c[2440596]|0}else{u=a[n+(s&255)|0]|0;v=t}}while(0);c[2440596]=v-1;a[9660978]=u;a[9660979]=a[9660979]&125|(u<<24>>24==0?2:u&-128);return}function fV9(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;g=(c[2440596]|0)-1|0;c[2440596]=g;b[4830480]=k+1&65535;e=k&65535;f=c[l+68+(e>>>8<<2)>>2]|0;do{if((f|0)==0){h=c[l+3168>>2]|0;if((h|0)==0){n=0;o=g;p=j;break}d=gj[h&4095](k)|0;n=d;o=c[2440596]|0;p=a[9660972]|0}else{n=a[f+(e&255)|0]|0;o=g;p=j}}while(0);a[9660973]=n;j=o-1|0;c[2440596]=j;o=a[9660977]|0;g=(o&255)+(p&255)|0;if((g|0)>255){p=n&255;n=(g&255|p<<8)&65535;g=c[2443776]|0;do{if((c[g+68+(p<<2)>>2]|0)==0){e=c[g+3148>>2]|0;if((e|0)==0){q=j;r=o;break}gj[e&4095](n)|0;q=c[2440596]|0;r=a[9660977]|0}else{q=j;r=o}}while(0);n=q-1|0;c[2440596]=n;s=r;t=n}else{s=o;t=j}b[4830486]=(b[4830486]|0)+(s&255)&65535;s=c[2415243]|0;j=c[2443776]|0;if((c[j+68+((s>>>8&255)<<2)>>2]|0)!=0){u=t;v=u-1|0;c[2440596]=v;return}o=c[j+3148>>2]|0;if((o|0)==0){u=t;v=u-1|0;c[2440596]=v;return}gj[o&4095](s&65535)|0;u=c[2440596]|0;v=u-1|0;c[2440596]=v;return}function fWa(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;g=(c[2440596]|0)-1|0;c[2440596]=g;b[4830480]=k+1&65535;e=k&65535;f=c[l+68+(e>>>8<<2)>>2]|0;do{if((f|0)==0){h=c[l+3168>>2]|0;if((h|0)==0){n=0;o=g;p=j;break}d=gj[h&4095](k)|0;n=d;o=c[2440596]|0;p=a[9660972]|0}else{n=a[f+(e&255)|0]|0;o=g;p=j}}while(0);a[9660973]=n;j=o-1|0;c[2440596]=j;o=a[9660977]|0;g=(o&255)+(p&255)|0;if((g|0)>255){p=n&255;n=(g&255|p<<8)&65535;g=c[2443776]|0;do{if((c[g+68+(p<<2)>>2]|0)==0){e=c[g+3148>>2]|0;if((e|0)==0){q=j;r=o;break}gj[e&4095](n)|0;q=c[2440596]|0;r=a[9660977]|0}else{q=j;r=o}}while(0);n=q-1|0;c[2440596]=n;s=r;t=n}else{s=o;t=j}b[4830486]=(b[4830486]|0)+(s&255)&65535;s=c[2415243]|0;j=c[2443776]|0;if((c[j+68+((s>>>8&255)<<2)>>2]|0)!=0){u=t;v=u-1|0;c[2440596]=v;return}o=c[j+3148>>2]|0;if((o|0)==0){u=t;v=u-1|0;c[2440596]=v;return}gj[o&4095](s&65535)|0;u=c[2440596]|0;v=u-1|0;c[2440596]=v;return}function fWb(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;b[4830480]=k+1&65535;g=k&65535;e=c[l+68+(g>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[l+3168>>2]|0;if((f|0)==0){n=0;o=j;p=l;break}h=gj[f&4095](k)|0;n=h;o=c[2440596]|0;p=c[2443776]|0}else{n=a[e+(g&255)|0]|0;o=j;p=l}}while(0);a[9660973]=n;n=o-1|0;c[2440596]=n;o=c[2415243]|0;l=o&65535;j=c[p+68+((o>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[p+3148>>2]|0;if((g|0)==0){q=0;r=n;break}e=gj[g&4095](l)|0;q=e;r=c[2440596]|0}else{q=a[j+(o&255)|0]|0;r=n}}while(0);c[2440596]=r-1;r=a[9660976]|q;a[9660976]=r;a[9660979]=(r<<24>>24==0?2:r&-128)|a[9660979]&125;return}function fWc(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;b[4830480]=k+1&65535;g=k&65535;e=c[l+68+(g>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[l+3168>>2]|0;if((f|0)==0){n=0;o=j;p=l;break}h=gj[f&4095](k)|0;n=h;o=c[2440596]|0;p=c[2443776]|0}else{n=a[e+(g&255)|0]|0;o=j;p=l}}while(0);a[9660973]=n;n=o-1|0;c[2440596]=n;o=c[2415243]|0;l=o&65535;j=c[p+68+((o>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[p+3148>>2]|0;if((g|0)==0){q=0;r=n;break}e=gj[g&4095](l)|0;q=e;r=c[2440596]|0}else{q=a[j+(o&255)|0]|0;r=n}}while(0);c[2440596]=r-1;r=a[9660976]&q;a[9660976]=r;a[9660979]=(r<<24>>24==0?2:r&-128)|a[9660979]&125;return}function fWd(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;b[4830480]=k+1&65535;g=k&65535;e=c[l+68+(g>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[l+3168>>2]|0;if((f|0)==0){n=0;o=j;p=l;break}h=gj[f&4095](k)|0;n=h;o=c[2440596]|0;p=c[2443776]|0}else{n=a[e+(g&255)|0]|0;o=j;p=l}}while(0);a[9660973]=n;n=o-1|0;c[2440596]=n;o=c[2415243]|0;l=o&65535;j=c[p+68+((o>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[p+3148>>2]|0;if((g|0)==0){q=0;r=n;break}e=gj[g&4095](l)|0;q=e;r=c[2440596]|0}else{q=a[j+(o&255)|0]|0;r=n}}while(0);c[2440596]=r-1;r=a[9660976]|0;n=r^q;a[9660976]=n;a[9660979]=(r<<24>>24==q<<24>>24?2:n&-128)|a[9660979]&125;return}function fWe(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;b[4830480]=k+1&65535;g=k&65535;e=c[l+68+(g>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[l+3168>>2]|0;if((f|0)==0){n=0;o=j;p=l;break}h=gj[f&4095](k)|0;n=h;o=c[2440596]|0;p=c[2443776]|0}else{n=a[e+(g&255)|0]|0;o=j;p=l}}while(0);a[9660973]=n;n=o-1|0;c[2440596]=n;o=c[2415243]|0;l=o&65535;j=c[p+68+((o>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[p+3148>>2]|0;if((g|0)==0){q=0;r=n;break}e=gj[g&4095](l)|0;q=e;r=c[2440596]|0}else{q=a[j+(o&255)|0]|0;r=n}}while(0);n=q&255;c[2440596]=r-1;r=a[9660979]|0;o=r&255;j=o&1;l=a[9660976]|0;p=l&255;if((o&8|0)==0){o=p+n+j|0;e=r&-66;g=((((l^q)&128^128)&(o^p)|0)==0?e:e|64)|(o&65280|0)!=0;a[9660979]=g;a[9660976]=o&255;if((o&255|0)==0){a[9660979]=g&125|2;return}else{a[9660979]=(g&125|o&128)&255;return}}o=j+(n&15)+(p&15)|0;j=(p&240)+(n&240)|0;n=r&60;r=(o+j&255|0)==0?n|2:n;a[9660979]=r;if((o|0)>9){s=o+6|0;t=j+16|0}else{s=o;t=j}if((t&128|0)==0){u=r}else{j=r|-128;a[9660979]=j;u=j}if((((l^q)&128^128)&(t^p)|0)==0){v=u}else{p=u|64;a[9660979]=p;v=p}p=(t|0)>144?t+96|0:t;if((p&65280|0)!=0){a[9660979]=v|1}a[9660976]=(p&240|s&15)&255;return}function fWf(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=a[9660976]|0;e=b[4830480]|0;f=e+1&65535;b[4830480]=f;g=e&65535;h=c[2443776]|0;i=c[h+68+(g>>>8<<2)>>2]|0;do{if((i|0)==0){j=c[h+3168>>2]|0;if((j|0)==0){k=0;l=f;m=h;break}n=gj[j&4095](e)|0;k=n;l=b[4830480]|0;m=c[2443776]|0}else{k=a[i+(g&255)|0]|0;l=f;m=h}}while(0);a[9660972]=k;k=(c[2440596]|0)-1|0;c[2440596]=k;b[4830480]=l+1&65535;h=l&65535;f=c[m+68+(h>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[m+3168>>2]|0;if((g|0)==0){o=0;p=k;q=m;break}i=gj[g&4095](l)|0;o=i;p=c[2440596]|0;q=c[2443776]|0}else{o=a[f+(h&255)|0]|0;p=k;q=m}}while(0);a[9660973]=o;o=p-1|0;c[2440596]=o;p=c[2415243]|0;m=c[q+68+((p>>>8&255|256)<<2)>>2]|0;if((m|0)!=0){a[m+(p&255)|0]=d;r=o;s=r-1|0;c[2440596]=s;return}m=c[q+3152>>2]|0;if((m|0)==0){r=o;s=r-1|0;c[2440596]=s;return}gg[m&4095](p&65535,d);r=c[2440596]|0;s=r-1|0;c[2440596]=s;return}function fWg(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;b[4830480]=k+1&65535;g=k&65535;e=c[l+68+(g>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[l+3168>>2]|0;if((f|0)==0){n=0;o=j;p=l;break}h=gj[f&4095](k)|0;n=h;o=c[2440596]|0;p=c[2443776]|0}else{n=a[e+(g&255)|0]|0;o=j;p=l}}while(0);a[9660973]=n;n=o-1|0;c[2440596]=n;o=c[2415243]|0;l=o&65535;j=c[p+68+((o>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[p+3148>>2]|0;if((g|0)==0){q=0;r=n;break}e=gj[g&4095](l)|0;q=e;r=c[2440596]|0}else{q=a[j+(o&255)|0]|0;r=n}}while(0);c[2440596]=r-1;a[9660976]=q;a[9660979]=a[9660979]&125|(q<<24>>24==0?2:q&-128);return}function fWh(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;b[4830480]=k+1&65535;g=k&65535;e=c[l+68+(g>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[l+3168>>2]|0;if((f|0)==0){n=0;o=j;p=l;break}h=gj[f&4095](k)|0;n=h;o=c[2440596]|0;p=c[2443776]|0}else{n=a[e+(g&255)|0]|0;o=j;p=l}}while(0);a[9660973]=n;n=o-1|0;c[2440596]=n;o=c[2415243]|0;l=o&65535;j=c[p+68+((o>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[p+3148>>2]|0;if((g|0)==0){q=0;r=n;break}e=gj[g&4095](l)|0;q=e;r=c[2440596]|0}else{q=a[j+(o&255)|0]|0;r=n}}while(0);c[2440596]=r-1;r=a[9660979]|0;n=r&-2;a[9660979]=n;o=a[9660976]|0;if((o&255)<(q&255)){s=n}else{n=r|1;a[9660979]=n;s=n}if(o<<24>>24==q<<24>>24){t=s&125|2;a[9660979]=t;return}else{t=s&125|o-q&255&-128;a[9660979]=t;return}}function fWi(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;b[4830480]=k+1&65535;g=k&65535;e=c[l+68+(g>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[l+3168>>2]|0;if((f|0)==0){n=0;o=j;p=l;break}h=gj[f&4095](k)|0;n=h;o=c[2440596]|0;p=c[2443776]|0}else{n=a[e+(g&255)|0]|0;o=j;p=l}}while(0);a[9660973]=n;n=o-1|0;c[2440596]=n;o=c[2415243]|0;l=o&65535;j=c[p+68+((o>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[p+3148>>2]|0;if((g|0)==0){q=0;r=n;break}e=gj[g&4095](l)|0;q=e;r=c[2440596]|0}else{q=a[j+(o&255)|0]|0;r=n}}while(0);n=q&255;c[2440596]=r-1;r=a[9660979]|0;o=r&255;j=o&1^1;l=a[9660976]|0;p=l&255;e=p-n-j|0;if((o&8|0)!=0){o=(p&15)-(n&15)-j|0;j=(p&240)-(n&240)|0;if((o&16|0)==0){s=o;t=j}else{s=o-6|0;t=j-1|0}j=r&60;o=(((l^q)&128&(e^p)|0)==0?j:j|64)|(e&65280|0)==0;j=(e&255|0)==0?o|2:o;a[9660979]=(e&128|0)==0?j:j|-128;a[9660976]=(((t&256|0)==0?t:t+160|0)&240|s&15)&255;return}s=r&-66;r=(((l^q)&128&(e^p)|0)==0?s:s|64)|(e&65280|0)==0;a[9660979]=r;a[9660976]=e&255;if((e&255|0)==0){a[9660979]=r&125|2;return}else{a[9660979]=(r&125|e&128)&255;return}}function fWj(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;g=(c[2440596]|0)-1|0;c[2440596]=g;b[4830480]=k+1&65535;e=k&65535;f=c[l+68+(e>>>8<<2)>>2]|0;do{if((f|0)==0){h=c[l+3168>>2]|0;if((h|0)==0){n=0;o=g;p=j;break}d=gj[h&4095](k)|0;n=d;o=c[2440596]|0;p=a[9660972]|0}else{n=a[f+(e&255)|0]|0;o=g;p=j}}while(0);a[9660973]=n;j=o-1|0;c[2440596]=j;o=a[9660977]|0;g=(o&255)+(p&255)|0;if((g|0)>255){p=n&255;n=(g&255|p<<8)&65535;g=c[2443776]|0;do{if((c[g+68+(p<<2)>>2]|0)==0){e=c[g+3148>>2]|0;if((e|0)==0){q=j;r=o;break}gj[e&4095](n)|0;q=c[2440596]|0;r=a[9660977]|0}else{q=j;r=o}}while(0);n=q-1|0;c[2440596]=n;s=r;t=n}else{s=o;t=j}b[4830486]=(b[4830486]|0)+(s&255)&65535;s=c[2415243]|0;j=s&65535;o=c[2443776]|0;n=c[o+68+((s>>>8&255)<<2)>>2]|0;do{if((n|0)==0){r=c[o+3148>>2]|0;if((r|0)==0){u=0;v=t;break}q=gj[r&4095](j)|0;u=q;v=c[2440596]|0}else{u=a[n+(s&255)|0]|0;v=t}}while(0);c[2440596]=v-1;v=a[9660976]|u;a[9660976]=v;a[9660979]=(v<<24>>24==0?2:v&-128)|a[9660979]&125;return}function fWk(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;g=(c[2440596]|0)-1|0;c[2440596]=g;b[4830480]=k+1&65535;e=k&65535;f=c[l+68+(e>>>8<<2)>>2]|0;do{if((f|0)==0){h=c[l+3168>>2]|0;if((h|0)==0){n=0;o=g;p=j;break}d=gj[h&4095](k)|0;n=d;o=c[2440596]|0;p=a[9660972]|0}else{n=a[f+(e&255)|0]|0;o=g;p=j}}while(0);a[9660973]=n;j=o-1|0;c[2440596]=j;o=a[9660977]|0;g=(o&255)+(p&255)|0;if((g|0)>255){p=n&255;n=(g&255|p<<8)&65535;g=c[2443776]|0;do{if((c[g+68+(p<<2)>>2]|0)==0){e=c[g+3148>>2]|0;if((e|0)==0){q=j;r=o;break}gj[e&4095](n)|0;q=c[2440596]|0;r=a[9660977]|0}else{q=j;r=o}}while(0);n=q-1|0;c[2440596]=n;s=r;t=n}else{s=o;t=j}b[4830486]=(b[4830486]|0)+(s&255)&65535;s=c[2415243]|0;j=s&65535;o=c[2443776]|0;n=c[o+68+((s>>>8&255)<<2)>>2]|0;do{if((n|0)==0){r=c[o+3148>>2]|0;if((r|0)==0){u=0;v=t;break}q=gj[r&4095](j)|0;u=q;v=c[2440596]|0}else{u=a[n+(s&255)|0]|0;v=t}}while(0);c[2440596]=v-1;v=a[9660976]&u;a[9660976]=v;a[9660979]=(v<<24>>24==0?2:v&-128)|a[9660979]&125;return}function fWl(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;g=(c[2440596]|0)-1|0;c[2440596]=g;b[4830480]=k+1&65535;e=k&65535;f=c[l+68+(e>>>8<<2)>>2]|0;do{if((f|0)==0){h=c[l+3168>>2]|0;if((h|0)==0){n=0;o=g;p=j;break}d=gj[h&4095](k)|0;n=d;o=c[2440596]|0;p=a[9660972]|0}else{n=a[f+(e&255)|0]|0;o=g;p=j}}while(0);a[9660973]=n;j=o-1|0;c[2440596]=j;o=a[9660977]|0;g=(o&255)+(p&255)|0;if((g|0)>255){p=n&255;n=(g&255|p<<8)&65535;g=c[2443776]|0;do{if((c[g+68+(p<<2)>>2]|0)==0){e=c[g+3148>>2]|0;if((e|0)==0){q=j;r=o;break}gj[e&4095](n)|0;q=c[2440596]|0;r=a[9660977]|0}else{q=j;r=o}}while(0);n=q-1|0;c[2440596]=n;s=r;t=n}else{s=o;t=j}b[4830486]=(b[4830486]|0)+(s&255)&65535;s=c[2415243]|0;j=s&65535;o=c[2443776]|0;n=c[o+68+((s>>>8&255)<<2)>>2]|0;do{if((n|0)==0){r=c[o+3148>>2]|0;if((r|0)==0){u=0;v=t;break}q=gj[r&4095](j)|0;u=q;v=c[2440596]|0}else{u=a[n+(s&255)|0]|0;v=t}}while(0);c[2440596]=v-1;v=a[9660976]|0;t=v^u;a[9660976]=t;a[9660979]=(v<<24>>24==u<<24>>24?2:t&-128)|a[9660979]&125;return}function fWm(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;g=(c[2440596]|0)-1|0;c[2440596]=g;b[4830480]=k+1&65535;e=k&65535;f=c[l+68+(e>>>8<<2)>>2]|0;do{if((f|0)==0){h=c[l+3168>>2]|0;if((h|0)==0){n=0;o=g;p=j;break}d=gj[h&4095](k)|0;n=d;o=c[2440596]|0;p=a[9660972]|0}else{n=a[f+(e&255)|0]|0;o=g;p=j}}while(0);a[9660973]=n;j=o-1|0;c[2440596]=j;o=a[9660977]|0;g=(o&255)+(p&255)|0;if((g|0)>255){p=n&255;n=(g&255|p<<8)&65535;g=c[2443776]|0;do{if((c[g+68+(p<<2)>>2]|0)==0){e=c[g+3148>>2]|0;if((e|0)==0){q=j;r=o;break}gj[e&4095](n)|0;q=c[2440596]|0;r=a[9660977]|0}else{q=j;r=o}}while(0);n=q-1|0;c[2440596]=n;s=r;t=n}else{s=o;t=j}b[4830486]=(b[4830486]|0)+(s&255)&65535;s=c[2415243]|0;j=s&65535;o=c[2443776]|0;n=c[o+68+((s>>>8&255)<<2)>>2]|0;do{if((n|0)==0){r=c[o+3148>>2]|0;if((r|0)==0){u=0;v=t;break}q=gj[r&4095](j)|0;u=q;v=c[2440596]|0}else{u=a[n+(s&255)|0]|0;v=t}}while(0);t=u&255;c[2440596]=v-1;v=a[9660979]|0;s=v&255;n=s&1;j=a[9660976]|0;o=j&255;if((s&8|0)==0){s=o+t+n|0;q=v&-66;r=((((j^u)&128^128)&(s^o)|0)==0?q:q|64)|(s&65280|0)!=0;a[9660979]=r;a[9660976]=s&255;if((s&255|0)==0){a[9660979]=r&125|2;return}else{a[9660979]=(r&125|s&128)&255;return}}s=n+(t&15)+(o&15)|0;n=(o&240)+(t&240)|0;t=v&60;v=(s+n&255|0)==0?t|2:t;a[9660979]=v;if((s|0)>9){w=s+6|0;x=n+16|0}else{w=s;x=n}if((x&128|0)==0){y=v}else{n=v|-128;a[9660979]=n;y=n}if((((j^u)&128^128)&(x^o)|0)==0){z=y}else{o=y|64;a[9660979]=o;z=o}o=(x|0)>144?x+96|0:x;if((o&65280|0)!=0){a[9660979]=z|1}a[9660976]=(o&240|w&15)&255;return}function fWn(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=a[9660976]|0;e=b[4830480]|0;f=e+1&65535;b[4830480]=f;g=e&65535;h=c[2443776]|0;i=c[h+68+(g>>>8<<2)>>2]|0;do{if((i|0)==0){j=c[h+3168>>2]|0;if((j|0)==0){k=0;l=f;m=h;break}n=gj[j&4095](e)|0;k=n;l=b[4830480]|0;m=c[2443776]|0}else{k=a[i+(g&255)|0]|0;l=f;m=h}}while(0);a[9660972]=k;h=(c[2440596]|0)-1|0;c[2440596]=h;b[4830480]=l+1&65535;f=l&65535;g=c[m+68+(f>>>8<<2)>>2]|0;do{if((g|0)==0){i=c[m+3168>>2]|0;if((i|0)==0){o=0;p=h;q=k;r=m;break}e=gj[i&4095](l)|0;o=e;p=c[2440596]|0;q=a[9660972]|0;r=c[2443776]|0}else{o=a[g+(f&255)|0]|0;p=h;q=k;r=m}}while(0);a[9660973]=o;m=p-1|0;c[2440596]=m;p=(o&255)<<8;o=a[9660977]|0;k=(o&255)+(q&255)&255|p;do{if((c[r+68+((p&65535)>>>8<<2)>>2]|0)==0){q=c[r+3148>>2]|0;if((q|0)==0){s=m;t=o;u=r;break}gj[q&4095](k)|0;s=c[2440596]|0;t=a[9660977]|0;u=c[2443776]|0}else{s=m;t=o;u=r}}while(0);r=s-1|0;c[2440596]=r;b[4830486]=(b[4830486]|0)+(t&255)&65535;t=c[2415243]|0;s=c[u+68+((t>>>8&255|256)<<2)>>2]|0;if((s|0)!=0){a[s+(t&255)|0]=d;v=r;w=v-1|0;c[2440596]=w;return}s=c[u+3152>>2]|0;if((s|0)==0){v=r;w=v-1|0;c[2440596]=w;return}gg[s&4095](t&65535,d);v=c[2440596]|0;w=v-1|0;c[2440596]=w;return}function fWo(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;g=(c[2440596]|0)-1|0;c[2440596]=g;b[4830480]=k+1&65535;e=k&65535;f=c[l+68+(e>>>8<<2)>>2]|0;do{if((f|0)==0){h=c[l+3168>>2]|0;if((h|0)==0){n=0;o=g;p=j;break}d=gj[h&4095](k)|0;n=d;o=c[2440596]|0;p=a[9660972]|0}else{n=a[f+(e&255)|0]|0;o=g;p=j}}while(0);a[9660973]=n;j=o-1|0;c[2440596]=j;o=a[9660977]|0;g=(o&255)+(p&255)|0;if((g|0)>255){p=n&255;n=(g&255|p<<8)&65535;g=c[2443776]|0;do{if((c[g+68+(p<<2)>>2]|0)==0){e=c[g+3148>>2]|0;if((e|0)==0){q=j;r=o;break}gj[e&4095](n)|0;q=c[2440596]|0;r=a[9660977]|0}else{q=j;r=o}}while(0);n=q-1|0;c[2440596]=n;s=r;t=n}else{s=o;t=j}b[4830486]=(b[4830486]|0)+(s&255)&65535;s=c[2415243]|0;j=s&65535;o=c[2443776]|0;n=c[o+68+((s>>>8&255)<<2)>>2]|0;do{if((n|0)==0){r=c[o+3148>>2]|0;if((r|0)==0){u=0;v=t;break}q=gj[r&4095](j)|0;u=q;v=c[2440596]|0}else{u=a[n+(s&255)|0]|0;v=t}}while(0);c[2440596]=v-1;a[9660976]=u;a[9660979]=a[9660979]&125|(u<<24>>24==0?2:u&-128);return}function fWp(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;g=(c[2440596]|0)-1|0;c[2440596]=g;b[4830480]=k+1&65535;e=k&65535;f=c[l+68+(e>>>8<<2)>>2]|0;do{if((f|0)==0){h=c[l+3168>>2]|0;if((h|0)==0){n=0;o=g;p=j;break}d=gj[h&4095](k)|0;n=d;o=c[2440596]|0;p=a[9660972]|0}else{n=a[f+(e&255)|0]|0;o=g;p=j}}while(0);a[9660973]=n;j=o-1|0;c[2440596]=j;o=a[9660977]|0;g=(o&255)+(p&255)|0;if((g|0)>255){p=n&255;n=(g&255|p<<8)&65535;g=c[2443776]|0;do{if((c[g+68+(p<<2)>>2]|0)==0){e=c[g+3148>>2]|0;if((e|0)==0){q=j;r=o;break}gj[e&4095](n)|0;q=c[2440596]|0;r=a[9660977]|0}else{q=j;r=o}}while(0);n=q-1|0;c[2440596]=n;s=r;t=n}else{s=o;t=j}b[4830486]=(b[4830486]|0)+(s&255)&65535;s=c[2415243]|0;j=s&65535;o=c[2443776]|0;n=c[o+68+((s>>>8&255)<<2)>>2]|0;do{if((n|0)==0){r=c[o+3148>>2]|0;if((r|0)==0){u=0;v=t;break}q=gj[r&4095](j)|0;u=q;v=c[2440596]|0}else{u=a[n+(s&255)|0]|0;v=t}}while(0);c[2440596]=v-1;v=a[9660979]|0;t=v&-2;a[9660979]=t;s=a[9660976]|0;if((s&255)<(u&255)){w=t}else{t=v|1;a[9660979]=t;w=t}if(s<<24>>24==u<<24>>24){x=w&125|2;a[9660979]=x;return}else{x=w&125|s-u&255&-128;a[9660979]=x;return}}function fWq(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;g=(c[2440596]|0)-1|0;c[2440596]=g;b[4830480]=k+1&65535;e=k&65535;f=c[l+68+(e>>>8<<2)>>2]|0;do{if((f|0)==0){h=c[l+3168>>2]|0;if((h|0)==0){n=0;o=g;p=j;break}d=gj[h&4095](k)|0;n=d;o=c[2440596]|0;p=a[9660972]|0}else{n=a[f+(e&255)|0]|0;o=g;p=j}}while(0);a[9660973]=n;j=o-1|0;c[2440596]=j;o=a[9660977]|0;g=(o&255)+(p&255)|0;if((g|0)>255){p=n&255;n=(g&255|p<<8)&65535;g=c[2443776]|0;do{if((c[g+68+(p<<2)>>2]|0)==0){e=c[g+3148>>2]|0;if((e|0)==0){q=j;r=o;break}gj[e&4095](n)|0;q=c[2440596]|0;r=a[9660977]|0}else{q=j;r=o}}while(0);n=q-1|0;c[2440596]=n;s=r;t=n}else{s=o;t=j}b[4830486]=(b[4830486]|0)+(s&255)&65535;s=c[2415243]|0;j=s&65535;o=c[2443776]|0;n=c[o+68+((s>>>8&255)<<2)>>2]|0;do{if((n|0)==0){r=c[o+3148>>2]|0;if((r|0)==0){u=0;v=t;break}q=gj[r&4095](j)|0;u=q;v=c[2440596]|0}else{u=a[n+(s&255)|0]|0;v=t}}while(0);t=u&255;c[2440596]=v-1;v=a[9660979]|0;s=v&255;n=s&1^1;j=a[9660976]|0;o=j&255;q=o-t-n|0;if((s&8|0)!=0){s=(o&15)-(t&15)-n|0;n=(o&240)-(t&240)|0;if((s&16|0)==0){w=s;x=n}else{w=s-6|0;x=n-1|0}n=v&60;s=(((j^u)&128&(q^o)|0)==0?n:n|64)|(q&65280|0)==0;n=(q&255|0)==0?s|2:s;a[9660979]=(q&128|0)==0?n:n|-128;a[9660976]=(((x&256|0)==0?x:x+160|0)&240|w&15)&255;return}w=v&-66;v=(((j^u)&128&(q^o)|0)==0?w:w|64)|(q&65280|0)==0;a[9660979]=v;a[9660976]=q&255;if((q&255|0)==0){a[9660979]=v&125|2;return}else{a[9660979]=(v&125|q&128)&255;return}}function fWr(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;b[4830480]=k+1&65535;g=k&65535;e=c[l+68+(g>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[l+3168>>2]|0;if((f|0)==0){n=0;o=j;p=l;break}h=gj[f&4095](k)|0;n=h;o=c[2440596]|0;p=c[2443776]|0}else{n=a[e+(g&255)|0]|0;o=j;p=l}}while(0);a[9660973]=n;n=o-1|0;c[2440596]=n;o=c[2415243]|0;l=o&65535;j=c[p+68+((o>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[p+3148>>2]|0;if((g|0)==0){q=0;r=n;s=o;t=p;break}e=gj[g&4095](l)|0;q=e;r=c[2440596]|0;s=c[2415243]|0;t=c[2443776]|0}else{q=a[j+(o&255)|0]|0;r=n;s=o;t=p}}while(0);p=r-1|0;c[2440596]=p;r=s&65535;o=c[t+68+((s>>>8&255|256)<<2)>>2]|0;do{if((o|0)==0){n=c[t+3152>>2]|0;if((n|0)==0){u=p;v=t;break}gg[n&4095](r,q);u=c[2440596]|0;v=c[2443776]|0}else{a[o+(s&255)|0]=q;u=p;v=t}}while(0);t=u-1|0;c[2440596]=t;u=q<<1;a[9660979]=(u<<24>>24==0?2:u&-128)|(q&255)>>>7|a[9660979]&124;q=c[2415243]|0;p=c[v+68+((q>>>8&255|256)<<2)>>2]|0;if((p|0)!=0){a[p+(q&255)|0]=u;w=t;x=w-1|0;c[2440596]=x;return}p=c[v+3152>>2]|0;if((p|0)==0){w=t;x=w-1|0;c[2440596]=x;return}gg[p&4095](q&65535,u);w=c[2440596]|0;x=w-1|0;c[2440596]=x;return}function fWs(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;b[4830480]=k+1&65535;g=k&65535;e=c[l+68+(g>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[l+3168>>2]|0;if((f|0)==0){n=0;o=j;p=l;break}h=gj[f&4095](k)|0;n=h;o=c[2440596]|0;p=c[2443776]|0}else{n=a[e+(g&255)|0]|0;o=j;p=l}}while(0);a[9660973]=n;n=o-1|0;c[2440596]=n;o=c[2415243]|0;l=o&65535;j=c[p+68+((o>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[p+3148>>2]|0;if((g|0)==0){q=0;r=n;s=o;t=p;break}e=gj[g&4095](l)|0;q=e;r=c[2440596]|0;s=c[2415243]|0;t=c[2443776]|0}else{q=a[j+(o&255)|0]|0;r=n;s=o;t=p}}while(0);p=r-1|0;c[2440596]=p;r=s&65535;o=c[t+68+((s>>>8&255|256)<<2)>>2]|0;do{if((o|0)==0){n=c[t+3152>>2]|0;if((n|0)==0){u=p;v=t;break}gg[n&4095](r,q);u=c[2440596]|0;v=c[2443776]|0}else{a[o+(s&255)|0]=q;u=p;v=t}}while(0);t=u-1|0;c[2440596]=t;u=q<<1;p=a[9660979]|0;s=p&1|u;a[9660979]=p&124|(q&255)>>>7|(s<<24>>24==0?2:u&-128);u=c[2415243]|0;q=c[v+68+((u>>>8&255|256)<<2)>>2]|0;if((q|0)!=0){a[q+(u&255)|0]=s;w=t;x=w-1|0;c[2440596]=x;return}q=c[v+3152>>2]|0;if((q|0)==0){w=t;x=w-1|0;c[2440596]=x;return}gg[q&4095](u&65535,s);w=c[2440596]|0;x=w-1|0;c[2440596]=x;return}function fWt(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;b[4830480]=k+1&65535;g=k&65535;e=c[l+68+(g>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[l+3168>>2]|0;if((f|0)==0){n=0;o=j;p=l;break}h=gj[f&4095](k)|0;n=h;o=c[2440596]|0;p=c[2443776]|0}else{n=a[e+(g&255)|0]|0;o=j;p=l}}while(0);a[9660973]=n;n=o-1|0;c[2440596]=n;o=c[2415243]|0;l=o&65535;j=c[p+68+((o>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[p+3148>>2]|0;if((g|0)==0){q=0;r=n;s=o;t=p;break}e=gj[g&4095](l)|0;q=e;r=c[2440596]|0;s=c[2415243]|0;t=c[2443776]|0}else{q=a[j+(o&255)|0]|0;r=n;s=o;t=p}}while(0);p=r-1|0;c[2440596]=p;r=s&65535;o=c[t+68+((s>>>8&255|256)<<2)>>2]|0;do{if((o|0)==0){n=c[t+3152>>2]|0;if((n|0)==0){u=p;v=t;break}gg[n&4095](r,q);u=c[2440596]|0;v=c[2443776]|0}else{a[o+(s&255)|0]=q;u=p;v=t}}while(0);t=u-1|0;c[2440596]=t;u=a[9660979]&124|q&1;p=(q&255)>>>1;a[9660979]=(p|0)==0?u|2:u;u=c[2415243]|0;q=p&255;p=c[v+68+((u>>>8&255|256)<<2)>>2]|0;if((p|0)!=0){a[p+(u&255)|0]=q;w=t;x=w-1|0;c[2440596]=x;return}p=c[v+3152>>2]|0;if((p|0)==0){w=t;x=w-1|0;c[2440596]=x;return}gg[p&4095](u&65535,q);w=c[2440596]|0;x=w-1|0;c[2440596]=x;return}function fWu(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;b[4830480]=k+1&65535;g=k&65535;e=c[l+68+(g>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[l+3168>>2]|0;if((f|0)==0){n=0;o=j;p=l;break}h=gj[f&4095](k)|0;n=h;o=c[2440596]|0;p=c[2443776]|0}else{n=a[e+(g&255)|0]|0;o=j;p=l}}while(0);a[9660973]=n;n=o-1|0;c[2440596]=n;o=c[2415243]|0;l=o&65535;j=c[p+68+((o>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[p+3148>>2]|0;if((g|0)==0){q=0;r=n;s=o;t=p;break}e=gj[g&4095](l)|0;q=e;r=c[2440596]|0;s=c[2415243]|0;t=c[2443776]|0}else{q=a[j+(o&255)|0]|0;r=n;s=o;t=p}}while(0);p=q&255;o=r-1|0;c[2440596]=o;r=s&65535;n=c[t+68+((s>>>8&255|256)<<2)>>2]|0;do{if((n|0)==0){j=c[t+3152>>2]|0;if((j|0)==0){u=o;break}gg[j&4095](r,q);u=c[2440596]|0}else{a[n+(s&255)|0]=q;u=o}}while(0);o=u-1|0;c[2440596]=o;u=a[9660979]|0;s=u&-2|q&1;a[9660979]=s;q=((u&255)<<8|p)>>>1;if((q&255|0)==0){v=s&125|2}else{v=(q&128|s&125)&255}a[9660979]=v;v=c[2415243]|0;s=q&255;q=c[2443776]|0;p=c[q+68+((v>>>8&255|256)<<2)>>2]|0;if((p|0)!=0){a[p+(v&255)|0]=s;w=o;x=w-1|0;c[2440596]=x;return}p=c[q+3152>>2]|0;if((p|0)==0){w=o;x=w-1|0;c[2440596]=x;return}gg[p&4095](v&65535,s);w=c[2440596]|0;x=w-1|0;c[2440596]=x;return}function fWv(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=a[9660977]|0;e=b[4830480]|0;f=e+1&65535;b[4830480]=f;g=e&65535;h=c[2443776]|0;i=c[h+68+(g>>>8<<2)>>2]|0;do{if((i|0)==0){j=c[h+3168>>2]|0;if((j|0)==0){k=0;l=f;m=h;break}n=gj[j&4095](e)|0;k=n;l=b[4830480]|0;m=c[2443776]|0}else{k=a[i+(g&255)|0]|0;l=f;m=h}}while(0);a[9660972]=k;k=(c[2440596]|0)-1|0;c[2440596]=k;b[4830480]=l+1&65535;h=l&65535;f=c[m+68+(h>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[m+3168>>2]|0;if((g|0)==0){o=0;p=k;q=m;break}i=gj[g&4095](l)|0;o=i;p=c[2440596]|0;q=c[2443776]|0}else{o=a[f+(h&255)|0]|0;p=k;q=m}}while(0);a[9660973]=o;o=p-1|0;c[2440596]=o;p=c[2415243]|0;m=c[q+68+((p>>>8&255|256)<<2)>>2]|0;if((m|0)!=0){a[m+(p&255)|0]=d;r=o;s=r-1|0;c[2440596]=s;return}m=c[q+3152>>2]|0;if((m|0)==0){r=o;s=r-1|0;c[2440596]=s;return}gg[m&4095](p&65535,d);r=c[2440596]|0;s=r-1|0;c[2440596]=s;return}function fWw(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;b[4830480]=k+1&65535;g=k&65535;e=c[l+68+(g>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[l+3168>>2]|0;if((f|0)==0){n=0;o=j;p=l;break}h=gj[f&4095](k)|0;n=h;o=c[2440596]|0;p=c[2443776]|0}else{n=a[e+(g&255)|0]|0;o=j;p=l}}while(0);a[9660973]=n;n=o-1|0;c[2440596]=n;o=c[2415243]|0;l=o&65535;j=c[p+68+((o>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[p+3148>>2]|0;if((g|0)==0){q=0;r=n;break}e=gj[g&4095](l)|0;q=e;r=c[2440596]|0}else{q=a[j+(o&255)|0]|0;r=n}}while(0);c[2440596]=r-1;a[9660977]=q;a[9660979]=a[9660979]&125|(q<<24>>24==0?2:q&-128);return}function fWx(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;b[4830480]=k+1&65535;g=k&65535;e=c[l+68+(g>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[l+3168>>2]|0;if((f|0)==0){n=0;o=j;p=l;break}h=gj[f&4095](k)|0;n=h;o=c[2440596]|0;p=c[2443776]|0}else{n=a[e+(g&255)|0]|0;o=j;p=l}}while(0);a[9660973]=n;n=o-1|0;c[2440596]=n;o=c[2415243]|0;l=o&65535;j=c[p+68+((o>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[p+3148>>2]|0;if((g|0)==0){q=0;r=n;s=o;t=p;break}e=gj[g&4095](l)|0;q=e;r=c[2440596]|0;s=c[2415243]|0;t=c[2443776]|0}else{q=a[j+(o&255)|0]|0;r=n;s=o;t=p}}while(0);p=r-1|0;c[2440596]=p;r=s&65535;o=c[t+68+((s>>>8&255|256)<<2)>>2]|0;do{if((o|0)==0){n=c[t+3152>>2]|0;if((n|0)==0){u=p;v=t;break}gg[n&4095](r,q);u=c[2440596]|0;v=c[2443776]|0}else{a[o+(s&255)|0]=q;u=p;v=t}}while(0);t=u-1|0;c[2440596]=t;u=q-1&255;a[9660979]=a[9660979]&125|(u<<24>>24==0?2:u&-128);q=c[2415243]|0;p=c[v+68+((q>>>8&255|256)<<2)>>2]|0;if((p|0)!=0){a[p+(q&255)|0]=u;w=t;x=w-1|0;c[2440596]=x;return}p=c[v+3152>>2]|0;if((p|0)==0){w=t;x=w-1|0;c[2440596]=x;return}gg[p&4095](q&65535,u);w=c[2440596]|0;x=w-1|0;c[2440596]=x;return}function fWy(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;b[4830480]=k+1&65535;g=k&65535;e=c[l+68+(g>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[l+3168>>2]|0;if((f|0)==0){n=0;o=j;p=l;break}h=gj[f&4095](k)|0;n=h;o=c[2440596]|0;p=c[2443776]|0}else{n=a[e+(g&255)|0]|0;o=j;p=l}}while(0);a[9660973]=n;n=o-1|0;c[2440596]=n;o=c[2415243]|0;l=o&65535;j=c[p+68+((o>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[p+3148>>2]|0;if((g|0)==0){q=0;r=n;s=o;t=p;break}e=gj[g&4095](l)|0;q=e;r=c[2440596]|0;s=c[2415243]|0;t=c[2443776]|0}else{q=a[j+(o&255)|0]|0;r=n;s=o;t=p}}while(0);p=r-1|0;c[2440596]=p;r=s&65535;o=c[t+68+((s>>>8&255|256)<<2)>>2]|0;do{if((o|0)==0){n=c[t+3152>>2]|0;if((n|0)==0){u=p;v=t;break}gg[n&4095](r,q);u=c[2440596]|0;v=c[2443776]|0}else{a[o+(s&255)|0]=q;u=p;v=t}}while(0);t=u-1|0;c[2440596]=t;u=q+1&255;a[9660979]=a[9660979]&125|(u<<24>>24==0?2:u&-128);q=c[2415243]|0;p=c[v+68+((q>>>8&255|256)<<2)>>2]|0;if((p|0)!=0){a[p+(q&255)|0]=u;w=t;x=w-1|0;c[2440596]=x;return}p=c[v+3152>>2]|0;if((p|0)==0){w=t;x=w-1|0;c[2440596]=x;return}gg[p&4095](q&65535,u);w=c[2440596]|0;x=w-1|0;c[2440596]=x;return}function fWz(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;g=(c[2440596]|0)-1|0;c[2440596]=g;b[4830480]=k+1&65535;e=k&65535;f=c[l+68+(e>>>8<<2)>>2]|0;do{if((f|0)==0){h=c[l+3168>>2]|0;if((h|0)==0){n=0;o=g;p=j;q=l;break}d=gj[h&4095](k)|0;n=d;o=c[2440596]|0;p=a[9660972]|0;q=c[2443776]|0}else{n=a[f+(e&255)|0]|0;o=g;p=j;q=l}}while(0);a[9660973]=n;l=o-1|0;c[2440596]=l;o=(n&255)<<8;n=a[9660977]|0;j=(n&255)+(p&255)&255|o;do{if((c[q+68+((o&65535)>>>8<<2)>>2]|0)==0){p=c[q+3148>>2]|0;if((p|0)==0){r=l;s=n;t=q;break}gj[p&4095](j)|0;r=c[2440596]|0;s=a[9660977]|0;t=c[2443776]|0}else{r=l;s=n;t=q}}while(0);q=r-1|0;c[2440596]=q;b[4830486]=(b[4830486]|0)+(s&255)&65535;s=c[2415243]|0;r=s&65535;n=c[t+68+((s>>>8&255)<<2)>>2]|0;do{if((n|0)==0){l=c[t+3148>>2]|0;if((l|0)==0){u=0;v=q;w=s;x=t;break}j=gj[l&4095](r)|0;u=j;v=c[2440596]|0;w=c[2415243]|0;x=c[2443776]|0}else{u=a[n+(s&255)|0]|0;v=q;w=s;x=t}}while(0);t=v-1|0;c[2440596]=t;v=w&65535;s=c[x+68+((w>>>8&255|256)<<2)>>2]|0;do{if((s|0)==0){q=c[x+3152>>2]|0;if((q|0)==0){y=t;z=x;break}gg[q&4095](v,u);y=c[2440596]|0;z=c[2443776]|0}else{a[s+(w&255)|0]=u;y=t;z=x}}while(0);x=y-1|0;c[2440596]=x;y=u<<1;a[9660979]=(y<<24>>24==0?2:y&-128)|(u&255)>>>7|a[9660979]&124;u=c[2415243]|0;t=c[z+68+((u>>>8&255|256)<<2)>>2]|0;if((t|0)!=0){a[t+(u&255)|0]=y;A=x;B=A-1|0;c[2440596]=B;return}t=c[z+3152>>2]|0;if((t|0)==0){A=x;B=A-1|0;c[2440596]=B;return}gg[t&4095](u&65535,y);A=c[2440596]|0;B=A-1|0;c[2440596]=B;return}function fWA(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;g=(c[2440596]|0)-1|0;c[2440596]=g;b[4830480]=k+1&65535;e=k&65535;f=c[l+68+(e>>>8<<2)>>2]|0;do{if((f|0)==0){h=c[l+3168>>2]|0;if((h|0)==0){n=0;o=g;p=j;q=l;break}d=gj[h&4095](k)|0;n=d;o=c[2440596]|0;p=a[9660972]|0;q=c[2443776]|0}else{n=a[f+(e&255)|0]|0;o=g;p=j;q=l}}while(0);a[9660973]=n;l=o-1|0;c[2440596]=l;o=(n&255)<<8;n=a[9660977]|0;j=(n&255)+(p&255)&255|o;do{if((c[q+68+((o&65535)>>>8<<2)>>2]|0)==0){p=c[q+3148>>2]|0;if((p|0)==0){r=l;s=n;t=q;break}gj[p&4095](j)|0;r=c[2440596]|0;s=a[9660977]|0;t=c[2443776]|0}else{r=l;s=n;t=q}}while(0);q=r-1|0;c[2440596]=q;b[4830486]=(b[4830486]|0)+(s&255)&65535;s=c[2415243]|0;r=s&65535;n=c[t+68+((s>>>8&255)<<2)>>2]|0;do{if((n|0)==0){l=c[t+3148>>2]|0;if((l|0)==0){u=0;v=q;w=s;x=t;break}j=gj[l&4095](r)|0;u=j;v=c[2440596]|0;w=c[2415243]|0;x=c[2443776]|0}else{u=a[n+(s&255)|0]|0;v=q;w=s;x=t}}while(0);t=v-1|0;c[2440596]=t;v=w&65535;s=c[x+68+((w>>>8&255|256)<<2)>>2]|0;do{if((s|0)==0){q=c[x+3152>>2]|0;if((q|0)==0){y=t;z=x;break}gg[q&4095](v,u);y=c[2440596]|0;z=c[2443776]|0}else{a[s+(w&255)|0]=u;y=t;z=x}}while(0);x=y-1|0;c[2440596]=x;y=u<<1;t=a[9660979]|0;w=t&1|y;a[9660979]=t&124|(u&255)>>>7|(w<<24>>24==0?2:y&-128);y=c[2415243]|0;u=c[z+68+((y>>>8&255|256)<<2)>>2]|0;if((u|0)!=0){a[u+(y&255)|0]=w;A=x;B=A-1|0;c[2440596]=B;return}u=c[z+3152>>2]|0;if((u|0)==0){A=x;B=A-1|0;c[2440596]=B;return}gg[u&4095](y&65535,w);A=c[2440596]|0;B=A-1|0;c[2440596]=B;return}function fWB(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;g=(c[2440596]|0)-1|0;c[2440596]=g;b[4830480]=k+1&65535;e=k&65535;f=c[l+68+(e>>>8<<2)>>2]|0;do{if((f|0)==0){h=c[l+3168>>2]|0;if((h|0)==0){n=0;o=g;p=j;q=l;break}d=gj[h&4095](k)|0;n=d;o=c[2440596]|0;p=a[9660972]|0;q=c[2443776]|0}else{n=a[f+(e&255)|0]|0;o=g;p=j;q=l}}while(0);a[9660973]=n;l=o-1|0;c[2440596]=l;o=(n&255)<<8;n=a[9660977]|0;j=(n&255)+(p&255)&255|o;do{if((c[q+68+((o&65535)>>>8<<2)>>2]|0)==0){p=c[q+3148>>2]|0;if((p|0)==0){r=l;s=n;t=q;break}gj[p&4095](j)|0;r=c[2440596]|0;s=a[9660977]|0;t=c[2443776]|0}else{r=l;s=n;t=q}}while(0);q=r-1|0;c[2440596]=q;b[4830486]=(b[4830486]|0)+(s&255)&65535;s=c[2415243]|0;r=s&65535;n=c[t+68+((s>>>8&255)<<2)>>2]|0;do{if((n|0)==0){l=c[t+3148>>2]|0;if((l|0)==0){u=0;v=q;w=s;x=t;break}j=gj[l&4095](r)|0;u=j;v=c[2440596]|0;w=c[2415243]|0;x=c[2443776]|0}else{u=a[n+(s&255)|0]|0;v=q;w=s;x=t}}while(0);t=v-1|0;c[2440596]=t;v=w&65535;s=c[x+68+((w>>>8&255|256)<<2)>>2]|0;do{if((s|0)==0){q=c[x+3152>>2]|0;if((q|0)==0){y=t;z=x;break}gg[q&4095](v,u);y=c[2440596]|0;z=c[2443776]|0}else{a[s+(w&255)|0]=u;y=t;z=x}}while(0);x=y-1|0;c[2440596]=x;y=a[9660979]&124|u&1;t=(u&255)>>>1;a[9660979]=(t|0)==0?y|2:y;y=c[2415243]|0;u=t&255;t=c[z+68+((y>>>8&255|256)<<2)>>2]|0;if((t|0)!=0){a[t+(y&255)|0]=u;A=x;B=A-1|0;c[2440596]=B;return}t=c[z+3152>>2]|0;if((t|0)==0){A=x;B=A-1|0;c[2440596]=B;return}gg[t&4095](y&65535,u);A=c[2440596]|0;B=A-1|0;c[2440596]=B;return}function fWC(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;g=(c[2440596]|0)-1|0;c[2440596]=g;b[4830480]=k+1&65535;e=k&65535;f=c[l+68+(e>>>8<<2)>>2]|0;do{if((f|0)==0){h=c[l+3168>>2]|0;if((h|0)==0){n=0;o=g;p=j;q=l;break}d=gj[h&4095](k)|0;n=d;o=c[2440596]|0;p=a[9660972]|0;q=c[2443776]|0}else{n=a[f+(e&255)|0]|0;o=g;p=j;q=l}}while(0);a[9660973]=n;l=o-1|0;c[2440596]=l;o=(n&255)<<8;n=a[9660977]|0;j=(n&255)+(p&255)&255|o;do{if((c[q+68+((o&65535)>>>8<<2)>>2]|0)==0){p=c[q+3148>>2]|0;if((p|0)==0){r=l;s=n;t=q;break}gj[p&4095](j)|0;r=c[2440596]|0;s=a[9660977]|0;t=c[2443776]|0}else{r=l;s=n;t=q}}while(0);q=r-1|0;c[2440596]=q;b[4830486]=(b[4830486]|0)+(s&255)&65535;s=c[2415243]|0;r=s&65535;n=c[t+68+((s>>>8&255)<<2)>>2]|0;do{if((n|0)==0){l=c[t+3148>>2]|0;if((l|0)==0){u=0;v=q;w=s;x=t;break}j=gj[l&4095](r)|0;u=j;v=c[2440596]|0;w=c[2415243]|0;x=c[2443776]|0}else{u=a[n+(s&255)|0]|0;v=q;w=s;x=t}}while(0);t=u&255;s=v-1|0;c[2440596]=s;v=w&65535;q=c[x+68+((w>>>8&255|256)<<2)>>2]|0;do{if((q|0)==0){n=c[x+3152>>2]|0;if((n|0)==0){y=s;break}gg[n&4095](v,u);y=c[2440596]|0}else{a[q+(w&255)|0]=u;y=s}}while(0);s=y-1|0;c[2440596]=s;y=a[9660979]|0;w=y&-2|u&1;a[9660979]=w;u=((y&255)<<8|t)>>>1;if((u&255|0)==0){z=w&125|2}else{z=(u&128|w&125)&255}a[9660979]=z;z=c[2415243]|0;w=u&255;u=c[2443776]|0;t=c[u+68+((z>>>8&255|256)<<2)>>2]|0;if((t|0)!=0){a[t+(z&255)|0]=w;A=s;B=A-1|0;c[2440596]=B;return}t=c[u+3152>>2]|0;if((t|0)==0){A=s;B=A-1|0;c[2440596]=B;return}gg[t&4095](z&65535,w);A=c[2440596]|0;B=A-1|0;c[2440596]=B;return}function fWD(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;g=(c[2440596]|0)-1|0;c[2440596]=g;b[4830480]=k+1&65535;e=k&65535;f=c[l+68+(e>>>8<<2)>>2]|0;do{if((f|0)==0){h=c[l+3168>>2]|0;if((h|0)==0){n=0;o=g;p=j;q=l;break}d=gj[h&4095](k)|0;n=d;o=c[2440596]|0;p=a[9660972]|0;q=c[2443776]|0}else{n=a[f+(e&255)|0]|0;o=g;p=j;q=l}}while(0);a[9660973]=n;l=o-1|0;c[2440596]=l;o=(n&255)<<8;n=a[9660978]|0;j=(n&255)+(p&255)&255|o;do{if((c[q+68+((o&65535)>>>8<<2)>>2]|0)==0){p=c[q+3148>>2]|0;if((p|0)==0){r=l;s=n;t=q;break}gj[p&4095](j)|0;r=c[2440596]|0;s=a[9660978]|0;t=c[2443776]|0}else{r=l;s=n;t=q}}while(0);q=r-1|0;c[2440596]=q;r=(b[4830486]|0)+(s&255)&65535;b[4830486]=r;s=((r&65535)>>>8&255)+1&255&a[9660977];r=c[2415243]|0;n=c[t+68+((r>>>8&255|256)<<2)>>2]|0;if((n|0)!=0){a[n+(r&255)|0]=s;u=q;v=u-1|0;c[2440596]=v;return}n=c[t+3152>>2]|0;if((n|0)==0){u=q;v=u-1|0;c[2440596]=v;return}gg[n&4095](r&65535,s);u=c[2440596]|0;v=u-1|0;c[2440596]=v;return}function fWE(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;g=(c[2440596]|0)-1|0;c[2440596]=g;b[4830480]=k+1&65535;e=k&65535;f=c[l+68+(e>>>8<<2)>>2]|0;do{if((f|0)==0){h=c[l+3168>>2]|0;if((h|0)==0){n=0;o=g;p=j;break}d=gj[h&4095](k)|0;n=d;o=c[2440596]|0;p=a[9660972]|0}else{n=a[f+(e&255)|0]|0;o=g;p=j}}while(0);a[9660973]=n;j=o-1|0;c[2440596]=j;o=a[9660978]|0;g=(o&255)+(p&255)|0;if((g|0)>255){p=n&255;n=(g&255|p<<8)&65535;g=c[2443776]|0;do{if((c[g+68+(p<<2)>>2]|0)==0){e=c[g+3148>>2]|0;if((e|0)==0){q=j;r=o;break}gj[e&4095](n)|0;q=c[2440596]|0;r=a[9660978]|0}else{q=j;r=o}}while(0);n=q-1|0;c[2440596]=n;s=r;t=n}else{s=o;t=j}b[4830486]=(b[4830486]|0)+(s&255)&65535;s=c[2415243]|0;j=s&65535;o=c[2443776]|0;n=c[o+68+((s>>>8&255)<<2)>>2]|0;do{if((n|0)==0){r=c[o+3148>>2]|0;if((r|0)==0){u=0;v=t;break}q=gj[r&4095](j)|0;u=q;v=c[2440596]|0}else{u=a[n+(s&255)|0]|0;v=t}}while(0);c[2440596]=v-1;a[9660977]=u;a[9660979]=a[9660979]&125|(u<<24>>24==0?2:u&-128);return}function fWF(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;g=(c[2440596]|0)-1|0;c[2440596]=g;b[4830480]=k+1&65535;e=k&65535;f=c[l+68+(e>>>8<<2)>>2]|0;do{if((f|0)==0){h=c[l+3168>>2]|0;if((h|0)==0){n=0;o=g;p=j;q=l;break}d=gj[h&4095](k)|0;n=d;o=c[2440596]|0;p=a[9660972]|0;q=c[2443776]|0}else{n=a[f+(e&255)|0]|0;o=g;p=j;q=l}}while(0);a[9660973]=n;l=o-1|0;c[2440596]=l;o=(n&255)<<8;n=a[9660977]|0;j=(n&255)+(p&255)&255|o;do{if((c[q+68+((o&65535)>>>8<<2)>>2]|0)==0){p=c[q+3148>>2]|0;if((p|0)==0){r=l;s=n;t=q;break}gj[p&4095](j)|0;r=c[2440596]|0;s=a[9660977]|0;t=c[2443776]|0}else{r=l;s=n;t=q}}while(0);q=r-1|0;c[2440596]=q;b[4830486]=(b[4830486]|0)+(s&255)&65535;s=c[2415243]|0;r=s&65535;n=c[t+68+((s>>>8&255)<<2)>>2]|0;do{if((n|0)==0){l=c[t+3148>>2]|0;if((l|0)==0){u=0;v=q;w=s;x=t;break}j=gj[l&4095](r)|0;u=j;v=c[2440596]|0;w=c[2415243]|0;x=c[2443776]|0}else{u=a[n+(s&255)|0]|0;v=q;w=s;x=t}}while(0);t=v-1|0;c[2440596]=t;v=w&65535;s=c[x+68+((w>>>8&255|256)<<2)>>2]|0;do{if((s|0)==0){q=c[x+3152>>2]|0;if((q|0)==0){y=t;z=x;break}gg[q&4095](v,u);y=c[2440596]|0;z=c[2443776]|0}else{a[s+(w&255)|0]=u;y=t;z=x}}while(0);x=y-1|0;c[2440596]=x;y=u-1&255;a[9660979]=a[9660979]&125|(y<<24>>24==0?2:y&-128);u=c[2415243]|0;t=c[z+68+((u>>>8&255|256)<<2)>>2]|0;if((t|0)!=0){a[t+(u&255)|0]=y;A=x;B=A-1|0;c[2440596]=B;return}t=c[z+3152>>2]|0;if((t|0)==0){A=x;B=A-1|0;c[2440596]=B;return}gg[t&4095](u&65535,y);A=c[2440596]|0;B=A-1|0;c[2440596]=B;return}function fWG(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;g=(c[2440596]|0)-1|0;c[2440596]=g;b[4830480]=k+1&65535;e=k&65535;f=c[l+68+(e>>>8<<2)>>2]|0;do{if((f|0)==0){h=c[l+3168>>2]|0;if((h|0)==0){n=0;o=g;p=j;q=l;break}d=gj[h&4095](k)|0;n=d;o=c[2440596]|0;p=a[9660972]|0;q=c[2443776]|0}else{n=a[f+(e&255)|0]|0;o=g;p=j;q=l}}while(0);a[9660973]=n;l=o-1|0;c[2440596]=l;o=(n&255)<<8;n=a[9660977]|0;j=(n&255)+(p&255)&255|o;do{if((c[q+68+((o&65535)>>>8<<2)>>2]|0)==0){p=c[q+3148>>2]|0;if((p|0)==0){r=l;s=n;t=q;break}gj[p&4095](j)|0;r=c[2440596]|0;s=a[9660977]|0;t=c[2443776]|0}else{r=l;s=n;t=q}}while(0);q=r-1|0;c[2440596]=q;b[4830486]=(b[4830486]|0)+(s&255)&65535;s=c[2415243]|0;r=s&65535;n=c[t+68+((s>>>8&255)<<2)>>2]|0;do{if((n|0)==0){l=c[t+3148>>2]|0;if((l|0)==0){u=0;v=q;w=s;x=t;break}j=gj[l&4095](r)|0;u=j;v=c[2440596]|0;w=c[2415243]|0;x=c[2443776]|0}else{u=a[n+(s&255)|0]|0;v=q;w=s;x=t}}while(0);t=v-1|0;c[2440596]=t;v=w&65535;s=c[x+68+((w>>>8&255|256)<<2)>>2]|0;do{if((s|0)==0){q=c[x+3152>>2]|0;if((q|0)==0){y=t;z=x;break}gg[q&4095](v,u);y=c[2440596]|0;z=c[2443776]|0}else{a[s+(w&255)|0]=u;y=t;z=x}}while(0);x=y-1|0;c[2440596]=x;y=u+1&255;a[9660979]=a[9660979]&125|(y<<24>>24==0?2:y&-128);u=c[2415243]|0;t=c[z+68+((u>>>8&255|256)<<2)>>2]|0;if((t|0)!=0){a[t+(u&255)|0]=y;A=x;B=A-1|0;c[2440596]=B;return}t=c[z+3152>>2]|0;if((t|0)==0){A=x;B=A-1|0;c[2440596]=B;return}gg[t&4095](u&65535,y);A=c[2440596]|0;B=A-1|0;c[2440596]=B;return}function fWH(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;b[4830480]=k+1&65535;g=k&65535;e=c[l+68+(g>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[l+3168>>2]|0;if((f|0)==0){n=0;o=j;p=l;break}h=gj[f&4095](k)|0;n=h;o=c[2440596]|0;p=c[2443776]|0}else{n=a[e+(g&255)|0]|0;o=j;p=l}}while(0);a[9660973]=n;n=o-1|0;c[2440596]=n;o=c[2415243]|0;l=o&65535;j=c[p+68+((o>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[p+3148>>2]|0;if((g|0)==0){q=0;r=n;s=o;t=p;break}e=gj[g&4095](l)|0;q=e;r=c[2440596]|0;s=c[2415243]|0;t=c[2443776]|0}else{q=a[j+(o&255)|0]|0;r=n;s=o;t=p}}while(0);p=r-1|0;c[2440596]=p;r=s&65535;o=c[t+68+((s>>>8&255|256)<<2)>>2]|0;do{if((o|0)==0){n=c[t+3152>>2]|0;if((n|0)==0){u=p;v=t;break}gg[n&4095](r,q);u=c[2440596]|0;v=c[2443776]|0}else{a[o+(s&255)|0]=q;u=p;v=t}}while(0);t=u-1|0;c[2440596]=t;u=a[9660979]&124;p=q<<1;s=a[9660976]|p;a[9660976]=s;a[9660979]=u|(q&255)>>>7|(s<<24>>24==0?2:s&-128);s=c[2415243]|0;q=c[v+68+((s>>>8&255|256)<<2)>>2]|0;if((q|0)!=0){a[q+(s&255)|0]=p;w=t;x=w-1|0;c[2440596]=x;return}q=c[v+3152>>2]|0;if((q|0)==0){w=t;x=w-1|0;c[2440596]=x;return}gg[q&4095](s&65535,p);w=c[2440596]|0;x=w-1|0;c[2440596]=x;return}function fWI(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;b[4830480]=k+1&65535;g=k&65535;e=c[l+68+(g>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[l+3168>>2]|0;if((f|0)==0){n=0;o=j;p=l;break}h=gj[f&4095](k)|0;n=h;o=c[2440596]|0;p=c[2443776]|0}else{n=a[e+(g&255)|0]|0;o=j;p=l}}while(0);a[9660973]=n;n=o-1|0;c[2440596]=n;o=c[2415243]|0;l=o&65535;j=c[p+68+((o>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[p+3148>>2]|0;if((g|0)==0){q=0;r=n;s=o;t=p;break}e=gj[g&4095](l)|0;q=e;r=c[2440596]|0;s=c[2415243]|0;t=c[2443776]|0}else{q=a[j+(o&255)|0]|0;r=n;s=o;t=p}}while(0);p=r-1|0;c[2440596]=p;r=s&65535;o=c[t+68+((s>>>8&255|256)<<2)>>2]|0;do{if((o|0)==0){n=c[t+3152>>2]|0;if((n|0)==0){u=p;v=t;break}gg[n&4095](r,q);u=c[2440596]|0;v=c[2443776]|0}else{a[o+(s&255)|0]=q;u=p;v=t}}while(0);t=u-1|0;c[2440596]=t;u=a[9660979]|0;p=u&1|q<<1;s=p&a[9660976];a[9660976]=s;a[9660979]=u&124|(q&255)>>>7|(s<<24>>24==0?2:s&-128);s=c[2415243]|0;q=c[v+68+((s>>>8&255|256)<<2)>>2]|0;if((q|0)!=0){a[q+(s&255)|0]=p;w=t;x=w-1|0;c[2440596]=x;return}q=c[v+3152>>2]|0;if((q|0)==0){w=t;x=w-1|0;c[2440596]=x;return}gg[q&4095](s&65535,p);w=c[2440596]|0;x=w-1|0;c[2440596]=x;return}function fWJ(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;e=b[4830480]|0;f=e+1&65535;b[4830480]=f;g=e&65535;h=c[2443776]|0;i=c[h+68+(g>>>8<<2)>>2]|0;do{if((i|0)==0){j=c[h+3168>>2]|0;if((j|0)==0){k=0;l=f;m=h;break}n=gj[j&4095](e)|0;k=n;l=b[4830480]|0;m=c[2443776]|0}else{k=a[i+(g&255)|0]|0;l=f;m=h}}while(0);a[9660972]=k;k=(c[2440596]|0)-1|0;c[2440596]=k;b[4830480]=l+1&65535;h=l&65535;f=c[m+68+(h>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[m+3168>>2]|0;if((g|0)==0){o=0;p=k;q=m;break}i=gj[g&4095](l)|0;o=i;p=c[2440596]|0;q=c[2443776]|0}else{o=a[f+(h&255)|0]|0;p=k;q=m}}while(0);a[9660973]=o;o=p-1|0;c[2440596]=o;p=c[2415243]|0;m=p&65535;k=c[q+68+((p>>>8&255)<<2)>>2]|0;do{if((k|0)==0){h=c[q+3148>>2]|0;if((h|0)==0){r=0;s=o;t=p;u=q;break}f=gj[h&4095](m)|0;r=f;s=c[2440596]|0;t=c[2415243]|0;u=c[2443776]|0}else{r=a[k+(p&255)|0]|0;s=o;t=p;u=q}}while(0);q=s-1|0;c[2440596]=q;s=t&65535;p=c[u+68+((t>>>8&255|256)<<2)>>2]|0;do{if((p|0)==0){o=c[u+3152>>2]|0;if((o|0)==0){v=q;break}gg[o&4095](s,r);v=c[2440596]|0}else{a[p+(t&255)|0]=r;v=q}}while(0);q=v-1|0;c[2440596]=q;v=a[9660979]&-2|r&1;a[9660979]=v;t=(r&255)>>>1;r=d[9660976]|0;p=r^t;a[9660976]=p&255;if((r|0)==(t|0)){w=v&125|2}else{w=(v&125|p&128)&255}a[9660979]=w;w=c[2415243]|0;p=t&255;t=c[2443776]|0;v=c[t+68+((w>>>8&255|256)<<2)>>2]|0;if((v|0)!=0){a[v+(w&255)|0]=p;x=q;y=x-1|0;c[2440596]=y;return}v=c[t+3152>>2]|0;if((v|0)==0){x=q;y=x-1|0;c[2440596]=y;return}gg[v&4095](w&65535,p);x=c[2440596]|0;y=x-1|0;c[2440596]=y;return}function fWK(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;e=b[4830480]|0;f=e+1&65535;b[4830480]=f;g=e&65535;h=c[2443776]|0;i=c[h+68+(g>>>8<<2)>>2]|0;do{if((i|0)==0){j=c[h+3168>>2]|0;if((j|0)==0){k=0;l=f;m=h;break}n=gj[j&4095](e)|0;k=n;l=b[4830480]|0;m=c[2443776]|0}else{k=a[i+(g&255)|0]|0;l=f;m=h}}while(0);a[9660972]=k;k=(c[2440596]|0)-1|0;c[2440596]=k;b[4830480]=l+1&65535;h=l&65535;f=c[m+68+(h>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[m+3168>>2]|0;if((g|0)==0){o=0;p=k;q=m;break}i=gj[g&4095](l)|0;o=i;p=c[2440596]|0;q=c[2443776]|0}else{o=a[f+(h&255)|0]|0;p=k;q=m}}while(0);a[9660973]=o;o=p-1|0;c[2440596]=o;p=c[2415243]|0;m=p&65535;k=c[q+68+((p>>>8&255)<<2)>>2]|0;do{if((k|0)==0){h=c[q+3148>>2]|0;if((h|0)==0){r=0;s=o;t=p;u=q;break}f=gj[h&4095](m)|0;r=f;s=c[2440596]|0;t=c[2415243]|0;u=c[2443776]|0}else{r=a[k+(p&255)|0]|0;s=o;t=p;u=q}}while(0);q=r&255;p=s-1|0;c[2440596]=p;s=t&65535;o=c[u+68+((t>>>8&255|256)<<2)>>2]|0;do{if((o|0)==0){k=c[u+3152>>2]|0;if((k|0)==0){v=p;break}gg[k&4095](s,r);v=c[2440596]|0}else{a[o+(t&255)|0]=r;v=p}}while(0);p=v-1|0;c[2440596]=p;v=a[9660979]|0;t=v&-2|r&1;a[9660979]=t;r=((v&255)<<8|q)>>>1;q=t&255;t=q&1;do{if((q&8|0)==0){o=d[9660976]|0;s=(r&255)+t+o|0;u=v&-66;k=(((r^128^o)&128&(s^o)|0)==0?u:u|64)|(s&65280|0)!=0;a[9660979]=k;a[9660976]=s&255;if((s&255|0)==0){a[9660979]=k&125|2;break}else{a[9660979]=(k&125|s&128)&255;break}}else{s=d[9660976]|0;k=(r&15)+t+(s&15)|0;u=(s&240)+(r&240)|0;o=v&60;m=(k+u&255|0)==0?o|2:o;a[9660979]=m;if((k|0)>9){w=k+6|0;x=u+16|0}else{w=k;x=u}if((x&128|0)==0){y=m}else{u=m|-128;a[9660979]=u;y=u}if(((r^128^s)&128&(x^s)|0)==0){z=y}else{s=y|64;a[9660979]=s;z=s}s=(x|0)>144?x+96|0:x;if((s&65280|0)!=0){a[9660979]=z|1}a[9660976]=(s&240|w&15)&255}}while(0);w=c[2415243]|0;z=r&255;r=c[2443776]|0;x=c[r+68+((w>>>8&255|256)<<2)>>2]|0;if((x|0)!=0){a[x+(w&255)|0]=z;A=p;B=A-1|0;c[2440596]=B;return}x=c[r+3152>>2]|0;if((x|0)==0){A=p;B=A-1|0;c[2440596]=B;return}gg[x&4095](w&65535,z);A=c[2440596]|0;B=A-1|0;c[2440596]=B;return}function fWL(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=a[9660977]&a[9660976];e=b[4830480]|0;f=e+1&65535;b[4830480]=f;g=e&65535;h=c[2443776]|0;i=c[h+68+(g>>>8<<2)>>2]|0;do{if((i|0)==0){j=c[h+3168>>2]|0;if((j|0)==0){k=0;l=f;m=h;break}n=gj[j&4095](e)|0;k=n;l=b[4830480]|0;m=c[2443776]|0}else{k=a[i+(g&255)|0]|0;l=f;m=h}}while(0);a[9660972]=k;k=(c[2440596]|0)-1|0;c[2440596]=k;b[4830480]=l+1&65535;h=l&65535;f=c[m+68+(h>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[m+3168>>2]|0;if((g|0)==0){o=0;p=k;q=m;break}i=gj[g&4095](l)|0;o=i;p=c[2440596]|0;q=c[2443776]|0}else{o=a[f+(h&255)|0]|0;p=k;q=m}}while(0);a[9660973]=o;o=p-1|0;c[2440596]=o;p=c[2415243]|0;m=c[q+68+((p>>>8&255|256)<<2)>>2]|0;if((m|0)!=0){a[m+(p&255)|0]=d;r=o;s=r-1|0;c[2440596]=s;return}m=c[q+3152>>2]|0;if((m|0)==0){r=o;s=r-1|0;c[2440596]=s;return}gg[m&4095](p&65535,d);r=c[2440596]|0;s=r-1|0;c[2440596]=s;return}function fWM(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;b[4830480]=k+1&65535;g=k&65535;e=c[l+68+(g>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[l+3168>>2]|0;if((f|0)==0){n=0;o=j;p=l;break}h=gj[f&4095](k)|0;n=h;o=c[2440596]|0;p=c[2443776]|0}else{n=a[e+(g&255)|0]|0;o=j;p=l}}while(0);a[9660973]=n;n=o-1|0;c[2440596]=n;o=c[2415243]|0;l=o&65535;j=c[p+68+((o>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[p+3148>>2]|0;if((g|0)==0){q=0;r=n;break}e=gj[g&4095](l)|0;q=e;r=c[2440596]|0}else{q=a[j+(o&255)|0]|0;r=n}}while(0);c[2440596]=r-1;a[9660977]=q;a[9660976]=q;a[9660979]=a[9660979]&125|(q<<24>>24==0?2:q&-128);return}function fWN(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;b[4830480]=k+1&65535;g=k&65535;e=c[l+68+(g>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[l+3168>>2]|0;if((f|0)==0){n=0;o=j;p=l;break}h=gj[f&4095](k)|0;n=h;o=c[2440596]|0;p=c[2443776]|0}else{n=a[e+(g&255)|0]|0;o=j;p=l}}while(0);a[9660973]=n;n=o-1|0;c[2440596]=n;o=c[2415243]|0;l=o&65535;j=c[p+68+((o>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[p+3148>>2]|0;if((g|0)==0){q=0;r=n;s=o;t=p;break}e=gj[g&4095](l)|0;q=e;r=c[2440596]|0;s=c[2415243]|0;t=c[2443776]|0}else{q=a[j+(o&255)|0]|0;r=n;s=o;t=p}}while(0);p=r-1|0;c[2440596]=p;r=s&65535;o=c[t+68+((s>>>8&255|256)<<2)>>2]|0;do{if((o|0)==0){n=c[t+3152>>2]|0;if((n|0)==0){u=p;break}gg[n&4095](r,q);u=c[2440596]|0}else{a[o+(s&255)|0]=q;u=p}}while(0);p=u-1|0;c[2440596]=p;u=q-1&255;q=a[9660979]|0;s=q&-2;a[9660979]=s;o=a[9660976]|0;if((o&255)<(u&255)){v=s}else{s=q|1;a[9660979]=s;v=s}if(o<<24>>24==u<<24>>24){w=v&125|2}else{w=v&125|o-u&255&-128}a[9660979]=w;w=c[2415243]|0;o=c[2443776]|0;v=c[o+68+((w>>>8&255|256)<<2)>>2]|0;if((v|0)!=0){a[v+(w&255)|0]=u;x=p;y=x-1|0;c[2440596]=y;return}v=c[o+3152>>2]|0;if((v|0)==0){x=p;y=x-1|0;c[2440596]=y;return}gg[v&4095](w&65535,u);x=c[2440596]|0;y=x-1|0;c[2440596]=y;return}function fWO(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;b[4830480]=k+1&65535;g=k&65535;e=c[l+68+(g>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[l+3168>>2]|0;if((f|0)==0){n=0;o=j;p=l;break}h=gj[f&4095](k)|0;n=h;o=c[2440596]|0;p=c[2443776]|0}else{n=a[e+(g&255)|0]|0;o=j;p=l}}while(0);a[9660973]=n;n=o-1|0;c[2440596]=n;o=c[2415243]|0;l=o&65535;j=c[p+68+((o>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[p+3148>>2]|0;if((g|0)==0){q=0;r=n;s=o;t=p;break}e=gj[g&4095](l)|0;q=e;r=c[2440596]|0;s=c[2415243]|0;t=c[2443776]|0}else{q=a[j+(o&255)|0]|0;r=n;s=o;t=p}}while(0);p=r-1|0;c[2440596]=p;r=s&65535;o=c[t+68+((s>>>8&255|256)<<2)>>2]|0;do{if((o|0)==0){n=c[t+3152>>2]|0;if((n|0)==0){u=p;break}gg[n&4095](r,q);u=c[2440596]|0}else{a[o+(s&255)|0]=q;u=p}}while(0);p=u-1|0;c[2440596]=p;u=q+1&255;q=u&255;s=a[9660979]|0;o=s&255;r=o&1^1;t=a[9660976]|0;n=t&255;j=n-q-r|0;do{if((o&8|0)==0){l=s&-66;e=(((t^u)&128&(j^n)|0)==0?l:l|64)|(j&65280|0)==0;a[9660979]=e;a[9660976]=j&255;if((j&255|0)==0){a[9660979]=e&125|2;break}else{a[9660979]=(e&125|j&128)&255;break}}else{e=(n&15)-(q&15)-r|0;l=(n&240)-(q&240)|0;if((e&16|0)==0){v=e;w=l}else{v=e-6|0;w=l-1|0}l=s&60;e=(((t^u)&128&(j^n)|0)==0?l:l|64)|(j&65280|0)==0;l=(j&255|0)==0?e|2:e;a[9660979]=(j&128|0)==0?l:l|-128;a[9660976]=(((w&256|0)==0?w:w+160|0)&240|v&15)&255}}while(0);v=c[2415243]|0;w=c[2443776]|0;j=c[w+68+((v>>>8&255|256)<<2)>>2]|0;if((j|0)!=0){a[j+(v&255)|0]=u;x=p;y=x-1|0;c[2440596]=y;return}j=c[w+3152>>2]|0;if((j|0)==0){x=p;y=x-1|0;c[2440596]=y;return}gg[j&4095](v&65535,u);x=c[2440596]|0;y=x-1|0;c[2440596]=y;return}function fWP(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;g=(c[2440596]|0)-1|0;c[2440596]=g;b[4830480]=k+1&65535;e=k&65535;f=c[l+68+(e>>>8<<2)>>2]|0;do{if((f|0)==0){h=c[l+3168>>2]|0;if((h|0)==0){n=0;o=g;p=j;q=l;break}d=gj[h&4095](k)|0;n=d;o=c[2440596]|0;p=a[9660972]|0;q=c[2443776]|0}else{n=a[f+(e&255)|0]|0;o=g;p=j;q=l}}while(0);a[9660973]=n;l=o-1|0;c[2440596]=l;o=(n&255)<<8;n=a[9660977]|0;j=(n&255)+(p&255)&255|o;do{if((c[q+68+((o&65535)>>>8<<2)>>2]|0)==0){p=c[q+3148>>2]|0;if((p|0)==0){r=l;s=n;t=q;break}gj[p&4095](j)|0;r=c[2440596]|0;s=a[9660977]|0;t=c[2443776]|0}else{r=l;s=n;t=q}}while(0);q=r-1|0;c[2440596]=q;b[4830486]=(b[4830486]|0)+(s&255)&65535;s=c[2415243]|0;r=s&65535;n=c[t+68+((s>>>8&255)<<2)>>2]|0;do{if((n|0)==0){l=c[t+3148>>2]|0;if((l|0)==0){u=0;v=q;w=s;x=t;break}j=gj[l&4095](r)|0;u=j;v=c[2440596]|0;w=c[2415243]|0;x=c[2443776]|0}else{u=a[n+(s&255)|0]|0;v=q;w=s;x=t}}while(0);t=v-1|0;c[2440596]=t;v=w&65535;s=c[x+68+((w>>>8&255|256)<<2)>>2]|0;do{if((s|0)==0){q=c[x+3152>>2]|0;if((q|0)==0){y=t;z=x;break}gg[q&4095](v,u);y=c[2440596]|0;z=c[2443776]|0}else{a[s+(w&255)|0]=u;y=t;z=x}}while(0);x=y-1|0;c[2440596]=x;y=a[9660979]&124;t=u<<1;w=a[9660976]|t;a[9660976]=w;a[9660979]=y|(u&255)>>>7|(w<<24>>24==0?2:w&-128);w=c[2415243]|0;u=c[z+68+((w>>>8&255|256)<<2)>>2]|0;if((u|0)!=0){a[u+(w&255)|0]=t;A=x;B=A-1|0;c[2440596]=B;return}u=c[z+3152>>2]|0;if((u|0)==0){A=x;B=A-1|0;c[2440596]=B;return}gg[u&4095](w&65535,t);A=c[2440596]|0;B=A-1|0;c[2440596]=B;return}function fWQ(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;g=(c[2440596]|0)-1|0;c[2440596]=g;b[4830480]=k+1&65535;e=k&65535;f=c[l+68+(e>>>8<<2)>>2]|0;do{if((f|0)==0){h=c[l+3168>>2]|0;if((h|0)==0){n=0;o=g;p=j;q=l;break}d=gj[h&4095](k)|0;n=d;o=c[2440596]|0;p=a[9660972]|0;q=c[2443776]|0}else{n=a[f+(e&255)|0]|0;o=g;p=j;q=l}}while(0);a[9660973]=n;l=o-1|0;c[2440596]=l;o=(n&255)<<8;n=a[9660977]|0;j=(n&255)+(p&255)&255|o;do{if((c[q+68+((o&65535)>>>8<<2)>>2]|0)==0){p=c[q+3148>>2]|0;if((p|0)==0){r=l;s=n;t=q;break}gj[p&4095](j)|0;r=c[2440596]|0;s=a[9660977]|0;t=c[2443776]|0}else{r=l;s=n;t=q}}while(0);q=r-1|0;c[2440596]=q;b[4830486]=(b[4830486]|0)+(s&255)&65535;s=c[2415243]|0;r=s&65535;n=c[t+68+((s>>>8&255)<<2)>>2]|0;do{if((n|0)==0){l=c[t+3148>>2]|0;if((l|0)==0){u=0;v=q;w=s;x=t;break}j=gj[l&4095](r)|0;u=j;v=c[2440596]|0;w=c[2415243]|0;x=c[2443776]|0}else{u=a[n+(s&255)|0]|0;v=q;w=s;x=t}}while(0);t=v-1|0;c[2440596]=t;v=w&65535;s=c[x+68+((w>>>8&255|256)<<2)>>2]|0;do{if((s|0)==0){q=c[x+3152>>2]|0;if((q|0)==0){y=t;z=x;break}gg[q&4095](v,u);y=c[2440596]|0;z=c[2443776]|0}else{a[s+(w&255)|0]=u;y=t;z=x}}while(0);x=y-1|0;c[2440596]=x;y=a[9660979]|0;t=y&1|u<<1;w=t&a[9660976];a[9660976]=w;a[9660979]=y&124|(u&255)>>>7|(w<<24>>24==0?2:w&-128);w=c[2415243]|0;u=c[z+68+((w>>>8&255|256)<<2)>>2]|0;if((u|0)!=0){a[u+(w&255)|0]=t;A=x;B=A-1|0;c[2440596]=B;return}u=c[z+3152>>2]|0;if((u|0)==0){A=x;B=A-1|0;c[2440596]=B;return}gg[u&4095](w&65535,t);A=c[2440596]|0;B=A-1|0;c[2440596]=B;return}function fWR(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;e=b[4830480]|0;f=e+1&65535;b[4830480]=f;g=e&65535;h=c[2443776]|0;i=c[h+68+(g>>>8<<2)>>2]|0;do{if((i|0)==0){j=c[h+3168>>2]|0;if((j|0)==0){k=0;l=f;m=h;break}n=gj[j&4095](e)|0;k=n;l=b[4830480]|0;m=c[2443776]|0}else{k=a[i+(g&255)|0]|0;l=f;m=h}}while(0);a[9660972]=k;h=(c[2440596]|0)-1|0;c[2440596]=h;b[4830480]=l+1&65535;f=l&65535;g=c[m+68+(f>>>8<<2)>>2]|0;do{if((g|0)==0){i=c[m+3168>>2]|0;if((i|0)==0){o=0;p=h;q=k;r=m;break}e=gj[i&4095](l)|0;o=e;p=c[2440596]|0;q=a[9660972]|0;r=c[2443776]|0}else{o=a[g+(f&255)|0]|0;p=h;q=k;r=m}}while(0);a[9660973]=o;m=p-1|0;c[2440596]=m;p=(o&255)<<8;o=a[9660977]|0;k=(o&255)+(q&255)&255|p;do{if((c[r+68+((p&65535)>>>8<<2)>>2]|0)==0){q=c[r+3148>>2]|0;if((q|0)==0){s=m;t=o;u=r;break}gj[q&4095](k)|0;s=c[2440596]|0;t=a[9660977]|0;u=c[2443776]|0}else{s=m;t=o;u=r}}while(0);r=s-1|0;c[2440596]=r;b[4830486]=(b[4830486]|0)+(t&255)&65535;t=c[2415243]|0;s=t&65535;o=c[u+68+((t>>>8&255)<<2)>>2]|0;do{if((o|0)==0){m=c[u+3148>>2]|0;if((m|0)==0){v=0;w=r;x=t;y=u;break}k=gj[m&4095](s)|0;v=k;w=c[2440596]|0;x=c[2415243]|0;y=c[2443776]|0}else{v=a[o+(t&255)|0]|0;w=r;x=t;y=u}}while(0);u=w-1|0;c[2440596]=u;w=x&65535;t=c[y+68+((x>>>8&255|256)<<2)>>2]|0;do{if((t|0)==0){r=c[y+3152>>2]|0;if((r|0)==0){z=u;break}gg[r&4095](w,v);z=c[2440596]|0}else{a[t+(x&255)|0]=v;z=u}}while(0);u=z-1|0;c[2440596]=u;z=a[9660979]&-2|v&1;a[9660979]=z;x=(v&255)>>>1;v=d[9660976]|0;t=v^x;a[9660976]=t&255;if((v|0)==(x|0)){A=z&125|2}else{A=(z&125|t&128)&255}a[9660979]=A;A=c[2415243]|0;t=x&255;x=c[2443776]|0;z=c[x+68+((A>>>8&255|256)<<2)>>2]|0;if((z|0)!=0){a[z+(A&255)|0]=t;B=u;C=B-1|0;c[2440596]=C;return}z=c[x+3152>>2]|0;if((z|0)==0){B=u;C=B-1|0;c[2440596]=C;return}gg[z&4095](A&65535,t);B=c[2440596]|0;C=B-1|0;c[2440596]=C;return}function fWS(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;e=b[4830480]|0;f=e+1&65535;b[4830480]=f;g=e&65535;h=c[2443776]|0;i=c[h+68+(g>>>8<<2)>>2]|0;do{if((i|0)==0){j=c[h+3168>>2]|0;if((j|0)==0){k=0;l=f;m=h;break}n=gj[j&4095](e)|0;k=n;l=b[4830480]|0;m=c[2443776]|0}else{k=a[i+(g&255)|0]|0;l=f;m=h}}while(0);a[9660972]=k;h=(c[2440596]|0)-1|0;c[2440596]=h;b[4830480]=l+1&65535;f=l&65535;g=c[m+68+(f>>>8<<2)>>2]|0;do{if((g|0)==0){i=c[m+3168>>2]|0;if((i|0)==0){o=0;p=h;q=k;r=m;break}e=gj[i&4095](l)|0;o=e;p=c[2440596]|0;q=a[9660972]|0;r=c[2443776]|0}else{o=a[g+(f&255)|0]|0;p=h;q=k;r=m}}while(0);a[9660973]=o;m=p-1|0;c[2440596]=m;p=(o&255)<<8;o=a[9660977]|0;k=(o&255)+(q&255)&255|p;do{if((c[r+68+((p&65535)>>>8<<2)>>2]|0)==0){q=c[r+3148>>2]|0;if((q|0)==0){s=m;t=o;u=r;break}gj[q&4095](k)|0;s=c[2440596]|0;t=a[9660977]|0;u=c[2443776]|0}else{s=m;t=o;u=r}}while(0);r=s-1|0;c[2440596]=r;b[4830486]=(b[4830486]|0)+(t&255)&65535;t=c[2415243]|0;s=t&65535;o=c[u+68+((t>>>8&255)<<2)>>2]|0;do{if((o|0)==0){m=c[u+3148>>2]|0;if((m|0)==0){v=0;w=r;x=t;y=u;break}k=gj[m&4095](s)|0;v=k;w=c[2440596]|0;x=c[2415243]|0;y=c[2443776]|0}else{v=a[o+(t&255)|0]|0;w=r;x=t;y=u}}while(0);u=v&255;t=w-1|0;c[2440596]=t;w=x&65535;r=c[y+68+((x>>>8&255|256)<<2)>>2]|0;do{if((r|0)==0){o=c[y+3152>>2]|0;if((o|0)==0){z=t;break}gg[o&4095](w,v);z=c[2440596]|0}else{a[r+(x&255)|0]=v;z=t}}while(0);t=z-1|0;c[2440596]=t;z=a[9660979]|0;x=z&-2|v&1;a[9660979]=x;v=((z&255)<<8|u)>>>1;u=x&255;x=u&1;do{if((u&8|0)==0){r=d[9660976]|0;w=(v&255)+x+r|0;y=z&-66;o=(((v^128^r)&128&(w^r)|0)==0?y:y|64)|(w&65280|0)!=0;a[9660979]=o;a[9660976]=w&255;if((w&255|0)==0){a[9660979]=o&125|2;break}else{a[9660979]=(o&125|w&128)&255;break}}else{w=d[9660976]|0;o=(v&15)+x+(w&15)|0;y=(w&240)+(v&240)|0;r=z&60;s=(o+y&255|0)==0?r|2:r;a[9660979]=s;if((o|0)>9){A=o+6|0;B=y+16|0}else{A=o;B=y}if((B&128|0)==0){C=s}else{y=s|-128;a[9660979]=y;C=y}if(((v^128^w)&128&(B^w)|0)==0){D=C}else{w=C|64;a[9660979]=w;D=w}w=(B|0)>144?B+96|0:B;if((w&65280|0)!=0){a[9660979]=D|1}a[9660976]=(w&240|A&15)&255}}while(0);A=c[2415243]|0;D=v&255;v=c[2443776]|0;B=c[v+68+((A>>>8&255|256)<<2)>>2]|0;if((B|0)!=0){a[B+(A&255)|0]=D;E=t;F=E-1|0;c[2440596]=F;return}B=c[v+3152>>2]|0;if((B|0)==0){E=t;F=E-1|0;c[2440596]=F;return}gg[B&4095](A&65535,D);E=c[2440596]|0;F=E-1|0;c[2440596]=F;return}function fWT(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;g=(c[2440596]|0)-1|0;c[2440596]=g;b[4830480]=k+1&65535;e=k&65535;f=c[l+68+(e>>>8<<2)>>2]|0;do{if((f|0)==0){h=c[l+3168>>2]|0;if((h|0)==0){n=0;o=g;p=j;q=l;break}d=gj[h&4095](k)|0;n=d;o=c[2440596]|0;p=a[9660972]|0;q=c[2443776]|0}else{n=a[f+(e&255)|0]|0;o=g;p=j;q=l}}while(0);a[9660973]=n;l=o-1|0;c[2440596]=l;o=(n&255)<<8;n=a[9660978]|0;j=(n&255)+(p&255)&255|o;do{if((c[q+68+((o&65535)>>>8<<2)>>2]|0)==0){p=c[q+3148>>2]|0;if((p|0)==0){r=l;s=n;t=q;break}gj[p&4095](j)|0;r=c[2440596]|0;s=a[9660978]|0;t=c[2443776]|0}else{r=l;s=n;t=q}}while(0);q=r-1|0;c[2440596]=q;r=(b[4830486]|0)+(s&255)&65535;b[4830486]=r;s=a[9660977]&a[9660976]&(((r&65535)>>>8&255)+1&255);r=c[2415243]|0;n=c[t+68+((r>>>8&255|256)<<2)>>2]|0;if((n|0)!=0){a[n+(r&255)|0]=s;u=q;v=u-1|0;c[2440596]=v;return}n=c[t+3152>>2]|0;if((n|0)==0){u=q;v=u-1|0;c[2440596]=v;return}gg[n&4095](r&65535,s);u=c[2440596]|0;v=u-1|0;c[2440596]=v;return}function fWU(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;g=(c[2440596]|0)-1|0;c[2440596]=g;b[4830480]=k+1&65535;e=k&65535;f=c[l+68+(e>>>8<<2)>>2]|0;do{if((f|0)==0){h=c[l+3168>>2]|0;if((h|0)==0){n=0;o=g;p=j;break}d=gj[h&4095](k)|0;n=d;o=c[2440596]|0;p=a[9660972]|0}else{n=a[f+(e&255)|0]|0;o=g;p=j}}while(0);a[9660973]=n;j=o-1|0;c[2440596]=j;o=a[9660978]|0;g=(o&255)+(p&255)|0;if((g|0)>255){p=n&255;n=(g&255|p<<8)&65535;g=c[2443776]|0;do{if((c[g+68+(p<<2)>>2]|0)==0){e=c[g+3148>>2]|0;if((e|0)==0){q=j;r=o;break}gj[e&4095](n)|0;q=c[2440596]|0;r=a[9660978]|0}else{q=j;r=o}}while(0);n=q-1|0;c[2440596]=n;s=r;t=n}else{s=o;t=j}b[4830486]=(b[4830486]|0)+(s&255)&65535;s=c[2415243]|0;j=s&65535;o=c[2443776]|0;n=c[o+68+((s>>>8&255)<<2)>>2]|0;do{if((n|0)==0){r=c[o+3148>>2]|0;if((r|0)==0){u=0;v=t;break}q=gj[r&4095](j)|0;u=q;v=c[2440596]|0}else{u=a[n+(s&255)|0]|0;v=t}}while(0);c[2440596]=v-1;a[9660977]=u;a[9660976]=u;a[9660979]=a[9660979]&125|(u<<24>>24==0?2:u&-128);return}function fWV(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;g=(c[2440596]|0)-1|0;c[2440596]=g;b[4830480]=k+1&65535;e=k&65535;f=c[l+68+(e>>>8<<2)>>2]|0;do{if((f|0)==0){h=c[l+3168>>2]|0;if((h|0)==0){n=0;o=g;p=j;q=l;break}d=gj[h&4095](k)|0;n=d;o=c[2440596]|0;p=a[9660972]|0;q=c[2443776]|0}else{n=a[f+(e&255)|0]|0;o=g;p=j;q=l}}while(0);a[9660973]=n;l=o-1|0;c[2440596]=l;o=(n&255)<<8;n=a[9660977]|0;j=(n&255)+(p&255)&255|o;do{if((c[q+68+((o&65535)>>>8<<2)>>2]|0)==0){p=c[q+3148>>2]|0;if((p|0)==0){r=l;s=n;t=q;break}gj[p&4095](j)|0;r=c[2440596]|0;s=a[9660977]|0;t=c[2443776]|0}else{r=l;s=n;t=q}}while(0);q=r-1|0;c[2440596]=q;b[4830486]=(b[4830486]|0)+(s&255)&65535;s=c[2415243]|0;r=s&65535;n=c[t+68+((s>>>8&255)<<2)>>2]|0;do{if((n|0)==0){l=c[t+3148>>2]|0;if((l|0)==0){u=0;v=q;w=s;x=t;break}j=gj[l&4095](r)|0;u=j;v=c[2440596]|0;w=c[2415243]|0;x=c[2443776]|0}else{u=a[n+(s&255)|0]|0;v=q;w=s;x=t}}while(0);t=v-1|0;c[2440596]=t;v=w&65535;s=c[x+68+((w>>>8&255|256)<<2)>>2]|0;do{if((s|0)==0){q=c[x+3152>>2]|0;if((q|0)==0){y=t;break}gg[q&4095](v,u);y=c[2440596]|0}else{a[s+(w&255)|0]=u;y=t}}while(0);t=y-1|0;c[2440596]=t;y=u-1&255;u=a[9660979]|0;w=u&-2;a[9660979]=w;s=a[9660976]|0;if((s&255)<(y&255)){z=w}else{w=u|1;a[9660979]=w;z=w}if(s<<24>>24==y<<24>>24){A=z&125|2}else{A=z&125|s-y&255&-128}a[9660979]=A;A=c[2415243]|0;s=c[2443776]|0;z=c[s+68+((A>>>8&255|256)<<2)>>2]|0;if((z|0)!=0){a[z+(A&255)|0]=y;B=t;C=B-1|0;c[2440596]=C;return}z=c[s+3152>>2]|0;if((z|0)==0){B=t;C=B-1|0;c[2440596]=C;return}gg[z&4095](A&65535,y);B=c[2440596]|0;C=B-1|0;c[2440596]=C;return}function fWW(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;g=(c[2440596]|0)-1|0;c[2440596]=g;b[4830480]=k+1&65535;e=k&65535;f=c[l+68+(e>>>8<<2)>>2]|0;do{if((f|0)==0){h=c[l+3168>>2]|0;if((h|0)==0){n=0;o=g;p=j;q=l;break}d=gj[h&4095](k)|0;n=d;o=c[2440596]|0;p=a[9660972]|0;q=c[2443776]|0}else{n=a[f+(e&255)|0]|0;o=g;p=j;q=l}}while(0);a[9660973]=n;l=o-1|0;c[2440596]=l;o=(n&255)<<8;n=a[9660977]|0;j=(n&255)+(p&255)&255|o;do{if((c[q+68+((o&65535)>>>8<<2)>>2]|0)==0){p=c[q+3148>>2]|0;if((p|0)==0){r=l;s=n;t=q;break}gj[p&4095](j)|0;r=c[2440596]|0;s=a[9660977]|0;t=c[2443776]|0}else{r=l;s=n;t=q}}while(0);q=r-1|0;c[2440596]=q;b[4830486]=(b[4830486]|0)+(s&255)&65535;s=c[2415243]|0;r=s&65535;n=c[t+68+((s>>>8&255)<<2)>>2]|0;do{if((n|0)==0){l=c[t+3148>>2]|0;if((l|0)==0){u=0;v=q;w=s;x=t;break}j=gj[l&4095](r)|0;u=j;v=c[2440596]|0;w=c[2415243]|0;x=c[2443776]|0}else{u=a[n+(s&255)|0]|0;v=q;w=s;x=t}}while(0);t=v-1|0;c[2440596]=t;v=w&65535;s=c[x+68+((w>>>8&255|256)<<2)>>2]|0;do{if((s|0)==0){q=c[x+3152>>2]|0;if((q|0)==0){y=t;break}gg[q&4095](v,u);y=c[2440596]|0}else{a[s+(w&255)|0]=u;y=t}}while(0);t=y-1|0;c[2440596]=t;y=u+1&255;u=y&255;w=a[9660979]|0;s=w&255;v=s&1^1;x=a[9660976]|0;q=x&255;n=q-u-v|0;do{if((s&8|0)==0){r=w&-66;j=(((x^y)&128&(n^q)|0)==0?r:r|64)|(n&65280|0)==0;a[9660979]=j;a[9660976]=n&255;if((n&255|0)==0){a[9660979]=j&125|2;break}else{a[9660979]=(j&125|n&128)&255;break}}else{j=(q&15)-(u&15)-v|0;r=(q&240)-(u&240)|0;if((j&16|0)==0){z=j;A=r}else{z=j-6|0;A=r-1|0}r=w&60;j=(((x^y)&128&(n^q)|0)==0?r:r|64)|(n&65280|0)==0;r=(n&255|0)==0?j|2:j;a[9660979]=(n&128|0)==0?r:r|-128;a[9660976]=(((A&256|0)==0?A:A+160|0)&240|z&15)&255}}while(0);z=c[2415243]|0;A=c[2443776]|0;n=c[A+68+((z>>>8&255|256)<<2)>>2]|0;if((n|0)!=0){a[n+(z&255)|0]=y;B=t;C=B-1|0;c[2440596]=C;return}n=c[A+3152>>2]|0;if((n|0)==0){B=t;C=B-1|0;c[2440596]=C;return}gg[n&4095](z&65535,y);B=c[2440596]|0;C=B-1|0;c[2440596]=C;return}function fWX(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=f&255;do{if((c[j+68+((f>>>8&255)<<2)>>2]|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=i;m=g;n=j;break}gj[d&4095](e)|0;l=c[2440596]|0;m=a[9660968]|0;n=c[2443776]|0}else{l=i;m=g;n=j}}while(0);j=l-1|0;c[2440596]=j;a[9660968]=(a[9660977]|0)+m&255;m=c[2415242]|0;l=m&65535;g=c[n+68+((m>>>8&255)<<2)>>2]|0;i=m&255;do{if((g|0)==0){e=c[n+3148>>2]|0;if((e|0)==0){o=0;p=j;q=i;r=n;break}f=gj[e&4095](l)|0;o=f;p=c[2440596]|0;q=a[9660968]|0;r=c[2443776]|0}else{o=a[g+(m&255)|0]|0;p=j;q=i;r=n}}while(0);a[9660972]=o;o=p-1|0;c[2440596]=o;a[9660968]=q+1&255;q=c[2415242]|0;p=q&65535;n=c[r+68+((q>>>8&255)<<2)>>2]|0;do{if((n|0)==0){i=c[r+3148>>2]|0;if((i|0)==0){s=0;t=o;u=r;break}j=gj[i&4095](p)|0;s=j;t=c[2440596]|0;u=c[2443776]|0}else{s=a[n+(q&255)|0]|0;t=o;u=r}}while(0);a[9660973]=s;s=t-1|0;c[2440596]=s;t=c[2415243]|0;r=t&65535;o=c[u+68+((t>>>8&255)<<2)>>2]|0;do{if((o|0)==0){q=c[u+3156>>2]|0;if((q|0)==0){v=0;w=s;break}n=gj[q&4095](r)|0;v=n;w=c[2440596]|0}else{v=a[o+(t&255)|0]|0;w=s}}while(0);c[2440596]=w-1;w=a[9660979]|0;s=a[9660976]|0;t=s&255;o=t+(v&255)+(w&1)|0;r=w&-66;w=((((s^v)&128^128)&(o^t)|0)==0?r:r|64)|(o&65280|0)!=0;a[9660979]=w;a[9660976]=o&255;if((o&255|0)==0){x=w&125|2;a[9660979]=x;return}else{x=(w&125|o&128)&255;a[9660979]=x;return}}function fWY(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=f&255;do{if((c[j+68+((f>>>8&255)<<2)>>2]|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=i;m=g;n=j;break}gj[d&4095](e)|0;l=c[2440596]|0;m=a[9660968]|0;n=c[2443776]|0}else{l=i;m=g;n=j}}while(0);j=l-1|0;c[2440596]=j;a[9660968]=(a[9660977]|0)+m&255;m=c[2415242]|0;l=m&65535;g=c[n+68+((m>>>8&255)<<2)>>2]|0;i=m&255;do{if((g|0)==0){e=c[n+3148>>2]|0;if((e|0)==0){o=0;p=j;q=i;r=n;break}f=gj[e&4095](l)|0;o=f;p=c[2440596]|0;q=a[9660968]|0;r=c[2443776]|0}else{o=a[g+(m&255)|0]|0;p=j;q=i;r=n}}while(0);a[9660972]=o;o=p-1|0;c[2440596]=o;a[9660968]=q+1&255;q=c[2415242]|0;p=q&65535;n=c[r+68+((q>>>8&255)<<2)>>2]|0;do{if((n|0)==0){i=c[r+3148>>2]|0;if((i|0)==0){s=0;t=o;u=r;break}j=gj[i&4095](p)|0;s=j;t=c[2440596]|0;u=c[2443776]|0}else{s=a[n+(q&255)|0]|0;t=o;u=r}}while(0);a[9660973]=s;s=t-1|0;c[2440596]=s;t=c[2415243]|0;r=t&65535;o=c[u+68+((t>>>8&255)<<2)>>2]|0;do{if((o|0)==0){q=c[u+3156>>2]|0;if((q|0)==0){v=0;w=s;break}n=gj[q&4095](r)|0;v=n;w=c[2440596]|0}else{v=a[o+(t&255)|0]|0;w=s}}while(0);c[2440596]=w-1;w=a[9660979]|0;s=a[9660976]|0;t=s&255;o=t-(v&255)-(w&1^1)|0;r=w&-66;w=(((s^v)&128&(o^t)|0)==0?r:r|64)|(o&65280|0)==0;a[9660979]=w;a[9660976]=o&255;if((o&255|0)==0){x=w&125|2;a[9660979]=x;return}else{x=(w&125|o&128)&255;a[9660979]=x;return}}function fWZ(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;d=f&255;do{if((g|0)==0){k=c[j+3148>>2]|0;if((k|0)==0){l=0;m=i;n=d;o=j;break}h=gj[k&4095](e)|0;l=h;m=c[2440596]|0;n=a[9660968]|0;o=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=d;o=j}}while(0);a[9660972]=l;j=m-1|0;c[2440596]=j;a[9660968]=n+1&255;n=c[2415242]|0;m=n&65535;d=c[o+68+((n>>>8&255)<<2)>>2]|0;do{if((d|0)==0){i=c[o+3148>>2]|0;if((i|0)==0){p=0;q=j;r=l;break}f=gj[i&4095](m)|0;p=f;q=c[2440596]|0;r=a[9660972]|0}else{p=a[d+(n&255)|0]|0;q=j;r=l}}while(0);a[9660973]=p;l=q-1|0;c[2440596]=l;q=a[9660978]|0;j=(q&255)+(r&255)|0;if((j|0)>255){r=p&255;p=(j&255|r<<8)&65535;j=c[2443776]|0;do{if((c[j+68+(r<<2)>>2]|0)==0){n=c[j+3148>>2]|0;if((n|0)==0){s=l;t=q;break}gj[n&4095](p)|0;s=c[2440596]|0;t=a[9660978]|0}else{s=l;t=q}}while(0);p=s-1|0;c[2440596]=p;u=t;v=p}else{u=q;v=l}b[4830486]=(b[4830486]|0)+(u&255)&65535;u=c[2415243]|0;l=u&65535;q=c[2443776]|0;p=c[q+68+((u>>>8&255)<<2)>>2]|0;do{if((p|0)==0){t=c[q+3156>>2]|0;if((t|0)==0){w=0;x=v;break}s=gj[t&4095](l)|0;w=s;x=c[2440596]|0}else{w=a[p+(u&255)|0]|0;x=v}}while(0);c[2440596]=x-1;x=a[9660979]|0;v=a[9660976]|0;u=v&255;p=u+(w&255)+(x&1)|0;l=x&-66;x=((((v^w)&128^128)&(p^u)|0)==0?l:l|64)|(p&65280|0)!=0;a[9660979]=x;a[9660976]=p&255;if((p&255|0)==0){y=x&125|2;a[9660979]=y;return}else{y=(x&125|p&128)&255;a[9660979]=y;return}}function fW_(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;d=f&255;do{if((g|0)==0){k=c[j+3148>>2]|0;if((k|0)==0){l=0;m=i;n=d;o=j;break}h=gj[k&4095](e)|0;l=h;m=c[2440596]|0;n=a[9660968]|0;o=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=d;o=j}}while(0);a[9660972]=l;j=m-1|0;c[2440596]=j;a[9660968]=n+1&255;n=c[2415242]|0;m=n&65535;d=c[o+68+((n>>>8&255)<<2)>>2]|0;do{if((d|0)==0){i=c[o+3148>>2]|0;if((i|0)==0){p=0;q=j;r=l;break}f=gj[i&4095](m)|0;p=f;q=c[2440596]|0;r=a[9660972]|0}else{p=a[d+(n&255)|0]|0;q=j;r=l}}while(0);a[9660973]=p;l=q-1|0;c[2440596]=l;q=a[9660978]|0;j=(q&255)+(r&255)|0;if((j|0)>255){r=p&255;p=(j&255|r<<8)&65535;j=c[2443776]|0;do{if((c[j+68+(r<<2)>>2]|0)==0){n=c[j+3148>>2]|0;if((n|0)==0){s=l;t=q;break}gj[n&4095](p)|0;s=c[2440596]|0;t=a[9660978]|0}else{s=l;t=q}}while(0);p=s-1|0;c[2440596]=p;u=t;v=p}else{u=q;v=l}b[4830486]=(b[4830486]|0)+(u&255)&65535;u=c[2415243]|0;l=u&65535;q=c[2443776]|0;p=c[q+68+((u>>>8&255)<<2)>>2]|0;do{if((p|0)==0){t=c[q+3156>>2]|0;if((t|0)==0){w=0;x=v;break}s=gj[t&4095](l)|0;w=s;x=c[2440596]|0}else{w=a[p+(u&255)|0]|0;x=v}}while(0);c[2440596]=x-1;x=a[9660979]|0;v=a[9660976]|0;u=v&255;p=u-(w&255)-(x&1^1)|0;l=x&-66;x=(((v^w)&128&(p^u)|0)==0?l:l|64)|(p&65280|0)==0;a[9660979]=x;a[9660976]=p&255;if((p&255|0)==0){y=x&125|2;a[9660979]=y;return}else{y=(x&125|p&128)&255;a[9660979]=y;return}}function fW$(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;e=b[4830480]|0;b[4830480]=e+1&65535;f=e&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](e)|0;j=l;k=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=g}}while(0);a[9660968]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;g=c[2415242]|0;f=g&65535;h=g&255;do{if((c[k+68+((g>>>8&255)<<2)>>2]|0)==0){e=c[k+3148>>2]|0;if((e|0)==0){m=j;n=h;o=k;break}gj[e&4095](f)|0;m=c[2440596]|0;n=a[9660968]|0;o=c[2443776]|0}else{m=j;n=h;o=k}}while(0);k=m-1|0;c[2440596]=k;a[9660968]=(a[9660977]|0)+n&255;n=c[2415242]|0;m=n&65535;h=c[o+68+((n>>>8&255)<<2)>>2]|0;j=n&255;do{if((h|0)==0){f=c[o+3148>>2]|0;if((f|0)==0){p=0;q=k;r=j;s=o;break}g=gj[f&4095](m)|0;p=g;q=c[2440596]|0;r=a[9660968]|0;s=c[2443776]|0}else{p=a[h+(n&255)|0]|0;q=k;r=j;s=o}}while(0);a[9660972]=p;p=q-1|0;c[2440596]=p;a[9660968]=r+1&255;r=c[2415242]|0;q=r&65535;o=c[s+68+((r>>>8&255)<<2)>>2]|0;do{if((o|0)==0){j=c[s+3148>>2]|0;if((j|0)==0){t=0;u=p;v=s;break}k=gj[j&4095](q)|0;t=k;u=c[2440596]|0;v=c[2443776]|0}else{t=a[o+(r&255)|0]|0;u=p;v=s}}while(0);a[9660973]=t;t=u-1|0;c[2440596]=t;u=c[2415243]|0;s=u&65535;p=c[v+68+((u>>>8&255)<<2)>>2]|0;do{if((p|0)==0){r=c[v+3156>>2]|0;if((r|0)==0){w=0;x=t;y=u;z=v;break}o=gj[r&4095](s)|0;w=o;x=c[2440596]|0;y=c[2415243]|0;z=c[2443776]|0}else{w=a[p+(u&255)|0]|0;x=t;y=u;z=v}}while(0);v=w&255;u=x-1|0;c[2440596]=u;x=y&65535;t=c[z+68+((y>>>8&255|256)<<2)>>2]|0;do{if((t|0)==0){p=c[z+3152>>2]|0;if((p|0)==0){A=u;break}gg[p&4095](x,w);A=c[2440596]|0}else{a[t+(y&255)|0]=w;A=u}}while(0);u=A-1|0;c[2440596]=u;A=a[9660979]|0;w=((A&255)<<8|v)>>>1;y=d[9660976]|0;t=y+(v&1)|0;v=(w&255)+t|0;x=A&-66;A=(((y^128^w)&128&(v^y)|0)==0?x:x|64)|(v&65280|0)!=0;a[9660979]=A;a[9660976]=v&255;if((w+t&255|0)==0){B=A&125|2}else{B=(A&125|v&128)&255}a[9660979]=B;B=c[2415243]|0;v=w&255;w=c[2443776]|0;A=c[w+68+((B>>>8&255|256)<<2)>>2]|0;if((A|0)!=0){a[A+(B&255)|0]=v;C=u;D=C-1|0;c[2440596]=D;return}A=c[w+3152>>2]|0;if((A|0)==0){C=u;D=C-1|0;c[2440596]=D;return}gg[A&4095](B&65535,v);C=c[2440596]|0;D=C-1|0;c[2440596]=D;return}function fW0(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;e=b[4830480]|0;b[4830480]=e+1&65535;f=e&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](e)|0;j=l;k=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=g}}while(0);a[9660968]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;g=c[2415242]|0;f=g&65535;h=c[k+68+((g>>>8&255)<<2)>>2]|0;e=g&255;do{if((h|0)==0){l=c[k+3148>>2]|0;if((l|0)==0){m=0;n=j;o=e;p=k;break}i=gj[l&4095](f)|0;m=i;n=c[2440596]|0;o=a[9660968]|0;p=c[2443776]|0}else{m=a[h+(g&255)|0]|0;n=j;o=e;p=k}}while(0);a[9660972]=m;k=n-1|0;c[2440596]=k;a[9660968]=o+1&255;o=c[2415242]|0;n=o&65535;e=c[p+68+((o>>>8&255)<<2)>>2]|0;do{if((e|0)==0){j=c[p+3148>>2]|0;if((j|0)==0){q=0;r=k;s=m;t=p;break}g=gj[j&4095](n)|0;q=g;r=c[2440596]|0;s=a[9660972]|0;t=c[2443776]|0}else{q=a[e+(o&255)|0]|0;r=k;s=m;t=p}}while(0);a[9660973]=q;p=r-1|0;c[2440596]=p;r=(q&255)<<8;q=a[9660978]|0;m=(q&255)+(s&255)&255|r;do{if((c[t+68+((r&65535)>>>8<<2)>>2]|0)==0){s=c[t+3148>>2]|0;if((s|0)==0){u=p;v=q;w=t;break}gj[s&4095](m)|0;u=c[2440596]|0;v=a[9660978]|0;w=c[2443776]|0}else{u=p;v=q;w=t}}while(0);t=u-1|0;c[2440596]=t;b[4830486]=(b[4830486]|0)+(v&255)&65535;v=c[2415243]|0;u=v&65535;q=c[w+68+((v>>>8&255)<<2)>>2]|0;do{if((q|0)==0){p=c[w+3156>>2]|0;if((p|0)==0){x=0;y=t;z=v;A=w;break}m=gj[p&4095](u)|0;x=m;y=c[2440596]|0;z=c[2415243]|0;A=c[2443776]|0}else{x=a[q+(v&255)|0]|0;y=t;z=v;A=w}}while(0);w=x&255;v=y-1|0;c[2440596]=v;y=z&65535;t=c[A+68+((z>>>8&255|256)<<2)>>2]|0;do{if((t|0)==0){q=c[A+3152>>2]|0;if((q|0)==0){B=v;break}gg[q&4095](y,x);B=c[2440596]|0}else{a[t+(z&255)|0]=x;B=v}}while(0);v=B-1|0;c[2440596]=v;B=a[9660979]|0;x=((B&255)<<8|w)>>>1;z=d[9660976]|0;t=z+(w&1)|0;w=(x&255)+t|0;y=B&-66;B=(((z^128^x)&128&(w^z)|0)==0?y:y|64)|(w&65280|0)!=0;a[9660979]=B;a[9660976]=w&255;if((x+t&255|0)==0){C=B&125|2}else{C=(B&125|w&128)&255}a[9660979]=C;C=c[2415243]|0;w=x&255;x=c[2443776]|0;B=c[x+68+((C>>>8&255|256)<<2)>>2]|0;if((B|0)!=0){a[B+(C&255)|0]=w;D=v;E=D-1|0;c[2440596]=E;return}B=c[x+3152>>2]|0;if((B|0)==0){D=v;E=D-1|0;c[2440596]=E;return}gg[B&4095](C&65535,w);D=c[2440596]|0;E=D-1|0;c[2440596]=E;return}function fW1(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=f&255;do{if((c[j+68+((f>>>8&255)<<2)>>2]|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=i;m=g;n=j;break}gj[d&4095](e)|0;l=c[2440596]|0;m=a[9660968]|0;n=c[2443776]|0}else{l=i;m=g;n=j}}while(0);j=l-1|0;c[2440596]=j;a[9660968]=(a[9660977]|0)+m&255;m=c[2415242]|0;l=m&65535;g=c[n+68+((m>>>8&255)<<2)>>2]|0;i=m&255;do{if((g|0)==0){e=c[n+3148>>2]|0;if((e|0)==0){o=0;p=j;q=i;r=n;break}f=gj[e&4095](l)|0;o=f;p=c[2440596]|0;q=a[9660968]|0;r=c[2443776]|0}else{o=a[g+(m&255)|0]|0;p=j;q=i;r=n}}while(0);a[9660972]=o;o=p-1|0;c[2440596]=o;a[9660968]=q+1&255;q=c[2415242]|0;p=q&65535;n=c[r+68+((q>>>8&255)<<2)>>2]|0;do{if((n|0)==0){i=c[r+3148>>2]|0;if((i|0)==0){s=0;t=o;u=r;break}j=gj[i&4095](p)|0;s=j;t=c[2440596]|0;u=c[2443776]|0}else{s=a[n+(q&255)|0]|0;t=o;u=r}}while(0);a[9660973]=s;s=t-1|0;c[2440596]=s;t=c[2415243]|0;r=t&65535;o=c[u+68+((t>>>8&255)<<2)>>2]|0;do{if((o|0)==0){q=c[u+3156>>2]|0;if((q|0)==0){v=0;w=s;x=t;y=u;break}n=gj[q&4095](r)|0;v=n;w=c[2440596]|0;x=c[2415243]|0;y=c[2443776]|0}else{v=a[o+(t&255)|0]|0;w=s;x=t;y=u}}while(0);u=w-1|0;c[2440596]=u;w=x&65535;t=c[y+68+((x>>>8&255|256)<<2)>>2]|0;do{if((t|0)==0){s=c[y+3152>>2]|0;if((s|0)==0){z=u;break}gg[s&4095](w,v);z=c[2440596]|0}else{a[t+(x&255)|0]=v;z=u}}while(0);u=z-1|0;c[2440596]=u;z=v+1&255;v=a[9660979]|0;x=a[9660976]|0;t=x&255;w=t-(z&255)-(v&1^1)|0;y=v&-66;v=(((x^z)&128&(w^t)|0)==0?y:y|64)|(w&65280|0)==0;a[9660979]=v;a[9660976]=w&255;if((w&255|0)==0){A=v&125|2}else{A=(v&125|w&128)&255}a[9660979]=A;A=c[2415243]|0;w=c[2443776]|0;v=c[w+68+((A>>>8&255|256)<<2)>>2]|0;if((v|0)!=0){a[v+(A&255)|0]=z;B=u;C=B-1|0;c[2440596]=C;return}v=c[w+3152>>2]|0;if((v|0)==0){B=u;C=B-1|0;c[2440596]=C;return}gg[v&4095](A&65535,z);B=c[2440596]|0;C=B-1|0;c[2440596]=C;return}function fW2(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;d=f&255;do{if((g|0)==0){k=c[j+3148>>2]|0;if((k|0)==0){l=0;m=i;n=d;o=j;break}h=gj[k&4095](e)|0;l=h;m=c[2440596]|0;n=a[9660968]|0;o=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=d;o=j}}while(0);a[9660972]=l;j=m-1|0;c[2440596]=j;a[9660968]=n+1&255;n=c[2415242]|0;m=n&65535;d=c[o+68+((n>>>8&255)<<2)>>2]|0;do{if((d|0)==0){i=c[o+3148>>2]|0;if((i|0)==0){p=0;q=j;r=l;s=o;break}f=gj[i&4095](m)|0;p=f;q=c[2440596]|0;r=a[9660972]|0;s=c[2443776]|0}else{p=a[d+(n&255)|0]|0;q=j;r=l;s=o}}while(0);a[9660973]=p;o=q-1|0;c[2440596]=o;q=(p&255)<<8;p=a[9660978]|0;l=(p&255)+(r&255)&255|q;do{if((c[s+68+((q&65535)>>>8<<2)>>2]|0)==0){r=c[s+3148>>2]|0;if((r|0)==0){t=o;u=p;v=s;break}gj[r&4095](l)|0;t=c[2440596]|0;u=a[9660978]|0;v=c[2443776]|0}else{t=o;u=p;v=s}}while(0);s=t-1|0;c[2440596]=s;b[4830486]=(b[4830486]|0)+(u&255)&65535;u=c[2415243]|0;t=u&65535;p=c[v+68+((u>>>8&255)<<2)>>2]|0;do{if((p|0)==0){o=c[v+3156>>2]|0;if((o|0)==0){w=0;x=s;y=u;z=v;break}l=gj[o&4095](t)|0;w=l;x=c[2440596]|0;y=c[2415243]|0;z=c[2443776]|0}else{w=a[p+(u&255)|0]|0;x=s;y=u;z=v}}while(0);v=x-1|0;c[2440596]=v;x=y&65535;u=c[z+68+((y>>>8&255|256)<<2)>>2]|0;do{if((u|0)==0){s=c[z+3152>>2]|0;if((s|0)==0){A=v;break}gg[s&4095](x,w);A=c[2440596]|0}else{a[u+(y&255)|0]=w;A=v}}while(0);v=A-1|0;c[2440596]=v;A=w+1&255;w=a[9660979]|0;y=a[9660976]|0;u=y&255;x=u-(A&255)-(w&1^1)|0;z=w&-66;w=(((y^A)&128&(x^u)|0)==0?z:z|64)|(x&65280|0)==0;a[9660979]=w;a[9660976]=x&255;if((x&255|0)==0){B=w&125|2}else{B=(w&125|x&128)&255}a[9660979]=B;B=c[2415243]|0;x=c[2443776]|0;w=c[x+68+((B>>>8&255|256)<<2)>>2]|0;if((w|0)!=0){a[w+(B&255)|0]=A;C=v;D=C-1|0;c[2440596]=D;return}w=c[x+3152>>2]|0;if((w|0)==0){C=v;D=C-1|0;c[2440596]=D;return}gg[w&4095](B&65535,A);C=c[2440596]|0;D=C-1|0;c[2440596]=D;return}function fW3(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=0;m=i;break}k=gj[d&4095](e)|0;l=k;m=c[2440596]|0}else{l=a[g+(f&255)|0]|0;m=i}}while(0);c[2440596]=m-1;m=a[9660979]|0;i=a[9660976]|0;f=i&255;g=f+(l&255)+(m&1)|0;e=m&-66;m=((((i^l)&128^128)&(g^f)|0)==0?e:e|64)|(g&65280|0)!=0;a[9660979]=m;a[9660976]=g&255;if((g&255|0)==0){n=m&125|2;a[9660979]=n;return}else{n=(m&125|g&128)&255;a[9660979]=n;return}}function fW4(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=0;m=i;break}k=gj[d&4095](e)|0;l=k;m=c[2440596]|0}else{l=a[g+(f&255)|0]|0;m=i}}while(0);c[2440596]=m-1;m=a[9660979]|0;i=a[9660976]|0;f=i&255;g=f-(l&255)-(m&1^1)|0;e=m&-66;m=(((i^l)&128&(g^f)|0)==0?e:e|64)|(g&65280|0)==0;a[9660979]=m;a[9660976]=g&255;if((g&255|0)==0){n=m&125|2;a[9660979]=n;return}else{n=(m&125|g&128)&255;a[9660979]=n;return}}function fW5(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=f&255;do{if((c[j+68+((f>>>8&255)<<2)>>2]|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=i;m=g;n=j;break}gj[d&4095](e)|0;l=c[2440596]|0;m=a[9660968]|0;n=c[2443776]|0}else{l=i;m=g;n=j}}while(0);j=l-1|0;c[2440596]=j;a[9660968]=m+(a[9660977]|0)&255;m=c[2415242]|0;c[2415243]=m;l=m&65535;g=c[n+68+((m>>>8&255)<<2)>>2]|0;do{if((g|0)==0){i=c[n+3148>>2]|0;if((i|0)==0){o=0;p=j;break}e=gj[i&4095](l)|0;o=e;p=c[2440596]|0}else{o=a[g+(m&255)|0]|0;p=j}}while(0);c[2440596]=p-1;p=a[9660979]|0;j=a[9660976]|0;m=j&255;g=m+(o&255)+(p&1)|0;l=p&-66;p=((((j^o)&128^128)&(g^m)|0)==0?l:l|64)|(g&65280|0)!=0;a[9660979]=p;a[9660976]=g&255;if((g&255|0)==0){q=p&125|2;a[9660979]=q;return}else{q=(p&125|g&128)&255;a[9660979]=q;return}}function fW6(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=f&255;do{if((c[j+68+((f>>>8&255)<<2)>>2]|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=i;m=g;n=j;break}gj[d&4095](e)|0;l=c[2440596]|0;m=a[9660968]|0;n=c[2443776]|0}else{l=i;m=g;n=j}}while(0);j=l-1|0;c[2440596]=j;a[9660968]=m+(a[9660977]|0)&255;m=c[2415242]|0;c[2415243]=m;l=m&65535;g=c[n+68+((m>>>8&255)<<2)>>2]|0;do{if((g|0)==0){i=c[n+3148>>2]|0;if((i|0)==0){o=0;p=j;break}e=gj[i&4095](l)|0;o=e;p=c[2440596]|0}else{o=a[g+(m&255)|0]|0;p=j}}while(0);c[2440596]=p-1;p=a[9660979]|0;j=a[9660976]|0;m=j&255;g=m-(o&255)-(p&1^1)|0;l=p&-66;p=(((j^o)&128&(g^m)|0)==0?l:l|64)|(g&65280|0)==0;a[9660979]=p;a[9660976]=g&255;if((g&255|0)==0){q=p&125|2;a[9660979]=q;return}else{q=(p&125|g&128)&255;a[9660979]=q;return}}function fW7(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=b[4830480]|0;b[4830480]=e+1&65535;f=e&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](e)|0;j=l;k=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=g}}while(0);a[9660968]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;g=c[2415242]|0;c[2415243]=g;f=g&65535;h=c[k+68+((g>>>8&255)<<2)>>2]|0;do{if((h|0)==0){e=c[k+3148>>2]|0;if((e|0)==0){m=0;n=j;o=g;p=k;break}l=gj[e&4095](f)|0;m=l;n=c[2440596]|0;o=c[2415243]|0;p=c[2443776]|0}else{m=a[h+(g&255)|0]|0;n=j;o=g;p=k}}while(0);k=m&255;g=n-1|0;c[2440596]=g;n=o&65535;j=c[p+68+((o>>>8&255|256)<<2)>>2]|0;do{if((j|0)==0){h=c[p+3152>>2]|0;if((h|0)==0){q=g;break}gg[h&4095](n,m);q=c[2440596]|0}else{a[j+(o&255)|0]=m;q=g}}while(0);g=q-1|0;c[2440596]=g;q=a[9660979]|0;m=((q&255)<<8|k)>>>1;o=d[9660976]|0;j=o+(k&1)|0;k=(m&255)+j|0;n=q&-66;q=(((o^128^m)&128&(k^o)|0)==0?n:n|64)|(k&65280|0)!=0;a[9660979]=q;a[9660976]=k&255;if((m+j&255|0)==0){r=q&125|2}else{r=(q&125|k&128)&255}a[9660979]=r;r=c[2415243]|0;k=m&255;m=c[2443776]|0;q=c[m+68+((r>>>8&255|256)<<2)>>2]|0;if((q|0)!=0){a[q+(r&255)|0]=k;s=g;t=s-1|0;c[2440596]=t;return}q=c[m+3152>>2]|0;if((q|0)==0){s=g;t=s-1|0;c[2440596]=t;return}gg[q&4095](r&65535,k);s=c[2440596]|0;t=s-1|0;c[2440596]=t;return}function fW8(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;e=b[4830480]|0;b[4830480]=e+1&65535;f=e&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](e)|0;j=l;k=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=g}}while(0);a[9660968]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;g=c[2415242]|0;f=g&65535;h=g&255;do{if((c[k+68+((g>>>8&255)<<2)>>2]|0)==0){e=c[k+3148>>2]|0;if((e|0)==0){m=j;n=h;o=k;break}gj[e&4095](f)|0;m=c[2440596]|0;n=a[9660968]|0;o=c[2443776]|0}else{m=j;n=h;o=k}}while(0);k=m-1|0;c[2440596]=k;a[9660968]=n+(a[9660977]|0)&255;n=c[2415242]|0;c[2415243]=n;m=n&65535;h=c[o+68+((n>>>8&255)<<2)>>2]|0;do{if((h|0)==0){j=c[o+3148>>2]|0;if((j|0)==0){p=0;q=k;r=n;s=o;break}f=gj[j&4095](m)|0;p=f;q=c[2440596]|0;r=c[2415243]|0;s=c[2443776]|0}else{p=a[h+(n&255)|0]|0;q=k;r=n;s=o}}while(0);o=p&255;n=q-1|0;c[2440596]=n;q=r&65535;k=c[s+68+((r>>>8&255|256)<<2)>>2]|0;do{if((k|0)==0){h=c[s+3152>>2]|0;if((h|0)==0){t=n;break}gg[h&4095](q,p);t=c[2440596]|0}else{a[k+(r&255)|0]=p;t=n}}while(0);n=t-1|0;c[2440596]=n;t=a[9660979]|0;p=((t&255)<<8|o)>>>1;r=d[9660976]|0;k=r+(o&1)|0;o=(p&255)+k|0;q=t&-66;t=(((r^128^p)&128&(o^r)|0)==0?q:q|64)|(o&65280|0)!=0;a[9660979]=t;a[9660976]=o&255;if((p+k&255|0)==0){u=t&125|2}else{u=(t&125|o&128)&255}a[9660979]=u;u=c[2415243]|0;o=p&255;p=c[2443776]|0;t=c[p+68+((u>>>8&255|256)<<2)>>2]|0;if((t|0)!=0){a[t+(u&255)|0]=o;v=n;w=v-1|0;c[2440596]=w;return}t=c[p+3152>>2]|0;if((t|0)==0){v=n;w=v-1|0;c[2440596]=w;return}gg[t&4095](u&65535,o);v=c[2440596]|0;w=v-1|0;c[2440596]=w;return}function fW9(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=0;m=i;n=f;o=j;break}k=gj[d&4095](e)|0;l=k;m=c[2440596]|0;n=c[2415243]|0;o=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=f;o=j}}while(0);j=m-1|0;c[2440596]=j;m=n&65535;f=c[o+68+((n>>>8&255|256)<<2)>>2]|0;do{if((f|0)==0){i=c[o+3152>>2]|0;if((i|0)==0){p=j;break}gg[i&4095](m,l);p=c[2440596]|0}else{a[f+(n&255)|0]=l;p=j}}while(0);j=p-1|0;c[2440596]=j;p=l+1&255;l=a[9660979]|0;n=a[9660976]|0;f=n&255;m=f-(p&255)-(l&1^1)|0;o=l&-66;l=(((n^p)&128&(m^f)|0)==0?o:o|64)|(m&65280|0)==0;a[9660979]=l;a[9660976]=m&255;if((m&255|0)==0){q=l&125|2}else{q=(l&125|m&128)&255}a[9660979]=q;q=c[2415243]|0;m=c[2443776]|0;l=c[m+68+((q>>>8&255|256)<<2)>>2]|0;if((l|0)!=0){a[l+(q&255)|0]=p;r=j;s=r-1|0;c[2440596]=s;return}l=c[m+3152>>2]|0;if((l|0)==0){r=j;s=r-1|0;c[2440596]=s;return}gg[l&4095](q&65535,p);r=c[2440596]|0;s=r-1|0;c[2440596]=s;return}function fXa(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=f&255;do{if((c[j+68+((f>>>8&255)<<2)>>2]|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=i;m=g;n=j;break}gj[d&4095](e)|0;l=c[2440596]|0;m=a[9660968]|0;n=c[2443776]|0}else{l=i;m=g;n=j}}while(0);j=l-1|0;c[2440596]=j;a[9660968]=m+(a[9660977]|0)&255;m=c[2415242]|0;c[2415243]=m;l=m&65535;g=c[n+68+((m>>>8&255)<<2)>>2]|0;do{if((g|0)==0){i=c[n+3148>>2]|0;if((i|0)==0){o=0;p=j;q=m;r=n;break}e=gj[i&4095](l)|0;o=e;p=c[2440596]|0;q=c[2415243]|0;r=c[2443776]|0}else{o=a[g+(m&255)|0]|0;p=j;q=m;r=n}}while(0);n=p-1|0;c[2440596]=n;p=q&65535;m=c[r+68+((q>>>8&255|256)<<2)>>2]|0;do{if((m|0)==0){j=c[r+3152>>2]|0;if((j|0)==0){s=n;break}gg[j&4095](p,o);s=c[2440596]|0}else{a[m+(q&255)|0]=o;s=n}}while(0);n=s-1|0;c[2440596]=n;s=o+1&255;o=a[9660979]|0;q=a[9660976]|0;m=q&255;p=m-(s&255)-(o&1^1)|0;r=o&-66;o=(((q^s)&128&(p^m)|0)==0?r:r|64)|(p&65280|0)==0;a[9660979]=o;a[9660976]=p&255;if((p&255|0)==0){t=o&125|2}else{t=(o&125|p&128)&255}a[9660979]=t;t=c[2415243]|0;p=c[2443776]|0;o=c[p+68+((t>>>8&255|256)<<2)>>2]|0;if((o|0)!=0){a[o+(t&255)|0]=s;u=n;v=u-1|0;c[2440596]=v;return}o=c[p+3152>>2]|0;if((o|0)==0){u=n;v=u-1|0;c[2440596]=v;return}gg[o&4095](t&65535,s);u=c[2440596]|0;v=u-1|0;c[2440596]=v;return}function fXb(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(e&255)|0]|0}}while(0);c[2440596]=(c[2440596]|0)-1;e=a[9660979]|0;g=a[9660976]|0;d=g&255;f=d+(i&255)+(e&1)|0;h=e&-66;e=((((g^i)&128^128)&(f^d)|0)==0?h:h|64)|(f&65280|0)!=0;a[9660979]=e;a[9660976]=f&255;if((f&255|0)==0){j=e&125|2;a[9660979]=j;return}else{j=(e&125|f&128)&255;a[9660979]=j;return}}function fXc(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(e&255)|0]|0}}while(0);c[2440596]=(c[2440596]|0)-1;e=a[9660979]|0;g=a[9660976]|0;d=g&255;f=d-(i&255)-(e&1^1)|0;h=e&-66;e=(((g^i)&128&(f^d)|0)==0?h:h|64)|(f&65280|0)==0;a[9660979]=e;a[9660976]=f&255;if((f&255|0)==0){j=e&125|2;a[9660979]=j;return}else{j=(e&125|f&128)&255;a[9660979]=j;return}}function fXd(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;g=(c[2440596]|0)-1|0;c[2440596]=g;b[4830480]=k+1&65535;e=k&65535;f=c[l+68+(e>>>8<<2)>>2]|0;do{if((f|0)==0){h=c[l+3168>>2]|0;if((h|0)==0){n=0;o=g;p=j;break}d=gj[h&4095](k)|0;n=d;o=c[2440596]|0;p=a[9660972]|0}else{n=a[f+(e&255)|0]|0;o=g;p=j}}while(0);a[9660973]=n;j=o-1|0;c[2440596]=j;o=a[9660978]|0;g=(o&255)+(p&255)|0;if((g|0)>255){p=n&255;n=(g&255|p<<8)&65535;g=c[2443776]|0;do{if((c[g+68+(p<<2)>>2]|0)==0){e=c[g+3148>>2]|0;if((e|0)==0){q=j;r=o;break}gj[e&4095](n)|0;q=c[2440596]|0;r=a[9660978]|0}else{q=j;r=o}}while(0);n=q-1|0;c[2440596]=n;s=r;t=n}else{s=o;t=j}b[4830486]=(b[4830486]|0)+(s&255)&65535;s=c[2415243]|0;j=s&65535;o=c[2443776]|0;n=c[o+68+((s>>>8&255)<<2)>>2]|0;do{if((n|0)==0){r=c[o+3148>>2]|0;if((r|0)==0){u=0;v=t;break}q=gj[r&4095](j)|0;u=q;v=c[2440596]|0}else{u=a[n+(s&255)|0]|0;v=t}}while(0);c[2440596]=v-1;v=a[9660979]|0;t=a[9660976]|0;s=t&255;n=s+(u&255)+(v&1)|0;j=v&-66;v=((((t^u)&128^128)&(n^s)|0)==0?j:j|64)|(n&65280|0)!=0;a[9660979]=v;a[9660976]=n&255;if((n&255|0)==0){w=v&125|2;a[9660979]=w;return}else{w=(v&125|n&128)&255;a[9660979]=w;return}}function fXe(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;g=(c[2440596]|0)-1|0;c[2440596]=g;b[4830480]=k+1&65535;e=k&65535;f=c[l+68+(e>>>8<<2)>>2]|0;do{if((f|0)==0){h=c[l+3168>>2]|0;if((h|0)==0){n=0;o=g;p=j;break}d=gj[h&4095](k)|0;n=d;o=c[2440596]|0;p=a[9660972]|0}else{n=a[f+(e&255)|0]|0;o=g;p=j}}while(0);a[9660973]=n;j=o-1|0;c[2440596]=j;o=a[9660978]|0;g=(o&255)+(p&255)|0;if((g|0)>255){p=n&255;n=(g&255|p<<8)&65535;g=c[2443776]|0;do{if((c[g+68+(p<<2)>>2]|0)==0){e=c[g+3148>>2]|0;if((e|0)==0){q=j;r=o;break}gj[e&4095](n)|0;q=c[2440596]|0;r=a[9660978]|0}else{q=j;r=o}}while(0);n=q-1|0;c[2440596]=n;s=r;t=n}else{s=o;t=j}b[4830486]=(b[4830486]|0)+(s&255)&65535;s=c[2415243]|0;j=s&65535;o=c[2443776]|0;n=c[o+68+((s>>>8&255)<<2)>>2]|0;do{if((n|0)==0){r=c[o+3148>>2]|0;if((r|0)==0){u=0;v=t;break}q=gj[r&4095](j)|0;u=q;v=c[2440596]|0}else{u=a[n+(s&255)|0]|0;v=t}}while(0);c[2440596]=v-1;v=a[9660979]|0;t=a[9660976]|0;s=t&255;n=s-(u&255)-(v&1^1)|0;j=v&-66;v=(((t^u)&128&(n^s)|0)==0?j:j|64)|(n&65280|0)==0;a[9660979]=v;a[9660976]=n&255;if((n&255|0)==0){w=v&125|2;a[9660979]=w;return}else{w=(v&125|n&128)&255;a[9660979]=w;return}}function fXf(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(e&255)|0]|0}}while(0);c[2440596]=(c[2440596]|0)-1;e=a[9660976]&i;i=a[9660979]|0;g=i&-2|e&1;a[9660979]=g;d=((i&255)<<8|e&255)>>>1;if((d&255|0)==0){j=g&125|2}else{j=(d&128|g&125)&255}g=j&-66|(e&255)>>>7;a[9660979]=g;e=d&96;if(!((e|0)==32|(e|0)==64)){k=d&255;a[9660976]=k;return}a[9660979]=g|64;k=d&255;a[9660976]=k;return}function fXg(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;e=b[4830480]|0;f=e+1&65535;b[4830480]=f;g=e&65535;h=c[2443776]|0;i=c[h+68+(g>>>8<<2)>>2]|0;do{if((i|0)==0){j=c[h+3168>>2]|0;if((j|0)==0){k=0;l=f;m=h;break}n=gj[j&4095](e)|0;k=n;l=b[4830480]|0;m=c[2443776]|0}else{k=a[i+(g&255)|0]|0;l=f;m=h}}while(0);a[9660972]=k;h=(c[2440596]|0)-1|0;c[2440596]=h;b[4830480]=l+1&65535;f=l&65535;g=c[m+68+(f>>>8<<2)>>2]|0;do{if((g|0)==0){i=c[m+3168>>2]|0;if((i|0)==0){o=0;p=h;q=k;r=m;break}e=gj[i&4095](l)|0;o=e;p=c[2440596]|0;q=a[9660972]|0;r=c[2443776]|0}else{o=a[g+(f&255)|0]|0;p=h;q=k;r=m}}while(0);a[9660973]=o;m=p-1|0;c[2440596]=m;p=(o&255)<<8;o=a[9660978]|0;k=(o&255)+(q&255)&255|p;do{if((c[r+68+((p&65535)>>>8<<2)>>2]|0)==0){q=c[r+3148>>2]|0;if((q|0)==0){s=m;t=o;u=r;break}gj[q&4095](k)|0;s=c[2440596]|0;t=a[9660978]|0;u=c[2443776]|0}else{s=m;t=o;u=r}}while(0);r=s-1|0;c[2440596]=r;b[4830486]=(b[4830486]|0)+(t&255)&65535;t=c[2415243]|0;s=t&65535;o=c[u+68+((t>>>8&255)<<2)>>2]|0;do{if((o|0)==0){m=c[u+3148>>2]|0;if((m|0)==0){v=0;w=r;x=t;y=u;break}k=gj[m&4095](s)|0;v=k;w=c[2440596]|0;x=c[2415243]|0;y=c[2443776]|0}else{v=a[o+(t&255)|0]|0;w=r;x=t;y=u}}while(0);u=v&255;t=w-1|0;c[2440596]=t;w=x&65535;r=c[y+68+((x>>>8&255|256)<<2)>>2]|0;do{if((r|0)==0){o=c[y+3152>>2]|0;if((o|0)==0){z=t;break}gg[o&4095](w,v);z=c[2440596]|0}else{a[r+(x&255)|0]=v;z=t}}while(0);t=z-1|0;c[2440596]=t;z=a[9660979]|0;v=((z&255)<<8|u)>>>1;x=d[9660976]|0;r=x+(u&1)|0;u=(v&255)+r|0;w=z&-66;z=(((x^128^v)&128&(u^x)|0)==0?w:w|64)|(u&65280|0)!=0;a[9660979]=z;a[9660976]=u&255;if((v+r&255|0)==0){A=z&125|2}else{A=(z&125|u&128)&255}a[9660979]=A;A=c[2415243]|0;u=v&255;v=c[2443776]|0;z=c[v+68+((A>>>8&255|256)<<2)>>2]|0;if((z|0)!=0){a[z+(A&255)|0]=u;B=t;C=B-1|0;c[2440596]=C;return}z=c[v+3152>>2]|0;if((z|0)==0){B=t;C=B-1|0;c[2440596]=C;return}gg[z&4095](A&65535,u);B=c[2440596]|0;C=B-1|0;c[2440596]=C;return}function fXh(){var d=0,e=0,f=0,g=0,h=0,i=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(e&255)|0]|0}}while(0);c[2440596]=(c[2440596]|0)-1;a[9660977]=i;a[9660976]=i;a[9660979]=a[9660979]&125|(i<<24>>24==0?2:i&-128);return}function fXi(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(e&255)|0]|0}}while(0);c[2440596]=(c[2440596]|0)-1;e=a[9660979]|0;g=a[9660976]|0;d=g&255;f=d-(i&255)-(e&1^1)|0;h=e&-66;e=(((g^i)&128&(f^d)|0)==0?h:h|64)|(f&65280|0)==0;a[9660979]=e;a[9660976]=f&255;if((f&255|0)==0){j=e&125|2;a[9660979]=j;return}else{j=(e&125|f&128)&255;a[9660979]=j;return}}function fXj(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;g=(c[2440596]|0)-1|0;c[2440596]=g;b[4830480]=k+1&65535;e=k&65535;f=c[l+68+(e>>>8<<2)>>2]|0;do{if((f|0)==0){h=c[l+3168>>2]|0;if((h|0)==0){n=0;o=g;p=j;q=l;break}d=gj[h&4095](k)|0;n=d;o=c[2440596]|0;p=a[9660972]|0;q=c[2443776]|0}else{n=a[f+(e&255)|0]|0;o=g;p=j;q=l}}while(0);a[9660973]=n;l=o-1|0;c[2440596]=l;o=(n&255)<<8;n=a[9660978]|0;j=(n&255)+(p&255)&255|o;do{if((c[q+68+((o&65535)>>>8<<2)>>2]|0)==0){p=c[q+3148>>2]|0;if((p|0)==0){r=l;s=n;t=q;break}gj[p&4095](j)|0;r=c[2440596]|0;s=a[9660978]|0;t=c[2443776]|0}else{r=l;s=n;t=q}}while(0);q=r-1|0;c[2440596]=q;b[4830486]=(b[4830486]|0)+(s&255)&65535;s=c[2415243]|0;r=s&65535;n=c[t+68+((s>>>8&255)<<2)>>2]|0;do{if((n|0)==0){l=c[t+3148>>2]|0;if((l|0)==0){u=0;v=q;w=s;x=t;break}j=gj[l&4095](r)|0;u=j;v=c[2440596]|0;w=c[2415243]|0;x=c[2443776]|0}else{u=a[n+(s&255)|0]|0;v=q;w=s;x=t}}while(0);t=v-1|0;c[2440596]=t;v=w&65535;s=c[x+68+((w>>>8&255|256)<<2)>>2]|0;do{if((s|0)==0){q=c[x+3152>>2]|0;if((q|0)==0){y=t;break}gg[q&4095](v,u);y=c[2440596]|0}else{a[s+(w&255)|0]=u;y=t}}while(0);t=y-1|0;c[2440596]=t;y=u+1&255;u=a[9660979]|0;w=a[9660976]|0;s=w&255;v=s-(y&255)-(u&1^1)|0;x=u&-66;u=(((w^y)&128&(v^s)|0)==0?x:x|64)|(v&65280|0)==0;a[9660979]=u;a[9660976]=v&255;if((v&255|0)==0){z=u&125|2}else{z=(u&125|v&128)&255}a[9660979]=z;z=c[2415243]|0;v=c[2443776]|0;u=c[v+68+((z>>>8&255|256)<<2)>>2]|0;if((u|0)!=0){a[u+(z&255)|0]=y;A=t;B=A-1|0;c[2440596]=B;return}u=c[v+3152>>2]|0;if((u|0)==0){A=t;B=A-1|0;c[2440596]=B;return}gg[u&4095](z&65535,y);A=c[2440596]|0;B=A-1|0;c[2440596]=B;return}function fXk(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;g=(c[2440596]|0)-1|0;c[2440596]=g;b[4830480]=k+1&65535;e=k&65535;f=c[l+68+(e>>>8<<2)>>2]|0;do{if((f|0)==0){h=c[l+3168>>2]|0;if((h|0)==0){n=0;o=g;p=j;q=l;break}d=gj[h&4095](k)|0;n=d;o=c[2440596]|0;p=a[9660972]|0;q=c[2443776]|0}else{n=a[f+(e&255)|0]|0;o=g;p=j;q=l}}while(0);a[9660973]=n;l=o-1|0;c[2440596]=l;o=(n&255)<<8;n=a[9660977]|0;j=(n&255)+(p&255)&255|o;do{if((c[q+68+((o&65535)>>>8<<2)>>2]|0)==0){p=c[q+3148>>2]|0;if((p|0)==0){r=l;s=n;break}gj[p&4095](j)|0;r=c[2440596]|0;s=a[9660977]|0}else{r=l;s=n}}while(0);n=r-1|0;c[2440596]=n;r=(b[4830486]|0)+(s&255)&65535;b[4830486]=r;l=(r&65535)>>>8&255;do{if(s<<24>>24==0){t=l}else{if((s&255)<=(r&255)){t=l;break}j=l|s<<1;a[9660973]=j;t=j}}while(0);s=t+1&255&a[9660978];t=c[2415243]|0;l=c[2443776]|0;r=c[l+68+((t>>>8&255|256)<<2)>>2]|0;if((r|0)!=0){a[r+(t&255)|0]=s;u=n;v=u-1|0;c[2440596]=v;return}r=c[l+3152>>2]|0;if((r|0)==0){u=n;v=u-1|0;c[2440596]=v;return}gg[r&4095](t&65535,s);u=c[2440596]|0;v=u-1|0;c[2440596]=v;return}function fXl(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;b[4830480]=k+1&65535;g=k&65535;e=c[l+68+(g>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[l+3168>>2]|0;if((f|0)==0){n=0;o=j;p=l;break}h=gj[f&4095](k)|0;n=h;o=c[2440596]|0;p=c[2443776]|0}else{n=a[e+(g&255)|0]|0;o=j;p=l}}while(0);a[9660973]=n;n=o-1|0;c[2440596]=n;o=c[2415243]|0;l=o&65535;j=c[p+68+((o>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[p+3148>>2]|0;if((g|0)==0){q=0;r=n;break}e=gj[g&4095](l)|0;q=e;r=c[2440596]|0}else{q=a[j+(o&255)|0]|0;r=n}}while(0);c[2440596]=r-1;r=a[9660979]|0;n=a[9660976]|0;o=n&255;j=o+(q&255)+(r&1)|0;l=r&-66;r=((((n^q)&128^128)&(j^o)|0)==0?l:l|64)|(j&65280|0)!=0;a[9660979]=r;a[9660976]=j&255;if((j&255|0)==0){s=r&125|2;a[9660979]=s;return}else{s=(r&125|j&128)&255;a[9660979]=s;return}}function fXm(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;b[4830480]=k+1&65535;g=k&65535;e=c[l+68+(g>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[l+3168>>2]|0;if((f|0)==0){n=0;o=j;p=l;break}h=gj[f&4095](k)|0;n=h;o=c[2440596]|0;p=c[2443776]|0}else{n=a[e+(g&255)|0]|0;o=j;p=l}}while(0);a[9660973]=n;n=o-1|0;c[2440596]=n;o=c[2415243]|0;l=o&65535;j=c[p+68+((o>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[p+3148>>2]|0;if((g|0)==0){q=0;r=n;break}e=gj[g&4095](l)|0;q=e;r=c[2440596]|0}else{q=a[j+(o&255)|0]|0;r=n}}while(0);c[2440596]=r-1;r=a[9660979]|0;n=a[9660976]|0;o=n&255;j=o-(q&255)-(r&1^1)|0;l=r&-66;r=(((n^q)&128&(j^o)|0)==0?l:l|64)|(j&65280|0)==0;a[9660979]=r;a[9660976]=j&255;if((j&255|0)==0){s=r&125|2;a[9660979]=s;return}else{s=(r&125|j&128)&255;a[9660979]=s;return}}function fXn(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;g=(c[2440596]|0)-1|0;c[2440596]=g;b[4830480]=k+1&65535;e=k&65535;f=c[l+68+(e>>>8<<2)>>2]|0;do{if((f|0)==0){h=c[l+3168>>2]|0;if((h|0)==0){n=0;o=g;p=j;break}d=gj[h&4095](k)|0;n=d;o=c[2440596]|0;p=a[9660972]|0}else{n=a[f+(e&255)|0]|0;o=g;p=j}}while(0);a[9660973]=n;j=o-1|0;c[2440596]=j;o=a[9660977]|0;g=(o&255)+(p&255)|0;if((g|0)>255){p=n&255;n=(g&255|p<<8)&65535;g=c[2443776]|0;do{if((c[g+68+(p<<2)>>2]|0)==0){e=c[g+3148>>2]|0;if((e|0)==0){q=j;r=o;break}gj[e&4095](n)|0;q=c[2440596]|0;r=a[9660977]|0}else{q=j;r=o}}while(0);n=q-1|0;c[2440596]=n;s=r;t=n}else{s=o;t=j}b[4830486]=(b[4830486]|0)+(s&255)&65535;s=c[2415243]|0;j=s&65535;o=c[2443776]|0;n=c[o+68+((s>>>8&255)<<2)>>2]|0;do{if((n|0)==0){r=c[o+3148>>2]|0;if((r|0)==0){u=0;v=t;break}q=gj[r&4095](j)|0;u=q;v=c[2440596]|0}else{u=a[n+(s&255)|0]|0;v=t}}while(0);c[2440596]=v-1;v=a[9660979]|0;t=a[9660976]|0;s=t&255;n=s+(u&255)+(v&1)|0;j=v&-66;v=((((t^u)&128^128)&(n^s)|0)==0?j:j|64)|(n&65280|0)!=0;a[9660979]=v;a[9660976]=n&255;if((n&255|0)==0){w=v&125|2;a[9660979]=w;return}else{w=(v&125|n&128)&255;a[9660979]=w;return}}function fXo(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;g=(c[2440596]|0)-1|0;c[2440596]=g;b[4830480]=k+1&65535;e=k&65535;f=c[l+68+(e>>>8<<2)>>2]|0;do{if((f|0)==0){h=c[l+3168>>2]|0;if((h|0)==0){n=0;o=g;p=j;break}d=gj[h&4095](k)|0;n=d;o=c[2440596]|0;p=a[9660972]|0}else{n=a[f+(e&255)|0]|0;o=g;p=j}}while(0);a[9660973]=n;j=o-1|0;c[2440596]=j;o=a[9660977]|0;g=(o&255)+(p&255)|0;if((g|0)>255){p=n&255;n=(g&255|p<<8)&65535;g=c[2443776]|0;do{if((c[g+68+(p<<2)>>2]|0)==0){e=c[g+3148>>2]|0;if((e|0)==0){q=j;r=o;break}gj[e&4095](n)|0;q=c[2440596]|0;r=a[9660977]|0}else{q=j;r=o}}while(0);n=q-1|0;c[2440596]=n;s=r;t=n}else{s=o;t=j}b[4830486]=(b[4830486]|0)+(s&255)&65535;s=c[2415243]|0;j=s&65535;o=c[2443776]|0;n=c[o+68+((s>>>8&255)<<2)>>2]|0;do{if((n|0)==0){r=c[o+3148>>2]|0;if((r|0)==0){u=0;v=t;break}q=gj[r&4095](j)|0;u=q;v=c[2440596]|0}else{u=a[n+(s&255)|0]|0;v=t}}while(0);c[2440596]=v-1;v=a[9660979]|0;t=a[9660976]|0;s=t&255;n=s-(u&255)-(v&1^1)|0;j=v&-66;v=(((t^u)&128&(n^s)|0)==0?j:j|64)|(n&65280|0)==0;a[9660979]=v;a[9660976]=n&255;if((n&255|0)==0){w=v&125|2;a[9660979]=w;return}else{w=(v&125|n&128)&255;a[9660979]=w;return}}function fXp(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;g=(c[2440596]|0)-1|0;c[2440596]=g;b[4830480]=k+1&65535;e=k&65535;f=c[l+68+(e>>>8<<2)>>2]|0;do{if((f|0)==0){h=c[l+3168>>2]|0;if((h|0)==0){n=0;o=g;p=j;q=l;break}d=gj[h&4095](k)|0;n=d;o=c[2440596]|0;p=a[9660972]|0;q=c[2443776]|0}else{n=a[f+(e&255)|0]|0;o=g;p=j;q=l}}while(0);a[9660973]=n;l=o-1|0;c[2440596]=l;o=(n&255)<<8;n=a[9660978]|0;j=(n&255)+(p&255)&255|o;do{if((c[q+68+((o&65535)>>>8<<2)>>2]|0)==0){p=c[q+3148>>2]|0;if((p|0)==0){r=l;s=n;break}gj[p&4095](j)|0;r=c[2440596]|0;s=a[9660978]|0}else{r=l;s=n}}while(0);n=r-1|0;c[2440596]=n;r=(b[4830486]|0)+(s&255)&65535;b[4830486]=r;l=(r&65535)>>>8&255;do{if(s<<24>>24==0){t=l}else{if((s&255)<=(r&255)){t=l;break}j=l|s<<1;a[9660973]=j;t=j}}while(0);s=t+1&255&a[9660977];t=c[2415243]|0;l=c[2443776]|0;r=c[l+68+((t>>>8&255|256)<<2)>>2]|0;if((r|0)!=0){a[r+(t&255)|0]=s;u=n;v=u-1|0;c[2440596]=v;return}r=c[l+3152>>2]|0;if((r|0)==0){u=n;v=u-1|0;c[2440596]=v;return}gg[r&4095](t&65535,s);u=c[2440596]|0;v=u-1|0;c[2440596]=v;return}function fXq(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;e=b[4830480]|0;f=e+1&65535;b[4830480]=f;g=e&65535;h=c[2443776]|0;i=c[h+68+(g>>>8<<2)>>2]|0;do{if((i|0)==0){j=c[h+3168>>2]|0;if((j|0)==0){k=0;l=f;m=h;break}n=gj[j&4095](e)|0;k=n;l=b[4830480]|0;m=c[2443776]|0}else{k=a[i+(g&255)|0]|0;l=f;m=h}}while(0);a[9660972]=k;k=(c[2440596]|0)-1|0;c[2440596]=k;b[4830480]=l+1&65535;h=l&65535;f=c[m+68+(h>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[m+3168>>2]|0;if((g|0)==0){o=0;p=k;q=m;break}i=gj[g&4095](l)|0;o=i;p=c[2440596]|0;q=c[2443776]|0}else{o=a[f+(h&255)|0]|0;p=k;q=m}}while(0);a[9660973]=o;o=p-1|0;c[2440596]=o;p=c[2415243]|0;m=p&65535;k=c[q+68+((p>>>8&255)<<2)>>2]|0;do{if((k|0)==0){h=c[q+3148>>2]|0;if((h|0)==0){r=0;s=o;t=p;u=q;break}f=gj[h&4095](m)|0;r=f;s=c[2440596]|0;t=c[2415243]|0;u=c[2443776]|0}else{r=a[k+(p&255)|0]|0;s=o;t=p;u=q}}while(0);q=r&255;p=s-1|0;c[2440596]=p;s=t&65535;o=c[u+68+((t>>>8&255|256)<<2)>>2]|0;do{if((o|0)==0){k=c[u+3152>>2]|0;if((k|0)==0){v=p;break}gg[k&4095](s,r);v=c[2440596]|0}else{a[o+(t&255)|0]=r;v=p}}while(0);p=v-1|0;c[2440596]=p;v=a[9660979]|0;r=((v&255)<<8|q)>>>1;t=d[9660976]|0;o=t+(q&1)|0;q=(r&255)+o|0;s=v&-66;v=(((t^128^r)&128&(q^t)|0)==0?s:s|64)|(q&65280|0)!=0;a[9660979]=v;a[9660976]=q&255;if((r+o&255|0)==0){w=v&125|2}else{w=(v&125|q&128)&255}a[9660979]=w;w=c[2415243]|0;q=r&255;r=c[2443776]|0;v=c[r+68+((w>>>8&255|256)<<2)>>2]|0;if((v|0)!=0){a[v+(w&255)|0]=q;x=p;y=x-1|0;c[2440596]=y;return}v=c[r+3152>>2]|0;if((v|0)==0){x=p;y=x-1|0;c[2440596]=y;return}gg[v&4095](w&65535,q);x=c[2440596]|0;y=x-1|0;c[2440596]=y;return}function fXr(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;e=b[4830480]|0;f=e+1&65535;b[4830480]=f;g=e&65535;h=c[2443776]|0;i=c[h+68+(g>>>8<<2)>>2]|0;do{if((i|0)==0){j=c[h+3168>>2]|0;if((j|0)==0){k=0;l=f;m=h;break}n=gj[j&4095](e)|0;k=n;l=b[4830480]|0;m=c[2443776]|0}else{k=a[i+(g&255)|0]|0;l=f;m=h}}while(0);a[9660972]=k;h=(c[2440596]|0)-1|0;c[2440596]=h;b[4830480]=l+1&65535;f=l&65535;g=c[m+68+(f>>>8<<2)>>2]|0;do{if((g|0)==0){i=c[m+3168>>2]|0;if((i|0)==0){o=0;p=h;q=k;r=m;break}e=gj[i&4095](l)|0;o=e;p=c[2440596]|0;q=a[9660972]|0;r=c[2443776]|0}else{o=a[g+(f&255)|0]|0;p=h;q=k;r=m}}while(0);a[9660973]=o;m=p-1|0;c[2440596]=m;p=(o&255)<<8;o=a[9660977]|0;k=(o&255)+(q&255)&255|p;do{if((c[r+68+((p&65535)>>>8<<2)>>2]|0)==0){q=c[r+3148>>2]|0;if((q|0)==0){s=m;t=o;u=r;break}gj[q&4095](k)|0;s=c[2440596]|0;t=a[9660977]|0;u=c[2443776]|0}else{s=m;t=o;u=r}}while(0);r=s-1|0;c[2440596]=r;b[4830486]=(b[4830486]|0)+(t&255)&65535;t=c[2415243]|0;s=t&65535;o=c[u+68+((t>>>8&255)<<2)>>2]|0;do{if((o|0)==0){m=c[u+3148>>2]|0;if((m|0)==0){v=0;w=r;x=t;y=u;break}k=gj[m&4095](s)|0;v=k;w=c[2440596]|0;x=c[2415243]|0;y=c[2443776]|0}else{v=a[o+(t&255)|0]|0;w=r;x=t;y=u}}while(0);u=v&255;t=w-1|0;c[2440596]=t;w=x&65535;r=c[y+68+((x>>>8&255|256)<<2)>>2]|0;do{if((r|0)==0){o=c[y+3152>>2]|0;if((o|0)==0){z=t;break}gg[o&4095](w,v);z=c[2440596]|0}else{a[r+(x&255)|0]=v;z=t}}while(0);t=z-1|0;c[2440596]=t;z=a[9660979]|0;v=((z&255)<<8|u)>>>1;x=d[9660976]|0;r=x+(u&1)|0;u=(v&255)+r|0;w=z&-66;z=(((x^128^v)&128&(u^x)|0)==0?w:w|64)|(u&65280|0)!=0;a[9660979]=z;a[9660976]=u&255;if((v+r&255|0)==0){A=z&125|2}else{A=(z&125|u&128)&255}a[9660979]=A;A=c[2415243]|0;u=v&255;v=c[2443776]|0;z=c[v+68+((A>>>8&255|256)<<2)>>2]|0;if((z|0)!=0){a[z+(A&255)|0]=u;B=t;C=B-1|0;c[2440596]=C;return}z=c[v+3152>>2]|0;if((z|0)==0){B=t;C=B-1|0;c[2440596]=C;return}gg[z&4095](A&65535,u);B=c[2440596]|0;C=B-1|0;c[2440596]=C;return}function fXs(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;b[4830480]=k+1&65535;g=k&65535;e=c[l+68+(g>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[l+3168>>2]|0;if((f|0)==0){n=0;o=j;p=l;break}h=gj[f&4095](k)|0;n=h;o=c[2440596]|0;p=c[2443776]|0}else{n=a[e+(g&255)|0]|0;o=j;p=l}}while(0);a[9660973]=n;n=o-1|0;c[2440596]=n;o=c[2415243]|0;l=o&65535;j=c[p+68+((o>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[p+3148>>2]|0;if((g|0)==0){q=0;r=n;s=o;t=p;break}e=gj[g&4095](l)|0;q=e;r=c[2440596]|0;s=c[2415243]|0;t=c[2443776]|0}else{q=a[j+(o&255)|0]|0;r=n;s=o;t=p}}while(0);p=r-1|0;c[2440596]=p;r=s&65535;o=c[t+68+((s>>>8&255|256)<<2)>>2]|0;do{if((o|0)==0){n=c[t+3152>>2]|0;if((n|0)==0){u=p;break}gg[n&4095](r,q);u=c[2440596]|0}else{a[o+(s&255)|0]=q;u=p}}while(0);p=u-1|0;c[2440596]=p;u=q+1&255;q=a[9660979]|0;s=a[9660976]|0;o=s&255;r=o-(u&255)-(q&1^1)|0;t=q&-66;q=(((s^u)&128&(r^o)|0)==0?t:t|64)|(r&65280|0)==0;a[9660979]=q;a[9660976]=r&255;if((r&255|0)==0){v=q&125|2}else{v=(q&125|r&128)&255}a[9660979]=v;v=c[2415243]|0;r=c[2443776]|0;q=c[r+68+((v>>>8&255|256)<<2)>>2]|0;if((q|0)!=0){a[q+(v&255)|0]=u;w=p;x=w-1|0;c[2440596]=x;return}q=c[r+3152>>2]|0;if((q|0)==0){w=p;x=w-1|0;c[2440596]=x;return}gg[q&4095](v&65535,u);w=c[2440596]|0;x=w-1|0;c[2440596]=x;return}function fXt(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;g=(c[2440596]|0)-1|0;c[2440596]=g;b[4830480]=k+1&65535;e=k&65535;f=c[l+68+(e>>>8<<2)>>2]|0;do{if((f|0)==0){h=c[l+3168>>2]|0;if((h|0)==0){n=0;o=g;p=j;q=l;break}d=gj[h&4095](k)|0;n=d;o=c[2440596]|0;p=a[9660972]|0;q=c[2443776]|0}else{n=a[f+(e&255)|0]|0;o=g;p=j;q=l}}while(0);a[9660973]=n;l=o-1|0;c[2440596]=l;o=(n&255)<<8;n=a[9660977]|0;j=(n&255)+(p&255)&255|o;do{if((c[q+68+((o&65535)>>>8<<2)>>2]|0)==0){p=c[q+3148>>2]|0;if((p|0)==0){r=l;s=n;t=q;break}gj[p&4095](j)|0;r=c[2440596]|0;s=a[9660977]|0;t=c[2443776]|0}else{r=l;s=n;t=q}}while(0);q=r-1|0;c[2440596]=q;b[4830486]=(b[4830486]|0)+(s&255)&65535;s=c[2415243]|0;r=s&65535;n=c[t+68+((s>>>8&255)<<2)>>2]|0;do{if((n|0)==0){l=c[t+3148>>2]|0;if((l|0)==0){u=0;v=q;w=s;x=t;break}j=gj[l&4095](r)|0;u=j;v=c[2440596]|0;w=c[2415243]|0;x=c[2443776]|0}else{u=a[n+(s&255)|0]|0;v=q;w=s;x=t}}while(0);t=v-1|0;c[2440596]=t;v=w&65535;s=c[x+68+((w>>>8&255|256)<<2)>>2]|0;do{if((s|0)==0){q=c[x+3152>>2]|0;if((q|0)==0){y=t;break}gg[q&4095](v,u);y=c[2440596]|0}else{a[s+(w&255)|0]=u;y=t}}while(0);t=y-1|0;c[2440596]=t;y=u+1&255;u=a[9660979]|0;w=a[9660976]|0;s=w&255;v=s-(y&255)-(u&1^1)|0;x=u&-66;u=(((w^y)&128&(v^s)|0)==0?x:x|64)|(v&65280|0)==0;a[9660979]=u;a[9660976]=v&255;if((v&255|0)==0){z=u&125|2}else{z=(u&125|v&128)&255}a[9660979]=z;z=c[2415243]|0;v=c[2443776]|0;u=c[v+68+((z>>>8&255|256)<<2)>>2]|0;if((u|0)!=0){a[u+(z&255)|0]=y;A=t;B=A-1|0;c[2440596]=B;return}u=c[v+3152>>2]|0;if((u|0)==0){A=t;B=A-1|0;c[2440596]=B;return}gg[u&4095](z&65535,y);A=c[2440596]|0;B=A-1|0;c[2440596]=B;return}function fXu(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=c[2443776]|0;g=(e&65535)>>>8&255;do{if((c[f+68+((d&65535)>>>8<<2)>>2]|0)==0){e=c[f+3168>>2]|0;if((e|0)==0){h=g;i=f;break}gj[e&4095](d)|0;h=a[9660961]|0;i=c[2443776]|0}else{h=g;i=f}}while(0);f=(c[2440596]|0)-1|0;c[2440596]=f;g=c[2415241]|0;d=g&65535;e=c[i+68+((g>>>8&255|256)<<2)>>2]|0;do{if((e|0)==0){j=c[i+3152>>2]|0;if((j|0)==0){k=f;l=i;break}gg[j&4095](d,h);k=c[2440596]|0;l=c[2443776]|0}else{a[e+(g&255)|0]=h;k=f;l=i}}while(0);i=k-1|0;c[2440596]=i;a[9660964]=(a[9660964]|0)-1&255;k=c[2415241]|0;f=k&65535;h=a[9660960]|0;g=c[l+68+((k>>>8&255|256)<<2)>>2]|0;do{if((g|0)==0){e=c[l+3152>>2]|0;if((e|0)==0){m=i;n=l;break}gg[e&4095](f,h);m=c[2440596]|0;n=c[2443776]|0}else{a[g+(k&255)|0]=h;m=i;n=l}}while(0);l=m-1|0;c[2440596]=l;a[9660964]=(a[9660964]|0)-1&255;m=c[2415241]|0;i=m&65535;h=a[9660979]|16;k=c[n+68+((m>>>8&255|256)<<2)>>2]|0;do{if((k|0)==0){g=c[n+3152>>2]|0;if((g|0)==0){o=l;p=n;break}gg[g&4095](i,h);o=c[2440596]|0;p=c[2443776]|0}else{a[k+(m&255)|0]=h;o=l;p=n}}while(0);n=o-1|0;c[2440596]=n;a[9660964]=(a[9660964]|0)-1&255;a[9660979]=a[9660979]&-13|4;o=c[p+1088>>2]|0;do{if((o|0)==0){l=c[p+3148>>2]|0;if((l|0)==0){q=0;r=n;s=p;break}h=gj[l&4095](-2)|0;q=h;r=c[2440596]|0;s=c[2443776]|0}else{q=a[o+254|0]|0;r=n;s=p}}while(0);a[9660960]=q;q=r-1|0;c[2440596]=q;r=c[s+1088>>2]|0;if((r|0)!=0){t=a[r+255|0]|0;u=q;a[9660961]=t;v=u-1|0;c[2440596]=v;return}r=c[s+3148>>2]|0;if((r|0)==0){t=0;u=q;a[9660961]=t;v=u-1|0;c[2440596]=v;return}q=gj[r&4095](-1)|0;t=q;u=c[2440596]|0;a[9660961]=t;v=u-1|0;c[2440596]=v;return}function fXv(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660972]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415241]|0;e=f&65535;do{if((c[j+68+((f>>>8&255)<<2)>>2]|0)==0){g=c[j+3148>>2]|0;if((g|0)==0){l=i;m=f;n=j;break}gj[g&4095](e)|0;l=c[2440596]|0;m=c[2415241]|0;n=c[2443776]|0}else{l=i;m=f;n=j}}while(0);j=l-1|0;c[2440596]=j;l=m&65535;f=a[9660961]|0;i=c[n+68+((m>>>8&255|256)<<2)>>2]|0;do{if((i|0)==0){e=c[n+3152>>2]|0;if((e|0)==0){o=j;p=n;break}gg[e&4095](l,f);o=c[2440596]|0;p=c[2443776]|0}else{a[i+(m&255)|0]=f;o=j;p=n}}while(0);n=o-1|0;c[2440596]=n;a[9660964]=(a[9660964]|0)-1&255;o=c[2415241]|0;j=o&65535;f=a[9660960]|0;m=c[p+68+((o>>>8&255|256)<<2)>>2]|0;do{if((m|0)==0){i=c[p+3152>>2]|0;if((i|0)==0){q=n;r=p;break}gg[i&4095](j,f);q=c[2440596]|0;r=c[2443776]|0}else{a[m+(o&255)|0]=f;q=n;r=p}}while(0);p=q-1|0;c[2440596]=p;a[9660964]=(a[9660964]|0)-1&255;q=b[4830480]|0;b[4830480]=q+1&65535;n=q&65535;f=c[r+68+(n>>>8<<2)>>2]|0;if((f|0)!=0){s=a[f+(n&255)|0]|0;t=p;a[9660973]=s;u=t-1|0;c[2440596]=u;v=c[2415243]|0;c[2415240]=v;return}n=c[r+3168>>2]|0;if((n|0)==0){s=0;t=p;a[9660973]=s;u=t-1|0;c[2440596]=u;v=c[2415243]|0;c[2415240]=v;return}p=gj[n&4095](q)|0;s=p;t=c[2440596]|0;a[9660973]=s;u=t-1|0;c[2440596]=u;v=c[2415243]|0;c[2415240]=v;return}function fXw(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=c[2443776]|0;do{if((c[e+68+((d&65535)>>>8<<2)>>2]|0)==0){f=c[e+3168>>2]|0;if((f|0)==0){g=e;break}gj[f&4095](d)|0;g=c[2443776]|0}else{g=e}}while(0);e=(c[2440596]|0)-1|0;c[2440596]=e;d=c[2415241]|0;f=d&65535;h=d&255;do{if((c[g+68+((d>>>8&255)<<2)>>2]|0)==0){i=c[g+3148>>2]|0;if((i|0)==0){j=e;k=h;l=g;break}gj[i&4095](f)|0;j=c[2440596]|0;k=a[9660964]|0;l=c[2443776]|0}else{j=e;k=h;l=g}}while(0);g=j-1|0;c[2440596]=g;a[9660964]=k+1&255;k=c[2415241]|0;j=k&65535;h=c[l+68+((k>>>8&255)<<2)>>2]|0;e=k&255;do{if((h|0)==0){f=c[l+3148>>2]|0;if((f|0)==0){m=0;n=g;o=e;p=l;break}d=gj[f&4095](j)|0;m=d;n=c[2440596]|0;o=a[9660964]|0;p=c[2443776]|0}else{m=a[h+(k&255)|0]|0;n=g;o=e;p=l}}while(0);a[9660979]=m;m=n-1|0;c[2440596]=m;a[9660964]=o+1&255;o=c[2415241]|0;n=o&65535;l=c[p+68+((o>>>8&255)<<2)>>2]|0;e=o&255;do{if((l|0)==0){g=c[p+3148>>2]|0;if((g|0)==0){q=0;r=m;s=e;t=p;break}k=gj[g&4095](n)|0;q=k;r=c[2440596]|0;s=a[9660964]|0;t=c[2443776]|0}else{q=a[l+(o&255)|0]|0;r=m;s=e;t=p}}while(0);a[9660960]=q;q=r-1|0;c[2440596]=q;a[9660964]=s+1&255;s=c[2415241]|0;r=s&65535;p=c[t+68+((s>>>8&255)<<2)>>2]|0;do{if((p|0)==0){e=c[t+3148>>2]|0;if((e|0)==0){u=0;v=q;break}m=gj[e&4095](r)|0;u=m;v=c[2440596]|0}else{u=a[p+(s&255)|0]|0;v=q}}while(0);a[9660961]=u;c[2440596]=v-1;v=a[9660979]|0;a[9660979]=v|48;if((a[9660983]|0)==0){return}if((v&4)!=0){return}a[9660981]=1;return}function fXx(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=c[2443776]|0;do{if((c[e+68+((d&65535)>>>8<<2)>>2]|0)==0){f=c[e+3168>>2]|0;if((f|0)==0){g=e;break}gj[f&4095](d)|0;g=c[2443776]|0}else{g=e}}while(0);e=(c[2440596]|0)-1|0;c[2440596]=e;d=c[2415241]|0;f=d&65535;h=d&255;do{if((c[g+68+((d>>>8&255)<<2)>>2]|0)==0){i=c[g+3148>>2]|0;if((i|0)==0){j=e;k=h;l=g;break}gj[i&4095](f)|0;j=c[2440596]|0;k=a[9660964]|0;l=c[2443776]|0}else{j=e;k=h;l=g}}while(0);g=j-1|0;c[2440596]=g;a[9660964]=k+1&255;k=c[2415241]|0;j=k&65535;h=c[l+68+((k>>>8&255)<<2)>>2]|0;e=k&255;do{if((h|0)==0){f=c[l+3148>>2]|0;if((f|0)==0){m=0;n=g;o=e;p=l;break}d=gj[f&4095](j)|0;m=d;n=c[2440596]|0;o=a[9660964]|0;p=c[2443776]|0}else{m=a[h+(k&255)|0]|0;n=g;o=e;p=l}}while(0);a[9660960]=m;m=n-1|0;c[2440596]=m;a[9660964]=o+1&255;o=c[2415241]|0;n=o&65535;l=c[p+68+((o>>>8&255)<<2)>>2]|0;do{if((l|0)==0){e=c[p+3148>>2]|0;if((e|0)==0){q=0;r=m;s=p;break}g=gj[e&4095](n)|0;q=g;r=c[2440596]|0;s=c[2443776]|0}else{q=a[l+(o&255)|0]|0;r=m;s=p}}while(0);a[9660961]=q;q=r-1|0;c[2440596]=q;r=b[4830480]|0;if((c[s+68+((r&65535)>>>8<<2)>>2]|0)!=0){t=q;u=r;v=t-1|0;c[2440596]=v;w=u+1&65535;b[4830480]=w;return}p=c[s+3148>>2]|0;if((p|0)==0){t=q;u=r;v=t-1|0;c[2440596]=v;w=u+1&65535;b[4830480]=w;return}gj[p&4095](r)|0;t=c[2440596]|0;u=b[4830480]|0;v=t-1|0;c[2440596]=v;w=u+1&65535;b[4830480]=w;return}function fXy(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);g=(c[2440596]|0)-1|0;c[2440596]=g;do{if((c[l+68+((k&65535)>>>8<<2)>>2]|0)==0){e=c[l+3148>>2]|0;if((e|0)==0){n=g;o=k;break}gj[e&4095](k)|0;n=c[2440596]|0;o=b[4830480]|0}else{n=g;o=k}}while(0);k=n-1|0;c[2440596]=k;n=o+(j<<24>>24)&65535;b[4830486]=n;if(((n&65535)>>>8&255)<<24>>24==(a[9660961]|0)){p=c[2415243]|0;c[2415240]=p;return}n=o-1&65535;o=c[2443776]|0;do{if((c[o+68+((n&65535)>>>8<<2)>>2]|0)==0){j=c[o+3148>>2]|0;if((j|0)==0){q=k;break}gj[j&4095](n)|0;q=c[2440596]|0}else{q=k}}while(0);c[2440596]=q-1;p=c[2415243]|0;c[2415240]=p;return}function fXz(){var d=0,e=0,f=0,g=0,h=0,i=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(e&255)|0]|0}}while(0);c[2440596]=(c[2440596]|0)-1;a[9660978]=i;a[9660979]=a[9660979]&125|(i<<24>>24==0?2:i&-128);return}function fXA(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(e&255)|0]|0}}while(0);c[2440596]=(c[2440596]|0)-1;e=a[9660979]|0;g=e&-2;a[9660979]=g;d=a[9660978]|0;if((d&255)<(i&255)){j=g}else{g=e|1;a[9660979]=g;j=g}if(d<<24>>24==i<<24>>24){k=j&125|2;a[9660979]=k;return}else{k=j&125|d-i&255&-128;a[9660979]=k;return}}function fXB(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(e&255)|0]|0}}while(0);c[2440596]=(c[2440596]|0)-1;e=a[9660979]|0;g=e&-2;a[9660979]=g;d=a[9660977]|0;if((d&255)<(i&255)){j=g}else{g=e|1;a[9660979]=g;j=g}if(d<<24>>24==i<<24>>24){k=j&125|2;a[9660979]=k;return}else{k=j&125|d-i&255&-128;a[9660979]=k;return}}function fXC(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(e&255)|0]|0}}while(0);e=(c[2440596]|0)-1|0;c[2440596]=e;if((a[9660979]|0)<0){return}g=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((g&65535)>>>8<<2)>>2]|0)==0){f=c[d+3148>>2]|0;if((f|0)==0){j=e;k=g;break}gj[f&4095](g)|0;j=c[2440596]|0;k=b[4830480]|0}else{j=e;k=g}}while(0);g=j-1|0;c[2440596]=g;j=k+(i<<24>>24)&65535;b[4830486]=j;if(((j&65535)>>>8&255)<<24>>24!=(a[9660961]|0)){j=k-1&65535;k=c[2443776]|0;do{if((c[k+68+((j&65535)>>>8<<2)>>2]|0)==0){i=c[k+3148>>2]|0;if((i|0)==0){l=g;break}gj[i&4095](j)|0;l=c[2440596]|0}else{l=g}}while(0);c[2440596]=l-1}c[2415240]=c[2415243];return}function fXD(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(e&255)|0]|0}}while(0);e=(c[2440596]|0)-1|0;c[2440596]=e;if((a[9660979]|0)>=0){return}g=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((g&65535)>>>8<<2)>>2]|0)==0){f=c[d+3148>>2]|0;if((f|0)==0){j=e;k=g;break}gj[f&4095](g)|0;j=c[2440596]|0;k=b[4830480]|0}else{j=e;k=g}}while(0);g=j-1|0;c[2440596]=g;j=k+(i<<24>>24)&65535;b[4830486]=j;if(((j&65535)>>>8&255)<<24>>24!=(a[9660961]|0)){j=k-1&65535;k=c[2443776]|0;do{if((c[k+68+((j&65535)>>>8<<2)>>2]|0)==0){i=c[k+3148>>2]|0;if((i|0)==0){l=g;break}gj[i&4095](j)|0;l=c[2440596]|0}else{l=g}}while(0);c[2440596]=l-1}c[2415240]=c[2415243];return}function fXE(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(e&255)|0]|0}}while(0);e=(c[2440596]|0)-1|0;c[2440596]=e;if((a[9660979]&64)!=0){return}g=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((g&65535)>>>8<<2)>>2]|0)==0){f=c[d+3148>>2]|0;if((f|0)==0){j=e;k=g;break}gj[f&4095](g)|0;j=c[2440596]|0;k=b[4830480]|0}else{j=e;k=g}}while(0);g=j-1|0;c[2440596]=g;j=k+(i<<24>>24)&65535;b[4830486]=j;if(((j&65535)>>>8&255)<<24>>24!=(a[9660961]|0)){j=k-1&65535;k=c[2443776]|0;do{if((c[k+68+((j&65535)>>>8<<2)>>2]|0)==0){i=c[k+3148>>2]|0;if((i|0)==0){l=g;break}gj[i&4095](j)|0;l=c[2440596]|0}else{l=g}}while(0);c[2440596]=l-1}c[2415240]=c[2415243];return}function fXF(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(e&255)|0]|0}}while(0);e=(c[2440596]|0)-1|0;c[2440596]=e;if((a[9660979]&64)==0){return}g=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((g&65535)>>>8<<2)>>2]|0)==0){f=c[d+3148>>2]|0;if((f|0)==0){j=e;k=g;break}gj[f&4095](g)|0;j=c[2440596]|0;k=b[4830480]|0}else{j=e;k=g}}while(0);g=j-1|0;c[2440596]=g;j=k+(i<<24>>24)&65535;b[4830486]=j;if(((j&65535)>>>8&255)<<24>>24!=(a[9660961]|0)){j=k-1&65535;k=c[2443776]|0;do{if((c[k+68+((j&65535)>>>8<<2)>>2]|0)==0){i=c[k+3148>>2]|0;if((i|0)==0){l=g;break}gj[i&4095](j)|0;l=c[2440596]|0}else{l=g}}while(0);c[2440596]=l-1}c[2415240]=c[2415243];return}function fXG(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(e&255)|0]|0}}while(0);e=(c[2440596]|0)-1|0;c[2440596]=e;if((a[9660979]&1)!=0){return}g=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((g&65535)>>>8<<2)>>2]|0)==0){f=c[d+3148>>2]|0;if((f|0)==0){j=e;k=g;break}gj[f&4095](g)|0;j=c[2440596]|0;k=b[4830480]|0}else{j=e;k=g}}while(0);g=j-1|0;c[2440596]=g;j=k+(i<<24>>24)&65535;b[4830486]=j;if(((j&65535)>>>8&255)<<24>>24!=(a[9660961]|0)){j=k-1&65535;k=c[2443776]|0;do{if((c[k+68+((j&65535)>>>8<<2)>>2]|0)==0){i=c[k+3148>>2]|0;if((i|0)==0){l=g;break}gj[i&4095](j)|0;l=c[2440596]|0}else{l=g}}while(0);c[2440596]=l-1}c[2415240]=c[2415243];return}function fXH(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(e&255)|0]|0}}while(0);e=(c[2440596]|0)-1|0;c[2440596]=e;if((a[9660979]&1)==0){return}g=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((g&65535)>>>8<<2)>>2]|0)==0){f=c[d+3148>>2]|0;if((f|0)==0){j=e;k=g;break}gj[f&4095](g)|0;j=c[2440596]|0;k=b[4830480]|0}else{j=e;k=g}}while(0);g=j-1|0;c[2440596]=g;j=k+(i<<24>>24)&65535;b[4830486]=j;if(((j&65535)>>>8&255)<<24>>24!=(a[9660961]|0)){j=k-1&65535;k=c[2443776]|0;do{if((c[k+68+((j&65535)>>>8<<2)>>2]|0)==0){i=c[k+3148>>2]|0;if((i|0)==0){l=g;break}gj[i&4095](j)|0;l=c[2440596]|0}else{l=g}}while(0);c[2440596]=l-1}c[2415240]=c[2415243];return}function fXI(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(e&255)|0]|0}}while(0);e=(c[2440596]|0)-1|0;c[2440596]=e;if((a[9660979]&2)!=0){return}g=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((g&65535)>>>8<<2)>>2]|0)==0){f=c[d+3148>>2]|0;if((f|0)==0){j=e;k=g;break}gj[f&4095](g)|0;j=c[2440596]|0;k=b[4830480]|0}else{j=e;k=g}}while(0);g=j-1|0;c[2440596]=g;j=k+(i<<24>>24)&65535;b[4830486]=j;if(((j&65535)>>>8&255)<<24>>24!=(a[9660961]|0)){j=k-1&65535;k=c[2443776]|0;do{if((c[k+68+((j&65535)>>>8<<2)>>2]|0)==0){i=c[k+3148>>2]|0;if((i|0)==0){l=g;break}gj[i&4095](j)|0;l=c[2440596]|0}else{l=g}}while(0);c[2440596]=l-1}c[2415240]=c[2415243];return}function fXJ(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(e&255)|0]|0}}while(0);e=(c[2440596]|0)-1|0;c[2440596]=e;if((a[9660979]&2)==0){return}g=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((g&65535)>>>8<<2)>>2]|0)==0){f=c[d+3148>>2]|0;if((f|0)==0){j=e;k=g;break}gj[f&4095](g)|0;j=c[2440596]|0;k=b[4830480]|0}else{j=e;k=g}}while(0);g=j-1|0;c[2440596]=g;j=k+(i<<24>>24)&65535;b[4830486]=j;if(((j&65535)>>>8&255)<<24>>24!=(a[9660961]|0)){j=k-1&65535;k=c[2443776]|0;do{if((c[k+68+((j&65535)>>>8<<2)>>2]|0)==0){i=c[k+3148>>2]|0;if((i|0)==0){l=g;break}gj[i&4095](j)|0;l=c[2440596]|0}else{l=g}}while(0);c[2440596]=l-1}c[2415240]=c[2415243];return}function fXK(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=f&255;do{if((c[j+68+((f>>>8&255)<<2)>>2]|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=i;m=g;n=j;break}gj[d&4095](e)|0;l=c[2440596]|0;m=a[9660968]|0;n=c[2443776]|0}else{l=i;m=g;n=j}}while(0);j=l-1|0;c[2440596]=j;a[9660968]=(a[9660977]|0)+m&255;m=c[2415242]|0;l=m&65535;g=c[n+68+((m>>>8&255)<<2)>>2]|0;i=m&255;do{if((g|0)==0){e=c[n+3148>>2]|0;if((e|0)==0){o=0;p=j;q=i;r=n;break}f=gj[e&4095](l)|0;o=f;p=c[2440596]|0;q=a[9660968]|0;r=c[2443776]|0}else{o=a[g+(m&255)|0]|0;p=j;q=i;r=n}}while(0);a[9660972]=o;o=p-1|0;c[2440596]=o;a[9660968]=q+1&255;q=c[2415242]|0;p=q&65535;n=c[r+68+((q>>>8&255)<<2)>>2]|0;do{if((n|0)==0){i=c[r+3148>>2]|0;if((i|0)==0){s=0;t=o;u=r;break}j=gj[i&4095](p)|0;s=j;t=c[2440596]|0;u=c[2443776]|0}else{s=a[n+(q&255)|0]|0;t=o;u=r}}while(0);a[9660973]=s;s=t-1|0;c[2440596]=s;t=c[2415243]|0;r=t&65535;o=c[u+68+((t>>>8&255)<<2)>>2]|0;do{if((o|0)==0){q=c[u+3156>>2]|0;if((q|0)==0){v=0;w=s;break}n=gj[q&4095](r)|0;v=n;w=c[2440596]|0}else{v=a[o+(t&255)|0]|0;w=s}}while(0);c[2440596]=w-1;w=a[9660976]|v;a[9660976]=w;a[9660979]=(w<<24>>24==0?2:w&-128)|a[9660979]&125;return}function fXL(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=f&255;do{if((c[j+68+((f>>>8&255)<<2)>>2]|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=i;m=g;n=j;break}gj[d&4095](e)|0;l=c[2440596]|0;m=a[9660968]|0;n=c[2443776]|0}else{l=i;m=g;n=j}}while(0);j=l-1|0;c[2440596]=j;a[9660968]=(a[9660977]|0)+m&255;m=c[2415242]|0;l=m&65535;g=c[n+68+((m>>>8&255)<<2)>>2]|0;i=m&255;do{if((g|0)==0){e=c[n+3148>>2]|0;if((e|0)==0){o=0;p=j;q=i;r=n;break}f=gj[e&4095](l)|0;o=f;p=c[2440596]|0;q=a[9660968]|0;r=c[2443776]|0}else{o=a[g+(m&255)|0]|0;p=j;q=i;r=n}}while(0);a[9660972]=o;o=p-1|0;c[2440596]=o;a[9660968]=q+1&255;q=c[2415242]|0;p=q&65535;n=c[r+68+((q>>>8&255)<<2)>>2]|0;do{if((n|0)==0){i=c[r+3148>>2]|0;if((i|0)==0){s=0;t=o;u=r;break}j=gj[i&4095](p)|0;s=j;t=c[2440596]|0;u=c[2443776]|0}else{s=a[n+(q&255)|0]|0;t=o;u=r}}while(0);a[9660973]=s;s=t-1|0;c[2440596]=s;t=c[2415243]|0;r=t&65535;o=c[u+68+((t>>>8&255)<<2)>>2]|0;do{if((o|0)==0){q=c[u+3156>>2]|0;if((q|0)==0){v=0;w=s;break}n=gj[q&4095](r)|0;v=n;w=c[2440596]|0}else{v=a[o+(t&255)|0]|0;w=s}}while(0);c[2440596]=w-1;w=a[9660976]&v;a[9660976]=w;a[9660979]=(w<<24>>24==0?2:w&-128)|a[9660979]&125;return}function fXM(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=f&255;do{if((c[j+68+((f>>>8&255)<<2)>>2]|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=i;m=g;n=j;break}gj[d&4095](e)|0;l=c[2440596]|0;m=a[9660968]|0;n=c[2443776]|0}else{l=i;m=g;n=j}}while(0);j=l-1|0;c[2440596]=j;a[9660968]=(a[9660977]|0)+m&255;m=c[2415242]|0;l=m&65535;g=c[n+68+((m>>>8&255)<<2)>>2]|0;i=m&255;do{if((g|0)==0){e=c[n+3148>>2]|0;if((e|0)==0){o=0;p=j;q=i;r=n;break}f=gj[e&4095](l)|0;o=f;p=c[2440596]|0;q=a[9660968]|0;r=c[2443776]|0}else{o=a[g+(m&255)|0]|0;p=j;q=i;r=n}}while(0);a[9660972]=o;o=p-1|0;c[2440596]=o;a[9660968]=q+1&255;q=c[2415242]|0;p=q&65535;n=c[r+68+((q>>>8&255)<<2)>>2]|0;do{if((n|0)==0){i=c[r+3148>>2]|0;if((i|0)==0){s=0;t=o;u=r;break}j=gj[i&4095](p)|0;s=j;t=c[2440596]|0;u=c[2443776]|0}else{s=a[n+(q&255)|0]|0;t=o;u=r}}while(0);a[9660973]=s;s=t-1|0;c[2440596]=s;t=c[2415243]|0;r=t&65535;o=c[u+68+((t>>>8&255)<<2)>>2]|0;do{if((o|0)==0){q=c[u+3156>>2]|0;if((q|0)==0){v=0;w=s;break}n=gj[q&4095](r)|0;v=n;w=c[2440596]|0}else{v=a[o+(t&255)|0]|0;w=s}}while(0);c[2440596]=w-1;w=a[9660976]|0;s=w^v;a[9660976]=s;a[9660979]=(w<<24>>24==v<<24>>24?2:s&-128)|a[9660979]&125;return}function fXN(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=f&255;do{if((c[j+68+((f>>>8&255)<<2)>>2]|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=i;m=g;n=j;break}gj[d&4095](e)|0;l=c[2440596]|0;m=a[9660968]|0;n=c[2443776]|0}else{l=i;m=g;n=j}}while(0);j=l-1|0;c[2440596]=j;a[9660968]=(a[9660977]|0)+m&255;m=c[2415242]|0;l=m&65535;g=c[n+68+((m>>>8&255)<<2)>>2]|0;i=m&255;do{if((g|0)==0){e=c[n+3148>>2]|0;if((e|0)==0){o=0;p=j;q=i;r=n;break}f=gj[e&4095](l)|0;o=f;p=c[2440596]|0;q=a[9660968]|0;r=c[2443776]|0}else{o=a[g+(m&255)|0]|0;p=j;q=i;r=n}}while(0);a[9660972]=o;o=p-1|0;c[2440596]=o;a[9660968]=q+1&255;q=c[2415242]|0;p=q&65535;n=c[r+68+((q>>>8&255)<<2)>>2]|0;do{if((n|0)==0){i=c[r+3148>>2]|0;if((i|0)==0){s=0;t=o;u=r;break}j=gj[i&4095](p)|0;s=j;t=c[2440596]|0;u=c[2443776]|0}else{s=a[n+(q&255)|0]|0;t=o;u=r}}while(0);a[9660973]=s;s=t-1|0;c[2440596]=s;t=c[2415243]|0;r=t&65535;o=c[u+68+((t>>>8&255)<<2)>>2]|0;do{if((o|0)==0){q=c[u+3156>>2]|0;if((q|0)==0){v=0;w=s;break}n=gj[q&4095](r)|0;v=n;w=c[2440596]|0}else{v=a[o+(t&255)|0]|0;w=s}}while(0);s=v&255;t=w-1|0;c[2440596]=t;w=a[9660979]|0;o=w&255;r=o&1;u=a[9660976]|0;n=u&255;if((o&8|0)==0){o=n+s+r|0;q=w&-66;p=((((u^v)&128^128)&(o^n)|0)==0?q:q|64)|(o&65280|0)!=0;a[9660979]=p;q=o&255;a[9660976]=q;x=q;y=p;z=x<<24>>24==0;A=y&125;B=x&-128;C=z?2:B;D=C|A;a[9660979]=D;return}p=r+(s&15)+(n&15)|0;r=(n&240)+(s&240)|0;s=w&-66;a[9660979]=s;if((p|0)>9){E=p+6|0;F=r+16|0}else{E=p;F=r}if((((u^v)&128^128)&(F^n)|0)==0){G=s}else{n=s|64;a[9660979]=n;G=n}n=(F|0)>144?F+96|0:F;if((n&65280|0)==0){H=G}else{F=G|1;a[9660979]=F;H=F}F=(n&240|E&15)&255;a[9660976]=F;E=(b[4830480]|0)-1&65535;n=c[2443776]|0;do{if((c[n+68+((E&65535)>>>8<<2)>>2]|0)==0){G=c[n+3148>>2]|0;if((G|0)==0){I=t;J=F;K=H;break}gj[G&4095](E)|0;I=c[2440596]|0;J=a[9660976]|0;K=a[9660979]|0}else{I=t;J=F;K=H}}while(0);c[2440596]=I-1;x=J;y=K;z=x<<24>>24==0;A=y&125;B=x&-128;C=z?2:B;D=C|A;a[9660979]=D;return}function fXO(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=a[9660976]|0;e=b[4830480]|0;b[4830480]=e+1&65535;f=e&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](e)|0;j=l;k=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=g}}while(0);a[9660968]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;g=c[2415242]|0;f=g&65535;h=g&255;do{if((c[k+68+((g>>>8&255)<<2)>>2]|0)==0){e=c[k+3148>>2]|0;if((e|0)==0){m=j;n=h;o=k;break}gj[e&4095](f)|0;m=c[2440596]|0;n=a[9660968]|0;o=c[2443776]|0}else{m=j;n=h;o=k}}while(0);k=m-1|0;c[2440596]=k;a[9660968]=(a[9660977]|0)+n&255;n=c[2415242]|0;m=n&65535;h=c[o+68+((n>>>8&255)<<2)>>2]|0;j=n&255;do{if((h|0)==0){f=c[o+3148>>2]|0;if((f|0)==0){p=0;q=k;r=j;s=o;break}g=gj[f&4095](m)|0;p=g;q=c[2440596]|0;r=a[9660968]|0;s=c[2443776]|0}else{p=a[h+(n&255)|0]|0;q=k;r=j;s=o}}while(0);a[9660972]=p;p=q-1|0;c[2440596]=p;a[9660968]=r+1&255;r=c[2415242]|0;q=r&65535;o=c[s+68+((r>>>8&255)<<2)>>2]|0;do{if((o|0)==0){j=c[s+3148>>2]|0;if((j|0)==0){t=0;u=p;v=s;break}k=gj[j&4095](q)|0;t=k;u=c[2440596]|0;v=c[2443776]|0}else{t=a[o+(r&255)|0]|0;u=p;v=s}}while(0);a[9660973]=t;t=u-1|0;c[2440596]=t;u=c[2415243]|0;s=c[v+68+((u>>>8&255|256)<<2)>>2]|0;if((s|0)!=0){a[s+(u&255)|0]=d;w=t;x=w-1|0;c[2440596]=x;return}s=c[v+3160>>2]|0;if((s|0)==0){w=t;x=w-1|0;c[2440596]=x;return}gg[s&4095](u&65535,d);w=c[2440596]|0;x=w-1|0;c[2440596]=x;return}function fXP(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=f&255;do{if((c[j+68+((f>>>8&255)<<2)>>2]|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=i;m=g;n=j;break}gj[d&4095](e)|0;l=c[2440596]|0;m=a[9660968]|0;n=c[2443776]|0}else{l=i;m=g;n=j}}while(0);j=l-1|0;c[2440596]=j;a[9660968]=(a[9660977]|0)+m&255;m=c[2415242]|0;l=m&65535;g=c[n+68+((m>>>8&255)<<2)>>2]|0;i=m&255;do{if((g|0)==0){e=c[n+3148>>2]|0;if((e|0)==0){o=0;p=j;q=i;r=n;break}f=gj[e&4095](l)|0;o=f;p=c[2440596]|0;q=a[9660968]|0;r=c[2443776]|0}else{o=a[g+(m&255)|0]|0;p=j;q=i;r=n}}while(0);a[9660972]=o;o=p-1|0;c[2440596]=o;a[9660968]=q+1&255;q=c[2415242]|0;p=q&65535;n=c[r+68+((q>>>8&255)<<2)>>2]|0;do{if((n|0)==0){i=c[r+3148>>2]|0;if((i|0)==0){s=0;t=o;u=r;break}j=gj[i&4095](p)|0;s=j;t=c[2440596]|0;u=c[2443776]|0}else{s=a[n+(q&255)|0]|0;t=o;u=r}}while(0);a[9660973]=s;s=t-1|0;c[2440596]=s;t=c[2415243]|0;r=c[u+68+((t>>>8&255)<<2)>>2]|0;if((r|0)!=0){v=a[r+(t&255)|0]|0;w=s;x=w-1|0;c[2440596]=x;a[9660976]=v;y=v<<24>>24==0;z=a[9660979]|0;A=z&125;B=v&-128;C=y?2:B;D=A|C;a[9660979]=D;return}r=c[u+3156>>2]|0;if((r|0)==0){v=0;w=s;x=w-1|0;c[2440596]=x;a[9660976]=v;y=v<<24>>24==0;z=a[9660979]|0;A=z&125;B=v&-128;C=y?2:B;D=A|C;a[9660979]=D;return}s=gj[r&4095](t&65535)|0;v=s;w=c[2440596]|0;x=w-1|0;c[2440596]=x;a[9660976]=v;y=v<<24>>24==0;z=a[9660979]|0;A=z&125;B=v&-128;C=y?2:B;D=A|C;a[9660979]=D;return}function fXQ(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=f&255;do{if((c[j+68+((f>>>8&255)<<2)>>2]|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=i;m=g;n=j;break}gj[d&4095](e)|0;l=c[2440596]|0;m=a[9660968]|0;n=c[2443776]|0}else{l=i;m=g;n=j}}while(0);j=l-1|0;c[2440596]=j;a[9660968]=(a[9660977]|0)+m&255;m=c[2415242]|0;l=m&65535;g=c[n+68+((m>>>8&255)<<2)>>2]|0;i=m&255;do{if((g|0)==0){e=c[n+3148>>2]|0;if((e|0)==0){o=0;p=j;q=i;r=n;break}f=gj[e&4095](l)|0;o=f;p=c[2440596]|0;q=a[9660968]|0;r=c[2443776]|0}else{o=a[g+(m&255)|0]|0;p=j;q=i;r=n}}while(0);a[9660972]=o;o=p-1|0;c[2440596]=o;a[9660968]=q+1&255;q=c[2415242]|0;p=q&65535;n=c[r+68+((q>>>8&255)<<2)>>2]|0;do{if((n|0)==0){i=c[r+3148>>2]|0;if((i|0)==0){s=0;t=o;u=r;break}j=gj[i&4095](p)|0;s=j;t=c[2440596]|0;u=c[2443776]|0}else{s=a[n+(q&255)|0]|0;t=o;u=r}}while(0);a[9660973]=s;s=t-1|0;c[2440596]=s;t=c[2415243]|0;r=t&65535;o=c[u+68+((t>>>8&255)<<2)>>2]|0;do{if((o|0)==0){q=c[u+3156>>2]|0;if((q|0)==0){v=0;w=s;break}n=gj[q&4095](r)|0;v=n;w=c[2440596]|0}else{v=a[o+(t&255)|0]|0;w=s}}while(0);c[2440596]=w-1;w=a[9660979]|0;s=w&-2;a[9660979]=s;t=a[9660976]|0;if((t&255)<(v&255)){x=s}else{s=w|1;a[9660979]=s;x=s}if(t<<24>>24==v<<24>>24){y=x&125|2;a[9660979]=y;return}else{y=x&125|t-v&255&-128;a[9660979]=y;return}}function fXR(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=f&255;do{if((c[j+68+((f>>>8&255)<<2)>>2]|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=i;m=g;n=j;break}gj[d&4095](e)|0;l=c[2440596]|0;m=a[9660968]|0;n=c[2443776]|0}else{l=i;m=g;n=j}}while(0);j=l-1|0;c[2440596]=j;a[9660968]=(a[9660977]|0)+m&255;m=c[2415242]|0;l=m&65535;g=c[n+68+((m>>>8&255)<<2)>>2]|0;i=m&255;do{if((g|0)==0){e=c[n+3148>>2]|0;if((e|0)==0){o=0;p=j;q=i;r=n;break}f=gj[e&4095](l)|0;o=f;p=c[2440596]|0;q=a[9660968]|0;r=c[2443776]|0}else{o=a[g+(m&255)|0]|0;p=j;q=i;r=n}}while(0);a[9660972]=o;o=p-1|0;c[2440596]=o;a[9660968]=q+1&255;q=c[2415242]|0;p=q&65535;n=c[r+68+((q>>>8&255)<<2)>>2]|0;do{if((n|0)==0){i=c[r+3148>>2]|0;if((i|0)==0){s=0;t=o;u=r;break}j=gj[i&4095](p)|0;s=j;t=c[2440596]|0;u=c[2443776]|0}else{s=a[n+(q&255)|0]|0;t=o;u=r}}while(0);a[9660973]=s;s=t-1|0;c[2440596]=s;t=c[2415243]|0;r=t&65535;o=c[u+68+((t>>>8&255)<<2)>>2]|0;do{if((o|0)==0){q=c[u+3156>>2]|0;if((q|0)==0){v=0;w=s;break}n=gj[q&4095](r)|0;v=n;w=c[2440596]|0}else{v=a[o+(t&255)|0]|0;w=s}}while(0);s=v&255;t=w-1|0;c[2440596]=t;w=a[9660979]|0;o=w&255;r=o&1^1;u=a[9660976]|0;n=u&255;q=n-s-r|0;if((o&8|0)==0){o=w&-66;p=(((u^v)&128&(q^n)|0)==0?o:o|64)|(q&65280|0)==0;a[9660979]=p;o=q&255;a[9660976]=o;x=o;y=p;z=x<<24>>24==0;A=y&125;B=x&-128;C=z?2:B;D=C|A;a[9660979]=D;return}p=(n&15)-(s&15)-r|0;r=(n&240)-(s&240)|0;s=w&-66;w=(p&240|0)==0?p:p-6|0;p=(w&128|0)==0?r:r-16|0;r=(((u^v)&128&(q^n)|0)==0?s:s|64)|(q&65280|0)==0;a[9660979]=r;q=(((p&3840|0)==0?p:p+160|0)&240|w&15)&255;a[9660976]=q;w=(b[4830480]|0)-1&65535;p=c[2443776]|0;do{if((c[p+68+((w&65535)>>>8<<2)>>2]|0)==0){s=c[p+3148>>2]|0;if((s|0)==0){E=t;F=q;G=r;break}gj[s&4095](w)|0;E=c[2440596]|0;F=a[9660976]|0;G=a[9660979]|0}else{E=t;F=q;G=r}}while(0);c[2440596]=E-1;x=F;y=G;z=x<<24>>24==0;A=y&125;B=x&-128;C=z?2:B;D=C|A;a[9660979]=D;return}function fXS(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;d=f&255;do{if((g|0)==0){k=c[j+3148>>2]|0;if((k|0)==0){l=0;m=i;n=d;o=j;break}h=gj[k&4095](e)|0;l=h;m=c[2440596]|0;n=a[9660968]|0;o=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=d;o=j}}while(0);a[9660972]=l;j=m-1|0;c[2440596]=j;a[9660968]=n+1&255;n=c[2415242]|0;m=n&65535;d=c[o+68+((n>>>8&255)<<2)>>2]|0;do{if((d|0)==0){i=c[o+3148>>2]|0;if((i|0)==0){p=0;q=j;r=l;break}f=gj[i&4095](m)|0;p=f;q=c[2440596]|0;r=a[9660972]|0}else{p=a[d+(n&255)|0]|0;q=j;r=l}}while(0);a[9660973]=p;p=q-1|0;c[2440596]=p;q=a[9660978]|0;if(((q&255)+(r&255)|0)>255){r=(b[4830480]|0)-1&65535;l=c[2443776]|0;do{if((c[l+68+((r&65535)>>>8<<2)>>2]|0)==0){j=c[l+3148>>2]|0;if((j|0)==0){s=p;t=q;break}gj[j&4095](r)|0;s=c[2440596]|0;t=a[9660978]|0}else{s=p;t=q}}while(0);r=s-1|0;c[2440596]=r;u=t;v=r}else{u=q;v=p}b[4830486]=(b[4830486]|0)+(u&255)&65535;u=c[2415243]|0;p=c[2443776]|0;q=c[p+68+((u>>>8&255)<<2)>>2]|0;if((q|0)!=0){w=a[q+(u&255)|0]|0;x=v;y=x-1|0;c[2440596]=y;z=a[9660976]|0;A=z|w;a[9660976]=A;B=A<<24>>24==0;C=a[9660979]|0;D=C&125;E=A&-128;F=B?2:E;G=F|D;a[9660979]=G;return}q=c[p+3156>>2]|0;if((q|0)==0){w=0;x=v;y=x-1|0;c[2440596]=y;z=a[9660976]|0;A=z|w;a[9660976]=A;B=A<<24>>24==0;C=a[9660979]|0;D=C&125;E=A&-128;F=B?2:E;G=F|D;a[9660979]=G;return}v=gj[q&4095](u&65535)|0;w=v;x=c[2440596]|0;y=x-1|0;c[2440596]=y;z=a[9660976]|0;A=z|w;a[9660976]=A;B=A<<24>>24==0;C=a[9660979]|0;D=C&125;E=A&-128;F=B?2:E;G=F|D;a[9660979]=G;return}function fXT(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;d=f&255;do{if((g|0)==0){k=c[j+3148>>2]|0;if((k|0)==0){l=0;m=i;n=d;o=j;break}h=gj[k&4095](e)|0;l=h;m=c[2440596]|0;n=a[9660968]|0;o=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=d;o=j}}while(0);a[9660972]=l;j=m-1|0;c[2440596]=j;a[9660968]=n+1&255;n=c[2415242]|0;m=n&65535;d=c[o+68+((n>>>8&255)<<2)>>2]|0;do{if((d|0)==0){i=c[o+3148>>2]|0;if((i|0)==0){p=0;q=j;r=l;break}f=gj[i&4095](m)|0;p=f;q=c[2440596]|0;r=a[9660972]|0}else{p=a[d+(n&255)|0]|0;q=j;r=l}}while(0);a[9660973]=p;p=q-1|0;c[2440596]=p;q=a[9660978]|0;if(((q&255)+(r&255)|0)>255){r=(b[4830480]|0)-1&65535;l=c[2443776]|0;do{if((c[l+68+((r&65535)>>>8<<2)>>2]|0)==0){j=c[l+3148>>2]|0;if((j|0)==0){s=p;t=q;break}gj[j&4095](r)|0;s=c[2440596]|0;t=a[9660978]|0}else{s=p;t=q}}while(0);r=s-1|0;c[2440596]=r;u=t;v=r}else{u=q;v=p}b[4830486]=(b[4830486]|0)+(u&255)&65535;u=c[2415243]|0;p=c[2443776]|0;q=c[p+68+((u>>>8&255)<<2)>>2]|0;if((q|0)!=0){w=a[q+(u&255)|0]|0;x=v;y=x-1|0;c[2440596]=y;z=a[9660976]|0;A=z&w;a[9660976]=A;B=A<<24>>24==0;C=a[9660979]|0;D=C&125;E=A&-128;F=B?2:E;G=F|D;a[9660979]=G;return}q=c[p+3156>>2]|0;if((q|0)==0){w=0;x=v;y=x-1|0;c[2440596]=y;z=a[9660976]|0;A=z&w;a[9660976]=A;B=A<<24>>24==0;C=a[9660979]|0;D=C&125;E=A&-128;F=B?2:E;G=F|D;a[9660979]=G;return}v=gj[q&4095](u&65535)|0;w=v;x=c[2440596]|0;y=x-1|0;c[2440596]=y;z=a[9660976]|0;A=z&w;a[9660976]=A;B=A<<24>>24==0;C=a[9660979]|0;D=C&125;E=A&-128;F=B?2:E;G=F|D;a[9660979]=G;return}function fXU(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;d=f&255;do{if((g|0)==0){k=c[j+3148>>2]|0;if((k|0)==0){l=0;m=i;n=d;o=j;break}h=gj[k&4095](e)|0;l=h;m=c[2440596]|0;n=a[9660968]|0;o=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=d;o=j}}while(0);a[9660972]=l;j=m-1|0;c[2440596]=j;a[9660968]=n+1&255;n=c[2415242]|0;m=n&65535;d=c[o+68+((n>>>8&255)<<2)>>2]|0;do{if((d|0)==0){i=c[o+3148>>2]|0;if((i|0)==0){p=0;q=j;r=l;break}f=gj[i&4095](m)|0;p=f;q=c[2440596]|0;r=a[9660972]|0}else{p=a[d+(n&255)|0]|0;q=j;r=l}}while(0);a[9660973]=p;p=q-1|0;c[2440596]=p;q=a[9660978]|0;if(((q&255)+(r&255)|0)>255){r=(b[4830480]|0)-1&65535;l=c[2443776]|0;do{if((c[l+68+((r&65535)>>>8<<2)>>2]|0)==0){j=c[l+3148>>2]|0;if((j|0)==0){s=p;t=q;break}gj[j&4095](r)|0;s=c[2440596]|0;t=a[9660978]|0}else{s=p;t=q}}while(0);r=s-1|0;c[2440596]=r;u=t;v=r}else{u=q;v=p}b[4830486]=(b[4830486]|0)+(u&255)&65535;u=c[2415243]|0;p=u&65535;q=c[2443776]|0;r=c[q+68+((u>>>8&255)<<2)>>2]|0;do{if((r|0)==0){t=c[q+3156>>2]|0;if((t|0)==0){w=0;x=v;break}s=gj[t&4095](p)|0;w=s;x=c[2440596]|0}else{w=a[r+(u&255)|0]|0;x=v}}while(0);c[2440596]=x-1;x=a[9660976]|0;v=x^w;a[9660976]=v;a[9660979]=(x<<24>>24==w<<24>>24?2:v&-128)|a[9660979]&125;return}function fXV(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;d=f&255;do{if((g|0)==0){k=c[j+3148>>2]|0;if((k|0)==0){l=0;m=i;n=d;o=j;break}h=gj[k&4095](e)|0;l=h;m=c[2440596]|0;n=a[9660968]|0;o=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=d;o=j}}while(0);a[9660972]=l;j=m-1|0;c[2440596]=j;a[9660968]=n+1&255;n=c[2415242]|0;m=n&65535;d=c[o+68+((n>>>8&255)<<2)>>2]|0;do{if((d|0)==0){i=c[o+3148>>2]|0;if((i|0)==0){p=0;q=j;r=l;break}f=gj[i&4095](m)|0;p=f;q=c[2440596]|0;r=a[9660972]|0}else{p=a[d+(n&255)|0]|0;q=j;r=l}}while(0);a[9660973]=p;p=q-1|0;c[2440596]=p;q=a[9660978]|0;if(((q&255)+(r&255)|0)>255){r=(b[4830480]|0)-1&65535;l=c[2443776]|0;do{if((c[l+68+((r&65535)>>>8<<2)>>2]|0)==0){j=c[l+3148>>2]|0;if((j|0)==0){s=p;t=q;break}gj[j&4095](r)|0;s=c[2440596]|0;t=a[9660978]|0}else{s=p;t=q}}while(0);r=s-1|0;c[2440596]=r;u=t;v=r}else{u=q;v=p}b[4830486]=(b[4830486]|0)+(u&255)&65535;u=c[2415243]|0;p=u&65535;q=c[2443776]|0;r=c[q+68+((u>>>8&255)<<2)>>2]|0;do{if((r|0)==0){t=c[q+3156>>2]|0;if((t|0)==0){w=0;x=v;break}s=gj[t&4095](p)|0;w=s;x=c[2440596]|0}else{w=a[r+(u&255)|0]|0;x=v}}while(0);v=w&255;u=x-1|0;c[2440596]=u;x=a[9660979]|0;r=x&255;p=r&1;q=a[9660976]|0;s=q&255;if((r&8|0)==0){r=s+v+p|0;t=x&-66;l=((((q^w)&128^128)&(r^s)|0)==0?t:t|64)|(r&65280|0)!=0;a[9660979]=l;t=r&255;a[9660976]=t;y=t;z=l;A=y<<24>>24==0;B=z&125;C=y&-128;D=A?2:C;E=D|B;a[9660979]=E;return}l=p+(v&15)+(s&15)|0;p=(s&240)+(v&240)|0;v=x&-66;a[9660979]=v;if((l|0)>9){F=l+6|0;G=p+16|0}else{F=l;G=p}if((((q^w)&128^128)&(G^s)|0)==0){H=v}else{s=v|64;a[9660979]=s;H=s}s=(G|0)>144?G+96|0:G;if((s&65280|0)==0){I=H}else{G=H|1;a[9660979]=G;I=G}G=(s&240|F&15)&255;a[9660976]=G;F=(b[4830480]|0)-1&65535;s=c[2443776]|0;do{if((c[s+68+((F&65535)>>>8<<2)>>2]|0)==0){H=c[s+3148>>2]|0;if((H|0)==0){J=u;K=G;L=I;break}gj[H&4095](F)|0;J=c[2440596]|0;K=a[9660976]|0;L=a[9660979]|0}else{J=u;K=G;L=I}}while(0);c[2440596]=J-1;y=K;z=L;A=y<<24>>24==0;B=z&125;C=y&-128;D=A?2:C;E=D|B;a[9660979]=E;return}function fXW(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;e=a[9660976]|0;f=b[4830480]|0;b[4830480]=f+1&65535;g=f&65535;h=c[2443776]|0;i=c[h+68+(g>>>8<<2)>>2]|0;do{if((i|0)==0){j=c[h+3168>>2]|0;if((j|0)==0){k=0;l=h;break}m=gj[j&4095](f)|0;k=m;l=c[2443776]|0}else{k=a[i+(g&255)|0]|0;l=h}}while(0);a[9660968]=k;k=(c[2440596]|0)-1|0;c[2440596]=k;h=c[2415242]|0;g=h&65535;i=c[l+68+((h>>>8&255)<<2)>>2]|0;f=h&255;do{if((i|0)==0){m=c[l+3148>>2]|0;if((m|0)==0){n=0;o=k;p=f;q=l;break}j=gj[m&4095](g)|0;n=j;o=c[2440596]|0;p=a[9660968]|0;q=c[2443776]|0}else{n=a[i+(h&255)|0]|0;o=k;p=f;q=l}}while(0);a[9660972]=n;n=o-1|0;c[2440596]=n;a[9660968]=p+1&255;p=c[2415242]|0;o=p&65535;l=c[q+68+((p>>>8&255)<<2)>>2]|0;do{if((l|0)==0){f=c[q+3148>>2]|0;if((f|0)==0){r=0;s=n;t=q;break}k=gj[f&4095](o)|0;r=k;s=c[2440596]|0;t=c[2443776]|0}else{r=a[l+(p&255)|0]|0;s=n;t=q}}while(0);a[9660973]=r;r=s-1|0;c[2440596]=r;s=(b[4830480]|0)-1&65535;do{if((c[t+68+((s&65535)>>>8<<2)>>2]|0)==0){q=c[t+3148>>2]|0;if((q|0)==0){u=r;v=t;break}gj[q&4095](s)|0;u=c[2440596]|0;v=c[2443776]|0}else{u=r;v=t}}while(0);t=u-1|0;c[2440596]=t;b[4830486]=(b[4830486]|0)+(d[9660978]|0)&65535;u=c[2415243]|0;r=c[v+68+((u>>>8&255|256)<<2)>>2]|0;if((r|0)!=0){a[r+(u&255)|0]=e;w=t;x=w-1|0;c[2440596]=x;return}r=c[v+3160>>2]|0;if((r|0)==0){w=t;x=w-1|0;c[2440596]=x;return}gg[r&4095](u&65535,e);w=c[2440596]|0;x=w-1|0;c[2440596]=x;return}function fXX(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;d=f&255;do{if((g|0)==0){k=c[j+3148>>2]|0;if((k|0)==0){l=0;m=i;n=d;o=j;break}h=gj[k&4095](e)|0;l=h;m=c[2440596]|0;n=a[9660968]|0;o=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=d;o=j}}while(0);a[9660972]=l;j=m-1|0;c[2440596]=j;a[9660968]=n+1&255;n=c[2415242]|0;m=n&65535;d=c[o+68+((n>>>8&255)<<2)>>2]|0;do{if((d|0)==0){i=c[o+3148>>2]|0;if((i|0)==0){p=0;q=j;r=l;break}f=gj[i&4095](m)|0;p=f;q=c[2440596]|0;r=a[9660972]|0}else{p=a[d+(n&255)|0]|0;q=j;r=l}}while(0);a[9660973]=p;p=q-1|0;c[2440596]=p;q=a[9660978]|0;if(((q&255)+(r&255)|0)>255){r=(b[4830480]|0)-1&65535;l=c[2443776]|0;do{if((c[l+68+((r&65535)>>>8<<2)>>2]|0)==0){j=c[l+3148>>2]|0;if((j|0)==0){s=p;t=q;break}gj[j&4095](r)|0;s=c[2440596]|0;t=a[9660978]|0}else{s=p;t=q}}while(0);r=s-1|0;c[2440596]=r;u=t;v=r}else{u=q;v=p}b[4830486]=(b[4830486]|0)+(u&255)&65535;u=c[2415243]|0;p=c[2443776]|0;q=c[p+68+((u>>>8&255)<<2)>>2]|0;if((q|0)!=0){w=a[q+(u&255)|0]|0;x=v;y=x-1|0;c[2440596]=y;a[9660976]=w;z=w<<24>>24==0;A=a[9660979]|0;B=A&125;C=w&-128;D=z?2:C;E=B|D;a[9660979]=E;return}q=c[p+3156>>2]|0;if((q|0)==0){w=0;x=v;y=x-1|0;c[2440596]=y;a[9660976]=w;z=w<<24>>24==0;A=a[9660979]|0;B=A&125;C=w&-128;D=z?2:C;E=B|D;a[9660979]=E;return}v=gj[q&4095](u&65535)|0;w=v;x=c[2440596]|0;y=x-1|0;c[2440596]=y;a[9660976]=w;z=w<<24>>24==0;A=a[9660979]|0;B=A&125;C=w&-128;D=z?2:C;E=B|D;a[9660979]=E;return}function fXY(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;d=f&255;do{if((g|0)==0){k=c[j+3148>>2]|0;if((k|0)==0){l=0;m=i;n=d;o=j;break}h=gj[k&4095](e)|0;l=h;m=c[2440596]|0;n=a[9660968]|0;o=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=d;o=j}}while(0);a[9660972]=l;j=m-1|0;c[2440596]=j;a[9660968]=n+1&255;n=c[2415242]|0;m=n&65535;d=c[o+68+((n>>>8&255)<<2)>>2]|0;do{if((d|0)==0){i=c[o+3148>>2]|0;if((i|0)==0){p=0;q=j;r=l;break}f=gj[i&4095](m)|0;p=f;q=c[2440596]|0;r=a[9660972]|0}else{p=a[d+(n&255)|0]|0;q=j;r=l}}while(0);a[9660973]=p;p=q-1|0;c[2440596]=p;q=a[9660978]|0;if(((q&255)+(r&255)|0)>255){r=(b[4830480]|0)-1&65535;l=c[2443776]|0;do{if((c[l+68+((r&65535)>>>8<<2)>>2]|0)==0){j=c[l+3148>>2]|0;if((j|0)==0){s=p;t=q;break}gj[j&4095](r)|0;s=c[2440596]|0;t=a[9660978]|0}else{s=p;t=q}}while(0);r=s-1|0;c[2440596]=r;u=t;v=r}else{u=q;v=p}b[4830486]=(b[4830486]|0)+(u&255)&65535;u=c[2415243]|0;p=u&65535;q=c[2443776]|0;r=c[q+68+((u>>>8&255)<<2)>>2]|0;do{if((r|0)==0){t=c[q+3156>>2]|0;if((t|0)==0){w=0;x=v;break}s=gj[t&4095](p)|0;w=s;x=c[2440596]|0}else{w=a[r+(u&255)|0]|0;x=v}}while(0);c[2440596]=x-1;x=a[9660979]|0;v=x&-2;a[9660979]=v;u=a[9660976]|0;if((u&255)<(w&255)){y=v}else{v=x|1;a[9660979]=v;y=v}if(u<<24>>24==w<<24>>24){z=y&125|2;a[9660979]=z;return}else{z=y&125|u-w&255&-128;a[9660979]=z;return}}function fXZ(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;d=f&255;do{if((g|0)==0){k=c[j+3148>>2]|0;if((k|0)==0){l=0;m=i;n=d;o=j;break}h=gj[k&4095](e)|0;l=h;m=c[2440596]|0;n=a[9660968]|0;o=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=d;o=j}}while(0);a[9660972]=l;j=m-1|0;c[2440596]=j;a[9660968]=n+1&255;n=c[2415242]|0;m=n&65535;d=c[o+68+((n>>>8&255)<<2)>>2]|0;do{if((d|0)==0){i=c[o+3148>>2]|0;if((i|0)==0){p=0;q=j;r=l;break}f=gj[i&4095](m)|0;p=f;q=c[2440596]|0;r=a[9660972]|0}else{p=a[d+(n&255)|0]|0;q=j;r=l}}while(0);a[9660973]=p;p=q-1|0;c[2440596]=p;q=a[9660978]|0;if(((q&255)+(r&255)|0)>255){r=(b[4830480]|0)-1&65535;l=c[2443776]|0;do{if((c[l+68+((r&65535)>>>8<<2)>>2]|0)==0){j=c[l+3148>>2]|0;if((j|0)==0){s=p;t=q;break}gj[j&4095](r)|0;s=c[2440596]|0;t=a[9660978]|0}else{s=p;t=q}}while(0);r=s-1|0;c[2440596]=r;u=t;v=r}else{u=q;v=p}b[4830486]=(b[4830486]|0)+(u&255)&65535;u=c[2415243]|0;p=u&65535;q=c[2443776]|0;r=c[q+68+((u>>>8&255)<<2)>>2]|0;do{if((r|0)==0){t=c[q+3156>>2]|0;if((t|0)==0){w=0;x=v;break}s=gj[t&4095](p)|0;w=s;x=c[2440596]|0}else{w=a[r+(u&255)|0]|0;x=v}}while(0);v=w&255;u=x-1|0;c[2440596]=u;x=a[9660979]|0;r=x&255;p=r&1^1;q=a[9660976]|0;s=q&255;t=s-v-p|0;if((r&8|0)==0){r=x&-66;l=(((q^w)&128&(t^s)|0)==0?r:r|64)|(t&65280|0)==0;a[9660979]=l;r=t&255;a[9660976]=r;y=r;z=l;A=y<<24>>24==0;B=z&125;C=y&-128;D=A?2:C;E=D|B;a[9660979]=E;return}l=(s&15)-(v&15)-p|0;p=(s&240)-(v&240)|0;v=x&-66;x=(l&240|0)==0?l:l-6|0;l=(x&128|0)==0?p:p-16|0;p=(((q^w)&128&(t^s)|0)==0?v:v|64)|(t&65280|0)==0;a[9660979]=p;t=(((l&3840|0)==0?l:l+160|0)&240|x&15)&255;a[9660976]=t;x=(b[4830480]|0)-1&65535;l=c[2443776]|0;do{if((c[l+68+((x&65535)>>>8<<2)>>2]|0)==0){v=c[l+3148>>2]|0;if((v|0)==0){F=u;G=t;H=p;break}gj[v&4095](x)|0;F=c[2440596]|0;G=a[9660976]|0;H=a[9660979]|0}else{F=u;G=t;H=p}}while(0);c[2440596]=F-1;y=G;z=H;A=y<<24>>24==0;B=z&125;C=y&-128;D=A?2:C;E=D|B;a[9660979]=E;return}function fX_(){var a=0,d=0,e=0;a=b[4830480]|0;b[4830480]=a+1&65535;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3168>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function fX$(){var a=0,d=0,e=0;a=b[4830480]|0;b[4830480]=a+1&65535;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3168>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function fX0(){var a=0,d=0,e=0;a=b[4830480]|0;b[4830480]=a+1&65535;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3168>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function fX1(){var a=0,d=0,e=0;a=b[4830480]|0;b[4830480]=a+1&65535;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3168>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function fX2(){var a=0,d=0,e=0;a=b[4830480]|0;b[4830480]=a+1&65535;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3168>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function fX3(){var d=0,e=0,f=0,g=0,h=0,i=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(e&255)|0]|0}}while(0);c[2440596]=(c[2440596]|0)-1;a[9660977]=i;a[9660979]=a[9660979]&125|(i<<24>>24==0?2:i&-128);return}function fX4(){var a=0,d=0,e=0;a=b[4830480]|0;b[4830480]=a+1&65535;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3168>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function fX5(){var a=0,d=0,e=0;a=b[4830480]|0;b[4830480]=a+1&65535;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3168>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function fX6(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;d=f&255;do{if((g|0)==0){k=c[j+3148>>2]|0;if((k|0)==0){l=0;m=i;n=d;o=j;break}h=gj[k&4095](e)|0;l=h;m=c[2440596]|0;n=a[9660968]|0;o=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=d;o=j}}while(0);a[9660972]=l;l=m-1|0;c[2440596]=l;a[9660968]=n+1&255;n=c[2415242]|0;m=n&65535;j=c[o+68+((n>>>8&255)<<2)>>2]|0;do{if((j|0)==0){d=c[o+3148>>2]|0;if((d|0)==0){p=0;q=l;r=o;break}i=gj[d&4095](m)|0;p=i;q=c[2440596]|0;r=c[2443776]|0}else{p=a[j+(n&255)|0]|0;q=l;r=o}}while(0);a[9660973]=p;p=q-1|0;c[2440596]=p;q=c[2415243]|0;o=q&65535;l=c[r+68+((q>>>8&255)<<2)>>2]|0;do{if((l|0)==0){n=c[r+3148>>2]|0;if((n|0)==0){s=0;t=p;break}j=gj[n&4095](o)|0;s=j;t=c[2440596]|0}else{s=a[l+(q&255)|0]|0;t=p}}while(0);c[2440596]=t-1;t=a[9660976]|s;a[9660976]=t;a[9660979]=(t<<24>>24==0?2:t&-128)|a[9660979]&125;return}function fX7(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;d=f&255;do{if((g|0)==0){k=c[j+3148>>2]|0;if((k|0)==0){l=0;m=i;n=d;o=j;break}h=gj[k&4095](e)|0;l=h;m=c[2440596]|0;n=a[9660968]|0;o=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=d;o=j}}while(0);a[9660972]=l;l=m-1|0;c[2440596]=l;a[9660968]=n+1&255;n=c[2415242]|0;m=n&65535;j=c[o+68+((n>>>8&255)<<2)>>2]|0;do{if((j|0)==0){d=c[o+3148>>2]|0;if((d|0)==0){p=0;q=l;r=o;break}i=gj[d&4095](m)|0;p=i;q=c[2440596]|0;r=c[2443776]|0}else{p=a[j+(n&255)|0]|0;q=l;r=o}}while(0);a[9660973]=p;p=q-1|0;c[2440596]=p;q=c[2415243]|0;o=q&65535;l=c[r+68+((q>>>8&255)<<2)>>2]|0;do{if((l|0)==0){n=c[r+3148>>2]|0;if((n|0)==0){s=0;t=p;break}j=gj[n&4095](o)|0;s=j;t=c[2440596]|0}else{s=a[l+(q&255)|0]|0;t=p}}while(0);c[2440596]=t-1;t=a[9660976]&s;a[9660976]=t;a[9660979]=(t<<24>>24==0?2:t&-128)|a[9660979]&125;return}function fX8(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;d=f&255;do{if((g|0)==0){k=c[j+3148>>2]|0;if((k|0)==0){l=0;m=i;n=d;o=j;break}h=gj[k&4095](e)|0;l=h;m=c[2440596]|0;n=a[9660968]|0;o=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=d;o=j}}while(0);a[9660972]=l;l=m-1|0;c[2440596]=l;a[9660968]=n+1&255;n=c[2415242]|0;m=n&65535;j=c[o+68+((n>>>8&255)<<2)>>2]|0;do{if((j|0)==0){d=c[o+3148>>2]|0;if((d|0)==0){p=0;q=l;r=o;break}i=gj[d&4095](m)|0;p=i;q=c[2440596]|0;r=c[2443776]|0}else{p=a[j+(n&255)|0]|0;q=l;r=o}}while(0);a[9660973]=p;p=q-1|0;c[2440596]=p;q=c[2415243]|0;o=q&65535;l=c[r+68+((q>>>8&255)<<2)>>2]|0;do{if((l|0)==0){n=c[r+3148>>2]|0;if((n|0)==0){s=0;t=p;break}j=gj[n&4095](o)|0;s=j;t=c[2440596]|0}else{s=a[l+(q&255)|0]|0;t=p}}while(0);c[2440596]=t-1;t=a[9660976]|0;p=t^s;a[9660976]=p;a[9660979]=(t<<24>>24==s<<24>>24?2:p&-128)|a[9660979]&125;return}function fX9(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;d=f&255;do{if((g|0)==0){k=c[j+3148>>2]|0;if((k|0)==0){l=0;m=i;n=d;o=j;break}h=gj[k&4095](e)|0;l=h;m=c[2440596]|0;n=a[9660968]|0;o=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=d;o=j}}while(0);a[9660972]=l;l=m-1|0;c[2440596]=l;a[9660968]=n+1&255;n=c[2415242]|0;m=n&65535;j=c[o+68+((n>>>8&255)<<2)>>2]|0;do{if((j|0)==0){d=c[o+3148>>2]|0;if((d|0)==0){p=0;q=l;r=o;break}i=gj[d&4095](m)|0;p=i;q=c[2440596]|0;r=c[2443776]|0}else{p=a[j+(n&255)|0]|0;q=l;r=o}}while(0);a[9660973]=p;p=q-1|0;c[2440596]=p;q=c[2415243]|0;o=q&65535;l=c[r+68+((q>>>8&255)<<2)>>2]|0;do{if((l|0)==0){n=c[r+3148>>2]|0;if((n|0)==0){s=0;t=p;break}j=gj[n&4095](o)|0;s=j;t=c[2440596]|0}else{s=a[l+(q&255)|0]|0;t=p}}while(0);p=s&255;q=t-1|0;c[2440596]=q;t=a[9660979]|0;l=t&255;o=l&1;r=a[9660976]|0;j=r&255;if((l&8|0)==0){l=j+p+o|0;n=t&-66;m=((((r^s)&128^128)&(l^j)|0)==0?n:n|64)|(l&65280|0)!=0;a[9660979]=m;n=l&255;a[9660976]=n;u=n;v=m;w=u<<24>>24==0;x=v&125;y=u&-128;z=w?2:y;A=z|x;a[9660979]=A;return}m=o+(p&15)+(j&15)|0;o=(j&240)+(p&240)|0;p=t&-66;a[9660979]=p;if((m|0)>9){B=m+6|0;C=o+16|0}else{B=m;C=o}if((((r^s)&128^128)&(C^j)|0)==0){D=p}else{j=p|64;a[9660979]=j;D=j}j=(C|0)>144?C+96|0:C;if((j&65280|0)==0){E=D}else{C=D|1;a[9660979]=C;E=C}C=(j&240|B&15)&255;a[9660976]=C;B=(b[4830480]|0)-1&65535;j=c[2443776]|0;do{if((c[j+68+((B&65535)>>>8<<2)>>2]|0)==0){D=c[j+3148>>2]|0;if((D|0)==0){F=q;G=C;H=E;break}gj[D&4095](B)|0;F=c[2440596]|0;G=a[9660976]|0;H=a[9660979]|0}else{F=q;G=C;H=E}}while(0);c[2440596]=F-1;u=G;v=H;w=u<<24>>24==0;x=v&125;y=u&-128;z=w?2:y;A=z|x;a[9660979]=A;return}function fYa(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;d=a[9660976]|0;e=b[4830480]|0;b[4830480]=e+1&65535;f=e&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](e)|0;j=l;k=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=g}}while(0);a[9660968]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;g=c[2415242]|0;f=g&65535;h=c[k+68+((g>>>8&255)<<2)>>2]|0;e=g&255;do{if((h|0)==0){l=c[k+3148>>2]|0;if((l|0)==0){m=0;n=j;o=e;p=k;break}i=gj[l&4095](f)|0;m=i;n=c[2440596]|0;o=a[9660968]|0;p=c[2443776]|0}else{m=a[h+(g&255)|0]|0;n=j;o=e;p=k}}while(0);a[9660972]=m;m=n-1|0;c[2440596]=m;a[9660968]=o+1&255;o=c[2415242]|0;n=o&65535;k=c[p+68+((o>>>8&255)<<2)>>2]|0;do{if((k|0)==0){e=c[p+3148>>2]|0;if((e|0)==0){q=0;r=m;s=p;break}j=gj[e&4095](n)|0;q=j;r=c[2440596]|0;s=c[2443776]|0}else{q=a[k+(o&255)|0]|0;r=m;s=p}}while(0);a[9660973]=q;q=r-1|0;c[2440596]=q;r=c[2415243]|0;p=c[s+68+((r>>>8&255|256)<<2)>>2]|0;if((p|0)!=0){a[p+(r&255)|0]=d;t=q;u=t-1|0;c[2440596]=u;return}p=c[s+3152>>2]|0;if((p|0)==0){t=q;u=t-1|0;c[2440596]=u;return}gg[p&4095](r&65535,d);t=c[2440596]|0;u=t-1|0;c[2440596]=u;return}function fYb(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;d=f&255;do{if((g|0)==0){k=c[j+3148>>2]|0;if((k|0)==0){l=0;m=i;n=d;o=j;break}h=gj[k&4095](e)|0;l=h;m=c[2440596]|0;n=a[9660968]|0;o=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=d;o=j}}while(0);a[9660972]=l;l=m-1|0;c[2440596]=l;a[9660968]=n+1&255;n=c[2415242]|0;m=n&65535;j=c[o+68+((n>>>8&255)<<2)>>2]|0;do{if((j|0)==0){d=c[o+3148>>2]|0;if((d|0)==0){p=0;q=l;r=o;break}i=gj[d&4095](m)|0;p=i;q=c[2440596]|0;r=c[2443776]|0}else{p=a[j+(n&255)|0]|0;q=l;r=o}}while(0);a[9660973]=p;p=q-1|0;c[2440596]=p;q=c[2415243]|0;o=q&65535;l=c[r+68+((q>>>8&255)<<2)>>2]|0;do{if((l|0)==0){n=c[r+3148>>2]|0;if((n|0)==0){s=0;t=p;break}j=gj[n&4095](o)|0;s=j;t=c[2440596]|0}else{s=a[l+(q&255)|0]|0;t=p}}while(0);c[2440596]=t-1;a[9660976]=s;a[9660979]=a[9660979]&125|(s<<24>>24==0?2:s&-128);return}function fYc(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;d=f&255;do{if((g|0)==0){k=c[j+3148>>2]|0;if((k|0)==0){l=0;m=i;n=d;o=j;break}h=gj[k&4095](e)|0;l=h;m=c[2440596]|0;n=a[9660968]|0;o=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=d;o=j}}while(0);a[9660972]=l;l=m-1|0;c[2440596]=l;a[9660968]=n+1&255;n=c[2415242]|0;m=n&65535;j=c[o+68+((n>>>8&255)<<2)>>2]|0;do{if((j|0)==0){d=c[o+3148>>2]|0;if((d|0)==0){p=0;q=l;r=o;break}i=gj[d&4095](m)|0;p=i;q=c[2440596]|0;r=c[2443776]|0}else{p=a[j+(n&255)|0]|0;q=l;r=o}}while(0);a[9660973]=p;p=q-1|0;c[2440596]=p;q=c[2415243]|0;o=q&65535;l=c[r+68+((q>>>8&255)<<2)>>2]|0;do{if((l|0)==0){n=c[r+3148>>2]|0;if((n|0)==0){s=0;t=p;break}j=gj[n&4095](o)|0;s=j;t=c[2440596]|0}else{s=a[l+(q&255)|0]|0;t=p}}while(0);c[2440596]=t-1;t=a[9660979]|0;p=t&-2;a[9660979]=p;q=a[9660976]|0;if((q&255)<(s&255)){u=p}else{p=t|1;a[9660979]=p;u=p}if(q<<24>>24==s<<24>>24){v=u&125|2;a[9660979]=v;return}else{v=u&125|q-s&255&-128;a[9660979]=v;return}}function fYd(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;d=f&255;do{if((g|0)==0){k=c[j+3148>>2]|0;if((k|0)==0){l=0;m=i;n=d;o=j;break}h=gj[k&4095](e)|0;l=h;m=c[2440596]|0;n=a[9660968]|0;o=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=d;o=j}}while(0);a[9660972]=l;l=m-1|0;c[2440596]=l;a[9660968]=n+1&255;n=c[2415242]|0;m=n&65535;j=c[o+68+((n>>>8&255)<<2)>>2]|0;do{if((j|0)==0){d=c[o+3148>>2]|0;if((d|0)==0){p=0;q=l;r=o;break}i=gj[d&4095](m)|0;p=i;q=c[2440596]|0;r=c[2443776]|0}else{p=a[j+(n&255)|0]|0;q=l;r=o}}while(0);a[9660973]=p;p=q-1|0;c[2440596]=p;q=c[2415243]|0;o=q&65535;l=c[r+68+((q>>>8&255)<<2)>>2]|0;do{if((l|0)==0){n=c[r+3148>>2]|0;if((n|0)==0){s=0;t=p;break}j=gj[n&4095](o)|0;s=j;t=c[2440596]|0}else{s=a[l+(q&255)|0]|0;t=p}}while(0);p=s&255;q=t-1|0;c[2440596]=q;t=a[9660979]|0;l=t&255;o=l&1^1;r=a[9660976]|0;j=r&255;n=j-p-o|0;if((l&8|0)==0){l=t&-66;m=(((r^s)&128&(n^j)|0)==0?l:l|64)|(n&65280|0)==0;a[9660979]=m;l=n&255;a[9660976]=l;u=l;v=m;w=u<<24>>24==0;x=v&125;y=u&-128;z=w?2:y;A=z|x;a[9660979]=A;return}m=(j&15)-(p&15)-o|0;o=(j&240)-(p&240)|0;p=t&-66;t=(m&240|0)==0?m:m-6|0;m=(t&128|0)==0?o:o-16|0;o=(((r^s)&128&(n^j)|0)==0?p:p|64)|(n&65280|0)==0;a[9660979]=o;n=(((m&3840|0)==0?m:m+160|0)&240|t&15)&255;a[9660976]=n;t=(b[4830480]|0)-1&65535;m=c[2443776]|0;do{if((c[m+68+((t&65535)>>>8<<2)>>2]|0)==0){p=c[m+3148>>2]|0;if((p|0)==0){B=q;C=n;D=o;break}gj[p&4095](t)|0;B=c[2440596]|0;C=a[9660976]|0;D=a[9660979]|0}else{B=q;C=n;D=o}}while(0);c[2440596]=B-1;u=C;v=D;w=u<<24>>24==0;x=v&125;y=u&-128;z=w?2:y;A=z|x;a[9660979]=A;return}function fYe(){return}function fYf(){return}function fYg(){return}function fYh(){return}function fYi(){return}function fYj(){return}function fYk(){return}function fYl(){return}function fYm(){return}function fYn(){return}function fYo(){return}function fYp(){return}function fYq(){return}function fYr(){return}function fYs(){return}function fYt(){return}function fYu(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=0;m=i;n=f;o=j;break}k=gj[d&4095](e)|0;l=k;m=c[2440596]|0;n=c[2415243]|0;o=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=f;o=j}}while(0);j=m-1|0;c[2440596]=j;m=n&65535;do{if((c[o+68+((n>>>8&255)<<2)>>2]|0)==0){f=c[o+3148>>2]|0;if((f|0)==0){p=j;q=n;r=o;break}gj[f&4095](m)|0;p=c[2440596]|0;q=c[2415243]|0;r=c[2443776]|0}else{p=j;q=n;r=o}}while(0);o=p-1|0;c[2440596]=o;p=a[9660976]|0;n=a[9660979]|0;a[9660979]=(p&l)<<24>>24==0?n|2:n&-3;n=p|l;l=c[r+68+((q>>>8&255|256)<<2)>>2]|0;if((l|0)!=0){a[l+(q&255)|0]=n;s=o;t=s-1|0;c[2440596]=t;return}l=c[r+3152>>2]|0;if((l|0)==0){s=o;t=s-1|0;c[2440596]=t;return}gg[l&4095](q&65535,n);s=c[2440596]|0;t=s-1|0;c[2440596]=t;return}function fYv(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=0;m=i;break}k=gj[d&4095](e)|0;l=k;m=c[2440596]|0}else{l=a[g+(f&255)|0]|0;m=i}}while(0);c[2440596]=m-1;m=a[9660979]&61|l&-64;a[9660979]=m;if((a[9660976]&l)<<24>>24!=0){return}a[9660979]=m|2;return}function fYw(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;if((c[j+68+((f>>>8&255)<<2)>>2]|0)!=0){l=i;m=l-1|0;c[2440596]=m;return}e=c[j+3148>>2]|0;if((e|0)==0){l=i;m=l-1|0;c[2440596]=m;return}gj[e&4095](f&65535)|0;l=c[2440596]|0;m=l-1|0;c[2440596]=m;return}function fYx(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=c[j+68+((f>>>8&255|256)<<2)>>2]|0;if((e|0)!=0){a[e+(f&255)|0]=0;l=i;m=l-1|0;c[2440596]=m;return}e=c[j+3152>>2]|0;if((e|0)==0){l=i;m=l-1|0;c[2440596]=m;return}gg[e&4095](f&65535,0);l=c[2440596]|0;m=l-1|0;c[2440596]=m;return}function fYy(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=a[9660978]|0;e=b[4830480]|0;b[4830480]=e+1&65535;f=e&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](e)|0;j=l;k=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=g}}while(0);a[9660968]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;g=c[2415242]|0;c[2415243]=g;f=c[k+68+((g>>>8&255|256)<<2)>>2]|0;if((f|0)!=0){a[f+(g&255)|0]=d;m=j;n=m-1|0;c[2440596]=n;return}f=c[k+3152>>2]|0;if((f|0)==0){m=j;n=m-1|0;c[2440596]=n;return}gg[f&4095](g&65535,d);m=c[2440596]|0;n=m-1|0;c[2440596]=n;return}function fYz(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=0;m=i;break}k=gj[d&4095](e)|0;l=k;m=c[2440596]|0}else{l=a[g+(f&255)|0]|0;m=i}}while(0);c[2440596]=m-1;a[9660978]=l;a[9660979]=a[9660979]&125|(l<<24>>24==0?2:l&-128);return}function fYA(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=0;m=i;break}k=gj[d&4095](e)|0;l=k;m=c[2440596]|0}else{l=a[g+(f&255)|0]|0;m=i}}while(0);c[2440596]=m-1;m=a[9660979]|0;i=m&-2;a[9660979]=i;f=a[9660978]|0;if((f&255)<(l&255)){n=i}else{i=m|1;a[9660979]=i;n=i}if(f<<24>>24==l<<24>>24){o=n&125|2;a[9660979]=o;return}else{o=n&125|f-l&255&-128;a[9660979]=o;return}}function fYB(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=0;m=i;break}k=gj[d&4095](e)|0;l=k;m=c[2440596]|0}else{l=a[g+(f&255)|0]|0;m=i}}while(0);c[2440596]=m-1;m=a[9660979]|0;i=m&-2;a[9660979]=i;f=a[9660977]|0;if((f&255)<(l&255)){n=i}else{i=m|1;a[9660979]=i;n=i}if(f<<24>>24==l<<24>>24){o=n&125|2;a[9660979]=o;return}else{o=n&125|f-l&255&-128;a[9660979]=o;return}}function fYC(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=0;m=i;n=f;o=j;break}k=gj[d&4095](e)|0;l=k;m=c[2440596]|0;n=c[2415243]|0;o=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=f;o=j}}while(0);j=m-1|0;c[2440596]=j;m=n&65535;do{if((c[o+68+((n>>>8&255)<<2)>>2]|0)==0){f=c[o+3148>>2]|0;if((f|0)==0){p=j;q=n;r=o;break}gj[f&4095](m)|0;p=c[2440596]|0;q=c[2415243]|0;r=c[2443776]|0}else{p=j;q=n;r=o}}while(0);o=p-1|0;c[2440596]=o;p=a[9660976]|0;n=a[9660979]|0;a[9660979]=(p&l)<<24>>24==0?n|2:n&-3;n=l&~p;p=c[r+68+((q>>>8&255|256)<<2)>>2]|0;if((p|0)!=0){a[p+(q&255)|0]=n;s=o;t=s-1|0;c[2440596]=t;return}p=c[r+3152>>2]|0;if((p|0)==0){s=o;t=s-1|0;c[2440596]=t;return}gg[p&4095](q&65535,n);s=c[2440596]|0;t=s-1|0;c[2440596]=t;return}function fYD(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=f&255;do{if((c[j+68+((f>>>8&255)<<2)>>2]|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=i;m=g;n=j;break}gj[d&4095](e)|0;l=c[2440596]|0;m=a[9660968]|0;n=c[2443776]|0}else{l=i;m=g;n=j}}while(0);j=l-1|0;c[2440596]=j;a[9660968]=m+(a[9660977]|0)&255;m=c[2415242]|0;c[2415243]=m;l=m&65535;g=c[n+68+((m>>>8&255)<<2)>>2]|0;do{if((g|0)==0){i=c[n+3148>>2]|0;if((i|0)==0){o=0;p=j;break}e=gj[i&4095](l)|0;o=e;p=c[2440596]|0}else{o=a[g+(m&255)|0]|0;p=j}}while(0);c[2440596]=p-1;p=a[9660979]&61|o&-64;a[9660979]=p;if((a[9660976]&o)<<24>>24!=0){return}a[9660979]=p|2;return}function fYE(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=f&255;do{if((c[j+68+((f>>>8&255)<<2)>>2]|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=i;m=g;n=j;break}gj[d&4095](e)|0;l=c[2440596]|0;m=a[9660968]|0;n=c[2443776]|0}else{l=i;m=g;n=j}}while(0);j=l-1|0;c[2440596]=j;a[9660968]=m+(a[9660977]|0)&255;m=c[2415242]|0;c[2415243]=m;if((c[n+68+((m>>>8&255)<<2)>>2]|0)!=0){o=j;p=o-1|0;c[2440596]=p;return}l=c[n+3148>>2]|0;if((l|0)==0){o=j;p=o-1|0;c[2440596]=p;return}gj[l&4095](m&65535)|0;o=c[2440596]|0;p=o-1|0;c[2440596]=p;return}function fYF(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=f&255;do{if((c[j+68+((f>>>8&255)<<2)>>2]|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=i;m=g;n=j;break}gj[d&4095](e)|0;l=c[2440596]|0;m=a[9660968]|0;n=c[2443776]|0}else{l=i;m=g;n=j}}while(0);j=l-1|0;c[2440596]=j;a[9660968]=m+(a[9660977]|0)&255;m=c[2415242]|0;c[2415243]=m;l=c[n+68+((m>>>8&255|256)<<2)>>2]|0;if((l|0)!=0){a[l+(m&255)|0]=0;o=j;p=o-1|0;c[2440596]=p;return}l=c[n+3152>>2]|0;if((l|0)==0){o=j;p=o-1|0;c[2440596]=p;return}gg[l&4095](m&65535,0);o=c[2440596]|0;p=o-1|0;c[2440596]=p;return}function fYG(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=a[9660978]|0;e=b[4830480]|0;b[4830480]=e+1&65535;f=e&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](e)|0;j=l;k=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=g}}while(0);a[9660968]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;g=c[2415242]|0;f=g&65535;h=g&255;do{if((c[k+68+((g>>>8&255)<<2)>>2]|0)==0){e=c[k+3148>>2]|0;if((e|0)==0){m=j;n=h;o=k;break}gj[e&4095](f)|0;m=c[2440596]|0;n=a[9660968]|0;o=c[2443776]|0}else{m=j;n=h;o=k}}while(0);k=m-1|0;c[2440596]=k;a[9660968]=n+(a[9660977]|0)&255;n=c[2415242]|0;c[2415243]=n;m=c[o+68+((n>>>8&255|256)<<2)>>2]|0;if((m|0)!=0){a[m+(n&255)|0]=d;p=k;q=p-1|0;c[2440596]=q;return}m=c[o+3152>>2]|0;if((m|0)==0){p=k;q=p-1|0;c[2440596]=q;return}gg[m&4095](n&65535,d);p=c[2440596]|0;q=p-1|0;c[2440596]=q;return}function fYH(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=f&255;do{if((c[j+68+((f>>>8&255)<<2)>>2]|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=i;m=g;n=j;break}gj[d&4095](e)|0;l=c[2440596]|0;m=a[9660968]|0;n=c[2443776]|0}else{l=i;m=g;n=j}}while(0);j=l-1|0;c[2440596]=j;a[9660968]=m+(a[9660977]|0)&255;m=c[2415242]|0;c[2415243]=m;l=m&65535;g=c[n+68+((m>>>8&255)<<2)>>2]|0;do{if((g|0)==0){i=c[n+3148>>2]|0;if((i|0)==0){o=0;p=j;break}e=gj[i&4095](l)|0;o=e;p=c[2440596]|0}else{o=a[g+(m&255)|0]|0;p=j}}while(0);c[2440596]=p-1;a[9660978]=o;a[9660979]=a[9660979]&125|(o<<24>>24==0?2:o&-128);return}function fYI(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=f&255;do{if((c[j+68+((f>>>8&255)<<2)>>2]|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=i;m=g;n=j;break}gj[d&4095](e)|0;l=c[2440596]|0;m=a[9660968]|0;n=c[2443776]|0}else{l=i;m=g;n=j}}while(0);j=l-1|0;c[2440596]=j;a[9660968]=m+(a[9660977]|0)&255;m=c[2415242]|0;c[2415243]=m;if((c[n+68+((m>>>8&255)<<2)>>2]|0)!=0){o=j;p=o-1|0;c[2440596]=p;return}l=c[n+3148>>2]|0;if((l|0)==0){o=j;p=o-1|0;c[2440596]=p;return}gj[l&4095](m&65535)|0;o=c[2440596]|0;p=o-1|0;c[2440596]=p;return}function fYJ(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=f&255;do{if((c[j+68+((f>>>8&255)<<2)>>2]|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=i;m=g;n=j;break}gj[d&4095](e)|0;l=c[2440596]|0;m=a[9660968]|0;n=c[2443776]|0}else{l=i;m=g;n=j}}while(0);j=l-1|0;c[2440596]=j;a[9660968]=m+(a[9660977]|0)&255;m=c[2415242]|0;c[2415243]=m;if((c[n+68+((m>>>8&255)<<2)>>2]|0)!=0){o=j;p=o-1|0;c[2440596]=p;return}l=c[n+3148>>2]|0;if((l|0)==0){o=j;p=o-1|0;c[2440596]=p;return}gj[l&4095](m&65535)|0;o=c[2440596]|0;p=o-1|0;c[2440596]=p;return}function fYK(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=0;m=i;break}k=gj[d&4095](e)|0;l=k;m=c[2440596]|0}else{l=a[g+(f&255)|0]|0;m=i}}while(0);c[2440596]=m-1;m=a[9660976]|l;a[9660976]=m;a[9660979]=(m<<24>>24==0?2:m&-128)|a[9660979]&125;return}function fYL(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=0;m=i;break}k=gj[d&4095](e)|0;l=k;m=c[2440596]|0}else{l=a[g+(f&255)|0]|0;m=i}}while(0);c[2440596]=m-1;m=a[9660976]&l;a[9660976]=m;a[9660979]=(m<<24>>24==0?2:m&-128)|a[9660979]&125;return}function fYM(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=0;m=i;break}k=gj[d&4095](e)|0;l=k;m=c[2440596]|0}else{l=a[g+(f&255)|0]|0;m=i}}while(0);c[2440596]=m-1;m=a[9660976]|0;i=m^l;a[9660976]=i;a[9660979]=(m<<24>>24==l<<24>>24?2:i&-128)|a[9660979]&125;return}function fYN(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=0;m=i;break}k=gj[d&4095](e)|0;l=k;m=c[2440596]|0}else{l=a[g+(f&255)|0]|0;m=i}}while(0);i=l&255;f=m-1|0;c[2440596]=f;m=a[9660979]|0;g=m&255;e=g&1;j=a[9660976]|0;k=j&255;if((g&8|0)==0){g=k+i+e|0;d=m&-66;h=((((j^l)&128^128)&(g^k)|0)==0?d:d|64)|(g&65280|0)!=0;a[9660979]=h;d=g&255;a[9660976]=d;n=d;o=h;p=n<<24>>24==0;q=o&125;r=n&-128;s=p?2:r;t=s|q;a[9660979]=t;return}h=e+(i&15)+(k&15)|0;e=(k&240)+(i&240)|0;i=m&-66;a[9660979]=i;if((h|0)>9){u=h+6|0;v=e+16|0}else{u=h;v=e}if((((j^l)&128^128)&(v^k)|0)==0){w=i}else{k=i|64;a[9660979]=k;w=k}k=(v|0)>144?v+96|0:v;if((k&65280|0)==0){x=w}else{v=w|1;a[9660979]=v;x=v}v=(k&240|u&15)&255;a[9660976]=v;u=(b[4830480]|0)-1&65535;k=c[2443776]|0;do{if((c[k+68+((u&65535)>>>8<<2)>>2]|0)==0){w=c[k+3148>>2]|0;if((w|0)==0){y=f;z=v;A=x;break}gj[w&4095](u)|0;y=c[2440596]|0;z=a[9660976]|0;A=a[9660979]|0}else{y=f;z=v;A=x}}while(0);c[2440596]=y-1;n=z;o=A;p=n<<24>>24==0;q=o&125;r=n&-128;s=p?2:r;t=s|q;a[9660979]=t;return}function fYO(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=a[9660976]|0;e=b[4830480]|0;b[4830480]=e+1&65535;f=e&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](e)|0;j=l;k=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=g}}while(0);a[9660968]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;g=c[2415242]|0;c[2415243]=g;f=c[k+68+((g>>>8&255|256)<<2)>>2]|0;if((f|0)!=0){a[f+(g&255)|0]=d;m=j;n=m-1|0;c[2440596]=n;return}f=c[k+3152>>2]|0;if((f|0)==0){m=j;n=m-1|0;c[2440596]=n;return}gg[f&4095](g&65535,d);m=c[2440596]|0;n=m-1|0;c[2440596]=n;return}function fYP(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=0;m=i;break}k=gj[d&4095](e)|0;l=k;m=c[2440596]|0}else{l=a[g+(f&255)|0]|0;m=i}}while(0);c[2440596]=m-1;a[9660976]=l;a[9660979]=a[9660979]&125|(l<<24>>24==0?2:l&-128);return}function fYQ(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=0;m=i;break}k=gj[d&4095](e)|0;l=k;m=c[2440596]|0}else{l=a[g+(f&255)|0]|0;m=i}}while(0);c[2440596]=m-1;m=a[9660979]|0;i=m&-2;a[9660979]=i;f=a[9660976]|0;if((f&255)<(l&255)){n=i}else{i=m|1;a[9660979]=i;n=i}if(f<<24>>24==l<<24>>24){o=n&125|2;a[9660979]=o;return}else{o=n&125|f-l&255&-128;a[9660979]=o;return}}function fYR(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=0;m=i;break}k=gj[d&4095](e)|0;l=k;m=c[2440596]|0}else{l=a[g+(f&255)|0]|0;m=i}}while(0);i=l&255;f=m-1|0;c[2440596]=f;m=a[9660979]|0;g=m&255;e=g&1^1;j=a[9660976]|0;k=j&255;d=k-i-e|0;if((g&8|0)==0){g=m&-66;h=(((j^l)&128&(d^k)|0)==0?g:g|64)|(d&65280|0)==0;a[9660979]=h;g=d&255;a[9660976]=g;n=g;o=h;p=n<<24>>24==0;q=o&125;r=n&-128;s=p?2:r;t=s|q;a[9660979]=t;return}h=(k&15)-(i&15)-e|0;e=(k&240)-(i&240)|0;i=m&-66;m=(h&240|0)==0?h:h-6|0;h=(m&128|0)==0?e:e-16|0;e=(((j^l)&128&(d^k)|0)==0?i:i|64)|(d&65280|0)==0;a[9660979]=e;d=(((h&3840|0)==0?h:h+160|0)&240|m&15)&255;a[9660976]=d;m=(b[4830480]|0)-1&65535;h=c[2443776]|0;do{if((c[h+68+((m&65535)>>>8<<2)>>2]|0)==0){i=c[h+3148>>2]|0;if((i|0)==0){u=f;v=d;w=e;break}gj[i&4095](m)|0;u=c[2440596]|0;v=a[9660976]|0;w=a[9660979]|0}else{u=f;v=d;w=e}}while(0);c[2440596]=u-1;n=v;o=w;p=n<<24>>24==0;q=o&125;r=n&-128;s=p?2:r;t=s|q;a[9660979]=t;return}function fYS(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=f&255;do{if((c[j+68+((f>>>8&255)<<2)>>2]|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=i;m=g;n=j;break}gj[d&4095](e)|0;l=c[2440596]|0;m=a[9660968]|0;n=c[2443776]|0}else{l=i;m=g;n=j}}while(0);j=l-1|0;c[2440596]=j;a[9660968]=m+(a[9660977]|0)&255;m=c[2415242]|0;c[2415243]=m;l=m&65535;g=c[n+68+((m>>>8&255)<<2)>>2]|0;do{if((g|0)==0){i=c[n+3148>>2]|0;if((i|0)==0){o=0;p=j;break}e=gj[i&4095](l)|0;o=e;p=c[2440596]|0}else{o=a[g+(m&255)|0]|0;p=j}}while(0);c[2440596]=p-1;p=a[9660976]|o;a[9660976]=p;a[9660979]=(p<<24>>24==0?2:p&-128)|a[9660979]&125;return}function fYT(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=f&255;do{if((c[j+68+((f>>>8&255)<<2)>>2]|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=i;m=g;n=j;break}gj[d&4095](e)|0;l=c[2440596]|0;m=a[9660968]|0;n=c[2443776]|0}else{l=i;m=g;n=j}}while(0);j=l-1|0;c[2440596]=j;a[9660968]=m+(a[9660977]|0)&255;m=c[2415242]|0;c[2415243]=m;l=m&65535;g=c[n+68+((m>>>8&255)<<2)>>2]|0;do{if((g|0)==0){i=c[n+3148>>2]|0;if((i|0)==0){o=0;p=j;break}e=gj[i&4095](l)|0;o=e;p=c[2440596]|0}else{o=a[g+(m&255)|0]|0;p=j}}while(0);c[2440596]=p-1;p=a[9660976]&o;a[9660976]=p;a[9660979]=(p<<24>>24==0?2:p&-128)|a[9660979]&125;return}function fYU(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=f&255;do{if((c[j+68+((f>>>8&255)<<2)>>2]|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=i;m=g;n=j;break}gj[d&4095](e)|0;l=c[2440596]|0;m=a[9660968]|0;n=c[2443776]|0}else{l=i;m=g;n=j}}while(0);j=l-1|0;c[2440596]=j;a[9660968]=m+(a[9660977]|0)&255;m=c[2415242]|0;c[2415243]=m;l=m&65535;g=c[n+68+((m>>>8&255)<<2)>>2]|0;do{if((g|0)==0){i=c[n+3148>>2]|0;if((i|0)==0){o=0;p=j;break}e=gj[i&4095](l)|0;o=e;p=c[2440596]|0}else{o=a[g+(m&255)|0]|0;p=j}}while(0);c[2440596]=p-1;p=a[9660976]|0;j=p^o;a[9660976]=j;a[9660979]=(p<<24>>24==o<<24>>24?2:j&-128)|a[9660979]&125;return}function fYV(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=f&255;do{if((c[j+68+((f>>>8&255)<<2)>>2]|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=i;m=g;n=j;break}gj[d&4095](e)|0;l=c[2440596]|0;m=a[9660968]|0;n=c[2443776]|0}else{l=i;m=g;n=j}}while(0);j=l-1|0;c[2440596]=j;a[9660968]=m+(a[9660977]|0)&255;m=c[2415242]|0;c[2415243]=m;l=m&65535;g=c[n+68+((m>>>8&255)<<2)>>2]|0;do{if((g|0)==0){i=c[n+3148>>2]|0;if((i|0)==0){o=0;p=j;break}e=gj[i&4095](l)|0;o=e;p=c[2440596]|0}else{o=a[g+(m&255)|0]|0;p=j}}while(0);j=o&255;m=p-1|0;c[2440596]=m;p=a[9660979]|0;g=p&255;l=g&1;n=a[9660976]|0;e=n&255;if((g&8|0)==0){g=e+j+l|0;i=p&-66;f=((((n^o)&128^128)&(g^e)|0)==0?i:i|64)|(g&65280|0)!=0;a[9660979]=f;i=g&255;a[9660976]=i;q=i;r=f;s=q<<24>>24==0;t=r&125;u=q&-128;v=s?2:u;w=v|t;a[9660979]=w;return}f=l+(j&15)+(e&15)|0;l=(e&240)+(j&240)|0;j=p&-66;a[9660979]=j;if((f|0)>9){x=f+6|0;y=l+16|0}else{x=f;y=l}if((((n^o)&128^128)&(y^e)|0)==0){z=j}else{e=j|64;a[9660979]=e;z=e}e=(y|0)>144?y+96|0:y;if((e&65280|0)==0){A=z}else{y=z|1;a[9660979]=y;A=y}y=(e&240|x&15)&255;a[9660976]=y;x=(b[4830480]|0)-1&65535;e=c[2443776]|0;do{if((c[e+68+((x&65535)>>>8<<2)>>2]|0)==0){z=c[e+3148>>2]|0;if((z|0)==0){B=m;C=y;D=A;break}gj[z&4095](x)|0;B=c[2440596]|0;C=a[9660976]|0;D=a[9660979]|0}else{B=m;C=y;D=A}}while(0);c[2440596]=B-1;q=C;r=D;s=q<<24>>24==0;t=r&125;u=q&-128;v=s?2:u;w=v|t;a[9660979]=w;return}function fYW(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=a[9660976]|0;e=b[4830480]|0;b[4830480]=e+1&65535;f=e&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](e)|0;j=l;k=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=g}}while(0);a[9660968]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;g=c[2415242]|0;f=g&65535;h=g&255;do{if((c[k+68+((g>>>8&255)<<2)>>2]|0)==0){e=c[k+3148>>2]|0;if((e|0)==0){m=j;n=h;o=k;break}gj[e&4095](f)|0;m=c[2440596]|0;n=a[9660968]|0;o=c[2443776]|0}else{m=j;n=h;o=k}}while(0);k=m-1|0;c[2440596]=k;a[9660968]=n+(a[9660977]|0)&255;n=c[2415242]|0;c[2415243]=n;m=c[o+68+((n>>>8&255|256)<<2)>>2]|0;if((m|0)!=0){a[m+(n&255)|0]=d;p=k;q=p-1|0;c[2440596]=q;return}m=c[o+3152>>2]|0;if((m|0)==0){p=k;q=p-1|0;c[2440596]=q;return}gg[m&4095](n&65535,d);p=c[2440596]|0;q=p-1|0;c[2440596]=q;return}function fYX(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=f&255;do{if((c[j+68+((f>>>8&255)<<2)>>2]|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=i;m=g;n=j;break}gj[d&4095](e)|0;l=c[2440596]|0;m=a[9660968]|0;n=c[2443776]|0}else{l=i;m=g;n=j}}while(0);j=l-1|0;c[2440596]=j;a[9660968]=m+(a[9660977]|0)&255;m=c[2415242]|0;c[2415243]=m;l=m&65535;g=c[n+68+((m>>>8&255)<<2)>>2]|0;do{if((g|0)==0){i=c[n+3148>>2]|0;if((i|0)==0){o=0;p=j;break}e=gj[i&4095](l)|0;o=e;p=c[2440596]|0}else{o=a[g+(m&255)|0]|0;p=j}}while(0);c[2440596]=p-1;a[9660976]=o;a[9660979]=a[9660979]&125|(o<<24>>24==0?2:o&-128);return}function fYY(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=f&255;do{if((c[j+68+((f>>>8&255)<<2)>>2]|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=i;m=g;n=j;break}gj[d&4095](e)|0;l=c[2440596]|0;m=a[9660968]|0;n=c[2443776]|0}else{l=i;m=g;n=j}}while(0);j=l-1|0;c[2440596]=j;a[9660968]=m+(a[9660977]|0)&255;m=c[2415242]|0;c[2415243]=m;l=m&65535;g=c[n+68+((m>>>8&255)<<2)>>2]|0;do{if((g|0)==0){i=c[n+3148>>2]|0;if((i|0)==0){o=0;p=j;break}e=gj[i&4095](l)|0;o=e;p=c[2440596]|0}else{o=a[g+(m&255)|0]|0;p=j}}while(0);c[2440596]=p-1;p=a[9660979]|0;j=p&-2;a[9660979]=j;m=a[9660976]|0;if((m&255)<(o&255)){q=j}else{j=p|1;a[9660979]=j;q=j}if(m<<24>>24==o<<24>>24){r=q&125|2;a[9660979]=r;return}else{r=q&125|m-o&255&-128;a[9660979]=r;return}}function fYZ(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=f&255;do{if((c[j+68+((f>>>8&255)<<2)>>2]|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=i;m=g;n=j;break}gj[d&4095](e)|0;l=c[2440596]|0;m=a[9660968]|0;n=c[2443776]|0}else{l=i;m=g;n=j}}while(0);j=l-1|0;c[2440596]=j;a[9660968]=m+(a[9660977]|0)&255;m=c[2415242]|0;c[2415243]=m;l=m&65535;g=c[n+68+((m>>>8&255)<<2)>>2]|0;do{if((g|0)==0){i=c[n+3148>>2]|0;if((i|0)==0){o=0;p=j;break}e=gj[i&4095](l)|0;o=e;p=c[2440596]|0}else{o=a[g+(m&255)|0]|0;p=j}}while(0);j=o&255;m=p-1|0;c[2440596]=m;p=a[9660979]|0;g=p&255;l=g&1^1;n=a[9660976]|0;e=n&255;i=e-j-l|0;if((g&8|0)==0){g=p&-66;f=(((n^o)&128&(i^e)|0)==0?g:g|64)|(i&65280|0)==0;a[9660979]=f;g=i&255;a[9660976]=g;q=g;r=f;s=q<<24>>24==0;t=r&125;u=q&-128;v=s?2:u;w=v|t;a[9660979]=w;return}f=(e&15)-(j&15)-l|0;l=(e&240)-(j&240)|0;j=p&-66;p=(f&240|0)==0?f:f-6|0;f=(p&128|0)==0?l:l-16|0;l=(((n^o)&128&(i^e)|0)==0?j:j|64)|(i&65280|0)==0;a[9660979]=l;i=(((f&3840|0)==0?f:f+160|0)&240|p&15)&255;a[9660976]=i;p=(b[4830480]|0)-1&65535;f=c[2443776]|0;do{if((c[f+68+((p&65535)>>>8<<2)>>2]|0)==0){j=c[f+3148>>2]|0;if((j|0)==0){x=m;y=i;z=l;break}gj[j&4095](p)|0;x=c[2440596]|0;y=a[9660976]|0;z=a[9660979]|0}else{x=m;y=i;z=l}}while(0);c[2440596]=x-1;q=y;r=z;s=q<<24>>24==0;t=r&125;u=q&-128;v=s?2:u;w=v|t;a[9660979]=w;return}function fY_(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=0;m=i;n=f;o=j;break}k=gj[d&4095](e)|0;l=k;m=c[2440596]|0;n=c[2415243]|0;o=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=f;o=j}}while(0);j=m-1|0;c[2440596]=j;m=n&65535;do{if((c[o+68+((n>>>8&255)<<2)>>2]|0)==0){f=c[o+3148>>2]|0;if((f|0)==0){p=j;q=n;r=o;break}gj[f&4095](m)|0;p=c[2440596]|0;q=c[2415243]|0;r=c[2443776]|0}else{p=j;q=n;r=o}}while(0);o=p-1|0;c[2440596]=o;p=l<<1;a[9660979]=(p<<24>>24==0?2:p&-128)|(l&255)>>>7|a[9660979]&124;l=c[r+68+((q>>>8&255|256)<<2)>>2]|0;if((l|0)!=0){a[l+(q&255)|0]=p;s=o;t=s-1|0;c[2440596]=t;return}l=c[r+3152>>2]|0;if((l|0)==0){s=o;t=s-1|0;c[2440596]=t;return}gg[l&4095](q&65535,p);s=c[2440596]|0;t=s-1|0;c[2440596]=t;return}function fY$(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=0;m=i;n=f;o=j;break}k=gj[d&4095](e)|0;l=k;m=c[2440596]|0;n=c[2415243]|0;o=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=f;o=j}}while(0);j=m-1|0;c[2440596]=j;m=n&65535;do{if((c[o+68+((n>>>8&255)<<2)>>2]|0)==0){f=c[o+3148>>2]|0;if((f|0)==0){p=j;q=n;r=o;break}gj[f&4095](m)|0;p=c[2440596]|0;q=c[2415243]|0;r=c[2443776]|0}else{p=j;q=n;r=o}}while(0);o=p-1|0;c[2440596]=o;p=l<<1;n=a[9660979]|0;j=n&1|p;a[9660979]=n&124|(l&255)>>>7|(j<<24>>24==0?2:p&-128);p=c[r+68+((q>>>8&255|256)<<2)>>2]|0;if((p|0)!=0){a[p+(q&255)|0]=j;s=o;t=s-1|0;c[2440596]=t;return}p=c[r+3152>>2]|0;if((p|0)==0){s=o;t=s-1|0;c[2440596]=t;return}gg[p&4095](q&65535,j);s=c[2440596]|0;t=s-1|0;c[2440596]=t;return}function fY0(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=0;m=i;n=f;o=j;break}k=gj[d&4095](e)|0;l=k;m=c[2440596]|0;n=c[2415243]|0;o=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=f;o=j}}while(0);j=m-1|0;c[2440596]=j;m=n&65535;do{if((c[o+68+((n>>>8&255)<<2)>>2]|0)==0){f=c[o+3148>>2]|0;if((f|0)==0){p=j;q=n;r=o;break}gj[f&4095](m)|0;p=c[2440596]|0;q=c[2415243]|0;r=c[2443776]|0}else{p=j;q=n;r=o}}while(0);o=p-1|0;c[2440596]=o;p=a[9660979]&124|l&1;n=(l&255)>>>1;a[9660979]=(n|0)==0?p|2:p;p=n&255;n=c[r+68+((q>>>8&255|256)<<2)>>2]|0;if((n|0)!=0){a[n+(q&255)|0]=p;s=o;t=s-1|0;c[2440596]=t;return}n=c[r+3152>>2]|0;if((n|0)==0){s=o;t=s-1|0;c[2440596]=t;return}gg[n&4095](q&65535,p);s=c[2440596]|0;t=s-1|0;c[2440596]=t;return}function fY1(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=0;m=i;n=f;o=j;break}k=gj[d&4095](e)|0;l=k;m=c[2440596]|0;n=c[2415243]|0;o=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=f;o=j}}while(0);j=l&255;f=m-1|0;c[2440596]=f;m=n&65535;do{if((c[o+68+((n>>>8&255)<<2)>>2]|0)==0){i=c[o+3148>>2]|0;if((i|0)==0){p=f;break}gj[i&4095](m)|0;p=c[2440596]|0}else{p=f}}while(0);f=p-1|0;c[2440596]=f;p=a[9660979]|0;m=p&-2|l&1;a[9660979]=m;l=((p&255)<<8|j)>>>1;if((l&255|0)==0){q=m&125|2}else{q=(l&128|m&125)&255}a[9660979]=q;q=c[2415243]|0;m=l&255;l=c[2443776]|0;j=c[l+68+((q>>>8&255|256)<<2)>>2]|0;if((j|0)!=0){a[j+(q&255)|0]=m;r=f;s=r-1|0;c[2440596]=s;return}j=c[l+3152>>2]|0;if((j|0)==0){r=f;s=r-1|0;c[2440596]=s;return}gg[j&4095](q&65535,m);r=c[2440596]|0;s=r-1|0;c[2440596]=s;return}function fY2(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=a[9660977]|0;e=b[4830480]|0;b[4830480]=e+1&65535;f=e&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](e)|0;j=l;k=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=g}}while(0);a[9660968]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;g=c[2415242]|0;c[2415243]=g;f=c[k+68+((g>>>8&255|256)<<2)>>2]|0;if((f|0)!=0){a[f+(g&255)|0]=d;m=j;n=m-1|0;c[2440596]=n;return}f=c[k+3152>>2]|0;if((f|0)==0){m=j;n=m-1|0;c[2440596]=n;return}gg[f&4095](g&65535,d);m=c[2440596]|0;n=m-1|0;c[2440596]=n;return}function fY3(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=0;m=i;break}k=gj[d&4095](e)|0;l=k;m=c[2440596]|0}else{l=a[g+(f&255)|0]|0;m=i}}while(0);c[2440596]=m-1;a[9660977]=l;a[9660979]=a[9660979]&125|(l<<24>>24==0?2:l&-128);return}function fY4(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=0;m=i;n=f;o=j;break}k=gj[d&4095](e)|0;l=k;m=c[2440596]|0;n=c[2415243]|0;o=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=f;o=j}}while(0);j=m-1|0;c[2440596]=j;m=n&65535;do{if((c[o+68+((n>>>8&255)<<2)>>2]|0)==0){f=c[o+3148>>2]|0;if((f|0)==0){p=j;q=n;r=o;break}gj[f&4095](m)|0;p=c[2440596]|0;q=c[2415243]|0;r=c[2443776]|0}else{p=j;q=n;r=o}}while(0);o=p-1|0;c[2440596]=o;p=l-1&255;a[9660979]=a[9660979]&125|(p<<24>>24==0?2:p&-128);l=c[r+68+((q>>>8&255|256)<<2)>>2]|0;if((l|0)!=0){a[l+(q&255)|0]=p;s=o;t=s-1|0;c[2440596]=t;return}l=c[r+3152>>2]|0;if((l|0)==0){s=o;t=s-1|0;c[2440596]=t;return}gg[l&4095](q&65535,p);s=c[2440596]|0;t=s-1|0;c[2440596]=t;return}function fY5(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=0;m=i;n=f;o=j;break}k=gj[d&4095](e)|0;l=k;m=c[2440596]|0;n=c[2415243]|0;o=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=f;o=j}}while(0);j=m-1|0;c[2440596]=j;m=n&65535;do{if((c[o+68+((n>>>8&255)<<2)>>2]|0)==0){f=c[o+3148>>2]|0;if((f|0)==0){p=j;q=n;r=o;break}gj[f&4095](m)|0;p=c[2440596]|0;q=c[2415243]|0;r=c[2443776]|0}else{p=j;q=n;r=o}}while(0);o=p-1|0;c[2440596]=o;p=l+1&255;a[9660979]=a[9660979]&125|(p<<24>>24==0?2:p&-128);l=c[r+68+((q>>>8&255|256)<<2)>>2]|0;if((l|0)!=0){a[l+(q&255)|0]=p;s=o;t=s-1|0;c[2440596]=t;return}l=c[r+3152>>2]|0;if((l|0)==0){s=o;t=s-1|0;c[2440596]=t;return}gg[l&4095](q&65535,p);s=c[2440596]|0;t=s-1|0;c[2440596]=t;return}function fY6(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=f&255;do{if((c[j+68+((f>>>8&255)<<2)>>2]|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=i;m=g;n=j;break}gj[d&4095](e)|0;l=c[2440596]|0;m=a[9660968]|0;n=c[2443776]|0}else{l=i;m=g;n=j}}while(0);j=l-1|0;c[2440596]=j;a[9660968]=m+(a[9660977]|0)&255;m=c[2415242]|0;c[2415243]=m;l=m&65535;g=c[n+68+((m>>>8&255)<<2)>>2]|0;do{if((g|0)==0){i=c[n+3148>>2]|0;if((i|0)==0){o=0;p=j;q=m;r=n;break}e=gj[i&4095](l)|0;o=e;p=c[2440596]|0;q=c[2415243]|0;r=c[2443776]|0}else{o=a[g+(m&255)|0]|0;p=j;q=m;r=n}}while(0);n=p-1|0;c[2440596]=n;p=q&65535;do{if((c[r+68+((q>>>8&255)<<2)>>2]|0)==0){m=c[r+3148>>2]|0;if((m|0)==0){s=n;t=q;u=r;break}gj[m&4095](p)|0;s=c[2440596]|0;t=c[2415243]|0;u=c[2443776]|0}else{s=n;t=q;u=r}}while(0);r=s-1|0;c[2440596]=r;s=o<<1;a[9660979]=(s<<24>>24==0?2:s&-128)|(o&255)>>>7|a[9660979]&124;o=c[u+68+((t>>>8&255|256)<<2)>>2]|0;if((o|0)!=0){a[o+(t&255)|0]=s;v=r;w=v-1|0;c[2440596]=w;return}o=c[u+3152>>2]|0;if((o|0)==0){v=r;w=v-1|0;c[2440596]=w;return}gg[o&4095](t&65535,s);v=c[2440596]|0;w=v-1|0;c[2440596]=w;return}function fY7(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=f&255;do{if((c[j+68+((f>>>8&255)<<2)>>2]|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=i;m=g;n=j;break}gj[d&4095](e)|0;l=c[2440596]|0;m=a[9660968]|0;n=c[2443776]|0}else{l=i;m=g;n=j}}while(0);j=l-1|0;c[2440596]=j;a[9660968]=m+(a[9660977]|0)&255;m=c[2415242]|0;c[2415243]=m;l=m&65535;g=c[n+68+((m>>>8&255)<<2)>>2]|0;do{if((g|0)==0){i=c[n+3148>>2]|0;if((i|0)==0){o=0;p=j;q=m;r=n;break}e=gj[i&4095](l)|0;o=e;p=c[2440596]|0;q=c[2415243]|0;r=c[2443776]|0}else{o=a[g+(m&255)|0]|0;p=j;q=m;r=n}}while(0);n=p-1|0;c[2440596]=n;p=q&65535;do{if((c[r+68+((q>>>8&255)<<2)>>2]|0)==0){m=c[r+3148>>2]|0;if((m|0)==0){s=n;t=q;u=r;break}gj[m&4095](p)|0;s=c[2440596]|0;t=c[2415243]|0;u=c[2443776]|0}else{s=n;t=q;u=r}}while(0);r=s-1|0;c[2440596]=r;s=o<<1;q=a[9660979]|0;n=q&1|s;a[9660979]=q&124|(o&255)>>>7|(n<<24>>24==0?2:s&-128);s=c[u+68+((t>>>8&255|256)<<2)>>2]|0;if((s|0)!=0){a[s+(t&255)|0]=n;v=r;w=v-1|0;c[2440596]=w;return}s=c[u+3152>>2]|0;if((s|0)==0){v=r;w=v-1|0;c[2440596]=w;return}gg[s&4095](t&65535,n);v=c[2440596]|0;w=v-1|0;c[2440596]=w;return}function fY8(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=f&255;do{if((c[j+68+((f>>>8&255)<<2)>>2]|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=i;m=g;n=j;break}gj[d&4095](e)|0;l=c[2440596]|0;m=a[9660968]|0;n=c[2443776]|0}else{l=i;m=g;n=j}}while(0);j=l-1|0;c[2440596]=j;a[9660968]=m+(a[9660977]|0)&255;m=c[2415242]|0;c[2415243]=m;l=m&65535;g=c[n+68+((m>>>8&255)<<2)>>2]|0;do{if((g|0)==0){i=c[n+3148>>2]|0;if((i|0)==0){o=0;p=j;q=m;r=n;break}e=gj[i&4095](l)|0;o=e;p=c[2440596]|0;q=c[2415243]|0;r=c[2443776]|0}else{o=a[g+(m&255)|0]|0;p=j;q=m;r=n}}while(0);n=p-1|0;c[2440596]=n;p=q&65535;do{if((c[r+68+((q>>>8&255)<<2)>>2]|0)==0){m=c[r+3148>>2]|0;if((m|0)==0){s=n;t=q;u=r;break}gj[m&4095](p)|0;s=c[2440596]|0;t=c[2415243]|0;u=c[2443776]|0}else{s=n;t=q;u=r}}while(0);r=s-1|0;c[2440596]=r;s=a[9660979]&124|o&1;q=(o&255)>>>1;a[9660979]=(q|0)==0?s|2:s;s=q&255;q=c[u+68+((t>>>8&255|256)<<2)>>2]|0;if((q|0)!=0){a[q+(t&255)|0]=s;v=r;w=v-1|0;c[2440596]=w;return}q=c[u+3152>>2]|0;if((q|0)==0){v=r;w=v-1|0;c[2440596]=w;return}gg[q&4095](t&65535,s);v=c[2440596]|0;w=v-1|0;c[2440596]=w;return}function fY9(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=f&255;do{if((c[j+68+((f>>>8&255)<<2)>>2]|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=i;m=g;n=j;break}gj[d&4095](e)|0;l=c[2440596]|0;m=a[9660968]|0;n=c[2443776]|0}else{l=i;m=g;n=j}}while(0);j=l-1|0;c[2440596]=j;a[9660968]=m+(a[9660977]|0)&255;m=c[2415242]|0;c[2415243]=m;l=m&65535;g=c[n+68+((m>>>8&255)<<2)>>2]|0;do{if((g|0)==0){i=c[n+3148>>2]|0;if((i|0)==0){o=0;p=j;q=m;r=n;break}e=gj[i&4095](l)|0;o=e;p=c[2440596]|0;q=c[2415243]|0;r=c[2443776]|0}else{o=a[g+(m&255)|0]|0;p=j;q=m;r=n}}while(0);n=o&255;m=p-1|0;c[2440596]=m;p=q&65535;do{if((c[r+68+((q>>>8&255)<<2)>>2]|0)==0){j=c[r+3148>>2]|0;if((j|0)==0){s=m;break}gj[j&4095](p)|0;s=c[2440596]|0}else{s=m}}while(0);m=s-1|0;c[2440596]=m;s=a[9660979]|0;p=s&-2|o&1;a[9660979]=p;o=((s&255)<<8|n)>>>1;if((o&255|0)==0){t=p&125|2}else{t=(o&128|p&125)&255}a[9660979]=t;t=c[2415243]|0;p=o&255;o=c[2443776]|0;n=c[o+68+((t>>>8&255|256)<<2)>>2]|0;if((n|0)!=0){a[n+(t&255)|0]=p;u=m;v=u-1|0;c[2440596]=v;return}n=c[o+3152>>2]|0;if((n|0)==0){u=m;v=u-1|0;c[2440596]=v;return}gg[n&4095](t&65535,p);u=c[2440596]|0;v=u-1|0;c[2440596]=v;return}function fZa(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=a[9660977]|0;e=b[4830480]|0;b[4830480]=e+1&65535;f=e&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](e)|0;j=l;k=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=g}}while(0);a[9660968]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;g=c[2415242]|0;f=g&65535;h=g&255;do{if((c[k+68+((g>>>8&255)<<2)>>2]|0)==0){e=c[k+3148>>2]|0;if((e|0)==0){m=j;n=h;o=k;break}gj[e&4095](f)|0;m=c[2440596]|0;n=a[9660968]|0;o=c[2443776]|0}else{m=j;n=h;o=k}}while(0);k=m-1|0;c[2440596]=k;a[9660968]=n+(a[9660978]|0)&255;n=c[2415242]|0;c[2415243]=n;m=c[o+68+((n>>>8&255|256)<<2)>>2]|0;if((m|0)!=0){a[m+(n&255)|0]=d;p=k;q=p-1|0;c[2440596]=q;return}m=c[o+3152>>2]|0;if((m|0)==0){p=k;q=p-1|0;c[2440596]=q;return}gg[m&4095](n&65535,d);p=c[2440596]|0;q=p-1|0;c[2440596]=q;return}function fZb(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=f&255;do{if((c[j+68+((f>>>8&255)<<2)>>2]|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=i;m=g;n=j;break}gj[d&4095](e)|0;l=c[2440596]|0;m=a[9660968]|0;n=c[2443776]|0}else{l=i;m=g;n=j}}while(0);j=l-1|0;c[2440596]=j;a[9660968]=m+(a[9660978]|0)&255;m=c[2415242]|0;c[2415243]=m;l=m&65535;g=c[n+68+((m>>>8&255)<<2)>>2]|0;do{if((g|0)==0){i=c[n+3148>>2]|0;if((i|0)==0){o=0;p=j;break}e=gj[i&4095](l)|0;o=e;p=c[2440596]|0}else{o=a[g+(m&255)|0]|0;p=j}}while(0);c[2440596]=p-1;a[9660977]=o;a[9660979]=a[9660979]&125|(o<<24>>24==0?2:o&-128);return}function fZc(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=f&255;do{if((c[j+68+((f>>>8&255)<<2)>>2]|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=i;m=g;n=j;break}gj[d&4095](e)|0;l=c[2440596]|0;m=a[9660968]|0;n=c[2443776]|0}else{l=i;m=g;n=j}}while(0);j=l-1|0;c[2440596]=j;a[9660968]=m+(a[9660977]|0)&255;m=c[2415242]|0;c[2415243]=m;l=m&65535;g=c[n+68+((m>>>8&255)<<2)>>2]|0;do{if((g|0)==0){i=c[n+3148>>2]|0;if((i|0)==0){o=0;p=j;q=m;r=n;break}e=gj[i&4095](l)|0;o=e;p=c[2440596]|0;q=c[2415243]|0;r=c[2443776]|0}else{o=a[g+(m&255)|0]|0;p=j;q=m;r=n}}while(0);n=p-1|0;c[2440596]=n;p=q&65535;do{if((c[r+68+((q>>>8&255)<<2)>>2]|0)==0){m=c[r+3148>>2]|0;if((m|0)==0){s=n;t=q;u=r;break}gj[m&4095](p)|0;s=c[2440596]|0;t=c[2415243]|0;u=c[2443776]|0}else{s=n;t=q;u=r}}while(0);r=s-1|0;c[2440596]=r;s=o-1&255;a[9660979]=a[9660979]&125|(s<<24>>24==0?2:s&-128);o=c[u+68+((t>>>8&255|256)<<2)>>2]|0;if((o|0)!=0){a[o+(t&255)|0]=s;v=r;w=v-1|0;c[2440596]=w;return}o=c[u+3152>>2]|0;if((o|0)==0){v=r;w=v-1|0;c[2440596]=w;return}gg[o&4095](t&65535,s);v=c[2440596]|0;w=v-1|0;c[2440596]=w;return}function fZd(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;e=f&65535;g=f&255;do{if((c[j+68+((f>>>8&255)<<2)>>2]|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=i;m=g;n=j;break}gj[d&4095](e)|0;l=c[2440596]|0;m=a[9660968]|0;n=c[2443776]|0}else{l=i;m=g;n=j}}while(0);j=l-1|0;c[2440596]=j;a[9660968]=m+(a[9660977]|0)&255;m=c[2415242]|0;c[2415243]=m;l=m&65535;g=c[n+68+((m>>>8&255)<<2)>>2]|0;do{if((g|0)==0){i=c[n+3148>>2]|0;if((i|0)==0){o=0;p=j;q=m;r=n;break}e=gj[i&4095](l)|0;o=e;p=c[2440596]|0;q=c[2415243]|0;r=c[2443776]|0}else{o=a[g+(m&255)|0]|0;p=j;q=m;r=n}}while(0);n=p-1|0;c[2440596]=n;p=q&65535;do{if((c[r+68+((q>>>8&255)<<2)>>2]|0)==0){m=c[r+3148>>2]|0;if((m|0)==0){s=n;t=q;u=r;break}gj[m&4095](p)|0;s=c[2440596]|0;t=c[2415243]|0;u=c[2443776]|0}else{s=n;t=q;u=r}}while(0);r=s-1|0;c[2440596]=r;s=o+1&255;a[9660979]=a[9660979]&125|(s<<24>>24==0?2:s&-128);o=c[u+68+((t>>>8&255|256)<<2)>>2]|0;if((o|0)!=0){a[o+(t&255)|0]=s;v=r;w=v-1|0;c[2440596]=w;return}o=c[u+3152>>2]|0;if((o|0)==0){v=r;w=v-1|0;c[2440596]=w;return}gg[o&4095](t&65535,s);v=c[2440596]|0;w=v-1|0;c[2440596]=w;return}function fZe(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=0;m=i;n=f;o=j;break}k=gj[d&4095](e)|0;l=k;m=c[2440596]|0;n=c[2415243]|0;o=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=f;o=j}}while(0);j=m-1|0;c[2440596]=j;m=n&65535;do{if((c[o+68+((n>>>8&255)<<2)>>2]|0)==0){f=c[o+3148>>2]|0;if((f|0)==0){p=j;q=n;r=o;break}gj[f&4095](m)|0;p=c[2440596]|0;q=c[2415243]|0;r=c[2443776]|0}else{p=j;q=n;r=o}}while(0);o=p-1|0;c[2440596]=o;p=l&-2;l=c[r+68+((q>>>8&255|256)<<2)>>2]|0;if((l|0)!=0){a[l+(q&255)|0]=p;s=o;t=s-1|0;c[2440596]=t;return}l=c[r+3152>>2]|0;if((l|0)==0){s=o;t=s-1|0;c[2440596]=t;return}gg[l&4095](q&65535,p);s=c[2440596]|0;t=s-1|0;c[2440596]=t;return}function fZf(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=0;m=i;n=f;o=j;break}k=gj[d&4095](e)|0;l=k;m=c[2440596]|0;n=c[2415243]|0;o=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=f;o=j}}while(0);j=m-1|0;c[2440596]=j;m=n&65535;do{if((c[o+68+((n>>>8&255)<<2)>>2]|0)==0){f=c[o+3148>>2]|0;if((f|0)==0){p=j;q=n;r=o;break}gj[f&4095](m)|0;p=c[2440596]|0;q=c[2415243]|0;r=c[2443776]|0}else{p=j;q=n;r=o}}while(0);o=p-1|0;c[2440596]=o;p=l&-5;l=c[r+68+((q>>>8&255|256)<<2)>>2]|0;if((l|0)!=0){a[l+(q&255)|0]=p;s=o;t=s-1|0;c[2440596]=t;return}l=c[r+3152>>2]|0;if((l|0)==0){s=o;t=s-1|0;c[2440596]=t;return}gg[l&4095](q&65535,p);s=c[2440596]|0;t=s-1|0;c[2440596]=t;return}function fZg(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=0;m=i;n=f;o=j;break}k=gj[d&4095](e)|0;l=k;m=c[2440596]|0;n=c[2415243]|0;o=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=f;o=j}}while(0);j=m-1|0;c[2440596]=j;m=n&65535;do{if((c[o+68+((n>>>8&255)<<2)>>2]|0)==0){f=c[o+3148>>2]|0;if((f|0)==0){p=j;q=n;r=o;break}gj[f&4095](m)|0;p=c[2440596]|0;q=c[2415243]|0;r=c[2443776]|0}else{p=j;q=n;r=o}}while(0);o=p-1|0;c[2440596]=o;p=l&-17;l=c[r+68+((q>>>8&255|256)<<2)>>2]|0;if((l|0)!=0){a[l+(q&255)|0]=p;s=o;t=s-1|0;c[2440596]=t;return}l=c[r+3152>>2]|0;if((l|0)==0){s=o;t=s-1|0;c[2440596]=t;return}gg[l&4095](q&65535,p);s=c[2440596]|0;t=s-1|0;c[2440596]=t;return}function fZh(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=0;m=i;n=f;o=j;break}k=gj[d&4095](e)|0;l=k;m=c[2440596]|0;n=c[2415243]|0;o=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=f;o=j}}while(0);j=m-1|0;c[2440596]=j;m=n&65535;do{if((c[o+68+((n>>>8&255)<<2)>>2]|0)==0){f=c[o+3148>>2]|0;if((f|0)==0){p=j;q=n;r=o;break}gj[f&4095](m)|0;p=c[2440596]|0;q=c[2415243]|0;r=c[2443776]|0}else{p=j;q=n;r=o}}while(0);o=p-1|0;c[2440596]=o;p=l&-65;l=c[r+68+((q>>>8&255|256)<<2)>>2]|0;if((l|0)!=0){a[l+(q&255)|0]=p;s=o;t=s-1|0;c[2440596]=t;return}l=c[r+3152>>2]|0;if((l|0)==0){s=o;t=s-1|0;c[2440596]=t;return}gg[l&4095](q&65535,p);s=c[2440596]|0;t=s-1|0;c[2440596]=t;return}function fZi(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=0;m=i;n=f;o=j;break}k=gj[d&4095](e)|0;l=k;m=c[2440596]|0;n=c[2415243]|0;o=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=f;o=j}}while(0);j=m-1|0;c[2440596]=j;m=n&65535;do{if((c[o+68+((n>>>8&255)<<2)>>2]|0)==0){f=c[o+3148>>2]|0;if((f|0)==0){p=j;q=n;r=o;break}gj[f&4095](m)|0;p=c[2440596]|0;q=c[2415243]|0;r=c[2443776]|0}else{p=j;q=n;r=o}}while(0);o=p-1|0;c[2440596]=o;p=l|1;l=c[r+68+((q>>>8&255|256)<<2)>>2]|0;if((l|0)!=0){a[l+(q&255)|0]=p;s=o;t=s-1|0;c[2440596]=t;return}l=c[r+3152>>2]|0;if((l|0)==0){s=o;t=s-1|0;c[2440596]=t;return}gg[l&4095](q&65535,p);s=c[2440596]|0;t=s-1|0;c[2440596]=t;return}function fZj(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=0;m=i;n=f;o=j;break}k=gj[d&4095](e)|0;l=k;m=c[2440596]|0;n=c[2415243]|0;o=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=f;o=j}}while(0);j=m-1|0;c[2440596]=j;m=n&65535;do{if((c[o+68+((n>>>8&255)<<2)>>2]|0)==0){f=c[o+3148>>2]|0;if((f|0)==0){p=j;q=n;r=o;break}gj[f&4095](m)|0;p=c[2440596]|0;q=c[2415243]|0;r=c[2443776]|0}else{p=j;q=n;r=o}}while(0);o=p-1|0;c[2440596]=o;p=l|4;l=c[r+68+((q>>>8&255|256)<<2)>>2]|0;if((l|0)!=0){a[l+(q&255)|0]=p;s=o;t=s-1|0;c[2440596]=t;return}l=c[r+3152>>2]|0;if((l|0)==0){s=o;t=s-1|0;c[2440596]=t;return}gg[l&4095](q&65535,p);s=c[2440596]|0;t=s-1|0;c[2440596]=t;return}function fZk(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=0;m=i;n=f;o=j;break}k=gj[d&4095](e)|0;l=k;m=c[2440596]|0;n=c[2415243]|0;o=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=f;o=j}}while(0);j=m-1|0;c[2440596]=j;m=n&65535;do{if((c[o+68+((n>>>8&255)<<2)>>2]|0)==0){f=c[o+3148>>2]|0;if((f|0)==0){p=j;q=n;r=o;break}gj[f&4095](m)|0;p=c[2440596]|0;q=c[2415243]|0;r=c[2443776]|0}else{p=j;q=n;r=o}}while(0);o=p-1|0;c[2440596]=o;p=l|16;l=c[r+68+((q>>>8&255|256)<<2)>>2]|0;if((l|0)!=0){a[l+(q&255)|0]=p;s=o;t=s-1|0;c[2440596]=t;return}l=c[r+3152>>2]|0;if((l|0)==0){s=o;t=s-1|0;c[2440596]=t;return}gg[l&4095](q&65535,p);s=c[2440596]|0;t=s-1|0;c[2440596]=t;return}function fZl(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=0;m=i;n=f;o=j;break}k=gj[d&4095](e)|0;l=k;m=c[2440596]|0;n=c[2415243]|0;o=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=f;o=j}}while(0);j=m-1|0;c[2440596]=j;m=n&65535;do{if((c[o+68+((n>>>8&255)<<2)>>2]|0)==0){f=c[o+3148>>2]|0;if((f|0)==0){p=j;q=n;r=o;break}gj[f&4095](m)|0;p=c[2440596]|0;q=c[2415243]|0;r=c[2443776]|0}else{p=j;q=n;r=o}}while(0);o=p-1|0;c[2440596]=o;p=l|64;l=c[r+68+((q>>>8&255|256)<<2)>>2]|0;if((l|0)!=0){a[l+(q&255)|0]=p;s=o;t=s-1|0;c[2440596]=t;return}l=c[r+3152>>2]|0;if((l|0)==0){s=o;t=s-1|0;c[2440596]=t;return}gg[l&4095](q&65535,p);s=c[2440596]|0;t=s-1|0;c[2440596]=t;return}function fZm(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=0;m=i;n=f;o=j;break}k=gj[d&4095](e)|0;l=k;m=c[2440596]|0;n=c[2415243]|0;o=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=f;o=j}}while(0);j=m-1|0;c[2440596]=j;m=n&65535;do{if((c[o+68+((n>>>8&255)<<2)>>2]|0)==0){f=c[o+3148>>2]|0;if((f|0)==0){p=j;q=n;r=o;break}gj[f&4095](m)|0;p=c[2440596]|0;q=c[2415243]|0;r=c[2443776]|0}else{p=j;q=n;r=o}}while(0);o=p-1|0;c[2440596]=o;p=l&-3;l=c[r+68+((q>>>8&255|256)<<2)>>2]|0;if((l|0)!=0){a[l+(q&255)|0]=p;s=o;t=s-1|0;c[2440596]=t;return}l=c[r+3152>>2]|0;if((l|0)==0){s=o;t=s-1|0;c[2440596]=t;return}gg[l&4095](q&65535,p);s=c[2440596]|0;t=s-1|0;c[2440596]=t;return}function fZn(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=0;m=i;n=f;o=j;break}k=gj[d&4095](e)|0;l=k;m=c[2440596]|0;n=c[2415243]|0;o=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=f;o=j}}while(0);j=m-1|0;c[2440596]=j;m=n&65535;do{if((c[o+68+((n>>>8&255)<<2)>>2]|0)==0){f=c[o+3148>>2]|0;if((f|0)==0){p=j;q=n;r=o;break}gj[f&4095](m)|0;p=c[2440596]|0;q=c[2415243]|0;r=c[2443776]|0}else{p=j;q=n;r=o}}while(0);o=p-1|0;c[2440596]=o;p=l&-9;l=c[r+68+((q>>>8&255|256)<<2)>>2]|0;if((l|0)!=0){a[l+(q&255)|0]=p;s=o;t=s-1|0;c[2440596]=t;return}l=c[r+3152>>2]|0;if((l|0)==0){s=o;t=s-1|0;c[2440596]=t;return}gg[l&4095](q&65535,p);s=c[2440596]|0;t=s-1|0;c[2440596]=t;return}function fZo(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=0;m=i;n=f;o=j;break}k=gj[d&4095](e)|0;l=k;m=c[2440596]|0;n=c[2415243]|0;o=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=f;o=j}}while(0);j=m-1|0;c[2440596]=j;m=n&65535;do{if((c[o+68+((n>>>8&255)<<2)>>2]|0)==0){f=c[o+3148>>2]|0;if((f|0)==0){p=j;q=n;r=o;break}gj[f&4095](m)|0;p=c[2440596]|0;q=c[2415243]|0;r=c[2443776]|0}else{p=j;q=n;r=o}}while(0);o=p-1|0;c[2440596]=o;p=l&-33;l=c[r+68+((q>>>8&255|256)<<2)>>2]|0;if((l|0)!=0){a[l+(q&255)|0]=p;s=o;t=s-1|0;c[2440596]=t;return}l=c[r+3152>>2]|0;if((l|0)==0){s=o;t=s-1|0;c[2440596]=t;return}gg[l&4095](q&65535,p);s=c[2440596]|0;t=s-1|0;c[2440596]=t;return}function fZp(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=0;m=i;n=f;o=j;break}k=gj[d&4095](e)|0;l=k;m=c[2440596]|0;n=c[2415243]|0;o=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=f;o=j}}while(0);j=m-1|0;c[2440596]=j;m=n&65535;do{if((c[o+68+((n>>>8&255)<<2)>>2]|0)==0){f=c[o+3148>>2]|0;if((f|0)==0){p=j;q=n;r=o;break}gj[f&4095](m)|0;p=c[2440596]|0;q=c[2415243]|0;r=c[2443776]|0}else{p=j;q=n;r=o}}while(0);o=p-1|0;c[2440596]=o;p=l&127;l=c[r+68+((q>>>8&255|256)<<2)>>2]|0;if((l|0)!=0){a[l+(q&255)|0]=p;s=o;t=s-1|0;c[2440596]=t;return}l=c[r+3152>>2]|0;if((l|0)==0){s=o;t=s-1|0;c[2440596]=t;return}gg[l&4095](q&65535,p);s=c[2440596]|0;t=s-1|0;c[2440596]=t;return}function fZq(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=0;m=i;n=f;o=j;break}k=gj[d&4095](e)|0;l=k;m=c[2440596]|0;n=c[2415243]|0;o=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=f;o=j}}while(0);j=m-1|0;c[2440596]=j;m=n&65535;do{if((c[o+68+((n>>>8&255)<<2)>>2]|0)==0){f=c[o+3148>>2]|0;if((f|0)==0){p=j;q=n;r=o;break}gj[f&4095](m)|0;p=c[2440596]|0;q=c[2415243]|0;r=c[2443776]|0}else{p=j;q=n;r=o}}while(0);o=p-1|0;c[2440596]=o;p=l|2;l=c[r+68+((q>>>8&255|256)<<2)>>2]|0;if((l|0)!=0){a[l+(q&255)|0]=p;s=o;t=s-1|0;c[2440596]=t;return}l=c[r+3152>>2]|0;if((l|0)==0){s=o;t=s-1|0;c[2440596]=t;return}gg[l&4095](q&65535,p);s=c[2440596]|0;t=s-1|0;c[2440596]=t;return}function fZr(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=0;m=i;n=f;o=j;break}k=gj[d&4095](e)|0;l=k;m=c[2440596]|0;n=c[2415243]|0;o=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=f;o=j}}while(0);j=m-1|0;c[2440596]=j;m=n&65535;do{if((c[o+68+((n>>>8&255)<<2)>>2]|0)==0){f=c[o+3148>>2]|0;if((f|0)==0){p=j;q=n;r=o;break}gj[f&4095](m)|0;p=c[2440596]|0;q=c[2415243]|0;r=c[2443776]|0}else{p=j;q=n;r=o}}while(0);o=p-1|0;c[2440596]=o;p=l|8;l=c[r+68+((q>>>8&255|256)<<2)>>2]|0;if((l|0)!=0){a[l+(q&255)|0]=p;s=o;t=s-1|0;c[2440596]=t;return}l=c[r+3152>>2]|0;if((l|0)==0){s=o;t=s-1|0;c[2440596]=t;return}gg[l&4095](q&65535,p);s=c[2440596]|0;t=s-1|0;c[2440596]=t;return}function fZs(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=0;m=i;n=f;o=j;break}k=gj[d&4095](e)|0;l=k;m=c[2440596]|0;n=c[2415243]|0;o=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=f;o=j}}while(0);j=m-1|0;c[2440596]=j;m=n&65535;do{if((c[o+68+((n>>>8&255)<<2)>>2]|0)==0){f=c[o+3148>>2]|0;if((f|0)==0){p=j;q=n;r=o;break}gj[f&4095](m)|0;p=c[2440596]|0;q=c[2415243]|0;r=c[2443776]|0}else{p=j;q=n;r=o}}while(0);o=p-1|0;c[2440596]=o;p=l|32;l=c[r+68+((q>>>8&255|256)<<2)>>2]|0;if((l|0)!=0){a[l+(q&255)|0]=p;s=o;t=s-1|0;c[2440596]=t;return}l=c[r+3152>>2]|0;if((l|0)==0){s=o;t=s-1|0;c[2440596]=t;return}gg[l&4095](q&65535,p);s=c[2440596]|0;t=s-1|0;c[2440596]=t;return}function fZt(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=0;m=i;n=f;o=j;break}k=gj[d&4095](e)|0;l=k;m=c[2440596]|0;n=c[2415243]|0;o=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=f;o=j}}while(0);j=m-1|0;c[2440596]=j;m=n&65535;do{if((c[o+68+((n>>>8&255)<<2)>>2]|0)==0){f=c[o+3148>>2]|0;if((f|0)==0){p=j;q=n;r=o;break}gj[f&4095](m)|0;p=c[2440596]|0;q=c[2415243]|0;r=c[2443776]|0}else{p=j;q=n;r=o}}while(0);o=p-1|0;c[2440596]=o;p=l|-128;l=c[r+68+((q>>>8&255|256)<<2)>>2]|0;if((l|0)!=0){a[l+(q&255)|0]=p;s=o;t=s-1|0;c[2440596]=t;return}l=c[r+3152>>2]|0;if((l|0)==0){s=o;t=s-1|0;c[2440596]=t;return}gg[l&4095](q&65535,p);s=c[2440596]|0;t=s-1|0;c[2440596]=t;return}function fZu(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=b[4830480]|0;e=c[2443776]|0;do{if((c[e+68+((d&65535)>>>8<<2)>>2]|0)==0){f=c[e+3148>>2]|0;if((f|0)==0){g=e;break}gj[f&4095](d)|0;g=c[2443776]|0}else{g=e}}while(0);e=(c[2440596]|0)-1|0;c[2440596]=e;d=c[2415241]|0;f=d&65535;h=a[9660979]|0;i=c[g+68+((d>>>8&255|256)<<2)>>2]|0;do{if((i|0)==0){j=c[g+3152>>2]|0;if((j|0)==0){k=e;break}gg[j&4095](f,h);k=c[2440596]|0}else{a[i+(d&255)|0]=h;k=e}}while(0);c[2440596]=k-1;a[9660964]=(a[9660964]|0)-1&255;return}function fZv(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=b[4830480]|0;e=c[2443776]|0;do{if((c[e+68+((d&65535)>>>8<<2)>>2]|0)==0){f=c[e+3148>>2]|0;if((f|0)==0){g=e;break}gj[f&4095](d)|0;g=c[2443776]|0}else{g=e}}while(0);e=(c[2440596]|0)-1|0;c[2440596]=e;d=c[2415241]|0;f=d&65535;h=d&255;do{if((c[g+68+((d>>>8&255)<<2)>>2]|0)==0){i=c[g+3148>>2]|0;if((i|0)==0){j=e;k=h;l=g;break}gj[i&4095](f)|0;j=c[2440596]|0;k=a[9660964]|0;l=c[2443776]|0}else{j=e;k=h;l=g}}while(0);g=j-1|0;c[2440596]=g;j=(a[9660979]&4)==0;a[9660964]=k+1&255;k=c[2415241]|0;h=k&65535;e=c[l+68+((k>>>8&255)<<2)>>2]|0;do{if((e|0)==0){f=c[l+3148>>2]|0;if((f|0)==0){m=0;n=g;break}d=gj[f&4095](h)|0;m=d;n=c[2440596]|0}else{m=a[e+(k&255)|0]|0;n=g}}while(0);a[9660979]=m;c[2440596]=n-1;if(j|(a[9660983]|0)==0){o=m|48;a[9660979]=o;return}if((m&4)!=0){o=m|48;a[9660979]=o;return}a[9660981]=1;o=m|48;a[9660979]=o;return}function fZw(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=b[4830480]|0;e=c[2443776]|0;do{if((c[e+68+((d&65535)>>>8<<2)>>2]|0)==0){f=c[e+3148>>2]|0;if((f|0)==0){g=e;break}gj[f&4095](d)|0;g=c[2443776]|0}else{g=e}}while(0);e=(c[2440596]|0)-1|0;c[2440596]=e;d=c[2415241]|0;f=d&65535;h=a[9660976]|0;i=c[g+68+((d>>>8&255|256)<<2)>>2]|0;do{if((i|0)==0){j=c[g+3152>>2]|0;if((j|0)==0){k=e;break}gg[j&4095](f,h);k=c[2440596]|0}else{a[i+(d&255)|0]=h;k=e}}while(0);c[2440596]=k-1;a[9660964]=(a[9660964]|0)-1&255;return}function fZx(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=b[4830480]|0;e=c[2443776]|0;do{if((c[e+68+((d&65535)>>>8<<2)>>2]|0)==0){f=c[e+3148>>2]|0;if((f|0)==0){g=e;break}gj[f&4095](d)|0;g=c[2443776]|0}else{g=e}}while(0);e=(c[2440596]|0)-1|0;c[2440596]=e;d=c[2415241]|0;f=d&65535;h=d&255;do{if((c[g+68+((d>>>8&255)<<2)>>2]|0)==0){i=c[g+3148>>2]|0;if((i|0)==0){j=e;k=h;l=g;break}gj[i&4095](f)|0;j=c[2440596]|0;k=a[9660964]|0;l=c[2443776]|0}else{j=e;k=h;l=g}}while(0);g=j-1|0;c[2440596]=g;a[9660964]=k+1&255;k=c[2415241]|0;j=k&65535;h=c[l+68+((k>>>8&255)<<2)>>2]|0;do{if((h|0)==0){e=c[l+3148>>2]|0;if((e|0)==0){m=0;n=g;break}f=gj[e&4095](j)|0;m=f;n=c[2440596]|0}else{m=a[h+(k&255)|0]|0;n=g}}while(0);a[9660976]=m;c[2440596]=n-1;a[9660979]=a[9660979]&125|(m<<24>>24==0?2:m&-128);return}function fZy(){var d=0,e=0,f=0;d=b[4830480]|0;e=c[2443776]|0;do{if((c[e+68+((d&65535)>>>8<<2)>>2]|0)==0){f=c[e+3148>>2]|0;if((f|0)==0){break}gj[f&4095](d)|0}}while(0);c[2440596]=(c[2440596]|0)-1;d=(a[9660978]|0)-1&255;a[9660978]=d;a[9660979]=(d<<24>>24==0?2:d&-128)|a[9660979]&125;return}function fZz(){var d=0,e=0,f=0;d=b[4830480]|0;e=c[2443776]|0;do{if((c[e+68+((d&65535)>>>8<<2)>>2]|0)==0){f=c[e+3148>>2]|0;if((f|0)==0){break}gj[f&4095](d)|0}}while(0);c[2440596]=(c[2440596]|0)-1;d=a[9660976]|0;a[9660978]=d;a[9660979]=a[9660979]&125|(d<<24>>24==0?2:d&-128);return}function fZA(){var d=0,e=0,f=0;d=b[4830480]|0;e=c[2443776]|0;do{if((c[e+68+((d&65535)>>>8<<2)>>2]|0)==0){f=c[e+3148>>2]|0;if((f|0)==0){break}gj[f&4095](d)|0}}while(0);c[2440596]=(c[2440596]|0)-1;d=(a[9660978]|0)+1&255;a[9660978]=d;a[9660979]=(d<<24>>24==0?2:d&-128)|a[9660979]&125;return}function fZB(){var d=0,e=0,f=0;d=b[4830480]|0;e=c[2443776]|0;do{if((c[e+68+((d&65535)>>>8<<2)>>2]|0)==0){f=c[e+3148>>2]|0;if((f|0)==0){break}gj[f&4095](d)|0}}while(0);c[2440596]=(c[2440596]|0)-1;d=(a[9660977]|0)+1&255;a[9660977]=d;a[9660979]=(d<<24>>24==0?2:d&-128)|a[9660979]&125;return}function fZC(){var d=0,e=0,f=0;d=b[4830480]|0;e=c[2443776]|0;do{if((c[e+68+((d&65535)>>>8<<2)>>2]|0)==0){f=c[e+3148>>2]|0;if((f|0)==0){break}gj[f&4095](d)|0}}while(0);c[2440596]=(c[2440596]|0)-1;a[9660979]=a[9660979]&-2;return}function fZD(){var d=0,e=0,f=0;d=b[4830480]|0;e=c[2443776]|0;do{if((c[e+68+((d&65535)>>>8<<2)>>2]|0)==0){f=c[e+3148>>2]|0;if((f|0)==0){break}gj[f&4095](d)|0}}while(0);c[2440596]=(c[2440596]|0)-1;a[9660979]=a[9660979]|1;return}function fZE(){var d=0,e=0,f=0,g=0;d=b[4830480]|0;e=c[2443776]|0;do{if((c[e+68+((d&65535)>>>8<<2)>>2]|0)==0){f=c[e+3148>>2]|0;if((f|0)==0){break}gj[f&4095](d)|0}}while(0);c[2440596]=(c[2440596]|0)-1;d=a[9660979]|0;if((a[9660983]|0)==0){g=d&-5;a[9660979]=g;return}if((d&4)==0){g=d&-5;a[9660979]=g;return}a[9660981]=1;g=d&-5;a[9660979]=g;return}function fZF(){var d=0,e=0,f=0;d=b[4830480]|0;e=c[2443776]|0;do{if((c[e+68+((d&65535)>>>8<<2)>>2]|0)==0){f=c[e+3148>>2]|0;if((f|0)==0){break}gj[f&4095](d)|0}}while(0);c[2440596]=(c[2440596]|0)-1;a[9660979]=a[9660979]|4;return}function fZG(){var d=0,e=0,f=0;d=b[4830480]|0;e=c[2443776]|0;do{if((c[e+68+((d&65535)>>>8<<2)>>2]|0)==0){f=c[e+3148>>2]|0;if((f|0)==0){break}gj[f&4095](d)|0}}while(0);c[2440596]=(c[2440596]|0)-1;d=a[9660978]|0;a[9660976]=d;a[9660979]=a[9660979]&125|(d<<24>>24==0?2:d&-128);return}function fZH(){var d=0,e=0,f=0;d=b[4830480]|0;e=c[2443776]|0;do{if((c[e+68+((d&65535)>>>8<<2)>>2]|0)==0){f=c[e+3148>>2]|0;if((f|0)==0){break}gj[f&4095](d)|0}}while(0);c[2440596]=(c[2440596]|0)-1;a[9660979]=a[9660979]&-65;return}function fZI(){var d=0,e=0,f=0;d=b[4830480]|0;e=c[2443776]|0;do{if((c[e+68+((d&65535)>>>8<<2)>>2]|0)==0){f=c[e+3148>>2]|0;if((f|0)==0){break}gj[f&4095](d)|0}}while(0);c[2440596]=(c[2440596]|0)-1;a[9660979]=a[9660979]&-9;return}function fZJ(){var d=0,e=0,f=0;d=b[4830480]|0;e=c[2443776]|0;do{if((c[e+68+((d&65535)>>>8<<2)>>2]|0)==0){f=c[e+3148>>2]|0;if((f|0)==0){break}gj[f&4095](d)|0}}while(0);c[2440596]=(c[2440596]|0)-1;a[9660979]=a[9660979]|8;return}function fZK(){var d=0,e=0,f=0,g=0,h=0,i=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(e&255)|0]|0}}while(0);c[2440596]=(c[2440596]|0)-1;e=a[9660976]|i;a[9660976]=e;a[9660979]=(e<<24>>24==0?2:e&-128)|a[9660979]&125;return}function fZL(){var d=0,e=0,f=0,g=0,h=0,i=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(e&255)|0]|0}}while(0);c[2440596]=(c[2440596]|0)-1;e=a[9660976]&i;a[9660976]=e;a[9660979]=(e<<24>>24==0?2:e&-128)|a[9660979]&125;return}function fZM(){var d=0,e=0,f=0,g=0,h=0,i=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(e&255)|0]|0}}while(0);c[2440596]=(c[2440596]|0)-1;e=a[9660976]|0;g=e^i;a[9660976]=g;a[9660979]=(e<<24>>24==i<<24>>24?2:g&-128)|a[9660979]&125;return}function fZN(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(e&255)|0]|0}}while(0);e=i&255;g=(c[2440596]|0)-1|0;c[2440596]=g;d=a[9660979]|0;f=d&255;h=f&1;j=a[9660976]|0;k=j&255;if((f&8|0)==0){f=k+e+h|0;l=d&-66;m=((((j^i)&128^128)&(f^k)|0)==0?l:l|64)|(f&65280|0)!=0;a[9660979]=m;l=f&255;a[9660976]=l;n=l;o=m;p=n<<24>>24==0;q=o&125;r=n&-128;s=p?2:r;t=s|q;a[9660979]=t;return}m=h+(e&15)+(k&15)|0;h=(k&240)+(e&240)|0;e=d&-66;a[9660979]=e;if((m|0)>9){u=m+6|0;v=h+16|0}else{u=m;v=h}if((((j^i)&128^128)&(v^k)|0)==0){w=e}else{k=e|64;a[9660979]=k;w=k}k=(v|0)>144?v+96|0:v;if((k&65280|0)==0){x=w}else{v=w|1;a[9660979]=v;x=v}v=(k&240|u&15)&255;a[9660976]=v;u=(b[4830480]|0)-1&65535;k=c[2443776]|0;do{if((c[k+68+((u&65535)>>>8<<2)>>2]|0)==0){w=c[k+3148>>2]|0;if((w|0)==0){y=g;z=v;A=x;break}gj[w&4095](u)|0;y=c[2440596]|0;z=a[9660976]|0;A=a[9660979]|0}else{y=g;z=v;A=x}}while(0);c[2440596]=y-1;n=z;o=A;p=n<<24>>24==0;q=o&125;r=n&-128;s=p?2:r;t=s|q;a[9660979]=t;return}function fZO(){var d=0,e=0,f=0,g=0,h=0,i=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(e&255)|0]|0}}while(0);c[2440596]=(c[2440596]|0)-1;e=a[9660979]|0;a[9660979]=e&-3;if((a[9660976]&i)<<24>>24!=0){return}a[9660979]=e|2;return}function fZP(){var d=0,e=0,f=0,g=0,h=0,i=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(e&255)|0]|0}}while(0);c[2440596]=(c[2440596]|0)-1;a[9660976]=i;a[9660979]=a[9660979]&125|(i<<24>>24==0?2:i&-128);return}function fZQ(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(e&255)|0]|0}}while(0);c[2440596]=(c[2440596]|0)-1;e=a[9660979]|0;g=e&-2;a[9660979]=g;d=a[9660976]|0;if((d&255)<(i&255)){j=g}else{g=e|1;a[9660979]=g;j=g}if(d<<24>>24==i<<24>>24){k=j&125|2;a[9660979]=k;return}else{k=j&125|d-i&255&-128;a[9660979]=k;return}}function fZR(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(e&255)|0]|0}}while(0);e=i&255;g=(c[2440596]|0)-1|0;c[2440596]=g;d=a[9660979]|0;f=d&255;h=f&1^1;j=a[9660976]|0;k=j&255;l=k-e-h|0;if((f&8|0)==0){f=d&-66;m=(((j^i)&128&(l^k)|0)==0?f:f|64)|(l&65280|0)==0;a[9660979]=m;f=l&255;a[9660976]=f;n=f;o=m;p=n<<24>>24==0;q=o&125;r=n&-128;s=p?2:r;t=s|q;a[9660979]=t;return}m=(k&15)-(e&15)-h|0;h=(k&240)-(e&240)|0;e=d&-66;d=(m&240|0)==0?m:m-6|0;m=(d&128|0)==0?h:h-16|0;h=(((j^i)&128&(l^k)|0)==0?e:e|64)|(l&65280|0)==0;a[9660979]=h;l=(((m&3840|0)==0?m:m+160|0)&240|d&15)&255;a[9660976]=l;d=(b[4830480]|0)-1&65535;m=c[2443776]|0;do{if((c[m+68+((d&65535)>>>8<<2)>>2]|0)==0){e=c[m+3148>>2]|0;if((e|0)==0){u=g;v=l;w=h;break}gj[e&4095](d)|0;u=c[2440596]|0;v=a[9660976]|0;w=a[9660979]|0}else{u=g;v=l;w=h}}while(0);c[2440596]=u-1;n=v;o=w;p=n<<24>>24==0;q=o&125;r=n&-128;s=p?2:r;t=s|q;a[9660979]=t;return}function fZS(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;g=(c[2440596]|0)-1|0;c[2440596]=g;b[4830480]=k+1&65535;e=k&65535;f=c[l+68+(e>>>8<<2)>>2]|0;do{if((f|0)==0){h=c[l+3168>>2]|0;if((h|0)==0){n=0;o=g;p=j;break}d=gj[h&4095](k)|0;n=d;o=c[2440596]|0;p=a[9660972]|0}else{n=a[f+(e&255)|0]|0;o=g;p=j}}while(0);a[9660973]=n;n=o-1|0;c[2440596]=n;o=a[9660978]|0;if(((o&255)+(p&255)|0)>255){p=(b[4830480]|0)-1&65535;j=c[2443776]|0;do{if((c[j+68+((p&65535)>>>8<<2)>>2]|0)==0){g=c[j+3148>>2]|0;if((g|0)==0){q=n;r=o;break}gj[g&4095](p)|0;q=c[2440596]|0;r=a[9660978]|0}else{q=n;r=o}}while(0);p=q-1|0;c[2440596]=p;s=r;t=p}else{s=o;t=n}b[4830486]=(b[4830486]|0)+(s&255)&65535;s=c[2415243]|0;n=s&65535;o=c[2443776]|0;p=c[o+68+((s>>>8&255)<<2)>>2]|0;do{if((p|0)==0){r=c[o+3148>>2]|0;if((r|0)==0){u=0;v=t;break}q=gj[r&4095](n)|0;u=q;v=c[2440596]|0}else{u=a[p+(s&255)|0]|0;v=t}}while(0);c[2440596]=v-1;v=a[9660976]|u;a[9660976]=v;a[9660979]=(v<<24>>24==0?2:v&-128)|a[9660979]&125;return}function fZT(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;g=(c[2440596]|0)-1|0;c[2440596]=g;b[4830480]=k+1&65535;e=k&65535;f=c[l+68+(e>>>8<<2)>>2]|0;do{if((f|0)==0){h=c[l+3168>>2]|0;if((h|0)==0){n=0;o=g;p=j;break}d=gj[h&4095](k)|0;n=d;o=c[2440596]|0;p=a[9660972]|0}else{n=a[f+(e&255)|0]|0;o=g;p=j}}while(0);a[9660973]=n;n=o-1|0;c[2440596]=n;o=a[9660978]|0;if(((o&255)+(p&255)|0)>255){p=(b[4830480]|0)-1&65535;j=c[2443776]|0;do{if((c[j+68+((p&65535)>>>8<<2)>>2]|0)==0){g=c[j+3148>>2]|0;if((g|0)==0){q=n;r=o;break}gj[g&4095](p)|0;q=c[2440596]|0;r=a[9660978]|0}else{q=n;r=o}}while(0);p=q-1|0;c[2440596]=p;s=r;t=p}else{s=o;t=n}b[4830486]=(b[4830486]|0)+(s&255)&65535;s=c[2415243]|0;n=s&65535;o=c[2443776]|0;p=c[o+68+((s>>>8&255)<<2)>>2]|0;do{if((p|0)==0){r=c[o+3148>>2]|0;if((r|0)==0){u=0;v=t;break}q=gj[r&4095](n)|0;u=q;v=c[2440596]|0}else{u=a[p+(s&255)|0]|0;v=t}}while(0);c[2440596]=v-1;v=a[9660976]&u;a[9660976]=v;a[9660979]=(v<<24>>24==0?2:v&-128)|a[9660979]&125;return}function fZU(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;g=(c[2440596]|0)-1|0;c[2440596]=g;b[4830480]=k+1&65535;e=k&65535;f=c[l+68+(e>>>8<<2)>>2]|0;do{if((f|0)==0){h=c[l+3168>>2]|0;if((h|0)==0){n=0;o=g;p=j;break}d=gj[h&4095](k)|0;n=d;o=c[2440596]|0;p=a[9660972]|0}else{n=a[f+(e&255)|0]|0;o=g;p=j}}while(0);a[9660973]=n;n=o-1|0;c[2440596]=n;o=a[9660978]|0;if(((o&255)+(p&255)|0)>255){p=(b[4830480]|0)-1&65535;j=c[2443776]|0;do{if((c[j+68+((p&65535)>>>8<<2)>>2]|0)==0){g=c[j+3148>>2]|0;if((g|0)==0){q=n;r=o;break}gj[g&4095](p)|0;q=c[2440596]|0;r=a[9660978]|0}else{q=n;r=o}}while(0);p=q-1|0;c[2440596]=p;s=r;t=p}else{s=o;t=n}b[4830486]=(b[4830486]|0)+(s&255)&65535;s=c[2415243]|0;n=s&65535;o=c[2443776]|0;p=c[o+68+((s>>>8&255)<<2)>>2]|0;do{if((p|0)==0){r=c[o+3148>>2]|0;if((r|0)==0){u=0;v=t;break}q=gj[r&4095](n)|0;u=q;v=c[2440596]|0}else{u=a[p+(s&255)|0]|0;v=t}}while(0);c[2440596]=v-1;v=a[9660976]|0;t=v^u;a[9660976]=t;a[9660979]=(v<<24>>24==u<<24>>24?2:t&-128)|a[9660979]&125;return}function fZV(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;g=(c[2440596]|0)-1|0;c[2440596]=g;b[4830480]=k+1&65535;e=k&65535;f=c[l+68+(e>>>8<<2)>>2]|0;do{if((f|0)==0){h=c[l+3168>>2]|0;if((h|0)==0){n=0;o=g;p=j;break}d=gj[h&4095](k)|0;n=d;o=c[2440596]|0;p=a[9660972]|0}else{n=a[f+(e&255)|0]|0;o=g;p=j}}while(0);a[9660973]=n;n=o-1|0;c[2440596]=n;o=a[9660978]|0;if(((o&255)+(p&255)|0)>255){p=(b[4830480]|0)-1&65535;j=c[2443776]|0;do{if((c[j+68+((p&65535)>>>8<<2)>>2]|0)==0){g=c[j+3148>>2]|0;if((g|0)==0){q=n;r=o;break}gj[g&4095](p)|0;q=c[2440596]|0;r=a[9660978]|0}else{q=n;r=o}}while(0);p=q-1|0;c[2440596]=p;s=r;t=p}else{s=o;t=n}b[4830486]=(b[4830486]|0)+(s&255)&65535;s=c[2415243]|0;n=s&65535;o=c[2443776]|0;p=c[o+68+((s>>>8&255)<<2)>>2]|0;do{if((p|0)==0){r=c[o+3148>>2]|0;if((r|0)==0){u=0;v=t;break}q=gj[r&4095](n)|0;u=q;v=c[2440596]|0}else{u=a[p+(s&255)|0]|0;v=t}}while(0);t=u&255;s=v-1|0;c[2440596]=s;v=a[9660979]|0;p=v&255;n=p&1;o=a[9660976]|0;q=o&255;if((p&8|0)==0){p=q+t+n|0;r=v&-66;j=((((o^u)&128^128)&(p^q)|0)==0?r:r|64)|(p&65280|0)!=0;a[9660979]=j;r=p&255;a[9660976]=r;w=r;x=j;y=w<<24>>24==0;z=x&125;A=w&-128;B=y?2:A;C=B|z;a[9660979]=C;return}j=n+(t&15)+(q&15)|0;n=(q&240)+(t&240)|0;t=v&-66;a[9660979]=t;if((j|0)>9){D=j+6|0;E=n+16|0}else{D=j;E=n}if((((o^u)&128^128)&(E^q)|0)==0){F=t}else{q=t|64;a[9660979]=q;F=q}q=(E|0)>144?E+96|0:E;if((q&65280|0)==0){G=F}else{E=F|1;a[9660979]=E;G=E}E=(q&240|D&15)&255;a[9660976]=E;D=(b[4830480]|0)-1&65535;q=c[2443776]|0;do{if((c[q+68+((D&65535)>>>8<<2)>>2]|0)==0){F=c[q+3148>>2]|0;if((F|0)==0){H=s;I=E;J=G;break}gj[F&4095](D)|0;H=c[2440596]|0;I=a[9660976]|0;J=a[9660979]|0}else{H=s;I=E;J=G}}while(0);c[2440596]=H-1;w=I;x=J;y=w<<24>>24==0;z=x&125;A=w&-128;B=y?2:A;C=B|z;a[9660979]=C;return}function fZW(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;e=a[9660976]|0;f=b[4830480]|0;g=f+1&65535;b[4830480]=g;h=f&65535;i=c[2443776]|0;j=c[i+68+(h>>>8<<2)>>2]|0;do{if((j|0)==0){k=c[i+3168>>2]|0;if((k|0)==0){l=0;m=g;n=i;break}o=gj[k&4095](f)|0;l=o;m=b[4830480]|0;n=c[2443776]|0}else{l=a[j+(h&255)|0]|0;m=g;n=i}}while(0);a[9660972]=l;l=(c[2440596]|0)-1|0;c[2440596]=l;i=m+1&65535;b[4830480]=i;g=m&65535;h=c[n+68+(g>>>8<<2)>>2]|0;do{if((h|0)==0){j=c[n+3168>>2]|0;if((j|0)==0){p=0;q=l;r=i;s=n;break}f=gj[j&4095](m)|0;p=f;q=c[2440596]|0;r=b[4830480]|0;s=c[2443776]|0}else{p=a[h+(g&255)|0]|0;q=l;r=i;s=n}}while(0);a[9660973]=p;p=q-1|0;c[2440596]=p;q=r-1&65535;do{if((c[s+68+((q&65535)>>>8<<2)>>2]|0)==0){r=c[s+3148>>2]|0;if((r|0)==0){t=p;u=s;break}gj[r&4095](q)|0;t=c[2440596]|0;u=c[2443776]|0}else{t=p;u=s}}while(0);s=t-1|0;c[2440596]=s;b[4830486]=(b[4830486]|0)+(d[9660978]|0)&65535;t=c[2415243]|0;p=c[u+68+((t>>>8&255|256)<<2)>>2]|0;if((p|0)!=0){a[p+(t&255)|0]=e;v=s;w=v-1|0;c[2440596]=w;return}p=c[u+3152>>2]|0;if((p|0)==0){v=s;w=v-1|0;c[2440596]=w;return}gg[p&4095](t&65535,e);v=c[2440596]|0;w=v-1|0;c[2440596]=w;return}function fZX(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;g=(c[2440596]|0)-1|0;c[2440596]=g;b[4830480]=k+1&65535;e=k&65535;f=c[l+68+(e>>>8<<2)>>2]|0;do{if((f|0)==0){h=c[l+3168>>2]|0;if((h|0)==0){n=0;o=g;p=j;break}d=gj[h&4095](k)|0;n=d;o=c[2440596]|0;p=a[9660972]|0}else{n=a[f+(e&255)|0]|0;o=g;p=j}}while(0);a[9660973]=n;n=o-1|0;c[2440596]=n;o=a[9660978]|0;if(((o&255)+(p&255)|0)>255){p=(b[4830480]|0)-1&65535;j=c[2443776]|0;do{if((c[j+68+((p&65535)>>>8<<2)>>2]|0)==0){g=c[j+3148>>2]|0;if((g|0)==0){q=n;r=o;break}gj[g&4095](p)|0;q=c[2440596]|0;r=a[9660978]|0}else{q=n;r=o}}while(0);p=q-1|0;c[2440596]=p;s=r;t=p}else{s=o;t=n}b[4830486]=(b[4830486]|0)+(s&255)&65535;s=c[2415243]|0;n=s&65535;o=c[2443776]|0;p=c[o+68+((s>>>8&255)<<2)>>2]|0;do{if((p|0)==0){r=c[o+3148>>2]|0;if((r|0)==0){u=0;v=t;break}q=gj[r&4095](n)|0;u=q;v=c[2440596]|0}else{u=a[p+(s&255)|0]|0;v=t}}while(0);c[2440596]=v-1;a[9660976]=u;a[9660979]=a[9660979]&125|(u<<24>>24==0?2:u&-128);return}function fZY(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;g=(c[2440596]|0)-1|0;c[2440596]=g;b[4830480]=k+1&65535;e=k&65535;f=c[l+68+(e>>>8<<2)>>2]|0;do{if((f|0)==0){h=c[l+3168>>2]|0;if((h|0)==0){n=0;o=g;p=j;break}d=gj[h&4095](k)|0;n=d;o=c[2440596]|0;p=a[9660972]|0}else{n=a[f+(e&255)|0]|0;o=g;p=j}}while(0);a[9660973]=n;n=o-1|0;c[2440596]=n;o=a[9660978]|0;if(((o&255)+(p&255)|0)>255){p=(b[4830480]|0)-1&65535;j=c[2443776]|0;do{if((c[j+68+((p&65535)>>>8<<2)>>2]|0)==0){g=c[j+3148>>2]|0;if((g|0)==0){q=n;r=o;break}gj[g&4095](p)|0;q=c[2440596]|0;r=a[9660978]|0}else{q=n;r=o}}while(0);p=q-1|0;c[2440596]=p;s=r;t=p}else{s=o;t=n}b[4830486]=(b[4830486]|0)+(s&255)&65535;s=c[2415243]|0;n=s&65535;o=c[2443776]|0;p=c[o+68+((s>>>8&255)<<2)>>2]|0;do{if((p|0)==0){r=c[o+3148>>2]|0;if((r|0)==0){u=0;v=t;break}q=gj[r&4095](n)|0;u=q;v=c[2440596]|0}else{u=a[p+(s&255)|0]|0;v=t}}while(0);c[2440596]=v-1;v=a[9660979]|0;t=v&-2;a[9660979]=t;s=a[9660976]|0;if((s&255)<(u&255)){w=t}else{t=v|1;a[9660979]=t;w=t}if(s<<24>>24==u<<24>>24){x=w&125|2;a[9660979]=x;return}else{x=w&125|s-u&255&-128;a[9660979]=x;return}}function fZZ(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;g=(c[2440596]|0)-1|0;c[2440596]=g;b[4830480]=k+1&65535;e=k&65535;f=c[l+68+(e>>>8<<2)>>2]|0;do{if((f|0)==0){h=c[l+3168>>2]|0;if((h|0)==0){n=0;o=g;p=j;break}d=gj[h&4095](k)|0;n=d;o=c[2440596]|0;p=a[9660972]|0}else{n=a[f+(e&255)|0]|0;o=g;p=j}}while(0);a[9660973]=n;n=o-1|0;c[2440596]=n;o=a[9660978]|0;if(((o&255)+(p&255)|0)>255){p=(b[4830480]|0)-1&65535;j=c[2443776]|0;do{if((c[j+68+((p&65535)>>>8<<2)>>2]|0)==0){g=c[j+3148>>2]|0;if((g|0)==0){q=n;r=o;break}gj[g&4095](p)|0;q=c[2440596]|0;r=a[9660978]|0}else{q=n;r=o}}while(0);p=q-1|0;c[2440596]=p;s=r;t=p}else{s=o;t=n}b[4830486]=(b[4830486]|0)+(s&255)&65535;s=c[2415243]|0;n=s&65535;o=c[2443776]|0;p=c[o+68+((s>>>8&255)<<2)>>2]|0;do{if((p|0)==0){r=c[o+3148>>2]|0;if((r|0)==0){u=0;v=t;break}q=gj[r&4095](n)|0;u=q;v=c[2440596]|0}else{u=a[p+(s&255)|0]|0;v=t}}while(0);t=u&255;s=v-1|0;c[2440596]=s;v=a[9660979]|0;p=v&255;n=p&1^1;o=a[9660976]|0;q=o&255;r=q-t-n|0;if((p&8|0)==0){p=v&-66;j=(((o^u)&128&(r^q)|0)==0?p:p|64)|(r&65280|0)==0;a[9660979]=j;p=r&255;a[9660976]=p;w=p;x=j;y=w<<24>>24==0;z=x&125;A=w&-128;B=y?2:A;C=B|z;a[9660979]=C;return}j=(q&15)-(t&15)-n|0;n=(q&240)-(t&240)|0;t=v&-66;v=(j&240|0)==0?j:j-6|0;j=(v&128|0)==0?n:n-16|0;n=(((o^u)&128&(r^q)|0)==0?t:t|64)|(r&65280|0)==0;a[9660979]=n;r=(((j&3840|0)==0?j:j+160|0)&240|v&15)&255;a[9660976]=r;v=(b[4830480]|0)-1&65535;j=c[2443776]|0;do{if((c[j+68+((v&65535)>>>8<<2)>>2]|0)==0){t=c[j+3148>>2]|0;if((t|0)==0){D=s;E=r;F=n;break}gj[t&4095](v)|0;D=c[2440596]|0;E=a[9660976]|0;F=a[9660979]|0}else{D=s;E=r;F=n}}while(0);c[2440596]=D-1;w=E;x=F;y=w<<24>>24==0;z=x&125;A=w&-128;B=y?2:A;C=B|z;a[9660979]=C;return}function fZ_(){var d=0,e=0,f=0;d=b[4830480]|0;e=c[2443776]|0;do{if((c[e+68+((d&65535)>>>8<<2)>>2]|0)==0){f=c[e+3148>>2]|0;if((f|0)==0){break}gj[f&4095](d)|0}}while(0);c[2440596]=(c[2440596]|0)-1;d=a[9660976]|0;e=d<<1;a[9660979]=a[9660979]&124|(d&255)>>>7|(e<<24>>24==0?2:e&-128);a[9660976]=e;return}function fZ$(){var d=0,e=0,f=0,g=0;d=b[4830480]|0;e=c[2443776]|0;do{if((c[e+68+((d&65535)>>>8<<2)>>2]|0)==0){f=c[e+3148>>2]|0;if((f|0)==0){break}gj[f&4095](d)|0}}while(0);c[2440596]=(c[2440596]|0)-1;d=a[9660976]|0;e=d<<1;f=a[9660979]|0;g=f&1|e;a[9660979]=f&124|(d&255)>>>7|(g<<24>>24==0?2:e&-128);a[9660976]=g;return}function fZ0(){var d=0,e=0,f=0;d=b[4830480]|0;e=c[2443776]|0;do{if((c[e+68+((d&65535)>>>8<<2)>>2]|0)==0){f=c[e+3148>>2]|0;if((f|0)==0){break}gj[f&4095](d)|0}}while(0);c[2440596]=(c[2440596]|0)-1;d=a[9660976]|0;e=a[9660979]&124|d&1;f=(d&255)>>>1;a[9660979]=(f|0)==0?e|2:e;a[9660976]=f&255;return}function fZ1(){var d=0,e=0,f=0,g=0,h=0,i=0;d=b[4830480]|0;e=c[2443776]|0;do{if((c[e+68+((d&65535)>>>8<<2)>>2]|0)==0){f=c[e+3148>>2]|0;if((f|0)==0){break}gj[f&4095](d)|0}}while(0);c[2440596]=(c[2440596]|0)-1;d=a[9660976]|0;e=a[9660979]|0;f=e&-2|d&1;a[9660979]=f;g=((e&255)<<8|d&255)>>>1;if((g&255|0)==0){h=f&125|2;a[9660979]=h;i=g&255;a[9660976]=i;return}else{h=(g&128|f&125)&255;a[9660979]=h;i=g&255;a[9660976]=i;return}}function fZ2(){var d=0,e=0,f=0;d=b[4830480]|0;e=c[2443776]|0;do{if((c[e+68+((d&65535)>>>8<<2)>>2]|0)==0){f=c[e+3148>>2]|0;if((f|0)==0){break}gj[f&4095](d)|0}}while(0);c[2440596]=(c[2440596]|0)-1;d=a[9660977]|0;a[9660976]=d;a[9660979]=a[9660979]&125|(d<<24>>24==0?2:d&-128);return}function fZ3(){var d=0,e=0,f=0;d=b[4830480]|0;e=c[2443776]|0;do{if((c[e+68+((d&65535)>>>8<<2)>>2]|0)==0){f=c[e+3148>>2]|0;if((f|0)==0){break}gj[f&4095](d)|0}}while(0);c[2440596]=(c[2440596]|0)-1;d=a[9660976]|0;a[9660977]=d;a[9660979]=a[9660979]&125|(d<<24>>24==0?2:d&-128);return}function fZ4(){var d=0,e=0,f=0;d=b[4830480]|0;e=c[2443776]|0;do{if((c[e+68+((d&65535)>>>8<<2)>>2]|0)==0){f=c[e+3148>>2]|0;if((f|0)==0){break}gj[f&4095](d)|0}}while(0);c[2440596]=(c[2440596]|0)-1;d=(a[9660977]|0)-1&255;a[9660977]=d;a[9660979]=(d<<24>>24==0?2:d&-128)|a[9660979]&125;return}function fZ5(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function fZ6(){var d=0,e=0,f=0;d=b[4830480]|0;e=c[2443776]|0;do{if((c[e+68+((d&65535)>>>8<<2)>>2]|0)==0){f=c[e+3148>>2]|0;if((f|0)==0){break}gj[f&4095](d)|0}}while(0);c[2440596]=(c[2440596]|0)-1;d=(a[9660976]|0)+1&255;a[9660976]=d;a[9660979]=(d<<24>>24==0?2:d&-128)|a[9660979]&125;return}function fZ7(){var d=0,e=0,f=0;d=b[4830480]|0;e=c[2443776]|0;do{if((c[e+68+((d&65535)>>>8<<2)>>2]|0)==0){f=c[e+3148>>2]|0;if((f|0)==0){break}gj[f&4095](d)|0}}while(0);c[2440596]=(c[2440596]|0)-1;d=(a[9660976]|0)-1&255;a[9660976]=d;a[9660979]=(d<<24>>24==0?2:d&-128)|a[9660979]&125;return}function fZ8(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=b[4830480]|0;e=c[2443776]|0;do{if((c[e+68+((d&65535)>>>8<<2)>>2]|0)==0){f=c[e+3148>>2]|0;if((f|0)==0){g=e;break}gj[f&4095](d)|0;g=c[2443776]|0}else{g=e}}while(0);e=(c[2440596]|0)-1|0;c[2440596]=e;d=c[2415241]|0;f=d&65535;h=a[9660978]|0;i=c[g+68+((d>>>8&255|256)<<2)>>2]|0;do{if((i|0)==0){j=c[g+3152>>2]|0;if((j|0)==0){k=e;break}gg[j&4095](f,h);k=c[2440596]|0}else{a[i+(d&255)|0]=h;k=e}}while(0);c[2440596]=k-1;a[9660964]=(a[9660964]|0)-1&255;return}function fZ9(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=b[4830480]|0;e=c[2443776]|0;do{if((c[e+68+((d&65535)>>>8<<2)>>2]|0)==0){f=c[e+3148>>2]|0;if((f|0)==0){g=e;break}gj[f&4095](d)|0;g=c[2443776]|0}else{g=e}}while(0);e=(c[2440596]|0)-1|0;c[2440596]=e;d=c[2415241]|0;f=d&65535;h=d&255;do{if((c[g+68+((d>>>8&255)<<2)>>2]|0)==0){i=c[g+3148>>2]|0;if((i|0)==0){j=e;k=h;l=g;break}gj[i&4095](f)|0;j=c[2440596]|0;k=a[9660964]|0;l=c[2443776]|0}else{j=e;k=h;l=g}}while(0);g=j-1|0;c[2440596]=g;a[9660964]=k+1&255;k=c[2415241]|0;j=k&65535;h=c[l+68+((k>>>8&255)<<2)>>2]|0;do{if((h|0)==0){e=c[l+3148>>2]|0;if((e|0)==0){m=0;n=g;break}f=gj[e&4095](j)|0;m=f;n=c[2440596]|0}else{m=a[h+(k&255)|0]|0;n=g}}while(0);a[9660978]=m;c[2440596]=n-1;a[9660979]=a[9660979]&125|(m<<24>>24==0?2:m&-128);return}function f_a(){var d=0,e=0,f=0;d=b[4830480]|0;e=c[2443776]|0;do{if((c[e+68+((d&65535)>>>8<<2)>>2]|0)==0){f=c[e+3148>>2]|0;if((f|0)==0){break}gj[f&4095](d)|0}}while(0);c[2440596]=(c[2440596]|0)-1;a[9660964]=a[9660977]|0;return}function f_b(){var d=0,e=0,f=0;d=b[4830480]|0;e=c[2443776]|0;do{if((c[e+68+((d&65535)>>>8<<2)>>2]|0)==0){f=c[e+3148>>2]|0;if((f|0)==0){break}gj[f&4095](d)|0}}while(0);c[2440596]=(c[2440596]|0)-1;d=a[9660964]|0;a[9660977]=d;a[9660979]=a[9660979]&125|(d<<24>>24==0?2:d&-128);return}function f_c(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=b[4830480]|0;e=c[2443776]|0;do{if((c[e+68+((d&65535)>>>8<<2)>>2]|0)==0){f=c[e+3148>>2]|0;if((f|0)==0){g=e;break}gj[f&4095](d)|0;g=c[2443776]|0}else{g=e}}while(0);e=(c[2440596]|0)-1|0;c[2440596]=e;d=c[2415241]|0;f=d&65535;h=a[9660977]|0;i=c[g+68+((d>>>8&255|256)<<2)>>2]|0;do{if((i|0)==0){j=c[g+3152>>2]|0;if((j|0)==0){k=e;break}gg[j&4095](f,h);k=c[2440596]|0}else{a[i+(d&255)|0]=h;k=e}}while(0);c[2440596]=k-1;a[9660964]=(a[9660964]|0)-1&255;return}function f_d(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=b[4830480]|0;e=c[2443776]|0;do{if((c[e+68+((d&65535)>>>8<<2)>>2]|0)==0){f=c[e+3148>>2]|0;if((f|0)==0){g=e;break}gj[f&4095](d)|0;g=c[2443776]|0}else{g=e}}while(0);e=(c[2440596]|0)-1|0;c[2440596]=e;d=c[2415241]|0;f=d&65535;h=d&255;do{if((c[g+68+((d>>>8&255)<<2)>>2]|0)==0){i=c[g+3148>>2]|0;if((i|0)==0){j=e;k=h;l=g;break}gj[i&4095](f)|0;j=c[2440596]|0;k=a[9660964]|0;l=c[2443776]|0}else{j=e;k=h;l=g}}while(0);g=j-1|0;c[2440596]=g;a[9660964]=k+1&255;k=c[2415241]|0;j=k&65535;h=c[l+68+((k>>>8&255)<<2)>>2]|0;do{if((h|0)==0){e=c[l+3148>>2]|0;if((e|0)==0){m=0;n=g;break}f=gj[e&4095](j)|0;m=f;n=c[2440596]|0}else{m=a[h+(k&255)|0]|0;n=g}}while(0);a[9660977]=m;c[2440596]=n-1;a[9660979]=a[9660979]&125|(m<<24>>24==0?2:m&-128);return}function f_e(){return}function f_f(){return}function f_g(){return}function f_h(){return}function f_i(){return}function f_j(){return}function f_k(){return}function f_l(){return}function f_m(){return}function f_n(){return}function f_o(){return}function f_p(){return}function f_q(){return}function f_r(){return}function f_s(){return}function f_t(){return}function f_u(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;b[4830480]=k+1&65535;g=k&65535;e=c[l+68+(g>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[l+3168>>2]|0;if((f|0)==0){n=0;o=j;p=l;break}h=gj[f&4095](k)|0;n=h;o=c[2440596]|0;p=c[2443776]|0}else{n=a[e+(g&255)|0]|0;o=j;p=l}}while(0);a[9660973]=n;n=o-1|0;c[2440596]=n;o=c[2415243]|0;l=o&65535;j=c[p+68+((o>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[p+3148>>2]|0;if((g|0)==0){q=0;r=n;s=o;t=p;break}e=gj[g&4095](l)|0;q=e;r=c[2440596]|0;s=c[2415243]|0;t=c[2443776]|0}else{q=a[j+(o&255)|0]|0;r=n;s=o;t=p}}while(0);p=r-1|0;c[2440596]=p;r=s&65535;do{if((c[t+68+((s>>>8&255)<<2)>>2]|0)==0){o=c[t+3148>>2]|0;if((o|0)==0){u=p;v=s;w=t;break}gj[o&4095](r)|0;u=c[2440596]|0;v=c[2415243]|0;w=c[2443776]|0}else{u=p;v=s;w=t}}while(0);t=u-1|0;c[2440596]=t;u=a[9660976]|0;s=a[9660979]|0;a[9660979]=(u&q)<<24>>24==0?s|2:s&-3;s=u|q;q=c[w+68+((v>>>8&255|256)<<2)>>2]|0;if((q|0)!=0){a[q+(v&255)|0]=s;x=t;y=x-1|0;c[2440596]=y;return}q=c[w+3152>>2]|0;if((q|0)==0){x=t;y=x-1|0;c[2440596]=y;return}gg[q&4095](v&65535,s);x=c[2440596]|0;y=x-1|0;c[2440596]=y;return}function f_v(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;b[4830480]=k+1&65535;g=k&65535;e=c[l+68+(g>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[l+3168>>2]|0;if((f|0)==0){n=0;o=j;p=l;break}h=gj[f&4095](k)|0;n=h;o=c[2440596]|0;p=c[2443776]|0}else{n=a[e+(g&255)|0]|0;o=j;p=l}}while(0);a[9660973]=n;n=o-1|0;c[2440596]=n;o=c[2415243]|0;l=o&65535;j=c[p+68+((o>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[p+3148>>2]|0;if((g|0)==0){q=0;r=n;break}e=gj[g&4095](l)|0;q=e;r=c[2440596]|0}else{q=a[j+(o&255)|0]|0;r=n}}while(0);c[2440596]=r-1;r=a[9660979]&61|q&-64;a[9660979]=r;if((a[9660976]&q)<<24>>24!=0){return}a[9660979]=r|2;return}function f_w(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;b[4830480]=k+1&65535;g=k&65535;e=c[l+68+(g>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[l+3168>>2]|0;if((f|0)==0){n=0;o=j;break}h=gj[f&4095](k)|0;n=h;o=c[2440596]|0}else{n=a[e+(g&255)|0]|0;o=j}}while(0);a[9660973]=n;n=o-1|0;c[2440596]=n;o=c[2415243]|0;if(!((n|0)>0&(((o|0)!=(c[2415239]|0)|(a[9660980]|0)!=0|(a[9660981]|0)!=0)^1))){c[2415240]=o;return}c[2440596]=0;c[2415240]=o;return}function f_x(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;b[4830480]=k+1&65535;g=k&65535;e=c[l+68+(g>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[l+3168>>2]|0;if((f|0)==0){n=0;o=j;p=l;break}h=gj[f&4095](k)|0;n=h;o=c[2440596]|0;p=c[2443776]|0}else{n=a[e+(g&255)|0]|0;o=j;p=l}}while(0);a[9660973]=n;n=o-1|0;c[2440596]=n;o=c[2415243]|0;l=o&65535;j=c[p+68+((o>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[p+3148>>2]|0;if((g|0)==0){q=0;r=n;s=p;break}e=gj[g&4095](l)|0;q=e;r=c[2440596]|0;s=c[2443776]|0}else{q=a[j+(o&255)|0]|0;r=n;s=p}}while(0);p=r-1|0;c[2440596]=p;r=(b[4830480]|0)-1&65535;do{if((c[s+68+((r&65535)>>>8<<2)>>2]|0)==0){n=c[s+3148>>2]|0;if((n|0)==0){t=p;u=s;break}gj[n&4095](r)|0;t=c[2440596]|0;u=c[2443776]|0}else{t=p;u=s}}while(0);s=t-1|0;c[2440596]=s;t=(c[2415243]|0)+1|0;c[2415243]=t;p=t&65535;r=c[u+68+((t>>>8&255)<<2)>>2]|0;do{if((r|0)==0){n=c[u+3148>>2]|0;if((n|0)==0){v=0;w=s;break}o=gj[n&4095](p)|0;v=o;w=c[2440596]|0}else{v=a[r+(t&255)|0]|0;w=s}}while(0);a[9660973]=v;v=w-1|0;c[2440596]=v;a[9660972]=q;q=c[2415243]|0;if(!((v|0)>0&(((q|0)!=(c[2415239]|0)|(a[9660980]|0)!=0|(a[9660981]|0)!=0)^1))){c[2415240]=q;return}c[2440596]=0;c[2415240]=q;return}function f_y(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=a[9660978]|0;e=b[4830480]|0;f=e+1&65535;b[4830480]=f;g=e&65535;h=c[2443776]|0;i=c[h+68+(g>>>8<<2)>>2]|0;do{if((i|0)==0){j=c[h+3168>>2]|0;if((j|0)==0){k=0;l=f;m=h;break}n=gj[j&4095](e)|0;k=n;l=b[4830480]|0;m=c[2443776]|0}else{k=a[i+(g&255)|0]|0;l=f;m=h}}while(0);a[9660972]=k;k=(c[2440596]|0)-1|0;c[2440596]=k;b[4830480]=l+1&65535;h=l&65535;f=c[m+68+(h>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[m+3168>>2]|0;if((g|0)==0){o=0;p=k;q=m;break}i=gj[g&4095](l)|0;o=i;p=c[2440596]|0;q=c[2443776]|0}else{o=a[f+(h&255)|0]|0;p=k;q=m}}while(0);a[9660973]=o;o=p-1|0;c[2440596]=o;p=c[2415243]|0;m=c[q+68+((p>>>8&255|256)<<2)>>2]|0;if((m|0)!=0){a[m+(p&255)|0]=d;r=o;s=r-1|0;c[2440596]=s;return}m=c[q+3152>>2]|0;if((m|0)==0){r=o;s=r-1|0;c[2440596]=s;return}gg[m&4095](p&65535,d);r=c[2440596]|0;s=r-1|0;c[2440596]=s;return}function f_z(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;b[4830480]=k+1&65535;g=k&65535;e=c[l+68+(g>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[l+3168>>2]|0;if((f|0)==0){n=0;o=j;p=l;break}h=gj[f&4095](k)|0;n=h;o=c[2440596]|0;p=c[2443776]|0}else{n=a[e+(g&255)|0]|0;o=j;p=l}}while(0);a[9660973]=n;n=o-1|0;c[2440596]=n;o=c[2415243]|0;l=o&65535;j=c[p+68+((o>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[p+3148>>2]|0;if((g|0)==0){q=0;r=n;break}e=gj[g&4095](l)|0;q=e;r=c[2440596]|0}else{q=a[j+(o&255)|0]|0;r=n}}while(0);c[2440596]=r-1;a[9660978]=q;a[9660979]=a[9660979]&125|(q<<24>>24==0?2:q&-128);return}function f_A(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;b[4830480]=k+1&65535;g=k&65535;e=c[l+68+(g>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[l+3168>>2]|0;if((f|0)==0){n=0;o=j;p=l;break}h=gj[f&4095](k)|0;n=h;o=c[2440596]|0;p=c[2443776]|0}else{n=a[e+(g&255)|0]|0;o=j;p=l}}while(0);a[9660973]=n;n=o-1|0;c[2440596]=n;o=c[2415243]|0;l=o&65535;j=c[p+68+((o>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[p+3148>>2]|0;if((g|0)==0){q=0;r=n;break}e=gj[g&4095](l)|0;q=e;r=c[2440596]|0}else{q=a[j+(o&255)|0]|0;r=n}}while(0);c[2440596]=r-1;r=a[9660979]|0;n=r&-2;a[9660979]=n;o=a[9660978]|0;if((o&255)<(q&255)){s=n}else{n=r|1;a[9660979]=n;s=n}if(o<<24>>24==q<<24>>24){t=s&125|2;a[9660979]=t;return}else{t=s&125|o-q&255&-128;a[9660979]=t;return}}function f_B(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;b[4830480]=k+1&65535;g=k&65535;e=c[l+68+(g>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[l+3168>>2]|0;if((f|0)==0){n=0;o=j;p=l;break}h=gj[f&4095](k)|0;n=h;o=c[2440596]|0;p=c[2443776]|0}else{n=a[e+(g&255)|0]|0;o=j;p=l}}while(0);a[9660973]=n;n=o-1|0;c[2440596]=n;o=c[2415243]|0;l=o&65535;j=c[p+68+((o>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[p+3148>>2]|0;if((g|0)==0){q=0;r=n;break}e=gj[g&4095](l)|0;q=e;r=c[2440596]|0}else{q=a[j+(o&255)|0]|0;r=n}}while(0);c[2440596]=r-1;r=a[9660979]|0;n=r&-2;a[9660979]=n;o=a[9660977]|0;if((o&255)<(q&255)){s=n}else{n=r|1;a[9660979]=n;s=n}if(o<<24>>24==q<<24>>24){t=s&125|2;a[9660979]=t;return}else{t=s&125|o-q&255&-128;a[9660979]=t;return}}function f_C(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;b[4830480]=k+1&65535;g=k&65535;e=c[l+68+(g>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[l+3168>>2]|0;if((f|0)==0){n=0;o=j;p=l;break}h=gj[f&4095](k)|0;n=h;o=c[2440596]|0;p=c[2443776]|0}else{n=a[e+(g&255)|0]|0;o=j;p=l}}while(0);a[9660973]=n;n=o-1|0;c[2440596]=n;o=c[2415243]|0;l=o&65535;j=c[p+68+((o>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[p+3148>>2]|0;if((g|0)==0){q=0;r=n;s=o;t=p;break}e=gj[g&4095](l)|0;q=e;r=c[2440596]|0;s=c[2415243]|0;t=c[2443776]|0}else{q=a[j+(o&255)|0]|0;r=n;s=o;t=p}}while(0);p=r-1|0;c[2440596]=p;r=s&65535;do{if((c[t+68+((s>>>8&255)<<2)>>2]|0)==0){o=c[t+3148>>2]|0;if((o|0)==0){u=p;v=s;w=t;break}gj[o&4095](r)|0;u=c[2440596]|0;v=c[2415243]|0;w=c[2443776]|0}else{u=p;v=s;w=t}}while(0);t=u-1|0;c[2440596]=t;u=a[9660976]|0;s=a[9660979]|0;a[9660979]=(u&q)<<24>>24==0?s|2:s&-3;s=q&~u;u=c[w+68+((v>>>8&255|256)<<2)>>2]|0;if((u|0)!=0){a[u+(v&255)|0]=s;x=t;y=x-1|0;c[2440596]=y;return}u=c[w+3152>>2]|0;if((u|0)==0){x=t;y=x-1|0;c[2440596]=y;return}gg[u&4095](v&65535,s);x=c[2440596]|0;y=x-1|0;c[2440596]=y;return}function f_D(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;g=(c[2440596]|0)-1|0;c[2440596]=g;b[4830480]=k+1&65535;e=k&65535;f=c[l+68+(e>>>8<<2)>>2]|0;do{if((f|0)==0){h=c[l+3168>>2]|0;if((h|0)==0){n=0;o=g;p=j;break}d=gj[h&4095](k)|0;n=d;o=c[2440596]|0;p=a[9660972]|0}else{n=a[f+(e&255)|0]|0;o=g;p=j}}while(0);a[9660973]=n;n=o-1|0;c[2440596]=n;o=a[9660977]|0;if(((o&255)+(p&255)|0)>255){p=(b[4830480]|0)-1&65535;j=c[2443776]|0;do{if((c[j+68+((p&65535)>>>8<<2)>>2]|0)==0){g=c[j+3148>>2]|0;if((g|0)==0){q=n;r=o;break}gj[g&4095](p)|0;q=c[2440596]|0;r=a[9660977]|0}else{q=n;r=o}}while(0);p=q-1|0;c[2440596]=p;s=r;t=p}else{s=o;t=n}b[4830486]=(b[4830486]|0)+(s&255)&65535;s=c[2415243]|0;n=s&65535;o=c[2443776]|0;p=c[o+68+((s>>>8&255)<<2)>>2]|0;do{if((p|0)==0){r=c[o+3148>>2]|0;if((r|0)==0){u=0;v=t;break}q=gj[r&4095](n)|0;u=q;v=c[2440596]|0}else{u=a[p+(s&255)|0]|0;v=t}}while(0);c[2440596]=v-1;v=a[9660979]&61|u&-64;a[9660979]=v;if((a[9660976]&u)<<24>>24!=0){return}a[9660979]=v|2;return}function f_E(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;e=b[4830480]|0;f=e+1&65535;b[4830480]=f;g=e&65535;h=c[2443776]|0;i=c[h+68+(g>>>8<<2)>>2]|0;do{if((i|0)==0){j=c[h+3168>>2]|0;if((j|0)==0){k=0;l=f;m=h;break}n=gj[j&4095](e)|0;k=n;l=b[4830480]|0;m=c[2443776]|0}else{k=a[i+(g&255)|0]|0;l=f;m=h}}while(0);a[9660972]=k;k=(c[2440596]|0)-1|0;c[2440596]=k;h=l+1&65535;b[4830480]=h;f=l&65535;g=c[m+68+(f>>>8<<2)>>2]|0;do{if((g|0)==0){i=c[m+3168>>2]|0;if((i|0)==0){o=0;p=k;q=h;r=m;break}e=gj[i&4095](l)|0;o=e;p=c[2440596]|0;q=b[4830480]|0;r=c[2443776]|0}else{o=a[g+(f&255)|0]|0;p=k;q=h;r=m}}while(0);a[9660973]=o;o=p-1|0;c[2440596]=o;p=q-1&65535;do{if((c[r+68+((p&65535)>>>8<<2)>>2]|0)==0){q=c[r+3148>>2]|0;if((q|0)==0){s=o;t=r;break}gj[q&4095](p)|0;s=c[2440596]|0;t=c[2443776]|0}else{s=o;t=r}}while(0);r=s-1|0;c[2440596]=r;b[4830486]=(b[4830486]|0)+(d[9660977]|0)&65535;s=c[2415243]|0;o=s&65535;do{if((c[t+68+((s>>>8&255)<<2)>>2]|0)==0){p=c[t+3148>>2]|0;if((p|0)==0){u=r;v=t;break}gj[p&4095](o)|0;u=c[2440596]|0;v=c[2443776]|0}else{u=r;v=t}}while(0);t=u-1|0;c[2440596]=t;u=b[4830480]|0;do{if((c[v+68+((u&65535)>>>8<<2)>>2]|0)==0){r=c[v+3148>>2]|0;if((r|0)==0){w=t;x=u;y=v;break}gj[r&4095](u)|0;w=c[2440596]|0;x=b[4830480]|0;y=c[2443776]|0}else{w=t;x=u;y=v}}while(0);v=w-1|0;c[2440596]=v;do{if((c[y+68+((x&65535)>>>8<<2)>>2]|0)==0){w=c[y+3148>>2]|0;if((w|0)==0){z=v;A=x;B=y;break}gj[w&4095](x)|0;z=c[2440596]|0;A=b[4830480]|0;B=c[2443776]|0}else{z=v;A=x;B=y}}while(0);y=z-1|0;c[2440596]=y;do{if((c[B+68+((A&65535)>>>8<<2)>>2]|0)==0){z=c[B+3148>>2]|0;if((z|0)==0){C=y;D=A;E=B;break}gj[z&4095](A)|0;C=c[2440596]|0;D=b[4830480]|0;E=c[2443776]|0}else{C=y;D=A;E=B}}while(0);B=C-1|0;c[2440596]=B;if((c[E+68+((D&65535)>>>8<<2)>>2]|0)!=0){F=B;G=F-1|0;c[2440596]=G;return}C=c[E+3148>>2]|0;if((C|0)==0){F=B;G=F-1|0;c[2440596]=G;return}gj[C&4095](D)|0;F=c[2440596]|0;G=F-1|0;c[2440596]=G;return}function f_F(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;e=b[4830480]|0;f=e+1&65535;b[4830480]=f;g=e&65535;h=c[2443776]|0;i=c[h+68+(g>>>8<<2)>>2]|0;do{if((i|0)==0){j=c[h+3168>>2]|0;if((j|0)==0){k=0;l=f;m=h;break}n=gj[j&4095](e)|0;k=n;l=b[4830480]|0;m=c[2443776]|0}else{k=a[i+(g&255)|0]|0;l=f;m=h}}while(0);a[9660972]=k;k=(c[2440596]|0)-1|0;c[2440596]=k;h=l+1&65535;b[4830480]=h;f=l&65535;g=c[m+68+(f>>>8<<2)>>2]|0;do{if((g|0)==0){i=c[m+3168>>2]|0;if((i|0)==0){o=0;p=k;q=h;r=m;break}e=gj[i&4095](l)|0;o=e;p=c[2440596]|0;q=b[4830480]|0;r=c[2443776]|0}else{o=a[g+(f&255)|0]|0;p=k;q=h;r=m}}while(0);a[9660973]=o;o=p-1|0;c[2440596]=o;p=q-1&65535;do{if((c[r+68+((p&65535)>>>8<<2)>>2]|0)==0){q=c[r+3148>>2]|0;if((q|0)==0){s=o;break}gj[q&4095](p)|0;s=c[2440596]|0}else{s=o}}while(0);o=s-1|0;c[2440596]=o;s=a[9660977]|0;if(((s&255)+(d[9660972]|0)|0)>255){p=(b[4830480]|0)-1&65535;r=c[2443776]|0;do{if((c[r+68+((p&65535)>>>8<<2)>>2]|0)==0){q=c[r+3148>>2]|0;if((q|0)==0){t=o;u=s;break}gj[q&4095](p)|0;t=c[2440596]|0;u=a[9660977]|0}else{t=o;u=s}}while(0);p=t-1|0;c[2440596]=p;v=u;w=p}else{v=s;w=o}b[4830486]=(b[4830486]|0)+(v&255)&65535;v=c[2415243]|0;o=v&65535;s=c[2443776]|0;p=c[s+68+((v>>>8&255)<<2)>>2]|0;do{if((p|0)==0){u=c[s+3148>>2]|0;if((u|0)==0){x=0;y=w;z=v;A=s;break}t=gj[u&4095](o)|0;x=t;y=c[2440596]|0;z=c[2415243]|0;A=c[2443776]|0}else{x=a[p+(v&255)|0]|0;y=w;z=v;A=s}}while(0);s=y-1|0;c[2440596]=s;y=z+1|0;c[2415243]=y;z=y&65535;v=c[A+68+((y>>>8&255)<<2)>>2]|0;do{if((v|0)==0){w=c[A+3148>>2]|0;if((w|0)==0){B=0;C=s;break}p=gj[w&4095](z)|0;B=p;C=c[2440596]|0}else{B=a[v+(y&255)|0]|0;C=s}}while(0);a[9660973]=B;B=C-1|0;c[2440596]=B;a[9660972]=x;x=c[2415243]|0;if(!((B|0)>0&(((x|0)!=(c[2415239]|0)|(a[9660980]|0)!=0|(a[9660981]|0)!=0)^1))){c[2415240]=x;return}c[2440596]=0;c[2415240]=x;return}function f_G(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;b[4830480]=k+1&65535;g=k&65535;e=c[l+68+(g>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[l+3168>>2]|0;if((f|0)==0){n=0;o=j;p=l;break}h=gj[f&4095](k)|0;n=h;o=c[2440596]|0;p=c[2443776]|0}else{n=a[e+(g&255)|0]|0;o=j;p=l}}while(0);a[9660973]=n;n=o-1|0;c[2440596]=n;o=c[2415243]|0;l=c[p+68+((o>>>8&255|256)<<2)>>2]|0;if((l|0)!=0){a[l+(o&255)|0]=0;q=n;r=q-1|0;c[2440596]=r;return}l=c[p+3152>>2]|0;if((l|0)==0){q=n;r=q-1|0;c[2440596]=r;return}gg[l&4095](o&65535,0);q=c[2440596]|0;r=q-1|0;c[2440596]=r;return}function f_H(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;g=(c[2440596]|0)-1|0;c[2440596]=g;b[4830480]=k+1&65535;e=k&65535;f=c[l+68+(e>>>8<<2)>>2]|0;do{if((f|0)==0){h=c[l+3168>>2]|0;if((h|0)==0){n=0;o=g;p=j;break}d=gj[h&4095](k)|0;n=d;o=c[2440596]|0;p=a[9660972]|0}else{n=a[f+(e&255)|0]|0;o=g;p=j}}while(0);a[9660973]=n;n=o-1|0;c[2440596]=n;o=a[9660977]|0;if(((o&255)+(p&255)|0)>255){p=(b[4830480]|0)-1&65535;j=c[2443776]|0;do{if((c[j+68+((p&65535)>>>8<<2)>>2]|0)==0){g=c[j+3148>>2]|0;if((g|0)==0){q=n;r=o;break}gj[g&4095](p)|0;q=c[2440596]|0;r=a[9660977]|0}else{q=n;r=o}}while(0);p=q-1|0;c[2440596]=p;s=r;t=p}else{s=o;t=n}b[4830486]=(b[4830486]|0)+(s&255)&65535;s=c[2415243]|0;n=s&65535;o=c[2443776]|0;p=c[o+68+((s>>>8&255)<<2)>>2]|0;do{if((p|0)==0){r=c[o+3148>>2]|0;if((r|0)==0){u=0;v=t;break}q=gj[r&4095](n)|0;u=q;v=c[2440596]|0}else{u=a[p+(s&255)|0]|0;v=t}}while(0);c[2440596]=v-1;a[9660978]=u;a[9660979]=a[9660979]&125|(u<<24>>24==0?2:u&-128);return}function f_I(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=b[4830480]|0;f=e+1&65535;b[4830480]=f;g=e&65535;h=c[2443776]|0;i=c[h+68+(g>>>8<<2)>>2]|0;do{if((i|0)==0){j=c[h+3168>>2]|0;if((j|0)==0){k=0;l=f;m=h;break}n=gj[j&4095](e)|0;k=n;l=b[4830480]|0;m=c[2443776]|0}else{k=a[i+(g&255)|0]|0;l=f;m=h}}while(0);a[9660972]=k;k=(c[2440596]|0)-1|0;c[2440596]=k;h=l+1&65535;b[4830480]=h;f=l&65535;g=c[m+68+(f>>>8<<2)>>2]|0;do{if((g|0)==0){i=c[m+3168>>2]|0;if((i|0)==0){o=0;p=k;q=h;r=m;break}e=gj[i&4095](l)|0;o=e;p=c[2440596]|0;q=b[4830480]|0;r=c[2443776]|0}else{o=a[g+(f&255)|0]|0;p=k;q=h;r=m}}while(0);a[9660973]=o;o=p-1|0;c[2440596]=o;p=q-1&65535;do{if((c[r+68+((p&65535)>>>8<<2)>>2]|0)==0){q=c[r+3148>>2]|0;if((q|0)==0){s=o;t=r;break}gj[q&4095](p)|0;s=c[2440596]|0;t=c[2443776]|0}else{s=o;t=r}}while(0);r=s-1|0;c[2440596]=r;b[4830486]=(b[4830486]|0)+(d[9660977]|0)&65535;s=c[2415243]|0;if((c[t+68+((s>>>8&255)<<2)>>2]|0)!=0){u=r;v=u-1|0;c[2440596]=v;return}o=c[t+3148>>2]|0;if((o|0)==0){u=r;v=u-1|0;c[2440596]=v;return}gj[o&4095](s&65535)|0;u=c[2440596]|0;v=u-1|0;c[2440596]=v;return}function f_J(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=b[4830480]|0;f=e+1&65535;b[4830480]=f;g=e&65535;h=c[2443776]|0;i=c[h+68+(g>>>8<<2)>>2]|0;do{if((i|0)==0){j=c[h+3168>>2]|0;if((j|0)==0){k=0;l=f;m=h;break}n=gj[j&4095](e)|0;k=n;l=b[4830480]|0;m=c[2443776]|0}else{k=a[i+(g&255)|0]|0;l=f;m=h}}while(0);a[9660972]=k;k=(c[2440596]|0)-1|0;c[2440596]=k;h=l+1&65535;b[4830480]=h;f=l&65535;g=c[m+68+(f>>>8<<2)>>2]|0;do{if((g|0)==0){i=c[m+3168>>2]|0;if((i|0)==0){o=0;p=k;q=h;r=m;break}e=gj[i&4095](l)|0;o=e;p=c[2440596]|0;q=b[4830480]|0;r=c[2443776]|0}else{o=a[g+(f&255)|0]|0;p=k;q=h;r=m}}while(0);a[9660973]=o;o=p-1|0;c[2440596]=o;p=q-1&65535;do{if((c[r+68+((p&65535)>>>8<<2)>>2]|0)==0){q=c[r+3148>>2]|0;if((q|0)==0){s=o;t=r;break}gj[q&4095](p)|0;s=c[2440596]|0;t=c[2443776]|0}else{s=o;t=r}}while(0);r=s-1|0;c[2440596]=r;b[4830486]=(b[4830486]|0)+(d[9660977]|0)&65535;s=c[2415243]|0;if((c[t+68+((s>>>8&255)<<2)>>2]|0)!=0){u=r;v=u-1|0;c[2440596]=v;return}o=c[t+3148>>2]|0;if((o|0)==0){u=r;v=u-1|0;c[2440596]=v;return}gj[o&4095](s&65535)|0;u=c[2440596]|0;v=u-1|0;c[2440596]=v;return}function f_K(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;b[4830480]=k+1&65535;g=k&65535;e=c[l+68+(g>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[l+3168>>2]|0;if((f|0)==0){n=0;o=j;p=l;break}h=gj[f&4095](k)|0;n=h;o=c[2440596]|0;p=c[2443776]|0}else{n=a[e+(g&255)|0]|0;o=j;p=l}}while(0);a[9660973]=n;n=o-1|0;c[2440596]=n;o=c[2415243]|0;l=o&65535;j=c[p+68+((o>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[p+3148>>2]|0;if((g|0)==0){q=0;r=n;break}e=gj[g&4095](l)|0;q=e;r=c[2440596]|0}else{q=a[j+(o&255)|0]|0;r=n}}while(0);c[2440596]=r-1;r=a[9660976]|q;a[9660976]=r;a[9660979]=(r<<24>>24==0?2:r&-128)|a[9660979]&125;return}function f_L(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;b[4830480]=k+1&65535;g=k&65535;e=c[l+68+(g>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[l+3168>>2]|0;if((f|0)==0){n=0;o=j;p=l;break}h=gj[f&4095](k)|0;n=h;o=c[2440596]|0;p=c[2443776]|0}else{n=a[e+(g&255)|0]|0;o=j;p=l}}while(0);a[9660973]=n;n=o-1|0;c[2440596]=n;o=c[2415243]|0;l=o&65535;j=c[p+68+((o>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[p+3148>>2]|0;if((g|0)==0){q=0;r=n;break}e=gj[g&4095](l)|0;q=e;r=c[2440596]|0}else{q=a[j+(o&255)|0]|0;r=n}}while(0);c[2440596]=r-1;r=a[9660976]&q;a[9660976]=r;a[9660979]=(r<<24>>24==0?2:r&-128)|a[9660979]&125;return}function f_M(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;b[4830480]=k+1&65535;g=k&65535;e=c[l+68+(g>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[l+3168>>2]|0;if((f|0)==0){n=0;o=j;p=l;break}h=gj[f&4095](k)|0;n=h;o=c[2440596]|0;p=c[2443776]|0}else{n=a[e+(g&255)|0]|0;o=j;p=l}}while(0);a[9660973]=n;n=o-1|0;c[2440596]=n;o=c[2415243]|0;l=o&65535;j=c[p+68+((o>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[p+3148>>2]|0;if((g|0)==0){q=0;r=n;break}e=gj[g&4095](l)|0;q=e;r=c[2440596]|0}else{q=a[j+(o&255)|0]|0;r=n}}while(0);c[2440596]=r-1;r=a[9660976]|0;n=r^q;a[9660976]=n;a[9660979]=(r<<24>>24==q<<24>>24?2:n&-128)|a[9660979]&125;return}function f_N(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;b[4830480]=k+1&65535;g=k&65535;e=c[l+68+(g>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[l+3168>>2]|0;if((f|0)==0){n=0;o=j;p=l;break}h=gj[f&4095](k)|0;n=h;o=c[2440596]|0;p=c[2443776]|0}else{n=a[e+(g&255)|0]|0;o=j;p=l}}while(0);a[9660973]=n;n=o-1|0;c[2440596]=n;o=c[2415243]|0;l=o&65535;j=c[p+68+((o>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[p+3148>>2]|0;if((g|0)==0){q=0;r=n;break}e=gj[g&4095](l)|0;q=e;r=c[2440596]|0}else{q=a[j+(o&255)|0]|0;r=n}}while(0);n=q&255;o=r-1|0;c[2440596]=o;r=a[9660979]|0;j=r&255;l=j&1;p=a[9660976]|0;e=p&255;if((j&8|0)==0){j=e+n+l|0;g=r&-66;k=((((p^q)&128^128)&(j^e)|0)==0?g:g|64)|(j&65280|0)!=0;a[9660979]=k;g=j&255;a[9660976]=g;s=g;t=k;u=s<<24>>24==0;v=t&125;w=s&-128;x=u?2:w;y=x|v;a[9660979]=y;return}k=l+(n&15)+(e&15)|0;l=(e&240)+(n&240)|0;n=r&-66;a[9660979]=n;if((k|0)>9){z=k+6|0;A=l+16|0}else{z=k;A=l}if((((p^q)&128^128)&(A^e)|0)==0){B=n}else{e=n|64;a[9660979]=e;B=e}e=(A|0)>144?A+96|0:A;if((e&65280|0)==0){C=B}else{A=B|1;a[9660979]=A;C=A}A=(e&240|z&15)&255;a[9660976]=A;z=(b[4830480]|0)-1&65535;e=c[2443776]|0;do{if((c[e+68+((z&65535)>>>8<<2)>>2]|0)==0){B=c[e+3148>>2]|0;if((B|0)==0){D=o;E=A;F=C;break}gj[B&4095](z)|0;D=c[2440596]|0;E=a[9660976]|0;F=a[9660979]|0}else{D=o;E=A;F=C}}while(0);c[2440596]=D-1;s=E;t=F;u=s<<24>>24==0;v=t&125;w=s&-128;x=u?2:w;y=x|v;a[9660979]=y;return}function f_O(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=a[9660976]|0;e=b[4830480]|0;f=e+1&65535;b[4830480]=f;g=e&65535;h=c[2443776]|0;i=c[h+68+(g>>>8<<2)>>2]|0;do{if((i|0)==0){j=c[h+3168>>2]|0;if((j|0)==0){k=0;l=f;m=h;break}n=gj[j&4095](e)|0;k=n;l=b[4830480]|0;m=c[2443776]|0}else{k=a[i+(g&255)|0]|0;l=f;m=h}}while(0);a[9660972]=k;k=(c[2440596]|0)-1|0;c[2440596]=k;b[4830480]=l+1&65535;h=l&65535;f=c[m+68+(h>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[m+3168>>2]|0;if((g|0)==0){o=0;p=k;q=m;break}i=gj[g&4095](l)|0;o=i;p=c[2440596]|0;q=c[2443776]|0}else{o=a[f+(h&255)|0]|0;p=k;q=m}}while(0);a[9660973]=o;o=p-1|0;c[2440596]=o;p=c[2415243]|0;m=c[q+68+((p>>>8&255|256)<<2)>>2]|0;if((m|0)!=0){a[m+(p&255)|0]=d;r=o;s=r-1|0;c[2440596]=s;return}m=c[q+3152>>2]|0;if((m|0)==0){r=o;s=r-1|0;c[2440596]=s;return}gg[m&4095](p&65535,d);r=c[2440596]|0;s=r-1|0;c[2440596]=s;return}function f_P(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;b[4830480]=k+1&65535;g=k&65535;e=c[l+68+(g>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[l+3168>>2]|0;if((f|0)==0){n=0;o=j;p=l;break}h=gj[f&4095](k)|0;n=h;o=c[2440596]|0;p=c[2443776]|0}else{n=a[e+(g&255)|0]|0;o=j;p=l}}while(0);a[9660973]=n;n=o-1|0;c[2440596]=n;o=c[2415243]|0;l=o&65535;j=c[p+68+((o>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[p+3148>>2]|0;if((g|0)==0){q=0;r=n;break}e=gj[g&4095](l)|0;q=e;r=c[2440596]|0}else{q=a[j+(o&255)|0]|0;r=n}}while(0);c[2440596]=r-1;a[9660976]=q;a[9660979]=a[9660979]&125|(q<<24>>24==0?2:q&-128);return}function f_Q(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;b[4830480]=k+1&65535;g=k&65535;e=c[l+68+(g>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[l+3168>>2]|0;if((f|0)==0){n=0;o=j;p=l;break}h=gj[f&4095](k)|0;n=h;o=c[2440596]|0;p=c[2443776]|0}else{n=a[e+(g&255)|0]|0;o=j;p=l}}while(0);a[9660973]=n;n=o-1|0;c[2440596]=n;o=c[2415243]|0;l=o&65535;j=c[p+68+((o>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[p+3148>>2]|0;if((g|0)==0){q=0;r=n;break}e=gj[g&4095](l)|0;q=e;r=c[2440596]|0}else{q=a[j+(o&255)|0]|0;r=n}}while(0);c[2440596]=r-1;r=a[9660979]|0;n=r&-2;a[9660979]=n;o=a[9660976]|0;if((o&255)<(q&255)){s=n}else{n=r|1;a[9660979]=n;s=n}if(o<<24>>24==q<<24>>24){t=s&125|2;a[9660979]=t;return}else{t=s&125|o-q&255&-128;a[9660979]=t;return}}function f_R(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;b[4830480]=k+1&65535;g=k&65535;e=c[l+68+(g>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[l+3168>>2]|0;if((f|0)==0){n=0;o=j;p=l;break}h=gj[f&4095](k)|0;n=h;o=c[2440596]|0;p=c[2443776]|0}else{n=a[e+(g&255)|0]|0;o=j;p=l}}while(0);a[9660973]=n;n=o-1|0;c[2440596]=n;o=c[2415243]|0;l=o&65535;j=c[p+68+((o>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[p+3148>>2]|0;if((g|0)==0){q=0;r=n;break}e=gj[g&4095](l)|0;q=e;r=c[2440596]|0}else{q=a[j+(o&255)|0]|0;r=n}}while(0);n=q&255;o=r-1|0;c[2440596]=o;r=a[9660979]|0;j=r&255;l=j&1^1;p=a[9660976]|0;e=p&255;g=e-n-l|0;if((j&8|0)==0){j=r&-66;k=(((p^q)&128&(g^e)|0)==0?j:j|64)|(g&65280|0)==0;a[9660979]=k;j=g&255;a[9660976]=j;s=j;t=k;u=s<<24>>24==0;v=t&125;w=s&-128;x=u?2:w;y=x|v;a[9660979]=y;return}k=(e&15)-(n&15)-l|0;l=(e&240)-(n&240)|0;n=r&-66;r=(k&240|0)==0?k:k-6|0;k=(r&128|0)==0?l:l-16|0;l=(((p^q)&128&(g^e)|0)==0?n:n|64)|(g&65280|0)==0;a[9660979]=l;g=(((k&3840|0)==0?k:k+160|0)&240|r&15)&255;a[9660976]=g;r=(b[4830480]|0)-1&65535;k=c[2443776]|0;do{if((c[k+68+((r&65535)>>>8<<2)>>2]|0)==0){n=c[k+3148>>2]|0;if((n|0)==0){z=o;A=g;B=l;break}gj[n&4095](r)|0;z=c[2440596]|0;A=a[9660976]|0;B=a[9660979]|0}else{z=o;A=g;B=l}}while(0);c[2440596]=z-1;s=A;t=B;u=s<<24>>24==0;v=t&125;w=s&-128;x=u?2:w;y=x|v;a[9660979]=y;return}function f_S(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;g=(c[2440596]|0)-1|0;c[2440596]=g;b[4830480]=k+1&65535;e=k&65535;f=c[l+68+(e>>>8<<2)>>2]|0;do{if((f|0)==0){h=c[l+3168>>2]|0;if((h|0)==0){n=0;o=g;p=j;break}d=gj[h&4095](k)|0;n=d;o=c[2440596]|0;p=a[9660972]|0}else{n=a[f+(e&255)|0]|0;o=g;p=j}}while(0);a[9660973]=n;n=o-1|0;c[2440596]=n;o=a[9660977]|0;if(((o&255)+(p&255)|0)>255){p=(b[4830480]|0)-1&65535;j=c[2443776]|0;do{if((c[j+68+((p&65535)>>>8<<2)>>2]|0)==0){g=c[j+3148>>2]|0;if((g|0)==0){q=n;r=o;break}gj[g&4095](p)|0;q=c[2440596]|0;r=a[9660977]|0}else{q=n;r=o}}while(0);p=q-1|0;c[2440596]=p;s=r;t=p}else{s=o;t=n}b[4830486]=(b[4830486]|0)+(s&255)&65535;s=c[2415243]|0;n=s&65535;o=c[2443776]|0;p=c[o+68+((s>>>8&255)<<2)>>2]|0;do{if((p|0)==0){r=c[o+3148>>2]|0;if((r|0)==0){u=0;v=t;break}q=gj[r&4095](n)|0;u=q;v=c[2440596]|0}else{u=a[p+(s&255)|0]|0;v=t}}while(0);c[2440596]=v-1;v=a[9660976]|u;a[9660976]=v;a[9660979]=(v<<24>>24==0?2:v&-128)|a[9660979]&125;return}function f_T(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;g=(c[2440596]|0)-1|0;c[2440596]=g;b[4830480]=k+1&65535;e=k&65535;f=c[l+68+(e>>>8<<2)>>2]|0;do{if((f|0)==0){h=c[l+3168>>2]|0;if((h|0)==0){n=0;o=g;p=j;break}d=gj[h&4095](k)|0;n=d;o=c[2440596]|0;p=a[9660972]|0}else{n=a[f+(e&255)|0]|0;o=g;p=j}}while(0);a[9660973]=n;n=o-1|0;c[2440596]=n;o=a[9660977]|0;if(((o&255)+(p&255)|0)>255){p=(b[4830480]|0)-1&65535;j=c[2443776]|0;do{if((c[j+68+((p&65535)>>>8<<2)>>2]|0)==0){g=c[j+3148>>2]|0;if((g|0)==0){q=n;r=o;break}gj[g&4095](p)|0;q=c[2440596]|0;r=a[9660977]|0}else{q=n;r=o}}while(0);p=q-1|0;c[2440596]=p;s=r;t=p}else{s=o;t=n}b[4830486]=(b[4830486]|0)+(s&255)&65535;s=c[2415243]|0;n=s&65535;o=c[2443776]|0;p=c[o+68+((s>>>8&255)<<2)>>2]|0;do{if((p|0)==0){r=c[o+3148>>2]|0;if((r|0)==0){u=0;v=t;break}q=gj[r&4095](n)|0;u=q;v=c[2440596]|0}else{u=a[p+(s&255)|0]|0;v=t}}while(0);c[2440596]=v-1;v=a[9660976]&u;a[9660976]=v;a[9660979]=(v<<24>>24==0?2:v&-128)|a[9660979]&125;return}function f_U(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;g=(c[2440596]|0)-1|0;c[2440596]=g;b[4830480]=k+1&65535;e=k&65535;f=c[l+68+(e>>>8<<2)>>2]|0;do{if((f|0)==0){h=c[l+3168>>2]|0;if((h|0)==0){n=0;o=g;p=j;break}d=gj[h&4095](k)|0;n=d;o=c[2440596]|0;p=a[9660972]|0}else{n=a[f+(e&255)|0]|0;o=g;p=j}}while(0);a[9660973]=n;n=o-1|0;c[2440596]=n;o=a[9660977]|0;if(((o&255)+(p&255)|0)>255){p=(b[4830480]|0)-1&65535;j=c[2443776]|0;do{if((c[j+68+((p&65535)>>>8<<2)>>2]|0)==0){g=c[j+3148>>2]|0;if((g|0)==0){q=n;r=o;break}gj[g&4095](p)|0;q=c[2440596]|0;r=a[9660977]|0}else{q=n;r=o}}while(0);p=q-1|0;c[2440596]=p;s=r;t=p}else{s=o;t=n}b[4830486]=(b[4830486]|0)+(s&255)&65535;s=c[2415243]|0;n=s&65535;o=c[2443776]|0;p=c[o+68+((s>>>8&255)<<2)>>2]|0;do{if((p|0)==0){r=c[o+3148>>2]|0;if((r|0)==0){u=0;v=t;break}q=gj[r&4095](n)|0;u=q;v=c[2440596]|0}else{u=a[p+(s&255)|0]|0;v=t}}while(0);c[2440596]=v-1;v=a[9660976]|0;t=v^u;a[9660976]=t;a[9660979]=(v<<24>>24==u<<24>>24?2:t&-128)|a[9660979]&125;return}function f_V(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;g=(c[2440596]|0)-1|0;c[2440596]=g;b[4830480]=k+1&65535;e=k&65535;f=c[l+68+(e>>>8<<2)>>2]|0;do{if((f|0)==0){h=c[l+3168>>2]|0;if((h|0)==0){n=0;o=g;p=j;break}d=gj[h&4095](k)|0;n=d;o=c[2440596]|0;p=a[9660972]|0}else{n=a[f+(e&255)|0]|0;o=g;p=j}}while(0);a[9660973]=n;n=o-1|0;c[2440596]=n;o=a[9660977]|0;if(((o&255)+(p&255)|0)>255){p=(b[4830480]|0)-1&65535;j=c[2443776]|0;do{if((c[j+68+((p&65535)>>>8<<2)>>2]|0)==0){g=c[j+3148>>2]|0;if((g|0)==0){q=n;r=o;break}gj[g&4095](p)|0;q=c[2440596]|0;r=a[9660977]|0}else{q=n;r=o}}while(0);p=q-1|0;c[2440596]=p;s=r;t=p}else{s=o;t=n}b[4830486]=(b[4830486]|0)+(s&255)&65535;s=c[2415243]|0;n=s&65535;o=c[2443776]|0;p=c[o+68+((s>>>8&255)<<2)>>2]|0;do{if((p|0)==0){r=c[o+3148>>2]|0;if((r|0)==0){u=0;v=t;break}q=gj[r&4095](n)|0;u=q;v=c[2440596]|0}else{u=a[p+(s&255)|0]|0;v=t}}while(0);t=u&255;s=v-1|0;c[2440596]=s;v=a[9660979]|0;p=v&255;n=p&1;o=a[9660976]|0;q=o&255;if((p&8|0)==0){p=q+t+n|0;r=v&-66;j=((((o^u)&128^128)&(p^q)|0)==0?r:r|64)|(p&65280|0)!=0;a[9660979]=j;r=p&255;a[9660976]=r;w=r;x=j;y=w<<24>>24==0;z=x&125;A=w&-128;B=y?2:A;C=B|z;a[9660979]=C;return}j=n+(t&15)+(q&15)|0;n=(q&240)+(t&240)|0;t=v&-66;a[9660979]=t;if((j|0)>9){D=j+6|0;E=n+16|0}else{D=j;E=n}if((((o^u)&128^128)&(E^q)|0)==0){F=t}else{q=t|64;a[9660979]=q;F=q}q=(E|0)>144?E+96|0:E;if((q&65280|0)==0){G=F}else{E=F|1;a[9660979]=E;G=E}E=(q&240|D&15)&255;a[9660976]=E;D=(b[4830480]|0)-1&65535;q=c[2443776]|0;do{if((c[q+68+((D&65535)>>>8<<2)>>2]|0)==0){F=c[q+3148>>2]|0;if((F|0)==0){H=s;I=E;J=G;break}gj[F&4095](D)|0;H=c[2440596]|0;I=a[9660976]|0;J=a[9660979]|0}else{H=s;I=E;J=G}}while(0);c[2440596]=H-1;w=I;x=J;y=w<<24>>24==0;z=x&125;A=w&-128;B=y?2:A;C=B|z;a[9660979]=C;return}function f_W(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;e=a[9660976]|0;f=b[4830480]|0;g=f+1&65535;b[4830480]=g;h=f&65535;i=c[2443776]|0;j=c[i+68+(h>>>8<<2)>>2]|0;do{if((j|0)==0){k=c[i+3168>>2]|0;if((k|0)==0){l=0;m=g;n=i;break}o=gj[k&4095](f)|0;l=o;m=b[4830480]|0;n=c[2443776]|0}else{l=a[j+(h&255)|0]|0;m=g;n=i}}while(0);a[9660972]=l;l=(c[2440596]|0)-1|0;c[2440596]=l;i=m+1&65535;b[4830480]=i;g=m&65535;h=c[n+68+(g>>>8<<2)>>2]|0;do{if((h|0)==0){j=c[n+3168>>2]|0;if((j|0)==0){p=0;q=l;r=i;s=n;break}f=gj[j&4095](m)|0;p=f;q=c[2440596]|0;r=b[4830480]|0;s=c[2443776]|0}else{p=a[h+(g&255)|0]|0;q=l;r=i;s=n}}while(0);a[9660973]=p;p=q-1|0;c[2440596]=p;q=r-1&65535;do{if((c[s+68+((q&65535)>>>8<<2)>>2]|0)==0){r=c[s+3148>>2]|0;if((r|0)==0){t=p;u=s;break}gj[r&4095](q)|0;t=c[2440596]|0;u=c[2443776]|0}else{t=p;u=s}}while(0);s=t-1|0;c[2440596]=s;b[4830486]=(b[4830486]|0)+(d[9660977]|0)&65535;t=c[2415243]|0;p=c[u+68+((t>>>8&255|256)<<2)>>2]|0;if((p|0)!=0){a[p+(t&255)|0]=e;v=s;w=v-1|0;c[2440596]=w;return}p=c[u+3152>>2]|0;if((p|0)==0){v=s;w=v-1|0;c[2440596]=w;return}gg[p&4095](t&65535,e);v=c[2440596]|0;w=v-1|0;c[2440596]=w;return}function f_X(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;g=(c[2440596]|0)-1|0;c[2440596]=g;b[4830480]=k+1&65535;e=k&65535;f=c[l+68+(e>>>8<<2)>>2]|0;do{if((f|0)==0){h=c[l+3168>>2]|0;if((h|0)==0){n=0;o=g;p=j;break}d=gj[h&4095](k)|0;n=d;o=c[2440596]|0;p=a[9660972]|0}else{n=a[f+(e&255)|0]|0;o=g;p=j}}while(0);a[9660973]=n;n=o-1|0;c[2440596]=n;o=a[9660977]|0;if(((o&255)+(p&255)|0)>255){p=(b[4830480]|0)-1&65535;j=c[2443776]|0;do{if((c[j+68+((p&65535)>>>8<<2)>>2]|0)==0){g=c[j+3148>>2]|0;if((g|0)==0){q=n;r=o;break}gj[g&4095](p)|0;q=c[2440596]|0;r=a[9660977]|0}else{q=n;r=o}}while(0);p=q-1|0;c[2440596]=p;s=r;t=p}else{s=o;t=n}b[4830486]=(b[4830486]|0)+(s&255)&65535;s=c[2415243]|0;n=s&65535;o=c[2443776]|0;p=c[o+68+((s>>>8&255)<<2)>>2]|0;do{if((p|0)==0){r=c[o+3148>>2]|0;if((r|0)==0){u=0;v=t;break}q=gj[r&4095](n)|0;u=q;v=c[2440596]|0}else{u=a[p+(s&255)|0]|0;v=t}}while(0);c[2440596]=v-1;a[9660976]=u;a[9660979]=a[9660979]&125|(u<<24>>24==0?2:u&-128);return}function f_Y(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;g=(c[2440596]|0)-1|0;c[2440596]=g;b[4830480]=k+1&65535;e=k&65535;f=c[l+68+(e>>>8<<2)>>2]|0;do{if((f|0)==0){h=c[l+3168>>2]|0;if((h|0)==0){n=0;o=g;p=j;break}d=gj[h&4095](k)|0;n=d;o=c[2440596]|0;p=a[9660972]|0}else{n=a[f+(e&255)|0]|0;o=g;p=j}}while(0);a[9660973]=n;n=o-1|0;c[2440596]=n;o=a[9660977]|0;if(((o&255)+(p&255)|0)>255){p=(b[4830480]|0)-1&65535;j=c[2443776]|0;do{if((c[j+68+((p&65535)>>>8<<2)>>2]|0)==0){g=c[j+3148>>2]|0;if((g|0)==0){q=n;r=o;break}gj[g&4095](p)|0;q=c[2440596]|0;r=a[9660977]|0}else{q=n;r=o}}while(0);p=q-1|0;c[2440596]=p;s=r;t=p}else{s=o;t=n}b[4830486]=(b[4830486]|0)+(s&255)&65535;s=c[2415243]|0;n=s&65535;o=c[2443776]|0;p=c[o+68+((s>>>8&255)<<2)>>2]|0;do{if((p|0)==0){r=c[o+3148>>2]|0;if((r|0)==0){u=0;v=t;break}q=gj[r&4095](n)|0;u=q;v=c[2440596]|0}else{u=a[p+(s&255)|0]|0;v=t}}while(0);c[2440596]=v-1;v=a[9660979]|0;t=v&-2;a[9660979]=t;s=a[9660976]|0;if((s&255)<(u&255)){w=t}else{t=v|1;a[9660979]=t;w=t}if(s<<24>>24==u<<24>>24){x=w&125|2;a[9660979]=x;return}else{x=w&125|s-u&255&-128;a[9660979]=x;return}}function f_Z(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;g=(c[2440596]|0)-1|0;c[2440596]=g;b[4830480]=k+1&65535;e=k&65535;f=c[l+68+(e>>>8<<2)>>2]|0;do{if((f|0)==0){h=c[l+3168>>2]|0;if((h|0)==0){n=0;o=g;p=j;break}d=gj[h&4095](k)|0;n=d;o=c[2440596]|0;p=a[9660972]|0}else{n=a[f+(e&255)|0]|0;o=g;p=j}}while(0);a[9660973]=n;n=o-1|0;c[2440596]=n;o=a[9660977]|0;if(((o&255)+(p&255)|0)>255){p=(b[4830480]|0)-1&65535;j=c[2443776]|0;do{if((c[j+68+((p&65535)>>>8<<2)>>2]|0)==0){g=c[j+3148>>2]|0;if((g|0)==0){q=n;r=o;break}gj[g&4095](p)|0;q=c[2440596]|0;r=a[9660977]|0}else{q=n;r=o}}while(0);p=q-1|0;c[2440596]=p;s=r;t=p}else{s=o;t=n}b[4830486]=(b[4830486]|0)+(s&255)&65535;s=c[2415243]|0;n=s&65535;o=c[2443776]|0;p=c[o+68+((s>>>8&255)<<2)>>2]|0;do{if((p|0)==0){r=c[o+3148>>2]|0;if((r|0)==0){u=0;v=t;break}q=gj[r&4095](n)|0;u=q;v=c[2440596]|0}else{u=a[p+(s&255)|0]|0;v=t}}while(0);t=u&255;s=v-1|0;c[2440596]=s;v=a[9660979]|0;p=v&255;n=p&1^1;o=a[9660976]|0;q=o&255;r=q-t-n|0;if((p&8|0)==0){p=v&-66;j=(((o^u)&128&(r^q)|0)==0?p:p|64)|(r&65280|0)==0;a[9660979]=j;p=r&255;a[9660976]=p;w=p;x=j;y=w<<24>>24==0;z=x&125;A=w&-128;B=y?2:A;C=B|z;a[9660979]=C;return}j=(q&15)-(t&15)-n|0;n=(q&240)-(t&240)|0;t=v&-66;v=(j&240|0)==0?j:j-6|0;j=(v&128|0)==0?n:n-16|0;n=(((o^u)&128&(r^q)|0)==0?t:t|64)|(r&65280|0)==0;a[9660979]=n;r=(((j&3840|0)==0?j:j+160|0)&240|v&15)&255;a[9660976]=r;v=(b[4830480]|0)-1&65535;j=c[2443776]|0;do{if((c[j+68+((v&65535)>>>8<<2)>>2]|0)==0){t=c[j+3148>>2]|0;if((t|0)==0){D=s;E=r;F=n;break}gj[t&4095](v)|0;D=c[2440596]|0;E=a[9660976]|0;F=a[9660979]|0}else{D=s;E=r;F=n}}while(0);c[2440596]=D-1;w=E;x=F;y=w<<24>>24==0;z=x&125;A=w&-128;B=y?2:A;C=B|z;a[9660979]=C;return}function f__(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;b[4830480]=k+1&65535;g=k&65535;e=c[l+68+(g>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[l+3168>>2]|0;if((f|0)==0){n=0;o=j;p=l;break}h=gj[f&4095](k)|0;n=h;o=c[2440596]|0;p=c[2443776]|0}else{n=a[e+(g&255)|0]|0;o=j;p=l}}while(0);a[9660973]=n;n=o-1|0;c[2440596]=n;o=c[2415243]|0;l=o&65535;j=c[p+68+((o>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[p+3148>>2]|0;if((g|0)==0){q=0;r=n;s=o;t=p;break}e=gj[g&4095](l)|0;q=e;r=c[2440596]|0;s=c[2415243]|0;t=c[2443776]|0}else{q=a[j+(o&255)|0]|0;r=n;s=o;t=p}}while(0);p=r-1|0;c[2440596]=p;r=s&65535;do{if((c[t+68+((s>>>8&255)<<2)>>2]|0)==0){o=c[t+3148>>2]|0;if((o|0)==0){u=p;v=s;w=t;break}gj[o&4095](r)|0;u=c[2440596]|0;v=c[2415243]|0;w=c[2443776]|0}else{u=p;v=s;w=t}}while(0);t=u-1|0;c[2440596]=t;u=q<<1;a[9660979]=(u<<24>>24==0?2:u&-128)|(q&255)>>>7|a[9660979]&124;q=c[w+68+((v>>>8&255|256)<<2)>>2]|0;if((q|0)!=0){a[q+(v&255)|0]=u;x=t;y=x-1|0;c[2440596]=y;return}q=c[w+3152>>2]|0;if((q|0)==0){x=t;y=x-1|0;c[2440596]=y;return}gg[q&4095](v&65535,u);x=c[2440596]|0;y=x-1|0;c[2440596]=y;return}function f_$(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;b[4830480]=k+1&65535;g=k&65535;e=c[l+68+(g>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[l+3168>>2]|0;if((f|0)==0){n=0;o=j;p=l;break}h=gj[f&4095](k)|0;n=h;o=c[2440596]|0;p=c[2443776]|0}else{n=a[e+(g&255)|0]|0;o=j;p=l}}while(0);a[9660973]=n;n=o-1|0;c[2440596]=n;o=c[2415243]|0;l=o&65535;j=c[p+68+((o>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[p+3148>>2]|0;if((g|0)==0){q=0;r=n;s=o;t=p;break}e=gj[g&4095](l)|0;q=e;r=c[2440596]|0;s=c[2415243]|0;t=c[2443776]|0}else{q=a[j+(o&255)|0]|0;r=n;s=o;t=p}}while(0);p=r-1|0;c[2440596]=p;r=s&65535;do{if((c[t+68+((s>>>8&255)<<2)>>2]|0)==0){o=c[t+3148>>2]|0;if((o|0)==0){u=p;v=s;w=t;break}gj[o&4095](r)|0;u=c[2440596]|0;v=c[2415243]|0;w=c[2443776]|0}else{u=p;v=s;w=t}}while(0);t=u-1|0;c[2440596]=t;u=q<<1;s=a[9660979]|0;p=s&1|u;a[9660979]=s&124|(q&255)>>>7|(p<<24>>24==0?2:u&-128);u=c[w+68+((v>>>8&255|256)<<2)>>2]|0;if((u|0)!=0){a[u+(v&255)|0]=p;x=t;y=x-1|0;c[2440596]=y;return}u=c[w+3152>>2]|0;if((u|0)==0){x=t;y=x-1|0;c[2440596]=y;return}gg[u&4095](v&65535,p);x=c[2440596]|0;y=x-1|0;c[2440596]=y;return}function f_0(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;b[4830480]=k+1&65535;g=k&65535;e=c[l+68+(g>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[l+3168>>2]|0;if((f|0)==0){n=0;o=j;p=l;break}h=gj[f&4095](k)|0;n=h;o=c[2440596]|0;p=c[2443776]|0}else{n=a[e+(g&255)|0]|0;o=j;p=l}}while(0);a[9660973]=n;n=o-1|0;c[2440596]=n;o=c[2415243]|0;l=o&65535;j=c[p+68+((o>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[p+3148>>2]|0;if((g|0)==0){q=0;r=n;s=o;t=p;break}e=gj[g&4095](l)|0;q=e;r=c[2440596]|0;s=c[2415243]|0;t=c[2443776]|0}else{q=a[j+(o&255)|0]|0;r=n;s=o;t=p}}while(0);p=r-1|0;c[2440596]=p;r=s&65535;do{if((c[t+68+((s>>>8&255)<<2)>>2]|0)==0){o=c[t+3148>>2]|0;if((o|0)==0){u=p;v=s;w=t;break}gj[o&4095](r)|0;u=c[2440596]|0;v=c[2415243]|0;w=c[2443776]|0}else{u=p;v=s;w=t}}while(0);t=u-1|0;c[2440596]=t;u=a[9660979]&124|q&1;s=(q&255)>>>1;a[9660979]=(s|0)==0?u|2:u;u=s&255;s=c[w+68+((v>>>8&255|256)<<2)>>2]|0;if((s|0)!=0){a[s+(v&255)|0]=u;x=t;y=x-1|0;c[2440596]=y;return}s=c[w+3152>>2]|0;if((s|0)==0){x=t;y=x-1|0;c[2440596]=y;return}gg[s&4095](v&65535,u);x=c[2440596]|0;y=x-1|0;c[2440596]=y;return}function f_1(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;b[4830480]=k+1&65535;g=k&65535;e=c[l+68+(g>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[l+3168>>2]|0;if((f|0)==0){n=0;o=j;p=l;break}h=gj[f&4095](k)|0;n=h;o=c[2440596]|0;p=c[2443776]|0}else{n=a[e+(g&255)|0]|0;o=j;p=l}}while(0);a[9660973]=n;n=o-1|0;c[2440596]=n;o=c[2415243]|0;l=o&65535;j=c[p+68+((o>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[p+3148>>2]|0;if((g|0)==0){q=0;r=n;s=o;t=p;break}e=gj[g&4095](l)|0;q=e;r=c[2440596]|0;s=c[2415243]|0;t=c[2443776]|0}else{q=a[j+(o&255)|0]|0;r=n;s=o;t=p}}while(0);p=q&255;o=r-1|0;c[2440596]=o;r=s&65535;do{if((c[t+68+((s>>>8&255)<<2)>>2]|0)==0){n=c[t+3148>>2]|0;if((n|0)==0){u=o;break}gj[n&4095](r)|0;u=c[2440596]|0}else{u=o}}while(0);o=u-1|0;c[2440596]=o;u=a[9660979]|0;r=u&-2|q&1;a[9660979]=r;q=((u&255)<<8|p)>>>1;if((q&255|0)==0){v=r&125|2}else{v=(q&128|r&125)&255}a[9660979]=v;v=c[2415243]|0;r=q&255;q=c[2443776]|0;p=c[q+68+((v>>>8&255|256)<<2)>>2]|0;if((p|0)!=0){a[p+(v&255)|0]=r;w=o;x=w-1|0;c[2440596]=x;return}p=c[q+3152>>2]|0;if((p|0)==0){w=o;x=w-1|0;c[2440596]=x;return}gg[p&4095](v&65535,r);w=c[2440596]|0;x=w-1|0;c[2440596]=x;return}function f_2(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=a[9660977]|0;e=b[4830480]|0;f=e+1&65535;b[4830480]=f;g=e&65535;h=c[2443776]|0;i=c[h+68+(g>>>8<<2)>>2]|0;do{if((i|0)==0){j=c[h+3168>>2]|0;if((j|0)==0){k=0;l=f;m=h;break}n=gj[j&4095](e)|0;k=n;l=b[4830480]|0;m=c[2443776]|0}else{k=a[i+(g&255)|0]|0;l=f;m=h}}while(0);a[9660972]=k;k=(c[2440596]|0)-1|0;c[2440596]=k;b[4830480]=l+1&65535;h=l&65535;f=c[m+68+(h>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[m+3168>>2]|0;if((g|0)==0){o=0;p=k;q=m;break}i=gj[g&4095](l)|0;o=i;p=c[2440596]|0;q=c[2443776]|0}else{o=a[f+(h&255)|0]|0;p=k;q=m}}while(0);a[9660973]=o;o=p-1|0;c[2440596]=o;p=c[2415243]|0;m=c[q+68+((p>>>8&255|256)<<2)>>2]|0;if((m|0)!=0){a[m+(p&255)|0]=d;r=o;s=r-1|0;c[2440596]=s;return}m=c[q+3152>>2]|0;if((m|0)==0){r=o;s=r-1|0;c[2440596]=s;return}gg[m&4095](p&65535,d);r=c[2440596]|0;s=r-1|0;c[2440596]=s;return}function f_3(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;b[4830480]=k+1&65535;g=k&65535;e=c[l+68+(g>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[l+3168>>2]|0;if((f|0)==0){n=0;o=j;p=l;break}h=gj[f&4095](k)|0;n=h;o=c[2440596]|0;p=c[2443776]|0}else{n=a[e+(g&255)|0]|0;o=j;p=l}}while(0);a[9660973]=n;n=o-1|0;c[2440596]=n;o=c[2415243]|0;l=o&65535;j=c[p+68+((o>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[p+3148>>2]|0;if((g|0)==0){q=0;r=n;break}e=gj[g&4095](l)|0;q=e;r=c[2440596]|0}else{q=a[j+(o&255)|0]|0;r=n}}while(0);c[2440596]=r-1;a[9660977]=q;a[9660979]=a[9660979]&125|(q<<24>>24==0?2:q&-128);return}function f_4(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;b[4830480]=k+1&65535;g=k&65535;e=c[l+68+(g>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[l+3168>>2]|0;if((f|0)==0){n=0;o=j;p=l;break}h=gj[f&4095](k)|0;n=h;o=c[2440596]|0;p=c[2443776]|0}else{n=a[e+(g&255)|0]|0;o=j;p=l}}while(0);a[9660973]=n;n=o-1|0;c[2440596]=n;o=c[2415243]|0;l=o&65535;j=c[p+68+((o>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[p+3148>>2]|0;if((g|0)==0){q=0;r=n;s=o;t=p;break}e=gj[g&4095](l)|0;q=e;r=c[2440596]|0;s=c[2415243]|0;t=c[2443776]|0}else{q=a[j+(o&255)|0]|0;r=n;s=o;t=p}}while(0);p=r-1|0;c[2440596]=p;r=s&65535;do{if((c[t+68+((s>>>8&255)<<2)>>2]|0)==0){o=c[t+3148>>2]|0;if((o|0)==0){u=p;v=s;w=t;break}gj[o&4095](r)|0;u=c[2440596]|0;v=c[2415243]|0;w=c[2443776]|0}else{u=p;v=s;w=t}}while(0);t=u-1|0;c[2440596]=t;u=q-1&255;a[9660979]=a[9660979]&125|(u<<24>>24==0?2:u&-128);q=c[w+68+((v>>>8&255|256)<<2)>>2]|0;if((q|0)!=0){a[q+(v&255)|0]=u;x=t;y=x-1|0;c[2440596]=y;return}q=c[w+3152>>2]|0;if((q|0)==0){x=t;y=x-1|0;c[2440596]=y;return}gg[q&4095](v&65535,u);x=c[2440596]|0;y=x-1|0;c[2440596]=y;return}function f_5(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;j=(c[2440596]|0)-1|0;c[2440596]=j;b[4830480]=k+1&65535;g=k&65535;e=c[l+68+(g>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[l+3168>>2]|0;if((f|0)==0){n=0;o=j;p=l;break}h=gj[f&4095](k)|0;n=h;o=c[2440596]|0;p=c[2443776]|0}else{n=a[e+(g&255)|0]|0;o=j;p=l}}while(0);a[9660973]=n;n=o-1|0;c[2440596]=n;o=c[2415243]|0;l=o&65535;j=c[p+68+((o>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[p+3148>>2]|0;if((g|0)==0){q=0;r=n;s=o;t=p;break}e=gj[g&4095](l)|0;q=e;r=c[2440596]|0;s=c[2415243]|0;t=c[2443776]|0}else{q=a[j+(o&255)|0]|0;r=n;s=o;t=p}}while(0);p=r-1|0;c[2440596]=p;r=s&65535;do{if((c[t+68+((s>>>8&255)<<2)>>2]|0)==0){o=c[t+3148>>2]|0;if((o|0)==0){u=p;v=s;w=t;break}gj[o&4095](r)|0;u=c[2440596]|0;v=c[2415243]|0;w=c[2443776]|0}else{u=p;v=s;w=t}}while(0);t=u-1|0;c[2440596]=t;u=q+1&255;a[9660979]=a[9660979]&125|(u<<24>>24==0?2:u&-128);q=c[w+68+((v>>>8&255|256)<<2)>>2]|0;if((q|0)!=0){a[q+(v&255)|0]=u;x=t;y=x-1|0;c[2440596]=y;return}q=c[w+3152>>2]|0;if((q|0)==0){x=t;y=x-1|0;c[2440596]=y;return}gg[q&4095](v&65535,u);x=c[2440596]|0;y=x-1|0;c[2440596]=y;return}function f_6(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;e=b[4830480]|0;f=e+1&65535;b[4830480]=f;g=e&65535;h=c[2443776]|0;i=c[h+68+(g>>>8<<2)>>2]|0;do{if((i|0)==0){j=c[h+3168>>2]|0;if((j|0)==0){k=0;l=f;m=h;break}n=gj[j&4095](e)|0;k=n;l=b[4830480]|0;m=c[2443776]|0}else{k=a[i+(g&255)|0]|0;l=f;m=h}}while(0);a[9660972]=k;k=(c[2440596]|0)-1|0;c[2440596]=k;h=l+1&65535;b[4830480]=h;f=l&65535;g=c[m+68+(f>>>8<<2)>>2]|0;do{if((g|0)==0){i=c[m+3168>>2]|0;if((i|0)==0){o=0;p=k;q=h;r=m;break}e=gj[i&4095](l)|0;o=e;p=c[2440596]|0;q=b[4830480]|0;r=c[2443776]|0}else{o=a[g+(f&255)|0]|0;p=k;q=h;r=m}}while(0);a[9660973]=o;o=p-1|0;c[2440596]=o;p=q-1&65535;do{if((c[r+68+((p&65535)>>>8<<2)>>2]|0)==0){q=c[r+3148>>2]|0;if((q|0)==0){s=o;t=r;break}gj[q&4095](p)|0;s=c[2440596]|0;t=c[2443776]|0}else{s=o;t=r}}while(0);r=s-1|0;c[2440596]=r;b[4830486]=(b[4830486]|0)+(d[9660977]|0)&65535;s=c[2415243]|0;o=s&65535;p=c[t+68+((s>>>8&255)<<2)>>2]|0;do{if((p|0)==0){q=c[t+3148>>2]|0;if((q|0)==0){u=0;v=r;w=s;x=t;break}m=gj[q&4095](o)|0;u=m;v=c[2440596]|0;w=c[2415243]|0;x=c[2443776]|0}else{u=a[p+(s&255)|0]|0;v=r;w=s;x=t}}while(0);t=v-1|0;c[2440596]=t;v=w&65535;do{if((c[x+68+((w>>>8&255)<<2)>>2]|0)==0){s=c[x+3148>>2]|0;if((s|0)==0){y=t;z=w;A=x;break}gj[s&4095](v)|0;y=c[2440596]|0;z=c[2415243]|0;A=c[2443776]|0}else{y=t;z=w;A=x}}while(0);x=y-1|0;c[2440596]=x;y=u<<1;a[9660979]=(y<<24>>24==0?2:y&-128)|(u&255)>>>7|a[9660979]&124;u=c[A+68+((z>>>8&255|256)<<2)>>2]|0;if((u|0)!=0){a[u+(z&255)|0]=y;B=x;C=B-1|0;c[2440596]=C;return}u=c[A+3152>>2]|0;if((u|0)==0){B=x;C=B-1|0;c[2440596]=C;return}gg[u&4095](z&65535,y);B=c[2440596]|0;C=B-1|0;c[2440596]=C;return}function f_7(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;e=b[4830480]|0;f=e+1&65535;b[4830480]=f;g=e&65535;h=c[2443776]|0;i=c[h+68+(g>>>8<<2)>>2]|0;do{if((i|0)==0){j=c[h+3168>>2]|0;if((j|0)==0){k=0;l=f;m=h;break}n=gj[j&4095](e)|0;k=n;l=b[4830480]|0;m=c[2443776]|0}else{k=a[i+(g&255)|0]|0;l=f;m=h}}while(0);a[9660972]=k;k=(c[2440596]|0)-1|0;c[2440596]=k;h=l+1&65535;b[4830480]=h;f=l&65535;g=c[m+68+(f>>>8<<2)>>2]|0;do{if((g|0)==0){i=c[m+3168>>2]|0;if((i|0)==0){o=0;p=k;q=h;r=m;break}e=gj[i&4095](l)|0;o=e;p=c[2440596]|0;q=b[4830480]|0;r=c[2443776]|0}else{o=a[g+(f&255)|0]|0;p=k;q=h;r=m}}while(0);a[9660973]=o;o=p-1|0;c[2440596]=o;p=q-1&65535;do{if((c[r+68+((p&65535)>>>8<<2)>>2]|0)==0){q=c[r+3148>>2]|0;if((q|0)==0){s=o;t=r;break}gj[q&4095](p)|0;s=c[2440596]|0;t=c[2443776]|0}else{s=o;t=r}}while(0);r=s-1|0;c[2440596]=r;b[4830486]=(b[4830486]|0)+(d[9660977]|0)&65535;s=c[2415243]|0;o=s&65535;p=c[t+68+((s>>>8&255)<<2)>>2]|0;do{if((p|0)==0){q=c[t+3148>>2]|0;if((q|0)==0){u=0;v=r;w=s;x=t;break}m=gj[q&4095](o)|0;u=m;v=c[2440596]|0;w=c[2415243]|0;x=c[2443776]|0}else{u=a[p+(s&255)|0]|0;v=r;w=s;x=t}}while(0);t=v-1|0;c[2440596]=t;v=w&65535;do{if((c[x+68+((w>>>8&255)<<2)>>2]|0)==0){s=c[x+3148>>2]|0;if((s|0)==0){y=t;z=w;A=x;break}gj[s&4095](v)|0;y=c[2440596]|0;z=c[2415243]|0;A=c[2443776]|0}else{y=t;z=w;A=x}}while(0);x=y-1|0;c[2440596]=x;y=u<<1;w=a[9660979]|0;t=w&1|y;a[9660979]=w&124|(u&255)>>>7|(t<<24>>24==0?2:y&-128);y=c[A+68+((z>>>8&255|256)<<2)>>2]|0;if((y|0)!=0){a[y+(z&255)|0]=t;B=x;C=B-1|0;c[2440596]=C;return}y=c[A+3152>>2]|0;if((y|0)==0){B=x;C=B-1|0;c[2440596]=C;return}gg[y&4095](z&65535,t);B=c[2440596]|0;C=B-1|0;c[2440596]=C;return}function f_8(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;e=b[4830480]|0;f=e+1&65535;b[4830480]=f;g=e&65535;h=c[2443776]|0;i=c[h+68+(g>>>8<<2)>>2]|0;do{if((i|0)==0){j=c[h+3168>>2]|0;if((j|0)==0){k=0;l=f;m=h;break}n=gj[j&4095](e)|0;k=n;l=b[4830480]|0;m=c[2443776]|0}else{k=a[i+(g&255)|0]|0;l=f;m=h}}while(0);a[9660972]=k;k=(c[2440596]|0)-1|0;c[2440596]=k;h=l+1&65535;b[4830480]=h;f=l&65535;g=c[m+68+(f>>>8<<2)>>2]|0;do{if((g|0)==0){i=c[m+3168>>2]|0;if((i|0)==0){o=0;p=k;q=h;r=m;break}e=gj[i&4095](l)|0;o=e;p=c[2440596]|0;q=b[4830480]|0;r=c[2443776]|0}else{o=a[g+(f&255)|0]|0;p=k;q=h;r=m}}while(0);a[9660973]=o;o=p-1|0;c[2440596]=o;p=q-1&65535;do{if((c[r+68+((p&65535)>>>8<<2)>>2]|0)==0){q=c[r+3148>>2]|0;if((q|0)==0){s=o;t=r;break}gj[q&4095](p)|0;s=c[2440596]|0;t=c[2443776]|0}else{s=o;t=r}}while(0);r=s-1|0;c[2440596]=r;b[4830486]=(b[4830486]|0)+(d[9660977]|0)&65535;s=c[2415243]|0;o=s&65535;p=c[t+68+((s>>>8&255)<<2)>>2]|0;do{if((p|0)==0){q=c[t+3148>>2]|0;if((q|0)==0){u=0;v=r;w=s;x=t;break}m=gj[q&4095](o)|0;u=m;v=c[2440596]|0;w=c[2415243]|0;x=c[2443776]|0}else{u=a[p+(s&255)|0]|0;v=r;w=s;x=t}}while(0);t=v-1|0;c[2440596]=t;v=w&65535;do{if((c[x+68+((w>>>8&255)<<2)>>2]|0)==0){s=c[x+3148>>2]|0;if((s|0)==0){y=t;z=w;A=x;break}gj[s&4095](v)|0;y=c[2440596]|0;z=c[2415243]|0;A=c[2443776]|0}else{y=t;z=w;A=x}}while(0);x=y-1|0;c[2440596]=x;y=a[9660979]&124|u&1;w=(u&255)>>>1;a[9660979]=(w|0)==0?y|2:y;y=w&255;w=c[A+68+((z>>>8&255|256)<<2)>>2]|0;if((w|0)!=0){a[w+(z&255)|0]=y;B=x;C=B-1|0;c[2440596]=C;return}w=c[A+3152>>2]|0;if((w|0)==0){B=x;C=B-1|0;c[2440596]=C;return}gg[w&4095](z&65535,y);B=c[2440596]|0;C=B-1|0;c[2440596]=C;return}function f_9(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;e=b[4830480]|0;f=e+1&65535;b[4830480]=f;g=e&65535;h=c[2443776]|0;i=c[h+68+(g>>>8<<2)>>2]|0;do{if((i|0)==0){j=c[h+3168>>2]|0;if((j|0)==0){k=0;l=f;m=h;break}n=gj[j&4095](e)|0;k=n;l=b[4830480]|0;m=c[2443776]|0}else{k=a[i+(g&255)|0]|0;l=f;m=h}}while(0);a[9660972]=k;k=(c[2440596]|0)-1|0;c[2440596]=k;h=l+1&65535;b[4830480]=h;f=l&65535;g=c[m+68+(f>>>8<<2)>>2]|0;do{if((g|0)==0){i=c[m+3168>>2]|0;if((i|0)==0){o=0;p=k;q=h;r=m;break}e=gj[i&4095](l)|0;o=e;p=c[2440596]|0;q=b[4830480]|0;r=c[2443776]|0}else{o=a[g+(f&255)|0]|0;p=k;q=h;r=m}}while(0);a[9660973]=o;o=p-1|0;c[2440596]=o;p=q-1&65535;do{if((c[r+68+((p&65535)>>>8<<2)>>2]|0)==0){q=c[r+3148>>2]|0;if((q|0)==0){s=o;t=r;break}gj[q&4095](p)|0;s=c[2440596]|0;t=c[2443776]|0}else{s=o;t=r}}while(0);r=s-1|0;c[2440596]=r;b[4830486]=(b[4830486]|0)+(d[9660977]|0)&65535;s=c[2415243]|0;o=s&65535;p=c[t+68+((s>>>8&255)<<2)>>2]|0;do{if((p|0)==0){q=c[t+3148>>2]|0;if((q|0)==0){u=0;v=r;w=s;x=t;break}m=gj[q&4095](o)|0;u=m;v=c[2440596]|0;w=c[2415243]|0;x=c[2443776]|0}else{u=a[p+(s&255)|0]|0;v=r;w=s;x=t}}while(0);t=u&255;s=v-1|0;c[2440596]=s;v=w&65535;do{if((c[x+68+((w>>>8&255)<<2)>>2]|0)==0){r=c[x+3148>>2]|0;if((r|0)==0){y=s;break}gj[r&4095](v)|0;y=c[2440596]|0}else{y=s}}while(0);s=y-1|0;c[2440596]=s;y=a[9660979]|0;v=y&-2|u&1;a[9660979]=v;u=((y&255)<<8|t)>>>1;if((u&255|0)==0){z=v&125|2}else{z=(u&128|v&125)&255}a[9660979]=z;z=c[2415243]|0;v=u&255;u=c[2443776]|0;t=c[u+68+((z>>>8&255|256)<<2)>>2]|0;if((t|0)!=0){a[t+(z&255)|0]=v;A=s;B=A-1|0;c[2440596]=B;return}t=c[u+3152>>2]|0;if((t|0)==0){A=s;B=A-1|0;c[2440596]=B;return}gg[t&4095](z&65535,v);A=c[2440596]|0;B=A-1|0;c[2440596]=B;return}function f$a(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=b[4830480]|0;f=e+1&65535;b[4830480]=f;g=e&65535;h=c[2443776]|0;i=c[h+68+(g>>>8<<2)>>2]|0;do{if((i|0)==0){j=c[h+3168>>2]|0;if((j|0)==0){k=0;l=f;m=h;break}n=gj[j&4095](e)|0;k=n;l=b[4830480]|0;m=c[2443776]|0}else{k=a[i+(g&255)|0]|0;l=f;m=h}}while(0);a[9660972]=k;k=(c[2440596]|0)-1|0;c[2440596]=k;h=l+1&65535;b[4830480]=h;f=l&65535;g=c[m+68+(f>>>8<<2)>>2]|0;do{if((g|0)==0){i=c[m+3168>>2]|0;if((i|0)==0){o=0;p=k;q=h;r=m;break}e=gj[i&4095](l)|0;o=e;p=c[2440596]|0;q=b[4830480]|0;r=c[2443776]|0}else{o=a[g+(f&255)|0]|0;p=k;q=h;r=m}}while(0);a[9660973]=o;o=p-1|0;c[2440596]=o;p=q-1&65535;do{if((c[r+68+((p&65535)>>>8<<2)>>2]|0)==0){q=c[r+3148>>2]|0;if((q|0)==0){s=o;t=r;break}gj[q&4095](p)|0;s=c[2440596]|0;t=c[2443776]|0}else{s=o;t=r}}while(0);r=s-1|0;c[2440596]=r;b[4830486]=(b[4830486]|0)+(d[9660977]|0)&65535;s=c[2415243]|0;o=c[t+68+((s>>>8&255|256)<<2)>>2]|0;if((o|0)!=0){a[o+(s&255)|0]=0;u=r;v=u-1|0;c[2440596]=v;return}o=c[t+3152>>2]|0;if((o|0)==0){u=r;v=u-1|0;c[2440596]=v;return}gg[o&4095](s&65535,0);u=c[2440596]|0;v=u-1|0;c[2440596]=v;return}function f$b(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=d&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=e;l=g;break}m=gj[i&4095](d)|0;j=m;k=b[4830480]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=e;l=g}}while(0);a[9660972]=j;g=(c[2440596]|0)-1|0;c[2440596]=g;b[4830480]=k+1&65535;e=k&65535;f=c[l+68+(e>>>8<<2)>>2]|0;do{if((f|0)==0){h=c[l+3168>>2]|0;if((h|0)==0){n=0;o=g;p=j;break}d=gj[h&4095](k)|0;n=d;o=c[2440596]|0;p=a[9660972]|0}else{n=a[f+(e&255)|0]|0;o=g;p=j}}while(0);a[9660973]=n;n=o-1|0;c[2440596]=n;o=a[9660978]|0;if(((o&255)+(p&255)|0)>255){p=(b[4830480]|0)-1&65535;j=c[2443776]|0;do{if((c[j+68+((p&65535)>>>8<<2)>>2]|0)==0){g=c[j+3148>>2]|0;if((g|0)==0){q=n;r=o;break}gj[g&4095](p)|0;q=c[2440596]|0;r=a[9660978]|0}else{q=n;r=o}}while(0);p=q-1|0;c[2440596]=p;s=r;t=p}else{s=o;t=n}b[4830486]=(b[4830486]|0)+(s&255)&65535;s=c[2415243]|0;n=s&65535;o=c[2443776]|0;p=c[o+68+((s>>>8&255)<<2)>>2]|0;do{if((p|0)==0){r=c[o+3148>>2]|0;if((r|0)==0){u=0;v=t;break}q=gj[r&4095](n)|0;u=q;v=c[2440596]|0}else{u=a[p+(s&255)|0]|0;v=t}}while(0);c[2440596]=v-1;a[9660977]=u;a[9660979]=a[9660979]&125|(u<<24>>24==0?2:u&-128);return}function f$c(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;e=b[4830480]|0;f=e+1&65535;b[4830480]=f;g=e&65535;h=c[2443776]|0;i=c[h+68+(g>>>8<<2)>>2]|0;do{if((i|0)==0){j=c[h+3168>>2]|0;if((j|0)==0){k=0;l=f;m=h;break}n=gj[j&4095](e)|0;k=n;l=b[4830480]|0;m=c[2443776]|0}else{k=a[i+(g&255)|0]|0;l=f;m=h}}while(0);a[9660972]=k;k=(c[2440596]|0)-1|0;c[2440596]=k;h=l+1&65535;b[4830480]=h;f=l&65535;g=c[m+68+(f>>>8<<2)>>2]|0;do{if((g|0)==0){i=c[m+3168>>2]|0;if((i|0)==0){o=0;p=k;q=h;r=m;break}e=gj[i&4095](l)|0;o=e;p=c[2440596]|0;q=b[4830480]|0;r=c[2443776]|0}else{o=a[g+(f&255)|0]|0;p=k;q=h;r=m}}while(0);a[9660973]=o;o=p-1|0;c[2440596]=o;p=q-1&65535;do{if((c[r+68+((p&65535)>>>8<<2)>>2]|0)==0){q=c[r+3148>>2]|0;if((q|0)==0){s=o;t=r;break}gj[q&4095](p)|0;s=c[2440596]|0;t=c[2443776]|0}else{s=o;t=r}}while(0);r=s-1|0;c[2440596]=r;b[4830486]=(b[4830486]|0)+(d[9660977]|0)&65535;s=c[2415243]|0;o=s&65535;p=c[t+68+((s>>>8&255)<<2)>>2]|0;do{if((p|0)==0){q=c[t+3148>>2]|0;if((q|0)==0){u=0;v=r;w=s;x=t;break}m=gj[q&4095](o)|0;u=m;v=c[2440596]|0;w=c[2415243]|0;x=c[2443776]|0}else{u=a[p+(s&255)|0]|0;v=r;w=s;x=t}}while(0);t=v-1|0;c[2440596]=t;v=w&65535;do{if((c[x+68+((w>>>8&255)<<2)>>2]|0)==0){s=c[x+3148>>2]|0;if((s|0)==0){y=t;z=w;A=x;break}gj[s&4095](v)|0;y=c[2440596]|0;z=c[2415243]|0;A=c[2443776]|0}else{y=t;z=w;A=x}}while(0);x=y-1|0;c[2440596]=x;y=u-1&255;a[9660979]=a[9660979]&125|(y<<24>>24==0?2:y&-128);u=c[A+68+((z>>>8&255|256)<<2)>>2]|0;if((u|0)!=0){a[u+(z&255)|0]=y;B=x;C=B-1|0;c[2440596]=C;return}u=c[A+3152>>2]|0;if((u|0)==0){B=x;C=B-1|0;c[2440596]=C;return}gg[u&4095](z&65535,y);B=c[2440596]|0;C=B-1|0;c[2440596]=C;return}function f$d(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;e=b[4830480]|0;f=e+1&65535;b[4830480]=f;g=e&65535;h=c[2443776]|0;i=c[h+68+(g>>>8<<2)>>2]|0;do{if((i|0)==0){j=c[h+3168>>2]|0;if((j|0)==0){k=0;l=f;m=h;break}n=gj[j&4095](e)|0;k=n;l=b[4830480]|0;m=c[2443776]|0}else{k=a[i+(g&255)|0]|0;l=f;m=h}}while(0);a[9660972]=k;k=(c[2440596]|0)-1|0;c[2440596]=k;h=l+1&65535;b[4830480]=h;f=l&65535;g=c[m+68+(f>>>8<<2)>>2]|0;do{if((g|0)==0){i=c[m+3168>>2]|0;if((i|0)==0){o=0;p=k;q=h;r=m;break}e=gj[i&4095](l)|0;o=e;p=c[2440596]|0;q=b[4830480]|0;r=c[2443776]|0}else{o=a[g+(f&255)|0]|0;p=k;q=h;r=m}}while(0);a[9660973]=o;o=p-1|0;c[2440596]=o;p=q-1&65535;do{if((c[r+68+((p&65535)>>>8<<2)>>2]|0)==0){q=c[r+3148>>2]|0;if((q|0)==0){s=o;t=r;break}gj[q&4095](p)|0;s=c[2440596]|0;t=c[2443776]|0}else{s=o;t=r}}while(0);r=s-1|0;c[2440596]=r;b[4830486]=(b[4830486]|0)+(d[9660977]|0)&65535;s=c[2415243]|0;o=s&65535;p=c[t+68+((s>>>8&255)<<2)>>2]|0;do{if((p|0)==0){q=c[t+3148>>2]|0;if((q|0)==0){u=0;v=r;w=s;x=t;break}m=gj[q&4095](o)|0;u=m;v=c[2440596]|0;w=c[2415243]|0;x=c[2443776]|0}else{u=a[p+(s&255)|0]|0;v=r;w=s;x=t}}while(0);t=v-1|0;c[2440596]=t;v=w&65535;do{if((c[x+68+((w>>>8&255)<<2)>>2]|0)==0){s=c[x+3148>>2]|0;if((s|0)==0){y=t;z=w;A=x;break}gj[s&4095](v)|0;y=c[2440596]|0;z=c[2415243]|0;A=c[2443776]|0}else{y=t;z=w;A=x}}while(0);x=y-1|0;c[2440596]=x;y=u+1&255;a[9660979]=a[9660979]&125|(y<<24>>24==0?2:y&-128);u=c[A+68+((z>>>8&255|256)<<2)>>2]|0;if((u|0)!=0){a[u+(z&255)|0]=y;B=x;C=B-1|0;c[2440596]=C;return}u=c[A+3152>>2]|0;if((u|0)==0){B=x;C=B-1|0;c[2440596]=C;return}gg[u&4095](z&65535,y);B=c[2440596]|0;C=B-1|0;c[2440596]=C;return}function f$e(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=0;m=i;n=j;break}k=gj[d&4095](e)|0;l=k;m=c[2440596]|0;n=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=j}}while(0);j=m-1|0;c[2440596]=j;m=b[4830480]|0;b[4830480]=m+1&65535;i=m&65535;f=c[n+68+(i>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[n+3168>>2]|0;if((g|0)==0){o=0;p=j;break}e=gj[g&4095](m)|0;o=e;p=c[2440596]|0}else{o=a[f+(i&255)|0]|0;p=j}}while(0);j=p-1|0;c[2440596]=j;if((l&1)!=0){return}l=b[4830480]|0;p=c[2443776]|0;do{if((c[p+68+((l&65535)>>>8<<2)>>2]|0)==0){i=c[p+3148>>2]|0;if((i|0)==0){q=j;r=l;break}gj[i&4095](l)|0;q=c[2440596]|0;r=b[4830480]|0}else{q=j;r=l}}while(0);l=q-1|0;c[2440596]=l;q=r+(o<<24>>24)&65535;b[4830486]=q;o=a[9660961]|0;if(((q&65535)>>>8&255)<<24>>24!=o<<24>>24){r=(o&255)<<8;o=r|q&255;q=c[2443776]|0;do{if((c[q+68+((r&65535)>>>8<<2)>>2]|0)==0){j=c[q+3148>>2]|0;if((j|0)==0){s=l;break}gj[j&4095](o)|0;s=c[2440596]|0}else{s=l}}while(0);c[2440596]=s-1}c[2415240]=c[2415243];return}function f$f(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=0;m=i;n=j;break}k=gj[d&4095](e)|0;l=k;m=c[2440596]|0;n=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=j}}while(0);j=m-1|0;c[2440596]=j;m=b[4830480]|0;b[4830480]=m+1&65535;i=m&65535;f=c[n+68+(i>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[n+3168>>2]|0;if((g|0)==0){o=0;p=j;break}e=gj[g&4095](m)|0;o=e;p=c[2440596]|0}else{o=a[f+(i&255)|0]|0;p=j}}while(0);j=p-1|0;c[2440596]=j;if((l&4)!=0){return}l=b[4830480]|0;p=c[2443776]|0;do{if((c[p+68+((l&65535)>>>8<<2)>>2]|0)==0){i=c[p+3148>>2]|0;if((i|0)==0){q=j;r=l;break}gj[i&4095](l)|0;q=c[2440596]|0;r=b[4830480]|0}else{q=j;r=l}}while(0);l=q-1|0;c[2440596]=l;q=r+(o<<24>>24)&65535;b[4830486]=q;o=a[9660961]|0;if(((q&65535)>>>8&255)<<24>>24!=o<<24>>24){r=(o&255)<<8;o=r|q&255;q=c[2443776]|0;do{if((c[q+68+((r&65535)>>>8<<2)>>2]|0)==0){j=c[q+3148>>2]|0;if((j|0)==0){s=l;break}gj[j&4095](o)|0;s=c[2440596]|0}else{s=l}}while(0);c[2440596]=s-1}c[2415240]=c[2415243];return}function f$g(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=0;m=i;n=j;break}k=gj[d&4095](e)|0;l=k;m=c[2440596]|0;n=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=j}}while(0);j=m-1|0;c[2440596]=j;m=b[4830480]|0;b[4830480]=m+1&65535;i=m&65535;f=c[n+68+(i>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[n+3168>>2]|0;if((g|0)==0){o=0;p=j;break}e=gj[g&4095](m)|0;o=e;p=c[2440596]|0}else{o=a[f+(i&255)|0]|0;p=j}}while(0);j=p-1|0;c[2440596]=j;if((l&16)!=0){return}l=b[4830480]|0;p=c[2443776]|0;do{if((c[p+68+((l&65535)>>>8<<2)>>2]|0)==0){i=c[p+3148>>2]|0;if((i|0)==0){q=j;r=l;break}gj[i&4095](l)|0;q=c[2440596]|0;r=b[4830480]|0}else{q=j;r=l}}while(0);l=q-1|0;c[2440596]=l;q=r+(o<<24>>24)&65535;b[4830486]=q;o=a[9660961]|0;if(((q&65535)>>>8&255)<<24>>24!=o<<24>>24){r=(o&255)<<8;o=r|q&255;q=c[2443776]|0;do{if((c[q+68+((r&65535)>>>8<<2)>>2]|0)==0){j=c[q+3148>>2]|0;if((j|0)==0){s=l;break}gj[j&4095](o)|0;s=c[2440596]|0}else{s=l}}while(0);c[2440596]=s-1}c[2415240]=c[2415243];return}function f$h(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=0;m=i;n=j;break}k=gj[d&4095](e)|0;l=k;m=c[2440596]|0;n=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=j}}while(0);j=m-1|0;c[2440596]=j;m=b[4830480]|0;b[4830480]=m+1&65535;i=m&65535;f=c[n+68+(i>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[n+3168>>2]|0;if((g|0)==0){o=0;p=j;break}e=gj[g&4095](m)|0;o=e;p=c[2440596]|0}else{o=a[f+(i&255)|0]|0;p=j}}while(0);j=p-1|0;c[2440596]=j;if((l&64)!=0){return}l=b[4830480]|0;p=c[2443776]|0;do{if((c[p+68+((l&65535)>>>8<<2)>>2]|0)==0){i=c[p+3148>>2]|0;if((i|0)==0){q=j;r=l;break}gj[i&4095](l)|0;q=c[2440596]|0;r=b[4830480]|0}else{q=j;r=l}}while(0);l=q-1|0;c[2440596]=l;q=r+(o<<24>>24)&65535;b[4830486]=q;o=a[9660961]|0;if(((q&65535)>>>8&255)<<24>>24!=o<<24>>24){r=(o&255)<<8;o=r|q&255;q=c[2443776]|0;do{if((c[q+68+((r&65535)>>>8<<2)>>2]|0)==0){j=c[q+3148>>2]|0;if((j|0)==0){s=l;break}gj[j&4095](o)|0;s=c[2440596]|0}else{s=l}}while(0);c[2440596]=s-1}c[2415240]=c[2415243];return}function f$i(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=0;m=i;n=j;break}k=gj[d&4095](e)|0;l=k;m=c[2440596]|0;n=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=j}}while(0);j=m-1|0;c[2440596]=j;m=b[4830480]|0;b[4830480]=m+1&65535;i=m&65535;f=c[n+68+(i>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[n+3168>>2]|0;if((g|0)==0){o=0;p=j;break}e=gj[g&4095](m)|0;o=e;p=c[2440596]|0}else{o=a[f+(i&255)|0]|0;p=j}}while(0);j=p-1|0;c[2440596]=j;if((l&1)==0){return}l=b[4830480]|0;p=c[2443776]|0;do{if((c[p+68+((l&65535)>>>8<<2)>>2]|0)==0){i=c[p+3148>>2]|0;if((i|0)==0){q=j;r=l;break}gj[i&4095](l)|0;q=c[2440596]|0;r=b[4830480]|0}else{q=j;r=l}}while(0);l=q-1|0;c[2440596]=l;q=r+(o<<24>>24)&65535;b[4830486]=q;o=a[9660961]|0;if(((q&65535)>>>8&255)<<24>>24!=o<<24>>24){r=(o&255)<<8;o=r|q&255;q=c[2443776]|0;do{if((c[q+68+((r&65535)>>>8<<2)>>2]|0)==0){j=c[q+3148>>2]|0;if((j|0)==0){s=l;break}gj[j&4095](o)|0;s=c[2440596]|0}else{s=l}}while(0);c[2440596]=s-1}c[2415240]=c[2415243];return}function f$j(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=0;m=i;n=j;break}k=gj[d&4095](e)|0;l=k;m=c[2440596]|0;n=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=j}}while(0);j=m-1|0;c[2440596]=j;m=b[4830480]|0;b[4830480]=m+1&65535;i=m&65535;f=c[n+68+(i>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[n+3168>>2]|0;if((g|0)==0){o=0;p=j;break}e=gj[g&4095](m)|0;o=e;p=c[2440596]|0}else{o=a[f+(i&255)|0]|0;p=j}}while(0);j=p-1|0;c[2440596]=j;if((l&4)==0){return}l=b[4830480]|0;p=c[2443776]|0;do{if((c[p+68+((l&65535)>>>8<<2)>>2]|0)==0){i=c[p+3148>>2]|0;if((i|0)==0){q=j;r=l;break}gj[i&4095](l)|0;q=c[2440596]|0;r=b[4830480]|0}else{q=j;r=l}}while(0);l=q-1|0;c[2440596]=l;q=r+(o<<24>>24)&65535;b[4830486]=q;o=a[9660961]|0;if(((q&65535)>>>8&255)<<24>>24!=o<<24>>24){r=(o&255)<<8;o=r|q&255;q=c[2443776]|0;do{if((c[q+68+((r&65535)>>>8<<2)>>2]|0)==0){j=c[q+3148>>2]|0;if((j|0)==0){s=l;break}gj[j&4095](o)|0;s=c[2440596]|0}else{s=l}}while(0);c[2440596]=s-1}c[2415240]=c[2415243];return}function f$k(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=0;m=i;n=j;break}k=gj[d&4095](e)|0;l=k;m=c[2440596]|0;n=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=j}}while(0);j=m-1|0;c[2440596]=j;m=b[4830480]|0;b[4830480]=m+1&65535;i=m&65535;f=c[n+68+(i>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[n+3168>>2]|0;if((g|0)==0){o=0;p=j;break}e=gj[g&4095](m)|0;o=e;p=c[2440596]|0}else{o=a[f+(i&255)|0]|0;p=j}}while(0);j=p-1|0;c[2440596]=j;if((l&16)==0){return}l=b[4830480]|0;p=c[2443776]|0;do{if((c[p+68+((l&65535)>>>8<<2)>>2]|0)==0){i=c[p+3148>>2]|0;if((i|0)==0){q=j;r=l;break}gj[i&4095](l)|0;q=c[2440596]|0;r=b[4830480]|0}else{q=j;r=l}}while(0);l=q-1|0;c[2440596]=l;q=r+(o<<24>>24)&65535;b[4830486]=q;o=a[9660961]|0;if(((q&65535)>>>8&255)<<24>>24!=o<<24>>24){r=(o&255)<<8;o=r|q&255;q=c[2443776]|0;do{if((c[q+68+((r&65535)>>>8<<2)>>2]|0)==0){j=c[q+3148>>2]|0;if((j|0)==0){s=l;break}gj[j&4095](o)|0;s=c[2440596]|0}else{s=l}}while(0);c[2440596]=s-1}c[2415240]=c[2415243];return}function f$l(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=0;m=i;n=j;break}k=gj[d&4095](e)|0;l=k;m=c[2440596]|0;n=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=j}}while(0);j=m-1|0;c[2440596]=j;m=b[4830480]|0;b[4830480]=m+1&65535;i=m&65535;f=c[n+68+(i>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[n+3168>>2]|0;if((g|0)==0){o=0;p=j;break}e=gj[g&4095](m)|0;o=e;p=c[2440596]|0}else{o=a[f+(i&255)|0]|0;p=j}}while(0);j=p-1|0;c[2440596]=j;if((l&64)==0){return}l=b[4830480]|0;p=c[2443776]|0;do{if((c[p+68+((l&65535)>>>8<<2)>>2]|0)==0){i=c[p+3148>>2]|0;if((i|0)==0){q=j;r=l;break}gj[i&4095](l)|0;q=c[2440596]|0;r=b[4830480]|0}else{q=j;r=l}}while(0);l=q-1|0;c[2440596]=l;q=r+(o<<24>>24)&65535;b[4830486]=q;o=a[9660961]|0;if(((q&65535)>>>8&255)<<24>>24!=o<<24>>24){r=(o&255)<<8;o=r|q&255;q=c[2443776]|0;do{if((c[q+68+((r&65535)>>>8<<2)>>2]|0)==0){j=c[q+3148>>2]|0;if((j|0)==0){s=l;break}gj[j&4095](o)|0;s=c[2440596]|0}else{s=l}}while(0);c[2440596]=s-1}c[2415240]=c[2415243];return}function f$m(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=0;m=i;n=j;break}k=gj[d&4095](e)|0;l=k;m=c[2440596]|0;n=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=j}}while(0);j=m-1|0;c[2440596]=j;m=b[4830480]|0;b[4830480]=m+1&65535;i=m&65535;f=c[n+68+(i>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[n+3168>>2]|0;if((g|0)==0){o=0;p=j;break}e=gj[g&4095](m)|0;o=e;p=c[2440596]|0}else{o=a[f+(i&255)|0]|0;p=j}}while(0);j=p-1|0;c[2440596]=j;if((l&2)!=0){return}l=b[4830480]|0;p=c[2443776]|0;do{if((c[p+68+((l&65535)>>>8<<2)>>2]|0)==0){i=c[p+3148>>2]|0;if((i|0)==0){q=j;r=l;break}gj[i&4095](l)|0;q=c[2440596]|0;r=b[4830480]|0}else{q=j;r=l}}while(0);l=q-1|0;c[2440596]=l;q=r+(o<<24>>24)&65535;b[4830486]=q;o=a[9660961]|0;if(((q&65535)>>>8&255)<<24>>24!=o<<24>>24){r=(o&255)<<8;o=r|q&255;q=c[2443776]|0;do{if((c[q+68+((r&65535)>>>8<<2)>>2]|0)==0){j=c[q+3148>>2]|0;if((j|0)==0){s=l;break}gj[j&4095](o)|0;s=c[2440596]|0}else{s=l}}while(0);c[2440596]=s-1}c[2415240]=c[2415243];return}function f$n(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=0;m=i;n=j;break}k=gj[d&4095](e)|0;l=k;m=c[2440596]|0;n=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=j}}while(0);j=m-1|0;c[2440596]=j;m=b[4830480]|0;b[4830480]=m+1&65535;i=m&65535;f=c[n+68+(i>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[n+3168>>2]|0;if((g|0)==0){o=0;p=j;break}e=gj[g&4095](m)|0;o=e;p=c[2440596]|0}else{o=a[f+(i&255)|0]|0;p=j}}while(0);j=p-1|0;c[2440596]=j;if((l&8)!=0){return}l=b[4830480]|0;p=c[2443776]|0;do{if((c[p+68+((l&65535)>>>8<<2)>>2]|0)==0){i=c[p+3148>>2]|0;if((i|0)==0){q=j;r=l;break}gj[i&4095](l)|0;q=c[2440596]|0;r=b[4830480]|0}else{q=j;r=l}}while(0);l=q-1|0;c[2440596]=l;q=r+(o<<24>>24)&65535;b[4830486]=q;o=a[9660961]|0;if(((q&65535)>>>8&255)<<24>>24!=o<<24>>24){r=(o&255)<<8;o=r|q&255;q=c[2443776]|0;do{if((c[q+68+((r&65535)>>>8<<2)>>2]|0)==0){j=c[q+3148>>2]|0;if((j|0)==0){s=l;break}gj[j&4095](o)|0;s=c[2440596]|0}else{s=l}}while(0);c[2440596]=s-1}c[2415240]=c[2415243];return}function f$o(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=0;m=i;n=j;break}k=gj[d&4095](e)|0;l=k;m=c[2440596]|0;n=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=j}}while(0);j=m-1|0;c[2440596]=j;m=b[4830480]|0;b[4830480]=m+1&65535;i=m&65535;f=c[n+68+(i>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[n+3168>>2]|0;if((g|0)==0){o=0;p=j;break}e=gj[g&4095](m)|0;o=e;p=c[2440596]|0}else{o=a[f+(i&255)|0]|0;p=j}}while(0);j=p-1|0;c[2440596]=j;if((l&32)!=0){return}l=b[4830480]|0;p=c[2443776]|0;do{if((c[p+68+((l&65535)>>>8<<2)>>2]|0)==0){i=c[p+3148>>2]|0;if((i|0)==0){q=j;r=l;break}gj[i&4095](l)|0;q=c[2440596]|0;r=b[4830480]|0}else{q=j;r=l}}while(0);l=q-1|0;c[2440596]=l;q=r+(o<<24>>24)&65535;b[4830486]=q;o=a[9660961]|0;if(((q&65535)>>>8&255)<<24>>24!=o<<24>>24){r=(o&255)<<8;o=r|q&255;q=c[2443776]|0;do{if((c[q+68+((r&65535)>>>8<<2)>>2]|0)==0){j=c[q+3148>>2]|0;if((j|0)==0){s=l;break}gj[j&4095](o)|0;s=c[2440596]|0}else{s=l}}while(0);c[2440596]=s-1}c[2415240]=c[2415243];return}function f$p(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=0;m=i;n=j;break}k=gj[d&4095](e)|0;l=k;m=c[2440596]|0;n=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=j}}while(0);j=m-1|0;c[2440596]=j;m=b[4830480]|0;b[4830480]=m+1&65535;i=m&65535;f=c[n+68+(i>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[n+3168>>2]|0;if((g|0)==0){o=0;p=j;break}e=gj[g&4095](m)|0;o=e;p=c[2440596]|0}else{o=a[f+(i&255)|0]|0;p=j}}while(0);j=p-1|0;c[2440596]=j;if(l<<24>>24<0){return}l=b[4830480]|0;p=c[2443776]|0;do{if((c[p+68+((l&65535)>>>8<<2)>>2]|0)==0){i=c[p+3148>>2]|0;if((i|0)==0){q=j;r=l;break}gj[i&4095](l)|0;q=c[2440596]|0;r=b[4830480]|0}else{q=j;r=l}}while(0);l=q-1|0;c[2440596]=l;q=r+(o<<24>>24)&65535;b[4830486]=q;o=a[9660961]|0;if(((q&65535)>>>8&255)<<24>>24!=o<<24>>24){r=(o&255)<<8;o=r|q&255;q=c[2443776]|0;do{if((c[q+68+((r&65535)>>>8<<2)>>2]|0)==0){j=c[q+3148>>2]|0;if((j|0)==0){s=l;break}gj[j&4095](o)|0;s=c[2440596]|0}else{s=l}}while(0);c[2440596]=s-1}c[2415240]=c[2415243];return}function f$q(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=0;m=i;n=j;break}k=gj[d&4095](e)|0;l=k;m=c[2440596]|0;n=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=j}}while(0);j=m-1|0;c[2440596]=j;m=b[4830480]|0;b[4830480]=m+1&65535;i=m&65535;f=c[n+68+(i>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[n+3168>>2]|0;if((g|0)==0){o=0;p=j;break}e=gj[g&4095](m)|0;o=e;p=c[2440596]|0}else{o=a[f+(i&255)|0]|0;p=j}}while(0);j=p-1|0;c[2440596]=j;if((l&2)==0){return}l=b[4830480]|0;p=c[2443776]|0;do{if((c[p+68+((l&65535)>>>8<<2)>>2]|0)==0){i=c[p+3148>>2]|0;if((i|0)==0){q=j;r=l;break}gj[i&4095](l)|0;q=c[2440596]|0;r=b[4830480]|0}else{q=j;r=l}}while(0);l=q-1|0;c[2440596]=l;q=r+(o<<24>>24)&65535;b[4830486]=q;o=a[9660961]|0;if(((q&65535)>>>8&255)<<24>>24!=o<<24>>24){r=(o&255)<<8;o=r|q&255;q=c[2443776]|0;do{if((c[q+68+((r&65535)>>>8<<2)>>2]|0)==0){j=c[q+3148>>2]|0;if((j|0)==0){s=l;break}gj[j&4095](o)|0;s=c[2440596]|0}else{s=l}}while(0);c[2440596]=s-1}c[2415240]=c[2415243];return}function f$r(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=0;m=i;n=j;break}k=gj[d&4095](e)|0;l=k;m=c[2440596]|0;n=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=j}}while(0);j=m-1|0;c[2440596]=j;m=b[4830480]|0;b[4830480]=m+1&65535;i=m&65535;f=c[n+68+(i>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[n+3168>>2]|0;if((g|0)==0){o=0;p=j;break}e=gj[g&4095](m)|0;o=e;p=c[2440596]|0}else{o=a[f+(i&255)|0]|0;p=j}}while(0);j=p-1|0;c[2440596]=j;if((l&8)==0){return}l=b[4830480]|0;p=c[2443776]|0;do{if((c[p+68+((l&65535)>>>8<<2)>>2]|0)==0){i=c[p+3148>>2]|0;if((i|0)==0){q=j;r=l;break}gj[i&4095](l)|0;q=c[2440596]|0;r=b[4830480]|0}else{q=j;r=l}}while(0);l=q-1|0;c[2440596]=l;q=r+(o<<24>>24)&65535;b[4830486]=q;o=a[9660961]|0;if(((q&65535)>>>8&255)<<24>>24!=o<<24>>24){r=(o&255)<<8;o=r|q&255;q=c[2443776]|0;do{if((c[q+68+((r&65535)>>>8<<2)>>2]|0)==0){j=c[q+3148>>2]|0;if((j|0)==0){s=l;break}gj[j&4095](o)|0;s=c[2440596]|0}else{s=l}}while(0);c[2440596]=s-1}c[2415240]=c[2415243];return}function f$s(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=0;m=i;n=j;break}k=gj[d&4095](e)|0;l=k;m=c[2440596]|0;n=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=j}}while(0);j=m-1|0;c[2440596]=j;m=b[4830480]|0;b[4830480]=m+1&65535;i=m&65535;f=c[n+68+(i>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[n+3168>>2]|0;if((g|0)==0){o=0;p=j;break}e=gj[g&4095](m)|0;o=e;p=c[2440596]|0}else{o=a[f+(i&255)|0]|0;p=j}}while(0);j=p-1|0;c[2440596]=j;if((l&32)==0){return}l=b[4830480]|0;p=c[2443776]|0;do{if((c[p+68+((l&65535)>>>8<<2)>>2]|0)==0){i=c[p+3148>>2]|0;if((i|0)==0){q=j;r=l;break}gj[i&4095](l)|0;q=c[2440596]|0;r=b[4830480]|0}else{q=j;r=l}}while(0);l=q-1|0;c[2440596]=l;q=r+(o<<24>>24)&65535;b[4830486]=q;o=a[9660961]|0;if(((q&65535)>>>8&255)<<24>>24!=o<<24>>24){r=(o&255)<<8;o=r|q&255;q=c[2443776]|0;do{if((c[q+68+((r&65535)>>>8<<2)>>2]|0)==0){j=c[q+3148>>2]|0;if((j|0)==0){s=l;break}gj[j&4095](o)|0;s=c[2440596]|0}else{s=l}}while(0);c[2440596]=s-1}c[2415240]=c[2415243];return}function f$t(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=d&65535;f=c[2443776]|0;g=c[f+68+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3168>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2443776]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9660968]=i;i=(c[2440596]|0)-1|0;c[2440596]=i;f=c[2415242]|0;c[2415243]=f;e=f&65535;g=c[j+68+((f>>>8&255)<<2)>>2]|0;do{if((g|0)==0){d=c[j+3148>>2]|0;if((d|0)==0){l=0;m=i;n=j;break}k=gj[d&4095](e)|0;l=k;m=c[2440596]|0;n=c[2443776]|0}else{l=a[g+(f&255)|0]|0;m=i;n=j}}while(0);j=m-1|0;c[2440596]=j;m=b[4830480]|0;b[4830480]=m+1&65535;i=m&65535;f=c[n+68+(i>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[n+3168>>2]|0;if((g|0)==0){o=0;p=j;break}e=gj[g&4095](m)|0;o=e;p=c[2440596]|0}else{o=a[f+(i&255)|0]|0;p=j}}while(0);j=p-1|0;c[2440596]=j;if(l<<24>>24>=0){return}l=b[4830480]|0;p=c[2443776]|0;do{if((c[p+68+((l&65535)>>>8<<2)>>2]|0)==0){i=c[p+3148>>2]|0;if((i|0)==0){q=j;r=l;break}gj[i&4095](l)|0;q=c[2440596]|0;r=b[4830480]|0}else{q=j;r=l}}while(0);l=q-1|0;c[2440596]=l;q=r+(o<<24>>24)&65535;b[4830486]=q;o=a[9660961]|0;if(((q&65535)>>>8&255)<<24>>24!=o<<24>>24){r=(o&255)<<8;o=r|q&255;q=c[2443776]|0;do{if((c[q+68+((r&65535)>>>8<<2)>>2]|0)==0){j=c[q+3148>>2]|0;if((j|0)==0){s=l;break}gj[j&4095](o)|0;s=c[2440596]|0}else{s=l}}while(0);c[2440596]=s-1}c[2415240]=c[2415243];return}function f$u(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=b[4830480]|0;e=d+1&65535;b[4830480]=e;f=c[2443776]|0;g=(e&65535)>>>8&255;do{if((c[f+68+((d&65535)>>>8<<2)>>2]|0)==0){e=c[f+3168>>2]|0;if((e|0)==0){h=g;i=f;break}gj[e&4095](d)|0;h=a[9660961]|0;i=c[2443776]|0}else{h=g;i=f}}while(0);f=(c[2440596]|0)-1|0;c[2440596]=f;g=c[2415241]|0;d=g&65535;e=c[i+68+((g>>>8&255|256)<<2)>>2]|0;do{if((e|0)==0){j=c[i+3152>>2]|0;if((j|0)==0){k=f;l=i;break}gg[j&4095](d,h);k=c[2440596]|0;l=c[2443776]|0}else{a[e+(g&255)|0]=h;k=f;l=i}}while(0);i=k-1|0;c[2440596]=i;a[9660964]=(a[9660964]|0)-1&255;k=c[2415241]|0;f=k&65535;h=a[9660960]|0;g=c[l+68+((k>>>8&255|256)<<2)>>2]|0;do{if((g|0)==0){e=c[l+3152>>2]|0;if((e|0)==0){m=i;n=l;break}gg[e&4095](f,h);m=c[2440596]|0;n=c[2443776]|0}else{a[g+(k&255)|0]=h;m=i;n=l}}while(0);l=m-1|0;c[2440596]=l;a[9660964]=(a[9660964]|0)-1&255;m=c[2415241]|0;i=m&65535;h=a[9660979]|16;k=c[n+68+((m>>>8&255|256)<<2)>>2]|0;do{if((k|0)==0){g=c[n+3152>>2]|0;if((g|0)==0){o=l;p=n;break}gg[g&4095](i,h);o=c[2440596]|0;p=c[2443776]|0}else{a[k+(m&255)|0]=h;o=l;p=n}}while(0);n=o-1|0;c[2440596]=n;a[9660964]=(a[9660964]|0)-1&255;a[9660979]=a[9660979]|4;o=c[p+1088>>2]|0;do{if((o|0)==0){l=c[p+3148>>2]|0;if((l|0)==0){q=0;r=n;s=p;break}h=gj[l&4095](-13)|0;q=h;r=c[2440596]|0;s=c[2443776]|0}else{q=a[o+243|0]|0;r=n;s=p}}while(0);a[9660960]=q;q=r-1|0;c[2440596]=q;r=c[s+1088>>2]|0;if((r|0)!=0){t=a[r+242|0]|0;u=q;a[9660961]=t;v=u-1|0;c[2440596]=v;return}r=c[s+3148>>2]|0;if((r|0)==0){t=0;u=q;a[9660961]=t;v=u-1|0;c[2440596]=v;return}q=gj[r&4095](-14)|0;t=q;u=c[2440596]|0;a[9660961]=t;v=u-1|0;c[2440596]=v;return}function f$v(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f$w(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f$x(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f$y(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f$z(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f$A(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f$B(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f$C(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f$D(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f$E(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f$F(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f$G(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f$H(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f$I(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f$J(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f$K(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f$L(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f$M(){var a=0,d=0,e=0,f=0,g=0;a=(c[2440596]|0)-1|0;c[2440596]=a;d=b[4830480]|0;b[4830480]=d+1&65535;e=c[2443776]|0;do{if((c[e+68+((d&65535)>>>8<<2)>>2]|0)==0){f=c[e+3168>>2]|0;if((f|0)==0){g=a;break}gj[f&4095](d)|0;g=c[2440596]|0}else{g=a}}while(0);c[2440596]=g-1;return}function f$N(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f$O(){var a=0,d=0,e=0,f=0,g=0;a=(c[2440596]|0)-1|0;c[2440596]=a;d=b[4830480]|0;b[4830480]=d+1&65535;e=c[2443776]|0;do{if((c[e+68+((d&65535)>>>8<<2)>>2]|0)==0){f=c[e+3168>>2]|0;if((f|0)==0){g=a;break}gj[f&4095](d)|0;g=c[2440596]|0}else{g=a}}while(0);c[2440596]=g-1;return}function f$P(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f$Q(){var a=0,d=0,e=0,f=0,g=0;a=(c[2440596]|0)-1|0;c[2440596]=a;d=b[4830480]|0;b[4830480]=d+1&65535;e=c[2443776]|0;do{if((c[e+68+((d&65535)>>>8<<2)>>2]|0)==0){f=c[e+3168>>2]|0;if((f|0)==0){g=a;break}gj[f&4095](d)|0;g=c[2440596]|0}else{g=a}}while(0);c[2440596]=g-1;return}function f$R(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f$S(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f$T(){var a=0,d=0,e=0,f=0,g=0;a=(c[2440596]|0)-1|0;c[2440596]=a;d=b[4830480]|0;b[4830480]=d+1&65535;e=c[2443776]|0;do{if((c[e+68+((d&65535)>>>8<<2)>>2]|0)==0){f=c[e+3168>>2]|0;if((f|0)==0){g=a;break}gj[f&4095](d)|0;g=c[2440596]|0}else{g=a}}while(0);c[2440596]=g-1;return}function f$U(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f$V(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f$W(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f$X(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f$Y(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f$Z(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f$_(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f$$(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f$0(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f$1(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f$2(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f$3(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f$4(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f$5(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f$6(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f$7(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f$8(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f$9(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f0a(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f0b(){var d=0,e=0,f=0,g=0,h=0;d=b[4830480]|0;b[4830480]=d+1&65535;e=c[2443776]|0;do{if((c[e+68+((d&65535)>>>8<<2)>>2]|0)==0){f=c[e+3168>>2]|0;if((f|0)==0){g=e;break}gj[f&4095](d)|0;g=c[2443776]|0}else{g=e}}while(0);c[2440596]=(c[2440596]|0)-1;e=c[g+3140>>2]|0;if((e|0)==0){h=0;a[9660976]=h;return}h=gj[e&4095](0)|0;a[9660976]=h;return}function f0c(){var a=0,d=0,e=0,f=0,g=0;a=(c[2440596]|0)-1|0;c[2440596]=a;d=b[4830480]|0;b[4830480]=d+1&65535;e=c[2443776]|0;do{if((c[e+68+((d&65535)>>>8<<2)>>2]|0)==0){f=c[e+3168>>2]|0;if((f|0)==0){g=a;break}gj[f&4095](d)|0;g=c[2440596]|0}else{g=a}}while(0);c[2440596]=g-1;return}function f0d(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f0e(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f0f(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f0g(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f0h(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f0i(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f0j(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f0k(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f0l(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f0m(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f0n(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f0o(){var a=0,d=0,e=0,f=0,g=0;a=(c[2440596]|0)-1|0;c[2440596]=a;d=b[4830480]|0;b[4830480]=d+1&65535;e=c[2443776]|0;do{if((c[e+68+((d&65535)>>>8<<2)>>2]|0)==0){f=c[e+3168>>2]|0;if((f|0)==0){g=a;break}gj[f&4095](d)|0;g=c[2440596]|0}else{g=a}}while(0);c[2440596]=g-1;return}function f0p(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f0q(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=(c[2440596]|0)-1|0;c[2440596]=d;e=b[4830480]|0;b[4830480]=e+1&65535;f=c[2443776]|0;do{if((c[f+68+((e&65535)>>>8<<2)>>2]|0)==0){g=c[f+3168>>2]|0;if((g|0)==0){h=d;i=f;break}gj[g&4095](e)|0;h=c[2440596]|0;i=c[2443776]|0}else{h=d;i=f}}while(0);c[2440596]=h-1;h=c[i+3140>>2]|0;if((h|0)==0){j=0;a[9660976]=j;return}j=gj[h&4095](1)|0;a[9660976]=j;return}function f0r(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f0s(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f0t(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f0u(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f0v(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f0w(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f0x(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f0y(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f0z(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f0A(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f0B(){var a=0,d=0,e=0,f=0,g=0;a=(c[2440596]|0)-1|0;c[2440596]=a;d=b[4830480]|0;b[4830480]=d+1&65535;e=c[2443776]|0;do{if((c[e+68+((d&65535)>>>8<<2)>>2]|0)==0){f=c[e+3168>>2]|0;if((f|0)==0){g=a;break}gj[f&4095](d)|0;g=c[2440596]|0}else{g=a}}while(0);c[2440596]=g-1;return}function f0C(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f0D(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f0E(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f0F(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f0G(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f0H(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f0I(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f0J(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f0K(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f0L(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=(c[2440596]|0)-1|0;c[2440596]=d;e=b[4830480]|0;b[4830480]=e+1&65535;f=e&65535;g=c[2443776]|0;h=c[g+68+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+3168>>2]|0;if((i|0)==0){j=0;k=d;l=g;break}m=gj[i&4095](e)|0;j=m;k=c[2440596]|0;l=c[2443776]|0}else{j=a[h+(f&255)|0]|0;k=d;l=g}}while(0);c[2440596]=k-1;k=c[l+3144>>2]|0;if((k|0)==0){return}gg[k&4095](0,j);return}function f0M(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f0N(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f0O(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f0P(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f0Q(){var a=0,d=0,e=0,f=0,g=0;a=(c[2440596]|0)-1|0;c[2440596]=a;d=b[4830480]|0;b[4830480]=d+1&65535;e=c[2443776]|0;do{if((c[e+68+((d&65535)>>>8<<2)>>2]|0)==0){f=c[e+3168>>2]|0;if((f|0)==0){g=a;break}gj[f&4095](d)|0;g=c[2440596]|0}else{g=a}}while(0);c[2440596]=g-1;return}function f0R(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f0S(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f0T(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f0U(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f0V(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f0W(){var a=0,d=0,e=0;a=b[4830480]|0;d=c[2443776]|0;do{if((c[d+68+((a&65535)>>>8<<2)>>2]|0)==0){e=c[d+3148>>2]|0;if((e|0)==0){break}gj[e&4095](a)|0}}while(0);c[2440596]=(c[2440596]|0)-1;return}function f0X(){gGz(9660952|0,0|0,52|0);a[9660952]=0;c[2309668]=638960;return}function f0Y(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[2443776]|0;d=c[b+1088>>2]|0;do{if((d|0)==0){e=c[b+3148>>2]|0;if((e|0)==0){f=0;g=b;break}h=gj[e&4095](-4)|0;f=h;g=c[2443776]|0}else{f=a[d+252|0]|0;g=b}}while(0);a[9660960]=f;f=(c[2440596]|0)-1|0;c[2440596]=f;b=c[g+1088>>2]|0;do{if((b|0)==0){d=c[g+3148>>2]|0;if((d|0)==0){i=0;j=f;break}h=gj[d&4095](-3)|0;i=h;j=c[2440596]|0}else{i=a[b+253|0]|0;j=f}}while(0);a[9660961]=i;c[2440596]=j-1;c[2415241]=511;a[9660979]=a[9660979]&8|54;c[2415245]=0;return}function f0Z(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;if((a[9660979]&4)!=0){a[9660980]=0;return}c[2415243]=65534;b=(c[2440596]|0)-2|0;c[2440596]=b;d=c[2415241]|0;e=d&65535;f=a[9660961]|0;g=c[2443776]|0;h=c[g+68+((d>>>8&255|256)<<2)>>2]|0;do{if((h|0)==0){i=c[g+3152>>2]|0;if((i|0)==0){j=b;k=g;break}gg[i&4095](e,f);j=c[2440596]|0;k=c[2443776]|0}else{a[h+(d&255)|0]=f;j=b;k=g}}while(0);g=j-1|0;c[2440596]=g;a[9660964]=(a[9660964]|0)-1&255;j=c[2415241]|0;b=j&65535;f=a[9660960]|0;d=c[k+68+((j>>>8&255|256)<<2)>>2]|0;do{if((d|0)==0){h=c[k+3152>>2]|0;if((h|0)==0){l=g;m=k;break}gg[h&4095](b,f);l=c[2440596]|0;m=c[2443776]|0}else{a[d+(j&255)|0]=f;l=g;m=k}}while(0);k=l-1|0;c[2440596]=k;a[9660964]=(a[9660964]|0)-1&255;l=c[2415241]|0;g=l&65535;f=a[9660979]&-17;j=c[m+68+((l>>>8&255|256)<<2)>>2]|0;do{if((j|0)==0){d=c[m+3152>>2]|0;if((d|0)==0){n=k;o=m;break}gg[d&4095](g,f);n=c[2440596]|0;o=c[2443776]|0}else{a[j+(l&255)|0]=f;n=k;o=m}}while(0);m=n-1|0;c[2440596]=m;a[9660964]=(a[9660964]|0)-1&255;a[9660979]=a[9660979]|4;n=c[2415243]|0;k=n&65535;f=c[o+68+((n>>>8&255)<<2)>>2]|0;do{if((f|0)==0){l=c[o+3148>>2]|0;if((l|0)==0){p=0;q=m;r=n;s=o;break}j=gj[l&4095](k)|0;p=j;q=c[2440596]|0;r=c[2415243]|0;s=c[2443776]|0}else{p=a[f+(n&255)|0]|0;q=m;r=n;s=o}}while(0);a[9660960]=p;p=q-1|0;c[2440596]=p;q=r+1|0;r=q&65535;o=c[s+68+((q>>>8&255)<<2)>>2]|0;do{if((o|0)==0){n=c[s+3148>>2]|0;if((n|0)==0){t=0;u=p;break}m=gj[n&4095](r)|0;t=m;u=c[2440596]|0}else{t=a[o+(q&255)|0]|0;u=p}}while(0);a[9660961]=t;c[2440596]=u-1;u=c[2415247]|0;if((u|0)==0){a[9660980]=0;return}gj[u&4095](0)|0;a[9660980]=0;return}function f0_(d){d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c[2440596]=d;do{e=c[2415240]|0;c[2415239]=e;if((a[9660980]|0)==0){f=e&65535}else{f0Z();f=b[4830480]|0}b[4830480]=f+1&65535;e=f&65535;g=c[2443776]|0;h=c[g+68+((e>>>8|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+3164>>2]|0;if((i|0)==0){j=0;break}j=gj[i&4095](f)|0}else{j=a[h+(e&255)|0]|0}}while(0);c[2440596]=(c[2440596]|0)-1;gu[c[(c[2309668]|0)+((j&255)<<2)>>2]&16383]();L36079:do{if((a[9660981]|0)==0){e=a[9660980]|0;do{if((e<<24>>24|0)==2){if(((c[2432916]|0)-(c[2440596]|0)|0)<=1){break}a[9660980]=1;k=29473}else if((e<<24>>24|0)==1){k=29473}else{break L36079}}while(0);if((k|0)==29473){k=0;f0Z();if((a[9660980]|0)!=2){break}}a[9660980]=1}else{a[9660981]=0;if((a[9660983]|0)==0){break}a[9660980]=1}}while(0);l=c[2440596]|0;}while((l|0)>0);return d-l|0}function f0$(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;if((b|0)==32){if((d[9660982]|0)==(e|0)){return}a[9660982]=e&255;if((e|0)==0){return}c[2415243]=65530;f=(c[2440596]|0)-2|0;c[2440596]=f;g=c[2415241]|0;h=g&65535;i=a[9660961]|0;j=c[2443776]|0;k=c[j+68+((g>>>8&255|256)<<2)>>2]|0;do{if((k|0)==0){l=c[j+3152>>2]|0;if((l|0)==0){m=f;n=j;break}gg[l&4095](h,i);m=c[2440596]|0;n=c[2443776]|0}else{a[k+(g&255)|0]=i;m=f;n=j}}while(0);j=m-1|0;c[2440596]=j;a[9660964]=(a[9660964]|0)-1&255;m=c[2415241]|0;f=m&65535;i=a[9660960]|0;g=c[n+68+((m>>>8&255|256)<<2)>>2]|0;do{if((g|0)==0){k=c[n+3152>>2]|0;if((k|0)==0){o=j;p=n;break}gg[k&4095](f,i);o=c[2440596]|0;p=c[2443776]|0}else{a[g+(m&255)|0]=i;o=j;p=n}}while(0);n=o-1|0;c[2440596]=n;a[9660964]=(a[9660964]|0)-1&255;o=c[2415241]|0;j=o&65535;i=a[9660979]&-17;m=c[p+68+((o>>>8&255|256)<<2)>>2]|0;do{if((m|0)==0){g=c[p+3152>>2]|0;if((g|0)==0){q=n;r=p;break}gg[g&4095](j,i);q=c[2440596]|0;r=c[2443776]|0}else{a[m+(o&255)|0]=i;q=n;r=p}}while(0);p=q-1|0;c[2440596]=p;a[9660964]=(a[9660964]|0)-1&255;a[9660979]=a[9660979]|4;q=c[2415243]|0;n=q&65535;i=c[r+68+((q>>>8&255)<<2)>>2]|0;do{if((i|0)==0){o=c[r+3148>>2]|0;if((o|0)==0){s=0;t=p;u=q;v=r;break}m=gj[o&4095](n)|0;s=m;t=c[2440596]|0;u=c[2415243]|0;v=c[2443776]|0}else{s=a[i+(q&255)|0]|0;t=p;u=q;v=r}}while(0);a[9660960]=s;s=t-1|0;c[2440596]=s;t=u+1|0;u=t&65535;r=c[v+68+((t>>>8&255)<<2)>>2]|0;do{if((r|0)==0){q=c[v+3148>>2]|0;if((q|0)==0){w=0;x=s;break}p=gj[q&4095](u)|0;w=p;x=c[2440596]|0}else{w=a[r+(t&255)|0]|0;x=s}}while(0);a[9660961]=w;c[2440596]=x-1;return}else if((b|0)==1){if((a[9660984]|0)!=0&(e|0)==0){a[9660979]=a[9660979]|64}a[9660984]=e&255;return}else{a[9660983]=e&255;if((e|0)==0){return}a[9660980]=1;c[2432916]=c[2440596];return}}function f00(d){d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;e=a[9660901]|0;f=e&255;if((f&24|0)==0){g=c[2415222]|0;h=g&65535;i=a[9660884]|0;j=c[2437644]|0;k=c[j+72+((g>>>8&255|256)<<2)>>2]|0;do{if((k|0)==0){l=c[j+3148>>2]|0;if((l|0)==0){m=j;break}gg[l&4095](h,i);m=c[2437644]|0}else{a[k+(g&255)|0]=i;m=j}}while(0);b[4830444]=(b[4830444]|0)-1&65535;j=c[2415222]|0;i=j&65535;g=a[9660885]|0;k=c[m+72+((j>>>8&255|256)<<2)>>2]|0;do{if((k|0)==0){h=c[m+3148>>2]|0;if((h|0)==0){n=m;break}gg[h&4095](i,g);n=c[2437644]|0}else{a[k+(j&255)|0]=g;n=m}}while(0);b[4830444]=(b[4830444]|0)-1&65535;m=c[2415222]|0;g=m&65535;j=a[9660892]|0;k=c[n+72+((m>>>8&255|256)<<2)>>2]|0;do{if((k|0)==0){i=c[n+3148>>2]|0;if((i|0)==0){o=n;break}gg[i&4095](g,j);o=c[2437644]|0}else{a[k+(m&255)|0]=j;o=n}}while(0);b[4830444]=(b[4830444]|0)-1&65535;n=c[2415222]|0;j=n&65535;m=a[9660893]|0;k=c[o+72+((n>>>8&255|256)<<2)>>2]|0;do{if((k|0)==0){g=c[o+3148>>2]|0;if((g|0)==0){p=o;break}gg[g&4095](j,m);p=c[2437644]|0}else{a[k+(n&255)|0]=m;p=o}}while(0);b[4830444]=(b[4830444]|0)-1&65535;o=c[2415222]|0;m=o&65535;n=a[9660897]|0;k=c[p+72+((o>>>8&255|256)<<2)>>2]|0;do{if((k|0)==0){j=c[p+3148>>2]|0;if((j|0)==0){q=p;break}gg[j&4095](m,n);q=c[2437644]|0}else{a[k+(o&255)|0]=n;q=p}}while(0);b[4830444]=(b[4830444]|0)-1&65535;p=c[2415222]|0;n=p&65535;o=a[9660896]|0;k=c[q+72+((p>>>8&255|256)<<2)>>2]|0;do{if((k|0)==0){m=c[q+3148>>2]|0;if((m|0)==0){r=q;break}gg[m&4095](n,o);r=c[2437644]|0}else{a[k+(p&255)|0]=o;r=q}}while(0);b[4830444]=(b[4830444]|0)-1&65535;q=c[2415222]|0;o=q&65535;p=a[9660900]|0;k=c[r+72+((q>>>8&255|256)<<2)>>2]|0;do{if((k|0)==0){n=c[r+3148>>2]|0;if((n|0)==0){break}gg[n&4095](o,p)}else{a[k+(q&255)|0]=p}}while(0);b[4830444]=(b[4830444]|0)-1&65535;c[2415227]=(c[2415227]|0)+12}else{if((f&8|0)!=0){c[2415227]=(c[2415227]|0)+4}a[9660901]=e&-25}a[9660900]=a[9660900]|16;e=d&65535;f=c[2437644]|0;p=c[f+72+(e>>>8<<2)>>2]|0;do{if((p|0)==0){q=c[f+3144>>2]|0;if((q|0)==0){s=0;t=f;break}k=gj[q&4095](d)|0;s=k;t=c[2437644]|0}else{s=a[p+(e&255)|0]|0;t=f}}while(0);f=(s&255)<<8;s=d+1&65535;d=s&65535;e=c[t+72+(d>>>8<<2)>>2]|0;if((e|0)!=0){u=a[e+(d&255)|0]|0;v=u&255;w=v|f;c[2415221]=w;x=w&65535;b[4830442]=x;return}d=c[t+3144>>2]|0;if((d|0)==0){u=0;v=u&255;w=v|f;c[2415221]=w;x=w&65535;b[4830442]=x;return}u=gj[d&4095](s)|0;v=u&255;w=v|f;c[2415221]=w;x=w&65535;b[4830442]=x;return}function f01(){if((a[9660903]|0)==1){return}a[9660903]=1;if((a[9660900]&16)!=0){return}f00(-8);return}function f02(f){f=f|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0,cf=0,cg=0,ch=0,ci=0,cj=0,ck=0,cl=0,cm=0,cn=0,co=0,cp=0,cq=0,cr=0,cs=0,ct=0,cu=0,cv=0,cw=0,cx=0,cy=0,cz=0,cA=0,cB=0,cC=0,cD=0,cE=0,cF=0,cG=0,cH=0,cI=0,cJ=0,cK=0,cL=0,cM=0,cN=0,cO=0,cP=0,cQ=0,cR=0,cS=0,cT=0,cU=0,cV=0,cW=0,cX=0,cY=0,cZ=0,c_=0,c$=0,c0=0,c1=0,c2=0,c3=0,c4=0,c5=0,c6=0,c7=0,c8=0,c9=0,da=0,db=0,dc=0,dd=0,de=0,df=0,dg=0,dh=0,di=0,dj=0,dk=0,dl=0,dm=0,dn=0,dp=0,dq=0,dr=0,ds=0,dt=0,du=0,dv=0,dw=0,dx=0,dy=0,dz=0,dA=0,dB=0,dC=0,dD=0,dE=0,dF=0,dG=0,dH=0;h=i;i=i+21496|0;j=b[4830469]|0;b[4830471]=(b[4830471]|0)-j&65535;b[4830474]=(b[4830474]|0)-j&65535;b[4830469]=0;j=c[2415235]|0;k=c[2415234]|0;l=c[2415237]|0;m=(j-k|0)>>>0<(l-k|0)>>>0?j:l;c[3528192]=m;l=c[2415227]|0;c[2440594]=f-l;c[2415234]=l+k|0;if((l+k|0)>>>0>=m>>>0){f03()}c[2415227]=0;do{do{m=1;if(m){m=0;if((a[9660901]&8)==0){k=c[2415221]|0;c[2415220]=k;l=c[2437644]|0;j=c[l+72+((k>>>8&255|512)<<2)>>2]|0;do{if((j|0)==0){n=c[l+3152>>2]|0;if((n|0)==0){o=0;p=k&65535;break}q=gj[n&4095](k&65535)|0;o=q;p=b[4830442]|0}else{o=a[j+(k&255)|0]|0;p=k&65535}}while(0);k=p+1&65535;b[4830442]=k;j=o&255;L36216:do{l=1;q=j|0;if(l){l=0;switch(q|0){case 7:{a[9660897]=a[9660900]|0;break};case 10:{a[9660900]=a[9660900]&-3;break};case 11:{a[9660900]=a[9660900]|2;break};case 12:{a[9660900]=a[9660900]&-2;break};case 15:{f1b();break};case 16:{n=a[9660897]|0;r=a[9660896]|0;s=(n&255)-(r&255)&65535&65535;t=(s>>>4&8|a[9660900]&-16&255)&255;a[9660900]=((s^(r^n)&255^s>>>1)>>>6&2|s>>>8&1|(((n&255)-(r&255)&65535&255)<<24>>24==0?t|4:t)&255)&255;a[9660897]=(n&255)-(r&255)&65535&255;break};case 17:{r=a[9660897]|0;n=a[9660896]|0;t=(r&255)-(n&255)&65535&65535;s=(t>>>4&8|a[9660900]&-16&255)&255;a[9660900]=((t^(n^r)&255^t>>>1)>>>6&2|t>>>8&1|(((r&255)-(n&255)&65535&255)<<24>>24==0?s|4:s)&255)&255;break};case 22:{s=a[9660897]|0;a[9660896]=s;n=(s&255)>>>4&8|a[9660900]&-15;a[9660900]=s<<24>>24==0?n|4:n;break};case 23:{n=a[9660896]|0;a[9660897]=n;s=(n&255)>>>4&8|a[9660900]&-15;a[9660900]=n<<24>>24==0?s|4:s;break};case 25:{s=a[9660897]|0;if((s&14)>9){u=29593}else{if((a[9660900]&32)==0){v=0}else{u=29593}}if((u|0)==29593){u=0;v=6}do{if((s&-16&255)>128){n=(s&14)>9?v|96:v;if((s&-16&255)<=144){w=n;u=29597;break}x=n;y=a[9660900]|0;u=29598}else{w=v;u=29597}}while(0);if((u|0)==29597){u=0;n=a[9660900]|0;if((n&1)==0){z=w;A=n}else{x=w;y=n;u=29598}}if((u|0)==29598){u=0;z=x|96;A=y}n=z+(s&255)&65535;r=((n&65535)>>>4&8|A&-15&255)&255;a[9660900]=(((n&255)<<24>>24==0?r|4:r)&255|(n&65535)>>>8&1)&255;a[9660897]=n&255;break};case 27:{n=a[9660897]|0;r=a[9660896]|0;t=(r&255)+(n&255)&65535&65535;C=(t>>>4&8|a[9660900]&-48&255)&255;a[9660900]=((t^(r^n)&255)<<1&32|t>>>8&1|(t^(r^n)&255^t>>>1)>>>6&2|(((r&255)+(n&255)&65535&255)<<24>>24==0?C|4:C)&255)&255;a[9660897]=(r&255)+(n&255)&65535&255;break};case 32:{n=c[2415221]|0;r=c[2437644]|0;C=c[r+72+((n>>>8&255|512)<<2)>>2]|0;do{if((C|0)==0){t=c[r+3156>>2]|0;if((t|0)==0){D=0;E=n&65535;break}F=gj[t&4095](n&65535)|0;D=F;E=b[4830442]|0}else{D=a[C+(n&255)|0]|0;E=n&65535}}while(0);n=D&255;b[4830442]=((n&128|0)!=0?n|65280:n)+(E+1&65535)&65535;b[4830442]=c[2415221]&65535;if(D<<24>>24!=-2){break L36216}n=c[3528192]|0;C=c[2415234]|0;r=c[2440594]|0;s=(n-C|0|0)>(r|0)?r:n-C|0;if((s|0)<=0){break L36216}c[2440594]=r-s;c[2415234]=s+C|0;if((s+C|0)>>>0<n>>>0){break L36216}f03();break};case 33:{n=c[2415221]|0;C=c[2437644]|0;do{if((c[C+72+((n>>>8&255|512)<<2)>>2]|0)==0){s=c[C+3156>>2]|0;if((s|0)==0){G=n&65535;break}gj[s&4095](n&65535)|0;G=b[4830442]|0}else{G=n&65535}}while(0);b[4830442]=G+1&65535;break};case 34:{n=c[2415221]|0;C=c[2437644]|0;s=c[C+72+((n>>>8&255|512)<<2)>>2]|0;do{if((s|0)==0){r=c[C+3156>>2]|0;if((r|0)==0){H=0;K=n&65535;break}F=gj[r&4095](n&65535)|0;H=F;K=b[4830442]|0}else{H=a[s+(n&255)|0]|0;K=n&65535}}while(0);n=K+1&65535;b[4830442]=n;if((a[9660900]&5)!=0){break L36216}s=H&255;b[4830442]=((s&128|0)!=0?s|65280:s)+(n&65535)&65535;b[4830442]=c[2415221]&65535;break};case 13:{a[9660900]=a[9660900]|1;break};case 37:{n=c[2415221]|0;s=c[2437644]|0;C=c[s+72+((n>>>8&255|512)<<2)>>2]|0;do{if((C|0)==0){F=c[s+3156>>2]|0;if((F|0)==0){L=0;M=n&65535;break}r=gj[F&4095](n&65535)|0;L=r;M=b[4830442]|0}else{L=a[C+(n&255)|0]|0;M=n&65535}}while(0);n=M+1&65535;b[4830442]=n;if((a[9660900]&1)==0){break L36216}C=L&255;b[4830442]=((C&128|0)!=0?C|65280:C)+(n&65535)&65535;b[4830442]=c[2415221]&65535;break};case 99:{n=b[4830446]|0;C=c[2415221]|0;s=c[2437644]|0;r=c[s+72+((C>>>8&255|512)<<2)>>2]|0;do{if((r|0)==0){F=c[s+3156>>2]|0;if((F|0)==0){N=0;O=C&65535;P=s;break}t=gj[F&4095](C&65535)|0;N=t;O=b[4830442]|0;P=c[2437644]|0}else{N=a[r+(C&255)|0]|0;O=C&65535;P=s}}while(0);b[4853736]=(N&255)+n&65535;b[4830442]=O+1&65535;s=c[2426868]|0;C=c[P+72+((s>>>8&255)<<2)>>2]|0;do{if((C|0)==0){r=c[P+3144>>2]|0;if((r|0)==0){Q=0;R=s;S=P;break}t=gj[r&4095](s&65535)|0;Q=t;R=c[2426868]|0;S=c[2437644]|0}else{Q=a[C+(s&255)|0]|0;R=s;S=P}}while(0);s=~Q;C=a[9660900]&-15|(s&255)>>>4&8;a[9660900]=(Q<<24>>24==-1?C|4:C)|1;C=c[S+72+((R>>>8&255|256)<<2)>>2]|0;if((C|0)!=0){a[C+(R&255)|0]=s;break L36216}C=c[S+3148>>2]|0;if((C|0)==0){break L36216}gg[C&4095](R&65535,s);break};case 100:{s=b[4830446]|0;C=c[2415221]|0;n=c[2437644]|0;t=c[n+72+((C>>>8&255|512)<<2)>>2]|0;do{if((t|0)==0){r=c[n+3156>>2]|0;if((r|0)==0){T=0;U=C&65535;V=n;break}F=gj[r&4095](C&65535)|0;T=F;U=b[4830442]|0;V=c[2437644]|0}else{T=a[t+(C&255)|0]|0;U=C&65535;V=n}}while(0);b[4853736]=(T&255)+s&65535;b[4830442]=U+1&65535;n=c[2426868]|0;C=c[V+72+((n>>>8&255)<<2)>>2]|0;do{if((C|0)==0){t=c[V+3144>>2]|0;if((t|0)==0){W=0;X=n;Y=V;break}F=gj[t&4095](n&65535)|0;W=F;X=c[2426868]|0;Y=c[2437644]|0}else{W=a[C+(n&255)|0]|0;X=n;Y=V}}while(0);n=a[9660900]&-14|W&1;C=(W&255)>>>1;a[9660900]=C<<24>>24==0?n|4:n;n=c[Y+72+((X>>>8&255|256)<<2)>>2]|0;if((n|0)!=0){a[n+(X&255)|0]=C;break L36216}n=c[Y+3148>>2]|0;if((n|0)==0){break L36216}gg[n&4095](X&65535,C);break};case 102:{C=b[4830446]|0;n=c[2415221]|0;s=c[2437644]|0;F=c[s+72+((n>>>8&255|512)<<2)>>2]|0;do{if((F|0)==0){t=c[s+3156>>2]|0;if((t|0)==0){Z=0;_=n&65535;$=s;break}r=gj[t&4095](n&65535)|0;Z=r;_=b[4830442]|0;$=c[2437644]|0}else{Z=a[F+(n&255)|0]|0;_=n&65535;$=s}}while(0);b[4853736]=(Z&255)+C&65535;b[4830442]=_+1&65535;s=c[2426868]|0;n=c[$+72+((s>>>8&255)<<2)>>2]|0;do{if((n|0)==0){F=c[$+3144>>2]|0;if((F|0)==0){aa=0;ab=s;ac=$;break}r=gj[F&4095](s&65535)|0;aa=r;ab=c[2426868]|0;ac=c[2437644]|0}else{aa=a[n+(s&255)|0]|0;ab=s;ac=$}}while(0);s=a[9660900]|0;n=s<<7|(aa&255)>>>1;C=s&-14|aa&1|s<<3&8;a[9660900]=n<<24>>24==0?C|4:C;C=c[ac+72+((ab>>>8&255|256)<<2)>>2]|0;if((C|0)!=0){a[C+(ab&255)|0]=n;break L36216}C=c[ac+3148>>2]|0;if((C|0)==0){break L36216}gg[C&4095](ab&65535,n);break};case 103:{n=b[4830446]|0;C=c[2415221]|0;s=c[2437644]|0;r=c[s+72+((C>>>8&255|512)<<2)>>2]|0;do{if((r|0)==0){F=c[s+3156>>2]|0;if((F|0)==0){ad=0;ae=C&65535;af=s;break}t=gj[F&4095](C&65535)|0;ad=t;ae=b[4830442]|0;af=c[2437644]|0}else{ad=a[r+(C&255)|0]|0;ae=C&65535;af=s}}while(0);b[4853736]=(ad&255)+n&65535;b[4830442]=ae+1&65535;s=c[2426868]|0;C=c[af+72+((s>>>8&255)<<2)>>2]|0;do{if((C|0)==0){r=c[af+3144>>2]|0;if((r|0)==0){ag=0;ah=s;ai=af;break}t=gj[r&4095](s&65535)|0;ag=t;ah=c[2426868]|0;ai=c[2437644]|0}else{ag=a[C+(s&255)|0]|0;ah=s;ai=af}}while(0);s=(ag&255)>>>1;C=a[9660900]&-14|ag&1|(ag&255)>>>4&8;a[9660900]=(s<<1&-128|s)<<24>>24==0?C|4:C;C=c[ai+72+((ah>>>8&255|256)<<2)>>2]|0;if((C|0)!=0){a[C+(ah&255)|0]=s<<1&-128|s;break L36216}C=c[ai+3148>>2]|0;if((C|0)==0){break L36216}gg[C&4095](ah&65535,s<<1&-128|s);break};case 104:{s=b[4830446]|0;C=c[2415221]|0;n=c[2437644]|0;t=c[n+72+((C>>>8&255|512)<<2)>>2]|0;do{if((t|0)==0){r=c[n+3156>>2]|0;if((r|0)==0){aj=0;ak=C&65535;al=n;break}F=gj[r&4095](C&65535)|0;aj=F;ak=b[4830442]|0;al=c[2437644]|0}else{aj=a[t+(C&255)|0]|0;ak=C&65535;al=n}}while(0);b[4853736]=(aj&255)+s&65535;b[4830442]=ak+1&65535;n=c[2426868]|0;C=c[al+72+((n>>>8&255)<<2)>>2]|0;do{if((C|0)==0){t=c[al+3144>>2]|0;if((t|0)==0){am=0;an=n;ao=al;break}F=gj[t&4095](n&65535)|0;am=F;an=c[2426868]|0;ao=c[2437644]|0}else{am=a[C+(n&255)|0]|0;an=n;ao=al}}while(0);n=(am&255)<<1;C=((n&65535)>>>4&8|a[9660900]&-16&255)&255;a[9660900]=(((n&65535)>>>1^n&65535)>>>6&2|(n&65535)>>>8|((n&255)<<24>>24==0?C|4:C)&255)&255;C=c[ao+72+((an>>>8&255|256)<<2)>>2]|0;if((C|0)!=0){a[C+(an&255)|0]=n&255;break L36216}C=c[ao+3148>>2]|0;if((C|0)==0){break L36216}gg[C&4095](an&65535,n&255);break};case 105:{n=b[4830446]|0;C=c[2415221]|0;s=c[2437644]|0;F=c[s+72+((C>>>8&255|512)<<2)>>2]|0;do{if((F|0)==0){t=c[s+3156>>2]|0;if((t|0)==0){ap=0;aq=C&65535;ar=s;break}r=gj[t&4095](C&65535)|0;ap=r;aq=b[4830442]|0;ar=c[2437644]|0}else{ap=a[F+(C&255)|0]|0;aq=C&65535;ar=s}}while(0);b[4853736]=(ap&255)+n&65535;b[4830442]=aq+1&65535;s=c[2426868]|0;C=c[ar+72+((s>>>8&255)<<2)>>2]|0;do{if((C|0)==0){F=c[ar+3144>>2]|0;if((F|0)==0){as=0;at=s;au=ar;break}r=gj[F&4095](s&65535)|0;as=r;at=c[2426868]|0;au=c[2437644]|0}else{as=a[C+(s&255)|0]|0;at=s;au=ar}}while(0);s=a[9660900]|0;C=s&1|(as&255)<<1;a[9660900]=(((C&65535)>>>1^C&65535)>>>6&2|(C&65535)>>>8|((C&255)<<24>>24==0?((C&65535)>>>4&8|s&-16&255)&255|4:((C&65535)>>>4&8|s&-16&255)&255)&255)&255;s=c[au+72+((at>>>8&255|256)<<2)>>2]|0;if((s|0)!=0){a[s+(at&255)|0]=C&255;break L36216}s=c[au+3148>>2]|0;if((s|0)==0){break L36216}gg[s&4095](at&65535,C&255);break};case 106:{C=b[4830446]|0;s=c[2415221]|0;n=c[2437644]|0;r=c[n+72+((s>>>8&255|512)<<2)>>2]|0;do{if((r|0)==0){F=c[n+3156>>2]|0;if((F|0)==0){av=0;aw=s&65535;ax=n;break}t=gj[F&4095](s&65535)|0;av=t;aw=b[4830442]|0;ax=c[2437644]|0}else{av=a[r+(s&255)|0]|0;aw=s&65535;ax=n}}while(0);b[4853736]=(av&255)+C&65535;b[4830442]=aw+1&65535;n=c[2426868]|0;s=c[ax+72+((n>>>8&255)<<2)>>2]|0;do{if((s|0)==0){r=c[ax+3144>>2]|0;if((r|0)==0){ay=0;az=n;aA=ax;break}t=gj[r&4095](n&65535)|0;ay=t;az=c[2426868]|0;aA=c[2437644]|0}else{ay=a[s+(n&255)|0]|0;az=n;aA=ax}}while(0);n=ay-1&255;a[9660900]=a[9660900]&-15|a[669184+(n&255)|0];s=c[aA+72+((az>>>8&255|256)<<2)>>2]|0;if((s|0)!=0){a[s+(az&255)|0]=n;break L36216}s=c[aA+3148>>2]|0;if((s|0)==0){break L36216}gg[s&4095](az&65535,n);break};case 108:{n=b[4830446]|0;s=c[2415221]|0;C=c[2437644]|0;t=c[C+72+((s>>>8&255|512)<<2)>>2]|0;do{if((t|0)==0){r=c[C+3156>>2]|0;if((r|0)==0){aB=0;aC=s&65535;aD=C;break}F=gj[r&4095](s&65535)|0;aB=F;aC=b[4830442]|0;aD=c[2437644]|0}else{aB=a[t+(s&255)|0]|0;aC=s&65535;aD=C}}while(0);b[4853736]=(aB&255)+n&65535;b[4830442]=aC+1&65535;C=c[2426868]|0;s=c[aD+72+((C>>>8&255)<<2)>>2]|0;do{if((s|0)==0){t=c[aD+3144>>2]|0;if((t|0)==0){aE=0;aF=C;aG=aD;break}F=gj[t&4095](C&65535)|0;aE=F;aF=c[2426868]|0;aG=c[2437644]|0}else{aE=a[s+(C&255)|0]|0;aF=C;aG=aD}}while(0);C=aE+1&255;a[9660900]=a[9660900]&-15|a[668928+(C&255)|0];s=c[aG+72+((aF>>>8&255|256)<<2)>>2]|0;if((s|0)!=0){a[s+(aF&255)|0]=C;break L36216}s=c[aG+3148>>2]|0;if((s|0)==0){break L36216}gg[s&4095](aF&65535,C);break};case 109:{C=b[4830446]|0;s=c[2415221]|0;n=c[2437644]|0;F=c[n+72+((s>>>8&255|512)<<2)>>2]|0;do{if((F|0)==0){t=c[n+3156>>2]|0;if((t|0)==0){aH=0;aI=s&65535;aJ=n;break}r=gj[t&4095](s&65535)|0;aH=r;aI=b[4830442]|0;aJ=c[2437644]|0}else{aH=a[F+(s&255)|0]|0;aI=s&65535;aJ=n}}while(0);b[4853736]=(aH&255)+C&65535;b[4830442]=aI+1&65535;n=c[2426868]|0;s=c[aJ+72+((n>>>8&255)<<2)>>2]|0;do{if((s|0)==0){F=c[aJ+3144>>2]|0;if((F|0)==0){aK=0;break}aK=gj[F&4095](n&65535)|0}else{aK=a[s+(n&255)|0]|0}}while(0);n=a[9660900]&-16|(aK&255)>>>4&8;a[9660900]=aK<<24>>24==0?n|4:n;break};case 110:{n=b[4830446]|0;s=c[2415221]|0;C=c[2437644]|0;F=c[C+72+((s>>>8&255|512)<<2)>>2]|0;do{if((F|0)==0){r=c[C+3156>>2]|0;if((r|0)==0){aL=0;break}aL=gj[r&4095](s&65535)|0}else{aL=a[F+(s&255)|0]|0}}while(0);s=(aL&255)+n&65535;b[4853736]=s;b[4830442]=s;b[4830442]=c[2415221]&65535;break};case 111:{s=b[4830446]|0;F=c[2415221]|0;C=c[2437644]|0;r=c[C+72+((F>>>8&255|512)<<2)>>2]|0;do{if((r|0)==0){t=c[C+3156>>2]|0;if((t|0)==0){aM=0;aN=F&65535;aO=C;break}aP=gj[t&4095](F&65535)|0;aM=aP;aN=b[4830442]|0;aO=c[2437644]|0}else{aM=a[r+(F&255)|0]|0;aN=F&65535;aO=C}}while(0);b[4853736]=(aM&255)+s&65535;b[4830442]=aN+1&65535;C=c[2426868]|0;F=c[aO+72+((C>>>8&255|256)<<2)>>2]|0;do{if((F|0)==0){r=c[aO+3148>>2]|0;if((r|0)==0){break}gg[r&4095](C&65535,0)}else{a[F+(C&255)|0]=0}}while(0);a[9660900]=a[9660900]&-16|4;break};case 112:{C=c[2415221]|0;F=c[2437644]|0;s=c[F+72+((C>>>8&255|512)<<2)>>2]|0;do{if((s|0)==0){r=c[F+3156>>2]|0;if((r|0)==0){aQ=0;aR=C;aS=F;aT=C&65535;break}n=gj[r&4095](C&65535)|0;r=c[2415221]|0;aQ=n;aR=r;aS=c[2437644]|0;aT=r&65535}else{aQ=a[s+(C&255)|0]|0;aR=C;aS=F;aT=C&65535}}while(0);C=aQ&255;F=aR+1|0;s=c[aS+72+((F>>>8&255|512)<<2)>>2]|0;do{if((s|0)==0){r=c[aS+3156>>2]|0;if((r|0)==0){aU=0;aV=aT;aW=aS;break}n=gj[r&4095](F&65535)|0;aU=n;aV=b[4830442]|0;aW=c[2437644]|0}else{aU=a[s+(F&255)|0]|0;aV=aT;aW=aS}}while(0);F=aU&255;c[2426868]=F|C<<8;b[4830442]=aV+2&65535;s=c[aW+72+(C<<2)>>2]|0;do{if((s|0)==0){n=c[aW+3144>>2]|0;if((n|0)==0){aX=0;aY=F|C<<8;aZ=aW;break}r=gj[n&4095]((F|C<<8)&65535)|0;aX=r;aY=c[2426868]|0;aZ=c[2437644]|0}else{aX=a[s+F|0]|0;aY=F|C<<8;aZ=aW}}while(0);C=aX&255;F=(a[9660900]&-16&255|(-C|0)>>>4&8)&255;a[9660900]=((C^(-C|0)^(-C|0)>>>1)>>>6&2|(-C|0)>>>8&1|(((-C|0)&255)<<24>>24==0?F|4:F)&255)&255;F=c[aZ+72+((aY>>>8&255|256)<<2)>>2]|0;if((F|0)!=0){a[F+(aY&255)|0]=(-C|0)&255;break L36216}F=c[aZ+3148>>2]|0;if((F|0)==0){break L36216}gg[F&4095](aY&65535,(-C|0)&255);break};case 115:{C=c[2415221]|0;F=c[2437644]|0;s=c[F+72+((C>>>8&255|512)<<2)>>2]|0;do{if((s|0)==0){r=c[F+3156>>2]|0;if((r|0)==0){a_=0;a$=C;a0=F;a1=C&65535;break}n=gj[r&4095](C&65535)|0;r=c[2415221]|0;a_=n;a$=r;a0=c[2437644]|0;a1=r&65535}else{a_=a[s+(C&255)|0]|0;a$=C;a0=F;a1=C&65535}}while(0);C=a_&255;F=a$+1|0;s=c[a0+72+((F>>>8&255|512)<<2)>>2]|0;do{if((s|0)==0){r=c[a0+3156>>2]|0;if((r|0)==0){a2=0;a3=a1;a4=a0;break}n=gj[r&4095](F&65535)|0;a2=n;a3=b[4830442]|0;a4=c[2437644]|0}else{a2=a[s+(F&255)|0]|0;a3=a1;a4=a0}}while(0);F=a2&255;c[2426868]=F|C<<8;b[4830442]=a3+2&65535;s=c[a4+72+(C<<2)>>2]|0;do{if((s|0)==0){n=c[a4+3144>>2]|0;if((n|0)==0){a5=0;a6=F|C<<8;a7=a4;break}r=gj[n&4095]((F|C<<8)&65535)|0;a5=r;a6=c[2426868]|0;a7=c[2437644]|0}else{a5=a[s+F|0]|0;a6=F|C<<8;a7=a4}}while(0);C=~a5;F=a[9660900]&-15|(C&255)>>>4&8;a[9660900]=(a5<<24>>24==-1?F|4:F)|1;F=c[a7+72+((a6>>>8&255|256)<<2)>>2]|0;if((F|0)!=0){a[F+(a6&255)|0]=C;break L36216}F=c[a7+3148>>2]|0;if((F|0)==0){break L36216}gg[F&4095](a6&65535,C);break};case 116:{C=c[2415221]|0;F=c[2437644]|0;s=c[F+72+((C>>>8&255|512)<<2)>>2]|0;do{if((s|0)==0){r=c[F+3156>>2]|0;if((r|0)==0){a8=0;a9=C;ba=F;bb=C&65535;break}n=gj[r&4095](C&65535)|0;r=c[2415221]|0;a8=n;a9=r;ba=c[2437644]|0;bb=r&65535}else{a8=a[s+(C&255)|0]|0;a9=C;ba=F;bb=C&65535}}while(0);C=a8&255;F=a9+1|0;s=c[ba+72+((F>>>8&255|512)<<2)>>2]|0;do{if((s|0)==0){r=c[ba+3156>>2]|0;if((r|0)==0){bc=0;bd=bb;be=ba;break}n=gj[r&4095](F&65535)|0;bc=n;bd=b[4830442]|0;be=c[2437644]|0}else{bc=a[s+(F&255)|0]|0;bd=bb;be=ba}}while(0);F=bc&255;c[2426868]=F|C<<8;b[4830442]=bd+2&65535;s=c[be+72+(C<<2)>>2]|0;do{if((s|0)==0){n=c[be+3144>>2]|0;if((n|0)==0){bf=0;bg=F|C<<8;bh=be;break}r=gj[n&4095]((F|C<<8)&65535)|0;bf=r;bg=c[2426868]|0;bh=c[2437644]|0}else{bf=a[s+F|0]|0;bg=F|C<<8;bh=be}}while(0);C=a[9660900]&-14|bf&1;F=(bf&255)>>>1;a[9660900]=F<<24>>24==0?C|4:C;C=c[bh+72+((bg>>>8&255|256)<<2)>>2]|0;if((C|0)!=0){a[C+(bg&255)|0]=F;break L36216}C=c[bh+3148>>2]|0;if((C|0)==0){break L36216}gg[C&4095](bg&65535,F);break};case 118:{F=c[2415221]|0;C=c[2437644]|0;s=c[C+72+((F>>>8&255|512)<<2)>>2]|0;do{if((s|0)==0){r=c[C+3156>>2]|0;if((r|0)==0){bi=0;bj=F;bk=C;bl=F&65535;break}n=gj[r&4095](F&65535)|0;r=c[2415221]|0;bi=n;bj=r;bk=c[2437644]|0;bl=r&65535}else{bi=a[s+(F&255)|0]|0;bj=F;bk=C;bl=F&65535}}while(0);F=bi&255;C=bj+1|0;s=c[bk+72+((C>>>8&255|512)<<2)>>2]|0;do{if((s|0)==0){r=c[bk+3156>>2]|0;if((r|0)==0){bm=0;bn=bl;bo=bk;break}n=gj[r&4095](C&65535)|0;bm=n;bn=b[4830442]|0;bo=c[2437644]|0}else{bm=a[s+(C&255)|0]|0;bn=bl;bo=bk}}while(0);C=bm&255;c[2426868]=C|F<<8;b[4830442]=bn+2&65535;s=c[bo+72+(F<<2)>>2]|0;do{if((s|0)==0){n=c[bo+3144>>2]|0;if((n|0)==0){bp=0;bq=C|F<<8;br=bo;break}r=gj[n&4095]((C|F<<8)&65535)|0;bp=r;bq=c[2426868]|0;br=c[2437644]|0}else{bp=a[s+C|0]|0;bq=C|F<<8;br=bo}}while(0);F=a[9660900]|0;C=F<<7|(bp&255)>>>1;s=F&-14|bp&1|F<<3&8;a[9660900]=C<<24>>24==0?s|4:s;s=c[br+72+((bq>>>8&255|256)<<2)>>2]|0;if((s|0)!=0){a[s+(bq&255)|0]=C;break L36216}s=c[br+3148>>2]|0;if((s|0)==0){break L36216}gg[s&4095](bq&65535,C);break};case 119:{C=c[2415221]|0;s=c[2437644]|0;F=c[s+72+((C>>>8&255|512)<<2)>>2]|0;do{if((F|0)==0){r=c[s+3156>>2]|0;if((r|0)==0){bs=0;bt=C;bu=s;bv=C&65535;break}n=gj[r&4095](C&65535)|0;r=c[2415221]|0;bs=n;bt=r;bu=c[2437644]|0;bv=r&65535}else{bs=a[F+(C&255)|0]|0;bt=C;bu=s;bv=C&65535}}while(0);C=bs&255;s=bt+1|0;F=c[bu+72+((s>>>8&255|512)<<2)>>2]|0;do{if((F|0)==0){r=c[bu+3156>>2]|0;if((r|0)==0){bw=0;bx=bv;by=bu;break}n=gj[r&4095](s&65535)|0;bw=n;bx=b[4830442]|0;by=c[2437644]|0}else{bw=a[F+(s&255)|0]|0;bx=bv;by=bu}}while(0);s=bw&255;c[2426868]=s|C<<8;b[4830442]=bx+2&65535;F=c[by+72+(C<<2)>>2]|0;do{if((F|0)==0){n=c[by+3144>>2]|0;if((n|0)==0){bz=0;bA=s|C<<8;bB=by;break}r=gj[n&4095]((s|C<<8)&65535)|0;bz=r;bA=c[2426868]|0;bB=c[2437644]|0}else{bz=a[F+s|0]|0;bA=s|C<<8;bB=by}}while(0);C=(bz&255)>>>1;s=a[9660900]&-14|bz&1|(bz&255)>>>4&8;a[9660900]=(C<<1&-128|C)<<24>>24==0?s|4:s;s=c[bB+72+((bA>>>8&255|256)<<2)>>2]|0;if((s|0)!=0){a[s+(bA&255)|0]=C<<1&-128|C;break L36216}s=c[bB+3148>>2]|0;if((s|0)==0){break L36216}gg[s&4095](bA&65535,C<<1&-128|C);break};case 120:{C=c[2415221]|0;s=c[2437644]|0;F=c[s+72+((C>>>8&255|512)<<2)>>2]|0;do{if((F|0)==0){r=c[s+3156>>2]|0;if((r|0)==0){bC=0;bD=C;bE=s;bF=C&65535;break}n=gj[r&4095](C&65535)|0;r=c[2415221]|0;bC=n;bD=r;bE=c[2437644]|0;bF=r&65535}else{bC=a[F+(C&255)|0]|0;bD=C;bE=s;bF=C&65535}}while(0);C=bC&255;s=bD+1|0;F=c[bE+72+((s>>>8&255|512)<<2)>>2]|0;do{if((F|0)==0){r=c[bE+3156>>2]|0;if((r|0)==0){bG=0;bH=bF;bI=bE;break}n=gj[r&4095](s&65535)|0;bG=n;bH=b[4830442]|0;bI=c[2437644]|0}else{bG=a[F+(s&255)|0]|0;bH=bF;bI=bE}}while(0);s=bG&255;c[2426868]=s|C<<8;b[4830442]=bH+2&65535;F=c[bI+72+(C<<2)>>2]|0;do{if((F|0)==0){n=c[bI+3144>>2]|0;if((n|0)==0){bJ=0;bK=s|C<<8;bL=bI;break}r=gj[n&4095]((s|C<<8)&65535)|0;bJ=r;bK=c[2426868]|0;bL=c[2437644]|0}else{bJ=a[F+s|0]|0;bK=s|C<<8;bL=bI}}while(0);C=(bJ&255)<<1;s=((C&65535)>>>4&8|a[9660900]&-16&255)&255;a[9660900]=(((C&65535)>>>1^C&65535)>>>6&2|(C&65535)>>>8|((C&255)<<24>>24==0?s|4:s)&255)&255;s=c[bL+72+((bK>>>8&255|256)<<2)>>2]|0;if((s|0)!=0){a[s+(bK&255)|0]=C&255;break L36216}s=c[bL+3148>>2]|0;if((s|0)==0){break L36216}gg[s&4095](bK&65535,C&255);break};case 121:{C=c[2415221]|0;s=c[2437644]|0;F=c[s+72+((C>>>8&255|512)<<2)>>2]|0;do{if((F|0)==0){r=c[s+3156>>2]|0;if((r|0)==0){bM=0;bN=C;bO=s;bP=C&65535;break}n=gj[r&4095](C&65535)|0;r=c[2415221]|0;bM=n;bN=r;bO=c[2437644]|0;bP=r&65535}else{bM=a[F+(C&255)|0]|0;bN=C;bO=s;bP=C&65535}}while(0);C=bM&255;s=bN+1|0;F=c[bO+72+((s>>>8&255|512)<<2)>>2]|0;do{if((F|0)==0){r=c[bO+3156>>2]|0;if((r|0)==0){bQ=0;bR=bP;bS=bO;break}n=gj[r&4095](s&65535)|0;bQ=n;bR=b[4830442]|0;bS=c[2437644]|0}else{bQ=a[F+(s&255)|0]|0;bR=bP;bS=bO}}while(0);s=bQ&255;c[2426868]=s|C<<8;b[4830442]=bR+2&65535;F=c[bS+72+(C<<2)>>2]|0;do{if((F|0)==0){n=c[bS+3144>>2]|0;if((n|0)==0){bT=0;bU=s|C<<8;bV=bS;break}r=gj[n&4095]((s|C<<8)&65535)|0;bT=r;bU=c[2426868]|0;bV=c[2437644]|0}else{bT=a[F+s|0]|0;bU=s|C<<8;bV=bS}}while(0);C=a[9660900]|0;s=C&1|(bT&255)<<1;a[9660900]=(((s&65535)>>>1^s&65535)>>>6&2|(s&65535)>>>8|((s&255)<<24>>24==0?((s&65535)>>>4&8|C&-16&255)&255|4:((s&65535)>>>4&8|C&-16&255)&255)&255)&255;C=c[bV+72+((bU>>>8&255|256)<<2)>>2]|0;if((C|0)!=0){a[C+(bU&255)|0]=s&255;break L36216}C=c[bV+3148>>2]|0;if((C|0)==0){break L36216}gg[C&4095](bU&65535,s&255);break};default:{l=1}}}if(l){l=0;switch(q|0){case 122:{s=c[2415221]|0;C=c[2437644]|0;F=c[C+72+((s>>>8&255|512)<<2)>>2]|0;do{if((F|0)==0){r=c[C+3156>>2]|0;if((r|0)==0){bW=0;bX=s;bY=C;bZ=s&65535;break}n=gj[r&4095](s&65535)|0;r=c[2415221]|0;bW=n;bX=r;bY=c[2437644]|0;bZ=r&65535}else{bW=a[F+(s&255)|0]|0;bX=s;bY=C;bZ=s&65535}}while(0);s=bW&255;C=bX+1|0;F=c[bY+72+((C>>>8&255|512)<<2)>>2]|0;do{if((F|0)==0){r=c[bY+3156>>2]|0;if((r|0)==0){b_=0;b$=bZ;b0=bY;break}n=gj[r&4095](C&65535)|0;b_=n;b$=b[4830442]|0;b0=c[2437644]|0}else{b_=a[F+(C&255)|0]|0;b$=bZ;b0=bY}}while(0);C=b_&255;c[2426868]=C|s<<8;b[4830442]=b$+2&65535;F=c[b0+72+(s<<2)>>2]|0;do{if((F|0)==0){n=c[b0+3144>>2]|0;if((n|0)==0){b1=0;b2=C|s<<8;b3=b0;break}r=gj[n&4095]((C|s<<8)&65535)|0;b1=r;b2=c[2426868]|0;b3=c[2437644]|0}else{b1=a[F+C|0]|0;b2=C|s<<8;b3=b0}}while(0);s=b1-1&255;a[9660900]=a[9660900]&-15|a[669184+(s&255)|0];C=c[b3+72+((b2>>>8&255|256)<<2)>>2]|0;if((C|0)!=0){a[C+(b2&255)|0]=s;break L36216}C=c[b3+3148>>2]|0;if((C|0)==0){break L36216}gg[C&4095](b2&65535,s);break};case 124:{s=c[2415221]|0;C=c[2437644]|0;F=c[C+72+((s>>>8&255|512)<<2)>>2]|0;do{if((F|0)==0){r=c[C+3156>>2]|0;if((r|0)==0){b4=0;b5=s;b6=C;b7=s&65535;break}n=gj[r&4095](s&65535)|0;r=c[2415221]|0;b4=n;b5=r;b6=c[2437644]|0;b7=r&65535}else{b4=a[F+(s&255)|0]|0;b5=s;b6=C;b7=s&65535}}while(0);s=b4&255;C=b5+1|0;F=c[b6+72+((C>>>8&255|512)<<2)>>2]|0;do{if((F|0)==0){r=c[b6+3156>>2]|0;if((r|0)==0){b8=0;b9=b7;ca=b6;break}n=gj[r&4095](C&65535)|0;b8=n;b9=b[4830442]|0;ca=c[2437644]|0}else{b8=a[F+(C&255)|0]|0;b9=b7;ca=b6}}while(0);C=b8&255;c[2426868]=C|s<<8;b[4830442]=b9+2&65535;F=c[ca+72+(s<<2)>>2]|0;do{if((F|0)==0){n=c[ca+3144>>2]|0;if((n|0)==0){cb=0;cc=C|s<<8;cd=ca;break}r=gj[n&4095]((C|s<<8)&65535)|0;cb=r;cc=c[2426868]|0;cd=c[2437644]|0}else{cb=a[F+C|0]|0;cc=C|s<<8;cd=ca}}while(0);s=cb+1&255;a[9660900]=a[9660900]&-15|a[668928+(s&255)|0];C=c[cd+72+((cc>>>8&255|256)<<2)>>2]|0;if((C|0)!=0){a[C+(cc&255)|0]=s;break L36216}C=c[cd+3148>>2]|0;if((C|0)==0){break L36216}gg[C&4095](cc&65535,s);break};case 125:{s=c[2415221]|0;C=c[2437644]|0;F=c[C+72+((s>>>8&255|512)<<2)>>2]|0;do{if((F|0)==0){r=c[C+3156>>2]|0;if((r|0)==0){ce=0;cf=s;cg=C;ch=s&65535;break}n=gj[r&4095](s&65535)|0;r=c[2415221]|0;ce=n;cf=r;cg=c[2437644]|0;ch=r&65535}else{ce=a[F+(s&255)|0]|0;cf=s;cg=C;ch=s&65535}}while(0);s=ce&255;C=cf+1|0;F=c[cg+72+((C>>>8&255|512)<<2)>>2]|0;do{if((F|0)==0){r=c[cg+3156>>2]|0;if((r|0)==0){ci=0;cj=ch;ck=cg;break}n=gj[r&4095](C&65535)|0;ci=n;cj=b[4830442]|0;ck=c[2437644]|0}else{ci=a[F+(C&255)|0]|0;cj=ch;ck=cg}}while(0);C=ci&255;c[2426868]=C|s<<8;b[4830442]=cj+2&65535;F=c[ck+72+(s<<2)>>2]|0;do{if((F|0)==0){n=c[ck+3144>>2]|0;if((n|0)==0){cl=0;break}cl=gj[n&4095]((C|s<<8)&65535)|0}else{cl=a[F+C|0]|0}}while(0);C=a[9660900]&-16|(cl&255)>>>4&8;a[9660900]=cl<<24>>24==0?C|4:C;break};case 126:{C=c[2415221]|0;F=c[2437644]|0;s=c[F+72+((C>>>8&255|512)<<2)>>2]|0;do{if((s|0)==0){n=c[F+3156>>2]|0;if((n|0)==0){cm=0;cn=C;co=F;break}r=gj[n&4095](C&65535)|0;cm=r;cn=c[2415221]|0;co=c[2437644]|0}else{cm=a[s+(C&255)|0]|0;cn=C;co=F}}while(0);F=(cm&255)<<8;C=cn+1|0;s=c[co+72+((C>>>8&255|512)<<2)>>2]|0;do{if((s|0)==0){r=c[co+3156>>2]|0;if((r|0)==0){cp=0;break}cp=gj[r&4095](C&65535)|0}else{cp=a[s+(C&255)|0]|0}}while(0);C=cp&255|F;c[2426868]=C;b[4830442]=C&65535;b[4830442]=c[2415221]&65535;break};case 127:{C=c[2415221]|0;s=c[2437644]|0;r=c[s+72+((C>>>8&255|512)<<2)>>2]|0;do{if((r|0)==0){n=c[s+3156>>2]|0;if((n|0)==0){cq=0;cr=C;cs=s;ct=C&65535;break}aP=gj[n&4095](C&65535)|0;n=c[2415221]|0;cq=aP;cr=n;cs=c[2437644]|0;ct=n&65535}else{cq=a[r+(C&255)|0]|0;cr=C;cs=s;ct=C&65535}}while(0);C=cq&255;s=cr+1|0;r=c[cs+72+((s>>>8&255|512)<<2)>>2]|0;do{if((r|0)==0){F=c[cs+3156>>2]|0;if((F|0)==0){cu=0;cv=ct;cw=cs;break}n=gj[F&4095](s&65535)|0;cu=n;cv=b[4830442]|0;cw=c[2437644]|0}else{cu=a[r+(s&255)|0]|0;cv=ct;cw=cs}}while(0);s=cu&255;c[2426868]=s|C<<8;b[4830442]=cv+2&65535;r=c[cw+72+((C|256)<<2)>>2]|0;do{if((r|0)==0){n=c[cw+3148>>2]|0;if((n|0)==0){break}gg[n&4095]((s|C<<8)&65535,0)}else{a[r+s|0]=0}}while(0);a[9660900]=a[9660900]&-16|4;break};case 128:{s=c[2415221]|0;r=c[2437644]|0;C=c[r+72+((s>>>8&255|512)<<2)>>2]|0;do{if((C|0)==0){n=c[r+3156>>2]|0;if((n|0)==0){cx=0;cy=s&65535;break}F=gj[n&4095](s&65535)|0;cx=F;cy=b[4830442]|0}else{cx=a[C+(s&255)|0]|0;cy=s&65535}}while(0);b[4830442]=cy+1&65535;s=a[9660897]|0;C=(s&255)-(cx&255)|0;r=(C>>>4&8|a[9660900]&-16&255)&255;a[9660900]=(((s^cx)&255^C^C>>>1)>>>6&2|C>>>8&1|((C&255)<<24>>24==0?r|4:r)&255)&255;a[9660897]=C&255;break};case 129:{C=c[2415221]|0;r=c[2437644]|0;s=c[r+72+((C>>>8&255|512)<<2)>>2]|0;do{if((s|0)==0){F=c[r+3156>>2]|0;if((F|0)==0){cz=0;cA=C&65535;break}n=gj[F&4095](C&65535)|0;cz=n;cA=b[4830442]|0}else{cz=a[s+(C&255)|0]|0;cA=C&65535}}while(0);b[4830442]=cA+1&65535;C=a[9660897]|0;s=(C&255)-(cz&255)|0;r=(s>>>4&8|a[9660900]&-16&255)&255;a[9660900]=(((C^cz)&255^s^s>>>1)>>>6&2|s>>>8&1|((s&255)<<24>>24==0?r|4:r)&255)&255;break};case 130:{r=c[2415221]|0;s=c[2437644]|0;C=c[s+72+((r>>>8&255|512)<<2)>>2]|0;do{if((C|0)==0){n=c[s+3156>>2]|0;if((n|0)==0){cB=0;cC=r&65535;break}F=gj[n&4095](r&65535)|0;cB=F;cC=b[4830442]|0}else{cB=a[C+(r&255)|0]|0;cC=r&65535}}while(0);b[4830442]=cC+1&65535;r=a[9660897]|0;C=a[9660900]|0;s=(r&255)-(cB&255)-(C&1)|0;a[9660900]=((s^(r^cB)&255^s>>>1)>>>6&2|s>>>8&1|((s&255)<<24>>24==0?(s>>>4&8|C&-16&255)&255|4:(s>>>4&8|C&-16&255)&255)&255)&255;a[9660897]=s&255;break};case 132:{s=c[2415221]|0;C=c[2437644]|0;r=c[C+72+((s>>>8&255|512)<<2)>>2]|0;do{if((r|0)==0){F=c[C+3156>>2]|0;if((F|0)==0){cD=0;cE=s&65535;break}n=gj[F&4095](s&65535)|0;cD=n;cE=b[4830442]|0}else{cD=a[r+(s&255)|0]|0;cE=s&65535}}while(0);b[4830442]=cE+1&65535;s=a[9660897]&cD;a[9660897]=s;r=(s&255)>>>4&8|a[9660900]&-15;a[9660900]=s<<24>>24==0?r|4:r;break};case 133:{r=c[2415221]|0;s=c[2437644]|0;C=c[s+72+((r>>>8&255|512)<<2)>>2]|0;do{if((C|0)==0){n=c[s+3156>>2]|0;if((n|0)==0){cF=0;cG=r&65535;break}F=gj[n&4095](r&65535)|0;cF=F;cG=b[4830442]|0}else{cF=a[C+(r&255)|0]|0;cG=r&65535}}while(0);b[4830442]=cG+1&65535;r=a[9660897]&cF;C=(r&255)>>>4&8|a[9660900]&-15;a[9660900]=r<<24>>24==0?C|4:C;break};case 134:{C=c[2415221]|0;r=c[2437644]|0;s=c[r+72+((C>>>8&255|512)<<2)>>2]|0;do{if((s|0)==0){F=c[r+3156>>2]|0;if((F|0)==0){cH=0;cI=C&65535;break}n=gj[F&4095](C&65535)|0;cH=n;cI=b[4830442]|0}else{cH=a[s+(C&255)|0]|0;cI=C&65535}}while(0);a[9660897]=cH;b[4830442]=cI+1&65535;C=a[9660900]&-15|(cH&255)>>>4&8;a[9660900]=cH<<24>>24==0?C|4:C;break};case 135:{C=a[9660897]|0;s=(C&255)>>>4&8|a[9660900]&-15;a[9660900]=C<<24>>24==0?s|4:s;b[4830442]=p+2&65535;b[4853736]=k;s=c[2426868]|0;r=c[2437644]|0;n=c[r+72+((s>>>8&255|256)<<2)>>2]|0;if((n|0)!=0){a[n+(s&255)|0]=C;break L36216}n=c[r+3148>>2]|0;if((n|0)==0){break L36216}gg[n&4095](s&65535,C);break};case 136:{C=c[2415221]|0;s=c[2437644]|0;n=c[s+72+((C>>>8&255|512)<<2)>>2]|0;do{if((n|0)==0){r=c[s+3156>>2]|0;if((r|0)==0){cJ=0;cK=C&65535;break}F=gj[r&4095](C&65535)|0;cJ=F;cK=b[4830442]|0}else{cJ=a[n+(C&255)|0]|0;cK=C&65535}}while(0);b[4830442]=cK+1&65535;C=a[9660897]|0;n=C^cJ;a[9660897]=n;s=(n&255)>>>4&8|a[9660900]&-15;a[9660900]=C<<24>>24==cJ<<24>>24?s|4:s;break};case 137:{s=c[2415221]|0;C=c[2437644]|0;n=c[C+72+((s>>>8&255|512)<<2)>>2]|0;do{if((n|0)==0){F=c[C+3156>>2]|0;if((F|0)==0){cL=0;cM=s&65535;break}r=gj[F&4095](s&65535)|0;cL=r;cM=b[4830442]|0}else{cL=a[n+(s&255)|0]|0;cM=s&65535}}while(0);b[4830442]=cM+1&65535;s=a[9660897]|0;n=a[9660900]|0;C=(s&255)+(cL&255)+(n&1)|0;r=C^(s^cL)&255;a[9660900]=(r<<1&32|C>>>8&1|(r^C>>>1)>>>6&2|((C&255)<<24>>24==0?(C>>>4&8|n&-48&255)&255|4:(C>>>4&8|n&-48&255)&255)&255)&255;a[9660897]=C&255;break};case 138:{C=c[2415221]|0;n=c[2437644]|0;r=c[n+72+((C>>>8&255|512)<<2)>>2]|0;do{if((r|0)==0){s=c[n+3156>>2]|0;if((s|0)==0){cN=0;cO=C&65535;break}F=gj[s&4095](C&65535)|0;cN=F;cO=b[4830442]|0}else{cN=a[r+(C&255)|0]|0;cO=C&65535}}while(0);b[4830442]=cO+1&65535;C=a[9660897]|cN;a[9660897]=C;r=(C&255)>>>4&8|a[9660900]&-15;a[9660900]=C<<24>>24==0?r|4:r;break};case 139:{r=c[2415221]|0;C=c[2437644]|0;n=c[C+72+((r>>>8&255|512)<<2)>>2]|0;do{if((n|0)==0){F=c[C+3156>>2]|0;if((F|0)==0){cP=0;cQ=r&65535;break}s=gj[F&4095](r&65535)|0;cP=s;cQ=b[4830442]|0}else{cP=a[n+(r&255)|0]|0;cQ=r&65535}}while(0);b[4830442]=cQ+1&65535;r=a[9660897]|0;n=(r&255)+(cP&255)|0;C=(n>>>4&8|a[9660900]&-48&255)&255;s=(r^cP)&255^n;a[9660900]=(s<<1&32|n>>>8&1|(s^n>>>1)>>>6&2|((n&255)<<24>>24==0?C|4:C)&255)&255;a[9660897]=n&255;break};case 140:{n=c[2415221]|0;C=c[2437644]|0;s=c[C+72+((n>>>8&255|512)<<2)>>2]|0;do{if((s|0)==0){r=c[C+3156>>2]|0;if((r|0)==0){cR=0;cS=n;cT=C;cU=n&65535;break}F=gj[r&4095](n&65535)|0;r=c[2415221]|0;cR=F;cS=r;cT=c[2437644]|0;cU=r&65535}else{cR=a[s+(n&255)|0]|0;cS=n;cT=C;cU=n&65535}}while(0);n=(cR&255)<<8;C=cS+1|0;s=c[cT+72+((C>>>8&255|512)<<2)>>2]|0;do{if((s|0)==0){r=c[cT+3156>>2]|0;if((r|0)==0){cV=0;cW=cU;break}F=gj[r&4095](C&65535)|0;cV=F;cW=b[4830442]|0}else{cV=a[s+(C&255)|0]|0;cW=cU}}while(0);b[4830442]=cW+2&65535;C=e[4830446]|0;s=C-(cV&255|n)|0;F=(s>>>12&8|a[9660900]&-15&255)&255;a[9660900]=(((s&65535)<<16>>16==0?F|4:F)&255|(C^n^s^s>>>1)>>>14&2)&255;break};case 141:{s=c[2415221]|0;C=c[2437644]|0;F=c[C+72+((s>>>8&255|512)<<2)>>2]|0;do{if((F|0)==0){r=c[C+3156>>2]|0;if((r|0)==0){cX=0;cY=s&65535;cZ=C;break}aP=gj[r&4095](s&65535)|0;cX=aP;cY=b[4830442]|0;cZ=c[2437644]|0}else{cX=a[F+(s&255)|0]|0;cY=s&65535;cZ=C}}while(0);C=cY+1&65535;b[4830442]=C;s=c[2415222]|0;F=c[cZ+72+((s>>>8&255|256)<<2)>>2]|0;do{if((F|0)==0){n=c[cZ+3148>>2]|0;if((n|0)==0){c_=cZ;break}gg[n&4095](s&65535,C&255);c_=c[2437644]|0}else{a[F+(s&255)|0]=C&255;c_=cZ}}while(0);b[4830444]=(b[4830444]|0)-1&65535;C=c[2415222]|0;s=a[9660885]|0;F=c[c_+72+((C>>>8&255|256)<<2)>>2]|0;do{if((F|0)==0){n=c[c_+3148>>2]|0;if((n|0)==0){break}gg[n&4095](C&65535,s)}else{a[F+(C&255)|0]=s}}while(0);b[4830444]=(b[4830444]|0)-1&65535;s=cX&255;b[4830442]=(e[4830442]|0)+((s&128|0)!=0?s|65280:s)&65535;b[4830442]=c[2415221]&65535;break};case 142:{s=c[2415221]|0;C=c[2437644]|0;F=c[C+72+((s>>>8&255|512)<<2)>>2]|0;do{if((F|0)==0){n=c[C+3156>>2]|0;if((n|0)==0){c$=0;c0=s;c1=C;c2=s&65535;break}aP=gj[n&4095](s&65535)|0;n=c[2415221]|0;c$=aP;c0=n;c1=c[2437644]|0;c2=n&65535}else{c$=a[F+(s&255)|0]|0;c0=s;c1=C;c2=s&65535}}while(0);s=c$&255;C=c0+1|0;F=c[c1+72+((C>>>8&255|512)<<2)>>2]|0;do{if((F|0)==0){n=c[c1+3156>>2]|0;if((n|0)==0){c3=0;c4=c2;break}aP=gj[n&4095](C&65535)|0;c3=aP;c4=b[4830442]|0}else{c3=a[F+(C&255)|0]|0;c4=c2}}while(0);C=c3&255|s<<8;c[2415222]=C;b[4830442]=c4+2&65535;F=a[9660900]&-15;a[9660900]=F;if((C|0)==0){c5=(F&255|s>>>4&8|4)&255}else{c5=(F&255|s>>>4&8)&255}a[9660900]=c5;break};case 143:{F=b[4830444]|0;C=(F&65535)>>>12&8|a[9660900]&-15&255;a[9660900]=(F<<16>>16==0?C|4:C)&255;b[4853736]=k;b[4830442]=p+3&65535;C=c[2426868]|0;F=a[9660889]|0;aP=c[2437644]|0;n=c[aP+72+((C>>>8&255|256)<<2)>>2]|0;do{if((n|0)==0){r=c[aP+3148>>2]|0;if((r|0)==0){c6=aP;break}gg[r&4095](C&65535,F);c6=c[2437644]|0}else{a[n+(C&255)|0]=F;c6=aP}}while(0);aP=a[9660888]|0;F=c[c6+72+(((C+1|0)>>>8&255|256)<<2)>>2]|0;if((F|0)!=0){a[F+((C+1|0)&255)|0]=aP;break L36216}F=c[c6+3148>>2]|0;if((F|0)==0){break L36216}gg[F&4095]((C+1|0)&65535,aP);break};case 144:{aP=c[2415221]|0;F=c[2437644]|0;n=c[F+72+((aP>>>8&255|512)<<2)>>2]|0;do{if((n|0)==0){s=c[F+3156>>2]|0;if((s|0)==0){c7=0;c8=aP&65535;c9=F;break}r=gj[s&4095](aP&65535)|0;c7=r;c8=b[4830442]|0;c9=c[2437644]|0}else{c7=a[n+(aP&255)|0]|0;c8=aP&65535;c9=F}}while(0);F=c7&255;c[2426868]=F;b[4830442]=c8+1&65535;aP=c7&255;n=c[c9+72>>2]|0;do{if((n|0)==0){C=c[c9+3144>>2]|0;if((C|0)==0){da=0;break}da=gj[C&4095](aP)|0}else{da=a[n+F|0]|0}}while(0);F=a[9660897]|0;n=(F&255)-(da&255)|0;aP=(n>>>4&8|a[9660900]&-16&255)&255;a[9660900]=(((F^da)&255^n^n>>>1)>>>6&2|n>>>8&1|((n&255)<<24>>24==0?aP|4:aP)&255)&255;a[9660897]=n&255;break};case 145:{n=c[2415221]|0;aP=c[2437644]|0;F=c[aP+72+((n>>>8&255|512)<<2)>>2]|0;do{if((F|0)==0){C=c[aP+3156>>2]|0;if((C|0)==0){db=0;dc=n&65535;dd=aP;break}r=gj[C&4095](n&65535)|0;db=r;dc=b[4830442]|0;dd=c[2437644]|0}else{db=a[F+(n&255)|0]|0;dc=n&65535;dd=aP}}while(0);aP=db&255;c[2426868]=aP;b[4830442]=dc+1&65535;n=db&255;F=c[dd+72>>2]|0;do{if((F|0)==0){r=c[dd+3144>>2]|0;if((r|0)==0){de=0;break}de=gj[r&4095](n)|0}else{de=a[F+aP|0]|0}}while(0);aP=a[9660897]|0;F=(aP&255)-(de&255)|0;n=(F>>>4&8|a[9660900]&-16&255)&255;a[9660900]=(((aP^de)&255^F^F>>>1)>>>6&2|F>>>8&1|((F&255)<<24>>24==0?n|4:n)&255)&255;break};case 146:{n=c[2415221]|0;F=c[2437644]|0;aP=c[F+72+((n>>>8&255|512)<<2)>>2]|0;do{if((aP|0)==0){r=c[F+3156>>2]|0;if((r|0)==0){df=0;dg=n&65535;dh=F;break}C=gj[r&4095](n&65535)|0;df=C;dg=b[4830442]|0;dh=c[2437644]|0}else{df=a[aP+(n&255)|0]|0;dg=n&65535;dh=F}}while(0);F=df&255;c[2426868]=F;b[4830442]=dg+1&65535;n=df&255;aP=c[dh+72>>2]|0;do{if((aP|0)==0){C=c[dh+3144>>2]|0;if((C|0)==0){di=0;break}di=gj[C&4095](n)|0}else{di=a[aP+F|0]|0}}while(0);F=a[9660897]|0;aP=a[9660900]|0;n=(F&255)-(di&255)-(aP&1)|0;a[9660900]=((n^(F^di)&255^n>>>1)>>>6&2|n>>>8&1|((n&255)<<24>>24==0?(n>>>4&8|aP&-16&255)&255|4:(n>>>4&8|aP&-16&255)&255)&255)&255;a[9660897]=n&255;break};case 41:{n=c[2415221]|0;aP=c[2437644]|0;F=c[aP+72+((n>>>8&255|512)<<2)>>2]|0;do{if((F|0)==0){C=c[aP+3156>>2]|0;if((C|0)==0){dj=0;dk=n&65535;break}r=gj[C&4095](n&65535)|0;dj=r;dk=b[4830442]|0}else{dj=a[F+(n&255)|0]|0;dk=n&65535}}while(0);n=dk+1&65535;b[4830442]=n;if((a[9660900]&2)==0){break L36216}F=dj&255;b[4830442]=((F&128|0)!=0?F|65280:F)+(n&65535)&65535;b[4830442]=c[2415221]&65535;break};case 42:{n=c[2415221]|0;F=c[2437644]|0;aP=c[F+72+((n>>>8&255|512)<<2)>>2]|0;do{if((aP|0)==0){r=c[F+3156>>2]|0;if((r|0)==0){dl=0;dm=n&65535;break}C=gj[r&4095](n&65535)|0;dl=C;dm=b[4830442]|0}else{dl=a[aP+(n&255)|0]|0;dm=n&65535}}while(0);n=dm+1&65535;b[4830442]=n;if((a[9660900]&8)!=0){break L36216}aP=dl&255;b[4830442]=((aP&128|0)!=0?aP|65280:aP)+(n&65535)&65535;b[4830442]=c[2415221]&65535;break};case 43:{n=c[2415221]|0;aP=c[2437644]|0;F=c[aP+72+((n>>>8&255|512)<<2)>>2]|0;do{if((F|0)==0){C=c[aP+3156>>2]|0;if((C|0)==0){dn=0;dp=n&65535;break}r=gj[C&4095](n&65535)|0;dn=r;dp=b[4830442]|0}else{dn=a[F+(n&255)|0]|0;dp=n&65535}}while(0);n=dp+1&65535;b[4830442]=n;if((a[9660900]&8)==0){break L36216}F=dn&255;b[4830442]=((F&128|0)!=0?F|65280:F)+(n&65535)&65535;b[4830442]=c[2415221]&65535;break};case 44:{n=c[2415221]|0;F=c[2437644]|0;aP=c[F+72+((n>>>8&255|512)<<2)>>2]|0;do{if((aP|0)==0){r=c[F+3156>>2]|0;if((r|0)==0){dq=0;dr=n&65535;break}C=gj[r&4095](n&65535)|0;dq=C;dr=b[4830442]|0}else{dq=a[aP+(n&255)|0]|0;dr=n&65535}}while(0);n=dr+1&65535;b[4830442]=n;aP=d[9660900]|0;if(((aP<<2^aP)&8|0)!=0){break L36216}aP=dq&255;b[4830442]=((aP&128|0)!=0?aP|65280:aP)+(n&65535)&65535;b[4830442]=c[2415221]&65535;break};case 45:{n=c[2415221]|0;aP=c[2437644]|0;F=c[aP+72+((n>>>8&255|512)<<2)>>2]|0;do{if((F|0)==0){C=c[aP+3156>>2]|0;if((C|0)==0){ds=0;dt=n&65535;break}r=gj[C&4095](n&65535)|0;ds=r;dt=b[4830442]|0}else{ds=a[F+(n&255)|0]|0;dt=n&65535}}while(0);n=dt+1&65535;b[4830442]=n;F=d[9660900]|0;if(((F<<2^F)&8|0)==0){break L36216}F=ds&255;b[4830442]=((F&128|0)!=0?F|65280:F)+(n&65535)&65535;b[4830442]=c[2415221]&65535;break};case 46:{n=c[2415221]|0;F=c[2437644]|0;aP=c[F+72+((n>>>8&255|512)<<2)>>2]|0;do{if((aP|0)==0){r=c[F+3156>>2]|0;if((r|0)==0){du=0;dv=n&65535;break}C=gj[r&4095](n&65535)|0;du=C;dv=b[4830442]|0}else{du=a[aP+(n&255)|0]|0;dv=n&65535}}while(0);n=dv+1&65535;b[4830442]=n;aP=d[9660900]|0;if(((aP<<2^aP)&8|aP&4|0)!=0){break L36216}aP=du&255;b[4830442]=((aP&128|0)!=0?aP|65280:aP)+(n&65535)&65535;b[4830442]=c[2415221]&65535;break};case 47:{n=c[2415221]|0;aP=c[2437644]|0;F=c[aP+72+((n>>>8&255|512)<<2)>>2]|0;do{if((F|0)==0){C=c[aP+3156>>2]|0;if((C|0)==0){dw=0;dx=n&65535;break}r=gj[C&4095](n&65535)|0;dw=r;dx=b[4830442]|0}else{dw=a[F+(n&255)|0]|0;dx=n&65535}}while(0);n=dx+1&65535;b[4830442]=n;F=d[9660900]|0;if(((F<<2^F)&8|F&4|0)==0){break L36216}F=dw&255;b[4830442]=((F&128|0)!=0?F|65280:F)+(n&65535)&65535;b[4830442]=c[2415221]&65535;break};case 48:{b[4830446]=(b[4830444]|0)+1&65535;break};case 49:{b[4830444]=(b[4830444]|0)+1&65535;break};case 50:{b[4830444]=(b[4830444]|0)+1&65535;n=c[2415222]|0;F=c[2437644]|0;aP=c[F+72+((n>>>8&255)<<2)>>2]|0;do{if((aP|0)==0){r=c[F+3144>>2]|0;if((r|0)==0){dy=0;break}dy=gj[r&4095](n&65535)|0}else{dy=a[aP+(n&255)|0]|0}}while(0);a[9660897]=dy;break};case 51:{b[4830444]=(b[4830444]|0)+1&65535;n=c[2415222]|0;aP=c[2437644]|0;F=c[aP+72+((n>>>8&255)<<2)>>2]|0;do{if((F|0)==0){r=c[aP+3144>>2]|0;if((r|0)==0){dz=0;break}dz=gj[r&4095](n&65535)|0}else{dz=a[F+(n&255)|0]|0}}while(0);a[9660896]=dz;break};case 52:{b[4830444]=(b[4830444]|0)-1&65535;break};case 53:{b[4830444]=(b[4830446]|0)-1&65535;break};case 54:{n=c[2415222]|0;F=a[9660897]|0;aP=c[2437644]|0;r=c[aP+72+((n>>>8&255|256)<<2)>>2]|0;do{if((r|0)==0){C=c[aP+3148>>2]|0;if((C|0)==0){break}gg[C&4095](n&65535,F)}else{a[r+(n&255)|0]=F}}while(0);b[4830444]=(b[4830444]|0)-1&65535;break};case 55:{F=c[2415222]|0;n=a[9660896]|0;r=c[2437644]|0;aP=c[r+72+((F>>>8&255|256)<<2)>>2]|0;do{if((aP|0)==0){C=c[r+3148>>2]|0;if((C|0)==0){break}gg[C&4095](F&65535,n)}else{a[aP+(F&255)|0]=n}}while(0);b[4830444]=(b[4830444]|0)-1&65535;break};case 57:{b[4830444]=(b[4830444]|0)+1&65535;n=c[2415222]|0;F=c[2437644]|0;aP=c[F+72+((n>>>8&255)<<2)>>2]|0;do{if((aP|0)==0){r=c[F+3144>>2]|0;if((r|0)==0){dA=0;dB=n&65535;dC=F;break}C=gj[r&4095](n&65535)|0;dA=C;dB=b[4830444]|0;dC=c[2437644]|0}else{dA=a[aP+(n&255)|0]|0;dB=n&65535;dC=F}}while(0);F=(dA&255)<<8;c[2415221]=F;b[4830444]=dB+1&65535;n=c[2415222]|0;aP=c[dC+72+((n>>>8&255)<<2)>>2]|0;do{if((aP|0)==0){C=c[dC+3144>>2]|0;if((C|0)==0){dD=0;dE=F;break}r=gj[C&4095](n&65535)|0;dD=r;dE=c[2415221]|0}else{dD=a[aP+(n&255)|0]|0;dE=F}}while(0);F=dE|dD&255;c[2415221]=F;b[4830442]=F&65535;break};case 59:{f1H();break};case 62:{f1I();break};case 63:{f1J();break};case 64:{F=a[9660897]|0;n=-(F&255)&65535&65535;aP=(n>>>4&8|a[9660900]&-16&255)&255;a[9660900]=((n^F&255^n>>>1)>>>6&2|n>>>8&1|((-(F&255)&65535&255)<<24>>24==0?aP|4:aP)&255)&255;a[9660897]=-(F&255)&65535&255;break};case 67:{F=a[9660897]|0;a[9660897]=~F;aP=(~F&255)>>>4&8|a[9660900]&-15;a[9660900]=(F<<24>>24==-1?aP|4:aP)|1;break};case 68:{aP=a[9660897]|0;F=aP&1|a[9660900]&-14;a[9660900]=F;a[9660897]=(aP&255)>>>1;if((aP&255)>>>1<<24>>24!=0){break L36216}a[9660900]=F|4;break};case 70:{F=a[9660900]|0;aP=a[9660897]|0;a[9660900]=((aP&255)>>>1|F<<7)<<24>>24==0?aP&1|F&-14|F<<3&8|4:aP&1|F&-14|F<<3&8;a[9660897]=(aP&255)>>>1|F<<7;break};case 71:{F=a[9660897]|0;aP=F&1|a[9660900]&-14;a[9660897]=(F&255)>>>1<<1&-128|(F&255)>>>1;a[9660900]=((F&255)>>>1<<1&-128|(F&255)>>>1)<<24>>24==0?aP|(F&255)>>>4&8|4:aP|(F&255)>>>4&8;break};case 72:{F=(d[9660897]|0)<<1;aP=((F&65535)>>>4&8|a[9660900]&-16&255)&255;a[9660900]=(((F&65535)>>>1^F&65535)>>>6&2|(F&65535)>>>8|((F&255)<<24>>24==0?aP|4:aP)&255)&255;a[9660897]=F&255;break};default:{l=1}}}c[h+136>>2]=p;c[h+152>>2]=k;c[h+21416>>2]=l;c[h+21424>>2]=q;c[h+21432>>2]=0;c[h+21436>>2]=0;__Z13m6800_executei$0(h);l=c[h+21416>>2]|0;I=c[h+21432>>2]|0;B=c[h+21436>>2]|0;J=+g[h+21436>>2];c[h+21432>>2]=0;c[h+21436>>2]=0;if((I|0)==1){break}if((I|0)==2){switch(B|0){case 32:{break L36216}}}}while(0);k=d[7066880+j|0]|0;c[2440594]=(c[2440594]|0)-k;F=(c[2415234]|0)+k|0;c[2415234]=F;if(F>>>0<(c[3528192]|0)>>>0){u=31128;break}f03();u=31128}else{m=1}}if(m){m=0;if(1){F=c[3528192]|0;k=c[2415234]|0;aP=c[2440594]|0;n=(F-k|0|0)>(aP|0)?aP:F-k|0;if((n|0)<=0){dF=aP;break}c[2440594]=aP-n;c[2415234]=n+k|0;if((n+k|0)>>>0<F>>>0){u=31128;break}f03();u=31128}else{m=1}}}while(0);if((u|0)==31128){u=0;dF=c[2440594]|0}}while((dF|0)>0);u=c[2415227]|0;p=dF-u|0;c[2440594]=p;dF=(c[2415234]|0)+u|0;c[2415234]=dF;if(dF>>>0<(c[3528192]|0)>>>0){dG=p;c[2415227]=0;dH=f-dG|0;i=h;return dH|0}f03();dG=c[2440594]|0;c[2415227]=0;dH=f-dG|0;i=h;return dH|0}function f03(){var d=0,e=0,f=0,g=0,h=0;d=c[2415234]|0;do{if(d>>>0<(c[2415235]|0)>>>0){e=d}else{b[4830471]=(b[4830471]|0)+1&65535;f=a[9660928]|0;g=f|64;a[9660928]=g;a[9660930]=a[9660930]|64;a[9660931]=g&-32&f<<3;if((a[9660900]&16)!=0){e=d;break}if((f&8)==0){e=d;break}f00(-12);e=c[2415234]|0}}while(0);d=c[2415237]|0;do{if(e>>>0<d>>>0){h=e}else{b[4830474]=(d&65535)+1&65535;f=a[9660928]|0;g=f|32;a[9660928]=g;a[9660930]=a[9660930]|32;a[9660931]=g&-32&f<<3;if((a[9660900]&16)!=0){h=e;break}if((f&4)==0){h=e;break}f00(-14);h=c[2415234]|0}}while(0);e=c[2415235]|0;d=c[2415237]|0;c[3528192]=(e-h|0)>>>0<(d-h|0)>>>0?e:d;return}function f04(){return}function f05(){return}function f06(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a[9660900]=a[9660897]|0;e=c[2415221]|0;c[2415220]=e;f=e&65535;g=c[2437644]|0;h=c[g+72+((e>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+3152>>2]|0;if((i|0)==0){j=0;k=f;break}l=gj[i&4095](f)|0;j=l;k=b[4830442]|0}else{j=a[h+(e&255)|0]|0;k=f}}while(0);b[4830442]=k+1&65535;k=j&255;gu[c[(c[2415228]|0)+(k<<2)>>2]&16383]();j=d[(c[2415229]|0)+k|0]|0;c[2440594]=(c[2440594]|0)-j;k=(c[2415234]|0)+j|0;c[2415234]=k;if(k>>>0>=(c[3528192]|0)>>>0){f03()}if((a[9660900]&16)!=0){return}if((a[9660903]|0)!=0){f00(-8);return}k=d[9660931]|0;if((k&224|0)==0){return}if((k&128|0)!=0){f00(-10);return}if((k&64|0)!=0){f00(-12);return}if((k&32|0)==0){return}f00(-14);return}function f07(){a[9660897]=a[9660900]|0;return}function f08(){var c=0,d=0;c=(b[4830446]|0)+1&65535;b[4830446]=c;d=a[9660900]|0;a[9660900]=c<<16>>16==0?d|4:d&-5;return}function f09(){var c=0,d=0;c=(b[4830446]|0)-1&65535;b[4830446]=c;d=a[9660900]|0;a[9660900]=c<<16>>16==0?d|4:d&-5;return}function f1a(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a[9660900]=a[9660900]&-17;e=c[2415221]|0;c[2415220]=e;f=e&65535;g=c[2437644]|0;h=c[g+72+((e>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+3152>>2]|0;if((i|0)==0){j=0;k=f;break}l=gj[i&4095](f)|0;j=l;k=b[4830442]|0}else{j=a[h+(e&255)|0]|0;k=f}}while(0);b[4830442]=k+1&65535;k=j&255;gu[c[(c[2415228]|0)+(k<<2)>>2]&16383]();j=d[(c[2415229]|0)+k|0]|0;c[2440594]=(c[2440594]|0)-j;k=(c[2415234]|0)+j|0;c[2415234]=k;if(k>>>0>=(c[3528192]|0)>>>0){f03()}if((a[9660900]&16)!=0){return}if((a[9660903]|0)!=0){f00(-8);return}k=d[9660931]|0;if((k&224|0)==0){return}if((k&128|0)!=0){f00(-10);return}if((k&64|0)!=0){f00(-12);return}if((k&32|0)==0){return}f00(-14);return}function f1b(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a[9660900]=a[9660900]|16;e=c[2415221]|0;c[2415220]=e;f=e&65535;g=c[2437644]|0;h=c[g+72+((e>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+3152>>2]|0;if((i|0)==0){j=0;k=f;break}l=gj[i&4095](f)|0;j=l;k=b[4830442]|0}else{j=a[h+(e&255)|0]|0;k=f}}while(0);b[4830442]=k+1&65535;k=j&255;gu[c[(c[2415228]|0)+(k<<2)>>2]&16383]();j=d[(c[2415229]|0)+k|0]|0;c[2440594]=(c[2440594]|0)-j;k=(c[2415234]|0)+j|0;c[2415234]=k;if(k>>>0>=(c[3528192]|0)>>>0){f03()}if((a[9660900]&16)!=0){return}if((a[9660903]|0)!=0){f00(-8);return}k=d[9660931]|0;if((k&224|0)==0){return}if((k&128|0)!=0){f00(-10);return}if((k&64|0)!=0){f00(-12);return}if((k&32|0)==0){return}f00(-14);return}function f1c(){var b=0,c=0,d=0,e=0,f=0,g=0;b=a[9660897]|0;c=a[9660896]|0;d=(b&255)-(c&255)&65535;e=d&65535;f=(e>>>4&8|a[9660900]&-16&255)&255;g=d&255;a[9660900]=((e^(c^b)&255^e>>>1)>>>6&2|e>>>8&1|(g<<24>>24==0?f|4:f)&255)&255;a[9660897]=g;return}function f1d(){var b=0,c=0,d=0,e=0,f=0;b=a[9660897]|0;c=a[9660896]|0;d=(b&255)-(c&255)&65535;e=d&65535;f=(e>>>4&8|a[9660900]&-16&255)&255;a[9660900]=((e^(c^b)&255^e>>>1)>>>6&2|e>>>8&1|((d&255)<<24>>24==0?f|4:f)&255)&255;return}function f1e(){var b=0,c=0;b=a[9660897]|0;a[9660896]=b;c=(b&255)>>>4&8|a[9660900]&-15;a[9660900]=b<<24>>24==0?c|4:c;return}function f1f(){var b=0,c=0;b=a[9660896]|0;a[9660897]=b;c=(b&255)>>>4&8|a[9660900]&-15;a[9660900]=b<<24>>24==0?c|4:c;return}function f1g(){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=a[9660897]|0;c=b&-16;d=(b&14)>9;if(d){e=31227}else{if((a[9660900]&32)==0){f=0}else{e=31227}}if((e|0)==31227){f=6}do{if((c&255)>128){g=d?f|96:f;if((c&255)<=144){h=g;e=31231;break}i=g;j=a[9660900]|0;e=31232}else{h=f;e=31231}}while(0);if((e|0)==31231){f=a[9660900]|0;if((f&1)==0){k=h;l=f}else{i=h;j=f;e=31232}}if((e|0)==31232){k=i|96;l=j}j=k+(b&255)&65535;b=j&255;k=j&65535;j=(k>>>4&8|l&-15&255)&255;a[9660900]=((b<<24>>24==0?j|4:j)&255|k>>>8&1)&255;a[9660897]=b;return}function f1h(){var b=0,c=0,d=0,e=0,f=0,g=0;b=a[9660897]|0;c=a[9660896]|0;d=(c&255)+(b&255)&65535;e=d&65535;f=(e>>>4&8|a[9660900]&-48&255)&255;g=d&255;d=e^(c^b)&255;a[9660900]=(d<<1&32|e>>>8&1|(d^e>>>1)>>>6&2|(g<<24>>24==0?f|4:f)&255)&255;a[9660897]=g;return}function f1i(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=e;break}k=gj[h&4095](e)|0;i=k;j=b[4830442]|0}else{i=a[g+(d&255)|0]|0;j=e}}while(0);e=i&255;b[4830442]=((e&128|0)!=0?e|65280:e)+(j+1&65535)&65535;b[4830442]=c[2415221]&65535;if(i<<24>>24!=-2){return}i=c[3528192]|0;j=c[2415234]|0;e=i-j|0;d=c[2440594]|0;g=(e|0)>(d|0)?d:e;if((g|0)<=0){return}c[2440594]=d-g;d=g+j|0;c[2415234]=d;if(d>>>0<i>>>0){return}f03();return}function f1j(){var a=0,d=0,e=0,f=0,g=0;a=c[2415221]|0;d=a&65535;e=c[2437644]|0;do{if((c[e+72+((a>>>8&255|512)<<2)>>2]|0)==0){f=c[e+3156>>2]|0;if((f|0)==0){g=d;break}gj[f&4095](d)|0;g=b[4830442]|0}else{g=d}}while(0);b[4830442]=g+1&65535;return}function f1k(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=e;break}k=gj[h&4095](e)|0;i=k;j=b[4830442]|0}else{i=a[g+(d&255)|0]|0;j=e}}while(0);e=j+1&65535;b[4830442]=e;if((a[9660900]&5)!=0){return}j=i&255;b[4830442]=((j&128|0)!=0?j|65280:j)+(e&65535)&65535;b[4830442]=c[2415221]&65535;return}function f1l(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=e;break}k=gj[h&4095](e)|0;i=k;j=b[4830442]|0}else{i=a[g+(d&255)|0]|0;j=e}}while(0);e=j+1&65535;b[4830442]=e;if((a[9660900]&5)==0){return}j=i&255;b[4830442]=((j&128|0)!=0?j|65280:j)+(e&65535)&65535;b[4830442]=c[2415221]&65535;return}function f1m(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=e;break}k=gj[h&4095](e)|0;i=k;j=b[4830442]|0}else{i=a[g+(d&255)|0]|0;j=e}}while(0);e=j+1&65535;b[4830442]=e;if((a[9660900]&1)!=0){return}j=i&255;b[4830442]=((j&128|0)!=0?j|65280:j)+(e&65535)&65535;b[4830442]=c[2415221]&65535;return}function f1n(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=e;break}k=gj[h&4095](e)|0;i=k;j=b[4830442]|0}else{i=a[g+(d&255)|0]|0;j=e}}while(0);e=j+1&65535;b[4830442]=e;if((a[9660900]&1)==0){return}j=i&255;b[4830442]=((j&128|0)!=0?j|65280:j)+(e&65535)&65535;b[4830442]=c[2415221]&65535;return}function f1o(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=e;break}k=gj[h&4095](e)|0;i=k;j=b[4830442]|0}else{i=a[g+(d&255)|0]|0;j=e}}while(0);e=j+1&65535;b[4830442]=e;if((a[9660900]&4)!=0){return}j=i&255;b[4830442]=((j&128|0)!=0?j|65280:j)+(e&65535)&65535;b[4830442]=c[2415221]&65535;return}function f1p(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=e;break}k=gj[h&4095](e)|0;i=k;j=b[4830442]|0}else{i=a[g+(d&255)|0]|0;j=e}}while(0);e=j+1&65535;b[4830442]=e;if((a[9660900]&4)==0){return}j=i&255;b[4830442]=((j&128|0)!=0?j|65280:j)+(e&65535)&65535;b[4830442]=c[2415221]&65535;return}function f1q(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=e;break}k=gj[h&4095](e)|0;i=k;j=b[4830442]|0}else{i=a[g+(d&255)|0]|0;j=e}}while(0);e=j+1&65535;b[4830442]=e;if((a[9660900]&2)!=0){return}j=i&255;b[4830442]=((j&128|0)!=0?j|65280:j)+(e&65535)&65535;b[4830442]=c[2415221]&65535;return}function f1r(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=e;break}k=gj[h&4095](e)|0;i=k;j=b[4830442]|0}else{i=a[g+(d&255)|0]|0;j=e}}while(0);e=j+1&65535;b[4830442]=e;if((a[9660900]&2)==0){return}j=i&255;b[4830442]=((j&128|0)!=0?j|65280:j)+(e&65535)&65535;b[4830442]=c[2415221]&65535;return}function f1s(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=e;break}k=gj[h&4095](e)|0;i=k;j=b[4830442]|0}else{i=a[g+(d&255)|0]|0;j=e}}while(0);e=j+1&65535;b[4830442]=e;if((a[9660900]&8)!=0){return}j=i&255;b[4830442]=((j&128|0)!=0?j|65280:j)+(e&65535)&65535;b[4830442]=c[2415221]&65535;return}function f1t(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=e;break}k=gj[h&4095](e)|0;i=k;j=b[4830442]|0}else{i=a[g+(d&255)|0]|0;j=e}}while(0);e=j+1&65535;b[4830442]=e;if((a[9660900]&8)==0){return}j=i&255;b[4830442]=((j&128|0)!=0?j|65280:j)+(e&65535)&65535;b[4830442]=c[2415221]&65535;return}function f1u(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=c[2415221]|0;f=e&65535;g=c[2437644]|0;h=c[g+72+((e>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+3156>>2]|0;if((i|0)==0){j=0;k=f;break}l=gj[i&4095](f)|0;j=l;k=b[4830442]|0}else{j=a[h+(e&255)|0]|0;k=f}}while(0);f=k+1&65535;b[4830442]=f;k=d[9660900]|0;if(((k<<2^k)&8|0)!=0){return}k=j&255;b[4830442]=((k&128|0)!=0?k|65280:k)+(f&65535)&65535;b[4830442]=c[2415221]&65535;return}function f1v(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=c[2415221]|0;f=e&65535;g=c[2437644]|0;h=c[g+72+((e>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+3156>>2]|0;if((i|0)==0){j=0;k=f;break}l=gj[i&4095](f)|0;j=l;k=b[4830442]|0}else{j=a[h+(e&255)|0]|0;k=f}}while(0);f=k+1&65535;b[4830442]=f;k=d[9660900]|0;if(((k<<2^k)&8|0)==0){return}k=j&255;b[4830442]=((k&128|0)!=0?k|65280:k)+(f&65535)&65535;b[4830442]=c[2415221]&65535;return}function f1w(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=c[2415221]|0;f=e&65535;g=c[2437644]|0;h=c[g+72+((e>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+3156>>2]|0;if((i|0)==0){j=0;k=f;break}l=gj[i&4095](f)|0;j=l;k=b[4830442]|0}else{j=a[h+(e&255)|0]|0;k=f}}while(0);f=k+1&65535;b[4830442]=f;k=d[9660900]|0;if(((k<<2^k)&8|k&4|0)!=0){return}k=j&255;b[4830442]=((k&128|0)!=0?k|65280:k)+(f&65535)&65535;b[4830442]=c[2415221]&65535;return}function f1x(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=c[2415221]|0;f=e&65535;g=c[2437644]|0;h=c[g+72+((e>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+3156>>2]|0;if((i|0)==0){j=0;k=f;break}l=gj[i&4095](f)|0;j=l;k=b[4830442]|0}else{j=a[h+(e&255)|0]|0;k=f}}while(0);f=k+1&65535;b[4830442]=f;k=d[9660900]|0;if(((k<<2^k)&8|k&4|0)==0){return}k=j&255;b[4830442]=((k&128|0)!=0?k|65280:k)+(f&65535)&65535;b[4830442]=c[2415221]&65535;return}function f1y(){b[4830446]=(b[4830444]|0)+1&65535;return}function f1z(){b[4830444]=(b[4830444]|0)+1&65535;return}function f1A(){var d=0,e=0,f=0,g=0;b[4830444]=(b[4830444]|0)+1&65535;d=c[2415222]|0;e=c[2437644]|0;f=c[e+72+((d>>>8&255)<<2)>>2]|0;if((f|0)!=0){g=a[f+(d&255)|0]|0;a[9660897]=g;return}f=c[e+3144>>2]|0;if((f|0)==0){g=0;a[9660897]=g;return}g=gj[f&4095](d&65535)|0;a[9660897]=g;return}function f1B(){var d=0,e=0,f=0,g=0;b[4830444]=(b[4830444]|0)+1&65535;d=c[2415222]|0;e=c[2437644]|0;f=c[e+72+((d>>>8&255)<<2)>>2]|0;if((f|0)!=0){g=a[f+(d&255)|0]|0;a[9660896]=g;return}f=c[e+3144>>2]|0;if((f|0)==0){g=0;a[9660896]=g;return}g=gj[f&4095](d&65535)|0;a[9660896]=g;return}function f1C(){b[4830444]=(b[4830444]|0)-1&65535;return}function f1D(){b[4830444]=(b[4830446]|0)-1&65535;return}function f1E(){var d=0,e=0,f=0,g=0,h=0,i=0;d=c[2415222]|0;e=d&65535;f=a[9660897]|0;g=c[2437644]|0;h=c[g+72+((d>>>8&255|256)<<2)>>2]|0;do{if((h|0)==0){i=c[g+3148>>2]|0;if((i|0)==0){break}gg[i&4095](e,f)}else{a[h+(d&255)|0]=f}}while(0);b[4830444]=(b[4830444]|0)-1&65535;return}function f1F(){var d=0,e=0,f=0,g=0,h=0,i=0;d=c[2415222]|0;e=d&65535;f=a[9660896]|0;g=c[2437644]|0;h=c[g+72+((d>>>8&255|256)<<2)>>2]|0;do{if((h|0)==0){i=c[g+3148>>2]|0;if((i|0)==0){break}gg[i&4095](e,f)}else{a[h+(d&255)|0]=f}}while(0);b[4830444]=(b[4830444]|0)-1&65535;return}function f1G(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b[4830444]=(b[4830444]|0)+1&65535;d=c[2415222]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3144>>2]|0;if((h|0)==0){i=0;j=e;k=f;break}l=gj[h&4095](e)|0;i=l;j=b[4830444]|0;k=c[2437644]|0}else{i=a[g+(d&255)|0]|0;j=e;k=f}}while(0);f=(i&255)<<8;c[2415221]=f;b[4830444]=j+1&65535;j=c[2415222]|0;i=j&65535;e=c[k+72+((j>>>8&255)<<2)>>2]|0;do{if((e|0)==0){d=c[k+3144>>2]|0;if((d|0)==0){m=0;n=f;break}g=gj[d&4095](i)|0;m=g;n=c[2415221]|0}else{m=a[e+(j&255)|0]|0;n=f}}while(0);f=n|m&255;c[2415221]=f;b[4830442]=f&65535;return}function f1H(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;b[4830444]=(b[4830444]|0)+1&65535;e=c[2415222]|0;f=e&65535;g=c[2437644]|0;h=c[g+72+((e>>>8&255)<<2)>>2]|0;do{if((h|0)==0){i=c[g+3144>>2]|0;if((i|0)==0){j=0;k=f;l=g;break}m=gj[i&4095](f)|0;j=m;k=b[4830444]|0;l=c[2437644]|0}else{j=a[h+(e&255)|0]|0;k=f;l=g}}while(0);a[9660900]=j;b[4830444]=k+1&65535;k=c[2415222]|0;j=k&65535;g=c[l+72+((k>>>8&255)<<2)>>2]|0;do{if((g|0)==0){f=c[l+3144>>2]|0;if((f|0)==0){n=0;o=j;p=l;break}e=gj[f&4095](j)|0;n=e;o=b[4830444]|0;p=c[2437644]|0}else{n=a[g+(k&255)|0]|0;o=j;p=l}}while(0);a[9660896]=n;b[4830444]=o+1&65535;o=c[2415222]|0;n=o&65535;l=c[p+72+((o>>>8&255)<<2)>>2]|0;do{if((l|0)==0){j=c[p+3144>>2]|0;if((j|0)==0){q=0;r=n;s=p;break}k=gj[j&4095](n)|0;q=k;r=b[4830444]|0;s=c[2437644]|0}else{q=a[l+(o&255)|0]|0;r=n;s=p}}while(0);a[9660897]=q;b[4830444]=r+1&65535;r=c[2415222]|0;q=r&65535;p=c[s+72+((r>>>8&255)<<2)>>2]|0;do{if((p|0)==0){n=c[s+3144>>2]|0;if((n|0)==0){t=0;u=q;v=s;break}o=gj[n&4095](q)|0;t=o;u=b[4830444]|0;v=c[2437644]|0}else{t=a[p+(r&255)|0]|0;u=q;v=s}}while(0);s=(t&255)<<8;c[2415223]=s;b[4830444]=u+1&65535;u=c[2415222]|0;t=u&65535;q=c[v+72+((u>>>8&255)<<2)>>2]|0;do{if((q|0)==0){r=c[v+3144>>2]|0;if((r|0)==0){w=0;x=s;y=t;z=v;break}p=gj[r&4095](t)|0;w=p;x=c[2415223]|0;y=b[4830444]|0;z=c[2437644]|0}else{w=a[q+(u&255)|0]|0;x=s;y=t;z=v}}while(0);c[2415223]=x|w&255;b[4830444]=y+1&65535;y=c[2415222]|0;w=y&65535;x=c[z+72+((y>>>8&255)<<2)>>2]|0;do{if((x|0)==0){v=c[z+3144>>2]|0;if((v|0)==0){A=0;B=w;C=z;break}t=gj[v&4095](w)|0;A=t;B=b[4830444]|0;C=c[2437644]|0}else{A=a[x+(y&255)|0]|0;B=w;C=z}}while(0);z=(A&255)<<8;c[2415221]=z;b[4830444]=B+1&65535;B=c[2415222]|0;A=B&65535;w=c[C+72+((B>>>8&255)<<2)>>2]|0;do{if((w|0)==0){y=c[C+3144>>2]|0;if((y|0)==0){D=0;E=z;break}x=gj[y&4095](A)|0;D=x;E=c[2415221]|0}else{D=a[w+(B&255)|0]|0;E=z}}while(0);z=E|D&255;c[2415221]=z;b[4830442]=z&65535;if((a[9660900]&16)!=0){return}if((a[9660903]|0)!=0){f00(-8);return}z=d[9660931]|0;if((z&224|0)==0){return}if((z&128|0)!=0){f00(-10);return}if((z&64|0)!=0){f00(-12);return}if((z&32|0)==0){return}f00(-14);return}function f1I(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;a[9660901]=a[9660901]|8;e=c[2415222]|0;f=e&65535;g=a[9660884]|0;h=c[2437644]|0;i=c[h+72+((e>>>8&255|256)<<2)>>2]|0;do{if((i|0)==0){j=c[h+3148>>2]|0;if((j|0)==0){k=h;break}gg[j&4095](f,g);k=c[2437644]|0}else{a[i+(e&255)|0]=g;k=h}}while(0);b[4830444]=(b[4830444]|0)-1&65535;h=c[2415222]|0;g=h&65535;e=a[9660885]|0;i=c[k+72+((h>>>8&255|256)<<2)>>2]|0;do{if((i|0)==0){f=c[k+3148>>2]|0;if((f|0)==0){l=k;break}gg[f&4095](g,e);l=c[2437644]|0}else{a[i+(h&255)|0]=e;l=k}}while(0);b[4830444]=(b[4830444]|0)-1&65535;k=c[2415222]|0;e=k&65535;h=a[9660892]|0;i=c[l+72+((k>>>8&255|256)<<2)>>2]|0;do{if((i|0)==0){g=c[l+3148>>2]|0;if((g|0)==0){m=l;break}gg[g&4095](e,h);m=c[2437644]|0}else{a[i+(k&255)|0]=h;m=l}}while(0);b[4830444]=(b[4830444]|0)-1&65535;l=c[2415222]|0;h=l&65535;k=a[9660893]|0;i=c[m+72+((l>>>8&255|256)<<2)>>2]|0;do{if((i|0)==0){e=c[m+3148>>2]|0;if((e|0)==0){n=m;break}gg[e&4095](h,k);n=c[2437644]|0}else{a[i+(l&255)|0]=k;n=m}}while(0);b[4830444]=(b[4830444]|0)-1&65535;m=c[2415222]|0;k=m&65535;l=a[9660897]|0;i=c[n+72+((m>>>8&255|256)<<2)>>2]|0;do{if((i|0)==0){h=c[n+3148>>2]|0;if((h|0)==0){o=n;break}gg[h&4095](k,l);o=c[2437644]|0}else{a[i+(m&255)|0]=l;o=n}}while(0);b[4830444]=(b[4830444]|0)-1&65535;n=c[2415222]|0;l=n&65535;m=a[9660896]|0;i=c[o+72+((n>>>8&255|256)<<2)>>2]|0;do{if((i|0)==0){k=c[o+3148>>2]|0;if((k|0)==0){p=o;break}gg[k&4095](l,m);p=c[2437644]|0}else{a[i+(n&255)|0]=m;p=o}}while(0);b[4830444]=(b[4830444]|0)-1&65535;o=c[2415222]|0;m=o&65535;n=a[9660900]|0;i=c[p+72+((o>>>8&255|256)<<2)>>2]|0;do{if((i|0)==0){l=c[p+3148>>2]|0;if((l|0)==0){break}gg[l&4095](m,n)}else{a[i+(o&255)|0]=n}}while(0);b[4830444]=(b[4830444]|0)-1&65535;do{if((a[9660900]&16)==0){if((a[9660903]|0)!=0){f00(-8);break}n=d[9660931]|0;if((n&224|0)==0){break}if((n&128|0)!=0){f00(-10);break}if((n&64|0)!=0){f00(-12);break}if((n&32|0)==0){break}f00(-14)}}while(0);if((a[9660901]&8)==0){return}n=c[3528192]|0;o=c[2415234]|0;i=n-o|0;m=c[2440594]|0;p=(i|0)>(m|0)?m:i;if((p|0)<=0){return}c[2440594]=m-p;m=p+o|0;c[2415234]=m;if(m>>>0<n>>>0){return}f03();return}function f1J(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;e=c[2415222]|0;f=e&65535;g=a[9660884]|0;h=c[2437644]|0;i=c[h+72+((e>>>8&255|256)<<2)>>2]|0;do{if((i|0)==0){j=c[h+3148>>2]|0;if((j|0)==0){k=h;break}gg[j&4095](f,g);k=c[2437644]|0}else{a[i+(e&255)|0]=g;k=h}}while(0);b[4830444]=(b[4830444]|0)-1&65535;h=c[2415222]|0;g=h&65535;e=a[9660885]|0;i=c[k+72+((h>>>8&255|256)<<2)>>2]|0;do{if((i|0)==0){f=c[k+3148>>2]|0;if((f|0)==0){l=k;break}gg[f&4095](g,e);l=c[2437644]|0}else{a[i+(h&255)|0]=e;l=k}}while(0);b[4830444]=(b[4830444]|0)-1&65535;k=c[2415222]|0;e=k&65535;h=a[9660892]|0;i=c[l+72+((k>>>8&255|256)<<2)>>2]|0;do{if((i|0)==0){g=c[l+3148>>2]|0;if((g|0)==0){m=l;break}gg[g&4095](e,h);m=c[2437644]|0}else{a[i+(k&255)|0]=h;m=l}}while(0);b[4830444]=(b[4830444]|0)-1&65535;l=c[2415222]|0;h=l&65535;k=a[9660893]|0;i=c[m+72+((l>>>8&255|256)<<2)>>2]|0;do{if((i|0)==0){e=c[m+3148>>2]|0;if((e|0)==0){n=m;break}gg[e&4095](h,k);n=c[2437644]|0}else{a[i+(l&255)|0]=k;n=m}}while(0);b[4830444]=(b[4830444]|0)-1&65535;m=c[2415222]|0;k=m&65535;l=a[9660897]|0;i=c[n+72+((m>>>8&255|256)<<2)>>2]|0;do{if((i|0)==0){h=c[n+3148>>2]|0;if((h|0)==0){o=n;break}gg[h&4095](k,l);o=c[2437644]|0}else{a[i+(m&255)|0]=l;o=n}}while(0);b[4830444]=(b[4830444]|0)-1&65535;n=c[2415222]|0;l=n&65535;m=a[9660896]|0;i=c[o+72+((n>>>8&255|256)<<2)>>2]|0;do{if((i|0)==0){k=c[o+3148>>2]|0;if((k|0)==0){p=o;break}gg[k&4095](l,m);p=c[2437644]|0}else{a[i+(n&255)|0]=m;p=o}}while(0);b[4830444]=(b[4830444]|0)-1&65535;o=c[2415222]|0;m=o&65535;n=a[9660900]|0;i=c[p+72+((o>>>8&255|256)<<2)>>2]|0;do{if((i|0)==0){l=c[p+3148>>2]|0;if((l|0)==0){q=p;break}gg[l&4095](m,n);q=c[2437644]|0}else{a[i+(o&255)|0]=n;q=p}}while(0);b[4830444]=(b[4830444]|0)-1&65535;a[9660900]=a[9660900]|16;p=c[q+1092>>2]|0;do{if((p|0)==0){n=c[q+3144>>2]|0;if((n|0)==0){r=0;s=0;t=r&255;u=t|s;c[2415221]=u;v=u&65535;b[4830442]=v;return}o=gj[n&4095](-6)|0;n=c[2437644]|0;i=c[n+1092>>2]|0;m=(o&255)<<8;if((i|0)!=0){w=i;x=m;break}i=c[n+3144>>2]|0;if((i|0)==0){r=0;s=m;t=r&255;u=t|s;c[2415221]=u;v=u&65535;b[4830442]=v;return}r=gj[i&4095](-5)|0;s=m;t=r&255;u=t|s;c[2415221]=u;v=u&65535;b[4830442]=v;return}else{w=p;x=(d[p+250|0]|0)<<8}}while(0);r=a[w+251|0]|0;s=x;t=r&255;u=t|s;c[2415221]=u;v=u&65535;b[4830442]=v;return}function f1K(){var b=0,c=0,d=0,e=0,f=0;b=a[9660897]|0;c=-(b&255)&65535;d=c&65535;e=(d>>>4&8|a[9660900]&-16&255)&255;f=c&255;a[9660900]=((d^b&255^d>>>1)>>>6&2|d>>>8&1|(f<<24>>24==0?e|4:e)&255)&255;a[9660897]=f;return}function f1L(){var b=0,c=0,d=0;b=a[9660897]|0;c=~b;a[9660897]=c;d=(c&255)>>>4&8|a[9660900]&-15;a[9660900]=(b<<24>>24==-1?d|4:d)|1;return}function f1M(){var b=0,c=0,d=0;b=a[9660897]|0;c=b&1|a[9660900]&-14;a[9660900]=c;d=(b&255)>>>1;a[9660897]=d;if(d<<24>>24!=0){return}a[9660900]=c|4;return}function f1N(){var b=0,c=0,d=0,e=0;b=a[9660900]|0;c=a[9660897]|0;d=(c&255)>>>1|b<<7;e=c&1|b&-14|b<<3&8;a[9660900]=d<<24>>24==0?e|4:e;a[9660897]=d;return}function f1O(){var b=0,c=0,d=0,e=0;b=a[9660897]|0;c=b&1|a[9660900]&-14;d=(b&255)>>>1;e=d<<1&-128|d;a[9660897]=e;d=(b&255)>>>4&8|c;a[9660900]=e<<24>>24==0?d|4:d;return}function f1P(){var b=0,c=0,e=0,f=0;b=(d[9660897]|0)<<1;c=b&65535;e=(c>>>4&8|a[9660900]&-16&255)&255;f=b&255;a[9660900]=((c>>>1^c)>>>6&2|c>>>8|(f<<24>>24==0?e|4:e)&255)&255;a[9660897]=f;return}function f1Q(){var b=0,c=0,e=0,f=0;b=a[9660900]|0;c=b&1|(d[9660897]|0)<<1;e=c&65535;f=(e>>>4&8|b&-16&255)&255;b=c&255;a[9660900]=((e>>>1^e)>>>6&2|e>>>8|(b<<24>>24==0?f|4:f)&255)&255;a[9660897]=b;return}function f1R(){var b=0;b=(a[9660897]|0)-1&255;a[9660897]=b;a[9660900]=a[669184+(b&255)|0]|a[9660900]&-15;return}function f1S(){var b=0;b=(a[9660897]|0)+1&255;a[9660897]=b;a[9660900]=a[668928+(b&255)|0]|a[9660900]&-15;return}function f1T(){var b=0,c=0;b=a[9660897]|0;c=(b&255)>>>4&8|a[9660900]&-16;a[9660900]=b<<24>>24==0?c|4:c;return}function f1U(){a[9660897]=0;a[9660900]=a[9660900]&-16|4;return}function f1V(){var b=0,c=0,d=0,e=0,f=0;b=a[9660896]|0;c=-(b&255)&65535;d=c&65535;e=(d>>>4&8|a[9660900]&-16&255)&255;f=c&255;a[9660900]=((d^b&255^d>>>1)>>>6&2|d>>>8&1|(f<<24>>24==0?e|4:e)&255)&255;a[9660896]=f;return}function f1W(){var b=0,c=0,d=0;b=a[9660896]|0;c=~b;a[9660896]=c;d=(c&255)>>>4&8|a[9660900]&-15;a[9660900]=(b<<24>>24==-1?d|4:d)|1;return}function f1X(){var b=0,c=0,d=0;b=a[9660896]|0;c=b&1|a[9660900]&-14;a[9660900]=c;d=(b&255)>>>1;a[9660896]=d;if(d<<24>>24!=0){return}a[9660900]=c|4;return}function f1Y(){var b=0,c=0,d=0,e=0;b=a[9660900]|0;c=a[9660896]|0;d=(c&255)>>>1|b<<7;e=c&1|b&-14|b<<3&8;a[9660900]=d<<24>>24==0?e|4:e;a[9660896]=d;return}function f1Z(){var b=0,c=0,d=0,e=0;b=a[9660896]|0;c=b&1|a[9660900]&-14;d=(b&255)>>>1;e=d<<1&-128|d;a[9660896]=e;d=(b&255)>>>4&8|c;a[9660900]=e<<24>>24==0?d|4:d;return}function f1_(){var b=0,c=0,e=0,f=0;b=(d[9660896]|0)<<1;c=b&65535;e=(c>>>4&8|a[9660900]&-16&255)&255;f=b&255;a[9660900]=((c>>>1^c)>>>6&2|c>>>8|(f<<24>>24==0?e|4:e)&255)&255;a[9660896]=f;return}function f1$(){var b=0,c=0,e=0,f=0;b=a[9660900]|0;c=b&1|(d[9660896]|0)<<1;e=c&65535;f=(e>>>4&8|b&-16&255)&255;b=c&255;a[9660900]=((e>>>1^e)>>>6&2|e>>>8|(b<<24>>24==0?f|4:f)&255)&255;a[9660896]=b;return}function f10(){var b=0;b=(a[9660896]|0)-1&255;a[9660896]=b;a[9660900]=a[669184+(b&255)|0]|a[9660900]&-15;return}function f11(){var b=0;b=(a[9660896]|0)+1&255;a[9660896]=b;a[9660900]=a[668928+(b&255)|0]|a[9660900]&-15;return}function f12(){var b=0,c=0;b=a[9660896]|0;c=(b&255)>>>4&8|a[9660900]&-16;a[9660900]=b<<24>>24==0?c|4:c;return}function f13(){a[9660896]=0;a[9660900]=a[9660900]&-16|4;return}function f14(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=b[4830446]|0;e=c[2415221]|0;f=e&65535;g=c[2437644]|0;h=c[g+72+((e>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+3156>>2]|0;if((i|0)==0){j=0;k=f;l=g;break}m=gj[i&4095](f)|0;j=m;k=b[4830442]|0;l=c[2437644]|0}else{j=a[h+(e&255)|0]|0;k=f;l=g}}while(0);b[4853736]=(j&255)+d&65535;b[4830442]=k+1&65535;k=c[2426868]|0;d=k&65535;j=c[l+72+((k>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[l+3144>>2]|0;if((g|0)==0){n=0;o=k;p=l;break}f=gj[g&4095](d)|0;n=f;o=c[2426868]|0;p=c[2437644]|0}else{n=a[j+(k&255)|0]|0;o=k;p=l}}while(0);l=n&255;n=-l|0;k=(a[9660900]&-16&255|n>>>4&8)&255;j=n&255;a[9660900]=((l^n^n>>>1)>>>6&2|n>>>8&1|(j<<24>>24==0?k|4:k)&255)&255;k=c[p+72+((o>>>8&255|256)<<2)>>2]|0;if((k|0)!=0){a[k+(o&255)|0]=j;return}k=c[p+3148>>2]|0;if((k|0)==0){return}gg[k&4095](o&65535,j);return}function f15(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=b[4830446]|0;e=c[2415221]|0;f=e&65535;g=c[2437644]|0;h=c[g+72+((e>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+3156>>2]|0;if((i|0)==0){j=0;k=f;l=g;break}m=gj[i&4095](f)|0;j=m;k=b[4830442]|0;l=c[2437644]|0}else{j=a[h+(e&255)|0]|0;k=f;l=g}}while(0);b[4853736]=(j&255)+d&65535;b[4830442]=k+1&65535;k=c[2426868]|0;d=k&65535;j=c[l+72+((k>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[l+3144>>2]|0;if((g|0)==0){n=0;o=k;p=l;break}f=gj[g&4095](d)|0;n=f;o=c[2426868]|0;p=c[2437644]|0}else{n=a[j+(k&255)|0]|0;o=k;p=l}}while(0);l=~n;k=a[9660900]&-15|(l&255)>>>4&8;a[9660900]=(n<<24>>24==-1?k|4:k)|1;k=c[p+72+((o>>>8&255|256)<<2)>>2]|0;if((k|0)!=0){a[k+(o&255)|0]=l;return}k=c[p+3148>>2]|0;if((k|0)==0){return}gg[k&4095](o&65535,l);return}function f16(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=b[4830446]|0;e=c[2415221]|0;f=e&65535;g=c[2437644]|0;h=c[g+72+((e>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+3156>>2]|0;if((i|0)==0){j=0;k=f;l=g;break}m=gj[i&4095](f)|0;j=m;k=b[4830442]|0;l=c[2437644]|0}else{j=a[h+(e&255)|0]|0;k=f;l=g}}while(0);b[4853736]=(j&255)+d&65535;b[4830442]=k+1&65535;k=c[2426868]|0;d=k&65535;j=c[l+72+((k>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[l+3144>>2]|0;if((g|0)==0){n=0;o=k;p=l;break}f=gj[g&4095](d)|0;n=f;o=c[2426868]|0;p=c[2437644]|0}else{n=a[j+(k&255)|0]|0;o=k;p=l}}while(0);l=a[9660900]&-14|n&1;k=(n&255)>>>1;a[9660900]=k<<24>>24==0?l|4:l;l=c[p+72+((o>>>8&255|256)<<2)>>2]|0;if((l|0)!=0){a[l+(o&255)|0]=k;return}l=c[p+3148>>2]|0;if((l|0)==0){return}gg[l&4095](o&65535,k);return}function f17(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=b[4830446]|0;e=c[2415221]|0;f=e&65535;g=c[2437644]|0;h=c[g+72+((e>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+3156>>2]|0;if((i|0)==0){j=0;k=f;l=g;break}m=gj[i&4095](f)|0;j=m;k=b[4830442]|0;l=c[2437644]|0}else{j=a[h+(e&255)|0]|0;k=f;l=g}}while(0);b[4853736]=(j&255)+d&65535;b[4830442]=k+1&65535;k=c[2426868]|0;d=k&65535;j=c[l+72+((k>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[l+3144>>2]|0;if((g|0)==0){n=0;o=k;p=l;break}f=gj[g&4095](d)|0;n=f;o=c[2426868]|0;p=c[2437644]|0}else{n=a[j+(k&255)|0]|0;o=k;p=l}}while(0);l=a[9660900]|0;k=l<<7|(n&255)>>>1;j=l&-14|n&1|l<<3&8;a[9660900]=k<<24>>24==0?j|4:j;j=c[p+72+((o>>>8&255|256)<<2)>>2]|0;if((j|0)!=0){a[j+(o&255)|0]=k;return}j=c[p+3148>>2]|0;if((j|0)==0){return}gg[j&4095](o&65535,k);return}function f18(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=b[4830446]|0;e=c[2415221]|0;f=e&65535;g=c[2437644]|0;h=c[g+72+((e>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+3156>>2]|0;if((i|0)==0){j=0;k=f;l=g;break}m=gj[i&4095](f)|0;j=m;k=b[4830442]|0;l=c[2437644]|0}else{j=a[h+(e&255)|0]|0;k=f;l=g}}while(0);b[4853736]=(j&255)+d&65535;b[4830442]=k+1&65535;k=c[2426868]|0;d=k&65535;j=c[l+72+((k>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[l+3144>>2]|0;if((g|0)==0){n=0;o=k;p=l;break}f=gj[g&4095](d)|0;n=f;o=c[2426868]|0;p=c[2437644]|0}else{n=a[j+(k&255)|0]|0;o=k;p=l}}while(0);l=(n&255)>>>1;k=l<<1&-128|l;l=a[9660900]&-14|n&1|(n&255)>>>4&8;a[9660900]=k<<24>>24==0?l|4:l;l=c[p+72+((o>>>8&255|256)<<2)>>2]|0;if((l|0)!=0){a[l+(o&255)|0]=k;return}l=c[p+3148>>2]|0;if((l|0)==0){return}gg[l&4095](o&65535,k);return}function f19(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=b[4830446]|0;e=c[2415221]|0;f=e&65535;g=c[2437644]|0;h=c[g+72+((e>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+3156>>2]|0;if((i|0)==0){j=0;k=f;l=g;break}m=gj[i&4095](f)|0;j=m;k=b[4830442]|0;l=c[2437644]|0}else{j=a[h+(e&255)|0]|0;k=f;l=g}}while(0);b[4853736]=(j&255)+d&65535;b[4830442]=k+1&65535;k=c[2426868]|0;d=k&65535;j=c[l+72+((k>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[l+3144>>2]|0;if((g|0)==0){n=0;o=k;p=l;break}f=gj[g&4095](d)|0;n=f;o=c[2426868]|0;p=c[2437644]|0}else{n=a[j+(k&255)|0]|0;o=k;p=l}}while(0);l=(n&255)<<1;n=l&65535;k=(n>>>4&8|a[9660900]&-16&255)&255;j=l&255;a[9660900]=((n>>>1^n)>>>6&2|n>>>8|(j<<24>>24==0?k|4:k)&255)&255;k=c[p+72+((o>>>8&255|256)<<2)>>2]|0;if((k|0)!=0){a[k+(o&255)|0]=j;return}k=c[p+3148>>2]|0;if((k|0)==0){return}gg[k&4095](o&65535,j);return}function f2a(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=b[4830446]|0;e=c[2415221]|0;f=e&65535;g=c[2437644]|0;h=c[g+72+((e>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+3156>>2]|0;if((i|0)==0){j=0;k=f;l=g;break}m=gj[i&4095](f)|0;j=m;k=b[4830442]|0;l=c[2437644]|0}else{j=a[h+(e&255)|0]|0;k=f;l=g}}while(0);b[4853736]=(j&255)+d&65535;b[4830442]=k+1&65535;k=c[2426868]|0;d=k&65535;j=c[l+72+((k>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[l+3144>>2]|0;if((g|0)==0){n=0;o=k;p=l;break}f=gj[g&4095](d)|0;n=f;o=c[2426868]|0;p=c[2437644]|0}else{n=a[j+(k&255)|0]|0;o=k;p=l}}while(0);l=a[9660900]|0;k=l&1|(n&255)<<1;n=k&65535;j=(n>>>4&8|l&-16&255)&255;l=k&255;a[9660900]=((n>>>1^n)>>>6&2|n>>>8|(l<<24>>24==0?j|4:j)&255)&255;j=c[p+72+((o>>>8&255|256)<<2)>>2]|0;if((j|0)!=0){a[j+(o&255)|0]=l;return}j=c[p+3148>>2]|0;if((j|0)==0){return}gg[j&4095](o&65535,l);return}function f2b(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=b[4830446]|0;e=c[2415221]|0;f=e&65535;g=c[2437644]|0;h=c[g+72+((e>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+3156>>2]|0;if((i|0)==0){j=0;k=f;l=g;break}m=gj[i&4095](f)|0;j=m;k=b[4830442]|0;l=c[2437644]|0}else{j=a[h+(e&255)|0]|0;k=f;l=g}}while(0);b[4853736]=(j&255)+d&65535;b[4830442]=k+1&65535;k=c[2426868]|0;d=k&65535;j=c[l+72+((k>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[l+3144>>2]|0;if((g|0)==0){n=0;o=k;p=l;break}f=gj[g&4095](d)|0;n=f;o=c[2426868]|0;p=c[2437644]|0}else{n=a[j+(k&255)|0]|0;o=k;p=l}}while(0);l=n-1&255;a[9660900]=a[9660900]&-15|a[669184+(l&255)|0];n=c[p+72+((o>>>8&255|256)<<2)>>2]|0;if((n|0)!=0){a[n+(o&255)|0]=l;return}n=c[p+3148>>2]|0;if((n|0)==0){return}gg[n&4095](o&65535,l);return}function f2c(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=b[4830446]|0;e=c[2415221]|0;f=e&65535;g=c[2437644]|0;h=c[g+72+((e>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+3156>>2]|0;if((i|0)==0){j=0;k=f;l=g;break}m=gj[i&4095](f)|0;j=m;k=b[4830442]|0;l=c[2437644]|0}else{j=a[h+(e&255)|0]|0;k=f;l=g}}while(0);b[4853736]=(j&255)+d&65535;b[4830442]=k+1&65535;k=c[2426868]|0;d=k&65535;j=c[l+72+((k>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[l+3144>>2]|0;if((g|0)==0){n=0;o=k;p=l;break}f=gj[g&4095](d)|0;n=f;o=c[2426868]|0;p=c[2437644]|0}else{n=a[j+(k&255)|0]|0;o=k;p=l}}while(0);l=n+1&255;a[9660900]=a[9660900]&-15|a[668928+(l&255)|0];n=c[p+72+((o>>>8&255|256)<<2)>>2]|0;if((n|0)!=0){a[n+(o&255)|0]=l;return}n=c[p+3148>>2]|0;if((n|0)==0){return}gg[n&4095](o&65535,l);return}function f2d(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=b[4830446]|0;e=c[2415221]|0;f=e&65535;g=c[2437644]|0;h=c[g+72+((e>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+3156>>2]|0;if((i|0)==0){j=0;k=f;l=g;break}m=gj[i&4095](f)|0;j=m;k=b[4830442]|0;l=c[2437644]|0}else{j=a[h+(e&255)|0]|0;k=f;l=g}}while(0);b[4853736]=(j&255)+d&65535;b[4830442]=k+1&65535;k=c[2426868]|0;d=k&65535;j=c[l+72+((k>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[l+3144>>2]|0;if((g|0)==0){n=0;break}n=gj[g&4095](d)|0}else{n=a[j+(k&255)|0]|0}}while(0);k=a[9660900]&-16|(n&255)>>>4&8;a[9660900]=n<<24>>24==0?k|4:k;return}function f2e(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=b[4830446]|0;e=c[2415221]|0;f=e&65535;g=c[2437644]|0;h=c[g+72+((e>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+3156>>2]|0;if((i|0)==0){j=0;break}j=gj[i&4095](f)|0}else{j=a[h+(e&255)|0]|0}}while(0);e=(j&255)+d&65535;b[4853736]=e;b[4830442]=e;b[4830442]=c[2415221]&65535;return}function f2f(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=b[4830446]|0;e=c[2415221]|0;f=e&65535;g=c[2437644]|0;h=c[g+72+((e>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+3156>>2]|0;if((i|0)==0){j=0;k=f;l=g;break}m=gj[i&4095](f)|0;j=m;k=b[4830442]|0;l=c[2437644]|0}else{j=a[h+(e&255)|0]|0;k=f;l=g}}while(0);b[4853736]=(j&255)+d&65535;b[4830442]=k+1&65535;k=c[2426868]|0;d=c[l+72+((k>>>8&255|256)<<2)>>2]|0;if((d|0)!=0){a[d+(k&255)|0]=0;n=a[9660900]|0;o=n&-16;p=o|4;a[9660900]=p;return}d=c[l+3148>>2]|0;if((d|0)==0){n=a[9660900]|0;o=n&-16;p=o|4;a[9660900]=p;return}gg[d&4095](k&65535,0);n=a[9660900]|0;o=n&-16;p=o|4;a[9660900]=p;return}function f2g(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=d;k=f;l=e;break}m=gj[h&4095](e)|0;h=c[2415221]|0;i=m;j=h;k=c[2437644]|0;l=h&65535}else{i=a[g+(d&255)|0]|0;j=d;k=f;l=e}}while(0);e=i&255;i=e<<8;f=j+1|0;j=f&65535;d=c[k+72+((f>>>8&255|512)<<2)>>2]|0;do{if((d|0)==0){g=c[k+3156>>2]|0;if((g|0)==0){n=0;o=l;p=k;break}h=gj[g&4095](j)|0;n=h;o=b[4830442]|0;p=c[2437644]|0}else{n=a[d+(f&255)|0]|0;o=l;p=k}}while(0);k=n&255;n=k|i;c[2426868]=n;b[4830442]=o+2&65535;o=n&65535;i=c[p+72+(e<<2)>>2]|0;do{if((i|0)==0){e=c[p+3144>>2]|0;if((e|0)==0){q=0;r=n;s=p;break}l=gj[e&4095](o)|0;q=l;r=c[2426868]|0;s=c[2437644]|0}else{q=a[i+k|0]|0;r=n;s=p}}while(0);p=q&255;q=-p|0;n=(a[9660900]&-16&255|q>>>4&8)&255;k=q&255;a[9660900]=((p^q^q>>>1)>>>6&2|q>>>8&1|(k<<24>>24==0?n|4:n)&255)&255;n=c[s+72+((r>>>8&255|256)<<2)>>2]|0;if((n|0)!=0){a[n+(r&255)|0]=k;return}n=c[s+3148>>2]|0;if((n|0)==0){return}gg[n&4095](r&65535,k);return}function f2h(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=d;k=f;l=e;break}m=gj[h&4095](e)|0;h=c[2415221]|0;i=m;j=h;k=c[2437644]|0;l=h&65535}else{i=a[g+(d&255)|0]|0;j=d;k=f;l=e}}while(0);e=i&255;i=e<<8;f=j+1|0;j=f&65535;d=c[k+72+((f>>>8&255|512)<<2)>>2]|0;do{if((d|0)==0){g=c[k+3156>>2]|0;if((g|0)==0){n=0;o=l;p=k;break}h=gj[g&4095](j)|0;n=h;o=b[4830442]|0;p=c[2437644]|0}else{n=a[d+(f&255)|0]|0;o=l;p=k}}while(0);k=n&255;n=k|i;c[2426868]=n;b[4830442]=o+2&65535;o=n&65535;i=c[p+72+(e<<2)>>2]|0;do{if((i|0)==0){e=c[p+3144>>2]|0;if((e|0)==0){q=0;r=n;s=p;break}l=gj[e&4095](o)|0;q=l;r=c[2426868]|0;s=c[2437644]|0}else{q=a[i+k|0]|0;r=n;s=p}}while(0);p=~q;n=a[9660900]&-15|(p&255)>>>4&8;a[9660900]=(q<<24>>24==-1?n|4:n)|1;n=c[s+72+((r>>>8&255|256)<<2)>>2]|0;if((n|0)!=0){a[n+(r&255)|0]=p;return}n=c[s+3148>>2]|0;if((n|0)==0){return}gg[n&4095](r&65535,p);return}function f2i(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=d;k=f;l=e;break}m=gj[h&4095](e)|0;h=c[2415221]|0;i=m;j=h;k=c[2437644]|0;l=h&65535}else{i=a[g+(d&255)|0]|0;j=d;k=f;l=e}}while(0);e=i&255;i=e<<8;f=j+1|0;j=f&65535;d=c[k+72+((f>>>8&255|512)<<2)>>2]|0;do{if((d|0)==0){g=c[k+3156>>2]|0;if((g|0)==0){n=0;o=l;p=k;break}h=gj[g&4095](j)|0;n=h;o=b[4830442]|0;p=c[2437644]|0}else{n=a[d+(f&255)|0]|0;o=l;p=k}}while(0);k=n&255;n=k|i;c[2426868]=n;b[4830442]=o+2&65535;o=n&65535;i=c[p+72+(e<<2)>>2]|0;do{if((i|0)==0){e=c[p+3144>>2]|0;if((e|0)==0){q=0;r=n;s=p;break}l=gj[e&4095](o)|0;q=l;r=c[2426868]|0;s=c[2437644]|0}else{q=a[i+k|0]|0;r=n;s=p}}while(0);p=a[9660900]&-14|q&1;n=(q&255)>>>1;a[9660900]=n<<24>>24==0?p|4:p;p=c[s+72+((r>>>8&255|256)<<2)>>2]|0;if((p|0)!=0){a[p+(r&255)|0]=n;return}p=c[s+3148>>2]|0;if((p|0)==0){return}gg[p&4095](r&65535,n);return}function f2j(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=d;k=f;l=e;break}m=gj[h&4095](e)|0;h=c[2415221]|0;i=m;j=h;k=c[2437644]|0;l=h&65535}else{i=a[g+(d&255)|0]|0;j=d;k=f;l=e}}while(0);e=i&255;i=e<<8;f=j+1|0;j=f&65535;d=c[k+72+((f>>>8&255|512)<<2)>>2]|0;do{if((d|0)==0){g=c[k+3156>>2]|0;if((g|0)==0){n=0;o=l;p=k;break}h=gj[g&4095](j)|0;n=h;o=b[4830442]|0;p=c[2437644]|0}else{n=a[d+(f&255)|0]|0;o=l;p=k}}while(0);k=n&255;n=k|i;c[2426868]=n;b[4830442]=o+2&65535;o=n&65535;i=c[p+72+(e<<2)>>2]|0;do{if((i|0)==0){e=c[p+3144>>2]|0;if((e|0)==0){q=0;r=n;s=p;break}l=gj[e&4095](o)|0;q=l;r=c[2426868]|0;s=c[2437644]|0}else{q=a[i+k|0]|0;r=n;s=p}}while(0);p=a[9660900]|0;n=p<<7|(q&255)>>>1;k=p&-14|q&1|p<<3&8;a[9660900]=n<<24>>24==0?k|4:k;k=c[s+72+((r>>>8&255|256)<<2)>>2]|0;if((k|0)!=0){a[k+(r&255)|0]=n;return}k=c[s+3148>>2]|0;if((k|0)==0){return}gg[k&4095](r&65535,n);return}function f2k(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=d;k=f;l=e;break}m=gj[h&4095](e)|0;h=c[2415221]|0;i=m;j=h;k=c[2437644]|0;l=h&65535}else{i=a[g+(d&255)|0]|0;j=d;k=f;l=e}}while(0);e=i&255;i=e<<8;f=j+1|0;j=f&65535;d=c[k+72+((f>>>8&255|512)<<2)>>2]|0;do{if((d|0)==0){g=c[k+3156>>2]|0;if((g|0)==0){n=0;o=l;p=k;break}h=gj[g&4095](j)|0;n=h;o=b[4830442]|0;p=c[2437644]|0}else{n=a[d+(f&255)|0]|0;o=l;p=k}}while(0);k=n&255;n=k|i;c[2426868]=n;b[4830442]=o+2&65535;o=n&65535;i=c[p+72+(e<<2)>>2]|0;do{if((i|0)==0){e=c[p+3144>>2]|0;if((e|0)==0){q=0;r=n;s=p;break}l=gj[e&4095](o)|0;q=l;r=c[2426868]|0;s=c[2437644]|0}else{q=a[i+k|0]|0;r=n;s=p}}while(0);p=(q&255)>>>1;n=p<<1&-128|p;p=a[9660900]&-14|q&1|(q&255)>>>4&8;a[9660900]=n<<24>>24==0?p|4:p;p=c[s+72+((r>>>8&255|256)<<2)>>2]|0;if((p|0)!=0){a[p+(r&255)|0]=n;return}p=c[s+3148>>2]|0;if((p|0)==0){return}gg[p&4095](r&65535,n);return}function f2l(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=d;k=f;l=e;break}m=gj[h&4095](e)|0;h=c[2415221]|0;i=m;j=h;k=c[2437644]|0;l=h&65535}else{i=a[g+(d&255)|0]|0;j=d;k=f;l=e}}while(0);e=i&255;i=e<<8;f=j+1|0;j=f&65535;d=c[k+72+((f>>>8&255|512)<<2)>>2]|0;do{if((d|0)==0){g=c[k+3156>>2]|0;if((g|0)==0){n=0;o=l;p=k;break}h=gj[g&4095](j)|0;n=h;o=b[4830442]|0;p=c[2437644]|0}else{n=a[d+(f&255)|0]|0;o=l;p=k}}while(0);k=n&255;n=k|i;c[2426868]=n;b[4830442]=o+2&65535;o=n&65535;i=c[p+72+(e<<2)>>2]|0;do{if((i|0)==0){e=c[p+3144>>2]|0;if((e|0)==0){q=0;r=n;s=p;break}l=gj[e&4095](o)|0;q=l;r=c[2426868]|0;s=c[2437644]|0}else{q=a[i+k|0]|0;r=n;s=p}}while(0);p=(q&255)<<1;q=p&65535;n=(q>>>4&8|a[9660900]&-16&255)&255;k=p&255;a[9660900]=((q>>>1^q)>>>6&2|q>>>8|(k<<24>>24==0?n|4:n)&255)&255;n=c[s+72+((r>>>8&255|256)<<2)>>2]|0;if((n|0)!=0){a[n+(r&255)|0]=k;return}n=c[s+3148>>2]|0;if((n|0)==0){return}gg[n&4095](r&65535,k);return}function f2m(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=d;k=f;l=e;break}m=gj[h&4095](e)|0;h=c[2415221]|0;i=m;j=h;k=c[2437644]|0;l=h&65535}else{i=a[g+(d&255)|0]|0;j=d;k=f;l=e}}while(0);e=i&255;i=e<<8;f=j+1|0;j=f&65535;d=c[k+72+((f>>>8&255|512)<<2)>>2]|0;do{if((d|0)==0){g=c[k+3156>>2]|0;if((g|0)==0){n=0;o=l;p=k;break}h=gj[g&4095](j)|0;n=h;o=b[4830442]|0;p=c[2437644]|0}else{n=a[d+(f&255)|0]|0;o=l;p=k}}while(0);k=n&255;n=k|i;c[2426868]=n;b[4830442]=o+2&65535;o=n&65535;i=c[p+72+(e<<2)>>2]|0;do{if((i|0)==0){e=c[p+3144>>2]|0;if((e|0)==0){q=0;r=n;s=p;break}l=gj[e&4095](o)|0;q=l;r=c[2426868]|0;s=c[2437644]|0}else{q=a[i+k|0]|0;r=n;s=p}}while(0);p=a[9660900]|0;n=p&1|(q&255)<<1;q=n&65535;k=(q>>>4&8|p&-16&255)&255;p=n&255;a[9660900]=((q>>>1^q)>>>6&2|q>>>8|(p<<24>>24==0?k|4:k)&255)&255;k=c[s+72+((r>>>8&255|256)<<2)>>2]|0;if((k|0)!=0){a[k+(r&255)|0]=p;return}k=c[s+3148>>2]|0;if((k|0)==0){return}gg[k&4095](r&65535,p);return}function f2n(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=d;k=f;l=e;break}m=gj[h&4095](e)|0;h=c[2415221]|0;i=m;j=h;k=c[2437644]|0;l=h&65535}else{i=a[g+(d&255)|0]|0;j=d;k=f;l=e}}while(0);e=i&255;i=e<<8;f=j+1|0;j=f&65535;d=c[k+72+((f>>>8&255|512)<<2)>>2]|0;do{if((d|0)==0){g=c[k+3156>>2]|0;if((g|0)==0){n=0;o=l;p=k;break}h=gj[g&4095](j)|0;n=h;o=b[4830442]|0;p=c[2437644]|0}else{n=a[d+(f&255)|0]|0;o=l;p=k}}while(0);k=n&255;n=k|i;c[2426868]=n;b[4830442]=o+2&65535;o=n&65535;i=c[p+72+(e<<2)>>2]|0;do{if((i|0)==0){e=c[p+3144>>2]|0;if((e|0)==0){q=0;r=n;s=p;break}l=gj[e&4095](o)|0;q=l;r=c[2426868]|0;s=c[2437644]|0}else{q=a[i+k|0]|0;r=n;s=p}}while(0);p=q-1&255;a[9660900]=a[9660900]&-15|a[669184+(p&255)|0];q=c[s+72+((r>>>8&255|256)<<2)>>2]|0;if((q|0)!=0){a[q+(r&255)|0]=p;return}q=c[s+3148>>2]|0;if((q|0)==0){return}gg[q&4095](r&65535,p);return}function f2o(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=d;k=f;l=e;break}m=gj[h&4095](e)|0;h=c[2415221]|0;i=m;j=h;k=c[2437644]|0;l=h&65535}else{i=a[g+(d&255)|0]|0;j=d;k=f;l=e}}while(0);e=i&255;i=e<<8;f=j+1|0;j=f&65535;d=c[k+72+((f>>>8&255|512)<<2)>>2]|0;do{if((d|0)==0){g=c[k+3156>>2]|0;if((g|0)==0){n=0;o=l;p=k;break}h=gj[g&4095](j)|0;n=h;o=b[4830442]|0;p=c[2437644]|0}else{n=a[d+(f&255)|0]|0;o=l;p=k}}while(0);k=n&255;n=k|i;c[2426868]=n;b[4830442]=o+2&65535;o=n&65535;i=c[p+72+(e<<2)>>2]|0;do{if((i|0)==0){e=c[p+3144>>2]|0;if((e|0)==0){q=0;r=n;s=p;break}l=gj[e&4095](o)|0;q=l;r=c[2426868]|0;s=c[2437644]|0}else{q=a[i+k|0]|0;r=n;s=p}}while(0);p=q+1&255;a[9660900]=a[9660900]&-15|a[668928+(p&255)|0];q=c[s+72+((r>>>8&255|256)<<2)>>2]|0;if((q|0)!=0){a[q+(r&255)|0]=p;return}q=c[s+3148>>2]|0;if((q|0)==0){return}gg[q&4095](r&65535,p);return}function f2p(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=d;k=f;l=e;break}m=gj[h&4095](e)|0;h=c[2415221]|0;i=m;j=h;k=c[2437644]|0;l=h&65535}else{i=a[g+(d&255)|0]|0;j=d;k=f;l=e}}while(0);e=i&255;i=e<<8;f=j+1|0;j=f&65535;d=c[k+72+((f>>>8&255|512)<<2)>>2]|0;do{if((d|0)==0){g=c[k+3156>>2]|0;if((g|0)==0){n=0;o=l;p=k;break}h=gj[g&4095](j)|0;n=h;o=b[4830442]|0;p=c[2437644]|0}else{n=a[d+(f&255)|0]|0;o=l;p=k}}while(0);k=n&255;n=k|i;c[2426868]=n;b[4830442]=o+2&65535;o=n&65535;n=c[p+72+(e<<2)>>2]|0;do{if((n|0)==0){e=c[p+3144>>2]|0;if((e|0)==0){q=0;break}q=gj[e&4095](o)|0}else{q=a[n+k|0]|0}}while(0);k=a[9660900]&-16|(q&255)>>>4&8;a[9660900]=q<<24>>24==0?k|4:k;return}function f2q(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=d;k=f;break}l=gj[h&4095](e)|0;i=l;j=c[2415221]|0;k=c[2437644]|0}else{i=a[g+(d&255)|0]|0;j=d;k=f}}while(0);f=(i&255)<<8;i=j+1|0;j=i&65535;d=c[k+72+((i>>>8&255|512)<<2)>>2]|0;do{if((d|0)==0){g=c[k+3156>>2]|0;if((g|0)==0){m=0;break}m=gj[g&4095](j)|0}else{m=a[d+(i&255)|0]|0}}while(0);i=m&255|f;c[2426868]=i;b[4830442]=i&65535;b[4830442]=c[2415221]&65535;return}function f2r(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=d;k=f;l=e;break}m=gj[h&4095](e)|0;h=c[2415221]|0;i=m;j=h;k=c[2437644]|0;l=h&65535}else{i=a[g+(d&255)|0]|0;j=d;k=f;l=e}}while(0);e=i&255;i=e<<8;f=j+1|0;j=f&65535;d=c[k+72+((f>>>8&255|512)<<2)>>2]|0;do{if((d|0)==0){g=c[k+3156>>2]|0;if((g|0)==0){n=0;o=l;p=k;break}h=gj[g&4095](j)|0;n=h;o=b[4830442]|0;p=c[2437644]|0}else{n=a[d+(f&255)|0]|0;o=l;p=k}}while(0);k=n&255;n=k|i;c[2426868]=n;b[4830442]=o+2&65535;o=c[p+72+((e|256)<<2)>>2]|0;if((o|0)!=0){a[o+k|0]=0;q=a[9660900]|0;r=q&-16;s=r|4;a[9660900]=s;return}k=c[p+3148>>2]|0;if((k|0)==0){q=a[9660900]|0;r=q&-16;s=r|4;a[9660900]=s;return}gg[k&4095](n&65535,0);q=a[9660900]|0;r=q&-16;s=r|4;a[9660900]=s;return}function f2s(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=e;break}k=gj[h&4095](e)|0;i=k;j=b[4830442]|0}else{i=a[g+(d&255)|0]|0;j=e}}while(0);b[4830442]=j+1&65535;j=a[9660897]|0;e=(j&255)-(i&255)|0;d=(e>>>4&8|a[9660900]&-16&255)&255;g=e&255;a[9660900]=(((j^i)&255^e^e>>>1)>>>6&2|e>>>8&1|(g<<24>>24==0?d|4:d)&255)&255;a[9660897]=g;return}function f2t(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=e;break}k=gj[h&4095](e)|0;i=k;j=b[4830442]|0}else{i=a[g+(d&255)|0]|0;j=e}}while(0);b[4830442]=j+1&65535;j=a[9660897]|0;e=(j&255)-(i&255)|0;d=(e>>>4&8|a[9660900]&-16&255)&255;a[9660900]=(((j^i)&255^e^e>>>1)>>>6&2|e>>>8&1|((e&255)<<24>>24==0?d|4:d)&255)&255;return}function f2u(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=e;break}k=gj[h&4095](e)|0;i=k;j=b[4830442]|0}else{i=a[g+(d&255)|0]|0;j=e}}while(0);b[4830442]=j+1&65535;j=a[9660897]|0;e=a[9660900]|0;d=(j&255)-(i&255)-(e&1)|0;g=(d>>>4&8|e&-16&255)&255;e=d&255;a[9660900]=((d^(j^i)&255^d>>>1)>>>6&2|d>>>8&1|(e<<24>>24==0?g|4:g)&255)&255;a[9660897]=e;return}function f2v(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=e;break}k=gj[h&4095](e)|0;i=k;j=b[4830442]|0}else{i=a[g+(d&255)|0]|0;j=e}}while(0);b[4830442]=j+1&65535;j=a[9660897]&i;a[9660897]=j;i=(j&255)>>>4&8|a[9660900]&-15;a[9660900]=j<<24>>24==0?i|4:i;return}function f2w(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=e;break}k=gj[h&4095](e)|0;i=k;j=b[4830442]|0}else{i=a[g+(d&255)|0]|0;j=e}}while(0);b[4830442]=j+1&65535;j=a[9660897]&i;i=(j&255)>>>4&8|a[9660900]&-15;a[9660900]=j<<24>>24==0?i|4:i;return}function f2x(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=e;break}k=gj[h&4095](e)|0;i=k;j=b[4830442]|0}else{i=a[g+(d&255)|0]|0;j=e}}while(0);a[9660897]=i;b[4830442]=j+1&65535;j=a[9660900]&-15|(i&255)>>>4&8;a[9660900]=i<<24>>24==0?j|4:j;return}function f2y(){var d=0,e=0,f=0,g=0;d=a[9660897]|0;e=(d&255)>>>4&8|a[9660900]&-15;a[9660900]=d<<24>>24==0?e|4:e;e=b[4830442]|0;b[4830442]=e+1&65535;b[4853736]=e;e=c[2426868]|0;f=c[2437644]|0;g=c[f+72+((e>>>8&255|256)<<2)>>2]|0;if((g|0)!=0){a[g+(e&255)|0]=d;return}g=c[f+3148>>2]|0;if((g|0)==0){return}gg[g&4095](e&65535,d);return}function f2z(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=e;break}k=gj[h&4095](e)|0;i=k;j=b[4830442]|0}else{i=a[g+(d&255)|0]|0;j=e}}while(0);b[4830442]=j+1&65535;j=a[9660897]|0;e=j^i;a[9660897]=e;d=(e&255)>>>4&8|a[9660900]&-15;a[9660900]=j<<24>>24==i<<24>>24?d|4:d;return}function f2A(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=e;break}k=gj[h&4095](e)|0;i=k;j=b[4830442]|0}else{i=a[g+(d&255)|0]|0;j=e}}while(0);b[4830442]=j+1&65535;j=a[9660897]|0;e=a[9660900]|0;d=(j&255)+(i&255)+(e&1)|0;g=(d>>>4&8|e&-48&255)&255;e=d&255;f=d^(j^i)&255;a[9660900]=(f<<1&32|d>>>8&1|(f^d>>>1)>>>6&2|(e<<24>>24==0?g|4:g)&255)&255;a[9660897]=e;return}function f2B(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=e;break}k=gj[h&4095](e)|0;i=k;j=b[4830442]|0}else{i=a[g+(d&255)|0]|0;j=e}}while(0);b[4830442]=j+1&65535;j=a[9660897]|i;a[9660897]=j;i=(j&255)>>>4&8|a[9660900]&-15;a[9660900]=j<<24>>24==0?i|4:i;return}function f2C(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=e;break}k=gj[h&4095](e)|0;i=k;j=b[4830442]|0}else{i=a[g+(d&255)|0]|0;j=e}}while(0);b[4830442]=j+1&65535;j=a[9660897]|0;e=(j&255)+(i&255)|0;d=(e>>>4&8|a[9660900]&-48&255)&255;g=e&255;f=(j^i)&255^e;a[9660900]=(f<<1&32|e>>>8&1|(f^e>>>1)>>>6&2|(g<<24>>24==0?d|4:d)&255)&255;a[9660897]=g;return}function f2D(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=c[2415221]|0;f=d&65535;g=c[2437644]|0;h=c[g+72+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+3156>>2]|0;if((i|0)==0){j=0;k=d;l=g;m=f;break}n=gj[i&4095](f)|0;i=c[2415221]|0;j=n;k=i;l=c[2437644]|0;m=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=g;m=f}}while(0);f=(j&255)<<8;j=k+1|0;k=j&65535;g=c[l+72+((j>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){d=c[l+3156>>2]|0;if((d|0)==0){o=0;p=m;break}h=gj[d&4095](k)|0;o=h;p=b[4830442]|0}else{o=a[g+(j&255)|0]|0;p=m}}while(0);b[4830442]=p+2&65535;p=e[4830446]|0;m=p-(o&255|f)|0;o=(m>>>12&8|a[9660900]&-15&255)&255;a[9660900]=(((m&65535)<<16>>16==0?o|4:o)&255|(p^f^m^m>>>1)>>>14&2)&255;return}function f2E(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=c[2415221]|0;f=d&65535;g=c[2437644]|0;h=c[g+72+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+3156>>2]|0;if((i|0)==0){j=0;k=f;l=g;break}m=gj[i&4095](f)|0;j=m;k=b[4830442]|0;l=c[2437644]|0}else{j=a[h+(d&255)|0]|0;k=f;l=g}}while(0);g=k+1&65535;b[4830442]=g;k=c[2415222]|0;f=k&65535;d=g&255;g=c[l+72+((k>>>8&255|256)<<2)>>2]|0;do{if((g|0)==0){h=c[l+3148>>2]|0;if((h|0)==0){n=l;break}gg[h&4095](f,d);n=c[2437644]|0}else{a[g+(k&255)|0]=d;n=l}}while(0);b[4830444]=(b[4830444]|0)-1&65535;l=c[2415222]|0;d=l&65535;k=a[9660885]|0;g=c[n+72+((l>>>8&255|256)<<2)>>2]|0;do{if((g|0)==0){f=c[n+3148>>2]|0;if((f|0)==0){break}gg[f&4095](d,k)}else{a[g+(l&255)|0]=k}}while(0);b[4830444]=(b[4830444]|0)-1&65535;k=j&255;b[4830442]=(e[4830442]|0)+((k&128|0)!=0?k|65280:k)&65535;b[4830442]=c[2415221]&65535;return}function f2F(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=d;k=f;l=e;break}m=gj[h&4095](e)|0;h=c[2415221]|0;i=m;j=h;k=c[2437644]|0;l=h&65535}else{i=a[g+(d&255)|0]|0;j=d;k=f;l=e}}while(0);e=i&255;i=e<<8;f=j+1|0;j=f&65535;d=c[k+72+((f>>>8&255|512)<<2)>>2]|0;do{if((d|0)==0){g=c[k+3156>>2]|0;if((g|0)==0){n=0;o=l;break}h=gj[g&4095](j)|0;n=h;o=b[4830442]|0}else{n=a[d+(f&255)|0]|0;o=l}}while(0);l=n&255|i;c[2415222]=l;b[4830442]=o+2&65535;o=a[9660900]&-15;a[9660900]=o;i=o&255|e>>>4&8;if((l|0)!=0){p=i&255;a[9660900]=p;return}p=(i|4)&255;a[9660900]=p;return}function f2G(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=a[9660900]&-15;a[9660900]=d;e=b[4830444]|0;f=(e&65535)>>>12&8|d&255;if(e<<16>>16==0){g=(f|4)&255}else{g=f&255}a[9660900]=g;g=b[4830442]|0;b[4853736]=g;b[4830442]=g+2&65535;g=c[2426868]|0;f=g&65535;e=a[9660889]|0;d=c[2437644]|0;h=c[d+72+((g>>>8&255|256)<<2)>>2]|0;do{if((h|0)==0){i=c[d+3148>>2]|0;if((i|0)==0){j=d;break}gg[i&4095](f,e);j=c[2437644]|0}else{a[h+(g&255)|0]=e;j=d}}while(0);d=g+1|0;g=a[9660888]|0;e=c[j+72+((d>>>8&255|256)<<2)>>2]|0;if((e|0)!=0){a[e+(d&255)|0]=g;return}e=c[j+3148>>2]|0;if((e|0)==0){return}gg[e&4095](d&65535,g);return}function f2H(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=e;k=f;break}l=gj[h&4095](e)|0;i=l;j=b[4830442]|0;k=c[2437644]|0}else{i=a[g+(d&255)|0]|0;j=e;k=f}}while(0);f=i&255;c[2426868]=f;b[4830442]=j+1&65535;j=i&255;i=c[k+72>>2]|0;do{if((i|0)==0){e=c[k+3144>>2]|0;if((e|0)==0){m=0;break}m=gj[e&4095](j)|0}else{m=a[i+f|0]|0}}while(0);f=a[9660897]|0;i=(f&255)-(m&255)|0;j=(i>>>4&8|a[9660900]&-16&255)&255;k=i&255;a[9660900]=(((f^m)&255^i^i>>>1)>>>6&2|i>>>8&1|(k<<24>>24==0?j|4:j)&255)&255;a[9660897]=k;return}function f2I(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=e;k=f;break}l=gj[h&4095](e)|0;i=l;j=b[4830442]|0;k=c[2437644]|0}else{i=a[g+(d&255)|0]|0;j=e;k=f}}while(0);f=i&255;c[2426868]=f;b[4830442]=j+1&65535;j=i&255;i=c[k+72>>2]|0;do{if((i|0)==0){e=c[k+3144>>2]|0;if((e|0)==0){m=0;break}m=gj[e&4095](j)|0}else{m=a[i+f|0]|0}}while(0);f=a[9660897]|0;i=(f&255)-(m&255)|0;j=(i>>>4&8|a[9660900]&-16&255)&255;a[9660900]=(((f^m)&255^i^i>>>1)>>>6&2|i>>>8&1|((i&255)<<24>>24==0?j|4:j)&255)&255;return}function f2J(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=e;k=f;break}l=gj[h&4095](e)|0;i=l;j=b[4830442]|0;k=c[2437644]|0}else{i=a[g+(d&255)|0]|0;j=e;k=f}}while(0);f=i&255;c[2426868]=f;b[4830442]=j+1&65535;j=i&255;i=c[k+72>>2]|0;do{if((i|0)==0){e=c[k+3144>>2]|0;if((e|0)==0){m=0;break}m=gj[e&4095](j)|0}else{m=a[i+f|0]|0}}while(0);f=a[9660897]|0;i=a[9660900]|0;j=(f&255)-(m&255)-(i&1)|0;k=(j>>>4&8|i&-16&255)&255;i=j&255;a[9660900]=((j^(f^m)&255^j>>>1)>>>6&2|j>>>8&1|(i<<24>>24==0?k|4:k)&255)&255;a[9660897]=i;return}function f2K(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=e;k=f;break}l=gj[h&4095](e)|0;i=l;j=b[4830442]|0;k=c[2437644]|0}else{i=a[g+(d&255)|0]|0;j=e;k=f}}while(0);f=i&255;c[2426868]=f;b[4830442]=j+1&65535;j=i&255;i=c[k+72>>2]|0;do{if((i|0)==0){e=c[k+3144>>2]|0;if((e|0)==0){m=0;break}m=gj[e&4095](j)|0}else{m=a[i+f|0]|0}}while(0);f=a[9660897]&m;a[9660897]=f;m=(f&255)>>>4&8|a[9660900]&-15;a[9660900]=f<<24>>24==0?m|4:m;return}function f2L(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=e;k=f;break}l=gj[h&4095](e)|0;i=l;j=b[4830442]|0;k=c[2437644]|0}else{i=a[g+(d&255)|0]|0;j=e;k=f}}while(0);f=i&255;c[2426868]=f;b[4830442]=j+1&65535;j=i&255;i=c[k+72>>2]|0;do{if((i|0)==0){e=c[k+3144>>2]|0;if((e|0)==0){m=0;break}m=gj[e&4095](j)|0}else{m=a[i+f|0]|0}}while(0);f=a[9660897]&m;m=(f&255)>>>4&8|a[9660900]&-15;a[9660900]=f<<24>>24==0?m|4:m;return}function f2M(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=e;k=f;break}l=gj[h&4095](e)|0;i=l;j=b[4830442]|0;k=c[2437644]|0}else{i=a[g+(d&255)|0]|0;j=e;k=f}}while(0);f=i&255;c[2426868]=f;b[4830442]=j+1&65535;j=i&255;i=c[k+72>>2]|0;do{if((i|0)==0){e=c[k+3144>>2]|0;if((e|0)==0){m=0;break}m=gj[e&4095](j)|0}else{m=a[i+f|0]|0}}while(0);a[9660897]=m;f=(m&255)>>>4&8|a[9660900]&-15;a[9660900]=m<<24>>24==0?f|4:f;return}function f2N(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=a[9660897]|0;e=(d&255)>>>4&8|a[9660900]&-15;a[9660900]=d<<24>>24==0?e|4:e;e=c[2415221]|0;f=e&65535;g=c[2437644]|0;h=c[g+72+((e>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+3156>>2]|0;if((i|0)==0){j=0;k=f;l=d;m=g;break}n=gj[i&4095](f)|0;j=n;k=b[4830442]|0;l=a[9660897]|0;m=c[2437644]|0}else{j=a[h+(e&255)|0]|0;k=f;l=d;m=g}}while(0);g=j&255;c[2426868]=g;b[4830442]=k+1&65535;k=c[m+1096>>2]|0;if((k|0)!=0){a[k+g|0]=l;return}g=c[m+3148>>2]|0;if((g|0)==0){return}gg[g&4095](j&255,l);return}function f2O(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=e;k=f;break}l=gj[h&4095](e)|0;i=l;j=b[4830442]|0;k=c[2437644]|0}else{i=a[g+(d&255)|0]|0;j=e;k=f}}while(0);f=i&255;c[2426868]=f;b[4830442]=j+1&65535;j=i&255;i=c[k+72>>2]|0;do{if((i|0)==0){e=c[k+3144>>2]|0;if((e|0)==0){m=0;break}m=gj[e&4095](j)|0}else{m=a[i+f|0]|0}}while(0);f=a[9660897]|0;i=f^m;a[9660897]=i;j=(i&255)>>>4&8|a[9660900]&-15;a[9660900]=f<<24>>24==m<<24>>24?j|4:j;return}function f2P(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=e;k=f;break}l=gj[h&4095](e)|0;i=l;j=b[4830442]|0;k=c[2437644]|0}else{i=a[g+(d&255)|0]|0;j=e;k=f}}while(0);f=i&255;c[2426868]=f;b[4830442]=j+1&65535;j=i&255;i=c[k+72>>2]|0;do{if((i|0)==0){e=c[k+3144>>2]|0;if((e|0)==0){m=0;break}m=gj[e&4095](j)|0}else{m=a[i+f|0]|0}}while(0);f=a[9660897]|0;i=a[9660900]|0;j=(f&255)+(m&255)+(i&1)|0;k=(j>>>4&8|i&-48&255)&255;i=j&255;e=j^(f^m)&255;a[9660900]=(e<<1&32|j>>>8&1|(e^j>>>1)>>>6&2|(i<<24>>24==0?k|4:k)&255)&255;a[9660897]=i;return}function f2Q(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=e;k=f;break}l=gj[h&4095](e)|0;i=l;j=b[4830442]|0;k=c[2437644]|0}else{i=a[g+(d&255)|0]|0;j=e;k=f}}while(0);f=i&255;c[2426868]=f;b[4830442]=j+1&65535;j=i&255;i=c[k+72>>2]|0;do{if((i|0)==0){e=c[k+3144>>2]|0;if((e|0)==0){m=0;break}m=gj[e&4095](j)|0}else{m=a[i+f|0]|0}}while(0);f=a[9660897]|m;a[9660897]=f;m=(f&255)>>>4&8|a[9660900]&-15;a[9660900]=f<<24>>24==0?m|4:m;return}function f2R(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=e;k=f;break}l=gj[h&4095](e)|0;i=l;j=b[4830442]|0;k=c[2437644]|0}else{i=a[g+(d&255)|0]|0;j=e;k=f}}while(0);f=i&255;c[2426868]=f;b[4830442]=j+1&65535;j=i&255;i=c[k+72>>2]|0;do{if((i|0)==0){e=c[k+3144>>2]|0;if((e|0)==0){m=0;break}m=gj[e&4095](j)|0}else{m=a[i+f|0]|0}}while(0);f=a[9660897]|0;i=(f&255)+(m&255)|0;j=(i>>>4&8|a[9660900]&-48&255)&255;k=i&255;e=(f^m)&255^i;a[9660900]=(e<<1&32|i>>>8&1|(e^i>>>1)>>>6&2|(k<<24>>24==0?j|4:j)&255)&255;a[9660897]=k;return}function f2S(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=c[2415221]|0;f=d&65535;g=c[2437644]|0;h=c[g+72+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+3156>>2]|0;if((i|0)==0){j=0;k=f;l=g;break}m=gj[i&4095](f)|0;j=m;k=b[4830442]|0;l=c[2437644]|0}else{j=a[h+(d&255)|0]|0;k=f;l=g}}while(0);g=j&255;c[2426868]=g;b[4830442]=k+1&65535;k=j&255;j=c[l+72>>2]|0;do{if((j|0)==0){f=c[l+3144>>2]|0;if((f|0)==0){n=0;o=l;break}d=gj[f&4095](k)|0;n=d;o=c[2437644]|0}else{n=a[j+g|0]|0;o=l}}while(0);l=(n&255)<<8;n=g+1|0;g=n&65535;j=c[o+72+((n>>>8&255)<<2)>>2]|0;do{if((j|0)==0){k=c[o+3144>>2]|0;if((k|0)==0){p=0;break}p=gj[k&4095](g)|0}else{p=a[j+(n&255)|0]|0}}while(0);n=e[4830446]|0;j=n-(p&255|l)|0;p=(j>>>12&8|a[9660900]&-15&255)&255;a[9660900]=(((j&65535)<<16>>16==0?p|4:p)&255|(n^l^j^j>>>1)>>>14&2)&255;return}function f2T(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=e;k=f;break}l=gj[h&4095](e)|0;i=l;j=b[4830442]|0;k=c[2437644]|0}else{i=a[g+(d&255)|0]|0;j=e;k=f}}while(0);c[2426868]=i&255;i=j+1&65535;b[4830442]=i;j=c[2415222]|0;f=j&65535;e=i&255;i=c[k+72+((j>>>8&255|256)<<2)>>2]|0;do{if((i|0)==0){d=c[k+3148>>2]|0;if((d|0)==0){m=k;break}gg[d&4095](f,e);m=c[2437644]|0}else{a[i+(j&255)|0]=e;m=k}}while(0);b[4830444]=(b[4830444]|0)-1&65535;k=c[2415222]|0;e=k&65535;j=a[9660885]|0;i=c[m+72+((k>>>8&255|256)<<2)>>2]|0;do{if((i|0)==0){f=c[m+3148>>2]|0;if((f|0)==0){break}gg[f&4095](e,j)}else{a[i+(k&255)|0]=j}}while(0);b[4830444]=(b[4830444]|0)-1&65535;b[4830442]=b[4853736]|0;b[4830442]=c[2415221]&65535;return}function f2U(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=e;k=f;break}l=gj[h&4095](e)|0;i=l;j=b[4830442]|0;k=c[2437644]|0}else{i=a[g+(d&255)|0]|0;j=e;k=f}}while(0);f=i&255;c[2426868]=f;b[4830442]=j+1&65535;j=i&255;i=c[k+72>>2]|0;do{if((i|0)==0){e=c[k+3144>>2]|0;if((e|0)==0){m=0;n=k;break}d=gj[e&4095](j)|0;m=d;n=c[2437644]|0}else{m=a[i+f|0]|0;n=k}}while(0);k=m&255;m=k<<8;i=f+1|0;f=i&65535;j=c[n+72+((i>>>8&255)<<2)>>2]|0;do{if((j|0)==0){d=c[n+3144>>2]|0;if((d|0)==0){o=0;break}o=gj[d&4095](f)|0}else{o=a[j+(i&255)|0]|0}}while(0);i=o&255|m;c[2415222]=i;m=a[9660900]&-15;a[9660900]=m;o=m&255|k>>>4&8;if((i|0)!=0){p=o&255;a[9660900]=p;return}p=(o|4)&255;a[9660900]=p;return}function f2V(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=a[9660900]&-15;a[9660900]=d;e=b[4830444]|0;f=(e&65535)>>>12&8|d&255;if(e<<16>>16==0){g=(f|4)&255}else{g=f&255}a[9660900]=g;g=c[2415221]|0;f=g&65535;e=c[2437644]|0;d=c[e+72+((g>>>8&255|512)<<2)>>2]|0;do{if((d|0)==0){h=c[e+3156>>2]|0;if((h|0)==0){i=0;j=f;k=e;break}l=gj[h&4095](f)|0;i=l;j=b[4830442]|0;k=c[2437644]|0}else{i=a[d+(g&255)|0]|0;j=f;k=e}}while(0);e=i&255;c[2426868]=e;b[4830442]=j+1&65535;j=i&255;i=a[9660889]|0;f=c[k+1096>>2]|0;do{if((f|0)==0){g=c[k+3148>>2]|0;if((g|0)==0){m=k;break}gg[g&4095](j,i);m=c[2437644]|0}else{a[f+e|0]=i;m=k}}while(0);k=e+1|0;e=a[9660888]|0;i=c[m+72+((k>>>8&255|256)<<2)>>2]|0;if((i|0)!=0){a[i+(k&255)|0]=e;return}i=c[m+3148>>2]|0;if((i|0)==0){return}gg[i&4095](k&65535,e);return}function f2W(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=b[4830446]|0;e=c[2415221]|0;f=e&65535;g=c[2437644]|0;h=c[g+72+((e>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+3156>>2]|0;if((i|0)==0){j=0;k=f;l=g;break}m=gj[i&4095](f)|0;j=m;k=b[4830442]|0;l=c[2437644]|0}else{j=a[h+(e&255)|0]|0;k=f;l=g}}while(0);b[4853736]=(j&255)+d&65535;b[4830442]=k+1&65535;k=c[2426868]|0;d=k&65535;j=c[l+72+((k>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[l+3144>>2]|0;if((g|0)==0){n=0;break}n=gj[g&4095](d)|0}else{n=a[j+(k&255)|0]|0}}while(0);k=a[9660897]|0;j=(k&255)-(n&255)|0;d=(j>>>4&8|a[9660900]&-16&255)&255;l=j&255;a[9660900]=(((k^n)&255^j^j>>>1)>>>6&2|j>>>8&1|(l<<24>>24==0?d|4:d)&255)&255;a[9660897]=l;return}function f2X(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=b[4830446]|0;e=c[2415221]|0;f=e&65535;g=c[2437644]|0;h=c[g+72+((e>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+3156>>2]|0;if((i|0)==0){j=0;k=f;l=g;break}m=gj[i&4095](f)|0;j=m;k=b[4830442]|0;l=c[2437644]|0}else{j=a[h+(e&255)|0]|0;k=f;l=g}}while(0);b[4853736]=(j&255)+d&65535;b[4830442]=k+1&65535;k=c[2426868]|0;d=k&65535;j=c[l+72+((k>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[l+3144>>2]|0;if((g|0)==0){n=0;break}n=gj[g&4095](d)|0}else{n=a[j+(k&255)|0]|0}}while(0);k=a[9660897]|0;j=(k&255)-(n&255)|0;d=(j>>>4&8|a[9660900]&-16&255)&255;a[9660900]=(((k^n)&255^j^j>>>1)>>>6&2|j>>>8&1|((j&255)<<24>>24==0?d|4:d)&255)&255;return}function f2Y(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=b[4830446]|0;e=c[2415221]|0;f=e&65535;g=c[2437644]|0;h=c[g+72+((e>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+3156>>2]|0;if((i|0)==0){j=0;k=f;l=g;break}m=gj[i&4095](f)|0;j=m;k=b[4830442]|0;l=c[2437644]|0}else{j=a[h+(e&255)|0]|0;k=f;l=g}}while(0);b[4853736]=(j&255)+d&65535;b[4830442]=k+1&65535;k=c[2426868]|0;d=k&65535;j=c[l+72+((k>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[l+3144>>2]|0;if((g|0)==0){n=0;break}n=gj[g&4095](d)|0}else{n=a[j+(k&255)|0]|0}}while(0);k=a[9660897]|0;j=a[9660900]|0;d=(k&255)-(n&255)-(j&1)|0;l=(d>>>4&8|j&-16&255)&255;j=d&255;a[9660900]=((d^(k^n)&255^d>>>1)>>>6&2|d>>>8&1|(j<<24>>24==0?l|4:l)&255)&255;a[9660897]=j;return}function f2Z(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=b[4830446]|0;e=c[2415221]|0;f=e&65535;g=c[2437644]|0;h=c[g+72+((e>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+3156>>2]|0;if((i|0)==0){j=0;k=f;l=g;break}m=gj[i&4095](f)|0;j=m;k=b[4830442]|0;l=c[2437644]|0}else{j=a[h+(e&255)|0]|0;k=f;l=g}}while(0);b[4853736]=(j&255)+d&65535;b[4830442]=k+1&65535;k=c[2426868]|0;d=k&65535;j=c[l+72+((k>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[l+3144>>2]|0;if((g|0)==0){n=0;break}n=gj[g&4095](d)|0}else{n=a[j+(k&255)|0]|0}}while(0);k=a[9660897]&n;a[9660897]=k;n=(k&255)>>>4&8|a[9660900]&-15;a[9660900]=k<<24>>24==0?n|4:n;return}function f2_(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=b[4830446]|0;e=c[2415221]|0;f=e&65535;g=c[2437644]|0;h=c[g+72+((e>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+3156>>2]|0;if((i|0)==0){j=0;k=f;l=g;break}m=gj[i&4095](f)|0;j=m;k=b[4830442]|0;l=c[2437644]|0}else{j=a[h+(e&255)|0]|0;k=f;l=g}}while(0);b[4853736]=(j&255)+d&65535;b[4830442]=k+1&65535;k=c[2426868]|0;d=k&65535;j=c[l+72+((k>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[l+3144>>2]|0;if((g|0)==0){n=0;break}n=gj[g&4095](d)|0}else{n=a[j+(k&255)|0]|0}}while(0);k=a[9660897]&n;n=(k&255)>>>4&8|a[9660900]&-15;a[9660900]=k<<24>>24==0?n|4:n;return}function f2$(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=b[4830446]|0;e=c[2415221]|0;f=e&65535;g=c[2437644]|0;h=c[g+72+((e>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+3156>>2]|0;if((i|0)==0){j=0;k=f;l=g;break}m=gj[i&4095](f)|0;j=m;k=b[4830442]|0;l=c[2437644]|0}else{j=a[h+(e&255)|0]|0;k=f;l=g}}while(0);b[4853736]=(j&255)+d&65535;b[4830442]=k+1&65535;k=c[2426868]|0;d=k&65535;j=c[l+72+((k>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[l+3144>>2]|0;if((g|0)==0){n=0;break}n=gj[g&4095](d)|0}else{n=a[j+(k&255)|0]|0}}while(0);a[9660897]=n;k=(n&255)>>>4&8|a[9660900]&-15;a[9660900]=n<<24>>24==0?k|4:k;return}function f20(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=a[9660897]|0;e=(d&255)>>>4&8|a[9660900]&-15;a[9660900]=d<<24>>24==0?e|4:e;e=b[4830446]|0;f=c[2415221]|0;g=f&65535;h=c[2437644]|0;i=c[h+72+((f>>>8&255|512)<<2)>>2]|0;do{if((i|0)==0){j=c[h+3156>>2]|0;if((j|0)==0){k=0;l=g;m=d;n=h;break}o=gj[j&4095](g)|0;k=o;l=b[4830442]|0;m=a[9660897]|0;n=c[2437644]|0}else{k=a[i+(f&255)|0]|0;l=g;m=d;n=h}}while(0);b[4853736]=(k&255)+e&65535;b[4830442]=l+1&65535;l=c[2426868]|0;e=c[n+72+((l>>>8&255|256)<<2)>>2]|0;if((e|0)!=0){a[e+(l&255)|0]=m;return}e=c[n+3148>>2]|0;if((e|0)==0){return}gg[e&4095](l&65535,m);return}function f21(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=b[4830446]|0;e=c[2415221]|0;f=e&65535;g=c[2437644]|0;h=c[g+72+((e>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+3156>>2]|0;if((i|0)==0){j=0;k=f;l=g;break}m=gj[i&4095](f)|0;j=m;k=b[4830442]|0;l=c[2437644]|0}else{j=a[h+(e&255)|0]|0;k=f;l=g}}while(0);b[4853736]=(j&255)+d&65535;b[4830442]=k+1&65535;k=c[2426868]|0;d=k&65535;j=c[l+72+((k>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[l+3144>>2]|0;if((g|0)==0){n=0;break}n=gj[g&4095](d)|0}else{n=a[j+(k&255)|0]|0}}while(0);k=a[9660897]|0;j=k^n;a[9660897]=j;d=(j&255)>>>4&8|a[9660900]&-15;a[9660900]=k<<24>>24==n<<24>>24?d|4:d;return}function f22(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=b[4830446]|0;e=c[2415221]|0;f=e&65535;g=c[2437644]|0;h=c[g+72+((e>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+3156>>2]|0;if((i|0)==0){j=0;k=f;l=g;break}m=gj[i&4095](f)|0;j=m;k=b[4830442]|0;l=c[2437644]|0}else{j=a[h+(e&255)|0]|0;k=f;l=g}}while(0);b[4853736]=(j&255)+d&65535;b[4830442]=k+1&65535;k=c[2426868]|0;d=k&65535;j=c[l+72+((k>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[l+3144>>2]|0;if((g|0)==0){n=0;break}n=gj[g&4095](d)|0}else{n=a[j+(k&255)|0]|0}}while(0);k=a[9660897]|0;j=a[9660900]|0;d=(k&255)+(n&255)+(j&1)|0;l=(d>>>4&8|j&-48&255)&255;j=d&255;g=d^(k^n)&255;a[9660900]=(g<<1&32|d>>>8&1|(g^d>>>1)>>>6&2|(j<<24>>24==0?l|4:l)&255)&255;a[9660897]=j;return}function f23(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=b[4830446]|0;e=c[2415221]|0;f=e&65535;g=c[2437644]|0;h=c[g+72+((e>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+3156>>2]|0;if((i|0)==0){j=0;k=f;l=g;break}m=gj[i&4095](f)|0;j=m;k=b[4830442]|0;l=c[2437644]|0}else{j=a[h+(e&255)|0]|0;k=f;l=g}}while(0);b[4853736]=(j&255)+d&65535;b[4830442]=k+1&65535;k=c[2426868]|0;d=k&65535;j=c[l+72+((k>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[l+3144>>2]|0;if((g|0)==0){n=0;break}n=gj[g&4095](d)|0}else{n=a[j+(k&255)|0]|0}}while(0);k=a[9660897]|n;a[9660897]=k;n=(k&255)>>>4&8|a[9660900]&-15;a[9660900]=k<<24>>24==0?n|4:n;return}function f24(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=b[4830446]|0;e=c[2415221]|0;f=e&65535;g=c[2437644]|0;h=c[g+72+((e>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+3156>>2]|0;if((i|0)==0){j=0;k=f;l=g;break}m=gj[i&4095](f)|0;j=m;k=b[4830442]|0;l=c[2437644]|0}else{j=a[h+(e&255)|0]|0;k=f;l=g}}while(0);b[4853736]=(j&255)+d&65535;b[4830442]=k+1&65535;k=c[2426868]|0;d=k&65535;j=c[l+72+((k>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[l+3144>>2]|0;if((g|0)==0){n=0;break}n=gj[g&4095](d)|0}else{n=a[j+(k&255)|0]|0}}while(0);k=a[9660897]|0;j=(k&255)+(n&255)|0;d=(j>>>4&8|a[9660900]&-48&255)&255;l=j&255;g=(k^n)&255^j;a[9660900]=(g<<1&32|j>>>8&1|(g^j>>>1)>>>6&2|(l<<24>>24==0?d|4:d)&255)&255;a[9660897]=l;return}function f25(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=b[4830446]|0;f=c[2415221]|0;g=f&65535;h=c[2437644]|0;i=c[h+72+((f>>>8&255|512)<<2)>>2]|0;do{if((i|0)==0){j=c[h+3156>>2]|0;if((j|0)==0){k=0;l=g;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830442]|0;m=c[2437644]|0}else{k=a[i+(f&255)|0]|0;l=g;m=h}}while(0);b[4853736]=(k&255)+d&65535;b[4830442]=l+1&65535;l=c[2426868]|0;d=l&65535;k=c[m+72+((l>>>8&255)<<2)>>2]|0;do{if((k|0)==0){h=c[m+3144>>2]|0;if((h|0)==0){o=0;p=m;break}g=gj[h&4095](d)|0;o=g;p=c[2437644]|0}else{o=a[k+(l&255)|0]|0;p=m}}while(0);m=(o&255)<<8;o=l+1|0;l=o&65535;k=c[p+72+((o>>>8&255)<<2)>>2]|0;do{if((k|0)==0){d=c[p+3144>>2]|0;if((d|0)==0){q=0;break}q=gj[d&4095](l)|0}else{q=a[k+(o&255)|0]|0}}while(0);o=e[4830446]|0;k=o-(q&255|m)|0;q=(k>>>12&8|a[9660900]&-15&255)&255;a[9660900]=(((k&65535)<<16>>16==0?q|4:q)&255|(o^m^k^k>>>1)>>>14&2)&255;return}function f26(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=b[4830446]|0;e=c[2415221]|0;f=e&65535;g=c[2437644]|0;h=c[g+72+((e>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+3156>>2]|0;if((i|0)==0){j=0;k=f;l=g;break}m=gj[i&4095](f)|0;j=m;k=b[4830442]|0;l=c[2437644]|0}else{j=a[h+(e&255)|0]|0;k=f;l=g}}while(0);b[4853736]=(j&255)+d&65535;d=k+1&65535;b[4830442]=d;k=c[2415222]|0;j=k&65535;g=d&255;d=c[l+72+((k>>>8&255|256)<<2)>>2]|0;do{if((d|0)==0){f=c[l+3148>>2]|0;if((f|0)==0){n=l;break}gg[f&4095](j,g);n=c[2437644]|0}else{a[d+(k&255)|0]=g;n=l}}while(0);b[4830444]=(b[4830444]|0)-1&65535;l=c[2415222]|0;g=l&65535;k=a[9660885]|0;d=c[n+72+((l>>>8&255|256)<<2)>>2]|0;do{if((d|0)==0){j=c[n+3148>>2]|0;if((j|0)==0){break}gg[j&4095](g,k)}else{a[d+(l&255)|0]=k}}while(0);b[4830444]=(b[4830444]|0)-1&65535;b[4830442]=b[4853736]|0;b[4830442]=c[2415221]&65535;return}function f27(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=b[4830446]|0;e=c[2415221]|0;f=e&65535;g=c[2437644]|0;h=c[g+72+((e>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+3156>>2]|0;if((i|0)==0){j=0;k=f;l=g;break}m=gj[i&4095](f)|0;j=m;k=b[4830442]|0;l=c[2437644]|0}else{j=a[h+(e&255)|0]|0;k=f;l=g}}while(0);b[4853736]=(j&255)+d&65535;b[4830442]=k+1&65535;k=c[2426868]|0;d=k&65535;j=c[l+72+((k>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[l+3144>>2]|0;if((g|0)==0){n=0;o=l;break}f=gj[g&4095](d)|0;n=f;o=c[2437644]|0}else{n=a[j+(k&255)|0]|0;o=l}}while(0);l=n&255;n=l<<8;j=k+1|0;k=j&65535;d=c[o+72+((j>>>8&255)<<2)>>2]|0;do{if((d|0)==0){f=c[o+3144>>2]|0;if((f|0)==0){p=0;break}p=gj[f&4095](k)|0}else{p=a[d+(j&255)|0]|0}}while(0);j=p&255|n;c[2415222]=j;n=a[9660900]&-15;a[9660900]=n;p=n&255|l>>>4&8;if((j|0)!=0){q=p&255;a[9660900]=q;return}q=(p|4)&255;a[9660900]=q;return}function f28(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=a[9660900]&-15;a[9660900]=d;e=b[4830444]|0;f=(e&65535)>>>12&8|d&255;if(e<<16>>16==0){g=(f|4)&255}else{g=f&255}a[9660900]=g;g=b[4830446]|0;f=c[2415221]|0;e=f&65535;d=c[2437644]|0;h=c[d+72+((f>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[d+3156>>2]|0;if((i|0)==0){j=0;k=e;l=d;break}m=gj[i&4095](e)|0;j=m;k=b[4830442]|0;l=c[2437644]|0}else{j=a[h+(f&255)|0]|0;k=e;l=d}}while(0);b[4853736]=(j&255)+g&65535;b[4830442]=k+1&65535;k=c[2426868]|0;g=k&65535;j=a[9660889]|0;d=c[l+72+((k>>>8&255|256)<<2)>>2]|0;do{if((d|0)==0){e=c[l+3148>>2]|0;if((e|0)==0){n=l;break}gg[e&4095](g,j);n=c[2437644]|0}else{a[d+(k&255)|0]=j;n=l}}while(0);l=k+1|0;k=a[9660888]|0;j=c[n+72+((l>>>8&255|256)<<2)>>2]|0;if((j|0)!=0){a[j+(l&255)|0]=k;return}j=c[n+3148>>2]|0;if((j|0)==0){return}gg[j&4095](l&65535,k);return}function f29(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=d;k=f;l=e;break}m=gj[h&4095](e)|0;h=c[2415221]|0;i=m;j=h;k=c[2437644]|0;l=h&65535}else{i=a[g+(d&255)|0]|0;j=d;k=f;l=e}}while(0);e=i&255;i=e<<8;f=j+1|0;j=f&65535;d=c[k+72+((f>>>8&255|512)<<2)>>2]|0;do{if((d|0)==0){g=c[k+3156>>2]|0;if((g|0)==0){n=0;o=l;p=k;break}h=gj[g&4095](j)|0;n=h;o=b[4830442]|0;p=c[2437644]|0}else{n=a[d+(f&255)|0]|0;o=l;p=k}}while(0);k=n&255;n=k|i;c[2426868]=n;b[4830442]=o+2&65535;o=n&65535;n=c[p+72+(e<<2)>>2]|0;do{if((n|0)==0){e=c[p+3144>>2]|0;if((e|0)==0){q=0;break}q=gj[e&4095](o)|0}else{q=a[n+k|0]|0}}while(0);k=a[9660897]|0;n=(k&255)-(q&255)|0;o=(n>>>4&8|a[9660900]&-16&255)&255;p=n&255;a[9660900]=(((k^q)&255^n^n>>>1)>>>6&2|n>>>8&1|(p<<24>>24==0?o|4:o)&255)&255;a[9660897]=p;return}function f3a(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=d;k=f;l=e;break}m=gj[h&4095](e)|0;h=c[2415221]|0;i=m;j=h;k=c[2437644]|0;l=h&65535}else{i=a[g+(d&255)|0]|0;j=d;k=f;l=e}}while(0);e=i&255;i=e<<8;f=j+1|0;j=f&65535;d=c[k+72+((f>>>8&255|512)<<2)>>2]|0;do{if((d|0)==0){g=c[k+3156>>2]|0;if((g|0)==0){n=0;o=l;p=k;break}h=gj[g&4095](j)|0;n=h;o=b[4830442]|0;p=c[2437644]|0}else{n=a[d+(f&255)|0]|0;o=l;p=k}}while(0);k=n&255;n=k|i;c[2426868]=n;b[4830442]=o+2&65535;o=n&65535;n=c[p+72+(e<<2)>>2]|0;do{if((n|0)==0){e=c[p+3144>>2]|0;if((e|0)==0){q=0;break}q=gj[e&4095](o)|0}else{q=a[n+k|0]|0}}while(0);k=a[9660897]|0;n=(k&255)-(q&255)|0;o=(n>>>4&8|a[9660900]&-16&255)&255;a[9660900]=(((k^q)&255^n^n>>>1)>>>6&2|n>>>8&1|((n&255)<<24>>24==0?o|4:o)&255)&255;return}function f3b(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=d;k=f;l=e;break}m=gj[h&4095](e)|0;h=c[2415221]|0;i=m;j=h;k=c[2437644]|0;l=h&65535}else{i=a[g+(d&255)|0]|0;j=d;k=f;l=e}}while(0);e=i&255;i=e<<8;f=j+1|0;j=f&65535;d=c[k+72+((f>>>8&255|512)<<2)>>2]|0;do{if((d|0)==0){g=c[k+3156>>2]|0;if((g|0)==0){n=0;o=l;p=k;break}h=gj[g&4095](j)|0;n=h;o=b[4830442]|0;p=c[2437644]|0}else{n=a[d+(f&255)|0]|0;o=l;p=k}}while(0);k=n&255;n=k|i;c[2426868]=n;b[4830442]=o+2&65535;o=n&65535;n=c[p+72+(e<<2)>>2]|0;do{if((n|0)==0){e=c[p+3144>>2]|0;if((e|0)==0){q=0;break}q=gj[e&4095](o)|0}else{q=a[n+k|0]|0}}while(0);k=a[9660897]|0;n=a[9660900]|0;o=(k&255)-(q&255)-(n&1)|0;p=(o>>>4&8|n&-16&255)&255;n=o&255;a[9660900]=((o^(k^q)&255^o>>>1)>>>6&2|o>>>8&1|(n<<24>>24==0?p|4:p)&255)&255;a[9660897]=n;return}function f3c(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=d;k=f;l=e;break}m=gj[h&4095](e)|0;h=c[2415221]|0;i=m;j=h;k=c[2437644]|0;l=h&65535}else{i=a[g+(d&255)|0]|0;j=d;k=f;l=e}}while(0);e=i&255;i=e<<8;f=j+1|0;j=f&65535;d=c[k+72+((f>>>8&255|512)<<2)>>2]|0;do{if((d|0)==0){g=c[k+3156>>2]|0;if((g|0)==0){n=0;o=l;p=k;break}h=gj[g&4095](j)|0;n=h;o=b[4830442]|0;p=c[2437644]|0}else{n=a[d+(f&255)|0]|0;o=l;p=k}}while(0);k=n&255;n=k|i;c[2426868]=n;b[4830442]=o+2&65535;o=n&65535;n=c[p+72+(e<<2)>>2]|0;do{if((n|0)==0){e=c[p+3144>>2]|0;if((e|0)==0){q=0;break}q=gj[e&4095](o)|0}else{q=a[n+k|0]|0}}while(0);k=a[9660897]&q;a[9660897]=k;q=(k&255)>>>4&8|a[9660900]&-15;a[9660900]=k<<24>>24==0?q|4:q;return}function f3d(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=d;k=f;l=e;break}m=gj[h&4095](e)|0;h=c[2415221]|0;i=m;j=h;k=c[2437644]|0;l=h&65535}else{i=a[g+(d&255)|0]|0;j=d;k=f;l=e}}while(0);e=i&255;i=e<<8;f=j+1|0;j=f&65535;d=c[k+72+((f>>>8&255|512)<<2)>>2]|0;do{if((d|0)==0){g=c[k+3156>>2]|0;if((g|0)==0){n=0;o=l;p=k;break}h=gj[g&4095](j)|0;n=h;o=b[4830442]|0;p=c[2437644]|0}else{n=a[d+(f&255)|0]|0;o=l;p=k}}while(0);k=n&255;n=k|i;c[2426868]=n;b[4830442]=o+2&65535;o=n&65535;n=c[p+72+(e<<2)>>2]|0;do{if((n|0)==0){e=c[p+3144>>2]|0;if((e|0)==0){q=0;break}q=gj[e&4095](o)|0}else{q=a[n+k|0]|0}}while(0);k=a[9660897]&q;q=(k&255)>>>4&8|a[9660900]&-15;a[9660900]=k<<24>>24==0?q|4:q;return}function f3e(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=d;k=f;l=e;break}m=gj[h&4095](e)|0;h=c[2415221]|0;i=m;j=h;k=c[2437644]|0;l=h&65535}else{i=a[g+(d&255)|0]|0;j=d;k=f;l=e}}while(0);e=i&255;i=e<<8;f=j+1|0;j=f&65535;d=c[k+72+((f>>>8&255|512)<<2)>>2]|0;do{if((d|0)==0){g=c[k+3156>>2]|0;if((g|0)==0){n=0;o=l;p=k;break}h=gj[g&4095](j)|0;n=h;o=b[4830442]|0;p=c[2437644]|0}else{n=a[d+(f&255)|0]|0;o=l;p=k}}while(0);k=n&255;n=k|i;c[2426868]=n;b[4830442]=o+2&65535;o=n&65535;n=c[p+72+(e<<2)>>2]|0;do{if((n|0)==0){e=c[p+3144>>2]|0;if((e|0)==0){q=0;break}q=gj[e&4095](o)|0}else{q=a[n+k|0]|0}}while(0);a[9660897]=q;k=(q&255)>>>4&8|a[9660900]&-15;a[9660900]=q<<24>>24==0?k|4:k;return}function f3f(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=a[9660897]|0;e=(d&255)>>>4&8|a[9660900]&-15;a[9660900]=d<<24>>24==0?e|4:e;e=c[2415221]|0;d=e&65535;f=c[2437644]|0;g=c[f+72+((e>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=e;k=f;l=d;break}m=gj[h&4095](d)|0;h=c[2415221]|0;i=m;j=h;k=c[2437644]|0;l=h&65535}else{i=a[g+(e&255)|0]|0;j=e;k=f;l=d}}while(0);d=i&255;i=d<<8;f=j+1|0;j=f&65535;e=c[k+72+((f>>>8&255|512)<<2)>>2]|0;do{if((e|0)==0){g=c[k+3156>>2]|0;if((g|0)==0){n=0;o=l;p=k;break}h=gj[g&4095](j)|0;n=h;o=b[4830442]|0;p=c[2437644]|0}else{n=a[e+(f&255)|0]|0;o=l;p=k}}while(0);k=n&255;n=k|i;c[2426868]=n;b[4830442]=o+2&65535;o=a[9660897]|0;i=c[p+72+((d|256)<<2)>>2]|0;if((i|0)!=0){a[i+k|0]=o;return}k=c[p+3148>>2]|0;if((k|0)==0){return}gg[k&4095](n&65535,o);return}function f3g(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=d;k=f;l=e;break}m=gj[h&4095](e)|0;h=c[2415221]|0;i=m;j=h;k=c[2437644]|0;l=h&65535}else{i=a[g+(d&255)|0]|0;j=d;k=f;l=e}}while(0);e=i&255;i=e<<8;f=j+1|0;j=f&65535;d=c[k+72+((f>>>8&255|512)<<2)>>2]|0;do{if((d|0)==0){g=c[k+3156>>2]|0;if((g|0)==0){n=0;o=l;p=k;break}h=gj[g&4095](j)|0;n=h;o=b[4830442]|0;p=c[2437644]|0}else{n=a[d+(f&255)|0]|0;o=l;p=k}}while(0);k=n&255;n=k|i;c[2426868]=n;b[4830442]=o+2&65535;o=n&65535;n=c[p+72+(e<<2)>>2]|0;do{if((n|0)==0){e=c[p+3144>>2]|0;if((e|0)==0){q=0;break}q=gj[e&4095](o)|0}else{q=a[n+k|0]|0}}while(0);k=a[9660897]|0;n=k^q;a[9660897]=n;o=(n&255)>>>4&8|a[9660900]&-15;a[9660900]=k<<24>>24==q<<24>>24?o|4:o;return}function f3h(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=d;k=f;l=e;break}m=gj[h&4095](e)|0;h=c[2415221]|0;i=m;j=h;k=c[2437644]|0;l=h&65535}else{i=a[g+(d&255)|0]|0;j=d;k=f;l=e}}while(0);e=i&255;i=e<<8;f=j+1|0;j=f&65535;d=c[k+72+((f>>>8&255|512)<<2)>>2]|0;do{if((d|0)==0){g=c[k+3156>>2]|0;if((g|0)==0){n=0;o=l;p=k;break}h=gj[g&4095](j)|0;n=h;o=b[4830442]|0;p=c[2437644]|0}else{n=a[d+(f&255)|0]|0;o=l;p=k}}while(0);k=n&255;n=k|i;c[2426868]=n;b[4830442]=o+2&65535;o=n&65535;n=c[p+72+(e<<2)>>2]|0;do{if((n|0)==0){e=c[p+3144>>2]|0;if((e|0)==0){q=0;break}q=gj[e&4095](o)|0}else{q=a[n+k|0]|0}}while(0);k=a[9660897]|0;n=a[9660900]|0;o=(k&255)+(q&255)+(n&1)|0;p=(o>>>4&8|n&-48&255)&255;n=o&255;e=o^(k^q)&255;a[9660900]=(e<<1&32|o>>>8&1|(e^o>>>1)>>>6&2|(n<<24>>24==0?p|4:p)&255)&255;a[9660897]=n;return}function f3i(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=d;k=f;l=e;break}m=gj[h&4095](e)|0;h=c[2415221]|0;i=m;j=h;k=c[2437644]|0;l=h&65535}else{i=a[g+(d&255)|0]|0;j=d;k=f;l=e}}while(0);e=i&255;i=e<<8;f=j+1|0;j=f&65535;d=c[k+72+((f>>>8&255|512)<<2)>>2]|0;do{if((d|0)==0){g=c[k+3156>>2]|0;if((g|0)==0){n=0;o=l;p=k;break}h=gj[g&4095](j)|0;n=h;o=b[4830442]|0;p=c[2437644]|0}else{n=a[d+(f&255)|0]|0;o=l;p=k}}while(0);k=n&255;n=k|i;c[2426868]=n;b[4830442]=o+2&65535;o=n&65535;n=c[p+72+(e<<2)>>2]|0;do{if((n|0)==0){e=c[p+3144>>2]|0;if((e|0)==0){q=0;break}q=gj[e&4095](o)|0}else{q=a[n+k|0]|0}}while(0);k=a[9660897]|q;a[9660897]=k;q=(k&255)>>>4&8|a[9660900]&-15;a[9660900]=k<<24>>24==0?q|4:q;return}function f3j(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=d;k=f;l=e;break}m=gj[h&4095](e)|0;h=c[2415221]|0;i=m;j=h;k=c[2437644]|0;l=h&65535}else{i=a[g+(d&255)|0]|0;j=d;k=f;l=e}}while(0);e=i&255;i=e<<8;f=j+1|0;j=f&65535;d=c[k+72+((f>>>8&255|512)<<2)>>2]|0;do{if((d|0)==0){g=c[k+3156>>2]|0;if((g|0)==0){n=0;o=l;p=k;break}h=gj[g&4095](j)|0;n=h;o=b[4830442]|0;p=c[2437644]|0}else{n=a[d+(f&255)|0]|0;o=l;p=k}}while(0);k=n&255;n=k|i;c[2426868]=n;b[4830442]=o+2&65535;o=n&65535;n=c[p+72+(e<<2)>>2]|0;do{if((n|0)==0){e=c[p+3144>>2]|0;if((e|0)==0){q=0;break}q=gj[e&4095](o)|0}else{q=a[n+k|0]|0}}while(0);k=a[9660897]|0;n=(k&255)+(q&255)|0;o=(n>>>4&8|a[9660900]&-48&255)&255;p=n&255;e=(k^q)&255^n;a[9660900]=(e<<1&32|n>>>8&1|(e^n>>>1)>>>6&2|(p<<24>>24==0?o|4:o)&255)&255;a[9660897]=p;return}function f3k(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=c[2415221]|0;f=d&65535;g=c[2437644]|0;h=c[g+72+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+3156>>2]|0;if((i|0)==0){j=0;k=d;l=g;m=f;break}n=gj[i&4095](f)|0;i=c[2415221]|0;j=n;k=i;l=c[2437644]|0;m=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=g;m=f}}while(0);f=j&255;j=f<<8;g=k+1|0;k=g&65535;d=c[l+72+((g>>>8&255|512)<<2)>>2]|0;do{if((d|0)==0){h=c[l+3156>>2]|0;if((h|0)==0){o=0;p=m;q=l;break}i=gj[h&4095](k)|0;o=i;p=b[4830442]|0;q=c[2437644]|0}else{o=a[d+(g&255)|0]|0;p=m;q=l}}while(0);l=o&255;o=l|j;c[2426868]=o;b[4830442]=p+2&65535;p=o&65535;j=c[q+72+(f<<2)>>2]|0;do{if((j|0)==0){f=c[q+3144>>2]|0;if((f|0)==0){r=0;s=q;break}m=gj[f&4095](p)|0;r=m;s=c[2437644]|0}else{r=a[j+l|0]|0;s=q}}while(0);q=(r&255)<<8;r=o+1|0;o=r&65535;l=c[s+72+((r>>>8&255)<<2)>>2]|0;do{if((l|0)==0){j=c[s+3144>>2]|0;if((j|0)==0){t=0;break}t=gj[j&4095](o)|0}else{t=a[l+(r&255)|0]|0}}while(0);r=e[4830446]|0;l=r-(t&255|q)|0;t=(l>>>12&8|a[9660900]&-15&255)&255;a[9660900]=(((l&65535)<<16>>16==0?t|4:t)&255|(r^q^l^l>>>1)>>>14&2)&255;return}function f3l(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=d;k=f;l=e;break}m=gj[h&4095](e)|0;h=c[2415221]|0;i=m;j=h;k=c[2437644]|0;l=h&65535}else{i=a[g+(d&255)|0]|0;j=d;k=f;l=e}}while(0);e=(i&255)<<8;i=j+1|0;j=i&65535;f=c[k+72+((i>>>8&255|512)<<2)>>2]|0;do{if((f|0)==0){d=c[k+3156>>2]|0;if((d|0)==0){n=0;o=l;p=k;break}g=gj[d&4095](j)|0;n=g;o=b[4830442]|0;p=c[2437644]|0}else{n=a[f+(i&255)|0]|0;o=l;p=k}}while(0);c[2426868]=n&255|e;e=o+2&65535;b[4830442]=e;o=c[2415222]|0;n=o&65535;k=e&255;e=c[p+72+((o>>>8&255|256)<<2)>>2]|0;do{if((e|0)==0){l=c[p+3148>>2]|0;if((l|0)==0){q=p;break}gg[l&4095](n,k);q=c[2437644]|0}else{a[e+(o&255)|0]=k;q=p}}while(0);b[4830444]=(b[4830444]|0)-1&65535;p=c[2415222]|0;k=p&65535;o=a[9660885]|0;e=c[q+72+((p>>>8&255|256)<<2)>>2]|0;do{if((e|0)==0){n=c[q+3148>>2]|0;if((n|0)==0){break}gg[n&4095](k,o)}else{a[e+(p&255)|0]=o}}while(0);b[4830444]=(b[4830444]|0)-1&65535;b[4830442]=b[4853736]|0;b[4830442]=c[2415221]&65535;return}function f3m(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=d;k=f;l=e;break}m=gj[h&4095](e)|0;h=c[2415221]|0;i=m;j=h;k=c[2437644]|0;l=h&65535}else{i=a[g+(d&255)|0]|0;j=d;k=f;l=e}}while(0);e=i&255;i=e<<8;f=j+1|0;j=f&65535;d=c[k+72+((f>>>8&255|512)<<2)>>2]|0;do{if((d|0)==0){g=c[k+3156>>2]|0;if((g|0)==0){n=0;o=l;p=k;break}h=gj[g&4095](j)|0;n=h;o=b[4830442]|0;p=c[2437644]|0}else{n=a[d+(f&255)|0]|0;o=l;p=k}}while(0);k=n&255;n=k|i;c[2426868]=n;b[4830442]=o+2&65535;o=n&65535;i=c[p+72+(e<<2)>>2]|0;do{if((i|0)==0){e=c[p+3144>>2]|0;if((e|0)==0){q=0;r=p;break}l=gj[e&4095](o)|0;q=l;r=c[2437644]|0}else{q=a[i+k|0]|0;r=p}}while(0);p=q&255;q=p<<8;k=n+1|0;n=k&65535;i=c[r+72+((k>>>8&255)<<2)>>2]|0;do{if((i|0)==0){o=c[r+3144>>2]|0;if((o|0)==0){s=0;break}s=gj[o&4095](n)|0}else{s=a[i+(k&255)|0]|0}}while(0);k=s&255|q;c[2415222]=k;q=a[9660900]&-15;a[9660900]=q;s=q&255|p>>>4&8;if((k|0)!=0){t=s&255;a[9660900]=t;return}t=(s|4)&255;a[9660900]=t;return}function f3n(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=a[9660900]&-15;a[9660900]=d;e=b[4830444]|0;f=(e&65535)>>>12&8|d&255;if(e<<16>>16==0){g=(f|4)&255}else{g=f&255}a[9660900]=g;g=c[2415221]|0;f=g&65535;e=c[2437644]|0;d=c[e+72+((g>>>8&255|512)<<2)>>2]|0;do{if((d|0)==0){h=c[e+3156>>2]|0;if((h|0)==0){i=0;j=g;k=e;l=f;break}m=gj[h&4095](f)|0;h=c[2415221]|0;i=m;j=h;k=c[2437644]|0;l=h&65535}else{i=a[d+(g&255)|0]|0;j=g;k=e;l=f}}while(0);f=i&255;i=f<<8;e=j+1|0;j=e&65535;g=c[k+72+((e>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){d=c[k+3156>>2]|0;if((d|0)==0){n=0;o=l;p=k;break}h=gj[d&4095](j)|0;n=h;o=b[4830442]|0;p=c[2437644]|0}else{n=a[g+(e&255)|0]|0;o=l;p=k}}while(0);k=n&255;n=k|i;c[2426868]=n;b[4830442]=o+2&65535;o=n&65535;i=a[9660889]|0;l=c[p+72+((f|256)<<2)>>2]|0;do{if((l|0)==0){f=c[p+3148>>2]|0;if((f|0)==0){q=p;break}gg[f&4095](o,i);q=c[2437644]|0}else{a[l+k|0]=i;q=p}}while(0);p=n+1|0;n=a[9660888]|0;i=c[q+72+((p>>>8&255|256)<<2)>>2]|0;if((i|0)!=0){a[i+(p&255)|0]=n;return}i=c[q+3148>>2]|0;if((i|0)==0){return}gg[i&4095](p&65535,n);return}function f3o(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=e;break}k=gj[h&4095](e)|0;i=k;j=b[4830442]|0}else{i=a[g+(d&255)|0]|0;j=e}}while(0);b[4830442]=j+1&65535;j=a[9660896]|0;e=(j&255)-(i&255)|0;d=(e>>>4&8|a[9660900]&-16&255)&255;g=e&255;a[9660900]=(((j^i)&255^e^e>>>1)>>>6&2|e>>>8&1|(g<<24>>24==0?d|4:d)&255)&255;a[9660896]=g;return}function f3p(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=e;break}k=gj[h&4095](e)|0;i=k;j=b[4830442]|0}else{i=a[g+(d&255)|0]|0;j=e}}while(0);b[4830442]=j+1&65535;j=a[9660896]|0;e=(j&255)-(i&255)|0;d=(e>>>4&8|a[9660900]&-16&255)&255;a[9660900]=(((j^i)&255^e^e>>>1)>>>6&2|e>>>8&1|((e&255)<<24>>24==0?d|4:d)&255)&255;return}function f3q(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=e;break}k=gj[h&4095](e)|0;i=k;j=b[4830442]|0}else{i=a[g+(d&255)|0]|0;j=e}}while(0);b[4830442]=j+1&65535;j=a[9660896]|0;e=a[9660900]|0;d=(j&255)-(i&255)-(e&1)|0;g=(d>>>4&8|e&-16&255)&255;e=d&255;a[9660900]=((d^(j^i)&255^d>>>1)>>>6&2|d>>>8&1|(e<<24>>24==0?g|4:g)&255)&255;a[9660896]=e;return}function f3r(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=e;break}k=gj[h&4095](e)|0;i=k;j=b[4830442]|0}else{i=a[g+(d&255)|0]|0;j=e}}while(0);b[4830442]=j+1&65535;j=a[9660896]&i;a[9660896]=j;i=(j&255)>>>4&8|a[9660900]&-15;a[9660900]=j<<24>>24==0?i|4:i;return}function f3s(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=e;break}k=gj[h&4095](e)|0;i=k;j=b[4830442]|0}else{i=a[g+(d&255)|0]|0;j=e}}while(0);b[4830442]=j+1&65535;j=a[9660896]&i;i=(j&255)>>>4&8|a[9660900]&-15;a[9660900]=j<<24>>24==0?i|4:i;return}function f3t(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=e;break}k=gj[h&4095](e)|0;i=k;j=b[4830442]|0}else{i=a[g+(d&255)|0]|0;j=e}}while(0);a[9660896]=i;b[4830442]=j+1&65535;j=a[9660900]&-15|(i&255)>>>4&8;a[9660900]=i<<24>>24==0?j|4:j;return}function f3u(){var d=0,e=0,f=0,g=0;d=a[9660896]|0;e=(d&255)>>>4&8|a[9660900]&-15;a[9660900]=d<<24>>24==0?e|4:e;e=b[4830442]|0;b[4830442]=e+1&65535;b[4853736]=e;e=c[2426868]|0;f=c[2437644]|0;g=c[f+72+((e>>>8&255|256)<<2)>>2]|0;if((g|0)!=0){a[g+(e&255)|0]=d;return}g=c[f+3148>>2]|0;if((g|0)==0){return}gg[g&4095](e&65535,d);return}function f3v(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=e;break}k=gj[h&4095](e)|0;i=k;j=b[4830442]|0}else{i=a[g+(d&255)|0]|0;j=e}}while(0);b[4830442]=j+1&65535;j=a[9660896]|0;e=j^i;a[9660896]=e;d=(e&255)>>>4&8|a[9660900]&-15;a[9660900]=j<<24>>24==i<<24>>24?d|4:d;return}function f3w(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=e;break}k=gj[h&4095](e)|0;i=k;j=b[4830442]|0}else{i=a[g+(d&255)|0]|0;j=e}}while(0);b[4830442]=j+1&65535;j=a[9660896]|0;e=a[9660900]|0;d=(j&255)+(i&255)+(e&1)|0;g=(d>>>4&8|e&-48&255)&255;e=d&255;f=d^(j^i)&255;a[9660900]=(f<<1&32|d>>>8&1|(f^d>>>1)>>>6&2|(e<<24>>24==0?g|4:g)&255)&255;a[9660896]=e;return}function f3x(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=e;break}k=gj[h&4095](e)|0;i=k;j=b[4830442]|0}else{i=a[g+(d&255)|0]|0;j=e}}while(0);b[4830442]=j+1&65535;j=a[9660896]|i;a[9660896]=j;i=(j&255)>>>4&8|a[9660900]&-15;a[9660900]=j<<24>>24==0?i|4:i;return}function f3y(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=e;break}k=gj[h&4095](e)|0;i=k;j=b[4830442]|0}else{i=a[g+(d&255)|0]|0;j=e}}while(0);b[4830442]=j+1&65535;j=a[9660896]|0;e=(j&255)+(i&255)|0;d=(e>>>4&8|a[9660900]&-48&255)&255;g=e&255;f=(j^i)&255^e;a[9660900]=(f<<1&32|e>>>8&1|(f^e>>>1)>>>6&2|(g<<24>>24==0?d|4:d)&255)&255;a[9660896]=g;return}function f3z(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=d;k=f;l=e;break}m=gj[h&4095](e)|0;h=c[2415221]|0;i=m;j=h;k=c[2437644]|0;l=h&65535}else{i=a[g+(d&255)|0]|0;j=d;k=f;l=e}}while(0);e=i&255;i=e<<8;f=j+1|0;j=f&65535;d=c[k+72+((f>>>8&255|512)<<2)>>2]|0;do{if((d|0)==0){g=c[k+3156>>2]|0;if((g|0)==0){n=0;o=l;break}h=gj[g&4095](j)|0;n=h;o=b[4830442]|0}else{n=a[d+(f&255)|0]|0;o=l}}while(0);l=n&255|i;c[2415223]=l;b[4830442]=o+2&65535;o=a[9660900]&-15;a[9660900]=o;i=o&255|e>>>4&8;if((l|0)!=0){p=i&255;a[9660900]=p;return}p=(i|4)&255;a[9660900]=p;return}function f3A(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=a[9660900]&-15;a[9660900]=d;e=b[4830446]|0;f=(e&65535)>>>12&8|d&255;if(e<<16>>16==0){g=(f|4)&255}else{g=f&255}a[9660900]=g;g=b[4830442]|0;b[4853736]=g;b[4830442]=g+2&65535;g=c[2426868]|0;f=g&65535;e=a[9660893]|0;d=c[2437644]|0;h=c[d+72+((g>>>8&255|256)<<2)>>2]|0;do{if((h|0)==0){i=c[d+3148>>2]|0;if((i|0)==0){j=d;break}gg[i&4095](f,e);j=c[2437644]|0}else{a[h+(g&255)|0]=e;j=d}}while(0);d=g+1|0;g=a[9660892]|0;e=c[j+72+((d>>>8&255|256)<<2)>>2]|0;if((e|0)!=0){a[e+(d&255)|0]=g;return}e=c[j+3148>>2]|0;if((e|0)==0){return}gg[e&4095](d&65535,g);return}function f3B(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=e;k=f;break}l=gj[h&4095](e)|0;i=l;j=b[4830442]|0;k=c[2437644]|0}else{i=a[g+(d&255)|0]|0;j=e;k=f}}while(0);f=i&255;c[2426868]=f;b[4830442]=j+1&65535;j=i&255;i=c[k+72>>2]|0;do{if((i|0)==0){e=c[k+3144>>2]|0;if((e|0)==0){m=0;break}m=gj[e&4095](j)|0}else{m=a[i+f|0]|0}}while(0);f=a[9660896]|0;i=(f&255)-(m&255)|0;j=(i>>>4&8|a[9660900]&-16&255)&255;k=i&255;a[9660900]=(((f^m)&255^i^i>>>1)>>>6&2|i>>>8&1|(k<<24>>24==0?j|4:j)&255)&255;a[9660896]=k;return}function f3C(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=e;k=f;break}l=gj[h&4095](e)|0;i=l;j=b[4830442]|0;k=c[2437644]|0}else{i=a[g+(d&255)|0]|0;j=e;k=f}}while(0);f=i&255;c[2426868]=f;b[4830442]=j+1&65535;j=i&255;i=c[k+72>>2]|0;do{if((i|0)==0){e=c[k+3144>>2]|0;if((e|0)==0){m=0;break}m=gj[e&4095](j)|0}else{m=a[i+f|0]|0}}while(0);f=a[9660896]|0;i=(f&255)-(m&255)|0;j=(i>>>4&8|a[9660900]&-16&255)&255;a[9660900]=(((f^m)&255^i^i>>>1)>>>6&2|i>>>8&1|((i&255)<<24>>24==0?j|4:j)&255)&255;return}function f3D(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=e;k=f;break}l=gj[h&4095](e)|0;i=l;j=b[4830442]|0;k=c[2437644]|0}else{i=a[g+(d&255)|0]|0;j=e;k=f}}while(0);f=i&255;c[2426868]=f;b[4830442]=j+1&65535;j=i&255;i=c[k+72>>2]|0;do{if((i|0)==0){e=c[k+3144>>2]|0;if((e|0)==0){m=0;break}m=gj[e&4095](j)|0}else{m=a[i+f|0]|0}}while(0);f=a[9660896]|0;i=a[9660900]|0;j=(f&255)-(m&255)-(i&1)|0;k=(j>>>4&8|i&-16&255)&255;i=j&255;a[9660900]=((j^(f^m)&255^j>>>1)>>>6&2|j>>>8&1|(i<<24>>24==0?k|4:k)&255)&255;a[9660896]=i;return}function f3E(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=e;k=f;break}l=gj[h&4095](e)|0;i=l;j=b[4830442]|0;k=c[2437644]|0}else{i=a[g+(d&255)|0]|0;j=e;k=f}}while(0);f=i&255;c[2426868]=f;b[4830442]=j+1&65535;j=i&255;i=c[k+72>>2]|0;do{if((i|0)==0){e=c[k+3144>>2]|0;if((e|0)==0){m=0;break}m=gj[e&4095](j)|0}else{m=a[i+f|0]|0}}while(0);f=a[9660896]&m;a[9660896]=f;m=(f&255)>>>4&8|a[9660900]&-15;a[9660900]=f<<24>>24==0?m|4:m;return}function f3F(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=e;k=f;break}l=gj[h&4095](e)|0;i=l;j=b[4830442]|0;k=c[2437644]|0}else{i=a[g+(d&255)|0]|0;j=e;k=f}}while(0);f=i&255;c[2426868]=f;b[4830442]=j+1&65535;j=i&255;i=c[k+72>>2]|0;do{if((i|0)==0){e=c[k+3144>>2]|0;if((e|0)==0){m=0;break}m=gj[e&4095](j)|0}else{m=a[i+f|0]|0}}while(0);f=a[9660896]&m;m=(f&255)>>>4&8|a[9660900]&-15;a[9660900]=f<<24>>24==0?m|4:m;return}function f3G(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=e;k=f;break}l=gj[h&4095](e)|0;i=l;j=b[4830442]|0;k=c[2437644]|0}else{i=a[g+(d&255)|0]|0;j=e;k=f}}while(0);f=i&255;c[2426868]=f;b[4830442]=j+1&65535;j=i&255;i=c[k+72>>2]|0;do{if((i|0)==0){e=c[k+3144>>2]|0;if((e|0)==0){m=0;break}m=gj[e&4095](j)|0}else{m=a[i+f|0]|0}}while(0);a[9660896]=m;f=(m&255)>>>4&8|a[9660900]&-15;a[9660900]=m<<24>>24==0?f|4:f;return}function f3H(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=a[9660896]|0;e=(d&255)>>>4&8|a[9660900]&-15;a[9660900]=d<<24>>24==0?e|4:e;e=c[2415221]|0;f=e&65535;g=c[2437644]|0;h=c[g+72+((e>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+3156>>2]|0;if((i|0)==0){j=0;k=f;l=d;m=g;break}n=gj[i&4095](f)|0;j=n;k=b[4830442]|0;l=a[9660896]|0;m=c[2437644]|0}else{j=a[h+(e&255)|0]|0;k=f;l=d;m=g}}while(0);g=j&255;c[2426868]=g;b[4830442]=k+1&65535;k=c[m+1096>>2]|0;if((k|0)!=0){a[k+g|0]=l;return}g=c[m+3148>>2]|0;if((g|0)==0){return}gg[g&4095](j&255,l);return}function f3I(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=e;k=f;break}l=gj[h&4095](e)|0;i=l;j=b[4830442]|0;k=c[2437644]|0}else{i=a[g+(d&255)|0]|0;j=e;k=f}}while(0);f=i&255;c[2426868]=f;b[4830442]=j+1&65535;j=i&255;i=c[k+72>>2]|0;do{if((i|0)==0){e=c[k+3144>>2]|0;if((e|0)==0){m=0;break}m=gj[e&4095](j)|0}else{m=a[i+f|0]|0}}while(0);f=a[9660896]|0;i=f^m;a[9660896]=i;j=(i&255)>>>4&8|a[9660900]&-15;a[9660900]=f<<24>>24==m<<24>>24?j|4:j;return}function f3J(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=e;k=f;break}l=gj[h&4095](e)|0;i=l;j=b[4830442]|0;k=c[2437644]|0}else{i=a[g+(d&255)|0]|0;j=e;k=f}}while(0);f=i&255;c[2426868]=f;b[4830442]=j+1&65535;j=i&255;i=c[k+72>>2]|0;do{if((i|0)==0){e=c[k+3144>>2]|0;if((e|0)==0){m=0;break}m=gj[e&4095](j)|0}else{m=a[i+f|0]|0}}while(0);f=a[9660896]|0;i=a[9660900]|0;j=(f&255)+(m&255)+(i&1)|0;k=(j>>>4&8|i&-48&255)&255;i=j&255;e=j^(f^m)&255;a[9660900]=(e<<1&32|j>>>8&1|(e^j>>>1)>>>6&2|(i<<24>>24==0?k|4:k)&255)&255;a[9660896]=i;return}function f3K(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=e;k=f;break}l=gj[h&4095](e)|0;i=l;j=b[4830442]|0;k=c[2437644]|0}else{i=a[g+(d&255)|0]|0;j=e;k=f}}while(0);f=i&255;c[2426868]=f;b[4830442]=j+1&65535;j=i&255;i=c[k+72>>2]|0;do{if((i|0)==0){e=c[k+3144>>2]|0;if((e|0)==0){m=0;break}m=gj[e&4095](j)|0}else{m=a[i+f|0]|0}}while(0);f=a[9660896]|m;a[9660896]=f;m=(f&255)>>>4&8|a[9660900]&-15;a[9660900]=f<<24>>24==0?m|4:m;return}function f3L(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=e;k=f;break}l=gj[h&4095](e)|0;i=l;j=b[4830442]|0;k=c[2437644]|0}else{i=a[g+(d&255)|0]|0;j=e;k=f}}while(0);f=i&255;c[2426868]=f;b[4830442]=j+1&65535;j=i&255;i=c[k+72>>2]|0;do{if((i|0)==0){e=c[k+3144>>2]|0;if((e|0)==0){m=0;break}m=gj[e&4095](j)|0}else{m=a[i+f|0]|0}}while(0);f=a[9660896]|0;i=(f&255)+(m&255)|0;j=(i>>>4&8|a[9660900]&-48&255)&255;k=i&255;e=(f^m)&255^i;a[9660900]=(e<<1&32|i>>>8&1|(e^i>>>1)>>>6&2|(k<<24>>24==0?j|4:j)&255)&255;a[9660896]=k;return}function f3M(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=e;k=f;break}l=gj[h&4095](e)|0;i=l;j=b[4830442]|0;k=c[2437644]|0}else{i=a[g+(d&255)|0]|0;j=e;k=f}}while(0);f=i&255;c[2426868]=f;b[4830442]=j+1&65535;j=i&255;i=c[k+72>>2]|0;do{if((i|0)==0){e=c[k+3144>>2]|0;if((e|0)==0){m=0;n=k;break}d=gj[e&4095](j)|0;m=d;n=c[2437644]|0}else{m=a[i+f|0]|0;n=k}}while(0);k=m&255;m=k<<8;i=f+1|0;f=i&65535;j=c[n+72+((i>>>8&255)<<2)>>2]|0;do{if((j|0)==0){d=c[n+3144>>2]|0;if((d|0)==0){o=0;break}o=gj[d&4095](f)|0}else{o=a[j+(i&255)|0]|0}}while(0);i=o&255|m;c[2415223]=i;m=a[9660900]&-15;a[9660900]=m;o=m&255|k>>>4&8;if((i|0)!=0){p=o&255;a[9660900]=p;return}p=(o|4)&255;a[9660900]=p;return}function f3N(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=a[9660900]&-15;a[9660900]=d;e=b[4830446]|0;f=(e&65535)>>>12&8|d&255;if(e<<16>>16==0){g=(f|4)&255}else{g=f&255}a[9660900]=g;g=c[2415221]|0;f=g&65535;e=c[2437644]|0;d=c[e+72+((g>>>8&255|512)<<2)>>2]|0;do{if((d|0)==0){h=c[e+3156>>2]|0;if((h|0)==0){i=0;j=f;k=e;break}l=gj[h&4095](f)|0;i=l;j=b[4830442]|0;k=c[2437644]|0}else{i=a[d+(g&255)|0]|0;j=f;k=e}}while(0);e=i&255;c[2426868]=e;b[4830442]=j+1&65535;j=i&255;i=a[9660893]|0;f=c[k+1096>>2]|0;do{if((f|0)==0){g=c[k+3148>>2]|0;if((g|0)==0){m=k;break}gg[g&4095](j,i);m=c[2437644]|0}else{a[f+e|0]=i;m=k}}while(0);k=e+1|0;e=a[9660892]|0;i=c[m+72+((k>>>8&255|256)<<2)>>2]|0;if((i|0)!=0){a[i+(k&255)|0]=e;return}i=c[m+3148>>2]|0;if((i|0)==0){return}gg[i&4095](k&65535,e);return}function f3O(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=b[4830446]|0;e=c[2415221]|0;f=e&65535;g=c[2437644]|0;h=c[g+72+((e>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+3156>>2]|0;if((i|0)==0){j=0;k=f;l=g;break}m=gj[i&4095](f)|0;j=m;k=b[4830442]|0;l=c[2437644]|0}else{j=a[h+(e&255)|0]|0;k=f;l=g}}while(0);b[4853736]=(j&255)+d&65535;b[4830442]=k+1&65535;k=c[2426868]|0;d=k&65535;j=c[l+72+((k>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[l+3144>>2]|0;if((g|0)==0){n=0;break}n=gj[g&4095](d)|0}else{n=a[j+(k&255)|0]|0}}while(0);k=a[9660896]|0;j=(k&255)-(n&255)|0;d=(j>>>4&8|a[9660900]&-16&255)&255;l=j&255;a[9660900]=(((k^n)&255^j^j>>>1)>>>6&2|j>>>8&1|(l<<24>>24==0?d|4:d)&255)&255;a[9660896]=l;return}function f3P(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=b[4830446]|0;e=c[2415221]|0;f=e&65535;g=c[2437644]|0;h=c[g+72+((e>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+3156>>2]|0;if((i|0)==0){j=0;k=f;l=g;break}m=gj[i&4095](f)|0;j=m;k=b[4830442]|0;l=c[2437644]|0}else{j=a[h+(e&255)|0]|0;k=f;l=g}}while(0);b[4853736]=(j&255)+d&65535;b[4830442]=k+1&65535;k=c[2426868]|0;d=k&65535;j=c[l+72+((k>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[l+3144>>2]|0;if((g|0)==0){n=0;break}n=gj[g&4095](d)|0}else{n=a[j+(k&255)|0]|0}}while(0);k=a[9660896]|0;j=(k&255)-(n&255)|0;d=(j>>>4&8|a[9660900]&-16&255)&255;a[9660900]=(((k^n)&255^j^j>>>1)>>>6&2|j>>>8&1|((j&255)<<24>>24==0?d|4:d)&255)&255;return}function f3Q(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=b[4830446]|0;e=c[2415221]|0;f=e&65535;g=c[2437644]|0;h=c[g+72+((e>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+3156>>2]|0;if((i|0)==0){j=0;k=f;l=g;break}m=gj[i&4095](f)|0;j=m;k=b[4830442]|0;l=c[2437644]|0}else{j=a[h+(e&255)|0]|0;k=f;l=g}}while(0);b[4853736]=(j&255)+d&65535;b[4830442]=k+1&65535;k=c[2426868]|0;d=k&65535;j=c[l+72+((k>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[l+3144>>2]|0;if((g|0)==0){n=0;break}n=gj[g&4095](d)|0}else{n=a[j+(k&255)|0]|0}}while(0);k=a[9660896]|0;j=a[9660900]|0;d=(k&255)-(n&255)-(j&1)|0;l=(d>>>4&8|j&-16&255)&255;j=d&255;a[9660900]=((d^(k^n)&255^d>>>1)>>>6&2|d>>>8&1|(j<<24>>24==0?l|4:l)&255)&255;a[9660896]=j;return}function f3R(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=b[4830446]|0;e=c[2415221]|0;f=e&65535;g=c[2437644]|0;h=c[g+72+((e>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+3156>>2]|0;if((i|0)==0){j=0;k=f;l=g;break}m=gj[i&4095](f)|0;j=m;k=b[4830442]|0;l=c[2437644]|0}else{j=a[h+(e&255)|0]|0;k=f;l=g}}while(0);b[4853736]=(j&255)+d&65535;b[4830442]=k+1&65535;k=c[2426868]|0;d=k&65535;j=c[l+72+((k>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[l+3144>>2]|0;if((g|0)==0){n=0;break}n=gj[g&4095](d)|0}else{n=a[j+(k&255)|0]|0}}while(0);k=a[9660896]&n;a[9660896]=k;n=(k&255)>>>4&8|a[9660900]&-15;a[9660900]=k<<24>>24==0?n|4:n;return}function f3S(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=b[4830446]|0;e=c[2415221]|0;f=e&65535;g=c[2437644]|0;h=c[g+72+((e>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+3156>>2]|0;if((i|0)==0){j=0;k=f;l=g;break}m=gj[i&4095](f)|0;j=m;k=b[4830442]|0;l=c[2437644]|0}else{j=a[h+(e&255)|0]|0;k=f;l=g}}while(0);b[4853736]=(j&255)+d&65535;b[4830442]=k+1&65535;k=c[2426868]|0;d=k&65535;j=c[l+72+((k>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[l+3144>>2]|0;if((g|0)==0){n=0;break}n=gj[g&4095](d)|0}else{n=a[j+(k&255)|0]|0}}while(0);k=a[9660896]&n;n=(k&255)>>>4&8|a[9660900]&-15;a[9660900]=k<<24>>24==0?n|4:n;return}function f3T(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=b[4830446]|0;e=c[2415221]|0;f=e&65535;g=c[2437644]|0;h=c[g+72+((e>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+3156>>2]|0;if((i|0)==0){j=0;k=f;l=g;break}m=gj[i&4095](f)|0;j=m;k=b[4830442]|0;l=c[2437644]|0}else{j=a[h+(e&255)|0]|0;k=f;l=g}}while(0);b[4853736]=(j&255)+d&65535;b[4830442]=k+1&65535;k=c[2426868]|0;d=k&65535;j=c[l+72+((k>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[l+3144>>2]|0;if((g|0)==0){n=0;break}n=gj[g&4095](d)|0}else{n=a[j+(k&255)|0]|0}}while(0);a[9660896]=n;k=(n&255)>>>4&8|a[9660900]&-15;a[9660900]=n<<24>>24==0?k|4:k;return}function f3U(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=a[9660896]|0;e=(d&255)>>>4&8|a[9660900]&-15;a[9660900]=d<<24>>24==0?e|4:e;e=b[4830446]|0;f=c[2415221]|0;g=f&65535;h=c[2437644]|0;i=c[h+72+((f>>>8&255|512)<<2)>>2]|0;do{if((i|0)==0){j=c[h+3156>>2]|0;if((j|0)==0){k=0;l=g;m=d;n=h;break}o=gj[j&4095](g)|0;k=o;l=b[4830442]|0;m=a[9660896]|0;n=c[2437644]|0}else{k=a[i+(f&255)|0]|0;l=g;m=d;n=h}}while(0);b[4853736]=(k&255)+e&65535;b[4830442]=l+1&65535;l=c[2426868]|0;e=c[n+72+((l>>>8&255|256)<<2)>>2]|0;if((e|0)!=0){a[e+(l&255)|0]=m;return}e=c[n+3148>>2]|0;if((e|0)==0){return}gg[e&4095](l&65535,m);return}function f3V(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=b[4830446]|0;e=c[2415221]|0;f=e&65535;g=c[2437644]|0;h=c[g+72+((e>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+3156>>2]|0;if((i|0)==0){j=0;k=f;l=g;break}m=gj[i&4095](f)|0;j=m;k=b[4830442]|0;l=c[2437644]|0}else{j=a[h+(e&255)|0]|0;k=f;l=g}}while(0);b[4853736]=(j&255)+d&65535;b[4830442]=k+1&65535;k=c[2426868]|0;d=k&65535;j=c[l+72+((k>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[l+3144>>2]|0;if((g|0)==0){n=0;break}n=gj[g&4095](d)|0}else{n=a[j+(k&255)|0]|0}}while(0);k=a[9660896]|0;j=k^n;a[9660896]=j;d=(j&255)>>>4&8|a[9660900]&-15;a[9660900]=k<<24>>24==n<<24>>24?d|4:d;return}function f3W(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=b[4830446]|0;e=c[2415221]|0;f=e&65535;g=c[2437644]|0;h=c[g+72+((e>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+3156>>2]|0;if((i|0)==0){j=0;k=f;l=g;break}m=gj[i&4095](f)|0;j=m;k=b[4830442]|0;l=c[2437644]|0}else{j=a[h+(e&255)|0]|0;k=f;l=g}}while(0);b[4853736]=(j&255)+d&65535;b[4830442]=k+1&65535;k=c[2426868]|0;d=k&65535;j=c[l+72+((k>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[l+3144>>2]|0;if((g|0)==0){n=0;break}n=gj[g&4095](d)|0}else{n=a[j+(k&255)|0]|0}}while(0);k=a[9660896]|0;j=a[9660900]|0;d=(k&255)+(n&255)+(j&1)|0;l=(d>>>4&8|j&-48&255)&255;j=d&255;g=d^(k^n)&255;a[9660900]=(g<<1&32|d>>>8&1|(g^d>>>1)>>>6&2|(j<<24>>24==0?l|4:l)&255)&255;a[9660896]=j;return}function f3X(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=b[4830446]|0;e=c[2415221]|0;f=e&65535;g=c[2437644]|0;h=c[g+72+((e>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+3156>>2]|0;if((i|0)==0){j=0;k=f;l=g;break}m=gj[i&4095](f)|0;j=m;k=b[4830442]|0;l=c[2437644]|0}else{j=a[h+(e&255)|0]|0;k=f;l=g}}while(0);b[4853736]=(j&255)+d&65535;b[4830442]=k+1&65535;k=c[2426868]|0;d=k&65535;j=c[l+72+((k>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[l+3144>>2]|0;if((g|0)==0){n=0;break}n=gj[g&4095](d)|0}else{n=a[j+(k&255)|0]|0}}while(0);k=a[9660896]|n;a[9660896]=k;n=(k&255)>>>4&8|a[9660900]&-15;a[9660900]=k<<24>>24==0?n|4:n;return}function f3Y(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=b[4830446]|0;e=c[2415221]|0;f=e&65535;g=c[2437644]|0;h=c[g+72+((e>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+3156>>2]|0;if((i|0)==0){j=0;k=f;l=g;break}m=gj[i&4095](f)|0;j=m;k=b[4830442]|0;l=c[2437644]|0}else{j=a[h+(e&255)|0]|0;k=f;l=g}}while(0);b[4853736]=(j&255)+d&65535;b[4830442]=k+1&65535;k=c[2426868]|0;d=k&65535;j=c[l+72+((k>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[l+3144>>2]|0;if((g|0)==0){n=0;break}n=gj[g&4095](d)|0}else{n=a[j+(k&255)|0]|0}}while(0);k=a[9660896]|0;j=(k&255)+(n&255)|0;d=(j>>>4&8|a[9660900]&-48&255)&255;l=j&255;g=(k^n)&255^j;a[9660900]=(g<<1&32|j>>>8&1|(g^j>>>1)>>>6&2|(l<<24>>24==0?d|4:d)&255)&255;a[9660896]=l;return}function f3Z(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=b[4830446]|0;e=c[2415221]|0;f=e&65535;g=c[2437644]|0;h=c[g+72+((e>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+3156>>2]|0;if((i|0)==0){j=0;k=f;l=g;break}m=gj[i&4095](f)|0;j=m;k=b[4830442]|0;l=c[2437644]|0}else{j=a[h+(e&255)|0]|0;k=f;l=g}}while(0);b[4853736]=(j&255)+d&65535;b[4830442]=k+1&65535;k=c[2426868]|0;d=k&65535;j=c[l+72+((k>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[l+3144>>2]|0;if((g|0)==0){n=0;o=l;break}f=gj[g&4095](d)|0;n=f;o=c[2437644]|0}else{n=a[j+(k&255)|0]|0;o=l}}while(0);l=n&255;n=l<<8;j=k+1|0;k=j&65535;d=c[o+72+((j>>>8&255)<<2)>>2]|0;do{if((d|0)==0){f=c[o+3144>>2]|0;if((f|0)==0){p=0;break}p=gj[f&4095](k)|0}else{p=a[d+(j&255)|0]|0}}while(0);j=p&255|n;c[2415223]=j;n=a[9660900]&-15;a[9660900]=n;p=n&255|l>>>4&8;if((j|0)!=0){q=p&255;a[9660900]=q;return}q=(p|4)&255;a[9660900]=q;return}function f3_(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=a[9660900]&-15;a[9660900]=d;e=b[4830446]|0;f=(e&65535)>>>12&8|d&255;if(e<<16>>16==0){g=(f|4)&255}else{g=f&255}a[9660900]=g;g=c[2415221]|0;f=g&65535;d=c[2437644]|0;h=c[d+72+((g>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[d+3156>>2]|0;if((i|0)==0){j=0;k=f;l=d;break}m=gj[i&4095](f)|0;j=m;k=b[4830442]|0;l=c[2437644]|0}else{j=a[h+(g&255)|0]|0;k=f;l=d}}while(0);b[4853736]=(j&255)+e&65535;b[4830442]=k+1&65535;k=c[2426868]|0;e=k&65535;j=a[9660893]|0;d=c[l+72+((k>>>8&255|256)<<2)>>2]|0;do{if((d|0)==0){f=c[l+3148>>2]|0;if((f|0)==0){n=l;break}gg[f&4095](e,j);n=c[2437644]|0}else{a[d+(k&255)|0]=j;n=l}}while(0);l=k+1|0;k=a[9660892]|0;j=c[n+72+((l>>>8&255|256)<<2)>>2]|0;if((j|0)!=0){a[j+(l&255)|0]=k;return}j=c[n+3148>>2]|0;if((j|0)==0){return}gg[j&4095](l&65535,k);return}function f3$(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=d;k=f;l=e;break}m=gj[h&4095](e)|0;h=c[2415221]|0;i=m;j=h;k=c[2437644]|0;l=h&65535}else{i=a[g+(d&255)|0]|0;j=d;k=f;l=e}}while(0);e=i&255;i=e<<8;f=j+1|0;j=f&65535;d=c[k+72+((f>>>8&255|512)<<2)>>2]|0;do{if((d|0)==0){g=c[k+3156>>2]|0;if((g|0)==0){n=0;o=l;p=k;break}h=gj[g&4095](j)|0;n=h;o=b[4830442]|0;p=c[2437644]|0}else{n=a[d+(f&255)|0]|0;o=l;p=k}}while(0);k=n&255;n=k|i;c[2426868]=n;b[4830442]=o+2&65535;o=n&65535;n=c[p+72+(e<<2)>>2]|0;do{if((n|0)==0){e=c[p+3144>>2]|0;if((e|0)==0){q=0;break}q=gj[e&4095](o)|0}else{q=a[n+k|0]|0}}while(0);k=a[9660896]|0;n=(k&255)-(q&255)|0;o=(n>>>4&8|a[9660900]&-16&255)&255;p=n&255;a[9660900]=(((k^q)&255^n^n>>>1)>>>6&2|n>>>8&1|(p<<24>>24==0?o|4:o)&255)&255;a[9660896]=p;return}function f30(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=d;k=f;l=e;break}m=gj[h&4095](e)|0;h=c[2415221]|0;i=m;j=h;k=c[2437644]|0;l=h&65535}else{i=a[g+(d&255)|0]|0;j=d;k=f;l=e}}while(0);e=i&255;i=e<<8;f=j+1|0;j=f&65535;d=c[k+72+((f>>>8&255|512)<<2)>>2]|0;do{if((d|0)==0){g=c[k+3156>>2]|0;if((g|0)==0){n=0;o=l;p=k;break}h=gj[g&4095](j)|0;n=h;o=b[4830442]|0;p=c[2437644]|0}else{n=a[d+(f&255)|0]|0;o=l;p=k}}while(0);k=n&255;n=k|i;c[2426868]=n;b[4830442]=o+2&65535;o=n&65535;n=c[p+72+(e<<2)>>2]|0;do{if((n|0)==0){e=c[p+3144>>2]|0;if((e|0)==0){q=0;break}q=gj[e&4095](o)|0}else{q=a[n+k|0]|0}}while(0);k=a[9660896]|0;n=(k&255)-(q&255)|0;o=(n>>>4&8|a[9660900]&-16&255)&255;a[9660900]=(((k^q)&255^n^n>>>1)>>>6&2|n>>>8&1|((n&255)<<24>>24==0?o|4:o)&255)&255;return}function f31(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=d;k=f;l=e;break}m=gj[h&4095](e)|0;h=c[2415221]|0;i=m;j=h;k=c[2437644]|0;l=h&65535}else{i=a[g+(d&255)|0]|0;j=d;k=f;l=e}}while(0);e=i&255;i=e<<8;f=j+1|0;j=f&65535;d=c[k+72+((f>>>8&255|512)<<2)>>2]|0;do{if((d|0)==0){g=c[k+3156>>2]|0;if((g|0)==0){n=0;o=l;p=k;break}h=gj[g&4095](j)|0;n=h;o=b[4830442]|0;p=c[2437644]|0}else{n=a[d+(f&255)|0]|0;o=l;p=k}}while(0);k=n&255;n=k|i;c[2426868]=n;b[4830442]=o+2&65535;o=n&65535;n=c[p+72+(e<<2)>>2]|0;do{if((n|0)==0){e=c[p+3144>>2]|0;if((e|0)==0){q=0;break}q=gj[e&4095](o)|0}else{q=a[n+k|0]|0}}while(0);k=a[9660896]|0;n=a[9660900]|0;o=(k&255)-(q&255)-(n&1)|0;p=(o>>>4&8|n&-16&255)&255;n=o&255;a[9660900]=((o^(k^q)&255^o>>>1)>>>6&2|o>>>8&1|(n<<24>>24==0?p|4:p)&255)&255;a[9660896]=n;return}function f32(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=d;k=f;l=e;break}m=gj[h&4095](e)|0;h=c[2415221]|0;i=m;j=h;k=c[2437644]|0;l=h&65535}else{i=a[g+(d&255)|0]|0;j=d;k=f;l=e}}while(0);e=i&255;i=e<<8;f=j+1|0;j=f&65535;d=c[k+72+((f>>>8&255|512)<<2)>>2]|0;do{if((d|0)==0){g=c[k+3156>>2]|0;if((g|0)==0){n=0;o=l;p=k;break}h=gj[g&4095](j)|0;n=h;o=b[4830442]|0;p=c[2437644]|0}else{n=a[d+(f&255)|0]|0;o=l;p=k}}while(0);k=n&255;n=k|i;c[2426868]=n;b[4830442]=o+2&65535;o=n&65535;n=c[p+72+(e<<2)>>2]|0;do{if((n|0)==0){e=c[p+3144>>2]|0;if((e|0)==0){q=0;break}q=gj[e&4095](o)|0}else{q=a[n+k|0]|0}}while(0);k=a[9660896]&q;a[9660896]=k;q=(k&255)>>>4&8|a[9660900]&-15;a[9660900]=k<<24>>24==0?q|4:q;return}function f33(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=d;k=f;l=e;break}m=gj[h&4095](e)|0;h=c[2415221]|0;i=m;j=h;k=c[2437644]|0;l=h&65535}else{i=a[g+(d&255)|0]|0;j=d;k=f;l=e}}while(0);e=i&255;i=e<<8;f=j+1|0;j=f&65535;d=c[k+72+((f>>>8&255|512)<<2)>>2]|0;do{if((d|0)==0){g=c[k+3156>>2]|0;if((g|0)==0){n=0;o=l;p=k;break}h=gj[g&4095](j)|0;n=h;o=b[4830442]|0;p=c[2437644]|0}else{n=a[d+(f&255)|0]|0;o=l;p=k}}while(0);k=n&255;n=k|i;c[2426868]=n;b[4830442]=o+2&65535;o=n&65535;n=c[p+72+(e<<2)>>2]|0;do{if((n|0)==0){e=c[p+3144>>2]|0;if((e|0)==0){q=0;break}q=gj[e&4095](o)|0}else{q=a[n+k|0]|0}}while(0);k=a[9660896]&q;q=(k&255)>>>4&8|a[9660900]&-15;a[9660900]=k<<24>>24==0?q|4:q;return}function f34(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=d;k=f;l=e;break}m=gj[h&4095](e)|0;h=c[2415221]|0;i=m;j=h;k=c[2437644]|0;l=h&65535}else{i=a[g+(d&255)|0]|0;j=d;k=f;l=e}}while(0);e=i&255;i=e<<8;f=j+1|0;j=f&65535;d=c[k+72+((f>>>8&255|512)<<2)>>2]|0;do{if((d|0)==0){g=c[k+3156>>2]|0;if((g|0)==0){n=0;o=l;p=k;break}h=gj[g&4095](j)|0;n=h;o=b[4830442]|0;p=c[2437644]|0}else{n=a[d+(f&255)|0]|0;o=l;p=k}}while(0);k=n&255;n=k|i;c[2426868]=n;b[4830442]=o+2&65535;o=n&65535;n=c[p+72+(e<<2)>>2]|0;do{if((n|0)==0){e=c[p+3144>>2]|0;if((e|0)==0){q=0;break}q=gj[e&4095](o)|0}else{q=a[n+k|0]|0}}while(0);a[9660896]=q;k=(q&255)>>>4&8|a[9660900]&-15;a[9660900]=q<<24>>24==0?k|4:k;return}function f35(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=a[9660896]|0;e=(d&255)>>>4&8|a[9660900]&-15;a[9660900]=d<<24>>24==0?e|4:e;e=c[2415221]|0;d=e&65535;f=c[2437644]|0;g=c[f+72+((e>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=e;k=f;l=d;break}m=gj[h&4095](d)|0;h=c[2415221]|0;i=m;j=h;k=c[2437644]|0;l=h&65535}else{i=a[g+(e&255)|0]|0;j=e;k=f;l=d}}while(0);d=i&255;i=d<<8;f=j+1|0;j=f&65535;e=c[k+72+((f>>>8&255|512)<<2)>>2]|0;do{if((e|0)==0){g=c[k+3156>>2]|0;if((g|0)==0){n=0;o=l;p=k;break}h=gj[g&4095](j)|0;n=h;o=b[4830442]|0;p=c[2437644]|0}else{n=a[e+(f&255)|0]|0;o=l;p=k}}while(0);k=n&255;n=k|i;c[2426868]=n;b[4830442]=o+2&65535;o=a[9660896]|0;i=c[p+72+((d|256)<<2)>>2]|0;if((i|0)!=0){a[i+k|0]=o;return}k=c[p+3148>>2]|0;if((k|0)==0){return}gg[k&4095](n&65535,o);return}function f36(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=d;k=f;l=e;break}m=gj[h&4095](e)|0;h=c[2415221]|0;i=m;j=h;k=c[2437644]|0;l=h&65535}else{i=a[g+(d&255)|0]|0;j=d;k=f;l=e}}while(0);e=i&255;i=e<<8;f=j+1|0;j=f&65535;d=c[k+72+((f>>>8&255|512)<<2)>>2]|0;do{if((d|0)==0){g=c[k+3156>>2]|0;if((g|0)==0){n=0;o=l;p=k;break}h=gj[g&4095](j)|0;n=h;o=b[4830442]|0;p=c[2437644]|0}else{n=a[d+(f&255)|0]|0;o=l;p=k}}while(0);k=n&255;n=k|i;c[2426868]=n;b[4830442]=o+2&65535;o=n&65535;n=c[p+72+(e<<2)>>2]|0;do{if((n|0)==0){e=c[p+3144>>2]|0;if((e|0)==0){q=0;break}q=gj[e&4095](o)|0}else{q=a[n+k|0]|0}}while(0);k=a[9660896]|0;n=k^q;a[9660896]=n;o=(n&255)>>>4&8|a[9660900]&-15;a[9660900]=k<<24>>24==q<<24>>24?o|4:o;return}function f37(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=d;k=f;l=e;break}m=gj[h&4095](e)|0;h=c[2415221]|0;i=m;j=h;k=c[2437644]|0;l=h&65535}else{i=a[g+(d&255)|0]|0;j=d;k=f;l=e}}while(0);e=i&255;i=e<<8;f=j+1|0;j=f&65535;d=c[k+72+((f>>>8&255|512)<<2)>>2]|0;do{if((d|0)==0){g=c[k+3156>>2]|0;if((g|0)==0){n=0;o=l;p=k;break}h=gj[g&4095](j)|0;n=h;o=b[4830442]|0;p=c[2437644]|0}else{n=a[d+(f&255)|0]|0;o=l;p=k}}while(0);k=n&255;n=k|i;c[2426868]=n;b[4830442]=o+2&65535;o=n&65535;n=c[p+72+(e<<2)>>2]|0;do{if((n|0)==0){e=c[p+3144>>2]|0;if((e|0)==0){q=0;break}q=gj[e&4095](o)|0}else{q=a[n+k|0]|0}}while(0);k=a[9660896]|0;n=a[9660900]|0;o=(k&255)+(q&255)+(n&1)|0;p=(o>>>4&8|n&-48&255)&255;n=o&255;e=o^(k^q)&255;a[9660900]=(e<<1&32|o>>>8&1|(e^o>>>1)>>>6&2|(n<<24>>24==0?p|4:p)&255)&255;a[9660896]=n;return}function f38(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=d;k=f;l=e;break}m=gj[h&4095](e)|0;h=c[2415221]|0;i=m;j=h;k=c[2437644]|0;l=h&65535}else{i=a[g+(d&255)|0]|0;j=d;k=f;l=e}}while(0);e=i&255;i=e<<8;f=j+1|0;j=f&65535;d=c[k+72+((f>>>8&255|512)<<2)>>2]|0;do{if((d|0)==0){g=c[k+3156>>2]|0;if((g|0)==0){n=0;o=l;p=k;break}h=gj[g&4095](j)|0;n=h;o=b[4830442]|0;p=c[2437644]|0}else{n=a[d+(f&255)|0]|0;o=l;p=k}}while(0);k=n&255;n=k|i;c[2426868]=n;b[4830442]=o+2&65535;o=n&65535;n=c[p+72+(e<<2)>>2]|0;do{if((n|0)==0){e=c[p+3144>>2]|0;if((e|0)==0){q=0;break}q=gj[e&4095](o)|0}else{q=a[n+k|0]|0}}while(0);k=a[9660896]|q;a[9660896]=k;q=(k&255)>>>4&8|a[9660900]&-15;a[9660900]=k<<24>>24==0?q|4:q;return}function f39(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=d;k=f;l=e;break}m=gj[h&4095](e)|0;h=c[2415221]|0;i=m;j=h;k=c[2437644]|0;l=h&65535}else{i=a[g+(d&255)|0]|0;j=d;k=f;l=e}}while(0);e=i&255;i=e<<8;f=j+1|0;j=f&65535;d=c[k+72+((f>>>8&255|512)<<2)>>2]|0;do{if((d|0)==0){g=c[k+3156>>2]|0;if((g|0)==0){n=0;o=l;p=k;break}h=gj[g&4095](j)|0;n=h;o=b[4830442]|0;p=c[2437644]|0}else{n=a[d+(f&255)|0]|0;o=l;p=k}}while(0);k=n&255;n=k|i;c[2426868]=n;b[4830442]=o+2&65535;o=n&65535;n=c[p+72+(e<<2)>>2]|0;do{if((n|0)==0){e=c[p+3144>>2]|0;if((e|0)==0){q=0;break}q=gj[e&4095](o)|0}else{q=a[n+k|0]|0}}while(0);k=a[9660896]|0;n=(k&255)+(q&255)|0;o=(n>>>4&8|a[9660900]&-48&255)&255;p=n&255;e=(k^q)&255^n;a[9660900]=(e<<1&32|n>>>8&1|(e^n>>>1)>>>6&2|(p<<24>>24==0?o|4:o)&255)&255;a[9660896]=p;return}function f4a(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=d;k=f;l=e;break}m=gj[h&4095](e)|0;h=c[2415221]|0;i=m;j=h;k=c[2437644]|0;l=h&65535}else{i=a[g+(d&255)|0]|0;j=d;k=f;l=e}}while(0);e=i&255;i=e<<8;f=j+1|0;j=f&65535;d=c[k+72+((f>>>8&255|512)<<2)>>2]|0;do{if((d|0)==0){g=c[k+3156>>2]|0;if((g|0)==0){n=0;o=l;p=k;break}h=gj[g&4095](j)|0;n=h;o=b[4830442]|0;p=c[2437644]|0}else{n=a[d+(f&255)|0]|0;o=l;p=k}}while(0);k=n&255;n=k|i;c[2426868]=n;b[4830442]=o+2&65535;o=n&65535;i=c[p+72+(e<<2)>>2]|0;do{if((i|0)==0){e=c[p+3144>>2]|0;if((e|0)==0){q=0;r=p;break}l=gj[e&4095](o)|0;q=l;r=c[2437644]|0}else{q=a[i+k|0]|0;r=p}}while(0);p=q&255;q=p<<8;k=n+1|0;n=k&65535;i=c[r+72+((k>>>8&255)<<2)>>2]|0;do{if((i|0)==0){o=c[r+3144>>2]|0;if((o|0)==0){s=0;break}s=gj[o&4095](n)|0}else{s=a[i+(k&255)|0]|0}}while(0);k=s&255|q;c[2415223]=k;q=a[9660900]&-15;a[9660900]=q;s=q&255|p>>>4&8;if((k|0)!=0){t=s&255;a[9660900]=t;return}t=(s|4)&255;a[9660900]=t;return}function f4b(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=a[9660900]&-15;a[9660900]=d;e=b[4830446]|0;f=(e&65535)>>>12&8|d&255;if(e<<16>>16==0){g=(f|4)&255}else{g=f&255}a[9660900]=g;g=c[2415221]|0;f=g&65535;e=c[2437644]|0;d=c[e+72+((g>>>8&255|512)<<2)>>2]|0;do{if((d|0)==0){h=c[e+3156>>2]|0;if((h|0)==0){i=0;j=g;k=e;l=f;break}m=gj[h&4095](f)|0;h=c[2415221]|0;i=m;j=h;k=c[2437644]|0;l=h&65535}else{i=a[d+(g&255)|0]|0;j=g;k=e;l=f}}while(0);f=i&255;i=f<<8;e=j+1|0;j=e&65535;g=c[k+72+((e>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){d=c[k+3156>>2]|0;if((d|0)==0){n=0;o=l;p=k;break}h=gj[d&4095](j)|0;n=h;o=b[4830442]|0;p=c[2437644]|0}else{n=a[g+(e&255)|0]|0;o=l;p=k}}while(0);k=n&255;n=k|i;c[2426868]=n;b[4830442]=o+2&65535;o=n&65535;i=a[9660893]|0;l=c[p+72+((f|256)<<2)>>2]|0;do{if((l|0)==0){f=c[p+3148>>2]|0;if((f|0)==0){q=p;break}gg[f&4095](o,i);q=c[2437644]|0}else{a[l+k|0]=i;q=p}}while(0);p=n+1|0;n=a[9660892]|0;i=c[q+72+((p>>>8&255|256)<<2)>>2]|0;if((i|0)!=0){a[i+(p&255)|0]=n;return}i=c[q+3148>>2]|0;if((i|0)==0){return}gg[i&4095](p&65535,n);return}function f4c(f){f=f|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0,cf=0,cg=0,ch=0,ci=0,cj=0,ck=0,cl=0,cm=0,cn=0,co=0,cp=0,cq=0,cr=0,cs=0,ct=0,cu=0,cv=0,cw=0,cx=0,cy=0,cz=0,cA=0,cB=0,cC=0,cD=0,cE=0,cF=0,cG=0,cH=0,cI=0,cJ=0,cK=0,cL=0,cM=0,cN=0,cO=0,cP=0,cQ=0,cR=0,cS=0,cT=0,cU=0,cV=0,cW=0,cX=0,cY=0,cZ=0,c_=0,c$=0,c0=0,c1=0,c2=0,c3=0,c4=0,c5=0,c6=0,c7=0,c8=0,c9=0,da=0,db=0,dc=0,dd=0,de=0,df=0,dg=0,dh=0,di=0,dj=0,dk=0,dl=0,dm=0,dn=0,dp=0,dq=0,dr=0,ds=0,dt=0,du=0,dv=0,dw=0,dx=0,dy=0,dz=0,dA=0,dB=0,dC=0,dD=0,dE=0,dF=0,dG=0,dH=0,dI=0,dJ=0,dK=0,dL=0,dM=0,dN=0,dO=0,dP=0,dQ=0,dR=0,dS=0,dT=0,dU=0,dV=0,dW=0,dX=0,dY=0,dZ=0,d_=0,d$=0,d0=0,d1=0,d2=0,d3=0,d4=0,d5=0,d6=0,d7=0,d8=0,d9=0,ea=0,eb=0,ec=0,ed=0,ee=0,ef=0,eg=0,eh=0,ei=0,ej=0,ek=0,el=0,em=0,en=0,eo=0,ep=0,eq=0,er=0,es=0,et=0,eu=0,ev=0,ew=0,ex=0,ey=0,ez=0,eA=0,eB=0,eC=0,eD=0,eE=0,eF=0,eG=0,eH=0,eI=0,eJ=0,eK=0,eL=0,eM=0,eN=0,eO=0,eP=0,eQ=0,eR=0,eS=0,eT=0,eU=0,eV=0,eW=0,eX=0,eY=0,eZ=0,e_=0,e$=0,e0=0,e1=0,e2=0,e3=0,e4=0,e5=0,e6=0,e7=0,e8=0,e9=0,fa=0,fb=0,fc=0,fd=0,fe=0,ff=0,fg=0;h=i;i=i+23944|0;j=b[4830469]|0;b[4830471]=(b[4830471]|0)-j&65535;b[4830474]=(b[4830474]|0)-j&65535;b[4830469]=0;j=c[2415235]|0;k=c[2415234]|0;l=c[2415237]|0;m=(j-k|0)>>>0<(l-k|0)>>>0?j:l;c[3528192]=m;l=c[2415227]|0;c[2440594]=f-l;c[2415234]=l+k|0;if((l+k|0)>>>0>=m>>>0){f03()}c[2415227]=0;do{do{m=1;if(m){m=0;if((a[9660901]&8)==0){k=c[2415221]|0;c[2415220]=k;l=c[2437644]|0;j=c[l+72+((k>>>8&255|512)<<2)>>2]|0;do{if((j|0)==0){n=c[l+3152>>2]|0;if((n|0)==0){o=0;p=k&65535;break}q=gj[n&4095](k&65535)|0;o=q;p=b[4830442]|0}else{o=a[j+(k&255)|0]|0;p=k&65535}}while(0);k=p+1&65535;b[4830442]=k;j=o&255;L40594:do{l=1;q=j|0;if(l){l=0;switch(q|0){case 4:{n=a[9660900]&-14;a[9660900]=n;r=b[4830448]|0;if((r&65535)>>>1<<16>>16==0){s=(r&1|n&255|4)&255}else{s=(r&1|n&255)&255}a[9660900]=s;b[4830448]=(r&65535)>>>1;break};case 33:{r=c[2415221]|0;n=c[2437644]|0;do{if((c[n+72+((r>>>8&255|512)<<2)>>2]|0)==0){t=c[n+3156>>2]|0;if((t|0)==0){u=r&65535;break}gj[t&4095](r&65535)|0;u=b[4830442]|0}else{u=r&65535}}while(0);b[4830442]=u+1&65535;break};case 34:{r=c[2415221]|0;n=c[2437644]|0;t=c[n+72+((r>>>8&255|512)<<2)>>2]|0;do{if((t|0)==0){v=c[n+3156>>2]|0;if((v|0)==0){w=0;x=r&65535;break}y=gj[v&4095](r&65535)|0;w=y;x=b[4830442]|0}else{w=a[t+(r&255)|0]|0;x=r&65535}}while(0);r=x+1&65535;b[4830442]=r;if((a[9660900]&5)!=0){break L40594}t=w&255;b[4830442]=((t&128|0)!=0?t|65280:t)+(r&65535)&65535;b[4830442]=c[2415221]&65535;break};case 35:{r=c[2415221]|0;t=c[2437644]|0;n=c[t+72+((r>>>8&255|512)<<2)>>2]|0;do{if((n|0)==0){y=c[t+3156>>2]|0;if((y|0)==0){z=0;A=r&65535;break}v=gj[y&4095](r&65535)|0;z=v;A=b[4830442]|0}else{z=a[n+(r&255)|0]|0;A=r&65535}}while(0);r=A+1&65535;b[4830442]=r;if((a[9660900]&5)==0){break L40594}n=z&255;b[4830442]=((n&128|0)!=0?n|65280:n)+(r&65535)&65535;b[4830442]=c[2415221]&65535;break};case 13:{a[9660900]=a[9660900]|1;break};case 7:{a[9660897]=a[9660900]|0;break};case 10:{a[9660900]=a[9660900]&-3;break};case 6:{f06();break};case 61:{r=ag(d[9660896]|0,d[9660897]|0)|0;n=a[9660900]|0;a[9660900]=(r&128)==0?n&-2:n|1;b[4830448]=r;break};case 62:{f1I();break};case 63:{f1J();break};case 64:{r=a[9660897]|0;n=-(r&255)&65535&65535;t=(n>>>4&8|a[9660900]&-16&255)&255;a[9660900]=((n^r&255^n>>>1)>>>6&2|n>>>8&1|((-(r&255)&65535&255)<<24>>24==0?t|4:t)&255)&255;a[9660897]=-(r&255)&65535&255;break};case 67:{r=a[9660897]|0;a[9660897]=~r;t=(~r&255)>>>4&8|a[9660900]&-15;a[9660900]=(r<<24>>24==-1?t|4:t)|1;break};case 68:{t=a[9660897]|0;r=t&1|a[9660900]&-14;a[9660900]=r;a[9660897]=(t&255)>>>1;if((t&255)>>>1<<24>>24!=0){break L40594}a[9660900]=r|4;break};case 70:{r=a[9660900]|0;t=a[9660897]|0;a[9660900]=((t&255)>>>1|r<<7)<<24>>24==0?t&1|r&-14|r<<3&8|4:t&1|r&-14|r<<3&8;a[9660897]=(t&255)>>>1|r<<7;break};case 71:{r=a[9660897]|0;t=r&1|a[9660900]&-14;a[9660897]=(r&255)>>>1<<1&-128|(r&255)>>>1;a[9660900]=((r&255)>>>1<<1&-128|(r&255)>>>1)<<24>>24==0?t|(r&255)>>>4&8|4:t|(r&255)>>>4&8;break};case 72:{r=(d[9660897]|0)<<1;t=((r&65535)>>>4&8|a[9660900]&-16&255)&255;a[9660900]=(((r&65535)>>>1^r&65535)>>>6&2|(r&65535)>>>8|((r&255)<<24>>24==0?t|4:t)&255)&255;a[9660897]=r&255;break};case 73:{r=a[9660900]|0;t=r&1|(d[9660897]|0)<<1;a[9660900]=(((t&65535)>>>1^t&65535)>>>6&2|(t&65535)>>>8|((t&255)<<24>>24==0?((t&65535)>>>4&8|r&-16&255)&255|4:((t&65535)>>>4&8|r&-16&255)&255)&255)&255;a[9660897]=t&255;break};case 74:{t=(a[9660897]|0)-1&255;a[9660897]=t;a[9660900]=a[669184+(t&255)|0]|a[9660900]&-15;break};case 76:{t=(a[9660897]|0)+1&255;a[9660897]=t;a[9660900]=a[668928+(t&255)|0]|a[9660900]&-15;break};case 77:{t=a[9660897]|0;r=(t&255)>>>4&8|a[9660900]&-16;a[9660900]=t<<24>>24==0?r|4:r;break};case 79:{a[9660897]=0;a[9660900]=a[9660900]&-16|4;break};case 80:{r=a[9660896]|0;t=-(r&255)&65535&65535;n=(t>>>4&8|a[9660900]&-16&255)&255;a[9660900]=((t^r&255^t>>>1)>>>6&2|t>>>8&1|((-(r&255)&65535&255)<<24>>24==0?n|4:n)&255)&255;a[9660896]=-(r&255)&65535&255;break};case 83:{r=a[9660896]|0;a[9660896]=~r;n=(~r&255)>>>4&8|a[9660900]&-15;a[9660900]=(r<<24>>24==-1?n|4:n)|1;break};case 84:{n=a[9660896]|0;r=n&1|a[9660900]&-14;a[9660900]=r;a[9660896]=(n&255)>>>1;if((n&255)>>>1<<24>>24!=0){break L40594}a[9660900]=r|4;break};case 86:{r=a[9660900]|0;n=a[9660896]|0;a[9660900]=((n&255)>>>1|r<<7)<<24>>24==0?n&1|r&-14|r<<3&8|4:n&1|r&-14|r<<3&8;a[9660896]=(n&255)>>>1|r<<7;break};case 87:{r=a[9660896]|0;n=r&1|a[9660900]&-14;a[9660896]=(r&255)>>>1<<1&-128|(r&255)>>>1;a[9660900]=((r&255)>>>1<<1&-128|(r&255)>>>1)<<24>>24==0?n|(r&255)>>>4&8|4:n|(r&255)>>>4&8;break};case 88:{r=(d[9660896]|0)<<1;n=((r&65535)>>>4&8|a[9660900]&-16&255)&255;a[9660900]=(((r&65535)>>>1^r&65535)>>>6&2|(r&65535)>>>8|((r&255)<<24>>24==0?n|4:n)&255)&255;a[9660896]=r&255;break};case 89:{r=a[9660900]|0;n=r&1|(d[9660896]|0)<<1;a[9660900]=(((n&65535)>>>1^n&65535)>>>6&2|(n&65535)>>>8|((n&255)<<24>>24==0?((n&65535)>>>4&8|r&-16&255)&255|4:((n&65535)>>>4&8|r&-16&255)&255)&255)&255;a[9660896]=n&255;break};case 90:{n=(a[9660896]|0)-1&255;a[9660896]=n;a[9660900]=a[669184+(n&255)|0]|a[9660900]&-15;break};case 92:{n=(a[9660896]|0)+1&255;a[9660896]=n;a[9660900]=a[668928+(n&255)|0]|a[9660900]&-15;break};case 93:{n=a[9660896]|0;r=(n&255)>>>4&8|a[9660900]&-16;a[9660900]=n<<24>>24==0?r|4:r;break};case 95:{a[9660896]=0;a[9660900]=a[9660900]&-16|4;break};case 96:{r=b[4830446]|0;n=c[2415221]|0;t=c[2437644]|0;v=c[t+72+((n>>>8&255|512)<<2)>>2]|0;do{if((v|0)==0){y=c[t+3156>>2]|0;if((y|0)==0){C=0;D=n&65535;E=t;break}F=gj[y&4095](n&65535)|0;C=F;D=b[4830442]|0;E=c[2437644]|0}else{C=a[v+(n&255)|0]|0;D=n&65535;E=t}}while(0);b[4853736]=(C&255)+r&65535;b[4830442]=D+1&65535;t=c[2426868]|0;n=c[E+72+((t>>>8&255)<<2)>>2]|0;do{if((n|0)==0){v=c[E+3144>>2]|0;if((v|0)==0){G=0;H=t;K=E;break}F=gj[v&4095](t&65535)|0;G=F;H=c[2426868]|0;K=c[2437644]|0}else{G=a[n+(t&255)|0]|0;H=t;K=E}}while(0);t=G&255;n=(a[9660900]&-16&255|(-t|0)>>>4&8)&255;a[9660900]=((t^(-t|0)^(-t|0)>>>1)>>>6&2|(-t|0)>>>8&1|(((-t|0)&255)<<24>>24==0?n|4:n)&255)&255;n=c[K+72+((H>>>8&255|256)<<2)>>2]|0;if((n|0)!=0){a[n+(H&255)|0]=(-t|0)&255;break L40594}n=c[K+3148>>2]|0;if((n|0)==0){break L40594}gg[n&4095](H&65535,(-t|0)&255);break};case 99:{t=b[4830446]|0;n=c[2415221]|0;r=c[2437644]|0;F=c[r+72+((n>>>8&255|512)<<2)>>2]|0;do{if((F|0)==0){v=c[r+3156>>2]|0;if((v|0)==0){L=0;M=n&65535;N=r;break}y=gj[v&4095](n&65535)|0;L=y;M=b[4830442]|0;N=c[2437644]|0}else{L=a[F+(n&255)|0]|0;M=n&65535;N=r}}while(0);b[4853736]=(L&255)+t&65535;b[4830442]=M+1&65535;r=c[2426868]|0;n=c[N+72+((r>>>8&255)<<2)>>2]|0;do{if((n|0)==0){F=c[N+3144>>2]|0;if((F|0)==0){O=0;P=r;Q=N;break}y=gj[F&4095](r&65535)|0;O=y;P=c[2426868]|0;Q=c[2437644]|0}else{O=a[n+(r&255)|0]|0;P=r;Q=N}}while(0);r=~O;n=a[9660900]&-15|(r&255)>>>4&8;a[9660900]=(O<<24>>24==-1?n|4:n)|1;n=c[Q+72+((P>>>8&255|256)<<2)>>2]|0;if((n|0)!=0){a[n+(P&255)|0]=r;break L40594}n=c[Q+3148>>2]|0;if((n|0)==0){break L40594}gg[n&4095](P&65535,r);break};case 100:{r=b[4830446]|0;n=c[2415221]|0;t=c[2437644]|0;y=c[t+72+((n>>>8&255|512)<<2)>>2]|0;do{if((y|0)==0){F=c[t+3156>>2]|0;if((F|0)==0){R=0;S=n&65535;T=t;break}v=gj[F&4095](n&65535)|0;R=v;S=b[4830442]|0;T=c[2437644]|0}else{R=a[y+(n&255)|0]|0;S=n&65535;T=t}}while(0);b[4853736]=(R&255)+r&65535;b[4830442]=S+1&65535;t=c[2426868]|0;n=c[T+72+((t>>>8&255)<<2)>>2]|0;do{if((n|0)==0){y=c[T+3144>>2]|0;if((y|0)==0){U=0;V=t;W=T;break}v=gj[y&4095](t&65535)|0;U=v;V=c[2426868]|0;W=c[2437644]|0}else{U=a[n+(t&255)|0]|0;V=t;W=T}}while(0);t=a[9660900]&-14|U&1;n=(U&255)>>>1;a[9660900]=n<<24>>24==0?t|4:t;t=c[W+72+((V>>>8&255|256)<<2)>>2]|0;if((t|0)!=0){a[t+(V&255)|0]=n;break L40594}t=c[W+3148>>2]|0;if((t|0)==0){break L40594}gg[t&4095](V&65535,n);break};case 102:{n=b[4830446]|0;t=c[2415221]|0;r=c[2437644]|0;v=c[r+72+((t>>>8&255|512)<<2)>>2]|0;do{if((v|0)==0){y=c[r+3156>>2]|0;if((y|0)==0){X=0;Y=t&65535;Z=r;break}F=gj[y&4095](t&65535)|0;X=F;Y=b[4830442]|0;Z=c[2437644]|0}else{X=a[v+(t&255)|0]|0;Y=t&65535;Z=r}}while(0);b[4853736]=(X&255)+n&65535;b[4830442]=Y+1&65535;r=c[2426868]|0;t=c[Z+72+((r>>>8&255)<<2)>>2]|0;do{if((t|0)==0){v=c[Z+3144>>2]|0;if((v|0)==0){_=0;$=r;aa=Z;break}F=gj[v&4095](r&65535)|0;_=F;$=c[2426868]|0;aa=c[2437644]|0}else{_=a[t+(r&255)|0]|0;$=r;aa=Z}}while(0);r=a[9660900]|0;t=r<<7|(_&255)>>>1;n=r&-14|_&1|r<<3&8;a[9660900]=t<<24>>24==0?n|4:n;n=c[aa+72+(($>>>8&255|256)<<2)>>2]|0;if((n|0)!=0){a[n+($&255)|0]=t;break L40594}n=c[aa+3148>>2]|0;if((n|0)==0){break L40594}gg[n&4095]($&65535,t);break};case 103:{t=b[4830446]|0;n=c[2415221]|0;r=c[2437644]|0;F=c[r+72+((n>>>8&255|512)<<2)>>2]|0;do{if((F|0)==0){v=c[r+3156>>2]|0;if((v|0)==0){ab=0;ac=n&65535;ad=r;break}y=gj[v&4095](n&65535)|0;ab=y;ac=b[4830442]|0;ad=c[2437644]|0}else{ab=a[F+(n&255)|0]|0;ac=n&65535;ad=r}}while(0);b[4853736]=(ab&255)+t&65535;b[4830442]=ac+1&65535;r=c[2426868]|0;n=c[ad+72+((r>>>8&255)<<2)>>2]|0;do{if((n|0)==0){F=c[ad+3144>>2]|0;if((F|0)==0){ae=0;af=r;ah=ad;break}y=gj[F&4095](r&65535)|0;ae=y;af=c[2426868]|0;ah=c[2437644]|0}else{ae=a[n+(r&255)|0]|0;af=r;ah=ad}}while(0);r=(ae&255)>>>1;n=a[9660900]&-14|ae&1|(ae&255)>>>4&8;a[9660900]=(r<<1&-128|r)<<24>>24==0?n|4:n;n=c[ah+72+((af>>>8&255|256)<<2)>>2]|0;if((n|0)!=0){a[n+(af&255)|0]=r<<1&-128|r;break L40594}n=c[ah+3148>>2]|0;if((n|0)==0){break L40594}gg[n&4095](af&65535,r<<1&-128|r);break};case 104:{r=b[4830446]|0;n=c[2415221]|0;t=c[2437644]|0;y=c[t+72+((n>>>8&255|512)<<2)>>2]|0;do{if((y|0)==0){F=c[t+3156>>2]|0;if((F|0)==0){ai=0;aj=n&65535;ak=t;break}v=gj[F&4095](n&65535)|0;ai=v;aj=b[4830442]|0;ak=c[2437644]|0}else{ai=a[y+(n&255)|0]|0;aj=n&65535;ak=t}}while(0);b[4853736]=(ai&255)+r&65535;b[4830442]=aj+1&65535;t=c[2426868]|0;n=c[ak+72+((t>>>8&255)<<2)>>2]|0;do{if((n|0)==0){y=c[ak+3144>>2]|0;if((y|0)==0){al=0;am=t;an=ak;break}v=gj[y&4095](t&65535)|0;al=v;am=c[2426868]|0;an=c[2437644]|0}else{al=a[n+(t&255)|0]|0;am=t;an=ak}}while(0);t=(al&255)<<1;n=((t&65535)>>>4&8|a[9660900]&-16&255)&255;a[9660900]=(((t&65535)>>>1^t&65535)>>>6&2|(t&65535)>>>8|((t&255)<<24>>24==0?n|4:n)&255)&255;n=c[an+72+((am>>>8&255|256)<<2)>>2]|0;if((n|0)!=0){a[n+(am&255)|0]=t&255;break L40594}n=c[an+3148>>2]|0;if((n|0)==0){break L40594}gg[n&4095](am&65535,t&255);break};case 105:{t=b[4830446]|0;n=c[2415221]|0;r=c[2437644]|0;v=c[r+72+((n>>>8&255|512)<<2)>>2]|0;do{if((v|0)==0){y=c[r+3156>>2]|0;if((y|0)==0){ao=0;ap=n&65535;aq=r;break}F=gj[y&4095](n&65535)|0;ao=F;ap=b[4830442]|0;aq=c[2437644]|0}else{ao=a[v+(n&255)|0]|0;ap=n&65535;aq=r}}while(0);b[4853736]=(ao&255)+t&65535;b[4830442]=ap+1&65535;r=c[2426868]|0;n=c[aq+72+((r>>>8&255)<<2)>>2]|0;do{if((n|0)==0){v=c[aq+3144>>2]|0;if((v|0)==0){ar=0;as=r;at=aq;break}F=gj[v&4095](r&65535)|0;ar=F;as=c[2426868]|0;at=c[2437644]|0}else{ar=a[n+(r&255)|0]|0;as=r;at=aq}}while(0);r=a[9660900]|0;n=r&1|(ar&255)<<1;a[9660900]=(((n&65535)>>>1^n&65535)>>>6&2|(n&65535)>>>8|((n&255)<<24>>24==0?((n&65535)>>>4&8|r&-16&255)&255|4:((n&65535)>>>4&8|r&-16&255)&255)&255)&255;r=c[at+72+((as>>>8&255|256)<<2)>>2]|0;if((r|0)!=0){a[r+(as&255)|0]=n&255;break L40594}r=c[at+3148>>2]|0;if((r|0)==0){break L40594}gg[r&4095](as&65535,n&255);break};case 106:{n=b[4830446]|0;r=c[2415221]|0;t=c[2437644]|0;F=c[t+72+((r>>>8&255|512)<<2)>>2]|0;do{if((F|0)==0){v=c[t+3156>>2]|0;if((v|0)==0){au=0;av=r&65535;aw=t;break}y=gj[v&4095](r&65535)|0;au=y;av=b[4830442]|0;aw=c[2437644]|0}else{au=a[F+(r&255)|0]|0;av=r&65535;aw=t}}while(0);b[4853736]=(au&255)+n&65535;b[4830442]=av+1&65535;t=c[2426868]|0;r=c[aw+72+((t>>>8&255)<<2)>>2]|0;do{if((r|0)==0){F=c[aw+3144>>2]|0;if((F|0)==0){ax=0;ay=t;az=aw;break}y=gj[F&4095](t&65535)|0;ax=y;ay=c[2426868]|0;az=c[2437644]|0}else{ax=a[r+(t&255)|0]|0;ay=t;az=aw}}while(0);t=ax-1&255;a[9660900]=a[9660900]&-15|a[669184+(t&255)|0];r=c[az+72+((ay>>>8&255|256)<<2)>>2]|0;if((r|0)!=0){a[r+(ay&255)|0]=t;break L40594}r=c[az+3148>>2]|0;if((r|0)==0){break L40594}gg[r&4095](ay&65535,t);break};case 108:{t=b[4830446]|0;r=c[2415221]|0;n=c[2437644]|0;y=c[n+72+((r>>>8&255|512)<<2)>>2]|0;do{if((y|0)==0){F=c[n+3156>>2]|0;if((F|0)==0){aA=0;aB=r&65535;aC=n;break}v=gj[F&4095](r&65535)|0;aA=v;aB=b[4830442]|0;aC=c[2437644]|0}else{aA=a[y+(r&255)|0]|0;aB=r&65535;aC=n}}while(0);b[4853736]=(aA&255)+t&65535;b[4830442]=aB+1&65535;n=c[2426868]|0;r=c[aC+72+((n>>>8&255)<<2)>>2]|0;do{if((r|0)==0){y=c[aC+3144>>2]|0;if((y|0)==0){aD=0;aE=n;aF=aC;break}v=gj[y&4095](n&65535)|0;aD=v;aE=c[2426868]|0;aF=c[2437644]|0}else{aD=a[r+(n&255)|0]|0;aE=n;aF=aC}}while(0);n=aD+1&255;a[9660900]=a[9660900]&-15|a[668928+(n&255)|0];r=c[aF+72+((aE>>>8&255|256)<<2)>>2]|0;if((r|0)!=0){a[r+(aE&255)|0]=n;break L40594}r=c[aF+3148>>2]|0;if((r|0)==0){break L40594}gg[r&4095](aE&65535,n);break};case 109:{n=b[4830446]|0;r=c[2415221]|0;t=c[2437644]|0;v=c[t+72+((r>>>8&255|512)<<2)>>2]|0;do{if((v|0)==0){y=c[t+3156>>2]|0;if((y|0)==0){aG=0;aH=r&65535;aI=t;break}F=gj[y&4095](r&65535)|0;aG=F;aH=b[4830442]|0;aI=c[2437644]|0}else{aG=a[v+(r&255)|0]|0;aH=r&65535;aI=t}}while(0);b[4853736]=(aG&255)+n&65535;b[4830442]=aH+1&65535;t=c[2426868]|0;r=c[aI+72+((t>>>8&255)<<2)>>2]|0;do{if((r|0)==0){v=c[aI+3144>>2]|0;if((v|0)==0){aJ=0;break}aJ=gj[v&4095](t&65535)|0}else{aJ=a[r+(t&255)|0]|0}}while(0);t=a[9660900]&-16|(aJ&255)>>>4&8;a[9660900]=aJ<<24>>24==0?t|4:t;break};case 110:{t=b[4830446]|0;r=c[2415221]|0;n=c[2437644]|0;v=c[n+72+((r>>>8&255|512)<<2)>>2]|0;do{if((v|0)==0){F=c[n+3156>>2]|0;if((F|0)==0){aK=0;break}aK=gj[F&4095](r&65535)|0}else{aK=a[v+(r&255)|0]|0}}while(0);r=(aK&255)+t&65535;b[4853736]=r;b[4830442]=r;b[4830442]=c[2415221]&65535;break};case 111:{r=b[4830446]|0;v=c[2415221]|0;n=c[2437644]|0;F=c[n+72+((v>>>8&255|512)<<2)>>2]|0;do{if((F|0)==0){y=c[n+3156>>2]|0;if((y|0)==0){aL=0;aM=v&65535;aN=n;break}aO=gj[y&4095](v&65535)|0;aL=aO;aM=b[4830442]|0;aN=c[2437644]|0}else{aL=a[F+(v&255)|0]|0;aM=v&65535;aN=n}}while(0);b[4853736]=(aL&255)+r&65535;b[4830442]=aM+1&65535;n=c[2426868]|0;v=c[aN+72+((n>>>8&255|256)<<2)>>2]|0;do{if((v|0)==0){F=c[aN+3148>>2]|0;if((F|0)==0){break}gg[F&4095](n&65535,0)}else{a[v+(n&255)|0]=0}}while(0);a[9660900]=a[9660900]&-16|4;break};case 112:{n=c[2415221]|0;v=c[2437644]|0;r=c[v+72+((n>>>8&255|512)<<2)>>2]|0;do{if((r|0)==0){F=c[v+3156>>2]|0;if((F|0)==0){aP=0;aQ=n;aR=v;aS=n&65535;break}t=gj[F&4095](n&65535)|0;F=c[2415221]|0;aP=t;aQ=F;aR=c[2437644]|0;aS=F&65535}else{aP=a[r+(n&255)|0]|0;aQ=n;aR=v;aS=n&65535}}while(0);n=aP&255;v=aQ+1|0;r=c[aR+72+((v>>>8&255|512)<<2)>>2]|0;do{if((r|0)==0){F=c[aR+3156>>2]|0;if((F|0)==0){aT=0;aU=aS;aV=aR;break}t=gj[F&4095](v&65535)|0;aT=t;aU=b[4830442]|0;aV=c[2437644]|0}else{aT=a[r+(v&255)|0]|0;aU=aS;aV=aR}}while(0);v=aT&255;c[2426868]=v|n<<8;b[4830442]=aU+2&65535;r=c[aV+72+(n<<2)>>2]|0;do{if((r|0)==0){t=c[aV+3144>>2]|0;if((t|0)==0){aW=0;aX=v|n<<8;aY=aV;break}F=gj[t&4095]((v|n<<8)&65535)|0;aW=F;aX=c[2426868]|0;aY=c[2437644]|0}else{aW=a[r+v|0]|0;aX=v|n<<8;aY=aV}}while(0);n=aW&255;v=(a[9660900]&-16&255|(-n|0)>>>4&8)&255;a[9660900]=((n^(-n|0)^(-n|0)>>>1)>>>6&2|(-n|0)>>>8&1|(((-n|0)&255)<<24>>24==0?v|4:v)&255)&255;v=c[aY+72+((aX>>>8&255|256)<<2)>>2]|0;if((v|0)!=0){a[v+(aX&255)|0]=(-n|0)&255;break L40594}v=c[aY+3148>>2]|0;if((v|0)==0){break L40594}gg[v&4095](aX&65535,(-n|0)&255);break};case 115:{n=c[2415221]|0;v=c[2437644]|0;r=c[v+72+((n>>>8&255|512)<<2)>>2]|0;do{if((r|0)==0){F=c[v+3156>>2]|0;if((F|0)==0){aZ=0;a_=n;a$=v;a0=n&65535;break}t=gj[F&4095](n&65535)|0;F=c[2415221]|0;aZ=t;a_=F;a$=c[2437644]|0;a0=F&65535}else{aZ=a[r+(n&255)|0]|0;a_=n;a$=v;a0=n&65535}}while(0);n=aZ&255;v=a_+1|0;r=c[a$+72+((v>>>8&255|512)<<2)>>2]|0;do{if((r|0)==0){F=c[a$+3156>>2]|0;if((F|0)==0){a1=0;a2=a0;a3=a$;break}t=gj[F&4095](v&65535)|0;a1=t;a2=b[4830442]|0;a3=c[2437644]|0}else{a1=a[r+(v&255)|0]|0;a2=a0;a3=a$}}while(0);v=a1&255;c[2426868]=v|n<<8;b[4830442]=a2+2&65535;r=c[a3+72+(n<<2)>>2]|0;do{if((r|0)==0){t=c[a3+3144>>2]|0;if((t|0)==0){a4=0;a5=v|n<<8;a6=a3;break}F=gj[t&4095]((v|n<<8)&65535)|0;a4=F;a5=c[2426868]|0;a6=c[2437644]|0}else{a4=a[r+v|0]|0;a5=v|n<<8;a6=a3}}while(0);n=~a4;v=a[9660900]&-15|(n&255)>>>4&8;a[9660900]=(a4<<24>>24==-1?v|4:v)|1;v=c[a6+72+((a5>>>8&255|256)<<2)>>2]|0;if((v|0)!=0){a[v+(a5&255)|0]=n;break L40594}v=c[a6+3148>>2]|0;if((v|0)==0){break L40594}gg[v&4095](a5&65535,n);break};case 116:{n=c[2415221]|0;v=c[2437644]|0;r=c[v+72+((n>>>8&255|512)<<2)>>2]|0;do{if((r|0)==0){F=c[v+3156>>2]|0;if((F|0)==0){a7=0;a8=n;a9=v;ba=n&65535;break}t=gj[F&4095](n&65535)|0;F=c[2415221]|0;a7=t;a8=F;a9=c[2437644]|0;ba=F&65535}else{a7=a[r+(n&255)|0]|0;a8=n;a9=v;ba=n&65535}}while(0);n=a7&255;v=a8+1|0;r=c[a9+72+((v>>>8&255|512)<<2)>>2]|0;do{if((r|0)==0){F=c[a9+3156>>2]|0;if((F|0)==0){bb=0;bc=ba;bd=a9;break}t=gj[F&4095](v&65535)|0;bb=t;bc=b[4830442]|0;bd=c[2437644]|0}else{bb=a[r+(v&255)|0]|0;bc=ba;bd=a9}}while(0);v=bb&255;c[2426868]=v|n<<8;b[4830442]=bc+2&65535;r=c[bd+72+(n<<2)>>2]|0;do{if((r|0)==0){t=c[bd+3144>>2]|0;if((t|0)==0){be=0;bf=v|n<<8;bg=bd;break}F=gj[t&4095]((v|n<<8)&65535)|0;be=F;bf=c[2426868]|0;bg=c[2437644]|0}else{be=a[r+v|0]|0;bf=v|n<<8;bg=bd}}while(0);n=a[9660900]&-14|be&1;v=(be&255)>>>1;a[9660900]=v<<24>>24==0?n|4:n;n=c[bg+72+((bf>>>8&255|256)<<2)>>2]|0;if((n|0)!=0){a[n+(bf&255)|0]=v;break L40594}n=c[bg+3148>>2]|0;if((n|0)==0){break L40594}gg[n&4095](bf&65535,v);break};case 118:{v=c[2415221]|0;n=c[2437644]|0;r=c[n+72+((v>>>8&255|512)<<2)>>2]|0;do{if((r|0)==0){F=c[n+3156>>2]|0;if((F|0)==0){bh=0;bi=v;bj=n;bk=v&65535;break}t=gj[F&4095](v&65535)|0;F=c[2415221]|0;bh=t;bi=F;bj=c[2437644]|0;bk=F&65535}else{bh=a[r+(v&255)|0]|0;bi=v;bj=n;bk=v&65535}}while(0);v=bh&255;n=bi+1|0;r=c[bj+72+((n>>>8&255|512)<<2)>>2]|0;do{if((r|0)==0){F=c[bj+3156>>2]|0;if((F|0)==0){bl=0;bm=bk;bn=bj;break}t=gj[F&4095](n&65535)|0;bl=t;bm=b[4830442]|0;bn=c[2437644]|0}else{bl=a[r+(n&255)|0]|0;bm=bk;bn=bj}}while(0);n=bl&255;c[2426868]=n|v<<8;b[4830442]=bm+2&65535;r=c[bn+72+(v<<2)>>2]|0;do{if((r|0)==0){t=c[bn+3144>>2]|0;if((t|0)==0){bo=0;bp=n|v<<8;bq=bn;break}F=gj[t&4095]((n|v<<8)&65535)|0;bo=F;bp=c[2426868]|0;bq=c[2437644]|0}else{bo=a[r+n|0]|0;bp=n|v<<8;bq=bn}}while(0);v=a[9660900]|0;n=v<<7|(bo&255)>>>1;r=v&-14|bo&1|v<<3&8;a[9660900]=n<<24>>24==0?r|4:r;r=c[bq+72+((bp>>>8&255|256)<<2)>>2]|0;if((r|0)!=0){a[r+(bp&255)|0]=n;break L40594}r=c[bq+3148>>2]|0;if((r|0)==0){break L40594}gg[r&4095](bp&65535,n);break};case 119:{n=c[2415221]|0;r=c[2437644]|0;v=c[r+72+((n>>>8&255|512)<<2)>>2]|0;do{if((v|0)==0){F=c[r+3156>>2]|0;if((F|0)==0){br=0;bs=n;bt=r;bu=n&65535;break}t=gj[F&4095](n&65535)|0;F=c[2415221]|0;br=t;bs=F;bt=c[2437644]|0;bu=F&65535}else{br=a[v+(n&255)|0]|0;bs=n;bt=r;bu=n&65535}}while(0);n=br&255;r=bs+1|0;v=c[bt+72+((r>>>8&255|512)<<2)>>2]|0;do{if((v|0)==0){F=c[bt+3156>>2]|0;if((F|0)==0){bv=0;bw=bu;bx=bt;break}t=gj[F&4095](r&65535)|0;bv=t;bw=b[4830442]|0;bx=c[2437644]|0}else{bv=a[v+(r&255)|0]|0;bw=bu;bx=bt}}while(0);r=bv&255;c[2426868]=r|n<<8;b[4830442]=bw+2&65535;v=c[bx+72+(n<<2)>>2]|0;do{if((v|0)==0){t=c[bx+3144>>2]|0;if((t|0)==0){by=0;bz=r|n<<8;bA=bx;break}F=gj[t&4095]((r|n<<8)&65535)|0;by=F;bz=c[2426868]|0;bA=c[2437644]|0}else{by=a[v+r|0]|0;bz=r|n<<8;bA=bx}}while(0);n=(by&255)>>>1;r=a[9660900]&-14|by&1|(by&255)>>>4&8;a[9660900]=(n<<1&-128|n)<<24>>24==0?r|4:r;r=c[bA+72+((bz>>>8&255|256)<<2)>>2]|0;if((r|0)!=0){a[r+(bz&255)|0]=n<<1&-128|n;break L40594}r=c[bA+3148>>2]|0;if((r|0)==0){break L40594}gg[r&4095](bz&65535,n<<1&-128|n);break};default:{l=1}}}if(l){l=0;switch(q|0){case 120:{n=c[2415221]|0;r=c[2437644]|0;v=c[r+72+((n>>>8&255|512)<<2)>>2]|0;do{if((v|0)==0){F=c[r+3156>>2]|0;if((F|0)==0){bB=0;bC=n;bD=r;bE=n&65535;break}t=gj[F&4095](n&65535)|0;F=c[2415221]|0;bB=t;bC=F;bD=c[2437644]|0;bE=F&65535}else{bB=a[v+(n&255)|0]|0;bC=n;bD=r;bE=n&65535}}while(0);n=bB&255;r=bC+1|0;v=c[bD+72+((r>>>8&255|512)<<2)>>2]|0;do{if((v|0)==0){F=c[bD+3156>>2]|0;if((F|0)==0){bF=0;bG=bE;bH=bD;break}t=gj[F&4095](r&65535)|0;bF=t;bG=b[4830442]|0;bH=c[2437644]|0}else{bF=a[v+(r&255)|0]|0;bG=bE;bH=bD}}while(0);r=bF&255;c[2426868]=r|n<<8;b[4830442]=bG+2&65535;v=c[bH+72+(n<<2)>>2]|0;do{if((v|0)==0){t=c[bH+3144>>2]|0;if((t|0)==0){bI=0;bJ=r|n<<8;bK=bH;break}F=gj[t&4095]((r|n<<8)&65535)|0;bI=F;bJ=c[2426868]|0;bK=c[2437644]|0}else{bI=a[v+r|0]|0;bJ=r|n<<8;bK=bH}}while(0);n=(bI&255)<<1;r=((n&65535)>>>4&8|a[9660900]&-16&255)&255;a[9660900]=(((n&65535)>>>1^n&65535)>>>6&2|(n&65535)>>>8|((n&255)<<24>>24==0?r|4:r)&255)&255;r=c[bK+72+((bJ>>>8&255|256)<<2)>>2]|0;if((r|0)!=0){a[r+(bJ&255)|0]=n&255;break L40594}r=c[bK+3148>>2]|0;if((r|0)==0){break L40594}gg[r&4095](bJ&65535,n&255);break};case 121:{n=c[2415221]|0;r=c[2437644]|0;v=c[r+72+((n>>>8&255|512)<<2)>>2]|0;do{if((v|0)==0){F=c[r+3156>>2]|0;if((F|0)==0){bL=0;bM=n;bN=r;bO=n&65535;break}t=gj[F&4095](n&65535)|0;F=c[2415221]|0;bL=t;bM=F;bN=c[2437644]|0;bO=F&65535}else{bL=a[v+(n&255)|0]|0;bM=n;bN=r;bO=n&65535}}while(0);n=bL&255;r=bM+1|0;v=c[bN+72+((r>>>8&255|512)<<2)>>2]|0;do{if((v|0)==0){F=c[bN+3156>>2]|0;if((F|0)==0){bP=0;bQ=bO;bR=bN;break}t=gj[F&4095](r&65535)|0;bP=t;bQ=b[4830442]|0;bR=c[2437644]|0}else{bP=a[v+(r&255)|0]|0;bQ=bO;bR=bN}}while(0);r=bP&255;c[2426868]=r|n<<8;b[4830442]=bQ+2&65535;v=c[bR+72+(n<<2)>>2]|0;do{if((v|0)==0){t=c[bR+3144>>2]|0;if((t|0)==0){bS=0;bT=r|n<<8;bU=bR;break}F=gj[t&4095]((r|n<<8)&65535)|0;bS=F;bT=c[2426868]|0;bU=c[2437644]|0}else{bS=a[v+r|0]|0;bT=r|n<<8;bU=bR}}while(0);n=a[9660900]|0;r=n&1|(bS&255)<<1;a[9660900]=(((r&65535)>>>1^r&65535)>>>6&2|(r&65535)>>>8|((r&255)<<24>>24==0?((r&65535)>>>4&8|n&-16&255)&255|4:((r&65535)>>>4&8|n&-16&255)&255)&255)&255;n=c[bU+72+((bT>>>8&255|256)<<2)>>2]|0;if((n|0)!=0){a[n+(bT&255)|0]=r&255;break L40594}n=c[bU+3148>>2]|0;if((n|0)==0){break L40594}gg[n&4095](bT&65535,r&255);break};case 122:{r=c[2415221]|0;n=c[2437644]|0;v=c[n+72+((r>>>8&255|512)<<2)>>2]|0;do{if((v|0)==0){F=c[n+3156>>2]|0;if((F|0)==0){bV=0;bW=r;bX=n;bY=r&65535;break}t=gj[F&4095](r&65535)|0;F=c[2415221]|0;bV=t;bW=F;bX=c[2437644]|0;bY=F&65535}else{bV=a[v+(r&255)|0]|0;bW=r;bX=n;bY=r&65535}}while(0);r=bV&255;n=bW+1|0;v=c[bX+72+((n>>>8&255|512)<<2)>>2]|0;do{if((v|0)==0){F=c[bX+3156>>2]|0;if((F|0)==0){bZ=0;b_=bY;b$=bX;break}t=gj[F&4095](n&65535)|0;bZ=t;b_=b[4830442]|0;b$=c[2437644]|0}else{bZ=a[v+(n&255)|0]|0;b_=bY;b$=bX}}while(0);n=bZ&255;c[2426868]=n|r<<8;b[4830442]=b_+2&65535;v=c[b$+72+(r<<2)>>2]|0;do{if((v|0)==0){t=c[b$+3144>>2]|0;if((t|0)==0){b0=0;b1=n|r<<8;b2=b$;break}F=gj[t&4095]((n|r<<8)&65535)|0;b0=F;b1=c[2426868]|0;b2=c[2437644]|0}else{b0=a[v+n|0]|0;b1=n|r<<8;b2=b$}}while(0);r=b0-1&255;a[9660900]=a[9660900]&-15|a[669184+(r&255)|0];n=c[b2+72+((b1>>>8&255|256)<<2)>>2]|0;if((n|0)!=0){a[n+(b1&255)|0]=r;break L40594}n=c[b2+3148>>2]|0;if((n|0)==0){break L40594}gg[n&4095](b1&65535,r);break};case 124:{r=c[2415221]|0;n=c[2437644]|0;v=c[n+72+((r>>>8&255|512)<<2)>>2]|0;do{if((v|0)==0){F=c[n+3156>>2]|0;if((F|0)==0){b3=0;b4=r;b5=n;b6=r&65535;break}t=gj[F&4095](r&65535)|0;F=c[2415221]|0;b3=t;b4=F;b5=c[2437644]|0;b6=F&65535}else{b3=a[v+(r&255)|0]|0;b4=r;b5=n;b6=r&65535}}while(0);r=b3&255;n=b4+1|0;v=c[b5+72+((n>>>8&255|512)<<2)>>2]|0;do{if((v|0)==0){F=c[b5+3156>>2]|0;if((F|0)==0){b7=0;b8=b6;b9=b5;break}t=gj[F&4095](n&65535)|0;b7=t;b8=b[4830442]|0;b9=c[2437644]|0}else{b7=a[v+(n&255)|0]|0;b8=b6;b9=b5}}while(0);n=b7&255;c[2426868]=n|r<<8;b[4830442]=b8+2&65535;v=c[b9+72+(r<<2)>>2]|0;do{if((v|0)==0){t=c[b9+3144>>2]|0;if((t|0)==0){ca=0;cb=n|r<<8;cc=b9;break}F=gj[t&4095]((n|r<<8)&65535)|0;ca=F;cb=c[2426868]|0;cc=c[2437644]|0}else{ca=a[v+n|0]|0;cb=n|r<<8;cc=b9}}while(0);r=ca+1&255;a[9660900]=a[9660900]&-15|a[668928+(r&255)|0];n=c[cc+72+((cb>>>8&255|256)<<2)>>2]|0;if((n|0)!=0){a[n+(cb&255)|0]=r;break L40594}n=c[cc+3148>>2]|0;if((n|0)==0){break L40594}gg[n&4095](cb&65535,r);break};case 125:{r=c[2415221]|0;n=c[2437644]|0;v=c[n+72+((r>>>8&255|512)<<2)>>2]|0;do{if((v|0)==0){F=c[n+3156>>2]|0;if((F|0)==0){cd=0;ce=r;cf=n;cg=r&65535;break}t=gj[F&4095](r&65535)|0;F=c[2415221]|0;cd=t;ce=F;cf=c[2437644]|0;cg=F&65535}else{cd=a[v+(r&255)|0]|0;ce=r;cf=n;cg=r&65535}}while(0);r=cd&255;n=ce+1|0;v=c[cf+72+((n>>>8&255|512)<<2)>>2]|0;do{if((v|0)==0){F=c[cf+3156>>2]|0;if((F|0)==0){ch=0;ci=cg;cj=cf;break}t=gj[F&4095](n&65535)|0;ch=t;ci=b[4830442]|0;cj=c[2437644]|0}else{ch=a[v+(n&255)|0]|0;ci=cg;cj=cf}}while(0);n=ch&255;c[2426868]=n|r<<8;b[4830442]=ci+2&65535;v=c[cj+72+(r<<2)>>2]|0;do{if((v|0)==0){t=c[cj+3144>>2]|0;if((t|0)==0){ck=0;break}ck=gj[t&4095]((n|r<<8)&65535)|0}else{ck=a[v+n|0]|0}}while(0);n=a[9660900]&-16|(ck&255)>>>4&8;a[9660900]=ck<<24>>24==0?n|4:n;break};case 126:{n=c[2415221]|0;v=c[2437644]|0;r=c[v+72+((n>>>8&255|512)<<2)>>2]|0;do{if((r|0)==0){t=c[v+3156>>2]|0;if((t|0)==0){cl=0;cm=n;cn=v;break}F=gj[t&4095](n&65535)|0;cl=F;cm=c[2415221]|0;cn=c[2437644]|0}else{cl=a[r+(n&255)|0]|0;cm=n;cn=v}}while(0);v=(cl&255)<<8;n=cm+1|0;r=c[cn+72+((n>>>8&255|512)<<2)>>2]|0;do{if((r|0)==0){F=c[cn+3156>>2]|0;if((F|0)==0){co=0;break}co=gj[F&4095](n&65535)|0}else{co=a[r+(n&255)|0]|0}}while(0);n=co&255|v;c[2426868]=n;b[4830442]=n&65535;b[4830442]=c[2415221]&65535;break};case 127:{n=c[2415221]|0;r=c[2437644]|0;F=c[r+72+((n>>>8&255|512)<<2)>>2]|0;do{if((F|0)==0){t=c[r+3156>>2]|0;if((t|0)==0){cp=0;cq=n;cr=r;cs=n&65535;break}aO=gj[t&4095](n&65535)|0;t=c[2415221]|0;cp=aO;cq=t;cr=c[2437644]|0;cs=t&65535}else{cp=a[F+(n&255)|0]|0;cq=n;cr=r;cs=n&65535}}while(0);n=cp&255;r=cq+1|0;F=c[cr+72+((r>>>8&255|512)<<2)>>2]|0;do{if((F|0)==0){v=c[cr+3156>>2]|0;if((v|0)==0){ct=0;cu=cs;cv=cr;break}t=gj[v&4095](r&65535)|0;ct=t;cu=b[4830442]|0;cv=c[2437644]|0}else{ct=a[F+(r&255)|0]|0;cu=cs;cv=cr}}while(0);r=ct&255;c[2426868]=r|n<<8;b[4830442]=cu+2&65535;F=c[cv+72+((n|256)<<2)>>2]|0;do{if((F|0)==0){t=c[cv+3148>>2]|0;if((t|0)==0){break}gg[t&4095]((r|n<<8)&65535,0)}else{a[F+r|0]=0}}while(0);a[9660900]=a[9660900]&-16|4;break};case 128:{r=c[2415221]|0;F=c[2437644]|0;n=c[F+72+((r>>>8&255|512)<<2)>>2]|0;do{if((n|0)==0){t=c[F+3156>>2]|0;if((t|0)==0){cw=0;cx=r&65535;break}v=gj[t&4095](r&65535)|0;cw=v;cx=b[4830442]|0}else{cw=a[n+(r&255)|0]|0;cx=r&65535}}while(0);b[4830442]=cx+1&65535;r=a[9660897]|0;n=(r&255)-(cw&255)|0;F=(n>>>4&8|a[9660900]&-16&255)&255;a[9660900]=(((r^cw)&255^n^n>>>1)>>>6&2|n>>>8&1|((n&255)<<24>>24==0?F|4:F)&255)&255;a[9660897]=n&255;break};case 129:{n=c[2415221]|0;F=c[2437644]|0;r=c[F+72+((n>>>8&255|512)<<2)>>2]|0;do{if((r|0)==0){v=c[F+3156>>2]|0;if((v|0)==0){cy=0;cz=n&65535;break}t=gj[v&4095](n&65535)|0;cy=t;cz=b[4830442]|0}else{cy=a[r+(n&255)|0]|0;cz=n&65535}}while(0);b[4830442]=cz+1&65535;n=a[9660897]|0;r=(n&255)-(cy&255)|0;F=(r>>>4&8|a[9660900]&-16&255)&255;a[9660900]=(((n^cy)&255^r^r>>>1)>>>6&2|r>>>8&1|((r&255)<<24>>24==0?F|4:F)&255)&255;break};case 130:{F=c[2415221]|0;r=c[2437644]|0;n=c[r+72+((F>>>8&255|512)<<2)>>2]|0;do{if((n|0)==0){t=c[r+3156>>2]|0;if((t|0)==0){cA=0;cB=F&65535;break}v=gj[t&4095](F&65535)|0;cA=v;cB=b[4830442]|0}else{cA=a[n+(F&255)|0]|0;cB=F&65535}}while(0);b[4830442]=cB+1&65535;F=a[9660897]|0;n=a[9660900]|0;r=(F&255)-(cA&255)-(n&1)|0;a[9660900]=((r^(F^cA)&255^r>>>1)>>>6&2|r>>>8&1|((r&255)<<24>>24==0?(r>>>4&8|n&-16&255)&255|4:(r>>>4&8|n&-16&255)&255)&255)&255;a[9660897]=r&255;break};case 131:{r=c[2415221]|0;n=c[2437644]|0;F=c[n+72+((r>>>8&255|512)<<2)>>2]|0;do{if((F|0)==0){v=c[n+3156>>2]|0;if((v|0)==0){cC=0;cD=r;cE=n;cF=r&65535;break}t=gj[v&4095](r&65535)|0;v=c[2415221]|0;cC=t;cD=v;cE=c[2437644]|0;cF=v&65535}else{cC=a[F+(r&255)|0]|0;cD=r;cE=n;cF=r&65535}}while(0);r=(cC&255)<<8;n=cD+1|0;F=c[cE+72+((n>>>8&255|512)<<2)>>2]|0;do{if((F|0)==0){v=c[cE+3156>>2]|0;if((v|0)==0){cG=0;cH=cF;break}t=gj[v&4095](n&65535)|0;cG=t;cH=b[4830442]|0}else{cG=a[F+(n&255)|0]|0;cH=cF}}while(0);b[4830442]=cH+2&65535;n=e[4830448]|0;F=n-(cG&255|r)|0;t=(F>>>12&8|a[9660900]&-16&255)&255;a[9660900]=((n^r^F^F>>>1)>>>14&2|F>>>16&1|((F&65535)<<16>>16==0?t|4:t)&255)&255;b[4830448]=F&65535;break};case 132:{F=c[2415221]|0;t=c[2437644]|0;n=c[t+72+((F>>>8&255|512)<<2)>>2]|0;do{if((n|0)==0){v=c[t+3156>>2]|0;if((v|0)==0){cI=0;cJ=F&65535;break}aO=gj[v&4095](F&65535)|0;cI=aO;cJ=b[4830442]|0}else{cI=a[n+(F&255)|0]|0;cJ=F&65535}}while(0);b[4830442]=cJ+1&65535;F=a[9660897]&cI;a[9660897]=F;n=(F&255)>>>4&8|a[9660900]&-15;a[9660900]=F<<24>>24==0?n|4:n;break};case 133:{n=c[2415221]|0;F=c[2437644]|0;t=c[F+72+((n>>>8&255|512)<<2)>>2]|0;do{if((t|0)==0){r=c[F+3156>>2]|0;if((r|0)==0){cK=0;cL=n&65535;break}aO=gj[r&4095](n&65535)|0;cK=aO;cL=b[4830442]|0}else{cK=a[t+(n&255)|0]|0;cL=n&65535}}while(0);b[4830442]=cL+1&65535;n=a[9660897]&cK;t=(n&255)>>>4&8|a[9660900]&-15;a[9660900]=n<<24>>24==0?t|4:t;break};case 134:{t=c[2415221]|0;n=c[2437644]|0;F=c[n+72+((t>>>8&255|512)<<2)>>2]|0;do{if((F|0)==0){aO=c[n+3156>>2]|0;if((aO|0)==0){cM=0;cN=t&65535;break}r=gj[aO&4095](t&65535)|0;cM=r;cN=b[4830442]|0}else{cM=a[F+(t&255)|0]|0;cN=t&65535}}while(0);a[9660897]=cM;b[4830442]=cN+1&65535;t=a[9660900]&-15|(cM&255)>>>4&8;a[9660900]=cM<<24>>24==0?t|4:t;break};case 135:{t=a[9660897]|0;F=(t&255)>>>4&8|a[9660900]&-15;a[9660900]=t<<24>>24==0?F|4:F;b[4830442]=p+2&65535;b[4853736]=k;F=c[2426868]|0;n=c[2437644]|0;r=c[n+72+((F>>>8&255|256)<<2)>>2]|0;if((r|0)!=0){a[r+(F&255)|0]=t;break L40594}r=c[n+3148>>2]|0;if((r|0)==0){break L40594}gg[r&4095](F&65535,t);break};case 136:{t=c[2415221]|0;F=c[2437644]|0;r=c[F+72+((t>>>8&255|512)<<2)>>2]|0;do{if((r|0)==0){n=c[F+3156>>2]|0;if((n|0)==0){cO=0;cP=t&65535;break}aO=gj[n&4095](t&65535)|0;cO=aO;cP=b[4830442]|0}else{cO=a[r+(t&255)|0]|0;cP=t&65535}}while(0);b[4830442]=cP+1&65535;t=a[9660897]|0;r=t^cO;a[9660897]=r;F=(r&255)>>>4&8|a[9660900]&-15;a[9660900]=t<<24>>24==cO<<24>>24?F|4:F;break};case 137:{F=c[2415221]|0;t=c[2437644]|0;r=c[t+72+((F>>>8&255|512)<<2)>>2]|0;do{if((r|0)==0){aO=c[t+3156>>2]|0;if((aO|0)==0){cQ=0;cR=F&65535;break}n=gj[aO&4095](F&65535)|0;cQ=n;cR=b[4830442]|0}else{cQ=a[r+(F&255)|0]|0;cR=F&65535}}while(0);b[4830442]=cR+1&65535;F=a[9660897]|0;r=a[9660900]|0;t=(F&255)+(cQ&255)+(r&1)|0;n=t^(F^cQ)&255;a[9660900]=(n<<1&32|t>>>8&1|(n^t>>>1)>>>6&2|((t&255)<<24>>24==0?(t>>>4&8|r&-48&255)&255|4:(t>>>4&8|r&-48&255)&255)&255)&255;a[9660897]=t&255;break};case 138:{t=c[2415221]|0;r=c[2437644]|0;n=c[r+72+((t>>>8&255|512)<<2)>>2]|0;do{if((n|0)==0){F=c[r+3156>>2]|0;if((F|0)==0){cS=0;cT=t&65535;break}aO=gj[F&4095](t&65535)|0;cS=aO;cT=b[4830442]|0}else{cS=a[n+(t&255)|0]|0;cT=t&65535}}while(0);b[4830442]=cT+1&65535;t=a[9660897]|cS;a[9660897]=t;n=(t&255)>>>4&8|a[9660900]&-15;a[9660900]=t<<24>>24==0?n|4:n;break};case 139:{n=c[2415221]|0;t=c[2437644]|0;r=c[t+72+((n>>>8&255|512)<<2)>>2]|0;do{if((r|0)==0){aO=c[t+3156>>2]|0;if((aO|0)==0){cU=0;cV=n&65535;break}F=gj[aO&4095](n&65535)|0;cU=F;cV=b[4830442]|0}else{cU=a[r+(n&255)|0]|0;cV=n&65535}}while(0);b[4830442]=cV+1&65535;n=a[9660897]|0;r=(n&255)+(cU&255)|0;t=(r>>>4&8|a[9660900]&-48&255)&255;F=(n^cU)&255^r;a[9660900]=(F<<1&32|r>>>8&1|(F^r>>>1)>>>6&2|((r&255)<<24>>24==0?t|4:t)&255)&255;a[9660897]=r&255;break};case 140:{r=c[2415221]|0;t=c[2437644]|0;F=c[t+72+((r>>>8&255|512)<<2)>>2]|0;do{if((F|0)==0){n=c[t+3156>>2]|0;if((n|0)==0){cW=0;cX=r;cY=t;cZ=r&65535;break}aO=gj[n&4095](r&65535)|0;n=c[2415221]|0;cW=aO;cX=n;cY=c[2437644]|0;cZ=n&65535}else{cW=a[F+(r&255)|0]|0;cX=r;cY=t;cZ=r&65535}}while(0);r=(cW&255)<<8;t=cX+1|0;F=c[cY+72+((t>>>8&255|512)<<2)>>2]|0;do{if((F|0)==0){n=c[cY+3156>>2]|0;if((n|0)==0){c_=0;c$=cZ;break}aO=gj[n&4095](t&65535)|0;c_=aO;c$=b[4830442]|0}else{c_=a[F+(t&255)|0]|0;c$=cZ}}while(0);b[4830442]=c$+2&65535;t=e[4830446]|0;F=t-(c_&255|r)|0;aO=(F>>>12&8|a[9660900]&-16&255)&255;a[9660900]=((t^r^F^F>>>1)>>>14&2|F>>>16&1|((F&65535)<<16>>16==0?aO|4:aO)&255)&255;break};case 36:{aO=c[2415221]|0;F=c[2437644]|0;t=c[F+72+((aO>>>8&255|512)<<2)>>2]|0;do{if((t|0)==0){n=c[F+3156>>2]|0;if((n|0)==0){c0=0;c1=aO&65535;break}v=gj[n&4095](aO&65535)|0;c0=v;c1=b[4830442]|0}else{c0=a[t+(aO&255)|0]|0;c1=aO&65535}}while(0);aO=c1+1&65535;b[4830442]=aO;if((a[9660900]&1)!=0){break L40594}t=c0&255;b[4830442]=((t&128|0)!=0?t|65280:t)+(aO&65535)&65535;b[4830442]=c[2415221]&65535;break};case 37:{aO=c[2415221]|0;t=c[2437644]|0;F=c[t+72+((aO>>>8&255|512)<<2)>>2]|0;do{if((F|0)==0){r=c[t+3156>>2]|0;if((r|0)==0){c2=0;c3=aO&65535;break}v=gj[r&4095](aO&65535)|0;c2=v;c3=b[4830442]|0}else{c2=a[F+(aO&255)|0]|0;c3=aO&65535}}while(0);aO=c3+1&65535;b[4830442]=aO;if((a[9660900]&1)==0){break L40594}F=c2&255;b[4830442]=((F&128|0)!=0?F|65280:F)+(aO&65535)&65535;b[4830442]=c[2415221]&65535;break};case 38:{aO=c[2415221]|0;F=c[2437644]|0;t=c[F+72+((aO>>>8&255|512)<<2)>>2]|0;do{if((t|0)==0){v=c[F+3156>>2]|0;if((v|0)==0){c4=0;c5=aO&65535;break}r=gj[v&4095](aO&65535)|0;c4=r;c5=b[4830442]|0}else{c4=a[t+(aO&255)|0]|0;c5=aO&65535}}while(0);aO=c5+1&65535;b[4830442]=aO;if((a[9660900]&4)!=0){break L40594}t=c4&255;b[4830442]=((t&128|0)!=0?t|65280:t)+(aO&65535)&65535;b[4830442]=c[2415221]&65535;break};case 39:{aO=c[2415221]|0;t=c[2437644]|0;F=c[t+72+((aO>>>8&255|512)<<2)>>2]|0;do{if((F|0)==0){r=c[t+3156>>2]|0;if((r|0)==0){c6=0;c7=aO&65535;break}v=gj[r&4095](aO&65535)|0;c6=v;c7=b[4830442]|0}else{c6=a[F+(aO&255)|0]|0;c7=aO&65535}}while(0);aO=c7+1&65535;b[4830442]=aO;if((a[9660900]&4)==0){break L40594}F=c6&255;b[4830442]=((F&128|0)!=0?F|65280:F)+(aO&65535)&65535;b[4830442]=c[2415221]&65535;break};case 40:{aO=c[2415221]|0;F=c[2437644]|0;t=c[F+72+((aO>>>8&255|512)<<2)>>2]|0;do{if((t|0)==0){v=c[F+3156>>2]|0;if((v|0)==0){c8=0;c9=aO&65535;break}r=gj[v&4095](aO&65535)|0;c8=r;c9=b[4830442]|0}else{c8=a[t+(aO&255)|0]|0;c9=aO&65535}}while(0);aO=c9+1&65535;b[4830442]=aO;if((a[9660900]&2)!=0){break L40594}t=c8&255;b[4830442]=((t&128|0)!=0?t|65280:t)+(aO&65535)&65535;b[4830442]=c[2415221]&65535;break};case 41:{aO=c[2415221]|0;t=c[2437644]|0;F=c[t+72+((aO>>>8&255|512)<<2)>>2]|0;do{if((F|0)==0){r=c[t+3156>>2]|0;if((r|0)==0){da=0;db=aO&65535;break}v=gj[r&4095](aO&65535)|0;da=v;db=b[4830442]|0}else{da=a[F+(aO&255)|0]|0;db=aO&65535}}while(0);aO=db+1&65535;b[4830442]=aO;if((a[9660900]&2)==0){break L40594}F=da&255;b[4830442]=((F&128|0)!=0?F|65280:F)+(aO&65535)&65535;b[4830442]=c[2415221]&65535;break};case 42:{aO=c[2415221]|0;F=c[2437644]|0;t=c[F+72+((aO>>>8&255|512)<<2)>>2]|0;do{if((t|0)==0){v=c[F+3156>>2]|0;if((v|0)==0){dc=0;dd=aO&65535;break}r=gj[v&4095](aO&65535)|0;dc=r;dd=b[4830442]|0}else{dc=a[t+(aO&255)|0]|0;dd=aO&65535}}while(0);aO=dd+1&65535;b[4830442]=aO;if((a[9660900]&8)!=0){break L40594}t=dc&255;b[4830442]=((t&128|0)!=0?t|65280:t)+(aO&65535)&65535;b[4830442]=c[2415221]&65535;break};case 43:{aO=c[2415221]|0;t=c[2437644]|0;F=c[t+72+((aO>>>8&255|512)<<2)>>2]|0;do{if((F|0)==0){r=c[t+3156>>2]|0;if((r|0)==0){de=0;df=aO&65535;break}v=gj[r&4095](aO&65535)|0;de=v;df=b[4830442]|0}else{de=a[F+(aO&255)|0]|0;df=aO&65535}}while(0);aO=df+1&65535;b[4830442]=aO;if((a[9660900]&8)==0){break L40594}F=de&255;b[4830442]=((F&128|0)!=0?F|65280:F)+(aO&65535)&65535;b[4830442]=c[2415221]&65535;break};case 44:{aO=c[2415221]|0;F=c[2437644]|0;t=c[F+72+((aO>>>8&255|512)<<2)>>2]|0;do{if((t|0)==0){v=c[F+3156>>2]|0;if((v|0)==0){dg=0;dh=aO&65535;break}r=gj[v&4095](aO&65535)|0;dg=r;dh=b[4830442]|0}else{dg=a[t+(aO&255)|0]|0;dh=aO&65535}}while(0);aO=dh+1&65535;b[4830442]=aO;t=d[9660900]|0;if(((t<<2^t)&8|0)!=0){break L40594}t=dg&255;b[4830442]=((t&128|0)!=0?t|65280:t)+(aO&65535)&65535;b[4830442]=c[2415221]&65535;break};case 45:{aO=c[2415221]|0;t=c[2437644]|0;F=c[t+72+((aO>>>8&255|512)<<2)>>2]|0;do{if((F|0)==0){r=c[t+3156>>2]|0;if((r|0)==0){di=0;dj=aO&65535;break}v=gj[r&4095](aO&65535)|0;di=v;dj=b[4830442]|0}else{di=a[F+(aO&255)|0]|0;dj=aO&65535}}while(0);aO=dj+1&65535;b[4830442]=aO;F=d[9660900]|0;if(((F<<2^F)&8|0)==0){break L40594}F=di&255;b[4830442]=((F&128|0)!=0?F|65280:F)+(aO&65535)&65535;b[4830442]=c[2415221]&65535;break};case 46:{aO=c[2415221]|0;F=c[2437644]|0;t=c[F+72+((aO>>>8&255|512)<<2)>>2]|0;do{if((t|0)==0){v=c[F+3156>>2]|0;if((v|0)==0){dk=0;dl=aO&65535;break}r=gj[v&4095](aO&65535)|0;dk=r;dl=b[4830442]|0}else{dk=a[t+(aO&255)|0]|0;dl=aO&65535}}while(0);aO=dl+1&65535;b[4830442]=aO;t=d[9660900]|0;if(((t<<2^t)&8|t&4|0)!=0){break L40594}t=dk&255;b[4830442]=((t&128|0)!=0?t|65280:t)+(aO&65535)&65535;b[4830442]=c[2415221]&65535;break};case 47:{aO=c[2415221]|0;t=c[2437644]|0;F=c[t+72+((aO>>>8&255|512)<<2)>>2]|0;do{if((F|0)==0){r=c[t+3156>>2]|0;if((r|0)==0){dm=0;dn=aO&65535;break}v=gj[r&4095](aO&65535)|0;dm=v;dn=b[4830442]|0}else{dm=a[F+(aO&255)|0]|0;dn=aO&65535}}while(0);aO=dn+1&65535;b[4830442]=aO;F=d[9660900]|0;if(((F<<2^F)&8|F&4|0)==0){break L40594}F=dm&255;b[4830442]=((F&128|0)!=0?F|65280:F)+(aO&65535)&65535;b[4830442]=c[2415221]&65535;break};case 48:{b[4830446]=(b[4830444]|0)+1&65535;break};case 49:{b[4830444]=(b[4830444]|0)+1&65535;break};case 50:{b[4830444]=(b[4830444]|0)+1&65535;aO=c[2415222]|0;F=c[2437644]|0;t=c[F+72+((aO>>>8&255)<<2)>>2]|0;do{if((t|0)==0){v=c[F+3144>>2]|0;if((v|0)==0){dp=0;break}dp=gj[v&4095](aO&65535)|0}else{dp=a[t+(aO&255)|0]|0}}while(0);a[9660897]=dp;break};case 51:{b[4830444]=(b[4830444]|0)+1&65535;aO=c[2415222]|0;t=c[2437644]|0;F=c[t+72+((aO>>>8&255)<<2)>>2]|0;do{if((F|0)==0){v=c[t+3144>>2]|0;if((v|0)==0){dq=0;break}dq=gj[v&4095](aO&65535)|0}else{dq=a[F+(aO&255)|0]|0}}while(0);a[9660896]=dq;break};case 52:{b[4830444]=(b[4830444]|0)-1&65535;break};case 53:{b[4830444]=(b[4830446]|0)-1&65535;break};case 54:{aO=c[2415222]|0;F=a[9660897]|0;t=c[2437644]|0;v=c[t+72+((aO>>>8&255|256)<<2)>>2]|0;do{if((v|0)==0){r=c[t+3148>>2]|0;if((r|0)==0){break}gg[r&4095](aO&65535,F)}else{a[v+(aO&255)|0]=F}}while(0);b[4830444]=(b[4830444]|0)-1&65535;break};case 55:{F=c[2415222]|0;aO=a[9660896]|0;v=c[2437644]|0;t=c[v+72+((F>>>8&255|256)<<2)>>2]|0;do{if((t|0)==0){r=c[v+3148>>2]|0;if((r|0)==0){break}gg[r&4095](F&65535,aO)}else{a[t+(F&255)|0]=aO}}while(0);b[4830444]=(b[4830444]|0)-1&65535;break};case 56:{b[4830444]=(b[4830444]|0)+1&65535;aO=c[2415222]|0;F=c[2437644]|0;t=c[F+72+((aO>>>8&255)<<2)>>2]|0;do{if((t|0)==0){v=c[F+3144>>2]|0;if((v|0)==0){dr=0;ds=aO&65535;dt=F;break}r=gj[v&4095](aO&65535)|0;dr=r;ds=b[4830444]|0;dt=c[2437644]|0}else{dr=a[t+(aO&255)|0]|0;ds=aO&65535;dt=F}}while(0);F=(dr&255)<<8;c[2415223]=F;b[4830444]=ds+1&65535;aO=c[2415222]|0;t=c[dt+72+((aO>>>8&255)<<2)>>2]|0;do{if((t|0)==0){r=c[dt+3144>>2]|0;if((r|0)==0){du=0;dv=F;break}v=gj[r&4095](aO&65535)|0;du=v;dv=c[2415223]|0}else{du=a[t+(aO&255)|0]|0;dv=F}}while(0);c[2415223]=dv|du&255;break};default:{l=1}}}if(l){l=0;switch(q|0){case 57:{b[4830444]=(b[4830444]|0)+1&65535;F=c[2415222]|0;aO=c[2437644]|0;t=c[aO+72+((F>>>8&255)<<2)>>2]|0;do{if((t|0)==0){v=c[aO+3144>>2]|0;if((v|0)==0){dw=0;dx=F&65535;dy=aO;break}r=gj[v&4095](F&65535)|0;dw=r;dx=b[4830444]|0;dy=c[2437644]|0}else{dw=a[t+(F&255)|0]|0;dx=F&65535;dy=aO}}while(0);aO=(dw&255)<<8;c[2415221]=aO;b[4830444]=dx+1&65535;F=c[2415222]|0;t=c[dy+72+((F>>>8&255)<<2)>>2]|0;do{if((t|0)==0){r=c[dy+3144>>2]|0;if((r|0)==0){dz=0;dA=aO;break}v=gj[r&4095](F&65535)|0;dz=v;dA=c[2415221]|0}else{dz=a[t+(F&255)|0]|0;dA=aO}}while(0);aO=dA|dz&255;c[2415221]=aO;b[4830442]=aO&65535;break};case 58:{b[4830446]=(b[4830446]|0)+(d[9660896]|0)&65535;break};case 59:{f1H();break};case 60:{aO=c[2415222]|0;F=a[9660892]|0;t=c[2437644]|0;v=c[t+72+((aO>>>8&255|256)<<2)>>2]|0;do{if((v|0)==0){r=c[t+3148>>2]|0;if((r|0)==0){dB=t;break}gg[r&4095](aO&65535,F);dB=c[2437644]|0}else{a[v+(aO&255)|0]=F;dB=t}}while(0);b[4830444]=(b[4830444]|0)-1&65535;t=c[2415222]|0;F=a[9660893]|0;aO=c[dB+72+((t>>>8&255|256)<<2)>>2]|0;do{if((aO|0)==0){v=c[dB+3148>>2]|0;if((v|0)==0){break}gg[v&4095](t&65535,F)}else{a[aO+(t&255)|0]=F}}while(0);b[4830444]=(b[4830444]|0)-1&65535;break};case 8:{F=(b[4830446]|0)+1&65535;b[4830446]=F;t=a[9660900]|0;a[9660900]=F<<16>>16==0?t|4:t&-5;break};case 9:{t=(b[4830446]|0)-1&65535;b[4830446]=t;F=a[9660900]|0;a[9660900]=t<<16>>16==0?F|4:F&-5;break};case 11:{a[9660900]=a[9660900]|2;break};case 14:{f1a();break};case 15:{f1b();break};case 16:{F=a[9660897]|0;t=a[9660896]|0;aO=(F&255)-(t&255)&65535&65535;v=(aO>>>4&8|a[9660900]&-16&255)&255;a[9660900]=((aO^(t^F)&255^aO>>>1)>>>6&2|aO>>>8&1|(((F&255)-(t&255)&65535&255)<<24>>24==0?v|4:v)&255)&255;a[9660897]=(F&255)-(t&255)&65535&255;break};case 17:{t=a[9660897]|0;F=a[9660896]|0;v=(t&255)-(F&255)&65535&65535;aO=(v>>>4&8|a[9660900]&-16&255)&255;a[9660900]=((v^(F^t)&255^v>>>1)>>>6&2|v>>>8&1|(((t&255)-(F&255)&65535&255)<<24>>24==0?aO|4:aO)&255)&255;break};case 22:{aO=a[9660897]|0;a[9660896]=aO;F=(aO&255)>>>4&8|a[9660900]&-15;a[9660900]=aO<<24>>24==0?F|4:F;break};case 23:{F=a[9660896]|0;a[9660897]=F;aO=(F&255)>>>4&8|a[9660900]&-15;a[9660900]=F<<24>>24==0?aO|4:aO;break};case 25:{aO=a[9660897]|0;if((aO&14)>9){dC=33204}else{if((a[9660900]&32)==0){dD=0}else{dC=33204}}if((dC|0)==33204){dC=0;dD=6}do{if((aO&-16&255)>128){F=(aO&14)>9?dD|96:dD;if((aO&-16&255)<=144){dE=F;dC=33208;break}dF=F;dG=a[9660900]|0;dC=33209}else{dE=dD;dC=33208}}while(0);if((dC|0)==33208){dC=0;F=a[9660900]|0;if((F&1)==0){dH=dE;dI=F}else{dF=dE;dG=F;dC=33209}}if((dC|0)==33209){dC=0;dH=dF|96;dI=dG}F=dH+(aO&255)&65535;t=((F&65535)>>>4&8|dI&-15&255)&255;a[9660900]=(((F&255)<<24>>24==0?t|4:t)&255|(F&65535)>>>8&1)&255;a[9660897]=F&255;break};case 5:{F=e[4830448]|0;t=(a[9660900]&-16&255|F>>>11&8)&255;a[9660900]=((F<<1^F)>>>14&2|F>>>15|((F<<1&65535)<<16>>16==0?t|4:t)&255)&255;b[4830448]=F<<1&65535;break};case 12:{a[9660900]=a[9660900]&-2;break};case 27:{F=a[9660897]|0;t=a[9660896]|0;v=(t&255)+(F&255)&65535&65535;r=(v>>>4&8|a[9660900]&-48&255)&255;a[9660900]=((v^(t^F)&255)<<1&32|v>>>8&1|(v^(t^F)&255^v>>>1)>>>6&2|(((t&255)+(F&255)&65535&255)<<24>>24==0?r|4:r)&255)&255;a[9660897]=(t&255)+(F&255)&65535&255;break};case 32:{F=c[2415221]|0;t=c[2437644]|0;r=c[t+72+((F>>>8&255|512)<<2)>>2]|0;do{if((r|0)==0){v=c[t+3156>>2]|0;if((v|0)==0){dJ=0;dK=F&65535;break}n=gj[v&4095](F&65535)|0;dJ=n;dK=b[4830442]|0}else{dJ=a[r+(F&255)|0]|0;dK=F&65535}}while(0);F=dJ&255;b[4830442]=((F&128|0)!=0?F|65280:F)+(dK+1&65535)&65535;b[4830442]=c[2415221]&65535;if(dJ<<24>>24!=-2){break L40594}F=c[3528192]|0;r=c[2415234]|0;t=c[2440594]|0;aO=(F-r|0|0)>(t|0)?t:F-r|0;if((aO|0)<=0){break L40594}c[2440594]=t-aO;c[2415234]=aO+r|0;if((aO+r|0)>>>0<F>>>0){break L40594}f03();break};case 141:{F=c[2415221]|0;r=c[2437644]|0;aO=c[r+72+((F>>>8&255|512)<<2)>>2]|0;do{if((aO|0)==0){t=c[r+3156>>2]|0;if((t|0)==0){dL=0;dM=F&65535;dN=r;break}n=gj[t&4095](F&65535)|0;dL=n;dM=b[4830442]|0;dN=c[2437644]|0}else{dL=a[aO+(F&255)|0]|0;dM=F&65535;dN=r}}while(0);r=dM+1&65535;b[4830442]=r;F=c[2415222]|0;aO=c[dN+72+((F>>>8&255|256)<<2)>>2]|0;do{if((aO|0)==0){n=c[dN+3148>>2]|0;if((n|0)==0){dO=dN;break}gg[n&4095](F&65535,r&255);dO=c[2437644]|0}else{a[aO+(F&255)|0]=r&255;dO=dN}}while(0);b[4830444]=(b[4830444]|0)-1&65535;r=c[2415222]|0;F=a[9660885]|0;aO=c[dO+72+((r>>>8&255|256)<<2)>>2]|0;do{if((aO|0)==0){n=c[dO+3148>>2]|0;if((n|0)==0){break}gg[n&4095](r&65535,F)}else{a[aO+(r&255)|0]=F}}while(0);b[4830444]=(b[4830444]|0)-1&65535;F=dL&255;b[4830442]=(e[4830442]|0)+((F&128|0)!=0?F|65280:F)&65535;b[4830442]=c[2415221]&65535;break};case 142:{F=c[2415221]|0;r=c[2437644]|0;aO=c[r+72+((F>>>8&255|512)<<2)>>2]|0;do{if((aO|0)==0){n=c[r+3156>>2]|0;if((n|0)==0){dP=0;dQ=F;dR=r;dS=F&65535;break}t=gj[n&4095](F&65535)|0;n=c[2415221]|0;dP=t;dQ=n;dR=c[2437644]|0;dS=n&65535}else{dP=a[aO+(F&255)|0]|0;dQ=F;dR=r;dS=F&65535}}while(0);F=dP&255;r=dQ+1|0;aO=c[dR+72+((r>>>8&255|512)<<2)>>2]|0;do{if((aO|0)==0){n=c[dR+3156>>2]|0;if((n|0)==0){dT=0;dU=dS;break}t=gj[n&4095](r&65535)|0;dT=t;dU=b[4830442]|0}else{dT=a[aO+(r&255)|0]|0;dU=dS}}while(0);r=dT&255|F<<8;c[2415222]=r;b[4830442]=dU+2&65535;aO=a[9660900]&-15;a[9660900]=aO;if((r|0)==0){dV=(aO&255|F>>>4&8|4)&255}else{dV=(aO&255|F>>>4&8)&255}a[9660900]=dV;break};case 143:{aO=b[4830444]|0;r=(aO&65535)>>>12&8|a[9660900]&-15&255;a[9660900]=(aO<<16>>16==0?r|4:r)&255;b[4853736]=k;b[4830442]=p+3&65535;r=c[2426868]|0;aO=a[9660889]|0;t=c[2437644]|0;n=c[t+72+((r>>>8&255|256)<<2)>>2]|0;do{if((n|0)==0){v=c[t+3148>>2]|0;if((v|0)==0){dW=t;break}gg[v&4095](r&65535,aO);dW=c[2437644]|0}else{a[n+(r&255)|0]=aO;dW=t}}while(0);t=a[9660888]|0;aO=c[dW+72+(((r+1|0)>>>8&255|256)<<2)>>2]|0;if((aO|0)!=0){a[aO+((r+1|0)&255)|0]=t;break L40594}aO=c[dW+3148>>2]|0;if((aO|0)==0){break L40594}gg[aO&4095]((r+1|0)&65535,t);break};case 144:{t=c[2415221]|0;aO=c[2437644]|0;n=c[aO+72+((t>>>8&255|512)<<2)>>2]|0;do{if((n|0)==0){F=c[aO+3156>>2]|0;if((F|0)==0){dX=0;dY=t&65535;dZ=aO;break}v=gj[F&4095](t&65535)|0;dX=v;dY=b[4830442]|0;dZ=c[2437644]|0}else{dX=a[n+(t&255)|0]|0;dY=t&65535;dZ=aO}}while(0);aO=dX&255;c[2426868]=aO;b[4830442]=dY+1&65535;t=dX&255;n=c[dZ+72>>2]|0;do{if((n|0)==0){r=c[dZ+3144>>2]|0;if((r|0)==0){d_=0;break}d_=gj[r&4095](t)|0}else{d_=a[n+aO|0]|0}}while(0);aO=a[9660897]|0;n=(aO&255)-(d_&255)|0;t=(n>>>4&8|a[9660900]&-16&255)&255;a[9660900]=(((aO^d_)&255^n^n>>>1)>>>6&2|n>>>8&1|((n&255)<<24>>24==0?t|4:t)&255)&255;a[9660897]=n&255;break};case 145:{n=c[2415221]|0;t=c[2437644]|0;aO=c[t+72+((n>>>8&255|512)<<2)>>2]|0;do{if((aO|0)==0){r=c[t+3156>>2]|0;if((r|0)==0){d$=0;d0=n&65535;d1=t;break}v=gj[r&4095](n&65535)|0;d$=v;d0=b[4830442]|0;d1=c[2437644]|0}else{d$=a[aO+(n&255)|0]|0;d0=n&65535;d1=t}}while(0);t=d$&255;c[2426868]=t;b[4830442]=d0+1&65535;n=d$&255;aO=c[d1+72>>2]|0;do{if((aO|0)==0){v=c[d1+3144>>2]|0;if((v|0)==0){d2=0;break}d2=gj[v&4095](n)|0}else{d2=a[aO+t|0]|0}}while(0);t=a[9660897]|0;aO=(t&255)-(d2&255)|0;n=(aO>>>4&8|a[9660900]&-16&255)&255;a[9660900]=(((t^d2)&255^aO^aO>>>1)>>>6&2|aO>>>8&1|((aO&255)<<24>>24==0?n|4:n)&255)&255;break};case 146:{n=c[2415221]|0;aO=c[2437644]|0;t=c[aO+72+((n>>>8&255|512)<<2)>>2]|0;do{if((t|0)==0){v=c[aO+3156>>2]|0;if((v|0)==0){d3=0;d4=n&65535;d5=aO;break}r=gj[v&4095](n&65535)|0;d3=r;d4=b[4830442]|0;d5=c[2437644]|0}else{d3=a[t+(n&255)|0]|0;d4=n&65535;d5=aO}}while(0);aO=d3&255;c[2426868]=aO;b[4830442]=d4+1&65535;n=d3&255;t=c[d5+72>>2]|0;do{if((t|0)==0){r=c[d5+3144>>2]|0;if((r|0)==0){d6=0;break}d6=gj[r&4095](n)|0}else{d6=a[t+aO|0]|0}}while(0);aO=a[9660897]|0;t=a[9660900]|0;n=(aO&255)-(d6&255)-(t&1)|0;a[9660900]=((n^(aO^d6)&255^n>>>1)>>>6&2|n>>>8&1|((n&255)<<24>>24==0?(n>>>4&8|t&-16&255)&255|4:(n>>>4&8|t&-16&255)&255)&255)&255;a[9660897]=n&255;break};case 147:{n=c[2415221]|0;t=c[2437644]|0;aO=c[t+72+((n>>>8&255|512)<<2)>>2]|0;do{if((aO|0)==0){r=c[t+3156>>2]|0;if((r|0)==0){d7=0;d8=n&65535;d9=t;break}v=gj[r&4095](n&65535)|0;d7=v;d8=b[4830442]|0;d9=c[2437644]|0}else{d7=a[aO+(n&255)|0]|0;d8=n&65535;d9=t}}while(0);t=d7&255;c[2426868]=t;b[4830442]=d8+1&65535;n=d7&255;aO=c[d9+72>>2]|0;do{if((aO|0)==0){v=c[d9+3144>>2]|0;if((v|0)==0){ea=0;eb=d9;break}r=gj[v&4095](n)|0;ea=r;eb=c[2437644]|0}else{ea=a[aO+t|0]|0;eb=d9}}while(0);aO=(ea&255)<<8;n=c[eb+72+(((t+1|0)>>>8&255)<<2)>>2]|0;do{if((n|0)==0){r=c[eb+3144>>2]|0;if((r|0)==0){ec=0;break}ec=gj[r&4095]((t+1|0)&65535)|0}else{ec=a[n+((t+1|0)&255)|0]|0}}while(0);t=e[4830448]|0;n=t-(ec&255|aO)|0;r=(n>>>12&8|a[9660900]&-16&255)&255;a[9660900]=((t^aO^n^n>>>1)>>>14&2|n>>>16&1|((n&65535)<<16>>16==0?r|4:r)&255)&255;b[4830448]=n&65535;break};case 148:{n=c[2415221]|0;r=c[2437644]|0;t=c[r+72+((n>>>8&255|512)<<2)>>2]|0;do{if((t|0)==0){v=c[r+3156>>2]|0;if((v|0)==0){ed=0;ee=n&65535;ef=r;break}F=gj[v&4095](n&65535)|0;ed=F;ee=b[4830442]|0;ef=c[2437644]|0}else{ed=a[t+(n&255)|0]|0;ee=n&65535;ef=r}}while(0);r=ed&255;c[2426868]=r;b[4830442]=ee+1&65535;n=ed&255;t=c[ef+72>>2]|0;do{if((t|0)==0){aO=c[ef+3144>>2]|0;if((aO|0)==0){eg=0;break}eg=gj[aO&4095](n)|0}else{eg=a[t+r|0]|0}}while(0);r=a[9660897]&eg;a[9660897]=r;t=(r&255)>>>4&8|a[9660900]&-15;a[9660900]=r<<24>>24==0?t|4:t;break};case 149:{t=c[2415221]|0;r=c[2437644]|0;n=c[r+72+((t>>>8&255|512)<<2)>>2]|0;do{if((n|0)==0){aO=c[r+3156>>2]|0;if((aO|0)==0){eh=0;ei=t&65535;ej=r;break}F=gj[aO&4095](t&65535)|0;eh=F;ei=b[4830442]|0;ej=c[2437644]|0}else{eh=a[n+(t&255)|0]|0;ei=t&65535;ej=r}}while(0);r=eh&255;c[2426868]=r;b[4830442]=ei+1&65535;t=eh&255;n=c[ej+72>>2]|0;do{if((n|0)==0){F=c[ej+3144>>2]|0;if((F|0)==0){ek=0;break}ek=gj[F&4095](t)|0}else{ek=a[n+r|0]|0}}while(0);r=a[9660897]&ek;n=(r&255)>>>4&8|a[9660900]&-15;a[9660900]=r<<24>>24==0?n|4:n;break};case 150:{n=c[2415221]|0;r=c[2437644]|0;t=c[r+72+((n>>>8&255|512)<<2)>>2]|0;do{if((t|0)==0){F=c[r+3156>>2]|0;if((F|0)==0){el=0;em=n&65535;en=r;break}aO=gj[F&4095](n&65535)|0;el=aO;em=b[4830442]|0;en=c[2437644]|0}else{el=a[t+(n&255)|0]|0;em=n&65535;en=r}}while(0);r=el&255;c[2426868]=r;b[4830442]=em+1&65535;n=el&255;t=c[en+72>>2]|0;do{if((t|0)==0){aO=c[en+3144>>2]|0;if((aO|0)==0){eo=0;break}eo=gj[aO&4095](n)|0}else{eo=a[t+r|0]|0}}while(0);a[9660897]=eo;r=(eo&255)>>>4&8|a[9660900]&-15;a[9660900]=eo<<24>>24==0?r|4:r;break};case 151:{r=a[9660897]|0;t=(r&255)>>>4&8|a[9660900]&-15;a[9660900]=r<<24>>24==0?t|4:t;t=c[2415221]|0;n=c[2437644]|0;aO=c[n+72+((t>>>8&255|512)<<2)>>2]|0;do{if((aO|0)==0){F=c[n+3156>>2]|0;if((F|0)==0){ep=0;eq=t&65535;er=r;es=n;break}v=gj[F&4095](t&65535)|0;ep=v;eq=b[4830442]|0;er=a[9660897]|0;es=c[2437644]|0}else{ep=a[aO+(t&255)|0]|0;eq=t&65535;er=r;es=n}}while(0);n=ep&255;c[2426868]=n;b[4830442]=eq+1&65535;r=c[es+1096>>2]|0;if((r|0)!=0){a[r+n|0]=er;break L40594}n=c[es+3148>>2]|0;if((n|0)==0){break L40594}gg[n&4095](ep&255,er);break};case 152:{n=c[2415221]|0;r=c[2437644]|0;t=c[r+72+((n>>>8&255|512)<<2)>>2]|0;do{if((t|0)==0){aO=c[r+3156>>2]|0;if((aO|0)==0){et=0;eu=n&65535;ev=r;break}v=gj[aO&4095](n&65535)|0;et=v;eu=b[4830442]|0;ev=c[2437644]|0}else{et=a[t+(n&255)|0]|0;eu=n&65535;ev=r}}while(0);r=et&255;c[2426868]=r;b[4830442]=eu+1&65535;n=et&255;t=c[ev+72>>2]|0;do{if((t|0)==0){v=c[ev+3144>>2]|0;if((v|0)==0){ew=0;break}ew=gj[v&4095](n)|0}else{ew=a[t+r|0]|0}}while(0);r=a[9660897]|0;t=r^ew;a[9660897]=t;n=(t&255)>>>4&8|a[9660900]&-15;a[9660900]=r<<24>>24==ew<<24>>24?n|4:n;break};case 153:{n=c[2415221]|0;r=c[2437644]|0;t=c[r+72+((n>>>8&255|512)<<2)>>2]|0;do{if((t|0)==0){v=c[r+3156>>2]|0;if((v|0)==0){ex=0;ey=n&65535;ez=r;break}aO=gj[v&4095](n&65535)|0;ex=aO;ey=b[4830442]|0;ez=c[2437644]|0}else{ex=a[t+(n&255)|0]|0;ey=n&65535;ez=r}}while(0);r=ex&255;c[2426868]=r;b[4830442]=ey+1&65535;n=ex&255;t=c[ez+72>>2]|0;do{if((t|0)==0){aO=c[ez+3144>>2]|0;if((aO|0)==0){eA=0;break}eA=gj[aO&4095](n)|0}else{eA=a[t+r|0]|0}}while(0);r=a[9660897]|0;t=a[9660900]|0;n=(r&255)+(eA&255)+(t&1)|0;aO=n^(r^eA)&255;a[9660900]=(aO<<1&32|n>>>8&1|(aO^n>>>1)>>>6&2|((n&255)<<24>>24==0?(n>>>4&8|t&-48&255)&255|4:(n>>>4&8|t&-48&255)&255)&255)&255;a[9660897]=n&255;break};case 154:{n=c[2415221]|0;t=c[2437644]|0;aO=c[t+72+((n>>>8&255|512)<<2)>>2]|0;do{if((aO|0)==0){r=c[t+3156>>2]|0;if((r|0)==0){eB=0;eC=n&65535;eD=t;break}v=gj[r&4095](n&65535)|0;eB=v;eC=b[4830442]|0;eD=c[2437644]|0}else{eB=a[aO+(n&255)|0]|0;eC=n&65535;eD=t}}while(0);t=eB&255;c[2426868]=t;b[4830442]=eC+1&65535;n=eB&255;aO=c[eD+72>>2]|0;do{if((aO|0)==0){v=c[eD+3144>>2]|0;if((v|0)==0){eE=0;break}eE=gj[v&4095](n)|0}else{eE=a[aO+t|0]|0}}while(0);t=a[9660897]|eE;a[9660897]=t;aO=(t&255)>>>4&8|a[9660900]&-15;a[9660900]=t<<24>>24==0?aO|4:aO;break};case 155:{aO=c[2415221]|0;t=c[2437644]|0;n=c[t+72+((aO>>>8&255|512)<<2)>>2]|0;do{if((n|0)==0){v=c[t+3156>>2]|0;if((v|0)==0){eF=0;eG=aO&65535;eH=t;break}r=gj[v&4095](aO&65535)|0;eF=r;eG=b[4830442]|0;eH=c[2437644]|0}else{eF=a[n+(aO&255)|0]|0;eG=aO&65535;eH=t}}while(0);t=eF&255;c[2426868]=t;b[4830442]=eG+1&65535;aO=eF&255;n=c[eH+72>>2]|0;do{if((n|0)==0){r=c[eH+3144>>2]|0;if((r|0)==0){eI=0;break}eI=gj[r&4095](aO)|0}else{eI=a[n+t|0]|0}}while(0);t=a[9660897]|0;n=(t&255)+(eI&255)|0;aO=(n>>>4&8|a[9660900]&-48&255)&255;r=(t^eI)&255^n;a[9660900]=(r<<1&32|n>>>8&1|(r^n>>>1)>>>6&2|((n&255)<<24>>24==0?aO|4:aO)&255)&255;a[9660897]=n&255;break};case 156:{n=c[2415221]|0;aO=c[2437644]|0;r=c[aO+72+((n>>>8&255|512)<<2)>>2]|0;do{if((r|0)==0){t=c[aO+3156>>2]|0;if((t|0)==0){eJ=0;eK=n&65535;eL=aO;break}v=gj[t&4095](n&65535)|0;eJ=v;eK=b[4830442]|0;eL=c[2437644]|0}else{eJ=a[r+(n&255)|0]|0;eK=n&65535;eL=aO}}while(0);aO=eJ&255;c[2426868]=aO;b[4830442]=eK+1&65535;n=eJ&255;r=c[eL+72>>2]|0;do{if((r|0)==0){v=c[eL+3144>>2]|0;if((v|0)==0){eM=0;eN=eL;break}t=gj[v&4095](n)|0;eM=t;eN=c[2437644]|0}else{eM=a[r+aO|0]|0;eN=eL}}while(0);r=(eM&255)<<8;n=c[eN+72+(((aO+1|0)>>>8&255)<<2)>>2]|0;do{if((n|0)==0){t=c[eN+3144>>2]|0;if((t|0)==0){eO=0;break}eO=gj[t&4095]((aO+1|0)&65535)|0}else{eO=a[n+((aO+1|0)&255)|0]|0}}while(0);aO=e[4830446]|0;n=aO-(eO&255|r)|0;t=(n>>>12&8|a[9660900]&-16&255)&255;a[9660900]=((aO^r^n^n>>>1)>>>14&2|n>>>16&1|((n&65535)<<16>>16==0?t|4:t)&255)&255;break};case 157:{t=c[2415221]|0;n=c[2437644]|0;aO=c[n+72+((t>>>8&255|512)<<2)>>2]|0;do{if((aO|0)==0){v=c[n+3156>>2]|0;if((v|0)==0){eP=0;eQ=t&65535;eR=n;break}F=gj[v&4095](t&65535)|0;eP=F;eQ=b[4830442]|0;eR=c[2437644]|0}else{eP=a[aO+(t&255)|0]|0;eQ=t&65535;eR=n}}while(0);c[2426868]=eP&255;n=eQ+1&65535;b[4830442]=n;t=c[2415222]|0;aO=c[eR+72+((t>>>8&255|256)<<2)>>2]|0;do{if((aO|0)==0){r=c[eR+3148>>2]|0;if((r|0)==0){eS=eR;break}gg[r&4095](t&65535,n&255);eS=c[2437644]|0}else{a[aO+(t&255)|0]=n&255;eS=eR}}while(0);b[4830444]=(b[4830444]|0)-1&65535;n=c[2415222]|0;t=a[9660885]|0;aO=c[eS+72+((n>>>8&255|256)<<2)>>2]|0;do{if((aO|0)==0){r=c[eS+3148>>2]|0;if((r|0)==0){break}gg[r&4095](n&65535,t)}else{a[aO+(n&255)|0]=t}}while(0);b[4830444]=(b[4830444]|0)-1&65535;b[4830442]=b[4853736]|0;b[4830442]=c[2415221]&65535;break};case 158:{t=c[2415221]|0;n=c[2437644]|0;aO=c[n+72+((t>>>8&255|512)<<2)>>2]|0;do{if((aO|0)==0){r=c[n+3156>>2]|0;if((r|0)==0){eT=0;eU=t&65535;eV=n;break}F=gj[r&4095](t&65535)|0;eT=F;eU=b[4830442]|0;eV=c[2437644]|0}else{eT=a[aO+(t&255)|0]|0;eU=t&65535;eV=n}}while(0);n=eT&255;c[2426868]=n;b[4830442]=eU+1&65535;t=eT&255;aO=c[eV+72>>2]|0;do{if((aO|0)==0){F=c[eV+3144>>2]|0;if((F|0)==0){eW=0;eX=eV;break}r=gj[F&4095](t)|0;eW=r;eX=c[2437644]|0}else{eW=a[aO+n|0]|0;eX=eV}}while(0);aO=eW&255;t=c[eX+72+(((n+1|0)>>>8&255)<<2)>>2]|0;do{if((t|0)==0){r=c[eX+3144>>2]|0;if((r|0)==0){eY=0;break}eY=gj[r&4095]((n+1|0)&65535)|0}else{eY=a[t+((n+1|0)&255)|0]|0}}while(0);n=eY&255|aO<<8;c[2415222]=n;t=a[9660900]&-15;a[9660900]=t;if((n|0)==0){eZ=(t&255|aO>>>4&8|4)&255}else{eZ=(t&255|aO>>>4&8)&255}a[9660900]=eZ;break};case 159:{t=b[4830444]|0;n=(t&65535)>>>12&8|a[9660900]&-15&255;a[9660900]=(t<<16>>16==0?n|4:n)&255;n=c[2415221]|0;t=c[2437644]|0;r=c[t+72+((n>>>8&255|512)<<2)>>2]|0;do{if((r|0)==0){F=c[t+3156>>2]|0;if((F|0)==0){e_=0;e$=n&65535;e0=t;break}v=gj[F&4095](n&65535)|0;e_=v;e$=b[4830442]|0;e0=c[2437644]|0}else{e_=a[r+(n&255)|0]|0;e$=n&65535;e0=t}}while(0);t=e_&255;c[2426868]=t;b[4830442]=e$+1&65535;n=e_&255;r=a[9660889]|0;aO=c[e0+1096>>2]|0;do{if((aO|0)==0){v=c[e0+3148>>2]|0;if((v|0)==0){e1=e0;break}gg[v&4095](n,r);e1=c[2437644]|0}else{a[aO+t|0]=r;e1=e0}}while(0);r=a[9660888]|0;aO=c[e1+72+(((t+1|0)>>>8&255|256)<<2)>>2]|0;if((aO|0)!=0){a[aO+((t+1|0)&255)|0]=r;break L40594}aO=c[e1+3148>>2]|0;if((aO|0)==0){break L40594}gg[aO&4095]((t+1|0)&65535,r);break};case 160:{r=b[4830446]|0;aO=c[2415221]|0;n=c[2437644]|0;v=c[n+72+((aO>>>8&255|512)<<2)>>2]|0;do{if((v|0)==0){F=c[n+3156>>2]|0;if((F|0)==0){e2=0;e3=aO&65535;e4=n;break}y=gj[F&4095](aO&65535)|0;e2=y;e3=b[4830442]|0;e4=c[2437644]|0}else{e2=a[v+(aO&255)|0]|0;e3=aO&65535;e4=n}}while(0);b[4853736]=(e2&255)+r&65535;b[4830442]=e3+1&65535;n=c[2426868]|0;aO=c[e4+72+((n>>>8&255)<<2)>>2]|0;do{if((aO|0)==0){v=c[e4+3144>>2]|0;if((v|0)==0){e5=0;break}e5=gj[v&4095](n&65535)|0}else{e5=a[aO+(n&255)|0]|0}}while(0);n=a[9660897]|0;aO=(n&255)-(e5&255)|0;r=(aO>>>4&8|a[9660900]&-16&255)&255;a[9660900]=(((n^e5)&255^aO^aO>>>1)>>>6&2|aO>>>8&1|((aO&255)<<24>>24==0?r|4:r)&255)&255;a[9660897]=aO&255;break};case 161:{aO=b[4830446]|0;r=c[2415221]|0;n=c[2437644]|0;v=c[n+72+((r>>>8&255|512)<<2)>>2]|0;do{if((v|0)==0){t=c[n+3156>>2]|0;if((t|0)==0){e6=0;e7=r&65535;e8=n;break}y=gj[t&4095](r&65535)|0;e6=y;e7=b[4830442]|0;e8=c[2437644]|0}else{e6=a[v+(r&255)|0]|0;e7=r&65535;e8=n}}while(0);b[4853736]=(e6&255)+aO&65535;b[4830442]=e7+1&65535;n=c[2426868]|0;r=c[e8+72+((n>>>8&255)<<2)>>2]|0;do{if((r|0)==0){v=c[e8+3144>>2]|0;if((v|0)==0){e9=0;break}e9=gj[v&4095](n&65535)|0}else{e9=a[r+(n&255)|0]|0}}while(0);n=a[9660897]|0;r=(n&255)-(e9&255)|0;aO=(r>>>4&8|a[9660900]&-16&255)&255;a[9660900]=(((n^e9)&255^r^r>>>1)>>>6&2|r>>>8&1|((r&255)<<24>>24==0?aO|4:aO)&255)&255;break};case 162:{aO=b[4830446]|0;r=c[2415221]|0;n=c[2437644]|0;v=c[n+72+((r>>>8&255|512)<<2)>>2]|0;do{if((v|0)==0){y=c[n+3156>>2]|0;if((y|0)==0){fa=0;fb=r&65535;fc=n;break}t=gj[y&4095](r&65535)|0;fa=t;fb=b[4830442]|0;fc=c[2437644]|0}else{fa=a[v+(r&255)|0]|0;fb=r&65535;fc=n}}while(0);b[4853736]=(fa&255)+aO&65535;b[4830442]=fb+1&65535;n=c[2426868]|0;r=c[fc+72+((n>>>8&255)<<2)>>2]|0;do{if((r|0)==0){v=c[fc+3144>>2]|0;if((v|0)==0){fd=0;break}fd=gj[v&4095](n&65535)|0}else{fd=a[r+(n&255)|0]|0}}while(0);n=a[9660897]|0;r=a[9660900]|0;aO=(n&255)-(fd&255)-(r&1)|0;a[9660900]=((aO^(n^fd)&255^aO>>>1)>>>6&2|aO>>>8&1|((aO&255)<<24>>24==0?(aO>>>4&8|r&-16&255)&255|4:(aO>>>4&8|r&-16&255)&255)&255)&255;a[9660897]=aO&255;break};default:{l=1}}}c[h+136>>2]=p;c[h+152>>2]=k;c[h+23848>>2]=l;c[h+23856>>2]=q;c[h+23864>>2]=0;c[h+23868>>2]=0;__Z13m6803_executei$0(h);l=c[h+23848>>2]|0;I=c[h+23864>>2]|0;B=c[h+23868>>2]|0;J=+g[h+23868>>2];c[h+23864>>2]=0;c[h+23868>>2]=0;if((I|0)==1){break}if((I|0)==2){switch(B|0){case 26:{break L40594}}}}while(0);k=d[7066624+j|0]|0;c[2440594]=(c[2440594]|0)-k;aO=(c[2415234]|0)+k|0;c[2415234]=aO;if(aO>>>0<(c[3528192]|0)>>>0){dC=34921;break}f03();dC=34921}else{m=1}}if(m){m=0;if(1){aO=c[3528192]|0;k=c[2415234]|0;r=c[2440594]|0;n=(aO-k|0|0)>(r|0)?r:aO-k|0;if((n|0)<=0){fe=r;break}c[2440594]=r-n;c[2415234]=n+k|0;if((n+k|0)>>>0<aO>>>0){dC=34921;break}f03();dC=34921}else{m=1}}}while(0);if((dC|0)==34921){dC=0;fe=c[2440594]|0}}while((fe|0)>0);dC=c[2415227]|0;p=fe-dC|0;c[2440594]=p;fe=(c[2415234]|0)+dC|0;c[2415234]=fe;if(fe>>>0<(c[3528192]|0)>>>0){ff=p;c[2415227]=0;fg=f-ff|0;i=h;return fg|0}f03();ff=c[2440594]|0;c[2415227]=0;fg=f-ff|0;i=h;return fg|0}function f4d(){var c=0,d=0,e=0,f=0;c=a[9660900]&-14;a[9660900]=c;d=b[4830448]|0;e=d&1|c&255;c=(d&65535)>>>1;if(c<<16>>16==0){f=(e|4)&255}else{f=e&255}a[9660900]=f;b[4830448]=c;return}function f4e(){var c=0,d=0,f=0,g=0;c=e[4830448]|0;d=c<<1;f=(a[9660900]&-16&255|c>>>11&8)&255;g=d&65535;a[9660900]=((d^c)>>>14&2|c>>>15|(g<<16>>16==0?f|4:f)&255)&255;b[4830448]=g;return}function f4f(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b[4830444]=(b[4830444]|0)+1&65535;d=c[2415222]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3144>>2]|0;if((h|0)==0){i=0;j=e;k=f;break}l=gj[h&4095](e)|0;i=l;j=b[4830444]|0;k=c[2437644]|0}else{i=a[g+(d&255)|0]|0;j=e;k=f}}while(0);f=(i&255)<<8;c[2415223]=f;b[4830444]=j+1&65535;j=c[2415222]|0;i=c[k+72+((j>>>8&255)<<2)>>2]|0;if((i|0)!=0){m=a[i+(j&255)|0]|0;n=f;o=m&255;p=n|o;c[2415223]=p;return}i=c[k+3144>>2]|0;if((i|0)==0){m=0;n=f;o=m&255;p=n|o;c[2415223]=p;return}f=gj[i&4095](j&65535)|0;m=f;n=c[2415223]|0;o=m&255;p=n|o;c[2415223]=p;return}function f4g(){b[4830446]=(b[4830446]|0)+(d[9660896]|0)&65535;return}function f4h(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[2415222]|0;e=d&65535;f=a[9660892]|0;g=c[2437644]|0;h=c[g+72+((d>>>8&255|256)<<2)>>2]|0;do{if((h|0)==0){i=c[g+3148>>2]|0;if((i|0)==0){j=g;break}gg[i&4095](e,f);j=c[2437644]|0}else{a[h+(d&255)|0]=f;j=g}}while(0);b[4830444]=(b[4830444]|0)-1&65535;g=c[2415222]|0;f=a[9660893]|0;d=c[j+72+((g>>>8&255|256)<<2)>>2]|0;if((d|0)!=0){a[d+(g&255)|0]=f;k=b[4830444]|0;l=k-1&65535;b[4830444]=l;return}d=c[j+3148>>2]|0;if((d|0)==0){k=b[4830444]|0;l=k-1&65535;b[4830444]=l;return}gg[d&4095](g&65535,f);k=b[4830444]|0;l=k-1&65535;b[4830444]=l;return}function f4i(){var c=0,e=0;c=ag(d[9660896]|0,d[9660897]|0)|0;e=a[9660900]|0;a[9660900]=(c&128)==0?e&-2:e|1;b[4830448]=c;return}function f4j(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=c[2415221]|0;f=d&65535;g=c[2437644]|0;h=c[g+72+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+3156>>2]|0;if((i|0)==0){j=0;k=d;l=g;m=f;break}n=gj[i&4095](f)|0;i=c[2415221]|0;j=n;k=i;l=c[2437644]|0;m=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=g;m=f}}while(0);f=(j&255)<<8;j=k+1|0;k=j&65535;g=c[l+72+((j>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){d=c[l+3156>>2]|0;if((d|0)==0){o=0;p=m;break}h=gj[d&4095](k)|0;o=h;p=b[4830442]|0}else{o=a[g+(j&255)|0]|0;p=m}}while(0);b[4830442]=p+2&65535;p=e[4830448]|0;m=p-(o&255|f)|0;o=(m>>>12&8|a[9660900]&-16&255)&255;j=m&65535;a[9660900]=((p^f^m^m>>>1)>>>14&2|m>>>16&1|(j<<16>>16==0?o|4:o)&255)&255;b[4830448]=j;return}function f4k(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=c[2415221]|0;f=d&65535;g=c[2437644]|0;h=c[g+72+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+3156>>2]|0;if((i|0)==0){j=0;k=d;l=g;m=f;break}n=gj[i&4095](f)|0;i=c[2415221]|0;j=n;k=i;l=c[2437644]|0;m=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=g;m=f}}while(0);f=(j&255)<<8;j=k+1|0;k=j&65535;g=c[l+72+((j>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){d=c[l+3156>>2]|0;if((d|0)==0){o=0;p=m;break}h=gj[d&4095](k)|0;o=h;p=b[4830442]|0}else{o=a[g+(j&255)|0]|0;p=m}}while(0);b[4830442]=p+2&65535;p=e[4830446]|0;m=p-(o&255|f)|0;o=(m>>>12&8|a[9660900]&-16&255)&255;a[9660900]=((p^f^m^m>>>1)>>>14&2|m>>>16&1|((m&65535)<<16>>16==0?o|4:o)&255)&255;return}function f4l(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=c[2415221]|0;f=d&65535;g=c[2437644]|0;h=c[g+72+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+3156>>2]|0;if((i|0)==0){j=0;k=f;l=g;break}m=gj[i&4095](f)|0;j=m;k=b[4830442]|0;l=c[2437644]|0}else{j=a[h+(d&255)|0]|0;k=f;l=g}}while(0);g=j&255;c[2426868]=g;b[4830442]=k+1&65535;k=j&255;j=c[l+72>>2]|0;do{if((j|0)==0){f=c[l+3144>>2]|0;if((f|0)==0){n=0;o=l;break}d=gj[f&4095](k)|0;n=d;o=c[2437644]|0}else{n=a[j+g|0]|0;o=l}}while(0);l=(n&255)<<8;n=g+1|0;g=n&65535;j=c[o+72+((n>>>8&255)<<2)>>2]|0;do{if((j|0)==0){k=c[o+3144>>2]|0;if((k|0)==0){p=0;break}p=gj[k&4095](g)|0}else{p=a[j+(n&255)|0]|0}}while(0);n=e[4830448]|0;j=n-(p&255|l)|0;p=(j>>>12&8|a[9660900]&-16&255)&255;g=j&65535;a[9660900]=((n^l^j^j>>>1)>>>14&2|j>>>16&1|(g<<16>>16==0?p|4:p)&255)&255;b[4830448]=g;return}function f4m(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=c[2415221]|0;f=d&65535;g=c[2437644]|0;h=c[g+72+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+3156>>2]|0;if((i|0)==0){j=0;k=f;l=g;break}m=gj[i&4095](f)|0;j=m;k=b[4830442]|0;l=c[2437644]|0}else{j=a[h+(d&255)|0]|0;k=f;l=g}}while(0);g=j&255;c[2426868]=g;b[4830442]=k+1&65535;k=j&255;j=c[l+72>>2]|0;do{if((j|0)==0){f=c[l+3144>>2]|0;if((f|0)==0){n=0;o=l;break}d=gj[f&4095](k)|0;n=d;o=c[2437644]|0}else{n=a[j+g|0]|0;o=l}}while(0);l=(n&255)<<8;n=g+1|0;g=n&65535;j=c[o+72+((n>>>8&255)<<2)>>2]|0;do{if((j|0)==0){k=c[o+3144>>2]|0;if((k|0)==0){p=0;break}p=gj[k&4095](g)|0}else{p=a[j+(n&255)|0]|0}}while(0);n=e[4830446]|0;j=n-(p&255|l)|0;p=(j>>>12&8|a[9660900]&-16&255)&255;a[9660900]=((n^l^j^j>>>1)>>>14&2|j>>>16&1|((j&65535)<<16>>16==0?p|4:p)&255)&255;return}function f4n(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=b[4830446]|0;f=c[2415221]|0;g=f&65535;h=c[2437644]|0;i=c[h+72+((f>>>8&255|512)<<2)>>2]|0;do{if((i|0)==0){j=c[h+3156>>2]|0;if((j|0)==0){k=0;l=g;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830442]|0;m=c[2437644]|0}else{k=a[i+(f&255)|0]|0;l=g;m=h}}while(0);b[4853736]=(k&255)+d&65535;b[4830442]=l+1&65535;l=c[2426868]|0;d=l&65535;k=c[m+72+((l>>>8&255)<<2)>>2]|0;do{if((k|0)==0){h=c[m+3144>>2]|0;if((h|0)==0){o=0;p=m;break}g=gj[h&4095](d)|0;o=g;p=c[2437644]|0}else{o=a[k+(l&255)|0]|0;p=m}}while(0);m=(o&255)<<8;o=l+1|0;l=o&65535;k=c[p+72+((o>>>8&255)<<2)>>2]|0;do{if((k|0)==0){d=c[p+3144>>2]|0;if((d|0)==0){q=0;break}q=gj[d&4095](l)|0}else{q=a[k+(o&255)|0]|0}}while(0);o=e[4830448]|0;k=o-(q&255|m)|0;q=(k>>>12&8|a[9660900]&-16&255)&255;l=k&65535;a[9660900]=((o^m^k^k>>>1)>>>14&2|k>>>16&1|(l<<16>>16==0?q|4:q)&255)&255;b[4830448]=l;return}function f4o(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=b[4830446]|0;f=c[2415221]|0;g=f&65535;h=c[2437644]|0;i=c[h+72+((f>>>8&255|512)<<2)>>2]|0;do{if((i|0)==0){j=c[h+3156>>2]|0;if((j|0)==0){k=0;l=g;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830442]|0;m=c[2437644]|0}else{k=a[i+(f&255)|0]|0;l=g;m=h}}while(0);b[4853736]=(k&255)+d&65535;b[4830442]=l+1&65535;l=c[2426868]|0;d=l&65535;k=c[m+72+((l>>>8&255)<<2)>>2]|0;do{if((k|0)==0){h=c[m+3144>>2]|0;if((h|0)==0){o=0;p=m;break}g=gj[h&4095](d)|0;o=g;p=c[2437644]|0}else{o=a[k+(l&255)|0]|0;p=m}}while(0);m=(o&255)<<8;o=l+1|0;l=o&65535;k=c[p+72+((o>>>8&255)<<2)>>2]|0;do{if((k|0)==0){d=c[p+3144>>2]|0;if((d|0)==0){q=0;break}q=gj[d&4095](l)|0}else{q=a[k+(o&255)|0]|0}}while(0);o=e[4830446]|0;k=o-(q&255|m)|0;q=(k>>>12&8|a[9660900]&-16&255)&255;a[9660900]=((o^m^k^k>>>1)>>>14&2|k>>>16&1|((k&65535)<<16>>16==0?q|4:q)&255)&255;return}function f4p(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=c[2415221]|0;f=d&65535;g=c[2437644]|0;h=c[g+72+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+3156>>2]|0;if((i|0)==0){j=0;k=d;l=g;m=f;break}n=gj[i&4095](f)|0;i=c[2415221]|0;j=n;k=i;l=c[2437644]|0;m=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=g;m=f}}while(0);f=j&255;j=f<<8;g=k+1|0;k=g&65535;d=c[l+72+((g>>>8&255|512)<<2)>>2]|0;do{if((d|0)==0){h=c[l+3156>>2]|0;if((h|0)==0){o=0;p=m;q=l;break}i=gj[h&4095](k)|0;o=i;p=b[4830442]|0;q=c[2437644]|0}else{o=a[d+(g&255)|0]|0;p=m;q=l}}while(0);l=o&255;o=l|j;c[2426868]=o;b[4830442]=p+2&65535;p=o&65535;j=c[q+72+(f<<2)>>2]|0;do{if((j|0)==0){f=c[q+3144>>2]|0;if((f|0)==0){r=0;s=q;break}m=gj[f&4095](p)|0;r=m;s=c[2437644]|0}else{r=a[j+l|0]|0;s=q}}while(0);q=(r&255)<<8;r=o+1|0;o=r&65535;l=c[s+72+((r>>>8&255)<<2)>>2]|0;do{if((l|0)==0){j=c[s+3144>>2]|0;if((j|0)==0){t=0;break}t=gj[j&4095](o)|0}else{t=a[l+(r&255)|0]|0}}while(0);r=e[4830448]|0;l=r-(t&255|q)|0;t=(l>>>12&8|a[9660900]&-16&255)&255;o=l&65535;a[9660900]=((r^q^l^l>>>1)>>>14&2|l>>>16&1|(o<<16>>16==0?t|4:t)&255)&255;b[4830448]=o;return}function f4q(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=c[2415221]|0;f=d&65535;g=c[2437644]|0;h=c[g+72+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+3156>>2]|0;if((i|0)==0){j=0;k=d;l=g;m=f;break}n=gj[i&4095](f)|0;i=c[2415221]|0;j=n;k=i;l=c[2437644]|0;m=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=g;m=f}}while(0);f=j&255;j=f<<8;g=k+1|0;k=g&65535;d=c[l+72+((g>>>8&255|512)<<2)>>2]|0;do{if((d|0)==0){h=c[l+3156>>2]|0;if((h|0)==0){o=0;p=m;q=l;break}i=gj[h&4095](k)|0;o=i;p=b[4830442]|0;q=c[2437644]|0}else{o=a[d+(g&255)|0]|0;p=m;q=l}}while(0);l=o&255;o=l|j;c[2426868]=o;b[4830442]=p+2&65535;p=o&65535;j=c[q+72+(f<<2)>>2]|0;do{if((j|0)==0){f=c[q+3144>>2]|0;if((f|0)==0){r=0;s=q;break}m=gj[f&4095](p)|0;r=m;s=c[2437644]|0}else{r=a[j+l|0]|0;s=q}}while(0);q=(r&255)<<8;r=o+1|0;o=r&65535;l=c[s+72+((r>>>8&255)<<2)>>2]|0;do{if((l|0)==0){j=c[s+3144>>2]|0;if((j|0)==0){t=0;break}t=gj[j&4095](o)|0}else{t=a[l+(r&255)|0]|0}}while(0);r=e[4830446]|0;l=r-(t&255|q)|0;t=(l>>>12&8|a[9660900]&-16&255)&255;a[9660900]=((r^q^l^l>>>1)>>>14&2|l>>>16&1|((l&65535)<<16>>16==0?t|4:t)&255)&255;return}function f4r(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=c[2415221]|0;f=d&65535;g=c[2437644]|0;h=c[g+72+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+3156>>2]|0;if((i|0)==0){j=0;k=d;l=g;m=f;break}n=gj[i&4095](f)|0;i=c[2415221]|0;j=n;k=i;l=c[2437644]|0;m=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=g;m=f}}while(0);f=(j&255)<<8;j=k+1|0;k=j&65535;g=c[l+72+((j>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){d=c[l+3156>>2]|0;if((d|0)==0){o=0;p=m;break}h=gj[d&4095](k)|0;o=h;p=b[4830442]|0}else{o=a[g+(j&255)|0]|0;p=m}}while(0);b[4830442]=p+2&65535;p=e[4830448]|0;m=p+(o&255|f)|0;o=(m>>>12&8|a[9660900]&-16&255)&255;j=m&65535;a[9660900]=((p^f^m^m>>>1)>>>14&2|m>>>16&1|(j<<16>>16==0?o|4:o)&255)&255;b[4830448]=j;return}function f4s(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=d;k=f;l=e;break}m=gj[h&4095](e)|0;h=c[2415221]|0;i=m;j=h;k=c[2437644]|0;l=h&65535}else{i=a[g+(d&255)|0]|0;j=d;k=f;l=e}}while(0);e=i&255;i=e<<8;f=j+1|0;j=f&65535;d=c[k+72+((f>>>8&255|512)<<2)>>2]|0;do{if((d|0)==0){g=c[k+3156>>2]|0;if((g|0)==0){n=0;o=l;break}h=gj[g&4095](j)|0;n=h;o=b[4830442]|0}else{n=a[d+(f&255)|0]|0;o=l}}while(0);l=n&255|i;c[2415224]=l;b[4830442]=o+2&65535;o=a[9660900]&-15;a[9660900]=o;i=o&255|e>>>4&8;if((l|0)!=0){p=i&255;a[9660900]=p;return}p=(i|4)&255;a[9660900]=p;return}function f4t(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=b[4830442]|0;b[4853736]=d;b[4830442]=d+2&65535;d=a[9660900]&-15;a[9660900]=d;e=b[4830448]|0;f=(e&65535)>>>12&8|d&255;if(e<<16>>16==0){g=(f|4)&255}else{g=f&255}a[9660900]=g;g=c[2426868]|0;f=g&65535;e=a[9660897]|0;d=c[2437644]|0;h=c[d+72+((g>>>8&255|256)<<2)>>2]|0;do{if((h|0)==0){i=c[d+3148>>2]|0;if((i|0)==0){j=d;break}gg[i&4095](f,e);j=c[2437644]|0}else{a[h+(g&255)|0]=e;j=d}}while(0);d=g+1|0;g=a[9660896]|0;e=c[j+72+((d>>>8&255|256)<<2)>>2]|0;if((e|0)!=0){a[e+(d&255)|0]=g;return}e=c[j+3148>>2]|0;if((e|0)==0){return}gg[e&4095](d&65535,g);return}function f4u(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=c[2415221]|0;f=d&65535;g=c[2437644]|0;h=c[g+72+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+3156>>2]|0;if((i|0)==0){j=0;k=f;l=g;break}m=gj[i&4095](f)|0;j=m;k=b[4830442]|0;l=c[2437644]|0}else{j=a[h+(d&255)|0]|0;k=f;l=g}}while(0);g=j&255;c[2426868]=g;b[4830442]=k+1&65535;k=j&255;j=c[l+72>>2]|0;do{if((j|0)==0){f=c[l+3144>>2]|0;if((f|0)==0){n=0;o=l;break}d=gj[f&4095](k)|0;n=d;o=c[2437644]|0}else{n=a[j+g|0]|0;o=l}}while(0);l=(n&255)<<8;n=g+1|0;g=n&65535;j=c[o+72+((n>>>8&255)<<2)>>2]|0;do{if((j|0)==0){k=c[o+3144>>2]|0;if((k|0)==0){p=0;break}p=gj[k&4095](g)|0}else{p=a[j+(n&255)|0]|0}}while(0);n=e[4830448]|0;j=n+(p&255|l)|0;p=(j>>>12&8|a[9660900]&-16&255)&255;g=j&65535;a[9660900]=((n^l^j^j>>>1)>>>14&2|j>>>16&1|(g<<16>>16==0?p|4:p)&255)&255;b[4830448]=g;return}function f4v(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=e;k=f;break}l=gj[h&4095](e)|0;i=l;j=b[4830442]|0;k=c[2437644]|0}else{i=a[g+(d&255)|0]|0;j=e;k=f}}while(0);f=i&255;c[2426868]=f;b[4830442]=j+1&65535;j=i&255;i=c[k+72>>2]|0;do{if((i|0)==0){e=c[k+3144>>2]|0;if((e|0)==0){m=0;n=k;break}d=gj[e&4095](j)|0;m=d;n=c[2437644]|0}else{m=a[i+f|0]|0;n=k}}while(0);k=m&255;m=k<<8;i=f+1|0;f=i&65535;j=c[n+72+((i>>>8&255)<<2)>>2]|0;do{if((j|0)==0){d=c[n+3144>>2]|0;if((d|0)==0){o=0;break}o=gj[d&4095](f)|0}else{o=a[j+(i&255)|0]|0}}while(0);i=o&255|m;c[2415224]=i;m=a[9660900]&-15;a[9660900]=m;o=m&255|k>>>4&8;if((i|0)!=0){p=o&255;a[9660900]=p;return}p=(o|4)&255;a[9660900]=p;return}function f4w(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=e;k=f;break}l=gj[h&4095](e)|0;i=l;j=b[4830442]|0;k=c[2437644]|0}else{i=a[g+(d&255)|0]|0;j=e;k=f}}while(0);f=i&255;c[2426868]=f;b[4830442]=j+1&65535;j=b[4830448]|0;e=(j&65535)>>>12&8|a[9660900]&-15&255;a[9660900]=(j<<16>>16==0?e|4:e)&255;e=i&255;i=a[9660897]|0;j=c[k+1096>>2]|0;do{if((j|0)==0){d=c[k+3148>>2]|0;if((d|0)==0){m=k;break}gg[d&4095](e,i);m=c[2437644]|0}else{a[j+f|0]=i;m=k}}while(0);k=f+1|0;f=a[9660896]|0;i=c[m+72+((k>>>8&255|256)<<2)>>2]|0;if((i|0)!=0){a[i+(k&255)|0]=f;return}i=c[m+3148>>2]|0;if((i|0)==0){return}gg[i&4095](k&65535,f);return}function f4x(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=b[4830446]|0;f=c[2415221]|0;g=f&65535;h=c[2437644]|0;i=c[h+72+((f>>>8&255|512)<<2)>>2]|0;do{if((i|0)==0){j=c[h+3156>>2]|0;if((j|0)==0){k=0;l=g;m=h;break}n=gj[j&4095](g)|0;k=n;l=b[4830442]|0;m=c[2437644]|0}else{k=a[i+(f&255)|0]|0;l=g;m=h}}while(0);b[4853736]=(k&255)+d&65535;b[4830442]=l+1&65535;l=c[2426868]|0;d=l&65535;k=c[m+72+((l>>>8&255)<<2)>>2]|0;do{if((k|0)==0){h=c[m+3144>>2]|0;if((h|0)==0){o=0;p=m;break}g=gj[h&4095](d)|0;o=g;p=c[2437644]|0}else{o=a[k+(l&255)|0]|0;p=m}}while(0);m=(o&255)<<8;o=l+1|0;l=o&65535;k=c[p+72+((o>>>8&255)<<2)>>2]|0;do{if((k|0)==0){d=c[p+3144>>2]|0;if((d|0)==0){q=0;break}q=gj[d&4095](l)|0}else{q=a[k+(o&255)|0]|0}}while(0);o=e[4830448]|0;k=o+(q&255|m)|0;q=(k>>>12&8|a[9660900]&-16&255)&255;l=k&65535;a[9660900]=((o^m^k^k>>>1)>>>14&2|k>>>16&1|(l<<16>>16==0?q|4:q)&255)&255;b[4830448]=l;return}function f4y(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=b[4830446]|0;e=c[2415221]|0;f=e&65535;g=c[2437644]|0;h=c[g+72+((e>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+3156>>2]|0;if((i|0)==0){j=0;k=f;l=g;break}m=gj[i&4095](f)|0;j=m;k=b[4830442]|0;l=c[2437644]|0}else{j=a[h+(e&255)|0]|0;k=f;l=g}}while(0);b[4853736]=(j&255)+d&65535;b[4830442]=k+1&65535;k=c[2426868]|0;d=k&65535;j=c[l+72+((k>>>8&255)<<2)>>2]|0;do{if((j|0)==0){g=c[l+3144>>2]|0;if((g|0)==0){n=0;o=l;break}f=gj[g&4095](d)|0;n=f;o=c[2437644]|0}else{n=a[j+(k&255)|0]|0;o=l}}while(0);l=n&255;n=l<<8;j=k+1|0;k=j&65535;d=c[o+72+((j>>>8&255)<<2)>>2]|0;do{if((d|0)==0){f=c[o+3144>>2]|0;if((f|0)==0){p=0;break}p=gj[f&4095](k)|0}else{p=a[d+(j&255)|0]|0}}while(0);j=p&255|n;c[2415224]=j;n=a[9660900]&-15;a[9660900]=n;p=n&255|l>>>4&8;if((j|0)!=0){q=p&255;a[9660900]=q;return}q=(p|4)&255;a[9660900]=q;return}function f4z(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=b[4830446]|0;e=c[2415221]|0;f=e&65535;g=c[2437644]|0;h=c[g+72+((e>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+3156>>2]|0;if((i|0)==0){j=0;k=f;l=g;break}m=gj[i&4095](f)|0;j=m;k=b[4830442]|0;l=c[2437644]|0}else{j=a[h+(e&255)|0]|0;k=f;l=g}}while(0);b[4853736]=(j&255)+d&65535;b[4830442]=k+1&65535;k=b[4830448]|0;d=(k&65535)>>>12&8|a[9660900]&-15&255;a[9660900]=(k<<16>>16==0?d|4:d)&255;d=c[2426868]|0;k=d&65535;j=a[9660897]|0;g=c[l+72+((d>>>8&255|256)<<2)>>2]|0;do{if((g|0)==0){f=c[l+3148>>2]|0;if((f|0)==0){n=l;break}gg[f&4095](k,j);n=c[2437644]|0}else{a[g+(d&255)|0]=j;n=l}}while(0);l=d+1|0;d=a[9660896]|0;j=c[n+72+((l>>>8&255|256)<<2)>>2]|0;if((j|0)!=0){a[j+(l&255)|0]=d;return}j=c[n+3148>>2]|0;if((j|0)==0){return}gg[j&4095](l&65535,d);return}function f4A(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=c[2415221]|0;f=d&65535;g=c[2437644]|0;h=c[g+72+((d>>>8&255|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+3156>>2]|0;if((i|0)==0){j=0;k=d;l=g;m=f;break}n=gj[i&4095](f)|0;i=c[2415221]|0;j=n;k=i;l=c[2437644]|0;m=i&65535}else{j=a[h+(d&255)|0]|0;k=d;l=g;m=f}}while(0);f=j&255;j=f<<8;g=k+1|0;k=g&65535;d=c[l+72+((g>>>8&255|512)<<2)>>2]|0;do{if((d|0)==0){h=c[l+3156>>2]|0;if((h|0)==0){o=0;p=m;q=l;break}i=gj[h&4095](k)|0;o=i;p=b[4830442]|0;q=c[2437644]|0}else{o=a[d+(g&255)|0]|0;p=m;q=l}}while(0);l=o&255;o=l|j;c[2426868]=o;b[4830442]=p+2&65535;p=o&65535;j=c[q+72+(f<<2)>>2]|0;do{if((j|0)==0){f=c[q+3144>>2]|0;if((f|0)==0){r=0;s=q;break}m=gj[f&4095](p)|0;r=m;s=c[2437644]|0}else{r=a[j+l|0]|0;s=q}}while(0);q=(r&255)<<8;r=o+1|0;o=r&65535;l=c[s+72+((r>>>8&255)<<2)>>2]|0;do{if((l|0)==0){j=c[s+3144>>2]|0;if((j|0)==0){t=0;break}t=gj[j&4095](o)|0}else{t=a[l+(r&255)|0]|0}}while(0);r=e[4830448]|0;l=r+(t&255|q)|0;t=(l>>>12&8|a[9660900]&-16&255)&255;o=l&65535;a[9660900]=((r^q^l^l>>>1)>>>14&2|l>>>16&1|(o<<16>>16==0?t|4:t)&255)&255;b[4830448]=o;return}function f4B(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=d;k=f;l=e;break}m=gj[h&4095](e)|0;h=c[2415221]|0;i=m;j=h;k=c[2437644]|0;l=h&65535}else{i=a[g+(d&255)|0]|0;j=d;k=f;l=e}}while(0);e=i&255;i=e<<8;f=j+1|0;j=f&65535;d=c[k+72+((f>>>8&255|512)<<2)>>2]|0;do{if((d|0)==0){g=c[k+3156>>2]|0;if((g|0)==0){n=0;o=l;p=k;break}h=gj[g&4095](j)|0;n=h;o=b[4830442]|0;p=c[2437644]|0}else{n=a[d+(f&255)|0]|0;o=l;p=k}}while(0);k=n&255;n=k|i;c[2426868]=n;b[4830442]=o+2&65535;o=n&65535;i=c[p+72+(e<<2)>>2]|0;do{if((i|0)==0){e=c[p+3144>>2]|0;if((e|0)==0){q=0;r=p;break}l=gj[e&4095](o)|0;q=l;r=c[2437644]|0}else{q=a[i+k|0]|0;r=p}}while(0);p=q&255;q=p<<8;k=n+1|0;n=k&65535;i=c[r+72+((k>>>8&255)<<2)>>2]|0;do{if((i|0)==0){o=c[r+3144>>2]|0;if((o|0)==0){s=0;break}s=gj[o&4095](n)|0}else{s=a[i+(k&255)|0]|0}}while(0);k=s&255|q;c[2415224]=k;q=a[9660900]&-15;a[9660900]=q;s=q&255|p>>>4&8;if((k|0)!=0){t=s&255;a[9660900]=t;return}t=(s|4)&255;a[9660900]=t;return}function f4C(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=d;k=f;l=e;break}m=gj[h&4095](e)|0;h=c[2415221]|0;i=m;j=h;k=c[2437644]|0;l=h&65535}else{i=a[g+(d&255)|0]|0;j=d;k=f;l=e}}while(0);e=i&255;i=e<<8;f=j+1|0;j=f&65535;d=c[k+72+((f>>>8&255|512)<<2)>>2]|0;do{if((d|0)==0){g=c[k+3156>>2]|0;if((g|0)==0){n=0;o=l;p=k;break}h=gj[g&4095](j)|0;n=h;o=b[4830442]|0;p=c[2437644]|0}else{n=a[d+(f&255)|0]|0;o=l;p=k}}while(0);k=n&255;n=k|i;c[2426868]=n;b[4830442]=o+2&65535;o=b[4830448]|0;i=(o&65535)>>>12&8|a[9660900]&-15&255;a[9660900]=(o<<16>>16==0?i|4:i)&255;i=n&65535;o=a[9660897]|0;l=c[p+72+((e|256)<<2)>>2]|0;do{if((l|0)==0){e=c[p+3148>>2]|0;if((e|0)==0){q=p;break}gg[e&4095](i,o);q=c[2437644]|0}else{a[l+k|0]=o;q=p}}while(0);p=n+1|0;n=a[9660896]|0;o=c[q+72+((p>>>8&255|256)<<2)>>2]|0;if((o|0)!=0){a[o+(p&255)|0]=n;return}o=c[q+3148>>2]|0;if((o|0)==0){return}gg[o&4095](p&65535,n);return}function f4D(f){f=f|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0,cf=0,cg=0,ch=0,ci=0,cj=0,ck=0,cl=0,cm=0,cn=0,co=0,cp=0,cq=0,cr=0,cs=0,ct=0,cu=0,cv=0,cw=0,cx=0,cy=0,cz=0,cA=0,cB=0,cC=0,cD=0,cE=0,cF=0,cG=0,cH=0,cI=0,cJ=0,cK=0,cL=0,cM=0,cN=0,cO=0,cP=0,cQ=0,cR=0,cS=0,cT=0,cU=0,cV=0,cW=0,cX=0,cY=0,cZ=0,c_=0,c$=0,c0=0,c1=0,c2=0,c3=0,c4=0,c5=0,c6=0,c7=0,c8=0,c9=0,da=0,db=0,dc=0,dd=0,de=0,df=0,dg=0,dh=0,di=0,dj=0,dk=0,dl=0,dm=0,dn=0,dp=0,dq=0,dr=0,ds=0,dt=0,du=0,dv=0,dw=0,dx=0,dy=0,dz=0,dA=0,dB=0,dC=0,dD=0,dE=0,dF=0,dG=0,dH=0,dI=0,dJ=0,dK=0,dL=0,dM=0,dN=0,dO=0,dP=0,dQ=0,dR=0,dS=0,dT=0,dU=0,dV=0,dW=0,dX=0,dY=0,dZ=0,d_=0,d$=0,d0=0,d1=0,d2=0,d3=0,d4=0,d5=0,d6=0,d7=0,d8=0,d9=0,ea=0,eb=0,ec=0,ed=0,ee=0,ef=0,eg=0,eh=0,ei=0,ej=0,ek=0,el=0,em=0,en=0,eo=0,ep=0,eq=0,er=0,es=0,et=0,eu=0,ev=0,ew=0,ex=0,ey=0,ez=0,eA=0,eB=0,eC=0,eD=0,eE=0,eF=0,eG=0,eH=0,eI=0,eJ=0,eK=0,eL=0,eM=0,eN=0,eO=0,eP=0,eQ=0,eR=0,eS=0,eT=0,eU=0,eV=0,eW=0,eX=0,eY=0,eZ=0,e_=0,e$=0,e0=0,e1=0,e2=0,e3=0,e4=0,e5=0,e6=0,e7=0,e8=0,e9=0,fa=0,fb=0,fc=0,fd=0,fe=0,ff=0,fg=0,fh=0,fi=0,fj=0,fk=0,fl=0,fm=0,fn=0,fo=0,fp=0,fq=0,fr=0,fs=0,ft=0,fu=0,fv=0,fw=0,fx=0,fy=0,fz=0,fA=0,fB=0,fC=0;h=i;i=i+25712|0;j=b[4830469]|0;b[4830471]=(b[4830471]|0)-j&65535;b[4830474]=(b[4830474]|0)-j&65535;b[4830469]=0;j=c[2415235]|0;k=c[2415234]|0;l=c[2415237]|0;m=(j-k|0)>>>0<(l-k|0)>>>0?j:l;c[3528192]=m;l=c[2415227]|0;c[2440594]=f-l;c[2415234]=l+k|0;if((l+k|0)>>>0>=m>>>0){f03()}c[2415227]=0;do{do{m=1;if(m){m=0;if((a[9660901]&24)==0){k=c[2415221]|0;c[2415220]=k;l=c[2437644]|0;j=c[l+72+((k>>>8&255|512)<<2)>>2]|0;do{if((j|0)==0){n=c[l+3152>>2]|0;if((n|0)==0){o=0;p=k&65535;break}q=gj[n&4095](k&65535)|0;o=q;p=b[4830442]|0}else{o=a[j+(k&255)|0]|0;p=k&65535}}while(0);k=p+1&65535;b[4830442]=k;j=o&255;L43129:do{l=1;q=j|0;if(l){l=0;switch(q|0){case 9:{n=(b[4830446]|0)-1&65535;b[4830446]=n;r=a[9660900]|0;a[9660900]=n<<16>>16==0?r|4:r&-5;break};case 8:{r=(b[4830446]|0)+1&65535;b[4830446]=r;n=a[9660900]|0;a[9660900]=r<<16>>16==0?n|4:n&-5;break};case 25:{n=a[9660897]|0;if((n&14)>9){s=35296}else{if((a[9660900]&32)==0){t=0}else{s=35296}}if((s|0)==35296){s=0;t=6}do{if((n&-16&255)>128){r=(n&14)>9?t|96:t;if((n&-16&255)<=144){u=r;s=35300;break}v=r;w=a[9660900]|0;s=35301}else{u=t;s=35300}}while(0);if((s|0)==35300){s=0;r=a[9660900]|0;if((r&1)==0){x=u;y=r}else{v=u;w=r;s=35301}}if((s|0)==35301){s=0;x=v|96;y=w}r=x+(n&255)&65535;z=((r&65535)>>>4&8|y&-15&255)&255;a[9660900]=(((r&255)<<24>>24==0?z|4:z)&255|(r&65535)>>>8&1)&255;a[9660897]=r&255;break};case 26:{a[9660901]=a[9660901]|16;r=c[3528192]|0;z=c[2415234]|0;A=c[2440594]|0;C=(r-z|0|0)>(A|0)?A:r-z|0;if((C|0)<=0){break L43129}c[2440594]=A-C;c[2415234]=C+z|0;if((C+z|0)>>>0<r>>>0){break L43129}f03();break};case 27:{r=a[9660897]|0;z=a[9660896]|0;C=(z&255)+(r&255)&65535&65535;A=(C>>>4&8|a[9660900]&-48&255)&255;a[9660900]=((C^(z^r)&255)<<1&32|C>>>8&1|(C^(z^r)&255^C>>>1)>>>6&2|(((z&255)+(r&255)&65535&255)<<24>>24==0?A|4:A)&255)&255;a[9660897]=(z&255)+(r&255)&65535&255;break};case 28:{f00(-18);break};case 13:{a[9660900]=a[9660900]|1;break};case 14:{f1a();break};case 15:{f1b();break};case 6:{f06();break};case 10:{a[9660900]=a[9660900]&-3;break};case 116:{r=c[2415221]|0;z=c[2437644]|0;A=c[z+72+((r>>>8&255|512)<<2)>>2]|0;do{if((A|0)==0){C=c[z+3156>>2]|0;if((C|0)==0){D=0;E=r;F=z;G=r&65535;break}H=gj[C&4095](r&65535)|0;C=c[2415221]|0;D=H;E=C;F=c[2437644]|0;G=C&65535}else{D=a[A+(r&255)|0]|0;E=r;F=z;G=r&65535}}while(0);r=D&255;z=E+1|0;A=c[F+72+((z>>>8&255|512)<<2)>>2]|0;do{if((A|0)==0){n=c[F+3156>>2]|0;if((n|0)==0){K=0;L=G;M=F;break}C=gj[n&4095](z&65535)|0;K=C;L=b[4830442]|0;M=c[2437644]|0}else{K=a[A+(z&255)|0]|0;L=G;M=F}}while(0);z=K&255;c[2426868]=z|r<<8;b[4830442]=L+2&65535;A=c[M+72+(r<<2)>>2]|0;do{if((A|0)==0){C=c[M+3144>>2]|0;if((C|0)==0){N=0;O=z|r<<8;P=M;break}n=gj[C&4095]((z|r<<8)&65535)|0;N=n;O=c[2426868]|0;P=c[2437644]|0}else{N=a[A+z|0]|0;O=z|r<<8;P=M}}while(0);r=a[9660900]&-14|N&1;z=(N&255)>>>1;a[9660900]=z<<24>>24==0?r|4:r;r=c[P+72+((O>>>8&255|256)<<2)>>2]|0;if((r|0)!=0){a[r+(O&255)|0]=z;break L43129}r=c[P+3148>>2]|0;if((r|0)==0){break L43129}gg[r&4095](O&65535,z);break};case 117:{z=c[2415221]|0;r=c[2437644]|0;A=c[r+72+((z>>>8&255|512)<<2)>>2]|0;do{if((A|0)==0){n=c[r+3156>>2]|0;if((n|0)==0){Q=0;R=z&65535;S=r;break}C=gj[n&4095](z&65535)|0;Q=C;R=b[4830442]|0;S=c[2437644]|0}else{Q=a[A+(z&255)|0]|0;R=z&65535;S=r}}while(0);b[4830442]=R+1&65535;r=c[2415221]|0;z=c[S+72+((r>>>8&255|512)<<2)>>2]|0;do{if((z|0)==0){A=c[S+3156>>2]|0;if((A|0)==0){T=0;U=r&65535;V=S;break}C=gj[A&4095](r&65535)|0;T=C;U=b[4830442]|0;V=c[2437644]|0}else{T=a[z+(r&255)|0]|0;U=r&65535;V=S}}while(0);r=T&255;c[2426868]=r;b[4830442]=U+1&65535;z=T&255;C=c[V+72>>2]|0;do{if((C|0)==0){A=c[V+3144>>2]|0;if((A|0)==0){W=0;X=r;Y=V;break}n=gj[A&4095](z)|0;W=n;X=c[2426868]|0;Y=c[2437644]|0}else{W=a[C+r|0]|0;X=r;Y=V}}while(0);r=W^Q;C=(r&255)>>>4&8|a[9660900]&-15;a[9660900]=W<<24>>24==Q<<24>>24?C|4:C;C=c[Y+72+((X>>>8&255|256)<<2)>>2]|0;if((C|0)!=0){a[C+(X&255)|0]=r;break L43129}C=c[Y+3148>>2]|0;if((C|0)==0){break L43129}gg[C&4095](X&65535,r);break};case 118:{r=c[2415221]|0;C=c[2437644]|0;z=c[C+72+((r>>>8&255|512)<<2)>>2]|0;do{if((z|0)==0){n=c[C+3156>>2]|0;if((n|0)==0){Z=0;_=r;$=C;aa=r&65535;break}A=gj[n&4095](r&65535)|0;n=c[2415221]|0;Z=A;_=n;$=c[2437644]|0;aa=n&65535}else{Z=a[z+(r&255)|0]|0;_=r;$=C;aa=r&65535}}while(0);r=Z&255;C=_+1|0;z=c[$+72+((C>>>8&255|512)<<2)>>2]|0;do{if((z|0)==0){n=c[$+3156>>2]|0;if((n|0)==0){ab=0;ac=aa;ad=$;break}A=gj[n&4095](C&65535)|0;ab=A;ac=b[4830442]|0;ad=c[2437644]|0}else{ab=a[z+(C&255)|0]|0;ac=aa;ad=$}}while(0);C=ab&255;c[2426868]=C|r<<8;b[4830442]=ac+2&65535;z=c[ad+72+(r<<2)>>2]|0;do{if((z|0)==0){A=c[ad+3144>>2]|0;if((A|0)==0){ae=0;af=C|r<<8;ag=ad;break}n=gj[A&4095]((C|r<<8)&65535)|0;ae=n;af=c[2426868]|0;ag=c[2437644]|0}else{ae=a[z+C|0]|0;af=C|r<<8;ag=ad}}while(0);r=a[9660900]|0;C=r<<7|(ae&255)>>>1;z=r&-14|ae&1|r<<3&8;a[9660900]=C<<24>>24==0?z|4:z;z=c[ag+72+((af>>>8&255|256)<<2)>>2]|0;if((z|0)!=0){a[z+(af&255)|0]=C;break L43129}z=c[ag+3148>>2]|0;if((z|0)==0){break L43129}gg[z&4095](af&65535,C);break};case 119:{C=c[2415221]|0;z=c[2437644]|0;r=c[z+72+((C>>>8&255|512)<<2)>>2]|0;do{if((r|0)==0){n=c[z+3156>>2]|0;if((n|0)==0){ah=0;ai=C;aj=z;ak=C&65535;break}A=gj[n&4095](C&65535)|0;n=c[2415221]|0;ah=A;ai=n;aj=c[2437644]|0;ak=n&65535}else{ah=a[r+(C&255)|0]|0;ai=C;aj=z;ak=C&65535}}while(0);C=ah&255;z=ai+1|0;r=c[aj+72+((z>>>8&255|512)<<2)>>2]|0;do{if((r|0)==0){n=c[aj+3156>>2]|0;if((n|0)==0){al=0;am=ak;an=aj;break}A=gj[n&4095](z&65535)|0;al=A;am=b[4830442]|0;an=c[2437644]|0}else{al=a[r+(z&255)|0]|0;am=ak;an=aj}}while(0);z=al&255;c[2426868]=z|C<<8;b[4830442]=am+2&65535;r=c[an+72+(C<<2)>>2]|0;do{if((r|0)==0){A=c[an+3144>>2]|0;if((A|0)==0){ao=0;ap=z|C<<8;aq=an;break}n=gj[A&4095]((z|C<<8)&65535)|0;ao=n;ap=c[2426868]|0;aq=c[2437644]|0}else{ao=a[r+z|0]|0;ap=z|C<<8;aq=an}}while(0);C=(ao&255)>>>1;z=a[9660900]&-14|ao&1|(ao&255)>>>4&8;a[9660900]=(C<<1&-128|C)<<24>>24==0?z|4:z;z=c[aq+72+((ap>>>8&255|256)<<2)>>2]|0;if((z|0)!=0){a[z+(ap&255)|0]=C<<1&-128|C;break L43129}z=c[aq+3148>>2]|0;if((z|0)==0){break L43129}gg[z&4095](ap&65535,C<<1&-128|C);break};case 120:{C=c[2415221]|0;z=c[2437644]|0;r=c[z+72+((C>>>8&255|512)<<2)>>2]|0;do{if((r|0)==0){n=c[z+3156>>2]|0;if((n|0)==0){ar=0;as=C;at=z;au=C&65535;break}A=gj[n&4095](C&65535)|0;n=c[2415221]|0;ar=A;as=n;at=c[2437644]|0;au=n&65535}else{ar=a[r+(C&255)|0]|0;as=C;at=z;au=C&65535}}while(0);C=ar&255;z=as+1|0;r=c[at+72+((z>>>8&255|512)<<2)>>2]|0;do{if((r|0)==0){n=c[at+3156>>2]|0;if((n|0)==0){av=0;aw=au;ax=at;break}A=gj[n&4095](z&65535)|0;av=A;aw=b[4830442]|0;ax=c[2437644]|0}else{av=a[r+(z&255)|0]|0;aw=au;ax=at}}while(0);z=av&255;c[2426868]=z|C<<8;b[4830442]=aw+2&65535;r=c[ax+72+(C<<2)>>2]|0;do{if((r|0)==0){A=c[ax+3144>>2]|0;if((A|0)==0){ay=0;az=z|C<<8;aA=ax;break}n=gj[A&4095]((z|C<<8)&65535)|0;ay=n;az=c[2426868]|0;aA=c[2437644]|0}else{ay=a[r+z|0]|0;az=z|C<<8;aA=ax}}while(0);C=(ay&255)<<1;z=((C&65535)>>>4&8|a[9660900]&-16&255)&255;a[9660900]=(((C&65535)>>>1^C&65535)>>>6&2|(C&65535)>>>8|((C&255)<<24>>24==0?z|4:z)&255)&255;z=c[aA+72+((az>>>8&255|256)<<2)>>2]|0;if((z|0)!=0){a[z+(az&255)|0]=C&255;break L43129}z=c[aA+3148>>2]|0;if((z|0)==0){break L43129}gg[z&4095](az&65535,C&255);break};case 121:{C=c[2415221]|0;z=c[2437644]|0;r=c[z+72+((C>>>8&255|512)<<2)>>2]|0;do{if((r|0)==0){n=c[z+3156>>2]|0;if((n|0)==0){aB=0;aC=C;aD=z;aE=C&65535;break}A=gj[n&4095](C&65535)|0;n=c[2415221]|0;aB=A;aC=n;aD=c[2437644]|0;aE=n&65535}else{aB=a[r+(C&255)|0]|0;aC=C;aD=z;aE=C&65535}}while(0);C=aB&255;z=aC+1|0;r=c[aD+72+((z>>>8&255|512)<<2)>>2]|0;do{if((r|0)==0){n=c[aD+3156>>2]|0;if((n|0)==0){aF=0;aG=aE;aH=aD;break}A=gj[n&4095](z&65535)|0;aF=A;aG=b[4830442]|0;aH=c[2437644]|0}else{aF=a[r+(z&255)|0]|0;aG=aE;aH=aD}}while(0);z=aF&255;c[2426868]=z|C<<8;b[4830442]=aG+2&65535;r=c[aH+72+(C<<2)>>2]|0;do{if((r|0)==0){A=c[aH+3144>>2]|0;if((A|0)==0){aI=0;aJ=z|C<<8;aK=aH;break}n=gj[A&4095]((z|C<<8)&65535)|0;aI=n;aJ=c[2426868]|0;aK=c[2437644]|0}else{aI=a[r+z|0]|0;aJ=z|C<<8;aK=aH}}while(0);C=a[9660900]|0;z=C&1|(aI&255)<<1;a[9660900]=(((z&65535)>>>1^z&65535)>>>6&2|(z&65535)>>>8|((z&255)<<24>>24==0?((z&65535)>>>4&8|C&-16&255)&255|4:((z&65535)>>>4&8|C&-16&255)&255)&255)&255;C=c[aK+72+((aJ>>>8&255|256)<<2)>>2]|0;if((C|0)!=0){a[C+(aJ&255)|0]=z&255;break L43129}C=c[aK+3148>>2]|0;if((C|0)==0){break L43129}gg[C&4095](aJ&65535,z&255);break};case 122:{z=c[2415221]|0;C=c[2437644]|0;r=c[C+72+((z>>>8&255|512)<<2)>>2]|0;do{if((r|0)==0){n=c[C+3156>>2]|0;if((n|0)==0){aL=0;aM=z;aN=C;aO=z&65535;break}A=gj[n&4095](z&65535)|0;n=c[2415221]|0;aL=A;aM=n;aN=c[2437644]|0;aO=n&65535}else{aL=a[r+(z&255)|0]|0;aM=z;aN=C;aO=z&65535}}while(0);z=aL&255;C=aM+1|0;r=c[aN+72+((C>>>8&255|512)<<2)>>2]|0;do{if((r|0)==0){n=c[aN+3156>>2]|0;if((n|0)==0){aP=0;aQ=aO;aR=aN;break}A=gj[n&4095](C&65535)|0;aP=A;aQ=b[4830442]|0;aR=c[2437644]|0}else{aP=a[r+(C&255)|0]|0;aQ=aO;aR=aN}}while(0);C=aP&255;c[2426868]=C|z<<8;b[4830442]=aQ+2&65535;r=c[aR+72+(z<<2)>>2]|0;do{if((r|0)==0){A=c[aR+3144>>2]|0;if((A|0)==0){aS=0;aT=C|z<<8;aU=aR;break}n=gj[A&4095]((C|z<<8)&65535)|0;aS=n;aT=c[2426868]|0;aU=c[2437644]|0}else{aS=a[r+C|0]|0;aT=C|z<<8;aU=aR}}while(0);z=aS-1&255;a[9660900]=a[9660900]&-15|a[669184+(z&255)|0];C=c[aU+72+((aT>>>8&255|256)<<2)>>2]|0;if((C|0)!=0){a[C+(aT&255)|0]=z;break L43129}C=c[aU+3148>>2]|0;if((C|0)==0){break L43129}gg[C&4095](aT&65535,z);break};case 123:{z=c[2415221]|0;C=c[2437644]|0;r=c[C+72+((z>>>8&255|512)<<2)>>2]|0;do{if((r|0)==0){n=c[C+3156>>2]|0;if((n|0)==0){aV=0;aW=z&65535;aX=C;break}A=gj[n&4095](z&65535)|0;aV=A;aW=b[4830442]|0;aX=c[2437644]|0}else{aV=a[r+(z&255)|0]|0;aW=z&65535;aX=C}}while(0);b[4830442]=aW+1&65535;C=c[2415221]|0;z=c[aX+72+((C>>>8&255|512)<<2)>>2]|0;do{if((z|0)==0){r=c[aX+3156>>2]|0;if((r|0)==0){aY=0;aZ=C&65535;a_=aX;break}A=gj[r&4095](C&65535)|0;aY=A;aZ=b[4830442]|0;a_=c[2437644]|0}else{aY=a[z+(C&255)|0]|0;aZ=C&65535;a_=aX}}while(0);C=aY&255;c[2426868]=C;b[4830442]=aZ+1&65535;z=aY&255;A=c[a_+72>>2]|0;do{if((A|0)==0){r=c[a_+3144>>2]|0;if((r|0)==0){a$=0;break}a$=gj[r&4095](z)|0}else{a$=a[A+C|0]|0}}while(0);C=a$&aV;A=(C&255)>>>4&8|a[9660900]&-15;a[9660900]=C<<24>>24==0?A|4:A;break};case 124:{A=c[2415221]|0;C=c[2437644]|0;z=c[C+72+((A>>>8&255|512)<<2)>>2]|0;do{if((z|0)==0){r=c[C+3156>>2]|0;if((r|0)==0){a0=0;a1=A;a2=C;a3=A&65535;break}n=gj[r&4095](A&65535)|0;r=c[2415221]|0;a0=n;a1=r;a2=c[2437644]|0;a3=r&65535}else{a0=a[z+(A&255)|0]|0;a1=A;a2=C;a3=A&65535}}while(0);A=a0&255;C=a1+1|0;z=c[a2+72+((C>>>8&255|512)<<2)>>2]|0;do{if((z|0)==0){r=c[a2+3156>>2]|0;if((r|0)==0){a4=0;a5=a3;a6=a2;break}n=gj[r&4095](C&65535)|0;a4=n;a5=b[4830442]|0;a6=c[2437644]|0}else{a4=a[z+(C&255)|0]|0;a5=a3;a6=a2}}while(0);C=a4&255;c[2426868]=C|A<<8;b[4830442]=a5+2&65535;z=c[a6+72+(A<<2)>>2]|0;do{if((z|0)==0){n=c[a6+3144>>2]|0;if((n|0)==0){a7=0;a8=C|A<<8;a9=a6;break}r=gj[n&4095]((C|A<<8)&65535)|0;a7=r;a8=c[2426868]|0;a9=c[2437644]|0}else{a7=a[z+C|0]|0;a8=C|A<<8;a9=a6}}while(0);A=a7+1&255;a[9660900]=a[9660900]&-15|a[668928+(A&255)|0];C=c[a9+72+((a8>>>8&255|256)<<2)>>2]|0;if((C|0)!=0){a[C+(a8&255)|0]=A;break L43129}C=c[a9+3148>>2]|0;if((C|0)==0){break L43129}gg[C&4095](a8&65535,A);break};case 125:{A=c[2415221]|0;C=c[2437644]|0;z=c[C+72+((A>>>8&255|512)<<2)>>2]|0;do{if((z|0)==0){r=c[C+3156>>2]|0;if((r|0)==0){ba=0;bb=A;bc=C;bd=A&65535;break}n=gj[r&4095](A&65535)|0;r=c[2415221]|0;ba=n;bb=r;bc=c[2437644]|0;bd=r&65535}else{ba=a[z+(A&255)|0]|0;bb=A;bc=C;bd=A&65535}}while(0);A=ba&255;C=bb+1|0;z=c[bc+72+((C>>>8&255|512)<<2)>>2]|0;do{if((z|0)==0){r=c[bc+3156>>2]|0;if((r|0)==0){be=0;bf=bd;bg=bc;break}n=gj[r&4095](C&65535)|0;be=n;bf=b[4830442]|0;bg=c[2437644]|0}else{be=a[z+(C&255)|0]|0;bf=bd;bg=bc}}while(0);C=be&255;c[2426868]=C|A<<8;b[4830442]=bf+2&65535;z=c[bg+72+(A<<2)>>2]|0;do{if((z|0)==0){n=c[bg+3144>>2]|0;if((n|0)==0){bh=0;break}bh=gj[n&4095]((C|A<<8)&65535)|0}else{bh=a[z+C|0]|0}}while(0);C=a[9660900]&-16|(bh&255)>>>4&8;a[9660900]=bh<<24>>24==0?C|4:C;break};case 126:{C=c[2415221]|0;z=c[2437644]|0;A=c[z+72+((C>>>8&255|512)<<2)>>2]|0;do{if((A|0)==0){n=c[z+3156>>2]|0;if((n|0)==0){bi=0;bj=C;bk=z;break}r=gj[n&4095](C&65535)|0;bi=r;bj=c[2415221]|0;bk=c[2437644]|0}else{bi=a[A+(C&255)|0]|0;bj=C;bk=z}}while(0);z=(bi&255)<<8;C=bj+1|0;A=c[bk+72+((C>>>8&255|512)<<2)>>2]|0;do{if((A|0)==0){r=c[bk+3156>>2]|0;if((r|0)==0){bl=0;break}bl=gj[r&4095](C&65535)|0}else{bl=a[A+(C&255)|0]|0}}while(0);C=bl&255|z;c[2426868]=C;b[4830442]=C&65535;b[4830442]=c[2415221]&65535;break};case 127:{C=c[2415221]|0;A=c[2437644]|0;r=c[A+72+((C>>>8&255|512)<<2)>>2]|0;do{if((r|0)==0){n=c[A+3156>>2]|0;if((n|0)==0){bm=0;bn=C;bo=A;bp=C&65535;break}H=gj[n&4095](C&65535)|0;n=c[2415221]|0;bm=H;bn=n;bo=c[2437644]|0;bp=n&65535}else{bm=a[r+(C&255)|0]|0;bn=C;bo=A;bp=C&65535}}while(0);C=bm&255;A=bn+1|0;r=c[bo+72+((A>>>8&255|512)<<2)>>2]|0;do{if((r|0)==0){z=c[bo+3156>>2]|0;if((z|0)==0){bq=0;br=bp;bs=bo;break}n=gj[z&4095](A&65535)|0;bq=n;br=b[4830442]|0;bs=c[2437644]|0}else{bq=a[r+(A&255)|0]|0;br=bp;bs=bo}}while(0);A=bq&255;c[2426868]=A|C<<8;b[4830442]=br+2&65535;r=c[bs+72+((C|256)<<2)>>2]|0;do{if((r|0)==0){n=c[bs+3148>>2]|0;if((n|0)==0){break}gg[n&4095]((A|C<<8)&65535,0)}else{a[r+A|0]=0}}while(0);a[9660900]=a[9660900]&-16|4;break};case 128:{A=c[2415221]|0;r=c[2437644]|0;C=c[r+72+((A>>>8&255|512)<<2)>>2]|0;do{if((C|0)==0){n=c[r+3156>>2]|0;if((n|0)==0){bt=0;bu=A&65535;break}z=gj[n&4095](A&65535)|0;bt=z;bu=b[4830442]|0}else{bt=a[C+(A&255)|0]|0;bu=A&65535}}while(0);b[4830442]=bu+1&65535;A=a[9660897]|0;C=(A&255)-(bt&255)|0;r=(C>>>4&8|a[9660900]&-16&255)&255;a[9660900]=(((A^bt)&255^C^C>>>1)>>>6&2|C>>>8&1|((C&255)<<24>>24==0?r|4:r)&255)&255;a[9660897]=C&255;break};case 129:{C=c[2415221]|0;r=c[2437644]|0;A=c[r+72+((C>>>8&255|512)<<2)>>2]|0;do{if((A|0)==0){z=c[r+3156>>2]|0;if((z|0)==0){bv=0;bw=C&65535;break}n=gj[z&4095](C&65535)|0;bv=n;bw=b[4830442]|0}else{bv=a[A+(C&255)|0]|0;bw=C&65535}}while(0);b[4830442]=bw+1&65535;C=a[9660897]|0;A=(C&255)-(bv&255)|0;r=(A>>>4&8|a[9660900]&-16&255)&255;a[9660900]=(((C^bv)&255^A^A>>>1)>>>6&2|A>>>8&1|((A&255)<<24>>24==0?r|4:r)&255)&255;break};case 130:{r=c[2415221]|0;A=c[2437644]|0;C=c[A+72+((r>>>8&255|512)<<2)>>2]|0;do{if((C|0)==0){n=c[A+3156>>2]|0;if((n|0)==0){bx=0;by=r&65535;break}z=gj[n&4095](r&65535)|0;bx=z;by=b[4830442]|0}else{bx=a[C+(r&255)|0]|0;by=r&65535}}while(0);b[4830442]=by+1&65535;r=a[9660897]|0;C=a[9660900]|0;A=(r&255)-(bx&255)-(C&1)|0;a[9660900]=((A^(r^bx)&255^A>>>1)>>>6&2|A>>>8&1|((A&255)<<24>>24==0?(A>>>4&8|C&-16&255)&255|4:(A>>>4&8|C&-16&255)&255)&255)&255;a[9660897]=A&255;break};case 131:{A=c[2415221]|0;C=c[2437644]|0;r=c[C+72+((A>>>8&255|512)<<2)>>2]|0;do{if((r|0)==0){z=c[C+3156>>2]|0;if((z|0)==0){bz=0;bA=A;bB=C;bC=A&65535;break}n=gj[z&4095](A&65535)|0;z=c[2415221]|0;bz=n;bA=z;bB=c[2437644]|0;bC=z&65535}else{bz=a[r+(A&255)|0]|0;bA=A;bB=C;bC=A&65535}}while(0);A=(bz&255)<<8;C=bA+1|0;r=c[bB+72+((C>>>8&255|512)<<2)>>2]|0;do{if((r|0)==0){z=c[bB+3156>>2]|0;if((z|0)==0){bD=0;bE=bC;break}n=gj[z&4095](C&65535)|0;bD=n;bE=b[4830442]|0}else{bD=a[r+(C&255)|0]|0;bE=bC}}while(0);b[4830442]=bE+2&65535;C=e[4830448]|0;r=C-(bD&255|A)|0;n=(r>>>12&8|a[9660900]&-16&255)&255;a[9660900]=((C^A^r^r>>>1)>>>14&2|r>>>16&1|((r&65535)<<16>>16==0?n|4:n)&255)&255;b[4830448]=r&65535;break};case 132:{r=c[2415221]|0;n=c[2437644]|0;C=c[n+72+((r>>>8&255|512)<<2)>>2]|0;do{if((C|0)==0){z=c[n+3156>>2]|0;if((z|0)==0){bF=0;bG=r&65535;break}H=gj[z&4095](r&65535)|0;bF=H;bG=b[4830442]|0}else{bF=a[C+(r&255)|0]|0;bG=r&65535}}while(0);b[4830442]=bG+1&65535;r=a[9660897]&bF;a[9660897]=r;C=(r&255)>>>4&8|a[9660900]&-15;a[9660900]=r<<24>>24==0?C|4:C;break};case 133:{C=c[2415221]|0;r=c[2437644]|0;n=c[r+72+((C>>>8&255|512)<<2)>>2]|0;do{if((n|0)==0){A=c[r+3156>>2]|0;if((A|0)==0){bH=0;bI=C&65535;break}H=gj[A&4095](C&65535)|0;bH=H;bI=b[4830442]|0}else{bH=a[n+(C&255)|0]|0;bI=C&65535}}while(0);b[4830442]=bI+1&65535;C=a[9660897]&bH;n=(C&255)>>>4&8|a[9660900]&-15;a[9660900]=C<<24>>24==0?n|4:n;break};case 134:{n=c[2415221]|0;C=c[2437644]|0;r=c[C+72+((n>>>8&255|512)<<2)>>2]|0;do{if((r|0)==0){H=c[C+3156>>2]|0;if((H|0)==0){bJ=0;bK=n&65535;break}A=gj[H&4095](n&65535)|0;bJ=A;bK=b[4830442]|0}else{bJ=a[r+(n&255)|0]|0;bK=n&65535}}while(0);a[9660897]=bJ;b[4830442]=bK+1&65535;n=a[9660900]&-15|(bJ&255)>>>4&8;a[9660900]=bJ<<24>>24==0?n|4:n;break};case 135:{n=a[9660897]|0;r=(n&255)>>>4&8|a[9660900]&-15;a[9660900]=n<<24>>24==0?r|4:r;b[4830442]=p+2&65535;b[4853736]=k;r=c[2426868]|0;C=c[2437644]|0;A=c[C+72+((r>>>8&255|256)<<2)>>2]|0;if((A|0)!=0){a[A+(r&255)|0]=n;break L43129}A=c[C+3148>>2]|0;if((A|0)==0){break L43129}gg[A&4095](r&65535,n);break};case 136:{n=c[2415221]|0;r=c[2437644]|0;A=c[r+72+((n>>>8&255|512)<<2)>>2]|0;do{if((A|0)==0){C=c[r+3156>>2]|0;if((C|0)==0){bL=0;bM=n&65535;break}H=gj[C&4095](n&65535)|0;bL=H;bM=b[4830442]|0}else{bL=a[A+(n&255)|0]|0;bM=n&65535}}while(0);b[4830442]=bM+1&65535;n=a[9660897]|0;A=n^bL;a[9660897]=A;r=(A&255)>>>4&8|a[9660900]&-15;a[9660900]=n<<24>>24==bL<<24>>24?r|4:r;break};case 137:{r=c[2415221]|0;n=c[2437644]|0;A=c[n+72+((r>>>8&255|512)<<2)>>2]|0;do{if((A|0)==0){H=c[n+3156>>2]|0;if((H|0)==0){bN=0;bO=r&65535;break}C=gj[H&4095](r&65535)|0;bN=C;bO=b[4830442]|0}else{bN=a[A+(r&255)|0]|0;bO=r&65535}}while(0);b[4830442]=bO+1&65535;r=a[9660897]|0;A=a[9660900]|0;n=(r&255)+(bN&255)+(A&1)|0;C=n^(r^bN)&255;a[9660900]=(C<<1&32|n>>>8&1|(C^n>>>1)>>>6&2|((n&255)<<24>>24==0?(n>>>4&8|A&-48&255)&255|4:(n>>>4&8|A&-48&255)&255)&255)&255;a[9660897]=n&255;break};case 138:{n=c[2415221]|0;A=c[2437644]|0;C=c[A+72+((n>>>8&255|512)<<2)>>2]|0;do{if((C|0)==0){r=c[A+3156>>2]|0;if((r|0)==0){bP=0;bQ=n&65535;break}H=gj[r&4095](n&65535)|0;bP=H;bQ=b[4830442]|0}else{bP=a[C+(n&255)|0]|0;bQ=n&65535}}while(0);b[4830442]=bQ+1&65535;n=a[9660897]|bP;a[9660897]=n;C=(n&255)>>>4&8|a[9660900]&-15;a[9660900]=n<<24>>24==0?C|4:C;break};case 139:{C=c[2415221]|0;n=c[2437644]|0;A=c[n+72+((C>>>8&255|512)<<2)>>2]|0;do{if((A|0)==0){H=c[n+3156>>2]|0;if((H|0)==0){bR=0;bS=C&65535;break}r=gj[H&4095](C&65535)|0;bR=r;bS=b[4830442]|0}else{bR=a[A+(C&255)|0]|0;bS=C&65535}}while(0);b[4830442]=bS+1&65535;C=a[9660897]|0;A=(C&255)+(bR&255)|0;n=(A>>>4&8|a[9660900]&-48&255)&255;r=(C^bR)&255^A;a[9660900]=(r<<1&32|A>>>8&1|(r^A>>>1)>>>6&2|((A&255)<<24>>24==0?n|4:n)&255)&255;a[9660897]=A&255;break};case 140:{A=c[2415221]|0;n=c[2437644]|0;r=c[n+72+((A>>>8&255|512)<<2)>>2]|0;do{if((r|0)==0){C=c[n+3156>>2]|0;if((C|0)==0){bT=0;bU=A;bV=n;bW=A&65535;break}H=gj[C&4095](A&65535)|0;C=c[2415221]|0;bT=H;bU=C;bV=c[2437644]|0;bW=C&65535}else{bT=a[r+(A&255)|0]|0;bU=A;bV=n;bW=A&65535}}while(0);A=(bT&255)<<8;n=bU+1|0;r=c[bV+72+((n>>>8&255|512)<<2)>>2]|0;do{if((r|0)==0){C=c[bV+3156>>2]|0;if((C|0)==0){bX=0;bY=bW;break}H=gj[C&4095](n&65535)|0;bX=H;bY=b[4830442]|0}else{bX=a[r+(n&255)|0]|0;bY=bW}}while(0);b[4830442]=bY+2&65535;n=e[4830446]|0;r=n-(bX&255|A)|0;H=(r>>>12&8|a[9660900]&-16&255)&255;a[9660900]=((n^A^r^r>>>1)>>>14&2|r>>>16&1|((r&65535)<<16>>16==0?H|4:H)&255)&255;break};default:{l=1}}}if(l){l=0;switch(q|0){case 141:{H=c[2415221]|0;r=c[2437644]|0;n=c[r+72+((H>>>8&255|512)<<2)>>2]|0;do{if((n|0)==0){C=c[r+3156>>2]|0;if((C|0)==0){bZ=0;b_=H&65535;b$=r;break}z=gj[C&4095](H&65535)|0;bZ=z;b_=b[4830442]|0;b$=c[2437644]|0}else{bZ=a[n+(H&255)|0]|0;b_=H&65535;b$=r}}while(0);r=b_+1&65535;b[4830442]=r;H=c[2415222]|0;n=c[b$+72+((H>>>8&255|256)<<2)>>2]|0;do{if((n|0)==0){A=c[b$+3148>>2]|0;if((A|0)==0){b0=b$;break}gg[A&4095](H&65535,r&255);b0=c[2437644]|0}else{a[n+(H&255)|0]=r&255;b0=b$}}while(0);b[4830444]=(b[4830444]|0)-1&65535;r=c[2415222]|0;H=a[9660885]|0;n=c[b0+72+((r>>>8&255|256)<<2)>>2]|0;do{if((n|0)==0){A=c[b0+3148>>2]|0;if((A|0)==0){break}gg[A&4095](r&65535,H)}else{a[n+(r&255)|0]=H}}while(0);b[4830444]=(b[4830444]|0)-1&65535;H=bZ&255;b[4830442]=(e[4830442]|0)+((H&128|0)!=0?H|65280:H)&65535;b[4830442]=c[2415221]&65535;break};case 142:{H=c[2415221]|0;r=c[2437644]|0;n=c[r+72+((H>>>8&255|512)<<2)>>2]|0;do{if((n|0)==0){A=c[r+3156>>2]|0;if((A|0)==0){b1=0;b2=H;b3=r;b4=H&65535;break}z=gj[A&4095](H&65535)|0;A=c[2415221]|0;b1=z;b2=A;b3=c[2437644]|0;b4=A&65535}else{b1=a[n+(H&255)|0]|0;b2=H;b3=r;b4=H&65535}}while(0);H=b1&255;r=b2+1|0;n=c[b3+72+((r>>>8&255|512)<<2)>>2]|0;do{if((n|0)==0){A=c[b3+3156>>2]|0;if((A|0)==0){b5=0;b6=b4;break}z=gj[A&4095](r&65535)|0;b5=z;b6=b[4830442]|0}else{b5=a[n+(r&255)|0]|0;b6=b4}}while(0);r=b5&255|H<<8;c[2415222]=r;b[4830442]=b6+2&65535;n=a[9660900]&-15;a[9660900]=n;if((r|0)==0){b7=(n&255|H>>>4&8|4)&255}else{b7=(n&255|H>>>4&8)&255}a[9660900]=b7;break};case 143:{n=b[4830444]|0;r=(n&65535)>>>12&8|a[9660900]&-15&255;a[9660900]=(n<<16>>16==0?r|4:r)&255;b[4853736]=k;b[4830442]=p+3&65535;r=c[2426868]|0;n=a[9660889]|0;z=c[2437644]|0;A=c[z+72+((r>>>8&255|256)<<2)>>2]|0;do{if((A|0)==0){C=c[z+3148>>2]|0;if((C|0)==0){b8=z;break}gg[C&4095](r&65535,n);b8=c[2437644]|0}else{a[A+(r&255)|0]=n;b8=z}}while(0);z=a[9660888]|0;n=c[b8+72+(((r+1|0)>>>8&255|256)<<2)>>2]|0;if((n|0)!=0){a[n+((r+1|0)&255)|0]=z;break L43129}n=c[b8+3148>>2]|0;if((n|0)==0){break L43129}gg[n&4095]((r+1|0)&65535,z);break};case 144:{z=c[2415221]|0;n=c[2437644]|0;A=c[n+72+((z>>>8&255|512)<<2)>>2]|0;do{if((A|0)==0){H=c[n+3156>>2]|0;if((H|0)==0){b9=0;ca=z&65535;cb=n;break}C=gj[H&4095](z&65535)|0;b9=C;ca=b[4830442]|0;cb=c[2437644]|0}else{b9=a[A+(z&255)|0]|0;ca=z&65535;cb=n}}while(0);n=b9&255;c[2426868]=n;b[4830442]=ca+1&65535;z=b9&255;A=c[cb+72>>2]|0;do{if((A|0)==0){r=c[cb+3144>>2]|0;if((r|0)==0){cc=0;break}cc=gj[r&4095](z)|0}else{cc=a[A+n|0]|0}}while(0);n=a[9660897]|0;A=(n&255)-(cc&255)|0;z=(A>>>4&8|a[9660900]&-16&255)&255;a[9660900]=(((n^cc)&255^A^A>>>1)>>>6&2|A>>>8&1|((A&255)<<24>>24==0?z|4:z)&255)&255;a[9660897]=A&255;break};case 145:{A=c[2415221]|0;z=c[2437644]|0;n=c[z+72+((A>>>8&255|512)<<2)>>2]|0;do{if((n|0)==0){r=c[z+3156>>2]|0;if((r|0)==0){cd=0;ce=A&65535;cf=z;break}C=gj[r&4095](A&65535)|0;cd=C;ce=b[4830442]|0;cf=c[2437644]|0}else{cd=a[n+(A&255)|0]|0;ce=A&65535;cf=z}}while(0);z=cd&255;c[2426868]=z;b[4830442]=ce+1&65535;A=cd&255;n=c[cf+72>>2]|0;do{if((n|0)==0){C=c[cf+3144>>2]|0;if((C|0)==0){cg=0;break}cg=gj[C&4095](A)|0}else{cg=a[n+z|0]|0}}while(0);z=a[9660897]|0;n=(z&255)-(cg&255)|0;A=(n>>>4&8|a[9660900]&-16&255)&255;a[9660900]=(((z^cg)&255^n^n>>>1)>>>6&2|n>>>8&1|((n&255)<<24>>24==0?A|4:A)&255)&255;break};case 146:{A=c[2415221]|0;n=c[2437644]|0;z=c[n+72+((A>>>8&255|512)<<2)>>2]|0;do{if((z|0)==0){C=c[n+3156>>2]|0;if((C|0)==0){ch=0;ci=A&65535;cj=n;break}r=gj[C&4095](A&65535)|0;ch=r;ci=b[4830442]|0;cj=c[2437644]|0}else{ch=a[z+(A&255)|0]|0;ci=A&65535;cj=n}}while(0);n=ch&255;c[2426868]=n;b[4830442]=ci+1&65535;A=ch&255;z=c[cj+72>>2]|0;do{if((z|0)==0){r=c[cj+3144>>2]|0;if((r|0)==0){ck=0;break}ck=gj[r&4095](A)|0}else{ck=a[z+n|0]|0}}while(0);n=a[9660897]|0;z=a[9660900]|0;A=(n&255)-(ck&255)-(z&1)|0;a[9660900]=((A^(n^ck)&255^A>>>1)>>>6&2|A>>>8&1|((A&255)<<24>>24==0?(A>>>4&8|z&-16&255)&255|4:(A>>>4&8|z&-16&255)&255)&255)&255;a[9660897]=A&255;break};case 147:{A=c[2415221]|0;z=c[2437644]|0;n=c[z+72+((A>>>8&255|512)<<2)>>2]|0;do{if((n|0)==0){r=c[z+3156>>2]|0;if((r|0)==0){cl=0;cm=A&65535;cn=z;break}C=gj[r&4095](A&65535)|0;cl=C;cm=b[4830442]|0;cn=c[2437644]|0}else{cl=a[n+(A&255)|0]|0;cm=A&65535;cn=z}}while(0);z=cl&255;c[2426868]=z;b[4830442]=cm+1&65535;A=cl&255;n=c[cn+72>>2]|0;do{if((n|0)==0){C=c[cn+3144>>2]|0;if((C|0)==0){co=0;cp=cn;break}r=gj[C&4095](A)|0;co=r;cp=c[2437644]|0}else{co=a[n+z|0]|0;cp=cn}}while(0);n=(co&255)<<8;A=c[cp+72+(((z+1|0)>>>8&255)<<2)>>2]|0;do{if((A|0)==0){r=c[cp+3144>>2]|0;if((r|0)==0){cq=0;break}cq=gj[r&4095]((z+1|0)&65535)|0}else{cq=a[A+((z+1|0)&255)|0]|0}}while(0);z=e[4830448]|0;A=z-(cq&255|n)|0;r=(A>>>12&8|a[9660900]&-16&255)&255;a[9660900]=((z^n^A^A>>>1)>>>14&2|A>>>16&1|((A&65535)<<16>>16==0?r|4:r)&255)&255;b[4830448]=A&65535;break};case 148:{A=c[2415221]|0;r=c[2437644]|0;z=c[r+72+((A>>>8&255|512)<<2)>>2]|0;do{if((z|0)==0){C=c[r+3156>>2]|0;if((C|0)==0){cr=0;cs=A&65535;ct=r;break}H=gj[C&4095](A&65535)|0;cr=H;cs=b[4830442]|0;ct=c[2437644]|0}else{cr=a[z+(A&255)|0]|0;cs=A&65535;ct=r}}while(0);r=cr&255;c[2426868]=r;b[4830442]=cs+1&65535;A=cr&255;z=c[ct+72>>2]|0;do{if((z|0)==0){n=c[ct+3144>>2]|0;if((n|0)==0){cu=0;break}cu=gj[n&4095](A)|0}else{cu=a[z+r|0]|0}}while(0);r=a[9660897]&cu;a[9660897]=r;z=(r&255)>>>4&8|a[9660900]&-15;a[9660900]=r<<24>>24==0?z|4:z;break};case 149:{z=c[2415221]|0;r=c[2437644]|0;A=c[r+72+((z>>>8&255|512)<<2)>>2]|0;do{if((A|0)==0){n=c[r+3156>>2]|0;if((n|0)==0){cv=0;cw=z&65535;cx=r;break}H=gj[n&4095](z&65535)|0;cv=H;cw=b[4830442]|0;cx=c[2437644]|0}else{cv=a[A+(z&255)|0]|0;cw=z&65535;cx=r}}while(0);r=cv&255;c[2426868]=r;b[4830442]=cw+1&65535;z=cv&255;A=c[cx+72>>2]|0;do{if((A|0)==0){H=c[cx+3144>>2]|0;if((H|0)==0){cy=0;break}cy=gj[H&4095](z)|0}else{cy=a[A+r|0]|0}}while(0);r=a[9660897]&cy;A=(r&255)>>>4&8|a[9660900]&-15;a[9660900]=r<<24>>24==0?A|4:A;break};case 150:{A=c[2415221]|0;r=c[2437644]|0;z=c[r+72+((A>>>8&255|512)<<2)>>2]|0;do{if((z|0)==0){H=c[r+3156>>2]|0;if((H|0)==0){cz=0;cA=A&65535;cB=r;break}n=gj[H&4095](A&65535)|0;cz=n;cA=b[4830442]|0;cB=c[2437644]|0}else{cz=a[z+(A&255)|0]|0;cA=A&65535;cB=r}}while(0);r=cz&255;c[2426868]=r;b[4830442]=cA+1&65535;A=cz&255;z=c[cB+72>>2]|0;do{if((z|0)==0){n=c[cB+3144>>2]|0;if((n|0)==0){cC=0;break}cC=gj[n&4095](A)|0}else{cC=a[z+r|0]|0}}while(0);a[9660897]=cC;r=(cC&255)>>>4&8|a[9660900]&-15;a[9660900]=cC<<24>>24==0?r|4:r;break};case 151:{r=a[9660897]|0;z=(r&255)>>>4&8|a[9660900]&-15;a[9660900]=r<<24>>24==0?z|4:z;z=c[2415221]|0;A=c[2437644]|0;n=c[A+72+((z>>>8&255|512)<<2)>>2]|0;do{if((n|0)==0){H=c[A+3156>>2]|0;if((H|0)==0){cD=0;cE=z&65535;cF=r;cG=A;break}C=gj[H&4095](z&65535)|0;cD=C;cE=b[4830442]|0;cF=a[9660897]|0;cG=c[2437644]|0}else{cD=a[n+(z&255)|0]|0;cE=z&65535;cF=r;cG=A}}while(0);A=cD&255;c[2426868]=A;b[4830442]=cE+1&65535;r=c[cG+1096>>2]|0;if((r|0)!=0){a[r+A|0]=cF;break L43129}A=c[cG+3148>>2]|0;if((A|0)==0){break L43129}gg[A&4095](cD&255,cF);break};case 152:{A=c[2415221]|0;r=c[2437644]|0;z=c[r+72+((A>>>8&255|512)<<2)>>2]|0;do{if((z|0)==0){n=c[r+3156>>2]|0;if((n|0)==0){cH=0;cI=A&65535;cJ=r;break}C=gj[n&4095](A&65535)|0;cH=C;cI=b[4830442]|0;cJ=c[2437644]|0}else{cH=a[z+(A&255)|0]|0;cI=A&65535;cJ=r}}while(0);r=cH&255;c[2426868]=r;b[4830442]=cI+1&65535;A=cH&255;z=c[cJ+72>>2]|0;do{if((z|0)==0){C=c[cJ+3144>>2]|0;if((C|0)==0){cK=0;break}cK=gj[C&4095](A)|0}else{cK=a[z+r|0]|0}}while(0);r=a[9660897]|0;z=r^cK;a[9660897]=z;A=(z&255)>>>4&8|a[9660900]&-15;a[9660900]=r<<24>>24==cK<<24>>24?A|4:A;break};case 153:{A=c[2415221]|0;r=c[2437644]|0;z=c[r+72+((A>>>8&255|512)<<2)>>2]|0;do{if((z|0)==0){C=c[r+3156>>2]|0;if((C|0)==0){cL=0;cM=A&65535;cN=r;break}n=gj[C&4095](A&65535)|0;cL=n;cM=b[4830442]|0;cN=c[2437644]|0}else{cL=a[z+(A&255)|0]|0;cM=A&65535;cN=r}}while(0);r=cL&255;c[2426868]=r;b[4830442]=cM+1&65535;A=cL&255;z=c[cN+72>>2]|0;do{if((z|0)==0){n=c[cN+3144>>2]|0;if((n|0)==0){cO=0;break}cO=gj[n&4095](A)|0}else{cO=a[z+r|0]|0}}while(0);r=a[9660897]|0;z=a[9660900]|0;A=(r&255)+(cO&255)+(z&1)|0;n=A^(r^cO)&255;a[9660900]=(n<<1&32|A>>>8&1|(n^A>>>1)>>>6&2|((A&255)<<24>>24==0?(A>>>4&8|z&-48&255)&255|4:(A>>>4&8|z&-48&255)&255)&255)&255;a[9660897]=A&255;break};case 154:{A=c[2415221]|0;z=c[2437644]|0;n=c[z+72+((A>>>8&255|512)<<2)>>2]|0;do{if((n|0)==0){r=c[z+3156>>2]|0;if((r|0)==0){cP=0;cQ=A&65535;cR=z;break}C=gj[r&4095](A&65535)|0;cP=C;cQ=b[4830442]|0;cR=c[2437644]|0}else{cP=a[n+(A&255)|0]|0;cQ=A&65535;cR=z}}while(0);z=cP&255;c[2426868]=z;b[4830442]=cQ+1&65535;A=cP&255;n=c[cR+72>>2]|0;do{if((n|0)==0){C=c[cR+3144>>2]|0;if((C|0)==0){cS=0;break}cS=gj[C&4095](A)|0}else{cS=a[n+z|0]|0}}while(0);z=a[9660897]|cS;a[9660897]=z;n=(z&255)>>>4&8|a[9660900]&-15;a[9660900]=z<<24>>24==0?n|4:n;break};case 155:{n=c[2415221]|0;z=c[2437644]|0;A=c[z+72+((n>>>8&255|512)<<2)>>2]|0;do{if((A|0)==0){C=c[z+3156>>2]|0;if((C|0)==0){cT=0;cU=n&65535;cV=z;break}r=gj[C&4095](n&65535)|0;cT=r;cU=b[4830442]|0;cV=c[2437644]|0}else{cT=a[A+(n&255)|0]|0;cU=n&65535;cV=z}}while(0);z=cT&255;c[2426868]=z;b[4830442]=cU+1&65535;n=cT&255;A=c[cV+72>>2]|0;do{if((A|0)==0){r=c[cV+3144>>2]|0;if((r|0)==0){cW=0;break}cW=gj[r&4095](n)|0}else{cW=a[A+z|0]|0}}while(0);z=a[9660897]|0;A=(z&255)+(cW&255)|0;n=(A>>>4&8|a[9660900]&-48&255)&255;r=(z^cW)&255^A;a[9660900]=(r<<1&32|A>>>8&1|(r^A>>>1)>>>6&2|((A&255)<<24>>24==0?n|4:n)&255)&255;a[9660897]=A&255;break};case 156:{A=c[2415221]|0;n=c[2437644]|0;r=c[n+72+((A>>>8&255|512)<<2)>>2]|0;do{if((r|0)==0){z=c[n+3156>>2]|0;if((z|0)==0){cX=0;cY=A&65535;cZ=n;break}C=gj[z&4095](A&65535)|0;cX=C;cY=b[4830442]|0;cZ=c[2437644]|0}else{cX=a[r+(A&255)|0]|0;cY=A&65535;cZ=n}}while(0);n=cX&255;c[2426868]=n;b[4830442]=cY+1&65535;A=cX&255;r=c[cZ+72>>2]|0;do{if((r|0)==0){C=c[cZ+3144>>2]|0;if((C|0)==0){c_=0;c$=cZ;break}z=gj[C&4095](A)|0;c_=z;c$=c[2437644]|0}else{c_=a[r+n|0]|0;c$=cZ}}while(0);r=(c_&255)<<8;A=c[c$+72+(((n+1|0)>>>8&255)<<2)>>2]|0;do{if((A|0)==0){z=c[c$+3144>>2]|0;if((z|0)==0){c0=0;break}c0=gj[z&4095]((n+1|0)&65535)|0}else{c0=a[A+((n+1|0)&255)|0]|0}}while(0);n=e[4830446]|0;A=n-(c0&255|r)|0;z=(A>>>12&8|a[9660900]&-16&255)&255;a[9660900]=((n^r^A^A>>>1)>>>14&2|A>>>16&1|((A&65535)<<16>>16==0?z|4:z)&255)&255;break};case 157:{z=c[2415221]|0;A=c[2437644]|0;n=c[A+72+((z>>>8&255|512)<<2)>>2]|0;do{if((n|0)==0){C=c[A+3156>>2]|0;if((C|0)==0){c1=0;c2=z&65535;c3=A;break}H=gj[C&4095](z&65535)|0;c1=H;c2=b[4830442]|0;c3=c[2437644]|0}else{c1=a[n+(z&255)|0]|0;c2=z&65535;c3=A}}while(0);c[2426868]=c1&255;A=c2+1&65535;b[4830442]=A;z=c[2415222]|0;n=c[c3+72+((z>>>8&255|256)<<2)>>2]|0;do{if((n|0)==0){r=c[c3+3148>>2]|0;if((r|0)==0){c4=c3;break}gg[r&4095](z&65535,A&255);c4=c[2437644]|0}else{a[n+(z&255)|0]=A&255;c4=c3}}while(0);b[4830444]=(b[4830444]|0)-1&65535;A=c[2415222]|0;z=a[9660885]|0;n=c[c4+72+((A>>>8&255|256)<<2)>>2]|0;do{if((n|0)==0){r=c[c4+3148>>2]|0;if((r|0)==0){break}gg[r&4095](A&65535,z)}else{a[n+(A&255)|0]=z}}while(0);b[4830444]=(b[4830444]|0)-1&65535;b[4830442]=b[4853736]|0;b[4830442]=c[2415221]&65535;break};case 29:{f00(-18);break};case 30:{f00(-18);break};case 31:{f00(-18);break};case 32:{z=c[2415221]|0;A=c[2437644]|0;n=c[A+72+((z>>>8&255|512)<<2)>>2]|0;do{if((n|0)==0){r=c[A+3156>>2]|0;if((r|0)==0){c5=0;c6=z&65535;break}H=gj[r&4095](z&65535)|0;c5=H;c6=b[4830442]|0}else{c5=a[n+(z&255)|0]|0;c6=z&65535}}while(0);z=c5&255;b[4830442]=((z&128|0)!=0?z|65280:z)+(c6+1&65535)&65535;b[4830442]=c[2415221]&65535;if(c5<<24>>24!=-2){break L43129}z=c[3528192]|0;n=c[2415234]|0;A=c[2440594]|0;H=(z-n|0|0)>(A|0)?A:z-n|0;if((H|0)<=0){break L43129}c[2440594]=A-H;c[2415234]=H+n|0;if((H+n|0)>>>0<z>>>0){break L43129}f03();break};case 33:{z=c[2415221]|0;n=c[2437644]|0;do{if((c[n+72+((z>>>8&255|512)<<2)>>2]|0)==0){H=c[n+3156>>2]|0;if((H|0)==0){c7=z&65535;break}gj[H&4095](z&65535)|0;c7=b[4830442]|0}else{c7=z&65535}}while(0);b[4830442]=c7+1&65535;break};case 34:{z=c[2415221]|0;n=c[2437644]|0;H=c[n+72+((z>>>8&255|512)<<2)>>2]|0;do{if((H|0)==0){A=c[n+3156>>2]|0;if((A|0)==0){c8=0;c9=z&65535;break}r=gj[A&4095](z&65535)|0;c8=r;c9=b[4830442]|0}else{c8=a[H+(z&255)|0]|0;c9=z&65535}}while(0);z=c9+1&65535;b[4830442]=z;if((a[9660900]&5)!=0){break L43129}H=c8&255;b[4830442]=((H&128|0)!=0?H|65280:H)+(z&65535)&65535;b[4830442]=c[2415221]&65535;break};case 35:{z=c[2415221]|0;H=c[2437644]|0;n=c[H+72+((z>>>8&255|512)<<2)>>2]|0;do{if((n|0)==0){r=c[H+3156>>2]|0;if((r|0)==0){da=0;db=z&65535;break}A=gj[r&4095](z&65535)|0;da=A;db=b[4830442]|0}else{da=a[n+(z&255)|0]|0;db=z&65535}}while(0);z=db+1&65535;b[4830442]=z;if((a[9660900]&5)==0){break L43129}n=da&255;b[4830442]=((n&128|0)!=0?n|65280:n)+(z&65535)&65535;b[4830442]=c[2415221]&65535;break};case 36:{z=c[2415221]|0;n=c[2437644]|0;H=c[n+72+((z>>>8&255|512)<<2)>>2]|0;do{if((H|0)==0){A=c[n+3156>>2]|0;if((A|0)==0){dc=0;dd=z&65535;break}r=gj[A&4095](z&65535)|0;dc=r;dd=b[4830442]|0}else{dc=a[H+(z&255)|0]|0;dd=z&65535}}while(0);z=dd+1&65535;b[4830442]=z;if((a[9660900]&1)!=0){break L43129}H=dc&255;b[4830442]=((H&128|0)!=0?H|65280:H)+(z&65535)&65535;b[4830442]=c[2415221]&65535;break};case 37:{z=c[2415221]|0;H=c[2437644]|0;n=c[H+72+((z>>>8&255|512)<<2)>>2]|0;do{if((n|0)==0){r=c[H+3156>>2]|0;if((r|0)==0){de=0;df=z&65535;break}A=gj[r&4095](z&65535)|0;de=A;df=b[4830442]|0}else{de=a[n+(z&255)|0]|0;df=z&65535}}while(0);z=df+1&65535;b[4830442]=z;if((a[9660900]&1)==0){break L43129}n=de&255;b[4830442]=((n&128|0)!=0?n|65280:n)+(z&65535)&65535;b[4830442]=c[2415221]&65535;break};case 38:{z=c[2415221]|0;n=c[2437644]|0;H=c[n+72+((z>>>8&255|512)<<2)>>2]|0;do{if((H|0)==0){A=c[n+3156>>2]|0;if((A|0)==0){dg=0;dh=z&65535;break}r=gj[A&4095](z&65535)|0;dg=r;dh=b[4830442]|0}else{dg=a[H+(z&255)|0]|0;dh=z&65535}}while(0);z=dh+1&65535;b[4830442]=z;if((a[9660900]&4)!=0){break L43129}H=dg&255;b[4830442]=((H&128|0)!=0?H|65280:H)+(z&65535)&65535;b[4830442]=c[2415221]&65535;break};case 39:{z=c[2415221]|0;H=c[2437644]|0;n=c[H+72+((z>>>8&255|512)<<2)>>2]|0;do{if((n|0)==0){r=c[H+3156>>2]|0;if((r|0)==0){di=0;dj=z&65535;break}A=gj[r&4095](z&65535)|0;di=A;dj=b[4830442]|0}else{di=a[n+(z&255)|0]|0;dj=z&65535}}while(0);z=dj+1&65535;b[4830442]=z;if((a[9660900]&4)==0){break L43129}n=di&255;b[4830442]=((n&128|0)!=0?n|65280:n)+(z&65535)&65535;b[4830442]=c[2415221]&65535;break};case 40:{z=c[2415221]|0;n=c[2437644]|0;H=c[n+72+((z>>>8&255|512)<<2)>>2]|0;do{if((H|0)==0){A=c[n+3156>>2]|0;if((A|0)==0){dk=0;dl=z&65535;break}r=gj[A&4095](z&65535)|0;dk=r;dl=b[4830442]|0}else{dk=a[H+(z&255)|0]|0;dl=z&65535}}while(0);z=dl+1&65535;b[4830442]=z;if((a[9660900]&2)!=0){break L43129}H=dk&255;b[4830442]=((H&128|0)!=0?H|65280:H)+(z&65535)&65535;b[4830442]=c[2415221]&65535;break};case 41:{z=c[2415221]|0;H=c[2437644]|0;n=c[H+72+((z>>>8&255|512)<<2)>>2]|0;do{if((n|0)==0){r=c[H+3156>>2]|0;if((r|0)==0){dm=0;dn=z&65535;break}A=gj[r&4095](z&65535)|0;dm=A;dn=b[4830442]|0}else{dm=a[n+(z&255)|0]|0;dn=z&65535}}while(0);z=dn+1&65535;b[4830442]=z;if((a[9660900]&2)==0){break L43129}n=dm&255;b[4830442]=((n&128|0)!=0?n|65280:n)+(z&65535)&65535;b[4830442]=c[2415221]&65535;break};case 42:{z=c[2415221]|0;n=c[2437644]|0;H=c[n+72+((z>>>8&255|512)<<2)>>2]|0;do{if((H|0)==0){A=c[n+3156>>2]|0;if((A|0)==0){dp=0;dq=z&65535;break}r=gj[A&4095](z&65535)|0;dp=r;dq=b[4830442]|0}else{dp=a[H+(z&255)|0]|0;dq=z&65535}}while(0);z=dq+1&65535;b[4830442]=z;if((a[9660900]&8)!=0){break L43129}H=dp&255;b[4830442]=((H&128|0)!=0?H|65280:H)+(z&65535)&65535;b[4830442]=c[2415221]&65535;break};case 43:{z=c[2415221]|0;H=c[2437644]|0;n=c[H+72+((z>>>8&255|512)<<2)>>2]|0;do{if((n|0)==0){r=c[H+3156>>2]|0;if((r|0)==0){dr=0;ds=z&65535;break}A=gj[r&4095](z&65535)|0;dr=A;ds=b[4830442]|0}else{dr=a[n+(z&255)|0]|0;ds=z&65535}}while(0);z=ds+1&65535;b[4830442]=z;if((a[9660900]&8)==0){break L43129}n=dr&255;b[4830442]=((n&128|0)!=0?n|65280:n)+(z&65535)&65535;b[4830442]=c[2415221]&65535;break};case 44:{z=c[2415221]|0;n=c[2437644]|0;H=c[n+72+((z>>>8&255|512)<<2)>>2]|0;do{if((H|0)==0){A=c[n+3156>>2]|0;if((A|0)==0){dt=0;du=z&65535;break}r=gj[A&4095](z&65535)|0;dt=r;du=b[4830442]|0}else{dt=a[H+(z&255)|0]|0;du=z&65535}}while(0);z=du+1&65535;b[4830442]=z;H=d[9660900]|0;if(((H<<2^H)&8|0)!=0){break L43129}H=dt&255;b[4830442]=((H&128|0)!=0?H|65280:H)+(z&65535)&65535;b[4830442]=c[2415221]&65535;break};case 45:{z=c[2415221]|0;H=c[2437644]|0;n=c[H+72+((z>>>8&255|512)<<2)>>2]|0;do{if((n|0)==0){r=c[H+3156>>2]|0;if((r|0)==0){dv=0;dw=z&65535;break}A=gj[r&4095](z&65535)|0;dv=A;dw=b[4830442]|0}else{dv=a[n+(z&255)|0]|0;dw=z&65535}}while(0);z=dw+1&65535;b[4830442]=z;n=d[9660900]|0;if(((n<<2^n)&8|0)==0){break L43129}n=dv&255;b[4830442]=((n&128|0)!=0?n|65280:n)+(z&65535)&65535;b[4830442]=c[2415221]&65535;break};case 46:{z=c[2415221]|0;n=c[2437644]|0;H=c[n+72+((z>>>8&255|512)<<2)>>2]|0;do{if((H|0)==0){A=c[n+3156>>2]|0;if((A|0)==0){dx=0;dy=z&65535;break}r=gj[A&4095](z&65535)|0;dx=r;dy=b[4830442]|0}else{dx=a[H+(z&255)|0]|0;dy=z&65535}}while(0);z=dy+1&65535;b[4830442]=z;H=d[9660900]|0;if(((H<<2^H)&8|H&4|0)!=0){break L43129}H=dx&255;b[4830442]=((H&128|0)!=0?H|65280:H)+(z&65535)&65535;b[4830442]=c[2415221]&65535;break};case 47:{z=c[2415221]|0;H=c[2437644]|0;n=c[H+72+((z>>>8&255|512)<<2)>>2]|0;do{if((n|0)==0){r=c[H+3156>>2]|0;if((r|0)==0){dz=0;dA=z&65535;break}A=gj[r&4095](z&65535)|0;dz=A;dA=b[4830442]|0}else{dz=a[n+(z&255)|0]|0;dA=z&65535}}while(0);z=dA+1&65535;b[4830442]=z;n=d[9660900]|0;if(((n<<2^n)&8|n&4|0)==0){break L43129}n=dz&255;b[4830442]=((n&128|0)!=0?n|65280:n)+(z&65535)&65535;b[4830442]=c[2415221]&65535;break};case 48:{b[4830446]=(b[4830444]|0)+1&65535;break};case 49:{b[4830444]=(b[4830444]|0)+1&65535;break};case 50:{b[4830444]=(b[4830444]|0)+1&65535;z=c[2415222]|0;n=c[2437644]|0;H=c[n+72+((z>>>8&255)<<2)>>2]|0;do{if((H|0)==0){A=c[n+3144>>2]|0;if((A|0)==0){dB=0;break}dB=gj[A&4095](z&65535)|0}else{dB=a[H+(z&255)|0]|0}}while(0);a[9660897]=dB;break};case 51:{b[4830444]=(b[4830444]|0)+1&65535;z=c[2415222]|0;H=c[2437644]|0;n=c[H+72+((z>>>8&255)<<2)>>2]|0;do{if((n|0)==0){A=c[H+3144>>2]|0;if((A|0)==0){dC=0;break}dC=gj[A&4095](z&65535)|0}else{dC=a[n+(z&255)|0]|0}}while(0);a[9660896]=dC;break};case 52:{b[4830444]=(b[4830444]|0)-1&65535;break};case 53:{b[4830444]=(b[4830446]|0)-1&65535;break};case 54:{z=c[2415222]|0;n=a[9660897]|0;H=c[2437644]|0;A=c[H+72+((z>>>8&255|256)<<2)>>2]|0;do{if((A|0)==0){r=c[H+3148>>2]|0;if((r|0)==0){break}gg[r&4095](z&65535,n)}else{a[A+(z&255)|0]=n}}while(0);b[4830444]=(b[4830444]|0)-1&65535;break};case 55:{n=c[2415222]|0;z=a[9660896]|0;A=c[2437644]|0;H=c[A+72+((n>>>8&255|256)<<2)>>2]|0;do{if((H|0)==0){r=c[A+3148>>2]|0;if((r|0)==0){break}gg[r&4095](n&65535,z)}else{a[H+(n&255)|0]=z}}while(0);b[4830444]=(b[4830444]|0)-1&65535;break};case 56:{b[4830444]=(b[4830444]|0)+1&65535;z=c[2415222]|0;n=c[2437644]|0;H=c[n+72+((z>>>8&255)<<2)>>2]|0;do{if((H|0)==0){A=c[n+3144>>2]|0;if((A|0)==0){dD=0;dE=z&65535;dF=n;break}r=gj[A&4095](z&65535)|0;dD=r;dE=b[4830444]|0;dF=c[2437644]|0}else{dD=a[H+(z&255)|0]|0;dE=z&65535;dF=n}}while(0);n=(dD&255)<<8;c[2415223]=n;b[4830444]=dE+1&65535;z=c[2415222]|0;H=c[dF+72+((z>>>8&255)<<2)>>2]|0;do{if((H|0)==0){r=c[dF+3144>>2]|0;if((r|0)==0){dG=0;dH=n;break}A=gj[r&4095](z&65535)|0;dG=A;dH=c[2415223]|0}else{dG=a[H+(z&255)|0]|0;dH=n}}while(0);c[2415223]=dH|dG&255;break};case 4:{n=a[9660900]&-14;a[9660900]=n;z=b[4830448]|0;if((z&65535)>>>1<<16>>16==0){dI=(z&1|n&255|4)&255}else{dI=(z&1|n&255)&255}a[9660900]=dI;b[4830448]=(z&65535)>>>1;break};default:{l=1}}}if(l){l=0;switch(q|0){case 5:{z=e[4830448]|0;n=(a[9660900]&-16&255|z>>>11&8)&255;a[9660900]=((z<<1^z)>>>14&2|z>>>15|((z<<1&65535)<<16>>16==0?n|4:n)&255)&255;b[4830448]=z<<1&65535;break};case 11:{a[9660900]=a[9660900]|2;break};case 12:{a[9660900]=a[9660900]&-2;break};case 2:{f00(-18);break};case 19:{z=(b[4830444]|0)+1&65535;n=c[2437644]|0;H=c[n+72+((z&65535)>>>8<<2)>>2]|0;do{if((H|0)==0){A=c[n+3144>>2]|0;if((A|0)==0){dJ=0;break}dJ=gj[A&4095](z)|0}else{dJ=a[H+(z&65535&255)|0]|0}}while(0);b[4830446]=(b[4830446]|0)+(dJ&255)&65535;break};case 0:{f00(-18);break};case 7:{a[9660897]=a[9660900]|0;break};case 3:{f00(-18);break};case 16:{z=a[9660897]|0;H=a[9660896]|0;n=(z&255)-(H&255)&65535&65535;A=(n>>>4&8|a[9660900]&-16&255)&255;a[9660900]=((n^(H^z)&255^n>>>1)>>>6&2|n>>>8&1|(((z&255)-(H&255)&65535&255)<<24>>24==0?A|4:A)&255)&255;a[9660897]=(z&255)-(H&255)&65535&255;break};case 17:{H=a[9660897]|0;z=a[9660896]|0;A=(H&255)-(z&255)&65535&65535;n=(A>>>4&8|a[9660900]&-16&255)&255;a[9660900]=((A^(z^H)&255^A>>>1)>>>6&2|A>>>8&1|(((H&255)-(z&255)&65535&255)<<24>>24==0?n|4:n)&255)&255;break};case 18:{n=(b[4830444]|0)+1&65535;z=c[2437644]|0;H=c[z+72+((n&65535)>>>8<<2)>>2]|0;do{if((H|0)==0){A=c[z+3144>>2]|0;if((A|0)==0){dK=0;break}dK=gj[A&4095](n)|0}else{dK=a[H+(n&65535&255)|0]|0}}while(0);b[4830446]=(b[4830446]|0)+(dK&255)&65535;break};case 20:{f00(-18);break};case 21:{f00(-18);break};case 22:{n=a[9660897]|0;a[9660896]=n;H=(n&255)>>>4&8|a[9660900]&-15;a[9660900]=n<<24>>24==0?H|4:H;break};case 23:{H=a[9660896]|0;a[9660897]=H;n=(H&255)>>>4&8|a[9660900]&-15;a[9660900]=H<<24>>24==0?n|4:n;break};case 24:{n=b[4830446]|0;b[4830446]=b[4830448]|0;b[4830448]=n;break};case 158:{n=c[2415221]|0;H=c[2437644]|0;z=c[H+72+((n>>>8&255|512)<<2)>>2]|0;do{if((z|0)==0){A=c[H+3156>>2]|0;if((A|0)==0){dL=0;dM=n&65535;dN=H;break}r=gj[A&4095](n&65535)|0;dL=r;dM=b[4830442]|0;dN=c[2437644]|0}else{dL=a[z+(n&255)|0]|0;dM=n&65535;dN=H}}while(0);H=dL&255;c[2426868]=H;b[4830442]=dM+1&65535;n=dL&255;z=c[dN+72>>2]|0;do{if((z|0)==0){r=c[dN+3144>>2]|0;if((r|0)==0){dO=0;dP=dN;break}A=gj[r&4095](n)|0;dO=A;dP=c[2437644]|0}else{dO=a[z+H|0]|0;dP=dN}}while(0);z=dO&255;n=c[dP+72+(((H+1|0)>>>8&255)<<2)>>2]|0;do{if((n|0)==0){A=c[dP+3144>>2]|0;if((A|0)==0){dQ=0;break}dQ=gj[A&4095]((H+1|0)&65535)|0}else{dQ=a[n+((H+1|0)&255)|0]|0}}while(0);H=dQ&255|z<<8;c[2415222]=H;n=a[9660900]&-15;a[9660900]=n;if((H|0)==0){dR=(n&255|z>>>4&8|4)&255}else{dR=(n&255|z>>>4&8)&255}a[9660900]=dR;break};case 159:{n=b[4830444]|0;H=(n&65535)>>>12&8|a[9660900]&-15&255;a[9660900]=(n<<16>>16==0?H|4:H)&255;H=c[2415221]|0;n=c[2437644]|0;A=c[n+72+((H>>>8&255|512)<<2)>>2]|0;do{if((A|0)==0){r=c[n+3156>>2]|0;if((r|0)==0){dS=0;dT=H&65535;dU=n;break}C=gj[r&4095](H&65535)|0;dS=C;dT=b[4830442]|0;dU=c[2437644]|0}else{dS=a[A+(H&255)|0]|0;dT=H&65535;dU=n}}while(0);n=dS&255;c[2426868]=n;b[4830442]=dT+1&65535;H=dS&255;A=a[9660889]|0;z=c[dU+1096>>2]|0;do{if((z|0)==0){C=c[dU+3148>>2]|0;if((C|0)==0){dV=dU;break}gg[C&4095](H,A);dV=c[2437644]|0}else{a[z+n|0]=A;dV=dU}}while(0);A=a[9660888]|0;z=c[dV+72+(((n+1|0)>>>8&255|256)<<2)>>2]|0;if((z|0)!=0){a[z+((n+1|0)&255)|0]=A;break L43129}z=c[dV+3148>>2]|0;if((z|0)==0){break L43129}gg[z&4095]((n+1|0)&65535,A);break};case 160:{A=b[4830446]|0;z=c[2415221]|0;H=c[2437644]|0;C=c[H+72+((z>>>8&255|512)<<2)>>2]|0;do{if((C|0)==0){r=c[H+3156>>2]|0;if((r|0)==0){dW=0;dX=z&65535;dY=H;break}dZ=gj[r&4095](z&65535)|0;dW=dZ;dX=b[4830442]|0;dY=c[2437644]|0}else{dW=a[C+(z&255)|0]|0;dX=z&65535;dY=H}}while(0);b[4853736]=(dW&255)+A&65535;b[4830442]=dX+1&65535;H=c[2426868]|0;z=c[dY+72+((H>>>8&255)<<2)>>2]|0;do{if((z|0)==0){C=c[dY+3144>>2]|0;if((C|0)==0){d_=0;break}d_=gj[C&4095](H&65535)|0}else{d_=a[z+(H&255)|0]|0}}while(0);H=a[9660897]|0;z=(H&255)-(d_&255)|0;A=(z>>>4&8|a[9660900]&-16&255)&255;a[9660900]=(((H^d_)&255^z^z>>>1)>>>6&2|z>>>8&1|((z&255)<<24>>24==0?A|4:A)&255)&255;a[9660897]=z&255;break};case 161:{z=b[4830446]|0;A=c[2415221]|0;H=c[2437644]|0;C=c[H+72+((A>>>8&255|512)<<2)>>2]|0;do{if((C|0)==0){n=c[H+3156>>2]|0;if((n|0)==0){d$=0;d0=A&65535;d1=H;break}dZ=gj[n&4095](A&65535)|0;d$=dZ;d0=b[4830442]|0;d1=c[2437644]|0}else{d$=a[C+(A&255)|0]|0;d0=A&65535;d1=H}}while(0);b[4853736]=(d$&255)+z&65535;b[4830442]=d0+1&65535;H=c[2426868]|0;A=c[d1+72+((H>>>8&255)<<2)>>2]|0;do{if((A|0)==0){C=c[d1+3144>>2]|0;if((C|0)==0){d2=0;break}d2=gj[C&4095](H&65535)|0}else{d2=a[A+(H&255)|0]|0}}while(0);H=a[9660897]|0;A=(H&255)-(d2&255)|0;z=(A>>>4&8|a[9660900]&-16&255)&255;a[9660900]=(((H^d2)&255^A^A>>>1)>>>6&2|A>>>8&1|((A&255)<<24>>24==0?z|4:z)&255)&255;break};case 162:{z=b[4830446]|0;A=c[2415221]|0;H=c[2437644]|0;C=c[H+72+((A>>>8&255|512)<<2)>>2]|0;do{if((C|0)==0){dZ=c[H+3156>>2]|0;if((dZ|0)==0){d3=0;d4=A&65535;d5=H;break}n=gj[dZ&4095](A&65535)|0;d3=n;d4=b[4830442]|0;d5=c[2437644]|0}else{d3=a[C+(A&255)|0]|0;d4=A&65535;d5=H}}while(0);b[4853736]=(d3&255)+z&65535;b[4830442]=d4+1&65535;H=c[2426868]|0;A=c[d5+72+((H>>>8&255)<<2)>>2]|0;do{if((A|0)==0){C=c[d5+3144>>2]|0;if((C|0)==0){d6=0;break}d6=gj[C&4095](H&65535)|0}else{d6=a[A+(H&255)|0]|0}}while(0);H=a[9660897]|0;A=a[9660900]|0;z=(H&255)-(d6&255)-(A&1)|0;a[9660900]=((z^(H^d6)&255^z>>>1)>>>6&2|z>>>8&1|((z&255)<<24>>24==0?(z>>>4&8|A&-16&255)&255|4:(z>>>4&8|A&-16&255)&255)&255)&255;a[9660897]=z&255;break};case 163:{z=b[4830446]|0;A=c[2415221]|0;H=c[2437644]|0;C=c[H+72+((A>>>8&255|512)<<2)>>2]|0;do{if((C|0)==0){n=c[H+3156>>2]|0;if((n|0)==0){d7=0;d8=A&65535;d9=H;break}dZ=gj[n&4095](A&65535)|0;d7=dZ;d8=b[4830442]|0;d9=c[2437644]|0}else{d7=a[C+(A&255)|0]|0;d8=A&65535;d9=H}}while(0);b[4853736]=(d7&255)+z&65535;b[4830442]=d8+1&65535;H=c[2426868]|0;A=c[d9+72+((H>>>8&255)<<2)>>2]|0;do{if((A|0)==0){C=c[d9+3144>>2]|0;if((C|0)==0){ea=0;eb=d9;break}dZ=gj[C&4095](H&65535)|0;ea=dZ;eb=c[2437644]|0}else{ea=a[A+(H&255)|0]|0;eb=d9}}while(0);A=(ea&255)<<8;z=c[eb+72+(((H+1|0)>>>8&255)<<2)>>2]|0;do{if((z|0)==0){dZ=c[eb+3144>>2]|0;if((dZ|0)==0){ec=0;break}ec=gj[dZ&4095]((H+1|0)&65535)|0}else{ec=a[z+((H+1|0)&255)|0]|0}}while(0);H=e[4830448]|0;z=H-(ec&255|A)|0;dZ=(z>>>12&8|a[9660900]&-16&255)&255;a[9660900]=((H^A^z^z>>>1)>>>14&2|z>>>16&1|((z&65535)<<16>>16==0?dZ|4:dZ)&255)&255;b[4830448]=z&65535;break};case 164:{z=b[4830446]|0;dZ=c[2415221]|0;H=c[2437644]|0;C=c[H+72+((dZ>>>8&255|512)<<2)>>2]|0;do{if((C|0)==0){n=c[H+3156>>2]|0;if((n|0)==0){ed=0;ee=dZ&65535;ef=H;break}r=gj[n&4095](dZ&65535)|0;ed=r;ee=b[4830442]|0;ef=c[2437644]|0}else{ed=a[C+(dZ&255)|0]|0;ee=dZ&65535;ef=H}}while(0);b[4853736]=(ed&255)+z&65535;b[4830442]=ee+1&65535;H=c[2426868]|0;dZ=c[ef+72+((H>>>8&255)<<2)>>2]|0;do{if((dZ|0)==0){C=c[ef+3144>>2]|0;if((C|0)==0){eg=0;break}eg=gj[C&4095](H&65535)|0}else{eg=a[dZ+(H&255)|0]|0}}while(0);H=a[9660897]&eg;a[9660897]=H;dZ=(H&255)>>>4&8|a[9660900]&-15;a[9660900]=H<<24>>24==0?dZ|4:dZ;break};case 165:{dZ=b[4830446]|0;H=c[2415221]|0;z=c[2437644]|0;C=c[z+72+((H>>>8&255|512)<<2)>>2]|0;do{if((C|0)==0){A=c[z+3156>>2]|0;if((A|0)==0){eh=0;ei=H&65535;ej=z;break}r=gj[A&4095](H&65535)|0;eh=r;ei=b[4830442]|0;ej=c[2437644]|0}else{eh=a[C+(H&255)|0]|0;ei=H&65535;ej=z}}while(0);b[4853736]=(eh&255)+dZ&65535;b[4830442]=ei+1&65535;z=c[2426868]|0;H=c[ej+72+((z>>>8&255)<<2)>>2]|0;do{if((H|0)==0){C=c[ej+3144>>2]|0;if((C|0)==0){ek=0;break}ek=gj[C&4095](z&65535)|0}else{ek=a[H+(z&255)|0]|0}}while(0);z=a[9660897]&ek;H=(z&255)>>>4&8|a[9660900]&-15;a[9660900]=z<<24>>24==0?H|4:H;break};case 166:{H=b[4830446]|0;z=c[2415221]|0;dZ=c[2437644]|0;C=c[dZ+72+((z>>>8&255|512)<<2)>>2]|0;do{if((C|0)==0){r=c[dZ+3156>>2]|0;if((r|0)==0){el=0;em=z&65535;en=dZ;break}A=gj[r&4095](z&65535)|0;el=A;em=b[4830442]|0;en=c[2437644]|0}else{el=a[C+(z&255)|0]|0;em=z&65535;en=dZ}}while(0);b[4853736]=(el&255)+H&65535;b[4830442]=em+1&65535;dZ=c[2426868]|0;z=c[en+72+((dZ>>>8&255)<<2)>>2]|0;do{if((z|0)==0){C=c[en+3144>>2]|0;if((C|0)==0){eo=0;break}eo=gj[C&4095](dZ&65535)|0}else{eo=a[z+(dZ&255)|0]|0}}while(0);a[9660897]=eo;dZ=(eo&255)>>>4&8|a[9660900]&-15;a[9660900]=eo<<24>>24==0?dZ|4:dZ;break};case 167:{dZ=a[9660897]|0;z=(dZ&255)>>>4&8|a[9660900]&-15;a[9660900]=dZ<<24>>24==0?z|4:z;z=b[4830446]|0;H=c[2415221]|0;C=c[2437644]|0;A=c[C+72+((H>>>8&255|512)<<2)>>2]|0;do{if((A|0)==0){r=c[C+3156>>2]|0;if((r|0)==0){ep=0;eq=H&65535;er=dZ;es=C;break}n=gj[r&4095](H&65535)|0;ep=n;eq=b[4830442]|0;er=a[9660897]|0;es=c[2437644]|0}else{ep=a[A+(H&255)|0]|0;eq=H&65535;er=dZ;es=C}}while(0);b[4853736]=(ep&255)+z&65535;b[4830442]=eq+1&65535;C=c[2426868]|0;dZ=c[es+72+((C>>>8&255|256)<<2)>>2]|0;if((dZ|0)!=0){a[dZ+(C&255)|0]=er;break L43129}dZ=c[es+3148>>2]|0;if((dZ|0)==0){break L43129}gg[dZ&4095](C&65535,er);break};case 168:{C=b[4830446]|0;dZ=c[2415221]|0;H=c[2437644]|0;A=c[H+72+((dZ>>>8&255|512)<<2)>>2]|0;do{if((A|0)==0){n=c[H+3156>>2]|0;if((n|0)==0){et=0;eu=dZ&65535;ev=H;break}r=gj[n&4095](dZ&65535)|0;et=r;eu=b[4830442]|0;ev=c[2437644]|0}else{et=a[A+(dZ&255)|0]|0;eu=dZ&65535;ev=H}}while(0);b[4853736]=(et&255)+C&65535;b[4830442]=eu+1&65535;H=c[2426868]|0;dZ=c[ev+72+((H>>>8&255)<<2)>>2]|0;do{if((dZ|0)==0){A=c[ev+3144>>2]|0;if((A|0)==0){ew=0;break}ew=gj[A&4095](H&65535)|0}else{ew=a[dZ+(H&255)|0]|0}}while(0);H=a[9660897]|0;dZ=H^ew;a[9660897]=dZ;C=(dZ&255)>>>4&8|a[9660900]&-15;a[9660900]=H<<24>>24==ew<<24>>24?C|4:C;break};case 169:{C=b[4830446]|0;H=c[2415221]|0;dZ=c[2437644]|0;A=c[dZ+72+((H>>>8&255|512)<<2)>>2]|0;do{if((A|0)==0){z=c[dZ+3156>>2]|0;if((z|0)==0){ex=0;ey=H&65535;ez=dZ;break}r=gj[z&4095](H&65535)|0;ex=r;ey=b[4830442]|0;ez=c[2437644]|0}else{ex=a[A+(H&255)|0]|0;ey=H&65535;ez=dZ}}while(0);b[4853736]=(ex&255)+C&65535;b[4830442]=ey+1&65535;dZ=c[2426868]|0;H=c[ez+72+((dZ>>>8&255)<<2)>>2]|0;do{if((H|0)==0){A=c[ez+3144>>2]|0;if((A|0)==0){eA=0;break}eA=gj[A&4095](dZ&65535)|0}else{eA=a[H+(dZ&255)|0]|0}}while(0);dZ=a[9660897]|0;H=a[9660900]|0;C=(dZ&255)+(eA&255)+(H&1)|0;A=C^(dZ^eA)&255;a[9660900]=(A<<1&32|C>>>8&1|(A^C>>>1)>>>6&2|((C&255)<<24>>24==0?(C>>>4&8|H&-48&255)&255|4:(C>>>4&8|H&-48&255)&255)&255)&255;a[9660897]=C&255;break};case 170:{C=b[4830446]|0;H=c[2415221]|0;A=c[2437644]|0;dZ=c[A+72+((H>>>8&255|512)<<2)>>2]|0;do{if((dZ|0)==0){r=c[A+3156>>2]|0;if((r|0)==0){eB=0;eC=H&65535;eD=A;break}z=gj[r&4095](H&65535)|0;eB=z;eC=b[4830442]|0;eD=c[2437644]|0}else{eB=a[dZ+(H&255)|0]|0;eC=H&65535;eD=A}}while(0);b[4853736]=(eB&255)+C&65535;b[4830442]=eC+1&65535;A=c[2426868]|0;H=c[eD+72+((A>>>8&255)<<2)>>2]|0;do{if((H|0)==0){dZ=c[eD+3144>>2]|0;if((dZ|0)==0){eE=0;break}eE=gj[dZ&4095](A&65535)|0}else{eE=a[H+(A&255)|0]|0}}while(0);A=a[9660897]|eE;a[9660897]=A;H=(A&255)>>>4&8|a[9660900]&-15;a[9660900]=A<<24>>24==0?H|4:H;break};case 171:{H=b[4830446]|0;A=c[2415221]|0;C=c[2437644]|0;dZ=c[C+72+((A>>>8&255|512)<<2)>>2]|0;do{if((dZ|0)==0){z=c[C+3156>>2]|0;if((z|0)==0){eF=0;eG=A&65535;eH=C;break}r=gj[z&4095](A&65535)|0;eF=r;eG=b[4830442]|0;eH=c[2437644]|0}else{eF=a[dZ+(A&255)|0]|0;eG=A&65535;eH=C}}while(0);b[4853736]=(eF&255)+H&65535;b[4830442]=eG+1&65535;C=c[2426868]|0;A=c[eH+72+((C>>>8&255)<<2)>>2]|0;do{if((A|0)==0){dZ=c[eH+3144>>2]|0;if((dZ|0)==0){eI=0;break}eI=gj[dZ&4095](C&65535)|0}else{eI=a[A+(C&255)|0]|0}}while(0);C=a[9660897]|0;A=(C&255)+(eI&255)|0;H=(A>>>4&8|a[9660900]&-48&255)&255;dZ=(C^eI)&255^A;a[9660900]=(dZ<<1&32|A>>>8&1|(dZ^A>>>1)>>>6&2|((A&255)<<24>>24==0?H|4:H)&255)&255;a[9660897]=A&255;break};case 172:{A=b[4830446]|0;H=c[2415221]|0;dZ=c[2437644]|0;C=c[dZ+72+((H>>>8&255|512)<<2)>>2]|0;do{if((C|0)==0){r=c[dZ+3156>>2]|0;if((r|0)==0){eJ=0;eK=H&65535;eL=dZ;break}z=gj[r&4095](H&65535)|0;eJ=z;eK=b[4830442]|0;eL=c[2437644]|0}else{eJ=a[C+(H&255)|0]|0;eK=H&65535;eL=dZ}}while(0);b[4853736]=(eJ&255)+A&65535;b[4830442]=eK+1&65535;dZ=c[2426868]|0;H=c[eL+72+((dZ>>>8&255)<<2)>>2]|0;do{if((H|0)==0){C=c[eL+3144>>2]|0;if((C|0)==0){eM=0;eN=eL;break}z=gj[C&4095](dZ&65535)|0;eM=z;eN=c[2437644]|0}else{eM=a[H+(dZ&255)|0]|0;eN=eL}}while(0);H=(eM&255)<<8;A=c[eN+72+(((dZ+1|0)>>>8&255)<<2)>>2]|0;do{if((A|0)==0){z=c[eN+3144>>2]|0;if((z|0)==0){eO=0;break}eO=gj[z&4095]((dZ+1|0)&65535)|0}else{eO=a[A+((dZ+1|0)&255)|0]|0}}while(0);dZ=e[4830446]|0;A=dZ-(eO&255|H)|0;z=(A>>>12&8|a[9660900]&-16&255)&255;a[9660900]=((dZ^H^A^A>>>1)>>>14&2|A>>>16&1|((A&65535)<<16>>16==0?z|4:z)&255)&255;break};case 173:{z=b[4830446]|0;A=c[2415221]|0;dZ=c[2437644]|0;C=c[dZ+72+((A>>>8&255|512)<<2)>>2]|0;do{if((C|0)==0){r=c[dZ+3156>>2]|0;if((r|0)==0){eP=0;eQ=A&65535;eR=dZ;break}n=gj[r&4095](A&65535)|0;eP=n;eQ=b[4830442]|0;eR=c[2437644]|0}else{eP=a[C+(A&255)|0]|0;eQ=A&65535;eR=dZ}}while(0);b[4853736]=(eP&255)+z&65535;dZ=eQ+1&65535;b[4830442]=dZ;A=c[2415222]|0;C=c[eR+72+((A>>>8&255|256)<<2)>>2]|0;do{if((C|0)==0){H=c[eR+3148>>2]|0;if((H|0)==0){eS=eR;break}gg[H&4095](A&65535,dZ&255);eS=c[2437644]|0}else{a[C+(A&255)|0]=dZ&255;eS=eR}}while(0);b[4830444]=(b[4830444]|0)-1&65535;dZ=c[2415222]|0;A=a[9660885]|0;C=c[eS+72+((dZ>>>8&255|256)<<2)>>2]|0;do{if((C|0)==0){z=c[eS+3148>>2]|0;if((z|0)==0){break}gg[z&4095](dZ&65535,A)}else{a[C+(dZ&255)|0]=A}}while(0);b[4830444]=(b[4830444]|0)-1&65535;b[4830442]=b[4853736]|0;b[4830442]=c[2415221]&65535;break};case 174:{A=b[4830446]|0;dZ=c[2415221]|0;C=c[2437644]|0;z=c[C+72+((dZ>>>8&255|512)<<2)>>2]|0;do{if((z|0)==0){H=c[C+3156>>2]|0;if((H|0)==0){eT=0;eU=dZ&65535;eV=C;break}n=gj[H&4095](dZ&65535)|0;eT=n;eU=b[4830442]|0;eV=c[2437644]|0}else{eT=a[z+(dZ&255)|0]|0;eU=dZ&65535;eV=C}}while(0);b[4853736]=(eT&255)+A&65535;b[4830442]=eU+1&65535;C=c[2426868]|0;dZ=c[eV+72+((C>>>8&255)<<2)>>2]|0;do{if((dZ|0)==0){z=c[eV+3144>>2]|0;if((z|0)==0){eW=0;eX=eV;break}n=gj[z&4095](C&65535)|0;eW=n;eX=c[2437644]|0}else{eW=a[dZ+(C&255)|0]|0;eX=eV}}while(0);dZ=eW&255;A=c[eX+72+(((C+1|0)>>>8&255)<<2)>>2]|0;do{if((A|0)==0){n=c[eX+3144>>2]|0;if((n|0)==0){eY=0;break}eY=gj[n&4095]((C+1|0)&65535)|0}else{eY=a[A+((C+1|0)&255)|0]|0}}while(0);C=eY&255|dZ<<8;c[2415222]=C;A=a[9660900]&-15;a[9660900]=A;if((C|0)==0){eZ=(A&255|dZ>>>4&8|4)&255}else{eZ=(A&255|dZ>>>4&8)&255}a[9660900]=eZ;break};case 175:{A=b[4830444]|0;C=(A&65535)>>>12&8|a[9660900]&-15&255;a[9660900]=(A<<16>>16==0?C|4:C)&255;C=b[4830446]|0;A=c[2415221]|0;n=c[2437644]|0;z=c[n+72+((A>>>8&255|512)<<2)>>2]|0;do{if((z|0)==0){H=c[n+3156>>2]|0;if((H|0)==0){e_=0;e$=A&65535;e0=n;break}r=gj[H&4095](A&65535)|0;e_=r;e$=b[4830442]|0;e0=c[2437644]|0}else{e_=a[z+(A&255)|0]|0;e$=A&65535;e0=n}}while(0);b[4853736]=(e_&255)+C&65535;b[4830442]=e$+1&65535;n=c[2426868]|0;A=a[9660889]|0;z=c[e0+72+((n>>>8&255|256)<<2)>>2]|0;do{if((z|0)==0){dZ=c[e0+3148>>2]|0;if((dZ|0)==0){e1=e0;break}gg[dZ&4095](n&65535,A);e1=c[2437644]|0}else{a[z+(n&255)|0]=A;e1=e0}}while(0);A=a[9660888]|0;z=c[e1+72+(((n+1|0)>>>8&255|256)<<2)>>2]|0;if((z|0)!=0){a[z+((n+1|0)&255)|0]=A;break L43129}z=c[e1+3148>>2]|0;if((z|0)==0){break L43129}gg[z&4095]((n+1|0)&65535,A);break};case 176:{A=c[2415221]|0;z=c[2437644]|0;C=c[z+72+((A>>>8&255|512)<<2)>>2]|0;do{if((C|0)==0){dZ=c[z+3156>>2]|0;if((dZ|0)==0){e2=0;e3=A;e4=z;e5=A&65535;break}r=gj[dZ&4095](A&65535)|0;dZ=c[2415221]|0;e2=r;e3=dZ;e4=c[2437644]|0;e5=dZ&65535}else{e2=a[C+(A&255)|0]|0;e3=A;e4=z;e5=A&65535}}while(0);A=e2&255;z=e3+1|0;C=c[e4+72+((z>>>8&255|512)<<2)>>2]|0;do{if((C|0)==0){n=c[e4+3156>>2]|0;if((n|0)==0){e6=0;e7=e5;e8=e4;break}dZ=gj[n&4095](z&65535)|0;e6=dZ;e7=b[4830442]|0;e8=c[2437644]|0}else{e6=a[C+(z&255)|0]|0;e7=e5;e8=e4}}while(0);z=e6&255;c[2426868]=z|A<<8;b[4830442]=e7+2&65535;C=c[e8+72+(A<<2)>>2]|0;do{if((C|0)==0){dZ=c[e8+3144>>2]|0;if((dZ|0)==0){e9=0;break}e9=gj[dZ&4095]((z|A<<8)&65535)|0}else{e9=a[C+z|0]|0}}while(0);z=a[9660897]|0;C=(z&255)-(e9&255)|0;A=(C>>>4&8|a[9660900]&-16&255)&255;a[9660900]=(((z^e9)&255^C^C>>>1)>>>6&2|C>>>8&1|((C&255)<<24>>24==0?A|4:A)&255)&255;a[9660897]=C&255;break};case 177:{C=c[2415221]|0;A=c[2437644]|0;z=c[A+72+((C>>>8&255|512)<<2)>>2]|0;do{if((z|0)==0){dZ=c[A+3156>>2]|0;if((dZ|0)==0){fa=0;fb=C;fc=A;fd=C&65535;break}n=gj[dZ&4095](C&65535)|0;dZ=c[2415221]|0;fa=n;fb=dZ;fc=c[2437644]|0;fd=dZ&65535}else{fa=a[z+(C&255)|0]|0;fb=C;fc=A;fd=C&65535}}while(0);C=fa&255;A=fb+1|0;z=c[fc+72+((A>>>8&255|512)<<2)>>2]|0;do{if((z|0)==0){dZ=c[fc+3156>>2]|0;if((dZ|0)==0){fe=0;ff=fd;fg=fc;break}n=gj[dZ&4095](A&65535)|0;fe=n;ff=b[4830442]|0;fg=c[2437644]|0}else{fe=a[z+(A&255)|0]|0;ff=fd;fg=fc}}while(0);A=fe&255;c[2426868]=A|C<<8;b[4830442]=ff+2&65535;z=c[fg+72+(C<<2)>>2]|0;do{if((z|0)==0){n=c[fg+3144>>2]|0;if((n|0)==0){fh=0;break}fh=gj[n&4095]((A|C<<8)&65535)|0}else{fh=a[z+A|0]|0}}while(0);A=a[9660897]|0;z=(A&255)-(fh&255)|0;C=(z>>>4&8|a[9660900]&-16&255)&255;a[9660900]=(((A^fh)&255^z^z>>>1)>>>6&2|z>>>8&1|((z&255)<<24>>24==0?C|4:C)&255)&255;break};case 178:{C=c[2415221]|0;z=c[2437644]|0;A=c[z+72+((C>>>8&255|512)<<2)>>2]|0;do{if((A|0)==0){n=c[z+3156>>2]|0;if((n|0)==0){fi=0;fj=C;fk=z;fl=C&65535;break}dZ=gj[n&4095](C&65535)|0;n=c[2415221]|0;fi=dZ;fj=n;fk=c[2437644]|0;fl=n&65535}else{fi=a[A+(C&255)|0]|0;fj=C;fk=z;fl=C&65535}}while(0);C=fi&255;z=fj+1|0;A=c[fk+72+((z>>>8&255|512)<<2)>>2]|0;do{if((A|0)==0){n=c[fk+3156>>2]|0;if((n|0)==0){fm=0;fn=fl;fo=fk;break}dZ=gj[n&4095](z&65535)|0;fm=dZ;fn=b[4830442]|0;fo=c[2437644]|0}else{fm=a[A+(z&255)|0]|0;fn=fl;fo=fk}}while(0);z=fm&255;c[2426868]=z|C<<8;b[4830442]=fn+2&65535;A=c[fo+72+(C<<2)>>2]|0;do{if((A|0)==0){dZ=c[fo+3144>>2]|0;if((dZ|0)==0){fp=0;break}fp=gj[dZ&4095]((z|C<<8)&65535)|0}else{fp=a[A+z|0]|0}}while(0);z=a[9660897]|0;A=a[9660900]|0;C=(z&255)-(fp&255)-(A&1)|0;a[9660900]=((C^(z^fp)&255^C>>>1)>>>6&2|C>>>8&1|((C&255)<<24>>24==0?(C>>>4&8|A&-16&255)&255|4:(C>>>4&8|A&-16&255)&255)&255)&255;a[9660897]=C&255;break};case 179:{C=c[2415221]|0;A=c[2437644]|0;z=c[A+72+((C>>>8&255|512)<<2)>>2]|0;do{if((z|0)==0){dZ=c[A+3156>>2]|0;if((dZ|0)==0){fq=0;fr=C;fs=A;ft=C&65535;break}n=gj[dZ&4095](C&65535)|0;dZ=c[2415221]|0;fq=n;fr=dZ;fs=c[2437644]|0;ft=dZ&65535}else{fq=a[z+(C&255)|0]|0;fr=C;fs=A;ft=C&65535}}while(0);C=fq&255;A=fr+1|0;z=c[fs+72+((A>>>8&255|512)<<2)>>2]|0;do{if((z|0)==0){dZ=c[fs+3156>>2]|0;if((dZ|0)==0){fu=0;fv=ft;fw=fs;break}n=gj[dZ&4095](A&65535)|0;fu=n;fv=b[4830442]|0;fw=c[2437644]|0}else{fu=a[z+(A&255)|0]|0;fv=ft;fw=fs}}while(0);A=fu&255;c[2426868]=A|C<<8;b[4830442]=fv+2&65535;z=c[fw+72+(C<<2)>>2]|0;do{if((z|0)==0){n=c[fw+3144>>2]|0;if((n|0)==0){fx=0;fy=fw;break}dZ=gj[n&4095]((A|C<<8)&65535)|0;fx=dZ;fy=c[2437644]|0}else{fx=a[z+A|0]|0;fy=fw}}while(0);z=(fx&255)<<8;dZ=c[fy+72+((((A|C<<8)+1|0)>>>8&255)<<2)>>2]|0;do{if((dZ|0)==0){n=c[fy+3144>>2]|0;if((n|0)==0){fz=0;break}fz=gj[n&4095](((A|C<<8)+1|0)&65535)|0}else{fz=a[dZ+(((A|C<<8)+1|0)&255)|0]|0}}while(0);C=e[4830448]|0;A=C-(fz&255|z)|0;dZ=(A>>>12&8|a[9660900]&-16&255)&255;a[9660900]=((C^z^A^A>>>1)>>>14&2|A>>>16&1|((A&65535)<<16>>16==0?dZ|4:dZ)&255)&255;b[4830448]=A&65535;break};default:{l=1}}}c[h+136>>2]=p;c[h+152>>2]=k;c[h+25616>>2]=l;c[h+25624>>2]=q;c[h+25632>>2]=0;c[h+25636>>2]=0;__Z15hd63701_executei$0(h);l=c[h+25616>>2]|0;I=c[h+25632>>2]|0;B=c[h+25636>>2]|0;J=+g[h+25636>>2];c[h+25632>>2]=0;c[h+25636>>2]=0;if((I|0)==1){break}if((I|0)==2){switch(B|0){case 56:{break L43129}}}}while(0);k=d[6595512+j|0]|0;c[2440594]=(c[2440594]|0)-k;A=(c[2415234]|0)+k|0;c[2415234]=A;if(A>>>0<(c[3528192]|0)>>>0){s=37152;break}f03();s=37152}else{m=1}}if(m){m=0;if(1){A=c[3528192]|0;k=c[2415234]|0;dZ=c[2440594]|0;C=(A-k|0|0)>(dZ|0)?dZ:A-k|0;if((C|0)<=0){fA=dZ;break}c[2440594]=dZ-C;c[2415234]=C+k|0;if((C+k|0)>>>0<A>>>0){s=37152;break}f03();s=37152}else{m=1}}}while(0);if((s|0)==37152){s=0;fA=c[2440594]|0}}while((fA|0)>0);s=c[2415227]|0;p=fA-s|0;c[2440594]=p;fA=(c[2415234]|0)+s|0;c[2415234]=fA;if(fA>>>0<(c[3528192]|0)>>>0){fB=p;c[2415227]=0;fC=f-fB|0;i=h;return fC|0}f03();fB=c[2440594]|0;c[2415227]=0;fC=f-fB|0;i=h;return fC|0}function f4E(){f00(-18);return}function f4F(){var d=0,e=0,f=0,g=0,h=0,i=0;d=(b[4830444]|0)+1&65535;e=d&65535;f=c[2437644]|0;g=c[f+72+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3144>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(e&255)|0]|0}}while(0);b[4830446]=(b[4830446]|0)+(i&255)&65535;return}function f4G(){var d=0,e=0,f=0,g=0,h=0,i=0;d=(b[4830444]|0)+1&65535;e=d&65535;f=c[2437644]|0;g=c[f+72+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+3144>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](d)|0}else{i=a[g+(e&255)|0]|0}}while(0);b[4830446]=(b[4830446]|0)+(i&255)&65535;return}function f4H(){var a=0;a=b[4830446]|0;b[4830446]=b[4830448]|0;b[4830448]=a;return}function f4I(){var b=0,d=0,e=0,f=0,g=0;a[9660901]=a[9660901]|16;b=c[3528192]|0;d=c[2415234]|0;e=b-d|0;f=c[2440594]|0;g=(e|0)>(f|0)?f:e;if((g|0)<=0){return}c[2440594]=f-g;f=g+d|0;c[2415234]=f;if(f>>>0<b>>>0){return}f03();return}function f4J(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=e;k=f;break}l=gj[h&4095](e)|0;i=l;j=b[4830442]|0;k=c[2437644]|0}else{i=a[g+(d&255)|0]|0;j=e;k=f}}while(0);b[4830442]=j+1&65535;j=b[4830446]|0;f=c[2415221]|0;e=f&65535;d=c[k+72+((f>>>8&255|512)<<2)>>2]|0;do{if((d|0)==0){g=c[k+3156>>2]|0;if((g|0)==0){m=0;n=e;o=k;break}l=gj[g&4095](e)|0;m=l;n=b[4830442]|0;o=c[2437644]|0}else{m=a[d+(f&255)|0]|0;n=e;o=k}}while(0);b[4853736]=(m&255)+j&65535;b[4830442]=n+1&65535;n=c[2426868]|0;j=n&65535;m=c[o+72+((n>>>8&255)<<2)>>2]|0;do{if((m|0)==0){k=c[o+3144>>2]|0;if((k|0)==0){p=0;q=n;r=o;break}e=gj[k&4095](j)|0;p=e;q=c[2426868]|0;r=c[2437644]|0}else{p=a[m+(n&255)|0]|0;q=n;r=o}}while(0);o=p&i;i=(o&255)>>>4&8|a[9660900]&-15;a[9660900]=o<<24>>24==0?i|4:i;i=c[r+72+((q>>>8&255|256)<<2)>>2]|0;if((i|0)!=0){a[i+(q&255)|0]=o;return}i=c[r+3148>>2]|0;if((i|0)==0){return}gg[i&4095](q&65535,o);return}function f4K(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=e;k=f;break}l=gj[h&4095](e)|0;i=l;j=b[4830442]|0;k=c[2437644]|0}else{i=a[g+(d&255)|0]|0;j=e;k=f}}while(0);b[4830442]=j+1&65535;j=b[4830446]|0;f=c[2415221]|0;e=f&65535;d=c[k+72+((f>>>8&255|512)<<2)>>2]|0;do{if((d|0)==0){g=c[k+3156>>2]|0;if((g|0)==0){m=0;n=e;o=k;break}l=gj[g&4095](e)|0;m=l;n=b[4830442]|0;o=c[2437644]|0}else{m=a[d+(f&255)|0]|0;n=e;o=k}}while(0);b[4853736]=(m&255)+j&65535;b[4830442]=n+1&65535;n=c[2426868]|0;j=n&65535;m=c[o+72+((n>>>8&255)<<2)>>2]|0;do{if((m|0)==0){k=c[o+3144>>2]|0;if((k|0)==0){p=0;q=n;r=o;break}e=gj[k&4095](j)|0;p=e;q=c[2426868]|0;r=c[2437644]|0}else{p=a[m+(n&255)|0]|0;q=n;r=o}}while(0);o=p|i;i=(o&255)>>>4&8|a[9660900]&-15;a[9660900]=o<<24>>24==0?i|4:i;i=c[r+72+((q>>>8&255|256)<<2)>>2]|0;if((i|0)!=0){a[i+(q&255)|0]=o;return}i=c[r+3148>>2]|0;if((i|0)==0){return}gg[i&4095](q&65535,o);return}function f4L(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=e;k=f;break}l=gj[h&4095](e)|0;i=l;j=b[4830442]|0;k=c[2437644]|0}else{i=a[g+(d&255)|0]|0;j=e;k=f}}while(0);b[4830442]=j+1&65535;j=b[4830446]|0;f=c[2415221]|0;e=f&65535;d=c[k+72+((f>>>8&255|512)<<2)>>2]|0;do{if((d|0)==0){g=c[k+3156>>2]|0;if((g|0)==0){m=0;n=e;o=k;break}l=gj[g&4095](e)|0;m=l;n=b[4830442]|0;o=c[2437644]|0}else{m=a[d+(f&255)|0]|0;n=e;o=k}}while(0);b[4853736]=(m&255)+j&65535;b[4830442]=n+1&65535;n=c[2426868]|0;j=n&65535;m=c[o+72+((n>>>8&255)<<2)>>2]|0;do{if((m|0)==0){k=c[o+3144>>2]|0;if((k|0)==0){p=0;q=n;r=o;break}e=gj[k&4095](j)|0;p=e;q=c[2426868]|0;r=c[2437644]|0}else{p=a[m+(n&255)|0]|0;q=n;r=o}}while(0);o=p^i;n=(o&255)>>>4&8|a[9660900]&-15;a[9660900]=p<<24>>24==i<<24>>24?n|4:n;n=c[r+72+((q>>>8&255|256)<<2)>>2]|0;if((n|0)!=0){a[n+(q&255)|0]=o;return}n=c[r+3148>>2]|0;if((n|0)==0){return}gg[n&4095](q&65535,o);return}function f4M(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=e;k=f;break}l=gj[h&4095](e)|0;i=l;j=b[4830442]|0;k=c[2437644]|0}else{i=a[g+(d&255)|0]|0;j=e;k=f}}while(0);b[4830442]=j+1&65535;j=b[4830446]|0;f=c[2415221]|0;e=f&65535;d=c[k+72+((f>>>8&255|512)<<2)>>2]|0;do{if((d|0)==0){g=c[k+3156>>2]|0;if((g|0)==0){m=0;n=e;o=k;break}l=gj[g&4095](e)|0;m=l;n=b[4830442]|0;o=c[2437644]|0}else{m=a[d+(f&255)|0]|0;n=e;o=k}}while(0);b[4853736]=(m&255)+j&65535;b[4830442]=n+1&65535;n=c[2426868]|0;j=n&65535;m=c[o+72+((n>>>8&255)<<2)>>2]|0;do{if((m|0)==0){k=c[o+3144>>2]|0;if((k|0)==0){p=0;break}p=gj[k&4095](j)|0}else{p=a[m+(n&255)|0]|0}}while(0);n=p&i;i=(n&255)>>>4&8|a[9660900]&-15;a[9660900]=n<<24>>24==0?i|4:i;return}function f4N(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=e;k=f;break}l=gj[h&4095](e)|0;i=l;j=b[4830442]|0;k=c[2437644]|0}else{i=a[g+(d&255)|0]|0;j=e;k=f}}while(0);b[4830442]=j+1&65535;j=c[2415221]|0;f=j&65535;e=c[k+72+((j>>>8&255|512)<<2)>>2]|0;do{if((e|0)==0){d=c[k+3156>>2]|0;if((d|0)==0){m=0;n=f;o=k;break}g=gj[d&4095](f)|0;m=g;n=b[4830442]|0;o=c[2437644]|0}else{m=a[e+(j&255)|0]|0;n=f;o=k}}while(0);k=m&255;c[2426868]=k;b[4830442]=n+1&65535;n=m&255;m=c[o+72>>2]|0;do{if((m|0)==0){f=c[o+3144>>2]|0;if((f|0)==0){p=0;q=k;r=o;break}j=gj[f&4095](n)|0;p=j;q=c[2426868]|0;r=c[2437644]|0}else{p=a[m+k|0]|0;q=k;r=o}}while(0);o=p&i;i=(o&255)>>>4&8|a[9660900]&-15;a[9660900]=o<<24>>24==0?i|4:i;i=c[r+72+((q>>>8&255|256)<<2)>>2]|0;if((i|0)!=0){a[i+(q&255)|0]=o;return}i=c[r+3148>>2]|0;if((i|0)==0){return}gg[i&4095](q&65535,o);return}function f4O(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=e;k=f;break}l=gj[h&4095](e)|0;i=l;j=b[4830442]|0;k=c[2437644]|0}else{i=a[g+(d&255)|0]|0;j=e;k=f}}while(0);b[4830442]=j+1&65535;j=c[2415221]|0;f=j&65535;e=c[k+72+((j>>>8&255|512)<<2)>>2]|0;do{if((e|0)==0){d=c[k+3156>>2]|0;if((d|0)==0){m=0;n=f;o=k;break}g=gj[d&4095](f)|0;m=g;n=b[4830442]|0;o=c[2437644]|0}else{m=a[e+(j&255)|0]|0;n=f;o=k}}while(0);k=m&255;c[2426868]=k;b[4830442]=n+1&65535;n=m&255;m=c[o+72>>2]|0;do{if((m|0)==0){f=c[o+3144>>2]|0;if((f|0)==0){p=0;q=k;r=o;break}j=gj[f&4095](n)|0;p=j;q=c[2426868]|0;r=c[2437644]|0}else{p=a[m+k|0]|0;q=k;r=o}}while(0);o=p|i;i=(o&255)>>>4&8|a[9660900]&-15;a[9660900]=o<<24>>24==0?i|4:i;i=c[r+72+((q>>>8&255|256)<<2)>>2]|0;if((i|0)!=0){a[i+(q&255)|0]=o;return}i=c[r+3148>>2]|0;if((i|0)==0){return}gg[i&4095](q&65535,o);return}function f4P(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=e;k=f;break}l=gj[h&4095](e)|0;i=l;j=b[4830442]|0;k=c[2437644]|0}else{i=a[g+(d&255)|0]|0;j=e;k=f}}while(0);b[4830442]=j+1&65535;j=c[2415221]|0;f=j&65535;e=c[k+72+((j>>>8&255|512)<<2)>>2]|0;do{if((e|0)==0){d=c[k+3156>>2]|0;if((d|0)==0){m=0;n=f;o=k;break}g=gj[d&4095](f)|0;m=g;n=b[4830442]|0;o=c[2437644]|0}else{m=a[e+(j&255)|0]|0;n=f;o=k}}while(0);k=m&255;c[2426868]=k;b[4830442]=n+1&65535;n=m&255;m=c[o+72>>2]|0;do{if((m|0)==0){f=c[o+3144>>2]|0;if((f|0)==0){p=0;q=k;r=o;break}j=gj[f&4095](n)|0;p=j;q=c[2426868]|0;r=c[2437644]|0}else{p=a[m+k|0]|0;q=k;r=o}}while(0);o=p^i;k=(o&255)>>>4&8|a[9660900]&-15;a[9660900]=p<<24>>24==i<<24>>24?k|4:k;k=c[r+72+((q>>>8&255|256)<<2)>>2]|0;if((k|0)!=0){a[k+(q&255)|0]=o;return}k=c[r+3148>>2]|0;if((k|0)==0){return}gg[k&4095](q&65535,o);return}function f4Q(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=c[2415221]|0;e=d&65535;f=c[2437644]|0;g=c[f+72+((d>>>8&255|512)<<2)>>2]|0;do{if((g|0)==0){h=c[f+3156>>2]|0;if((h|0)==0){i=0;j=e;k=f;break}l=gj[h&4095](e)|0;i=l;j=b[4830442]|0;k=c[2437644]|0}else{i=a[g+(d&255)|0]|0;j=e;k=f}}while(0);b[4830442]=j+1&65535;j=c[2415221]|0;f=j&65535;e=c[k+72+((j>>>8&255|512)<<2)>>2]|0;do{if((e|0)==0){d=c[k+3156>>2]|0;if((d|0)==0){m=0;n=f;o=k;break}g=gj[d&4095](f)|0;m=g;n=b[4830442]|0;o=c[2437644]|0}else{m=a[e+(j&255)|0]|0;n=f;o=k}}while(0);k=m&255;c[2426868]=k;b[4830442]=n+1&65535;n=m&255;m=c[o+72>>2]|0;do{if((m|0)==0){f=c[o+3144>>2]|0;if((f|0)==0){p=0;break}p=gj[f&4095](n)|0}else{p=a[m+k|0]|0}}while(0);k=p&i;i=(k&255)>>>4&8|a[9660900]&-15;a[9660900]=k<<24>>24==0?i|4:i;return}function f4R(d){d=d|0;var f=0,g=0,h=0,i=0,j=0;switch(d&65535|0){case 3:{d=c[(c[2437644]|0)+3160>>2]|0;if((d|0)==0){f=0}else{f=gj[d&4095](257)|0}d=a[9660921]|0;g=a[9660925]&d|f&~d;return g|0};case 5:{g=a[9660923]|0;return g|0};case 1:{g=a[9660921]|0;return g|0};case 0:{g=a[9660920]|0;return g|0};case 2:{d=c[(c[2437644]|0)+3160>>2]|0;if((d|0)==0){h=0}else{h=gj[d&4095](256)|0}d=a[9660920]|0;g=a[9660924]&d|h&~d;return g|0};case 6:{d=c[(c[2437644]|0)+3160>>2]|0;if((d|0)==0){i=0}else{i=gj[d&4095](258)|0}d=a[9660922]|0;g=a[9660926]&d|i&~d;return g|0};case 7:{d=c[(c[2437644]|0)+3160>>2]|0;if((d|0)==0){j=0}else{j=gj[d&4095](259)|0}d=a[9660923]|0;g=a[9660927]&d|j&~d;return g|0};case 9:{if((a[9660930]&32)==0){d=a[9660928]|0;a[9660928]=d&-33;a[9660931]=d&-64&d<<3}g=a[9660937]|0;return g|0};case 12:{if((a[9660930]&64)==0){d=a[9660928]|0;a[9660928]=d&-65;a[9660931]=d&-96&d<<3}g=a[9660940]|0;return g|0};case 13:{if((a[9660930]|0)>=0){d=a[9660928]|0;a[9660928]=d&127;a[9660931]=d&96&d<<3}g=b[4830472]&255;return g|0};case 4:{g=a[9660922]|0;return g|0};case 10:{g=a[9660936]|0;return g|0};case 11:{if((a[9660930]&64)==0){d=a[9660928]|0;a[9660928]=d&-65;a[9660931]=d&-96&d<<3}g=a[9660941]|0;return g|0};case 8:{a[9660930]=0;g=a[9660928]|0;return g|0};case 14:{g=(e[4830472]|0)>>>8&255;return g|0};case 20:{g=a[9660932]|0;return g|0};default:{g=0;return g|0}}return 0}function f4S(d,f){d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;switch(d&65535|0){case 1:{if((a[9660921]|0)==f<<24>>24){return}a[9660921]=f;d=a[9660925]|0;if(f<<24>>24==-1){g=c[(c[2437644]|0)+3164>>2]|0;if((g|0)==0){return}gg[g&4095](257,d);return}g=c[2437644]|0;h=c[g+3160>>2]|0;if((h|0)==0){i=0;j=g}else{g=gj[h&4095](257)|0;i=g;j=c[2437644]|0}g=c[j+3164>>2]|0;if((g|0)==0){return}gg[g&4095](257,i&~a[9660921]|d&f);return};case 2:{a[9660924]=f;d=a[9660920]|0;if(d<<24>>24==-1){i=c[(c[2437644]|0)+3164>>2]|0;if((i|0)==0){return}gg[i&4095](256,f);return}i=c[2437644]|0;g=c[i+3160>>2]|0;if((g|0)==0){k=0;l=i}else{i=gj[g&4095](256)|0;k=i;l=c[2437644]|0}i=c[l+3164>>2]|0;if((i|0)==0){return}gg[i&4095](256,k&~a[9660920]|d&f);return};case 3:{a[9660925]=f;a[9660921]=f;d=c[2437644]|0;if(f<<24>>24==-1){k=c[d+3164>>2]|0;if((k|0)==0){return}gg[k&4095](257,-1);return}k=c[d+3160>>2]|0;if((k|0)==0){m=0;n=d}else{d=gj[k&4095](257)|0;m=d;n=c[2437644]|0}d=c[n+3164>>2]|0;if((d|0)==0){return}gg[d&4095](257,m&~a[9660921]|f);return};case 4:{if((a[9660922]|0)==f<<24>>24){return}a[9660922]=f;m=a[9660926]|0;if(f<<24>>24==-1){d=c[(c[2437644]|0)+3164>>2]|0;if((d|0)==0){return}gg[d&4095](258,m);return}d=c[2437644]|0;n=c[d+3160>>2]|0;if((n|0)==0){o=0;p=d}else{d=gj[n&4095](258)|0;o=d;p=c[2437644]|0}d=c[p+3164>>2]|0;if((d|0)==0){return}gg[d&4095](258,o&~a[9660922]|m&f);return};case 5:{if((a[9660923]|0)==f<<24>>24){return}a[9660923]=f;m=a[9660927]|0;if(f<<24>>24==-1){o=c[(c[2437644]|0)+3164>>2]|0;if((o|0)==0){return}gg[o&4095](259,m);return}o=c[2437644]|0;d=c[o+3160>>2]|0;if((d|0)==0){q=0;r=o}else{o=gj[d&4095](259)|0;q=o;r=c[2437644]|0}o=c[r+3164>>2]|0;if((o|0)==0){return}gg[o&4095](259,q&~a[9660923]|m&f);return};case 6:{a[9660926]=f;m=a[9660922]|0;if(m<<24>>24==-1){q=c[(c[2437644]|0)+3164>>2]|0;if((q|0)==0){return}gg[q&4095](258,f);return}q=c[2437644]|0;o=c[q+3160>>2]|0;if((o|0)==0){s=0;t=q}else{q=gj[o&4095](258)|0;s=q;t=c[2437644]|0}q=c[t+3164>>2]|0;if((q|0)==0){return}gg[q&4095](258,s&~a[9660922]|m&f);return};case 7:{a[9660927]=f;m=a[9660923]|0;if(m<<24>>24==-1){s=c[(c[2437644]|0)+3164>>2]|0;if((s|0)==0){return}gg[s&4095](259,f);return}s=c[2437644]|0;q=c[s+3160>>2]|0;if((q|0)==0){u=0;v=s}else{s=gj[q&4095](259)|0;u=s;v=c[2437644]|0}s=c[v+3164>>2]|0;if((s|0)==0){return}gg[s&4095](259,u&~a[9660923]|m&f);return};case 8:{a[9660928]=f;a[9660930]=a[9660930]&f;m=f&-32&f<<3;a[9660931]=m;if((a[9660900]&16)!=0){return}u=m&255;if(m<<24>>24==0){return}if((u&128|0)!=0){f00(-10);return}if((u&64|0)!=0){f00(-12);return}if((u&32|0)==0){return}f00(-14);return};case 9:{c[2384428]=f&255;b[4830468]=-8;u=b[4830469]|0;b[4830474]=u;b[4830471]=((e[4830470]|0)<65528)+u&65535;u=c[2415235]|0;m=c[2415234]|0;s=c[2415237]|0;c[3528192]=(u-m|0)>>>0<(s-m|0)>>>0?u:s;return};case 10:{s=(c[2384428]<<8|f&255)&65535;b[4830468]=s;u=b[4830469]|0;b[4830474]=u;b[4830471]=((e[4830470]|0)<(s&65535))+u&65535;u=c[2415235]|0;s=c[2415234]|0;m=c[2415237]|0;c[3528192]=(u-s|0)>>>0<(m-s|0)>>>0?u:m;return};case 11:{if((a[9660941]|0)==f<<24>>24){return}a[9660941]=f;b[4830471]=((e[4830470]|0)<(e[4830468]|0))+(b[4830469]|0)&65535;m=c[2415235]|0;u=c[2415234]|0;s=c[2415237]|0;c[3528192]=(m-u|0)>>>0<(s-u|0)>>>0?m:s;return};case 12:{if((a[9660940]|0)==f<<24>>24){return}a[9660940]=f;b[4830471]=((e[4830470]|0)<(e[4830468]|0))+(b[4830469]|0)&65535;s=c[2415235]|0;m=c[2415234]|0;u=c[2415237]|0;c[3528192]=(s-m|0)>>>0<(u-m|0)>>>0?s:u;return};case 20:{a[9660932]=f;return};case 0:{if((a[9660920]|0)==f<<24>>24){return}a[9660920]=f;u=a[9660924]|0;if(f<<24>>24==-1){s=c[(c[2437644]|0)+3164>>2]|0;if((s|0)==0){return}gg[s&4095](256,u);return}s=c[2437644]|0;m=c[s+3160>>2]|0;if((m|0)==0){w=0;x=s}else{s=gj[m&4095](256)|0;w=s;x=c[2437644]|0}s=c[x+3164>>2]|0;if((s|0)==0){return}gg[s&4095](256,w&~a[9660920]|u&f);return};default:{return}}}function f4T(){a[9660900]=a[9660900]&-3;return}function f4U(){a[9660900]=a[9660900]|2;return}function f4V(){a[9660900]=a[9660900]&-2;return}function f4W(){a[9660900]=a[9660900]|1;return}function f4X(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=c[2415207]|0;gGz(9660800,0,76);c[2415207]=d;c[2415200]=0;c[2415201]=127;c[2415202]=96;b[4830408]=127;a[9660822]=8;c[2415203]=0;d=c[2443666]|0;e=d&65534;f=e&65535;g=c[3528996]|0;h=c[9702704+(e>>>(g>>>0)<<2)>>2]|0;do{if((h|0)==0){i=c[2385590]|0;if((i|0)==0){j=0;k=d;l=g;break}m=gj[i&4095](f)|0;j=m;k=c[2443666]|0;l=c[3528996]|0}else{j=a[h+(c[2385780]&e)|0]|0;k=d;l=g}}while(0);a[9660813]=j;j=k&65535;g=c[9702704+(j>>>(l>>>0)<<2)>>2]|0;if((g|0)!=0){n=a[g+(c[2385780]&j)|0]|0;a[9660812]=n;return}j=c[2385590]|0;if((j|0)==0){n=0;a[9660812]=n;return}n=gj[j&4095](k&65535)|0;a[9660812]=n;return}function f4Y(f){f=f|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0,cf=0,cg=0,ch=0,ci=0,cj=0,ck=0,cl=0,cm=0,cn=0,co=0,cp=0,cq=0,cr=0,cs=0,ct=0,cu=0,cv=0,cw=0,cx=0,cy=0,cz=0,cA=0,cB=0,cC=0,cD=0,cE=0,cF=0,cG=0,cH=0,cI=0,cJ=0,cK=0,cL=0,cM=0,cN=0,cO=0,cP=0,cQ=0,cR=0,cS=0,cT=0,cU=0,cV=0,cW=0,cX=0,cY=0,cZ=0,c_=0,c$=0,c0=0,c1=0,c2=0,c3=0,c4=0,c5=0,c6=0,c7=0,c8=0,c9=0,da=0,db=0,dc=0,dd=0,de=0,df=0,dg=0,dh=0,di=0,dj=0,dk=0,dl=0,dm=0,dn=0,dp=0,dq=0,dr=0,ds=0,dt=0,du=0,dv=0,dw=0,dx=0,dy=0,dz=0,dA=0,dB=0,dC=0,dD=0,dE=0,dF=0,dG=0,dH=0,dI=0,dJ=0,dK=0,dL=0,dM=0,dN=0,dO=0,dP=0,dQ=0,dR=0,dS=0,dT=0,dU=0,dV=0,dW=0,dX=0,dY=0,dZ=0,d_=0,d$=0,d0=0,d1=0,d2=0,d3=0,d4=0,d5=0,d6=0,d7=0,d8=0,d9=0,ea=0,eb=0,ec=0,ed=0,ee=0,ef=0,eg=0,eh=0,ei=0,ej=0,ek=0,el=0,em=0,en=0,eo=0,ep=0,eq=0,er=0,es=0,et=0,eu=0,ev=0,ew=0;h=i;i=i+23512|0;c[1631650]=f;j=f;do{k=b[4830412]|0;do{if(k<<16>>16!=0){if((c[2415200]|0)==1){if((k&3)==0){break}do{if((a[9660822]&8)==0){l=a[9660812]|0;m=c[2443666]&(e[4830408]|0);n=c[9703728+(m>>>((c[3528996]|0)>>>0)<<2)>>2]|0;do{if((n|0)==0){o=c[3528586]|0;if((o|0)==0){break}gg[o&4095](m&65535,l)}else{a[n+(c[2385780]&m)|0]=l}}while(0);l=(b[4830408]|0)-1&65535;b[4830408]=l;if((l&65535)>>>0<(c[2415202]|0)>>>0){m=c[2415201]&65535;b[4830408]=m;p=m}else{p=l}l=a[9660813]|0;m=c[2443666]&(p&65535);n=c[9703728+(m>>>((c[3528996]|0)>>>0)<<2)>>2]|0;do{if((n|0)==0){o=c[3528586]|0;if((o|0)==0){break}gg[o&4095](m&65535,l)}else{a[n+(c[2385780]&m)|0]=l}}while(0);l=(b[4830408]|0)-1&65535;b[4830408]=l;if((l&65535)>>>0<(c[2415202]|0)>>>0){m=c[2415201]&65535;b[4830408]=m;q=m}else{q=l}l=a[9660821]|0;m=c[2443666]&(q&65535);n=c[9703728+(m>>>((c[3528996]|0)>>>0)<<2)>>2]|0;do{if((n|0)==0){o=c[3528586]|0;if((o|0)==0){break}gg[o&4095](m&65535,l)}else{a[n+(c[2385780]&m)|0]=l}}while(0);l=(b[4830408]|0)-1&65535;b[4830408]=l;if((l&65535)>>>0<(c[2415202]|0)>>>0){m=c[2415201]&65535;b[4830408]=m;r=m}else{r=l}l=a[9660820]|0;m=c[2443666]&(r&65535);n=c[9703728+(m>>>((c[3528996]|0)>>>0)<<2)>>2]|0;do{if((n|0)==0){o=c[3528586]|0;if((o|0)==0){break}gg[o&4095](m&65535,l)}else{a[n+(c[2385780]&m)|0]=l}}while(0);l=(b[4830408]|0)-1&65535;b[4830408]=l;if((l&65535)>>>0<(c[2415202]|0)>>>0){m=c[2415201]&65535;b[4830408]=m;s=m}else{s=l}l=a[9660822]|0;m=c[2443666]&(s&65535);n=c[9703728+(m>>>((c[3528996]|0)>>>0)<<2)>>2]|0;do{if((n|0)==0){o=c[3528586]|0;if((o|0)==0){break}gg[o&4095](m&65535,l)}else{a[n+(c[2385780]&m)|0]=l}}while(0);l=(b[4830408]|0)-1&65535;b[4830408]=l;if((l&65535)>>>0<(c[2415202]|0)>>>0){b[4830408]=c[2415201]&65535}a[9660822]=a[9660822]|8;l=c[2415207]|0;if((l|0)!=0){gj[l&4095](0)|0}l=b[4830412]|0;if((l&65535&1|0)!=0){b[4830412]=l&-2;c[2415203]=0;m=c[2443666]|0;n=c[3528996]|0;o=c[9702704+((m&65530)>>>(n>>>0)<<2)>>2]|0;do{if((o|0)==0){t=c[2385590]|0;if((t|0)==0){u=0;v=m;w=n;break}x=gj[t&4095](m&65530&65535)|0;u=x;v=c[2443666]|0;w=c[3528996]|0}else{u=a[o+(c[2385780]&(m&65530))|0]|0;v=m;w=n}}while(0);a[9660813]=u;n=v&65531;m=c[9702704+(n>>>(w>>>0)<<2)>>2]|0;do{if((m|0)==0){o=c[2385590]|0;if((o|0)==0){y=0;break}y=gj[o&4095](n&65535)|0}else{y=a[m+(c[2385780]&n)|0]|0}}while(0);a[9660812]=y;break}if((l&65535&2|0)==0){break}b[4830412]=l&-3;c[2415203]=0;n=c[2443666]|0;m=c[3528996]|0;o=c[9702704+((n&65528)>>>(m>>>0)<<2)>>2]|0;do{if((o|0)==0){x=c[2385590]|0;if((x|0)==0){z=0;A=n;C=m;break}t=gj[x&4095](n&65528&65535)|0;z=t;A=c[2443666]|0;C=c[3528996]|0}else{z=a[o+(c[2385780]&(n&65528))|0]|0;A=n;C=m}}while(0);a[9660813]=z;m=A&65529;n=c[9702704+(m>>>(C>>>0)<<2)>>2]|0;do{if((n|0)==0){o=c[2385590]|0;if((o|0)==0){D=0;break}D=gj[o&4095](m&65535)|0}else{D=a[n+(c[2385780]&m)|0]|0}}while(0);a[9660812]=D}}while(0);c[1631650]=(c[1631650]|0)-11;break}if((k&65535&256|0)!=0){m=a[9660812]|0;n=c[2443666]&(e[4830408]|0);o=c[9703728+(n>>>((c[3528996]|0)>>>0)<<2)>>2]|0;do{if((o|0)==0){l=c[3528586]|0;if((l|0)==0){break}gg[l&4095](n&65535,m)}else{a[o+(c[2385780]&n)|0]=m}}while(0);m=(b[4830408]|0)-1&65535;b[4830408]=m;if((m&65535)>>>0<(c[2415202]|0)>>>0){n=c[2415201]&65535;b[4830408]=n;E=n}else{E=m}m=a[9660813]|0;n=c[2443666]&(E&65535);o=c[9703728+(n>>>((c[3528996]|0)>>>0)<<2)>>2]|0;do{if((o|0)==0){l=c[3528586]|0;if((l|0)==0){break}gg[l&4095](n&65535,m)}else{a[o+(c[2385780]&n)|0]=m}}while(0);m=(b[4830408]|0)-1&65535;b[4830408]=m;if((m&65535)>>>0<(c[2415202]|0)>>>0){n=c[2415201]&65535;b[4830408]=n;F=n}else{F=m}m=a[9660821]|0;n=c[2443666]&(F&65535);o=c[9703728+(n>>>((c[3528996]|0)>>>0)<<2)>>2]|0;do{if((o|0)==0){l=c[3528586]|0;if((l|0)==0){break}gg[l&4095](n&65535,m)}else{a[o+(c[2385780]&n)|0]=m}}while(0);m=(b[4830408]|0)-1&65535;b[4830408]=m;if((m&65535)>>>0<(c[2415202]|0)>>>0){n=c[2415201]&65535;b[4830408]=n;G=n}else{G=m}m=a[9660820]|0;n=c[2443666]&(G&65535);o=c[9703728+(n>>>((c[3528996]|0)>>>0)<<2)>>2]|0;do{if((o|0)==0){l=c[3528586]|0;if((l|0)==0){break}gg[l&4095](n&65535,m)}else{a[o+(c[2385780]&n)|0]=m}}while(0);m=(b[4830408]|0)-1&65535;b[4830408]=m;if((m&65535)>>>0<(c[2415202]|0)>>>0){n=c[2415201]&65535;b[4830408]=n;H=n}else{H=m}m=a[9660822]|0;n=c[2443666]&(H&65535);o=c[9703728+(n>>>((c[3528996]|0)>>>0)<<2)>>2]|0;do{if((o|0)==0){l=c[3528586]|0;if((l|0)==0){break}gg[l&4095](n&65535,m)}else{a[o+(c[2385780]&n)|0]=m}}while(0);m=(b[4830408]|0)-1&65535;b[4830408]=m;if((m&65535)>>>0<(c[2415202]|0)>>>0){b[4830408]=c[2415201]&65535}a[9660822]=a[9660822]|8;m=c[2415207]|0;if((m|0)!=0){gj[m&4095](0)|0}c[2415203]=0;m=c[2443666]|0;n=c[3528996]|0;o=c[9702704+((m&8188)>>>(n>>>0)<<2)>>2]|0;do{if((o|0)==0){l=c[2385590]|0;if((l|0)==0){K=0;L=m;M=n;break}t=gj[l&4095](m&8188&65535)|0;K=t;L=c[2443666]|0;M=c[3528996]|0}else{K=a[o+(c[2385780]&(m&8188))|0]|0;L=m;M=n}}while(0);a[9660813]=K;n=L&8189;m=c[9702704+(n>>>(M>>>0)<<2)>>2]|0;do{if((m|0)==0){o=c[2385590]|0;if((o|0)==0){N=0;break}N=gj[o&4095](n&65535)|0}else{N=a[m+(c[2385780]&n)|0]|0}}while(0);a[9660812]=N;b[4830412]=b[4830412]&-257;c[1631650]=(c[1631650]|0)-11;break}if((k&65535&511|0)==0){break}if((a[9660822]&8)==0){n=a[9660812]|0;m=c[2443666]&(e[4830408]|0);o=c[9703728+(m>>>((c[3528996]|0)>>>0)<<2)>>2]|0;do{if((o|0)==0){t=c[3528586]|0;if((t|0)==0){break}gg[t&4095](m&65535,n)}else{a[o+(c[2385780]&m)|0]=n}}while(0);n=(b[4830408]|0)-1&65535;b[4830408]=n;if((n&65535)>>>0<(c[2415202]|0)>>>0){m=c[2415201]&65535;b[4830408]=m;O=m}else{O=n}n=a[9660813]|0;m=c[2443666]&(O&65535);o=c[9703728+(m>>>((c[3528996]|0)>>>0)<<2)>>2]|0;do{if((o|0)==0){t=c[3528586]|0;if((t|0)==0){break}gg[t&4095](m&65535,n)}else{a[o+(c[2385780]&m)|0]=n}}while(0);n=(b[4830408]|0)-1&65535;b[4830408]=n;if((n&65535)>>>0<(c[2415202]|0)>>>0){m=c[2415201]&65535;b[4830408]=m;P=m}else{P=n}n=a[9660821]|0;m=c[2443666]&(P&65535);o=c[9703728+(m>>>((c[3528996]|0)>>>0)<<2)>>2]|0;do{if((o|0)==0){t=c[3528586]|0;if((t|0)==0){break}gg[t&4095](m&65535,n)}else{a[o+(c[2385780]&m)|0]=n}}while(0);n=(b[4830408]|0)-1&65535;b[4830408]=n;if((n&65535)>>>0<(c[2415202]|0)>>>0){m=c[2415201]&65535;b[4830408]=m;Q=m}else{Q=n}n=a[9660820]|0;m=c[2443666]&(Q&65535);o=c[9703728+(m>>>((c[3528996]|0)>>>0)<<2)>>2]|0;do{if((o|0)==0){t=c[3528586]|0;if((t|0)==0){break}gg[t&4095](m&65535,n)}else{a[o+(c[2385780]&m)|0]=n}}while(0);n=(b[4830408]|0)-1&65535;b[4830408]=n;if((n&65535)>>>0<(c[2415202]|0)>>>0){m=c[2415201]&65535;b[4830408]=m;R=m}else{R=n}n=a[9660822]|0;m=c[2443666]&(R&65535);o=c[9703728+(m>>>((c[3528996]|0)>>>0)<<2)>>2]|0;do{if((o|0)==0){t=c[3528586]|0;if((t|0)==0){break}gg[t&4095](m&65535,n)}else{a[o+(c[2385780]&m)|0]=n}}while(0);n=(b[4830408]|0)-1&65535;b[4830408]=n;if((n&65535)>>>0<(c[2415202]|0)>>>0){b[4830408]=c[2415201]&65535}a[9660822]=a[9660822]|8;n=c[2415207]|0;if((n|0)!=0){gj[n&4095](0)|0}do{if((c[2415200]|0)==2){n=b[4830412]|0;if((n&65535&1|0)!=0){b[4830412]=n&-2;c[2415203]=0;m=c[2443666]|0;o=c[3528996]|0;t=c[9702704+((m&8184)>>>(o>>>0)<<2)>>2]|0;do{if((t|0)==0){l=c[2385590]|0;if((l|0)==0){S=0;T=m;U=o;break}x=gj[l&4095](m&8184&65535)|0;S=x;T=c[2443666]|0;U=c[3528996]|0}else{S=a[t+(c[2385780]&(m&8184))|0]|0;T=m;U=o}}while(0);a[9660813]=S;o=T&8185;m=c[9702704+(o>>>(U>>>0)<<2)>>2]|0;do{if((m|0)==0){t=c[2385590]|0;if((t|0)==0){V=0;break}V=gj[t&4095](o&65535)|0}else{V=a[m+(c[2385780]&o)|0]|0}}while(0);a[9660812]=V;break}if((n&65535&2|0)!=0){b[4830412]=n&-3;c[2415203]=0;o=c[2443666]|0;m=c[3528996]|0;t=c[9702704+((o&8172)>>>(m>>>0)<<2)>>2]|0;do{if((t|0)==0){x=c[2385590]|0;if((x|0)==0){W=0;X=o;Y=m;break}l=gj[x&4095](o&8172&65535)|0;W=l;X=c[2443666]|0;Y=c[3528996]|0}else{W=a[t+(c[2385780]&(o&8172))|0]|0;X=o;Y=m}}while(0);a[9660813]=W;m=X&8173;o=c[9702704+(m>>>(Y>>>0)<<2)>>2]|0;do{if((o|0)==0){t=c[2385590]|0;if((t|0)==0){Z=0;break}Z=gj[t&4095](m&65535)|0}else{Z=a[o+(c[2385780]&m)|0]|0}}while(0);a[9660812]=Z;break}if((n&65535&128|0)!=0){b[4830412]=n&-129;c[2415203]=0;m=c[2443666]|0;o=c[3528996]|0;t=c[9702704+((m&8170)>>>(o>>>0)<<2)>>2]|0;do{if((t|0)==0){l=c[2385590]|0;if((l|0)==0){_=0;$=m;aa=o;break}x=gj[l&4095](m&8170&65535)|0;_=x;$=c[2443666]|0;aa=c[3528996]|0}else{_=a[t+(c[2385780]&(m&8170))|0]|0;$=m;aa=o}}while(0);a[9660813]=_;o=$&8171;m=c[9702704+(o>>>(aa>>>0)<<2)>>2]|0;do{if((m|0)==0){t=c[2385590]|0;if((t|0)==0){ab=0;break}ab=gj[t&4095](o&65535)|0}else{ab=a[m+(c[2385780]&o)|0]|0}}while(0);a[9660812]=ab;break}if((n&65535&4|0)!=0){b[4830412]=n&-5;c[2415203]=0;o=c[2443666]|0;m=c[3528996]|0;t=c[9702704+((o&8182)>>>(m>>>0)<<2)>>2]|0;do{if((t|0)==0){x=c[2385590]|0;if((x|0)==0){ac=0;ad=o;ae=m;break}l=gj[x&4095](o&8182&65535)|0;ac=l;ad=c[2443666]|0;ae=c[3528996]|0}else{ac=a[t+(c[2385780]&(o&8182))|0]|0;ad=o;ae=m}}while(0);a[9660813]=ac;m=ad&8183;o=c[9702704+(m>>>(ae>>>0)<<2)>>2]|0;do{if((o|0)==0){t=c[2385590]|0;if((t|0)==0){af=0;break}af=gj[t&4095](m&65535)|0}else{af=a[o+(c[2385780]&m)|0]|0}}while(0);a[9660812]=af;break}if((n&65535&8|0)!=0){b[4830412]=n&-9;c[2415203]=0;m=c[2443666]|0;o=c[3528996]|0;t=c[9702704+((m&8180)>>>(o>>>0)<<2)>>2]|0;do{if((t|0)==0){l=c[2385590]|0;if((l|0)==0){ag=0;ah=m;ai=o;break}x=gj[l&4095](m&8180&65535)|0;ag=x;ah=c[2443666]|0;ai=c[3528996]|0}else{ag=a[t+(c[2385780]&(m&8180))|0]|0;ah=m;ai=o}}while(0);a[9660813]=ag;o=ah&8181;m=c[9702704+(o>>>(ai>>>0)<<2)>>2]|0;do{if((m|0)==0){t=c[2385590]|0;if((t|0)==0){aj=0;break}aj=gj[t&4095](o&65535)|0}else{aj=a[m+(c[2385780]&o)|0]|0}}while(0);a[9660812]=aj;break}if((n&65535&16|0)!=0){b[4830412]=n&-17;c[2415203]=0;o=c[2443666]|0;m=c[3528996]|0;t=c[9702704+((o&8178)>>>(m>>>0)<<2)>>2]|0;do{if((t|0)==0){x=c[2385590]|0;if((x|0)==0){ak=0;al=o;am=m;break}l=gj[x&4095](o&8178&65535)|0;ak=l;al=c[2443666]|0;am=c[3528996]|0}else{ak=a[t+(c[2385780]&(o&8178))|0]|0;al=o;am=m}}while(0);a[9660813]=ak;m=al&8179;o=c[9702704+(m>>>(am>>>0)<<2)>>2]|0;do{if((o|0)==0){t=c[2385590]|0;if((t|0)==0){an=0;break}an=gj[t&4095](m&65535)|0}else{an=a[o+(c[2385780]&m)|0]|0}}while(0);a[9660812]=an;break}if((n&65535&32|0)!=0){b[4830412]=n&-33;c[2415203]=0;m=c[2443666]|0;o=c[3528996]|0;t=c[9702704+((m&8176)>>>(o>>>0)<<2)>>2]|0;do{if((t|0)==0){l=c[2385590]|0;if((l|0)==0){ao=0;ap=m;aq=o;break}x=gj[l&4095](m&8176&65535)|0;ao=x;ap=c[2443666]|0;aq=c[3528996]|0}else{ao=a[t+(c[2385780]&(m&8176))|0]|0;ap=m;aq=o}}while(0);a[9660813]=ao;o=ap&8177;m=c[9702704+(o>>>(aq>>>0)<<2)>>2]|0;do{if((m|0)==0){t=c[2385590]|0;if((t|0)==0){ar=0;break}ar=gj[t&4095](o&65535)|0}else{ar=a[m+(c[2385780]&o)|0]|0}}while(0);a[9660812]=ar;break}if((n&65535&64|0)==0){break}b[4830412]=n&-65;c[2415203]=0;o=c[2443666]|0;m=c[3528996]|0;t=c[9702704+((o&8174)>>>(m>>>0)<<2)>>2]|0;do{if((t|0)==0){x=c[2385590]|0;if((x|0)==0){as=0;at=o;au=m;break}l=gj[x&4095](o&8174&65535)|0;as=l;at=c[2443666]|0;au=c[3528996]|0}else{as=a[t+(c[2385780]&(o&8174))|0]|0;at=o;au=m}}while(0);a[9660813]=as;m=at&8175;o=c[9702704+(m>>>(au>>>0)<<2)>>2]|0;do{if((o|0)==0){t=c[2385590]|0;if((t|0)==0){av=0;break}av=gj[t&4095](m&65535)|0}else{av=a[o+(c[2385780]&m)|0]|0}}while(0);a[9660812]=av}else{c[2415203]=0;m=c[2443666]|0;o=c[3528996]|0;t=c[9702704+((m&65530)>>>(o>>>0)<<2)>>2]|0;do{if((t|0)==0){n=c[2385590]|0;if((n|0)==0){aw=0;ax=m;ay=o;break}l=gj[n&4095](m&65530&65535)|0;aw=l;ax=c[2443666]|0;ay=c[3528996]|0}else{aw=a[t+(c[2385780]&(m&65530))|0]|0;ax=m;ay=o}}while(0);a[9660813]=aw;o=ax&65531;m=c[9702704+(o>>>(ay>>>0)<<2)>>2]|0;do{if((m|0)==0){t=c[2385590]|0;if((t|0)==0){az=0;break}az=gj[t&4095](o&65535)|0}else{az=a[m+(c[2385780]&o)|0]|0}}while(0);a[9660812]=az}}while(0);b[4830412]=b[4830412]&-2;aA=c[1631650]|0}else{aA=j}c[1631650]=aA-11}}while(0);k=b[4830406]|0;b[4830406]=k+1&65535;o=c[2443666]&(k&65535);k=o>>>((c[3528996]|0)>>>0);m=c[9704752+(k<<2)>>2]|0;do{if((m|0)==0){t=c[9702704+(k<<2)>>2]|0;if((t|0)!=0){aB=a[t+(c[2385780]&o)|0]|0;break}t=c[2385590]|0;if((t|0)==0){aB=0;break}aB=gj[t&4095](o&65535)|0}else{aB=a[m+(c[2385780]&o)|0]|0}}while(0);o=aB&255;L46207:do{m=1;k=o|0;if(m){m=0;switch(k|0){case 103:{c[2426866]=0;t=b[4830406]|0;b[4830406]=t+1&65535;l=c[2443666]|0;n=c[3528996]|0;x=c[9702704+((l&(t&65535))>>>(n>>>0)<<2)>>2]|0;do{if((x|0)==0){aC=c[2385590]|0;if((aC|0)==0){aD=0;aE=l;aF=n;break}aG=gj[aC&4095](l&(t&65535)&65535)|0;aD=aG;aE=c[2443666]|0;aF=c[3528996]|0}else{aD=a[x+(c[2385780]&(l&(t&65535)))|0]|0;aE=l;aF=n}}while(0);a[9707464]=aD;b[4853732]=(b[4853732]|0)+(d[9660821]|0)&65535;n=c[2426866]|0;l=n&65535&aE;t=c[9702704+(l>>>(aF>>>0)<<2)>>2]|0;do{if((t|0)==0){x=c[2385590]|0;if((x|0)==0){aH=0;aI=n;aJ=aE;aK=aF;break}aG=gj[x&4095](l&65535)|0;aH=aG;aI=c[2426866]|0;aJ=c[2443666]|0;aK=c[3528996]|0}else{aH=a[t+(c[2385780]&l)|0]|0;aI=n;aJ=aE;aK=aF}}while(0);n=(aH&255)>>>1;l=a[9660822]&-8|aH&1|(aH&255)>>>5&4;a[9660822]=(n<<1&-128|n)<<24>>24==0?l|2:l;l=aI&65535&aJ;t=c[9703728+(l>>>(aK>>>0)<<2)>>2]|0;if((t|0)!=0){a[t+(c[2385780]&l)|0]=n<<1&-128|n;break L46207}t=c[3528586]|0;if((t|0)==0){break L46207}gg[t&4095](l&65535,n<<1&-128|n);break};case 104:{c[2426866]=0;n=b[4830406]|0;b[4830406]=n+1&65535;l=c[2443666]|0;t=c[3528996]|0;aG=c[9702704+((l&(n&65535))>>>(t>>>0)<<2)>>2]|0;do{if((aG|0)==0){x=c[2385590]|0;if((x|0)==0){aL=0;aM=l;aN=t;break}aC=gj[x&4095](l&(n&65535)&65535)|0;aL=aC;aM=c[2443666]|0;aN=c[3528996]|0}else{aL=a[aG+(c[2385780]&(l&(n&65535)))|0]|0;aM=l;aN=t}}while(0);a[9707464]=aL;b[4853732]=(b[4853732]|0)+(d[9660821]|0)&65535;t=c[2426866]|0;l=t&65535&aM;n=c[9702704+(l>>>(aN>>>0)<<2)>>2]|0;do{if((n|0)==0){aG=c[2385590]|0;if((aG|0)==0){aO=0;aP=t;aQ=aM;aR=aN;break}aC=gj[aG&4095](l&65535)|0;aO=aC;aP=c[2426866]|0;aQ=c[2443666]|0;aR=c[3528996]|0}else{aO=a[n+(c[2385780]&l)|0]|0;aP=t;aQ=aM;aR=aN}}while(0);t=(aO&255)<<1;l=((t&65535)>>>5&4|a[9660822]&-8&255)&255;a[9660822]=(((t&255)<<24>>24==0?l|2:l)&255|(t&65535)>>>8)&255;l=aP&65535&aQ;n=c[9703728+(l>>>(aR>>>0)<<2)>>2]|0;if((n|0)!=0){a[n+(c[2385780]&l)|0]=t&255;break L46207}n=c[3528586]|0;if((n|0)==0){break L46207}gg[n&4095](l&65535,t&255);break};case 105:{c[2426866]=0;t=b[4830406]|0;b[4830406]=t+1&65535;l=c[2443666]|0;n=c[3528996]|0;aC=c[9702704+((l&(t&65535))>>>(n>>>0)<<2)>>2]|0;do{if((aC|0)==0){aG=c[2385590]|0;if((aG|0)==0){aS=0;aT=l;aU=n;break}x=gj[aG&4095](l&(t&65535)&65535)|0;aS=x;aT=c[2443666]|0;aU=c[3528996]|0}else{aS=a[aC+(c[2385780]&(l&(t&65535)))|0]|0;aT=l;aU=n}}while(0);a[9707464]=aS;b[4853732]=(b[4853732]|0)+(d[9660821]|0)&65535;n=c[2426866]|0;l=n&65535&aT;t=c[9702704+(l>>>(aU>>>0)<<2)>>2]|0;do{if((t|0)==0){aC=c[2385590]|0;if((aC|0)==0){aV=0;aW=n;aX=aT;aY=aU;break}x=gj[aC&4095](l&65535)|0;aV=x;aW=c[2426866]|0;aX=c[2443666]|0;aY=c[3528996]|0}else{aV=a[t+(c[2385780]&l)|0]|0;aW=n;aX=aT;aY=aU}}while(0);n=a[9660822]|0;l=n&1|(aV&255)<<1;a[9660822]=(((l&255)<<24>>24==0?((l&65535)>>>5&4|n&-8&255)&255|2:((l&65535)>>>5&4|n&-8&255)&255)&255|(l&65535)>>>8)&255;n=aW&65535&aX;t=c[9703728+(n>>>(aY>>>0)<<2)>>2]|0;if((t|0)!=0){a[t+(c[2385780]&n)|0]=l&255;break L46207}t=c[3528586]|0;if((t|0)==0){break L46207}gg[t&4095](n&65535,l&255);break};case 106:{c[2426866]=0;l=b[4830406]|0;b[4830406]=l+1&65535;n=c[2443666]|0;t=c[3528996]|0;x=c[9702704+((n&(l&65535))>>>(t>>>0)<<2)>>2]|0;do{if((x|0)==0){aC=c[2385590]|0;if((aC|0)==0){aZ=0;a_=n;a$=t;break}aG=gj[aC&4095](n&(l&65535)&65535)|0;aZ=aG;a_=c[2443666]|0;a$=c[3528996]|0}else{aZ=a[x+(c[2385780]&(n&(l&65535)))|0]|0;a_=n;a$=t}}while(0);a[9707464]=aZ;b[4853732]=(b[4853732]|0)+(d[9660821]|0)&65535;t=c[2426866]|0;n=t&65535&a_;l=c[9702704+(n>>>(a$>>>0)<<2)>>2]|0;do{if((l|0)==0){x=c[2385590]|0;if((x|0)==0){a0=0;a1=t;a2=a_;a3=a$;break}aG=gj[x&4095](n&65535)|0;a0=aG;a1=c[2426866]|0;a2=c[2443666]|0;a3=c[3528996]|0}else{a0=a[l+(c[2385780]&n)|0]|0;a1=t;a2=a_;a3=a$}}while(0);t=a0-1&255;a[9660822]=a[9660822]&-7|a[669440+(t&255)|0];n=a1&65535&a2;l=c[9703728+(n>>>(a3>>>0)<<2)>>2]|0;if((l|0)!=0){a[l+(c[2385780]&n)|0]=t;break L46207}l=c[3528586]|0;if((l|0)==0){break L46207}gg[l&4095](n&65535,t);break};case 108:{c[2426866]=0;t=b[4830406]|0;b[4830406]=t+1&65535;n=c[2443666]|0;l=c[3528996]|0;aG=c[9702704+((n&(t&65535))>>>(l>>>0)<<2)>>2]|0;do{if((aG|0)==0){x=c[2385590]|0;if((x|0)==0){a4=0;a5=n;a6=l;break}aC=gj[x&4095](n&(t&65535)&65535)|0;a4=aC;a5=c[2443666]|0;a6=c[3528996]|0}else{a4=a[aG+(c[2385780]&(n&(t&65535)))|0]|0;a5=n;a6=l}}while(0);a[9707464]=a4;b[4853732]=(b[4853732]|0)+(d[9660821]|0)&65535;l=c[2426866]|0;n=l&65535&a5;t=c[9702704+(n>>>(a6>>>0)<<2)>>2]|0;do{if((t|0)==0){aG=c[2385590]|0;if((aG|0)==0){a7=0;a8=l;a9=a5;ba=a6;break}aC=gj[aG&4095](n&65535)|0;a7=aC;a8=c[2426866]|0;a9=c[2443666]|0;ba=c[3528996]|0}else{a7=a[t+(c[2385780]&n)|0]|0;a8=l;a9=a5;ba=a6}}while(0);l=a7+1&255;a[9660822]=a[9660822]&-7|a[669440+(l&255)|0];n=a8&65535&a9;t=c[9703728+(n>>>(ba>>>0)<<2)>>2]|0;if((t|0)!=0){a[t+(c[2385780]&n)|0]=l;break L46207}t=c[3528586]|0;if((t|0)==0){break L46207}gg[t&4095](n&65535,l);break};case 109:{c[2426866]=0;l=b[4830406]|0;b[4830406]=l+1&65535;n=c[2443666]|0;t=c[3528996]|0;aC=c[9702704+((n&(l&65535))>>>(t>>>0)<<2)>>2]|0;do{if((aC|0)==0){aG=c[2385590]|0;if((aG|0)==0){bb=0;bc=n;bd=t;break}x=gj[aG&4095](n&(l&65535)&65535)|0;bb=x;bc=c[2443666]|0;bd=c[3528996]|0}else{bb=a[aC+(c[2385780]&(n&(l&65535)))|0]|0;bc=n;bd=t}}while(0);a[9707464]=bb;b[4853732]=(b[4853732]|0)+(d[9660821]|0)&65535;t=c[2426866]&65535&bc;n=c[9702704+(t>>>(bd>>>0)<<2)>>2]|0;do{if((n|0)==0){l=c[2385590]|0;if((l|0)==0){be=0;break}be=gj[l&4095](t&65535)|0}else{be=a[n+(c[2385780]&t)|0]|0}}while(0);t=a[9660822]&-7|(be&255)>>>5&4;a[9660822]=be<<24>>24==0?t|2:t;break};case 111:{c[2426866]=0;t=b[4830406]|0;b[4830406]=t+1&65535;n=c[2443666]|0;l=c[3528996]|0;aC=c[9702704+((n&(t&65535))>>>(l>>>0)<<2)>>2]|0;do{if((aC|0)==0){x=c[2385590]|0;if((x|0)==0){bf=0;bg=n;bh=l;break}aG=gj[x&4095](n&(t&65535)&65535)|0;bf=aG;bg=c[2443666]|0;bh=c[3528996]|0}else{bf=a[aC+(c[2385780]&(n&(t&65535)))|0]|0;bg=n;bh=l}}while(0);a[9707464]=bf;b[4853732]=(b[4853732]|0)+(d[9660821]|0)&65535;a[9660822]=a[9660822]&-8|2;l=c[2426866]&65535&bg;n=c[9703728+(l>>>(bh>>>0)<<2)>>2]|0;if((n|0)!=0){a[n+(c[2385780]&l)|0]=0;break L46207}n=c[3528586]|0;if((n|0)==0){break L46207}gg[n&4095](l&65535,0);break};case 112:{b[4853732]=d[9660821]|0;l=c[2426866]|0;n=c[2443666]|0;t=c[3528996]|0;aC=c[9702704+((l&65535&n)>>>(t>>>0)<<2)>>2]|0;do{if((aC|0)==0){aG=c[2385590]|0;if((aG|0)==0){bi=0;bj=l;bk=n;bl=t;break}x=gj[aG&4095](l&65535&n&65535)|0;bi=x;bj=c[2426866]|0;bk=c[2443666]|0;bl=c[3528996]|0}else{bi=a[aC+(c[2385780]&(l&65535&n))|0]|0;bj=l;bk=n;bl=t}}while(0);t=-(bi&255)&65535;n=((t&65535)>>>5&4|a[9660822]&-8&255)&255;a[9660822]=(((t&255)<<24>>24==0?n|2:n)&255|(t&65535)>>>8&1)&255;n=bj&65535&bk;l=c[9703728+(n>>>(bl>>>0)<<2)>>2]|0;if((l|0)!=0){a[l+(c[2385780]&n)|0]=t&255;break L46207}l=c[3528586]|0;if((l|0)==0){break L46207}gg[l&4095](n&65535,t&255);break};case 115:{b[4853732]=d[9660821]|0;t=c[2426866]|0;n=c[2443666]|0;l=c[3528996]|0;aC=c[9702704+((t&65535&n)>>>(l>>>0)<<2)>>2]|0;do{if((aC|0)==0){x=c[2385590]|0;if((x|0)==0){bm=0;bn=t;bo=n;bp=l;break}aG=gj[x&4095](t&65535&n&65535)|0;bm=aG;bn=c[2426866]|0;bo=c[2443666]|0;bp=c[3528996]|0}else{bm=a[aC+(c[2385780]&(t&65535&n))|0]|0;bn=t;bo=n;bp=l}}while(0);l=~bm;n=a[9660822]&-7|(l&255)>>>5&4;a[9660822]=(bm<<24>>24==-1?n|2:n)|1;n=bn&65535&bo;t=c[9703728+(n>>>(bp>>>0)<<2)>>2]|0;if((t|0)!=0){a[t+(c[2385780]&n)|0]=l;break L46207}t=c[3528586]|0;if((t|0)==0){break L46207}gg[t&4095](n&65535,l);break};case 116:{b[4853732]=d[9660821]|0;l=c[2426866]|0;n=c[2443666]|0;t=c[3528996]|0;aC=c[9702704+((l&65535&n)>>>(t>>>0)<<2)>>2]|0;do{if((aC|0)==0){aG=c[2385590]|0;if((aG|0)==0){bq=0;br=l;bs=n;bt=t;break}x=gj[aG&4095](l&65535&n&65535)|0;bq=x;br=c[2426866]|0;bs=c[2443666]|0;bt=c[3528996]|0}else{bq=a[aC+(c[2385780]&(l&65535&n))|0]|0;br=l;bs=n;bt=t}}while(0);t=a[9660822]&-8|bq&1;n=(bq&255)>>>1;a[9660822]=n<<24>>24==0?t|2:t;t=br&65535&bs;l=c[9703728+(t>>>(bt>>>0)<<2)>>2]|0;if((l|0)!=0){a[l+(c[2385780]&t)|0]=n;break L46207}l=c[3528586]|0;if((l|0)==0){break L46207}gg[l&4095](t&65535,n);break};case 118:{b[4853732]=d[9660821]|0;n=c[2426866]|0;t=c[2443666]|0;l=c[3528996]|0;aC=c[9702704+((n&65535&t)>>>(l>>>0)<<2)>>2]|0;do{if((aC|0)==0){x=c[2385590]|0;if((x|0)==0){bu=0;bv=n;bw=t;bx=l;break}aG=gj[x&4095](n&65535&t&65535)|0;bu=aG;bv=c[2426866]|0;bw=c[2443666]|0;bx=c[3528996]|0}else{bu=a[aC+(c[2385780]&(n&65535&t))|0]|0;bv=n;bw=t;bx=l}}while(0);l=a[9660822]|0;t=l<<7|(bu&255)>>>1;n=l&-8|bu&1|l<<2&4;a[9660822]=t<<24>>24==0?n|2:n;n=bv&65535&bw;l=c[9703728+(n>>>(bx>>>0)<<2)>>2]|0;if((l|0)!=0){a[l+(c[2385780]&n)|0]=t;break L46207}l=c[3528586]|0;if((l|0)==0){break L46207}gg[l&4095](n&65535,t);break};case 119:{b[4853732]=d[9660821]|0;t=c[2426866]|0;n=c[2443666]|0;l=c[3528996]|0;aC=c[9702704+((t&65535&n)>>>(l>>>0)<<2)>>2]|0;do{if((aC|0)==0){aG=c[2385590]|0;if((aG|0)==0){by=0;bz=t;bA=n;bB=l;break}x=gj[aG&4095](t&65535&n&65535)|0;by=x;bz=c[2426866]|0;bA=c[2443666]|0;bB=c[3528996]|0}else{by=a[aC+(c[2385780]&(t&65535&n))|0]|0;bz=t;bA=n;bB=l}}while(0);l=by&-128|(by&255)>>>1;n=a[9660822]&-8|by&1|(by&255)>>>5&4;a[9660822]=l<<24>>24==0?n|2:n;n=bz&65535&bA;t=c[9703728+(n>>>(bB>>>0)<<2)>>2]|0;if((t|0)!=0){a[t+(c[2385780]&n)|0]=l;break L46207}t=c[3528586]|0;if((t|0)==0){break L46207}gg[t&4095](n&65535,l);break};case 120:{b[4853732]=d[9660821]|0;l=c[2426866]|0;n=c[2443666]|0;t=c[3528996]|0;aC=c[9702704+((l&65535&n)>>>(t>>>0)<<2)>>2]|0;do{if((aC|0)==0){x=c[2385590]|0;if((x|0)==0){bC=0;bD=l;bE=n;bF=t;break}aG=gj[x&4095](l&65535&n&65535)|0;bC=aG;bD=c[2426866]|0;bE=c[2443666]|0;bF=c[3528996]|0}else{bC=a[aC+(c[2385780]&(l&65535&n))|0]|0;bD=l;bE=n;bF=t}}while(0);t=(bC&255)<<1;n=((t&65535)>>>5&4|a[9660822]&-8&255)&255;a[9660822]=(((t&255)<<24>>24==0?n|2:n)&255|(t&65535)>>>8)&255;n=bD&65535&bE;l=c[9703728+(n>>>(bF>>>0)<<2)>>2]|0;if((l|0)!=0){a[l+(c[2385780]&n)|0]=t&255;break L46207}l=c[3528586]|0;if((l|0)==0){break L46207}gg[l&4095](n&65535,t&255);break};case 121:{b[4853732]=d[9660821]|0;t=c[2426866]|0;n=c[2443666]|0;l=c[3528996]|0;aC=c[9702704+((t&65535&n)>>>(l>>>0)<<2)>>2]|0;do{if((aC|0)==0){aG=c[2385590]|0;if((aG|0)==0){bG=0;bH=t;bI=n;bJ=l;break}x=gj[aG&4095](t&65535&n&65535)|0;bG=x;bH=c[2426866]|0;bI=c[2443666]|0;bJ=c[3528996]|0}else{bG=a[aC+(c[2385780]&(t&65535&n))|0]|0;bH=t;bI=n;bJ=l}}while(0);l=a[9660822]|0;n=l&1|(bG&255)<<1;a[9660822]=(((n&255)<<24>>24==0?((n&65535)>>>5&4|l&-8&255)&255|2:((n&65535)>>>5&4|l&-8&255)&255)&255|(n&65535)>>>8)&255;l=bH&65535&bI;t=c[9703728+(l>>>(bJ>>>0)<<2)>>2]|0;if((t|0)!=0){a[t+(c[2385780]&l)|0]=n&255;break L46207}t=c[3528586]|0;if((t|0)==0){break L46207}gg[t&4095](l&65535,n&255);break};case 122:{b[4853732]=d[9660821]|0;n=c[2426866]|0;l=c[2443666]|0;t=c[3528996]|0;aC=c[9702704+((n&65535&l)>>>(t>>>0)<<2)>>2]|0;do{if((aC|0)==0){x=c[2385590]|0;if((x|0)==0){bK=0;bL=n;bM=l;bN=t;break}aG=gj[x&4095](n&65535&l&65535)|0;bK=aG;bL=c[2426866]|0;bM=c[2443666]|0;bN=c[3528996]|0}else{bK=a[aC+(c[2385780]&(n&65535&l))|0]|0;bL=n;bM=l;bN=t}}while(0);t=bK-1&255;a[9660822]=a[9660822]&-7|a[669440+(t&255)|0];l=bL&65535&bM;n=c[9703728+(l>>>(bN>>>0)<<2)>>2]|0;if((n|0)!=0){a[n+(c[2385780]&l)|0]=t;break L46207}n=c[3528586]|0;if((n|0)==0){break L46207}gg[n&4095](l&65535,t);break};case 124:{b[4853732]=d[9660821]|0;t=c[2426866]|0;l=c[2443666]|0;n=c[3528996]|0;aC=c[9702704+((t&65535&l)>>>(n>>>0)<<2)>>2]|0;do{if((aC|0)==0){aG=c[2385590]|0;if((aG|0)==0){bO=0;bP=t;bQ=l;bR=n;break}x=gj[aG&4095](t&65535&l&65535)|0;bO=x;bP=c[2426866]|0;bQ=c[2443666]|0;bR=c[3528996]|0}else{bO=a[aC+(c[2385780]&(t&65535&l))|0]|0;bP=t;bQ=l;bR=n}}while(0);n=bO+1&255;a[9660822]=a[9660822]&-7|a[669440+(n&255)|0];l=bP&65535&bQ;t=c[9703728+(l>>>(bR>>>0)<<2)>>2]|0;if((t|0)!=0){a[t+(c[2385780]&l)|0]=n;break L46207}t=c[3528586]|0;if((t|0)==0){break L46207}gg[t&4095](l&65535,n);break};case 125:{b[4853732]=d[9660821]|0;n=c[2426866]&65535&c[2443666];l=c[9702704+(n>>>((c[3528996]|0)>>>0)<<2)>>2]|0;do{if((l|0)==0){t=c[2385590]|0;if((t|0)==0){bS=0;break}bS=gj[t&4095](n&65535)|0}else{bS=a[l+(c[2385780]&n)|0]|0}}while(0);n=a[9660822]&-7|(bS&255)>>>5&4;a[9660822]=bS<<24>>24==0?n|2:n;break};case 127:{b[4853732]=d[9660821]|0;a[9660822]=a[9660822]&-8|2;n=c[2426866]&65535&c[2443666];l=c[9703728+(n>>>((c[3528996]|0)>>>0)<<2)>>2]|0;if((l|0)!=0){a[l+(c[2385780]&n)|0]=0;break L46207}l=c[3528586]|0;if((l|0)==0){break L46207}gg[l&4095](n&65535,0);break};case 128:{n=(b[4830408]|0)+1&65535;b[4830408]=n;l=c[2415201]|0;if((n&65535)>>>0>l>>>0){t=c[2415202]&65535;b[4830408]=t;bT=t}else{bT=n}n=c[2443666]&(bT&65535);t=c[9702704+(n>>>((c[3528996]|0)>>>0)<<2)>>2]|0;do{if((t|0)==0){aC=c[2385590]|0;if((aC|0)==0){bU=0;bV=bT;bW=l;break}x=gj[aC&4095](n&65535)|0;bU=x;bV=b[4830408]|0;bW=c[2415201]|0}else{bU=a[t+(c[2385780]&n)|0]|0;bV=bT;bW=l}}while(0);a[9660822]=bU;l=bV+1&65535;b[4830408]=l;if((l&65535)>>>0>bW>>>0){n=c[2415202]&65535;b[4830408]=n;bX=n}else{bX=l}l=c[2443666]&(bX&65535);n=c[9702704+(l>>>((c[3528996]|0)>>>0)<<2)>>2]|0;do{if((n|0)==0){t=c[2385590]|0;if((t|0)==0){bY=0;bZ=bX;b_=bW;break}x=gj[t&4095](l&65535)|0;bY=x;bZ=b[4830408]|0;b_=c[2415201]|0}else{bY=a[n+(c[2385780]&l)|0]|0;bZ=bX;b_=bW}}while(0);a[9660820]=bY;l=bZ+1&65535;b[4830408]=l;if((l&65535)>>>0>b_>>>0){n=c[2415202]&65535;b[4830408]=n;b$=n}else{b$=l}l=c[2443666]&(b$&65535);n=c[9702704+(l>>>((c[3528996]|0)>>>0)<<2)>>2]|0;do{if((n|0)==0){x=c[2385590]|0;if((x|0)==0){b0=0;b1=b$;b2=b_;break}t=gj[x&4095](l&65535)|0;b0=t;b1=b[4830408]|0;b2=c[2415201]|0}else{b0=a[n+(c[2385780]&l)|0]|0;b1=b$;b2=b_}}while(0);a[9660821]=b0;c[2415203]=0;l=b1+1&65535;b[4830408]=l;if((l&65535)>>>0>b2>>>0){n=c[2415202]&65535;b[4830408]=n;b3=n}else{b3=l}l=c[2443666]&(b3&65535);n=c[9702704+(l>>>((c[3528996]|0)>>>0)<<2)>>2]|0;do{if((n|0)==0){t=c[2385590]|0;if((t|0)==0){b4=0;b5=b3;b6=b2;break}x=gj[t&4095](l&65535)|0;b4=x;b5=b[4830408]|0;b6=c[2415201]|0}else{b4=a[n+(c[2385780]&l)|0]|0;b5=b3;b6=b2}}while(0);a[9660813]=b4;l=b5+1&65535;b[4830408]=l;if((l&65535)>>>0>b6>>>0){n=c[2415202]&65535;b[4830408]=n;b7=n}else{b7=l}l=c[2443666]&(b7&65535);n=c[9702704+(l>>>((c[3528996]|0)>>>0)<<2)>>2]|0;do{if((n|0)==0){x=c[2385590]|0;if((x|0)==0){b8=0;break}b8=gj[x&4095](l&65535)|0}else{b8=a[n+(c[2385780]&l)|0]|0}}while(0);a[9660812]=b8;break};case 129:{c[2415203]=0;l=(b[4830408]|0)+1&65535;b[4830408]=l;n=c[2415201]|0;if((l&65535)>>>0>n>>>0){x=c[2415202]&65535;b[4830408]=x;b9=x}else{b9=l}l=c[2443666]&(b9&65535);x=c[9702704+(l>>>((c[3528996]|0)>>>0)<<2)>>2]|0;do{if((x|0)==0){t=c[2385590]|0;if((t|0)==0){ca=0;cb=b9;cc=n;break}aC=gj[t&4095](l&65535)|0;ca=aC;cb=b[4830408]|0;cc=c[2415201]|0}else{ca=a[x+(c[2385780]&l)|0]|0;cb=b9;cc=n}}while(0);a[9660813]=ca;n=cb+1&65535;b[4830408]=n;if((n&65535)>>>0>cc>>>0){l=c[2415202]&65535;b[4830408]=l;cd=l}else{cd=n}n=c[2443666]&(cd&65535);l=c[9702704+(n>>>((c[3528996]|0)>>>0)<<2)>>2]|0;do{if((l|0)==0){x=c[2385590]|0;if((x|0)==0){ce=0;break}ce=gj[x&4095](n&65535)|0}else{ce=a[l+(c[2385780]&n)|0]|0}}while(0);a[9660812]=ce;break};case 131:{n=a[9660812]|0;l=c[2443666]&(e[4830408]|0);x=c[9703728+(l>>>((c[3528996]|0)>>>0)<<2)>>2]|0;do{if((x|0)==0){aC=c[3528586]|0;if((aC|0)==0){break}gg[aC&4095](l&65535,n)}else{a[x+(c[2385780]&l)|0]=n}}while(0);n=(b[4830408]|0)-1&65535;b[4830408]=n;if((n&65535)>>>0<(c[2415202]|0)>>>0){l=c[2415201]&65535;b[4830408]=l;cf=l}else{cf=n}n=a[9660813]|0;l=c[2443666]&(cf&65535);x=c[9703728+(l>>>((c[3528996]|0)>>>0)<<2)>>2]|0;do{if((x|0)==0){aC=c[3528586]|0;if((aC|0)==0){break}gg[aC&4095](l&65535,n)}else{a[x+(c[2385780]&l)|0]=n}}while(0);n=(b[4830408]|0)-1&65535;b[4830408]=n;if((n&65535)>>>0<(c[2415202]|0)>>>0){l=c[2415201]&65535;b[4830408]=l;cg=l}else{cg=n}n=a[9660821]|0;l=c[2443666]&(cg&65535);x=c[9703728+(l>>>((c[3528996]|0)>>>0)<<2)>>2]|0;do{if((x|0)==0){aC=c[3528586]|0;if((aC|0)==0){break}gg[aC&4095](l&65535,n)}else{a[x+(c[2385780]&l)|0]=n}}while(0);n=(b[4830408]|0)-1&65535;b[4830408]=n;if((n&65535)>>>0<(c[2415202]|0)>>>0){l=c[2415201]&65535;b[4830408]=l;ch=l}else{ch=n}n=a[9660820]|0;l=c[2443666]&(ch&65535);x=c[9703728+(l>>>((c[3528996]|0)>>>0)<<2)>>2]|0;do{if((x|0)==0){aC=c[3528586]|0;if((aC|0)==0){break}gg[aC&4095](l&65535,n)}else{a[x+(c[2385780]&l)|0]=n}}while(0);n=(b[4830408]|0)-1&65535;b[4830408]=n;if((n&65535)>>>0<(c[2415202]|0)>>>0){l=c[2415201]&65535;b[4830408]=l;ci=l}else{ci=n}n=a[9660822]|0;l=c[2443666]&(ci&65535);x=c[9703728+(l>>>((c[3528996]|0)>>>0)<<2)>>2]|0;do{if((x|0)==0){aC=c[3528586]|0;if((aC|0)==0){break}gg[aC&4095](l&65535,n)}else{a[x+(c[2385780]&l)|0]=n}}while(0);n=(b[4830408]|0)-1&65535;b[4830408]=n;if((n&65535)>>>0<(c[2415202]|0)>>>0){b[4830408]=c[2415201]&65535}a[9660822]=a[9660822]|8;n=(c[2415200]|0)==2;c[2415203]=0;l=c[2443666]|0;do{if(n){x=c[3528996]|0;aC=c[9702704+((l&8186)>>>(x>>>0)<<2)>>2]|0;do{if((aC|0)==0){t=c[2385590]|0;if((t|0)==0){cj=0;ck=l;cl=x;break}aG=gj[t&4095](l&8186&65535)|0;cj=aG;ck=c[2443666]|0;cl=c[3528996]|0}else{cj=a[aC+(c[2385780]&(l&8186))|0]|0;ck=l;cl=x}}while(0);a[9660813]=cj;x=ck&8187;aC=c[9702704+(x>>>(cl>>>0)<<2)>>2]|0;if((aC|0)!=0){cm=a[aC+(c[2385780]&x)|0]|0;break}aC=c[2385590]|0;if((aC|0)==0){cm=0;break}cm=gj[aC&4095](x&65535)|0}else{x=c[3528996]|0;aC=c[9702704+((l&65532)>>>(x>>>0)<<2)>>2]|0;do{if((aC|0)==0){aG=c[2385590]|0;if((aG|0)==0){cn=0;co=l;cp=x;break}t=gj[aG&4095](l&65532&65535)|0;cn=t;co=c[2443666]|0;cp=c[3528996]|0}else{cn=a[aC+(c[2385780]&(l&65532))|0]|0;co=l;cp=x}}while(0);a[9660813]=cn;x=co&65533;aC=c[9702704+(x>>>(cp>>>0)<<2)>>2]|0;if((aC|0)!=0){cm=a[aC+(c[2385780]&x)|0]|0;break}aC=c[2385590]|0;if((aC|0)==0){cm=0;break}cm=gj[aC&4095](x&65535)|0}}while(0);a[9660812]=cm;break};case 151:{a[9660821]=a[9660820]|0;break};case 152:{a[9660822]=a[9660822]&-2;break};case 153:{a[9660822]=a[9660822]|1;break};case 154:{a[9660822]=a[9660822]&-9;break};case 155:{a[9660822]=a[9660822]|8;break};case 156:{b[4830408]=c[2415201]&65535;break};case 159:{a[9660820]=a[9660821]|0;break};case 160:{l=b[4830406]|0;b[4830406]=l+1&65535;n=c[2443666]&(l&65535);l=c[9702704+(n>>>((c[3528996]|0)>>>0)<<2)>>2]|0;do{if((l|0)==0){x=c[2385590]|0;if((x|0)==0){cq=0;break}cq=gj[x&4095](n&65535)|0}else{cq=a[l+(c[2385780]&n)|0]|0}}while(0);n=(d[9660820]|0)-(cq&255)&65535;l=((n&65535)>>>5&4|a[9660822]&-8&255)&255;a[9660822]=(((n&255)<<24>>24==0?l|2:l)&255|(n&65535)>>>8&1)&255;a[9660820]=n&255;break};case 161:{n=b[4830406]|0;b[4830406]=n+1&65535;l=c[2443666]&(n&65535);n=c[9702704+(l>>>((c[3528996]|0)>>>0)<<2)>>2]|0;do{if((n|0)==0){x=c[2385590]|0;if((x|0)==0){cr=0;break}cr=gj[x&4095](l&65535)|0}else{cr=a[n+(c[2385780]&l)|0]|0}}while(0);l=(d[9660820]|0)-(cr&255)&65535;n=((l&65535)>>>5&4|a[9660822]&-8&255)&255;a[9660822]=(((l&255)<<24>>24==0?n|2:n)&255|(l&65535)>>>8&1)&255;break};case 162:{l=b[4830406]|0;b[4830406]=l+1&65535;n=c[2443666]&(l&65535);l=c[9702704+(n>>>((c[3528996]|0)>>>0)<<2)>>2]|0;do{if((l|0)==0){x=c[2385590]|0;if((x|0)==0){cs=0;break}cs=gj[x&4095](n&65535)|0}else{cs=a[l+(c[2385780]&n)|0]|0}}while(0);n=a[9660822]|0;l=(d[9660820]|0)-(cs&255)-(n&1)|0;a[9660822]=(((l&255)<<24>>24==0?(l>>>5&4|n&-8&255)&255|2:(l>>>5&4|n&-8&255)&255)&255|l>>>8&1)&255;a[9660820]=l&255;break};case 163:{l=b[4830406]|0;b[4830406]=l+1&65535;n=c[2443666]&(l&65535);l=c[9702704+(n>>>((c[3528996]|0)>>>0)<<2)>>2]|0;do{if((l|0)==0){x=c[2385590]|0;if((x|0)==0){ct=0;break}ct=gj[x&4095](n&65535)|0}else{ct=a[l+(c[2385780]&n)|0]|0}}while(0);n=(d[9660821]|0)-(ct&255)&65535;l=((n&65535)>>>5&4|a[9660822]&-8&255)&255;a[9660822]=(((n&255)<<24>>24==0?l|2:l)&255|(n&65535)>>>8&1)&255;break};case 164:{n=b[4830406]|0;b[4830406]=n+1&65535;l=c[2443666]&(n&65535);n=c[9702704+(l>>>((c[3528996]|0)>>>0)<<2)>>2]|0;do{if((n|0)==0){x=c[2385590]|0;if((x|0)==0){cu=0;break}cu=gj[x&4095](l&65535)|0}else{cu=a[n+(c[2385780]&l)|0]|0}}while(0);l=a[9660820]&cu;a[9660820]=l;n=(l&255)>>>5&4|a[9660822]&-7;a[9660822]=l<<24>>24==0?n|2:n;break};case 165:{n=b[4830406]|0;b[4830406]=n+1&65535;l=c[2443666]&(n&65535);n=c[9702704+(l>>>((c[3528996]|0)>>>0)<<2)>>2]|0;do{if((n|0)==0){x=c[2385590]|0;if((x|0)==0){cv=0;break}cv=gj[x&4095](l&65535)|0}else{cv=a[n+(c[2385780]&l)|0]|0}}while(0);l=a[9660820]&cv;n=(l&255)>>>5&4|a[9660822]&-7;a[9660822]=l<<24>>24==0?n|2:n;break};case 166:{n=b[4830406]|0;b[4830406]=n+1&65535;l=c[2443666]&(n&65535);n=c[9702704+(l>>>((c[3528996]|0)>>>0)<<2)>>2]|0;do{if((n|0)==0){x=c[2385590]|0;if((x|0)==0){cw=0;break}cw=gj[x&4095](l&65535)|0}else{cw=a[n+(c[2385780]&l)|0]|0}}while(0);a[9660820]=cw;l=(cw&255)>>>5&4|a[9660822]&-7;a[9660822]=cw<<24>>24==0?l|2:l;break};case 168:{l=b[4830406]|0;b[4830406]=l+1&65535;n=c[2443666]&(l&65535);l=c[9702704+(n>>>((c[3528996]|0)>>>0)<<2)>>2]|0;do{if((l|0)==0){x=c[2385590]|0;if((x|0)==0){cx=0;break}cx=gj[x&4095](n&65535)|0}else{cx=a[l+(c[2385780]&n)|0]|0}}while(0);n=a[9660820]|0;l=n^cx;a[9660820]=l;x=(l&255)>>>5&4|a[9660822]&-7;a[9660822]=n<<24>>24==cx<<24>>24?x|2:x;break};default:{m=1}}}if(m){m=0;switch(k|0){case 169:{x=b[4830406]|0;b[4830406]=x+1&65535;n=c[2443666]&(x&65535);x=c[9702704+(n>>>((c[3528996]|0)>>>0)<<2)>>2]|0;do{if((x|0)==0){l=c[2385590]|0;if((l|0)==0){cy=0;break}cy=gj[l&4095](n&65535)|0}else{cy=a[x+(c[2385780]&n)|0]|0}}while(0);n=a[9660820]|0;x=a[9660822]|0;l=(n&255)+(cy&255)+(x&1)|0;a[9660822]=((l^(n^cy)&255)&16|l>>>8&1|((l&255)<<24>>24==0?(l>>>5&4|x&-24&255)&255|2:(l>>>5&4|x&-24&255)&255)&255)&255;a[9660820]=l&255;break};case 170:{l=b[4830406]|0;b[4830406]=l+1&65535;x=c[2443666]&(l&65535);l=c[9702704+(x>>>((c[3528996]|0)>>>0)<<2)>>2]|0;do{if((l|0)==0){n=c[2385590]|0;if((n|0)==0){cz=0;break}cz=gj[n&4095](x&65535)|0}else{cz=a[l+(c[2385780]&x)|0]|0}}while(0);x=a[9660820]|cz;a[9660820]=x;l=(x&255)>>>5&4|a[9660822]&-7;a[9660822]=x<<24>>24==0?l|2:l;break};case 171:{l=b[4830406]|0;b[4830406]=l+1&65535;x=c[2443666]&(l&65535);l=c[9702704+(x>>>((c[3528996]|0)>>>0)<<2)>>2]|0;do{if((l|0)==0){n=c[2385590]|0;if((n|0)==0){cA=0;break}cA=gj[n&4095](x&65535)|0}else{cA=a[l+(c[2385780]&x)|0]|0}}while(0);x=a[9660820]|0;l=(x&255)+(cA&255)|0;n=(l>>>5&4|a[9660822]&-24&255)&255;a[9660822]=(((x^cA)&255^l)&16|l>>>8&1|((l&255)<<24>>24==0?n|2:n)&255)&255;a[9660820]=l&255;break};case 173:{l=b[4830406]|0;b[4830406]=l+1&65535;n=c[2443666]|0;x=c[3528996]|0;aC=c[9702704+((n&(l&65535))>>>(x>>>0)<<2)>>2]|0;do{if((aC|0)==0){t=c[2385590]|0;if((t|0)==0){cB=0;cC=l+1&65535&255;cD=n;cE=x;break}aG=gj[t&4095](n&(l&65535)&65535)|0;cB=aG;cC=a[9660812]|0;cD=c[2443666]|0;cE=c[3528996]|0}else{cB=a[aC+(c[2385780]&(n&(l&65535)))|0]|0;cC=l+1&65535&255;cD=n;cE=x}}while(0);x=cD&(e[4830408]|0);n=c[9703728+(x>>>(cE>>>0)<<2)>>2]|0;do{if((n|0)==0){l=c[3528586]|0;if((l|0)==0){break}gg[l&4095](x&65535,cC)}else{a[n+(c[2385780]&x)|0]=cC}}while(0);x=(b[4830408]|0)-1&65535;b[4830408]=x;if((x&65535)>>>0<(c[2415202]|0)>>>0){n=c[2415201]&65535;b[4830408]=n;cF=n}else{cF=x}x=a[9660813]|0;n=c[2443666]&(cF&65535);l=c[9703728+(n>>>((c[3528996]|0)>>>0)<<2)>>2]|0;do{if((l|0)==0){aC=c[3528586]|0;if((aC|0)==0){break}gg[aC&4095](n&65535,x)}else{a[l+(c[2385780]&n)|0]=x}}while(0);x=(b[4830408]|0)-1&65535;b[4830408]=x;if((x&65535)>>>0<(c[2415202]|0)>>>0){b[4830408]=c[2415201]&65535}x=cB&255;b[4830406]=(e[4830406]|0)+((x&128|0)!=0?x|65280:x)&65535;break};case 174:{x=b[4830406]|0;b[4830406]=x+1&65535;n=c[2443666]&(x&65535);x=c[9702704+(n>>>((c[3528996]|0)>>>0)<<2)>>2]|0;do{if((x|0)==0){l=c[2385590]|0;if((l|0)==0){cG=0;break}cG=gj[l&4095](n&65535)|0}else{cG=a[x+(c[2385780]&n)|0]|0}}while(0);a[9660821]=cG;n=(cG&255)>>>5&4|a[9660822]&-7;a[9660822]=cG<<24>>24==0?n|2:n;break};case 176:{c[2426866]=0;n=b[4830406]|0;b[4830406]=n+1&65535;x=c[2443666]|0;l=c[3528996]|0;aC=c[9702704+((x&(n&65535))>>>(l>>>0)<<2)>>2]|0;do{if((aC|0)==0){aG=c[2385590]|0;if((aG|0)==0){cH=0;cI=x;cJ=l;break}t=gj[aG&4095](x&(n&65535)&65535)|0;cH=t;cI=c[2443666]|0;cJ=c[3528996]|0}else{cH=a[aC+(c[2385780]&(x&(n&65535)))|0]|0;cI=x;cJ=l}}while(0);a[9707464]=cH;l=c[2426866]&65535&cI;x=c[9702704+(l>>>(cJ>>>0)<<2)>>2]|0;do{if((x|0)==0){n=c[2385590]|0;if((n|0)==0){cK=0;break}cK=gj[n&4095](l&65535)|0}else{cK=a[x+(c[2385780]&l)|0]|0}}while(0);l=(d[9660820]|0)-(cK&255)&65535;x=((l&65535)>>>5&4|a[9660822]&-8&255)&255;a[9660822]=(((l&255)<<24>>24==0?x|2:x)&255|(l&65535)>>>8&1)&255;a[9660820]=l&255;break};case 177:{c[2426866]=0;l=b[4830406]|0;b[4830406]=l+1&65535;x=c[2443666]|0;n=c[3528996]|0;aC=c[9702704+((x&(l&65535))>>>(n>>>0)<<2)>>2]|0;do{if((aC|0)==0){t=c[2385590]|0;if((t|0)==0){cL=0;cM=x;cN=n;break}aG=gj[t&4095](x&(l&65535)&65535)|0;cL=aG;cM=c[2443666]|0;cN=c[3528996]|0}else{cL=a[aC+(c[2385780]&(x&(l&65535)))|0]|0;cM=x;cN=n}}while(0);a[9707464]=cL;n=c[2426866]&65535&cM;x=c[9702704+(n>>>(cN>>>0)<<2)>>2]|0;do{if((x|0)==0){l=c[2385590]|0;if((l|0)==0){cO=0;break}cO=gj[l&4095](n&65535)|0}else{cO=a[x+(c[2385780]&n)|0]|0}}while(0);n=(d[9660820]|0)-(cO&255)&65535;x=((n&65535)>>>5&4|a[9660822]&-8&255)&255;a[9660822]=(((n&255)<<24>>24==0?x|2:x)&255|(n&65535)>>>8&1)&255;break};case 178:{c[2426866]=0;n=b[4830406]|0;b[4830406]=n+1&65535;x=c[2443666]|0;l=c[3528996]|0;aC=c[9702704+((x&(n&65535))>>>(l>>>0)<<2)>>2]|0;do{if((aC|0)==0){aG=c[2385590]|0;if((aG|0)==0){cP=0;cQ=x;cR=l;break}t=gj[aG&4095](x&(n&65535)&65535)|0;cP=t;cQ=c[2443666]|0;cR=c[3528996]|0}else{cP=a[aC+(c[2385780]&(x&(n&65535)))|0]|0;cQ=x;cR=l}}while(0);a[9707464]=cP;l=c[2426866]&65535&cQ;x=c[9702704+(l>>>(cR>>>0)<<2)>>2]|0;do{if((x|0)==0){n=c[2385590]|0;if((n|0)==0){cS=0;break}cS=gj[n&4095](l&65535)|0}else{cS=a[x+(c[2385780]&l)|0]|0}}while(0);l=a[9660822]|0;x=(d[9660820]|0)-(cS&255)-(l&1)|0;a[9660822]=(((x&255)<<24>>24==0?(x>>>5&4|l&-8&255)&255|2:(x>>>5&4|l&-8&255)&255)&255|x>>>8&1)&255;a[9660820]=x&255;break};case 179:{c[2426866]=0;x=b[4830406]|0;b[4830406]=x+1&65535;l=c[2443666]|0;n=c[3528996]|0;aC=c[9702704+((l&(x&65535))>>>(n>>>0)<<2)>>2]|0;do{if((aC|0)==0){t=c[2385590]|0;if((t|0)==0){cT=0;cU=l;cV=n;break}aG=gj[t&4095](l&(x&65535)&65535)|0;cT=aG;cU=c[2443666]|0;cV=c[3528996]|0}else{cT=a[aC+(c[2385780]&(l&(x&65535)))|0]|0;cU=l;cV=n}}while(0);a[9707464]=cT;n=c[2426866]&65535&cU;l=c[9702704+(n>>>(cV>>>0)<<2)>>2]|0;do{if((l|0)==0){x=c[2385590]|0;if((x|0)==0){cW=0;break}cW=gj[x&4095](n&65535)|0}else{cW=a[l+(c[2385780]&n)|0]|0}}while(0);n=(d[9660821]|0)-(cW&255)&65535;l=((n&65535)>>>5&4|a[9660822]&-8&255)&255;a[9660822]=(((n&255)<<24>>24==0?l|2:l)&255|(n&65535)>>>8&1)&255;break};case 180:{c[2426866]=0;n=b[4830406]|0;b[4830406]=n+1&65535;l=c[2443666]|0;x=c[3528996]|0;aC=c[9702704+((l&(n&65535))>>>(x>>>0)<<2)>>2]|0;do{if((aC|0)==0){aG=c[2385590]|0;if((aG|0)==0){cX=0;cY=l;cZ=x;break}t=gj[aG&4095](l&(n&65535)&65535)|0;cX=t;cY=c[2443666]|0;cZ=c[3528996]|0}else{cX=a[aC+(c[2385780]&(l&(n&65535)))|0]|0;cY=l;cZ=x}}while(0);a[9707464]=cX;x=c[2426866]&65535&cY;l=c[9702704+(x>>>(cZ>>>0)<<2)>>2]|0;do{if((l|0)==0){n=c[2385590]|0;if((n|0)==0){c_=0;break}c_=gj[n&4095](x&65535)|0}else{c_=a[l+(c[2385780]&x)|0]|0}}while(0);x=a[9660820]&c_;a[9660820]=x;l=(x&255)>>>5&4|a[9660822]&-7;a[9660822]=x<<24>>24==0?l|2:l;break};case 181:{c[2426866]=0;l=b[4830406]|0;b[4830406]=l+1&65535;x=c[2443666]|0;n=c[3528996]|0;aC=c[9702704+((x&(l&65535))>>>(n>>>0)<<2)>>2]|0;do{if((aC|0)==0){t=c[2385590]|0;if((t|0)==0){c$=0;c0=x;c1=n;break}aG=gj[t&4095](x&(l&65535)&65535)|0;c$=aG;c0=c[2443666]|0;c1=c[3528996]|0}else{c$=a[aC+(c[2385780]&(x&(l&65535)))|0]|0;c0=x;c1=n}}while(0);a[9707464]=c$;n=c[2426866]&65535&c0;x=c[9702704+(n>>>(c1>>>0)<<2)>>2]|0;do{if((x|0)==0){l=c[2385590]|0;if((l|0)==0){c2=0;break}c2=gj[l&4095](n&65535)|0}else{c2=a[x+(c[2385780]&n)|0]|0}}while(0);n=a[9660820]&c2;x=(n&255)>>>5&4|a[9660822]&-7;a[9660822]=n<<24>>24==0?x|2:x;break};case 182:{c[2426866]=0;x=b[4830406]|0;b[4830406]=x+1&65535;n=c[2443666]|0;l=c[3528996]|0;aC=c[9702704+((n&(x&65535))>>>(l>>>0)<<2)>>2]|0;do{if((aC|0)==0){aG=c[2385590]|0;if((aG|0)==0){c3=0;c4=n;c5=l;break}t=gj[aG&4095](n&(x&65535)&65535)|0;c3=t;c4=c[2443666]|0;c5=c[3528996]|0}else{c3=a[aC+(c[2385780]&(n&(x&65535)))|0]|0;c4=n;c5=l}}while(0);a[9707464]=c3;l=c[2426866]&65535&c4;n=c[9702704+(l>>>(c5>>>0)<<2)>>2]|0;do{if((n|0)==0){x=c[2385590]|0;if((x|0)==0){c6=0;break}c6=gj[x&4095](l&65535)|0}else{c6=a[n+(c[2385780]&l)|0]|0}}while(0);a[9660820]=c6;l=(c6&255)>>>5&4|a[9660822]&-7;a[9660822]=c6<<24>>24==0?l|2:l;break};case 27:{c[2426866]=0;l=b[4830406]|0;b[4830406]=l+1&65535;n=c[2443666]|0;x=c[3528996]|0;aC=c[9702704+((n&(l&65535))>>>(x>>>0)<<2)>>2]|0;do{if((aC|0)==0){t=c[2385590]|0;if((t|0)==0){c7=0;c8=n;c9=x;break}aG=gj[t&4095](n&(l&65535)&65535)|0;c7=aG;c8=c[2443666]|0;c9=c[3528996]|0}else{c7=a[aC+(c[2385780]&(n&(l&65535)))|0]|0;c8=n;c9=x}}while(0);a[9707464]=c7;x=c[2426866]|0;n=x&65535&c8;l=c[9702704+(n>>>(c9>>>0)<<2)>>2]|0;do{if((l|0)==0){aC=c[2385590]|0;if((aC|0)==0){da=0;db=x;dc=c8;dd=c9;break}aG=gj[aC&4095](n&65535)|0;da=aG;db=c[2426866]|0;dc=c[2443666]|0;dd=c[3528996]|0}else{da=a[l+(c[2385780]&n)|0]|0;db=x;dc=c8;dd=c9}}while(0);x=da&-33;n=db&65535&dc;l=c[9703728+(n>>>(dd>>>0)<<2)>>2]|0;if((l|0)!=0){a[l+(c[2385780]&n)|0]=x;break L46207}l=c[3528586]|0;if((l|0)==0){break L46207}gg[l&4095](n&65535,x);break};case 28:{c[2426866]=0;x=b[4830406]|0;b[4830406]=x+1&65535;n=c[2443666]|0;l=c[3528996]|0;aG=c[9702704+((n&(x&65535))>>>(l>>>0)<<2)>>2]|0;do{if((aG|0)==0){aC=c[2385590]|0;if((aC|0)==0){de=0;df=n;dg=l;break}t=gj[aC&4095](n&(x&65535)&65535)|0;de=t;df=c[2443666]|0;dg=c[3528996]|0}else{de=a[aG+(c[2385780]&(n&(x&65535)))|0]|0;df=n;dg=l}}while(0);a[9707464]=de;l=c[2426866]|0;n=l&65535&df;x=c[9702704+(n>>>(dg>>>0)<<2)>>2]|0;do{if((x|0)==0){aG=c[2385590]|0;if((aG|0)==0){dh=0;di=l;dj=df;dk=dg;break}t=gj[aG&4095](n&65535)|0;dh=t;di=c[2426866]|0;dj=c[2443666]|0;dk=c[3528996]|0}else{dh=a[x+(c[2385780]&n)|0]|0;di=l;dj=df;dk=dg}}while(0);l=dh|64;n=di&65535&dj;x=c[9703728+(n>>>(dk>>>0)<<2)>>2]|0;if((x|0)!=0){a[x+(c[2385780]&n)|0]=l;break L46207}x=c[3528586]|0;if((x|0)==0){break L46207}gg[x&4095](n&65535,l);break};case 26:{c[2426866]=0;l=b[4830406]|0;b[4830406]=l+1&65535;n=c[2443666]|0;x=c[3528996]|0;t=c[9702704+((n&(l&65535))>>>(x>>>0)<<2)>>2]|0;do{if((t|0)==0){aG=c[2385590]|0;if((aG|0)==0){dl=0;dm=n;dn=x;break}aC=gj[aG&4095](n&(l&65535)&65535)|0;dl=aC;dm=c[2443666]|0;dn=c[3528996]|0}else{dl=a[t+(c[2385780]&(n&(l&65535)))|0]|0;dm=n;dn=x}}while(0);a[9707464]=dl;x=c[2426866]|0;n=x&65535&dm;l=c[9702704+(n>>>(dn>>>0)<<2)>>2]|0;do{if((l|0)==0){t=c[2385590]|0;if((t|0)==0){dp=0;dq=x;dr=dm;ds=dn;break}aC=gj[t&4095](n&65535)|0;dp=aC;dq=c[2426866]|0;dr=c[2443666]|0;ds=c[3528996]|0}else{dp=a[l+(c[2385780]&n)|0]|0;dq=x;dr=dm;ds=dn}}while(0);x=dp|32;n=dq&65535&dr;l=c[9703728+(n>>>(ds>>>0)<<2)>>2]|0;if((l|0)!=0){a[l+(c[2385780]&n)|0]=x;break L46207}l=c[3528586]|0;if((l|0)==0){break L46207}gg[l&4095](n&65535,x);break};case 29:{c[2426866]=0;x=b[4830406]|0;b[4830406]=x+1&65535;n=c[2443666]|0;l=c[3528996]|0;aC=c[9702704+((n&(x&65535))>>>(l>>>0)<<2)>>2]|0;do{if((aC|0)==0){t=c[2385590]|0;if((t|0)==0){dt=0;du=n;dv=l;break}aG=gj[t&4095](n&(x&65535)&65535)|0;dt=aG;du=c[2443666]|0;dv=c[3528996]|0}else{dt=a[aC+(c[2385780]&(n&(x&65535)))|0]|0;du=n;dv=l}}while(0);a[9707464]=dt;l=c[2426866]|0;n=l&65535&du;x=c[9702704+(n>>>(dv>>>0)<<2)>>2]|0;do{if((x|0)==0){aC=c[2385590]|0;if((aC|0)==0){dw=0;dx=l;dy=du;dz=dv;break}aG=gj[aC&4095](n&65535)|0;dw=aG;dx=c[2426866]|0;dy=c[2443666]|0;dz=c[3528996]|0}else{dw=a[x+(c[2385780]&n)|0]|0;dx=l;dy=du;dz=dv}}while(0);l=dw&-65;n=dx&65535&dy;x=c[9703728+(n>>>(dz>>>0)<<2)>>2]|0;if((x|0)!=0){a[x+(c[2385780]&n)|0]=l;break L46207}x=c[3528586]|0;if((x|0)==0){break L46207}gg[x&4095](n&65535,l);break};case 30:{c[2426866]=0;l=b[4830406]|0;b[4830406]=l+1&65535;n=c[2443666]|0;x=c[3528996]|0;aG=c[9702704+((n&(l&65535))>>>(x>>>0)<<2)>>2]|0;do{if((aG|0)==0){aC=c[2385590]|0;if((aC|0)==0){dA=0;dB=n;dC=x;break}t=gj[aC&4095](n&(l&65535)&65535)|0;dA=t;dB=c[2443666]|0;dC=c[3528996]|0}else{dA=a[aG+(c[2385780]&(n&(l&65535)))|0]|0;dB=n;dC=x}}while(0);a[9707464]=dA;x=c[2426866]|0;n=x&65535&dB;l=c[9702704+(n>>>(dC>>>0)<<2)>>2]|0;do{if((l|0)==0){aG=c[2385590]|0;if((aG|0)==0){dD=0;dE=x;dF=dB;dG=dC;break}t=gj[aG&4095](n&65535)|0;dD=t;dE=c[2426866]|0;dF=c[2443666]|0;dG=c[3528996]|0}else{dD=a[l+(c[2385780]&n)|0]|0;dE=x;dF=dB;dG=dC}}while(0);x=dD|-128;n=dE&65535&dF;l=c[9703728+(n>>>(dG>>>0)<<2)>>2]|0;if((l|0)!=0){a[l+(c[2385780]&n)|0]=x;break L46207}l=c[3528586]|0;if((l|0)==0){break L46207}gg[l&4095](n&65535,x);break};case 31:{c[2426866]=0;x=b[4830406]|0;b[4830406]=x+1&65535;n=c[2443666]|0;l=c[3528996]|0;t=c[9702704+((n&(x&65535))>>>(l>>>0)<<2)>>2]|0;do{if((t|0)==0){aG=c[2385590]|0;if((aG|0)==0){dH=0;dI=n;dJ=l;break}aC=gj[aG&4095](n&(x&65535)&65535)|0;dH=aC;dI=c[2443666]|0;dJ=c[3528996]|0}else{dH=a[t+(c[2385780]&(n&(x&65535)))|0]|0;dI=n;dJ=l}}while(0);a[9707464]=dH;l=c[2426866]|0;n=l&65535&dI;x=c[9702704+(n>>>(dJ>>>0)<<2)>>2]|0;do{if((x|0)==0){t=c[2385590]|0;if((t|0)==0){dK=0;dL=l;dM=dI;dN=dJ;break}aC=gj[t&4095](n&65535)|0;dK=aC;dL=c[2426866]|0;dM=c[2443666]|0;dN=c[3528996]|0}else{dK=a[x+(c[2385780]&n)|0]|0;dL=l;dM=dI;dN=dJ}}while(0);l=dK&127;n=dL&65535&dM;x=c[9703728+(n>>>(dN>>>0)<<2)>>2]|0;if((x|0)!=0){a[x+(c[2385780]&n)|0]=l;break L46207}x=c[3528586]|0;if((x|0)==0){break L46207}gg[x&4095](n&65535,l);break};case 32:{l=b[4830406]|0;b[4830406]=l+1&65535;n=c[2443666]&(l&65535);x=c[9702704+(n>>>((c[3528996]|0)>>>0)<<2)>>2]|0;do{if((x|0)==0){aC=c[2385590]|0;if((aC|0)==0){dO=0;dP=l+1&65535;break}t=gj[aC&4095](n&65535)|0;dO=t;dP=b[4830406]|0}else{dO=a[x+(c[2385780]&n)|0]|0;dP=l+1&65535}}while(0);l=dO&255;b[4830406]=((l&128|0)!=0?l|65280:l)+(dP&65535)&65535;if(!(dO<<24>>24==-2&(c[1631650]|0)>0)){break L46207}c[1631650]=0;break};case 33:{l=b[4830406]|0;b[4830406]=l+1&65535;n=c[2443666]&(l&65535);if((c[9702704+(n>>>((c[3528996]|0)>>>0)<<2)>>2]|0)!=0){break L46207}l=c[2385590]|0;if((l|0)==0){break L46207}gj[l&4095](n&65535)|0;break};case 34:{n=b[4830406]|0;b[4830406]=n+1&65535;l=c[2443666]&(n&65535);n=c[9702704+(l>>>((c[3528996]|0)>>>0)<<2)>>2]|0;do{if((n|0)==0){x=c[2385590]|0;if((x|0)==0){dQ=0;break}dQ=gj[x&4095](l&65535)|0}else{dQ=a[n+(c[2385780]&l)|0]|0}}while(0);if((a[9660822]&3)!=0){break L46207}l=dQ&255;b[4830406]=(e[4830406]|0)+((l&128|0)!=0?l|65280:l)&65535;if(!(dQ<<24>>24==-2&(c[1631650]|0)>0)){break L46207}c[1631650]=0;break};case 183:{l=a[9660820]|0;n=(l&255)>>>5&4|a[9660822]&-7;a[9660822]=l<<24>>24==0?n|2:n;c[2426866]=0;n=b[4830406]|0;b[4830406]=n+1&65535;x=c[2443666]|0;t=c[3528996]|0;aC=c[9702704+((x&(n&65535))>>>(t>>>0)<<2)>>2]|0;do{if((aC|0)==0){aG=c[2385590]|0;if((aG|0)==0){dR=0;dS=l;dT=x;dU=t;break}dV=gj[aG&4095](x&(n&65535)&65535)|0;dR=dV;dS=a[9660820]|0;dT=c[2443666]|0;dU=c[3528996]|0}else{dR=a[aC+(c[2385780]&(x&(n&65535)))|0]|0;dS=l;dT=x;dU=t}}while(0);a[9707464]=dR;t=c[2426866]&65535&dT;x=c[9703728+(t>>>(dU>>>0)<<2)>>2]|0;if((x|0)!=0){a[x+(c[2385780]&t)|0]=dS;break L46207}x=c[3528586]|0;if((x|0)==0){break L46207}gg[x&4095](t&65535,dS);break};case 184:{c[2426866]=0;t=b[4830406]|0;b[4830406]=t+1&65535;x=c[2443666]|0;l=c[3528996]|0;n=c[9702704+((x&(t&65535))>>>(l>>>0)<<2)>>2]|0;do{if((n|0)==0){aC=c[2385590]|0;if((aC|0)==0){dW=0;dX=x;dY=l;break}dV=gj[aC&4095](x&(t&65535)&65535)|0;dW=dV;dX=c[2443666]|0;dY=c[3528996]|0}else{dW=a[n+(c[2385780]&(x&(t&65535)))|0]|0;dX=x;dY=l}}while(0);a[9707464]=dW;l=c[2426866]&65535&dX;x=c[9702704+(l>>>(dY>>>0)<<2)>>2]|0;do{if((x|0)==0){t=c[2385590]|0;if((t|0)==0){dZ=0;break}dZ=gj[t&4095](l&65535)|0}else{dZ=a[x+(c[2385780]&l)|0]|0}}while(0);l=a[9660820]|0;x=l^dZ;a[9660820]=x;t=(x&255)>>>5&4|a[9660822]&-7;a[9660822]=l<<24>>24==dZ<<24>>24?t|2:t;break};case 185:{c[2426866]=0;t=b[4830406]|0;b[4830406]=t+1&65535;l=c[2443666]|0;x=c[3528996]|0;n=c[9702704+((l&(t&65535))>>>(x>>>0)<<2)>>2]|0;do{if((n|0)==0){dV=c[2385590]|0;if((dV|0)==0){d_=0;d$=l;d0=x;break}aC=gj[dV&4095](l&(t&65535)&65535)|0;d_=aC;d$=c[2443666]|0;d0=c[3528996]|0}else{d_=a[n+(c[2385780]&(l&(t&65535)))|0]|0;d$=l;d0=x}}while(0);a[9707464]=d_;x=c[2426866]&65535&d$;l=c[9702704+(x>>>(d0>>>0)<<2)>>2]|0;do{if((l|0)==0){t=c[2385590]|0;if((t|0)==0){d1=0;break}d1=gj[t&4095](x&65535)|0}else{d1=a[l+(c[2385780]&x)|0]|0}}while(0);x=a[9660820]|0;l=a[9660822]|0;t=(x&255)+(d1&255)+(l&1)|0;a[9660822]=((t^(x^d1)&255)&16|t>>>8&1|((t&255)<<24>>24==0?(t>>>5&4|l&-24&255)&255|2:(t>>>5&4|l&-24&255)&255)&255)&255;a[9660820]=t&255;break};case 186:{c[2426866]=0;t=b[4830406]|0;b[4830406]=t+1&65535;l=c[2443666]|0;x=c[3528996]|0;n=c[9702704+((l&(t&65535))>>>(x>>>0)<<2)>>2]|0;do{if((n|0)==0){aC=c[2385590]|0;if((aC|0)==0){d2=0;d3=l;d4=x;break}dV=gj[aC&4095](l&(t&65535)&65535)|0;d2=dV;d3=c[2443666]|0;d4=c[3528996]|0}else{d2=a[n+(c[2385780]&(l&(t&65535)))|0]|0;d3=l;d4=x}}while(0);a[9707464]=d2;x=c[2426866]&65535&d3;l=c[9702704+(x>>>(d4>>>0)<<2)>>2]|0;do{if((l|0)==0){t=c[2385590]|0;if((t|0)==0){d5=0;break}d5=gj[t&4095](x&65535)|0}else{d5=a[l+(c[2385780]&x)|0]|0}}while(0);x=a[9660820]|d5;a[9660820]=x;l=(x&255)>>>5&4|a[9660822]&-7;a[9660822]=x<<24>>24==0?l|2:l;break};case 187:{c[2426866]=0;l=b[4830406]|0;b[4830406]=l+1&65535;x=c[2443666]|0;t=c[3528996]|0;n=c[9702704+((x&(l&65535))>>>(t>>>0)<<2)>>2]|0;do{if((n|0)==0){dV=c[2385590]|0;if((dV|0)==0){d6=0;d7=x;d8=t;break}aC=gj[dV&4095](x&(l&65535)&65535)|0;d6=aC;d7=c[2443666]|0;d8=c[3528996]|0}else{d6=a[n+(c[2385780]&(x&(l&65535)))|0]|0;d7=x;d8=t}}while(0);a[9707464]=d6;t=c[2426866]&65535&d7;x=c[9702704+(t>>>(d8>>>0)<<2)>>2]|0;do{if((x|0)==0){l=c[2385590]|0;if((l|0)==0){d9=0;break}d9=gj[l&4095](t&65535)|0}else{d9=a[x+(c[2385780]&t)|0]|0}}while(0);t=a[9660820]|0;x=(t&255)+(d9&255)|0;l=(x>>>5&4|a[9660822]&-24&255)&255;a[9660822]=(((t^d9)&255^x)&16|x>>>8&1|((x&255)<<24>>24==0?l|2:l)&255)&255;a[9660820]=x&255;break};case 188:{c[2426866]=0;x=b[4830406]|0;b[4830406]=x+1&65535;l=c[2443666]&(x&65535);x=c[9702704+(l>>>((c[3528996]|0)>>>0)<<2)>>2]|0;do{if((x|0)==0){t=c[2385590]|0;if((t|0)==0){ea=0;break}ea=gj[t&4095](l&65535)|0}else{ea=a[x+(c[2385780]&l)|0]|0}}while(0);a[9707464]=ea;b[4830406]=b[4853732]|0;break};case 189:{c[2426866]=0;l=b[4830406]|0;b[4830406]=l+1&65535;x=c[2443666]|0;t=c[3528996]|0;n=c[9702704+((x&(l&65535))>>>(t>>>0)<<2)>>2]|0;do{if((n|0)==0){aC=c[2385590]|0;if((aC|0)==0){eb=0;ec=l+1&65535&255;ed=x;ee=t;break}dV=gj[aC&4095](x&(l&65535)&65535)|0;eb=dV;ec=a[9660812]|0;ed=c[2443666]|0;ee=c[3528996]|0}else{eb=a[n+(c[2385780]&(x&(l&65535)))|0]|0;ec=l+1&65535&255;ed=x;ee=t}}while(0);a[9707464]=eb;t=ed&(e[4830408]|0);x=c[9703728+(t>>>(ee>>>0)<<2)>>2]|0;do{if((x|0)==0){l=c[3528586]|0;if((l|0)==0){break}gg[l&4095](t&65535,ec)}else{a[x+(c[2385780]&t)|0]=ec}}while(0);t=(b[4830408]|0)-1&65535;b[4830408]=t;if((t&65535)>>>0<(c[2415202]|0)>>>0){x=c[2415201]&65535;b[4830408]=x;ef=x}else{ef=t}t=a[9660813]|0;x=c[2443666]&(ef&65535);l=c[9703728+(x>>>((c[3528996]|0)>>>0)<<2)>>2]|0;do{if((l|0)==0){n=c[3528586]|0;if((n|0)==0){break}gg[n&4095](x&65535,t)}else{a[l+(c[2385780]&x)|0]=t}}while(0);t=(b[4830408]|0)-1&65535;b[4830408]=t;if((t&65535)>>>0<(c[2415202]|0)>>>0){b[4830408]=c[2415201]&65535}b[4830406]=b[4853732]|0;break};case 190:{c[2426866]=0;t=b[4830406]|0;b[4830406]=t+1&65535;x=c[2443666]|0;l=c[3528996]|0;n=c[9702704+((x&(t&65535))>>>(l>>>0)<<2)>>2]|0;do{if((n|0)==0){dV=c[2385590]|0;if((dV|0)==0){eg=0;eh=x;ei=l;break}aC=gj[dV&4095](x&(t&65535)&65535)|0;eg=aC;eh=c[2443666]|0;ei=c[3528996]|0}else{eg=a[n+(c[2385780]&(x&(t&65535)))|0]|0;eh=x;ei=l}}while(0);a[9707464]=eg;l=c[2426866]&65535&eh;x=c[9702704+(l>>>(ei>>>0)<<2)>>2]|0;do{if((x|0)==0){t=c[2385590]|0;if((t|0)==0){ej=0;break}ej=gj[t&4095](l&65535)|0}else{ej=a[x+(c[2385780]&l)|0]|0}}while(0);a[9660821]=ej;l=(ej&255)>>>5&4|a[9660822]&-7;a[9660822]=ej<<24>>24==0?l|2:l;break};case 191:{l=a[9660821]|0;x=(l&255)>>>5&4|a[9660822]&-7;a[9660822]=l<<24>>24==0?x|2:x;c[2426866]=0;x=b[4830406]|0;b[4830406]=x+1&65535;t=c[2443666]|0;n=c[3528996]|0;aC=c[9702704+((t&(x&65535))>>>(n>>>0)<<2)>>2]|0;do{if((aC|0)==0){dV=c[2385590]|0;if((dV|0)==0){ek=0;el=l;em=t;en=n;break}aG=gj[dV&4095](t&(x&65535)&65535)|0;ek=aG;el=a[9660821]|0;em=c[2443666]|0;en=c[3528996]|0}else{ek=a[aC+(c[2385780]&(t&(x&65535)))|0]|0;el=l;em=t;en=n}}while(0);a[9707464]=ek;n=c[2426866]&65535&em;t=c[9703728+(n>>>(en>>>0)<<2)>>2]|0;if((t|0)!=0){a[t+(c[2385780]&n)|0]=el;break L46207}t=c[3528586]|0;if((t|0)==0){break L46207}gg[t&4095](n&65535,el);break};case 192:{c[2426866]=0;n=b[4830406]|0;t=c[2443666]|0;l=c[3528996]|0;x=c[9702704+((t&(n&65535))>>>(l>>>0)<<2)>>2]|0;do{if((x|0)==0){aC=c[2385590]|0;if((aC|0)==0){eo=0;ep=n;eq=t;er=l;break}aG=gj[aC&4095](t&(n&65535)&65535)|0;eo=aG;ep=b[4830406]|0;eq=c[2443666]|0;er=c[3528996]|0}else{eo=a[x+(c[2385780]&(t&(n&65535)))|0]|0;ep=n;eq=t;er=l}}while(0);a[9707465]=eo;l=ep+1&65535&eq;t=c[9702704+(l>>>(er>>>0)<<2)>>2]|0;do{if((t|0)==0){n=c[2385590]|0;if((n|0)==0){es=0;et=ep;eu=eq;ev=er;break}x=gj[n&4095](l&65535)|0;es=x;et=b[4830406]|0;eu=c[2443666]|0;ev=c[3528996]|0}else{es=a[t+(c[2385780]&l)|0]|0;et=ep;eu=eq;ev=er}}while(0);a[9707464]=es;b[4830406]=et+2&65535;l=c[2426866]&65535&eu;t=c[9702704+(l>>>(ev>>>0)<<2)>>2]|0;do{if((t|0)==0){x=c[2385590]|0;if((x|0)==0){ew=0;break}ew=gj[x&4095](l&65535)|0}else{ew=a[t+(c[2385780]&l)|0]|0}}while(0);l=(d[9660820]|0)-(ew&255)&65535;t=((l&65535)>>>5&4|a[9660822]&-8&255)&255;a[9660822]=(((l&255)<<24>>24==0?t|2:t)&255|(l&65535)>>>8&1)&255;a[9660820]=l&255;break};default:{m=1}}}c[h+23416>>2]=m;c[h+23424>>2]=k;c[h+23432>>2]=0;c[h+23436>>2]=0;__Z8m6805Runi$0(h);m=c[h+23416>>2]|0;I=c[h+23432>>2]|0;B=c[h+23436>>2]|0;J=+g[h+23436>>2];c[h+23432>>2]=0;c[h+23436>>2]=0;if((I|0)==1){break}if((I|0)==2){switch(B|0){case 100:{break L46207}}}}while(0);l=d[669712+o|0]|0;j=(c[1631650]|0)-l|0;c[1631650]=j;c[2415218]=(c[2415218]|0)+l;}while((j|0)>0);i=h;return f-j|0}function f4Z(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;c[2426866]=0;f=b[4830406]|0;b[4830406]=f+1&65535;g=c[2443666]|0;h=g&(f&65535);f=h&65535;i=c[3528996]|0;j=c[9702704+(h>>>(i>>>0)<<2)>>2]|0;do{if((j|0)==0){k=c[2385590]|0;if((k|0)==0){l=0;m=g;n=i;break}o=gj[k&4095](f)|0;l=o;m=c[2443666]|0;n=c[3528996]|0}else{l=a[j+(c[2385780]&h)|0]|0;m=g;n=i}}while(0);a[9707464]=l;l=c[2426866]&65535&m;i=l&65535;g=c[9702704+(l>>>(n>>>0)<<2)>>2]|0;do{if((g|0)==0){h=c[2385590]|0;if((h|0)==0){p=0;q=m;r=n;break}j=gj[h&4095](i)|0;p=j;q=c[2443666]|0;r=c[3528996]|0}else{p=a[g+(c[2385780]&l)|0]|0;q=m;r=n}}while(0);n=b[4830406]|0;b[4830406]=n+1&65535;m=q&(n&65535);n=m&65535;q=c[9702704+(m>>>(r>>>0)<<2)>>2]|0;do{if((q|0)==0){r=c[2385590]|0;if((r|0)==0){s=0;break}s=gj[r&4095](n)|0}else{s=a[q+(c[2385780]&m)|0]|0}}while(0);m=a[9660822]|0;a[9660822]=m&-2;if((p&d)<<24>>24==0){return}a[9660822]=m|1;m=s&255;b[4830406]=(e[4830406]|0)+((m&128|0)!=0?m|65280:m)&65535;if(!(s<<24>>24==-3&(c[1631650]|0)>0)){return}c[1631650]=0;return}function f4_(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;c[2426866]=0;f=b[4830406]|0;b[4830406]=f+1&65535;g=c[2443666]|0;h=g&(f&65535);f=h&65535;i=c[3528996]|0;j=c[9702704+(h>>>(i>>>0)<<2)>>2]|0;do{if((j|0)==0){k=c[2385590]|0;if((k|0)==0){l=0;m=g;n=i;break}o=gj[k&4095](f)|0;l=o;m=c[2443666]|0;n=c[3528996]|0}else{l=a[j+(c[2385780]&h)|0]|0;m=g;n=i}}while(0);a[9707464]=l;l=c[2426866]&65535&m;i=l&65535;g=c[9702704+(l>>>(n>>>0)<<2)>>2]|0;do{if((g|0)==0){h=c[2385590]|0;if((h|0)==0){p=0;q=m;r=n;break}j=gj[h&4095](i)|0;p=j;q=c[2443666]|0;r=c[3528996]|0}else{p=a[g+(c[2385780]&l)|0]|0;q=m;r=n}}while(0);n=b[4830406]|0;b[4830406]=n+1&65535;m=q&(n&65535);n=m&65535;q=c[9702704+(m>>>(r>>>0)<<2)>>2]|0;do{if((q|0)==0){r=c[2385590]|0;if((r|0)==0){s=0;break}s=gj[r&4095](n)|0}else{s=a[q+(c[2385780]&m)|0]|0}}while(0);m=a[9660822]|0;a[9660822]=m|1;if((p&d)<<24>>24!=0){return}a[9660822]=m&-2;m=s&255;b[4830406]=(e[4830406]|0)+((m&128|0)!=0?m|65280:m)&65535;if(!(s<<24>>24==-3&(c[1631650]|0)>0)){return}c[1631650]=0;return}function f4$(){c[1631650]=0;return}function f40(){c[2415218]=0;return}function f41(){return c[2415218]|0}function f42(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=c[2415207]|0;gGz(9660800,0,76);c[2415207]=d;c[2415200]=0;c[2415201]=127;c[2415202]=96;b[4830408]=127;a[9660822]=8;c[2415203]=0;d=c[2443666]|0;e=d&65534;f=e&65535;g=c[3528996]|0;h=c[9702704+(e>>>(g>>>0)<<2)>>2]|0;do{if((h|0)==0){i=c[2385590]|0;if((i|0)==0){j=0;k=d;l=g;break}m=gj[i&4095](f)|0;j=m;k=c[2443666]|0;l=c[3528996]|0}else{j=a[h+(c[2385780]&e)|0]|0;k=d;l=g}}while(0);a[9660813]=j;j=k&65535;do{if((c[9702704+((k&65535)>>>(l>>>0)<<2)>>2]|0)==0){g=c[2385590]|0;if((g|0)==0){n=k;o=l;break}gj[g&4095](j)|0;n=c[2443666]|0;o=c[3528996]|0}else{n=k;o=l}}while(0);c[2415200]=1;c[2415203]=0;l=n&65534;k=l&65535;j=c[9702704+(l>>>(o>>>0)<<2)>>2]|0;do{if((j|0)==0){g=c[2385590]|0;if((g|0)==0){p=0;q=n;r=o;break}d=gj[g&4095](k)|0;p=d;q=c[2443666]|0;r=c[3528996]|0}else{p=a[j+(c[2385780]&l)|0]|0;q=n;r=o}}while(0);a[9660813]=p;p=q&65535;o=c[9702704+(p>>>(r>>>0)<<2)>>2]|0;if((o|0)!=0){s=a[o+(c[2385780]&p)|0]|0;a[9660812]=s;return}p=c[2385590]|0;if((p|0)==0){s=0;a[9660812]=s;return}s=gj[p&4095](q&65535)|0;a[9660812]=s;return}function f43(e){e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0;if((e|0)!=0){gGC(9660752,e|0,48)|0}e=c[2415188]|0;b[4830376]=e&65535;f=a[9660786]|0;g=a[9660787]|0;h=e&255;if((g|f)<<24>>24!=0){a[9660796]=a[9660796]&-17}do{if(g<<24>>24!=0){e=a[9660784]|0;if((e&64)!=0){break}i=a[9660796]|0;if((i&8)==0){a[9660784]=e&127;b[4830386]=(b[4830386]|0)-1&65535;j=c[2415193]|0;k=j&65535;l=c[3528554]|0;m=c[2433592]|0;n=c[m+(l*3148|0)+48+((j>>>8&255|256)<<2)>>2]|0;do{if((n|0)==0){o=c[m+(l*3148|0)+3124>>2]|0;if((o|0)==0){p=l;q=m;break}gg[o&4095](k,h);p=c[3528554]|0;q=c[2433592]|0}else{a[n+(j&255)|0]=h;p=l;q=m}}while(0);b[4830386]=(b[4830386]|0)-1&65535;m=c[2415193]|0;l=m&65535;j=a[9660753]|0;n=c[q+(p*3148|0)+48+((m>>>8&255|256)<<2)>>2]|0;do{if((n|0)==0){k=c[q+(p*3148|0)+3124>>2]|0;if((k|0)==0){r=p;s=q;break}gg[k&4095](l,j);r=c[3528554]|0;s=c[2433592]|0}else{a[n+(m&255)|0]=j;r=p;s=q}}while(0);b[4830386]=(b[4830386]|0)-1&65535;j=c[2415193]|0;m=j&65535;n=a[9660784]|0;l=c[s+(r*3148|0)+48+((j>>>8&255|256)<<2)>>2]|0;do{if((l|0)==0){k=c[s+(r*3148|0)+3124>>2]|0;if((k|0)==0){break}gg[k&4095](m,n)}else{a[l+(j&255)|0]=n}}while(0);t=(c[2415197]|0)+10|0;u=a[9660784]|0}else{a[9660796]=i&-9;t=(c[2415197]|0)+7|0;u=e}c[2415197]=t;a[9660784]=u|80;n=c[3528554]|0;j=c[2433592]|0;l=c[j+(n*3148|0)+1068>>2]|0;do{if((l|0)==0){m=c[j+(n*3148|0)+3120>>2]|0;if((m|0)==0){v=0;w=0;break}k=gj[m&4095](-10)|0;m=c[3528554]|0;o=c[2433592]|0;x=c[o+(m*3148|0)+1068>>2]|0;y=(k&255)<<8;if((x|0)!=0){z=x;A=y;B=39486;break}x=c[o+(m*3148|0)+3120>>2]|0;if((x|0)==0){v=0;w=y;break}v=gj[x&4095](-9)|0;w=y}else{z=l;A=(d[l+246|0]|0)<<8;B=39486}}while(0);if((B|0)==39486){v=a[z+247|0]|0;w=A}l=v&255|w;c[2415188]=l;b[4830376]=l&65535;return}}while(0);if(f<<24>>24==0){return}f=a[9660784]|0;if((f&16)!=0){return}w=a[9660796]|0;if((w&8)==0){a[9660784]=f|-128;b[4830386]=(b[4830386]|0)-1&65535;v=c[2415193]|0;A=v&65535;z=c[3528554]|0;u=c[2433592]|0;t=c[u+(z*3148|0)+48+((v>>>8&255|256)<<2)>>2]|0;do{if((t|0)==0){r=c[u+(z*3148|0)+3124>>2]|0;if((r|0)==0){C=z;D=u;break}gg[r&4095](A,h);C=c[3528554]|0;D=c[2433592]|0}else{a[t+(v&255)|0]=h;C=z;D=u}}while(0);b[4830386]=(b[4830386]|0)-1&65535;u=c[2415193]|0;z=u&65535;h=a[9660753]|0;v=c[D+(C*3148|0)+48+((u>>>8&255|256)<<2)>>2]|0;do{if((v|0)==0){t=c[D+(C*3148|0)+3124>>2]|0;if((t|0)==0){E=C;F=D;break}gg[t&4095](z,h);E=c[3528554]|0;F=c[2433592]|0}else{a[v+(u&255)|0]=h;E=C;F=D}}while(0);b[4830386]=(b[4830386]|0)-1&65535;D=c[2415193]|0;C=D&65535;h=a[9660768]|0;u=c[F+(E*3148|0)+48+((D>>>8&255|256)<<2)>>2]|0;do{if((u|0)==0){v=c[F+(E*3148|0)+3124>>2]|0;if((v|0)==0){G=E;H=F;break}gg[v&4095](C,h);G=c[3528554]|0;H=c[2433592]|0}else{a[u+(D&255)|0]=h;G=E;H=F}}while(0);b[4830386]=(b[4830386]|0)-1&65535;F=c[2415193]|0;E=F&65535;h=a[9660769]|0;D=c[H+(G*3148|0)+48+((F>>>8&255|256)<<2)>>2]|0;do{if((D|0)==0){u=c[H+(G*3148|0)+3124>>2]|0;if((u|0)==0){I=G;J=H;break}gg[u&4095](E,h);I=c[3528554]|0;J=c[2433592]|0}else{a[D+(F&255)|0]=h;I=G;J=H}}while(0);b[4830386]=(b[4830386]|0)-1&65535;H=c[2415193]|0;G=H&65535;h=a[9660780]|0;F=c[J+(I*3148|0)+48+((H>>>8&255|256)<<2)>>2]|0;do{if((F|0)==0){D=c[J+(I*3148|0)+3124>>2]|0;if((D|0)==0){K=I;L=J;break}gg[D&4095](G,h);K=c[3528554]|0;L=c[2433592]|0}else{a[F+(H&255)|0]=h;K=I;L=J}}while(0);b[4830386]=(b[4830386]|0)-1&65535;J=c[2415193]|0;I=J&65535;h=a[9660781]|0;H=c[L+(K*3148|0)+48+((J>>>8&255|256)<<2)>>2]|0;do{if((H|0)==0){F=c[L+(K*3148|0)+3124>>2]|0;if((F|0)==0){M=K;N=L;break}gg[F&4095](I,h);M=c[3528554]|0;N=c[2433592]|0}else{a[H+(J&255)|0]=h;M=K;N=L}}while(0);b[4830386]=(b[4830386]|0)-1&65535;L=c[2415193]|0;K=L&65535;h=a[9660776]|0;J=c[N+(M*3148|0)+48+((L>>>8&255|256)<<2)>>2]|0;do{if((J|0)==0){H=c[N+(M*3148|0)+3124>>2]|0;if((H|0)==0){O=M;P=N;break}gg[H&4095](K,h);O=c[3528554]|0;P=c[2433592]|0}else{a[J+(L&255)|0]=h;O=M;P=N}}while(0);b[4830386]=(b[4830386]|0)-1&65535;N=c[2415193]|0;M=N&65535;h=a[9660777]|0;L=c[P+(O*3148|0)+48+((N>>>8&255|256)<<2)>>2]|0;do{if((L|0)==0){J=c[P+(O*3148|0)+3124>>2]|0;if((J|0)==0){Q=O;R=P;break}gg[J&4095](M,h);Q=c[3528554]|0;R=c[2433592]|0}else{a[L+(N&255)|0]=h;Q=O;R=P}}while(0);b[4830386]=(b[4830386]|0)-1&65535;P=c[2415193]|0;O=P&65535;h=a[9660765]|0;N=c[R+(Q*3148|0)+48+((P>>>8&255|256)<<2)>>2]|0;do{if((N|0)==0){L=c[R+(Q*3148|0)+3124>>2]|0;if((L|0)==0){S=Q;T=R;break}gg[L&4095](O,h);S=c[3528554]|0;T=c[2433592]|0}else{a[N+(P&255)|0]=h;S=Q;T=R}}while(0);b[4830386]=(b[4830386]|0)-1&65535;R=c[2415193]|0;Q=R&65535;h=a[9660760]|0;P=c[T+(S*3148|0)+48+((R>>>8&255|256)<<2)>>2]|0;do{if((P|0)==0){N=c[T+(S*3148|0)+3124>>2]|0;if((N|0)==0){U=S;V=T;break}gg[N&4095](Q,h);U=c[3528554]|0;V=c[2433592]|0}else{a[P+(R&255)|0]=h;U=S;V=T}}while(0);b[4830386]=(b[4830386]|0)-1&65535;T=c[2415193]|0;S=T&65535;h=a[9660761]|0;R=c[V+(U*3148|0)+48+((T>>>8&255|256)<<2)>>2]|0;do{if((R|0)==0){P=c[V+(U*3148|0)+3124>>2]|0;if((P|0)==0){W=U;X=V;break}gg[P&4095](S,h);W=c[3528554]|0;X=c[2433592]|0}else{a[R+(T&255)|0]=h;W=U;X=V}}while(0);b[4830386]=(b[4830386]|0)-1&65535;V=c[2415193]|0;U=V&65535;h=a[9660784]|0;T=c[X+(W*3148|0)+48+((V>>>8&255|256)<<2)>>2]|0;do{if((T|0)==0){R=c[X+(W*3148|0)+3124>>2]|0;if((R|0)==0){break}gg[R&4095](U,h)}else{a[T+(V&255)|0]=h}}while(0);Y=(c[2415197]|0)+19|0;Z=a[9660784]|0}else{a[9660796]=w&-9;Y=(c[2415197]|0)+7|0;Z=f}c[2415197]=Y;a[9660784]=Z|16;Z=c[3528554]|0;Y=c[2433592]|0;f=c[Y+(Z*3148|0)+1068>>2]|0;do{if((f|0)==0){w=c[Y+(Z*3148|0)+3120>>2]|0;if((w|0)==0){_=0;$=0;break}h=gj[w&4095](-8)|0;w=c[3528554]|0;V=c[2433592]|0;T=c[V+(w*3148|0)+1068>>2]|0;U=(h&255)<<8;if((T|0)!=0){aa=T;ab=U;B=39547;break}T=c[V+(w*3148|0)+3120>>2]|0;if((T|0)==0){_=0;$=U;break}_=gj[T&4095](-7)|0;$=U}else{aa=f;ab=(d[f+248|0]|0)<<8;B=39547}}while(0);if((B|0)==39547){_=a[aa+249|0]|0;$=ab}ab=_&255|$;c[2415188]=ab;b[4830376]=ab&65535;return}function f44(e){e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0;if((e|0)==32){if((a[9660797]|0)==1){return}a[9660797]=1;f=a[9660796]|0;if((f&32)==0){return}a[9660796]=f&-17;if((f&8)==0){a[9660784]=a[9660784]|-128;b[4830386]=(b[4830386]|0)-1&65535;g=c[2415193]|0;h=g&65535;i=a[9660752]|0;j=c[3528554]|0;k=c[2433592]|0;l=c[k+(j*3148|0)+48+((g>>>8&255|256)<<2)>>2]|0;do{if((l|0)==0){m=c[k+(j*3148|0)+3124>>2]|0;if((m|0)==0){n=j;o=k;break}gg[m&4095](h,i);n=c[3528554]|0;o=c[2433592]|0}else{a[l+(g&255)|0]=i;n=j;o=k}}while(0);b[4830386]=(b[4830386]|0)-1&65535;k=c[2415193]|0;j=k&65535;i=a[9660753]|0;g=c[o+(n*3148|0)+48+((k>>>8&255|256)<<2)>>2]|0;do{if((g|0)==0){l=c[o+(n*3148|0)+3124>>2]|0;if((l|0)==0){p=n;q=o;break}gg[l&4095](j,i);p=c[3528554]|0;q=c[2433592]|0}else{a[g+(k&255)|0]=i;p=n;q=o}}while(0);b[4830386]=(b[4830386]|0)-1&65535;o=c[2415193]|0;n=o&65535;i=a[9660768]|0;k=c[q+(p*3148|0)+48+((o>>>8&255|256)<<2)>>2]|0;do{if((k|0)==0){g=c[q+(p*3148|0)+3124>>2]|0;if((g|0)==0){r=p;s=q;break}gg[g&4095](n,i);r=c[3528554]|0;s=c[2433592]|0}else{a[k+(o&255)|0]=i;r=p;s=q}}while(0);b[4830386]=(b[4830386]|0)-1&65535;q=c[2415193]|0;p=q&65535;i=a[9660769]|0;o=c[s+(r*3148|0)+48+((q>>>8&255|256)<<2)>>2]|0;do{if((o|0)==0){k=c[s+(r*3148|0)+3124>>2]|0;if((k|0)==0){t=r;u=s;break}gg[k&4095](p,i);t=c[3528554]|0;u=c[2433592]|0}else{a[o+(q&255)|0]=i;t=r;u=s}}while(0);b[4830386]=(b[4830386]|0)-1&65535;s=c[2415193]|0;r=s&65535;i=a[9660780]|0;q=c[u+(t*3148|0)+48+((s>>>8&255|256)<<2)>>2]|0;do{if((q|0)==0){o=c[u+(t*3148|0)+3124>>2]|0;if((o|0)==0){v=t;w=u;break}gg[o&4095](r,i);v=c[3528554]|0;w=c[2433592]|0}else{a[q+(s&255)|0]=i;v=t;w=u}}while(0);b[4830386]=(b[4830386]|0)-1&65535;u=c[2415193]|0;t=u&65535;i=a[9660781]|0;s=c[w+(v*3148|0)+48+((u>>>8&255|256)<<2)>>2]|0;do{if((s|0)==0){q=c[w+(v*3148|0)+3124>>2]|0;if((q|0)==0){x=v;y=w;break}gg[q&4095](t,i);x=c[3528554]|0;y=c[2433592]|0}else{a[s+(u&255)|0]=i;x=v;y=w}}while(0);b[4830386]=(b[4830386]|0)-1&65535;w=c[2415193]|0;v=w&65535;i=a[9660776]|0;u=c[y+(x*3148|0)+48+((w>>>8&255|256)<<2)>>2]|0;do{if((u|0)==0){s=c[y+(x*3148|0)+3124>>2]|0;if((s|0)==0){z=x;A=y;break}gg[s&4095](v,i);z=c[3528554]|0;A=c[2433592]|0}else{a[u+(w&255)|0]=i;z=x;A=y}}while(0);b[4830386]=(b[4830386]|0)-1&65535;y=c[2415193]|0;x=y&65535;i=a[9660777]|0;w=c[A+(z*3148|0)+48+((y>>>8&255|256)<<2)>>2]|0;do{if((w|0)==0){u=c[A+(z*3148|0)+3124>>2]|0;if((u|0)==0){B=z;C=A;break}gg[u&4095](x,i);B=c[3528554]|0;C=c[2433592]|0}else{a[w+(y&255)|0]=i;B=z;C=A}}while(0);b[4830386]=(b[4830386]|0)-1&65535;A=c[2415193]|0;z=A&65535;i=a[9660765]|0;y=c[C+(B*3148|0)+48+((A>>>8&255|256)<<2)>>2]|0;do{if((y|0)==0){w=c[C+(B*3148|0)+3124>>2]|0;if((w|0)==0){D=B;E=C;break}gg[w&4095](z,i);D=c[3528554]|0;E=c[2433592]|0}else{a[y+(A&255)|0]=i;D=B;E=C}}while(0);b[4830386]=(b[4830386]|0)-1&65535;C=c[2415193]|0;B=C&65535;i=a[9660760]|0;A=c[E+(D*3148|0)+48+((C>>>8&255|256)<<2)>>2]|0;do{if((A|0)==0){y=c[E+(D*3148|0)+3124>>2]|0;if((y|0)==0){F=D;G=E;break}gg[y&4095](B,i);F=c[3528554]|0;G=c[2433592]|0}else{a[A+(C&255)|0]=i;F=D;G=E}}while(0);b[4830386]=(b[4830386]|0)-1&65535;E=c[2415193]|0;D=E&65535;i=a[9660761]|0;C=c[G+(F*3148|0)+48+((E>>>8&255|256)<<2)>>2]|0;do{if((C|0)==0){A=c[G+(F*3148|0)+3124>>2]|0;if((A|0)==0){H=F;I=G;break}gg[A&4095](D,i);H=c[3528554]|0;I=c[2433592]|0}else{a[C+(E&255)|0]=i;H=F;I=G}}while(0);b[4830386]=(b[4830386]|0)-1&65535;G=c[2415193]|0;F=G&65535;i=a[9660784]|0;E=c[I+(H*3148|0)+48+((G>>>8&255|256)<<2)>>2]|0;do{if((E|0)==0){C=c[I+(H*3148|0)+3124>>2]|0;if((C|0)==0){break}gg[C&4095](F,i)}else{a[E+(G&255)|0]=i}}while(0);J=(c[2415197]|0)+19|0}else{a[9660796]=f&-25;J=(c[2415197]|0)+7|0}c[2415197]=J;a[9660784]=a[9660784]|80;J=c[3528554]|0;f=c[2433592]|0;i=c[f+(J*3148|0)+1068>>2]|0;do{if((i|0)==0){G=c[f+(J*3148|0)+3120>>2]|0;if((G|0)==0){K=0;L=0;break}E=gj[G&4095](-4)|0;G=c[3528554]|0;F=c[2433592]|0;H=c[F+(G*3148|0)+1068>>2]|0;I=(E&255)<<8;if((H|0)!=0){M=H;N=I;O=39614;break}H=c[F+(G*3148|0)+3120>>2]|0;if((H|0)==0){K=0;L=I;break}K=gj[H&4095](-3)|0;L=I}else{M=i;N=d[i+252|0]<<8;O=39614}}while(0);if((O|0)==39614){K=a[M+253|0]|0;L=N}N=K&255|L;c[2415188]=N;b[4830376]=N&65535;return}if((e|0)>=2){return}a[9660786+e|0]=1;e=a[9660786]|0;N=a[9660787]|0;if((N|e)<<24>>24!=0){a[9660796]=a[9660796]&-17}do{if(N<<24>>24!=0){L=a[9660784]|0;if((L&64)!=0){break}K=a[9660796]|0;if((K&8)==0){a[9660784]=L&127;b[4830386]=(b[4830386]|0)-1&65535;M=c[2415193]|0;i=M&65535;J=a[9660752]|0;f=c[3528554]|0;I=c[2433592]|0;H=c[I+(f*3148|0)+48+((M>>>8&255|256)<<2)>>2]|0;do{if((H|0)==0){G=c[I+(f*3148|0)+3124>>2]|0;if((G|0)==0){P=f;Q=I;break}gg[G&4095](i,J);P=c[3528554]|0;Q=c[2433592]|0}else{a[H+(M&255)|0]=J;P=f;Q=I}}while(0);b[4830386]=(b[4830386]|0)-1&65535;I=c[2415193]|0;f=I&65535;J=a[9660753]|0;M=c[Q+(P*3148|0)+48+((I>>>8&255|256)<<2)>>2]|0;do{if((M|0)==0){H=c[Q+(P*3148|0)+3124>>2]|0;if((H|0)==0){R=P;S=Q;break}gg[H&4095](f,J);R=c[3528554]|0;S=c[2433592]|0}else{a[M+(I&255)|0]=J;R=P;S=Q}}while(0);b[4830386]=(b[4830386]|0)-1&65535;J=c[2415193]|0;I=J&65535;M=a[9660784]|0;f=c[S+(R*3148|0)+48+((J>>>8&255|256)<<2)>>2]|0;do{if((f|0)==0){H=c[S+(R*3148|0)+3124>>2]|0;if((H|0)==0){break}gg[H&4095](I,M)}else{a[f+(J&255)|0]=M}}while(0);T=(c[2415197]|0)+10|0;U=a[9660784]|0}else{a[9660796]=K&-9;T=(c[2415197]|0)+7|0;U=L}c[2415197]=T;a[9660784]=U|80;M=c[3528554]|0;J=c[2433592]|0;f=c[J+(M*3148|0)+1068>>2]|0;do{if((f|0)==0){I=c[J+(M*3148|0)+3120>>2]|0;if((I|0)==0){V=0;W=0;break}H=gj[I&4095](-10)|0;I=c[3528554]|0;i=c[2433592]|0;G=c[i+(I*3148|0)+1068>>2]|0;F=(H&255)<<8;if((G|0)!=0){X=G;Y=F;O=39642;break}G=c[i+(I*3148|0)+3120>>2]|0;if((G|0)==0){V=0;W=F;break}V=gj[G&4095](-9)|0;W=F}else{X=f;Y=d[f+246|0]<<8;O=39642}}while(0);if((O|0)==39642){V=a[X+247|0]|0;W=Y}f=V&255|W;c[2415188]=f;b[4830376]=f&65535;return}}while(0);if(e<<24>>24==0){return}e=a[9660784]|0;if((e&16)!=0){return}W=a[9660796]|0;if((W&8)==0){a[9660784]=e|-128;b[4830386]=(b[4830386]|0)-1&65535;V=c[2415193]|0;Y=V&65535;X=a[9660752]|0;U=c[3528554]|0;T=c[2433592]|0;R=c[T+(U*3148|0)+48+((V>>>8&255|256)<<2)>>2]|0;do{if((R|0)==0){S=c[T+(U*3148|0)+3124>>2]|0;if((S|0)==0){Z=U;_=T;break}gg[S&4095](Y,X);Z=c[3528554]|0;_=c[2433592]|0}else{a[R+(V&255)|0]=X;Z=U;_=T}}while(0);b[4830386]=(b[4830386]|0)-1&65535;T=c[2415193]|0;U=T&65535;X=a[9660753]|0;V=c[_+(Z*3148|0)+48+((T>>>8&255|256)<<2)>>2]|0;do{if((V|0)==0){R=c[_+(Z*3148|0)+3124>>2]|0;if((R|0)==0){$=Z;aa=_;break}gg[R&4095](U,X);$=c[3528554]|0;aa=c[2433592]|0}else{a[V+(T&255)|0]=X;$=Z;aa=_}}while(0);b[4830386]=(b[4830386]|0)-1&65535;_=c[2415193]|0;Z=_&65535;X=a[9660768]|0;T=c[aa+($*3148|0)+48+((_>>>8&255|256)<<2)>>2]|0;do{if((T|0)==0){V=c[aa+($*3148|0)+3124>>2]|0;if((V|0)==0){ab=$;ac=aa;break}gg[V&4095](Z,X);ab=c[3528554]|0;ac=c[2433592]|0}else{a[T+(_&255)|0]=X;ab=$;ac=aa}}while(0);b[4830386]=(b[4830386]|0)-1&65535;aa=c[2415193]|0;$=aa&65535;X=a[9660769]|0;_=c[ac+(ab*3148|0)+48+((aa>>>8&255|256)<<2)>>2]|0;do{if((_|0)==0){T=c[ac+(ab*3148|0)+3124>>2]|0;if((T|0)==0){ad=ab;ae=ac;break}gg[T&4095]($,X);ad=c[3528554]|0;ae=c[2433592]|0}else{a[_+(aa&255)|0]=X;ad=ab;ae=ac}}while(0);b[4830386]=(b[4830386]|0)-1&65535;ac=c[2415193]|0;ab=ac&65535;X=a[9660780]|0;aa=c[ae+(ad*3148|0)+48+((ac>>>8&255|256)<<2)>>2]|0;do{if((aa|0)==0){_=c[ae+(ad*3148|0)+3124>>2]|0;if((_|0)==0){af=ad;ag=ae;break}gg[_&4095](ab,X);af=c[3528554]|0;ag=c[2433592]|0}else{a[aa+(ac&255)|0]=X;af=ad;ag=ae}}while(0);b[4830386]=(b[4830386]|0)-1&65535;ae=c[2415193]|0;ad=ae&65535;X=a[9660781]|0;ac=c[ag+(af*3148|0)+48+((ae>>>8&255|256)<<2)>>2]|0;do{if((ac|0)==0){aa=c[ag+(af*3148|0)+3124>>2]|0;if((aa|0)==0){ah=af;ai=ag;break}gg[aa&4095](ad,X);ah=c[3528554]|0;ai=c[2433592]|0}else{a[ac+(ae&255)|0]=X;ah=af;ai=ag}}while(0);b[4830386]=(b[4830386]|0)-1&65535;ag=c[2415193]|0;af=ag&65535;X=a[9660776]|0;ae=c[ai+(ah*3148|0)+48+((ag>>>8&255|256)<<2)>>2]|0;do{if((ae|0)==0){ac=c[ai+(ah*3148|0)+3124>>2]|0;if((ac|0)==0){aj=ah;ak=ai;break}gg[ac&4095](af,X);aj=c[3528554]|0;ak=c[2433592]|0}else{a[ae+(ag&255)|0]=X;aj=ah;ak=ai}}while(0);b[4830386]=(b[4830386]|0)-1&65535;ai=c[2415193]|0;ah=ai&65535;X=a[9660777]|0;ag=c[ak+(aj*3148|0)+48+((ai>>>8&255|256)<<2)>>2]|0;do{if((ag|0)==0){ae=c[ak+(aj*3148|0)+3124>>2]|0;if((ae|0)==0){al=aj;am=ak;break}gg[ae&4095](ah,X);al=c[3528554]|0;am=c[2433592]|0}else{a[ag+(ai&255)|0]=X;al=aj;am=ak}}while(0);b[4830386]=(b[4830386]|0)-1&65535;ak=c[2415193]|0;aj=ak&65535;X=a[9660765]|0;ai=c[am+(al*3148|0)+48+((ak>>>8&255|256)<<2)>>2]|0;do{if((ai|0)==0){ag=c[am+(al*3148|0)+3124>>2]|0;if((ag|0)==0){an=al;ao=am;break}gg[ag&4095](aj,X);an=c[3528554]|0;ao=c[2433592]|0}else{a[ai+(ak&255)|0]=X;an=al;ao=am}}while(0);b[4830386]=(b[4830386]|0)-1&65535;am=c[2415193]|0;al=am&65535;X=a[9660760]|0;ak=c[ao+(an*3148|0)+48+((am>>>8&255|256)<<2)>>2]|0;do{if((ak|0)==0){ai=c[ao+(an*3148|0)+3124>>2]|0;if((ai|0)==0){ap=an;aq=ao;break}gg[ai&4095](al,X);ap=c[3528554]|0;aq=c[2433592]|0}else{a[ak+(am&255)|0]=X;ap=an;aq=ao}}while(0);b[4830386]=(b[4830386]|0)-1&65535;ao=c[2415193]|0;an=ao&65535;X=a[9660761]|0;am=c[aq+(ap*3148|0)+48+((ao>>>8&255|256)<<2)>>2]|0;do{if((am|0)==0){ak=c[aq+(ap*3148|0)+3124>>2]|0;if((ak|0)==0){ar=ap;as=aq;break}gg[ak&4095](an,X);ar=c[3528554]|0;as=c[2433592]|0}else{a[am+(ao&255)|0]=X;ar=ap;as=aq}}while(0);b[4830386]=(b[4830386]|0)-1&65535;aq=c[2415193]|0;ap=aq&65535;X=a[9660784]|0;ao=c[as+(ar*3148|0)+48+((aq>>>8&255|256)<<2)>>2]|0;do{if((ao|0)==0){am=c[as+(ar*3148|0)+3124>>2]|0;if((am|0)==0){break}gg[am&4095](ap,X)}else{a[ao+(aq&255)|0]=X}}while(0);at=(c[2415197]|0)+19|0;au=a[9660784]|0}else{a[9660796]=W&-9;at=(c[2415197]|0)+7|0;au=e}c[2415197]=at;a[9660784]=au|16;au=c[3528554]|0;at=c[2433592]|0;e=c[at+(au*3148|0)+1068>>2]|0;do{if((e|0)==0){W=c[at+(au*3148|0)+3120>>2]|0;if((W|0)==0){av=0;aw=0;break}X=gj[W&4095](-8)|0;W=c[3528554]|0;aq=c[2433592]|0;ao=c[aq+(W*3148|0)+1068>>2]|0;ap=(X&255)<<8;if((ao|0)!=0){ax=ao;ay=ap;O=39703;break}ao=c[aq+(W*3148|0)+3120>>2]|0;if((ao|0)==0){av=0;aw=ap;break}av=gj[ao&4095](-7)|0;aw=ap}else{ax=e;ay=d[e+248|0]<<8;O=39703}}while(0);if((O|0)==39703){av=a[ax+249|0]|0;aw=ay}ay=av&255|aw;c[2415188]=ay;b[4830376]=ay&65535;return}function __Z13m6800_executei$0(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0,cf=0,cg=0,ch=0,ci=0,cj=0,ck=0,cl=0,cm=0,cn=0,co=0,cp=0,cq=0,cr=0,cs=0,ct=0,cu=0,cv=0,cw=0,cx=0,cy=0,cz=0,cA=0,cB=0,cC=0,cD=0,cE=0,cF=0,cG=0,cH=0,cI=0,cJ=0,cK=0,cL=0,cM=0,cN=0,cO=0,cP=0,cQ=0,cR=0,cS=0,cT=0,cU=0,cV=0,cW=0,cX=0,cY=0,cZ=0,c_=0,c$=0,c0=0,c1=0,c2=0,c3=0,c4=0,c5=0,c6=0,c7=0,c8=0,c9=0,da=0,db=0,dc=0,dd=0,de=0,df=0,dg=0,dh=0,di=0,dj=0,dk=0,dl=0,dm=0,dn=0,dp=0,dq=0,dr=0,ds=0,dt=0,du=0,dv=0,dw=0,dx=0,dy=0,dz=0,dA=0,dB=0,dC=0,dD=0,dE=0,dF=0,dG=0,dH=0,dI=0,dJ=0,dK=0,dL=0,dM=0,dN=0,dO=0,dP=0,dQ=0,dR=0,dS=0,dT=0,dU=0,dV=0,dW=0,dX=0,dY=0,dZ=0,d_=0,d$=0,d0=0,d1=0,d2=0,d3=0,d4=0,d5=0,d6=0,d7=0,d8=0,d9=0,ea=0,eb=0,ec=0,ed=0,ee=0,ef=0,eg=0,eh=0,ei=0,ej=0,ek=0,el=0,em=0,en=0,eo=0,ep=0,eq=0,er=0,es=0,et=0,eu=0,ev=0,ew=0,ex=0,ey=0,ez=0,eA=0,eB=0,eC=0,eD=0,eE=0,eF=0,eG=0,eH=0,eI=0,eJ=0,eK=0,eL=0,eM=0,eN=0,eO=0,eP=0,eQ=0,eR=0,eS=0,eT=0,eU=0,eV=0,eW=0,eX=0,eY=0,eZ=0,e_=0,e$=0,e0=0,e1=0,e2=0,e3=0,e4=0,e5=0,e6=0,e7=0,e8=0,e9=0,fa=0,fb=0,fc=0,fd=0,fe=0,ff=0,fg=0,fh=0,fi=0,fj=0,fk=0,fl=0,fm=0,fn=0,fo=0,fp=0,fq=0,fr=0,fs=0,ft=0,fu=0,fv=0,fw=0,fx=0,fy=0,fz=0,fA=0,fB=0,fC=0,fD=0,fE=0,fF=0,fG=0,fH=0,fI=0,fJ=0,fK=0,fL=0,fM=0,fN=0,fO=0,fP=0,fQ=0,fR=0,fS=0,fT=0,fU=0,fV=0,fW=0,fX=0,fY=0,fZ=0,f_=0,f$=0,f0=0,f1=0,f2=0,f3=0,f4=0,f5=0,f6=0,f7=0,f8=0,f9=0,ga=0,gb=0,gc=0,gd=0,ge=0,gf=0,gh=0,gi=0,gk=0,gl=0,gm=0,gn=0,go=0,gp=0,gq=0,gr=0,gs=0,gt=0,gu=0,gv=0,gw=0,gx=0,gy=0,gz=0,gA=0,gB=0,gC=0,gD=0,gE=0,gF=0,gG=0,gH=0,gI=0,gJ=0,gK=0,gL=0,gM=0,gN=0,gO=0,gP=0,gQ=0,gR=0,gS=0,gT=0,gU=0,gV=0,gW=0,gX=0,gY=0,gZ=0,g_=0,g$=0,g0=0,g1=0;g=c[f+136>>2]|0;h=c[f+152>>2]|0;i=c[f+21416>>2]|0;j=c[f+21424>>2]|0;OL:do{if(i){i=0;switch(j|0){case 73:{k=a[9660900]|0;l=k&1|(d[9660897]|0)<<1;a[9660900]=(((l&65535)>>>1^l&65535)>>>6&2|(l&65535)>>>8|((l&255)<<24>>24==0?((l&65535)>>>4&8|k&-16&255)&255|4:((l&65535)>>>4&8|k&-16&255)&255)&255)&255;a[9660897]=l&255;break};case 74:{l=(a[9660897]|0)-1&255;a[9660897]=l;a[9660900]=a[669184+(l&255)|0]|a[9660900]&-15;break};case 76:{l=(a[9660897]|0)+1&255;a[9660897]=l;a[9660900]=a[668928+(l&255)|0]|a[9660900]&-15;break};case 77:{l=a[9660897]|0;k=(l&255)>>>4&8|a[9660900]&-16;a[9660900]=l<<24>>24==0?k|4:k;break};case 79:{a[9660897]=0;a[9660900]=a[9660900]&-16|4;break};case 80:{k=a[9660896]|0;l=-(k&255)&65535&65535;m=(l>>>4&8|a[9660900]&-16&255)&255;a[9660900]=((l^k&255^l>>>1)>>>6&2|l>>>8&1|((-(k&255)&65535&255)<<24>>24==0?m|4:m)&255)&255;a[9660896]=-(k&255)&65535&255;break};case 83:{k=a[9660896]|0;a[9660896]=~k;m=(~k&255)>>>4&8|a[9660900]&-15;a[9660900]=(k<<24>>24==-1?m|4:m)|1;break};case 84:{m=a[9660896]|0;k=m&1|a[9660900]&-14;a[9660900]=k;a[9660896]=(m&255)>>>1;if((m&255)>>>1<<24>>24!=0){c[f+21432>>2]=2;c[f+21436>>2]=32;break OL}a[9660900]=k|4;break};case 86:{k=a[9660900]|0;m=a[9660896]|0;a[9660900]=((m&255)>>>1|k<<7)<<24>>24==0?m&1|k&-14|k<<3&8|4:m&1|k&-14|k<<3&8;a[9660896]=(m&255)>>>1|k<<7;break};case 87:{k=a[9660896]|0;m=k&1|a[9660900]&-14;a[9660896]=(k&255)>>>1<<1&-128|(k&255)>>>1;a[9660900]=((k&255)>>>1<<1&-128|(k&255)>>>1)<<24>>24==0?m|(k&255)>>>4&8|4:m|(k&255)>>>4&8;break};case 88:{k=(d[9660896]|0)<<1;m=((k&65535)>>>4&8|a[9660900]&-16&255)&255;a[9660900]=(((k&65535)>>>1^k&65535)>>>6&2|(k&65535)>>>8|((k&255)<<24>>24==0?m|4:m)&255)&255;a[9660896]=k&255;break};case 89:{k=a[9660900]|0;m=k&1|(d[9660896]|0)<<1;a[9660900]=(((m&65535)>>>1^m&65535)>>>6&2|(m&65535)>>>8|((m&255)<<24>>24==0?((m&65535)>>>4&8|k&-16&255)&255|4:((m&65535)>>>4&8|k&-16&255)&255)&255)&255;a[9660896]=m&255;break};case 90:{m=(a[9660896]|0)-1&255;a[9660896]=m;a[9660900]=a[669184+(m&255)|0]|a[9660900]&-15;break};case 92:{m=(a[9660896]|0)+1&255;a[9660896]=m;a[9660900]=a[668928+(m&255)|0]|a[9660900]&-15;break};case 93:{m=a[9660896]|0;k=(m&255)>>>4&8|a[9660900]&-16;a[9660900]=m<<24>>24==0?k|4:k;break};case 95:{a[9660896]=0;a[9660900]=a[9660900]&-16|4;break};case 96:{k=b[4830446]|0;m=c[2415221]|0;l=c[2437644]|0;n=c[l+72+((m>>>8&255|512)<<2)>>2]|0;do{if((n|0)==0){o=c[l+3156>>2]|0;if((o|0)==0){p=0;q=m&65535;r=l;break}s=gj[o&4095](m&65535)|0;p=s;q=b[4830442]|0;r=c[2437644]|0}else{p=a[n+(m&255)|0]|0;q=m&65535;r=l}}while(0);b[4853736]=(p&255)+k&65535;b[4830442]=q+1&65535;l=c[2426868]|0;m=c[r+72+((l>>>8&255)<<2)>>2]|0;do{if((m|0)==0){n=c[r+3144>>2]|0;if((n|0)==0){t=0;u=l;v=r;break}s=gj[n&4095](l&65535)|0;t=s;u=c[2426868]|0;v=c[2437644]|0}else{t=a[m+(l&255)|0]|0;u=l;v=r}}while(0);l=t&255;m=(a[9660900]&-16&255|(-l|0)>>>4&8)&255;a[9660900]=((l^(-l|0)^(-l|0)>>>1)>>>6&2|(-l|0)>>>8&1|(((-l|0)&255)<<24>>24==0?m|4:m)&255)&255;m=c[v+72+((u>>>8&255|256)<<2)>>2]|0;if((m|0)!=0){a[m+(u&255)|0]=(-l|0)&255;c[f+21432>>2]=2;c[f+21436>>2]=32;break OL}m=c[v+3148>>2]|0;if((m|0)==0){c[f+21432>>2]=2;c[f+21436>>2]=32;break OL}gg[m&4095](u&65535,(-l|0)&255);break};case 9:{l=(b[4830446]|0)-1&65535;b[4830446]=l;m=a[9660900]|0;a[9660900]=l<<16>>16==0?m|4:m&-5;break};case 14:{f1a();break};case 8:{m=(b[4830446]|0)+1&65535;b[4830446]=m;l=a[9660900]|0;a[9660900]=m<<16>>16==0?l|4:l&-5;break};case 35:{l=c[2415221]|0;m=c[2437644]|0;k=c[m+72+((l>>>8&255|512)<<2)>>2]|0;do{if((k|0)==0){s=c[m+3156>>2]|0;if((s|0)==0){w=0;x=l&65535;break}n=gj[s&4095](l&65535)|0;w=n;x=b[4830442]|0}else{w=a[k+(l&255)|0]|0;x=l&65535}}while(0);l=x+1&65535;b[4830442]=l;if((a[9660900]&5)==0){c[f+21432>>2]=2;c[f+21436>>2]=32;break OL}k=w&255;b[4830442]=((k&128|0)!=0?k|65280:k)+(l&65535)&65535;b[4830442]=c[2415221]&65535;break};case 6:{f06();break};case 36:{l=c[2415221]|0;k=c[2437644]|0;m=c[k+72+((l>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){n=c[k+3156>>2]|0;if((n|0)==0){y=0;z=l&65535;break}s=gj[n&4095](l&65535)|0;y=s;z=b[4830442]|0}else{y=a[m+(l&255)|0]|0;z=l&65535}}while(0);l=z+1&65535;b[4830442]=l;if((a[9660900]&1)!=0){c[f+21432>>2]=2;c[f+21436>>2]=32;break OL}m=y&255;b[4830442]=((m&128|0)!=0?m|65280:m)+(l&65535)&65535;b[4830442]=c[2415221]&65535;break};case 38:{l=c[2415221]|0;m=c[2437644]|0;k=c[m+72+((l>>>8&255|512)<<2)>>2]|0;do{if((k|0)==0){s=c[m+3156>>2]|0;if((s|0)==0){A=0;B=l&65535;break}n=gj[s&4095](l&65535)|0;A=n;B=b[4830442]|0}else{A=a[k+(l&255)|0]|0;B=l&65535}}while(0);l=B+1&65535;b[4830442]=l;if((a[9660900]&4)!=0){c[f+21432>>2]=2;c[f+21436>>2]=32;break OL}k=A&255;b[4830442]=((k&128|0)!=0?k|65280:k)+(l&65535)&65535;b[4830442]=c[2415221]&65535;break};case 39:{l=c[2415221]|0;k=c[2437644]|0;m=c[k+72+((l>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){n=c[k+3156>>2]|0;if((n|0)==0){C=0;D=l&65535;break}s=gj[n&4095](l&65535)|0;C=s;D=b[4830442]|0}else{C=a[m+(l&255)|0]|0;D=l&65535}}while(0);l=D+1&65535;b[4830442]=l;if((a[9660900]&4)==0){c[f+21432>>2]=2;c[f+21436>>2]=32;break OL}m=C&255;b[4830442]=((m&128|0)!=0?m|65280:m)+(l&65535)&65535;b[4830442]=c[2415221]&65535;break};case 40:{l=c[2415221]|0;m=c[2437644]|0;k=c[m+72+((l>>>8&255|512)<<2)>>2]|0;do{if((k|0)==0){s=c[m+3156>>2]|0;if((s|0)==0){E=0;F=l&65535;break}n=gj[s&4095](l&65535)|0;E=n;F=b[4830442]|0}else{E=a[k+(l&255)|0]|0;F=l&65535}}while(0);l=F+1&65535;b[4830442]=l;if((a[9660900]&2)!=0){c[f+21432>>2]=2;c[f+21436>>2]=32;break OL}k=E&255;b[4830442]=((k&128|0)!=0?k|65280:k)+(l&65535)&65535;b[4830442]=c[2415221]&65535;break};case 148:{l=c[2415221]|0;k=c[2437644]|0;m=c[k+72+((l>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){n=c[k+3156>>2]|0;if((n|0)==0){G=0;H=l&65535;I=k;break}s=gj[n&4095](l&65535)|0;G=s;H=b[4830442]|0;I=c[2437644]|0}else{G=a[m+(l&255)|0]|0;H=l&65535;I=k}}while(0);k=G&255;c[2426868]=k;b[4830442]=H+1&65535;l=G&255;m=c[I+72>>2]|0;do{if((m|0)==0){s=c[I+3144>>2]|0;if((s|0)==0){J=0;break}J=gj[s&4095](l)|0}else{J=a[m+k|0]|0}}while(0);k=a[9660897]&J;a[9660897]=k;m=(k&255)>>>4&8|a[9660900]&-15;a[9660900]=k<<24>>24==0?m|4:m;break};case 149:{m=c[2415221]|0;k=c[2437644]|0;l=c[k+72+((m>>>8&255|512)<<2)>>2]|0;do{if((l|0)==0){s=c[k+3156>>2]|0;if((s|0)==0){K=0;L=m&65535;M=k;break}n=gj[s&4095](m&65535)|0;K=n;L=b[4830442]|0;M=c[2437644]|0}else{K=a[l+(m&255)|0]|0;L=m&65535;M=k}}while(0);k=K&255;c[2426868]=k;b[4830442]=L+1&65535;m=K&255;l=c[M+72>>2]|0;do{if((l|0)==0){n=c[M+3144>>2]|0;if((n|0)==0){N=0;break}N=gj[n&4095](m)|0}else{N=a[l+k|0]|0}}while(0);k=a[9660897]&N;l=(k&255)>>>4&8|a[9660900]&-15;a[9660900]=k<<24>>24==0?l|4:l;break};case 150:{l=c[2415221]|0;k=c[2437644]|0;m=c[k+72+((l>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){n=c[k+3156>>2]|0;if((n|0)==0){O=0;P=l&65535;Q=k;break}s=gj[n&4095](l&65535)|0;O=s;P=b[4830442]|0;Q=c[2437644]|0}else{O=a[m+(l&255)|0]|0;P=l&65535;Q=k}}while(0);k=O&255;c[2426868]=k;b[4830442]=P+1&65535;l=O&255;m=c[Q+72>>2]|0;do{if((m|0)==0){s=c[Q+3144>>2]|0;if((s|0)==0){R=0;break}R=gj[s&4095](l)|0}else{R=a[m+k|0]|0}}while(0);a[9660897]=R;k=(R&255)>>>4&8|a[9660900]&-15;a[9660900]=R<<24>>24==0?k|4:k;break};case 151:{k=a[9660897]|0;m=(k&255)>>>4&8|a[9660900]&-15;a[9660900]=k<<24>>24==0?m|4:m;m=c[2415221]|0;l=c[2437644]|0;s=c[l+72+((m>>>8&255|512)<<2)>>2]|0;do{if((s|0)==0){n=c[l+3156>>2]|0;if((n|0)==0){S=0;T=m&65535;U=k;V=l;break}o=gj[n&4095](m&65535)|0;S=o;T=b[4830442]|0;U=a[9660897]|0;V=c[2437644]|0}else{S=a[s+(m&255)|0]|0;T=m&65535;U=k;V=l}}while(0);l=S&255;c[2426868]=l;b[4830442]=T+1&65535;k=c[V+1096>>2]|0;if((k|0)!=0){a[k+l|0]=U;c[f+21432>>2]=2;c[f+21436>>2]=32;break OL}l=c[V+3148>>2]|0;if((l|0)==0){c[f+21432>>2]=2;c[f+21436>>2]=32;break OL}gg[l&4095](S&255,U);break};case 152:{l=c[2415221]|0;k=c[2437644]|0;m=c[k+72+((l>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){s=c[k+3156>>2]|0;if((s|0)==0){W=0;X=l&65535;Y=k;break}o=gj[s&4095](l&65535)|0;W=o;X=b[4830442]|0;Y=c[2437644]|0}else{W=a[m+(l&255)|0]|0;X=l&65535;Y=k}}while(0);k=W&255;c[2426868]=k;b[4830442]=X+1&65535;l=W&255;m=c[Y+72>>2]|0;do{if((m|0)==0){o=c[Y+3144>>2]|0;if((o|0)==0){Z=0;break}Z=gj[o&4095](l)|0}else{Z=a[m+k|0]|0}}while(0);k=a[9660897]|0;m=k^Z;a[9660897]=m;l=(m&255)>>>4&8|a[9660900]&-15;a[9660900]=k<<24>>24==Z<<24>>24?l|4:l;break};case 153:{l=c[2415221]|0;k=c[2437644]|0;m=c[k+72+((l>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){o=c[k+3156>>2]|0;if((o|0)==0){_=0;$=l&65535;aa=k;break}s=gj[o&4095](l&65535)|0;_=s;$=b[4830442]|0;aa=c[2437644]|0}else{_=a[m+(l&255)|0]|0;$=l&65535;aa=k}}while(0);k=_&255;c[2426868]=k;b[4830442]=$+1&65535;l=_&255;m=c[aa+72>>2]|0;do{if((m|0)==0){s=c[aa+3144>>2]|0;if((s|0)==0){ab=0;break}ab=gj[s&4095](l)|0}else{ab=a[m+k|0]|0}}while(0);k=a[9660897]|0;m=a[9660900]|0;l=(k&255)+(ab&255)+(m&1)|0;s=l^(k^ab)&255;a[9660900]=(s<<1&32|l>>>8&1|(s^l>>>1)>>>6&2|((l&255)<<24>>24==0?(l>>>4&8|m&-48&255)&255|4:(l>>>4&8|m&-48&255)&255)&255)&255;a[9660897]=l&255;break};case 154:{l=c[2415221]|0;m=c[2437644]|0;s=c[m+72+((l>>>8&255|512)<<2)>>2]|0;do{if((s|0)==0){k=c[m+3156>>2]|0;if((k|0)==0){ac=0;ad=l&65535;ae=m;break}o=gj[k&4095](l&65535)|0;ac=o;ad=b[4830442]|0;ae=c[2437644]|0}else{ac=a[s+(l&255)|0]|0;ad=l&65535;ae=m}}while(0);m=ac&255;c[2426868]=m;b[4830442]=ad+1&65535;l=ac&255;s=c[ae+72>>2]|0;do{if((s|0)==0){o=c[ae+3144>>2]|0;if((o|0)==0){af=0;break}af=gj[o&4095](l)|0}else{af=a[s+m|0]|0}}while(0);m=a[9660897]|af;a[9660897]=m;s=(m&255)>>>4&8|a[9660900]&-15;a[9660900]=m<<24>>24==0?s|4:s;break};case 155:{s=c[2415221]|0;m=c[2437644]|0;l=c[m+72+((s>>>8&255|512)<<2)>>2]|0;do{if((l|0)==0){o=c[m+3156>>2]|0;if((o|0)==0){ag=0;ah=s&65535;ai=m;break}k=gj[o&4095](s&65535)|0;ag=k;ah=b[4830442]|0;ai=c[2437644]|0}else{ag=a[l+(s&255)|0]|0;ah=s&65535;ai=m}}while(0);m=ag&255;c[2426868]=m;b[4830442]=ah+1&65535;s=ag&255;l=c[ai+72>>2]|0;do{if((l|0)==0){k=c[ai+3144>>2]|0;if((k|0)==0){aj=0;break}aj=gj[k&4095](s)|0}else{aj=a[l+m|0]|0}}while(0);m=a[9660897]|0;l=(m&255)+(aj&255)|0;s=(l>>>4&8|a[9660900]&-48&255)&255;k=(m^aj)&255^l;a[9660900]=(k<<1&32|l>>>8&1|(k^l>>>1)>>>6&2|((l&255)<<24>>24==0?s|4:s)&255)&255;a[9660897]=l&255;break};case 156:{l=c[2415221]|0;s=c[2437644]|0;k=c[s+72+((l>>>8&255|512)<<2)>>2]|0;do{if((k|0)==0){m=c[s+3156>>2]|0;if((m|0)==0){ak=0;al=l&65535;am=s;break}o=gj[m&4095](l&65535)|0;ak=o;al=b[4830442]|0;am=c[2437644]|0}else{ak=a[k+(l&255)|0]|0;al=l&65535;am=s}}while(0);s=ak&255;c[2426868]=s;b[4830442]=al+1&65535;l=ak&255;k=c[am+72>>2]|0;do{if((k|0)==0){o=c[am+3144>>2]|0;if((o|0)==0){an=0;ao=am;break}m=gj[o&4095](l)|0;an=m;ao=c[2437644]|0}else{an=a[k+s|0]|0;ao=am}}while(0);k=(an&255)<<8;l=c[ao+72+(((s+1|0)>>>8&255)<<2)>>2]|0;do{if((l|0)==0){m=c[ao+3144>>2]|0;if((m|0)==0){ap=0;break}ap=gj[m&4095]((s+1|0)&65535)|0}else{ap=a[l+((s+1|0)&255)|0]|0}}while(0);s=e[4830446]|0;l=s-(ap&255|k)|0;m=(l>>>12&8|a[9660900]&-15&255)&255;a[9660900]=(((l&65535)<<16>>16==0?m|4:m)&255|(s^k^l^l>>>1)>>>14&2)&255;break};case 157:{l=c[2415221]|0;s=c[2437644]|0;m=c[s+72+((l>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){o=c[s+3156>>2]|0;if((o|0)==0){aq=0;ar=l&65535;as=s;break}n=gj[o&4095](l&65535)|0;aq=n;ar=b[4830442]|0;as=c[2437644]|0}else{aq=a[m+(l&255)|0]|0;ar=l&65535;as=s}}while(0);c[2426868]=aq&255;s=ar+1&65535;b[4830442]=s;l=c[2415222]|0;m=c[as+72+((l>>>8&255|256)<<2)>>2]|0;do{if((m|0)==0){k=c[as+3148>>2]|0;if((k|0)==0){at=as;break}gg[k&4095](l&65535,s&255);at=c[2437644]|0}else{a[m+(l&255)|0]=s&255;at=as}}while(0);b[4830444]=(b[4830444]|0)-1&65535;s=c[2415222]|0;l=a[9660885]|0;m=c[at+72+((s>>>8&255|256)<<2)>>2]|0;do{if((m|0)==0){k=c[at+3148>>2]|0;if((k|0)==0){break}gg[k&4095](s&65535,l)}else{a[m+(s&255)|0]=l}}while(0);b[4830444]=(b[4830444]|0)-1&65535;b[4830442]=b[4853736]|0;b[4830442]=c[2415221]&65535;break};case 158:{l=c[2415221]|0;s=c[2437644]|0;m=c[s+72+((l>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){k=c[s+3156>>2]|0;if((k|0)==0){au=0;av=l&65535;aw=s;break}n=gj[k&4095](l&65535)|0;au=n;av=b[4830442]|0;aw=c[2437644]|0}else{au=a[m+(l&255)|0]|0;av=l&65535;aw=s}}while(0);s=au&255;c[2426868]=s;b[4830442]=av+1&65535;l=au&255;m=c[aw+72>>2]|0;do{if((m|0)==0){n=c[aw+3144>>2]|0;if((n|0)==0){ax=0;ay=aw;break}k=gj[n&4095](l)|0;ax=k;ay=c[2437644]|0}else{ax=a[m+s|0]|0;ay=aw}}while(0);m=ax&255;l=c[ay+72+(((s+1|0)>>>8&255)<<2)>>2]|0;do{if((l|0)==0){k=c[ay+3144>>2]|0;if((k|0)==0){az=0;break}az=gj[k&4095]((s+1|0)&65535)|0}else{az=a[l+((s+1|0)&255)|0]|0}}while(0);s=az&255|m<<8;c[2415222]=s;l=a[9660900]&-15;a[9660900]=l;if((s|0)==0){aA=(l&255|m>>>4&8|4)&255}else{aA=(l&255|m>>>4&8)&255}a[9660900]=aA;break};case 159:{l=b[4830444]|0;s=(l&65535)>>>12&8|a[9660900]&-15&255;a[9660900]=(l<<16>>16==0?s|4:s)&255;s=c[2415221]|0;l=c[2437644]|0;k=c[l+72+((s>>>8&255|512)<<2)>>2]|0;do{if((k|0)==0){n=c[l+3156>>2]|0;if((n|0)==0){aB=0;aC=s&65535;aD=l;break}o=gj[n&4095](s&65535)|0;aB=o;aC=b[4830442]|0;aD=c[2437644]|0}else{aB=a[k+(s&255)|0]|0;aC=s&65535;aD=l}}while(0);l=aB&255;c[2426868]=l;b[4830442]=aC+1&65535;s=aB&255;k=a[9660889]|0;m=c[aD+1096>>2]|0;do{if((m|0)==0){o=c[aD+3148>>2]|0;if((o|0)==0){aE=aD;break}gg[o&4095](s,k);aE=c[2437644]|0}else{a[m+l|0]=k;aE=aD}}while(0);k=a[9660888]|0;m=c[aE+72+(((l+1|0)>>>8&255|256)<<2)>>2]|0;if((m|0)!=0){a[m+((l+1|0)&255)|0]=k;c[f+21432>>2]=2;c[f+21436>>2]=32;break OL}m=c[aE+3148>>2]|0;if((m|0)==0){c[f+21432>>2]=2;c[f+21436>>2]=32;break OL}gg[m&4095]((l+1|0)&65535,k);break};case 160:{k=b[4830446]|0;m=c[2415221]|0;s=c[2437644]|0;o=c[s+72+((m>>>8&255|512)<<2)>>2]|0;do{if((o|0)==0){n=c[s+3156>>2]|0;if((n|0)==0){aF=0;aG=m&65535;aH=s;break}aI=gj[n&4095](m&65535)|0;aF=aI;aG=b[4830442]|0;aH=c[2437644]|0}else{aF=a[o+(m&255)|0]|0;aG=m&65535;aH=s}}while(0);b[4853736]=(aF&255)+k&65535;b[4830442]=aG+1&65535;s=c[2426868]|0;m=c[aH+72+((s>>>8&255)<<2)>>2]|0;do{if((m|0)==0){o=c[aH+3144>>2]|0;if((o|0)==0){aJ=0;break}aJ=gj[o&4095](s&65535)|0}else{aJ=a[m+(s&255)|0]|0}}while(0);s=a[9660897]|0;m=(s&255)-(aJ&255)|0;k=(m>>>4&8|a[9660900]&-16&255)&255;a[9660900]=(((s^aJ)&255^m^m>>>1)>>>6&2|m>>>8&1|((m&255)<<24>>24==0?k|4:k)&255)&255;a[9660897]=m&255;break};case 161:{m=b[4830446]|0;k=c[2415221]|0;s=c[2437644]|0;o=c[s+72+((k>>>8&255|512)<<2)>>2]|0;do{if((o|0)==0){l=c[s+3156>>2]|0;if((l|0)==0){aK=0;aL=k&65535;aM=s;break}aI=gj[l&4095](k&65535)|0;aK=aI;aL=b[4830442]|0;aM=c[2437644]|0}else{aK=a[o+(k&255)|0]|0;aL=k&65535;aM=s}}while(0);b[4853736]=(aK&255)+m&65535;b[4830442]=aL+1&65535;s=c[2426868]|0;k=c[aM+72+((s>>>8&255)<<2)>>2]|0;do{if((k|0)==0){o=c[aM+3144>>2]|0;if((o|0)==0){aN=0;break}aN=gj[o&4095](s&65535)|0}else{aN=a[k+(s&255)|0]|0}}while(0);s=a[9660897]|0;k=(s&255)-(aN&255)|0;m=(k>>>4&8|a[9660900]&-16&255)&255;a[9660900]=(((s^aN)&255^k^k>>>1)>>>6&2|k>>>8&1|((k&255)<<24>>24==0?m|4:m)&255)&255;break};case 162:{m=b[4830446]|0;k=c[2415221]|0;s=c[2437644]|0;o=c[s+72+((k>>>8&255|512)<<2)>>2]|0;do{if((o|0)==0){aI=c[s+3156>>2]|0;if((aI|0)==0){aO=0;aP=k&65535;aQ=s;break}l=gj[aI&4095](k&65535)|0;aO=l;aP=b[4830442]|0;aQ=c[2437644]|0}else{aO=a[o+(k&255)|0]|0;aP=k&65535;aQ=s}}while(0);b[4853736]=(aO&255)+m&65535;b[4830442]=aP+1&65535;s=c[2426868]|0;k=c[aQ+72+((s>>>8&255)<<2)>>2]|0;do{if((k|0)==0){o=c[aQ+3144>>2]|0;if((o|0)==0){aR=0;break}aR=gj[o&4095](s&65535)|0}else{aR=a[k+(s&255)|0]|0}}while(0);s=a[9660897]|0;k=a[9660900]|0;m=(s&255)-(aR&255)-(k&1)|0;a[9660900]=((m^(s^aR)&255^m>>>1)>>>6&2|m>>>8&1|((m&255)<<24>>24==0?(m>>>4&8|k&-16&255)&255|4:(m>>>4&8|k&-16&255)&255)&255)&255;a[9660897]=m&255;break};case 164:{m=b[4830446]|0;k=c[2415221]|0;s=c[2437644]|0;o=c[s+72+((k>>>8&255|512)<<2)>>2]|0;do{if((o|0)==0){l=c[s+3156>>2]|0;if((l|0)==0){aS=0;aT=k&65535;aU=s;break}aI=gj[l&4095](k&65535)|0;aS=aI;aT=b[4830442]|0;aU=c[2437644]|0}else{aS=a[o+(k&255)|0]|0;aT=k&65535;aU=s}}while(0);b[4853736]=(aS&255)+m&65535;b[4830442]=aT+1&65535;s=c[2426868]|0;k=c[aU+72+((s>>>8&255)<<2)>>2]|0;do{if((k|0)==0){o=c[aU+3144>>2]|0;if((o|0)==0){aV=0;break}aV=gj[o&4095](s&65535)|0}else{aV=a[k+(s&255)|0]|0}}while(0);s=a[9660897]&aV;a[9660897]=s;k=(s&255)>>>4&8|a[9660900]&-15;a[9660900]=s<<24>>24==0?k|4:k;break};case 165:{k=b[4830446]|0;s=c[2415221]|0;m=c[2437644]|0;o=c[m+72+((s>>>8&255|512)<<2)>>2]|0;do{if((o|0)==0){aI=c[m+3156>>2]|0;if((aI|0)==0){aW=0;aX=s&65535;aY=m;break}l=gj[aI&4095](s&65535)|0;aW=l;aX=b[4830442]|0;aY=c[2437644]|0}else{aW=a[o+(s&255)|0]|0;aX=s&65535;aY=m}}while(0);b[4853736]=(aW&255)+k&65535;b[4830442]=aX+1&65535;m=c[2426868]|0;s=c[aY+72+((m>>>8&255)<<2)>>2]|0;do{if((s|0)==0){o=c[aY+3144>>2]|0;if((o|0)==0){aZ=0;break}aZ=gj[o&4095](m&65535)|0}else{aZ=a[s+(m&255)|0]|0}}while(0);m=a[9660897]&aZ;s=(m&255)>>>4&8|a[9660900]&-15;a[9660900]=m<<24>>24==0?s|4:s;break};case 166:{s=b[4830446]|0;m=c[2415221]|0;k=c[2437644]|0;o=c[k+72+((m>>>8&255|512)<<2)>>2]|0;do{if((o|0)==0){l=c[k+3156>>2]|0;if((l|0)==0){a_=0;a$=m&65535;a0=k;break}aI=gj[l&4095](m&65535)|0;a_=aI;a$=b[4830442]|0;a0=c[2437644]|0}else{a_=a[o+(m&255)|0]|0;a$=m&65535;a0=k}}while(0);b[4853736]=(a_&255)+s&65535;b[4830442]=a$+1&65535;k=c[2426868]|0;m=c[a0+72+((k>>>8&255)<<2)>>2]|0;do{if((m|0)==0){o=c[a0+3144>>2]|0;if((o|0)==0){a1=0;break}a1=gj[o&4095](k&65535)|0}else{a1=a[m+(k&255)|0]|0}}while(0);a[9660897]=a1;k=(a1&255)>>>4&8|a[9660900]&-15;a[9660900]=a1<<24>>24==0?k|4:k;break};case 167:{k=a[9660897]|0;m=(k&255)>>>4&8|a[9660900]&-15;a[9660900]=k<<24>>24==0?m|4:m;m=b[4830446]|0;s=c[2415221]|0;o=c[2437644]|0;aI=c[o+72+((s>>>8&255|512)<<2)>>2]|0;do{if((aI|0)==0){l=c[o+3156>>2]|0;if((l|0)==0){a2=0;a3=s&65535;a4=k;a5=o;break}n=gj[l&4095](s&65535)|0;a2=n;a3=b[4830442]|0;a4=a[9660897]|0;a5=c[2437644]|0}else{a2=a[aI+(s&255)|0]|0;a3=s&65535;a4=k;a5=o}}while(0);b[4853736]=(a2&255)+m&65535;b[4830442]=a3+1&65535;o=c[2426868]|0;k=c[a5+72+((o>>>8&255|256)<<2)>>2]|0;if((k|0)!=0){a[k+(o&255)|0]=a4;c[f+21432>>2]=2;c[f+21436>>2]=32;break OL}k=c[a5+3148>>2]|0;if((k|0)==0){c[f+21432>>2]=2;c[f+21436>>2]=32;break OL}gg[k&4095](o&65535,a4);break};case 168:{o=b[4830446]|0;k=c[2415221]|0;s=c[2437644]|0;aI=c[s+72+((k>>>8&255|512)<<2)>>2]|0;do{if((aI|0)==0){n=c[s+3156>>2]|0;if((n|0)==0){a6=0;a7=k&65535;a8=s;break}l=gj[n&4095](k&65535)|0;a6=l;a7=b[4830442]|0;a8=c[2437644]|0}else{a6=a[aI+(k&255)|0]|0;a7=k&65535;a8=s}}while(0);b[4853736]=(a6&255)+o&65535;b[4830442]=a7+1&65535;s=c[2426868]|0;k=c[a8+72+((s>>>8&255)<<2)>>2]|0;do{if((k|0)==0){aI=c[a8+3144>>2]|0;if((aI|0)==0){a9=0;break}a9=gj[aI&4095](s&65535)|0}else{a9=a[k+(s&255)|0]|0}}while(0);s=a[9660897]|0;k=s^a9;a[9660897]=k;o=(k&255)>>>4&8|a[9660900]&-15;a[9660900]=s<<24>>24==a9<<24>>24?o|4:o;break};case 169:{o=b[4830446]|0;s=c[2415221]|0;k=c[2437644]|0;aI=c[k+72+((s>>>8&255|512)<<2)>>2]|0;do{if((aI|0)==0){m=c[k+3156>>2]|0;if((m|0)==0){ba=0;bb=s&65535;bc=k;break}l=gj[m&4095](s&65535)|0;ba=l;bb=b[4830442]|0;bc=c[2437644]|0}else{ba=a[aI+(s&255)|0]|0;bb=s&65535;bc=k}}while(0);b[4853736]=(ba&255)+o&65535;b[4830442]=bb+1&65535;k=c[2426868]|0;s=c[bc+72+((k>>>8&255)<<2)>>2]|0;do{if((s|0)==0){aI=c[bc+3144>>2]|0;if((aI|0)==0){bd=0;break}bd=gj[aI&4095](k&65535)|0}else{bd=a[s+(k&255)|0]|0}}while(0);k=a[9660897]|0;s=a[9660900]|0;o=(k&255)+(bd&255)+(s&1)|0;aI=o^(k^bd)&255;a[9660900]=(aI<<1&32|o>>>8&1|(aI^o>>>1)>>>6&2|((o&255)<<24>>24==0?(o>>>4&8|s&-48&255)&255|4:(o>>>4&8|s&-48&255)&255)&255)&255;a[9660897]=o&255;break};default:{i=1}}}if(i){i=0;switch(j|0){case 170:{o=b[4830446]|0;s=c[2415221]|0;aI=c[2437644]|0;k=c[aI+72+((s>>>8&255|512)<<2)>>2]|0;do{if((k|0)==0){l=c[aI+3156>>2]|0;if((l|0)==0){be=0;bf=s&65535;bg=aI;break}m=gj[l&4095](s&65535)|0;be=m;bf=b[4830442]|0;bg=c[2437644]|0}else{be=a[k+(s&255)|0]|0;bf=s&65535;bg=aI}}while(0);b[4853736]=(be&255)+o&65535;b[4830442]=bf+1&65535;aI=c[2426868]|0;s=c[bg+72+((aI>>>8&255)<<2)>>2]|0;do{if((s|0)==0){k=c[bg+3144>>2]|0;if((k|0)==0){bh=0;break}bh=gj[k&4095](aI&65535)|0}else{bh=a[s+(aI&255)|0]|0}}while(0);aI=a[9660897]|bh;a[9660897]=aI;s=(aI&255)>>>4&8|a[9660900]&-15;a[9660900]=aI<<24>>24==0?s|4:s;break};case 171:{s=b[4830446]|0;aI=c[2415221]|0;o=c[2437644]|0;k=c[o+72+((aI>>>8&255|512)<<2)>>2]|0;do{if((k|0)==0){m=c[o+3156>>2]|0;if((m|0)==0){bi=0;bj=aI&65535;bk=o;break}l=gj[m&4095](aI&65535)|0;bi=l;bj=b[4830442]|0;bk=c[2437644]|0}else{bi=a[k+(aI&255)|0]|0;bj=aI&65535;bk=o}}while(0);b[4853736]=(bi&255)+s&65535;b[4830442]=bj+1&65535;o=c[2426868]|0;aI=c[bk+72+((o>>>8&255)<<2)>>2]|0;do{if((aI|0)==0){k=c[bk+3144>>2]|0;if((k|0)==0){bl=0;break}bl=gj[k&4095](o&65535)|0}else{bl=a[aI+(o&255)|0]|0}}while(0);o=a[9660897]|0;aI=(o&255)+(bl&255)|0;s=(aI>>>4&8|a[9660900]&-48&255)&255;k=(o^bl)&255^aI;a[9660900]=(k<<1&32|aI>>>8&1|(k^aI>>>1)>>>6&2|((aI&255)<<24>>24==0?s|4:s)&255)&255;a[9660897]=aI&255;break};case 172:{aI=b[4830446]|0;s=c[2415221]|0;k=c[2437644]|0;o=c[k+72+((s>>>8&255|512)<<2)>>2]|0;do{if((o|0)==0){l=c[k+3156>>2]|0;if((l|0)==0){bm=0;bn=s&65535;bo=k;break}m=gj[l&4095](s&65535)|0;bm=m;bn=b[4830442]|0;bo=c[2437644]|0}else{bm=a[o+(s&255)|0]|0;bn=s&65535;bo=k}}while(0);b[4853736]=(bm&255)+aI&65535;b[4830442]=bn+1&65535;k=c[2426868]|0;s=c[bo+72+((k>>>8&255)<<2)>>2]|0;do{if((s|0)==0){o=c[bo+3144>>2]|0;if((o|0)==0){bp=0;bq=bo;break}m=gj[o&4095](k&65535)|0;bp=m;bq=c[2437644]|0}else{bp=a[s+(k&255)|0]|0;bq=bo}}while(0);s=(bp&255)<<8;aI=c[bq+72+(((k+1|0)>>>8&255)<<2)>>2]|0;do{if((aI|0)==0){m=c[bq+3144>>2]|0;if((m|0)==0){br=0;break}br=gj[m&4095]((k+1|0)&65535)|0}else{br=a[aI+((k+1|0)&255)|0]|0}}while(0);k=e[4830446]|0;aI=k-(br&255|s)|0;m=(aI>>>12&8|a[9660900]&-15&255)&255;a[9660900]=(((aI&65535)<<16>>16==0?m|4:m)&255|(k^s^aI^aI>>>1)>>>14&2)&255;break};case 173:{aI=b[4830446]|0;k=c[2415221]|0;m=c[2437644]|0;o=c[m+72+((k>>>8&255|512)<<2)>>2]|0;do{if((o|0)==0){l=c[m+3156>>2]|0;if((l|0)==0){bs=0;bt=k&65535;bu=m;break}n=gj[l&4095](k&65535)|0;bs=n;bt=b[4830442]|0;bu=c[2437644]|0}else{bs=a[o+(k&255)|0]|0;bt=k&65535;bu=m}}while(0);b[4853736]=(bs&255)+aI&65535;m=bt+1&65535;b[4830442]=m;k=c[2415222]|0;o=c[bu+72+((k>>>8&255|256)<<2)>>2]|0;do{if((o|0)==0){s=c[bu+3148>>2]|0;if((s|0)==0){bv=bu;break}gg[s&4095](k&65535,m&255);bv=c[2437644]|0}else{a[o+(k&255)|0]=m&255;bv=bu}}while(0);b[4830444]=(b[4830444]|0)-1&65535;m=c[2415222]|0;k=a[9660885]|0;o=c[bv+72+((m>>>8&255|256)<<2)>>2]|0;do{if((o|0)==0){aI=c[bv+3148>>2]|0;if((aI|0)==0){break}gg[aI&4095](m&65535,k)}else{a[o+(m&255)|0]=k}}while(0);b[4830444]=(b[4830444]|0)-1&65535;b[4830442]=b[4853736]|0;b[4830442]=c[2415221]&65535;break};case 174:{k=b[4830446]|0;m=c[2415221]|0;o=c[2437644]|0;aI=c[o+72+((m>>>8&255|512)<<2)>>2]|0;do{if((aI|0)==0){s=c[o+3156>>2]|0;if((s|0)==0){bw=0;bx=m&65535;by=o;break}n=gj[s&4095](m&65535)|0;bw=n;bx=b[4830442]|0;by=c[2437644]|0}else{bw=a[aI+(m&255)|0]|0;bx=m&65535;by=o}}while(0);b[4853736]=(bw&255)+k&65535;b[4830442]=bx+1&65535;o=c[2426868]|0;m=c[by+72+((o>>>8&255)<<2)>>2]|0;do{if((m|0)==0){aI=c[by+3144>>2]|0;if((aI|0)==0){bz=0;bA=by;break}n=gj[aI&4095](o&65535)|0;bz=n;bA=c[2437644]|0}else{bz=a[m+(o&255)|0]|0;bA=by}}while(0);m=bz&255;k=c[bA+72+(((o+1|0)>>>8&255)<<2)>>2]|0;do{if((k|0)==0){n=c[bA+3144>>2]|0;if((n|0)==0){bB=0;break}bB=gj[n&4095]((o+1|0)&65535)|0}else{bB=a[k+((o+1|0)&255)|0]|0}}while(0);o=bB&255|m<<8;c[2415222]=o;k=a[9660900]&-15;a[9660900]=k;if((o|0)==0){bC=(k&255|m>>>4&8|4)&255}else{bC=(k&255|m>>>4&8)&255}a[9660900]=bC;break};case 175:{k=b[4830444]|0;o=(k&65535)>>>12&8|a[9660900]&-15&255;a[9660900]=(k<<16>>16==0?o|4:o)&255;o=b[4830446]|0;k=c[2415221]|0;n=c[2437644]|0;aI=c[n+72+((k>>>8&255|512)<<2)>>2]|0;do{if((aI|0)==0){s=c[n+3156>>2]|0;if((s|0)==0){bD=0;bE=k&65535;bF=n;break}l=gj[s&4095](k&65535)|0;bD=l;bE=b[4830442]|0;bF=c[2437644]|0}else{bD=a[aI+(k&255)|0]|0;bE=k&65535;bF=n}}while(0);b[4853736]=(bD&255)+o&65535;b[4830442]=bE+1&65535;n=c[2426868]|0;k=a[9660889]|0;aI=c[bF+72+((n>>>8&255|256)<<2)>>2]|0;do{if((aI|0)==0){m=c[bF+3148>>2]|0;if((m|0)==0){bG=bF;break}gg[m&4095](n&65535,k);bG=c[2437644]|0}else{a[aI+(n&255)|0]=k;bG=bF}}while(0);k=a[9660888]|0;aI=c[bG+72+(((n+1|0)>>>8&255|256)<<2)>>2]|0;if((aI|0)!=0){a[aI+((n+1|0)&255)|0]=k;c[f+21432>>2]=2;c[f+21436>>2]=32;break OL}aI=c[bG+3148>>2]|0;if((aI|0)==0){c[f+21432>>2]=2;c[f+21436>>2]=32;break OL}gg[aI&4095]((n+1|0)&65535,k);break};case 176:{k=c[2415221]|0;aI=c[2437644]|0;o=c[aI+72+((k>>>8&255|512)<<2)>>2]|0;do{if((o|0)==0){m=c[aI+3156>>2]|0;if((m|0)==0){bH=0;bI=k;bJ=aI;bK=k&65535;break}l=gj[m&4095](k&65535)|0;m=c[2415221]|0;bH=l;bI=m;bJ=c[2437644]|0;bK=m&65535}else{bH=a[o+(k&255)|0]|0;bI=k;bJ=aI;bK=k&65535}}while(0);k=bH&255;aI=bI+1|0;o=c[bJ+72+((aI>>>8&255|512)<<2)>>2]|0;do{if((o|0)==0){n=c[bJ+3156>>2]|0;if((n|0)==0){bL=0;bM=bK;bN=bJ;break}m=gj[n&4095](aI&65535)|0;bL=m;bM=b[4830442]|0;bN=c[2437644]|0}else{bL=a[o+(aI&255)|0]|0;bM=bK;bN=bJ}}while(0);aI=bL&255;c[2426868]=aI|k<<8;b[4830442]=bM+2&65535;o=c[bN+72+(k<<2)>>2]|0;do{if((o|0)==0){m=c[bN+3144>>2]|0;if((m|0)==0){bO=0;break}bO=gj[m&4095]((aI|k<<8)&65535)|0}else{bO=a[o+aI|0]|0}}while(0);aI=a[9660897]|0;o=(aI&255)-(bO&255)|0;k=(o>>>4&8|a[9660900]&-16&255)&255;a[9660900]=(((aI^bO)&255^o^o>>>1)>>>6&2|o>>>8&1|((o&255)<<24>>24==0?k|4:k)&255)&255;a[9660897]=o&255;break};case 177:{o=c[2415221]|0;k=c[2437644]|0;aI=c[k+72+((o>>>8&255|512)<<2)>>2]|0;do{if((aI|0)==0){m=c[k+3156>>2]|0;if((m|0)==0){bP=0;bQ=o;bR=k;bS=o&65535;break}n=gj[m&4095](o&65535)|0;m=c[2415221]|0;bP=n;bQ=m;bR=c[2437644]|0;bS=m&65535}else{bP=a[aI+(o&255)|0]|0;bQ=o;bR=k;bS=o&65535}}while(0);o=bP&255;k=bQ+1|0;aI=c[bR+72+((k>>>8&255|512)<<2)>>2]|0;do{if((aI|0)==0){m=c[bR+3156>>2]|0;if((m|0)==0){bT=0;bU=bS;bV=bR;break}n=gj[m&4095](k&65535)|0;bT=n;bU=b[4830442]|0;bV=c[2437644]|0}else{bT=a[aI+(k&255)|0]|0;bU=bS;bV=bR}}while(0);k=bT&255;c[2426868]=k|o<<8;b[4830442]=bU+2&65535;aI=c[bV+72+(o<<2)>>2]|0;do{if((aI|0)==0){n=c[bV+3144>>2]|0;if((n|0)==0){bW=0;break}bW=gj[n&4095]((k|o<<8)&65535)|0}else{bW=a[aI+k|0]|0}}while(0);k=a[9660897]|0;aI=(k&255)-(bW&255)|0;o=(aI>>>4&8|a[9660900]&-16&255)&255;a[9660900]=(((k^bW)&255^aI^aI>>>1)>>>6&2|aI>>>8&1|((aI&255)<<24>>24==0?o|4:o)&255)&255;break};case 178:{o=c[2415221]|0;aI=c[2437644]|0;k=c[aI+72+((o>>>8&255|512)<<2)>>2]|0;do{if((k|0)==0){n=c[aI+3156>>2]|0;if((n|0)==0){bX=0;bY=o;bZ=aI;b_=o&65535;break}m=gj[n&4095](o&65535)|0;n=c[2415221]|0;bX=m;bY=n;bZ=c[2437644]|0;b_=n&65535}else{bX=a[k+(o&255)|0]|0;bY=o;bZ=aI;b_=o&65535}}while(0);o=bX&255;aI=bY+1|0;k=c[bZ+72+((aI>>>8&255|512)<<2)>>2]|0;do{if((k|0)==0){n=c[bZ+3156>>2]|0;if((n|0)==0){b$=0;b0=b_;b1=bZ;break}m=gj[n&4095](aI&65535)|0;b$=m;b0=b[4830442]|0;b1=c[2437644]|0}else{b$=a[k+(aI&255)|0]|0;b0=b_;b1=bZ}}while(0);aI=b$&255;c[2426868]=aI|o<<8;b[4830442]=b0+2&65535;k=c[b1+72+(o<<2)>>2]|0;do{if((k|0)==0){m=c[b1+3144>>2]|0;if((m|0)==0){b2=0;break}b2=gj[m&4095]((aI|o<<8)&65535)|0}else{b2=a[k+aI|0]|0}}while(0);aI=a[9660897]|0;k=a[9660900]|0;o=(aI&255)-(b2&255)-(k&1)|0;a[9660900]=((o^(aI^b2)&255^o>>>1)>>>6&2|o>>>8&1|((o&255)<<24>>24==0?(o>>>4&8|k&-16&255)&255|4:(o>>>4&8|k&-16&255)&255)&255)&255;a[9660897]=o&255;break};case 180:{o=c[2415221]|0;k=c[2437644]|0;aI=c[k+72+((o>>>8&255|512)<<2)>>2]|0;do{if((aI|0)==0){m=c[k+3156>>2]|0;if((m|0)==0){b3=0;b4=o;b5=k;b6=o&65535;break}n=gj[m&4095](o&65535)|0;m=c[2415221]|0;b3=n;b4=m;b5=c[2437644]|0;b6=m&65535}else{b3=a[aI+(o&255)|0]|0;b4=o;b5=k;b6=o&65535}}while(0);o=b3&255;k=b4+1|0;aI=c[b5+72+((k>>>8&255|512)<<2)>>2]|0;do{if((aI|0)==0){m=c[b5+3156>>2]|0;if((m|0)==0){b7=0;b8=b6;b9=b5;break}n=gj[m&4095](k&65535)|0;b7=n;b8=b[4830442]|0;b9=c[2437644]|0}else{b7=a[aI+(k&255)|0]|0;b8=b6;b9=b5}}while(0);k=b7&255;c[2426868]=k|o<<8;b[4830442]=b8+2&65535;aI=c[b9+72+(o<<2)>>2]|0;do{if((aI|0)==0){n=c[b9+3144>>2]|0;if((n|0)==0){ca=0;break}ca=gj[n&4095]((k|o<<8)&65535)|0}else{ca=a[aI+k|0]|0}}while(0);k=a[9660897]&ca;a[9660897]=k;aI=(k&255)>>>4&8|a[9660900]&-15;a[9660900]=k<<24>>24==0?aI|4:aI;break};case 181:{aI=c[2415221]|0;k=c[2437644]|0;o=c[k+72+((aI>>>8&255|512)<<2)>>2]|0;do{if((o|0)==0){n=c[k+3156>>2]|0;if((n|0)==0){cb=0;cc=aI;cd=k;ce=aI&65535;break}m=gj[n&4095](aI&65535)|0;n=c[2415221]|0;cb=m;cc=n;cd=c[2437644]|0;ce=n&65535}else{cb=a[o+(aI&255)|0]|0;cc=aI;cd=k;ce=aI&65535}}while(0);aI=cb&255;k=cc+1|0;o=c[cd+72+((k>>>8&255|512)<<2)>>2]|0;do{if((o|0)==0){n=c[cd+3156>>2]|0;if((n|0)==0){cf=0;cg=ce;ch=cd;break}m=gj[n&4095](k&65535)|0;cf=m;cg=b[4830442]|0;ch=c[2437644]|0}else{cf=a[o+(k&255)|0]|0;cg=ce;ch=cd}}while(0);k=cf&255;c[2426868]=k|aI<<8;b[4830442]=cg+2&65535;o=c[ch+72+(aI<<2)>>2]|0;do{if((o|0)==0){m=c[ch+3144>>2]|0;if((m|0)==0){ci=0;break}ci=gj[m&4095]((k|aI<<8)&65535)|0}else{ci=a[o+k|0]|0}}while(0);k=a[9660897]&ci;o=(k&255)>>>4&8|a[9660900]&-15;a[9660900]=k<<24>>24==0?o|4:o;break};case 182:{o=c[2415221]|0;k=c[2437644]|0;aI=c[k+72+((o>>>8&255|512)<<2)>>2]|0;do{if((aI|0)==0){m=c[k+3156>>2]|0;if((m|0)==0){cj=0;ck=o;cl=k;cm=o&65535;break}n=gj[m&4095](o&65535)|0;m=c[2415221]|0;cj=n;ck=m;cl=c[2437644]|0;cm=m&65535}else{cj=a[aI+(o&255)|0]|0;ck=o;cl=k;cm=o&65535}}while(0);o=cj&255;k=ck+1|0;aI=c[cl+72+((k>>>8&255|512)<<2)>>2]|0;do{if((aI|0)==0){m=c[cl+3156>>2]|0;if((m|0)==0){cn=0;co=cm;cp=cl;break}n=gj[m&4095](k&65535)|0;cn=n;co=b[4830442]|0;cp=c[2437644]|0}else{cn=a[aI+(k&255)|0]|0;co=cm;cp=cl}}while(0);k=cn&255;c[2426868]=k|o<<8;b[4830442]=co+2&65535;aI=c[cp+72+(o<<2)>>2]|0;do{if((aI|0)==0){n=c[cp+3144>>2]|0;if((n|0)==0){cq=0;break}cq=gj[n&4095]((k|o<<8)&65535)|0}else{cq=a[aI+k|0]|0}}while(0);a[9660897]=cq;k=(cq&255)>>>4&8|a[9660900]&-15;a[9660900]=cq<<24>>24==0?k|4:k;break};case 183:{k=a[9660897]|0;aI=(k&255)>>>4&8|a[9660900]&-15;a[9660900]=k<<24>>24==0?aI|4:aI;aI=c[2415221]|0;k=c[2437644]|0;o=c[k+72+((aI>>>8&255|512)<<2)>>2]|0;do{if((o|0)==0){n=c[k+3156>>2]|0;if((n|0)==0){cr=0;cs=aI;ct=k;cu=aI&65535;break}m=gj[n&4095](aI&65535)|0;n=c[2415221]|0;cr=m;cs=n;ct=c[2437644]|0;cu=n&65535}else{cr=a[o+(aI&255)|0]|0;cs=aI;ct=k;cu=aI&65535}}while(0);aI=cr&255;k=cs+1|0;o=c[ct+72+((k>>>8&255|512)<<2)>>2]|0;do{if((o|0)==0){n=c[ct+3156>>2]|0;if((n|0)==0){cv=0;cw=cu;cx=ct;break}m=gj[n&4095](k&65535)|0;cv=m;cw=b[4830442]|0;cx=c[2437644]|0}else{cv=a[o+(k&255)|0]|0;cw=cu;cx=ct}}while(0);k=cv&255;c[2426868]=k|aI<<8;b[4830442]=cw+2&65535;o=a[9660897]|0;m=c[cx+72+((aI|256)<<2)>>2]|0;if((m|0)!=0){a[m+k|0]=o;c[f+21432>>2]=2;c[f+21436>>2]=32;break OL}m=c[cx+3148>>2]|0;if((m|0)==0){c[f+21432>>2]=2;c[f+21436>>2]=32;break OL}gg[m&4095]((k|aI<<8)&65535,o);break};case 184:{o=c[2415221]|0;k=c[2437644]|0;m=c[k+72+((o>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){n=c[k+3156>>2]|0;if((n|0)==0){cy=0;cz=o;cA=k;cB=o&65535;break}l=gj[n&4095](o&65535)|0;n=c[2415221]|0;cy=l;cz=n;cA=c[2437644]|0;cB=n&65535}else{cy=a[m+(o&255)|0]|0;cz=o;cA=k;cB=o&65535}}while(0);o=cy&255;k=cz+1|0;m=c[cA+72+((k>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){aI=c[cA+3156>>2]|0;if((aI|0)==0){cC=0;cD=cB;cE=cA;break}n=gj[aI&4095](k&65535)|0;cC=n;cD=b[4830442]|0;cE=c[2437644]|0}else{cC=a[m+(k&255)|0]|0;cD=cB;cE=cA}}while(0);k=cC&255;c[2426868]=k|o<<8;b[4830442]=cD+2&65535;m=c[cE+72+(o<<2)>>2]|0;do{if((m|0)==0){n=c[cE+3144>>2]|0;if((n|0)==0){cF=0;break}cF=gj[n&4095]((k|o<<8)&65535)|0}else{cF=a[m+k|0]|0}}while(0);k=a[9660897]|0;m=k^cF;a[9660897]=m;o=(m&255)>>>4&8|a[9660900]&-15;a[9660900]=k<<24>>24==cF<<24>>24?o|4:o;break};case 185:{o=c[2415221]|0;k=c[2437644]|0;m=c[k+72+((o>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){n=c[k+3156>>2]|0;if((n|0)==0){cG=0;cH=o;cI=k;cJ=o&65535;break}aI=gj[n&4095](o&65535)|0;n=c[2415221]|0;cG=aI;cH=n;cI=c[2437644]|0;cJ=n&65535}else{cG=a[m+(o&255)|0]|0;cH=o;cI=k;cJ=o&65535}}while(0);o=cG&255;k=cH+1|0;m=c[cI+72+((k>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){n=c[cI+3156>>2]|0;if((n|0)==0){cK=0;cL=cJ;cM=cI;break}aI=gj[n&4095](k&65535)|0;cK=aI;cL=b[4830442]|0;cM=c[2437644]|0}else{cK=a[m+(k&255)|0]|0;cL=cJ;cM=cI}}while(0);k=cK&255;c[2426868]=k|o<<8;b[4830442]=cL+2&65535;m=c[cM+72+(o<<2)>>2]|0;do{if((m|0)==0){aI=c[cM+3144>>2]|0;if((aI|0)==0){cN=0;break}cN=gj[aI&4095]((k|o<<8)&65535)|0}else{cN=a[m+k|0]|0}}while(0);k=a[9660897]|0;m=a[9660900]|0;o=(k&255)+(cN&255)+(m&1)|0;aI=o^(k^cN)&255;a[9660900]=(aI<<1&32|o>>>8&1|(aI^o>>>1)>>>6&2|((o&255)<<24>>24==0?(o>>>4&8|m&-48&255)&255|4:(o>>>4&8|m&-48&255)&255)&255)&255;a[9660897]=o&255;break};case 186:{o=c[2415221]|0;m=c[2437644]|0;aI=c[m+72+((o>>>8&255|512)<<2)>>2]|0;do{if((aI|0)==0){k=c[m+3156>>2]|0;if((k|0)==0){cO=0;cP=o;cQ=m;cR=o&65535;break}n=gj[k&4095](o&65535)|0;k=c[2415221]|0;cO=n;cP=k;cQ=c[2437644]|0;cR=k&65535}else{cO=a[aI+(o&255)|0]|0;cP=o;cQ=m;cR=o&65535}}while(0);o=cO&255;m=cP+1|0;aI=c[cQ+72+((m>>>8&255|512)<<2)>>2]|0;do{if((aI|0)==0){k=c[cQ+3156>>2]|0;if((k|0)==0){cS=0;cT=cR;cU=cQ;break}n=gj[k&4095](m&65535)|0;cS=n;cT=b[4830442]|0;cU=c[2437644]|0}else{cS=a[aI+(m&255)|0]|0;cT=cR;cU=cQ}}while(0);m=cS&255;c[2426868]=m|o<<8;b[4830442]=cT+2&65535;aI=c[cU+72+(o<<2)>>2]|0;do{if((aI|0)==0){n=c[cU+3144>>2]|0;if((n|0)==0){cV=0;break}cV=gj[n&4095]((m|o<<8)&65535)|0}else{cV=a[aI+m|0]|0}}while(0);m=a[9660897]|cV;a[9660897]=m;aI=(m&255)>>>4&8|a[9660900]&-15;a[9660900]=m<<24>>24==0?aI|4:aI;break};case 187:{aI=c[2415221]|0;m=c[2437644]|0;o=c[m+72+((aI>>>8&255|512)<<2)>>2]|0;do{if((o|0)==0){n=c[m+3156>>2]|0;if((n|0)==0){cW=0;cX=aI;cY=m;cZ=aI&65535;break}k=gj[n&4095](aI&65535)|0;n=c[2415221]|0;cW=k;cX=n;cY=c[2437644]|0;cZ=n&65535}else{cW=a[o+(aI&255)|0]|0;cX=aI;cY=m;cZ=aI&65535}}while(0);aI=cW&255;m=cX+1|0;o=c[cY+72+((m>>>8&255|512)<<2)>>2]|0;do{if((o|0)==0){n=c[cY+3156>>2]|0;if((n|0)==0){c_=0;c$=cZ;c0=cY;break}k=gj[n&4095](m&65535)|0;c_=k;c$=b[4830442]|0;c0=c[2437644]|0}else{c_=a[o+(m&255)|0]|0;c$=cZ;c0=cY}}while(0);m=c_&255;c[2426868]=m|aI<<8;b[4830442]=c$+2&65535;o=c[c0+72+(aI<<2)>>2]|0;do{if((o|0)==0){k=c[c0+3144>>2]|0;if((k|0)==0){c1=0;break}c1=gj[k&4095]((m|aI<<8)&65535)|0}else{c1=a[o+m|0]|0}}while(0);m=a[9660897]|0;o=(m&255)+(c1&255)|0;aI=(o>>>4&8|a[9660900]&-48&255)&255;k=(m^c1)&255^o;a[9660900]=(k<<1&32|o>>>8&1|(k^o>>>1)>>>6&2|((o&255)<<24>>24==0?aI|4:aI)&255)&255;a[9660897]=o&255;break};case 188:{o=c[2415221]|0;aI=c[2437644]|0;k=c[aI+72+((o>>>8&255|512)<<2)>>2]|0;do{if((k|0)==0){m=c[aI+3156>>2]|0;if((m|0)==0){c2=0;c3=o;c4=aI;c5=o&65535;break}n=gj[m&4095](o&65535)|0;m=c[2415221]|0;c2=n;c3=m;c4=c[2437644]|0;c5=m&65535}else{c2=a[k+(o&255)|0]|0;c3=o;c4=aI;c5=o&65535}}while(0);o=c2&255;aI=c3+1|0;k=c[c4+72+((aI>>>8&255|512)<<2)>>2]|0;do{if((k|0)==0){m=c[c4+3156>>2]|0;if((m|0)==0){c6=0;c7=c5;c8=c4;break}n=gj[m&4095](aI&65535)|0;c6=n;c7=b[4830442]|0;c8=c[2437644]|0}else{c6=a[k+(aI&255)|0]|0;c7=c5;c8=c4}}while(0);aI=c6&255;c[2426868]=aI|o<<8;b[4830442]=c7+2&65535;k=c[c8+72+(o<<2)>>2]|0;do{if((k|0)==0){n=c[c8+3144>>2]|0;if((n|0)==0){c9=0;da=c8;break}m=gj[n&4095]((aI|o<<8)&65535)|0;c9=m;da=c[2437644]|0}else{c9=a[k+aI|0]|0;da=c8}}while(0);k=(c9&255)<<8;m=c[da+72+((((aI|o<<8)+1|0)>>>8&255)<<2)>>2]|0;do{if((m|0)==0){n=c[da+3144>>2]|0;if((n|0)==0){db=0;break}db=gj[n&4095](((aI|o<<8)+1|0)&65535)|0}else{db=a[m+(((aI|o<<8)+1|0)&255)|0]|0}}while(0);o=e[4830446]|0;aI=o-(db&255|k)|0;m=(aI>>>12&8|a[9660900]&-15&255)&255;a[9660900]=(((aI&65535)<<16>>16==0?m|4:m)&255|(o^k^aI^aI>>>1)>>>14&2)&255;break};case 189:{aI=c[2415221]|0;o=c[2437644]|0;m=c[o+72+((aI>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){n=c[o+3156>>2]|0;if((n|0)==0){dc=0;dd=aI;de=o;df=aI&65535;break}l=gj[n&4095](aI&65535)|0;n=c[2415221]|0;dc=l;dd=n;de=c[2437644]|0;df=n&65535}else{dc=a[m+(aI&255)|0]|0;dd=aI;de=o;df=aI&65535}}while(0);aI=(dc&255)<<8;o=dd+1|0;m=c[de+72+((o>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){k=c[de+3156>>2]|0;if((k|0)==0){dg=0;dh=df;di=de;break}n=gj[k&4095](o&65535)|0;dg=n;dh=b[4830442]|0;di=c[2437644]|0}else{dg=a[m+(o&255)|0]|0;dh=df;di=de}}while(0);c[2426868]=dg&255|aI;o=dh+2&65535;b[4830442]=o;m=c[2415222]|0;n=c[di+72+((m>>>8&255|256)<<2)>>2]|0;do{if((n|0)==0){k=c[di+3148>>2]|0;if((k|0)==0){dj=di;break}gg[k&4095](m&65535,o&255);dj=c[2437644]|0}else{a[n+(m&255)|0]=o&255;dj=di}}while(0);b[4830444]=(b[4830444]|0)-1&65535;o=c[2415222]|0;m=a[9660885]|0;n=c[dj+72+((o>>>8&255|256)<<2)>>2]|0;do{if((n|0)==0){aI=c[dj+3148>>2]|0;if((aI|0)==0){break}gg[aI&4095](o&65535,m)}else{a[n+(o&255)|0]=m}}while(0);b[4830444]=(b[4830444]|0)-1&65535;b[4830442]=b[4853736]|0;b[4830442]=c[2415221]&65535;break};case 190:{f3m();break};case 191:{f3n();break};case 192:{m=c[2415221]|0;o=c[2437644]|0;n=c[o+72+((m>>>8&255|512)<<2)>>2]|0;do{if((n|0)==0){aI=c[o+3156>>2]|0;if((aI|0)==0){dk=0;dl=m&65535;break}k=gj[aI&4095](m&65535)|0;dk=k;dl=b[4830442]|0}else{dk=a[n+(m&255)|0]|0;dl=m&65535}}while(0);b[4830442]=dl+1&65535;m=a[9660896]|0;n=(m&255)-(dk&255)|0;o=(n>>>4&8|a[9660900]&-16&255)&255;a[9660900]=(((m^dk)&255^n^n>>>1)>>>6&2|n>>>8&1|((n&255)<<24>>24==0?o|4:o)&255)&255;a[9660896]=n&255;break};case 193:{n=c[2415221]|0;o=c[2437644]|0;m=c[o+72+((n>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){k=c[o+3156>>2]|0;if((k|0)==0){dm=0;dn=n&65535;break}aI=gj[k&4095](n&65535)|0;dm=aI;dn=b[4830442]|0}else{dm=a[m+(n&255)|0]|0;dn=n&65535}}while(0);b[4830442]=dn+1&65535;n=a[9660896]|0;m=(n&255)-(dm&255)|0;o=(m>>>4&8|a[9660900]&-16&255)&255;a[9660900]=(((n^dm)&255^m^m>>>1)>>>6&2|m>>>8&1|((m&255)<<24>>24==0?o|4:o)&255)&255;break};case 194:{o=c[2415221]|0;m=c[2437644]|0;n=c[m+72+((o>>>8&255|512)<<2)>>2]|0;do{if((n|0)==0){aI=c[m+3156>>2]|0;if((aI|0)==0){dp=0;dq=o&65535;break}k=gj[aI&4095](o&65535)|0;dp=k;dq=b[4830442]|0}else{dp=a[n+(o&255)|0]|0;dq=o&65535}}while(0);b[4830442]=dq+1&65535;o=a[9660896]|0;n=a[9660900]|0;m=(o&255)-(dp&255)-(n&1)|0;a[9660900]=((m^(o^dp)&255^m>>>1)>>>6&2|m>>>8&1|((m&255)<<24>>24==0?(m>>>4&8|n&-16&255)&255|4:(m>>>4&8|n&-16&255)&255)&255)&255;a[9660896]=m&255;break};case 196:{m=c[2415221]|0;n=c[2437644]|0;o=c[n+72+((m>>>8&255|512)<<2)>>2]|0;do{if((o|0)==0){k=c[n+3156>>2]|0;if((k|0)==0){dr=0;ds=m&65535;break}aI=gj[k&4095](m&65535)|0;dr=aI;ds=b[4830442]|0}else{dr=a[o+(m&255)|0]|0;ds=m&65535}}while(0);b[4830442]=ds+1&65535;m=a[9660896]&dr;a[9660896]=m;o=(m&255)>>>4&8|a[9660900]&-15;a[9660900]=m<<24>>24==0?o|4:o;break};case 197:{o=c[2415221]|0;m=c[2437644]|0;n=c[m+72+((o>>>8&255|512)<<2)>>2]|0;do{if((n|0)==0){aI=c[m+3156>>2]|0;if((aI|0)==0){dt=0;du=o&65535;break}k=gj[aI&4095](o&65535)|0;dt=k;du=b[4830442]|0}else{dt=a[n+(o&255)|0]|0;du=o&65535}}while(0);b[4830442]=du+1&65535;o=a[9660896]&dt;n=(o&255)>>>4&8|a[9660900]&-15;a[9660900]=o<<24>>24==0?n|4:n;break};default:{i=1}}}if(i){i=0;switch(j|0){case 198:{n=c[2415221]|0;o=c[2437644]|0;m=c[o+72+((n>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){k=c[o+3156>>2]|0;if((k|0)==0){dv=0;dw=n&65535;break}aI=gj[k&4095](n&65535)|0;dv=aI;dw=b[4830442]|0}else{dv=a[m+(n&255)|0]|0;dw=n&65535}}while(0);a[9660896]=dv;b[4830442]=dw+1&65535;n=a[9660900]&-15|(dv&255)>>>4&8;a[9660900]=dv<<24>>24==0?n|4:n;break};case 199:{n=a[9660896]|0;m=(n&255)>>>4&8|a[9660900]&-15;a[9660900]=n<<24>>24==0?m|4:m;b[4830442]=g+2&65535;b[4853736]=h;m=c[2426868]|0;o=c[2437644]|0;aI=c[o+72+((m>>>8&255|256)<<2)>>2]|0;if((aI|0)!=0){a[aI+(m&255)|0]=n;c[f+21432>>2]=2;c[f+21436>>2]=32;break OL}aI=c[o+3148>>2]|0;if((aI|0)==0){c[f+21432>>2]=2;c[f+21436>>2]=32;break OL}gg[aI&4095](m&65535,n);break};case 200:{n=c[2415221]|0;m=c[2437644]|0;aI=c[m+72+((n>>>8&255|512)<<2)>>2]|0;do{if((aI|0)==0){o=c[m+3156>>2]|0;if((o|0)==0){dx=0;dy=n&65535;break}k=gj[o&4095](n&65535)|0;dx=k;dy=b[4830442]|0}else{dx=a[aI+(n&255)|0]|0;dy=n&65535}}while(0);b[4830442]=dy+1&65535;n=a[9660896]|0;aI=n^dx;a[9660896]=aI;m=(aI&255)>>>4&8|a[9660900]&-15;a[9660900]=n<<24>>24==dx<<24>>24?m|4:m;break};case 201:{m=c[2415221]|0;n=c[2437644]|0;aI=c[n+72+((m>>>8&255|512)<<2)>>2]|0;do{if((aI|0)==0){k=c[n+3156>>2]|0;if((k|0)==0){dz=0;dA=m&65535;break}o=gj[k&4095](m&65535)|0;dz=o;dA=b[4830442]|0}else{dz=a[aI+(m&255)|0]|0;dA=m&65535}}while(0);b[4830442]=dA+1&65535;m=a[9660896]|0;aI=a[9660900]|0;n=(m&255)+(dz&255)+(aI&1)|0;o=n^(m^dz)&255;a[9660900]=(o<<1&32|n>>>8&1|(o^n>>>1)>>>6&2|((n&255)<<24>>24==0?(n>>>4&8|aI&-48&255)&255|4:(n>>>4&8|aI&-48&255)&255)&255)&255;a[9660896]=n&255;break};case 202:{n=c[2415221]|0;aI=c[2437644]|0;o=c[aI+72+((n>>>8&255|512)<<2)>>2]|0;do{if((o|0)==0){m=c[aI+3156>>2]|0;if((m|0)==0){dB=0;dC=n&65535;break}k=gj[m&4095](n&65535)|0;dB=k;dC=b[4830442]|0}else{dB=a[o+(n&255)|0]|0;dC=n&65535}}while(0);b[4830442]=dC+1&65535;n=a[9660896]|dB;a[9660896]=n;o=(n&255)>>>4&8|a[9660900]&-15;a[9660900]=n<<24>>24==0?o|4:o;break};case 203:{o=c[2415221]|0;n=c[2437644]|0;aI=c[n+72+((o>>>8&255|512)<<2)>>2]|0;do{if((aI|0)==0){k=c[n+3156>>2]|0;if((k|0)==0){dD=0;dE=o&65535;break}m=gj[k&4095](o&65535)|0;dD=m;dE=b[4830442]|0}else{dD=a[aI+(o&255)|0]|0;dE=o&65535}}while(0);b[4830442]=dE+1&65535;o=a[9660896]|0;aI=(o&255)+(dD&255)|0;n=(aI>>>4&8|a[9660900]&-48&255)&255;m=(o^dD)&255^aI;a[9660900]=(m<<1&32|aI>>>8&1|(m^aI>>>1)>>>6&2|((aI&255)<<24>>24==0?n|4:n)&255)&255;a[9660896]=aI&255;break};case 206:{aI=c[2415221]|0;n=c[2437644]|0;m=c[n+72+((aI>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){o=c[n+3156>>2]|0;if((o|0)==0){dF=0;dG=aI;dH=n;dI=aI&65535;break}k=gj[o&4095](aI&65535)|0;o=c[2415221]|0;dF=k;dG=o;dH=c[2437644]|0;dI=o&65535}else{dF=a[m+(aI&255)|0]|0;dG=aI;dH=n;dI=aI&65535}}while(0);aI=dF&255;n=dG+1|0;m=c[dH+72+((n>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){o=c[dH+3156>>2]|0;if((o|0)==0){dJ=0;dK=dI;break}k=gj[o&4095](n&65535)|0;dJ=k;dK=b[4830442]|0}else{dJ=a[m+(n&255)|0]|0;dK=dI}}while(0);n=dJ&255|aI<<8;c[2415223]=n;b[4830442]=dK+2&65535;m=a[9660900]&-15;a[9660900]=m;if((n|0)==0){dL=(m&255|aI>>>4&8|4)&255}else{dL=(m&255|aI>>>4&8)&255}a[9660900]=dL;break};case 207:{m=b[4830446]|0;n=(m&65535)>>>12&8|a[9660900]&-15&255;a[9660900]=(m<<16>>16==0?n|4:n)&255;b[4853736]=h;b[4830442]=g+3&65535;n=c[2426868]|0;m=a[9660893]|0;k=c[2437644]|0;o=c[k+72+((n>>>8&255|256)<<2)>>2]|0;do{if((o|0)==0){l=c[k+3148>>2]|0;if((l|0)==0){dM=k;break}gg[l&4095](n&65535,m);dM=c[2437644]|0}else{a[o+(n&255)|0]=m;dM=k}}while(0);k=a[9660892]|0;m=c[dM+72+(((n+1|0)>>>8&255|256)<<2)>>2]|0;if((m|0)!=0){a[m+((n+1|0)&255)|0]=k;c[f+21432>>2]=2;c[f+21436>>2]=32;break OL}m=c[dM+3148>>2]|0;if((m|0)==0){c[f+21432>>2]=2;c[f+21436>>2]=32;break OL}gg[m&4095]((n+1|0)&65535,k);break};case 208:{k=c[2415221]|0;m=c[2437644]|0;o=c[m+72+((k>>>8&255|512)<<2)>>2]|0;do{if((o|0)==0){aI=c[m+3156>>2]|0;if((aI|0)==0){dN=0;dO=k&65535;dP=m;break}l=gj[aI&4095](k&65535)|0;dN=l;dO=b[4830442]|0;dP=c[2437644]|0}else{dN=a[o+(k&255)|0]|0;dO=k&65535;dP=m}}while(0);m=dN&255;c[2426868]=m;b[4830442]=dO+1&65535;k=dN&255;o=c[dP+72>>2]|0;do{if((o|0)==0){n=c[dP+3144>>2]|0;if((n|0)==0){dQ=0;break}dQ=gj[n&4095](k)|0}else{dQ=a[o+m|0]|0}}while(0);m=a[9660896]|0;o=(m&255)-(dQ&255)|0;k=(o>>>4&8|a[9660900]&-16&255)&255;a[9660900]=(((m^dQ)&255^o^o>>>1)>>>6&2|o>>>8&1|((o&255)<<24>>24==0?k|4:k)&255)&255;a[9660896]=o&255;break};case 209:{o=c[2415221]|0;k=c[2437644]|0;m=c[k+72+((o>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){n=c[k+3156>>2]|0;if((n|0)==0){dR=0;dS=o&65535;dT=k;break}l=gj[n&4095](o&65535)|0;dR=l;dS=b[4830442]|0;dT=c[2437644]|0}else{dR=a[m+(o&255)|0]|0;dS=o&65535;dT=k}}while(0);k=dR&255;c[2426868]=k;b[4830442]=dS+1&65535;o=dR&255;m=c[dT+72>>2]|0;do{if((m|0)==0){l=c[dT+3144>>2]|0;if((l|0)==0){dU=0;break}dU=gj[l&4095](o)|0}else{dU=a[m+k|0]|0}}while(0);k=a[9660896]|0;m=(k&255)-(dU&255)|0;o=(m>>>4&8|a[9660900]&-16&255)&255;a[9660900]=(((k^dU)&255^m^m>>>1)>>>6&2|m>>>8&1|((m&255)<<24>>24==0?o|4:o)&255)&255;break};case 210:{o=c[2415221]|0;m=c[2437644]|0;k=c[m+72+((o>>>8&255|512)<<2)>>2]|0;do{if((k|0)==0){l=c[m+3156>>2]|0;if((l|0)==0){dV=0;dW=o&65535;dX=m;break}n=gj[l&4095](o&65535)|0;dV=n;dW=b[4830442]|0;dX=c[2437644]|0}else{dV=a[k+(o&255)|0]|0;dW=o&65535;dX=m}}while(0);m=dV&255;c[2426868]=m;b[4830442]=dW+1&65535;o=dV&255;k=c[dX+72>>2]|0;do{if((k|0)==0){n=c[dX+3144>>2]|0;if((n|0)==0){dY=0;break}dY=gj[n&4095](o)|0}else{dY=a[k+m|0]|0}}while(0);m=a[9660896]|0;k=a[9660900]|0;o=(m&255)-(dY&255)-(k&1)|0;a[9660900]=((o^(m^dY)&255^o>>>1)>>>6&2|o>>>8&1|((o&255)<<24>>24==0?(o>>>4&8|k&-16&255)&255|4:(o>>>4&8|k&-16&255)&255)&255)&255;a[9660896]=o&255;break};case 212:{o=c[2415221]|0;k=c[2437644]|0;m=c[k+72+((o>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){n=c[k+3156>>2]|0;if((n|0)==0){dZ=0;d_=o&65535;d$=k;break}l=gj[n&4095](o&65535)|0;dZ=l;d_=b[4830442]|0;d$=c[2437644]|0}else{dZ=a[m+(o&255)|0]|0;d_=o&65535;d$=k}}while(0);k=dZ&255;c[2426868]=k;b[4830442]=d_+1&65535;o=dZ&255;m=c[d$+72>>2]|0;do{if((m|0)==0){l=c[d$+3144>>2]|0;if((l|0)==0){d0=0;break}d0=gj[l&4095](o)|0}else{d0=a[m+k|0]|0}}while(0);k=a[9660896]&d0;a[9660896]=k;m=(k&255)>>>4&8|a[9660900]&-15;a[9660900]=k<<24>>24==0?m|4:m;break};case 213:{m=c[2415221]|0;k=c[2437644]|0;o=c[k+72+((m>>>8&255|512)<<2)>>2]|0;do{if((o|0)==0){l=c[k+3156>>2]|0;if((l|0)==0){d1=0;d2=m&65535;d3=k;break}n=gj[l&4095](m&65535)|0;d1=n;d2=b[4830442]|0;d3=c[2437644]|0}else{d1=a[o+(m&255)|0]|0;d2=m&65535;d3=k}}while(0);k=d1&255;c[2426868]=k;b[4830442]=d2+1&65535;m=d1&255;o=c[d3+72>>2]|0;do{if((o|0)==0){n=c[d3+3144>>2]|0;if((n|0)==0){d4=0;break}d4=gj[n&4095](m)|0}else{d4=a[o+k|0]|0}}while(0);k=a[9660896]&d4;o=(k&255)>>>4&8|a[9660900]&-15;a[9660900]=k<<24>>24==0?o|4:o;break};case 214:{o=c[2415221]|0;k=c[2437644]|0;m=c[k+72+((o>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){n=c[k+3156>>2]|0;if((n|0)==0){d5=0;d6=o&65535;d7=k;break}l=gj[n&4095](o&65535)|0;d5=l;d6=b[4830442]|0;d7=c[2437644]|0}else{d5=a[m+(o&255)|0]|0;d6=o&65535;d7=k}}while(0);k=d5&255;c[2426868]=k;b[4830442]=d6+1&65535;o=d5&255;m=c[d7+72>>2]|0;do{if((m|0)==0){l=c[d7+3144>>2]|0;if((l|0)==0){d8=0;break}d8=gj[l&4095](o)|0}else{d8=a[m+k|0]|0}}while(0);a[9660896]=d8;k=(d8&255)>>>4&8|a[9660900]&-15;a[9660900]=d8<<24>>24==0?k|4:k;break};case 215:{k=a[9660896]|0;m=(k&255)>>>4&8|a[9660900]&-15;a[9660900]=k<<24>>24==0?m|4:m;m=c[2415221]|0;o=c[2437644]|0;l=c[o+72+((m>>>8&255|512)<<2)>>2]|0;do{if((l|0)==0){n=c[o+3156>>2]|0;if((n|0)==0){d9=0;ea=m&65535;eb=k;ec=o;break}aI=gj[n&4095](m&65535)|0;d9=aI;ea=b[4830442]|0;eb=a[9660896]|0;ec=c[2437644]|0}else{d9=a[l+(m&255)|0]|0;ea=m&65535;eb=k;ec=o}}while(0);o=d9&255;c[2426868]=o;b[4830442]=ea+1&65535;k=c[ec+1096>>2]|0;if((k|0)!=0){a[k+o|0]=eb;c[f+21432>>2]=2;c[f+21436>>2]=32;break OL}o=c[ec+3148>>2]|0;if((o|0)==0){c[f+21432>>2]=2;c[f+21436>>2]=32;break OL}gg[o&4095](d9&255,eb);break};case 216:{o=c[2415221]|0;k=c[2437644]|0;m=c[k+72+((o>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){l=c[k+3156>>2]|0;if((l|0)==0){ed=0;ee=o&65535;ef=k;break}aI=gj[l&4095](o&65535)|0;ed=aI;ee=b[4830442]|0;ef=c[2437644]|0}else{ed=a[m+(o&255)|0]|0;ee=o&65535;ef=k}}while(0);k=ed&255;c[2426868]=k;b[4830442]=ee+1&65535;o=ed&255;m=c[ef+72>>2]|0;do{if((m|0)==0){aI=c[ef+3144>>2]|0;if((aI|0)==0){eg=0;break}eg=gj[aI&4095](o)|0}else{eg=a[m+k|0]|0}}while(0);k=a[9660896]|0;m=k^eg;a[9660896]=m;o=(m&255)>>>4&8|a[9660900]&-15;a[9660900]=k<<24>>24==eg<<24>>24?o|4:o;break};case 217:{o=c[2415221]|0;k=c[2437644]|0;m=c[k+72+((o>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){aI=c[k+3156>>2]|0;if((aI|0)==0){eh=0;ei=o&65535;ej=k;break}l=gj[aI&4095](o&65535)|0;eh=l;ei=b[4830442]|0;ej=c[2437644]|0}else{eh=a[m+(o&255)|0]|0;ei=o&65535;ej=k}}while(0);k=eh&255;c[2426868]=k;b[4830442]=ei+1&65535;o=eh&255;m=c[ej+72>>2]|0;do{if((m|0)==0){l=c[ej+3144>>2]|0;if((l|0)==0){ek=0;break}ek=gj[l&4095](o)|0}else{ek=a[m+k|0]|0}}while(0);k=a[9660896]|0;m=a[9660900]|0;o=(k&255)+(ek&255)+(m&1)|0;l=o^(k^ek)&255;a[9660900]=(l<<1&32|o>>>8&1|(l^o>>>1)>>>6&2|((o&255)<<24>>24==0?(o>>>4&8|m&-48&255)&255|4:(o>>>4&8|m&-48&255)&255)&255)&255;a[9660896]=o&255;break};case 218:{o=c[2415221]|0;m=c[2437644]|0;l=c[m+72+((o>>>8&255|512)<<2)>>2]|0;do{if((l|0)==0){k=c[m+3156>>2]|0;if((k|0)==0){el=0;em=o&65535;en=m;break}aI=gj[k&4095](o&65535)|0;el=aI;em=b[4830442]|0;en=c[2437644]|0}else{el=a[l+(o&255)|0]|0;em=o&65535;en=m}}while(0);m=el&255;c[2426868]=m;b[4830442]=em+1&65535;o=el&255;l=c[en+72>>2]|0;do{if((l|0)==0){aI=c[en+3144>>2]|0;if((aI|0)==0){eo=0;break}eo=gj[aI&4095](o)|0}else{eo=a[l+m|0]|0}}while(0);m=a[9660896]|eo;a[9660896]=m;l=(m&255)>>>4&8|a[9660900]&-15;a[9660900]=m<<24>>24==0?l|4:l;break};case 219:{l=c[2415221]|0;m=c[2437644]|0;o=c[m+72+((l>>>8&255|512)<<2)>>2]|0;do{if((o|0)==0){aI=c[m+3156>>2]|0;if((aI|0)==0){ep=0;eq=l&65535;er=m;break}k=gj[aI&4095](l&65535)|0;ep=k;eq=b[4830442]|0;er=c[2437644]|0}else{ep=a[o+(l&255)|0]|0;eq=l&65535;er=m}}while(0);m=ep&255;c[2426868]=m;b[4830442]=eq+1&65535;l=ep&255;o=c[er+72>>2]|0;do{if((o|0)==0){k=c[er+3144>>2]|0;if((k|0)==0){es=0;break}es=gj[k&4095](l)|0}else{es=a[o+m|0]|0}}while(0);m=a[9660896]|0;o=(m&255)+(es&255)|0;l=(o>>>4&8|a[9660900]&-48&255)&255;k=(m^es)&255^o;a[9660900]=(k<<1&32|o>>>8&1|(k^o>>>1)>>>6&2|((o&255)<<24>>24==0?l|4:l)&255)&255;a[9660896]=o&255;break};case 222:{o=c[2415221]|0;l=c[2437644]|0;k=c[l+72+((o>>>8&255|512)<<2)>>2]|0;do{if((k|0)==0){m=c[l+3156>>2]|0;if((m|0)==0){et=0;eu=o&65535;ev=l;break}aI=gj[m&4095](o&65535)|0;et=aI;eu=b[4830442]|0;ev=c[2437644]|0}else{et=a[k+(o&255)|0]|0;eu=o&65535;ev=l}}while(0);l=et&255;c[2426868]=l;b[4830442]=eu+1&65535;o=et&255;k=c[ev+72>>2]|0;do{if((k|0)==0){aI=c[ev+3144>>2]|0;if((aI|0)==0){ew=0;ex=ev;break}m=gj[aI&4095](o)|0;ew=m;ex=c[2437644]|0}else{ew=a[k+l|0]|0;ex=ev}}while(0);k=ew&255;o=c[ex+72+(((l+1|0)>>>8&255)<<2)>>2]|0;do{if((o|0)==0){m=c[ex+3144>>2]|0;if((m|0)==0){ey=0;break}ey=gj[m&4095]((l+1|0)&65535)|0}else{ey=a[o+((l+1|0)&255)|0]|0}}while(0);l=ey&255|k<<8;c[2415223]=l;o=a[9660900]&-15;a[9660900]=o;if((l|0)==0){ez=(o&255|k>>>4&8|4)&255}else{ez=(o&255|k>>>4&8)&255}a[9660900]=ez;break};case 223:{o=b[4830446]|0;l=(o&65535)>>>12&8|a[9660900]&-15&255;a[9660900]=(o<<16>>16==0?l|4:l)&255;l=c[2415221]|0;o=c[2437644]|0;m=c[o+72+((l>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){aI=c[o+3156>>2]|0;if((aI|0)==0){eA=0;eB=l&65535;eC=o;break}n=gj[aI&4095](l&65535)|0;eA=n;eB=b[4830442]|0;eC=c[2437644]|0}else{eA=a[m+(l&255)|0]|0;eB=l&65535;eC=o}}while(0);o=eA&255;c[2426868]=o;b[4830442]=eB+1&65535;l=eA&255;m=a[9660893]|0;k=c[eC+1096>>2]|0;do{if((k|0)==0){n=c[eC+3148>>2]|0;if((n|0)==0){eD=eC;break}gg[n&4095](l,m);eD=c[2437644]|0}else{a[k+o|0]=m;eD=eC}}while(0);m=a[9660892]|0;k=c[eD+72+(((o+1|0)>>>8&255|256)<<2)>>2]|0;if((k|0)!=0){a[k+((o+1|0)&255)|0]=m;c[f+21432>>2]=2;c[f+21436>>2]=32;break OL}k=c[eD+3148>>2]|0;if((k|0)==0){c[f+21432>>2]=2;c[f+21436>>2]=32;break OL}gg[k&4095]((o+1|0)&65535,m);break};case 224:{m=b[4830446]|0;k=c[2415221]|0;l=c[2437644]|0;n=c[l+72+((k>>>8&255|512)<<2)>>2]|0;do{if((n|0)==0){aI=c[l+3156>>2]|0;if((aI|0)==0){eE=0;eF=k&65535;eG=l;break}s=gj[aI&4095](k&65535)|0;eE=s;eF=b[4830442]|0;eG=c[2437644]|0}else{eE=a[n+(k&255)|0]|0;eF=k&65535;eG=l}}while(0);b[4853736]=(eE&255)+m&65535;b[4830442]=eF+1&65535;l=c[2426868]|0;k=c[eG+72+((l>>>8&255)<<2)>>2]|0;do{if((k|0)==0){n=c[eG+3144>>2]|0;if((n|0)==0){eH=0;break}eH=gj[n&4095](l&65535)|0}else{eH=a[k+(l&255)|0]|0}}while(0);l=a[9660896]|0;k=(l&255)-(eH&255)|0;m=(k>>>4&8|a[9660900]&-16&255)&255;a[9660900]=(((l^eH)&255^k^k>>>1)>>>6&2|k>>>8&1|((k&255)<<24>>24==0?m|4:m)&255)&255;a[9660896]=k&255;break};case 225:{k=b[4830446]|0;m=c[2415221]|0;l=c[2437644]|0;n=c[l+72+((m>>>8&255|512)<<2)>>2]|0;do{if((n|0)==0){o=c[l+3156>>2]|0;if((o|0)==0){eI=0;eJ=m&65535;eK=l;break}s=gj[o&4095](m&65535)|0;eI=s;eJ=b[4830442]|0;eK=c[2437644]|0}else{eI=a[n+(m&255)|0]|0;eJ=m&65535;eK=l}}while(0);b[4853736]=(eI&255)+k&65535;b[4830442]=eJ+1&65535;l=c[2426868]|0;m=c[eK+72+((l>>>8&255)<<2)>>2]|0;do{if((m|0)==0){n=c[eK+3144>>2]|0;if((n|0)==0){eL=0;break}eL=gj[n&4095](l&65535)|0}else{eL=a[m+(l&255)|0]|0}}while(0);l=a[9660896]|0;m=(l&255)-(eL&255)|0;k=(m>>>4&8|a[9660900]&-16&255)&255;a[9660900]=(((l^eL)&255^m^m>>>1)>>>6&2|m>>>8&1|((m&255)<<24>>24==0?k|4:k)&255)&255;break};case 226:{k=b[4830446]|0;m=c[2415221]|0;l=c[2437644]|0;n=c[l+72+((m>>>8&255|512)<<2)>>2]|0;do{if((n|0)==0){s=c[l+3156>>2]|0;if((s|0)==0){eM=0;eN=m&65535;eO=l;break}o=gj[s&4095](m&65535)|0;eM=o;eN=b[4830442]|0;eO=c[2437644]|0}else{eM=a[n+(m&255)|0]|0;eN=m&65535;eO=l}}while(0);b[4853736]=(eM&255)+k&65535;b[4830442]=eN+1&65535;l=c[2426868]|0;m=c[eO+72+((l>>>8&255)<<2)>>2]|0;do{if((m|0)==0){n=c[eO+3144>>2]|0;if((n|0)==0){eP=0;break}eP=gj[n&4095](l&65535)|0}else{eP=a[m+(l&255)|0]|0}}while(0);l=a[9660896]|0;m=a[9660900]|0;k=(l&255)-(eP&255)-(m&1)|0;a[9660900]=((k^(l^eP)&255^k>>>1)>>>6&2|k>>>8&1|((k&255)<<24>>24==0?(k>>>4&8|m&-16&255)&255|4:(k>>>4&8|m&-16&255)&255)&255)&255;a[9660896]=k&255;break};case 228:{k=b[4830446]|0;m=c[2415221]|0;l=c[2437644]|0;n=c[l+72+((m>>>8&255|512)<<2)>>2]|0;do{if((n|0)==0){o=c[l+3156>>2]|0;if((o|0)==0){eQ=0;eR=m&65535;eS=l;break}s=gj[o&4095](m&65535)|0;eQ=s;eR=b[4830442]|0;eS=c[2437644]|0}else{eQ=a[n+(m&255)|0]|0;eR=m&65535;eS=l}}while(0);b[4853736]=(eQ&255)+k&65535;b[4830442]=eR+1&65535;l=c[2426868]|0;m=c[eS+72+((l>>>8&255)<<2)>>2]|0;do{if((m|0)==0){n=c[eS+3144>>2]|0;if((n|0)==0){eT=0;break}eT=gj[n&4095](l&65535)|0}else{eT=a[m+(l&255)|0]|0}}while(0);l=a[9660896]&eT;a[9660896]=l;m=(l&255)>>>4&8|a[9660900]&-15;a[9660900]=l<<24>>24==0?m|4:m;break};case 229:{m=b[4830446]|0;l=c[2415221]|0;k=c[2437644]|0;n=c[k+72+((l>>>8&255|512)<<2)>>2]|0;do{if((n|0)==0){s=c[k+3156>>2]|0;if((s|0)==0){eU=0;eV=l&65535;eW=k;break}o=gj[s&4095](l&65535)|0;eU=o;eV=b[4830442]|0;eW=c[2437644]|0}else{eU=a[n+(l&255)|0]|0;eV=l&65535;eW=k}}while(0);b[4853736]=(eU&255)+m&65535;b[4830442]=eV+1&65535;k=c[2426868]|0;l=c[eW+72+((k>>>8&255)<<2)>>2]|0;do{if((l|0)==0){n=c[eW+3144>>2]|0;if((n|0)==0){eX=0;break}eX=gj[n&4095](k&65535)|0}else{eX=a[l+(k&255)|0]|0}}while(0);k=a[9660896]&eX;l=(k&255)>>>4&8|a[9660900]&-15;a[9660900]=k<<24>>24==0?l|4:l;break};case 230:{l=b[4830446]|0;k=c[2415221]|0;m=c[2437644]|0;n=c[m+72+((k>>>8&255|512)<<2)>>2]|0;do{if((n|0)==0){o=c[m+3156>>2]|0;if((o|0)==0){eY=0;eZ=k&65535;e_=m;break}s=gj[o&4095](k&65535)|0;eY=s;eZ=b[4830442]|0;e_=c[2437644]|0}else{eY=a[n+(k&255)|0]|0;eZ=k&65535;e_=m}}while(0);b[4853736]=(eY&255)+l&65535;b[4830442]=eZ+1&65535;m=c[2426868]|0;k=c[e_+72+((m>>>8&255)<<2)>>2]|0;do{if((k|0)==0){n=c[e_+3144>>2]|0;if((n|0)==0){e$=0;break}e$=gj[n&4095](m&65535)|0}else{e$=a[k+(m&255)|0]|0}}while(0);a[9660896]=e$;m=(e$&255)>>>4&8|a[9660900]&-15;a[9660900]=e$<<24>>24==0?m|4:m;break};case 231:{m=a[9660896]|0;k=(m&255)>>>4&8|a[9660900]&-15;a[9660900]=m<<24>>24==0?k|4:k;k=b[4830446]|0;l=c[2415221]|0;n=c[2437644]|0;s=c[n+72+((l>>>8&255|512)<<2)>>2]|0;do{if((s|0)==0){o=c[n+3156>>2]|0;if((o|0)==0){e0=0;e1=l&65535;e2=m;e3=n;break}aI=gj[o&4095](l&65535)|0;e0=aI;e1=b[4830442]|0;e2=a[9660896]|0;e3=c[2437644]|0}else{e0=a[s+(l&255)|0]|0;e1=l&65535;e2=m;e3=n}}while(0);b[4853736]=(e0&255)+k&65535;b[4830442]=e1+1&65535;n=c[2426868]|0;m=c[e3+72+((n>>>8&255|256)<<2)>>2]|0;if((m|0)!=0){a[m+(n&255)|0]=e2;c[f+21432>>2]=2;c[f+21436>>2]=32;break OL}m=c[e3+3148>>2]|0;if((m|0)==0){c[f+21432>>2]=2;c[f+21436>>2]=32;break OL}gg[m&4095](n&65535,e2);break};case 232:{n=b[4830446]|0;m=c[2415221]|0;l=c[2437644]|0;s=c[l+72+((m>>>8&255|512)<<2)>>2]|0;do{if((s|0)==0){aI=c[l+3156>>2]|0;if((aI|0)==0){e4=0;e5=m&65535;e6=l;break}o=gj[aI&4095](m&65535)|0;e4=o;e5=b[4830442]|0;e6=c[2437644]|0}else{e4=a[s+(m&255)|0]|0;e5=m&65535;e6=l}}while(0);b[4853736]=(e4&255)+n&65535;b[4830442]=e5+1&65535;l=c[2426868]|0;m=c[e6+72+((l>>>8&255)<<2)>>2]|0;do{if((m|0)==0){s=c[e6+3144>>2]|0;if((s|0)==0){e7=0;break}e7=gj[s&4095](l&65535)|0}else{e7=a[m+(l&255)|0]|0}}while(0);l=a[9660896]|0;m=l^e7;a[9660896]=m;n=(m&255)>>>4&8|a[9660900]&-15;a[9660900]=l<<24>>24==e7<<24>>24?n|4:n;break};case 233:{n=b[4830446]|0;l=c[2415221]|0;m=c[2437644]|0;s=c[m+72+((l>>>8&255|512)<<2)>>2]|0;do{if((s|0)==0){k=c[m+3156>>2]|0;if((k|0)==0){e8=0;e9=l&65535;fa=m;break}o=gj[k&4095](l&65535)|0;e8=o;e9=b[4830442]|0;fa=c[2437644]|0}else{e8=a[s+(l&255)|0]|0;e9=l&65535;fa=m}}while(0);b[4853736]=(e8&255)+n&65535;b[4830442]=e9+1&65535;m=c[2426868]|0;l=c[fa+72+((m>>>8&255)<<2)>>2]|0;do{if((l|0)==0){s=c[fa+3144>>2]|0;if((s|0)==0){fb=0;break}fb=gj[s&4095](m&65535)|0}else{fb=a[l+(m&255)|0]|0}}while(0);m=a[9660896]|0;l=a[9660900]|0;n=(m&255)+(fb&255)+(l&1)|0;s=n^(m^fb)&255;a[9660900]=(s<<1&32|n>>>8&1|(s^n>>>1)>>>6&2|((n&255)<<24>>24==0?(n>>>4&8|l&-48&255)&255|4:(n>>>4&8|l&-48&255)&255)&255)&255;a[9660896]=n&255;break};case 234:{n=b[4830446]|0;l=c[2415221]|0;s=c[2437644]|0;m=c[s+72+((l>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){o=c[s+3156>>2]|0;if((o|0)==0){fc=0;fd=l&65535;fe=s;break}k=gj[o&4095](l&65535)|0;fc=k;fd=b[4830442]|0;fe=c[2437644]|0}else{fc=a[m+(l&255)|0]|0;fd=l&65535;fe=s}}while(0);b[4853736]=(fc&255)+n&65535;b[4830442]=fd+1&65535;s=c[2426868]|0;l=c[fe+72+((s>>>8&255)<<2)>>2]|0;do{if((l|0)==0){m=c[fe+3144>>2]|0;if((m|0)==0){ff=0;break}ff=gj[m&4095](s&65535)|0}else{ff=a[l+(s&255)|0]|0}}while(0);s=a[9660896]|ff;a[9660896]=s;l=(s&255)>>>4&8|a[9660900]&-15;a[9660900]=s<<24>>24==0?l|4:l;break};case 235:{l=b[4830446]|0;s=c[2415221]|0;n=c[2437644]|0;m=c[n+72+((s>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){k=c[n+3156>>2]|0;if((k|0)==0){fg=0;fh=s&65535;fi=n;break}o=gj[k&4095](s&65535)|0;fg=o;fh=b[4830442]|0;fi=c[2437644]|0}else{fg=a[m+(s&255)|0]|0;fh=s&65535;fi=n}}while(0);b[4853736]=(fg&255)+l&65535;b[4830442]=fh+1&65535;n=c[2426868]|0;s=c[fi+72+((n>>>8&255)<<2)>>2]|0;do{if((s|0)==0){m=c[fi+3144>>2]|0;if((m|0)==0){fj=0;break}fj=gj[m&4095](n&65535)|0}else{fj=a[s+(n&255)|0]|0}}while(0);n=a[9660896]|0;s=(n&255)+(fj&255)|0;l=(s>>>4&8|a[9660900]&-48&255)&255;m=(n^fj)&255^s;a[9660900]=(m<<1&32|s>>>8&1|(m^s>>>1)>>>6&2|((s&255)<<24>>24==0?l|4:l)&255)&255;a[9660896]=s&255;break};default:{i=1}}}if(i){i=0;switch(j|0){case 238:{s=b[4830446]|0;l=c[2415221]|0;m=c[2437644]|0;n=c[m+72+((l>>>8&255|512)<<2)>>2]|0;do{if((n|0)==0){o=c[m+3156>>2]|0;if((o|0)==0){fk=0;fl=l&65535;fm=m;break}k=gj[o&4095](l&65535)|0;fk=k;fl=b[4830442]|0;fm=c[2437644]|0}else{fk=a[n+(l&255)|0]|0;fl=l&65535;fm=m}}while(0);b[4853736]=(fk&255)+s&65535;b[4830442]=fl+1&65535;m=c[2426868]|0;l=c[fm+72+((m>>>8&255)<<2)>>2]|0;do{if((l|0)==0){n=c[fm+3144>>2]|0;if((n|0)==0){fn=0;fo=fm;break}k=gj[n&4095](m&65535)|0;fn=k;fo=c[2437644]|0}else{fn=a[l+(m&255)|0]|0;fo=fm}}while(0);l=fn&255;s=c[fo+72+(((m+1|0)>>>8&255)<<2)>>2]|0;do{if((s|0)==0){k=c[fo+3144>>2]|0;if((k|0)==0){fp=0;break}fp=gj[k&4095]((m+1|0)&65535)|0}else{fp=a[s+((m+1|0)&255)|0]|0}}while(0);m=fp&255|l<<8;c[2415223]=m;s=a[9660900]&-15;a[9660900]=s;if((m|0)==0){fq=(s&255|l>>>4&8|4)&255}else{fq=(s&255|l>>>4&8)&255}a[9660900]=fq;break};case 239:{s=b[4830446]|0;m=(s&65535)>>>12&8|a[9660900]&-15&255;a[9660900]=(s<<16>>16==0?m|4:m)&255;m=c[2415221]|0;k=c[2437644]|0;n=c[k+72+((m>>>8&255|512)<<2)>>2]|0;do{if((n|0)==0){o=c[k+3156>>2]|0;if((o|0)==0){fr=0;fs=m&65535;ft=k;break}aI=gj[o&4095](m&65535)|0;fr=aI;fs=b[4830442]|0;ft=c[2437644]|0}else{fr=a[n+(m&255)|0]|0;fs=m&65535;ft=k}}while(0);b[4853736]=(fr&255)+s&65535;b[4830442]=fs+1&65535;k=c[2426868]|0;m=a[9660893]|0;n=c[ft+72+((k>>>8&255|256)<<2)>>2]|0;do{if((n|0)==0){l=c[ft+3148>>2]|0;if((l|0)==0){fu=ft;break}gg[l&4095](k&65535,m);fu=c[2437644]|0}else{a[n+(k&255)|0]=m;fu=ft}}while(0);m=a[9660892]|0;n=c[fu+72+(((k+1|0)>>>8&255|256)<<2)>>2]|0;if((n|0)!=0){a[n+((k+1|0)&255)|0]=m;c[f+21432>>2]=2;c[f+21436>>2]=32;break OL}n=c[fu+3148>>2]|0;if((n|0)==0){c[f+21432>>2]=2;c[f+21436>>2]=32;break OL}gg[n&4095]((k+1|0)&65535,m);break};case 240:{m=c[2415221]|0;n=c[2437644]|0;s=c[n+72+((m>>>8&255|512)<<2)>>2]|0;do{if((s|0)==0){l=c[n+3156>>2]|0;if((l|0)==0){fv=0;fw=m;fx=n;fy=m&65535;break}aI=gj[l&4095](m&65535)|0;l=c[2415221]|0;fv=aI;fw=l;fx=c[2437644]|0;fy=l&65535}else{fv=a[s+(m&255)|0]|0;fw=m;fx=n;fy=m&65535}}while(0);m=fv&255;n=fw+1|0;s=c[fx+72+((n>>>8&255|512)<<2)>>2]|0;do{if((s|0)==0){k=c[fx+3156>>2]|0;if((k|0)==0){fz=0;fA=fy;fB=fx;break}l=gj[k&4095](n&65535)|0;fz=l;fA=b[4830442]|0;fB=c[2437644]|0}else{fz=a[s+(n&255)|0]|0;fA=fy;fB=fx}}while(0);n=fz&255;c[2426868]=n|m<<8;b[4830442]=fA+2&65535;s=c[fB+72+(m<<2)>>2]|0;do{if((s|0)==0){l=c[fB+3144>>2]|0;if((l|0)==0){fC=0;break}fC=gj[l&4095]((n|m<<8)&65535)|0}else{fC=a[s+n|0]|0}}while(0);n=a[9660896]|0;s=(n&255)-(fC&255)|0;m=(s>>>4&8|a[9660900]&-16&255)&255;a[9660900]=(((n^fC)&255^s^s>>>1)>>>6&2|s>>>8&1|((s&255)<<24>>24==0?m|4:m)&255)&255;a[9660896]=s&255;break};case 241:{s=c[2415221]|0;m=c[2437644]|0;n=c[m+72+((s>>>8&255|512)<<2)>>2]|0;do{if((n|0)==0){l=c[m+3156>>2]|0;if((l|0)==0){fD=0;fE=s;fF=m;fG=s&65535;break}k=gj[l&4095](s&65535)|0;l=c[2415221]|0;fD=k;fE=l;fF=c[2437644]|0;fG=l&65535}else{fD=a[n+(s&255)|0]|0;fE=s;fF=m;fG=s&65535}}while(0);s=fD&255;m=fE+1|0;n=c[fF+72+((m>>>8&255|512)<<2)>>2]|0;do{if((n|0)==0){l=c[fF+3156>>2]|0;if((l|0)==0){fH=0;fI=fG;fJ=fF;break}k=gj[l&4095](m&65535)|0;fH=k;fI=b[4830442]|0;fJ=c[2437644]|0}else{fH=a[n+(m&255)|0]|0;fI=fG;fJ=fF}}while(0);m=fH&255;c[2426868]=m|s<<8;b[4830442]=fI+2&65535;n=c[fJ+72+(s<<2)>>2]|0;do{if((n|0)==0){k=c[fJ+3144>>2]|0;if((k|0)==0){fK=0;break}fK=gj[k&4095]((m|s<<8)&65535)|0}else{fK=a[n+m|0]|0}}while(0);m=a[9660896]|0;n=(m&255)-(fK&255)|0;s=(n>>>4&8|a[9660900]&-16&255)&255;a[9660900]=(((m^fK)&255^n^n>>>1)>>>6&2|n>>>8&1|((n&255)<<24>>24==0?s|4:s)&255)&255;break};case 242:{s=c[2415221]|0;n=c[2437644]|0;m=c[n+72+((s>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){k=c[n+3156>>2]|0;if((k|0)==0){fL=0;fM=s;fN=n;fO=s&65535;break}l=gj[k&4095](s&65535)|0;k=c[2415221]|0;fL=l;fM=k;fN=c[2437644]|0;fO=k&65535}else{fL=a[m+(s&255)|0]|0;fM=s;fN=n;fO=s&65535}}while(0);s=fL&255;n=fM+1|0;m=c[fN+72+((n>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){k=c[fN+3156>>2]|0;if((k|0)==0){fP=0;fQ=fO;fR=fN;break}l=gj[k&4095](n&65535)|0;fP=l;fQ=b[4830442]|0;fR=c[2437644]|0}else{fP=a[m+(n&255)|0]|0;fQ=fO;fR=fN}}while(0);n=fP&255;c[2426868]=n|s<<8;b[4830442]=fQ+2&65535;m=c[fR+72+(s<<2)>>2]|0;do{if((m|0)==0){l=c[fR+3144>>2]|0;if((l|0)==0){fS=0;break}fS=gj[l&4095]((n|s<<8)&65535)|0}else{fS=a[m+n|0]|0}}while(0);n=a[9660896]|0;m=a[9660900]|0;s=(n&255)-(fS&255)-(m&1)|0;a[9660900]=((s^(n^fS)&255^s>>>1)>>>6&2|s>>>8&1|((s&255)<<24>>24==0?(s>>>4&8|m&-16&255)&255|4:(s>>>4&8|m&-16&255)&255)&255)&255;a[9660896]=s&255;break};case 244:{s=c[2415221]|0;m=c[2437644]|0;n=c[m+72+((s>>>8&255|512)<<2)>>2]|0;do{if((n|0)==0){l=c[m+3156>>2]|0;if((l|0)==0){fT=0;fU=s;fV=m;fW=s&65535;break}k=gj[l&4095](s&65535)|0;l=c[2415221]|0;fT=k;fU=l;fV=c[2437644]|0;fW=l&65535}else{fT=a[n+(s&255)|0]|0;fU=s;fV=m;fW=s&65535}}while(0);s=fT&255;m=fU+1|0;n=c[fV+72+((m>>>8&255|512)<<2)>>2]|0;do{if((n|0)==0){l=c[fV+3156>>2]|0;if((l|0)==0){fX=0;fY=fW;fZ=fV;break}k=gj[l&4095](m&65535)|0;fX=k;fY=b[4830442]|0;fZ=c[2437644]|0}else{fX=a[n+(m&255)|0]|0;fY=fW;fZ=fV}}while(0);m=fX&255;c[2426868]=m|s<<8;b[4830442]=fY+2&65535;n=c[fZ+72+(s<<2)>>2]|0;do{if((n|0)==0){k=c[fZ+3144>>2]|0;if((k|0)==0){f_=0;break}f_=gj[k&4095]((m|s<<8)&65535)|0}else{f_=a[n+m|0]|0}}while(0);m=a[9660896]&f_;a[9660896]=m;n=(m&255)>>>4&8|a[9660900]&-15;a[9660900]=m<<24>>24==0?n|4:n;break};case 245:{n=c[2415221]|0;m=c[2437644]|0;s=c[m+72+((n>>>8&255|512)<<2)>>2]|0;do{if((s|0)==0){k=c[m+3156>>2]|0;if((k|0)==0){f$=0;f0=n;f1=m;f2=n&65535;break}l=gj[k&4095](n&65535)|0;k=c[2415221]|0;f$=l;f0=k;f1=c[2437644]|0;f2=k&65535}else{f$=a[s+(n&255)|0]|0;f0=n;f1=m;f2=n&65535}}while(0);n=f$&255;m=f0+1|0;s=c[f1+72+((m>>>8&255|512)<<2)>>2]|0;do{if((s|0)==0){k=c[f1+3156>>2]|0;if((k|0)==0){f3=0;f4=f2;f5=f1;break}l=gj[k&4095](m&65535)|0;f3=l;f4=b[4830442]|0;f5=c[2437644]|0}else{f3=a[s+(m&255)|0]|0;f4=f2;f5=f1}}while(0);m=f3&255;c[2426868]=m|n<<8;b[4830442]=f4+2&65535;s=c[f5+72+(n<<2)>>2]|0;do{if((s|0)==0){l=c[f5+3144>>2]|0;if((l|0)==0){f6=0;break}f6=gj[l&4095]((m|n<<8)&65535)|0}else{f6=a[s+m|0]|0}}while(0);m=a[9660896]&f6;s=(m&255)>>>4&8|a[9660900]&-15;a[9660900]=m<<24>>24==0?s|4:s;break};case 246:{s=c[2415221]|0;m=c[2437644]|0;n=c[m+72+((s>>>8&255|512)<<2)>>2]|0;do{if((n|0)==0){l=c[m+3156>>2]|0;if((l|0)==0){f7=0;f8=s;f9=m;ga=s&65535;break}k=gj[l&4095](s&65535)|0;l=c[2415221]|0;f7=k;f8=l;f9=c[2437644]|0;ga=l&65535}else{f7=a[n+(s&255)|0]|0;f8=s;f9=m;ga=s&65535}}while(0);s=f7&255;m=f8+1|0;n=c[f9+72+((m>>>8&255|512)<<2)>>2]|0;do{if((n|0)==0){l=c[f9+3156>>2]|0;if((l|0)==0){gb=0;gc=ga;gd=f9;break}k=gj[l&4095](m&65535)|0;gb=k;gc=b[4830442]|0;gd=c[2437644]|0}else{gb=a[n+(m&255)|0]|0;gc=ga;gd=f9}}while(0);m=gb&255;c[2426868]=m|s<<8;b[4830442]=gc+2&65535;n=c[gd+72+(s<<2)>>2]|0;do{if((n|0)==0){k=c[gd+3144>>2]|0;if((k|0)==0){ge=0;break}ge=gj[k&4095]((m|s<<8)&65535)|0}else{ge=a[n+m|0]|0}}while(0);a[9660896]=ge;m=(ge&255)>>>4&8|a[9660900]&-15;a[9660900]=ge<<24>>24==0?m|4:m;break};case 247:{m=a[9660896]|0;n=(m&255)>>>4&8|a[9660900]&-15;a[9660900]=m<<24>>24==0?n|4:n;n=c[2415221]|0;m=c[2437644]|0;s=c[m+72+((n>>>8&255|512)<<2)>>2]|0;do{if((s|0)==0){k=c[m+3156>>2]|0;if((k|0)==0){gf=0;gh=n;gi=m;gk=n&65535;break}l=gj[k&4095](n&65535)|0;k=c[2415221]|0;gf=l;gh=k;gi=c[2437644]|0;gk=k&65535}else{gf=a[s+(n&255)|0]|0;gh=n;gi=m;gk=n&65535}}while(0);n=gf&255;m=gh+1|0;s=c[gi+72+((m>>>8&255|512)<<2)>>2]|0;do{if((s|0)==0){k=c[gi+3156>>2]|0;if((k|0)==0){gl=0;gm=gk;gn=gi;break}l=gj[k&4095](m&65535)|0;gl=l;gm=b[4830442]|0;gn=c[2437644]|0}else{gl=a[s+(m&255)|0]|0;gm=gk;gn=gi}}while(0);m=gl&255;c[2426868]=m|n<<8;b[4830442]=gm+2&65535;s=a[9660896]|0;l=c[gn+72+((n|256)<<2)>>2]|0;if((l|0)!=0){a[l+m|0]=s;c[f+21432>>2]=2;c[f+21436>>2]=32;break OL}l=c[gn+3148>>2]|0;if((l|0)==0){c[f+21432>>2]=2;c[f+21436>>2]=32;break OL}gg[l&4095]((m|n<<8)&65535,s);break};case 248:{s=c[2415221]|0;m=c[2437644]|0;l=c[m+72+((s>>>8&255|512)<<2)>>2]|0;do{if((l|0)==0){k=c[m+3156>>2]|0;if((k|0)==0){go=0;gp=s;gq=m;gr=s&65535;break}aI=gj[k&4095](s&65535)|0;k=c[2415221]|0;go=aI;gp=k;gq=c[2437644]|0;gr=k&65535}else{go=a[l+(s&255)|0]|0;gp=s;gq=m;gr=s&65535}}while(0);s=go&255;m=gp+1|0;l=c[gq+72+((m>>>8&255|512)<<2)>>2]|0;do{if((l|0)==0){n=c[gq+3156>>2]|0;if((n|0)==0){gs=0;gt=gr;gu=gq;break}k=gj[n&4095](m&65535)|0;gs=k;gt=b[4830442]|0;gu=c[2437644]|0}else{gs=a[l+(m&255)|0]|0;gt=gr;gu=gq}}while(0);m=gs&255;c[2426868]=m|s<<8;b[4830442]=gt+2&65535;l=c[gu+72+(s<<2)>>2]|0;do{if((l|0)==0){k=c[gu+3144>>2]|0;if((k|0)==0){gv=0;break}gv=gj[k&4095]((m|s<<8)&65535)|0}else{gv=a[l+m|0]|0}}while(0);m=a[9660896]|0;l=m^gv;a[9660896]=l;s=(l&255)>>>4&8|a[9660900]&-15;a[9660900]=m<<24>>24==gv<<24>>24?s|4:s;break};case 249:{s=c[2415221]|0;m=c[2437644]|0;l=c[m+72+((s>>>8&255|512)<<2)>>2]|0;do{if((l|0)==0){k=c[m+3156>>2]|0;if((k|0)==0){gw=0;gx=s;gy=m;gz=s&65535;break}n=gj[k&4095](s&65535)|0;k=c[2415221]|0;gw=n;gx=k;gy=c[2437644]|0;gz=k&65535}else{gw=a[l+(s&255)|0]|0;gx=s;gy=m;gz=s&65535}}while(0);s=gw&255;m=gx+1|0;l=c[gy+72+((m>>>8&255|512)<<2)>>2]|0;do{if((l|0)==0){k=c[gy+3156>>2]|0;if((k|0)==0){gA=0;gB=gz;gC=gy;break}n=gj[k&4095](m&65535)|0;gA=n;gB=b[4830442]|0;gC=c[2437644]|0}else{gA=a[l+(m&255)|0]|0;gB=gz;gC=gy}}while(0);m=gA&255;c[2426868]=m|s<<8;b[4830442]=gB+2&65535;l=c[gC+72+(s<<2)>>2]|0;do{if((l|0)==0){n=c[gC+3144>>2]|0;if((n|0)==0){gD=0;break}gD=gj[n&4095]((m|s<<8)&65535)|0}else{gD=a[l+m|0]|0}}while(0);m=a[9660896]|0;l=a[9660900]|0;s=(m&255)+(gD&255)+(l&1)|0;n=s^(m^gD)&255;a[9660900]=(n<<1&32|s>>>8&1|(n^s>>>1)>>>6&2|((s&255)<<24>>24==0?(s>>>4&8|l&-48&255)&255|4:(s>>>4&8|l&-48&255)&255)&255)&255;a[9660896]=s&255;break};case 250:{s=c[2415221]|0;l=c[2437644]|0;n=c[l+72+((s>>>8&255|512)<<2)>>2]|0;do{if((n|0)==0){m=c[l+3156>>2]|0;if((m|0)==0){gE=0;gF=s;gG=l;gH=s&65535;break}k=gj[m&4095](s&65535)|0;m=c[2415221]|0;gE=k;gF=m;gG=c[2437644]|0;gH=m&65535}else{gE=a[n+(s&255)|0]|0;gF=s;gG=l;gH=s&65535}}while(0);s=gE&255;l=gF+1|0;n=c[gG+72+((l>>>8&255|512)<<2)>>2]|0;do{if((n|0)==0){m=c[gG+3156>>2]|0;if((m|0)==0){gI=0;gJ=gH;gK=gG;break}k=gj[m&4095](l&65535)|0;gI=k;gJ=b[4830442]|0;gK=c[2437644]|0}else{gI=a[n+(l&255)|0]|0;gJ=gH;gK=gG}}while(0);l=gI&255;c[2426868]=l|s<<8;b[4830442]=gJ+2&65535;n=c[gK+72+(s<<2)>>2]|0;do{if((n|0)==0){k=c[gK+3144>>2]|0;if((k|0)==0){gL=0;break}gL=gj[k&4095]((l|s<<8)&65535)|0}else{gL=a[n+l|0]|0}}while(0);l=a[9660896]|gL;a[9660896]=l;n=(l&255)>>>4&8|a[9660900]&-15;a[9660900]=l<<24>>24==0?n|4:n;break};case 251:{n=c[2415221]|0;l=c[2437644]|0;s=c[l+72+((n>>>8&255|512)<<2)>>2]|0;do{if((s|0)==0){k=c[l+3156>>2]|0;if((k|0)==0){gM=0;gN=n;gO=l;gP=n&65535;break}m=gj[k&4095](n&65535)|0;k=c[2415221]|0;gM=m;gN=k;gO=c[2437644]|0;gP=k&65535}else{gM=a[s+(n&255)|0]|0;gN=n;gO=l;gP=n&65535}}while(0);n=gM&255;l=gN+1|0;s=c[gO+72+((l>>>8&255|512)<<2)>>2]|0;do{if((s|0)==0){k=c[gO+3156>>2]|0;if((k|0)==0){gQ=0;gR=gP;gS=gO;break}m=gj[k&4095](l&65535)|0;gQ=m;gR=b[4830442]|0;gS=c[2437644]|0}else{gQ=a[s+(l&255)|0]|0;gR=gP;gS=gO}}while(0);l=gQ&255;c[2426868]=l|n<<8;b[4830442]=gR+2&65535;s=c[gS+72+(n<<2)>>2]|0;do{if((s|0)==0){m=c[gS+3144>>2]|0;if((m|0)==0){gT=0;break}gT=gj[m&4095]((l|n<<8)&65535)|0}else{gT=a[s+l|0]|0}}while(0);l=a[9660896]|0;s=(l&255)+(gT&255)|0;n=(s>>>4&8|a[9660900]&-48&255)&255;m=(l^gT)&255^s;a[9660900]=(m<<1&32|s>>>8&1|(m^s>>>1)>>>6&2|((s&255)<<24>>24==0?n|4:n)&255)&255;a[9660896]=s&255;break};case 252:{s=c[2415221]|0;n=c[2437644]|0;m=c[n+72+((s>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){l=c[n+3156>>2]|0;if((l|0)==0){gU=0;gV=s;gW=n;gX=s&65535;break}k=gj[l&4095](s&65535)|0;l=c[2415221]|0;gU=k;gV=l;gW=c[2437644]|0;gX=l&65535}else{gU=a[m+(s&255)|0]|0;gV=s;gW=n;gX=s&65535}}while(0);s=gU&255;n=gV+1|0;m=c[gW+72+((n>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){l=c[gW+3156>>2]|0;if((l|0)==0){gY=0;gZ=gX;g_=gW;break}k=gj[l&4095](n&65535)|0;gY=k;gZ=b[4830442]|0;g_=c[2437644]|0}else{gY=a[m+(n&255)|0]|0;gZ=gX;g_=gW}}while(0);n=gY&255;c[2426868]=n|s<<8;b[4830442]=gZ+2&65535;m=c[g_+72+(s<<2)>>2]|0;do{if((m|0)==0){k=c[g_+3144>>2]|0;if((k|0)==0){g$=0;g0=g_;break}l=gj[k&4095]((n|s<<8)&65535)|0;g$=l;g0=c[2437644]|0}else{g$=a[m+n|0]|0;g0=g_}}while(0);m=(g$&255)<<8;l=c[g0+72+((((n|s<<8)+1|0)>>>8&255)<<2)>>2]|0;do{if((l|0)==0){k=c[g0+3144>>2]|0;if((k|0)==0){g1=0;break}g1=gj[k&4095](((n|s<<8)+1|0)&65535)|0}else{g1=a[l+(((n|s<<8)+1|0)&255)|0]|0}}while(0);s=e[4830446]|0;n=s+(g1&255|m)|0;l=(n>>>12&8|a[9660900]&-16&255)&255;a[9660900]=((s^m^n^n>>>1)>>>14&2|n>>>16&1|((n&65535)<<16>>16==0?l|4:l)&255)&255;b[4830446]=n&65535;break};case 254:{f4a();break};case 255:{f4b();break};default:{}}}}while(0);c[f+21416>>2]=i}function __Z13m6803_executei$0(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0,cf=0,cg=0,ch=0,ci=0,cj=0,ck=0,cl=0,cm=0,cn=0,co=0,cp=0,cq=0,cr=0,cs=0,ct=0,cu=0,cv=0,cw=0,cx=0,cy=0,cz=0,cA=0,cB=0,cC=0,cD=0,cE=0,cF=0,cG=0,cH=0,cI=0,cJ=0,cK=0,cL=0,cM=0,cN=0,cO=0,cP=0,cQ=0,cR=0,cS=0,cT=0,cU=0,cV=0,cW=0,cX=0,cY=0,cZ=0,c_=0,c$=0,c0=0,c1=0,c2=0,c3=0,c4=0,c5=0,c6=0,c7=0,c8=0,c9=0,da=0,db=0,dc=0,dd=0,de=0,df=0,dg=0,dh=0,di=0,dj=0,dk=0,dl=0,dm=0,dn=0,dp=0,dq=0,dr=0,ds=0,dt=0,du=0,dv=0,dw=0,dx=0,dy=0,dz=0,dA=0,dB=0,dC=0,dD=0,dE=0,dF=0,dG=0,dH=0,dI=0,dJ=0,dK=0,dL=0,dM=0,dN=0,dO=0,dP=0,dQ=0,dR=0,dS=0,dT=0,dU=0,dV=0,dW=0,dX=0,dY=0,dZ=0,d_=0,d$=0,d0=0,d1=0,d2=0,d3=0,d4=0,d5=0,d6=0,d7=0,d8=0,d9=0,ea=0,eb=0,ec=0,ed=0,ee=0,ef=0,eg=0,eh=0,ei=0,ej=0,ek=0,el=0,em=0,en=0,eo=0,ep=0,eq=0,er=0,es=0,et=0,eu=0,ev=0,ew=0,ex=0,ey=0,ez=0,eA=0,eB=0,eC=0,eD=0,eE=0,eF=0,eG=0,eH=0,eI=0,eJ=0,eK=0,eL=0,eM=0,eN=0,eO=0,eP=0,eQ=0,eR=0,eS=0,eT=0,eU=0,eV=0,eW=0,eX=0,eY=0,eZ=0,e_=0,e$=0,e0=0,e1=0,e2=0,e3=0,e4=0,e5=0,e6=0,e7=0,e8=0,e9=0,fa=0,fb=0,fc=0,fd=0,fe=0,ff=0,fg=0,fh=0,fi=0,fj=0,fk=0,fl=0,fm=0,fn=0,fo=0,fp=0,fq=0,fr=0,fs=0,ft=0,fu=0,fv=0,fw=0,fx=0,fy=0,fz=0,fA=0,fB=0,fC=0,fD=0,fE=0,fF=0,fG=0,fH=0,fI=0,fJ=0,fK=0,fL=0,fM=0,fN=0,fO=0,fP=0,fQ=0,fR=0,fS=0,fT=0,fU=0,fV=0,fW=0,fX=0,fY=0,fZ=0,f_=0,f$=0,f0=0,f1=0,f2=0,f3=0,f4=0,f5=0,f6=0,f7=0,f8=0,f9=0,ga=0,gb=0,gc=0,gd=0,ge=0,gf=0,gh=0,gi=0,gk=0,gl=0,gm=0,gn=0,go=0,gp=0,gq=0,gr=0,gs=0,gt=0,gu=0,gv=0,gw=0,gx=0,gy=0,gz=0,gA=0,gB=0,gC=0,gD=0,gE=0,gF=0,gG=0,gH=0,gI=0,gJ=0,gK=0,gL=0;f=c[d+136>>2]|0;g=c[d+152>>2]|0;h=c[d+23848>>2]|0;i=c[d+23856>>2]|0;OL:do{if(h){h=0;switch(i|0){case 163:{j=b[4830446]|0;k=c[2415221]|0;l=c[2437644]|0;m=c[l+72+((k>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){n=c[l+3156>>2]|0;if((n|0)==0){o=0;p=k&65535;q=l;break}r=gj[n&4095](k&65535)|0;o=r;p=b[4830442]|0;q=c[2437644]|0}else{o=a[m+(k&255)|0]|0;p=k&65535;q=l}}while(0);b[4853736]=(o&255)+j&65535;b[4830442]=p+1&65535;l=c[2426868]|0;k=c[q+72+((l>>>8&255)<<2)>>2]|0;do{if((k|0)==0){m=c[q+3144>>2]|0;if((m|0)==0){s=0;t=q;break}r=gj[m&4095](l&65535)|0;s=r;t=c[2437644]|0}else{s=a[k+(l&255)|0]|0;t=q}}while(0);k=(s&255)<<8;j=c[t+72+(((l+1|0)>>>8&255)<<2)>>2]|0;do{if((j|0)==0){r=c[t+3144>>2]|0;if((r|0)==0){u=0;break}u=gj[r&4095]((l+1|0)&65535)|0}else{u=a[j+((l+1|0)&255)|0]|0}}while(0);l=e[4830448]|0;j=l-(u&255|k)|0;r=(j>>>12&8|a[9660900]&-16&255)&255;a[9660900]=((l^k^j^j>>>1)>>>14&2|j>>>16&1|((j&65535)<<16>>16==0?r|4:r)&255)&255;b[4830448]=j&65535;break};case 164:{j=b[4830446]|0;r=c[2415221]|0;l=c[2437644]|0;m=c[l+72+((r>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){n=c[l+3156>>2]|0;if((n|0)==0){v=0;w=r&65535;x=l;break}y=gj[n&4095](r&65535)|0;v=y;w=b[4830442]|0;x=c[2437644]|0}else{v=a[m+(r&255)|0]|0;w=r&65535;x=l}}while(0);b[4853736]=(v&255)+j&65535;b[4830442]=w+1&65535;l=c[2426868]|0;r=c[x+72+((l>>>8&255)<<2)>>2]|0;do{if((r|0)==0){m=c[x+3144>>2]|0;if((m|0)==0){z=0;break}z=gj[m&4095](l&65535)|0}else{z=a[r+(l&255)|0]|0}}while(0);l=a[9660897]&z;a[9660897]=l;r=(l&255)>>>4&8|a[9660900]&-15;a[9660900]=l<<24>>24==0?r|4:r;break};case 165:{r=b[4830446]|0;l=c[2415221]|0;j=c[2437644]|0;m=c[j+72+((l>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){k=c[j+3156>>2]|0;if((k|0)==0){A=0;B=l&65535;C=j;break}y=gj[k&4095](l&65535)|0;A=y;B=b[4830442]|0;C=c[2437644]|0}else{A=a[m+(l&255)|0]|0;B=l&65535;C=j}}while(0);b[4853736]=(A&255)+r&65535;b[4830442]=B+1&65535;j=c[2426868]|0;l=c[C+72+((j>>>8&255)<<2)>>2]|0;do{if((l|0)==0){m=c[C+3144>>2]|0;if((m|0)==0){D=0;break}D=gj[m&4095](j&65535)|0}else{D=a[l+(j&255)|0]|0}}while(0);j=a[9660897]&D;l=(j&255)>>>4&8|a[9660900]&-15;a[9660900]=j<<24>>24==0?l|4:l;break};case 166:{l=b[4830446]|0;j=c[2415221]|0;r=c[2437644]|0;m=c[r+72+((j>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){y=c[r+3156>>2]|0;if((y|0)==0){E=0;F=j&65535;G=r;break}k=gj[y&4095](j&65535)|0;E=k;F=b[4830442]|0;G=c[2437644]|0}else{E=a[m+(j&255)|0]|0;F=j&65535;G=r}}while(0);b[4853736]=(E&255)+l&65535;b[4830442]=F+1&65535;r=c[2426868]|0;j=c[G+72+((r>>>8&255)<<2)>>2]|0;do{if((j|0)==0){m=c[G+3144>>2]|0;if((m|0)==0){H=0;break}H=gj[m&4095](r&65535)|0}else{H=a[j+(r&255)|0]|0}}while(0);a[9660897]=H;r=(H&255)>>>4&8|a[9660900]&-15;a[9660900]=H<<24>>24==0?r|4:r;break};case 167:{r=a[9660897]|0;j=(r&255)>>>4&8|a[9660900]&-15;a[9660900]=r<<24>>24==0?j|4:j;j=b[4830446]|0;l=c[2415221]|0;m=c[2437644]|0;k=c[m+72+((l>>>8&255|512)<<2)>>2]|0;do{if((k|0)==0){y=c[m+3156>>2]|0;if((y|0)==0){I=0;J=l&65535;K=r;L=m;break}n=gj[y&4095](l&65535)|0;I=n;J=b[4830442]|0;K=a[9660897]|0;L=c[2437644]|0}else{I=a[k+(l&255)|0]|0;J=l&65535;K=r;L=m}}while(0);b[4853736]=(I&255)+j&65535;b[4830442]=J+1&65535;m=c[2426868]|0;r=c[L+72+((m>>>8&255|256)<<2)>>2]|0;if((r|0)!=0){a[r+(m&255)|0]=K;c[d+23864>>2]=2;c[d+23868>>2]=26;break OL}r=c[L+3148>>2]|0;if((r|0)==0){c[d+23864>>2]=2;c[d+23868>>2]=26;break OL}gg[r&4095](m&65535,K);break};case 168:{m=b[4830446]|0;r=c[2415221]|0;l=c[2437644]|0;k=c[l+72+((r>>>8&255|512)<<2)>>2]|0;do{if((k|0)==0){n=c[l+3156>>2]|0;if((n|0)==0){M=0;N=r&65535;O=l;break}y=gj[n&4095](r&65535)|0;M=y;N=b[4830442]|0;O=c[2437644]|0}else{M=a[k+(r&255)|0]|0;N=r&65535;O=l}}while(0);b[4853736]=(M&255)+m&65535;b[4830442]=N+1&65535;l=c[2426868]|0;r=c[O+72+((l>>>8&255)<<2)>>2]|0;do{if((r|0)==0){k=c[O+3144>>2]|0;if((k|0)==0){P=0;break}P=gj[k&4095](l&65535)|0}else{P=a[r+(l&255)|0]|0}}while(0);l=a[9660897]|0;r=l^P;a[9660897]=r;m=(r&255)>>>4&8|a[9660900]&-15;a[9660900]=l<<24>>24==P<<24>>24?m|4:m;break};case 169:{m=b[4830446]|0;l=c[2415221]|0;r=c[2437644]|0;k=c[r+72+((l>>>8&255|512)<<2)>>2]|0;do{if((k|0)==0){j=c[r+3156>>2]|0;if((j|0)==0){Q=0;R=l&65535;S=r;break}y=gj[j&4095](l&65535)|0;Q=y;R=b[4830442]|0;S=c[2437644]|0}else{Q=a[k+(l&255)|0]|0;R=l&65535;S=r}}while(0);b[4853736]=(Q&255)+m&65535;b[4830442]=R+1&65535;r=c[2426868]|0;l=c[S+72+((r>>>8&255)<<2)>>2]|0;do{if((l|0)==0){k=c[S+3144>>2]|0;if((k|0)==0){T=0;break}T=gj[k&4095](r&65535)|0}else{T=a[l+(r&255)|0]|0}}while(0);r=a[9660897]|0;l=a[9660900]|0;m=(r&255)+(T&255)+(l&1)|0;k=m^(r^T)&255;a[9660900]=(k<<1&32|m>>>8&1|(k^m>>>1)>>>6&2|((m&255)<<24>>24==0?(m>>>4&8|l&-48&255)&255|4:(m>>>4&8|l&-48&255)&255)&255)&255;a[9660897]=m&255;break};case 170:{m=b[4830446]|0;l=c[2415221]|0;k=c[2437644]|0;r=c[k+72+((l>>>8&255|512)<<2)>>2]|0;do{if((r|0)==0){y=c[k+3156>>2]|0;if((y|0)==0){U=0;V=l&65535;W=k;break}j=gj[y&4095](l&65535)|0;U=j;V=b[4830442]|0;W=c[2437644]|0}else{U=a[r+(l&255)|0]|0;V=l&65535;W=k}}while(0);b[4853736]=(U&255)+m&65535;b[4830442]=V+1&65535;k=c[2426868]|0;l=c[W+72+((k>>>8&255)<<2)>>2]|0;do{if((l|0)==0){r=c[W+3144>>2]|0;if((r|0)==0){X=0;break}X=gj[r&4095](k&65535)|0}else{X=a[l+(k&255)|0]|0}}while(0);k=a[9660897]|X;a[9660897]=k;l=(k&255)>>>4&8|a[9660900]&-15;a[9660900]=k<<24>>24==0?l|4:l;break};case 171:{l=b[4830446]|0;k=c[2415221]|0;m=c[2437644]|0;r=c[m+72+((k>>>8&255|512)<<2)>>2]|0;do{if((r|0)==0){j=c[m+3156>>2]|0;if((j|0)==0){Y=0;Z=k&65535;_=m;break}y=gj[j&4095](k&65535)|0;Y=y;Z=b[4830442]|0;_=c[2437644]|0}else{Y=a[r+(k&255)|0]|0;Z=k&65535;_=m}}while(0);b[4853736]=(Y&255)+l&65535;b[4830442]=Z+1&65535;m=c[2426868]|0;k=c[_+72+((m>>>8&255)<<2)>>2]|0;do{if((k|0)==0){r=c[_+3144>>2]|0;if((r|0)==0){$=0;break}$=gj[r&4095](m&65535)|0}else{$=a[k+(m&255)|0]|0}}while(0);m=a[9660897]|0;k=(m&255)+($&255)|0;l=(k>>>4&8|a[9660900]&-48&255)&255;r=(m^$)&255^k;a[9660900]=(r<<1&32|k>>>8&1|(r^k>>>1)>>>6&2|((k&255)<<24>>24==0?l|4:l)&255)&255;a[9660897]=k&255;break};case 172:{k=b[4830446]|0;l=c[2415221]|0;r=c[2437644]|0;m=c[r+72+((l>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){y=c[r+3156>>2]|0;if((y|0)==0){aa=0;ab=l&65535;ac=r;break}j=gj[y&4095](l&65535)|0;aa=j;ab=b[4830442]|0;ac=c[2437644]|0}else{aa=a[m+(l&255)|0]|0;ab=l&65535;ac=r}}while(0);b[4853736]=(aa&255)+k&65535;b[4830442]=ab+1&65535;r=c[2426868]|0;l=c[ac+72+((r>>>8&255)<<2)>>2]|0;do{if((l|0)==0){m=c[ac+3144>>2]|0;if((m|0)==0){ad=0;ae=ac;break}j=gj[m&4095](r&65535)|0;ad=j;ae=c[2437644]|0}else{ad=a[l+(r&255)|0]|0;ae=ac}}while(0);l=(ad&255)<<8;k=c[ae+72+(((r+1|0)>>>8&255)<<2)>>2]|0;do{if((k|0)==0){j=c[ae+3144>>2]|0;if((j|0)==0){af=0;break}af=gj[j&4095]((r+1|0)&65535)|0}else{af=a[k+((r+1|0)&255)|0]|0}}while(0);r=e[4830446]|0;k=r-(af&255|l)|0;j=(k>>>12&8|a[9660900]&-16&255)&255;a[9660900]=((r^l^k^k>>>1)>>>14&2|k>>>16&1|((k&65535)<<16>>16==0?j|4:j)&255)&255;break};case 173:{j=b[4830446]|0;k=c[2415221]|0;r=c[2437644]|0;m=c[r+72+((k>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){y=c[r+3156>>2]|0;if((y|0)==0){ag=0;ah=k&65535;ai=r;break}n=gj[y&4095](k&65535)|0;ag=n;ah=b[4830442]|0;ai=c[2437644]|0}else{ag=a[m+(k&255)|0]|0;ah=k&65535;ai=r}}while(0);b[4853736]=(ag&255)+j&65535;r=ah+1&65535;b[4830442]=r;k=c[2415222]|0;m=c[ai+72+((k>>>8&255|256)<<2)>>2]|0;do{if((m|0)==0){l=c[ai+3148>>2]|0;if((l|0)==0){aj=ai;break}gg[l&4095](k&65535,r&255);aj=c[2437644]|0}else{a[m+(k&255)|0]=r&255;aj=ai}}while(0);b[4830444]=(b[4830444]|0)-1&65535;r=c[2415222]|0;k=a[9660885]|0;m=c[aj+72+((r>>>8&255|256)<<2)>>2]|0;do{if((m|0)==0){j=c[aj+3148>>2]|0;if((j|0)==0){break}gg[j&4095](r&65535,k)}else{a[m+(r&255)|0]=k}}while(0);b[4830444]=(b[4830444]|0)-1&65535;b[4830442]=b[4853736]|0;b[4830442]=c[2415221]&65535;break};case 174:{k=b[4830446]|0;r=c[2415221]|0;m=c[2437644]|0;j=c[m+72+((r>>>8&255|512)<<2)>>2]|0;do{if((j|0)==0){l=c[m+3156>>2]|0;if((l|0)==0){ak=0;al=r&65535;am=m;break}n=gj[l&4095](r&65535)|0;ak=n;al=b[4830442]|0;am=c[2437644]|0}else{ak=a[j+(r&255)|0]|0;al=r&65535;am=m}}while(0);b[4853736]=(ak&255)+k&65535;b[4830442]=al+1&65535;m=c[2426868]|0;r=c[am+72+((m>>>8&255)<<2)>>2]|0;do{if((r|0)==0){j=c[am+3144>>2]|0;if((j|0)==0){an=0;ao=am;break}n=gj[j&4095](m&65535)|0;an=n;ao=c[2437644]|0}else{an=a[r+(m&255)|0]|0;ao=am}}while(0);r=an&255;k=c[ao+72+(((m+1|0)>>>8&255)<<2)>>2]|0;do{if((k|0)==0){n=c[ao+3144>>2]|0;if((n|0)==0){ap=0;break}ap=gj[n&4095]((m+1|0)&65535)|0}else{ap=a[k+((m+1|0)&255)|0]|0}}while(0);m=ap&255|r<<8;c[2415222]=m;k=a[9660900]&-15;a[9660900]=k;if((m|0)==0){aq=(k&255|r>>>4&8|4)&255}else{aq=(k&255|r>>>4&8)&255}a[9660900]=aq;break};case 175:{k=b[4830444]|0;m=(k&65535)>>>12&8|a[9660900]&-15&255;a[9660900]=(k<<16>>16==0?m|4:m)&255;m=b[4830446]|0;k=c[2415221]|0;n=c[2437644]|0;j=c[n+72+((k>>>8&255|512)<<2)>>2]|0;do{if((j|0)==0){l=c[n+3156>>2]|0;if((l|0)==0){ar=0;as=k&65535;at=n;break}y=gj[l&4095](k&65535)|0;ar=y;as=b[4830442]|0;at=c[2437644]|0}else{ar=a[j+(k&255)|0]|0;as=k&65535;at=n}}while(0);b[4853736]=(ar&255)+m&65535;b[4830442]=as+1&65535;n=c[2426868]|0;k=a[9660889]|0;j=c[at+72+((n>>>8&255|256)<<2)>>2]|0;do{if((j|0)==0){r=c[at+3148>>2]|0;if((r|0)==0){au=at;break}gg[r&4095](n&65535,k);au=c[2437644]|0}else{a[j+(n&255)|0]=k;au=at}}while(0);k=a[9660888]|0;j=c[au+72+(((n+1|0)>>>8&255|256)<<2)>>2]|0;if((j|0)!=0){a[j+((n+1|0)&255)|0]=k;c[d+23864>>2]=2;c[d+23868>>2]=26;break OL}j=c[au+3148>>2]|0;if((j|0)==0){c[d+23864>>2]=2;c[d+23868>>2]=26;break OL}gg[j&4095]((n+1|0)&65535,k);break};case 176:{k=c[2415221]|0;j=c[2437644]|0;m=c[j+72+((k>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){r=c[j+3156>>2]|0;if((r|0)==0){av=0;aw=k;ax=j;ay=k&65535;break}y=gj[r&4095](k&65535)|0;r=c[2415221]|0;av=y;aw=r;ax=c[2437644]|0;ay=r&65535}else{av=a[m+(k&255)|0]|0;aw=k;ax=j;ay=k&65535}}while(0);k=av&255;j=aw+1|0;m=c[ax+72+((j>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){n=c[ax+3156>>2]|0;if((n|0)==0){az=0;aA=ay;aB=ax;break}r=gj[n&4095](j&65535)|0;az=r;aA=b[4830442]|0;aB=c[2437644]|0}else{az=a[m+(j&255)|0]|0;aA=ay;aB=ax}}while(0);j=az&255;c[2426868]=j|k<<8;b[4830442]=aA+2&65535;m=c[aB+72+(k<<2)>>2]|0;do{if((m|0)==0){r=c[aB+3144>>2]|0;if((r|0)==0){aC=0;break}aC=gj[r&4095]((j|k<<8)&65535)|0}else{aC=a[m+j|0]|0}}while(0);j=a[9660897]|0;m=(j&255)-(aC&255)|0;k=(m>>>4&8|a[9660900]&-16&255)&255;a[9660900]=(((j^aC)&255^m^m>>>1)>>>6&2|m>>>8&1|((m&255)<<24>>24==0?k|4:k)&255)&255;a[9660897]=m&255;break};case 177:{m=c[2415221]|0;k=c[2437644]|0;j=c[k+72+((m>>>8&255|512)<<2)>>2]|0;do{if((j|0)==0){r=c[k+3156>>2]|0;if((r|0)==0){aD=0;aE=m;aF=k;aG=m&65535;break}n=gj[r&4095](m&65535)|0;r=c[2415221]|0;aD=n;aE=r;aF=c[2437644]|0;aG=r&65535}else{aD=a[j+(m&255)|0]|0;aE=m;aF=k;aG=m&65535}}while(0);m=aD&255;k=aE+1|0;j=c[aF+72+((k>>>8&255|512)<<2)>>2]|0;do{if((j|0)==0){r=c[aF+3156>>2]|0;if((r|0)==0){aH=0;aI=aG;aJ=aF;break}n=gj[r&4095](k&65535)|0;aH=n;aI=b[4830442]|0;aJ=c[2437644]|0}else{aH=a[j+(k&255)|0]|0;aI=aG;aJ=aF}}while(0);k=aH&255;c[2426868]=k|m<<8;b[4830442]=aI+2&65535;j=c[aJ+72+(m<<2)>>2]|0;do{if((j|0)==0){n=c[aJ+3144>>2]|0;if((n|0)==0){aK=0;break}aK=gj[n&4095]((k|m<<8)&65535)|0}else{aK=a[j+k|0]|0}}while(0);k=a[9660897]|0;j=(k&255)-(aK&255)|0;m=(j>>>4&8|a[9660900]&-16&255)&255;a[9660900]=(((k^aK)&255^j^j>>>1)>>>6&2|j>>>8&1|((j&255)<<24>>24==0?m|4:m)&255)&255;break};case 178:{m=c[2415221]|0;j=c[2437644]|0;k=c[j+72+((m>>>8&255|512)<<2)>>2]|0;do{if((k|0)==0){n=c[j+3156>>2]|0;if((n|0)==0){aL=0;aM=m;aN=j;aO=m&65535;break}r=gj[n&4095](m&65535)|0;n=c[2415221]|0;aL=r;aM=n;aN=c[2437644]|0;aO=n&65535}else{aL=a[k+(m&255)|0]|0;aM=m;aN=j;aO=m&65535}}while(0);m=aL&255;j=aM+1|0;k=c[aN+72+((j>>>8&255|512)<<2)>>2]|0;do{if((k|0)==0){n=c[aN+3156>>2]|0;if((n|0)==0){aP=0;aQ=aO;aR=aN;break}r=gj[n&4095](j&65535)|0;aP=r;aQ=b[4830442]|0;aR=c[2437644]|0}else{aP=a[k+(j&255)|0]|0;aQ=aO;aR=aN}}while(0);j=aP&255;c[2426868]=j|m<<8;b[4830442]=aQ+2&65535;k=c[aR+72+(m<<2)>>2]|0;do{if((k|0)==0){r=c[aR+3144>>2]|0;if((r|0)==0){aS=0;break}aS=gj[r&4095]((j|m<<8)&65535)|0}else{aS=a[k+j|0]|0}}while(0);j=a[9660897]|0;k=a[9660900]|0;m=(j&255)-(aS&255)-(k&1)|0;a[9660900]=((m^(j^aS)&255^m>>>1)>>>6&2|m>>>8&1|((m&255)<<24>>24==0?(m>>>4&8|k&-16&255)&255|4:(m>>>4&8|k&-16&255)&255)&255)&255;a[9660897]=m&255;break};case 179:{m=c[2415221]|0;k=c[2437644]|0;j=c[k+72+((m>>>8&255|512)<<2)>>2]|0;do{if((j|0)==0){r=c[k+3156>>2]|0;if((r|0)==0){aT=0;aU=m;aV=k;aW=m&65535;break}n=gj[r&4095](m&65535)|0;r=c[2415221]|0;aT=n;aU=r;aV=c[2437644]|0;aW=r&65535}else{aT=a[j+(m&255)|0]|0;aU=m;aV=k;aW=m&65535}}while(0);m=aT&255;k=aU+1|0;j=c[aV+72+((k>>>8&255|512)<<2)>>2]|0;do{if((j|0)==0){r=c[aV+3156>>2]|0;if((r|0)==0){aX=0;aY=aW;aZ=aV;break}n=gj[r&4095](k&65535)|0;aX=n;aY=b[4830442]|0;aZ=c[2437644]|0}else{aX=a[j+(k&255)|0]|0;aY=aW;aZ=aV}}while(0);k=aX&255;c[2426868]=k|m<<8;b[4830442]=aY+2&65535;j=c[aZ+72+(m<<2)>>2]|0;do{if((j|0)==0){n=c[aZ+3144>>2]|0;if((n|0)==0){a_=0;a$=aZ;break}r=gj[n&4095]((k|m<<8)&65535)|0;a_=r;a$=c[2437644]|0}else{a_=a[j+k|0]|0;a$=aZ}}while(0);j=(a_&255)<<8;r=c[a$+72+((((k|m<<8)+1|0)>>>8&255)<<2)>>2]|0;do{if((r|0)==0){n=c[a$+3144>>2]|0;if((n|0)==0){a0=0;break}a0=gj[n&4095](((k|m<<8)+1|0)&65535)|0}else{a0=a[r+(((k|m<<8)+1|0)&255)|0]|0}}while(0);m=e[4830448]|0;k=m-(a0&255|j)|0;r=(k>>>12&8|a[9660900]&-16&255)&255;a[9660900]=((m^j^k^k>>>1)>>>14&2|k>>>16&1|((k&65535)<<16>>16==0?r|4:r)&255)&255;b[4830448]=k&65535;break};case 180:{k=c[2415221]|0;r=c[2437644]|0;m=c[r+72+((k>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){n=c[r+3156>>2]|0;if((n|0)==0){a1=0;a2=k;a3=r;a4=k&65535;break}y=gj[n&4095](k&65535)|0;n=c[2415221]|0;a1=y;a2=n;a3=c[2437644]|0;a4=n&65535}else{a1=a[m+(k&255)|0]|0;a2=k;a3=r;a4=k&65535}}while(0);k=a1&255;r=a2+1|0;m=c[a3+72+((r>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){j=c[a3+3156>>2]|0;if((j|0)==0){a5=0;a6=a4;a7=a3;break}n=gj[j&4095](r&65535)|0;a5=n;a6=b[4830442]|0;a7=c[2437644]|0}else{a5=a[m+(r&255)|0]|0;a6=a4;a7=a3}}while(0);r=a5&255;c[2426868]=r|k<<8;b[4830442]=a6+2&65535;m=c[a7+72+(k<<2)>>2]|0;do{if((m|0)==0){n=c[a7+3144>>2]|0;if((n|0)==0){a8=0;break}a8=gj[n&4095]((r|k<<8)&65535)|0}else{a8=a[m+r|0]|0}}while(0);r=a[9660897]&a8;a[9660897]=r;m=(r&255)>>>4&8|a[9660900]&-15;a[9660900]=r<<24>>24==0?m|4:m;break};case 181:{m=c[2415221]|0;r=c[2437644]|0;k=c[r+72+((m>>>8&255|512)<<2)>>2]|0;do{if((k|0)==0){n=c[r+3156>>2]|0;if((n|0)==0){a9=0;ba=m;bb=r;bc=m&65535;break}j=gj[n&4095](m&65535)|0;n=c[2415221]|0;a9=j;ba=n;bb=c[2437644]|0;bc=n&65535}else{a9=a[k+(m&255)|0]|0;ba=m;bb=r;bc=m&65535}}while(0);m=a9&255;r=ba+1|0;k=c[bb+72+((r>>>8&255|512)<<2)>>2]|0;do{if((k|0)==0){n=c[bb+3156>>2]|0;if((n|0)==0){bd=0;be=bc;bf=bb;break}j=gj[n&4095](r&65535)|0;bd=j;be=b[4830442]|0;bf=c[2437644]|0}else{bd=a[k+(r&255)|0]|0;be=bc;bf=bb}}while(0);r=bd&255;c[2426868]=r|m<<8;b[4830442]=be+2&65535;k=c[bf+72+(m<<2)>>2]|0;do{if((k|0)==0){j=c[bf+3144>>2]|0;if((j|0)==0){bg=0;break}bg=gj[j&4095]((r|m<<8)&65535)|0}else{bg=a[k+r|0]|0}}while(0);r=a[9660897]&bg;k=(r&255)>>>4&8|a[9660900]&-15;a[9660900]=r<<24>>24==0?k|4:k;break};case 182:{k=c[2415221]|0;r=c[2437644]|0;m=c[r+72+((k>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){j=c[r+3156>>2]|0;if((j|0)==0){bh=0;bi=k;bj=r;bk=k&65535;break}n=gj[j&4095](k&65535)|0;j=c[2415221]|0;bh=n;bi=j;bj=c[2437644]|0;bk=j&65535}else{bh=a[m+(k&255)|0]|0;bi=k;bj=r;bk=k&65535}}while(0);k=bh&255;r=bi+1|0;m=c[bj+72+((r>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){j=c[bj+3156>>2]|0;if((j|0)==0){bl=0;bm=bk;bn=bj;break}n=gj[j&4095](r&65535)|0;bl=n;bm=b[4830442]|0;bn=c[2437644]|0}else{bl=a[m+(r&255)|0]|0;bm=bk;bn=bj}}while(0);r=bl&255;c[2426868]=r|k<<8;b[4830442]=bm+2&65535;m=c[bn+72+(k<<2)>>2]|0;do{if((m|0)==0){n=c[bn+3144>>2]|0;if((n|0)==0){bo=0;break}bo=gj[n&4095]((r|k<<8)&65535)|0}else{bo=a[m+r|0]|0}}while(0);a[9660897]=bo;r=(bo&255)>>>4&8|a[9660900]&-15;a[9660900]=bo<<24>>24==0?r|4:r;break};case 183:{r=a[9660897]|0;m=(r&255)>>>4&8|a[9660900]&-15;a[9660900]=r<<24>>24==0?m|4:m;m=c[2415221]|0;r=c[2437644]|0;k=c[r+72+((m>>>8&255|512)<<2)>>2]|0;do{if((k|0)==0){n=c[r+3156>>2]|0;if((n|0)==0){bp=0;bq=m;br=r;bs=m&65535;break}j=gj[n&4095](m&65535)|0;n=c[2415221]|0;bp=j;bq=n;br=c[2437644]|0;bs=n&65535}else{bp=a[k+(m&255)|0]|0;bq=m;br=r;bs=m&65535}}while(0);m=bp&255;r=bq+1|0;k=c[br+72+((r>>>8&255|512)<<2)>>2]|0;do{if((k|0)==0){n=c[br+3156>>2]|0;if((n|0)==0){bt=0;bu=bs;bv=br;break}j=gj[n&4095](r&65535)|0;bt=j;bu=b[4830442]|0;bv=c[2437644]|0}else{bt=a[k+(r&255)|0]|0;bu=bs;bv=br}}while(0);r=bt&255;c[2426868]=r|m<<8;b[4830442]=bu+2&65535;k=a[9660897]|0;j=c[bv+72+((m|256)<<2)>>2]|0;if((j|0)!=0){a[j+r|0]=k;c[d+23864>>2]=2;c[d+23868>>2]=26;break OL}j=c[bv+3148>>2]|0;if((j|0)==0){c[d+23864>>2]=2;c[d+23868>>2]=26;break OL}gg[j&4095]((r|m<<8)&65535,k);break};case 184:{k=c[2415221]|0;r=c[2437644]|0;j=c[r+72+((k>>>8&255|512)<<2)>>2]|0;do{if((j|0)==0){n=c[r+3156>>2]|0;if((n|0)==0){bw=0;bx=k;by=r;bz=k&65535;break}y=gj[n&4095](k&65535)|0;n=c[2415221]|0;bw=y;bx=n;by=c[2437644]|0;bz=n&65535}else{bw=a[j+(k&255)|0]|0;bx=k;by=r;bz=k&65535}}while(0);k=bw&255;r=bx+1|0;j=c[by+72+((r>>>8&255|512)<<2)>>2]|0;do{if((j|0)==0){m=c[by+3156>>2]|0;if((m|0)==0){bA=0;bB=bz;bC=by;break}n=gj[m&4095](r&65535)|0;bA=n;bB=b[4830442]|0;bC=c[2437644]|0}else{bA=a[j+(r&255)|0]|0;bB=bz;bC=by}}while(0);r=bA&255;c[2426868]=r|k<<8;b[4830442]=bB+2&65535;j=c[bC+72+(k<<2)>>2]|0;do{if((j|0)==0){n=c[bC+3144>>2]|0;if((n|0)==0){bD=0;break}bD=gj[n&4095]((r|k<<8)&65535)|0}else{bD=a[j+r|0]|0}}while(0);r=a[9660897]|0;j=r^bD;a[9660897]=j;k=(j&255)>>>4&8|a[9660900]&-15;a[9660900]=r<<24>>24==bD<<24>>24?k|4:k;break};case 185:{k=c[2415221]|0;r=c[2437644]|0;j=c[r+72+((k>>>8&255|512)<<2)>>2]|0;do{if((j|0)==0){n=c[r+3156>>2]|0;if((n|0)==0){bE=0;bF=k;bG=r;bH=k&65535;break}m=gj[n&4095](k&65535)|0;n=c[2415221]|0;bE=m;bF=n;bG=c[2437644]|0;bH=n&65535}else{bE=a[j+(k&255)|0]|0;bF=k;bG=r;bH=k&65535}}while(0);k=bE&255;r=bF+1|0;j=c[bG+72+((r>>>8&255|512)<<2)>>2]|0;do{if((j|0)==0){n=c[bG+3156>>2]|0;if((n|0)==0){bI=0;bJ=bH;bK=bG;break}m=gj[n&4095](r&65535)|0;bI=m;bJ=b[4830442]|0;bK=c[2437644]|0}else{bI=a[j+(r&255)|0]|0;bJ=bH;bK=bG}}while(0);r=bI&255;c[2426868]=r|k<<8;b[4830442]=bJ+2&65535;j=c[bK+72+(k<<2)>>2]|0;do{if((j|0)==0){m=c[bK+3144>>2]|0;if((m|0)==0){bL=0;break}bL=gj[m&4095]((r|k<<8)&65535)|0}else{bL=a[j+r|0]|0}}while(0);r=a[9660897]|0;j=a[9660900]|0;k=(r&255)+(bL&255)+(j&1)|0;m=k^(r^bL)&255;a[9660900]=(m<<1&32|k>>>8&1|(m^k>>>1)>>>6&2|((k&255)<<24>>24==0?(k>>>4&8|j&-48&255)&255|4:(k>>>4&8|j&-48&255)&255)&255)&255;a[9660897]=k&255;break};default:{h=1}}}if(h){h=0;switch(i|0){case 186:{k=c[2415221]|0;j=c[2437644]|0;m=c[j+72+((k>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){r=c[j+3156>>2]|0;if((r|0)==0){bM=0;bN=k;bO=j;bP=k&65535;break}n=gj[r&4095](k&65535)|0;r=c[2415221]|0;bM=n;bN=r;bO=c[2437644]|0;bP=r&65535}else{bM=a[m+(k&255)|0]|0;bN=k;bO=j;bP=k&65535}}while(0);k=bM&255;j=bN+1|0;m=c[bO+72+((j>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){r=c[bO+3156>>2]|0;if((r|0)==0){bQ=0;bR=bP;bS=bO;break}n=gj[r&4095](j&65535)|0;bQ=n;bR=b[4830442]|0;bS=c[2437644]|0}else{bQ=a[m+(j&255)|0]|0;bR=bP;bS=bO}}while(0);j=bQ&255;c[2426868]=j|k<<8;b[4830442]=bR+2&65535;m=c[bS+72+(k<<2)>>2]|0;do{if((m|0)==0){n=c[bS+3144>>2]|0;if((n|0)==0){bT=0;break}bT=gj[n&4095]((j|k<<8)&65535)|0}else{bT=a[m+j|0]|0}}while(0);j=a[9660897]|bT;a[9660897]=j;m=(j&255)>>>4&8|a[9660900]&-15;a[9660900]=j<<24>>24==0?m|4:m;break};case 187:{m=c[2415221]|0;j=c[2437644]|0;k=c[j+72+((m>>>8&255|512)<<2)>>2]|0;do{if((k|0)==0){n=c[j+3156>>2]|0;if((n|0)==0){bU=0;bV=m;bW=j;bX=m&65535;break}r=gj[n&4095](m&65535)|0;n=c[2415221]|0;bU=r;bV=n;bW=c[2437644]|0;bX=n&65535}else{bU=a[k+(m&255)|0]|0;bV=m;bW=j;bX=m&65535}}while(0);m=bU&255;j=bV+1|0;k=c[bW+72+((j>>>8&255|512)<<2)>>2]|0;do{if((k|0)==0){n=c[bW+3156>>2]|0;if((n|0)==0){bY=0;bZ=bX;b_=bW;break}r=gj[n&4095](j&65535)|0;bY=r;bZ=b[4830442]|0;b_=c[2437644]|0}else{bY=a[k+(j&255)|0]|0;bZ=bX;b_=bW}}while(0);j=bY&255;c[2426868]=j|m<<8;b[4830442]=bZ+2&65535;k=c[b_+72+(m<<2)>>2]|0;do{if((k|0)==0){r=c[b_+3144>>2]|0;if((r|0)==0){b$=0;break}b$=gj[r&4095]((j|m<<8)&65535)|0}else{b$=a[k+j|0]|0}}while(0);j=a[9660897]|0;k=(j&255)+(b$&255)|0;m=(k>>>4&8|a[9660900]&-48&255)&255;r=(j^b$)&255^k;a[9660900]=(r<<1&32|k>>>8&1|(r^k>>>1)>>>6&2|((k&255)<<24>>24==0?m|4:m)&255)&255;a[9660897]=k&255;break};case 188:{k=c[2415221]|0;m=c[2437644]|0;r=c[m+72+((k>>>8&255|512)<<2)>>2]|0;do{if((r|0)==0){j=c[m+3156>>2]|0;if((j|0)==0){b0=0;b1=k;b2=m;b3=k&65535;break}n=gj[j&4095](k&65535)|0;j=c[2415221]|0;b0=n;b1=j;b2=c[2437644]|0;b3=j&65535}else{b0=a[r+(k&255)|0]|0;b1=k;b2=m;b3=k&65535}}while(0);k=b0&255;m=b1+1|0;r=c[b2+72+((m>>>8&255|512)<<2)>>2]|0;do{if((r|0)==0){j=c[b2+3156>>2]|0;if((j|0)==0){b4=0;b5=b3;b6=b2;break}n=gj[j&4095](m&65535)|0;b4=n;b5=b[4830442]|0;b6=c[2437644]|0}else{b4=a[r+(m&255)|0]|0;b5=b3;b6=b2}}while(0);m=b4&255;c[2426868]=m|k<<8;b[4830442]=b5+2&65535;r=c[b6+72+(k<<2)>>2]|0;do{if((r|0)==0){n=c[b6+3144>>2]|0;if((n|0)==0){b7=0;b8=b6;break}j=gj[n&4095]((m|k<<8)&65535)|0;b7=j;b8=c[2437644]|0}else{b7=a[r+m|0]|0;b8=b6}}while(0);r=(b7&255)<<8;j=c[b8+72+((((m|k<<8)+1|0)>>>8&255)<<2)>>2]|0;do{if((j|0)==0){n=c[b8+3144>>2]|0;if((n|0)==0){b9=0;break}b9=gj[n&4095](((m|k<<8)+1|0)&65535)|0}else{b9=a[j+(((m|k<<8)+1|0)&255)|0]|0}}while(0);k=e[4830446]|0;m=k-(b9&255|r)|0;j=(m>>>12&8|a[9660900]&-16&255)&255;a[9660900]=((k^r^m^m>>>1)>>>14&2|m>>>16&1|((m&65535)<<16>>16==0?j|4:j)&255)&255;break};case 189:{j=c[2415221]|0;m=c[2437644]|0;k=c[m+72+((j>>>8&255|512)<<2)>>2]|0;do{if((k|0)==0){n=c[m+3156>>2]|0;if((n|0)==0){ca=0;cb=j;cc=m;cd=j&65535;break}y=gj[n&4095](j&65535)|0;n=c[2415221]|0;ca=y;cb=n;cc=c[2437644]|0;cd=n&65535}else{ca=a[k+(j&255)|0]|0;cb=j;cc=m;cd=j&65535}}while(0);j=(ca&255)<<8;m=cb+1|0;k=c[cc+72+((m>>>8&255|512)<<2)>>2]|0;do{if((k|0)==0){r=c[cc+3156>>2]|0;if((r|0)==0){ce=0;cf=cd;cg=cc;break}n=gj[r&4095](m&65535)|0;ce=n;cf=b[4830442]|0;cg=c[2437644]|0}else{ce=a[k+(m&255)|0]|0;cf=cd;cg=cc}}while(0);c[2426868]=ce&255|j;m=cf+2&65535;b[4830442]=m;k=c[2415222]|0;n=c[cg+72+((k>>>8&255|256)<<2)>>2]|0;do{if((n|0)==0){r=c[cg+3148>>2]|0;if((r|0)==0){ch=cg;break}gg[r&4095](k&65535,m&255);ch=c[2437644]|0}else{a[n+(k&255)|0]=m&255;ch=cg}}while(0);b[4830444]=(b[4830444]|0)-1&65535;m=c[2415222]|0;k=a[9660885]|0;n=c[ch+72+((m>>>8&255|256)<<2)>>2]|0;do{if((n|0)==0){j=c[ch+3148>>2]|0;if((j|0)==0){break}gg[j&4095](m&65535,k)}else{a[n+(m&255)|0]=k}}while(0);b[4830444]=(b[4830444]|0)-1&65535;b[4830442]=b[4853736]|0;b[4830442]=c[2415221]&65535;break};case 190:{f3m();break};case 191:{f3n();break};case 192:{k=c[2415221]|0;m=c[2437644]|0;n=c[m+72+((k>>>8&255|512)<<2)>>2]|0;do{if((n|0)==0){j=c[m+3156>>2]|0;if((j|0)==0){ci=0;cj=k&65535;break}r=gj[j&4095](k&65535)|0;ci=r;cj=b[4830442]|0}else{ci=a[n+(k&255)|0]|0;cj=k&65535}}while(0);b[4830442]=cj+1&65535;k=a[9660896]|0;n=(k&255)-(ci&255)|0;m=(n>>>4&8|a[9660900]&-16&255)&255;a[9660900]=(((k^ci)&255^n^n>>>1)>>>6&2|n>>>8&1|((n&255)<<24>>24==0?m|4:m)&255)&255;a[9660896]=n&255;break};case 193:{n=c[2415221]|0;m=c[2437644]|0;k=c[m+72+((n>>>8&255|512)<<2)>>2]|0;do{if((k|0)==0){r=c[m+3156>>2]|0;if((r|0)==0){ck=0;cl=n&65535;break}j=gj[r&4095](n&65535)|0;ck=j;cl=b[4830442]|0}else{ck=a[k+(n&255)|0]|0;cl=n&65535}}while(0);b[4830442]=cl+1&65535;n=a[9660896]|0;k=(n&255)-(ck&255)|0;m=(k>>>4&8|a[9660900]&-16&255)&255;a[9660900]=(((n^ck)&255^k^k>>>1)>>>6&2|k>>>8&1|((k&255)<<24>>24==0?m|4:m)&255)&255;break};case 194:{m=c[2415221]|0;k=c[2437644]|0;n=c[k+72+((m>>>8&255|512)<<2)>>2]|0;do{if((n|0)==0){j=c[k+3156>>2]|0;if((j|0)==0){cm=0;cn=m&65535;break}r=gj[j&4095](m&65535)|0;cm=r;cn=b[4830442]|0}else{cm=a[n+(m&255)|0]|0;cn=m&65535}}while(0);b[4830442]=cn+1&65535;m=a[9660896]|0;n=a[9660900]|0;k=(m&255)-(cm&255)-(n&1)|0;a[9660900]=((k^(m^cm)&255^k>>>1)>>>6&2|k>>>8&1|((k&255)<<24>>24==0?(k>>>4&8|n&-16&255)&255|4:(k>>>4&8|n&-16&255)&255)&255)&255;a[9660896]=k&255;break};case 195:{k=c[2415221]|0;n=c[2437644]|0;m=c[n+72+((k>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){r=c[n+3156>>2]|0;if((r|0)==0){co=0;cp=k;cq=n;cr=k&65535;break}j=gj[r&4095](k&65535)|0;r=c[2415221]|0;co=j;cp=r;cq=c[2437644]|0;cr=r&65535}else{co=a[m+(k&255)|0]|0;cp=k;cq=n;cr=k&65535}}while(0);k=(co&255)<<8;n=cp+1|0;m=c[cq+72+((n>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){r=c[cq+3156>>2]|0;if((r|0)==0){cs=0;ct=cr;break}j=gj[r&4095](n&65535)|0;cs=j;ct=b[4830442]|0}else{cs=a[m+(n&255)|0]|0;ct=cr}}while(0);b[4830442]=ct+2&65535;n=e[4830448]|0;m=n+(cs&255|k)|0;j=(m>>>12&8|a[9660900]&-16&255)&255;a[9660900]=((n^k^m^m>>>1)>>>14&2|m>>>16&1|((m&65535)<<16>>16==0?j|4:j)&255)&255;b[4830448]=m&65535;break};case 196:{m=c[2415221]|0;j=c[2437644]|0;n=c[j+72+((m>>>8&255|512)<<2)>>2]|0;do{if((n|0)==0){r=c[j+3156>>2]|0;if((r|0)==0){cu=0;cv=m&65535;break}y=gj[r&4095](m&65535)|0;cu=y;cv=b[4830442]|0}else{cu=a[n+(m&255)|0]|0;cv=m&65535}}while(0);b[4830442]=cv+1&65535;m=a[9660896]&cu;a[9660896]=m;n=(m&255)>>>4&8|a[9660900]&-15;a[9660900]=m<<24>>24==0?n|4:n;break};case 197:{n=c[2415221]|0;m=c[2437644]|0;j=c[m+72+((n>>>8&255|512)<<2)>>2]|0;do{if((j|0)==0){k=c[m+3156>>2]|0;if((k|0)==0){cw=0;cx=n&65535;break}y=gj[k&4095](n&65535)|0;cw=y;cx=b[4830442]|0}else{cw=a[j+(n&255)|0]|0;cx=n&65535}}while(0);b[4830442]=cx+1&65535;n=a[9660896]&cw;j=(n&255)>>>4&8|a[9660900]&-15;a[9660900]=n<<24>>24==0?j|4:j;break};case 198:{j=c[2415221]|0;n=c[2437644]|0;m=c[n+72+((j>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){y=c[n+3156>>2]|0;if((y|0)==0){cy=0;cz=j&65535;break}k=gj[y&4095](j&65535)|0;cy=k;cz=b[4830442]|0}else{cy=a[m+(j&255)|0]|0;cz=j&65535}}while(0);a[9660896]=cy;b[4830442]=cz+1&65535;j=a[9660900]&-15|(cy&255)>>>4&8;a[9660900]=cy<<24>>24==0?j|4:j;break};case 199:{j=a[9660896]|0;m=(j&255)>>>4&8|a[9660900]&-15;a[9660900]=j<<24>>24==0?m|4:m;b[4830442]=f+2&65535;b[4853736]=g;m=c[2426868]|0;n=c[2437644]|0;k=c[n+72+((m>>>8&255|256)<<2)>>2]|0;if((k|0)!=0){a[k+(m&255)|0]=j;c[d+23864>>2]=2;c[d+23868>>2]=26;break OL}k=c[n+3148>>2]|0;if((k|0)==0){c[d+23864>>2]=2;c[d+23868>>2]=26;break OL}gg[k&4095](m&65535,j);break};case 200:{j=c[2415221]|0;m=c[2437644]|0;k=c[m+72+((j>>>8&255|512)<<2)>>2]|0;do{if((k|0)==0){n=c[m+3156>>2]|0;if((n|0)==0){cA=0;cB=j&65535;break}y=gj[n&4095](j&65535)|0;cA=y;cB=b[4830442]|0}else{cA=a[k+(j&255)|0]|0;cB=j&65535}}while(0);b[4830442]=cB+1&65535;j=a[9660896]|0;k=j^cA;a[9660896]=k;m=(k&255)>>>4&8|a[9660900]&-15;a[9660900]=j<<24>>24==cA<<24>>24?m|4:m;break};case 201:{m=c[2415221]|0;j=c[2437644]|0;k=c[j+72+((m>>>8&255|512)<<2)>>2]|0;do{if((k|0)==0){y=c[j+3156>>2]|0;if((y|0)==0){cC=0;cD=m&65535;break}n=gj[y&4095](m&65535)|0;cC=n;cD=b[4830442]|0}else{cC=a[k+(m&255)|0]|0;cD=m&65535}}while(0);b[4830442]=cD+1&65535;m=a[9660896]|0;k=a[9660900]|0;j=(m&255)+(cC&255)+(k&1)|0;n=j^(m^cC)&255;a[9660900]=(n<<1&32|j>>>8&1|(n^j>>>1)>>>6&2|((j&255)<<24>>24==0?(j>>>4&8|k&-48&255)&255|4:(j>>>4&8|k&-48&255)&255)&255)&255;a[9660896]=j&255;break};case 202:{j=c[2415221]|0;k=c[2437644]|0;n=c[k+72+((j>>>8&255|512)<<2)>>2]|0;do{if((n|0)==0){m=c[k+3156>>2]|0;if((m|0)==0){cE=0;cF=j&65535;break}y=gj[m&4095](j&65535)|0;cE=y;cF=b[4830442]|0}else{cE=a[n+(j&255)|0]|0;cF=j&65535}}while(0);b[4830442]=cF+1&65535;j=a[9660896]|cE;a[9660896]=j;n=(j&255)>>>4&8|a[9660900]&-15;a[9660900]=j<<24>>24==0?n|4:n;break};case 203:{n=c[2415221]|0;j=c[2437644]|0;k=c[j+72+((n>>>8&255|512)<<2)>>2]|0;do{if((k|0)==0){y=c[j+3156>>2]|0;if((y|0)==0){cG=0;cH=n&65535;break}m=gj[y&4095](n&65535)|0;cG=m;cH=b[4830442]|0}else{cG=a[k+(n&255)|0]|0;cH=n&65535}}while(0);b[4830442]=cH+1&65535;n=a[9660896]|0;k=(n&255)+(cG&255)|0;j=(k>>>4&8|a[9660900]&-48&255)&255;m=(n^cG)&255^k;a[9660900]=(m<<1&32|k>>>8&1|(m^k>>>1)>>>6&2|((k&255)<<24>>24==0?j|4:j)&255)&255;a[9660896]=k&255;break};case 204:{k=c[2415221]|0;j=c[2437644]|0;m=c[j+72+((k>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){n=c[j+3156>>2]|0;if((n|0)==0){cI=0;cJ=k;cK=j;cL=k&65535;break}y=gj[n&4095](k&65535)|0;n=c[2415221]|0;cI=y;cJ=n;cK=c[2437644]|0;cL=n&65535}else{cI=a[m+(k&255)|0]|0;cJ=k;cK=j;cL=k&65535}}while(0);k=cI&255;j=cJ+1|0;m=c[cK+72+((j>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){n=c[cK+3156>>2]|0;if((n|0)==0){cM=0;cN=cL;break}y=gj[n&4095](j&65535)|0;cM=y;cN=b[4830442]|0}else{cM=a[m+(j&255)|0]|0;cN=cL}}while(0);j=cM&255|k<<8;c[2415224]=j;b[4830442]=cN+2&65535;m=a[9660900]&-15;a[9660900]=m;if((j|0)==0){cO=(m&255|k>>>4&8|4)&255}else{cO=(m&255|k>>>4&8)&255}a[9660900]=cO;break};case 205:{b[4853736]=g;b[4830442]=f+3&65535;m=b[4830448]|0;j=(m&65535)>>>12&8|a[9660900]&-15&255;a[9660900]=(m<<16>>16==0?j|4:j)&255;j=c[2426868]|0;m=a[9660897]|0;y=c[2437644]|0;n=c[y+72+((j>>>8&255|256)<<2)>>2]|0;do{if((n|0)==0){r=c[y+3148>>2]|0;if((r|0)==0){cP=y;break}gg[r&4095](j&65535,m);cP=c[2437644]|0}else{a[n+(j&255)|0]=m;cP=y}}while(0);y=a[9660896]|0;m=c[cP+72+(((j+1|0)>>>8&255|256)<<2)>>2]|0;if((m|0)!=0){a[m+((j+1|0)&255)|0]=y;c[d+23864>>2]=2;c[d+23868>>2]=26;break OL}m=c[cP+3148>>2]|0;if((m|0)==0){c[d+23864>>2]=2;c[d+23868>>2]=26;break OL}gg[m&4095]((j+1|0)&65535,y);break};case 206:{y=c[2415221]|0;m=c[2437644]|0;n=c[m+72+((y>>>8&255|512)<<2)>>2]|0;do{if((n|0)==0){k=c[m+3156>>2]|0;if((k|0)==0){cQ=0;cR=y;cS=m;cT=y&65535;break}r=gj[k&4095](y&65535)|0;k=c[2415221]|0;cQ=r;cR=k;cS=c[2437644]|0;cT=k&65535}else{cQ=a[n+(y&255)|0]|0;cR=y;cS=m;cT=y&65535}}while(0);y=cQ&255;m=cR+1|0;n=c[cS+72+((m>>>8&255|512)<<2)>>2]|0;do{if((n|0)==0){j=c[cS+3156>>2]|0;if((j|0)==0){cU=0;cV=cT;break}k=gj[j&4095](m&65535)|0;cU=k;cV=b[4830442]|0}else{cU=a[n+(m&255)|0]|0;cV=cT}}while(0);m=cU&255|y<<8;c[2415223]=m;b[4830442]=cV+2&65535;n=a[9660900]&-15;a[9660900]=n;if((m|0)==0){cW=(n&255|y>>>4&8|4)&255}else{cW=(n&255|y>>>4&8)&255}a[9660900]=cW;break};case 207:{n=b[4830446]|0;m=(n&65535)>>>12&8|a[9660900]&-15&255;a[9660900]=(n<<16>>16==0?m|4:m)&255;b[4853736]=g;b[4830442]=f+3&65535;m=c[2426868]|0;n=a[9660893]|0;k=c[2437644]|0;j=c[k+72+((m>>>8&255|256)<<2)>>2]|0;do{if((j|0)==0){r=c[k+3148>>2]|0;if((r|0)==0){cX=k;break}gg[r&4095](m&65535,n);cX=c[2437644]|0}else{a[j+(m&255)|0]=n;cX=k}}while(0);k=a[9660892]|0;n=c[cX+72+(((m+1|0)>>>8&255|256)<<2)>>2]|0;if((n|0)!=0){a[n+((m+1|0)&255)|0]=k;c[d+23864>>2]=2;c[d+23868>>2]=26;break OL}n=c[cX+3148>>2]|0;if((n|0)==0){c[d+23864>>2]=2;c[d+23868>>2]=26;break OL}gg[n&4095]((m+1|0)&65535,k);break};case 208:{k=c[2415221]|0;n=c[2437644]|0;j=c[n+72+((k>>>8&255|512)<<2)>>2]|0;do{if((j|0)==0){y=c[n+3156>>2]|0;if((y|0)==0){cY=0;cZ=k&65535;c_=n;break}r=gj[y&4095](k&65535)|0;cY=r;cZ=b[4830442]|0;c_=c[2437644]|0}else{cY=a[j+(k&255)|0]|0;cZ=k&65535;c_=n}}while(0);n=cY&255;c[2426868]=n;b[4830442]=cZ+1&65535;k=cY&255;j=c[c_+72>>2]|0;do{if((j|0)==0){m=c[c_+3144>>2]|0;if((m|0)==0){c$=0;break}c$=gj[m&4095](k)|0}else{c$=a[j+n|0]|0}}while(0);n=a[9660896]|0;j=(n&255)-(c$&255)|0;k=(j>>>4&8|a[9660900]&-16&255)&255;a[9660900]=(((n^c$)&255^j^j>>>1)>>>6&2|j>>>8&1|((j&255)<<24>>24==0?k|4:k)&255)&255;a[9660896]=j&255;break};case 209:{j=c[2415221]|0;k=c[2437644]|0;n=c[k+72+((j>>>8&255|512)<<2)>>2]|0;do{if((n|0)==0){m=c[k+3156>>2]|0;if((m|0)==0){c0=0;c1=j&65535;c2=k;break}r=gj[m&4095](j&65535)|0;c0=r;c1=b[4830442]|0;c2=c[2437644]|0}else{c0=a[n+(j&255)|0]|0;c1=j&65535;c2=k}}while(0);k=c0&255;c[2426868]=k;b[4830442]=c1+1&65535;j=c0&255;n=c[c2+72>>2]|0;do{if((n|0)==0){r=c[c2+3144>>2]|0;if((r|0)==0){c3=0;break}c3=gj[r&4095](j)|0}else{c3=a[n+k|0]|0}}while(0);k=a[9660896]|0;n=(k&255)-(c3&255)|0;j=(n>>>4&8|a[9660900]&-16&255)&255;a[9660900]=(((k^c3)&255^n^n>>>1)>>>6&2|n>>>8&1|((n&255)<<24>>24==0?j|4:j)&255)&255;break};case 210:{j=c[2415221]|0;n=c[2437644]|0;k=c[n+72+((j>>>8&255|512)<<2)>>2]|0;do{if((k|0)==0){r=c[n+3156>>2]|0;if((r|0)==0){c4=0;c5=j&65535;c6=n;break}m=gj[r&4095](j&65535)|0;c4=m;c5=b[4830442]|0;c6=c[2437644]|0}else{c4=a[k+(j&255)|0]|0;c5=j&65535;c6=n}}while(0);n=c4&255;c[2426868]=n;b[4830442]=c5+1&65535;j=c4&255;k=c[c6+72>>2]|0;do{if((k|0)==0){m=c[c6+3144>>2]|0;if((m|0)==0){c7=0;break}c7=gj[m&4095](j)|0}else{c7=a[k+n|0]|0}}while(0);n=a[9660896]|0;k=a[9660900]|0;j=(n&255)-(c7&255)-(k&1)|0;a[9660900]=((j^(n^c7)&255^j>>>1)>>>6&2|j>>>8&1|((j&255)<<24>>24==0?(j>>>4&8|k&-16&255)&255|4:(j>>>4&8|k&-16&255)&255)&255)&255;a[9660896]=j&255;break};case 211:{j=c[2415221]|0;k=c[2437644]|0;n=c[k+72+((j>>>8&255|512)<<2)>>2]|0;do{if((n|0)==0){m=c[k+3156>>2]|0;if((m|0)==0){c8=0;c9=j&65535;da=k;break}r=gj[m&4095](j&65535)|0;c8=r;c9=b[4830442]|0;da=c[2437644]|0}else{c8=a[n+(j&255)|0]|0;c9=j&65535;da=k}}while(0);k=c8&255;c[2426868]=k;b[4830442]=c9+1&65535;j=c8&255;n=c[da+72>>2]|0;do{if((n|0)==0){r=c[da+3144>>2]|0;if((r|0)==0){db=0;dc=da;break}m=gj[r&4095](j)|0;db=m;dc=c[2437644]|0}else{db=a[n+k|0]|0;dc=da}}while(0);n=(db&255)<<8;j=c[dc+72+(((k+1|0)>>>8&255)<<2)>>2]|0;do{if((j|0)==0){m=c[dc+3144>>2]|0;if((m|0)==0){dd=0;break}dd=gj[m&4095]((k+1|0)&65535)|0}else{dd=a[j+((k+1|0)&255)|0]|0}}while(0);k=e[4830448]|0;j=k+(dd&255|n)|0;m=(j>>>12&8|a[9660900]&-16&255)&255;a[9660900]=((k^n^j^j>>>1)>>>14&2|j>>>16&1|((j&65535)<<16>>16==0?m|4:m)&255)&255;b[4830448]=j&65535;break};case 212:{j=c[2415221]|0;m=c[2437644]|0;k=c[m+72+((j>>>8&255|512)<<2)>>2]|0;do{if((k|0)==0){r=c[m+3156>>2]|0;if((r|0)==0){de=0;df=j&65535;dg=m;break}y=gj[r&4095](j&65535)|0;de=y;df=b[4830442]|0;dg=c[2437644]|0}else{de=a[k+(j&255)|0]|0;df=j&65535;dg=m}}while(0);m=de&255;c[2426868]=m;b[4830442]=df+1&65535;j=de&255;k=c[dg+72>>2]|0;do{if((k|0)==0){n=c[dg+3144>>2]|0;if((n|0)==0){dh=0;break}dh=gj[n&4095](j)|0}else{dh=a[k+m|0]|0}}while(0);m=a[9660896]&dh;a[9660896]=m;k=(m&255)>>>4&8|a[9660900]&-15;a[9660900]=m<<24>>24==0?k|4:k;break};case 213:{k=c[2415221]|0;m=c[2437644]|0;j=c[m+72+((k>>>8&255|512)<<2)>>2]|0;do{if((j|0)==0){n=c[m+3156>>2]|0;if((n|0)==0){di=0;dj=k&65535;dk=m;break}y=gj[n&4095](k&65535)|0;di=y;dj=b[4830442]|0;dk=c[2437644]|0}else{di=a[j+(k&255)|0]|0;dj=k&65535;dk=m}}while(0);m=di&255;c[2426868]=m;b[4830442]=dj+1&65535;k=di&255;j=c[dk+72>>2]|0;do{if((j|0)==0){y=c[dk+3144>>2]|0;if((y|0)==0){dl=0;break}dl=gj[y&4095](k)|0}else{dl=a[j+m|0]|0}}while(0);m=a[9660896]&dl;j=(m&255)>>>4&8|a[9660900]&-15;a[9660900]=m<<24>>24==0?j|4:j;break};case 214:{j=c[2415221]|0;m=c[2437644]|0;k=c[m+72+((j>>>8&255|512)<<2)>>2]|0;do{if((k|0)==0){y=c[m+3156>>2]|0;if((y|0)==0){dm=0;dn=j&65535;dp=m;break}n=gj[y&4095](j&65535)|0;dm=n;dn=b[4830442]|0;dp=c[2437644]|0}else{dm=a[k+(j&255)|0]|0;dn=j&65535;dp=m}}while(0);m=dm&255;c[2426868]=m;b[4830442]=dn+1&65535;j=dm&255;k=c[dp+72>>2]|0;do{if((k|0)==0){n=c[dp+3144>>2]|0;if((n|0)==0){dq=0;break}dq=gj[n&4095](j)|0}else{dq=a[k+m|0]|0}}while(0);a[9660896]=dq;m=(dq&255)>>>4&8|a[9660900]&-15;a[9660900]=dq<<24>>24==0?m|4:m;break};case 215:{m=a[9660896]|0;k=(m&255)>>>4&8|a[9660900]&-15;a[9660900]=m<<24>>24==0?k|4:k;k=c[2415221]|0;j=c[2437644]|0;n=c[j+72+((k>>>8&255|512)<<2)>>2]|0;do{if((n|0)==0){y=c[j+3156>>2]|0;if((y|0)==0){dr=0;ds=k&65535;dt=m;du=j;break}r=gj[y&4095](k&65535)|0;dr=r;ds=b[4830442]|0;dt=a[9660896]|0;du=c[2437644]|0}else{dr=a[n+(k&255)|0]|0;ds=k&65535;dt=m;du=j}}while(0);j=dr&255;c[2426868]=j;b[4830442]=ds+1&65535;m=c[du+1096>>2]|0;if((m|0)!=0){a[m+j|0]=dt;c[d+23864>>2]=2;c[d+23868>>2]=26;break OL}j=c[du+3148>>2]|0;if((j|0)==0){c[d+23864>>2]=2;c[d+23868>>2]=26;break OL}gg[j&4095](dr&255,dt);break};case 216:{j=c[2415221]|0;m=c[2437644]|0;k=c[m+72+((j>>>8&255|512)<<2)>>2]|0;do{if((k|0)==0){n=c[m+3156>>2]|0;if((n|0)==0){dv=0;dw=j&65535;dx=m;break}r=gj[n&4095](j&65535)|0;dv=r;dw=b[4830442]|0;dx=c[2437644]|0}else{dv=a[k+(j&255)|0]|0;dw=j&65535;dx=m}}while(0);m=dv&255;c[2426868]=m;b[4830442]=dw+1&65535;j=dv&255;k=c[dx+72>>2]|0;do{if((k|0)==0){r=c[dx+3144>>2]|0;if((r|0)==0){dy=0;break}dy=gj[r&4095](j)|0}else{dy=a[k+m|0]|0}}while(0);m=a[9660896]|0;k=m^dy;a[9660896]=k;j=(k&255)>>>4&8|a[9660900]&-15;a[9660900]=m<<24>>24==dy<<24>>24?j|4:j;break};case 217:{j=c[2415221]|0;m=c[2437644]|0;k=c[m+72+((j>>>8&255|512)<<2)>>2]|0;do{if((k|0)==0){r=c[m+3156>>2]|0;if((r|0)==0){dz=0;dA=j&65535;dB=m;break}n=gj[r&4095](j&65535)|0;dz=n;dA=b[4830442]|0;dB=c[2437644]|0}else{dz=a[k+(j&255)|0]|0;dA=j&65535;dB=m}}while(0);m=dz&255;c[2426868]=m;b[4830442]=dA+1&65535;j=dz&255;k=c[dB+72>>2]|0;do{if((k|0)==0){n=c[dB+3144>>2]|0;if((n|0)==0){dC=0;break}dC=gj[n&4095](j)|0}else{dC=a[k+m|0]|0}}while(0);m=a[9660896]|0;k=a[9660900]|0;j=(m&255)+(dC&255)+(k&1)|0;n=j^(m^dC)&255;a[9660900]=(n<<1&32|j>>>8&1|(n^j>>>1)>>>6&2|((j&255)<<24>>24==0?(j>>>4&8|k&-48&255)&255|4:(j>>>4&8|k&-48&255)&255)&255)&255;a[9660896]=j&255;break};case 218:{j=c[2415221]|0;k=c[2437644]|0;n=c[k+72+((j>>>8&255|512)<<2)>>2]|0;do{if((n|0)==0){m=c[k+3156>>2]|0;if((m|0)==0){dD=0;dE=j&65535;dF=k;break}r=gj[m&4095](j&65535)|0;dD=r;dE=b[4830442]|0;dF=c[2437644]|0}else{dD=a[n+(j&255)|0]|0;dE=j&65535;dF=k}}while(0);k=dD&255;c[2426868]=k;b[4830442]=dE+1&65535;j=dD&255;n=c[dF+72>>2]|0;do{if((n|0)==0){r=c[dF+3144>>2]|0;if((r|0)==0){dG=0;break}dG=gj[r&4095](j)|0}else{dG=a[n+k|0]|0}}while(0);k=a[9660896]|dG;a[9660896]=k;n=(k&255)>>>4&8|a[9660900]&-15;a[9660900]=k<<24>>24==0?n|4:n;break};default:{h=1}}}if(h){h=0;switch(i|0){case 219:{n=c[2415221]|0;k=c[2437644]|0;j=c[k+72+((n>>>8&255|512)<<2)>>2]|0;do{if((j|0)==0){r=c[k+3156>>2]|0;if((r|0)==0){dH=0;dI=n&65535;dJ=k;break}m=gj[r&4095](n&65535)|0;dH=m;dI=b[4830442]|0;dJ=c[2437644]|0}else{dH=a[j+(n&255)|0]|0;dI=n&65535;dJ=k}}while(0);k=dH&255;c[2426868]=k;b[4830442]=dI+1&65535;n=dH&255;j=c[dJ+72>>2]|0;do{if((j|0)==0){m=c[dJ+3144>>2]|0;if((m|0)==0){dK=0;break}dK=gj[m&4095](n)|0}else{dK=a[j+k|0]|0}}while(0);k=a[9660896]|0;j=(k&255)+(dK&255)|0;n=(j>>>4&8|a[9660900]&-48&255)&255;m=(k^dK)&255^j;a[9660900]=(m<<1&32|j>>>8&1|(m^j>>>1)>>>6&2|((j&255)<<24>>24==0?n|4:n)&255)&255;a[9660896]=j&255;break};case 220:{j=c[2415221]|0;n=c[2437644]|0;m=c[n+72+((j>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){k=c[n+3156>>2]|0;if((k|0)==0){dL=0;dM=j&65535;dN=n;break}r=gj[k&4095](j&65535)|0;dL=r;dM=b[4830442]|0;dN=c[2437644]|0}else{dL=a[m+(j&255)|0]|0;dM=j&65535;dN=n}}while(0);n=dL&255;c[2426868]=n;b[4830442]=dM+1&65535;j=dL&255;m=c[dN+72>>2]|0;do{if((m|0)==0){r=c[dN+3144>>2]|0;if((r|0)==0){dO=0;dP=dN;break}k=gj[r&4095](j)|0;dO=k;dP=c[2437644]|0}else{dO=a[m+n|0]|0;dP=dN}}while(0);m=dO&255;j=c[dP+72+(((n+1|0)>>>8&255)<<2)>>2]|0;do{if((j|0)==0){k=c[dP+3144>>2]|0;if((k|0)==0){dQ=0;break}dQ=gj[k&4095]((n+1|0)&65535)|0}else{dQ=a[j+((n+1|0)&255)|0]|0}}while(0);n=dQ&255|m<<8;c[2415224]=n;j=a[9660900]&-15;a[9660900]=j;if((n|0)==0){dR=(j&255|m>>>4&8|4)&255}else{dR=(j&255|m>>>4&8)&255}a[9660900]=dR;break};case 221:{j=c[2415221]|0;n=c[2437644]|0;k=c[n+72+((j>>>8&255|512)<<2)>>2]|0;do{if((k|0)==0){r=c[n+3156>>2]|0;if((r|0)==0){dS=0;dT=j&65535;dU=n;break}y=gj[r&4095](j&65535)|0;dS=y;dT=b[4830442]|0;dU=c[2437644]|0}else{dS=a[k+(j&255)|0]|0;dT=j&65535;dU=n}}while(0);n=dS&255;c[2426868]=n;b[4830442]=dT+1&65535;j=b[4830448]|0;k=(j&65535)>>>12&8|a[9660900]&-15&255;a[9660900]=(j<<16>>16==0?k|4:k)&255;k=dS&255;j=a[9660897]|0;m=c[dU+1096>>2]|0;do{if((m|0)==0){y=c[dU+3148>>2]|0;if((y|0)==0){dV=dU;break}gg[y&4095](k,j);dV=c[2437644]|0}else{a[m+n|0]=j;dV=dU}}while(0);j=a[9660896]|0;m=c[dV+72+(((n+1|0)>>>8&255|256)<<2)>>2]|0;if((m|0)!=0){a[m+((n+1|0)&255)|0]=j;c[d+23864>>2]=2;c[d+23868>>2]=26;break OL}m=c[dV+3148>>2]|0;if((m|0)==0){c[d+23864>>2]=2;c[d+23868>>2]=26;break OL}gg[m&4095]((n+1|0)&65535,j);break};case 222:{j=c[2415221]|0;m=c[2437644]|0;k=c[m+72+((j>>>8&255|512)<<2)>>2]|0;do{if((k|0)==0){y=c[m+3156>>2]|0;if((y|0)==0){dW=0;dX=j&65535;dY=m;break}r=gj[y&4095](j&65535)|0;dW=r;dX=b[4830442]|0;dY=c[2437644]|0}else{dW=a[k+(j&255)|0]|0;dX=j&65535;dY=m}}while(0);m=dW&255;c[2426868]=m;b[4830442]=dX+1&65535;j=dW&255;k=c[dY+72>>2]|0;do{if((k|0)==0){n=c[dY+3144>>2]|0;if((n|0)==0){dZ=0;d_=dY;break}r=gj[n&4095](j)|0;dZ=r;d_=c[2437644]|0}else{dZ=a[k+m|0]|0;d_=dY}}while(0);k=dZ&255;j=c[d_+72+(((m+1|0)>>>8&255)<<2)>>2]|0;do{if((j|0)==0){r=c[d_+3144>>2]|0;if((r|0)==0){d$=0;break}d$=gj[r&4095]((m+1|0)&65535)|0}else{d$=a[j+((m+1|0)&255)|0]|0}}while(0);m=d$&255|k<<8;c[2415223]=m;j=a[9660900]&-15;a[9660900]=j;if((m|0)==0){d0=(j&255|k>>>4&8|4)&255}else{d0=(j&255|k>>>4&8)&255}a[9660900]=d0;break};case 223:{j=b[4830446]|0;m=(j&65535)>>>12&8|a[9660900]&-15&255;a[9660900]=(j<<16>>16==0?m|4:m)&255;m=c[2415221]|0;j=c[2437644]|0;r=c[j+72+((m>>>8&255|512)<<2)>>2]|0;do{if((r|0)==0){n=c[j+3156>>2]|0;if((n|0)==0){d1=0;d2=m&65535;d3=j;break}y=gj[n&4095](m&65535)|0;d1=y;d2=b[4830442]|0;d3=c[2437644]|0}else{d1=a[r+(m&255)|0]|0;d2=m&65535;d3=j}}while(0);j=d1&255;c[2426868]=j;b[4830442]=d2+1&65535;m=d1&255;r=a[9660893]|0;k=c[d3+1096>>2]|0;do{if((k|0)==0){y=c[d3+3148>>2]|0;if((y|0)==0){d4=d3;break}gg[y&4095](m,r);d4=c[2437644]|0}else{a[k+j|0]=r;d4=d3}}while(0);r=a[9660892]|0;k=c[d4+72+(((j+1|0)>>>8&255|256)<<2)>>2]|0;if((k|0)!=0){a[k+((j+1|0)&255)|0]=r;c[d+23864>>2]=2;c[d+23868>>2]=26;break OL}k=c[d4+3148>>2]|0;if((k|0)==0){c[d+23864>>2]=2;c[d+23868>>2]=26;break OL}gg[k&4095]((j+1|0)&65535,r);break};case 224:{r=b[4830446]|0;k=c[2415221]|0;m=c[2437644]|0;y=c[m+72+((k>>>8&255|512)<<2)>>2]|0;do{if((y|0)==0){n=c[m+3156>>2]|0;if((n|0)==0){d5=0;d6=k&65535;d7=m;break}l=gj[n&4095](k&65535)|0;d5=l;d6=b[4830442]|0;d7=c[2437644]|0}else{d5=a[y+(k&255)|0]|0;d6=k&65535;d7=m}}while(0);b[4853736]=(d5&255)+r&65535;b[4830442]=d6+1&65535;m=c[2426868]|0;k=c[d7+72+((m>>>8&255)<<2)>>2]|0;do{if((k|0)==0){y=c[d7+3144>>2]|0;if((y|0)==0){d8=0;break}d8=gj[y&4095](m&65535)|0}else{d8=a[k+(m&255)|0]|0}}while(0);m=a[9660896]|0;k=(m&255)-(d8&255)|0;r=(k>>>4&8|a[9660900]&-16&255)&255;a[9660900]=(((m^d8)&255^k^k>>>1)>>>6&2|k>>>8&1|((k&255)<<24>>24==0?r|4:r)&255)&255;a[9660896]=k&255;break};case 225:{k=b[4830446]|0;r=c[2415221]|0;m=c[2437644]|0;y=c[m+72+((r>>>8&255|512)<<2)>>2]|0;do{if((y|0)==0){j=c[m+3156>>2]|0;if((j|0)==0){d9=0;ea=r&65535;eb=m;break}l=gj[j&4095](r&65535)|0;d9=l;ea=b[4830442]|0;eb=c[2437644]|0}else{d9=a[y+(r&255)|0]|0;ea=r&65535;eb=m}}while(0);b[4853736]=(d9&255)+k&65535;b[4830442]=ea+1&65535;m=c[2426868]|0;r=c[eb+72+((m>>>8&255)<<2)>>2]|0;do{if((r|0)==0){y=c[eb+3144>>2]|0;if((y|0)==0){ec=0;break}ec=gj[y&4095](m&65535)|0}else{ec=a[r+(m&255)|0]|0}}while(0);m=a[9660896]|0;r=(m&255)-(ec&255)|0;k=(r>>>4&8|a[9660900]&-16&255)&255;a[9660900]=(((m^ec)&255^r^r>>>1)>>>6&2|r>>>8&1|((r&255)<<24>>24==0?k|4:k)&255)&255;break};case 226:{k=b[4830446]|0;r=c[2415221]|0;m=c[2437644]|0;y=c[m+72+((r>>>8&255|512)<<2)>>2]|0;do{if((y|0)==0){l=c[m+3156>>2]|0;if((l|0)==0){ed=0;ee=r&65535;ef=m;break}j=gj[l&4095](r&65535)|0;ed=j;ee=b[4830442]|0;ef=c[2437644]|0}else{ed=a[y+(r&255)|0]|0;ee=r&65535;ef=m}}while(0);b[4853736]=(ed&255)+k&65535;b[4830442]=ee+1&65535;m=c[2426868]|0;r=c[ef+72+((m>>>8&255)<<2)>>2]|0;do{if((r|0)==0){y=c[ef+3144>>2]|0;if((y|0)==0){eg=0;break}eg=gj[y&4095](m&65535)|0}else{eg=a[r+(m&255)|0]|0}}while(0);m=a[9660896]|0;r=a[9660900]|0;k=(m&255)-(eg&255)-(r&1)|0;a[9660900]=((k^(m^eg)&255^k>>>1)>>>6&2|k>>>8&1|((k&255)<<24>>24==0?(k>>>4&8|r&-16&255)&255|4:(k>>>4&8|r&-16&255)&255)&255)&255;a[9660896]=k&255;break};case 227:{k=b[4830446]|0;r=c[2415221]|0;m=c[2437644]|0;y=c[m+72+((r>>>8&255|512)<<2)>>2]|0;do{if((y|0)==0){j=c[m+3156>>2]|0;if((j|0)==0){eh=0;ei=r&65535;ej=m;break}l=gj[j&4095](r&65535)|0;eh=l;ei=b[4830442]|0;ej=c[2437644]|0}else{eh=a[y+(r&255)|0]|0;ei=r&65535;ej=m}}while(0);b[4853736]=(eh&255)+k&65535;b[4830442]=ei+1&65535;m=c[2426868]|0;r=c[ej+72+((m>>>8&255)<<2)>>2]|0;do{if((r|0)==0){y=c[ej+3144>>2]|0;if((y|0)==0){ek=0;el=ej;break}l=gj[y&4095](m&65535)|0;ek=l;el=c[2437644]|0}else{ek=a[r+(m&255)|0]|0;el=ej}}while(0);r=(ek&255)<<8;k=c[el+72+(((m+1|0)>>>8&255)<<2)>>2]|0;do{if((k|0)==0){l=c[el+3144>>2]|0;if((l|0)==0){em=0;break}em=gj[l&4095]((m+1|0)&65535)|0}else{em=a[k+((m+1|0)&255)|0]|0}}while(0);m=e[4830448]|0;k=m+(em&255|r)|0;l=(k>>>12&8|a[9660900]&-16&255)&255;a[9660900]=((m^r^k^k>>>1)>>>14&2|k>>>16&1|((k&65535)<<16>>16==0?l|4:l)&255)&255;b[4830448]=k&65535;break};case 228:{k=b[4830446]|0;l=c[2415221]|0;m=c[2437644]|0;y=c[m+72+((l>>>8&255|512)<<2)>>2]|0;do{if((y|0)==0){j=c[m+3156>>2]|0;if((j|0)==0){en=0;eo=l&65535;ep=m;break}n=gj[j&4095](l&65535)|0;en=n;eo=b[4830442]|0;ep=c[2437644]|0}else{en=a[y+(l&255)|0]|0;eo=l&65535;ep=m}}while(0);b[4853736]=(en&255)+k&65535;b[4830442]=eo+1&65535;m=c[2426868]|0;l=c[ep+72+((m>>>8&255)<<2)>>2]|0;do{if((l|0)==0){y=c[ep+3144>>2]|0;if((y|0)==0){eq=0;break}eq=gj[y&4095](m&65535)|0}else{eq=a[l+(m&255)|0]|0}}while(0);m=a[9660896]&eq;a[9660896]=m;l=(m&255)>>>4&8|a[9660900]&-15;a[9660900]=m<<24>>24==0?l|4:l;break};case 229:{l=b[4830446]|0;m=c[2415221]|0;k=c[2437644]|0;y=c[k+72+((m>>>8&255|512)<<2)>>2]|0;do{if((y|0)==0){r=c[k+3156>>2]|0;if((r|0)==0){er=0;es=m&65535;et=k;break}n=gj[r&4095](m&65535)|0;er=n;es=b[4830442]|0;et=c[2437644]|0}else{er=a[y+(m&255)|0]|0;es=m&65535;et=k}}while(0);b[4853736]=(er&255)+l&65535;b[4830442]=es+1&65535;k=c[2426868]|0;m=c[et+72+((k>>>8&255)<<2)>>2]|0;do{if((m|0)==0){y=c[et+3144>>2]|0;if((y|0)==0){eu=0;break}eu=gj[y&4095](k&65535)|0}else{eu=a[m+(k&255)|0]|0}}while(0);k=a[9660896]&eu;m=(k&255)>>>4&8|a[9660900]&-15;a[9660900]=k<<24>>24==0?m|4:m;break};case 230:{m=b[4830446]|0;k=c[2415221]|0;l=c[2437644]|0;y=c[l+72+((k>>>8&255|512)<<2)>>2]|0;do{if((y|0)==0){n=c[l+3156>>2]|0;if((n|0)==0){ev=0;ew=k&65535;ex=l;break}r=gj[n&4095](k&65535)|0;ev=r;ew=b[4830442]|0;ex=c[2437644]|0}else{ev=a[y+(k&255)|0]|0;ew=k&65535;ex=l}}while(0);b[4853736]=(ev&255)+m&65535;b[4830442]=ew+1&65535;l=c[2426868]|0;k=c[ex+72+((l>>>8&255)<<2)>>2]|0;do{if((k|0)==0){y=c[ex+3144>>2]|0;if((y|0)==0){ey=0;break}ey=gj[y&4095](l&65535)|0}else{ey=a[k+(l&255)|0]|0}}while(0);a[9660896]=ey;l=(ey&255)>>>4&8|a[9660900]&-15;a[9660900]=ey<<24>>24==0?l|4:l;break};case 231:{l=a[9660896]|0;k=(l&255)>>>4&8|a[9660900]&-15;a[9660900]=l<<24>>24==0?k|4:k;k=b[4830446]|0;m=c[2415221]|0;y=c[2437644]|0;r=c[y+72+((m>>>8&255|512)<<2)>>2]|0;do{if((r|0)==0){n=c[y+3156>>2]|0;if((n|0)==0){ez=0;eA=m&65535;eB=l;eC=y;break}j=gj[n&4095](m&65535)|0;ez=j;eA=b[4830442]|0;eB=a[9660896]|0;eC=c[2437644]|0}else{ez=a[r+(m&255)|0]|0;eA=m&65535;eB=l;eC=y}}while(0);b[4853736]=(ez&255)+k&65535;b[4830442]=eA+1&65535;y=c[2426868]|0;l=c[eC+72+((y>>>8&255|256)<<2)>>2]|0;if((l|0)!=0){a[l+(y&255)|0]=eB;c[d+23864>>2]=2;c[d+23868>>2]=26;break OL}l=c[eC+3148>>2]|0;if((l|0)==0){c[d+23864>>2]=2;c[d+23868>>2]=26;break OL}gg[l&4095](y&65535,eB);break};case 232:{y=b[4830446]|0;l=c[2415221]|0;m=c[2437644]|0;r=c[m+72+((l>>>8&255|512)<<2)>>2]|0;do{if((r|0)==0){j=c[m+3156>>2]|0;if((j|0)==0){eD=0;eE=l&65535;eF=m;break}n=gj[j&4095](l&65535)|0;eD=n;eE=b[4830442]|0;eF=c[2437644]|0}else{eD=a[r+(l&255)|0]|0;eE=l&65535;eF=m}}while(0);b[4853736]=(eD&255)+y&65535;b[4830442]=eE+1&65535;m=c[2426868]|0;l=c[eF+72+((m>>>8&255)<<2)>>2]|0;do{if((l|0)==0){r=c[eF+3144>>2]|0;if((r|0)==0){eG=0;break}eG=gj[r&4095](m&65535)|0}else{eG=a[l+(m&255)|0]|0}}while(0);m=a[9660896]|0;l=m^eG;a[9660896]=l;y=(l&255)>>>4&8|a[9660900]&-15;a[9660900]=m<<24>>24==eG<<24>>24?y|4:y;break};case 233:{y=b[4830446]|0;m=c[2415221]|0;l=c[2437644]|0;r=c[l+72+((m>>>8&255|512)<<2)>>2]|0;do{if((r|0)==0){k=c[l+3156>>2]|0;if((k|0)==0){eH=0;eI=m&65535;eJ=l;break}n=gj[k&4095](m&65535)|0;eH=n;eI=b[4830442]|0;eJ=c[2437644]|0}else{eH=a[r+(m&255)|0]|0;eI=m&65535;eJ=l}}while(0);b[4853736]=(eH&255)+y&65535;b[4830442]=eI+1&65535;l=c[2426868]|0;m=c[eJ+72+((l>>>8&255)<<2)>>2]|0;do{if((m|0)==0){r=c[eJ+3144>>2]|0;if((r|0)==0){eK=0;break}eK=gj[r&4095](l&65535)|0}else{eK=a[m+(l&255)|0]|0}}while(0);l=a[9660896]|0;m=a[9660900]|0;y=(l&255)+(eK&255)+(m&1)|0;r=y^(l^eK)&255;a[9660900]=(r<<1&32|y>>>8&1|(r^y>>>1)>>>6&2|((y&255)<<24>>24==0?(y>>>4&8|m&-48&255)&255|4:(y>>>4&8|m&-48&255)&255)&255)&255;a[9660896]=y&255;break};case 234:{y=b[4830446]|0;m=c[2415221]|0;r=c[2437644]|0;l=c[r+72+((m>>>8&255|512)<<2)>>2]|0;do{if((l|0)==0){n=c[r+3156>>2]|0;if((n|0)==0){eL=0;eM=m&65535;eN=r;break}k=gj[n&4095](m&65535)|0;eL=k;eM=b[4830442]|0;eN=c[2437644]|0}else{eL=a[l+(m&255)|0]|0;eM=m&65535;eN=r}}while(0);b[4853736]=(eL&255)+y&65535;b[4830442]=eM+1&65535;r=c[2426868]|0;m=c[eN+72+((r>>>8&255)<<2)>>2]|0;do{if((m|0)==0){l=c[eN+3144>>2]|0;if((l|0)==0){eO=0;break}eO=gj[l&4095](r&65535)|0}else{eO=a[m+(r&255)|0]|0}}while(0);r=a[9660896]|eO;a[9660896]=r;m=(r&255)>>>4&8|a[9660900]&-15;a[9660900]=r<<24>>24==0?m|4:m;break};case 235:{m=b[4830446]|0;r=c[2415221]|0;y=c[2437644]|0;l=c[y+72+((r>>>8&255|512)<<2)>>2]|0;do{if((l|0)==0){k=c[y+3156>>2]|0;if((k|0)==0){eP=0;eQ=r&65535;eR=y;break}n=gj[k&4095](r&65535)|0;eP=n;eQ=b[4830442]|0;eR=c[2437644]|0}else{eP=a[l+(r&255)|0]|0;eQ=r&65535;eR=y}}while(0);b[4853736]=(eP&255)+m&65535;b[4830442]=eQ+1&65535;y=c[2426868]|0;r=c[eR+72+((y>>>8&255)<<2)>>2]|0;do{if((r|0)==0){l=c[eR+3144>>2]|0;if((l|0)==0){eS=0;break}eS=gj[l&4095](y&65535)|0}else{eS=a[r+(y&255)|0]|0}}while(0);y=a[9660896]|0;r=(y&255)+(eS&255)|0;m=(r>>>4&8|a[9660900]&-48&255)&255;l=(y^eS)&255^r;a[9660900]=(l<<1&32|r>>>8&1|(l^r>>>1)>>>6&2|((r&255)<<24>>24==0?m|4:m)&255)&255;a[9660896]=r&255;break};case 236:{r=b[4830446]|0;m=c[2415221]|0;l=c[2437644]|0;y=c[l+72+((m>>>8&255|512)<<2)>>2]|0;do{if((y|0)==0){n=c[l+3156>>2]|0;if((n|0)==0){eT=0;eU=m&65535;eV=l;break}k=gj[n&4095](m&65535)|0;eT=k;eU=b[4830442]|0;eV=c[2437644]|0}else{eT=a[y+(m&255)|0]|0;eU=m&65535;eV=l}}while(0);b[4853736]=(eT&255)+r&65535;b[4830442]=eU+1&65535;l=c[2426868]|0;m=c[eV+72+((l>>>8&255)<<2)>>2]|0;do{if((m|0)==0){y=c[eV+3144>>2]|0;if((y|0)==0){eW=0;eX=eV;break}k=gj[y&4095](l&65535)|0;eW=k;eX=c[2437644]|0}else{eW=a[m+(l&255)|0]|0;eX=eV}}while(0);m=eW&255;r=c[eX+72+(((l+1|0)>>>8&255)<<2)>>2]|0;do{if((r|0)==0){k=c[eX+3144>>2]|0;if((k|0)==0){eY=0;break}eY=gj[k&4095]((l+1|0)&65535)|0}else{eY=a[r+((l+1|0)&255)|0]|0}}while(0);l=eY&255|m<<8;c[2415224]=l;r=a[9660900]&-15;a[9660900]=r;if((l|0)==0){eZ=(r&255|m>>>4&8|4)&255}else{eZ=(r&255|m>>>4&8)&255}a[9660900]=eZ;break};case 237:{r=b[4830446]|0;l=c[2415221]|0;k=c[2437644]|0;y=c[k+72+((l>>>8&255|512)<<2)>>2]|0;do{if((y|0)==0){n=c[k+3156>>2]|0;if((n|0)==0){e_=0;e$=l&65535;e0=k;break}j=gj[n&4095](l&65535)|0;e_=j;e$=b[4830442]|0;e0=c[2437644]|0}else{e_=a[y+(l&255)|0]|0;e$=l&65535;e0=k}}while(0);b[4853736]=(e_&255)+r&65535;b[4830442]=e$+1&65535;k=b[4830448]|0;l=(k&65535)>>>12&8|a[9660900]&-15&255;a[9660900]=(k<<16>>16==0?l|4:l)&255;l=c[2426868]|0;k=a[9660897]|0;y=c[e0+72+((l>>>8&255|256)<<2)>>2]|0;do{if((y|0)==0){m=c[e0+3148>>2]|0;if((m|0)==0){e1=e0;break}gg[m&4095](l&65535,k);e1=c[2437644]|0}else{a[y+(l&255)|0]=k;e1=e0}}while(0);k=a[9660896]|0;y=c[e1+72+(((l+1|0)>>>8&255|256)<<2)>>2]|0;if((y|0)!=0){a[y+((l+1|0)&255)|0]=k;c[d+23864>>2]=2;c[d+23868>>2]=26;break OL}y=c[e1+3148>>2]|0;if((y|0)==0){c[d+23864>>2]=2;c[d+23868>>2]=26;break OL}gg[y&4095]((l+1|0)&65535,k);break};case 238:{k=b[4830446]|0;y=c[2415221]|0;r=c[2437644]|0;m=c[r+72+((y>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){j=c[r+3156>>2]|0;if((j|0)==0){e2=0;e3=y&65535;e4=r;break}n=gj[j&4095](y&65535)|0;e2=n;e3=b[4830442]|0;e4=c[2437644]|0}else{e2=a[m+(y&255)|0]|0;e3=y&65535;e4=r}}while(0);b[4853736]=(e2&255)+k&65535;b[4830442]=e3+1&65535;r=c[2426868]|0;y=c[e4+72+((r>>>8&255)<<2)>>2]|0;do{if((y|0)==0){m=c[e4+3144>>2]|0;if((m|0)==0){e5=0;e6=e4;break}l=gj[m&4095](r&65535)|0;e5=l;e6=c[2437644]|0}else{e5=a[y+(r&255)|0]|0;e6=e4}}while(0);y=e5&255;k=c[e6+72+(((r+1|0)>>>8&255)<<2)>>2]|0;do{if((k|0)==0){l=c[e6+3144>>2]|0;if((l|0)==0){e7=0;break}e7=gj[l&4095]((r+1|0)&65535)|0}else{e7=a[k+((r+1|0)&255)|0]|0}}while(0);r=e7&255|y<<8;c[2415223]=r;k=a[9660900]&-15;a[9660900]=k;if((r|0)==0){e8=(k&255|y>>>4&8|4)&255}else{e8=(k&255|y>>>4&8)&255}a[9660900]=e8;break};case 239:{k=b[4830446]|0;r=(k&65535)>>>12&8|a[9660900]&-15&255;a[9660900]=(k<<16>>16==0?r|4:r)&255;r=c[2415221]|0;l=c[2437644]|0;m=c[l+72+((r>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){n=c[l+3156>>2]|0;if((n|0)==0){e9=0;fa=r&65535;fb=l;break}j=gj[n&4095](r&65535)|0;e9=j;fa=b[4830442]|0;fb=c[2437644]|0}else{e9=a[m+(r&255)|0]|0;fa=r&65535;fb=l}}while(0);b[4853736]=(e9&255)+k&65535;b[4830442]=fa+1&65535;l=c[2426868]|0;r=a[9660893]|0;m=c[fb+72+((l>>>8&255|256)<<2)>>2]|0;do{if((m|0)==0){y=c[fb+3148>>2]|0;if((y|0)==0){fc=fb;break}gg[y&4095](l&65535,r);fc=c[2437644]|0}else{a[m+(l&255)|0]=r;fc=fb}}while(0);r=a[9660892]|0;m=c[fc+72+(((l+1|0)>>>8&255|256)<<2)>>2]|0;if((m|0)!=0){a[m+((l+1|0)&255)|0]=r;c[d+23864>>2]=2;c[d+23868>>2]=26;break OL}m=c[fc+3148>>2]|0;if((m|0)==0){c[d+23864>>2]=2;c[d+23868>>2]=26;break OL}gg[m&4095]((l+1|0)&65535,r);break};case 240:{r=c[2415221]|0;m=c[2437644]|0;k=c[m+72+((r>>>8&255|512)<<2)>>2]|0;do{if((k|0)==0){y=c[m+3156>>2]|0;if((y|0)==0){fd=0;fe=r;ff=m;fg=r&65535;break}j=gj[y&4095](r&65535)|0;y=c[2415221]|0;fd=j;fe=y;ff=c[2437644]|0;fg=y&65535}else{fd=a[k+(r&255)|0]|0;fe=r;ff=m;fg=r&65535}}while(0);r=fd&255;m=fe+1|0;k=c[ff+72+((m>>>8&255|512)<<2)>>2]|0;do{if((k|0)==0){l=c[ff+3156>>2]|0;if((l|0)==0){fh=0;fi=fg;fj=ff;break}y=gj[l&4095](m&65535)|0;fh=y;fi=b[4830442]|0;fj=c[2437644]|0}else{fh=a[k+(m&255)|0]|0;fi=fg;fj=ff}}while(0);m=fh&255;c[2426868]=m|r<<8;b[4830442]=fi+2&65535;k=c[fj+72+(r<<2)>>2]|0;do{if((k|0)==0){y=c[fj+3144>>2]|0;if((y|0)==0){fk=0;break}fk=gj[y&4095]((m|r<<8)&65535)|0}else{fk=a[k+m|0]|0}}while(0);m=a[9660896]|0;k=(m&255)-(fk&255)|0;r=(k>>>4&8|a[9660900]&-16&255)&255;a[9660900]=(((m^fk)&255^k^k>>>1)>>>6&2|k>>>8&1|((k&255)<<24>>24==0?r|4:r)&255)&255;a[9660896]=k&255;break};case 241:{k=c[2415221]|0;r=c[2437644]|0;m=c[r+72+((k>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){y=c[r+3156>>2]|0;if((y|0)==0){fl=0;fm=k;fn=r;fo=k&65535;break}l=gj[y&4095](k&65535)|0;y=c[2415221]|0;fl=l;fm=y;fn=c[2437644]|0;fo=y&65535}else{fl=a[m+(k&255)|0]|0;fm=k;fn=r;fo=k&65535}}while(0);k=fl&255;r=fm+1|0;m=c[fn+72+((r>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){y=c[fn+3156>>2]|0;if((y|0)==0){fp=0;fq=fo;fr=fn;break}l=gj[y&4095](r&65535)|0;fp=l;fq=b[4830442]|0;fr=c[2437644]|0}else{fp=a[m+(r&255)|0]|0;fq=fo;fr=fn}}while(0);r=fp&255;c[2426868]=r|k<<8;b[4830442]=fq+2&65535;m=c[fr+72+(k<<2)>>2]|0;do{if((m|0)==0){l=c[fr+3144>>2]|0;if((l|0)==0){fs=0;break}fs=gj[l&4095]((r|k<<8)&65535)|0}else{fs=a[m+r|0]|0}}while(0);r=a[9660896]|0;m=(r&255)-(fs&255)|0;k=(m>>>4&8|a[9660900]&-16&255)&255;a[9660900]=(((r^fs)&255^m^m>>>1)>>>6&2|m>>>8&1|((m&255)<<24>>24==0?k|4:k)&255)&255;break};case 242:{k=c[2415221]|0;m=c[2437644]|0;r=c[m+72+((k>>>8&255|512)<<2)>>2]|0;do{if((r|0)==0){l=c[m+3156>>2]|0;if((l|0)==0){ft=0;fu=k;fv=m;fw=k&65535;break}y=gj[l&4095](k&65535)|0;l=c[2415221]|0;ft=y;fu=l;fv=c[2437644]|0;fw=l&65535}else{ft=a[r+(k&255)|0]|0;fu=k;fv=m;fw=k&65535}}while(0);k=ft&255;m=fu+1|0;r=c[fv+72+((m>>>8&255|512)<<2)>>2]|0;do{if((r|0)==0){l=c[fv+3156>>2]|0;if((l|0)==0){fx=0;fy=fw;fz=fv;break}y=gj[l&4095](m&65535)|0;fx=y;fy=b[4830442]|0;fz=c[2437644]|0}else{fx=a[r+(m&255)|0]|0;fy=fw;fz=fv}}while(0);m=fx&255;c[2426868]=m|k<<8;b[4830442]=fy+2&65535;r=c[fz+72+(k<<2)>>2]|0;do{if((r|0)==0){y=c[fz+3144>>2]|0;if((y|0)==0){fA=0;break}fA=gj[y&4095]((m|k<<8)&65535)|0}else{fA=a[r+m|0]|0}}while(0);m=a[9660896]|0;r=a[9660900]|0;k=(m&255)-(fA&255)-(r&1)|0;a[9660900]=((k^(m^fA)&255^k>>>1)>>>6&2|k>>>8&1|((k&255)<<24>>24==0?(k>>>4&8|r&-16&255)&255|4:(k>>>4&8|r&-16&255)&255)&255)&255;a[9660896]=k&255;break};default:{h=1}}}if(h){h=0;switch(i|0){case 243:{k=c[2415221]|0;r=c[2437644]|0;m=c[r+72+((k>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){y=c[r+3156>>2]|0;if((y|0)==0){fB=0;fC=k;fD=r;fE=k&65535;break}l=gj[y&4095](k&65535)|0;y=c[2415221]|0;fB=l;fC=y;fD=c[2437644]|0;fE=y&65535}else{fB=a[m+(k&255)|0]|0;fC=k;fD=r;fE=k&65535}}while(0);k=fB&255;r=fC+1|0;m=c[fD+72+((r>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){y=c[fD+3156>>2]|0;if((y|0)==0){fF=0;fG=fE;fH=fD;break}l=gj[y&4095](r&65535)|0;fF=l;fG=b[4830442]|0;fH=c[2437644]|0}else{fF=a[m+(r&255)|0]|0;fG=fE;fH=fD}}while(0);r=fF&255;c[2426868]=r|k<<8;b[4830442]=fG+2&65535;m=c[fH+72+(k<<2)>>2]|0;do{if((m|0)==0){l=c[fH+3144>>2]|0;if((l|0)==0){fI=0;fJ=fH;break}y=gj[l&4095]((r|k<<8)&65535)|0;fI=y;fJ=c[2437644]|0}else{fI=a[m+r|0]|0;fJ=fH}}while(0);m=(fI&255)<<8;y=c[fJ+72+((((r|k<<8)+1|0)>>>8&255)<<2)>>2]|0;do{if((y|0)==0){l=c[fJ+3144>>2]|0;if((l|0)==0){fK=0;break}fK=gj[l&4095](((r|k<<8)+1|0)&65535)|0}else{fK=a[y+(((r|k<<8)+1|0)&255)|0]|0}}while(0);k=e[4830448]|0;r=k+(fK&255|m)|0;y=(r>>>12&8|a[9660900]&-16&255)&255;a[9660900]=((k^m^r^r>>>1)>>>14&2|r>>>16&1|((r&65535)<<16>>16==0?y|4:y)&255)&255;b[4830448]=r&65535;break};case 244:{r=c[2415221]|0;y=c[2437644]|0;k=c[y+72+((r>>>8&255|512)<<2)>>2]|0;do{if((k|0)==0){l=c[y+3156>>2]|0;if((l|0)==0){fL=0;fM=r;fN=y;fO=r&65535;break}j=gj[l&4095](r&65535)|0;l=c[2415221]|0;fL=j;fM=l;fN=c[2437644]|0;fO=l&65535}else{fL=a[k+(r&255)|0]|0;fM=r;fN=y;fO=r&65535}}while(0);r=fL&255;y=fM+1|0;k=c[fN+72+((y>>>8&255|512)<<2)>>2]|0;do{if((k|0)==0){m=c[fN+3156>>2]|0;if((m|0)==0){fP=0;fQ=fO;fR=fN;break}l=gj[m&4095](y&65535)|0;fP=l;fQ=b[4830442]|0;fR=c[2437644]|0}else{fP=a[k+(y&255)|0]|0;fQ=fO;fR=fN}}while(0);y=fP&255;c[2426868]=y|r<<8;b[4830442]=fQ+2&65535;k=c[fR+72+(r<<2)>>2]|0;do{if((k|0)==0){l=c[fR+3144>>2]|0;if((l|0)==0){fS=0;break}fS=gj[l&4095]((y|r<<8)&65535)|0}else{fS=a[k+y|0]|0}}while(0);y=a[9660896]&fS;a[9660896]=y;k=(y&255)>>>4&8|a[9660900]&-15;a[9660900]=y<<24>>24==0?k|4:k;break};case 245:{k=c[2415221]|0;y=c[2437644]|0;r=c[y+72+((k>>>8&255|512)<<2)>>2]|0;do{if((r|0)==0){l=c[y+3156>>2]|0;if((l|0)==0){fT=0;fU=k;fV=y;fW=k&65535;break}m=gj[l&4095](k&65535)|0;l=c[2415221]|0;fT=m;fU=l;fV=c[2437644]|0;fW=l&65535}else{fT=a[r+(k&255)|0]|0;fU=k;fV=y;fW=k&65535}}while(0);k=fT&255;y=fU+1|0;r=c[fV+72+((y>>>8&255|512)<<2)>>2]|0;do{if((r|0)==0){l=c[fV+3156>>2]|0;if((l|0)==0){fX=0;fY=fW;fZ=fV;break}m=gj[l&4095](y&65535)|0;fX=m;fY=b[4830442]|0;fZ=c[2437644]|0}else{fX=a[r+(y&255)|0]|0;fY=fW;fZ=fV}}while(0);y=fX&255;c[2426868]=y|k<<8;b[4830442]=fY+2&65535;r=c[fZ+72+(k<<2)>>2]|0;do{if((r|0)==0){m=c[fZ+3144>>2]|0;if((m|0)==0){f_=0;break}f_=gj[m&4095]((y|k<<8)&65535)|0}else{f_=a[r+y|0]|0}}while(0);y=a[9660896]&f_;r=(y&255)>>>4&8|a[9660900]&-15;a[9660900]=y<<24>>24==0?r|4:r;break};case 246:{r=c[2415221]|0;y=c[2437644]|0;k=c[y+72+((r>>>8&255|512)<<2)>>2]|0;do{if((k|0)==0){m=c[y+3156>>2]|0;if((m|0)==0){f$=0;f0=r;f1=y;f2=r&65535;break}l=gj[m&4095](r&65535)|0;m=c[2415221]|0;f$=l;f0=m;f1=c[2437644]|0;f2=m&65535}else{f$=a[k+(r&255)|0]|0;f0=r;f1=y;f2=r&65535}}while(0);r=f$&255;y=f0+1|0;k=c[f1+72+((y>>>8&255|512)<<2)>>2]|0;do{if((k|0)==0){m=c[f1+3156>>2]|0;if((m|0)==0){f3=0;f4=f2;f5=f1;break}l=gj[m&4095](y&65535)|0;f3=l;f4=b[4830442]|0;f5=c[2437644]|0}else{f3=a[k+(y&255)|0]|0;f4=f2;f5=f1}}while(0);y=f3&255;c[2426868]=y|r<<8;b[4830442]=f4+2&65535;k=c[f5+72+(r<<2)>>2]|0;do{if((k|0)==0){l=c[f5+3144>>2]|0;if((l|0)==0){f6=0;break}f6=gj[l&4095]((y|r<<8)&65535)|0}else{f6=a[k+y|0]|0}}while(0);a[9660896]=f6;y=(f6&255)>>>4&8|a[9660900]&-15;a[9660900]=f6<<24>>24==0?y|4:y;break};case 247:{y=a[9660896]|0;k=(y&255)>>>4&8|a[9660900]&-15;a[9660900]=y<<24>>24==0?k|4:k;k=c[2415221]|0;y=c[2437644]|0;r=c[y+72+((k>>>8&255|512)<<2)>>2]|0;do{if((r|0)==0){l=c[y+3156>>2]|0;if((l|0)==0){f7=0;f8=k;f9=y;ga=k&65535;break}m=gj[l&4095](k&65535)|0;l=c[2415221]|0;f7=m;f8=l;f9=c[2437644]|0;ga=l&65535}else{f7=a[r+(k&255)|0]|0;f8=k;f9=y;ga=k&65535}}while(0);k=f7&255;y=f8+1|0;r=c[f9+72+((y>>>8&255|512)<<2)>>2]|0;do{if((r|0)==0){l=c[f9+3156>>2]|0;if((l|0)==0){gb=0;gc=ga;gd=f9;break}m=gj[l&4095](y&65535)|0;gb=m;gc=b[4830442]|0;gd=c[2437644]|0}else{gb=a[r+(y&255)|0]|0;gc=ga;gd=f9}}while(0);y=gb&255;c[2426868]=y|k<<8;b[4830442]=gc+2&65535;r=a[9660896]|0;m=c[gd+72+((k|256)<<2)>>2]|0;if((m|0)!=0){a[m+y|0]=r;c[d+23864>>2]=2;c[d+23868>>2]=26;break OL}m=c[gd+3148>>2]|0;if((m|0)==0){c[d+23864>>2]=2;c[d+23868>>2]=26;break OL}gg[m&4095]((y|k<<8)&65535,r);break};case 248:{r=c[2415221]|0;y=c[2437644]|0;m=c[y+72+((r>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){l=c[y+3156>>2]|0;if((l|0)==0){ge=0;gf=r;gh=y;gi=r&65535;break}j=gj[l&4095](r&65535)|0;l=c[2415221]|0;ge=j;gf=l;gh=c[2437644]|0;gi=l&65535}else{ge=a[m+(r&255)|0]|0;gf=r;gh=y;gi=r&65535}}while(0);r=ge&255;y=gf+1|0;m=c[gh+72+((y>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){k=c[gh+3156>>2]|0;if((k|0)==0){gk=0;gl=gi;gm=gh;break}l=gj[k&4095](y&65535)|0;gk=l;gl=b[4830442]|0;gm=c[2437644]|0}else{gk=a[m+(y&255)|0]|0;gl=gi;gm=gh}}while(0);y=gk&255;c[2426868]=y|r<<8;b[4830442]=gl+2&65535;m=c[gm+72+(r<<2)>>2]|0;do{if((m|0)==0){l=c[gm+3144>>2]|0;if((l|0)==0){gn=0;break}gn=gj[l&4095]((y|r<<8)&65535)|0}else{gn=a[m+y|0]|0}}while(0);y=a[9660896]|0;m=y^gn;a[9660896]=m;r=(m&255)>>>4&8|a[9660900]&-15;a[9660900]=y<<24>>24==gn<<24>>24?r|4:r;break};case 249:{r=c[2415221]|0;y=c[2437644]|0;m=c[y+72+((r>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){l=c[y+3156>>2]|0;if((l|0)==0){go=0;gp=r;gq=y;gr=r&65535;break}k=gj[l&4095](r&65535)|0;l=c[2415221]|0;go=k;gp=l;gq=c[2437644]|0;gr=l&65535}else{go=a[m+(r&255)|0]|0;gp=r;gq=y;gr=r&65535}}while(0);r=go&255;y=gp+1|0;m=c[gq+72+((y>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){l=c[gq+3156>>2]|0;if((l|0)==0){gs=0;gt=gr;gu=gq;break}k=gj[l&4095](y&65535)|0;gs=k;gt=b[4830442]|0;gu=c[2437644]|0}else{gs=a[m+(y&255)|0]|0;gt=gr;gu=gq}}while(0);y=gs&255;c[2426868]=y|r<<8;b[4830442]=gt+2&65535;m=c[gu+72+(r<<2)>>2]|0;do{if((m|0)==0){k=c[gu+3144>>2]|0;if((k|0)==0){gv=0;break}gv=gj[k&4095]((y|r<<8)&65535)|0}else{gv=a[m+y|0]|0}}while(0);y=a[9660896]|0;m=a[9660900]|0;r=(y&255)+(gv&255)+(m&1)|0;k=r^(y^gv)&255;a[9660900]=(k<<1&32|r>>>8&1|(k^r>>>1)>>>6&2|((r&255)<<24>>24==0?(r>>>4&8|m&-48&255)&255|4:(r>>>4&8|m&-48&255)&255)&255)&255;a[9660896]=r&255;break};case 250:{r=c[2415221]|0;m=c[2437644]|0;k=c[m+72+((r>>>8&255|512)<<2)>>2]|0;do{if((k|0)==0){y=c[m+3156>>2]|0;if((y|0)==0){gw=0;gx=r;gy=m;gz=r&65535;break}l=gj[y&4095](r&65535)|0;y=c[2415221]|0;gw=l;gx=y;gy=c[2437644]|0;gz=y&65535}else{gw=a[k+(r&255)|0]|0;gx=r;gy=m;gz=r&65535}}while(0);r=gw&255;m=gx+1|0;k=c[gy+72+((m>>>8&255|512)<<2)>>2]|0;do{if((k|0)==0){y=c[gy+3156>>2]|0;if((y|0)==0){gA=0;gB=gz;gC=gy;break}l=gj[y&4095](m&65535)|0;gA=l;gB=b[4830442]|0;gC=c[2437644]|0}else{gA=a[k+(m&255)|0]|0;gB=gz;gC=gy}}while(0);m=gA&255;c[2426868]=m|r<<8;b[4830442]=gB+2&65535;k=c[gC+72+(r<<2)>>2]|0;do{if((k|0)==0){l=c[gC+3144>>2]|0;if((l|0)==0){gD=0;break}gD=gj[l&4095]((m|r<<8)&65535)|0}else{gD=a[k+m|0]|0}}while(0);m=a[9660896]|gD;a[9660896]=m;k=(m&255)>>>4&8|a[9660900]&-15;a[9660900]=m<<24>>24==0?k|4:k;break};case 251:{k=c[2415221]|0;m=c[2437644]|0;r=c[m+72+((k>>>8&255|512)<<2)>>2]|0;do{if((r|0)==0){l=c[m+3156>>2]|0;if((l|0)==0){gE=0;gF=k;gG=m;gH=k&65535;break}y=gj[l&4095](k&65535)|0;l=c[2415221]|0;gE=y;gF=l;gG=c[2437644]|0;gH=l&65535}else{gE=a[r+(k&255)|0]|0;gF=k;gG=m;gH=k&65535}}while(0);k=gE&255;m=gF+1|0;r=c[gG+72+((m>>>8&255|512)<<2)>>2]|0;do{if((r|0)==0){l=c[gG+3156>>2]|0;if((l|0)==0){gI=0;gJ=gH;gK=gG;break}y=gj[l&4095](m&65535)|0;gI=y;gJ=b[4830442]|0;gK=c[2437644]|0}else{gI=a[r+(m&255)|0]|0;gJ=gH;gK=gG}}while(0);m=gI&255;c[2426868]=m|k<<8;b[4830442]=gJ+2&65535;r=c[gK+72+(k<<2)>>2]|0;do{if((r|0)==0){y=c[gK+3144>>2]|0;if((y|0)==0){gL=0;break}gL=gj[y&4095]((m|k<<8)&65535)|0}else{gL=a[r+m|0]|0}}while(0);m=a[9660896]|0;r=(m&255)+(gL&255)|0;k=(r>>>4&8|a[9660900]&-48&255)&255;y=(m^gL)&255^r;a[9660900]=(y<<1&32|r>>>8&1|(y^r>>>1)>>>6&2|((r&255)<<24>>24==0?k|4:k)&255)&255;a[9660896]=r&255;break};case 252:{f4B();break};case 253:{f4C();break};case 254:{f4a();break};case 255:{f4b();break};default:{}}}}while(0);c[d+23848>>2]=h}function __Z15hd63701_executei$0(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0,cf=0,cg=0,ch=0,ci=0,cj=0,ck=0,cl=0,cm=0,cn=0,co=0,cp=0,cq=0,cr=0,cs=0,ct=0,cu=0,cv=0,cw=0,cx=0,cy=0,cz=0,cA=0,cB=0,cC=0,cD=0,cE=0,cF=0,cG=0,cH=0,cI=0,cJ=0,cK=0,cL=0,cM=0,cN=0,cO=0,cP=0,cQ=0,cR=0,cS=0,cT=0,cU=0,cV=0,cW=0,cX=0,cY=0,cZ=0,c_=0,c$=0,c0=0,c1=0,c2=0,c3=0,c4=0,c5=0,c6=0,c7=0,c8=0,c9=0,da=0,db=0,dc=0,dd=0,de=0,df=0,dg=0,dh=0,di=0,dj=0,dk=0,dl=0,dm=0,dn=0,dp=0,dq=0,dr=0,ds=0,dt=0,du=0,dv=0,dw=0,dx=0,dy=0,dz=0,dA=0,dB=0,dC=0,dD=0,dE=0,dF=0,dG=0,dH=0,dI=0,dJ=0,dK=0,dL=0,dM=0,dN=0,dO=0,dP=0,dQ=0,dR=0,dS=0,dT=0,dU=0,dV=0,dW=0,dX=0,dY=0,dZ=0,d_=0,d$=0,d0=0,d1=0,d2=0,d3=0,d4=0,d5=0,d6=0,d7=0,d8=0,d9=0,ea=0,eb=0,ec=0,ed=0,ee=0,ef=0,eg=0,eh=0,ei=0,ej=0,ek=0,el=0,em=0,en=0,eo=0,ep=0,eq=0,er=0,es=0,et=0,eu=0,ev=0,ew=0,ex=0,ey=0,ez=0,eA=0,eB=0,eC=0,eD=0,eE=0,eF=0,eG=0,eH=0,eI=0,eJ=0,eK=0,eL=0,eM=0,eN=0,eO=0,eP=0,eQ=0,eR=0,eS=0,eT=0,eU=0,eV=0,eW=0,eX=0,eY=0,eZ=0,e_=0,e$=0,e0=0,e1=0,e2=0,e3=0,e4=0,e5=0,e6=0,e7=0,e8=0,e9=0,fa=0,fb=0,fc=0,fd=0,fe=0,ff=0,fg=0,fh=0,fi=0,fj=0,fk=0,fl=0,fm=0,fn=0,fo=0,fp=0,fq=0,fr=0,fs=0,ft=0,fu=0,fv=0,fw=0,fx=0,fy=0,fz=0,fA=0,fB=0,fC=0,fD=0,fE=0,fF=0,fG=0,fH=0,fI=0,fJ=0,fK=0,fL=0,fM=0,fN=0,fO=0,fP=0,fQ=0,fR=0,fS=0,fT=0,fU=0,fV=0,fW=0,fX=0,fY=0,fZ=0,f_=0,f$=0,f0=0,f1=0,f2=0,f3=0,f4=0,f5=0,f6=0,f7=0,f8=0,f9=0,ga=0,gb=0,gc=0,gd=0,ge=0,gf=0,gh=0,gi=0,gk=0,gl=0,gm=0,gn=0,go=0,gp=0,gq=0,gr=0,gs=0,gt=0,gu=0,gv=0,gw=0,gx=0,gy=0,gz=0,gA=0,gB=0,gC=0,gD=0,gE=0,gF=0,gG=0,gH=0,gI=0,gJ=0,gK=0,gL=0,gM=0,gN=0,gO=0,gP=0,gQ=0,gR=0,gS=0,gT=0,gU=0,gV=0,gW=0,gX=0,gY=0,gZ=0,g_=0,g$=0,g0=0,g1=0,g2=0,g3=0,g4=0,g5=0,g6=0,g7=0,g8=0,g9=0,ha=0,hb=0,hc=0,hd=0,he=0,hf=0,hg=0,hh=0,hi=0,hj=0,hk=0,hl=0,hm=0,hn=0,ho=0,hp=0,hq=0,hr=0,hs=0,ht=0,hu=0,hv=0,hw=0;g=c[f+136>>2]|0;h=c[f+152>>2]|0;i=c[f+25616>>2]|0;j=c[f+25624>>2]|0;OL:do{if(i){i=0;switch(j|0){case 180:{k=c[2415221]|0;l=c[2437644]|0;m=c[l+72+((k>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){n=c[l+3156>>2]|0;if((n|0)==0){o=0;p=k;q=l;r=k&65535;break}s=gj[n&4095](k&65535)|0;n=c[2415221]|0;o=s;p=n;q=c[2437644]|0;r=n&65535}else{o=a[m+(k&255)|0]|0;p=k;q=l;r=k&65535}}while(0);k=o&255;l=p+1|0;m=c[q+72+((l>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){n=c[q+3156>>2]|0;if((n|0)==0){t=0;u=r;v=q;break}s=gj[n&4095](l&65535)|0;t=s;u=b[4830442]|0;v=c[2437644]|0}else{t=a[m+(l&255)|0]|0;u=r;v=q}}while(0);l=t&255;c[2426868]=l|k<<8;b[4830442]=u+2&65535;m=c[v+72+(k<<2)>>2]|0;do{if((m|0)==0){s=c[v+3144>>2]|0;if((s|0)==0){w=0;break}w=gj[s&4095]((l|k<<8)&65535)|0}else{w=a[m+l|0]|0}}while(0);l=a[9660897]&w;a[9660897]=l;m=(l&255)>>>4&8|a[9660900]&-15;a[9660900]=l<<24>>24==0?m|4:m;break};case 181:{m=c[2415221]|0;l=c[2437644]|0;k=c[l+72+((m>>>8&255|512)<<2)>>2]|0;do{if((k|0)==0){s=c[l+3156>>2]|0;if((s|0)==0){x=0;y=m;z=l;A=m&65535;break}n=gj[s&4095](m&65535)|0;s=c[2415221]|0;x=n;y=s;z=c[2437644]|0;A=s&65535}else{x=a[k+(m&255)|0]|0;y=m;z=l;A=m&65535}}while(0);m=x&255;l=y+1|0;k=c[z+72+((l>>>8&255|512)<<2)>>2]|0;do{if((k|0)==0){s=c[z+3156>>2]|0;if((s|0)==0){B=0;C=A;D=z;break}n=gj[s&4095](l&65535)|0;B=n;C=b[4830442]|0;D=c[2437644]|0}else{B=a[k+(l&255)|0]|0;C=A;D=z}}while(0);l=B&255;c[2426868]=l|m<<8;b[4830442]=C+2&65535;k=c[D+72+(m<<2)>>2]|0;do{if((k|0)==0){n=c[D+3144>>2]|0;if((n|0)==0){E=0;break}E=gj[n&4095]((l|m<<8)&65535)|0}else{E=a[k+l|0]|0}}while(0);l=a[9660897]&E;k=(l&255)>>>4&8|a[9660900]&-15;a[9660900]=l<<24>>24==0?k|4:k;break};case 182:{k=c[2415221]|0;l=c[2437644]|0;m=c[l+72+((k>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){n=c[l+3156>>2]|0;if((n|0)==0){F=0;G=k;H=l;I=k&65535;break}s=gj[n&4095](k&65535)|0;n=c[2415221]|0;F=s;G=n;H=c[2437644]|0;I=n&65535}else{F=a[m+(k&255)|0]|0;G=k;H=l;I=k&65535}}while(0);k=F&255;l=G+1|0;m=c[H+72+((l>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){n=c[H+3156>>2]|0;if((n|0)==0){J=0;K=I;L=H;break}s=gj[n&4095](l&65535)|0;J=s;K=b[4830442]|0;L=c[2437644]|0}else{J=a[m+(l&255)|0]|0;K=I;L=H}}while(0);l=J&255;c[2426868]=l|k<<8;b[4830442]=K+2&65535;m=c[L+72+(k<<2)>>2]|0;do{if((m|0)==0){s=c[L+3144>>2]|0;if((s|0)==0){M=0;break}M=gj[s&4095]((l|k<<8)&65535)|0}else{M=a[m+l|0]|0}}while(0);a[9660897]=M;l=(M&255)>>>4&8|a[9660900]&-15;a[9660900]=M<<24>>24==0?l|4:l;break};case 183:{l=a[9660897]|0;m=(l&255)>>>4&8|a[9660900]&-15;a[9660900]=l<<24>>24==0?m|4:m;m=c[2415221]|0;l=c[2437644]|0;k=c[l+72+((m>>>8&255|512)<<2)>>2]|0;do{if((k|0)==0){s=c[l+3156>>2]|0;if((s|0)==0){N=0;O=m;P=l;Q=m&65535;break}n=gj[s&4095](m&65535)|0;s=c[2415221]|0;N=n;O=s;P=c[2437644]|0;Q=s&65535}else{N=a[k+(m&255)|0]|0;O=m;P=l;Q=m&65535}}while(0);m=N&255;l=O+1|0;k=c[P+72+((l>>>8&255|512)<<2)>>2]|0;do{if((k|0)==0){s=c[P+3156>>2]|0;if((s|0)==0){R=0;S=Q;T=P;break}n=gj[s&4095](l&65535)|0;R=n;S=b[4830442]|0;T=c[2437644]|0}else{R=a[k+(l&255)|0]|0;S=Q;T=P}}while(0);l=R&255;c[2426868]=l|m<<8;b[4830442]=S+2&65535;k=a[9660897]|0;n=c[T+72+((m|256)<<2)>>2]|0;if((n|0)!=0){a[n+l|0]=k;c[f+25632>>2]=2;c[f+25636>>2]=56;break OL}n=c[T+3148>>2]|0;if((n|0)==0){c[f+25632>>2]=2;c[f+25636>>2]=56;break OL}gg[n&4095]((l|m<<8)&65535,k);break};case 184:{k=c[2415221]|0;l=c[2437644]|0;n=c[l+72+((k>>>8&255|512)<<2)>>2]|0;do{if((n|0)==0){s=c[l+3156>>2]|0;if((s|0)==0){U=0;V=k;W=l;X=k&65535;break}Y=gj[s&4095](k&65535)|0;s=c[2415221]|0;U=Y;V=s;W=c[2437644]|0;X=s&65535}else{U=a[n+(k&255)|0]|0;V=k;W=l;X=k&65535}}while(0);k=U&255;l=V+1|0;n=c[W+72+((l>>>8&255|512)<<2)>>2]|0;do{if((n|0)==0){m=c[W+3156>>2]|0;if((m|0)==0){Z=0;_=X;$=W;break}s=gj[m&4095](l&65535)|0;Z=s;_=b[4830442]|0;$=c[2437644]|0}else{Z=a[n+(l&255)|0]|0;_=X;$=W}}while(0);l=Z&255;c[2426868]=l|k<<8;b[4830442]=_+2&65535;n=c[$+72+(k<<2)>>2]|0;do{if((n|0)==0){s=c[$+3144>>2]|0;if((s|0)==0){aa=0;break}aa=gj[s&4095]((l|k<<8)&65535)|0}else{aa=a[n+l|0]|0}}while(0);l=a[9660897]|0;n=l^aa;a[9660897]=n;k=(n&255)>>>4&8|a[9660900]&-15;a[9660900]=l<<24>>24==aa<<24>>24?k|4:k;break};case 185:{k=c[2415221]|0;l=c[2437644]|0;n=c[l+72+((k>>>8&255|512)<<2)>>2]|0;do{if((n|0)==0){s=c[l+3156>>2]|0;if((s|0)==0){ab=0;ac=k;ad=l;ae=k&65535;break}m=gj[s&4095](k&65535)|0;s=c[2415221]|0;ab=m;ac=s;ad=c[2437644]|0;ae=s&65535}else{ab=a[n+(k&255)|0]|0;ac=k;ad=l;ae=k&65535}}while(0);k=ab&255;l=ac+1|0;n=c[ad+72+((l>>>8&255|512)<<2)>>2]|0;do{if((n|0)==0){s=c[ad+3156>>2]|0;if((s|0)==0){af=0;ah=ae;ai=ad;break}m=gj[s&4095](l&65535)|0;af=m;ah=b[4830442]|0;ai=c[2437644]|0}else{af=a[n+(l&255)|0]|0;ah=ae;ai=ad}}while(0);l=af&255;c[2426868]=l|k<<8;b[4830442]=ah+2&65535;n=c[ai+72+(k<<2)>>2]|0;do{if((n|0)==0){m=c[ai+3144>>2]|0;if((m|0)==0){aj=0;break}aj=gj[m&4095]((l|k<<8)&65535)|0}else{aj=a[n+l|0]|0}}while(0);l=a[9660897]|0;n=a[9660900]|0;k=(l&255)+(aj&255)+(n&1)|0;m=k^(l^aj)&255;a[9660900]=(m<<1&32|k>>>8&1|(m^k>>>1)>>>6&2|((k&255)<<24>>24==0?(k>>>4&8|n&-48&255)&255|4:(k>>>4&8|n&-48&255)&255)&255)&255;a[9660897]=k&255;break};case 186:{k=c[2415221]|0;n=c[2437644]|0;m=c[n+72+((k>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){l=c[n+3156>>2]|0;if((l|0)==0){ak=0;al=k;am=n;an=k&65535;break}s=gj[l&4095](k&65535)|0;l=c[2415221]|0;ak=s;al=l;am=c[2437644]|0;an=l&65535}else{ak=a[m+(k&255)|0]|0;al=k;am=n;an=k&65535}}while(0);k=ak&255;n=al+1|0;m=c[am+72+((n>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){l=c[am+3156>>2]|0;if((l|0)==0){ao=0;ap=an;aq=am;break}s=gj[l&4095](n&65535)|0;ao=s;ap=b[4830442]|0;aq=c[2437644]|0}else{ao=a[m+(n&255)|0]|0;ap=an;aq=am}}while(0);n=ao&255;c[2426868]=n|k<<8;b[4830442]=ap+2&65535;m=c[aq+72+(k<<2)>>2]|0;do{if((m|0)==0){s=c[aq+3144>>2]|0;if((s|0)==0){ar=0;break}ar=gj[s&4095]((n|k<<8)&65535)|0}else{ar=a[m+n|0]|0}}while(0);n=a[9660897]|ar;a[9660897]=n;m=(n&255)>>>4&8|a[9660900]&-15;a[9660900]=n<<24>>24==0?m|4:m;break};case 187:{m=c[2415221]|0;n=c[2437644]|0;k=c[n+72+((m>>>8&255|512)<<2)>>2]|0;do{if((k|0)==0){s=c[n+3156>>2]|0;if((s|0)==0){as=0;at=m;au=n;av=m&65535;break}l=gj[s&4095](m&65535)|0;s=c[2415221]|0;as=l;at=s;au=c[2437644]|0;av=s&65535}else{as=a[k+(m&255)|0]|0;at=m;au=n;av=m&65535}}while(0);m=as&255;n=at+1|0;k=c[au+72+((n>>>8&255|512)<<2)>>2]|0;do{if((k|0)==0){s=c[au+3156>>2]|0;if((s|0)==0){aw=0;ax=av;ay=au;break}l=gj[s&4095](n&65535)|0;aw=l;ax=b[4830442]|0;ay=c[2437644]|0}else{aw=a[k+(n&255)|0]|0;ax=av;ay=au}}while(0);n=aw&255;c[2426868]=n|m<<8;b[4830442]=ax+2&65535;k=c[ay+72+(m<<2)>>2]|0;do{if((k|0)==0){l=c[ay+3144>>2]|0;if((l|0)==0){az=0;break}az=gj[l&4095]((n|m<<8)&65535)|0}else{az=a[k+n|0]|0}}while(0);n=a[9660897]|0;k=(n&255)+(az&255)|0;m=(k>>>4&8|a[9660900]&-48&255)&255;l=(n^az)&255^k;a[9660900]=(l<<1&32|k>>>8&1|(l^k>>>1)>>>6&2|((k&255)<<24>>24==0?m|4:m)&255)&255;a[9660897]=k&255;break};case 188:{k=c[2415221]|0;m=c[2437644]|0;l=c[m+72+((k>>>8&255|512)<<2)>>2]|0;do{if((l|0)==0){n=c[m+3156>>2]|0;if((n|0)==0){aA=0;aB=k;aC=m;aD=k&65535;break}s=gj[n&4095](k&65535)|0;n=c[2415221]|0;aA=s;aB=n;aC=c[2437644]|0;aD=n&65535}else{aA=a[l+(k&255)|0]|0;aB=k;aC=m;aD=k&65535}}while(0);k=aA&255;m=aB+1|0;l=c[aC+72+((m>>>8&255|512)<<2)>>2]|0;do{if((l|0)==0){n=c[aC+3156>>2]|0;if((n|0)==0){aE=0;aF=aD;aG=aC;break}s=gj[n&4095](m&65535)|0;aE=s;aF=b[4830442]|0;aG=c[2437644]|0}else{aE=a[l+(m&255)|0]|0;aF=aD;aG=aC}}while(0);m=aE&255;c[2426868]=m|k<<8;b[4830442]=aF+2&65535;l=c[aG+72+(k<<2)>>2]|0;do{if((l|0)==0){s=c[aG+3144>>2]|0;if((s|0)==0){aH=0;aI=aG;break}n=gj[s&4095]((m|k<<8)&65535)|0;aH=n;aI=c[2437644]|0}else{aH=a[l+m|0]|0;aI=aG}}while(0);l=(aH&255)<<8;n=c[aI+72+((((m|k<<8)+1|0)>>>8&255)<<2)>>2]|0;do{if((n|0)==0){s=c[aI+3144>>2]|0;if((s|0)==0){aJ=0;break}aJ=gj[s&4095](((m|k<<8)+1|0)&65535)|0}else{aJ=a[n+(((m|k<<8)+1|0)&255)|0]|0}}while(0);k=e[4830446]|0;m=k-(aJ&255|l)|0;n=(m>>>12&8|a[9660900]&-16&255)&255;a[9660900]=((k^l^m^m>>>1)>>>14&2|m>>>16&1|((m&65535)<<16>>16==0?n|4:n)&255)&255;break};case 189:{n=c[2415221]|0;m=c[2437644]|0;k=c[m+72+((n>>>8&255|512)<<2)>>2]|0;do{if((k|0)==0){s=c[m+3156>>2]|0;if((s|0)==0){aK=0;aL=n;aM=m;aN=n&65535;break}Y=gj[s&4095](n&65535)|0;s=c[2415221]|0;aK=Y;aL=s;aM=c[2437644]|0;aN=s&65535}else{aK=a[k+(n&255)|0]|0;aL=n;aM=m;aN=n&65535}}while(0);n=(aK&255)<<8;m=aL+1|0;k=c[aM+72+((m>>>8&255|512)<<2)>>2]|0;do{if((k|0)==0){l=c[aM+3156>>2]|0;if((l|0)==0){aO=0;aP=aN;aQ=aM;break}s=gj[l&4095](m&65535)|0;aO=s;aP=b[4830442]|0;aQ=c[2437644]|0}else{aO=a[k+(m&255)|0]|0;aP=aN;aQ=aM}}while(0);c[2426868]=aO&255|n;m=aP+2&65535;b[4830442]=m;k=c[2415222]|0;s=c[aQ+72+((k>>>8&255|256)<<2)>>2]|0;do{if((s|0)==0){l=c[aQ+3148>>2]|0;if((l|0)==0){aR=aQ;break}gg[l&4095](k&65535,m&255);aR=c[2437644]|0}else{a[s+(k&255)|0]=m&255;aR=aQ}}while(0);b[4830444]=(b[4830444]|0)-1&65535;m=c[2415222]|0;k=a[9660885]|0;s=c[aR+72+((m>>>8&255|256)<<2)>>2]|0;do{if((s|0)==0){n=c[aR+3148>>2]|0;if((n|0)==0){break}gg[n&4095](m&65535,k)}else{a[s+(m&255)|0]=k}}while(0);b[4830444]=(b[4830444]|0)-1&65535;b[4830442]=b[4853736]|0;b[4830442]=c[2415221]&65535;break};case 190:{f3m();break};case 191:{f3n();break};case 192:{k=c[2415221]|0;m=c[2437644]|0;s=c[m+72+((k>>>8&255|512)<<2)>>2]|0;do{if((s|0)==0){n=c[m+3156>>2]|0;if((n|0)==0){aS=0;aT=k&65535;break}l=gj[n&4095](k&65535)|0;aS=l;aT=b[4830442]|0}else{aS=a[s+(k&255)|0]|0;aT=k&65535}}while(0);b[4830442]=aT+1&65535;k=a[9660896]|0;s=(k&255)-(aS&255)|0;m=(s>>>4&8|a[9660900]&-16&255)&255;a[9660900]=(((k^aS)&255^s^s>>>1)>>>6&2|s>>>8&1|((s&255)<<24>>24==0?m|4:m)&255)&255;a[9660896]=s&255;break};case 193:{s=c[2415221]|0;m=c[2437644]|0;k=c[m+72+((s>>>8&255|512)<<2)>>2]|0;do{if((k|0)==0){l=c[m+3156>>2]|0;if((l|0)==0){aU=0;aV=s&65535;break}n=gj[l&4095](s&65535)|0;aU=n;aV=b[4830442]|0}else{aU=a[k+(s&255)|0]|0;aV=s&65535}}while(0);b[4830442]=aV+1&65535;s=a[9660896]|0;k=(s&255)-(aU&255)|0;m=(k>>>4&8|a[9660900]&-16&255)&255;a[9660900]=(((s^aU)&255^k^k>>>1)>>>6&2|k>>>8&1|((k&255)<<24>>24==0?m|4:m)&255)&255;break};case 194:{m=c[2415221]|0;k=c[2437644]|0;s=c[k+72+((m>>>8&255|512)<<2)>>2]|0;do{if((s|0)==0){n=c[k+3156>>2]|0;if((n|0)==0){aW=0;aX=m&65535;break}l=gj[n&4095](m&65535)|0;aW=l;aX=b[4830442]|0}else{aW=a[s+(m&255)|0]|0;aX=m&65535}}while(0);b[4830442]=aX+1&65535;m=a[9660896]|0;s=a[9660900]|0;k=(m&255)-(aW&255)-(s&1)|0;a[9660900]=((k^(m^aW)&255^k>>>1)>>>6&2|k>>>8&1|((k&255)<<24>>24==0?(k>>>4&8|s&-16&255)&255|4:(k>>>4&8|s&-16&255)&255)&255)&255;a[9660896]=k&255;break};case 195:{k=c[2415221]|0;s=c[2437644]|0;m=c[s+72+((k>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){l=c[s+3156>>2]|0;if((l|0)==0){aY=0;aZ=k;a_=s;a$=k&65535;break}n=gj[l&4095](k&65535)|0;l=c[2415221]|0;aY=n;aZ=l;a_=c[2437644]|0;a$=l&65535}else{aY=a[m+(k&255)|0]|0;aZ=k;a_=s;a$=k&65535}}while(0);k=(aY&255)<<8;s=aZ+1|0;m=c[a_+72+((s>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){l=c[a_+3156>>2]|0;if((l|0)==0){a0=0;a1=a$;break}n=gj[l&4095](s&65535)|0;a0=n;a1=b[4830442]|0}else{a0=a[m+(s&255)|0]|0;a1=a$}}while(0);b[4830442]=a1+2&65535;s=e[4830448]|0;m=s+(a0&255|k)|0;n=(m>>>12&8|a[9660900]&-16&255)&255;a[9660900]=((s^k^m^m>>>1)>>>14&2|m>>>16&1|((m&65535)<<16>>16==0?n|4:n)&255)&255;b[4830448]=m&65535;break};case 196:{m=c[2415221]|0;n=c[2437644]|0;s=c[n+72+((m>>>8&255|512)<<2)>>2]|0;do{if((s|0)==0){l=c[n+3156>>2]|0;if((l|0)==0){a2=0;a3=m&65535;break}Y=gj[l&4095](m&65535)|0;a2=Y;a3=b[4830442]|0}else{a2=a[s+(m&255)|0]|0;a3=m&65535}}while(0);b[4830442]=a3+1&65535;m=a[9660896]&a2;a[9660896]=m;s=(m&255)>>>4&8|a[9660900]&-15;a[9660900]=m<<24>>24==0?s|4:s;break};case 197:{s=c[2415221]|0;m=c[2437644]|0;n=c[m+72+((s>>>8&255|512)<<2)>>2]|0;do{if((n|0)==0){k=c[m+3156>>2]|0;if((k|0)==0){a4=0;a5=s&65535;break}Y=gj[k&4095](s&65535)|0;a4=Y;a5=b[4830442]|0}else{a4=a[n+(s&255)|0]|0;a5=s&65535}}while(0);b[4830442]=a5+1&65535;s=a[9660896]&a4;n=(s&255)>>>4&8|a[9660900]&-15;a[9660900]=s<<24>>24==0?n|4:n;break};case 198:{n=c[2415221]|0;s=c[2437644]|0;m=c[s+72+((n>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){Y=c[s+3156>>2]|0;if((Y|0)==0){a6=0;a7=n&65535;break}k=gj[Y&4095](n&65535)|0;a6=k;a7=b[4830442]|0}else{a6=a[m+(n&255)|0]|0;a7=n&65535}}while(0);a[9660896]=a6;b[4830442]=a7+1&65535;n=a[9660900]&-15|(a6&255)>>>4&8;a[9660900]=a6<<24>>24==0?n|4:n;break};case 199:{n=a[9660896]|0;m=(n&255)>>>4&8|a[9660900]&-15;a[9660900]=n<<24>>24==0?m|4:m;b[4830442]=g+2&65535;b[4853736]=h;m=c[2426868]|0;s=c[2437644]|0;k=c[s+72+((m>>>8&255|256)<<2)>>2]|0;if((k|0)!=0){a[k+(m&255)|0]=n;c[f+25632>>2]=2;c[f+25636>>2]=56;break OL}k=c[s+3148>>2]|0;if((k|0)==0){c[f+25632>>2]=2;c[f+25636>>2]=56;break OL}gg[k&4095](m&65535,n);break};case 200:{n=c[2415221]|0;m=c[2437644]|0;k=c[m+72+((n>>>8&255|512)<<2)>>2]|0;do{if((k|0)==0){s=c[m+3156>>2]|0;if((s|0)==0){a8=0;a9=n&65535;break}Y=gj[s&4095](n&65535)|0;a8=Y;a9=b[4830442]|0}else{a8=a[k+(n&255)|0]|0;a9=n&65535}}while(0);b[4830442]=a9+1&65535;n=a[9660896]|0;k=n^a8;a[9660896]=k;m=(k&255)>>>4&8|a[9660900]&-15;a[9660900]=n<<24>>24==a8<<24>>24?m|4:m;break};case 201:{m=c[2415221]|0;n=c[2437644]|0;k=c[n+72+((m>>>8&255|512)<<2)>>2]|0;do{if((k|0)==0){Y=c[n+3156>>2]|0;if((Y|0)==0){ba=0;bb=m&65535;break}s=gj[Y&4095](m&65535)|0;ba=s;bb=b[4830442]|0}else{ba=a[k+(m&255)|0]|0;bb=m&65535}}while(0);b[4830442]=bb+1&65535;m=a[9660896]|0;k=a[9660900]|0;n=(m&255)+(ba&255)+(k&1)|0;s=n^(m^ba)&255;a[9660900]=(s<<1&32|n>>>8&1|(s^n>>>1)>>>6&2|((n&255)<<24>>24==0?(n>>>4&8|k&-48&255)&255|4:(n>>>4&8|k&-48&255)&255)&255)&255;a[9660896]=n&255;break};case 202:{n=c[2415221]|0;k=c[2437644]|0;s=c[k+72+((n>>>8&255|512)<<2)>>2]|0;do{if((s|0)==0){m=c[k+3156>>2]|0;if((m|0)==0){bc=0;bd=n&65535;break}Y=gj[m&4095](n&65535)|0;bc=Y;bd=b[4830442]|0}else{bc=a[s+(n&255)|0]|0;bd=n&65535}}while(0);b[4830442]=bd+1&65535;n=a[9660896]|bc;a[9660896]=n;s=(n&255)>>>4&8|a[9660900]&-15;a[9660900]=n<<24>>24==0?s|4:s;break};case 203:{s=c[2415221]|0;n=c[2437644]|0;k=c[n+72+((s>>>8&255|512)<<2)>>2]|0;do{if((k|0)==0){Y=c[n+3156>>2]|0;if((Y|0)==0){be=0;bf=s&65535;break}m=gj[Y&4095](s&65535)|0;be=m;bf=b[4830442]|0}else{be=a[k+(s&255)|0]|0;bf=s&65535}}while(0);b[4830442]=bf+1&65535;s=a[9660896]|0;k=(s&255)+(be&255)|0;n=(k>>>4&8|a[9660900]&-48&255)&255;m=(s^be)&255^k;a[9660900]=(m<<1&32|k>>>8&1|(m^k>>>1)>>>6&2|((k&255)<<24>>24==0?n|4:n)&255)&255;a[9660896]=k&255;break};case 204:{k=c[2415221]|0;n=c[2437644]|0;m=c[n+72+((k>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){s=c[n+3156>>2]|0;if((s|0)==0){bg=0;bh=k;bi=n;bj=k&65535;break}Y=gj[s&4095](k&65535)|0;s=c[2415221]|0;bg=Y;bh=s;bi=c[2437644]|0;bj=s&65535}else{bg=a[m+(k&255)|0]|0;bh=k;bi=n;bj=k&65535}}while(0);k=bg&255;n=bh+1|0;m=c[bi+72+((n>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){s=c[bi+3156>>2]|0;if((s|0)==0){bk=0;bl=bj;break}Y=gj[s&4095](n&65535)|0;bk=Y;bl=b[4830442]|0}else{bk=a[m+(n&255)|0]|0;bl=bj}}while(0);n=bk&255|k<<8;c[2415224]=n;b[4830442]=bl+2&65535;m=a[9660900]&-15;a[9660900]=m;if((n|0)==0){bm=(m&255|k>>>4&8|4)&255}else{bm=(m&255|k>>>4&8)&255}a[9660900]=bm;break};case 205:{b[4853736]=h;b[4830442]=g+3&65535;m=b[4830448]|0;n=(m&65535)>>>12&8|a[9660900]&-15&255;a[9660900]=(m<<16>>16==0?n|4:n)&255;n=c[2426868]|0;m=a[9660897]|0;Y=c[2437644]|0;s=c[Y+72+((n>>>8&255|256)<<2)>>2]|0;do{if((s|0)==0){l=c[Y+3148>>2]|0;if((l|0)==0){bn=Y;break}gg[l&4095](n&65535,m);bn=c[2437644]|0}else{a[s+(n&255)|0]=m;bn=Y}}while(0);Y=a[9660896]|0;m=c[bn+72+(((n+1|0)>>>8&255|256)<<2)>>2]|0;if((m|0)!=0){a[m+((n+1|0)&255)|0]=Y;c[f+25632>>2]=2;c[f+25636>>2]=56;break OL}m=c[bn+3148>>2]|0;if((m|0)==0){c[f+25632>>2]=2;c[f+25636>>2]=56;break OL}gg[m&4095]((n+1|0)&65535,Y);break};case 206:{Y=c[2415221]|0;m=c[2437644]|0;s=c[m+72+((Y>>>8&255|512)<<2)>>2]|0;do{if((s|0)==0){k=c[m+3156>>2]|0;if((k|0)==0){bo=0;bp=Y;bq=m;br=Y&65535;break}l=gj[k&4095](Y&65535)|0;k=c[2415221]|0;bo=l;bp=k;bq=c[2437644]|0;br=k&65535}else{bo=a[s+(Y&255)|0]|0;bp=Y;bq=m;br=Y&65535}}while(0);Y=bo&255;m=bp+1|0;s=c[bq+72+((m>>>8&255|512)<<2)>>2]|0;do{if((s|0)==0){n=c[bq+3156>>2]|0;if((n|0)==0){bs=0;bt=br;break}k=gj[n&4095](m&65535)|0;bs=k;bt=b[4830442]|0}else{bs=a[s+(m&255)|0]|0;bt=br}}while(0);m=bs&255|Y<<8;c[2415223]=m;b[4830442]=bt+2&65535;s=a[9660900]&-15;a[9660900]=s;if((m|0)==0){bu=(s&255|Y>>>4&8|4)&255}else{bu=(s&255|Y>>>4&8)&255}a[9660900]=bu;break};case 207:{s=b[4830446]|0;m=(s&65535)>>>12&8|a[9660900]&-15&255;a[9660900]=(s<<16>>16==0?m|4:m)&255;b[4853736]=h;b[4830442]=g+3&65535;m=c[2426868]|0;s=a[9660893]|0;k=c[2437644]|0;n=c[k+72+((m>>>8&255|256)<<2)>>2]|0;do{if((n|0)==0){l=c[k+3148>>2]|0;if((l|0)==0){bv=k;break}gg[l&4095](m&65535,s);bv=c[2437644]|0}else{a[n+(m&255)|0]=s;bv=k}}while(0);k=a[9660892]|0;s=c[bv+72+(((m+1|0)>>>8&255|256)<<2)>>2]|0;if((s|0)!=0){a[s+((m+1|0)&255)|0]=k;c[f+25632>>2]=2;c[f+25636>>2]=56;break OL}s=c[bv+3148>>2]|0;if((s|0)==0){c[f+25632>>2]=2;c[f+25636>>2]=56;break OL}gg[s&4095]((m+1|0)&65535,k);break};case 208:{k=c[2415221]|0;s=c[2437644]|0;n=c[s+72+((k>>>8&255|512)<<2)>>2]|0;do{if((n|0)==0){Y=c[s+3156>>2]|0;if((Y|0)==0){bw=0;bx=k&65535;by=s;break}l=gj[Y&4095](k&65535)|0;bw=l;bx=b[4830442]|0;by=c[2437644]|0}else{bw=a[n+(k&255)|0]|0;bx=k&65535;by=s}}while(0);s=bw&255;c[2426868]=s;b[4830442]=bx+1&65535;k=bw&255;n=c[by+72>>2]|0;do{if((n|0)==0){m=c[by+3144>>2]|0;if((m|0)==0){bz=0;break}bz=gj[m&4095](k)|0}else{bz=a[n+s|0]|0}}while(0);s=a[9660896]|0;n=(s&255)-(bz&255)|0;k=(n>>>4&8|a[9660900]&-16&255)&255;a[9660900]=(((s^bz)&255^n^n>>>1)>>>6&2|n>>>8&1|((n&255)<<24>>24==0?k|4:k)&255)&255;a[9660896]=n&255;break};case 209:{n=c[2415221]|0;k=c[2437644]|0;s=c[k+72+((n>>>8&255|512)<<2)>>2]|0;do{if((s|0)==0){m=c[k+3156>>2]|0;if((m|0)==0){bA=0;bB=n&65535;bC=k;break}l=gj[m&4095](n&65535)|0;bA=l;bB=b[4830442]|0;bC=c[2437644]|0}else{bA=a[s+(n&255)|0]|0;bB=n&65535;bC=k}}while(0);k=bA&255;c[2426868]=k;b[4830442]=bB+1&65535;n=bA&255;s=c[bC+72>>2]|0;do{if((s|0)==0){l=c[bC+3144>>2]|0;if((l|0)==0){bD=0;break}bD=gj[l&4095](n)|0}else{bD=a[s+k|0]|0}}while(0);k=a[9660896]|0;s=(k&255)-(bD&255)|0;n=(s>>>4&8|a[9660900]&-16&255)&255;a[9660900]=(((k^bD)&255^s^s>>>1)>>>6&2|s>>>8&1|((s&255)<<24>>24==0?n|4:n)&255)&255;break};case 210:{n=c[2415221]|0;s=c[2437644]|0;k=c[s+72+((n>>>8&255|512)<<2)>>2]|0;do{if((k|0)==0){l=c[s+3156>>2]|0;if((l|0)==0){bE=0;bF=n&65535;bG=s;break}m=gj[l&4095](n&65535)|0;bE=m;bF=b[4830442]|0;bG=c[2437644]|0}else{bE=a[k+(n&255)|0]|0;bF=n&65535;bG=s}}while(0);s=bE&255;c[2426868]=s;b[4830442]=bF+1&65535;n=bE&255;k=c[bG+72>>2]|0;do{if((k|0)==0){m=c[bG+3144>>2]|0;if((m|0)==0){bH=0;break}bH=gj[m&4095](n)|0}else{bH=a[k+s|0]|0}}while(0);s=a[9660896]|0;k=a[9660900]|0;n=(s&255)-(bH&255)-(k&1)|0;a[9660900]=((n^(s^bH)&255^n>>>1)>>>6&2|n>>>8&1|((n&255)<<24>>24==0?(n>>>4&8|k&-16&255)&255|4:(n>>>4&8|k&-16&255)&255)&255)&255;a[9660896]=n&255;break};default:{i=1}}}if(i){i=0;switch(j|0){case 211:{n=c[2415221]|0;k=c[2437644]|0;s=c[k+72+((n>>>8&255|512)<<2)>>2]|0;do{if((s|0)==0){m=c[k+3156>>2]|0;if((m|0)==0){bI=0;bJ=n&65535;bK=k;break}l=gj[m&4095](n&65535)|0;bI=l;bJ=b[4830442]|0;bK=c[2437644]|0}else{bI=a[s+(n&255)|0]|0;bJ=n&65535;bK=k}}while(0);k=bI&255;c[2426868]=k;b[4830442]=bJ+1&65535;n=bI&255;s=c[bK+72>>2]|0;do{if((s|0)==0){l=c[bK+3144>>2]|0;if((l|0)==0){bL=0;bM=bK;break}m=gj[l&4095](n)|0;bL=m;bM=c[2437644]|0}else{bL=a[s+k|0]|0;bM=bK}}while(0);s=(bL&255)<<8;n=c[bM+72+(((k+1|0)>>>8&255)<<2)>>2]|0;do{if((n|0)==0){m=c[bM+3144>>2]|0;if((m|0)==0){bN=0;break}bN=gj[m&4095]((k+1|0)&65535)|0}else{bN=a[n+((k+1|0)&255)|0]|0}}while(0);k=e[4830448]|0;n=k+(bN&255|s)|0;m=(n>>>12&8|a[9660900]&-16&255)&255;a[9660900]=((k^s^n^n>>>1)>>>14&2|n>>>16&1|((n&65535)<<16>>16==0?m|4:m)&255)&255;b[4830448]=n&65535;break};case 212:{n=c[2415221]|0;m=c[2437644]|0;k=c[m+72+((n>>>8&255|512)<<2)>>2]|0;do{if((k|0)==0){l=c[m+3156>>2]|0;if((l|0)==0){bO=0;bP=n&65535;bQ=m;break}Y=gj[l&4095](n&65535)|0;bO=Y;bP=b[4830442]|0;bQ=c[2437644]|0}else{bO=a[k+(n&255)|0]|0;bP=n&65535;bQ=m}}while(0);m=bO&255;c[2426868]=m;b[4830442]=bP+1&65535;n=bO&255;k=c[bQ+72>>2]|0;do{if((k|0)==0){s=c[bQ+3144>>2]|0;if((s|0)==0){bR=0;break}bR=gj[s&4095](n)|0}else{bR=a[k+m|0]|0}}while(0);m=a[9660896]&bR;a[9660896]=m;k=(m&255)>>>4&8|a[9660900]&-15;a[9660900]=m<<24>>24==0?k|4:k;break};case 213:{k=c[2415221]|0;m=c[2437644]|0;n=c[m+72+((k>>>8&255|512)<<2)>>2]|0;do{if((n|0)==0){s=c[m+3156>>2]|0;if((s|0)==0){bS=0;bT=k&65535;bU=m;break}Y=gj[s&4095](k&65535)|0;bS=Y;bT=b[4830442]|0;bU=c[2437644]|0}else{bS=a[n+(k&255)|0]|0;bT=k&65535;bU=m}}while(0);m=bS&255;c[2426868]=m;b[4830442]=bT+1&65535;k=bS&255;n=c[bU+72>>2]|0;do{if((n|0)==0){Y=c[bU+3144>>2]|0;if((Y|0)==0){bV=0;break}bV=gj[Y&4095](k)|0}else{bV=a[n+m|0]|0}}while(0);m=a[9660896]&bV;n=(m&255)>>>4&8|a[9660900]&-15;a[9660900]=m<<24>>24==0?n|4:n;break};case 214:{n=c[2415221]|0;m=c[2437644]|0;k=c[m+72+((n>>>8&255|512)<<2)>>2]|0;do{if((k|0)==0){Y=c[m+3156>>2]|0;if((Y|0)==0){bW=0;bX=n&65535;bY=m;break}s=gj[Y&4095](n&65535)|0;bW=s;bX=b[4830442]|0;bY=c[2437644]|0}else{bW=a[k+(n&255)|0]|0;bX=n&65535;bY=m}}while(0);m=bW&255;c[2426868]=m;b[4830442]=bX+1&65535;n=bW&255;k=c[bY+72>>2]|0;do{if((k|0)==0){s=c[bY+3144>>2]|0;if((s|0)==0){bZ=0;break}bZ=gj[s&4095](n)|0}else{bZ=a[k+m|0]|0}}while(0);a[9660896]=bZ;m=(bZ&255)>>>4&8|a[9660900]&-15;a[9660900]=bZ<<24>>24==0?m|4:m;break};case 215:{m=a[9660896]|0;k=(m&255)>>>4&8|a[9660900]&-15;a[9660900]=m<<24>>24==0?k|4:k;k=c[2415221]|0;n=c[2437644]|0;s=c[n+72+((k>>>8&255|512)<<2)>>2]|0;do{if((s|0)==0){Y=c[n+3156>>2]|0;if((Y|0)==0){b_=0;b$=k&65535;b0=m;b1=n;break}l=gj[Y&4095](k&65535)|0;b_=l;b$=b[4830442]|0;b0=a[9660896]|0;b1=c[2437644]|0}else{b_=a[s+(k&255)|0]|0;b$=k&65535;b0=m;b1=n}}while(0);n=b_&255;c[2426868]=n;b[4830442]=b$+1&65535;m=c[b1+1096>>2]|0;if((m|0)!=0){a[m+n|0]=b0;c[f+25632>>2]=2;c[f+25636>>2]=56;break OL}n=c[b1+3148>>2]|0;if((n|0)==0){c[f+25632>>2]=2;c[f+25636>>2]=56;break OL}gg[n&4095](b_&255,b0);break};case 216:{n=c[2415221]|0;m=c[2437644]|0;k=c[m+72+((n>>>8&255|512)<<2)>>2]|0;do{if((k|0)==0){s=c[m+3156>>2]|0;if((s|0)==0){b2=0;b3=n&65535;b4=m;break}l=gj[s&4095](n&65535)|0;b2=l;b3=b[4830442]|0;b4=c[2437644]|0}else{b2=a[k+(n&255)|0]|0;b3=n&65535;b4=m}}while(0);m=b2&255;c[2426868]=m;b[4830442]=b3+1&65535;n=b2&255;k=c[b4+72>>2]|0;do{if((k|0)==0){l=c[b4+3144>>2]|0;if((l|0)==0){b5=0;break}b5=gj[l&4095](n)|0}else{b5=a[k+m|0]|0}}while(0);m=a[9660896]|0;k=m^b5;a[9660896]=k;n=(k&255)>>>4&8|a[9660900]&-15;a[9660900]=m<<24>>24==b5<<24>>24?n|4:n;break};case 217:{n=c[2415221]|0;m=c[2437644]|0;k=c[m+72+((n>>>8&255|512)<<2)>>2]|0;do{if((k|0)==0){l=c[m+3156>>2]|0;if((l|0)==0){b6=0;b7=n&65535;b8=m;break}s=gj[l&4095](n&65535)|0;b6=s;b7=b[4830442]|0;b8=c[2437644]|0}else{b6=a[k+(n&255)|0]|0;b7=n&65535;b8=m}}while(0);m=b6&255;c[2426868]=m;b[4830442]=b7+1&65535;n=b6&255;k=c[b8+72>>2]|0;do{if((k|0)==0){s=c[b8+3144>>2]|0;if((s|0)==0){b9=0;break}b9=gj[s&4095](n)|0}else{b9=a[k+m|0]|0}}while(0);m=a[9660896]|0;k=a[9660900]|0;n=(m&255)+(b9&255)+(k&1)|0;s=n^(m^b9)&255;a[9660900]=(s<<1&32|n>>>8&1|(s^n>>>1)>>>6&2|((n&255)<<24>>24==0?(n>>>4&8|k&-48&255)&255|4:(n>>>4&8|k&-48&255)&255)&255)&255;a[9660896]=n&255;break};case 218:{n=c[2415221]|0;k=c[2437644]|0;s=c[k+72+((n>>>8&255|512)<<2)>>2]|0;do{if((s|0)==0){m=c[k+3156>>2]|0;if((m|0)==0){ca=0;cb=n&65535;cc=k;break}l=gj[m&4095](n&65535)|0;ca=l;cb=b[4830442]|0;cc=c[2437644]|0}else{ca=a[s+(n&255)|0]|0;cb=n&65535;cc=k}}while(0);k=ca&255;c[2426868]=k;b[4830442]=cb+1&65535;n=ca&255;s=c[cc+72>>2]|0;do{if((s|0)==0){l=c[cc+3144>>2]|0;if((l|0)==0){cd=0;break}cd=gj[l&4095](n)|0}else{cd=a[s+k|0]|0}}while(0);k=a[9660896]|cd;a[9660896]=k;s=(k&255)>>>4&8|a[9660900]&-15;a[9660900]=k<<24>>24==0?s|4:s;break};case 219:{s=c[2415221]|0;k=c[2437644]|0;n=c[k+72+((s>>>8&255|512)<<2)>>2]|0;do{if((n|0)==0){l=c[k+3156>>2]|0;if((l|0)==0){ce=0;cf=s&65535;cg=k;break}m=gj[l&4095](s&65535)|0;ce=m;cf=b[4830442]|0;cg=c[2437644]|0}else{ce=a[n+(s&255)|0]|0;cf=s&65535;cg=k}}while(0);k=ce&255;c[2426868]=k;b[4830442]=cf+1&65535;s=ce&255;n=c[cg+72>>2]|0;do{if((n|0)==0){m=c[cg+3144>>2]|0;if((m|0)==0){ch=0;break}ch=gj[m&4095](s)|0}else{ch=a[n+k|0]|0}}while(0);k=a[9660896]|0;n=(k&255)+(ch&255)|0;s=(n>>>4&8|a[9660900]&-48&255)&255;m=(k^ch)&255^n;a[9660900]=(m<<1&32|n>>>8&1|(m^n>>>1)>>>6&2|((n&255)<<24>>24==0?s|4:s)&255)&255;a[9660896]=n&255;break};case 220:{n=c[2415221]|0;s=c[2437644]|0;m=c[s+72+((n>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){k=c[s+3156>>2]|0;if((k|0)==0){ci=0;cj=n&65535;ck=s;break}l=gj[k&4095](n&65535)|0;ci=l;cj=b[4830442]|0;ck=c[2437644]|0}else{ci=a[m+(n&255)|0]|0;cj=n&65535;ck=s}}while(0);s=ci&255;c[2426868]=s;b[4830442]=cj+1&65535;n=ci&255;m=c[ck+72>>2]|0;do{if((m|0)==0){l=c[ck+3144>>2]|0;if((l|0)==0){cl=0;cm=ck;break}k=gj[l&4095](n)|0;cl=k;cm=c[2437644]|0}else{cl=a[m+s|0]|0;cm=ck}}while(0);m=cl&255;n=c[cm+72+(((s+1|0)>>>8&255)<<2)>>2]|0;do{if((n|0)==0){k=c[cm+3144>>2]|0;if((k|0)==0){cn=0;break}cn=gj[k&4095]((s+1|0)&65535)|0}else{cn=a[n+((s+1|0)&255)|0]|0}}while(0);s=cn&255|m<<8;c[2415224]=s;n=a[9660900]&-15;a[9660900]=n;if((s|0)==0){co=(n&255|m>>>4&8|4)&255}else{co=(n&255|m>>>4&8)&255}a[9660900]=co;break};case 221:{n=c[2415221]|0;s=c[2437644]|0;k=c[s+72+((n>>>8&255|512)<<2)>>2]|0;do{if((k|0)==0){l=c[s+3156>>2]|0;if((l|0)==0){cp=0;cq=n&65535;cr=s;break}Y=gj[l&4095](n&65535)|0;cp=Y;cq=b[4830442]|0;cr=c[2437644]|0}else{cp=a[k+(n&255)|0]|0;cq=n&65535;cr=s}}while(0);s=cp&255;c[2426868]=s;b[4830442]=cq+1&65535;n=b[4830448]|0;k=(n&65535)>>>12&8|a[9660900]&-15&255;a[9660900]=(n<<16>>16==0?k|4:k)&255;k=cp&255;n=a[9660897]|0;m=c[cr+1096>>2]|0;do{if((m|0)==0){Y=c[cr+3148>>2]|0;if((Y|0)==0){cs=cr;break}gg[Y&4095](k,n);cs=c[2437644]|0}else{a[m+s|0]=n;cs=cr}}while(0);n=a[9660896]|0;m=c[cs+72+(((s+1|0)>>>8&255|256)<<2)>>2]|0;if((m|0)!=0){a[m+((s+1|0)&255)|0]=n;c[f+25632>>2]=2;c[f+25636>>2]=56;break OL}m=c[cs+3148>>2]|0;if((m|0)==0){c[f+25632>>2]=2;c[f+25636>>2]=56;break OL}gg[m&4095]((s+1|0)&65535,n);break};case 222:{n=c[2415221]|0;m=c[2437644]|0;k=c[m+72+((n>>>8&255|512)<<2)>>2]|0;do{if((k|0)==0){Y=c[m+3156>>2]|0;if((Y|0)==0){ct=0;cu=n&65535;cv=m;break}l=gj[Y&4095](n&65535)|0;ct=l;cu=b[4830442]|0;cv=c[2437644]|0}else{ct=a[k+(n&255)|0]|0;cu=n&65535;cv=m}}while(0);m=ct&255;c[2426868]=m;b[4830442]=cu+1&65535;n=ct&255;k=c[cv+72>>2]|0;do{if((k|0)==0){s=c[cv+3144>>2]|0;if((s|0)==0){cw=0;cx=cv;break}l=gj[s&4095](n)|0;cw=l;cx=c[2437644]|0}else{cw=a[k+m|0]|0;cx=cv}}while(0);k=cw&255;n=c[cx+72+(((m+1|0)>>>8&255)<<2)>>2]|0;do{if((n|0)==0){l=c[cx+3144>>2]|0;if((l|0)==0){cy=0;break}cy=gj[l&4095]((m+1|0)&65535)|0}else{cy=a[n+((m+1|0)&255)|0]|0}}while(0);m=cy&255|k<<8;c[2415223]=m;n=a[9660900]&-15;a[9660900]=n;if((m|0)==0){cz=(n&255|k>>>4&8|4)&255}else{cz=(n&255|k>>>4&8)&255}a[9660900]=cz;break};case 223:{n=b[4830446]|0;m=(n&65535)>>>12&8|a[9660900]&-15&255;a[9660900]=(n<<16>>16==0?m|4:m)&255;m=c[2415221]|0;n=c[2437644]|0;l=c[n+72+((m>>>8&255|512)<<2)>>2]|0;do{if((l|0)==0){s=c[n+3156>>2]|0;if((s|0)==0){cA=0;cB=m&65535;cC=n;break}Y=gj[s&4095](m&65535)|0;cA=Y;cB=b[4830442]|0;cC=c[2437644]|0}else{cA=a[l+(m&255)|0]|0;cB=m&65535;cC=n}}while(0);n=cA&255;c[2426868]=n;b[4830442]=cB+1&65535;m=cA&255;l=a[9660893]|0;k=c[cC+1096>>2]|0;do{if((k|0)==0){Y=c[cC+3148>>2]|0;if((Y|0)==0){cD=cC;break}gg[Y&4095](m,l);cD=c[2437644]|0}else{a[k+n|0]=l;cD=cC}}while(0);l=a[9660892]|0;k=c[cD+72+(((n+1|0)>>>8&255|256)<<2)>>2]|0;if((k|0)!=0){a[k+((n+1|0)&255)|0]=l;c[f+25632>>2]=2;c[f+25636>>2]=56;break OL}k=c[cD+3148>>2]|0;if((k|0)==0){c[f+25632>>2]=2;c[f+25636>>2]=56;break OL}gg[k&4095]((n+1|0)&65535,l);break};case 224:{l=b[4830446]|0;k=c[2415221]|0;m=c[2437644]|0;Y=c[m+72+((k>>>8&255|512)<<2)>>2]|0;do{if((Y|0)==0){s=c[m+3156>>2]|0;if((s|0)==0){cE=0;cF=k&65535;cG=m;break}cH=gj[s&4095](k&65535)|0;cE=cH;cF=b[4830442]|0;cG=c[2437644]|0}else{cE=a[Y+(k&255)|0]|0;cF=k&65535;cG=m}}while(0);b[4853736]=(cE&255)+l&65535;b[4830442]=cF+1&65535;m=c[2426868]|0;k=c[cG+72+((m>>>8&255)<<2)>>2]|0;do{if((k|0)==0){Y=c[cG+3144>>2]|0;if((Y|0)==0){cI=0;break}cI=gj[Y&4095](m&65535)|0}else{cI=a[k+(m&255)|0]|0}}while(0);m=a[9660896]|0;k=(m&255)-(cI&255)|0;l=(k>>>4&8|a[9660900]&-16&255)&255;a[9660900]=(((m^cI)&255^k^k>>>1)>>>6&2|k>>>8&1|((k&255)<<24>>24==0?l|4:l)&255)&255;a[9660896]=k&255;break};case 225:{k=b[4830446]|0;l=c[2415221]|0;m=c[2437644]|0;Y=c[m+72+((l>>>8&255|512)<<2)>>2]|0;do{if((Y|0)==0){n=c[m+3156>>2]|0;if((n|0)==0){cJ=0;cK=l&65535;cL=m;break}cH=gj[n&4095](l&65535)|0;cJ=cH;cK=b[4830442]|0;cL=c[2437644]|0}else{cJ=a[Y+(l&255)|0]|0;cK=l&65535;cL=m}}while(0);b[4853736]=(cJ&255)+k&65535;b[4830442]=cK+1&65535;m=c[2426868]|0;l=c[cL+72+((m>>>8&255)<<2)>>2]|0;do{if((l|0)==0){Y=c[cL+3144>>2]|0;if((Y|0)==0){cM=0;break}cM=gj[Y&4095](m&65535)|0}else{cM=a[l+(m&255)|0]|0}}while(0);m=a[9660896]|0;l=(m&255)-(cM&255)|0;k=(l>>>4&8|a[9660900]&-16&255)&255;a[9660900]=(((m^cM)&255^l^l>>>1)>>>6&2|l>>>8&1|((l&255)<<24>>24==0?k|4:k)&255)&255;break};case 226:{k=b[4830446]|0;l=c[2415221]|0;m=c[2437644]|0;Y=c[m+72+((l>>>8&255|512)<<2)>>2]|0;do{if((Y|0)==0){cH=c[m+3156>>2]|0;if((cH|0)==0){cN=0;cO=l&65535;cP=m;break}n=gj[cH&4095](l&65535)|0;cN=n;cO=b[4830442]|0;cP=c[2437644]|0}else{cN=a[Y+(l&255)|0]|0;cO=l&65535;cP=m}}while(0);b[4853736]=(cN&255)+k&65535;b[4830442]=cO+1&65535;m=c[2426868]|0;l=c[cP+72+((m>>>8&255)<<2)>>2]|0;do{if((l|0)==0){Y=c[cP+3144>>2]|0;if((Y|0)==0){cQ=0;break}cQ=gj[Y&4095](m&65535)|0}else{cQ=a[l+(m&255)|0]|0}}while(0);m=a[9660896]|0;l=a[9660900]|0;k=(m&255)-(cQ&255)-(l&1)|0;a[9660900]=((k^(m^cQ)&255^k>>>1)>>>6&2|k>>>8&1|((k&255)<<24>>24==0?(k>>>4&8|l&-16&255)&255|4:(k>>>4&8|l&-16&255)&255)&255)&255;a[9660896]=k&255;break};case 227:{k=b[4830446]|0;l=c[2415221]|0;m=c[2437644]|0;Y=c[m+72+((l>>>8&255|512)<<2)>>2]|0;do{if((Y|0)==0){n=c[m+3156>>2]|0;if((n|0)==0){cR=0;cS=l&65535;cT=m;break}cH=gj[n&4095](l&65535)|0;cR=cH;cS=b[4830442]|0;cT=c[2437644]|0}else{cR=a[Y+(l&255)|0]|0;cS=l&65535;cT=m}}while(0);b[4853736]=(cR&255)+k&65535;b[4830442]=cS+1&65535;m=c[2426868]|0;l=c[cT+72+((m>>>8&255)<<2)>>2]|0;do{if((l|0)==0){Y=c[cT+3144>>2]|0;if((Y|0)==0){cU=0;cV=cT;break}cH=gj[Y&4095](m&65535)|0;cU=cH;cV=c[2437644]|0}else{cU=a[l+(m&255)|0]|0;cV=cT}}while(0);l=(cU&255)<<8;k=c[cV+72+(((m+1|0)>>>8&255)<<2)>>2]|0;do{if((k|0)==0){cH=c[cV+3144>>2]|0;if((cH|0)==0){cW=0;break}cW=gj[cH&4095]((m+1|0)&65535)|0}else{cW=a[k+((m+1|0)&255)|0]|0}}while(0);m=e[4830448]|0;k=m+(cW&255|l)|0;cH=(k>>>12&8|a[9660900]&-16&255)&255;a[9660900]=((m^l^k^k>>>1)>>>14&2|k>>>16&1|((k&65535)<<16>>16==0?cH|4:cH)&255)&255;b[4830448]=k&65535;break};case 228:{k=b[4830446]|0;cH=c[2415221]|0;m=c[2437644]|0;Y=c[m+72+((cH>>>8&255|512)<<2)>>2]|0;do{if((Y|0)==0){n=c[m+3156>>2]|0;if((n|0)==0){cX=0;cY=cH&65535;cZ=m;break}s=gj[n&4095](cH&65535)|0;cX=s;cY=b[4830442]|0;cZ=c[2437644]|0}else{cX=a[Y+(cH&255)|0]|0;cY=cH&65535;cZ=m}}while(0);b[4853736]=(cX&255)+k&65535;b[4830442]=cY+1&65535;m=c[2426868]|0;cH=c[cZ+72+((m>>>8&255)<<2)>>2]|0;do{if((cH|0)==0){Y=c[cZ+3144>>2]|0;if((Y|0)==0){c_=0;break}c_=gj[Y&4095](m&65535)|0}else{c_=a[cH+(m&255)|0]|0}}while(0);m=a[9660896]&c_;a[9660896]=m;cH=(m&255)>>>4&8|a[9660900]&-15;a[9660900]=m<<24>>24==0?cH|4:cH;break};case 229:{cH=b[4830446]|0;m=c[2415221]|0;k=c[2437644]|0;Y=c[k+72+((m>>>8&255|512)<<2)>>2]|0;do{if((Y|0)==0){l=c[k+3156>>2]|0;if((l|0)==0){c$=0;c0=m&65535;c1=k;break}s=gj[l&4095](m&65535)|0;c$=s;c0=b[4830442]|0;c1=c[2437644]|0}else{c$=a[Y+(m&255)|0]|0;c0=m&65535;c1=k}}while(0);b[4853736]=(c$&255)+cH&65535;b[4830442]=c0+1&65535;k=c[2426868]|0;m=c[c1+72+((k>>>8&255)<<2)>>2]|0;do{if((m|0)==0){Y=c[c1+3144>>2]|0;if((Y|0)==0){c2=0;break}c2=gj[Y&4095](k&65535)|0}else{c2=a[m+(k&255)|0]|0}}while(0);k=a[9660896]&c2;m=(k&255)>>>4&8|a[9660900]&-15;a[9660900]=k<<24>>24==0?m|4:m;break};case 230:{m=b[4830446]|0;k=c[2415221]|0;cH=c[2437644]|0;Y=c[cH+72+((k>>>8&255|512)<<2)>>2]|0;do{if((Y|0)==0){s=c[cH+3156>>2]|0;if((s|0)==0){c3=0;c4=k&65535;c5=cH;break}l=gj[s&4095](k&65535)|0;c3=l;c4=b[4830442]|0;c5=c[2437644]|0}else{c3=a[Y+(k&255)|0]|0;c4=k&65535;c5=cH}}while(0);b[4853736]=(c3&255)+m&65535;b[4830442]=c4+1&65535;cH=c[2426868]|0;k=c[c5+72+((cH>>>8&255)<<2)>>2]|0;do{if((k|0)==0){Y=c[c5+3144>>2]|0;if((Y|0)==0){c6=0;break}c6=gj[Y&4095](cH&65535)|0}else{c6=a[k+(cH&255)|0]|0}}while(0);a[9660896]=c6;cH=(c6&255)>>>4&8|a[9660900]&-15;a[9660900]=c6<<24>>24==0?cH|4:cH;break};case 231:{cH=a[9660896]|0;k=(cH&255)>>>4&8|a[9660900]&-15;a[9660900]=cH<<24>>24==0?k|4:k;k=b[4830446]|0;m=c[2415221]|0;Y=c[2437644]|0;l=c[Y+72+((m>>>8&255|512)<<2)>>2]|0;do{if((l|0)==0){s=c[Y+3156>>2]|0;if((s|0)==0){c7=0;c8=m&65535;c9=cH;da=Y;break}n=gj[s&4095](m&65535)|0;c7=n;c8=b[4830442]|0;c9=a[9660896]|0;da=c[2437644]|0}else{c7=a[l+(m&255)|0]|0;c8=m&65535;c9=cH;da=Y}}while(0);b[4853736]=(c7&255)+k&65535;b[4830442]=c8+1&65535;Y=c[2426868]|0;cH=c[da+72+((Y>>>8&255|256)<<2)>>2]|0;if((cH|0)!=0){a[cH+(Y&255)|0]=c9;c[f+25632>>2]=2;c[f+25636>>2]=56;break OL}cH=c[da+3148>>2]|0;if((cH|0)==0){c[f+25632>>2]=2;c[f+25636>>2]=56;break OL}gg[cH&4095](Y&65535,c9);break};case 232:{Y=b[4830446]|0;cH=c[2415221]|0;m=c[2437644]|0;l=c[m+72+((cH>>>8&255|512)<<2)>>2]|0;do{if((l|0)==0){n=c[m+3156>>2]|0;if((n|0)==0){db=0;dc=cH&65535;dd=m;break}s=gj[n&4095](cH&65535)|0;db=s;dc=b[4830442]|0;dd=c[2437644]|0}else{db=a[l+(cH&255)|0]|0;dc=cH&65535;dd=m}}while(0);b[4853736]=(db&255)+Y&65535;b[4830442]=dc+1&65535;m=c[2426868]|0;cH=c[dd+72+((m>>>8&255)<<2)>>2]|0;do{if((cH|0)==0){l=c[dd+3144>>2]|0;if((l|0)==0){de=0;break}de=gj[l&4095](m&65535)|0}else{de=a[cH+(m&255)|0]|0}}while(0);m=a[9660896]|0;cH=m^de;a[9660896]=cH;Y=(cH&255)>>>4&8|a[9660900]&-15;a[9660900]=m<<24>>24==de<<24>>24?Y|4:Y;break};case 233:{Y=b[4830446]|0;m=c[2415221]|0;cH=c[2437644]|0;l=c[cH+72+((m>>>8&255|512)<<2)>>2]|0;do{if((l|0)==0){k=c[cH+3156>>2]|0;if((k|0)==0){df=0;dg=m&65535;dh=cH;break}s=gj[k&4095](m&65535)|0;df=s;dg=b[4830442]|0;dh=c[2437644]|0}else{df=a[l+(m&255)|0]|0;dg=m&65535;dh=cH}}while(0);b[4853736]=(df&255)+Y&65535;b[4830442]=dg+1&65535;cH=c[2426868]|0;m=c[dh+72+((cH>>>8&255)<<2)>>2]|0;do{if((m|0)==0){l=c[dh+3144>>2]|0;if((l|0)==0){di=0;break}di=gj[l&4095](cH&65535)|0}else{di=a[m+(cH&255)|0]|0}}while(0);cH=a[9660896]|0;m=a[9660900]|0;Y=(cH&255)+(di&255)+(m&1)|0;l=Y^(cH^di)&255;a[9660900]=(l<<1&32|Y>>>8&1|(l^Y>>>1)>>>6&2|((Y&255)<<24>>24==0?(Y>>>4&8|m&-48&255)&255|4:(Y>>>4&8|m&-48&255)&255)&255)&255;a[9660896]=Y&255;break};case 234:{Y=b[4830446]|0;m=c[2415221]|0;l=c[2437644]|0;cH=c[l+72+((m>>>8&255|512)<<2)>>2]|0;do{if((cH|0)==0){s=c[l+3156>>2]|0;if((s|0)==0){dj=0;dk=m&65535;dl=l;break}k=gj[s&4095](m&65535)|0;dj=k;dk=b[4830442]|0;dl=c[2437644]|0}else{dj=a[cH+(m&255)|0]|0;dk=m&65535;dl=l}}while(0);b[4853736]=(dj&255)+Y&65535;b[4830442]=dk+1&65535;l=c[2426868]|0;m=c[dl+72+((l>>>8&255)<<2)>>2]|0;do{if((m|0)==0){cH=c[dl+3144>>2]|0;if((cH|0)==0){dm=0;break}dm=gj[cH&4095](l&65535)|0}else{dm=a[m+(l&255)|0]|0}}while(0);l=a[9660896]|dm;a[9660896]=l;m=(l&255)>>>4&8|a[9660900]&-15;a[9660900]=l<<24>>24==0?m|4:m;break};case 235:{m=b[4830446]|0;l=c[2415221]|0;Y=c[2437644]|0;cH=c[Y+72+((l>>>8&255|512)<<2)>>2]|0;do{if((cH|0)==0){k=c[Y+3156>>2]|0;if((k|0)==0){dn=0;dp=l&65535;dq=Y;break}s=gj[k&4095](l&65535)|0;dn=s;dp=b[4830442]|0;dq=c[2437644]|0}else{dn=a[cH+(l&255)|0]|0;dp=l&65535;dq=Y}}while(0);b[4853736]=(dn&255)+m&65535;b[4830442]=dp+1&65535;Y=c[2426868]|0;l=c[dq+72+((Y>>>8&255)<<2)>>2]|0;do{if((l|0)==0){cH=c[dq+3144>>2]|0;if((cH|0)==0){dr=0;break}dr=gj[cH&4095](Y&65535)|0}else{dr=a[l+(Y&255)|0]|0}}while(0);Y=a[9660896]|0;l=(Y&255)+(dr&255)|0;m=(l>>>4&8|a[9660900]&-48&255)&255;cH=(Y^dr)&255^l;a[9660900]=(cH<<1&32|l>>>8&1|(cH^l>>>1)>>>6&2|((l&255)<<24>>24==0?m|4:m)&255)&255;a[9660896]=l&255;break};case 236:{l=b[4830446]|0;m=c[2415221]|0;cH=c[2437644]|0;Y=c[cH+72+((m>>>8&255|512)<<2)>>2]|0;do{if((Y|0)==0){s=c[cH+3156>>2]|0;if((s|0)==0){ds=0;dt=m&65535;du=cH;break}k=gj[s&4095](m&65535)|0;ds=k;dt=b[4830442]|0;du=c[2437644]|0}else{ds=a[Y+(m&255)|0]|0;dt=m&65535;du=cH}}while(0);b[4853736]=(ds&255)+l&65535;b[4830442]=dt+1&65535;cH=c[2426868]|0;m=c[du+72+((cH>>>8&255)<<2)>>2]|0;do{if((m|0)==0){Y=c[du+3144>>2]|0;if((Y|0)==0){dv=0;dw=du;break}k=gj[Y&4095](cH&65535)|0;dv=k;dw=c[2437644]|0}else{dv=a[m+(cH&255)|0]|0;dw=du}}while(0);m=dv&255;l=c[dw+72+(((cH+1|0)>>>8&255)<<2)>>2]|0;do{if((l|0)==0){k=c[dw+3144>>2]|0;if((k|0)==0){dx=0;break}dx=gj[k&4095]((cH+1|0)&65535)|0}else{dx=a[l+((cH+1|0)&255)|0]|0}}while(0);cH=dx&255|m<<8;c[2415224]=cH;l=a[9660900]&-15;a[9660900]=l;if((cH|0)==0){dy=(l&255|m>>>4&8|4)&255}else{dy=(l&255|m>>>4&8)&255}a[9660900]=dy;break};case 237:{l=b[4830446]|0;cH=c[2415221]|0;k=c[2437644]|0;Y=c[k+72+((cH>>>8&255|512)<<2)>>2]|0;do{if((Y|0)==0){s=c[k+3156>>2]|0;if((s|0)==0){dz=0;dA=cH&65535;dB=k;break}n=gj[s&4095](cH&65535)|0;dz=n;dA=b[4830442]|0;dB=c[2437644]|0}else{dz=a[Y+(cH&255)|0]|0;dA=cH&65535;dB=k}}while(0);b[4853736]=(dz&255)+l&65535;b[4830442]=dA+1&65535;k=b[4830448]|0;cH=(k&65535)>>>12&8|a[9660900]&-15&255;a[9660900]=(k<<16>>16==0?cH|4:cH)&255;cH=c[2426868]|0;k=a[9660897]|0;Y=c[dB+72+((cH>>>8&255|256)<<2)>>2]|0;do{if((Y|0)==0){m=c[dB+3148>>2]|0;if((m|0)==0){dC=dB;break}gg[m&4095](cH&65535,k);dC=c[2437644]|0}else{a[Y+(cH&255)|0]=k;dC=dB}}while(0);k=a[9660896]|0;Y=c[dC+72+(((cH+1|0)>>>8&255|256)<<2)>>2]|0;if((Y|0)!=0){a[Y+((cH+1|0)&255)|0]=k;c[f+25632>>2]=2;c[f+25636>>2]=56;break OL}Y=c[dC+3148>>2]|0;if((Y|0)==0){c[f+25632>>2]=2;c[f+25636>>2]=56;break OL}gg[Y&4095]((cH+1|0)&65535,k);break};default:{i=1}}}if(i){i=0;switch(j|0){case 238:{k=b[4830446]|0;Y=c[2415221]|0;l=c[2437644]|0;m=c[l+72+((Y>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){n=c[l+3156>>2]|0;if((n|0)==0){dD=0;dE=Y&65535;dF=l;break}s=gj[n&4095](Y&65535)|0;dD=s;dE=b[4830442]|0;dF=c[2437644]|0}else{dD=a[m+(Y&255)|0]|0;dE=Y&65535;dF=l}}while(0);b[4853736]=(dD&255)+k&65535;b[4830442]=dE+1&65535;l=c[2426868]|0;Y=c[dF+72+((l>>>8&255)<<2)>>2]|0;do{if((Y|0)==0){m=c[dF+3144>>2]|0;if((m|0)==0){dG=0;dH=dF;break}cH=gj[m&4095](l&65535)|0;dG=cH;dH=c[2437644]|0}else{dG=a[Y+(l&255)|0]|0;dH=dF}}while(0);Y=dG&255;k=c[dH+72+(((l+1|0)>>>8&255)<<2)>>2]|0;do{if((k|0)==0){cH=c[dH+3144>>2]|0;if((cH|0)==0){dI=0;break}dI=gj[cH&4095]((l+1|0)&65535)|0}else{dI=a[k+((l+1|0)&255)|0]|0}}while(0);l=dI&255|Y<<8;c[2415223]=l;k=a[9660900]&-15;a[9660900]=k;if((l|0)==0){dJ=(k&255|Y>>>4&8|4)&255}else{dJ=(k&255|Y>>>4&8)&255}a[9660900]=dJ;break};case 239:{k=b[4830446]|0;l=(k&65535)>>>12&8|a[9660900]&-15&255;a[9660900]=(k<<16>>16==0?l|4:l)&255;l=c[2415221]|0;cH=c[2437644]|0;m=c[cH+72+((l>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){s=c[cH+3156>>2]|0;if((s|0)==0){dK=0;dL=l&65535;dM=cH;break}n=gj[s&4095](l&65535)|0;dK=n;dL=b[4830442]|0;dM=c[2437644]|0}else{dK=a[m+(l&255)|0]|0;dL=l&65535;dM=cH}}while(0);b[4853736]=(dK&255)+k&65535;b[4830442]=dL+1&65535;cH=c[2426868]|0;l=a[9660893]|0;m=c[dM+72+((cH>>>8&255|256)<<2)>>2]|0;do{if((m|0)==0){Y=c[dM+3148>>2]|0;if((Y|0)==0){dN=dM;break}gg[Y&4095](cH&65535,l);dN=c[2437644]|0}else{a[m+(cH&255)|0]=l;dN=dM}}while(0);l=a[9660892]|0;m=c[dN+72+(((cH+1|0)>>>8&255|256)<<2)>>2]|0;if((m|0)!=0){a[m+((cH+1|0)&255)|0]=l;c[f+25632>>2]=2;c[f+25636>>2]=56;break OL}m=c[dN+3148>>2]|0;if((m|0)==0){c[f+25632>>2]=2;c[f+25636>>2]=56;break OL}gg[m&4095]((cH+1|0)&65535,l);break};case 240:{l=c[2415221]|0;m=c[2437644]|0;k=c[m+72+((l>>>8&255|512)<<2)>>2]|0;do{if((k|0)==0){Y=c[m+3156>>2]|0;if((Y|0)==0){dO=0;dP=l;dQ=m;dR=l&65535;break}n=gj[Y&4095](l&65535)|0;Y=c[2415221]|0;dO=n;dP=Y;dQ=c[2437644]|0;dR=Y&65535}else{dO=a[k+(l&255)|0]|0;dP=l;dQ=m;dR=l&65535}}while(0);l=dO&255;m=dP+1|0;k=c[dQ+72+((m>>>8&255|512)<<2)>>2]|0;do{if((k|0)==0){cH=c[dQ+3156>>2]|0;if((cH|0)==0){dS=0;dT=dR;dU=dQ;break}Y=gj[cH&4095](m&65535)|0;dS=Y;dT=b[4830442]|0;dU=c[2437644]|0}else{dS=a[k+(m&255)|0]|0;dT=dR;dU=dQ}}while(0);m=dS&255;c[2426868]=m|l<<8;b[4830442]=dT+2&65535;k=c[dU+72+(l<<2)>>2]|0;do{if((k|0)==0){Y=c[dU+3144>>2]|0;if((Y|0)==0){dV=0;break}dV=gj[Y&4095]((m|l<<8)&65535)|0}else{dV=a[k+m|0]|0}}while(0);m=a[9660896]|0;k=(m&255)-(dV&255)|0;l=(k>>>4&8|a[9660900]&-16&255)&255;a[9660900]=(((m^dV)&255^k^k>>>1)>>>6&2|k>>>8&1|((k&255)<<24>>24==0?l|4:l)&255)&255;a[9660896]=k&255;break};case 241:{k=c[2415221]|0;l=c[2437644]|0;m=c[l+72+((k>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){Y=c[l+3156>>2]|0;if((Y|0)==0){dW=0;dX=k;dY=l;dZ=k&65535;break}cH=gj[Y&4095](k&65535)|0;Y=c[2415221]|0;dW=cH;dX=Y;dY=c[2437644]|0;dZ=Y&65535}else{dW=a[m+(k&255)|0]|0;dX=k;dY=l;dZ=k&65535}}while(0);k=dW&255;l=dX+1|0;m=c[dY+72+((l>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){Y=c[dY+3156>>2]|0;if((Y|0)==0){d_=0;d$=dZ;d0=dY;break}cH=gj[Y&4095](l&65535)|0;d_=cH;d$=b[4830442]|0;d0=c[2437644]|0}else{d_=a[m+(l&255)|0]|0;d$=dZ;d0=dY}}while(0);l=d_&255;c[2426868]=l|k<<8;b[4830442]=d$+2&65535;m=c[d0+72+(k<<2)>>2]|0;do{if((m|0)==0){cH=c[d0+3144>>2]|0;if((cH|0)==0){d1=0;break}d1=gj[cH&4095]((l|k<<8)&65535)|0}else{d1=a[m+l|0]|0}}while(0);l=a[9660896]|0;m=(l&255)-(d1&255)|0;k=(m>>>4&8|a[9660900]&-16&255)&255;a[9660900]=(((l^d1)&255^m^m>>>1)>>>6&2|m>>>8&1|((m&255)<<24>>24==0?k|4:k)&255)&255;break};case 242:{k=c[2415221]|0;m=c[2437644]|0;l=c[m+72+((k>>>8&255|512)<<2)>>2]|0;do{if((l|0)==0){cH=c[m+3156>>2]|0;if((cH|0)==0){d2=0;d3=k;d4=m;d5=k&65535;break}Y=gj[cH&4095](k&65535)|0;cH=c[2415221]|0;d2=Y;d3=cH;d4=c[2437644]|0;d5=cH&65535}else{d2=a[l+(k&255)|0]|0;d3=k;d4=m;d5=k&65535}}while(0);k=d2&255;m=d3+1|0;l=c[d4+72+((m>>>8&255|512)<<2)>>2]|0;do{if((l|0)==0){cH=c[d4+3156>>2]|0;if((cH|0)==0){d6=0;d7=d5;d8=d4;break}Y=gj[cH&4095](m&65535)|0;d6=Y;d7=b[4830442]|0;d8=c[2437644]|0}else{d6=a[l+(m&255)|0]|0;d7=d5;d8=d4}}while(0);m=d6&255;c[2426868]=m|k<<8;b[4830442]=d7+2&65535;l=c[d8+72+(k<<2)>>2]|0;do{if((l|0)==0){Y=c[d8+3144>>2]|0;if((Y|0)==0){d9=0;break}d9=gj[Y&4095]((m|k<<8)&65535)|0}else{d9=a[l+m|0]|0}}while(0);m=a[9660896]|0;l=a[9660900]|0;k=(m&255)-(d9&255)-(l&1)|0;a[9660900]=((k^(m^d9)&255^k>>>1)>>>6&2|k>>>8&1|((k&255)<<24>>24==0?(k>>>4&8|l&-16&255)&255|4:(k>>>4&8|l&-16&255)&255)&255)&255;a[9660896]=k&255;break};case 243:{k=c[2415221]|0;l=c[2437644]|0;m=c[l+72+((k>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){Y=c[l+3156>>2]|0;if((Y|0)==0){ea=0;eb=k;ec=l;ed=k&65535;break}cH=gj[Y&4095](k&65535)|0;Y=c[2415221]|0;ea=cH;eb=Y;ec=c[2437644]|0;ed=Y&65535}else{ea=a[m+(k&255)|0]|0;eb=k;ec=l;ed=k&65535}}while(0);k=ea&255;l=eb+1|0;m=c[ec+72+((l>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){Y=c[ec+3156>>2]|0;if((Y|0)==0){ee=0;ef=ed;eg=ec;break}cH=gj[Y&4095](l&65535)|0;ee=cH;ef=b[4830442]|0;eg=c[2437644]|0}else{ee=a[m+(l&255)|0]|0;ef=ed;eg=ec}}while(0);l=ee&255;c[2426868]=l|k<<8;b[4830442]=ef+2&65535;m=c[eg+72+(k<<2)>>2]|0;do{if((m|0)==0){cH=c[eg+3144>>2]|0;if((cH|0)==0){eh=0;ei=eg;break}Y=gj[cH&4095]((l|k<<8)&65535)|0;eh=Y;ei=c[2437644]|0}else{eh=a[m+l|0]|0;ei=eg}}while(0);m=(eh&255)<<8;Y=c[ei+72+((((l|k<<8)+1|0)>>>8&255)<<2)>>2]|0;do{if((Y|0)==0){cH=c[ei+3144>>2]|0;if((cH|0)==0){ej=0;break}ej=gj[cH&4095](((l|k<<8)+1|0)&65535)|0}else{ej=a[Y+(((l|k<<8)+1|0)&255)|0]|0}}while(0);k=e[4830448]|0;l=k+(ej&255|m)|0;Y=(l>>>12&8|a[9660900]&-16&255)&255;a[9660900]=((k^m^l^l>>>1)>>>14&2|l>>>16&1|((l&65535)<<16>>16==0?Y|4:Y)&255)&255;b[4830448]=l&65535;break};case 244:{l=c[2415221]|0;Y=c[2437644]|0;k=c[Y+72+((l>>>8&255|512)<<2)>>2]|0;do{if((k|0)==0){cH=c[Y+3156>>2]|0;if((cH|0)==0){ek=0;el=l;em=Y;en=l&65535;break}n=gj[cH&4095](l&65535)|0;cH=c[2415221]|0;ek=n;el=cH;em=c[2437644]|0;en=cH&65535}else{ek=a[k+(l&255)|0]|0;el=l;em=Y;en=l&65535}}while(0);l=ek&255;Y=el+1|0;k=c[em+72+((Y>>>8&255|512)<<2)>>2]|0;do{if((k|0)==0){m=c[em+3156>>2]|0;if((m|0)==0){eo=0;ep=en;eq=em;break}cH=gj[m&4095](Y&65535)|0;eo=cH;ep=b[4830442]|0;eq=c[2437644]|0}else{eo=a[k+(Y&255)|0]|0;ep=en;eq=em}}while(0);Y=eo&255;c[2426868]=Y|l<<8;b[4830442]=ep+2&65535;k=c[eq+72+(l<<2)>>2]|0;do{if((k|0)==0){cH=c[eq+3144>>2]|0;if((cH|0)==0){er=0;break}er=gj[cH&4095]((Y|l<<8)&65535)|0}else{er=a[k+Y|0]|0}}while(0);Y=a[9660896]&er;a[9660896]=Y;k=(Y&255)>>>4&8|a[9660900]&-15;a[9660900]=Y<<24>>24==0?k|4:k;break};case 245:{k=c[2415221]|0;Y=c[2437644]|0;l=c[Y+72+((k>>>8&255|512)<<2)>>2]|0;do{if((l|0)==0){cH=c[Y+3156>>2]|0;if((cH|0)==0){es=0;et=k;eu=Y;ev=k&65535;break}m=gj[cH&4095](k&65535)|0;cH=c[2415221]|0;es=m;et=cH;eu=c[2437644]|0;ev=cH&65535}else{es=a[l+(k&255)|0]|0;et=k;eu=Y;ev=k&65535}}while(0);k=es&255;Y=et+1|0;l=c[eu+72+((Y>>>8&255|512)<<2)>>2]|0;do{if((l|0)==0){cH=c[eu+3156>>2]|0;if((cH|0)==0){ew=0;ex=ev;ey=eu;break}m=gj[cH&4095](Y&65535)|0;ew=m;ex=b[4830442]|0;ey=c[2437644]|0}else{ew=a[l+(Y&255)|0]|0;ex=ev;ey=eu}}while(0);Y=ew&255;c[2426868]=Y|k<<8;b[4830442]=ex+2&65535;l=c[ey+72+(k<<2)>>2]|0;do{if((l|0)==0){m=c[ey+3144>>2]|0;if((m|0)==0){ez=0;break}ez=gj[m&4095]((Y|k<<8)&65535)|0}else{ez=a[l+Y|0]|0}}while(0);Y=a[9660896]&ez;l=(Y&255)>>>4&8|a[9660900]&-15;a[9660900]=Y<<24>>24==0?l|4:l;break};case 246:{l=c[2415221]|0;Y=c[2437644]|0;k=c[Y+72+((l>>>8&255|512)<<2)>>2]|0;do{if((k|0)==0){m=c[Y+3156>>2]|0;if((m|0)==0){eA=0;eB=l;eC=Y;eD=l&65535;break}cH=gj[m&4095](l&65535)|0;m=c[2415221]|0;eA=cH;eB=m;eC=c[2437644]|0;eD=m&65535}else{eA=a[k+(l&255)|0]|0;eB=l;eC=Y;eD=l&65535}}while(0);l=eA&255;Y=eB+1|0;k=c[eC+72+((Y>>>8&255|512)<<2)>>2]|0;do{if((k|0)==0){m=c[eC+3156>>2]|0;if((m|0)==0){eE=0;eF=eD;eG=eC;break}cH=gj[m&4095](Y&65535)|0;eE=cH;eF=b[4830442]|0;eG=c[2437644]|0}else{eE=a[k+(Y&255)|0]|0;eF=eD;eG=eC}}while(0);Y=eE&255;c[2426868]=Y|l<<8;b[4830442]=eF+2&65535;k=c[eG+72+(l<<2)>>2]|0;do{if((k|0)==0){cH=c[eG+3144>>2]|0;if((cH|0)==0){eH=0;break}eH=gj[cH&4095]((Y|l<<8)&65535)|0}else{eH=a[k+Y|0]|0}}while(0);a[9660896]=eH;Y=(eH&255)>>>4&8|a[9660900]&-15;a[9660900]=eH<<24>>24==0?Y|4:Y;break};case 247:{Y=a[9660896]|0;k=(Y&255)>>>4&8|a[9660900]&-15;a[9660900]=Y<<24>>24==0?k|4:k;k=c[2415221]|0;Y=c[2437644]|0;l=c[Y+72+((k>>>8&255|512)<<2)>>2]|0;do{if((l|0)==0){cH=c[Y+3156>>2]|0;if((cH|0)==0){eI=0;eJ=k;eK=Y;eL=k&65535;break}m=gj[cH&4095](k&65535)|0;cH=c[2415221]|0;eI=m;eJ=cH;eK=c[2437644]|0;eL=cH&65535}else{eI=a[l+(k&255)|0]|0;eJ=k;eK=Y;eL=k&65535}}while(0);k=eI&255;Y=eJ+1|0;l=c[eK+72+((Y>>>8&255|512)<<2)>>2]|0;do{if((l|0)==0){cH=c[eK+3156>>2]|0;if((cH|0)==0){eM=0;eN=eL;eO=eK;break}m=gj[cH&4095](Y&65535)|0;eM=m;eN=b[4830442]|0;eO=c[2437644]|0}else{eM=a[l+(Y&255)|0]|0;eN=eL;eO=eK}}while(0);Y=eM&255;c[2426868]=Y|k<<8;b[4830442]=eN+2&65535;l=a[9660896]|0;m=c[eO+72+((k|256)<<2)>>2]|0;if((m|0)!=0){a[m+Y|0]=l;c[f+25632>>2]=2;c[f+25636>>2]=56;break OL}m=c[eO+3148>>2]|0;if((m|0)==0){c[f+25632>>2]=2;c[f+25636>>2]=56;break OL}gg[m&4095]((Y|k<<8)&65535,l);break};case 248:{l=c[2415221]|0;Y=c[2437644]|0;m=c[Y+72+((l>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){cH=c[Y+3156>>2]|0;if((cH|0)==0){eP=0;eQ=l;eR=Y;eS=l&65535;break}n=gj[cH&4095](l&65535)|0;cH=c[2415221]|0;eP=n;eQ=cH;eR=c[2437644]|0;eS=cH&65535}else{eP=a[m+(l&255)|0]|0;eQ=l;eR=Y;eS=l&65535}}while(0);l=eP&255;Y=eQ+1|0;m=c[eR+72+((Y>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){k=c[eR+3156>>2]|0;if((k|0)==0){eT=0;eU=eS;eV=eR;break}cH=gj[k&4095](Y&65535)|0;eT=cH;eU=b[4830442]|0;eV=c[2437644]|0}else{eT=a[m+(Y&255)|0]|0;eU=eS;eV=eR}}while(0);Y=eT&255;c[2426868]=Y|l<<8;b[4830442]=eU+2&65535;m=c[eV+72+(l<<2)>>2]|0;do{if((m|0)==0){cH=c[eV+3144>>2]|0;if((cH|0)==0){eW=0;break}eW=gj[cH&4095]((Y|l<<8)&65535)|0}else{eW=a[m+Y|0]|0}}while(0);Y=a[9660896]|0;m=Y^eW;a[9660896]=m;l=(m&255)>>>4&8|a[9660900]&-15;a[9660900]=Y<<24>>24==eW<<24>>24?l|4:l;break};case 249:{l=c[2415221]|0;Y=c[2437644]|0;m=c[Y+72+((l>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){cH=c[Y+3156>>2]|0;if((cH|0)==0){eX=0;eY=l;eZ=Y;e_=l&65535;break}k=gj[cH&4095](l&65535)|0;cH=c[2415221]|0;eX=k;eY=cH;eZ=c[2437644]|0;e_=cH&65535}else{eX=a[m+(l&255)|0]|0;eY=l;eZ=Y;e_=l&65535}}while(0);l=eX&255;Y=eY+1|0;m=c[eZ+72+((Y>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){cH=c[eZ+3156>>2]|0;if((cH|0)==0){e$=0;e0=e_;e1=eZ;break}k=gj[cH&4095](Y&65535)|0;e$=k;e0=b[4830442]|0;e1=c[2437644]|0}else{e$=a[m+(Y&255)|0]|0;e0=e_;e1=eZ}}while(0);Y=e$&255;c[2426868]=Y|l<<8;b[4830442]=e0+2&65535;m=c[e1+72+(l<<2)>>2]|0;do{if((m|0)==0){k=c[e1+3144>>2]|0;if((k|0)==0){e2=0;break}e2=gj[k&4095]((Y|l<<8)&65535)|0}else{e2=a[m+Y|0]|0}}while(0);Y=a[9660896]|0;m=a[9660900]|0;l=(Y&255)+(e2&255)+(m&1)|0;k=l^(Y^e2)&255;a[9660900]=(k<<1&32|l>>>8&1|(k^l>>>1)>>>6&2|((l&255)<<24>>24==0?(l>>>4&8|m&-48&255)&255|4:(l>>>4&8|m&-48&255)&255)&255)&255;a[9660896]=l&255;break};case 250:{l=c[2415221]|0;m=c[2437644]|0;k=c[m+72+((l>>>8&255|512)<<2)>>2]|0;do{if((k|0)==0){Y=c[m+3156>>2]|0;if((Y|0)==0){e3=0;e4=l;e5=m;e6=l&65535;break}cH=gj[Y&4095](l&65535)|0;Y=c[2415221]|0;e3=cH;e4=Y;e5=c[2437644]|0;e6=Y&65535}else{e3=a[k+(l&255)|0]|0;e4=l;e5=m;e6=l&65535}}while(0);l=e3&255;m=e4+1|0;k=c[e5+72+((m>>>8&255|512)<<2)>>2]|0;do{if((k|0)==0){Y=c[e5+3156>>2]|0;if((Y|0)==0){e7=0;e8=e6;e9=e5;break}cH=gj[Y&4095](m&65535)|0;e7=cH;e8=b[4830442]|0;e9=c[2437644]|0}else{e7=a[k+(m&255)|0]|0;e8=e6;e9=e5}}while(0);m=e7&255;c[2426868]=m|l<<8;b[4830442]=e8+2&65535;k=c[e9+72+(l<<2)>>2]|0;do{if((k|0)==0){cH=c[e9+3144>>2]|0;if((cH|0)==0){fa=0;break}fa=gj[cH&4095]((m|l<<8)&65535)|0}else{fa=a[k+m|0]|0}}while(0);m=a[9660896]|fa;a[9660896]=m;k=(m&255)>>>4&8|a[9660900]&-15;a[9660900]=m<<24>>24==0?k|4:k;break};case 251:{k=c[2415221]|0;m=c[2437644]|0;l=c[m+72+((k>>>8&255|512)<<2)>>2]|0;do{if((l|0)==0){cH=c[m+3156>>2]|0;if((cH|0)==0){fb=0;fc=k;fd=m;fe=k&65535;break}Y=gj[cH&4095](k&65535)|0;cH=c[2415221]|0;fb=Y;fc=cH;fd=c[2437644]|0;fe=cH&65535}else{fb=a[l+(k&255)|0]|0;fc=k;fd=m;fe=k&65535}}while(0);k=fb&255;m=fc+1|0;l=c[fd+72+((m>>>8&255|512)<<2)>>2]|0;do{if((l|0)==0){cH=c[fd+3156>>2]|0;if((cH|0)==0){ff=0;fg=fe;fh=fd;break}Y=gj[cH&4095](m&65535)|0;ff=Y;fg=b[4830442]|0;fh=c[2437644]|0}else{ff=a[l+(m&255)|0]|0;fg=fe;fh=fd}}while(0);m=ff&255;c[2426868]=m|k<<8;b[4830442]=fg+2&65535;l=c[fh+72+(k<<2)>>2]|0;do{if((l|0)==0){Y=c[fh+3144>>2]|0;if((Y|0)==0){fi=0;break}fi=gj[Y&4095]((m|k<<8)&65535)|0}else{fi=a[l+m|0]|0}}while(0);m=a[9660896]|0;l=(m&255)+(fi&255)|0;k=(l>>>4&8|a[9660900]&-48&255)&255;Y=(m^fi)&255^l;a[9660900]=(Y<<1&32|l>>>8&1|(Y^l>>>1)>>>6&2|((l&255)<<24>>24==0?k|4:k)&255)&255;a[9660896]=l&255;break};case 252:{f4B();break};case 253:{f4C();break};case 254:{f4a();break};case 255:{f4b();break};case 57:{b[4830444]=(b[4830444]|0)+1&65535;l=c[2415222]|0;k=c[2437644]|0;Y=c[k+72+((l>>>8&255)<<2)>>2]|0;do{if((Y|0)==0){m=c[k+3144>>2]|0;if((m|0)==0){fj=0;fk=l&65535;fl=k;break}cH=gj[m&4095](l&65535)|0;fj=cH;fk=b[4830444]|0;fl=c[2437644]|0}else{fj=a[Y+(l&255)|0]|0;fk=l&65535;fl=k}}while(0);k=(fj&255)<<8;c[2415221]=k;b[4830444]=fk+1&65535;l=c[2415222]|0;Y=c[fl+72+((l>>>8&255)<<2)>>2]|0;do{if((Y|0)==0){cH=c[fl+3144>>2]|0;if((cH|0)==0){fm=0;fn=k;break}m=gj[cH&4095](l&65535)|0;fm=m;fn=c[2415221]|0}else{fm=a[Y+(l&255)|0]|0;fn=k}}while(0);k=fn|fm&255;c[2415221]=k;b[4830442]=k&65535;break};case 58:{b[4830446]=(b[4830446]|0)+(d[9660896]|0)&65535;break};case 59:{f1H();break};case 60:{k=c[2415222]|0;l=a[9660892]|0;Y=c[2437644]|0;m=c[Y+72+((k>>>8&255|256)<<2)>>2]|0;do{if((m|0)==0){cH=c[Y+3148>>2]|0;if((cH|0)==0){fo=Y;break}gg[cH&4095](k&65535,l);fo=c[2437644]|0}else{a[m+(k&255)|0]=l;fo=Y}}while(0);b[4830444]=(b[4830444]|0)-1&65535;Y=c[2415222]|0;l=a[9660893]|0;k=c[fo+72+((Y>>>8&255|256)<<2)>>2]|0;do{if((k|0)==0){m=c[fo+3148>>2]|0;if((m|0)==0){break}gg[m&4095](Y&65535,l)}else{a[k+(Y&255)|0]=l}}while(0);b[4830444]=(b[4830444]|0)-1&65535;break};case 61:{l=ag(d[9660896]|0,d[9660897]|0)|0;Y=a[9660900]|0;a[9660900]=(l&128)==0?Y&-2:Y|1;b[4830448]=l;break};case 62:{f1I();break};case 63:{f1J();break};case 64:{l=a[9660897]|0;Y=-(l&255)&65535&65535;k=(Y>>>4&8|a[9660900]&-16&255)&255;a[9660900]=((Y^l&255^Y>>>1)>>>6&2|Y>>>8&1|((-(l&255)&65535&255)<<24>>24==0?k|4:k)&255)&255;a[9660897]=-(l&255)&65535&255;break};case 65:{f00(-18);break};case 66:{f00(-18);break};case 67:{l=a[9660897]|0;a[9660897]=~l;k=(~l&255)>>>4&8|a[9660900]&-15;a[9660900]=(l<<24>>24==-1?k|4:k)|1;break};case 68:{k=a[9660897]|0;l=k&1|a[9660900]&-14;a[9660900]=l;a[9660897]=(k&255)>>>1;if((k&255)>>>1<<24>>24!=0){c[f+25632>>2]=2;c[f+25636>>2]=56;break OL}a[9660900]=l|4;break};case 69:{f00(-18);break};case 70:{l=a[9660900]|0;k=a[9660897]|0;a[9660900]=((k&255)>>>1|l<<7)<<24>>24==0?k&1|l&-14|l<<3&8|4:k&1|l&-14|l<<3&8;a[9660897]=(k&255)>>>1|l<<7;break};case 71:{l=a[9660897]|0;k=l&1|a[9660900]&-14;a[9660897]=(l&255)>>>1<<1&-128|(l&255)>>>1;a[9660900]=((l&255)>>>1<<1&-128|(l&255)>>>1)<<24>>24==0?k|(l&255)>>>4&8|4:k|(l&255)>>>4&8;break};case 72:{l=(d[9660897]|0)<<1;k=((l&65535)>>>4&8|a[9660900]&-16&255)&255;a[9660900]=(((l&65535)>>>1^l&65535)>>>6&2|(l&65535)>>>8|((l&255)<<24>>24==0?k|4:k)&255)&255;a[9660897]=l&255;break};case 73:{l=a[9660900]|0;k=l&1|(d[9660897]|0)<<1;a[9660900]=(((k&65535)>>>1^k&65535)>>>6&2|(k&65535)>>>8|((k&255)<<24>>24==0?((k&65535)>>>4&8|l&-16&255)&255|4:((k&65535)>>>4&8|l&-16&255)&255)&255)&255;a[9660897]=k&255;break};case 74:{k=(a[9660897]|0)-1&255;a[9660897]=k;a[9660900]=a[669184+(k&255)|0]|a[9660900]&-15;break};case 75:{f00(-18);break};case 76:{k=(a[9660897]|0)+1&255;a[9660897]=k;a[9660900]=a[668928+(k&255)|0]|a[9660900]&-15;break};case 77:{k=a[9660897]|0;l=(k&255)>>>4&8|a[9660900]&-16;a[9660900]=k<<24>>24==0?l|4:l;break};case 78:{f00(-18);break};case 79:{a[9660897]=0;a[9660900]=a[9660900]&-16|4;break};case 80:{l=a[9660896]|0;k=-(l&255)&65535&65535;Y=(k>>>4&8|a[9660900]&-16&255)&255;a[9660900]=((k^l&255^k>>>1)>>>6&2|k>>>8&1|((-(l&255)&65535&255)<<24>>24==0?Y|4:Y)&255)&255;a[9660896]=-(l&255)&65535&255;break};case 81:{f00(-18);break};case 82:{f00(-18);break};case 83:{l=a[9660896]|0;a[9660896]=~l;Y=(~l&255)>>>4&8|a[9660900]&-15;a[9660900]=(l<<24>>24==-1?Y|4:Y)|1;break};case 84:{Y=a[9660896]|0;l=Y&1|a[9660900]&-14;a[9660900]=l;a[9660896]=(Y&255)>>>1;if((Y&255)>>>1<<24>>24!=0){c[f+25632>>2]=2;c[f+25636>>2]=56;break OL}a[9660900]=l|4;break};case 85:{f00(-18);break};case 86:{l=a[9660900]|0;Y=a[9660896]|0;a[9660900]=((Y&255)>>>1|l<<7)<<24>>24==0?Y&1|l&-14|l<<3&8|4:Y&1|l&-14|l<<3&8;a[9660896]=(Y&255)>>>1|l<<7;break};case 87:{l=a[9660896]|0;Y=l&1|a[9660900]&-14;a[9660896]=(l&255)>>>1<<1&-128|(l&255)>>>1;a[9660900]=((l&255)>>>1<<1&-128|(l&255)>>>1)<<24>>24==0?Y|(l&255)>>>4&8|4:Y|(l&255)>>>4&8;break};case 88:{l=(d[9660896]|0)<<1;Y=((l&65535)>>>4&8|a[9660900]&-16&255)&255;a[9660900]=(((l&65535)>>>1^l&65535)>>>6&2|(l&65535)>>>8|((l&255)<<24>>24==0?Y|4:Y)&255)&255;a[9660896]=l&255;break};case 89:{l=a[9660900]|0;Y=l&1|(d[9660896]|0)<<1;a[9660900]=(((Y&65535)>>>1^Y&65535)>>>6&2|(Y&65535)>>>8|((Y&255)<<24>>24==0?((Y&65535)>>>4&8|l&-16&255)&255|4:((Y&65535)>>>4&8|l&-16&255)&255)&255)&255;a[9660896]=Y&255;break};case 90:{Y=(a[9660896]|0)-1&255;a[9660896]=Y;a[9660900]=a[669184+(Y&255)|0]|a[9660900]&-15;break};case 91:{f00(-18);break};case 92:{Y=(a[9660896]|0)+1&255;a[9660896]=Y;a[9660900]=a[668928+(Y&255)|0]|a[9660900]&-15;break};case 93:{Y=a[9660896]|0;l=(Y&255)>>>4&8|a[9660900]&-16;a[9660900]=Y<<24>>24==0?l|4:l;break};case 94:{f00(-18);break};case 95:{a[9660896]=0;a[9660900]=a[9660900]&-16|4;break};case 96:{l=b[4830446]|0;Y=c[2415221]|0;k=c[2437644]|0;m=c[k+72+((Y>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){cH=c[k+3156>>2]|0;if((cH|0)==0){fp=0;fq=Y&65535;fr=k;break}n=gj[cH&4095](Y&65535)|0;fp=n;fq=b[4830442]|0;fr=c[2437644]|0}else{fp=a[m+(Y&255)|0]|0;fq=Y&65535;fr=k}}while(0);b[4853736]=(fp&255)+l&65535;b[4830442]=fq+1&65535;k=c[2426868]|0;Y=c[fr+72+((k>>>8&255)<<2)>>2]|0;do{if((Y|0)==0){m=c[fr+3144>>2]|0;if((m|0)==0){fs=0;ft=k;fu=fr;break}n=gj[m&4095](k&65535)|0;fs=n;ft=c[2426868]|0;fu=c[2437644]|0}else{fs=a[Y+(k&255)|0]|0;ft=k;fu=fr}}while(0);k=fs&255;Y=(a[9660900]&-16&255|(-k|0)>>>4&8)&255;a[9660900]=((k^(-k|0)^(-k|0)>>>1)>>>6&2|(-k|0)>>>8&1|(((-k|0)&255)<<24>>24==0?Y|4:Y)&255)&255;Y=c[fu+72+((ft>>>8&255|256)<<2)>>2]|0;if((Y|0)!=0){a[Y+(ft&255)|0]=(-k|0)&255;c[f+25632>>2]=2;c[f+25636>>2]=56;break OL}Y=c[fu+3148>>2]|0;if((Y|0)==0){c[f+25632>>2]=2;c[f+25636>>2]=56;break OL}gg[Y&4095](ft&65535,(-k|0)&255);break};default:{i=1}}}if(i){i=0;switch(j|0){case 97:{k=c[2415221]|0;Y=c[2437644]|0;l=c[Y+72+((k>>>8&255|512)<<2)>>2]|0;do{if((l|0)==0){n=c[Y+3156>>2]|0;if((n|0)==0){fv=0;fw=k&65535;fx=Y;break}m=gj[n&4095](k&65535)|0;fv=m;fw=b[4830442]|0;fx=c[2437644]|0}else{fv=a[l+(k&255)|0]|0;fw=k&65535;fx=Y}}while(0);b[4830442]=fw+1&65535;Y=b[4830446]|0;k=c[2415221]|0;l=c[fx+72+((k>>>8&255|512)<<2)>>2]|0;do{if((l|0)==0){m=c[fx+3156>>2]|0;if((m|0)==0){fy=0;fz=k&65535;fA=fx;break}n=gj[m&4095](k&65535)|0;fy=n;fz=b[4830442]|0;fA=c[2437644]|0}else{fy=a[l+(k&255)|0]|0;fz=k&65535;fA=fx}}while(0);b[4853736]=(fy&255)+Y&65535;b[4830442]=fz+1&65535;k=c[2426868]|0;l=c[fA+72+((k>>>8&255)<<2)>>2]|0;do{if((l|0)==0){n=c[fA+3144>>2]|0;if((n|0)==0){fB=0;fC=k;fD=fA;break}m=gj[n&4095](k&65535)|0;fB=m;fC=c[2426868]|0;fD=c[2437644]|0}else{fB=a[l+(k&255)|0]|0;fC=k;fD=fA}}while(0);k=fB&fv;l=(k&255)>>>4&8|a[9660900]&-15;a[9660900]=k<<24>>24==0?l|4:l;l=c[fD+72+((fC>>>8&255|256)<<2)>>2]|0;if((l|0)!=0){a[l+(fC&255)|0]=k;c[f+25632>>2]=2;c[f+25636>>2]=56;break OL}l=c[fD+3148>>2]|0;if((l|0)==0){c[f+25632>>2]=2;c[f+25636>>2]=56;break OL}gg[l&4095](fC&65535,k);break};case 98:{k=c[2415221]|0;l=c[2437644]|0;Y=c[l+72+((k>>>8&255|512)<<2)>>2]|0;do{if((Y|0)==0){m=c[l+3156>>2]|0;if((m|0)==0){fE=0;fF=k&65535;fG=l;break}n=gj[m&4095](k&65535)|0;fE=n;fF=b[4830442]|0;fG=c[2437644]|0}else{fE=a[Y+(k&255)|0]|0;fF=k&65535;fG=l}}while(0);b[4830442]=fF+1&65535;l=b[4830446]|0;k=c[2415221]|0;Y=c[fG+72+((k>>>8&255|512)<<2)>>2]|0;do{if((Y|0)==0){n=c[fG+3156>>2]|0;if((n|0)==0){fH=0;fI=k&65535;fJ=fG;break}m=gj[n&4095](k&65535)|0;fH=m;fI=b[4830442]|0;fJ=c[2437644]|0}else{fH=a[Y+(k&255)|0]|0;fI=k&65535;fJ=fG}}while(0);b[4853736]=(fH&255)+l&65535;b[4830442]=fI+1&65535;k=c[2426868]|0;Y=c[fJ+72+((k>>>8&255)<<2)>>2]|0;do{if((Y|0)==0){m=c[fJ+3144>>2]|0;if((m|0)==0){fK=0;fL=k;fM=fJ;break}n=gj[m&4095](k&65535)|0;fK=n;fL=c[2426868]|0;fM=c[2437644]|0}else{fK=a[Y+(k&255)|0]|0;fL=k;fM=fJ}}while(0);k=fK|fE;Y=(k&255)>>>4&8|a[9660900]&-15;a[9660900]=k<<24>>24==0?Y|4:Y;Y=c[fM+72+((fL>>>8&255|256)<<2)>>2]|0;if((Y|0)!=0){a[Y+(fL&255)|0]=k;c[f+25632>>2]=2;c[f+25636>>2]=56;break OL}Y=c[fM+3148>>2]|0;if((Y|0)==0){c[f+25632>>2]=2;c[f+25636>>2]=56;break OL}gg[Y&4095](fL&65535,k);break};case 99:{k=b[4830446]|0;Y=c[2415221]|0;l=c[2437644]|0;n=c[l+72+((Y>>>8&255|512)<<2)>>2]|0;do{if((n|0)==0){m=c[l+3156>>2]|0;if((m|0)==0){fN=0;fO=Y&65535;fP=l;break}cH=gj[m&4095](Y&65535)|0;fN=cH;fO=b[4830442]|0;fP=c[2437644]|0}else{fN=a[n+(Y&255)|0]|0;fO=Y&65535;fP=l}}while(0);b[4853736]=(fN&255)+k&65535;b[4830442]=fO+1&65535;l=c[2426868]|0;Y=c[fP+72+((l>>>8&255)<<2)>>2]|0;do{if((Y|0)==0){n=c[fP+3144>>2]|0;if((n|0)==0){fQ=0;fR=l;fS=fP;break}cH=gj[n&4095](l&65535)|0;fQ=cH;fR=c[2426868]|0;fS=c[2437644]|0}else{fQ=a[Y+(l&255)|0]|0;fR=l;fS=fP}}while(0);l=~fQ;Y=a[9660900]&-15|(l&255)>>>4&8;a[9660900]=(fQ<<24>>24==-1?Y|4:Y)|1;Y=c[fS+72+((fR>>>8&255|256)<<2)>>2]|0;if((Y|0)!=0){a[Y+(fR&255)|0]=l;c[f+25632>>2]=2;c[f+25636>>2]=56;break OL}Y=c[fS+3148>>2]|0;if((Y|0)==0){c[f+25632>>2]=2;c[f+25636>>2]=56;break OL}gg[Y&4095](fR&65535,l);break};case 100:{l=b[4830446]|0;Y=c[2415221]|0;k=c[2437644]|0;cH=c[k+72+((Y>>>8&255|512)<<2)>>2]|0;do{if((cH|0)==0){n=c[k+3156>>2]|0;if((n|0)==0){fT=0;fU=Y&65535;fV=k;break}m=gj[n&4095](Y&65535)|0;fT=m;fU=b[4830442]|0;fV=c[2437644]|0}else{fT=a[cH+(Y&255)|0]|0;fU=Y&65535;fV=k}}while(0);b[4853736]=(fT&255)+l&65535;b[4830442]=fU+1&65535;k=c[2426868]|0;Y=c[fV+72+((k>>>8&255)<<2)>>2]|0;do{if((Y|0)==0){cH=c[fV+3144>>2]|0;if((cH|0)==0){fW=0;fX=k;fY=fV;break}m=gj[cH&4095](k&65535)|0;fW=m;fX=c[2426868]|0;fY=c[2437644]|0}else{fW=a[Y+(k&255)|0]|0;fX=k;fY=fV}}while(0);k=a[9660900]&-14|fW&1;Y=(fW&255)>>>1;a[9660900]=Y<<24>>24==0?k|4:k;k=c[fY+72+((fX>>>8&255|256)<<2)>>2]|0;if((k|0)!=0){a[k+(fX&255)|0]=Y;c[f+25632>>2]=2;c[f+25636>>2]=56;break OL}k=c[fY+3148>>2]|0;if((k|0)==0){c[f+25632>>2]=2;c[f+25636>>2]=56;break OL}gg[k&4095](fX&65535,Y);break};case 101:{Y=c[2415221]|0;k=c[2437644]|0;l=c[k+72+((Y>>>8&255|512)<<2)>>2]|0;do{if((l|0)==0){m=c[k+3156>>2]|0;if((m|0)==0){fZ=0;f_=Y&65535;f$=k;break}cH=gj[m&4095](Y&65535)|0;fZ=cH;f_=b[4830442]|0;f$=c[2437644]|0}else{fZ=a[l+(Y&255)|0]|0;f_=Y&65535;f$=k}}while(0);b[4830442]=f_+1&65535;k=b[4830446]|0;Y=c[2415221]|0;l=c[f$+72+((Y>>>8&255|512)<<2)>>2]|0;do{if((l|0)==0){cH=c[f$+3156>>2]|0;if((cH|0)==0){f0=0;f1=Y&65535;f2=f$;break}m=gj[cH&4095](Y&65535)|0;f0=m;f1=b[4830442]|0;f2=c[2437644]|0}else{f0=a[l+(Y&255)|0]|0;f1=Y&65535;f2=f$}}while(0);b[4853736]=(f0&255)+k&65535;b[4830442]=f1+1&65535;Y=c[2426868]|0;l=c[f2+72+((Y>>>8&255)<<2)>>2]|0;do{if((l|0)==0){m=c[f2+3144>>2]|0;if((m|0)==0){f3=0;f4=Y;f5=f2;break}cH=gj[m&4095](Y&65535)|0;f3=cH;f4=c[2426868]|0;f5=c[2437644]|0}else{f3=a[l+(Y&255)|0]|0;f4=Y;f5=f2}}while(0);Y=f3^fZ;l=(Y&255)>>>4&8|a[9660900]&-15;a[9660900]=f3<<24>>24==fZ<<24>>24?l|4:l;l=c[f5+72+((f4>>>8&255|256)<<2)>>2]|0;if((l|0)!=0){a[l+(f4&255)|0]=Y;c[f+25632>>2]=2;c[f+25636>>2]=56;break OL}l=c[f5+3148>>2]|0;if((l|0)==0){c[f+25632>>2]=2;c[f+25636>>2]=56;break OL}gg[l&4095](f4&65535,Y);break};case 102:{Y=b[4830446]|0;l=c[2415221]|0;k=c[2437644]|0;cH=c[k+72+((l>>>8&255|512)<<2)>>2]|0;do{if((cH|0)==0){m=c[k+3156>>2]|0;if((m|0)==0){f6=0;f7=l&65535;f8=k;break}n=gj[m&4095](l&65535)|0;f6=n;f7=b[4830442]|0;f8=c[2437644]|0}else{f6=a[cH+(l&255)|0]|0;f7=l&65535;f8=k}}while(0);b[4853736]=(f6&255)+Y&65535;b[4830442]=f7+1&65535;k=c[2426868]|0;l=c[f8+72+((k>>>8&255)<<2)>>2]|0;do{if((l|0)==0){cH=c[f8+3144>>2]|0;if((cH|0)==0){f9=0;ga=k;gb=f8;break}n=gj[cH&4095](k&65535)|0;f9=n;ga=c[2426868]|0;gb=c[2437644]|0}else{f9=a[l+(k&255)|0]|0;ga=k;gb=f8}}while(0);k=a[9660900]|0;l=k<<7|(f9&255)>>>1;Y=k&-14|f9&1|k<<3&8;a[9660900]=l<<24>>24==0?Y|4:Y;Y=c[gb+72+((ga>>>8&255|256)<<2)>>2]|0;if((Y|0)!=0){a[Y+(ga&255)|0]=l;c[f+25632>>2]=2;c[f+25636>>2]=56;break OL}Y=c[gb+3148>>2]|0;if((Y|0)==0){c[f+25632>>2]=2;c[f+25636>>2]=56;break OL}gg[Y&4095](ga&65535,l);break};case 103:{l=b[4830446]|0;Y=c[2415221]|0;k=c[2437644]|0;n=c[k+72+((Y>>>8&255|512)<<2)>>2]|0;do{if((n|0)==0){cH=c[k+3156>>2]|0;if((cH|0)==0){gc=0;gd=Y&65535;ge=k;break}m=gj[cH&4095](Y&65535)|0;gc=m;gd=b[4830442]|0;ge=c[2437644]|0}else{gc=a[n+(Y&255)|0]|0;gd=Y&65535;ge=k}}while(0);b[4853736]=(gc&255)+l&65535;b[4830442]=gd+1&65535;k=c[2426868]|0;Y=c[ge+72+((k>>>8&255)<<2)>>2]|0;do{if((Y|0)==0){n=c[ge+3144>>2]|0;if((n|0)==0){gf=0;gh=k;gi=ge;break}m=gj[n&4095](k&65535)|0;gf=m;gh=c[2426868]|0;gi=c[2437644]|0}else{gf=a[Y+(k&255)|0]|0;gh=k;gi=ge}}while(0);k=(gf&255)>>>1;Y=a[9660900]&-14|gf&1|(gf&255)>>>4&8;a[9660900]=(k<<1&-128|k)<<24>>24==0?Y|4:Y;Y=c[gi+72+((gh>>>8&255|256)<<2)>>2]|0;if((Y|0)!=0){a[Y+(gh&255)|0]=k<<1&-128|k;c[f+25632>>2]=2;c[f+25636>>2]=56;break OL}Y=c[gi+3148>>2]|0;if((Y|0)==0){c[f+25632>>2]=2;c[f+25636>>2]=56;break OL}gg[Y&4095](gh&65535,k<<1&-128|k);break};case 104:{k=b[4830446]|0;Y=c[2415221]|0;l=c[2437644]|0;m=c[l+72+((Y>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){n=c[l+3156>>2]|0;if((n|0)==0){gk=0;gl=Y&65535;gm=l;break}cH=gj[n&4095](Y&65535)|0;gk=cH;gl=b[4830442]|0;gm=c[2437644]|0}else{gk=a[m+(Y&255)|0]|0;gl=Y&65535;gm=l}}while(0);b[4853736]=(gk&255)+k&65535;b[4830442]=gl+1&65535;l=c[2426868]|0;Y=c[gm+72+((l>>>8&255)<<2)>>2]|0;do{if((Y|0)==0){m=c[gm+3144>>2]|0;if((m|0)==0){gn=0;go=l;gp=gm;break}cH=gj[m&4095](l&65535)|0;gn=cH;go=c[2426868]|0;gp=c[2437644]|0}else{gn=a[Y+(l&255)|0]|0;go=l;gp=gm}}while(0);l=(gn&255)<<1;Y=((l&65535)>>>4&8|a[9660900]&-16&255)&255;a[9660900]=(((l&65535)>>>1^l&65535)>>>6&2|(l&65535)>>>8|((l&255)<<24>>24==0?Y|4:Y)&255)&255;Y=c[gp+72+((go>>>8&255|256)<<2)>>2]|0;if((Y|0)!=0){a[Y+(go&255)|0]=l&255;c[f+25632>>2]=2;c[f+25636>>2]=56;break OL}Y=c[gp+3148>>2]|0;if((Y|0)==0){c[f+25632>>2]=2;c[f+25636>>2]=56;break OL}gg[Y&4095](go&65535,l&255);break};case 105:{l=b[4830446]|0;Y=c[2415221]|0;k=c[2437644]|0;cH=c[k+72+((Y>>>8&255|512)<<2)>>2]|0;do{if((cH|0)==0){m=c[k+3156>>2]|0;if((m|0)==0){gq=0;gr=Y&65535;gs=k;break}n=gj[m&4095](Y&65535)|0;gq=n;gr=b[4830442]|0;gs=c[2437644]|0}else{gq=a[cH+(Y&255)|0]|0;gr=Y&65535;gs=k}}while(0);b[4853736]=(gq&255)+l&65535;b[4830442]=gr+1&65535;k=c[2426868]|0;Y=c[gs+72+((k>>>8&255)<<2)>>2]|0;do{if((Y|0)==0){cH=c[gs+3144>>2]|0;if((cH|0)==0){gt=0;gu=k;gv=gs;break}n=gj[cH&4095](k&65535)|0;gt=n;gu=c[2426868]|0;gv=c[2437644]|0}else{gt=a[Y+(k&255)|0]|0;gu=k;gv=gs}}while(0);k=a[9660900]|0;Y=k&1|(gt&255)<<1;a[9660900]=(((Y&65535)>>>1^Y&65535)>>>6&2|(Y&65535)>>>8|((Y&255)<<24>>24==0?((Y&65535)>>>4&8|k&-16&255)&255|4:((Y&65535)>>>4&8|k&-16&255)&255)&255)&255;k=c[gv+72+((gu>>>8&255|256)<<2)>>2]|0;if((k|0)!=0){a[k+(gu&255)|0]=Y&255;c[f+25632>>2]=2;c[f+25636>>2]=56;break OL}k=c[gv+3148>>2]|0;if((k|0)==0){c[f+25632>>2]=2;c[f+25636>>2]=56;break OL}gg[k&4095](gu&65535,Y&255);break};case 106:{Y=b[4830446]|0;k=c[2415221]|0;l=c[2437644]|0;n=c[l+72+((k>>>8&255|512)<<2)>>2]|0;do{if((n|0)==0){cH=c[l+3156>>2]|0;if((cH|0)==0){gw=0;gx=k&65535;gy=l;break}m=gj[cH&4095](k&65535)|0;gw=m;gx=b[4830442]|0;gy=c[2437644]|0}else{gw=a[n+(k&255)|0]|0;gx=k&65535;gy=l}}while(0);b[4853736]=(gw&255)+Y&65535;b[4830442]=gx+1&65535;l=c[2426868]|0;k=c[gy+72+((l>>>8&255)<<2)>>2]|0;do{if((k|0)==0){n=c[gy+3144>>2]|0;if((n|0)==0){gz=0;gA=l;gB=gy;break}m=gj[n&4095](l&65535)|0;gz=m;gA=c[2426868]|0;gB=c[2437644]|0}else{gz=a[k+(l&255)|0]|0;gA=l;gB=gy}}while(0);l=gz-1&255;a[9660900]=a[9660900]&-15|a[669184+(l&255)|0];k=c[gB+72+((gA>>>8&255|256)<<2)>>2]|0;if((k|0)!=0){a[k+(gA&255)|0]=l;c[f+25632>>2]=2;c[f+25636>>2]=56;break OL}k=c[gB+3148>>2]|0;if((k|0)==0){c[f+25632>>2]=2;c[f+25636>>2]=56;break OL}gg[k&4095](gA&65535,l);break};case 107:{l=c[2415221]|0;k=c[2437644]|0;Y=c[k+72+((l>>>8&255|512)<<2)>>2]|0;do{if((Y|0)==0){m=c[k+3156>>2]|0;if((m|0)==0){gC=0;gD=l&65535;gE=k;break}n=gj[m&4095](l&65535)|0;gC=n;gD=b[4830442]|0;gE=c[2437644]|0}else{gC=a[Y+(l&255)|0]|0;gD=l&65535;gE=k}}while(0);b[4830442]=gD+1&65535;k=b[4830446]|0;l=c[2415221]|0;Y=c[gE+72+((l>>>8&255|512)<<2)>>2]|0;do{if((Y|0)==0){n=c[gE+3156>>2]|0;if((n|0)==0){gF=0;gG=l&65535;gH=gE;break}m=gj[n&4095](l&65535)|0;gF=m;gG=b[4830442]|0;gH=c[2437644]|0}else{gF=a[Y+(l&255)|0]|0;gG=l&65535;gH=gE}}while(0);b[4853736]=(gF&255)+k&65535;b[4830442]=gG+1&65535;l=c[2426868]|0;Y=c[gH+72+((l>>>8&255)<<2)>>2]|0;do{if((Y|0)==0){m=c[gH+3144>>2]|0;if((m|0)==0){gI=0;break}gI=gj[m&4095](l&65535)|0}else{gI=a[Y+(l&255)|0]|0}}while(0);l=gI&gC;Y=(l&255)>>>4&8|a[9660900]&-15;a[9660900]=l<<24>>24==0?Y|4:Y;break};case 108:{Y=b[4830446]|0;l=c[2415221]|0;k=c[2437644]|0;m=c[k+72+((l>>>8&255|512)<<2)>>2]|0;do{if((m|0)==0){n=c[k+3156>>2]|0;if((n|0)==0){gJ=0;gK=l&65535;gL=k;break}cH=gj[n&4095](l&65535)|0;gJ=cH;gK=b[4830442]|0;gL=c[2437644]|0}else{gJ=a[m+(l&255)|0]|0;gK=l&65535;gL=k}}while(0);b[4853736]=(gJ&255)+Y&65535;b[4830442]=gK+1&65535;k=c[2426868]|0;l=c[gL+72+((k>>>8&255)<<2)>>2]|0;do{if((l|0)==0){m=c[gL+3144>>2]|0;if((m|0)==0){gM=0;gN=k;gO=gL;break}cH=gj[m&4095](k&65535)|0;gM=cH;gN=c[2426868]|0;gO=c[2437644]|0}else{gM=a[l+(k&255)|0]|0;gN=k;gO=gL}}while(0);k=gM+1&255;a[9660900]=a[9660900]&-15|a[668928+(k&255)|0];l=c[gO+72+((gN>>>8&255|256)<<2)>>2]|0;if((l|0)!=0){a[l+(gN&255)|0]=k;c[f+25632>>2]=2;c[f+25636>>2]=56;break OL}l=c[gO+3148>>2]|0;if((l|0)==0){c[f+25632>>2]=2;c[f+25636>>2]=56;break OL}gg[l&4095](gN&65535,k);break};case 109:{k=b[4830446]|0;l=c[2415221]|0;Y=c[2437644]|0;cH=c[Y+72+((l>>>8&255|512)<<2)>>2]|0;do{if((cH|0)==0){m=c[Y+3156>>2]|0;if((m|0)==0){gP=0;gQ=l&65535;gR=Y;break}n=gj[m&4095](l&65535)|0;gP=n;gQ=b[4830442]|0;gR=c[2437644]|0}else{gP=a[cH+(l&255)|0]|0;gQ=l&65535;gR=Y}}while(0);b[4853736]=(gP&255)+k&65535;b[4830442]=gQ+1&65535;Y=c[2426868]|0;l=c[gR+72+((Y>>>8&255)<<2)>>2]|0;do{if((l|0)==0){cH=c[gR+3144>>2]|0;if((cH|0)==0){gS=0;break}gS=gj[cH&4095](Y&65535)|0}else{gS=a[l+(Y&255)|0]|0}}while(0);Y=a[9660900]&-16|(gS&255)>>>4&8;a[9660900]=gS<<24>>24==0?Y|4:Y;break};case 110:{Y=b[4830446]|0;l=c[2415221]|0;k=c[2437644]|0;cH=c[k+72+((l>>>8&255|512)<<2)>>2]|0;do{if((cH|0)==0){n=c[k+3156>>2]|0;if((n|0)==0){gT=0;break}gT=gj[n&4095](l&65535)|0}else{gT=a[cH+(l&255)|0]|0}}while(0);l=(gT&255)+Y&65535;b[4853736]=l;b[4830442]=l;b[4830442]=c[2415221]&65535;break};case 111:{l=b[4830446]|0;cH=c[2415221]|0;k=c[2437644]|0;n=c[k+72+((cH>>>8&255|512)<<2)>>2]|0;do{if((n|0)==0){m=c[k+3156>>2]|0;if((m|0)==0){gU=0;gV=cH&65535;gW=k;break}s=gj[m&4095](cH&65535)|0;gU=s;gV=b[4830442]|0;gW=c[2437644]|0}else{gU=a[n+(cH&255)|0]|0;gV=cH&65535;gW=k}}while(0);b[4853736]=(gU&255)+l&65535;b[4830442]=gV+1&65535;k=c[2426868]|0;cH=c[gW+72+((k>>>8&255|256)<<2)>>2]|0;do{if((cH|0)==0){n=c[gW+3148>>2]|0;if((n|0)==0){break}gg[n&4095](k&65535,0)}else{a[cH+(k&255)|0]=0}}while(0);a[9660900]=a[9660900]&-16|4;break};case 112:{k=c[2415221]|0;cH=c[2437644]|0;l=c[cH+72+((k>>>8&255|512)<<2)>>2]|0;do{if((l|0)==0){n=c[cH+3156>>2]|0;if((n|0)==0){gX=0;gY=k;gZ=cH;g_=k&65535;break}Y=gj[n&4095](k&65535)|0;n=c[2415221]|0;gX=Y;gY=n;gZ=c[2437644]|0;g_=n&65535}else{gX=a[l+(k&255)|0]|0;gY=k;gZ=cH;g_=k&65535}}while(0);k=gX&255;cH=gY+1|0;l=c[gZ+72+((cH>>>8&255|512)<<2)>>2]|0;do{if((l|0)==0){n=c[gZ+3156>>2]|0;if((n|0)==0){g$=0;g0=g_;g1=gZ;break}Y=gj[n&4095](cH&65535)|0;g$=Y;g0=b[4830442]|0;g1=c[2437644]|0}else{g$=a[l+(cH&255)|0]|0;g0=g_;g1=gZ}}while(0);cH=g$&255;c[2426868]=cH|k<<8;b[4830442]=g0+2&65535;l=c[g1+72+(k<<2)>>2]|0;do{if((l|0)==0){Y=c[g1+3144>>2]|0;if((Y|0)==0){g2=0;g3=cH|k<<8;g4=g1;break}n=gj[Y&4095]((cH|k<<8)&65535)|0;g2=n;g3=c[2426868]|0;g4=c[2437644]|0}else{g2=a[l+cH|0]|0;g3=cH|k<<8;g4=g1}}while(0);k=g2&255;cH=(a[9660900]&-16&255|(-k|0)>>>4&8)&255;a[9660900]=((k^(-k|0)^(-k|0)>>>1)>>>6&2|(-k|0)>>>8&1|(((-k|0)&255)<<24>>24==0?cH|4:cH)&255)&255;cH=c[g4+72+((g3>>>8&255|256)<<2)>>2]|0;if((cH|0)!=0){a[cH+(g3&255)|0]=(-k|0)&255;c[f+25632>>2]=2;c[f+25636>>2]=56;break OL}cH=c[g4+3148>>2]|0;if((cH|0)==0){c[f+25632>>2]=2;c[f+25636>>2]=56;break OL}gg[cH&4095](g3&65535,(-k|0)&255);break};case 113:{k=c[2415221]|0;cH=c[2437644]|0;l=c[cH+72+((k>>>8&255|512)<<2)>>2]|0;do{if((l|0)==0){n=c[cH+3156>>2]|0;if((n|0)==0){g5=0;g6=k&65535;g7=cH;break}Y=gj[n&4095](k&65535)|0;g5=Y;g6=b[4830442]|0;g7=c[2437644]|0}else{g5=a[l+(k&255)|0]|0;g6=k&65535;g7=cH}}while(0);b[4830442]=g6+1&65535;cH=c[2415221]|0;k=c[g7+72+((cH>>>8&255|512)<<2)>>2]|0;do{if((k|0)==0){l=c[g7+3156>>2]|0;if((l|0)==0){g8=0;g9=cH&65535;ha=g7;break}Y=gj[l&4095](cH&65535)|0;g8=Y;g9=b[4830442]|0;ha=c[2437644]|0}else{g8=a[k+(cH&255)|0]|0;g9=cH&65535;ha=g7}}while(0);cH=g8&255;c[2426868]=cH;b[4830442]=g9+1&65535;k=g8&255;Y=c[ha+72>>2]|0;do{if((Y|0)==0){l=c[ha+3144>>2]|0;if((l|0)==0){hb=0;hc=cH;hd=ha;break}n=gj[l&4095](k)|0;hb=n;hc=c[2426868]|0;hd=c[2437644]|0}else{hb=a[Y+cH|0]|0;hc=cH;hd=ha}}while(0);cH=hb&g5;Y=(cH&255)>>>4&8|a[9660900]&-15;a[9660900]=cH<<24>>24==0?Y|4:Y;Y=c[hd+72+((hc>>>8&255|256)<<2)>>2]|0;if((Y|0)!=0){a[Y+(hc&255)|0]=cH;c[f+25632>>2]=2;c[f+25636>>2]=56;break OL}Y=c[hd+3148>>2]|0;if((Y|0)==0){c[f+25632>>2]=2;c[f+25636>>2]=56;break OL}gg[Y&4095](hc&65535,cH);break};case 114:{cH=c[2415221]|0;Y=c[2437644]|0;k=c[Y+72+((cH>>>8&255|512)<<2)>>2]|0;do{if((k|0)==0){n=c[Y+3156>>2]|0;if((n|0)==0){he=0;hf=cH&65535;hg=Y;break}l=gj[n&4095](cH&65535)|0;he=l;hf=b[4830442]|0;hg=c[2437644]|0}else{he=a[k+(cH&255)|0]|0;hf=cH&65535;hg=Y}}while(0);b[4830442]=hf+1&65535;Y=c[2415221]|0;cH=c[hg+72+((Y>>>8&255|512)<<2)>>2]|0;do{if((cH|0)==0){k=c[hg+3156>>2]|0;if((k|0)==0){hh=0;hi=Y&65535;hj=hg;break}l=gj[k&4095](Y&65535)|0;hh=l;hi=b[4830442]|0;hj=c[2437644]|0}else{hh=a[cH+(Y&255)|0]|0;hi=Y&65535;hj=hg}}while(0);Y=hh&255;c[2426868]=Y;b[4830442]=hi+1&65535;cH=hh&255;l=c[hj+72>>2]|0;do{if((l|0)==0){k=c[hj+3144>>2]|0;if((k|0)==0){hk=0;hl=Y;hm=hj;break}n=gj[k&4095](cH)|0;hk=n;hl=c[2426868]|0;hm=c[2437644]|0}else{hk=a[l+Y|0]|0;hl=Y;hm=hj}}while(0);Y=hk|he;l=(Y&255)>>>4&8|a[9660900]&-15;a[9660900]=Y<<24>>24==0?l|4:l;l=c[hm+72+((hl>>>8&255|256)<<2)>>2]|0;if((l|0)!=0){a[l+(hl&255)|0]=Y;c[f+25632>>2]=2;c[f+25636>>2]=56;break OL}l=c[hm+3148>>2]|0;if((l|0)==0){c[f+25632>>2]=2;c[f+25636>>2]=56;break OL}gg[l&4095](hl&65535,Y);break};case 115:{Y=c[2415221]|0;l=c[2437644]|0;cH=c[l+72+((Y>>>8&255|512)<<2)>>2]|0;do{if((cH|0)==0){n=c[l+3156>>2]|0;if((n|0)==0){hn=0;ho=Y;hp=l;hq=Y&65535;break}k=gj[n&4095](Y&65535)|0;n=c[2415221]|0;hn=k;ho=n;hp=c[2437644]|0;hq=n&65535}else{hn=a[cH+(Y&255)|0]|0;ho=Y;hp=l;hq=Y&65535}}while(0);Y=hn&255;l=ho+1|0;cH=c[hp+72+((l>>>8&255|512)<<2)>>2]|0;do{if((cH|0)==0){n=c[hp+3156>>2]|0;if((n|0)==0){hr=0;hs=hq;ht=hp;break}k=gj[n&4095](l&65535)|0;hr=k;hs=b[4830442]|0;ht=c[2437644]|0}else{hr=a[cH+(l&255)|0]|0;hs=hq;ht=hp}}while(0);l=hr&255;c[2426868]=l|Y<<8;b[4830442]=hs+2&65535;cH=c[ht+72+(Y<<2)>>2]|0;do{if((cH|0)==0){k=c[ht+3144>>2]|0;if((k|0)==0){hu=0;hv=l|Y<<8;hw=ht;break}n=gj[k&4095]((l|Y<<8)&65535)|0;hu=n;hv=c[2426868]|0;hw=c[2437644]|0}else{hu=a[cH+l|0]|0;hv=l|Y<<8;hw=ht}}while(0);Y=~hu;l=a[9660900]&-15|(Y&255)>>>4&8;a[9660900]=(hu<<24>>24==-1?l|4:l)|1;l=c[hw+72+((hv>>>8&255|256)<<2)>>2]|0;if((l|0)!=0){a[l+(hv&255)|0]=Y;c[f+25632>>2]=2;c[f+25636>>2]=56;break OL}l=c[hw+3148>>2]|0;if((l|0)==0){c[f+25632>>2]=2;c[f+25636>>2]=56;break OL}gg[l&4095](hv&65535,Y);break};default:{}}}}while(0);c[f+25616>>2]=i}function __Z8m6805Runi$0(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0,cf=0,cg=0,ch=0,ci=0,cj=0,ck=0,cl=0,cm=0,cn=0,co=0,cp=0,cq=0,cr=0,cs=0,ct=0,cu=0,cv=0,cw=0,cx=0,cy=0,cz=0,cA=0,cB=0,cC=0,cD=0,cE=0,cF=0,cG=0,cH=0,cI=0,cJ=0,cK=0,cL=0,cM=0,cN=0,cO=0,cP=0,cQ=0,cR=0,cS=0,cT=0,cU=0,cV=0,cW=0,cX=0,cY=0,cZ=0,c_=0,c$=0,c0=0,c1=0,c2=0,c3=0,c4=0,c5=0,c6=0,c7=0,c8=0,c9=0,da=0,db=0,dc=0,dd=0,de=0,df=0,dg=0,dh=0,di=0,dj=0,dk=0,dl=0,dm=0,dn=0,dp=0,dq=0,dr=0,ds=0,dt=0,du=0,dv=0,dw=0,dx=0,dy=0,dz=0,dA=0,dB=0,dC=0,dD=0,dE=0,dF=0,dG=0,dH=0,dI=0,dJ=0,dK=0,dL=0,dM=0,dN=0,dO=0,dP=0,dQ=0,dR=0,dS=0,dT=0,dU=0,dV=0,dW=0,dX=0,dY=0,dZ=0,d_=0,d$=0,d0=0,d1=0,d2=0,d3=0,d4=0,d5=0,d6=0,d7=0,d8=0,d9=0,ea=0,eb=0,ec=0,ed=0,ee=0,ef=0,eg=0,eh=0,ei=0,ej=0,ek=0,el=0,em=0,en=0,eo=0,ep=0,eq=0,er=0,es=0,et=0,eu=0,ev=0,ew=0,ex=0,ey=0,ez=0,eA=0,eB=0,eC=0,eD=0,eE=0,eF=0,eG=0,eH=0,eI=0,eJ=0,eK=0,eL=0,eM=0,eN=0,eO=0,eP=0,eQ=0,eR=0,eS=0,eT=0,eU=0,eV=0,eW=0,eX=0,eY=0,eZ=0,e_=0,e$=0,e0=0,e1=0,e2=0,e3=0,e4=0,e5=0,e6=0,e7=0,e8=0,e9=0,fa=0,fb=0,fc=0,fd=0,fe=0,ff=0,fg=0,fh=0,fi=0,fj=0,fk=0,fl=0,fm=0,fn=0,fo=0,fp=0,fq=0,fr=0,fs=0,ft=0,fu=0,fv=0,fw=0,fx=0,fy=0,fz=0,fA=0,fB=0,fC=0,fD=0,fE=0,fF=0,fG=0,fH=0,fI=0,fJ=0,fK=0,fL=0,fM=0,fN=0,fO=0,fP=0,fQ=0,fR=0,fS=0,fT=0,fU=0,fV=0,fW=0,fX=0,fY=0,fZ=0,f_=0,f$=0,f0=0,f1=0,f2=0,f3=0,f4=0,f5=0,f6=0,f7=0,f8=0,f9=0,ga=0,gb=0,gc=0,gd=0,ge=0,gf=0,gh=0,gi=0,gk=0,gl=0,gm=0,gn=0,go=0,gp=0,gq=0,gr=0,gs=0,gt=0,gu=0,gv=0,gw=0,gx=0,gy=0,gz=0,gA=0,gB=0,gC=0,gD=0,gE=0,gF=0,gG=0,gH=0,gI=0,gJ=0,gK=0,gL=0,gM=0,gN=0,gO=0,gP=0,gQ=0,gR=0,gS=0,gT=0,gU=0,gV=0,gW=0,gX=0,gY=0,gZ=0,g_=0,g$=0,g0=0,g1=0,g2=0,g3=0,g4=0,g5=0,g6=0,g7=0,g8=0,g9=0,ha=0,hb=0,hc=0,hd=0,he=0,hf=0,hg=0,hh=0,hi=0,hj=0,hk=0,hl=0,hm=0,hn=0,ho=0,hp=0,hq=0,hr=0,hs=0,ht=0,hu=0,hv=0,hw=0,hx=0,hy=0,hz=0,hA=0,hB=0,hC=0,hD=0,hE=0,hF=0,hG=0,hH=0,hI=0,hJ=0,hK=0,hL=0,hM=0,hN=0,hO=0,hP=0;g=c[f+23416>>2]|0;h=c[f+23424>>2]|0;OL:do{if(g){g=0;switch(h|0){case 193:{c[2426866]=0;i=b[4830406]|0;j=c[2443666]|0;k=c[3528996]|0;l=c[9702704+((j&(i&65535))>>>(k>>>0)<<2)>>2]|0;do{if((l|0)==0){m=c[2385590]|0;if((m|0)==0){n=0;o=i;p=j;q=k;break}r=gj[m&4095](j&(i&65535)&65535)|0;n=r;o=b[4830406]|0;p=c[2443666]|0;q=c[3528996]|0}else{n=a[l+(c[2385780]&(j&(i&65535)))|0]|0;o=i;p=j;q=k}}while(0);a[9707465]=n;k=o+1&65535&p;j=c[9702704+(k>>>(q>>>0)<<2)>>2]|0;do{if((j|0)==0){i=c[2385590]|0;if((i|0)==0){s=0;t=o;u=p;v=q;break}l=gj[i&4095](k&65535)|0;s=l;t=b[4830406]|0;u=c[2443666]|0;v=c[3528996]|0}else{s=a[j+(c[2385780]&k)|0]|0;t=o;u=p;v=q}}while(0);a[9707464]=s;b[4830406]=t+2&65535;k=c[2426866]&65535&u;j=c[9702704+(k>>>(v>>>0)<<2)>>2]|0;do{if((j|0)==0){l=c[2385590]|0;if((l|0)==0){w=0;break}w=gj[l&4095](k&65535)|0}else{w=a[j+(c[2385780]&k)|0]|0}}while(0);k=(d[9660820]|0)-(w&255)&65535;j=((k&65535)>>>5&4|a[9660822]&-8&255)&255;a[9660822]=(((k&255)<<24>>24==0?j|2:j)&255|(k&65535)>>>8&1)&255;break};case 194:{c[2426866]=0;k=b[4830406]|0;j=c[2443666]|0;l=c[3528996]|0;i=c[9702704+((j&(k&65535))>>>(l>>>0)<<2)>>2]|0;do{if((i|0)==0){r=c[2385590]|0;if((r|0)==0){x=0;y=k;z=j;A=l;break}m=gj[r&4095](j&(k&65535)&65535)|0;x=m;y=b[4830406]|0;z=c[2443666]|0;A=c[3528996]|0}else{x=a[i+(c[2385780]&(j&(k&65535)))|0]|0;y=k;z=j;A=l}}while(0);a[9707465]=x;l=y+1&65535&z;j=c[9702704+(l>>>(A>>>0)<<2)>>2]|0;do{if((j|0)==0){k=c[2385590]|0;if((k|0)==0){B=0;C=y;D=z;E=A;break}i=gj[k&4095](l&65535)|0;B=i;C=b[4830406]|0;D=c[2443666]|0;E=c[3528996]|0}else{B=a[j+(c[2385780]&l)|0]|0;C=y;D=z;E=A}}while(0);a[9707464]=B;b[4830406]=C+2&65535;l=c[2426866]&65535&D;j=c[9702704+(l>>>(E>>>0)<<2)>>2]|0;do{if((j|0)==0){i=c[2385590]|0;if((i|0)==0){F=0;break}F=gj[i&4095](l&65535)|0}else{F=a[j+(c[2385780]&l)|0]|0}}while(0);l=a[9660822]|0;j=(d[9660820]|0)-(F&255)-(l&1)|0;a[9660822]=(((j&255)<<24>>24==0?(j>>>5&4|l&-8&255)&255|2:(j>>>5&4|l&-8&255)&255)&255|j>>>8&1)&255;a[9660820]=j&255;break};case 195:{c[2426866]=0;j=b[4830406]|0;l=c[2443666]|0;i=c[3528996]|0;k=c[9702704+((l&(j&65535))>>>(i>>>0)<<2)>>2]|0;do{if((k|0)==0){m=c[2385590]|0;if((m|0)==0){G=0;H=j;I=l;J=i;break}r=gj[m&4095](l&(j&65535)&65535)|0;G=r;H=b[4830406]|0;I=c[2443666]|0;J=c[3528996]|0}else{G=a[k+(c[2385780]&(l&(j&65535)))|0]|0;H=j;I=l;J=i}}while(0);a[9707465]=G;i=H+1&65535&I;l=c[9702704+(i>>>(J>>>0)<<2)>>2]|0;do{if((l|0)==0){j=c[2385590]|0;if((j|0)==0){K=0;L=H;M=I;N=J;break}k=gj[j&4095](i&65535)|0;K=k;L=b[4830406]|0;M=c[2443666]|0;N=c[3528996]|0}else{K=a[l+(c[2385780]&i)|0]|0;L=H;M=I;N=J}}while(0);a[9707464]=K;b[4830406]=L+2&65535;i=c[2426866]&65535&M;l=c[9702704+(i>>>(N>>>0)<<2)>>2]|0;do{if((l|0)==0){k=c[2385590]|0;if((k|0)==0){O=0;break}O=gj[k&4095](i&65535)|0}else{O=a[l+(c[2385780]&i)|0]|0}}while(0);i=(d[9660821]|0)-(O&255)&65535;l=((i&65535)>>>5&4|a[9660822]&-8&255)&255;a[9660822]=(((i&255)<<24>>24==0?l|2:l)&255|(i&65535)>>>8&1)&255;break};case 196:{c[2426866]=0;i=b[4830406]|0;l=c[2443666]|0;k=c[3528996]|0;j=c[9702704+((l&(i&65535))>>>(k>>>0)<<2)>>2]|0;do{if((j|0)==0){r=c[2385590]|0;if((r|0)==0){P=0;Q=i;R=l;S=k;break}m=gj[r&4095](l&(i&65535)&65535)|0;P=m;Q=b[4830406]|0;R=c[2443666]|0;S=c[3528996]|0}else{P=a[j+(c[2385780]&(l&(i&65535)))|0]|0;Q=i;R=l;S=k}}while(0);a[9707465]=P;k=Q+1&65535&R;l=c[9702704+(k>>>(S>>>0)<<2)>>2]|0;do{if((l|0)==0){i=c[2385590]|0;if((i|0)==0){T=0;U=Q;V=R;W=S;break}j=gj[i&4095](k&65535)|0;T=j;U=b[4830406]|0;V=c[2443666]|0;W=c[3528996]|0}else{T=a[l+(c[2385780]&k)|0]|0;U=Q;V=R;W=S}}while(0);a[9707464]=T;b[4830406]=U+2&65535;k=c[2426866]&65535&V;l=c[9702704+(k>>>(W>>>0)<<2)>>2]|0;do{if((l|0)==0){j=c[2385590]|0;if((j|0)==0){X=0;break}X=gj[j&4095](k&65535)|0}else{X=a[l+(c[2385780]&k)|0]|0}}while(0);k=a[9660820]&X;a[9660820]=k;l=(k&255)>>>5&4|a[9660822]&-7;a[9660822]=k<<24>>24==0?l|2:l;break};case 197:{c[2426866]=0;l=b[4830406]|0;k=c[2443666]|0;j=c[3528996]|0;i=c[9702704+((k&(l&65535))>>>(j>>>0)<<2)>>2]|0;do{if((i|0)==0){m=c[2385590]|0;if((m|0)==0){Y=0;Z=l;_=k;$=j;break}r=gj[m&4095](k&(l&65535)&65535)|0;Y=r;Z=b[4830406]|0;_=c[2443666]|0;$=c[3528996]|0}else{Y=a[i+(c[2385780]&(k&(l&65535)))|0]|0;Z=l;_=k;$=j}}while(0);a[9707465]=Y;j=Z+1&65535&_;k=c[9702704+(j>>>($>>>0)<<2)>>2]|0;do{if((k|0)==0){l=c[2385590]|0;if((l|0)==0){aa=0;ab=Z;ac=_;ad=$;break}i=gj[l&4095](j&65535)|0;aa=i;ab=b[4830406]|0;ac=c[2443666]|0;ad=c[3528996]|0}else{aa=a[k+(c[2385780]&j)|0]|0;ab=Z;ac=_;ad=$}}while(0);a[9707464]=aa;b[4830406]=ab+2&65535;j=c[2426866]&65535&ac;k=c[9702704+(j>>>(ad>>>0)<<2)>>2]|0;do{if((k|0)==0){i=c[2385590]|0;if((i|0)==0){ae=0;break}ae=gj[i&4095](j&65535)|0}else{ae=a[k+(c[2385780]&j)|0]|0}}while(0);j=a[9660820]&ae;k=(j&255)>>>5&4|a[9660822]&-7;a[9660822]=j<<24>>24==0?k|2:k;break};case 198:{c[2426866]=0;k=b[4830406]|0;j=c[2443666]|0;i=c[3528996]|0;l=c[9702704+((j&(k&65535))>>>(i>>>0)<<2)>>2]|0;do{if((l|0)==0){r=c[2385590]|0;if((r|0)==0){af=0;ag=k;ah=j;ai=i;break}m=gj[r&4095](j&(k&65535)&65535)|0;af=m;ag=b[4830406]|0;ah=c[2443666]|0;ai=c[3528996]|0}else{af=a[l+(c[2385780]&(j&(k&65535)))|0]|0;ag=k;ah=j;ai=i}}while(0);a[9707465]=af;i=ag+1&65535&ah;j=c[9702704+(i>>>(ai>>>0)<<2)>>2]|0;do{if((j|0)==0){k=c[2385590]|0;if((k|0)==0){aj=0;ak=ag;al=ah;am=ai;break}l=gj[k&4095](i&65535)|0;aj=l;ak=b[4830406]|0;al=c[2443666]|0;am=c[3528996]|0}else{aj=a[j+(c[2385780]&i)|0]|0;ak=ag;al=ah;am=ai}}while(0);a[9707464]=aj;b[4830406]=ak+2&65535;i=c[2426866]&65535&al;j=c[9702704+(i>>>(am>>>0)<<2)>>2]|0;do{if((j|0)==0){l=c[2385590]|0;if((l|0)==0){an=0;break}an=gj[l&4095](i&65535)|0}else{an=a[j+(c[2385780]&i)|0]|0}}while(0);a[9660820]=an;i=(an&255)>>>5&4|a[9660822]&-7;a[9660822]=an<<24>>24==0?i|2:i;break};case 199:{i=a[9660820]|0;j=(i&255)>>>5&4|a[9660822]&-7;a[9660822]=i<<24>>24==0?j|2:j;c[2426866]=0;j=b[4830406]|0;i=c[2443666]|0;l=c[3528996]|0;k=c[9702704+((i&(j&65535))>>>(l>>>0)<<2)>>2]|0;do{if((k|0)==0){m=c[2385590]|0;if((m|0)==0){ao=0;ap=j;aq=i;ar=l;break}r=gj[m&4095](i&(j&65535)&65535)|0;ao=r;ap=b[4830406]|0;aq=c[2443666]|0;ar=c[3528996]|0}else{ao=a[k+(c[2385780]&(i&(j&65535)))|0]|0;ap=j;aq=i;ar=l}}while(0);a[9707465]=ao;l=ap+1&65535&aq;i=c[9702704+(l>>>(ar>>>0)<<2)>>2]|0;do{if((i|0)==0){j=c[2385590]|0;if((j|0)==0){as=0;at=ap;au=aq;av=ar;break}k=gj[j&4095](l&65535)|0;as=k;at=b[4830406]|0;au=c[2443666]|0;av=c[3528996]|0}else{as=a[i+(c[2385780]&l)|0]|0;at=ap;au=aq;av=ar}}while(0);a[9707464]=as;b[4830406]=at+2&65535;l=a[9660820]|0;i=c[2426866]&65535&au;k=c[9703728+(i>>>(av>>>0)<<2)>>2]|0;if((k|0)!=0){a[k+(c[2385780]&i)|0]=l;c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}k=c[3528586]|0;if((k|0)==0){c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}gg[k&4095](i&65535,l);break};case 200:{c[2426866]=0;l=b[4830406]|0;i=c[2443666]|0;k=c[3528996]|0;j=c[9702704+((i&(l&65535))>>>(k>>>0)<<2)>>2]|0;do{if((j|0)==0){r=c[2385590]|0;if((r|0)==0){aw=0;ax=l;ay=i;az=k;break}m=gj[r&4095](i&(l&65535)&65535)|0;aw=m;ax=b[4830406]|0;ay=c[2443666]|0;az=c[3528996]|0}else{aw=a[j+(c[2385780]&(i&(l&65535)))|0]|0;ax=l;ay=i;az=k}}while(0);a[9707465]=aw;k=ax+1&65535&ay;i=c[9702704+(k>>>(az>>>0)<<2)>>2]|0;do{if((i|0)==0){l=c[2385590]|0;if((l|0)==0){aA=0;aB=ax;aC=ay;aD=az;break}j=gj[l&4095](k&65535)|0;aA=j;aB=b[4830406]|0;aC=c[2443666]|0;aD=c[3528996]|0}else{aA=a[i+(c[2385780]&k)|0]|0;aB=ax;aC=ay;aD=az}}while(0);a[9707464]=aA;b[4830406]=aB+2&65535;k=c[2426866]&65535&aC;i=c[9702704+(k>>>(aD>>>0)<<2)>>2]|0;do{if((i|0)==0){j=c[2385590]|0;if((j|0)==0){aE=0;break}aE=gj[j&4095](k&65535)|0}else{aE=a[i+(c[2385780]&k)|0]|0}}while(0);k=a[9660820]|0;i=k^aE;a[9660820]=i;j=(i&255)>>>5&4|a[9660822]&-7;a[9660822]=k<<24>>24==aE<<24>>24?j|2:j;break};case 201:{c[2426866]=0;j=b[4830406]|0;k=c[2443666]|0;i=c[3528996]|0;l=c[9702704+((k&(j&65535))>>>(i>>>0)<<2)>>2]|0;do{if((l|0)==0){m=c[2385590]|0;if((m|0)==0){aF=0;aG=j;aH=k;aI=i;break}r=gj[m&4095](k&(j&65535)&65535)|0;aF=r;aG=b[4830406]|0;aH=c[2443666]|0;aI=c[3528996]|0}else{aF=a[l+(c[2385780]&(k&(j&65535)))|0]|0;aG=j;aH=k;aI=i}}while(0);a[9707465]=aF;i=aG+1&65535&aH;k=c[9702704+(i>>>(aI>>>0)<<2)>>2]|0;do{if((k|0)==0){j=c[2385590]|0;if((j|0)==0){aJ=0;aK=aG;aL=aH;aM=aI;break}l=gj[j&4095](i&65535)|0;aJ=l;aK=b[4830406]|0;aL=c[2443666]|0;aM=c[3528996]|0}else{aJ=a[k+(c[2385780]&i)|0]|0;aK=aG;aL=aH;aM=aI}}while(0);a[9707464]=aJ;b[4830406]=aK+2&65535;i=c[2426866]&65535&aL;k=c[9702704+(i>>>(aM>>>0)<<2)>>2]|0;do{if((k|0)==0){l=c[2385590]|0;if((l|0)==0){aN=0;break}aN=gj[l&4095](i&65535)|0}else{aN=a[k+(c[2385780]&i)|0]|0}}while(0);i=a[9660820]|0;k=a[9660822]|0;l=(i&255)+(aN&255)+(k&1)|0;a[9660822]=((l^(i^aN)&255)&16|l>>>8&1|((l&255)<<24>>24==0?(l>>>5&4|k&-24&255)&255|2:(l>>>5&4|k&-24&255)&255)&255)&255;a[9660820]=l&255;break};case 202:{c[2426866]=0;l=b[4830406]|0;k=c[2443666]|0;i=c[3528996]|0;j=c[9702704+((k&(l&65535))>>>(i>>>0)<<2)>>2]|0;do{if((j|0)==0){r=c[2385590]|0;if((r|0)==0){aO=0;aP=l;aQ=k;aR=i;break}m=gj[r&4095](k&(l&65535)&65535)|0;aO=m;aP=b[4830406]|0;aQ=c[2443666]|0;aR=c[3528996]|0}else{aO=a[j+(c[2385780]&(k&(l&65535)))|0]|0;aP=l;aQ=k;aR=i}}while(0);a[9707465]=aO;i=aP+1&65535&aQ;k=c[9702704+(i>>>(aR>>>0)<<2)>>2]|0;do{if((k|0)==0){l=c[2385590]|0;if((l|0)==0){aS=0;aT=aP;aU=aQ;aV=aR;break}j=gj[l&4095](i&65535)|0;aS=j;aT=b[4830406]|0;aU=c[2443666]|0;aV=c[3528996]|0}else{aS=a[k+(c[2385780]&i)|0]|0;aT=aP;aU=aQ;aV=aR}}while(0);a[9707464]=aS;b[4830406]=aT+2&65535;i=c[2426866]&65535&aU;k=c[9702704+(i>>>(aV>>>0)<<2)>>2]|0;do{if((k|0)==0){j=c[2385590]|0;if((j|0)==0){aW=0;break}aW=gj[j&4095](i&65535)|0}else{aW=a[k+(c[2385780]&i)|0]|0}}while(0);i=a[9660820]|aW;a[9660820]=i;k=(i&255)>>>5&4|a[9660822]&-7;a[9660822]=i<<24>>24==0?k|2:k;break};case 203:{c[2426866]=0;k=b[4830406]|0;i=c[2443666]|0;j=c[3528996]|0;l=c[9702704+((i&(k&65535))>>>(j>>>0)<<2)>>2]|0;do{if((l|0)==0){m=c[2385590]|0;if((m|0)==0){aX=0;aY=k;aZ=i;a_=j;break}r=gj[m&4095](i&(k&65535)&65535)|0;aX=r;aY=b[4830406]|0;aZ=c[2443666]|0;a_=c[3528996]|0}else{aX=a[l+(c[2385780]&(i&(k&65535)))|0]|0;aY=k;aZ=i;a_=j}}while(0);a[9707465]=aX;j=aY+1&65535&aZ;i=c[9702704+(j>>>(a_>>>0)<<2)>>2]|0;do{if((i|0)==0){k=c[2385590]|0;if((k|0)==0){a$=0;a0=aY;a1=aZ;a2=a_;break}l=gj[k&4095](j&65535)|0;a$=l;a0=b[4830406]|0;a1=c[2443666]|0;a2=c[3528996]|0}else{a$=a[i+(c[2385780]&j)|0]|0;a0=aY;a1=aZ;a2=a_}}while(0);a[9707464]=a$;b[4830406]=a0+2&65535;j=c[2426866]&65535&a1;i=c[9702704+(j>>>(a2>>>0)<<2)>>2]|0;do{if((i|0)==0){l=c[2385590]|0;if((l|0)==0){a3=0;break}a3=gj[l&4095](j&65535)|0}else{a3=a[i+(c[2385780]&j)|0]|0}}while(0);j=a[9660820]|0;i=(j&255)+(a3&255)|0;l=(i>>>5&4|a[9660822]&-24&255)&255;a[9660822]=(((j^a3)&255^i)&16|i>>>8&1|((i&255)<<24>>24==0?l|2:l)&255)&255;a[9660820]=i&255;break};case 204:{c[2426866]=0;i=b[4830406]|0;l=c[2443666]|0;j=c[3528996]|0;k=c[9702704+((l&(i&65535))>>>(j>>>0)<<2)>>2]|0;do{if((k|0)==0){r=c[2385590]|0;if((r|0)==0){a4=0;a5=i;a6=l;a7=j;break}m=gj[r&4095](l&(i&65535)&65535)|0;a4=m;a5=b[4830406]|0;a6=c[2443666]|0;a7=c[3528996]|0}else{a4=a[k+(c[2385780]&(l&(i&65535)))|0]|0;a5=i;a6=l;a7=j}}while(0);a[9707465]=a4;j=a5+1&65535&a6;l=c[9702704+(j>>>(a7>>>0)<<2)>>2]|0;do{if((l|0)==0){i=c[2385590]|0;if((i|0)==0){a8=0;break}a8=gj[i&4095](j&65535)|0}else{a8=a[l+(c[2385780]&j)|0]|0}}while(0);a[9707464]=a8;b[4830406]=b[4853732]|0;break};case 205:{c[2426866]=0;j=b[4830406]|0;l=c[2443666]|0;i=c[3528996]|0;k=c[9702704+((l&(j&65535))>>>(i>>>0)<<2)>>2]|0;do{if((k|0)==0){m=c[2385590]|0;if((m|0)==0){a9=0;ba=j;bb=l;bc=i;break}r=gj[m&4095](l&(j&65535)&65535)|0;a9=r;ba=b[4830406]|0;bb=c[2443666]|0;bc=c[3528996]|0}else{a9=a[k+(c[2385780]&(l&(j&65535)))|0]|0;ba=j;bb=l;bc=i}}while(0);a[9707465]=a9;i=ba+1&65535&bb;l=c[9702704+(i>>>(bc>>>0)<<2)>>2]|0;do{if((l|0)==0){j=c[2385590]|0;if((j|0)==0){bd=0;be=ba;bf=bb;bg=bc;break}k=gj[j&4095](i&65535)|0;bd=k;be=b[4830406]|0;bf=c[2443666]|0;bg=c[3528996]|0}else{bd=a[l+(c[2385780]&i)|0]|0;be=ba;bf=bb;bg=bc}}while(0);a[9707464]=bd;i=be+2&65535;b[4830406]=i;l=bf&(e[4830408]|0);k=c[9703728+(l>>>(bg>>>0)<<2)>>2]|0;do{if((k|0)==0){j=c[3528586]|0;if((j|0)==0){break}gg[j&4095](l&65535,i&255)}else{a[k+(c[2385780]&l)|0]=i&255}}while(0);i=(b[4830408]|0)-1&65535;b[4830408]=i;if((i&65535)>>>0<(c[2415202]|0)>>>0){l=c[2415201]&65535;b[4830408]=l;bh=l}else{bh=i}i=a[9660813]|0;l=c[2443666]&(bh&65535);k=c[9703728+(l>>>((c[3528996]|0)>>>0)<<2)>>2]|0;do{if((k|0)==0){j=c[3528586]|0;if((j|0)==0){break}gg[j&4095](l&65535,i)}else{a[k+(c[2385780]&l)|0]=i}}while(0);i=(b[4830408]|0)-1&65535;b[4830408]=i;if((i&65535)>>>0<(c[2415202]|0)>>>0){b[4830408]=c[2415201]&65535}b[4830406]=b[4853732]|0;break};case 206:{c[2426866]=0;i=b[4830406]|0;l=c[2443666]|0;k=c[3528996]|0;j=c[9702704+((l&(i&65535))>>>(k>>>0)<<2)>>2]|0;do{if((j|0)==0){r=c[2385590]|0;if((r|0)==0){bi=0;bj=i;bk=l;bl=k;break}m=gj[r&4095](l&(i&65535)&65535)|0;bi=m;bj=b[4830406]|0;bk=c[2443666]|0;bl=c[3528996]|0}else{bi=a[j+(c[2385780]&(l&(i&65535)))|0]|0;bj=i;bk=l;bl=k}}while(0);a[9707465]=bi;k=bj+1&65535&bk;l=c[9702704+(k>>>(bl>>>0)<<2)>>2]|0;do{if((l|0)==0){i=c[2385590]|0;if((i|0)==0){bm=0;bn=bj;bo=bk;bp=bl;break}j=gj[i&4095](k&65535)|0;bm=j;bn=b[4830406]|0;bo=c[2443666]|0;bp=c[3528996]|0}else{bm=a[l+(c[2385780]&k)|0]|0;bn=bj;bo=bk;bp=bl}}while(0);a[9707464]=bm;b[4830406]=bn+2&65535;k=c[2426866]&65535&bo;l=c[9702704+(k>>>(bp>>>0)<<2)>>2]|0;do{if((l|0)==0){j=c[2385590]|0;if((j|0)==0){bq=0;break}bq=gj[j&4095](k&65535)|0}else{bq=a[l+(c[2385780]&k)|0]|0}}while(0);a[9660821]=bq;k=(bq&255)>>>5&4|a[9660822]&-7;a[9660822]=bq<<24>>24==0?k|2:k;break};case 207:{k=a[9660821]|0;l=(k&255)>>>5&4|a[9660822]&-7;a[9660822]=k<<24>>24==0?l|2:l;c[2426866]=0;l=b[4830406]|0;k=c[2443666]|0;j=c[3528996]|0;i=c[9702704+((k&(l&65535))>>>(j>>>0)<<2)>>2]|0;do{if((i|0)==0){m=c[2385590]|0;if((m|0)==0){br=0;bs=l;bt=k;bu=j;break}r=gj[m&4095](k&(l&65535)&65535)|0;br=r;bs=b[4830406]|0;bt=c[2443666]|0;bu=c[3528996]|0}else{br=a[i+(c[2385780]&(k&(l&65535)))|0]|0;bs=l;bt=k;bu=j}}while(0);a[9707465]=br;j=bs+1&65535&bt;k=c[9702704+(j>>>(bu>>>0)<<2)>>2]|0;do{if((k|0)==0){l=c[2385590]|0;if((l|0)==0){bv=0;bw=bs;bx=bt;by=bu;break}i=gj[l&4095](j&65535)|0;bv=i;bw=b[4830406]|0;bx=c[2443666]|0;by=c[3528996]|0}else{bv=a[k+(c[2385780]&j)|0]|0;bw=bs;bx=bt;by=bu}}while(0);a[9707464]=bv;b[4830406]=bw+2&65535;j=a[9660821]|0;k=c[2426866]&65535&bx;i=c[9703728+(k>>>(by>>>0)<<2)>>2]|0;if((i|0)!=0){a[i+(c[2385780]&k)|0]=j;c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}i=c[3528586]|0;if((i|0)==0){c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}gg[i&4095](k&65535,j);break};case 208:{c[2426866]=0;j=b[4830406]|0;k=c[2443666]|0;i=c[3528996]|0;l=c[9702704+((k&(j&65535))>>>(i>>>0)<<2)>>2]|0;do{if((l|0)==0){r=c[2385590]|0;if((r|0)==0){bz=0;bA=j;bB=k;bC=i;break}m=gj[r&4095](k&(j&65535)&65535)|0;bz=m;bA=b[4830406]|0;bB=c[2443666]|0;bC=c[3528996]|0}else{bz=a[l+(c[2385780]&(k&(j&65535)))|0]|0;bA=j;bB=k;bC=i}}while(0);a[9707465]=bz;i=bA+1&65535&bB;k=c[9702704+(i>>>(bC>>>0)<<2)>>2]|0;do{if((k|0)==0){j=c[2385590]|0;if((j|0)==0){bD=0;bE=bA;bF=bB;bG=bC;break}l=gj[j&4095](i&65535)|0;bD=l;bE=b[4830406]|0;bF=c[2443666]|0;bG=c[3528996]|0}else{bD=a[k+(c[2385780]&i)|0]|0;bE=bA;bF=bB;bG=bC}}while(0);a[9707464]=bD;b[4830406]=bE+2&65535;b[4853732]=(b[4853732]|0)+(d[9660821]|0)&65535;i=c[2426866]&65535&bF;k=c[9702704+(i>>>(bG>>>0)<<2)>>2]|0;do{if((k|0)==0){l=c[2385590]|0;if((l|0)==0){bH=0;break}bH=gj[l&4095](i&65535)|0}else{bH=a[k+(c[2385780]&i)|0]|0}}while(0);i=(d[9660820]|0)-(bH&255)&65535;k=((i&65535)>>>5&4|a[9660822]&-8&255)&255;a[9660822]=(((i&255)<<24>>24==0?k|2:k)&255|(i&65535)>>>8&1)&255;a[9660820]=i&255;break};case 209:{c[2426866]=0;i=b[4830406]|0;k=c[2443666]|0;l=c[3528996]|0;j=c[9702704+((k&(i&65535))>>>(l>>>0)<<2)>>2]|0;do{if((j|0)==0){m=c[2385590]|0;if((m|0)==0){bI=0;bJ=i;bK=k;bL=l;break}r=gj[m&4095](k&(i&65535)&65535)|0;bI=r;bJ=b[4830406]|0;bK=c[2443666]|0;bL=c[3528996]|0}else{bI=a[j+(c[2385780]&(k&(i&65535)))|0]|0;bJ=i;bK=k;bL=l}}while(0);a[9707465]=bI;l=bJ+1&65535&bK;k=c[9702704+(l>>>(bL>>>0)<<2)>>2]|0;do{if((k|0)==0){i=c[2385590]|0;if((i|0)==0){bM=0;bN=bJ;bO=bK;bP=bL;break}j=gj[i&4095](l&65535)|0;bM=j;bN=b[4830406]|0;bO=c[2443666]|0;bP=c[3528996]|0}else{bM=a[k+(c[2385780]&l)|0]|0;bN=bJ;bO=bK;bP=bL}}while(0);a[9707464]=bM;b[4830406]=bN+2&65535;b[4853732]=(b[4853732]|0)+(d[9660821]|0)&65535;l=c[2426866]&65535&bO;k=c[9702704+(l>>>(bP>>>0)<<2)>>2]|0;do{if((k|0)==0){j=c[2385590]|0;if((j|0)==0){bQ=0;break}bQ=gj[j&4095](l&65535)|0}else{bQ=a[k+(c[2385780]&l)|0]|0}}while(0);l=(d[9660820]|0)-(bQ&255)&65535;k=((l&65535)>>>5&4|a[9660822]&-8&255)&255;a[9660822]=(((l&255)<<24>>24==0?k|2:k)&255|(l&65535)>>>8&1)&255;break};case 210:{c[2426866]=0;l=b[4830406]|0;k=c[2443666]|0;j=c[3528996]|0;i=c[9702704+((k&(l&65535))>>>(j>>>0)<<2)>>2]|0;do{if((i|0)==0){r=c[2385590]|0;if((r|0)==0){bR=0;bS=l;bT=k;bU=j;break}m=gj[r&4095](k&(l&65535)&65535)|0;bR=m;bS=b[4830406]|0;bT=c[2443666]|0;bU=c[3528996]|0}else{bR=a[i+(c[2385780]&(k&(l&65535)))|0]|0;bS=l;bT=k;bU=j}}while(0);a[9707465]=bR;j=bS+1&65535&bT;k=c[9702704+(j>>>(bU>>>0)<<2)>>2]|0;do{if((k|0)==0){l=c[2385590]|0;if((l|0)==0){bV=0;bW=bS;bX=bT;bY=bU;break}i=gj[l&4095](j&65535)|0;bV=i;bW=b[4830406]|0;bX=c[2443666]|0;bY=c[3528996]|0}else{bV=a[k+(c[2385780]&j)|0]|0;bW=bS;bX=bT;bY=bU}}while(0);a[9707464]=bV;b[4830406]=bW+2&65535;b[4853732]=(b[4853732]|0)+(d[9660821]|0)&65535;j=c[2426866]&65535&bX;k=c[9702704+(j>>>(bY>>>0)<<2)>>2]|0;do{if((k|0)==0){i=c[2385590]|0;if((i|0)==0){bZ=0;break}bZ=gj[i&4095](j&65535)|0}else{bZ=a[k+(c[2385780]&j)|0]|0}}while(0);j=a[9660822]|0;k=(d[9660820]|0)-(bZ&255)-(j&1)|0;a[9660822]=(((k&255)<<24>>24==0?(k>>>5&4|j&-8&255)&255|2:(k>>>5&4|j&-8&255)&255)&255|k>>>8&1)&255;a[9660820]=k&255;break};case 211:{c[2426866]=0;k=b[4830406]|0;j=c[2443666]|0;i=c[3528996]|0;l=c[9702704+((j&(k&65535))>>>(i>>>0)<<2)>>2]|0;do{if((l|0)==0){m=c[2385590]|0;if((m|0)==0){b_=0;b$=k;b0=j;b1=i;break}r=gj[m&4095](j&(k&65535)&65535)|0;b_=r;b$=b[4830406]|0;b0=c[2443666]|0;b1=c[3528996]|0}else{b_=a[l+(c[2385780]&(j&(k&65535)))|0]|0;b$=k;b0=j;b1=i}}while(0);a[9707465]=b_;i=b$+1&65535&b0;j=c[9702704+(i>>>(b1>>>0)<<2)>>2]|0;do{if((j|0)==0){k=c[2385590]|0;if((k|0)==0){b2=0;b3=b$;b4=b0;b5=b1;break}l=gj[k&4095](i&65535)|0;b2=l;b3=b[4830406]|0;b4=c[2443666]|0;b5=c[3528996]|0}else{b2=a[j+(c[2385780]&i)|0]|0;b3=b$;b4=b0;b5=b1}}while(0);a[9707464]=b2;b[4830406]=b3+2&65535;i=a[9660821]|0;b[4853732]=(b[4853732]|0)+(i&255)&65535;j=c[2426866]&65535&b4;l=c[9702704+(j>>>(b5>>>0)<<2)>>2]|0;do{if((l|0)==0){k=c[2385590]|0;if((k|0)==0){b6=0;b7=i;break}r=gj[k&4095](j&65535)|0;b6=r;b7=a[9660821]|0}else{b6=a[l+(c[2385780]&j)|0]|0;b7=i}}while(0);i=(b7&255)-(b6&255)&65535;j=((i&65535)>>>5&4|a[9660822]&-8&255)&255;a[9660822]=(((i&255)<<24>>24==0?j|2:j)&255|(i&65535)>>>8&1)&255;break};case 212:{c[2426866]=0;i=b[4830406]|0;j=c[2443666]|0;l=c[3528996]|0;r=c[9702704+((j&(i&65535))>>>(l>>>0)<<2)>>2]|0;do{if((r|0)==0){k=c[2385590]|0;if((k|0)==0){b8=0;b9=i;ca=j;cb=l;break}m=gj[k&4095](j&(i&65535)&65535)|0;b8=m;b9=b[4830406]|0;ca=c[2443666]|0;cb=c[3528996]|0}else{b8=a[r+(c[2385780]&(j&(i&65535)))|0]|0;b9=i;ca=j;cb=l}}while(0);a[9707465]=b8;l=b9+1&65535&ca;j=c[9702704+(l>>>(cb>>>0)<<2)>>2]|0;do{if((j|0)==0){i=c[2385590]|0;if((i|0)==0){cc=0;cd=b9;ce=ca;cf=cb;break}r=gj[i&4095](l&65535)|0;cc=r;cd=b[4830406]|0;ce=c[2443666]|0;cf=c[3528996]|0}else{cc=a[j+(c[2385780]&l)|0]|0;cd=b9;ce=ca;cf=cb}}while(0);a[9707464]=cc;b[4830406]=cd+2&65535;b[4853732]=(b[4853732]|0)+(d[9660821]|0)&65535;l=c[2426866]&65535&ce;j=c[9702704+(l>>>(cf>>>0)<<2)>>2]|0;do{if((j|0)==0){r=c[2385590]|0;if((r|0)==0){cg=0;break}cg=gj[r&4095](l&65535)|0}else{cg=a[j+(c[2385780]&l)|0]|0}}while(0);l=a[9660820]&cg;a[9660820]=l;j=(l&255)>>>5&4|a[9660822]&-7;a[9660822]=l<<24>>24==0?j|2:j;break};default:{g=1}}}if(g){g=0;switch(h|0){case 213:{c[2426866]=0;j=b[4830406]|0;l=c[2443666]|0;r=c[3528996]|0;i=c[9702704+((l&(j&65535))>>>(r>>>0)<<2)>>2]|0;do{if((i|0)==0){m=c[2385590]|0;if((m|0)==0){ch=0;ci=j;cj=l;ck=r;break}k=gj[m&4095](l&(j&65535)&65535)|0;ch=k;ci=b[4830406]|0;cj=c[2443666]|0;ck=c[3528996]|0}else{ch=a[i+(c[2385780]&(l&(j&65535)))|0]|0;ci=j;cj=l;ck=r}}while(0);a[9707465]=ch;r=ci+1&65535&cj;l=c[9702704+(r>>>(ck>>>0)<<2)>>2]|0;do{if((l|0)==0){j=c[2385590]|0;if((j|0)==0){cl=0;cm=ci;cn=cj;co=ck;break}i=gj[j&4095](r&65535)|0;cl=i;cm=b[4830406]|0;cn=c[2443666]|0;co=c[3528996]|0}else{cl=a[l+(c[2385780]&r)|0]|0;cm=ci;cn=cj;co=ck}}while(0);a[9707464]=cl;b[4830406]=cm+2&65535;b[4853732]=(b[4853732]|0)+(d[9660821]|0)&65535;r=c[2426866]&65535&cn;l=c[9702704+(r>>>(co>>>0)<<2)>>2]|0;do{if((l|0)==0){i=c[2385590]|0;if((i|0)==0){cp=0;break}cp=gj[i&4095](r&65535)|0}else{cp=a[l+(c[2385780]&r)|0]|0}}while(0);r=a[9660820]&cp;l=(r&255)>>>5&4|a[9660822]&-7;a[9660822]=r<<24>>24==0?l|2:l;break};case 214:{c[2426866]=0;l=b[4830406]|0;r=c[2443666]|0;i=c[3528996]|0;j=c[9702704+((r&(l&65535))>>>(i>>>0)<<2)>>2]|0;do{if((j|0)==0){k=c[2385590]|0;if((k|0)==0){cq=0;cr=l;cs=r;ct=i;break}m=gj[k&4095](r&(l&65535)&65535)|0;cq=m;cr=b[4830406]|0;cs=c[2443666]|0;ct=c[3528996]|0}else{cq=a[j+(c[2385780]&(r&(l&65535)))|0]|0;cr=l;cs=r;ct=i}}while(0);a[9707465]=cq;i=cr+1&65535&cs;r=c[9702704+(i>>>(ct>>>0)<<2)>>2]|0;do{if((r|0)==0){l=c[2385590]|0;if((l|0)==0){cu=0;cv=cr;cw=cs;cx=ct;break}j=gj[l&4095](i&65535)|0;cu=j;cv=b[4830406]|0;cw=c[2443666]|0;cx=c[3528996]|0}else{cu=a[r+(c[2385780]&i)|0]|0;cv=cr;cw=cs;cx=ct}}while(0);a[9707464]=cu;b[4830406]=cv+2&65535;b[4853732]=(b[4853732]|0)+(d[9660821]|0)&65535;i=c[2426866]&65535&cw;r=c[9702704+(i>>>(cx>>>0)<<2)>>2]|0;do{if((r|0)==0){j=c[2385590]|0;if((j|0)==0){cy=0;break}cy=gj[j&4095](i&65535)|0}else{cy=a[r+(c[2385780]&i)|0]|0}}while(0);a[9660820]=cy;i=(cy&255)>>>5&4|a[9660822]&-7;a[9660822]=cy<<24>>24==0?i|2:i;break};case 215:{i=a[9660820]|0;r=(i&255)>>>5&4|a[9660822]&-7;a[9660822]=i<<24>>24==0?r|2:r;c[2426866]=0;r=b[4830406]|0;i=c[2443666]|0;j=c[3528996]|0;l=c[9702704+((i&(r&65535))>>>(j>>>0)<<2)>>2]|0;do{if((l|0)==0){m=c[2385590]|0;if((m|0)==0){cz=0;cA=r;cB=i;cC=j;break}k=gj[m&4095](i&(r&65535)&65535)|0;cz=k;cA=b[4830406]|0;cB=c[2443666]|0;cC=c[3528996]|0}else{cz=a[l+(c[2385780]&(i&(r&65535)))|0]|0;cA=r;cB=i;cC=j}}while(0);a[9707465]=cz;j=cA+1&65535&cB;i=c[9702704+(j>>>(cC>>>0)<<2)>>2]|0;do{if((i|0)==0){r=c[2385590]|0;if((r|0)==0){cD=0;cE=cA;cF=cB;cG=cC;break}l=gj[r&4095](j&65535)|0;cD=l;cE=b[4830406]|0;cF=c[2443666]|0;cG=c[3528996]|0}else{cD=a[i+(c[2385780]&j)|0]|0;cE=cA;cF=cB;cG=cC}}while(0);a[9707464]=cD;b[4830406]=cE+2&65535;b[4853732]=(b[4853732]|0)+(d[9660821]|0)&65535;j=a[9660820]|0;i=c[2426866]&65535&cF;l=c[9703728+(i>>>(cG>>>0)<<2)>>2]|0;if((l|0)!=0){a[l+(c[2385780]&i)|0]=j;c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}l=c[3528586]|0;if((l|0)==0){c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}gg[l&4095](i&65535,j);break};case 216:{c[2426866]=0;j=b[4830406]|0;i=c[2443666]|0;l=c[3528996]|0;r=c[9702704+((i&(j&65535))>>>(l>>>0)<<2)>>2]|0;do{if((r|0)==0){k=c[2385590]|0;if((k|0)==0){cH=0;cI=j;cJ=i;cK=l;break}m=gj[k&4095](i&(j&65535)&65535)|0;cH=m;cI=b[4830406]|0;cJ=c[2443666]|0;cK=c[3528996]|0}else{cH=a[r+(c[2385780]&(i&(j&65535)))|0]|0;cI=j;cJ=i;cK=l}}while(0);a[9707465]=cH;l=cI+1&65535&cJ;i=c[9702704+(l>>>(cK>>>0)<<2)>>2]|0;do{if((i|0)==0){j=c[2385590]|0;if((j|0)==0){cL=0;cM=cI;cN=cJ;cO=cK;break}r=gj[j&4095](l&65535)|0;cL=r;cM=b[4830406]|0;cN=c[2443666]|0;cO=c[3528996]|0}else{cL=a[i+(c[2385780]&l)|0]|0;cM=cI;cN=cJ;cO=cK}}while(0);a[9707464]=cL;b[4830406]=cM+2&65535;b[4853732]=(b[4853732]|0)+(d[9660821]|0)&65535;l=c[2426866]&65535&cN;i=c[9702704+(l>>>(cO>>>0)<<2)>>2]|0;do{if((i|0)==0){r=c[2385590]|0;if((r|0)==0){cP=0;break}cP=gj[r&4095](l&65535)|0}else{cP=a[i+(c[2385780]&l)|0]|0}}while(0);l=a[9660820]|0;i=l^cP;a[9660820]=i;r=(i&255)>>>5&4|a[9660822]&-7;a[9660822]=l<<24>>24==cP<<24>>24?r|2:r;break};case 217:{c[2426866]=0;r=b[4830406]|0;l=c[2443666]|0;i=c[3528996]|0;j=c[9702704+((l&(r&65535))>>>(i>>>0)<<2)>>2]|0;do{if((j|0)==0){m=c[2385590]|0;if((m|0)==0){cQ=0;cR=r;cS=l;cT=i;break}k=gj[m&4095](l&(r&65535)&65535)|0;cQ=k;cR=b[4830406]|0;cS=c[2443666]|0;cT=c[3528996]|0}else{cQ=a[j+(c[2385780]&(l&(r&65535)))|0]|0;cR=r;cS=l;cT=i}}while(0);a[9707465]=cQ;i=cR+1&65535&cS;l=c[9702704+(i>>>(cT>>>0)<<2)>>2]|0;do{if((l|0)==0){r=c[2385590]|0;if((r|0)==0){cU=0;cV=cR;cW=cS;cX=cT;break}j=gj[r&4095](i&65535)|0;cU=j;cV=b[4830406]|0;cW=c[2443666]|0;cX=c[3528996]|0}else{cU=a[l+(c[2385780]&i)|0]|0;cV=cR;cW=cS;cX=cT}}while(0);a[9707464]=cU;b[4830406]=cV+2&65535;b[4853732]=(b[4853732]|0)+(d[9660821]|0)&65535;i=c[2426866]&65535&cW;l=c[9702704+(i>>>(cX>>>0)<<2)>>2]|0;do{if((l|0)==0){j=c[2385590]|0;if((j|0)==0){cY=0;break}cY=gj[j&4095](i&65535)|0}else{cY=a[l+(c[2385780]&i)|0]|0}}while(0);i=a[9660820]|0;l=a[9660822]|0;j=(i&255)+(cY&255)+(l&1)|0;a[9660822]=((j^(i^cY)&255)&16|j>>>8&1|((j&255)<<24>>24==0?(j>>>5&4|l&-24&255)&255|2:(j>>>5&4|l&-24&255)&255)&255)&255;a[9660820]=j&255;break};case 218:{c[2426866]=0;j=b[4830406]|0;l=c[2443666]|0;i=c[3528996]|0;r=c[9702704+((l&(j&65535))>>>(i>>>0)<<2)>>2]|0;do{if((r|0)==0){k=c[2385590]|0;if((k|0)==0){cZ=0;c_=j;c$=l;c0=i;break}m=gj[k&4095](l&(j&65535)&65535)|0;cZ=m;c_=b[4830406]|0;c$=c[2443666]|0;c0=c[3528996]|0}else{cZ=a[r+(c[2385780]&(l&(j&65535)))|0]|0;c_=j;c$=l;c0=i}}while(0);a[9707465]=cZ;i=c_+1&65535&c$;l=c[9702704+(i>>>(c0>>>0)<<2)>>2]|0;do{if((l|0)==0){j=c[2385590]|0;if((j|0)==0){c1=0;c2=c_;c3=c$;c4=c0;break}r=gj[j&4095](i&65535)|0;c1=r;c2=b[4830406]|0;c3=c[2443666]|0;c4=c[3528996]|0}else{c1=a[l+(c[2385780]&i)|0]|0;c2=c_;c3=c$;c4=c0}}while(0);a[9707464]=c1;b[4830406]=c2+2&65535;b[4853732]=(b[4853732]|0)+(d[9660821]|0)&65535;i=c[2426866]&65535&c3;l=c[9702704+(i>>>(c4>>>0)<<2)>>2]|0;do{if((l|0)==0){r=c[2385590]|0;if((r|0)==0){c5=0;break}c5=gj[r&4095](i&65535)|0}else{c5=a[l+(c[2385780]&i)|0]|0}}while(0);i=a[9660820]|c5;a[9660820]=i;l=(i&255)>>>5&4|a[9660822]&-7;a[9660822]=i<<24>>24==0?l|2:l;break};case 219:{c[2426866]=0;l=b[4830406]|0;i=c[2443666]|0;r=c[3528996]|0;j=c[9702704+((i&(l&65535))>>>(r>>>0)<<2)>>2]|0;do{if((j|0)==0){m=c[2385590]|0;if((m|0)==0){c6=0;c7=l;c8=i;c9=r;break}k=gj[m&4095](i&(l&65535)&65535)|0;c6=k;c7=b[4830406]|0;c8=c[2443666]|0;c9=c[3528996]|0}else{c6=a[j+(c[2385780]&(i&(l&65535)))|0]|0;c7=l;c8=i;c9=r}}while(0);a[9707465]=c6;r=c7+1&65535&c8;i=c[9702704+(r>>>(c9>>>0)<<2)>>2]|0;do{if((i|0)==0){l=c[2385590]|0;if((l|0)==0){da=0;db=c7;dc=c8;dd=c9;break}j=gj[l&4095](r&65535)|0;da=j;db=b[4830406]|0;dc=c[2443666]|0;dd=c[3528996]|0}else{da=a[i+(c[2385780]&r)|0]|0;db=c7;dc=c8;dd=c9}}while(0);a[9707464]=da;b[4830406]=db+2&65535;b[4853732]=(b[4853732]|0)+(d[9660821]|0)&65535;r=c[2426866]&65535&dc;i=c[9702704+(r>>>(dd>>>0)<<2)>>2]|0;do{if((i|0)==0){j=c[2385590]|0;if((j|0)==0){de=0;break}de=gj[j&4095](r&65535)|0}else{de=a[i+(c[2385780]&r)|0]|0}}while(0);r=a[9660820]|0;i=(r&255)+(de&255)|0;j=(i>>>5&4|a[9660822]&-24&255)&255;a[9660822]=(((r^de)&255^i)&16|i>>>8&1|((i&255)<<24>>24==0?j|2:j)&255)&255;a[9660820]=i&255;break};case 220:{c[2426866]=0;i=b[4830406]|0;j=c[2443666]|0;r=c[3528996]|0;l=c[9702704+((j&(i&65535))>>>(r>>>0)<<2)>>2]|0;do{if((l|0)==0){k=c[2385590]|0;if((k|0)==0){df=0;dg=i;dh=j;di=r;break}m=gj[k&4095](j&(i&65535)&65535)|0;df=m;dg=b[4830406]|0;dh=c[2443666]|0;di=c[3528996]|0}else{df=a[l+(c[2385780]&(j&(i&65535)))|0]|0;dg=i;dh=j;di=r}}while(0);a[9707465]=df;r=dg+1&65535&dh;j=c[9702704+(r>>>(di>>>0)<<2)>>2]|0;do{if((j|0)==0){i=c[2385590]|0;if((i|0)==0){dj=0;break}dj=gj[i&4095](r&65535)|0}else{dj=a[j+(c[2385780]&r)|0]|0}}while(0);a[9707464]=dj;r=(b[4853732]|0)+(d[9660821]|0)&65535;b[4853732]=r;b[4830406]=r;break};case 221:{c[2426866]=0;r=b[4830406]|0;j=c[2443666]|0;i=c[3528996]|0;l=c[9702704+((j&(r&65535))>>>(i>>>0)<<2)>>2]|0;do{if((l|0)==0){m=c[2385590]|0;if((m|0)==0){dk=0;dl=r;dm=j;dn=i;break}k=gj[m&4095](j&(r&65535)&65535)|0;dk=k;dl=b[4830406]|0;dm=c[2443666]|0;dn=c[3528996]|0}else{dk=a[l+(c[2385780]&(j&(r&65535)))|0]|0;dl=r;dm=j;dn=i}}while(0);a[9707465]=dk;i=dl+1&65535&dm;j=c[9702704+(i>>>(dn>>>0)<<2)>>2]|0;do{if((j|0)==0){r=c[2385590]|0;if((r|0)==0){dp=0;dq=dl;dr=dm;ds=dn;break}l=gj[r&4095](i&65535)|0;dp=l;dq=b[4830406]|0;dr=c[2443666]|0;ds=c[3528996]|0}else{dp=a[j+(c[2385780]&i)|0]|0;dq=dl;dr=dm;ds=dn}}while(0);a[9707464]=dp;i=dq+2&65535;b[4830406]=i;b[4853732]=(b[4853732]|0)+(d[9660821]|0)&65535;j=dr&(e[4830408]|0);l=c[9703728+(j>>>(ds>>>0)<<2)>>2]|0;do{if((l|0)==0){r=c[3528586]|0;if((r|0)==0){break}gg[r&4095](j&65535,i&255)}else{a[l+(c[2385780]&j)|0]=i&255}}while(0);i=(b[4830408]|0)-1&65535;b[4830408]=i;if((i&65535)>>>0<(c[2415202]|0)>>>0){j=c[2415201]&65535;b[4830408]=j;dt=j}else{dt=i}i=a[9660813]|0;j=c[2443666]&(dt&65535);l=c[9703728+(j>>>((c[3528996]|0)>>>0)<<2)>>2]|0;do{if((l|0)==0){r=c[3528586]|0;if((r|0)==0){break}gg[r&4095](j&65535,i)}else{a[l+(c[2385780]&j)|0]=i}}while(0);i=(b[4830408]|0)-1&65535;b[4830408]=i;if((i&65535)>>>0<(c[2415202]|0)>>>0){b[4830408]=c[2415201]&65535}b[4830406]=b[4853732]|0;break};case 222:{c[2426866]=0;i=b[4830406]|0;j=c[2443666]|0;l=c[3528996]|0;r=c[9702704+((j&(i&65535))>>>(l>>>0)<<2)>>2]|0;do{if((r|0)==0){k=c[2385590]|0;if((k|0)==0){du=0;dv=i;dw=j;dx=l;break}m=gj[k&4095](j&(i&65535)&65535)|0;du=m;dv=b[4830406]|0;dw=c[2443666]|0;dx=c[3528996]|0}else{du=a[r+(c[2385780]&(j&(i&65535)))|0]|0;dv=i;dw=j;dx=l}}while(0);a[9707465]=du;l=dv+1&65535&dw;j=c[9702704+(l>>>(dx>>>0)<<2)>>2]|0;do{if((j|0)==0){i=c[2385590]|0;if((i|0)==0){dy=0;dz=dv;dA=dw;dB=dx;break}r=gj[i&4095](l&65535)|0;dy=r;dz=b[4830406]|0;dA=c[2443666]|0;dB=c[3528996]|0}else{dy=a[j+(c[2385780]&l)|0]|0;dz=dv;dA=dw;dB=dx}}while(0);a[9707464]=dy;b[4830406]=dz+2&65535;b[4853732]=(b[4853732]|0)+(d[9660821]|0)&65535;l=c[2426866]&65535&dA;j=c[9702704+(l>>>(dB>>>0)<<2)>>2]|0;do{if((j|0)==0){r=c[2385590]|0;if((r|0)==0){dC=0;break}dC=gj[r&4095](l&65535)|0}else{dC=a[j+(c[2385780]&l)|0]|0}}while(0);a[9660821]=dC;l=(dC&255)>>>5&4|a[9660822]&-7;a[9660822]=dC<<24>>24==0?l|2:l;break};case 223:{l=a[9660821]|0;j=(l&255)>>>5&4|a[9660822]&-7;a[9660822]=l<<24>>24==0?j|2:j;c[2426866]=0;j=b[4830406]|0;l=c[2443666]|0;r=c[3528996]|0;i=c[9702704+((l&(j&65535))>>>(r>>>0)<<2)>>2]|0;do{if((i|0)==0){m=c[2385590]|0;if((m|0)==0){dD=0;dE=j;dF=l;dG=r;break}k=gj[m&4095](l&(j&65535)&65535)|0;dD=k;dE=b[4830406]|0;dF=c[2443666]|0;dG=c[3528996]|0}else{dD=a[i+(c[2385780]&(l&(j&65535)))|0]|0;dE=j;dF=l;dG=r}}while(0);a[9707465]=dD;r=dE+1&65535&dF;l=c[9702704+(r>>>(dG>>>0)<<2)>>2]|0;do{if((l|0)==0){j=c[2385590]|0;if((j|0)==0){dH=0;dI=dE;dJ=dF;dK=dG;break}i=gj[j&4095](r&65535)|0;dH=i;dI=b[4830406]|0;dJ=c[2443666]|0;dK=c[3528996]|0}else{dH=a[l+(c[2385780]&r)|0]|0;dI=dE;dJ=dF;dK=dG}}while(0);a[9707464]=dH;b[4830406]=dI+2&65535;r=a[9660821]|0;b[4853732]=(b[4853732]|0)+(r&255)&65535;l=c[2426866]&65535&dJ;i=c[9703728+(l>>>(dK>>>0)<<2)>>2]|0;if((i|0)!=0){a[i+(c[2385780]&l)|0]=r;c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}i=c[3528586]|0;if((i|0)==0){c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}gg[i&4095](l&65535,r);break};case 224:{c[2426866]=0;r=b[4830406]|0;b[4830406]=r+1&65535;l=c[2443666]|0;i=c[3528996]|0;j=c[9702704+((l&(r&65535))>>>(i>>>0)<<2)>>2]|0;do{if((j|0)==0){k=c[2385590]|0;if((k|0)==0){dL=0;dM=l;dN=i;break}m=gj[k&4095](l&(r&65535)&65535)|0;dL=m;dM=c[2443666]|0;dN=c[3528996]|0}else{dL=a[j+(c[2385780]&(l&(r&65535)))|0]|0;dM=l;dN=i}}while(0);a[9707464]=dL;b[4853732]=(b[4853732]|0)+(d[9660821]|0)&65535;i=c[2426866]&65535&dM;l=c[9702704+(i>>>(dN>>>0)<<2)>>2]|0;do{if((l|0)==0){r=c[2385590]|0;if((r|0)==0){dO=0;break}dO=gj[r&4095](i&65535)|0}else{dO=a[l+(c[2385780]&i)|0]|0}}while(0);i=(d[9660820]|0)-(dO&255)&65535;l=((i&65535)>>>5&4|a[9660822]&-8&255)&255;a[9660822]=(((i&255)<<24>>24==0?l|2:l)&255|(i&65535)>>>8&1)&255;a[9660820]=i&255;break};case 225:{c[2426866]=0;i=b[4830406]|0;b[4830406]=i+1&65535;l=c[2443666]|0;r=c[3528996]|0;j=c[9702704+((l&(i&65535))>>>(r>>>0)<<2)>>2]|0;do{if((j|0)==0){m=c[2385590]|0;if((m|0)==0){dP=0;dQ=l;dR=r;break}k=gj[m&4095](l&(i&65535)&65535)|0;dP=k;dQ=c[2443666]|0;dR=c[3528996]|0}else{dP=a[j+(c[2385780]&(l&(i&65535)))|0]|0;dQ=l;dR=r}}while(0);a[9707464]=dP;b[4853732]=(b[4853732]|0)+(d[9660821]|0)&65535;r=c[2426866]&65535&dQ;l=c[9702704+(r>>>(dR>>>0)<<2)>>2]|0;do{if((l|0)==0){i=c[2385590]|0;if((i|0)==0){dS=0;break}dS=gj[i&4095](r&65535)|0}else{dS=a[l+(c[2385780]&r)|0]|0}}while(0);r=(d[9660820]|0)-(dS&255)&65535;l=((r&65535)>>>5&4|a[9660822]&-8&255)&255;a[9660822]=(((r&255)<<24>>24==0?l|2:l)&255|(r&65535)>>>8&1)&255;break};case 226:{c[2426866]=0;r=b[4830406]|0;b[4830406]=r+1&65535;l=c[2443666]|0;i=c[3528996]|0;j=c[9702704+((l&(r&65535))>>>(i>>>0)<<2)>>2]|0;do{if((j|0)==0){k=c[2385590]|0;if((k|0)==0){dT=0;dU=l;dV=i;break}m=gj[k&4095](l&(r&65535)&65535)|0;dT=m;dU=c[2443666]|0;dV=c[3528996]|0}else{dT=a[j+(c[2385780]&(l&(r&65535)))|0]|0;dU=l;dV=i}}while(0);a[9707464]=dT;b[4853732]=(b[4853732]|0)+(d[9660821]|0)&65535;i=c[2426866]&65535&dU;l=c[9702704+(i>>>(dV>>>0)<<2)>>2]|0;do{if((l|0)==0){r=c[2385590]|0;if((r|0)==0){dW=0;break}dW=gj[r&4095](i&65535)|0}else{dW=a[l+(c[2385780]&i)|0]|0}}while(0);i=a[9660822]|0;l=(d[9660820]|0)-(dW&255)-(i&1)|0;a[9660822]=(((l&255)<<24>>24==0?(l>>>5&4|i&-8&255)&255|2:(l>>>5&4|i&-8&255)&255)&255|l>>>8&1)&255;a[9660820]=l&255;break};case 227:{c[2426866]=0;l=b[4830406]|0;b[4830406]=l+1&65535;i=c[2443666]|0;r=c[3528996]|0;j=c[9702704+((i&(l&65535))>>>(r>>>0)<<2)>>2]|0;do{if((j|0)==0){m=c[2385590]|0;if((m|0)==0){dX=0;dY=i;dZ=r;break}k=gj[m&4095](i&(l&65535)&65535)|0;dX=k;dY=c[2443666]|0;dZ=c[3528996]|0}else{dX=a[j+(c[2385780]&(i&(l&65535)))|0]|0;dY=i;dZ=r}}while(0);a[9707464]=dX;r=a[9660821]|0;b[4853732]=(b[4853732]|0)+(r&255)&65535;i=c[2426866]&65535&dY;l=c[9702704+(i>>>(dZ>>>0)<<2)>>2]|0;do{if((l|0)==0){j=c[2385590]|0;if((j|0)==0){d_=0;d$=r;break}k=gj[j&4095](i&65535)|0;d_=k;d$=a[9660821]|0}else{d_=a[l+(c[2385780]&i)|0]|0;d$=r}}while(0);r=(d$&255)-(d_&255)&65535;i=((r&65535)>>>5&4|a[9660822]&-8&255)&255;a[9660822]=(((r&255)<<24>>24==0?i|2:i)&255|(r&65535)>>>8&1)&255;break};case 228:{c[2426866]=0;r=b[4830406]|0;b[4830406]=r+1&65535;i=c[2443666]|0;l=c[3528996]|0;k=c[9702704+((i&(r&65535))>>>(l>>>0)<<2)>>2]|0;do{if((k|0)==0){j=c[2385590]|0;if((j|0)==0){d0=0;d1=i;d2=l;break}m=gj[j&4095](i&(r&65535)&65535)|0;d0=m;d1=c[2443666]|0;d2=c[3528996]|0}else{d0=a[k+(c[2385780]&(i&(r&65535)))|0]|0;d1=i;d2=l}}while(0);a[9707464]=d0;b[4853732]=(b[4853732]|0)+(d[9660821]|0)&65535;l=c[2426866]&65535&d1;i=c[9702704+(l>>>(d2>>>0)<<2)>>2]|0;do{if((i|0)==0){r=c[2385590]|0;if((r|0)==0){d3=0;break}d3=gj[r&4095](l&65535)|0}else{d3=a[i+(c[2385780]&l)|0]|0}}while(0);l=a[9660820]&d3;a[9660820]=l;i=(l&255)>>>5&4|a[9660822]&-7;a[9660822]=l<<24>>24==0?i|2:i;break};case 229:{c[2426866]=0;i=b[4830406]|0;b[4830406]=i+1&65535;l=c[2443666]|0;r=c[3528996]|0;k=c[9702704+((l&(i&65535))>>>(r>>>0)<<2)>>2]|0;do{if((k|0)==0){m=c[2385590]|0;if((m|0)==0){d4=0;d5=l;d6=r;break}j=gj[m&4095](l&(i&65535)&65535)|0;d4=j;d5=c[2443666]|0;d6=c[3528996]|0}else{d4=a[k+(c[2385780]&(l&(i&65535)))|0]|0;d5=l;d6=r}}while(0);a[9707464]=d4;b[4853732]=(b[4853732]|0)+(d[9660821]|0)&65535;r=c[2426866]&65535&d5;l=c[9702704+(r>>>(d6>>>0)<<2)>>2]|0;do{if((l|0)==0){i=c[2385590]|0;if((i|0)==0){d7=0;break}d7=gj[i&4095](r&65535)|0}else{d7=a[l+(c[2385780]&r)|0]|0}}while(0);r=a[9660820]&d7;l=(r&255)>>>5&4|a[9660822]&-7;a[9660822]=r<<24>>24==0?l|2:l;break};case 230:{c[2426866]=0;l=b[4830406]|0;b[4830406]=l+1&65535;r=c[2443666]|0;i=c[3528996]|0;k=c[9702704+((r&(l&65535))>>>(i>>>0)<<2)>>2]|0;do{if((k|0)==0){j=c[2385590]|0;if((j|0)==0){d8=0;d9=r;ea=i;break}m=gj[j&4095](r&(l&65535)&65535)|0;d8=m;d9=c[2443666]|0;ea=c[3528996]|0}else{d8=a[k+(c[2385780]&(r&(l&65535)))|0]|0;d9=r;ea=i}}while(0);a[9707464]=d8;b[4853732]=(b[4853732]|0)+(d[9660821]|0)&65535;i=c[2426866]&65535&d9;r=c[9702704+(i>>>(ea>>>0)<<2)>>2]|0;do{if((r|0)==0){l=c[2385590]|0;if((l|0)==0){eb=0;break}eb=gj[l&4095](i&65535)|0}else{eb=a[r+(c[2385780]&i)|0]|0}}while(0);a[9660820]=eb;i=(eb&255)>>>5&4|a[9660822]&-7;a[9660822]=eb<<24>>24==0?i|2:i;break};case 231:{i=a[9660820]|0;r=(i&255)>>>5&4|a[9660822]&-7;a[9660822]=i<<24>>24==0?r|2:r;c[2426866]=0;r=b[4830406]|0;b[4830406]=r+1&65535;l=c[2443666]|0;k=c[3528996]|0;m=c[9702704+((l&(r&65535))>>>(k>>>0)<<2)>>2]|0;do{if((m|0)==0){j=c[2385590]|0;if((j|0)==0){ec=0;ed=i;ee=l;ef=k;break}eg=gj[j&4095](l&(r&65535)&65535)|0;ec=eg;ed=a[9660820]|0;ee=c[2443666]|0;ef=c[3528996]|0}else{ec=a[m+(c[2385780]&(l&(r&65535)))|0]|0;ed=i;ee=l;ef=k}}while(0);a[9707464]=ec;b[4853732]=(b[4853732]|0)+(d[9660821]|0)&65535;k=c[2426866]&65535&ee;l=c[9703728+(k>>>(ef>>>0)<<2)>>2]|0;if((l|0)!=0){a[l+(c[2385780]&k)|0]=ed;c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}l=c[3528586]|0;if((l|0)==0){c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}gg[l&4095](k&65535,ed);break};case 232:{c[2426866]=0;k=b[4830406]|0;b[4830406]=k+1&65535;l=c[2443666]|0;i=c[3528996]|0;r=c[9702704+((l&(k&65535))>>>(i>>>0)<<2)>>2]|0;do{if((r|0)==0){m=c[2385590]|0;if((m|0)==0){eh=0;ei=l;ej=i;break}eg=gj[m&4095](l&(k&65535)&65535)|0;eh=eg;ei=c[2443666]|0;ej=c[3528996]|0}else{eh=a[r+(c[2385780]&(l&(k&65535)))|0]|0;ei=l;ej=i}}while(0);a[9707464]=eh;b[4853732]=(b[4853732]|0)+(d[9660821]|0)&65535;i=c[2426866]&65535&ei;l=c[9702704+(i>>>(ej>>>0)<<2)>>2]|0;do{if((l|0)==0){k=c[2385590]|0;if((k|0)==0){ek=0;break}ek=gj[k&4095](i&65535)|0}else{ek=a[l+(c[2385780]&i)|0]|0}}while(0);i=a[9660820]|0;l=i^ek;a[9660820]=l;k=(l&255)>>>5&4|a[9660822]&-7;a[9660822]=i<<24>>24==ek<<24>>24?k|2:k;break};case 233:{c[2426866]=0;k=b[4830406]|0;b[4830406]=k+1&65535;i=c[2443666]|0;l=c[3528996]|0;r=c[9702704+((i&(k&65535))>>>(l>>>0)<<2)>>2]|0;do{if((r|0)==0){eg=c[2385590]|0;if((eg|0)==0){el=0;em=i;en=l;break}m=gj[eg&4095](i&(k&65535)&65535)|0;el=m;em=c[2443666]|0;en=c[3528996]|0}else{el=a[r+(c[2385780]&(i&(k&65535)))|0]|0;em=i;en=l}}while(0);a[9707464]=el;b[4853732]=(b[4853732]|0)+(d[9660821]|0)&65535;l=c[2426866]&65535&em;i=c[9702704+(l>>>(en>>>0)<<2)>>2]|0;do{if((i|0)==0){k=c[2385590]|0;if((k|0)==0){eo=0;break}eo=gj[k&4095](l&65535)|0}else{eo=a[i+(c[2385780]&l)|0]|0}}while(0);l=a[9660820]|0;i=a[9660822]|0;k=(l&255)+(eo&255)+(i&1)|0;a[9660822]=((k^(l^eo)&255)&16|k>>>8&1|((k&255)<<24>>24==0?(k>>>5&4|i&-24&255)&255|2:(k>>>5&4|i&-24&255)&255)&255)&255;a[9660820]=k&255;break};case 234:{c[2426866]=0;k=b[4830406]|0;b[4830406]=k+1&65535;i=c[2443666]|0;l=c[3528996]|0;r=c[9702704+((i&(k&65535))>>>(l>>>0)<<2)>>2]|0;do{if((r|0)==0){m=c[2385590]|0;if((m|0)==0){ep=0;eq=i;er=l;break}eg=gj[m&4095](i&(k&65535)&65535)|0;ep=eg;eq=c[2443666]|0;er=c[3528996]|0}else{ep=a[r+(c[2385780]&(i&(k&65535)))|0]|0;eq=i;er=l}}while(0);a[9707464]=ep;b[4853732]=(b[4853732]|0)+(d[9660821]|0)&65535;l=c[2426866]&65535&eq;i=c[9702704+(l>>>(er>>>0)<<2)>>2]|0;do{if((i|0)==0){k=c[2385590]|0;if((k|0)==0){es=0;break}es=gj[k&4095](l&65535)|0}else{es=a[i+(c[2385780]&l)|0]|0}}while(0);l=a[9660820]|es;a[9660820]=l;i=(l&255)>>>5&4|a[9660822]&-7;a[9660822]=l<<24>>24==0?i|2:i;break};case 235:{c[2426866]=0;i=b[4830406]|0;b[4830406]=i+1&65535;l=c[2443666]|0;k=c[3528996]|0;r=c[9702704+((l&(i&65535))>>>(k>>>0)<<2)>>2]|0;do{if((r|0)==0){eg=c[2385590]|0;if((eg|0)==0){et=0;eu=l;ev=k;break}m=gj[eg&4095](l&(i&65535)&65535)|0;et=m;eu=c[2443666]|0;ev=c[3528996]|0}else{et=a[r+(c[2385780]&(l&(i&65535)))|0]|0;eu=l;ev=k}}while(0);a[9707464]=et;b[4853732]=(b[4853732]|0)+(d[9660821]|0)&65535;k=c[2426866]&65535&eu;l=c[9702704+(k>>>(ev>>>0)<<2)>>2]|0;do{if((l|0)==0){i=c[2385590]|0;if((i|0)==0){ew=0;break}ew=gj[i&4095](k&65535)|0}else{ew=a[l+(c[2385780]&k)|0]|0}}while(0);k=a[9660820]|0;l=(k&255)+(ew&255)|0;i=(l>>>5&4|a[9660822]&-24&255)&255;a[9660822]=(((k^ew)&255^l)&16|l>>>8&1|((l&255)<<24>>24==0?i|2:i)&255)&255;a[9660820]=l&255;break};case 236:{c[2426866]=0;l=b[4830406]|0;b[4830406]=l+1&65535;i=c[2443666]&(l&65535);l=c[9702704+(i>>>((c[3528996]|0)>>>0)<<2)>>2]|0;do{if((l|0)==0){k=c[2385590]|0;if((k|0)==0){ex=0;break}ex=gj[k&4095](i&65535)|0}else{ex=a[l+(c[2385780]&i)|0]|0}}while(0);a[9707464]=ex;i=(b[4853732]|0)+(d[9660821]|0)&65535;b[4853732]=i;b[4830406]=i;break};default:{g=1}}}if(g){g=0;switch(h|0){case 237:{c[2426866]=0;i=b[4830406]|0;b[4830406]=i+1&65535;l=c[2443666]|0;k=c[3528996]|0;r=c[9702704+((l&(i&65535))>>>(k>>>0)<<2)>>2]|0;do{if((r|0)==0){m=c[2385590]|0;if((m|0)==0){ey=0;ez=i+1&65535&255;eA=l;eB=k;break}eg=gj[m&4095](l&(i&65535)&65535)|0;ey=eg;ez=a[9660812]|0;eA=c[2443666]|0;eB=c[3528996]|0}else{ey=a[r+(c[2385780]&(l&(i&65535)))|0]|0;ez=i+1&65535&255;eA=l;eB=k}}while(0);a[9707464]=ey;b[4853732]=(b[4853732]|0)+(d[9660821]|0)&65535;k=eA&(e[4830408]|0);l=c[9703728+(k>>>(eB>>>0)<<2)>>2]|0;do{if((l|0)==0){i=c[3528586]|0;if((i|0)==0){break}gg[i&4095](k&65535,ez)}else{a[l+(c[2385780]&k)|0]=ez}}while(0);k=(b[4830408]|0)-1&65535;b[4830408]=k;if((k&65535)>>>0<(c[2415202]|0)>>>0){l=c[2415201]&65535;b[4830408]=l;eC=l}else{eC=k}k=a[9660813]|0;l=c[2443666]&(eC&65535);i=c[9703728+(l>>>((c[3528996]|0)>>>0)<<2)>>2]|0;do{if((i|0)==0){r=c[3528586]|0;if((r|0)==0){break}gg[r&4095](l&65535,k)}else{a[i+(c[2385780]&l)|0]=k}}while(0);k=(b[4830408]|0)-1&65535;b[4830408]=k;if((k&65535)>>>0<(c[2415202]|0)>>>0){b[4830408]=c[2415201]&65535}b[4830406]=b[4853732]|0;break};case 238:{c[2426866]=0;k=b[4830406]|0;b[4830406]=k+1&65535;l=c[2443666]|0;i=c[3528996]|0;r=c[9702704+((l&(k&65535))>>>(i>>>0)<<2)>>2]|0;do{if((r|0)==0){eg=c[2385590]|0;if((eg|0)==0){eD=0;eE=l;eF=i;break}m=gj[eg&4095](l&(k&65535)&65535)|0;eD=m;eE=c[2443666]|0;eF=c[3528996]|0}else{eD=a[r+(c[2385780]&(l&(k&65535)))|0]|0;eE=l;eF=i}}while(0);a[9707464]=eD;b[4853732]=(b[4853732]|0)+(d[9660821]|0)&65535;i=c[2426866]&65535&eE;l=c[9702704+(i>>>(eF>>>0)<<2)>>2]|0;do{if((l|0)==0){k=c[2385590]|0;if((k|0)==0){eG=0;break}eG=gj[k&4095](i&65535)|0}else{eG=a[l+(c[2385780]&i)|0]|0}}while(0);a[9660821]=eG;i=(eG&255)>>>5&4|a[9660822]&-7;a[9660822]=eG<<24>>24==0?i|2:i;break};case 239:{i=a[9660821]|0;l=(i&255)>>>5&4|a[9660822]&-7;a[9660822]=i<<24>>24==0?l|2:l;c[2426866]=0;l=b[4830406]|0;b[4830406]=l+1&65535;k=c[2443666]|0;r=c[3528996]|0;m=c[9702704+((k&(l&65535))>>>(r>>>0)<<2)>>2]|0;do{if((m|0)==0){eg=c[2385590]|0;if((eg|0)==0){eH=0;eI=i;eJ=k;eK=r;break}j=gj[eg&4095](k&(l&65535)&65535)|0;eH=j;eI=a[9660821]|0;eJ=c[2443666]|0;eK=c[3528996]|0}else{eH=a[m+(c[2385780]&(k&(l&65535)))|0]|0;eI=i;eJ=k;eK=r}}while(0);a[9707464]=eH;b[4853732]=(b[4853732]|0)+(eI&255)&65535;r=c[2426866]&65535&eJ;k=c[9703728+(r>>>(eK>>>0)<<2)>>2]|0;if((k|0)!=0){a[k+(c[2385780]&r)|0]=eI;c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}k=c[3528586]|0;if((k|0)==0){c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}gg[k&4095](r&65535,eI);break};case 240:{b[4853732]=d[9660821]|0;r=c[2426866]&65535&c[2443666];k=c[9702704+(r>>>((c[3528996]|0)>>>0)<<2)>>2]|0;do{if((k|0)==0){i=c[2385590]|0;if((i|0)==0){eL=0;break}eL=gj[i&4095](r&65535)|0}else{eL=a[k+(c[2385780]&r)|0]|0}}while(0);r=(d[9660820]|0)-(eL&255)&65535;k=((r&65535)>>>5&4|a[9660822]&-8&255)&255;a[9660822]=(((r&255)<<24>>24==0?k|2:k)&255|(r&65535)>>>8&1)&255;a[9660820]=r&255;break};case 241:{b[4853732]=d[9660821]|0;r=c[2426866]&65535&c[2443666];k=c[9702704+(r>>>((c[3528996]|0)>>>0)<<2)>>2]|0;do{if((k|0)==0){i=c[2385590]|0;if((i|0)==0){eM=0;break}eM=gj[i&4095](r&65535)|0}else{eM=a[k+(c[2385780]&r)|0]|0}}while(0);r=(d[9660820]|0)-(eM&255)&65535;k=((r&65535)>>>5&4|a[9660822]&-8&255)&255;a[9660822]=(((r&255)<<24>>24==0?k|2:k)&255|(r&65535)>>>8&1)&255;break};case 242:{b[4853732]=d[9660821]|0;r=c[2426866]&65535&c[2443666];k=c[9702704+(r>>>((c[3528996]|0)>>>0)<<2)>>2]|0;do{if((k|0)==0){i=c[2385590]|0;if((i|0)==0){eN=0;break}eN=gj[i&4095](r&65535)|0}else{eN=a[k+(c[2385780]&r)|0]|0}}while(0);r=a[9660822]|0;k=(d[9660820]|0)-(eN&255)-(r&1)|0;a[9660822]=(((k&255)<<24>>24==0?(k>>>5&4|r&-8&255)&255|2:(k>>>5&4|r&-8&255)&255)&255|k>>>8&1)&255;a[9660820]=k&255;break};case 243:{k=a[9660821]|0;b[4853732]=k&255;r=c[2426866]&65535&c[2443666];i=c[9702704+(r>>>((c[3528996]|0)>>>0)<<2)>>2]|0;do{if((i|0)==0){l=c[2385590]|0;if((l|0)==0){eO=0;eP=k;break}m=gj[l&4095](r&65535)|0;eO=m;eP=a[9660821]|0}else{eO=a[i+(c[2385780]&r)|0]|0;eP=k}}while(0);k=(eP&255)-(eO&255)&65535;r=((k&65535)>>>5&4|a[9660822]&-8&255)&255;a[9660822]=(((k&255)<<24>>24==0?r|2:r)&255|(k&65535)>>>8&1)&255;break};case 244:{b[4853732]=d[9660821]|0;k=c[2426866]&65535&c[2443666];r=c[9702704+(k>>>((c[3528996]|0)>>>0)<<2)>>2]|0;do{if((r|0)==0){i=c[2385590]|0;if((i|0)==0){eQ=0;break}eQ=gj[i&4095](k&65535)|0}else{eQ=a[r+(c[2385780]&k)|0]|0}}while(0);k=a[9660820]&eQ;a[9660820]=k;r=(k&255)>>>5&4|a[9660822]&-7;a[9660822]=k<<24>>24==0?r|2:r;break};case 245:{b[4853732]=d[9660821]|0;r=c[2426866]&65535&c[2443666];k=c[9702704+(r>>>((c[3528996]|0)>>>0)<<2)>>2]|0;do{if((k|0)==0){i=c[2385590]|0;if((i|0)==0){eR=0;break}eR=gj[i&4095](r&65535)|0}else{eR=a[k+(c[2385780]&r)|0]|0}}while(0);r=a[9660820]&eR;k=(r&255)>>>5&4|a[9660822]&-7;a[9660822]=r<<24>>24==0?k|2:k;break};case 246:{b[4853732]=d[9660821]|0;k=c[2426866]&65535&c[2443666];r=c[9702704+(k>>>((c[3528996]|0)>>>0)<<2)>>2]|0;do{if((r|0)==0){i=c[2385590]|0;if((i|0)==0){eS=0;break}eS=gj[i&4095](k&65535)|0}else{eS=a[r+(c[2385780]&k)|0]|0}}while(0);a[9660820]=eS;k=(eS&255)>>>5&4|a[9660822]&-7;a[9660822]=eS<<24>>24==0?k|2:k;break};case 247:{k=a[9660820]|0;r=(k&255)>>>5&4|a[9660822]&-7;a[9660822]=k<<24>>24==0?r|2:r;b[4853732]=d[9660821]|0;r=c[2426866]&65535&c[2443666];i=c[9703728+(r>>>((c[3528996]|0)>>>0)<<2)>>2]|0;if((i|0)!=0){a[i+(c[2385780]&r)|0]=k;c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}i=c[3528586]|0;if((i|0)==0){c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}gg[i&4095](r&65535,k);break};case 248:{b[4853732]=d[9660821]|0;k=c[2426866]&65535&c[2443666];r=c[9702704+(k>>>((c[3528996]|0)>>>0)<<2)>>2]|0;do{if((r|0)==0){i=c[2385590]|0;if((i|0)==0){eT=0;break}eT=gj[i&4095](k&65535)|0}else{eT=a[r+(c[2385780]&k)|0]|0}}while(0);k=a[9660820]|0;r=k^eT;a[9660820]=r;i=(r&255)>>>5&4|a[9660822]&-7;a[9660822]=k<<24>>24==eT<<24>>24?i|2:i;break};case 249:{b[4853732]=d[9660821]|0;i=c[2426866]&65535&c[2443666];k=c[9702704+(i>>>((c[3528996]|0)>>>0)<<2)>>2]|0;do{if((k|0)==0){r=c[2385590]|0;if((r|0)==0){eU=0;break}eU=gj[r&4095](i&65535)|0}else{eU=a[k+(c[2385780]&i)|0]|0}}while(0);i=a[9660820]|0;k=a[9660822]|0;r=(i&255)+(eU&255)+(k&1)|0;a[9660822]=((r^(i^eU)&255)&16|r>>>8&1|((r&255)<<24>>24==0?(r>>>5&4|k&-24&255)&255|2:(r>>>5&4|k&-24&255)&255)&255)&255;a[9660820]=r&255;break};case 250:{b[4853732]=d[9660821]|0;r=c[2426866]&65535&c[2443666];k=c[9702704+(r>>>((c[3528996]|0)>>>0)<<2)>>2]|0;do{if((k|0)==0){i=c[2385590]|0;if((i|0)==0){eV=0;break}eV=gj[i&4095](r&65535)|0}else{eV=a[k+(c[2385780]&r)|0]|0}}while(0);r=a[9660820]|eV;a[9660820]=r;k=(r&255)>>>5&4|a[9660822]&-7;a[9660822]=r<<24>>24==0?k|2:k;break};case 251:{b[4853732]=d[9660821]|0;k=c[2426866]&65535&c[2443666];r=c[9702704+(k>>>((c[3528996]|0)>>>0)<<2)>>2]|0;do{if((r|0)==0){i=c[2385590]|0;if((i|0)==0){eW=0;break}eW=gj[i&4095](k&65535)|0}else{eW=a[r+(c[2385780]&k)|0]|0}}while(0);k=a[9660820]|0;r=(k&255)+(eW&255)|0;i=(r>>>5&4|a[9660822]&-24&255)&255;a[9660822]=(((k^eW)&255^r)&16|r>>>8&1|((r&255)<<24>>24==0?i|2:i)&255)&255;a[9660820]=r&255;break};case 252:{r=d[9660821]|0;b[4853732]=r;b[4830406]=r;break};case 253:{b[4853732]=d[9660821]|0;r=a[9660812]|0;i=c[2443666]&(e[4830408]|0);k=c[9703728+(i>>>((c[3528996]|0)>>>0)<<2)>>2]|0;do{if((k|0)==0){m=c[3528586]|0;if((m|0)==0){break}gg[m&4095](i&65535,r)}else{a[k+(c[2385780]&i)|0]=r}}while(0);r=(b[4830408]|0)-1&65535;b[4830408]=r;if((r&65535)>>>0<(c[2415202]|0)>>>0){i=c[2415201]&65535;b[4830408]=i;eX=i}else{eX=r}r=a[9660813]|0;i=c[2443666]&(eX&65535);k=c[9703728+(i>>>((c[3528996]|0)>>>0)<<2)>>2]|0;do{if((k|0)==0){m=c[3528586]|0;if((m|0)==0){break}gg[m&4095](i&65535,r)}else{a[k+(c[2385780]&i)|0]=r}}while(0);r=(b[4830408]|0)-1&65535;b[4830408]=r;if((r&65535)>>>0<(c[2415202]|0)>>>0){b[4830408]=c[2415201]&65535}b[4830406]=b[4853732]|0;break};case 254:{b[4853732]=d[9660821]|0;r=c[2426866]&65535&c[2443666];i=c[9702704+(r>>>((c[3528996]|0)>>>0)<<2)>>2]|0;do{if((i|0)==0){k=c[2385590]|0;if((k|0)==0){eY=0;break}eY=gj[k&4095](r&65535)|0}else{eY=a[i+(c[2385780]&r)|0]|0}}while(0);a[9660821]=eY;r=(eY&255)>>>5&4|a[9660822]&-7;a[9660822]=eY<<24>>24==0?r|2:r;break};case 255:{r=a[9660821]|0;i=(r&255)>>>5&4|a[9660822]&-7;a[9660822]=r<<24>>24==0?i|2:i;b[4853732]=r&255;i=c[2426866]&65535&c[2443666];k=c[9703728+(i>>>((c[3528996]|0)>>>0)<<2)>>2]|0;if((k|0)!=0){a[k+(c[2385780]&i)|0]=r;c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}k=c[3528586]|0;if((k|0)==0){c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}gg[k&4095](i&65535,r);break};case 35:{r=b[4830406]|0;b[4830406]=r+1&65535;i=c[2443666]&(r&65535);r=c[9702704+(i>>>((c[3528996]|0)>>>0)<<2)>>2]|0;do{if((r|0)==0){k=c[2385590]|0;if((k|0)==0){eZ=0;break}eZ=gj[k&4095](i&65535)|0}else{eZ=a[r+(c[2385780]&i)|0]|0}}while(0);if((a[9660822]&3)==0){c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}i=eZ&255;b[4830406]=(e[4830406]|0)+((i&128|0)!=0?i|65280:i)&65535;if(!(eZ<<24>>24==-2&(c[1631650]|0)>0)){c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}c[1631650]=0;break};case 36:{i=b[4830406]|0;b[4830406]=i+1&65535;r=c[2443666]&(i&65535);i=c[9702704+(r>>>((c[3528996]|0)>>>0)<<2)>>2]|0;do{if((i|0)==0){k=c[2385590]|0;if((k|0)==0){e_=0;break}e_=gj[k&4095](r&65535)|0}else{e_=a[i+(c[2385780]&r)|0]|0}}while(0);if((a[9660822]&1)!=0){c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}r=e_&255;b[4830406]=(e[4830406]|0)+((r&128|0)!=0?r|65280:r)&65535;if(!(e_<<24>>24==-2&(c[1631650]|0)>0)){c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}c[1631650]=0;break};case 37:{r=b[4830406]|0;b[4830406]=r+1&65535;i=c[2443666]&(r&65535);r=c[9702704+(i>>>((c[3528996]|0)>>>0)<<2)>>2]|0;do{if((r|0)==0){k=c[2385590]|0;if((k|0)==0){e$=0;break}e$=gj[k&4095](i&65535)|0}else{e$=a[r+(c[2385780]&i)|0]|0}}while(0);if((a[9660822]&1)==0){c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}i=e$&255;b[4830406]=(e[4830406]|0)+((i&128|0)!=0?i|65280:i)&65535;if(!(e$<<24>>24==-2&(c[1631650]|0)>0)){c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}c[1631650]=0;break};case 38:{i=b[4830406]|0;b[4830406]=i+1&65535;r=c[2443666]&(i&65535);i=c[9702704+(r>>>((c[3528996]|0)>>>0)<<2)>>2]|0;do{if((i|0)==0){k=c[2385590]|0;if((k|0)==0){e0=0;break}e0=gj[k&4095](r&65535)|0}else{e0=a[i+(c[2385780]&r)|0]|0}}while(0);if((a[9660822]&2)!=0){c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}r=e0&255;b[4830406]=(e[4830406]|0)+((r&128|0)!=0?r|65280:r)&65535;if(!(e0<<24>>24==-2&(c[1631650]|0)>0)){c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}c[1631650]=0;break};case 39:{r=b[4830406]|0;b[4830406]=r+1&65535;i=c[2443666]&(r&65535);r=c[9702704+(i>>>((c[3528996]|0)>>>0)<<2)>>2]|0;do{if((r|0)==0){k=c[2385590]|0;if((k|0)==0){e1=0;break}e1=gj[k&4095](i&65535)|0}else{e1=a[r+(c[2385780]&i)|0]|0}}while(0);if((a[9660822]&2)==0){c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}i=e1&255;b[4830406]=(e[4830406]|0)+((i&128|0)!=0?i|65280:i)&65535;if(!(e1<<24>>24==-2&(c[1631650]|0)>0)){c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}c[1631650]=0;break};case 40:{i=b[4830406]|0;b[4830406]=i+1&65535;r=c[2443666]&(i&65535);i=c[9702704+(r>>>((c[3528996]|0)>>>0)<<2)>>2]|0;do{if((i|0)==0){k=c[2385590]|0;if((k|0)==0){e2=0;break}e2=gj[k&4095](r&65535)|0}else{e2=a[i+(c[2385780]&r)|0]|0}}while(0);if((a[9660822]&16)!=0){c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}r=e2&255;b[4830406]=(e[4830406]|0)+((r&128|0)!=0?r|65280:r)&65535;if(!(e2<<24>>24==-2&(c[1631650]|0)>0)){c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}c[1631650]=0;break};case 41:{r=b[4830406]|0;b[4830406]=r+1&65535;i=c[2443666]&(r&65535);r=c[9702704+(i>>>((c[3528996]|0)>>>0)<<2)>>2]|0;do{if((r|0)==0){k=c[2385590]|0;if((k|0)==0){e3=0;break}e3=gj[k&4095](i&65535)|0}else{e3=a[r+(c[2385780]&i)|0]|0}}while(0);if((a[9660822]&16)==0){c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}i=e3&255;b[4830406]=(e[4830406]|0)+((i&128|0)!=0?i|65280:i)&65535;if(!(e3<<24>>24==-2&(c[1631650]|0)>0)){c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}c[1631650]=0;break};case 42:{i=b[4830406]|0;b[4830406]=i+1&65535;r=c[2443666]&(i&65535);i=c[9702704+(r>>>((c[3528996]|0)>>>0)<<2)>>2]|0;do{if((i|0)==0){k=c[2385590]|0;if((k|0)==0){e4=0;break}e4=gj[k&4095](r&65535)|0}else{e4=a[i+(c[2385780]&r)|0]|0}}while(0);if((a[9660822]&4)!=0){c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}r=e4&255;b[4830406]=(e[4830406]|0)+((r&128|0)!=0?r|65280:r)&65535;if(!(e4<<24>>24==-2&(c[1631650]|0)>0)){c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}c[1631650]=0;break};case 43:{r=b[4830406]|0;b[4830406]=r+1&65535;i=c[2443666]&(r&65535);r=c[9702704+(i>>>((c[3528996]|0)>>>0)<<2)>>2]|0;do{if((r|0)==0){k=c[2385590]|0;if((k|0)==0){e5=0;break}e5=gj[k&4095](i&65535)|0}else{e5=a[r+(c[2385780]&i)|0]|0}}while(0);if((a[9660822]&4)==0){c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}i=e5&255;b[4830406]=(e[4830406]|0)+((i&128|0)!=0?i|65280:i)&65535;if(!(e5<<24>>24==-2&(c[1631650]|0)>0)){c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}c[1631650]=0;break};case 44:{i=b[4830406]|0;b[4830406]=i+1&65535;r=c[2443666]&(i&65535);i=c[9702704+(r>>>((c[3528996]|0)>>>0)<<2)>>2]|0;do{if((i|0)==0){k=c[2385590]|0;if((k|0)==0){e6=0;break}e6=gj[k&4095](r&65535)|0}else{e6=a[i+(c[2385780]&r)|0]|0}}while(0);if((a[9660822]&8)!=0){c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}r=e6&255;b[4830406]=(e[4830406]|0)+((r&128|0)!=0?r|65280:r)&65535;if(!(e6<<24>>24==-2&(c[1631650]|0)>0)){c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}c[1631650]=0;break};case 45:{r=b[4830406]|0;b[4830406]=r+1&65535;i=c[2443666]&(r&65535);r=c[9702704+(i>>>((c[3528996]|0)>>>0)<<2)>>2]|0;do{if((r|0)==0){k=c[2385590]|0;if((k|0)==0){e7=0;break}e7=gj[k&4095](i&65535)|0}else{e7=a[r+(c[2385780]&i)|0]|0}}while(0);if((a[9660822]&8)==0){c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}i=e7&255;b[4830406]=(e[4830406]|0)+((i&128|0)!=0?i|65280:i)&65535;if(!(e7<<24>>24==-2&(c[1631650]|0)>0)){c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}c[1631650]=0;break};case 46:{i=(c[2415200]|0)==2;r=b[4830406]|0;b[4830406]=r+1&65535;k=c[2443666]&(r&65535);r=c[9702704+(k>>>((c[3528996]|0)>>>0)<<2)>>2]|0;do{if((r|0)==0){m=c[2385590]|0;if((m|0)==0){e8=0;break}e8=gj[m&4095](k&65535)|0}else{e8=a[r+(c[2385780]&k)|0]|0}}while(0);if(i){if((c[2415217]|0)==0){c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}k=e8&255;b[4830406]=(e[4830406]|0)+((k&128|0)!=0?k|65280:k)&65535;if(!(e8<<24>>24==-2&(c[1631650]|0)>0)){c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}c[1631650]=0;c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}else{if((c[2415208]|0)==0){c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}k=e8&255;b[4830406]=(e[4830406]|0)+((k&128|0)!=0?k|65280:k)&65535;if(!(e8<<24>>24==-2&(c[1631650]|0)>0)){c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}c[1631650]=0;c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}break};case 47:{k=(c[2415200]|0)==2;r=b[4830406]|0;b[4830406]=r+1&65535;m=c[2443666]&(r&65535);r=c[9702704+(m>>>((c[3528996]|0)>>>0)<<2)>>2]|0;do{if((r|0)==0){l=c[2385590]|0;if((l|0)==0){e9=0;break}e9=gj[l&4095](m&65535)|0}else{e9=a[r+(c[2385780]&m)|0]|0}}while(0);if(k){if((c[2415217]|0)!=0){c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}m=e9&255;b[4830406]=(e[4830406]|0)+((m&128|0)!=0?m|65280:m)&65535;if(!(e9<<24>>24==-2&(c[1631650]|0)>0)){c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}c[1631650]=0;c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}else{if((c[2415208]|0)!=0){c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}m=e9&255;b[4830406]=(e[4830406]|0)+((m&128|0)!=0?m|65280:m)&65535;if(!(e9<<24>>24==-2&(c[1631650]|0)>0)){c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}c[1631650]=0;c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}break};case 48:{c[2426866]=0;m=b[4830406]|0;b[4830406]=m+1&65535;r=c[2443666]|0;i=c[3528996]|0;l=c[9702704+((r&(m&65535))>>>(i>>>0)<<2)>>2]|0;do{if((l|0)==0){j=c[2385590]|0;if((j|0)==0){fa=0;fb=r;fc=i;break}eg=gj[j&4095](r&(m&65535)&65535)|0;fa=eg;fb=c[2443666]|0;fc=c[3528996]|0}else{fa=a[l+(c[2385780]&(r&(m&65535)))|0]|0;fb=r;fc=i}}while(0);a[9707464]=fa;i=c[2426866]|0;r=i&65535&fb;m=c[9702704+(r>>>(fc>>>0)<<2)>>2]|0;do{if((m|0)==0){l=c[2385590]|0;if((l|0)==0){fd=0;fe=i;ff=fb;fg=fc;break}k=gj[l&4095](r&65535)|0;fd=k;fe=c[2426866]|0;ff=c[2443666]|0;fg=c[3528996]|0}else{fd=a[m+(c[2385780]&r)|0]|0;fe=i;ff=fb;fg=fc}}while(0);i=-(fd&255)&65535;r=((i&65535)>>>5&4|a[9660822]&-8&255)&255;a[9660822]=(((i&255)<<24>>24==0?r|2:r)&255|(i&65535)>>>8&1)&255;r=fe&65535&ff;m=c[9703728+(r>>>(fg>>>0)<<2)>>2]|0;if((m|0)!=0){a[m+(c[2385780]&r)|0]=i&255;c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}m=c[3528586]|0;if((m|0)==0){c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}gg[m&4095](r&65535,i&255);break};case 51:{c[2426866]=0;i=b[4830406]|0;b[4830406]=i+1&65535;r=c[2443666]|0;m=c[3528996]|0;k=c[9702704+((r&(i&65535))>>>(m>>>0)<<2)>>2]|0;do{if((k|0)==0){l=c[2385590]|0;if((l|0)==0){fh=0;fi=r;fj=m;break}eg=gj[l&4095](r&(i&65535)&65535)|0;fh=eg;fi=c[2443666]|0;fj=c[3528996]|0}else{fh=a[k+(c[2385780]&(r&(i&65535)))|0]|0;fi=r;fj=m}}while(0);a[9707464]=fh;m=c[2426866]|0;r=m&65535&fi;i=c[9702704+(r>>>(fj>>>0)<<2)>>2]|0;do{if((i|0)==0){k=c[2385590]|0;if((k|0)==0){fk=0;fl=m;fm=fi;fn=fj;break}eg=gj[k&4095](r&65535)|0;fk=eg;fl=c[2426866]|0;fm=c[2443666]|0;fn=c[3528996]|0}else{fk=a[i+(c[2385780]&r)|0]|0;fl=m;fm=fi;fn=fj}}while(0);m=~fk;r=a[9660822]&-7|(m&255)>>>5&4;a[9660822]=(fk<<24>>24==-1?r|2:r)|1;r=fl&65535&fm;i=c[9703728+(r>>>(fn>>>0)<<2)>>2]|0;if((i|0)!=0){a[i+(c[2385780]&r)|0]=m;c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}i=c[3528586]|0;if((i|0)==0){c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}gg[i&4095](r&65535,m);break};case 52:{c[2426866]=0;m=b[4830406]|0;b[4830406]=m+1&65535;r=c[2443666]|0;i=c[3528996]|0;eg=c[9702704+((r&(m&65535))>>>(i>>>0)<<2)>>2]|0;do{if((eg|0)==0){k=c[2385590]|0;if((k|0)==0){fo=0;fp=r;fq=i;break}l=gj[k&4095](r&(m&65535)&65535)|0;fo=l;fp=c[2443666]|0;fq=c[3528996]|0}else{fo=a[eg+(c[2385780]&(r&(m&65535)))|0]|0;fp=r;fq=i}}while(0);a[9707464]=fo;i=c[2426866]|0;r=i&65535&fp;m=c[9702704+(r>>>(fq>>>0)<<2)>>2]|0;do{if((m|0)==0){eg=c[2385590]|0;if((eg|0)==0){fr=0;fs=i;ft=fp;fu=fq;break}l=gj[eg&4095](r&65535)|0;fr=l;fs=c[2426866]|0;ft=c[2443666]|0;fu=c[3528996]|0}else{fr=a[m+(c[2385780]&r)|0]|0;fs=i;ft=fp;fu=fq}}while(0);i=a[9660822]&-8|fr&1;r=(fr&255)>>>1;a[9660822]=r<<24>>24==0?i|2:i;i=fs&65535&ft;m=c[9703728+(i>>>(fu>>>0)<<2)>>2]|0;if((m|0)!=0){a[m+(c[2385780]&i)|0]=r;c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}m=c[3528586]|0;if((m|0)==0){c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}gg[m&4095](i&65535,r);break};case 54:{c[2426866]=0;r=b[4830406]|0;b[4830406]=r+1&65535;i=c[2443666]|0;m=c[3528996]|0;l=c[9702704+((i&(r&65535))>>>(m>>>0)<<2)>>2]|0;do{if((l|0)==0){eg=c[2385590]|0;if((eg|0)==0){fv=0;fw=i;fx=m;break}k=gj[eg&4095](i&(r&65535)&65535)|0;fv=k;fw=c[2443666]|0;fx=c[3528996]|0}else{fv=a[l+(c[2385780]&(i&(r&65535)))|0]|0;fw=i;fx=m}}while(0);a[9707464]=fv;m=c[2426866]|0;i=m&65535&fw;r=c[9702704+(i>>>(fx>>>0)<<2)>>2]|0;do{if((r|0)==0){l=c[2385590]|0;if((l|0)==0){fy=0;fz=m;fA=fw;fB=fx;break}k=gj[l&4095](i&65535)|0;fy=k;fz=c[2426866]|0;fA=c[2443666]|0;fB=c[3528996]|0}else{fy=a[r+(c[2385780]&i)|0]|0;fz=m;fA=fw;fB=fx}}while(0);m=a[9660822]|0;i=m<<7|(fy&255)>>>1;r=m&-8|fy&1|m<<2&4;a[9660822]=i<<24>>24==0?r|2:r;r=fz&65535&fA;m=c[9703728+(r>>>(fB>>>0)<<2)>>2]|0;if((m|0)!=0){a[m+(c[2385780]&r)|0]=i;c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}m=c[3528586]|0;if((m|0)==0){c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}gg[m&4095](r&65535,i);break};case 55:{c[2426866]=0;i=b[4830406]|0;b[4830406]=i+1&65535;r=c[2443666]|0;m=c[3528996]|0;k=c[9702704+((r&(i&65535))>>>(m>>>0)<<2)>>2]|0;do{if((k|0)==0){l=c[2385590]|0;if((l|0)==0){fC=0;fD=r;fE=m;break}eg=gj[l&4095](r&(i&65535)&65535)|0;fC=eg;fD=c[2443666]|0;fE=c[3528996]|0}else{fC=a[k+(c[2385780]&(r&(i&65535)))|0]|0;fD=r;fE=m}}while(0);a[9707464]=fC;m=c[2426866]|0;r=m&65535&fD;i=c[9702704+(r>>>(fE>>>0)<<2)>>2]|0;do{if((i|0)==0){k=c[2385590]|0;if((k|0)==0){fF=0;fG=m;fH=fD;fI=fE;break}eg=gj[k&4095](r&65535)|0;fF=eg;fG=c[2426866]|0;fH=c[2443666]|0;fI=c[3528996]|0}else{fF=a[i+(c[2385780]&r)|0]|0;fG=m;fH=fD;fI=fE}}while(0);m=(fF&255)>>>1;r=a[9660822]&-8|fF&1|(fF&255)>>>5&4;a[9660822]=(m<<1&-128|m)<<24>>24==0?r|2:r;r=fG&65535&fH;i=c[9703728+(r>>>(fI>>>0)<<2)>>2]|0;if((i|0)!=0){a[i+(c[2385780]&r)|0]=m<<1&-128|m;c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}i=c[3528586]|0;if((i|0)==0){c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}gg[i&4095](r&65535,m<<1&-128|m);break};case 56:{c[2426866]=0;m=b[4830406]|0;b[4830406]=m+1&65535;r=c[2443666]|0;i=c[3528996]|0;eg=c[9702704+((r&(m&65535))>>>(i>>>0)<<2)>>2]|0;do{if((eg|0)==0){k=c[2385590]|0;if((k|0)==0){fJ=0;fK=r;fL=i;break}l=gj[k&4095](r&(m&65535)&65535)|0;fJ=l;fK=c[2443666]|0;fL=c[3528996]|0}else{fJ=a[eg+(c[2385780]&(r&(m&65535)))|0]|0;fK=r;fL=i}}while(0);a[9707464]=fJ;i=c[2426866]|0;r=i&65535&fK;m=c[9702704+(r>>>(fL>>>0)<<2)>>2]|0;do{if((m|0)==0){eg=c[2385590]|0;if((eg|0)==0){fM=0;fN=i;fO=fK;fP=fL;break}l=gj[eg&4095](r&65535)|0;fM=l;fN=c[2426866]|0;fO=c[2443666]|0;fP=c[3528996]|0}else{fM=a[m+(c[2385780]&r)|0]|0;fN=i;fO=fK;fP=fL}}while(0);i=(fM&255)<<1;r=((i&65535)>>>5&4|a[9660822]&-8&255)&255;a[9660822]=(((i&255)<<24>>24==0?r|2:r)&255|(i&65535)>>>8)&255;r=fN&65535&fO;m=c[9703728+(r>>>(fP>>>0)<<2)>>2]|0;if((m|0)!=0){a[m+(c[2385780]&r)|0]=i&255;c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}m=c[3528586]|0;if((m|0)==0){c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}gg[m&4095](r&65535,i&255);break};case 57:{c[2426866]=0;i=b[4830406]|0;b[4830406]=i+1&65535;r=c[2443666]|0;m=c[3528996]|0;l=c[9702704+((r&(i&65535))>>>(m>>>0)<<2)>>2]|0;do{if((l|0)==0){eg=c[2385590]|0;if((eg|0)==0){fQ=0;fR=r;fS=m;break}k=gj[eg&4095](r&(i&65535)&65535)|0;fQ=k;fR=c[2443666]|0;fS=c[3528996]|0}else{fQ=a[l+(c[2385780]&(r&(i&65535)))|0]|0;fR=r;fS=m}}while(0);a[9707464]=fQ;m=c[2426866]|0;r=m&65535&fR;i=c[9702704+(r>>>(fS>>>0)<<2)>>2]|0;do{if((i|0)==0){l=c[2385590]|0;if((l|0)==0){fT=0;fU=m;fV=fR;fW=fS;break}k=gj[l&4095](r&65535)|0;fT=k;fU=c[2426866]|0;fV=c[2443666]|0;fW=c[3528996]|0}else{fT=a[i+(c[2385780]&r)|0]|0;fU=m;fV=fR;fW=fS}}while(0);m=a[9660822]|0;r=m&1|(fT&255)<<1;a[9660822]=(((r&255)<<24>>24==0?((r&65535)>>>5&4|m&-8&255)&255|2:((r&65535)>>>5&4|m&-8&255)&255)&255|(r&65535)>>>8)&255;m=fU&65535&fV;i=c[9703728+(m>>>(fW>>>0)<<2)>>2]|0;if((i|0)!=0){a[i+(c[2385780]&m)|0]=r&255;c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}i=c[3528586]|0;if((i|0)==0){c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}gg[i&4095](m&65535,r&255);break};default:{g=1}}}if(g){g=0;switch(h|0){case 58:{c[2426866]=0;r=b[4830406]|0;b[4830406]=r+1&65535;m=c[2443666]|0;i=c[3528996]|0;k=c[9702704+((m&(r&65535))>>>(i>>>0)<<2)>>2]|0;do{if((k|0)==0){l=c[2385590]|0;if((l|0)==0){fX=0;fY=m;fZ=i;break}eg=gj[l&4095](m&(r&65535)&65535)|0;fX=eg;fY=c[2443666]|0;fZ=c[3528996]|0}else{fX=a[k+(c[2385780]&(m&(r&65535)))|0]|0;fY=m;fZ=i}}while(0);a[9707464]=fX;i=c[2426866]|0;m=i&65535&fY;r=c[9702704+(m>>>(fZ>>>0)<<2)>>2]|0;do{if((r|0)==0){k=c[2385590]|0;if((k|0)==0){f_=0;f$=i;f0=fY;f1=fZ;break}eg=gj[k&4095](m&65535)|0;f_=eg;f$=c[2426866]|0;f0=c[2443666]|0;f1=c[3528996]|0}else{f_=a[r+(c[2385780]&m)|0]|0;f$=i;f0=fY;f1=fZ}}while(0);i=f_-1&255;a[9660822]=a[9660822]&-7|a[669440+(i&255)|0];m=f$&65535&f0;r=c[9703728+(m>>>(f1>>>0)<<2)>>2]|0;if((r|0)!=0){a[r+(c[2385780]&m)|0]=i;c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}r=c[3528586]|0;if((r|0)==0){c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}gg[r&4095](m&65535,i);break};case 60:{c[2426866]=0;i=b[4830406]|0;b[4830406]=i+1&65535;m=c[2443666]|0;r=c[3528996]|0;eg=c[9702704+((m&(i&65535))>>>(r>>>0)<<2)>>2]|0;do{if((eg|0)==0){k=c[2385590]|0;if((k|0)==0){f2=0;f3=m;f4=r;break}l=gj[k&4095](m&(i&65535)&65535)|0;f2=l;f3=c[2443666]|0;f4=c[3528996]|0}else{f2=a[eg+(c[2385780]&(m&(i&65535)))|0]|0;f3=m;f4=r}}while(0);a[9707464]=f2;r=c[2426866]|0;m=r&65535&f3;i=c[9702704+(m>>>(f4>>>0)<<2)>>2]|0;do{if((i|0)==0){eg=c[2385590]|0;if((eg|0)==0){f5=0;f6=r;f7=f3;f8=f4;break}l=gj[eg&4095](m&65535)|0;f5=l;f6=c[2426866]|0;f7=c[2443666]|0;f8=c[3528996]|0}else{f5=a[i+(c[2385780]&m)|0]|0;f6=r;f7=f3;f8=f4}}while(0);r=f5+1&255;a[9660822]=a[9660822]&-7|a[669440+(r&255)|0];m=f6&65535&f7;i=c[9703728+(m>>>(f8>>>0)<<2)>>2]|0;if((i|0)!=0){a[i+(c[2385780]&m)|0]=r;c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}i=c[3528586]|0;if((i|0)==0){c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}gg[i&4095](m&65535,r);break};case 61:{c[2426866]=0;r=b[4830406]|0;b[4830406]=r+1&65535;m=c[2443666]|0;i=c[3528996]|0;l=c[9702704+((m&(r&65535))>>>(i>>>0)<<2)>>2]|0;do{if((l|0)==0){eg=c[2385590]|0;if((eg|0)==0){f9=0;ga=m;gb=i;break}k=gj[eg&4095](m&(r&65535)&65535)|0;f9=k;ga=c[2443666]|0;gb=c[3528996]|0}else{f9=a[l+(c[2385780]&(m&(r&65535)))|0]|0;ga=m;gb=i}}while(0);a[9707464]=f9;i=c[2426866]&65535&ga;m=c[9702704+(i>>>(gb>>>0)<<2)>>2]|0;do{if((m|0)==0){r=c[2385590]|0;if((r|0)==0){gc=0;break}gc=gj[r&4095](i&65535)|0}else{gc=a[m+(c[2385780]&i)|0]|0}}while(0);i=a[9660822]&-7|(gc&255)>>>5&4;a[9660822]=gc<<24>>24==0?i|2:i;break};case 63:{c[2426866]=0;i=b[4830406]|0;b[4830406]=i+1&65535;m=c[2443666]|0;r=c[3528996]|0;l=c[9702704+((m&(i&65535))>>>(r>>>0)<<2)>>2]|0;do{if((l|0)==0){k=c[2385590]|0;if((k|0)==0){gd=0;ge=m;gf=r;break}eg=gj[k&4095](m&(i&65535)&65535)|0;gd=eg;ge=c[2443666]|0;gf=c[3528996]|0}else{gd=a[l+(c[2385780]&(m&(i&65535)))|0]|0;ge=m;gf=r}}while(0);a[9707464]=gd;a[9660822]=a[9660822]&-8|2;r=c[2426866]&65535&ge;m=c[9703728+(r>>>(gf>>>0)<<2)>>2]|0;if((m|0)!=0){a[m+(c[2385780]&r)|0]=0;c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}m=c[3528586]|0;if((m|0)==0){c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}gg[m&4095](r&65535,0);break};case 64:{r=-(d[9660820]|0)&65535;m=((r&65535)>>>5&4|a[9660822]&-8&255)&255;a[9660822]=(((r&255)<<24>>24==0?m|2:m)&255|(r&65535)>>>8&1)&255;a[9660820]=r&255;break};case 67:{r=a[9660820]|0;a[9660820]=~r;m=(~r&255)>>>5&4|a[9660822]&-7;a[9660822]=(r<<24>>24==-1?m|2:m)|1;break};case 68:{m=a[9660820]|0;r=m&1|a[9660822]&-8;a[9660822]=r;a[9660820]=(m&255)>>>1;if((m&255)>>>1<<24>>24!=0){c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}a[9660822]=r|2;break};case 70:{r=a[9660822]|0;m=a[9660820]|0;a[9660822]=((m&255)>>>1|r<<7)<<24>>24==0?m&1|r&-8|r<<2&4|2:m&1|r&-8|r<<2&4;a[9660820]=(m&255)>>>1|r<<7;break};case 71:{r=a[9660820]|0;m=r&1|a[9660822]&-8;a[9660820]=r&-128|(r&255)>>>1;a[9660822]=(r&-128|(r&255)>>>1)<<24>>24==0?m|(r&255)>>>5&4|2:m|(r&255)>>>5&4;break};case 72:{r=(d[9660820]|0)<<1;m=((r&65535)>>>5&4|a[9660822]&-8&255)&255;a[9660822]=(((r&255)<<24>>24==0?m|2:m)&255|(r&65535)>>>8)&255;a[9660820]=r&255;break};case 73:{r=a[9660822]|0;m=r&1|(d[9660820]|0)<<1;a[9660822]=(((m&255)<<24>>24==0?((m&65535)>>>5&4|r&-8&255)&255|2:((m&65535)>>>5&4|r&-8&255)&255)&255|(m&65535)>>>8)&255;a[9660820]=m&255;break};case 74:{m=(a[9660820]|0)-1&255;a[9660820]=m;a[9660822]=a[669440+(m&255)|0]|a[9660822]&-7;break};case 76:{m=(a[9660820]|0)+1&255;a[9660820]=m;a[9660822]=a[669440+(m&255)|0]|a[9660822]&-7;break};case 77:{m=a[9660820]|0;r=(m&255)>>>5&4|a[9660822]&-7;a[9660822]=m<<24>>24==0?r|2:r;break};case 79:{a[9660820]=0;a[9660822]=a[9660822]&-7|2;break};case 80:{r=-(d[9660821]|0)&65535;m=((r&65535)>>>5&4|a[9660822]&-8&255)&255;a[9660822]=(((r&255)<<24>>24==0?m|2:m)&255|(r&65535)>>>8&1)&255;a[9660821]=r&255;break};case 83:{r=a[9660821]|0;a[9660821]=~r;m=(~r&255)>>>5&4|a[9660822]&-7;a[9660822]=(r<<24>>24==-1?m|2:m)|1;break};case 84:{m=a[9660821]|0;r=m&1|a[9660822]&-8;a[9660822]=r;a[9660821]=(m&255)>>>1;if((m&255)>>>1<<24>>24!=0){c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}a[9660822]=r|2;break};case 86:{r=a[9660822]|0;m=a[9660821]|0;a[9660822]=((m&255)>>>1|r<<7)<<24>>24==0?m&1|r&-8|r<<2&4|2:m&1|r&-8|r<<2&4;a[9660821]=(m&255)>>>1|r<<7;break};case 87:{r=a[9660821]|0;m=r&1|a[9660822]&-8;a[9660821]=r&-128|(r&255)>>>1;a[9660822]=(r&-128|(r&255)>>>1)<<24>>24==0?m|(r&255)>>>5&4|2:m|(r&255)>>>5&4;break};case 88:{r=(d[9660821]|0)<<1;m=((r&65535)>>>5&4|a[9660822]&-8&255)&255;a[9660822]=(((r&255)<<24>>24==0?m|2:m)&255|(r&65535)>>>8)&255;a[9660821]=r&255;break};case 89:{r=a[9660822]|0;m=r&1|(d[9660821]|0)<<1;a[9660822]=(((m&255)<<24>>24==0?((m&65535)>>>5&4|r&-8&255)&255|2:((m&65535)>>>5&4|r&-8&255)&255)&255|(m&65535)>>>8)&255;a[9660821]=m&255;break};case 90:{m=(a[9660821]|0)-1&255;a[9660821]=m;a[9660822]=a[669440+(m&255)|0]|a[9660822]&-7;break};case 92:{m=(a[9660821]|0)+1&255;a[9660821]=m;a[9660822]=a[669440+(m&255)|0]|a[9660822]&-7;break};case 93:{m=a[9660821]|0;r=(m&255)>>>5&4|a[9660822]&-7;a[9660822]=m<<24>>24==0?r|2:r;break};case 95:{a[9660821]=0;a[9660822]=a[9660822]&-8|2;break};case 96:{c[2426866]=0;r=b[4830406]|0;b[4830406]=r+1&65535;m=c[2443666]|0;i=c[3528996]|0;l=c[9702704+((m&(r&65535))>>>(i>>>0)<<2)>>2]|0;do{if((l|0)==0){eg=c[2385590]|0;if((eg|0)==0){gh=0;gi=m;gk=i;break}k=gj[eg&4095](m&(r&65535)&65535)|0;gh=k;gi=c[2443666]|0;gk=c[3528996]|0}else{gh=a[l+(c[2385780]&(m&(r&65535)))|0]|0;gi=m;gk=i}}while(0);a[9707464]=gh;b[4853732]=(b[4853732]|0)+(d[9660821]|0)&65535;i=c[2426866]|0;m=i&65535&gi;r=c[9702704+(m>>>(gk>>>0)<<2)>>2]|0;do{if((r|0)==0){l=c[2385590]|0;if((l|0)==0){gl=0;gm=i;gn=gi;go=gk;break}k=gj[l&4095](m&65535)|0;gl=k;gm=c[2426866]|0;gn=c[2443666]|0;go=c[3528996]|0}else{gl=a[r+(c[2385780]&m)|0]|0;gm=i;gn=gi;go=gk}}while(0);i=-(gl&255)&65535;m=((i&65535)>>>5&4|a[9660822]&-8&255)&255;a[9660822]=(((i&255)<<24>>24==0?m|2:m)&255|(i&65535)>>>8&1)&255;m=gm&65535&gn;r=c[9703728+(m>>>(go>>>0)<<2)>>2]|0;if((r|0)!=0){a[r+(c[2385780]&m)|0]=i&255;c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}r=c[3528586]|0;if((r|0)==0){c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}gg[r&4095](m&65535,i&255);break};case 99:{c[2426866]=0;i=b[4830406]|0;b[4830406]=i+1&65535;m=c[2443666]|0;r=c[3528996]|0;k=c[9702704+((m&(i&65535))>>>(r>>>0)<<2)>>2]|0;do{if((k|0)==0){l=c[2385590]|0;if((l|0)==0){gp=0;gq=m;gr=r;break}eg=gj[l&4095](m&(i&65535)&65535)|0;gp=eg;gq=c[2443666]|0;gr=c[3528996]|0}else{gp=a[k+(c[2385780]&(m&(i&65535)))|0]|0;gq=m;gr=r}}while(0);a[9707464]=gp;b[4853732]=(b[4853732]|0)+(d[9660821]|0)&65535;r=c[2426866]|0;m=r&65535&gq;i=c[9702704+(m>>>(gr>>>0)<<2)>>2]|0;do{if((i|0)==0){k=c[2385590]|0;if((k|0)==0){gs=0;gt=r;gu=gq;gv=gr;break}eg=gj[k&4095](m&65535)|0;gs=eg;gt=c[2426866]|0;gu=c[2443666]|0;gv=c[3528996]|0}else{gs=a[i+(c[2385780]&m)|0]|0;gt=r;gu=gq;gv=gr}}while(0);r=~gs;m=a[9660822]&-7|(r&255)>>>5&4;a[9660822]=(gs<<24>>24==-1?m|2:m)|1;m=gt&65535&gu;i=c[9703728+(m>>>(gv>>>0)<<2)>>2]|0;if((i|0)!=0){a[i+(c[2385780]&m)|0]=r;c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}i=c[3528586]|0;if((i|0)==0){c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}gg[i&4095](m&65535,r);break};case 100:{c[2426866]=0;r=b[4830406]|0;b[4830406]=r+1&65535;m=c[2443666]|0;i=c[3528996]|0;eg=c[9702704+((m&(r&65535))>>>(i>>>0)<<2)>>2]|0;do{if((eg|0)==0){k=c[2385590]|0;if((k|0)==0){gw=0;gx=m;gy=i;break}l=gj[k&4095](m&(r&65535)&65535)|0;gw=l;gx=c[2443666]|0;gy=c[3528996]|0}else{gw=a[eg+(c[2385780]&(m&(r&65535)))|0]|0;gx=m;gy=i}}while(0);a[9707464]=gw;b[4853732]=(b[4853732]|0)+(d[9660821]|0)&65535;i=c[2426866]|0;m=i&65535&gx;r=c[9702704+(m>>>(gy>>>0)<<2)>>2]|0;do{if((r|0)==0){eg=c[2385590]|0;if((eg|0)==0){gz=0;gA=i;gB=gx;gC=gy;break}l=gj[eg&4095](m&65535)|0;gz=l;gA=c[2426866]|0;gB=c[2443666]|0;gC=c[3528996]|0}else{gz=a[r+(c[2385780]&m)|0]|0;gA=i;gB=gx;gC=gy}}while(0);i=a[9660822]&-8|gz&1;m=(gz&255)>>>1;a[9660822]=m<<24>>24==0?i|2:i;i=gA&65535&gB;r=c[9703728+(i>>>(gC>>>0)<<2)>>2]|0;if((r|0)!=0){a[r+(c[2385780]&i)|0]=m;c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}r=c[3528586]|0;if((r|0)==0){c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}gg[r&4095](i&65535,m);break};case 102:{c[2426866]=0;m=b[4830406]|0;b[4830406]=m+1&65535;i=c[2443666]|0;r=c[3528996]|0;l=c[9702704+((i&(m&65535))>>>(r>>>0)<<2)>>2]|0;do{if((l|0)==0){eg=c[2385590]|0;if((eg|0)==0){gD=0;gE=i;gF=r;break}k=gj[eg&4095](i&(m&65535)&65535)|0;gD=k;gE=c[2443666]|0;gF=c[3528996]|0}else{gD=a[l+(c[2385780]&(i&(m&65535)))|0]|0;gE=i;gF=r}}while(0);a[9707464]=gD;b[4853732]=(b[4853732]|0)+(d[9660821]|0)&65535;r=c[2426866]|0;i=r&65535&gE;m=c[9702704+(i>>>(gF>>>0)<<2)>>2]|0;do{if((m|0)==0){l=c[2385590]|0;if((l|0)==0){gG=0;gH=r;gI=gE;gJ=gF;break}k=gj[l&4095](i&65535)|0;gG=k;gH=c[2426866]|0;gI=c[2443666]|0;gJ=c[3528996]|0}else{gG=a[m+(c[2385780]&i)|0]|0;gH=r;gI=gE;gJ=gF}}while(0);r=a[9660822]|0;i=r<<7|(gG&255)>>>1;m=r&-8|gG&1|r<<2&4;a[9660822]=i<<24>>24==0?m|2:m;m=gH&65535&gI;r=c[9703728+(m>>>(gJ>>>0)<<2)>>2]|0;if((r|0)!=0){a[r+(c[2385780]&m)|0]=i;c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}r=c[3528586]|0;if((r|0)==0){c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}gg[r&4095](m&65535,i);break};case 0:{f4Z(1);break};case 1:{f4_(1);break};case 2:{f4Z(2);break};case 3:{f4_(2);break};case 4:{f4Z(4);break};case 5:{f4_(4);break};case 6:{f4Z(8);break};case 7:{f4_(8);break};case 8:{f4Z(16);break};case 9:{f4_(16);break};case 10:{f4Z(32);break};case 11:{f4_(32);break};case 12:{f4Z(64);break};case 13:{f4_(64);break};case 14:{f4Z(-128);break};case 15:{f4_(-128);break};case 16:{c[2426866]=0;i=b[4830406]|0;b[4830406]=i+1&65535;m=c[2443666]|0;r=c[3528996]|0;k=c[9702704+((m&(i&65535))>>>(r>>>0)<<2)>>2]|0;do{if((k|0)==0){l=c[2385590]|0;if((l|0)==0){gK=0;gL=m;gM=r;break}eg=gj[l&4095](m&(i&65535)&65535)|0;gK=eg;gL=c[2443666]|0;gM=c[3528996]|0}else{gK=a[k+(c[2385780]&(m&(i&65535)))|0]|0;gL=m;gM=r}}while(0);a[9707464]=gK;r=c[2426866]|0;m=r&65535&gL;i=c[9702704+(m>>>(gM>>>0)<<2)>>2]|0;do{if((i|0)==0){k=c[2385590]|0;if((k|0)==0){gN=0;gO=r;gP=gL;gQ=gM;break}eg=gj[k&4095](m&65535)|0;gN=eg;gO=c[2426866]|0;gP=c[2443666]|0;gQ=c[3528996]|0}else{gN=a[i+(c[2385780]&m)|0]|0;gO=r;gP=gL;gQ=gM}}while(0);r=gN|1;m=gO&65535&gP;i=c[9703728+(m>>>(gQ>>>0)<<2)>>2]|0;if((i|0)!=0){a[i+(c[2385780]&m)|0]=r;c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}i=c[3528586]|0;if((i|0)==0){c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}gg[i&4095](m&65535,r);break};case 17:{c[2426866]=0;r=b[4830406]|0;b[4830406]=r+1&65535;m=c[2443666]|0;i=c[3528996]|0;eg=c[9702704+((m&(r&65535))>>>(i>>>0)<<2)>>2]|0;do{if((eg|0)==0){k=c[2385590]|0;if((k|0)==0){gR=0;gS=m;gT=i;break}l=gj[k&4095](m&(r&65535)&65535)|0;gR=l;gS=c[2443666]|0;gT=c[3528996]|0}else{gR=a[eg+(c[2385780]&(m&(r&65535)))|0]|0;gS=m;gT=i}}while(0);a[9707464]=gR;i=c[2426866]|0;m=i&65535&gS;r=c[9702704+(m>>>(gT>>>0)<<2)>>2]|0;do{if((r|0)==0){eg=c[2385590]|0;if((eg|0)==0){gU=0;gV=i;gW=gS;gX=gT;break}l=gj[eg&4095](m&65535)|0;gU=l;gV=c[2426866]|0;gW=c[2443666]|0;gX=c[3528996]|0}else{gU=a[r+(c[2385780]&m)|0]|0;gV=i;gW=gS;gX=gT}}while(0);i=gU&-2;m=gV&65535&gW;r=c[9703728+(m>>>(gX>>>0)<<2)>>2]|0;if((r|0)!=0){a[r+(c[2385780]&m)|0]=i;c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}r=c[3528586]|0;if((r|0)==0){c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}gg[r&4095](m&65535,i);break};case 18:{c[2426866]=0;i=b[4830406]|0;b[4830406]=i+1&65535;m=c[2443666]|0;r=c[3528996]|0;l=c[9702704+((m&(i&65535))>>>(r>>>0)<<2)>>2]|0;do{if((l|0)==0){eg=c[2385590]|0;if((eg|0)==0){gY=0;gZ=m;g_=r;break}k=gj[eg&4095](m&(i&65535)&65535)|0;gY=k;gZ=c[2443666]|0;g_=c[3528996]|0}else{gY=a[l+(c[2385780]&(m&(i&65535)))|0]|0;gZ=m;g_=r}}while(0);a[9707464]=gY;r=c[2426866]|0;m=r&65535&gZ;i=c[9702704+(m>>>(g_>>>0)<<2)>>2]|0;do{if((i|0)==0){l=c[2385590]|0;if((l|0)==0){g$=0;g0=r;g1=gZ;g2=g_;break}k=gj[l&4095](m&65535)|0;g$=k;g0=c[2426866]|0;g1=c[2443666]|0;g2=c[3528996]|0}else{g$=a[i+(c[2385780]&m)|0]|0;g0=r;g1=gZ;g2=g_}}while(0);r=g$|2;m=g0&65535&g1;i=c[9703728+(m>>>(g2>>>0)<<2)>>2]|0;if((i|0)!=0){a[i+(c[2385780]&m)|0]=r;c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}i=c[3528586]|0;if((i|0)==0){c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}gg[i&4095](m&65535,r);break};case 19:{c[2426866]=0;r=b[4830406]|0;b[4830406]=r+1&65535;m=c[2443666]|0;i=c[3528996]|0;k=c[9702704+((m&(r&65535))>>>(i>>>0)<<2)>>2]|0;do{if((k|0)==0){l=c[2385590]|0;if((l|0)==0){g3=0;g4=m;g5=i;break}eg=gj[l&4095](m&(r&65535)&65535)|0;g3=eg;g4=c[2443666]|0;g5=c[3528996]|0}else{g3=a[k+(c[2385780]&(m&(r&65535)))|0]|0;g4=m;g5=i}}while(0);a[9707464]=g3;i=c[2426866]|0;m=i&65535&g4;r=c[9702704+(m>>>(g5>>>0)<<2)>>2]|0;do{if((r|0)==0){k=c[2385590]|0;if((k|0)==0){g6=0;g7=i;g8=g4;g9=g5;break}eg=gj[k&4095](m&65535)|0;g6=eg;g7=c[2426866]|0;g8=c[2443666]|0;g9=c[3528996]|0}else{g6=a[r+(c[2385780]&m)|0]|0;g7=i;g8=g4;g9=g5}}while(0);i=g6&-3;m=g7&65535&g8;r=c[9703728+(m>>>(g9>>>0)<<2)>>2]|0;if((r|0)!=0){a[r+(c[2385780]&m)|0]=i;c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}r=c[3528586]|0;if((r|0)==0){c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}gg[r&4095](m&65535,i);break};case 20:{c[2426866]=0;i=b[4830406]|0;b[4830406]=i+1&65535;m=c[2443666]|0;r=c[3528996]|0;eg=c[9702704+((m&(i&65535))>>>(r>>>0)<<2)>>2]|0;do{if((eg|0)==0){k=c[2385590]|0;if((k|0)==0){ha=0;hb=m;hc=r;break}l=gj[k&4095](m&(i&65535)&65535)|0;ha=l;hb=c[2443666]|0;hc=c[3528996]|0}else{ha=a[eg+(c[2385780]&(m&(i&65535)))|0]|0;hb=m;hc=r}}while(0);a[9707464]=ha;r=c[2426866]|0;m=r&65535&hb;i=c[9702704+(m>>>(hc>>>0)<<2)>>2]|0;do{if((i|0)==0){eg=c[2385590]|0;if((eg|0)==0){hd=0;he=r;hf=hb;hg=hc;break}l=gj[eg&4095](m&65535)|0;hd=l;he=c[2426866]|0;hf=c[2443666]|0;hg=c[3528996]|0}else{hd=a[i+(c[2385780]&m)|0]|0;he=r;hf=hb;hg=hc}}while(0);r=hd|4;m=he&65535&hf;i=c[9703728+(m>>>(hg>>>0)<<2)>>2]|0;if((i|0)!=0){a[i+(c[2385780]&m)|0]=r;c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}i=c[3528586]|0;if((i|0)==0){c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}gg[i&4095](m&65535,r);break};case 21:{c[2426866]=0;r=b[4830406]|0;b[4830406]=r+1&65535;m=c[2443666]|0;i=c[3528996]|0;l=c[9702704+((m&(r&65535))>>>(i>>>0)<<2)>>2]|0;do{if((l|0)==0){eg=c[2385590]|0;if((eg|0)==0){hh=0;hi=m;hj=i;break}k=gj[eg&4095](m&(r&65535)&65535)|0;hh=k;hi=c[2443666]|0;hj=c[3528996]|0}else{hh=a[l+(c[2385780]&(m&(r&65535)))|0]|0;hi=m;hj=i}}while(0);a[9707464]=hh;i=c[2426866]|0;m=i&65535&hi;r=c[9702704+(m>>>(hj>>>0)<<2)>>2]|0;do{if((r|0)==0){l=c[2385590]|0;if((l|0)==0){hk=0;hl=i;hm=hi;hn=hj;break}k=gj[l&4095](m&65535)|0;hk=k;hl=c[2426866]|0;hm=c[2443666]|0;hn=c[3528996]|0}else{hk=a[r+(c[2385780]&m)|0]|0;hl=i;hm=hi;hn=hj}}while(0);i=hk&-5;m=hl&65535&hm;r=c[9703728+(m>>>(hn>>>0)<<2)>>2]|0;if((r|0)!=0){a[r+(c[2385780]&m)|0]=i;c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}r=c[3528586]|0;if((r|0)==0){c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}gg[r&4095](m&65535,i);break};case 22:{c[2426866]=0;i=b[4830406]|0;b[4830406]=i+1&65535;m=c[2443666]|0;r=c[3528996]|0;k=c[9702704+((m&(i&65535))>>>(r>>>0)<<2)>>2]|0;do{if((k|0)==0){l=c[2385590]|0;if((l|0)==0){ho=0;hp=m;hq=r;break}eg=gj[l&4095](m&(i&65535)&65535)|0;ho=eg;hp=c[2443666]|0;hq=c[3528996]|0}else{ho=a[k+(c[2385780]&(m&(i&65535)))|0]|0;hp=m;hq=r}}while(0);a[9707464]=ho;r=c[2426866]|0;m=r&65535&hp;i=c[9702704+(m>>>(hq>>>0)<<2)>>2]|0;do{if((i|0)==0){k=c[2385590]|0;if((k|0)==0){hr=0;hs=r;ht=hp;hu=hq;break}eg=gj[k&4095](m&65535)|0;hr=eg;hs=c[2426866]|0;ht=c[2443666]|0;hu=c[3528996]|0}else{hr=a[i+(c[2385780]&m)|0]|0;hs=r;ht=hp;hu=hq}}while(0);r=hr|8;m=hs&65535&ht;i=c[9703728+(m>>>(hu>>>0)<<2)>>2]|0;if((i|0)!=0){a[i+(c[2385780]&m)|0]=r;c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}i=c[3528586]|0;if((i|0)==0){c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}gg[i&4095](m&65535,r);break};case 23:{c[2426866]=0;r=b[4830406]|0;b[4830406]=r+1&65535;m=c[2443666]|0;i=c[3528996]|0;eg=c[9702704+((m&(r&65535))>>>(i>>>0)<<2)>>2]|0;do{if((eg|0)==0){k=c[2385590]|0;if((k|0)==0){hv=0;hw=m;hx=i;break}l=gj[k&4095](m&(r&65535)&65535)|0;hv=l;hw=c[2443666]|0;hx=c[3528996]|0}else{hv=a[eg+(c[2385780]&(m&(r&65535)))|0]|0;hw=m;hx=i}}while(0);a[9707464]=hv;i=c[2426866]|0;m=i&65535&hw;r=c[9702704+(m>>>(hx>>>0)<<2)>>2]|0;do{if((r|0)==0){eg=c[2385590]|0;if((eg|0)==0){hy=0;hz=i;hA=hw;hB=hx;break}l=gj[eg&4095](m&65535)|0;hy=l;hz=c[2426866]|0;hA=c[2443666]|0;hB=c[3528996]|0}else{hy=a[r+(c[2385780]&m)|0]|0;hz=i;hA=hw;hB=hx}}while(0);i=hy&-9;m=hz&65535&hA;r=c[9703728+(m>>>(hB>>>0)<<2)>>2]|0;if((r|0)!=0){a[r+(c[2385780]&m)|0]=i;c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}r=c[3528586]|0;if((r|0)==0){c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}gg[r&4095](m&65535,i);break};case 24:{c[2426866]=0;i=b[4830406]|0;b[4830406]=i+1&65535;m=c[2443666]|0;r=c[3528996]|0;l=c[9702704+((m&(i&65535))>>>(r>>>0)<<2)>>2]|0;do{if((l|0)==0){eg=c[2385590]|0;if((eg|0)==0){hC=0;hD=m;hE=r;break}k=gj[eg&4095](m&(i&65535)&65535)|0;hC=k;hD=c[2443666]|0;hE=c[3528996]|0}else{hC=a[l+(c[2385780]&(m&(i&65535)))|0]|0;hD=m;hE=r}}while(0);a[9707464]=hC;r=c[2426866]|0;m=r&65535&hD;i=c[9702704+(m>>>(hE>>>0)<<2)>>2]|0;do{if((i|0)==0){l=c[2385590]|0;if((l|0)==0){hF=0;hG=r;hH=hD;hI=hE;break}k=gj[l&4095](m&65535)|0;hF=k;hG=c[2426866]|0;hH=c[2443666]|0;hI=c[3528996]|0}else{hF=a[i+(c[2385780]&m)|0]|0;hG=r;hH=hD;hI=hE}}while(0);r=hF|16;m=hG&65535&hH;i=c[9703728+(m>>>(hI>>>0)<<2)>>2]|0;if((i|0)!=0){a[i+(c[2385780]&m)|0]=r;c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}i=c[3528586]|0;if((i|0)==0){c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}gg[i&4095](m&65535,r);break};case 25:{c[2426866]=0;r=b[4830406]|0;b[4830406]=r+1&65535;m=c[2443666]|0;i=c[3528996]|0;k=c[9702704+((m&(r&65535))>>>(i>>>0)<<2)>>2]|0;do{if((k|0)==0){l=c[2385590]|0;if((l|0)==0){hJ=0;hK=m;hL=i;break}eg=gj[l&4095](m&(r&65535)&65535)|0;hJ=eg;hK=c[2443666]|0;hL=c[3528996]|0}else{hJ=a[k+(c[2385780]&(m&(r&65535)))|0]|0;hK=m;hL=i}}while(0);a[9707464]=hJ;i=c[2426866]|0;m=i&65535&hK;r=c[9702704+(m>>>(hL>>>0)<<2)>>2]|0;do{if((r|0)==0){k=c[2385590]|0;if((k|0)==0){hM=0;hN=i;hO=hK;hP=hL;break}eg=gj[k&4095](m&65535)|0;hM=eg;hN=c[2426866]|0;hO=c[2443666]|0;hP=c[3528996]|0}else{hM=a[r+(c[2385780]&m)|0]|0;hN=i;hO=hK;hP=hL}}while(0);i=hM&-17;m=hN&65535&hO;r=c[9703728+(m>>>(hP>>>0)<<2)>>2]|0;if((r|0)!=0){a[r+(c[2385780]&m)|0]=i;c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}r=c[3528586]|0;if((r|0)==0){c[f+23432>>2]=2;c[f+23436>>2]=100;break OL}gg[r&4095](m&65535,i);break};default:{}}}}while(0);c[f+23416>>2]=g}
function c6z(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=-32768;b[a+4>>1]=(d[c+1|0]|0)+e&65535;b[a+6>>1]=(d[c+2|0]|0)+e&65535;b[a+8>>1]=-32768;b[a+10>>1]=-32768;b[a+12>>1]=-32768;b[a+14>>1]=-32768;return 3}function c6A(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=-32768;b[a+4>>1]=(d[c]|0)+e&65535;b[a+6>>1]=(d[c+1|0]|0)+e&65535;b[a+8>>1]=-32768;b[a+10>>1]=-32768;b[a+12>>1]=-32768;b[a+14>>1]=-32768;return 2}function c6B(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=(d[c+1|0]|0)+e&65535;b[a+4>>1]=-32768;b[a+6>>1]=(d[c+2|0]|0)+e&65535;b[a+8>>1]=-32768;b[a+10>>1]=-32768;b[a+12>>1]=-32768;b[a+14>>1]=-32768;return 3}function c6C(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=(d[c]|0)+e&65535;b[a+4>>1]=-32768;b[a+6>>1]=(d[c+1|0]|0)+e&65535;b[a+8>>1]=-32768;b[a+10>>1]=-32768;b[a+12>>1]=-32768;b[a+14>>1]=-32768;return 2}function c6D(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=-32768;b[a+4>>1]=-32768;b[a+6>>1]=(d[c+1|0]|0)+e&65535;b[a+8>>1]=-32768;b[a+10>>1]=-32768;b[a+12>>1]=-32768;b[a+14>>1]=-32768;return 2}function c6E(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=-32768;b[a+4>>1]=-32768;b[a+6>>1]=(d[c]|0)+e&65535;b[a+8>>1]=-32768;b[a+10>>1]=-32768;b[a+12>>1]=-32768;b[a+14>>1]=-32768;return 1}function c6F(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=(d[c+1|0]|0)+e&65535;b[a+4>>1]=(d[c+2|0]|0)+e&65535;b[a+6>>1]=-32768;b[a+8>>1]=-32768;b[a+10>>1]=-32768;b[a+12>>1]=-32768;b[a+14>>1]=-32768;return 3}function c6G(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=(d[c]|0)+e&65535;b[a+4>>1]=(d[c+1|0]|0)+e&65535;b[a+6>>1]=-32768;b[a+8>>1]=-32768;b[a+10>>1]=-32768;b[a+12>>1]=-32768;b[a+14>>1]=-32768;return 2}function c6H(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=-32768;b[a+4>>1]=(d[c+1|0]|0)+e&65535;b[a+6>>1]=-32768;b[a+8>>1]=-32768;b[a+10>>1]=-32768;b[a+12>>1]=-32768;b[a+14>>1]=-32768;return 2}function c6I(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=-32768;b[a+4>>1]=(d[c]|0)+e&65535;b[a+6>>1]=-32768;b[a+8>>1]=-32768;b[a+10>>1]=-32768;b[a+12>>1]=-32768;b[a+14>>1]=-32768;return 1}function c6J(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=(d[c+1|0]|0)+e&65535;b[a+4>>1]=-32768;b[a+6>>1]=-32768;b[a+8>>1]=-32768;b[a+10>>1]=-32768;b[a+12>>1]=-32768;b[a+14>>1]=-32768;return 2}function c6K(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=-32768;b[a+2>>1]=(d[c]|0)+e&65535;b[a+4>>1]=-32768;b[a+6>>1]=-32768;b[a+8>>1]=-32768;b[a+10>>1]=-32768;b[a+12>>1]=-32768;b[a+14>>1]=-32768;return 1}function c6L(a,c,e){a=a|0;c=c|0;e=e|0;b[a>>1]=(d[c]|0)+e&65535;b[a+2>>1]=-32768;b[a+4>>1]=-32768;b[a+6>>1]=-32768;b[a+8>>1]=-32768;b[a+10>>1]=-32768;b[a+12>>1]=-32768;b[a+14>>1]=-32768;return 1}function c6M(a,c,d){a=a|0;c=c|0;d=d|0;b[a>>1]=-32768;b[a+2>>1]=-32768;b[a+4>>1]=-32768;b[a+6>>1]=-32768;b[a+8>>1]=-32768;b[a+10>>1]=-32768;b[a+12>>1]=-32768;b[a+14>>1]=-32768;return 0}function c6N(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+2>>1]=(d[f+1|0]|0)+g&65535;a[e+1|0]=i;b[c+4>>1]=(d[f+2|0]|0)+g&65535;a[e+2|0]=i;b[c+6>>1]=(d[f+3|0]|0)+g&65535;a[e+3|0]=i;b[c+8>>1]=(d[f+4|0]|0)+g&65535;a[e+4|0]=i;b[c+10>>1]=(d[f+5|0]|0)+g&65535;a[e+5|0]=i;b[c+12>>1]=(d[f+6|0]|0)+g&65535;a[e+6|0]=i;b[c+14>>1]=(d[f+7|0]|0)+g&65535;a[e+7|0]=i;return 8}function c6O(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+2>>1]=(d[f]|0)+g&65535;i=h&255;a[e+1|0]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+8>>1]=(d[f+3|0]|0)+g&65535;a[e+4|0]=i;b[c+10>>1]=(d[f+4|0]|0)+g&65535;a[e+5|0]=i;b[c+12>>1]=(d[f+5|0]|0)+g&65535;a[e+6|0]=i;b[c+14>>1]=(d[f+6|0]|0)+g&65535;a[e+7|0]=i;return 7}function c6P(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+8>>1]=(d[f+3|0]|0)+g&65535;a[e+4|0]=i;b[c+10>>1]=(d[f+4|0]|0)+g&65535;a[e+5|0]=i;b[c+12>>1]=(d[f+5|0]|0)+g&65535;a[e+6|0]=i;b[c+14>>1]=(d[f+6|0]|0)+g&65535;a[e+7|0]=i;return 7}function c6Q(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+4>>1]=(d[f]|0)+g&65535;i=h&255;a[e+2|0]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+10>>1]=(d[f+3|0]|0)+g&65535;a[e+5|0]=i;b[c+12>>1]=(d[f+4|0]|0)+g&65535;a[e+6|0]=i;b[c+14>>1]=(d[f+5|0]|0)+g&65535;a[e+7|0]=i;return 6}function c6R(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+2>>1]=(d[f+1|0]|0)+g&65535;a[e+1|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+8>>1]=(d[f+3|0]|0)+g&65535;a[e+4|0]=i;b[c+10>>1]=(d[f+4|0]|0)+g&65535;a[e+5|0]=i;b[c+12>>1]=(d[f+5|0]|0)+g&65535;a[e+6|0]=i;b[c+14>>1]=(d[f+6|0]|0)+g&65535;a[e+7|0]=i;return 7}function c6S(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+2>>1]=(d[f]|0)+g&65535;i=h&255;a[e+1|0]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+10>>1]=(d[f+3|0]|0)+g&65535;a[e+5|0]=i;b[c+12>>1]=(d[f+4|0]|0)+g&65535;a[e+6|0]=i;b[c+14>>1]=(d[f+5|0]|0)+g&65535;a[e+7|0]=i;return 6}function c6T(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+10>>1]=(d[f+3|0]|0)+g&65535;a[e+5|0]=i;b[c+12>>1]=(d[f+4|0]|0)+g&65535;a[e+6|0]=i;b[c+14>>1]=(d[f+5|0]|0)+g&65535;a[e+7|0]=i;return 6}function c6U(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+6>>1]=(d[f]|0)+g&65535;i=h&255;a[e+3|0]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;b[c+10>>1]=(d[f+2|0]|0)+g&65535;a[e+5|0]=i;b[c+12>>1]=(d[f+3|0]|0)+g&65535;a[e+6|0]=i;b[c+14>>1]=(d[f+4|0]|0)+g&65535;a[e+7|0]=i;return 5}function c6V(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+2>>1]=(d[f+1|0]|0)+g&65535;a[e+1|0]=i;b[c+4>>1]=(d[f+2|0]|0)+g&65535;a[e+2|0]=i;b[c+8>>1]=(d[f+3|0]|0)+g&65535;a[e+4|0]=i;b[c+10>>1]=(d[f+4|0]|0)+g&65535;a[e+5|0]=i;b[c+12>>1]=(d[f+5|0]|0)+g&65535;a[e+6|0]=i;b[c+14>>1]=(d[f+6|0]|0)+g&65535;a[e+7|0]=i;return 7}function c6W(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+2>>1]=(d[f]|0)+g&65535;i=h&255;a[e+1|0]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+10>>1]=(d[f+3|0]|0)+g&65535;a[e+5|0]=i;b[c+12>>1]=(d[f+4|0]|0)+g&65535;a[e+6|0]=i;b[c+14>>1]=(d[f+5|0]|0)+g&65535;a[e+7|0]=i;return 6}function c6X(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+10>>1]=(d[f+3|0]|0)+g&65535;a[e+5|0]=i;b[c+12>>1]=(d[f+4|0]|0)+g&65535;a[e+6|0]=i;b[c+14>>1]=(d[f+5|0]|0)+g&65535;a[e+7|0]=i;return 6}function c6Y(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+4>>1]=(d[f]|0)+g&65535;i=h&255;a[e+2|0]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;b[c+10>>1]=(d[f+2|0]|0)+g&65535;a[e+5|0]=i;b[c+12>>1]=(d[f+3|0]|0)+g&65535;a[e+6|0]=i;b[c+14>>1]=(d[f+4|0]|0)+g&65535;a[e+7|0]=i;return 5}function c6Z(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+2>>1]=(d[f+1|0]|0)+g&65535;a[e+1|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+10>>1]=(d[f+3|0]|0)+g&65535;a[e+5|0]=i;b[c+12>>1]=(d[f+4|0]|0)+g&65535;a[e+6|0]=i;b[c+14>>1]=(d[f+5|0]|0)+g&65535;a[e+7|0]=i;return 6}function c6_(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+2>>1]=(d[f]|0)+g&65535;i=h&255;a[e+1|0]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;b[c+10>>1]=(d[f+2|0]|0)+g&65535;a[e+5|0]=i;b[c+12>>1]=(d[f+3|0]|0)+g&65535;a[e+6|0]=i;b[c+14>>1]=(d[f+4|0]|0)+g&65535;a[e+7|0]=i;return 5}function c6$(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;b[c+10>>1]=(d[f+2|0]|0)+g&65535;a[e+5|0]=i;b[c+12>>1]=(d[f+3|0]|0)+g&65535;a[e+6|0]=i;b[c+14>>1]=(d[f+4|0]|0)+g&65535;a[e+7|0]=i;return 5}function c60(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+8>>1]=(d[f]|0)+g&65535;i=h&255;a[e+4|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;b[c+12>>1]=(d[f+2|0]|0)+g&65535;a[e+6|0]=i;b[c+14>>1]=(d[f+3|0]|0)+g&65535;a[e+7|0]=i;return 4}function c61(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+2>>1]=(d[f+1|0]|0)+g&65535;a[e+1|0]=i;b[c+4>>1]=(d[f+2|0]|0)+g&65535;a[e+2|0]=i;b[c+6>>1]=(d[f+3|0]|0)+g&65535;a[e+3|0]=i;b[c+10>>1]=(d[f+4|0]|0)+g&65535;a[e+5|0]=i;b[c+12>>1]=(d[f+5|0]|0)+g&65535;a[e+6|0]=i;b[c+14>>1]=(d[f+6|0]|0)+g&65535;a[e+7|0]=i;return 7}function c62(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+2>>1]=(d[f]|0)+g&65535;i=h&255;a[e+1|0]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+10>>1]=(d[f+3|0]|0)+g&65535;a[e+5|0]=i;b[c+12>>1]=(d[f+4|0]|0)+g&65535;a[e+6|0]=i;b[c+14>>1]=(d[f+5|0]|0)+g&65535;a[e+7|0]=i;return 6}function c63(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+10>>1]=(d[f+3|0]|0)+g&65535;a[e+5|0]=i;b[c+12>>1]=(d[f+4|0]|0)+g&65535;a[e+6|0]=i;b[c+14>>1]=(d[f+5|0]|0)+g&65535;a[e+7|0]=i;return 6}function c64(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+4>>1]=(d[f]|0)+g&65535;i=h&255;a[e+2|0]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;b[c+10>>1]=(d[f+2|0]|0)+g&65535;a[e+5|0]=i;b[c+12>>1]=(d[f+3|0]|0)+g&65535;a[e+6|0]=i;b[c+14>>1]=(d[f+4|0]|0)+g&65535;a[e+7|0]=i;return 5}function c65(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+2>>1]=(d[f+1|0]|0)+g&65535;a[e+1|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+10>>1]=(d[f+3|0]|0)+g&65535;a[e+5|0]=i;b[c+12>>1]=(d[f+4|0]|0)+g&65535;a[e+6|0]=i;b[c+14>>1]=(d[f+5|0]|0)+g&65535;a[e+7|0]=i;return 6}function c66(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+2>>1]=(d[f]|0)+g&65535;i=h&255;a[e+1|0]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;b[c+10>>1]=(d[f+2|0]|0)+g&65535;a[e+5|0]=i;b[c+12>>1]=(d[f+3|0]|0)+g&65535;a[e+6|0]=i;b[c+14>>1]=(d[f+4|0]|0)+g&65535;a[e+7|0]=i;return 5}function c67(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;b[c+10>>1]=(d[f+2|0]|0)+g&65535;a[e+5|0]=i;b[c+12>>1]=(d[f+3|0]|0)+g&65535;a[e+6|0]=i;b[c+14>>1]=(d[f+4|0]|0)+g&65535;a[e+7|0]=i;return 5}function c68(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+6>>1]=(d[f]|0)+g&65535;i=h&255;a[e+3|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;b[c+12>>1]=(d[f+2|0]|0)+g&65535;a[e+6|0]=i;b[c+14>>1]=(d[f+3|0]|0)+g&65535;a[e+7|0]=i;return 4}function c69(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+2>>1]=(d[f+1|0]|0)+g&65535;a[e+1|0]=i;b[c+4>>1]=(d[f+2|0]|0)+g&65535;a[e+2|0]=i;b[c+10>>1]=(d[f+3|0]|0)+g&65535;a[e+5|0]=i;b[c+12>>1]=(d[f+4|0]|0)+g&65535;a[e+6|0]=i;b[c+14>>1]=(d[f+5|0]|0)+g&65535;a[e+7|0]=i;return 6}function c7a(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+2>>1]=(d[f]|0)+g&65535;i=h&255;a[e+1|0]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;b[c+10>>1]=(d[f+2|0]|0)+g&65535;a[e+5|0]=i;b[c+12>>1]=(d[f+3|0]|0)+g&65535;a[e+6|0]=i;b[c+14>>1]=(d[f+4|0]|0)+g&65535;a[e+7|0]=i;return 5}function c7b(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;b[c+10>>1]=(d[f+2|0]|0)+g&65535;a[e+5|0]=i;b[c+12>>1]=(d[f+3|0]|0)+g&65535;a[e+6|0]=i;b[c+14>>1]=(d[f+4|0]|0)+g&65535;a[e+7|0]=i;return 5}function c7c(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+4>>1]=(d[f]|0)+g&65535;i=h&255;a[e+2|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;b[c+12>>1]=(d[f+2|0]|0)+g&65535;a[e+6|0]=i;b[c+14>>1]=(d[f+3|0]|0)+g&65535;a[e+7|0]=i;return 4}function c7d(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+2>>1]=(d[f+1|0]|0)+g&65535;a[e+1|0]=i;b[c+10>>1]=(d[f+2|0]|0)+g&65535;a[e+5|0]=i;b[c+12>>1]=(d[f+3|0]|0)+g&65535;a[e+6|0]=i;b[c+14>>1]=(d[f+4|0]|0)+g&65535;a[e+7|0]=i;return 5}function c7e(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+2>>1]=(d[f]|0)+g&65535;i=h&255;a[e+1|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;b[c+12>>1]=(d[f+2|0]|0)+g&65535;a[e+6|0]=i;b[c+14>>1]=(d[f+3|0]|0)+g&65535;a[e+7|0]=i;return 4}function c7f(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;b[c+12>>1]=(d[f+2|0]|0)+g&65535;a[e+6|0]=i;b[c+14>>1]=(d[f+3|0]|0)+g&65535;a[e+7|0]=i;return 4}function c7g(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+10>>1]=(d[f]|0)+g&65535;i=h&255;a[e+5|0]=i;b[c+12>>1]=(d[f+1|0]|0)+g&65535;a[e+6|0]=i;b[c+14>>1]=(d[f+2|0]|0)+g&65535;a[e+7|0]=i;return 3}function c7h(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+2>>1]=(d[f+1|0]|0)+g&65535;a[e+1|0]=i;b[c+4>>1]=(d[f+2|0]|0)+g&65535;a[e+2|0]=i;b[c+6>>1]=(d[f+3|0]|0)+g&65535;a[e+3|0]=i;b[c+8>>1]=(d[f+4|0]|0)+g&65535;a[e+4|0]=i;b[c+12>>1]=(d[f+5|0]|0)+g&65535;a[e+6|0]=i;b[c+14>>1]=(d[f+6|0]|0)+g&65535;a[e+7|0]=i;return 7}function c7i(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+2>>1]=(d[f]|0)+g&65535;i=h&255;a[e+1|0]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+8>>1]=(d[f+3|0]|0)+g&65535;a[e+4|0]=i;b[c+12>>1]=(d[f+4|0]|0)+g&65535;a[e+6|0]=i;b[c+14>>1]=(d[f+5|0]|0)+g&65535;a[e+7|0]=i;return 6}function c7j(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+8>>1]=(d[f+3|0]|0)+g&65535;a[e+4|0]=i;b[c+12>>1]=(d[f+4|0]|0)+g&65535;a[e+6|0]=i;b[c+14>>1]=(d[f+5|0]|0)+g&65535;a[e+7|0]=i;return 6}function c7k(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+4>>1]=(d[f]|0)+g&65535;i=h&255;a[e+2|0]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+12>>1]=(d[f+3|0]|0)+g&65535;a[e+6|0]=i;b[c+14>>1]=(d[f+4|0]|0)+g&65535;a[e+7|0]=i;return 5}function c7l(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+2>>1]=(d[f+1|0]|0)+g&65535;a[e+1|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+8>>1]=(d[f+3|0]|0)+g&65535;a[e+4|0]=i;b[c+12>>1]=(d[f+4|0]|0)+g&65535;a[e+6|0]=i;b[c+14>>1]=(d[f+5|0]|0)+g&65535;a[e+7|0]=i;return 6}function c7m(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+2>>1]=(d[f]|0)+g&65535;i=h&255;a[e+1|0]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+12>>1]=(d[f+3|0]|0)+g&65535;a[e+6|0]=i;b[c+14>>1]=(d[f+4|0]|0)+g&65535;a[e+7|0]=i;return 5}function c7n(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+12>>1]=(d[f+3|0]|0)+g&65535;a[e+6|0]=i;b[c+14>>1]=(d[f+4|0]|0)+g&65535;a[e+7|0]=i;return 5}function c7o(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+6>>1]=(d[f]|0)+g&65535;i=h&255;a[e+3|0]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;b[c+12>>1]=(d[f+2|0]|0)+g&65535;a[e+6|0]=i;b[c+14>>1]=(d[f+3|0]|0)+g&65535;a[e+7|0]=i;return 4}function c7p(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+2>>1]=(d[f+1|0]|0)+g&65535;a[e+1|0]=i;b[c+4>>1]=(d[f+2|0]|0)+g&65535;a[e+2|0]=i;b[c+8>>1]=(d[f+3|0]|0)+g&65535;a[e+4|0]=i;b[c+12>>1]=(d[f+4|0]|0)+g&65535;a[e+6|0]=i;b[c+14>>1]=(d[f+5|0]|0)+g&65535;a[e+7|0]=i;return 6}function c7q(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+2>>1]=(d[f]|0)+g&65535;i=h&255;a[e+1|0]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+12>>1]=(d[f+3|0]|0)+g&65535;a[e+6|0]=i;b[c+14>>1]=(d[f+4|0]|0)+g&65535;a[e+7|0]=i;return 5}function c7r(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+12>>1]=(d[f+3|0]|0)+g&65535;a[e+6|0]=i;b[c+14>>1]=(d[f+4|0]|0)+g&65535;a[e+7|0]=i;return 5}function c7s(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+4>>1]=(d[f]|0)+g&65535;i=h&255;a[e+2|0]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;b[c+12>>1]=(d[f+2|0]|0)+g&65535;a[e+6|0]=i;b[c+14>>1]=(d[f+3|0]|0)+g&65535;a[e+7|0]=i;return 4}function c7t(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+2>>1]=(d[f+1|0]|0)+g&65535;a[e+1|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+12>>1]=(d[f+3|0]|0)+g&65535;a[e+6|0]=i;b[c+14>>1]=(d[f+4|0]|0)+g&65535;a[e+7|0]=i;return 5}function c7u(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+2>>1]=(d[f]|0)+g&65535;i=h&255;a[e+1|0]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;b[c+12>>1]=(d[f+2|0]|0)+g&65535;a[e+6|0]=i;b[c+14>>1]=(d[f+3|0]|0)+g&65535;a[e+7|0]=i;return 4}function c7v(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;b[c+12>>1]=(d[f+2|0]|0)+g&65535;a[e+6|0]=i;b[c+14>>1]=(d[f+3|0]|0)+g&65535;a[e+7|0]=i;return 4}function c7w(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+8>>1]=(d[f]|0)+g&65535;i=h&255;a[e+4|0]=i;b[c+12>>1]=(d[f+1|0]|0)+g&65535;a[e+6|0]=i;b[c+14>>1]=(d[f+2|0]|0)+g&65535;a[e+7|0]=i;return 3}function c7x(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+2>>1]=(d[f+1|0]|0)+g&65535;a[e+1|0]=i;b[c+4>>1]=(d[f+2|0]|0)+g&65535;a[e+2|0]=i;b[c+6>>1]=(d[f+3|0]|0)+g&65535;a[e+3|0]=i;b[c+12>>1]=(d[f+4|0]|0)+g&65535;a[e+6|0]=i;b[c+14>>1]=(d[f+5|0]|0)+g&65535;a[e+7|0]=i;return 6}function c7y(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+2>>1]=(d[f]|0)+g&65535;i=h&255;a[e+1|0]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+12>>1]=(d[f+3|0]|0)+g&65535;a[e+6|0]=i;b[c+14>>1]=(d[f+4|0]|0)+g&65535;a[e+7|0]=i;return 5}function c7z(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+12>>1]=(d[f+3|0]|0)+g&65535;a[e+6|0]=i;b[c+14>>1]=(d[f+4|0]|0)+g&65535;a[e+7|0]=i;return 5}function c7A(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+4>>1]=(d[f]|0)+g&65535;i=h&255;a[e+2|0]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;b[c+12>>1]=(d[f+2|0]|0)+g&65535;a[e+6|0]=i;b[c+14>>1]=(d[f+3|0]|0)+g&65535;a[e+7|0]=i;return 4}function c7B(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+2>>1]=(d[f+1|0]|0)+g&65535;a[e+1|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+12>>1]=(d[f+3|0]|0)+g&65535;a[e+6|0]=i;b[c+14>>1]=(d[f+4|0]|0)+g&65535;a[e+7|0]=i;return 5}function c7C(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+2>>1]=(d[f]|0)+g&65535;i=h&255;a[e+1|0]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;b[c+12>>1]=(d[f+2|0]|0)+g&65535;a[e+6|0]=i;b[c+14>>1]=(d[f+3|0]|0)+g&65535;a[e+7|0]=i;return 4}function c7D(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;b[c+12>>1]=(d[f+2|0]|0)+g&65535;a[e+6|0]=i;b[c+14>>1]=(d[f+3|0]|0)+g&65535;a[e+7|0]=i;return 4}function c7E(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+6>>1]=(d[f]|0)+g&65535;i=h&255;a[e+3|0]=i;b[c+12>>1]=(d[f+1|0]|0)+g&65535;a[e+6|0]=i;b[c+14>>1]=(d[f+2|0]|0)+g&65535;a[e+7|0]=i;return 3}function c7F(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+2>>1]=(d[f+1|0]|0)+g&65535;a[e+1|0]=i;b[c+4>>1]=(d[f+2|0]|0)+g&65535;a[e+2|0]=i;b[c+12>>1]=(d[f+3|0]|0)+g&65535;a[e+6|0]=i;b[c+14>>1]=(d[f+4|0]|0)+g&65535;a[e+7|0]=i;return 5}function c7G(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+2>>1]=(d[f]|0)+g&65535;i=h&255;a[e+1|0]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;b[c+12>>1]=(d[f+2|0]|0)+g&65535;a[e+6|0]=i;b[c+14>>1]=(d[f+3|0]|0)+g&65535;a[e+7|0]=i;return 4}function c7H(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;b[c+12>>1]=(d[f+2|0]|0)+g&65535;a[e+6|0]=i;b[c+14>>1]=(d[f+3|0]|0)+g&65535;a[e+7|0]=i;return 4}function c7I(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+4>>1]=(d[f]|0)+g&65535;i=h&255;a[e+2|0]=i;b[c+12>>1]=(d[f+1|0]|0)+g&65535;a[e+6|0]=i;b[c+14>>1]=(d[f+2|0]|0)+g&65535;a[e+7|0]=i;return 3}function c7J(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+2>>1]=(d[f+1|0]|0)+g&65535;a[e+1|0]=i;b[c+12>>1]=(d[f+2|0]|0)+g&65535;a[e+6|0]=i;b[c+14>>1]=(d[f+3|0]|0)+g&65535;a[e+7|0]=i;return 4}function c7K(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+2>>1]=(d[f]|0)+g&65535;i=h&255;a[e+1|0]=i;b[c+12>>1]=(d[f+1|0]|0)+g&65535;a[e+6|0]=i;b[c+14>>1]=(d[f+2|0]|0)+g&65535;a[e+7|0]=i;return 3}function c7L(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+12>>1]=(d[f+1|0]|0)+g&65535;a[e+6|0]=i;b[c+14>>1]=(d[f+2|0]|0)+g&65535;a[e+7|0]=i;return 3}function c7M(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+12>>1]=(d[f]|0)+g&65535;i=h&255;a[e+6|0]=i;b[c+14>>1]=(d[f+1|0]|0)+g&65535;a[e+7|0]=i;return 2}function c7N(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+2>>1]=(d[f+1|0]|0)+g&65535;a[e+1|0]=i;b[c+4>>1]=(d[f+2|0]|0)+g&65535;a[e+2|0]=i;b[c+6>>1]=(d[f+3|0]|0)+g&65535;a[e+3|0]=i;b[c+8>>1]=(d[f+4|0]|0)+g&65535;a[e+4|0]=i;b[c+10>>1]=(d[f+5|0]|0)+g&65535;a[e+5|0]=i;b[c+14>>1]=(d[f+6|0]|0)+g&65535;a[e+7|0]=i;return 7}function c7O(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+2>>1]=(d[f]|0)+g&65535;i=h&255;a[e+1|0]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+8>>1]=(d[f+3|0]|0)+g&65535;a[e+4|0]=i;b[c+10>>1]=(d[f+4|0]|0)+g&65535;a[e+5|0]=i;b[c+14>>1]=(d[f+5|0]|0)+g&65535;a[e+7|0]=i;return 6}function c7P(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+8>>1]=(d[f+3|0]|0)+g&65535;a[e+4|0]=i;b[c+10>>1]=(d[f+4|0]|0)+g&65535;a[e+5|0]=i;b[c+14>>1]=(d[f+5|0]|0)+g&65535;a[e+7|0]=i;return 6}function c7Q(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+4>>1]=(d[f]|0)+g&65535;i=h&255;a[e+2|0]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+10>>1]=(d[f+3|0]|0)+g&65535;a[e+5|0]=i;b[c+14>>1]=(d[f+4|0]|0)+g&65535;a[e+7|0]=i;return 5}function c7R(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+2>>1]=(d[f+1|0]|0)+g&65535;a[e+1|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+8>>1]=(d[f+3|0]|0)+g&65535;a[e+4|0]=i;b[c+10>>1]=(d[f+4|0]|0)+g&65535;a[e+5|0]=i;b[c+14>>1]=(d[f+5|0]|0)+g&65535;a[e+7|0]=i;return 6}function c7S(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+2>>1]=(d[f]|0)+g&65535;i=h&255;a[e+1|0]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+10>>1]=(d[f+3|0]|0)+g&65535;a[e+5|0]=i;b[c+14>>1]=(d[f+4|0]|0)+g&65535;a[e+7|0]=i;return 5}function c7T(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+10>>1]=(d[f+3|0]|0)+g&65535;a[e+5|0]=i;b[c+14>>1]=(d[f+4|0]|0)+g&65535;a[e+7|0]=i;return 5}function c7U(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+6>>1]=(d[f]|0)+g&65535;i=h&255;a[e+3|0]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;b[c+10>>1]=(d[f+2|0]|0)+g&65535;a[e+5|0]=i;b[c+14>>1]=(d[f+3|0]|0)+g&65535;a[e+7|0]=i;return 4}function c7V(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+2>>1]=(d[f+1|0]|0)+g&65535;a[e+1|0]=i;b[c+4>>1]=(d[f+2|0]|0)+g&65535;a[e+2|0]=i;b[c+8>>1]=(d[f+3|0]|0)+g&65535;a[e+4|0]=i;b[c+10>>1]=(d[f+4|0]|0)+g&65535;a[e+5|0]=i;b[c+14>>1]=(d[f+5|0]|0)+g&65535;a[e+7|0]=i;return 6}function c7W(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+2>>1]=(d[f]|0)+g&65535;i=h&255;a[e+1|0]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+10>>1]=(d[f+3|0]|0)+g&65535;a[e+5|0]=i;b[c+14>>1]=(d[f+4|0]|0)+g&65535;a[e+7|0]=i;return 5}function c7X(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+10>>1]=(d[f+3|0]|0)+g&65535;a[e+5|0]=i;b[c+14>>1]=(d[f+4|0]|0)+g&65535;a[e+7|0]=i;return 5}function c7Y(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+4>>1]=(d[f]|0)+g&65535;i=h&255;a[e+2|0]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;b[c+10>>1]=(d[f+2|0]|0)+g&65535;a[e+5|0]=i;b[c+14>>1]=(d[f+3|0]|0)+g&65535;a[e+7|0]=i;return 4}function c7Z(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+2>>1]=(d[f+1|0]|0)+g&65535;a[e+1|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+10>>1]=(d[f+3|0]|0)+g&65535;a[e+5|0]=i;b[c+14>>1]=(d[f+4|0]|0)+g&65535;a[e+7|0]=i;return 5}function c7_(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+2>>1]=(d[f]|0)+g&65535;i=h&255;a[e+1|0]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;b[c+10>>1]=(d[f+2|0]|0)+g&65535;a[e+5|0]=i;b[c+14>>1]=(d[f+3|0]|0)+g&65535;a[e+7|0]=i;return 4}function c7$(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;b[c+10>>1]=(d[f+2|0]|0)+g&65535;a[e+5|0]=i;b[c+14>>1]=(d[f+3|0]|0)+g&65535;a[e+7|0]=i;return 4}function c70(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+8>>1]=(d[f]|0)+g&65535;i=h&255;a[e+4|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;b[c+14>>1]=(d[f+2|0]|0)+g&65535;a[e+7|0]=i;return 3}function c71(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+2>>1]=(d[f+1|0]|0)+g&65535;a[e+1|0]=i;b[c+4>>1]=(d[f+2|0]|0)+g&65535;a[e+2|0]=i;b[c+6>>1]=(d[f+3|0]|0)+g&65535;a[e+3|0]=i;b[c+10>>1]=(d[f+4|0]|0)+g&65535;a[e+5|0]=i;b[c+14>>1]=(d[f+5|0]|0)+g&65535;a[e+7|0]=i;return 6}function c72(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+2>>1]=(d[f]|0)+g&65535;i=h&255;a[e+1|0]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+10>>1]=(d[f+3|0]|0)+g&65535;a[e+5|0]=i;b[c+14>>1]=(d[f+4|0]|0)+g&65535;a[e+7|0]=i;return 5}function c73(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+10>>1]=(d[f+3|0]|0)+g&65535;a[e+5|0]=i;b[c+14>>1]=(d[f+4|0]|0)+g&65535;a[e+7|0]=i;return 5}function c74(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+4>>1]=(d[f]|0)+g&65535;i=h&255;a[e+2|0]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;b[c+10>>1]=(d[f+2|0]|0)+g&65535;a[e+5|0]=i;b[c+14>>1]=(d[f+3|0]|0)+g&65535;a[e+7|0]=i;return 4}function c75(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+2>>1]=(d[f+1|0]|0)+g&65535;a[e+1|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+10>>1]=(d[f+3|0]|0)+g&65535;a[e+5|0]=i;b[c+14>>1]=(d[f+4|0]|0)+g&65535;a[e+7|0]=i;return 5}function c76(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+2>>1]=(d[f]|0)+g&65535;i=h&255;a[e+1|0]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;b[c+10>>1]=(d[f+2|0]|0)+g&65535;a[e+5|0]=i;b[c+14>>1]=(d[f+3|0]|0)+g&65535;a[e+7|0]=i;return 4}function c77(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;b[c+10>>1]=(d[f+2|0]|0)+g&65535;a[e+5|0]=i;b[c+14>>1]=(d[f+3|0]|0)+g&65535;a[e+7|0]=i;return 4}function c78(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+6>>1]=(d[f]|0)+g&65535;i=h&255;a[e+3|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;b[c+14>>1]=(d[f+2|0]|0)+g&65535;a[e+7|0]=i;return 3}function c79(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+2>>1]=(d[f+1|0]|0)+g&65535;a[e+1|0]=i;b[c+4>>1]=(d[f+2|0]|0)+g&65535;a[e+2|0]=i;b[c+10>>1]=(d[f+3|0]|0)+g&65535;a[e+5|0]=i;b[c+14>>1]=(d[f+4|0]|0)+g&65535;a[e+7|0]=i;return 5}function c8a(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+2>>1]=(d[f]|0)+g&65535;i=h&255;a[e+1|0]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;b[c+10>>1]=(d[f+2|0]|0)+g&65535;a[e+5|0]=i;b[c+14>>1]=(d[f+3|0]|0)+g&65535;a[e+7|0]=i;return 4}function c8b(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;b[c+10>>1]=(d[f+2|0]|0)+g&65535;a[e+5|0]=i;b[c+14>>1]=(d[f+3|0]|0)+g&65535;a[e+7|0]=i;return 4}function c8c(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+4>>1]=(d[f]|0)+g&65535;i=h&255;a[e+2|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;b[c+14>>1]=(d[f+2|0]|0)+g&65535;a[e+7|0]=i;return 3}function c8d(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+2>>1]=(d[f+1|0]|0)+g&65535;a[e+1|0]=i;b[c+10>>1]=(d[f+2|0]|0)+g&65535;a[e+5|0]=i;b[c+14>>1]=(d[f+3|0]|0)+g&65535;a[e+7|0]=i;return 4}function c8e(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+2>>1]=(d[f]|0)+g&65535;i=h&255;a[e+1|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;b[c+14>>1]=(d[f+2|0]|0)+g&65535;a[e+7|0]=i;return 3}function c8f(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;b[c+14>>1]=(d[f+2|0]|0)+g&65535;a[e+7|0]=i;return 3}function c8g(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+10>>1]=(d[f]|0)+g&65535;i=h&255;a[e+5|0]=i;b[c+14>>1]=(d[f+1|0]|0)+g&65535;a[e+7|0]=i;return 2}function c8h(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+2>>1]=(d[f+1|0]|0)+g&65535;a[e+1|0]=i;b[c+4>>1]=(d[f+2|0]|0)+g&65535;a[e+2|0]=i;b[c+6>>1]=(d[f+3|0]|0)+g&65535;a[e+3|0]=i;b[c+8>>1]=(d[f+4|0]|0)+g&65535;a[e+4|0]=i;b[c+14>>1]=(d[f+5|0]|0)+g&65535;a[e+7|0]=i;return 6}function c8i(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+2>>1]=(d[f]|0)+g&65535;i=h&255;a[e+1|0]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+8>>1]=(d[f+3|0]|0)+g&65535;a[e+4|0]=i;b[c+14>>1]=(d[f+4|0]|0)+g&65535;a[e+7|0]=i;return 5}function c8j(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+8>>1]=(d[f+3|0]|0)+g&65535;a[e+4|0]=i;b[c+14>>1]=(d[f+4|0]|0)+g&65535;a[e+7|0]=i;return 5}function c8k(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+4>>1]=(d[f]|0)+g&65535;i=h&255;a[e+2|0]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+14>>1]=(d[f+3|0]|0)+g&65535;a[e+7|0]=i;return 4}function c8l(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+2>>1]=(d[f+1|0]|0)+g&65535;a[e+1|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+8>>1]=(d[f+3|0]|0)+g&65535;a[e+4|0]=i;b[c+14>>1]=(d[f+4|0]|0)+g&65535;a[e+7|0]=i;return 5}function c8m(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+2>>1]=(d[f]|0)+g&65535;i=h&255;a[e+1|0]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+14>>1]=(d[f+3|0]|0)+g&65535;a[e+7|0]=i;return 4}function c8n(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+14>>1]=(d[f+3|0]|0)+g&65535;a[e+7|0]=i;return 4}function c8o(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+6>>1]=(d[f]|0)+g&65535;i=h&255;a[e+3|0]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;b[c+14>>1]=(d[f+2|0]|0)+g&65535;a[e+7|0]=i;return 3}function c8p(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+2>>1]=(d[f+1|0]|0)+g&65535;a[e+1|0]=i;b[c+4>>1]=(d[f+2|0]|0)+g&65535;a[e+2|0]=i;b[c+8>>1]=(d[f+3|0]|0)+g&65535;a[e+4|0]=i;b[c+14>>1]=(d[f+4|0]|0)+g&65535;a[e+7|0]=i;return 5}function c8q(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+2>>1]=(d[f]|0)+g&65535;i=h&255;a[e+1|0]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+14>>1]=(d[f+3|0]|0)+g&65535;a[e+7|0]=i;return 4}function c8r(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+14>>1]=(d[f+3|0]|0)+g&65535;a[e+7|0]=i;return 4}function c8s(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+4>>1]=(d[f]|0)+g&65535;i=h&255;a[e+2|0]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;b[c+14>>1]=(d[f+2|0]|0)+g&65535;a[e+7|0]=i;return 3}function c8t(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+2>>1]=(d[f+1|0]|0)+g&65535;a[e+1|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+14>>1]=(d[f+3|0]|0)+g&65535;a[e+7|0]=i;return 4}function c8u(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+2>>1]=(d[f]|0)+g&65535;i=h&255;a[e+1|0]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;b[c+14>>1]=(d[f+2|0]|0)+g&65535;a[e+7|0]=i;return 3}function c8v(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;b[c+14>>1]=(d[f+2|0]|0)+g&65535;a[e+7|0]=i;return 3}function c8w(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+8>>1]=(d[f]|0)+g&65535;i=h&255;a[e+4|0]=i;b[c+14>>1]=(d[f+1|0]|0)+g&65535;a[e+7|0]=i;return 2}function c8x(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+2>>1]=(d[f+1|0]|0)+g&65535;a[e+1|0]=i;b[c+4>>1]=(d[f+2|0]|0)+g&65535;a[e+2|0]=i;b[c+6>>1]=(d[f+3|0]|0)+g&65535;a[e+3|0]=i;b[c+14>>1]=(d[f+4|0]|0)+g&65535;a[e+7|0]=i;return 5}function c8y(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+2>>1]=(d[f]|0)+g&65535;i=h&255;a[e+1|0]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+14>>1]=(d[f+3|0]|0)+g&65535;a[e+7|0]=i;return 4}function c8z(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+14>>1]=(d[f+3|0]|0)+g&65535;a[e+7|0]=i;return 4}function c8A(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+4>>1]=(d[f]|0)+g&65535;i=h&255;a[e+2|0]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;b[c+14>>1]=(d[f+2|0]|0)+g&65535;a[e+7|0]=i;return 3}function c8B(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+2>>1]=(d[f+1|0]|0)+g&65535;a[e+1|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+14>>1]=(d[f+3|0]|0)+g&65535;a[e+7|0]=i;return 4}function c8C(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+2>>1]=(d[f]|0)+g&65535;i=h&255;a[e+1|0]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;b[c+14>>1]=(d[f+2|0]|0)+g&65535;a[e+7|0]=i;return 3}function c8D(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;b[c+14>>1]=(d[f+2|0]|0)+g&65535;a[e+7|0]=i;return 3}function c8E(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+6>>1]=(d[f]|0)+g&65535;i=h&255;a[e+3|0]=i;b[c+14>>1]=(d[f+1|0]|0)+g&65535;a[e+7|0]=i;return 2}function c8F(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+2>>1]=(d[f+1|0]|0)+g&65535;a[e+1|0]=i;b[c+4>>1]=(d[f+2|0]|0)+g&65535;a[e+2|0]=i;b[c+14>>1]=(d[f+3|0]|0)+g&65535;a[e+7|0]=i;return 4}function c8G(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+2>>1]=(d[f]|0)+g&65535;i=h&255;a[e+1|0]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;b[c+14>>1]=(d[f+2|0]|0)+g&65535;a[e+7|0]=i;return 3}function c8H(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;b[c+14>>1]=(d[f+2|0]|0)+g&65535;a[e+7|0]=i;return 3}function c8I(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+4>>1]=(d[f]|0)+g&65535;i=h&255;a[e+2|0]=i;b[c+14>>1]=(d[f+1|0]|0)+g&65535;a[e+7|0]=i;return 2}function c8J(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+2>>1]=(d[f+1|0]|0)+g&65535;a[e+1|0]=i;b[c+14>>1]=(d[f+2|0]|0)+g&65535;a[e+7|0]=i;return 3}function c8K(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+2>>1]=(d[f]|0)+g&65535;i=h&255;a[e+1|0]=i;b[c+14>>1]=(d[f+1|0]|0)+g&65535;a[e+7|0]=i;return 2}function c8L(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+14>>1]=(d[f+1|0]|0)+g&65535;a[e+7|0]=i;return 2}function c8M(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;b[c+14>>1]=(d[f]|0)+g&65535;a[e+7|0]=h&255;return 1}function c8N(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+2>>1]=(d[f+1|0]|0)+g&65535;a[e+1|0]=i;b[c+4>>1]=(d[f+2|0]|0)+g&65535;a[e+2|0]=i;b[c+6>>1]=(d[f+3|0]|0)+g&65535;a[e+3|0]=i;b[c+8>>1]=(d[f+4|0]|0)+g&65535;a[e+4|0]=i;b[c+10>>1]=(d[f+5|0]|0)+g&65535;a[e+5|0]=i;b[c+12>>1]=(d[f+6|0]|0)+g&65535;a[e+6|0]=i;return 7}function c8O(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+2>>1]=(d[f]|0)+g&65535;i=h&255;a[e+1|0]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+8>>1]=(d[f+3|0]|0)+g&65535;a[e+4|0]=i;b[c+10>>1]=(d[f+4|0]|0)+g&65535;a[e+5|0]=i;b[c+12>>1]=(d[f+5|0]|0)+g&65535;a[e+6|0]=i;return 6}function c8P(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+8>>1]=(d[f+3|0]|0)+g&65535;a[e+4|0]=i;b[c+10>>1]=(d[f+4|0]|0)+g&65535;a[e+5|0]=i;b[c+12>>1]=(d[f+5|0]|0)+g&65535;a[e+6|0]=i;return 6}function c8Q(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+4>>1]=(d[f]|0)+g&65535;i=h&255;a[e+2|0]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+10>>1]=(d[f+3|0]|0)+g&65535;a[e+5|0]=i;b[c+12>>1]=(d[f+4|0]|0)+g&65535;a[e+6|0]=i;return 5}function c8R(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+2>>1]=(d[f+1|0]|0)+g&65535;a[e+1|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+8>>1]=(d[f+3|0]|0)+g&65535;a[e+4|0]=i;b[c+10>>1]=(d[f+4|0]|0)+g&65535;a[e+5|0]=i;b[c+12>>1]=(d[f+5|0]|0)+g&65535;a[e+6|0]=i;return 6}function c8S(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+2>>1]=(d[f]|0)+g&65535;i=h&255;a[e+1|0]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+10>>1]=(d[f+3|0]|0)+g&65535;a[e+5|0]=i;b[c+12>>1]=(d[f+4|0]|0)+g&65535;a[e+6|0]=i;return 5}function c8T(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+10>>1]=(d[f+3|0]|0)+g&65535;a[e+5|0]=i;b[c+12>>1]=(d[f+4|0]|0)+g&65535;a[e+6|0]=i;return 5}function c8U(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+6>>1]=(d[f]|0)+g&65535;i=h&255;a[e+3|0]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;b[c+10>>1]=(d[f+2|0]|0)+g&65535;a[e+5|0]=i;b[c+12>>1]=(d[f+3|0]|0)+g&65535;a[e+6|0]=i;return 4}function c8V(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+2>>1]=(d[f+1|0]|0)+g&65535;a[e+1|0]=i;b[c+4>>1]=(d[f+2|0]|0)+g&65535;a[e+2|0]=i;b[c+8>>1]=(d[f+3|0]|0)+g&65535;a[e+4|0]=i;b[c+10>>1]=(d[f+4|0]|0)+g&65535;a[e+5|0]=i;b[c+12>>1]=(d[f+5|0]|0)+g&65535;a[e+6|0]=i;return 6}function c8W(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+2>>1]=(d[f]|0)+g&65535;i=h&255;a[e+1|0]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+10>>1]=(d[f+3|0]|0)+g&65535;a[e+5|0]=i;b[c+12>>1]=(d[f+4|0]|0)+g&65535;a[e+6|0]=i;return 5}function c8X(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+10>>1]=(d[f+3|0]|0)+g&65535;a[e+5|0]=i;b[c+12>>1]=(d[f+4|0]|0)+g&65535;a[e+6|0]=i;return 5}function c8Y(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+4>>1]=(d[f]|0)+g&65535;i=h&255;a[e+2|0]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;b[c+10>>1]=(d[f+2|0]|0)+g&65535;a[e+5|0]=i;b[c+12>>1]=(d[f+3|0]|0)+g&65535;a[e+6|0]=i;return 4}function c8Z(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+2>>1]=(d[f+1|0]|0)+g&65535;a[e+1|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+10>>1]=(d[f+3|0]|0)+g&65535;a[e+5|0]=i;b[c+12>>1]=(d[f+4|0]|0)+g&65535;a[e+6|0]=i;return 5}function c8_(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+2>>1]=(d[f]|0)+g&65535;i=h&255;a[e+1|0]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;b[c+10>>1]=(d[f+2|0]|0)+g&65535;a[e+5|0]=i;b[c+12>>1]=(d[f+3|0]|0)+g&65535;a[e+6|0]=i;return 4}function c8$(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;b[c+10>>1]=(d[f+2|0]|0)+g&65535;a[e+5|0]=i;b[c+12>>1]=(d[f+3|0]|0)+g&65535;a[e+6|0]=i;return 4}function c80(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+8>>1]=(d[f]|0)+g&65535;i=h&255;a[e+4|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;b[c+12>>1]=(d[f+2|0]|0)+g&65535;a[e+6|0]=i;return 3}function c81(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+2>>1]=(d[f+1|0]|0)+g&65535;a[e+1|0]=i;b[c+4>>1]=(d[f+2|0]|0)+g&65535;a[e+2|0]=i;b[c+6>>1]=(d[f+3|0]|0)+g&65535;a[e+3|0]=i;b[c+10>>1]=(d[f+4|0]|0)+g&65535;a[e+5|0]=i;b[c+12>>1]=(d[f+5|0]|0)+g&65535;a[e+6|0]=i;return 6}function c82(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+2>>1]=(d[f]|0)+g&65535;i=h&255;a[e+1|0]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+10>>1]=(d[f+3|0]|0)+g&65535;a[e+5|0]=i;b[c+12>>1]=(d[f+4|0]|0)+g&65535;a[e+6|0]=i;return 5}function c83(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+10>>1]=(d[f+3|0]|0)+g&65535;a[e+5|0]=i;b[c+12>>1]=(d[f+4|0]|0)+g&65535;a[e+6|0]=i;return 5}function c84(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+4>>1]=(d[f]|0)+g&65535;i=h&255;a[e+2|0]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;b[c+10>>1]=(d[f+2|0]|0)+g&65535;a[e+5|0]=i;b[c+12>>1]=(d[f+3|0]|0)+g&65535;a[e+6|0]=i;return 4}function c85(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+2>>1]=(d[f+1|0]|0)+g&65535;a[e+1|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+10>>1]=(d[f+3|0]|0)+g&65535;a[e+5|0]=i;b[c+12>>1]=(d[f+4|0]|0)+g&65535;a[e+6|0]=i;return 5}function c86(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+2>>1]=(d[f]|0)+g&65535;i=h&255;a[e+1|0]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;b[c+10>>1]=(d[f+2|0]|0)+g&65535;a[e+5|0]=i;b[c+12>>1]=(d[f+3|0]|0)+g&65535;a[e+6|0]=i;return 4}function c87(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;b[c+10>>1]=(d[f+2|0]|0)+g&65535;a[e+5|0]=i;b[c+12>>1]=(d[f+3|0]|0)+g&65535;a[e+6|0]=i;return 4}function c88(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+6>>1]=(d[f]|0)+g&65535;i=h&255;a[e+3|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;b[c+12>>1]=(d[f+2|0]|0)+g&65535;a[e+6|0]=i;return 3}function c89(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+2>>1]=(d[f+1|0]|0)+g&65535;a[e+1|0]=i;b[c+4>>1]=(d[f+2|0]|0)+g&65535;a[e+2|0]=i;b[c+10>>1]=(d[f+3|0]|0)+g&65535;a[e+5|0]=i;b[c+12>>1]=(d[f+4|0]|0)+g&65535;a[e+6|0]=i;return 5}function c9a(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+2>>1]=(d[f]|0)+g&65535;i=h&255;a[e+1|0]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;b[c+10>>1]=(d[f+2|0]|0)+g&65535;a[e+5|0]=i;b[c+12>>1]=(d[f+3|0]|0)+g&65535;a[e+6|0]=i;return 4}function c9b(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;b[c+10>>1]=(d[f+2|0]|0)+g&65535;a[e+5|0]=i;b[c+12>>1]=(d[f+3|0]|0)+g&65535;a[e+6|0]=i;return 4}function c9c(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+4>>1]=(d[f]|0)+g&65535;i=h&255;a[e+2|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;b[c+12>>1]=(d[f+2|0]|0)+g&65535;a[e+6|0]=i;return 3}function c9d(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+2>>1]=(d[f+1|0]|0)+g&65535;a[e+1|0]=i;b[c+10>>1]=(d[f+2|0]|0)+g&65535;a[e+5|0]=i;b[c+12>>1]=(d[f+3|0]|0)+g&65535;a[e+6|0]=i;return 4}function c9e(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+2>>1]=(d[f]|0)+g&65535;i=h&255;a[e+1|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;b[c+12>>1]=(d[f+2|0]|0)+g&65535;a[e+6|0]=i;return 3}function c9f(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;b[c+12>>1]=(d[f+2|0]|0)+g&65535;a[e+6|0]=i;return 3}function c9g(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+10>>1]=(d[f]|0)+g&65535;i=h&255;a[e+5|0]=i;b[c+12>>1]=(d[f+1|0]|0)+g&65535;a[e+6|0]=i;return 2}function c9h(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+2>>1]=(d[f+1|0]|0)+g&65535;a[e+1|0]=i;b[c+4>>1]=(d[f+2|0]|0)+g&65535;a[e+2|0]=i;b[c+6>>1]=(d[f+3|0]|0)+g&65535;a[e+3|0]=i;b[c+8>>1]=(d[f+4|0]|0)+g&65535;a[e+4|0]=i;b[c+12>>1]=(d[f+5|0]|0)+g&65535;a[e+6|0]=i;return 6}function c9i(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+2>>1]=(d[f]|0)+g&65535;i=h&255;a[e+1|0]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+8>>1]=(d[f+3|0]|0)+g&65535;a[e+4|0]=i;b[c+12>>1]=(d[f+4|0]|0)+g&65535;a[e+6|0]=i;return 5}function c9j(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+8>>1]=(d[f+3|0]|0)+g&65535;a[e+4|0]=i;b[c+12>>1]=(d[f+4|0]|0)+g&65535;a[e+6|0]=i;return 5}function c9k(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+4>>1]=(d[f]|0)+g&65535;i=h&255;a[e+2|0]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+12>>1]=(d[f+3|0]|0)+g&65535;a[e+6|0]=i;return 4}function c9l(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+2>>1]=(d[f+1|0]|0)+g&65535;a[e+1|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+8>>1]=(d[f+3|0]|0)+g&65535;a[e+4|0]=i;b[c+12>>1]=(d[f+4|0]|0)+g&65535;a[e+6|0]=i;return 5}function c9m(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+2>>1]=(d[f]|0)+g&65535;i=h&255;a[e+1|0]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+12>>1]=(d[f+3|0]|0)+g&65535;a[e+6|0]=i;return 4}function c9n(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+12>>1]=(d[f+3|0]|0)+g&65535;a[e+6|0]=i;return 4}function c9o(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+6>>1]=(d[f]|0)+g&65535;i=h&255;a[e+3|0]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;b[c+12>>1]=(d[f+2|0]|0)+g&65535;a[e+6|0]=i;return 3}function c9p(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+2>>1]=(d[f+1|0]|0)+g&65535;a[e+1|0]=i;b[c+4>>1]=(d[f+2|0]|0)+g&65535;a[e+2|0]=i;b[c+8>>1]=(d[f+3|0]|0)+g&65535;a[e+4|0]=i;b[c+12>>1]=(d[f+4|0]|0)+g&65535;a[e+6|0]=i;return 5}function c9q(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+2>>1]=(d[f]|0)+g&65535;i=h&255;a[e+1|0]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+12>>1]=(d[f+3|0]|0)+g&65535;a[e+6|0]=i;return 4}function c9r(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+12>>1]=(d[f+3|0]|0)+g&65535;a[e+6|0]=i;return 4}function c9s(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+4>>1]=(d[f]|0)+g&65535;i=h&255;a[e+2|0]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;b[c+12>>1]=(d[f+2|0]|0)+g&65535;a[e+6|0]=i;return 3}function c9t(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+2>>1]=(d[f+1|0]|0)+g&65535;a[e+1|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+12>>1]=(d[f+3|0]|0)+g&65535;a[e+6|0]=i;return 4}function c9u(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+2>>1]=(d[f]|0)+g&65535;i=h&255;a[e+1|0]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;b[c+12>>1]=(d[f+2|0]|0)+g&65535;a[e+6|0]=i;return 3}function c9v(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;b[c+12>>1]=(d[f+2|0]|0)+g&65535;a[e+6|0]=i;return 3}function c9w(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+8>>1]=(d[f]|0)+g&65535;i=h&255;a[e+4|0]=i;b[c+12>>1]=(d[f+1|0]|0)+g&65535;a[e+6|0]=i;return 2}function c9x(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+2>>1]=(d[f+1|0]|0)+g&65535;a[e+1|0]=i;b[c+4>>1]=(d[f+2|0]|0)+g&65535;a[e+2|0]=i;b[c+6>>1]=(d[f+3|0]|0)+g&65535;a[e+3|0]=i;b[c+12>>1]=(d[f+4|0]|0)+g&65535;a[e+6|0]=i;return 5}function c9y(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+2>>1]=(d[f]|0)+g&65535;i=h&255;a[e+1|0]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+12>>1]=(d[f+3|0]|0)+g&65535;a[e+6|0]=i;return 4}function c9z(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+12>>1]=(d[f+3|0]|0)+g&65535;a[e+6|0]=i;return 4}function c9A(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+4>>1]=(d[f]|0)+g&65535;i=h&255;a[e+2|0]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;b[c+12>>1]=(d[f+2|0]|0)+g&65535;a[e+6|0]=i;return 3}function c9B(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+2>>1]=(d[f+1|0]|0)+g&65535;a[e+1|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+12>>1]=(d[f+3|0]|0)+g&65535;a[e+6|0]=i;return 4}function c9C(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+2>>1]=(d[f]|0)+g&65535;i=h&255;a[e+1|0]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;b[c+12>>1]=(d[f+2|0]|0)+g&65535;a[e+6|0]=i;return 3}function c9D(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;b[c+12>>1]=(d[f+2|0]|0)+g&65535;a[e+6|0]=i;return 3}function c9E(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+6>>1]=(d[f]|0)+g&65535;i=h&255;a[e+3|0]=i;b[c+12>>1]=(d[f+1|0]|0)+g&65535;a[e+6|0]=i;return 2}function c9F(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+2>>1]=(d[f+1|0]|0)+g&65535;a[e+1|0]=i;b[c+4>>1]=(d[f+2|0]|0)+g&65535;a[e+2|0]=i;b[c+12>>1]=(d[f+3|0]|0)+g&65535;a[e+6|0]=i;return 4}function c9G(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+2>>1]=(d[f]|0)+g&65535;i=h&255;a[e+1|0]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;b[c+12>>1]=(d[f+2|0]|0)+g&65535;a[e+6|0]=i;return 3}function c9H(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;b[c+12>>1]=(d[f+2|0]|0)+g&65535;a[e+6|0]=i;return 3}function c9I(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+4>>1]=(d[f]|0)+g&65535;i=h&255;a[e+2|0]=i;b[c+12>>1]=(d[f+1|0]|0)+g&65535;a[e+6|0]=i;return 2}function c9J(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+2>>1]=(d[f+1|0]|0)+g&65535;a[e+1|0]=i;b[c+12>>1]=(d[f+2|0]|0)+g&65535;a[e+6|0]=i;return 3}function c9K(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+2>>1]=(d[f]|0)+g&65535;i=h&255;a[e+1|0]=i;b[c+12>>1]=(d[f+1|0]|0)+g&65535;a[e+6|0]=i;return 2}function c9L(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+12>>1]=(d[f+1|0]|0)+g&65535;a[e+6|0]=i;return 2}function c9M(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;b[c+12>>1]=(d[f]|0)+g&65535;a[e+6|0]=h&255;return 1}function c9N(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+2>>1]=(d[f+1|0]|0)+g&65535;a[e+1|0]=i;b[c+4>>1]=(d[f+2|0]|0)+g&65535;a[e+2|0]=i;b[c+6>>1]=(d[f+3|0]|0)+g&65535;a[e+3|0]=i;b[c+8>>1]=(d[f+4|0]|0)+g&65535;a[e+4|0]=i;b[c+10>>1]=(d[f+5|0]|0)+g&65535;a[e+5|0]=i;return 6}function c9O(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+2>>1]=(d[f]|0)+g&65535;i=h&255;a[e+1|0]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+8>>1]=(d[f+3|0]|0)+g&65535;a[e+4|0]=i;b[c+10>>1]=(d[f+4|0]|0)+g&65535;a[e+5|0]=i;return 5}function c9P(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+8>>1]=(d[f+3|0]|0)+g&65535;a[e+4|0]=i;b[c+10>>1]=(d[f+4|0]|0)+g&65535;a[e+5|0]=i;return 5}function c9Q(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+4>>1]=(d[f]|0)+g&65535;i=h&255;a[e+2|0]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+10>>1]=(d[f+3|0]|0)+g&65535;a[e+5|0]=i;return 4}function c9R(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+2>>1]=(d[f+1|0]|0)+g&65535;a[e+1|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+8>>1]=(d[f+3|0]|0)+g&65535;a[e+4|0]=i;b[c+10>>1]=(d[f+4|0]|0)+g&65535;a[e+5|0]=i;return 5}function c9S(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+2>>1]=(d[f]|0)+g&65535;i=h&255;a[e+1|0]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+10>>1]=(d[f+3|0]|0)+g&65535;a[e+5|0]=i;return 4}function c9T(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+10>>1]=(d[f+3|0]|0)+g&65535;a[e+5|0]=i;return 4}function c9U(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+6>>1]=(d[f]|0)+g&65535;i=h&255;a[e+3|0]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;b[c+10>>1]=(d[f+2|0]|0)+g&65535;a[e+5|0]=i;return 3}function c9V(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+2>>1]=(d[f+1|0]|0)+g&65535;a[e+1|0]=i;b[c+4>>1]=(d[f+2|0]|0)+g&65535;a[e+2|0]=i;b[c+8>>1]=(d[f+3|0]|0)+g&65535;a[e+4|0]=i;b[c+10>>1]=(d[f+4|0]|0)+g&65535;a[e+5|0]=i;return 5}function c9W(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+2>>1]=(d[f]|0)+g&65535;i=h&255;a[e+1|0]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+10>>1]=(d[f+3|0]|0)+g&65535;a[e+5|0]=i;return 4}function c9X(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+10>>1]=(d[f+3|0]|0)+g&65535;a[e+5|0]=i;return 4}function c9Y(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+4>>1]=(d[f]|0)+g&65535;i=h&255;a[e+2|0]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;b[c+10>>1]=(d[f+2|0]|0)+g&65535;a[e+5|0]=i;return 3}function c9Z(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+2>>1]=(d[f+1|0]|0)+g&65535;a[e+1|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+10>>1]=(d[f+3|0]|0)+g&65535;a[e+5|0]=i;return 4}function c9_(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+2>>1]=(d[f]|0)+g&65535;i=h&255;a[e+1|0]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;b[c+10>>1]=(d[f+2|0]|0)+g&65535;a[e+5|0]=i;return 3}function c9$(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;b[c+10>>1]=(d[f+2|0]|0)+g&65535;a[e+5|0]=i;return 3}function c90(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+8>>1]=(d[f]|0)+g&65535;i=h&255;a[e+4|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;return 2}function c91(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+2>>1]=(d[f+1|0]|0)+g&65535;a[e+1|0]=i;b[c+4>>1]=(d[f+2|0]|0)+g&65535;a[e+2|0]=i;b[c+6>>1]=(d[f+3|0]|0)+g&65535;a[e+3|0]=i;b[c+10>>1]=(d[f+4|0]|0)+g&65535;a[e+5|0]=i;return 5}function c92(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+2>>1]=(d[f]|0)+g&65535;i=h&255;a[e+1|0]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+10>>1]=(d[f+3|0]|0)+g&65535;a[e+5|0]=i;return 4}function c93(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+10>>1]=(d[f+3|0]|0)+g&65535;a[e+5|0]=i;return 4}function c94(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+4>>1]=(d[f]|0)+g&65535;i=h&255;a[e+2|0]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;b[c+10>>1]=(d[f+2|0]|0)+g&65535;a[e+5|0]=i;return 3}function c95(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+2>>1]=(d[f+1|0]|0)+g&65535;a[e+1|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+10>>1]=(d[f+3|0]|0)+g&65535;a[e+5|0]=i;return 4}function c96(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+2>>1]=(d[f]|0)+g&65535;i=h&255;a[e+1|0]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;b[c+10>>1]=(d[f+2|0]|0)+g&65535;a[e+5|0]=i;return 3}function c97(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;b[c+10>>1]=(d[f+2|0]|0)+g&65535;a[e+5|0]=i;return 3}function c98(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+6>>1]=(d[f]|0)+g&65535;i=h&255;a[e+3|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;return 2}function c99(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+2>>1]=(d[f+1|0]|0)+g&65535;a[e+1|0]=i;b[c+4>>1]=(d[f+2|0]|0)+g&65535;a[e+2|0]=i;b[c+10>>1]=(d[f+3|0]|0)+g&65535;a[e+5|0]=i;return 4}function daa(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+2>>1]=(d[f]|0)+g&65535;i=h&255;a[e+1|0]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;b[c+10>>1]=(d[f+2|0]|0)+g&65535;a[e+5|0]=i;return 3}function dab(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;b[c+10>>1]=(d[f+2|0]|0)+g&65535;a[e+5|0]=i;return 3}function dac(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+4>>1]=(d[f]|0)+g&65535;i=h&255;a[e+2|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;return 2}function dad(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+2>>1]=(d[f+1|0]|0)+g&65535;a[e+1|0]=i;b[c+10>>1]=(d[f+2|0]|0)+g&65535;a[e+5|0]=i;return 3}function dae(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+2>>1]=(d[f]|0)+g&65535;i=h&255;a[e+1|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;return 2}function daf(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;return 2}function dag(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;b[c+10>>1]=(d[f]|0)+g&65535;a[e+5|0]=h&255;return 1}function dah(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+2>>1]=(d[f+1|0]|0)+g&65535;a[e+1|0]=i;b[c+4>>1]=(d[f+2|0]|0)+g&65535;a[e+2|0]=i;b[c+6>>1]=(d[f+3|0]|0)+g&65535;a[e+3|0]=i;b[c+8>>1]=(d[f+4|0]|0)+g&65535;a[e+4|0]=i;return 5}function dai(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+2>>1]=(d[f]|0)+g&65535;i=h&255;a[e+1|0]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+8>>1]=(d[f+3|0]|0)+g&65535;a[e+4|0]=i;return 4}function daj(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+8>>1]=(d[f+3|0]|0)+g&65535;a[e+4|0]=i;return 4}function dak(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+4>>1]=(d[f]|0)+g&65535;i=h&255;a[e+2|0]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;return 3}function dal(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+2>>1]=(d[f+1|0]|0)+g&65535;a[e+1|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+8>>1]=(d[f+3|0]|0)+g&65535;a[e+4|0]=i;return 4}function dam(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+2>>1]=(d[f]|0)+g&65535;i=h&255;a[e+1|0]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;return 3}function dan(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;return 3}function dao(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+6>>1]=(d[f]|0)+g&65535;i=h&255;a[e+3|0]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;return 2}function dap(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+2>>1]=(d[f+1|0]|0)+g&65535;a[e+1|0]=i;b[c+4>>1]=(d[f+2|0]|0)+g&65535;a[e+2|0]=i;b[c+8>>1]=(d[f+3|0]|0)+g&65535;a[e+4|0]=i;return 4}function daq(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+2>>1]=(d[f]|0)+g&65535;i=h&255;a[e+1|0]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;return 3}function dar(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;return 3}function das(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+4>>1]=(d[f]|0)+g&65535;i=h&255;a[e+2|0]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;return 2}function dat(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+2>>1]=(d[f+1|0]|0)+g&65535;a[e+1|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;return 3}function dau(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+2>>1]=(d[f]|0)+g&65535;i=h&255;a[e+1|0]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;return 2}function dav(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;return 2}function daw(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;b[c+8>>1]=(d[f]|0)+g&65535;a[e+4|0]=h&255;return 1}function dax(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+2>>1]=(d[f+1|0]|0)+g&65535;a[e+1|0]=i;b[c+4>>1]=(d[f+2|0]|0)+g&65535;a[e+2|0]=i;b[c+6>>1]=(d[f+3|0]|0)+g&65535;a[e+3|0]=i;return 4}function day(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+2>>1]=(d[f]|0)+g&65535;i=h&255;a[e+1|0]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;return 3}function daz(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;return 3}function daA(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+4>>1]=(d[f]|0)+g&65535;i=h&255;a[e+2|0]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;return 2}function daB(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+2>>1]=(d[f+1|0]|0)+g&65535;a[e+1|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;return 3}function daC(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+2>>1]=(d[f]|0)+g&65535;i=h&255;a[e+1|0]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;return 2}function daD(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;return 2}function daE(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;b[c+6>>1]=(d[f]|0)+g&65535;a[e+3|0]=h&255;return 1}function daF(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+2>>1]=(d[f+1|0]|0)+g&65535;a[e+1|0]=i;b[c+4>>1]=(d[f+2|0]|0)+g&65535;a[e+2|0]=i;return 3}function daG(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+2>>1]=(d[f]|0)+g&65535;i=h&255;a[e+1|0]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;return 2}function daH(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;return 2}function daI(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;b[c+4>>1]=(d[f]|0)+g&65535;a[e+2|0]=h&255;return 1}function daJ(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c>>1]=(d[f]|0)+g&65535;i=h&255;a[e]=i;b[c+2>>1]=(d[f+1|0]|0)+g&65535;a[e+1|0]=i;return 2}function daK(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;b[c+2>>1]=(d[f]|0)+g&65535;a[e+1|0]=h&255;return 1}function daL(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;b[c>>1]=(d[f]|0)+g&65535;a[e]=h&255;return 1}function daM(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return 0}function daN(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+12>>1]=(d[f+1|0]|0)+g&65535;a[e+6|0]=i;b[c+10>>1]=(d[f+2|0]|0)+g&65535;a[e+5|0]=i;b[c+8>>1]=(d[f+3|0]|0)+g&65535;a[e+4|0]=i;b[c+6>>1]=(d[f+4|0]|0)+g&65535;a[e+3|0]=i;b[c+4>>1]=(d[f+5|0]|0)+g&65535;a[e+2|0]=i;b[c+2>>1]=(d[f+6|0]|0)+g&65535;a[e+1|0]=i;b[c>>1]=(d[f+7|0]|0)+g&65535;a[e]=i;return 8}function daO(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+12>>1]=(d[f]|0)+g&65535;i=h&255;a[e+6|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+6>>1]=(d[f+3|0]|0)+g&65535;a[e+3|0]=i;b[c+4>>1]=(d[f+4|0]|0)+g&65535;a[e+2|0]=i;b[c+2>>1]=(d[f+5|0]|0)+g&65535;a[e+1|0]=i;b[c>>1]=(d[f+6|0]|0)+g&65535;a[e]=i;return 7}function daP(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+6>>1]=(d[f+3|0]|0)+g&65535;a[e+3|0]=i;b[c+4>>1]=(d[f+4|0]|0)+g&65535;a[e+2|0]=i;b[c+2>>1]=(d[f+5|0]|0)+g&65535;a[e+1|0]=i;b[c>>1]=(d[f+6|0]|0)+g&65535;a[e]=i;return 7}function daQ(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+10>>1]=(d[f]|0)+g&65535;i=h&255;a[e+5|0]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+4>>1]=(d[f+3|0]|0)+g&65535;a[e+2|0]=i;b[c+2>>1]=(d[f+4|0]|0)+g&65535;a[e+1|0]=i;b[c>>1]=(d[f+5|0]|0)+g&65535;a[e]=i;return 6}function daR(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+12>>1]=(d[f+1|0]|0)+g&65535;a[e+6|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+6>>1]=(d[f+3|0]|0)+g&65535;a[e+3|0]=i;b[c+4>>1]=(d[f+4|0]|0)+g&65535;a[e+2|0]=i;b[c+2>>1]=(d[f+5|0]|0)+g&65535;a[e+1|0]=i;b[c>>1]=(d[f+6|0]|0)+g&65535;a[e]=i;return 7}function daS(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+12>>1]=(d[f]|0)+g&65535;i=h&255;a[e+6|0]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+4>>1]=(d[f+3|0]|0)+g&65535;a[e+2|0]=i;b[c+2>>1]=(d[f+4|0]|0)+g&65535;a[e+1|0]=i;b[c>>1]=(d[f+5|0]|0)+g&65535;a[e]=i;return 6}function daT(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+4>>1]=(d[f+3|0]|0)+g&65535;a[e+2|0]=i;b[c+2>>1]=(d[f+4|0]|0)+g&65535;a[e+1|0]=i;b[c>>1]=(d[f+5|0]|0)+g&65535;a[e]=i;return 6}function daU(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+8>>1]=(d[f]|0)+g&65535;i=h&255;a[e+4|0]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;b[c+4>>1]=(d[f+2|0]|0)+g&65535;a[e+2|0]=i;b[c+2>>1]=(d[f+3|0]|0)+g&65535;a[e+1|0]=i;b[c>>1]=(d[f+4|0]|0)+g&65535;a[e]=i;return 5}function daV(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+12>>1]=(d[f+1|0]|0)+g&65535;a[e+6|0]=i;b[c+10>>1]=(d[f+2|0]|0)+g&65535;a[e+5|0]=i;b[c+6>>1]=(d[f+3|0]|0)+g&65535;a[e+3|0]=i;b[c+4>>1]=(d[f+4|0]|0)+g&65535;a[e+2|0]=i;b[c+2>>1]=(d[f+5|0]|0)+g&65535;a[e+1|0]=i;b[c>>1]=(d[f+6|0]|0)+g&65535;a[e]=i;return 7}function daW(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+12>>1]=(d[f]|0)+g&65535;i=h&255;a[e+6|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+4>>1]=(d[f+3|0]|0)+g&65535;a[e+2|0]=i;b[c+2>>1]=(d[f+4|0]|0)+g&65535;a[e+1|0]=i;b[c>>1]=(d[f+5|0]|0)+g&65535;a[e]=i;return 6}function daX(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+4>>1]=(d[f+3|0]|0)+g&65535;a[e+2|0]=i;b[c+2>>1]=(d[f+4|0]|0)+g&65535;a[e+1|0]=i;b[c>>1]=(d[f+5|0]|0)+g&65535;a[e]=i;return 6}function daY(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+10>>1]=(d[f]|0)+g&65535;i=h&255;a[e+5|0]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;b[c+4>>1]=(d[f+2|0]|0)+g&65535;a[e+2|0]=i;b[c+2>>1]=(d[f+3|0]|0)+g&65535;a[e+1|0]=i;b[c>>1]=(d[f+4|0]|0)+g&65535;a[e]=i;return 5}function daZ(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+12>>1]=(d[f+1|0]|0)+g&65535;a[e+6|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+4>>1]=(d[f+3|0]|0)+g&65535;a[e+2|0]=i;b[c+2>>1]=(d[f+4|0]|0)+g&65535;a[e+1|0]=i;b[c>>1]=(d[f+5|0]|0)+g&65535;a[e]=i;return 6}function da_(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+12>>1]=(d[f]|0)+g&65535;i=h&255;a[e+6|0]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;b[c+4>>1]=(d[f+2|0]|0)+g&65535;a[e+2|0]=i;b[c+2>>1]=(d[f+3|0]|0)+g&65535;a[e+1|0]=i;b[c>>1]=(d[f+4|0]|0)+g&65535;a[e]=i;return 5}function da$(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;b[c+4>>1]=(d[f+2|0]|0)+g&65535;a[e+2|0]=i;b[c+2>>1]=(d[f+3|0]|0)+g&65535;a[e+1|0]=i;b[c>>1]=(d[f+4|0]|0)+g&65535;a[e]=i;return 5}function da0(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+6>>1]=(d[f]|0)+g&65535;i=h&255;a[e+3|0]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;b[c+2>>1]=(d[f+2|0]|0)+g&65535;a[e+1|0]=i;b[c>>1]=(d[f+3|0]|0)+g&65535;a[e]=i;return 4}function da1(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+12>>1]=(d[f+1|0]|0)+g&65535;a[e+6|0]=i;b[c+10>>1]=(d[f+2|0]|0)+g&65535;a[e+5|0]=i;b[c+8>>1]=(d[f+3|0]|0)+g&65535;a[e+4|0]=i;b[c+4>>1]=(d[f+4|0]|0)+g&65535;a[e+2|0]=i;b[c+2>>1]=(d[f+5|0]|0)+g&65535;a[e+1|0]=i;b[c>>1]=(d[f+6|0]|0)+g&65535;a[e]=i;return 7}function da2(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+12>>1]=(d[f]|0)+g&65535;i=h&255;a[e+6|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+4>>1]=(d[f+3|0]|0)+g&65535;a[e+2|0]=i;b[c+2>>1]=(d[f+4|0]|0)+g&65535;a[e+1|0]=i;b[c>>1]=(d[f+5|0]|0)+g&65535;a[e]=i;return 6}function da3(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+4>>1]=(d[f+3|0]|0)+g&65535;a[e+2|0]=i;b[c+2>>1]=(d[f+4|0]|0)+g&65535;a[e+1|0]=i;b[c>>1]=(d[f+5|0]|0)+g&65535;a[e]=i;return 6}function da4(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+10>>1]=(d[f]|0)+g&65535;i=h&255;a[e+5|0]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;b[c+4>>1]=(d[f+2|0]|0)+g&65535;a[e+2|0]=i;b[c+2>>1]=(d[f+3|0]|0)+g&65535;a[e+1|0]=i;b[c>>1]=(d[f+4|0]|0)+g&65535;a[e]=i;return 5}function da5(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+12>>1]=(d[f+1|0]|0)+g&65535;a[e+6|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+4>>1]=(d[f+3|0]|0)+g&65535;a[e+2|0]=i;b[c+2>>1]=(d[f+4|0]|0)+g&65535;a[e+1|0]=i;b[c>>1]=(d[f+5|0]|0)+g&65535;a[e]=i;return 6}function da6(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+12>>1]=(d[f]|0)+g&65535;i=h&255;a[e+6|0]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;b[c+4>>1]=(d[f+2|0]|0)+g&65535;a[e+2|0]=i;b[c+2>>1]=(d[f+3|0]|0)+g&65535;a[e+1|0]=i;b[c>>1]=(d[f+4|0]|0)+g&65535;a[e]=i;return 5}function da7(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;b[c+4>>1]=(d[f+2|0]|0)+g&65535;a[e+2|0]=i;b[c+2>>1]=(d[f+3|0]|0)+g&65535;a[e+1|0]=i;b[c>>1]=(d[f+4|0]|0)+g&65535;a[e]=i;return 5}function da8(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+8>>1]=(d[f]|0)+g&65535;i=h&255;a[e+4|0]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;b[c+2>>1]=(d[f+2|0]|0)+g&65535;a[e+1|0]=i;b[c>>1]=(d[f+3|0]|0)+g&65535;a[e]=i;return 4}function da9(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+12>>1]=(d[f+1|0]|0)+g&65535;a[e+6|0]=i;b[c+10>>1]=(d[f+2|0]|0)+g&65535;a[e+5|0]=i;b[c+4>>1]=(d[f+3|0]|0)+g&65535;a[e+2|0]=i;b[c+2>>1]=(d[f+4|0]|0)+g&65535;a[e+1|0]=i;b[c>>1]=(d[f+5|0]|0)+g&65535;a[e]=i;return 6}function dba(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+12>>1]=(d[f]|0)+g&65535;i=h&255;a[e+6|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;b[c+4>>1]=(d[f+2|0]|0)+g&65535;a[e+2|0]=i;b[c+2>>1]=(d[f+3|0]|0)+g&65535;a[e+1|0]=i;b[c>>1]=(d[f+4|0]|0)+g&65535;a[e]=i;return 5}function dbb(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;b[c+4>>1]=(d[f+2|0]|0)+g&65535;a[e+2|0]=i;b[c+2>>1]=(d[f+3|0]|0)+g&65535;a[e+1|0]=i;b[c>>1]=(d[f+4|0]|0)+g&65535;a[e]=i;return 5}function dbc(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+10>>1]=(d[f]|0)+g&65535;i=h&255;a[e+5|0]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;b[c+2>>1]=(d[f+2|0]|0)+g&65535;a[e+1|0]=i;b[c>>1]=(d[f+3|0]|0)+g&65535;a[e]=i;return 4}function dbd(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+12>>1]=(d[f+1|0]|0)+g&65535;a[e+6|0]=i;b[c+4>>1]=(d[f+2|0]|0)+g&65535;a[e+2|0]=i;b[c+2>>1]=(d[f+3|0]|0)+g&65535;a[e+1|0]=i;b[c>>1]=(d[f+4|0]|0)+g&65535;a[e]=i;return 5}function dbe(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+12>>1]=(d[f]|0)+g&65535;i=h&255;a[e+6|0]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;b[c+2>>1]=(d[f+2|0]|0)+g&65535;a[e+1|0]=i;b[c>>1]=(d[f+3|0]|0)+g&65535;a[e]=i;return 4}function dbf(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;b[c+2>>1]=(d[f+2|0]|0)+g&65535;a[e+1|0]=i;b[c>>1]=(d[f+3|0]|0)+g&65535;a[e]=i;return 4}function dbg(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+4>>1]=(d[f]|0)+g&65535;i=h&255;a[e+2|0]=i;b[c+2>>1]=(d[f+1|0]|0)+g&65535;a[e+1|0]=i;b[c>>1]=(d[f+2|0]|0)+g&65535;a[e]=i;return 3}function dbh(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+12>>1]=(d[f+1|0]|0)+g&65535;a[e+6|0]=i;b[c+10>>1]=(d[f+2|0]|0)+g&65535;a[e+5|0]=i;b[c+8>>1]=(d[f+3|0]|0)+g&65535;a[e+4|0]=i;b[c+6>>1]=(d[f+4|0]|0)+g&65535;a[e+3|0]=i;b[c+2>>1]=(d[f+5|0]|0)+g&65535;a[e+1|0]=i;b[c>>1]=(d[f+6|0]|0)+g&65535;a[e]=i;return 7}function dbi(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+12>>1]=(d[f]|0)+g&65535;i=h&255;a[e+6|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+6>>1]=(d[f+3|0]|0)+g&65535;a[e+3|0]=i;b[c+2>>1]=(d[f+4|0]|0)+g&65535;a[e+1|0]=i;b[c>>1]=(d[f+5|0]|0)+g&65535;a[e]=i;return 6}function dbj(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+6>>1]=(d[f+3|0]|0)+g&65535;a[e+3|0]=i;b[c+2>>1]=(d[f+4|0]|0)+g&65535;a[e+1|0]=i;b[c>>1]=(d[f+5|0]|0)+g&65535;a[e]=i;return 6}function dbk(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+10>>1]=(d[f]|0)+g&65535;i=h&255;a[e+5|0]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+2>>1]=(d[f+3|0]|0)+g&65535;a[e+1|0]=i;b[c>>1]=(d[f+4|0]|0)+g&65535;a[e]=i;return 5}function dbl(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+12>>1]=(d[f+1|0]|0)+g&65535;a[e+6|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+6>>1]=(d[f+3|0]|0)+g&65535;a[e+3|0]=i;b[c+2>>1]=(d[f+4|0]|0)+g&65535;a[e+1|0]=i;b[c>>1]=(d[f+5|0]|0)+g&65535;a[e]=i;return 6}function dbm(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+12>>1]=(d[f]|0)+g&65535;i=h&255;a[e+6|0]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+2>>1]=(d[f+3|0]|0)+g&65535;a[e+1|0]=i;b[c>>1]=(d[f+4|0]|0)+g&65535;a[e]=i;return 5}function dbn(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+2>>1]=(d[f+3|0]|0)+g&65535;a[e+1|0]=i;b[c>>1]=(d[f+4|0]|0)+g&65535;a[e]=i;return 5}function dbo(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+8>>1]=(d[f]|0)+g&65535;i=h&255;a[e+4|0]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;b[c+2>>1]=(d[f+2|0]|0)+g&65535;a[e+1|0]=i;b[c>>1]=(d[f+3|0]|0)+g&65535;a[e]=i;return 4}function dbp(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+12>>1]=(d[f+1|0]|0)+g&65535;a[e+6|0]=i;b[c+10>>1]=(d[f+2|0]|0)+g&65535;a[e+5|0]=i;b[c+6>>1]=(d[f+3|0]|0)+g&65535;a[e+3|0]=i;b[c+2>>1]=(d[f+4|0]|0)+g&65535;a[e+1|0]=i;b[c>>1]=(d[f+5|0]|0)+g&65535;a[e]=i;return 6}function dbq(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+12>>1]=(d[f]|0)+g&65535;i=h&255;a[e+6|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+2>>1]=(d[f+3|0]|0)+g&65535;a[e+1|0]=i;b[c>>1]=(d[f+4|0]|0)+g&65535;a[e]=i;return 5}function dbr(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+2>>1]=(d[f+3|0]|0)+g&65535;a[e+1|0]=i;b[c>>1]=(d[f+4|0]|0)+g&65535;a[e]=i;return 5}function dbs(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+10>>1]=(d[f]|0)+g&65535;i=h&255;a[e+5|0]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;b[c+2>>1]=(d[f+2|0]|0)+g&65535;a[e+1|0]=i;b[c>>1]=(d[f+3|0]|0)+g&65535;a[e]=i;return 4}function dbt(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+12>>1]=(d[f+1|0]|0)+g&65535;a[e+6|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+2>>1]=(d[f+3|0]|0)+g&65535;a[e+1|0]=i;b[c>>1]=(d[f+4|0]|0)+g&65535;a[e]=i;return 5}function dbu(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+12>>1]=(d[f]|0)+g&65535;i=h&255;a[e+6|0]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;b[c+2>>1]=(d[f+2|0]|0)+g&65535;a[e+1|0]=i;b[c>>1]=(d[f+3|0]|0)+g&65535;a[e]=i;return 4}function dbv(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;b[c+2>>1]=(d[f+2|0]|0)+g&65535;a[e+1|0]=i;b[c>>1]=(d[f+3|0]|0)+g&65535;a[e]=i;return 4}function dbw(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+6>>1]=(d[f]|0)+g&65535;i=h&255;a[e+3|0]=i;b[c+2>>1]=(d[f+1|0]|0)+g&65535;a[e+1|0]=i;b[c>>1]=(d[f+2|0]|0)+g&65535;a[e]=i;return 3}function dbx(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+12>>1]=(d[f+1|0]|0)+g&65535;a[e+6|0]=i;b[c+10>>1]=(d[f+2|0]|0)+g&65535;a[e+5|0]=i;b[c+8>>1]=(d[f+3|0]|0)+g&65535;a[e+4|0]=i;b[c+2>>1]=(d[f+4|0]|0)+g&65535;a[e+1|0]=i;b[c>>1]=(d[f+5|0]|0)+g&65535;a[e]=i;return 6}function dby(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+12>>1]=(d[f]|0)+g&65535;i=h&255;a[e+6|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+2>>1]=(d[f+3|0]|0)+g&65535;a[e+1|0]=i;b[c>>1]=(d[f+4|0]|0)+g&65535;a[e]=i;return 5}function dbz(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+2>>1]=(d[f+3|0]|0)+g&65535;a[e+1|0]=i;b[c>>1]=(d[f+4|0]|0)+g&65535;a[e]=i;return 5}function dbA(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+10>>1]=(d[f]|0)+g&65535;i=h&255;a[e+5|0]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;b[c+2>>1]=(d[f+2|0]|0)+g&65535;a[e+1|0]=i;b[c>>1]=(d[f+3|0]|0)+g&65535;a[e]=i;return 4}function dbB(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+12>>1]=(d[f+1|0]|0)+g&65535;a[e+6|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+2>>1]=(d[f+3|0]|0)+g&65535;a[e+1|0]=i;b[c>>1]=(d[f+4|0]|0)+g&65535;a[e]=i;return 5}function dbC(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+12>>1]=(d[f]|0)+g&65535;i=h&255;a[e+6|0]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;b[c+2>>1]=(d[f+2|0]|0)+g&65535;a[e+1|0]=i;b[c>>1]=(d[f+3|0]|0)+g&65535;a[e]=i;return 4}function dbD(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;b[c+2>>1]=(d[f+2|0]|0)+g&65535;a[e+1|0]=i;b[c>>1]=(d[f+3|0]|0)+g&65535;a[e]=i;return 4}function dbE(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+8>>1]=(d[f]|0)+g&65535;i=h&255;a[e+4|0]=i;b[c+2>>1]=(d[f+1|0]|0)+g&65535;a[e+1|0]=i;b[c>>1]=(d[f+2|0]|0)+g&65535;a[e]=i;return 3}function dbF(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+12>>1]=(d[f+1|0]|0)+g&65535;a[e+6|0]=i;b[c+10>>1]=(d[f+2|0]|0)+g&65535;a[e+5|0]=i;b[c+2>>1]=(d[f+3|0]|0)+g&65535;a[e+1|0]=i;b[c>>1]=(d[f+4|0]|0)+g&65535;a[e]=i;return 5}function dbG(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+12>>1]=(d[f]|0)+g&65535;i=h&255;a[e+6|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;b[c+2>>1]=(d[f+2|0]|0)+g&65535;a[e+1|0]=i;b[c>>1]=(d[f+3|0]|0)+g&65535;a[e]=i;return 4}function dbH(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;b[c+2>>1]=(d[f+2|0]|0)+g&65535;a[e+1|0]=i;b[c>>1]=(d[f+3|0]|0)+g&65535;a[e]=i;return 4}function dbI(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+10>>1]=(d[f]|0)+g&65535;i=h&255;a[e+5|0]=i;b[c+2>>1]=(d[f+1|0]|0)+g&65535;a[e+1|0]=i;b[c>>1]=(d[f+2|0]|0)+g&65535;a[e]=i;return 3}function dbJ(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+12>>1]=(d[f+1|0]|0)+g&65535;a[e+6|0]=i;b[c+2>>1]=(d[f+2|0]|0)+g&65535;a[e+1|0]=i;b[c>>1]=(d[f+3|0]|0)+g&65535;a[e]=i;return 4}function dbK(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+12>>1]=(d[f]|0)+g&65535;i=h&255;a[e+6|0]=i;b[c+2>>1]=(d[f+1|0]|0)+g&65535;a[e+1|0]=i;b[c>>1]=(d[f+2|0]|0)+g&65535;a[e]=i;return 3}function dbL(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+2>>1]=(d[f+1|0]|0)+g&65535;a[e+1|0]=i;b[c>>1]=(d[f+2|0]|0)+g&65535;a[e]=i;return 3}function dbM(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+2>>1]=(d[f]|0)+g&65535;i=h&255;a[e+1|0]=i;b[c>>1]=(d[f+1|0]|0)+g&65535;a[e]=i;return 2}function dbN(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+12>>1]=(d[f+1|0]|0)+g&65535;a[e+6|0]=i;b[c+10>>1]=(d[f+2|0]|0)+g&65535;a[e+5|0]=i;b[c+8>>1]=(d[f+3|0]|0)+g&65535;a[e+4|0]=i;b[c+6>>1]=(d[f+4|0]|0)+g&65535;a[e+3|0]=i;b[c+4>>1]=(d[f+5|0]|0)+g&65535;a[e+2|0]=i;b[c>>1]=(d[f+6|0]|0)+g&65535;a[e]=i;return 7}function dbO(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+12>>1]=(d[f]|0)+g&65535;i=h&255;a[e+6|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+6>>1]=(d[f+3|0]|0)+g&65535;a[e+3|0]=i;b[c+4>>1]=(d[f+4|0]|0)+g&65535;a[e+2|0]=i;b[c>>1]=(d[f+5|0]|0)+g&65535;a[e]=i;return 6}function dbP(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+6>>1]=(d[f+3|0]|0)+g&65535;a[e+3|0]=i;b[c+4>>1]=(d[f+4|0]|0)+g&65535;a[e+2|0]=i;b[c>>1]=(d[f+5|0]|0)+g&65535;a[e]=i;return 6}function dbQ(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+10>>1]=(d[f]|0)+g&65535;i=h&255;a[e+5|0]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+4>>1]=(d[f+3|0]|0)+g&65535;a[e+2|0]=i;b[c>>1]=(d[f+4|0]|0)+g&65535;a[e]=i;return 5}function dbR(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+12>>1]=(d[f+1|0]|0)+g&65535;a[e+6|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+6>>1]=(d[f+3|0]|0)+g&65535;a[e+3|0]=i;b[c+4>>1]=(d[f+4|0]|0)+g&65535;a[e+2|0]=i;b[c>>1]=(d[f+5|0]|0)+g&65535;a[e]=i;return 6}function dbS(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+12>>1]=(d[f]|0)+g&65535;i=h&255;a[e+6|0]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+4>>1]=(d[f+3|0]|0)+g&65535;a[e+2|0]=i;b[c>>1]=(d[f+4|0]|0)+g&65535;a[e]=i;return 5}function dbT(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+4>>1]=(d[f+3|0]|0)+g&65535;a[e+2|0]=i;b[c>>1]=(d[f+4|0]|0)+g&65535;a[e]=i;return 5}function dbU(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+8>>1]=(d[f]|0)+g&65535;i=h&255;a[e+4|0]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;b[c+4>>1]=(d[f+2|0]|0)+g&65535;a[e+2|0]=i;b[c>>1]=(d[f+3|0]|0)+g&65535;a[e]=i;return 4}function dbV(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+12>>1]=(d[f+1|0]|0)+g&65535;a[e+6|0]=i;b[c+10>>1]=(d[f+2|0]|0)+g&65535;a[e+5|0]=i;b[c+6>>1]=(d[f+3|0]|0)+g&65535;a[e+3|0]=i;b[c+4>>1]=(d[f+4|0]|0)+g&65535;a[e+2|0]=i;b[c>>1]=(d[f+5|0]|0)+g&65535;a[e]=i;return 6}function dbW(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+12>>1]=(d[f]|0)+g&65535;i=h&255;a[e+6|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+4>>1]=(d[f+3|0]|0)+g&65535;a[e+2|0]=i;b[c>>1]=(d[f+4|0]|0)+g&65535;a[e]=i;return 5}function dbX(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+4>>1]=(d[f+3|0]|0)+g&65535;a[e+2|0]=i;b[c>>1]=(d[f+4|0]|0)+g&65535;a[e]=i;return 5}function dbY(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+10>>1]=(d[f]|0)+g&65535;i=h&255;a[e+5|0]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;b[c+4>>1]=(d[f+2|0]|0)+g&65535;a[e+2|0]=i;b[c>>1]=(d[f+3|0]|0)+g&65535;a[e]=i;return 4}function dbZ(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+12>>1]=(d[f+1|0]|0)+g&65535;a[e+6|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+4>>1]=(d[f+3|0]|0)+g&65535;a[e+2|0]=i;b[c>>1]=(d[f+4|0]|0)+g&65535;a[e]=i;return 5}function db_(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+12>>1]=(d[f]|0)+g&65535;i=h&255;a[e+6|0]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;b[c+4>>1]=(d[f+2|0]|0)+g&65535;a[e+2|0]=i;b[c>>1]=(d[f+3|0]|0)+g&65535;a[e]=i;return 4}function db$(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;b[c+4>>1]=(d[f+2|0]|0)+g&65535;a[e+2|0]=i;b[c>>1]=(d[f+3|0]|0)+g&65535;a[e]=i;return 4}function db0(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+6>>1]=(d[f]|0)+g&65535;i=h&255;a[e+3|0]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;b[c>>1]=(d[f+2|0]|0)+g&65535;a[e]=i;return 3}function db1(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+12>>1]=(d[f+1|0]|0)+g&65535;a[e+6|0]=i;b[c+10>>1]=(d[f+2|0]|0)+g&65535;a[e+5|0]=i;b[c+8>>1]=(d[f+3|0]|0)+g&65535;a[e+4|0]=i;b[c+4>>1]=(d[f+4|0]|0)+g&65535;a[e+2|0]=i;b[c>>1]=(d[f+5|0]|0)+g&65535;a[e]=i;return 6}function db2(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+12>>1]=(d[f]|0)+g&65535;i=h&255;a[e+6|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+4>>1]=(d[f+3|0]|0)+g&65535;a[e+2|0]=i;b[c>>1]=(d[f+4|0]|0)+g&65535;a[e]=i;return 5}function db3(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+4>>1]=(d[f+3|0]|0)+g&65535;a[e+2|0]=i;b[c>>1]=(d[f+4|0]|0)+g&65535;a[e]=i;return 5}function db4(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+10>>1]=(d[f]|0)+g&65535;i=h&255;a[e+5|0]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;b[c+4>>1]=(d[f+2|0]|0)+g&65535;a[e+2|0]=i;b[c>>1]=(d[f+3|0]|0)+g&65535;a[e]=i;return 4}function db5(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+12>>1]=(d[f+1|0]|0)+g&65535;a[e+6|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+4>>1]=(d[f+3|0]|0)+g&65535;a[e+2|0]=i;b[c>>1]=(d[f+4|0]|0)+g&65535;a[e]=i;return 5}function db6(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+12>>1]=(d[f]|0)+g&65535;i=h&255;a[e+6|0]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;b[c+4>>1]=(d[f+2|0]|0)+g&65535;a[e+2|0]=i;b[c>>1]=(d[f+3|0]|0)+g&65535;a[e]=i;return 4}function db7(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;b[c+4>>1]=(d[f+2|0]|0)+g&65535;a[e+2|0]=i;b[c>>1]=(d[f+3|0]|0)+g&65535;a[e]=i;return 4}function db8(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+8>>1]=(d[f]|0)+g&65535;i=h&255;a[e+4|0]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;b[c>>1]=(d[f+2|0]|0)+g&65535;a[e]=i;return 3}function db9(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+12>>1]=(d[f+1|0]|0)+g&65535;a[e+6|0]=i;b[c+10>>1]=(d[f+2|0]|0)+g&65535;a[e+5|0]=i;b[c+4>>1]=(d[f+3|0]|0)+g&65535;a[e+2|0]=i;b[c>>1]=(d[f+4|0]|0)+g&65535;a[e]=i;return 5}function dca(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+12>>1]=(d[f]|0)+g&65535;i=h&255;a[e+6|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;b[c+4>>1]=(d[f+2|0]|0)+g&65535;a[e+2|0]=i;b[c>>1]=(d[f+3|0]|0)+g&65535;a[e]=i;return 4}function dcb(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;b[c+4>>1]=(d[f+2|0]|0)+g&65535;a[e+2|0]=i;b[c>>1]=(d[f+3|0]|0)+g&65535;a[e]=i;return 4}function dcc(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+10>>1]=(d[f]|0)+g&65535;i=h&255;a[e+5|0]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;b[c>>1]=(d[f+2|0]|0)+g&65535;a[e]=i;return 3}function dcd(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+12>>1]=(d[f+1|0]|0)+g&65535;a[e+6|0]=i;b[c+4>>1]=(d[f+2|0]|0)+g&65535;a[e+2|0]=i;b[c>>1]=(d[f+3|0]|0)+g&65535;a[e]=i;return 4}function dce(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+12>>1]=(d[f]|0)+g&65535;i=h&255;a[e+6|0]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;b[c>>1]=(d[f+2|0]|0)+g&65535;a[e]=i;return 3}function dcf(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;b[c>>1]=(d[f+2|0]|0)+g&65535;a[e]=i;return 3}function dcg(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+4>>1]=(d[f]|0)+g&65535;i=h&255;a[e+2|0]=i;b[c>>1]=(d[f+1|0]|0)+g&65535;a[e]=i;return 2}function dch(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+12>>1]=(d[f+1|0]|0)+g&65535;a[e+6|0]=i;b[c+10>>1]=(d[f+2|0]|0)+g&65535;a[e+5|0]=i;b[c+8>>1]=(d[f+3|0]|0)+g&65535;a[e+4|0]=i;b[c+6>>1]=(d[f+4|0]|0)+g&65535;a[e+3|0]=i;b[c>>1]=(d[f+5|0]|0)+g&65535;a[e]=i;return 6}function dci(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+12>>1]=(d[f]|0)+g&65535;i=h&255;a[e+6|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+6>>1]=(d[f+3|0]|0)+g&65535;a[e+3|0]=i;b[c>>1]=(d[f+4|0]|0)+g&65535;a[e]=i;return 5}function dcj(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+6>>1]=(d[f+3|0]|0)+g&65535;a[e+3|0]=i;b[c>>1]=(d[f+4|0]|0)+g&65535;a[e]=i;return 5}function dck(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+10>>1]=(d[f]|0)+g&65535;i=h&255;a[e+5|0]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c>>1]=(d[f+3|0]|0)+g&65535;a[e]=i;return 4}function dcl(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+12>>1]=(d[f+1|0]|0)+g&65535;a[e+6|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+6>>1]=(d[f+3|0]|0)+g&65535;a[e+3|0]=i;b[c>>1]=(d[f+4|0]|0)+g&65535;a[e]=i;return 5}function dcm(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+12>>1]=(d[f]|0)+g&65535;i=h&255;a[e+6|0]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c>>1]=(d[f+3|0]|0)+g&65535;a[e]=i;return 4}function dcn(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c>>1]=(d[f+3|0]|0)+g&65535;a[e]=i;return 4}function dco(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+8>>1]=(d[f]|0)+g&65535;i=h&255;a[e+4|0]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;b[c>>1]=(d[f+2|0]|0)+g&65535;a[e]=i;return 3}function dcp(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+12>>1]=(d[f+1|0]|0)+g&65535;a[e+6|0]=i;b[c+10>>1]=(d[f+2|0]|0)+g&65535;a[e+5|0]=i;b[c+6>>1]=(d[f+3|0]|0)+g&65535;a[e+3|0]=i;b[c>>1]=(d[f+4|0]|0)+g&65535;a[e]=i;return 5}function dcq(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+12>>1]=(d[f]|0)+g&65535;i=h&255;a[e+6|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c>>1]=(d[f+3|0]|0)+g&65535;a[e]=i;return 4}function dcr(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c>>1]=(d[f+3|0]|0)+g&65535;a[e]=i;return 4}function dcs(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+10>>1]=(d[f]|0)+g&65535;i=h&255;a[e+5|0]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;b[c>>1]=(d[f+2|0]|0)+g&65535;a[e]=i;return 3}function dct(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+12>>1]=(d[f+1|0]|0)+g&65535;a[e+6|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c>>1]=(d[f+3|0]|0)+g&65535;a[e]=i;return 4}function dcu(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+12>>1]=(d[f]|0)+g&65535;i=h&255;a[e+6|0]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;b[c>>1]=(d[f+2|0]|0)+g&65535;a[e]=i;return 3}function dcv(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;b[c>>1]=(d[f+2|0]|0)+g&65535;a[e]=i;return 3}function dcw(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+6>>1]=(d[f]|0)+g&65535;i=h&255;a[e+3|0]=i;b[c>>1]=(d[f+1|0]|0)+g&65535;a[e]=i;return 2}function dcx(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+12>>1]=(d[f+1|0]|0)+g&65535;a[e+6|0]=i;b[c+10>>1]=(d[f+2|0]|0)+g&65535;a[e+5|0]=i;b[c+8>>1]=(d[f+3|0]|0)+g&65535;a[e+4|0]=i;b[c>>1]=(d[f+4|0]|0)+g&65535;a[e]=i;return 5}function dcy(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+12>>1]=(d[f]|0)+g&65535;i=h&255;a[e+6|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c>>1]=(d[f+3|0]|0)+g&65535;a[e]=i;return 4}function dcz(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c>>1]=(d[f+3|0]|0)+g&65535;a[e]=i;return 4}function dcA(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+10>>1]=(d[f]|0)+g&65535;i=h&255;a[e+5|0]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;b[c>>1]=(d[f+2|0]|0)+g&65535;a[e]=i;return 3}function dcB(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+12>>1]=(d[f+1|0]|0)+g&65535;a[e+6|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c>>1]=(d[f+3|0]|0)+g&65535;a[e]=i;return 4}function dcC(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+12>>1]=(d[f]|0)+g&65535;i=h&255;a[e+6|0]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;b[c>>1]=(d[f+2|0]|0)+g&65535;a[e]=i;return 3}function dcD(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;b[c>>1]=(d[f+2|0]|0)+g&65535;a[e]=i;return 3}function dcE(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+8>>1]=(d[f]|0)+g&65535;i=h&255;a[e+4|0]=i;b[c>>1]=(d[f+1|0]|0)+g&65535;a[e]=i;return 2}function dcF(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+12>>1]=(d[f+1|0]|0)+g&65535;a[e+6|0]=i;b[c+10>>1]=(d[f+2|0]|0)+g&65535;a[e+5|0]=i;b[c>>1]=(d[f+3|0]|0)+g&65535;a[e]=i;return 4}function dcG(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+12>>1]=(d[f]|0)+g&65535;i=h&255;a[e+6|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;b[c>>1]=(d[f+2|0]|0)+g&65535;a[e]=i;return 3}function dcH(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;b[c>>1]=(d[f+2|0]|0)+g&65535;a[e]=i;return 3}function dcI(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+10>>1]=(d[f]|0)+g&65535;i=h&255;a[e+5|0]=i;b[c>>1]=(d[f+1|0]|0)+g&65535;a[e]=i;return 2}function dcJ(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+12>>1]=(d[f+1|0]|0)+g&65535;a[e+6|0]=i;b[c>>1]=(d[f+2|0]|0)+g&65535;a[e]=i;return 3}function dcK(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+12>>1]=(d[f]|0)+g&65535;i=h&255;a[e+6|0]=i;b[c>>1]=(d[f+1|0]|0)+g&65535;a[e]=i;return 2}function dcL(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c>>1]=(d[f+1|0]|0)+g&65535;a[e]=i;return 2}function dcM(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;b[c>>1]=(d[f]|0)+g&65535;a[e]=h&255;return 1}function dcN(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+12>>1]=(d[f+1|0]|0)+g&65535;a[e+6|0]=i;b[c+10>>1]=(d[f+2|0]|0)+g&65535;a[e+5|0]=i;b[c+8>>1]=(d[f+3|0]|0)+g&65535;a[e+4|0]=i;b[c+6>>1]=(d[f+4|0]|0)+g&65535;a[e+3|0]=i;b[c+4>>1]=(d[f+5|0]|0)+g&65535;a[e+2|0]=i;b[c+2>>1]=(d[f+6|0]|0)+g&65535;a[e+1|0]=i;return 7}function dcO(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+12>>1]=(d[f]|0)+g&65535;i=h&255;a[e+6|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+6>>1]=(d[f+3|0]|0)+g&65535;a[e+3|0]=i;b[c+4>>1]=(d[f+4|0]|0)+g&65535;a[e+2|0]=i;b[c+2>>1]=(d[f+5|0]|0)+g&65535;a[e+1|0]=i;return 6}function dcP(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+6>>1]=(d[f+3|0]|0)+g&65535;a[e+3|0]=i;b[c+4>>1]=(d[f+4|0]|0)+g&65535;a[e+2|0]=i;b[c+2>>1]=(d[f+5|0]|0)+g&65535;a[e+1|0]=i;return 6}function dcQ(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+10>>1]=(d[f]|0)+g&65535;i=h&255;a[e+5|0]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+4>>1]=(d[f+3|0]|0)+g&65535;a[e+2|0]=i;b[c+2>>1]=(d[f+4|0]|0)+g&65535;a[e+1|0]=i;return 5}function dcR(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+12>>1]=(d[f+1|0]|0)+g&65535;a[e+6|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+6>>1]=(d[f+3|0]|0)+g&65535;a[e+3|0]=i;b[c+4>>1]=(d[f+4|0]|0)+g&65535;a[e+2|0]=i;b[c+2>>1]=(d[f+5|0]|0)+g&65535;a[e+1|0]=i;return 6}function dcS(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+12>>1]=(d[f]|0)+g&65535;i=h&255;a[e+6|0]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+4>>1]=(d[f+3|0]|0)+g&65535;a[e+2|0]=i;b[c+2>>1]=(d[f+4|0]|0)+g&65535;a[e+1|0]=i;return 5}function dcT(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+4>>1]=(d[f+3|0]|0)+g&65535;a[e+2|0]=i;b[c+2>>1]=(d[f+4|0]|0)+g&65535;a[e+1|0]=i;return 5}function dcU(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+8>>1]=(d[f]|0)+g&65535;i=h&255;a[e+4|0]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;b[c+4>>1]=(d[f+2|0]|0)+g&65535;a[e+2|0]=i;b[c+2>>1]=(d[f+3|0]|0)+g&65535;a[e+1|0]=i;return 4}function dcV(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+12>>1]=(d[f+1|0]|0)+g&65535;a[e+6|0]=i;b[c+10>>1]=(d[f+2|0]|0)+g&65535;a[e+5|0]=i;b[c+6>>1]=(d[f+3|0]|0)+g&65535;a[e+3|0]=i;b[c+4>>1]=(d[f+4|0]|0)+g&65535;a[e+2|0]=i;b[c+2>>1]=(d[f+5|0]|0)+g&65535;a[e+1|0]=i;return 6}function dcW(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+12>>1]=(d[f]|0)+g&65535;i=h&255;a[e+6|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+4>>1]=(d[f+3|0]|0)+g&65535;a[e+2|0]=i;b[c+2>>1]=(d[f+4|0]|0)+g&65535;a[e+1|0]=i;return 5}function dcX(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+4>>1]=(d[f+3|0]|0)+g&65535;a[e+2|0]=i;b[c+2>>1]=(d[f+4|0]|0)+g&65535;a[e+1|0]=i;return 5}function dcY(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+10>>1]=(d[f]|0)+g&65535;i=h&255;a[e+5|0]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;b[c+4>>1]=(d[f+2|0]|0)+g&65535;a[e+2|0]=i;b[c+2>>1]=(d[f+3|0]|0)+g&65535;a[e+1|0]=i;return 4}function dcZ(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+12>>1]=(d[f+1|0]|0)+g&65535;a[e+6|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+4>>1]=(d[f+3|0]|0)+g&65535;a[e+2|0]=i;b[c+2>>1]=(d[f+4|0]|0)+g&65535;a[e+1|0]=i;return 5}function dc_(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+12>>1]=(d[f]|0)+g&65535;i=h&255;a[e+6|0]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;b[c+4>>1]=(d[f+2|0]|0)+g&65535;a[e+2|0]=i;b[c+2>>1]=(d[f+3|0]|0)+g&65535;a[e+1|0]=i;return 4}function dc$(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;b[c+4>>1]=(d[f+2|0]|0)+g&65535;a[e+2|0]=i;b[c+2>>1]=(d[f+3|0]|0)+g&65535;a[e+1|0]=i;return 4}function dc0(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+6>>1]=(d[f]|0)+g&65535;i=h&255;a[e+3|0]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;b[c+2>>1]=(d[f+2|0]|0)+g&65535;a[e+1|0]=i;return 3}function dc1(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+12>>1]=(d[f+1|0]|0)+g&65535;a[e+6|0]=i;b[c+10>>1]=(d[f+2|0]|0)+g&65535;a[e+5|0]=i;b[c+8>>1]=(d[f+3|0]|0)+g&65535;a[e+4|0]=i;b[c+4>>1]=(d[f+4|0]|0)+g&65535;a[e+2|0]=i;b[c+2>>1]=(d[f+5|0]|0)+g&65535;a[e+1|0]=i;return 6}function dc2(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+12>>1]=(d[f]|0)+g&65535;i=h&255;a[e+6|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+4>>1]=(d[f+3|0]|0)+g&65535;a[e+2|0]=i;b[c+2>>1]=(d[f+4|0]|0)+g&65535;a[e+1|0]=i;return 5}function dc3(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+4>>1]=(d[f+3|0]|0)+g&65535;a[e+2|0]=i;b[c+2>>1]=(d[f+4|0]|0)+g&65535;a[e+1|0]=i;return 5}function dc4(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+10>>1]=(d[f]|0)+g&65535;i=h&255;a[e+5|0]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;b[c+4>>1]=(d[f+2|0]|0)+g&65535;a[e+2|0]=i;b[c+2>>1]=(d[f+3|0]|0)+g&65535;a[e+1|0]=i;return 4}function dc5(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+12>>1]=(d[f+1|0]|0)+g&65535;a[e+6|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+4>>1]=(d[f+3|0]|0)+g&65535;a[e+2|0]=i;b[c+2>>1]=(d[f+4|0]|0)+g&65535;a[e+1|0]=i;return 5}function dc6(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+12>>1]=(d[f]|0)+g&65535;i=h&255;a[e+6|0]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;b[c+4>>1]=(d[f+2|0]|0)+g&65535;a[e+2|0]=i;b[c+2>>1]=(d[f+3|0]|0)+g&65535;a[e+1|0]=i;return 4}function dc7(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;b[c+4>>1]=(d[f+2|0]|0)+g&65535;a[e+2|0]=i;b[c+2>>1]=(d[f+3|0]|0)+g&65535;a[e+1|0]=i;return 4}function dc8(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+8>>1]=(d[f]|0)+g&65535;i=h&255;a[e+4|0]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;b[c+2>>1]=(d[f+2|0]|0)+g&65535;a[e+1|0]=i;return 3}function dc9(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+12>>1]=(d[f+1|0]|0)+g&65535;a[e+6|0]=i;b[c+10>>1]=(d[f+2|0]|0)+g&65535;a[e+5|0]=i;b[c+4>>1]=(d[f+3|0]|0)+g&65535;a[e+2|0]=i;b[c+2>>1]=(d[f+4|0]|0)+g&65535;a[e+1|0]=i;return 5}function dda(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+12>>1]=(d[f]|0)+g&65535;i=h&255;a[e+6|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;b[c+4>>1]=(d[f+2|0]|0)+g&65535;a[e+2|0]=i;b[c+2>>1]=(d[f+3|0]|0)+g&65535;a[e+1|0]=i;return 4}function ddb(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;b[c+4>>1]=(d[f+2|0]|0)+g&65535;a[e+2|0]=i;b[c+2>>1]=(d[f+3|0]|0)+g&65535;a[e+1|0]=i;return 4}function ddc(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+10>>1]=(d[f]|0)+g&65535;i=h&255;a[e+5|0]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;b[c+2>>1]=(d[f+2|0]|0)+g&65535;a[e+1|0]=i;return 3}function ddd(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+12>>1]=(d[f+1|0]|0)+g&65535;a[e+6|0]=i;b[c+4>>1]=(d[f+2|0]|0)+g&65535;a[e+2|0]=i;b[c+2>>1]=(d[f+3|0]|0)+g&65535;a[e+1|0]=i;return 4}function dde(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+12>>1]=(d[f]|0)+g&65535;i=h&255;a[e+6|0]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;b[c+2>>1]=(d[f+2|0]|0)+g&65535;a[e+1|0]=i;return 3}function ddf(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;b[c+2>>1]=(d[f+2|0]|0)+g&65535;a[e+1|0]=i;return 3}function ddg(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+4>>1]=(d[f]|0)+g&65535;i=h&255;a[e+2|0]=i;b[c+2>>1]=(d[f+1|0]|0)+g&65535;a[e+1|0]=i;return 2}function ddh(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+12>>1]=(d[f+1|0]|0)+g&65535;a[e+6|0]=i;b[c+10>>1]=(d[f+2|0]|0)+g&65535;a[e+5|0]=i;b[c+8>>1]=(d[f+3|0]|0)+g&65535;a[e+4|0]=i;b[c+6>>1]=(d[f+4|0]|0)+g&65535;a[e+3|0]=i;b[c+2>>1]=(d[f+5|0]|0)+g&65535;a[e+1|0]=i;return 6}function ddi(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+12>>1]=(d[f]|0)+g&65535;i=h&255;a[e+6|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+6>>1]=(d[f+3|0]|0)+g&65535;a[e+3|0]=i;b[c+2>>1]=(d[f+4|0]|0)+g&65535;a[e+1|0]=i;return 5}function ddj(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+6>>1]=(d[f+3|0]|0)+g&65535;a[e+3|0]=i;b[c+2>>1]=(d[f+4|0]|0)+g&65535;a[e+1|0]=i;return 5}function ddk(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+10>>1]=(d[f]|0)+g&65535;i=h&255;a[e+5|0]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+2>>1]=(d[f+3|0]|0)+g&65535;a[e+1|0]=i;return 4}function ddl(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+12>>1]=(d[f+1|0]|0)+g&65535;a[e+6|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+6>>1]=(d[f+3|0]|0)+g&65535;a[e+3|0]=i;b[c+2>>1]=(d[f+4|0]|0)+g&65535;a[e+1|0]=i;return 5}function ddm(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+12>>1]=(d[f]|0)+g&65535;i=h&255;a[e+6|0]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+2>>1]=(d[f+3|0]|0)+g&65535;a[e+1|0]=i;return 4}function ddn(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+2>>1]=(d[f+3|0]|0)+g&65535;a[e+1|0]=i;return 4}function ddo(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+8>>1]=(d[f]|0)+g&65535;i=h&255;a[e+4|0]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;b[c+2>>1]=(d[f+2|0]|0)+g&65535;a[e+1|0]=i;return 3}function ddp(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+12>>1]=(d[f+1|0]|0)+g&65535;a[e+6|0]=i;b[c+10>>1]=(d[f+2|0]|0)+g&65535;a[e+5|0]=i;b[c+6>>1]=(d[f+3|0]|0)+g&65535;a[e+3|0]=i;b[c+2>>1]=(d[f+4|0]|0)+g&65535;a[e+1|0]=i;return 5}function ddq(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+12>>1]=(d[f]|0)+g&65535;i=h&255;a[e+6|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+2>>1]=(d[f+3|0]|0)+g&65535;a[e+1|0]=i;return 4}function ddr(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+2>>1]=(d[f+3|0]|0)+g&65535;a[e+1|0]=i;return 4}function dds(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+10>>1]=(d[f]|0)+g&65535;i=h&255;a[e+5|0]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;b[c+2>>1]=(d[f+2|0]|0)+g&65535;a[e+1|0]=i;return 3}function ddt(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+12>>1]=(d[f+1|0]|0)+g&65535;a[e+6|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+2>>1]=(d[f+3|0]|0)+g&65535;a[e+1|0]=i;return 4}function ddu(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+12>>1]=(d[f]|0)+g&65535;i=h&255;a[e+6|0]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;b[c+2>>1]=(d[f+2|0]|0)+g&65535;a[e+1|0]=i;return 3}function ddv(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;b[c+2>>1]=(d[f+2|0]|0)+g&65535;a[e+1|0]=i;return 3}function ddw(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+6>>1]=(d[f]|0)+g&65535;i=h&255;a[e+3|0]=i;b[c+2>>1]=(d[f+1|0]|0)+g&65535;a[e+1|0]=i;return 2}function ddx(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+12>>1]=(d[f+1|0]|0)+g&65535;a[e+6|0]=i;b[c+10>>1]=(d[f+2|0]|0)+g&65535;a[e+5|0]=i;b[c+8>>1]=(d[f+3|0]|0)+g&65535;a[e+4|0]=i;b[c+2>>1]=(d[f+4|0]|0)+g&65535;a[e+1|0]=i;return 5}function ddy(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+12>>1]=(d[f]|0)+g&65535;i=h&255;a[e+6|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+2>>1]=(d[f+3|0]|0)+g&65535;a[e+1|0]=i;return 4}function ddz(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+2>>1]=(d[f+3|0]|0)+g&65535;a[e+1|0]=i;return 4}function ddA(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+10>>1]=(d[f]|0)+g&65535;i=h&255;a[e+5|0]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;b[c+2>>1]=(d[f+2|0]|0)+g&65535;a[e+1|0]=i;return 3}function ddB(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+12>>1]=(d[f+1|0]|0)+g&65535;a[e+6|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+2>>1]=(d[f+3|0]|0)+g&65535;a[e+1|0]=i;return 4}function ddC(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+12>>1]=(d[f]|0)+g&65535;i=h&255;a[e+6|0]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;b[c+2>>1]=(d[f+2|0]|0)+g&65535;a[e+1|0]=i;return 3}function ddD(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;b[c+2>>1]=(d[f+2|0]|0)+g&65535;a[e+1|0]=i;return 3}function ddE(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+8>>1]=(d[f]|0)+g&65535;i=h&255;a[e+4|0]=i;b[c+2>>1]=(d[f+1|0]|0)+g&65535;a[e+1|0]=i;return 2}function ddF(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+12>>1]=(d[f+1|0]|0)+g&65535;a[e+6|0]=i;b[c+10>>1]=(d[f+2|0]|0)+g&65535;a[e+5|0]=i;b[c+2>>1]=(d[f+3|0]|0)+g&65535;a[e+1|0]=i;return 4}function ddG(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+12>>1]=(d[f]|0)+g&65535;i=h&255;a[e+6|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;b[c+2>>1]=(d[f+2|0]|0)+g&65535;a[e+1|0]=i;return 3}function ddH(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;b[c+2>>1]=(d[f+2|0]|0)+g&65535;a[e+1|0]=i;return 3}function ddI(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+10>>1]=(d[f]|0)+g&65535;i=h&255;a[e+5|0]=i;b[c+2>>1]=(d[f+1|0]|0)+g&65535;a[e+1|0]=i;return 2}function ddJ(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+12>>1]=(d[f+1|0]|0)+g&65535;a[e+6|0]=i;b[c+2>>1]=(d[f+2|0]|0)+g&65535;a[e+1|0]=i;return 3}function ddK(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+12>>1]=(d[f]|0)+g&65535;i=h&255;a[e+6|0]=i;b[c+2>>1]=(d[f+1|0]|0)+g&65535;a[e+1|0]=i;return 2}function ddL(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+2>>1]=(d[f+1|0]|0)+g&65535;a[e+1|0]=i;return 2}function ddM(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;b[c+2>>1]=(d[f]|0)+g&65535;a[e+1|0]=h&255;return 1}function ddN(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+12>>1]=(d[f+1|0]|0)+g&65535;a[e+6|0]=i;b[c+10>>1]=(d[f+2|0]|0)+g&65535;a[e+5|0]=i;b[c+8>>1]=(d[f+3|0]|0)+g&65535;a[e+4|0]=i;b[c+6>>1]=(d[f+4|0]|0)+g&65535;a[e+3|0]=i;b[c+4>>1]=(d[f+5|0]|0)+g&65535;a[e+2|0]=i;return 6}function ddO(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+12>>1]=(d[f]|0)+g&65535;i=h&255;a[e+6|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+6>>1]=(d[f+3|0]|0)+g&65535;a[e+3|0]=i;b[c+4>>1]=(d[f+4|0]|0)+g&65535;a[e+2|0]=i;return 5}function ddP(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+6>>1]=(d[f+3|0]|0)+g&65535;a[e+3|0]=i;b[c+4>>1]=(d[f+4|0]|0)+g&65535;a[e+2|0]=i;return 5}function ddQ(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+10>>1]=(d[f]|0)+g&65535;i=h&255;a[e+5|0]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+4>>1]=(d[f+3|0]|0)+g&65535;a[e+2|0]=i;return 4}function ddR(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+12>>1]=(d[f+1|0]|0)+g&65535;a[e+6|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+6>>1]=(d[f+3|0]|0)+g&65535;a[e+3|0]=i;b[c+4>>1]=(d[f+4|0]|0)+g&65535;a[e+2|0]=i;return 5}function ddS(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+12>>1]=(d[f]|0)+g&65535;i=h&255;a[e+6|0]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+4>>1]=(d[f+3|0]|0)+g&65535;a[e+2|0]=i;return 4}function ddT(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+4>>1]=(d[f+3|0]|0)+g&65535;a[e+2|0]=i;return 4}function ddU(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+8>>1]=(d[f]|0)+g&65535;i=h&255;a[e+4|0]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;b[c+4>>1]=(d[f+2|0]|0)+g&65535;a[e+2|0]=i;return 3}function ddV(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+12>>1]=(d[f+1|0]|0)+g&65535;a[e+6|0]=i;b[c+10>>1]=(d[f+2|0]|0)+g&65535;a[e+5|0]=i;b[c+6>>1]=(d[f+3|0]|0)+g&65535;a[e+3|0]=i;b[c+4>>1]=(d[f+4|0]|0)+g&65535;a[e+2|0]=i;return 5}function ddW(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+12>>1]=(d[f]|0)+g&65535;i=h&255;a[e+6|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+4>>1]=(d[f+3|0]|0)+g&65535;a[e+2|0]=i;return 4}function ddX(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+4>>1]=(d[f+3|0]|0)+g&65535;a[e+2|0]=i;return 4}function ddY(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+10>>1]=(d[f]|0)+g&65535;i=h&255;a[e+5|0]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;b[c+4>>1]=(d[f+2|0]|0)+g&65535;a[e+2|0]=i;return 3}function ddZ(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+12>>1]=(d[f+1|0]|0)+g&65535;a[e+6|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;b[c+4>>1]=(d[f+3|0]|0)+g&65535;a[e+2|0]=i;return 4}function dd_(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+12>>1]=(d[f]|0)+g&65535;i=h&255;a[e+6|0]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;b[c+4>>1]=(d[f+2|0]|0)+g&65535;a[e+2|0]=i;return 3}function dd$(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;b[c+4>>1]=(d[f+2|0]|0)+g&65535;a[e+2|0]=i;return 3}function dd0(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+6>>1]=(d[f]|0)+g&65535;i=h&255;a[e+3|0]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;return 2}function dd1(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+12>>1]=(d[f+1|0]|0)+g&65535;a[e+6|0]=i;b[c+10>>1]=(d[f+2|0]|0)+g&65535;a[e+5|0]=i;b[c+8>>1]=(d[f+3|0]|0)+g&65535;a[e+4|0]=i;b[c+4>>1]=(d[f+4|0]|0)+g&65535;a[e+2|0]=i;return 5}function dd2(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+12>>1]=(d[f]|0)+g&65535;i=h&255;a[e+6|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+4>>1]=(d[f+3|0]|0)+g&65535;a[e+2|0]=i;return 4}function dd3(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+4>>1]=(d[f+3|0]|0)+g&65535;a[e+2|0]=i;return 4}function dd4(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+10>>1]=(d[f]|0)+g&65535;i=h&255;a[e+5|0]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;b[c+4>>1]=(d[f+2|0]|0)+g&65535;a[e+2|0]=i;return 3}function dd5(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+12>>1]=(d[f+1|0]|0)+g&65535;a[e+6|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+4>>1]=(d[f+3|0]|0)+g&65535;a[e+2|0]=i;return 4}function dd6(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+12>>1]=(d[f]|0)+g&65535;i=h&255;a[e+6|0]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;b[c+4>>1]=(d[f+2|0]|0)+g&65535;a[e+2|0]=i;return 3}function dd7(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;b[c+4>>1]=(d[f+2|0]|0)+g&65535;a[e+2|0]=i;return 3}function dd8(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+8>>1]=(d[f]|0)+g&65535;i=h&255;a[e+4|0]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;return 2}function dd9(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+12>>1]=(d[f+1|0]|0)+g&65535;a[e+6|0]=i;b[c+10>>1]=(d[f+2|0]|0)+g&65535;a[e+5|0]=i;b[c+4>>1]=(d[f+3|0]|0)+g&65535;a[e+2|0]=i;return 4}function dea(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+12>>1]=(d[f]|0)+g&65535;i=h&255;a[e+6|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;b[c+4>>1]=(d[f+2|0]|0)+g&65535;a[e+2|0]=i;return 3}function deb(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;b[c+4>>1]=(d[f+2|0]|0)+g&65535;a[e+2|0]=i;return 3}function dec(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+10>>1]=(d[f]|0)+g&65535;i=h&255;a[e+5|0]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;return 2}function ded(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+12>>1]=(d[f+1|0]|0)+g&65535;a[e+6|0]=i;b[c+4>>1]=(d[f+2|0]|0)+g&65535;a[e+2|0]=i;return 3}function dee(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+12>>1]=(d[f]|0)+g&65535;i=h&255;a[e+6|0]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;return 2}function def(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+4>>1]=(d[f+1|0]|0)+g&65535;a[e+2|0]=i;return 2}function deg(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;b[c+4>>1]=(d[f]|0)+g&65535;a[e+2|0]=h&255;return 1}function deh(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+12>>1]=(d[f+1|0]|0)+g&65535;a[e+6|0]=i;b[c+10>>1]=(d[f+2|0]|0)+g&65535;a[e+5|0]=i;b[c+8>>1]=(d[f+3|0]|0)+g&65535;a[e+4|0]=i;b[c+6>>1]=(d[f+4|0]|0)+g&65535;a[e+3|0]=i;return 5}function dei(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+12>>1]=(d[f]|0)+g&65535;i=h&255;a[e+6|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+6>>1]=(d[f+3|0]|0)+g&65535;a[e+3|0]=i;return 4}function dej(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+6>>1]=(d[f+3|0]|0)+g&65535;a[e+3|0]=i;return 4}function dek(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+10>>1]=(d[f]|0)+g&65535;i=h&255;a[e+5|0]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;return 3}function del(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+12>>1]=(d[f+1|0]|0)+g&65535;a[e+6|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;b[c+6>>1]=(d[f+3|0]|0)+g&65535;a[e+3|0]=i;return 4}function dem(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+12>>1]=(d[f]|0)+g&65535;i=h&255;a[e+6|0]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;return 3}function den(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;return 3}function deo(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+8>>1]=(d[f]|0)+g&65535;i=h&255;a[e+4|0]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;return 2}function dep(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+12>>1]=(d[f+1|0]|0)+g&65535;a[e+6|0]=i;b[c+10>>1]=(d[f+2|0]|0)+g&65535;a[e+5|0]=i;b[c+6>>1]=(d[f+3|0]|0)+g&65535;a[e+3|0]=i;return 4}function deq(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+12>>1]=(d[f]|0)+g&65535;i=h&255;a[e+6|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;return 3}function der(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;return 3}function des(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+10>>1]=(d[f]|0)+g&65535;i=h&255;a[e+5|0]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;return 2}function det(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+12>>1]=(d[f+1|0]|0)+g&65535;a[e+6|0]=i;b[c+6>>1]=(d[f+2|0]|0)+g&65535;a[e+3|0]=i;return 3}function deu(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+12>>1]=(d[f]|0)+g&65535;i=h&255;a[e+6|0]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;return 2}function dev(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+6>>1]=(d[f+1|0]|0)+g&65535;a[e+3|0]=i;return 2}function dew(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;b[c+6>>1]=(d[f]|0)+g&65535;a[e+3|0]=h&255;return 1}function dex(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+12>>1]=(d[f+1|0]|0)+g&65535;a[e+6|0]=i;b[c+10>>1]=(d[f+2|0]|0)+g&65535;a[e+5|0]=i;b[c+8>>1]=(d[f+3|0]|0)+g&65535;a[e+4|0]=i;return 4}function dey(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+12>>1]=(d[f]|0)+g&65535;i=h&255;a[e+6|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;return 3}function dez(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;return 3}function deA(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+10>>1]=(d[f]|0)+g&65535;i=h&255;a[e+5|0]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;return 2}function deB(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+12>>1]=(d[f+1|0]|0)+g&65535;a[e+6|0]=i;b[c+8>>1]=(d[f+2|0]|0)+g&65535;a[e+4|0]=i;return 3}function deC(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+12>>1]=(d[f]|0)+g&65535;i=h&255;a[e+6|0]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;return 2}function deD(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+8>>1]=(d[f+1|0]|0)+g&65535;a[e+4|0]=i;return 2}function deE(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;b[c+8>>1]=(d[f]|0)+g&65535;a[e+4|0]=h&255;return 1}function deF(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+12>>1]=(d[f+1|0]|0)+g&65535;a[e+6|0]=i;b[c+10>>1]=(d[f+2|0]|0)+g&65535;a[e+5|0]=i;return 3}function deG(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+12>>1]=(d[f]|0)+g&65535;i=h&255;a[e+6|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;return 2}function deH(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+10>>1]=(d[f+1|0]|0)+g&65535;a[e+5|0]=i;return 2}function deI(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;b[c+10>>1]=(d[f]|0)+g&65535;a[e+5|0]=h&255;return 1}function deJ(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;b[c+14>>1]=(d[f]|0)+g&65535;i=h&255;a[e+7|0]=i;b[c+12>>1]=(d[f+1|0]|0)+g&65535;a[e+6|0]=i;return 2}function deK(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;b[c+12>>1]=(d[f]|0)+g&65535;a[e+6|0]=h&255;return 1}function deL(c,e,f,g,h){c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;b[c+14>>1]=(d[f]|0)+g&65535;a[e+7|0]=h&255;return 1}function deM(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return 0}function deN(){var a=0,d=0,e=0,f=0,g=0,h=0;a=c[3540942]|0;d=c[2113112]|0;if((d|0)<=1){return}e=(d|0)/2|0;d=0;do{f=a+(d<<1)|0;g=b[f>>1]|0;h=(d&27904|0)==1024?g^8:g;g=(d&27776|0)==2176?h^8:h;h=(d&29952|0)==9216?g^4096:g;b[f>>1]=(d&30208|0)==12800?h^4096:h;d=d+1|0;}while((d|0)<(e|0));return}function deO(){var a=0,e=0,f=0,g=0,h=0,i=0;a=c[3540942]|0;e=c[2113112]|0;if((e|0)<=1){return}f=(e|0)/2|0;e=0;do{g=a+(e<<1)|0;h=(e&263296|0)!=128^b[g>>1];i=(e&16392|0)==16392?h^2:h;h=(e&48|0)!=16|(e&1572864|0)==524288?i:i^4;i=(e&578|0)==66?h:h^8;h=(e&33024|0)==32768?i^16:i;i=(e&139268|0)==4?h:h^32;h=(e&71680|0)==65536?i:i^64;b[g>>1]=((e&18464|0)==18464?h^128:h)^(d[668656+(e&255)|0]|0)<<8;e=e+1|0;}while((e|0)<(f|0));return}function deP(){var a=0,e=0,f=0,g=0,h=0,i=0;a=c[3540942]|0;e=c[2113112]|0;if((e|0)<=1){return}f=(e|0)/2|0;e=0;do{g=a+(e<<1)|0;h=(e&262272|0)!=128^b[g>>1];i=(e&16392|0)!=16392|(e&1572864|0)==0?h:h^2;h=(e&48|0)==16?i^4:i;i=(e&578|0)==66?h:h^8;h=(e&33024|0)==32768?i^16:i;i=(e&8196|0)==4?h:h^32;h=(e&71680|0)==65536?i:i^64;b[g>>1]=((e&2080|0)==2080?h^128:h)^(d[632552+(e&255)|0]|0)<<8;e=e+1|0;}while((e|0)<(f|0));return}function deQ(){var a=0,e=0,f=0,g=0,h=0,i=0;a=c[3540942]|0;e=c[2113112]|0;if((e|0)<=1){return}f=(e|0)/2|0;e=0;do{g=a+(e<<1)|0;h=(e&262272|0)!=128^b[g>>1];i=(e&540680|0)==540680?h^2:h;h=(e&48|0)==16?i^4:i;i=(e&578|0)==66?h:h^8;h=(e&295168|0)==294912?i^16:i;i=(e&8196|0)==4?h:h^32;h=(e&6144|0)==0?i:i^64;b[g>>1]=((e&18464|0)==18464?h^128:h)^(d[6501784+(e&255)|0]|0)<<8;e=e+1|0;}while((e|0)<(f|0));return}function deR(){var a=0,e=0,f=0,g=0,h=0,i=0;a=c[3540942]|0;e=c[2113112]|0;if((e|0)<=1){return}f=(e|0)/2|0;e=0;do{g=a+(e<<1)|0;h=(e&263296|0)!=128^b[g>>1];i=(e&48|0)==16?h^4:h;h=(e&578|0)==66?i:i^8;i=(e&33024|0)==32768?h^16:h;h=(e&139268|0)==4?i:i^32;i=(e&71680|0)==65536?h:h^64;b[g>>1]=((e&18464|0)==18464?i^128:i)^(d[6500408+(e&255)|0]|0)<<8;e=e+1|0;}while((e|0)<(f|0));return}function deS(){var a=0,e=0,f=0,g=0,h=0,i=0;a=c[3540942]|0;e=c[2113112]|0;if((e|0)<=1){return}f=(e|0)/2|0;e=0;do{g=a+(e<<1)|0;h=(e&262272|0)!=128^b[g>>1];i=(e&16392|0)==16392?h^2:h;h=(e&48|0)==16?i^4:i;i=(e&578|0)==66?h:h^8;h=(e&33024|0)==32768?i^16:i;i=(e&139268|0)==4?h:h^32;h=(e&71680|0)==65536?i:i^64;b[g>>1]=((e&18464|0)==18464?h^128:h)^(d[7008120+(e&255)|0]|0)<<8;e=e+1|0;}while((e|0)<(f|0));return}function deT(){var a=0,e=0,f=0,g=0,h=0,i=0;a=c[3540942]|0;e=c[2113112]|0;if((e|0)<=1){return}f=(e|0)/2|0;e=0;do{g=a+(e<<1)|0;h=(e&263296|0)!=128^b[g>>1];i=(e&16392|0)==16392?h^2:h;h=(e&48|0)==16?i^4:i;i=(e&578|0)==66?h:h^8;h=(e&295168|0)==294912?i^16:i;i=(e&8196|0)==4?h:h^32;h=(e&71680|0)==65536?i:i^64;b[g>>1]=((e&2080|0)==2080?h^128:h)^(d[6512344+(e&255)|0]|0)<<8;e=e+1|0;}while((e|0)<(f|0));return}function deU(){var a=0,e=0,f=0,g=0,h=0,i=0;a=c[3540942]|0;e=c[2113112]|0;if((e|0)<=1){return}f=(e|0)/2|0;e=0;do{g=a+(e<<1)|0;h=(e&263296|0)!=128^b[g>>1];i=(e&540680|0)==540680?h^2:h;h=(e&48|0)!=16|(e&1572864|0)==524288?i:i^4;i=(e&66|0)==66?h:h^8;h=(e&33024|0)==32768?i^16:i;i=(e&139268|0)==4?h:h^32;h=(e&71680|0)==65536?i:i^64;b[g>>1]=((e&18464|0)==18464?h^128:h)^(d[632104+(e&255)|0]|0)<<8;e=e+1|0;}while((e|0)<(f|0));return}function deV(){var a=0,e=0,f=0,g=0,h=0,i=0;a=c[3540942]|0;e=c[2113112]|0;if((e|0)<=1){return}f=(e|0)/2|0;e=0;do{g=a+(e<<1)|0;h=(e&263296|0)!=128^b[g>>1];i=(e&16392|0)==16392?h^2:h;h=(e&524336|0)==16?i^4:i;i=(e&66|0)==66?h:h^8;h=(e&33024|0)==32768?i^16:i;i=(e&8196|0)==4?h:h^32;h=(e&71680|0)==65536?i:i^64;b[g>>1]=((e&2080|0)==2080?h^128:h)^(d[7353832+(e&255)|0]|0)<<8;e=e+1|0;}while((e|0)<(f|0));return}function deW(){var a=0,e=0,f=0,g=0,h=0,i=0;a=c[3540942]|0;e=c[2113112]|0;if((e|0)<=1){return}f=(e|0)/2|0;e=0;do{g=a+(e<<1)|0;h=(e&263296|0)!=128^b[g>>1];i=(e&540680|0)==540680?h^2:h;h=(e&48|0)==16?i^4:i;i=(e&66|0)==66?h:h^8;h=(e&295168|0)==294912?i^16:i;i=(e&139268|0)==4?h:h^32;h=(e&71680|0)==65536?i:i^64;b[g>>1]=((e&2080|0)==2080?h^128:h)^(d[7358888+(e&255)|0]|0)<<8;e=e+1|0;}while((e|0)<(f|0));return}function deX(){var a=0,e=0,f=0,g=0,h=0,i=0;a=c[3540910]|0;e=c[2113108]|0;if((e|0)<=1){return}f=(e|0)/2|0;e=0;do{g=a+(e<<1)|0;h=(e&1152|0)!=128^b[g>>1];i=(e&66|0)==66?h:h^8;h=(e&33024|0)==32768?i^16:i;i=(e&8196|0)==4?h:h^32;h=(e&6144|0)==0?i:i^64;b[g>>1]=((e&2080|0)==2080?h^128:h)^(d[641528+(e>>>1&255)|0]|0)<<8;e=e+1|0;}while((e|0)<(f|0));return}function deY(){var a=0,e=0,f=0,g=0,h=0,i=0;a=c[3540910]|0;e=c[2113108]|0;if((e|0)<=1){return}f=(e|0)/2|0;e=0;do{g=a+(e<<1)|0;h=(e&263296|0)!=128^b[g>>1];i=(e&16392|0)==16392?h^2:h;h=(e&48|0)==16?i^4:i;i=(e&578|0)==66?h:h^8;h=(e&33024|0)==32768?i^16:i;i=(e&139268|0)==4?h:h^32;h=(e&71680|0)==65536?i:i^64;b[g>>1]=((e&2080|0)==2080?h^128:h)^(d[672824+(e>>>1&255)|0]|0)<<8;e=e+1|0;}while((e|0)<(f|0));return}function deZ(){var a=0,e=0,f=0,g=0,h=0,i=0;a=c[3540910]|0;e=c[2113108]|0;if((e|0)<=1){return}f=(e|0)/2|0;e=0;do{g=a+(e<<1)|0;h=(e&262272|0)!=128^b[g>>1];i=(e&524336|0)==524304?h^4:h;h=(e&66|0)==66?i:i^8;i=(e&295168|0)==294912?h^16:h;h=(e&139268|0)==4?i:i^32;i=(e&6144|0)==0?h:h^64;b[g>>1]=((e&2080|0)==2080?i^128:i)^(d[638696+(e>>>1&255)|0]|0)<<8;e=e+1|0;}while((e|0)<(f|0));return}function de_(){var a=0,e=0,f=0,g=0,h=0,i=0;a=c[3540910]|0;e=c[2113108]|0;if((e|0)<=1){return}f=(e|0)/2|0;e=0;do{g=a+(e<<1)|0;h=(e&262272|0)!=128^b[g>>1];i=(e&16392|0)==16392?h^2:h;h=(e&524336|0)==524304?i^4:i;i=(e&578|0)==66?h:h^8;h=(e&33024|0)==32768?i^16:i;i=(e&8196|0)==4?h:h^32;h=(e&71680|0)==65536?i:i^64;b[g>>1]=((e&2080|0)==2080?h^128:h)^(d[632808+(e>>>1&255)|0]|0)<<8;e=e+1|0;}while((e|0)<(f|0));return}function de$(b){b=b|0;var d=0,e=0,f=0,g=0,h=0;d=0;while(1){if((d|0)>=1024){e=0;break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==0){g=59203;break}else{d=d+1|0}}do{if((g|0)==59203){d=gGq(8388608)|0;c[f>>2]=d;if((d|0)==0){e=0;break}gGz(d|0,0,8388608);e=d}}while(0);f=0;do{a[e+(f>>>10<<22&4194304|f&9175551|f>>>9<<21&2097152|f>>>22<<20&1048576|f>>>20<<17&131072|f>>>21<<16&65536|f>>>17<<15&32768|f>>>16<<14&16384|f>>>15<<13&8192|f>>>14<<12&4096|f>>>13<<11&2048|f>>>12<<10&1024|f>>>11<<9&512)|0]=a[b+f|0]|0;f=f+1|0;}while((f|0)<8388608);gGC(b|0,e|0,8388608)|0;b=0;while(1){if((b|0)>=1024){g=59213;break}h=9638528+(b<<2)|0;if((c[h>>2]|0)==(e|0)){break}else{b=b+1|0}}if((g|0)==59213){return}gGr(e);c[h>>2]=0;return}function de0(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[3540942]|0;e=d;f=0;while(1){if((f|0)>=1024){g=0;break}h=9638528+(f<<2)|0;if((c[h>>2]|0)==0){i=59217;break}else{f=f+1|0}}do{if((i|0)==59217){f=gGq(4194304)|0;c[h>>2]=f;if((f|0)==0){g=0;break}gGz(f|0,0,4194304);g=f}}while(0);h=g;f=0;do{j=b[e+(f<<1)>>1]|0;b[h+((f>>>6<<7&128|f&16777023|f>>>7<<6&64)<<1)>>1]=(j&65535)>>>4<<5&32|j&-49|(j&65535)>>>5<<4&16;f=f+1|0;}while((f|0)<2097152);gGC(d|0,g|0,4194304)|0;d=0;while(1){if((d|0)>=1024){break}k=9638528+(d<<2)|0;if((c[k>>2]|0)==(g|0)){i=59224;break}else{d=d+1|0}}if((i|0)==59224){gGr(g);c[k>>2]=0}de$(c[3540920]|0);de$((c[3540920]|0)+8388608|0);k=c[3541280]|0;g=0;do{a[k+(g+4194305)|0]=a[k+(g+12582913)|0]|0;g=g+2|0;}while((g|0)<4194304);return}function de1(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0;c[2113110]=2;c[2112950]=12286;if((c[2394]|0)==0){a=c[2112932]|0}else{c[2394]=0;b=c[3532596]|0;c[2112932]=b;d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];a=b}b=c[3540932]|0;d=a+53248|0;e=13631488;while(1){f=b+(e-13631488)|0;c[d>>2]=f;c[d+65536>>2]=f;c[d+131072>>2]=f;f=e+1024|0;if(f>>>0>13697023){break}else{d=d+4|0;e=f}}c[a+53504>>2]=4;c[a+119040>>2]=4;c[a+196704>>2]=1328;c[a+196624>>2]=3206;c[a+196744>>2]=1538;c[a+196664>>2]=2184;a=c[3532592]|0;if((a|0)!=0){gGC(a|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;c[2406724]=gGq(2097152)|0;c[2406722]=gGq(2097152)|0;a=gGq(2097152)|0;e=a;c[2406720]=e;d=c[2427044]|0;c[9681616+(d<<3)>>2]=990744;c[9681620+(d<<3)>>2]=1;c[2427044]=d+1;d=c[3540934]|0;b=c[2406724]|0;c[b>>2]=d;c[e>>2]=d;f=d+4096|0;c[b+4>>2]=f;c[a+4>>2]=f;f=d+8192|0;c[b+8>>2]=f;c[a+8>>2]=f;f=d+12288|0;c[b+12>>2]=f;c[a+12>>2]=f;f=c[3540910]|0;d=(((c[2113108]|0)-1|0)>>>12)+1|0;g=0;do{h=g+32768|0;i=f+(g<<12)|0;c[b+(h<<2)>>2]=i;c[e+(h<<2)>>2]=i;g=g+1|0;}while(g>>>0<d>>>0);d=c[3540940]|0;c[b+262144>>2]=d;g=c[2406722]|0;c[g+262144>>2]=d;c[a+262144>>2]=d;d=c[3540938]|0;f=0;do{i=f+98304|0;h=d+(f<<12)|0;c[b+(i<<2)>>2]=h;c[g+(i<<2)>>2]=h;c[e+(i<<2)>>2]=h;f=f+1|0;}while(f>>>0<16);f=c[3540932]|0;d=0;do{h=d+294912|0;i=f+(d<<12)|0;c[b+(h<<2)>>2]=i;c[g+(h<<2)>>2]=i;c[e+(h<<2)>>2]=i;d=d+1|0;}while(d>>>0<16);d=c[3540936]|0;c[b+1310720>>2]=d;c[g+1310720>>2]=d;c[a+1310720>>2]=d;c[2430392]=984;c[2432806]=1354;return}function de2(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=i;i=i+112|0;d=b|0;e=b+16|0;f=b+32|0;g=b+48|0;h=b+64|0;j=b+80|0;k=b+96|0;if((a&32|0)!=0){l=k|0;c[l>>2]=c[3540932];m=k+4|0;c[m>>2]=65536;n=k+8|0;c[n>>2]=13631488;o=k+12|0;c[o>>2]=187320;p=c[2076592]|0;gj[p&4095](k)|0;c[l>>2]=c[3540940];c[m>>2]=1024;c[n>>2]=0;c[o>>2]=217512;p=c[2076592]|0;gj[p&4095](k)|0;c[l>>2]=c[3540938];c[m>>2]=65536;c[n>>2]=0;c[o>>2]=213888;p=c[2076592]|0;gj[p&4095](k)|0;c[l>>2]=c[3540936];c[m>>2]=1024;c[n>>2]=0;c[o>>2]=210088;o=c[2076592]|0;gj[o&4095](k)|0}if((a&64|0)==0){i=b;return 0}gGz(g|0,0,12);c[g>>2]=9698808;c[g+4>>2]=160;c[g+12>>2]=532152;gj[c[2076592]&4095](g)|0;gGz(f|0,0,12);c[f>>2]=14107896;c[f+4>>2]=4;c[f+12>>2]=518504;gj[c[2076592]&4095](f)|0;gGz(e|0,0,12);c[e>>2]=9760744;c[e+4>>2]=4;c[e+12>>2]=505312;gj[c[2076592]&4095](e)|0;gGz(d|0,0,12);c[d>>2]=14107744;c[d+4>>2]=4;c[d+12>>2]=493296;gj[c[2076592]&4095](d)|0;gGz(j|0,0,12);c[j>>2]=9753376;c[j+4>>2]=1;c[j+12>>2]=204928;gj[c[2076592]&4095](j)|0;gGz(h|0,0,12);c[h>>2]=9753384;c[h+4>>2]=1;c[h+12>>2]=198760;gj[c[2076592]&4095](h)|0;i=b;return 0}function de3(a){a=a|0;var b=0;if((a&16777212|0)!=13697024){b=0;return b|0}a=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)-(c[2440186]|0)|0;if((a|0)>0){fyW(a)|0}b=d[9753384]|0;return b|0}function de4(b){b=b|0;var d=0;if((b&16777212|0)!=13697024){d=0;return d|0}b=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)-(c[2440186]|0)|0;if((b|0)>0){fyW(b)|0}d=a[9753384]|0;return d|0}function de5(b,d){b=b|0;d=d|0;if((b&16777214|0)!=13697024){return}b=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)-(c[2440186]|0)|0;if((b|0)>0){fyW(b)|0}a[9753376]=d&255;a[9698957]=1;fyX();return}function de6(b,d){b=b|0;d=d|0;if((b&16777214|0)!=13697024){return}b=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)-(c[2440186]|0)|0;if((b|0)>0){fyW(b)|0}a[9753376]=d;a[9698957]=1;fyX();return}function de7(b,c){b=b|0;c=c|0;if((b|0)!=939524096){return}a[9753384]=c;return}function de8(b){b=b|0;var c=0;if((b|0)!=939524096){c=0;return c|0}a[9698957]=0;fyX();c=a[9753376]|0;return c|0}function de9(){var a=0,b=0,d=0,e=0;c[2113110]=1;c[2112950]=13728;c[2112952]=8882;if((c[2394]|0)==0){a=c[2112932]|0}else{c[2394]=0;b=c[3532596]|0;c[2112932]=b;d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];a=b}b=c[3540932]|0;c[a+20224>>2]=b;c[a+85760>>2]=b;c[a+151296>>2]=b;b=a+20480|0;d=5242880;while(1){c[b>>2]=4;c[b+65536>>2]=4;e=d+1024|0;if(e>>>0>6291461){break}else{b=b+4|0;d=e}}c[a+196704>>2]=1592;c[a+196744>>2]=2214;a=c[3532592]|0;if((a|0)!=0){gGC(a|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;c[2406724]=gGq(2097152)|0;c[2406722]=gGq(2097152)|0;a=gGq(2097152)|0;d=a;c[2406720]=d;b=c[2427044]|0;c[9681616+(b<<3)>>2]=990744;c[9681620+(b<<3)>>2]=1;c[2427044]=b+1;b=c[3540934]|0;e=c[2406724]|0;c[e>>2]=b;c[d>>2]=b;d=b+4096|0;c[e+4>>2]=d;c[a+4>>2]=d;d=b+8192|0;c[e+8>>2]=d;c[a+8>>2]=d;d=b+12288|0;c[e+12>>2]=d;c[a+12>>2]=d;d=c[3540940]|0;c[e+262144>>2]=d;b=c[2406722]|0;c[b+262144>>2]=d;c[a+262144>>2]=d;d=c[3540936]|0;c[e+1310720>>2]=d;c[b+1310720>>2]=d;c[a+1310720>>2]=d;c[2430384]=2572;c[2430388]=1776;c[2432802]=1658;return}function dfa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=i;i=i+160|0;d=b|0;e=b+16|0;f=b+32|0;g=b+48|0;h=b+64|0;j=b+80|0;k=b+96|0;l=b+112|0;m=b+128|0;n=b+144|0;if((a&32|0)!=0){o=n|0;c[o>>2]=c[3540932];p=n+4|0;c[p>>2]=64;q=n+8|0;c[q>>2]=4194304;r=n+12|0;c[r>>2]=187320;s=c[2076592]|0;gj[s&4095](n)|0;c[o>>2]=c[3540940];c[p>>2]=1024;c[q>>2]=0;c[r>>2]=217512;s=c[2076592]|0;gj[s&4095](n)|0;c[o>>2]=c[3540936];c[p>>2]=1024;c[q>>2]=0;c[r>>2]=213888;r=c[2076592]|0;gj[r&4095](n)|0}if((a&64|0)==0){i=b;return 0}gGz(g|0,0,12);c[g>>2]=9698808;c[g+4>>2]=160;c[g+12>>2]=532152;gj[c[2076592]&4095](g)|0;gGz(f|0,0,12);c[f>>2]=14107896;c[f+4>>2]=4;c[f+12>>2]=518504;gj[c[2076592]&4095](f)|0;gGz(e|0,0,12);c[e>>2]=9760744;c[e+4>>2]=4;c[e+12>>2]=505312;gj[c[2076592]&4095](e)|0;gGz(d|0,0,12);c[d>>2]=14107744;c[d+4>>2]=4;c[d+12>>2]=493296;gj[c[2076592]&4095](d)|0;gGz(m|0,0,12);c[m>>2]=9717144;c[m+4>>2]=2;c[m+12>>2]=182184;gj[c[2076592]&4095](m)|0;gGz(l|0,0,12);c[l>>2]=9717552;c[l+4>>2]=2;c[l+12>>2]=177496;gj[c[2076592]&4095](l)|0;gGz(k|0,0,12);c[k>>2]=9717152;c[k+4>>2]=2;c[k+12>>2]=173920;gj[c[2076592]&4095](k)|0;gGz(j|0,0,12);c[j>>2]=9717560;c[j+4>>2]=2;c[j+12>>2]=170304;gj[c[2076592]&4095](j)|0;gGz(h|0,0,12);c[h>>2]=9757064;c[h+4>>2]=4;c[h+12>>2]=167232;gj[c[2076592]&4095](h)|0;i=b;return 0}function dfb(){b[4858572]=0;b[4858776]=0;b[4858576]=0;b[4858780]=0;c[2439266]=1;return}function dfc(a){a=a|0;var d=0,e=0;if((a&16777152|0)==5177344){d=b[(c[3540932]|0)+(a&62)>>1]|0;return d|0}if((a|0)==5242882|(a|0)==6291458){e=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)-(c[2440186]|0)|0;if((e|0)>0){fyW(e)|0}d=b[4858572]|0;return d|0}else if((a|0)==5242880|(a|0)==6291456){a=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)-(c[2440186]|0)|0;if((a|0)>0){fyW(a)|0}d=b[4858776]|0;return d|0}else{d=0;return d|0}return 0}function dfd(a,c){a=a|0;c=c|0;if((a|0)==5242880|(a|0)==6291456){b[4858780]=c}else if((a|0)==5242882|(a|0)==6291458){b[4858576]=c}return}function dfe(a,d){a=a|0;d=d|0;if((a&-128|0)!=1350565888){return}b[(c[3540932]|0)+(a>>>1&62)>>1]=d;return}function dff(a,c){a=a|0;c=c|0;if((a|0)!=1073741824){return}b[4858572]=c>>>16&65535;b[4858776]=c&65535;b[4858576]=0;b[4858780]=0;return}function dfg(a){a=a|0;var b=0,d=0;if((a|0)==1073741836){b=c[2439266]|0;c[2439266]=b+1;d=b;return d|0}else if((a|0)==1073741824){d=(e[4858576]|0)<<16|(e[4858780]|0);return d|0}else{d=0;return d|0}return 0}function dfh(a,c){a=a|0;c=c|0;var d=0,e=0;d=a&6;if((d|0)==0){b[4858780]=c;return}else if((d|0)==2){d=(c&65535)>>>8;a=d^c;switch(a&255|0){case 204:{e=-16;break};case 208:{e=-32;break};case 224:{e=-48;break};case 231:{e=112;break};case 170:{e=86;break};case 248:{e=-13;break};case 56:{e=-83;break};case 67:{e=-54;break};case 86:{e=-84;break};case 115:{e=-109;break};case 135:{e=-79;break};case 166:{e=-87;break};case 132:{e=-77;break};case 147:{e=115;break};case 179:{e=-124;break};case 180:{e=-112;break};case 137:{e=-74;break};case 165:{e=-87;break};case 172:{e=86;break};case 237:{e=-53;break};case 240:{e=-52;break};case 241:{e=-11;break};case 242:{e=-15;break};case 244:{e=-14;break};case 245:{e=-12;break};case 252:{e=-64;break};case 254:{e=-61;break};case 182:{e=-119;break};case 197:{e=-116;break};case 202:{e=67;break};case 154:{e=-103;break};case 173:{e=56;break};case 177:{e=-121;break};default:{e=a&255}}b[4858576]=e&255^(d<<8|d);return}else{return}}function dfi(){var a=0,b=0,d=0,e=0;c[2113110]=1;c[2112950]=13728;if((c[2394]|0)==0){a=c[2112932]|0}else{c[2394]=0;b=c[3532596]|0;c[2112932]=b;d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];a=b}b=c[3540932]|0;c[a+20224>>2]=b;c[a+85760>>2]=b;c[a+151296>>2]=b;b=a+20480|0;d=5242880;while(1){c[b>>2]=4;c[b+65536>>2]=4;e=d+1024|0;if(e>>>0>6291461){break}else{b=b+4|0;d=e}}c[a+196704>>2]=1592;c[a+196744>>2]=2308;a=c[3532592]|0;if((a|0)!=0){gGC(a|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;c[2406724]=gGq(2097152)|0;c[2406722]=gGq(2097152)|0;a=gGq(2097152)|0;d=a;c[2406720]=d;b=c[2427044]|0;c[9681616+(b<<3)>>2]=990744;c[9681620+(b<<3)>>2]=1;c[2427044]=b+1;b=c[3540934]|0;e=c[2406724]|0;c[e>>2]=b;c[d>>2]=b;d=b+4096|0;c[e+4>>2]=d;c[a+4>>2]=d;d=b+8192|0;c[e+8>>2]=d;c[a+8>>2]=d;d=b+12288|0;c[e+12>>2]=d;c[a+12>>2]=d;d=c[3540940]|0;c[e+262144>>2]=d;b=c[2406722]|0;c[b+262144>>2]=d;c[a+262144>>2]=d;d=c[3540936]|0;c[e+1310720>>2]=d;c[b+1310720>>2]=d;c[a+1310720>>2]=d;c[2430384]=2572;c[2430388]=1776;c[2432802]=1658;return}function dfj(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c[2113110]=3;c[2112950]=6502;a[9774784]=0;c[2406628]=c[3540932];c[2406629]=c[3540930];if((c[2394]|0)==0){b=c[2112932]|0}else{c[2394]=0;d=c[3532596]|0;c[2112932]=d;e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060];b=d}d=b+20480|0;e=5242880;while(1){c[d>>2]=5;c[d+65536>>2]=5;c[d+131072>>2]=5;f=e+1024|0;if(f>>>0>6291455){break}else{d=d+4|0;e=f}}c[b+196708>>2]=1542;c[b+196628>>2]=1876;c[b+196748>>2]=2108;c[b+196668>>2]=2426;b=c[3532592]|0;if((b|0)!=0){gGC(b|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;c[2406724]=gGq(2097152)|0;c[2406722]=gGq(2097152)|0;b=gGq(2097152)|0;e=b;c[2406720]=e;d=c[2427044]|0;c[9681616+(d<<3)>>2]=990744;c[9681620+(d<<3)>>2]=1;c[2427044]=d+1;d=c[3540934]|0;f=c[2406724]|0;c[f>>2]=d;c[e>>2]=d;g=d+4096|0;c[f+4>>2]=g;c[b+4>>2]=g;g=d+8192|0;c[f+8>>2]=g;c[b+8>>2]=g;g=d+12288|0;c[f+12>>2]=g;c[b+12>>2]=g;g=c[3540910]|0;d=((((c[2113108]|0)-1|134217728)-134217728|0)>>>12)+1|0;h=0;do{i=h+32768|0;j=g+(h<<12)|0;c[f+(i<<2)>>2]=j;c[e+(i<<2)>>2]=j;h=h+1|0;}while(h>>>0<d>>>0);d=c[3540940]|0;c[f+262144>>2]=d;h=c[2406722]|0;c[h+262144>>2]=d;c[b+262144>>2]=d;d=c[3540938]|0;g=0;do{j=g+98304|0;i=d+(g<<12)|0;c[f+(j<<2)>>2]=i;c[h+(j<<2)>>2]=i;c[e+(j<<2)>>2]=i;g=g+1|0;}while(g>>>0<64);g=c[2406629]|0;d=0;do{i=d+229376|0;j=g+(d<<12)|0;c[f+(i<<2)>>2]=j;c[h+(i<<2)>>2]=j;c[e+(i<<2)>>2]=j;d=d+1|0;}while(d>>>0<32);d=c[3540936]|0;c[f+1310720>>2]=d;c[h+1310720>>2]=d;c[b+1310720>>2]=d;c[2430392]=1794;c[2430384]=778;c[2430388]=2826;c[2432806]=3042;c[2432798]=188;c[2432802]=3278;return}function dfk(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=i;i=i+128|0;e=d|0;f=d+16|0;g=d+32|0;h=d+48|0;j=d+64|0;k=d+80|0;l=d+96|0;m=d+112|0;if((b&32|0)!=0){n=m|0;c[n>>2]=c[3540932];o=m+4|0;c[o>>2]=131072;p=m+8|0;c[p>>2]=4194304;q=m+12|0;c[q>>2]=227384;r=c[2076592]|0;gj[r&4095](m)|0;c[n>>2]=c[3540930];c[o>>2]=131072;c[p>>2]=5242880;c[q>>2]=221544;r=c[2076592]|0;gj[r&4095](m)|0;c[n>>2]=c[3540940];c[o>>2]=1024;c[p>>2]=0;c[q>>2]=217512;r=c[2076592]|0;gj[r&4095](m)|0;c[n>>2]=c[3540938];c[o>>2]=262144;c[p>>2]=0;c[q>>2]=213888;r=c[2076592]|0;gj[r&4095](m)|0;c[n>>2]=c[3540936];c[o>>2]=1024;c[p>>2]=0;c[q>>2]=210088;q=c[2076592]|0;gj[q&4095](m)|0}if((b&64|0)==0){i=d;return 0}gGz(h|0,0,12);c[h>>2]=9698808;c[h+4>>2]=160;c[h+12>>2]=532152;gj[c[2076592]&4095](h)|0;gGz(g|0,0,12);c[g>>2]=14107896;c[g+4>>2]=4;c[g+12>>2]=518504;gj[c[2076592]&4095](g)|0;gGz(f|0,0,12);c[f>>2]=9760744;c[f+4>>2]=4;c[f+12>>2]=505312;gj[c[2076592]&4095](f)|0;gGz(e|0,0,12);c[e>>2]=14107744;c[e+4>>2]=4;c[e+12>>2]=493296;gj[c[2076592]&4095](e)|0;gGz(l|0,0,12);c[l>>2]=9753376;c[l+4>>2]=1;c[l+12>>2]=204928;gj[c[2076592]&4095](l)|0;gGz(k|0,0,12);c[k>>2]=9753384;c[k+4>>2]=1;c[k+12>>2]=198760;gj[c[2076592]&4095](k)|0;gGz(j|0,0,12);c[j>>2]=9774784;c[j+4>>2]=1;c[j+12>>2]=193288;gj[c[2076592]&4095](j)|0;j=a[9774784]&1;a[9774784]=j;k=j&255;j=c[9626512+(k<<2)>>2]|0;l=c[2406724]|0;e=c[2406722]|0;f=c[2406720]|0;g=0;do{h=g+229376|0;b=j+(g<<12)|0;c[l+(h<<2)>>2]=b;c[e+(h<<2)>>2]=b;c[f+(h<<2)>>2]=b;g=g+1|0;}while(g>>>0<32);g=c[9626512+((k^1)<<2)>>2]|0;k=(c[2112932]|0)+20480|0;f=5242880;while(1){c[k+131072>>2]=g+(f-5242880);e=f+1024|0;if(e>>>0>5373951){break}else{k=k+4|0;f=e}}i=d;return 0}function dfl(a){a=a|0;var e=0,f=0;if((a&268304384|0)==5242880){e=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)-(c[2440186]|0)|0;if((e|0)>0){fyW(e)|0}f=b[(c[9626512+(((d[9774784]|0)^1)<<2)>>2]|0)+(a&131070)>>1]|0;return f|0}if((a|0)!=6030080){f=0;return f|0}a=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)-(c[2440186]|0)|0;if((a|0)>0){fyW(a)|0}f=d[9753384]|0;return f|0}function dfm(b){b=b|0;var e=0,f=0;if((b&268304384|0)!=5242880){e=0;return e|0}f=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)-(c[2440186]|0)|0;if((f|0)>0){fyW(f)|0}e=a[(c[9626512+(((d[9774784]|0)^1)<<2)>>2]|0)+(b&131071^1)|0]|0;return e|0}function dfn(e,f){e=e|0;f=f|0;var g=0;g=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)-(c[2440186]|0)|0;if((g|0)>0){fyW(g)|0}if((e&268304384|0)==5242880){b[(c[9626512+(((d[9774784]|0)^1)<<2)>>2]|0)+(e&131070)>>1]=f;return}if((e|0)==6029312){a[9698957]=1;fyX();fyW(0)|0;a[9698957]=0;fyX();return}else if((e|0)==6030080){a[9753376]=f&255;return}else{return}}function dfo(b,e){b=b|0;e=e|0;var f=0;f=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)-(c[2440186]|0)|0;if((f|0)>0){fyW(f)|0}if((b&268304384|0)==5242880){a[(c[9626512+(((d[9774784]|0)^1)<<2)>>2]|0)+(b&131071^1)|0]=e;return}if((b-6029312|0)>>>0>=2){return}a[9698957]=1;fyX();fyW(0)|0;a[9698957]=0;fyX();return}function dfp(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;if((b|0)==1207959552){a[9753384]=d;return}else if((b|0)==1073741848){b=d&1;a[9774784]=b;d=b&255;b=c[9626512+(d<<2)>>2]|0;e=c[2406724]|0;f=c[2406722]|0;g=c[2406720]|0;h=0;do{i=h+229376|0;j=b+(h<<12)|0;c[e+(i<<2)>>2]=j;c[f+(i<<2)>>2]=j;c[g+(i<<2)>>2]=j;h=h+1|0;}while(h>>>0<32);h=c[9626512+((d^1)<<2)>>2]|0;d=(c[2112932]|0)+20480|0;g=5242880;while(1){c[d+131072>>2]=h+(g-5242880);f=g+1024|0;if(f>>>0>5373951){break}else{d=d+4|0;g=f}}return}else{return}}function dfq(a,b){a=a|0;b=b|0;return}function dfr(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;if((b|0)==1207959552){a[9753384]=d&255;return}else if((b|0)==1073741848){b=d&1;a[9774784]=b;d=b&255;b=c[9626512+(d<<2)>>2]|0;e=c[2406724]|0;f=c[2406722]|0;g=c[2406720]|0;h=0;do{i=h+229376|0;j=b+(h<<12)|0;c[e+(i<<2)>>2]=j;c[f+(i<<2)>>2]=j;c[g+(i<<2)>>2]=j;h=h+1|0;}while(h>>>0<32);h=c[9626512+((d^1)<<2)>>2]|0;d=(c[2112932]|0)+20480|0;g=5242880;while(1){c[d+131072>>2]=h+(g-5242880);f=g+1024|0;if(f>>>0>5373951){break}else{d=d+4|0;g=f}}return}else{return}}function dfs(b){b=b|0;return((b-1207959552|0)>>>0<4?a[9753376]|0:0)|0}function dft(a){a=a|0;var b=0;if((a|0)==1207959552|(a|0)==1207959554){b=d[9753376]|0}else{b=0}return b|0}function dfu(a){a=a|0;var b=0;if((a|0)==1207959552){b=d[9753376]|0}else{b=0}return b|0}function dfv(){var a=0,b=0,d=0,e=0,f=0;c[2112950]=2138;c[2112952]=1650;if((c[2394]|0)==0){a=c[2112932]|0;b=c[3532592]|0}else{c[2394]=0;d=c[3532596]|0;c[2112932]=d;e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060];a=d;b=e}c[a+49216>>2]=4;c[a+114752>>2]=4;c[a+196704>>2]=986;c[a+196744>>2]=3120;if((b|0)==0){f=c[2113054]|0;c[2113060]=f;c[2394]=-1;return}gGC(b|0,9104152,280)|0;f=c[2113054]|0;c[2113060]=f;c[2394]=-1;return}function dfw(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;i=i+160|0;d=b|0;e=b+16|0;f=b+32|0;g=b+48|0;h=b+64|0;j=b+80|0;k=b+96|0;l=b+112|0;m=b+128|0;n=b+144|0;if((a&64|0)==0){i=b;return 0}gGz(n|0,0,12);c[n>>2]=9542904;c[n+4>>2]=1;c[n+12>>2]=298336;gj[c[2076592]&4095](n)|0;gGz(m|0,0,12);c[m>>2]=14107888;c[m+4>>2]=1;c[m+12>>2]=291040;gj[c[2076592]&4095](m)|0;gGz(l|0,0,12);c[l>>2]=14107889;c[l+4>>2]=1;c[l+12>>2]=284528;gj[c[2076592]&4095](l)|0;gGz(k|0,0,12);c[k>>2]=14107890;c[k+4>>2]=1;c[k+12>>2]=277768;gj[c[2076592]&4095](k)|0;gGz(j|0,0,12);c[j>>2]=9627208;c[j+4>>2]=1;c[j+12>>2]=270464;gj[c[2076592]&4095](j)|0;gGz(h|0,0,12);c[h>>2]=9627200;c[h+4>>2]=1;c[h+12>>2]=263216;gj[c[2076592]&4095](h)|0;gGz(g|0,0,12);c[g>>2]=9627192;c[g+4>>2]=1;c[g+12>>2]=254640;gj[c[2076592]&4095](g)|0;gGz(f|0,0,12);c[f>>2]=9620544;c[f+4>>2]=1;c[f+12>>2]=246776;gj[c[2076592]&4095](f)|0;gGz(e|0,0,12);c[e>>2]=9620536;c[e+4>>2]=1;c[e+12>>2]=240128;gj[c[2076592]&4095](e)|0;gGz(d|0,0,12);c[d>>2]=14115376;c[d+4>>2]=2;c[d+12>>2]=233568;gj[c[2076592]&4095](d)|0;i=b;return 0}function dfx(){gGz(14107888|0,0|0,3|0);b[7057688]=0;a[9542904]=0;a[9627208]=0;a[9627200]=0;a[9627192]=0;a[9620544]=0;a[9620536]=0;return}function dfy(b){b=b|0;var c=0,f=0;if((b|0)!=12599310){c=0;return c|0}switch(d[9542904]|0|0){case 44:{f=73;break};case 45:{f=-7;break};case 46:{f=10;break};case 48:{f=38;break};case 40:{f=65;break};case 42:{f=62;break};case 43:{f=65;break};case 38:{f=127;break};case 39:{f=65;break};case 3:{b=e[7057688]|0;f=(b>>>5<<7|b>>>15|b>>>12<<1&2|b>>>13<<2&4|b>>>10<<3&8|b>>>7<<4&16|b>>>9<<5&32|b>>>2<<6&64)&255;break};case 36:{f=65;break};case 32:{f=73;break};case 2:{f=a[14163495]<<6&-128|a[14107890]&127;break};case 33:{f=71;break};case 0:{f=a[14163495]<<3&8|a[14107888]&-9;break};case 1:{f=a[14107889]|0;break};case 37:{f=65;break};case 49:{f=73;break};case 50:{f=73;break};case 51:{f=73;break};case 52:{f=50;break};case 34:{f=83;break};default:{f=0}}c=f&255;return c|0}function dfz(f,g){f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0;if((f|0)==12599310){h=a[9542904]|0;if((h&255)<3){a[14107888+(h&255)|0]=(g&255)<<1;return}if((h<<24>>24|0)==64){a[9620536]=a[9620544]|0;a[9620544]=g&255;return}else if((h<<24>>24|0)==(-96|0)){b[7057688]=0;return}else if((h<<24>>24|0)==72){a[9627208]=0;i=a[9620536]|0;if((i&10)==0){a[9627208]=8;j=8}else{j=0}if((i&-112)<<24>>24==0){i=j|4;a[9627208]=i;k=i}else{k=j}j=a[9620544]|0;if((j&6)==0){i=k|2;a[9627208]=i;l=i}else{l=k}if((j&-112)<<24>>24!=0){return}a[9627208]=l|1;return}else{if(!(h<<24>>24<0&(h&255)<136)){return}l=h&7;a[9627200]=l;a[9627192]=g&255;h=c[597976+((a[14163495]&3)<<2)>>2]|0;if((h|0)==1){j=e[7057688]|0;k=d[9627208]|0;b[7057688]=((1<<(l&255)&(g&255)|0)!=0^11181^j<<1^j>>>15^j>>>10&1^j>>>8&1^j>>>5&1^k<<1&2^k>>>1<<6&64^k>>>2<<10&1024^k>>>3<<14&16384)&65535;return}else if((h|0)==2){k=e[7057688]|0;j=d[9627208]|0;b[7057688]=((1<<(l&255)&(g&255)|0)!=0^11181^k<<1^k>>>15^k>>>7&1^k>>>6&1^k>>>5&1^j<<4&16^j>>>1<<6&64^j>>>2<<10&1024^j>>>3<<12&4096)&65535;return}else if((h|0)==3){h=e[7057688]|0;j=d[9627208]|0;b[7057688]=((1<<(l&255)&(g&255)|0)!=0^11181^h<<1^h>>>15^h>>>10&1^h>>>8&1^h>>>5&1^j<<4&16^j>>>1<<6&64^j>>>2<<10&1024^j>>>3<<12&4096)&65535;return}else{return}}}else if((f|0)==12599296){a[9542904]=g&255;return}else{return}}function dfA(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;h=g&15;L70182:do{switch(h<<16>>16){case 0:case 1:case 2:case 3:{i=c[3540910]|0;j=i+65536|0;k=f&65535;if(f<<16>>16!=0){l=a&65535;m=(g&65535)>>>8&65535;n=e&65535;if((h<<16>>16|0)==1){o=c[2438904]|0;p=0;do{q=(p<<1)+m&255;r=(d[i+(q|65536)|0]|0)<<8|(d[i+(q+65537)|0]|0);b[o+(p+n<<1)>>1]=(ga(b[j+(p+l<<1)>>1]|0)|0)-r&65535;p=p+1|0;}while((p|0)<(k|0))}else if((h<<16>>16|0)==2){p=c[2438904]|0;o=0;do{r=(o<<1)+m&255;q=(d[i+(r|65536)|0]|0)<<8|(d[i+(r+65537)|0]|0);b[p+(o+n<<1)>>1]=q+(ga(b[j+(o+l<<1)>>1]|0)|0)&65535;o=o+1|0;}while((o|0)<(k|0))}else if((h<<16>>16|0)==3){o=c[2438904]|0;p=0;do{q=(p<<1)+m&255;r=ga(b[j+(p+l<<1)>>1]|0)|0;b[o+(p+n<<1)>>1]=((d[i+(q|65536)|0]|0)<<8|(d[i+(q+65537)|0]|0))^r;p=p+1|0;}while((p|0)<(k|0))}else{p=c[2438904]|0;o=0;do{b[p+(o+n<<1)>>1]=ga(b[j+(o+l<<1)>>1]|0)|0;o=o+1|0;}while((o|0)<(k|0))}}if((h<<16>>16|0)==5){s=k;t=i;u=59579;break L70182}else if((h<<16>>16|0)==6){v=k;w=i;u=59582;break L70182}return};case 6:{v=f&65535;w=c[3540910]|0;u=59582;break};case 5:{s=f&65535;t=c[3540910]|0;u=59579;break};default:{return}}}while(0);if((u|0)==59579){h=t+65536|0;if(f<<16>>16==0){return}t=a&65535;g=e&65535;o=c[2438904]|0;l=0;do{b[o+(l+g<<1)>>1]=b[h+(l+t<<1)>>1]|0;l=l+1|0;}while((l|0)<(s|0));return}else if((u|0)==59582){u=w+65536|0;if(f<<16>>16==0){return}f=a&65535;a=e&65535;e=c[2438904]|0;w=0;do{s=b[u+(w+f<<1)>>1]|0;b[e+(w+a<<1)>>1]=s<<12|(s&65535)>>>12|(s&65535)>>>4&240|s<<4&3840;w=w+1|0;}while((w|0)<(v|0));return}}function dfB(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=i;i=i+240|0;d=b|0;e=b+112|0;f=b+120|0;g=b+232|0;h=c[642608+(c[2436]<<2)>>2]|0;j=(fa(c[h>>2]|0,382360)|0)==0;k=(c[3540910]|0)+65536|0;do{if(j){if((c[3542200]|0)==0){break}l=d+108|0;c[l>>2]=0;m=d+100|0;c[m>>2]=0;n=c[h+76>>2]|0;gA[n&16383](d,11)|0;if((c[l>>2]|0)==0){break}l=c[m>>2]|0;c[e>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](e,11,0)|0;if((l|0)<1){break}gzL(k,0,11)|0}else{if((c[3542200]|0)==0){break}l=f+108|0;c[l>>2]=0;m=f+100|0;c[m>>2]=0;n=c[h+76>>2]|0;gA[n&16383](f,14)|0;if((c[l>>2]|0)==0){break}l=c[m>>2]|0;c[g>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](g,14,0)|0;if((l|0)<1){break}gzL(k,0,14)|0}}while(0);k=c[3540910]|0;g=0;f=k+65536|0;while(1){h=a[f]|0;e=f+1|0;a[f]=a[e]|0;a[e]=h;h=g+1|0;if((h|0)<32768){g=h;f=f+2|0}else{break}}c[2112950]=15080;c[2112952]=11712;c[2438904]=k;c[2432914]=794832;a[684312]=1;a[6526584]=1;if((c[2394]|0)==0){o=c[2112932]|0;p=c[3532592]|0}else{c[2394]=0;f=c[3532596]|0;c[2112932]=f;g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060];o=f;p=g}c[o+12288>>2]=k;c[o+77824>>2]=k;c[o+143360>>2]=k;g=k+1024|0;c[o+12292>>2]=g;c[o+77828>>2]=g;c[o+143364>>2]=g;g=k+2048|0;c[o+12296>>2]=g;c[o+77832>>2]=g;c[o+143368>>2]=g;g=k+3072|0;c[o+12300>>2]=g;c[o+77836>>2]=g;c[o+143372>>2]=g;g=k+4096|0;c[o+12304>>2]=g;c[o+77840>>2]=g;c[o+143376>>2]=g;g=k+5120|0;c[o+12308>>2]=g;c[o+77844>>2]=g;c[o+143380>>2]=g;g=k+6144|0;c[o+12312>>2]=g;c[o+77848>>2]=g;c[o+143384>>2]=g;g=k+7168|0;c[o+12316>>2]=g;c[o+77852>>2]=g;c[o+143388>>2]=g;g=k+8192|0;c[o+12320>>2]=g;c[o+77856>>2]=g;c[o+143392>>2]=g;g=k+9216|0;c[o+12324>>2]=g;c[o+77860>>2]=g;c[o+143396>>2]=g;g=k+10240|0;c[o+12328>>2]=g;c[o+77864>>2]=g;c[o+143400>>2]=g;g=k+11264|0;c[o+12332>>2]=g;c[o+77868>>2]=g;c[o+143404>>2]=g;g=k+12288|0;c[o+12336>>2]=g;c[o+77872>>2]=g;c[o+143408>>2]=g;g=k+13312|0;c[o+12340>>2]=g;c[o+77876>>2]=g;c[o+143412>>2]=g;g=k+14336|0;c[o+12344>>2]=g;c[o+77880>>2]=g;c[o+143416>>2]=g;g=k+15360|0;c[o+12348>>2]=g;c[o+77884>>2]=g;c[o+143420>>2]=g;c[o+54272>>2]=4;c[o+119808>>2]=4;c[o+196704>>2]=2858;c[o+196744>>2]=1708;if((p|0)==0){q=c[2113054]|0;c[2113060]=q;c[2394]=-1;i=b;return}gGC(p|0,9104152,280)|0;q=c[2113054]|0;c[2113060]=q;c[2394]=-1;i=b;return}function dfC(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=i;i=i+128|0;d=b|0;e=b+16|0;f=b+32|0;g=b+48|0;h=b+64|0;j=b+80|0;k=b+96|0;l=b+112|0;if((a&32|0)!=0){m=l|0;c[m>>2]=c[3540910];n=l+4|0;c[n>>2]=16384;o=l+8|0;c[o>>2]=3145728;p=l+12|0;c[p>>2]=156232;q=c[2076592]|0;gj[q&4095](l)|0;c[m>>2]=9542288;c[n>>2]=1024;c[o>>2]=-1024;c[p>>2]=363624;p=c[2076592]|0;gj[p&4095](l)|0}if((a&64|0)==0){i=b;return 0}gGz(k|0,0,12);c[k>>2]=9752976;c[k+4>>2]=2;c[k+12>>2]=356464;gj[c[2076592]&4095](k)|0;gGz(j|0,0,12);c[j>>2]=9752984;c[j+4>>2]=2;c[j+12>>2]=348256;gj[c[2076592]&4095](j)|0;gGz(h|0,0,12);c[h>>2]=9717136;c[h+4>>2]=2;c[h+12>>2]=340680;gj[c[2076592]&4095](h)|0;gGz(g|0,0,12);c[g>>2]=9579224;c[g+4>>2]=4;c[g+12>>2]=332696;gj[c[2076592]&4095](g)|0;gGz(f|0,0,12);c[f>>2]=9579208;c[f+4>>2]=4;c[f+12>>2]=323800;gj[c[2076592]&4095](f)|0;gGz(e|0,0,12);c[e>>2]=9579216;c[e+4>>2]=4;c[e+12>>2]=315120;gj[c[2076592]&4095](e)|0;gGz(d|0,0,12);c[d>>2]=9542280;c[d+4>>2]=1;c[d+12>>2]=306384;gj[c[2076592]&4095](d)|0;i=b;return 0}function dfD(){var d=0,e=0,f=0,g=0,h=0,i=0;d=c[3540910]|0;e=c[2438904]|0;f=0;do{b[e+(f<<1)>>1]=-23206;f=f+1|0;}while((f|0)<8192);f=b[d+65792>>1]|0;g=b[d+65796>>1]|0;h=b[d+65798>>1]|0;i=ga(b[d+65794>>1]|0)|0;dfA(f<<7&32640|(f&65535)>>>9,i,ga(g|0)|0,h&255);b[e+674>>1]=ga(b[d+65812>>1]|0)|0;b[4876488]=0;b[4876492]=0;b[4858568]=0;c[2394806]=0;c[2394802]=0;c[2394804]=0;a[9542280]=0;gGz(9542288,0,64);return}function dfE(e){e=e|0;var f=0,g=0,h=0,i=0,j=0;if((e&2|0)==0){f=0;return f|0}e=c[2394806]|0;if((e|0)==1){f=c[2394802]&127;return f|0}else if((e|0)==5){g=c[2394804]|0;if((g|0)==1){f=d[14163495]|0|16128;return f|0}else if((g|0)==2){f=a[6526584]|0?16148:16128;return f|0}else if((g|0)==3){f=a[6526584]|0?16273:16128;return f|0}else if((g|0)==4){f=a[6526584]|0?16265:16128;return f|0}else{g=b[4876488]|0;f=(g&65535)>>>15|(g&65535)>>>2<<6&64|(g&65535)>>>5<<7&128|(g&65535)>>>9<<5&32|(g&65535)>>>7<<4&16|(g&65535)>>>10<<3&8|(g&65535)>>>13<<2&4|(g&65535)>>>12<<1&2|16128;return f|0}}else if((e|0)==64){g=(b[4858568]|0)+1&65535;h=(g&65535)>235?0:g;b[4858568]=h;g=h&65535;h=a[(c[2432914]|0)+(((d[14163495]|0)-(a[684312]|0?22:0)|0)*236|0)+g|0]|0;i=b[4876492]|0;if((g&1|0)==0){j=i&-256|h&255}else{j=i&255|(h&255)<<8}b[4876492]=j;f=0;return f|0}else if((e|0)==0){e=(d[9542280]|0)+1|0;f=(e>>>7&1|e<<7&128|e>>>1<<6&64|e>>>2<<5&32|e>>>3<<4&16|e>>>4<<3&8|e>>>5<<2&4|e>>>6<<1&2)&65535;return f|0}else{f=0;return f|0}return 0}function dfF(d,f){d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((d&15|0)==0){c[2394806]=f&65535;return}d=c[2394806]|0;switch(d|0){case 4:{c[2394804]=f&65535;return};case 32:case 33:case 34:case 35:case 36:case 37:case 38:case 39:{c[2394804]=(c[2394804]|0)+1;g=b[4876488]|0;h=g&65535;b[4876488]=(((g<<1|(g&65535)>>>15)^11181)&65535^16^(h>>>7^(f&255)>>>((d&15)>>>0))&1^(e[4876492]|0)<<1&63470^(h>>>13<<4&16|h>>>3<<11&2048))&65535;return};case 0:{c[2394802]=f&65535;return};case 3:{a[9542280]=f&255;return};case 2:{if(f<<16>>16!=1){return}f=c[2438904]|0;h=b[f+512>>1]|0;do{if((h<<16>>16|0)==109){d=e[f+664>>1]|0;g=e[f+666>>1]|0;i=d<<16|g;j=f+668|0;k=e[j>>1]|0;l=f+670|0;m=b[l>>1]|0;if((m<<16>>16|0)==9){if((k&512|0)==0){break}c[9542288+((k&255)<<2)>>2]=i;break}else if((m<<16>>16|0)==6){c[9542288+((k&255)<<2)>>2]=(c[9542288+((g&255)<<2)>>2]|0)-(c[9542288+((d&255)<<2)>>2]|0);break}else if((m<<16>>16|0)==1){i=9542288+((k&255)<<2)|0;c[i>>2]=(c[i>>2]|0)+g;break}else if((m<<16>>16|0)==10){m=9542288+((d&255)<<2)|0;b[j>>1]=(c[m>>2]|0)>>>16&65535;b[l>>1]=c[m>>2]&65535;break}else{break}}else if((h<<16>>16|0)==79){dfA((e[f+656>>1]|0)>>>1,b[f+658>>1]|0,b[f+660>>1]|0,b[f+662>>1]|0)}}while(0);c[2394802]=(c[2394802]|0)+1;return};default:{return}}}function dfG(a,d){a=a|0;d=d|0;var e=0,f=0,g=0;e=a&6;if((e|0)==2){if((d&-256)<<16>>16==-256){b[4873544]=-1;f=-1}else{f=b[4873544]|0}a=b[4861048]^f;b[4861048]=a;g=f^d;b[9731936+((g&255)<<1)>>1]=a;gf[c[2429682]&2047](g&255);g=(b[4873544]|0)+256&65535&-256;a=g<<16>>16==-256?256:g;b[4873544]=(a&65535)>>>8|a;return}else if((e|0)==0){b[4861048]=d;return}else{return}}function dfH(){var a=0,b=0,d=0,e=0,f=0;c[2112952]=2392;c[2112950]=1460;c[2429682]=634;if((c[2394]|0)==0){a=c[2112932]|0;b=c[3532592]|0}else{c[2394]=0;d=c[3532596]|0;c[2112932]=d;e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060];a=d;b=e}c[a+16384>>2]=4;c[a+81920>>2]=4;c[a+196704>>2]=2158;c[a+196744>>2]=1174;if((b|0)==0){f=c[2113054]|0;c[2113060]=f;c[2394]=-1;return}gGC(b|0,9104152,280)|0;f=c[2113054]|0;c[2113060]=f;c[2394]=-1;return}function dfI(){var d=0,e=0,f=0,g=0;d=c[3540910]|0;gGz(d|0,0,1024);e=a[14163495]|0;gGC(d|0,598128,9)|0;f=d+9|0;a[f]=e;g=d+10|0;a[g]=a[598138]|0;a[g+1|0]=a[598139]|0;a[g+2|0]=a[598140]|0;a[g+3|0]=a[598141]|0;a[g+4|0]=a[598142]|0;a[d]=71;a[d+1|0]=73;a[d+2|0]=80;a[d+3|0]=83;a[d+4|0]=77;a[d+5|0]=71;a[d+6|0]=0;a[d+7|0]=0;a[d+8|0]=e;a[f]=0;a[g]=72;a[d+11|0]=67;a[d+12|0]=78;a[d+13|0]=73;a[d+14|0]=0;a[d+15|0]=65;gGz(9722104,0,1024);gGz(9731936,0,512);b[4861048]=0;b[4873544]=0;c[2429448]=0;a[9707904]=0;return}function dfJ(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;i=i+80|0;d=b|0;e=b+16|0;f=b+32|0;g=b+48|0;h=b+64|0;if((a&32|0)!=0){j=h|0;c[j>>2]=9722104;k=h+4|0;c[k>>2]=1024;l=h+8|0;c[l>>2]=267386880;m=h+12|0;c[m>>2]=428928;n=c[2076592]|0;gj[n&4095](h)|0;c[j>>2]=9731936;c[k>>2]=512;c[l>>2]=267390976;c[m>>2]=417584;m=c[2076592]|0;gj[m&4095](h)|0}if((a&64|0)==0){i=b;return 0}gGz(g|0,0,12);c[g>>2]=9722096;c[g+4>>2]=2;c[g+12>>2]=405608;gj[c[2076592]&4095](g)|0;gGz(f|0,0,12);c[f>>2]=9747088;c[f+4>>2]=2;c[f+12>>2]=394688;gj[c[2076592]&4095](f)|0;gGz(e|0,0,12);c[e>>2]=9717792;c[e+4>>2]=4;c[e+12>>2]=383080;gj[c[2076592]&4095](e)|0;gGz(d|0,0,12);c[d>>2]=9707904;c[d+4>>2]=1;c[d+12>>2]=373304;gj[c[2076592]&4095](d)|0;i=b;return 0}function dfK(f){f=f|0;var g=0;switch(f&255|0){case 103:{f=b[4861048]|0;g=(f&65535)>>>8;a[9707904]=g&255;c[9722104+((g&65535)<<2)>>2]=(f&65535)<<16&16711680;c[2429448]=8912896;return};case 64:{f=e[4861048]|0;c[9722104+((f>>>10&31)<<2)>>2]=(c[9722104+((f&31)<<2)>>2]|0)+(c[9722104+((f>>>5&31)<<2)>>2]|0)&16777215;c[2429448]=8912896;return};case 153:{b[4873544]=0;c[2429448]=(d[14163495]|0)<<8|8912896;return};case 142:{c[2429448]=c[9722104+((b[4861048]&255)<<2)>>2];return};case 229:{f=9722104+((d[9707904]|0)<<2)|0;c[f>>2]=c[f>>2]|(e[4861048]|0);c[2429448]=8912896;return};default:{c[2429448]=8912896;return}}}function dfL(a){a=a|0;var b=0,d=0;b=a&2;if((b|0)==0){d=((e[4873544]|0)^c[2429448])&65535;return d|0}else if((b|0)==2){d=((e[4873544]|0)^(c[2429448]|0)>>>16)&65535;return d|0}else{d=0;return d|0}return 0}function dfM(){var a=0,b=0,d=0,e=0,f=0;c[2112952]=2392;c[2112950]=1460;c[2429682]=634;if((c[2394]|0)==0){a=c[2112932]|0;b=c[3532592]|0}else{c[2394]=0;d=c[3532596]|0;c[2112932]=d;e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060];a=d;b=e}c[a+20480>>2]=4;c[a+86016>>2]=4;c[a+196704>>2]=2158;c[a+196744>>2]=1174;if((b|0)==0){f=c[2113054]|0;c[2113060]=f;c[2394]=-1;return}gGC(b|0,9104152,280)|0;f=c[2113054]|0;c[2113060]=f;c[2394]=-1;return}function dfN(){var a=0,b=0,d=0,e=0,f=0;c[2112952]=2392;c[2112950]=1460;c[2429682]=1144;if((c[2394]|0)==0){a=c[2112932]|0;b=c[3532592]|0}else{c[2394]=0;d=c[3532596]|0;c[2112932]=d;e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060];a=d;b=e}c[a+20224>>2]=c[3540910];c[a+20480>>2]=4;c[a+86016>>2]=4;c[a+196704>>2]=2158;c[a+196744>>2]=1174;if((b|0)==0){f=c[2113054]|0;c[2113060]=f;c[2394]=-1;return}gGC(b|0,9104152,280)|0;f=c[2113054]|0;c[2113060]=f;c[2394]=-1;return}function dfO(f){f=f|0;var g=0,h=0,i=0,j=0;switch(f&255|0){case 248:{c[2429448]=c[9722104+((e[4861048]|0)<<2)>>2];return};case 197:{c[2430539]=(c[2430539]|0)-1;c[2429448]=10027008;return};case 51:{c[2429448]=10027008;return};case 54:{c[2429448]=10027008;return};case 56:{c[2429448]=e[4866019]|0;return};case 136:{b[4873544]=0;c[2429448]=(d[14163495]|0)<<8|10027008;return};case 160:{f=b[4861048]|0;if((f&65535)>14){g=525}else{g=(f&65535)*35|0}c[2429448]=g;return};case 208:{c[2429448]=((e[4861048]|0)<<5)+10489856;return};case 231:{c[2429448]=10027008;a[9707904]=(e[4861048]|0)>>>12&255;return};case 229:{c[2429448]=10027008;g=a[9707904]|0;c[9722104+((g&255)<<2)>>2]=e[4861048]|0;if(g<<24>>24!=11){return}c[2430538]=0;return};case 192:{c[2429448]=((e[4861048]|0)<<6)+10485760;return};case 240:{c[2429448]=10027008;return};case 237:{g=b[4861048]|0;if((g&1024)==0){h=g}else{f=g|-1024;b[4861048]=f;h=f}c[2429448]=(((h&65535)<<6)+(e[4866208]|0)<<2)+9437184;return};case 224:{c[2429448]=10027008;return};case 195:{c[2429448]=((e[4861048]|0)<<6)+10487808;return};case 55:{b[4866019]=(b[4866019]|0)+(b[4861048]|0)&65535;c[2429448]=10027008;return};case 52:{c[2429448]=e[4866022]|0;return};case 214:{c[2430537]=(c[2430537]|0)+1;c[2429448]=10027008;return};case 58:{c[2430541]=0;c[2429448]=10027008;return};case 220:{c[2429448]=(((e[4861048]|0)<<6)+(e[4866192]|0)<<2)+9453568;return};case 203:{c[2429448]=49152;return};case 94:{c[2429448]=d[7018296+(e[4861048]|0)|0]|0;return};case 128:{h=b[4861048]|0;if((h&65535)<4){i=((h&65535)*3e3|0)+3e3|0}else{i=1e6}c[2429448]=i;return};case 140:{c[2429448]=e[7018232+((e[4861048]|0)<<1)>>1]|0;return};case 144:{c[2429448]=e[7018216+((e[4861048]|0)<<1)>>1]|0;return};case 157:{i=b[4861048]|0;h=(i&65535)%39|0;do{if((h&65535)<8){j=h*100&65535}else{if((h&65535)>22){j=1724;break}j=(ag(d[614024+(((i&65535)/39|0)&65535)|0]|0,h-7&65535)|0)+700&65535}}while(0);c[2429448]=j&65535;return};case 53:{b[4866022]=(b[4866022]|0)+(b[4861048]|0)&65535;c[2429448]=10027008;return};case 174:{c[2429448]=d[7017992+(e[4861048]|0)|0]|0;return};case 176:{c[2429448]=d[7017768+(e[4861048]|0)|0]|0;return};case 186:{c[2429448]=e[7017760+((e[4861048]|0)<<1)>>1]|0;return};case 252:{c[2429448]=d[7017728+(e[4861048]|0)|0]|0;return};default:{c[2429448]=10027008;return}}}function dfP(){var a=0,b=0,d=0,e=0,f=0;c[2112952]=2392;c[2112950]=1460;c[2429682]=682;if((c[2394]|0)==0){a=c[2112932]|0;b=c[3532592]|0}else{c[2394]=0;d=c[3532596]|0;c[2112932]=d;e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060];a=d;b=e}c[a+20224>>2]=c[3540910];c[a+20480>>2]=4;c[a+86016>>2]=4;c[a+196704>>2]=2158;c[a+196744>>2]=1174;if((b|0)==0){f=c[2113054]|0;c[2113060]=f;c[2394]=-1;return}gGC(b|0,9104152,280)|0;f=c[2113054]|0;c[2113060]=f;c[2394]=-1;return}function dfQ(f){f=f|0;var g=0,h=0,i=0;switch(f&255|0){case 231:{c[2429448]=8912896;f=b[4861048]|0;g=(f&65535)>>>12;a[9707904]=g&255;h=9722104+((g&65535)<<2)|0;c[h>>2]=(f&65535)<<16&16711680|c[h>>2]&65535;return};case 192:{c[2429448]=8912896;return};case 103:case 142:case 163:case 51:case 58:case 197:{c[2429448]=8912896;return};case 203:{c[2429448]=8912896;return};case 157:{c[2429448]=(e[4861048]|0)<<6&1984|10485760;return};case 153:{b[4873544]=0;c[2429448]=(d[14163495]|0)<<8|8912896;return};case 180:case 183:{c[2429448]=8912896;h=b[4861048]|0;if(h<<16>>16==258){b[4861048]=256;i=256}else{i=h}h=i&65535;c[9722104+((h>>>8&15)<<2)>>2]=c[9722104+((h&15)<<2)>>2];return};case 224:case 158:{c[2429448]=(e[4861048]|0)<<6&1984|10485760;return};case 229:{c[2429448]=8912896;h=9722104+((d[9707904]|0)<<2)|0;c[h>>2]=e[4861048]|0|c[h>>2]&16711680;return};case 195:{c[2429448]=(((e[4861048]|0)<<6)+(e[4866160]|0)<<2)+9453568;return};case 186:{c[2429448]=d[672480+(b[4861048]&63)|0]|0;return};case 220:case 17:{c[2429448]=((e[4861048]|0)<<6)+10487808;return};case 240:{c[2429448]=49152;return};case 248:case 171:{c[2429448]=c[9722104+((b[4861048]&15)<<2)>>2]&16777215;return};case 176:{c[2429448]=d[672544+(b[4861048]&7)|0]|0;return};case 208:case 205:{c[2429448]=((e[4861048]|0)<<5)+10489856;return};case 204:{h=e[4861048]|0;c[2429448]=((((h&1024|0)==0?h:h|16776192)<<6)+(e[4866171]|0)<<2)+9437184;return};case 214:{c[2429448]=8912896;c[2430526]=c[9722104+((b[4861048]&15)<<2)>>2];return};case 252:{c[2429448]=(ag(e[4866222]|0,e[4861048]|0)|0)>>>6;return};case 254:{c[2429448]=8912896;return};default:{c[2429448]=8912896;return}}}function dfR(){var a=0,b=0,d=0,e=0,f=0;c[2112952]=2392;c[2112950]=1460;c[2429682]=1472;if((c[2394]|0)==0){a=c[2112932]|0;b=c[3532592]|0}else{c[2394]=0;d=c[3532596]|0;c[2112932]=d;e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060];a=d;b=e}c[a+20480>>2]=4;c[a+86016>>2]=4;c[a+196704>>2]=2158;c[a+196744>>2]=1174;c[a+20224>>2]=5;c[a+196708>>2]=1388;c[a+196628>>2]=1210;if((b|0)==0){f=c[2113054]|0;c[2113060]=f;c[2394]=-1;return}gGC(b|0,9104152,280)|0;f=c[2113054]|0;c[2113060]=f;c[2394]=-1;return}function dfS(f){f=f|0;var g=0,h=0;switch(f&255|0){case 174:{c[2429448]=e[641896+((e[4861048]|0)<<1)>>1]|0;return};case 224:{c[2429448]=((e[4861048]|0)<<6)+10485760;return};case 153:{b[4873544]=0;c[2429448]=(d[14163495]|0)<<8|8978432;return};case 186:{c[2429448]=d[641848+(e[4861048]|0)|0]|0;return};case 144:{c[2429448]=d[641960+(e[4861048]|0)|0]|0;return};case 177:{c[2429448]=8978432;return};case 191:{c[2429448]=ag(e[4861048]|0,e[4866145]|0)|0;return};case 206:{c[2429448]=8978432;return};case 207:{c[9722104+((e[4866174]|0)+16<<2)>>2]=e[4861048]|0;c[2429448]=8978432;return};case 208:{c[2429448]=((e[4861048]|0)<<5)+10489856;return};case 176:{c[2429448]=d[641880+(e[4861048]|0)|0]|0;return};case 231:{c[2429448]=8978432;f=b[4861048]|0;g=(f&65535)>>>12;a[9707904]=g&255;h=9722104+((g&65535)<<2)|0;c[h>>2]=(f&65535)<<16&16711680|c[h>>2]&65535;return};case 220:{c[2429448]=((e[4861048]|0)<<6)+10487808;return};case 248:{c[2429448]=c[9722104+((e[4861048]|0)<<2)>>2];return};case 157:{c[2429448]=d[641944+(e[4861048]|0)|0]|0;return};case 160:{c[2429448]=d[641928+(e[4861048]|0)|0]|0;return};case 229:{c[2429448]=8978432;h=9722104+((d[9707904]|0)<<2)|0;c[h>>2]=e[4861048]|0|c[h>>2]&16711680;return};case 193:{c[2429448]=0;return};case 128:{c[2429448]=d[642016+(e[4861048]|0)|0]|0;return};case 140:{c[2429448]=d[641976+(e[4861048]|0)|0]|0;return};default:{c[2429448]=8978432;return}}}function dfT(a){a=a|0;var b=0,e=0;if((a&62|0)==8){b=d[14163495]|0;return b|0}if((a&56|0)!=32){b=0;return b|0}e=9722104+((a>>>1&3|16)<<2)|0;a=c[e>>2]|0;c[e>>2]=a-1;b=a&65535;return b|0}function dfU(b){b=b|0;return((b&62|0)==8?a[14163495]|0:0)|0}function dfV(){var a=0,b=0,d=0,e=0,f=0;c[2112952]=2392;c[2112950]=1460;c[2429682]=872;if((c[2394]|0)==0){a=c[2112932]|0;b=c[3532592]|0}else{c[2394]=0;d=c[3532596]|0;c[2112932]=d;e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060];a=d;b=e}c[a+20224>>2]=c[3540910];c[a+20480>>2]=4;c[a+86016>>2]=4;c[a+196704>>2]=2158;c[a+196744>>2]=1174;if((b|0)==0){f=c[2113054]|0;c[2113060]=f;c[2394]=-1;return}gGC(b|0,9104152,280)|0;f=c[2113054]|0;c[2113060]=f;c[2394]=-1;return}function dfW(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;switch(f&255|0){case 49:{if((c[2429296]|0)!=2){f=c[2432824]|0;c[2429448]=f|13762560;c[2432824]=f+1;return}f=c[3528628]|0;g=(f|0)==0;h=b[4861048]|0;i=c[2415136]|0;do{if((i|0)==-1){c[2440740]=0;c[2439294]=0;c[3528800]=0;c[2439192]=0;c[2415286]=0;b[4878516]=0;c[2385226]=h&255;c[3528194]=0;c[2415136]=0;j=59981}else{k=c[3528194]|0;l=a[704864+(k+(c[2385226]|0)&255)|0]^h&255;c[3528194]=k+1&15;if((i|0)==1){c[2415136]=2;k=l&255;c[2440740]=k>>>4;b[4878516]=k<<8&3840;j=59981;break}else if((i|0)==0){c[2415136]=1;k=l&255;c[2415286]=k&240;c[2439192]=(k&15)+1;j=59981;break}else if((i|0)==3){k=l&255;L70624:do{if((l&255)<17){m=(k|256)&65535}else{if((l&255)<34){m=k+271&65535;break}if((l&255)<51){m=k+286&65535;break}if((l&255)<68){m=k+333&65535;break}switch(l<<24>>24){case-32:{m=-32768;break L70624;break};case-28:{m=-32640;break L70624;break};case-48:{m=512;break L70624;break};case-31:{m=-32736;break L70624;break};case-30:{m=-32704;break L70624;break};case-29:{m=-32672;break L70624;break};default:{m=272;break L70624}}}}while(0);k=e[4878516]|0;n=(c[3528800]|0)+1|0;o=0;p=0;while(1){if((o|0)>=16){break}q=((1<<o&k|0)!=0)+p|0;if((q|0)==(n|0)){j=59977;break}else{o=o+1|0;p=q}}do{if((j|0)==59977){if((o|0)==-1){break}b[9734408+((c[2439294]|0)*20|0)+(o<<1)>>1]=m}}while(0);c[3528800]=n;o=(c[2440740]|0)-1|0;c[2440740]=o;if((o|0)!=0){j=59981;break}c[2415136]=1;o=(c[2439294]|0)+1|0;c[2439294]=o;c[3528800]=0;b[4878516]=0;if((o|0)==(c[2439192]|0)){r=1;break}else{j=59981;break}}else if((i|0)==2){c[2415136]=3;b[4878516]=b[4878516]|l&255;if((c[2440740]|0)!=0){j=59981;break}c[2415136]=1;o=(c[2439294]|0)+1|0;c[2439294]=o;c[3528800]=0;b[4878516]=0;if((o|0)==(c[2439192]|0)){r=1;break}else{j=59981;break}}else{j=59981;break}}}while(0);if((j|0)==59981){r=0}if(g){c[3528628]=1;c[2429448]=13762560;return}if((r|0)==0){c[2429448]=13762560;c[3528628]=f+1;return}else{c[3528628]=0;c[2429448]=c[2439192]|6488064;return}break};case 19:{f=c[2385612]|0;do{if((f|0)==0){c[2429448]=(c[2415286]>>4)+1|2949120;s=1}else{if((f|0)<((c[2439192]|0)*10|0|1|0)){c[2429448]=e[9734408+(f-1<<1)>>1]|0|2949120;s=f+1|0;break}else{c[2385612]=0;c[2429448]=7602260;s=1;break}}}while(0);c[2385612]=s;return};case 56:{c[2429448]=(d[14163495]|0)<<8|7864320;b[4873544]=256;return};case 71:{c[2439276]=e[4861048]|0;c[2429448]=7602247;return};case 82:{s=c[2439276]|0;f=(s>>>8&15)*25|0;r=b[4861048]|0;if(r<<16>>16==0){t=f}else{t=f+((s&15)*5|0)|0}c[2429448]=t+(r&15)&65535|7602176;return};case 97:{c[2429296]=1;c[2429448]=3538944;c[2432824]=12;return};case 65:{c[2429296]=0;c[2429448]=7602273;return};case 84:{c[2429296]=2;c[2415136]=-1;c[3528628]=0;c[2385612]=0;c[2429448]=3538944;gGz(9734408,0,160);return};case 99:{r=(fa(c[c[642608+(c[2436]<<2)>>2]>>2]|0,451328)|0)==0;t=b[4861048]&7;if(r){c[2429448]=c[592064+(t<<2)>>2];return}else{c[2429448]=c[592096+(t<<2)>>2];return}break};case 103:{t=(fa(c[c[642608+(c[2436]<<2)>>2]>>2]|0,451328)|0)==0;r=b[4861048]&7;if(t){c[2429448]=c[592e3+(r<<2)>>2];return}else{c[2429448]=c[592032+(r<<2)>>2];return}break};default:{c[2429448]=7602176;return}}}function dfX(){var a=0,b=0,d=0,e=0,f=0;a=c[c[642608+(c[2436]<<2)>>2]>>2]|0;if((fa(a|0,545480)|0)==0){c[2426974]=6}if((fa(a|0,424184)|0)==0){c[2426974]=6}if((fa(a|0,329208)|0)==0){c[2426974]=5}if((fa(a|0,250712)|0)==0){c[2426974]=1}c[2112950]=3688;c[2112952]=9856;if((c[2394]|0)==0){b=c[2112932]|0;d=c[3532592]|0}else{c[2394]=0;a=c[3532596]|0;c[2112932]=a;e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060];b=a;d=e}c[b+55296>>2]=4;c[b+120832>>2]=4;c[b+196704>>2]=312;c[b+196744>>2]=282;if((d|0)==0){f=c[2113054]|0;c[2113060]=f;c[2394]=-1;return}gGC(d|0,9104152,280)|0;f=c[2113054]|0;c[2113060]=f;c[2394]=-1;return}function dfY(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;b=i;i=i+80|0;d=b|0;e=b+16|0;f=b+32|0;g=b+48|0;h=b+64|0;if((a&64|0)==0){i=b;return 0}gGz(h|0,0,12);c[h>>2]=9721848;c[h+4>>2]=2;c[h+12>>2]=511024;gj[c[2076592]&4095](h)|0;gGz(g|0,0,12);c[g>>2]=9721856;c[g+4>>2]=2;c[g+12>>2]=498336;gj[c[2076592]&4095](g)|0;gGz(f|0,0,12);c[f>>2]=9707976;c[f+4>>2]=2;c[f+12>>2]=486480;gj[c[2076592]&4095](f)|0;gGz(e|0,0,12);c[e>>2]=9776672;c[e+4>>2]=2;c[e+12>>2]=473712;gj[c[2076592]&4095](e)|0;gGz(d|0,0,12);c[d>>2]=9776680;c[d+4>>2]=2;c[d+12>>2]=462304;gj[c[2076592]&4095](d)|0;i=b;return 0}function dfZ(){b[4860924]=0;b[4860928]=0;b[4853988]=0;b[4888336]=0;b[4888340]=0;return}function df_(d){d=d|0;var f=0,g=0,h=0,i=0,j=0;d=e[4888340]|0;if((d|0)==64){f=(b[4853988]|0)+1&65535;g=(f&65535)>235?0:f;b[4853988]=g;f=g&65535;g=a[1103440+((c[2426974]|0)*236|0)+f|0]|0;h=b[4860928]|0;if((f&1|0)==0){i=h&-256|g&255}else{i=h&255|(g&255)<<8}b[4860928]=i;j=0;return j|0}else if((d|0)==5){d=e[4888336]|0;if((d|0)==4){j=((c[2426974]|0)>>>24|16128)&65535;return j|0}else if((d|0)==1){j=(c[2426974]&255|16128)&65535;return j|0}else if((d|0)==2){j=((c[2426974]|0)>>>8&255|16128)&65535;return j|0}else if((d|0)==3){j=((c[2426974]|0)>>>16&255|16128)&65535;return j|0}else{d=b[4860924]|0;j=(d&65535)>>>15|(d&65535)>>>2<<6&64|(d&65535)>>>5<<7&128|(d&65535)>>>9<<5&32|(d&65535)>>>7<<4&16|(d&65535)>>>10<<3&8|(d&65535)>>>13<<2&4|(d&65535)>>>12<<1&2|16128;return j|0}}else{j=0;return j|0}return 0}function df$(a,c){a=a|0;c=c|0;var d=0,f=0;if((a&2|0)==0){b[4888340]=c;return}a=e[4888340]|0;if((a-32|0)>>>0>=8){return}b[4888336]=(b[4888336]|0)+1&65535;d=b[4860924]|0;f=d&65535;b[4860924]=(((d<<1|(d&65535)>>>15)^11181)&65535^16^(f>>>7^(c&255)>>>((a&15)>>>0))&1^(e[4860928]|0)<<1&63470^(f>>>13<<4&16|f>>>3<<11&2048))&65535;return}function df0(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;a=i;i=i+240|0;b=a|0;d=a+112|0;e=a+120|0;f=a+232|0;c[2112950]=10286;c[2112952]=9632;g=c[3540910]|0;c[2438904]=g;h=c[642608+(c[2436]<<2)>>2]|0;j=g+65536|0;do{if((fa(c[h>>2]|0,196368)|0)==0){if((c[3542200]|0)==0){break}g=b+108|0;c[g>>2]=0;k=b+100|0;c[k>>2]=0;l=c[h+76>>2]|0;gA[l&16383](b,15)|0;if((c[g>>2]|0)==0){break}g=c[k>>2]|0;c[d>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](d,15,0)|0;if((g|0)<1){break}gzL(j,0,15)|0}else{if((c[3542200]|0)==0){break}g=e+108|0;c[g>>2]=0;k=e+100|0;c[k>>2]=0;l=c[h+76>>2]|0;gA[l&16383](e,19)|0;if((c[g>>2]|0)==0){break}g=c[k>>2]|0;c[f>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](f,19,0)|0;if((g|0)<1){break}gzL(j,0,19)|0}}while(0);if((c[2394]|0)==0){m=c[2112932]|0;n=c[3532592]|0}else{c[2394]=0;j=c[3532596]|0;c[2112932]=j;f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];m=j;n=f}f=c[3540910]|0;c[m+16384>>2]=f;c[m+81920>>2]=f;c[m+147456>>2]=f;j=f+1024|0;c[m+16388>>2]=j;c[m+81924>>2]=j;c[m+147460>>2]=j;j=f+2048|0;c[m+16392>>2]=j;c[m+81928>>2]=j;c[m+147464>>2]=j;j=f+3072|0;c[m+16396>>2]=j;c[m+81932>>2]=j;c[m+147468>>2]=j;j=f+4096|0;c[m+16400>>2]=j;c[m+81936>>2]=j;c[m+147472>>2]=j;j=f+5120|0;c[m+16404>>2]=j;c[m+81940>>2]=j;c[m+147476>>2]=j;j=f+6144|0;c[m+16408>>2]=j;c[m+81944>>2]=j;c[m+147480>>2]=j;j=f+7168|0;c[m+16412>>2]=j;c[m+81948>>2]=j;c[m+147484>>2]=j;j=f+8192|0;c[m+16416>>2]=j;c[m+81952>>2]=j;c[m+147488>>2]=j;j=f+9216|0;c[m+16420>>2]=j;c[m+81956>>2]=j;c[m+147492>>2]=j;j=f+10240|0;c[m+16424>>2]=j;c[m+81960>>2]=j;c[m+147496>>2]=j;j=f+11264|0;c[m+16428>>2]=j;c[m+81964>>2]=j;c[m+147500>>2]=j;j=f+12288|0;c[m+16432>>2]=j;c[m+81968>>2]=j;c[m+147504>>2]=j;j=f+13312|0;c[m+16436>>2]=j;c[m+81972>>2]=j;c[m+147508>>2]=j;j=f+14336|0;c[m+16440>>2]=j;c[m+81976>>2]=j;c[m+147512>>2]=j;j=f+15360|0;c[m+16444>>2]=j;c[m+81980>>2]=j;c[m+147516>>2]=j;c[m+56500>>2]=4;c[m+122036>>2]=4;c[m+196704>>2]=1062;c[m+196744>>2]=2872;if((n|0)==0){o=c[2113054]|0;c[2113060]=o;c[2394]=-1;i=a;return}gGC(n|0,9104152,280)|0;o=c[2113054]|0;c[2113060]=o;c[2394]=-1;i=a;return}function df1(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;i=i+144|0;d=b|0;e=b+16|0;f=b+32|0;g=b+48|0;h=b+64|0;j=b+80|0;k=b+96|0;l=b+112|0;m=b+128|0;if((a&32|0)!=0){c[m>>2]=c[3540910];c[m+4>>2]=16384;c[m+8>>2]=4194304;c[m+12>>2]=156232;n=c[2076592]|0;gj[n&4095](m)|0}if((a&64|0)==0){i=b;return 0}gGz(l|0,0,12);c[l>>2]=9731640;c[l+4>>2]=2;c[l+12>>2]=125960;gj[c[2076592]&4095](l)|0;gGz(k|0,0,12);c[k>>2]=9731648;c[k+4>>2]=2;c[k+12>>2]=101432;gj[c[2076592]&4095](k)|0;gGz(j|0,0,12);c[j>>2]=9708136;c[j+4>>2]=2;c[j+12>>2]=78304;gj[c[2076592]&4095](j)|0;gGz(h|0,0,12);c[h>>2]=14114304;c[h+4>>2]=4;c[h+12>>2]=585248;gj[c[2076592]&4095](h)|0;gGz(g|0,0,12);c[g>>2]=14114288;c[g+4>>2]=4;c[g+12>>2]=568768;gj[c[2076592]&4095](g)|0;gGz(f|0,0,12);c[f>>2]=14114296;c[f+4>>2]=4;c[f+12>>2]=552496;gj[c[2076592]&4095](f)|0;gGz(e|0,0,12);c[e>>2]=9542272;c[e+4>>2]=2;c[e+12>>2]=538024;gj[c[2076592]&4095](e)|0;gGz(d|0,0,12);c[d>>2]=9776656;c[d+4>>2]=2;c[d+12>>2]=524672;gj[c[2076592]&4095](d)|0;i=b;return 0}function df2(){var a=0;a=c[2438904]|0;b[a+4096>>1]=18249;b[a+4098>>1]=11859;b[a+4100>>1]=14386;b[a+12388>>1]=-19691;b[a+10756>>1]=2;b[a+10946>>1]=1;b[a+11782>>1]=9;b[a+11786>>1]=6;b[4865820]=0;b[4865824]=0;b[4854068]=0;c[3528576]=0;c[3528572]=0;c[3528574]=0;b[4771136]=0;b[4888328]=0;return}function df3(e){e=e|0;var f=0,g=0,h=0,i=0;if((e&2|0)==0){f=0;return f|0}switch(c[3528576]|0){case 3:{f=b[4888328]|0;return f|0};case 2:{f=b[4771136]|128;return f|0};case 1:{f=c[3528572]&127;return f|0};case 64:{e=(b[4854068]|0)+1&65535;g=(e&65535)>235?0:e;b[4854068]=g;e=g&65535;g=a[1449104+(((d[14163495]|0)-1|0)*236|0)+e|0]|0;h=b[4865824]|0;if((e&1|0)==0){i=h&-256|g&255}else{i=h&255|(g&255)<<8}b[4865824]=i;f=0;return f|0};case 5:{i=c[3528574]|0;if((i|0)==3){f=16272;return f|0}else if((i|0)==1){f=d[14163495]|0|16128;return f|0}else if((i|0)==2|(i|0)==4){f=16128;return f|0}else{i=b[4865820]|0;f=(i&65535)>>>15|(i&65535)>>>2<<6&64|(i&65535)>>>5<<7&128|(i&65535)>>>9<<5&32|(i&65535)>>>7<<4&16|(i&65535)>>>10<<3&8|(i&65535)>>>13<<2&4|(i&65535)>>>12<<1&2|16128;return f|0}break};default:{f=0;return f|0}}return 0}function df4(a,f){a=a|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;if((a&2|0)==0){c[3528576]=f&65535;return}a=c[3528576]|0;switch(a|0){case 0:{c[3528572]=f&65535;return};case 2:{b[4771136]=f<<6&192|f<<3&32|f<<1&16;return};case 3:{g=c[2438904]|0;h=e[g+12326>>1]|0;L70834:do{if((h|0)==18){i=b[g+12350>>1]|0;j=b[g+12450>>1]&8191;k=c[3540910]|0;l=k+65536|0;m=i&15;switch(m&65535|0){case 0:case 1:case 2:case 5:case 6:{break};default:{break L70834}}n=j&65535;if(j<<16>>16==0){break}j=(e[g+12394>>1]|0)>>>1&65535;o=(i&65535)>>>8&65535;i=m<<16>>16==0;p=m<<16>>16==1;q=b[g+12420>>1]&8191;r=m<<16>>16==2;s=m<<16>>16==6;t=0;do{u=(t<<1)+o&255;v=(d[k+(u+65793)|0]|0)<<8|(d[k+(u|65792)|0]|0);u=i?20085:b[l+(t+j<<1)>>1]|0;do{if(p){w=u<<12|(u&65535)>>>12|(u&65535)>>>4&240|u<<4&3840}else{x=((r?v:0)^u)+(s?v:0)&65535;if(!((m<<16>>16|0)==6|(m<<16>>16|0)==2)){w=x;break}w=ga(x|0)|0}}while(0);b[g+(t+q<<1)>>1]=ga(w|0)|0;t=t+1|0;}while((t|0)<(n|0))}else if((h|0)==100){n=b[g+12368>>1]|0;t=b[g+12418>>1]|0;q=b[g+12372>>1]|0;m=b[g+12424>>1]|0;if(t<<16>>16==2){s=n&65535;switch(s&255|0){case 0:case 5:case 10:{y=(s>>>8<<2)+4205056|0;break};case 2:case 8:{y=(s>>>8<<2)+4206080|0;break};case 3:{y=4206736;break};case 4:{y=4206746;break};case 6:{y=4206756;break};case 7:{y=4206592;break};case 9:{y=4206702;break};case 1:{y=4206718;break};default:{y=0}}s=(y-4194304|0)>>>1;df5(n,((e[g+(s<<1)>>1]|0)<<16|(e[g+(s+1<<1)>>1]|0))+65536|0)}switch(m&65535|0){case 14:{m=q&65535;switch(m&255|0){case 2:case 8:{z=(m>>>8<<2)+4206080|0;break};case 0:case 5:case 10:{z=(m>>>8<<2)+4205056|0;break};case 7:{z=4206592;break};case 9:{z=4206702;break};case 1:{z=4206718;break};case 3:{z=4206736;break};case 4:{z=4206746;break};case 6:{z=4206756;break};default:{z=0}}m=(z-4194304|0)>>>1;df5(q,((e[g+(m<<1)>>1]|0)<<16|(e[g+(m+1<<1)>>1]|0))+65536|0);break L70834;break};case 6:{m=t&65535;switch(m&255|0){case 0:case 5:case 10:{A=(m>>>8<<2)+4205056|0;break};case 2:case 8:{A=(m>>>8<<2)+4206080|0;break};case 3:{A=4206736;break};case 4:{A=4206746;break};case 6:{A=4206756;break};case 7:{A=4206592;break};case 9:{A=4206702;break};case 1:{A=4206718;break};default:{A=0}}m=(A-4194304|0)>>>1;s=n&65535;switch(s&255|0){case 0:case 5:case 10:{B=(s>>>8<<2)+4205056|0;break};case 2:case 8:{B=(s>>>8<<2)+4206080|0;break};case 3:{B=4206736;break};case 4:{B=4206746;break};case 6:{B=4206756;break};case 7:{B=4206592;break};case 9:{B=4206702;break};case 1:{B=4206718;break};default:{B=0}}s=(B-4194304|0)>>>1;df5(q,((e[g+(s<<1)>>1]|0)<<16|(e[g+(s+1<<1)>>1]|0))&((e[g+(m<<1)>>1]|0)<<16|(e[g+(m+1<<1)>>1]|0)));break L70834;break};case 2:{m=t&65535;switch(m&255|0){case 7:{C=4206592;break};case 9:{C=4206702;break};case 1:{C=4206718;break};case 2:case 8:{C=(m>>>8<<2)+4206080|0;break};case 0:case 5:case 10:{C=(m>>>8<<2)+4205056|0;break};case 3:{C=4206736;break};case 4:{C=4206746;break};case 6:{C=4206756;break};default:{C=0}}m=(C-4194304|0)>>>1;s=q&65535;switch(s&255|0){case 0:case 5:case 10:{D=(s>>>8<<2)+4205056|0;break};case 2:case 8:{D=(s>>>8<<2)+4206080|0;break};case 3:{D=4206736;break};case 4:{D=4206746;break};case 6:{D=4206756;break};case 7:{D=4206592;break};case 9:{D=4206702;break};case 1:{D=4206718;break};default:{D=0}}s=(D-4194304|0)>>>1;df5(n,((e[g+(s<<1)>>1]|0)<<16|(e[g+(s+1<<1)>>1]|0))+((e[g+(m<<1)>>1]|0)<<16|(e[g+(m+1<<1)>>1]|0))|0);break L70834;break};case 13:{m=q&65535;switch(m&255|0){case 0:case 5:case 10:{E=(m>>>8<<2)+4205056|0;break};case 2:case 8:{E=(m>>>8<<2)+4206080|0;break};case 3:{E=4206736;break};case 4:{E=4206746;break};case 6:{E=4206756;break};case 7:{E=4206592;break};case 9:{E=4206702;break};case 1:{E=4206718;break};default:{E=0}}m=(E-4194304|0)>>>1;df5(n,(e[g+(m<<1)>>1]|0)<<16|(e[g+(m+1<<1)>>1]|0));break L70834;break};case 0:{m=t&65535;switch(m&255|0){case 0:case 5:case 10:{F=(m>>>8<<2)+4205056|0;break};case 2:case 8:{F=(m>>>8<<2)+4206080|0;break};case 3:{F=4206736;break};case 4:{F=4206746;break};case 6:{F=4206756;break};case 7:{F=4206592;break};case 9:{F=4206702;break};case 1:{F=4206718;break};default:{F=0}}m=(F-4194304|0)>>>1;s=n&65535;switch(s&255|0){case 2:case 8:{G=(s>>>8<<2)+4206080|0;break};case 0:case 5:case 10:{G=(s>>>8<<2)+4205056|0;break};case 7:{G=4206592;break};case 9:{G=4206702;break};case 3:{G=4206736;break};case 1:{G=4206718;break};case 4:{G=4206746;break};case 6:{G=4206756;break};default:{G=0}}s=(G-4194304|0)>>>1;df5(q,((e[g+(s<<1)>>1]|0)<<16|(e[g+(s+1<<1)>>1]|0))^((e[g+(m<<1)>>1]|0)<<16|(e[g+(m+1<<1)>>1]|0)));break L70834;break};case 1:{m=n&65535;switch(m&255|0){case 0:case 5:case 10:{H=(m>>>8<<2)+4205056|0;break};case 2:case 8:{H=(m>>>8<<2)+4206080|0;break};case 3:{H=4206736;break};case 4:{H=4206746;break};case 6:{H=4206756;break};case 7:{H=4206592;break};case 9:{H=4206702;break};case 1:{H=4206718;break};default:{H=0}}m=(H-4194304|0)>>>1;df5(t,((e[g+(m<<1)>>1]|0)<<16|(e[g+(m+1<<1)>>1]|0))+65536|0);break L70834;break};case 7:{m=n&65535;switch(m&255|0){case 0:case 5:case 10:{I=(m>>>8<<2)+4205056|0;break};case 2:case 8:{I=(m>>>8<<2)+4206080|0;break};case 3:{I=4206736;break};case 4:{I=4206746;break};case 6:{I=4206756;break};case 7:{I=4206592;break};case 9:{I=4206702;break};case 1:{I=4206718;break};default:{I=0}}m=(I-4194304|0)>>>1;df5(q,(e[g+(m<<1)>>1]|0)<<16|(e[g+(m+1<<1)>>1]|0));break L70834;break};default:{break L70834}}}}while(0);b[4888328]=((f&65535)>>>4)+1&3;return};case 4:{c[3528574]=f&65535;return};case 32:case 33:case 34:case 35:case 36:case 37:case 38:case 39:{c[3528574]=(c[3528574]|0)+1;g=b[4865820]|0;I=g&65535;b[4865820]=(((g<<1|(g&65535)>>>15)^11181)&65535^16^(I>>>7^(f&255)>>>((a&15)>>>0))&1^(e[4865824]|0)<<1&63470^(I>>>13<<4&16|I>>>3<<11&2048))&65535;return};default:{return}}}function df5(a,d){a=a|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;e=d>>>16&65535;f=a&65535;a=f&255;switch(a|0){case 6:{g=c[2438904]|0;b[g+12452>>1]=e;h=d&65535;i=g;j=60276;break};case 7:{g=c[2438904]|0;b[g+12288>>1]=e;k=d&65535;l=g;j=60277;break};case 2:case 8:{m=(f>>>8<<2)+4206080|0;j=60271;break};case 4:{g=c[2438904]|0;b[g+12442>>1]=e;n=d&65535;o=g;j=60275;break};case 0:case 5:case 10:{m=(f>>>8<<2)+4205056|0;j=60271;break};case 1:{g=c[2438904]|0;b[g+12414>>1]=e;p=4206718;q=d&65535;r=g;break};case 9:{g=c[2438904]|0;b[g+12398>>1]=e;s=d&65535;t=g;j=60278;break};case 3:{g=c[2438904]|0;b[g+12432>>1]=e;u=d&65535;v=g;j=60274;break};default:{m=0;j=60271}}L70984:do{if((j|0)==60271){g=c[2438904]|0;b[g+((m-4194304|0)>>>1<<1)>>1]=e;w=d&65535;switch(a|0){case 7:{k=w;l=g;j=60277;break L70984;break};case 9:{s=w;t=g;j=60278;break L70984;break};case 3:{u=w;v=g;j=60274;break L70984;break};case 4:{n=w;o=g;j=60275;break L70984;break};case 6:{h=w;i=g;j=60276;break L70984;break};case 1:{p=4206718;q=w;r=g;break L70984;break};case 0:case 5:case 10:{p=(f>>>8<<2)+4205056|0;q=w;r=g;break L70984;break};case 2:case 8:{p=(f>>>8<<2)+4206080|0;q=w;r=g;break L70984;break};default:{p=0;q=w;r=g;break L70984}}}}while(0);if((j|0)==60277){p=4206592;q=k;r=l}else if((j|0)==60278){p=4206702;q=s;r=t}else if((j|0)==60274){p=4206736;q=u;r=v}else if((j|0)==60275){p=4206746;q=n;r=o}else if((j|0)==60276){p=4206756;q=h;r=i}b[r+(((p-4194304|0)>>>1)+1<<1)>>1]=q;return}function df6(b){b=b|0;var c=0,d=0,e=0;if((b|0)==12582919){c=a[9635888]|0;d=(c&a[9658128])<<24>>24!=0|0;a[9635888]=c<<1;e=d;return e|0}else if((b|0)==12615687){e=(a[14163494]|-32)^31;return e|0}else{e=0;return e|0}return 0}function df7(c){c=c|0;var e=0,f=0,g=0;if((c|0)==12615684){e=~((d[14163493]|0)<<8|(d[14163492]|0));return e|0}else if((c|0)==12615686){e=(d[14163494]|0|-32)^31;return e|0}else if((c|0)==12582918){f=a[9635888]|0;g=(f&a[9658128])<<24>>24!=0;a[9635888]=f<<1;e=g&1;return e|0}else if((c|0)==12615682){e=~((d[14163491]|0)<<8|(d[14163490]|0));return e|0}else if((c|0)==12582916){a[9747065]=1;e=b[4887737]|0;return e|0}else if((c|0)==12615680){e=~((d[14163489]|0)<<8|(d[14163488]|0));return e|0}else{e=0;return e|0}return 0}function df8(a,b){a=a|0;b=b|0;return}function df9(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;i=i+8|0;g=f|0;switch(d|0){case 12582918:{c[g>>2]=gb(0)|0;d=a5(g|0)|0;h=a[9658136]<<1|e&1;a[9658136]=h;j=(a[9658144]|0)+1&255;a[9658144]=j;if(j<<24>>24!=4){i=f;return}a[9635888]=1;a[9658128]=1;a[9658144]=0;switch(h&15|0){case 15:{a5(g|0)|0;i=f;return};case 1:case 3:case 5:case 7:case 9:case 11:case 13:{a[9658128]=2;i=f;return};case 2:{g=c[d+8>>2]&255;a[9658128]=((g&255)/10|0)<<4|((g&255)%10|0);i=f;return};case 4:{g=c[d>>2]&255;a[9658128]=((g&255)/10|0)<<4|((g&255)%10|0);i=f;return};case 6:{g=(c[d+16>>2]|0)+1&255;a[9658128]=((g&255)/10|0)<<4|((g&255)%10|0);i=f;return};case 0:{g=c[d+24>>2]&255;a[9658128]=((g&255)/10|0)<<4|((g&255)%10|0);i=f;return};case 8:{a[9658128]=0;i=f;return};case 10:{g=c[d+12>>2]&255;a[9658128]=((g&255)/10|0)<<4|((g&255)%10|0);i=f;return};case 14:{g=((c[d+20>>2]|0)%100|0)&255;a[9658128]=((g&255)/10|0)<<4|((g&255)%10|0);i=f;return};case 12:{g=c[d+4>>2]&255;a[9658128]=((g&255)/10|0)<<4|((g&255)%10|0);i=f;return};default:{i=f;return}}break};case 12582924:{b[4887738]=e;a[9747066]=0;i=f;return};case 12582916:{b[4887737]=e;a[9747065]=0;i=f;return};case 12582914:{b[4887736]=e;a[9747064]=0;if((a[9775568]|0)==0){i=f;return}if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12;i=f;return};case 12582920:{if(e<<16>>16==20560){UW();a[9775568]=1;gGz(9706056,0,76);i=f;return}else{a[9775568]=0;i=f;return}break};default:{i=f;return}}}function dga(a){a=a|0;var b=0;b=a&65535;a=c[2411354]|0;return(d[a+b|0]|0)<<8|(d[a+(b+1)|0]|0)|0}function dgb(b,d){b=b|0;d=d|0;var e=0;e=b&65535;b=c[2411354]|0;a[b+e|0]=(d&65535)>>>8&255;a[b+(e+1)|0]=d&255;return}function dgc(a,d){a=a|0;d=d|0;var e=0;e=(a-10485760|0)>>>1;b[(c[3540926]|0)+(e<<1)>>1]=d;a=d&65535;d=a>>>2&248;c[(c[3532644]|0)+(e<<2)>>2]=a>>>7<<8&63488|a&31|(d>>>5|d)<<3&2016;return}function dgd(b,d){b=b|0;d=d|0;var f=0;f=b-10485760|0;b=c[3540926]|0;a[b+(f^1)|0]=d;d=f>>>1;f=e[b+(d<<1)>>1]|0;b=f>>>2&248;c[(c[3532644]|0)+(d<<2)>>2]=f>>>7<<8&63488|f&31|(b>>>5|b)<<3&2016;return}function dge(d){d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=(d&65535)>>>8;if((e|0)==129){a[9747066]=1;f=b[4887738]&255;return f|0}else if((e|0)==128){g=d&255;if((g|0)==2){f=(UU(a[(c[2420426]|0)+1236|0]|0)|0)&255;return f|0}else if((g|0)==0){d=c[2420426]|0;if((c[d+1240>>2]|0)==0){f=0;return f|0}h=(a[d+1238|0]&3&a[d+1239|0])<<24>>24==0?-128:-127;i=0;while(1){if((i|0)>=32){f=h;j=60366;break}if((a[d+516+(i*22|0)+21|0]&2)==0){i=i+1|0}else{break}}if((j|0)==60366){return f|0}f=h|2;return f|0}else if((g|0)==1){f=a[(c[2420426]|0)+1236|0]|0;return f|0}else{f=((UU(a[(c[2420426]|0)+1236|0]|0)|0)&65535)>>>8&255;return f|0}}else if((e|0)==130){a[9747064]=1;f=b[4887736]&255;return f|0}else if((e|0)==132){a[9747065]=1;f=b[4887737]&255;return f|0}else{f=0;return f|0}return 0}function dgf(d,e){d=d|0;e=e|0;var f=0;f=(d&65535)>>>8;if((f|0)==129){b[4887738]=e&255;a[9747066]=0;return}else if((f|0)==130){b[4887736]=e&255;a[9747064]=0;return}else if((f|0)==132){b[4887737]=e&255;a[9747065]=0;return}else if((f|0)==128){f=d&255;if((f|0)==2){UV(a[(c[2420426]|0)+1236|0]|0,e,0);return}else if((f|0)==1){a[(c[2420426]|0)+1236|0]=e;return}else if((f|0)==3){UV(a[(c[2420426]|0)+1236|0]|0,e,1);return}else{return}}else{return}}function dgg(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;i=i+120|0;e=b|0;f=b+112|0;g=d[14163496]|0;do{if((c[631004]|0)!=(g|0)){h=c[642608+(c[2436]<<2)>>2]|0;if((c[h+60>>2]&2|0)!=0){break}c[631004]=g;j=c[3540946]|0;k=g+130|0;if((c[3542200]|0)==0){break}l=e+108|0;c[l>>2]=0;m=e+100|0;c[m>>2]=0;n=c[h+76>>2]|0;gA[n&16383](e,k)|0;if((c[l>>2]|0)==0){break}l=c[m>>2]|0;c[f>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](f,k,0)|0;if((l|0)<1){break}gzL(j,0,k)|0}}while(0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060]}RI();f=c[2394]|0;e=c[14130368+(f<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(f<<2)>>2]=c[2113054];c[2394]=-1;if(a[7024728]|0){gGz(9698808,0,156);c[2424718]=211;c[2424717]=0}f=c[2439330]|0;e=(f|0)==0;if(!e){g=f;gGC(9706056,g|0,76)|0}g=c[2438118]|0;c[2433530]=g;k=c[3528484]|0;c[2076596]=k;j=c[2417276]|0;c[3541536]=j;c[1836236]=0;a[9775568]=0;gGz(9706056,0,76);if(!e){e=f;gGC(e|0,9706056,76)|0}c[2438118]=g;c[3528484]=k;c[2417276]=j;c[1836236]=-1;UW();j=c[2112952]|0;if((j|0)==0){i=b;return}gu[j&16383]();i=b;return}function dgh(){var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0;e=i;i=i+480|0;f=e|0;g=e+112|0;h=e+120|0;j=e+232|0;k=e+240|0;l=e+352|0;m=e+360|0;n=e+368|0;c[2424]=(c[(c[642608+(c[2436]<<2)>>2]|0)+60>>2]&2|0)!=0?5917:6e3;c[2426810]=0;dgi(0);o=((c[2113102]|0)/2|0)*3|0;p=1;while(1){if((p|0)<(o|0)){p=p<<1}else{break}}c[2113104]=p;o=c[2113098]|0;q=1;while(1){if((q|0)<(o|0)){q=q<<1}else{break}}c[2113100]=q-1;q=0;while(1){if((q|0)>=1024){r=0;break}s=9638528+(q<<2)|0;if((c[s>>2]|0)==0){t=60421;break}else{q=q+1|0}}do{if((t|0)==60421){q=gGq(p)|0;c[s>>2]=q;if((q|0)==0){r=0;break}gGz(q|0,0,p|0);r=q}}while(0);c[3540922]=r;c[2113104]=(c[2113104]|0)-1;r=c[2113102]|0;p=0;while(1){if((p|0)>=1024){break}u=9638528+(p<<2)|0;if((c[u>>2]|0)==0){t=60426;break}else{p=p+1|0}}L71164:do{if((t|0)==60426){p=gGq(r)|0;c[u>>2]=p;if((p|0)==0){break}gGz(p|0,0,r|0);if((gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](m,0,0)|0)==0){s=n+108|0;q=n+100|0;o=k+108|0;v=k+100|0;w=p;x=0;y=0;while(1){gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,y)|0;if((c[s>>2]&2097167|0)==2097155){if((c[q>>2]|0)==4194304){z=(x|0)==4194304&(c[2113102]|0)==33554432?w-2097152|0:w}else{z=w}do{if((c[3542200]|0)!=0){c[o>>2]=0;c[v>>2]=0;A=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[A&16383](k,y)|0;if((c[o>>2]|0)==0){break}A=c[v>>2]|0;c[l>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](l,y,0)|0;if((A|0)<1){break}gzL(z,0,y)|0}}while(0);A=c[q>>2]|0;C=A;D=z+A|0}else{C=x;D=w}A=y+1|0;if((gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](m,A,0)|0)==0){w=D;x=C;y=A}else{break}}}y=c[c[642608+(c[2436]<<2)>>2]>>2]|0;do{if((fa(y|0,538008)|0)==0){t=60444}else{if((fa(y|0,524656)|0)==0){t=60444;break}if((fa(y|0,511008)|0)==0){t=60444;break}if((fa(y|0,498328)|0)==0){t=60444;break}if((fa(y|0,486464)|0)==0){t=60444;break}if((fa(y|0,473704)|0)==0){t=60444}}}while(0);if((t|0)==60444){de$(p);de$(p+8388608|0);de$(p+16777216|0);de$(p+25165824|0);de$(p+33554432|0);de$(p+41943040|0)}y=c[2113102]|0;if((y|0)>1){x=c[3540922]|0;w=(y|0)/2|0;y=0;while(1){q=y<<1;v=a[p+q|0]|0;o=a[p+(q|1)|0]|0;q=y*3|0;a[x+q|0]=v&31;a[x+(q+1)|0]=(((o&255)<<8|v&255)&65535)>>>5&31;a[x+(q+2)|0]=(o&255)>>>2&31;o=y+1|0;if((o|0)<(w|0)){y=o}else{E=0;break}}}else{E=0}while(1){if((E|0)>=1024){break L71164}F=9638528+(E<<2)|0;if((c[F>>2]|0)==(p|0)){break}else{E=E+1|0}}gGr(p);c[F>>2]=0}}while(0);F=c[2113096]|0;E=0;while(1){if((E|0)>=1024){G=0;break}H=9638528+(E<<2)|0;if((c[H>>2]|0)==0){t=60454;break}else{E=E+1|0}}do{if((t|0)==60454){E=gGq(F)|0;c[H>>2]=E;if((E|0)==0){G=0;break}gGz(E|0,0,F|0);G=E}}while(0);c[3540916]=G;G=((c[2113096]|0)/5|0)<<3;F=0;while(1){if((F|0)>=1024){I=0;break}J=9638528+(F<<2)|0;if((c[J>>2]|0)==0){t=60459;break}else{F=F+1|0}}do{if((t|0)==60459){F=gGq(G)|0;c[J>>2]=F;if((F|0)==0){I=0;break}gGz(F|0,0,G|0);I=F}}while(0);c[3540914]=I;I=c[2113098]|0;G=0;while(1){if((G|0)>=1024){K=0;break}L=9638528+(G<<2)|0;if((c[L>>2]|0)==0){t=60464;break}else{G=G+1|0}}do{if((t|0)==60464){G=gGq(I)|0;c[L>>2]=G;if((G|0)==0){K=0;break}gGz(G|0,0,I|0);K=G}}while(0);c[3540920]=K;K=c[2113106]|0;I=0;while(1){if((I|0)>=1024){M=0;break}N=9638528+(I<<2)|0;if((c[N>>2]|0)==0){t=60469;break}else{I=I+1|0}}do{if((t|0)==60469){I=gGq(K)|0;c[N>>2]=I;if((I|0)==0){M=0;break}gGz(I|0,0,K|0);M=I}}while(0);c[3541280]=M;M=c[2426810]|0;c[3540946]=M;c[3540942]=M+524288;K=(c[2113112]|0)+524288|0;c[3540910]=M+K;N=K+(c[2113108]|0)|0;K=M+N|0;if((c[(c[642608+(c[2436]<<2)>>2]|0)+60>>2]&1|0)==0){c[2405716]=K;c[3540944]=K;c[2411354]=K+131072;O=K+196608|0}else{c[3540934]=K;K=M+(N+16384)|0;c[2405716]=K;c[3540944]=K;c[2411354]=K+131072;c[3540932]=K+196608;c[3540930]=K+327680;c[3540940]=K+458752;c[3540938]=K+462848;c[3540936]=K+724992;O=K+729088|0}c[3540928]=O;c[3540912]=O+4096;c[3540924]=O+12288;c[3540926]=O+16384;c[3540908]=O+21504;c[3540918]=O+87040;K=O+89600|0;c[2411824]=K;c[3532644]=K;K=O+98820|0;c[2414372]=K;O=K;K=0;while(1){if((K|0)>=1024){break}P=9638528+(K<<2)|0;if((c[P>>2]|0)==0){t=60477;break}else{K=K+1|0}}do{if((t|0)==60477){K=gGq(O)|0;c[P>>2]=K;if((K|0)==0){break}gGz(K|0,0,O|0);c[2426810]=K;gGz(K|0,0,O|0);c[3540946]=K;c[3540942]=K+524288;N=(c[2113112]|0)+524288|0;c[3540910]=K+N;M=N+(c[2113108]|0)|0;N=K+M|0;I=c[642608+(c[2436]<<2)>>2]|0;if((c[I+60>>2]&1|0)==0){c[2405716]=N;c[3540944]=N;c[2411354]=N+131072;Q=N+196608|0}else{c[3540934]=N;N=K+(M+16384)|0;c[2405716]=N;c[3540944]=N;c[2411354]=N+131072;c[3540932]=N+196608;c[3540930]=N+327680;c[3540940]=N+458752;c[3540938]=N+462848;c[3540936]=N+724992;Q=N+729088|0}c[3540928]=Q;c[3540912]=Q+4096;c[3540924]=Q+12288;c[3540926]=Q+16384;c[3540908]=Q+21504;c[3540918]=Q+87040;N=Q+89600|0;c[2411824]=N;c[3532644]=N;c[2414372]=Q+98820;N=c[3540916]|0;if((c[3542200]|0)==0){R=1;i=e;return R|0}M=h+108|0;c[M>>2]=0;K=h+100|0;c[K>>2]=0;L=c[I+76>>2]|0;gA[L&16383](h,128)|0;do{if((c[M>>2]|0)!=0){L=c[K>>2]|0;c[j>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](j,128,0)|0;if((L|0)<1){R=1;i=e;return R|0}if((gzL(N,0,128)|0)==0){break}else{R=1}i=e;return R|0}}while(0);N=c[3541280]|0;do{if((c[3542200]|0)!=0){K=f+108|0;c[K>>2]=0;M=f+100|0;c[M>>2]=0;p=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[p&16383](f,129)|0;if((c[K>>2]|0)==0){break}K=c[M>>2]|0;c[g>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](g,129,0)|0;if((K|0)<1){break}gzL(N,0,129)|0}}while(0);dgi(1);N=c[3540916]|0;K=c[3540914]|0;M=c[c[642608+(c[2436]<<2)>>2]>>2]|0;do{if((fa(M|0,538008)|0)==0){t=60496}else{if((fa(M|0,524656)|0)==0){t=60496;break}if((fa(M|0,511008)|0)==0){t=60496;break}if((fa(M|0,498328)|0)==0){t=60496;break}if((fa(M|0,486464)|0)==0){t=60496;break}if((fa(M|0,473704)|0)==0){t=60496}}}while(0);L71264:do{if((t|0)==60496){M=N+1572864|0;p=M;L=0;while(1){if((L|0)>=1024){S=0;break}T=9638528+(L<<2)|0;if((c[T>>2]|0)==0){t=60499;break}else{L=L+1|0}}do{if((t|0)==60499){L=gGq(8388608)|0;c[T>>2]=L;if((L|0)==0){S=0;break}gGz(L|0,0,8388608);S=L}}while(0);L=S;I=0;do{G=b[p+(I<<1)>>1]|0;b[L+((I<<17&131072|I&12845056|I>>>4&1|I>>>9<<21&2097152|I>>>8<<20&1048576|I>>>21<<19&524288|I>>>1<<16&65536|I>>>2<<15&32768|I>>>3<<14&16384|I>>>16<<13&8192|I>>>15<<12&4096|I>>>14<<11&2048|I>>>13<<10&1024|I>>>12<<9&512|I>>>11<<8&256|I>>>10<<7&128|I>>>19<<6&64|I>>>20<<5&32|I>>>17<<4&16|I>>>7<<3&8|I>>>6<<2&4|I>>>5<<1&2)<<1)>>1]=(G&65535)>>>1<<15|G&16416|G<<11&2048|(G&65535)>>>15<<10|(G&65535)>>>11&1|(G&65535)>>>8<<13&8192|(G&65535)>>>7<<12&4096|(G&65535)>>>6<<9&512|(G&65535)>>>9<<8&256|(G&65535)>>>13<<7&128|(G&65535)>>>2<<6&64|(G&65535)>>>10<<4&16|(G&65535)>>>12<<3&8|(G&65535)>>>3<<2&4|(G&65535)>>>4<<1&2;I=I+1|0;}while((I|0)<4194304);gGC(M|0,S|0,8388608)|0;I=0;while(1){if((I|0)>=1024){break L71264}U=9638528+(I<<2)|0;if((c[U>>2]|0)==(S|0)){break}else{I=I+1|0}}gGr(S);c[U>>2]=0}}while(0);I=c[2113096]|0;if((I|0)>4){M=(I|0)/5|0;do{M=M-1|0;I=M*5|0;L=N+I|0;p=M<<3;a[K+p|0]=a[L]&31;G=N+(I+1)|0;a[K+(p|1)|0]=a[G]<<3&24|(d[L]|0)>>>5;a[K+(p|2)|0]=(d[G]|0)>>>2&31;L=N+(I+2)|0;a[K+(p|3)|0]=a[L]<<1&30|(d[G]|0)>>>7;G=N+(I+3)|0;a[K+(p|4)|0]=a[G]<<4&16|(d[L]|0)>>>4;a[K+(p|5)|0]=(d[G]|0)>>>1&31;L=N+(I+4)|0;a[K+(p|6)|0]=a[L]<<2&28|(d[G]|0)>>>6;a[K+(p|7)|0]=(d[L]|0)>>>3;}while((M|0)>0)}M=c[3540916]|0;K=2097151;while(1){N=a[M+K|0]|0;L=K<<1;a[M+L|0]=N&15;a[M+(L|1)|0]=(N&255)>>>4;if((K|0)>0){K=K-1|0}else{break}}c[3540916]=gGs(M,4194304)|0;fxU(0,425984);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];K=c[3532592]|0;if((K|0)!=0){gGC(9104152,K|0,280)|0}c[2113054]=c[2113060]}do{if((c[(c[642608+(c[2436]<<2)>>2]|0)+60>>2]&2|0)==0){K=c[3540946]|0;N=c[2112932]|0;L=N|0;p=0;while(1){G=K+p|0;c[L>>2]=G;c[L+131072>>2]=G;G=p+1024|0;if(G>>>0>524287){break}else{L=L+4|0;p=G}}p=c[3540942]|0;L=(c[2113112]|0)+1048575|0;if(L>>>0<1048576){V=N;break}K=N+4096|0;G=1048576;while(1){I=p+(G-1048576)|0;c[K>>2]=I;c[K+131072>>2]=I;I=G+1024|0;if(I>>>0>L>>>0){V=N;break}else{K=K+4|0;G=I}}}else{G=c[3540942]|0;K=(c[2113112]|0)-1|0;N=c[2112932]|0;L=N|0;p=0;while(1){I=G+p|0;c[L>>2]=I;c[L+131072>>2]=I;I=p+1024|0;if(I>>>0>K>>>0){V=N;break}else{L=L+4|0;p=I}}}}while(0);M=c[3540944]|0;p=V+32768|0;L=8388608;while(1){N=M+(L-8388608)|0;c[p>>2]=N;c[p+65536>>2]=N;c[p+131072>>2]=N;N=L+1024|0;if(N>>>0>8519679){break}else{p=p+4|0;L=N}}L=V+33280|0;p=8519680;while(1){N=M+(p-8519680)|0;c[L>>2]=N;c[L+65536>>2]=N;c[L+131072>>2]=N;N=p+1024|0;if(N>>>0>8650751){break}else{L=L+4|0;p=N}}p=V+33792|0;L=8650752;while(1){N=M+(L-8650752)|0;c[p>>2]=N;c[p+65536>>2]=N;c[p+131072>>2]=N;N=L+1024|0;if(N>>>0>8781823){break}else{p=p+4|0;L=N}}L=V+34304|0;p=8781824;while(1){N=M+(p-8781824)|0;c[L>>2]=N;c[L+65536>>2]=N;c[L+131072>>2]=N;N=p+1024|0;if(N>>>0>8912895){break}else{L=L+4|0;p=N}}p=V+34816|0;L=8912896;while(1){N=M+(L-8912896)|0;c[p>>2]=N;c[p+65536>>2]=N;c[p+131072>>2]=N;N=L+1024|0;if(N>>>0>9043967){break}else{p=p+4|0;L=N}}L=V+35328|0;p=9043968;while(1){N=M+(p-9043968)|0;c[L>>2]=N;c[L+65536>>2]=N;c[L+131072>>2]=N;N=p+1024|0;if(N>>>0>9175039){break}else{L=L+4|0;p=N}}p=V+35840|0;L=9175040;while(1){N=M+(L-9175040)|0;c[p>>2]=N;c[p+65536>>2]=N;c[p+131072>>2]=N;N=L+1024|0;if(N>>>0>9306111){break}else{p=p+4|0;L=N}}L=V+36352|0;p=9306112;while(1){N=M+(p-9306112)|0;c[L>>2]=N;c[L+65536>>2]=N;c[L+131072>>2]=N;N=p+1024|0;if(N>>>0>9437183){break}else{L=L+4|0;p=N}}p=c[3540928]|0;L=c[3540912]|0;M=c[3540924]|0;N=0;do{K=N|9437184;G=N|9441279;if(K>>>0<=G>>>0){I=V+(K>>>10<<2)|0;J=K;while(1){F=p+(J-K)|0;c[I>>2]=F;c[I+65536>>2]=F;c[I+131072>>2]=F;F=J+1024|0;if(F>>>0>G>>>0){break}else{I=I+4|0;J=F}}}J=N|9441280;I=N|9445375;if(J>>>0<=I>>>0){G=V+(J>>>10<<2)|0;K=J;while(1){F=p+(K-J)|0;c[G>>2]=F;c[G+65536>>2]=F;c[G+131072>>2]=F;F=K+1024|0;if(F>>>0>I>>>0){break}else{G=G+4|0;K=F}}}K=N|9445376;G=N|9449471;if(K>>>0<=G>>>0){I=V+(K>>>10<<2)|0;J=K;while(1){F=p+(J-K)|0;c[I>>2]=F;c[I+65536>>2]=F;c[I+131072>>2]=F;F=J+1024|0;if(F>>>0>G>>>0){break}else{I=I+4|0;J=F}}}J=N|9449472;I=N|9457663;if(J>>>0<=I>>>0){G=V+(J>>>10<<2)|0;K=J;while(1){F=p+(K-J)|0;c[G>>2]=F;c[G+65536>>2]=F;c[G+131072>>2]=F;F=K+1024|0;if(F>>>0>I>>>0){break}else{G=G+4|0;K=F}}}K=N|9453568;G=N|9461759;if(K>>>0<=G>>>0){I=V+(K>>>10<<2)|0;J=K;while(1){F=L+(J-K)|0;c[I>>2]=F;c[I+65536>>2]=F;c[I+131072>>2]=F;F=J+1024|0;if(F>>>0>G>>>0){break}else{I=I+4|0;J=F}}}J=N|9461760;I=N|9465855;if(J>>>0<=I>>>0){G=V+(J>>>10<<2)|0;K=J;while(1){F=L+(K-J)|0;c[G>>2]=F;c[G+65536>>2]=F;c[G+131072>>2]=F;F=K+1024|0;if(F>>>0>I>>>0){break}else{G=G+4|0;K=F}}}K=N|9465856;G=N|9469951;if(K>>>0<=G>>>0){I=V+(K>>>10<<2)|0;J=K;while(1){F=M+(J-K)|0;c[I>>2]=F;c[I+65536>>2]=F;c[I+131072>>2]=F;F=J+1024|0;if(F>>>0>G>>>0){break}else{I=I+4|0;J=F}}}N=N+32768|0;}while((N|0)<1048576);N=c[3540926]|0;M=N;c[V+40960>>2]=M;c[V+172032>>2]=M;M=N+1024|0;c[V+40964>>2]=M;c[V+172036>>2]=M;M=N+2048|0;c[V+40968>>2]=M;c[V+172040>>2]=M;M=N+3072|0;c[V+40972>>2]=M;c[V+172044>>2]=M;M=N+4096|0;c[V+40976>>2]=M;c[V+172048>>2]=M;M=c[3540908]|0;N=V+45056|0;L=11534336;while(1){p=M+(L-11534336)|0;c[N>>2]=p;c[N+65536>>2]=p;c[N+131072>>2]=p;p=L+1024|0;if(p>>>0>11599871){break}else{N=N+4|0;L=p}}c[V+106496>>2]=1;c[V+106500>>2]=1;c[V+106504>>2]=1;c[V+106508>>2]=1;c[V+106512>>2]=1;L=V+49408|0;N=12648448;while(1){c[L>>2]=2;c[L+65536>>2]=2;M=N+1024|0;if(M>>>0>12713983){break}else{L=L+4|0;N=M}}c[V+196688>>2]=2938;c[V+196608>>2]=1016;c[V+196728>>2]=82;c[V+196648>>2]=1298;c[V+196652>>2]=732;c[V+196732>>2]=2016;c[V+196696>>2]=2558;c[V+196736>>2]=790;N=c[3532592]|0;if((N|0)!=0){gGC(N|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);N=c[2439330]|0;L=(N|0)==0;if(!L){M=N;gGC(9706056,M|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];M=c[3528484]|0;c[2076596]=M;p=c[2417276]|0;c[3541536]=p;c[1836236]=0;J=c[2411354]|0;I=0;G=0;while(1){c[N+76+(G<<2)>>2]=J+(G<<8);K=I+1&65535;if((K&65535)>255){W=0;X=0;break}else{I=K;G=K&65535}}while(1){c[N+76+(X+256<<2)>>2]=J+(X<<8);G=W+1&65535;if((G&65535)>255){Y=0;Z=0;break}else{W=G;X=G&65535}}while(1){G=J+(Z<<8)|0;c[N+76+(Z+512<<2)>>2]=G;c[N+76+(Z+768<<2)>>2]=G;G=Y+1&65535;if((G&65535)>255){break}else{Y=G;Z=G&65535}}c[N+4176>>2]=3094;c[N+4172>>2]=2906;if(!L){J=N;gGC(J|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=M;c[2417276]=p;c[1836236]=-1;J=c[642608+(c[2436]<<2)>>2]|0;if((c[J+60>>2]&1|0)!=0){a[7024728]=1}G=c[J+128>>2]|0;if((c[J+52>>2]&4|0)==0){c[2113068]=G;I=c[J+132>>2]|0;c[2113070]=I;c[2443814]=G;c[2440436]=I;_=G;$=I}else{c[2113070]=G;I=c[J+132>>2]|0;c[2113068]=I;c[2440436]=G;c[2443814]=I;_=I;$=G}G=ag(_<<1,$)|0;I=gGq(G)|0;c[2112926]=I;if((I|0)==0){aa=0}else{gGz(I|0,0,G|0);aa=0}while(1){if((aa|0)>=1024){ab=0;break}ac=9638528+(aa<<2)|0;if((c[ac>>2]|0)==0){t=60586;break}else{aa=aa+1|0}}do{if((t|0)==60586){p=gGq(1048576)|0;c[ac>>2]=p;if((p|0)==0){ab=0;break}gGz(p|0,0,1048576);ab=p}}while(0);c[2385352]=ab;p=ag(c[2113070]|0,c[2113068]|0)|0;M=0;while(1){if((M|0)>=1024){ad=0;break}ae=9638528+(M<<2)|0;if((c[ae>>2]|0)==0){t=60591;break}else{M=M+1|0}}do{if((t|0)==60591){M=gGq(p)|0;c[ae>>2]=M;if((M|0)==0){ad=0;break}gGz(M|0,0,p|0);ad=M}}while(0);c[3528926]=ad;p=ag(c[2113068]<<1,c[2113070]|0)|0;M=0;while(1){if((M|0)>=1024){af=0;break}ah=9638528+(M<<2)|0;if((c[ah>>2]|0)==0){t=60596;break}else{M=M+1|0}}do{if((t|0)==60596){M=gGq(p)|0;c[ah>>2]=M;if((M|0)==0){af=0;break}gGz(M|0,0,p|0);af=M}}while(0);c[2443760]=af;p=(((c[2113096]|0)/5|0)<<3|0)/1024|0;c[2385474]=p;M=0;while(1){if((M|0)>=1024){ai=0;break}aj=9638528+(M<<2)|0;if((c[aj>>2]|0)==0){t=60601;break}else{M=M+1|0}}do{if((t|0)==60601){M=gGq(p)|0;c[aj>>2]=M;if((M|0)==0){ai=0;break}gGz(M|0,0,p|0);ai=M}}while(0);c[2385206]=ai;p=c[2385474]|0;gGz(ai|0,0,p|0);M=p<<10;if((M|0)>0){p=c[3540914]|0;N=0;while(1){L=ai+((N|0)/1024|0)|0;G=31;I=0;do{J=I+N|0;if((a[p+J|0]|0)==31){ak=0}else{a[L]=1;ak=d[p+J|0]^31}G=ak&G;I=I+1|0;}while((I|0)<1024);if((G|0)!=0){a[L]=a[L]|2}I=N+1024|0;if((I|0)<(M|0)){N=I}else{al=0;break}}}else{al=0}while(1){if((al|0)>=1024){am=0;break}an=9638528+(al<<2)|0;if((c[an>>2]|0)==0){t=60614;break}else{al=al+1|0}}do{if((t|0)==60614){N=gGq(65536)|0;c[an>>2]=N;if((N|0)==0){am=0;break}gGz(N|0,0,65536);am=N}}while(0);c[2385220]=am;gGz(am|0,0,65536);N=c[3540916]|0;M=0;do{p=am+((M|0)/64|0)|0;I=15;J=0;do{K=J+M|0;if((a[N+K|0]|0)==15){ao=0}else{a[p]=1;ao=d[N+K|0]^15}I=ao&I;J=J+1|0;}while((J|0)<64);if((I|0)!=0){a[p]=a[p]|2}M=M+64|0;}while((M|0)<4194304);gGz(9540928,0,256);M=0;while(1){N=9540928+M|0;if((M&1|0)!=0){a[N]=(a[N]|0)+1&255}if((M&2|0)!=0){a[N]=(a[N]|0)+1&255}if((M&4|0)!=0){a[N]=(a[N]|0)+1&255}if((M&8|0)!=0){a[N]=(a[N]|0)+1&255}if((M&16|0)!=0){a[N]=(a[N]|0)+1&255}if((M&32|0)!=0){a[N]=(a[N]|0)+1&255}if((M&64|0)!=0){a[N]=(a[N]|0)+1&255}if((M&128|0)!=0){a[N]=(a[N]|0)+1&255}N=M+1|0;if((N|0)<256){M=N}else{ap=0;break}}while(1){if((ap|0)>=1024){t=60645;break}aq=9638528+(ap<<2)|0;if((c[aq>>2]|0)==0){t=60644;break}else{ap=ap+1|0}}do{if((t|0)==60644){M=gGq(1244)|0;c[aq>>2]=M;if((M|0)==0){t=60645;break}gGz(M|0,0,1244);c[2420426]=M;M=0;while(1){if((M|0)>=1024){ar=0;break}as=9638528+(M<<2)|0;if((c[as>>2]|0)==0){t=60649;break}else{M=M+1|0}}do{if((t|0)==60649){M=gGq(2208)|0;c[as>>2]=M;if((M|0)==0){ar=0;break}gGz(M|0,0,2208);ar=M}}while(0);c[2385304]=ar}}while(0);if((t|0)==60645){c[2420426]=0}c[2112966]=c[3540926];M=c[2112956]|0;if((M|0)!=0){gu[M&16383]()}M=c[2112954]|0;if((M|0)!=0){gu[M&16383]()}dgg();R=0;i=e;return R|0}}while(0);c[2426810]=0;R=1;i=e;return R|0}function dgi(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0;b=i;i=i+952|0;d=b|0;e=b+112|0;f=b+120|0;g=b+232|0;h=b+240|0;j=b+352|0;k=b+360|0;l=b+472|0;m=b+480|0;n=b+592|0;o=b+600|0;p=b+712|0;q=b+720|0;r=b+728|0;s=b+840|0;t=c[642608+(c[2436]<<2)>>2]|0;u=(dW(c[t>>2]|0,462280,4)|0)==0;v=c[3540942]|0;w=(c[3540916]|0)+1572864|0;x=c[3540920]|0;y=c[3541280]|0;z=y+4194304|0;if(u){A=a?y+8388608|0:z}else{A=z}if((gp[c[t+80>>2]&16383](q,0,0)|0)==0){t=r+108|0;z=r+100|0;y=s+100|0;B=o+108|0;C=o+100|0;D=h+108|0;E=h+100|0;F=f+108|0;G=f+100|0;H=d+108|0;I=d+100|0;J=m+108|0;K=m+100|0;L=k+108|0;M=k+100|0;N=v;v=w;w=x;x=A;A=0;while(1){gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,A)|0;O=c[t>>2]|0;P=O&1048591;do{if((P|0)==1048577){if(!a){c[2113112]=(c[2113112]|0)+(c[z>>2]|0);Q=A;R=x;S=w;T=v;U=N;break}V=A+1|0;W=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[W&16383](s,V)|0;do{if((c[z>>2]|0)==524288){if((c[y>>2]|0)!=524288){X=60672;break}R6(N,A,2)|0;W=N+1|0;R6(W,V,2)|0;Y=V;Z=N+(c[y>>2]|0)|0}else{X=60672}}while(0);do{if((X|0)==60672){X=0;if((c[3542200]|0)==0){Y=A;Z=N;break}c[B>>2]=0;c[C>>2]=0;V=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[V&16383](o,A)|0;if((c[B>>2]|0)==0){Y=A;Z=N;break}V=c[C>>2]|0;c[p>>2]=9534384;W=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[W&16383](p,A,0)|0;if((V|0)<1){Y=A;Z=N;break}gzL(N,0,A)|0;Y=A;Z=N}}while(0);Q=Y;R=x;S=w;T=v;U=Z+(c[z>>2]|0)|0}else{V=O&2097167;if((V|0)==2097154){if(!a){c[2113096]=(c[2113096]|0)+(c[z>>2]|0);Q=A;R=x;S=w;T=v;U=N;break}do{if((c[3542200]|0)!=0){c[J>>2]=0;c[K>>2]=0;W=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[W&16383](m,A)|0;if((c[J>>2]|0)==0){break}W=c[K>>2]|0;c[n>>2]=9534384;_=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[_&16383](n,A,0)|0;if((W|0)<1){break}gzL(v,0,A)|0}}while(0);Q=A;R=x;S=w;T=v+(c[z>>2]|0)|0;U=N;break}else if((V|0)==2097156){if(!a){c[2113098]=(c[2113098]|0)+(c[z>>2]|0);Q=A;R=x;S=w;T=v;U=N;break}W=c[642608+(c[2436]<<2)>>2]|0;if((fa(c[W>>2]|0,451320)|0)==0){$=(w-(c[3540920]|0)|0)==16777216?w-1048576|0:w}else{$=w}do{if((c[3542200]|0)!=0){c[L>>2]=0;c[M>>2]=0;_=c[W+76>>2]|0;gA[_&16383](k,A)|0;if((c[L>>2]|0)==0){break}_=c[M>>2]|0;c[l>>2]=9534384;aa=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aa&16383](l,A,0)|0;if((_|0)<1){break}gzL($,0,A)|0}}while(0);Q=A;R=x;S=$+(c[z>>2]|0)|0;T=v;U=N;break}else if((V|0)==2097155){if(a){Q=A;R=x;S=w;T=v;U=N;break}c[2113102]=(c[2113102]|0)+(c[z>>2]|0);Q=A;R=x;S=w;T=v;U=N;break}else{if((O&4194319|0)==4194309){if(!a){c[2113106]=(c[2113106]|0)+(c[z>>2]|0);Q=A;R=x;S=w;T=v;U=N;break}do{if((c[3542200]|0)!=0){c[D>>2]=0;c[E>>2]=0;W=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[W&16383](h,A)|0;if((c[D>>2]|0)==0){break}W=c[E>>2]|0;c[j>>2]=9534384;_=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[_&16383](j,A,0)|0;if((W|0)<1){break}gzL(x,0,A)|0}}while(0);Q=A;R=x+(c[z>>2]|0)|0;S=w;T=v;U=N;break}if((P|0)==1048583){if(!a){Q=A;R=x;S=w;T=v;U=N;break}V=c[642608+(c[2436]<<2)>>2]|0;if((c[V+60>>2]&1|0)==0){Q=A;R=x;S=w;T=v;U=N;break}W=c[3540934]|0;if((c[3542200]|0)==0){Q=A;R=x;S=w;T=v;U=N;break}c[F>>2]=0;c[G>>2]=0;_=c[V+76>>2]|0;gA[_&16383](f,A)|0;if((c[F>>2]|0)==0){Q=A;R=x;S=w;T=v;U=N;break}_=c[G>>2]|0;c[g>>2]=9534384;V=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[V&16383](g,A,0)|0;if((_|0)<1){Q=A;R=x;S=w;T=v;U=N;break}gzL(W,0,A)|0;Q=A;R=x;S=w;T=v;U=N;break}else if((P|0)!=1048584){Q=A;R=x;S=w;T=v;U=N;break}W=c[642608+(c[2436]<<2)>>2]|0;if((c[W+60>>2]&1|0)==0){Q=A;R=x;S=w;T=v;U=N;break}if(!a){c[2113108]=(c[2113108]|0)+(c[z>>2]|0);Q=A;R=x;S=w;T=v;U=N;break}_=c[3540910]|0;if((c[3542200]|0)==0){Q=A;R=x;S=w;T=v;U=N;break}c[H>>2]=0;c[I>>2]=0;gA[c[W+76>>2]&16383](d,A)|0;if((c[H>>2]|0)==0){Q=A;R=x;S=w;T=v;U=N;break}W=c[I>>2]|0;c[e>>2]=9534384;gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](e,A,0)|0;if((W|0)<1){Q=A;R=x;S=w;T=v;U=N;break}gzL(_,0,A)|0;Q=A;R=x;S=w;T=v;U=N;break}}}while(0);P=Q+1|0;if((gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](q,P,0)|0)==0){N=U;v=T;w=S;x=R;A=P}else{break}}}if(a){i=b;return}a=(c[2113096]|0)+1572864|0;c[2113096]=(a|0)<4194304?4194304:a;c[2113106]=((c[2113106]|0)+(u?8388607:4194303)|1048575)+1;if((c[2113108]|0)!=0){i=b;return}c[2113108]=2097152;i=b;return}function dgj(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;c[2385474]=0;b=c[2385352]|0;d=0;while(1){if((d|0)>=1024){break}e=9638528+(d<<2)|0;if((c[e>>2]|0)==(b|0)){f=60730;break}else{d=d+1|0}}if((f|0)==60730){gGr(b);c[e>>2]=0}c[2385352]=0;e=c[2385206]|0;b=0;while(1){if((b|0)>=1024){break}g=9638528+(b<<2)|0;if((c[g>>2]|0)==(e|0)){f=60734;break}else{b=b+1|0}}if((f|0)==60734){gGr(e);c[g>>2]=0}c[2385206]=0;g=c[2385220]|0;e=0;while(1){if((e|0)>=1024){break}h=9638528+(e<<2)|0;if((c[h>>2]|0)==(g|0)){f=60738;break}else{e=e+1|0}}if((f|0)==60738){gGr(g);c[h>>2]=0}c[2385220]=0;h=c[2443760]|0;g=0;while(1){if((g|0)>=1024){break}i=9638528+(g<<2)|0;if((c[i>>2]|0)==(h|0)){f=60742;break}else{g=g+1|0}}if((f|0)==60742){gGr(h);c[i>>2]=0}c[2443760]=0;i=c[3528926]|0;h=0;while(1){if((h|0)>=1024){break}j=9638528+(h<<2)|0;if((c[j>>2]|0)==(i|0)){f=60746;break}else{h=h+1|0}}if((f|0)==60746){gGr(i);c[j>>2]=0}c[3528926]=0;c[2113070]=0;c[2113068]=0;j=c[2112926]|0;if((j|0)!=0){gGr(j);c[2112926]=0}if((c[2392]|0)>=0){j=0;do{i=14130368+(j<<2)|0;h=c[i>>2]|0;if((h|0)!=0){gGr(h);c[i>>2]=0}i=14130384+(j<<2)|0;h=c[i>>2]|0;if((h|0)!=0){gGr(h);c[i>>2]=0}j=j+1|0;}while((j|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;fwZ();if(a[7024728]|0){j=c[2406724]|0;if((j|0)!=0){gGr(j);c[2406724]=0}j=c[2406722]|0;if((j|0)!=0){gGr(j);c[2406722]=0}j=c[2406720]|0;if((j|0)!=0){gGr(j);c[2406720]=0}c[1744674]=-1}j=c[2426810]|0;i=0;while(1){if((i|0)>=1024){break}k=9638528+(i<<2)|0;if((c[k>>2]|0)==(j|0)){f=60766;break}else{i=i+1|0}}if((f|0)==60766){gGr(j);c[k>>2]=0}c[2426810]=0;k=c[2420426]|0;j=0;while(1){if((j|0)>=1024){break}l=9638528+(j<<2)|0;if((c[l>>2]|0)==(k|0)){f=60770;break}else{j=j+1|0}}if((f|0)==60770){gGr(k);c[l>>2]=0}c[2420426]=0;l=c[3541280]|0;k=0;while(1){if((k|0)>=1024){break}m=9638528+(k<<2)|0;if((c[m>>2]|0)==(l|0)){f=60774;break}else{k=k+1|0}}if((f|0)==60774){gGr(l);c[m>>2]=0}c[3541280]=0;m=c[2385304]|0;l=0;while(1){if((l|0)>=1024){break}n=9638528+(l<<2)|0;if((c[n>>2]|0)==(m|0)){f=60778;break}else{l=l+1|0}}if((f|0)==60778){gGr(m);c[n>>2]=0}c[2385304]=0;n=c[3540916]|0;m=0;while(1){if((m|0)>=1024){break}o=9638528+(m<<2)|0;if((c[o>>2]|0)==(n|0)){f=60782;break}else{m=m+1|0}}if((f|0)==60782){gGr(n);c[o>>2]=0}c[3540916]=0;o=c[3540914]|0;n=0;while(1){if((n|0)>=1024){break}p=9638528+(n<<2)|0;if((c[p>>2]|0)==(o|0)){f=60786;break}else{n=n+1|0}}if((f|0)==60786){gGr(o);c[p>>2]=0}c[3540914]=0;p=c[3540922]|0;o=0;while(1){if((o|0)>=1024){break}q=9638528+(o<<2)|0;if((c[q>>2]|0)==(p|0)){f=60790;break}else{o=o+1|0}}if((f|0)==60790){gGr(p);c[q>>2]=0}c[3540922]=0;q=c[3540920]|0;p=0;while(1){if((p|0)>=1024){f=60796;break}r=9638528+(p<<2)|0;if((c[r>>2]|0)==(q|0)){break}else{p=p+1|0}}if((f|0)==60796){c[3540920]=0;c[2113112]=0;c[2113096]=0;c[2113102]=0;c[2113098]=0;c[2113106]=0;c[2113108]=0;c[2112956]=0;c[2112954]=0;c[2112950]=0;c[2112952]=0;a[7024728]=0;a[9592]=0;c[2113110]=0;c[2113094]=0;c[631004]=-1;return 0}gGr(q);c[r>>2]=0;c[3540920]=0;c[2113112]=0;c[2113096]=0;c[2113102]=0;c[2113098]=0;c[2113106]=0;c[2113108]=0;c[2112956]=0;c[2112954]=0;c[2112950]=0;c[2112952]=0;a[7024728]=0;a[9592]=0;c[2113110]=0;c[2113094]=0;c[631004]=-1;return 0}function dgk(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;if((a[14163448]|0)!=0){dgg()}gGz(14163488,0,6);f=0;g=0;h=0;i=0;j=0;k=0;l=0;do{g=((a[14163480+f|0]&1)<<f|g&255)&255;h=((a[14163472+f|0]&1)<<f|h&255)&255;i=((a[14163464+f|0]&1)<<f|i&255)&255;j=((a[14163456+f|0]&1)<<f|j&255)&255;k=((a[14163512+f|0]&1)<<f|k&255)&255;l=((a[14163504+f|0]&1)<<f|l&255)&255;f=f+1|0;}while((f|0)<8);a[14163488]=g;a[14163489]=h;a[14163490]=i;a[14163491]=j;a[14163492]=k;a[14163493]=l;if((g&6)==6){l=g&-7;a[14163488]=l;m=l}else{m=g}if((m&24)==24){a[14163488]=m&-25}if((h&6)==6){m=h&-7;a[14163489]=m;n=m}else{n=h}if((n&24)==24){a[14163489]=n&-25}if((i&6)==6){n=i&-7;a[14163490]=n;o=n}else{o=i}if((o&24)==24){a[14163490]=o&-25}if((j&6)==6){o=j&-7;a[14163491]=o;p=o}else{p=j}if((p&24)==24){a[14163491]=p&-25}c[2444046]=0;c[2443994]=0;c[2443962]=0;p=c[2392]|0;if((p|0)>=0){gGz(8452240,0,((p|0)>0?(p<<2)+4|0:4)|0)}c[2113054]=0;p=c[2385548]|0;if((p|0)>0){gGz(9752472,0,((p|0)>1?p<<2:4)|0)}c[2433530]=0;do{if(a[7024728]|0){c[2440186]=0;p=c[2113110]|0;if((p|0)==1|(p|0)==2){j=c[2113094]|0;if((j|0)==0){break}a[(c[3540934]|0)+j|0]=a[14163495]|0;break}else if((p|0)==3){if((dW(c[c[642608+(c[2436]<<2)>>2]>>2]|0,380304,7)|0)!=0){break}a[(c[3540932]|0)+344|0]=a[14163495]|0;break}else{break}}}while(0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];p=c[3532592]|0;if((p|0)!=0){gGC(9104152,p|0,280)|0}c[2113054]=c[2113060]}p=c[2439330]|0;if((p|0)!=0){j=p;gGC(9706056,j|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;j=0;p=0;do{o=c[2424]|0;i=(2e9/(o|0)|0|0)/100|0;j=((8468e5/(o|0)|0|0)/100|0)+j|0;c[2113056]=i;o=RG(i)|0;i=(c[2113054]|0)+o|0;c[2113054]=i;c[2276108]=-1;c[2113056]=-1;c[2444046]=(c[2444046]|0)+o;do{if(a[7024728]|0){o=i-(c[2440186]|0)|0;if((o|0)<=0){break}n=fyW(o)|0;c[2443962]=(c[2443962]|0)+n}}while(0);do{if((p|0)==99|(p|0)==49){if((a[9775568]|0)==0){q=j}else{i=c[2443994]|0;n=j-i|0;do{if((n|0)<1){r=0;s=i}else{if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){o=gfc(n)|0;c[2433530]=(c[2433530]|0)+o;r=o;s=c[2443994]|0;break}else{c[2433530]=(c[2433530]|0)+n;r=n;s=i;break}}}while(0);q=s+r|0}c[2443994]=q;if((p|0)!=49|a[9592]){break}c[8452200+(c[2394]<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0>=1024){break}RH(4)}}while(0);p=p+1|0;}while((p|0)<100);c[8452200+(c[2394]<<2)>>2]=8198;c[2276080]=1536;if((c[2276079]|0)>>>0<1536){RH(6)}p=c[2420426]|0;do{if((a[p+1222|0]&1)!=0){q=p+1239|0;r=a[q]|1;a[q]=r;q=(r&a[p+1238|0])<<24>>24!=0;r=q&1;if(q){t=r;u=1}else{q=r;r=0;while(1){s=(a[p+516+(r*22|0)+21|0]&2)==0?q:1;j=r+1|0;i=(s|0)!=0;if((j|0)<32&(i^1)){q=s;r=j}else{t=s;u=i;break}}}r=p+1240|0;if((t|0)==(c[r>>2]|0)){break}c[r>>2]=t;if(u){a[9706117]=1;break}else{a[9706117]=0;break}}}while(0);do{if((a[p+1230|0]&1)!=0){u=p+1239|0;t=a[u]|2;a[u]=t;u=(t&a[p+1238|0])<<24>>24!=0;t=u&1;if(u){v=t;w=1}else{u=t;t=0;while(1){r=(a[p+516+(t*22|0)+21|0]&2)==0?u:1;q=t+1|0;i=(r|0)!=0;if((q|0)<32&(i^1)){u=r;t=q}else{v=r;w=i;break}}}t=p+1240|0;if((v|0)==(c[t>>2]|0)){break}c[t>>2]=v;if(w){a[9706117]=1;break}else{a[9706117]=0;break}}}while(0);w=c[1836236]|0;v=c[9757320+(w<<2)>>2]|0;if((v|0)!=0){t=v;gGC(t|0,9706056,76)|0}c[9752472+(w<<2)>>2]=c[2433530];c[14113936+(w<<2)>>2]=c[2076596];c[9669104+(w<<2)>>2]=c[3541536];c[1836236]=-1;w=c[2394]|0;t=c[14130368+(w<<2)>>2]|0;if((t|0)!=0){gGC(t|0,9104152,280)|0}c[8452240+(w<<2)>>2]=c[2113054];c[2394]=-1;w=c[2385304]|0;gGz(w|0,0,1104);t=p|0;v=0;u=0;while(1){i=p+516+(v*22|0)+21|0;if((a[i]&1)==0){x=u}else{r=d[p+516+(v*22|0)+14|0]<<20&15728640;q=p+516+(v*22|0)+2|0;s=p+516+(v*22|0)+4|0;j=e[q>>1]<<16|e[s>>1];n=d[p+516+(v*22|0)+13|0]<<8|e[p+516+(v*22|0)+8>>1]<<16;o=d[p+516+(v*22|0)+12|0]<<8|e[p+516+(v*22|0)+6>>1]<<16;h=e[p+516+(v*22|0)+10>>1]|0;m=(h&4080|4096)<<(h>>>12)>>12;h=e[p+516+(v*22|0)>>1]<<2;L71809:do{if((a[p+516+(v*22|0)+16|0]&1)==0){g=m<<6;l=0;k=j;while(1){if((l|0)>=552){break}f=(ag(g,a[(c[t>>2]|0)+(k>>>12|r)|0]|0)|0)>>21;y=w+(l<<1)|0;b[y>>1]=(e[y>>1]|0)+f&65535;f=k+h|0;if(f>>>0<n>>>0){l=l+1|0;k=f}else{z=f;A=60878;break L71809}}B=u;C=k>>>16&65535;D=k&65535}else{l=0;g=j;while(1){if((l|0)>=552){break}f=(ag(b[p+4+(d[(c[t>>2]|0)+(g>>>12|r)|0]<<1)>>1]|0,m)|0)>>21;y=w+(l<<1)|0;b[y>>1]=(e[y>>1]|0)+f&65535;f=g+h|0;if(f>>>0<n>>>0){l=l+1|0;g=f}else{z=f;A=60878;break L71809}}B=u;C=g>>>16&65535;D=g&65535}}while(0);if((A|0)==60878){A=0;h=z+(o-n)|0;a[i]=a[i]&-4|2;B=1;C=h>>>16&65535;D=h&65535}b[q>>1]=C;b[s>>1]=D;x=B}h=v+1|0;if((h|0)<32){v=h;u=x}else{break}}do{if((x|0)!=0){u=(a[p+1239|0]&a[p+1238|0])<<24>>24!=0;v=u&1;if(u){E=v;F=1}else{u=v;v=0;while(1){B=(a[p+516+(v*22|0)+21|0]&2)==0?u:1;D=v+1|0;C=(B|0)!=0;if((D|0)<32&(C^1)){u=B;v=D}else{E=B;F=C;break}}}v=p+1240|0;if((E|0)==(c[v>>2]|0)){break}c[v>>2]=E;if(F){a[9706117]=1;break}else{a[9706117]=0;break}}}while(0);F=c[2112964]|0;if((F|0)!=0&a[9688]){E=b[w>>1]<<4;b[7049077]=E;b[7049076]=E;E=c[2443874]|0;p=1;x=F;F=0;while(1){v=E+F|0;u=x+4|0;s=p+1|0;q=b[w+(v>>16<<1)>>1]<<4;b[x+6>>1]=q;b[u>>1]=q;if((s|0)<534){p=s;x=u;F=v}else{break}}}if((c[2112968]|0)==0){G=c[3540918]|0;H=G;I=c[3540944]|0;gGC(H|0,I|0,2560)|0;return 0}c2M()|0;G=c[3540918]|0;H=G;I=c[3540944]|0;gGC(H|0,I|0,2560)|0;return 0}function dgl(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;e=i;i=i+224|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;l=e+80|0;m=e+96|0;n=e+112|0;o=e+128|0;p=e+144|0;q=e+160|0;r=e+176|0;s=e+192|0;t=e+208|0;if((d|0)!=0){c[d>>2]=169730}a[8452368]=1;do{if((b&4|0)!=0){if((c[(c[642608+(c[2436]<<2)>>2]|0)+60>>2]&2|0)==0){u=t|0;c[u>>2]=c[3540946];v=t+4|0;c[v>>2]=131072;w=t+8|0;c[w>>2]=0;x=t+12|0;c[x>>2]=424080;y=c[2076592]|0;gj[y&4095](t)|0;c[u>>2]=c[3540942];c[v>>2]=c[2113112];c[w>>2]=1048576;c[x>>2]=496208;x=c[2076592]|0;gj[x&4095](t)|0;break}else{c[t>>2]=c[3540942];c[t+4>>2]=c[2113112];c[t+8>>2]=0;c[t+12>>2]=496208;x=c[2076592]|0;gj[x&4095](t)|0;break}}}while(0);if((b&32|0)!=0){x=t|0;c[x>>2]=c[3540928];w=t+4|0;c[w>>2]=16384;v=t+8|0;c[v>>2]=9437184;u=t+12|0;c[u>>2]=329104;y=c[2076592]|0;gj[y&4095](t)|0;c[x>>2]=c[3540912];c[w>>2]=12288;c[v>>2]=9453568;c[u>>2]=250616;y=c[2076592]|0;gj[y&4095](t)|0;c[x>>2]=c[3540924];c[w>>2]=4096;c[v>>2]=9465856;c[u>>2]=196352;y=c[2076592]|0;gj[y&4095](t)|0;c[x>>2]=c[3540926];c[w>>2]=5120;c[v>>2]=10485760;c[u>>2]=426800;y=c[2076592]|0;gj[y&4095](t)|0;c[x>>2]=c[3540908];c[w>>2]=65536;c[v>>2]=11534336;c[u>>2]=125944;y=c[2076592]|0;gj[y&4095](t)|0;c[x>>2]=c[2411354];c[w>>2]=65536;c[v>>2]=12648448;c[u>>2]=498600;u=c[2076592]|0;gj[u&4095](t)|0}if((b&8|0)!=0){c[t>>2]=c[3540944];c[t+4>>2]=131072;c[t+8>>2]=8388608;c[t+12>>2]=484192;u=c[2076592]|0;gj[u&4095](t)|0}if((b&64|0)!=0){t=p|0;gGz(o|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){u=p+9|0;p=n;v=n|0;w=n+4|0;x=n+12|0;y=o|0;z=o+4|0;A=o+12|0;B=0;do{gGC(t|0,614896,11)|0;a[u]=B+48&255;C=8452256+(B<<2)|0;gGz(p|0,0,12);c[v>>2]=C;c[w>>2]=4;c[x>>2]=164976;gj[c[2076592]&4095](n)|0;if((c[C>>2]|0)!=0){c[y>>2]=c[14130368+(B<<2)>>2];c[z>>2]=c[8452184+(B<<2)>>2];c[A>>2]=t;C=c[2076592]|0;gj[C&4095](o)|0}B=B+1|0;}while((B|0)<=(c[2392]|0))}fw$(b);gGz(m|0,0,12);c[m>>2]=9658128;c[m+4>>2]=1;c[m+12>>2]=184072;B=c[2076592]|0;gj[B&4095](m)|0;gGz(l|0,0,12);c[l>>2]=9635888;c[l+4>>2]=1;c[l+12>>2]=506960;m=c[2076592]|0;gj[m&4095](l)|0;gGz(k|0,0,12);c[k>>2]=9658136;c[k+4>>2]=1;c[k+12>>2]=391144;l=c[2076592]|0;gj[l&4095](k)|0;gGz(j|0,0,12);c[j>>2]=9658144;c[j+4>>2]=1;c[j+12>>2]=303720;k=c[2076592]|0;gj[k&4095](j)|0;gGz(s|0,0,12);c[s>>2]=14163488;c[s+4>>2]=9;c[s+12>>2]=585232;j=c[2076592]|0;gj[j&4095](s)|0;gGz(r|0,0,12);c[r>>2]=9775568;c[r+4>>2]=1;c[r+12>>2]=568752;s=c[2076592]|0;gj[s&4095](r)|0;gGz(q|0,0,12);c[q>>2]=2524016;c[q+4>>2]=4;c[q+12>>2]=552480;r=c[2076592]|0;gj[r&4095](q)|0;q=c[2420426]|0;r=c[q>>2]|0;c[h>>2]=q;c[h+4>>2]=1244;c[h+8>>2]=0;c[h+12>>2]=118576;q=c[2076592]|0;gj[q&4095](h)|0;c[c[2420426]>>2]=r;gGz(g|0,0,12);c[g>>2]=9775472;c[g+4>>2]=6;c[g+12>>2]=495376;r=c[2076592]|0;gj[r&4095](g)|0;gGz(f|0,0,12);c[f>>2]=9747064;c[f+4>>2]=3;c[f+12>>2]=369832;g=c[2076592]|0;gj[g&4095](f)|0}f=c[2112950]|0;if((f|0)==0){i=e;return 0}gA[f&16383](b,d)|0;i=e;return 0}function dgm(d,e){d=d|0;e=e|0;if(d>>>0<131072){return}switch(d|0){case 393216:case 393218:case 393220:case 393222:{b[(c[2409008]|0)+((d>>>1&3)<<1)>>1]=e;return};case 393230:{a[c[3528340]|0]=e&255;f44(32);f45(0)|0;if((a[9660797]|0)!=0){a[9660797]=0}f45(0)|0;return};case 393224:{b[c[2439264]>>1]=e;return};case 393228:{a[c[3528768]|0]=e&1^1;return};default:{return}}}function dgn(a){a=a|0;var c=0;if((a|0)==458752){c=b[4775040]|0}else if((a|0)==458754){c=(d[9635545]|0)<<8|(d[9635544]|0)}else{c=0}return c|0}function dgo(a,b){a=a|0;b=b|0;return}function dgp(a){a=a|0;return 0}function dgq(b,e){b=b|0;e=e|0;var f=0,g=0;f=b&65535;if((f|0)==8192|(f|0)==8193){b=c[3540988]|0;if((f&1|0)==0){a[b+5885|0]=e;return}g=c[b+5876>>2]|0;if((g|0)!=0){gg[g&4095](c[b+5880>>2]|0,0)}lH(b,d[b+5885|0]|0,e&255);return}else if((f|0)==2049){a[14108328]=e;return}else if((f|0)==2051){a[14108312]=e;return}else if((f|0)==2050){a[14108320]=e;return}else if((f|0)==2048){a[14108336]=e;b=(e&255)>>>7;a[14108344]=b;if(b<<24>>24==0){return}b=a[14108320]|0;if(b<<24>>24==(a[9773168]|0)|b<<24>>24==0){return}a[9773168]=b;return}else if((f|0)==10240|(f|0)==10241){b=e&255;if((f&1|0)==0){c[3542228]=b&15;return}f=c[3542228]|0;if((f|0)>15){return}do{if((f|0)<14){if((f|0)!=13){if((a[14168916+f|0]|0)==e<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(0,f,b);return}else{return}}function dgr(b){b=b|0;var d=0;if(b<<16>>16!=6144){d=0;return d|0}d=a[c[3528340]|0]|0;return d|0}function dgs(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2827052+(b*112|0)>>2];c[a+104>>2]=c[2827056+(b*112|0)>>2];c[a+108>>2]=c[2827060+(b*112|0)>>2];d=0;return d|0}function dgt(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=2826952+(b*112|0);e=0;return e|0}function dgu(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1241680+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dgv(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>42){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3906976+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dgw(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0.0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0;e=i;i=i+1704|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;B=e+1200|0;C=e+1312|0;D=e+1320|0;E=e+1432|0;F=e+1440|0;G=e+1552|0;H=e+1560|0;I=e+1576|0;J=e+1640|0;c[2415058]=0;c[2388186]=0;c[3527394]=131072;c[3530912]=196608;c[3530676]=458752;c[3530478]=720896;c[3530358]=753664;c[3530296]=1802240;c[2386674]=1835008;c[3530142]=1966080;c[2439154]=1970176;K=a[9688]|0?1068:0;L=K|1970176;c[2439155]=L;M=L+K|0;c[2439156]=M;L=M+K|0;K=L|0;c[2414766]=K;c[2388304]=K;c[3527410]=L+16384;c[2387250]=L+18432;c[2406508]=L+20480;c[2386338]=L+36864;c[2386524]=L+38912;c[2439264]=L+40960;c[3528340]=L+40962;c[3528768]=L+40963;c[2409008]=L+40964;K=L+40972|0;c[2411822]=K;c[2414370]=K;L=K;K=0;while(1){if((K|0)>=1024){break}N=9638528+(K<<2)|0;if((c[N>>2]|0)==0){O=61007;break}else{K=K+1|0}}do{if((O|0)==61007){K=gGq(L)|0;c[N>>2]=K;if((K|0)==0){break}gGz(K|0,0,L|0);c[2415058]=K;gGz(K|0,0,L|0);c[2388186]=K;c[3527394]=K+131072;c[3530912]=K+196608;c[3530676]=K+458752;c[3530478]=K+720896;c[3530358]=K+753664;c[3530296]=K+1802240;c[2386674]=K+1835008;c[3530142]=K+1966080;c[2439154]=K+1970176;M=a[9688]|0?1068:0;P=M|1970176;c[2439155]=K+P;Q=P+M|0;c[2439156]=K+Q;P=Q+M|0;M=K+P|0;c[2414766]=M;c[2388304]=M;c[3527410]=K+(P+16384);c[2387250]=K+(P+18432);c[2406508]=K+(P+20480);c[2386338]=K+(P+36864);c[2386524]=K+(P+38912);c[2439264]=K+(P+40960);c[3528340]=K+(P+40962);c[3528768]=K+(P+40963);c[2409008]=K+(P+40964);M=K+(P+40972)|0;c[2411822]=M;c[2414370]=M;if((R6(K+1|0,0,2)|0)!=0){R=1;i=e;return R|0}if((R6(c[2388186]|0,1,2)|0)!=0){R=1;i=e;return R|0}K=c[3527394]|0;if((c[3542200]|0)==0){R=1;i=e;return R|0}M=F+108|0;c[M>>2]=0;P=F+100|0;c[P>>2]=0;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Q&16383](F,2)|0;do{if((c[M>>2]|0)!=0){Q=c[P>>2]|0;c[G>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](G,2,0)|0;if((Q|0)<1){R=1;i=e;return R|0}if((gzL(K,0,2)|0)==0){break}else{R=1}i=e;return R|0}}while(0);K=c[3530912]|0;if((c[3542200]|0)==0){R=1;i=e;return R|0}P=D+108|0;c[P>>2]=0;M=D+100|0;c[M>>2]=0;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Q&16383](D,3)|0;do{if((c[P>>2]|0)!=0){Q=c[M>>2]|0;c[E>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](E,3,0)|0;if((Q|0)<1){R=1;i=e;return R|0}if((gzL(K,0,3)|0)==0){break}else{R=1}i=e;return R|0}}while(0);K=(c[3530912]|0)+65536|0;if((c[3542200]|0)==0){R=1;i=e;return R|0}M=B+108|0;c[M>>2]=0;P=B+100|0;c[P>>2]=0;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Q&16383](B,4)|0;do{if((c[M>>2]|0)!=0){Q=c[P>>2]|0;c[C>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](C,4,0)|0;if((Q|0)<1){R=1;i=e;return R|0}if((gzL(K,0,4)|0)==0){break}else{R=1}i=e;return R|0}}while(0);K=c[3530676]|0;if((c[3542200]|0)==0){R=1;i=e;return R|0}P=z+108|0;c[P>>2]=0;M=z+100|0;c[M>>2]=0;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Q&16383](z,5)|0;do{if((c[P>>2]|0)!=0){Q=c[M>>2]|0;c[A>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](A,5,0)|0;if((Q|0)<1){R=1;i=e;return R|0}if((gzL(K,0,5)|0)==0){break}else{R=1}i=e;return R|0}}while(0);K=(c[3530676]|0)+65536|0;if((c[3542200]|0)==0){R=1;i=e;return R|0}M=x+108|0;c[M>>2]=0;P=x+100|0;c[P>>2]=0;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Q&16383](x,6)|0;do{if((c[M>>2]|0)!=0){Q=c[P>>2]|0;c[y>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](y,6,0)|0;if((Q|0)<1){R=1;i=e;return R|0}if((gzL(K,0,6)|0)==0){break}else{R=1}i=e;return R|0}}while(0);K=c[3530478]|0;if((c[3542200]|0)==0){R=1;i=e;return R|0}P=v+108|0;c[P>>2]=0;M=v+100|0;c[M>>2]=0;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Q&16383](v,7)|0;do{if((c[P>>2]|0)!=0){Q=c[M>>2]|0;c[w>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](w,7,0)|0;if((Q|0)<1){R=1;i=e;return R|0}if((gzL(K,0,7)|0)==0){break}else{R=1}i=e;return R|0}}while(0);K=c[3530358]|0;if((c[3542200]|0)==0){R=1;i=e;return R|0}M=t+108|0;c[M>>2]=0;P=t+100|0;c[P>>2]=0;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Q&16383](t,8)|0;do{if((c[M>>2]|0)!=0){Q=c[P>>2]|0;c[u>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](u,8,0)|0;if((Q|0)<1){R=1;i=e;return R|0}if((gzL(K,0,8)|0)==0){break}else{R=1}i=e;return R|0}}while(0);K=c[3530358]|0;P=K+262144|0;M=K+65536|0;gGC(P|0,M|0,65536)|0;if((c[3542200]|0)==0){R=1;i=e;return R|0}P=r+108|0;c[P>>2]=0;K=r+100|0;c[K>>2]=0;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Q&16383](r,9)|0;do{if((c[P>>2]|0)!=0){Q=c[K>>2]|0;c[s>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](s,9,0)|0;if((Q|0)<1){R=1;i=e;return R|0}if((gzL(M,0,9)|0)==0){break}else{R=1}i=e;return R|0}}while(0);M=(c[3530358]|0)+131072|0;if((c[3542200]|0)==0){R=1;i=e;return R|0}K=p+108|0;c[K>>2]=0;P=p+100|0;c[P>>2]=0;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Q&16383](p,10)|0;do{if((c[K>>2]|0)!=0){Q=c[P>>2]|0;c[q>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](q,10,0)|0;if((Q|0)<1){R=1;i=e;return R|0}if((gzL(M,0,10)|0)==0){break}else{R=1}i=e;return R|0}}while(0);M=(c[3530358]|0)+196608|0;if((c[3542200]|0)==0){R=1;i=e;return R|0}P=n+108|0;c[P>>2]=0;K=n+100|0;c[K>>2]=0;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Q&16383](n,11)|0;do{if((c[P>>2]|0)!=0){Q=c[K>>2]|0;c[o>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](o,11,0)|0;if((Q|0)<1){R=1;i=e;return R|0}if((gzL(M,0,11)|0)==0){break}else{R=1}i=e;return R|0}}while(0);M=c[3530296]|0;if((c[3542200]|0)==0){R=1;i=e;return R|0}K=l+108|0;c[K>>2]=0;P=l+100|0;c[P>>2]=0;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Q&16383](l,12)|0;do{if((c[K>>2]|0)!=0){Q=c[P>>2]|0;c[m>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](m,12,0)|0;if((Q|0)<1){R=1;i=e;return R|0}if((gzL(M,0,12)|0)==0){break}else{R=1}i=e;return R|0}}while(0);M=0;P=c[3530296]|0;while(1){K=a[P]|0;Q=P+1|0;a[P]=a[Q]|0;a[Q]=K;K=M+1|0;if((K|0)<16384){M=K;P=P+2|0}else{break}}P=c[2386674]|0;if((c[3542200]|0)==0){R=1;i=e;return R|0}M=j+108|0;c[M>>2]=0;K=j+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,13)|0;do{if((c[M>>2]|0)!=0){Q=c[K>>2]|0;c[k>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](k,13,0)|0;if((Q|0)<1){R=1;i=e;return R|0}if((gzL(P,0,13)|0)==0){break}else{R=1}i=e;return R|0}}while(0);P=(c[2386674]|0)+65536|0;if((c[3542200]|0)==0){R=1;i=e;return R|0}K=f+108|0;c[K>>2]=0;M=f+100|0;c[M>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,14)|0;do{if((c[K>>2]|0)!=0){Q=c[M>>2]|0;c[g>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](g,14,0)|0;if((Q|0)<1){R=1;i=e;return R|0}if((gzL(P,0,14)|0)==0){break}else{R=1}i=e;return R|0}}while(0);P=c[3530912]|0;M=H;K=I;Q=J;c[M>>2]=c[175854];c[M+4>>2]=c[175855];c[M+8>>2]=c[175856];c[M+12>>2]=c[175857];gGC(K|0,600104,64)|0;gGC(Q|0,611840,64)|0;S=gGq(131072)|0;if((S|0)!=0){gGC(S|0,P|0,131072)|0;T=0;do{U=T<<8;gGz(P+U|0,0,256);V=T<<10;W=0;do{X=1<<3-W;Y=(c[H+(W<<2)>>2]|0)+V|0;Z=0;do{_=Y+(c[J+(Z<<2)>>2]|0)|0;$=(Z<<4)+U|0;aa=0;do{ab=_+(c[I+(aa<<2)>>2]|0)|0;if(((d[S+((ab|0)/8|0)|0]|0)&128>>>((ab&7)>>>0)|0)!=0){ab=P+($+aa)|0;a[ab]=(d[ab]|0|X)&255}aa=aa+1|0;}while((aa|0)<16);Z=Z+1|0;}while((Z|0)<16);W=W+1|0;}while((W|0)<4);T=T+1|0;}while((T|0)<1024);gGr(S)}T=c[3530676]|0;c[M>>2]=c[175854];c[M+4>>2]=c[175855];c[M+8>>2]=c[175856];c[M+12>>2]=c[175857];gGC(K|0,600104,64)|0;gGC(Q|0,611840,64)|0;P=gGq(131072)|0;if((P|0)!=0){gGC(P|0,T|0,131072)|0;W=0;do{U=W<<8;gGz(T+U|0,0,256);V=W<<10;Z=0;do{X=1<<3-Z;Y=(c[H+(Z<<2)>>2]|0)+V|0;aa=0;do{$=Y+(c[J+(aa<<2)>>2]|0)|0;_=(aa<<4)+U|0;ab=0;do{ac=$+(c[I+(ab<<2)>>2]|0)|0;if(((d[P+((ac|0)/8|0)|0]|0)&128>>>((ac&7)>>>0)|0)!=0){ac=T+(_+ab)|0;a[ac]=(d[ac]|0|X)&255}ab=ab+1|0;}while((ab|0)<16);aa=aa+1|0;}while((aa|0)<16);Z=Z+1|0;}while((Z|0)<4);W=W+1|0;}while((W|0)<1024);gGr(P)}W=c[3530478]|0;c[M>>2]=c[175854];c[M+4>>2]=c[175855];c[M+8>>2]=c[175856];c[M+12>>2]=c[175857];gGC(K|0,600104,64)|0;gGC(Q|0,611840,64)|0;T=gGq(16384)|0;if((T|0)!=0){gGC(T|0,W|0,16384)|0;S=0;do{Z=S<<6;gGz(W+Z|0,0,64);U=S<<8;V=0;do{aa=1<<3-V;X=(c[H+(V<<2)>>2]|0)+U|0;Y=0;do{ab=X+(c[J+(Y<<2)>>2]|0)|0;_=(Y<<3)+Z|0;$=0;do{ac=ab+(c[I+($<<2)>>2]|0)|0;if(((d[T+((ac|0)/8|0)|0]|0)&128>>>((ac&7)>>>0)|0)!=0){ac=W+(_+$)|0;a[ac]=(d[ac]|0|aa)&255}$=$+1|0;}while(($|0)<8);Y=Y+1|0;}while((Y|0)<8);V=V+1|0;}while((V|0)<4);S=S+1|0;}while((S|0)<512);gGr(T)}S=c[3530358]|0;c[M>>2]=c[175854];c[M+4>>2]=c[175855];c[M+8>>2]=c[175856];c[M+12>>2]=c[175857];gGC(K|0,600104,64)|0;gGC(Q|0,611840,64)|0;W=gGq(327680)|0;if((W|0)!=0){gGC(W|0,S|0,327680)|0;P=0;do{V=P<<8;gGz(S+V|0,0,256);Z=P<<10;U=0;do{Y=1<<3-U;aa=(c[H+(U<<2)>>2]|0)+Z|0;X=0;do{$=aa+(c[J+(X<<2)>>2]|0)|0;_=(X<<4)+V|0;ab=0;do{ac=$+(c[I+(ab<<2)>>2]|0)|0;if(((d[W+((ac|0)/8|0)|0]|0)&128>>>((ac&7)>>>0)|0)!=0){ac=S+(_+ab)|0;a[ac]=(d[ac]|0|Y)&255}ab=ab+1|0;}while((ab|0)<16);X=X+1|0;}while((X|0)<16);U=U+1|0;}while((U|0)<4);P=P+1|0;}while((P|0)<2560);gGr(W)}fxU(0,425984);if((c[2394]|0)==0){ad=c[2112932]|0}else{c[2394]=0;P=c[3532596]|0;c[2112932]=P;S=c[3532592]|0;if((S|0)!=0){gGC(9104152,S|0,280)|0}c[2113054]=c[2113060];ad=P}P=c[2388186]|0;S=ad|0;Q=0;while(1){K=P+Q|0;c[S>>2]=K;c[S+131072>>2]=K;K=Q+1024|0;if(K>>>0>131071){break}else{S=S+4|0;Q=K}}Q=c[2388304]|0;c[ad+512>>2]=Q;c[ad+66048>>2]=Q;c[ad+131584>>2]=Q;S=Q+1024|0;c[ad+516>>2]=S;c[ad+66052>>2]=S;c[ad+131588>>2]=S;S=Q+2048|0;c[ad+520>>2]=S;c[ad+66056>>2]=S;c[ad+131592>>2]=S;S=Q+3072|0;c[ad+524>>2]=S;c[ad+66060>>2]=S;c[ad+131596>>2]=S;S=Q+4096|0;c[ad+528>>2]=S;c[ad+66064>>2]=S;c[ad+131600>>2]=S;S=Q+5120|0;c[ad+532>>2]=S;c[ad+66068>>2]=S;c[ad+131604>>2]=S;S=Q+6144|0;c[ad+536>>2]=S;c[ad+66072>>2]=S;c[ad+131608>>2]=S;S=Q+7168|0;c[ad+540>>2]=S;c[ad+66076>>2]=S;c[ad+131612>>2]=S;S=Q+8192|0;c[ad+544>>2]=S;c[ad+66080>>2]=S;c[ad+131616>>2]=S;S=Q+9216|0;c[ad+548>>2]=S;c[ad+66084>>2]=S;c[ad+131620>>2]=S;S=Q+10240|0;c[ad+552>>2]=S;c[ad+66088>>2]=S;c[ad+131624>>2]=S;S=Q+11264|0;c[ad+556>>2]=S;c[ad+66092>>2]=S;c[ad+131628>>2]=S;S=Q+12288|0;c[ad+560>>2]=S;c[ad+66096>>2]=S;c[ad+131632>>2]=S;S=Q+13312|0;c[ad+564>>2]=S;c[ad+66100>>2]=S;c[ad+131636>>2]=S;S=Q+14336|0;c[ad+568>>2]=S;c[ad+66104>>2]=S;c[ad+131640>>2]=S;S=Q+15360|0;c[ad+572>>2]=S;c[ad+66108>>2]=S;c[ad+131644>>2]=S;S=c[2386338]|0;c[ad+768>>2]=S;c[ad+66304>>2]=S;c[ad+131840>>2]=S;Q=S+1024|0;c[ad+772>>2]=Q;c[ad+66308>>2]=Q;c[ad+131844>>2]=Q;Q=c[2386524]|0;c[ad+1024>>2]=Q;c[ad+66560>>2]=Q;c[ad+132096>>2]=Q;S=Q+1024|0;c[ad+1028>>2]=S;c[ad+66564>>2]=S;c[ad+132100>>2]=S;S=c[2387250]|0;c[ad+1280>>2]=S;c[ad+66816>>2]=S;c[ad+132352>>2]=S;Q=S+1024|0;c[ad+1284>>2]=Q;c[ad+66820>>2]=Q;c[ad+132356>>2]=Q;Q=c[2406508]|0;c[ad+1664>>2]=Q;c[ad+67200>>2]=Q;c[ad+132736>>2]=Q;S=Q+1024|0;c[ad+1668>>2]=S;c[ad+67204>>2]=S;c[ad+132740>>2]=S;S=Q+2048|0;c[ad+1672>>2]=S;c[ad+67208>>2]=S;c[ad+132744>>2]=S;S=Q+3072|0;c[ad+1676>>2]=S;c[ad+67212>>2]=S;c[ad+132748>>2]=S;S=Q+4096|0;c[ad+1680>>2]=S;c[ad+67216>>2]=S;c[ad+132752>>2]=S;S=Q+5120|0;c[ad+1684>>2]=S;c[ad+67220>>2]=S;c[ad+132756>>2]=S;S=Q+6144|0;c[ad+1688>>2]=S;c[ad+67224>>2]=S;c[ad+132760>>2]=S;S=Q+7168|0;c[ad+1692>>2]=S;c[ad+67228>>2]=S;c[ad+132764>>2]=S;S=Q+8192|0;c[ad+1696>>2]=S;c[ad+67232>>2]=S;c[ad+132768>>2]=S;S=Q+9216|0;c[ad+1700>>2]=S;c[ad+67236>>2]=S;c[ad+132772>>2]=S;S=Q+10240|0;c[ad+1704>>2]=S;c[ad+67240>>2]=S;c[ad+132776>>2]=S;S=Q+11264|0;c[ad+1708>>2]=S;c[ad+67244>>2]=S;c[ad+132780>>2]=S;S=Q+12288|0;c[ad+1712>>2]=S;c[ad+67248>>2]=S;c[ad+132784>>2]=S;S=Q+13312|0;c[ad+1716>>2]=S;c[ad+67252>>2]=S;c[ad+132788>>2]=S;S=Q+14336|0;c[ad+1720>>2]=S;c[ad+67256>>2]=S;c[ad+132792>>2]=S;S=Q+15360|0;c[ad+1724>>2]=S;c[ad+67260>>2]=S;c[ad+132796>>2]=S;c[ad+196728>>2]=648;c[ad+196648>>2]=1352;c[ad+196688>>2]=1466;c[ad+196608>>2]=822;S=c[3532592]|0;if((S|0)!=0){gGC(S|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;c[3528554]=-1;c[2113160]=1;S=gGq(3148)|0;Q=S;c[2433592]=Q;if((S|0)!=0){gGz(S|0,0,3148);c[S+3120>>2]=3128;c[S+3124>>2]=1840;c[S+3128>>2]=136;c[S+3132>>2]=1902;c[2432840]=0;P=0;do{c[Q+48+(P<<2)>>2]=0;P=P+1|0;}while((P|0)<768);c[2113158]=0;c[2415198]=0;P=c[2427044]|0;c[9681616+(P<<3)>>2]=809272;c[9681620+(P<<3)>>2]=0;c[2427044]=P+1}c[3528554]=0;f43(S);P=c[3528554]|0;Q=9731360+(P<<2)|0;W=c[Q>>2]|0;c[2113158]=W;K=c[3527410]|0;M=c[2433592]|0;c[M+(P*3148|0)+48>>2]=K;c[M+(P*3148|0)+1072>>2]=K;c[M+(P*3148|0)+2096>>2]=K;T=K+256|0;c[M+(P*3148|0)+52>>2]=T;c[M+(P*3148|0)+1076>>2]=T;c[M+(P*3148|0)+2100>>2]=T;T=K+512|0;c[M+(P*3148|0)+56>>2]=T;c[M+(P*3148|0)+1080>>2]=T;c[M+(P*3148|0)+2104>>2]=T;T=K+768|0;c[M+(P*3148|0)+60>>2]=T;c[M+(P*3148|0)+1084>>2]=T;c[M+(P*3148|0)+2108>>2]=T;T=K+1024|0;c[M+(P*3148|0)+64>>2]=T;c[M+(P*3148|0)+1088>>2]=T;c[M+(P*3148|0)+2112>>2]=T;T=K+1280|0;c[M+(P*3148|0)+68>>2]=T;c[M+(P*3148|0)+1092>>2]=T;c[M+(P*3148|0)+2116>>2]=T;T=K+1536|0;c[M+(P*3148|0)+72>>2]=T;c[M+(P*3148|0)+1096>>2]=T;c[M+(P*3148|0)+2120>>2]=T;T=K+1792|0;c[M+(P*3148|0)+76>>2]=T;c[M+(P*3148|0)+1100>>2]=T;c[M+(P*3148|0)+2124>>2]=T;T=c[3527394]|0;K=64;U=64;while(1){V=T+(U<<8)|0;c[M+(P*3148|0)+48+(U<<2)>>2]=V;c[M+(P*3148|0)+48+(U+512<<2)>>2]=V;V=K+1&65535;if((V&65535)>255){break}else{K=V;U=V&65535}}c[M+(P*3148|0)+3124>>2]=826;c[M+(P*3148|0)+3120>>2]=2544;U=M+(P*3148|0)|0;if((U|0)!=0){K=U;gGC(K|0,9660752,48)|0}c[Q>>2]=W;c[3528554]=-1;K=a[9680]|0?32e3:0;c[3542220]=11200;if((c[2113008]|0)==0){gGz(14168888,0,252);c[3542223]=K;gGz(14168896,0,16);c[3542234]=~~((+(K|0)*32768.0*8.0+894886.0)/1789772.0);K=31;ae=32767.0;while(1){c[14169012+(K<<2)>>2]=~~(ae+.5);U=K-1|0;if((U|0)>0){K=U;ae=ae/1.188502227}else{break}}c[3542253]=0;h[1771269]=1.0;h[1771270]=1.0;h[1771271]=1.0;c[3542574]=3;c[3542575]=3;c[3542576]=3;mB(0);c[2113008]=(c[2113008]|0)+1}h[1771269]=.1;c[3542574]=3;h[1771270]=.1;c[3542575]=3;h[1771271]=.1;c[3542576]=3;T7(1,c[2386674]|0,131072,0,0,1352,1);c[2438226]=1e6;c[2433524]=4814;c[2406674]=206;c[3528470]=4026;c[2443844]=2047;h[826309]=1.0;c[2438350]=3;K=c[642608+(c[2436]<<2)>>2]|0;W=c[K+128>>2]|0;if((c[K+52>>2]&4|0)==0){c[2113068]=W;Q=c[K+132>>2]|0;c[2113070]=Q;c[2443814]=W;c[2440436]=Q;af=W;ah=Q}else{c[2113070]=W;Q=c[K+132>>2]|0;c[2113068]=Q;c[2440436]=W;c[2443814]=Q;af=Q;ah=W}W=ag(af<<1,ah)|0;Q=gGq(W)|0;c[2112926]=Q;if((Q|0)!=0){gGz(Q|0,0,W|0)}W=c[2414766]|0;gGz(W|0,0,(c[2411822]|0)-W|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];W=c[3532592]|0;if((W|0)!=0){gGC(9104152,W|0,280)|0}c[2113054]=c[2113060]}RI();W=c[2394]|0;Q=c[14130368+(W<<2)>>2]|0;if((Q|0)!=0){gGC(Q|0,9104152,280)|0}c[8452240+(W<<2)>>2]=c[2113054];c[2394]=-1;c[3528554]=0;f43(c[2433592]|0);W=c[3528554]|0;c[2113158]=c[9731360+(W<<2)>>2];a[9660796]=0;a[9660797]=0;a[9660786]=0;a[9660787]=0;c[2415191]=0;a[9660784]=a[9660784]|80;Q=c[2433592]|0;K=c[Q+(W*3148|0)+1068>>2]|0;do{if((K|0)==0){P=c[Q+(W*3148|0)+3120>>2]|0;if((P|0)==0){ai=0;aj=0;ak=W;al=Q;break}M=gj[P&4095](-2)|0;P=c[3528554]|0;U=c[2433592]|0;T=c[U+(P*3148|0)+1068>>2]|0;S=(M&255)<<8;if((T|0)!=0){am=T;an=S;ao=P;ap=U;O=61149;break}T=c[U+(P*3148|0)+3120>>2]|0;if((T|0)==0){ai=0;aj=S;ak=P;al=U;break}U=gj[T&4095](-1)|0;ai=U;aj=S;ak=c[3528554]|0;al=c[2433592]|0}else{am=K;an=(d[K+254|0]|0)<<8;ao=W;ap=Q;O=61149}}while(0);if((O|0)==61149){ai=a[am+255|0]|0;aj=an;ak=ao;al=ap}Q=ai&255|aj;c[2415188]=Q;b[4830376]=Q&65535;Q=al+(ak*3148|0)|0;if((Q|0)!=0){W=Q;gGC(W|0,9660752,48)|0}c[9731360+(ak<<2)>>2]=c[2113158];c[3528554]=-1;mB(0);c[2443829]=1073676288;c[2443828]=1073676288;c[2443821]=1073676288;c[2443820]=1073676288;h[920261]=0.0;c[3528510]=0;if((c[2385514]|0)>0){W=0;do{lw(c[14163952+(W<<2)>>2]|0);W=W+1|0;}while((W|0)<(c[2385514]|0))}a[14108336]=0;a[14108328]=0;a[14108320]=0;a[14108312]=0;a[14108344]=0;a[9773168]=0;a[9757784]=0;a[14116032]=0;R=0;i=e;return R|0}}while(0);c[2415058]=0;R=1;i=e;return R|0}function dgx(){var a=0,b=0,d=0,e=0,f=0;c[2113070]=0;c[2113068]=0;a=c[2112926]|0;if((a|0)!=0){gGr(a);c[2112926]=0}if((c[2392]|0)>=0){a=0;do{b=14130368+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}b=14130384+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}a=a+1|0;}while((a|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;c[2113160]=0;a=c[2433592]|0;if((a|0)!=0){gGr(a);c[2433592]=0}T6();c[2113008]=0;c[2076598]=0;c[2383582]=0;a=c[2415058]|0;b=0;while(1){if((b|0)>=1024){e=61216;break}f=9638528+(b<<2)|0;if((c[f>>2]|0)==(a|0)){break}else{b=b+1|0}}if((e|0)==61216){c[2415058]=0;return 0}gGr(a);c[f>>2]=0;c[2415058]=0;return 0}function dgy(){var e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;if((a[9624848]|0)!=0){e=c[2414766]|0;gGz(e|0,0,(c[2411822]|0)-e|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060]}RI();e=c[2394]|0;f=c[14130368+(e<<2)>>2]|0;if((f|0)!=0){gGC(f|0,9104152,280)|0}c[8452240+(e<<2)>>2]=c[2113054];c[2394]=-1;c[3528554]=0;f43(c[2433592]|0);e=c[3528554]|0;c[2113158]=c[9731360+(e<<2)>>2];a[9660796]=0;a[9660797]=0;a[9660786]=0;a[9660787]=0;c[2415191]=0;a[9660784]=a[9660784]|80;f=c[2433592]|0;g=c[f+(e*3148|0)+1068>>2]|0;do{if((g|0)==0){i=c[f+(e*3148|0)+3120>>2]|0;if((i|0)==0){j=0;k=0;l=e;m=f;break}n=gj[i&4095](-2)|0;i=c[3528554]|0;o=c[2433592]|0;p=c[o+(i*3148|0)+1068>>2]|0;q=(n&255)<<8;if((p|0)!=0){r=p;s=q;t=i;u=o;v=61229;break}p=c[o+(i*3148|0)+3120>>2]|0;if((p|0)==0){j=0;k=q;l=i;m=o;break}o=gj[p&4095](-1)|0;j=o;k=q;l=c[3528554]|0;m=c[2433592]|0}else{r=g;s=d[g+254|0]<<8;t=e;u=f;v=61229}}while(0);if((v|0)==61229){j=a[r+255|0]|0;k=s;l=t;m=u}u=j&255|k;c[2415188]=u;b[4830376]=u&65535;u=m+(l*3148|0)|0;if((u|0)!=0){m=u;gGC(m|0,9660752,48)|0}c[9731360+(l<<2)>>2]=c[2113158];c[3528554]=-1;mB(0);c[2443829]=1073676288;c[2443828]=1073676288;c[2443821]=1073676288;c[2443820]=1073676288;h[920261]=0.0;c[3528510]=0;if((c[2385514]|0)>0){l=0;do{lw(c[14163952+(l<<2)>>2]|0);l=l+1|0;}while((l|0)<(c[2385514]|0))}a[14108336]=0;a[14108328]=0;a[14108320]=0;a[14108312]=0;a[14108344]=0;a[9773168]=0;a[9757784]=0;a[14116032]=0}b[4775040]=-1;l=0;m=-1;do{m=((a[9634184+l|0]&1)<<l^m&65535)&65535;l=l+1|0;}while((l|0)<16);b[4775040]=m;m=c[2113160]|0;if((m|0)>0){gGz(9731360,0,((m|0)>1?m<<2:4)|0)}c[2113158]=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];m=c[3532592]|0;if((m|0)!=0){gGC(9104152,m|0,280)|0}c[2113054]=c[2113060]}c[3528554]=0;f43(c[2433592]|0);c[2113158]=c[9731360+(c[3528554]<<2)>>2];m=0;do{c[2113056]=1666;l=RG(1666)|0;c[2113054]=(c[2113054]|0)+l;c[2276108]=-1;c[2113056]=-1;do{if((m|0)==59){c[8452200+(c[2394]<<2)>>2]=8193;c[2276080]=256;if((c[2276079]|0)>>>0>=256){break}RH(1)}}while(0);T2(m*277|0);l=a[9773168]|0;if((a[9757784]|0)!=l<<24>>24){a[9757784]=l;a[14116032]=0}do{if((a[14108344]|0)!=0){u=a[14116032]|0;if((u&255)>(l&255)){a[14116032]=0;f44(0);f45(0)|0;a[9660786]=0;f45(0)|0;break}else{a[14116032]=u+1&255;break}}}while(0);m=m+1|0;}while((m|0)<60);m=c[2394]|0;l=c[14130368+(m<<2)>>2]|0;if((l|0)!=0){gGC(l|0,9104152,280)|0}c[8452240+(m<<2)>>2]=c[2113054];c[2394]=-1;m=c[2438226]|0;l=gGS(-137101312,7946,m,(m|0)<0|0?-1:0)|0;m=l;T2(16666);l=c[2443828]|0;if((l|0)<1073676288){c[2443828]=l-m}l=c[2443829]|0;if((l|0)<1073676288){c[2443829]=l-m}l=(c[3528510]|0)-m|0;c[3528510]=(l|0)<0?0:l;l=c[2112964]|0;if((l|0)!=0){m=a[9688]|0?534:0;mF(9756616,l,m,0);gg[c[3542190]&4095](l,m)}m=c[3528554]|0;l=(c[2433592]|0)+(m*3148|0)|0;if((l|0)!=0){u=l;gGC(u|0,9660752,48)|0}c[9731360+(m<<2)>>2]=c[2113158];c[3528554]=-1;if((c[2112968]|0)==0){return 0}dgz()|0;return 0}function dgz(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;if((a[9547848]|0)!=0){d=c[2387250]|0;f=c[3530142]|0;g=0;do{h=e[d+(g<<1)>>1]|0;i=h>>>8;c[f+(g<<2)>>2]=h>>>7&1|h&16|i<<3&96|i<<4&224|h>>>12<<8&2048;g=g+1|0;}while((g|0)<1024)}g=c[2439264]|0;if((b[g>>1]&1)==0){f=c[2112926]|0;gGz(f|0,0,ag(c[2443814]<<1,c[2440436]|0)|0)}else{dgD(c[3530296]|0,c[3530912]|0,768,512,2,0)}f=b[g>>1]|0;if((f&2)==0){j=f}else{dgD(c[2406508]|0,c[3530676]|0,512,256,0,1);j=b[g>>1]|0}if((j&8)==0){k=j}else{j=c[2386524]|0;f=c[3528768]|0;d=c[2112926]|0;h=c[3530358]|0;i=0;do{l=e[j+(i<<1)>>1]|0;m=e[j+((i|1)<<1)>>1]|0;n=e[j+((i|2)<<1)>>1]|0;o=(e[j+((i|3)<<1)>>1]|0)>>>12;p=n&16384;q=n&32768;r=(m&255)-(m&256)|0;m=(l&255)-(l&256)|0;l=n&4095;do{if(l>>>0<=2559){if((a[f]|0)==0){s=q;t=p;u=r;v=m}else{s=q^32768;t=p^16384;u=240-r|0;v=240-m|0}n=(t|0)!=0;w=v-16|0;if((s|0)==0){if(n){SJ(d,l,u,w,o,4,15,256,h);break}else{SH(d,l,u,w,o,4,15,256,h);break}}else{if(n){SN(d,l,u,w,o,4,15,256,h);break}else{SL(d,l,u,w,o,4,15,256,h);break}}}}while(0);i=i+4|0;}while((i|0)<1024);k=b[g>>1]|0}if((k&4)==0){x=c[3530142]|0;R8(x);return 0}k=c[2386338]|0;g=c[3528768]|0;i=c[2112926]|0;h=c[3530478]|0;u=0;do{d=u<<3&248;s=u>>5<<3;v=s-16|0;do{if(v>>>0<=224){t=e[k+(u<<1)>>1]|0;f=t&511;if((a[g]|0)==0){Sq(i,f,d,v,t>>>12,4,15,0,h);break}else{Sw(i,f,d^248,(s^248)-16|0,t>>>12,4,15,0,h);break}}}while(0);u=u+1|0;}while((u|0)<1024);x=c[3530142]|0;R8(x);return 0}function dgA(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;e=i;i=i+304|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;l=e+80|0;m=e+96|0;n=e+112|0;o=e+128|0;p=e+144|0;q=e+160|0;r=e+176|0;s=e+192|0;t=e+208|0;u=e+224|0;v=e+240|0;w=e+256|0;x=e+272|0;y=e+288|0;z=(d|0)==0;if(!z){c[d>>2]=169762}if((b&96|0)==0){i=e;return 0}gGz(y|0,0,12);A=c[2414766]|0;c[y>>2]=A;c[y+4>>2]=(c[2411822]|0)-A;c[y+12>>2]=162152;gj[c[2076592]&4095](y)|0;y=p|0;A=(b&64|0)==0;do{if(!A){gGz(o|0,0,16);c[2394]=-1;if((c[2392]|0)<0){break}B=p+9|0;C=n;D=n|0;E=n+4|0;F=n+12|0;G=o|0;H=o+4|0;I=o+12|0;J=0;do{gGC(y|0,614896,11)|0;a[B]=J+48&255;K=8452256+(J<<2)|0;gGz(C|0,0,12);c[D>>2]=K;c[E>>2]=4;c[F>>2]=164976;gj[c[2076592]&4095](n)|0;if((c[K>>2]|0)!=0){c[G>>2]=c[14130368+(J<<2)>>2];c[H>>2]=c[8452184+(J<<2)>>2];c[I>>2]=y;K=c[2076592]|0;gj[K&4095](o)|0}J=J+1|0;}while((J|0)<=(c[2392]|0))}}while(0);o=m|0;if((c[2113160]|0)>0&(A^1)){y=m+7|0;m=l|0;n=l+4|0;p=l+12|0;J=k;I=k|0;H=k+4|0;G=k+12|0;F=j;E=j|0;D=j+4|0;C=j+12|0;B=h;K=h|0;L=h+4|0;M=h+12|0;N=0;do{O=c[2433592]|0;P=O+(N*3148|0)+40|0;Q=c[P>>2]|0;gGC(o|0,614752,9)|0;a[y]=N+48&255;c[m>>2]=O+(N*3148|0);c[n>>2]=48;c[p>>2]=o;gj[c[2076592]&4095](l)|0;gGz(J|0,0,12);c[I>>2]=O+(N*3148|0)+3136;c[H>>2]=4;c[G>>2]=165288;gj[c[2076592]&4095](k)|0;gGz(F|0,0,12);c[E>>2]=O+(N*3148|0)+3140;c[D>>2]=4;c[C>>2]=501592;gj[c[2076592]&4095](j)|0;gGz(B|0,0,12);c[K>>2]=O+(N*3148|0)+3144;c[L>>2]=4;c[M>>2]=386080;gj[c[2076592]&4095](h)|0;c[P>>2]=Q;N=N+1|0;}while((N|0)<(c[2113160]|0))}N=g|0;do{if(!A){do{if(!z){if((c[d>>2]|0)>=169110){break}c[d>>2]=169110}}while(0);if((c[2113008]|0)<=0){break}g=f|0;h=f+4|0;M=f+8|0;L=f+12|0;K=0;do{cC(N|0,531144,(B=i,i=i+8|0,c[B>>2]=K,B)|0)|0;i=B;c[g>>2]=14168888+(K*252|0);c[h>>2]=252;c[M>>2]=0;c[L>>2]=N;gj[c[2076592]&4095](f)|0;K=K+1|0;}while((K|0)<(c[2113008]|0))}}while(0);Uc(b,d);gGz(x|0,0,12);c[x>>2]=14108336;c[x+4>>2]=1;c[x+12>>2]=585216;gj[c[2076592]&4095](x)|0;gGz(w|0,0,12);c[w>>2]=14108328;c[w+4>>2]=1;c[w+12>>2]=568736;gj[c[2076592]&4095](w)|0;gGz(v|0,0,12);c[v>>2]=14108320;c[v+4>>2]=1;c[v+12>>2]=552464;gj[c[2076592]&4095](v)|0;gGz(u|0,0,12);c[u>>2]=14108312;c[u+4>>2]=1;c[u+12>>2]=537992;gj[c[2076592]&4095](u)|0;gGz(t|0,0,12);c[t>>2]=9773168;c[t+4>>2]=1;c[t+12>>2]=524640;gj[c[2076592]&4095](t)|0;gGz(s|0,0,12);c[s>>2]=9757784;c[s+4>>2]=1;c[s+12>>2]=510992;gj[c[2076592]&4095](s)|0;gGz(r|0,0,12);c[r>>2]=14116032;c[r+4>>2]=1;c[r+12>>2]=498312;gj[c[2076592]&4095](r)|0;gGz(q|0,0,12);c[q>>2]=14108344;c[q+4>>2]=1;c[q+12>>2]=486448;gj[c[2076592]&4095](q)|0;i=e;return 0}function dgB(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1544804+(b*112|0)>>2];c[a+104>>2]=c[1544808+(b*112|0)>>2];c[a+108>>2]=c[1544812+(b*112|0)>>2];d=0;return d|0}function dgC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=1544704+(b*112|0);e=0;return e|0}function dgD(b,d,f,g,h,i){b=b|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;j=c[2409008]|0;k=e[j+(h+1<<1)>>1]|0;l=e[j+(h<<1)>>1]|0;h=b;b=(k&(g<<4)+2147483647)>>>4;j=g+134217727|0;g=l>>>4;m=l&15;l=k&15;k=c[3528768]|0;n=c[2112926]|0;if((i|0)==0){i=0;do{o=i>>4;p=i&15;q=(p<<4)-m|0;r=(o<<4)-l|0;s=e[h+(((o+b&j)<<5|p+g&31)<<1)>>1]|0;p=s&1023;o=s>>>12;if((a[k]|0)==0){Sz(n,p,r,q-16|0,o,4,f,d)}else{SF(n,p,240-r|0,224-q|0,o,4,f,d)}i=i+1|0;}while((i|0)<272);return}else{i=0;do{o=i>>4;q=i&15;r=(q<<4)-m|0;p=(o<<4)-l|0;s=e[h+(((o+b&j)<<5|q+g&31)<<1)>>1]|0;q=s&1023;o=s>>>12;if((a[k]|0)==0){SH(n,q,p,r-16|0,o,4,15,f,d)}else{SN(n,q,240-p|0,224-r|0,o,4,15,f,d)}i=i+1|0;}while((i|0)<272);return}}function dgE(a){a=a|0;var b=0,d=0;b=c[2113158]|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,1e6,0)|0;return a|0}function dgF(d){d=d|0;var e=0,f=0;e=d&65535;if((d-8192&65535)<4096){do{if(d<<16>>16==8265){if((b[4821352]|0)!=25185){break}if((a[(c[2443434]|0)+73|0]|0)==31){f=1}else{break}return f|0}}while(0);f=a[(c[2443434]|0)+(e-8192)|0]|0;return f|0}if(a[7303768]&(d&65535)>16383&d<<16>>16>-1){if(!((e|0)==21505|(e|0)==16385)){f=-1;return f|0}f=a[c[3527372]|0]|0;return f|0}switch(e|0){case 14340:{f=a[9658081]|0;return f|0};case 14336:{f=a[9625368]|0;return f|0};case 14339:{f=a[9658080]|0;return f|0};case 14338:{f=((a[9545168]|0)!=0?8:0)|a[9625272]|((a[9758104]|0)!=0?16:0);return f|0};case 14337:{f=a[9625320]|0;return f|0};default:{f=0;return f|0}}return 0}function dgG(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;do{if(a[7303768]|0){if(!((d&65535)>16383&d<<16>>16>-1)){break}f=d&65535;if(!((f|0)==21504|(f|0)==16384)){return}a[(c[3527372]|0)+1|0]=(e&255)>>>7|e<<7|(e&255)>>>1<<6&64|(e&255)>>>2<<5&32|(e&255)>>>3<<4&16|(e&255)>>>4<<3&8|(e&255)>>>5<<2&4|(e&255)>>>6<<1&2;return}}while(0);switch(d&65535|0){case 14348:{a[9642748]=0;return};case 14349:{a[9642747]=0;return};case 14350:{a[9758248]=e;d=c[2437750]|0;if((d|0)==5){c[3528554]=0;f43(c[2433592]|0);c[2113158]=c[9731360+(c[3528554]<<2)>>2];f44(0);f=c[3528554]|0;g=(c[2433592]|0)+(f*3148|0)|0;if((g|0)!=0){h=g;gGC(h|0,9660752,48)|0}c[9731360+(f<<2)>>2]=c[2113158];c[3528554]=-1;i=c[2437750]|0}else{i=d}if((i|0)!=4){return}i=c[2439331]|0;if((i|0)!=0){d=i;gGC(9706056,d|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;d=(c[2433530]|0)+12|0;c[2433530]=d;i=c[1836236]|0;f=c[9757320+(i<<2)>>2]|0;if((f|0)!=0){h=f;gGC(h|0,9706056,76)|0}c[9752472+(i<<2)>>2]=d;c[14113936+(i<<2)>>2]=c[2076596];c[9669104+(i<<2)>>2]=c[3541536];c[1836236]=-1;return};case 14346:{a[9773824]=e;return};case 14347:{if((a[9642761]|0)==0){return}a[9642761]=0;return};case 14344:{i=a[14119360]|0;d=(e&255)>>>5;a[14119360]=d;h=c[2443542]|0;f=c[3528552]|0;g=c[2433426]|0;j=((d&255)<<14)+16384|0;d=64;k=64;while(1){l=h+(j+(k<<8))|0;c[g+(f*3160|0)+60+(k<<2)>>2]=l;c[g+(f*3160|0)+60+(k+512<<2)>>2]=l;l=d+1&65535;if((l&65535)>127){break}else{d=l;k=l&65535}}k=e&255;b[4886924]=k<<8&256;b[4886916]=k<<7&256;do{if((k&16|0)==0){if((a[9758104]|0)!=0){break}d=c[2439524]|0;if((d|0)==1){if((a[9660902]|0)==1){break}a[9660902]=1;f00(-4);m=c[2439524]|0}else{m=d}if((m|0)==2){d=c[3528552]|0;f=c[2433426]|0;g=f+(d*3160|0)|0;if((g|0)!=0){j=g;gGC(j|0,9642704,60)|0}c[9721800+(d<<2)>>2]=c[2113194];c[3528552]=1;d=f+3160|0;if((d|0)!=0){f=d;gGC(9642704,f|0,60)|0}b[4821352]=c[2410676]&65535;fC1();f=(a[9642745]&1)==0;c[2430032]=f?1595912:1595656;c[2429672]=f?1114752:1114496;c[2429670]=f?1114240:1113984;c[2444186]=f?4654424:4654168;c[2113194]=c[9721800+(c[3528552]<<2)>>2];fC3();f=c[3528552]|0;d=c[2433426]|0;j=d+(f*3160|0)|0;if((j|0)==0){c[9721800+(f<<2)>>2]=c[2113194];c[3528552]=0;if((d|0)!=0){n=61397}}else{g=j;gGC(g|0,9642704,60)|0;c[9721800+(f<<2)>>2]=c[2113194];c[3528552]=0;n=61397}if((n|0)==61397){f=d;gGC(9642704,f|0,60)|0}b[4821352]=c[2410676]&65535;fC1();f=(a[9642745]&1)==0;c[2430032]=f?1595912:1595656;c[2429672]=f?1114752:1114496;c[2429670]=f?1114240:1113984;c[2444186]=f?4654424:4654168;c[2113194]=c[9721800+(c[3528552]<<2)>>2];o=c[2439524]|0}else{o=m}if((o|0)==3){if((a[9660902]|0)==1){break}a[9660902]=1;f00(-4);p=c[2439524]|0}else{p=o}if((p|0)!=4){break}f=c[2439330]|0;if((f|0)!=0){d=f;gGC(9706056,d|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;d=(c[2433530]|0)+12|0;c[2433530]=d;f=c[1836236]|0;g=c[9757320+(f<<2)>>2]|0;if((g|0)!=0){j=g;gGC(j|0,9706056,76)|0}c[9752472+(f<<2)>>2]=d;c[14113936+(f<<2)>>2]=c[2076596];c[9669104+(f<<2)>>2]=c[3541536];c[1836236]=-1}else{a[9758104]=0}}while(0);if(!(a[7303768]|0)){return}p=a[14119360]|0;o=p<<24>>24!=4;m=i<<24>>24==4;if(!(o|m)){i=c[3528552]|0;n=c[2433426]|0;k=64;f=64;while(1){c[n+(i*3160|0)+60+(f<<2)>>2]=0;c[n+(i*3160|0)+60+(f+256<<2)>>2]=0;c[n+(i*3160|0)+60+(f+512<<2)>>2]=0;d=k+1&65535;if((d&65535)>127){break}else{k=d;f=d&65535}}return}if(!(o&m)){return}m=c[2443542]|0;o=c[3528552]|0;f=c[2433426]|0;k=((p&255)<<14)+16384|0;p=64;i=64;while(1){n=m+(k+(i<<8))|0;c[f+(o*3160|0)+60+(i<<2)>>2]=n;c[f+(o*3160|0)+60+(i+512<<2)>>2]=n;n=p+1&65535;if((n&65535)>127){break}else{p=n;i=n&65535}}return};case 14345:{a[9773840]=e;return};default:{return}}}function dgH(d){d=d|0;var e=0,f=0;e=d&65535;if((d-32&65535)<4064){f=a[(c[2443396]|0)+(e-32)|0]|0;return f|0}if(!(d<<16>>16<0&(d&65535)<36864)){f=0;return f|0}do{if(d<<16>>16==-32695){if((b[4830442]|0)!=25185){break}if((a[(c[2443434]|0)+73|0]|0)==31){f=1}else{break}return f|0}}while(0);f=a[(c[2443434]|0)+(e-32768)|0]|0;return f|0}function dgI(d,e){d=d|0;e=e|0;var f=0;f=d&65535;if((d&65535)>=32){if((d&65535)<4096){a[(c[2443396]|0)+(f-32)|0]=e;return}if(!(d<<16>>16<0&(d&65535)<36864)){return}if(d<<16>>16==-32768){a[9758104]=1}a[(c[2443434]|0)+(f-32768)|0]=e;return}if(d<<16>>16!=23){return}if((e&3)==0){return}c[3528552]=0;e=c[2433426]|0;if((e|0)!=0){d=e;gGC(9642704,d|0,60)|0}b[4821352]=c[2410676]&65535;fC1();d=(a[9642745]&1)==0;c[2430032]=d?1595912:1595656;c[2429672]=d?1114752:1114496;c[2429670]=d?1114240:1113984;c[2444186]=d?4654424:4654168;c[2113194]=c[9721800+(c[3528552]<<2)>>2];a[9642747]=1;fC1();d=c[3528552]|0;e=(c[2433426]|0)+(d*3160|0)|0;if((e|0)!=0){f=e;gGC(f|0,9642704,60)|0}c[9721800+(d<<2)>>2]=c[2113194];c[3528552]=-1;if((a[9660902]|0)==0){return}a[9660902]=0;return}function dgJ(b){b=b|0;var d=0,e=0;d=b&65535;if((b-32&65535)<4064){e=a[(c[2443396]|0)+(d-32)|0]|0;return e|0}if(!(b<<16>>16<0&(b&65535)<36864)){e=0;return e|0}e=a[(c[2443434]|0)+(d-32768)|0]|0;return e|0}function dgK(d,e){d=d|0;e=e|0;var f=0,g=0,h=0;f=d&65535;if((d&65535)>=32){if((d&65535)<4096){a[(c[2443396]|0)+(f-32)|0]=e;return}if(!(d<<16>>16<0&(d&65535)<36864)){return}if(d<<16>>16==-32768){a[9758104]=1}a[(c[2443434]|0)+(f-32768)|0]=e;return}if(d<<16>>16!=23){return}if((e&3)==0){return}e=c[3528552]|0;d=c[2433426]|0;f=d+(e*3160|0)|0;if((f|0)==0){c[9721800+(e<<2)>>2]=c[2113194];c[3528552]=0;if((d|0)!=0){g=61500}}else{h=f;gGC(h|0,9642704,60)|0;c[9721800+(e<<2)>>2]=c[2113194];c[3528552]=0;g=61500}if((g|0)==61500){g=d;gGC(9642704,g|0,60)|0}b[4821352]=c[2410676]&65535;fC1();g=(a[9642745]&1)==0;c[2430032]=g?1595912:1595656;c[2429672]=g?1114752:1114496;c[2429670]=g?1114240:1113984;c[2444186]=g?4654424:4654168;c[2113194]=c[9721800+(c[3528552]<<2)>>2];a[9642747]=1;fC1();g=c[3528552]|0;d=c[2433426]|0;e=d+(g*3160|0)|0;if((e|0)!=0){h=e;gGC(h|0,9642704,60)|0}c[9721800+(g<<2)>>2]=c[2113194];c[3528552]=1;g=d+3160|0;if((g|0)!=0){d=g;gGC(9642704,d|0,60)|0}b[4821352]=c[2410676]&65535;fC1();d=(a[9642745]&1)==0;c[2430032]=d?1595912:1595656;c[2429672]=d?1114752:1114496;c[2429670]=d?1114240:1113984;c[2444186]=d?4654424:4654168;c[2113194]=c[9721800+(c[3528552]<<2)>>2];if((a[9642761]|0)==0){return}a[9642761]=0;return}function dgL(b){b=b|0;var d=0,e=0;d=b&65535;if((b-32&65535)<4064){e=a[(c[2443396]|0)+(d-32)|0]|0;return e|0}if(!(b<<16>>16<0&(b&65535)<36864)){e=0;return e|0}e=a[(c[2443434]|0)+(d-32768)|0]|0;return e|0}function dgM(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((b-32&65535)<4064){a[(c[2443396]|0)+(e-32)|0]=d;return}if(b<<16>>16<0&(b&65535)<36864){if(b<<16>>16==-32768){a[9758104]=1}a[(c[2443434]|0)+(e-32768)|0]=d;return}else{if((b&65535)>=32){return}f4S(b,d);return}}function dgN(d,e){d=d|0;e=e|0;var f=0,g=0,h=0;if((a[9660902]|0)!=0){a[9660902]=0}c[3528552]=0;e=c[2433426]|0;if((e|0)!=0){d=e;gGC(9642704,d|0,60)|0}b[4821352]=c[2410676]&65535;fC1();d=(a[9642745]&1)==0;c[2430032]=d?1595912:1595656;c[2429672]=d?1114752:1114496;c[2429670]=d?1114240:1113984;c[2444186]=d?4654424:4654168;c[2113194]=c[9721800+(c[3528552]<<2)>>2];a[9642747]=1;fC1();d=c[3528552]|0;e=(c[2433426]|0)+(d*3160|0)|0;if((e|0)==0){f=c[2113194]|0;g=9721800+(d<<2)|0;c[g>>2]=f;c[3528552]=-1;return}h=e;gGC(h|0,9642704,60)|0;f=c[2113194]|0;g=9721800+(d<<2)|0;c[g>>2]=f;c[3528552]=-1;return}function dgO(d,e){d=d|0;e=e|0;var f=0;f=d&65535;if((d+16384&65535)<1024){if(d<<16>>16==-16384){a[9758104]=1}a[(c[2443434]|0)+(f-49152)|0]=e;return}if(d<<16>>16!=-8192){return}c[3528552]=0;d=c[2433426]|0;if((d|0)!=0){e=d;gGC(9642704,e|0,60)|0}b[4821352]=c[2410676]&65535;fC1();e=(a[9642745]&1)==0;c[2430032]=e?1595912:1595656;c[2429672]=e?1114752:1114496;c[2429670]=e?1114240:1113984;c[2444186]=e?4654424:4654168;c[2113194]=c[9721800+(c[3528552]<<2)>>2];a[9642747]=1;fC1();e=c[3528552]|0;d=(c[2433426]|0)+(e*3160|0)|0;if((d|0)!=0){f=d;gGC(f|0,9642704,60)|0}c[9721800+(e<<2)>>2]=c[2113194];c[3528552]=-1;return}function dgP(b){b=b|0;var d=0,e=0;d=b&65535;if((d|0)==10241){e=c[(c[3531464]|0)+4240>>2]&255}else if((d|0)==4096){a[9660786]=0;e=a[9758248]|0}else if((d|0)==6144){e=(a[9774465]<<1)+(a[9774464]|0)&255}else{e=0}return e|0}function dgQ(b,d){b=b|0;d=d|0;switch(b&65535|0){case 14338:{c[3527486]=(d&255)<<9&65024;return};case 14341:{c[3527485]=(d&255)<<9&65024;return};case 14337:{a[9774465]=0;c[2415126]=9665376;c[2416346]=0;return};case 14336:{a[9774464]=0;c[2415126]=9662152;c[2415540]=0;return};case 14342:{a[9774464]=1;c[2415126]=9662152;c[2415540]=1;return};case 14340:{c[3527484]=(d&255)<<9&65024;return};case 14339:{c[3527487]=(d&255)<<9&65024;return};case 10240:{c[2113304]=d&255;return};case 14343:{a[9774465]=1;c[2415126]=9665376;c[2416346]=1;return};case 10241:{b=c[2113304]|0;a[14168504+b|0]=d;mv(0,b,d&255);return};default:{return}}}function dgR(b){b=b|0;var d=0,e=0;d=b&65535;if((d|0)==40960){e=a[9758248]|0}else if((d|0)==38912){e=c[2113156]&255}else if((d|0)==34817){e=c[(c[3531464]|0)+4240>>2]&255}else{e=0}return e|0}function dgS(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((e|0)==34816){c[2113304]=d&255;return}else if((e|0)==34817){b=c[2113304]|0;a[14168504+b|0]=d;mv(0,b,d&255);return}else if((e|0)==38912){Uv(0,d);return}else{return}}function dgT(b){b=b|0;var d=0;if((b&65535)>=8){d=0;return d|0}d=a[(c[3527372]|0)+(b&65535)|0]|0;return d|0}function dgU(b,d){b=b|0;d=d|0;if((b&65535)>=8){return}a[(c[3527372]|0)+(b&65535)|0]=d;return}function dgV(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7427908+(b*112|0)>>2];c[a+104>>2]=c[7427912+(b*112|0)>>2];c[a+108>>2]=c[7427916+(b*112|0)>>2];d=0;return d|0}function dgW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=7427808+(b*112|0);e=0;return e|0}function dgX(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6937120+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dgY(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>43){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7448384+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dgZ(){var a=0,b=0,d=0,e=0,f=0;c[2439524]=1;c[2437750]=5;c[2426808]=0;c[2443542]=0;c[2443394]=196608;c[2438754]=212992;c[2439656]=245760;c[2405714]=376832;c[2443544]=376832;c[2443396]=380928;c[2438756]=384976;c[2439950]=389072;c[2443434]=391120;c[2439968]=395216;c[2438774]=397264;c[2438768]=397776;c[2411820]=398288;c[2406546]=398288;c[2405826]=463824;c[3529598]=988112;c[3530140]=2036688;a=0;while(1){if((a|0)>=1024){break}b=9638528+(a<<2)|0;if((c[b>>2]|0)==0){d=61646;break}else{a=a+1|0}}do{if((d|0)==61646){a=gGq(2038224)|0;c[b>>2]=a;if((a|0)==0){break}c[2426808]=a;gGz(a|0,0,2038224);c[2443542]=a;c[2443394]=a+196608;c[2438754]=a+212992;c[2439656]=a+245760;e=a+376832|0;c[2405714]=e;c[2443544]=e;c[2443396]=a+380928;c[2438756]=a+384976;c[2439950]=a+389072;c[2443434]=a+391120;c[2439968]=a+395216;c[2438774]=a+397264;c[2438768]=a+397776;e=a+398288|0;c[2411820]=e;c[2406546]=e;c[2405826]=a+463824;c[3529598]=a+988112;c[3530140]=a+2036688;c[2414368]=a+2038224;if((dhA()|0)!=0){f=1;return f|0}dht();f=0;return f|0}}while(0);c[2426808]=0;f=1;return f|0}function dg_(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;c[2113196]=0;d=c[2433426]|0;if((d|0)!=0){gGr(d);c[2433426]=0}d=c[2439524]|0;do{if((d|0)==3|(d|0)==1){e=c[2437644]|0;if((e|0)==0){break}gGr(e);c[2437644]=0}}while(0);if(a[7303768]|0){c[2443666]=0;c[2385780]=0;c[3528996]=0}d=c[2437750]|0;do{if((d|0)==5){c[2113160]=0;e=c[2433592]|0;if((e|0)==0){f=5;break}gGr(e);c[2433592]=0;f=c[2437750]|0}else{f=d}}while(0);if((c[2439524]|0)==4|(f|0)==4){fwZ()}f=c[3531464]|0;c[f+44344>>2]=0;c[f+44348>>2]=0;if((f|0)!=0){gGr(f);c[3531464]=0}f=c[2406684]|0;if((f|0)!=0){gGr(f);c[2406684]=0}do{if((c[2437750]|0)==4){Uw(0)}else{c[2415126]=9662152;f=c[2408988]|0;if((f|0)!=0){gGz(9662152,0,3224);d=f;f=0;while(1){if((f|0)>=1024){break}g=9638528+(f<<2)|0;if((c[g>>2]|0)==(d|0)){h=61676;break}else{f=f+1|0}}if((h|0)==61676){gGr(d);c[g>>2]=0}c[2408988]=0}c[2415126]=9665376;f=c[2408989]|0;if((f|0)==0){break}gGz(9665376,0,3224);e=f;f=0;while(1){if((f|0)>=1024){break}i=9638528+(f<<2)|0;if((c[i>>2]|0)==(e|0)){h=61682;break}else{f=f+1|0}}if((h|0)==61682){gGr(e);c[i>>2]=0}c[2408989]=0}}while(0);c[2113070]=0;c[2113068]=0;i=c[2112926]|0;if((i|0)!=0){gGr(i);c[2112926]=0}i=c[2426808]|0;g=0;while(1){if((g|0)>=1024){h=61691;break}j=9638528+(g<<2)|0;if((c[j>>2]|0)==(i|0)){break}else{g=g+1|0}}if((h|0)==61691){c[2426808]=0;a[14119360]=0;a[9545168]=0;a[9758104]=0;a[9758248]=0;b[4886924]=0;b[4886916]=0;a[9773840]=0;a[9773824]=0;a[9774464]=0;a[9774465]=0;c[3527484]=0;c[3527485]=0;c[3527486]=0;c[3527487]=0;c[2443618]=0;c[2443619]=0;c[2439524]=0;c[2437750]=0;a[986960]=0;a[7303768]=0;return 0}gGr(i);c[j>>2]=0;c[2426808]=0;a[14119360]=0;a[9545168]=0;a[9758104]=0;a[9758248]=0;b[4886924]=0;b[4886916]=0;a[9773840]=0;a[9773824]=0;a[9774464]=0;a[9774465]=0;c[3527484]=0;c[3527485]=0;c[3527486]=0;c[3527487]=0;c[2443618]=0;c[2443619]=0;c[2439524]=0;c[2437750]=0;a[986960]=0;a[7303768]=0;return 0}function dg$(){var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0.0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;f=i;i=i+64|0;g=f|0;do{if((c[2437750]|0)==5){h=a[6518360]|0?3999712:0;c[2415126]=9662152;j=c[2415557]|0;k=j&3;if((k|0)==3){l=133;break}l=((h|0)/((h|0)/((c[2415554]|0)/(c[600992+((j>>>3&1)<<4)+(k<<2)>>2]|0)|0|0)|0|0)|0|0)/((c[2424]|0)/100|0|0)|0}else{l=272}}while(0);c[g>>2]=(l|0)/17|0;c[g+4>>2]=(l<<1|0)/17|0;c[g+8>>2]=(l*3|0|0)/17|0;c[g+12>>2]=(l<<2|0)/17|0;c[g+16>>2]=(l*5|0|0)/17|0;c[g+20>>2]=(l*6|0|0)/17|0;c[g+24>>2]=(l*7|0|0)/17|0;c[g+28>>2]=(l<<3|0)/17|0;c[g+32>>2]=(l*9|0|0)/17|0;c[g+36>>2]=(l*10|0|0)/17|0;c[g+40>>2]=(l*11|0|0)/17|0;c[g+44>>2]=(l*12|0|0)/17|0;c[g+48>>2]=(l*13|0|0)/17|0;c[g+52>>2]=(l*14|0|0)/17|0;c[g+56>>2]=(l*15|0|0)/17|0;c[g+60>>2]=(l<<4|0)/17|0;k=~~(+(l*240|0|0)/272.0);if((a[9624840]|0)!=0){dhy()}a[9625320]=-1;a[9625368]=-1;a[9625272]=-25;j=0;h=-1;m=-1;n=-25;do{h=(h&255)-((a[9759296+j|0]&1)<<j)&255;m=(m&255)-((a[9759104+j|0]&1)<<j)&255;n=(n&255)-((a[9758912+j|0]&1)<<j)&255;j=j+1|0;}while((j|0)<8);a[9625368]=h;a[9625320]=m;a[9625272]=n;o=+(c[2438]|0);n=~~((a[6518360]|0?69627.0:0.0)*o*.00390625);m=~~(o*+(c[2440490]|0)*.00390625);gGz(9776456,0,16);h=c[2113196]|0;if((h|0)>0){gGz(9721800,0,((h|0)>1?h<<2:4)|0)}c[2113194]=0;h=c[2439524]|0;if((h|0)==1){c[2113162]=0}else if((h|0)==3){c[2113162]=0}j=c[2437750]|0;if((h|0)==4|(j|0)==4){h=c[2385548]|0;if((h|0)>0){gGz(9752472,0,((h|0)>1?h<<2:4)|0)}c[2433530]=0}if((j|0)==5){j=c[2113160]|0;if((j|0)>0){gGz(9731360,0,((j|0)>1?j<<2:4)|0)}c[2113158]=0}if(a[7303768]|0){c[2415218]=0}a[9545168]=0;j=0;h=0;L72924:while(1){p=h;while(1){if((p|0)>=(l|0)){break L72924}c[3528552]=0;q=c[2433426]|0;if((q|0)!=0){r=q;gGC(9642704,r|0,60)|0}b[4821352]=c[2410676]&65535;fC1();r=(a[9642745]&1)==0;c[2430032]=r?1595912:1595656;c[2429672]=r?1114752:1114496;c[2429670]=r?1114240:1113984;c[2444186]=r?4654424:4654168;c[2113194]=c[9721800+(c[3528552]<<2)>>2];s=p+1|0;r=((ag(s,n)|0)>>>0)/(l>>>0)|0;q=r-(c[2444114]|0)|0;c[2438206]=q;r=fC4(q)|0;c[2113194]=(c[2113194]|0)+r;c[2444114]=(c[2444114]|0)+r;if((c[2437750]|0)==5){UD()}r=c[3528552]|0;q=(c[2433426]|0)+(r*3160|0)|0;if((q|0)!=0){t=q;gGC(t|0,9642704,60)|0}c[9721800+(r<<2)>>2]=c[2113194];c[3528552]=-1;r=c[2439524]|0;if((r|0)==1){t=((ag(s,m)|0)>>>0)/(l>>>0)|0;q=t-(c[2444115]|0)|0;c[2438206]=q;t=f4D(q)|0;c[2113162]=(c[2113162]|0)+t;c[2438206]=t;c[2444115]=(c[2444115]|0)+t;u=c[2439524]|0}else{u=r}if((u|0)==2){c[3528552]=1;r=(c[2433426]|0)+3160|0;if((r|0)!=0){t=r;gGC(9642704,t|0,60)|0}b[4821352]=c[2410676]&65535;fC1();t=(a[9642745]&1)==0;c[2430032]=t?1595912:1595656;c[2429672]=t?1114752:1114496;c[2429670]=t?1114240:1113984;c[2444186]=t?4654424:4654168;c[2113194]=c[9721800+(c[3528552]<<2)>>2];t=((ag(s,m)|0)>>>0)/(l>>>0)|0;r=t-(c[2444115]|0)|0;c[2438206]=r;t=fC4(r)|0;r=(c[2113194]|0)+t|0;c[2113194]=r;c[2438206]=t;c[2444115]=(c[2444115]|0)+t;t=c[3528552]|0;q=(c[2433426]|0)+(t*3160|0)|0;if((q|0)!=0){v=q;gGC(v|0,9642704,60)|0}c[9721800+(t<<2)>>2]=r;c[3528552]=-1;w=c[2439524]|0}else{w=u}if((w|0)==3){r=((ag(s,m)|0)>>>0)/(l>>>0)|0;t=r-(c[2444115]|0)|0;c[2438206]=t;r=f4c(t)|0;c[2113162]=(c[2113162]|0)+r;c[2438206]=r;c[2444115]=(c[2444115]|0)+r;x=c[2439524]|0}else{x=w}if((x|0)==4){r=c[2439330]|0;if((r|0)!=0){t=r;gGC(9706056,t|0,76)|0}b[4853030]=c[2426515]&65535;t=c[2438118]|0;c[2433530]=t;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;v=((ag(s,m)|0)>>>0)/(l>>>0)|0;q=c[2444115]|0;y=v-q|0;c[2438206]=y;do{if((y|0)<1){z=0;A=q;B=0;C=r;D=t}else{if((a[r+4188|0]|0)==0){v=gfc(y)|0;E=(c[2433530]|0)+v|0;c[2433530]=E;F=c[1836236]|0;z=v;A=c[2444115]|0;B=F;C=c[9757320+(F<<2)>>2]|0;D=E;break}else{E=t+y|0;c[2433530]=E;z=y;A=q;B=0;C=r;D=E;break}}}while(0);c[2438206]=z;c[2444115]=A+z;if((C|0)!=0){r=C;gGC(r|0,9706056,76)|0}c[9752472+(B<<2)>>2]=D;c[14113936+(B<<2)>>2]=c[2076596];c[9669104+(B<<2)>>2]=c[3541536];c[1836236]=-1}r=c[2437750]|0;if((r|0)==5){c[3528554]=0;f43(c[2433592]|0);c[2113158]=c[9731360+(c[3528554]<<2)>>2];q=(ag(c[2440478]|0,s)|0)/(l|0)|0;y=q-(c[2444116]|0)|0;c[2438206]=y;q=f45(y)|0;y=(c[2113158]|0)+q|0;c[2113158]=y;c[2444116]=(c[2444116]|0)+q;q=c[3528554]|0;t=(c[2433592]|0)+(q*3148|0)|0;if((t|0)!=0){E=t;gGC(E|0,9660752,48)|0}c[9731360+(q<<2)>>2]=y;c[3528554]=-1;G=c[2437750]|0}else{G=r}if((G|0)==4){r=c[2439331]|0;if((r|0)!=0){y=r;gGC(9706056,y|0,76)|0}b[4853030]=c[2426515]&65535;y=c[2438119]|0;c[2433530]=y;c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;q=(ag(c[2440478]|0,s)|0)/(l|0)|0;E=c[2444116]|0;t=q-E|0;c[2438206]=t;do{if((t|0)<1){H=0;I=E;J=1;K=r;L=y}else{if((a[r+4188|0]|0)==0){q=gfc(t)|0;F=(c[2433530]|0)+q|0;c[2433530]=F;v=c[1836236]|0;H=q;I=c[2444116]|0;J=v;K=c[9757320+(v<<2)>>2]|0;L=F;break}else{F=y+t|0;c[2433530]=F;H=t;I=E;J=1;K=r;L=F;break}}}while(0);c[2438206]=H;c[2444116]=I+H;if((K|0)!=0){r=K;gGC(r|0,9706056,76)|0}c[9752472+(J<<2)>>2]=L;c[14113936+(J<<2)>>2]=c[2076596];c[9669104+(J<<2)>>2]=c[3541536];c[1836236]=-1}if(a[7303768]|0){r=(ag(a[6517864]|0?69627:0,s)|0)/(l|0)|0;E=r-(c[2444117]|0)|0;c[2438206]=E;r=f4Y(E)|0;c[2438206]=r;c[2444117]=(c[2444117]|0)+r}if((p|0)==(k|0)){a[9545168]=1;c[3528552]=0;r=c[2433426]|0;if((r|0)!=0){E=r;gGC(9642704,E|0,60)|0}b[4821352]=c[2410676]&65535;fC1();E=(a[9642745]&1)==0;c[2430032]=E?1595912:1595656;c[2429672]=E?1114752:1114496;c[2429670]=E?1114240:1113984;c[2444186]=E?4654424:4654168;c[2113194]=c[9721800+(c[3528552]<<2)>>2];fC3();E=c[3528552]|0;r=(c[2433426]|0)+(E*3160|0)|0;if((r|0)!=0){t=r;gGC(t|0,9642704,60)|0}c[9721800+(E<<2)>>2]=c[2113194];c[3528552]=-1;M=0}else{M=0}do{if((p|0)==(c[g+(M<<2)>>2]|0)){c[3528552]=0;E=c[2433426]|0;if((E|0)!=0){t=E;gGC(9642704,t|0,60)|0}b[4821352]=c[2410676]&65535;fC1();t=(a[9642745]&1)==0;c[2430032]=t?1595912:1595656;c[2429672]=t?1114752:1114496;c[2429670]=t?1114240:1113984;c[2444186]=t?4654424:4654168;c[2113194]=c[9721800+(c[3528552]<<2)>>2];a[9642748]=1;fC1();t=c[3528552]|0;E=(c[2433426]|0)+(t*3160|0)|0;if((E|0)!=0){r=E;gGC(r|0,9642704,60)|0}c[9721800+(t<<2)>>2]=c[2113194];c[3528552]=-1}M=M+1|0;}while((M|0)<16);N=c[2112964]|0;if((N|0)==0){p=s}else{break}}p=((a[9688]|0?534:0)|0)/(l|0)|0;t=N+(j<<1<<1)|0;r=c[2437750]|0;if((r|0)==5){c[3528554]=0;f43(c[2433592]|0);c[2113158]=c[9731360+(c[3528554]<<2)>>2];gg[c[3542124]&4095](t,p);E=c[3528554]|0;y=(c[2433592]|0)+(E*3148|0)|0;if((y|0)!=0){F=y;gGC(F|0,9660752,48)|0}c[9731360+(E<<2)>>2]=c[2113158];c[3528554]=-1;O=c[2437750]|0}else{O=r}if((O|0)==4){r=c[2439331]|0;if((r|0)!=0){E=r;gGC(9706056,E|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;gg[c[3542124]&4095](t,p);E=c[1836236]|0;r=c[9757320+(E<<2)>>2]|0;if((r|0)!=0){F=r;gGC(F|0,9706056,76)|0}c[9752472+(E<<2)>>2]=c[2433530];c[14113936+(E<<2)>>2]=c[2076596];c[9669104+(E<<2)>>2]=c[3541536];c[1836236]=-1;Uu(0,t,p)}j=p+j|0;h=s}s=c[2112964]|0;do{if((s|0)!=0){h=a[9688]|0?534:0;O=h-j|0;N=s+(j<<1<<1)|0;if((h|0)==(j|0)){break}h=c[2437750]|0;if((h|0)==5){c[3528554]=0;f43(c[2433592]|0);c[2113158]=c[9731360+(c[3528554]<<2)>>2];gg[c[3542124]&4095](N,O);l=c[3528554]|0;M=(c[2433592]|0)+(l*3148|0)|0;if((M|0)!=0){g=M;gGC(g|0,9660752,48)|0}c[9731360+(l<<2)>>2]=c[2113158];c[3528554]=-1;P=c[2437750]|0}else{P=h}if((P|0)!=4){break}h=c[2439331]|0;if((h|0)!=0){l=h;gGC(9706056,l|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;gg[c[3542124]&4095](N,O);l=c[1836236]|0;h=c[9757320+(l<<2)>>2]|0;if((h|0)!=0){g=h;gGC(g|0,9706056,76)|0}c[9752472+(l<<2)>>2]=c[2433530];c[14113936+(l<<2)>>2]=c[2076596];c[9669104+(l<<2)>>2]=c[3541536];c[1836236]=-1;Uu(0,N,O)}}while(0);if((c[2437750]|0)==5&(c[2112964]|0)!=0){c[3528554]=0;f43(c[2433592]|0);c[2113158]=c[9731360+(c[3528554]<<2)>>2];Uz(0,c[2112964]|0,a[9688]|0?534:0);Uz(1,c[2112964]|0,a[9688]|0?534:0);P=c[3528554]|0;j=(c[2433592]|0)+(P*3148|0)|0;if((j|0)!=0){s=j;gGC(s|0,9660752,48)|0}c[9731360+(P<<2)>>2]=c[2113158];c[3528554]=-1}if((c[2112968]|0)==0){i=f;return 0}P=c[2112926]|0;gGz(P|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);s=c[2438774]|0;j=c[2438768]|0;O=c[3530140]|0;N=0;do{l=a[s+N|0]|0;g=a[j+N|0]|0;h=(((g&255)<<8|l&255)&65535)>>>4;c[O+(N<<2)>>2]=((g<<4|g&8)&255)>>>3|((l<<4|l&8)&255)<<8&63488|((h<<4&255|h&12)&255)<<3&2016;N=N+1|0;}while((N|0)<384);N=(d[9773840]|0)+(e[4886924]|0)&511;j=(d[9773824]|0)+(e[4886916]|0)&511;s=c[2439968]|0;h=c[2405826]|0;l=0;do{g=l<<4;M=l<<5&512|g&240;k=g-j|0;g=(k|0)<-16?k+512|0:k;k=g-8|0;if((g-25|0)>>>0<207){g=0;do{J=g<<4;L=(g&15|M|J&256)<<1;K=d[s+L|0]|0;H=K<<8&1792|d[s+(L|1)|0];L=K>>>3&7;I=J-N|0;J=(I|0)<-16?I+512|0:I;I=(K&64|0)==0;G=(K&128|0)!=0;do{if((J-17|0)>>>0<223){if(I){if(G){SC(P,H,J,k,L,4,256,h);break}else{Sy(P,H,J,k,L,4,256,h);break}}else{if(G){SE(P,H,J,k,L,4,256,h);break}else{SA(P,H,J,k,L,4,256,h);break}}}else{if(I){if(G){SD(P,H,J,k,L,4,256,h);break}else{Sz(P,H,J,k,L,4,256,h);break}}else{if(G){SF(P,H,J,k,L,4,256,h);break}else{SB(P,H,J,k,L,4,256,h);break}}}}while(0);g=g+1|0;}while((g|0)<32)}else{g=0;do{L=g<<4;J=(g&15|M|L&256)<<1;H=d[s+J|0]|0;G=H<<8&1792|d[s+(J|1)|0];J=H>>>3&7;I=L-N|0;L=(I|0)<-16?I+512|0:I;I=(H&128|0)!=0;do{if((H&64|0)==0){if(I){SD(P,G,L,k,J,4,256,h);break}else{Sz(P,G,L,k,J,4,256,h);break}}else{if(I){SF(P,G,L,k,J,4,256,h);break}else{SB(P,G,L,k,J,4,256,h);break}}}while(0);g=g+1|0;}while((g|0)<32)}l=l+1|0;}while((l|0)<32);l=c[2443434]|0;h=a[986960]|0;N=c[3529598]|0;s=0;do{j=d[l+(s+2049)|0]|0;L73101:do{if((j&128|0)!=0){g=240-(d[l+(s+2052)|0]|0)+(j<<7&256)|0;k=232-(d[l+(s+2048)|0]|0)+(j<<8&256)|0;M=j>>>4;J=M&3;L=j&8;G=j&4;I=d[l+(s+2050)|0]|0;if(h){Q=d[l+(s+2051)|0]|I<<8&7936;R=I>>>5}else{Q=d[l+(s+2051)|0]|I<<8&3840;R=I>>>4&7}I=Q&((M|-4)^3);if((J|0)==3){M=g-16|0;H=(g-33|0)>>>0<223;K=k-16|0;do{if(H){if((k-33|0)>>>0>=207){S=61926;break}B=(G|0)!=0;if((L|0)==0){if(B){SK(P,I,M,K,R,4,0,128,N);S=61934;break}else{SG(P,I,M,K,R,4,0,128,N);S=61933;break}}else{if(B){SM(P,I,M,K,R,4,0,128,N);S=61934;break}else{SI(P,I,M,K,R,4,0,128,N);S=61933;break}}}else{S=61926}}while(0);do{if((S|0)==61926){S=0;B=(G|0)!=0;if((L|0)==0){if(B){SL(P,I,M,K,R,4,0,128,N);S=61933;break}else{SH(P,I,M,K,R,4,0,128,N);S=61933;break}}else{if(B){SN(P,I,M,K,R,4,0,128,N);S=61933;break}else{SJ(P,I,M,K,R,4,0,128,N);S=61933;break}}}}while(0);if((S|0)==61933){S=0;if(H){S=61934}else{S=61942}}do{if((S|0)==61934){S=0;if((k-17|0)>>>0>=207){S=61942;break}B=(G|0)!=0;D=I+1|0;if((L|0)==0){if(B){SK(P,D,M,k,R,4,0,128,N);break}else{SG(P,D,M,k,R,4,0,128,N);break}}else{if(B){SM(P,D,M,k,R,4,0,128,N);break}else{SI(P,D,M,k,R,4,0,128,N);break}}}}while(0);do{if((S|0)==61942){S=0;H=(G|0)!=0;D=I+1|0;if((L|0)==0){if(H){SL(P,D,M,k,R,4,0,128,N);break}else{SH(P,D,M,k,R,4,0,128,N);break}}else{if(H){SN(P,D,M,k,R,4,0,128,N);break}else{SJ(P,D,M,k,R,4,0,128,N);break}}}}while(0);M=(g-17|0)>>>0<223;do{if(M){if((k-33|0)>>>0>=207){S=61958;break}D=(G|0)!=0;H=I+2|0;if((L|0)==0){if(D){SK(P,H,g,K,R,4,0,128,N);S=61966;break}else{SG(P,H,g,K,R,4,0,128,N);S=61965;break}}else{if(D){SM(P,H,g,K,R,4,0,128,N);S=61966;break}else{SI(P,H,g,K,R,4,0,128,N);S=61965;break}}}else{S=61958}}while(0);do{if((S|0)==61958){S=0;H=(G|0)!=0;D=I+2|0;if((L|0)==0){if(H){SL(P,D,g,K,R,4,0,128,N);S=61965;break}else{SH(P,D,g,K,R,4,0,128,N);S=61965;break}}else{if(H){SN(P,D,g,K,R,4,0,128,N);S=61965;break}else{SJ(P,D,g,K,R,4,0,128,N);S=61965;break}}}}while(0);if((S|0)==61965){S=0;if(M){S=61966}}do{if((S|0)==61966){S=0;if((k-17|0)>>>0>=207){break}K=(G|0)!=0;D=I+3|0;if((L|0)==0){if(K){SK(P,D,g,k,R,4,0,128,N);break L73101}else{SG(P,D,g,k,R,4,0,128,N);break L73101}}else{if(K){SM(P,D,g,k,R,4,0,128,N);break L73101}else{SI(P,D,g,k,R,4,0,128,N);break L73101}}}}while(0);M=(G|0)!=0;D=I+3|0;if((L|0)==0){if(M){SL(P,D,g,k,R,4,0,128,N);break}else{SH(P,D,g,k,R,4,0,128,N);break}}else{if(M){SN(P,D,g,k,R,4,0,128,N);break}else{SJ(P,D,g,k,R,4,0,128,N);break}}}else if((J|0)==0){do{if((g-17|0)>>>0<223){if((k-17|0)>>>0>=207){break}D=(G|0)!=0;if((L|0)==0){if(D){SK(P,I,g,k,R,4,0,128,N);break L73101}else{SG(P,I,g,k,R,4,0,128,N);break L73101}}else{if(D){SM(P,I,g,k,R,4,0,128,N);break L73101}else{SI(P,I,g,k,R,4,0,128,N);break L73101}}}}while(0);D=(G|0)!=0;if((L|0)==0){if(D){SL(P,I,g,k,R,4,0,128,N);break}else{SH(P,I,g,k,R,4,0,128,N);break}}else{if(D){SN(P,I,g,k,R,4,0,128,N);break}else{SJ(P,I,g,k,R,4,0,128,N);break}}}else if((J|0)==1){D=(g-17|0)>>>0<223;M=k-16|0;do{if(D){if((k-33|0)>>>0>=207){S=61862;break}K=(G|0)!=0;if((L|0)==0){if(K){SK(P,I,g,M,R,4,0,128,N);S=61870;break}else{SG(P,I,g,M,R,4,0,128,N);S=61869;break}}else{if(K){SM(P,I,g,M,R,4,0,128,N);S=61870;break}else{SI(P,I,g,M,R,4,0,128,N);S=61869;break}}}else{S=61862}}while(0);do{if((S|0)==61862){S=0;K=(G|0)!=0;if((L|0)==0){if(K){SL(P,I,g,M,R,4,0,128,N);S=61869;break}else{SH(P,I,g,M,R,4,0,128,N);S=61869;break}}else{if(K){SN(P,I,g,M,R,4,0,128,N);S=61869;break}else{SJ(P,I,g,M,R,4,0,128,N);S=61869;break}}}}while(0);if((S|0)==61869){S=0;if(D){S=61870}}do{if((S|0)==61870){S=0;if((k-17|0)>>>0>=207){break}M=(G|0)!=0;K=I+1|0;if((L|0)==0){if(M){SK(P,K,g,k,R,4,0,128,N);break L73101}else{SG(P,K,g,k,R,4,0,128,N);break L73101}}else{if(M){SM(P,K,g,k,R,4,0,128,N);break L73101}else{SI(P,K,g,k,R,4,0,128,N);break L73101}}}}while(0);D=(G|0)!=0;K=I+1|0;if((L|0)==0){if(D){SL(P,K,g,k,R,4,0,128,N);break}else{SH(P,K,g,k,R,4,0,128,N);break}}else{if(D){SN(P,K,g,k,R,4,0,128,N);break}else{SJ(P,K,g,k,R,4,0,128,N);break}}}else if((J|0)==2){K=g-16|0;do{if((g-33|0)>>>0<223){if((k-17|0)>>>0>=207){S=61894;break}D=(G|0)!=0;if((L|0)==0){if(D){SK(P,I,K,k,R,4,0,128,N);break}else{SG(P,I,K,k,R,4,0,128,N);break}}else{if(D){SM(P,I,K,k,R,4,0,128,N);break}else{SI(P,I,K,k,R,4,0,128,N);break}}}else{S=61894}}while(0);do{if((S|0)==61894){S=0;J=(G|0)!=0;if((L|0)==0){if(J){SL(P,I,K,k,R,4,0,128,N);break}else{SH(P,I,K,k,R,4,0,128,N);break}}else{if(J){SN(P,I,K,k,R,4,0,128,N);break}else{SJ(P,I,K,k,R,4,0,128,N);break}}}}while(0);do{if((g-17|0)>>>0<223){if((k-17|0)>>>0>=207){break}K=(G|0)!=0;J=I+2|0;if((L|0)==0){if(K){SK(P,J,g,k,R,4,0,128,N);break L73101}else{SG(P,J,g,k,R,4,0,128,N);break L73101}}else{if(K){SM(P,J,g,k,R,4,0,128,N);break L73101}else{SI(P,J,g,k,R,4,0,128,N);break L73101}}}}while(0);J=(G|0)!=0;K=I+2|0;if((L|0)==0){if(J){SL(P,K,g,k,R,4,0,128,N);break}else{SH(P,K,g,k,R,4,0,128,N);break}}else{if(J){SN(P,K,g,k,R,4,0,128,N);break}else{SJ(P,K,g,k,R,4,0,128,N);break}}}else{break}}}while(0);s=s+5|0;}while((s|0)<320);s=c[2439950]|0;N=c[2406546]|0;R=0;S=0;while(1){Q=R<<3;l=Q-8|0;j=(Q-9|0)>>>0>230;Q=0;K=S;while(1){J=K<<1;D=d[s+J|0]|0;M=D<<8&1792|d[s+(J|1)|0];J=h?M:M&1023;M=D>>>5;D=Q<<3;if((D-1|0)>>>0>246|j){Sr(P,J,D,l,M,4,0,0,N)}else{Sq(P,J,D,l,M,4,0,0,N)}M=Q+1|0;if((M|0)>=32){break}Q=M;K=K+1|0}K=R+1|0;if((K|0)<32){R=K;S=S+32|0}else{break}}R8(O);i=f;return 0}function dg0(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0;g=i;i=i+368|0;h=g|0;j=g+16|0;k=g+32|0;l=g+48|0;m=g+64|0;n=g+80|0;o=g+96|0;p=g+112|0;q=g+128|0;r=g+144|0;s=g+160|0;t=g+176|0;u=g+192|0;v=g+208|0;w=g+224|0;x=g+240|0;y=g+256|0;z=g+272|0;A=g+288|0;B=g+304|0;C=g+320|0;D=g+336|0;E=g+352|0;if((f|0)!=0){c[f>>2]=169753}if((e&32|0)!=0){gGz(E|0,0,12);F=c[2405714]|0;c[E>>2]=F;c[E+4>>2]=(c[2411820]|0)-F;c[E+12>>2]=162152;F=c[2076592]|0;gj[F&4095](E)|0}if((e&64|0)==0){i=g;return 0}fyq(e);E=c[2439524]|0;if((E|0)==1){fwv(e);G=c[2439524]|0}else{G=E}if((G|0)==3){fwv(e);H=c[2439524]|0}else{H=G}G=c[2437750]|0;if((H|0)==4|(G|0)==4){fw$(e);I=c[2437750]|0}else{I=G}do{if((I|0)==5){G=p|0;if((c[2113160]|0)<=0){break}H=p+7|0;E=o|0;F=o+4|0;J=o+12|0;K=n;L=n|0;M=n+4|0;N=n+12|0;O=m;P=m|0;Q=m+4|0;R=m+12|0;S=l;T=l|0;U=l+4|0;V=l+12|0;W=0;do{X=c[2433592]|0;Y=X+(W*3148|0)+40|0;Z=c[Y>>2]|0;gGC(G|0,614752,9)|0;a[H]=W+48&255;c[E>>2]=X+(W*3148|0);c[F>>2]=48;c[J>>2]=G;gj[c[2076592]&4095](o)|0;gGz(K|0,0,12);c[L>>2]=X+(W*3148|0)+3136;c[M>>2]=4;c[N>>2]=165288;gj[c[2076592]&4095](n)|0;gGz(O|0,0,12);c[P>>2]=X+(W*3148|0)+3140;c[Q>>2]=4;c[R>>2]=501592;gj[c[2076592]&4095](m)|0;gGz(S|0,0,12);c[T>>2]=X+(W*3148|0)+3144;c[U>>2]=4;c[V>>2]=386080;gj[c[2076592]&4095](l)|0;c[Y>>2]=Z;W=W+1|0;}while((W|0)<(c[2113160]|0))}}while(0);if(a[7303768]|0){l=c[2415207]|0;gGz(k|0,0,12);c[k>>2]=9660800;c[k+4>>2]=76;c[k+12>>2]=162384;m=c[2076592]|0;gj[m&4095](k)|0;c[2415207]=l}gGz(j|0,0,12);c[j>>2]=8453216;c[j+4>>2]=4;c[j+12>>2]=107480;gj[c[2076592]&4095](j)|0;gGz(h|0,0,12);c[h>>2]=14168504;c[h+4>>2]=256;c[h+12>>2]=476464;gj[c[2076592]&4095](h)|0;h=(e&2|0)==0;if(!h){j=0;do{mv(0,j,d[14168504+j|0]|0);j=j+1|0;}while((j|0)<256)}j=c[2437750]|0;if((j|0)==4){Ut(0);_=c[2437750]|0}else{_=j}if((_|0)==5){UE(e,f)}gGz(D|0,0,12);c[D>>2]=14119360;c[D+4>>2]=1;c[D+12>>2]=511192;gj[c[2076592]&4095](D)|0;gGz(C|0,0,12);c[C>>2]=9545168;c[C+4>>2]=1;c[C+12>>2]=449152;gj[c[2076592]&4095](C)|0;gGz(B|0,0,12);c[B>>2]=9758104;c[B+4>>2]=1;c[B+12>>2]=107080;gj[c[2076592]&4095](B)|0;gGz(A|0,0,12);c[A>>2]=9758248;c[A+4>>2]=1;c[A+12>>2]=497064;gj[c[2076592]&4095](A)|0;gGz(z|0,0,12);c[z>>2]=9773848;c[z+4>>2]=2;c[z+12>>2]=102408;gj[c[2076592]&4095](z)|0;gGz(y|0,0,12);c[y>>2]=9773832;c[y+4>>2]=2;c[y+12>>2]=99080;gj[c[2076592]&4095](y)|0;gGz(x|0,0,12);c[x>>2]=9773840;c[x+4>>2]=1;c[x+12>>2]=95568;gj[c[2076592]&4095](x)|0;gGz(w|0,0,12);c[w>>2]=9773824;c[w+4>>2]=1;c[w+12>>2]=92464;gj[c[2076592]&4095](w)|0;gGz(v|0,0,12);c[v>>2]=9774464;c[v+4>>2]=2;c[v+12>>2]=89696;gj[c[2076592]&4095](v)|0;gGz(u|0,0,12);c[u>>2]=14109936;c[u+4>>2]=8;c[u+12>>2]=88056;gj[c[2076592]&4095](u)|0;gGz(t|0,0,12);c[t>>2]=14109944;c[t+4>>2]=8;c[t+12>>2]=86248;gj[c[2076592]&4095](t)|0;gGz(s|0,0,12);c[s>>2]=9774472;c[s+4>>2]=8;c[s+12>>2]=84296;gj[c[2076592]&4095](s)|0;gGz(r|0,0,12);c[r>>2]=9776456;c[r+4>>2]=16;c[r+12>>2]=212472;gj[c[2076592]&4095](r)|0;gGz(q|0,0,12);c[q>>2]=9752824;c[q+4>>2]=4;c[q+12>>2]=436576;gj[c[2076592]&4095](q)|0;if(h){i=g;return 0}c[3528552]=0;h=c[2433426]|0;if((h|0)!=0){q=h;gGC(9642704,q|0,60)|0}b[4821352]=c[2410676]&65535;fC1();q=(a[9642745]&1)==0;c[2430032]=q?1595912:1595656;c[2429672]=q?1114752:1114496;c[2429670]=q?1114240:1113984;c[2444186]=q?4654424:4654168;q=c[3528552]|0;h=9721800+(q<<2)|0;c[2113194]=c[h>>2];r=c[2443542]|0;s=c[2433426]|0;t=(d[14119360]<<14)+16384|0;u=64;v=64;while(1){w=r+(t+(v<<8))|0;c[s+(q*3160|0)+60+(v<<2)>>2]=w;c[s+(q*3160|0)+60+(v+512<<2)>>2]=w;w=u+1&65535;if((w&65535)>127){break}else{u=w;v=w&65535}}v=s+(q*3160|0)|0;if((v|0)!=0){q=v;gGC(q|0,9642704,60)|0}c[h>>2]=c[2113194];c[3528552]=-1;if((a[9758104]|0)!=0){i=g;return 0}h=c[2439524]|0;do{if((h|0)==1){if((a[9660902]|0)==1){i=g;return 0}else{a[9660902]=1;f00(-4);$=c[2439524]|0;break}}else{$=h}}while(0);if(($|0)!=3|(a[9660902]|0)==1){i=g;return 0}a[9660902]=1;f00(-4);i=g;return 0}function dg1(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7220452+(b*112|0)>>2];c[a+104>>2]=c[7220456+(b*112|0)>>2];c[a+108>>2]=c[7220460+(b*112|0)>>2];d=0;return d|0}function dg2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=7220352+(b*112|0);e=0;return e|0}function dg3(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6894868+(b*112|0)>>2];c[a+104>>2]=c[6894872+(b*112|0)>>2];c[a+108>>2]=c[6894876+(b*112|0)>>2];d=0;return d|0}function dg4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=6894768+(b*112|0);e=0;return e|0}function dg5(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7232772+(b*112|0)>>2];c[a+104>>2]=c[7232776+(b*112|0)>>2];c[a+108>>2]=c[7232780+(b*112|0)>>2];d=0;return d|0}function dg6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=7232672+(b*112|0);e=0;return e|0}function dg7(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6900020+(b*112|0)>>2];c[a+104>>2]=c[6900024+(b*112|0)>>2];c[a+108>>2]=c[6900028+(b*112|0)>>2];d=0;return d|0}function dg8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=6899920+(b*112|0);e=0;return e|0}function dg9(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6897444+(b*112|0)>>2];c[a+104>>2]=c[6897448+(b*112|0)>>2];c[a+108>>2]=c[6897452+(b*112|0)>>2];d=0;return d|0}function dha(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=6897344+(b*112|0);e=0;return e|0}function dhb(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6919732+(b*112|0)>>2];c[a+104>>2]=c[6919736+(b*112|0)>>2];c[a+108>>2]=c[6919740+(b*112|0)>>2];d=0;return d|0}function dhc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=6919632+(b*112|0);e=0;return e|0}function dhd(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7289644+(b*112|0)>>2];c[a+104>>2]=c[7289648+(b*112|0)>>2];c[a+108>>2]=c[7289652+(b*112|0)>>2];d=0;return d|0}function dhe(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=7289544+(b*112|0);e=0;return e|0}function dhf(){var a=0,b=0,d=0,e=0,f=0;c[2439524]=2;c[2437750]=5;c[2426808]=0;c[2443542]=0;c[2443394]=196608;c[2438754]=212992;c[2439656]=245760;c[2405714]=376832;c[2443544]=376832;c[2443396]=380928;c[2438756]=384976;c[2439950]=389072;c[2443434]=391120;c[2439968]=395216;c[2438774]=397264;c[2438768]=397776;c[2411820]=398288;c[2406546]=398288;c[2405826]=463824;c[3529598]=988112;c[3530140]=2036688;a=0;while(1){if((a|0)>=1024){break}b=9638528+(a<<2)|0;if((c[b>>2]|0)==0){d=62124;break}else{a=a+1|0}}do{if((d|0)==62124){a=gGq(2038224)|0;c[b>>2]=a;if((a|0)==0){break}c[2426808]=a;gGz(a|0,0,2038224);c[2443542]=a;c[2443394]=a+196608;c[2438754]=a+212992;c[2439656]=a+245760;e=a+376832|0;c[2405714]=e;c[2443544]=e;c[2443396]=a+380928;c[2438756]=a+384976;c[2439950]=a+389072;c[2443434]=a+391120;c[2439968]=a+395216;c[2438774]=a+397264;c[2438768]=a+397776;e=a+398288|0;c[2411820]=e;c[2406546]=e;c[2405826]=a+463824;c[3529598]=a+988112;c[3530140]=a+2036688;c[2414368]=a+2038224;if((dhA()|0)!=0){f=1;return f|0}dht();c[2440490]=26110;f=0;return f|0}}while(0);c[2426808]=0;f=1;return f|0}function dhg(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6911220+(b*112|0)>>2];c[a+104>>2]=c[6911224+(b*112|0)>>2];c[a+108>>2]=c[6911228+(b*112|0)>>2];d=0;return d|0}function dhh(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<22&(d|0)==0)){e=1;return e|0}c[a>>2]=6911120+(b*112|0);e=0;return e|0}function dhi(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0;b=i;i=i+2400|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;l=b+360|0;m=b+472|0;n=b+480|0;o=b+592|0;p=b+600|0;q=b+712|0;r=b+720|0;s=b+832|0;t=b+840|0;u=b+952|0;v=b+960|0;w=b+1072|0;x=b+1080|0;y=b+1192|0;z=b+1200|0;A=b+1312|0;B=b+1320|0;C=b+1432|0;D=b+1440|0;E=b+1552|0;F=b+1560|0;G=b+1672|0;H=b+1680|0;I=b+1792|0;J=b+1800|0;K=b+1912|0;L=b+1920|0;M=b+2032|0;N=b+2040|0;O=b+2152|0;P=b+2160|0;Q=b+2272|0;R=b+2280|0;S=b+2392|0;c[2439524]=3;c[2437750]=5;c[2426808]=0;c[2443542]=0;c[2443394]=196608;c[2438754]=212992;c[2439656]=245760;c[2405714]=376832;c[2443544]=376832;c[2443396]=380928;c[2438756]=384976;c[2439950]=389072;c[2443434]=391120;c[2439968]=395216;c[2438774]=397264;c[2438768]=397776;c[2411820]=398288;c[2406546]=398288;c[2405826]=463824;c[3529598]=988112;c[3530140]=2036688;T=0;while(1){if((T|0)>=1024){break}U=9638528+(T<<2)|0;if((c[U>>2]|0)==0){V=62147;break}else{T=T+1|0}}do{if((V|0)==62147){T=gGq(2038224)|0;c[U>>2]=T;if((T|0)==0){break}c[2426808]=T;gGz(T|0,0,2038224);c[2443542]=T;c[2443394]=T+196608;c[2438754]=T+212992;c[2439656]=T+245760;W=T+376832|0;c[2405714]=W;c[2443544]=W;c[2443396]=T+380928;c[2438756]=T+384976;c[2439950]=T+389072;c[2443434]=T+391120;c[2439968]=T+395216;c[2438774]=T+397264;c[2438768]=T+397776;W=T+398288|0;c[2411820]=W;c[2406546]=W;c[2405826]=T+463824;c[3529598]=T+988112;c[3530140]=T+2036688;c[2414368]=T+2038224;T=0;while(1){if((T|0)>=1024){X=0;break}Y=9638528+(T<<2)|0;if((c[Y>>2]|0)==0){V=62152;break}else{T=T+1|0}}do{if((V|0)==62152){T=gGq(524288)|0;c[Y>>2]=T;if((T|0)==0){X=0;break}gGz(T|0,0,524288);X=T}}while(0);c[3529548]=X;T=c[2443542]|0;if((c[3542200]|0)==0){Z=1;i=b;return Z|0}W=R+108|0;c[W>>2]=0;_=R+100|0;c[_>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](R,0)|0;do{if((c[W>>2]|0)!=0){$=c[_>>2]|0;c[S>>2]=9534384;aa=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aa&16383](S,0,0)|0;if(($|0)<1){Z=1;i=b;return Z|0}if((gzL(T,0,0)|0)==0){break}else{Z=1}i=b;return Z|0}}while(0);T=(c[2443542]|0)+32768|0;if((c[3542200]|0)==0){Z=1;i=b;return Z|0}_=P+108|0;c[_>>2]=0;W=P+100|0;c[W>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](P,1)|0;do{if((c[_>>2]|0)!=0){$=c[W>>2]|0;c[Q>>2]=9534384;aa=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aa&16383](Q,1,0)|0;if(($|0)<1){Z=1;i=b;return Z|0}if((gzL(T,0,1)|0)==0){break}else{Z=1}i=b;return Z|0}}while(0);T=c[2443542]|0;W=T+98304|0;_=T+65536|0;gGC(W|0,_|0,32768)|0;if((c[3542200]|0)==0){Z=1;i=b;return Z|0}W=N+108|0;c[W>>2]=0;T=N+100|0;c[T>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](N,2)|0;do{if((c[W>>2]|0)!=0){$=c[T>>2]|0;c[O>>2]=9534384;aa=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aa&16383](O,2,0)|0;if(($|0)<1){Z=1;i=b;return Z|0}if((gzL(_,0,2)|0)==0){break}else{Z=1}i=b;return Z|0}}while(0);_=c[2443394]|0;if((c[3542200]|0)==0){Z=1;i=b;return Z|0}T=L+108|0;c[T>>2]=0;W=L+100|0;c[W>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](L,3)|0;do{if((c[T>>2]|0)!=0){$=c[W>>2]|0;c[M>>2]=9534384;aa=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aa&16383](M,3,0)|0;if(($|0)<1){Z=1;i=b;return Z|0}if((gzL(_,0,3)|0)==0){break}else{Z=1}i=b;return Z|0}}while(0);_=c[2438754]|0;if((c[3542200]|0)==0){Z=1;i=b;return Z|0}W=J+108|0;c[W>>2]=0;T=J+100|0;c[T>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](J,4)|0;do{if((c[W>>2]|0)!=0){$=c[T>>2]|0;c[K>>2]=9534384;aa=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aa&16383](K,4,0)|0;if(($|0)<1){Z=1;i=b;return Z|0}if((gzL(_,0,4)|0)==0){break}else{Z=1}i=b;return Z|0}}while(0);_=c[3529548]|0;if((c[3542200]|0)==0){Z=1;i=b;return Z|0}T=H+108|0;c[T>>2]=0;W=H+100|0;c[W>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](H,5)|0;do{if((c[T>>2]|0)!=0){$=c[W>>2]|0;c[I>>2]=9534384;aa=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aa&16383](I,5,0)|0;if(($|0)<1){Z=1;i=b;return Z|0}if((gzL(_,0,5)|0)==0){break}else{Z=1}i=b;return Z|0}}while(0);_=c[3529548]|0;W=c[2406546]|0;T=0;do{$=T<<6;gGz(W+$|0,0,64);aa=T<<8;ab=0;do{ac=1<<3-ab;ad=(c[1983672+(ab<<2)>>2]|0)+aa|0;ae=0;do{af=ad+(c[1238464+(ae<<2)>>2]|0)|0;ag=(ae<<3)+$|0;ah=0;do{ai=af+(c[6964280+(ah<<2)>>2]|0)|0;if(((d[_+((ai|0)/8|0)|0]|0)&128>>>((ai&7)>>>0)|0)!=0){ai=W+(ag+ah)|0;a[ai]=(d[ai]|0|ac)&255}ah=ah+1|0;}while((ah|0)<8);ae=ae+1|0;}while((ae|0)<8);ab=ab+1|0;}while((ab|0)<4);T=T+1|0;}while((T|0)<1024);gGz(_|0,0,524288);if((c[3542200]|0)==0){Z=1;i=b;return Z|0}T=F+108|0;c[T>>2]=0;W=F+100|0;c[W>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](F,6)|0;do{if((c[T>>2]|0)!=0){ab=c[W>>2]|0;c[G>>2]=9534384;$=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[$&16383](G,6,0)|0;if((ab|0)<1){Z=1;i=b;return Z|0}if((gzL(_,0,6)|0)==0){break}else{Z=1}i=b;return Z|0}}while(0);_=(c[3529548]|0)+65536|0;if((c[3542200]|0)==0){Z=1;i=b;return Z|0}W=D+108|0;c[W>>2]=0;T=D+100|0;c[T>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](D,7)|0;do{if((c[W>>2]|0)!=0){ab=c[T>>2]|0;c[E>>2]=9534384;$=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[$&16383](E,7,0)|0;if((ab|0)<1){Z=1;i=b;return Z|0}if((gzL(_,0,7)|0)==0){break}else{Z=1}i=b;return Z|0}}while(0);_=(c[3529548]|0)+131072|0;if((c[3542200]|0)==0){Z=1;i=b;return Z|0}T=B+108|0;c[T>>2]=0;W=B+100|0;c[W>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](B,8)|0;do{if((c[T>>2]|0)!=0){ab=c[W>>2]|0;c[C>>2]=9534384;$=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[$&16383](C,8,0)|0;if((ab|0)<1){Z=1;i=b;return Z|0}if((gzL(_,0,8)|0)==0){break}else{Z=1}i=b;return Z|0}}while(0);_=(c[3529548]|0)+196608|0;if((c[3542200]|0)==0){Z=1;i=b;return Z|0}W=z+108|0;c[W>>2]=0;T=z+100|0;c[T>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,9)|0;do{if((c[W>>2]|0)!=0){ab=c[T>>2]|0;c[A>>2]=9534384;$=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[$&16383](A,9,0)|0;if((ab|0)<1){Z=1;i=b;return Z|0}if((gzL(_,0,9)|0)==0){break}else{Z=1}i=b;return Z|0}}while(0);_=(c[3529548]|0)+262144|0;if((c[3542200]|0)==0){Z=1;i=b;return Z|0}T=x+108|0;c[T>>2]=0;W=x+100|0;c[W>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,10)|0;do{if((c[T>>2]|0)!=0){ab=c[W>>2]|0;c[y>>2]=9534384;$=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[$&16383](y,10,0)|0;if((ab|0)<1){Z=1;i=b;return Z|0}if((gzL(_,0,10)|0)==0){break}else{Z=1}i=b;return Z|0}}while(0);_=(c[3529548]|0)+327680|0;if((c[3542200]|0)==0){Z=1;i=b;return Z|0}W=v+108|0;c[W>>2]=0;T=v+100|0;c[T>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,11)|0;do{if((c[W>>2]|0)!=0){ab=c[T>>2]|0;c[w>>2]=9534384;$=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[$&16383](w,11,0)|0;if((ab|0)<1){Z=1;i=b;return Z|0}if((gzL(_,0,11)|0)==0){break}else{Z=1}i=b;return Z|0}}while(0);_=(c[3529548]|0)+393216|0;if((c[3542200]|0)==0){Z=1;i=b;return Z|0}T=t+108|0;c[T>>2]=0;W=t+100|0;c[W>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,12)|0;do{if((c[T>>2]|0)!=0){ab=c[W>>2]|0;c[u>>2]=9534384;$=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[$&16383](u,12,0)|0;if((ab|0)<1){Z=1;i=b;return Z|0}if((gzL(_,0,12)|0)==0){break}else{Z=1}i=b;return Z|0}}while(0);_=(c[3529548]|0)+458752|0;if((c[3542200]|0)==0){Z=1;i=b;return Z|0}W=r+108|0;c[W>>2]=0;T=r+100|0;c[T>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,13)|0;do{if((c[W>>2]|0)!=0){ab=c[T>>2]|0;c[s>>2]=9534384;$=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[$&16383](s,13,0)|0;if((ab|0)<1){Z=1;i=b;return Z|0}if((gzL(_,0,13)|0)==0){break}else{Z=1}i=b;return Z|0}}while(0);_=c[3529548]|0;T=c[3529598]|0;W=0;do{ab=W<<8;gGz(T+ab|0,0,256);$=W<<9;aa=0;do{ae=1<<3-aa;ac=(c[611168+(aa<<2)>>2]|0)+$|0;ad=0;do{ah=ac+(c[609008+(ad<<2)>>2]|0)|0;ag=(ad<<4)+ab|0;af=0;do{ai=ah+(c[610128+(af<<2)>>2]|0)|0;if(((d[_+((ai|0)/8|0)|0]|0)&128>>>((ai&7)>>>0)|0)!=0){ai=T+(ag+af)|0;a[ai]=(d[ai]|0|ae)&255}af=af+1|0;}while((af|0)<16);ad=ad+1|0;}while((ad|0)<16);aa=aa+1|0;}while((aa|0)<4);W=W+1|0;}while((W|0)<4096);gGz(_|0,0,524288);if((c[3542200]|0)==0){Z=1;i=b;return Z|0}W=p+108|0;c[W>>2]=0;T=p+100|0;c[T>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,14)|0;do{if((c[W>>2]|0)!=0){aa=c[T>>2]|0;c[q>>2]=9534384;ab=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ab&16383](q,14,0)|0;if((aa|0)<1){Z=1;i=b;return Z|0}if((gzL(_,0,14)|0)==0){break}else{Z=1}i=b;return Z|0}}while(0);_=(c[3529548]|0)+65536|0;if((c[3542200]|0)==0){Z=1;i=b;return Z|0}T=n+108|0;c[T>>2]=0;W=n+100|0;c[W>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,15)|0;do{if((c[T>>2]|0)!=0){aa=c[W>>2]|0;c[o>>2]=9534384;ab=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ab&16383](o,15,0)|0;if((aa|0)<1){Z=1;i=b;return Z|0}if((gzL(_,0,15)|0)==0){break}else{Z=1}i=b;return Z|0}}while(0);_=(c[3529548]|0)+131072|0;if((c[3542200]|0)==0){Z=1;i=b;return Z|0}W=l+108|0;c[W>>2]=0;T=l+100|0;c[T>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,16)|0;do{if((c[W>>2]|0)!=0){aa=c[T>>2]|0;c[m>>2]=9534384;ab=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ab&16383](m,16,0)|0;if((aa|0)<1){Z=1;i=b;return Z|0}if((gzL(_,0,16)|0)==0){break}else{Z=1}i=b;return Z|0}}while(0);_=(c[3529548]|0)+196608|0;if((c[3542200]|0)==0){Z=1;i=b;return Z|0}T=j+108|0;c[T>>2]=0;W=j+100|0;c[W>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,17)|0;do{if((c[T>>2]|0)!=0){aa=c[W>>2]|0;c[k>>2]=9534384;ab=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ab&16383](k,17,0)|0;if((aa|0)<1){Z=1;i=b;return Z|0}if((gzL(_,0,17)|0)==0){break}else{Z=1}i=b;return Z|0}}while(0);_=c[3529548]|0;W=c[2405826]|0;T=0;do{aa=T<<8;gGz(W+aa|0,0,256);ab=T<<9;$=0;do{ad=1<<3-$;ae=(c[1658032+($<<2)>>2]|0)+ab|0;ac=0;do{af=ae+(c[609008+(ac<<2)>>2]|0)|0;ag=(ac<<4)+aa|0;ah=0;do{ai=af+(c[610128+(ah<<2)>>2]|0)|0;if(((d[_+((ai|0)/8|0)|0]|0)&128>>>((ai&7)>>>0)|0)!=0){ai=W+(ag+ah)|0;a[ai]=(d[ai]|0|ad)&255}ah=ah+1|0;}while((ah|0)<16);ac=ac+1|0;}while((ac|0)<16);$=$+1|0;}while(($|0)<4);T=T+1|0;}while((T|0)<2048);T=c[2439656]|0;if((c[3542200]|0)==0){Z=1;i=b;return Z|0}W=g+108|0;c[W>>2]=0;_=g+100|0;c[_>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,18)|0;do{if((c[W>>2]|0)!=0){$=c[_>>2]|0;c[h>>2]=9534384;aa=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aa&16383](h,18,0)|0;if(($|0)<1){Z=1;i=b;return Z|0}if((gzL(T,0,18)|0)==0){break}else{Z=1}i=b;return Z|0}}while(0);T=(c[2439656]|0)+65536|0;if((c[3542200]|0)==0){Z=1;i=b;return Z|0}_=e+108|0;c[_>>2]=0;W=e+100|0;c[W>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,19)|0;do{if((c[_>>2]|0)!=0){$=c[W>>2]|0;c[f>>2]=9534384;aa=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aa&16383](f,19,0)|0;if(($|0)<1){Z=1;i=b;return Z|0}if((gzL(T,0,19)|0)==0){break}else{Z=1}i=b;return Z|0}}while(0);T=c[3529548]|0;W=0;while(1){if((W|0)>=1024){break}aj=9638528+(W<<2)|0;if((c[aj>>2]|0)==(T|0)){V=62267;break}else{W=W+1|0}}if((V|0)==62267){gGr(T);c[aj>>2]=0}c[3529548]=0;dht();Z=0;i=b;return Z|0}}while(0);c[2426808]=0;Z=1;i=b;return Z|0}function dhj(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7303876+(b*112|0)>>2];c[a+104>>2]=c[7303880+(b*112|0)>>2];c[a+108>>2]=c[7303884+(b*112|0)>>2];d=0;return d|0}function dhk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=7303776+(b*112|0);e=0;return e|0}function dhl(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>38){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7305792+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dhm(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0;e=i;i=i+2040|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;B=e+1200|0;C=e+1312|0;D=e+1320|0;E=e+1432|0;F=e+1440|0;G=e+1552|0;H=e+1560|0;I=e+1672|0;J=e+1680|0;K=e+1792|0;L=e+1800|0;M=e+1912|0;N=e+1920|0;O=e+2032|0;c[2439524]=4;c[2437750]=4;a[986960]=1;c[2443542]=0;c[2443394]=196608;c[2438754]=262144;c[3541206]=294912;c[2405714]=557056;c[2443544]=557056;c[2438756]=563200;c[2439950]=565248;c[2443434]=567296;c[2439968]=571392;c[2438774]=573440;c[2438768]=573952;c[2411820]=574464;c[2406546]=574464;c[2405826]=705536;c[3529598]=1229824;c[3530140]=2802688;P=gGq(2804224)|0;c[2426808]=P;if((P|0)==0){Q=1;i=e;return Q|0}gGz(P|0,0,2804224);c[2443542]=P;c[2443394]=P+196608;c[2438754]=P+262144;c[3541206]=P+294912;R=P+557056|0;c[2405714]=R;c[2443544]=R;c[2438756]=P+563200;c[2439950]=P+565248;c[2443434]=P+567296;c[2439968]=P+571392;c[2438774]=P+573440;c[2438768]=P+573952;R=P+574464|0;c[2411820]=R;c[2406546]=R;c[2405826]=P+705536;c[3529598]=P+1229824;c[3530140]=P+2802688;c[2414368]=P+2804224;P=0;while(1){if((P|0)>=1024){S=0;break}T=9638528+(P<<2)|0;if((c[T>>2]|0)==0){U=62355;break}else{P=P+1|0}}do{if((U|0)==62355){P=gGq(786432)|0;c[T>>2]=P;if((P|0)==0){S=0;break}gGz(P|0,0,786432);S=P}}while(0);c[3529548]=S;S=c[2443542]|0;if((c[3542200]|0)==0){Q=1;i=e;return Q|0}T=N+108|0;c[T>>2]=0;P=N+100|0;c[P>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](N,0)|0;do{if((c[T>>2]|0)!=0){N=c[P>>2]|0;c[O>>2]=9534384;R=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[R&16383](O,0,0)|0;if((N|0)<1){Q=1;i=e;return Q|0}if((gzL(S,0,0)|0)==0){break}else{Q=1}i=e;return Q|0}}while(0);S=(c[2443542]|0)+32768|0;if((c[3542200]|0)==0){Q=1;i=e;return Q|0}O=L+108|0;c[O>>2]=0;P=L+100|0;c[P>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](L,1)|0;do{if((c[O>>2]|0)!=0){L=c[P>>2]|0;c[M>>2]=9534384;T=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[T&16383](M,1,0)|0;if((L|0)<1){Q=1;i=e;return Q|0}if((gzL(S,0,1)|0)==0){break}else{Q=1}i=e;return Q|0}}while(0);S=(c[2443542]|0)+65536|0;if((c[3542200]|0)==0){Q=1;i=e;return Q|0}M=J+108|0;c[M>>2]=0;P=J+100|0;c[P>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](J,2)|0;do{if((c[M>>2]|0)!=0){J=c[P>>2]|0;c[K>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](K,2,0)|0;if((J|0)<1){Q=1;i=e;return Q|0}if((gzL(S,0,2)|0)==0){break}else{Q=1}i=e;return Q|0}}while(0);S=(c[2443542]|0)+98304|0;if((c[3542200]|0)==0){Q=1;i=e;return Q|0}K=H+108|0;c[K>>2]=0;P=H+100|0;c[P>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](H,3)|0;do{if((c[K>>2]|0)!=0){H=c[P>>2]|0;c[I>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](I,3,0)|0;if((H|0)<1){Q=1;i=e;return Q|0}if((gzL(S,0,3)|0)==0){break}else{Q=1}i=e;return Q|0}}while(0);S=c[2443394]|0;if((c[3542200]|0)==0){Q=1;i=e;return Q|0}I=F+108|0;c[I>>2]=0;P=F+100|0;c[P>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](F,4)|0;do{if((c[I>>2]|0)!=0){F=c[P>>2]|0;c[G>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](G,4,0)|0;if((F|0)<1){Q=1;i=e;return Q|0}if((gzL(S,0,4)|0)==0){break}else{Q=1}i=e;return Q|0}}while(0);S=c[2438754]|0;if((c[3542200]|0)==0){Q=1;i=e;return Q|0}G=D+108|0;c[G>>2]=0;P=D+100|0;c[P>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](D,5)|0;do{if((c[G>>2]|0)!=0){D=c[P>>2]|0;c[E>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](E,5,0)|0;if((D|0)<1){Q=1;i=e;return Q|0}if((gzL(S,0,5)|0)==0){break}else{Q=1}i=e;return Q|0}}while(0);S=c[3529548]|0;if((c[3542200]|0)==0){Q=1;i=e;return Q|0}E=B+108|0;c[E>>2]=0;P=B+100|0;c[P>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](B,6)|0;do{if((c[E>>2]|0)!=0){B=c[P>>2]|0;c[C>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](C,6,0)|0;if((B|0)<1){Q=1;i=e;return Q|0}if((gzL(S,0,6)|0)==0){break}else{Q=1}i=e;return Q|0}}while(0);S=c[3529548]|0;C=c[2406546]|0;P=0;do{E=P<<6;gGz(C+E|0,0,64);B=P<<8;G=0;do{D=1<<3-G;I=(c[1983672+(G<<2)>>2]|0)+B|0;F=0;do{K=I+(c[1238464+(F<<2)>>2]|0)|0;H=(F<<3)+E|0;M=0;do{J=K+(c[6964280+(M<<2)>>2]|0)|0;if(((d[S+((J|0)/8|0)|0]|0)&128>>>((J&7)>>>0)|0)!=0){J=C+(H+M)|0;a[J]=(d[J]|0|D)&255}M=M+1|0;}while((M|0)<8);F=F+1|0;}while((F|0)<8);G=G+1|0;}while((G|0)<4);P=P+1|0;}while((P|0)<2048);gGz(S|0,0,786432);if((c[3542200]|0)==0){Q=1;i=e;return Q|0}P=z+108|0;c[P>>2]=0;C=z+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,7)|0;do{if((c[P>>2]|0)!=0){z=c[C>>2]|0;c[A>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](A,7,0)|0;if((z|0)<1){Q=1;i=e;return Q|0}if((gzL(S,0,7)|0)==0){break}else{Q=1}i=e;return Q|0}}while(0);S=(c[3529548]|0)+131072|0;if((c[3542200]|0)==0){Q=1;i=e;return Q|0}A=x+108|0;c[A>>2]=0;C=x+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,8)|0;do{if((c[A>>2]|0)!=0){x=c[C>>2]|0;c[y>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](y,8,0)|0;if((x|0)<1){Q=1;i=e;return Q|0}if((gzL(S,0,8)|0)==0){break}else{Q=1}i=e;return Q|0}}while(0);S=(c[3529548]|0)+262144|0;if((c[3542200]|0)==0){Q=1;i=e;return Q|0}y=v+108|0;c[y>>2]=0;C=v+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,9)|0;do{if((c[y>>2]|0)!=0){v=c[C>>2]|0;c[w>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](w,9,0)|0;if((v|0)<1){Q=1;i=e;return Q|0}if((gzL(S,0,9)|0)==0){break}else{Q=1}i=e;return Q|0}}while(0);S=(c[3529548]|0)+393216|0;if((c[3542200]|0)==0){Q=1;i=e;return Q|0}w=t+108|0;c[w>>2]=0;C=t+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,10)|0;do{if((c[w>>2]|0)!=0){t=c[C>>2]|0;c[u>>2]=9534384;y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[y&16383](u,10,0)|0;if((t|0)<1){Q=1;i=e;return Q|0}if((gzL(S,0,10)|0)==0){break}else{Q=1}i=e;return Q|0}}while(0);S=(c[3529548]|0)+524288|0;if((c[3542200]|0)==0){Q=1;i=e;return Q|0}u=r+108|0;c[u>>2]=0;C=r+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,11)|0;do{if((c[u>>2]|0)!=0){r=c[C>>2]|0;c[s>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](s,11,0)|0;if((r|0)<1){Q=1;i=e;return Q|0}if((gzL(S,0,11)|0)==0){break}else{Q=1}i=e;return Q|0}}while(0);S=(c[3529548]|0)+655360|0;if((c[3542200]|0)==0){Q=1;i=e;return Q|0}s=p+108|0;c[s>>2]=0;C=p+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,12)|0;do{if((c[s>>2]|0)!=0){p=c[C>>2]|0;c[q>>2]=9534384;u=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[u&16383](q,12,0)|0;if((p|0)<1){Q=1;i=e;return Q|0}if((gzL(S,0,12)|0)==0){break}else{Q=1}i=e;return Q|0}}while(0);S=c[3529548]|0;q=c[3529598]|0;C=0;do{s=C<<8;gGz(q+s|0,0,256);p=C<<9;u=0;do{r=1<<3-u;w=(c[704216+(u<<2)>>2]|0)+p|0;t=0;do{y=w+(c[609008+(t<<2)>>2]|0)|0;v=(t<<4)+s|0;A=0;do{x=y+(c[610128+(A<<2)>>2]|0)|0;if(((d[S+((x|0)/8|0)|0]|0)&128>>>((x&7)>>>0)|0)!=0){x=q+(v+A)|0;a[x]=(d[x]|0|r)&255}A=A+1|0;}while((A|0)<16);t=t+1|0;}while((t|0)<16);u=u+1|0;}while((u|0)<4);C=C+1|0;}while((C|0)<6144);gGz(S|0,0,786432);if((c[3542200]|0)==0){Q=1;i=e;return Q|0}C=n+108|0;c[C>>2]=0;q=n+100|0;c[q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,13)|0;do{if((c[C>>2]|0)!=0){n=c[q>>2]|0;c[o>>2]=9534384;u=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[u&16383](o,13,0)|0;if((n|0)<1){Q=1;i=e;return Q|0}if((gzL(S,0,13)|0)==0){break}else{Q=1}i=e;return Q|0}}while(0);S=(c[3529548]|0)+131072|0;if((c[3542200]|0)==0){Q=1;i=e;return Q|0}o=l+108|0;c[o>>2]=0;q=l+100|0;c[q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,14)|0;do{if((c[o>>2]|0)!=0){l=c[q>>2]|0;c[m>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](m,14,0)|0;if((l|0)<1){Q=1;i=e;return Q|0}if((gzL(S,0,14)|0)==0){break}else{Q=1}i=e;return Q|0}}while(0);S=c[3529548]|0;m=c[2405826]|0;q=0;do{o=q<<8;gGz(m+o|0,0,256);l=q<<9;C=0;do{n=1<<3-C;u=(c[1658032+(C<<2)>>2]|0)+l|0;s=0;do{p=u+(c[609008+(s<<2)>>2]|0)|0;t=(s<<4)+o|0;r=0;do{w=p+(c[610128+(r<<2)>>2]|0)|0;if(((d[S+((w|0)/8|0)|0]|0)&128>>>((w&7)>>>0)|0)!=0){w=m+(t+r)|0;a[w]=(d[w]|0|n)&255}r=r+1|0;}while((r|0)<16);s=s+1|0;}while((s|0)<16);C=C+1|0;}while((C|0)<4);q=q+1|0;}while((q|0)<2048);q=c[3541206]|0;if((c[3542200]|0)==0){Q=1;i=e;return Q|0}m=j+108|0;c[m>>2]=0;S=j+100|0;c[S>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,15)|0;do{if((c[m>>2]|0)!=0){j=c[S>>2]|0;c[k>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](k,15,0)|0;if((j|0)<1){Q=1;i=e;return Q|0}if((gzL(q,0,15)|0)==0){break}else{Q=1}i=e;return Q|0}}while(0);q=(c[3541206]|0)+131072|0;if((c[3542200]|0)==0){Q=1;i=e;return Q|0}k=f+108|0;c[k>>2]=0;S=f+100|0;c[S>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,16)|0;do{if((c[k>>2]|0)!=0){f=c[S>>2]|0;c[g>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](g,16,0)|0;if((f|0)<1){Q=1;i=e;return Q|0}if((gzL(q,0,16)|0)==0){break}else{Q=1}i=e;return Q|0}}while(0);q=c[3529548]|0;g=0;while(1){if((g|0)>=1024){break}V=9638528+(g<<2)|0;if((c[V>>2]|0)==(q|0)){U=62458;break}else{g=g+1|0}}if((U|0)==62458){gGr(q);c[V>>2]=0}c[3529548]=0;c[3528552]=-1;c[2113196]=1;V=gGq(3160)|0;q=V;c[2433426]=q;if((V|0)==0){c[3528552]=0}else{gGz(V|0,0,3160);c[V+3132>>2]=2102;c[V+3136>>2]=2420;c[V+3140>>2]=1856;c[V+3144>>2]=1450;c[2430450]=0;U=0;do{c[q+60+(U<<2)>>2]=0;U=U+1|0;}while((U|0)<768);c[2113194]=0;U=c[2427044]|0;c[9681616+(U<<3)>>2]=726904;c[9681620+(U<<3)>>2]=0;c[2427044]=U+1;c[3528552]=0;gGC(9642704,V|0,60)|0}b[4821352]=c[2410676]&65535;fC1();V=(a[9642745]&1)==0;c[2430032]=V?1595912:1595656;c[2429672]=V?1114752:1114496;c[2429670]=V?1114240:1113984;c[2444186]=V?4654424:4654168;V=c[3528552]|0;U=9721800+(V<<2)|0;c[2113194]=c[U>>2];q=c[2443544]|0;g=c[2433426]|0;S=0;k=0;while(1){f=q+(k<<8)|0;c[g+(V*3160|0)+60+(k<<2)>>2]=f;c[g+(V*3160|0)+60+(k+256<<2)>>2]=f;c[g+(V*3160|0)+60+(k+512<<2)>>2]=f;f=S+1&65535;if((f&65535)>23){break}else{S=f;k=f&65535}}k=c[2439950]|0;c[g+(V*3160|0)+156>>2]=k;c[g+(V*3160|0)+1180>>2]=k;c[g+(V*3160|0)+2204>>2]=k;S=k+256|0;c[g+(V*3160|0)+160>>2]=S;c[g+(V*3160|0)+1184>>2]=S;c[g+(V*3160|0)+2208>>2]=S;S=k+512|0;c[g+(V*3160|0)+164>>2]=S;c[g+(V*3160|0)+1188>>2]=S;c[g+(V*3160|0)+2212>>2]=S;S=k+768|0;c[g+(V*3160|0)+168>>2]=S;c[g+(V*3160|0)+1192>>2]=S;c[g+(V*3160|0)+2216>>2]=S;S=k+1024|0;c[g+(V*3160|0)+172>>2]=S;c[g+(V*3160|0)+1196>>2]=S;c[g+(V*3160|0)+2220>>2]=S;S=k+1280|0;c[g+(V*3160|0)+176>>2]=S;c[g+(V*3160|0)+1200>>2]=S;c[g+(V*3160|0)+2224>>2]=S;S=k+1536|0;c[g+(V*3160|0)+180>>2]=S;c[g+(V*3160|0)+1204>>2]=S;c[g+(V*3160|0)+2228>>2]=S;S=k+1792|0;c[g+(V*3160|0)+184>>2]=S;c[g+(V*3160|0)+1208>>2]=S;c[g+(V*3160|0)+2232>>2]=S;S=c[2443434]|0;k=32;q=32;while(1){c[g+(V*3160|0)+60+(q+256<<2)>>2]=S+((q<<8)-8192);f=k+1&65535;if((f&65535)>47){break}else{k=f;q=f&65535}}q=c[2439968]|0;c[g+(V*3160|0)+252>>2]=q;c[g+(V*3160|0)+1276>>2]=q;c[g+(V*3160|0)+2300>>2]=q;k=q+256|0;c[g+(V*3160|0)+256>>2]=k;c[g+(V*3160|0)+1280>>2]=k;c[g+(V*3160|0)+2304>>2]=k;k=q+512|0;c[g+(V*3160|0)+260>>2]=k;c[g+(V*3160|0)+1284>>2]=k;c[g+(V*3160|0)+2308>>2]=k;k=q+768|0;c[g+(V*3160|0)+264>>2]=k;c[g+(V*3160|0)+1288>>2]=k;c[g+(V*3160|0)+2312>>2]=k;k=q+1024|0;c[g+(V*3160|0)+268>>2]=k;c[g+(V*3160|0)+1292>>2]=k;c[g+(V*3160|0)+2316>>2]=k;k=q+1280|0;c[g+(V*3160|0)+272>>2]=k;c[g+(V*3160|0)+1296>>2]=k;c[g+(V*3160|0)+2320>>2]=k;k=q+1536|0;c[g+(V*3160|0)+276>>2]=k;c[g+(V*3160|0)+1300>>2]=k;c[g+(V*3160|0)+2324>>2]=k;k=q+1792|0;c[g+(V*3160|0)+280>>2]=k;c[g+(V*3160|0)+1304>>2]=k;c[g+(V*3160|0)+2328>>2]=k;k=c[2438774]|0;c[g+(V*3160|0)+300>>2]=k;c[g+(V*3160|0)+1324>>2]=k;c[g+(V*3160|0)+2348>>2]=k;q=k+256|0;c[g+(V*3160|0)+304>>2]=q;c[g+(V*3160|0)+1328>>2]=q;c[g+(V*3160|0)+2352>>2]=q;q=c[2438768]|0;c[g+(V*3160|0)+308>>2]=q;c[g+(V*3160|0)+1332>>2]=q;c[g+(V*3160|0)+2356>>2]=q;k=q+256|0;c[g+(V*3160|0)+312>>2]=k;c[g+(V*3160|0)+1336>>2]=k;c[g+(V*3160|0)+2360>>2]=k;k=c[2443542]|0;q=64;S=64;while(1){f=k+((S<<8)+16384)|0;c[g+(V*3160|0)+60+(S<<2)>>2]=f;c[g+(V*3160|0)+60+(S+512<<2)>>2]=f;f=q+1&65535;if((f&65535)>127){W=128;X=128;break}else{q=f;S=f&65535}}while(1){S=k+((X<<8)-32768)|0;c[g+(V*3160|0)+60+(X<<2)>>2]=S;c[g+(V*3160|0)+60+(X+512<<2)>>2]=S;S=W+1&65535;if((S&65535)>255){break}else{W=S;X=S&65535}}c[g+(V*3160|0)+3132>>2]=2032;c[g+(V*3160|0)+3136>>2]=3374;X=g+(V*3160|0)|0;if((X|0)!=0){V=X;gGC(V|0,9642704,60)|0}c[U>>2]=c[2113194];c[3528552]=-1;fwR(0);U=c[2439330]|0;V=(U|0)==0;if(!V){X=U;gGC(9706056,X|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];X=c[3528484]|0;c[2076596]=X;g=c[2417276]|0;c[3541536]=g;c[1836236]=0;c[U+4184>>2]=2446;W=c[2443394]|0;k=0;S=0;while(1){c[U+76+(S<<2)>>2]=W+(S<<8);q=k+1&65535;if((q&65535)>191){Y=0;Z=0;break}else{k=q;S=q&65535}}while(1){S=W+(Z<<8)|0;c[U+76+(Z+512<<2)>>2]=S;c[U+76+(Z+768<<2)>>2]=S;S=Y+1&65535;if((S&65535)>191){break}else{Y=S;Z=S&65535}}Z=c[2443434]|0;c[U+844>>2]=Z;Y=Z+256|0;c[U+848>>2]=Y;W=Z+512|0;c[U+852>>2]=W;S=Z+768|0;c[U+856>>2]=S;c[U+2892>>2]=Z;c[U+3916>>2]=Z;c[U+2896>>2]=Y;c[U+3920>>2]=Y;c[U+2900>>2]=W;c[U+3924>>2]=W;c[U+2904>>2]=S;c[U+3928>>2]=S;if(!V){V=U;gGC(V|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=X;c[2417276]=g;c[1836236]=-1;fwR(1);g=c[2439331]|0;X=(g|0)==0;if(!X){V=g;gGC(9706056,V|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];V=c[3528485]|0;c[2076596]=V;U=c[2417277]|0;c[3541536]=U;c[1836236]=1;c[g+4180>>2]=1790;c[g+4184>>2]=1570;S=c[2438754]|0;W=0;Y=0;while(1){c[g+76+(Y<<2)>>2]=S+(Y<<8);Z=W+1&65535;if((Z&65535)>127){_=0;$=0;break}else{W=Z;Y=Z&65535}}while(1){Y=S+($<<8)|0;c[g+76+($+512<<2)>>2]=Y;c[g+76+($+768<<2)>>2]=Y;Y=_+1&65535;if((Y&65535)>127){break}else{_=Y;$=Y&65535}}$=c[2438756]|0;c[g+588>>2]=$;_=$+256|0;c[g+592>>2]=_;S=$+512|0;c[g+596>>2]=S;Y=$+768|0;c[g+600>>2]=Y;W=$+1024|0;c[g+604>>2]=W;Z=$+1280|0;c[g+608>>2]=Z;k=$+1536|0;c[g+612>>2]=k;q=$+1792|0;c[g+616>>2]=q;c[g+1612>>2]=$;c[g+1616>>2]=_;c[g+1620>>2]=S;c[g+1624>>2]=Y;c[g+1628>>2]=W;c[g+1632>>2]=Z;c[g+1636>>2]=k;c[g+1640>>2]=q;c[g+2636>>2]=$;c[g+3660>>2]=$;c[g+2640>>2]=_;c[g+3664>>2]=_;c[g+2644>>2]=S;c[g+3668>>2]=S;c[g+2648>>2]=Y;c[g+3672>>2]=Y;c[g+2652>>2]=W;c[g+3676>>2]=W;c[g+2656>>2]=Z;c[g+3680>>2]=Z;c[g+2660>>2]=k;c[g+3684>>2]=k;c[g+2664>>2]=q;c[g+3688>>2]=q;if(!X){X=g;gGC(X|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=V;c[2417277]=U;c[1836236]=-1;U=a[9680]|0;V=U?32e3:0;if(U){if(a[9624]|0){U=V*3|0;X=55930;while(1){if((X|0)>(U|0)){X=X>>1}else{aa=1222;ab=X;break}}}else{aa=2462;ab=V}c[2429380]=ab;c[3542124]=aa;mw(3579545,ab);ab=gGq(262144)|0;c[2406684]=ab;gGz(ab|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(3579545,11025)}c[(c[3531464]|0)+44344>>2]=544;h[745421]=.6;c[2436794]=3;h[745420]=.6;c[2436792]=3;Ux(0,8e3,1);c[2407030]=51;c[2407068]=3;c[2424]=5744;a[6518360]=1;c[2440490]=69627;c[2440478]=62308;a[6517864]=1;ab=c[642608+(c[2436]<<2)>>2]|0;aa=c[ab+128>>2]|0;if((c[ab+52>>2]&4|0)==0){c[2113068]=aa;V=c[ab+132>>2]|0;c[2113070]=V;c[2443814]=aa;c[2440436]=V;ac=aa;ad=V}else{c[2113070]=aa;V=c[ab+132>>2]|0;c[2113068]=V;c[2440436]=aa;c[2443814]=V;ac=V;ad=aa}aa=ag(ac<<1,ad)|0;ad=gGq(aa)|0;c[2112926]=ad;if((ad|0)!=0){gGz(ad|0,0,aa|0)}dhy();Q=0;i=e;return Q|0}function dhn(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6939860+(b*112|0)>>2];c[a+104>>2]=c[6939864+(b*112|0)>>2];c[a+108>>2]=c[6939868+(b*112|0)>>2];d=0;return d|0}function dho(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=6939760+(b*112|0);e=0;return e|0}function dhp(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4100020+(b*112|0)>>2];c[a+104>>2]=c[4100024+(b*112|0)>>2];c[a+108>>2]=c[4100028+(b*112|0)>>2];d=0;return d|0}function dhq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=4099920+(b*112|0);e=0;return e|0}function dhr(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>35){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4102496+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dhs(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0;b=i;i=i+2520|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;l=b+360|0;m=b+472|0;n=b+480|0;o=b+592|0;p=b+600|0;q=b+712|0;r=b+720|0;s=b+832|0;t=b+840|0;u=b+952|0;v=b+960|0;w=b+1072|0;x=b+1080|0;y=b+1192|0;z=b+1200|0;A=b+1312|0;B=b+1320|0;C=b+1432|0;D=b+1440|0;E=b+1552|0;F=b+1560|0;G=b+1672|0;H=b+1680|0;I=b+1792|0;J=b+1800|0;K=b+1912|0;L=b+1920|0;M=b+2032|0;N=b+2040|0;O=b+2152|0;P=b+2160|0;Q=b+2272|0;R=b+2280|0;S=b+2392|0;T=b+2400|0;U=b+2512|0;c[2439524]=1;c[2437750]=5;a[7303768]=1;c[2443542]=0;c[2443394]=196608;c[2438754]=212992;c[2387350]=245760;c[2439656]=247808;c[2405714]=378880;c[2443544]=378880;c[2443396]=382976;c[2438756]=387024;c[3527372]=391240;c[2439950]=391248;c[2443434]=393296;c[2439968]=397392;c[2438774]=399440;c[2438768]=399952;c[2411820]=400464;c[2406546]=400464;c[2405826]=466e3;c[3529598]=990288;c[3530140]=2038864;V=gGq(2040400)|0;c[2426808]=V;if((V|0)==0){W=1;i=b;return W|0}gGz(V|0,0,2040400);c[2443542]=V;c[2443394]=V+196608;c[2438754]=V+212992;c[2387350]=V+245760;c[2439656]=V+247808;X=V+378880|0;c[2405714]=X;c[2443544]=X;c[2443396]=V+382976;c[2438756]=V+387024;c[2387352]=V+391120;c[3527372]=V+391240;c[2439950]=V+391248;c[2443434]=V+393296;c[2439968]=V+397392;c[2438774]=V+399440;c[2438768]=V+399952;X=V+400464|0;c[2411820]=X;c[2406546]=X;c[2405826]=V+466e3;c[3529598]=V+990288;c[3530140]=V+2038864;c[2414368]=V+2040400;V=0;while(1){if((V|0)>=1024){Y=0;break}Z=9638528+(V<<2)|0;if((c[Z>>2]|0)==0){_=62588;break}else{V=V+1|0}}do{if((_|0)==62588){V=gGq(524288)|0;c[Z>>2]=V;if((V|0)==0){Y=0;break}gGz(V|0,0,524288);Y=V}}while(0);c[3529548]=Y;Y=c[2443542]|0;if((c[3542200]|0)==0){W=1;i=b;return W|0}Z=T+108|0;c[Z>>2]=0;V=T+100|0;c[V>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](T,0)|0;do{if((c[Z>>2]|0)!=0){T=c[V>>2]|0;c[U>>2]=9534384;X=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[X&16383](U,0,0)|0;if((T|0)<1){W=1;i=b;return W|0}if((gzL(Y,0,0)|0)==0){break}else{W=1}i=b;return W|0}}while(0);Y=(c[2443542]|0)+32768|0;if((c[3542200]|0)==0){W=1;i=b;return W|0}U=R+108|0;c[U>>2]=0;V=R+100|0;c[V>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](R,1)|0;do{if((c[U>>2]|0)!=0){R=c[V>>2]|0;c[S>>2]=9534384;Z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Z&16383](S,1,0)|0;if((R|0)<1){W=1;i=b;return W|0}if((gzL(Y,0,1)|0)==0){break}else{W=1}i=b;return W|0}}while(0);Y=(c[2443542]|0)+65536|0;if((c[3542200]|0)==0){W=1;i=b;return W|0}S=P+108|0;c[S>>2]=0;V=P+100|0;c[V>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](P,2)|0;do{if((c[S>>2]|0)!=0){P=c[V>>2]|0;c[Q>>2]=9534384;U=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[U&16383](Q,2,0)|0;if((P|0)<1){W=1;i=b;return W|0}if((gzL(Y,0,2)|0)==0){break}else{W=1}i=b;return W|0}}while(0);Y=c[2443394]|0;if((c[3542200]|0)==0){W=1;i=b;return W|0}Q=N+108|0;c[Q>>2]=0;V=N+100|0;c[V>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](N,3)|0;do{if((c[Q>>2]|0)!=0){N=c[V>>2]|0;c[O>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](O,3,0)|0;if((N|0)<1){W=1;i=b;return W|0}if((gzL(Y,0,3)|0)==0){break}else{W=1}i=b;return W|0}}while(0);Y=c[2438754]|0;if((c[3542200]|0)==0){W=1;i=b;return W|0}O=L+108|0;c[O>>2]=0;V=L+100|0;c[V>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](L,4)|0;do{if((c[O>>2]|0)!=0){L=c[V>>2]|0;c[M>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](M,4,0)|0;if((L|0)<1){W=1;i=b;return W|0}if((gzL(Y,0,4)|0)==0){break}else{W=1}i=b;return W|0}}while(0);Y=c[2387350]|0;if((c[3542200]|0)==0){W=1;i=b;return W|0}M=J+108|0;c[M>>2]=0;V=J+100|0;c[V>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](J,5)|0;do{if((c[M>>2]|0)!=0){J=c[V>>2]|0;c[K>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](K,5,0)|0;if((J|0)<1){W=1;i=b;return W|0}if((gzL(Y,0,5)|0)==0){break}else{W=1}i=b;return W|0}}while(0);Y=c[3529548]|0;if((c[3542200]|0)==0){W=1;i=b;return W|0}K=H+108|0;c[K>>2]=0;V=H+100|0;c[V>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](H,6)|0;do{if((c[K>>2]|0)!=0){H=c[V>>2]|0;c[I>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](I,6,0)|0;if((H|0)<1){W=1;i=b;return W|0}if((gzL(Y,0,6)|0)==0){break}else{W=1}i=b;return W|0}}while(0);Y=c[3529548]|0;I=c[2406546]|0;V=0;do{K=V<<6;gGz(I+K|0,0,64);H=V<<8;M=0;do{J=1<<3-M;O=(c[1983672+(M<<2)>>2]|0)+H|0;L=0;do{Q=O+(c[1238464+(L<<2)>>2]|0)|0;N=(L<<3)+K|0;S=0;do{P=Q+(c[6964280+(S<<2)>>2]|0)|0;if(((d[Y+((P|0)/8|0)|0]|0)&128>>>((P&7)>>>0)|0)!=0){P=I+(N+S)|0;a[P]=(d[P]|0|J)&255}S=S+1|0;}while((S|0)<8);L=L+1|0;}while((L|0)<8);M=M+1|0;}while((M|0)<4);V=V+1|0;}while((V|0)<1024);gGz(Y|0,0,524288);if((c[3542200]|0)==0){W=1;i=b;return W|0}V=F+108|0;c[V>>2]=0;I=F+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](F,7)|0;do{if((c[V>>2]|0)!=0){F=c[I>>2]|0;c[G>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](G,7,0)|0;if((F|0)<1){W=1;i=b;return W|0}if((gzL(Y,0,7)|0)==0){break}else{W=1}i=b;return W|0}}while(0);Y=(c[3529548]|0)+65536|0;if((c[3542200]|0)==0){W=1;i=b;return W|0}G=D+108|0;c[G>>2]=0;I=D+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](D,8)|0;do{if((c[G>>2]|0)!=0){D=c[I>>2]|0;c[E>>2]=9534384;V=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[V&16383](E,8,0)|0;if((D|0)<1){W=1;i=b;return W|0}if((gzL(Y,0,8)|0)==0){break}else{W=1}i=b;return W|0}}while(0);Y=(c[3529548]|0)+131072|0;if((c[3542200]|0)==0){W=1;i=b;return W|0}E=B+108|0;c[E>>2]=0;I=B+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](B,9)|0;do{if((c[E>>2]|0)!=0){B=c[I>>2]|0;c[C>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](C,9,0)|0;if((B|0)<1){W=1;i=b;return W|0}if((gzL(Y,0,9)|0)==0){break}else{W=1}i=b;return W|0}}while(0);Y=(c[3529548]|0)+196608|0;if((c[3542200]|0)==0){W=1;i=b;return W|0}C=z+108|0;c[C>>2]=0;I=z+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,10)|0;do{if((c[C>>2]|0)!=0){z=c[I>>2]|0;c[A>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](A,10,0)|0;if((z|0)<1){W=1;i=b;return W|0}if((gzL(Y,0,10)|0)==0){break}else{W=1}i=b;return W|0}}while(0);Y=(c[3529548]|0)+262144|0;if((c[3542200]|0)==0){W=1;i=b;return W|0}A=x+108|0;c[A>>2]=0;I=x+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,11)|0;do{if((c[A>>2]|0)!=0){x=c[I>>2]|0;c[y>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](y,11,0)|0;if((x|0)<1){W=1;i=b;return W|0}if((gzL(Y,0,11)|0)==0){break}else{W=1}i=b;return W|0}}while(0);Y=(c[3529548]|0)+327680|0;if((c[3542200]|0)==0){W=1;i=b;return W|0}y=v+108|0;c[y>>2]=0;I=v+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,12)|0;do{if((c[y>>2]|0)!=0){v=c[I>>2]|0;c[w>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](w,12,0)|0;if((v|0)<1){W=1;i=b;return W|0}if((gzL(Y,0,12)|0)==0){break}else{W=1}i=b;return W|0}}while(0);Y=(c[3529548]|0)+393216|0;if((c[3542200]|0)==0){W=1;i=b;return W|0}w=t+108|0;c[w>>2]=0;I=t+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,13)|0;do{if((c[w>>2]|0)!=0){t=c[I>>2]|0;c[u>>2]=9534384;y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[y&16383](u,13,0)|0;if((t|0)<1){W=1;i=b;return W|0}if((gzL(Y,0,13)|0)==0){break}else{W=1}i=b;return W|0}}while(0);Y=(c[3529548]|0)+458752|0;if((c[3542200]|0)==0){W=1;i=b;return W|0}u=r+108|0;c[u>>2]=0;I=r+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,14)|0;do{if((c[u>>2]|0)!=0){r=c[I>>2]|0;c[s>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](s,14,0)|0;if((r|0)<1){W=1;i=b;return W|0}if((gzL(Y,0,14)|0)==0){break}else{W=1}i=b;return W|0}}while(0);Y=c[3529548]|0;s=c[3529598]|0;I=0;do{u=I<<8;gGz(s+u|0,0,256);r=I<<9;w=0;do{t=1<<3-w;y=(c[611168+(w<<2)>>2]|0)+r|0;v=0;do{A=y+(c[609008+(v<<2)>>2]|0)|0;x=(v<<4)+u|0;C=0;do{z=A+(c[610128+(C<<2)>>2]|0)|0;if(((d[Y+((z|0)/8|0)|0]|0)&128>>>((z&7)>>>0)|0)!=0){z=s+(x+C)|0;a[z]=(d[z]|0|t)&255}C=C+1|0;}while((C|0)<16);v=v+1|0;}while((v|0)<16);w=w+1|0;}while((w|0)<4);I=I+1|0;}while((I|0)<4096);gGz(Y|0,0,524288);if((c[3542200]|0)==0){W=1;i=b;return W|0}I=p+108|0;c[I>>2]=0;s=p+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,15)|0;do{if((c[I>>2]|0)!=0){p=c[s>>2]|0;c[q>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](q,15,0)|0;if((p|0)<1){W=1;i=b;return W|0}if((gzL(Y,0,15)|0)==0){break}else{W=1}i=b;return W|0}}while(0);Y=(c[3529548]|0)+65536|0;if((c[3542200]|0)==0){W=1;i=b;return W|0}q=n+108|0;c[q>>2]=0;s=n+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,16)|0;do{if((c[q>>2]|0)!=0){n=c[s>>2]|0;c[o>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](o,16,0)|0;if((n|0)<1){W=1;i=b;return W|0}if((gzL(Y,0,16)|0)==0){break}else{W=1}i=b;return W|0}}while(0);Y=(c[3529548]|0)+131072|0;if((c[3542200]|0)==0){W=1;i=b;return W|0}o=l+108|0;c[o>>2]=0;s=l+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,17)|0;do{if((c[o>>2]|0)!=0){l=c[s>>2]|0;c[m>>2]=9534384;q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[q&16383](m,17,0)|0;if((l|0)<1){W=1;i=b;return W|0}if((gzL(Y,0,17)|0)==0){break}else{W=1}i=b;return W|0}}while(0);Y=(c[3529548]|0)+196608|0;if((c[3542200]|0)==0){W=1;i=b;return W|0}m=j+108|0;c[m>>2]=0;s=j+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,18)|0;do{if((c[m>>2]|0)!=0){j=c[s>>2]|0;c[k>>2]=9534384;o=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[o&16383](k,18,0)|0;if((j|0)<1){W=1;i=b;return W|0}if((gzL(Y,0,18)|0)==0){break}else{W=1}i=b;return W|0}}while(0);Y=c[3529548]|0;k=c[2405826]|0;s=0;do{m=s<<8;gGz(k+m|0,0,256);j=s<<9;o=0;do{l=1<<3-o;q=(c[1658032+(o<<2)>>2]|0)+j|0;n=0;do{I=q+(c[609008+(n<<2)>>2]|0)|0;p=(n<<4)+m|0;w=0;do{u=I+(c[610128+(w<<2)>>2]|0)|0;if(((d[Y+((u|0)/8|0)|0]|0)&128>>>((u&7)>>>0)|0)!=0){u=k+(p+w)|0;a[u]=(d[u]|0|l)&255}w=w+1|0;}while((w|0)<16);n=n+1|0;}while((n|0)<16);o=o+1|0;}while((o|0)<4);s=s+1|0;}while((s|0)<2048);s=c[2439656]|0;if((c[3542200]|0)==0){W=1;i=b;return W|0}k=g+108|0;c[k>>2]=0;Y=g+100|0;c[Y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,19)|0;do{if((c[k>>2]|0)!=0){g=c[Y>>2]|0;c[h>>2]=9534384;o=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[o&16383](h,19,0)|0;if((g|0)<1){W=1;i=b;return W|0}if((gzL(s,0,19)|0)==0){break}else{W=1}i=b;return W|0}}while(0);s=(c[2439656]|0)+65536|0;if((c[3542200]|0)==0){W=1;i=b;return W|0}h=e+108|0;c[h>>2]=0;Y=e+100|0;c[Y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,20)|0;do{if((c[h>>2]|0)!=0){e=c[Y>>2]|0;c[f>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](f,20,0)|0;if((e|0)<1){W=1;i=b;return W|0}if((gzL(s,0,20)|0)==0){break}else{W=1}i=b;return W|0}}while(0);s=c[3529548]|0;f=0;while(1){if((f|0)>=1024){break}$=9638528+(f<<2)|0;if((c[$>>2]|0)==(s|0)){_=62707;break}else{f=f+1|0}}if((_|0)==62707){gGr(s);c[$>>2]=0}c[3529548]=0;dht();W=0;i=b;return W|0}function dht(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;c[2424]=5744;d=(c[2439524]|0)==2;c[3528552]=-1;do{if(d){c[2113196]=2;e=gGq(6320)|0;f=e;c[2433426]=f;if((e|0)==0){g=f;break}gGz(e|0,0,6320);e=0;do{c[f+(e*3160|0)+3132>>2]=2102;c[f+(e*3160|0)+3136>>2]=2420;c[f+(e*3160|0)+3140>>2]=1856;c[f+(e*3160|0)+3144>>2]=1450;c[9721800+(e<<2)>>2]=0;i=0;do{c[f+(e*3160|0)+60+(i<<2)>>2]=0;i=i+1|0;}while((i|0)<768);e=e+1|0;}while((e|0)<2);c[2113194]=0;e=c[2427044]|0;c[9681616+(e<<3)>>2]=726904;c[9681620+(e<<3)>>2]=0;i=e+1|0;c[9681616+(i<<3)>>2]=726904;c[9681620+(i<<3)>>2]=1;j=e+2|0;k=f;l=62786}else{c[2113196]=1;e=gGq(3160)|0;i=e;c[2433426]=i;if((e|0)==0){g=i;break}gGz(e|0,0,3160);c[e+3132>>2]=2102;c[e+3136>>2]=2420;c[e+3140>>2]=1856;c[e+3144>>2]=1450;c[2430450]=0;e=0;do{c[i+60+(e<<2)>>2]=0;e=e+1|0;}while((e|0)<768);c[2113194]=0;e=c[2427044]|0;c[9681616+(e<<3)>>2]=726904;c[9681620+(e<<3)>>2]=0;j=e+1|0;k=i;l=62786}}while(0);if((l|0)==62786){c[2427044]=j;g=k}c[3528552]=0;if((g|0)!=0){k=g;gGC(9642704,k|0,60)|0}b[4821352]=c[2410676]&65535;fC1();k=(a[9642745]&1)==0;c[2430032]=k?1595912:1595656;c[2429672]=k?1114752:1114496;c[2429670]=k?1114240:1113984;c[2444186]=k?4654424:4654168;k=c[3528552]|0;g=9721800+(k<<2)|0;c[2113194]=c[g>>2];j=c[2443544]|0;l=c[2433426]|0;d=0;e=0;while(1){f=j+(e<<8)|0;c[l+(k*3160|0)+60+(e<<2)>>2]=f;c[l+(k*3160|0)+60+(e+256<<2)>>2]=f;c[l+(k*3160|0)+60+(e+512<<2)>>2]=f;f=d+1&65535;if((f&65535)>15){break}else{d=f;e=f&65535}}e=c[2438774]|0;c[l+(k*3160|0)+124>>2]=e;c[l+(k*3160|0)+1148>>2]=e;c[l+(k*3160|0)+2172>>2]=e;d=e+256|0;c[l+(k*3160|0)+128>>2]=d;c[l+(k*3160|0)+1152>>2]=d;c[l+(k*3160|0)+2176>>2]=d;d=c[2438768]|0;c[l+(k*3160|0)+132>>2]=d;c[l+(k*3160|0)+1156>>2]=d;c[l+(k*3160|0)+2180>>2]=d;e=d+256|0;c[l+(k*3160|0)+136>>2]=e;c[l+(k*3160|0)+1160>>2]=e;c[l+(k*3160|0)+2184>>2]=e;e=c[2439950]|0;c[l+(k*3160|0)+156>>2]=e;c[l+(k*3160|0)+1180>>2]=e;c[l+(k*3160|0)+2204>>2]=e;d=e+256|0;c[l+(k*3160|0)+160>>2]=d;c[l+(k*3160|0)+1184>>2]=d;c[l+(k*3160|0)+2208>>2]=d;d=e+512|0;c[l+(k*3160|0)+164>>2]=d;c[l+(k*3160|0)+1188>>2]=d;c[l+(k*3160|0)+2212>>2]=d;d=e+768|0;c[l+(k*3160|0)+168>>2]=d;c[l+(k*3160|0)+1192>>2]=d;c[l+(k*3160|0)+2216>>2]=d;d=e+1024|0;c[l+(k*3160|0)+172>>2]=d;c[l+(k*3160|0)+1196>>2]=d;c[l+(k*3160|0)+2220>>2]=d;d=e+1280|0;c[l+(k*3160|0)+176>>2]=d;c[l+(k*3160|0)+1200>>2]=d;c[l+(k*3160|0)+2224>>2]=d;d=e+1536|0;c[l+(k*3160|0)+180>>2]=d;c[l+(k*3160|0)+1204>>2]=d;c[l+(k*3160|0)+2228>>2]=d;d=e+1792|0;c[l+(k*3160|0)+184>>2]=d;c[l+(k*3160|0)+1208>>2]=d;c[l+(k*3160|0)+2232>>2]=d;d=c[2443434]|0;e=32;j=32;while(1){c[l+(k*3160|0)+60+(j+256<<2)>>2]=d+((j<<8)-8192);f=e+1&65535;if((f&65535)>47){break}else{e=f;j=f&65535}}j=c[2439968]|0;c[l+(k*3160|0)+252>>2]=j;c[l+(k*3160|0)+1276>>2]=j;c[l+(k*3160|0)+2300>>2]=j;e=j+256|0;c[l+(k*3160|0)+256>>2]=e;c[l+(k*3160|0)+1280>>2]=e;c[l+(k*3160|0)+2304>>2]=e;e=j+512|0;c[l+(k*3160|0)+260>>2]=e;c[l+(k*3160|0)+1284>>2]=e;c[l+(k*3160|0)+2308>>2]=e;e=j+768|0;c[l+(k*3160|0)+264>>2]=e;c[l+(k*3160|0)+1288>>2]=e;c[l+(k*3160|0)+2312>>2]=e;e=j+1024|0;c[l+(k*3160|0)+268>>2]=e;c[l+(k*3160|0)+1292>>2]=e;c[l+(k*3160|0)+2316>>2]=e;e=j+1280|0;c[l+(k*3160|0)+272>>2]=e;c[l+(k*3160|0)+1296>>2]=e;c[l+(k*3160|0)+2320>>2]=e;e=j+1536|0;c[l+(k*3160|0)+276>>2]=e;c[l+(k*3160|0)+1300>>2]=e;c[l+(k*3160|0)+2324>>2]=e;e=j+1792|0;c[l+(k*3160|0)+280>>2]=e;c[l+(k*3160|0)+1304>>2]=e;c[l+(k*3160|0)+2328>>2]=e;e=c[2443542]|0;j=64;d=64;while(1){f=e+((d<<8)+16384)|0;c[l+(k*3160|0)+60+(d<<2)>>2]=f;c[l+(k*3160|0)+60+(d+512<<2)>>2]=f;f=j+1&65535;if((f&65535)>127){m=128;n=128;break}else{j=f;d=f&65535}}while(1){d=e+((n<<8)-32768)|0;c[l+(k*3160|0)+60+(n<<2)>>2]=d;c[l+(k*3160|0)+60+(n+512<<2)>>2]=d;d=m+1&65535;if((d&65535)>255){break}else{m=d;n=d&65535}}c[l+(k*3160|0)+3132>>2]=2032;c[l+(k*3160|0)+3136>>2]=3374;n=l+(k*3160|0)|0;if((n|0)!=0){k=n;gGC(k|0,9642704,60)|0}c[g>>2]=c[2113194];c[3528552]=-1;g=c[2439524]|0;if((g|0)==1){fwj(2);k=c[2443394]|0;n=c[2437644]|0;l=192;m=192;while(1){e=k+((m<<8)-49152)|0;c[n+72+(m<<2)>>2]=e;c[n+72+(m+512<<2)>>2]=e;e=l+1&65535;if((e&65535)>255){break}else{l=e;m=e&65535}}c[n+3144>>2]=1212;c[n+3148>>2]=1556;o=c[2439524]|0}else{o=g}if((o|0)==2){c[3528552]=1;g=(c[2433426]|0)+3160|0;if((g|0)!=0){n=g;gGC(9642704,n|0,60)|0}b[4821352]=c[2410676]&65535;fC1();n=(a[9642745]&1)==0;c[2430032]=n?1595912:1595656;c[2429672]=n?1114752:1114496;c[2429670]=n?1114240:1113984;c[2444186]=n?4654424:4654168;n=c[3528552]|0;g=9721800+(n<<2)|0;c[2113194]=c[g>>2];m=c[2443394]|0;l=c[2433426]|0;k=192;e=192;while(1){d=m+((e<<8)-49152)|0;c[l+(n*3160|0)+60+(e<<2)>>2]=d;c[l+(n*3160|0)+60+(e+512<<2)>>2]=d;d=k+1&65535;if((d&65535)>255){break}else{k=d;e=d&65535}}c[l+(n*3160|0)+3132>>2]=1578;c[l+(n*3160|0)+3136>>2]=1474;e=l+(n*3160|0)|0;if((e|0)!=0){n=e;gGC(n|0,9642704,60)|0}c[g>>2]=c[2113194];c[3528552]=-1;p=c[2439524]|0}else{p=o}if((p|0)==3){fwj(3);p=c[2443394]|0;o=c[2437644]|0;g=192;n=192;while(1){e=p+((n<<8)-49152)|0;c[o+72+(n<<2)>>2]=e;c[o+72+(n+512<<2)>>2]=e;e=g+1&65535;if((e&65535)>255){break}else{g=e;n=e&65535}}c[o+3144>>2]=3606;c[o+3148>>2]=2066;c[o+3164>>2]=1504}if((c[2437750]|0)==5){c[3528554]=-1;c[2113160]=1;o=gGq(3148)|0;n=o;c[2433592]=n;if((o|0)!=0){gGz(o|0,0,3148);c[o+3120>>2]=3128;c[o+3124>>2]=1840;c[o+3128>>2]=136;c[o+3132>>2]=1902;c[2432840]=0;g=0;do{c[n+48+(g<<2)>>2]=0;g=g+1|0;}while((g|0)<768);c[2113158]=0;c[2415198]=0;g=c[2427044]|0;c[9681616+(g<<3)>>2]=809272;c[9681620+(g<<3)>>2]=0;c[2427044]=g+1}c[3528554]=0;f43(o);o=c[3528554]|0;g=9731360+(o<<2)|0;n=c[g>>2]|0;c[2113158]=n;p=c[2438756]|0;e=c[2433592]|0;l=0;k=0;while(1){m=p+(k<<8)|0;c[e+(o*3148|0)+48+(k<<2)>>2]=m;c[e+(o*3148|0)+48+(k+256<<2)>>2]=m;c[e+(o*3148|0)+48+(k+512<<2)>>2]=m;m=l+1&65535;if((m&65535)>15){break}else{l=m;k=m&65535}}k=c[2438754]|0;l=128;p=128;while(1){m=k+((p<<8)-32768)|0;c[e+(o*3148|0)+48+(p<<2)>>2]=m;c[e+(o*3148|0)+48+(p+512<<2)>>2]=m;m=l+1&65535;if((m&65535)>255){break}else{l=m;p=m&65535}}c[e+(o*3148|0)+3120>>2]=1168;c[e+(o*3148|0)+3124>>2]=1062;p=e+(o*3148|0)|0;if((p|0)!=0){o=p;gGC(o|0,9660752,48)|0}c[g>>2]=n;c[3528554]=-1;n=a[9680]|0;g=n?32e3:0;if(n){if(a[9624]|0){n=g*3|0;o=55930;while(1){if((o|0)>(n|0)){o=o>>1}else{q=1222;r=o;break}}}else{q=2462;r=g}c[2429380]=r;c[3542124]=q;mw(3579545,r);r=gGq(262144)|0;c[2406684]=r;gGz(r|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(3579545,11025)}c[(c[3531464]|0)+44344>>2]=1590;h[745421]=.6;c[2436794]=3;h[745420]=.6;c[2436792]=3;UB(0,1874,375e3,82,5);UB(1,1874,375e3,8266,5);h[1207773]=.5;c[2415548]=3;c[2415126]=9665376;h[1208176]=.5;c[2416354]=3}if(a[7303768]|0){c[2443666]=2047;c[2385780]=7;c[3528996]=3;gGz(9702704,0,32);gGz(9703728,0,32);gGz(9704752,0,32);r=c[2427044]|0;c[9681616+(r<<3)>>2]=809328;c[9681620+(r<<3)>>2]=0;c[2427044]=r+1;r=c[2387350]|0;q=16;while(1){g=r+(q<<3)|0;c[9702704+(q<<2)>>2]=g;c[9704752+(q<<2)>>2]=g;g=q+1|0;if((g|0)<256){q=g}else{s=1;break}}do{q=r+((s<<3)-8)|0;c[9702704+(s<<2)>>2]=q;c[9703728+(s<<2)>>2]=q;c[9704752+(s<<2)>>2]=q;s=s+1|0;}while((s|0)<16);c[2385590]=3298;c[3528586]=2586}a[6518360]=1;c[2440490]=69627;c[2440478]=26110;s=c[642608+(c[2436]<<2)>>2]|0;r=c[s+128>>2]|0;if((c[s+52>>2]&4|0)==0){c[2113068]=r;q=c[s+132>>2]|0;c[2113070]=q;c[2443814]=r;c[2440436]=q;t=r;u=q}else{c[2113070]=r;q=c[s+132>>2]|0;c[2113068]=q;c[2440436]=r;c[2443814]=q;t=q;u=r}r=ag(t<<1,u)|0;u=gGq(r)|0;c[2112926]=u;if((u|0)==0){dhy();return}gGz(u|0,0,r|0);dhy();return}function dhu(b){b=b|0;if((b|0)==0){a[9660787]=0;return}else{f44(1);b=f45(1e3)|0;c[2113158]=(c[2113158]|0)+b;c[2444116]=(c[2444116]|0)+b;return}}function dhv(b){b=b|0;var d=0.0;d=+(b|0)*+(c[2113194]|0)/(a[6518360]|0?3999712.0:0.0);+V(d)>=1.0?d>0.0?(al(+U(d/4294967296.0),4294967295.0)|0)>>>0:~~+af((d- +(~~d>>>0))/4294967296.0)>>>0:0;return~~d>>>0|0}function dhw(){var b=0,e=0,f=0,g=0;b=c[3527484]|0;if(b>>>0>=(c[3527486]|0)>>>0|b>>>0>65535){a[9774464]=1;c[2415126]=9662152;c[2415540]=1;return}e=c[2443618]|0;if((e|0)!=-1){f=e&15;c[2415126]=9662152;if((c[2415542]|0)==4){g=f}else{g=f<<1&14}c[2415538]=g;c[2443618]=-1;return}g=c[2439656]|0;c[3527484]=b+1;f=d[g+(b&65535)|0]|0;c[2443618]=f;b=f>>>4;c[2415126]=9662152;if((c[2415542]|0)==4){c[2415538]=b;return}else{c[2415538]=b<<1&14;return}}function dhx(){var b=0,e=0,f=0,g=0;b=c[3527485]|0;if(b>>>0>=(c[3527487]|0)>>>0|b>>>0>65535){a[9774465]=1;c[2415126]=9665376;c[2416346]=1;return}e=c[2443619]|0;if((e|0)!=-1){f=e&15;c[2415126]=9665376;if((c[2416348]|0)==4){g=f}else{g=f<<1&14}c[2416344]=g;c[2443619]=-1;return}g=c[2439656]|0;c[3527485]=b+1;f=d[g+(b&65535|65536)|0]|0;c[2443619]=f;b=f>>>4;c[2415126]=9665376;if((c[2416348]|0)==4){c[2416344]=b;return}else{c[2416344]=b<<1&14;return}}function dhy(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;c[3528552]=0;e=c[2433426]|0;if((e|0)!=0){f=e;gGC(9642704,f|0,60)|0}b[4821352]=c[2410676]&65535;fC1();f=(a[9642745]&1)==0;c[2430032]=f?1595912:1595656;c[2429672]=f?1114752:1114496;c[2429670]=f?1114240:1113984;c[2444186]=f?4654424:4654168;c[2113194]=c[9721800+(c[3528552]<<2)>>2];fC2();f=c[3528552]|0;e=(c[2433426]|0)+(f*3160|0)|0;if((e|0)!=0){g=e;gGC(g|0,9642704,60)|0}c[9721800+(f<<2)>>2]=c[2113194];c[3528552]=-1;f=c[2439524]|0;if((f|0)==1){a[9660900]=a[9660900]|16;g=c[2437644]|0;e=c[g+1092>>2]|0;do{if((e|0)==0){h=c[g+3144>>2]|0;if((h|0)==0){i=0;j=0;break}k=gj[h&4095](-2)|0;h=c[2437644]|0;l=c[h+1092>>2]|0;m=(k&255)<<8;if((l|0)!=0){n=l;o=m;p=62889;break}l=c[h+3144>>2]|0;if((l|0)==0){i=0;j=m;break}i=gj[l&4095](-1)|0;j=m}else{n=e;o=(d[e+254|0]|0)<<8;p=62889}}while(0);if((p|0)==62889){i=a[n+255|0]|0;j=o}o=i&255|j;c[2415221]=o;b[4830442]=o&65535;a[9660920]=0;a[9660921]=0;a[9660928]=0;a[9660930]=0;a[9660931]=0;c[2415234]=0;gGz(9660901,0,5);c[2415235]=65535;c[2415237]=65535;a[9660932]=a[9660932]|64;q=c[2439524]|0}else{q=f}if((q|0)==2){c[3528552]=1;f=(c[2433426]|0)+3160|0;if((f|0)!=0){o=f;gGC(9642704,o|0,60)|0}b[4821352]=c[2410676]&65535;fC1();o=(a[9642745]&1)==0;c[2430032]=o?1595912:1595656;c[2429672]=o?1114752:1114496;c[2429670]=o?1114240:1113984;c[2444186]=o?4654424:4654168;c[2113194]=c[9721800+(c[3528552]<<2)>>2];fC2();o=c[3528552]|0;f=(c[2433426]|0)+(o*3160|0)|0;if((f|0)!=0){j=f;gGC(j|0,9642704,60)|0}c[9721800+(o<<2)>>2]=c[2113194];c[3528552]=-1;r=c[2439524]|0}else{r=q}if((r|0)==3){a[9660900]=a[9660900]|16;q=c[2437644]|0;o=c[q+1092>>2]|0;do{if((o|0)==0){j=c[q+3144>>2]|0;if((j|0)==0){s=0;t=0;break}f=gj[j&4095](-2)|0;j=c[2437644]|0;i=c[j+1092>>2]|0;n=(f&255)<<8;if((i|0)!=0){u=i;v=n;p=62904;break}i=c[j+3144>>2]|0;if((i|0)==0){s=0;t=n;break}s=gj[i&4095](-1)|0;t=n}else{u=o;v=(d[o+254|0]|0)<<8;p=62904}}while(0);if((p|0)==62904){s=a[u+255|0]|0;t=v}v=s&255|t;c[2415221]=v;b[4830442]=v&65535;a[9660920]=0;a[9660921]=0;a[9660928]=0;a[9660930]=0;a[9660931]=0;c[2415234]=0;gGz(9660901,0,5);c[2415235]=65535;c[2415237]=65535;a[9660932]=a[9660932]|64;w=c[2439524]|0}else{w=r}if((w|0)==4){w=c[2439330]|0;r=(w|0)==0;if(!r){v=w;gGC(9706056,v|0,76)|0}v=c[2438118]|0;c[2433530]=v;t=c[3528484]|0;c[2076596]=t;s=c[2417276]|0;c[3541536]=s;c[1836236]=0;gGz(9706056,0,76);if(!r){r=w;gGC(r|0,9706056,76)|0}c[2438118]=v;c[3528484]=t;c[2417276]=s;c[1836236]=-1}s=c[2437750]|0;if((s|0)==5){c[3528554]=0;f43(c[2433592]|0);t=c[3528554]|0;c[2113158]=c[9731360+(t<<2)>>2];a[9660796]=0;a[9660797]=0;a[9660786]=0;a[9660787]=0;c[2415191]=0;a[9660784]=a[9660784]|80;v=c[2433592]|0;r=c[v+(t*3148|0)+1068>>2]|0;do{if((r|0)==0){w=c[v+(t*3148|0)+3120>>2]|0;if((w|0)==0){x=0;y=0;z=t;A=v;break}u=gj[w&4095](-2)|0;w=c[3528554]|0;o=c[2433592]|0;q=c[o+(w*3148|0)+1068>>2]|0;n=(u&255)<<8;if((q|0)!=0){B=q;C=n;D=w;E=o;p=62919;break}q=c[o+(w*3148|0)+3120>>2]|0;if((q|0)==0){x=0;y=n;z=w;A=o;break}o=gj[q&4095](-1)|0;x=o;y=n;z=c[3528554]|0;A=c[2433592]|0}else{B=r;C=(d[r+254|0]|0)<<8;D=t;E=v;p=62919}}while(0);if((p|0)==62919){x=a[B+255|0]|0;y=C;z=D;A=E}E=x&255|y;c[2415188]=E;b[4830376]=E&65535;E=A+(z*3148|0)|0;if((E|0)!=0){A=E;gGC(A|0,9660752,48)|0}c[9731360+(z<<2)>>2]=c[2113158];c[3528554]=-1;UA();F=c[2437750]|0}else{F=s}if((F|0)==4){F=c[2439331]|0;s=(F|0)==0;if(!s){z=F;gGC(9706056,z|0,76)|0}z=c[2438119]|0;c[2433530]=z;A=c[3528485]|0;c[2076596]=A;E=c[2417277]|0;c[3541536]=E;c[1836236]=1;gGz(9706056,0,76);if(!s){s=F;gGC(s|0,9706056,76)|0}c[2438119]=z;c[3528485]=A;c[2417277]=E;c[1836236]=-1;c[2113156]=0;a[9628264]=0;c[2407033]=0;E=c[3541206]|0;c[3541190]=E;c[3541198]=E;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=E+256;c[3541199]=E+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=E+512;c[3541200]=E+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=E+768;c[3541201]=E+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4}if(!(a[7303768]|0)){mx(0);a[14119360]=0;a[9545168]=0;a[9758104]=1;a[9758248]=0;b[4886924]=0;b[4886916]=0;a[9773840]=0;a[9773824]=0;a[9774464]=1;a[9774465]=1;c[3527484]=0;c[3527485]=0;c[3527486]=0;c[3527487]=0;c[2443618]=-1;c[2443619]=-1;return}f42();mx(0);a[14119360]=0;a[9545168]=0;a[9758104]=1;a[9758248]=0;b[4886924]=0;b[4886916]=0;a[9773840]=0;a[9773824]=0;a[9774464]=1;a[9774465]=1;c[3527484]=0;c[3527485]=0;c[3527486]=0;c[3527487]=0;c[2443618]=-1;c[2443619]=-1;return}function dhz(b){b=b|0;a[9706117]=(b|0)!=0|0;return}function dhA(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0;b=i;i=i+2520|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;l=b+360|0;m=b+472|0;n=b+480|0;o=b+592|0;p=b+600|0;q=b+712|0;r=b+720|0;s=b+832|0;t=b+840|0;u=b+952|0;v=b+960|0;w=b+1072|0;x=b+1080|0;y=b+1192|0;z=b+1200|0;A=b+1312|0;B=b+1320|0;C=b+1432|0;D=b+1440|0;E=b+1552|0;F=b+1560|0;G=b+1672|0;H=b+1680|0;I=b+1792|0;J=b+1800|0;K=b+1912|0;L=b+1920|0;M=b+2032|0;N=b+2040|0;O=b+2152|0;P=b+2160|0;Q=b+2272|0;R=b+2280|0;S=b+2392|0;T=b+2400|0;U=b+2512|0;V=0;while(1){if((V|0)>=1024){W=0;break}X=9638528+(V<<2)|0;if((c[X>>2]|0)==0){Y=62940;break}else{V=V+1|0}}do{if((Y|0)==62940){V=gGq(524288)|0;c[X>>2]=V;if((V|0)==0){W=0;break}gGz(V|0,0,524288);W=V}}while(0);c[3529548]=W;W=c[2443542]|0;if((c[3542200]|0)==0){Z=1;i=b;return Z|0}X=T+108|0;c[X>>2]=0;V=T+100|0;c[V>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](T,0)|0;do{if((c[X>>2]|0)!=0){T=c[V>>2]|0;c[U>>2]=9534384;_=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[_&16383](U,0,0)|0;if((T|0)<1){Z=1;i=b;return Z|0}if((gzL(W,0,0)|0)==0){break}else{Z=1}i=b;return Z|0}}while(0);W=(c[2443542]|0)+32768|0;if((c[3542200]|0)==0){Z=1;i=b;return Z|0}U=R+108|0;c[U>>2]=0;V=R+100|0;c[V>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](R,1)|0;do{if((c[U>>2]|0)!=0){R=c[V>>2]|0;c[S>>2]=9534384;X=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[X&16383](S,1,0)|0;if((R|0)<1){Z=1;i=b;return Z|0}if((gzL(W,0,1)|0)==0){break}else{Z=1}i=b;return Z|0}}while(0);W=(c[2443542]|0)+65536|0;if((c[3542200]|0)==0){Z=1;i=b;return Z|0}S=P+108|0;c[S>>2]=0;V=P+100|0;c[V>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](P,2)|0;do{if((c[S>>2]|0)!=0){P=c[V>>2]|0;c[Q>>2]=9534384;U=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[U&16383](Q,2,0)|0;if((P|0)<1){Z=1;i=b;return Z|0}if((gzL(W,0,2)|0)==0){break}else{Z=1}i=b;return Z|0}}while(0);W=(c[2443542]|0)+98304|0;if((c[3542200]|0)==0){Z=1;i=b;return Z|0}Q=N+108|0;c[Q>>2]=0;V=N+100|0;c[V>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](N,3)|0;do{if((c[Q>>2]|0)!=0){N=c[V>>2]|0;c[O>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](O,3,0)|0;if((N|0)<1){Z=1;i=b;return Z|0}if((gzL(W,0,3)|0)==0){break}else{Z=1}i=b;return Z|0}}while(0);W=c[2443394]|0;if((c[3542200]|0)==0){Z=1;i=b;return Z|0}O=L+108|0;c[O>>2]=0;V=L+100|0;c[V>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](L,4)|0;do{if((c[O>>2]|0)!=0){L=c[V>>2]|0;c[M>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](M,4,0)|0;if((L|0)<1){Z=1;i=b;return Z|0}if((gzL(W,0,4)|0)==0){break}else{Z=1}i=b;return Z|0}}while(0);W=c[2438754]|0;if((c[3542200]|0)==0){Z=1;i=b;return Z|0}M=J+108|0;c[M>>2]=0;V=J+100|0;c[V>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](J,5)|0;do{if((c[M>>2]|0)!=0){J=c[V>>2]|0;c[K>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](K,5,0)|0;if((J|0)<1){Z=1;i=b;return Z|0}if((gzL(W,0,5)|0)==0){break}else{Z=1}i=b;return Z|0}}while(0);W=c[3529548]|0;if((c[3542200]|0)==0){Z=1;i=b;return Z|0}K=H+108|0;c[K>>2]=0;V=H+100|0;c[V>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](H,6)|0;do{if((c[K>>2]|0)!=0){H=c[V>>2]|0;c[I>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](I,6,0)|0;if((H|0)<1){Z=1;i=b;return Z|0}if((gzL(W,0,6)|0)==0){break}else{Z=1}i=b;return Z|0}}while(0);W=c[3529548]|0;I=c[2406546]|0;V=0;do{K=V<<6;gGz(I+K|0,0,64);H=V<<8;M=0;do{J=1<<3-M;O=(c[1983672+(M<<2)>>2]|0)+H|0;L=0;do{Q=O+(c[1238464+(L<<2)>>2]|0)|0;N=(L<<3)+K|0;S=0;do{P=Q+(c[6964280+(S<<2)>>2]|0)|0;if(((d[W+((P|0)/8|0)|0]|0)&128>>>((P&7)>>>0)|0)!=0){P=I+(N+S)|0;a[P]=(d[P]|0|J)&255}S=S+1|0;}while((S|0)<8);L=L+1|0;}while((L|0)<8);M=M+1|0;}while((M|0)<4);V=V+1|0;}while((V|0)<1024);gGz(W|0,0,524288);if((c[3542200]|0)==0){Z=1;i=b;return Z|0}V=F+108|0;c[V>>2]=0;I=F+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](F,7)|0;do{if((c[V>>2]|0)!=0){F=c[I>>2]|0;c[G>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](G,7,0)|0;if((F|0)<1){Z=1;i=b;return Z|0}if((gzL(W,0,7)|0)==0){break}else{Z=1}i=b;return Z|0}}while(0);W=(c[3529548]|0)+65536|0;if((c[3542200]|0)==0){Z=1;i=b;return Z|0}G=D+108|0;c[G>>2]=0;I=D+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](D,8)|0;do{if((c[G>>2]|0)!=0){D=c[I>>2]|0;c[E>>2]=9534384;V=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[V&16383](E,8,0)|0;if((D|0)<1){Z=1;i=b;return Z|0}if((gzL(W,0,8)|0)==0){break}else{Z=1}i=b;return Z|0}}while(0);W=(c[3529548]|0)+131072|0;if((c[3542200]|0)==0){Z=1;i=b;return Z|0}E=B+108|0;c[E>>2]=0;I=B+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](B,9)|0;do{if((c[E>>2]|0)!=0){B=c[I>>2]|0;c[C>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](C,9,0)|0;if((B|0)<1){Z=1;i=b;return Z|0}if((gzL(W,0,9)|0)==0){break}else{Z=1}i=b;return Z|0}}while(0);W=(c[3529548]|0)+196608|0;if((c[3542200]|0)==0){Z=1;i=b;return Z|0}C=z+108|0;c[C>>2]=0;I=z+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,10)|0;do{if((c[C>>2]|0)!=0){z=c[I>>2]|0;c[A>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](A,10,0)|0;if((z|0)<1){Z=1;i=b;return Z|0}if((gzL(W,0,10)|0)==0){break}else{Z=1}i=b;return Z|0}}while(0);W=(c[3529548]|0)+262144|0;if((c[3542200]|0)==0){Z=1;i=b;return Z|0}A=x+108|0;c[A>>2]=0;I=x+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,11)|0;do{if((c[A>>2]|0)!=0){x=c[I>>2]|0;c[y>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](y,11,0)|0;if((x|0)<1){Z=1;i=b;return Z|0}if((gzL(W,0,11)|0)==0){break}else{Z=1}i=b;return Z|0}}while(0);W=(c[3529548]|0)+327680|0;if((c[3542200]|0)==0){Z=1;i=b;return Z|0}y=v+108|0;c[y>>2]=0;I=v+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,12)|0;do{if((c[y>>2]|0)!=0){v=c[I>>2]|0;c[w>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](w,12,0)|0;if((v|0)<1){Z=1;i=b;return Z|0}if((gzL(W,0,12)|0)==0){break}else{Z=1}i=b;return Z|0}}while(0);W=(c[3529548]|0)+393216|0;if((c[3542200]|0)==0){Z=1;i=b;return Z|0}w=t+108|0;c[w>>2]=0;I=t+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,13)|0;do{if((c[w>>2]|0)!=0){t=c[I>>2]|0;c[u>>2]=9534384;y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[y&16383](u,13,0)|0;if((t|0)<1){Z=1;i=b;return Z|0}if((gzL(W,0,13)|0)==0){break}else{Z=1}i=b;return Z|0}}while(0);W=(c[3529548]|0)+458752|0;if((c[3542200]|0)==0){Z=1;i=b;return Z|0}u=r+108|0;c[u>>2]=0;I=r+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,14)|0;do{if((c[u>>2]|0)!=0){r=c[I>>2]|0;c[s>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](s,14,0)|0;if((r|0)<1){Z=1;i=b;return Z|0}if((gzL(W,0,14)|0)==0){break}else{Z=1}i=b;return Z|0}}while(0);W=c[3529548]|0;s=c[3529598]|0;I=0;do{u=I<<8;gGz(s+u|0,0,256);r=I<<9;w=0;do{t=1<<3-w;y=(c[611168+(w<<2)>>2]|0)+r|0;v=0;do{A=y+(c[609008+(v<<2)>>2]|0)|0;x=(v<<4)+u|0;C=0;do{z=A+(c[610128+(C<<2)>>2]|0)|0;if(((d[W+((z|0)/8|0)|0]|0)&128>>>((z&7)>>>0)|0)!=0){z=s+(x+C)|0;a[z]=(d[z]|0|t)&255}C=C+1|0;}while((C|0)<16);v=v+1|0;}while((v|0)<16);w=w+1|0;}while((w|0)<4);I=I+1|0;}while((I|0)<4096);gGz(W|0,0,524288);if((c[3542200]|0)==0){Z=1;i=b;return Z|0}I=p+108|0;c[I>>2]=0;s=p+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,15)|0;do{if((c[I>>2]|0)!=0){p=c[s>>2]|0;c[q>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](q,15,0)|0;if((p|0)<1){Z=1;i=b;return Z|0}if((gzL(W,0,15)|0)==0){break}else{Z=1}i=b;return Z|0}}while(0);W=(c[3529548]|0)+65536|0;if((c[3542200]|0)==0){Z=1;i=b;return Z|0}q=n+108|0;c[q>>2]=0;s=n+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,16)|0;do{if((c[q>>2]|0)!=0){n=c[s>>2]|0;c[o>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](o,16,0)|0;if((n|0)<1){Z=1;i=b;return Z|0}if((gzL(W,0,16)|0)==0){break}else{Z=1}i=b;return Z|0}}while(0);W=(c[3529548]|0)+131072|0;if((c[3542200]|0)==0){Z=1;i=b;return Z|0}o=l+108|0;c[o>>2]=0;s=l+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,17)|0;do{if((c[o>>2]|0)!=0){l=c[s>>2]|0;c[m>>2]=9534384;q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[q&16383](m,17,0)|0;if((l|0)<1){Z=1;i=b;return Z|0}if((gzL(W,0,17)|0)==0){break}else{Z=1}i=b;return Z|0}}while(0);W=(c[3529548]|0)+196608|0;if((c[3542200]|0)==0){Z=1;i=b;return Z|0}m=j+108|0;c[m>>2]=0;s=j+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,18)|0;do{if((c[m>>2]|0)!=0){j=c[s>>2]|0;c[k>>2]=9534384;o=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[o&16383](k,18,0)|0;if((j|0)<1){Z=1;i=b;return Z|0}if((gzL(W,0,18)|0)==0){break}else{Z=1}i=b;return Z|0}}while(0);W=c[3529548]|0;k=c[2405826]|0;s=0;do{m=s<<8;gGz(k+m|0,0,256);j=s<<9;o=0;do{l=1<<3-o;q=(c[1658032+(o<<2)>>2]|0)+j|0;n=0;do{I=q+(c[609008+(n<<2)>>2]|0)|0;p=(n<<4)+m|0;w=0;do{u=I+(c[610128+(w<<2)>>2]|0)|0;if(((d[W+((u|0)/8|0)|0]|0)&128>>>((u&7)>>>0)|0)!=0){u=k+(p+w)|0;a[u]=(d[u]|0|l)&255}w=w+1|0;}while((w|0)<16);n=n+1|0;}while((n|0)<16);o=o+1|0;}while((o|0)<4);s=s+1|0;}while((s|0)<2048);s=c[2439656]|0;if((c[3542200]|0)==0){Z=1;i=b;return Z|0}k=g+108|0;c[k>>2]=0;W=g+100|0;c[W>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,19)|0;do{if((c[k>>2]|0)!=0){g=c[W>>2]|0;c[h>>2]=9534384;o=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[o&16383](h,19,0)|0;if((g|0)<1){Z=1;i=b;return Z|0}if((gzL(s,0,19)|0)==0){break}else{Z=1}i=b;return Z|0}}while(0);s=(c[2439656]|0)+65536|0;if((c[3542200]|0)==0){Z=1;i=b;return Z|0}h=e+108|0;c[h>>2]=0;W=e+100|0;c[W>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,20)|0;do{if((c[h>>2]|0)!=0){e=c[W>>2]|0;c[f>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](f,20,0)|0;if((e|0)<1){Z=1;i=b;return Z|0}if((gzL(s,0,20)|0)==0){break}else{Z=1}i=b;return Z|0}}while(0);s=c[3529548]|0;f=0;while(1){if((f|0)>=1024){break}$=9638528+(f<<2)|0;if((c[$>>2]|0)==(s|0)){Y=63059;break}else{f=f+1|0}}if((Y|0)==63059){gGr(s);c[$>>2]=0}c[3529548]=0;Z=0;i=b;return Z|0}function dhB(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=b&65535;if((f&63488|0)==55296){g=c[2387248]|0;a[g+(f&1023)|0]=e;h=b&1022;b=((d[g+h|0]|0)<<8|(d[g+(h|1)|0]|0))&65535;g=b>>>8&15;i=b>>>4&15;c[(c[3530138]|0)+(h>>>1<<2)>>2]=(i<<4|i)<<3&2016|(b&8|b<<4)>>>3&31|(g<<4|g)<<8&63488;return}switch(f|0){case 59393:{a[c[2406626]|0]=e;return};case 56321:{a[c[3528784]|0]=e;return};case 61440:case 61441:{a[(c[3528816]|0)+(f&1)|0]=e;return};case 59392:{a[c[3528184]|0]=e;return};case 61447:{a[c[3526968]|0]=e&1;return};case 61444:{a[c[2406772]|0]=e;g=c[3531076]|0;b=(e&255)<<12&126976;i=c[9757320+(c[1836236]<<2)>>2]|0;h=b-61440|0;c[i+1036>>2]=g+b;c[i+1040>>2]=g+(b|256);c[i+1044>>2]=g+(b|512);c[i+1048>>2]=g+(b|768);c[i+1052>>2]=g+(b|1024);c[i+1056>>2]=g+(b|1280);c[i+1060>>2]=g+(b|1536);c[i+1064>>2]=g+(b|1792);c[i+1068>>2]=g+(b|2048);c[i+1072>>2]=g+(b|2304);c[i+1076>>2]=g+(b|2560);c[i+1080>>2]=g+(b|2816);c[i+1084>>2]=g+(b|3072);c[i+1088>>2]=g+(b|3328);c[i+1092>>2]=g+(b|3584);c[i+1096>>2]=g+(b|3840);b=240;j=240;while(1){k=g+(h+(j<<8))|0;c[i+76+(j+512<<2)>>2]=k;c[i+76+(j+768<<2)>>2]=k;k=b+1&65535;if((k&65535)>255){break}else{b=k;j=k&65535}}return};case 54278:{a[c[3528338]|0]=e;return};case 56320:{a[c[3528782]|0]=e;return};case 54276:{c[2388390]=0;return};case 56322:{a[c[2385618]|0]=e;return};case 54274:{a[c[3528766]|0]=e&1;return};case 61442:case 61443:{a[(c[3528818]|0)+(f&1)|0]=e;return};case 61446:{a[c[2385720]|0]=e;return};default:{return}}}function dhC(b){b=b|0;var c=0,d=0;c=b&65535;if((c|0)==54272){d=a[9550808]|0}else if((c|0)==54278){d=a[9635536]&127|a[9550810]&-128}else if((c|0)==54279){d=a[9635537]|0}else if((c|0)==54274){d=a[9550809]|0}else{d=0}return d|0}function dhD(a,b){a=a|0;b=b|0;var c=0;c=a&65535;if((c|0)==49152|(c|0)==49153){lS(1,c&1,b);return}else if((c|0)==40960|(c|0)==40961){lS(0,c&1,b);return}else{return}}function dhE(b){b=b|0;var e=0,f=0,g=0.0,i=0.0,j=0,k=0;e=b&65535;if((e|0)==40960|(e|0)==40961){b=c[3541518]|0;if((e&1|0)==0){f=b+296|0;g=+h[f>>3];do{if(g!=0.0){i=+h[6675];if(g-(i+ +gC[c[2429842]&255]())<=0.0){h[f>>3]=0.0;break}j=a[b+307|0]|-128;return j|0}}while(0);j=a[b+307|0]|0;return j|0}if((d[b+304|0]|0)>=16){j=0;return j|0}b=c[2383582]|0;f=c[14168912+(b*252|0)>>2]|0;if((f|0)>15){j=0;return j|0}do{if((f|0)==15){k=c[14168900+(b*252|0)>>2]|0;if((k|0)==0){break}a[14168931+(b*252|0)|0]=gj[k&4095](0)|0}else if((f|0)==14){k=c[14168896+(b*252|0)>>2]|0;if((k|0)==0){break}a[14168930+(b*252|0)|0]=gj[k&4095](0)|0}}while(0);j=a[14168916+(b*252|0)+f|0]|0;return j|0}else if((e|0)==49152|(e|0)==49153){f=c[3541518]|0;if((e&1|0)==0){e=f+19320|0;g=+h[e>>3];do{if(g!=0.0){i=+h[6675];if(g-(i+ +gC[c[2429842]&255]())<=0.0){h[e>>3]=0.0;break}j=a[f+19331|0]|-128;return j|0}}while(0);j=a[f+19331|0]|0;return j|0}if((d[f+19328|0]|0)>=16){j=0;return j|0}f=(c[2383582]|0)+1|0;e=c[14168912+(f*252|0)>>2]|0;if((e|0)>15){j=0;return j|0}do{if((e|0)==14){b=c[14168896+(f*252|0)>>2]|0;if((b|0)==0){break}a[14168930+(f*252|0)|0]=gj[b&4095](0)|0}else if((e|0)==15){b=c[14168900+(f*252|0)>>2]|0;if((b|0)==0){break}a[14168931+(f*252|0)|0]=gj[b&4095](0)|0}}while(0);j=a[14168916+(f*252|0)+e|0]|0;return j|0}else{j=0;return j|0}return 0}function dhF(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5781084+(b*112|0)>>2];c[a+104>>2]=c[5781088+(b*112|0)>>2];c[a+108>>2]=c[5781092+(b*112|0)>>2];d=0;return d|0}function dhG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=5780984+(b*112|0);e=0;return e|0}function dhH(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3720424+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dhI(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>29){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6229752+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dhJ(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0;e=i;i=i+1560|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;B=e+1200|0;D=e+1312|0;E=e+1320|0;F=e+1432|0;G=e+1440|0;H=e+1552|0;c[2415056]=0;c[3529260]=0;c[3529216]=49152;c[3531076]=81920;c[3531074]=212992;c[3530982]=221184;c[3531042]=237568;c[3530910]=237856;c[3530674]=270624;c[3527454]=794912;c[3530476]=925984;c[3530356]=958752;c[3527242]=1220896;c[3527240]=1224992;c[3527238]=1225504;c[3527236]=1226016;c[3530138]=1228064;c[2414764]=1230112;c[2386522]=1230112;c[3529348]=1230368;c[3529304]=1234464;c[2387248]=1236512;c[2386264]=1237536;c[3528338]=1238560;c[3528766]=1238561;c[3528782]=1238562;c[3528784]=1238563;c[2385618]=1238564;c[3528184]=1238565;c[2406626]=1238566;c[3528816]=1238567;c[3528818]=1238569;c[2385720]=1238571;c[3526968]=1238572;c[2406772]=1238573;c[2411818]=1238574;I=0;while(1){if((I|0)>=1024){break}J=9638528+(I<<2)|0;if((c[J>>2]|0)==0){K=63242;break}else{I=I+1|0}}do{if((K|0)==63242){I=gGq(1238574)|0;c[J>>2]=I;if((I|0)==0){break}c[2415056]=I;gGz(I|0,0,1238574);c[3529260]=I;c[3529216]=I+49152;c[3531076]=I+81920;c[3531074]=I+212992;c[3530982]=I+221184;c[3531042]=I+237568;c[3530910]=I+237856;c[3530674]=I+270624;c[3527454]=I+794912;c[3530476]=I+925984;c[3530356]=I+958752;c[3527242]=I+1220896;c[3527240]=I+1224992;c[3527238]=I+1225504;c[3527236]=I+1226016;c[3530138]=I+1228064;L=I+1230112|0;c[2414764]=L;c[2386522]=L;c[3529348]=I+1230368;c[3529304]=I+1234464;c[2387248]=I+1236512;c[2386264]=I+1237536;c[3528338]=I+1238560;c[3528766]=I+1238561;c[3528782]=I+1238562;c[3528784]=I+1238563;c[2385618]=I+1238564;c[3528184]=I+1238565;c[2406626]=I+1238566;c[3528816]=I+1238567;c[3528818]=I+1238569;c[2385720]=I+1238571;c[3526968]=I+1238572;c[2406772]=I+1238573;L=I+1238574|0;c[2411818]=L;c[2414366]=L;if((c[3542200]|0)==0){M=1;i=e;return M|0}L=G+108|0;c[L>>2]=0;N=G+100|0;c[N>>2]=0;O=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[O&16383](G,0)|0;do{if((c[L>>2]|0)!=0){O=c[N>>2]|0;c[H>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](H,0,0)|0;if((O|0)<1){M=1;i=e;return M|0}if((gzL(I,0,0)|0)==0){break}else{M=1}i=e;return M|0}}while(0);I=(c[3529260]|0)+32768|0;if((c[3542200]|0)==0){M=1;i=e;return M|0}N=E+108|0;c[N>>2]=0;L=E+100|0;c[L>>2]=0;O=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[O&16383](E,1)|0;do{if((c[N>>2]|0)!=0){O=c[L>>2]|0;c[F>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](F,1,0)|0;if((O|0)<1){M=1;i=e;return M|0}if((gzL(I,0,1)|0)==0){break}else{M=1}i=e;return M|0}}while(0);I=c[3529216]|0;if((c[3542200]|0)==0){M=1;i=e;return M|0}L=B+108|0;c[L>>2]=0;N=B+100|0;c[N>>2]=0;O=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[O&16383](B,2)|0;do{if((c[L>>2]|0)!=0){O=c[N>>2]|0;c[D>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](D,2,0)|0;if((O|0)<1){M=1;i=e;return M|0}if((gzL(I,0,2)|0)==0){break}else{M=1}i=e;return M|0}}while(0);I=c[3530910]|0;if((c[3542200]|0)==0){M=1;i=e;return M|0}N=z+108|0;c[N>>2]=0;L=z+100|0;c[L>>2]=0;O=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[O&16383](z,3)|0;do{if((c[N>>2]|0)!=0){O=c[L>>2]|0;c[A>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](A,3,0)|0;if((O|0)<1){M=1;i=e;return M|0}if((gzL(I,0,3)|0)==0){break}else{M=1}i=e;return M|0}}while(0);I=c[3530476]|0;if((c[3542200]|0)==0){M=1;i=e;return M|0}L=x+108|0;c[L>>2]=0;N=x+100|0;c[N>>2]=0;O=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[O&16383](x,4)|0;do{if((c[L>>2]|0)!=0){O=c[N>>2]|0;c[y>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](y,4,0)|0;if((O|0)<1){M=1;i=e;return M|0}if((gzL(I,0,4)|0)==0){break}else{M=1}i=e;return M|0}}while(0);if((R6((c[3530356]|0)+1|0,5,2)|0)!=0){M=1;i=e;return M|0}if((R6(c[3530356]|0,6,2)|0)!=0){M=1;i=e;return M|0}if((R6(c[3530674]|0,7,2)|0)!=0){M=1;i=e;return M|0}if((R6((c[3530674]|0)+1|0,8,2)|0)!=0){M=1;i=e;return M|0}if((R6((c[3530674]|0)+65536|0,9,2)|0)!=0){M=1;i=e;return M|0}if((R6((c[3530674]|0)+65537|0,10,2)|0)!=0){M=1;i=e;return M|0}I=c[3531076]|0;if((c[3542200]|0)==0){M=1;i=e;return M|0}N=v+108|0;c[N>>2]=0;L=v+100|0;c[L>>2]=0;O=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[O&16383](v,11)|0;do{if((c[N>>2]|0)!=0){O=c[L>>2]|0;c[w>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](w,11,0)|0;if((O|0)<1){M=1;i=e;return M|0}if((gzL(I,0,11)|0)==0){break}else{M=1}i=e;return M|0}}while(0);I=(c[3531076]|0)+32768|0;if((c[3542200]|0)==0){M=1;i=e;return M|0}L=t+108|0;c[L>>2]=0;N=t+100|0;c[N>>2]=0;O=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[O&16383](t,12)|0;do{if((c[L>>2]|0)!=0){O=c[N>>2]|0;c[u>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](u,12,0)|0;if((O|0)<1){M=1;i=e;return M|0}if((gzL(I,0,12)|0)==0){break}else{M=1}i=e;return M|0}}while(0);I=(c[3531076]|0)+65536|0;if((c[3542200]|0)==0){M=1;i=e;return M|0}N=r+108|0;c[N>>2]=0;L=r+100|0;c[L>>2]=0;O=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[O&16383](r,13)|0;do{if((c[N>>2]|0)!=0){O=c[L>>2]|0;c[s>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](s,13,0)|0;if((O|0)<1){M=1;i=e;return M|0}if((gzL(I,0,13)|0)==0){break}else{M=1}i=e;return M|0}}while(0);I=(c[3531076]|0)+98304|0;if((c[3542200]|0)==0){M=1;i=e;return M|0}L=p+108|0;c[L>>2]=0;N=p+100|0;c[N>>2]=0;O=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[O&16383](p,14)|0;do{if((c[L>>2]|0)!=0){O=c[N>>2]|0;c[q>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](q,14,0)|0;if((O|0)<1){M=1;i=e;return M|0}if((gzL(I,0,14)|0)==0){break}else{M=1}i=e;return M|0}}while(0);I=c[3531074]|0;if((c[3542200]|0)==0){M=1;i=e;return M|0}N=n+108|0;c[N>>2]=0;L=n+100|0;c[L>>2]=0;O=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[O&16383](n,15)|0;do{if((c[N>>2]|0)!=0){O=c[L>>2]|0;c[o>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](o,15,0)|0;if((O|0)<1){M=1;i=e;return M|0}if((gzL(I,0,15)|0)==0){break}else{M=1}i=e;return M|0}}while(0);I=c[3530982]|0;if((c[3542200]|0)==0){M=1;i=e;return M|0}L=l+108|0;c[L>>2]=0;N=l+100|0;c[N>>2]=0;O=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[O&16383](l,16)|0;do{if((c[L>>2]|0)!=0){O=c[N>>2]|0;c[m>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](m,16,0)|0;if((O|0)<1){M=1;i=e;return M|0}if((gzL(I,0,16)|0)==0){break}else{M=1}i=e;return M|0}}while(0);I=c[3531042]|0;if((c[3542200]|0)==0){M=1;i=e;return M|0}N=j+108|0;c[N>>2]=0;L=j+100|0;c[L>>2]=0;O=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[O&16383](j,17)|0;do{if((c[N>>2]|0)!=0){O=c[L>>2]|0;c[k>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](k,17,0)|0;if((O|0)<1){M=1;i=e;return M|0}if((gzL(I,0,17)|0)==0){break}else{M=1}i=e;return M|0}}while(0);I=(c[3531042]|0)+256|0;if((c[3542200]|0)==0){M=1;i=e;return M|0}L=f+108|0;c[L>>2]=0;N=f+100|0;c[N>>2]=0;O=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[O&16383](f,18)|0;do{if((c[L>>2]|0)==0){Q=0}else{O=c[N>>2]|0;c[g>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](g,18,0)|0;if((O|0)<1){M=1;i=e;return M|0}if((gzL(I,0,18)|0)==0){Q=0;break}else{M=1}i=e;return M|0}}while(0);while(1){if((Q|0)>=1024){M=1;K=63445;break}R=9638528+(Q<<2)|0;if((c[R>>2]|0)==0){break}else{Q=Q+1|0}}if((K|0)==63445){i=e;return M|0}I=gGq(131072)|0;c[R>>2]=I;if((I|0)==0){M=1;i=e;return M|0}gGz(I|0,0,131072);N=c[3530910]|0;gGC(I|0,N|0,8192)|0;L=0;do{O=L<<6;gGz(N+O|0,0,64);P=O|4;S=0;while(1){T=P+(c[1238464+(S<<2)>>2]|0)|0;U=(S<<3)+O|0;V=0;do{W=T+(c[611024+(V<<2)>>2]|0)|0;if((d[I+((W|0)/8|0)|0]&128>>>((W&7)>>>0)|0)!=0){W=N+(U+V)|0;a[W]=a[W]|2}V=V+1|0;}while((V|0)<8);V=S+1|0;if((V|0)<8){S=V}else{X=0;break}}do{S=O+(c[1238464+(X<<2)>>2]|0)|0;P=(X<<3)+O|0;V=0;do{U=S+(c[611024+(V<<2)>>2]|0)|0;if((d[I+((U|0)/8|0)|0]&128>>>((U&7)>>>0)|0)!=0){U=N+(P+V)|0;a[U]=a[U]|1}V=V+1|0;}while((V|0)<8);X=X+1|0;}while((X|0)<8);L=L+1|0;}while((L|0)<512);L=c[3527454]|0;O=c[3530674]|0;gGC(L|0,O|0,131072)|0;V=0;do{P=V<<6;gGz(O+P|0,0,64);S=V<<7;U=0;do{T=1<<3-U;W=(c[611088+(U<<2)>>2]|0)+S|0;Y=0;do{Z=W+(c[608544+(Y<<2)>>2]|0)|0;_=(Y<<3)+P|0;$=0;do{aa=Z+(c[610320+($<<2)>>2]|0)|0;if((d[L+((aa|0)/8|0)|0]&128>>>((aa&7)>>>0)|0)!=0){aa=O+(_+$)|0;a[aa]=(d[aa]|T)&255}$=$+1|0;}while(($|0)<8);Y=Y+1|0;}while((Y|0)<8);U=U+1|0;}while((U|0)<4);V=V+1|0;}while((V|0)<8192);V=c[3530476]|0;gGC(I|0,V|0,8192)|0;O=0;do{L=O<<3;U=V+L|0;P=U|0;C=0;a[P]=C&255;C=C>>8;a[P+1|0]=C&255;C=C>>8;a[P+2|0]=C&255;C=C>>8;a[P+3|0]=C&255;P=U+4|0;C=0;a[P]=C&255;C=C>>8;a[P+1|0]=C&255;C=C>>8;a[P+2|0]=C&255;C=C>>8;a[P+3|0]=C&255;P=L|4;U=0;while(1){S=P+(c[611024+(U<<2)>>2]|0)|0;if((d[I+((S|0)/8|0)|0]&128>>>((S&7)>>>0)|0)!=0){S=V+(L+U)|0;a[S]=a[S]|2}S=U+1|0;if((S|0)<8){U=S}else{ab=0;break}}do{U=L+(c[611024+(ab<<2)>>2]|0)|0;if((d[I+((U|0)/8|0)|0]&128>>>((U&7)>>>0)|0)!=0){U=V+(L+ab)|0;a[U]=a[U]|1}ab=ab+1|0;}while((ab|0)<8);O=O+1|0;}while((O|0)<2048);O=c[3530356]|0;gGC(I|0,O|0,65536)|0;V=0;while(1){L=V<<7;gGz(O+L|0,0,128);U=V<<8;P=0;do{S=1<<3-P;Y=(c[611088+(P<<2)>>2]|0)+U|0;T=0;do{W=Y+(c[608544+(T<<2)>>2]|0)|0;$=(T<<3)+L|0;_=0;do{Z=W+(c[610320+(_<<2)>>2]|0)|0;if((d[I+((Z|0)/8|0)|0]&128>>>((Z&7)>>>0)|0)!=0){Z=O+($+_)|0;a[Z]=(d[Z]|S)&255}_=_+1|0;}while((_|0)<8);T=T+1|0;}while((T|0)<16);P=P+1|0;}while((P|0)<4);P=V+1|0;if((P|0)<2048){V=P}else{ac=0;break}}while(1){if((ac|0)>=1024){ad=N;break}ae=9638528+(ac<<2)|0;if((c[ae>>2]|0)==(I|0)){K=63339;break}else{ac=ac+1|0}}if((K|0)==63339){gGr(I);c[ae>>2]=0;ad=c[3530910]|0}N=c[3527242]|0;gGz(N|0,1,4096);V=0;do{O=0;while(1){if((O|0)>=8){break}if((a[ad+(O+V)|0]|0)==0){O=O+1|0}else{K=63344;break}}if((K|0)==63344){K=0;a[N+((V|0)/8|0)|0]=0}V=V+8|0;}while((V|0)<32768);V=c[3530356]|0;N=c[3527236]|0;gGz(N|0,1,2048);I=0;do{O=0;while(1){if((O|0)>=128){break}if((a[V+(O+I)|0]|0)==0){O=O+1|0}else{K=63350;break}}if((K|0)==63350){K=0;a[N+((I|0)/128|0)|0]=0}I=I+128|0;}while((I|0)<262144);I=c[3530476]|0;N=c[3527238]|0;gGz(N|0,1,512);V=0;do{O=0;while(1){if((O|0)>=64){break}if((a[I+(O+V)|0]|0)==0){O=O+1|0}else{K=63356;break}}if((K|0)==63356){K=0;a[N+((V|0)/64|0)|0]=0}V=V+64|0;}while((V|0)<32768);V=c[3527240]|0;N=V+264|0;I=N|0;C=-1;a[I]=C&255;C=C>>8;a[I+1|0]=C&255;C=C>>8;a[I+2|0]=C&255;C=C>>8;a[I+3|0]=C&255;I=N+4|0;C=-1;a[I]=C&255;C=C>>8;a[I+1|0]=C&255;C=C>>8;a[I+2|0]=C&255;C=C>>8;a[I+3|0]=C&255;I=V+280|0;N=I|0;C=-1;a[N]=C&255;C=C>>8;a[N+1|0]=C&255;C=C>>8;a[N+2|0]=C&255;C=C>>8;a[N+3|0]=C&255;N=I+4|0;C=-1;a[N]=C&255;C=C>>8;a[N+1|0]=C&255;C=C>>8;a[N+2|0]=C&255;C=C>>8;a[N+3|0]=C&255;N=V+296|0;I=N|0;C=-1;a[I]=C&255;C=C>>8;a[I+1|0]=C&255;C=C>>8;a[I+2|0]=C&255;C=C>>8;a[I+3|0]=C&255;I=N+4|0;C=-1;a[I]=C&255;C=C>>8;a[I+1|0]=C&255;C=C>>8;a[I+2|0]=C&255;C=C>>8;a[I+3|0]=C&255;I=V+312|0;N=I|0;C=-1;a[N]=C&255;C=C>>8;a[N+1|0]=C&255;C=C>>8;a[N+2|0]=C&255;C=C>>8;a[N+3|0]=C&255;N=I+4|0;C=-1;a[N]=C&255;C=C>>8;a[N+1|0]=C&255;C=C>>8;a[N+2|0]=C&255;C=C>>8;a[N+3|0]=C&255;N=V+328|0;I=N|0;C=-1;a[I]=C&255;C=C>>8;a[I+1|0]=C&255;C=C>>8;a[I+2|0]=C&255;C=C>>8;a[I+3|0]=C&255;I=N+4|0;C=-1;a[I]=C&255;C=C>>8;a[I+1|0]=C&255;C=C>>8;a[I+2|0]=C&255;C=C>>8;a[I+3|0]=C&255;I=V+344|0;N=I|0;C=-1;a[N]=C&255;C=C>>8;a[N+1|0]=C&255;C=C>>8;a[N+2|0]=C&255;C=C>>8;a[N+3|0]=C&255;N=I+4|0;C=-1;a[N]=C&255;C=C>>8;a[N+1|0]=C&255;C=C>>8;a[N+2|0]=C&255;C=C>>8;a[N+3|0]=C&255;N=V+360|0;I=N|0;C=-1;a[I]=C&255;C=C>>8;a[I+1|0]=C&255;C=C>>8;a[I+2|0]=C&255;C=C>>8;a[I+3|0]=C&255;I=N+4|0;C=-1;a[I]=C&255;C=C>>8;a[I+1|0]=C&255;C=C>>8;a[I+2|0]=C&255;C=C>>8;a[I+3|0]=C&255;I=V+376|0;N=I|0;C=-1;a[N]=C&255;C=C>>8;a[N+1|0]=C&255;C=C>>8;a[N+2|0]=C&255;C=C>>8;a[N+3|0]=C&255;N=I+4|0;C=-1;a[N]=C&255;C=C>>8;a[N+1|0]=C&255;C=C>>8;a[N+2|0]=C&255;C=C>>8;a[N+3|0]=C&255;N=V+392|0;I=N|0;C=-1;a[I]=C&255;C=C>>8;a[I+1|0]=C&255;C=C>>8;a[I+2|0]=C&255;C=C>>8;a[I+3|0]=C&255;I=N+4|0;C=-1;a[I]=C&255;C=C>>8;a[I+1|0]=C&255;C=C>>8;a[I+2|0]=C&255;C=C>>8;a[I+3|0]=C&255;I=V+408|0;N=I|0;C=-1;a[N]=C&255;C=C>>8;a[N+1|0]=C&255;C=C>>8;a[N+2|0]=C&255;C=C>>8;a[N+3|0]=C&255;N=I+4|0;C=-1;a[N]=C&255;C=C>>8;a[N+1|0]=C&255;C=C>>8;a[N+2|0]=C&255;C=C>>8;a[N+3|0]=C&255;N=V+424|0;I=N|0;C=-1;a[I]=C&255;C=C>>8;a[I+1|0]=C&255;C=C>>8;a[I+2|0]=C&255;C=C>>8;a[I+3|0]=C&255;I=N+4|0;C=-1;a[I]=C&255;C=C>>8;a[I+1|0]=C&255;C=C>>8;a[I+2|0]=C&255;C=C>>8;a[I+3|0]=C&255;I=V+440|0;N=I|0;C=-1;a[N]=C&255;C=C>>8;a[N+1|0]=C&255;C=C>>8;a[N+2|0]=C&255;C=C>>8;a[N+3|0]=C&255;N=I+4|0;C=-1;a[N]=C&255;C=C>>8;a[N+1|0]=C&255;C=C>>8;a[N+2|0]=C&255;C=C>>8;a[N+3|0]=C&255;N=V+456|0;I=N|0;C=-1;a[I]=C&255;C=C>>8;a[I+1|0]=C&255;C=C>>8;a[I+2|0]=C&255;C=C>>8;a[I+3|0]=C&255;I=N+4|0;C=-1;a[I]=C&255;C=C>>8;a[I+1|0]=C&255;C=C>>8;a[I+2|0]=C&255;C=C>>8;a[I+3|0]=C&255;I=V+472|0;N=I|0;C=-1;a[N]=C&255;C=C>>8;a[N+1|0]=C&255;C=C>>8;a[N+2|0]=C&255;C=C>>8;a[N+3|0]=C&255;N=I+4|0;C=-1;a[N]=C&255;C=C>>8;a[N+1|0]=C&255;C=C>>8;a[N+2|0]=C&255;C=C>>8;a[N+3|0]=C&255;N=V+488|0;I=N|0;C=-1;a[I]=C&255;C=C>>8;a[I+1|0]=C&255;C=C>>8;a[I+2|0]=C&255;C=C>>8;a[I+3|0]=C&255;I=N+4|0;C=-1;a[I]=C&255;C=C>>8;a[I+1|0]=C&255;C=C>>8;a[I+2|0]=C&255;C=C>>8;a[I+3|0]=C&255;I=V+504|0;V=I|0;C=-1;a[V]=C&255;C=C>>8;a[V+1|0]=C&255;C=C>>8;a[V+2|0]=C&255;C=C>>8;a[V+3|0]=C&255;V=I+4|0;C=-1;a[V]=C&255;C=C>>8;a[V+1|0]=C&255;C=C>>8;a[V+2|0]=C&255;C=C>>8;a[V+3|0]=C&255;fwR(0);V=c[2439330]|0;I=(V|0)==0;if(!I){N=V;gGC(9706056,N|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];N=c[3528484]|0;c[2076596]=N;O=c[2417276]|0;c[3541536]=O;c[1836236]=0;P=c[3529260]|0;L=0;U=0;while(1){c[V+76+(U<<2)>>2]=P+(U<<8);T=L+1&65535;if((T&65535)>191){af=0;ah=0;break}else{L=T;U=T&65535}}while(1){U=P+(ah<<8)|0;c[V+76+(ah+512<<2)>>2]=U;c[V+76+(ah+768<<2)>>2]=U;U=af+1&65535;if((U&65535)>191){break}else{af=U;ah=U&65535}}P=c[3529348]|0;c[V+844>>2]=P;c[V+848>>2]=P+256;c[V+852>>2]=P+512;c[V+856>>2]=P+768;c[V+860>>2]=P+1024;c[V+864>>2]=P+1280;c[V+868>>2]=P+1536;c[V+872>>2]=P+1792;c[V+876>>2]=P+2048;c[V+880>>2]=P+2304;c[V+884>>2]=P+2560;c[V+888>>2]=P+2816;c[V+892>>2]=P+3072;c[V+896>>2]=P+3328;c[V+900>>2]=P+3584;c[V+904>>2]=P+3840;U=192;L=192;while(1){c[V+76+(L+256<<2)>>2]=P+((L<<8)-49152);T=U+1&65535;if((T&65535)>207){ai=192;aj=192;break}else{U=T;L=T&65535}}while(1){L=P+((aj<<8)-49152)|0;c[V+76+(aj+512<<2)>>2]=L;c[V+76+(aj+768<<2)>>2]=L;L=ai+1&65535;if((L&65535)>207){break}else{ai=L;aj=L&65535}}P=c[2386522]|0;c[V+908>>2]=P;c[V+1932>>2]=P;c[V+2956>>2]=P;c[V+3980>>2]=P;P=c[2387248]|0;c[V+940>>2]=P;L=P+256|0;c[V+944>>2]=L;U=P+512|0;c[V+948>>2]=U;T=P+768|0;c[V+952>>2]=T;c[V+2988>>2]=P;c[V+4012>>2]=P;c[V+2992>>2]=L;c[V+4016>>2]=L;c[V+2996>>2]=U;c[V+4020>>2]=U;c[V+3e3>>2]=T;c[V+4024>>2]=T;T=c[2386264]|0;c[V+972>>2]=T;U=T+256|0;c[V+976>>2]=U;L=T+512|0;c[V+980>>2]=L;P=T+768|0;c[V+984>>2]=P;c[V+1996>>2]=T;c[V+2e3>>2]=U;c[V+2004>>2]=L;c[V+2008>>2]=P;c[V+3020>>2]=T;c[V+4044>>2]=T;c[V+3024>>2]=U;c[V+4048>>2]=U;c[V+3028>>2]=L;c[V+4052>>2]=L;c[V+3032>>2]=P;c[V+4056>>2]=P;c[V+4184>>2]=1884;c[V+4180>>2]=3560;if(!I){P=V;gGC(P|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=N;c[2417276]=O;c[1836236]=-1;fwR(1);P=c[2439331]|0;L=(P|0)==0;if(!L){U=P;gGC(9706056,U|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];U=c[3528485]|0;c[2076596]=U;T=c[2417277]|0;c[3541536]=T;c[1836236]=1;S=c[3529216]|0;Y=0;_=0;while(1){c[P+76+(_<<2)>>2]=S+(_<<8);$=Y+1&65535;if(($&65535)>127){ak=0;al=0;break}else{Y=$;_=$&65535}}while(1){_=S+(al<<8)|0;c[P+76+(al+512<<2)>>2]=_;c[P+76+(al+768<<2)>>2]=_;_=ak+1&65535;if((_&65535)>127){break}else{ak=_;al=_&65535}}S=c[3529304]|0;c[P+588>>2]=S;_=S+256|0;c[P+592>>2]=_;Y=S+512|0;c[P+596>>2]=Y;O=S+768|0;c[P+600>>2]=O;N=S+1024|0;c[P+604>>2]=N;V=S+1280|0;c[P+608>>2]=V;I=S+1536|0;c[P+612>>2]=I;$=S+1792|0;c[P+616>>2]=$;c[P+1612>>2]=S;c[P+1616>>2]=_;c[P+1620>>2]=Y;c[P+1624>>2]=O;c[P+1628>>2]=N;c[P+1632>>2]=V;c[P+1636>>2]=I;c[P+1640>>2]=$;c[P+2636>>2]=S;c[P+3660>>2]=S;c[P+2640>>2]=_;c[P+3664>>2]=_;c[P+2644>>2]=Y;c[P+3668>>2]=Y;c[P+2648>>2]=O;c[P+3672>>2]=O;c[P+2652>>2]=N;c[P+3676>>2]=N;c[P+2656>>2]=V;c[P+3680>>2]=V;c[P+2660>>2]=I;c[P+3684>>2]=I;c[P+2664>>2]=$;c[P+3688>>2]=$;c[P+4184>>2]=1558;c[P+4180>>2]=554;if(!L){$=P;gGC($|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=U;c[2417277]=T;c[1836236]=-1;Vr(2,125e4,0,1440,34,0);c[3542287]=2294;c[3542288]=0;c[3542289]=0;c[3542290]=0;c[2438228]=25e5;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=818;h[745419]=.4;a[3203368]=1;h[745418]=.15;a[3203360]=1;h[745417]=.15;a[3203352]=1;h[745416]=.15;a[3203344]=1;h[745415]=.4;a[3203336]=1;h[745414]=.15;a[3203328]=1;h[745413]=.15;a[3203320]=1;h[745412]=.15;a[3203312]=1;$=c[642608+(c[2436]<<2)>>2]|0;I=c[$+128>>2]|0;if((c[$+52>>2]&4|0)==0){c[2113068]=I;V=c[$+132>>2]|0;c[2113070]=V;c[2443814]=I;c[2440436]=V;am=I;an=V}else{c[2113070]=I;V=c[$+132>>2]|0;c[2113068]=V;c[2440436]=I;c[2443814]=V;am=V;an=I}I=ag(am<<1,an)|0;V=gGq(I)|0;c[2112926]=V;if((V|0)!=0){gGz(V|0,0,I|0)}I=c[2414764]|0;gGz(I|0,0,(c[2411818]|0)-I|0);I=c[2439330]|0;V=(I|0)==0;if(!V){$=I;gGC(9706056,$|0,76)|0}$=c[2438118]|0;c[2433530]=$;N=c[3528484]|0;c[2076596]=N;O=c[2417276]|0;c[3541536]=O;c[1836236]=0;gGz(9706056,0,76);if(!V){V=I;gGC(V|0,9706056,76)|0}c[2438118]=$;c[3528484]=N;c[2417276]=O;c[1836236]=-1;O=c[2439331]|0;N=(O|0)==0;if(!N){$=O;gGC(9706056,$|0,76)|0}$=c[2438119]|0;c[2433530]=$;V=c[3528485]|0;c[2076596]=V;I=c[2417277]|0;c[3541536]=I;c[1836236]=1;gGz(9706056,0,76);if(!N){N=O;gGC(N|0,9706056,76)|0}c[2438119]=$;c[3528485]=V;c[2417277]=I;c[1836236]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){I=0;do{lN(I);mB(I);I=I+1|0;}while((I|0)<(c[2385508]|0))}c[2388390]=0;M=0;i=e;return M|0}}while(0);c[2415056]=0;M=1;i=e;return M|0}function dhK(){var b=0,d=0,e=0,f=0;c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}fwZ();b=c[3541518]|0;if((b|0)!=0){gGr(b|0);c[3541518]=0}if((c[2385508]|0)>0){c[2113008]=0;c[2076598]=0;c[2383582]=0}c[2438228]=0;c[2433526]=0;c[2406676]=0;c[3528472]=0;b=c[2406680]|0;if((b|0)!=0){gGr(b);c[2406680]=0}c[2385508]=0;c[2432978]=0;a[64240]=0;b=c[2415056]|0;d=0;while(1){if((d|0)>=1024){e=63464;break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==(b|0)){break}else{d=d+1|0}}if((e|0)==63464){c[2415056]=0;return 0}gGr(b);c[f>>2]=0;c[2415056]=0;return 0}function dhL(){var d=0,e=0,f=0,g=0,i=0,j=0;d=(c[2388390]|0)+1|0;c[2388390]=d;if((d|0)>179){d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=i;c[1836236]=-1;i=c[2439331]|0;g=(i|0)==0;if(!g){f=i;gGC(9706056,f|0,76)|0}f=c[2438119]|0;c[2433530]=f;e=c[3528485]|0;c[2076596]=e;d=c[2417277]|0;c[3541536]=d;c[1836236]=1;gGz(9706056,0,76);if(!g){g=i;gGC(g|0,9706056,76)|0}c[2438119]=f;c[3528485]=e;c[2417277]=d;c[1836236]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){d=0;do{lN(d);mB(d);d=d+1|0;}while((d|0)<(c[2385508]|0))}c[2388390]=0}if((a[9624832]|0)!=0){d=c[2414764]|0;gGz(d|0,0,(c[2411818]|0)-d|0);d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=i;c[1836236]=-1;i=c[2439331]|0;g=(i|0)==0;if(!g){f=i;gGC(9706056,f|0,76)|0}f=c[2438119]|0;c[2433530]=f;e=c[3528485]|0;c[2076596]=e;d=c[2417277]|0;c[3541536]=d;c[1836236]=1;gGz(9706056,0,76);if(!g){g=i;gGC(g|0,9706056,76)|0}c[2438119]=f;c[3528485]=e;c[2417277]=d;c[1836236]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){d=0;do{lN(d);mB(d);d=d+1|0;}while((d|0)<(c[2385508]|0))}c[2388390]=0}d=c[2385548]|0;if((d|0)>0){gGz(9752472,0,((d|0)>1?d<<2:4)|0)}c[2433530]=0;gGz(9550808,-1|0,3);d=0;e=-1;f=-1;g=-1;do{e=((a[9634176+d|0]&1)<<d^e&255)&255;f=((a[9631952+d|0]&1)<<d^f&255)&255;g=((a[9629872+d|0]&1)<<d^g&255)&255;d=d+1|0;}while((d|0)<8);a[9550808]=e;a[9550809]=f;a[9550810]=g;g=0;do{f=c[2439330]|0;if((f|0)!=0){e=f;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;e=c[2438118]|0;c[2433530]=e;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;if((a[f+4188|0]|0)==0){f=gfc(8333)|0;j=(c[2433530]|0)+f|0}else{j=e+8333|0}c[2433530]=j;if((g|0)==9){a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0}e=c[1836236]|0;f=c[9757320+(e<<2)>>2]|0;if((f|0)!=0){d=f;gGC(d|0,9706056,76)|0}c[9752472+(e<<2)>>2]=c[2433530];c[14113936+(e<<2)>>2]=c[2076596];c[9669104+(e<<2)>>2]=c[3541536];c[1836236]=-1;e=c[2439331]|0;if((e|0)!=0){d=e;gGC(9706056,d|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;Sb(g*4166|0);d=c[1836236]|0;e=c[9757320+(d<<2)>>2]|0;if((e|0)!=0){f=e;gGC(f|0,9706056,76)|0}c[9752472+(d<<2)>>2]=c[2433530];c[14113936+(d<<2)>>2]=c[2076596];c[9669104+(d<<2)>>2]=c[3541536];c[1836236]=-1;g=g+1|0;}while((g|0)<10);g=c[2439331]|0;if((g|0)!=0){j=g;gGC(9706056,j|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;j=c[2438228]|0;g=gGS(-442236928,19867,j,(j|0)<0|0?-1:0)|0;j=g;Sb(41666);g=c[2443830]|0;if((g|0)<1073676288){c[2443830]=g-j}g=c[2443831]|0;if((g|0)<1073676288){c[2443831]=g-j}g=(c[3528512]|0)-j|0;c[3528512]=(g|0)<0?0:g;g=c[2112964]|0;if((g|0)!=0){gg[c[3542122]&4095](g,a[9688]|0?534:0)}g=c[1836236]|0;j=c[9757320+(g<<2)>>2]|0;if((j|0)!=0){d=j;gGC(d|0,9706056,76)|0}c[9752472+(g<<2)>>2]=c[2433530];c[14113936+(g<<2)>>2]=c[2076596];c[9669104+(g<<2)>>2]=c[3541536];c[1836236]=-1;if((c[2112968]|0)==0){return 0}dhM()|0;return 0}function dhM(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;if((a[9547840]|0)!=0){e=c[2387248]|0;f=c[3530138]|0;g=0;do{h=(d[e+g|0]<<8|d[e+(g|1)|0])&65535;i=h>>>8&15;j=h>>>4&15;c[f+(g>>>1<<2)>>2]=(j<<4|j)<<3&2016|(h&8|h<<4)>>>3&31|(i<<4|i)<<8&63488;g=g+2|0;}while((g|0)<1024);a[9547840]=0}g=c[2385720]|0;f=a[g]|0;do{if((f&16)==0){e=c[3528818]|0;i=d[e]|0;h=i&7;j=c[3528816]|0;k=d[j]|0;l=k&7;m=(d[e+1|0]<<8|i)>>>3;i=(d[j+1|0]<<8|k)>>>3;k=(f&255)<<9&7680;j=c[3531076]|0;e=c[3526968]|0;n=c[3531074]|0;o=c[2112926]|0;p=c[3530674]|0;q=0;do{r=q&31;s=(q|0)/32|0;t=d[j+((s+i<<7)+256&130944|r+m&127)|0]|k;Sj(o,t,((r<<3|h)^7)-14|0,((s<<3|l)^7)-7|0,a[n+((d[e]<<8)+t)|0]&15,4,256,p);q=q+1|0;}while((q|0)<1024)}else{q=ag(c[2113070]|0,c[2113068]|0)|0;if((q|0)<=0){break}p=c[2112926]|0;e=0;do{b[p+(e<<1)>>1]=256;e=e+1|0;}while((e|0)<(q|0))}}while(0);dhO(0,36);f=a[g]|0;if((f&16)==0){g=c[3528818]|0;q=d[g]|0;e=q&7;p=c[3528816]|0;n=d[p]|0;l=n&7;h=(d[g+1|0]<<8|q)>>>3;q=(d[p+1|0]<<8|n)>>>3;n=(f&255)<<9&7680;f=c[3531076]|0;p=c[3526968]|0;g=c[3531074]|0;o=c[2112926]|0;k=c[3530674]|0;m=c[3527240]|0;i=c[2113070]|0;j=c[2113068]|0;t=0;while(1){s=t&31;r=(t|0)/32|0;u=d[f+((r+q<<7)+256&130944|s+h&127)|0]|n;v=d[g+((d[p]<<8)+u)|0]|0;L75465:do{if((v&16|0)==0){w=((s<<3|e)^7)-14|0;x=v<<4&240;y=u<<6;z=((r<<3|l)^7)-7|0;A=0;while(1){if((z|0)>-1&(z|0)<(i|0)){B=(A<<3)+y|0;C=ag(j,z)|0;D=w;E=0;while(1){do{if((D|0)>=0&(D|0)<(j|0)){F=x|d[k+(B+E)|0]|256;if((a[m+F|0]|0)==0){break}b[o+(C+D<<1)>>1]=F&65535}}while(0);F=E+1|0;if((F|0)<8){D=D+1|0;E=F}else{break}}}E=A+1|0;if((E|0)>=8){break L75465}z=z+1|0;A=E}}}while(0);r=t+1|0;if((r|0)<1024){t=r}else{G=o;break}}}else{G=c[2112926]|0}dhO(36,156);o=(c[2406626]|0)==0;t=c[3531042]|0;m=c[2386264]|0;k=c[3527242]|0;j=c[3530910]|0;i=c[2113068]|0;l=c[2113070]|0;e=c[3528184]|0;p=512;do{g=p<<3&248;n=(p|0)/32|0;if(o){H=n;I=a[t+((n>>3)+256)|0]&15}else{h=a[t+n|0]|0;if((h&255)<8){q=n-(d[e]|0)|0;J=q;K=a[t+q|0]|0}else{J=n;K=h}H=J;I=K&7|16}h=d[m+(H>>>3<<5|g>>>3)|0]<<3|H&7;if((a[k+h|0]|0)==0){n=g-8|0;g=H-16|0;q=I<<2;f=h<<3;c[2112928]=j+f;h=(ag(i,g)|0)+n|0;if(!((g|0)>=(l|0)|(g|0)<0)){g=0;do{r=g+n|0;do{if((r|0)>-1&(r|0)<(i|0)){u=a[j+(f+g)|0]|0;if(u<<24>>24==0){break}b[G+(h+g<<1)>>1]=u&255|q}}while(0);g=g+1|0;}while((g|0)<8)}c[2112928]=j+(f+8)}p=p+1|0;}while((p|0)<7680);p=a[c[2385618]|0]|0;if((p&16)!=0){L=c[3530138]|0;R8(L);return 0}j=d[c[3528784]|0]|0;i=j&7;l=d[c[3528782]|0]|0;I=l&7;H=j>>>3;j=l>>>3;l=(p&255)<<11&6144;p=c[3530982]|0;k=c[3527238]|0;m=c[3530476]|0;K=0;do{J=(K|0)/32|0;t=d[p+(K+H&31|l|(J+j<<5)+1088&2016)|0]|0;if((a[k+t|0]|0)==0){Sr(G,t,((K<<3&248|i)^7)-14|0,((J<<3|I)^7)-7|0,0,2,0,0,m)}K=K+1|0;}while((K|0)<1024);L=c[3530138]|0;R8(L);return 0}function dhN(a,e){a=a|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+16|0;g=f|0;if((e|0)!=0){c[e>>2]=169730}if((a&96|0)!=0){h=c[2414764]|0;c[g>>2]=h;c[g+4>>2]=(c[2411818]|0)-h;c[g+12>>2]=196728;h=c[2076592]|0;gj[h&4095](g)|0;fw$(a);Vx(a,e)}if((a&2|0)==0){i=f;return 0}a=c[2439330]|0;if((a|0)!=0){e=a;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];e=c[3528484]|0;c[2076596]=e;g=c[2417276]|0;c[3541536]=g;c[1836236]=0;h=c[3531076]|0;j=(d[c[2406772]|0]|0)<<12&126976;k=j-61440|0;c[a+1036>>2]=h+j;c[a+1040>>2]=h+(j|256);c[a+1044>>2]=h+(j|512);c[a+1048>>2]=h+(j|768);c[a+1052>>2]=h+(j|1024);c[a+1056>>2]=h+(j|1280);c[a+1060>>2]=h+(j|1536);c[a+1064>>2]=h+(j|1792);c[a+1068>>2]=h+(j|2048);c[a+1072>>2]=h+(j|2304);c[a+1076>>2]=h+(j|2560);c[a+1080>>2]=h+(j|2816);c[a+1084>>2]=h+(j|3072);c[a+1088>>2]=h+(j|3328);c[a+1092>>2]=h+(j|3584);c[a+1096>>2]=h+(j|3840);j=240;l=240;while(1){m=h+(k+(l<<8))|0;c[a+76+(l+512<<2)>>2]=m;c[a+76+(l+768<<2)>>2]=m;m=j+1&65535;if((m&65535)>255){break}else{j=m;l=m&65535}}l=a;gGC(l|0,9706056,76)|0;c[2438118]=c[2433530];c[3528484]=e;c[2417276]=g;c[1836236]=-1;i=f;return 0}function dhO(e,f){e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;g=c[2386522]|0;if((e|0)>=(f|0)){return}h=c[3527236]|0;i=c[3530356]|0;j=c[2113070]|0;k=c[2113068]|0;l=c[2112926]|0;m=e;do{e=d[g+(m+101)|0]|0;n=d[g+(m+102)|0]|0;o=(n<<3&768|e)<<1&1792|e&127;if((a[h+o|0]|0)==0){e=o<<7;o=((n&16|0)!=0?0:7)|((n&8|0)!=0?120:0);p=n<<4&112|128;n=(d[g+(m+103)|0]|0)-8|0;q=223-(d[g+(m+100)|0]|0)|0;r=0;while(1){s=r<<3;L75539:do{if((q|0)>-1){t=(q|0)<(j|0);u=ag(k,q)|0;v=n;w=0;while(1){x=a[i+((w+s^o)+e)|0]|0;if(x<<24>>24!=0&t&(v|0)>-1&(v|0)<(k|0)){b[l+(u+v<<1)>>1]=(x&255)+p&65535}x=w+1|0;if((x|0)>=8){break L75539}v=v+1|0;w=x}}}while(0);s=r+1|0;if((s|0)<16){q=q+1|0;r=s}else{break}}}m=m+4|0;}while((m|0)<(f|0));return}function dhP(a){a=a|0;var b=0,d=0;b=(c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,25e5,0)|0;return a|0}function dhQ(){return+(+((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)/25.0e5)}function dhR(b){b=b|0;return a[c[3528338]|0]|0}function dhS(b){b=b|0;var c=0,d=0;c=b&65535;switch(c|0){case 63488:case 63489:case 63490:case 63491:case 63492:case 63493:case 63494:case 63495:case 63496:case 63497:{d=a[9550792+(c&15)|0]|0;break};case 63503:{d=a[9550802]|0;break};default:{d=0}}return d|0}function dhT(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=d&65535;if((f&61440|0)==57344){d=f&2047;g=c[2387246]|0;a[g+d|0]=e;h=ga(b[g+(f&2046)>>1]|0)|0;g=(h&65535)>>>4;i=h&255;j=(h&65535)>>>8;c[(c[3530136]|0)+(d>>>1<<2)>>2]=((j&8|j<<4&255)&255)>>>3|((i&12|i<<4)&255)<<3&2016|((g&8|g<<4&255)&255)<<8&63488;return}switch(f|0){case 63493:{b[(c[3527472]|0)+2>>1]=e&255;return};case 63495:{a[14115056]=e&1;return};case 63489:{f=c[3527456]|0;b[f>>1]=b[f>>1]&255|(e&255)<<8;return};case 63490:{b[(c[3527456]|0)+2>>1]=e&255;return};case 63494:{a[14113344]=e;a[6939752]=1;return};case 63492:{f=c[3527472]|0;b[f>>1]=b[f>>1]&255|(e&255)<<8;return};case 63491:{f=c[3527472]|0;b[f>>1]=b[f>>1]&-256|e&255;return};case 63496:{f=(e&255)<<8;g=f&63488;i=g|65536;c[3529374]=i;j=c[3529258]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;c[d+1036>>2]=j+i;c[d+1040>>2]=j+(g|65792);c[d+1044>>2]=j+(g|66048);c[d+1048>>2]=j+(g|66304);c[d+1052>>2]=j+(g|66560);c[d+1056>>2]=j+(g|66816);c[d+1060>>2]=j+(g|67072);c[d+1064>>2]=j+(f|67328);f=c[3529374]|0;g=j+f|0;c[d+3084>>2]=g;c[d+4108>>2]=g;g=j+(f+256)|0;c[d+3088>>2]=g;c[d+4112>>2]=g;g=j+(f+512)|0;c[d+3092>>2]=g;c[d+4116>>2]=g;g=j+(f+768)|0;c[d+3096>>2]=g;c[d+4120>>2]=g;g=j+(f+1024)|0;c[d+3100>>2]=g;c[d+4124>>2]=g;g=j+(f+1280)|0;c[d+3104>>2]=g;c[d+4128>>2]=g;g=j+(f+1536)|0;c[d+3108>>2]=g;c[d+4132>>2]=g;g=j+(f+1792)|0;c[d+3112>>2]=g;c[d+4136>>2]=g;return};case 63488:{g=c[3527456]|0;b[g>>1]=b[g>>1]&-256|e&255;return};default:{return}}}function dhU(b){b=b|0;return(b<<16>>16==-16384?a[14113344]|0:0)|0}function dhV(b,e){b=b|0;e=e|0;var f=0;f=b&65535;if((f&65408|0)==8192){a[(c[3529214]|0)+f|0]=e;return}if((f|0)==32768|(f|0)==40960){a[(c[3540984]|0)+5885|0]=e;return}else if((f|0)==49152){if(!(a[7303752]|0)){return}c[2385728]=(e&255)<<8;c[2415126]=9662152;c[2415540]=0;return}else if((f|0)==50176|(f|0)==53248){c[2385730]=((e&255)<<8)+256;return}else if((f|0)==51200|(f|0)==57344){if(!(a[7303752]|0)){return}c[2415126]=9662152;h[1207773]=+(((e&15)>>>0)/15|0|0);c[2415548]=3;return}else if((f|0)==32769|(f|0)==40961){f=c[3540984]|0;b=c[f+5876>>2]|0;if((b|0)!=0){gg[b&4095](c[f+5880>>2]|0,0)}lH(f,d[f+5885|0]|0,e&255);return}else{return}}function dhW(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6488068+(b*112|0)>>2];c[a+104>>2]=c[6488072+(b*112|0)>>2];c[a+108>>2]=c[6488076+(b*112|0)>>2];d=0;return d|0}function dhX(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=6487968+(b*112|0);e=0;return e|0}function dhY(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5094688+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dhZ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>37){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6809432+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dh_(){var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;d=i;i=i+840|0;e=d|0;f=d+112|0;g=d+120|0;j=d+232|0;k=d+240|0;l=d+352|0;m=d+360|0;n=d+472|0;o=d+480|0;p=d+592|0;q=d+600|0;r=d+712|0;s=d+720|0;t=d+832|0;c[2432764]=0;a[7303752]=1;c[3528912]=16384;c[2415054]=0;c[3529258]=0;c[3529214]=131072;c[2386672]=163840;c[3530908]=180224;c[3530672]=245760;c[3530474]=770048;c[3530354]=1294336;c[2414762]=1818624;c[3529346]=1818624;c[3529302]=1822720;c[2387246]=1824768;c[3529510]=1826816;c[3531096]=1828864;c[3530978]=1829888;c[2386520]=1830912;c[3527472]=1832960;c[3527456]=1832964;c[3530136]=1832968;c[2411816]=1837064;u=0;while(1){if((u|0)>=1024){break}v=9638528+(u<<2)|0;if((c[v>>2]|0)==0){w=63681;break}else{u=u+1|0}}do{if((w|0)==63681){u=gGq(1837064)|0;c[v>>2]=u;if((u|0)==0){break}c[2415054]=u;gGz(u|0,0,1837064);c[3529258]=u;c[3529214]=u+131072;c[2386672]=u+163840;x=c[3528912]|0;c[3530908]=u+(x+163840);c[3530672]=u+(x+229376);c[3530474]=u+(x+753664);c[3530354]=u+(x+1277952);y=u+(x+1802240)|0;c[2414762]=y;c[3529346]=y;c[3529302]=u+(x+1806336);c[2387246]=u+(x+1808384);c[3529510]=u+(x+1810432);c[3531096]=u+(x+1812480);c[3530978]=u+(x+1813504);c[2386520]=u+(x+1814528);c[3527472]=u+(x+1816576);c[3527456]=u+(x+1816580);c[3530136]=u+(x+1816584);y=u+(x+1820680)|0;c[2411816]=y;c[2414364]=y;fwR(0);y=c[2439330]|0;x=(y|0)==0;if(!x){u=y;gGC(9706056,u|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];u=c[3528484]|0;c[2076596]=u;z=c[2417276]|0;c[3541536]=z;c[1836236]=0;A=c[3529258]|0;B=0;C=0;while(1){c[y+76+(C<<2)>>2]=A+(C<<8);D=B+1&65535;if((D&65535)>191){E=0;F=0;break}else{B=D;C=D&65535}}while(1){C=A+(F<<8)|0;c[y+76+(F+512<<2)>>2]=C;c[y+76+(F+768<<2)>>2]=C;C=E+1&65535;if((C&65535)>191){break}else{E=C;F=C&65535}}A=c[3529346]|0;c[y+844>>2]=A;c[y+848>>2]=A+256;c[y+852>>2]=A+512;c[y+856>>2]=A+768;c[y+860>>2]=A+1024;c[y+864>>2]=A+1280;c[y+868>>2]=A+1536;c[y+872>>2]=A+1792;c[y+876>>2]=A+2048;c[y+880>>2]=A+2304;c[y+884>>2]=A+2560;c[y+888>>2]=A+2816;c[y+892>>2]=A+3072;c[y+896>>2]=A+3328;c[y+900>>2]=A+3584;c[y+904>>2]=A+3840;C=192;B=192;while(1){c[y+76+(B+256<<2)>>2]=A+((B<<8)-49152);D=C+1&65535;if((D&65535)>207){G=192;H=192;break}else{C=D;B=D&65535}}while(1){B=A+((H<<8)-49152)|0;c[y+76+(H+512<<2)>>2]=B;c[y+76+(H+768<<2)>>2]=B;B=G+1&65535;if((B&65535)>207){break}else{G=B;H=B&65535}}A=c[3529510]|0;c[y+908>>2]=A;B=A+256|0;c[y+912>>2]=B;C=A+512|0;c[y+916>>2]=C;D=A+768|0;c[y+920>>2]=D;I=A+1024|0;c[y+924>>2]=I;J=A+1280|0;c[y+928>>2]=J;K=A+1536|0;c[y+932>>2]=K;L=A+1792|0;c[y+936>>2]=L;c[y+1932>>2]=A;c[y+1936>>2]=B;c[y+1940>>2]=C;c[y+1944>>2]=D;c[y+1948>>2]=I;c[y+1952>>2]=J;c[y+1956>>2]=K;c[y+1960>>2]=L;L=c[3530978]|0;c[y+940>>2]=L;K=L+256|0;c[y+944>>2]=K;J=L+512|0;c[y+948>>2]=J;I=L+768|0;c[y+952>>2]=I;c[y+1964>>2]=L;c[y+1968>>2]=K;c[y+1972>>2]=J;c[y+1976>>2]=I;I=c[3531096]|0;c[y+956>>2]=I;J=I+256|0;c[y+960>>2]=J;K=I+512|0;c[y+964>>2]=K;L=I+768|0;c[y+968>>2]=L;c[y+1980>>2]=I;c[y+1984>>2]=J;c[y+1988>>2]=K;c[y+1992>>2]=L;L=c[2386520]|0;c[y+972>>2]=L;K=L+256|0;c[y+976>>2]=K;J=L+512|0;c[y+980>>2]=J;I=L+768|0;c[y+984>>2]=I;D=L+1024|0;c[y+988>>2]=D;C=L+1280|0;c[y+992>>2]=C;B=L+1536|0;c[y+996>>2]=B;A=L+1792|0;c[y+1e3>>2]=A;c[y+1996>>2]=L;c[y+2e3>>2]=K;c[y+2004>>2]=J;c[y+2008>>2]=I;c[y+2012>>2]=D;c[y+2016>>2]=C;c[y+2020>>2]=B;c[y+2024>>2]=A;A=c[2387246]|0;c[y+1004>>2]=A;c[y+1008>>2]=A+256;c[y+1012>>2]=A+512;c[y+1016>>2]=A+768;c[y+1020>>2]=A+1024;c[y+1024>>2]=A+1280;c[y+1028>>2]=A+1536;c[y+1032>>2]=A+1792;c[y+4184>>2]=2574;c[y+4180>>2]=172;if(!x){A=y;gGC(A|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=u;c[2417276]=z;c[1836236]=-1;fwR(1);A=c[2439331]|0;B=(A|0)==0;if(!B){C=A;gGC(9706056,C|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];C=c[3528485]|0;c[2076596]=C;D=c[2417277]|0;c[3541536]=D;c[1836236]=1;I=c[3529214]|0;J=0;K=0;while(1){c[A+76+(K<<2)>>2]=I+(K<<8);L=J+1&65535;if((L&65535)>63){M=0;N=0;break}else{J=L;K=L&65535}}while(1){K=I+(N<<8)|0;c[A+76+(N+512<<2)>>2]=K;c[A+76+(N+768<<2)>>2]=K;K=M+1&65535;if((K&65535)>63){break}else{M=K;N=K&65535}}I=c[3529302]|0;c[A+332>>2]=I;K=I+256|0;c[A+336>>2]=K;J=I+512|0;c[A+340>>2]=J;z=I+768|0;c[A+344>>2]=z;u=I+1024|0;c[A+348>>2]=u;y=I+1280|0;c[A+352>>2]=y;x=I+1536|0;c[A+356>>2]=x;L=I+1792|0;c[A+360>>2]=L;c[A+1356>>2]=I;c[A+1360>>2]=K;c[A+1364>>2]=J;c[A+1368>>2]=z;c[A+1372>>2]=u;c[A+1376>>2]=y;c[A+1380>>2]=x;c[A+1384>>2]=L;c[A+2380>>2]=I;c[A+3404>>2]=I;c[A+2384>>2]=K;c[A+3408>>2]=K;c[A+2388>>2]=J;c[A+3412>>2]=J;c[A+2392>>2]=z;c[A+3416>>2]=z;c[A+2396>>2]=u;c[A+3420>>2]=u;c[A+2400>>2]=y;c[A+3424>>2]=y;c[A+2404>>2]=x;c[A+3428>>2]=x;c[A+2408>>2]=L;c[A+3432>>2]=L;c[A+4184>>2]=2064;c[A+4180>>2]=2480;if(!B){L=A;gGC(L|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=C;c[2417277]=D;c[1836236]=-1;L=e+108|0;x=e+100|0;y=c[3529258]|0;if((c[3542200]|0)==0){O=1;i=d;return O|0}c[L>>2]=0;c[x>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,0)|0;do{if((c[L>>2]|0)!=0){u=c[x>>2]|0;c[f>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](f,0,0)|0;if((u|0)<1){O=1;i=d;return O|0}if((gzL(y,0,0)|0)==0){break}else{O=1}i=d;return O|0}}while(0);y=(c[3529258]|0)+32768|0;if((c[3542200]|0)==0){O=1;i=d;return O|0}c[L>>2]=0;c[x>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,1)|0;do{if((c[L>>2]|0)!=0){D=c[x>>2]|0;c[f>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](f,1,0)|0;if((D|0)<1){O=1;i=d;return O|0}if((gzL(y,0,1)|0)==0){break}else{O=1}i=d;return O|0}}while(0);y=(c[3529258]|0)+65536|0;if((c[3542200]|0)==0){O=1;i=d;return O|0}c[L>>2]=0;c[x>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,2)|0;do{if((c[L>>2]|0)!=0){D=c[x>>2]|0;c[f>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](f,2,0)|0;if((D|0)<1){O=1;i=d;return O|0}if((gzL(y,0,2)|0)==0){break}else{O=1}i=d;return O|0}}while(0);y=c[3529214]|0;if((c[3542200]|0)==0){O=1;i=d;return O|0}x=g+108|0;c[x>>2]=0;L=g+100|0;c[L>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,3)|0;do{if((c[x>>2]|0)!=0){D=c[L>>2]|0;c[j>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](j,3,0)|0;if((D|0)<1){O=1;i=d;return O|0}if((gzL(y,0,3)|0)==0){break}else{O=1}i=d;return O|0}}while(0);y=c[3530908]|0;if((c[3542200]|0)==0){O=1;i=d;return O|0}L=k+108|0;c[L>>2]=0;x=k+100|0;c[x>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,4)|0;do{if((c[L>>2]|0)!=0){D=c[x>>2]|0;c[l>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](l,4,0)|0;if((D|0)<1){O=1;i=d;return O|0}if((gzL(y,0,4)|0)==0){break}else{O=1}i=d;return O|0}}while(0);y=m+108|0;x=m+100|0;L=o+108|0;D=o+100|0;C=q+108|0;A=q+100|0;B=0;while(1){u=B<<15;z=(c[3530672]|0)+u|0;J=B+5|0;if((c[3542200]|0)==0){O=1;w=63747;break}c[y>>2]=0;c[x>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,J)|0;if((c[y>>2]|0)!=0){K=c[x>>2]|0;c[n>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](n,J,0)|0;if((K|0)<1){O=1;w=63757;break}if((gzL(z,0,J)|0)!=0){O=1;w=63752;break}}J=(c[3530474]|0)+u|0;z=B+9|0;if((c[3542200]|0)==0){O=1;w=63755;break}c[L>>2]=0;c[D>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](o,z)|0;if((c[L>>2]|0)!=0){K=c[D>>2]|0;c[p>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](p,z,0)|0;if((K|0)<1){O=1;w=63771;break}if((gzL(J,0,z)|0)!=0){O=1;w=63768;break}}z=(c[3530354]|0)+u|0;u=B+13|0;if((c[3542200]|0)==0){O=1;w=63745;break}c[C>>2]=0;c[A>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](q,u)|0;if((c[C>>2]|0)!=0){J=c[A>>2]|0;c[r>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](r,u,0)|0;if((J|0)<1){O=1;w=63767;break}if((gzL(z,0,u)|0)!=0){O=1;w=63773;break}}u=B+1|0;if((u|0)<4){B=u}else{w=63726;break}}if((w|0)==63773){i=d;return O|0}else if((w|0)==63771){i=d;return O|0}else if((w|0)==63767){i=d;return O|0}else if((w|0)==63745){i=d;return O|0}else if((w|0)==63747){i=d;return O|0}else if((w|0)==63757){i=d;return O|0}else if((w|0)==63752){i=d;return O|0}else if((w|0)==63768){i=d;return O|0}else if((w|0)==63755){i=d;return O|0}else if((w|0)==63726){B=c[2386672]|0;if((c[3542200]|0)==0){O=1;i=d;return O|0}A=s+108|0;c[A>>2]=0;C=s+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](s,17)|0;do{if((c[A>>2]|0)!=0){D=c[C>>2]|0;c[t>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](t,17,0)|0;if((D|0)<1){O=1;i=d;return O|0}if((gzL(B,0,17)|0)==0){break}else{O=1}i=d;return O|0}}while(0);dit();UL(4e6,3040,702,0);c[2438224]=4e6;c[2433522]=3416;c[2406672]=1752;c[3528468]=9362;c[2443842]=511;h[745398]=1.0;a[3203264]=1;UB(0,702,4e5,726,5);c[2415126]=9662152;h[1207773]=.5;c[2415548]=3;B=c[642608+(c[2436]<<2)>>2]|0;C=c[B+128>>2]|0;if((c[B+52>>2]&4|0)==0){c[2113068]=C;A=c[B+132>>2]|0;c[2113070]=A;c[2443814]=C;c[2440436]=A;P=C;Q=A}else{c[2113070]=C;A=c[B+132>>2]|0;c[2113068]=A;c[2440436]=C;c[2443814]=A;P=A;Q=C}C=ag(P<<1,Q)|0;A=gGq(C)|0;c[2112926]=A;if((A|0)!=0){gGz(A|0,0,C|0)}dix();O=0;i=d;return O|0}}}while(0);c[2415054]=0;O=1;i=d;return O|0}function dh$(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;do{if(a[7303752]|0){c[2415126]=9662152;b=c[2408988]|0;if((b|0)!=0){gGz(9662152,0,3224);d=b;b=0;while(1){if((b|0)>=1024){break}e=9638528+(b<<2)|0;if((c[e>>2]|0)==(d|0)){f=63779;break}else{b=b+1|0}}if((f|0)==63779){gGr(d);c[e>>2]=0}c[2408988]=0}c[2415126]=9665376;b=c[2408989]|0;if((b|0)==0){break}gGz(9665376,0,3224);g=b;b=0;while(1){if((b|0)>=1024){break}h=9638528+(b<<2)|0;if((c[h>>2]|0)==(g|0)){f=63785;break}else{b=b+1|0}}if((f|0)==63785){gGr(g);c[h>>2]=0}c[2408989]=0}}while(0);h=a[7452584]|0;if(h){e=0;b=h&1;while(1){h=14163936+(e<<2)|0;d=c[h>>2]|0;i=c[2113006]|0;if((i|0)==0){f=63791}else{j=i-1|0;c[2113006]=j;if((j|0)==0){f=63791}}if((f|0)==63791){f=0;c[2383474]=0}if((d|0)==0){k=b}else{gGr(d);k=a[7452584]&1}c[h>>2]=0;h=e+1|0;if((h|0)<(k|0)){e=h;b=k}else{break}}}a[7452584]=0;c[2438224]=0;c[2433522]=0;c[2406672]=0;c[3528468]=0;k=c[2406688]|0;if((k|0)!=0){gGr(k);c[2406688]=0}c[2432972]=0;c[2113070]=0;c[2113068]=0;k=c[2112926]|0;if((k|0)!=0){gGr(k);c[2112926]=0}fwZ();k=c[2415054]|0;b=0;while(1){if((b|0)>=1024){f=63804;break}l=9638528+(b<<2)|0;if((c[l>>2]|0)==(k|0)){break}else{b=b+1|0}}if((f|0)==63804){c[2415054]=0;a[7303752]=0;return 0}gGr(k);c[l>>2]=0;c[2415054]=0;a[7303752]=0;return 0}function dh0(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((a[9624824]|0)!=0){dix()}gGz(9550792,0,6);a[9550802]=0;e=0;f=0;g=0;h=0;i=0;j=0;k=0;l=0;do{f=(d[9634168+e|0]<<e^f&255)&255;g=(d[9631944+e|0]<<e^g&255)&255;h=(d[9629864+e|0]<<e^h&255)&255;i=(d[9629048+e|0]<<e^i&255)&255;j=(d[9628808+e|0]<<e^j&255)&255;k=(d[9628688+e|0]<<e^k&255)&255;l=(d[9625240+e|0]<<e^l&255)&255;e=e+1|0;}while((e|0)<8);a[9550792]=f;a[9550793]=g;a[9550794]=h;a[9550795]=i;a[9550796]=j;a[9550797]=k;a[9550802]=l;l=c[2385548]|0;if((l|0)>0){gGz(9752472,0,((l|0)>1?l<<2:4)|0)}c[2433530]=0;do{if(a[7303752]|0){c[2415126]=9662152;l=c[2415557]|0;k=l&3;if((k|0)==3){m=133;n=63815;break}j=(4e6/(4e6/((c[2415554]|0)/(c[600992+((l>>>3&1)<<4)+(k<<2)>>2]|0)|0|0)|0|0)|0|0)/((c[2424]|0)/100|0|0)|0;if((j|0)>0){m=j;n=63815}}else{m=10;n=63815}}while(0);if((n|0)==63815){n=m-1|0;j=0;k=0;do{l=(1e5-j|0)/(m-k|0)|0;i=c[2439330]|0;if((i|0)!=0){h=i;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;h=c[2438118]|0;c[2433530]=h;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;do{if((l|0)<1){o=0}else{if((a[i+4188|0]|0)==0){g=gfc(l)|0;c[2433530]=(c[2433530]|0)+g;o=g;break}else{c[2433530]=h+l;o=l;break}}}while(0);j=o+j|0;if((k|0)==(n|0)){a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0}l=c[1836236]|0;h=c[9757320+(l<<2)>>2]|0;if((h|0)!=0){i=h;gGC(i|0,9706056,76)|0}c[9752472+(l<<2)>>2]=c[2433530];c[14113936+(l<<2)>>2]=c[2076596];c[9669104+(l<<2)>>2]=c[3541536];c[1836236]=-1;l=c[2439331]|0;if((l|0)!=0){i=l;gGC(9706056,i|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;if(a[6939752]|0){if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12;a[6939752]=0}UF(ag(66666/(m|0)|0,k)|0)|0;if(a[7303752]|0){UD()}i=c[1836236]|0;l=c[9757320+(i<<2)>>2]|0;if((l|0)!=0){h=l;gGC(h|0,9706056,76)|0}c[9752472+(i<<2)>>2]=c[2433530];c[14113936+(i<<2)>>2]=c[2076596];c[9669104+(i<<2)>>2]=c[3541536];c[1836236]=-1;k=k+1|0;}while((k|0)<(m|0))}m=c[2439331]|0;if((m|0)!=0){k=m;gGC(9706056,k|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;do{if((c[2112964]|0)!=0){k=c[2438224]|0;m=gGS(-747372544,31788,k,(k|0)<0|0?-1:0)|0;k=m;UF(66666)|0;m=c[2443826]|0;if((m|0)<1073676288){c[2443826]=m-k}m=c[2443827]|0;if((m|0)<1073676288){c[2443827]=m-k}m=(c[3528508]|0)-k|0;c[3528508]=(m|0)<0?0:m;gg[c[3542112]&4095](c[2112964]|0,a[9688]|0?534:0);if(!(a[7303752]|0)){break}Uz(0,c[2112964]|0,a[9688]|0?534:0)}}while(0);m=c[1836236]|0;k=c[9757320+(m<<2)>>2]|0;if((k|0)!=0){n=k;gGC(n|0,9706056,76)|0}c[9752472+(m<<2)>>2]=c[2433530];c[14113936+(m<<2)>>2]=c[2076596];c[9669104+(m<<2)>>2]=c[3541536];c[1836236]=-1;if((c[2112968]|0)==0){return 0}dh1()|0;return 0}function dh1(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((a[9547832]|0)!=0){e=c[2387246]|0;f=c[3530136]|0;g=0;do{h=ga(b[e+g>>1]|0)|0;i=(h&65535)>>>4;j=h&255;k=(h&65535)>>>8;c[f+(g>>1<<2)>>2]=((k&8|k<<4&255)&255)>>>3|((j&12|j<<4)&255)<<3&2016|((i&8|i<<4&255)&255)<<8&63488;g=g+2|0;}while((g|0)<2048);a[9547832]=0}g=ag(c[2113070]|0,c[2113068]|0)|0;f=c[2112926]|0;if((g|0)>0){e=0;while(1){b[f+(e<<1)>>1]=256;i=e+1|0;if((i|0)<(g|0)){e=i}else{l=f;break}}}else{l=f}diy(3);diz(c[3531096]|0,c[3530354]|0,768,c[3527472]|0);diy(2);diz(c[3530978]|0,c[3530474]|0,512,c[3527456]|0);diy(1);diy(0);f=c[3529510]|0;e=c[3530908]|0;i=0;do{j=d[f+(i|1024)|0]|0;k=(i>>5<<3)-16|0;if(k>>>0<=223){Sq(l,d[f+i|0]|j<<8&768,i<<3&248,k,j>>>4,4,0,256,e)}i=i+1|0;}while((i|0)<1024);if((a[14115056]|0)==0){m=c[3530136]|0;R8(m);return 0}i=g-1|0;g=i>>1;if((g|0)>0){n=0}else{m=c[3530136]|0;R8(m);return 0}do{e=l+(n<<1)|0;f=b[e>>1]|0;j=l+(i-n<<1)|0;b[e>>1]=b[j>>1]|0;b[j>>1]=f;n=n+1|0;}while((n|0)<(g|0));m=c[3530136]|0;R8(m);return 0}function dh2(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+96|0;g=f|0;h=f+16|0;j=f+32|0;k=f+48|0;l=f+64|0;m=f+80|0;if((e|0)!=0){c[e>>2]=169506}if((d&96|0)!=0){gGz(m|0,0,12);n=c[2414762]|0;o=m|0;c[o>>2]=n;p=m+4|0;c[p>>2]=(c[2411816]|0)-n;n=m+12|0;c[n>>2]=162152;q=c[2076592]|0;gj[q&4095](m)|0;c[o>>2]=(c[3529214]|0)+8192;c[p>>2]=128;c[n>>2]=557504;n=c[2076592]|0;gj[n&4095](m)|0;fw$(d);UQ(d,e);if(a[7303752]|0){UE(d,e)}gGz(l|0,0,12);c[l>>2]=14115056;c[l+4>>2]=1;c[l+12>>2]=142288;e=c[2076592]|0;gj[e&4095](l)|0;gGz(k|0,0,12);c[k>>2]=14113344;c[k+4>>2]=1;c[k+12>>2]=191240;l=c[2076592]|0;gj[l&4095](k)|0;gGz(j|0,0,12);c[j>>2]=14117496;c[j+4>>2]=4;c[j+12>>2]=435944;k=c[2076592]|0;gj[k&4095](j)|0;gGz(h|0,0,12);c[h>>2]=9542912;c[h+4>>2]=4;c[h+12>>2]=551280;j=c[2076592]|0;gj[j&4095](h)|0;gGz(g|0,0,12);c[g>>2]=9542920;c[g+4>>2]=4;c[g+12>>2]=548976;h=c[2076592]|0;gj[h&4095](g)|0}g=c[2439330]|0;h=(g|0)==0;if(!h){j=g;gGC(9706056,j|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];j=c[3528484]|0;c[2076596]=j;k=c[2417276]|0;c[3541536]=k;c[1836236]=0;l=c[3529258]|0;e=c[3529374]|0;c[g+1036>>2]=l+e;c[g+1040>>2]=l+(e+256);c[g+1044>>2]=l+(e+512);c[g+1048>>2]=l+(e+768);c[g+1052>>2]=l+(e+1024);c[g+1056>>2]=l+(e+1280);c[g+1060>>2]=l+(e+1536);c[g+1064>>2]=l+(e+1792);e=c[3529374]|0;d=l+e|0;c[g+3084>>2]=d;c[g+4108>>2]=d;d=l+(e+256)|0;c[g+3088>>2]=d;c[g+4112>>2]=d;d=l+(e+512)|0;c[g+3092>>2]=d;c[g+4116>>2]=d;d=l+(e+768)|0;c[g+3096>>2]=d;c[g+4120>>2]=d;d=l+(e+1024)|0;c[g+3100>>2]=d;c[g+4124>>2]=d;d=l+(e+1280)|0;c[g+3104>>2]=d;c[g+4128>>2]=d;d=l+(e+1536)|0;c[g+3108>>2]=d;c[g+4132>>2]=d;d=l+(e+1792)|0;c[g+3112>>2]=d;c[g+4136>>2]=d;if(h){r=c[2433530]|0;c[2438118]=r;c[3528484]=j;c[2417276]=k;c[1836236]=-1;i=f;return 0}h=g;gGC(h|0,9706056,76)|0;r=c[2433530]|0;c[2438118]=r;c[3528484]=j;c[2417276]=k;c[1836236]=-1;i=f;return 0}function dh3(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5702804+(b*112|0)>>2];c[a+104>>2]=c[5702808+(b*112|0)>>2];c[a+108>>2]=c[5702812+(b*112|0)>>2];d=0;return d|0}function dh4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=5702704+(b*112|0);e=0;return e|0}function dh5(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5700788+(b*112|0)>>2];c[a+104>>2]=c[5700792+(b*112|0)>>2];c[a+108>>2]=c[5700796+(b*112|0)>>2];d=0;return d|0}function dh6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=5700688+(b*112|0);e=0;return e|0}function dh7(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5696756+(b*112|0)>>2];c[a+104>>2]=c[5696760+(b*112|0)>>2];c[a+108>>2]=c[5696764+(b*112|0)>>2];d=0;return d|0}function dh8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=5696656+(b*112|0);e=0;return e|0}function dh9(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5698772+(b*112|0)>>2];c[a+104>>2]=c[5698776+(b*112|0)>>2];c[a+108>>2]=c[5698780+(b*112|0)>>2];d=0;return d|0}function dia(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=5698672+(b*112|0);e=0;return e|0}function dib(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2277148+(b*112|0)>>2];c[a+104>>2]=c[2277152+(b*112|0)>>2];c[a+108>>2]=c[2277156+(b*112|0)>>2];d=0;return d|0}function dic(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=2277048+(b*112|0);e=0;return e|0}function did(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1195752+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function die(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>40){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3446008+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dif(){var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;d=i;i=i+840|0;e=d|0;f=d+112|0;g=d+120|0;j=d+232|0;k=d+240|0;l=d+352|0;m=d+360|0;n=d+472|0;o=d+480|0;p=d+592|0;q=d+600|0;r=d+712|0;s=d+720|0;t=d+832|0;c[2432764]=1;a[7303752]=1;c[3528912]=32768;c[2415054]=0;c[3529258]=0;c[3529214]=131072;c[2386672]=163840;c[3530908]=196608;c[3530672]=262144;c[3530474]=786432;c[3530354]=1310720;c[2414762]=1835008;c[3529346]=1835008;c[3529302]=1839104;c[2387246]=1841152;c[3529510]=1843200;c[3531096]=1845248;c[3530978]=1846272;c[2386520]=1847296;c[3527472]=1849344;c[3527456]=1849348;c[3530136]=1849352;c[2411816]=1853448;u=0;while(1){if((u|0)>=1024){break}v=9638528+(u<<2)|0;if((c[v>>2]|0)==0){w=63960;break}else{u=u+1|0}}do{if((w|0)==63960){u=gGq(1853448)|0;c[v>>2]=u;if((u|0)==0){break}c[2415054]=u;gGz(u|0,0,1853448);c[3529258]=u;c[3529214]=u+131072;c[2386672]=u+163840;x=c[3528912]|0;c[3530908]=u+(x+163840);c[3530672]=u+(x+229376);c[3530474]=u+(x+753664);c[3530354]=u+(x+1277952);y=u+(x+1802240)|0;c[2414762]=y;c[3529346]=y;c[3529302]=u+(x+1806336);c[2387246]=u+(x+1808384);c[3529510]=u+(x+1810432);c[3531096]=u+(x+1812480);c[3530978]=u+(x+1813504);c[2386520]=u+(x+1814528);c[3527472]=u+(x+1816576);c[3527456]=u+(x+1816580);c[3530136]=u+(x+1816584);y=u+(x+1820680)|0;c[2411816]=y;c[2414364]=y;fwR(0);y=c[2439330]|0;x=(y|0)==0;if(!x){u=y;gGC(9706056,u|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];u=c[3528484]|0;c[2076596]=u;z=c[2417276]|0;c[3541536]=z;c[1836236]=0;A=c[3529258]|0;B=0;C=0;while(1){c[y+76+(C<<2)>>2]=A+(C<<8);D=B+1&65535;if((D&65535)>191){E=0;F=0;break}else{B=D;C=D&65535}}while(1){C=A+(F<<8)|0;c[y+76+(F+512<<2)>>2]=C;c[y+76+(F+768<<2)>>2]=C;C=E+1&65535;if((C&65535)>191){break}else{E=C;F=C&65535}}A=c[3531096]|0;c[y+844>>2]=A;C=A+256|0;c[y+848>>2]=C;B=A+512|0;c[y+852>>2]=B;D=A+768|0;c[y+856>>2]=D;c[y+1868>>2]=A;c[y+1872>>2]=C;c[y+1876>>2]=B;c[y+1880>>2]=D;D=c[3530978]|0;c[y+860>>2]=D;B=D+256|0;c[y+864>>2]=B;C=D+512|0;c[y+868>>2]=C;A=D+768|0;c[y+872>>2]=A;c[y+1884>>2]=D;c[y+1888>>2]=B;c[y+1892>>2]=C;c[y+1896>>2]=A;A=c[3529510]|0;c[y+876>>2]=A;C=A+256|0;c[y+880>>2]=C;B=A+512|0;c[y+884>>2]=B;D=A+768|0;c[y+888>>2]=D;G=A+1024|0;c[y+892>>2]=G;H=A+1280|0;c[y+896>>2]=H;I=A+1536|0;c[y+900>>2]=I;J=A+1792|0;c[y+904>>2]=J;c[y+1900>>2]=A;c[y+1904>>2]=C;c[y+1908>>2]=B;c[y+1912>>2]=D;c[y+1916>>2]=G;c[y+1920>>2]=H;c[y+1924>>2]=I;c[y+1928>>2]=J;J=c[3529346]|0;c[y+908>>2]=J;c[y+912>>2]=J+256;c[y+916>>2]=J+512;c[y+920>>2]=J+768;c[y+924>>2]=J+1024;c[y+928>>2]=J+1280;c[y+932>>2]=J+1536;c[y+936>>2]=J+1792;c[y+940>>2]=J+2048;c[y+944>>2]=J+2304;c[y+948>>2]=J+2560;c[y+952>>2]=J+2816;c[y+956>>2]=J+3072;c[y+960>>2]=J+3328;c[y+964>>2]=J+3584;c[y+968>>2]=J+3840;I=208;H=208;while(1){c[y+76+(H+256<<2)>>2]=J+((H<<8)-53248);G=I+1&65535;if((G&65535)>223){K=208;L=208;break}else{I=G;H=G&65535}}while(1){H=J+((L<<8)-53248)|0;c[y+76+(L+512<<2)>>2]=H;c[y+76+(L+768<<2)>>2]=H;H=K+1&65535;if((H&65535)>223){break}else{K=H;L=H&65535}}J=c[2386520]|0;c[y+972>>2]=J;H=J+256|0;c[y+976>>2]=H;I=J+512|0;c[y+980>>2]=I;G=J+768|0;c[y+984>>2]=G;D=J+1024|0;c[y+988>>2]=D;B=J+1280|0;c[y+992>>2]=B;C=J+1536|0;c[y+996>>2]=C;A=J+1792|0;c[y+1e3>>2]=A;c[y+1996>>2]=J;c[y+2e3>>2]=H;c[y+2004>>2]=I;c[y+2008>>2]=G;c[y+2012>>2]=D;c[y+2016>>2]=B;c[y+2020>>2]=C;c[y+2024>>2]=A;A=c[2387246]|0;c[y+1004>>2]=A;c[y+1008>>2]=A+256;c[y+1012>>2]=A+512;c[y+1016>>2]=A+768;c[y+1020>>2]=A+1024;c[y+1024>>2]=A+1280;c[y+1028>>2]=A+1536;c[y+1032>>2]=A+1792;c[y+4184>>2]=2574;c[y+4180>>2]=172;if(!x){A=y;gGC(A|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=u;c[2417276]=z;c[1836236]=-1;fwR(1);A=c[2439331]|0;C=(A|0)==0;if(!C){B=A;gGC(9706056,B|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];B=c[3528485]|0;c[2076596]=B;D=c[2417277]|0;c[3541536]=D;c[1836236]=1;G=c[3529214]|0;I=0;H=0;while(1){c[A+76+(H<<2)>>2]=G+(H<<8);J=I+1&65535;if((J&65535)>127){M=0;N=0;break}else{I=J;H=J&65535}}while(1){H=G+(N<<8)|0;c[A+76+(N+512<<2)>>2]=H;c[A+76+(N+768<<2)>>2]=H;H=M+1&65535;if((H&65535)>127){break}else{M=H;N=H&65535}}G=c[3529302]|0;c[A+588>>2]=G;H=G+256|0;c[A+592>>2]=H;I=G+512|0;c[A+596>>2]=I;z=G+768|0;c[A+600>>2]=z;u=G+1024|0;c[A+604>>2]=u;y=G+1280|0;c[A+608>>2]=y;x=G+1536|0;c[A+612>>2]=x;J=G+1792|0;c[A+616>>2]=J;c[A+1612>>2]=G;c[A+1616>>2]=H;c[A+1620>>2]=I;c[A+1624>>2]=z;c[A+1628>>2]=u;c[A+1632>>2]=y;c[A+1636>>2]=x;c[A+1640>>2]=J;c[A+2636>>2]=G;c[A+3660>>2]=G;c[A+2640>>2]=H;c[A+3664>>2]=H;c[A+2644>>2]=I;c[A+3668>>2]=I;c[A+2648>>2]=z;c[A+3672>>2]=z;c[A+2652>>2]=u;c[A+3676>>2]=u;c[A+2656>>2]=y;c[A+3680>>2]=y;c[A+2660>>2]=x;c[A+3684>>2]=x;c[A+2664>>2]=J;c[A+3688>>2]=J;c[A+4184>>2]=2064;c[A+4180>>2]=2480;if(!C){J=A;gGC(J|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=B;c[2417277]=D;c[1836236]=-1;J=e+108|0;x=e+100|0;y=c[3529258]|0;if((c[3542200]|0)==0){O=1;i=d;return O|0}c[J>>2]=0;c[x>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,0)|0;do{if((c[J>>2]|0)!=0){u=c[x>>2]|0;c[f>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](f,0,0)|0;if((u|0)<1){O=1;i=d;return O|0}if((gzL(y,0,0)|0)==0){break}else{O=1}i=d;return O|0}}while(0);y=(c[3529258]|0)+65536|0;if((c[3542200]|0)==0){O=1;i=d;return O|0}c[J>>2]=0;c[x>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,1)|0;do{if((c[J>>2]|0)!=0){D=c[x>>2]|0;c[f>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](f,1,0)|0;if((D|0)<1){O=1;i=d;return O|0}if((gzL(y,0,1)|0)==0){break}else{O=1}i=d;return O|0}}while(0);y=c[3529214]|0;if((c[3542200]|0)==0){O=1;i=d;return O|0}x=g+108|0;c[x>>2]=0;J=g+100|0;c[J>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,2)|0;do{if((c[x>>2]|0)!=0){D=c[J>>2]|0;c[j>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](j,2,0)|0;if((D|0)<1){O=1;i=d;return O|0}if((gzL(y,0,2)|0)==0){break}else{O=1}i=d;return O|0}}while(0);y=c[3530908]|0;if((c[3542200]|0)==0){O=1;i=d;return O|0}J=k+108|0;c[J>>2]=0;x=k+100|0;c[x>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,3)|0;do{if((c[J>>2]|0)!=0){D=c[x>>2]|0;c[l>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](l,3,0)|0;if((D|0)<1){O=1;i=d;return O|0}if((gzL(y,0,3)|0)==0){break}else{O=1}i=d;return O|0}}while(0);y=m+108|0;x=m+100|0;J=o+108|0;D=o+100|0;B=q+108|0;A=q+100|0;C=0;while(1){u=C<<16;z=(c[3530672]|0)+u|0;I=C+4|0;if((c[3542200]|0)==0){O=1;w=64034;break}c[y>>2]=0;c[x>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,I)|0;if((c[y>>2]|0)!=0){H=c[x>>2]|0;c[n>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](n,I,0)|0;if((H|0)<1){O=1;w=64033;break}if((gzL(z,0,I)|0)!=0){O=1;w=64035;break}}I=(c[3530474]|0)+u|0;z=C+8|0;if((c[3542200]|0)==0){O=1;w=64022;break}c[J>>2]=0;c[D>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](o,z)|0;if((c[J>>2]|0)!=0){H=c[D>>2]|0;c[p>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](p,z,0)|0;if((H|0)<1){O=1;w=64026;break}if((gzL(I,0,z)|0)!=0){O=1;w=64044;break}}z=(c[3530354]|0)+u|0;u=C+12|0;if((c[3542200]|0)==0){O=1;w=64020;break}c[B>>2]=0;c[A>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](q,u)|0;if((c[B>>2]|0)!=0){I=c[A>>2]|0;c[r>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](r,u,0)|0;if((I|0)<1){O=1;w=64040;break}if((gzL(z,0,u)|0)!=0){O=1;w=64023;break}}u=C+1|0;if((u|0)<4){C=u}else{w=64005;break}}if((w|0)==64040){i=d;return O|0}else if((w|0)==64026){i=d;return O|0}else if((w|0)==64022){i=d;return O|0}else if((w|0)==64044){i=d;return O|0}else if((w|0)==64005){C=c[2386672]|0;if((c[3542200]|0)==0){O=1;i=d;return O|0}A=s+108|0;c[A>>2]=0;B=s+100|0;c[B>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](s,16)|0;do{if((c[A>>2]|0)!=0){D=c[B>>2]|0;c[t>>2]=9534384;J=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[J&16383](t,16,0)|0;if((D|0)<1){O=1;i=d;return O|0}if((gzL(C,0,16)|0)==0){break}else{O=1}i=d;return O|0}}while(0);dit();UL(4e6,3040,702,0);c[2438224]=4e6;c[2433522]=3416;c[2406672]=1752;c[3528468]=9362;c[2443842]=511;h[745398]=1.0;a[3203264]=1;UB(0,702,4e5,726,5);c[2415126]=9662152;h[1207773]=.5;c[2415548]=3;C=c[642608+(c[2436]<<2)>>2]|0;B=c[C+128>>2]|0;if((c[C+52>>2]&4|0)==0){c[2113068]=B;A=c[C+132>>2]|0;c[2113070]=A;c[2443814]=B;c[2440436]=A;P=B;Q=A}else{c[2113070]=B;A=c[C+132>>2]|0;c[2113068]=A;c[2440436]=B;c[2443814]=A;P=A;Q=B}B=ag(P<<1,Q)|0;A=gGq(B)|0;c[2112926]=A;if((A|0)!=0){gGz(A|0,0,B|0)}dix();O=0;i=d;return O|0}else if((w|0)==64034){i=d;return O|0}else if((w|0)==64033){i=d;return O|0}else if((w|0)==64023){i=d;return O|0}else if((w|0)==64035){i=d;return O|0}else if((w|0)==64020){i=d;return O|0}}}while(0);c[2415054]=0;O=1;i=d;return O|0}function dig(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2275244+(b*112|0)>>2];c[a+104>>2]=c[2275248+(b*112|0)>>2];c[a+108>>2]=c[2275252+(b*112|0)>>2];d=0;return d|0}function dih(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=2275144+(b*112|0);e=0;return e|0}function dii(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1390084+(b*112|0)>>2];c[a+104>>2]=c[1390088+(b*112|0)>>2];c[a+108>>2]=c[1390092+(b*112|0)>>2];d=0;return d|0}function dij(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=1389984+(b*112|0);e=0;return e|0}function dik(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3118196+(b*112|0)>>2];c[a+104>>2]=c[3118200+(b*112|0)>>2];c[a+108>>2]=c[3118204+(b*112|0)>>2];d=0;return d|0}function dil(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=3118096+(b*112|0);e=0;return e|0}function dim(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1313120+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function din(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>38){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4257904+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dio(){var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;d=i;i=i+840|0;e=d|0;f=d+112|0;g=d+120|0;j=d+232|0;k=d+240|0;l=d+352|0;m=d+360|0;n=d+472|0;o=d+480|0;p=d+592|0;q=d+600|0;r=d+712|0;s=d+720|0;t=d+832|0;c[2432764]=2;a[7303752]=1;if((fa(c[c[642608+(c[2436]<<2)>>2]>>2]|0,451264)|0)==0){a[7303752]=0;u=c[3528912]|0}else{c[3528912]=32768;u=32768}c[2415054]=0;c[3529258]=0;c[3529214]=131072;c[2386672]=163840;c[3530908]=u+163840;c[3530672]=u+229376;c[3530474]=u+753664;c[3530354]=u+1277952;v=u+1802240|0;c[2414762]=v;c[3529346]=v;c[3529302]=u+1806336;c[2387246]=u+1808384;c[3529510]=u+1810432;c[3531096]=u+1812480;c[3530978]=u+1813504;c[2386520]=u+1814528;c[3527472]=u+1816576;c[3527456]=u+1816580;c[3530136]=u+1816584;v=u+1820680|0;c[2411816]=v;c[2414364]=v;u=v;v=0;while(1){if((v|0)>=1024){break}w=9638528+(v<<2)|0;if((c[w>>2]|0)==0){x=64102;break}else{v=v+1|0}}do{if((x|0)==64102){v=gGq(u)|0;c[w>>2]=v;if((v|0)==0){break}gGz(v|0,0,u|0);c[2415054]=v;gGz(v|0,0,u|0);c[3529258]=v;c[3529214]=v+131072;c[2386672]=v+163840;y=c[3528912]|0;c[3530908]=v+(y+163840);c[3530672]=v+(y+229376);c[3530474]=v+(y+753664);c[3530354]=v+(y+1277952);z=v+(y+1802240)|0;c[2414762]=z;c[3529346]=z;c[3529302]=v+(y+1806336);c[2387246]=v+(y+1808384);c[3529510]=v+(y+1810432);c[3531096]=v+(y+1812480);c[3530978]=v+(y+1813504);c[2386520]=v+(y+1814528);c[3527472]=v+(y+1816576);c[3527456]=v+(y+1816580);c[3530136]=v+(y+1816584);z=v+(y+1820680)|0;c[2411816]=z;c[2414364]=z;fwR(0);z=c[2439330]|0;y=(z|0)==0;if(!y){v=z;gGC(9706056,v|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];v=c[3528484]|0;c[2076596]=v;A=c[2417276]|0;c[3541536]=A;c[1836236]=0;B=c[3529258]|0;C=0;D=0;while(1){c[z+76+(D<<2)>>2]=B+(D<<8);E=C+1&65535;if((E&65535)>191){F=0;G=0;break}else{C=E;D=E&65535}}while(1){D=B+(G<<8)|0;c[z+76+(G+512<<2)>>2]=D;c[z+76+(G+768<<2)>>2]=D;D=F+1&65535;if((D&65535)>191){break}else{F=D;G=D&65535}}B=c[3529346]|0;c[z+844>>2]=B;c[z+848>>2]=B+256;c[z+852>>2]=B+512;c[z+856>>2]=B+768;c[z+860>>2]=B+1024;c[z+864>>2]=B+1280;c[z+868>>2]=B+1536;c[z+872>>2]=B+1792;c[z+876>>2]=B+2048;c[z+880>>2]=B+2304;c[z+884>>2]=B+2560;c[z+888>>2]=B+2816;c[z+892>>2]=B+3072;c[z+896>>2]=B+3328;c[z+900>>2]=B+3584;c[z+904>>2]=B+3840;D=192;C=192;while(1){c[z+76+(C+256<<2)>>2]=B+((C<<8)-49152);E=D+1&65535;if((E&65535)>207){H=192;I=192;break}else{D=E;C=E&65535}}while(1){C=B+((I<<8)-49152)|0;c[z+76+(I+512<<2)>>2]=C;c[z+76+(I+768<<2)>>2]=C;C=H+1&65535;if((C&65535)>207){break}else{H=C;I=C&65535}}B=c[3529510]|0;c[z+908>>2]=B;C=B+256|0;c[z+912>>2]=C;D=B+512|0;c[z+916>>2]=D;E=B+768|0;c[z+920>>2]=E;J=B+1024|0;c[z+924>>2]=J;K=B+1280|0;c[z+928>>2]=K;L=B+1536|0;c[z+932>>2]=L;M=B+1792|0;c[z+936>>2]=M;c[z+1932>>2]=B;c[z+1936>>2]=C;c[z+1940>>2]=D;c[z+1944>>2]=E;c[z+1948>>2]=J;c[z+1952>>2]=K;c[z+1956>>2]=L;c[z+1960>>2]=M;M=c[3530978]|0;c[z+940>>2]=M;L=M+256|0;c[z+944>>2]=L;K=M+512|0;c[z+948>>2]=K;J=M+768|0;c[z+952>>2]=J;c[z+1964>>2]=M;c[z+1968>>2]=L;c[z+1972>>2]=K;c[z+1976>>2]=J;J=c[3531096]|0;c[z+956>>2]=J;K=J+256|0;c[z+960>>2]=K;L=J+512|0;c[z+964>>2]=L;M=J+768|0;c[z+968>>2]=M;c[z+1980>>2]=J;c[z+1984>>2]=K;c[z+1988>>2]=L;c[z+1992>>2]=M;M=c[2387246]|0;c[z+972>>2]=M;c[z+976>>2]=M+256;c[z+980>>2]=M+512;c[z+984>>2]=M+768;c[z+988>>2]=M+1024;c[z+992>>2]=M+1280;c[z+996>>2]=M+1536;c[z+1e3>>2]=M+1792;M=c[2386520]|0;c[z+1004>>2]=M;L=M+256|0;c[z+1008>>2]=L;K=M+512|0;c[z+1012>>2]=K;J=M+768|0;c[z+1016>>2]=J;E=M+1024|0;c[z+1020>>2]=E;D=M+1280|0;c[z+1024>>2]=D;C=M+1536|0;c[z+1028>>2]=C;B=M+1792|0;c[z+1032>>2]=B;c[z+2028>>2]=M;c[z+2032>>2]=L;c[z+2036>>2]=K;c[z+2040>>2]=J;c[z+2044>>2]=E;c[z+2048>>2]=D;c[z+2052>>2]=C;c[z+2056>>2]=B;c[z+4184>>2]=2574;c[z+4180>>2]=172;if(!y){B=z;gGC(B|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=v;c[2417276]=A;c[1836236]=-1;fwR(1);B=c[2439331]|0;C=(B|0)==0;if(!C){D=B;gGC(9706056,D|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];D=c[3528485]|0;c[2076596]=D;E=c[2417277]|0;c[3541536]=E;c[1836236]=1;J=c[3529214]|0;K=0;L=0;while(1){c[B+76+(L<<2)>>2]=J+(L<<8);M=K+1&65535;if((M&65535)>127){N=0;O=0;break}else{K=M;L=M&65535}}while(1){L=J+(O<<8)|0;c[B+76+(O+512<<2)>>2]=L;c[B+76+(O+768<<2)>>2]=L;L=N+1&65535;if((L&65535)>127){break}else{N=L;O=L&65535}}J=c[3529302]|0;c[B+588>>2]=J;L=J+256|0;c[B+592>>2]=L;K=J+512|0;c[B+596>>2]=K;A=J+768|0;c[B+600>>2]=A;v=J+1024|0;c[B+604>>2]=v;z=J+1280|0;c[B+608>>2]=z;y=J+1536|0;c[B+612>>2]=y;M=J+1792|0;c[B+616>>2]=M;c[B+1612>>2]=J;c[B+1616>>2]=L;c[B+1620>>2]=K;c[B+1624>>2]=A;c[B+1628>>2]=v;c[B+1632>>2]=z;c[B+1636>>2]=y;c[B+1640>>2]=M;c[B+2636>>2]=J;c[B+3660>>2]=J;c[B+2640>>2]=L;c[B+3664>>2]=L;c[B+2644>>2]=K;c[B+3668>>2]=K;c[B+2648>>2]=A;c[B+3672>>2]=A;c[B+2652>>2]=v;c[B+3676>>2]=v;c[B+2656>>2]=z;c[B+3680>>2]=z;c[B+2660>>2]=y;c[B+3684>>2]=y;c[B+2664>>2]=M;c[B+3688>>2]=M;c[B+4184>>2]=2064;c[B+4180>>2]=2480;if(!C){M=B;gGC(M|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=D;c[2417277]=E;c[1836236]=-1;M=e+108|0;y=e+100|0;z=c[3529258]|0;if((c[3542200]|0)==0){P=1;i=d;return P|0}c[M>>2]=0;c[y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,0)|0;do{if((c[M>>2]|0)!=0){v=c[y>>2]|0;c[f>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](f,0,0)|0;if((v|0)<1){P=1;i=d;return P|0}if((gzL(z,0,0)|0)==0){break}else{P=1}i=d;return P|0}}while(0);z=(c[3529258]|0)+65536|0;if((c[3542200]|0)==0){P=1;i=d;return P|0}c[M>>2]=0;c[y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,1)|0;do{if((c[M>>2]|0)!=0){E=c[y>>2]|0;c[f>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](f,1,0)|0;if((E|0)<1){P=1;i=d;return P|0}if((gzL(z,0,1)|0)==0){break}else{P=1}i=d;return P|0}}while(0);z=c[3529214]|0;if((c[3542200]|0)==0){P=1;i=d;return P|0}y=g+108|0;c[y>>2]=0;M=g+100|0;c[M>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,2)|0;do{if((c[y>>2]|0)!=0){E=c[M>>2]|0;c[j>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](j,2,0)|0;if((E|0)<1){P=1;i=d;return P|0}if((gzL(z,0,2)|0)==0){break}else{P=1}i=d;return P|0}}while(0);z=c[3530908]|0;if((c[3542200]|0)==0){P=1;i=d;return P|0}M=k+108|0;c[M>>2]=0;y=k+100|0;c[y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,3)|0;do{if((c[M>>2]|0)!=0){E=c[y>>2]|0;c[l>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](l,3,0)|0;if((E|0)<1){P=1;i=d;return P|0}if((gzL(z,0,3)|0)==0){break}else{P=1}i=d;return P|0}}while(0);z=m+108|0;y=m+100|0;M=o+108|0;E=o+100|0;D=q+108|0;B=q+100|0;C=0;while(1){v=C<<16;A=(c[3530672]|0)+v|0;K=C+4|0;if((c[3542200]|0)==0){P=1;x=64178;break}c[z>>2]=0;c[y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,K)|0;if((c[z>>2]|0)!=0){L=c[y>>2]|0;c[n>>2]=9534384;J=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[J&16383](n,K,0)|0;if((L|0)<1){P=1;x=64164;break}if((gzL(A,0,K)|0)!=0){P=1;x=64171;break}}K=(c[3530474]|0)+v|0;A=C+8|0;if((c[3542200]|0)==0){P=1;x=64169;break}c[M>>2]=0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](o,A)|0;if((c[M>>2]|0)!=0){L=c[E>>2]|0;c[p>>2]=9534384;J=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[J&16383](p,A,0)|0;if((L|0)<1){P=1;x=64165;break}if((gzL(K,0,A)|0)!=0){P=1;x=64181;break}}A=(c[3530354]|0)+v|0;v=C+12|0;if((c[3542200]|0)==0){P=1;x=64175;break}c[D>>2]=0;c[B>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](q,v)|0;if((c[D>>2]|0)!=0){K=c[B>>2]|0;c[r>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](r,v,0)|0;if((K|0)<1){P=1;x=64177;break}if((gzL(A,0,v)|0)!=0){P=1;x=64183;break}}v=C+1|0;if((v|0)<4){C=v}else{x=64147;break}}if((x|0)==64165){i=d;return P|0}else if((x|0)==64171){i=d;return P|0}else if((x|0)==64169){i=d;return P|0}else if((x|0)==64147){C=c[2386672]|0;do{if((c[3542200]|0)!=0){B=s+108|0;c[B>>2]=0;D=s+100|0;c[D>>2]=0;E=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[E&16383](s,16)|0;if((c[B>>2]|0)==0){break}B=c[D>>2]|0;c[t>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](t,16,0)|0;if((B|0)<1){break}gzL(C,0,16)|0}}while(0);dit();UL(4e6,3040,702,0);c[2438224]=4e6;c[2433522]=3416;c[2406672]=1752;c[3528468]=9362;c[2443842]=511;h[745398]=1.0;a[3203264]=1;if(a[7303752]|0){UB(0,702,4e5,726,5);c[2415126]=9662152;h[1207773]=.5;c[2415548]=3}C=c[642608+(c[2436]<<2)>>2]|0;B=c[C+128>>2]|0;if((c[C+52>>2]&4|0)==0){c[2113068]=B;D=c[C+132>>2]|0;c[2113070]=D;c[2443814]=B;c[2440436]=D;Q=B;R=D}else{c[2113070]=B;D=c[C+132>>2]|0;c[2113068]=D;c[2440436]=B;c[2443814]=D;Q=D;R=B}B=ag(Q<<1,R)|0;D=gGq(B)|0;c[2112926]=D;if((D|0)!=0){gGz(D|0,0,B|0)}dix();P=0;i=d;return P|0}else if((x|0)==64178){i=d;return P|0}else if((x|0)==64181){i=d;return P|0}else if((x|0)==64175){i=d;return P|0}else if((x|0)==64177){i=d;return P|0}else if((x|0)==64183){i=d;return P|0}else if((x|0)==64164){i=d;return P|0}}}while(0);c[2415054]=0;P=1;i=d;return P|0}function dip(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5883676+(b*112|0)>>2];c[a+104>>2]=c[5883680+(b*112|0)>>2];c[a+108>>2]=c[5883684+(b*112|0)>>2];d=0;return d|0}function diq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=5883576+(b*112|0);e=0;return e|0}function dir(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3919104+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dis(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>49){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6295680+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dit(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=0;while(1){if((b|0)>=1024){e=64262;break}f=9638528+(b<<2)|0;if((c[f>>2]|0)==0){break}else{b=b+1|0}}if((e|0)==64262){return}b=gGq(262144)|0;c[f>>2]=b;if((b|0)==0){return}gGz(b|0,0,262144);f=c[3530908]|0;gGC(b|0,f|0,32768)|0;g=0;do{h=g<<6;gGz(f+h|0,0,64);i=g<<8;j=0;do{k=1<<3-j;l=(c[703416+(j<<2)>>2]|0)+i|0;m=0;do{n=l+(c[3946808+(m<<2)>>2]|0)|0;o=(m<<3)+h|0;p=0;do{q=n+(c[3946872+(p<<2)>>2]|0)|0;if(((d[b+((q|0)/8|0)|0]|0)&128>>>((q&7)>>>0)|0)!=0){q=f+(o+p)|0;a[q]=(d[q]|0|k)&255}p=p+1|0;}while((p|0)<8);m=m+1|0;}while((m|0)<8);j=j+1|0;}while((j|0)<4);g=g+1|0;}while((g|0)<1024);g=c[3530672]|0;gGC(b|0,g|0,262144)|0;f=0;do{j=f<<6;gGz(g+j|0,0,64);h=f<<8;i=0;do{m=1<<3-i;k=(c[703416+(i<<2)>>2]|0)+h|0;l=0;do{p=k+(c[3946808+(l<<2)>>2]|0)|0;o=(l<<3)+j|0;n=0;do{q=p+(c[3946872+(n<<2)>>2]|0)|0;if(((d[b+((q|0)/8|0)|0]|0)&128>>>((q&7)>>>0)|0)!=0){q=g+(o+n)|0;a[q]=(d[q]|0|m)&255}n=n+1|0;}while((n|0)<8);l=l+1|0;}while((l|0)<8);i=i+1|0;}while((i|0)<4);f=f+1|0;}while((f|0)<8192);f=c[3530474]|0;gGC(b|0,f|0,262144)|0;g=0;do{i=g<<8;gGz(f+i|0,0,256);j=g<<10;h=0;do{l=1<<3-h;m=(c[703416+(h<<2)>>2]|0)+j|0;k=0;do{n=m+(c[3946808+(k<<2)>>2]|0)|0;o=(k<<4)+i|0;p=0;do{q=n+(c[3946872+(p<<2)>>2]|0)|0;if(((d[b+((q|0)/8|0)|0]|0)&128>>>((q&7)>>>0)|0)!=0){q=f+(o+p)|0;a[q]=(d[q]|0|l)&255}p=p+1|0;}while((p|0)<16);k=k+1|0;}while((k|0)<16);h=h+1|0;}while((h|0)<4);g=g+1|0;}while((g|0)<2048);g=c[3530354]|0;gGC(b|0,g|0,262144)|0;f=0;while(1){h=f<<8;gGz(g+h|0,0,256);i=f<<10;j=0;do{k=1<<3-j;l=(c[703416+(j<<2)>>2]|0)+i|0;m=0;do{p=l+(c[3946808+(m<<2)>>2]|0)|0;o=(m<<4)+h|0;n=0;do{q=p+(c[3946872+(n<<2)>>2]|0)|0;if(((d[b+((q|0)/8|0)|0]|0)&128>>>((q&7)>>>0)|0)!=0){q=g+(o+n)|0;a[q]=(d[q]|0|k)&255}n=n+1|0;}while((n|0)<16);m=m+1|0;}while((m|0)<16);j=j+1|0;}while((j|0)<4);j=f+1|0;if((j|0)<2048){f=j}else{r=0;break}}while(1){if((r|0)>=1024){e=64263;break}s=9638528+(r<<2)|0;if((c[s>>2]|0)==(b|0)){break}else{r=r+1|0}}if((e|0)==64263){return}gGr(b);c[s>>2]=0;return}function diu(b,c){b=b|0;c=c|0;a[9706117]=(c|0)!=0|0;return}function div(a){a=a|0;var b=0.0,d=0,e=0;b=+((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0);d=+V(b)>=1.0?b>0.0?(al(+U(b/4294967296.0),4294967295.0)|0)>>>0:~~+af((b- +(~~b>>>0))/4294967296.0)>>>0:0;e=gGU(~~b>>>0,d,a,(a|0)<0|0?-1:0)|0;a=gGS(e,K,4e6,0)|0;return a|0}function diw(){var a=0,b=0,e=0,f=0,g=0;a=c[2385728]|0;b=c[3528912]|0;if(!(a>>>0<(c[2385730]|0)>>>0&a>>>0<b>>>0)){c[2415126]=9662152;c[2415540]=1;return}e=c[3528914]|0;if((e|0)!=-1){f=e&15;c[2415126]=9662152;if((c[2415542]|0)==4){g=f}else{g=f<<1&14}c[2415538]=g;c[3528914]=-1;return}c[2385728]=a+1;g=d[(c[2386672]|0)+(b-1&a)|0]|0;c[3528914]=g;a=g>>>4;c[2415126]=9662152;if((c[2415542]|0)==4){c[2415538]=a;return}else{c[2415538]=a<<1&14;return}}function dix(){var b=0,d=0,e=0,f=0,g=0,i=0,j=0;a[9624824]=0;b=c[2414762]|0;gGz(b|0,0,(c[2411816]|0)-b|0);b=c[2439330]|0;d=(b|0)==0;if(!d){e=b;gGC(9706056,e|0,76)|0}c[2433530]=c[2438118];e=c[3528484]|0;c[2076596]=e;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;gGz(9706056,0,76);c[3529374]=65536;g=c[3529258]|0;c[b+1036>>2]=g+65536;c[b+1040>>2]=g+65792;c[b+1044>>2]=g+66048;c[b+1048>>2]=g+66304;c[b+1052>>2]=g+66560;c[b+1056>>2]=g+66816;c[b+1060>>2]=g+67072;c[b+1064>>2]=g+67328;i=c[3529374]|0;j=g+i|0;c[b+3084>>2]=j;c[b+4108>>2]=j;j=g+(i+256)|0;c[b+3088>>2]=j;c[b+4112>>2]=j;j=g+(i+512)|0;c[b+3092>>2]=j;c[b+4116>>2]=j;j=g+(i+768)|0;c[b+3096>>2]=j;c[b+4120>>2]=j;j=g+(i+1024)|0;c[b+3100>>2]=j;c[b+4124>>2]=j;j=g+(i+1280)|0;c[b+3104>>2]=j;c[b+4128>>2]=j;j=g+(i+1536)|0;c[b+3108>>2]=j;c[b+4132>>2]=j;j=g+(i+1792)|0;c[b+3112>>2]=j;c[b+4136>>2]=j;if(!d){d=b;gGC(d|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=e;c[2417276]=f;c[1836236]=-1;f=c[2439331]|0;e=(f|0)==0;if(!e){d=f;gGC(9706056,d|0,76)|0}d=c[2438119]|0;c[2433530]=d;b=c[3528485]|0;c[2076596]=b;j=c[2417277]|0;c[3541536]=j;c[1836236]=1;gGz(9706056,0,76);if(!e){e=f;gGC(e|0,9706056,76)|0}c[2438119]=d;c[3528485]=b;c[2417277]=j;c[1836236]=-1;if(a[7303752]|0){UA()}c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;lw(c[3540984]|0);if((c[2432764]|0)==0){a[14113344]=0;a[14115056]=0;c[2385728]=0;c[2385730]=0;c[3528914]=-1;return}gGz((c[3529214]|0)+8192|0,0,128);a[14113344]=0;a[14115056]=0;c[2385728]=0;c[2385730]=0;c[3528914]=-1;return}function diy(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;e=c[2386520]|0;f=(c[2432764]|0)==0;g=c[2112926]|0;h=c[3530672]|0;i=0;do{j=d[e+(i|3)|0]|0;do{if((j>>>6|0)==(b|0)){k=d[e+i|0]|0;if((k&4|0)==0){break}l=a[e+(i|2)|0]&3;if(f){m=k<<4&3840}else{m=k<<5&7936}n=(m|(d[e+(i|1)|0]|0))&-1<<(l<<1);o=1<<l;l=(d[e+(i|5)|0]|0)-(j<<4&256)|0;if((o|0)<=0){break}p=(k&1|0)==0;q=o-1|0;r=(k&2|0)!=0;k=(d[e+(i|4)|0]|0)+(-16-(j<<3&256))|0;s=j&15;t=0;do{u=(t&1|0)==0;v=(t&2|0)==0;w=(t&4|0)==0;x=((r?q-t|0:t)<<3)+k|0;y=(x|0)<-7;z=(x|0)>223;if(p){A=0;do{B=(A<<3)+l|0;do{if(!y){if((B+7|0)>>>0>262|z){break}C=A&1;D=u?C:C|2;C=(A&2|0)==0?D:D|4;D=v?C:C|8;C=(A&4|0)==0?D:D|16;D=(w?C:C|32)+n&8191;if(r){Sv(g,D,B,x,s,4,0,0,h);break}else{Sr(g,D,B,x,s,4,0,0,h);break}}}while(0);A=A+1|0;}while((A|0)<(o|0))}else{A=0;do{B=(q-A<<3)+l|0;do{if(!y){if((B+7|0)>>>0>262|z){break}D=A&1;C=u?D:D|2;D=(A&2|0)==0?C:C|4;C=v?D:D|8;D=(A&4|0)==0?C:C|16;C=(w?D:D|32)+n&8191;if(r){Sx(g,C,B,x,s,4,0,0,h);break}else{St(g,C,B,x,s,4,0,0,h);break}}}while(0);A=A+1|0;}while((A|0)<(o|0))}t=t+1|0;}while((t|0)<(o|0))}}while(0);i=i+8|0;}while((i|0)<2048);return}function diz(f,g,h,i){f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;j=i+2|0;k=(c[2432764]|0)==2;l=c[2112926]|0;m=c[2113068]|0;n=c[2113070]|0;o=0;do{p=(o<<4&496)-(b[i>>1]&511)+((a[14115056]|0)==0?-48:304)|0;q=(p|0)<-15?p+512|0:p;p=(q|0)>511?q-512|0:q;q=(o>>5<<4)-16-(e[j>>1]|0)|0;r=(q|0)<-15?q+256|0:q;L76491:do{if(!((p|0)>(m|0)|(r|0)>(n|0))){q=a[f+(o|512)|0]|0;if(k){s=q<<4|(q&255)>>>4}else{s=q}q=(s&255)<<8&1792|d[f+o|0];t=(s&255)>>>4;do{if((p|r|0)>=0){if((p|0)>(m-16|0)){break}if((r|0)>(n-16|0)){break}SG(l,q,p,r,t&255,4,0,h,g);break L76491}}while(0);SH(l,q,p,r,t&255,4,0,h,g)}}while(0);o=o+1|0;}while((o|0)<512);return}function diA(b){b=b|0;return(b<<16>>16==-14336?a[9635528]|0:0)|0}function diB(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((e|0)==52228){a[c[3528762]|0]=d;return}else if((e|0)==52229){a[c[3528808]|0]=d<<4&48;return}else{return}}function diC(b){b=b|0;var d=0,e=0,f=0;d=b&255;if((d|0)==0){b=c[3542228]|0;if((b|0)>15){e=0;return e|0}do{if((b|0)==15){f=c[3542225]|0;if((f|0)==0){break}a[14168931]=gj[f&4095](0)|0}else if((b|0)==14){f=c[3542224]|0;if((f|0)==0){break}a[14168930]=gj[f&4095](0)|0}}while(0);e=a[14168916+b|0]|0;return e|0}else if((d|0)==128){d=c[3542291]|0;if((d|0)>15){e=0;return e|0}do{if((d|0)==14){b=c[3542287]|0;if((b|0)==0){break}a[14169182]=gj[b&4095](0)|0}else if((d|0)==15){b=c[3542288]|0;if((b|0)==0){break}a[14169183]=gj[b&4095](0)|0}}while(0);e=a[14169168+d|0]|0;return e|0}else{e=0;return e|0}return 0}function diD(b,d){b=b|0;d=d|0;var e=0,f=0;e=b&255;if((e|0)==0){c[3542228]=d&15;return}else if((e|0)==129){b=d&255;f=c[3542291]|0;if((f|0)>15){return}do{if((f|0)<14){if((f|0)!=13){if((a[14169168+f|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(1,f,b);return}else if((e|0)==1){b=d&255;f=c[3542228]|0;if((f|0)>15){return}do{if((f|0)<14){if((f|0)!=13){if((a[14168916+f|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(0,f,b);return}else if((e|0)==128){c[3542291]=d&15;return}else{return}}function diE(b){b=b|0;return a[9550784]|0}function diF(b){b=b|0;return a[9550785]|0}function diG(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5953844+(b*112|0)>>2];c[a+104>>2]=c[5953848+(b*112|0)>>2];c[a+108>>2]=c[5953852+(b*112|0)>>2];d=0;return d|0}function diH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=5953744+(b*112|0);e=0;return e|0}function diI(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4281840+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function diJ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>23){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6440592+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function diK(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0.0,T=0,U=0,V=0,W=0;e=i;i=i+840|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;c[2415052]=0;c[2385970]=0;c[3530906]=32768;c[3530670]=98304;c[3531040]=163840;c[3530134]=164096;c[2406990]=165120;c[2414760]=166144;c[2386124]=166144;c[2386262]=168192;c[2386518]=169216;c[2387888]=169728;c[2386740]=169984;c[3528762]=170240;c[3528808]=170241;c[2411814]=170242;c[2439148]=170242;v=a[9688]|0?1068:0;w=v|170242;c[2439149]=w;x=w+v|0;c[2439150]=x;w=x+v|0;c[2439151]=w;x=w+v|0;c[2439152]=x;w=x+v|0;c[2439153]=w;x=w+v|0;c[2414362]=x;v=x;x=0;while(1){if((x|0)>=1024){break}y=9638528+(x<<2)|0;if((c[y>>2]|0)==0){z=64414;break}else{x=x+1|0}}do{if((z|0)==64414){x=gGq(v)|0;c[y>>2]=x;if((x|0)==0){break}gGz(x|0,0,v|0);c[2415052]=x;gGz(x|0,0,v|0);c[2385970]=x;c[3530906]=x+32768;c[3530670]=x+98304;c[3531040]=x+163840;c[3530134]=x+164096;c[2406990]=x+165120;w=x+166144|0;c[2414760]=w;c[2386124]=w;c[2386262]=x+168192;c[2386518]=x+169216;c[2387888]=x+169728;c[2386740]=x+169984;c[3528762]=x+170240;c[3528808]=x+170241;w=x+170242|0;c[2411814]=w;c[2439148]=w;w=a[9688]|0?1068:0;A=w|170242;c[2439149]=x+A;B=A+w|0;c[2439150]=x+B;A=B+w|0;c[2439151]=x+A;B=A+w|0;c[2439152]=x+B;A=B+w|0;c[2439153]=x+A;c[2414362]=x+(A+w);if((c[3542200]|0)==0){C=1;i=e;return C|0}w=t+108|0;c[w>>2]=0;A=t+100|0;c[A>>2]=0;B=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[B&16383](t,0)|0;do{if((c[w>>2]|0)!=0){B=c[A>>2]|0;c[u>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](u,0,0)|0;if((B|0)<1){C=1;i=e;return C|0}if((gzL(x,0,0)|0)==0){break}else{C=1}i=e;return C|0}}while(0);x=(c[2385970]|0)+8192|0;if((c[3542200]|0)==0){C=1;i=e;return C|0}A=r+108|0;c[A>>2]=0;w=r+100|0;c[w>>2]=0;B=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[B&16383](r,1)|0;do{if((c[A>>2]|0)!=0){B=c[w>>2]|0;c[s>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](s,1,0)|0;if((B|0)<1){C=1;i=e;return C|0}if((gzL(x,0,1)|0)==0){break}else{C=1}i=e;return C|0}}while(0);x=(c[2385970]|0)+16384|0;if((c[3542200]|0)==0){C=1;i=e;return C|0}w=p+108|0;c[w>>2]=0;A=p+100|0;c[A>>2]=0;B=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[B&16383](p,2)|0;do{if((c[w>>2]|0)!=0){B=c[A>>2]|0;c[q>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](q,2,0)|0;if((B|0)<1){C=1;i=e;return C|0}if((gzL(x,0,2)|0)==0){break}else{C=1}i=e;return C|0}}while(0);x=(c[2385970]|0)+24576|0;if((c[3542200]|0)==0){C=1;i=e;return C|0}A=n+108|0;c[A>>2]=0;w=n+100|0;c[w>>2]=0;B=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[B&16383](n,3)|0;do{if((c[A>>2]|0)!=0){B=c[w>>2]|0;c[o>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](o,3,0)|0;if((B|0)<1){C=1;i=e;return C|0}if((gzL(x,0,3)|0)==0){break}else{C=1}i=e;return C|0}}while(0);x=c[3530906]|0;if((c[3542200]|0)==0){C=1;i=e;return C|0}w=l+108|0;c[w>>2]=0;A=l+100|0;c[A>>2]=0;B=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[B&16383](l,4)|0;do{if((c[w>>2]|0)!=0){B=c[A>>2]|0;c[m>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](m,4,0)|0;if((B|0)<1){C=1;i=e;return C|0}if((gzL(x,0,4)|0)==0){break}else{C=1}i=e;return C|0}}while(0);x=(c[3530906]|0)+8192|0;if((c[3542200]|0)==0){C=1;i=e;return C|0}A=j+108|0;c[A>>2]=0;w=j+100|0;c[w>>2]=0;B=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[B&16383](j,5)|0;do{if((c[A>>2]|0)!=0){B=c[w>>2]|0;c[k>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](k,5,0)|0;if((B|0)<1){C=1;i=e;return C|0}if((gzL(x,0,5)|0)==0){break}else{C=1}i=e;return C|0}}while(0);x=c[3531040]|0;if((c[3542200]|0)==0){C=1;i=e;return C|0}w=f+108|0;c[w>>2]=0;A=f+100|0;c[A>>2]=0;B=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[B&16383](f,6)|0;do{if((c[w>>2]|0)!=0){B=c[A>>2]|0;c[g>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](g,6,0)|0;if((B|0)<1){C=1;i=e;return C|0}if((gzL(x,0,6)|0)==0){break}else{C=1}i=e;return C|0}}while(0);x=c[3531040]|0;A=c[2406990]|0;w=0;while(1){B=d[x+w|0]|0;c[A+(w<<2)>>2]=(-(B>>>3&1)&33)+(-(B>>>4&1)&71)+(-(B>>>5&1)&151)<<8|(-(B>>>6&1)&71)+(-(B>>>7)&151)|(-(B>>>1&1)&71)+(-(B&1)&33)+(-(B>>>2&1)&151)<<16;B=w+1|0;if((B|0)<256){w=B}else{E=0;break}}while(1){if((E|0)>=1024){break}F=9638528+(E<<2)|0;if((c[F>>2]|0)==0){z=64448;break}else{E=E+1|0}}L76678:do{if((z|0)==64448){w=gGq(16384)|0;c[F>>2]=w;if((w|0)==0){break}gGz(w|0,0,16384);A=c[3530906]|0;gGC(w|0,A|0,16384)|0;x=0;do{B=x<<6;gGz(A+B|0,0,64);D=0;do{G=B+(c[611776+(D<<2)>>2]|0)|0;H=(D<<3)+B|0;I=0;do{J=G+(c[601400+(I<<2)>>2]|0)|0;if(((d[w+((J|0)/8|0)|0]|0)&128>>>((J&7)>>>0)|0)!=0){J=A+(H+I)|0;a[J]=a[J]|2}I=I+1|0;}while((I|0)<8);D=D+1|0;}while((D|0)<8);D=B+65536|0;I=0;do{H=D+(c[611776+(I<<2)>>2]|0)|0;G=(I<<3)+B|0;J=0;do{K=H+(c[601400+(J<<2)>>2]|0)|0;if(((d[w+((K|0)/8|0)|0]|0)&128>>>((K&7)>>>0)|0)!=0){K=A+(G+J)|0;a[K]=a[K]|1}J=J+1|0;}while((J|0)<8);I=I+1|0;}while((I|0)<8);x=x+1|0;}while((x|0)<1024);x=c[3530670]|0;A=0;while(1){I=A<<8;gGz(x+I|0,0,256);B=0;do{D=I+(c[611776+(B<<2)>>2]|0)|0;J=(B<<4)+I|0;G=0;do{H=D+(c[601400+(G<<2)>>2]|0)|0;if(((d[w+((H|0)/8|0)|0]|0)&128>>>((H&7)>>>0)|0)!=0){H=x+(J+G)|0;a[H]=a[H]|2}G=G+1|0;}while((G|0)<16);B=B+1|0;}while((B|0)<16);B=I+65536|0;G=0;do{J=B+(c[611776+(G<<2)>>2]|0)|0;D=(G<<4)+I|0;H=0;do{K=J+(c[601400+(H<<2)>>2]|0)|0;if(((d[w+((K|0)/8|0)|0]|0)&128>>>((K&7)>>>0)|0)!=0){K=x+(D+H)|0;a[K]=a[K]|1}H=H+1|0;}while((H|0)<16);G=G+1|0;}while((G|0)<16);G=A+1|0;if((G|0)<256){A=G}else{L=0;break}}while(1){if((L|0)>=1024){break L76678}M=9638528+(L<<2)|0;if((c[M>>2]|0)==(w|0)){break}else{L=L+1|0}}gGr(w);c[M>>2]=0}}while(0);fwR(0);A=c[2439330]|0;x=(A|0)==0;if(!x){G=A;gGC(9706056,G|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];G=c[3528484]|0;c[2076596]=G;I=c[2417276]|0;c[3541536]=I;c[1836236]=0;B=c[2385970]|0;H=0;D=0;while(1){c[A+76+(D<<2)>>2]=B+(D<<8);J=H+1&65535;if((J&65535)>127){N=0;O=0;break}else{H=J;D=J&65535}}while(1){D=B+(O<<8)|0;c[A+76+(O+512<<2)>>2]=D;c[A+76+(O+768<<2)>>2]=D;D=N+1&65535;if((D&65535)>127){break}else{N=D;O=D&65535}}B=c[2386124]|0;c[A+588>>2]=B;D=B+256|0;c[A+592>>2]=D;H=B+512|0;c[A+596>>2]=H;J=B+768|0;c[A+600>>2]=J;K=B+1024|0;c[A+604>>2]=K;P=B+1280|0;c[A+608>>2]=P;Q=B+1536|0;c[A+612>>2]=Q;R=B+1792|0;c[A+616>>2]=R;c[A+1612>>2]=B;c[A+1616>>2]=D;c[A+1620>>2]=H;c[A+1624>>2]=J;c[A+1628>>2]=K;c[A+1632>>2]=P;c[A+1636>>2]=Q;c[A+1640>>2]=R;c[A+2636>>2]=B;c[A+3660>>2]=B;c[A+2640>>2]=D;c[A+3664>>2]=D;c[A+2644>>2]=H;c[A+3668>>2]=H;c[A+2648>>2]=J;c[A+3672>>2]=J;c[A+2652>>2]=K;c[A+3676>>2]=K;c[A+2656>>2]=P;c[A+3680>>2]=P;c[A+2660>>2]=Q;c[A+3684>>2]=Q;c[A+2664>>2]=R;c[A+3688>>2]=R;R=c[2386740]|0;c[A+844>>2]=R;c[A+1868>>2]=R;c[A+2892>>2]=R;c[A+3916>>2]=R;R=c[2387888]|0;c[A+848>>2]=R;c[A+1872>>2]=R;c[A+2896>>2]=R;c[A+3920>>2]=R;R=c[2386518]|0;c[A+852>>2]=R;Q=R+256|0;c[A+856>>2]=Q;c[A+1876>>2]=R;c[A+1880>>2]=Q;c[A+2900>>2]=R;c[A+3924>>2]=R;c[A+2904>>2]=Q;c[A+3928>>2]=Q;Q=c[2386262]|0;c[A+860>>2]=Q;R=Q+256|0;c[A+864>>2]=R;P=Q+512|0;c[A+868>>2]=P;K=Q+768|0;c[A+872>>2]=K;c[A+1884>>2]=Q;c[A+1888>>2]=R;c[A+1892>>2]=P;c[A+1896>>2]=K;c[A+2908>>2]=Q;c[A+3932>>2]=Q;c[A+2912>>2]=R;c[A+3936>>2]=R;c[A+2916>>2]=P;c[A+3940>>2]=P;c[A+2920>>2]=K;c[A+3944>>2]=K;c[A+4184>>2]=2226;c[A+4180>>2]=3086;c[A+4176>>2]=1968;c[A+4172>>2]=1496;if(!x){K=A;gGC(K|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=G;c[2417276]=I;c[1836236]=-1;K=a[9680]|0?32e3:0;c[3542220]=11200;P=c[2113008]|0;if((P|0)==0){gGz(14168888,0,252);c[3542223]=K;c[3542224]=1422;c[3542225]=0;c[3542226]=0;c[3542227]=0;c[3542234]=~~((+(K|0)*32768.0*8.0+75.0e4)/15.0e5);R=31;S=32767.0;while(1){c[14169012+(R<<2)>>2]=~~(S+.5);Q=R-1|0;if((Q|0)>0){R=Q;S=S/1.188502227}else{break}}c[3542253]=0;h[1771269]=1.0;h[1771270]=1.0;h[1771271]=1.0;c[3542574]=3;c[3542575]=3;c[3542576]=3;mB(0);R=(c[2113008]|0)+1|0;c[2113008]=R;T=R;U=a[9680]|0?32e3:0}else{T=P;U=K}c[3542220]=11200;if((T|0)==1){gGz(14169140,0,252);c[3542286]=U;c[3542287]=3498;c[3542288]=0;c[3542289]=0;c[3542290]=0;c[3542297]=~~((+(U|0)*32768.0*8.0+75.0e4)/15.0e5);R=31;S=32767.0;while(1){c[14169264+(R<<2)>>2]=~~(S+.5);I=R-1|0;if((I|0)>0){R=I;S=S/1.188502227}else{break}}c[3542316]=0;h[1771272]=1.0;h[1771273]=1.0;h[1771274]=1.0;c[3542577]=3;c[3542578]=3;c[3542579]=3;mB(1);c[2113008]=(c[2113008]|0)+1}h[1771269]=.33;c[3542574]=3;h[1771270]=.33;c[3542575]=3;h[1771271]=.33;c[3542576]=3;h[1771272]=.33;c[3542577]=3;h[1771273]=.33;c[3542578]=3;h[1771274]=.33;c[3542579]=3;R=c[642608+(c[2436]<<2)>>2]|0;K=c[R+128>>2]|0;if((c[R+52>>2]&4|0)==0){c[2113068]=K;P=c[R+132>>2]|0;c[2113070]=P;c[2443814]=K;c[2440436]=P;V=K;W=P}else{c[2113070]=K;P=c[R+132>>2]|0;c[2113068]=P;c[2440436]=K;c[2443814]=P;V=P;W=K}K=ag(V<<1,W)|0;P=gGq(K)|0;c[2112926]=P;if((P|0)!=0){gGz(P|0,0,K|0)}K=c[2414760]|0;gGz(K|0,0,(c[2411814]|0)-K|0);K=c[2439330]|0;P=(K|0)==0;if(!P){R=K;gGC(9706056,R|0,76)|0}R=c[2438118]|0;c[2433530]=R;I=c[3528484]|0;c[2076596]=I;G=c[2417276]|0;c[3541536]=G;c[1836236]=0;gGz(9706056,0,76);if(!P){P=K;gGC(P|0,9706056,76)|0}c[2438118]=R;c[3528484]=I;c[2417276]=G;c[1836236]=-1;mB(0);mB(1);C=0;i=e;return C|0}}while(0);c[2415052]=0;C=1;i=e;return C|0}function diL(){var a=0,b=0,d=0,e=0;c[2113070]=0;c[2113068]=0;a=c[2112926]|0;if((a|0)!=0){gGr(a);c[2112926]=0}fwZ();c[2113008]=0;c[2076598]=0;c[2383582]=0;a=c[2415052]|0;b=0;while(1){if((b|0)>=1024){d=64537;break}e=9638528+(b<<2)|0;if((c[e>>2]|0)==(a|0)){break}else{b=b+1|0}}if((d|0)==64537){c[2415052]=0;return 0}gGr(a);c[e>>2]=0;c[2415052]=0;return 0}function diM(){var d=0,e=0,f=0,g=0,h=0,i=0;if((a[9624816]|0)!=0){d=c[2414760]|0;gGz(d|0,0,(c[2411814]|0)-d|0);d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;h=c[2417276]|0;c[3541536]=h;c[1836236]=0;gGz(9706056,0,76);if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=h;c[1836236]=-1;mB(0);mB(1)}b[4775392]=-1;h=0;g=-1;f=-1;do{g=((a[9634160+h|0]&1)<<h^g&255)&255;f=((a[9631936+h|0]&1)<<h^f&255)&255;h=h+1|0;}while((h|0)<8);a[9550784]=g;a[9550785]=f;f=c[2439330]|0;if((f|0)!=0){g=f;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;g=c[2438118]|0;c[2433530]=g;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;if((a[f+4188|0]|0)==0){f=gfc(66666)|0;i=(c[2433530]|0)+f|0}else{i=g+66666|0}c[2433530]=i;a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0;i=c[1836236]|0;g=c[9757320+(i<<2)>>2]|0;if((g|0)!=0){f=g;gGC(f|0,9706056,76)|0}c[9752472+(i<<2)>>2]=c[2433530];c[14113936+(i<<2)>>2]=c[2076596];c[9669104+(i<<2)>>2]=c[3541536];c[1836236]=-1;i=c[2112964]|0;if((i|0)!=0){mF(9756592,i,a[9688]|0?534:0,0)}if((c[2112968]|0)==0){return 0}diN()|0;return 0}function diN(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;if((a[9547824]|0)!=0){b=c[2406990]|0;e=c[3530134]|0;f=0;do{g=c[b+(f<<2)>>2]|0;c[e+(f<<2)>>2]=g>>>8&2016|g&31|g>>16<<8&63488;f=f+1|0;}while((f|0)<256)}f=c[2112926]|0;gGz(f|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);diV(0);e=c[2386518]|0;b=c[3528808]|0;g=c[3528762]|0;h=c[3530670]|0;i=c[3530906]|0;j=508;do{k=a[e+j|0]|0;l=k&255;m=a[e+(j|3)|0]|0;n=m&255;L76815:do{if(!((k<<24>>24|0)==(-1|0)|(k<<24>>24|0)==0)){o=e+(j|2)|0;do{if((m&255)<64){p=a[o]|0;if((p&16)==0){q=p}else{break L76815}}else{p=a[o]|0;if((m&255)<=191){q=p;break}if((p&16)==0){break L76815}else{q=p}}}while(0);o=d[e+(j|1)|0]|0;p=q&255;r=o&63|p<<1&192;s=d[b]|p&15;p=o&64;t=(a[g]|0)==0;if(t){u=o&128;v=p;w=l}else{u=o>>>7^1;v=p>>>6^1;w=l-16|0}if(q<<24>>24<0){p=t?240-w|0:w;o=t?n:240-n|0;x=(v|0)!=0;if((u|0)==0){if(x){SJ(f,r,o,p,s,2,0,0,h);break}else{SH(f,r,o,p,s,2,0,0,h);break}}else{if(x){SN(f,r,o,p,s,2,0,0,h);break}else{SL(f,r,o,p,s,2,0,0,h);break}}}else{p=r<<2;r=t?248-w|0:w;o=t?n:248-n|0;t=(v|0)!=0;if((u|0)==0){if(t){St(f,p,o,r,s,2,0,0,i);break}else{Sr(f,p,o,r,s,2,0,0,i);break}}else{if(t){Sx(f,p,o,r,s,2,0,0,i);break}else{Sv(f,p,o,r,s,2,0,0,i);break}}}}}while(0);j=j-4|0;}while((j|0)>-1);diV(16);R8(c[3530134]|0);return 0}function diO(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;d=i;i=i+48|0;e=d|0;f=d+32|0;g=(b|0)==0;if(!g){c[b>>2]=169730}if((a&96|0)==0){i=d;return 0}gGz(f|0,0,12);h=c[2414760]|0;c[f>>2]=h;c[f+4>>2]=(c[2411814]|0)-h;c[f+12>>2]=162152;gj[c[2076592]&4095](f)|0;fw$(a);f=d+16|0;if((a&64|0)==0){i=d;return 0}do{if(!g){if((c[b>>2]|0)>=169110){break}c[b>>2]=169110}}while(0);if((c[2113008]|0)<=0){i=d;return 0}b=e|0;g=e+4|0;a=e+8|0;h=e+12|0;j=0;do{cC(f|0,531144,(k=i,i=i+8|0,c[k>>2]=j,k)|0)|0;i=k;c[b>>2]=14168888+(j*252|0);c[g>>2]=252;c[a>>2]=0;c[h>>2]=f;gj[c[2076592]&4095](e)|0;j=j+1|0;}while((j|0)<(c[2113008]|0));i=d;return 0}function diP(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4837396+(b*112|0)>>2];c[a+104>>2]=c[4837400+(b*112|0)>>2];c[a+108>>2]=c[4837404+(b*112|0)>>2];d=0;return d|0}function diQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=4837296+(b*112|0);e=0;return e|0}function diR(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4838516+(b*112|0)>>2];c[a+104>>2]=c[4838520+(b*112|0)>>2];c[a+108>>2]=c[4838524+(b*112|0)>>2];d=0;return d|0}function diS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=4838416+(b*112|0);e=0;return e|0}function diT(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4836276+(b*112|0)>>2];c[a+104>>2]=c[4836280+(b*112|0)>>2];c[a+108>>2]=c[4836284+(b*112|0)>>2];d=0;return d|0}function diU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=4836176+(b*112|0);e=0;return e|0}function diV(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=c[2387888]|0;f=c[2386262]|0;g=c[3528808]|0;h=c[2386740]|0;i=c[3528762]|0;j=c[2112926]|0;k=c[3530906]|0;if((b|0)==0){l=0;do{m=l<<3&248;n=l>>5<<3;o=m>>>3;p=d[e+(n&224|o)|0]|0;do{if((p&16|0)==0){q=d[f+l|0]|p<<3&768;r=d[g]|p&15;s=(d[h+o|0]^255)+n&255;if((a[i]|0)==0){Sj(j,q,m,s,r,2,0,k);break}else{Sp(j,q,248-m|0,232-s|0,r,2,0,k);break}}}while(0);l=l+1|0;}while((l|0)<1024);return}else{l=0;do{m=l<<3&248;n=l>>5<<3;o=m>>>3;p=d[e+(n&224|o)|0]|0;do{if((p&16|0)==(b|0)){r=d[f+l|0]|p<<3&768;s=d[g]|p&15;q=(d[h+o|0]^255)+n&255;if((a[i]|0)==0){Sr(j,r,m,q,s,2,0,0,k);break}else{Sx(j,r,248-m|0,232-q|0,s,2,0,0,k);break}}}while(0);l=l+1|0;}while((l|0)<1024);return}}function diW(d,e){d=d|0;e=e|0;var f=0,g=0,h=0;if((d&1046528|0)==655360){f=d&2046;b[(c[2387244]|0)+f>>1]=e;g=e&65535;h=g>>>5&31;c[(c[3530132]|0)+(f>>>1<<2)>>2]=g>>>10<<11&63488|g&31|(h<<3|h>>>2)<<3&2016;return}switch(d&1048575|0){case 786448:case 786450:{a[(c[2443702]|0)+(d>>>1&1)|0]=e&63;return};case 786444:{b[c[3529400]>>1]=e;return};case 786432:case 786434:case 786436:case 786438:{b[(c[3529820]|0)+((d>>>1&3)<<1)>>1]=e;return};default:{return}}}function diX(b,d){b=b|0;d=d|0;var f=0,g=0,h=0;if((b&1046528|0)==655360){f=c[2387244]|0;a[f+(b&2047^1)|0]=d;g=b&2046;h=e[f+g>>1]|0;f=h>>>5&31;c[(c[3530132]|0)+(g>>>1<<2)>>2]=h>>>10<<11&63488|h&31|(f<<3|f>>>2)<<3&2016;return}f=b&1048575;if((f|0)==786447){a[c[3528334]|0]=d;a[c[3528388]|0]=1;a[9706117]=1;return}else if((f|0)==786441){if((c[2439298]|0)!=11){return}c[3528802]=d<<24>>24==-64?2:1;return}else if((f|0)==786473){c[2439298]=d&255;return}else{return}}function diY(a){a=a|0;var b=0,c=0;b=a&1048575;if((b|0)==786458){c=(d[9550778]|0)<<8|(d[9550777]|0);return c|0}else if((b|0)==786456){c=(d[9550778]|0)<<8|(d[9550776]|0);return c|0}else if((b|0)==786460){c=(d[9635521]|0)<<8|(d[9635520]|0);return c|0}else{c=0;return c|0}return 0}function diZ(b){b=b|0;var d=0;switch(b&1048575|0){case 786456:case 786458:{d=a[9550778]|0;break};case 786463:{d=a[c[3528388]|0]|0;break};case 786459:{d=a[9550777]|0;break};case 786457:{d=a[9550776]|0;break};default:{d=0}}return d|0}function di_(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=b&65535;if((f|0)==61441){b=c[2113304]|0;a[14168504+b|0]=e;mv(0,b,e&255);return}else if((f|0)==62976){b=c[2418506]|0;a[b+8|0]=e;c[2424874]=b;g=b+10|0;h=a[g]|0;a[g]=0;g=c[2424874]|0;i=g+16|0;do{if((a[i]|h)<<24>>24==0){if((a[g+10|0]|0)==0){j=b;break}if((a[g+9|0]|0)==0){j=b;break}a[i]=2;if(!(a[635136]|0)){j=b;break}k=a[(c[2424874]|0)+11|0]|0;Vk();l=c[2424874]|0;m=a[l+11|0]|0;if(k<<24>>24==m<<24>>24){j=b;break}k=c[l+12>>2]|0;if((k|0)==0){j=b;break}gf[k&2047](m&255);j=c[2418506]|0}else{j=b}}while(0);c[2424874]=j;b=j+10|0;j=a[b]|0;a[b]=1;b=c[2424874]|0;i=b+16|0;if((a[i]|j)<<24>>24!=0){return}if((a[b+10|0]|0)==0){return}if((a[b+9|0]|0)==0){return}a[i]=2;if(!(a[635136]|0)){return}i=a[(c[2424874]|0)+11|0]|0;Vk();b=c[2424874]|0;j=a[b+11|0]|0;if(i<<24>>24==j<<24>>24){return}i=c[b+12>>2]|0;if((i|0)==0){return}gf[i&2047](j&255);return}else if((f|0)==62464){j=e&255;i=c[2418506]|0;c[2424874]=i;b=i+9|0;i=a[b]|0;a[b]=(e&255)>>>7;do{if(i<<24>>24!=0){if((a[(c[2424874]|0)+9|0]|0)!=0){break}Vl()}}while(0);i=j&1;j=c[3528392]|0;if((i|0)==(d[j]|0)){return}b=c[2386670]|0;g=b+((i<<17)+131072)|0;gGC(b|0,g|0,131072)|0;a[j]=i&255;return}else if((f|0)==61440){c[2113304]=e&255;return}else{return}}function di$(b){b=b|0;var d=0,e=0;d=b&65535;if((d|0)==61952){a[c[3528388]|0]=0;b=(a[c[2385298]|0]|0)!=0|0;if((b|0)==0){a[9706117]=0}else if((b|0)==1){a[9706117]=1}e=a[c[3528334]|0]|0;return e|0}else if((d|0)==61440|(d|0)==61441){e=c[(c[3531464]|0)+4240>>2]&255;return e|0}else{e=0;return e|0}return 0}function di0(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2406804+(b*112|0)>>2];c[a+104>>2]=c[2406808+(b*112|0)>>2];c[a+108>>2]=c[2406812+(b*112|0)>>2];d=0;return d|0}function di1(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=2406704+(b*112|0);e=0;return e|0}function di2(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3533272+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function di3(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>50){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3583048+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function di4(){return djl(3420,0)|0}function di5(){var b=0,d=0,e=0,f=0,g=0;if((c[2392]|0)>=0){b=0;do{d=14130368+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}d=14130384+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}b=b+1|0;}while((b|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;fwZ();b=c[3531464]|0;c[b+44344>>2]=0;c[b+44348>>2]=0;if((b|0)!=0){gGr(b);c[3531464]=0}b=c[2406684]|0;if((b|0)!=0){gGr(b);c[2406684]=0}b=c[2418506]|0;if((b|0)!=0){gGr(b);c[2418506]=0}b=c[2418507]|0;if((b|0)!=0){gGr(b);c[2418507]=0}a[635136]=0;c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}b=c[2415050]|0;d=0;while(1){if((d|0)>=1024){f=64788;break}g=9638528+(d<<2)|0;if((c[g>>2]|0)==(b|0)){break}else{d=d+1|0}}if((f|0)==64788){c[2415050]=0;return 0}gGr(b);c[g>>2]=0;c[2415050]=0;return 0}function di6(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((a[9624808]|0)!=0){djo()}d=c[2392]|0;if((d|0)>=0){gGz(8452240,0,((d|0)>0?(d<<2)+4|0:4)|0)}c[2113054]=0;d=c[2385548]|0;if((d|0)>0){gGz(9752472,0,((d|0)>1?d<<2:4)|0)}c[2433530]=0;gGz(9550776,0,3);d=0;e=0;f=0;g=0;do{e=((a[9634152+d|0]&1)<<d^e&255)&255;f=((a[9631928+d|0]&1)<<d^f&255)&255;g=((a[9629856+d|0]&1)<<d^g&255)&255;d=d+1|0;}while((d|0)<8);a[9550776]=e;a[9550777]=f;a[9550778]=g;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060]}g=c[2439330]|0;if((g|0)!=0){f=g;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;f=0;g=0;e=0;d=0;while(1){h=10-d|0;i=(133333-e|0)/(h|0)|0;c[2113056]=i;j=RG(i)|0;c[2113054]=(c[2113054]|0)+j;c[2276108]=-1;c[2113056]=-1;i=j+e|0;do{if((c[3528802]|0)==2&(d|0)==4){c[8452200+(c[2394]<<2)>>2]=8193;c[2276080]=256;if((c[2276079]|0)>>>0>=256){break}RH(1)}}while(0);j=(66666-g|0)/(h|0)|0;do{if((j|0)<1){k=0}else{if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){l=gfc(j)|0;c[2433530]=(c[2433530]|0)+l;k=l;break}else{c[2433530]=(c[2433530]|0)+j;k=j;break}}}while(0);j=c[2112964]|0;if((j|0)==0){m=f}else{h=a[9688]|0?53:0;l=f<<1;gg[c[3542124]&4095](j+(l<<1)|0,h);Vj(0,(c[2112964]|0)+(l<<1)|0,h);m=h+f|0}h=d+1|0;if((h|0)<10){f=m;g=k+g|0;e=i;d=h}else{break}}do{if((c[3528802]|0)!=0){c[8452200+(c[2394]<<2)>>2]=8193;c[2276080]=256;if((c[2276079]|0)>>>0>=256){break}RH(1)}}while(0);d=c[2112964]|0;do{if((d|0)!=0){e=a[9688]|0;g=e?534:0;k=g-m|0;if((k|0)>0){f=m<<1;gg[c[3542124]&4095](d+(f<<1)|0,k);Vj(0,(c[2112964]|0)+(f<<1)|0,k);k=a[9688]|0;n=k?534:0;o=k}else{n=g;o=e}if((n|0)==0){break}e=c[2112964]|0;g=o?534:0;k=0;do{f=k<<1;h=e+(f<<1)|0;b[h>>1]=((b[h>>1]|0)/2|0)&65535;h=e+((f|1)<<1)|0;b[h>>1]=((b[h>>1]|0)/2|0)&65535;k=k+1|0;}while((k|0)<(g|0))}}while(0);o=c[1836236]|0;n=c[9757320+(o<<2)>>2]|0;if((n|0)!=0){d=n;gGC(d|0,9706056,76)|0}c[9752472+(o<<2)>>2]=c[2433530];c[14113936+(o<<2)>>2]=c[2076596];c[9669104+(o<<2)>>2]=c[3541536];c[1836236]=-1;o=c[2394]|0;d=c[14130368+(o<<2)>>2]|0;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[8452240+(o<<2)>>2]=c[2113054];c[2394]=-1;if((c[2112968]|0)==0){return 0}di7()|0;return 0}function di7(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((a[9547816]|0)!=0){f=c[2387244]|0;g=c[3530132]|0;h=0;do{i=e[f+h>>1]|0;j=i>>>5&31;c[g+(((h|0)/2|0)<<2)>>2]=i>>>10<<11&63488|i&31|(j<<3|j>>>2)<<3&2016;h=h+2|0;}while((h|0)<2048);a[9547816]=0}h=c[2443702]|0;g=a[h+1|0]|0;f=a[h]|0;j=c[2112926]|0;gGz(j|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);djq(0,c[3530904]|0);i=(((g&255)>(f&255)?f:g)&255)<<2;djr(0,i);djq(1,c[3530668]|0);djr(i,d[h]<<2);if((c[2444214]|0)!=0){k=c[3530132]|0;R8(k);return 0}h=e[c[3529400]>>1]<<4&240|512;i=c[2113070]|0;if((i|0)<=0){k=c[3530132]|0;R8(k);return 0}g=c[2113068]|0;f=(c[2387998]|0)+6|0;l=0;m=j;while(1){if((g|0)>0){j=0;do{n=e[f+(((j|0)/4|0)<<1)>>1]|0;o=n>>>12;if((o|0)!=15){b[m+(j<<1)>>1]=(o|h)&65535}o=n>>>8&15;if((o|0)!=15){b[m+((j|1)<<1)>>1]=(o|h)&65535}o=n>>>4&15;if((o|0)!=15){b[m+((j|2)<<1)>>1]=(o|h)&65535}o=n&15;if((o|0)!=15){b[m+((j|3)<<1)>>1]=(o|h)&65535}j=j+4|0;}while((j|0)<(g|0))}j=l+1|0;if((j|0)<(i|0)){f=f+256|0;l=j;m=m+(g<<1)|0}else{break}}k=c[3530132]|0;R8(k);return 0}function di8(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;f=i;i=i+160|0;g=f|0;h=f+16|0;j=f+32|0;k=f+48|0;l=f+64|0;m=f+80|0;n=f+96|0;o=f+112|0;p=f+128|0;q=f+144|0;r=(e|0)==0;if(!r){c[e>>2]=169737}if((b&32|0)!=0){gGz(q|0,0,12);s=c[2414758]|0;c[q>>2]=s;c[q+4>>2]=(c[2411812]|0)-s;c[q+12>>2]=162152;s=c[2076592]|0;gj[s&4095](q)|0}if((b&64|0)==0){t=b&2}else{q=n|0;gGz(m|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){s=n+9|0;n=l;u=l|0;v=l+4|0;w=l+12|0;x=m|0;y=m+4|0;z=m+12|0;A=0;do{gGC(q|0,614896,11)|0;a[s]=A+48&255;B=8452256+(A<<2)|0;gGz(n|0,0,12);c[u>>2]=B;c[v>>2]=4;c[w>>2]=164976;gj[c[2076592]&4095](l)|0;if((c[B>>2]|0)!=0){c[x>>2]=c[14130368+(A<<2)>>2];c[y>>2]=c[8452184+(A<<2)>>2];c[z>>2]=q;B=c[2076592]|0;gj[B&4095](m)|0}A=A+1|0;}while((A|0)<=(c[2392]|0))}fw$(b);gGz(k|0,0,12);c[k>>2]=8453216;c[k+4>>2]=4;c[k+12>>2]=107480;A=c[2076592]|0;gj[A&4095](k)|0;gGz(j|0,0,12);c[j>>2]=14168504;c[j+4>>2]=256;c[j+12>>2]=476464;k=c[2076592]|0;gj[k&4095](j)|0;j=b&2;if((j|0)==0){C=g;D=h|0}else{b=0;do{mv(0,b,d[14168504+b|0]|0);b=b+1|0;}while((b|0)<256);C=g;D=h|0}if(!r){c[e>>2]=169600}c[2424874]=c[2418506];e=h|0;cC(e|0,100600,(h=i,i=i+8|0,c[h>>2]=0,h)|0)|0;i=h;c[g>>2]=9699496;c[g+4>>2]=80;c[g+8>>2]=0;c[g+12>>2]=e;e=c[2076592]|0;gj[e&4095](g)|0;gGz(p|0,0,12);c[p>>2]=9757192;c[p+4>>2]=4;c[p+12>>2]=150168;g=c[2076592]|0;gj[g&4095](p)|0;gGz(o|0,0,12);c[o>>2]=14115208;c[o+4>>2]=4;c[o+12>>2]=146856;p=c[2076592]|0;gj[p&4095](o)|0;t=j}if((t|0)==0){i=f;return 0}t=c[3528392]|0;j=d[t]|0;a[t]=-1;o=j&1;j=c[2386670]|0;p=j+((o<<17)+131072)|0;gGC(j|0,p|0,131072)|0;a[t]=o&255;a[9547816]=1;i=f;return 0}function di9(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5714116+(b*112|0)>>2];c[a+104>>2]=c[5714120+(b*112|0)>>2];c[a+108>>2]=c[5714124+(b*112|0)>>2];d=0;return d|0}function dja(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=5714016+(b*112|0);e=0;return e|0}function djb(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>50){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6146888+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function djc(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4369500+(b*112|0)>>2];c[a+104>>2]=c[4369504+(b*112|0)>>2];c[a+108>>2]=c[4369508+(b*112|0)>>2];d=0;return d|0}function djd(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=4369400+(b*112|0);e=0;return e|0}function dje(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>49){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4936512+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function djf(){return djl(1480,1)|0}function djg(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>23){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2184020+(b*112|0)>>2];c[a+104>>2]=c[2184024+(b*112|0)>>2];c[a+108>>2]=c[2184028+(b*112|0)>>2];d=0;return d|0}function djh(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<24&(d|0)==0)){e=1;return e|0}c[a>>2]=2183920+(b*112|0);e=0;return e|0}function dji(){return djl(1420,1)|0}function djj(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>23){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2181332+(b*112|0)>>2];c[a+104>>2]=c[2181336+(b*112|0)>>2];c[a+108>>2]=c[2181340+(b*112|0)>>2];d=0;return d|0}function djk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<24&(d|0)==0)){e=1;return e|0}c[a>>2]=2181232+(b*112|0);e=0;return e|0}function djl(d,e){d=d|0;e=e|0;var f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;f=c[2415050]|0;c[2388184]=f;c[2385968]=f+262144;c[3530904]=f+327680;c[3530668]=f+1376256;c[3530472]=f+2424832;c[2386670]=f+3473408;c[3530132]=f+3866624;g=f+3870720|0;c[2414758]=g;c[2387998]=g;c[2386516]=f+3936256;c[2386260]=f+3940352;c[2388302]=f+3956736;c[2387244]=f+3973120;c[2386122]=f+3975168;c[3528334]=f+3977216;c[3528388]=f+3977217;c[2385298]=f+3977218;c[3528392]=f+3977219;c[3529820]=f+3977220;c[3529400]=f+3977228;c[2443702]=f+3977230;g=f+3977232|0;c[2411812]=g;c[2414360]=g;f=g;g=0;while(1){if((g|0)>=1024){break}i=9638528+(g<<2)|0;if((c[i>>2]|0)==0){j=64944;break}else{g=g+1|0}}do{if((j|0)==64944){g=gGq(f)|0;c[i>>2]=g;if((g|0)==0){break}gGz(g|0,0,f|0);c[2415050]=g;gGz(g|0,0,f|0);c[2388184]=g;c[2385968]=g+262144;k=g+327680|0;c[3530904]=k;l=g+1376256|0;c[3530668]=l;m=g+2424832|0;c[3530472]=m;c[2386670]=g+3473408;c[3530132]=g+3866624;n=g+3870720|0;c[2414758]=n;c[2387998]=n;c[2386516]=g+3936256;c[2386260]=g+3940352;c[2388302]=g+3956736;c[2387244]=g+3973120;c[2386122]=g+3975168;c[3528334]=g+3977216;c[3528388]=g+3977217;c[2385298]=g+3977218;c[3528392]=g+3977219;c[3529820]=g+3977220;c[3529400]=g+3977228;c[2443702]=g+3977230;n=g+3977232|0;c[2411812]=n;c[2414360]=n;if((d|0)!=0){gGz(k|0,-1|0,524288);gGz(l|0,-1|0,524288);gGz(m|0,-1|0,524288);if((gD[d&8191]()|0)!=0){o=1;return o|0}m=c[3530904]|0;l=m+393216|0;k=m+262144|0;gGC(l|0,k|0,131072)|0;k=1048574;do{l=a[m+((k|0)/2|0)|0]|0;a[m+k|0]=l&15;a[m+(k|1)|0]=(l&255)>>>4;k=k-2|0;}while((k|0)>-1);k=c[3530668]|0;m=k+393216|0;l=k+262144|0;gGC(m|0,l|0,131072)|0;l=1048574;do{m=a[k+((l|0)/2|0)|0]|0;a[k+l|0]=m&15;a[k+(l|1)|0]=(m&255)>>>4;l=l-2|0;}while((l|0)>-1);l=c[3530472]|0;k=l+393216|0;m=l+262144|0;gGC(k|0,m|0,131072)|0;m=1048574;do{k=a[l+((m|0)/2|0)|0]|0;a[l+m|0]=k&15;a[l+(m|1)|0]=(k&255)>>>4;m=m-2|0;}while((m|0)>-1)}c[2444214]=e;fxU(0,425984);if((c[2394]|0)==0){p=c[2112932]|0}else{c[2394]=0;m=c[3532596]|0;c[2112932]=m;l=c[3532592]|0;if((l|0)!=0){gGC(9104152,l|0,280)|0}c[2113054]=c[2113060];p=m}m=c[2388184]|0;l=c[2387998]|0;k=c[2386516]|0;n=c[2386260]|0;g=c[2387244]|0;q=c[2388302]|0;r=q+1024|0;s=q+2048|0;t=q+3072|0;u=g+1024|0;v=n+1024|0;w=n+2048|0;x=n+3072|0;y=k+1024|0;z=k+2048|0;A=k+3072|0;B=0;do{C=B|262143;if(B>>>0<=C>>>0){D=p+(B>>>10<<2)|0;E=B;while(1){F=m+(E-B)|0;c[D>>2]=F;c[D+131072>>2]=F;F=E+1024|0;if(F>>>0>C>>>0){break}else{D=D+4|0;E=F}}}E=B|262144;D=B|327679;if(E>>>0<=D>>>0){C=p+(E>>>10<<2)|0;F=E;while(1){G=l+(F-E)|0;c[C>>2]=G;c[C+65536>>2]=G;c[C+131072>>2]=G;G=F+1024|0;if(G>>>0>D>>>0){break}else{C=C+4|0;F=G}}}F=B|393216;if(F>>>0<=(B|397311)>>>0){C=F>>>10;c[p+(C<<2)>>2]=k;c[p+(C+16384<<2)>>2]=k;c[p+(C+32768<<2)>>2]=k;F=C|1;c[p+(F<<2)>>2]=y;c[p+(F+16384<<2)>>2]=y;c[p+(F+32768<<2)>>2]=y;c[p+(F+1<<2)>>2]=z;c[p+(F+16385<<2)>>2]=z;c[p+(F+32769<<2)>>2]=z;F=C|3;c[p+(F<<2)>>2]=A;c[p+(F+16384<<2)>>2]=A;c[p+(F+32768<<2)>>2]=A}F=B|524288;if(F>>>0<=(B|540671)>>>0){C=F>>>10;c[p+(C<<2)>>2]=n;c[p+(C+16384<<2)>>2]=n;c[p+(C+32768<<2)>>2]=n;D=C|1;c[p+(D<<2)>>2]=v;c[p+(D+16384<<2)>>2]=v;c[p+(D+32768<<2)>>2]=v;c[p+(D+1<<2)>>2]=w;c[p+(D+16385<<2)>>2]=w;c[p+(D+32769<<2)>>2]=w;D=B|527360;E=C|3;c[p+(E<<2)>>2]=x;c[p+(E+16384<<2)>>2]=x;c[p+(E+32768<<2)>>2]=x;G=n+(D+1024-F)|0;c[p+(E+1<<2)>>2]=G;c[p+(E+16385<<2)>>2]=G;c[p+(E+32769<<2)>>2]=G;G=n+(D+2048-F)|0;c[p+(E+2<<2)>>2]=G;c[p+(E+16386<<2)>>2]=G;c[p+(E+32770<<2)>>2]=G;G=n+(D+3072-F)|0;c[p+(E+3<<2)>>2]=G;c[p+(E+16387<<2)>>2]=G;c[p+(E+32771<<2)>>2]=G;G=B|531456;E=C|7;D=n+(G-F)|0;c[p+(E<<2)>>2]=D;c[p+(E+16384<<2)>>2]=D;c[p+(E+32768<<2)>>2]=D;D=n+(G+1024-F)|0;c[p+(E+1<<2)>>2]=D;c[p+(E+16385<<2)>>2]=D;c[p+(E+32769<<2)>>2]=D;D=n+(G+2048-F)|0;c[p+(E+2<<2)>>2]=D;c[p+(E+16386<<2)>>2]=D;c[p+(E+32770<<2)>>2]=D;D=n+(G+3072-F)|0;c[p+(E+3<<2)>>2]=D;c[p+(E+16387<<2)>>2]=D;c[p+(E+32771<<2)>>2]=D;D=n+(G+4096-F)|0;c[p+(E+4<<2)>>2]=D;c[p+(E+16388<<2)>>2]=D;c[p+(E+32772<<2)>>2]=D;D=n+(G+5120-F)|0;c[p+(E+5<<2)>>2]=D;c[p+(E+16389<<2)>>2]=D;c[p+(E+32773<<2)>>2]=D;D=n+(G+6144-F)|0;c[p+(E+6<<2)>>2]=D;c[p+(E+16390<<2)>>2]=D;c[p+(E+32774<<2)>>2]=D;D=n+(G+7168-F)|0;c[p+(E+7<<2)>>2]=D;c[p+(E+16391<<2)>>2]=D;c[p+(E+32775<<2)>>2]=D;D=C|15;C=n+((B|539648)-F)|0;c[p+(D<<2)>>2]=C;c[p+(D+16384<<2)>>2]=C;c[p+(D+32768<<2)>>2]=C}C=B|655360;if(C>>>0<=(B|657407)>>>0){D=C>>>10;c[p+(D<<2)>>2]=g;c[p+(D+32768<<2)>>2]=g;C=D|1;c[p+(C<<2)>>2]=u;c[p+(C+32768<<2)>>2]=u}C=B|1032192;if(C>>>0<=(B|1048575)>>>0){D=C>>>10;c[p+(D<<2)>>2]=q;c[p+(D+16384<<2)>>2]=q;c[p+(D+32768<<2)>>2]=q;F=D|1;c[p+(F<<2)>>2]=r;c[p+(F+16384<<2)>>2]=r;c[p+(F+32768<<2)>>2]=r;c[p+(F+1<<2)>>2]=s;c[p+(F+16385<<2)>>2]=s;c[p+(F+32769<<2)>>2]=s;F=B|1035264;E=D|3;c[p+(E<<2)>>2]=t;c[p+(E+16384<<2)>>2]=t;c[p+(E+32768<<2)>>2]=t;G=q+(F+1024-C)|0;c[p+(E+1<<2)>>2]=G;c[p+(E+16385<<2)>>2]=G;c[p+(E+32769<<2)>>2]=G;G=q+(F+2048-C)|0;c[p+(E+2<<2)>>2]=G;c[p+(E+16386<<2)>>2]=G;c[p+(E+32770<<2)>>2]=G;G=q+(F+3072-C)|0;c[p+(E+3<<2)>>2]=G;c[p+(E+16387<<2)>>2]=G;c[p+(E+32771<<2)>>2]=G;G=B|1039360;E=D|7;F=q+(G-C)|0;c[p+(E<<2)>>2]=F;c[p+(E+16384<<2)>>2]=F;c[p+(E+32768<<2)>>2]=F;F=q+(G+1024-C)|0;c[p+(E+1<<2)>>2]=F;c[p+(E+16385<<2)>>2]=F;c[p+(E+32769<<2)>>2]=F;F=q+(G+2048-C)|0;c[p+(E+2<<2)>>2]=F;c[p+(E+16386<<2)>>2]=F;c[p+(E+32770<<2)>>2]=F;F=q+(G+3072-C)|0;c[p+(E+3<<2)>>2]=F;c[p+(E+16387<<2)>>2]=F;c[p+(E+32771<<2)>>2]=F;F=q+(G+4096-C)|0;c[p+(E+4<<2)>>2]=F;c[p+(E+16388<<2)>>2]=F;c[p+(E+32772<<2)>>2]=F;F=q+(G+5120-C)|0;c[p+(E+5<<2)>>2]=F;c[p+(E+16389<<2)>>2]=F;c[p+(E+32773<<2)>>2]=F;F=q+(G+6144-C)|0;c[p+(E+6<<2)>>2]=F;c[p+(E+16390<<2)>>2]=F;c[p+(E+32774<<2)>>2]=F;F=q+(G+7168-C)|0;c[p+(E+7<<2)>>2]=F;c[p+(E+16391<<2)>>2]=F;c[p+(E+32775<<2)>>2]=F;F=D|15;D=q+((B|1047552)-C)|0;c[p+(F<<2)>>2]=D;c[p+(F+16384<<2)>>2]=D;c[p+(F+32768<<2)>>2]=D}B=B+1048576|0;}while((B|0)<16777216);c[p+196728>>2]=2560;c[p+196648>>2]=1384;c[p+196688>>2]=1438;c[p+196608>>2]=3010;B=c[3532592]|0;if((B|0)!=0){gGC(B|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);B=c[2439330]|0;q=(B|0)==0;if(!q){t=B;gGC(9706056,t|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];t=c[3528484]|0;c[2076596]=t;s=c[2417276]|0;c[3541536]=s;c[1836236]=0;r=c[2385968]|0;u=0;g=0;while(1){c[B+76+(g<<2)>>2]=r+(g<<8);n=u+1&65535;if((n&65535)>239){H=0;I=0;break}else{u=n;g=n&65535}}while(1){g=r+(I<<8)|0;c[B+76+(I+512<<2)>>2]=g;c[B+76+(I+768<<2)>>2]=g;g=H+1&65535;if((g&65535)>239){break}else{H=g;I=g&65535}}r=c[2386122]|0;c[B+1068>>2]=r;g=r+256|0;c[B+1072>>2]=g;u=r+512|0;c[B+1076>>2]=u;n=r+768|0;c[B+1080>>2]=n;x=r+1024|0;c[B+1084>>2]=x;w=r+1280|0;c[B+1088>>2]=w;v=r+1536|0;c[B+1092>>2]=v;A=r+1792|0;c[B+1096>>2]=A;c[B+2092>>2]=r;c[B+2096>>2]=g;c[B+2100>>2]=u;c[B+2104>>2]=n;c[B+2108>>2]=x;c[B+2112>>2]=w;c[B+2116>>2]=v;c[B+2120>>2]=A;c[B+3116>>2]=r;c[B+4140>>2]=r;c[B+3120>>2]=g;c[B+4144>>2]=g;c[B+3124>>2]=u;c[B+4148>>2]=u;c[B+3128>>2]=n;c[B+4152>>2]=n;c[B+3132>>2]=x;c[B+4156>>2]=x;c[B+3136>>2]=w;c[B+4160>>2]=w;c[B+3140>>2]=v;c[B+4164>>2]=v;c[B+3144>>2]=A;c[B+4168>>2]=A;c[B+4184>>2]=1210;c[B+4180>>2]=2750;if(!q){A=B;gGC(A|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=t;c[2417276]=s;c[1836236]=-1;A=a[9680]|0;v=A?32e3:0;if(A){if(a[9624]|0){A=v*3|0;w=62500;while(1){if((w|0)>(A|0)){w=w>>1}else{J=1222;K=w;break}}}else{J=2462;K=v}c[2429380]=K;c[3542124]=J;mw(4e6,K);w=gGq(262144)|0;c[2406684]=w;gGz(w|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(4e6,11025)}c[(c[3531464]|0)+44344>>2]=308;h[745421]=.5;c[2436794]=3;h[745420]=.5;c[2436792]=3;w=c[2386670]|0;A=gGq(80)|0;s=A;c[2418506]=s;c[2424874]=s;gGz(A|0,0,80);a[635136]=0;c[A+4>>2]=~~(16.0e4/(a[9680]|0?32.0e3:0.0)*4194304.0);a[A+16|0]=0;if((w|0)==0){a[635136]=1}else{c[A+52>>2]=w}a[A+9|0]=1;a[(c[2424874]|0)+10|0]=1;w=c[2424874]|0;h[w+64>>3]=1.0;c[w+72>>2]=3;Vl();c[2424874]=s;h[A+64>>3]=.5;c[A+72>>2]=3;djo();A=c[642608+(c[2436]<<2)>>2]|0;s=c[A+128>>2]|0;if((c[A+52>>2]&4|0)==0){c[2113068]=s;w=c[A+132>>2]|0;c[2113070]=w;c[2443814]=s;c[2440436]=w;L=s;M=w}else{c[2113070]=s;w=c[A+132>>2]|0;c[2113068]=w;c[2440436]=s;c[2443814]=w;L=w;M=s}s=ag(L<<1,M)|0;w=gGq(s)|0;c[2112926]=w;if((w|0)==0){o=0;return o|0}gGz(w|0,0,s|0);o=0;return o|0}}while(0);c[2415050]=0;o=1;return o|0}function djm(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;a=i;i=i+1680|0;b=a|0;d=a+112|0;e=a+120|0;f=a+232|0;g=a+240|0;h=a+352|0;j=a+360|0;k=a+472|0;l=a+480|0;m=a+592|0;n=a+600|0;o=a+712|0;p=a+720|0;q=a+832|0;r=a+840|0;s=a+952|0;t=a+960|0;u=a+1072|0;v=a+1080|0;w=a+1192|0;x=a+1200|0;y=a+1312|0;z=a+1320|0;A=a+1432|0;B=a+1440|0;C=a+1552|0;D=a+1560|0;E=a+1672|0;if((R6((c[2388184]|0)+1|0,0,2)|0)!=0){F=1;i=a;return F|0}if((R6(c[2388184]|0,1,2)|0)!=0){F=1;i=a;return F|0}if((R6((c[2388184]|0)+131073|0,2,2)|0)!=0){F=1;i=a;return F|0}if((R6((c[2388184]|0)+131072|0,3,2)|0)!=0){F=1;i=a;return F|0}G=c[2385968]|0;if((c[3542200]|0)==0){F=1;i=a;return F|0}H=D+108|0;c[H>>2]=0;I=D+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](D,4)|0;do{if((c[H>>2]|0)!=0){D=c[I>>2]|0;c[E>>2]=9534384;J=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[J&16383](E,4,0)|0;if((D|0)<1){F=1;i=a;return F|0}if((gzL(G,0,4)|0)==0){break}else{F=1}i=a;return F|0}}while(0);G=c[3530904]|0;if((c[3542200]|0)==0){F=1;i=a;return F|0}E=B+108|0;c[E>>2]=0;I=B+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](B,5)|0;do{if((c[E>>2]|0)!=0){B=c[I>>2]|0;c[C>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](C,5,0)|0;if((B|0)<1){F=1;i=a;return F|0}if((gzL(G,0,5)|0)==0){break}else{F=1}i=a;return F|0}}while(0);G=(c[3530904]|0)+65536|0;if((c[3542200]|0)==0){F=1;i=a;return F|0}C=z+108|0;c[C>>2]=0;I=z+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,6)|0;do{if((c[C>>2]|0)!=0){z=c[I>>2]|0;c[A>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](A,6,0)|0;if((z|0)<1){F=1;i=a;return F|0}if((gzL(G,0,6)|0)==0){break}else{F=1}i=a;return F|0}}while(0);G=(c[3530904]|0)+131072|0;if((c[3542200]|0)==0){F=1;i=a;return F|0}A=x+108|0;c[A>>2]=0;I=x+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,7)|0;do{if((c[A>>2]|0)!=0){x=c[I>>2]|0;c[y>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](y,7,0)|0;if((x|0)<1){F=1;i=a;return F|0}if((gzL(G,0,7)|0)==0){break}else{F=1}i=a;return F|0}}while(0);G=(c[3530904]|0)+196608|0;if((c[3542200]|0)==0){F=1;i=a;return F|0}y=v+108|0;c[y>>2]=0;I=v+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,8)|0;do{if((c[y>>2]|0)!=0){v=c[I>>2]|0;c[w>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](w,8,0)|0;if((v|0)<1){F=1;i=a;return F|0}if((gzL(G,0,8)|0)==0){break}else{F=1}i=a;return F|0}}while(0);G=(c[3530904]|0)+262144|0;if((c[3542200]|0)==0){F=1;i=a;return F|0}w=t+108|0;c[w>>2]=0;I=t+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,9)|0;do{if((c[w>>2]|0)!=0){t=c[I>>2]|0;c[u>>2]=9534384;y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[y&16383](u,9,0)|0;if((t|0)<1){F=1;i=a;return F|0}if((gzL(G,0,9)|0)==0){break}else{F=1}i=a;return F|0}}while(0);G=c[3530668]|0;if((c[3542200]|0)==0){F=1;i=a;return F|0}u=r+108|0;c[u>>2]=0;I=r+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,10)|0;do{if((c[u>>2]|0)!=0){r=c[I>>2]|0;c[s>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](s,10,0)|0;if((r|0)<1){F=1;i=a;return F|0}if((gzL(G,0,10)|0)==0){break}else{F=1}i=a;return F|0}}while(0);G=(c[3530668]|0)+65536|0;if((c[3542200]|0)==0){F=1;i=a;return F|0}s=p+108|0;c[s>>2]=0;I=p+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,11)|0;do{if((c[s>>2]|0)!=0){p=c[I>>2]|0;c[q>>2]=9534384;u=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[u&16383](q,11,0)|0;if((p|0)<1){F=1;i=a;return F|0}if((gzL(G,0,11)|0)==0){break}else{F=1}i=a;return F|0}}while(0);G=(c[3530668]|0)+131072|0;if((c[3542200]|0)==0){F=1;i=a;return F|0}q=n+108|0;c[q>>2]=0;I=n+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,12)|0;do{if((c[q>>2]|0)!=0){n=c[I>>2]|0;c[o>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](o,12,0)|0;if((n|0)<1){F=1;i=a;return F|0}if((gzL(G,0,12)|0)==0){break}else{F=1}i=a;return F|0}}while(0);G=(c[3530668]|0)+196608|0;if((c[3542200]|0)==0){F=1;i=a;return F|0}o=l+108|0;c[o>>2]=0;I=l+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,13)|0;do{if((c[o>>2]|0)!=0){l=c[I>>2]|0;c[m>>2]=9534384;q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[q&16383](m,13,0)|0;if((l|0)<1){F=1;i=a;return F|0}if((gzL(G,0,13)|0)==0){break}else{F=1}i=a;return F|0}}while(0);G=(c[3530668]|0)+262144|0;if((c[3542200]|0)==0){F=1;i=a;return F|0}m=j+108|0;c[m>>2]=0;I=j+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,14)|0;do{if((c[m>>2]|0)!=0){j=c[I>>2]|0;c[k>>2]=9534384;o=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[o&16383](k,14,0)|0;if((j|0)<1){F=1;i=a;return F|0}if((gzL(G,0,14)|0)==0){break}else{F=1}i=a;return F|0}}while(0);G=(c[3530668]|0)+327680|0;if((c[3542200]|0)==0){F=1;i=a;return F|0}k=g+108|0;c[k>>2]=0;I=g+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,15)|0;do{if((c[k>>2]|0)!=0){g=c[I>>2]|0;c[h>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](h,15,0)|0;if((g|0)<1){F=1;i=a;return F|0}if((gzL(G,0,15)|0)==0){break}else{F=1}i=a;return F|0}}while(0);if((R6((c[3530472]|0)+1|0,16,2)|0)!=0){F=1;i=a;return F|0}if((R6(c[3530472]|0,17,2)|0)!=0){F=1;i=a;return F|0}if((R6((c[3530472]|0)+131073|0,18,2)|0)!=0){F=1;i=a;return F|0}if((R6((c[3530472]|0)+131072|0,19,2)|0)!=0){F=1;i=a;return F|0}if((R6((c[3530472]|0)+196609|0,20,2)|0)!=0){F=1;i=a;return F|0}if((R6((c[3530472]|0)+196608|0,21,2)|0)!=0){F=1;i=a;return F|0}G=(c[2386670]|0)+131072|0;if((c[3542200]|0)==0){F=1;i=a;return F|0}h=e+108|0;c[h>>2]=0;I=e+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,22)|0;do{if((c[h>>2]|0)!=0){e=c[I>>2]|0;c[f>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](f,22,0)|0;if((e|0)<1){F=1;i=a;return F|0}if((gzL(G,0,22)|0)==0){break}else{F=1}i=a;return F|0}}while(0);G=(c[2386670]|0)+262144|0;if((c[3542200]|0)==0){F=1;i=a;return F|0}f=b+108|0;c[f>>2]=0;I=b+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](b,23)|0;if((c[f>>2]|0)==0){F=0;i=a;return F|0}f=c[I>>2]|0;c[d>>2]=9534384;gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](d,23,0)|0;if((f|0)<1){F=1;i=a;return F|0}F=(gzL(G,0,23)|0)!=0|0;i=a;return F|0}function djn(b){b=b|0;var d=0;d=b&255;a[c[2385298]|0]=d;b=(a[c[3528388]|0]|d)<<24>>24!=0|0;if((b|0)==1){a[9706117]=1;return}else if((b|0)==0){a[9706117]=0;return}else{return}}function djo(){var b=0,d=0,e=0,f=0,g=0;b=c[2414758]|0;gGz(b|0,0,(c[2411812]|0)-b|0);gGz(c[2387998]|0,-1|0,65536);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];b=c[3532592]|0;if((b|0)!=0){gGC(9104152,b|0,280)|0}c[2113054]=c[2113060]}RI();b=c[2394]|0;d=c[14130368+(b<<2)>>2]|0;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[8452240+(b<<2)>>2]=c[2113054];c[2394]=-1;b=c[2439330]|0;d=(b|0)==0;if(!d){e=b;gGC(9706056,e|0,76)|0}e=c[2438118]|0;c[2433530]=e;f=c[3528484]|0;c[2076596]=f;g=c[2417276]|0;c[3541536]=g;c[1836236]=0;gGz(9706056,0,76);if(!d){d=b;gGC(d|0,9706056,76)|0}c[2438118]=e;c[3528484]=f;c[2417276]=g;c[1836236]=-1;mx(0);Vl();g=c[3528392]|0;a[g]=-1;f=c[2386670]|0;e=f+131072|0;gGC(f|0,e|0,131072)|0;a[g]=0;c[2439298]=0;c[3528802]=0;return}function djp(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;a=i;i=i+1560|0;b=a|0;d=a+112|0;e=a+120|0;f=a+232|0;g=a+240|0;h=a+352|0;j=a+360|0;k=a+472|0;l=a+480|0;m=a+592|0;n=a+600|0;o=a+712|0;p=a+720|0;q=a+832|0;r=a+840|0;s=a+952|0;t=a+960|0;u=a+1072|0;v=a+1080|0;w=a+1192|0;x=a+1200|0;y=a+1312|0;z=a+1320|0;A=a+1432|0;B=a+1440|0;C=a+1552|0;if((R6((c[2388184]|0)+1|0,0,2)|0)!=0){D=1;i=a;return D|0}if((R6(c[2388184]|0,1,2)|0)!=0){D=1;i=a;return D|0}if((R6((c[2388184]|0)+131073|0,2,2)|0)!=0){D=1;i=a;return D|0}if((R6((c[2388184]|0)+131072|0,3,2)|0)!=0){D=1;i=a;return D|0}E=c[2385968]|0;if((c[3542200]|0)==0){D=1;i=a;return D|0}F=B+108|0;c[F>>2]=0;G=B+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](B,4)|0;do{if((c[F>>2]|0)!=0){B=c[G>>2]|0;c[C>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](C,4,0)|0;if((B|0)<1){D=1;i=a;return D|0}if((gzL(E,0,4)|0)==0){break}else{D=1}i=a;return D|0}}while(0);E=c[3530904]|0;if((c[3542200]|0)==0){D=1;i=a;return D|0}C=z+108|0;c[C>>2]=0;G=z+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,5)|0;do{if((c[C>>2]|0)!=0){z=c[G>>2]|0;c[A>>2]=9534384;F=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[F&16383](A,5,0)|0;if((z|0)<1){D=1;i=a;return D|0}if((gzL(E,0,5)|0)==0){break}else{D=1}i=a;return D|0}}while(0);E=(c[3530904]|0)+65536|0;if((c[3542200]|0)==0){D=1;i=a;return D|0}A=x+108|0;c[A>>2]=0;G=x+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,6)|0;do{if((c[A>>2]|0)!=0){x=c[G>>2]|0;c[y>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](y,6,0)|0;if((x|0)<1){D=1;i=a;return D|0}if((gzL(E,0,6)|0)==0){break}else{D=1}i=a;return D|0}}while(0);E=(c[3530904]|0)+131072|0;if((c[3542200]|0)==0){D=1;i=a;return D|0}y=v+108|0;c[y>>2]=0;G=v+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,7)|0;do{if((c[y>>2]|0)!=0){v=c[G>>2]|0;c[w>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](w,7,0)|0;if((v|0)<1){D=1;i=a;return D|0}if((gzL(E,0,7)|0)==0){break}else{D=1}i=a;return D|0}}while(0);E=(c[3530904]|0)+196608|0;if((c[3542200]|0)==0){D=1;i=a;return D|0}w=t+108|0;c[w>>2]=0;G=t+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,8)|0;do{if((c[w>>2]|0)!=0){t=c[G>>2]|0;c[u>>2]=9534384;y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[y&16383](u,8,0)|0;if((t|0)<1){D=1;i=a;return D|0}if((gzL(E,0,8)|0)==0){break}else{D=1}i=a;return D|0}}while(0);E=(c[3530904]|0)+262144|0;if((c[3542200]|0)==0){D=1;i=a;return D|0}u=r+108|0;c[u>>2]=0;G=r+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,9)|0;do{if((c[u>>2]|0)!=0){r=c[G>>2]|0;c[s>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](s,9,0)|0;if((r|0)<1){D=1;i=a;return D|0}if((gzL(E,0,9)|0)==0){break}else{D=1}i=a;return D|0}}while(0);E=c[3530668]|0;if((c[3542200]|0)==0){D=1;i=a;return D|0}s=p+108|0;c[s>>2]=0;G=p+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,10)|0;do{if((c[s>>2]|0)!=0){p=c[G>>2]|0;c[q>>2]=9534384;u=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[u&16383](q,10,0)|0;if((p|0)<1){D=1;i=a;return D|0}if((gzL(E,0,10)|0)==0){break}else{D=1}i=a;return D|0}}while(0);E=(c[3530668]|0)+65536|0;if((c[3542200]|0)==0){D=1;i=a;return D|0}q=n+108|0;c[q>>2]=0;G=n+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,11)|0;do{if((c[q>>2]|0)!=0){n=c[G>>2]|0;c[o>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](o,11,0)|0;if((n|0)<1){D=1;i=a;return D|0}if((gzL(E,0,11)|0)==0){break}else{D=1}i=a;return D|0}}while(0);E=(c[3530668]|0)+131072|0;if((c[3542200]|0)==0){D=1;i=a;return D|0}o=l+108|0;c[o>>2]=0;G=l+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,12)|0;do{if((c[o>>2]|0)!=0){l=c[G>>2]|0;c[m>>2]=9534384;q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[q&16383](m,12,0)|0;if((l|0)<1){D=1;i=a;return D|0}if((gzL(E,0,12)|0)==0){break}else{D=1}i=a;return D|0}}while(0);E=(c[3530668]|0)+196608|0;if((c[3542200]|0)==0){D=1;i=a;return D|0}m=j+108|0;c[m>>2]=0;G=j+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,13)|0;do{if((c[m>>2]|0)!=0){j=c[G>>2]|0;c[k>>2]=9534384;o=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[o&16383](k,13,0)|0;if((j|0)<1){D=1;i=a;return D|0}if((gzL(E,0,13)|0)==0){break}else{D=1}i=a;return D|0}}while(0);E=(c[3530668]|0)+262144|0;if((c[3542200]|0)==0){D=1;i=a;return D|0}k=g+108|0;c[k>>2]=0;G=g+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,14)|0;do{if((c[k>>2]|0)!=0){g=c[G>>2]|0;c[h>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](h,14,0)|0;if((g|0)<1){D=1;i=a;return D|0}if((gzL(E,0,14)|0)==0){break}else{D=1}i=a;return D|0}}while(0);if((R6((c[3530472]|0)+1|0,15,2)|0)!=0){D=1;i=a;return D|0}if((R6(c[3530472]|0,16,2)|0)!=0){D=1;i=a;return D|0}if((R6((c[3530472]|0)+131073|0,17,2)|0)!=0){D=1;i=a;return D|0}if((R6((c[3530472]|0)+131072|0,18,2)|0)!=0){D=1;i=a;return D|0}if((R6((c[3530472]|0)+196609|0,19,2)|0)!=0){D=1;i=a;return D|0}if((R6((c[3530472]|0)+196608|0,20,2)|0)!=0){D=1;i=a;return D|0}E=(c[2386670]|0)+131072|0;if((c[3542200]|0)==0){D=1;i=a;return D|0}h=e+108|0;c[h>>2]=0;G=e+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,21)|0;do{if((c[h>>2]|0)!=0){e=c[G>>2]|0;c[f>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](f,21,0)|0;if((e|0)<1){D=1;i=a;return D|0}if((gzL(E,0,21)|0)==0){break}else{D=1}i=a;return D|0}}while(0);E=(c[2386670]|0)+262144|0;if((c[3542200]|0)==0){D=1;i=a;return D|0}f=b+108|0;c[f>>2]=0;G=b+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](b,22)|0;if((c[f>>2]|0)==0){D=0;i=a;return D|0}f=c[G>>2]|0;c[d>>2]=9534384;gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](d,22,0)|0;if((f|0)<1){D=1;i=a;return D|0}D=(gzL(E,0,22)|0)!=0|0;i=a;return D|0}function djq(a,d){a=a|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=(c[2386260]|0)+(a<<13)|0;g=c[3529820]|0;h=a<<1;i=(e[c[3529400]>>1]|0)>>>(a>>>0);j=b[g+(h<<1)>>1]&511;k=(e[g+((h|1)<<1)>>1]|0)+8&511;h=i<<3&8192;g=i>>>1&8|a<<4;i=c[2112926]|0;l=c[2113068]|0;m=c[2113070]|0;if((a|0)==0){a=0;do{n=(a<<3&504)-j|0;o=(n|0)<-7?n+512|0:n;n=(((a|0)/64|0)<<3)-k|0;p=(n|0)<-7?n+512|0:n;if((p|0)<(l|0)&(o|0)<(m|0)){n=e[f+(a<<1)>>1]|0;Sj(i,n&8191|h,p,o,n>>>13|g,4,0,d)}a=a+1|0;}while((a|0)<4096);return}else{a=0;do{n=(a<<3&504)-j|0;o=(n|0)<-7?n+512|0:n;n=(((a|0)/64|0)<<3)-k|0;p=(n|0)<-7?n+512|0:n;if((p|0)<(l|0)&(o|0)<(m|0)){n=e[f+(a<<1)>>1]|0;Sr(i,n&8191|h,p,o,n>>>13|g,4,15,0,d)}a=a+1|0;}while((a|0)<4096);return}}function djr(d,f){d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=((c[2444214]|0)!=0?8:48)+((e[c[3529400]>>1]|0)>>>3&8)&65535;h=c[2386516]|0;if((d|0)>=(f|0)){return}i=c[3530472]|0;j=c[2113070]|0;k=c[2113068]|0;l=c[2112926]|0;m=d;do{d=512-(b[h+(m<<1)>>1]&511)|0;n=b[h+(m+1<<1)>>1]|0;o=n&65535;p=e[h+(m+2<<1)>>1]|0;q=p&511;r=q>>>0>303?p|-512:q;q=((n&65535)>>>13|g)<<4;n=(o&4096|0)==0?0:15;p=(o&2048|0)==0?n:n|496;n=o<<9&1048064;o=d>>>0>223?d-512|0:d;d=0;while(1){if((o|0)>-1&(o|0)<(j|0)){s=ag(k,o)|0;t=r;u=0;while(1){do{if((t|0)>=0&(t|0)<(k|0)){v=a[i+((u+d^p)+n)|0]|0;if(v<<24>>24==15){break}b[l+(s+t<<1)>>1]=(v&255)+q&65535}}while(0);v=u+1|0;if((v|0)<16){t=t+1|0;u=v}else{break}}}u=d+16|0;if((u|0)>=512){break}o=o+1|0;d=u}m=m+4|0;}while((m|0)<(f|0));return}function djs(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;a=i;i=i+960|0;b=a|0;d=a+112|0;e=a+120|0;f=a+232|0;g=a+240|0;h=a+352|0;j=a+360|0;k=a+472|0;l=a+480|0;m=a+592|0;n=a+600|0;o=a+712|0;p=a+720|0;q=a+832|0;r=a+840|0;s=a+952|0;if((R6((c[2388184]|0)+1|0,0,2)|0)!=0){t=1;i=a;return t|0}if((R6(c[2388184]|0,1,2)|0)!=0){t=1;i=a;return t|0}if((R6((c[2388184]|0)+65537|0,2,2)|0)!=0){t=1;i=a;return t|0}if((R6((c[2388184]|0)+65536|0,3,2)|0)!=0){t=1;i=a;return t|0}u=c[2385968]|0;if((c[3542200]|0)==0){t=1;i=a;return t|0}v=r+108|0;c[v>>2]=0;w=r+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,4)|0;do{if((c[v>>2]|0)!=0){r=c[w>>2]|0;c[s>>2]=9534384;x=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[x&16383](s,4,0)|0;if((r|0)<1){t=1;i=a;return t|0}if((gzL(u,0,4)|0)==0){break}else{t=1}i=a;return t|0}}while(0);u=c[3530904]|0;if((c[3542200]|0)==0){t=1;i=a;return t|0}s=p+108|0;c[s>>2]=0;w=p+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,5)|0;do{if((c[s>>2]|0)!=0){p=c[w>>2]|0;c[q>>2]=9534384;v=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[v&16383](q,5,0)|0;if((p|0)<1){t=1;i=a;return t|0}if((gzL(u,0,5)|0)==0){break}else{t=1}i=a;return t|0}}while(0);u=(c[3530904]|0)+262144|0;if((c[3542200]|0)==0){t=1;i=a;return t|0}q=n+108|0;c[q>>2]=0;w=n+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,6)|0;do{if((c[q>>2]|0)!=0){n=c[w>>2]|0;c[o>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](o,6,0)|0;if((n|0)<1){t=1;i=a;return t|0}if((gzL(u,0,6)|0)==0){break}else{t=1}i=a;return t|0}}while(0);u=(c[3530904]|0)+294912|0;if((c[3542200]|0)==0){t=1;i=a;return t|0}o=l+108|0;c[o>>2]=0;w=l+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,7)|0;do{if((c[o>>2]|0)!=0){l=c[w>>2]|0;c[m>>2]=9534384;q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[q&16383](m,7,0)|0;if((l|0)<1){t=1;i=a;return t|0}if((gzL(u,0,7)|0)==0){break}else{t=1}i=a;return t|0}}while(0);u=c[3530668]|0;if((c[3542200]|0)==0){t=1;i=a;return t|0}m=j+108|0;c[m>>2]=0;w=j+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,8)|0;do{if((c[m>>2]|0)!=0){j=c[w>>2]|0;c[k>>2]=9534384;o=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[o&16383](k,8,0)|0;if((j|0)<1){t=1;i=a;return t|0}if((gzL(u,0,8)|0)==0){break}else{t=1}i=a;return t|0}}while(0);u=(c[3530668]|0)+262144|0;if((c[3542200]|0)==0){t=1;i=a;return t|0}k=g+108|0;c[k>>2]=0;w=g+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,9)|0;do{if((c[k>>2]|0)!=0){g=c[w>>2]|0;c[h>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](h,9,0)|0;if((g|0)<1){t=1;i=a;return t|0}if((gzL(u,0,9)|0)==0){break}else{t=1}i=a;return t|0}}while(0);u=(c[3530668]|0)+294912|0;if((c[3542200]|0)==0){t=1;i=a;return t|0}h=e+108|0;c[h>>2]=0;w=e+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,10)|0;do{if((c[h>>2]|0)!=0){e=c[w>>2]|0;c[f>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](f,10,0)|0;if((e|0)<1){t=1;i=a;return t|0}if((gzL(u,0,10)|0)==0){break}else{t=1}i=a;return t|0}}while(0);if((R6((c[3530472]|0)+1|0,11,2)|0)!=0){t=1;i=a;return t|0}if((R6(c[3530472]|0,12,2)|0)!=0){t=1;i=a;return t|0}if((R6((c[3530472]|0)+262145|0,13,2)|0)!=0){t=1;i=a;return t|0}if((R6((c[3530472]|0)+262144|0,14,2)|0)!=0){t=1;i=a;return t|0}if((R6((c[3530472]|0)+327681|0,15,2)|0)!=0){t=1;i=a;return t|0}if((R6((c[3530472]|0)+327680|0,16,2)|0)!=0){t=1;i=a;return t|0}u=(c[2386670]|0)+131072|0;if((c[3542200]|0)==0){t=1;i=a;return t|0}f=b+108|0;c[f>>2]=0;w=b+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](b,17)|0;if((c[f>>2]|0)==0){t=0;i=a;return t|0}f=c[w>>2]|0;c[d>>2]=9534384;gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](d,17,0)|0;if((f|0)<1){t=1;i=a;return t|0}t=(gzL(u,0,17)|0)!=0|0;i=a;return t|0}function djt(b){b=b|0;var c=0,d=0;c=b&65535;if((c|0)==41088){d=a[9658072]|a[9625312]}else if((c|0)==41216){d=a[9658073]|0}else if((c|0)==40960){d=a[9625360]|0}else{d=0}return d|0}function dju(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((b+24320&65535)<32){UY(e-41216|0,d);return}if((e|0)==41345){b=d&1;a[9759816]=b;if(b<<24>>24!=0){return}a[9706117]=0;return}else if((e|0)==41264){a[9626464]=d;return}else if((e|0)==41280){a[9626448]=d;return}else if((e|0)==41344){e=d&1;do{if((a[14109776]|0)!=0&e<<24>>24==0&(c[2439194]|0)>0){d=c[2406652]|0;c[3528400]=d;if((a[d+14|0]&1)!=0){break}a[d+12|0]=1;c[d+8>>2]=0}}while(0);a[14109776]=e;return}else{return}}function djv(a){a=a|0;return 0}function djw(b,c){b=b|0;c=c|0;if((b&255)!=0){return}a[9751112]=c;a[9706117]=0;return}function djx(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6158108+(b*112|0)>>2];c[a+104>>2]=c[6158112+(b*112|0)>>2];c[a+108>>2]=c[6158116+(b*112|0)>>2];d=0;return d|0}function djy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=6158008+(b*112|0);e=0;return e|0}function djz(a,b){a=a|0;b=b|0;var d=0;do{if(b>>>0>1){d=1}else{if((a|0)==0){d=0;break}c[a+100>>2]=c[1760628+(b*104|0)>>2];d=0}}while(0);return d|0}function djA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<2&(d|0)==0)){e=1;return e|0}c[a>>2]=1760528+(b*104|0);e=0;return e|0}function djB(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6936832+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function djC(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>26){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7448056+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function djD(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;b=i;i=i+1320|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;l=b+360|0;m=b+472|0;n=b+480|0;o=b+592|0;p=b+600|0;q=b+712|0;r=b+720|0;s=b+832|0;t=b+840|0;u=b+952|0;v=b+960|0;w=b+1072|0;x=b+1080|0;y=b+1192|0;z=b+1200|0;A=b+1312|0;c[2426806]=0;c[3529132]=0;c[2438762]=16384;c[2439588]=16416;c[2433454]=16672;c[2433452]=16704;c[3541148]=16736;c[2405712]=16992;c[3529158]=16992;c[3527226]=19040;c[2437756]=23136;c[2411810]=23152;c[2406544]=23152;c[3529596]=39536;c[2408650]=55920;c[3530130]=56048;B=0;while(1){if((B|0)>=1024){break}C=9638528+(B<<2)|0;if((c[C>>2]|0)==0){D=65425;break}else{B=B+1|0}}do{if((D|0)==65425){B=gGq(57088)|0;c[C>>2]=B;if((B|0)==0){break}c[2426806]=B;gGz(B|0,0,57088);c[3529132]=B;c[2438762]=B+16384;c[2439588]=B+16416;c[2433454]=B+16672;c[2433452]=B+16704;c[3541148]=B+16736;E=B+16992|0;c[2405712]=E;c[3529158]=E;c[3527226]=B+19040;c[2437756]=B+23136;E=B+23152|0;c[2411810]=E;c[2406544]=E;c[3529596]=B+39536;c[2408650]=B+55920;c[3530130]=B+56048;c[2414358]=B+57088;B=0;while(1){if((B|0)>=1024){F=0;break}G=9638528+(B<<2)|0;if((c[G>>2]|0)==0){D=65430;break}else{B=B+1|0}}do{if((D|0)==65430){B=gGq(4096)|0;c[G>>2]=B;if((B|0)==0){F=0;break}gGz(B|0,0,4096);F=B}}while(0);c[3529546]=F;B=c[3529132]|0;if((c[3542200]|0)==0){H=1;i=b;return H|0}E=z+108|0;c[E>>2]=0;I=z+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,0)|0;do{if((c[E>>2]|0)!=0){J=c[I>>2]|0;c[A>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](A,0,0)|0;if((J|0)<1){H=1;i=b;return H|0}if((gzL(B,0,0)|0)==0){break}else{H=1}i=b;return H|0}}while(0);B=(c[3529132]|0)+4096|0;if((c[3542200]|0)==0){H=1;i=b;return H|0}I=x+108|0;c[I>>2]=0;E=x+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,1)|0;do{if((c[I>>2]|0)!=0){J=c[E>>2]|0;c[y>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](y,1,0)|0;if((J|0)<1){H=1;i=b;return H|0}if((gzL(B,0,1)|0)==0){break}else{H=1}i=b;return H|0}}while(0);B=(c[3529132]|0)+8192|0;if((c[3542200]|0)==0){H=1;i=b;return H|0}E=v+108|0;c[E>>2]=0;I=v+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,2)|0;do{if((c[E>>2]|0)!=0){J=c[I>>2]|0;c[w>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](w,2,0)|0;if((J|0)<1){H=1;i=b;return H|0}if((gzL(B,0,2)|0)==0){break}else{H=1}i=b;return H|0}}while(0);B=(c[3529132]|0)+12288|0;if((c[3542200]|0)==0){H=1;i=b;return H|0}I=t+108|0;c[I>>2]=0;E=t+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,3)|0;do{if((c[I>>2]|0)!=0){J=c[E>>2]|0;c[u>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](u,3,0)|0;if((J|0)<1){H=1;i=b;return H|0}if((gzL(B,0,3)|0)==0){break}else{H=1}i=b;return H|0}}while(0);B=c[3529546]|0;if((c[3542200]|0)==0){H=1;i=b;return H|0}E=r+108|0;c[E>>2]=0;I=r+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,4)|0;do{if((c[E>>2]|0)!=0){J=c[I>>2]|0;c[s>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](s,4,0)|0;if((J|0)<1){H=1;i=b;return H|0}if((gzL(B,0,4)|0)==0){break}else{H=1}i=b;return H|0}}while(0);B=c[3529546]|0;I=c[2406544]|0;E=0;do{J=E<<6;gGz(I+J|0,0,64);K=E<<7;L=0;do{M=K+(c[1238464+(L<<2)>>2]|0)|0;N=(L<<3)+J|0;O=0;do{P=M+(c[610928+(O<<2)>>2]|0)|0;if(((d[B+((P|0)/8|0)|0]|0)&128>>>((P&7)>>>0)|0)!=0){P=I+(N+O)|0;a[P]=a[P]|2}O=O+1|0;}while((O|0)<8);L=L+1|0;}while((L|0)<8);L=K|4;O=0;do{N=L+(c[1238464+(O<<2)>>2]|0)|0;M=(O<<3)+J|0;P=0;do{Q=N+(c[610928+(P<<2)>>2]|0)|0;if(((d[B+((Q|0)/8|0)|0]|0)&128>>>((Q&7)>>>0)|0)!=0){Q=I+(M+P)|0;a[Q]=a[Q]|1}P=P+1|0;}while((P|0)<8);O=O+1|0;}while((O|0)<8);E=E+1|0;}while((E|0)<256);E=c[3529596]|0;I=0;do{O=I<<8;gGz(E+O|0,0,256);J=I<<9;L=0;do{K=J+(c[611712+(L<<2)>>2]|0)|0;P=(L<<4)+O|0;M=0;do{N=K+(c[61e4+(M<<2)>>2]|0)|0;if(((d[B+((N|0)/8|0)|0]|0)&128>>>((N&7)>>>0)|0)!=0){N=E+(P+M)|0;a[N]=a[N]|2}M=M+1|0;}while((M|0)<16);L=L+1|0;}while((L|0)<16);L=J|4;M=0;do{P=L+(c[611712+(M<<2)>>2]|0)|0;K=(M<<4)+O|0;N=0;do{Q=P+(c[61e4+(N<<2)>>2]|0)|0;if(((d[B+((Q|0)/8|0)|0]|0)&128>>>((Q&7)>>>0)|0)!=0){Q=E+(K+N)|0;a[Q]=a[Q]|1}N=N+1|0;}while((N|0)<16);M=M+1|0;}while((M|0)<16);I=I+1|0;}while((I|0)<64);gGz(B|0,0,4096);if((c[3542200]|0)==0){H=1;i=b;return H|0}I=p+108|0;c[I>>2]=0;E=p+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,5)|0;do{if((c[I>>2]|0)!=0){M=c[E>>2]|0;c[q>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](q,5,0)|0;if((M|0)<1){H=1;i=b;return H|0}if((gzL(B,0,5)|0)==0){break}else{H=1}i=b;return H|0}}while(0);B=c[3529546]|0;E=c[2408650]|0;I=0;do{M=I<<4;gGz(E+M|0,0,16);O=I<<7;L=0;do{J=1<<1-L;N=(c[4049784+(L<<2)>>2]|0)+O|0;K=0;do{P=N+(c[7308504+(K<<2)>>2]|0)|0;Q=(K<<2)+M|0;if(((d[B+((P|0)/8|0)|0]|0)&128>>>((P&7)>>>0)|0)!=0){R=E+Q|0;a[R]=(d[R]|0|J)&255}R=P+8|0;if(((d[B+((R|0)/8|0)|0]|0)&128>>>((R&7)>>>0)|0)!=0){R=E+(Q|1)|0;a[R]=(d[R]|0|J)&255}R=P+16|0;if(((d[B+((R|0)/8|0)|0]|0)&128>>>((R&7)>>>0)|0)!=0){R=E+(Q|2)|0;a[R]=(d[R]|0|J)&255}R=P+24|0;if(((d[B+((R|0)/8|0)|0]|0)&128>>>((R&7)>>>0)|0)!=0){R=E+(Q|3)|0;a[R]=(d[R]|0|J)&255}K=K+1|0;}while((K|0)<4);L=L+1|0;}while((L|0)<2);I=I+1|0;}while((I|0)<8);I=c[2438762]|0;if((c[3542200]|0)==0){H=1;i=b;return H|0}E=n+108|0;c[E>>2]=0;B=n+100|0;c[B>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,6)|0;do{if((c[E>>2]|0)!=0){L=c[B>>2]|0;c[o>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](o,6,0)|0;if((L|0)<1){H=1;i=b;return H|0}if((gzL(I,0,6)|0)==0){break}else{H=1}i=b;return H|0}}while(0);I=c[2439588]|0;if((c[3542200]|0)==0){H=1;i=b;return H|0}B=l+108|0;c[B>>2]=0;E=l+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,7)|0;do{if((c[B>>2]|0)!=0){L=c[E>>2]|0;c[m>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](m,7,0)|0;if((L|0)<1){H=1;i=b;return H|0}if((gzL(I,0,7)|0)==0){break}else{H=1}i=b;return H|0}}while(0);I=c[2433454]|0;if((c[3542200]|0)==0){H=1;i=b;return H|0}E=j+108|0;c[E>>2]=0;B=j+100|0;c[B>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,8)|0;do{if((c[E>>2]|0)!=0){L=c[B>>2]|0;c[k>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](k,8,0)|0;if((L|0)<1){H=1;i=b;return H|0}if((gzL(I,0,8)|0)==0){break}else{H=1}i=b;return H|0}}while(0);I=c[2433452]|0;if((c[3542200]|0)==0){H=1;i=b;return H|0}B=g+108|0;c[B>>2]=0;E=g+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,9)|0;do{if((c[B>>2]|0)!=0){L=c[E>>2]|0;c[h>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](h,9,0)|0;if((L|0)<1){H=1;i=b;return H|0}if((gzL(I,0,9)|0)==0){break}else{H=1}i=b;return H|0}}while(0);I=c[3541148]|0;if((c[3542200]|0)==0){H=1;i=b;return H|0}E=e+108|0;c[E>>2]=0;B=e+100|0;c[B>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,10)|0;do{if((c[E>>2]|0)!=0){L=c[B>>2]|0;c[f>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](f,10,0)|0;if((L|0)<1){H=1;i=b;return H|0}if((gzL(I,0,10)|0)==0){break}else{H=1}i=b;return H|0}}while(0);I=c[3529546]|0;B=0;while(1){if((B|0)>=1024){break}S=9638528+(B<<2)|0;if((c[S>>2]|0)==(I|0)){D=65503;break}else{B=B+1|0}}if((D|0)==65503){gGr(I);c[S>>2]=0}c[3529546]=0;djR();H=0;i=b;return H|0}}while(0);c[2426806]=0;H=1;i=b;return H|0}function djE(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}b=c[2420424]|0;if((b|0)!=0){gGr(b);c[2420424]=0}b=c[2433528]|0;if((b|0)!=0){gGr(b);c[2433528]=0}b=c[2439194]|0;d=c[2406652]|0;if((b|0)>0){e=0;f=d;g=b;while(1){b=f+(e*40|0)|0;c[3528400]=b;h=c[b>>2]|0;if((h|0)==0){i=g;j=f}else{gGr(h);c[c[3528400]>>2]=0;i=c[2439194]|0;j=c[2406652]|0}h=e+1|0;if((h|0)<(i|0)){e=h;f=j;g=i}else{k=j;break}}}else{k=d}if((k|0)!=0){gGr(k);c[2406652]=0}c[3528400]=0;c[2439194]=0;c[2442914]=0;fwZ();k=c[2426806]|0;d=0;while(1){if((d|0)>=1024){l=65577;break}m=9638528+(d<<2)|0;if((c[m>>2]|0)==(k|0)){break}else{d=d+1|0}}if((l|0)==65577){c[2426806]=0;a[9759816]=0;a[9751112]=0;a[9626464]=0;a[9626448]=0;a[14109776]=0;return 0}gGr(k);c[m>>2]=0;c[2426806]=0;a[9759816]=0;a[9751112]=0;a[9626464]=0;a[9626448]=0;a[14109776]=0;return 0}function djF(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0.0,H=0.0,I=0.0,J=0.0,K=0.0,L=0.0,M=0.0,N=0.0,O=0.0,P=0.0,Q=0.0,R=0.0,S=0.0,T=0.0,U=0.0,V=0,W=0,X=0,Y=0;e=i;i=i+1064|0;f=e|0;g=e+16|0;j=e+448|0;k=e+880|0;l=e+896|0;m=e+912|0;n=e+936|0;o=a[9688]|0?534:0;if((a[9624800]|0)!=0){p=c[2439330]|0;q=(p|0)==0;if(!q){r=p;gGC(9706056,r|0,76)|0}r=c[2438118]|0;c[2433530]=r;s=c[3528484]|0;c[2076596]=s;t=c[2417276]|0;c[3541536]=t;c[1836236]=0;gGz(9706056,0,76);if(!q){q=p;gGC(q|0,9706056,76)|0}c[2438118]=r;c[3528484]=s;c[2417276]=t;c[1836236]=-1;t=c[2439194]|0;if((t|0)>0){s=c[2406652]|0;r=0;do{u=s+(r*40|0)|0;q=s+(r*40|0)+12|0;a[q]=0;p=s+(r*40|0)+8|0;c[p>>2]=0;v=a[s+(r*40|0)+14|0]|0;do{if((v&2)!=0&(t|0)>(r|0)){if((v&4)==0){a[s+(r*40|0)+13|0]=1}if((v&1)!=0){break}a[q]=1;c[p>>2]=0}}while(0);r=r+1|0;}while((r|0)<(t|0));c[3528400]=u}a[9759816]=0;a[9751112]=0;a[9626464]=0;a[9626448]=0;a[14109776]=0}a[9625360]=-1;a[9625312]=-2;u=0;t=-1;r=-2;do{t=(t&255)-((a[9759288+u|0]&1)<<u)&255;r=(r&255)-((a[9759096+u|0]&1)<<u)&255;u=u+1|0;}while((u|0)<8);a[9625360]=t;a[9625312]=r;a[6518352]=1;c[2444044]=0;r=c[2385548]|0;if((r|0)>0){gGz(9752472,0,((r|0)>1?r<<2:4)|0)}c[2433530]=0;r=o-1|0;t=0;u=0;s=0;L78200:while(1){p=u;q=s;while(1){if((p|0)>=(o|0)){break L78200}v=c[2439330]|0;if((v|0)!=0){w=v;gGC(9706056,w|0,76)|0}b[4853030]=c[2426515]&65535;w=c[2438118]|0;c[2433530]=w;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;x=p+1|0;y=((ag(a[6518352]|0?51200:0,x)|0)/534|0)-q|0;do{if((y|0)<1){z=0;A=q;B=w}else{if((a[v+4188|0]|0)==0){C=gfc(y)|0;D=(c[2433530]|0)+C|0;c[2433530]=D;z=C;A=c[2444044]|0;B=D;break}else{D=w+y|0;c[2433530]=D;z=y;A=q;B=D;break}}}while(0);E=A+z|0;c[2444044]=E;if((p|0)==(r|0)&(a[9759816]|0)!=0){a[14125144]=a[9751112]|0;a[9706117]=1}y=c[1836236]|0;w=c[9757320+(y<<2)>>2]|0;if((w|0)!=0){v=w;gGC(v|0,9706056,76)|0}c[9752472+(y<<2)>>2]=B;c[14113936+(y<<2)>>2]=c[2076596];c[9669104+(y<<2)>>2]=c[3541536];c[1836236]=-1;F=c[2112964]|0;if((F|0)==0){p=x;q=E}else{break}}q=a[9688]|0;p=q&1;y=F+(t<<1<<1)|0;if(q){UX(y,p);Vg(y,p)}t=p+t|0;u=x;s=E}E=c[2112964]|0;do{if((E|0)!=0){s=a[9688]|0?534:0;x=s-t|0;u=E+(t<<1<<1)|0;if((s|0)==(t|0)){break}UX(u,x);Vg(u,x)}}while(0);if((c[2112968]|0)==0){i=e;return 0}t=c[2112926]|0;gGz(t|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);gGz(l|0,0,12);c[f>>2]=3;h[g>>3]=1.0e3;h[g+8>>3]=470.0;h[g+16>>3]=220.0;c[k>>2]=0;c[f+4>>2]=3;h[g+144>>3]=1.0e3;h[g+152>>3]=470.0;h[g+160>>3]=220.0;c[k+4>>2]=0;c[f+8>>2]=2;h[g+288>>3]=470.0;h[g+296>>3]=220.0;c[k+8>>2]=1e3;E=0;x=3;while(1){L78234:do{if((x|0)>0){u=c[k+(E<<2)>>2]|0;s=c[l+(E<<2)>>2]|0;F=(s|0)==0;G=1.0/+(s|0);H=1.0/+(u|0);if((u|0)==0){I=F?1.0e-12:G;u=0;while(1){s=0;J=1.0e-12;K=I;while(1){L=+h[g+(E*144|0)+(s<<3)>>3];B=L!=0.0;do{if((s|0)==(u|0)){if(!B){M=K;N=J;break}M=K+1.0/L;N=J}else{if(!B){M=K;N=J;break}M=K;N=J+1.0/L}}while(0);B=s+1|0;if((B|0)<(x|0)){s=B;J=N;K=M}else{break}}K=1.0/N;J=K*255.0/(K+1.0/M)+0.0;if(J<0.0){O=0.0}else{O=J>255.0?255.0:J}h[j+(E*144|0)+(u<<3)>>3]=O;u=u+1|0;if((u|0)>=(x|0)){break L78234}}}if(F){u=0;do{s=0;I=H;J=1.0e-12;while(1){K=+h[g+(E*144|0)+(s<<3)>>3];B=K!=0.0;do{if((s|0)==(u|0)){if(!B){P=J;Q=I;break}P=J+1.0/K;Q=I}else{if(!B){P=J;Q=I;break}P=J;Q=I+1.0/K}}while(0);B=s+1|0;if((B|0)<(x|0)){s=B;I=Q;J=P}else{break}}J=1.0/Q;I=J*255.0/(J+1.0/P)+0.0;if(I<0.0){R=0.0}else{R=I>255.0?255.0:I}h[j+(E*144|0)+(u<<3)>>3]=R;u=u+1|0;}while((u|0)<(x|0))}else{u=0;do{F=0;I=H;J=G;while(1){K=+h[g+(E*144|0)+(F<<3)>>3];s=K!=0.0;do{if((F|0)==(u|0)){if(!s){S=J;T=I;break}S=J+1.0/K;T=I}else{if(!s){S=J;T=I;break}S=J;T=I+1.0/K}}while(0);s=F+1|0;if((s|0)<(x|0)){F=s;I=T;J=S}else{break}}J=1.0/T;I=J*255.0/(J+1.0/S)+0.0;if(I<0.0){U=0.0}else{U=I>255.0?255.0:I}h[j+(E*144|0)+(u<<3)>>3]=U;u=u+1|0;}while((u|0)<(x|0))}}}while(0);u=E+1|0;if((u|0)>=3){break}E=u;x=c[f+(u<<2)>>2]|0}U=+h[j>>3];S=+h[j+8>>3];T=+h[j+16>>3];R=U+0.0+S+T;h[m>>3]=R;P=+h[j+144>>3];Q=+h[j+152>>3];O=+h[j+160>>3];M=P+0.0+Q+O;N=R>0.0?R:0.0;h[m+8>>3]=M;f=N<M;R=+h[j+288>>3];G=+h[j+296>>3];H=R+0.0+G;h[m+16>>3]=H;I=255.0/+h[m+(((f?M:N)<H?2:f&1)<<3)>>3];H=U*I;U=S*I;S=T*I;T=P*I;P=Q*I;Q=O*I;O=R*I;R=G*I;f=c[2438762]|0;m=0;do{j=d[f+m|0]|0;c[n+(m<<2)>>2]=~~(S*+(j>>>2&1|0)+(H*+(j&1|0)+U*+(j>>>1&1|0))+.5)<<8&63488|~~(R*+(j>>>7|0)+O*+(j>>>6&1|0)+.5)>>>3&31|~~(Q*+(j>>>5&1|0)+(T*+(j>>>3&1|0)+P*+(j>>>4&1|0))+.5)<<3&2016;m=m+1|0;}while(m>>>0<32);m=c[2439588]|0;f=c[3530130]|0;j=0;do{c[f+(j<<2)>>2]=c[n+((a[m+j|0]&15)<<2)>>2];j=j+1|0;}while(j>>>0<256);c[f+1024>>2]=c[n+64>>2];c[f+1028>>2]=c[n+68>>2];c[f+1032>>2]=c[n+72>>2];c[f+1036>>2]=c[n+76>>2];n=c[3527226]|0;j=d[9626464]|0;m=d[9626448]|0;x=c[2406544]|0;E=0;g=0;while(1){l=(g<<3)-m|0;k=l-16|0;u=(k|0)<-8?l+240|0:k;k=(u-9|0)>>>0<207;l=E;F=0;while(1){s=d[n+(l+1024)|0]|0;B=d[n+(l+3072)|0]|0;r=B>>>6^1;z=B&63;B=(F<<3)-j|0;A=B+3|0;o=(A|0)<-8?B+259|0:A;A=(o|0)>247?o-256|0:o;do{if((A|0)<224){o=(r&1|0)==0;B=(r&2|0)!=0;if((A-9|0)>>>0<271^1|k^1){if(o){if(B){Sn(t,s,A,u,z,2,0,x);break}else{Sj(t,s,A,u,z,2,0,x);break}}else{if(B){Sp(t,s,A,u,z,2,0,x);break}else{Sl(t,s,A,u,z,2,0,x);break}}}else{if(o){if(B){Sm(t,s,A,u,z,2,0,x);break}else{Si(t,s,A,u,z,2,0,x);break}}else{if(B){So(t,s,A,u,z,2,0,x);break}else{Sk(t,s,A,u,z,2,0,x);break}}}}}while(0);z=F+1|0;if((z|0)>=32){break}l=l+1|0;F=z}F=g+1|0;if((F|0)<32){E=E+32|0;g=F}else{break}}g=c[3529596]|0;E=30;while(1){j=E|1;m=d[n+(j+2048)|0]|0;F=m<<1&256|d[n+j|0];j=F-1|0;l=241-(d[n+(E+2048)|0]|0)|0;u=m&63;m=d[n+E|0]|0;k=m&1;z=m&2;A=m>>>2;m=l-17|0;do{if((F-18|0)>>>0<255){if((l-34|0)>>>0>=191){V=65690;break}s=(z|0)!=0;if((k|0)==0){if(s){SK(t,A,j,m,u,2,0,0,g);break}else{SG(t,A,j,m,u,2,0,0,g);break}}else{if(s){SM(t,A,j,m,u,2,0,0,g);break}else{SI(t,A,j,m,u,2,0,0,g);break}}}else{V=65690}}while(0);do{if((V|0)==65690){V=0;l=(z|0)!=0;if((k|0)==0){if(l){SL(t,A,j,m,u,2,0,0,g);break}else{SH(t,A,j,m,u,2,0,0,g);break}}else{if(l){SN(t,A,j,m,u,2,0,0,g);break}else{SJ(t,A,j,m,u,2,0,0,g);break}}}}while(0);u=E-2|0;if(u>>>0>19){E=u}else{W=0;break}}do{E=W<<5;g=W<<3;V=g-16|0;u=(g-25|0)>>>0>206;g=0;do{m=g+E|0;j=d[n+m|0]|0;A=d[n+(m+2048)|0]|0;m=A>>>6^1;k=A&63;A=g<<3;z=A-32|0;l=(z|0)<0?A+32|0:z;z=l+224|0;A=(m&1|0)==0;F=(m&2|0)!=0;do{if((l+215|0)>>>0>270|u){if(A){if(F){Sn(t,j,z,V,k,2,0,x);break}else{Sj(t,j,z,V,k,2,0,x);break}}else{if(F){Sp(t,j,z,V,k,2,0,x);break}else{Sl(t,j,z,V,k,2,0,x);break}}}else{if(A){if(F){Sm(t,j,z,V,k,2,0,x);break}else{Si(t,j,z,V,k,2,0,x);break}}else{if(F){So(t,j,z,V,k,2,0,x);break}else{Sk(t,j,z,V,k,2,0,x);break}}}}while(0);g=g+1|0;}while((g|0)<8);W=W+1|0;}while((W|0)<32);W=c[2113068]|0;x=c[2437756]|0;g=c[2408650]|0;V=c[2113070]|0;u=20;do{E=d[x+(u&15)|0]|0;k=(E<<8&256|d[n+(u+32)|0])^256;z=237-(d[n+(u+2080)|0]|0)|0;j=k+1|0;F=k+2|0;A=k+3|0;l=t+((ag(W,z)|0)+k<<1)|0;m=0;s=g+(E>>>1<<4&112^112)|0;while(1){E=m+z|0;do{if((E|0)>=(V|0)|(E|0)<0){X=s}else{do{if((k|0)<(W|0)){r=a[s]|0;if(r<<24>>24==3){break}b[l>>1]=r&255|256}}while(0);do{if((j|0)<(W|0)){r=a[s+1|0]|0;if(r<<24>>24==3){break}b[l+2>>1]=r&255|256}}while(0);do{if((F|0)<(W|0)){r=a[s+2|0]|0;if(r<<24>>24==3){break}b[l+4>>1]=r&255|256}}while(0);if((A|0)>=(W|0)){X=s;break}r=a[s+3|0]|0;if(r<<24>>24==3){X=s;break}b[l+6>>1]=r&255|256;X=s}}while(0);E=m+1|0;Y=X+4|0;if((E|0)>=4){break}l=l+(W<<1)|0;m=E;s=Y}u=u+1|0;}while(u>>>0<32);c[2112928]=Y;R8(f);i=e;return 0}function djG(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=i;i=i+48|0;e=d|0;f=d+32|0;g=(b|0)==0;if(!g){c[b>>2]=169736}if((a&32|0)!=0){gGz(f|0,0,12);h=c[2405712]|0;c[f>>2]=h;c[f+4>>2]=(c[2411810]|0)-h;c[f+12>>2]=162152;h=c[2076592]|0;gj[h&4095](f)|0}if((a&64|0)==0){i=d;return 0}fw$(a);a=d+16|0;if(!g){c[b>>2]=169735}gGC(a|0,117464,15)|0;c[e>>2]=c[2433528];c[e+4>>2]=64;c[e+8>>2]=0;c[e+12>>2]=a;gj[c[2076592]&4095](e)|0;i=d;return 0}function djH(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5116124+(b*112|0)>>2];c[a+104>>2]=c[5116128+(b*112|0)>>2];c[a+108>>2]=c[5116132+(b*112|0)>>2];d=0;return d|0}function djI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=5116024+(b*112|0);e=0;return e|0}function djJ(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0;b=i;i=i+1920|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;l=b+360|0;m=b+472|0;n=b+480|0;o=b+592|0;p=b+600|0;q=b+712|0;r=b+720|0;s=b+832|0;t=b+840|0;u=b+952|0;v=b+960|0;w=b+1072|0;x=b+1080|0;y=b+1192|0;z=b+1200|0;A=b+1312|0;B=b+1320|0;C=b+1432|0;D=b+1440|0;E=b+1552|0;F=b+1560|0;G=b+1672|0;H=b+1680|0;I=b+1792|0;J=b+1800|0;K=b+1912|0;c[2426806]=0;c[3529132]=0;c[2438762]=16384;c[2439588]=16416;c[2433454]=16672;c[2433452]=16704;c[3541148]=16736;c[2405712]=16992;c[3529158]=16992;c[3527226]=19040;c[2437756]=23136;c[2411810]=23152;c[2406544]=23152;c[3529596]=39536;c[2408650]=55920;c[3530130]=56048;L=0;while(1){if((L|0)>=1024){break}M=9638528+(L<<2)|0;if((c[M>>2]|0)==0){N=65764;break}else{L=L+1|0}}do{if((N|0)==65764){L=gGq(57088)|0;c[M>>2]=L;if((L|0)==0){break}c[2426806]=L;gGz(L|0,0,57088);c[3529132]=L;c[2438762]=L+16384;c[2439588]=L+16416;c[2433454]=L+16672;c[2433452]=L+16704;c[3541148]=L+16736;O=L+16992|0;c[2405712]=O;c[3529158]=O;c[3527226]=L+19040;c[2437756]=L+23136;O=L+23152|0;c[2411810]=O;c[2406544]=O;c[3529596]=L+39536;c[2408650]=L+55920;c[3530130]=L+56048;c[2414358]=L+57088;L=0;while(1){if((L|0)>=1024){P=0;break}Q=9638528+(L<<2)|0;if((c[Q>>2]|0)==0){N=65769;break}else{L=L+1|0}}do{if((N|0)==65769){L=gGq(4096)|0;c[Q>>2]=L;if((L|0)==0){P=0;break}gGz(L|0,0,4096);P=L}}while(0);c[3529546]=P;L=c[3529132]|0;if((c[3542200]|0)==0){R=1;i=b;return R|0}O=J+108|0;c[O>>2]=0;S=J+100|0;c[S>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](J,0)|0;do{if((c[O>>2]|0)!=0){T=c[S>>2]|0;c[K>>2]=9534384;U=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[U&16383](K,0,0)|0;if((T|0)<1){R=1;i=b;return R|0}if((gzL(L,0,0)|0)==0){break}else{R=1}i=b;return R|0}}while(0);L=(c[3529132]|0)+2048|0;if((c[3542200]|0)==0){R=1;i=b;return R|0}S=H+108|0;c[S>>2]=0;O=H+100|0;c[O>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](H,1)|0;do{if((c[S>>2]|0)!=0){T=c[O>>2]|0;c[I>>2]=9534384;U=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[U&16383](I,1,0)|0;if((T|0)<1){R=1;i=b;return R|0}if((gzL(L,0,1)|0)==0){break}else{R=1}i=b;return R|0}}while(0);L=(c[3529132]|0)+4096|0;if((c[3542200]|0)==0){R=1;i=b;return R|0}O=F+108|0;c[O>>2]=0;S=F+100|0;c[S>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](F,2)|0;do{if((c[O>>2]|0)!=0){T=c[S>>2]|0;c[G>>2]=9534384;U=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[U&16383](G,2,0)|0;if((T|0)<1){R=1;i=b;return R|0}if((gzL(L,0,2)|0)==0){break}else{R=1}i=b;return R|0}}while(0);L=(c[3529132]|0)+6144|0;if((c[3542200]|0)==0){R=1;i=b;return R|0}S=D+108|0;c[S>>2]=0;O=D+100|0;c[O>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](D,3)|0;do{if((c[S>>2]|0)!=0){T=c[O>>2]|0;c[E>>2]=9534384;U=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[U&16383](E,3,0)|0;if((T|0)<1){R=1;i=b;return R|0}if((gzL(L,0,3)|0)==0){break}else{R=1}i=b;return R|0}}while(0);L=(c[3529132]|0)+8192|0;if((c[3542200]|0)==0){R=1;i=b;return R|0}O=B+108|0;c[O>>2]=0;S=B+100|0;c[S>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](B,4)|0;do{if((c[O>>2]|0)!=0){T=c[S>>2]|0;c[C>>2]=9534384;U=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[U&16383](C,4,0)|0;if((T|0)<1){R=1;i=b;return R|0}if((gzL(L,0,4)|0)==0){break}else{R=1}i=b;return R|0}}while(0);L=(c[3529132]|0)+10240|0;if((c[3542200]|0)==0){R=1;i=b;return R|0}S=z+108|0;c[S>>2]=0;O=z+100|0;c[O>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,5)|0;do{if((c[S>>2]|0)!=0){T=c[O>>2]|0;c[A>>2]=9534384;U=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[U&16383](A,5,0)|0;if((T|0)<1){R=1;i=b;return R|0}if((gzL(L,0,5)|0)==0){break}else{R=1}i=b;return R|0}}while(0);L=(c[3529132]|0)+12288|0;if((c[3542200]|0)==0){R=1;i=b;return R|0}O=x+108|0;c[O>>2]=0;S=x+100|0;c[S>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,6)|0;do{if((c[O>>2]|0)!=0){T=c[S>>2]|0;c[y>>2]=9534384;U=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[U&16383](y,6,0)|0;if((T|0)<1){R=1;i=b;return R|0}if((gzL(L,0,6)|0)==0){break}else{R=1}i=b;return R|0}}while(0);L=(c[3529132]|0)+14336|0;if((c[3542200]|0)==0){R=1;i=b;return R|0}S=v+108|0;c[S>>2]=0;O=v+100|0;c[O>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,7)|0;do{if((c[S>>2]|0)!=0){T=c[O>>2]|0;c[w>>2]=9534384;U=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[U&16383](w,7,0)|0;if((T|0)<1){R=1;i=b;return R|0}if((gzL(L,0,7)|0)==0){break}else{R=1}i=b;return R|0}}while(0);L=c[3529546]|0;if((c[3542200]|0)==0){R=1;i=b;return R|0}O=t+108|0;c[O>>2]=0;S=t+100|0;c[S>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,8)|0;do{if((c[O>>2]|0)!=0){T=c[S>>2]|0;c[u>>2]=9534384;U=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[U&16383](u,8,0)|0;if((T|0)<1){R=1;i=b;return R|0}if((gzL(L,0,8)|0)==0){break}else{R=1}i=b;return R|0}}while(0);L=(c[3529546]|0)+2048|0;if((c[3542200]|0)==0){R=1;i=b;return R|0}S=r+108|0;c[S>>2]=0;O=r+100|0;c[O>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,9)|0;do{if((c[S>>2]|0)!=0){T=c[O>>2]|0;c[s>>2]=9534384;U=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[U&16383](s,9,0)|0;if((T|0)<1){R=1;i=b;return R|0}if((gzL(L,0,9)|0)==0){break}else{R=1}i=b;return R|0}}while(0);L=c[3529546]|0;O=c[2406544]|0;S=0;do{T=S<<6;gGz(O+T|0,0,64);U=S<<7;V=0;do{W=U+(c[1238464+(V<<2)>>2]|0)|0;X=(V<<3)+T|0;Y=0;do{Z=W+(c[610928+(Y<<2)>>2]|0)|0;if(((d[L+((Z|0)/8|0)|0]|0)&128>>>((Z&7)>>>0)|0)!=0){Z=O+(X+Y)|0;a[Z]=a[Z]|2}Y=Y+1|0;}while((Y|0)<8);V=V+1|0;}while((V|0)<8);V=U|4;Y=0;do{X=V+(c[1238464+(Y<<2)>>2]|0)|0;W=(Y<<3)+T|0;Z=0;do{_=X+(c[610928+(Z<<2)>>2]|0)|0;if(((d[L+((_|0)/8|0)|0]|0)&128>>>((_&7)>>>0)|0)!=0){_=O+(W+Z)|0;a[_]=a[_]|1}Z=Z+1|0;}while((Z|0)<8);Y=Y+1|0;}while((Y|0)<8);S=S+1|0;}while((S|0)<256);S=c[3529596]|0;O=0;do{Y=O<<8;gGz(S+Y|0,0,256);T=O<<9;V=0;do{U=T+(c[611712+(V<<2)>>2]|0)|0;Z=(V<<4)+Y|0;W=0;do{X=U+(c[61e4+(W<<2)>>2]|0)|0;if(((d[L+((X|0)/8|0)|0]|0)&128>>>((X&7)>>>0)|0)!=0){X=S+(Z+W)|0;a[X]=a[X]|2}W=W+1|0;}while((W|0)<16);V=V+1|0;}while((V|0)<16);V=T|4;W=0;do{Z=V+(c[611712+(W<<2)>>2]|0)|0;U=(W<<4)+Y|0;X=0;do{_=Z+(c[61e4+(X<<2)>>2]|0)|0;if(((d[L+((_|0)/8|0)|0]|0)&128>>>((_&7)>>>0)|0)!=0){_=S+(U+X)|0;a[_]=a[_]|1}X=X+1|0;}while((X|0)<16);W=W+1|0;}while((W|0)<16);O=O+1|0;}while((O|0)<64);gGz(L|0,0,4096);if((c[3542200]|0)==0){R=1;i=b;return R|0}O=p+108|0;c[O>>2]=0;S=p+100|0;c[S>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,10)|0;do{if((c[O>>2]|0)!=0){W=c[S>>2]|0;c[q>>2]=9534384;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Y&16383](q,10,0)|0;if((W|0)<1){R=1;i=b;return R|0}if((gzL(L,0,10)|0)==0){break}else{R=1}i=b;return R|0}}while(0);L=c[3529546]|0;S=c[2408650]|0;O=0;do{W=O<<4;gGz(S+W|0,0,16);Y=O<<7;V=0;do{T=1<<1-V;X=(c[4049784+(V<<2)>>2]|0)+Y|0;U=0;do{Z=X+(c[7308504+(U<<2)>>2]|0)|0;_=(U<<2)+W|0;if(((d[L+((Z|0)/8|0)|0]|0)&128>>>((Z&7)>>>0)|0)!=0){$=S+_|0;a[$]=(d[$]|0|T)&255}$=Z+8|0;if(((d[L+(($|0)/8|0)|0]|0)&128>>>(($&7)>>>0)|0)!=0){$=S+(_|1)|0;a[$]=(d[$]|0|T)&255}$=Z+16|0;if(((d[L+(($|0)/8|0)|0]|0)&128>>>(($&7)>>>0)|0)!=0){$=S+(_|2)|0;a[$]=(d[$]|0|T)&255}$=Z+24|0;if(((d[L+(($|0)/8|0)|0]|0)&128>>>(($&7)>>>0)|0)!=0){$=S+(_|3)|0;a[$]=(d[$]|0|T)&255}U=U+1|0;}while((U|0)<4);V=V+1|0;}while((V|0)<2);O=O+1|0;}while((O|0)<8);O=c[2438762]|0;if((c[3542200]|0)==0){R=1;i=b;return R|0}S=n+108|0;c[S>>2]=0;L=n+100|0;c[L>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,11)|0;do{if((c[S>>2]|0)!=0){V=c[L>>2]|0;c[o>>2]=9534384;W=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[W&16383](o,11,0)|0;if((V|0)<1){R=1;i=b;return R|0}if((gzL(O,0,11)|0)==0){break}else{R=1}i=b;return R|0}}while(0);O=c[2439588]|0;if((c[3542200]|0)==0){R=1;i=b;return R|0}L=l+108|0;c[L>>2]=0;S=l+100|0;c[S>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,12)|0;do{if((c[L>>2]|0)!=0){V=c[S>>2]|0;c[m>>2]=9534384;W=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[W&16383](m,12,0)|0;if((V|0)<1){R=1;i=b;return R|0}if((gzL(O,0,12)|0)==0){break}else{R=1}i=b;return R|0}}while(0);O=c[2433454]|0;if((c[3542200]|0)==0){R=1;i=b;return R|0}S=j+108|0;c[S>>2]=0;L=j+100|0;c[L>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,13)|0;do{if((c[S>>2]|0)!=0){V=c[L>>2]|0;c[k>>2]=9534384;W=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[W&16383](k,13,0)|0;if((V|0)<1){R=1;i=b;return R|0}if((gzL(O,0,13)|0)==0){break}else{R=1}i=b;return R|0}}while(0);O=c[2433452]|0;if((c[3542200]|0)==0){R=1;i=b;return R|0}L=g+108|0;c[L>>2]=0;S=g+100|0;c[S>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,14)|0;do{if((c[L>>2]|0)!=0){V=c[S>>2]|0;c[h>>2]=9534384;W=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[W&16383](h,14,0)|0;if((V|0)<1){R=1;i=b;return R|0}if((gzL(O,0,14)|0)==0){break}else{R=1}i=b;return R|0}}while(0);O=c[3541148]|0;if((c[3542200]|0)==0){R=1;i=b;return R|0}S=e+108|0;c[S>>2]=0;L=e+100|0;c[L>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,15)|0;do{if((c[S>>2]|0)!=0){V=c[L>>2]|0;c[f>>2]=9534384;W=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[W&16383](f,15,0)|0;if((V|0)<1){R=1;i=b;return R|0}if((gzL(O,0,15)|0)==0){break}else{R=1}i=b;return R|0}}while(0);O=c[3529546]|0;L=0;while(1){if((L|0)>=1024){break}aa=9638528+(L<<2)|0;if((c[aa>>2]|0)==(O|0)){N=65862;break}else{L=L+1|0}}if((N|0)==65862){gGr(O);c[aa>>2]=0}c[3529546]=0;djR();R=0;i=b;return R|0}}while(0);c[2426806]=0;R=1;i=b;return R|0}function djK(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5114780+(b*112|0)>>2];c[a+104>>2]=c[5114784+(b*112|0)>>2];c[a+108>>2]=c[5114788+(b*112|0)>>2];d=0;return d|0}function djL(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=5114680+(b*112|0);e=0;return e|0}function djM(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3577604+(b*112|0)>>2];c[a+104>>2]=c[3577608+(b*112|0)>>2];c[a+108>>2]=c[3577612+(b*112|0)>>2];d=0;return d|0}function djN(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=3577504+(b*112|0);e=0;return e|0}function djO(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5199988+(b*112|0)>>2];c[a+104>>2]=c[5199992+(b*112|0)>>2];c[a+108>>2]=c[5199996+(b*112|0)>>2];d=0;return d|0}function djP(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=5199888+(b*112|0);e=0;return e|0}function djQ(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;b=i;i=i+1440|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;l=b+360|0;m=b+472|0;n=b+480|0;o=b+592|0;p=b+600|0;q=b+712|0;r=b+720|0;s=b+832|0;t=b+840|0;u=b+952|0;v=b+960|0;w=b+1072|0;x=b+1080|0;y=b+1192|0;z=b+1200|0;A=b+1312|0;B=b+1320|0;C=b+1432|0;c[2426806]=0;c[3529132]=0;c[2438762]=16384;c[2439588]=16416;c[2433454]=16672;c[2433452]=16704;c[3541148]=16736;c[2405712]=16992;c[3529158]=16992;c[3527226]=19040;c[2437756]=23136;c[2411810]=23152;c[2406544]=23152;c[3529596]=39536;c[2408650]=55920;c[3530130]=56048;D=0;while(1){if((D|0)>=1024){break}E=9638528+(D<<2)|0;if((c[E>>2]|0)==0){F=65972;break}else{D=D+1|0}}do{if((F|0)==65972){D=gGq(57088)|0;c[E>>2]=D;if((D|0)==0){break}c[2426806]=D;gGz(D|0,0,57088);c[3529132]=D;c[2438762]=D+16384;c[2439588]=D+16416;c[2433454]=D+16672;c[2433452]=D+16704;c[3541148]=D+16736;G=D+16992|0;c[2405712]=G;c[3529158]=G;c[3527226]=D+19040;c[2437756]=D+23136;G=D+23152|0;c[2411810]=G;c[2406544]=G;c[3529596]=D+39536;c[2408650]=D+55920;c[3530130]=D+56048;c[2414358]=D+57088;D=0;while(1){if((D|0)>=1024){H=0;break}I=9638528+(D<<2)|0;if((c[I>>2]|0)==0){F=65977;break}else{D=D+1|0}}do{if((F|0)==65977){D=gGq(4096)|0;c[I>>2]=D;if((D|0)==0){H=0;break}gGz(D|0,0,4096);H=D}}while(0);c[3529546]=H;if((c[3542200]|0)==0){J=1;i=b;return J|0}D=B+108|0;c[D>>2]=0;G=B+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](B,0)|0;do{if((c[D>>2]|0)!=0){K=c[G>>2]|0;c[C>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](C,0,0)|0;if((K|0)<1){J=1;i=b;return J|0}if((gzL(H,0,0)|0)==0){break}else{J=1}i=b;return J|0}}while(0);G=c[3529132]|0;D=c[3529546]|0;gGC(G|0,D|0,2048)|0;K=G+4096|0;G=D+2048|0;gGC(K|0,G|0,2048)|0;if((c[3542200]|0)==0){J=1;i=b;return J|0}G=z+108|0;c[G>>2]=0;K=z+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,1)|0;do{if((c[G>>2]|0)!=0){L=c[K>>2]|0;c[A>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](A,1,0)|0;if((L|0)<1){J=1;i=b;return J|0}if((gzL(D,0,1)|0)==0){break}else{J=1}i=b;return J|0}}while(0);D=c[3529132]|0;K=D+2048|0;G=c[3529546]|0;gGC(K|0,G|0,2048)|0;K=D+6144|0;D=G+2048|0;gGC(K|0,D|0,2048)|0;if((c[3542200]|0)==0){J=1;i=b;return J|0}D=x+108|0;c[D>>2]=0;K=x+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,2)|0;do{if((c[D>>2]|0)!=0){L=c[K>>2]|0;c[y>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](y,2,0)|0;if((L|0)<1){J=1;i=b;return J|0}if((gzL(G,0,2)|0)==0){break}else{J=1}i=b;return J|0}}while(0);G=c[3529132]|0;K=G+8192|0;D=c[3529546]|0;gGC(K|0,D|0,2048)|0;K=G+12288|0;G=D+2048|0;gGC(K|0,G|0,2048)|0;if((c[3542200]|0)==0){J=1;i=b;return J|0}G=v+108|0;c[G>>2]=0;K=v+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,3)|0;do{if((c[G>>2]|0)!=0){L=c[K>>2]|0;c[w>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](w,3,0)|0;if((L|0)<1){J=1;i=b;return J|0}if((gzL(D,0,3)|0)==0){break}else{J=1}i=b;return J|0}}while(0);D=c[3529132]|0;K=D+10240|0;G=c[3529546]|0;gGC(K|0,G|0,2048)|0;K=D+14336|0;D=G+2048|0;gGC(K|0,D|0,2048)|0;gGz(G|0,0,4096);if((c[3542200]|0)==0){J=1;i=b;return J|0}D=t+108|0;c[D>>2]=0;K=t+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,4)|0;do{if((c[D>>2]|0)!=0){L=c[K>>2]|0;c[u>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](u,4,0)|0;if((L|0)<1){J=1;i=b;return J|0}if((gzL(G,0,4)|0)==0){break}else{J=1}i=b;return J|0}}while(0);G=(c[3529546]|0)+2048|0;if((c[3542200]|0)==0){J=1;i=b;return J|0}K=r+108|0;c[K>>2]=0;D=r+100|0;c[D>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,5)|0;do{if((c[K>>2]|0)!=0){L=c[D>>2]|0;c[s>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](s,5,0)|0;if((L|0)<1){J=1;i=b;return J|0}if((gzL(G,0,5)|0)==0){break}else{J=1}i=b;return J|0}}while(0);G=c[3529546]|0;D=c[2406544]|0;K=0;do{L=K<<6;gGz(D+L|0,0,64);M=K<<7;N=0;do{O=M+(c[1238464+(N<<2)>>2]|0)|0;P=(N<<3)+L|0;Q=0;do{R=O+(c[610928+(Q<<2)>>2]|0)|0;if(((d[G+((R|0)/8|0)|0]|0)&128>>>((R&7)>>>0)|0)!=0){R=D+(P+Q)|0;a[R]=a[R]|2}Q=Q+1|0;}while((Q|0)<8);N=N+1|0;}while((N|0)<8);N=M|4;Q=0;do{P=N+(c[1238464+(Q<<2)>>2]|0)|0;O=(Q<<3)+L|0;R=0;do{S=P+(c[610928+(R<<2)>>2]|0)|0;if(((d[G+((S|0)/8|0)|0]|0)&128>>>((S&7)>>>0)|0)!=0){S=D+(O+R)|0;a[S]=a[S]|1}R=R+1|0;}while((R|0)<8);Q=Q+1|0;}while((Q|0)<8);K=K+1|0;}while((K|0)<256);K=c[3529596]|0;D=0;do{Q=D<<8;gGz(K+Q|0,0,256);L=D<<9;N=0;do{M=L+(c[611712+(N<<2)>>2]|0)|0;R=(N<<4)+Q|0;O=0;do{P=M+(c[61e4+(O<<2)>>2]|0)|0;if(((d[G+((P|0)/8|0)|0]|0)&128>>>((P&7)>>>0)|0)!=0){P=K+(R+O)|0;a[P]=a[P]|2}O=O+1|0;}while((O|0)<16);N=N+1|0;}while((N|0)<16);N=L|4;O=0;do{R=N+(c[611712+(O<<2)>>2]|0)|0;M=(O<<4)+Q|0;P=0;do{S=R+(c[61e4+(P<<2)>>2]|0)|0;if(((d[G+((S|0)/8|0)|0]|0)&128>>>((S&7)>>>0)|0)!=0){S=K+(M+P)|0;a[S]=a[S]|1}P=P+1|0;}while((P|0)<16);O=O+1|0;}while((O|0)<16);D=D+1|0;}while((D|0)<64);gGz(G|0,0,4096);if((c[3542200]|0)==0){J=1;i=b;return J|0}D=p+108|0;c[D>>2]=0;K=p+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,6)|0;do{if((c[D>>2]|0)!=0){O=c[K>>2]|0;c[q>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](q,6,0)|0;if((O|0)<1){J=1;i=b;return J|0}if((gzL(G,0,6)|0)==0){break}else{J=1}i=b;return J|0}}while(0);G=c[3529546]|0;K=c[2408650]|0;D=0;do{O=D<<4;gGz(K+O|0,0,16);Q=D<<7;N=0;do{L=1<<1-N;P=(c[4049784+(N<<2)>>2]|0)+Q|0;M=0;do{R=P+(c[7308504+(M<<2)>>2]|0)|0;S=(M<<2)+O|0;if(((d[G+((R|0)/8|0)|0]|0)&128>>>((R&7)>>>0)|0)!=0){T=K+S|0;a[T]=(d[T]|0|L)&255}T=R+8|0;if(((d[G+((T|0)/8|0)|0]|0)&128>>>((T&7)>>>0)|0)!=0){T=K+(S|1)|0;a[T]=(d[T]|0|L)&255}T=R+16|0;if(((d[G+((T|0)/8|0)|0]|0)&128>>>((T&7)>>>0)|0)!=0){T=K+(S|2)|0;a[T]=(d[T]|0|L)&255}T=R+24|0;if(((d[G+((T|0)/8|0)|0]|0)&128>>>((T&7)>>>0)|0)!=0){T=K+(S|3)|0;a[T]=(d[T]|0|L)&255}M=M+1|0;}while((M|0)<4);N=N+1|0;}while((N|0)<2);D=D+1|0;}while((D|0)<8);D=c[2438762]|0;if((c[3542200]|0)==0){J=1;i=b;return J|0}K=n+108|0;c[K>>2]=0;G=n+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,7)|0;do{if((c[K>>2]|0)!=0){N=c[G>>2]|0;c[o>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](o,7,0)|0;if((N|0)<1){J=1;i=b;return J|0}if((gzL(D,0,7)|0)==0){break}else{J=1}i=b;return J|0}}while(0);D=c[2439588]|0;if((c[3542200]|0)==0){J=1;i=b;return J|0}G=l+108|0;c[G>>2]=0;K=l+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,8)|0;do{if((c[G>>2]|0)!=0){N=c[K>>2]|0;c[m>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](m,8,0)|0;if((N|0)<1){J=1;i=b;return J|0}if((gzL(D,0,8)|0)==0){break}else{J=1}i=b;return J|0}}while(0);D=c[2433454]|0;if((c[3542200]|0)==0){J=1;i=b;return J|0}K=j+108|0;c[K>>2]=0;G=j+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,9)|0;do{if((c[K>>2]|0)!=0){N=c[G>>2]|0;c[k>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](k,9,0)|0;if((N|0)<1){J=1;i=b;return J|0}if((gzL(D,0,9)|0)==0){break}else{J=1}i=b;return J|0}}while(0);D=c[2433452]|0;if((c[3542200]|0)==0){J=1;i=b;return J|0}G=g+108|0;c[G>>2]=0;K=g+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,10)|0;do{if((c[G>>2]|0)!=0){N=c[K>>2]|0;c[h>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](h,10,0)|0;if((N|0)<1){J=1;i=b;return J|0}if((gzL(D,0,10)|0)==0){break}else{J=1}i=b;return J|0}}while(0);D=c[3541148]|0;if((c[3542200]|0)==0){J=1;i=b;return J|0}K=e+108|0;c[K>>2]=0;G=e+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,11)|0;do{if((c[K>>2]|0)!=0){N=c[G>>2]|0;c[f>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](f,11,0)|0;if((N|0)<1){J=1;i=b;return J|0}if((gzL(D,0,11)|0)==0){break}else{J=1}i=b;return J|0}}while(0);D=c[3529546]|0;G=0;while(1){if((G|0)>=1024){break}U=9638528+(G<<2)|0;if((c[U>>2]|0)==(D|0)){F=66054;break}else{G=G+1|0}}if((F|0)==66054){gGr(D);c[U>>2]=0}c[3529546]=0;djR();J=0;i=b;return J|0}}while(0);c[2426806]=0;J=1;i=b;return J|0}function djR(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;fwR(0);d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];f=c[3528484]|0;c[2076596]=f;g=c[2417276]|0;c[3541536]=g;c[1836236]=0;c[d+4180>>2]=3430;c[d+4184>>2]=2754;c[d+4172>>2]=1714;c[d+4176>>2]=1846;i=c[3529132]|0;j=0;k=0;while(1){c[d+76+(k<<2)>>2]=i+(k<<8);l=j+1&65535;if((l&65535)>63){m=0;n=0;break}else{j=l;k=l&65535}}while(1){k=i+(n<<8)|0;c[d+76+(n+512<<2)>>2]=k;c[d+76+(n+768<<2)>>2]=k;k=m+1&65535;if((k&65535)>63){break}else{m=k;n=k&65535}}n=c[3527226]|0;c[d+588>>2]=n;c[d+592>>2]=n+256;c[d+596>>2]=n+512;c[d+600>>2]=n+768;c[d+604>>2]=n+1024;c[d+608>>2]=n+1280;c[d+612>>2]=n+1536;c[d+616>>2]=n+1792;c[d+620>>2]=n+2048;c[d+624>>2]=n+2304;c[d+628>>2]=n+2560;c[d+632>>2]=n+2816;c[d+636>>2]=n+3072;c[d+640>>2]=n+3328;c[d+644>>2]=n+3584;c[d+648>>2]=n+3840;m=128;i=128;while(1){c[d+76+(i+256<<2)>>2]=n+((i<<8)-32768);k=m+1&65535;if((k&65535)>143){o=128;p=128;break}else{m=k;i=k&65535}}while(1){i=n+((p<<8)-32768)|0;c[d+76+(p+512<<2)>>2]=i;c[d+76+(p+768<<2)>>2]=i;i=o+1&65535;if((i&65535)>143){break}else{o=i;p=i&65535}}p=c[3529158]|0;c[d+684>>2]=p;o=p+256|0;c[d+688>>2]=o;n=p+512|0;c[d+692>>2]=n;i=p+768|0;c[d+696>>2]=i;m=p+1024|0;c[d+700>>2]=m;k=p+1280|0;c[d+704>>2]=k;j=p+1536|0;c[d+708>>2]=j;l=p+1792|0;c[d+712>>2]=l;c[d+1708>>2]=p;c[d+1712>>2]=o;c[d+1716>>2]=n;c[d+1720>>2]=i;c[d+1724>>2]=m;c[d+1728>>2]=k;c[d+1732>>2]=j;c[d+1736>>2]=l;c[d+2732>>2]=p;c[d+3756>>2]=p;c[d+2736>>2]=o;c[d+3760>>2]=o;c[d+2740>>2]=n;c[d+3764>>2]=n;c[d+2744>>2]=i;c[d+3768>>2]=i;c[d+2748>>2]=m;c[d+3772>>2]=m;c[d+2752>>2]=k;c[d+3776>>2]=k;c[d+2756>>2]=j;c[d+3780>>2]=j;c[d+2760>>2]=l;c[d+3784>>2]=l;c[d+1740>>2]=c[2437756];if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=f;c[2417276]=g;c[1836236]=-1;U_(96e3,3);g=c[2420424]|0;h[g+424>>3]=1.0;c[g+440>>2]=3;h[g+432>>3]=1.0;c[g+444>>2]=3;Vf(0);g=c[2439194]|0;if((g|0)>0){f=c[2406652]|0;e=0;while(1){h[f+(e*40|0)+16>>3]=.8;c[f+(e*40|0)+32>>2]=3;d=e+1|0;if((d|0)<(g|0)){e=d}else{break}}c[3528400]=f+(e*40|0);e=0;while(1){h[f+(e*40|0)+24>>3]=.8;c[f+(e*40|0)+36>>2]=3;d=e+1|0;if((d|0)<(g|0)){e=d}else{break}}c[3528400]=f+(e*40|0)}e=c[642608+(c[2436]<<2)>>2]|0;f=c[e+128>>2]|0;if((c[e+52>>2]&4|0)==0){c[2113068]=f;g=c[e+132>>2]|0;c[2113070]=g;c[2443814]=f;c[2440436]=g;q=f;r=g}else{c[2113070]=f;g=c[e+132>>2]|0;c[2113068]=g;c[2440436]=f;c[2443814]=g;q=g;r=f}f=ag(q<<1,r)|0;r=gGq(f)|0;c[2112926]=r;if((r|0)!=0){gGz(r|0,0,f|0)}f=c[2439330]|0;r=(f|0)==0;if(!r){q=f;gGC(9706056,q|0,76)|0}q=c[2438118]|0;c[2433530]=q;g=c[3528484]|0;c[2076596]=g;e=c[2417276]|0;c[3541536]=e;c[1836236]=0;gGz(9706056,0,76);if(!r){r=f;gGC(r|0,9706056,76)|0}c[2438118]=q;c[3528484]=g;c[2417276]=e;c[1836236]=-1;e=c[2439194]|0;if((e|0)<=0){a[9759816]=0;a[9751112]=0;a[9626464]=0;a[9626448]=0;a[14109776]=0;return}g=c[2406652]|0;q=0;do{s=g+(q*40|0)|0;r=g+(q*40|0)+12|0;a[r]=0;f=g+(q*40|0)+8|0;c[f>>2]=0;d=a[g+(q*40|0)+14|0]|0;do{if((d&2)!=0&(e|0)>(q|0)){if((d&4)==0){a[g+(q*40|0)+13|0]=1}if((d&1)!=0){break}a[r]=1;c[f>>2]=0}}while(0);q=q+1|0;}while((q|0)<(e|0));c[3528400]=s;a[9759816]=0;a[9751112]=0;a[9626464]=0;a[9626448]=0;a[14109776]=0;return}function djS(b,d){b=b|0;d=d|0;var e=0,f=0;e=b&65535;if((e|0)==12288){b=c[3529808]|0;f=5;do{a[b+f|0]=d;f=f+1|0;}while((f|0)<32);return}else if((e|0)==12304){a[14113328]=d;return}else if((e|0)==12312){a[14115040]=d&1^1;return}else if((e|0)==12313){e=d&1;if(!((a[9750984]|0)!=0|e<<24>>24==0)){a[986984]=1}a[9750984]=e;return}else{return}}function djT(b){b=b|0;var c=0,d=0;c=b&65535;switch(c|0){case 12290:case 12291:case 12292:{d=a[9634560+(c-12290)|0]|0;break};case 12293:case 12294:{d=a[9635512+(c-12293)|0]|0;break};default:{d=0}}return d|0}function djU(b,d){b=b|0;d=d|0;var e=0,f=0;e=b&65535;if((e|0)==8193){b=d&255;f=c[3542228]|0;if((f|0)>15){return}do{if((f|0)<14){if((f|0)!=13){if((a[14168916+f|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(0,f,b);return}else if((e|0)==16385){b=d&255;f=c[3542291]|0;if((f|0)>15){return}do{if((f|0)<14){if((f|0)!=13){if((a[14169168+f|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(1,f,b);return}else if((e|0)==16384){c[3542291]=d&15;return}else if((e|0)==8192){c[3542228]=d&15;return}else{return}}function djV(b){b=b|0;return(b<<16>>16==-24576?a[14113328]|0:0)|0}function djW(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5666732+(b*112|0)>>2];c[a+104>>2]=c[5666736+(b*112|0)>>2];c[a+108>>2]=c[5666740+(b*112|0)>>2];d=0;return d|0}function djX(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=5666632+(b*112|0);e=0;return e|0}function djY(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3409888+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function djZ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>48){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6062840+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dj_(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0.0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0;e=i;i=i+1680|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;B=e+1200|0;C=e+1312|0;D=e+1320|0;E=e+1432|0;F=e+1440|0;G=e+1552|0;H=e+1560|0;I=e+1672|0;c[2415048]=0;c[2443524]=0;c[2443520]=65536;c[3530902]=131072;c[3530666]=196608;c[3531038]=327680;c[2406988]=328704;c[3530128]=330752;c[2414756]=332800;c[2443534]=332800;c[2443530]=336896;c[2386258]=343040;c[2387886]=344064;c[2386514]=345088;c[3529808]=345344;c[2411808]=345376;J=(a[9688]|0?351784:345376)|0;c[2414356]=J;K=J;J=0;while(1){if((J|0)>=1024){break}L=9638528+(J<<2)|0;if((c[L>>2]|0)==0){M=66221;break}else{J=J+1|0}}do{if((M|0)==66221){J=gGq(K)|0;c[L>>2]=J;if((J|0)==0){break}gGz(J|0,0,K|0);c[2415048]=J;gGz(J|0,0,K|0);c[2443524]=J;c[2443520]=J+65536;c[3530902]=J+131072;c[3530666]=J+196608;c[3531038]=J+327680;c[2406988]=J+328704;c[3530128]=J+330752;N=J+332800|0;c[2414756]=N;c[2443534]=N;c[2443530]=J+336896;c[2386258]=J+343040;c[2387886]=J+344064;c[2386514]=J+345088;c[3529808]=J+345344;N=J+345376|0;c[2411808]=N;O=N;c[2385404]=O;N=a[9688]|0?534:0;c[2414356]=J+((N*12|0)+345376);c[2439142]=O;c[2439143]=O+(N<<1);c[2439144]=O+(N<<1<<1);c[2439145]=O+((N*3|0)<<1);c[2439146]=O+(N<<2<<1);c[2439147]=O+((N*5|0)<<1);L79059:do{if(a[642592]|0){N=H+108|0;O=H+100|0;P=0;Q=J;while(1){R=Q+((P<<13)+16384)|0;if((c[3542200]|0)==0){S=1;M=66407;break}c[N>>2]=0;c[O>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](H,P)|0;if((c[N>>2]|0)!=0){T=c[O>>2]|0;c[I>>2]=9534384;U=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[U&16383](I,P,0)|0;if((T|0)<1){S=1;M=66387;break}if((gzL(R,0,P)|0)!=0){S=1;M=66403;break}}R=P+1|0;if((R|0)>=6){M=66231;break}P=R;Q=c[2443524]|0}if((M|0)==66231){Q=(c[2443520]|0)+57344|0;if((c[3542200]|0)==0){S=1;i=e;return S|0}P=F+108|0;c[P>>2]=0;O=F+100|0;c[O>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](F,6)|0;do{if((c[P>>2]|0)!=0){N=c[O>>2]|0;c[G>>2]=9534384;R=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[R&16383](G,6,0)|0;if((N|0)<1){S=1;i=e;return S|0}if((gzL(Q,0,6)|0)==0){break}else{S=1}i=e;return S|0}}while(0);Q=c[3530902]|0;if((c[3542200]|0)==0){S=1;i=e;return S|0}O=D+108|0;c[O>>2]=0;P=D+100|0;c[P>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](D,7)|0;do{if((c[O>>2]|0)!=0){N=c[P>>2]|0;c[E>>2]=9534384;R=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[R&16383](E,7,0)|0;if((N|0)<1){S=1;i=e;return S|0}if((gzL(Q,0,7)|0)==0){break}else{S=1}i=e;return S|0}}while(0);Q=(c[3530902]|0)+8192|0;if((c[3542200]|0)==0){S=1;i=e;return S|0}P=B+108|0;c[P>>2]=0;O=B+100|0;c[O>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](B,8)|0;do{if((c[P>>2]|0)!=0){N=c[O>>2]|0;c[C>>2]=9534384;R=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[R&16383](C,8,0)|0;if((N|0)<1){S=1;i=e;return S|0}if((gzL(Q,0,8)|0)==0){break}else{S=1}i=e;return S|0}}while(0);Q=z+108|0;O=z+100|0;P=0;while(1){N=(c[3530666]|0)+(P<<13)|0;R=P+9|0;if((c[3542200]|0)==0){S=1;M=66392;break}c[Q>>2]=0;c[O>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,R)|0;if((c[Q>>2]|0)!=0){T=c[O>>2]|0;c[A>>2]=9534384;U=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[U&16383](A,R,0)|0;if((T|0)<1){S=1;M=66393;break}if((gzL(N,0,R)|0)!=0){S=1;M=66388;break}}R=P+1|0;if((R|0)<6){P=R}else{M=66244;break}}if((M|0)==66244){P=x+108|0;O=x+100|0;Q=0;while(1){R=(c[3531038]|0)+(Q<<8)|0;N=Q+15|0;if((c[3542200]|0)==0){S=1;M=66409;break}c[P>>2]=0;c[O>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,N)|0;if((c[P>>2]|0)!=0){T=c[O>>2]|0;c[y>>2]=9534384;U=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[U&16383](y,N,0)|0;if((T|0)<1){S=1;M=66414;break}if((gzL(R,0,N)|0)!=0){S=1;M=66396;break}}N=Q+1|0;if((N|0)<4){Q=N}else{V=0;break L79059}}if((M|0)==66396){i=e;return S|0}else if((M|0)==66409){i=e;return S|0}else if((M|0)==66414){i=e;return S|0}}else if((M|0)==66388){i=e;return S|0}else if((M|0)==66392){i=e;return S|0}else if((M|0)==66393){i=e;return S|0}}else if((M|0)==66387){i=e;return S|0}else if((M|0)==66403){i=e;return S|0}else if((M|0)==66407){i=e;return S|0}}else{Q=J+16384|0;if((c[3542200]|0)==0){S=1;i=e;return S|0}O=v+108|0;c[O>>2]=0;P=v+100|0;c[P>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,0)|0;do{if((c[O>>2]|0)!=0){N=c[P>>2]|0;c[w>>2]=9534384;R=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[R&16383](w,0,0)|0;if((N|0)<1){S=1;i=e;return S|0}if((gzL(Q,0,0)|0)==0){break}else{S=1}i=e;return S|0}}while(0);Q=(c[2443524]|0)+32768|0;if((c[3542200]|0)==0){S=1;i=e;return S|0}P=t+108|0;c[P>>2]=0;O=t+100|0;c[O>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,1)|0;do{if((c[P>>2]|0)!=0){N=c[O>>2]|0;c[u>>2]=9534384;R=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[R&16383](u,1,0)|0;if((N|0)<1){S=1;i=e;return S|0}if((gzL(Q,0,1)|0)==0){break}else{S=1}i=e;return S|0}}while(0);Q=(c[2443524]|0)+49152|0;if((c[3542200]|0)==0){S=1;i=e;return S|0}O=r+108|0;c[O>>2]=0;P=r+100|0;c[P>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,2)|0;do{if((c[O>>2]|0)!=0){N=c[P>>2]|0;c[s>>2]=9534384;R=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[R&16383](s,2,0)|0;if((N|0)<1){S=1;i=e;return S|0}if((gzL(Q,0,2)|0)==0){break}else{S=1}i=e;return S|0}}while(0);Q=(c[2443520]|0)+57344|0;if((c[3542200]|0)==0){S=1;i=e;return S|0}P=p+108|0;c[P>>2]=0;O=p+100|0;c[O>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,3)|0;do{if((c[P>>2]|0)!=0){N=c[O>>2]|0;c[q>>2]=9534384;R=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[R&16383](q,3,0)|0;if((N|0)<1){S=1;i=e;return S|0}if((gzL(Q,0,3)|0)==0){break}else{S=1}i=e;return S|0}}while(0);Q=c[3530902]|0;if((c[3542200]|0)==0){S=1;i=e;return S|0}O=n+108|0;c[O>>2]=0;P=n+100|0;c[P>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,4)|0;do{if((c[O>>2]|0)!=0){N=c[P>>2]|0;c[o>>2]=9534384;R=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[R&16383](o,4,0)|0;if((N|0)<1){S=1;i=e;return S|0}if((gzL(Q,0,4)|0)==0){break}else{S=1}i=e;return S|0}}while(0);Q=(c[3530902]|0)+8192|0;if((c[3542200]|0)==0){S=1;i=e;return S|0}P=l+108|0;c[P>>2]=0;O=l+100|0;c[O>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,5)|0;do{if((c[P>>2]|0)!=0){N=c[O>>2]|0;c[m>>2]=9534384;R=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[R&16383](m,5,0)|0;if((N|0)<1){S=1;i=e;return S|0}if((gzL(Q,0,5)|0)==0){break}else{S=1}i=e;return S|0}}while(0);Q=j+108|0;O=j+100|0;P=0;while(1){N=(c[3530666]|0)+(P<<13)|0;R=P+6|0;if((c[3542200]|0)==0){S=1;M=66423;break}c[Q>>2]=0;c[O>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,R)|0;if((c[Q>>2]|0)!=0){T=c[O>>2]|0;c[k>>2]=9534384;U=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[U&16383](k,R,0)|0;if((T|0)<1){S=1;M=66401;break}if((gzL(N,0,R)|0)!=0){S=1;M=66424;break}}R=P+1|0;if((R|0)<6){P=R}else{M=66280;break}}if((M|0)==66280){P=f+108|0;O=f+100|0;Q=0;while(1){R=(c[3531038]|0)+(Q<<8)|0;N=Q+12|0;if((c[3542200]|0)==0){S=1;M=66404;break}c[P>>2]=0;c[O>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,N)|0;if((c[P>>2]|0)!=0){T=c[O>>2]|0;c[g>>2]=9534384;U=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[U&16383](g,N,0)|0;if((T|0)<1){S=1;M=66390;break}if((gzL(R,0,N)|0)!=0){S=1;M=66394;break}}N=Q+1|0;if((N|0)<4){Q=N}else{V=0;break L79059}}if((M|0)==66390){i=e;return S|0}else if((M|0)==66394){i=e;return S|0}else if((M|0)==66404){i=e;return S|0}}else if((M|0)==66401){i=e;return S|0}else if((M|0)==66423){i=e;return S|0}else if((M|0)==66424){i=e;return S|0}}}while(0);while(1){if((V|0)>=1024){W=0;break}X=9638528+(V<<2)|0;if((c[X>>2]|0)==0){M=66293;break}else{V=V+1|0}}L79214:do{if((M|0)==66293){J=gGq(128)|0;c[X>>2]=J;if((J|0)==0){W=0;break}gGz(J|0,0,128);Q=J;O=c[3531038]|0;P=0;do{N=d[O+(P+256)|0]|0;R=d[O+P|0]|0;c[Q+(P<<2)>>2]=(-(R>>>1&1)&31)+(-(R&1)&14)+(-(R>>>2&1)&67)+(-(R>>>3&1)&143)|(-(N>>>1&1)&31)+(-(N&1)&14)+(-(N>>>2&1)&67)+(-(N>>>3&1)&143)<<16|(-(R>>>5&1)&31)+(-(R>>>7)&143)+(-(R>>>4&1)&14)+(-(R>>>6&1)&67)<<8;P=P+1|0;}while((P|0)<32);P=c[2406988]|0;R=0;while(1){c[P+(R<<2)>>2]=c[Q+((a[O+(R+512)|0]&15|R>>>4&16)<<2)>>2];N=R+1|0;if((N|0)<512){R=N}else{Y=0;break}}while(1){if((Y|0)>=1024){W=0;break L79214}Z=9638528+(Y<<2)|0;if((c[Z>>2]|0)==(J|0)){break}else{Y=Y+1|0}}gGr(J);c[Z>>2]=0;W=0}}while(0);while(1){if((W|0)>=1024){break}_=9638528+(W<<2)|0;if((c[_>>2]|0)==0){M=66303;break}else{W=W+1|0}}L79229:do{if((M|0)==66303){R=gGq(49152)|0;c[_>>2]=R;if((R|0)==0){break}gGz(R|0,0,49152);O=c[3530902]|0;gGC(R|0,O|0,16384)|0;Q=0;do{P=Q<<6;gGz(O+P|0,0,64);N=P+65536|0;T=0;while(1){U=N+(c[609008+(T<<2)>>2]|0)|0;$=(T<<3)+P|0;aa=0;do{ab=U+(c[614800+(aa<<2)>>2]|0)|0;if(((d[R+((ab|0)/8|0)|0]|0)&128>>>((ab&7)>>>0)|0)!=0){ab=O+($+aa)|0;a[ab]=a[ab]|2}aa=aa+1|0;}while((aa|0)<8);aa=T+1|0;if((aa|0)<8){T=aa}else{ac=0;break}}do{T=P+(c[609008+(ac<<2)>>2]|0)|0;N=(ac<<3)+P|0;aa=0;do{$=T+(c[614800+(aa<<2)>>2]|0)|0;if(((d[R+(($|0)/8|0)|0]|0)&128>>>(($&7)>>>0)|0)!=0){$=O+(N+aa)|0;a[$]=a[$]|1}aa=aa+1|0;}while((aa|0)<8);ac=ac+1|0;}while((ac|0)<8);Q=Q+1|0;}while((Q|0)<1024);Q=c[3530666]|0;gGC(R|0,Q|0,49152)|0;O=0;while(1){J=O<<8;gGz(Q+J|0,0,256);P=J+262144|0;aa=0;do{N=P+(c[609008+(aa<<2)>>2]|0)|0;T=(aa<<4)+J|0;$=0;do{U=N+(c[612800+($<<2)>>2]|0)|0;if(((d[R+((U|0)/8|0)|0]|0)&128>>>((U&7)>>>0)|0)!=0){U=Q+(T+$)|0;a[U]=a[U]|4}$=$+1|0;}while(($|0)<16);aa=aa+1|0;}while((aa|0)<16);aa=J+131072|0;P=0;while(1){$=aa+(c[609008+(P<<2)>>2]|0)|0;T=(P<<4)+J|0;N=0;do{U=$+(c[612800+(N<<2)>>2]|0)|0;if(((d[R+((U|0)/8|0)|0]|0)&128>>>((U&7)>>>0)|0)!=0){U=Q+(T+N)|0;a[U]=a[U]|2}N=N+1|0;}while((N|0)<16);N=P+1|0;if((N|0)<16){P=N}else{ad=0;break}}do{P=J+(c[609008+(ad<<2)>>2]|0)|0;aa=(ad<<4)+J|0;N=0;do{T=P+(c[612800+(N<<2)>>2]|0)|0;if(((d[R+((T|0)/8|0)|0]|0)&128>>>((T&7)>>>0)|0)!=0){T=Q+(aa+N)|0;a[T]=a[T]|1}N=N+1|0;}while((N|0)<16);ad=ad+1|0;}while((ad|0)<16);J=O+1|0;if((J|0)<512){O=J}else{ae=0;break}}while(1){if((ae|0)>=1024){break L79229}af=9638528+(ae<<2)|0;if((c[af>>2]|0)==(R|0)){break}else{ae=ae+1|0}}gGr(R);c[af>>2]=0}}while(0);c[3528554]=-1;c[2113160]=2;O=gGq(6296)|0;Q=O;c[2433592]=Q;if((O|0)!=0){gGz(O|0,0,6296);J=0;do{c[Q+(J*3148|0)+3120>>2]=3128;c[Q+(J*3148|0)+3124>>2]=1840;c[Q+(J*3148|0)+3128>>2]=136;c[Q+(J*3148|0)+3132>>2]=1902;c[9731360+(J<<2)>>2]=0;N=0;do{c[Q+(J*3148|0)+48+(N<<2)>>2]=0;N=N+1|0;}while((N|0)<768);J=J+1|0;}while((J|0)<2);c[2113158]=0;c[2415198]=0;J=c[2427044]|0;c[9681616+(J<<3)>>2]=809272;c[9681620+(J<<3)>>2]=0;Q=J+1|0;c[9681616+(Q<<3)>>2]=809272;c[9681620+(Q<<3)>>2]=1;c[2427044]=J+2}c[3528554]=0;f43(O);J=c[3528554]|0;Q=9731360+(J<<2)|0;N=c[Q>>2]|0;c[2113158]=N;R=c[2443534]|0;aa=c[2433592]|0;P=0;T=0;while(1){$=R+(T<<8)|0;c[aa+(J*3148|0)+48+(T<<2)>>2]=$;c[aa+(J*3148|0)+48+(T+256<<2)>>2]=$;c[aa+(J*3148|0)+48+(T+512<<2)>>2]=$;$=P+1&65535;if(($&65535)>15){break}else{P=$;T=$&65535}}T=c[2386258]|0;c[aa+(J*3148|0)+112>>2]=T;c[aa+(J*3148|0)+1136>>2]=T;c[aa+(J*3148|0)+2160>>2]=T;P=T+256|0;c[aa+(J*3148|0)+116>>2]=P;c[aa+(J*3148|0)+1140>>2]=P;c[aa+(J*3148|0)+2164>>2]=P;P=T+512|0;c[aa+(J*3148|0)+120>>2]=P;c[aa+(J*3148|0)+1144>>2]=P;c[aa+(J*3148|0)+2168>>2]=P;P=T+768|0;c[aa+(J*3148|0)+124>>2]=P;c[aa+(J*3148|0)+1148>>2]=P;c[aa+(J*3148|0)+2172>>2]=P;P=c[2387886]|0;c[aa+(J*3148|0)+128>>2]=P;c[aa+(J*3148|0)+1152>>2]=P;c[aa+(J*3148|0)+2176>>2]=P;T=P+256|0;c[aa+(J*3148|0)+132>>2]=T;c[aa+(J*3148|0)+1156>>2]=T;c[aa+(J*3148|0)+2180>>2]=T;T=P+512|0;c[aa+(J*3148|0)+136>>2]=T;c[aa+(J*3148|0)+1160>>2]=T;c[aa+(J*3148|0)+2184>>2]=T;T=P+768|0;c[aa+(J*3148|0)+140>>2]=T;c[aa+(J*3148|0)+1164>>2]=T;c[aa+(J*3148|0)+2188>>2]=T;T=c[2386514]|0;c[aa+(J*3148|0)+176>>2]=T;c[aa+(J*3148|0)+1200>>2]=T;c[aa+(J*3148|0)+2224>>2]=T;T=c[2443524]|0;P=64;R=64;while(1){O=T+(R<<8)|0;c[aa+(J*3148|0)+48+(R<<2)>>2]=O;c[aa+(J*3148|0)+48+(R+512<<2)>>2]=O;O=P+1&65535;if((O&65535)>255){break}else{P=O;R=O&65535}}c[aa+(J*3148|0)+3120>>2]=1042;c[aa+(J*3148|0)+3124>>2]=302;R=aa+(J*3148|0)|0;if((R|0)!=0){P=R;gGC(P|0,9660752,48)|0}c[Q>>2]=N;c[3528554]=1;f43(aa+3148|0);P=c[3528554]|0;R=9731360+(P<<2)|0;T=c[R>>2]|0;c[2113158]=T;O=c[2443530]|0;$=c[2433592]|0;c[$+(P*3148|0)+48>>2]=O;c[$+(P*3148|0)+1072>>2]=O;c[$+(P*3148|0)+2096>>2]=O;U=O+256|0;c[$+(P*3148|0)+52>>2]=U;c[$+(P*3148|0)+1076>>2]=U;c[$+(P*3148|0)+2100>>2]=U;U=O+512|0;c[$+(P*3148|0)+56>>2]=U;c[$+(P*3148|0)+1080>>2]=U;c[$+(P*3148|0)+2104>>2]=U;U=O+768|0;c[$+(P*3148|0)+60>>2]=U;c[$+(P*3148|0)+1084>>2]=U;c[$+(P*3148|0)+2108>>2]=U;U=O+1024|0;c[$+(P*3148|0)+64>>2]=U;c[$+(P*3148|0)+1088>>2]=U;c[$+(P*3148|0)+2112>>2]=U;U=O+1280|0;c[$+(P*3148|0)+68>>2]=U;c[$+(P*3148|0)+1092>>2]=U;c[$+(P*3148|0)+2116>>2]=U;U=O+1536|0;c[$+(P*3148|0)+72>>2]=U;c[$+(P*3148|0)+1096>>2]=U;c[$+(P*3148|0)+2120>>2]=U;U=O+1792|0;c[$+(P*3148|0)+76>>2]=U;c[$+(P*3148|0)+1100>>2]=U;c[$+(P*3148|0)+2124>>2]=U;U=c[2443520]|0;O=224;ab=224;while(1){ah=U+(ab<<8)|0;c[$+(P*3148|0)+48+(ab<<2)>>2]=ah;c[$+(P*3148|0)+48+(ab+512<<2)>>2]=ah;ah=O+1&65535;if((ah&65535)>255){break}else{O=ah;ab=ah&65535}}c[$+(P*3148|0)+3120>>2]=3088;c[$+(P*3148|0)+3124>>2]=1176;ab=$+(P*3148|0)|0;if((ab|0)!=0){O=ab;gGC(O|0,9660752,48)|0}c[R>>2]=T;c[3528554]=-1;O=a[9680]|0?32e3:0;c[3542220]=11200;ab=c[2113008]|0;if((ab|0)==0){gGz(14168888,0,252);c[3542223]=O;gGz(14168896,0,16);c[3542234]=~~((+(O|0)*32768.0*8.0+75.0e4)/15.0e5);U=31;ai=32767.0;while(1){c[14169012+(U<<2)>>2]=~~(ai+.5);aa=U-1|0;if((aa|0)>0){U=aa;ai=ai/1.188502227}else{break}}c[3542253]=0;h[1771269]=1.0;h[1771270]=1.0;h[1771271]=1.0;c[3542574]=3;c[3542575]=3;c[3542576]=3;mB(0);U=(c[2113008]|0)+1|0;c[2113008]=U;aj=U;ak=a[9680]|0?32e3:0}else{aj=ab;ak=O}c[3542220]=11200;if((aj|0)==1){gGz(14169140,0,252);c[3542286]=ak;gGz(14169148,0,16);c[3542297]=~~((+(ak|0)*32768.0*8.0+75.0e4)/15.0e5);U=31;ai=32767.0;while(1){c[14169264+(U<<2)>>2]=~~(ai+.5);T=U-1|0;if((T|0)>0){U=T;ai=ai/1.188502227}else{break}}c[3542316]=0;h[1771272]=1.0;h[1771273]=1.0;h[1771274]=1.0;c[3542577]=3;c[3542578]=3;c[3542579]=3;mB(1);c[2113008]=(c[2113008]|0)+1}h[1771269]=.3;c[3542574]=3;h[1771270]=.3;c[3542575]=3;h[1771271]=.3;c[3542576]=3;h[1771272]=.3;c[3542577]=3;h[1771273]=.3;c[3542578]=3;h[1771274]=.3;c[3542579]=3;a[9624792]=0;U=c[2414756]|0;gGz(U|0,0,(c[2411808]|0)-U|0);c[3528554]=0;f43(c[2433592]|0);U=c[3528554]|0;c[2113158]=c[9731360+(U<<2)>>2];a[9660796]=0;a[9660797]=0;a[9660786]=0;a[9660787]=0;c[2415191]=0;a[9660784]=a[9660784]|80;O=c[2433592]|0;ab=c[O+(U*3148|0)+1068>>2]|0;do{if((ab|0)==0){T=c[O+(U*3148|0)+3120>>2]|0;if((T|0)==0){al=0;am=0;an=U;ao=O;break}R=gj[T&4095](-2)|0;T=c[3528554]|0;P=c[2433592]|0;$=c[P+(T*3148|0)+1068>>2]|0;aa=(R&255)<<8;if(($|0)!=0){ap=$;aq=aa;ar=T;as=P;M=66350;break}$=c[P+(T*3148|0)+3120>>2]|0;if(($|0)==0){al=0;am=aa;an=T;ao=P;break}P=gj[$&4095](-1)|0;al=P;am=aa;an=c[3528554]|0;ao=c[2433592]|0}else{ap=ab;aq=(d[ab+254|0]|0)<<8;ar=U;as=O;M=66350}}while(0);if((M|0)==66350){al=a[ap+255|0]|0;am=aq;an=ar;ao=as}O=al&255|am;c[2415188]=O;b[4830376]=O&65535;O=ao+(an*3148|0)|0;if((O|0)!=0){U=O;gGC(U|0,9660752,48)|0}c[9731360+(an<<2)>>2]=c[2113158];c[3528554]=1;f43(ao+3148|0);U=c[3528554]|0;c[2113158]=c[9731360+(U<<2)>>2];a[9660796]=0;a[9660797]=0;a[9660786]=0;a[9660787]=0;c[2415191]=0;a[9660784]=a[9660784]|80;O=c[2433592]|0;ab=c[O+(U*3148|0)+1068>>2]|0;do{if((ab|0)==0){aa=c[O+(U*3148|0)+3120>>2]|0;if((aa|0)==0){at=0;au=0;av=U;aw=O;break}P=gj[aa&4095](-2)|0;aa=c[3528554]|0;$=c[2433592]|0;T=c[$+(aa*3148|0)+1068>>2]|0;R=(P&255)<<8;if((T|0)!=0){ax=T;ay=R;az=aa;aA=$;M=66359;break}T=c[$+(aa*3148|0)+3120>>2]|0;if((T|0)==0){at=0;au=R;av=aa;aw=$;break}$=gj[T&4095](-1)|0;at=$;au=R;av=c[3528554]|0;aw=c[2433592]|0}else{ax=ab;ay=(d[ab+254|0]|0)<<8;az=U;aA=O;M=66359}}while(0);if((M|0)==66359){at=a[ax+255|0]|0;au=ay;av=az;aw=aA}O=at&255|au;c[2415188]=O;b[4830376]=O&65535;O=aw+(av*3148|0)|0;if((O|0)!=0){U=O;gGC(U|0,9660752,48)|0}c[9731360+(av<<2)>>2]=c[2113158];c[3528554]=-1;mB(0);mB(1);a[14113328]=0;a[14115040]=0;a[986984]=0;a[9750984]=0;U=c[642608+(c[2436]<<2)>>2]|0;O=c[U+128>>2]|0;if((c[U+52>>2]&4|0)==0){c[2113068]=O;ab=c[U+132>>2]|0;c[2113070]=ab;c[2443814]=O;c[2440436]=ab;aB=O;aC=ab}else{c[2113070]=O;ab=c[U+132>>2]|0;c[2113068]=ab;c[2440436]=O;c[2443814]=ab;aB=ab;aC=O}O=ag(aB<<1,aC)|0;ab=gGq(O)|0;c[2112926]=ab;if((ab|0)==0){S=0;i=e;return S|0}gGz(ab|0,0,O|0);S=0;i=e;return S|0}}while(0);c[2415048]=0;S=1;i=e;return S|0}function dj$(){var b=0,d=0,e=0,f=0;c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}c[2113160]=0;b=c[2433592]|0;if((b|0)!=0){gGr(b);c[2433592]=0}c[2113008]=0;c[2076598]=0;c[2383582]=0;b=c[2415048]|0;d=0;while(1){if((d|0)>=1024){e=66442;break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==(b|0)){break}else{d=d+1|0}}if((e|0)==66442){c[2415048]=0;a[642592]=0;return 0}gGr(b);c[f>>2]=0;c[2415048]=0;a[642592]=0;return 0}function dj0(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;if((a[9624792]|0)!=0){a[9624792]=0;e=c[2414756]|0;gGz(e|0,0,(c[2411808]|0)-e|0);c[3528554]=0;f43(c[2433592]|0);e=c[3528554]|0;c[2113158]=c[9731360+(e<<2)>>2];a[9660796]=0;a[9660797]=0;a[9660786]=0;a[9660787]=0;c[2415191]=0;a[9660784]=a[9660784]|80;f=c[2433592]|0;g=c[f+(e*3148|0)+1068>>2]|0;do{if((g|0)==0){h=c[f+(e*3148|0)+3120>>2]|0;if((h|0)==0){i=0;j=0;k=e;l=f;break}m=gj[h&4095](-2)|0;h=c[3528554]|0;n=c[2433592]|0;o=c[n+(h*3148|0)+1068>>2]|0;p=(m&255)<<8;if((o|0)!=0){q=o;r=p;s=h;t=n;u=66448;break}o=c[n+(h*3148|0)+3120>>2]|0;if((o|0)==0){i=0;j=p;k=h;l=n;break}n=gj[o&4095](-1)|0;i=n;j=p;k=c[3528554]|0;l=c[2433592]|0}else{q=g;r=d[g+254|0]<<8;s=e;t=f;u=66448}}while(0);if((u|0)==66448){i=a[q+255|0]|0;j=r;k=s;l=t}t=i&255|j;c[2415188]=t;b[4830376]=t&65535;t=l+(k*3148|0)|0;if((t|0)!=0){j=t;gGC(j|0,9660752,48)|0}c[9731360+(k<<2)>>2]=c[2113158];c[3528554]=1;f43(l+3148|0);l=c[3528554]|0;c[2113158]=c[9731360+(l<<2)>>2];a[9660796]=0;a[9660797]=0;a[9660786]=0;a[9660787]=0;c[2415191]=0;a[9660784]=a[9660784]|80;k=c[2433592]|0;j=c[k+(l*3148|0)+1068>>2]|0;do{if((j|0)==0){t=c[k+(l*3148|0)+3120>>2]|0;if((t|0)==0){v=0;w=0;x=l;y=k;break}i=gj[t&4095](-2)|0;t=c[3528554]|0;s=c[2433592]|0;r=c[s+(t*3148|0)+1068>>2]|0;q=(i&255)<<8;if((r|0)!=0){z=r;A=q;B=t;C=s;u=66457;break}r=c[s+(t*3148|0)+3120>>2]|0;if((r|0)==0){v=0;w=q;x=t;y=s;break}s=gj[r&4095](-1)|0;v=s;w=q;x=c[3528554]|0;y=c[2433592]|0}else{z=j;A=d[j+254|0]<<8;B=l;C=k;u=66457}}while(0);if((u|0)==66457){v=a[z+255|0]|0;w=A;x=B;y=C}C=v&255|w;c[2415188]=C;b[4830376]=C&65535;C=y+(x*3148|0)|0;if((C|0)!=0){y=C;gGC(y|0,9660752,48)|0}c[9731360+(x<<2)>>2]=c[2113158];c[3528554]=-1;mB(0);mB(1);a[14113328]=0;a[14115040]=0;a[986984]=0;a[9750984]=0}a[9634562]=-1;a[9634561]=-1;a[9634560]=-1;x=0;y=-1;C=-1;w=-1;do{y=((a[9634144+x|0]&1)<<x^y&255)&255;C=((a[9631920+x|0]&1)<<x^C&255)&255;w=((a[9629848+x|0]&1)<<x^w&255)&255;x=x+1|0;}while((x|0)<8);a[9634560]=y;a[9634561]=C;a[9634562]=w;w=0;C=0;y=0;x=0;L79400:while(1){v=C;B=y;A=x;while(1){if((v|0)>=16){break L79400}c[3528554]=0;f43(c[2433592]|0);c[2113158]=c[9731360+(c[3528554]<<2)>>2];D=v+1|0;z=(D*33333|0|0)/16|0;u=f45(z-B|0)|0;c[2113158]=(c[2113158]|0)+u;E=u+B|0;if((v|0)==15){f44(0);f45(0)|0;a[9660786]=0;f45(0)|0}u=c[3528554]|0;k=c[2433592]|0;l=k+(u*3148|0)|0;if((l|0)!=0){j=l;gGC(j|0,9660752,48)|0}c[9731360+(u<<2)>>2]=c[2113158];c[3528554]=1;f43(k+3148|0);c[2113158]=c[9731360+(c[3528554]<<2)>>2];if(a[986984]|0){f44(1);f45(0)|0;a[9660787]=0;f45(0)|0;a[986984]=0}k=f45(z-A|0)|0;c[2113158]=(c[2113158]|0)+k;F=k+A|0;if((v|0)==15|(v|0)==11|(v|0)==7|(v|0)==3){f44(0);f45(0)|0;a[9660786]=0;f45(0)|0}k=c[3528554]|0;z=(c[2433592]|0)+(k*3148|0)|0;if((z|0)!=0){u=z;gGC(u|0,9660752,48)|0}c[9731360+(k<<2)>>2]=c[2113158];c[3528554]=-1;G=c[2112964]|0;if((G|0)==0){v=D;B=E;A=F}else{break}}A=a[9688]|0?33:0;mF(9756568,G+(w<<1<<1)|0,A,0);w=A+w|0;C=D;y=E;x=F}F=c[2112964]|0;do{if((F|0)!=0){x=a[9688]|0?534:0;if((x|0)==(w|0)){break}mF(9756568,F+(w<<1<<1)|0,x-w|0,0)}}while(0);if((c[2112968]|0)==0){return 0}dj1()|0;return 0}function dj1(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;if((a[9547808]|0)!=0){b=c[2406988]|0;e=c[3530128]|0;f=0;do{g=c[b+(f<<2)>>2]|0;c[e+(f<<2)>>2]=g>>8<<3&2016|g>>>3&31|g>>16<<8&63488;f=f+1|0;}while((f|0)<512)}f=c[3529808]|0;e=c[2387886]|0;b=c[2386258]|0;g=c[2112926]|0;h=c[3530902]|0;i=0;do{j=i<<3&248;k=i>>5;l=k<<3;m=(a[14115040]|0)==0;do{if(m){n=j-(d[f+k|0]|0)|0;if((n|0)>=-7){o=n;p=l;break}o=n+256|0;p=l}else{n=l^248;q=(d[f+(n>>3)|0]|0)+(j^248)|0;if((q|0)<=255){o=q;p=n;break}o=q-256|0;p=n}}while(0);j=p-8|0;l=o-8|0;k=d[e+i|0]|0;n=d[b+i|0]|k<<8&768;q=k>>>2;if(m){Sj(g,n,l,j,q,2,0,h)}else{Sp(g,n,l,j,q,2,0,h)}i=i+1|0;}while((i|0)<1024);i=c[2386514]|0;h=c[3530666]|0;b=124;do{e=d[i+(b|1)|0]|0;o=e<<3&256|d[i+(b|2)|0];p=~e;f=p&64;q=p&128;p=d[i+(b|3)|0]|0;j=d[i+b|0]|0;l=e&31;if((a[14115040]|0)==0){r=j;s=p;t=q;u=f}else{r=240-j|0;s=240-p|0;t=q>>>7^1;u=f>>>6^1}f=r-8|0;q=s-8|0;p=(u|0)!=0;do{if((t|0)==0){if(p){SJ(g,o,q,f,l,3,0,256,h);break}else{SH(g,o,q,f,l,3,0,256,h);break}}else{if(p){SN(g,o,q,f,l,3,0,256,h);break}else{SL(g,o,q,f,l,3,0,256,h);break}}}while(0);b=b-4|0;}while((b|0)>31);R8(c[3530128]|0);return 0}function dj2(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;e=i;i=i+176|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;l=e+80|0;m=e+96|0;n=e+112|0;o=e+128|0;p=e+144|0;q=e+160|0;r=(d|0)==0;if(!r){c[d>>2]=169621}if((b&96|0)==0){i=e;return 0}gGz(q|0,0,12);s=c[2414756]|0;c[q>>2]=s;c[q+4>>2]=(c[2411808]|0)-s;c[q+12>>2]=162152;gj[c[2076592]&4095](q)|0;q=m|0;s=(b&64|0)==0;if((c[2113160]|0)>0&(s^1)){b=m+7|0;m=l|0;t=l+4|0;u=l+12|0;v=k;w=k|0;x=k+4|0;y=k+12|0;z=j;A=j|0;B=j+4|0;C=j+12|0;D=h;E=h|0;F=h+4|0;G=h+12|0;H=0;do{I=c[2433592]|0;J=I+(H*3148|0)+40|0;K=c[J>>2]|0;gGC(q|0,614752,9)|0;a[b]=H+48&255;c[m>>2]=I+(H*3148|0);c[t>>2]=48;c[u>>2]=q;gj[c[2076592]&4095](l)|0;gGz(v|0,0,12);c[w>>2]=I+(H*3148|0)+3136;c[x>>2]=4;c[y>>2]=165288;gj[c[2076592]&4095](k)|0;gGz(z|0,0,12);c[A>>2]=I+(H*3148|0)+3140;c[B>>2]=4;c[C>>2]=501592;gj[c[2076592]&4095](j)|0;gGz(D|0,0,12);c[E>>2]=I+(H*3148|0)+3144;c[F>>2]=4;c[G>>2]=386080;gj[c[2076592]&4095](h)|0;c[J>>2]=K;H=H+1|0;}while((H|0)<(c[2113160]|0))}H=g|0;do{if(!s){do{if(!r){if((c[d>>2]|0)>=169110){break}c[d>>2]=169110}}while(0);if((c[2113008]|0)<=0){break}g=f|0;h=f+4|0;G=f+8|0;F=f+12|0;E=0;do{cC(H|0,531144,(D=i,i=i+8|0,c[D>>2]=E,D)|0)|0;i=D;c[g>>2]=14168888+(E*252|0);c[h>>2]=252;c[G>>2]=0;c[F>>2]=H;gj[c[2076592]&4095](f)|0;E=E+1|0;}while((E|0)<(c[2113008]|0))}}while(0);gGz(p|0,0,12);c[p>>2]=14113328;c[p+4>>2]=1;c[p+12>>2]=191240;gj[c[2076592]&4095](p)|0;gGz(o|0,0,12);c[o>>2]=14115040;c[o+4>>2]=1;c[o+12>>2]=142288;gj[c[2076592]&4095](o)|0;gGz(n|0,0,12);c[n>>2]=9750984;c[n+4>>2]=1;c[n+12>>2]=585016;gj[c[2076592]&4095](n)|0;i=e;return 0}function dj3(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4385740+(b*112|0)>>2];c[a+104>>2]=c[4385744+(b*112|0)>>2];c[a+108>>2]=c[4385748+(b*112|0)>>2];d=0;return d|0}function dj4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=4385640+(b*112|0);e=0;return e|0}function dj5(){a[642592]=1;return dj_()|0}function dj6(b){b=b|0;var c=0;switch(b&65535|0){case 64517:{c=~a[9542946];break};case 64512:{c=~a[9542944];break};case 64518:{c=a[9627224]|0;break};case 64519:{c=a[9627225]|0;break};case 64514:{c=~a[9542945];break};default:{c=0}}return c|0}function dj7(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0;switch(d&65535|0){case 64579:{c[2438364]=e&255;return};case 64518:{c[2438382]=e&255;return};case 64578:{c[2438362]=e&255;return};case 64550:{c[2438374]=e&255;return};case 64519:{c[2438384]=e&255;return};case 64551:{c[2438376]=e&255;return};case 64704:{c[2438360]=e&255;d=c[1836236]|0;f=c[9757320+(d<<2)>>2]|0;if((f|0)!=0){g=f;gGC(g|0,9706056,76)|0}c[9752472+(d<<2)>>2]=c[2433530];c[14113936+(d<<2)>>2]=c[2076596];c[9669104+(d<<2)>>2]=c[3541536];c[1836236]=-1;d=c[2439332]|0;if((d|0)!=0){g=d;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438120];c[2076596]=c[3528486];c[3541536]=c[2417278];c[1836236]=2;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;g=(c[2433530]|0)+12|0;c[2433530]=g;d=c[1836236]|0;f=c[9757320+(d<<2)>>2]|0;if((f|0)!=0){h=f;gGC(h|0,9706056,76)|0}c[9752472+(d<<2)>>2]=g;c[14113936+(d<<2)>>2]=c[2076596];c[9669104+(d<<2)>>2]=c[3541536];c[1836236]=-1;d=c[2439330]|0;if((d|0)!=0){g=d;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;return};case 64582:{c[2438366]=e&255;return};case 64514:{c[2438378]=e&255;return};case 64515:{c[2438380]=e&255;return};case 64547:{c[2438372]=e&255;return};case 64546:{c[2438370]=e&255;return};case 64736:{g=(e&255)<<8;d=g&63488;h=d|65536;c[2429688]=h;f=c[3526992]|0;i=c[9757320+(c[1836236]<<2)>>2]|0;c[i+1036>>2]=f+h;c[i+1040>>2]=f+(d|65792);c[i+1044>>2]=f+(d|66048);c[i+1048>>2]=f+(d|66304);c[i+1052>>2]=f+(d|66560);c[i+1056>>2]=f+(d|66816);c[i+1060>>2]=f+(d|67072);c[i+1064>>2]=f+(g|67328);g=c[2429688]|0;d=f+g|0;c[i+3084>>2]=d;c[i+4108>>2]=d;d=f+(g+256)|0;c[i+3088>>2]=d;c[i+4112>>2]=d;d=f+(g+512)|0;c[i+3092>>2]=d;c[i+4116>>2]=d;d=f+(g+768)|0;c[i+3096>>2]=d;c[i+4120>>2]=d;d=f+(g+1024)|0;c[i+3100>>2]=d;c[i+4124>>2]=d;d=f+(g+1280)|0;c[i+3104>>2]=d;c[i+4128>>2]=d;d=f+(g+1536)|0;c[i+3108>>2]=d;c[i+4132>>2]=d;d=f+(g+1792)|0;c[i+3112>>2]=d;c[i+4136>>2]=d;return};case 64583:{c[2438368]=e&255;return};default:{return}}}function dj8(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(a<<16>>16!=-1024){return}a=(b&255)<<8;b=a&63488;d=b|65536;c[2429686]=d;e=c[3526990]|0;f=c[9757320+(c[1836236]<<2)>>2]|0;c[f+1036>>2]=e+d;c[f+1040>>2]=e+(b|65792);c[f+1044>>2]=e+(b|66048);c[f+1048>>2]=e+(b|66304);c[f+1052>>2]=e+(b|66560);c[f+1056>>2]=e+(b|66816);c[f+1060>>2]=e+(b|67072);c[f+1064>>2]=e+(a|67328);a=c[2429686]|0;b=e+a|0;c[f+3084>>2]=b;c[f+4108>>2]=b;b=e+(a+256)|0;c[f+3088>>2]=b;c[f+4112>>2]=b;b=e+(a+512)|0;c[f+3092>>2]=b;c[f+4116>>2]=b;b=e+(a+768)|0;c[f+3096>>2]=b;c[f+4120>>2]=b;b=e+(a+1024)|0;c[f+3100>>2]=b;c[f+4124>>2]=b;b=e+(a+1280)|0;c[f+3104>>2]=b;c[f+4128>>2]=b;b=e+(a+1536)|0;c[f+3108>>2]=b;c[f+4132>>2]=b;b=e+(a+1792)|0;c[f+3112>>2]=b;c[f+4136>>2]=b;return}function dj9(b){b=b|0;var d=0,e=0,f=0,g=0.0,i=0.0,j=0,k=0,l=0;d=b&65535;if((d|0)==64528){e=c[2438360]&255;return e|0}else if((d|0)==63488){b=c[3541516]|0;f=b+552|0;g=+h[f>>3];do{if(g!=0.0){i=+h[6675];if(g-(i+ +gC[c[2429842]&255]())>0.0){j=a[b+563|0]|-128;break}else{h[f>>3]=0.0;k=66601;break}}else{k=66601}}while(0);if((k|0)==66601){j=a[b+563|0]|0}e=j&-125;return e|0}else if((d|0)==63490){d=c[3541516]|0;j=d+552|0;g=+h[j>>3];do{if(g!=0.0){i=+h[6675];if(g-(i+ +gC[c[2429842]&255]())>0.0){l=a[d+563|0]|-128;break}else{h[j>>3]=0.0;k=66607;break}}else{k=66607}}while(0);if((k|0)==66607){l=a[d+563|0]|0}e=a[d+21012|0]<<5&32|(a[d+21032|0]|-128)&l;return e|0}else{e=0;return e|0}return 0}function dka(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,i=0,j=0,k=0;e=b&65535;if((e|0)==63491){l$(3,d);return}else if((e|0)==63488){b=c[3541516]|0;f=b+512|0;a[b+560|0]=d;a[b+20408|0]=0;g=d&255;if((d&255)<16){c[14168912+((c[2383582]|0)*252|0)>>2]=g&15}if((d-45&255)>=3){return}if((g|0)==45){i=b+568|0;j=a[i]|2;a[i]=j;k=j}else if((g|0)==47){a[b+568|0]=0;k=0}else if((g|0)==46){j=b+568|0;i=a[j]|1;a[j]=i;k=i}else if((g|0)==0){a[b+568|0]=2;k=2}else{k=a[b+568|0]|0}g=k&3;k=c[7461744+(g<<2)>>2]<<1;lI(f,k,k,c[7461728+(g<<2)>>2]<<1);h[b+20928>>3]=+h[b+536>>3];return}else if((e|0)==63489){l$(1,d);return}else if((e|0)==63490){e=c[3541516]|0;a[e+560|0]=d;a[e+20408|0]=1;return}else{return}}function dkb(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7095444+(b*112|0)>>2];c[a+104>>2]=c[7095448+(b*112|0)>>2];c[a+108>>2]=c[7095452+(b*112|0)>>2];d=0;return d|0}function dkc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=7095344+(b*112|0);e=0;return e|0}function dkd(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6003536+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dke(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>46){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6002968+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dkf(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0;e=i;i=i+1816|0;f=e|0;g=e+8|0;j=e+120|0;k=e+128|0;l=e+240|0;m=e+248|0;n=e+360|0;o=e+368|0;p=e+480|0;q=e+488|0;r=e+600|0;s=e+608|0;t=e+720|0;u=e+728|0;v=e+840|0;w=e+848|0;x=e+960|0;y=e+968|0;z=e+1080|0;A=e+1088|0;B=e+1200|0;C=e+1208|0;D=e+1320|0;E=e+1328|0;F=e+1440|0;G=e+1448|0;H=e+1560|0;I=e+1568|0;J=e+1680|0;K=e+1688|0;L=e+1800|0;M=e+1808|0;c[2426804]=0;c[3526992]=0;c[3526990]=131072;c[3526988]=262144;c[2439366]=327680;c[2405710]=458752;c[3526998]=458752;c[3526996]=475136;c[3526994]=481280;c[2438394]=483328;c[2438396]=487424;c[2433134]=491520;c[2439368]=495616;c[2438386]=497664;c[2439370]=499712;c[2411806]=500736;c[2439372]=500736;c[3527008]=631808;c[3527006]=1156096;c[3527002]=1680384;c[3527004]=2728960;N=0;while(1){if((N|0)>=1024){break}O=9638528+(N<<2)|0;if((c[O>>2]|0)==0){P=66665;break}else{N=N+1|0}}do{if((P|0)==66665){N=gGq(2733056)|0;c[O>>2]=N;if((N|0)==0){break}c[2426804]=N;gGz(N|0,0,2733056);c[3526992]=N;c[3526990]=N+131072;c[3526988]=N+262144;c[2439366]=N+327680;Q=N+458752|0;c[2405710]=Q;c[3526998]=Q;c[3526996]=N+475136;c[3526994]=N+481280;c[2438394]=N+483328;c[2438396]=N+487424;c[2433134]=N+491520;c[2439368]=N+495616;c[2438386]=N+497664;c[2439370]=N+499712;Q=N+500736|0;c[2411806]=Q;c[2439372]=Q;c[3527008]=N+631808;c[3527006]=N+1156096;c[3527002]=N+1680384;c[3527004]=N+2728960;c[2414354]=N+2733056;N=0;while(1){if((N|0)>=1024){break}R=9638528+(N<<2)|0;if((c[R>>2]|0)==0){P=66670;break}else{N=N+1|0}}do{if((P|0)==66670){N=gGq(524288)|0;c[R>>2]=N;if((N|0)==0){break}gGz(N|0,0,524288);c[3527e3]=N;N=c[3526992]|0;if((c[3542200]|0)==0){S=1;i=e;return S|0}Q=K+108|0;c[Q>>2]=0;T=K+100|0;c[T>>2]=0;U=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[U&16383](K,0)|0;do{if((c[Q>>2]|0)!=0){U=c[T>>2]|0;c[L>>2]=9534384;V=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[V&16383](L,0,0)|0;if((U|0)<1){S=1;i=e;return S|0}if((gzL(N,0,0)|0)==0){break}else{S=1}i=e;return S|0}}while(0);N=(c[3526992]|0)+65536|0;if((c[3542200]|0)==0){S=1;i=e;return S|0}T=I+108|0;c[T>>2]=0;Q=I+100|0;c[Q>>2]=0;U=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[U&16383](I,1)|0;do{if((c[T>>2]|0)!=0){U=c[Q>>2]|0;c[J>>2]=9534384;V=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[V&16383](J,1,0)|0;if((U|0)<1){S=1;i=e;return S|0}if((gzL(N,0,1)|0)==0){break}else{S=1}i=e;return S|0}}while(0);N=c[3526990]|0;if((c[3542200]|0)==0){S=1;i=e;return S|0}Q=G+108|0;c[Q>>2]=0;T=G+100|0;c[T>>2]=0;U=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[U&16383](G,2)|0;do{if((c[Q>>2]|0)!=0){U=c[T>>2]|0;c[H>>2]=9534384;V=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[V&16383](H,2,0)|0;if((U|0)<1){S=1;i=e;return S|0}if((gzL(N,0,2)|0)==0){break}else{S=1}i=e;return S|0}}while(0);N=(c[3526990]|0)+65536|0;if((c[3542200]|0)==0){S=1;i=e;return S|0}T=E+108|0;c[T>>2]=0;Q=E+100|0;c[Q>>2]=0;U=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[U&16383](E,3)|0;do{if((c[T>>2]|0)!=0){U=c[Q>>2]|0;c[F>>2]=9534384;V=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[V&16383](F,3,0)|0;if((U|0)<1){S=1;i=e;return S|0}if((gzL(N,0,3)|0)==0){break}else{S=1}i=e;return S|0}}while(0);N=c[3526988]|0;if((c[3542200]|0)==0){S=1;i=e;return S|0}Q=C+108|0;c[Q>>2]=0;T=C+100|0;c[T>>2]=0;U=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[U&16383](C,4)|0;do{if((c[Q>>2]|0)!=0){U=c[T>>2]|0;c[D>>2]=9534384;V=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[V&16383](D,4,0)|0;if((U|0)<1){S=1;i=e;return S|0}if((gzL(N,0,4)|0)==0){break}else{S=1}i=e;return S|0}}while(0);N=c[3527e3]|0;gGz(N|0,0,524288);if((c[3542200]|0)==0){S=1;i=e;return S|0}T=A+108|0;c[T>>2]=0;Q=A+100|0;c[Q>>2]=0;U=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[U&16383](A,5)|0;do{if((c[T>>2]|0)!=0){U=c[Q>>2]|0;c[B>>2]=9534384;V=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[V&16383](B,5,0)|0;if((U|0)<1){S=1;i=e;return S|0}if((gzL(N,0,5)|0)==0){break}else{S=1}i=e;return S|0}}while(0);N=c[3527e3]|0;Q=c[2439372]|0;T=0;do{U=T<<6;gGz(Q+U|0,0,64);V=T<<8;W=0;do{X=1<<3-W;Y=(c[703416+(W<<2)>>2]|0)+V|0;Z=0;do{_=Y+(c[1183816+(Z<<2)>>2]|0)|0;$=(Z<<3)+U|0;aa=0;do{ab=_+(c[1934976+(aa<<2)>>2]|0)|0;if(((d[N+((ab|0)/8|0)|0]|0)&128>>>((ab&7)>>>0)|0)!=0){ab=Q+($+aa)|0;a[ab]=(d[ab]|0|X)&255}aa=aa+1|0;}while((aa|0)<8);Z=Z+1|0;}while((Z|0)<8);W=W+1|0;}while((W|0)<4);T=T+1|0;}while((T|0)<2048);gGz(N|0,0,524288);if((c[3542200]|0)==0){S=1;i=e;return S|0}T=y+108|0;c[T>>2]=0;Q=y+100|0;c[Q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](y,6)|0;do{if((c[T>>2]|0)!=0){W=c[Q>>2]|0;c[z>>2]=9534384;U=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[U&16383](z,6,0)|0;if((W|0)<1){S=1;i=e;return S|0}if((gzL(N,0,6)|0)==0){break}else{S=1}i=e;return S|0}}while(0);N=(c[3527e3]|0)+131072|0;if((c[3542200]|0)==0){S=1;i=e;return S|0}Q=w+108|0;c[Q>>2]=0;T=w+100|0;c[T>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](w,7)|0;do{if((c[Q>>2]|0)!=0){W=c[T>>2]|0;c[x>>2]=9534384;U=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[U&16383](x,7,0)|0;if((W|0)<1){S=1;i=e;return S|0}if((gzL(N,0,7)|0)==0){break}else{S=1}i=e;return S|0}}while(0);N=c[3527e3]|0;T=c[3527006]|0;Q=0;do{W=Q<<8;gGz(T+W|0,0,256);U=Q<<10;V=0;do{Z=1<<3-V;X=(c[703416+(V<<2)>>2]|0)+U|0;Y=0;do{aa=X+(c[3946808+(Y<<2)>>2]|0)|0;$=(Y<<4)+W|0;_=0;do{ab=aa+(c[3946872+(_<<2)>>2]|0)|0;if(((d[N+((ab|0)/8|0)|0]|0)&128>>>((ab&7)>>>0)|0)!=0){ab=T+($+_)|0;a[ab]=(d[ab]|0|Z)&255}_=_+1|0;}while((_|0)<16);Y=Y+1|0;}while((Y|0)<16);V=V+1|0;}while((V|0)<4);Q=Q+1|0;}while((Q|0)<2048);gGz(N|0,0,524288);if((c[3542200]|0)==0){S=1;i=e;return S|0}Q=u+108|0;c[Q>>2]=0;T=u+100|0;c[T>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](u,8)|0;do{if((c[Q>>2]|0)!=0){V=c[T>>2]|0;c[v>>2]=9534384;W=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[W&16383](v,8,0)|0;if((V|0)<1){S=1;i=e;return S|0}if((gzL(N,0,8)|0)==0){break}else{S=1}i=e;return S|0}}while(0);N=(c[3527e3]|0)+131072|0;if((c[3542200]|0)==0){S=1;i=e;return S|0}T=s+108|0;c[T>>2]=0;Q=s+100|0;c[Q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](s,9)|0;do{if((c[T>>2]|0)!=0){V=c[Q>>2]|0;c[t>>2]=9534384;W=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[W&16383](t,9,0)|0;if((V|0)<1){S=1;i=e;return S|0}if((gzL(N,0,9)|0)==0){break}else{S=1}i=e;return S|0}}while(0);N=c[3527e3]|0;Q=c[3527008]|0;T=0;do{V=T<<8;gGz(Q+V|0,0,256);W=T<<10;U=0;do{Y=1<<3-U;Z=(c[703416+(U<<2)>>2]|0)+W|0;X=0;do{_=Z+(c[3946808+(X<<2)>>2]|0)|0;$=(X<<4)+V|0;aa=0;do{ab=_+(c[3946872+(aa<<2)>>2]|0)|0;if(((d[N+((ab|0)/8|0)|0]|0)&128>>>((ab&7)>>>0)|0)!=0){ab=Q+($+aa)|0;a[ab]=(d[ab]|0|Y)&255}aa=aa+1|0;}while((aa|0)<16);X=X+1|0;}while((X|0)<16);U=U+1|0;}while((U|0)<4);T=T+1|0;}while((T|0)<2048);gGz(N|0,0,524288);if((c[3542200]|0)==0){S=1;i=e;return S|0}T=q+108|0;c[T>>2]=0;Q=q+100|0;c[Q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](q,10)|0;do{if((c[T>>2]|0)!=0){U=c[Q>>2]|0;c[r>>2]=9534384;V=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[V&16383](r,10,0)|0;if((U|0)<1){S=1;i=e;return S|0}if((gzL(N,0,10)|0)==0){break}else{S=1}i=e;return S|0}}while(0);N=(c[3527e3]|0)+131072|0;if((c[3542200]|0)==0){S=1;i=e;return S|0}Q=o+108|0;c[Q>>2]=0;T=o+100|0;c[T>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](o,11)|0;do{if((c[Q>>2]|0)!=0){U=c[T>>2]|0;c[p>>2]=9534384;V=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[V&16383](p,11,0)|0;if((U|0)<1){S=1;i=e;return S|0}if((gzL(N,0,11)|0)==0){break}else{S=1}i=e;return S|0}}while(0);N=(c[3527e3]|0)+262144|0;if((c[3542200]|0)==0){S=1;i=e;return S|0}T=m+108|0;c[T>>2]=0;Q=m+100|0;c[Q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,12)|0;do{if((c[T>>2]|0)!=0){U=c[Q>>2]|0;c[n>>2]=9534384;V=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[V&16383](n,12,0)|0;if((U|0)<1){S=1;i=e;return S|0}if((gzL(N,0,12)|0)==0){break}else{S=1}i=e;return S|0}}while(0);N=(c[3527e3]|0)+393216|0;if((c[3542200]|0)==0){S=1;i=e;return S|0}Q=k+108|0;c[Q>>2]=0;T=k+100|0;c[T>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,13)|0;do{if((c[Q>>2]|0)!=0){U=c[T>>2]|0;c[l>>2]=9534384;V=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[V&16383](l,13,0)|0;if((U|0)<1){S=1;i=e;return S|0}if((gzL(N,0,13)|0)==0){break}else{S=1}i=e;return S|0}}while(0);N=c[3527e3]|0;T=c[3527002]|0;Q=0;while(1){U=Q<<8;gGz(T+U|0,0,256);V=Q<<9;W=0;do{X=1<<3-W;Y=(c[703416+(W<<2)>>2]|0)+V|0;Z=0;do{aa=Y+(c[597800+(Z<<2)>>2]|0)|0;$=(Z<<4)+U|0;_=0;do{ab=aa+(c[4969816+(_<<2)>>2]|0)|0;if(((d[N+((ab|0)/8|0)|0]|0)&128>>>((ab&7)>>>0)|0)!=0){ab=T+($+_)|0;a[ab]=(d[ab]|0|X)&255}_=_+1|0;}while((_|0)<16);Z=Z+1|0;}while((Z|0)<16);W=W+1|0;}while((W|0)<4);W=Q+1|0;if((W|0)<4096){Q=W}else{ac=0;break}}while(1){if((ac|0)>=1024){break}ad=9638528+(ac<<2)|0;if((c[ad>>2]|0)==(N|0)){P=66770;break}else{ac=ac+1|0}}if((P|0)==66770){gGr(N);c[ad>>2]=0}c[3527e3]=0;Q=c[2439366]|0;if((c[3542200]|0)==0){S=1;i=e;return S|0}T=g+108|0;c[T>>2]=0;W=g+100|0;c[W>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,14)|0;do{if((c[T>>2]|0)!=0){U=c[W>>2]|0;c[j>>2]=9534384;V=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[V&16383](j,14,0)|0;if((U|0)<1){S=1;i=e;return S|0}if((gzL(Q,0,14)|0)==0){break}else{S=1}i=e;return S|0}}while(0);fwR(0);Q=c[2439330]|0;W=(Q|0)==0;if(!W){T=Q;gGC(9706056,T|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];T=c[3528484]|0;c[2076596]=T;N=c[2417276]|0;c[3541536]=N;c[1836236]=0;c[Q+4180>>2]=856;c[Q+4184>>2]=1034;U=c[3526992]|0;V=0;Z=0;while(1){c[Q+76+(Z<<2)>>2]=U+(Z<<8);X=V+1&65535;if((X&65535)>127){ae=0;af=0;break}else{V=X;Z=X&65535}}while(1){Z=U+(af<<8)|0;c[Q+76+(af+512<<2)>>2]=Z;c[Q+76+(af+768<<2)>>2]=Z;Z=ae+1&65535;if((Z&65535)>127){break}else{ae=Z;af=Z&65535}}Z=c[3526998]|0;V=128;X=128;while(1){c[Q+76+(X<<2)>>2]=Z+((X<<8)-32768);Y=V+1&65535;if((Y&65535)>159){ah=128;ai=128;break}else{V=Y;X=Y&65535}}while(1){c[Q+76+(ai+256<<2)>>2]=Z+((ai<<8)-32768);X=ah+1&65535;if((X&65535)>159){aj=128;ak=128;break}else{ah=X;ai=X&65535}}while(1){X=Z+((ak<<8)-32768)|0;c[Q+76+(ak+512<<2)>>2]=X;c[Q+76+(ak+768<<2)>>2]=X;X=aj+1&65535;if((X&65535)>159){break}else{aj=X;ak=X&65535}}X=c[2438394]|0;c[Q+716>>2]=X;c[Q+720>>2]=X+256;c[Q+724>>2]=X+512;c[Q+728>>2]=X+768;c[Q+732>>2]=X+1024;c[Q+736>>2]=X+1280;c[Q+740>>2]=X+1536;c[Q+744>>2]=X+1792;c[Q+748>>2]=X+2048;c[Q+752>>2]=X+2304;c[Q+756>>2]=X+2560;c[Q+760>>2]=X+2816;c[Q+764>>2]=X+3072;c[Q+768>>2]=X+3328;c[Q+772>>2]=X+3584;c[Q+776>>2]=X+3840;V=160;Y=160;while(1){c[Q+76+(Y+256<<2)>>2]=X+((Y<<8)-40960);_=V+1&65535;if((_&65535)>175){al=160;am=160;break}else{V=_;Y=_&65535}}while(1){Y=X+((am<<8)-40960)|0;c[Q+76+(am+512<<2)>>2]=Y;c[Q+76+(am+768<<2)>>2]=Y;Y=al+1&65535;if((Y&65535)>175){break}else{al=Y;am=Y&65535}}c[Q+780>>2]=Z+8192;c[Q+784>>2]=Z+8448;c[Q+788>>2]=Z+8704;c[Q+792>>2]=Z+8960;c[Q+796>>2]=Z+9216;c[Q+800>>2]=Z+9472;c[Q+804>>2]=Z+9728;c[Q+808>>2]=Z+9984;c[Q+812>>2]=Z+10240;c[Q+816>>2]=Z+10496;c[Q+820>>2]=Z+10752;c[Q+824>>2]=Z+11008;c[Q+828>>2]=Z+11264;c[Q+832>>2]=Z+11520;c[Q+836>>2]=Z+11776;c[Q+840>>2]=Z+12032;X=176;Y=176;while(1){c[Q+76+(Y+256<<2)>>2]=Z+((Y<<8)-36864);V=X+1&65535;if((V&65535)>191){an=176;ao=176;break}else{X=V;Y=V&65535}}while(1){Y=Z+((ao<<8)-36864)|0;c[Q+76+(ao+512<<2)>>2]=Y;c[Q+76+(ao+768<<2)>>2]=Y;Y=an+1&65535;if((Y&65535)>191){break}else{an=Y;ao=Y&65535}}Y=c[2438396]|0;c[Q+844>>2]=Y;c[Q+848>>2]=Y+256;c[Q+852>>2]=Y+512;c[Q+856>>2]=Y+768;c[Q+860>>2]=Y+1024;c[Q+864>>2]=Y+1280;c[Q+868>>2]=Y+1536;c[Q+872>>2]=Y+1792;c[Q+876>>2]=Y+2048;c[Q+880>>2]=Y+2304;c[Q+884>>2]=Y+2560;c[Q+888>>2]=Y+2816;c[Q+892>>2]=Y+3072;c[Q+896>>2]=Y+3328;c[Q+900>>2]=Y+3584;c[Q+904>>2]=Y+3840;X=192;V=192;while(1){c[Q+76+(V+256<<2)>>2]=Y+((V<<8)-49152);_=X+1&65535;if((_&65535)>207){ap=192;aq=192;break}else{X=_;V=_&65535}}while(1){V=Y+((aq<<8)-49152)|0;c[Q+76+(aq+512<<2)>>2]=V;c[Q+76+(aq+768<<2)>>2]=V;V=ap+1&65535;if((V&65535)>207){break}else{ap=V;aq=V&65535}}c[Q+908>>2]=Z+12288;c[Q+912>>2]=Z+12544;c[Q+916>>2]=Z+12800;c[Q+920>>2]=Z+13056;c[Q+924>>2]=Z+13312;c[Q+928>>2]=Z+13568;c[Q+932>>2]=Z+13824;c[Q+936>>2]=Z+14080;c[Q+940>>2]=Z+14336;c[Q+944>>2]=Z+14592;c[Q+948>>2]=Z+14848;c[Q+952>>2]=Z+15104;c[Q+956>>2]=Z+15360;c[Q+960>>2]=Z+15616;c[Q+964>>2]=Z+15872;c[Q+968>>2]=Z+16128;Y=208;V=208;while(1){c[Q+76+(V+256<<2)>>2]=Z+((V<<8)-40960);X=Y+1&65535;if((X&65535)>223){ar=208;as=208;break}else{Y=X;V=X&65535}}while(1){V=Z+((as<<8)-40960)|0;c[Q+76+(as+512<<2)>>2]=V;c[Q+76+(as+768<<2)>>2]=V;V=ar+1&65535;if((V&65535)>223){break}else{ar=V;as=V&65535}}Z=c[2433134]|0;c[Q+972>>2]=Z;c[Q+976>>2]=Z+256;c[Q+980>>2]=Z+512;c[Q+984>>2]=Z+768;c[Q+988>>2]=Z+1024;c[Q+992>>2]=Z+1280;c[Q+996>>2]=Z+1536;c[Q+1e3>>2]=Z+1792;c[Q+1004>>2]=Z+2048;c[Q+1008>>2]=Z+2304;c[Q+1012>>2]=Z+2560;c[Q+1016>>2]=Z+2816;c[Q+1020>>2]=Z+3072;c[Q+1024>>2]=Z+3328;c[Q+1028>>2]=Z+3584;c[Q+1032>>2]=Z+3840;V=224;Y=224;while(1){c[Q+76+(Y+256<<2)>>2]=Z+((Y<<8)-57344);X=V+1&65535;if((X&65535)>239){at=224;au=224;break}else{V=X;Y=X&65535}}while(1){Y=Z+((au<<8)-57344)|0;c[Q+76+(au+512<<2)>>2]=Y;c[Q+76+(au+768<<2)>>2]=Y;Y=at+1&65535;if((Y&65535)>239){break}else{at=Y;au=Y&65535}}Z=U+65536|0;c[Q+1036>>2]=Z;Y=U+65792|0;c[Q+1040>>2]=Y;V=U+66048|0;c[Q+1044>>2]=V;X=U+66304|0;c[Q+1048>>2]=X;_=U+66560|0;c[Q+1052>>2]=_;$=U+66816|0;c[Q+1056>>2]=$;aa=U+67072|0;c[Q+1060>>2]=aa;ab=U+67328|0;c[Q+1064>>2]=ab;c[Q+3084>>2]=Z;c[Q+4108>>2]=Z;c[Q+3088>>2]=Y;c[Q+4112>>2]=Y;c[Q+3092>>2]=V;c[Q+4116>>2]=V;c[Q+3096>>2]=X;c[Q+4120>>2]=X;c[Q+3100>>2]=_;c[Q+4124>>2]=_;c[Q+3104>>2]=$;c[Q+4128>>2]=$;c[Q+3108>>2]=aa;c[Q+4132>>2]=aa;c[Q+3112>>2]=ab;c[Q+4136>>2]=ab;ab=c[2439370]|0;c[Q+1068>>2]=ab;aa=ab+256|0;c[Q+1072>>2]=aa;$=ab+512|0;c[Q+1076>>2]=$;_=ab+768|0;c[Q+1080>>2]=_;c[Q+2092>>2]=ab;c[Q+2096>>2]=aa;c[Q+2100>>2]=$;c[Q+2104>>2]=_;c[Q+3116>>2]=ab;c[Q+4140>>2]=ab;c[Q+3120>>2]=aa;c[Q+4144>>2]=aa;c[Q+3124>>2]=$;c[Q+4148>>2]=$;c[Q+3128>>2]=_;c[Q+4152>>2]=_;if(!W){_=Q;gGC(_|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=T;c[2417276]=N;c[1836236]=-1;fwR(1);_=c[2439331]|0;$=(_|0)==0;if(!$){aa=_;gGC(9706056,aa|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];aa=c[3528485]|0;c[2076596]=aa;ab=c[2417277]|0;c[3541536]=ab;c[1836236]=1;c[_+4184>>2]=84;X=c[3526990]|0;V=0;Y=0;while(1){c[_+76+(Y<<2)>>2]=X+(Y<<8);Z=V+1&65535;if((Z&65535)>191){av=0;aw=0;break}else{V=Z;Y=Z&65535}}while(1){Y=X+(aw<<8)|0;c[_+76+(aw+512<<2)>>2]=Y;c[_+76+(aw+768<<2)>>2]=Y;Y=av+1&65535;if((Y&65535)>191){break}else{av=Y;aw=Y&65535}}Y=c[3526996]|0;c[_+844>>2]=Y;c[_+848>>2]=Y+256;c[_+852>>2]=Y+512;c[_+856>>2]=Y+768;c[_+860>>2]=Y+1024;c[_+864>>2]=Y+1280;c[_+868>>2]=Y+1536;c[_+872>>2]=Y+1792;c[_+876>>2]=Y+2048;c[_+880>>2]=Y+2304;c[_+884>>2]=Y+2560;c[_+888>>2]=Y+2816;c[_+892>>2]=Y+3072;c[_+896>>2]=Y+3328;c[_+900>>2]=Y+3584;c[_+904>>2]=Y+3840;V=192;N=192;while(1){c[_+76+(N+256<<2)>>2]=Y+((N<<8)-49152);T=V+1&65535;if((T&65535)>207){ax=192;ay=192;break}else{V=T;N=T&65535}}while(1){N=Y+((ay<<8)-49152)|0;c[_+76+(ay+512<<2)>>2]=N;c[_+76+(ay+768<<2)>>2]=N;N=ax+1&65535;if((N&65535)>207){break}else{ax=N;ay=N&65535}}N=c[2439368]|0;c[_+908>>2]=N;V=N+256|0;c[_+912>>2]=V;T=N+512|0;c[_+916>>2]=T;Q=N+768|0;c[_+920>>2]=Q;W=N+1024|0;c[_+924>>2]=W;U=N+1280|0;c[_+928>>2]=U;Z=N+1536|0;c[_+932>>2]=Z;az=N+1792|0;c[_+936>>2]=az;c[_+1932>>2]=N;c[_+1936>>2]=V;c[_+1940>>2]=T;c[_+1944>>2]=Q;c[_+1948>>2]=W;c[_+1952>>2]=U;c[_+1956>>2]=Z;c[_+1960>>2]=az;c[_+2956>>2]=N;c[_+3980>>2]=N;c[_+2960>>2]=V;c[_+3984>>2]=V;c[_+2964>>2]=T;c[_+3988>>2]=T;c[_+2968>>2]=Q;c[_+3992>>2]=Q;c[_+2972>>2]=W;c[_+3996>>2]=W;c[_+2976>>2]=U;c[_+4e3>>2]=U;c[_+2980>>2]=Z;c[_+4004>>2]=Z;c[_+2984>>2]=az;c[_+4008>>2]=az;az=Y+4096|0;c[_+940>>2]=az;Z=Y+4352|0;c[_+944>>2]=Z;U=Y+4608|0;c[_+948>>2]=U;W=Y+4864|0;c[_+952>>2]=W;Q=Y+5120|0;c[_+956>>2]=Q;T=Y+5376|0;c[_+960>>2]=T;V=Y+5632|0;c[_+964>>2]=V;N=Y+5888|0;c[_+968>>2]=N;c[_+1964>>2]=az;c[_+1968>>2]=Z;c[_+1972>>2]=U;c[_+1976>>2]=W;c[_+1980>>2]=Q;c[_+1984>>2]=T;c[_+1988>>2]=V;c[_+1992>>2]=N;c[_+2988>>2]=az;c[_+4012>>2]=az;c[_+2992>>2]=Z;c[_+4016>>2]=Z;c[_+2996>>2]=U;c[_+4020>>2]=U;c[_+3e3>>2]=W;c[_+4024>>2]=W;c[_+3004>>2]=Q;c[_+4028>>2]=Q;c[_+3008>>2]=T;c[_+4032>>2]=T;c[_+3012>>2]=V;c[_+4036>>2]=V;c[_+3016>>2]=N;c[_+4040>>2]=N;N=c[2438386]|0;c[_+972>>2]=N;V=N+256|0;c[_+976>>2]=V;T=N+512|0;c[_+980>>2]=T;Q=N+768|0;c[_+984>>2]=Q;W=N+1024|0;c[_+988>>2]=W;U=N+1280|0;c[_+992>>2]=U;Z=N+1536|0;c[_+996>>2]=Z;az=N+1792|0;c[_+1e3>>2]=az;c[_+1996>>2]=N;c[_+2e3>>2]=V;c[_+2004>>2]=T;c[_+2008>>2]=Q;c[_+2012>>2]=W;c[_+2016>>2]=U;c[_+2020>>2]=Z;c[_+2024>>2]=az;c[_+3020>>2]=N;c[_+4044>>2]=N;c[_+3024>>2]=V;c[_+4048>>2]=V;c[_+3028>>2]=T;c[_+4052>>2]=T;c[_+3032>>2]=Q;c[_+4056>>2]=Q;c[_+3036>>2]=W;c[_+4060>>2]=W;c[_+3040>>2]=U;c[_+4064>>2]=U;c[_+3044>>2]=Z;c[_+4068>>2]=Z;c[_+3048>>2]=az;c[_+4072>>2]=az;az=X+65536|0;c[_+1036>>2]=az;Z=X+65792|0;c[_+1040>>2]=Z;U=X+66048|0;c[_+1044>>2]=U;W=X+66304|0;c[_+1048>>2]=W;Q=X+66560|0;c[_+1052>>2]=Q;T=X+66816|0;c[_+1056>>2]=T;V=X+67072|0;c[_+1060>>2]=V;N=X+67328|0;c[_+1064>>2]=N;c[_+3084>>2]=az;c[_+4108>>2]=az;c[_+3088>>2]=Z;c[_+4112>>2]=Z;c[_+3092>>2]=U;c[_+4116>>2]=U;c[_+3096>>2]=W;c[_+4120>>2]=W;c[_+3100>>2]=Q;c[_+4124>>2]=Q;c[_+3104>>2]=T;c[_+4128>>2]=T;c[_+3108>>2]=V;c[_+4132>>2]=V;c[_+3112>>2]=N;c[_+4136>>2]=N;N=c[2439370]|0;c[_+1068>>2]=N;V=N+256|0;c[_+1072>>2]=V;T=N+512|0;c[_+1076>>2]=T;Q=N+768|0;c[_+1080>>2]=Q;c[_+2092>>2]=N;c[_+2096>>2]=V;c[_+2100>>2]=T;c[_+2104>>2]=Q;c[_+3116>>2]=N;c[_+4140>>2]=N;c[_+3120>>2]=V;c[_+4144>>2]=V;c[_+3124>>2]=T;c[_+4148>>2]=T;c[_+3128>>2]=Q;c[_+4152>>2]=Q;if(!$){Q=_;gGC(Q|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=aa;c[2417277]=ab;c[1836236]=-1;fwR(2);Q=c[2439332]|0;T=(Q|0)==0;if(!T){V=Q;gGC(9706056,V|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438120];V=c[3528486]|0;c[2076596]=V;N=c[2417278]|0;c[3541536]=N;c[1836236]=2;c[Q+4180>>2]=2296;c[Q+4184>>2]=3136;W=c[3526988]|0;U=0;Z=0;while(1){c[Q+76+(Z<<2)>>2]=W+(Z<<8);az=U+1&65535;if((az&65535)>191){aA=0;aB=0;break}else{U=az;Z=az&65535}}while(1){Z=W+(aB<<8)|0;c[Q+76+(aB+512<<2)>>2]=Z;c[Q+76+(aB+768<<2)>>2]=Z;Z=aA+1&65535;if((Z&65535)>191){break}else{aA=Z;aB=Z&65535}}W=c[3526994]|0;c[Q+1036>>2]=W;Z=W+256|0;c[Q+1040>>2]=Z;U=W+512|0;c[Q+1044>>2]=U;ab=W+768|0;c[Q+1048>>2]=ab;aa=W+1024|0;c[Q+1052>>2]=aa;_=W+1280|0;c[Q+1056>>2]=_;$=W+1536|0;c[Q+1060>>2]=$;X=W+1792|0;c[Q+1064>>2]=X;c[Q+2060>>2]=W;c[Q+2064>>2]=Z;c[Q+2068>>2]=U;c[Q+2072>>2]=ab;c[Q+2076>>2]=aa;c[Q+2080>>2]=_;c[Q+2084>>2]=$;c[Q+2088>>2]=X;c[Q+3084>>2]=W;c[Q+4108>>2]=W;c[Q+3088>>2]=Z;c[Q+4112>>2]=Z;c[Q+3092>>2]=U;c[Q+4116>>2]=U;c[Q+3096>>2]=ab;c[Q+4120>>2]=ab;c[Q+3100>>2]=aa;c[Q+4124>>2]=aa;c[Q+3104>>2]=_;c[Q+4128>>2]=_;c[Q+3108>>2]=$;c[Q+4132>>2]=$;c[Q+3112>>2]=X;c[Q+4136>>2]=X;if(!T){X=Q;gGC(X|0,9706056,76)|0}c[2438120]=c[2433530];c[3528486]=V;c[2417278]=N;c[1836236]=-1;X=c[642608+(c[2436]<<2)>>2]|0;$=c[X+128>>2]|0;if((c[X+52>>2]&4|0)==0){c[2113068]=$;_=c[X+132>>2]|0;c[2113070]=_;c[2443814]=$;c[2440436]=_;aC=$;aD=_}else{c[2113070]=$;_=c[X+132>>2]|0;c[2113068]=_;c[2440436]=$;c[2443814]=_;aC=_;aD=$}$=ag(aC<<1,aD)|0;_=gGq($)|0;c[2112926]=_;if((_|0)!=0){gGz(_|0,0,$|0)}c[2424]=5917;c[M>>2]=131072;c[f>>2]=c[2439366];c[2438228]=0;c[2433526]=0;c[2406676]=0;c[3528472]=0;c[2429844]=5518;c[2429842]=4;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;$=a[9680]|0;_=$?32e3:0;if($){c[2427018]=1318;if(a[9624]|0){$=_*3|0;X=55555;while(1){if((X|0)>($|0)){X=X>>1}else{break}}c[2429376]=X;c[3542120]=2356;c[2443878]=(X<<16>>>0)/32e3|0;c[2429602]=0;aE=X}else{c[2429376]=_;c[3542120]=1948;aE=_}$=mD(c[2383582]|0,8e6,aE)|0;c[3542220]=4002;N=c[2076598]|0;if(($|0)==0){$=N+1|0;c[2076598]=$;aF=$}else{aF=N}c[2383582]=(c[2113008]|0)-aF;lX(c[2429376]|0,f,M);N=gGq(49152)|0;c[2406682]=N;gGz(N|0,0,49152);N=gGq(16384)|0;c[2385410]=N;gGz(N|0,0,16384);c[2433542]=0;c[2433576]=0;h[745409]=1.0;h[745408]=1.0;h[745407]=1.0;c[2436790]=1;c[2436788]=2;a[3203288]=1}else{c[2427018]=1962;c[3542120]=990;N=mD(c[2383582]|0,8e6,11025)|0;c[3542220]=4002;$=c[2076598]|0;if((N|0)==0){N=$+1|0;c[2076598]=N;aG=N}else{aG=$}c[2383582]=(c[2113008]|0)-aG;lX(11025,f,M)}c[2438228]=4e6;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=511;h[745409]=1.0;c[2436790]=3;h[745408]=1.0;c[2436788]=3;h[745407]=.5;a[3203288]=1;c[2438380]=0;c[2438378]=0;c[2438384]=0;c[2438382]=0;c[2438372]=0;c[2438370]=0;c[2438376]=0;c[2438374]=0;c[2438364]=0;c[2438362]=0;c[2438368]=0;c[2438366]=0;c[2438360]=0;$=c[2439330]|0;N=($|0)==0;if(!N){V=$;gGC(9706056,V|0,76)|0}V=c[2438118]|0;c[2433530]=V;Q=c[3528484]|0;c[2076596]=Q;T=c[2417276]|0;c[3541536]=T;c[1836236]=0;gGz(9706056,0,76);if(!N){N=$;gGC(N|0,9706056,76)|0}c[2438118]=V;c[3528484]=Q;c[2417276]=T;c[1836236]=-1;T=c[2439331]|0;Q=(T|0)==0;if(!Q){V=T;gGC(9706056,V|0,76)|0}V=c[2438119]|0;c[2433530]=V;N=c[3528485]|0;c[2076596]=N;$=c[2417277]|0;c[3541536]=$;c[1836236]=1;gGz(9706056,0,76);if(!Q){Q=T;gGC(Q|0,9706056,76)|0}c[2438119]=V;c[3528485]=N;c[2417277]=$;c[1836236]=-1;$=c[2439332]|0;N=($|0)==0;if(!N){V=$;gGC(9706056,V|0,76)|0}V=c[2438120]|0;c[2433530]=V;Q=c[3528486]|0;c[2076596]=Q;T=c[2417278]|0;c[3541536]=T;c[1836236]=2;gGz(9706056,0,76);if(!N){N=$;gGC(N|0,9706056,76)|0}c[2438120]=V;c[3528486]=Q;c[2417278]=T;c[1836236]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;l_(0);S=0;i=e;return S|0}}while(0);c[3527e3]=0;S=1;i=e;return S|0}}while(0);c[2426804]=0;S=1;i=e;return S|0}function dkg(){var b=0,d=0,e=0,f=0;fwZ();c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}b=c[3541516]|0;if((b|0)!=0){gGr(b|0);c[3541516]=0}c[2113008]=0;c[2076598]=0;c[2383582]=0;c[2438228]=0;c[2433526]=0;c[2406676]=0;c[3528472]=0;b=c[2406682]|0;if((b|0)!=0){gGr(b);c[2406682]=0}b=c[2385410]|0;if((b|0)!=0){gGr(b);c[2385410]=0}b=c[2426804]|0;d=0;while(1){if((d|0)>=1024){break}e=9638528+(d<<2)|0;if((c[e>>2]|0)==(b|0)){f=66908;break}else{d=d+1|0}}if((f|0)==66908){gGr(b);c[e>>2]=0}c[2426804]=0;c[2438378]=0;c[2438380]=0;c[2438382]=0;c[2438384]=0;c[2438370]=0;c[2438372]=0;c[2438374]=0;c[2438376]=0;c[2438362]=0;c[2438364]=0;c[2438366]=0;c[2438368]=0;c[2438360]=0;a[632368]=0;return 0}function dkh(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;if((a[9542936]|0)!=0){c[2438380]=0;c[2438378]=0;c[2438384]=0;c[2438382]=0;c[2438372]=0;c[2438370]=0;c[2438376]=0;c[2438374]=0;c[2438364]=0;c[2438362]=0;c[2438368]=0;c[2438366]=0;c[2438360]=0;d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=i;c[1836236]=-1;i=c[2439331]|0;g=(i|0)==0;if(!g){f=i;gGC(9706056,f|0,76)|0}f=c[2438119]|0;c[2433530]=f;e=c[3528485]|0;c[2076596]=e;d=c[2417277]|0;c[3541536]=d;c[1836236]=1;gGz(9706056,0,76);if(!g){g=i;gGC(g|0,9706056,76)|0}c[2438119]=f;c[3528485]=e;c[2417277]=d;c[1836236]=-1;d=c[2439332]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438120]|0;c[2433530]=f;g=c[3528486]|0;c[2076596]=g;i=c[2417278]|0;c[3541536]=i;c[1836236]=2;gGz(9706056,0,76);if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438120]=f;c[3528486]=g;c[2417278]=i;c[1836236]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;l_(0)}a[9542946]=3;i=a[9753569]<<1&2|a[9753568]&1;g=a[9753561]<<1&2|a[9753560]&1;f=a[9753570]<<2&4|i|a[9753571]<<3&8|a[9753572]<<4&16|a[9753573]<<5&32;e=a[9753562]<<2&4|g|a[9753563]<<3&8|a[9753564]<<4&16|a[9753565]<<5&32;a[9542944]=f;a[9542945]=e;if((a[9753552]|0)==0){j=3}else{a[9542946]=2;j=2}if((a[9753553]|0)==0){k=j}else{d=j-2&255;a[9542946]=d;k=d}if((a[9753554]|0)==0){l=k}else{d=k|4;a[9542946]=d;l=d}if((a[9753555]|0)!=0){a[9542946]=l|8}if(i<<24>>24==3){i=f&-4;a[9542944]=i;m=i}else{m=f}if((m&12)==12){a[9542944]=m&-13}if(g<<24>>24==3){g=e&-4;a[9542945]=g;n=g}else{n=e}if((n&12)==12){a[9542945]=n&-13}n=c[2438]|0;e=gGU(n,(n|0)<0|0?-1:0,8e6,0)|0;n=~~((+(e>>>0)+ +(K|0)*4294967296.0)/15147.52);c[2440548]=n;c[2440488]=n;a[6517912]=1;c[2443992]=0;c[2444042]=0;n=c[2385548]|0;if((n|0)>0){gGz(9752472,0,((n|0)>1?n<<2:4)|0)}c[2433530]=0;n=0;while(1){e=c[2439330]|0;if((e|0)!=0){g=e;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;g=c[2438118]|0;c[2433530]=g;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;m=n+1|0;f=(ag(c[2440548]|0,m)|0)/262|0;i=c[2444042]|0;l=f-i|0;do{if((l|0)<1){o=0;p=i}else{if((a[e+4188|0]|0)==0){f=gfc(l)|0;c[2433530]=(c[2433530]|0)+f;o=f;p=c[2444042]|0;break}else{c[2433530]=g+l;o=l;p=i;break}}}while(0);c[2444042]=p+o;if((n|0)==261){a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0;q=1}else{q=0}i=c[1836236]|0;l=c[9757320+(i<<2)>>2]|0;if((l|0)!=0){g=l;gGC(g|0,9706056,76)|0}c[9752472+(i<<2)>>2]=c[2433530];c[14113936+(i<<2)>>2]=c[2076596];c[9669104+(i<<2)>>2]=c[3541536];c[1836236]=-1;i=c[2439331]|0;if((i|0)!=0){g=i;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;g=c[2438119]|0;c[2433530]=g;c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;l=(ag(c[2440488]|0,m)|0)/262|0;e=c[2443992]|0;f=l-e|0;do{if((f|0)<1){r=0;s=e}else{if((a[i+4188|0]|0)==0){l=gfc(f)|0;c[2433530]=(c[2433530]|0)+l;r=l;s=c[2443992]|0;break}else{c[2433530]=g+f;r=f;s=e;break}}}while(0);c[2443992]=s+r;if(q){a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0}e=c[1836236]|0;f=c[9757320+(e<<2)>>2]|0;if((f|0)!=0){g=f;gGC(g|0,9706056,76)|0}c[9752472+(e<<2)>>2]=c[2433530];c[14113936+(e<<2)>>2]=c[2076596];c[9669104+(e<<2)>>2]=c[3541536];c[1836236]=-1;e=c[2439332]|0;if((e|0)!=0){g=e;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438120];c[2076596]=c[3528486];c[3541536]=c[2417278];c[1836236]=2;Sb(ag(a[6517912]|0?258:0,n)|0);g=c[1836236]|0;e=c[9757320+(g<<2)>>2]|0;if((e|0)!=0){f=e;gGC(f|0,9706056,76)|0}c[9752472+(g<<2)>>2]=c[2433530];c[14113936+(g<<2)>>2]=c[2076596];c[9669104+(g<<2)>>2]=c[3541536];c[1836236]=-1;if((m|0)<262){n=m}else{break}}n=c[2439332]|0;if((n|0)!=0){q=n;gGC(9706056,q|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438120];c[2076596]=c[3528486];c[3541536]=c[2417278];c[1836236]=2;q=a[6517912]|0?67601:0;n=gGU(q,0,2048e6,0)|0;r=c[2438228]|0;s=gGS(n,K,r,(r|0)<0|0?-1:0)|0;r=s;Sb(q);q=c[2443830]|0;if((q|0)<1073676288){c[2443830]=q-r}q=c[2443831]|0;if((q|0)<1073676288){c[2443831]=q-r}q=(c[3528512]|0)-r|0;c[3528512]=(q|0)<0?0:q;q=c[2112964]|0;if((q|0)!=0){gg[c[3542120]&4095](q,a[9688]|0?534:0)}q=c[1836236]|0;r=c[9757320+(q<<2)>>2]|0;if((r|0)!=0){s=r;gGC(s|0,9706056,76)|0}c[9752472+(q<<2)>>2]=c[2433530];c[14113936+(q<<2)>>2]=c[2076596];c[9669104+(q<<2)>>2]=c[3541536];c[1836236]=-1;if((c[2112968]|0)==0){return 0}gu[c[2922200+((a[632368]&1)<<2)>>2]&16383]();return 0}function dki(a,d){a=a|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;e=i;i=i+416|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;l=e+80|0;m=e+96|0;n=e+112|0;o=e+128|0;p=e+144|0;q=e+160|0;r=e+176|0;s=e+192|0;t=e+208|0;u=e+224|0;v=e+240|0;w=e+256|0;x=e+272|0;y=e+288|0;z=e+304|0;A=e+320|0;B=e+336|0;C=e+352|0;D=e+368|0;E=e+384|0;F=e+400|0;G=(d|0)==0;if(!G){c[d>>2]=169761}if((a&32|0)!=0){gGz(F|0,0,12);H=c[2405710]|0;c[F>>2]=H;c[F+4>>2]=(c[2411806]|0)-H;c[F+12>>2]=162152;H=c[2076592]|0;gj[H&4095](F)|0}if((a&64|0)==0){i=e;return 0}fw$(a);do{if(!G){if((c[d>>2]|0)>=169249){break}c[d>>2]=169249}}while(0);gGz(l|0,0,12);c[l>>2]=9775320;c[l+4>>2]=8;c[l+12>>2]=111920;gj[c[2076592]&4095](l)|0;gGz(k|0,0,12);c[k>>2]=9775288;c[k+4>>2]=8;c[k+12>>2]=478936;gj[c[2076592]&4095](k)|0;gGz(j|0,0,12);c[j>>2]=53400;c[j+4>>2]=8;c[j+12>>2]=398448;gj[c[2076592]&4095](j)|0;gGz(h|0,0,12);c[h>>2]=14114048;c[h+4>>2]=4;c[h+12>>2]=287368;gj[c[2076592]&4095](h)|0;h=g|0;do{if(!G){if((c[d>>2]|0)>=169110){break}c[d>>2]=169110}}while(0);if((c[2113008]|0)>0){d=f|0;G=f+4|0;g=f+8|0;j=f+12|0;k=0;do{cC(h|0,531144,(l=i,i=i+8|0,c[l>>2]=k,l)|0)|0;i=l;c[d>>2]=14168888+(k*252|0);c[G>>2]=252;c[g>>2]=0;c[j>>2]=h;gj[c[2076592]&4095](f)|0;k=k+1|0;}while((k|0)<(c[2113008]|0))}gGz(n|0,0,12);c[n>>2]=9734168;c[n+4>>2]=4;c[n+12>>2]=98432;gj[c[2076592]&4095](n)|0;gGz(m|0,0,12);c[m>>2]=9734304;c[m+4>>2]=4;c[m+12>>2]=470080;gj[c[2076592]&4095](m)|0;gGz(E|0,0,12);c[E>>2]=9753440;c[E+4>>2]=4;c[E+12>>2]=552304;gj[c[2076592]&4095](E)|0;gGz(D|0,0,12);c[D>>2]=9542944;c[D+4>>2]=3;c[D+12>>2]=537832;gj[c[2076592]&4095](D)|0;gGz(C|0,0,12);c[C>>2]=9627224;c[C+4>>2]=2;c[C+12>>2]=524512;gj[c[2076592]&4095](C)|0;gGz(B|0,0,12);c[B>>2]=9753512;c[B+4>>2]=4;c[B+12>>2]=510800;gj[c[2076592]&4095](B)|0;gGz(A|0,0,12);c[A>>2]=9753520;c[A+4>>2]=4;c[A+12>>2]=498224;gj[c[2076592]&4095](A)|0;gGz(z|0,0,12);c[z>>2]=9753528;c[z+4>>2]=4;c[z+12>>2]=486376;gj[c[2076592]&4095](z)|0;gGz(y|0,0,12);c[y>>2]=9753536;c[y+4>>2]=4;c[y+12>>2]=473600;gj[c[2076592]&4095](y)|0;gGz(x|0,0,12);c[x>>2]=9753480;c[x+4>>2]=4;c[x+12>>2]=462192;gj[c[2076592]&4095](x)|0;gGz(w|0,0,12);c[w>>2]=9753488;c[w+4>>2]=4;c[w+12>>2]=451248;gj[c[2076592]&4095](w)|0;gGz(v|0,0,12);c[v>>2]=9753496;c[v+4>>2]=4;c[v+12>>2]=440080;gj[c[2076592]&4095](v)|0;gGz(u|0,0,12);c[u>>2]=9753504;c[u+4>>2]=4;c[u+12>>2]=428880;gj[c[2076592]&4095](u)|0;gGz(t|0,0,12);c[t>>2]=9753448;c[t+4>>2]=4;c[t+12>>2]=417488;gj[c[2076592]&4095](t)|0;gGz(s|0,0,12);c[s>>2]=9753456;c[s+4>>2]=4;c[s+12>>2]=405512;gj[c[2076592]&4095](s)|0;gGz(r|0,0,12);c[r>>2]=9753464;c[r+4>>2]=4;c[r+12>>2]=394624;gj[c[2076592]&4095](r)|0;gGz(q|0,0,12);c[q>>2]=9753472;c[q+4>>2]=4;c[q+12>>2]=382992;gj[c[2076592]&4095](q)|0;gGz(p|0,0,12);c[p>>2]=9718752;c[p+4>>2]=4;c[p+12>>2]=373184;gj[c[2076592]&4095](p)|0;gGz(o|0,0,12);c[o>>2]=9718744;c[o+4>>2]=4;c[o+12>>2]=363544;gj[c[2076592]&4095](o)|0;if((a&2|0)==0){i=e;return 0}a=c[2439330]|0;o=(a|0)==0;if(!o){p=a;gGC(9706056,p|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];p=c[3528484]|0;c[2076596]=p;q=c[2417276]|0;c[3541536]=q;c[1836236]=0;r=c[3526992]|0;s=c[2429688]|0;c[a+1036>>2]=r+s;c[a+1040>>2]=r+(s+256);c[a+1044>>2]=r+(s+512);c[a+1048>>2]=r+(s+768);c[a+1052>>2]=r+(s+1024);c[a+1056>>2]=r+(s+1280);c[a+1060>>2]=r+(s+1536);c[a+1064>>2]=r+(s+1792);s=c[2429688]|0;t=r+s|0;c[a+3084>>2]=t;c[a+4108>>2]=t;t=r+(s+256)|0;c[a+3088>>2]=t;c[a+4112>>2]=t;t=r+(s+512)|0;c[a+3092>>2]=t;c[a+4116>>2]=t;t=r+(s+768)|0;c[a+3096>>2]=t;c[a+4120>>2]=t;t=r+(s+1024)|0;c[a+3100>>2]=t;c[a+4124>>2]=t;t=r+(s+1280)|0;c[a+3104>>2]=t;c[a+4128>>2]=t;t=r+(s+1536)|0;c[a+3108>>2]=t;c[a+4132>>2]=t;t=r+(s+1792)|0;c[a+3112>>2]=t;c[a+4136>>2]=t;if(!o){o=a;gGC(o|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=p;c[2417276]=q;c[1836236]=-1;q=c[2439331]|0;p=(q|0)==0;if(!p){o=q;gGC(9706056,o|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];o=c[3528485]|0;c[2076596]=o;a=c[2417277]|0;c[3541536]=a;c[1836236]=1;t=c[3526990]|0;s=c[2429686]|0;c[q+1036>>2]=t+s;c[q+1040>>2]=t+(s+256);c[q+1044>>2]=t+(s+512);c[q+1048>>2]=t+(s+768);c[q+1052>>2]=t+(s+1024);c[q+1056>>2]=t+(s+1280);c[q+1060>>2]=t+(s+1536);c[q+1064>>2]=t+(s+1792);s=c[2429686]|0;r=t+s|0;c[q+3084>>2]=r;c[q+4108>>2]=r;r=t+(s+256)|0;c[q+3088>>2]=r;c[q+4112>>2]=r;r=t+(s+512)|0;c[q+3092>>2]=r;c[q+4116>>2]=r;r=t+(s+768)|0;c[q+3096>>2]=r;c[q+4120>>2]=r;r=t+(s+1024)|0;c[q+3100>>2]=r;c[q+4124>>2]=r;r=t+(s+1280)|0;c[q+3104>>2]=r;c[q+4128>>2]=r;r=t+(s+1536)|0;c[q+3108>>2]=r;c[q+4132>>2]=r;r=t+(s+1792)|0;c[q+3112>>2]=r;c[q+4136>>2]=r;if(!p){p=q;gGC(p|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=o;c[2417277]=a;c[1836236]=-1;i=e;return 0}function dkj(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6627716+(b*112|0)>>2];c[a+104>>2]=c[6627720+(b*112|0)>>2];c[a+108>>2]=c[6627724+(b*112|0)>>2];d=0;return d|0}function dkk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=6627616+(b*112|0);e=0;return e|0}function dkl(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6626036+(b*112|0)>>2];c[a+104>>2]=c[6626040+(b*112|0)>>2];c[a+108>>2]=c[6626044+(b*112|0)>>2];d=0;return d|0}function dkm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=6625936+(b*112|0);e=0;return e|0}function dkn(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6624356+(b*112|0)>>2];c[a+104>>2]=c[6624360+(b*112|0)>>2];c[a+108>>2]=c[6624364+(b*112|0)>>2];d=0;return d|0}function dko(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=6624256+(b*112|0);e=0;return e|0}function dkp(){a[632368]=1;return dkf()|0}function dkq(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;a=c[2438386]|0;b=c[3527004]|0;e=0;do{f=((d[a+(e&-2)|0]|0)<<8|(d[a+(e|1)|0]|0))&65535;g=f>>>4&15;h=f>>>8;c[b+(((e|0)/2|0)<<2)>>2]=(h<<4|h&8)>>>3&31|(f<<4|f&12)<<3&2016|(g<<4|g)<<8&63488;e=e+1|0;}while((e|0)<2048);e=c[2438396]|0;b=c[2112926]|0;a=c[3527008]|0;g=0;f=0;while(1){h=g<<4;i=0;j=f;while(1){k=d[e+j|0]|0;l=(k>>>1&4|k&3)<<8|(d[e+(j+2048)|0]|0);m=k>>>4;k=(i<<4)-(c[2438366]|0)-(c[2438368]<<8)|0;n=k&1023;o=h-(c[2438362]|0)-(c[2438364]<<8)&511;p=o-16|0;q=n>>>0>968?k|-1024:n;do{if((q-16|0)>>>0<224){if((o-32|0)>>>0>=192){r=67055;break}Sy(b,l,q,p,m,4,768,a)}else{r=67055}}while(0);if((r|0)==67055){r=0;Sz(b,l,q,p,m,4,768,a)}o=i+1|0;if((o|0)<64){i=o;j=j+1|0}else{break}}j=g+1|0;if((j|0)<32){g=j;f=f+64|0}else{break}}dks(2);f=c[2438394]|0;g=c[2112926]|0;a=c[3527006]|0;b=0;e=0;while(1){j=b<<4;i=0;h=e;while(1){o=d[f+h|0]|0;n=(o>>>1&4|o&3)<<8|(d[f+(h+2048)|0]|0);k=o>>>4;o=(i<<4)-(c[2438374]|0)-(c[2438376]<<8)|0;s=o&1023;t=j-(c[2438370]|0)-(c[2438372]<<8)&511;u=t-16|0;v=s>>>0>968?o|-1024:s;do{if((v-16|0)>>>0<224){if((t-32|0)>>>0>=192){r=67063;break}SG(g,n,v,u,k,4,0,512,a)}else{r=67063}}while(0);if((r|0)==67063){r=0;SH(g,n,v,u,k,4,0,512,a)}t=i+1|0;if((t|0)<64){i=t;h=h+1|0}else{break}}h=b+1|0;if((h|0)<32){b=h;e=e+64|0}else{break}}dks(1);dkt();dks(0);R8(c[3527004]|0);return}function dkr(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;a=c[2438386]|0;b=c[3527004]|0;e=0;do{f=((d[a+(e&-2)|0]|0)<<8|(d[a+(e|1)|0]|0))&65535;g=f>>>4&15;h=f>>>8;c[b+(((e|0)/2|0)<<2)>>2]=(h<<4|h&8)>>>3&31|(f<<4|f&12)<<3&2016|(g<<4|g)<<8&63488;e=e+1|0;}while((e|0)<2048);e=c[2438396]|0;b=c[2112926]|0;a=c[3527008]|0;g=0;f=0;while(1){h=g<<4;i=0;j=f;while(1){k=d[e+j|0]|0;l=k<<8&1792|(d[e+(j+2048)|0]|0);m=k>>>4;k=(i<<4)-(c[2438366]|0)-(c[2438368]<<8)|0;n=k&1023;o=h-(c[2438362]|0)-(c[2438364]<<8)&511;p=o-16|0;q=n>>>0>968?k|-1024:n;do{if((q-16|0)>>>0<224){if((o-32|0)>>>0>=192){r=67074;break}Sy(b,l,q,p,m,4,768,a)}else{r=67074}}while(0);if((r|0)==67074){r=0;Sz(b,l,q,p,m,4,768,a)}o=i+1|0;if((o|0)<64){i=o;j=j+1|0}else{break}}j=g+1|0;if((j|0)<32){g=j;f=f+64|0}else{break}}dks(2);f=c[2438394]|0;g=c[2112926]|0;a=c[3527006]|0;b=0;e=0;while(1){j=b<<4;i=0;h=e;while(1){o=d[f+h|0]|0;n=o<<8&1792|(d[f+(h+2048)|0]|0);k=o>>>4;o=(i<<4)-(c[2438374]|0)-(c[2438376]<<8)|0;s=o&1023;t=j-(c[2438370]|0)-(c[2438372]<<8)&511;u=t-16|0;v=s>>>0>968?o|-1024:s;do{if((v-16|0)>>>0<224){if((t-32|0)>>>0>=192){r=67082;break}SG(g,n,v,u,k,4,0,512,a)}else{r=67082}}while(0);if((r|0)==67082){r=0;SH(g,n,v,u,k,4,0,512,a)}t=i+1|0;if((t|0)<64){i=t;h=h+1|0}else{break}}h=b+1|0;if((h|0)<32){b=h;e=e+64|0}else{break}}dks(1);dkt();dks(0);R8(c[3527004]|0);return}function dks(a){a=a|0;var b=0,e=0,f=0,g=0,h=0;b=0;do{e=c[2439368]|0;f=d[e+b|0]|0;if(!((f>>>4|0)!=(a|0)|(f&4|0)==0)){g=(d[e+(b|9)|0]|0)<<8&768|(d[e+(b|8)|0]|0);h=d[e+(b|4)|0]|0;ge[c[1560376+((h&15)<<2)>>2]&63]((d[e+(b|3)|0]|0)<<6|(d[e+(b|2)|0]|0)>>>2,g>>>0>767?g|-1024:g,((d[e+(b|7)|0]|0)<<8&256|(d[e+(b|6)|0]|0))-16|0,f,h)}b=b+16|0;}while((b|0)<2048);return}function dkt(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;a=c[2433134]|0;b=c[2112926]|0;e=c[2439372]|0;f=0;g=0;while(1){h=f<<3;i=0;j=g;while(1){k=d[a+j|0]|0;l=k<<8&1792|(d[a+(j+2048)|0]|0);m=k>>>4;k=(i<<3)-(c[2438382]|0)-(c[2438384]<<8)&511;n=h-(c[2438378]|0)&255;o=n-16|0;do{if((k-8|0)>>>0<240){if((n-24|0)>>>0>=208){p=67096;break}Sq(b,l,k,o,m,4,0,256,e)}else{p=67096}}while(0);if((p|0)==67096){p=0;Sr(b,l,k,o,m,4,0,256,e)}n=i+1|0;if((n|0)<64){i=n;j=j+1|0}else{break}}j=f+1|0;if((j|0)<32){f=j;g=g+64|0}else{break}}return}function dku(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return}function dkv(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;dkE(a,e>>4,d&1,d&2,b,c);return}function dkw(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=d&1;if((f|0)==0){g=e>>4;h=d&2;dkE(a,g,0,h,b,c);dkE(a+1|0,g,0,h,b+16|0,c);return}else{h=e>>4;e=d&2;dkE(a+1|0,h,f,e,b+16|0,c);dkE(a,h,f,e,b,c);return}}function dkx(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=d&1;if((f|0)==0){g=e>>4;h=d&2;dkE(a,g,0,h,b,c);dkE(a+1|0,g,0,h,b+16|0,c);dkE(a+2|0,g,0,h,b+32|0,c);dkE(a+3|0,g,0,h,b+48|0,c);return}else{h=e>>4;e=d&2;dkE(a+3|0,h,f,e,b+48|0,c);dkE(a+2|0,h,f,e,b+32|0,c);dkE(a+1|0,h,f,e,b+16|0,c);dkE(a,h,f,e,b,c);return}}function dky(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=d&2;if((f|0)==0){g=e>>4;h=d&1;dkE(a,g,h,0,b,c);dkE(a+1|0,g,h,0,b,c+16|0);return}else{h=e>>4;e=d&1;dkE(a+1|0,h,e,f,b,c+16|0);dkE(a,h,e,f,b,c);return}}function dkz(b,c,d,e,f){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;g=e&3;h=f>>4;f=e&1;i=e&2;dkE((a[672800+(g<<2)|0]|0)+b|0,h,f,i,c,d);e=c+16|0;dkE((a[672801+(g<<2)|0]|0)+b|0,h,f,i,e,d);j=d+16|0;dkE((a[672802+(g<<2)|0]|0)+b|0,h,f,i,c,j);dkE((a[672803+(g<<2)|0]|0)+b|0,h,f,i,e,j);return}function dkA(b,c,d,e,f){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;g=e&3;h=f>>4;f=e&1;i=e&2;dkE((a[672736+(g<<3)|0]|0)+b|0,h,f,i,c,d);e=c+16|0;dkE((a[672737+(g<<3)|0]|0)+b|0,h,f,i,e,d);j=d+16|0;dkE((a[672738+(g<<3)|0]|0)+b|0,h,f,i,c,j);dkE((a[672739+(g<<3)|0]|0)+b|0,h,f,i,e,j);e=c+32|0;dkE((a[672740+(g<<3)|0]|0)+b|0,h,f,i,e,d);k=c+48|0;dkE((a[672741+(g<<3)|0]|0)+b|0,h,f,i,k,d);dkE((a[672742+(g<<3)|0]|0)+b|0,h,f,i,e,j);dkE((a[672743+(g<<3)|0]|0)+b|0,h,f,i,k,j);return}function dkB(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=d&2;if((f|0)==0){g=e>>4;h=d&1;dkE(a,g,h,0,b,c);dkE(a+1|0,g,h,0,b,c+16|0);dkE(a+2|0,g,h,0,b,c+32|0);dkE(a+3|0,g,h,0,b,c+48|0);return}else{h=e>>4;e=d&1;dkE(a+3|0,h,e,f,b,c+48|0);dkE(a+2|0,h,e,f,b,c+32|0);dkE(a+1|0,h,e,f,b,c+16|0);dkE(a,h,e,f,b,c);return}}function dkC(b,c,d,e,f){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;g=e&3;h=f>>4;f=e&1;i=e&2;dkE((a[672768+(g<<3)|0]|0)+b|0,h,f,i,c,d);e=c+16|0;dkE((a[672769+(g<<3)|0]|0)+b|0,h,f,i,e,d);j=d+16|0;dkE((a[672770+(g<<3)|0]|0)+b|0,h,f,i,c,j);dkE((a[672771+(g<<3)|0]|0)+b|0,h,f,i,e,j);j=d+32|0;dkE((a[672772+(g<<3)|0]|0)+b|0,h,f,i,c,j);dkE((a[672773+(g<<3)|0]|0)+b|0,h,f,i,e,j);j=d+48|0;dkE((a[672774+(g<<3)|0]|0)+b|0,h,f,i,c,j);dkE((a[672775+(g<<3)|0]|0)+b|0,h,f,i,e,j);return}function dkD(b,c,d,e,f){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=e&3;h=f>>4;f=e&1;i=e&2;dkE((a[672672+(g<<4)|0]|0)+b|0,h,f,i,c,d);e=c+16|0;dkE((a[672673+(g<<4)|0]|0)+b|0,h,f,i,e,d);j=d+16|0;dkE((a[672674+(g<<4)|0]|0)+b|0,h,f,i,c,j);dkE((a[672675+(g<<4)|0]|0)+b|0,h,f,i,e,j);k=c+32|0;dkE((a[672676+(g<<4)|0]|0)+b|0,h,f,i,k,d);l=c+48|0;dkE((a[672677+(g<<4)|0]|0)+b|0,h,f,i,l,d);dkE((a[672678+(g<<4)|0]|0)+b|0,h,f,i,k,j);dkE((a[672679+(g<<4)|0]|0)+b|0,h,f,i,l,j);j=d+32|0;dkE((a[672680+(g<<4)|0]|0)+b|0,h,f,i,c,j);dkE((a[672681+(g<<4)|0]|0)+b|0,h,f,i,e,j);m=d+48|0;dkE((a[672682+(g<<4)|0]|0)+b|0,h,f,i,c,m);dkE((a[672683+(g<<4)|0]|0)+b|0,h,f,i,e,m);dkE((a[672684+(g<<4)|0]|0)+b|0,h,f,i,k,j);dkE((a[672685+(g<<4)|0]|0)+b|0,h,f,i,l,j);dkE((a[672686+(g<<4)|0]|0)+b|0,h,f,i,k,m);dkE((a[672687+(g<<4)|0]|0)+b|0,h,f,i,l,m);return}function dkE(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0;do{if((f-16|0)>>>0<224){if((g-16|0)>>>0>=192){break}h=(d|0)!=0;i=c[2112926]|0;j=c[3527002]|0;if((e|0)==0){if(h){SI(i,a,f,g,b,4,0,0,j);return}else{SG(i,a,f,g,b,4,0,0,j);return}}else{if(h){SM(i,a,f,g,b,4,0,0,j);return}else{SK(i,a,f,g,b,4,0,0,j);return}}}}while(0);j=(d|0)!=0;d=c[2112926]|0;i=c[3527002]|0;if((e|0)==0){if(j){SJ(d,a,f,g,b,4,0,0,i);return}else{SH(d,a,f,g,b,4,0,0,i);return}}else{if(j){SN(d,a,f,g,b,4,0,0,i);return}else{SL(d,a,f,g,b,4,0,0,i);return}}}function dkF(b,c){b=b|0;c=c|0;a[9706117]=c&1;return}function dkG(a){a=a|0;var b=0,d=0;b=(c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,4e6,0)|0;return a|0}function dkH(){return+(+((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)/4.0e6)}function dkI(b){b=b|0;var c=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=b&65535;switch(c|0){case 26624:case 26625:case 26626:case 26627:case 26628:case 26629:case 26630:case 26631:{b=c-26624|0;e=((d[9658065]|0)>>>(b>>>0)<<1&2|(d[9658066]|0)>>>(b>>>0)&1)&255;return e|0};case 28672:case 28673:case 28674:case 28675:case 28676:case 28677:case 28678:case 28679:case 28680:case 28681:case 28682:case 28683:case 28684:case 28685:case 28686:case 28687:{b=d[9718952]|0;if(!((b|0)==113|(b|0)==177)){e=-1;return e|0}if((c|0)==28674){e=a[9625882]|0;return e|0}else if((c|0)==28673){e=a[9625881]|0;return e|0}else if((c|0)==28672){c=a[9658064]|a[9625880];if((a[14116336]|0)!=0){e=c;return e|0}b=c&255;do{if(c<<24>>24==(a[14108144]|0)){f=a[9757952]|0}else{g=a[9718968]|0;do{if(g<<24>>24==0){a[9757952]=2;h=2}else{i=a[9757952]|0;if(!((b&112|0)!=112&(i&255)<99)){h=i;break}j=(a[9538128]|0)+1&255;a[9538128]=j;if((j&255)<(g&255)){h=i;break}j=(a[9718960]|0)+i&255;a[9757952]=j;a[9538128]=0;h=j}}while(0);if((b&4|0)==0){if(h<<24>>24==0){f=0;break}g=h-1&255;a[9757952]=g;k=g}else{k=h}if(!((b&8|0)==0&(k&255)>1)){f=k;break}g=k-2&255;a[9757952]=g;f=g}}while(0);a[14108144]=c;e=((f&255)/10|0)<<4|((f&255)%10|0);return e|0}else{e=-1;return e|0}break};case 28928:{e=a[9718952]|0;return e|0};default:{e=0;return e|0}}return 0}function dkJ(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=d&65535;if((d-26624&65535)<32){UY(f-26624|0,e);return}if((f|0)==28928){a[9718952]=e;a[9730760]=1;d=e&255;if((d|0)==225){a[9757952]=0;a[14116336]=0;return}else if((d|0)==16){a[9730760]=0;return}else if((d|0)==161){a[14116336]=1;return}else{return}}else if((f|0)==28672|(f|0)==28673|(f|0)==28674|(f|0)==28675|(f|0)==28676|(f|0)==28677|(f|0)==28678|(f|0)==28679|(f|0)==28680|(f|0)==28681|(f|0)==28682|(f|0)==28683|(f|0)==28684|(f|0)==28685|(f|0)==28686|(f|0)==28687){d=f-28672|0;a[9773304+d|0]=e;g=c[2384402]|0;L80382:do{if((g|0)==0){switch(e&240|0){case 16:{if(!((gGH(9537600,576680,4)|0)==0&(c[2439194]|0)>0)){break L80382}h=c[2406652]|0;c[3528400]=h;if((a[h+14|0]&1)!=0){break L80382}a[h+12|0]=1;c[h+8>>2]=0;break L80382;break};case 64:{c[2384402]=4;c[2384396]=2;break L80382;break};case 32:{if(!((gGH(9537592,575480,4)|0)==0&(c[2439194]|0)>1)){break L80382}h=c[2406652]|0;c[3528400]=h+40;if((a[h+54|0]&1)!=0){break L80382}a[h+52|0]=1;c[h+48>>2]=0;break L80382;break};case 96:{c[2384402]=5;c[2384396]=3;break L80382;break};case 48:{c[2384402]=4;c[2384396]=1;break L80382;break};default:{break L80382}}}else{h=c[2384396]|0;if((h|0)==2){c[2384402]=g-1;a[9537592+(4-g)|0]=e;break}else if((h|0)==3){c[2384402]=g-1;break}else{c[2384402]=g-1;a[9537600+(4-g)|0]=e;break}}}while(0);if(!((a[9718952]|0)==-31&(d|0)==7)){return}a[9718968]=a[9773305]|0;a[9718960]=a[9773306]|0;return}else if((f|0)==26658){a[9755232]=e&1^1;return}else if((f|0)==26657){a[9755240]=e&1;return}else if((f|0)==26656){a[9755248]=e&1;return}else if((f|0)==40960|(f|0)==40961|(f|0)==40962|(f|0)==40963|(f|0)==40964|(f|0)==40965|(f|0)==40966){a[9754992+(f-40960)|0]=e&1;return}else if((f|0)==26659){if((e&1)!=0){a[14109872]=0;a[14109864]=0;return}d=c[1836236]|0;g=c[9757320+(d<<2)>>2]|0;h=(g|0)==0;if(!h){i=g;gGC(i|0,9706056,76)|0}i=9752472+(d<<2)|0;c[i>>2]=c[2433530];j=14113936+(d<<2)|0;c[j>>2]=c[2076596];k=9669104+(d<<2)|0;c[k>>2]=c[3541536];c[1836236]=-1;l=c[2439331]|0;m=(l|0)==0;if(!m){n=l;gGC(9706056,n|0,76)|0}n=c[2438119]|0;c[2433530]=n;o=c[3528485]|0;c[2076596]=o;p=c[2417277]|0;c[3541536]=p;c[1836236]=1;gGz(9706056,0,76);if(!m){m=l;gGC(m|0,9706056,76)|0}c[2438119]=n;c[3528485]=o;c[2417277]=p;c[1836236]=-1;p=c[2439332]|0;o=(p|0)==0;if(!o){n=p;gGC(9706056,n|0,76)|0}n=c[2438120]|0;c[2433530]=n;m=c[3528486]|0;c[2076596]=m;l=c[2417278]|0;c[3541536]=l;c[1836236]=2;gGz(9706056,0,76);if(!o){o=p;gGC(o|0,9706056,76)|0}c[2438120]=n;c[3528486]=m;c[2417278]=l;c[1836236]=-1;if(!h){h=g;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[i>>2];c[2076596]=c[j>>2];c[3541536]=c[k>>2];c[1836236]=d;a[14109872]=1;a[14109864]=1;return}else if((f|0)==40967){a[9759744]=e&1;return}else{return}}function dkK(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7426340+(b*112|0)>>2];c[a+104>>2]=c[7426344+(b*112|0)>>2];c[a+108>>2]=c[7426348+(b*112|0)>>2];d=0;return d|0}function dkL(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=7426240+(b*112|0);e=0;return e|0}function dkM(a,b){a=a|0;b=b|0;var d=0;do{if(b>>>0>2){d=1}else{if((a|0)==0){d=0;break}c[a+100>>2]=c[1912924+(b*104|0)>>2];d=0}}while(0);return d|0}function dkN(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<3&(d|0)==0)){e=1;return e|0}c[a>>2]=1912824+(b*104|0);e=0;return e|0}function dkO(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6936592+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dkP(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>45){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7447504+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dkQ(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;b=i;i=i+1560|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;l=b+360|0;m=b+472|0;n=b+480|0;o=b+592|0;p=b+600|0;q=b+712|0;r=b+720|0;s=b+832|0;t=b+840|0;u=b+952|0;v=b+960|0;w=b+1072|0;x=b+1080|0;y=b+1192|0;z=b+1200|0;A=b+1312|0;B=b+1320|0;C=b+1432|0;D=b+1440|0;E=b+1552|0;c[2426802]=0;c[3529130]=0;c[3529116]=16384;c[3529104]=32768;c[2438760]=49152;c[2432722]=49184;c[2429762]=49440;c[3541148]=49696;c[2405708]=49952;c[3527224]=49952;c[2439574]=53024;c[2439572]=69408;c[2439570]=70432;c[2411804]=71456;c[2406542]=71456;c[3529594]=87840;c[3530126]=120608;F=0;while(1){if((F|0)>=1024){break}G=9638528+(F<<2)|0;if((c[G>>2]|0)==0){H=67287;break}else{F=F+1|0}}do{if((H|0)==67287){F=gGq(122912)|0;c[G>>2]=F;if((F|0)==0){break}c[2426802]=F;gGz(F|0,0,122912);c[3529130]=F;c[3529116]=F+16384;c[3529104]=F+32768;c[2438760]=F+49152;c[2432722]=F+49184;c[2429762]=F+49440;c[3541148]=F+49696;I=F+49952|0;c[2405708]=I;c[3527224]=I;c[2439574]=F+53024;c[2439572]=F+69408;c[2439570]=F+70432;I=F+71456|0;c[2411804]=I;c[2406542]=I;c[3529594]=F+87840;c[3530126]=F+120608;c[2414352]=F+122912;F=0;while(1){if((F|0)>=1024){J=0;break}K=9638528+(F<<2)|0;if((c[K>>2]|0)==0){H=67292;break}else{F=F+1|0}}do{if((H|0)==67292){F=gGq(8192)|0;c[K>>2]=F;if((F|0)==0){J=0;break}gGz(F|0,0,8192);J=F}}while(0);c[3529544]=J;F=c[3529130]|0;if((c[3542200]|0)==0){L=1;i=b;return L|0}I=D+108|0;c[I>>2]=0;M=D+100|0;c[M>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](D,0)|0;do{if((c[I>>2]|0)!=0){N=c[M>>2]|0;c[E>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](E,0,0)|0;if((N|0)<1){L=1;i=b;return L|0}if((gzL(F,0,0)|0)==0){break}else{L=1}i=b;return L|0}}while(0);F=(c[3529130]|0)+4096|0;if((c[3542200]|0)==0){L=1;i=b;return L|0}M=B+108|0;c[M>>2]=0;I=B+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](B,1)|0;do{if((c[M>>2]|0)!=0){N=c[I>>2]|0;c[C>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](C,1,0)|0;if((N|0)<1){L=1;i=b;return L|0}if((gzL(F,0,1)|0)==0){break}else{L=1}i=b;return L|0}}while(0);F=(c[3529130]|0)+8192|0;if((c[3542200]|0)==0){L=1;i=b;return L|0}I=z+108|0;c[I>>2]=0;M=z+100|0;c[M>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,2)|0;do{if((c[I>>2]|0)!=0){N=c[M>>2]|0;c[A>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](A,2,0)|0;if((N|0)<1){L=1;i=b;return L|0}if((gzL(F,0,2)|0)==0){break}else{L=1}i=b;return L|0}}while(0);F=(c[3529130]|0)+12288|0;if((c[3542200]|0)==0){L=1;i=b;return L|0}M=x+108|0;c[M>>2]=0;I=x+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,3)|0;do{if((c[M>>2]|0)!=0){N=c[I>>2]|0;c[y>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](y,3,0)|0;if((N|0)<1){L=1;i=b;return L|0}if((gzL(F,0,3)|0)==0){break}else{L=1}i=b;return L|0}}while(0);F=c[3529116]|0;if((c[3542200]|0)==0){L=1;i=b;return L|0}I=v+108|0;c[I>>2]=0;M=v+100|0;c[M>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,4)|0;do{if((c[I>>2]|0)!=0){N=c[M>>2]|0;c[w>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](w,4,0)|0;if((N|0)<1){L=1;i=b;return L|0}if((gzL(F,0,4)|0)==0){break}else{L=1}i=b;return L|0}}while(0);F=c[3529104]|0;if((c[3542200]|0)==0){L=1;i=b;return L|0}M=t+108|0;c[M>>2]=0;I=t+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,5)|0;do{if((c[M>>2]|0)!=0){N=c[I>>2]|0;c[u>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](u,5,0)|0;if((N|0)<1){L=1;i=b;return L|0}if((gzL(F,0,5)|0)==0){break}else{L=1}i=b;return L|0}}while(0);F=c[3529544]|0;if((c[3542200]|0)==0){L=1;i=b;return L|0}I=r+108|0;c[I>>2]=0;M=r+100|0;c[M>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,6)|0;do{if((c[I>>2]|0)!=0){N=c[M>>2]|0;c[s>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](s,6,0)|0;if((N|0)<1){L=1;i=b;return L|0}if((gzL(F,0,6)|0)==0){break}else{L=1}i=b;return L|0}}while(0);F=c[3529544]|0;M=c[2406542]|0;I=0;do{N=I<<6;gGz(M+N|0,0,64);O=I<<7;P=0;do{Q=O+(c[1238464+(P<<2)>>2]|0)|0;R=(P<<3)+N|0;S=0;do{T=Q+(c[610928+(S<<2)>>2]|0)|0;if(((d[F+((T|0)/8|0)|0]|0)&128>>>((T&7)>>>0)|0)!=0){T=M+(R+S)|0;a[T]=a[T]|2}S=S+1|0;}while((S|0)<8);P=P+1|0;}while((P|0)<8);P=O|4;S=0;do{R=P+(c[1238464+(S<<2)>>2]|0)|0;Q=(S<<3)+N|0;T=0;do{U=R+(c[610928+(T<<2)>>2]|0)|0;if(((d[F+((U|0)/8|0)|0]|0)&128>>>((U&7)>>>0)|0)!=0){U=M+(Q+T)|0;a[U]=a[U]|1}T=T+1|0;}while((T|0)<8);S=S+1|0;}while((S|0)<8);I=I+1|0;}while((I|0)<256);gGz(F|0,0,8192);if((c[3542200]|0)==0){L=1;i=b;return L|0}I=p+108|0;c[I>>2]=0;M=p+100|0;c[M>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,7)|0;do{if((c[I>>2]|0)!=0){S=c[M>>2]|0;c[q>>2]=9534384;N=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[N&16383](q,7,0)|0;if((S|0)<1){L=1;i=b;return L|0}if((gzL(F,0,7)|0)==0){break}else{L=1}i=b;return L|0}}while(0);F=(c[3529544]|0)+4096|0;if((c[3542200]|0)==0){L=1;i=b;return L|0}M=n+108|0;c[M>>2]=0;I=n+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,8)|0;do{if((c[M>>2]|0)!=0){S=c[I>>2]|0;c[o>>2]=9534384;N=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[N&16383](o,8,0)|0;if((S|0)<1){L=1;i=b;return L|0}if((gzL(F,0,8)|0)==0){break}else{L=1}i=b;return L|0}}while(0);F=c[3529544]|0;I=c[3529594]|0;M=0;do{S=M<<8;gGz(I+S|0,0,256);N=M<<9;P=0;do{O=N+(c[611712+(P<<2)>>2]|0)|0;T=(P<<4)+S|0;Q=0;do{R=O+(c[609488+(Q<<2)>>2]|0)|0;if(((d[F+((R|0)/8|0)|0]|0)&128>>>((R&7)>>>0)|0)!=0){R=I+(T+Q)|0;a[R]=a[R]|2}Q=Q+1|0;}while((Q|0)<16);P=P+1|0;}while((P|0)<16);P=N|4;Q=0;do{T=P+(c[611712+(Q<<2)>>2]|0)|0;O=(Q<<4)+S|0;R=0;do{U=T+(c[609488+(R<<2)>>2]|0)|0;if(((d[F+((U|0)/8|0)|0]|0)&128>>>((U&7)>>>0)|0)!=0){U=I+(O+R)|0;a[U]=a[U]|1}R=R+1|0;}while((R|0)<16);Q=Q+1|0;}while((Q|0)<16);M=M+1|0;}while((M|0)<128);M=c[2438760]|0;if((c[3542200]|0)==0){L=1;i=b;return L|0}I=l+108|0;c[I>>2]=0;F=l+100|0;c[F>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,9)|0;do{if((c[I>>2]|0)!=0){Q=c[F>>2]|0;c[m>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](m,9,0)|0;if((Q|0)<1){L=1;i=b;return L|0}if((gzL(M,0,9)|0)==0){break}else{L=1}i=b;return L|0}}while(0);M=c[2432722]|0;if((c[3542200]|0)==0){L=1;i=b;return L|0}F=j+108|0;c[F>>2]=0;I=j+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,10)|0;do{if((c[F>>2]|0)!=0){Q=c[I>>2]|0;c[k>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](k,10,0)|0;if((Q|0)<1){L=1;i=b;return L|0}if((gzL(M,0,10)|0)==0){break}else{L=1}i=b;return L|0}}while(0);M=c[2429762]|0;if((c[3542200]|0)==0){L=1;i=b;return L|0}I=g+108|0;c[I>>2]=0;F=g+100|0;c[F>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,11)|0;do{if((c[I>>2]|0)!=0){Q=c[F>>2]|0;c[h>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](h,11,0)|0;if((Q|0)<1){L=1;i=b;return L|0}if((gzL(M,0,11)|0)==0){break}else{L=1}i=b;return L|0}}while(0);M=c[3541148]|0;if((c[3542200]|0)==0){L=1;i=b;return L|0}F=e+108|0;c[F>>2]=0;I=e+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,12)|0;do{if((c[F>>2]|0)!=0){Q=c[I>>2]|0;c[f>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](f,12,0)|0;if((Q|0)<1){L=1;i=b;return L|0}if((gzL(M,0,12)|0)==0){break}else{L=1}i=b;return L|0}}while(0);M=c[3529544]|0;I=0;while(1){if((I|0)>=1024){break}V=9638528+(I<<2)|0;if((c[V>>2]|0)==(M|0)){H=67365;break}else{I=I+1|0}}if((H|0)==67365){gGr(M);c[V>>2]=0}c[3529544]=0;dk4();L=0;i=b;return L|0}}while(0);c[2426802]=0;L=1;i=b;return L|0}function dkR(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}b=c[2420424]|0;if((b|0)!=0){gGr(b);c[2420424]=0}b=c[2433528]|0;if((b|0)!=0){gGr(b);c[2433528]=0}b=c[2439194]|0;d=c[2406652]|0;if((b|0)>0){e=0;f=d;g=b;while(1){b=f+(e*40|0)|0;c[3528400]=b;h=c[b>>2]|0;if((h|0)==0){i=g;j=f}else{gGr(h);c[c[3528400]>>2]=0;i=c[2439194]|0;j=c[2406652]|0}h=e+1|0;if((h|0)<(i|0)){e=h;f=j;g=i}else{k=j;break}}}else{k=d}if((k|0)!=0){gGr(k);c[2406652]=0}c[3528400]=0;c[2439194]=0;c[2442914]=0;fwZ();k=c[2426802]|0;d=0;while(1){if((d|0)>=1024){break}l=9638528+(d<<2)|0;if((c[l>>2]|0)==(k|0)){m=67436;break}else{d=d+1|0}}if((m|0)==67436){gGr(k);c[l>>2]=0}c[2426802]=0;a[9755248]=0;a[9755240]=0;a[9755232]=0;a[14109872]=0;a[14109864]=0;a[9759744]=0;gGz(9754992,0,6);c[2438746]=0;c[2438744]=0;a[9718952]=0;a[9730760]=0;a[14116336]=0;a[9757952]=0;a[9718968]=0;a[9718960]=0;gGz(9773304,0,16);return 0}function dkS(){var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;f=i;i=i+384|0;g=f|0;h=a[9688]|0?534:0;if((a[9624784]|0)!=0){j=c[2439330]|0;k=(j|0)==0;if(!k){l=j;gGC(9706056,l|0,76)|0}l=c[2438118]|0;c[2433530]=l;m=c[3528484]|0;c[2076596]=m;n=c[2417276]|0;c[3541536]=n;c[1836236]=0;gGz(9706056,0,76);if(!k){k=j;gGC(k|0,9706056,76)|0}c[2438118]=l;c[3528484]=m;c[2417276]=n;c[1836236]=-1;n=c[2439331]|0;m=(n|0)==0;if(!m){l=n;gGC(9706056,l|0,76)|0}l=c[2438119]|0;c[2433530]=l;k=c[3528485]|0;c[2076596]=k;j=c[2417277]|0;c[3541536]=j;c[1836236]=1;gGz(9706056,0,76);if(!m){m=n;gGC(m|0,9706056,76)|0}c[2438119]=l;c[3528485]=k;c[2417277]=j;c[1836236]=-1;j=c[2439332]|0;k=(j|0)==0;if(!k){l=j;gGC(9706056,l|0,76)|0}l=c[2438120]|0;c[2433530]=l;m=c[3528486]|0;c[2076596]=m;n=c[2417278]|0;c[3541536]=n;c[1836236]=2;gGz(9706056,0,76);if(!k){k=j;gGC(k|0,9706056,76)|0}c[2438120]=l;c[3528486]=m;c[2417278]=n;c[1836236]=-1;n=c[2439194]|0;if((n|0)>0){m=c[2406652]|0;l=0;do{o=m+(l*40|0)|0;k=m+(l*40|0)+12|0;a[k]=0;j=m+(l*40|0)+8|0;c[j>>2]=0;p=a[m+(l*40|0)+14|0]|0;do{if((p&2)!=0&(n|0)>(l|0)){if((p&4)==0){a[m+(l*40|0)+13|0]=1}if((p&1)!=0){break}a[k]=1;c[j>>2]=0}}while(0);l=l+1|0;}while((l|0)<(n|0));c[3528400]=o}a[9755248]=0;a[9755240]=0;a[9755232]=0;a[14109872]=0;a[14109864]=0;a[9759744]=0;gGz(9754992,0,6);c[2438746]=0;c[2438744]=0;a[9718952]=0;a[9730760]=0;a[14116336]=0;a[9757952]=0;a[9718968]=0;a[9718960]=0;gGz(9773304,0,16)}a[9625880]=127;a[9625881]=-1;a[9625882]=-1;o=0;n=127;l=-1;m=-1;do{n=(n&255)-((a[9759280+o|0]&1)<<o)&255;l=(l&255)-((a[9759088+o|0]&1)<<o)&255;m=(m&255)-((a[9758904+o|0]&1)<<o)&255;o=o+1|0;}while((o|0)<8);a[9625880]=n;a[9625881]=l;a[9625882]=m;a[6518344]=1;a[6518168]=1;a[6517904]=1;c[2444112]=0;c[2444111]=0;c[2444110]=0;m=c[2385548]|0;if((m|0)>0){gGz(9752472,0,((m|0)>1?m<<2:4)|0)}c[2433530]=0;m=h-1|0;l=h>>>1;n=(h>>>0)/3|0;o=n<<1;j=0;k=0;L80740:while(1){p=k;while(1){if((p|0)>=(h|0)){break L80740}q=c[2439330]|0;if((q|0)!=0){r=q;gGC(9706056,r|0,76)|0}b[4853030]=c[2426515]&65535;r=c[2438118]|0;c[2433530]=r;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;s=p+1|0;t=(ag(a[6518344]|0?51200:0,s)|0)/534|0;u=c[2444110]|0;v=t-u|0;c[2438204]=v;do{if((v|0)<1){w=0;x=u}else{if((a[q+4188|0]|0)==0){t=gfc(v)|0;c[2433530]=(c[2433530]|0)+t;w=t;x=c[2444110]|0;break}else{c[2433530]=r+v;w=v;x=u;break}}}while(0);c[2438204]=w;c[2444110]=x+w;u=(p|0)==(m|0);if(u&(a[9755248]|0)!=0){a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0}if((p|0)==0|(p|0)==(n|0)){if((a[9730760]|0)!=0){y=67479}}else{if((p|0)==(o|0)&(a[9730760]|0)!=0){y=67479}}if((y|0)==67479){y=0;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12}v=c[1836236]|0;r=c[9757320+(v<<2)>>2]|0;if((r|0)!=0){q=r;gGC(q|0,9706056,76)|0}c[9752472+(v<<2)>>2]=c[2433530];c[14113936+(v<<2)>>2]=c[2076596];c[9669104+(v<<2)>>2]=c[3541536];c[1836236]=-1;if((a[14109872]|0)==0){v=c[2439331]|0;if((v|0)!=0){q=v;gGC(9706056,q|0,76)|0}b[4853030]=c[2426515]&65535;q=c[2438119]|0;c[2433530]=q;c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;r=(ag(a[6518168]|0?51200:0,s)|0)/534|0;t=c[2444111]|0;z=r-t|0;c[2438204]=z;do{if((z|0)<1){A=0;B=t}else{if((a[v+4188|0]|0)==0){r=gfc(z)|0;c[2433530]=(c[2433530]|0)+r;A=r;B=c[2444111]|0;break}else{c[2433530]=q+z;A=z;B=t;break}}}while(0);c[2438204]=A;c[2444111]=B+A;if(u&(a[9755240]|0)!=0){a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0}t=c[1836236]|0;z=c[9757320+(t<<2)>>2]|0;if((z|0)!=0){q=z;gGC(q|0,9706056,76)|0}c[9752472+(t<<2)>>2]=c[2433530];c[14113936+(t<<2)>>2]=c[2076596];c[9669104+(t<<2)>>2]=c[3541536];c[1836236]=-1}if((a[14109864]|0)==0){t=c[2439332]|0;if((t|0)!=0){q=t;gGC(9706056,q|0,76)|0}b[4853030]=c[2426515]&65535;q=c[2438120]|0;c[2433530]=q;c[2076596]=c[3528486];c[3541536]=c[2417278];c[1836236]=2;z=(ag(a[6517904]|0?51200:0,s)|0)/534|0;v=c[2444112]|0;r=z-v|0;c[2438204]=r;do{if((r|0)<1){C=0;D=v;E=q}else{if((a[t+4188|0]|0)==0){z=gfc(r)|0;F=(c[2433530]|0)+z|0;c[2433530]=F;C=z;D=c[2444112]|0;E=F;break}else{F=q+r|0;c[2433530]=F;C=r;D=v;E=F;break}}}while(0);c[2438204]=C;c[2444112]=D+C;v=a[9755232]|0;if((p|0)==(l|0)){if(v<<24>>24==0){G=E}else{y=67506}}else{if(u&v<<24>>24!=0){y=67506}else{G=E}}if((y|0)==67506){y=0;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;v=(c[2433530]|0)+12|0;c[2433530]=v;G=v}v=c[1836236]|0;r=c[9757320+(v<<2)>>2]|0;if((r|0)!=0){q=r;gGC(q|0,9706056,76)|0}c[9752472+(v<<2)>>2]=G;c[14113936+(v<<2)>>2]=c[2076596];c[9669104+(v<<2)>>2]=c[3541536];c[1836236]=-1}H=c[2112964]|0;if((H|0)==0){p=s}else{break}}p=a[9688]|0;v=p&1;q=H+(j<<1<<1)|0;if(p){UX(q,v);Vg(q,v)}j=v+j|0;k=s}s=c[2112964]|0;do{if((s|0)!=0){k=a[9688]|0?534:0;H=k-j|0;G=s+(j<<1<<1)|0;if((k|0)==(j|0)){break}UX(G,H);Vg(G,H)}}while(0);if((c[2112968]|0)==0){I=a[9754992]|0;J=I&255;K=a[9754993]|0;L=K&255;M=L<<1;N=M+J|0;O=a[9754994]|0;P=O&255;Q=P<<2;R=N+Q|0;S=591232+(R<<2)|0;T=c[S>>2]|0;U=c[2438746]|0;V=U+T|0;c[2438746]=V;i=f;return 0}j=c[2112926]|0;gGz(j|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);s=c[2438760]|0;H=0;while(1){G=d[s+H|0]|0;c[g+(H<<2)>>2]=(-(G>>>3&1)&33)+(-(G>>>4&1)&71)+(-(G>>>5&1)&151)<<3&2016|((-(G>>>6&1)&71)+(-(G>>>7)&151)|0)>>>3&31|(-(G>>>1&1)&71)+(-(G&1)&33)+(-(G>>>2&1)&151)<<8&63488;G=H+1|0;if((G|0)<32){H=G}else{W=0;break}}do{c[g+(W+32<<2)>>2]=c[605984+((W>>>2&3)<<2)>>2]<<3&2016|c[605984+((W&3)<<2)>>2]<<8&63488|(c[605984+((W>>>4&3)<<2)>>2]|0)>>>3&31;W=W+1|0;}while((W|0)<64);W=c[2432722]|0;H=c[3530126]|0;s=0;do{c[H+(s<<2)>>2]=c[g+((a[W+s|0]&15|16)<<2)>>2];s=s+1|0;}while((s|0)<256);s=c[2429762]|0;W=0;while(1){c[H+(W+256<<2)>>2]=c[g+((a[s+W|0]&15)<<2)>>2];G=W+1|0;if((G|0)<256){W=G}else{X=0;break}}do{c[H+(X+512<<2)>>2]=c[g+(X+32<<2)>>2];X=X+1|0;}while((X|0)<64);X=c[3527224]|0;g=c[2406542]|0;W=0;do{s=W+2|0;G=s<<5;k=W<<3;E=216-k|0;l=0;do{C=l-2|0;if((C&32|0)==0){Y=C+G|0}else{Y=(C<<5&992)+s|0}C=a[X+Y|0]&127;D=a[X+(Y+1024)|0]&63;A=l<<3;B=(a[9759744]|0)==0;o=B?A:280-A|0;A=B?k:E;do{if((o-9|0)>>>0<271){if((A-9|0)>>>0>=207){y=67538;break}if(B){Si(j,C,o,A,D,2,0,g);break}else{So(j,C,o,A,D,2,0,g);break}}else{y=67538}}while(0);do{if((y|0)==67538){y=0;if(B){Sj(j,C,o,A,D,2,0,g);break}else{Sp(j,C,o,A,D,2,0,g);break}}}while(0);l=l+1|0;}while((l|0)<36);W=W+1|0;}while((W|0)<28);if((a[9754997]|0)==1){W=a[9754995]|0;g=d[9754996]|2;y=c[2113068]|0;Y=0;do{X=a[7119029+(Y*6|0)|0]|0;do{if(W<<24>>24==X<<24>>24|(g|0)==(X&255|0)){l=((e[7119024+(Y*6|0)>>1]|0)+(c[2438746]|0)&255)+16|0;E=(e[7119026+(Y*6|0)>>1]|0)+112+(c[2438744]|0)&255;if(!(l>>>0<288&E>>>0<224)){break}k=d[7119028+(Y*6|0)|0]|512;b[j+((ag(y,E)|0)+l<<1)>>1]=k}}while(0);Y=Y+1|0;}while((Y|0)<252)}Y=c[2439574]|0;y=c[2439572]|0;g=c[2439570]|0;W=c[3529594]|0;X=0;do{k=X+896|0;l=a[Y+k|0]&127;E=(X|1)+896|0;s=a[Y+E|0]&63;G=(d[y+E|0]|0)-40+(d[g+E|0]<<8&768)|0;E=d[g+k|0]|0;D=E&1;A=E>>>1&1;o=E>>>2&1;C=E>>>3&1;E=(257-(d[y+k|0]|0)-(C<<4)&255)-32|0;if((a[9759744]|0)==0){Z=D;_=A}else{Z=D^1;_=A^1}A=Z&-o;D=_&-C;k=(Z|0)==0;B=(_|0)!=0;u=0;do{n=u^D;m=E+(u<<4)|0;if((m-17|0)>>>0<191){w=0;do{x=(c[607912+(n<<3)+((w^A)<<2)>>2]|0)+l|0;h=(w<<4)+G|0;do{if((h-17|0)>>>0<255){if(k){if(B){SK(j,x,h,m,s,2,0,256,W);break}else{SG(j,x,h,m,s,2,0,256,W);break}}else{if(B){SM(j,x,h,m,s,2,0,256,W);break}else{SI(j,x,h,m,s,2,0,256,W);break}}}else{if(k){if(B){SL(j,x,h,m,s,2,0,256,W);break}else{SH(j,x,h,m,s,2,0,256,W);break}}else{if(B){SN(j,x,h,m,s,2,0,256,W);break}else{SJ(j,x,h,m,s,2,0,256,W);break}}}}while(0);w=w+1|0;}while((w|0)<=(o|0))}else{w=0;do{h=(c[607912+(n<<3)+((w^A)<<2)>>2]|0)+l|0;x=(w<<4)+G|0;do{if(k){if(B){SL(j,h,x,m,s,2,0,256,W);break}else{SH(j,h,x,m,s,2,0,256,W);break}}else{if(B){SN(j,h,x,m,s,2,0,256,W);break}else{SJ(j,h,x,m,s,2,0,256,W);break}}}while(0);w=w+1|0;}while((w|0)<=(o|0))}u=u+1|0;}while((u|0)<=(C|0));X=X+2|0;}while((X|0)<128);R8(H);I=a[9754992]|0;J=I&255;K=a[9754993]|0;L=K&255;M=L<<1;N=M+J|0;O=a[9754994]|0;P=O&255;Q=P<<2;R=N+Q|0;S=591232+(R<<2)|0;T=c[S>>2]|0;U=c[2438746]|0;V=U+T|0;c[2438746]=V;i=f;return 0}function dkT(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;d=i;i=i+384|0;e=d|0;f=d+32|0;g=d+48|0;h=d+64|0;j=d+80|0;k=d+96|0;l=d+112|0;m=d+128|0;n=d+144|0;o=d+160|0;p=d+176|0;q=d+192|0;r=d+208|0;s=d+224|0;t=d+240|0;u=d+256|0;v=d+272|0;w=d+288|0;x=d+304|0;y=d+320|0;z=d+336|0;A=d+352|0;B=d+368|0;C=(b|0)==0;if(!C){c[b>>2]=169624}if((a&32|0)!=0){gGz(B|0,0,12);D=c[2405708]|0;c[B>>2]=D;c[B+4>>2]=(c[2411804]|0)-D;c[B+12>>2]=162152;D=c[2076592]|0;gj[D&4095](B)|0}if((a&64|0)==0){i=d;return 0}fw$(a);a=d+16|0;if(!C){c[b>>2]=169735}gGC(a|0,117464,15)|0;c[e>>2]=c[2433528];c[e+4>>2]=64;c[e+8>>2]=0;c[e+12>>2]=a;gj[c[2076592]&4095](e)|0;gGz(A|0,0,12);c[A>>2]=9776440;c[A+4>>2]=12;c[A+12>>2]=212472;gj[c[2076592]&4095](A)|0;gGz(z|0,0,12);c[z>>2]=9752816;c[z+4>>2]=4;c[z+12>>2]=436576;gj[c[2076592]&4095](z)|0;gGz(y|0,0,12);c[y>>2]=9755248;c[y+4>>2]=1;c[y+12>>2]=164360;gj[c[2076592]&4095](y)|0;gGz(x|0,0,12);c[x>>2]=9755240;c[x+4>>2]=1;c[x+12>>2]=160552;gj[c[2076592]&4095](x)|0;gGz(w|0,0,12);c[w>>2]=9755232;c[w+4>>2]=1;c[w+12>>2]=157472;gj[c[2076592]&4095](w)|0;gGz(v|0,0,12);c[v>>2]=14109872;c[v+4>>2]=1;c[v+12>>2]=154160;gj[c[2076592]&4095](v)|0;gGz(u|0,0,12);c[u>>2]=14109864;c[u+4>>2]=1;c[u+12>>2]=150120;gj[c[2076592]&4095](u)|0;gGz(t|0,0,12);c[t>>2]=9759744;c[t+4>>2]=1;c[t+12>>2]=503888;gj[c[2076592]&4095](t)|0;gGz(s|0,0,12);c[s>>2]=9754984;c[s+4>>2]=4;c[s+12>>2]=142896;gj[c[2076592]&4095](s)|0;gGz(r|0,0,12);c[r>>2]=9754976;c[r+4>>2]=4;c[r+12>>2]=139896;gj[c[2076592]&4095](r)|0;gGz(q|0,0,12);c[q>>2]=9718952;c[q+4>>2]=1;c[q+12>>2]=137288;gj[c[2076592]&4095](q)|0;gGz(p|0,0,12);c[p>>2]=9730760;c[p+4>>2]=1;c[p+12>>2]=134896;gj[c[2076592]&4095](p)|0;gGz(o|0,0,12);c[o>>2]=14116336;c[o+4>>2]=1;c[o+12>>2]=132784;gj[c[2076592]&4095](o)|0;gGz(n|0,0,12);c[n>>2]=9757952;c[n+4>>2]=1;c[n+12>>2]=130216;gj[c[2076592]&4095](n)|0;gGz(m|0,0,12);c[m>>2]=9718968;c[m+4>>2]=1;c[m+12>>2]=127288;gj[c[2076592]&4095](m)|0;gGz(l|0,0,12);c[l>>2]=9718960;c[l+4>>2]=1;c[l+12>>2]=124472;gj[c[2076592]&4095](l)|0;gGz(k|0,0,12);c[k>>2]=14108144;c[k+4>>2]=1;c[k+12>>2]=120680;gj[c[2076592]&4095](k)|0;k=j;l=j|0;m=j+4|0;n=j+12|0;gGz(k|0,0,12);c[l>>2]=9754992;c[m>>2]=1;c[n>>2]=117496;gj[c[2076592]&4095](j)|0;gGz(k|0,0,12);c[l>>2]=9754993;c[m>>2]=1;c[n>>2]=117496;gj[c[2076592]&4095](j)|0;gGz(k|0,0,12);c[l>>2]=9754994;c[m>>2]=1;c[n>>2]=117496;gj[c[2076592]&4095](j)|0;gGz(k|0,0,12);c[l>>2]=9754995;c[m>>2]=1;c[n>>2]=117496;gj[c[2076592]&4095](j)|0;gGz(k|0,0,12);c[l>>2]=9754996;c[m>>2]=1;c[n>>2]=117496;gj[c[2076592]&4095](j)|0;gGz(k|0,0,12);c[l>>2]=9754997;c[m>>2]=1;c[n>>2]=117496;gj[c[2076592]&4095](j)|0;j=h;n=h|0;m=h+4|0;l=h+12|0;k=0;do{gGz(j|0,0,12);c[n>>2]=9773304+k;c[m>>2]=1;c[l>>2]=114736;gj[c[2076592]&4095](h)|0;k=k+1|0;}while((k|0)<16);gGz(g|0,0,12);c[g>>2]=9658064;c[g+4>>2]=3;c[g+12>>2]=483352;gj[c[2076592]&4095](g)|0;gGz(f|0,0,12);c[f>>2]=9625880;c[f+4>>2]=3;c[f+12>>2]=215728;gj[c[2076592]&4095](f)|0;i=d;return 0}function dkU(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5396036+(b*112|0)>>2];c[a+104>>2]=c[5396040+(b*112|0)>>2];c[a+108>>2]=c[5396044+(b*112|0)>>2];d=0;return d|0}function dkV(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=5395936+(b*112|0);e=0;return e|0}function dkW(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3933108+(b*112|0)>>2];c[a+104>>2]=c[3933112+(b*112|0)>>2];c[a+108>>2]=c[3933116+(b*112|0)>>2];d=0;return d|0}function dkX(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=3933008+(b*112|0);e=0;return e|0}function dkY(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>48){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3934576+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dkZ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3935268+(b*112|0)>>2];c[a+104>>2]=c[3935272+(b*112|0)>>2];c[a+108>>2]=c[3935276+(b*112|0)>>2];d=0;return d|0}function dk_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=3935168+(b*112|0);e=0;return e|0}function dk$(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3936836+(b*112|0)>>2];c[a+104>>2]=c[3936840+(b*112|0)>>2];c[a+108>>2]=c[3936844+(b*112|0)>>2];d=0;return d|0}function dk0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=3936736+(b*112|0);e=0;return e|0}function dk1(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6301900+(b*112|0)>>2];c[a+104>>2]=c[6301904+(b*112|0)>>2];c[a+108>>2]=c[6301908+(b*112|0)>>2];d=0;return d|0}function dk2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=6301800+(b*112|0);e=0;return e|0}function dk3(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;b=i;i=i+1560|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;l=b+360|0;m=b+472|0;n=b+480|0;o=b+592|0;p=b+600|0;q=b+712|0;r=b+720|0;s=b+832|0;t=b+840|0;u=b+952|0;v=b+960|0;w=b+1072|0;x=b+1080|0;y=b+1192|0;z=b+1200|0;A=b+1312|0;B=b+1320|0;C=b+1432|0;D=b+1440|0;E=b+1552|0;c[2426802]=0;c[3529130]=0;c[3529116]=16384;c[3529104]=32768;c[2438760]=49152;c[2432722]=49184;c[2429762]=49440;c[3541148]=49696;c[2405708]=49952;c[3527224]=49952;c[2439574]=53024;c[2439572]=69408;c[2439570]=70432;c[2411804]=71456;c[2406542]=71456;c[3529594]=87840;c[3530126]=120608;F=0;while(1){if((F|0)>=1024){break}G=9638528+(F<<2)|0;if((c[G>>2]|0)==0){H=67667;break}else{F=F+1|0}}do{if((H|0)==67667){F=gGq(122912)|0;c[G>>2]=F;if((F|0)==0){break}c[2426802]=F;gGz(F|0,0,122912);c[3529130]=F;c[3529116]=F+16384;c[3529104]=F+32768;c[2438760]=F+49152;c[2432722]=F+49184;c[2429762]=F+49440;c[3541148]=F+49696;I=F+49952|0;c[2405708]=I;c[3527224]=I;c[2439574]=F+53024;c[2439572]=F+69408;c[2439570]=F+70432;I=F+71456|0;c[2411804]=I;c[2406542]=I;c[3529594]=F+87840;c[3530126]=F+120608;c[2414352]=F+122912;F=0;while(1){if((F|0)>=1024){J=0;break}K=9638528+(F<<2)|0;if((c[K>>2]|0)==0){H=67672;break}else{F=F+1|0}}do{if((H|0)==67672){F=gGq(8192)|0;c[K>>2]=F;if((F|0)==0){J=0;break}gGz(F|0,0,8192);J=F}}while(0);c[3529544]=J;F=c[3529130]|0;if((c[3542200]|0)==0){L=1;i=b;return L|0}I=D+108|0;c[I>>2]=0;M=D+100|0;c[M>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](D,0)|0;do{if((c[I>>2]|0)!=0){N=c[M>>2]|0;c[E>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](E,0,0)|0;if((N|0)<1){L=1;i=b;return L|0}if((gzL(F,0,0)|0)==0){break}else{L=1}i=b;return L|0}}while(0);F=(c[3529130]|0)+4096|0;if((c[3542200]|0)==0){L=1;i=b;return L|0}M=B+108|0;c[M>>2]=0;I=B+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](B,1)|0;do{if((c[M>>2]|0)!=0){N=c[I>>2]|0;c[C>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](C,1,0)|0;if((N|0)<1){L=1;i=b;return L|0}if((gzL(F,0,1)|0)==0){break}else{L=1}i=b;return L|0}}while(0);F=(c[3529130]|0)+8192|0;if((c[3542200]|0)==0){L=1;i=b;return L|0}I=z+108|0;c[I>>2]=0;M=z+100|0;c[M>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,2)|0;do{if((c[I>>2]|0)!=0){N=c[M>>2]|0;c[A>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](A,2,0)|0;if((N|0)<1){L=1;i=b;return L|0}if((gzL(F,0,2)|0)==0){break}else{L=1}i=b;return L|0}}while(0);F=(c[3529130]|0)+12288|0;if((c[3542200]|0)==0){L=1;i=b;return L|0}M=x+108|0;c[M>>2]=0;I=x+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,3)|0;do{if((c[M>>2]|0)!=0){N=c[I>>2]|0;c[y>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](y,3,0)|0;if((N|0)<1){L=1;i=b;return L|0}if((gzL(F,0,3)|0)==0){break}else{L=1}i=b;return L|0}}while(0);F=c[3529116]|0;if((c[3542200]|0)==0){L=1;i=b;return L|0}I=v+108|0;c[I>>2]=0;M=v+100|0;c[M>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,4)|0;do{if((c[I>>2]|0)!=0){N=c[M>>2]|0;c[w>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](w,4,0)|0;if((N|0)<1){L=1;i=b;return L|0}if((gzL(F,0,4)|0)==0){break}else{L=1}i=b;return L|0}}while(0);F=c[3529104]|0;if((c[3542200]|0)==0){L=1;i=b;return L|0}M=t+108|0;c[M>>2]=0;I=t+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,5)|0;do{if((c[M>>2]|0)!=0){N=c[I>>2]|0;c[u>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](u,5,0)|0;if((N|0)<1){L=1;i=b;return L|0}if((gzL(F,0,5)|0)==0){break}else{L=1}i=b;return L|0}}while(0);F=c[3529544]|0;if((c[3542200]|0)==0){L=1;i=b;return L|0}I=r+108|0;c[I>>2]=0;M=r+100|0;c[M>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,7)|0;do{if((c[I>>2]|0)!=0){N=c[M>>2]|0;c[s>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](s,7,0)|0;if((N|0)<1){L=1;i=b;return L|0}if((gzL(F,0,7)|0)==0){break}else{L=1}i=b;return L|0}}while(0);F=c[3529544]|0;M=c[2406542]|0;I=0;do{N=I<<6;gGz(M+N|0,0,64);O=I<<7;P=0;do{Q=O+(c[1238464+(P<<2)>>2]|0)|0;R=(P<<3)+N|0;S=0;do{T=Q+(c[610928+(S<<2)>>2]|0)|0;if(((d[F+((T|0)/8|0)|0]|0)&128>>>((T&7)>>>0)|0)!=0){T=M+(R+S)|0;a[T]=a[T]|2}S=S+1|0;}while((S|0)<8);P=P+1|0;}while((P|0)<8);P=O|4;S=0;do{R=P+(c[1238464+(S<<2)>>2]|0)|0;Q=(S<<3)+N|0;T=0;do{U=R+(c[610928+(T<<2)>>2]|0)|0;if(((d[F+((U|0)/8|0)|0]|0)&128>>>((U&7)>>>0)|0)!=0){U=M+(Q+T)|0;a[U]=a[U]|1}T=T+1|0;}while((T|0)<8);S=S+1|0;}while((S|0)<8);I=I+1|0;}while((I|0)<256);gGz(F|0,0,8192);if((c[3542200]|0)==0){L=1;i=b;return L|0}I=p+108|0;c[I>>2]=0;M=p+100|0;c[M>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,8)|0;do{if((c[I>>2]|0)!=0){S=c[M>>2]|0;c[q>>2]=9534384;N=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[N&16383](q,8,0)|0;if((S|0)<1){L=1;i=b;return L|0}if((gzL(F,0,8)|0)==0){break}else{L=1}i=b;return L|0}}while(0);F=(c[3529544]|0)+4096|0;if((c[3542200]|0)==0){L=1;i=b;return L|0}M=n+108|0;c[M>>2]=0;I=n+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,9)|0;do{if((c[M>>2]|0)!=0){S=c[I>>2]|0;c[o>>2]=9534384;N=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[N&16383](o,9,0)|0;if((S|0)<1){L=1;i=b;return L|0}if((gzL(F,0,9)|0)==0){break}else{L=1}i=b;return L|0}}while(0);F=c[3529544]|0;I=c[3529594]|0;M=0;do{S=M<<8;gGz(I+S|0,0,256);N=M<<9;P=0;do{O=N+(c[611712+(P<<2)>>2]|0)|0;T=(P<<4)+S|0;Q=0;do{R=O+(c[609488+(Q<<2)>>2]|0)|0;if(((d[F+((R|0)/8|0)|0]|0)&128>>>((R&7)>>>0)|0)!=0){R=I+(T+Q)|0;a[R]=a[R]|2}Q=Q+1|0;}while((Q|0)<16);P=P+1|0;}while((P|0)<16);P=N|4;Q=0;do{T=P+(c[611712+(Q<<2)>>2]|0)|0;O=(Q<<4)+S|0;R=0;do{U=T+(c[609488+(R<<2)>>2]|0)|0;if(((d[F+((U|0)/8|0)|0]|0)&128>>>((U&7)>>>0)|0)!=0){U=I+(O+R)|0;a[U]=a[U]|1}R=R+1|0;}while((R|0)<16);Q=Q+1|0;}while((Q|0)<16);M=M+1|0;}while((M|0)<128);M=c[2438760]|0;if((c[3542200]|0)==0){L=1;i=b;return L|0}I=l+108|0;c[I>>2]=0;F=l+100|0;c[F>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,10)|0;do{if((c[I>>2]|0)!=0){Q=c[F>>2]|0;c[m>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](m,10,0)|0;if((Q|0)<1){L=1;i=b;return L|0}if((gzL(M,0,10)|0)==0){break}else{L=1}i=b;return L|0}}while(0);M=c[2432722]|0;if((c[3542200]|0)==0){L=1;i=b;return L|0}F=j+108|0;c[F>>2]=0;I=j+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,11)|0;do{if((c[F>>2]|0)!=0){Q=c[I>>2]|0;c[k>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](k,11,0)|0;if((Q|0)<1){L=1;i=b;return L|0}if((gzL(M,0,11)|0)==0){break}else{L=1}i=b;return L|0}}while(0);M=c[2429762]|0;if((c[3542200]|0)==0){L=1;i=b;return L|0}I=g+108|0;c[I>>2]=0;F=g+100|0;c[F>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,12)|0;do{if((c[I>>2]|0)!=0){Q=c[F>>2]|0;c[h>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](h,12,0)|0;if((Q|0)<1){L=1;i=b;return L|0}if((gzL(M,0,12)|0)==0){break}else{L=1}i=b;return L|0}}while(0);M=c[3541148]|0;if((c[3542200]|0)==0){L=1;i=b;return L|0}F=e+108|0;c[F>>2]=0;I=e+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,13)|0;do{if((c[F>>2]|0)!=0){Q=c[I>>2]|0;c[f>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](f,13,0)|0;if((Q|0)<1){L=1;i=b;return L|0}if((gzL(M,0,13)|0)==0){break}else{L=1}i=b;return L|0}}while(0);M=c[3529544]|0;I=0;while(1){if((I|0)>=1024){break}V=9638528+(I<<2)|0;if((c[V>>2]|0)==(M|0)){H=67745;break}else{I=I+1|0}}if((H|0)==67745){gGr(M);c[V>>2]=0}c[3529544]=0;dk4();L=0;i=b;return L|0}}while(0);c[2426802]=0;L=1;i=b;return L|0}function dk4(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;fwR(0);d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];f=c[3528484]|0;c[2076596]=f;g=c[2417276]|0;c[3541536]=g;c[1836236]=0;c[d+4180>>2]=3256;c[d+4184>>2]=3240;i=c[3529130]|0;j=0;k=0;while(1){c[d+76+(k<<2)>>2]=i+(k<<8);l=j+1&65535;if((l&65535)>63){m=0;n=0;break}else{j=l;k=l&65535}}while(1){k=i+(n<<8)|0;c[d+76+(n+512<<2)>>2]=k;c[d+76+(n+768<<2)>>2]=k;k=m+1&65535;if((k&65535)>63){break}else{m=k;n=k&65535}}n=c[3527224]|0;c[d+588>>2]=n;m=n+256|0;c[d+592>>2]=m;i=n+512|0;c[d+596>>2]=i;k=n+768|0;c[d+600>>2]=k;j=n+1024|0;c[d+604>>2]=j;l=n+1280|0;c[d+608>>2]=l;o=n+1536|0;c[d+612>>2]=o;p=n+1792|0;c[d+616>>2]=p;c[d+1612>>2]=n;c[d+1616>>2]=m;c[d+1620>>2]=i;c[d+1624>>2]=k;c[d+1628>>2]=j;c[d+1632>>2]=l;c[d+1636>>2]=o;c[d+1640>>2]=p;c[d+2636>>2]=n;c[d+3660>>2]=n;c[d+2640>>2]=m;c[d+3664>>2]=m;c[d+2644>>2]=i;c[d+3668>>2]=i;c[d+2648>>2]=k;c[d+3672>>2]=k;c[d+2652>>2]=j;c[d+3676>>2]=j;c[d+2656>>2]=l;c[d+3680>>2]=l;c[d+2660>>2]=o;c[d+3684>>2]=o;c[d+2664>>2]=p;c[d+3688>>2]=p;p=c[2439574]|0;c[d+620>>2]=p;o=p+256|0;c[d+624>>2]=o;l=p+512|0;c[d+628>>2]=l;j=p+768|0;c[d+632>>2]=j;c[d+1644>>2]=p;c[d+1648>>2]=o;c[d+1652>>2]=l;c[d+1656>>2]=j;c[d+2668>>2]=p;c[d+3692>>2]=p;c[d+2672>>2]=o;c[d+3696>>2]=o;c[d+2676>>2]=l;c[d+3700>>2]=l;c[d+2680>>2]=j;c[d+3704>>2]=j;j=c[2439572]|0;c[d+652>>2]=j;l=j+256|0;c[d+656>>2]=l;o=j+512|0;c[d+660>>2]=o;p=j+768|0;c[d+664>>2]=p;c[d+1676>>2]=j;c[d+1680>>2]=l;c[d+1684>>2]=o;c[d+1688>>2]=p;c[d+2700>>2]=j;c[d+3724>>2]=j;c[d+2704>>2]=l;c[d+3728>>2]=l;c[d+2708>>2]=o;c[d+3732>>2]=o;c[d+2712>>2]=p;c[d+3736>>2]=p;p=c[2439570]|0;c[d+684>>2]=p;o=p+256|0;c[d+688>>2]=o;l=p+512|0;c[d+692>>2]=l;j=p+768|0;c[d+696>>2]=j;c[d+1708>>2]=p;c[d+1712>>2]=o;c[d+1716>>2]=l;c[d+1720>>2]=j;c[d+2732>>2]=p;c[d+3756>>2]=p;c[d+2736>>2]=o;c[d+3760>>2]=o;c[d+2740>>2]=l;c[d+3764>>2]=l;c[d+2744>>2]=j;c[d+3768>>2]=j;if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=f;c[2417276]=g;c[1836236]=-1;fwR(1);g=c[2439331]|0;f=(g|0)==0;if(!f){e=g;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];e=c[3528485]|0;c[2076596]=e;d=c[2417277]|0;c[3541536]=d;c[1836236]=1;c[g+4180>>2]=3256;c[g+4184>>2]=3240;j=c[3529116]|0;l=0;o=0;while(1){c[g+76+(o<<2)>>2]=j+(o<<8);p=l+1&65535;if((p&65535)>63){q=0;r=0;break}else{l=p;o=p&65535}}while(1){o=j+(r<<8)|0;c[g+76+(r+512<<2)>>2]=o;c[g+76+(r+768<<2)>>2]=o;o=q+1&65535;if((o&65535)>63){break}else{q=o;r=o&65535}}r=c[3527224]|0;c[g+588>>2]=r;q=r+256|0;c[g+592>>2]=q;j=r+512|0;c[g+596>>2]=j;o=r+768|0;c[g+600>>2]=o;l=r+1024|0;c[g+604>>2]=l;p=r+1280|0;c[g+608>>2]=p;k=r+1536|0;c[g+612>>2]=k;i=r+1792|0;c[g+616>>2]=i;c[g+1612>>2]=r;c[g+1616>>2]=q;c[g+1620>>2]=j;c[g+1624>>2]=o;c[g+1628>>2]=l;c[g+1632>>2]=p;c[g+1636>>2]=k;c[g+1640>>2]=i;c[g+2636>>2]=r;c[g+3660>>2]=r;c[g+2640>>2]=q;c[g+3664>>2]=q;c[g+2644>>2]=j;c[g+3668>>2]=j;c[g+2648>>2]=o;c[g+3672>>2]=o;c[g+2652>>2]=l;c[g+3676>>2]=l;c[g+2656>>2]=p;c[g+3680>>2]=p;c[g+2660>>2]=k;c[g+3684>>2]=k;c[g+2664>>2]=i;c[g+3688>>2]=i;i=c[2439574]|0;c[g+620>>2]=i;k=i+256|0;c[g+624>>2]=k;p=i+512|0;c[g+628>>2]=p;l=i+768|0;c[g+632>>2]=l;c[g+1644>>2]=i;c[g+1648>>2]=k;c[g+1652>>2]=p;c[g+1656>>2]=l;c[g+2668>>2]=i;c[g+3692>>2]=i;c[g+2672>>2]=k;c[g+3696>>2]=k;c[g+2676>>2]=p;c[g+3700>>2]=p;c[g+2680>>2]=l;c[g+3704>>2]=l;l=c[2439572]|0;c[g+652>>2]=l;p=l+256|0;c[g+656>>2]=p;k=l+512|0;c[g+660>>2]=k;i=l+768|0;c[g+664>>2]=i;c[g+1676>>2]=l;c[g+1680>>2]=p;c[g+1684>>2]=k;c[g+1688>>2]=i;c[g+2700>>2]=l;c[g+3724>>2]=l;c[g+2704>>2]=p;c[g+3728>>2]=p;c[g+2708>>2]=k;c[g+3732>>2]=k;c[g+2712>>2]=i;c[g+3736>>2]=i;i=c[2439570]|0;c[g+684>>2]=i;k=i+256|0;c[g+688>>2]=k;p=i+512|0;c[g+692>>2]=p;l=i+768|0;c[g+696>>2]=l;c[g+1708>>2]=i;c[g+1712>>2]=k;c[g+1716>>2]=p;c[g+1720>>2]=l;c[g+2732>>2]=i;c[g+3756>>2]=i;c[g+2736>>2]=k;c[g+3760>>2]=k;c[g+2740>>2]=p;c[g+3764>>2]=p;c[g+2744>>2]=l;c[g+3768>>2]=l;if(!f){f=g;gGC(f|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=e;c[2417277]=d;c[1836236]=-1;fwR(2);d=c[2439332]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438120];f=c[3528486]|0;c[2076596]=f;g=c[2417278]|0;c[3541536]=g;c[1836236]=2;c[d+4180>>2]=3256;c[d+4184>>2]=3240;l=c[3529104]|0;p=0;k=0;while(1){c[d+76+(k<<2)>>2]=l+(k<<8);i=p+1&65535;if((i&65535)>63){s=0;t=0;break}else{p=i;k=i&65535}}while(1){k=l+(t<<8)|0;c[d+76+(t+512<<2)>>2]=k;c[d+76+(t+768<<2)>>2]=k;k=s+1&65535;if((k&65535)>63){break}else{s=k;t=k&65535}}t=c[3527224]|0;c[d+588>>2]=t;s=t+256|0;c[d+592>>2]=s;l=t+512|0;c[d+596>>2]=l;k=t+768|0;c[d+600>>2]=k;p=t+1024|0;c[d+604>>2]=p;i=t+1280|0;c[d+608>>2]=i;o=t+1536|0;c[d+612>>2]=o;j=t+1792|0;c[d+616>>2]=j;c[d+1612>>2]=t;c[d+1616>>2]=s;c[d+1620>>2]=l;c[d+1624>>2]=k;c[d+1628>>2]=p;c[d+1632>>2]=i;c[d+1636>>2]=o;c[d+1640>>2]=j;c[d+2636>>2]=t;c[d+3660>>2]=t;c[d+2640>>2]=s;c[d+3664>>2]=s;c[d+2644>>2]=l;c[d+3668>>2]=l;c[d+2648>>2]=k;c[d+3672>>2]=k;c[d+2652>>2]=p;c[d+3676>>2]=p;c[d+2656>>2]=i;c[d+3680>>2]=i;c[d+2660>>2]=o;c[d+3684>>2]=o;c[d+2664>>2]=j;c[d+3688>>2]=j;j=c[2439574]|0;c[d+620>>2]=j;o=j+256|0;c[d+624>>2]=o;i=j+512|0;c[d+628>>2]=i;p=j+768|0;c[d+632>>2]=p;c[d+1644>>2]=j;c[d+1648>>2]=o;c[d+1652>>2]=i;c[d+1656>>2]=p;c[d+2668>>2]=j;c[d+3692>>2]=j;c[d+2672>>2]=o;c[d+3696>>2]=o;c[d+2676>>2]=i;c[d+3700>>2]=i;c[d+2680>>2]=p;c[d+3704>>2]=p;p=c[2439572]|0;c[d+652>>2]=p;i=p+256|0;c[d+656>>2]=i;o=p+512|0;c[d+660>>2]=o;j=p+768|0;c[d+664>>2]=j;c[d+1676>>2]=p;c[d+1680>>2]=i;c[d+1684>>2]=o;c[d+1688>>2]=j;c[d+2700>>2]=p;c[d+3724>>2]=p;c[d+2704>>2]=i;c[d+3728>>2]=i;c[d+2708>>2]=o;c[d+3732>>2]=o;c[d+2712>>2]=j;c[d+3736>>2]=j;j=c[2439570]|0;c[d+684>>2]=j;o=j+256|0;c[d+688>>2]=o;i=j+512|0;c[d+692>>2]=i;p=j+768|0;c[d+696>>2]=p;c[d+1708>>2]=j;c[d+1712>>2]=o;c[d+1716>>2]=i;c[d+1720>>2]=p;c[d+2732>>2]=j;c[d+3756>>2]=j;c[d+2736>>2]=o;c[d+3760>>2]=o;c[d+2740>>2]=i;c[d+3764>>2]=i;c[d+2744>>2]=p;c[d+3768>>2]=p;if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438120]=c[2433530];c[3528486]=f;c[2417278]=g;c[1836236]=-1;U_(96e3,3);g=c[2420424]|0;h[g+424>>3]=.5625;c[g+440>>2]=3;h[g+432>>3]=.5625;c[g+444>>2]=3;Vf(0);g=c[2439194]|0;if((g|0)>0){f=c[2406652]|0;e=0;while(1){h[f+(e*40|0)+16>>3]=.8;c[f+(e*40|0)+32>>2]=3;d=e+1|0;if((d|0)<(g|0)){e=d}else{break}}c[3528400]=f+(e*40|0);e=0;while(1){h[f+(e*40|0)+24>>3]=.8;c[f+(e*40|0)+36>>2]=3;d=e+1|0;if((d|0)<(g|0)){e=d}else{break}}c[3528400]=f+(e*40|0)}e=c[642608+(c[2436]<<2)>>2]|0;f=c[e+128>>2]|0;if((c[e+52>>2]&4|0)==0){c[2113068]=f;g=c[e+132>>2]|0;c[2113070]=g;c[2443814]=f;c[2440436]=g;u=f;v=g}else{c[2113070]=f;g=c[e+132>>2]|0;c[2113068]=g;c[2440436]=f;c[2443814]=g;u=g;v=f}f=ag(u<<1,v)|0;v=gGq(f)|0;c[2112926]=v;if((v|0)!=0){gGz(v|0,0,f|0)}f=c[2439330]|0;v=(f|0)==0;if(!v){u=f;gGC(9706056,u|0,76)|0}u=c[2438118]|0;c[2433530]=u;g=c[3528484]|0;c[2076596]=g;e=c[2417276]|0;c[3541536]=e;c[1836236]=0;gGz(9706056,0,76);if(!v){v=f;gGC(v|0,9706056,76)|0}c[2438118]=u;c[3528484]=g;c[2417276]=e;c[1836236]=-1;e=c[2439331]|0;g=(e|0)==0;if(!g){u=e;gGC(9706056,u|0,76)|0}u=c[2438119]|0;c[2433530]=u;v=c[3528485]|0;c[2076596]=v;f=c[2417277]|0;c[3541536]=f;c[1836236]=1;gGz(9706056,0,76);if(!g){g=e;gGC(g|0,9706056,76)|0}c[2438119]=u;c[3528485]=v;c[2417277]=f;c[1836236]=-1;f=c[2439332]|0;v=(f|0)==0;if(!v){u=f;gGC(9706056,u|0,76)|0}u=c[2438120]|0;c[2433530]=u;g=c[3528486]|0;c[2076596]=g;e=c[2417278]|0;c[3541536]=e;c[1836236]=2;gGz(9706056,0,76);if(!v){v=f;gGC(v|0,9706056,76)|0}c[2438120]=u;c[3528486]=g;c[2417278]=e;c[1836236]=-1;e=c[2439194]|0;if((e|0)<=0){a[9755248]=0;a[9755240]=0;a[9755232]=0;a[14109872]=0;a[14109864]=0;a[9759744]=0;gGz(9754992,0,6);c[2438746]=0;c[2438744]=0;a[9718952]=0;a[9730760]=0;a[14116336]=0;a[9757952]=0;a[9718968]=0;a[9718960]=0;gGz(9773304,0,16);return}g=c[2406652]|0;u=0;do{w=g+(u*40|0)|0;v=g+(u*40|0)+12|0;a[v]=0;f=g+(u*40|0)+8|0;c[f>>2]=0;d=a[g+(u*40|0)+14|0]|0;do{if((d&2)!=0&(e|0)>(u|0)){if((d&4)==0){a[g+(u*40|0)+13|0]=1}if((d&1)!=0){break}a[v]=1;c[f>>2]=0}}while(0);u=u+1|0;}while((u|0)<(e|0));c[3528400]=w;a[9755248]=0;a[9755240]=0;a[9755232]=0;a[14109872]=0;a[14109864]=0;a[9759744]=0;gGz(9754992,0,6);c[2438746]=0;c[2438744]=0;a[9718952]=0;a[9730760]=0;a[14116336]=0;a[9757952]=0;a[9718968]=0;a[9718960]=0;gGz(9773304,0,16);return}function dk5(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((e|0)==57352){a[c[3528758]|0]=d&4;return}else if((e|0)==57354|(e|0)==57355){a[(c[2444188]|0)+(e&1)|0]=d;return}else{return}}function dk6(b){b=b|0;var c=0;switch(b&65535|0){case 57344:{c=a[672624]|0?2:0;break};case 57346:{c=a[9635505]|0;break};case 57348:{c=a[9550768]|0;break};case 57349:{c=a[9550769]|0;break};case 57345:{c=a[9635504]|0;break};case 57347:{c=a[9550770]|0;break};default:{c=0}}return c|0}function dk7(a,b){a=a|0;b=b|0;var c=0;c=a&65535;if((c|0)==55297){TR(0,b&255);return}else if((c|0)==55298){TR(1,b&255);return}else{return}}function dk8(a){a=a|0;return 0}function dk9(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7045356+(b*112|0)>>2];c[a+104>>2]=c[7045360+(b*112|0)>>2];c[a+108>>2]=c[7045364+(b*112|0)>>2];d=0;return d|0}function dla(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=7045256+(b*112|0);e=0;return e|0}function dlb(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6271160+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dlc(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>38){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7202216+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dld(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0;e=i;i=i+1320|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;B=e+1200|0;C=e+1312|0;c[2415046]=0;c[3529256]=0;c[3529212]=65536;c[3531036]=131072;c[3529486]=133120;c[3530124]=133376;c[2406986]=137472;c[3530900]=141568;c[3530664]=272640;c[2443392]=403712;c[2414754]=404224;c[3529344]=404224;c[3527314]=406272;c[2386512]=408320;c[2386256]=410368;c[2444188]=412416;c[3528758]=412418;c[2411802]=412419;D=0;while(1){if((D|0)>=1024){break}E=9638528+(D<<2)|0;if((c[E>>2]|0)==0){F=67909;break}else{D=D+1|0}}do{if((F|0)==67909){D=gGq(412419)|0;c[E>>2]=D;if((D|0)==0){break}c[2415046]=D;gGz(D|0,0,412419);c[3529256]=D;c[3529212]=D+65536;c[3531036]=D+131072;c[3529486]=D+133120;c[3530124]=D+133376;c[2406986]=D+137472;c[3530900]=D+141568;c[3530664]=D+272640;c[2443392]=D+403712;G=D+404224|0;c[2414754]=G;c[3529344]=G;c[3527314]=D+406272;c[2386512]=D+408320;c[2386256]=D+410368;c[2444188]=D+412416;c[3528758]=D+412418;G=D+412419|0;c[2411802]=G;c[2414350]=G;if((c[3542200]|0)==0){H=1;i=e;return H|0}G=B+108|0;c[G>>2]=0;I=B+100|0;c[I>>2]=0;J=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[J&16383](B,0)|0;do{if((c[G>>2]|0)!=0){J=c[I>>2]|0;c[C>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](C,0,0)|0;if((J|0)<1){H=1;i=e;return H|0}if((gzL(D,0,0)|0)==0){break}else{H=1}i=e;return H|0}}while(0);D=c[3529256]|0;I=D+32768|0;G=D+8192|0;gGC(I|0,G|0,8192)|0;if((c[3542200]|0)==0){H=1;i=e;return H|0}I=z+108|0;c[I>>2]=0;D=z+100|0;c[D>>2]=0;J=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[J&16383](z,1)|0;do{if((c[I>>2]|0)!=0){J=c[D>>2]|0;c[A>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](A,1,0)|0;if((J|0)<1){H=1;i=e;return H|0}if((gzL(G,0,1)|0)==0){break}else{H=1}i=e;return H|0}}while(0);G=(c[3529256]|0)+16384|0;if((c[3542200]|0)==0){H=1;i=e;return H|0}D=x+108|0;c[D>>2]=0;I=x+100|0;c[I>>2]=0;J=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[J&16383](x,2)|0;do{if((c[D>>2]|0)!=0){J=c[I>>2]|0;c[y>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](y,2,0)|0;if((J|0)<1){H=1;i=e;return H|0}if((gzL(G,0,2)|0)==0){break}else{H=1}i=e;return H|0}}while(0);G=(c[3529256]|0)+24576|0;if((c[3542200]|0)==0){H=1;i=e;return H|0}I=v+108|0;c[I>>2]=0;D=v+100|0;c[D>>2]=0;J=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[J&16383](v,3)|0;do{if((c[I>>2]|0)!=0){J=c[D>>2]|0;c[w>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](w,3,0)|0;if((J|0)<1){H=1;i=e;return H|0}if((gzL(G,0,3)|0)==0){break}else{H=1}i=e;return H|0}}while(0);G=c[3529212]|0;if((c[3542200]|0)==0){H=1;i=e;return H|0}D=t+108|0;c[D>>2]=0;I=t+100|0;c[I>>2]=0;J=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[J&16383](t,4)|0;do{if((c[D>>2]|0)!=0){J=c[I>>2]|0;c[u>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](u,4,0)|0;if((J|0)<1){H=1;i=e;return H|0}if((gzL(G,0,4)|0)==0){break}else{H=1}i=e;return H|0}}while(0);G=r+108|0;I=r+100|0;D=p+108|0;J=p+100|0;K=n+108|0;L=n+100|0;M=0;while(1){N=M<<14;O=(c[3530664]|0)+N|0;P=M+5|0;if((c[3542200]|0)==0){H=1;F=68078;break}c[G>>2]=0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,P)|0;if((c[G>>2]|0)!=0){Q=c[I>>2]|0;c[s>>2]=9534384;R=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[R&16383](s,P,0)|0;if((Q|0)<1){H=1;F=68057;break}if((gzL(O,0,P)|0)!=0){H=1;F=68063;break}}P=(c[3530900]|0)+N|0;N=M+8|0;if((c[3542200]|0)==0){H=1;F=68051;break}c[D>>2]=0;c[J>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,N)|0;if((c[D>>2]|0)!=0){O=c[J>>2]|0;c[q>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](q,N,0)|0;if((O|0)<1){H=1;F=68070;break}if((gzL(P,0,N)|0)!=0){H=1;F=68056;break}}N=(c[3531036]|0)+(M<<8)|0;P=M+11|0;if((c[3542200]|0)==0){H=1;F=68058;break}c[K>>2]=0;c[L>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,P)|0;if((c[K>>2]|0)!=0){O=c[L>>2]|0;c[o>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](o,P,0)|0;if((O|0)<1){H=1;F=68075;break}if((gzL(N,0,P)|0)!=0){H=1;F=68076;break}}P=M+1|0;if((P|0)<3){M=P}else{F=67945;break}}if((F|0)==68051){i=e;return H|0}else if((F|0)==68056){i=e;return H|0}else if((F|0)==68057){i=e;return H|0}else if((F|0)==68058){i=e;return H|0}else if((F|0)==68063){i=e;return H|0}else if((F|0)==68070){i=e;return H|0}else if((F|0)==68075){i=e;return H|0}else if((F|0)==68076){i=e;return H|0}else if((F|0)==68078){i=e;return H|0}else if((F|0)==67945){M=(c[3531036]|0)+768|0;if((c[3542200]|0)==0){H=1;i=e;return H|0}L=l+108|0;c[L>>2]=0;K=l+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,14)|0;do{if((c[L>>2]|0)!=0){J=c[K>>2]|0;c[m>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](m,14,0)|0;if((J|0)<1){H=1;i=e;return H|0}if((gzL(M,0,14)|0)==0){break}else{H=1}i=e;return H|0}}while(0);M=(c[3531036]|0)+1280|0;if((c[3542200]|0)==0){H=1;i=e;return H|0}K=j+108|0;c[K>>2]=0;L=j+100|0;c[L>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,15)|0;do{if((c[K>>2]|0)!=0){J=c[L>>2]|0;c[k>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](k,15,0)|0;if((J|0)<1){H=1;i=e;return H|0}if((gzL(M,0,15)|0)==0){break}else{H=1}i=e;return H|0}}while(0);M=c[3529486]|0;if((c[3542200]|0)==0){H=1;i=e;return H|0}L=f+108|0;c[L>>2]=0;K=f+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,16)|0;do{if((c[L>>2]|0)==0){S=0}else{J=c[K>>2]|0;c[g>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](g,16,0)|0;if((J|0)<1){H=1;i=e;return H|0}if((gzL(M,0,16)|0)==0){S=0;break}else{H=1}i=e;return H|0}}while(0);while(1){if((S|0)>=1024){T=0;break}U=9638528+(S<<2)|0;if((c[U>>2]|0)==0){F=67959;break}else{S=S+1|0}}L81452:do{if((F|0)==67959){M=gGq(49152)|0;c[U>>2]=M;if((M|0)==0){T=0;break}gGz(M|0,0,49152);K=c[3530900]|0;gGC(M|0,K|0,49152)|0;L=0;do{J=L<<6;gGz(K+J|0,0,64);D=J+262144|0;I=0;do{G=D+(c[612096+(I<<2)>>2]|0)|0;P=(I<<3)+J|0;N=0;do{O=G+(c[610384+(N<<2)>>2]|0)|0;if(((d[M+((O|0)/8|0)|0]|0)&128>>>((O&7)>>>0)|0)!=0){O=K+(P+N)|0;a[O]=a[O]|4}N=N+1|0;}while((N|0)<8);I=I+1|0;}while((I|0)<8);I=J+131072|0;D=0;while(1){N=I+(c[612096+(D<<2)>>2]|0)|0;P=(D<<3)+J|0;G=0;do{O=N+(c[610384+(G<<2)>>2]|0)|0;if(((d[M+((O|0)/8|0)|0]|0)&128>>>((O&7)>>>0)|0)!=0){O=K+(P+G)|0;a[O]=a[O]|2}G=G+1|0;}while((G|0)<8);G=D+1|0;if((G|0)<8){D=G}else{V=0;break}}do{D=J+(c[612096+(V<<2)>>2]|0)|0;I=(V<<3)+J|0;G=0;do{P=D+(c[610384+(G<<2)>>2]|0)|0;if(((d[M+((P|0)/8|0)|0]|0)&128>>>((P&7)>>>0)|0)!=0){P=K+(I+G)|0;a[P]=a[P]|1}G=G+1|0;}while((G|0)<8);V=V+1|0;}while((V|0)<8);L=L+1|0;}while((L|0)<2048);L=c[3530664]|0;gGC(M|0,L|0,49152)|0;K=0;while(1){J=K<<9;gGz(L+J|0,0,512);G=J+262144|0;I=0;do{D=G+(c[612096+(I<<2)>>2]|0)|0;P=(I<<4)+J|0;N=0;do{O=D+(c[610384+(N<<2)>>2]|0)|0;if(((d[M+((O|0)/8|0)|0]|0)&128>>>((O&7)>>>0)|0)!=0){O=L+(P+N)|0;a[O]=a[O]|4}N=N+1|0;}while((N|0)<16);I=I+1|0;}while((I|0)<32);I=J+131072|0;G=0;while(1){N=I+(c[612096+(G<<2)>>2]|0)|0;P=(G<<4)+J|0;D=0;do{O=N+(c[610384+(D<<2)>>2]|0)|0;if(((d[M+((O|0)/8|0)|0]|0)&128>>>((O&7)>>>0)|0)!=0){O=L+(P+D)|0;a[O]=a[O]|2}D=D+1|0;}while((D|0)<16);D=G+1|0;if((D|0)<32){G=D}else{W=0;break}}do{G=J+(c[612096+(W<<2)>>2]|0)|0;I=(W<<4)+J|0;D=0;do{P=G+(c[610384+(D<<2)>>2]|0)|0;if(((d[M+((P|0)/8|0)|0]|0)&128>>>((P&7)>>>0)|0)!=0){P=L+(I+D)|0;a[P]=a[P]|1}D=D+1|0;}while((D|0)<16);W=W+1|0;}while((W|0)<32);J=K+1|0;if((J|0)<256){K=J}else{X=0;break}}while(1){if((X|0)>=1024){T=0;break L81452}Y=9638528+(X<<2)|0;if((c[Y>>2]|0)==(M|0)){break}else{X=X+1|0}}gGr(M);c[Y>>2]=0;T=0}}while(0);while(1){if((T|0)>=1024){Z=0;break}_=9638528+(T<<2)|0;if((c[_>>2]|0)==0){F=67981;break}else{T=T+1|0}}do{if((F|0)==67981){K=gGq(1024)|0;c[_>>2]=K;if((K|0)==0){Z=0;break}gGz(K|0,0,1024);Z=K}}while(0);K=Z;L=c[3531036]|0;J=0;do{D=a[L+J|0]&15;I=a[L+(J+256)|0]&15;G=a[L+(J+512)|0]&15;c[K+(J<<2)>>2]=D<<20|D<<16|I<<12|I<<8|G|G<<4;J=J+1|0;}while((J|0)<256);c[3531036]=L+768;J=c[2443392]|0;gGz(J|0,1,512);G=c[2406986]|0;I=0;while(1){D=a[L+(I+768)|0]|0;P=I&7;if((P|0)==7&D<<24>>24==-1){a[J+I|0]=0}if((P|0)==0){a[J+I|0]=0}c[G+(I<<2)>>2]=c[K+(((D&255^255)&65535)<<2)>>2];D=I+1|0;if((D|0)<512){I=D}else{$=512;break}}while(1){c[G+($<<2)>>2]=c[K+((d[L+($+768)|0]|0)<<2)>>2];I=$+1|0;if((I|0)<1024){$=I}else{aa=0;break}}while(1){if((aa|0)>=1024){break}ab=9638528+(aa<<2)|0;if((c[ab>>2]|0)==(Z|0)){F=67994;break}else{aa=aa+1|0}}if((F|0)==67994){gGr(Z);c[ab>>2]=0}fwR(0);L=c[2439330]|0;K=(L|0)==0;if(!K){G=L;gGC(9706056,G|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];G=c[3528484]|0;c[2076596]=G;I=c[2417276]|0;c[3541536]=I;c[1836236]=0;J=c[3529256]|0;D=0;P=0;while(1){c[L+76+(P<<2)>>2]=J+(P<<8);N=D+1&65535;if((N&65535)>159){ac=0;ad=0;break}else{D=N;P=N&65535}}while(1){P=J+(ad<<8)|0;c[L+76+(ad+512<<2)>>2]=P;c[L+76+(ad+768<<2)>>2]=P;P=ac+1&65535;if((P&65535)>159){break}else{ac=P;ad=P&65535}}J=c[3529344]|0;c[L+844>>2]=J;P=J+256|0;c[L+848>>2]=P;D=J+512|0;c[L+852>>2]=D;N=J+768|0;c[L+856>>2]=N;O=J+1024|0;c[L+860>>2]=O;Q=J+1280|0;c[L+864>>2]=Q;R=J+1536|0;c[L+868>>2]=R;ae=J+1792|0;c[L+872>>2]=ae;c[L+1868>>2]=J;c[L+1872>>2]=P;c[L+1876>>2]=D;c[L+1880>>2]=N;c[L+1884>>2]=O;c[L+1888>>2]=Q;c[L+1892>>2]=R;c[L+1896>>2]=ae;c[L+2892>>2]=J;c[L+3916>>2]=J;c[L+2896>>2]=P;c[L+3920>>2]=P;c[L+2900>>2]=D;c[L+3924>>2]=D;c[L+2904>>2]=N;c[L+3928>>2]=N;c[L+2908>>2]=O;c[L+3932>>2]=O;c[L+2912>>2]=Q;c[L+3936>>2]=Q;c[L+2916>>2]=R;c[L+3940>>2]=R;c[L+2920>>2]=ae;c[L+3944>>2]=ae;ae=c[3527314]|0;c[L+876>>2]=ae;R=ae+256|0;c[L+880>>2]=R;Q=ae+512|0;c[L+884>>2]=Q;O=ae+768|0;c[L+888>>2]=O;N=ae+1024|0;c[L+892>>2]=N;D=ae+1280|0;c[L+896>>2]=D;P=ae+1536|0;c[L+900>>2]=P;J=ae+1792|0;c[L+904>>2]=J;c[L+1900>>2]=ae;c[L+1904>>2]=R;c[L+1908>>2]=Q;c[L+1912>>2]=O;c[L+1916>>2]=N;c[L+1920>>2]=D;c[L+1924>>2]=P;c[L+1928>>2]=J;c[L+2924>>2]=ae;c[L+3948>>2]=ae;c[L+2928>>2]=R;c[L+3952>>2]=R;c[L+2932>>2]=Q;c[L+3956>>2]=Q;c[L+2936>>2]=O;c[L+3960>>2]=O;c[L+2940>>2]=N;c[L+3964>>2]=N;c[L+2944>>2]=D;c[L+3968>>2]=D;c[L+2948>>2]=P;c[L+3972>>2]=P;c[L+2952>>2]=J;c[L+3976>>2]=J;J=c[2386256]|0;c[L+908>>2]=J;P=J+256|0;c[L+912>>2]=P;D=J+512|0;c[L+916>>2]=D;N=J+768|0;c[L+920>>2]=N;O=J+1024|0;c[L+924>>2]=O;Q=J+1280|0;c[L+928>>2]=Q;R=J+1536|0;c[L+932>>2]=R;ae=J+1792|0;c[L+936>>2]=ae;c[L+1932>>2]=J;c[L+1936>>2]=P;c[L+1940>>2]=D;c[L+1944>>2]=N;c[L+1948>>2]=O;c[L+1952>>2]=Q;c[L+1956>>2]=R;c[L+1960>>2]=ae;c[L+2956>>2]=J;c[L+3980>>2]=J;c[L+2960>>2]=P;c[L+3984>>2]=P;c[L+2964>>2]=D;c[L+3988>>2]=D;c[L+2968>>2]=N;c[L+3992>>2]=N;c[L+2972>>2]=O;c[L+3996>>2]=O;c[L+2976>>2]=Q;c[L+4e3>>2]=Q;c[L+2980>>2]=R;c[L+4004>>2]=R;c[L+2984>>2]=ae;c[L+4008>>2]=ae;c[L+4184>>2]=2262;c[L+4180>>2]=2330;if(!K){ae=L;gGC(ae|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=G;c[2417276]=I;c[1836236]=-1;fwR(1);ae=c[2439331]|0;R=(ae|0)==0;if(!R){Q=ae;gGC(9706056,Q|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];Q=c[3528485]|0;c[2076596]=Q;O=c[2417277]|0;c[3541536]=O;c[1836236]=1;N=c[3529212]|0;D=0;P=0;while(1){c[ae+76+(P<<2)>>2]=N+(P<<8);J=D+1&65535;if((J&65535)>31){af=0;ah=0;break}else{D=J;P=J&65535}}while(1){P=N+(ah<<8)|0;c[ae+76+(ah+512<<2)>>2]=P;c[ae+76+(ah+768<<2)>>2]=P;P=af+1&65535;if((P&65535)>31){break}else{af=P;ah=P&65535}}N=c[2386512]|0;c[ae+844>>2]=N;P=N+256|0;c[ae+848>>2]=P;D=N+512|0;c[ae+852>>2]=D;I=N+768|0;c[ae+856>>2]=I;G=N+1024|0;c[ae+860>>2]=G;L=N+1280|0;c[ae+864>>2]=L;K=N+1536|0;c[ae+868>>2]=K;J=N+1792|0;c[ae+872>>2]=J;c[ae+1868>>2]=N;c[ae+1872>>2]=P;c[ae+1876>>2]=D;c[ae+1880>>2]=I;c[ae+1884>>2]=G;c[ae+1888>>2]=L;c[ae+1892>>2]=K;c[ae+1896>>2]=J;c[ae+2892>>2]=N;c[ae+3916>>2]=N;c[ae+2896>>2]=P;c[ae+3920>>2]=P;c[ae+2900>>2]=D;c[ae+3924>>2]=D;c[ae+2904>>2]=I;c[ae+3928>>2]=I;c[ae+2908>>2]=G;c[ae+3932>>2]=G;c[ae+2912>>2]=L;c[ae+3936>>2]=L;c[ae+2916>>2]=K;c[ae+3940>>2]=K;c[ae+2920>>2]=J;c[ae+3944>>2]=J;J=c[3527314]|0;c[ae+876>>2]=J;K=J+256|0;c[ae+880>>2]=K;L=J+512|0;c[ae+884>>2]=L;G=J+768|0;c[ae+888>>2]=G;I=J+1024|0;c[ae+892>>2]=I;D=J+1280|0;c[ae+896>>2]=D;P=J+1536|0;c[ae+900>>2]=P;N=J+1792|0;c[ae+904>>2]=N;c[ae+1900>>2]=J;c[ae+1904>>2]=K;c[ae+1908>>2]=L;c[ae+1912>>2]=G;c[ae+1916>>2]=I;c[ae+1920>>2]=D;c[ae+1924>>2]=P;c[ae+1928>>2]=N;c[ae+2924>>2]=J;c[ae+3948>>2]=J;c[ae+2928>>2]=K;c[ae+3952>>2]=K;c[ae+2932>>2]=L;c[ae+3956>>2]=L;c[ae+2936>>2]=G;c[ae+3960>>2]=G;c[ae+2940>>2]=I;c[ae+3964>>2]=I;c[ae+2944>>2]=D;c[ae+3968>>2]=D;c[ae+2948>>2]=P;c[ae+3972>>2]=P;c[ae+2952>>2]=N;c[ae+3976>>2]=N;c[ae+4184>>2]=1152;c[ae+4180>>2]=1848;if(!R){N=ae;gGC(N|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=Q;c[2417277]=O;c[1836236]=-1;TS(0,2e6,32768,6,0,0);TS(1,4e6,32768,6,0,1);N=c[2420348]|0;h[N+192>>3]=.75;c[N+200>>2]=3;N=c[2420346]|0;h[N+192>>3]=.75;c[N+200>>2]=3;N=c[642608+(c[2436]<<2)>>2]|0;P=c[N+128>>2]|0;if((c[N+52>>2]&4|0)==0){c[2113068]=P;D=c[N+132>>2]|0;c[2113070]=D;c[2443814]=P;c[2440436]=D;ai=P;aj=D}else{c[2113070]=P;D=c[N+132>>2]|0;c[2113068]=D;c[2440436]=P;c[2443814]=D;ai=D;aj=P}P=ag(ai<<1,aj)|0;D=gGq(P)|0;c[2112926]=D;if((D|0)!=0){gGz(D|0,0,P|0)}a[9624776]=0;P=c[2414754]|0;gGz(P|0,0,(c[2411802]|0)-P|0);P=c[2439330]|0;D=(P|0)==0;if(!D){N=P;gGC(9706056,N|0,76)|0}N=c[2438118]|0;c[2433530]=N;I=c[3528484]|0;c[2076596]=I;G=c[2417276]|0;c[3541536]=G;c[1836236]=0;gGz(9706056,0,76);if(!D){D=P;gGC(D|0,9706056,76)|0}c[2438118]=N;c[3528484]=I;c[2417276]=G;c[1836236]=-1;G=c[2439331]|0;I=(G|0)==0;if(!I){N=G;gGC(9706056,N|0,76)|0}N=c[2438119]|0;c[2433530]=N;D=c[3528485]|0;c[2076596]=D;P=c[2417277]|0;c[3541536]=P;c[1836236]=1;gGz(9706056,0,76);if(!I){I=G;gGC(I|0,9706056,76)|0}c[2438119]=N;c[3528485]=D;c[2417277]=P;c[1836236]=-1;H=0;i=e;return H|0}}}while(0);c[2415046]=0;H=1;i=e;return H|0}function dle(){var a=0,b=0,d=0,e=0;c[2113070]=0;c[2113068]=0;a=c[2112926]|0;if((a|0)!=0){gGr(a);c[2112926]=0}TT();fwZ();a=c[2415046]|0;b=0;while(1){if((b|0)>=1024){d=68089;break}e=9638528+(b<<2)|0;if((c[e>>2]|0)==(a|0)){break}else{b=b+1|0}}if((d|0)==68089){c[2415046]=0;return 0}gGr(a);c[e>>2]=0;c[2415046]=0;return 0}function dlf(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;if((a[9624776]|0)!=0){a[9624776]=0;d=c[2414754]|0;gGz(d|0,0,(c[2411802]|0)-d|0);d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;h=c[2417276]|0;c[3541536]=h;c[1836236]=0;gGz(9706056,0,76);if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=h;c[1836236]=-1;h=c[2439331]|0;g=(h|0)==0;if(!g){f=h;gGC(9706056,f|0,76)|0}f=c[2438119]|0;c[2433530]=f;e=c[3528485]|0;c[2076596]=e;d=c[2417277]|0;c[3541536]=d;c[1836236]=1;gGz(9706056,0,76);if(!g){g=h;gGC(g|0,9706056,76)|0}c[2438119]=f;c[3528485]=e;c[2417277]=d;c[1836236]=-1}gGz(9550768,0,3);d=0;e=0;f=0;g=0;do{e=((a[9634136+d|0]&1)<<d^e&255)&255;f=((a[9631912+d|0]&1)<<d^f&255)&255;g=((a[9629840+d|0]&1)<<d^g&255)&255;d=d+1|0;}while((d|0)<8);a[9550768]=e;a[9550769]=f;a[9550770]=g;if((a[9634138]|0)!=0&(a[9634139]|0)!=0){g=e&-13;a[9550768]=g;i=g}else{i=e}if((a[9634137]|0)!=0&(a[9634136]|0)!=0){a[9550768]=i&-4}if((a[9631915]|0)!=0&(a[9631914]|0)!=0){i=f&-13;a[9550769]=i;j=i}else{j=f}if((a[9631913]|0)!=0&(a[9631912]|0)!=0){a[9550769]=j&-4}a[672624]=1;j=0;f=0;i=0;while(1){e=256-i|0;g=(66666-f|0)/(e|0)|0;d=c[2439330]|0;if((d|0)!=0){h=d;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;h=c[2438118]|0;c[2433530]=h;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;do{if((g|0)<1){k=0}else{if((a[d+4188|0]|0)==0){l=gfc(g)|0;c[2433530]=(c[2433530]|0)+l;k=l;break}else{c[2433530]=h+g;k=g;break}}}while(0);g=k+f|0;h=(i|0)==15;do{if(h){a[672624]=0;a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0;m=0}else{if((i|0)!=239){m=0;break}a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0;a[672624]=1;m=1}}while(0);d=c[1836236]|0;l=c[9757320+(d<<2)>>2]|0;if((l|0)!=0){n=l;gGC(n|0,9706056,76)|0}c[9752472+(d<<2)>>2]=c[2433530];c[14113936+(d<<2)>>2]=c[2076596];c[9669104+(d<<2)>>2]=c[3541536];c[1836236]=-1;d=(66666-j|0)/(e|0)|0;n=c[2439331]|0;if((n|0)!=0){l=n;gGC(9706056,l|0,76)|0}b[4853030]=c[2426515]&65535;l=c[2438119]|0;c[2433530]=l;c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;do{if((d|0)<1){o=0}else{if((a[n+4188|0]|0)==0){p=gfc(d)|0;c[2433530]=(c[2433530]|0)+p;o=p;break}else{c[2433530]=l+d;o=d;break}}}while(0);if(h){a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0}if(m){a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0}d=c[1836236]|0;l=c[9757320+(d<<2)>>2]|0;if((l|0)!=0){n=l;gGC(n|0,9706056,76)|0}c[9752472+(d<<2)>>2]=c[2433530];c[14113936+(d<<2)>>2]=c[2076596];c[9669104+(d<<2)>>2]=c[3541536];c[1836236]=-1;d=i+1|0;if((d|0)<256){j=o+j|0;f=g;i=d}else{break}}i=c[2112964]|0;if((i|0)!=0){f=a[9688]|0?534:0;TQ(0,i,f);TQ(1,i,f)}if((c[2112968]|0)==0){return 0}dlg()|0;return 0}function dlg(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;if((a[9547800]|0)!=0){e=c[2406986]|0;f=c[3530124]|0;g=0;do{h=c[e+(g<<2)>>2]|0;c[f+(g<<2)>>2]=h>>8<<3&2016|h>>>3&31|h>>16<<8&63488;g=g+1|0;}while((g|0)<1024)}dlk(0);g=c[2386512]|0;f=c[3528758]|0;e=c[3530664]|0;h=c[2113068]|0;i=c[2113070]|0;j=c[2443392]|0;k=c[2112926]|0;l=0;do{m=d[g+(l|2)|0]|0;n=d[g+(l|3)|0]|0;o=d[g+l|0]|0;p=(a[f]|0)==0;q=p?224-o|0:o;o=p?n:240-n|0;n=o&255;r=q&255;s=(r>>>0>240?q|-256:r)-16|0;r=(n>>>0>248?o|-256:n)-8|0;n=e+(((d[g+(l|1)|0]|0)>>>1|m&128)<<9)|0;o=m<<3&504;if(p){p=n;m=0;while(1){q=m+s|0;t=(q|0)<(i|0);u=ag(h,q)|0;v=0;do{w=v+r|0;x=d[p+v|0]|o;do{if((w|q|0)>=0){if(!((w|0)<(h|0)&t)){break}if((a[j+x|0]|0)==0){break}b[k+(u+w<<1)>>1]=x&65535}}while(0);v=v+1|0;}while((v|0)<16);v=m+1|0;if((v|0)<32){p=p+16|0;m=v}else{break}}}else{m=31;p=n;while(1){v=m+s|0;u=(v|0)<(i|0);t=ag(h,v)|0;q=15;while(1){x=q+r|0;w=d[p+(15-q)|0]|o;do{if((x|v|0)>=0){if(!((x|0)<(h|0)&u)){break}if((a[j+w|0]|0)==0){break}b[k+(t+x<<1)>>1]=w&65535}}while(0);if((q|0)>0){q=q-1|0}else{break}}if((m|0)>0){m=m-1|0;p=p+16|0}else{break}}}l=l+4|0;}while((l|0)<2048);dlk(1);R8(c[3530124]|0);return 0}function dlh(a,b){a=a|0;b=b|0;var d=0,e=0;d=i;i=i+16|0;e=d|0;if((b|0)!=0){c[b>>2]=169624}if((a&96|0)==0){i=d;return 0}gGz(e|0,0,12);b=c[2414754]|0;c[e>>2]=b;c[e+4>>2]=(c[2411802]|0)-b;c[e+12>>2]=162152;gj[c[2076592]&4095](e)|0;fw$(a);i=d;return 0}function dli(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5900244+(b*112|0)>>2];c[a+104>>2]=c[5900248+(b*112|0)>>2];c[a+108>>2]=c[5900252+(b*112|0)>>2];d=0;return d|0}function dlj(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=5900144+(b*112|0);e=0;return e|0}function dlk(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=c[3529486]|0;f=c[2386256]|0;if((b|0)!=0){b=c[3528758]|0;g=c[2112926]|0;h=c[3530900]|0;i=0;do{j=i>>5;k=j<<3;l=i<<3&248;m=a[e+j|0]|0;do{if((m<<24>>24|0)==13|(m<<24>>24|0)==0){j=i<<1;n=d[f+j|0]|0;o=n<<3&1792|d[f+(j|1)|0];j=n>>>2&32|n&31;if((a[b]|0)==0){Sj(g,o,k-8|0,l-16|0,j,3,512,h);break}else{Sp(g,o,240-k|0,232-l|0,j,3,512,h);break}}}while(0);i=i+1|0;}while((i|0)<1024);return}i=c[2444188]|0;h=i+1|0;g=c[3528758]|0;b=c[2112926]|0;l=c[3530900]|0;k=0;do{m=k>>5;j=m<<3;o=k<<3;n=k<<1;p=d[f+n|0]|0;q=p<<3&1792|d[f+(n|1)|0];n=p>>>2&32|p&31;if((a[e+m|0]|0)==2){m=j-(d[h]|0)|0;r=(m|0)<0?m+176|0:m;s=(d[i]^255)+o&255}else{r=j;s=o&248}if((a[g]|0)==0){Sj(b,q,r-8|0,s-16|0,n,3,512,l)}else{Sp(b,q,240-r|0,232-s|0,n,3,512,l)}k=k+1|0;}while((k|0)<1024);return}function dll(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;f=b&65535;if((f&49152|0)==32768){g=b&16383;a[(c[2386254]|0)+g|0]=e;h=g>>>8<<2|(b&255)<<8;b=c[3529558]|0;g=b+h|0;i=c[3531066]|0;j=a[i]|0;if((j&8)==0){k=j}else{j=(e&255)>>>3;a[g]=j&2|e&1|a[g]&-4;l=b+(h|1)|0;a[l]=(e&255)>>>1&1|(e&255)>>>4&2|a[l]&-4;l=b+(h|2)|0;a[l]=(e&255)>>>2&1|(e&255)>>>5&2|a[l]&-4;l=b+(h|3)|0;a[l]=j&1|(e&255)>>>6&2|a[l]&-4;k=a[i]|0}if((k&4)==0){m=k}else{k=(e&255)>>>1;a[g]=e<<2&4|k&8|a[g]&-13;l=b+(h|1)|0;a[l]=e<<1&4|(e&255)>>>2&8|a[l]&-13;l=b+(h|2)|0;a[l]=(e&255)>>>3&8|e&4|a[l]&-13;l=b+(h|3)|0;a[l]=k&4|(e&255)>>>4&8|a[l]&-13;m=a[i]|0}if((m&2)==0){n=m}else{m=e<<1;a[g]=e<<4&16|m&32|a[g]&-49;l=b+(h|1)|0;a[l]=e<<3&16|e&32|a[l]&-49;l=b+(h|2)|0;a[l]=e<<2&16|(e&255)>>>1&32|a[l]&-49;l=b+(h|3)|0;a[l]=m&16|(e&255)>>>2&32|a[l]&-49;n=a[i]|0}if((n&1)==0){return}n=e<<3;a[g]=e<<6&64|n&-128|a[g]&63;g=b+(h|1)|0;a[g]=e<<5&64|e<<2&-128|a[g]&63;g=b+(h|2)|0;a[g]=e<<4&64|e<<1&-128|a[g]&63;g=b+(h|3)|0;a[g]=n&64|e&-128|a[g]&63;return}if((f&61440|0)!=57344){return}g=f&7;f=c[3531066]|0;a[f+g|0]=e;if((g|0)!=6){return}g=d[f+6|0]|0;e=d[f+5|0]|0;n=d[f+3|0]|0;h=d[f]|0;b=(h&1|0)==0;i=(h&4|0)==0;h=(e<<2)+4|0;l=c[3529558]|0;m=0;k=(c[2387832]|0)+((((d[f+2|0]|0)<<8|(d[f+1|0]|0))&65535)<<2)|0;j=a[f+4|0]<<2;while(1){f=j&255;if(b){o=0;p=k;while(1){q=a[p]|0;r=a[p+1|0]|0;s=a[p+2|0]|0;t=p+4|0;u=a[p+3|0]|0;v=o+n<<8&65280|f;w=l+v|0;do{if(!i){if(u<<24>>24!=8){a[w]=a[w]&-16|u}if(s<<24>>24!=8){x=l+(v|1)|0;a[x]=a[x]&-16|s}if(r<<24>>24!=8){x=l+(v|2)|0;a[x]=a[x]&-16|r}if(q<<24>>24==8){break}x=l+(v|3)|0;a[x]=a[x]&-16|q}}while(0);q=o+1|0;if((q|0)>(e|0)){break}else{o=q;p=t}}}else{p=0;o=k;while(1){q=a[o]|0;v=a[o+1|0]|0;r=a[o+2|0]|0;s=o+4|0;u=a[o+3|0]|0;w=p+n<<8&65280|f;x=l+w|0;y=u<<24>>24==8;if(!y){a[x]=a[x]&15|u<<4}z=r<<24>>24==8;if(!z){A=l+(w|1)|0;a[A]=a[A]&15|r<<4}A=v<<24>>24==8;if(!A){B=l+(w|2)|0;a[B]=a[B]&15|v<<4}B=q<<24>>24==8;if(!B){C=l+(w|3)|0;a[C]=a[C]&15|q<<4}do{if(!i){if(!y){a[x]=a[x]&-16|u}if(!z){C=l+(w|1)|0;a[C]=a[C]&-16|r}if(!A){C=l+(w|2)|0;a[C]=a[C]&-16|v}if(B){break}C=l+(w|3)|0;a[C]=a[C]&-16|q}}while(0);q=p+1|0;if((q|0)>(e|0)){break}else{p=q;o=s}}}o=m+1|0;if((o|0)>(g|0)){break}else{m=o;k=k+h|0;j=j+4&255}}return}function dlm(b){b=b|0;var d=0,e=0,f=0,g=0,h=0;d=b&65535;e=d&65024;L81819:do{if((e|0)==49152){f=a[9550760]|0}else if((e|0)==49664){f=a[9635496]|0}else{if((d&65280|0)!=55040){f=0;break}g=b&2047;h=g&65535;if((c[2432970]|0)!=0|(g&65535)<2032){f=a[(c[2386120]|0)+h|0]|0;break}g=h&15;switch(g|0){case 8:{f=a[(c[2386120]|0)+(h-1)|0]|0;break L81819;break};case 0:case 1:case 2:case 3:case 4:case 5:{f=a[g+9550762|0]|0;break L81819;break};case 6:{g=c[2436756]^1;c[2436756]=g;f=g&255;break L81819;break};default:{f=0;break L81819}}}}while(0);return f|0}function dln(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((e|0)==51200){c[3542228]=d&15;return}else if((e|0)==51712){e=d&255;b=c[3542228]|0;if((b|0)>15){return}do{if((b|0)<14){if((b|0)!=13){if((a[14168916+b|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(0,b,e);return}else{return}}function dlo(b,d){b=b|0;d=d|0;a[c[2439324]|0]=d>>>3&255;return}function dlp(a,b){a=a|0;b=b|0;c[2432970]=b&16^16;return}function dlq(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4835268+(b*112|0)>>2];c[a+104>>2]=c[4835272+(b*112|0)>>2];c[a+108>>2]=c[4835276+(b*112|0)>>2];d=0;return d|0}function dlr(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=4835168+(b*112|0);e=0;return e|0}function dls(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=2015528+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dlt(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>41){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5609136+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dlu(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0.0,Z=0,_=0;e=i;i=i+1216|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;c[2415044]=0;c[2385966]=0;c[2387832]=32768;c[2406984]=98304;c[3530122]=131072;c[2439138]=163840;y=a[9688]|0?1068:0;z=y|163840;c[2439139]=z;A=z+y|0;c[2439140]=A;z=A+y|0;y=z|0;c[2414752]=y;c[2386120]=y;c[2386254]=z+2048;c[3531066]=z+18432;c[3529558]=z+22528;c[3528756]=z+88064;c[2439324]=z+88065;y=z+88066|0;c[2411800]=y;c[2414348]=y;z=y;y=0;while(1){if((y|0)>=1024){break}B=9638528+(y<<2)|0;if((c[B>>2]|0)==0){C=68303;break}else{y=y+1|0}}do{if((C|0)==68303){y=gGq(z)|0;c[B>>2]=y;if((y|0)==0){break}gGz(y|0,0,z|0);c[2415044]=y;gGz(y|0,0,z|0);c[2385966]=y;c[2387832]=y+32768;c[2406984]=y+98304;c[3530122]=y+131072;c[2439138]=y+163840;A=a[9688]|0?1068:0;D=A|163840;c[2439139]=y+D;E=D+A|0;c[2439140]=y+E;D=E+A|0;A=y+D|0;c[2414752]=A;c[2386120]=A;c[2386254]=y+(D+2048);c[3531066]=y+(D+18432);c[3529558]=y+(D+22528);c[3528756]=y+(D+88064);c[2439324]=y+(D+88065);A=y+(D+88066)|0;c[2411800]=A;c[2414348]=A;if((c[3542200]|0)==0){F=1;i=e;return F|0}A=v+108|0;c[A>>2]=0;D=v+100|0;c[D>>2]=0;E=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[E&16383](v,0)|0;do{if((c[A>>2]|0)!=0){E=c[D>>2]|0;c[w>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](w,0,0)|0;if((E|0)<1){F=1;i=e;return F|0}if((gzL(y,0,0)|0)==0){break}else{F=1}i=e;return F|0}}while(0);y=(c[2385966]|0)+8192|0;if((c[3542200]|0)==0){F=1;i=e;return F|0}D=t+108|0;c[D>>2]=0;A=t+100|0;c[A>>2]=0;E=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[E&16383](t,1)|0;do{if((c[D>>2]|0)!=0){E=c[A>>2]|0;c[u>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](u,1,0)|0;if((E|0)<1){F=1;i=e;return F|0}if((gzL(y,0,1)|0)==0){break}else{F=1}i=e;return F|0}}while(0);y=(c[2385966]|0)+16384|0;if((c[3542200]|0)==0){F=1;i=e;return F|0}A=r+108|0;c[A>>2]=0;D=r+100|0;c[D>>2]=0;E=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[E&16383](r,2)|0;do{if((c[A>>2]|0)!=0){E=c[D>>2]|0;c[s>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](s,2,0)|0;if((E|0)<1){F=1;i=e;return F|0}if((gzL(y,0,2)|0)==0){break}else{F=1}i=e;return F|0}}while(0);y=(c[2385966]|0)+24576|0;if((c[3542200]|0)==0){F=1;i=e;return F|0}D=p+108|0;c[D>>2]=0;A=p+100|0;c[A>>2]=0;E=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[E&16383](p,3)|0;do{if((c[D>>2]|0)!=0){E=c[A>>2]|0;c[q>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](q,3,0)|0;if((E|0)<1){F=1;i=e;return F|0}if((gzL(y,0,3)|0)==0){break}else{F=1}i=e;return F|0}}while(0);y=c[2387832]|0;if((c[3542200]|0)==0){F=1;i=e;return F|0}A=n+108|0;c[A>>2]=0;D=n+100|0;c[D>>2]=0;E=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[E&16383](n,4)|0;do{if((c[A>>2]|0)!=0){E=c[D>>2]|0;c[o>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](o,4,0)|0;if((E|0)<1){F=1;i=e;return F|0}if((gzL(y,0,4)|0)==0){break}else{F=1}i=e;return F|0}}while(0);y=(c[2387832]|0)+8192|0;if((c[3542200]|0)==0){F=1;i=e;return F|0}D=l+108|0;c[D>>2]=0;A=l+100|0;c[A>>2]=0;E=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[E&16383](l,5)|0;do{if((c[D>>2]|0)!=0){E=c[A>>2]|0;c[m>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](m,5,0)|0;if((E|0)<1){F=1;i=e;return F|0}if((gzL(y,0,5)|0)==0){break}else{F=1}i=e;return F|0}}while(0);y=(c[2387832]|0)+16384|0;if((c[3542200]|0)==0){F=1;i=e;return F|0}A=j+108|0;c[A>>2]=0;D=j+100|0;c[D>>2]=0;E=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[E&16383](j,6)|0;do{if((c[A>>2]|0)!=0){E=c[D>>2]|0;c[k>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](k,6,0)|0;if((E|0)<1){F=1;i=e;return F|0}if((gzL(y,0,6)|0)==0){break}else{F=1}i=e;return F|0}}while(0);y=(c[2387832]|0)+24576|0;if((c[3542200]|0)==0){F=1;i=e;return F|0}D=f+108|0;c[D>>2]=0;A=f+100|0;c[A>>2]=0;E=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[E&16383](f,7)|0;do{if((c[D>>2]|0)!=0){E=c[A>>2]|0;c[g>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](g,7,0)|0;if((E|0)<1){F=1;i=e;return F|0}if((gzL(y,0,7)|0)==0){break}else{F=1}i=e;return F|0}}while(0);y=0;do{c[x+(y<<2)>>2]=-(y>>>1&1)&192|-(y&1)&63|(-(y>>>3&1)&117)+(-(y>>>2&1)&74)+((y&12|0)!=0?63:0)<<8|(-(y>>>5&1)&115)+(-(y>>>4&1)&76)+((y&48|0)!=0?63:0)<<16;y=y+1|0;}while((y|0)<64);y=c[2406984]|0;A=0;while(1){D=~A;E=A>>>7;G=A>>>6;H=G&1;I=A>>>5;J=I&1;K=A>>>4;L=K&1;if((A>>>12&1&(E|G|I|K)|0)==0){K=(A&2048|0)!=0;M=K?A>>>1&1:0;N=K?A>>>2&1:0;O=K?A>>>3&1:0;P=K?A&1:0}else{M=((D>>>9&1^1)&E|0)!=0?0:J;N=((D>>>8&1^1)&E|0)!=0?0:H;O=H;P=J}c[y+(A<<2)>>2]=c[x+(((((D>>>10&1^1)&E|0)!=0?0:L)|L<<1|P<<3|O<<5|N<<4|M<<2)<<2)>>2];L=A+1|0;if((L|0)<8192){A=L}else{Q=0;break}}while(1){if((Q|0)>=1024){R=0;break}S=9638528+(Q<<2)|0;if((c[S>>2]|0)==0){C=68346;break}else{Q=Q+1|0}}do{if((C|0)==68346){A=gGq(65536)|0;c[S>>2]=A;if((A|0)==0){R=0;break}gGz(A|0,0,65536);R=A}}while(0);A=c[2387832]|0;y=0;do{L=(y|0)/4|0;E=d[A+L|0]|0;D=d[A+(L+16384)|0]|0;L=y|3;J=E>>>3;H=D>>>1;a[R+L|0]=(J&2|E&1|D<<2&4|H&8)&255;K=D>>>2;a[R+(L-1)|0]=(E>>>4&2|E>>>1&1|K&8|H<<2&4)&255;H=D>>>3;a[R+(L-2)|0]=(E>>>5&2|E>>>2&1|H&8|K<<2&4)&255;a[R+(L-3)|0]=(E>>>6&2|J&1|D>>>4&8|H<<2&4)&255;y=y+4|0;}while((y|0)<65536);gGC(A|0,R|0,65536)|0;y=0;while(1){if((y|0)>=1024){break}T=9638528+(y<<2)|0;if((c[T>>2]|0)==(R|0)){C=68353;break}else{y=y+1|0}}if((C|0)==68353){gGr(R);c[T>>2]=0}fwR(0);y=c[2439330]|0;A=(y|0)==0;if(!A){H=y;gGC(9706056,H|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];H=c[3528484]|0;c[2076596]=H;D=c[2417276]|0;c[3541536]=D;c[1836236]=0;J=c[2385966]|0;E=0;L=0;while(1){c[y+76+(L<<2)>>2]=J+(L<<8);K=E+1&65535;if((K&65535)>127){U=0;V=0;break}else{E=K;L=K&65535}}while(1){L=J+(V<<8)|0;c[y+76+(V+512<<2)>>2]=L;c[y+76+(V+768<<2)>>2]=L;L=U+1&65535;if((L&65535)>127){break}else{U=L;V=L&65535}}J=c[2386120]|0;c[y+908>>2]=J;L=J+256|0;c[y+912>>2]=L;E=J+512|0;c[y+916>>2]=E;K=J+768|0;c[y+920>>2]=K;I=J+1024|0;c[y+924>>2]=I;G=J+1280|0;c[y+928>>2]=G;W=J+1536|0;c[y+932>>2]=W;c[y+1932>>2]=J;c[y+1936>>2]=L;c[y+1940>>2]=E;c[y+1944>>2]=K;c[y+1948>>2]=I;c[y+1952>>2]=G;c[y+1956>>2]=W;X=J+1792|0;c[y+1960>>2]=X;c[y+2956>>2]=J;c[y+3980>>2]=J;c[y+2960>>2]=L;c[y+3984>>2]=L;c[y+2964>>2]=E;c[y+3988>>2]=E;c[y+2968>>2]=K;c[y+3992>>2]=K;c[y+2972>>2]=I;c[y+3996>>2]=I;c[y+2976>>2]=G;c[y+4e3>>2]=G;c[y+2980>>2]=W;c[y+4004>>2]=W;c[y+2984>>2]=X;c[y+4008>>2]=X;c[y+4184>>2]=3138;c[y+4180>>2]=28;c[y+4176>>2]=2234;if(!A){X=y;gGC(X|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=H;c[2417276]=D;c[1836236]=-1;X=a[9680]|0?32e3:0;c[3542220]=11200;if((c[2113008]|0)==0){gGz(14168888,0,252);c[3542223]=X;c[3542224]=0;c[3542225]=0;c[3542226]=910;c[3542227]=2388;c[3542234]=~~((+(X|0)*32768.0*8.0+75.0e4)/15.0e5);X=31;Y=32767.0;while(1){c[14169012+(X<<2)>>2]=~~(Y+.5);W=X-1|0;if((W|0)>0){X=W;Y=Y/1.188502227}else{break}}c[3542253]=0;h[1771269]=1.0;h[1771270]=1.0;h[1771271]=1.0;c[3542574]=3;c[3542575]=3;c[3542576]=3;mB(0);c[2113008]=(c[2113008]|0)+1}h[1771269]=.5;c[3542574]=3;h[1771270]=.5;c[3542575]=3;h[1771271]=.5;c[3542576]=3;X=c[642608+(c[2436]<<2)>>2]|0;D=c[X+128>>2]|0;if((c[X+52>>2]&4|0)==0){c[2113068]=D;H=c[X+132>>2]|0;c[2113070]=H;c[2443814]=D;c[2440436]=H;Z=D;_=H}else{c[2113070]=D;H=c[X+132>>2]|0;c[2113068]=H;c[2440436]=D;c[2443814]=H;Z=H;_=D}D=ag(Z<<1,_)|0;H=gGq(D)|0;c[2112926]=H;if((H|0)!=0){gGz(H|0,0,D|0)}a[9624768]=0;D=c[2414752]|0;gGz(D|0,0,(c[2411800]|0)-D|0);D=c[2439330]|0;H=(D|0)==0;if(!H){X=D;gGC(9706056,X|0,76)|0}X=c[2438118]|0;c[2433530]=X;y=c[3528484]|0;c[2076596]=y;A=c[2417276]|0;c[3541536]=A;c[1836236]=0;gGz(9706056,0,76);if(!H){H=D;gGC(H|0,9706056,76)|0}c[2438118]=X;c[3528484]=y;c[2417276]=A;c[1836236]=-1;mB(0);c[2432970]=0;c[2436756]=0;F=0;i=e;return F|0}}while(0);c[2415044]=0;F=1;i=e;return F|0}function dlv(){var a=0,b=0,d=0,e=0;c[2113070]=0;c[2113068]=0;a=c[2112926]|0;if((a|0)!=0){gGr(a);c[2112926]=0}fwZ();c[2113008]=0;c[2076598]=0;c[2383582]=0;a=c[2415044]|0;b=0;while(1){if((b|0)>=1024){d=68410;break}e=9638528+(b<<2)|0;if((c[e>>2]|0)==(a|0)){break}else{b=b+1|0}}if((d|0)==68410){c[2415044]=0;return 0}gGr(a);c[e>>2]=0;c[2415044]=0;return 0}function dlw(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if((a[9624768]|0)!=0){a[9624768]=0;d=c[2414752]|0;gGz(d|0,0,(c[2411800]|0)-d|0);d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;h=c[2417276]|0;c[3541536]=h;c[1836236]=0;gGz(9706056,0,76);if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=h;c[1836236]=-1;mB(0);c[2432970]=0;c[2436756]=0}h=9550760;c[h>>2]=0;c[h+4>>2]=0;h=0;g=0;f=0;e=0;d=0;i=0;j=0;do{g=((a[9634128+h|0]&1)<<h^g&255)&255;f=((a[9629832+h|0]&1)<<h^f&255)&255;e=((a[9629040+h|0]&1)<<h^e&255)&255;d=((a[9628800+h|0]&1)<<h^d&255)&255;i=((a[9628680+h|0]&1)<<h^i&255)&255;j=((a[9628640+h|0]&1)<<h^j&255)&255;h=h+1|0;}while((h|0)<8);a[9550760]=g;a[9550763]=e;a[9550764]=d;a[9550765]=i;a[9550766]=j;a[9550761]=a[9635496]|0;a[9550762]=f|1;a[9550767]=a[9635497]|0;f=c[2439330]|0;if((f|0)!=0){j=f;gGC(9706056,j|0,76)|0}b[4853030]=c[2426515]&65535;j=c[2438118]|0;c[2433530]=j;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;if((a[f+4188|0]|0)==0){f=gfc(5e4)|0;k=(c[2433530]|0)+f|0}else{k=j+5e4|0}c[2433530]=k;a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0;k=c[1836236]|0;j=c[9757320+(k<<2)>>2]|0;if((j|0)!=0){f=j;gGC(f|0,9706056,76)|0}c[9752472+(k<<2)>>2]=c[2433530];c[14113936+(k<<2)>>2]=c[2076596];c[9669104+(k<<2)>>2]=c[3541536];c[1836236]=-1;k=c[2112964]|0;if((k|0)!=0){mF(9756552,k,a[9688]|0?534:0,0)}if((c[2112968]|0)==0){return 0}dlx()|0;return 0}function dlx(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((a[9547792]|0)!=0){e=c[2406984]|0;f=c[3530122]|0;g=0;do{h=c[e+(g<<2)>>2]|0;c[f+(g<<2)>>2]=h>>>8&2016|h&31|h>>16<<8&63488;g=g+1|0;}while((g|0)<8192)}g=c[2386120]|0;f=a[g+843|0]|0;e=c[3528756]|0;a[e]=f;do{if((a[g+1024|0]|0)==0){i=f}else{if((a[g+1025|0]&2)!=0){i=f;break}h=f<<24>>24==0|0;a[e]=h;i=h}}while(0);e=c[2112926]|0;f=(c[3529558]|0)+2816|0;g=c[2113068]|0;if(i<<24>>24==0){i=e;h=f;j=11;while(1){k=0;do{b[i+(k<<1)>>1]=d[h+k|0]|0;k=k+1|0;}while((k|0)<256);k=j+1|0;if((k|0)<245){i=i+(g<<1)|0;h=h+256|0;j=k}else{break}}l=c[3530122]|0;m=c[2439324]|0;n=a[m]|0;o=n&255;p=o<<8;q=l+(p<<2)|0;R8(q);return 0}j=-g|0;h=e+((ag((c[2113070]|0)-1|0,g)|0)<<1)|0;g=f;f=11;while(1){e=0;do{b[h+(e<<1)>>1]=d[g+(e^255)|0]|0;e=e+1|0;}while((e|0)<256);e=f+1|0;if((e|0)<245){h=h+(j<<1)|0;g=g+256|0;f=e}else{break}}l=c[3530122]|0;m=c[2439324]|0;n=a[m]|0;o=n&255;p=o<<8;q=l+(p<<2)|0;R8(q);return 0}function dly(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=i;i=i+80|0;e=d|0;f=d+32|0;g=d+48|0;h=d+64|0;j=(b|0)==0;if(!j){c[b>>2]=169730}if((a&96|0)==0){i=d;return 0}gGz(h|0,0,12);k=c[2414752]|0;c[h>>2]=k;c[h+4>>2]=(c[2411800]|0)-k;c[h+12>>2]=162152;gj[c[2076592]&4095](h)|0;fw$(a);h=d+16|0;do{if((a&64|0)!=0){do{if(!j){if((c[b>>2]|0)>=169110){break}c[b>>2]=169110}}while(0);if((c[2113008]|0)<=0){break}k=e|0;l=e+4|0;m=e+8|0;n=e+12|0;o=0;do{cC(h|0,531144,(p=i,i=i+8|0,c[p>>2]=o,p)|0)|0;i=p;c[k>>2]=14168888+(o*252|0);c[l>>2]=252;c[m>>2]=0;c[n>>2]=h;gj[c[2076592]&4095](e)|0;o=o+1|0;}while((o|0)<(c[2113008]|0))}}while(0);gGz(g|0,0,12);c[g>>2]=9731880;c[g+4>>2]=4;c[g+12>>2]=221504;gj[c[2076592]&4095](g)|0;gGz(f|0,0,12);c[f>>2]=9747024;c[f+4>>2]=4;c[f+12>>2]=217464;gj[c[2076592]&4095](f)|0;i=d;return 0}function dlz(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3157476+(b*112|0)>>2];c[a+104>>2]=c[3157480+(b*112|0)>>2];c[a+108>>2]=c[3157484+(b*112|0)>>2];d=0;return d|0}function dlA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=3157376+(b*112|0);e=0;return e|0}function dlB(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>41){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4276616+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dlC(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=b&65535;if((b+8192&65535)<2048){g=f&1023;h=c[2426618]|0;a[h+(g|57344)|0]=e;a[h+(g|58368)|0]=(b&65535)>>>10&1;return}if((b+6144&65535)<64){g=c[2426618]|0;a[g+f|0]=e;h=d[g+(f|1)|0]|0;i=(h&15|h<<4)<<16;h=(c[2406982]|0)+((f>>>1&31)<<2)|0;c[h>>2]=i;j=g+(f&65534)|0;g=d[j]|0;k=(g&240|g>>>4)<<8|i;c[h>>2]=k;i=d[j]|0;c[h>>2]=i&15|i<<4|k;return}if((b+5120&65535)>=256){return}if((f&2|0)==0){l=b;m=c[2426618]|0}else{k=c[2426618]|0;a[k+(f|1)|0]=b&1;l=b&-2;m=k}a[m+(l&65535)|0]=e;return}function dlD(d,e){d=d|0;e=e|0;var f=0;f=d&255;if((f|0)==96){a[9734328]=e;return}else if((f|0)==64){c[2439250]=c[2439250]|8;c[2385558]=e&255;e=c[1836236]|0;f=c[9757320+(e<<2)>>2]|0;if((f|0)!=0){d=f;gGC(d|0,9706056,76)|0}c[9752472+(e<<2)>>2]=c[2433530];c[14113936+(e<<2)>>2]=c[2076596];c[9669104+(e<<2)>>2]=c[3541536];c[1836236]=-1;e=c[2439331]|0;if((e|0)!=0){d=e;gGC(9706056,d|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0;d=c[1836236]|0;e=c[9757320+(d<<2)>>2]|0;if((e|0)!=0){f=e;gGC(f|0,9706056,76)|0}c[9752472+(d<<2)>>2]=c[2433530];c[14113936+(d<<2)>>2]=c[2076596];c[9669104+(d<<2)>>2]=c[3541536];c[1836236]=-1;d=c[2439330]|0;if((d|0)!=0){f=d;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;return}else{return}}function dlE(a){a=a|0;var b=0,d=0;b=a&255;if((b|0)==65){c[2439250]=c[2439250]&-2;d=c[2444144]&255;return d|0}else if((b|0)==66){d=(c[2439250]^8)&255;return d|0}else{d=0;return d|0}return 0}function dlF(b,d){b=b|0;d=d|0;var e=0;e=b&65535;switch(e&255|0){case 33:{c[2439250]=c[2439250]|1;c[2444144]=d&255;return};case 71:case 69:case 67:case 65:{c[9757008+((e>>>1&3)<<2)>>2]=d&255;return};case 68:{e=c[2439254]&15;c[3542291]=e;b=d&255;do{if(e>>>0<14){if((e|0)!=13){if((a[14169168+e|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(1,e,b);return};case 70:{b=c[2439255]&15;c[3542354]=b;e=d&255;do{if(b>>>0<14){if((b|0)!=13){if((a[14169420+b|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(2,b,e);return};case 64:{e=c[2439252]&15;c[3542228]=e;b=d&255;do{if(e>>>0<14){if((e|0)!=13){if((a[14168916+e|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(0,e,b);return};default:{return}}}function dlG(b){b=b|0;var d=0;switch(b&255|0){case 16:{d=((c[2439250]|0)>>>3&1^1)&255;return d|0};case 68:{return(((c[2439254]|0)-14|0)>>>0<2)<<31>>31|0};case 64:{b=c[2439252]|0;if((b|0)==15){d=~(a[9634121]<<1|a[9634120]|a[9634122]<<2|a[9634123]<<3|a[9634124]<<4|a[9634125]<<5|a[9634126]<<6|a[9634127]<<7);return d|0}else if((b|0)==14){d=~(a[9631905]<<1|a[9631904]|a[9631906]<<2|a[9631907]<<3|a[9631908]<<4|a[9631909]<<5|a[9631910]<<6|a[9631911]<<7);return d|0}else{d=0;return d|0}break};case 32:{c[2439250]=c[2439250]&-9;d=c[2385558]&255;return d|0};case 34:{d=(c[2439250]^1)&255;return d|0};default:{d=0;return d|0}}return 0}function dlH(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>24){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5778284+(b*112|0)>>2];c[a+104>>2]=c[5778288+(b*112|0)>>2];c[a+108>>2]=c[5778292+(b*112|0)>>2];d=0;return d|0}function dlI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<25&(d|0)==0)){e=1;return e|0}c[a>>2]=5778184+(b*112|0);e=0;return e|0}function dlJ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6936416+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dlK(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7447240+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dlL(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0.0,$=0,aa=0,ab=0,ac=0;e=i;i=i+720|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=0;while(1){if((t|0)>=1024){break}u=9638528+(t<<2)|0;if((c[u>>2]|0)==0){v=68589;break}else{t=t+1|0}}do{if((v|0)==68589){t=gGq(459264)|0;c[u>>2]=t;if((t|0)==0){break}gGz(t|0,0,459264);c[2426800]=t;t=a[9688]|0?9612:0;w=0;while(1){if((w|0)>=1024){break}x=9638528+(w<<2)|0;if((c[x>>2]|0)==0){v=68594;break}else{w=w+1|0}}do{if((v|0)==68594){w=gGq(t)|0;c[x>>2]=w;if((w|0)==0){break}gGz(w|0,0,t|0);c[2385402]=w;w=c[2426800]|0;gGz(w|0,0,458880);c[2424770]=w;c[2424756]=w+65536;c[2426618]=w+131072;c[2424864]=w+196608;c[2424840]=w+327680;c[2406982]=w+458752;y=r+108|0;z=r+100|0;A=0;B=w;while(1){w=B+(A<<13)|0;if((c[3542200]|0)==0){C=1;v=68682;break}c[y>>2]=0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,A)|0;if((c[y>>2]|0)!=0){D=c[z>>2]|0;c[s>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](s,A,0)|0;if((D|0)<1){C=1;v=68685;break}if((gzL(w,0,A)|0)!=0){C=1;v=68671;break}}w=A+1|0;if((w|0)>=6){v=68603;break}A=w;B=c[2424770]|0}if((v|0)==68603){B=c[2424756]|0;if((c[3542200]|0)==0){C=1;i=e;return C|0}A=p+108|0;c[A>>2]=0;z=p+100|0;c[z>>2]=0;y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[y&16383](p,6)|0;do{if((c[A>>2]|0)!=0){y=c[z>>2]|0;c[q>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](q,6,0)|0;if((y|0)<1){C=1;i=e;return C|0}if((gzL(B,0,6)|0)==0){break}else{C=1}i=e;return C|0}}while(0);B=(c[2424756]|0)+8192|0;if((c[3542200]|0)==0){C=1;i=e;return C|0}z=n+108|0;c[z>>2]=0;A=n+100|0;c[A>>2]=0;y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[y&16383](n,7)|0;do{if((c[z>>2]|0)!=0){y=c[A>>2]|0;c[o>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](o,7,0)|0;if((y|0)<1){C=1;i=e;return C|0}if((gzL(B,0,7)|0)==0){break}else{C=1}i=e;return C|0}}while(0);B=(c[2424756]|0)+12288|0;if((c[3542200]|0)==0){C=1;i=e;return C|0}A=l+108|0;c[A>>2]=0;z=l+100|0;c[z>>2]=0;y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[y&16383](l,8)|0;do{if((c[A>>2]|0)!=0){y=c[z>>2]|0;c[m>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](m,8,0)|0;if((y|0)<1){C=1;i=e;return C|0}if((gzL(B,0,8)|0)==0){break}else{C=1}i=e;return C|0}}while(0);B=j+108|0;z=j+100|0;A=f+108|0;y=f+100|0;w=0;while(1){D=w<<13;E=(c[2424864]|0)+D|0;F=w+9|0;if((c[3542200]|0)==0){C=1;v=68674;break}c[B>>2]=0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,F)|0;if((c[B>>2]|0)!=0){G=c[z>>2]|0;c[k>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](k,F,0)|0;if((G|0)<1){C=1;v=68683;break}if((gzL(E,0,F)|0)!=0){C=1;v=68672;break}}F=(c[2424840]|0)+D|0;D=w+17|0;if((c[3542200]|0)==0){C=1;v=68675;break}c[A>>2]=0;c[y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,D)|0;if((c[A>>2]|0)!=0){E=c[y>>2]|0;c[g>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](g,D,0)|0;if((E|0)<1){C=1;v=68686;break}if((gzL(F,0,D)|0)!=0){C=1;v=68688;break}}D=w+1|0;if((D|0)<8){w=D}else{I=0;v=68625;break}}if((v|0)==68625){while(1){v=0;if((I|0)>=1024){C=1;v=68684;break}J=9638528+(I<<2)|0;if((c[J>>2]|0)==0){break}else{I=I+1|0;v=68625}}if((v|0)==68684){i=e;return C|0}w=gGq(65536)|0;c[J>>2]=w;if((w|0)==0){C=1;i=e;return C|0}gGz(w|0,0,65536);y=c[2424864]|0;gGC(w|0,y|0,65536)|0;A=0;do{z=A>>3;B=A&7;D=(d[w+z|0]|0)>>>(B>>>0)<<3&8;F=y+(A^7)|0;a[F]=D;E=(d[w+(z+16384)|0]|0)>>>(B>>>0)<<2&4|D&255;a[F]=E&255;D=(d[w+(z+32768)|0]|0)>>>(B>>>0)<<1&2|E;a[F]=D&255;a[F]=(D|(d[w+(z+49152)|0]|0)>>>(B>>>0)&1)&255;A=A+1|0;}while((A|0)<131072);A=c[2424840]|0;gGC(w|0,A|0,65536)|0;a[A]=(d[w]|0)>>>4;a[A+1|0]=a[w]&15;y=2;while(1){B=w+(y>>1)|0;a[A+y|0]=(d[B]|0)>>>4;a[A+(y|1)|0]=a[B]&15;B=y+2|0;if((B|0)<131072){y=B}else{K=0;break}}while(1){if((K|0)>=1024){break}L=9638528+(K<<2)|0;if((c[L>>2]|0)==(w|0)){v=68634;break}else{K=K+1|0}}if((v|0)==68634){gGr(w);c[L>>2]=0}fwR(0);y=c[2439330]|0;if((y|0)!=0){A=y;gGC(9706056,A|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];A=c[3528484]|0;c[2076596]=A;B=c[2417276]|0;c[3541536]=B;c[1836236]=0;c[y+4172>>2]=1726;c[y+4176>>2]=1240;c[y+4184>>2]=1044;z=c[2424770]|0;D=0;F=0;while(1){c[y+76+(F<<2)>>2]=z+(F<<8);E=D+1&65535;if((E&65535)>191){M=0;N=0;break}else{D=E;F=E&65535}}while(1){F=z+(N<<8)|0;c[y+76+(N+512<<2)>>2]=F;c[y+76+(N+768<<2)>>2]=F;F=M+1&65535;if((F&65535)>191){break}else{M=F;N=F&65535}}z=c[2426618]|0;F=z+49152|0;c[y+844>>2]=F;D=z+49408|0;c[y+848>>2]=D;w=z+49664|0;c[y+852>>2]=w;E=z+49920|0;c[y+856>>2]=E;G=z+50176|0;c[y+860>>2]=G;H=z+50432|0;c[y+864>>2]=H;O=z+50688|0;c[y+868>>2]=O;P=z+50944|0;c[y+872>>2]=P;Q=z+51200|0;c[y+876>>2]=Q;R=z+51456|0;c[y+880>>2]=R;S=z+51712|0;c[y+884>>2]=S;T=z+51968|0;c[y+888>>2]=T;U=z+52224|0;c[y+892>>2]=U;V=z+52480|0;c[y+896>>2]=V;W=z+52736|0;c[y+900>>2]=W;X=z+52992|0;c[y+904>>2]=X;c[y+1868>>2]=F;c[y+1872>>2]=D;c[y+1876>>2]=w;c[y+1880>>2]=E;c[y+1884>>2]=G;c[y+1888>>2]=H;c[y+1892>>2]=O;c[y+1896>>2]=P;c[y+1900>>2]=Q;c[y+1904>>2]=R;c[y+1908>>2]=S;c[y+1912>>2]=T;c[y+1916>>2]=U;c[y+1920>>2]=V;c[y+1924>>2]=W;c[y+1928>>2]=X;X=192;W=192;while(1){V=z+(W<<8)|0;c[y+76+(W+512<<2)>>2]=V;c[y+76+(W+768<<2)>>2]=V;V=X+1&65535;if((V&65535)>207){break}else{X=V;W=V&65535}}W=y;gGC(W|0,9706056,76)|0;c[2438118]=c[2433530];c[3528484]=A;c[2417276]=B;c[1836236]=-1;fwR(1);W=c[2439331]|0;X=(W|0)==0;if(!X){z=W;gGC(9706056,z|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];z=c[3528485]|0;c[2076596]=z;V=c[2417277]|0;c[3541536]=V;c[1836236]=1;c[W+4172>>2]=1264;c[W+4176>>2]=3258;U=c[2424756]|0;T=0;S=0;while(1){c[W+76+(S<<2)>>2]=U+(S<<8);R=T+1&65535;if((R&65535)>63){Y=0;Z=0;break}else{T=R;S=R&65535}}while(1){S=U+(Z<<8)|0;c[W+76+(Z+512<<2)>>2]=S;c[W+76+(Z+768<<2)>>2]=S;S=Y+1&65535;if((S&65535)>63){break}else{Y=S;Z=S&65535}}U=c[2426618]|0;S=U+32768|0;c[W+588>>2]=S;c[W+1612>>2]=S;c[W+2636>>2]=S;c[W+3660>>2]=S;S=U+36864|0;c[W+652>>2]=S;c[W+1676>>2]=S;c[W+2700>>2]=S;c[W+3724>>2]=S;if(!X){S=W;gGC(S|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=z;c[2417277]=V;c[1836236]=-1;S=c[2385402]|0;U=a[9688]|0?534:0;c[2439128]=S;c[2439129]=S+(U<<1);c[2439130]=S+(U<<1<<1);c[2439131]=S+((U*3|0)<<1);c[2439132]=S+(U<<2<<1);c[2439133]=S+((U*5|0)<<1);c[2439134]=S+((U*6|0)<<1);c[2439135]=S+((U*7|0)<<1);c[2439136]=S+(U<<3<<1);U=a[9680]|0?32e3:0;c[3542220]=11200;S=c[2113008]|0;if((S|0)==0){gGz(14168888,0,252);c[3542223]=U;gGz(14168896,0,16);c[3542234]=~~((+(U|0)*32768.0*8.0+1.0e6)/2.0e6);T=31;_=32767.0;while(1){c[14169012+(T<<2)>>2]=~~(_+.5);B=T-1|0;if((B|0)>0){T=B;_=_/1.188502227}else{break}}c[3542253]=0;h[1771269]=1.0;h[1771270]=1.0;h[1771271]=1.0;c[3542574]=3;c[3542575]=3;c[3542576]=3;mB(0);T=(c[2113008]|0)+1|0;c[2113008]=T;$=T;aa=a[9680]|0?32e3:0}else{$=S;aa=U}c[3542220]=11200;if(($|0)==1){gGz(14169140,0,252);c[3542286]=aa;gGz(14169148,0,16);c[3542297]=~~((+(aa|0)*32768.0*8.0+1.0e6)/2.0e6);T=31;_=32767.0;while(1){c[14169264+(T<<2)>>2]=~~(_+.5);V=T-1|0;if((V|0)>0){T=V;_=_/1.188502227}else{break}}c[3542316]=0;h[1771272]=1.0;h[1771273]=1.0;h[1771274]=1.0;c[3542577]=3;c[3542578]=3;c[3542579]=3;mB(1);T=(c[2113008]|0)+1|0;c[2113008]=T;ab=T;ac=a[9680]|0?32e3:0}else{ab=$;ac=aa}c[3542220]=11200;if((ab|0)==2){gGz(14169392,0,252);c[3542349]=ac;gGz(14169400,0,16);c[3542360]=~~((+(ac|0)*32768.0*8.0+1.0e6)/2.0e6);T=31;_=32767.0;while(1){c[14169516+(T<<2)>>2]=~~(_+.5);U=T-1|0;if((U|0)>0){T=U;_=_/1.188502227}else{break}}c[3542379]=0;h[1771275]=1.0;h[1771276]=1.0;h[1771277]=1.0;c[3542580]=3;c[3542581]=3;c[3542582]=3;mB(2);c[2113008]=(c[2113008]|0)+1}h[1771269]=.25;c[3542574]=3;h[1771270]=.25;c[3542575]=3;h[1771271]=.25;c[3542576]=3;h[1771272]=.25;c[3542577]=3;h[1771273]=.25;c[3542578]=3;h[1771274]=.25;c[3542579]=3;h[1771275]=.25;c[3542580]=3;h[1771276]=.25;c[3542581]=3;h[1771277]=.25;c[3542582]=3;gGz(c[2426618]|0,0,65536);gGz(9757008,0,16);c[2385558]=0;c[2444144]=0;c[2439250]=0;a[9734328]=0;a[9624760]=0;T=c[2439330]|0;U=(T|0)==0;if(!U){S=T;gGC(9706056,S|0,76)|0}S=c[2438118]|0;c[2433530]=S;V=c[3528484]|0;c[2076596]=V;z=c[2417276]|0;c[3541536]=z;c[1836236]=0;gGz(9706056,0,76);if(!U){U=T;gGC(U|0,9706056,76)|0}c[2438118]=S;c[3528484]=V;c[2417276]=z;c[1836236]=-1;z=c[2439331]|0;V=(z|0)==0;if(!V){S=z;gGC(9706056,S|0,76)|0}S=c[2438119]|0;c[2433530]=S;U=c[3528485]|0;c[2076596]=U;T=c[2417277]|0;c[3541536]=T;c[1836236]=1;gGz(9706056,0,76);if(!V){V=z;gGC(V|0,9706056,76)|0}c[2438119]=S;c[3528485]=U;c[2417277]=T;c[1836236]=-1;mB(0);mB(1);mB(2);C=0;i=e;return C|0}else if((v|0)==68674){i=e;return C|0}else if((v|0)==68675){i=e;return C|0}else if((v|0)==68683){i=e;return C|0}else if((v|0)==68686){i=e;return C|0}else if((v|0)==68688){i=e;return C|0}else if((v|0)==68672){i=e;return C|0}}else if((v|0)==68682){i=e;return C|0}else if((v|0)==68685){i=e;return C|0}else if((v|0)==68671){i=e;return C|0}}}while(0);c[2385402]=0;C=1;i=e;return C|0}}while(0);c[2426800]=0;C=1;i=e;return C|0}function dlM(){var a=0,b=0,d=0,e=0,f=0;fwZ();c[2113008]=0;c[2076598]=0;c[2383582]=0;a=c[2426800]|0;b=0;while(1){if((b|0)>=1024){break}d=9638528+(b<<2)|0;if((c[d>>2]|0)==(a|0)){e=68697;break}else{b=b+1|0}}if((e|0)==68697){gGr(a);c[d>>2]=0}c[2426800]=0;d=c[2385402]|0;a=0;while(1){if((a|0)>=1024){break}f=9638528+(a<<2)|0;if((c[f>>2]|0)==(d|0)){e=68701;break}else{a=a+1|0}}if((e|0)==68701){gGr(d);c[f>>2]=0}c[2424840]=0;c[2424864]=0;c[2426618]=0;c[2424756]=0;c[2424770]=0;c[2385402]=0;gGz(9756512,0,36);c[2406982]=0;return 0}function dlN(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;if((a[9624760]|0)!=0){gGz(c[2426618]|0,0,65536);gGz(9757008,0,16);c[2385558]=0;c[2444144]=0;c[2439250]=0;a[9734328]=0;a[9624760]=0;d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;h=c[2417276]|0;c[3541536]=h;c[1836236]=0;gGz(9706056,0,76);if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=h;c[1836236]=-1;h=c[2439331]|0;g=(h|0)==0;if(!g){f=h;gGC(9706056,f|0,76)|0}f=c[2438119]|0;c[2433530]=f;e=c[3528485]|0;c[2076596]=e;d=c[2417277]|0;c[3541536]=d;c[1836236]=1;gGz(9706056,0,76);if(!g){g=h;gGC(g|0,9706056,76)|0}c[2438119]=f;c[3528485]=e;c[2417277]=d;c[1836236]=-1;mB(0);mB(1);mB(2)}d=c[2385548]|0;if((d|0)>0){gGz(9752472,0,((d|0)>1?d<<2:4)|0)}c[2433530]=0;d=0;e=0;f=0;g=0;L82432:while(1){h=e;i=f;j=g;while(1){if((h|0)>=200){break L82432}k=c[2439330]|0;if((k|0)!=0){l=k;gGC(9706056,l|0,76)|0}b[4853030]=c[2426515]&65535;l=c[2438118]|0;c[2433530]=l;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;m=h+1|0;n=((m*66666|0|0)/200|0)-i|0;do{if((n|0)<1){o=0}else{if((a[k+4188|0]|0)==0){p=gfc(n)|0;c[2433530]=(c[2433530]|0)+p;o=p;break}else{c[2433530]=l+n;o=n;break}}}while(0);q=o+i|0;n=(h|0)==199;if(n){a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0}l=c[1836236]|0;k=c[9757320+(l<<2)>>2]|0;if((k|0)!=0){p=k;gGC(p|0,9706056,76)|0}c[9752472+(l<<2)>>2]=c[2433530];c[14113936+(l<<2)>>2]=c[2076596];c[9669104+(l<<2)>>2]=c[3541536];c[1836236]=-1;l=c[2439331]|0;if((l|0)!=0){p=l;gGC(9706056,p|0,76)|0}b[4853030]=c[2426515]&65535;p=c[2438119]|0;c[2433530]=p;c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;k=((m*1e5|0|0)/200|0)-j|0;do{if((k|0)<1){r=0}else{if((a[l+4188|0]|0)==0){s=gfc(k)|0;c[2433530]=(c[2433530]|0)+s;r=s;break}else{c[2433530]=p+k;r=k;break}}}while(0);t=r+j|0;if((c[2439250]&8|0)!=0|n){a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0}k=c[1836236]|0;p=c[9757320+(k<<2)>>2]|0;if((p|0)!=0){l=p;gGC(l|0,9706056,76)|0}c[9752472+(k<<2)>>2]=c[2433530];c[14113936+(k<<2)>>2]=c[2076596];c[9669104+(k<<2)>>2]=c[3541536];c[1836236]=-1;u=c[2112964]|0;if((u|0)==0){h=m;i=q;j=t}else{break}}j=a[9688]|0?534:0;mF(9756512,u+(d<<1<<1)|0,j-d|0,0);d=j;e=m;f=q;g=t}t=c[2112964]|0;do{if((t|0)!=0){g=a[9688]|0?534:0;if((g|0)==(d|0)){break}mF(9756512,t+(d<<1<<1)|0,g-d|0,0)}}while(0);if((c[2112968]|0)==0){return 0}dlO()|0;return 0}function dlO(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;e=d[9734328]|0;f=e<<8&1024|e<<5&512;e=c[2426618]|0;g=c[2424840]|0;h=c[2406982]|0;i=c[2112968]|0;j=c[2113308]|0;k=(j|0)>3;l=(j|0)==2;m=0;n=0;while(1){o=n&255;p=o+8|0;q=o|1;r=(p>>>0>q>>>0?p:q)-o|0;o=m>>>2&248;q=m<<3&248;if((o|0)!=248){p=o+8|0;s=q+8|0;t=o;o=g+(((d[e+(m+58368)|0]|0)<<8)+(f|(d[e+(m+57344)|0]|0))<<6)|0;while(1){u=t<<8;v=q;w=o;while(1){x=c[h+((d[w]|0)<<2)>>2]|0;y=ag(j,v|u)|0;z=i+y|0;A=x>>16<<8&63488|x>>8<<3&2016;B=A|x>>>3&31;do{if(k){c[z>>2]=B}else{if(l){b[z>>1]=B&65535;break}else{a[z]=B&255;a[i+(y+1)|0]=A>>>8&255;a[i+(y+2)|0]=0;break}}}while(0);y=v+1|0;if((y|0)<(s|0)){v=y;w=w+1|0}else{break}}w=t+1|0;if((w|0)<(p|0)){t=w;o=o+r|0}else{break}}}r=m+1|0;if((r|0)<1024){m=r;n=n+8&255}else{break}}n=c[2424864]|0;m=0;do{f=d[e+(m+60417)|0]|0;g=d[e+(m+60416)|0]|0;r=g+3|0;o=f+16|0;t=f+1|0;p=(o>>>0>t>>>0?o:t)-f|0;t=n+(((d[e+(m+60419)|0]|0)<<8|(d[e+(m+60418)|0]|0))<<8)|0;s=g-13|0;while(1){g=s<<8;if(s>>>0<=247){q=t;w=f;while(1){v=a[q]|0;do{if(!(v<<24>>24==0|(w|0)>254)){u=c[h+((v&255|16)<<2)>>2]|0;y=ag(j,w|g)|0;A=i+y|0;B=u>>16<<8&63488|u>>8<<3&2016;z=B|u>>>3&31;if(k){c[A>>2]=z;break}if(l){b[A>>1]=z&65535;break}else{a[A]=z&255;a[i+(y+1)|0]=B>>>8&255;a[i+(y+2)|0]=0;break}}}while(0);v=w+1|0;if((v|0)<(o|0)){q=q+1|0;w=v}else{break}}}w=s+1|0;if((w|0)<(r|0)){t=t+p|0;s=w}else{break}}m=m+4|0;}while((m|0)<256);return 0}function dlP(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=i;i=i+176|0;e=d|0;f=d+32|0;g=d+48|0;h=d+64|0;j=d+80|0;k=d+96|0;l=d+112|0;m=d+128|0;n=d+144|0;o=d+160|0;p=(b|0)==0;if(!p){c[b>>2]=169249}if((a&96|0)==0){i=d;return 0}q=o;gGz(q|0,0,12);r=o|0;c[r>>2]=c[2426618];s=o+4|0;c[s>>2]=65536;t=o+12|0;c[t>>2]=162152;gj[c[2076592]&4095](o)|0;gGz(q|0,0,12);c[r>>2]=c[2406982];c[s>>2]=512;c[t>>2]=426800;gj[c[2076592]&4095](o)|0;fw$(a);o=d+16|0;do{if((a&64|0)!=0){do{if(!p){if((c[b>>2]|0)>=169110){break}c[b>>2]=169110}}while(0);if((c[2113008]|0)<=0){break}t=e|0;s=e+4|0;r=e+8|0;q=e+12|0;u=0;do{cC(o|0,531144,(v=i,i=i+8|0,c[v>>2]=u,v)|0)|0;i=v;c[t>>2]=14168888+(u*252|0);c[s>>2]=252;c[r>>2]=0;c[q>>2]=o;gj[c[2076592]&4095](e)|0;u=u+1|0;}while((u|0)<(c[2113008]|0))}}while(0);gGz(n|0,0,12);c[n>>2]=9542232;c[n+4>>2]=4;c[n+12>>2]=125632;gj[c[2076592]&4095](n)|0;gGz(m|0,0,12);c[m>>2]=9776576;c[m+4>>2]=4;c[m+12>>2]=100824;gj[c[2076592]&4095](m)|0;gGz(l|0,0,12);c[l>>2]=9757e3;c[l+4>>2]=4;c[l+12>>2]=78080;gj[c[2076592]&4095](l)|0;gGz(k|0,0,12);c[k>>2]=9734328;c[k+4>>2]=1;c[k+12>>2]=584920;gj[c[2076592]&4095](k)|0;gGz(j|0,0,12);c[j>>2]=9757008;c[j+4>>2]=4;c[j+12>>2]=568496;gj[c[2076592]&4095](j)|0;gGz(h|0,0,12);c[h>>2]=9757012;c[h+4>>2]=4;c[h+12>>2]=552248;gj[c[2076592]&4095](h)|0;gGz(g|0,0,12);c[g>>2]=9757016;c[g+4>>2]=4;c[g+12>>2]=537672;gj[c[2076592]&4095](g)|0;gGz(f|0,0,12);c[f>>2]=9757020;c[f+4>>2]=4;c[f+12>>2]=524424;gj[c[2076592]&4095](f)|0;i=d;return 0}function dlQ(b){b=b|0;var c=0;switch(b&65535|0){case 12292:{c=a[9658057]|0;break};case 12289:{c=~a[9625873];break};case 12290:{c=~a[9625874];break};case 12291:{c=a[9658056]|0;break};case 12288:{c=~a[9625872];break};default:{c=0}}return c|0}function dlR(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;switch(b&65535|0){case 14848:{a[9758240]=d;return};case 15113:{a[9774425]=d;return};case 15114:{a[9774376]=d;return};case 15112:{a[9774424]=d;return};case 15115:{a[9774377]=d;return};case 15872:{b=d&3;a[14119352]=b;if(d<<24>>24==4){a[14119352]=4;d=c[3527378]|0;e=c[3528554]|0;f=c[2433592]|0;g=64;h=64;while(1){i=d+((h<<8)-16384)|0;c[f+(e*3148|0)+48+(h<<2)>>2]=i;c[f+(e*3148|0)+48+(h+512<<2)>>2]=i;i=g+1&65535;if((i&65535)>95){break}else{g=i;h=i&65535}}return}else{h=c[3527378]|0;g=c[3528554]|0;e=c[2433592]|0;f=(b&255)<<13|32768;b=64;d=64;while(1){i=h+(f+(d<<8))|0;c[e+(g*3148|0)+48+(d<<2)>>2]=i;c[e+(g*3148|0)+48+(d+512<<2)>>2]=i;i=b+1&65535;if((i&65535)>95){break}else{b=i;d=i&65535}}return}break};default:{return}}}function dlS(b){b=b|0;return(b<<16>>16==-14336?a[9758240]|0:0)|0}function dlT(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=b&65535;if((e|0)==57344){b=c[3541518]|0;f=b+256|0;a[b+304|0]=d;g=d&255;if((d&255)<16){c[14168912+((c[2383582]|0)*252|0)>>2]=g&15}if((d-45&255)>=3){return}if((g|0)==47){a[b+312|0]=0;h=0}else if((g|0)==45){i=b+312|0;j=a[i]|2;a[i]=j;h=j}else if((g|0)==0){a[b+312|0]=2;h=2}else if((g|0)==46){g=b+312|0;j=a[g]|1;a[g]=j;h=j}else{h=a[b+312|0]|0}b=h&3;h=c[7461744+(b<<2)>>2]|0;lI(f,h,h,c[7461728+(b<<2)>>2]|0);return}else if((e|0)==57347){lS(1,1,d);return}else if((e|0)==57345){lS(0,1,d);return}else if((e|0)==57346){e=c[3541518]|0;b=e+19280|0;a[e+19328|0]=d;h=d&255;if((d&255)<16){c[14168912+(((c[2383582]|0)+1|0)*252|0)>>2]=h&15}if((d-45&255)>=3){return}if((h|0)==46){d=e+19336|0;f=a[d]|1;a[d]=f;k=f}else if((h|0)==47){a[e+19336|0]=0;k=0}else if((h|0)==45){f=e+19336|0;d=a[f]|2;a[f]=d;k=d}else if((h|0)==0){a[e+19336|0]=2;k=2}else{k=a[e+19336|0]|0}e=k&3;k=c[7461744+(e<<2)>>2]|0;lI(b,k,k,c[7461728+(e<<2)>>2]|0);return}else{return}}function dlU(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7424100+(b*112|0)>>2];c[a+104>>2]=c[7424104+(b*112|0)>>2];c[a+108>>2]=c[7424108+(b*112|0)>>2];d=0;return d|0}function dlV(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=7424e3+(b*112|0);e=0;return e|0}function dlW(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6936096+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dlX(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>48){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7446648+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dlY(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0;e=i;i=i+2520|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;B=e+1200|0;C=e+1312|0;D=e+1320|0;E=e+1432|0;F=e+1440|0;G=e+1552|0;H=e+1560|0;I=e+1672|0;J=e+1680|0;K=e+1792|0;L=e+1800|0;M=e+1912|0;N=e+1920|0;O=e+2032|0;P=e+2040|0;Q=e+2152|0;R=e+2160|0;S=e+2272|0;T=e+2280|0;U=e+2392|0;V=e+2400|0;W=e+2512|0;c[2426798]=0;c[3527378]=0;c[2385846]=81920;c[2405706]=114688;c[3527384]=114688;c[2385864]=122368;c[2443432]=124416;c[2430222]=124928;c[2439948]=125440;c[2439966]=127488;c[2438772]=129536;c[2438766]=129792;c[2411798]=130048;c[2406540]=130048;c[2405824]=195584;c[3529592]=457728;c[3530120]=719872;X=0;while(1){if((X|0)>=1024){break}Y=9638528+(X<<2)|0;if((c[Y>>2]|0)==0){Z=68875;break}else{X=X+1|0}}do{if((Z|0)==68875){X=gGq(720896)|0;c[Y>>2]=X;if((X|0)==0){break}c[2426798]=X;gGz(X|0,0,720896);c[3527378]=X;c[2385846]=X+81920;_=X+114688|0;c[2405706]=_;c[3527384]=_;c[2385864]=X+122368;c[2443432]=X+124416;c[2430222]=X+124928;c[2439948]=X+125440;c[2439966]=X+127488;c[2438772]=X+129536;c[2438766]=X+129792;_=X+130048|0;c[2411798]=_;c[2406540]=_;c[2405824]=X+195584;c[3529592]=X+457728;c[3530120]=X+719872;c[2414346]=X+720896;X=0;while(1){if((X|0)>=1024){$=0;break}aa=9638528+(X<<2)|0;if((c[aa>>2]|0)==0){Z=68880;break}else{X=X+1|0}}do{if((Z|0)==68880){X=gGq(131072)|0;c[aa>>2]=X;if((X|0)==0){$=0;break}gGz(X|0,0,131072);$=X}}while(0);c[3529542]=$;X=a[6147504]|0;_=c[3527378]|0;do{if((c[3542200]|0)==0){ab=1}else{ac=V+108|0;c[ac>>2]=0;ad=V+100|0;c[ad>>2]=0;ae=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ae&16383](V,0)|0;if((c[ac>>2]|0)==0){ab=0;break}ac=c[ad>>2]|0;c[W>>2]=9534384;ad=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ad&16383](W,0,0)|0;if((ac|0)<1){ab=1;break}ab=(gzL(_,0,0)|0)!=0}}while(0);do{if(X){if(ab){af=1;i=e;return af|0}_=(c[3527378]|0)+16384|0;if((c[3542200]|0)==0){af=1;i=e;return af|0}ac=T+108|0;c[ac>>2]=0;ad=T+100|0;c[ad>>2]=0;ae=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ae&16383](T,1)|0;do{if((c[ac>>2]|0)!=0){ae=c[ad>>2]|0;c[U>>2]=9534384;ah=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ah&16383](U,1,0)|0;if((ae|0)<1){af=1;i=e;return af|0}if((gzL(_,0,1)|0)==0){break}else{af=1}i=e;return af|0}}while(0);_=(c[3527378]|0)+32768|0;if((c[3542200]|0)==0){af=1;i=e;return af|0}ad=R+108|0;c[ad>>2]=0;ac=R+100|0;c[ac>>2]=0;ae=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ae&16383](R,2)|0;do{if((c[ad>>2]|0)!=0){ae=c[ac>>2]|0;c[S>>2]=9534384;ah=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ah&16383](S,2,0)|0;if((ae|0)<1){af=1;i=e;return af|0}if((gzL(_,0,2)|0)==0){break}else{af=1}i=e;return af|0}}while(0);_=(c[3527378]|0)+49152|0;if((c[3542200]|0)==0){af=1;i=e;return af|0}ac=P+108|0;c[ac>>2]=0;ad=P+100|0;c[ad>>2]=0;ae=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ae&16383](P,3)|0;do{if((c[ac>>2]|0)!=0){ae=c[ad>>2]|0;c[Q>>2]=9534384;ah=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ah&16383](Q,3,0)|0;if((ae|0)<1){af=1;i=e;return af|0}if((gzL(_,0,3)|0)==0){break}else{af=1}i=e;return af|0}}while(0);_=(c[3527378]|0)+65536|0;if((c[3542200]|0)==0){af=1;i=e;return af|0}ad=N+108|0;c[ad>>2]=0;ac=N+100|0;c[ac>>2]=0;ae=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ae&16383](N,4)|0;if((c[ad>>2]|0)==0){break}ad=c[ac>>2]|0;c[O>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](O,4,0)|0;if((ad|0)<1){af=1;i=e;return af|0}if((gzL(_,0,4)|0)==0){break}else{af=1}i=e;return af|0}else{if(ab){af=1;i=e;return af|0}_=(c[3527378]|0)+16384|0;if((c[3542200]|0)==0){af=1;i=e;return af|0}ad=L+108|0;c[ad>>2]=0;ac=L+100|0;c[ac>>2]=0;ae=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ae&16383](L,1)|0;do{if((c[ad>>2]|0)!=0){ae=c[ac>>2]|0;c[M>>2]=9534384;ah=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ah&16383](M,1,0)|0;if((ae|0)<1){af=1;i=e;return af|0}if((gzL(_,0,1)|0)==0){break}else{af=1}i=e;return af|0}}while(0);_=(c[3527378]|0)+49152|0;if((c[3542200]|0)==0){af=1;i=e;return af|0}ac=J+108|0;c[ac>>2]=0;ad=J+100|0;c[ad>>2]=0;ae=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ae&16383](J,2)|0;if((c[ac>>2]|0)==0){break}ac=c[ad>>2]|0;c[K>>2]=9534384;ad=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ad&16383](K,2,0)|0;if((ac|0)<1){af=1;i=e;return af|0}if((gzL(_,0,2)|0)==0){break}else{af=1}i=e;return af|0}}while(0);X=c[2385846]|0;_=a[6147504]|0?5:3;if((c[3542200]|0)==0){af=1;i=e;return af|0}ac=H+108|0;c[ac>>2]=0;ad=H+100|0;c[ad>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](H,_)|0;do{if((c[ac>>2]|0)!=0){ae=c[ad>>2]|0;c[I>>2]=9534384;ah=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ah&16383](I,_,0)|0;if((ae|0)<1){af=1;i=e;return af|0}if((gzL(X,0,_)|0)==0){break}else{af=1}i=e;return af|0}}while(0);_=c[3529542]|0;X=a[6147504]|0?6:4;if((c[3542200]|0)==0){af=1;i=e;return af|0}ad=F+108|0;c[ad>>2]=0;ac=F+100|0;c[ac>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](F,X)|0;do{if((c[ad>>2]|0)!=0){ae=c[ac>>2]|0;c[G>>2]=9534384;ah=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ah&16383](G,X,0)|0;if((ae|0)<1){af=1;i=e;return af|0}if((gzL(_,0,X)|0)==0){break}else{af=1}i=e;return af|0}}while(0);X=c[3529542]|0;_=c[2406540]|0;ac=0;do{ad=ac<<6;gGz(_+ad|0,0,64);ae=ac<<7;ah=ae|4;ai=0;while(1){aj=ah+(c[6669224+(ai<<2)>>2]|0)|0;ak=(ai<<3)+ad|0;al=0;do{am=aj+(c[612480+(al<<2)>>2]|0)|0;if(((d[X+((am|0)/8|0)|0]|0)&128>>>((am&7)>>>0)|0)!=0){am=_+(ak+al)|0;a[am]=a[am]|2}al=al+1|0;}while((al|0)<8);al=ai+1|0;if((al|0)<8){ai=al}else{an=0;break}}do{ai=ae+(c[6669224+(an<<2)>>2]|0)|0;ah=(an<<3)+ad|0;al=0;do{ak=ai+(c[612480+(al<<2)>>2]|0)|0;if(((d[X+((ak|0)/8|0)|0]|0)&128>>>((ak&7)>>>0)|0)!=0){ak=_+(ah+al)|0;a[ak]=a[ak]|1}al=al+1|0;}while((al|0)<8);an=an+1|0;}while((an|0)<8);ac=ac+1|0;}while((ac|0)<1024);gGz(X|0,0,131072);ac=a[6147504]|0?7:5;if((c[3542200]|0)==0){af=1;i=e;return af|0}_=D+108|0;c[_>>2]=0;ad=D+100|0;c[ad>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](D,ac)|0;do{if((c[_>>2]|0)!=0){ae=c[ad>>2]|0;c[E>>2]=9534384;al=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[al&16383](E,ac,0)|0;if((ae|0)<1){af=1;i=e;return af|0}if((gzL(X,0,ac)|0)==0){break}else{af=1}i=e;return af|0}}while(0);ac=(c[3529542]|0)+16384|0;X=a[6147504]|0?8:6;if((c[3542200]|0)==0){af=1;i=e;return af|0}ad=B+108|0;c[ad>>2]=0;_=B+100|0;c[_>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](B,X)|0;do{if((c[ad>>2]|0)!=0){ae=c[_>>2]|0;c[C>>2]=9534384;al=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[al&16383](C,X,0)|0;if((ae|0)<1){af=1;i=e;return af|0}if((gzL(ac,0,X)|0)==0){break}else{af=1}i=e;return af|0}}while(0);X=(c[3529542]|0)+32768|0;ac=a[6147504]|0?9:7;if((c[3542200]|0)==0){af=1;i=e;return af|0}_=z+108|0;c[_>>2]=0;ad=z+100|0;c[ad>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,ac)|0;do{if((c[_>>2]|0)!=0){ae=c[ad>>2]|0;c[A>>2]=9534384;al=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[al&16383](A,ac,0)|0;if((ae|0)<1){af=1;i=e;return af|0}if((gzL(X,0,ac)|0)==0){break}else{af=1}i=e;return af|0}}while(0);ac=(c[3529542]|0)+49152|0;X=a[6147504]|0?10:8;if((c[3542200]|0)==0){af=1;i=e;return af|0}ad=x+108|0;c[ad>>2]=0;_=x+100|0;c[_>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,X)|0;do{if((c[ad>>2]|0)!=0){ae=c[_>>2]|0;c[y>>2]=9534384;al=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[al&16383](y,X,0)|0;if((ae|0)<1){af=1;i=e;return af|0}if((gzL(ac,0,X)|0)==0){break}else{af=1}i=e;return af|0}}while(0);X=(c[3529542]|0)+65536|0;ac=a[6147504]|0?11:9;if((c[3542200]|0)==0){af=1;i=e;return af|0}_=v+108|0;c[_>>2]=0;ad=v+100|0;c[ad>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,ac)|0;do{if((c[_>>2]|0)!=0){ae=c[ad>>2]|0;c[w>>2]=9534384;al=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[al&16383](w,ac,0)|0;if((ae|0)<1){af=1;i=e;return af|0}if((gzL(X,0,ac)|0)==0){break}else{af=1}i=e;return af|0}}while(0);ac=(c[3529542]|0)+81920|0;X=a[6147504]|0?12:10;if((c[3542200]|0)==0){af=1;i=e;return af|0}ad=t+108|0;c[ad>>2]=0;_=t+100|0;c[_>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,X)|0;do{if((c[ad>>2]|0)!=0){ae=c[_>>2]|0;c[u>>2]=9534384;al=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[al&16383](u,X,0)|0;if((ae|0)<1){af=1;i=e;return af|0}if((gzL(ac,0,X)|0)==0){break}else{af=1}i=e;return af|0}}while(0);X=c[3529542]|0;ac=c[2405824]|0;_=0;do{ad=_<<8;gGz(ac+ad|0,0,256);ae=ad+524288|0;al=0;do{ah=ae+(c[609008+(al<<2)>>2]|0)|0;ai=(al<<4)+ad|0;ak=0;do{aj=ah+(c[597864+(ak<<2)>>2]|0)|0;if(((d[X+((aj|0)/8|0)|0]|0)&128>>>((aj&7)>>>0)|0)!=0){aj=ac+(ai+ak)|0;a[aj]=a[aj]|4}ak=ak+1|0;}while((ak|0)<16);al=al+1|0;}while((al|0)<16);al=ad+262144|0;ae=0;while(1){ak=al+(c[609008+(ae<<2)>>2]|0)|0;ai=(ae<<4)+ad|0;ah=0;do{aj=ak+(c[597864+(ah<<2)>>2]|0)|0;if(((d[X+((aj|0)/8|0)|0]|0)&128>>>((aj&7)>>>0)|0)!=0){aj=ac+(ai+ah)|0;a[aj]=a[aj]|2}ah=ah+1|0;}while((ah|0)<16);ah=ae+1|0;if((ah|0)<16){ae=ah}else{ao=0;break}}do{ae=ad+(c[609008+(ao<<2)>>2]|0)|0;al=(ao<<4)+ad|0;ah=0;do{ai=ae+(c[597864+(ah<<2)>>2]|0)|0;if(((d[X+((ai|0)/8|0)|0]|0)&128>>>((ai&7)>>>0)|0)!=0){ai=ac+(al+ah)|0;a[ai]=a[ai]|1}ah=ah+1|0;}while((ah|0)<16);ao=ao+1|0;}while((ao|0)<16);_=_+1|0;}while((_|0)<1024);gGz(X|0,-1|0,131072);_=a[6147504]|0?13:11;if((c[3542200]|0)==0){af=1;i=e;return af|0}ac=r+108|0;c[ac>>2]=0;ad=r+100|0;c[ad>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,_)|0;do{if((c[ac>>2]|0)!=0){ah=c[ad>>2]|0;c[s>>2]=9534384;al=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[al&16383](s,_,0)|0;if((ah|0)<1){af=1;i=e;return af|0}if((gzL(X,0,_)|0)==0){break}else{af=1}i=e;return af|0}}while(0);_=(c[3529542]|0)+16384|0;X=a[6147504]|0?14:12;if((c[3542200]|0)==0){af=1;i=e;return af|0}ad=p+108|0;c[ad>>2]=0;ac=p+100|0;c[ac>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,X)|0;do{if((c[ad>>2]|0)!=0){ah=c[ac>>2]|0;c[q>>2]=9534384;al=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[al&16383](q,X,0)|0;if((ah|0)<1){af=1;i=e;return af|0}if((gzL(_,0,X)|0)==0){break}else{af=1}i=e;return af|0}}while(0);X=(c[3529542]|0)+32768|0;_=a[6147504]|0?15:13;if((c[3542200]|0)==0){af=1;i=e;return af|0}ac=n+108|0;c[ac>>2]=0;ad=n+100|0;c[ad>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,_)|0;do{if((c[ac>>2]|0)!=0){ah=c[ad>>2]|0;c[o>>2]=9534384;al=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[al&16383](o,_,0)|0;if((ah|0)<1){af=1;i=e;return af|0}if((gzL(X,0,_)|0)==0){break}else{af=1}i=e;return af|0}}while(0);_=(c[3529542]|0)+65536|0;X=a[6147504]|0?16:14;if((c[3542200]|0)==0){af=1;i=e;return af|0}ad=l+108|0;c[ad>>2]=0;ac=l+100|0;c[ac>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,X)|0;do{if((c[ad>>2]|0)!=0){ah=c[ac>>2]|0;c[m>>2]=9534384;al=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[al&16383](m,X,0)|0;if((ah|0)<1){af=1;i=e;return af|0}if((gzL(_,0,X)|0)==0){break}else{af=1}i=e;return af|0}}while(0);X=(c[3529542]|0)+81920|0;_=a[6147504]|0?17:15;if((c[3542200]|0)==0){af=1;i=e;return af|0}ac=j+108|0;c[ac>>2]=0;ad=j+100|0;c[ad>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,_)|0;do{if((c[ac>>2]|0)!=0){ah=c[ad>>2]|0;c[k>>2]=9534384;al=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[al&16383](k,_,0)|0;if((ah|0)<1){af=1;i=e;return af|0}if((gzL(X,0,_)|0)==0){break}else{af=1}i=e;return af|0}}while(0);_=(c[3529542]|0)+98304|0;X=a[6147504]|0?18:16;if((c[3542200]|0)==0){af=1;i=e;return af|0}ad=f+108|0;c[ad>>2]=0;ac=f+100|0;c[ac>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,X)|0;do{if((c[ad>>2]|0)!=0){ah=c[ac>>2]|0;c[g>>2]=9534384;al=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[al&16383](g,X,0)|0;if((ah|0)<1){af=1;i=e;return af|0}if((gzL(_,0,X)|0)==0){break}else{af=1}i=e;return af|0}}while(0);X=c[3529542]|0;_=c[3529592]|0;ac=0;while(1){ad=ac<<8;gGz(_+ad|0,0,256);ah=ac<<9;al=0;do{ae=1<<3-al;ai=(c[611360+(al<<2)>>2]|0)+ah|0;ak=0;do{aj=ai+(c[608544+(ak<<2)>>2]|0)|0;am=(ak<<4)+ad|0;ap=0;do{aq=aj+(c[609552+(ap<<2)>>2]|0)|0;if(((d[X+((aq|0)/8|0)|0]|0)&128>>>((aq&7)>>>0)|0)!=0){aq=_+(am+ap)|0;a[aq]=(d[aq]|0|ae)&255}ap=ap+1|0;}while((ap|0)<16);ak=ak+1|0;}while((ak|0)<16);al=al+1|0;}while((al|0)<4);al=ac+1|0;if((al|0)<1024){ac=al}else{ar=0;break}}while(1){if((ar|0)>=1024){break}as=9638528+(ar<<2)|0;if((c[as>>2]|0)==(X|0)){Z=68996;break}else{ar=ar+1|0}}if((Z|0)==68996){gGr(X);c[as>>2]=0}c[3529542]=0;c[3528554]=-1;c[2113160]=1;ac=gGq(3148)|0;_=ac;c[2433592]=_;if((ac|0)!=0){gGz(ac|0,0,3148);c[ac+3120>>2]=3128;c[ac+3124>>2]=1840;c[ac+3128>>2]=136;c[ac+3132>>2]=1902;c[2432840]=0;al=0;do{c[_+48+(al<<2)>>2]=0;al=al+1|0;}while((al|0)<768);c[2113158]=0;c[2415198]=0;al=c[2427044]|0;c[9681616+(al<<3)>>2]=809272;c[9681620+(al<<3)>>2]=0;c[2427044]=al+1}c[3528554]=0;f43(ac);al=c[3528554]|0;_=9731360+(al<<2)|0;X=c[_>>2]|0;c[2113158]=X;ad=c[3527384]|0;ah=c[2433592]|0;ak=0;ae=0;while(1){ai=ad+(ae<<8)|0;c[ah+(al*3148|0)+48+(ae<<2)>>2]=ai;c[ah+(al*3148|0)+48+(ae+256<<2)>>2]=ai;c[ah+(al*3148|0)+48+(ae+512<<2)>>2]=ai;ai=ak+1&65535;if((ai&65535)>29){break}else{ak=ai;ae=ai&65535}}ae=c[2443432]|0;c[ah+(al*3148|0)+168>>2]=ae;c[ah+(al*3148|0)+1192>>2]=ae;c[ah+(al*3148|0)+2216>>2]=ae;ak=ae+256|0;c[ah+(al*3148|0)+172>>2]=ak;c[ah+(al*3148|0)+1196>>2]=ak;c[ah+(al*3148|0)+2220>>2]=ak;ak=c[2439948]|0;c[ah+(al*3148|0)+176>>2]=ak;c[ah+(al*3148|0)+1200>>2]=ak;c[ah+(al*3148|0)+2224>>2]=ak;ae=ak+256|0;c[ah+(al*3148|0)+180>>2]=ae;c[ah+(al*3148|0)+1204>>2]=ae;c[ah+(al*3148|0)+2228>>2]=ae;ae=ak+512|0;c[ah+(al*3148|0)+184>>2]=ae;c[ah+(al*3148|0)+1208>>2]=ae;c[ah+(al*3148|0)+2232>>2]=ae;ae=ak+768|0;c[ah+(al*3148|0)+188>>2]=ae;c[ah+(al*3148|0)+1212>>2]=ae;c[ah+(al*3148|0)+2236>>2]=ae;ae=ak+1024|0;c[ah+(al*3148|0)+192>>2]=ae;c[ah+(al*3148|0)+1216>>2]=ae;c[ah+(al*3148|0)+2240>>2]=ae;ae=ak+1280|0;c[ah+(al*3148|0)+196>>2]=ae;c[ah+(al*3148|0)+1220>>2]=ae;c[ah+(al*3148|0)+2244>>2]=ae;ae=ak+1536|0;c[ah+(al*3148|0)+200>>2]=ae;c[ah+(al*3148|0)+1224>>2]=ae;c[ah+(al*3148|0)+2248>>2]=ae;ae=ak+1792|0;c[ah+(al*3148|0)+204>>2]=ae;c[ah+(al*3148|0)+1228>>2]=ae;c[ah+(al*3148|0)+2252>>2]=ae;ae=c[2439966]|0;c[ah+(al*3148|0)+208>>2]=ae;c[ah+(al*3148|0)+1232>>2]=ae;c[ah+(al*3148|0)+2256>>2]=ae;ak=ae+256|0;c[ah+(al*3148|0)+212>>2]=ak;c[ah+(al*3148|0)+1236>>2]=ak;c[ah+(al*3148|0)+2260>>2]=ak;ak=ae+512|0;c[ah+(al*3148|0)+216>>2]=ak;c[ah+(al*3148|0)+1240>>2]=ak;c[ah+(al*3148|0)+2264>>2]=ak;ak=ae+768|0;c[ah+(al*3148|0)+220>>2]=ak;c[ah+(al*3148|0)+1244>>2]=ak;c[ah+(al*3148|0)+2268>>2]=ak;ak=ae+1024|0;c[ah+(al*3148|0)+224>>2]=ak;c[ah+(al*3148|0)+1248>>2]=ak;c[ah+(al*3148|0)+2272>>2]=ak;ak=ae+1280|0;c[ah+(al*3148|0)+228>>2]=ak;c[ah+(al*3148|0)+1252>>2]=ak;c[ah+(al*3148|0)+2276>>2]=ak;ak=ae+1536|0;c[ah+(al*3148|0)+232>>2]=ak;c[ah+(al*3148|0)+1256>>2]=ak;c[ah+(al*3148|0)+2280>>2]=ak;ak=ae+1792|0;c[ah+(al*3148|0)+236>>2]=ak;c[ah+(al*3148|0)+1260>>2]=ak;c[ah+(al*3148|0)+2284>>2]=ak;ak=c[2438766]|0;c[ah+(al*3148|0)+272>>2]=ak;c[ah+(al*3148|0)+1296>>2]=ak;c[ah+(al*3148|0)+2320>>2]=ak;ak=c[2438772]|0;c[ah+(al*3148|0)+276>>2]=ak;c[ah+(al*3148|0)+1300>>2]=ak;c[ah+(al*3148|0)+2324>>2]=ak;ak=c[3527378]|0;ae=64;ad=64;while(1){ac=ak+((ad<<8)-16384)|0;c[ah+(al*3148|0)+48+(ad<<2)>>2]=ac;c[ah+(al*3148|0)+48+(ad+512<<2)>>2]=ac;ac=ae+1&65535;if((ac&65535)>95){at=96;au=96;break}else{ae=ac;ad=ac&65535}}while(1){ad=ak+((au<<8)-16384)|0;c[ah+(al*3148|0)+48+(au<<2)>>2]=ad;c[ah+(al*3148|0)+48+(au+512<<2)>>2]=ad;ad=at+1&65535;if((ad&65535)>255){break}else{at=ad;au=ad&65535}}c[ah+(al*3148|0)+3120>>2]=220;c[ah+(al*3148|0)+3124>>2]=1424;ak=ah+(al*3148|0)|0;if((ak|0)!=0){ad=ak;gGC(ad|0,9660752,48)|0}c[_>>2]=X;c[3528554]=-1;fwR(0);ad=c[2439330]|0;ak=(ad|0)==0;if(!ak){ae=ad;gGC(9706056,ae|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];ae=c[3528484]|0;c[2076596]=ae;ac=c[2417276]|0;c[3541536]=ac;c[1836236]=0;c[ad+4180>>2]=1674;c[ad+4184>>2]=1156;ai=c[2385846]|0;ap=0;am=0;while(1){c[ad+76+(am<<2)>>2]=ai+(am<<8);aj=ap+1&65535;if((aj&65535)>127){av=0;aw=0;break}else{ap=aj;am=aj&65535}}while(1){am=ai+(aw<<8)|0;c[ad+76+(aw+512<<2)>>2]=am;c[ad+76+(aw+768<<2)>>2]=am;am=av+1&65535;if((am&65535)>127){break}else{av=am;aw=am&65535}}ai=c[2385864]|0;c[ad+844>>2]=ai;am=ai+256|0;c[ad+848>>2]=am;ap=ai+512|0;c[ad+852>>2]=ap;X=ai+768|0;c[ad+856>>2]=X;_=ai+1024|0;c[ad+860>>2]=_;al=ai+1280|0;c[ad+864>>2]=al;ah=ai+1536|0;c[ad+868>>2]=ah;aj=ai+1792|0;c[ad+872>>2]=aj;c[ad+1868>>2]=ai;c[ad+1872>>2]=am;c[ad+1876>>2]=ap;c[ad+1880>>2]=X;c[ad+1884>>2]=_;c[ad+1888>>2]=al;c[ad+1892>>2]=ah;c[ad+1896>>2]=aj;c[ad+2892>>2]=ai;c[ad+3916>>2]=ai;c[ad+2896>>2]=am;c[ad+3920>>2]=am;c[ad+2900>>2]=ap;c[ad+3924>>2]=ap;c[ad+2904>>2]=X;c[ad+3928>>2]=X;c[ad+2908>>2]=_;c[ad+3932>>2]=_;c[ad+2912>>2]=al;c[ad+3936>>2]=al;c[ad+2916>>2]=ah;c[ad+3940>>2]=ah;c[ad+2920>>2]=aj;c[ad+3944>>2]=aj;if(!ak){aj=ad;gGC(aj|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=ae;c[2417276]=ac;c[1836236]=-1;Vr(2,15e5,0,3530,42,0);c[2438228]=3e6;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=681;h[745419]=.2;a[3203368]=1;h[745418]=.4;a[3203360]=1;h[745417]=.4;a[3203352]=1;h[745416]=.4;a[3203344]=1;h[745415]=.2;a[3203336]=1;h[745414]=.4;a[3203328]=1;h[745413]=.4;a[3203320]=1;h[745412]=.4;a[3203312]=1;aj=c[642608+(c[2436]<<2)>>2]|0;ah=c[aj+128>>2]|0;if((c[aj+52>>2]&4|0)==0){c[2113068]=ah;al=c[aj+132>>2]|0;c[2113070]=al;c[2443814]=ah;c[2440436]=al;ax=ah;ay=al}else{c[2113070]=ah;al=c[aj+132>>2]|0;c[2113068]=al;c[2440436]=ah;c[2443814]=al;ax=al;ay=ah}ah=ag(ax<<1,ay)|0;al=gGq(ah)|0;c[2112926]=al;if((al|0)!=0){gGz(al|0,0,ah|0)}c[3528554]=0;f43(c[2433592]|0);ah=c[3528554]|0;c[2113158]=c[9731360+(ah<<2)>>2];a[9660796]=0;a[9660797]=0;a[9660786]=0;a[9660787]=0;c[2415191]=0;a[9660784]=a[9660784]|80;al=c[2433592]|0;aj=c[al+(ah*3148|0)+1068>>2]|0;do{if((aj|0)==0){_=c[al+(ah*3148|0)+3120>>2]|0;if((_|0)==0){az=0;aA=0;aB=ah;aC=al;break}X=gj[_&4095](-2)|0;_=c[3528554]|0;ap=c[2433592]|0;am=c[ap+(_*3148|0)+1068>>2]|0;ai=(X&255)<<8;if((am|0)!=0){aD=am;aE=ai;aF=_;aG=ap;Z=69024;break}am=c[ap+(_*3148|0)+3120>>2]|0;if((am|0)==0){az=0;aA=ai;aB=_;aC=ap;break}ap=gj[am&4095](-1)|0;az=ap;aA=ai;aB=c[3528554]|0;aC=c[2433592]|0}else{aD=aj;aE=(d[aj+254|0]|0)<<8;aF=ah;aG=al;Z=69024}}while(0);if((Z|0)==69024){az=a[aD+255|0]|0;aA=aE;aB=aF;aC=aG}al=az&255|aA;c[2415188]=al;b[4830376]=al&65535;al=aC+(aB*3148|0)|0;if((al|0)!=0){ah=al;gGC(ah|0,9660752,48)|0}c[9731360+(aB<<2)>>2]=c[2113158];c[3528554]=-1;ah=c[2439330]|0;al=(ah|0)==0;if(!al){aj=ah;gGC(9706056,aj|0,76)|0}aj=c[2438118]|0;c[2433530]=aj;ac=c[3528484]|0;c[2076596]=ac;ae=c[2417276]|0;c[3541536]=ae;c[1836236]=0;gGz(9706056,0,76);if(!al){al=ah;gGC(al|0,9706056,76)|0}c[2438118]=aj;c[3528484]=ac;c[2417276]=ae;c[1836236]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){ae=0;do{lN(ae);mB(ae);ae=ae+1|0;}while((ae|0)<(c[2385508]|0))}a[14119352]=0;a[9774425]=0;a[9774424]=0;a[9774377]=0;a[9774376]=0;a[9758240]=0;af=0;i=e;return af|0}}while(0);c[2426798]=0;af=1;i=e;return af|0}function dlZ(){var b=0,d=0,e=0,f=0;c[2113160]=0;b=c[2433592]|0;if((b|0)!=0){gGr(b);c[2433592]=0}fwZ();b=c[3541518]|0;if((b|0)!=0){gGr(b|0);c[3541518]=0}if((c[2385508]|0)>0){c[2113008]=0;c[2076598]=0;c[2383582]=0}c[2438228]=0;c[2433526]=0;c[2406676]=0;c[3528472]=0;b=c[2406680]|0;if((b|0)!=0){gGr(b);c[2406680]=0}c[2385508]=0;c[2432978]=0;a[64240]=0;c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}b=c[2426798]|0;d=0;while(1){if((d|0)>=1024){e=69134;break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==(b|0)){break}else{d=d+1|0}}if((e|0)==69134){c[2426798]=0;a[14119352]=0;a[9774425]=0;a[9774424]=0;a[9774377]=0;a[9774376]=0;a[9758240]=0;a[6147504]=0;return 0}gGr(b);c[f>>2]=0;c[2426798]=0;a[14119352]=0;a[9774425]=0;a[9774424]=0;a[9774377]=0;a[9774376]=0;a[9758240]=0;a[6147504]=0;return 0}function dl_(){var e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;if((a[9624752]|0)!=0){c[3528554]=0;f43(c[2433592]|0);e=c[3528554]|0;c[2113158]=c[9731360+(e<<2)>>2];a[9660796]=0;a[9660797]=0;a[9660786]=0;a[9660787]=0;c[2415191]=0;a[9660784]=a[9660784]|80;f=c[2433592]|0;g=c[f+(e*3148|0)+1068>>2]|0;do{if((g|0)==0){i=c[f+(e*3148|0)+3120>>2]|0;if((i|0)==0){j=0;k=0;l=e;m=f;break}n=gj[i&4095](-2)|0;i=c[3528554]|0;o=c[2433592]|0;p=c[o+(i*3148|0)+1068>>2]|0;q=(n&255)<<8;if((p|0)!=0){r=p;s=q;t=i;u=o;v=69140;break}p=c[o+(i*3148|0)+3120>>2]|0;if((p|0)==0){j=0;k=q;l=i;m=o;break}o=gj[p&4095](-1)|0;j=o;k=q;l=c[3528554]|0;m=c[2433592]|0}else{r=g;s=d[g+254|0]<<8;t=e;u=f;v=69140}}while(0);if((v|0)==69140){j=a[r+255|0]|0;k=s;l=t;m=u}u=j&255|k;c[2415188]=u;b[4830376]=u&65535;u=m+(l*3148|0)|0;if((u|0)!=0){m=u;gGC(m|0,9660752,48)|0}c[9731360+(l<<2)>>2]=c[2113158];c[3528554]=-1;l=c[2439330]|0;m=(l|0)==0;if(!m){u=l;gGC(9706056,u|0,76)|0}u=c[2438118]|0;c[2433530]=u;k=c[3528484]|0;c[2076596]=k;j=c[2417276]|0;c[3541536]=j;c[1836236]=0;gGz(9706056,0,76);if(!m){m=l;gGC(m|0,9706056,76)|0}c[2438118]=u;c[3528484]=k;c[2417276]=j;c[1836236]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){j=0;do{lN(j);mB(j);j=j+1|0;}while((j|0)<(c[2385508]|0))}a[14119352]=0;a[9774425]=0;a[9774424]=0;a[9774377]=0;a[9774376]=0;a[9758240]=0}a[9625874]=0;a[9625873]=0;a[9625872]=0;j=0;k=0;u=0;m=0;do{k=((a[9759272+j|0]&1)<<j|k&255)&255;u=((a[9759080+j|0]&1)<<j|u&255)&255;m=((a[9758896+j|0]&1)<<j|m&255)&255;j=j+1|0;}while((j|0)<8);a[9625872]=k;a[9625873]=u;a[9625874]=m;if((u&3)==3){k=u&-4;a[9625873]=k;w=k}else{w=u}if((w&12)==12){a[9625873]=w&-13}if((m&3)==3){w=m&-4;a[9625874]=w;x=w}else{x=m}if((x&12)==12){a[9625874]=x&-13}a[6518336]=1;a[6518160]=1;c[2444109]=0;c[2444108]=0;x=c[2385548]|0;if((x|0)>0){gGz(9752472,0,((x|0)>1?x<<2:4)|0)}c[2433530]=0;x=0;m=0;L83052:while(1){w=m;while(1){if((w|0)>=25){break L83052}c[3528554]=0;f43(c[2433592]|0);c[2113158]=c[9731360+(c[3528554]<<2)>>2];y=w+1|0;u=(ag(a[6518336]|0?25e3:0,y)|0)/25|0;k=u-(c[2444108]|0)|0;c[2438202]=k;u=f45(k)|0;c[2113158]=(c[2113158]|0)+u;c[2444108]=(c[2444108]|0)+u;if((w|0)==24){f44(0);f45(0)|0;a[9660786]=0;f45(0)|0}u=c[3528554]|0;k=(c[2433592]|0)+(u*3148|0)|0;if((k|0)!=0){j=k;gGC(j|0,9660752,48)|0}c[9731360+(u<<2)>>2]=c[2113158];c[3528554]=-1;u=c[2439330]|0;if((u|0)!=0){j=u;gGC(9706056,j|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;Sb(ag(a[6518160]|0?2e3:0,w)|0);switch(w|0){case 21:case 16:case 11:case 6:{v=69175;break};case 20:case 15:case 10:case 5:{a[9706117]=1;if((w|0)==6|(w|0)==16|(w|0)==11){v=69175}break};default:{}}if((v|0)==69175){v=0;a[9706117]=0}j=c[1836236]|0;u=c[9757320+(j<<2)>>2]|0;if((u|0)!=0){k=u;gGC(k|0,9706056,76)|0}c[9752472+(j<<2)>>2]=c[2433530];c[14113936+(j<<2)>>2]=c[2076596];c[9669104+(j<<2)>>2]=c[3541536];c[1836236]=-1;z=c[2112964]|0;if((z|0)==0){w=y}else{break}}w=a[9688]|0?534:0;j=c[2439330]|0;if((j|0)!=0){k=j;gGC(9706056,k|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;gg[c[3542122]&4095](z+(x<<1<<1)|0,w-x|0);k=c[1836236]|0;j=c[9757320+(k<<2)>>2]|0;if((j|0)!=0){u=j;gGC(u|0,9706056,76)|0}c[9752472+(k<<2)>>2]=c[2433530];c[14113936+(k<<2)>>2]=c[2076596];c[9669104+(k<<2)>>2]=c[3541536];c[1836236]=-1;x=w;m=y}y=c[2439330]|0;if((y|0)!=0){m=y;gGC(9706056,m|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;m=a[6518160]|0?5e4:0;y=gGU(m,0,2048e6,0)|0;z=c[2438228]|0;w=gGS(y,K,z,(z|0)<0|0?-1:0)|0;z=w;Sb(m);m=c[2443830]|0;if((m|0)<1073676288){c[2443830]=m-z}m=c[2443831]|0;if((m|0)<1073676288){c[2443831]=m-z}m=(c[3528512]|0)-z|0;c[3528512]=(m|0)<0?0:m;m=c[1836236]|0;z=c[9757320+(m<<2)>>2]|0;if((z|0)!=0){w=z;gGC(w|0,9706056,76)|0}c[9752472+(m<<2)>>2]=c[2433530];c[14113936+(m<<2)>>2]=c[2076596];c[9669104+(m<<2)>>2]=c[3541536];c[1836236]=-1;m=c[2112964]|0;do{if((m|0)!=0){w=a[9688]|0?534:0;if((w|0)==(x|0)){break}z=c[2439330]|0;if((z|0)!=0){y=z;gGC(9706056,y|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;gg[c[3542122]&4095](m+(x<<1<<1)|0,w-x|0);w=c[1836236]|0;y=c[9757320+(w<<2)>>2]|0;if((y|0)!=0){z=y;gGC(z|0,9706056,76)|0}c[9752472+(w<<2)>>2]=c[2433530];c[14113936+(w<<2)>>2]=c[2076596];c[9669104+(w<<2)>>2]=c[3541536];c[1836236]=-1}}while(0);if((c[2112968]|0)==0){A=c[2430222]|0;B=c[2443432]|0;gGC(A|0,B|0,512)|0;return 0}x=c[2112926]|0;gGz(x|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);m=c[2438772]|0;w=c[2438766]|0;z=c[3530120]|0;y=0;do{k=a[w+y|0]|0;u=k&255;j=(u&65535)>>>4;l=((u<<8|d[m+y|0])&65535)>>>4;c[z+(y<<2)>>2]=((j<<4|j)&65535)<<8&63488|((k<<4|k&12)&255)<<3&2016|((l<<4&255|l&8)&255)>>>3;y=y+1|0;}while((y|0)<256);dmt(0,1);y=c[2430222]|0;m=c[3529592]|0;w=508;do{l=d[y+(w|1)|0]|0;k=(d[y+(w|3)|0]|0)-(l<<8&256)|0;j=a[y+(w|2)|0]|0;u=j&255;t=l&4;s=l&8;r=d[y+w|0]|l<<2&768;f=l>>>4&3;do{if((k-17|0)>>>0<223){if((j-17&255)>=191){v=69213;break}l=(s|0)!=0;e=u-16|0;if((t|0)==0){if(l){SK(x,r,k,e,f,4,15,64,m);break}else{SG(x,r,k,e,f,4,15,64,m);break}}else{if(l){SM(x,r,k,e,f,4,15,64,m);break}else{SI(x,r,k,e,f,4,15,64,m);break}}}else{v=69213}}while(0);do{if((v|0)==69213){v=0;j=(s|0)!=0;e=u-16|0;if((t|0)==0){if(j){SL(x,r,k,e,f,4,15,64,m);break}else{SH(x,r,k,e,f,4,15,64,m);break}}else{if(j){SN(x,r,k,e,f,4,15,64,m);break}else{SJ(x,r,k,e,f,4,15,64,m);break}}}}while(0);w=w-4|0;}while((w|0)>-1);dmt(1,0);w=c[2439948]|0;m=c[2406540]|0;v=0;f=0;while(1){k=f<<3;r=k-16|0;if((k-25|0)>>>0<207){k=v;t=0;while(1){u=d[w+(k+1024)|0]|0;s=u<<2&768|d[w+k|0];e=u&15;j=t<<3;l=(u&16|0)==0;g=(u&32|0)!=0;do{if((j-9|0)>>>0<239){if(l){if(g){Su(x,s,j,r,e,2,3,128,m);break}else{Sq(x,s,j,r,e,2,3,128,m);break}}else{if(g){Sw(x,s,j,r,e,2,3,128,m);break}else{Ss(x,s,j,r,e,2,3,128,m);break}}}else{if(l){if(g){Sv(x,s,j,r,e,2,3,128,m);break}else{Sr(x,s,j,r,e,2,3,128,m);break}}else{if(g){Sx(x,s,j,r,e,2,3,128,m);break}else{St(x,s,j,r,e,2,3,128,m);break}}}}while(0);e=t+1|0;if((e|0)<32){k=k+1|0;t=e}else{break}}}else{t=v;k=0;while(1){e=d[w+(t+1024)|0]|0;j=e<<2&768|d[w+t|0];s=e&15;g=k<<3;l=(e&32|0)!=0;do{if((e&16|0)==0){if(l){Sv(x,j,g,r,s,2,3,128,m);break}else{Sr(x,j,g,r,s,2,3,128,m);break}}else{if(l){Sx(x,j,g,r,s,2,3,128,m);break}else{St(x,j,g,r,s,2,3,128,m);break}}}while(0);s=k+1|0;if((s|0)<32){t=t+1|0;k=s}else{break}}}k=f+1|0;if((k|0)<32){v=v+32|0;f=k}else{break}}R8(z);A=y;B=c[2443432]|0;gGC(A|0,B|0,512)|0;return 0}function dl$(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;e=i;i=i+224|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;l=e+80|0;m=e+96|0;n=e+112|0;o=e+128|0;p=e+144|0;q=e+160|0;r=e+176|0;s=e+192|0;t=e+208|0;if((d|0)!=0){c[d>>2]=169622}if((b&32|0)!=0){gGz(t|0,0,12);u=c[2405706]|0;c[t>>2]=u;c[t+4>>2]=(c[2411798]|0)-u;c[t+12>>2]=162152;u=c[2076592]|0;gj[u&4095](t)|0}if((b&64|0)==0){i=e;return 0}t=k|0;if((c[2113160]|0)>0){u=k+7|0;k=j|0;v=j+4|0;w=j+12|0;x=h;y=h|0;z=h+4|0;A=h+12|0;B=g;C=g|0;D=g+4|0;E=g+12|0;F=f;G=f|0;H=f+4|0;I=f+12|0;J=0;do{K=c[2433592]|0;L=K+(J*3148|0)+40|0;M=c[L>>2]|0;gGC(t|0,614752,9)|0;a[u]=J+48&255;c[k>>2]=K+(J*3148|0);c[v>>2]=48;c[w>>2]=t;gj[c[2076592]&4095](j)|0;gGz(x|0,0,12);c[y>>2]=K+(J*3148|0)+3136;c[z>>2]=4;c[A>>2]=165288;gj[c[2076592]&4095](h)|0;gGz(B|0,0,12);c[C>>2]=K+(J*3148|0)+3140;c[D>>2]=4;c[E>>2]=501592;gj[c[2076592]&4095](g)|0;gGz(F|0,0,12);c[G>>2]=K+(J*3148|0)+3144;c[H>>2]=4;c[I>>2]=386080;gj[c[2076592]&4095](f)|0;c[L>>2]=M;J=J+1|0;}while((J|0)<(c[2113160]|0))}fw$(b);Vx(b,d);gGz(s|0,0,12);c[s>>2]=9776432;c[s+4>>2]=8;c[s+12>>2]=212472;gj[c[2076592]&4095](s)|0;gGz(r|0,0,12);c[r>>2]=9752808;c[r+4>>2]=4;c[r+12>>2]=436576;gj[c[2076592]&4095](r)|0;gGz(q|0,0,12);c[q>>2]=14119352;c[q+4>>2]=1;c[q+12>>2]=511192;gj[c[2076592]&4095](q)|0;gGz(p|0,0,12);c[p>>2]=9758240;c[p+4>>2]=1;c[p+12>>2]=497064;gj[c[2076592]&4095](p)|0;gGz(o|0,0,12);c[o>>2]=9774424;c[o+4>>2]=2;c[o+12>>2]=169648;gj[c[2076592]&4095](o)|0;gGz(n|0,0,12);c[n>>2]=9774376;c[n+4>>2]=2;c[n+12>>2]=166776;gj[c[2076592]&4095](n)|0;gGz(m|0,0,12);c[m>>2]=9658056;c[m+4>>2]=2;c[m+12>>2]=483352;gj[c[2076592]&4095](m)|0;gGz(l|0,0,12);c[l>>2]=9625872;c[l+4>>2]=3;c[l+12>>2]=215728;gj[c[2076592]&4095](l)|0;i=e;return 0}function dl0(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7301492+(b*112|0)>>2];c[a+104>>2]=c[7301496+(b*112|0)>>2];c[a+108>>2]=c[7301500+(b*112|0)>>2];d=0;return d|0}function dl1(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<21&(d|0)==0)){e=1;return e|0}c[a>>2]=7301392+(b*112|0);e=0;return e|0}function dl2(){a[6147504]=1;return dlY()|0}function dl3(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6909092+(b*112|0)>>2];c[a+104>>2]=c[6909096+(b*112|0)>>2];c[a+108>>2]=c[6909100+(b*112|0)>>2];d=0;return d|0}function dl4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=6908992+(b*112|0);e=0;return e|0}function dl5(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6342324+(b*112|0)>>2];c[a+104>>2]=c[6342328+(b*112|0)>>2];c[a+108>>2]=c[6342332+(b*112|0)>>2];d=0;return d|0}function dl6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=6342224+(b*112|0);e=0;return e|0}function dl7(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4037364+(b*112|0)>>2];c[a+104>>2]=c[4037368+(b*112|0)>>2];c[a+108>>2]=c[4037372+(b*112|0)>>2];d=0;return d|0}function dl8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=4037264+(b*112|0);e=0;return e|0}function dl9(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5448444+(b*112|0)>>2];c[a+104>>2]=c[5448448+(b*112|0)>>2];c[a+108>>2]=c[5448452+(b*112|0)>>2];d=0;return d|0}function dma(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=5448344+(b*112|0);e=0;return e|0}function dmb(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7237588+(b*112|0)>>2];c[a+104>>2]=c[7237592+(b*112|0)>>2];c[a+108>>2]=c[7237596+(b*112|0)>>2];d=0;return d|0}function dmc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=7237488+(b*112|0);e=0;return e|0}function dmd(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7270044+(b*112|0)>>2];c[a+104>>2]=c[7270048+(b*112|0)>>2];c[a+108>>2]=c[7270052+(b*112|0)>>2];d=0;return d|0}function dme(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=7269944+(b*112|0);e=0;return e|0}function dmf(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3767236+(b*112|0)>>2];c[a+104>>2]=c[3767240+(b*112|0)>>2];c[a+108>>2]=c[3767244+(b*112|0)>>2];d=0;return d|0}function dmg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=3767136+(b*112|0);e=0;return e|0}function dmh(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>51){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7268960+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dmi(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3771492+(b*112|0)>>2];c[a+104>>2]=c[3771496+(b*112|0)>>2];c[a+108>>2]=c[3771500+(b*112|0)>>2];d=0;return d|0}function dmj(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=3771392+(b*112|0);e=0;return e|0}function dmk(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3769364+(b*112|0)>>2];c[a+104>>2]=c[3769368+(b*112|0)>>2];c[a+108>>2]=c[3769372+(b*112|0)>>2];d=0;return d|0}function dml(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=3769264+(b*112|0);e=0;return e|0}function dmm(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5461268+(b*112|0)>>2];c[a+104>>2]=c[5461272+(b*112|0)>>2];c[a+108>>2]=c[5461276+(b*112|0)>>2];d=0;return d|0}function dmn(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=5461168+(b*112|0);e=0;return e|0}function dmo(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1957672+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dmp(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>41){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5462960+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dmq(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0;e=i;i=i+1680|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;B=e+1200|0;C=e+1312|0;D=e+1320|0;E=e+1432|0;F=e+1440|0;G=e+1552|0;H=e+1560|0;I=e+1672|0;c[2426798]=0;c[3527378]=0;c[2385846]=81920;c[2405706]=114688;c[3527384]=114688;c[2385864]=122368;c[2443432]=124416;c[2430222]=124928;c[2439948]=125440;c[2439966]=127488;c[2438772]=129536;c[2438766]=129792;c[2411798]=130048;c[2406540]=130048;c[2405824]=195584;c[3529592]=457728;c[3530120]=719872;J=0;while(1){if((J|0)>=1024){break}K=9638528+(J<<2)|0;if((c[K>>2]|0)==0){L=69421;break}else{J=J+1|0}}do{if((L|0)==69421){J=gGq(720896)|0;c[K>>2]=J;if((J|0)==0){break}c[2426798]=J;gGz(J|0,0,720896);c[3527378]=J;c[2385846]=J+81920;M=J+114688|0;c[2405706]=M;c[3527384]=M;c[2385864]=J+122368;c[2443432]=J+124416;c[2430222]=J+124928;c[2439948]=J+125440;c[2439966]=J+127488;c[2438772]=J+129536;c[2438766]=J+129792;M=J+130048|0;c[2411798]=M;c[2406540]=M;c[2405824]=J+195584;c[3529592]=J+457728;c[3530120]=J+719872;c[2414346]=J+720896;J=0;while(1){if((J|0)>=1024){N=0;break}O=9638528+(J<<2)|0;if((c[O>>2]|0)==0){L=69426;break}else{J=J+1|0}}do{if((L|0)==69426){J=gGq(131072)|0;c[O>>2]=J;if((J|0)==0){N=0;break}gGz(J|0,0,131072);N=J}}while(0);c[3529542]=N;J=c[3527378]|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}M=H+108|0;c[M>>2]=0;Q=H+100|0;c[Q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](H,0)|0;do{if((c[M>>2]|0)!=0){R=c[Q>>2]|0;c[I>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](I,0,0)|0;if((R|0)<1){P=1;i=e;return P|0}if((gzL(J,0,0)|0)==0){break}else{P=1}i=e;return P|0}}while(0);J=(c[3527378]|0)+16384|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}Q=F+108|0;c[Q>>2]=0;M=F+100|0;c[M>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](F,1)|0;do{if((c[Q>>2]|0)!=0){R=c[M>>2]|0;c[G>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](G,1,0)|0;if((R|0)<1){P=1;i=e;return P|0}if((gzL(J,0,1)|0)==0){break}else{P=1}i=e;return P|0}}while(0);J=(c[3527378]|0)+49152|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}M=D+108|0;c[M>>2]=0;Q=D+100|0;c[Q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](D,2)|0;do{if((c[M>>2]|0)!=0){R=c[Q>>2]|0;c[E>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](E,2,0)|0;if((R|0)<1){P=1;i=e;return P|0}if((gzL(J,0,2)|0)==0){break}else{P=1}i=e;return P|0}}while(0);J=(c[3527378]|0)+81920|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}Q=B+108|0;c[Q>>2]=0;M=B+100|0;c[M>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](B,3)|0;do{if((c[Q>>2]|0)!=0){R=c[M>>2]|0;c[C>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](C,3,0)|0;if((R|0)<1){P=1;i=e;return P|0}if((gzL(J,0,3)|0)==0){break}else{P=1}i=e;return P|0}}while(0);J=c[2385846]|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}M=z+108|0;c[M>>2]=0;Q=z+100|0;c[Q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,4)|0;do{if((c[M>>2]|0)!=0){R=c[Q>>2]|0;c[A>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](A,4,0)|0;if((R|0)<1){P=1;i=e;return P|0}if((gzL(J,0,4)|0)==0){break}else{P=1}i=e;return P|0}}while(0);J=c[3529542]|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}Q=x+108|0;c[Q>>2]=0;M=x+100|0;c[M>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,5)|0;do{if((c[Q>>2]|0)!=0){R=c[M>>2]|0;c[y>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](y,5,0)|0;if((R|0)<1){P=1;i=e;return P|0}if((gzL(J,0,5)|0)==0){break}else{P=1}i=e;return P|0}}while(0);J=c[3529542]|0;M=c[2406540]|0;Q=0;do{R=Q<<6;gGz(M+R|0,0,64);S=Q<<7;T=S|4;U=0;while(1){V=T+(c[6669224+(U<<2)>>2]|0)|0;W=(U<<3)+R|0;X=0;do{Y=V+(c[612480+(X<<2)>>2]|0)|0;if(((d[J+((Y|0)/8|0)|0]|0)&128>>>((Y&7)>>>0)|0)!=0){Y=M+(W+X)|0;a[Y]=a[Y]|2}X=X+1|0;}while((X|0)<8);X=U+1|0;if((X|0)<8){U=X}else{Z=0;break}}do{U=S+(c[6669224+(Z<<2)>>2]|0)|0;T=(Z<<3)+R|0;X=0;do{W=U+(c[612480+(X<<2)>>2]|0)|0;if(((d[J+((W|0)/8|0)|0]|0)&128>>>((W&7)>>>0)|0)!=0){W=M+(T+X)|0;a[W]=a[W]|1}X=X+1|0;}while((X|0)<8);Z=Z+1|0;}while((Z|0)<8);Q=Q+1|0;}while((Q|0)<1024);gGz(J|0,0,131072);if((c[3542200]|0)==0){P=1;i=e;return P|0}Q=v+108|0;c[Q>>2]=0;M=v+100|0;c[M>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,6)|0;do{if((c[Q>>2]|0)!=0){R=c[M>>2]|0;c[w>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](w,6,0)|0;if((R|0)<1){P=1;i=e;return P|0}if((gzL(J,0,6)|0)==0){break}else{P=1}i=e;return P|0}}while(0);J=(c[3529542]|0)+16384|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}M=t+108|0;c[M>>2]=0;Q=t+100|0;c[Q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,7)|0;do{if((c[M>>2]|0)!=0){R=c[Q>>2]|0;c[u>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](u,7,0)|0;if((R|0)<1){P=1;i=e;return P|0}if((gzL(J,0,7)|0)==0){break}else{P=1}i=e;return P|0}}while(0);J=(c[3529542]|0)+32768|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}Q=r+108|0;c[Q>>2]=0;M=r+100|0;c[M>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,8)|0;do{if((c[Q>>2]|0)!=0){R=c[M>>2]|0;c[s>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](s,8,0)|0;if((R|0)<1){P=1;i=e;return P|0}if((gzL(J,0,8)|0)==0){break}else{P=1}i=e;return P|0}}while(0);J=(c[3529542]|0)+49152|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}M=p+108|0;c[M>>2]=0;Q=p+100|0;c[Q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,9)|0;do{if((c[M>>2]|0)!=0){R=c[Q>>2]|0;c[q>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](q,9,0)|0;if((R|0)<1){P=1;i=e;return P|0}if((gzL(J,0,9)|0)==0){break}else{P=1}i=e;return P|0}}while(0);J=(c[3529542]|0)+65536|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}Q=n+108|0;c[Q>>2]=0;M=n+100|0;c[M>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,10)|0;do{if((c[Q>>2]|0)!=0){R=c[M>>2]|0;c[o>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](o,10,0)|0;if((R|0)<1){P=1;i=e;return P|0}if((gzL(J,0,10)|0)==0){break}else{P=1}i=e;return P|0}}while(0);J=(c[3529542]|0)+81920|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}M=l+108|0;c[M>>2]=0;Q=l+100|0;c[Q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,11)|0;do{if((c[M>>2]|0)!=0){R=c[Q>>2]|0;c[m>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](m,11,0)|0;if((R|0)<1){P=1;i=e;return P|0}if((gzL(J,0,11)|0)==0){break}else{P=1}i=e;return P|0}}while(0);J=c[3529542]|0;Q=c[2405824]|0;M=0;do{R=M<<8;gGz(Q+R|0,0,256);S=R+524288|0;X=0;do{T=S+(c[609008+(X<<2)>>2]|0)|0;U=(X<<4)+R|0;W=0;do{V=T+(c[597864+(W<<2)>>2]|0)|0;if(((d[J+((V|0)/8|0)|0]|0)&128>>>((V&7)>>>0)|0)!=0){V=Q+(U+W)|0;a[V]=a[V]|4}W=W+1|0;}while((W|0)<16);X=X+1|0;}while((X|0)<16);X=R+262144|0;S=0;while(1){W=X+(c[609008+(S<<2)>>2]|0)|0;U=(S<<4)+R|0;T=0;do{V=W+(c[597864+(T<<2)>>2]|0)|0;if(((d[J+((V|0)/8|0)|0]|0)&128>>>((V&7)>>>0)|0)!=0){V=Q+(U+T)|0;a[V]=a[V]|2}T=T+1|0;}while((T|0)<16);T=S+1|0;if((T|0)<16){S=T}else{_=0;break}}do{S=R+(c[609008+(_<<2)>>2]|0)|0;X=(_<<4)+R|0;T=0;do{U=S+(c[597864+(T<<2)>>2]|0)|0;if(((d[J+((U|0)/8|0)|0]|0)&128>>>((U&7)>>>0)|0)!=0){U=Q+(X+T)|0;a[U]=a[U]|1}T=T+1|0;}while((T|0)<16);_=_+1|0;}while((_|0)<16);M=M+1|0;}while((M|0)<1024);gGz(J|0,-1|0,131072);if((c[3542200]|0)==0){P=1;i=e;return P|0}M=j+108|0;c[M>>2]=0;Q=j+100|0;c[Q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,12)|0;do{if((c[M>>2]|0)!=0){R=c[Q>>2]|0;c[k>>2]=9534384;T=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[T&16383](k,12,0)|0;if((R|0)<1){P=1;i=e;return P|0}if((gzL(J,0,12)|0)==0){break}else{P=1}i=e;return P|0}}while(0);J=(c[3529542]|0)+65536|0;Q=a[6147504]|0?15:13;if((c[3542200]|0)==0){P=1;i=e;return P|0}M=f+108|0;c[M>>2]=0;R=f+100|0;c[R>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,Q)|0;do{if((c[M>>2]|0)!=0){T=c[R>>2]|0;c[g>>2]=9534384;X=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[X&16383](g,Q,0)|0;if((T|0)<1){P=1;i=e;return P|0}if((gzL(J,0,Q)|0)==0){break}else{P=1}i=e;return P|0}}while(0);Q=c[3529542]|0;J=c[3529592]|0;R=0;while(1){M=R<<8;gGz(J+M|0,0,256);T=R<<9;X=0;do{S=1<<3-X;U=(c[611360+(X<<2)>>2]|0)+T|0;W=0;do{V=U+(c[608544+(W<<2)>>2]|0)|0;Y=(W<<4)+M|0;$=0;do{aa=V+(c[609552+($<<2)>>2]|0)|0;if(((d[Q+((aa|0)/8|0)|0]|0)&128>>>((aa&7)>>>0)|0)!=0){aa=J+(Y+$)|0;a[aa]=(d[aa]|0|S)&255}$=$+1|0;}while(($|0)<16);W=W+1|0;}while((W|0)<16);X=X+1|0;}while((X|0)<4);X=R+1|0;if((X|0)<1024){R=X}else{ab=0;break}}while(1){if((ab|0)>=1024){break}ac=9638528+(ab<<2)|0;if((c[ac>>2]|0)==(Q|0)){L=69511;break}else{ab=ab+1|0}}if((L|0)==69511){gGr(Q);c[ac>>2]=0}c[3529542]=0;c[3528554]=-1;c[2113160]=1;R=gGq(3148)|0;J=R;c[2433592]=J;if((R|0)!=0){gGz(R|0,0,3148);c[R+3120>>2]=3128;c[R+3124>>2]=1840;c[R+3128>>2]=136;c[R+3132>>2]=1902;c[2432840]=0;X=0;do{c[J+48+(X<<2)>>2]=0;X=X+1|0;}while((X|0)<768);c[2113158]=0;c[2415198]=0;X=c[2427044]|0;c[9681616+(X<<3)>>2]=809272;c[9681620+(X<<3)>>2]=0;c[2427044]=X+1}c[3528554]=0;f43(R);X=c[3528554]|0;J=9731360+(X<<2)|0;Q=c[J>>2]|0;c[2113158]=Q;M=c[3527384]|0;T=c[2433592]|0;W=0;S=0;while(1){U=M+(S<<8)|0;c[T+(X*3148|0)+48+(S<<2)>>2]=U;c[T+(X*3148|0)+48+(S+256<<2)>>2]=U;c[T+(X*3148|0)+48+(S+512<<2)>>2]=U;U=W+1&65535;if((U&65535)>29){break}else{W=U;S=U&65535}}S=c[2443432]|0;c[T+(X*3148|0)+168>>2]=S;c[T+(X*3148|0)+1192>>2]=S;c[T+(X*3148|0)+2216>>2]=S;W=S+256|0;c[T+(X*3148|0)+172>>2]=W;c[T+(X*3148|0)+1196>>2]=W;c[T+(X*3148|0)+2220>>2]=W;W=c[2439948]|0;c[T+(X*3148|0)+176>>2]=W;c[T+(X*3148|0)+1200>>2]=W;c[T+(X*3148|0)+2224>>2]=W;S=W+256|0;c[T+(X*3148|0)+180>>2]=S;c[T+(X*3148|0)+1204>>2]=S;c[T+(X*3148|0)+2228>>2]=S;S=W+512|0;c[T+(X*3148|0)+184>>2]=S;c[T+(X*3148|0)+1208>>2]=S;c[T+(X*3148|0)+2232>>2]=S;S=W+768|0;c[T+(X*3148|0)+188>>2]=S;c[T+(X*3148|0)+1212>>2]=S;c[T+(X*3148|0)+2236>>2]=S;S=W+1024|0;c[T+(X*3148|0)+192>>2]=S;c[T+(X*3148|0)+1216>>2]=S;c[T+(X*3148|0)+2240>>2]=S;S=W+1280|0;c[T+(X*3148|0)+196>>2]=S;c[T+(X*3148|0)+1220>>2]=S;c[T+(X*3148|0)+2244>>2]=S;S=W+1536|0;c[T+(X*3148|0)+200>>2]=S;c[T+(X*3148|0)+1224>>2]=S;c[T+(X*3148|0)+2248>>2]=S;S=W+1792|0;c[T+(X*3148|0)+204>>2]=S;c[T+(X*3148|0)+1228>>2]=S;c[T+(X*3148|0)+2252>>2]=S;S=c[2439966]|0;c[T+(X*3148|0)+208>>2]=S;c[T+(X*3148|0)+1232>>2]=S;c[T+(X*3148|0)+2256>>2]=S;W=S+256|0;c[T+(X*3148|0)+212>>2]=W;c[T+(X*3148|0)+1236>>2]=W;c[T+(X*3148|0)+2260>>2]=W;W=S+512|0;c[T+(X*3148|0)+216>>2]=W;c[T+(X*3148|0)+1240>>2]=W;c[T+(X*3148|0)+2264>>2]=W;W=S+768|0;c[T+(X*3148|0)+220>>2]=W;c[T+(X*3148|0)+1244>>2]=W;c[T+(X*3148|0)+2268>>2]=W;W=S+1024|0;c[T+(X*3148|0)+224>>2]=W;c[T+(X*3148|0)+1248>>2]=W;c[T+(X*3148|0)+2272>>2]=W;W=S+1280|0;c[T+(X*3148|0)+228>>2]=W;c[T+(X*3148|0)+1252>>2]=W;c[T+(X*3148|0)+2276>>2]=W;W=S+1536|0;c[T+(X*3148|0)+232>>2]=W;c[T+(X*3148|0)+1256>>2]=W;c[T+(X*3148|0)+2280>>2]=W;W=S+1792|0;c[T+(X*3148|0)+236>>2]=W;c[T+(X*3148|0)+1260>>2]=W;c[T+(X*3148|0)+2284>>2]=W;W=c[2438766]|0;c[T+(X*3148|0)+272>>2]=W;c[T+(X*3148|0)+1296>>2]=W;c[T+(X*3148|0)+2320>>2]=W;W=c[2438772]|0;c[T+(X*3148|0)+276>>2]=W;c[T+(X*3148|0)+1300>>2]=W;c[T+(X*3148|0)+2324>>2]=W;W=c[3527378]|0;S=64;M=64;while(1){R=W+((M<<8)-16384)|0;c[T+(X*3148|0)+48+(M<<2)>>2]=R;c[T+(X*3148|0)+48+(M+512<<2)>>2]=R;R=S+1&65535;if((R&65535)>95){ad=96;ae=96;break}else{S=R;M=R&65535}}while(1){M=W+((ae<<8)-16384)|0;c[T+(X*3148|0)+48+(ae<<2)>>2]=M;c[T+(X*3148|0)+48+(ae+512<<2)>>2]=M;M=ad+1&65535;if((M&65535)>255){break}else{ad=M;ae=M&65535}}c[T+(X*3148|0)+3120>>2]=220;c[T+(X*3148|0)+3124>>2]=1424;W=T+(X*3148|0)|0;if((W|0)!=0){M=W;gGC(M|0,9660752,48)|0}c[J>>2]=Q;c[3528554]=-1;fwR(0);M=c[2439330]|0;W=(M|0)==0;if(!W){S=M;gGC(9706056,S|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];S=c[3528484]|0;c[2076596]=S;R=c[2417276]|0;c[3541536]=R;c[1836236]=0;c[M+4180>>2]=1674;c[M+4184>>2]=1156;U=c[2385846]|0;$=0;Y=0;while(1){c[M+76+(Y<<2)>>2]=U+(Y<<8);V=$+1&65535;if((V&65535)>127){af=0;ah=0;break}else{$=V;Y=V&65535}}while(1){Y=U+(ah<<8)|0;c[M+76+(ah+512<<2)>>2]=Y;c[M+76+(ah+768<<2)>>2]=Y;Y=af+1&65535;if((Y&65535)>127){break}else{af=Y;ah=Y&65535}}U=c[2385864]|0;c[M+844>>2]=U;Y=U+256|0;c[M+848>>2]=Y;$=U+512|0;c[M+852>>2]=$;Q=U+768|0;c[M+856>>2]=Q;J=U+1024|0;c[M+860>>2]=J;X=U+1280|0;c[M+864>>2]=X;T=U+1536|0;c[M+868>>2]=T;V=U+1792|0;c[M+872>>2]=V;c[M+1868>>2]=U;c[M+1872>>2]=Y;c[M+1876>>2]=$;c[M+1880>>2]=Q;c[M+1884>>2]=J;c[M+1888>>2]=X;c[M+1892>>2]=T;c[M+1896>>2]=V;c[M+2892>>2]=U;c[M+3916>>2]=U;c[M+2896>>2]=Y;c[M+3920>>2]=Y;c[M+2900>>2]=$;c[M+3924>>2]=$;c[M+2904>>2]=Q;c[M+3928>>2]=Q;c[M+2908>>2]=J;c[M+3932>>2]=J;c[M+2912>>2]=X;c[M+3936>>2]=X;c[M+2916>>2]=T;c[M+3940>>2]=T;c[M+2920>>2]=V;c[M+3944>>2]=V;if(!W){V=M;gGC(V|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=S;c[2417276]=R;c[1836236]=-1;Vr(2,15e5,0,3530,42,0);c[2438228]=3e6;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=681;h[745419]=.2;a[3203368]=1;h[745418]=.4;a[3203360]=1;h[745417]=.4;a[3203352]=1;h[745416]=.4;a[3203344]=1;h[745415]=.2;a[3203336]=1;h[745414]=.4;a[3203328]=1;h[745413]=.4;a[3203320]=1;h[745412]=.4;a[3203312]=1;V=c[642608+(c[2436]<<2)>>2]|0;T=c[V+128>>2]|0;if((c[V+52>>2]&4|0)==0){c[2113068]=T;X=c[V+132>>2]|0;c[2113070]=X;c[2443814]=T;c[2440436]=X;ai=T;aj=X}else{c[2113070]=T;X=c[V+132>>2]|0;c[2113068]=X;c[2440436]=T;c[2443814]=X;ai=X;aj=T}T=ag(ai<<1,aj)|0;X=gGq(T)|0;c[2112926]=X;if((X|0)!=0){gGz(X|0,0,T|0)}a[(c[3527378]|0)+8192|0]=0;c[3528554]=0;f43(c[2433592]|0);T=c[3528554]|0;c[2113158]=c[9731360+(T<<2)>>2];a[9660796]=0;a[9660797]=0;a[9660786]=0;a[9660787]=0;c[2415191]=0;a[9660784]=a[9660784]|80;X=c[2433592]|0;V=c[X+(T*3148|0)+1068>>2]|0;do{if((V|0)==0){J=c[X+(T*3148|0)+3120>>2]|0;if((J|0)==0){ak=0;al=0;am=T;an=X;break}Q=gj[J&4095](-2)|0;J=c[3528554]|0;$=c[2433592]|0;Y=c[$+(J*3148|0)+1068>>2]|0;U=(Q&255)<<8;if((Y|0)!=0){ao=Y;ap=U;aq=J;ar=$;L=69539;break}Y=c[$+(J*3148|0)+3120>>2]|0;if((Y|0)==0){ak=0;al=U;am=J;an=$;break}$=gj[Y&4095](-1)|0;ak=$;al=U;am=c[3528554]|0;an=c[2433592]|0}else{ao=V;ap=(d[V+254|0]|0)<<8;aq=T;ar=X;L=69539}}while(0);if((L|0)==69539){ak=a[ao+255|0]|0;al=ap;am=aq;an=ar}X=ak&255|al;c[2415188]=X;b[4830376]=X&65535;X=an+(am*3148|0)|0;if((X|0)!=0){T=X;gGC(T|0,9660752,48)|0}c[9731360+(am<<2)>>2]=c[2113158];c[3528554]=-1;T=c[2439330]|0;X=(T|0)==0;if(!X){V=T;gGC(9706056,V|0,76)|0}V=c[2438118]|0;c[2433530]=V;R=c[3528484]|0;c[2076596]=R;S=c[2417276]|0;c[3541536]=S;c[1836236]=0;gGz(9706056,0,76);if(!X){X=T;gGC(X|0,9706056,76)|0}c[2438118]=V;c[3528484]=R;c[2417276]=S;c[1836236]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){S=0;do{lN(S);mB(S);S=S+1|0;}while((S|0)<(c[2385508]|0))}a[14119352]=0;a[9774425]=0;a[9774424]=0;a[9774377]=0;a[9774376]=0;a[9758240]=0;P=0;i=e;return P|0}}while(0);c[2426798]=0;P=1;i=e;return P|0}function dmr(a){a=a|0;return(ag((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0,a)|0)/3e6|0|0}function dms(){return+(+((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)/3.0e6)}function dmt(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=(d[9774425]|0)<<8&256|(d[9774424]|0);f=(d[9774377]|0)<<8&256|(d[9774376]|0);g=(b|0)==0;b=c[2439966]|0;h=c[2112926]|0;i=c[2405824]|0;j=0;do{k=(j<<4)-f|0;l=(k|0)<-16?k+512|0:k;k=l-16|0;m=(l-33|0)>>>0>190;l=0;do{n=(l<<5)+j|0;o=d[b+(n+1024)|0]|0;p=o<<2&768|(d[b+n|0]|0);n=o&7;do{if((o>>>3&1|0)==(a|0)){q=(l<<4)-e|0;r=(q|0)<-16?q+512|0:q;q=(r-17|0)>>>0>222|m;s=(o&16|0)==0;t=(o&32|0)!=0;if(g){if(q){if(s){if(t){SL(h,p,r,k,n,3,0,0,i);break}else{SH(h,p,r,k,n,3,0,0,i);break}}else{if(t){SN(h,p,r,k,n,3,0,0,i);break}else{SJ(h,p,r,k,n,3,0,0,i);break}}}else{if(s){if(t){SK(h,p,r,k,n,3,0,0,i);break}else{SG(h,p,r,k,n,3,0,0,i);break}}else{if(t){SM(h,p,r,k,n,3,0,0,i);break}else{SI(h,p,r,k,n,3,0,0,i);break}}}}else{if(q){if(s){if(t){SD(h,p,r,k,n,3,0,i);break}else{Sz(h,p,r,k,n,3,0,i);break}}else{if(t){SF(h,p,r,k,n,3,0,i);break}else{SB(h,p,r,k,n,3,0,i);break}}}else{if(s){if(t){SC(h,p,r,k,n,3,0,i);break}else{Sy(h,p,r,k,n,3,0,i);break}}else{if(t){SE(h,p,r,k,n,3,0,i);break}else{SA(h,p,r,k,n,3,0,i);break}}}}}}while(0);l=l+1|0;}while((l|0)<32);j=j+1|0;}while((j|0)<32);return}function dmu(b){b=b|0;var c=0,d=0;c=b&65535;if((c|0)==64768){d=~a[14107944]}else if((c|0)==64770){d=~a[14107945]}else if((c|0)==64774){d=a[9542928]|0}else if((c|0)==64776){d=a[9542929]|0}else{d=0}return d|0}function dmv(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;switch(d&65535|0){case 64776:{a[9753408]=e;return};case 64778:{a[9753416]=e;return};case 64768:{a[9732488]=e;d=c[1836236]|0;f=c[9757320+(d<<2)>>2]|0;if((f|0)!=0){g=f;gGC(g|0,9706056,76)|0}c[9752472+(d<<2)>>2]=c[2433530];c[14113936+(d<<2)>>2]=c[2076596];c[9669104+(d<<2)>>2]=c[3541536];c[1836236]=-1;d=c[2439332]|0;g=(d|0)==0;if(!g){f=d;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;f=c[2438120]|0;c[2433530]=f;h=c[3528486]|0;c[2076596]=h;i=c[2417278]|0;c[3541536]=i;c[1836236]=2;a[9706117]=1;if(!g){g=d;gGC(g|0,9706056,76)|0}c[2438120]=f;c[3528486]=h;c[2417278]=i;c[1836236]=-1;i=c[2439330]|0;if((i|0)!=0){h=i;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;return};case 64774:{a[9753432]=e;return};case 64772:{a[9753424]=e;return};case 64512:{h=(e&255)<<8;i=h&63488;f=c[2439352]|0;g=c[9757320+(c[1836236]<<2)>>2]|0;d=f+(i|65536)|0;c[g+1036>>2]=d;j=f+(i|65792)|0;c[g+1040>>2]=j;k=f+(i|66048)|0;c[g+1044>>2]=k;l=f+(i|66304)|0;c[g+1048>>2]=l;m=f+(i|66560)|0;c[g+1052>>2]=m;n=f+(i|66816)|0;c[g+1056>>2]=n;o=f+(i|67072)|0;c[g+1060>>2]=o;i=f+(h|67328)|0;c[g+1064>>2]=i;c[g+3084>>2]=d;c[g+4108>>2]=d;c[g+3088>>2]=j;c[g+4112>>2]=j;c[g+3092>>2]=k;c[g+4116>>2]=k;c[g+3096>>2]=l;c[g+4120>>2]=l;c[g+3100>>2]=m;c[g+4124>>2]=m;c[g+3104>>2]=n;c[g+4128>>2]=n;c[g+3108>>2]=o;c[g+4132>>2]=o;c[g+3112>>2]=i;c[g+4136>>2]=i;return};case 64782:{a[9747200]=e;return};default:{return}}}function dmw(a){a=a|0;return 0}function dmx(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if(a<<16>>16!=-1024){return}a=(b&255)<<8;b=a&63488;d=c[2439350]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=d+(b|65536)|0;c[e+1036>>2]=f;g=d+(b|65792)|0;c[e+1040>>2]=g;h=d+(b|66048)|0;c[e+1044>>2]=h;i=d+(b|66304)|0;c[e+1048>>2]=i;j=d+(b|66560)|0;c[e+1052>>2]=j;k=d+(b|66816)|0;c[e+1056>>2]=k;l=d+(b|67072)|0;c[e+1060>>2]=l;b=d+(a|67328)|0;c[e+1064>>2]=b;c[e+3084>>2]=f;c[e+4108>>2]=f;c[e+3088>>2]=g;c[e+4112>>2]=g;c[e+3092>>2]=h;c[e+4116>>2]=h;c[e+3096>>2]=i;c[e+4120>>2]=i;c[e+3100>>2]=j;c[e+4124>>2]=j;c[e+3104>>2]=k;c[e+4128>>2]=k;c[e+3108>>2]=l;c[e+4132>>2]=l;c[e+3112>>2]=b;c[e+4136>>2]=b;return}function dmy(b){b=b|0;var d=0,e=0,f=0.0,g=0.0,i=0;d=b&65535;if((d|0)==59392){b=c[3541518]|0;e=b+296|0;f=+h[e>>3];do{if(f!=0.0){g=+h[6675];if(f-(g+ +gC[c[2429842]&255]())<=0.0){h[e>>3]=0.0;break}i=a[b+307|0]|-128;return i|0}}while(0);i=a[b+307|0]|0;return i|0}else if((d|0)==63488){a[9706117]=0;i=a[9732488]|0;return i|0}else{i=0;return i|0}return 0}function dmz(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=b&65535;if((e|0)==58368){c[2430798]=d&255;return}else if((e|0)==59392){b=c[3541518]|0;f=b+256|0;a[b+304|0]=d;g=d&255;if((d&255)<16){c[14168912+((c[2383582]|0)*252|0)>>2]=g&15}if((d-45&255)>=3){return}if((g|0)==46){h=b+312|0;i=a[h]|1;a[h]=i;j=i}else if((g|0)==45){i=b+312|0;h=a[i]|2;a[i]=h;j=h}else if((g|0)==0){a[b+312|0]=2;j=2}else if((g|0)==47){a[b+312|0]=0;j=0}else{j=a[b+312|0]|0}b=j&3;j=c[7461744+(b<<2)>>2]|0;lI(f,j,j,c[7461728+(b<<2)>>2]|0);return}else if((e|0)==57344){b=d&255;j=c[2439348]|0;f=c[9757320+(c[1836236]<<2)>>2]|0;g=(b<<14&16384|32768)-32768|0;h=128;i=128;while(1){c[f+76+(i<<2)>>2]=j+(g+(i<<8));k=h+1&65535;if((k&65535)>191){l=128;m=128;break}else{h=k;i=k&65535}}while(1){i=j+(g+(m<<8))|0;c[f+76+(m+512<<2)>>2]=i;c[f+76+(m+768<<2)>>2]=i;i=l+1&65535;if((i&65535)>191){break}else{l=i;m=i&65535}}c[2415126]=9662152;c[2415540]=b&8;return}else if((e|0)==59393){lS(0,1,d);return}else{return}}function dmA(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>25){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6000156+(b*112|0)>>2];c[a+104>>2]=c[6000160+(b*112|0)>>2];c[a+108>>2]=c[6000164+(b*112|0)>>2];d=0;return d|0}function dmB(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<26&(d|0)==0)){e=1;return e|0}c[a>>2]=6000056+(b*112|0);e=0;return e|0}function dmC(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3249192+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dmD(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>46){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6002968+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dmE(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0;e=i;i=i+2520|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;B=e+1200|0;C=e+1312|0;D=e+1320|0;E=e+1432|0;F=e+1440|0;G=e+1552|0;H=e+1560|0;I=e+1672|0;J=e+1680|0;K=e+1792|0;L=e+1800|0;M=e+1912|0;N=e+1920|0;O=e+2032|0;P=e+2040|0;Q=e+2152|0;R=e+2160|0;S=e+2272|0;T=e+2280|0;U=e+2392|0;V=e+2400|0;W=e+2512|0;c[2426796]=0;c[2439352]=0;c[2439350]=131072;c[2439348]=262144;c[2405704]=327680;c[2439358]=327680;c[2439356]=344064;c[2439354]=350208;c[2433130]=352256;c[2433132]=356352;c[2430044]=360448;c[2436796]=364544;c[2433124]=366592;c[2436798]=368640;c[2411796]=369664;c[2436802]=369664;c[3526982]=500736;c[2439362]=1549312;c[2439364]=2597888;X=0;while(1){if((X|0)>=1024){break}Y=9638528+(X<<2)|0;if((c[Y>>2]|0)==0){Z=69754;break}else{X=X+1|0}}do{if((Z|0)==69754){X=gGq(2601984)|0;c[Y>>2]=X;if((X|0)==0){break}c[2426796]=X;gGz(X|0,0,2601984);c[2439352]=X;c[2439350]=X+131072;c[2439348]=X+262144;_=X+327680|0;c[2405704]=_;c[2439358]=_;c[2439356]=X+344064;c[2439354]=X+350208;c[2433130]=X+352256;c[2433132]=X+356352;c[2430044]=X+360448;c[2436796]=X+364544;c[2433124]=X+366592;c[2436798]=X+368640;_=X+369664|0;c[2411796]=_;c[2436802]=_;c[3526982]=X+500736;c[2439362]=X+1549312;c[2439364]=X+2597888;c[2414344]=X+2601984;X=0;while(1){if((X|0)>=1024){break}$=9638528+(X<<2)|0;if((c[$>>2]|0)==0){Z=69759;break}else{X=X+1|0}}do{if((Z|0)==69759){X=gGq(524288)|0;c[$>>2]=X;if((X|0)==0){break}gGz(X|0,0,524288);c[2439360]=X;X=c[2439352]|0;if((c[3542200]|0)==0){aa=1;i=e;return aa|0}_=V+108|0;c[_>>2]=0;ab=V+100|0;c[ab>>2]=0;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ac&16383](V,0)|0;do{if((c[_>>2]|0)!=0){ac=c[ab>>2]|0;c[W>>2]=9534384;ad=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ad&16383](W,0,0)|0;if((ac|0)<1){aa=1;i=e;return aa|0}if((gzL(X,0,0)|0)==0){break}else{aa=1}i=e;return aa|0}}while(0);X=(c[2439352]|0)+65536|0;if((c[3542200]|0)==0){aa=1;i=e;return aa|0}ab=T+108|0;c[ab>>2]=0;_=T+100|0;c[_>>2]=0;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ac&16383](T,1)|0;do{if((c[ab>>2]|0)!=0){ac=c[_>>2]|0;c[U>>2]=9534384;ad=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ad&16383](U,1,0)|0;if((ac|0)<1){aa=1;i=e;return aa|0}if((gzL(X,0,1)|0)==0){break}else{aa=1}i=e;return aa|0}}while(0);X=c[2439350]|0;if((c[3542200]|0)==0){aa=1;i=e;return aa|0}_=R+108|0;c[_>>2]=0;ab=R+100|0;c[ab>>2]=0;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ac&16383](R,2)|0;do{if((c[_>>2]|0)!=0){ac=c[ab>>2]|0;c[S>>2]=9534384;ad=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ad&16383](S,2,0)|0;if((ac|0)<1){aa=1;i=e;return aa|0}if((gzL(X,0,2)|0)==0){break}else{aa=1}i=e;return aa|0}}while(0);X=(c[2439350]|0)+65536|0;if((c[3542200]|0)==0){aa=1;i=e;return aa|0}ab=P+108|0;c[ab>>2]=0;_=P+100|0;c[_>>2]=0;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ac&16383](P,3)|0;do{if((c[ab>>2]|0)!=0){ac=c[_>>2]|0;c[Q>>2]=9534384;ad=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ad&16383](Q,3,0)|0;if((ac|0)<1){aa=1;i=e;return aa|0}if((gzL(X,0,3)|0)==0){break}else{aa=1}i=e;return aa|0}}while(0);X=c[2439348]|0;if((c[3542200]|0)==0){aa=1;i=e;return aa|0}_=N+108|0;c[_>>2]=0;ab=N+100|0;c[ab>>2]=0;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ac&16383](N,4)|0;do{if((c[_>>2]|0)!=0){ac=c[ab>>2]|0;c[O>>2]=9534384;ad=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ad&16383](O,4,0)|0;if((ac|0)<1){aa=1;i=e;return aa|0}if((gzL(X,0,4)|0)==0){break}else{aa=1}i=e;return aa|0}}while(0);X=c[2439360]|0;gGz(X|0,0,524288);if((c[3542200]|0)==0){aa=1;i=e;return aa|0}ab=L+108|0;c[ab>>2]=0;_=L+100|0;c[_>>2]=0;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ac&16383](L,5)|0;do{if((c[ab>>2]|0)!=0){ac=c[_>>2]|0;c[M>>2]=9534384;ad=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ad&16383](M,5,0)|0;if((ac|0)<1){aa=1;i=e;return aa|0}if((gzL(X,0,5)|0)==0){break}else{aa=1}i=e;return aa|0}}while(0);X=(c[2439360]|0)+16384|0;if((c[3542200]|0)==0){aa=1;i=e;return aa|0}_=J+108|0;c[_>>2]=0;ab=J+100|0;c[ab>>2]=0;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ac&16383](J,6)|0;do{if((c[_>>2]|0)!=0){ac=c[ab>>2]|0;c[K>>2]=9534384;ad=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ad&16383](K,6,0)|0;if((ac|0)<1){aa=1;i=e;return aa|0}if((gzL(X,0,6)|0)==0){break}else{aa=1}i=e;return aa|0}}while(0);X=(c[2439360]|0)+32768|0;if((c[3542200]|0)==0){aa=1;i=e;return aa|0}ab=H+108|0;c[ab>>2]=0;_=H+100|0;c[_>>2]=0;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ac&16383](H,7)|0;do{if((c[ab>>2]|0)!=0){ac=c[_>>2]|0;c[I>>2]=9534384;ad=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ad&16383](I,7,0)|0;if((ac|0)<1){aa=1;i=e;return aa|0}if((gzL(X,0,7)|0)==0){break}else{aa=1}i=e;return aa|0}}while(0);X=(c[2439360]|0)+49152|0;if((c[3542200]|0)==0){aa=1;i=e;return aa|0}_=F+108|0;c[_>>2]=0;ab=F+100|0;c[ab>>2]=0;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ac&16383](F,8)|0;do{if((c[_>>2]|0)!=0){ac=c[ab>>2]|0;c[G>>2]=9534384;ad=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ad&16383](G,8,0)|0;if((ac|0)<1){aa=1;i=e;return aa|0}if((gzL(X,0,8)|0)==0){break}else{aa=1}i=e;return aa|0}}while(0);X=c[2439360]|0;ab=c[2436802]|0;_=0;do{ac=_<<6;gGz(ab+ac|0,0,64);ad=0;do{ae=1<<3-ad;af=(c[961488+(ad<<2)>>2]|0)+ac|0;ah=0;do{ai=af+(c[1238464+(ah<<2)>>2]|0)|0;aj=(ah<<3)+ac|0;ak=0;do{al=ai+(c[614800+(ak<<2)>>2]|0)|0;if(((d[X+((al|0)/8|0)|0]|0)&128>>>((al&7)>>>0)|0)!=0){al=ab+(aj+ak)|0;a[al]=(d[al]|0|ae)&255}ak=ak+1|0;}while((ak|0)<8);ah=ah+1|0;}while((ah|0)<8);ad=ad+1|0;}while((ad|0)<4);_=_+1|0;}while((_|0)<2048);gGz(X|0,0,524288);if((c[3542200]|0)==0){aa=1;i=e;return aa|0}_=D+108|0;c[_>>2]=0;ab=D+100|0;c[ab>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](D,9)|0;do{if((c[_>>2]|0)!=0){ad=c[ab>>2]|0;c[E>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](E,9,0)|0;if((ad|0)<1){aa=1;i=e;return aa|0}if((gzL(X,0,9)|0)==0){break}else{aa=1}i=e;return aa|0}}while(0);X=(c[2439360]|0)+131072|0;if((c[3542200]|0)==0){aa=1;i=e;return aa|0}ab=B+108|0;c[ab>>2]=0;_=B+100|0;c[_>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](B,10)|0;do{if((c[ab>>2]|0)!=0){ad=c[_>>2]|0;c[C>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](C,10,0)|0;if((ad|0)<1){aa=1;i=e;return aa|0}if((gzL(X,0,10)|0)==0){break}else{aa=1}i=e;return aa|0}}while(0);X=(c[2439360]|0)+262144|0;if((c[3542200]|0)==0){aa=1;i=e;return aa|0}_=z+108|0;c[_>>2]=0;ab=z+100|0;c[ab>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,11)|0;do{if((c[_>>2]|0)!=0){ad=c[ab>>2]|0;c[A>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](A,11,0)|0;if((ad|0)<1){aa=1;i=e;return aa|0}if((gzL(X,0,11)|0)==0){break}else{aa=1}i=e;return aa|0}}while(0);X=(c[2439360]|0)+393216|0;if((c[3542200]|0)==0){aa=1;i=e;return aa|0}ab=x+108|0;c[ab>>2]=0;_=x+100|0;c[_>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,12)|0;do{if((c[ab>>2]|0)!=0){ad=c[_>>2]|0;c[y>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](y,12,0)|0;if((ad|0)<1){aa=1;i=e;return aa|0}if((gzL(X,0,12)|0)==0){break}else{aa=1}i=e;return aa|0}}while(0);X=c[2439360]|0;_=c[3526982]|0;ab=0;while(1){ad=ab<<8;gGz(_+ad|0,0,256);ac=ab<<6;ah=0;do{ae=1<<3-ah;af=(c[961520+(ah<<2)>>2]|0)+ac|0;ak=0;do{aj=af+(c[6669256+(ak<<2)>>2]|0)|0;ai=(ak<<4)+ad|0;al=0;do{am=aj+(c[610256+(al<<2)>>2]|0)|0;if(((d[X+((am|0)/8|0)|0]|0)&128>>>((am&7)>>>0)|0)!=0){am=_+(ai+al)|0;a[am]=(d[am]|0|ae)&255}al=al+1|0;}while((al|0)<16);ak=ak+1|0;}while((ak|0)<16);ah=ah+1|0;}while((ah|0)<4);ah=ab+1|0;if((ah|0)<256){ab=ah}else{an=0;break}}while(1){ab=(an<<8)+65536|0;gGz(_+ab|0,0,256);ah=an<<6;ad=0;do{ac=1<<3-ad;ak=(c[961520+(ad<<2)>>2]|0)+ah|0;ae=0;do{af=ak+(c[6669256+(ae<<2)>>2]|0)|0;al=ab+(ae<<4)|0;ai=0;do{aj=af+(c[610256+(ai<<2)>>2]|0)|0;if(((d[X+(((aj|0)/8|0)+8192)|0]|0)&128>>>((aj&7)>>>0)|0)!=0){aj=_+(al+ai)|0;a[aj]=(d[aj]|0|ac)&255}ai=ai+1|0;}while((ai|0)<16);ae=ae+1|0;}while((ae|0)<16);ad=ad+1|0;}while((ad|0)<4);ad=an+1|0;if((ad|0)<256){an=ad}else{ao=0;break}}while(1){ad=(ao<<8)+131072|0;gGz(_+ad|0,0,256);ab=ao<<6;ah=0;do{ae=1<<3-ah;ac=(c[961520+(ah<<2)>>2]|0)+ab|0;ak=0;do{ai=ac+(c[6669256+(ak<<2)>>2]|0)|0;al=ad+(ak<<4)|0;af=0;do{aj=ai+(c[610256+(af<<2)>>2]|0)|0;if(((d[X+(((aj|0)/8|0)+16384)|0]|0)&128>>>((aj&7)>>>0)|0)!=0){aj=_+(al+af)|0;a[aj]=(d[aj]|0|ae)&255}af=af+1|0;}while((af|0)<16);ak=ak+1|0;}while((ak|0)<16);ah=ah+1|0;}while((ah|0)<4);ah=ao+1|0;if((ah|0)<256){ao=ah}else{ap=0;break}}while(1){ah=(ap<<8)+196608|0;gGz(_+ah|0,0,256);ad=ap<<6;ab=0;do{ak=1<<3-ab;ae=(c[961520+(ab<<2)>>2]|0)+ad|0;ac=0;do{af=ae+(c[6669256+(ac<<2)>>2]|0)|0;al=ah+(ac<<4)|0;ai=0;do{aj=af+(c[610256+(ai<<2)>>2]|0)|0;if(((d[X+(((aj|0)/8|0)+24576)|0]|0)&128>>>((aj&7)>>>0)|0)!=0){aj=_+(al+ai)|0;a[aj]=(d[aj]|0|ak)&255}ai=ai+1|0;}while((ai|0)<16);ac=ac+1|0;}while((ac|0)<16);ab=ab+1|0;}while((ab|0)<4);ab=ap+1|0;if((ab|0)<256){ap=ab}else{aq=0;break}}while(1){ab=(aq<<8)+262144|0;gGz(_+ab|0,0,256);ah=aq<<6;ad=0;do{ac=1<<3-ad;ak=(c[961520+(ad<<2)>>2]|0)+ah|0;ae=0;do{ai=ak+(c[6669256+(ae<<2)>>2]|0)|0;al=ab+(ae<<4)|0;af=0;do{aj=ai+(c[610256+(af<<2)>>2]|0)|0;if(((d[X+(((aj|0)/8|0)+32768)|0]|0)&128>>>((aj&7)>>>0)|0)!=0){aj=_+(al+af)|0;a[aj]=(d[aj]|0|ac)&255}af=af+1|0;}while((af|0)<16);ae=ae+1|0;}while((ae|0)<16);ad=ad+1|0;}while((ad|0)<4);ad=aq+1|0;if((ad|0)<256){aq=ad}else{ar=0;break}}while(1){ad=(ar<<8)+327680|0;gGz(_+ad|0,0,256);ab=ar<<6;ah=0;do{ae=1<<3-ah;ac=(c[961520+(ah<<2)>>2]|0)+ab|0;ak=0;do{af=ac+(c[6669256+(ak<<2)>>2]|0)|0;al=ad+(ak<<4)|0;ai=0;do{aj=af+(c[610256+(ai<<2)>>2]|0)|0;if(((d[X+(((aj|0)/8|0)+40960)|0]|0)&128>>>((aj&7)>>>0)|0)!=0){aj=_+(al+ai)|0;a[aj]=(d[aj]|0|ae)&255}ai=ai+1|0;}while((ai|0)<16);ak=ak+1|0;}while((ak|0)<16);ah=ah+1|0;}while((ah|0)<4);ah=ar+1|0;if((ah|0)<256){ar=ah}else{as=0;break}}while(1){ah=(as<<8)+393216|0;gGz(_+ah|0,0,256);ad=as<<6;ab=0;do{ak=1<<3-ab;ae=(c[961520+(ab<<2)>>2]|0)+ad|0;ac=0;do{ai=ae+(c[6669256+(ac<<2)>>2]|0)|0;al=ah+(ac<<4)|0;af=0;do{aj=ai+(c[610256+(af<<2)>>2]|0)|0;if(((d[X+(((aj|0)/8|0)+49152)|0]|0)&128>>>((aj&7)>>>0)|0)!=0){aj=_+(al+af)|0;a[aj]=(d[aj]|0|ak)&255}af=af+1|0;}while((af|0)<16);ac=ac+1|0;}while((ac|0)<16);ab=ab+1|0;}while((ab|0)<4);ab=as+1|0;if((ab|0)<256){as=ab}else{at=0;break}}while(1){ab=(at<<8)+458752|0;gGz(_+ab|0,0,256);ah=at<<6;ad=0;do{ac=1<<3-ad;ak=(c[961520+(ad<<2)>>2]|0)+ah|0;ae=0;do{af=ak+(c[6669256+(ae<<2)>>2]|0)|0;al=ab+(ae<<4)|0;ai=0;do{aj=af+(c[610256+(ai<<2)>>2]|0)|0;if(((d[X+(((aj|0)/8|0)+57344)|0]|0)&128>>>((aj&7)>>>0)|0)!=0){aj=_+(al+ai)|0;a[aj]=(d[aj]|0|ac)&255}ai=ai+1|0;}while((ai|0)<16);ae=ae+1|0;}while((ae|0)<16);ad=ad+1|0;}while((ad|0)<4);ad=at+1|0;if((ad|0)<256){at=ad}else{au=0;break}}while(1){ad=(au<<8)+524288|0;gGz(_+ad|0,0,256);ab=au<<6;ah=0;do{ae=1<<3-ah;ac=(c[961520+(ah<<2)>>2]|0)+ab|0;ak=0;do{ai=ac+(c[6669256+(ak<<2)>>2]|0)|0;al=ad+(ak<<4)|0;af=0;do{aj=ai+(c[610256+(af<<2)>>2]|0)|0;if(((d[X+(((aj|0)/8|0)+65536)|0]|0)&128>>>((aj&7)>>>0)|0)!=0){aj=_+(al+af)|0;a[aj]=(d[aj]|0|ae)&255}af=af+1|0;}while((af|0)<16);ak=ak+1|0;}while((ak|0)<16);ah=ah+1|0;}while((ah|0)<4);ah=au+1|0;if((ah|0)<256){au=ah}else{av=0;break}}while(1){ah=(av<<8)+589824|0;gGz(_+ah|0,0,256);ad=av<<6;ab=0;do{ak=1<<3-ab;ae=(c[961520+(ab<<2)>>2]|0)+ad|0;ac=0;do{af=ae+(c[6669256+(ac<<2)>>2]|0)|0;al=ah+(ac<<4)|0;ai=0;do{aj=af+(c[610256+(ai<<2)>>2]|0)|0;if(((d[X+(((aj|0)/8|0)+73728)|0]|0)&128>>>((aj&7)>>>0)|0)!=0){aj=_+(al+ai)|0;a[aj]=(d[aj]|0|ak)&255}ai=ai+1|0;}while((ai|0)<16);ac=ac+1|0;}while((ac|0)<16);ab=ab+1|0;}while((ab|0)<4);ab=av+1|0;if((ab|0)<256){av=ab}else{aw=0;break}}while(1){ab=(aw<<8)+655360|0;gGz(_+ab|0,0,256);ah=aw<<6;ad=0;do{ac=1<<3-ad;ak=(c[961520+(ad<<2)>>2]|0)+ah|0;ae=0;do{ai=ak+(c[6669256+(ae<<2)>>2]|0)|0;al=ab+(ae<<4)|0;af=0;do{aj=ai+(c[610256+(af<<2)>>2]|0)|0;if(((d[X+(((aj|0)/8|0)+81920)|0]|0)&128>>>((aj&7)>>>0)|0)!=0){aj=_+(al+af)|0;a[aj]=(d[aj]|0|ac)&255}af=af+1|0;}while((af|0)<16);ae=ae+1|0;}while((ae|0)<16);ad=ad+1|0;}while((ad|0)<4);ad=aw+1|0;if((ad|0)<256){aw=ad}else{ax=0;break}}while(1){ad=(ax<<8)+720896|0;gGz(_+ad|0,0,256);ab=ax<<6;ah=0;do{ae=1<<3-ah;ac=(c[961520+(ah<<2)>>2]|0)+ab|0;ak=0;do{af=ac+(c[6669256+(ak<<2)>>2]|0)|0;al=ad+(ak<<4)|0;ai=0;do{aj=af+(c[610256+(ai<<2)>>2]|0)|0;if(((d[X+(((aj|0)/8|0)+90112)|0]|0)&128>>>((aj&7)>>>0)|0)!=0){aj=_+(al+ai)|0;a[aj]=(d[aj]|0|ae)&255}ai=ai+1|0;}while((ai|0)<16);ak=ak+1|0;}while((ak|0)<16);ah=ah+1|0;}while((ah|0)<4);ah=ax+1|0;if((ah|0)<256){ax=ah}else{ay=0;break}}while(1){ah=(ay<<8)+786432|0;gGz(_+ah|0,0,256);ad=ay<<6;ab=0;do{ak=1<<3-ab;ae=(c[961520+(ab<<2)>>2]|0)+ad|0;ac=0;do{ai=ae+(c[6669256+(ac<<2)>>2]|0)|0;al=ah+(ac<<4)|0;af=0;do{aj=ai+(c[610256+(af<<2)>>2]|0)|0;if(((d[X+(((aj|0)/8|0)+98304)|0]|0)&128>>>((aj&7)>>>0)|0)!=0){aj=_+(al+af)|0;a[aj]=(d[aj]|0|ak)&255}af=af+1|0;}while((af|0)<16);ac=ac+1|0;}while((ac|0)<16);ab=ab+1|0;}while((ab|0)<4);ab=ay+1|0;if((ab|0)<256){ay=ab}else{az=0;break}}while(1){ab=(az<<8)+851968|0;gGz(_+ab|0,0,256);ah=az<<6;ad=0;do{ac=1<<3-ad;ak=(c[961520+(ad<<2)>>2]|0)+ah|0;ae=0;do{af=ak+(c[6669256+(ae<<2)>>2]|0)|0;al=ab+(ae<<4)|0;ai=0;do{aj=af+(c[610256+(ai<<2)>>2]|0)|0;if(((d[X+(((aj|0)/8|0)+106496)|0]|0)&128>>>((aj&7)>>>0)|0)!=0){aj=_+(al+ai)|0;a[aj]=(d[aj]|0|ac)&255}ai=ai+1|0;}while((ai|0)<16);ae=ae+1|0;}while((ae|0)<16);ad=ad+1|0;}while((ad|0)<4);ad=az+1|0;if((ad|0)<256){az=ad}else{aA=0;break}}while(1){ad=(aA<<8)+917504|0;gGz(_+ad|0,0,256);ab=aA<<6;ah=0;do{ae=1<<3-ah;ac=(c[961520+(ah<<2)>>2]|0)+ab|0;ak=0;do{ai=ac+(c[6669256+(ak<<2)>>2]|0)|0;al=ad+(ak<<4)|0;af=0;do{aj=ai+(c[610256+(af<<2)>>2]|0)|0;if(((d[X+(((aj|0)/8|0)+114688)|0]|0)&128>>>((aj&7)>>>0)|0)!=0){aj=_+(al+af)|0;a[aj]=(d[aj]|0|ae)&255}af=af+1|0;}while((af|0)<16);ak=ak+1|0;}while((ak|0)<16);ah=ah+1|0;}while((ah|0)<4);ah=aA+1|0;if((ah|0)<256){aA=ah}else{aB=0;break}}do{ah=(aB<<8)+983040|0;gGz(_+ah|0,0,256);ad=aB<<6;ab=0;do{ak=1<<3-ab;ae=(c[961520+(ab<<2)>>2]|0)+ad|0;ac=0;do{af=ae+(c[6669256+(ac<<2)>>2]|0)|0;al=ah+(ac<<4)|0;ai=0;do{aj=af+(c[610256+(ai<<2)>>2]|0)|0;if(((d[X+(((aj|0)/8|0)+122880)|0]|0)&128>>>((aj&7)>>>0)|0)!=0){aj=_+(al+ai)|0;a[aj]=(d[aj]|0|ak)&255}ai=ai+1|0;}while((ai|0)<16);ac=ac+1|0;}while((ac|0)<16);ab=ab+1|0;}while((ab|0)<4);aB=aB+1|0;}while((aB|0)<256);gGz(X|0,0,524288);if((c[3542200]|0)==0){aa=1;i=e;return aa|0}_=v+108|0;c[_>>2]=0;ab=v+100|0;c[ab>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,13)|0;do{if((c[_>>2]|0)!=0){ah=c[ab>>2]|0;c[w>>2]=9534384;ad=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ad&16383](w,13,0)|0;if((ah|0)<1){aa=1;i=e;return aa|0}if((gzL(X,0,13)|0)==0){break}else{aa=1}i=e;return aa|0}}while(0);X=(c[2439360]|0)+65536|0;if((c[3542200]|0)==0){aa=1;i=e;return aa|0}ab=t+108|0;c[ab>>2]=0;_=t+100|0;c[_>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,14)|0;do{if((c[ab>>2]|0)!=0){ah=c[_>>2]|0;c[u>>2]=9534384;ad=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ad&16383](u,14,0)|0;if((ah|0)<1){aa=1;i=e;return aa|0}if((gzL(X,0,14)|0)==0){break}else{aa=1}i=e;return aa|0}}while(0);X=(c[2439360]|0)+131072|0;if((c[3542200]|0)==0){aa=1;i=e;return aa|0}_=r+108|0;c[_>>2]=0;ab=r+100|0;c[ab>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,15)|0;do{if((c[_>>2]|0)!=0){ah=c[ab>>2]|0;c[s>>2]=9534384;ad=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ad&16383](s,15,0)|0;if((ah|0)<1){aa=1;i=e;return aa|0}if((gzL(X,0,15)|0)==0){break}else{aa=1}i=e;return aa|0}}while(0);X=(c[2439360]|0)+196608|0;if((c[3542200]|0)==0){aa=1;i=e;return aa|0}ab=p+108|0;c[ab>>2]=0;_=p+100|0;c[_>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,16)|0;do{if((c[ab>>2]|0)!=0){ah=c[_>>2]|0;c[q>>2]=9534384;ad=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ad&16383](q,16,0)|0;if((ah|0)<1){aa=1;i=e;return aa|0}if((gzL(X,0,16)|0)==0){break}else{aa=1}i=e;return aa|0}}while(0);X=(c[2439360]|0)+262144|0;if((c[3542200]|0)==0){aa=1;i=e;return aa|0}_=n+108|0;c[_>>2]=0;ab=n+100|0;c[ab>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,17)|0;do{if((c[_>>2]|0)!=0){ah=c[ab>>2]|0;c[o>>2]=9534384;ad=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ad&16383](o,17,0)|0;if((ah|0)<1){aa=1;i=e;return aa|0}if((gzL(X,0,17)|0)==0){break}else{aa=1}i=e;return aa|0}}while(0);X=(c[2439360]|0)+327680|0;if((c[3542200]|0)==0){aa=1;i=e;return aa|0}ab=l+108|0;c[ab>>2]=0;_=l+100|0;c[_>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,18)|0;do{if((c[ab>>2]|0)!=0){ah=c[_>>2]|0;c[m>>2]=9534384;ad=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ad&16383](m,18,0)|0;if((ah|0)<1){aa=1;i=e;return aa|0}if((gzL(X,0,18)|0)==0){break}else{aa=1}i=e;return aa|0}}while(0);X=(c[2439360]|0)+393216|0;if((c[3542200]|0)==0){aa=1;i=e;return aa|0}_=j+108|0;c[_>>2]=0;ab=j+100|0;c[ab>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,19)|0;do{if((c[_>>2]|0)!=0){ah=c[ab>>2]|0;c[k>>2]=9534384;ad=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ad&16383](k,19,0)|0;if((ah|0)<1){aa=1;i=e;return aa|0}if((gzL(X,0,19)|0)==0){break}else{aa=1}i=e;return aa|0}}while(0);X=(c[2439360]|0)+458752|0;if((c[3542200]|0)==0){aa=1;i=e;return aa|0}ab=f+108|0;c[ab>>2]=0;_=f+100|0;c[_>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,20)|0;do{if((c[ab>>2]|0)!=0){ah=c[_>>2]|0;c[g>>2]=9534384;ad=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ad&16383](g,20,0)|0;if((ah|0)<1){aa=1;i=e;return aa|0}if((gzL(X,0,20)|0)==0){break}else{aa=1}i=e;return aa|0}}while(0);X=c[2439360]|0;_=0;do{ab=X+_|0;a[ab]=~a[ab];_=_+1|0;}while((_|0)<524288);_=c[2439362]|0;ab=0;while(1){ah=ab<<8;gGz(_+ah|0,0,256);ad=0;do{ac=1<<3-ad;ak=(c[704200+(ad<<2)>>2]|0)+ah|0;ae=0;do{ai=ak+(c[609008+(ae<<2)>>2]|0)|0;al=(ae<<4)+ah|0;af=0;do{aj=ai+(c[597864+(af<<2)>>2]|0)|0;if(((d[X+((aj|0)/8|0)|0]|0)&128>>>((aj&7)>>>0)|0)!=0){aj=_+(al+af)|0;a[aj]=(d[aj]|0|ac)&255}af=af+1|0;}while((af|0)<16);ae=ae+1|0;}while((ae|0)<16);ad=ad+1|0;}while((ad|0)<4);ad=ab+1|0;if((ad|0)<4096){ab=ad}else{aC=0;break}}while(1){if((aC|0)>=1024){break}aD=9638528+(aC<<2)|0;if((c[aD>>2]|0)==(X|0)){Z=70014;break}else{aC=aC+1|0}}if((Z|0)==70014){gGr(X);c[aD>>2]=0}c[2439360]=0;fwR(0);ab=c[2439330]|0;_=(ab|0)==0;if(!_){ad=ab;gGC(9706056,ad|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];ad=c[3528484]|0;c[2076596]=ad;ah=c[2417276]|0;c[3541536]=ah;c[1836236]=0;c[ab+4180>>2]=984;c[ab+4184>>2]=3298;ae=c[2439352]|0;ac=0;ak=0;while(1){c[ab+76+(ak<<2)>>2]=ae+(ak<<8);af=ac+1&65535;if((af&65535)>127){aE=0;aF=0;break}else{ac=af;ak=af&65535}}while(1){ak=ae+(aF<<8)|0;c[ab+76+(aF+512<<2)>>2]=ak;c[ab+76+(aF+768<<2)>>2]=ak;ak=aE+1&65535;if((ak&65535)>127){break}else{aE=ak;aF=ak&65535}}ak=c[2439358]|0;ac=128;X=128;while(1){c[ab+76+(X<<2)>>2]=ak+((X<<8)-32768);af=ac+1&65535;if((af&65535)>159){aG=128;aH=128;break}else{ac=af;X=af&65535}}while(1){c[ab+76+(aH+256<<2)>>2]=ak+((aH<<8)-32768);X=aG+1&65535;if((X&65535)>159){aI=128;aJ=128;break}else{aG=X;aH=X&65535}}while(1){X=ak+((aJ<<8)-32768)|0;c[ab+76+(aJ+512<<2)>>2]=X;c[ab+76+(aJ+768<<2)>>2]=X;X=aI+1&65535;if((X&65535)>159){break}else{aI=X;aJ=X&65535}}X=c[2433130]|0;c[ab+716>>2]=X;c[ab+720>>2]=X+256;c[ab+724>>2]=X+512;c[ab+728>>2]=X+768;c[ab+732>>2]=X+1024;c[ab+736>>2]=X+1280;c[ab+740>>2]=X+1536;c[ab+744>>2]=X+1792;c[ab+748>>2]=X+2048;c[ab+752>>2]=X+2304;c[ab+756>>2]=X+2560;c[ab+760>>2]=X+2816;c[ab+764>>2]=X+3072;c[ab+768>>2]=X+3328;c[ab+772>>2]=X+3584;c[ab+776>>2]=X+3840;ac=160;af=160;while(1){c[ab+76+(af+256<<2)>>2]=X+((af<<8)-40960);al=ac+1&65535;if((al&65535)>175){aK=160;aL=160;break}else{ac=al;af=al&65535}}while(1){af=X+((aL<<8)-40960)|0;c[ab+76+(aL+512<<2)>>2]=af;c[ab+76+(aL+768<<2)>>2]=af;af=aK+1&65535;if((af&65535)>175){break}else{aK=af;aL=af&65535}}X=c[2433132]|0;c[ab+844>>2]=X;c[ab+848>>2]=X+256;c[ab+852>>2]=X+512;c[ab+856>>2]=X+768;c[ab+860>>2]=X+1024;c[ab+864>>2]=X+1280;c[ab+868>>2]=X+1536;c[ab+872>>2]=X+1792;c[ab+876>>2]=X+2048;c[ab+880>>2]=X+2304;c[ab+884>>2]=X+2560;c[ab+888>>2]=X+2816;c[ab+892>>2]=X+3072;c[ab+896>>2]=X+3328;c[ab+900>>2]=X+3584;c[ab+904>>2]=X+3840;af=192;ac=192;while(1){c[ab+76+(ac+256<<2)>>2]=X+((ac<<8)-49152);al=af+1&65535;if((al&65535)>207){aM=192;aN=192;break}else{af=al;ac=al&65535}}while(1){ac=X+((aN<<8)-49152)|0;c[ab+76+(aN+512<<2)>>2]=ac;c[ab+76+(aN+768<<2)>>2]=ac;ac=aM+1&65535;if((ac&65535)>207){break}else{aM=ac;aN=ac&65535}}c[ab+908>>2]=ak+12288;c[ab+912>>2]=ak+12544;c[ab+916>>2]=ak+12800;c[ab+920>>2]=ak+13056;c[ab+924>>2]=ak+13312;c[ab+928>>2]=ak+13568;c[ab+932>>2]=ak+13824;c[ab+936>>2]=ak+14080;c[ab+940>>2]=ak+14336;c[ab+944>>2]=ak+14592;c[ab+948>>2]=ak+14848;c[ab+952>>2]=ak+15104;c[ab+956>>2]=ak+15360;c[ab+960>>2]=ak+15616;c[ab+964>>2]=ak+15872;c[ab+968>>2]=ak+16128;X=208;ac=208;while(1){c[ab+76+(ac+256<<2)>>2]=ak+((ac<<8)-40960);af=X+1&65535;if((af&65535)>223){aO=208;aP=208;break}else{X=af;ac=af&65535}}while(1){ac=ak+((aP<<8)-40960)|0;c[ab+76+(aP+512<<2)>>2]=ac;c[ab+76+(aP+768<<2)>>2]=ac;ac=aO+1&65535;if((ac&65535)>223){break}else{aO=ac;aP=ac&65535}}ak=c[2430044]|0;c[ab+972>>2]=ak;c[ab+976>>2]=ak+256;c[ab+980>>2]=ak+512;c[ab+984>>2]=ak+768;c[ab+988>>2]=ak+1024;c[ab+992>>2]=ak+1280;c[ab+996>>2]=ak+1536;c[ab+1e3>>2]=ak+1792;c[ab+1004>>2]=ak+2048;c[ab+1008>>2]=ak+2304;c[ab+1012>>2]=ak+2560;c[ab+1016>>2]=ak+2816;c[ab+1020>>2]=ak+3072;c[ab+1024>>2]=ak+3328;c[ab+1028>>2]=ak+3584;c[ab+1032>>2]=ak+3840;ac=224;X=224;while(1){c[ab+76+(X+256<<2)>>2]=ak+((X<<8)-57344);af=ac+1&65535;if((af&65535)>239){aQ=224;aR=224;break}else{ac=af;X=af&65535}}while(1){X=ak+((aR<<8)-57344)|0;c[ab+76+(aR+512<<2)>>2]=X;c[ab+76+(aR+768<<2)>>2]=X;X=aQ+1&65535;if((X&65535)>239){break}else{aQ=X;aR=X&65535}}ak=ae+65536|0;c[ab+1036>>2]=ak;X=ae+65792|0;c[ab+1040>>2]=X;ac=ae+66048|0;c[ab+1044>>2]=ac;af=ae+66304|0;c[ab+1048>>2]=af;al=ae+66560|0;c[ab+1052>>2]=al;ai=ae+66816|0;c[ab+1056>>2]=ai;aj=ae+67072|0;c[ab+1060>>2]=aj;am=ae+67328|0;c[ab+1064>>2]=am;c[ab+3084>>2]=ak;c[ab+4108>>2]=ak;c[ab+3088>>2]=X;c[ab+4112>>2]=X;c[ab+3092>>2]=ac;c[ab+4116>>2]=ac;c[ab+3096>>2]=af;c[ab+4120>>2]=af;c[ab+3100>>2]=al;c[ab+4124>>2]=al;c[ab+3104>>2]=ai;c[ab+4128>>2]=ai;c[ab+3108>>2]=aj;c[ab+4132>>2]=aj;c[ab+3112>>2]=am;c[ab+4136>>2]=am;am=c[2436798]|0;c[ab+1068>>2]=am;aj=am+256|0;c[ab+1072>>2]=aj;ai=am+512|0;c[ab+1076>>2]=ai;al=am+768|0;c[ab+1080>>2]=al;c[ab+2092>>2]=am;c[ab+2096>>2]=aj;c[ab+2100>>2]=ai;c[ab+2104>>2]=al;c[ab+3116>>2]=am;c[ab+4140>>2]=am;c[ab+3120>>2]=aj;c[ab+4144>>2]=aj;c[ab+3124>>2]=ai;c[ab+4148>>2]=ai;c[ab+3128>>2]=al;c[ab+4152>>2]=al;if(!_){al=ab;gGC(al|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=ad;c[2417276]=ah;c[1836236]=-1;fwR(1);al=c[2439331]|0;ai=(al|0)==0;if(!ai){aj=al;gGC(9706056,aj|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];aj=c[3528485]|0;c[2076596]=aj;am=c[2417277]|0;c[3541536]=am;c[1836236]=1;c[al+4180>>2]=2442;c[al+4184>>2]=2492;af=c[2439350]|0;ac=0;X=0;while(1){c[al+76+(X<<2)>>2]=af+(X<<8);ak=ac+1&65535;if((ak&65535)>191){aS=0;aT=0;break}else{ac=ak;X=ak&65535}}while(1){X=af+(aT<<8)|0;c[al+76+(aT+512<<2)>>2]=X;c[al+76+(aT+768<<2)>>2]=X;X=aS+1&65535;if((X&65535)>191){break}else{aS=X;aT=X&65535}}X=c[2439356]|0;c[al+844>>2]=X;c[al+848>>2]=X+256;c[al+852>>2]=X+512;c[al+856>>2]=X+768;c[al+860>>2]=X+1024;c[al+864>>2]=X+1280;c[al+868>>2]=X+1536;c[al+872>>2]=X+1792;c[al+876>>2]=X+2048;c[al+880>>2]=X+2304;c[al+884>>2]=X+2560;c[al+888>>2]=X+2816;c[al+892>>2]=X+3072;c[al+896>>2]=X+3328;c[al+900>>2]=X+3584;c[al+904>>2]=X+3840;ac=192;ah=192;while(1){c[al+76+(ah+256<<2)>>2]=X+((ah<<8)-49152);ad=ac+1&65535;if((ad&65535)>207){aU=192;aV=192;break}else{ac=ad;ah=ad&65535}}while(1){ah=X+((aV<<8)-49152)|0;c[al+76+(aV+512<<2)>>2]=ah;c[al+76+(aV+768<<2)>>2]=ah;ah=aU+1&65535;if((ah&65535)>207){break}else{aU=ah;aV=ah&65535}}ah=c[2436796]|0;c[al+908>>2]=ah;ac=ah+256|0;c[al+912>>2]=ac;ad=ah+512|0;c[al+916>>2]=ad;ab=ah+768|0;c[al+920>>2]=ab;_=ah+1024|0;c[al+924>>2]=_;ae=ah+1280|0;c[al+928>>2]=ae;ak=ah+1536|0;c[al+932>>2]=ak;aW=ah+1792|0;c[al+936>>2]=aW;c[al+1932>>2]=ah;c[al+1936>>2]=ac;c[al+1940>>2]=ad;c[al+1944>>2]=ab;c[al+1948>>2]=_;c[al+1952>>2]=ae;c[al+1956>>2]=ak;c[al+1960>>2]=aW;c[al+2956>>2]=ah;c[al+3980>>2]=ah;c[al+2960>>2]=ac;c[al+3984>>2]=ac;c[al+2964>>2]=ad;c[al+3988>>2]=ad;c[al+2968>>2]=ab;c[al+3992>>2]=ab;c[al+2972>>2]=_;c[al+3996>>2]=_;c[al+2976>>2]=ae;c[al+4e3>>2]=ae;c[al+2980>>2]=ak;c[al+4004>>2]=ak;c[al+2984>>2]=aW;c[al+4008>>2]=aW;aW=X+4096|0;c[al+940>>2]=aW;ak=X+4352|0;c[al+944>>2]=ak;ae=X+4608|0;c[al+948>>2]=ae;_=X+4864|0;c[al+952>>2]=_;ab=X+5120|0;c[al+956>>2]=ab;ad=X+5376|0;c[al+960>>2]=ad;ac=X+5632|0;c[al+964>>2]=ac;ah=X+5888|0;c[al+968>>2]=ah;c[al+1964>>2]=aW;c[al+1968>>2]=ak;c[al+1972>>2]=ae;c[al+1976>>2]=_;c[al+1980>>2]=ab;c[al+1984>>2]=ad;c[al+1988>>2]=ac;c[al+1992>>2]=ah;c[al+2988>>2]=aW;c[al+4012>>2]=aW;c[al+2992>>2]=ak;c[al+4016>>2]=ak;c[al+2996>>2]=ae;c[al+4020>>2]=ae;c[al+3e3>>2]=_;c[al+4024>>2]=_;c[al+3004>>2]=ab;c[al+4028>>2]=ab;c[al+3008>>2]=ad;c[al+4032>>2]=ad;c[al+3012>>2]=ac;c[al+4036>>2]=ac;c[al+3016>>2]=ah;c[al+4040>>2]=ah;ah=c[2433124]|0;c[al+972>>2]=ah;ac=ah+256|0;c[al+976>>2]=ac;ad=ah+512|0;c[al+980>>2]=ad;ab=ah+768|0;c[al+984>>2]=ab;_=ah+1024|0;c[al+988>>2]=_;ae=ah+1280|0;c[al+992>>2]=ae;ak=ah+1536|0;c[al+996>>2]=ak;aW=ah+1792|0;c[al+1e3>>2]=aW;c[al+1996>>2]=ah;c[al+2e3>>2]=ac;c[al+2004>>2]=ad;c[al+2008>>2]=ab;c[al+2012>>2]=_;c[al+2016>>2]=ae;c[al+2020>>2]=ak;c[al+2024>>2]=aW;c[al+3020>>2]=ah;c[al+4044>>2]=ah;c[al+3024>>2]=ac;c[al+4048>>2]=ac;c[al+3028>>2]=ad;c[al+4052>>2]=ad;c[al+3032>>2]=ab;c[al+4056>>2]=ab;c[al+3036>>2]=_;c[al+4060>>2]=_;c[al+3040>>2]=ae;c[al+4064>>2]=ae;c[al+3044>>2]=ak;c[al+4068>>2]=ak;c[al+3048>>2]=aW;c[al+4072>>2]=aW;aW=af+59392|0;c[al+1004>>2]=aW;ak=af+59648|0;c[al+1008>>2]=ak;ae=af+59904|0;c[al+1012>>2]=ae;_=af+60160|0;c[al+1016>>2]=_;ab=af+60416|0;c[al+1020>>2]=ab;ad=af+60672|0;c[al+1024>>2]=ad;ac=af+60928|0;c[al+1028>>2]=ac;ah=af+61184|0;c[al+1032>>2]=ah;c[al+3052>>2]=aW;c[al+4076>>2]=aW;c[al+3056>>2]=ak;c[al+4080>>2]=ak;c[al+3060>>2]=ae;c[al+4084>>2]=ae;c[al+3064>>2]=_;c[al+4088>>2]=_;c[al+3068>>2]=ab;c[al+4092>>2]=ab;c[al+3072>>2]=ad;c[al+4096>>2]=ad;c[al+3076>>2]=ac;c[al+4100>>2]=ac;c[al+3080>>2]=ah;c[al+4104>>2]=ah;ah=af+65536|0;c[al+1036>>2]=ah;ac=af+65792|0;c[al+1040>>2]=ac;ad=af+66048|0;c[al+1044>>2]=ad;ab=af+66304|0;c[al+1048>>2]=ab;_=af+66560|0;c[al+1052>>2]=_;ae=af+66816|0;c[al+1056>>2]=ae;ak=af+67072|0;c[al+1060>>2]=ak;aW=af+67328|0;c[al+1064>>2]=aW;c[al+3084>>2]=ah;c[al+4108>>2]=ah;c[al+3088>>2]=ac;c[al+4112>>2]=ac;c[al+3092>>2]=ad;c[al+4116>>2]=ad;c[al+3096>>2]=ab;c[al+4120>>2]=ab;c[al+3100>>2]=_;c[al+4124>>2]=_;c[al+3104>>2]=ae;c[al+4128>>2]=ae;c[al+3108>>2]=ak;c[al+4132>>2]=ak;c[al+3112>>2]=aW;c[al+4136>>2]=aW;aW=c[2436798]|0;c[al+1068>>2]=aW;ak=aW+256|0;c[al+1072>>2]=ak;ae=aW+512|0;c[al+1076>>2]=ae;_=aW+768|0;c[al+1080>>2]=_;c[al+2092>>2]=aW;c[al+2096>>2]=ak;c[al+2100>>2]=ae;c[al+2104>>2]=_;c[al+3116>>2]=aW;c[al+4140>>2]=aW;c[al+3120>>2]=ak;c[al+4144>>2]=ak;c[al+3124>>2]=ae;c[al+4148>>2]=ae;c[al+3128>>2]=_;c[al+4152>>2]=_;if(!ai){_=al;gGC(_|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=aj;c[2417277]=am;c[1836236]=-1;fwR(2);_=c[2439332]|0;ae=(_|0)==0;if(!ae){ak=_;gGC(9706056,ak|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438120];ak=c[3528486]|0;c[2076596]=ak;aW=c[2417278]|0;c[3541536]=aW;c[1836236]=2;c[_+4180>>2]=1114;c[_+4184>>2]=1258;ab=c[2439348]|0;ad=0;ac=0;while(1){c[_+76+(ac<<2)>>2]=ab+(ac<<8);ah=ad+1&65535;if((ah&65535)>127){aX=0;aY=0;break}else{ad=ah;ac=ah&65535}}while(1){ac=ab+(aY<<8)|0;c[_+76+(aY+512<<2)>>2]=ac;c[_+76+(aY+768<<2)>>2]=ac;ac=aX+1&65535;if((ac&65535)>127){aZ=128;a_=128;break}else{aX=ac;aY=ac&65535}}while(1){c[_+76+(a_<<2)>>2]=ab+(a_<<8);ac=aZ+1&65535;if((ac&65535)>191){a$=128;a0=128;break}else{aZ=ac;a_=ac&65535}}while(1){ac=ab+(a0<<8)|0;c[_+76+(a0+512<<2)>>2]=ac;c[_+76+(a0+768<<2)>>2]=ac;ac=a$+1&65535;if((ac&65535)>191){break}else{a$=ac;a0=ac&65535}}ab=c[2439354]|0;c[_+1036>>2]=ab;ac=ab+256|0;c[_+1040>>2]=ac;ad=ab+512|0;c[_+1044>>2]=ad;am=ab+768|0;c[_+1048>>2]=am;aj=ab+1024|0;c[_+1052>>2]=aj;al=ab+1280|0;c[_+1056>>2]=al;ai=ab+1536|0;c[_+1060>>2]=ai;af=ab+1792|0;c[_+1064>>2]=af;c[_+2060>>2]=ab;c[_+2064>>2]=ac;c[_+2068>>2]=ad;c[_+2072>>2]=am;c[_+2076>>2]=aj;c[_+2080>>2]=al;c[_+2084>>2]=ai;c[_+2088>>2]=af;c[_+3084>>2]=ab;c[_+4108>>2]=ab;c[_+3088>>2]=ac;c[_+4112>>2]=ac;c[_+3092>>2]=ad;c[_+4116>>2]=ad;c[_+3096>>2]=am;c[_+4120>>2]=am;c[_+3100>>2]=aj;c[_+4124>>2]=aj;c[_+3104>>2]=al;c[_+4128>>2]=al;c[_+3108>>2]=ai;c[_+4132>>2]=ai;c[_+3112>>2]=af;c[_+4136>>2]=af;if(!ae){af=_;gGC(af|0,9706056,76)|0}c[2438120]=c[2433530];c[3528486]=ak;c[2417278]=aW;c[1836236]=-1;af=c[642608+(c[2436]<<2)>>2]|0;ai=c[af+128>>2]|0;if((c[af+52>>2]&4|0)==0){c[2113068]=ai;al=c[af+132>>2]|0;c[2113070]=al;c[2443814]=ai;c[2440436]=al;a1=ai;a2=al}else{c[2113070]=ai;al=c[af+132>>2]|0;c[2113068]=al;c[2440436]=ai;c[2443814]=al;a1=al;a2=ai}ai=ag(a1<<1,a2)|0;al=gGq(ai)|0;c[2112926]=al;if((al|0)!=0){gGz(al|0,0,ai|0)}Vr(1,125e4,0,1756,74,0);c[2438228]=5e6;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=408;h[745419]=.2;a[3203368]=1;h[745418]=.2;a[3203360]=1;h[745417]=.2;a[3203352]=1;h[745416]=.2;a[3203344]=1;UB(0,1756,384e3,932,4);c[2415126]=9662152;h[1207773]=.3;c[2415548]=3;a[9753424]=0;a[9753432]=0;a[9753408]=0;a[9753416]=0;a[9747200]=0;a[9732488]=0;c[2430798]=0;ai=c[2439330]|0;al=(ai|0)==0;if(!al){af=ai;gGC(9706056,af|0,76)|0}af=c[2438118]|0;c[2433530]=af;aj=c[3528484]|0;c[2076596]=aj;am=c[2417276]|0;c[3541536]=am;c[1836236]=0;gGz(9706056,0,76);if(!al){al=ai;gGC(al|0,9706056,76)|0}c[2438118]=af;c[3528484]=aj;c[2417276]=am;c[1836236]=-1;am=c[2439331]|0;aj=(am|0)==0;if(!aj){af=am;gGC(9706056,af|0,76)|0}af=c[2438119]|0;c[2433530]=af;al=c[3528485]|0;c[2076596]=al;ai=c[2417277]|0;c[3541536]=ai;c[1836236]=1;gGz(9706056,0,76);if(!aj){aj=am;gGC(aj|0,9706056,76)|0}c[2438119]=af;c[3528485]=al;c[2417277]=ai;c[1836236]=-1;ai=c[2439332]|0;al=(ai|0)==0;if(!al){af=ai;gGC(9706056,af|0,76)|0}af=c[2438120]|0;c[2433530]=af;aj=c[3528486]|0;c[2076596]=aj;am=c[2417278]|0;c[3541536]=am;c[1836236]=2;gGz(9706056,0,76);if(!al){al=ai;gGC(al|0,9706056,76)|0}c[2438120]=af;c[3528486]=aj;c[2417278]=am;c[1836236]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){am=0;do{lN(am);mB(am);am=am+1|0;}while((am|0)<(c[2385508]|0))}UA();aa=0;i=e;return aa|0}}while(0);c[2439360]=0;aa=1;i=e;return aa|0}}while(0);c[2426796]=0;aa=1;i=e;return aa|0}function dmF(){var b=0,d=0,e=0,f=0,g=0,h=0;fwZ();c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}b=c[3541518]|0;if((b|0)!=0){gGr(b|0);c[3541518]=0}if((c[2385508]|0)>0){c[2113008]=0;c[2076598]=0;c[2383582]=0}c[2438228]=0;c[2433526]=0;c[2406676]=0;c[3528472]=0;b=c[2406680]|0;if((b|0)!=0){gGr(b);c[2406680]=0}c[2385508]=0;c[2432978]=0;a[64240]=0;c[2415126]=9662152;b=c[2408988]|0;if((b|0)!=0){gGz(9662152,0,3224);d=b;b=0;while(1){if((b|0)>=1024){break}e=9638528+(b<<2)|0;if((c[e>>2]|0)==(d|0)){f=70156;break}else{b=b+1|0}}if((f|0)==70156){gGr(d);c[e>>2]=0}c[2408988]=0}c[2415126]=9665376;e=c[2408989]|0;if((e|0)!=0){gGz(9665376,0,3224);d=e;e=0;while(1){if((e|0)>=1024){break}g=9638528+(e<<2)|0;if((c[g>>2]|0)==(d|0)){f=70162;break}else{e=e+1|0}}if((f|0)==70162){gGr(d);c[g>>2]=0}c[2408989]=0}g=c[2426796]|0;d=0;while(1){if((d|0)>=1024){f=70169;break}h=9638528+(d<<2)|0;if((c[h>>2]|0)==(g|0)){break}else{d=d+1|0}}if((f|0)==70169){c[2426796]=0;a[9753424]=0;a[9753432]=0;a[9753408]=0;a[9753416]=0;a[9747200]=0;a[9732488]=0;c[2430798]=0;return 0}gGr(g);c[h>>2]=0;c[2426796]=0;a[9753424]=0;a[9753432]=0;a[9753408]=0;a[9753416]=0;a[9747200]=0;a[9732488]=0;c[2430798]=0;return 0}function dmG(){var e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;c[2415126]=9662152;e=c[2415557]|0;f=e&3;if((f|0)==3){g=133}else{g=(5e6/(5e6/((c[2415554]|0)/(c[600992+((e>>>3&1)<<4)+(f<<2)>>2]|0)|0|0)|0|0)|0|0)/((c[2424]|0)/100|0|0)|0}f=~~(+(g|0)*.9307692307692308);if((a[14107936]|0)!=0){a[9753424]=0;a[9753432]=0;a[9753408]=0;a[9753416]=0;a[9747200]=0;a[9732488]=0;c[2430798]=0;e=c[2439330]|0;i=(e|0)==0;if(!i){j=e;gGC(9706056,j|0,76)|0}j=c[2438118]|0;c[2433530]=j;k=c[3528484]|0;c[2076596]=k;l=c[2417276]|0;c[3541536]=l;c[1836236]=0;gGz(9706056,0,76);if(!i){i=e;gGC(i|0,9706056,76)|0}c[2438118]=j;c[3528484]=k;c[2417276]=l;c[1836236]=-1;l=c[2439331]|0;k=(l|0)==0;if(!k){j=l;gGC(9706056,j|0,76)|0}j=c[2438119]|0;c[2433530]=j;i=c[3528485]|0;c[2076596]=i;e=c[2417277]|0;c[3541536]=e;c[1836236]=1;gGz(9706056,0,76);if(!k){k=l;gGC(k|0,9706056,76)|0}c[2438119]=j;c[3528485]=i;c[2417277]=e;c[1836236]=-1;e=c[2439332]|0;i=(e|0)==0;if(!i){j=e;gGC(9706056,j|0,76)|0}j=c[2438120]|0;c[2433530]=j;k=c[3528486]|0;c[2076596]=k;l=c[2417278]|0;c[3541536]=l;c[1836236]=2;gGz(9706056,0,76);if(!i){i=e;gGC(i|0,9706056,76)|0}c[2438120]=j;c[3528486]=k;c[2417278]=l;c[1836236]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){l=0;do{lN(l);mB(l);l=l+1|0;}while((l|0)<(c[2385508]|0))}UA()}a[14107945]=0;a[14107944]=0;l=0;k=0;j=0;do{k=((a[9732512+l|0]&1)<<l|k&255)&255;j=((a[9732504+l|0]&1)<<l|j&255)&255;l=l+1|0;}while((l|0)<8);a[14107944]=k;a[14107945]=j;if((k&3)==3){l=k&-4;a[14107944]=l;m=l}else{m=k}if((m&12)==12){a[14107944]=m&-13}if((j&3)==3){m=j&-4;a[14107945]=m;n=m}else{n=j}if((n&12)==12){a[14107945]=n&-13}n=c[2438]|0;j=gGU(n,(n|0)<0|0?-1:0,7159090,0)|0;n=gGS(j,K,15360,0)|0;j=n;c[2440546]=j;c[2440486]=j;a[6517896]=1;c[2443990]=0;c[2444040]=0;j=c[2385548]|0;if((j|0)>0){gGz(9752472,0,((j|0)>1?j<<2:4)|0)}c[2433530]=0;if((g|0)>0){j=f+1|0;n=0;while(1){m=c[2439330]|0;if((m|0)!=0){k=m;gGC(9706056,k|0,76)|0}b[4853030]=c[2426515]&65535;k=c[2438118]|0;c[2433530]=k;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;l=n+1|0;i=(ag(c[2440546]|0,l)|0)/(g|0)|0;e=c[2444040]|0;o=i-e|0;do{if((o|0)<1){p=0;q=e;r=k}else{if((a[m+4188|0]|0)==0){i=gfc(o)|0;s=(c[2433530]|0)+i|0;c[2433530]=s;p=i;q=c[2444040]|0;r=s;break}else{s=k+o|0;c[2433530]=s;p=o;q=e;r=s;break}}}while(0);c[2444040]=q+p;e=(n|0)==(f|0);if(e){a[9706117]=1}o=(n|0)==(j|0);if(o){a[9706117]=0}k=c[1836236]|0;m=c[9757320+(k<<2)>>2]|0;if((m|0)!=0){s=m;gGC(s|0,9706056,76)|0}c[9752472+(k<<2)>>2]=r;c[14113936+(k<<2)>>2]=c[2076596];c[9669104+(k<<2)>>2]=c[3541536];c[1836236]=-1;k=c[2439331]|0;if((k|0)!=0){s=k;gGC(9706056,s|0,76)|0}b[4853030]=c[2426515]&65535;s=c[2438119]|0;c[2433530]=s;c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;m=(ag(c[2440486]|0,l)|0)/(g|0)|0;i=c[2443990]|0;t=m-i|0;do{if((t|0)<1){u=0;v=i;w=s}else{if((a[k+4188|0]|0)==0){m=gfc(t)|0;x=(c[2433530]|0)+m|0;c[2433530]=x;u=m;v=c[2443990]|0;w=x;break}else{x=s+t|0;c[2433530]=x;u=t;v=i;w=x;break}}}while(0);c[2443990]=v+u;if(e){a[9706117]=1}if(o){a[9706117]=0}i=c[1836236]|0;t=c[9757320+(i<<2)>>2]|0;if((t|0)!=0){s=t;gGC(s|0,9706056,76)|0}c[9752472+(i<<2)>>2]=w;c[14113936+(i<<2)>>2]=c[2076596];c[9669104+(i<<2)>>2]=c[3541536];c[1836236]=-1;i=c[2439332]|0;if((i|0)!=0){s=i;gGC(9706056,s|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438120];c[2076596]=c[3528486];c[3541536]=c[2417278];c[1836236]=2;Sb(ag(((a[6517896]|0?83333:0)|0)/(g|0)|0,n)|0);UD();s=c[1836236]|0;i=c[9757320+(s<<2)>>2]|0;if((i|0)!=0){t=i;gGC(t|0,9706056,76)|0}c[9752472+(s<<2)>>2]=c[2433530];c[14113936+(s<<2)>>2]=c[2076596];c[9669104+(s<<2)>>2]=c[3541536];c[1836236]=-1;if((l|0)<(g|0)){n=l}else{break}}}n=c[2439332]|0;if((n|0)!=0){g=n;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438120];c[2076596]=c[3528486];c[3541536]=c[2417278];c[1836236]=2;g=a[6517896]|0?83333:0;n=gGU(g,0,2048e6,0)|0;w=c[2438228]|0;u=gGS(n,K,w,(w|0)<0|0?-1:0)|0;w=u;Sb(g);g=c[2443830]|0;if((g|0)<1073676288){c[2443830]=g-w}g=c[2443831]|0;if((g|0)<1073676288){c[2443831]=g-w}g=(c[3528512]|0)-w|0;c[3528512]=(g|0)<0?0:g;g=c[2112964]|0;if((g|0)!=0){gg[c[3542122]&4095](g,a[9688]|0?534:0);Uz(0,c[2112964]|0,a[9688]|0?534:0)}g=c[1836236]|0;w=c[9757320+(g<<2)>>2]|0;if((w|0)!=0){u=w;gGC(u|0,9706056,76)|0}c[9752472+(g<<2)>>2]=c[2433530];c[14113936+(g<<2)>>2]=c[2076596];c[9669104+(g<<2)>>2]=c[3541536];c[1836236]=-1;if((c[2112968]|0)==0){return 0}g=c[2112926]|0;gGz(g|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);u=c[2433124]|0;w=c[2439364]|0;n=0;do{v=(d[u+(n&-2)|0]<<8|d[u+(n|1)|0])&65535;r=v>>>4&15;j=v>>>8;c[w+(((n|0)/2|0)<<2)>>2]=(j<<4|j&8)>>>3&31|(v<<4|v&8)<<8&63488|(r<<4|r)<<3&2016;n=n+1|0;}while((n|0)<2048);n=c[2433132]|0;u=c[3526982]|0;r=0;v=0;while(1){j=(r<<4)+511|0;f=0;p=v;while(1){q=d[n+p|0]|0;s=q>>>4;t=d[n+(p+2048)|0]|(q>>>1&4|q&3)<<8|2048;q=d[9753416]|0;i=(f<<4)-252-(q<<3)-(a[9747200]&7)|0;k=i&1023;x=j-(d[9753408]|0)-(q<<1&256)&511;q=x-16|0;m=k>>>0>968?i|-1024:k;do{if((m-16|0)>>>0<224){if((x-32|0)>>>0>=192){y=70250;break}Sy(g,t,m,q,s,4,768,u)}else{y=70250}}while(0);if((y|0)==70250){y=0;Sz(g,t,m,q,s,4,768,u)}x=f+1|0;if((x|0)<64){f=x;p=p+1|0}else{break}}p=r+1|0;if((p|0)<32){r=p;v=v+64|0}else{break}}v=c[2433130]|0;r=0;n=0;while(1){p=(r<<4)+511|0;f=0;j=n;while(1){l=d[v+j|0]|0;o=l>>>4;e=(l>>>1&4|l&3)<<8|d[v+(j+2048)|0];l=d[9753432]|0;x=(f<<4)-250-(l<<3)-((d[9747200]|0)>>>3&7)|0;k=x&1023;i=p-(d[9753424]|0)-(l<<1&256)&511;l=i-16|0;z=k>>>0>968?x|-1024:k;do{if((z-16|0)>>>0<224){if((i-32|0)>>>0>=192){y=70258;break}SG(g,e,z,l,o,4,15,512,u)}else{y=70258}}while(0);if((y|0)==70258){y=0;SH(g,e,z,l,o,4,15,512,u)}i=f+1|0;if((i|0)<64){f=i;j=j+1|0}else{break}}j=r+1|0;if((j|0)<32){r=j;n=n+64|0}else{break}}dmK(1);n=c[2430044]|0;r=c[2436802]|0;u=0;y=0;while(1){v=u<<3;j=v-16|0;if((v-24|0)>>>0<208){v=0;f=y;while(1){p=d[n+f|0]|0;i=p<<8&1792|d[n+(f+2048)|0];s=p>>>4;p=v<<3;if((p-8|0)>>>0<240){Sq(g,i,p,j,s,4,15,256,r)}else{Sr(g,i,p,j,s,4,15,256,r)}s=v+1|0;if((s|0)<64){v=s;f=f+1|0}else{break}}}else{f=0;v=y;while(1){s=d[n+v|0]|0;Sr(g,s<<8&1792|d[n+(v+2048)|0],f<<3,j,s>>>4,4,15,256,r);s=f+1|0;if((s|0)<64){f=s;v=v+1|0}else{break}}}v=u+1|0;if((v|0)<32){u=v;y=y+64|0}else{break}}dmK(0);R8(w);return 0}function dmH(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=i;i=i+160|0;e=d|0;f=d+16|0;g=d+32|0;h=d+48|0;j=d+64|0;k=d+80|0;l=d+96|0;m=d+112|0;n=d+128|0;o=d+144|0;if((b|0)!=0){c[b>>2]=169737}if((a&32|0)!=0){gGz(o|0,0,12);p=c[2405704]|0;c[o>>2]=p;c[o+4>>2]=(c[2411796]|0)-p;c[o+12>>2]=162152;p=c[2076592]|0;gj[p&4095](o)|0}if((a&64|0)==0){i=d;return 0}fw$(a);Vx(a,b);gGz(n|0,0,12);c[n>>2]=9732488;c[n+4>>2]=1;c[n+12>>2]=78016;gj[c[2076592]&4095](n)|0;gGz(m|0,0,12);c[m>>2]=9723192;c[m+4>>2]=4;c[m+12>>2]=584856;gj[c[2076592]&4095](m)|0;gGz(l|0,0,12);c[l>>2]=14107944;c[l+4>>2]=2;c[l+12>>2]=568432;gj[c[2076592]&4095](l)|0;gGz(k|0,0,12);c[k>>2]=9542928;c[k+4>>2]=2;c[k+12>>2]=552208;gj[c[2076592]&4095](k)|0;gGz(j|0,0,12);c[j>>2]=9753424;c[j+4>>2]=1;c[j+12>>2]=537584;gj[c[2076592]&4095](j)|0;gGz(h|0,0,12);c[h>>2]=9753432;c[h+4>>2]=1;c[h+12>>2]=524352;gj[c[2076592]&4095](h)|0;gGz(g|0,0,12);c[g>>2]=9753408;c[g+4>>2]=1;c[g+12>>2]=510680;gj[c[2076592]&4095](g)|0;gGz(f|0,0,12);c[f>>2]=9753416;c[f+4>>2]=1;c[f+12>>2]=498136;gj[c[2076592]&4095](f)|0;gGz(e|0,0,12);c[e>>2]=9747200;c[e+4>>2]=1;c[e+12>>2]=486256;gj[c[2076592]&4095](e)|0;i=d;return 0}function dmI(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>25){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5997244+(b*112|0)>>2];c[a+104>>2]=c[5997248+(b*112|0)>>2];c[a+108>>2]=c[5997252+(b*112|0)>>2];d=0;return d|0}function dmJ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<26&(d|0)==0)){e=1;return e|0}c[a>>2]=5997144+(b*112|0);e=0;return e|0}function dmK(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=c[2436796]|0;e=c[2112926]|0;f=c[2439362]|0;g=2040;do{h=d[b+(g|3)|0]|0;L84625:do{if((h>>>7^1|0)==(a|0)){i=d[b+g|0]|0;j=d[b+(g|4)|0]|0;k=i&1;l=i&2;m=(i>>>4|h<<4&1008)<<2|i>>>2&3;i=d[b+(g|2)|0]|0;n=(h&64|0)==0?i|-256:i;i=240-(d[b+(g|1)|0]|0)|0;o=i-16|0;do{if((n-16|0)>>>0<224){if((i-32|0)>>>0>=192){break}p=(l|0)!=0;q=j>>>4;if((k|0)==0){if(p){SK(e,m,n,o,q,4,15,0,f);break L84625}else{SG(e,m,n,o,q,4,15,0,f);break L84625}}else{if(p){SM(e,m,n,o,q,4,15,0,f);break L84625}else{SI(e,m,n,o,q,4,15,0,f);break L84625}}}}while(0);i=(l|0)!=0;q=j>>>4;if((k|0)==0){if(i){SL(e,m,n,o,q,4,15,0,f);break}else{SH(e,m,n,o,q,4,15,0,f);break}}else{if(i){SN(e,m,n,o,q,4,15,0,f);break}else{SJ(e,m,n,o,q,4,15,0,f);break}}}}while(0);g=g-8|0;}while((g|0)>-1);return}function dmL(a){a=a|0;var b=0.0,d=0,e=0;b=+((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0);d=+V(b)>=1.0?b>0.0?(al(+U(b/4294967296.0),4294967295.0)|0)>>>0:~~+af((b- +(~~b>>>0))/4294967296.0)>>>0:0;e=gGU(~~b>>>0,d,a,(a|0)<0|0?-1:0)|0;a=gGS(e,K,5e6,0)|0;return a|0}function dmM(){return+(+((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)/5.0e6)}function dmN(){var b=0,d=0,e=0;b=c[2384366]|0;c[2384366]=b^1;d=c[2430798]|0;if((b|0)==1){b=d&15;c[2415126]=9662152;if((c[2415542]|0)==4){c[2415538]=b;return}else{c[2415538]=b<<1&14;return}}b=d>>>4;c[2415126]=9662152;if((c[2415542]|0)==4){e=b&15}else{e=b<<1&14}c[2415538]=e;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12;return}function dmO(e,f){e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=e&65535;if((g&65280|0)==24576){b[(c[2409006]|0)+2>>1]=e&255;return}if((g&65024|0)==25088){b[c[2409006]>>1]=e&511;return}if((g&64512|0)==26624){UZ(g&1023,f&255);return}h=g&61440;if((h|0)==32768){i=a[1530616]|0;if((g&2048|0)==0){if(!i){return}j=~~(+(c[2113158]|0)*102400.0/25600.0);if((j|0)>0){c[2443988]=j}a[1530616]=0;return}if(i){return}i=~~(+(c[2113158]|0)*102400.0/25600.0);if((i|0)>0){j=f4D(i-(c[2443988]|0)|0)|0;c[2113162]=(c[2113162]|0)+j;c[2443988]=(c[2443988]|0)+j}a[9660900]=a[9660900]|16;j=c[2437644]|0;i=c[j+1092>>2]|0;do{if((i|0)==0){k=c[j+3144>>2]|0;if((k|0)==0){l=0;m=0;break}n=gj[k&4095](-2)|0;k=c[2437644]|0;o=c[k+1092>>2]|0;p=(n&255)<<8;if((o|0)!=0){q=o;r=p;s=70347;break}o=c[k+3144>>2]|0;if((o|0)==0){l=0;m=p;break}l=gj[o&4095](-1)|0;m=p}else{q=i;r=(d[i+254|0]|0)<<8;s=70347}}while(0);if((s|0)==70347){l=a[q+255|0]|0;m=r}r=l&255|m;c[2415221]=r;b[4830442]=r&65535;a[9660920]=0;a[9660921]=0;a[9660928]=0;a[9660930]=0;a[9660931]=0;c[2415234]=0;gGz(9660901,0,5);c[2415235]=65535;c[2415237]=65535;a[9660932]=a[9660932]|64;a[1530616]=1;return}else if((h|0)==28672){r=g>>>11&1;a[c[2432936]|0]=(r^1)&255;if((r|0)==0){return}a[9660786]=0;return}else if((h|0)==36864){h=g>>>11&1^1;r=c[3528584]|0;if((d[r]|0|0)==(h|0)){return}a[r]=h&255;r=c[3527392]|0;m=h<<13|65536;h=c[3528554]|0;l=c[2433592]|0;q=0;s=0;while(1){i=r+((s<<8)+m)|0;c[l+(h*3148|0)+48+(s<<2)>>2]=i;c[l+(h*3148|0)+48+(s+512<<2)>>2]=i;i=q+1&65535;if((i&65535)>31){break}else{q=i;s=i&65535}}return}else{if((g&65534|0)!=40960){return}a[c[3528754]|0]=e&1;a[c[2394702]|0]=(f&-16)<<24>>24==80|0;return}}function dmP(b){b=b|0;var d=0,e=0;d=b&65535;if((d&64512|0)==26624){e=a[(c[2438116]|0)+(d&1023)|0]|0;return e|0}if((d&63488|0)!=30720){e=0;return e|0}c[2388388]=0;e=0;return e|0}function dmQ(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((e&65504|0)==0){f4S(b&31,d);return}if((e&65408|0)==128){a[(c[2438794]|0)+(e&127)|0]=d;return}if((e&64512|0)==4096){UZ(e&1023,d&255);return}if((e&57344|0)==8192){c[2388388]=0;return}if((e&49152|0)!=16384){return}d=e>>>13&1;a[(c[2432936]|0)+1|0]=(d^1)&255;if((d|0)==0|(a[9660903]|0)==0){return}a[9660903]=0;return}function dmR(b){b=b|0;var d=0,e=0;d=b&65535;if((d&65504|0)==0){e=f4R(b&31)|0;return e|0}if((d&65408|0)==128){e=a[(c[2438794]|0)+(d&127)|0]|0;return e|0}if((d&64512|0)!=4096){e=0;return e|0}e=a[(c[2438116]|0)+(d&1023)|0]|0;return e|0}function dmS(b,d){b=b|0;d=d|0;if((b&511)!=256){return}b=d&224;if((b|0)==192){a[c[2442902]|0]=d&1^1;return}else if((b|0)==96){a[c[2385608]|0]=d&7;return}else{return}}function dmT(b){b=b|0;var e=0,f=0;e=b&511;if((e|0)==256){f=a[9550752+(d[c[2385608]|0]|0)|0]|0}else if((e|0)==257){f=-1}else{f=0}return f|0}function dmU(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5668636+(b*112|0)>>2];c[a+104>>2]=c[5668640+(b*112|0)>>2];c[a+108>>2]=c[5668644+(b*112|0)>>2];d=0;return d|0}function dmV(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=5668536+(b*112|0);e=0;return e|0}function dmW(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3440072+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dmX(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>40){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6080120+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dmY(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0;e=i;i=i+1680|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;B=e+1200|0;C=e+1312|0;D=e+1320|0;E=e+1432|0;F=e+1440|0;G=e+1552|0;H=e+1560|0;I=e+1672|0;c[2415042]=0;c[3527392]=0;c[2439834]=81920;c[3530898]=147456;c[3530662]=212992;c[3530470]=278528;c[3531034]=475136;c[2406980]=476928;c[3530118]=482048;c[2414750]=487168;c[2438794]=487168;c[2439838]=487296;c[3541148]=489344;c[2386252]=490624;c[2386336]=494720;c[2386510]=496768;c[3528584]=502912;c[2432936]=502913;c[3528754]=502915;c[2394702]=502916;c[2442902]=502917;c[2385608]=502918;c[2409006]=502919;c[2411794]=502923;J=0;while(1){if((J|0)>=1024){break}K=9638528+(J<<2)|0;if((c[K>>2]|0)==0){L=70454;break}else{J=J+1|0}}do{if((L|0)==70454){J=gGq(502923)|0;c[K>>2]=J;if((J|0)==0){break}c[2415042]=J;gGz(J|0,0,502923);c[3527392]=J;c[2439834]=J+81920;c[3530898]=J+147456;c[3530662]=J+212992;c[3530470]=J+278528;c[3531034]=J+475136;c[2406980]=J+476928;c[3530118]=J+482048;M=J+487168|0;c[2414750]=M;c[2438794]=M;c[2439838]=J+487296;M=J+489344|0;c[3541148]=M;c[2386178]=M;c[2386252]=J+490624;c[2386336]=J+494720;c[2386510]=J+496768;c[3528584]=J+502912;c[2432936]=J+502913;c[3528754]=J+502915;c[2394702]=J+502916;c[2442902]=J+502917;c[2385608]=J+502918;c[2409006]=J+502919;M=J+502923|0;c[2411794]=M;c[2414342]=M;M=J+32768|0;if((c[3542200]|0)==0){N=1;i=e;return N|0}J=H+108|0;c[J>>2]=0;O=H+100|0;c[O>>2]=0;P=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[P&16383](H,0)|0;do{if((c[J>>2]|0)!=0){P=c[O>>2]|0;c[I>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](I,0,0)|0;if((P|0)<1){N=1;i=e;return N|0}if((gzL(M,0,0)|0)==0){break}else{N=1}i=e;return N|0}}while(0);M=(c[3527392]|0)+49152|0;if((c[3542200]|0)==0){N=1;i=e;return N|0}O=F+108|0;c[O>>2]=0;J=F+100|0;c[J>>2]=0;P=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[P&16383](F,1)|0;do{if((c[O>>2]|0)!=0){P=c[J>>2]|0;c[G>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](G,1,0)|0;if((P|0)<1){N=1;i=e;return N|0}if((gzL(M,0,1)|0)==0){break}else{N=1}i=e;return N|0}}while(0);M=(c[3527392]|0)+65536|0;if((c[3542200]|0)==0){N=1;i=e;return N|0}J=D+108|0;c[J>>2]=0;O=D+100|0;c[O>>2]=0;P=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[P&16383](D,2)|0;do{if((c[J>>2]|0)!=0){P=c[O>>2]|0;c[E>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](E,2,0)|0;if((P|0)<1){N=1;i=e;return N|0}if((gzL(M,0,2)|0)==0){break}else{N=1}i=e;return N|0}}while(0);M=(c[2439834]|0)+32768|0;if((c[3542200]|0)==0){N=1;i=e;return N|0}O=B+108|0;c[O>>2]=0;J=B+100|0;c[J>>2]=0;P=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[P&16383](B,3)|0;do{if((c[O>>2]|0)!=0){P=c[J>>2]|0;c[C>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](C,3,0)|0;if((P|0)<1){N=1;i=e;return N|0}if((gzL(M,0,3)|0)==0){break}else{N=1}i=e;return N|0}}while(0);M=(c[2439834]|0)+61440|0;if((c[3542200]|0)==0){N=1;i=e;return N|0}J=z+108|0;c[J>>2]=0;O=z+100|0;c[O>>2]=0;P=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[P&16383](z,4)|0;do{if((c[J>>2]|0)!=0){P=c[O>>2]|0;c[A>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](A,4,0)|0;if((P|0)<1){N=1;i=e;return N|0}if((gzL(M,0,4)|0)==0){break}else{N=1}i=e;return N|0}}while(0);M=c[3530898]|0;if((c[3542200]|0)==0){N=1;i=e;return N|0}O=x+108|0;c[O>>2]=0;J=x+100|0;c[J>>2]=0;P=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[P&16383](x,5)|0;do{if((c[O>>2]|0)!=0){P=c[J>>2]|0;c[y>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](y,5,0)|0;if((P|0)<1){N=1;i=e;return N|0}if((gzL(M,0,5)|0)==0){break}else{N=1}i=e;return N|0}}while(0);M=c[3530662]|0;if((c[3542200]|0)==0){N=1;i=e;return N|0}J=v+108|0;c[J>>2]=0;O=v+100|0;c[O>>2]=0;P=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[P&16383](v,6)|0;do{if((c[J>>2]|0)!=0){P=c[O>>2]|0;c[w>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](w,6,0)|0;if((P|0)<1){N=1;i=e;return N|0}if((gzL(M,0,6)|0)==0){break}else{N=1}i=e;return N|0}}while(0);M=c[3530470]|0;if((c[3542200]|0)==0){N=1;i=e;return N|0}O=t+108|0;c[O>>2]=0;J=t+100|0;c[J>>2]=0;P=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[P&16383](t,7)|0;do{if((c[O>>2]|0)!=0){P=c[J>>2]|0;c[u>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](u,7,0)|0;if((P|0)<1){N=1;i=e;return N|0}if((gzL(M,0,7)|0)==0){break}else{N=1}i=e;return N|0}}while(0);M=(c[3530470]|0)+16384|0;if((c[3542200]|0)==0){N=1;i=e;return N|0}J=r+108|0;c[J>>2]=0;O=r+100|0;c[O>>2]=0;P=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[P&16383](r,8)|0;do{if((c[J>>2]|0)!=0){P=c[O>>2]|0;c[s>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](s,8,0)|0;if((P|0)<1){N=1;i=e;return N|0}if((gzL(M,0,8)|0)==0){break}else{N=1}i=e;return N|0}}while(0);M=c[3531034]|0;if((c[3542200]|0)==0){N=1;i=e;return N|0}O=p+108|0;c[O>>2]=0;J=p+100|0;c[J>>2]=0;P=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[P&16383](p,9)|0;do{if((c[O>>2]|0)!=0){P=c[J>>2]|0;c[q>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](q,9,0)|0;if((P|0)<1){N=1;i=e;return N|0}if((gzL(M,0,9)|0)==0){break}else{N=1}i=e;return N|0}}while(0);M=(c[3531034]|0)+256|0;if((c[3542200]|0)==0){N=1;i=e;return N|0}J=n+108|0;c[J>>2]=0;O=n+100|0;c[O>>2]=0;P=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[P&16383](n,10)|0;do{if((c[J>>2]|0)!=0){P=c[O>>2]|0;c[o>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](o,10,0)|0;if((P|0)<1){N=1;i=e;return N|0}if((gzL(M,0,10)|0)==0){break}else{N=1}i=e;return N|0}}while(0);M=(c[3531034]|0)+512|0;if((c[3542200]|0)==0){N=1;i=e;return N|0}O=l+108|0;c[O>>2]=0;J=l+100|0;c[J>>2]=0;P=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[P&16383](l,11)|0;do{if((c[O>>2]|0)!=0){P=c[J>>2]|0;c[m>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](m,11,0)|0;if((P|0)<1){N=1;i=e;return N|0}if((gzL(M,0,11)|0)==0){break}else{N=1}i=e;return N|0}}while(0);M=(c[3531034]|0)+768|0;if((c[3542200]|0)==0){N=1;i=e;return N|0}J=j+108|0;c[J>>2]=0;O=j+100|0;c[O>>2]=0;P=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[P&16383](j,12)|0;do{if((c[J>>2]|0)!=0){P=c[O>>2]|0;c[k>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](k,12,0)|0;if((P|0)<1){N=1;i=e;return N|0}if((gzL(M,0,12)|0)==0){break}else{N=1}i=e;return N|0}}while(0);M=(c[3531034]|0)+1280|0;if((c[3542200]|0)==0){N=1;i=e;return N|0}O=f+108|0;c[O>>2]=0;J=f+100|0;c[J>>2]=0;P=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[P&16383](f,13)|0;do{if((c[O>>2]|0)!=0){P=c[J>>2]|0;c[g>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](g,13,0)|0;if((P|0)<1){N=1;i=e;return N|0}if((gzL(M,0,13)|0)==0){break}else{N=1}i=e;return N|0}}while(0);M=c[3530470]|0;J=0;while(1){O=M+(J+16384)|0;P=a[O]|0;a[M+(J+32768)|0]=P;a[M+(J+40960)|0]=(P&255)>>>4;a[O]=a[M+(J+24576)|0]|0;O=J+1|0;if((O|0)<8192){J=O}else{R=0;break}}while(1){if((R|0)>=1024){break}S=9638528+(R<<2)|0;if((c[S>>2]|0)==0){L=70516;break}else{R=R+1|0}}L84970:do{if((L|0)==70516){J=gGq(65536)|0;c[S>>2]=J;if((J|0)==0){break}gGz(J|0,0,65536);M=c[3530898]|0;gGC(J|0,M|0,8192)|0;O=0;do{P=O<<6;gGz(M+P|0,0,64);Q=O<<7;T=0;do{U=Q+(c[611712+(T<<2)>>2]|0)|0;V=(T<<3)+P|0;W=0;do{X=U+(c[610928+(W<<2)>>2]|0)|0;if(((d[J+((X|0)/8|0)|0]|0)&128>>>((X&7)>>>0)|0)!=0){X=M+(V+W)|0;a[X]=a[X]|2}W=W+1|0;}while((W|0)<8);T=T+1|0;}while((T|0)<8);T=Q|4;W=0;do{V=T+(c[611712+(W<<2)>>2]|0)|0;U=(W<<3)+P|0;X=0;do{Y=V+(c[610928+(X<<2)>>2]|0)|0;if(((d[J+((Y|0)/8|0)|0]|0)&128>>>((Y&7)>>>0)|0)!=0){Y=M+(U+X)|0;a[Y]=a[Y]|1}X=X+1|0;}while((X|0)<8);W=W+1|0;}while((W|0)<8);O=O+1|0;}while((O|0)<512);O=c[3530662]|0;gGC(J|0,O|0,8192)|0;M=0;do{W=M<<6;gGz(O+W|0,0,64);P=M<<7;T=0;do{Q=P+(c[6669224+(T<<2)>>2]|0)|0;X=(T<<3)+W|0;U=0;do{V=Q+(c[612480+(U<<2)>>2]|0)|0;if(((d[J+((V|0)/8|0)|0]|0)&128>>>((V&7)>>>0)|0)!=0){V=O+(X+U)|0;a[V]=a[V]|2}U=U+1|0;}while((U|0)<8);T=T+1|0;}while((T|0)<8);T=P|4;U=0;do{X=T+(c[6669224+(U<<2)>>2]|0)|0;Q=(U<<3)+W|0;V=0;do{Y=X+(c[612480+(V<<2)>>2]|0)|0;if(((d[J+((Y|0)/8|0)|0]|0)&128>>>((Y&7)>>>0)|0)!=0){Y=O+(Q+V)|0;a[Y]=a[Y]|1}V=V+1|0;}while((V|0)<8);U=U+1|0;}while((U|0)<8);M=M+1|0;}while((M|0)<512);M=c[3530470]|0;gGC(J|0,M|0,65536)|0;O=0;while(1){U=O<<8;gGz(M+U|0,0,256);W=O<<9;T=W+262148|0;P=0;while(1){V=T+(c[611712+(P<<2)>>2]|0)|0;Q=(P<<4)+U|0;X=0;do{Y=V+(c[609488+(X<<2)>>2]|0)|0;if(((d[J+((Y|0)/8|0)|0]|0)&128>>>((Y&7)>>>0)|0)!=0){Y=M+(Q+X)|0;a[Y]=a[Y]|4}X=X+1|0;}while((X|0)<16);X=P+1|0;if((X|0)<16){P=X}else{Z=0;break}}do{P=W+(c[611712+(Z<<2)>>2]|0)|0;T=(Z<<4)+U|0;X=0;do{Q=P+(c[609488+(X<<2)>>2]|0)|0;if(((d[J+((Q|0)/8|0)|0]|0)&128>>>((Q&7)>>>0)|0)!=0){Q=M+(T+X)|0;a[Q]=a[Q]|2}X=X+1|0;}while((X|0)<16);Z=Z+1|0;}while((Z|0)<16);X=W|4;T=0;do{P=X+(c[611712+(T<<2)>>2]|0)|0;Q=(T<<4)+U|0;V=0;do{Y=P+(c[609488+(V<<2)>>2]|0)|0;if(((d[J+((Y|0)/8|0)|0]|0)&128>>>((Y&7)>>>0)|0)!=0){Y=M+(Q+V)|0;a[Y]=a[Y]|1}V=V+1|0;}while((V|0)<16);T=T+1|0;}while((T|0)<16);T=O+1|0;if((T|0)<512){O=T}else{_=0;break}}while(1){if((_|0)>=1024){break L84970}$=9638528+(_<<2)|0;if((c[$>>2]|0)==(J|0)){break}else{_=_+1|0}}gGr(J);c[$>>2]=0}}while(0);O=c[3531034]|0;M=c[2406980]|0;T=0;while(1){U=a[O+T|0]&15;X=a[O+(T+256)|0]&15;W=a[O+(T+512)|0]&15;c[M+(T<<2)>>2]=U<<20|U<<16|X<<12|X<<8|W|W<<4;W=T+1|0;if((W|0)<256){T=W}else{aa=0;break}}do{c[M+(aa+256<<2)>>2]=c[M+((d[O+(aa+768)|0]|0)<<2)>>2];aa=aa+1|0;}while((aa|0)<1024);c[3528554]=-1;c[2113160]=1;O=gGq(3148)|0;M=O;c[2433592]=M;if((O|0)!=0){gGz(O|0,0,3148);c[O+3120>>2]=3128;c[O+3124>>2]=1840;c[O+3128>>2]=136;c[O+3132>>2]=1902;c[2432840]=0;T=0;do{c[M+48+(T<<2)>>2]=0;T=T+1|0;}while((T|0)<768);c[2113158]=0;c[2415198]=0;T=c[2427044]|0;c[9681616+(T<<3)>>2]=809272;c[9681620+(T<<3)>>2]=0;c[2427044]=T+1}c[3528554]=0;f43(O);T=c[3528554]|0;M=9731360+(T<<2)|0;W=c[M>>2]|0;c[2113158]=W;X=c[3527392]|0;U=c[2433592]|0;V=0;Q=0;while(1){P=X+((Q<<8)+65536)|0;c[U+(T*3148|0)+48+(Q<<2)>>2]=P;c[U+(T*3148|0)+48+(Q+512<<2)>>2]=P;P=V+1&65535;if((P&65535)>31){break}else{V=P;Q=P&65535}}Q=c[2386252]|0;V=32;O=32;while(1){P=Q+((O<<8)-8192)|0;c[U+(T*3148|0)+48+(O<<2)>>2]=P;c[U+(T*3148|0)+48+(O+256<<2)>>2]=P;c[U+(T*3148|0)+48+(O+512<<2)>>2]=P;P=V+1&65535;if((P&65535)>47){break}else{V=P;O=P&65535}}O=c[2386336]|0;c[U+(T*3148|0)+304>>2]=O;c[U+(T*3148|0)+1328>>2]=O;c[U+(T*3148|0)+2352>>2]=O;V=O+256|0;c[U+(T*3148|0)+308>>2]=V;c[U+(T*3148|0)+1332>>2]=V;c[U+(T*3148|0)+2356>>2]=V;V=O+512|0;c[U+(T*3148|0)+312>>2]=V;c[U+(T*3148|0)+1336>>2]=V;c[U+(T*3148|0)+2360>>2]=V;V=O+768|0;c[U+(T*3148|0)+316>>2]=V;c[U+(T*3148|0)+1340>>2]=V;c[U+(T*3148|0)+2364>>2]=V;V=O+1024|0;c[U+(T*3148|0)+320>>2]=V;c[U+(T*3148|0)+1344>>2]=V;c[U+(T*3148|0)+2368>>2]=V;V=O+1280|0;c[U+(T*3148|0)+324>>2]=V;c[U+(T*3148|0)+1348>>2]=V;c[U+(T*3148|0)+2372>>2]=V;V=O+1536|0;c[U+(T*3148|0)+328>>2]=V;c[U+(T*3148|0)+1352>>2]=V;c[U+(T*3148|0)+2376>>2]=V;V=O+1792|0;c[U+(T*3148|0)+332>>2]=V;c[U+(T*3148|0)+1356>>2]=V;c[U+(T*3148|0)+2380>>2]=V;V=c[2386510]|0;O=72;Q=72;while(1){P=V+((Q<<8)-18432)|0;c[U+(T*3148|0)+48+(Q<<2)>>2]=P;c[U+(T*3148|0)+48+(Q+256<<2)>>2]=P;c[U+(T*3148|0)+48+(Q+512<<2)>>2]=P;P=O+1&65535;if((P&65535)>95){ab=128;ac=128;break}else{O=P;Q=P&65535}}while(1){Q=X+(ac<<8)|0;c[U+(T*3148|0)+48+(ac<<2)>>2]=Q;c[U+(T*3148|0)+48+(ac+512<<2)>>2]=Q;Q=ab+1&65535;if((Q&65535)>255){break}else{ab=Q;ac=Q&65535}}c[U+(T*3148|0)+3124>>2]=2600;c[U+(T*3148|0)+3120>>2]=2734;X=U+(T*3148|0)|0;if((X|0)!=0){Q=X;gGC(Q|0,9660752,48)|0}c[M>>2]=W;c[3528554]=-1;fwj(2);Q=c[2439834]|0;X=c[2437644]|0;O=128;V=128;while(1){P=Q+(V<<8)|0;c[X+72+(V<<2)>>2]=P;c[X+72+(V+512<<2)>>2]=P;P=O+1&65535;if((P&65535)>191){break}else{O=P;V=P&65535}}V=c[2439838]|0;c[X+840>>2]=V;c[X+1864>>2]=V;c[X+2888>>2]=V;O=V+256|0;c[X+844>>2]=O;c[X+1868>>2]=O;c[X+2892>>2]=O;O=V+512|0;c[X+848>>2]=O;c[X+1872>>2]=O;c[X+2896>>2]=O;O=V+768|0;c[X+852>>2]=O;c[X+1876>>2]=O;c[X+2900>>2]=O;O=V+1024|0;c[X+856>>2]=O;c[X+1880>>2]=O;c[X+2904>>2]=O;O=V+1280|0;c[X+860>>2]=O;c[X+1884>>2]=O;c[X+2908>>2]=O;O=V+1536|0;c[X+864>>2]=O;c[X+1888>>2]=O;c[X+2912>>2]=O;O=V+1792|0;c[X+868>>2]=O;c[X+1892>>2]=O;c[X+2916>>2]=O;O=240;V=240;while(1){W=Q+(V<<8)|0;c[X+72+(V<<2)>>2]=W;c[X+72+(V+512<<2)>>2]=W;W=O+1&65535;if((W&65535)>255){break}else{O=W;V=W&65535}}c[X+3144>>2]=538;c[X+3148>>2]=808;c[X+3160>>2]=2232;c[X+3164>>2]=1906;U_(24e3,8);V=c[2420424]|0;h[V+424>>3]=.5;c[V+440>>2]=3;h[V+432>>3]=.5;c[V+444>>2]=3;V=c[642608+(c[2436]<<2)>>2]|0;O=c[V+128>>2]|0;if((c[V+52>>2]&4|0)==0){c[2113068]=O;Q=c[V+132>>2]|0;c[2113070]=Q;c[2443814]=O;c[2440436]=Q;ad=O;ae=Q}else{c[2113070]=O;Q=c[V+132>>2]|0;c[2113068]=Q;c[2440436]=O;c[2443814]=Q;ad=Q;ae=O}O=ag(ad<<1,ae)|0;Q=gGq(O)|0;c[2112926]=Q;if((Q|0)!=0){gGz(Q|0,0,O|0)}O=c[2414750]|0;gGz(O|0,0,(c[2411794]|0)-O|0);c[3528554]=0;f43(c[2433592]|0);O=c[3528554]|0;c[2113158]=c[9731360+(O<<2)>>2];a[9660796]=0;a[9660797]=0;a[9660786]=0;a[9660787]=0;c[2415191]=0;a[9660784]=a[9660784]|80;Q=c[2433592]|0;V=c[Q+(O*3148|0)+1068>>2]|0;do{if((V|0)==0){W=c[Q+(O*3148|0)+3120>>2]|0;if((W|0)==0){af=0;ah=0;break}M=gj[W&4095](-2)|0;W=c[3528554]|0;T=c[2433592]|0;U=c[T+(W*3148|0)+1068>>2]|0;P=(M&255)<<8;if((U|0)!=0){ai=U;aj=P;L=70572;break}U=c[T+(W*3148|0)+3120>>2]|0;if((U|0)==0){af=0;ah=P;break}af=gj[U&4095](-1)|0;ah=P}else{ai=V;aj=(d[V+254|0]|0)<<8;L=70572}}while(0);if((L|0)==70572){af=a[ai+255|0]|0;ah=aj}V=af&255|ah;c[2415188]=V;b[4830376]=V&65535;V=c[3528584]|0;a[V]=-1;a[V]=0;V=c[3527392]|0;O=c[3528554]|0;Q=c[2433592]|0;X=0;P=0;while(1){U=V+((P<<8)+65536)|0;c[Q+(O*3148|0)+48+(P<<2)>>2]=U;c[Q+(O*3148|0)+48+(P+512<<2)>>2]=U;U=X+1&65535;if((U&65535)>31){break}else{X=U;P=U&65535}}P=Q+(O*3148|0)|0;if((P|0)!=0){X=P;gGC(X|0,9660752,48)|0}c[9731360+(O<<2)>>2]=c[2113158];c[3528554]=-1;a[9660900]=a[9660900]|16;X=c[2437644]|0;P=c[X+1092>>2]|0;do{if((P|0)==0){V=c[X+3144>>2]|0;if((V|0)==0){ak=0;al=0;break}U=gj[V&4095](-2)|0;V=c[2437644]|0;W=c[V+1092>>2]|0;T=(U&255)<<8;if((W|0)!=0){am=W;an=T;L=70583;break}W=c[V+3144>>2]|0;if((W|0)==0){ak=0;al=T;break}ak=gj[W&4095](-1)|0;al=T}else{am=P;an=(d[P+254|0]|0)<<8;L=70583}}while(0);if((L|0)==70583){ak=a[am+255|0]|0;al=an}P=ak&255|al;c[2415221]=P;b[4830442]=P&65535;a[9660920]=0;a[9660921]=0;a[9660928]=0;a[9660930]=0;a[9660931]=0;c[2415234]=0;gGz(9660901,0,5);c[2415235]=65535;c[2415237]=65535;a[9660932]=a[9660932]|64;c[2388388]=0;a[1530616]=0;N=0;i=e;return N|0}}while(0);c[2415042]=0;N=1;i=e;return N|0}function dmZ(){var a=0,b=0,d=0,e=0;c[2113070]=0;c[2113068]=0;a=c[2112926]|0;if((a|0)!=0){gGr(a);c[2112926]=0}a=c[2420424]|0;if((a|0)!=0){gGr(a);c[2420424]=0}a=c[2433528]|0;if((a|0)!=0){gGr(a);c[2433528]=0}c[2113160]=0;a=c[2433592]|0;if((a|0)!=0){gGr(a);c[2433592]=0}a=c[2437644]|0;if((a|0)!=0){gGr(a);c[2437644]=0}a=c[2415042]|0;b=0;while(1){if((b|0)>=1024){d=70671;break}e=9638528+(b<<2)|0;if((c[e>>2]|0)==(a|0)){break}else{b=b+1|0}}if((d|0)==70671){c[2415042]=0;c[3541148]=0;return 0}gGr(a);c[e>>2]=0;c[2415042]=0;c[3541148]=0;return 0}function dm_(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;do{if((a[9624744]|0)==0){e=(c[2388388]|0)+1|0;c[2388388]=e;if((e|0)<=180){break}c[3528554]=0;f43(c[2433592]|0);e=c[3528554]|0;c[2113158]=c[9731360+(e<<2)>>2];a[9660796]=0;a[9660797]=0;a[9660786]=0;a[9660787]=0;c[2415191]=0;a[9660784]=a[9660784]|80;f=c[2433592]|0;g=c[f+(e*3148|0)+1068>>2]|0;do{if((g|0)==0){h=c[f+(e*3148|0)+3120>>2]|0;if((h|0)==0){i=0;j=0;break}k=gj[h&4095](-2)|0;h=c[3528554]|0;l=c[2433592]|0;m=c[l+(h*3148|0)+1068>>2]|0;n=(k&255)<<8;if((m|0)!=0){o=m;p=n;q=70698;break}m=c[l+(h*3148|0)+3120>>2]|0;if((m|0)==0){i=0;j=n;break}i=gj[m&4095](-1)|0;j=n}else{o=g;p=d[g+254|0]<<8;q=70698}}while(0);if((q|0)==70698){i=a[o+255|0]|0;j=p}g=i&255|j;c[2415188]=g;b[4830376]=g&65535;g=c[3528584]|0;a[g]=-1;a[g]=0;g=c[3527392]|0;e=c[3528554]|0;f=c[2433592]|0;n=0;m=0;while(1){h=g+((m<<8)+65536)|0;c[f+(e*3148|0)+48+(m<<2)>>2]=h;c[f+(e*3148|0)+48+(m+512<<2)>>2]=h;h=n+1&65535;if((h&65535)>31){break}else{n=h;m=h&65535}}m=f+(e*3148|0)|0;if((m|0)!=0){n=m;gGC(n|0,9660752,48)|0}c[9731360+(e<<2)>>2]=c[2113158];c[3528554]=-1;a[9660900]=a[9660900]|16;n=c[2437644]|0;m=c[n+1092>>2]|0;do{if((m|0)==0){g=c[n+3144>>2]|0;if((g|0)==0){r=0;s=0;break}h=gj[g&4095](-2)|0;g=c[2437644]|0;l=c[g+1092>>2]|0;k=(h&255)<<8;if((l|0)!=0){t=l;u=k;q=70709;break}l=c[g+3144>>2]|0;if((l|0)==0){r=0;s=k;break}r=gj[l&4095](-1)|0;s=k}else{t=m;u=d[m+254|0]<<8;q=70709}}while(0);if((q|0)==70709){r=a[t+255|0]|0;s=u}m=r&255|s;c[2415221]=m;b[4830442]=m&65535;a[9660920]=0;a[9660921]=0;a[9660928]=0;a[9660930]=0;a[9660931]=0;c[2415234]=0;gGz(9660901,0,5);c[2415235]=65535;c[2415237]=65535;a[9660932]=a[9660932]|64;c[2388388]=0;a[1530616]=0}else{m=c[2414750]|0;gGz(m|0,0,(c[2411794]|0)-m|0);c[3528554]=0;f43(c[2433592]|0);m=c[3528554]|0;c[2113158]=c[9731360+(m<<2)>>2];a[9660796]=0;a[9660797]=0;a[9660786]=0;a[9660787]=0;c[2415191]=0;a[9660784]=a[9660784]|80;n=c[2433592]|0;e=c[n+(m*3148|0)+1068>>2]|0;do{if((e|0)==0){f=c[n+(m*3148|0)+3120>>2]|0;if((f|0)==0){v=0;w=0;break}k=gj[f&4095](-2)|0;f=c[3528554]|0;l=c[2433592]|0;g=c[l+(f*3148|0)+1068>>2]|0;h=(k&255)<<8;if((g|0)!=0){x=g;y=h;q=70678;break}g=c[l+(f*3148|0)+3120>>2]|0;if((g|0)==0){v=0;w=h;break}v=gj[g&4095](-1)|0;w=h}else{x=e;y=d[e+254|0]<<8;q=70678}}while(0);if((q|0)==70678){v=a[x+255|0]|0;w=y}e=v&255|w;c[2415188]=e;b[4830376]=e&65535;e=c[3528584]|0;a[e]=-1;a[e]=0;e=c[3527392]|0;m=c[3528554]|0;n=c[2433592]|0;h=0;g=0;while(1){f=e+((g<<8)+65536)|0;c[n+(m*3148|0)+48+(g<<2)>>2]=f;c[n+(m*3148|0)+48+(g+512<<2)>>2]=f;f=h+1&65535;if((f&65535)>31){break}else{h=f;g=f&65535}}g=n+(m*3148|0)|0;if((g|0)!=0){h=g;gGC(h|0,9660752,48)|0}c[9731360+(m<<2)>>2]=c[2113158];c[3528554]=-1;a[9660900]=a[9660900]|16;h=c[2437644]|0;g=c[h+1092>>2]|0;do{if((g|0)==0){e=c[h+3144>>2]|0;if((e|0)==0){z=0;A=0;break}f=gj[e&4095](-2)|0;e=c[2437644]|0;l=c[e+1092>>2]|0;k=(f&255)<<8;if((l|0)!=0){B=l;C=k;q=70689;break}l=c[e+3144>>2]|0;if((l|0)==0){z=0;A=k;break}z=gj[l&4095](-1)|0;A=k}else{B=g;C=d[g+254|0]<<8;q=70689}}while(0);if((q|0)==70689){z=a[B+255|0]|0;A=C}g=z&255|A;c[2415221]=g;b[4830442]=g&65535;a[9660920]=0;a[9660921]=0;a[9660928]=0;a[9660930]=0;a[9660931]=0;c[2415234]=0;gGz(9660901,0,5);c[2415235]=65535;c[2415237]=65535;a[9660932]=a[9660932]|64;a[1530616]=0;c[2388388]=1}}while(0);A=9550752;c[A>>2]=-1;c[A+4>>2]=-1;A=0;z=-1;C=-1;B=-1;q=-1;do{z=((a[9634112+A|0]&1)<<A^z&255)&255;C=((a[9631896+A|0]&1)<<A^C&255)&255;B=((a[9629032+A|0]&1)<<A^B&255)&255;q=((a[9629824+A|0]&1)<<A^q&255)&255;A=A+1|0;}while((A|0)<8);a[9550756]=C;a[9550757]=B;a[9550758]=q;q=a[9635481]|0;a[9550752]=(q&255)>>>3;B=a[9635480]|0;a[9550753]=q<<2&28|(B&255)>>>6;a[9550754]=(B&255)>>>1&31;a[9550755]=a[9635482]&2|z&13|B<<4&16;if((a[c[2442902]|0]|0)!=0){a[9550756]=C|3}C=c[2113160]|0;if((C|0)>0){gGz(9731360,0,((C|0)>1?C<<2:4)|0)}c[2113158]=0;c[2113162]=0;c[2443988]=0;c[2444038]=0;C=0;B=0;L85199:while(1){z=B;while(1){if((z|0)>=100){break L85199}c[3528554]=0;f43(c[2433592]|0);c[2113158]=c[9731360+(c[3528554]<<2)>>2];D=z+1|0;q=f45(((D*25600|0|0)/100|0)-(c[2444038]|0)|0)|0;c[2113158]=(c[2113158]|0)+q;c[2444038]=(c[2444038]|0)+q;q=(z|0)==99;do{if(q){if((a[c[2432936]|0]|0)==0){break}f44(0)}}while(0);A=c[3528554]|0;w=(c[2433592]|0)+(A*3148|0)|0;if((w|0)!=0){v=w;gGC(v|0,9660752,48)|0}v=c[2113158]|0;c[9731360+(A<<2)>>2]=v;c[3528554]=-1;A=~~(+(v|0)*102400.0/25600.0);v=(A|0)>0;do{if(a[1530616]|0){if(!v){break}c[2443988]=A}else{if(v){w=f4D(A-(c[2443988]|0)|0)|0;c[2113162]=(c[2113162]|0)+w;c[2443988]=(c[2443988]|0)+w}if(!q){break}if((a[(c[2432936]|0)+1|0]|0)==0){break}f01()}}while(0);E=c[2112964]|0;if((E|0)==0){z=D}else{break}}z=a[9688]|0?5:0;UX(E+(C<<1<<1)|0,z);C=z+C|0;B=D}D=c[2112964]|0;do{if((D|0)!=0){B=a[9688]|0?534:0;if((B|0)==(C|0)){break}UX(D+(C<<1<<1)|0,B-C|0)}}while(0);if((c[2112968]|0)==0){return 0}dm$()|0;return 0}function dm$(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;if((a[9547784]|0)!=0){b=c[2406980]|0;f=c[3530118]|0;g=0;do{h=c[b+(g<<2)>>2]|0;c[f+(g<<2)>>2]=h>>8<<3&2016|h>>>3&31|h>>16<<8&63488;g=g+1|0;}while((g|0)<1280);a[9547784]=0}g=c[3528754]|0;f=c[2409006]|0;b=e[f>>1]|0;if((a[g]|0)==0){i=b+35|0;j=(e[f+2>>1]|0)+25|0}else{i=189-(b^1)|0;j=7-(e[f+2>>1]|0)|0}f=i&511;i=j&255;j=c[2386252]|0;b=c[2112926]|0;h=c[3530662]|0;k=c[2113068]|0;l=c[2113070]|0;m=0;do{n=(m<<3&504)-f|0;o=(n|0)<-7?n+512|0:n;n=(m>>6<<3)-i|0;p=(n|0)<-7?n+256|0:n;do{if((o|0)<(k|0)&(p|0)<(l|0)){n=d[j+(m+2048)|0]|0;q=n&1;r=q<<8|d[j+m|0];s=n>>>1&63|q<<6;if((a[g]|0)==0){Sj(b,r,o,p,s+64|0,2,0,h);break}else{Sp(b,r,280-o|0,216-p|0,s+64|0,2,0,h);break}}}while(0);m=m+1|0;}while((m|0)<2048);m=c[2394702]|0;if((a[m]|0)==0){dnb()}h=(a[g]|0)!=0?256:0;j=c[2386336]|0;l=c[3530898]|0;k=0;do{i=k+2|0;f=i<<5;p=k<<3;o=216-p|0;s=0;do{r=s-2|0;if((r&32|0)==0){t=r+f|0}else{t=(r<<5&992)+i|0}r=d[j+t|0]|h;q=a[j+(t+1024)|0]&63;n=s<<3;if((a[g]|0)==0){Sr(b,r,n,p,q,2,0,0,l)}else{Sr(b,r,280-n|0,o,q,2,0,0,l)}s=s+1|0;}while((s|0)<36);k=k+1|0;}while((k|0)<28);if((a[m]|0)!=1){u=c[3530118]|0;R8(u);return 0}dnb();u=c[3530118]|0;R8(u);return 0}function dm0(a,b){a=a|0;b=b|0;return 1}function dm1(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4391676+(b*112|0)>>2];c[a+104>>2]=c[4391680+(b*112|0)>>2];c[a+108>>2]=c[4391684+(b*112|0)>>2];d=0;return d|0}function dm2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=4391576+(b*112|0);e=0;return e|0}function dm3(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4393244+(b*112|0)>>2];c[a+104>>2]=c[4393248+(b*112|0)>>2];c[a+108>>2]=c[4393252+(b*112|0)>>2];d=0;return d|0}function dm4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=4393144+(b*112|0);e=0;return e|0}function dm5(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4390108+(b*112|0)>>2];c[a+104>>2]=c[4390112+(b*112|0)>>2];c[a+108>>2]=c[4390116+(b*112|0)>>2];d=0;return d|0}function dm6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=4390008+(b*112|0);e=0;return e|0}function dm7(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>40){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4986008+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dm8(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2916732+(b*112|0)>>2];c[a+104>>2]=c[2916736+(b*112|0)>>2];c[a+108>>2]=c[2916740+(b*112|0)>>2];d=0;return d|0}function dm9(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=2916632+(b*112|0);e=0;return e|0}function dna(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>49){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4048136+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dnb(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;e=c[2386510]|0;f=c[3528754]|0;g=c[2112926]|0;h=c[3530470]|0;i=c[3531034]|0;j=c[2113070]|0;k=c[2113068]|0;l=0;do{m=d[e+(l+6016)|0]|0;n=(d[e+(l+1921)|0]<<3&504)+768|0;o=(d[e+(l+6017)|0]<<8&256|d[e+(l+3969)|0])-71|0;p=m&1;q=m>>>1&1;r=m>>>2;s=r&1;t=m>>>3&1;u=(m<<1&256|d[e+(l+1920)|0])&((r|16777214)^1)&(t<<1^16777215);if((a[f]|0)==0){v=q;w=p}else{v=q^1;w=p^1}p=(505-(t<<4)-(d[e+(l+3968)|0]|0)&255)-32|0;q=v&-t;r=w&-s;m=(v|0)==0?0:240;x=(w|0)==0?m:m|15;m=0;do{y=((m^q)<<1)+u|0;z=p+(m<<4)|0;A=0;do{B=o+(A<<4)|0;C=y+(A^r)<<8;D=z;E=0;while(1){if((D|0)>-1&(D|0)<(j|0)){F=E<<4;G=ag(k,D)|0;H=B;I=0;while(1){do{if((H|0)>=0&(H|0)<(k|0)){J=d[h+((I+F^x)+C)|0]|n;if((a[i+(J+512)|0]|0)==-1){break}b[g+(G+H<<1)>>1]=J&65535}}while(0);J=I+1|0;if((J|0)<16){H=H+1|0;I=J}else{break}}}I=E+1|0;if((I|0)>=16){break}D=D+1|0;E=I}A=A+1|0;}while((A|0)<=(s|0));m=m+1|0;}while((m|0)<=(t|0));l=l+2|0;}while((l|0)<128);return}function dnc(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=b&65535;switch(e|0){case 16393:{a[c[3528752]|0]=d&1;return};case 16392:{b=d&255;a[c[2408948]|0]=d;f=b&240;g=b<<4&240;b=c[2407136]|0;h=c[3527390]|0;i=c[3528554]|0;j=c[2433592]|0;k=5;do{l=((a[b+(g|k|256)|0]|a[b+(k|f)|0])&255)<<12;m=k<<4;n=m&240;o=n&65535;p=m|15;if(o>>>0<=p>>>0){m=n;n=o;do{q=h+((n-o<<8)+l)|0;c[j+(i*3148|0)+48+(n<<2)>>2]=q;c[j+(i*3148|0)+48+(n+512<<2)>>2]=q;m=m+1&65535;n=m&65535;}while(n>>>0<=p>>>0)}k=k+1|0;}while((k|0)<16);return};case 16394:case 16395:case 16396:case 16397:{a[(c[2386726]|0)+(e-16394)|0]=d;return};case 16398:{a[c[3528330]|0]=d;return};default:{return}}}function dnd(b){b=b|0;var c=0;switch(b&65535|0){case 16393:{c=a[9550745]|0;break};case 16394:{c=a[9550746]|0;break};case 16395:{c=a[9635472]|0;break};case 16392:{c=a[9550744]|0;break};case 16396:{c=a[9635473]|0;break};default:{c=0}}return c|0}function dne(a,b){a=a|0;b=b|0;var c=0;c=a&65535;if((c|0)==40960|(c|0)==40961){lS(1,c&1,b);return}else if((c|0)==32768|(c|0)==32769){lS(0,c&1,b);return}else{return}}function dnf(b){b=b|0;var d=0;if(b<<16>>16!=-8192){d=0;return d|0}d=a[c[3528330]|0]|0;return d|0}function dng(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>28){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2223396+(b*112|0)>>2];c[a+104>>2]=c[2223400+(b*112|0)>>2];c[a+108>>2]=c[2223404+(b*112|0)>>2];d=0;return d|0}function dnh(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<29&(d|0)==0)){e=1;return e|0}c[a>>2]=2223296+(b*112|0);e=0;return e|0}function dni(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1187848+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dnj(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>46){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3380528+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dnk(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0;e=i;i=i+3360|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;B=e+1200|0;C=e+1312|0;D=e+1320|0;E=e+1432|0;F=e+1440|0;G=e+1552|0;H=e+1560|0;I=e+1672|0;J=e+1680|0;K=e+1792|0;L=e+1800|0;M=e+1912|0;N=e+1920|0;O=e+2032|0;P=e+2040|0;Q=e+2152|0;R=e+2160|0;S=e+2272|0;T=e+2280|0;U=e+2392|0;V=e+2400|0;W=e+2512|0;X=e+2520|0;Y=e+2632|0;Z=e+2640|0;_=e+2752|0;$=e+2760|0;aa=e+2872|0;ab=e+2880|0;ac=e+2992|0;ad=e+3e3|0;ae=e+3112|0;af=e+3120|0;ah=e+3232|0;ai=e+3240|0;aj=e+3352|0;c[2415040]=0;c[3527390]=0;c[2385964]=262144;c[3530896]=327680;c[3530660]=458752;c[3530468]=983040;c[2407136]=1507328;c[3530116]=1507840;c[2414748]=1509888;c[3527408]=1509888;c[2386508]=1517568;c[2386584]=1518080;c[2406586]=1518592;c[2406506]=1526784;c[2387242]=1530880;c[2386118]=1531904;c[2408948]=1533952;c[2386726]=1533953;c[3528752]=1533957;c[3528330]=1533958;c[2411792]=1533959;ak=0;while(1){if((ak|0)>=1024){break}al=9638528+(ak<<2)|0;if((c[al>>2]|0)==0){am=70918;break}else{ak=ak+1|0}}do{if((am|0)==70918){ak=gGq(1533959)|0;c[al>>2]=ak;if((ak|0)==0){break}c[2415040]=ak;gGz(ak|0,0,1533959);c[3527390]=ak;c[2385964]=ak+262144;c[3530896]=ak+327680;c[3530660]=ak+458752;c[3530468]=ak+983040;c[2407136]=ak+1507328;c[3530116]=ak+1507840;an=ak+1509888|0;c[2414748]=an;c[3527408]=an;c[2386508]=ak+1517568;c[2386584]=ak+1518080;c[2406586]=ak+1518592;c[2406506]=ak+1526784;c[2387242]=ak+1530880;c[2386118]=ak+1531904;c[2408948]=ak+1533952;c[2386726]=ak+1533953;c[3528752]=ak+1533957;c[3528330]=ak+1533958;an=ak+1533959|0;c[2411792]=an;c[2414340]=an;if((c[3542200]|0)==0){ao=1;i=e;return ao|0}an=ai+108|0;c[an>>2]=0;ap=ai+100|0;c[ap>>2]=0;aq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aq&16383](ai,0)|0;do{if((c[an>>2]|0)!=0){aq=c[ap>>2]|0;c[aj>>2]=9534384;ar=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ar&16383](aj,0,0)|0;if((aq|0)<1){ao=1;i=e;return ao|0}if((gzL(ak,0,0)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ak=(c[3527390]|0)+32768|0;if((c[3542200]|0)==0){ao=1;i=e;return ao|0}ap=af+108|0;c[ap>>2]=0;an=af+100|0;c[an>>2]=0;aq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aq&16383](af,1)|0;do{if((c[ap>>2]|0)!=0){aq=c[an>>2]|0;c[ah>>2]=9534384;ar=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ar&16383](ah,1,0)|0;if((aq|0)<1){ao=1;i=e;return ao|0}if((gzL(ak,0,1)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ak=(c[3527390]|0)+65536|0;if((c[3542200]|0)==0){ao=1;i=e;return ao|0}an=ad+108|0;c[an>>2]=0;ap=ad+100|0;c[ap>>2]=0;aq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aq&16383](ad,2)|0;do{if((c[an>>2]|0)!=0){aq=c[ap>>2]|0;c[ae>>2]=9534384;ar=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ar&16383](ae,2,0)|0;if((aq|0)<1){ao=1;i=e;return ao|0}if((gzL(ak,0,2)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ak=(c[3527390]|0)+98304|0;if((c[3542200]|0)==0){ao=1;i=e;return ao|0}ap=ab+108|0;c[ap>>2]=0;an=ab+100|0;c[an>>2]=0;aq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aq&16383](ab,3)|0;do{if((c[ap>>2]|0)!=0){aq=c[an>>2]|0;c[ac>>2]=9534384;ar=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ar&16383](ac,3,0)|0;if((aq|0)<1){ao=1;i=e;return ao|0}if((gzL(ak,0,3)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ak=(c[3527390]|0)+131072|0;if((c[3542200]|0)==0){ao=1;i=e;return ao|0}an=$+108|0;c[an>>2]=0;ap=$+100|0;c[ap>>2]=0;aq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aq&16383]($,4)|0;do{if((c[an>>2]|0)!=0){aq=c[ap>>2]|0;c[aa>>2]=9534384;ar=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ar&16383](aa,4,0)|0;if((aq|0)<1){ao=1;i=e;return ao|0}if((gzL(ak,0,4)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ak=(c[3527390]|0)+163840|0;if((c[3542200]|0)==0){ao=1;i=e;return ao|0}ap=Z+108|0;c[ap>>2]=0;an=Z+100|0;c[an>>2]=0;aq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aq&16383](Z,5)|0;do{if((c[ap>>2]|0)!=0){aq=c[an>>2]|0;c[_>>2]=9534384;ar=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ar&16383](_,5,0)|0;if((aq|0)<1){ao=1;i=e;return ao|0}if((gzL(ak,0,5)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ak=(c[3527390]|0)+196608|0;if((c[3542200]|0)==0){ao=1;i=e;return ao|0}an=X+108|0;c[an>>2]=0;ap=X+100|0;c[ap>>2]=0;aq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aq&16383](X,6)|0;do{if((c[an>>2]|0)!=0){aq=c[ap>>2]|0;c[Y>>2]=9534384;ar=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ar&16383](Y,6,0)|0;if((aq|0)<1){ao=1;i=e;return ao|0}if((gzL(ak,0,6)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ak=(c[3527390]|0)+229376|0;if((c[3542200]|0)==0){ao=1;i=e;return ao|0}ap=V+108|0;c[ap>>2]=0;an=V+100|0;c[an>>2]=0;aq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aq&16383](V,7)|0;do{if((c[ap>>2]|0)!=0){aq=c[an>>2]|0;c[W>>2]=9534384;ar=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ar&16383](W,7,0)|0;if((aq|0)<1){ao=1;i=e;return ao|0}if((gzL(ak,0,7)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ak=c[2385964]|0;if((c[3542200]|0)==0){ao=1;i=e;return ao|0}an=T+108|0;c[an>>2]=0;ap=T+100|0;c[ap>>2]=0;aq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aq&16383](T,8)|0;do{if((c[an>>2]|0)!=0){aq=c[ap>>2]|0;c[U>>2]=9534384;ar=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ar&16383](U,8,0)|0;if((aq|0)<1){ao=1;i=e;return ao|0}if((gzL(ak,0,8)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ak=c[3530896]|0;if((c[3542200]|0)==0){ao=1;i=e;return ao|0}ap=R+108|0;c[ap>>2]=0;an=R+100|0;c[an>>2]=0;aq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aq&16383](R,9)|0;do{if((c[ap>>2]|0)!=0){aq=c[an>>2]|0;c[S>>2]=9534384;ar=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ar&16383](S,9,0)|0;if((aq|0)<1){ao=1;i=e;return ao|0}if((gzL(ak,0,9)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ak=c[3530660]|0;if((c[3542200]|0)==0){ao=1;i=e;return ao|0}an=P+108|0;c[an>>2]=0;ap=P+100|0;c[ap>>2]=0;aq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aq&16383](P,10)|0;do{if((c[an>>2]|0)!=0){aq=c[ap>>2]|0;c[Q>>2]=9534384;ar=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ar&16383](Q,10,0)|0;if((aq|0)<1){ao=1;i=e;return ao|0}if((gzL(ak,0,10)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ak=(c[3530660]|0)+32768|0;if((c[3542200]|0)==0){ao=1;i=e;return ao|0}ap=N+108|0;c[ap>>2]=0;an=N+100|0;c[an>>2]=0;aq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aq&16383](N,11)|0;do{if((c[ap>>2]|0)!=0){aq=c[an>>2]|0;c[O>>2]=9534384;ar=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ar&16383](O,11,0)|0;if((aq|0)<1){ao=1;i=e;return ao|0}if((gzL(ak,0,11)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ak=(c[3530660]|0)+65536|0;if((c[3542200]|0)==0){ao=1;i=e;return ao|0}an=L+108|0;c[an>>2]=0;ap=L+100|0;c[ap>>2]=0;aq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aq&16383](L,12)|0;do{if((c[an>>2]|0)!=0){aq=c[ap>>2]|0;c[M>>2]=9534384;ar=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ar&16383](M,12,0)|0;if((aq|0)<1){ao=1;i=e;return ao|0}if((gzL(ak,0,12)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ak=(c[3530660]|0)+98304|0;if((c[3542200]|0)==0){ao=1;i=e;return ao|0}ap=J+108|0;c[ap>>2]=0;an=J+100|0;c[an>>2]=0;aq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aq&16383](J,13)|0;do{if((c[ap>>2]|0)!=0){aq=c[an>>2]|0;c[K>>2]=9534384;ar=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ar&16383](K,13,0)|0;if((aq|0)<1){ao=1;i=e;return ao|0}if((gzL(ak,0,13)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ak=(c[3530660]|0)+131072|0;if((c[3542200]|0)==0){ao=1;i=e;return ao|0}an=H+108|0;c[an>>2]=0;ap=H+100|0;c[ap>>2]=0;aq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aq&16383](H,14)|0;do{if((c[an>>2]|0)!=0){aq=c[ap>>2]|0;c[I>>2]=9534384;ar=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ar&16383](I,14,0)|0;if((aq|0)<1){ao=1;i=e;return ao|0}if((gzL(ak,0,14)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ak=(c[3530660]|0)+163840|0;if((c[3542200]|0)==0){ao=1;i=e;return ao|0}ap=F+108|0;c[ap>>2]=0;an=F+100|0;c[an>>2]=0;aq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aq&16383](F,15)|0;do{if((c[ap>>2]|0)!=0){aq=c[an>>2]|0;c[G>>2]=9534384;ar=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ar&16383](G,15,0)|0;if((aq|0)<1){ao=1;i=e;return ao|0}if((gzL(ak,0,15)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ak=(c[3530660]|0)+196608|0;if((c[3542200]|0)==0){ao=1;i=e;return ao|0}an=D+108|0;c[an>>2]=0;ap=D+100|0;c[ap>>2]=0;aq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aq&16383](D,16)|0;do{if((c[an>>2]|0)!=0){aq=c[ap>>2]|0;c[E>>2]=9534384;ar=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ar&16383](E,16,0)|0;if((aq|0)<1){ao=1;i=e;return ao|0}if((gzL(ak,0,16)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ak=(c[3530660]|0)+229376|0;if((c[3542200]|0)==0){ao=1;i=e;return ao|0}ap=B+108|0;c[ap>>2]=0;an=B+100|0;c[an>>2]=0;aq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aq&16383](B,17)|0;do{if((c[ap>>2]|0)!=0){aq=c[an>>2]|0;c[C>>2]=9534384;ar=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ar&16383](C,17,0)|0;if((aq|0)<1){ao=1;i=e;return ao|0}if((gzL(ak,0,17)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ak=c[3530468]|0;if((c[3542200]|0)==0){ao=1;i=e;return ao|0}an=z+108|0;c[an>>2]=0;ap=z+100|0;c[ap>>2]=0;aq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aq&16383](z,18)|0;do{if((c[an>>2]|0)!=0){aq=c[ap>>2]|0;c[A>>2]=9534384;ar=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ar&16383](A,18,0)|0;if((aq|0)<1){ao=1;i=e;return ao|0}if((gzL(ak,0,18)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ak=(c[3530468]|0)+32768|0;if((c[3542200]|0)==0){ao=1;i=e;return ao|0}ap=x+108|0;c[ap>>2]=0;an=x+100|0;c[an>>2]=0;aq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aq&16383](x,19)|0;do{if((c[ap>>2]|0)!=0){aq=c[an>>2]|0;c[y>>2]=9534384;ar=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ar&16383](y,19,0)|0;if((aq|0)<1){ao=1;i=e;return ao|0}if((gzL(ak,0,19)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ak=(c[3530468]|0)+65536|0;if((c[3542200]|0)==0){ao=1;i=e;return ao|0}an=v+108|0;c[an>>2]=0;ap=v+100|0;c[ap>>2]=0;aq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aq&16383](v,20)|0;do{if((c[an>>2]|0)!=0){aq=c[ap>>2]|0;c[w>>2]=9534384;ar=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ar&16383](w,20,0)|0;if((aq|0)<1){ao=1;i=e;return ao|0}if((gzL(ak,0,20)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ak=(c[3530468]|0)+98304|0;if((c[3542200]|0)==0){ao=1;i=e;return ao|0}ap=t+108|0;c[ap>>2]=0;an=t+100|0;c[an>>2]=0;aq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aq&16383](t,21)|0;do{if((c[ap>>2]|0)!=0){aq=c[an>>2]|0;c[u>>2]=9534384;ar=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ar&16383](u,21,0)|0;if((aq|0)<1){ao=1;i=e;return ao|0}if((gzL(ak,0,21)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ak=(c[3530468]|0)+131072|0;if((c[3542200]|0)==0){ao=1;i=e;return ao|0}an=r+108|0;c[an>>2]=0;ap=r+100|0;c[ap>>2]=0;aq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aq&16383](r,22)|0;do{if((c[an>>2]|0)!=0){aq=c[ap>>2]|0;c[s>>2]=9534384;ar=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ar&16383](s,22,0)|0;if((aq|0)<1){ao=1;i=e;return ao|0}if((gzL(ak,0,22)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ak=(c[3530468]|0)+163840|0;if((c[3542200]|0)==0){ao=1;i=e;return ao|0}ap=p+108|0;c[ap>>2]=0;an=p+100|0;c[an>>2]=0;aq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aq&16383](p,23)|0;do{if((c[ap>>2]|0)!=0){aq=c[an>>2]|0;c[q>>2]=9534384;ar=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ar&16383](q,23,0)|0;if((aq|0)<1){ao=1;i=e;return ao|0}if((gzL(ak,0,23)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ak=(c[3530468]|0)+196608|0;if((c[3542200]|0)==0){ao=1;i=e;return ao|0}an=n+108|0;c[an>>2]=0;ap=n+100|0;c[ap>>2]=0;aq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aq&16383](n,24)|0;do{if((c[an>>2]|0)!=0){aq=c[ap>>2]|0;c[o>>2]=9534384;ar=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ar&16383](o,24,0)|0;if((aq|0)<1){ao=1;i=e;return ao|0}if((gzL(ak,0,24)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ak=(c[3530468]|0)+229376|0;if((c[3542200]|0)==0){ao=1;i=e;return ao|0}ap=l+108|0;c[ap>>2]=0;an=l+100|0;c[an>>2]=0;aq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aq&16383](l,25)|0;do{if((c[ap>>2]|0)!=0){aq=c[an>>2]|0;c[m>>2]=9534384;ar=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ar&16383](m,25,0)|0;if((aq|0)<1){ao=1;i=e;return ao|0}if((gzL(ak,0,25)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ak=c[2407136]|0;if((c[3542200]|0)==0){ao=1;i=e;return ao|0}an=j+108|0;c[an>>2]=0;ap=j+100|0;c[ap>>2]=0;aq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aq&16383](j,26)|0;do{if((c[an>>2]|0)!=0){aq=c[ap>>2]|0;c[k>>2]=9534384;ar=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ar&16383](k,26,0)|0;if((aq|0)<1){ao=1;i=e;return ao|0}if((gzL(ak,0,26)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ak=(c[2407136]|0)+256|0;if((c[3542200]|0)==0){ao=1;i=e;return ao|0}ap=f+108|0;c[ap>>2]=0;an=f+100|0;c[an>>2]=0;aq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aq&16383](f,27)|0;do{if((c[ap>>2]|0)!=0){aq=c[an>>2]|0;c[g>>2]=9534384;ar=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ar&16383](g,27,0)|0;if((aq|0)<1){ao=1;i=e;return ao|0}if((gzL(ak,0,27)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ak=c[2407136]|0;an=0;while(1){ap=ak+an|0;a[ap]=a[ap]<<4&48;ap=ak+(an+256)|0;a[ap]=a[ap]&15;ap=an+1|0;if((ap|0)<256){an=ap}else{as=0;break}}while(1){if((as|0)>=1024){break}at=9638528+(as<<2)|0;if((c[at>>2]|0)==0){am=71036;break}else{as=as+1|0}}L85725:do{if((am|0)==71036){an=gGq(262144)|0;c[at>>2]=an;if((an|0)==0){break}gGz(an|0,0,262144);ak=c[3530896]|0;gGC(an|0,ak|0,32768)|0;ap=0;do{aq=ap<<6;gGz(ak+aq|0,0,64);ar=ap<<7;au=ar|4;av=0;while(1){aw=au+(c[608544+(av<<2)>>2]|0)|0;ax=(av<<3)+aq|0;ay=0;do{az=aw+(c[609552+(ay<<2)>>2]|0)|0;if(((d[an+((az|0)/8|0)|0]|0)&128>>>((az&7)>>>0)|0)!=0){az=ak+(ax+ay)|0;a[az]=a[az]|2}ay=ay+1|0;}while((ay|0)<8);ay=av+1|0;if((ay|0)<8){av=ay}else{aA=0;break}}do{av=ar+(c[608544+(aA<<2)>>2]|0)|0;au=(aA<<3)+aq|0;ay=0;do{ax=av+(c[609552+(ay<<2)>>2]|0)|0;if(((d[an+((ax|0)/8|0)|0]|0)&128>>>((ax&7)>>>0)|0)!=0){ax=ak+(au+ay)|0;a[ax]=a[ax]|1}ay=ay+1|0;}while((ay|0)<8);aA=aA+1|0;}while((aA|0)<8);ap=ap+1|0;}while((ap|0)<1024);ap=c[3530660]|0;gGC(an|0,ap|0,262144)|0;ak=0;do{aq=ak<<8;gGz(ap+aq|0,0,256);ar=ak<<9;ay=0;do{au=1<<3-ay;av=(c[961472+(ay<<2)>>2]|0)+ar|0;ax=0;do{aw=av+(c[608544+(ax<<2)>>2]|0)|0;az=(ax<<4)+aq|0;aB=0;do{aC=aw+(c[609552+(aB<<2)>>2]|0)|0;if(((d[an+((aC|0)/8|0)|0]|0)&128>>>((aC&7)>>>0)|0)!=0){aC=ap+(az+aB)|0;a[aC]=(d[aC]|0|au)&255}aB=aB+1|0;}while((aB|0)<16);ax=ax+1|0;}while((ax|0)<16);ay=ay+1|0;}while((ay|0)<4);ak=ak+1|0;}while((ak|0)<2048);ak=c[3530468]|0;gGC(an|0,ak|0,262144)|0;ap=0;while(1){ay=ap<<8;gGz(ak+ay|0,0,256);aq=0;do{ar=1<<3-aq;ax=(c[613280+(aq<<2)>>2]|0)+ay|0;au=0;do{av=ax+(c[609008+(au<<2)>>2]|0)|0;aB=(au<<4)+ay|0;az=0;do{aw=av+(c[597864+(az<<2)>>2]|0)|0;if(((d[an+((aw|0)/8|0)|0]|0)&128>>>((aw&7)>>>0)|0)!=0){aw=ak+(aB+az)|0;a[aw]=(d[aw]|0|ar)&255}az=az+1|0;}while((az|0)<16);au=au+1|0;}while((au|0)<16);aq=aq+1|0;}while((aq|0)<4);aq=ap+1|0;if((aq|0)<2048){ap=aq}else{aD=0;break}}while(1){if((aD|0)>=1024){break L85725}aE=9638528+(aD<<2)|0;if((c[aE>>2]|0)==(an|0)){break}else{aD=aD+1|0}}gGr(an);c[aE>>2]=0}}while(0);c[3528554]=-1;c[2113160]=1;ap=gGq(3148)|0;ak=ap;c[2433592]=ak;if((ap|0)!=0){gGz(ap|0,0,3148);c[ap+3120>>2]=3128;c[ap+3124>>2]=1840;c[ap+3128>>2]=136;c[ap+3132>>2]=1902;c[2432840]=0;aq=0;do{c[ak+48+(aq<<2)>>2]=0;aq=aq+1|0;}while((aq|0)<768);c[2113158]=0;c[2415198]=0;aq=c[2427044]|0;c[9681616+(aq<<3)>>2]=809272;c[9681620+(aq<<3)>>2]=0;c[2427044]=aq+1}c[3528554]=0;f43(ap);aq=c[3528554]|0;ak=9731360+(aq<<2)|0;ay=c[ak>>2]|0;c[2113158]=ay;au=c[3527408]|0;ar=c[2433592]|0;ax=0;az=0;while(1){aB=au+(az<<8)|0;c[ar+(aq*3148|0)+48+(az<<2)>>2]=aB;c[ar+(aq*3148|0)+48+(az+256<<2)>>2]=aB;c[ar+(aq*3148|0)+48+(az+512<<2)>>2]=aB;aB=ax+1&65535;if((aB&65535)>29){break}else{ax=aB;az=aB&65535}}az=c[2386508]|0;c[ar+(aq*3148|0)+168>>2]=az;c[ar+(aq*3148|0)+1192>>2]=az;c[ar+(aq*3148|0)+2216>>2]=az;ax=az+256|0;c[ar+(aq*3148|0)+172>>2]=ax;c[ar+(aq*3148|0)+1196>>2]=ax;c[ar+(aq*3148|0)+2220>>2]=ax;ax=c[2406586]|0;az=32;au=32;while(1){ap=ax+((au<<8)-8192)|0;c[ar+(aq*3148|0)+48+(au<<2)>>2]=ap;c[ar+(aq*3148|0)+48+(au+256<<2)>>2]=ap;c[ar+(aq*3148|0)+48+(au+512<<2)>>2]=ap;ap=az+1&65535;if((ap&65535)>63){break}else{az=ap;au=ap&65535}}au=c[2406506]|0;az=80;ax=80;while(1){c[ar+(aq*3148|0)+48+(ax+256<<2)>>2]=au+((ax<<8)-20480);ap=az+1&65535;if((ap&65535)>95){break}else{az=ap;ax=ap&65535}}ax=c[2387242]|0;c[ar+(aq*3148|0)+1520>>2]=ax;c[ar+(aq*3148|0)+1524>>2]=ax+256;c[ar+(aq*3148|0)+1528>>2]=ax+512;c[ar+(aq*3148|0)+1532>>2]=ax+768;c[ar+(aq*3148|0)+3120>>2]=1538;c[ar+(aq*3148|0)+3124>>2]=3066;ax=ar+(aq*3148|0)|0;if((ax|0)!=0){az=ax;gGC(az|0,9660752,48)|0}c[ak>>2]=ay;c[3528554]=-1;fwR(0);az=c[2439330]|0;ax=(az|0)==0;if(!ax){au=az;gGC(9706056,au|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];au=c[3528484]|0;c[2076596]=au;ap=c[2417276]|0;c[3541536]=ap;c[1836236]=0;aB=c[2385964]|0;av=0;aw=0;while(1){c[az+76+(aw<<2)>>2]=aB+(aw<<8);aC=av+1&65535;if((aC&65535)>127){aF=0;aG=0;break}else{av=aC;aw=aC&65535}}while(1){aw=aB+(aG<<8)|0;c[az+76+(aG+512<<2)>>2]=aw;c[az+76+(aG+768<<2)>>2]=aw;aw=aF+1&65535;if((aw&65535)>127){break}else{aF=aw;aG=aw&65535}}aB=c[2386118]|0;c[az+844>>2]=aB;aw=aB+256|0;c[az+848>>2]=aw;av=aB+512|0;c[az+852>>2]=av;ay=aB+768|0;c[az+856>>2]=ay;ak=aB+1024|0;c[az+860>>2]=ak;aq=aB+1280|0;c[az+864>>2]=aq;ar=aB+1536|0;c[az+868>>2]=ar;aC=aB+1792|0;c[az+872>>2]=aC;c[az+1868>>2]=aB;c[az+1872>>2]=aw;c[az+1876>>2]=av;c[az+1880>>2]=ay;c[az+1884>>2]=ak;c[az+1888>>2]=aq;c[az+1892>>2]=ar;c[az+1896>>2]=aC;c[az+2892>>2]=aB;c[az+3916>>2]=aB;c[az+2896>>2]=aw;c[az+3920>>2]=aw;c[az+2900>>2]=av;c[az+3924>>2]=av;c[az+2904>>2]=ay;c[az+3928>>2]=ay;c[az+2908>>2]=ak;c[az+3932>>2]=ak;c[az+2912>>2]=aq;c[az+3936>>2]=aq;c[az+2916>>2]=ar;c[az+3940>>2]=ar;c[az+2920>>2]=aC;c[az+3944>>2]=aC;c[az+4184>>2]=2198;c[az+4180>>2]=3228;if(!ax){aC=az;gGC(aC|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=au;c[2417276]=ap;c[1836236]=-1;Vr(2,4e6,0,3046,106,0);c[2438228]=3e6;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=681;h[745419]=.3;a[3203368]=1;h[745418]=.1;a[3203360]=1;h[745417]=.1;a[3203352]=1;h[745416]=.1;a[3203344]=1;h[745415]=.3;a[3203336]=1;h[745414]=.1;a[3203328]=1;h[745413]=.1;a[3203320]=1;h[745412]=.1;a[3203312]=1;aC=c[642608+(c[2436]<<2)>>2]|0;ar=c[aC+128>>2]|0;if((c[aC+52>>2]&4|0)==0){c[2113068]=ar;aq=c[aC+132>>2]|0;c[2113070]=aq;c[2443814]=ar;c[2440436]=aq;aH=ar;aI=aq}else{c[2113070]=ar;aq=c[aC+132>>2]|0;c[2113068]=aq;c[2440436]=ar;c[2443814]=aq;aH=aq;aI=ar}ar=ag(aH<<1,aI)|0;aq=gGq(ar)|0;c[2112926]=aq;if((aq|0)!=0){gGz(aq|0,0,ar|0)}a[9624736]=0;ar=c[2414748]|0;gGz(ar|0,0,(c[2411792]|0)-ar|0);c[3528554]=0;f43(c[2433592]|0);ar=c[3528554]|0;c[2113158]=c[9731360+(ar<<2)>>2];a[c[2408948]|0]=0;aq=c[2407136]|0;aC=c[3527390]|0;ak=c[2433592]|0;ay=5;do{av=((a[aq+(ay|256)|0]|a[aq+ay|0])&255)<<12;aw=ay<<4;aB=aw&240;aJ=aB&65535;aK=aw|15;if(aJ>>>0<=aK>>>0){aw=aB;aB=aJ;do{aL=aC+((aB-aJ<<8)+av)|0;c[ak+(ar*3148|0)+48+(aB<<2)>>2]=aL;c[ak+(ar*3148|0)+48+(aB+512<<2)>>2]=aL;aw=aw+1&65535;aB=aw&65535;}while(aB>>>0<=aK>>>0)}ay=ay+1|0;}while((ay|0)<16);a[9660796]=0;a[9660797]=0;a[9660786]=0;a[9660787]=0;c[2415191]=0;a[9660784]=a[9660784]|80;ay=c[ak+(ar*3148|0)+1068>>2]|0;do{if((ay|0)==0){aC=c[ak+(ar*3148|0)+3120>>2]|0;if((aC|0)==0){aM=0;aN=0;aO=ar;aP=ak;break}aq=gj[aC&4095](-2)|0;aC=c[3528554]|0;ap=c[2433592]|0;au=c[ap+(aC*3148|0)+1068>>2]|0;az=(aq&255)<<8;if((au|0)!=0){aQ=au;aR=az;aS=aC;aT=ap;am=71099;break}au=c[ap+(aC*3148|0)+3120>>2]|0;if((au|0)==0){aM=0;aN=az;aO=aC;aP=ap;break}ap=gj[au&4095](-1)|0;aM=ap;aN=az;aO=c[3528554]|0;aP=c[2433592]|0}else{aQ=ay;aR=(d[ay+254|0]|0)<<8;aS=ar;aT=ak;am=71099}}while(0);if((am|0)==71099){aM=a[aQ+255|0]|0;aN=aR;aO=aS;aP=aT}ak=aM&255|aN;c[2415188]=ak;b[4830376]=ak&65535;ak=aP+(aO*3148|0)|0;if((ak|0)!=0){ar=ak;gGC(ar|0,9660752,48)|0}c[9731360+(aO<<2)>>2]=c[2113158];c[3528554]=-1;ar=c[2439330]|0;ak=(ar|0)==0;if(!ak){ay=ar;gGC(9706056,ay|0,76)|0}ay=c[2438118]|0;c[2433530]=ay;az=c[3528484]|0;c[2076596]=az;ap=c[2417276]|0;c[3541536]=ap;c[1836236]=0;gGz(9706056,0,76);if(!ak){ak=ar;gGC(ak|0,9706056,76)|0}c[2438118]=ay;c[3528484]=az;c[2417276]=ap;c[1836236]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){aU=0}else{ao=0;i=e;return ao|0}while(1){lN(aU);mB(aU);ap=aU+1|0;if((ap|0)<(c[2385508]|0)){aU=ap}else{ao=0;break}}i=e;return ao|0}}while(0);c[2415040]=0;ao=1;i=e;return ao|0}function dnl(){var b=0,d=0,e=0,f=0;c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}c[2113160]=0;b=c[2433592]|0;if((b|0)!=0){gGr(b);c[2433592]=0}fwZ();b=c[3541518]|0;if((b|0)!=0){gGr(b|0);c[3541518]=0}if((c[2385508]|0)>0){c[2113008]=0;c[2076598]=0;c[2383582]=0}c[2438228]=0;c[2433526]=0;c[2406676]=0;c[3528472]=0;b=c[2406680]|0;if((b|0)!=0){gGr(b);c[2406680]=0}c[2385508]=0;c[2432978]=0;a[64240]=0;b=c[2415040]|0;d=0;while(1){if((d|0)>=1024){e=71220;break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==(b|0)){break}else{d=d+1|0}}if((e|0)==71220){c[2415040]=0;return 0}gGr(b);c[f>>2]=0;c[2415040]=0;return 0}function dnm(){var e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;do{if((a[9624736]|0)!=0){a[9624736]=0;e=c[2414748]|0;gGz(e|0,0,(c[2411792]|0)-e|0);c[3528554]=0;f43(c[2433592]|0);e=c[3528554]|0;c[2113158]=c[9731360+(e<<2)>>2];a[c[2408948]|0]=0;f=c[2407136]|0;g=c[3527390]|0;i=c[2433592]|0;j=5;do{k=((a[f+(j|256)|0]|a[f+j|0])&255)<<12;l=j<<4;m=l&240;n=m&65535;o=l|15;if(n>>>0<=o>>>0){l=m;m=n;do{p=g+((m-n<<8)+k)|0;c[i+(e*3148|0)+48+(m<<2)>>2]=p;c[i+(e*3148|0)+48+(m+512<<2)>>2]=p;l=l+1&65535;m=l&65535;}while(m>>>0<=o>>>0)}j=j+1|0;}while((j|0)<16);a[9660796]=0;a[9660797]=0;a[9660786]=0;a[9660787]=0;c[2415191]=0;a[9660784]=a[9660784]|80;j=c[i+(e*3148|0)+1068>>2]|0;do{if((j|0)==0){g=c[i+(e*3148|0)+3120>>2]|0;if((g|0)==0){q=0;r=0;s=e;t=i;break}f=gj[g&4095](-2)|0;g=c[3528554]|0;o=c[2433592]|0;m=c[o+(g*3148|0)+1068>>2]|0;l=(f&255)<<8;if((m|0)!=0){u=m;v=l;w=g;x=o;y=71230;break}m=c[o+(g*3148|0)+3120>>2]|0;if((m|0)==0){q=0;r=l;s=g;t=o;break}o=gj[m&4095](-1)|0;q=o;r=l;s=c[3528554]|0;t=c[2433592]|0}else{u=j;v=d[j+254|0]<<8;w=e;x=i;y=71230}}while(0);if((y|0)==71230){q=a[u+255|0]|0;r=v;s=w;t=x}i=q&255|r;c[2415188]=i;b[4830376]=i&65535;i=t+(s*3148|0)|0;if((i|0)!=0){e=i;gGC(e|0,9660752,48)|0}c[9731360+(s<<2)>>2]=c[2113158];c[3528554]=-1;e=c[2439330]|0;i=(e|0)==0;if(!i){j=e;gGC(9706056,j|0,76)|0}j=c[2438118]|0;c[2433530]=j;l=c[3528484]|0;c[2076596]=l;o=c[2417276]|0;c[3541536]=o;c[1836236]=0;gGz(9706056,0,76);if(!i){i=e;gGC(i|0,9706056,76)|0}c[2438118]=j;c[3528484]=l;c[2417276]=o;c[1836236]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){z=0}else{break}do{lN(z);mB(z);z=z+1|0;}while((z|0)<(c[2385508]|0))}}while(0);z=c[2385548]|0;if((z|0)>0){gGz(9752472,0,((z|0)>1?z<<2:4)|0)}c[2433530]=0;gGz(9550744,-1|0,3);z=0;s=-1;t=-1;r=-1;do{s=((a[9634104+z|0]&1)<<z^s&255)&255;t=((a[9631888+z|0]&1)<<z^t&255)&255;r=((a[9629816+z|0]&1)<<z^r&255)&255;z=z+1|0;}while((z|0)<8);a[9550744]=s;a[9550745]=t;a[9550746]=r;c[3528554]=0;f43(c[2433592]|0);c[2113158]=c[9731360+(c[3528554]<<2)>>2];r=c[2439330]|0;if((r|0)!=0){t=r;gGC(9706056,t|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;t=f45(6250)|0;c[2113158]=(c[2113158]|0)+t;Sb(0);a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0;t=f45(6250)|0;c[2113158]=(c[2113158]|0)+t;f44(1);f45(0)|0;a[9660787]=0;f45(0)|0;Sb(12500);a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0;t=f45(6250)|0;c[2113158]=(c[2113158]|0)+t;Sb(25e3);a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0;t=f45(6250)|0;c[2113158]=(c[2113158]|0)+t;f44(0);f45(0)|0;a[9660786]=0;f45(0)|0;Sb(37500);a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0;t=c[2438228]|0;r=gGS(-610271232,23841,t,(t|0)<0|0?-1:0)|0;t=r;Sb(5e4);r=c[2443830]|0;if((r|0)<1073676288){c[2443830]=r-t}r=c[2443831]|0;if((r|0)<1073676288){c[2443831]=r-t}r=(c[3528512]|0)-t|0;c[3528512]=(r|0)<0?0:r;r=c[2112964]|0;if((r|0)!=0){gg[c[3542122]&4095](r,a[9688]|0?534:0)}r=c[1836236]|0;t=c[9757320+(r<<2)>>2]|0;if((t|0)!=0){s=t;gGC(s|0,9706056,76)|0}c[9752472+(r<<2)>>2]=c[2433530];c[14113936+(r<<2)>>2]=c[2076596];c[9669104+(r<<2)>>2]=c[3541536];c[1836236]=-1;r=c[3528554]|0;s=(c[2433592]|0)+(r*3148|0)|0;if((s|0)!=0){t=s;gGC(t|0,9660752,48)|0}c[9731360+(r<<2)>>2]=c[2113158];c[3528554]=-1;if((c[2112968]|0)==0){A=c[2386584]|0;B=c[2386508]|0;gGC(A|0,B|0,512)|0;return 0}dnn()|0;A=c[2386584]|0;B=c[2386508]|0;gGC(A|0,B|0,512)|0;return 0}function dnn(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if((a[9547776]|0)!=0){b=c[2387242]|0;e=c[3530116]|0;f=0;do{g=a[b+f|0]|0;h=g&15;i=(d[b+(f|1)|0]|0)>>>4&255;c[e+(f>>1<<2)>>2]=i<<4&16|i>>>3|((g&255)>>>4&255)<<8&2048|(h<<4|h<<3)&224;f=f+2|0;}while((f|0)<1024)}dnv(1);dnv(3);dnw(0);f=c[2386584]|0;e=c[3528752]|0;b=c[2112926]|0;h=c[3530468]|0;g=508;do{i=d[f+(g|1)|0]|0;j=i<<3&1792|d[f+g|0];k=d[f+(g|2)|0]|0;l=d[f+(g|3)|0]|i<<8&256;m=i>>>2&7;n=i&2;if((a[e]|0)==0){o=0;p=n;q=l;r=k}else{o=1;p=n^2;q=496-l|0;r=240-k|0}k=q-80|0;l=r-8|0;do{if((p|0)==0){if(o){SJ(b,j,k,l,m,4,15,256,h);break}else{SH(b,j,k,l,m,4,15,256,h);break}}else{if(o){SN(b,j,k,l,m,4,15,256,h);break}else{SL(b,j,k,l,m,4,15,256,h);break}}}while(0);g=g-4|0;}while((g|0)>-1);dnv(2);dnw(1);R8(c[3530116]|0);return 0}function dno(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;f=i;i=i+96|0;g=f|0;h=f+16|0;j=f+32|0;k=f+48|0;l=f+64|0;m=f+80|0;if((e|0)!=0){c[e>>2]=169734}if((b&96|0)!=0){gGz(m|0,0,12);n=c[2414748]|0;c[m>>2]=n;c[m+4>>2]=(c[2411792]|0)-n;c[m+12>>2]=196728;n=c[2076592]|0;gj[n&4095](m)|0}if((b&64|0)!=0){m=l|0;if((c[2113160]|0)>0){n=l+7|0;l=k|0;o=k+4|0;p=k+12|0;q=j;r=j|0;s=j+4|0;t=j+12|0;u=h;v=h|0;w=h+4|0;x=h+12|0;y=g;z=g|0;A=g+4|0;B=g+12|0;C=0;do{D=c[2433592]|0;E=D+(C*3148|0)+40|0;F=c[E>>2]|0;gGC(m|0,614752,9)|0;a[n]=C+48&255;c[l>>2]=D+(C*3148|0);c[o>>2]=48;c[p>>2]=m;gj[c[2076592]&4095](k)|0;gGz(q|0,0,12);c[r>>2]=D+(C*3148|0)+3136;c[s>>2]=4;c[t>>2]=165288;gj[c[2076592]&4095](j)|0;gGz(u|0,0,12);c[v>>2]=D+(C*3148|0)+3140;c[w>>2]=4;c[x>>2]=501592;gj[c[2076592]&4095](h)|0;gGz(y|0,0,12);c[z>>2]=D+(C*3148|0)+3144;c[A>>2]=4;c[B>>2]=386080;gj[c[2076592]&4095](g)|0;c[E>>2]=F;C=C+1|0;}while((C|0)<(c[2113160]|0))}fw$(b);Vx(b,e)}c[3528554]=0;f43(c[2433592]|0);e=c[3528554]|0;b=9731360+(e<<2)|0;C=c[b>>2]|0;c[2113158]=C;g=d[c[2408948]|0]|0;B=g&240;A=g<<4&240;g=c[2407136]|0;z=c[3527390]|0;y=c[2433592]|0;h=5;do{x=((a[g+(A|h|256)|0]|a[g+(h|B)|0])&255)<<12;w=h<<4;v=w&240;u=v&65535;j=w|15;if(u>>>0<=j>>>0){w=v;v=u;do{t=z+((v-u<<8)+x)|0;c[y+(e*3148|0)+48+(v<<2)>>2]=t;c[y+(e*3148|0)+48+(v+512<<2)>>2]=t;w=w+1&65535;v=w&65535;}while(v>>>0<=j>>>0)}h=h+1|0;}while((h|0)<16);h=y+(e*3148|0)|0;if((h|0)==0){c[b>>2]=C;c[3528554]=-1;i=f;return 0}e=h;gGC(e|0,9660752,48)|0;c[b>>2]=C;c[3528554]=-1;i=f;return 0}function dnp(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>28){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2220148+(b*112|0)>>2];c[a+104>>2]=c[2220152+(b*112|0)>>2];c[a+108>>2]=c[2220156+(b*112|0)>>2];d=0;return d|0}function dnq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<29&(d|0)==0)){e=1;return e|0}c[a>>2]=2220048+(b*112|0);e=0;return e|0}function dnr(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>28){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2216900+(b*112|0)>>2];c[a+104>>2]=c[2216904+(b*112|0)>>2];c[a+108>>2]=c[2216908+(b*112|0)>>2];d=0;return d|0}function dns(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<29&(d|0)==0)){e=1;return e|0}c[a>>2]=2216800+(b*112|0);e=0;return e|0}function dnt(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>28){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2358668+(b*112|0)>>2];c[a+104>>2]=c[2358672+(b*112|0)>>2];c[a+108>>2]=c[2358676+(b*112|0)>>2];d=0;return d|0}function dnu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<29&(d|0)==0)){e=1;return e|0}c[a>>2]=2358568+(b*112|0);e=0;return e|0}function dnv(e){e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;f=c[2386726]|0;g=c[595256+(e<<2)>>2]|0;h=-8-(d[f+3|0]<<8&768|d[f+2|0])|0;i=-80-(d[f+1|0]<<8&768|d[f])|0;f=e>>1;e=c[2113070]|0;j=c[2113068]|0;k=c[2406586]|0;l=c[3530660]|0;m=c[3528752]|0;n=c[2112926]|0;o=0;do{p=(o<<4&1008)+h|0;q=(p|0)<-15?p+1024|0:p;p=(o>>6<<4)+i|0;r=(p|0)<-15?p+1024|0:p;L86022:do{if((q|0)<(e|0)&(r|0)<(j|0)){p=o<<1;s=d[k+p|0]|0;if((f|0)!=(s>>>4&1|0)){break}t=s>>>5<<4;u=(s&8|0)==0?0:240;v=(d[k+(p|1)|0]|s<<8&1792)<<8;if((a[m]|0)==0){w=q;x=r;y=u}else{w=224-q|0;x=336-r|0;y=u^255}u=w;s=0;while(1){L86030:do{if((u|0)>-1&(u|0)<(e|0)){p=ag(j,u)|0;z=s<<4;A=x;B=0;while(1){do{if((A|0)>-1&(A|0)<(j|0)){C=d[l+(((B|z)^y)+v)|0]|0;if((1<<C&g|0)!=0){break}b[n+(A+p<<1)>>1]=(t|C|128)&65535}}while(0);C=B+1|0;if((C|0)>=16){break L86030}A=A+1|0;B=C}}}while(0);B=s+1|0;if((B|0)>=16){break L86022}u=u+1|0;s=B}}}while(0);o=o+1|0;}while((o|0)<4096);return}function dnw(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=c[2406506]|0;f=c[3528752]|0;g=c[3530896]|0;h=c[2112926]|0;i=c[2113068]|0;j=c[2113070]|0;if((b|0)==0){k=0;do{l=k<<3&248;m=k>>5<<3;n=m-80|0;o=l-8|0;do{if((n|0)>-16&(n|0)<(i|0)&(o|0)<(j|0)){p=k<<1;q=d[e+p|0]|0;r=q<<8&768|d[e+(p|1)|0];p=q>>>2&15;if((q&64|0)!=0){break}if((a[f]|0)==0){Sr(h,r,n,o,p,2,3,448,g);break}else{Sx(h,r,344-m|0,240-l|0,p,2,3,448,g);break}}}while(0);k=k+1|0;}while((k|0)<2048);return}else{k=0;do{l=k<<3&248;m=k>>5<<3;o=m-80|0;n=l-8|0;do{if((o|0)>-16&(o|0)<(i|0)&(n|0)<(j|0)){p=k<<1;r=d[e+p|0]|0;q=r<<8&768|d[e+(p|1)|0];p=r>>>2&15;if((r>>>6&1|0)!=(b|0)){break}if((a[f]|0)==0){Sj(h,q,o,n,p,2,448,g);break}else{Sp(h,q,424-m|0,240-l|0,p,2,448,g);break}}}while(0);k=k+1|0;}while((k|0)<2048);return}}function dnx(a){a=a|0;return(ag((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0,a)|0)/3e6|0|0}function dny(){return+(+((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)/3.0e6)}function dnz(e,f){e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;if((e&16775168|0)==11534336){b[(c[2443622]|0)+(e&2047)>>1]=f;g=e>>>1&1023;h=f&65535;i=h>>>8&15;j=h>>>4&15;k=h&15;h=i<<4|i;i=j<<4|j;j=k<<4|k;c[(c[2406978]|0)+(g<<2)>>2]=i<<8|j|h<<16;c[(c[3530114]|0)+(g<<2)>>2]=i<<3&2016|j>>>3|h<<8&63488;return}if((e|0)==12582936){c[2438056]=f&65535;return}else if((e|0)==12582940){c[3528328]=f&255;h=c[2439330]|0;if((h|0)!=0){j=h;gGC(9706056,j|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;j=(c[2433530]|0)+12|0;c[2433530]=j;h=c[1836236]|0;i=c[9757320+(h<<2)>>2]|0;if((i|0)!=0){g=i;gGC(g|0,9706056,76)|0}c[9752472+(h<<2)>>2]=j;c[14113936+(h<<2)>>2]=c[2076596];c[9669104+(h<<2)>>2]=c[3541536];c[1836236]=-1;return}else if((e|0)==12582932){c[2438054]=f&65535;return}else if((e|0)==12582942){if((c[2406618]|0)!=3){return}e=c[2112932]|0;f=c[e+65472>>2]|0;if(f>>>0>9){l=a[f+2|0]|0;m=e;n=f}else{h=gj[c[e+196608+(f<<2)>>2]&4095](16760835)|0;f=c[2112932]|0;l=h;m=f;n=c[f+65472>>2]|0}if(n>>>0>9){o=d[n+5|0]<<8|d[n+4|0];p=m;q=n}else{f=gj[c[m+196688+(n<<2)>>2]&4095](16760836)|0;n=c[2112932]|0;o=f;p=n;q=c[n+65472>>2]|0}if(q>>>0>9){r=a[q+7|0]|0;s=p}else{n=gj[c[p+196608+(q<<2)>>2]&4095](16760838)|0;r=n;s=c[2112932]|0}n=c[607272+((r&255)*40|0)+(((o&65535)>>>8)+((l&255)<<1)<<2)>>2]|0;l=c[s+65476>>2]|0;if(l>>>0>9){t=a[l+645|0]|0}else{t=gj[c[s+196608+(l<<2)>>2]&4095](16762500)|0}l=t&255;if((l|0)==1){t=n*12302|0;s=t+112360|0;o=(n*624|0)+93180|0;r=c[2112932]|0;q=c[r+131008>>2]|0;if(q>>>0>9){a[q+28|0]=o>>>16&255;a[q+29|0]=o>>>24&255;a[q+30|0]=o&255;a[q+31|0]=o>>>8&255;u=r}else{gg[c[r+196808+(q<<2)>>2]&4095](16760860,o);u=c[2112932]|0}o=t+112488|0;q=c[u+131008>>2]|0;if(q>>>0>9){a[q+32|0]=o>>>16&255;a[q+33|0]=o>>>24&255;a[q+34|0]=o&255;a[q+35|0]=o>>>8&255;v=u}else{gg[c[u+196808+(q<<2)>>2]&4095](16760864,o);v=c[2112932]|0}o=c[v+131008>>2]|0;if(o>>>0>9){a[o+36|0]=s>>>16&255;a[o+37|0]=s>>>24&255;a[o+38|0]=s&255;a[o+39|0]=s>>>8&255;w=v}else{gg[c[v+196808+(o<<2)>>2]&4095](16760868,s);w=c[2112932]|0}s=t+112494|0;o=c[w+131008>>2]|0;if(o>>>0>9){a[o+40|0]=s>>>16&255;a[o+41|0]=s>>>24&255;a[o+42|0]=s&255;a[o+43|0]=s>>>8&255;x=w}else{gg[c[w+196808+(o<<2)>>2]&4095](16760872,s);x=c[2112932]|0}s=t+112502|0;o=c[x+131008>>2]|0;if(o>>>0>9){a[o+44|0]=s>>>16&255;a[o+45|0]=s>>>24&255;a[o+46|0]=s&255;a[o+47|0]=s>>>8&255;y=x}else{gg[c[x+196808+(o<<2)>>2]&4095](16760876,s);y=c[2112932]|0}s=t+112886|0;o=c[y+131008>>2]|0;if(o>>>0>9){a[o+48|0]=s>>>16&255;a[o+49|0]=s>>>24&255;a[o+50|0]=s&255;a[o+51|0]=s>>>8&255;z=y}else{gg[c[y+196808+(o<<2)>>2]&4095](16760880,s);z=c[2112932]|0}s=t+113142|0;o=c[z+131008>>2]|0;if(o>>>0>9){a[o+52|0]=s>>>16&255;a[o+53|0]=s>>>24&255;a[o+54|0]=s&255;a[o+55|0]=s>>>8&255;A=z}else{gg[c[z+196808+(o<<2)>>2]&4095](16760884,s);A=c[2112932]|0}s=t+113270|0;o=c[A+131008>>2]|0;if(o>>>0>9){a[o+56|0]=s>>>16&255;a[o+57|0]=s>>>24&255;a[o+58|0]=s&255;a[o+59|0]=s>>>8&255;B=A}else{gg[c[A+196808+(o<<2)>>2]&4095](16760888,s);B=c[2112932]|0}s=t+113398|0;o=c[B+131008>>2]|0;if(o>>>0>9){a[o+60|0]=s>>>16&255;a[o+61|0]=s>>>24&255;a[o+62|0]=s&255;a[o+63|0]=s>>>8&255;C=B}else{gg[c[B+196808+(o<<2)>>2]&4095](16760892,s);C=c[2112932]|0}s=t+114422|0;o=c[C+131008>>2]|0;if(o>>>0>9){a[o+64|0]=s>>>16&255;a[o+65|0]=s>>>24&255;a[o+66|0]=s&255;a[o+67|0]=s>>>8&255;D=C}else{gg[c[C+196808+(o<<2)>>2]&4095](16760896,s);D=c[2112932]|0}s=t+115446|0;o=c[D+131008>>2]|0;if(o>>>0>9){a[o+68|0]=s>>>16&255;a[o+69|0]=s>>>24&255;a[o+70|0]=s&255;a[o+71|0]=s>>>8&255;E=D}else{gg[c[D+196808+(o<<2)>>2]&4095](16760900,s);E=c[2112932]|0}s=t+118518|0;o=c[E+131008>>2]|0;if(o>>>0>9){a[o+72|0]=s>>>16&255;a[o+73|0]=s>>>24&255;a[o+74|0]=s&255;a[o+75|0]=s>>>8&255;F=E}else{gg[c[E+196808+(o<<2)>>2]&4095](16760904,s);F=c[2112932]|0}s=t+121590|0;t=c[F+131008>>2]|0;if(t>>>0>9){a[t+76|0]=s>>>16&255;a[t+77|0]=s>>>24&255;a[t+78|0]=s&255;a[t+79|0]=s>>>8&255;G=F}else{gg[c[F+196808+(t<<2)>>2]&4095](16760908,s);G=c[2112932]|0}s=n*96|0;t=s+103752|0;F=c[G+131008>>2]|0;if(F>>>0>9){a[F+80|0]=t>>>16&255;a[F+81|0]=t>>>24&255;a[F+82|0]=t&255;a[F+83|0]=t>>>8&255;H=G}else{gg[c[G+196808+(F<<2)>>2]&4095](16760912,t);H=c[2112932]|0}t=s+103800|0;s=c[H+131008>>2]|0;if(s>>>0>9){a[s+84|0]=t>>>16&255;a[s+85|0]=t>>>24&255;a[s+86|0]=t&255;a[s+87|0]=t>>>8&255;return}else{gg[c[H+196808+(s<<2)>>2]&4095](16760916,t);return}}else if((l|0)==2){t=(c[607472+(n<<2)>>2]|0)+192|0;s=c[607432+(n<<2)>>2]|0;n=t&65535;H=c[2112932]|0;F=c[H+131012>>2]|0;if(F>>>0>9){a[F+640|0]=t&255;a[F+641|0]=(n&65535)>>>8&255;I=H}else{gg[c[H+196728+(F<<2)>>2]&4095](16762496,n);I=c[2112932]|0}n=s&65535;F=c[I+131012>>2]|0;if(F>>>0>9){a[F+642|0]=s&255;a[F+643|0]=(n&65535)>>>8&255;J=I}else{gg[c[I+196728+(F<<2)>>2]&4095](16762498,n);J=c[2112932]|0}n=c[J+131008>>2]|0;if(n>>>0>9){a[n+12|0]=-64;a[n+13|0]=0;K=J}else{gg[c[J+196728+(n<<2)>>2]&4095](16760844,192);K=c[2112932]|0}n=c[K+131008>>2]|0;if(n>>>0>9){a[n+14|0]=0;a[n+15|0]=0}else{gg[c[K+196728+(n<<2)>>2]&4095](16760846,0)}c[2438054]=t;c[2438056]=s;return}else if((l|0)==4){l=c[2112932]|0;s=c[l+65472>>2]|0;if(s>>>0>9){L=a[s+17|0]|0;M=l}else{t=gj[c[l+196608+(s<<2)>>2]&4095](16760848)|0;L=t;M=c[2112932]|0}t=(L&255)+1&3;L=t&255;s=c[M+131008>>2]|0;if(s>>>0>9){a[s+17|0]=L}else{gg[c[M+196648+(s<<2)>>2]&4095](16760848,L)}if((t|0)!=0){return}t=c[2112932]|0;L=c[t+65476>>2]|0;if(L>>>0>9){N=d[L+643|0]<<8|d[L+642|0];O=t}else{s=gj[c[t+196688+(L<<2)>>2]&4095](16762498)|0;N=s;O=c[2112932]|0}s=N&65535;N=c[O+65472>>2]|0;if(N>>>0>9){P=d[N+15|0]<<8|d[N+14|0]}else{P=gj[c[O+196688+(N<<2)>>2]&4095](16760846)|0}if(P<<16>>16==512){Q=0;R=s-512|0}else{Q=P+1&65535;R=s+1|0}s=R&65535;P=c[2112932]|0;N=c[P+131012>>2]|0;if(N>>>0>9){a[N+642|0]=R&255;a[N+643|0]=(s&65535)>>>8&255;S=P}else{gg[c[P+196728+(N<<2)>>2]&4095](16762498,s);S=c[2112932]|0}s=c[S+131008>>2]|0;if(s>>>0>9){a[s+14|0]=Q&255;a[s+15|0]=(Q&65535)>>>8&255}else{gg[c[S+196728+(s<<2)>>2]&4095](16760846,Q)}c[2438056]=R;return}else{return}}else{return}}function dnA(a,b){a=a|0;b=b|0;if((a|0)!=12582939){return}a=b&255;c[2385306]=a;c[3528750]=a&4;return}function dnB(a){a=a|0;var c=0;switch(a|0){case 12582914:{c=b[4774832]|0;break};case 12582920:{c=b[4775036]|0;break};case 12582912:{c=b[4774840]|0;break};case 12582926:{c=-1;break};case 12582924:{c=b[4774864]|0;break};case 12582916:{c=b[4774828]|0;break};case 12582922:{c=b[4774940]|0;break};case 12582918:{c=b[4774824]|0;break};default:{c=0}}return c|0}function dnC(a){a=a|0;var b=0;switch(a|0){case 12582922:case 12582923:{b=(e[4774940]|0)>>>((a<<3&8^8)>>>0)&255;return b|0};case 12582926:case 12582927:{b=-1;return b|0};case 12582918:case 12582919:{b=(e[4774824]|0)>>>((a<<3&8^8)>>>0)&255;return b|0};case 12582914:case 12582915:{b=(e[4774832]|0)>>>((a<<3&8^8)>>>0)&255;return b|0};case 12582912:case 12582913:{b=(e[4774840]|0)>>>((a<<3&8^8)>>>0)&255;return b|0};case 12582916:case 12582917:{b=(e[4774828]|0)>>>((a<<3&8^8)>>>0)&255;return b|0};case 12582920:case 12582921:{b=(e[4775036]|0)>>>((a<<3&8^8)>>>0)&255;return b|0};case 12582924:case 12582925:{b=(e[4774864]|0)>>>((a<<3&8^8)>>>0)&255;return b|0};default:{b=0;return b|0}}return 0}function dnD(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((e|0)==57344){c[2113304]=d&255;return}else if((e|0)==57345){e=c[2113304]|0;a[14168504+e|0]=d;mv(0,e,d&255);return}else{return}}function dnE(a){a=a|0;var b=0,d=0;b=a&65535;if((b|0)==57345){d=c[(c[3531464]|0)+4240>>2]&255}else if((b|0)==51200){d=c[3528328]&255}else{d=0}return d|0}function dnF(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=a&255;if((d|0)==2){a=(b&255)<<15;c[2443736]=a+32768;e=c[3529128]|0;f=c[9757320+(c[1836236]<<2)>>2]|0;g=128;h=128;while(1){c[f+76+(h<<2)>>2]=e+((h<<8)+a);i=g+1&65535;if((i&65535)>255){break}else{g=i;h=i&65535}}h=(c[2443736]|0)-32768|0;g=128;a=128;while(1){i=e+(h+(a<<8))|0;c[f+76+(a+512<<2)>>2]=i;c[f+76+(a+768<<2)>>2]=i;i=g+1&65535;if((i&65535)>255){break}else{g=i;a=i&65535}}return}else if((d|0)==1){a=b&255;c[2416346]=a&128;c[2415126]=9665376;if((c[2416348]|0)==4){j=a&15}else{j=a<<1&14}c[2416344]=j;c[2415126]=9665376;j=(c[2416347]|0)!=0;a=c[2416345]|0;if(j|(a|0)==1){k=a}else{c[2416345]=1;k=1}c[2415126]=9665376;if(j|(k|0)==0){return}c[2416345]=0;UC(1);return}else if((d|0)==0){d=b&255;c[2415540]=d&128;c[2415126]=9662152;if((c[2415542]|0)==4){l=d&15}else{l=d<<1&14}c[2415538]=l;c[2415126]=9662152;l=(c[2415541]|0)!=0;d=c[2415539]|0;if(l|(d|0)==1){m=d}else{c[2415539]=1;m=1}c[2415126]=9662152;if(l|(m|0)==0){return}c[2415539]=0;UC(0);return}else{return}}function dnG(b){b=b|0;var d=0;if((b&255)!=1){d=0;return d|0}a[9706117]=0;d=c[3528328]&255;return d|0}function dnH(b){b=b|0;a[9706117]=(b|0)!=0|0;return}function dnI(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>43){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[627268+(b*112|0)>>2];c[a+104>>2]=c[627272+(b*112|0)>>2];c[a+108>>2]=c[627276+(b*112|0)>>2];d=0;return d|0}function dnJ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<44&(d|0)==0)){e=1;return e|0}c[a>>2]=627168+(b*112|0);e=0;return e|0}function dnK(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>29){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7140592+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dnL(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>60){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=635144+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dnM(){return dn4(1)|0}function dnN(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0;a=c[3531464]|0;c[a+44344>>2]=0;c[a+44348>>2]=0;if((a|0)!=0){gGr(a);c[3531464]=0}a=c[2406684]|0;if((a|0)!=0){gGr(a);c[2406684]=0}if((c[2392]|0)>=0){a=0;do{b=14130368+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}b=14130384+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}a=a+1|0;}while((a|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;fwZ();c[2415126]=9662152;a=c[2408988]|0;if((a|0)!=0){gGz(9662152,0,3224);b=a;a=0;while(1){if((a|0)>=1024){break}e=9638528+(a<<2)|0;if((c[e>>2]|0)==(b|0)){f=71604;break}else{a=a+1|0}}if((f|0)==71604){gGr(b);c[e>>2]=0}c[2408988]=0}c[2415126]=9665376;e=c[2408989]|0;if((e|0)!=0){gGz(9665376,0,3224);b=e;e=0;while(1){if((e|0)>=1024){break}g=9638528+(e<<2)|0;if((c[g>>2]|0)==(b|0)){f=71610;break}else{e=e+1|0}}if((f|0)==71610){gGr(b);c[g>>2]=0}c[2408989]=0}c[2406618]=0;c[2113070]=0;c[2113068]=0;g=c[2112926]|0;if((g|0)!=0){gGr(g);c[2112926]=0}g=c[2426794]|0;b=0;while(1){if((b|0)>=1024){f=71620;break}h=9638528+(b<<2)|0;if((c[h>>2]|0)==(g|0)){break}else{b=b+1|0}}if((f|0)==71620){c[2426794]=0;c[2438054]=0;c[2438056]=0;c[3528328]=0;c[3528750]=0;c[2385306]=0;c[2443736]=0;return 0}gGr(g);c[h>>2]=0;c[2426794]=0;c[2438054]=0;c[2438056]=0;c[3528328]=0;c[3528750]=0;c[2385306]=0;c[2443736]=0;return 0}function dnO(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;if((a[9624728]|0)!=0){a[9624728]=0;e=c[2414746]|0;gGz(e|0,0,(c[2411790]|0)-e|0);c[2438054]=0;c[2438056]=0;c[3528328]=0;c[3528750]=0;c[2385306]=0;c[2443736]=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060]}RI();e=c[2394]|0;f=c[14130368+(e<<2)>>2]|0;if((f|0)!=0){gGC(f|0,9104152,280)|0}c[8452240+(e<<2)>>2]=c[2113054];c[2394]=-1;e=c[2439330]|0;f=(e|0)==0;if(!f){g=e;gGC(9706056,g|0,76)|0}g=c[2438118]|0;c[2433530]=g;h=c[3528484]|0;c[2076596]=h;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);if(!f){f=e;gGC(f|0,9706056,76)|0}c[2438118]=g;c[3528484]=h;c[2417276]=i;c[1836236]=-1;i=c[2439331]|0;h=(i|0)==0;if(!h){g=i;gGC(9706056,g|0,76)|0}g=c[2438119]|0;c[2433530]=g;f=c[3528485]|0;c[2076596]=f;e=c[2417277]|0;c[3541536]=e;c[1836236]=1;gGz(9706056,0,76);if(!h){h=i;gGC(h|0,9706056,76)|0}c[2438119]=g;c[3528485]=f;c[2417277]=e;c[1836236]=-1;mx(0);UA()}e=c[2392]|0;if((e|0)>=0){gGz(8452240,0,((e|0)>0?(e<<2)+4|0:4)|0)}c[2113054]=0;e=c[2385548]|0;if((e|0)>0){gGz(9752472,0,((e|0)>1?e<<2:4)|0)}c[2433530]=0;b[4775036]=d[9635464]<<8|d[9635465];b[4774940]=d[9635467]|d[9635466]<<4|-2048;b[4774864]=-129;b[4774840]=-1;b[4774832]=-1;b[4774828]=-1;b[4774824]=-1;e=0;f=-129;g=-1;h=-1;i=-1;do{f=((a[9634088+e|0]&1)<<e^f&65535)&65535;g=((a[9631872+e|0]&1)<<e^g&65535)&65535;h=((a[9629800+e|0]&1)<<e^h&65535)&65535;i=((a[9629016+e|0]&1)<<e^i&65535)&65535;e=e+1|0;}while((e|0)<16);b[4774864]=f;b[4774840]=g;b[4774832]=h;b[4774828]=i;if((h&3)==0){i=h|3;b[4774832]=i;j=i}else{j=h}if((j&12)==0){h=j|12;b[4774832]=h;k=h}else{k=j}if((k&768)==0){j=k|768;b[4774832]=j;l=j}else{l=k}if((l&3072)==0){b[4774832]=l|3072}l=c[2406618]|0;if((l|0)==4|(l|0)==1){b[4774828]=(c[606536+((d[9628785]<<1&2|a[9628784]&1|d[9628786]<<2&4)<<2)>>2]<<8|c[606536+((d[9629017]<<1&2|a[9629016]&1|d[9629018]<<2&4)<<2)>>2])&65535;b[4774824]=(c[606536+((d[9628793]<<1&2|a[9628792]&1|d[9628794]<<2&4)<<2)>>2]<<8|c[606536+((d[9629025]<<1&2|a[9629024]&1|d[9629026]<<2&4)<<2)>>2])&65535}l=c[2438]|0;k=l;j=(l|0)<0|0?-1:0;l=gGU(k,j,8e6,0)|0;h=gGS(l,K,15360,0)|0;l=h;h=gGU(k,j,3579545,0)|0;j=gGS(h,K,15360,0)|0;h=j;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];j=c[3532592]|0;if((j|0)!=0){gGC(9104152,j|0,280)|0}c[2113054]=c[2113060]}j=(l|0)/88|0;l=(h|0)/88|0;h=0;k=0;i=0;g=0;f=0;e=0;m=0;n=0;while(1){o=i+j|0;p=o-f|0;c[2113056]=p;q=RG(p)|0;c[2113054]=(c[2113054]|0)+q;c[2276108]=-1;c[2113056]=-1;p=q+f|0;q=c[2439330]|0;if((q|0)!=0){r=q;gGC(9706056,r|0,76)|0}b[4853030]=c[2426515]&65535;r=c[2438118]|0;c[2433530]=r;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;s=k+l|0;t=s-e|0;do{if((t|0)<1){u=0}else{if((a[q+4188|0]|0)==0){v=gfc(t)|0;c[2433530]=(c[2433530]|0)+v;u=v;break}else{c[2433530]=r+t;u=t;break}}}while(0);t=u+e|0;r=c[2112964]|0;if((r|0)==0){w=n}else{q=a[9688]|0?6:0;gg[c[3542124]&4095](r+(n<<1<<1)|0,q);w=q+n|0}q=c[1836236]|0;r=c[9757320+(q<<2)>>2]|0;if((r|0)!=0){v=r;gGC(v|0,9706056,76)|0}c[9752472+(q<<2)>>2]=c[2433530];c[14113936+(q<<2)>>2]=c[2076596];c[9669104+(q<<2)>>2]=c[3541536];c[1836236]=-1;q=c[2439331]|0;if((q|0)!=0){v=q;gGC(9706056,v|0,76)|0}b[4853030]=c[2426515]&65535;v=c[2438119]|0;c[2433530]=v;c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;r=h+677|0;x=r-m|0;do{if((x|0)<1){y=0;z=1;A=q;B=v}else{if((a[q+4188|0]|0)==0){C=gfc(x)|0;D=(c[2433530]|0)+C|0;c[2433530]=D;E=c[1836236]|0;y=C;z=E;A=c[9757320+(E<<2)>>2]|0;B=D;break}else{D=v+x|0;c[2433530]=D;y=x;z=1;A=q;B=D;break}}}while(0);F=y+m|0;a[9706117]=1;if((A|0)!=0){q=A;gGC(q|0,9706056,76)|0}c[9752472+(z<<2)>>2]=B;c[14113936+(z<<2)>>2]=c[2076596];c[9669104+(z<<2)>>2]=c[3541536];c[1836236]=-1;q=g+1|0;if((q|0)<88){h=r;k=s;i=o;g=q;f=p;e=t;m=F;n=w}else{break}}n=(c[2406618]|0)==4?6:1;m=c[2394]|0;c[8452200+(m<<2)>>2]=n|8192;e=n<<8;c[2276080]=e;if(e>>>0>(c[2276079]|0)>>>0){RH(n);G=c[2394]|0}else{G=m}m=c[14130368+(G<<2)>>2]|0;if((m|0)!=0){gGC(m|0,9104152,280)|0}c[8452240+(G<<2)>>2]=c[2113054];c[2394]=-1;G=c[2112964]|0;if((G|0)!=0){m=a[9688]|0?534:0;if((m|0)!=(w|0)){n=c[2439330]|0;if((n|0)!=0){e=n;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;gg[c[3542124]&4095](G+(w<<1<<1)|0,m-w|0);w=c[1836236]|0;m=c[9757320+(w<<2)>>2]|0;if((m|0)!=0){G=m;gGC(G|0,9706056,76)|0}c[9752472+(w<<2)>>2]=c[2433530];c[14113936+(w<<2)>>2]=c[2076596];c[9669104+(w<<2)>>2]=c[3541536];c[1836236]=-1}w=c[2439331]|0;if((w|0)!=0){G=w;gGC(9706056,G|0,76)|0}b[4853030]=c[2426515]&65535;G=c[2438119]|0;c[2433530]=G;c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;m=59659-F|0;do{if((m|0)>0){if((a[w+4188|0]|0)==0){F=gfc(m)|0;c[2433530]=(c[2433530]|0)+F;break}else{c[2433530]=G+m;break}}}while(0);Uz(0,c[2112964]|0,a[9688]|0?534:0);Uz(1,c[2112964]|0,a[9688]|0?534:0);m=c[1836236]|0;G=c[9757320+(m<<2)>>2]|0;if((G|0)!=0){w=G;gGC(w|0,9706056,76)|0}c[9752472+(m<<2)>>2]=c[2433530];c[14113936+(m<<2)>>2]=c[2076596];c[9669104+(m<<2)>>2]=c[3541536];c[1836236]=-1}if((c[2112968]|0)==0){return 0}dnP()|0;return 0}function dnP(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;if((a[9547768]|0)!=0){b=c[2406978]|0;f=c[3530114]|0;g=0;do{h=c[b+(g<<2)>>2]|0;c[f+(g<<2)>>2]=h>>8<<3&2016|h>>>3&31|h>>16<<8&63488;g=g+1|0;}while((g|0)<1025)}L86511:do{if((c[2385306]&32|0)==0){g=c[2112926]|0;gGz(g|0,0,ag(c[2113068]<<1,c[2113070]|0)|0);i=g}else{g=c[2438056]|0;f=c[2112926]|0;b=c[2424862]|0;h=0;j=(c[2424804]|0)+(g>>>4<<5)|0;k=g;while(1){g=h&496;l=k&15;m=g-l|0;n=h<<4&240;do{if((m-49|0)>>>0<=398){if(n>>>0<16|(n|0)==240){break}o=d[j+65536|0]|0;p=d[j]|0;q=d[j+65537|0]<<8|d[j+1|0];r=o&1;s=o&2;if((c[3528750]|0)==0){t=s;u=r;v=m;w=n}else{t=s>>>1^1;u=r^1;v=(g|l)^496;w=n^240}r=v-64|0;s=w-16|0;o=(u|0)!=0;if((t|0)==0){if(o){SB(f,q,r,s,p,4,0,b);break}else{Sz(f,q,r,s,p,4,0,b);break}}else{if(o){SF(f,q,r,s,p,4,0,b);break}else{SD(f,q,r,s,p,4,0,b);break}}}}while(0);n=h+1|0;if((n|0)>=512){i=f;break L86511}h=n;j=j+2|0;k=c[2438056]|0}}}while(0);t=c[2385306]|0;if((t&64|0)==0){x=t}else{t=c[2438054]|0;u=c[2385814]|0;w=c[2424838]|0;v=0;k=(c[2424804]|0)+((t>>>4<<5)+131072)|0;j=t;while(1){t=v&496;h=j&15;f=t-h|0;b=v<<4&240;do{if((f-49|0)>>>0<=398){if(b>>>0<16|(b|0)==240){break}n=d[k+65537|0]<<8|d[k+1|0];if((a[u+n|0]|0)!=0){break}l=d[k+65536|0]|0;g=d[k]|0;m=l&1;p=l&2;if((c[3528750]|0)==0){y=p;z=m;A=f;B=b}else{y=p>>>1^1;z=m^1;A=(t|h)^496;B=b^240}m=A-64|0;p=B-16|0;l=(z|0)!=0;if((y|0)==0){if(l){SJ(i,n,m,p,g,4,15,256,w);break}else{SH(i,n,m,p,g,4,15,256,w);break}}else{if(l){SN(i,n,m,p,g,4,15,256,w);break}else{SL(i,n,m,p,g,4,15,256,w);break}}}}while(0);b=v+1|0;if((b|0)>=512){break}v=b;k=k+2|0;j=c[2438054]|0}x=c[2385306]|0}if((x&128|0)==0){C=x}else{x=(c[2388020]|0)+24576|0;j=c[2424820]|0;k=4064;do{v=e[x+(k<<1)>>1]|0;w=e[x+((k|1)<<1)>>1]|0;y=e[x+((k|2)<<1)>>1]|0;z=e[x+((k|3)<<1)>>1]|0;B=w&15;A=w&256;u=w&512;b=(c[3528750]|0)!=0;do{if((w&1024|0)==0){if(b){D=u>>>9^1;E=A>>>8^1;F=496-z|0;G=240-y|0}else{D=u;E=A;F=z;G=y}if((G-1|0)>>>0>238){break}if((F-49|0)>>>0>398){break}h=F-64|0;t=G-16|0;f=(E|0)!=0;g=c[591192+((v>>>3&3)<<2)>>2]^v;if((D|0)==0){if(f){SJ(i,g,h,t,B,4,15,512,j);break}else{SH(i,g,h,t,B,4,15,512,j);break}}else{if(f){SN(i,g,h,t,B,4,15,512,j);break}else{SL(i,g,h,t,B,4,15,512,j);break}}}else{if(b){H=u>>>9^1;I=A>>>8^1;J=480-z|0;K=224-y|0}else{H=u;I=A;J=z;K=y}if((K|0)>239){break}if((J-33|0)>>>0>414){break}t=J-64|0;h=K-16|0;g=v+1|0;f=v+16|0;p=v+17|0;m=(I|0)!=0;n=m?g:v;l=m?v:g;g=m?p:f;s=m?f:p;p=(H|0)!=0;f=p?g:n;r=p?s:l;q=p?n:g;g=p?l:s;s=c[591192+((f>>>3&3)<<2)>>2]^f;if(p){if(m){SN(i,s,t,h,B,4,15,512,j);p=J-48|0;SN(i,c[591192+((r>>>3&3)<<2)>>2]^r,p,h,B,4,15,512,j);SN(i,c[591192+((q>>>3&3)<<2)>>2]^q,t,K,B,4,15,512,j);SN(i,c[591192+((g>>>3&3)<<2)>>2]^g,p,K,B,4,15,512,j);break}else{SL(i,s,t,h,B,4,15,512,j);p=J-48|0;SL(i,c[591192+((r>>>3&3)<<2)>>2]^r,p,h,B,4,15,512,j);SL(i,c[591192+((q>>>3&3)<<2)>>2]^q,t,K,B,4,15,512,j);SL(i,c[591192+((g>>>3&3)<<2)>>2]^g,p,K,B,4,15,512,j);break}}else{if(m){SJ(i,s,t,h,B,4,15,512,j);m=J-48|0;SJ(i,c[591192+((r>>>3&3)<<2)>>2]^r,m,h,B,4,15,512,j);SJ(i,c[591192+((q>>>3&3)<<2)>>2]^q,t,K,B,4,15,512,j);SJ(i,c[591192+((g>>>3&3)<<2)>>2]^g,m,K,B,4,15,512,j);break}else{SH(i,s,t,h,B,4,15,512,j);s=J-48|0;SH(i,c[591192+((r>>>3&3)<<2)>>2]^r,s,h,B,4,15,512,j);SH(i,c[591192+((q>>>3&3)<<2)>>2]^q,t,K,B,4,15,512,j);SH(i,c[591192+((g>>>3&3)<<2)>>2]^g,s,K,B,4,15,512,j);break}}}}while(0);k=k-32|0;}while((k|0)>-1);C=c[2385306]|0}if((C&8|0)==0){L=c[3530114]|0;R8(L);return 0}C=c[2443620]|0;k=c[2385812]|0;j=c[2424810]|0;K=128;do{J=K<<3&504;H=K>>6<<3;do{if((J-64|0)>>>0<=383){I=e[C+(K<<1)>>1]|0;D=I&1023;if((a[k+D|0]|0)!=0){break}E=I>>>12;G=I&1024;F=I&2048;if((c[3528750]|0)==0){M=F;N=G;O=J;P=H}else{M=F>>>11^1;N=G>>>10^1;O=J^504;P=H^248}G=O-64|0;F=P-16|0;I=(N|0)!=0;if((M|0)==0){if(I){Ss(i,D,G,F,E,2,3,768,j);break}else{Sq(i,D,G,F,E,2,3,768,j);break}}else{if(I){Sw(i,D,G,F,E,2,3,768,j);break}else{Su(i,D,G,F,E,2,3,768,j);break}}}}while(0);K=K+1|0;}while((K|0)<1920);L=c[3530114]|0;R8(L);return 0}function dnQ(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;g=i;i=i+192|0;h=g|0;j=g+16|0;k=g+32|0;l=g+48|0;m=g+64|0;n=g+80|0;o=g+96|0;p=g+112|0;q=g+128|0;r=g+144|0;s=g+160|0;t=g+176|0;if((f|0)!=0){c[f>>2]=169249}if((e&96|0)!=0){gGz(t|0,0,12);u=c[2414746]|0;c[t>>2]=u;c[t+4>>2]=(c[2411790]|0)-u;c[t+12>>2]=196728;u=c[2076592]|0;gj[u&4095](t)|0}if((e&64|0)==0){v=e&2}else{t=m|0;gGz(l|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){u=m+9|0;m=k;w=k|0;x=k+4|0;y=k+12|0;z=l|0;A=l+4|0;B=l+12|0;C=0;do{gGC(t|0,614896,11)|0;a[u]=C+48&255;D=8452256+(C<<2)|0;gGz(m|0,0,12);c[w>>2]=D;c[x>>2]=4;c[y>>2]=164976;gj[c[2076592]&4095](k)|0;if((c[D>>2]|0)!=0){c[z>>2]=c[14130368+(C<<2)>>2];c[A>>2]=c[8452184+(C<<2)>>2];c[B>>2]=t;D=c[2076592]|0;gj[D&4095](l)|0}C=C+1|0;}while((C|0)<=(c[2392]|0))}fw$(e);UE(e,f);gGz(j|0,0,12);c[j>>2]=8453216;c[j+4>>2]=4;c[j+12>>2]=107480;f=c[2076592]|0;gj[f&4095](j)|0;gGz(h|0,0,12);c[h>>2]=14168504;c[h+4>>2]=256;c[h+12>>2]=476464;j=c[2076592]|0;gj[j&4095](h)|0;h=e&2;if((h|0)!=0){e=0;do{mv(0,e,d[14168504+e|0]|0);e=e+1|0;}while((e|0)<256)}gGz(s|0,0,12);c[s>>2]=9752216;c[s+4>>2]=4;c[s+12>>2]=572896;e=c[2076592]|0;gj[e&4095](s)|0;gGz(r|0,0,12);c[r>>2]=9752224;c[r+4>>2]=4;c[r+12>>2]=571696;s=c[2076592]|0;gj[s&4095](r)|0;gGz(q|0,0,12);c[q>>2]=14113312;c[q+4>>2]=4;c[q+12>>2]=191240;r=c[2076592]|0;gj[r&4095](q)|0;gGz(p|0,0,12);c[p>>2]=14115e3;c[p+4>>2]=4;c[p+12>>2]=142288;q=c[2076592]|0;gj[q&4095](p)|0;gGz(o|0,0,12);c[o>>2]=9541224;c[o+4>>2]=4;c[o+12>>2]=564720;p=c[2076592]|0;gj[p&4095](o)|0;gGz(n|0,0,12);c[n>>2]=9774944;c[n+4>>2]=4;c[n+12>>2]=563216;o=c[2076592]|0;gj[o&4095](n)|0;v=h}if((v|0)==0){i=g;return 0}v=c[2439331]|0;if((v|0)!=0){h=v;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];h=c[3528485]|0;c[2076596]=h;n=c[2417277]|0;c[3541536]=n;c[1836236]=1;o=c[2443736]<<15;c[2443736]=o+32768;p=c[3529128]|0;q=128;r=128;while(1){c[v+76+(r<<2)>>2]=p+((r<<8)+o);s=q+1&65535;if((s&65535)>255){break}else{q=s;r=s&65535}}r=(c[2443736]|0)-32768|0;q=128;o=128;while(1){s=p+(r+(o<<8))|0;c[v+76+(o+512<<2)>>2]=s;c[v+76+(o+768<<2)>>2]=s;s=q+1&65535;if((s&65535)>255){break}else{q=s;o=s&65535}}o=v;gGC(o|0,9706056,76)|0;c[2438119]=c[2433530];c[3528485]=h;c[2417277]=n;c[1836236]=-1;i=g;return 0}function dnR(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>43){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7329492+(b*112|0)>>2];c[a+104>>2]=c[7329496+(b*112|0)>>2];c[a+108>>2]=c[7329500+(b*112|0)>>2];d=0;return d|0}function dnS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<44&(d|0)==0)){e=1;return e|0}c[a>>2]=7329392+(b*112|0);e=0;return e|0}function dnT(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>29){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6099912+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dnU(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>63){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7132880+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dnV(){return dn4(2)|0}function dnW(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>44){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6996532+(b*112|0)>>2];c[a+104>>2]=c[6996536+(b*112|0)>>2];c[a+108>>2]=c[6996540+(b*112|0)>>2];d=0;return d|0}function dnX(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<45&(d|0)==0)){e=1;return e|0}c[a>>2]=6996432+(b*112|0);e=0;return e|0}function dnY(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>29){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6100392+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dnZ(){return dn4(3)|0}function dn_(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>44){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7001572+(b*112|0)>>2];c[a+104>>2]=c[7001576+(b*112|0)>>2];c[a+108>>2]=c[7001580+(b*112|0)>>2];d=0;return d|0}function dn$(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<45&(d|0)==0)){e=1;return e|0}c[a>>2]=7001472+(b*112|0);e=0;return e|0}function dn0(){return dn4(3)|0}function dn1(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>36){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7334420+(b*112|0)>>2];c[a+104>>2]=c[7334424+(b*112|0)>>2];c[a+108>>2]=c[7334428+(b*112|0)>>2];d=0;return d|0}function dn2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<37&(d|0)==0)){e=1;return e|0}c[a>>2]=7334320+(b*112|0);e=0;return e|0}function dn3(){return dn4(4)|0}function dn4(e){e=e|0;var f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0;f=i;i=i+1920|0;g=f|0;j=f+112|0;k=f+120|0;l=f+232|0;m=f+240|0;n=f+352|0;o=f+360|0;p=f+472|0;q=f+480|0;r=f+592|0;s=f+600|0;t=f+712|0;u=f+720|0;v=f+832|0;w=f+840|0;x=f+952|0;y=f+960|0;z=f+1072|0;A=f+1080|0;B=f+1192|0;C=f+1200|0;D=f+1312|0;E=f+1320|0;F=f+1432|0;G=f+1440|0;H=f+1552|0;I=f+1560|0;J=f+1672|0;K=f+1680|0;L=f+1792|0;M=f+1800|0;N=f+1912|0;c[2426794]=0;c[2388016]=0;c[3529136]=393216;c[3529128]=425984;c[2424862]=688128;c[2424838]=1736704;c[2385814]=3833856;c[2424820]=3842048;c[2424810]=7512064;c[2385812]=7577600;c[2424804]=7578624;c[3530114]=7840768;c[2414746]=7844868;c[2443622]=7844868;c[2443620]=7846916;c[2388020]=7851012;c[3529162]=7883780;c[2406978]=7885828;c[2411790]=7889928;O=0;while(1){if((O|0)>=1024){break}P=9638528+(O<<2)|0;if((c[P>>2]|0)==0){Q=71883;break}else{O=O+1|0}}do{if((Q|0)==71883){O=gGq(7889928)|0;c[P>>2]=O;if((O|0)==0){break}c[2426794]=O;gGz(O|0,0,7889928);c[2388016]=O;c[3529136]=O+393216;c[3529128]=O+425984;c[2424862]=O+688128;c[2424838]=O+1736704;c[2385814]=O+3833856;c[2424820]=O+3842048;c[2424810]=O+7512064;c[2385812]=O+7577600;c[2424804]=O+7578624;c[3530114]=O+7840768;R=O+7844868|0;c[2414746]=R;c[2443622]=R;c[2443620]=O+7846916;c[2388020]=O+7851012;c[3529162]=O+7883780;c[2406978]=O+7885828;R=O+7889928|0;c[2411790]=R;c[2414338]=R;L86741:do{if((e|0)==4){if((R6(O+1|0,0,2)|0)!=0){S=1;i=f;return S|0}if((R6(c[2388016]|0,1,2)|0)!=0){S=1;i=f;return S|0}R=c[3529136]|0;if((c[3542200]|0)==0){S=1;i=f;return S|0}T=M+108|0;c[T>>2]=0;U=M+100|0;c[U>>2]=0;V=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[V&16383](M,2)|0;do{if((c[T>>2]|0)!=0){V=c[U>>2]|0;c[N>>2]=9534384;W=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[W&16383](N,2,0)|0;if((V|0)<1){S=1;i=f;return S|0}if((gzL(R,0,2)|0)==0){break}else{S=1}i=f;return S|0}}while(0);R=c[3529128]|0;if((c[3542200]|0)==0){S=1;i=f;return S|0}U=K+108|0;c[U>>2]=0;T=K+100|0;c[T>>2]=0;V=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[V&16383](K,3)|0;do{if((c[U>>2]|0)!=0){V=c[T>>2]|0;c[L>>2]=9534384;W=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[W&16383](L,3,0)|0;if((V|0)<1){S=1;i=f;return S|0}if((gzL(R,0,3)|0)==0){break}else{S=1}i=f;return S|0}}while(0);R=I+108|0;T=I+100|0;U=0;while(1){V=(c[2424862]|0)+(U<<17)|0;W=U+4|0;if((c[3542200]|0)==0){S=1;Q=72100;break}c[R>>2]=0;c[T>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](I,W)|0;if((c[R>>2]|0)!=0){X=c[T>>2]|0;c[J>>2]=9534384;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Y&16383](J,W,0)|0;if((X|0)<1){S=1;Q=72091;break}if((gzL(V,0,W)|0)!=0){S=1;Q=72115;break}}W=U+1|0;if((W|0)<4){U=W}else{Q=71897;break}}if((Q|0)==71897){U=G+108|0;T=G+100|0;R=0;while(1){W=(c[2424838]|0)+(R<<17)|0;V=R+8|0;if((c[3542200]|0)==0){S=1;Q=72095;break}c[U>>2]=0;c[T>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](G,V)|0;if((c[U>>2]|0)!=0){X=c[T>>2]|0;c[H>>2]=9534384;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Y&16383](H,V,0)|0;if((X|0)<1){S=1;Q=72110;break}if((gzL(W,0,V)|0)!=0){S=1;Q=72118;break}}V=R+1|0;if((V|0)<8){R=V}else{Q=71903;break}}if((Q|0)==71903){R=E+108|0;T=E+100|0;U=C+108|0;V=C+100|0;W=0;while(1){X=W<<16;Y=(c[2424820]|0)+X|0;Z=W+16|0;if((c[3542200]|0)==0){S=1;Q=72089;break}c[R>>2]=0;c[T>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](E,Z)|0;if((c[R>>2]|0)!=0){_=c[T>>2]|0;c[F>>2]=9534384;$=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[$&16383](F,Z,0)|0;if((_|0)<1){S=1;Q=72080;break}if((gzL(Y,0,Z)|0)!=0){S=1;Q=72094;break}}Z=(c[2424820]|0)+(X+917504)|0;X=W+22|0;if((c[3542200]|0)==0){S=1;Q=72108;break}c[U>>2]=0;c[V>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](C,X)|0;if((c[U>>2]|0)!=0){Y=c[V>>2]|0;c[D>>2]=9534384;_=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[_&16383](D,X,0)|0;if((Y|0)<1){S=1;Q=72117;break}if((gzL(Z,0,X)|0)!=0){S=1;Q=72112;break}}X=W+1|0;if((X|0)<6){W=X}else{Q=71918;break}}if((Q|0)==71918){W=c[2424810]|0;if((c[3542200]|0)==0){S=1;i=f;return S|0}V=A+108|0;c[V>>2]=0;U=A+100|0;c[U>>2]=0;T=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[T&16383](A,28)|0;do{if((c[V>>2]|0)!=0){T=c[U>>2]|0;c[B>>2]=9534384;R=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[R&16383](B,28,0)|0;if((T|0)<1){S=1;i=f;return S|0}if((gzL(W,0,28)|0)==0){break}else{S=1}i=f;return S|0}}while(0);W=y+108|0;U=y+100|0;V=0;while(1){T=(c[2424804]|0)+(V<<16)|0;R=V+29|0;if((c[3542200]|0)==0){S=1;Q=72126;break}c[W>>2]=0;c[U>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](y,R)|0;if((c[W>>2]|0)!=0){X=c[U>>2]|0;c[z>>2]=9534384;Z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Z&16383](z,R,0)|0;if((X|0)<1){S=1;Q=72130;break}if((gzL(T,0,R)|0)!=0){S=1;Q=72098;break}}R=V+1|0;if((R|0)<4){V=R}else{aa=0;break L86741}}if((Q|0)==72098){i=f;return S|0}else if((Q|0)==72126){i=f;return S|0}else if((Q|0)==72130){i=f;return S|0}}else if((Q|0)==72080){i=f;return S|0}else if((Q|0)==72089){i=f;return S|0}else if((Q|0)==72094){i=f;return S|0}else if((Q|0)==72108){i=f;return S|0}else if((Q|0)==72112){i=f;return S|0}else if((Q|0)==72117){i=f;return S|0}}else if((Q|0)==72095){i=f;return S|0}else if((Q|0)==72110){i=f;return S|0}else if((Q|0)==72118){i=f;return S|0}}else if((Q|0)==72091){i=f;return S|0}else if((Q|0)==72100){i=f;return S|0}else if((Q|0)==72115){i=f;return S|0}}else{V=0;while(1){if((V|0)>=6){Q=71931;break}U=V<<16;if((R6((c[2388016]|0)+(U|1)|0,V,2)|0)!=0){S=1;Q=72109;break}if((R6((c[2388016]|0)+U|0,V|1,2)|0)==0){V=V+2|0}else{S=1;Q=72134;break}}if((Q|0)==71931){V=c[3529136]|0;if((c[3542200]|0)==0){S=1;i=f;return S|0}U=w+108|0;c[U>>2]=0;W=w+100|0;c[W>>2]=0;R=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[R&16383](w,6)|0;do{if((c[U>>2]|0)!=0){R=c[W>>2]|0;c[x>>2]=9534384;T=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[T&16383](x,6,0)|0;if((R|0)<1){S=1;i=f;return S|0}if((gzL(V,0,6)|0)==0){break}else{S=1}i=f;return S|0}}while(0);V=c[3529128]|0;if((c[3542200]|0)==0){S=1;i=f;return S|0}W=u+108|0;c[W>>2]=0;U=u+100|0;c[U>>2]=0;R=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[R&16383](u,7)|0;do{if((c[W>>2]|0)!=0){R=c[U>>2]|0;c[v>>2]=9534384;T=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[T&16383](v,7,0)|0;if((R|0)<1){S=1;i=f;return S|0}if((gzL(V,0,7)|0)==0){break}else{S=1}i=f;return S|0}}while(0);V=(c[3529128]|0)+131072|0;if((c[3542200]|0)==0){S=1;i=f;return S|0}U=s+108|0;c[U>>2]=0;W=s+100|0;c[W>>2]=0;R=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[R&16383](s,8)|0;do{if((c[U>>2]|0)!=0){R=c[W>>2]|0;c[t>>2]=9534384;T=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[T&16383](t,8,0)|0;if((R|0)<1){S=1;i=f;return S|0}if((gzL(V,0,8)|0)==0){break}else{S=1}i=f;return S|0}}while(0);V=q+108|0;W=q+100|0;U=0;while(1){R=(c[2424862]|0)+(U<<17)|0;T=U+9|0;if((c[3542200]|0)==0){S=1;Q=72104;break}c[V>>2]=0;c[W>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](q,T)|0;if((c[V>>2]|0)!=0){X=c[W>>2]|0;c[r>>2]=9534384;Z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Z&16383](r,T,0)|0;if((X|0)<1){S=1;Q=72123;break}if((gzL(R,0,T)|0)!=0){S=1;Q=72083;break}}T=U+1|0;if((T|0)<4){U=T}else{Q=71944;break}}if((Q|0)==71944){U=o+108|0;W=o+100|0;V=0;while(1){T=(c[2424838]|0)+(V<<17)|0;R=V+13|0;if((c[3542200]|0)==0){S=1;Q=72135;break}c[U>>2]=0;c[W>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](o,R)|0;if((c[U>>2]|0)!=0){X=c[W>>2]|0;c[p>>2]=9534384;Z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Z&16383](p,R,0)|0;if((X|0)<1){S=1;Q=72125;break}if((gzL(T,0,R)|0)!=0){S=1;Q=72090;break}}R=V+1|0;if((R|0)<8){V=R}else{Q=71950;break}}if((Q|0)==71950){V=m+108|0;W=m+100|0;U=0;while(1){R=(c[2424820]|0)+(U<<17)|0;T=U+21|0;if((c[3542200]|0)==0){S=1;Q=72120;break}c[V>>2]=0;c[W>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,T)|0;if((c[V>>2]|0)!=0){X=c[W>>2]|0;c[n>>2]=9534384;Z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Z&16383](n,T,0)|0;if((X|0)<1){S=1;Q=72106;break}if((gzL(R,0,T)|0)!=0){S=1;Q=72082;break}}T=U+1|0;if((T|0)<14){U=T}else{Q=71961;break}}if((Q|0)==71961){U=c[2424810]|0;if((c[3542200]|0)==0){S=1;i=f;return S|0}W=k+108|0;c[W>>2]=0;V=k+100|0;c[V>>2]=0;T=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[T&16383](k,35)|0;do{if((c[W>>2]|0)!=0){T=c[V>>2]|0;c[l>>2]=9534384;R=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[R&16383](l,35,0)|0;if((T|0)<1){S=1;i=f;return S|0}if((gzL(U,0,35)|0)==0){break}else{S=1}i=f;return S|0}}while(0);U=g+108|0;V=g+100|0;W=0;while(1){T=(c[2424804]|0)+(W<<16)|0;R=W+36|0;if((c[3542200]|0)==0){S=1;Q=72081;break}c[U>>2]=0;c[V>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,R)|0;if((c[U>>2]|0)!=0){X=c[V>>2]|0;c[j>>2]=9534384;Z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Z&16383](j,R,0)|0;if((X|0)<1){S=1;Q=72132;break}if((gzL(T,0,R)|0)!=0){S=1;Q=72127;break}}R=W+1|0;if((R|0)<4){W=R}else{aa=0;break L86741}}if((Q|0)==72132){i=f;return S|0}else if((Q|0)==72081){i=f;return S|0}else if((Q|0)==72127){i=f;return S|0}}else if((Q|0)==72082){i=f;return S|0}else if((Q|0)==72106){i=f;return S|0}else if((Q|0)==72120){i=f;return S|0}}else if((Q|0)==72135){i=f;return S|0}else if((Q|0)==72090){i=f;return S|0}else if((Q|0)==72125){i=f;return S|0}}else if((Q|0)==72083){i=f;return S|0}else if((Q|0)==72104){i=f;return S|0}else if((Q|0)==72123){i=f;return S|0}}else if((Q|0)==72134){i=f;return S|0}else if((Q|0)==72109){i=f;return S|0}}}while(0);while(1){if((aa|0)>=1024){S=1;Q=72128;break}ab=9638528+(aa<<2)|0;if((c[ab>>2]|0)==0){break}else{aa=aa+1|0}}if((Q|0)==72128){i=f;return S|0}O=gGq(1835008)|0;c[ab>>2]=O;if((O|0)==0){S=1;i=f;return S|0}gGz(O|0,0,1835008);W=c[2424862]|0;gGC(O|0,W|0,524288)|0;V=0;do{U=V<<8;gGz(W+U|0,0,256);R=V<<9;T=0;do{X=1<<3-T;Z=(c[613328+(T<<2)>>2]|0)+R|0;Y=0;do{_=Z+(c[608544+(Y<<2)>>2]|0)|0;$=(Y<<4)+U|0;ac=0;do{ad=_+(c[609552+(ac<<2)>>2]|0)|0;if((d[O+((ad|0)/8|0)|0]&128>>>((ad&7)>>>0)|0)!=0){ad=W+($+ac)|0;a[ad]=(d[ad]|X)&255}ac=ac+1|0;}while((ac|0)<16);Y=Y+1|0;}while((Y|0)<16);T=T+1|0;}while((T|0)<4);V=V+1|0;}while((V|0)<4096);V=c[2424838]|0;gGC(O|0,V|0,1048576)|0;W=0;do{T=W<<8;gGz(V+T|0,0,256);U=W<<9;R=0;do{Y=1<<3-R;X=(c[613312+(R<<2)>>2]|0)+U|0;Z=0;do{ac=X+(c[608544+(Z<<2)>>2]|0)|0;$=(Z<<4)+T|0;_=0;do{ad=ac+(c[609552+(_<<2)>>2]|0)|0;if((d[O+((ad|0)/8|0)|0]&128>>>((ad&7)>>>0)|0)!=0){ad=V+($+_)|0;a[ad]=(d[ad]|Y)&255}_=_+1|0;}while((_|0)<16);Z=Z+1|0;}while((Z|0)<16);R=R+1|0;}while((R|0)<4);W=W+1|0;}while((W|0)<8192);W=c[2424820]|0;gGC(O|0,W|0,1835008)|0;R=0;do{T=R<<8;gGz(W+T|0,0,256);U=R<<9;Z=0;do{Y=1<<3-Z;X=(c[613296+(Z<<2)>>2]|0)+U|0;_=0;do{$=X+(c[608544+(_<<2)>>2]|0)|0;ac=(_<<4)+T|0;ad=0;do{ae=$+(c[609552+(ad<<2)>>2]|0)|0;if((d[O+((ae|0)/8|0)|0]&128>>>((ae&7)>>>0)|0)!=0){ae=W+(ac+ad)|0;a[ae]=(d[ae]|Y)&255}ad=ad+1|0;}while((ad|0)<16);_=_+1|0;}while((_|0)<16);Z=Z+1|0;}while((Z|0)<4);R=R+1|0;}while((R|0)<14336);R=c[2424810]|0;gGC(O|0,R|0,16384)|0;W=0;do{Z=W<<6;gGz(R+Z|0,0,64);T=W<<7;U=T|4;_=0;while(1){Y=U+(c[608544+(_<<2)>>2]|0)|0;X=(_<<3)+Z|0;ad=0;do{ac=Y+(c[609552+(ad<<2)>>2]|0)|0;if((d[O+((ac|0)/8|0)|0]&128>>>((ac&7)>>>0)|0)!=0){ac=R+(X+ad)|0;a[ac]=a[ac]|2}ad=ad+1|0;}while((ad|0)<8);ad=_+1|0;if((ad|0)<8){_=ad}else{af=0;break}}do{_=T+(c[608544+(af<<2)>>2]|0)|0;U=(af<<3)+Z|0;ad=0;do{X=_+(c[609552+(ad<<2)>>2]|0)|0;if((d[O+((X|0)/8|0)|0]&128>>>((X&7)>>>0)|0)!=0){X=R+(U+ad)|0;a[X]=a[X]|1}ad=ad+1|0;}while((ad|0)<8);af=af+1|0;}while((af|0)<8);W=W+1|0;}while((W|0)<1024);W=c[2385814]|0;gGz(W|0,1,8192);Z=0;do{if((a[V+Z|0]|0)!=15){a[W+((Z|0)/256|0)|0]=0}Z=Z+1|0;}while((Z|0)<2097152);Z=c[2385812]|0;gGz(Z|0,1,1024);W=0;while(1){if((a[R+W|0]|0)!=3){a[Z+((W|0)/64|0)|0]=0}V=W+1|0;if((V|0)<65536){W=V}else{ah=0;break}}while(1){if((ah|0)>=1024){break}ai=9638528+(ah<<2)|0;if((c[ai>>2]|0)==(O|0)){Q=72021;break}else{ah=ah+1|0}}if((Q|0)==72021){gGr(O);c[ai>>2]=0}fxU(0,425984);if((c[2394]|0)==0){aj=c[2112932]|0}else{c[2394]=0;W=c[3532596]|0;c[2112932]=W;Z=c[3532592]|0;if((Z|0)!=0){gGC(9104152,Z|0,280)|0}c[2113054]=c[2113060];aj=W}W=c[2388016]|0;Z=aj|0;R=0;while(1){V=W+R|0;c[Z>>2]=V;c[Z+131072>>2]=V;V=R+1024|0;if(V>>>0>327679){break}else{Z=Z+4|0;R=V}}R=c[2443620]|0;c[aj+32768>>2]=R;c[aj+98304>>2]=R;c[aj+163840>>2]=R;Z=R+1024|0;c[aj+32772>>2]=Z;c[aj+98308>>2]=Z;c[aj+163844>>2]=Z;Z=R+2048|0;c[aj+32776>>2]=Z;c[aj+98312>>2]=Z;c[aj+163848>>2]=Z;Z=R+3072|0;c[aj+32780>>2]=Z;c[aj+98316>>2]=Z;c[aj+163852>>2]=Z;Z=c[2388020]|0;R=aj+65408|0;W=16744448;while(1){O=Z+(W-16744448)|0;c[R>>2]=O;c[R+65536>>2]=O;c[R+131072>>2]=O;O=W+1024|0;if(O>>>0>16777215){break}else{R=R+4|0;W=O}}c[aj+196648>>2]=2068;c[aj+196728>>2]=386;c[aj+196608>>2]=1238;c[aj+196688>>2]=762;W=c[3532592]|0;if((W|0)!=0){gGC(W|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);W=c[2439330]|0;R=(W|0)==0;if(!R){Z=W;gGC(9706056,Z|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];Z=c[3528484]|0;c[2076596]=Z;O=c[2417276]|0;c[3541536]=O;c[1836236]=0;V=c[3529136]|0;T=0;ad=0;while(1){c[W+76+(ad<<2)>>2]=V+(ad<<8);U=T+1&65535;if((U&65535)>127){ak=0;al=0;break}else{T=U;ad=U&65535}}while(1){ad=V+(al<<8)|0;c[W+76+(al+512<<2)>>2]=ad;c[W+76+(al+768<<2)>>2]=ad;ad=ak+1&65535;if((ad&65535)>127){break}else{ak=ad;al=ad&65535}}V=c[3529162]|0;c[W+844>>2]=V;ad=V+256|0;c[W+848>>2]=ad;T=V+512|0;c[W+852>>2]=T;U=V+768|0;c[W+856>>2]=U;_=V+1024|0;c[W+860>>2]=_;X=V+1280|0;c[W+864>>2]=X;Y=V+1536|0;c[W+868>>2]=Y;ac=V+1792|0;c[W+872>>2]=ac;c[W+1868>>2]=V;c[W+1872>>2]=ad;c[W+1876>>2]=T;c[W+1880>>2]=U;c[W+1884>>2]=_;c[W+1888>>2]=X;c[W+1892>>2]=Y;c[W+1896>>2]=ac;c[W+2892>>2]=V;c[W+3916>>2]=V;c[W+2896>>2]=ad;c[W+3920>>2]=ad;c[W+2900>>2]=T;c[W+3924>>2]=T;c[W+2904>>2]=U;c[W+3928>>2]=U;c[W+2908>>2]=_;c[W+3932>>2]=_;c[W+2912>>2]=X;c[W+3936>>2]=X;c[W+2916>>2]=Y;c[W+3940>>2]=Y;c[W+2920>>2]=ac;c[W+3944>>2]=ac;c[W+4184>>2]=1620;c[W+4180>>2]=776;if(!R){ac=W;gGC(ac|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=Z;c[2417276]=O;c[1836236]=-1;fwR(1);ac=c[2439331]|0;Y=(ac|0)==0;if(!Y){X=ac;gGC(9706056,X|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];X=c[3528485]|0;c[2076596]=X;_=c[2417277]|0;c[3541536]=_;c[1836236]=1;U=c[3529128]|0;T=0;ad=0;while(1){c[ac+76+(ad<<2)>>2]=U+(ad<<8);V=T+1&65535;if((V&65535)>127){am=0;an=0;break}else{T=V;ad=V&65535}}while(1){ad=U+(an<<8)|0;c[ac+76+(an+512<<2)>>2]=ad;c[ac+76+(an+768<<2)>>2]=ad;ad=am+1&65535;if((ad&65535)>127){break}else{am=ad;an=ad&65535}}c[ac+4176>>2]=2114;c[ac+4172>>2]=1626;if(!Y){U=ac;gGC(U|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=X;c[2417277]=_;c[1836236]=-1;U=a[9680]|0;ad=U?32e3:0;if(U){if(a[9624]|0){U=ad*3|0;T=55930;while(1){if((T|0)>(U|0)){T=T>>1}else{ao=1222;ap=T;break}}}else{ao=2462;ap=ad}c[2429380]=ap;c[3542124]=ao;mw(3579545,ap);T=gGq(262144)|0;c[2406684]=T;gGz(T|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(3579545,11025)}c[(c[3531464]|0)+44344>>2]=1024;h[745421]=.6;c[2436794]=1;h[745420]=.6;c[2436792]=2;UB(0,2866,384e3,0,7);UB(1,2866,384e3,0,7);h[1207773]=1.0;c[2415548]=3;c[2415126]=9665376;h[1208176]=1.0;c[2416354]=3;T=c[642608+(c[2436]<<2)>>2]|0;U=c[T+128>>2]|0;if((c[T+52>>2]&4|0)==0){c[2113068]=U;_=c[T+132>>2]|0;c[2113070]=_;c[2443814]=U;c[2440436]=_;aq=U;ar=_}else{c[2113070]=U;_=c[T+132>>2]|0;c[2113068]=_;c[2440436]=U;c[2443814]=_;aq=_;ar=U}U=ag(aq<<1,ar)|0;_=gGq(U)|0;c[2112926]=_;if((_|0)!=0){gGz(_|0,0,U|0)}a[9624728]=0;U=c[2414746]|0;gGz(U|0,0,(c[2411790]|0)-U|0);c[2438054]=0;c[2438056]=0;c[3528328]=0;c[3528750]=0;c[2385306]=0;c[2443736]=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];U=c[3532592]|0;if((U|0)!=0){gGC(9104152,U|0,280)|0}c[2113054]=c[2113060]}RI();U=c[2394]|0;_=c[14130368+(U<<2)>>2]|0;if((_|0)!=0){gGC(_|0,9104152,280)|0}c[8452240+(U<<2)>>2]=c[2113054];c[2394]=-1;U=c[2439330]|0;_=(U|0)==0;if(!_){T=U;gGC(9706056,T|0,76)|0}T=c[2438118]|0;c[2433530]=T;X=c[3528484]|0;c[2076596]=X;ac=c[2417276]|0;c[3541536]=ac;c[1836236]=0;gGz(9706056,0,76);if(!_){_=U;gGC(_|0,9706056,76)|0}c[2438118]=T;c[3528484]=X;c[2417276]=ac;c[1836236]=-1;ac=c[2439331]|0;X=(ac|0)==0;if(!X){T=ac;gGC(9706056,T|0,76)|0}T=c[2438119]|0;c[2433530]=T;_=c[3528485]|0;c[2076596]=_;U=c[2417277]|0;c[3541536]=U;c[1836236]=1;gGz(9706056,0,76);if(!X){X=ac;gGC(X|0,9706056,76)|0}c[2438119]=T;c[3528485]=_;c[2417277]=U;c[1836236]=-1;mx(0);UA();c[2406618]=e;c[(c[2406978]|0)+4096>>2]=16711935;S=0;i=f;return S|0}}while(0);c[2426794]=0;S=1;i=f;return S|0}function dn5(a){a=a|0;var b=0.0,d=0,e=0;b=+((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0);d=+V(b)>=1.0?b>0.0?(al(+U(b/4294967296.0),4294967295.0)|0)>>>0:~~+af((b- +(~~b>>>0))/4294967296.0)>>>0:0;e=gGU(~~b>>>0,d,a,(a|0)<0|0?-1:0)|0;a=gGS(e,K,3579545,0)|0;return a|0}function dn6(b){b=b|0;var c=0;switch(b|0){case 16531458:{c=a[9658050]|0;break};case 16531457:{c=a[9658049]|0;break};case 16531462:{c=~a[9625866];break};case 16531456:{c=a[9658048]|0;break};case 16531461:{c=~a[9625865];break};case 16531460:{c=~a[9625864];break};default:{c=0}}return c|0}function dn7(c,d){c=c|0;d=d|0;if((c|0)==16580612){b[4887184]=d&511;return}else if((c|0)==16580614){b[4887208]=d&1023;return}else if((c|0)==16531458){a[9758232]=d&255;return}else if((c|0)==16580608){b[4887132]=d&511;return}else if((c|0)==16580610){b[4887148]=d&1023;return}else{return}}function dn8(b){b=b|0;var d=0,e=0,f=0.0,g=0.0,i=0;d=b&65535;if((d|0)==61440){b=c[3541518]|0;e=b+296|0;f=+h[e>>3];do{if(f!=0.0){g=+h[6675];if(f-(g+ +gC[c[2429842]&255]())<=0.0){h[e>>3]=0.0;break}i=a[b+307|0]|-128;return i|0}}while(0);i=a[b+307|0]|0;return i|0}else if((d|0)==61446){i=a[9758232]|0;return i|0}else if((d|0)==61442){d=c[3541518]|0;b=d+19320|0;f=+h[b>>3];do{if(f!=0.0){g=+h[6675];if(f-(g+ +gC[c[2429842]&255]())<=0.0){h[b>>3]=0.0;break}i=a[d+19331|0]|-128;return i|0}}while(0);i=a[d+19331|0]|0;return i|0}else{i=0;return i|0}return 0}function dn9(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;switch(b&65535|0){case 61443:{lS(1,1,d);return};case 61450:{b=d&1;a[9758008]=b;e=c[2385844]|0;f=(b&255)<<14;b=c[9757320+(c[1836236]<<2)>>2]|0;g=(f|32768)-32768|0;h=128;i=128;while(1){c[b+76+(i<<2)>>2]=e+(g+(i<<8));j=h+1&65535;if((j&65535)>191){k=128;l=128;break}else{h=j;i=j&65535}}while(1){i=e+((l<<8)+f)|0;c[b+76+(l+512<<2)>>2]=i;c[b+76+(l+768<<2)>>2]=i;i=k+1&65535;if((i&65535)>191){break}else{k=i;l=i&65535}}return};case 61441:{lS(0,1,d);return};case 61444:{Uv(0,d);return};case 61440:{l=c[3541518]|0;k=l+256|0;a[l+304|0]=d;b=d&255;if((d&255)<16){c[14168912+((c[2383582]|0)*252|0)>>2]=b&15}if((d-45&255)>=3){return}if((b|0)==0){a[l+312|0]=2;m=2}else if((b|0)==45){f=l+312|0;e=a[f]|2;a[f]=e;m=e}else if((b|0)==46){e=l+312|0;f=a[e]|1;a[e]=f;m=f}else if((b|0)==47){a[l+312|0]=0;m=0}else{m=a[l+312|0]|0}l=m&3;m=c[7461744+(l<<2)>>2]|0;lI(k,m,m,c[7461728+(l<<2)>>2]|0);return};case 61442:{l=c[3541518]|0;m=l+19280|0;a[l+19328|0]=d;k=d&255;if((d&255)<16){c[14168912+(((c[2383582]|0)+1|0)*252|0)>>2]=k&15}if((d-45&255)>=3){return}if((k|0)==0){a[l+19336|0]=2;n=2}else if((k|0)==46){d=l+19336|0;b=a[d]|1;a[d]=b;n=b}else if((k|0)==47){a[l+19336|0]=0;n=0}else if((k|0)==45){k=l+19336|0;b=a[k]|2;a[k]=b;n=b}else{n=a[l+19336|0]|0}l=n&3;n=c[7461744+(l<<2)>>2]|0;lI(m,n,n,c[7461728+(l<<2)>>2]|0);return};default:{return}}}function doa(b,c){b=b|0;c=c|0;if((b|0)!=16531459){return}a[9758232]=c;return}function dob(a){a=a|0;var b=0;if((a|0)==16531460){b=(d[9658049]|0)<<8|(d[9658048]|0)}else if((a|0)==16531458){b=~(d[9625866]|0)}else if((a|0)==16531462){b=d[9658050]|0}else if((a|0)==16531456){b=~((d[9625865]|0)<<8|(d[9625864]|0))}else{b=0}return b|0}function doc(a,c){a=a|0;c=c|0;if((a|0)==16547846){b[4887208]=c&1023;return}else if((a|0)==16547842){b[4887148]=c&1023;return}else if((a|0)==16547844){b[4887184]=c&511;return}else if((a|0)==16547840){b[4887132]=c&511;return}else{return}}function dod(b){b=b|0;var d=0,e=0,f=0.0,g=0.0,i=0;d=b&65535;if((d|0)==59392){b=c[3541518]|0;e=b+296|0;f=+h[e>>3];do{if(f!=0.0){g=+h[6675];if(f-(g+ +gC[c[2429842]&255]())<=0.0){h[e>>3]=0.0;break}i=a[b+307|0]|-128;return i|0}}while(0);i=a[b+307|0]|0;return i|0}else if((d|0)==63488){i=a[9758232]|0;return i|0}else if((d|0)==61440){d=c[3541518]|0;b=d+19320|0;f=+h[b>>3];do{if(f!=0.0){g=+h[6675];if(f-(g+ +gC[c[2429842]&255]())<=0.0){h[b>>3]=0.0;break}i=a[d+19331|0]|-128;return i|0}}while(0);i=a[d+19331|0]|0;return i|0}else{i=0;return i|0}return 0}function doe(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=b&65535;if((e|0)==61441){lS(1,1,d);return}else if((e|0)==59393){lS(0,1,d);return}else if((e|0)==59392){b=c[3541518]|0;f=b+256|0;a[b+304|0]=d;g=d&255;if((d&255)<16){c[14168912+((c[2383582]|0)*252|0)>>2]=g&15}if((d-45&255)>=3){return}if((g|0)==0){a[b+312|0]=2;h=2}else if((g|0)==45){i=b+312|0;j=a[i]|2;a[i]=j;h=j}else if((g|0)==46){j=b+312|0;i=a[j]|1;a[j]=i;h=i}else if((g|0)==47){a[b+312|0]=0;h=0}else{h=a[b+312|0]|0}b=h&3;h=c[7461744+(b<<2)>>2]|0;lI(f,h,h,c[7461728+(b<<2)>>2]|0);return}else if((e|0)==61440){e=c[3541518]|0;b=e+19280|0;a[e+19328|0]=d;h=d&255;if((d&255)<16){c[14168912+(((c[2383582]|0)+1|0)*252|0)>>2]=h&15}if((d-45&255)>=3){return}if((h|0)==0){a[e+19336|0]=2;k=2}else if((h|0)==45){d=e+19336|0;f=a[d]|2;a[d]=f;k=f}else if((h|0)==47){a[e+19336|0]=0;k=0}else if((h|0)==46){h=e+19336|0;f=a[h]|1;a[h]=f;k=f}else{k=a[e+19336|0]|0}e=k&3;k=c[7461744+(e<<2)>>2]|0;lI(b,k,k,c[7461728+(e<<2)>>2]|0);return}else{return}}function dof(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3807396+(b*112|0)>>2];c[a+104>>2]=c[3807400+(b*112|0)>>2];c[a+108>>2]=c[3807404+(b*112|0)>>2];d=0;return d|0}function dog(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=3807296+(b*112|0);e=0;return e|0}function doh(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1236368+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function doi(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>47){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3808864+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function doj(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;e=i;i=i+840|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;c[2426792]=0;c[2388036]=0;c[2385844]=524288;c[3541206]=589824;c[2405702]=851968;c[2388058]=851968;c[2385862]=983040;c[2443430]=985088;c[2430220]=987136;c[3527222]=989184;c[2439624]=997376;c[2439584]=999424;c[2439582]=1015808;c[2411788]=1048576;c[2406538]=1048576;c[3531070]=1179648;c[3530980]=1703936;c[3529590]=2752512;c[3530112]=3801088;v=0;while(1){if((v|0)>=1024){break}w=9638528+(v<<2)|0;if((c[w>>2]|0)==0){x=72315;break}else{v=v+1|0}}do{if((x|0)==72315){v=gGq(3809280)|0;c[w>>2]=v;if((v|0)==0){break}c[2426792]=v;gGz(v|0,0,3809280);c[2388036]=v;c[2385844]=v+524288;c[3541206]=v+589824;y=v+851968|0;c[2405702]=y;c[2388058]=y;c[2385862]=v+983040;c[2443430]=v+985088;c[2430220]=v+987136;c[3527222]=v+989184;c[2439624]=v+997376;c[2439584]=v+999424;c[2439582]=v+1015808;y=v+1048576|0;c[2411788]=y;c[2406538]=y;c[3531070]=v+1179648;c[3530980]=v+1703936;c[3529590]=v+2752512;c[3530112]=v+3801088;c[2414336]=v+3809280;v=0;while(1){if((v|0)>=1024){z=0;break}A=9638528+(v<<2)|0;if((c[A>>2]|0)==0){x=72320;break}else{v=v+1|0}}do{if((x|0)==72320){v=gGq(524288)|0;c[A>>2]=v;if((v|0)==0){z=0;break}gGz(v|0,0,524288);z=v}}while(0);c[3529540]=z;if((R6((c[2388036]|0)+1|0,0,2)|0)!=0){B=1;i=e;return B|0}if((R6(c[2388036]|0,1,2)|0)!=0){B=1;i=e;return B|0}if((R6((c[2388036]|0)+262145|0,2,2)|0)!=0){B=1;i=e;return B|0}if((R6((c[2388036]|0)+262144|0,3,2)|0)!=0){B=1;i=e;return B|0}v=c[2385844]|0;if((c[3542200]|0)==0){B=1;i=e;return B|0}y=t+108|0;c[y>>2]=0;C=t+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,4)|0;do{if((c[y>>2]|0)!=0){D=c[C>>2]|0;c[u>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](u,4,0)|0;if((D|0)<1){B=1;i=e;return B|0}if((gzL(v,0,4)|0)==0){break}else{B=1}i=e;return B|0}}while(0);v=c[3529540]|0;if((c[3542200]|0)==0){B=1;i=e;return B|0}C=r+108|0;c[C>>2]=0;y=r+100|0;c[y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,5)|0;do{if((c[C>>2]|0)!=0){D=c[y>>2]|0;c[s>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](s,5,0)|0;if((D|0)<1){B=1;i=e;return B|0}if((gzL(v,0,5)|0)==0){break}else{B=1}i=e;return B|0}}while(0);v=c[3529540]|0;y=c[2406538]|0;C=0;do{D=C<<6;gGz(y+D|0,0,64);E=C<<7;F=E|4;G=0;while(1){H=F+(c[6669224+(G<<2)>>2]|0)|0;I=(G<<3)+D|0;J=0;do{K=H+(c[612480+(J<<2)>>2]|0)|0;if(((d[v+((K|0)/8|0)|0]|0)&128>>>((K&7)>>>0)|0)!=0){K=y+(I+J)|0;a[K]=a[K]|2}J=J+1|0;}while((J|0)<8);J=G+1|0;if((J|0)<8){G=J}else{L=0;break}}do{G=E+(c[6669224+(L<<2)>>2]|0)|0;F=(L<<3)+D|0;J=0;do{I=G+(c[612480+(J<<2)>>2]|0)|0;if(((d[v+((I|0)/8|0)|0]|0)&128>>>((I&7)>>>0)|0)!=0){I=y+(F+J)|0;a[I]=a[I]|1}J=J+1|0;}while((J|0)<8);L=L+1|0;}while((L|0)<8);C=C+1|0;}while((C|0)<2048);gGz(v|0,0,524288);if((R6(v+1|0,6,2)|0)!=0){B=1;i=e;return B|0}if((R6(c[3529540]|0,7,2)|0)!=0){B=1;i=e;return B|0}C=c[3529540]|0;y=c[3531070]|0;D=0;do{E=D<<8;gGz(y+E|0,0,256);J=D<<10;F=0;do{G=1<<3-F;I=(c[687256+(F<<2)>>2]|0)+J|0;H=0;do{K=I+(c[611840+(H<<2)>>2]|0)|0;M=(H<<4)+E|0;N=0;do{O=K+(c[609424+(N<<2)>>2]|0)|0;if(((d[C+((O|0)/8|0)|0]|0)&128>>>((O&7)>>>0)|0)!=0){O=y+(M+N)|0;a[O]=(d[O]|0|G)&255}N=N+1|0;}while((N|0)<16);H=H+1|0;}while((H|0)<16);F=F+1|0;}while((F|0)<4);D=D+1|0;}while((D|0)<2048);gGz(C|0,0,524288);if((c[3542200]|0)==0){B=1;i=e;return B|0}D=p+108|0;c[D>>2]=0;y=p+100|0;c[y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,8)|0;do{if((c[D>>2]|0)!=0){v=c[y>>2]|0;c[q>>2]=9534384;F=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[F&16383](q,8,0)|0;if((v|0)<1){B=1;i=e;return B|0}if((gzL(C,0,8)|0)==0){break}else{B=1}i=e;return B|0}}while(0);C=c[3529540]|0;y=c[3530980]|0;D=0;do{v=D<<8;gGz(y+v|0,0,256);F=D<<10;E=0;do{J=1<<3-E;H=(c[687256+(E<<2)>>2]|0)+F|0;G=0;do{I=H+(c[611840+(G<<2)>>2]|0)|0;N=(G<<4)+v|0;M=0;do{K=I+(c[609424+(M<<2)>>2]|0)|0;if(((d[C+((K|0)/8|0)|0]|0)&128>>>((K&7)>>>0)|0)!=0){K=y+(N+M)|0;a[K]=(d[K]|0|J)&255}M=M+1|0;}while((M|0)<16);G=G+1|0;}while((G|0)<16);E=E+1|0;}while((E|0)<4);D=D+1|0;}while((D|0)<4096);gGz(C|0,0,524288);if((c[3542200]|0)==0){B=1;i=e;return B|0}D=n+108|0;c[D>>2]=0;y=n+100|0;c[y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,9)|0;do{if((c[D>>2]|0)!=0){E=c[y>>2]|0;c[o>>2]=9534384;v=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[v&16383](o,9,0)|0;if((E|0)<1){B=1;i=e;return B|0}if((gzL(C,0,9)|0)==0){break}else{B=1}i=e;return B|0}}while(0);C=(c[3529540]|0)+131072|0;if((c[3542200]|0)==0){B=1;i=e;return B|0}y=l+108|0;c[y>>2]=0;D=l+100|0;c[D>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,10)|0;do{if((c[y>>2]|0)!=0){E=c[D>>2]|0;c[m>>2]=9534384;v=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[v&16383](m,10,0)|0;if((E|0)<1){B=1;i=e;return B|0}if((gzL(C,0,10)|0)==0){break}else{B=1}i=e;return B|0}}while(0);C=(c[3529540]|0)+262144|0;if((c[3542200]|0)==0){B=1;i=e;return B|0}D=j+108|0;c[D>>2]=0;y=j+100|0;c[y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,11)|0;do{if((c[D>>2]|0)!=0){E=c[y>>2]|0;c[k>>2]=9534384;v=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[v&16383](k,11,0)|0;if((E|0)<1){B=1;i=e;return B|0}if((gzL(C,0,11)|0)==0){break}else{B=1}i=e;return B|0}}while(0);C=(c[3529540]|0)+393216|0;if((c[3542200]|0)==0){B=1;i=e;return B|0}y=f+108|0;c[y>>2]=0;D=f+100|0;c[D>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,12)|0;do{if((c[y>>2]|0)!=0){E=c[D>>2]|0;c[g>>2]=9534384;v=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[v&16383](g,12,0)|0;if((E|0)<1){B=1;i=e;return B|0}if((gzL(C,0,12)|0)==0){break}else{B=1}i=e;return B|0}}while(0);C=c[3529540]|0;D=c[3529590]|0;y=0;while(1){E=y<<8;gGz(D+E|0,0,256);v=0;do{F=1<<3-v;G=(c[961520+(v<<2)>>2]|0)+E|0;J=0;do{H=G+(c[609008+(J<<2)>>2]|0)|0;M=(J<<4)+E|0;N=0;do{I=H+(c[597864+(N<<2)>>2]|0)|0;if(((d[C+((I|0)/8|0)|0]|0)&128>>>((I&7)>>>0)|0)!=0){I=D+(M+N)|0;a[I]=(d[I]|0|F)&255}N=N+1|0;}while((N|0)<16);J=J+1|0;}while((J|0)<16);v=v+1|0;}while((v|0)<4);v=y+1|0;if((v|0)<4096){y=v}else{P=0;break}}while(1){if((P|0)>=1024){break}Q=9638528+(P<<2)|0;if((c[Q>>2]|0)==(C|0)){x=72395;break}else{P=P+1|0}}if((x|0)==72395){gGr(C);c[Q>>2]=0}c[3529540]=0;fxU(0,425984);if((c[2394]|0)==0){R=c[2112932]|0}else{c[2394]=0;y=c[3532596]|0;c[2112932]=y;D=c[3532592]|0;if((D|0)!=0){gGC(9104152,D|0,280)|0}c[2113054]=c[2113060];R=y}y=c[2388036]|0;D=R|0;v=0;while(1){E=y+v|0;c[D>>2]=E;c[D+131072>>2]=E;E=v+1024|0;if(E>>>0>393215){break}else{D=D+4|0;v=E}}v=c[2443430]|0;c[R+64520>>2]=v;c[R+130056>>2]=v;c[R+195592>>2]=v;D=v+1024|0;c[R+64524>>2]=D;c[R+130060>>2]=D;c[R+195596>>2]=D;D=c[3527222]|0;c[R+64704>>2]=D;c[R+130240>>2]=D;c[R+195776>>2]=D;v=D+1024|0;c[R+64708>>2]=v;c[R+130244>>2]=v;c[R+195780>>2]=v;v=D+2048|0;c[R+64712>>2]=v;c[R+130248>>2]=v;c[R+195784>>2]=v;v=D+3072|0;c[R+64716>>2]=v;c[R+130252>>2]=v;c[R+195788>>2]=v;v=D+4096|0;c[R+64720>>2]=v;c[R+130256>>2]=v;c[R+195792>>2]=v;v=D+5120|0;c[R+64724>>2]=v;c[R+130260>>2]=v;c[R+195796>>2]=v;v=D+6144|0;c[R+64728>>2]=v;c[R+130264>>2]=v;c[R+195800>>2]=v;v=D+7168|0;c[R+64732>>2]=v;c[R+130268>>2]=v;c[R+195804>>2]=v;v=c[2439584]|0;c[R+64768>>2]=v;c[R+130304>>2]=v;c[R+195840>>2]=v;D=v+1024|0;c[R+64772>>2]=D;c[R+130308>>2]=D;c[R+195844>>2]=D;D=v+2048|0;c[R+64776>>2]=D;c[R+130312>>2]=D;c[R+195848>>2]=D;D=v+3072|0;c[R+64780>>2]=D;c[R+130316>>2]=D;c[R+195852>>2]=D;D=v+4096|0;c[R+64784>>2]=D;c[R+130320>>2]=D;c[R+195856>>2]=D;D=v+5120|0;c[R+64788>>2]=D;c[R+130324>>2]=D;c[R+195860>>2]=D;D=v+6144|0;c[R+64792>>2]=D;c[R+130328>>2]=D;c[R+195864>>2]=D;D=v+7168|0;c[R+64796>>2]=D;c[R+130332>>2]=D;c[R+195868>>2]=D;D=v+8192|0;c[R+64800>>2]=D;c[R+130336>>2]=D;c[R+195872>>2]=D;D=v+9216|0;c[R+64804>>2]=D;c[R+130340>>2]=D;c[R+195876>>2]=D;D=v+10240|0;c[R+64808>>2]=D;c[R+130344>>2]=D;c[R+195880>>2]=D;D=v+11264|0;c[R+64812>>2]=D;c[R+130348>>2]=D;c[R+195884>>2]=D;D=v+12288|0;c[R+64816>>2]=D;c[R+130352>>2]=D;c[R+195888>>2]=D;D=v+13312|0;c[R+64820>>2]=D;c[R+130356>>2]=D;c[R+195892>>2]=D;D=v+14336|0;c[R+64824>>2]=D;c[R+130360>>2]=D;c[R+195896>>2]=D;D=v+15360|0;c[R+64828>>2]=D;c[R+130364>>2]=D;c[R+195900>>2]=D;D=c[2439582]|0;c[R+64832>>2]=D;c[R+130368>>2]=D;c[R+195904>>2]=D;v=D+1024|0;c[R+64836>>2]=v;c[R+130372>>2]=v;c[R+195908>>2]=v;v=D+2048|0;c[R+64840>>2]=v;c[R+130376>>2]=v;c[R+195912>>2]=v;v=D+3072|0;c[R+64844>>2]=v;c[R+130380>>2]=v;c[R+195916>>2]=v;v=D+4096|0;c[R+64848>>2]=v;c[R+130384>>2]=v;c[R+195920>>2]=v;v=D+5120|0;c[R+64852>>2]=v;c[R+130388>>2]=v;c[R+195924>>2]=v;v=D+6144|0;c[R+64856>>2]=v;c[R+130392>>2]=v;c[R+195928>>2]=v;v=D+7168|0;c[R+64860>>2]=v;c[R+130396>>2]=v;c[R+195932>>2]=v;v=D+8192|0;c[R+64864>>2]=v;c[R+130400>>2]=v;c[R+195936>>2]=v;v=D+9216|0;c[R+64868>>2]=v;c[R+130404>>2]=v;c[R+195940>>2]=v;v=D+10240|0;c[R+64872>>2]=v;c[R+130408>>2]=v;c[R+195944>>2]=v;v=D+11264|0;c[R+64876>>2]=v;c[R+130412>>2]=v;c[R+195948>>2]=v;v=D+12288|0;c[R+64880>>2]=v;c[R+130416>>2]=v;c[R+195952>>2]=v;v=D+13312|0;c[R+64884>>2]=v;c[R+130420>>2]=v;c[R+195956>>2]=v;v=D+14336|0;c[R+64888>>2]=v;c[R+130424>>2]=v;c[R+195960>>2]=v;v=D+15360|0;c[R+64892>>2]=v;c[R+130428>>2]=v;c[R+195964>>2]=v;v=c[2439624]|0;c[R+64896>>2]=v;c[R+130432>>2]=v;c[R+195968>>2]=v;D=v+1024|0;c[R+64900>>2]=D;c[R+130436>>2]=D;c[R+195972>>2]=D;D=c[2388058]|0;v=R+65024|0;y=16646144;while(1){C=D+(y-16646144)|0;c[v>>2]=C;c[v+65536>>2]=C;c[v+131072>>2]=C;C=y+1024|0;if(C>>>0>16777215){break}else{v=v+4|0;y=C}}c[R+196688>>2]=2996;c[R+196728>>2]=338;c[R+196648>>2]=1820;y=c[3532592]|0;if((y|0)!=0){gGC(y|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);y=c[2439330]|0;v=(y|0)==0;if(!v){D=y;gGC(9706056,D|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];D=c[3528484]|0;c[2076596]=D;C=c[2417276]|0;c[3541536]=C;c[1836236]=0;c[y+4180>>2]=580;c[y+4184>>2]=3042;E=c[2385844]|0;J=0;F=0;while(1){c[y+76+(F<<2)>>2]=E+(F<<8);G=J+1&65535;if((G&65535)>223){S=0;T=0;break}else{J=G;F=G&65535}}while(1){F=E+(T<<8)|0;c[y+76+(T+512<<2)>>2]=F;c[y+76+(T+768<<2)>>2]=F;F=S+1&65535;if((F&65535)>223){break}else{S=F;T=F&65535}}E=c[2385862]|0;c[y+972>>2]=E;F=E+256|0;c[y+976>>2]=F;J=E+512|0;c[y+980>>2]=J;G=E+768|0;c[y+984>>2]=G;N=E+1024|0;c[y+988>>2]=N;M=E+1280|0;c[y+992>>2]=M;H=E+1536|0;c[y+996>>2]=H;I=E+1792|0;c[y+1e3>>2]=I;c[y+1996>>2]=E;c[y+2e3>>2]=F;c[y+2004>>2]=J;c[y+2008>>2]=G;c[y+2012>>2]=N;c[y+2016>>2]=M;c[y+2020>>2]=H;c[y+2024>>2]=I;c[y+3020>>2]=E;c[y+4044>>2]=E;c[y+3024>>2]=F;c[y+4048>>2]=F;c[y+3028>>2]=J;c[y+4052>>2]=J;c[y+3032>>2]=G;c[y+4056>>2]=G;c[y+3036>>2]=N;c[y+4060>>2]=N;c[y+3040>>2]=M;c[y+4064>>2]=M;c[y+3044>>2]=H;c[y+4068>>2]=H;c[y+3048>>2]=I;c[y+4072>>2]=I;if(!v){I=y;gGC(I|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=D;c[2417276]=C;c[1836236]=-1;I=c[642608+(c[2436]<<2)>>2]|0;H=c[I+128>>2]|0;if((c[I+52>>2]&4|0)==0){c[2113068]=H;M=c[I+132>>2]|0;c[2113070]=M;c[2443814]=H;c[2440436]=M;U=H;V=M}else{c[2113070]=H;M=c[I+132>>2]|0;c[2113068]=M;c[2440436]=H;c[2443814]=M;U=M;V=H}H=ag(U<<1,V)|0;M=gGq(H)|0;c[2112926]=M;if((M|0)!=0){gGz(M|0,0,H|0)}a[1950792]=0;a[9720896]=64;Vr(2,3579545,2386,1286,44,0);c[2438228]=3579545;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=571;h[745419]=.4;a[3203368]=1;h[745418]=.4;a[3203360]=1;h[745417]=.4;a[3203352]=1;h[745416]=.4;a[3203344]=1;h[745415]=.4;a[3203336]=1;h[745414]=.4;a[3203328]=1;h[745413]=.4;a[3203320]=1;h[745412]=.4;a[3203312]=1;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];H=c[3532592]|0;if((H|0)!=0){gGC(9104152,H|0,280)|0}c[2113054]=c[2113060]}RI();H=c[2394]|0;M=c[14130368+(H<<2)>>2]|0;if((M|0)!=0){gGC(M|0,9104152,280)|0}c[8452240+(H<<2)>>2]=c[2113054];c[2394]=-1;H=c[2439330]|0;M=(H|0)==0;if(!M){I=H;gGC(9706056,I|0,76)|0}I=c[2438118]|0;c[2433530]=I;N=c[3528484]|0;c[2076596]=N;G=c[2417276]|0;c[3541536]=G;c[1836236]=0;gGz(9706056,0,76);if(!M){M=H;gGC(M|0,9706056,76)|0}c[2438118]=I;c[3528484]=N;c[2417276]=G;c[1836236]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){G=0;do{lN(G);mB(G);G=G+1|0;}while((G|0)<(c[2385508]|0))}b[4887148]=0;b[4887132]=0;b[4887208]=0;b[4887184]=0;a[9758008]=0;a[9758232]=0;B=0;i=e;return B|0}}while(0);c[2426792]=0;B=1;i=e;return B|0}function dok(){var d=0,e=0,f=0,g=0,h=0;if((c[2392]|0)>=0){d=0;do{e=14130368+(d<<2)|0;f=c[e>>2]|0;if((f|0)!=0){gGr(f);c[e>>2]=0}e=14130384+(d<<2)|0;f=c[e>>2]|0;if((f|0)!=0){gGr(f);c[e>>2]=0}d=d+1|0;}while((d|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;fwZ();d=c[3541518]|0;if((d|0)!=0){gGr(d|0);c[3541518]=0}if((c[2385508]|0)>0){c[2113008]=0;c[2076598]=0;c[2383582]=0}c[2438228]=0;c[2433526]=0;c[2406676]=0;c[3528472]=0;d=c[2406680]|0;if((d|0)!=0){gGr(d);c[2406680]=0}c[2385508]=0;c[2432978]=0;a[64240]=0;c[2113070]=0;c[2113068]=0;d=c[2112926]|0;if((d|0)!=0){gGr(d);c[2112926]=0}b[4887148]=0;b[4887132]=0;b[4887208]=0;b[4887184]=0;a[1950792]=0;a[9720896]=0;a[9758008]=0;a[9758232]=0;d=c[2426792]|0;e=0;while(1){if((e|0)>=1024){g=72487;break}h=9638528+(e<<2)|0;if((c[h>>2]|0)==(d|0)){break}else{e=e+1|0}}if((g|0)==72487){c[2426792]=0;return 0}gGr(d);c[h>>2]=0;c[2426792]=0;return 0}function dol(){var f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;if((a[9624720]|0)!=0){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060]}RI();f=c[2394]|0;g=c[14130368+(f<<2)>>2]|0;if((g|0)!=0){gGC(g|0,9104152,280)|0}c[8452240+(f<<2)>>2]=c[2113054];c[2394]=-1;f=c[2439330]|0;g=(f|0)==0;if(!g){i=f;gGC(9706056,i|0,76)|0}i=c[2438118]|0;c[2433530]=i;j=c[3528484]|0;c[2076596]=j;k=c[2417276]|0;c[3541536]=k;c[1836236]=0;gGz(9706056,0,76);if(!g){g=f;gGC(g|0,9706056,76)|0}c[2438118]=i;c[3528484]=j;c[2417276]=k;c[1836236]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){k=0;do{lN(k);mB(k);k=k+1|0;}while((k|0)<(c[2385508]|0))}b[4887148]=0;b[4887132]=0;b[4887208]=0;b[4887184]=0;a[9758008]=0;a[9758232]=0}a[9625866]=0;a[9625865]=0;a[9625864]=0;k=0;j=0;i=0;g=0;do{j=((a[9759264+k|0]&1)<<k|j&255)&255;i=((a[9759072+k|0]&1)<<k|i&255)&255;g=((a[9758888+k|0]&1)<<k|g&255)&255;k=k+1|0;}while((k|0)<8);a[9625864]=j;a[9625865]=i;a[9625866]=g;if((j&3)==3){g=j&-4;a[9625864]=g;l=g}else{l=j}if((l&12)==12){a[9625864]=l&-13}if((i&3)==3){l=i&-4;a[9625865]=l;m=l}else{m=i}if((m&12)==12){a[9625865]=m&-13}a[6518328]=1;a[6518152]=1;c[2444107]=0;c[2444106]=0;m=c[2392]|0;if((m|0)>=0){gGz(8452240,0,((m|0)>0?(m<<2)+4|0:4)|0)}c[2113054]=0;m=c[2385548]|0;if((m|0)>0){gGz(9752472,0,((m|0)>1?m<<2:4)|0)}c[2433530]=0;m=0;while(1){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];i=c[3532592]|0;if((i|0)!=0){gGC(9104152,i|0,280)|0}c[2113054]=c[2113060]}i=m+1|0;l=(ag(a[6518328]|0?166666:0,i)|0)/100|0;j=l-(c[2444106]|0)|0;c[2438200]=j;c[2113056]=j;l=RG(j)|0;c[2113054]=(c[2113054]|0)+l;c[2276108]=-1;c[2113056]=-1;c[2444106]=(c[2444106]|0)+l;do{if((m|0)==66|(m|0)==33){c[8452200+(c[2394]<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0>=1024){break}RH(4)}}while(0);l=c[2394]|0;j=c[14130368+(l<<2)>>2]|0;if((j|0)!=0){gGC(j|0,9104152,280)|0}c[8452240+(l<<2)>>2]=c[2113054];c[2394]=-1;l=c[2439330]|0;if((l|0)!=0){j=l;gGC(9706056,j|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;Sb(ag(a[6518152]|0?596:0,m)|0);j=c[1836236]|0;l=c[9757320+(j<<2)>>2]|0;if((l|0)!=0){g=l;gGC(g|0,9706056,76)|0}c[9752472+(j<<2)>>2]=c[2433530];c[14113936+(j<<2)>>2]=c[2076596];c[9669104+(j<<2)>>2]=c[3541536];c[1836236]=-1;if((i|0)<100){m=i}else{break}}m=c[2439330]|0;if((m|0)!=0){j=m;gGC(9706056,j|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;j=a[6518152]|0?59659:0;m=gGU(j,0,2048e6,0)|0;g=c[2438228]|0;l=gGS(m,K,g,(g|0)<0|0?-1:0)|0;g=l;Sb(j);j=c[2443830]|0;if((j|0)<1073676288){c[2443830]=j-g}j=c[2443831]|0;if((j|0)<1073676288){c[2443831]=j-g}j=(c[3528512]|0)-g|0;c[3528512]=(j|0)<0?0:j;j=c[2112964]|0;if((j|0)!=0){gg[c[3542122]&4095](j,a[9688]|0?534:0)}j=c[1836236]|0;g=c[9757320+(j<<2)>>2]|0;if((g|0)!=0){l=g;gGC(l|0,9706056,76)|0}c[9752472+(j<<2)>>2]=c[2433530];c[14113936+(j<<2)>>2]=c[2076596];c[9669104+(j<<2)>>2]=c[3541536];c[1836236]=-1;if((c[2112968]|0)!=0){j=c[2112926]|0;gGz(j|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);l=c[3530112]|0;g=0;m=c[2439624]|0;k=l;while(1){f=e[m>>1]|0;n=d[591736+(f&15)|0]|0;o=ag(f>>>4&15,n)|0;p=(ag(f>>>12<<8,n)|0)&63488;c[k>>2]=(ag(f>>>8<<3&120,n)|0)&2016|p|o>>>3&31;o=g+1|0;if((o|0)<2048){g=o;m=m+2|0;k=k+4|0}else{break}}k=c[2439582]|0;m=c[3531070]|0;g=0;o=0;while(1){p=o<<4;n=g;f=0;while(1){q=n<<1;r=b[k+(q<<1)>>1]&8191;s=e[k+((q|1)<<1)>>1]|0;q=s>>>5&1;t=s>>>6&1;u=s&15;s=(f<<4)-(e[4887208]|0)|0;v=p-(e[4887184]|0)|0;w=(s|0)<-16?s+1024|0:s;s=(v|0)<-16?v+1024|0:v;v=w-64|0;x=s-8|0;do{if((w-81|0)>>>0<351){if((s-25|0)>>>0>=207){y=72556;break}z=(t|0)!=0;if((q|0)==0){if(z){SC(j,r,v,x,u,4,0,m);break}else{Sy(j,r,v,x,u,4,0,m);break}}else{if(z){SE(j,r,v,x,u,4,0,m);break}else{SA(j,r,v,x,u,4,0,m);break}}}else{y=72556}}while(0);do{if((y|0)==72556){y=0;s=(t|0)!=0;if((q|0)==0){if(s){SD(j,r,v,x,u,4,0,m);break}else{Sz(j,r,v,x,u,4,0,m);break}}else{if(s){SF(j,r,v,x,u,4,0,m);break}else{SB(j,r,v,x,u,4,0,m);break}}}}while(0);u=f+1|0;if((u|0)<64){n=n+1|0;f=u}else{break}}f=o+1|0;if((f|0)<64){g=g+64|0;o=f}else{break}}doP(0);doN(0);doP(1);doO();R8(l)}if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];l=c[3532592]|0;if((l|0)!=0){gGC(9104152,l|0,280)|0}c[2113054]=c[2113060]}c[2113050]=8194;c[2276080]=512;if((c[2276079]|0)>>>0<512){RH(2);A=c[2394]|0}else{A=0}l=c[14130368+(A<<2)>>2]|0;if((l|0)==0){B=c[2113054]|0;C=8452240+(A<<2)|0;c[C>>2]=B;c[2394]=-1;D=c[2430220]|0;E=c[2443430]|0;gGC(D|0,E|0,2048)|0;return 0}gGC(l|0,9104152,280)|0;B=c[2113054]|0;C=8452240+(A<<2)|0;c[C>>2]=B;c[2394]=-1;D=c[2430220]|0;E=c[2443430]|0;gGC(D|0,E|0,2048)|0;return 0}function dom(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;e=i;i=i+224|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;l=e+80|0;m=e+96|0;n=e+112|0;o=e+128|0;p=e+144|0;q=e+160|0;r=e+176|0;s=e+192|0;t=e+208|0;if((d|0)!=0){c[d>>2]=169586}if((b&32|0)!=0){gGz(t|0,0,12);u=c[2405702]|0;c[t>>2]=u;c[t+4>>2]=(c[2411788]|0)-u;c[t+12>>2]=162152;u=c[2076592]|0;gj[u&4095](t)|0}if((b&64|0)==0){i=e;return 0}t=h|0;gGz(g|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){u=h+9|0;h=f;v=f|0;w=f+4|0;x=f+12|0;y=g|0;z=g+4|0;A=g+12|0;B=0;do{gGC(t|0,614896,11)|0;a[u]=B+48&255;C=8452256+(B<<2)|0;gGz(h|0,0,12);c[v>>2]=C;c[w>>2]=4;c[x>>2]=164976;gj[c[2076592]&4095](f)|0;if((c[C>>2]|0)!=0){c[y>>2]=c[14130368+(B<<2)>>2];c[z>>2]=c[8452184+(B<<2)>>2];c[A>>2]=t;C=c[2076592]|0;gj[C&4095](g)|0}B=B+1|0;}while((B|0)<=(c[2392]|0))}fw$(b);Vx(b,d);gGz(s|0,0,12);c[s>>2]=9776424;c[s+4>>2]=8;c[s+12>>2]=212472;gj[c[2076592]&4095](s)|0;gGz(r|0,0,12);c[r>>2]=9752800;c[r+4>>2]=4;c[r+12>>2]=436576;gj[c[2076592]&4095](r)|0;gGz(q|0,0,12);c[q>>2]=9758008;c[q+4>>2]=1;c[q+12>>2]=69824;gj[c[2076592]&4095](q)|0;gGz(p|0,0,12);c[p>>2]=9758232;c[p+4>>2]=1;c[p+12>>2]=497064;gj[c[2076592]&4095](p)|0;gGz(o|0,0,12);c[o>>2]=9774296;c[o+4>>2]=2;c[o+12>>2]=163920;gj[c[2076592]&4095](o)|0;gGz(n|0,0,12);c[n>>2]=9774264;c[n+4>>2]=2;c[n+12>>2]=160104;gj[c[2076592]&4095](n)|0;gGz(m|0,0,12);c[m>>2]=9774416;c[m+4>>2]=2;c[m+12>>2]=169648;gj[c[2076592]&4095](m)|0;gGz(l|0,0,12);c[l>>2]=9774368;c[l+4>>2]=2;c[l+12>>2]=166776;gj[c[2076592]&4095](l)|0;gGz(k|0,0,12);c[k>>2]=9658048;c[k+4>>2]=3;c[k+12>>2]=483352;gj[c[2076592]&4095](k)|0;gGz(j|0,0,12);c[j>>2]=9625864;c[j+4>>2]=3;c[j+12>>2]=215728;gj[c[2076592]&4095](j)|0;i=e;return 0}function don(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1844644+(b*112|0)>>2];c[a+104>>2]=c[1844648+(b*112|0)>>2];c[a+108>>2]=c[1844652+(b*112|0)>>2];d=0;return d|0}function doo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=1844544+(b*112|0);e=0;return e|0}function dop(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1846212+(b*112|0)>>2];c[a+104>>2]=c[1846216+(b*112|0)>>2];c[a+108>>2]=c[1846220+(b*112|0)>>2];d=0;return d|0}function doq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=1846112+(b*112|0);e=0;return e|0}function dor(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>28){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1847780+(b*112|0)>>2];c[a+104>>2]=c[1847784+(b*112|0)>>2];c[a+108>>2]=c[1847788+(b*112|0)>>2];d=0;return d|0}function dos(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<29&(d|0)==0)){e=1;return e|0}c[a>>2]=1847680+(b*112|0);e=0;return e|0}function dot(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0;e=i;i=i+1200|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;c[2426792]=0;c[2388036]=0;c[2385844]=524288;c[3541206]=589824;c[2405702]=851968;c[2388058]=851968;c[2385862]=983040;c[2443430]=985088;c[2430220]=987136;c[3527222]=989184;c[2439624]=997376;c[2439584]=999424;c[2439582]=1015808;c[2411788]=1048576;c[2406538]=1048576;c[3531070]=1179648;c[3530980]=1703936;c[3529590]=2752512;c[3530112]=3801088;B=0;while(1){if((B|0)>=1024){break}C=9638528+(B<<2)|0;if((c[C>>2]|0)==0){D=72630;break}else{B=B+1|0}}do{if((D|0)==72630){B=gGq(3809280)|0;c[C>>2]=B;if((B|0)==0){break}c[2426792]=B;gGz(B|0,0,3809280);c[2388036]=B;c[2385844]=B+524288;c[3541206]=B+589824;E=B+851968|0;c[2405702]=E;c[2388058]=E;c[2385862]=B+983040;c[2443430]=B+985088;c[2430220]=B+987136;c[3527222]=B+989184;c[2439624]=B+997376;c[2439584]=B+999424;c[2439582]=B+1015808;E=B+1048576|0;c[2411788]=E;c[2406538]=E;c[3531070]=B+1179648;c[3530980]=B+1703936;c[3529590]=B+2752512;c[3530112]=B+3801088;c[2414336]=B+3809280;B=0;while(1){if((B|0)>=1024){F=0;break}G=9638528+(B<<2)|0;if((c[G>>2]|0)==0){D=72635;break}else{B=B+1|0}}do{if((D|0)==72635){B=gGq(524288)|0;c[G>>2]=B;if((B|0)==0){F=0;break}gGz(B|0,0,524288);F=B}}while(0);c[3529540]=F;if((R6((c[2388036]|0)+1|0,0,2)|0)!=0){H=1;i=e;return H|0}if((R6(c[2388036]|0,1,2)|0)!=0){H=1;i=e;return H|0}if((R6((c[2388036]|0)+131073|0,2,2)|0)!=0){H=1;i=e;return H|0}if((R6((c[2388036]|0)+131072|0,3,2)|0)!=0){H=1;i=e;return H|0}if((R6((c[2388036]|0)+262145|0,4,2)|0)!=0){H=1;i=e;return H|0}if((R6((c[2388036]|0)+262144|0,5,2)|0)!=0){H=1;i=e;return H|0}B=c[2385844]|0;if((c[3542200]|0)==0){H=1;i=e;return H|0}E=z+108|0;c[E>>2]=0;I=z+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,6)|0;do{if((c[E>>2]|0)!=0){J=c[I>>2]|0;c[A>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](A,6,0)|0;if((J|0)<1){H=1;i=e;return H|0}if((gzL(B,0,6)|0)==0){break}else{H=1}i=e;return H|0}}while(0);B=c[3529540]|0;if((c[3542200]|0)==0){H=1;i=e;return H|0}I=x+108|0;c[I>>2]=0;E=x+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,7)|0;do{if((c[I>>2]|0)!=0){J=c[E>>2]|0;c[y>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](y,7,0)|0;if((J|0)<1){H=1;i=e;return H|0}if((gzL(B,0,7)|0)==0){break}else{H=1}i=e;return H|0}}while(0);B=c[3529540]|0;E=c[2406538]|0;I=0;do{J=I<<6;gGz(E+J|0,0,64);K=I<<7;L=K|4;M=0;while(1){N=L+(c[6669224+(M<<2)>>2]|0)|0;O=(M<<3)+J|0;P=0;do{Q=N+(c[612480+(P<<2)>>2]|0)|0;if(((d[B+((Q|0)/8|0)|0]|0)&128>>>((Q&7)>>>0)|0)!=0){Q=E+(O+P)|0;a[Q]=a[Q]|2}P=P+1|0;}while((P|0)<8);P=M+1|0;if((P|0)<8){M=P}else{R=0;break}}do{M=K+(c[6669224+(R<<2)>>2]|0)|0;L=(R<<3)+J|0;P=0;do{O=M+(c[612480+(P<<2)>>2]|0)|0;if(((d[B+((O|0)/8|0)|0]|0)&128>>>((O&7)>>>0)|0)!=0){O=E+(L+P)|0;a[O]=a[O]|1}P=P+1|0;}while((P|0)<8);R=R+1|0;}while((R|0)<8);I=I+1|0;}while((I|0)<2048);gGz(B|0,0,524288);if((R6(B+1|0,8,2)|0)!=0){H=1;i=e;return H|0}if((R6((c[3529540]|0)+131073|0,9,2)|0)!=0){H=1;i=e;return H|0}if((R6(c[3529540]|0,10,2)|0)!=0){H=1;i=e;return H|0}if((R6((c[3529540]|0)+131072|0,11,2)|0)!=0){H=1;i=e;return H|0}I=c[3529540]|0;E=c[3531070]|0;J=0;do{K=J<<8;gGz(E+K|0,0,256);P=J<<10;L=0;do{M=1<<3-L;O=(c[687256+(L<<2)>>2]|0)+P|0;N=0;do{Q=O+(c[611840+(N<<2)>>2]|0)|0;S=(N<<4)+K|0;T=0;do{U=Q+(c[609424+(T<<2)>>2]|0)|0;if(((d[I+((U|0)/8|0)|0]|0)&128>>>((U&7)>>>0)|0)!=0){U=E+(S+T)|0;a[U]=(d[U]|0|M)&255}T=T+1|0;}while((T|0)<16);N=N+1|0;}while((N|0)<16);L=L+1|0;}while((L|0)<4);J=J+1|0;}while((J|0)<2048);gGz(I|0,0,524288);if((R6(I+1|0,12,2)|0)!=0){H=1;i=e;return H|0}if((R6(c[3529540]|0,13,2)|0)!=0){H=1;i=e;return H|0}if((R6((c[3529540]|0)+131073|0,14,2)|0)!=0){H=1;i=e;return H|0}if((R6((c[3529540]|0)+131072|0,15,2)|0)!=0){H=1;i=e;return H|0}if((R6((c[3529540]|0)+262145|0,16,2)|0)!=0){H=1;i=e;return H|0}if((R6((c[3529540]|0)+262144|0,17,2)|0)!=0){H=1;i=e;return H|0}if((R6((c[3529540]|0)+393217|0,18,2)|0)!=0){H=1;i=e;return H|0}if((R6((c[3529540]|0)+393216|0,19,2)|0)!=0){H=1;i=e;return H|0}J=c[3529540]|0;E=c[3530980]|0;B=0;do{L=B<<8;gGz(E+L|0,0,256);K=B<<10;P=0;do{N=1<<3-P;M=(c[687256+(P<<2)>>2]|0)+K|0;O=0;do{T=M+(c[611840+(O<<2)>>2]|0)|0;S=(O<<4)+L|0;Q=0;do{U=T+(c[609424+(Q<<2)>>2]|0)|0;if(((d[J+((U|0)/8|0)|0]|0)&128>>>((U&7)>>>0)|0)!=0){U=E+(S+Q)|0;a[U]=(d[U]|0|N)&255}Q=Q+1|0;}while((Q|0)<16);O=O+1|0;}while((O|0)<16);P=P+1|0;}while((P|0)<4);B=B+1|0;}while((B|0)<4096);gGz(J|0,0,524288);if((c[3542200]|0)==0){H=1;i=e;return H|0}B=v+108|0;c[B>>2]=0;E=v+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,20)|0;do{if((c[B>>2]|0)!=0){I=c[E>>2]|0;c[w>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](w,20,0)|0;if((I|0)<1){H=1;i=e;return H|0}if((gzL(J,0,20)|0)==0){break}else{H=1}i=e;return H|0}}while(0);J=(c[3529540]|0)+65536|0;if((c[3542200]|0)==0){H=1;i=e;return H|0}E=t+108|0;c[E>>2]=0;B=t+100|0;c[B>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,21)|0;do{if((c[E>>2]|0)!=0){I=c[B>>2]|0;c[u>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](u,21,0)|0;if((I|0)<1){H=1;i=e;return H|0}if((gzL(J,0,21)|0)==0){break}else{H=1}i=e;return H|0}}while(0);J=(c[3529540]|0)+131072|0;if((c[3542200]|0)==0){H=1;i=e;return H|0}B=r+108|0;c[B>>2]=0;E=r+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,22)|0;do{if((c[B>>2]|0)!=0){I=c[E>>2]|0;c[s>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](s,22,0)|0;if((I|0)<1){H=1;i=e;return H|0}if((gzL(J,0,22)|0)==0){break}else{H=1}i=e;return H|0}}while(0);J=(c[3529540]|0)+196608|0;if((c[3542200]|0)==0){H=1;i=e;return H|0}E=p+108|0;c[E>>2]=0;B=p+100|0;c[B>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,23)|0;do{if((c[E>>2]|0)!=0){I=c[B>>2]|0;c[q>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](q,23,0)|0;if((I|0)<1){H=1;i=e;return H|0}if((gzL(J,0,23)|0)==0){break}else{H=1}i=e;return H|0}}while(0);J=(c[3529540]|0)+262144|0;if((c[3542200]|0)==0){H=1;i=e;return H|0}B=n+108|0;c[B>>2]=0;E=n+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,24)|0;do{if((c[B>>2]|0)!=0){I=c[E>>2]|0;c[o>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](o,24,0)|0;if((I|0)<1){H=1;i=e;return H|0}if((gzL(J,0,24)|0)==0){break}else{H=1}i=e;return H|0}}while(0);J=(c[3529540]|0)+327680|0;if((c[3542200]|0)==0){H=1;i=e;return H|0}E=l+108|0;c[E>>2]=0;B=l+100|0;c[B>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,25)|0;do{if((c[E>>2]|0)!=0){I=c[B>>2]|0;c[m>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](m,25,0)|0;if((I|0)<1){H=1;i=e;return H|0}if((gzL(J,0,25)|0)==0){break}else{H=1}i=e;return H|0}}while(0);J=(c[3529540]|0)+393216|0;if((c[3542200]|0)==0){H=1;i=e;return H|0}B=j+108|0;c[B>>2]=0;E=j+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,26)|0;do{if((c[B>>2]|0)!=0){I=c[E>>2]|0;c[k>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](k,26,0)|0;if((I|0)<1){H=1;i=e;return H|0}if((gzL(J,0,26)|0)==0){break}else{H=1}i=e;return H|0}}while(0);J=(c[3529540]|0)+458752|0;if((c[3542200]|0)==0){H=1;i=e;return H|0}E=f+108|0;c[E>>2]=0;B=f+100|0;c[B>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,27)|0;do{if((c[E>>2]|0)!=0){I=c[B>>2]|0;c[g>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](g,27,0)|0;if((I|0)<1){H=1;i=e;return H|0}if((gzL(J,0,27)|0)==0){break}else{H=1}i=e;return H|0}}while(0);J=c[3529540]|0;B=c[3529590]|0;E=0;while(1){I=E<<8;gGz(B+I|0,0,256);P=0;do{L=1<<3-P;K=(c[961520+(P<<2)>>2]|0)+I|0;O=0;do{N=K+(c[609008+(O<<2)>>2]|0)|0;M=(O<<4)+I|0;Q=0;do{S=N+(c[597864+(Q<<2)>>2]|0)|0;if(((d[J+((S|0)/8|0)|0]|0)&128>>>((S&7)>>>0)|0)!=0){S=B+(M+Q)|0;a[S]=(d[S]|0|L)&255}Q=Q+1|0;}while((Q|0)<16);O=O+1|0;}while((O|0)<16);P=P+1|0;}while((P|0)<4);P=E+1|0;if((P|0)<4096){E=P}else{V=0;break}}while(1){if((V|0)>=1024){break}W=9638528+(V<<2)|0;if((c[W>>2]|0)==(J|0)){D=72734;break}else{V=V+1|0}}if((D|0)==72734){gGr(J);c[W>>2]=0}c[3529540]=0;fxU(0,425984);if((c[2394]|0)==0){X=c[2112932]|0}else{c[2394]=0;E=c[3532596]|0;c[2112932]=E;B=c[3532592]|0;if((B|0)!=0){gGC(9104152,B|0,280)|0}c[2113054]=c[2113060];X=E}E=c[2388036]|0;B=X|0;P=0;while(1){I=E+P|0;c[B>>2]=I;c[B+131072>>2]=I;I=P+1024|0;if(I>>>0>393215){break}else{B=B+4|0;P=I}}P=c[2443430]|0;c[X+64520>>2]=P;c[X+130056>>2]=P;c[X+195592>>2]=P;B=P+1024|0;c[X+64524>>2]=B;c[X+130060>>2]=B;c[X+195596>>2]=B;B=c[3527222]|0;c[X+64704>>2]=B;c[X+130240>>2]=B;c[X+195776>>2]=B;P=B+1024|0;c[X+64708>>2]=P;c[X+130244>>2]=P;c[X+195780>>2]=P;P=B+2048|0;c[X+64712>>2]=P;c[X+130248>>2]=P;c[X+195784>>2]=P;P=B+3072|0;c[X+64716>>2]=P;c[X+130252>>2]=P;c[X+195788>>2]=P;P=B+4096|0;c[X+64720>>2]=P;c[X+130256>>2]=P;c[X+195792>>2]=P;P=B+5120|0;c[X+64724>>2]=P;c[X+130260>>2]=P;c[X+195796>>2]=P;P=B+6144|0;c[X+64728>>2]=P;c[X+130264>>2]=P;c[X+195800>>2]=P;P=B+7168|0;c[X+64732>>2]=P;c[X+130268>>2]=P;c[X+195804>>2]=P;P=c[2439584]|0;c[X+64768>>2]=P;c[X+130304>>2]=P;c[X+195840>>2]=P;B=P+1024|0;c[X+64772>>2]=B;c[X+130308>>2]=B;c[X+195844>>2]=B;B=P+2048|0;c[X+64776>>2]=B;c[X+130312>>2]=B;c[X+195848>>2]=B;B=P+3072|0;c[X+64780>>2]=B;c[X+130316>>2]=B;c[X+195852>>2]=B;B=P+4096|0;c[X+64784>>2]=B;c[X+130320>>2]=B;c[X+195856>>2]=B;B=P+5120|0;c[X+64788>>2]=B;c[X+130324>>2]=B;c[X+195860>>2]=B;B=P+6144|0;c[X+64792>>2]=B;c[X+130328>>2]=B;c[X+195864>>2]=B;B=P+7168|0;c[X+64796>>2]=B;c[X+130332>>2]=B;c[X+195868>>2]=B;B=P+8192|0;c[X+64800>>2]=B;c[X+130336>>2]=B;c[X+195872>>2]=B;B=P+9216|0;c[X+64804>>2]=B;c[X+130340>>2]=B;c[X+195876>>2]=B;B=P+10240|0;c[X+64808>>2]=B;c[X+130344>>2]=B;c[X+195880>>2]=B;B=P+11264|0;c[X+64812>>2]=B;c[X+130348>>2]=B;c[X+195884>>2]=B;B=P+12288|0;c[X+64816>>2]=B;c[X+130352>>2]=B;c[X+195888>>2]=B;B=P+13312|0;c[X+64820>>2]=B;c[X+130356>>2]=B;c[X+195892>>2]=B;B=P+14336|0;c[X+64824>>2]=B;c[X+130360>>2]=B;c[X+195896>>2]=B;B=P+15360|0;c[X+64828>>2]=B;c[X+130364>>2]=B;c[X+195900>>2]=B;B=c[2439582]|0;c[X+64832>>2]=B;c[X+130368>>2]=B;c[X+195904>>2]=B;P=B+1024|0;c[X+64836>>2]=P;c[X+130372>>2]=P;c[X+195908>>2]=P;P=B+2048|0;c[X+64840>>2]=P;c[X+130376>>2]=P;c[X+195912>>2]=P;P=B+3072|0;c[X+64844>>2]=P;c[X+130380>>2]=P;c[X+195916>>2]=P;P=B+4096|0;c[X+64848>>2]=P;c[X+130384>>2]=P;c[X+195920>>2]=P;P=B+5120|0;c[X+64852>>2]=P;c[X+130388>>2]=P;c[X+195924>>2]=P;P=B+6144|0;c[X+64856>>2]=P;c[X+130392>>2]=P;c[X+195928>>2]=P;P=B+7168|0;c[X+64860>>2]=P;c[X+130396>>2]=P;c[X+195932>>2]=P;P=B+8192|0;c[X+64864>>2]=P;c[X+130400>>2]=P;c[X+195936>>2]=P;P=B+9216|0;c[X+64868>>2]=P;c[X+130404>>2]=P;c[X+195940>>2]=P;P=B+10240|0;c[X+64872>>2]=P;c[X+130408>>2]=P;c[X+195944>>2]=P;P=B+11264|0;c[X+64876>>2]=P;c[X+130412>>2]=P;c[X+195948>>2]=P;P=B+12288|0;c[X+64880>>2]=P;c[X+130416>>2]=P;c[X+195952>>2]=P;P=B+13312|0;c[X+64884>>2]=P;c[X+130420>>2]=P;c[X+195956>>2]=P;P=B+14336|0;c[X+64888>>2]=P;c[X+130424>>2]=P;c[X+195960>>2]=P;P=B+15360|0;c[X+64892>>2]=P;c[X+130428>>2]=P;c[X+195964>>2]=P;P=c[2439624]|0;c[X+64896>>2]=P;c[X+130432>>2]=P;c[X+195968>>2]=P;B=P+1024|0;c[X+64900>>2]=B;c[X+130436>>2]=B;c[X+195972>>2]=B;B=c[2388058]|0;P=X+65024|0;E=16646144;while(1){J=B+(E-16646144)|0;c[P>>2]=J;c[P+65536>>2]=J;c[P+131072>>2]=J;J=E+1024|0;if(J>>>0>16777215){break}else{P=P+4|0;E=J}}c[X+196688>>2]=2996;c[X+196728>>2]=338;c[X+196648>>2]=1820;E=c[3532592]|0;if((E|0)!=0){gGC(E|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);E=c[2439330]|0;P=(E|0)==0;if(!P){B=E;gGC(9706056,B|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];B=c[3528484]|0;c[2076596]=B;J=c[2417276]|0;c[3541536]=J;c[1836236]=0;c[E+4180>>2]=580;c[E+4184>>2]=3042;I=c[2385844]|0;O=0;L=0;while(1){c[E+76+(L<<2)>>2]=I+(L<<8);K=O+1&65535;if((K&65535)>223){Y=0;Z=0;break}else{O=K;L=K&65535}}while(1){L=I+(Z<<8)|0;c[E+76+(Z+512<<2)>>2]=L;c[E+76+(Z+768<<2)>>2]=L;L=Y+1&65535;if((L&65535)>223){break}else{Y=L;Z=L&65535}}I=c[2385862]|0;c[E+972>>2]=I;L=I+256|0;c[E+976>>2]=L;O=I+512|0;c[E+980>>2]=O;K=I+768|0;c[E+984>>2]=K;Q=I+1024|0;c[E+988>>2]=Q;M=I+1280|0;c[E+992>>2]=M;N=I+1536|0;c[E+996>>2]=N;S=I+1792|0;c[E+1e3>>2]=S;c[E+1996>>2]=I;c[E+2e3>>2]=L;c[E+2004>>2]=O;c[E+2008>>2]=K;c[E+2012>>2]=Q;c[E+2016>>2]=M;c[E+2020>>2]=N;c[E+2024>>2]=S;c[E+3020>>2]=I;c[E+4044>>2]=I;c[E+3024>>2]=L;c[E+4048>>2]=L;c[E+3028>>2]=O;c[E+4052>>2]=O;c[E+3032>>2]=K;c[E+4056>>2]=K;c[E+3036>>2]=Q;c[E+4060>>2]=Q;c[E+3040>>2]=M;c[E+4064>>2]=M;c[E+3044>>2]=N;c[E+4068>>2]=N;c[E+3048>>2]=S;c[E+4072>>2]=S;if(!P){S=E;gGC(S|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=B;c[2417276]=J;c[1836236]=-1;S=c[642608+(c[2436]<<2)>>2]|0;N=c[S+128>>2]|0;if((c[S+52>>2]&4|0)==0){c[2113068]=N;M=c[S+132>>2]|0;c[2113070]=M;c[2443814]=N;c[2440436]=M;_=N;$=M}else{c[2113070]=N;M=c[S+132>>2]|0;c[2113068]=M;c[2440436]=N;c[2443814]=M;_=M;$=N}N=ag(_<<1,$)|0;M=gGq(N)|0;c[2112926]=M;if((M|0)!=0){gGz(M|0,0,N|0)}a[1950792]=0;a[9720896]=64;Vr(2,3579545,2386,1286,44,0);h[745419]=.4;a[3203368]=1;h[745418]=.4;a[3203360]=1;h[745417]=.4;a[3203352]=1;h[745416]=.4;a[3203344]=1;h[745415]=.4;a[3203336]=1;h[745414]=.4;a[3203328]=1;h[745413]=.4;a[3203320]=1;h[745412]=.4;a[3203312]=1;c[2438228]=3579545;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=571;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];N=c[3532592]|0;if((N|0)!=0){gGC(9104152,N|0,280)|0}c[2113054]=c[2113060]}RI();N=c[2394]|0;M=c[14130368+(N<<2)>>2]|0;if((M|0)!=0){gGC(M|0,9104152,280)|0}c[8452240+(N<<2)>>2]=c[2113054];c[2394]=-1;N=c[2439330]|0;M=(N|0)==0;if(!M){S=N;gGC(9706056,S|0,76)|0}S=c[2438118]|0;c[2433530]=S;Q=c[3528484]|0;c[2076596]=Q;K=c[2417276]|0;c[3541536]=K;c[1836236]=0;gGz(9706056,0,76);if(!M){M=N;gGC(M|0,9706056,76)|0}c[2438118]=S;c[3528484]=Q;c[2417276]=K;c[1836236]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){K=0;do{lN(K);mB(K);K=K+1|0;}while((K|0)<(c[2385508]|0))}b[4887148]=0;b[4887132]=0;b[4887208]=0;b[4887184]=0;a[9758008]=0;a[9758232]=0;H=0;i=e;return H|0}}while(0);c[2426792]=0;H=1;i=e;return H|0}function dou(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7421972+(b*112|0)>>2];c[a+104>>2]=c[7421976+(b*112|0)>>2];c[a+108>>2]=c[7421980+(b*112|0)>>2];d=0;return d|0}function dov(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=7421872+(b*112|0);e=0;return e|0}function dow(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6935792+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dox(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>59){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7445928+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function doy(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0;e=i;i=i+1680|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;B=e+1200|0;C=e+1312|0;D=e+1320|0;E=e+1432|0;F=e+1440|0;G=e+1552|0;H=e+1560|0;I=e+1672|0;c[2426792]=0;c[2388036]=0;c[2385844]=524288;c[3541206]=589824;c[2405702]=851968;c[2388058]=851968;c[2385862]=983040;c[2443430]=985088;c[2430220]=987136;c[3527222]=989184;c[2439624]=997376;c[2439584]=999424;c[2439582]=1015808;c[2411788]=1048576;c[2406538]=1048576;c[3531070]=1179648;c[3530980]=1703936;c[3529590]=2752512;c[3530112]=3801088;J=0;while(1){if((J|0)>=1024){break}K=9638528+(J<<2)|0;if((c[K>>2]|0)==0){L=72857;break}else{J=J+1|0}}do{if((L|0)==72857){J=gGq(3809280)|0;c[K>>2]=J;if((J|0)==0){break}c[2426792]=J;gGz(J|0,0,3809280);c[2388036]=J;c[2385844]=J+524288;c[3541206]=J+589824;M=J+851968|0;c[2405702]=M;c[2388058]=M;c[2385862]=J+983040;c[2443430]=J+985088;c[2430220]=J+987136;c[3527222]=J+989184;c[2439624]=J+997376;c[2439584]=J+999424;c[2439582]=J+1015808;M=J+1048576|0;c[2411788]=M;c[2406538]=M;c[3531070]=J+1179648;c[3530980]=J+1703936;c[3529590]=J+2752512;c[3530112]=J+3801088;c[2414336]=J+3809280;J=0;while(1){if((J|0)>=1024){N=0;break}O=9638528+(J<<2)|0;if((c[O>>2]|0)==0){L=72862;break}else{J=J+1|0}}do{if((L|0)==72862){J=gGq(524288)|0;c[O>>2]=J;if((J|0)==0){N=0;break}gGz(J|0,0,524288);N=J}}while(0);c[3529540]=N;if((R6((c[2388036]|0)+1|0,0,2)|0)!=0){P=1;i=e;return P|0}if((R6(c[2388036]|0,1,2)|0)!=0){P=1;i=e;return P|0}if((R6((c[2388036]|0)+262145|0,2,2)|0)!=0){P=1;i=e;return P|0}if((R6((c[2388036]|0)+262144|0,3,2)|0)!=0){P=1;i=e;return P|0}J=c[2385844]|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}M=H+108|0;c[M>>2]=0;Q=H+100|0;c[Q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](H,4)|0;do{if((c[M>>2]|0)!=0){R=c[Q>>2]|0;c[I>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](I,4,0)|0;if((R|0)<1){P=1;i=e;return P|0}if((gzL(J,0,4)|0)==0){break}else{P=1}i=e;return P|0}}while(0);J=c[3529540]|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}Q=F+108|0;c[Q>>2]=0;M=F+100|0;c[M>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](F,5)|0;do{if((c[Q>>2]|0)!=0){R=c[M>>2]|0;c[G>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](G,5,0)|0;if((R|0)<1){P=1;i=e;return P|0}if((gzL(J,0,5)|0)==0){break}else{P=1}i=e;return P|0}}while(0);J=c[3529540]|0;M=c[2406538]|0;Q=0;do{R=Q<<6;gGz(M+R|0,0,64);S=Q<<7;T=S|4;U=0;while(1){V=T+(c[6669224+(U<<2)>>2]|0)|0;W=(U<<3)+R|0;X=0;do{Y=V+(c[612480+(X<<2)>>2]|0)|0;if(((d[J+((Y|0)/8|0)|0]|0)&128>>>((Y&7)>>>0)|0)!=0){Y=M+(W+X)|0;a[Y]=a[Y]|2}X=X+1|0;}while((X|0)<8);X=U+1|0;if((X|0)<8){U=X}else{Z=0;break}}do{U=S+(c[6669224+(Z<<2)>>2]|0)|0;T=(Z<<3)+R|0;X=0;do{W=U+(c[612480+(X<<2)>>2]|0)|0;if(((d[J+((W|0)/8|0)|0]|0)&128>>>((W&7)>>>0)|0)!=0){W=M+(T+X)|0;a[W]=a[W]|1}X=X+1|0;}while((X|0)<8);Z=Z+1|0;}while((Z|0)<8);Q=Q+1|0;}while((Q|0)<2048);gGz(J|0,0,524288);if((c[3542200]|0)==0){P=1;i=e;return P|0}Q=D+108|0;c[Q>>2]=0;M=D+100|0;c[M>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](D,6)|0;do{if((c[Q>>2]|0)!=0){R=c[M>>2]|0;c[E>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](E,6,0)|0;if((R|0)<1){P=1;i=e;return P|0}if((gzL(J,0,6)|0)==0){break}else{P=1}i=e;return P|0}}while(0);J=c[3529540]|0;M=c[3531070]|0;Q=0;do{R=Q<<8;gGz(M+R|0,0,256);S=Q<<10;X=0;do{T=1<<3-X;U=(c[687256+(X<<2)>>2]|0)+S|0;W=0;do{V=U+(c[611840+(W<<2)>>2]|0)|0;Y=(W<<4)+R|0;_=0;do{$=V+(c[609424+(_<<2)>>2]|0)|0;if(((d[J+(($|0)/8|0)|0]|0)&128>>>(($&7)>>>0)|0)!=0){$=M+(Y+_)|0;a[$]=(d[$]|0|T)&255}_=_+1|0;}while((_|0)<16);W=W+1|0;}while((W|0)<16);X=X+1|0;}while((X|0)<4);Q=Q+1|0;}while((Q|0)<2048);gGz(J|0,0,524288);if((c[3542200]|0)==0){P=1;i=e;return P|0}Q=B+108|0;c[Q>>2]=0;M=B+100|0;c[M>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](B,7)|0;do{if((c[Q>>2]|0)!=0){X=c[M>>2]|0;c[C>>2]=9534384;R=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[R&16383](C,7,0)|0;if((X|0)<1){P=1;i=e;return P|0}if((gzL(J,0,7)|0)==0){break}else{P=1}i=e;return P|0}}while(0);J=c[3529540]|0;M=c[3530980]|0;Q=0;do{X=Q<<8;gGz(M+X|0,0,256);R=Q<<10;S=0;do{W=1<<3-S;T=(c[986384+(S<<2)>>2]|0)+R|0;U=0;do{_=T+(c[611840+(U<<2)>>2]|0)|0;Y=(U<<4)+X|0;V=0;do{$=_+(c[609424+(V<<2)>>2]|0)|0;if(((d[J+(($|0)/8|0)|0]|0)&128>>>(($&7)>>>0)|0)!=0){$=M+(Y+V)|0;a[$]=(d[$]|0|W)&255}V=V+1|0;}while((V|0)<16);U=U+1|0;}while((U|0)<16);S=S+1|0;}while((S|0)<4);Q=Q+1|0;}while((Q|0)<4096);gGz(J|0,0,524288);if((c[3542200]|0)==0){P=1;i=e;return P|0}Q=z+108|0;c[Q>>2]=0;M=z+100|0;c[M>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,8)|0;do{if((c[Q>>2]|0)!=0){S=c[M>>2]|0;c[A>>2]=9534384;X=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[X&16383](A,8,0)|0;if((S|0)<1){P=1;i=e;return P|0}if((gzL(J,0,8)|0)==0){break}else{P=1}i=e;return P|0}}while(0);J=(c[3529540]|0)+65536|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}M=x+108|0;c[M>>2]=0;Q=x+100|0;c[Q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,9)|0;do{if((c[M>>2]|0)!=0){S=c[Q>>2]|0;c[y>>2]=9534384;X=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[X&16383](y,9,0)|0;if((S|0)<1){P=1;i=e;return P|0}if((gzL(J,0,9)|0)==0){break}else{P=1}i=e;return P|0}}while(0);J=(c[3529540]|0)+131072|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}Q=v+108|0;c[Q>>2]=0;M=v+100|0;c[M>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,10)|0;do{if((c[Q>>2]|0)!=0){S=c[M>>2]|0;c[w>>2]=9534384;X=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[X&16383](w,10,0)|0;if((S|0)<1){P=1;i=e;return P|0}if((gzL(J,0,10)|0)==0){break}else{P=1}i=e;return P|0}}while(0);J=(c[3529540]|0)+196608|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}M=t+108|0;c[M>>2]=0;Q=t+100|0;c[Q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,11)|0;do{if((c[M>>2]|0)!=0){S=c[Q>>2]|0;c[u>>2]=9534384;X=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[X&16383](u,11,0)|0;if((S|0)<1){P=1;i=e;return P|0}if((gzL(J,0,11)|0)==0){break}else{P=1}i=e;return P|0}}while(0);J=(c[3529540]|0)+262144|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}Q=r+108|0;c[Q>>2]=0;M=r+100|0;c[M>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,12)|0;do{if((c[Q>>2]|0)!=0){S=c[M>>2]|0;c[s>>2]=9534384;X=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[X&16383](s,12,0)|0;if((S|0)<1){P=1;i=e;return P|0}if((gzL(J,0,12)|0)==0){break}else{P=1}i=e;return P|0}}while(0);J=(c[3529540]|0)+327680|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}M=p+108|0;c[M>>2]=0;Q=p+100|0;c[Q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,13)|0;do{if((c[M>>2]|0)!=0){S=c[Q>>2]|0;c[q>>2]=9534384;X=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[X&16383](q,13,0)|0;if((S|0)<1){P=1;i=e;return P|0}if((gzL(J,0,13)|0)==0){break}else{P=1}i=e;return P|0}}while(0);J=(c[3529540]|0)+393216|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}Q=n+108|0;c[Q>>2]=0;M=n+100|0;c[M>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,14)|0;do{if((c[Q>>2]|0)!=0){S=c[M>>2]|0;c[o>>2]=9534384;X=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[X&16383](o,14,0)|0;if((S|0)<1){P=1;i=e;return P|0}if((gzL(J,0,14)|0)==0){break}else{P=1}i=e;return P|0}}while(0);J=(c[3529540]|0)+458752|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}M=l+108|0;c[M>>2]=0;Q=l+100|0;c[Q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,15)|0;do{if((c[M>>2]|0)!=0){S=c[Q>>2]|0;c[m>>2]=9534384;X=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[X&16383](m,15,0)|0;if((S|0)<1){P=1;i=e;return P|0}if((gzL(J,0,15)|0)==0){break}else{P=1}i=e;return P|0}}while(0);J=c[3529540]|0;Q=c[3529590]|0;M=0;do{S=M<<8;gGz(Q+S|0,0,256);X=0;do{R=1<<3-X;U=(c[961520+(X<<2)>>2]|0)+S|0;W=0;do{T=U+(c[609008+(W<<2)>>2]|0)|0;V=(W<<4)+S|0;Y=0;do{_=T+(c[597864+(Y<<2)>>2]|0)|0;if(((d[J+((_|0)/8|0)|0]|0)&128>>>((_&7)>>>0)|0)!=0){_=Q+(V+Y)|0;a[_]=(d[_]|0|R)&255}Y=Y+1|0;}while((Y|0)<16);W=W+1|0;}while((W|0)<16);X=X+1|0;}while((X|0)<4);M=M+1|0;}while((M|0)<4096);M=c[3541206]|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}Q=j+108|0;c[Q>>2]=0;J=j+100|0;c[J>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,16)|0;do{if((c[Q>>2]|0)!=0){X=c[J>>2]|0;c[k>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](k,16,0)|0;if((X|0)<1){P=1;i=e;return P|0}if((gzL(M,0,16)|0)==0){break}else{P=1}i=e;return P|0}}while(0);M=(c[3541206]|0)+131072|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}J=f+108|0;c[J>>2]=0;Q=f+100|0;c[Q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,17)|0;do{if((c[J>>2]|0)!=0){X=c[Q>>2]|0;c[g>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](g,17,0)|0;if((X|0)<1){P=1;i=e;return P|0}if((gzL(M,0,17)|0)==0){break}else{P=1}i=e;return P|0}}while(0);M=c[3529540]|0;Q=0;while(1){if((Q|0)>=1024){break}aa=9638528+(Q<<2)|0;if((c[aa>>2]|0)==(M|0)){L=72964;break}else{Q=Q+1|0}}if((L|0)==72964){gGr(M);c[aa>>2]=0}c[3529540]=0;fxU(0,425984);if((c[2394]|0)==0){ab=c[2112932]|0}else{c[2394]=0;Q=c[3532596]|0;c[2112932]=Q;J=c[3532592]|0;if((J|0)!=0){gGC(9104152,J|0,280)|0}c[2113054]=c[2113060];ab=Q}Q=c[2388036]|0;J=ab|0;X=0;while(1){S=Q+X|0;c[J>>2]=S;c[J+131072>>2]=S;S=X+1024|0;if(S>>>0>524287){break}else{J=J+4|0;X=S}}X=c[2443430]|0;c[ab+64536>>2]=X;c[ab+130072>>2]=X;c[ab+195608>>2]=X;J=X+1024|0;c[ab+64540>>2]=J;c[ab+130076>>2]=J;c[ab+195612>>2]=J;J=c[3527222]|0;c[ab+64640>>2]=J;c[ab+130176>>2]=J;c[ab+195712>>2]=J;X=J+1024|0;c[ab+64644>>2]=X;c[ab+130180>>2]=X;c[ab+195716>>2]=X;X=J+2048|0;c[ab+64648>>2]=X;c[ab+130184>>2]=X;c[ab+195720>>2]=X;X=J+3072|0;c[ab+64652>>2]=X;c[ab+130188>>2]=X;c[ab+195724>>2]=X;X=J+4096|0;c[ab+64656>>2]=X;c[ab+130192>>2]=X;c[ab+195728>>2]=X;X=J+5120|0;c[ab+64660>>2]=X;c[ab+130196>>2]=X;c[ab+195732>>2]=X;X=J+6144|0;c[ab+64664>>2]=X;c[ab+130200>>2]=X;c[ab+195736>>2]=X;X=J+7168|0;c[ab+64668>>2]=X;c[ab+130204>>2]=X;c[ab+195740>>2]=X;X=c[2439624]|0;c[ab+64704>>2]=X;c[ab+130240>>2]=X;c[ab+195776>>2]=X;J=X+1024|0;c[ab+64708>>2]=J;c[ab+130244>>2]=J;c[ab+195780>>2]=J;J=c[2439584]|0;c[ab+64832>>2]=J;c[ab+130368>>2]=J;c[ab+195904>>2]=J;X=J+1024|0;c[ab+64836>>2]=X;c[ab+130372>>2]=X;c[ab+195908>>2]=X;X=J+2048|0;c[ab+64840>>2]=X;c[ab+130376>>2]=X;c[ab+195912>>2]=X;X=J+3072|0;c[ab+64844>>2]=X;c[ab+130380>>2]=X;c[ab+195916>>2]=X;X=J+4096|0;c[ab+64848>>2]=X;c[ab+130384>>2]=X;c[ab+195920>>2]=X;X=J+5120|0;c[ab+64852>>2]=X;c[ab+130388>>2]=X;c[ab+195924>>2]=X;X=J+6144|0;c[ab+64856>>2]=X;c[ab+130392>>2]=X;c[ab+195928>>2]=X;X=J+7168|0;c[ab+64860>>2]=X;c[ab+130396>>2]=X;c[ab+195932>>2]=X;X=J+8192|0;c[ab+64864>>2]=X;c[ab+130400>>2]=X;c[ab+195936>>2]=X;X=J+9216|0;c[ab+64868>>2]=X;c[ab+130404>>2]=X;c[ab+195940>>2]=X;X=J+10240|0;c[ab+64872>>2]=X;c[ab+130408>>2]=X;c[ab+195944>>2]=X;X=J+11264|0;c[ab+64876>>2]=X;c[ab+130412>>2]=X;c[ab+195948>>2]=X;X=J+12288|0;c[ab+64880>>2]=X;c[ab+130416>>2]=X;c[ab+195952>>2]=X;X=J+13312|0;c[ab+64884>>2]=X;c[ab+130420>>2]=X;c[ab+195956>>2]=X;X=J+14336|0;c[ab+64888>>2]=X;c[ab+130424>>2]=X;c[ab+195960>>2]=X;X=J+15360|0;c[ab+64892>>2]=X;c[ab+130428>>2]=X;c[ab+195964>>2]=X;X=c[2439582]|0;J=ab+64896|0;Q=16613376;while(1){M=X+(Q-16613376)|0;c[J>>2]=M;c[J+65536>>2]=M;c[J+131072>>2]=M;M=Q+1024|0;if(M>>>0>16646143){break}else{J=J+4|0;Q=M}}Q=c[2388058]|0;J=ab+65280|0;X=16711680;while(1){M=Q+(X-16711680)|0;c[J>>2]=M;c[J+65536>>2]=M;c[J+131072>>2]=M;M=X+1024|0;if(M>>>0>16777215){break}else{J=J+4|0;X=M}}c[ab+196728>>2]=2580;c[ab+196608>>2]=2822;X=c[3532592]|0;if((X|0)!=0){gGC(X|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);X=c[2439330]|0;J=(X|0)==0;if(!J){Q=X;gGC(9706056,Q|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];Q=c[3528484]|0;c[2076596]=Q;M=c[2417276]|0;c[3541536]=M;c[1836236]=0;c[X+4180>>2]=1122;c[X+4184>>2]=582;S=c[2385844]|0;W=0;R=0;while(1){c[X+76+(R<<2)>>2]=S+(R<<8);U=W+1&65535;if((U&65535)>127){ac=0;ad=0;break}else{W=U;R=U&65535}}while(1){R=S+(ad<<8)|0;c[X+76+(ad+512<<2)>>2]=R;c[X+76+(ad+768<<2)>>2]=R;R=ac+1&65535;if((R&65535)>127){ae=128;af=128;break}else{ac=R;ad=R&65535}}while(1){c[X+76+(af<<2)>>2]=S+(af<<8);R=ae+1&65535;if((R&65535)>191){ah=128;ai=128;break}else{ae=R;af=R&65535}}while(1){R=S+(ai<<8)|0;c[X+76+(ai+512<<2)>>2]=R;c[X+76+(ai+768<<2)>>2]=R;R=ah+1&65535;if((R&65535)>191){break}else{ah=R;ai=R&65535}}S=c[2385862]|0;c[X+908>>2]=S;R=S+256|0;c[X+912>>2]=R;W=S+512|0;c[X+916>>2]=W;U=S+768|0;c[X+920>>2]=U;Y=S+1024|0;c[X+924>>2]=Y;V=S+1280|0;c[X+928>>2]=V;T=S+1536|0;c[X+932>>2]=T;_=S+1792|0;c[X+936>>2]=_;c[X+1932>>2]=S;c[X+1936>>2]=R;c[X+1940>>2]=W;c[X+1944>>2]=U;c[X+1948>>2]=Y;c[X+1952>>2]=V;c[X+1956>>2]=T;c[X+1960>>2]=_;c[X+2956>>2]=S;c[X+3980>>2]=S;c[X+2960>>2]=R;c[X+3984>>2]=R;c[X+2964>>2]=W;c[X+3988>>2]=W;c[X+2968>>2]=U;c[X+3992>>2]=U;c[X+2972>>2]=Y;c[X+3996>>2]=Y;c[X+2976>>2]=V;c[X+4e3>>2]=V;c[X+2980>>2]=T;c[X+4004>>2]=T;c[X+2984>>2]=_;c[X+4008>>2]=_;if(!J){_=X;gGC(_|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=Q;c[2417276]=M;c[1836236]=-1;_=c[642608+(c[2436]<<2)>>2]|0;T=c[_+128>>2]|0;if((c[_+52>>2]&4|0)==0){c[2113068]=T;V=c[_+132>>2]|0;c[2113070]=V;c[2443814]=T;c[2440436]=V;aj=T;ak=V}else{c[2113070]=T;V=c[_+132>>2]|0;c[2113068]=V;c[2440436]=T;c[2443814]=V;aj=V;ak=T}T=ag(aj<<1,ak)|0;V=gGq(T)|0;c[2112926]=V;if((V|0)!=0){gGz(V|0,0,T|0)}a[1950792]=1;a[9720896]=-128;Vr(2,3579545,2386,1286,44,0);c[2438228]=3579545;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=571;h[745419]=.4;a[3203368]=1;h[745418]=.4;a[3203360]=1;h[745417]=.4;a[3203352]=1;h[745416]=.4;a[3203344]=1;h[745415]=.4;a[3203336]=1;h[745414]=.4;a[3203328]=1;h[745413]=.4;a[3203320]=1;h[745412]=.4;a[3203312]=1;Ux(0,7575,1);c[2407030]=251;c[2407068]=3;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];T=c[3532592]|0;if((T|0)!=0){gGC(9104152,T|0,280)|0}c[2113054]=c[2113060]}RI();T=c[2394]|0;V=c[14130368+(T<<2)>>2]|0;if((V|0)!=0){gGC(V|0,9104152,280)|0}c[8452240+(T<<2)>>2]=c[2113054];c[2394]=-1;T=c[2439330]|0;V=(T|0)==0;if(!V){_=T;gGC(9706056,_|0,76)|0}_=c[2438118]|0;c[2433530]=_;Y=c[3528484]|0;c[2076596]=Y;U=c[2417276]|0;c[3541536]=U;c[1836236]=0;gGz(9706056,0,76);if(!V){V=T;gGC(V|0,9706056,76)|0}c[2438118]=_;c[3528484]=Y;c[2417276]=U;c[1836236]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){U=0;do{lN(U);mB(U);U=U+1|0;}while((U|0)<(c[2385508]|0))}b[4887148]=0;b[4887132]=0;b[4887208]=0;b[4887184]=0;a[9758008]=0;a[9758232]=0;c[2113156]=0;a[9628264]=0;c[2407033]=0;U=c[3541206]|0;c[3541190]=U;c[3541198]=U;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=U+256;c[3541199]=U+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=U+512;c[3541200]=U+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=U+768;c[3541201]=U+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;P=0;i=e;return P|0}}while(0);c[2426792]=0;P=1;i=e;return P|0}function doz(){var d=0,e=0,f=0,g=0,h=0;Uw(0);if((c[2392]|0)>=0){d=0;do{e=14130368+(d<<2)|0;f=c[e>>2]|0;if((f|0)!=0){gGr(f);c[e>>2]=0}e=14130384+(d<<2)|0;f=c[e>>2]|0;if((f|0)!=0){gGr(f);c[e>>2]=0}d=d+1|0;}while((d|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;fwZ();d=c[3541518]|0;if((d|0)!=0){gGr(d|0);c[3541518]=0}if((c[2385508]|0)>0){c[2113008]=0;c[2076598]=0;c[2383582]=0}c[2438228]=0;c[2433526]=0;c[2406676]=0;c[3528472]=0;d=c[2406680]|0;if((d|0)!=0){gGr(d);c[2406680]=0}c[2385508]=0;c[2432978]=0;a[64240]=0;c[2113070]=0;c[2113068]=0;d=c[2112926]|0;if((d|0)!=0){gGr(d);c[2112926]=0}b[4887148]=0;b[4887132]=0;b[4887208]=0;b[4887184]=0;a[1950792]=0;a[9720896]=0;a[9758008]=0;a[9758232]=0;d=c[2426792]|0;e=0;while(1){if((e|0)>=1024){g=73079;break}h=9638528+(e<<2)|0;if((c[h>>2]|0)==(d|0)){break}else{e=e+1|0}}if((g|0)==73079){c[2426792]=0;return 0}gGr(d);c[h>>2]=0;c[2426792]=0;return 0}function doA(){var f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;if((a[9624720]|0)!=0){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060]}RI();f=c[2394]|0;g=c[14130368+(f<<2)>>2]|0;if((g|0)!=0){gGC(g|0,9104152,280)|0}c[8452240+(f<<2)>>2]=c[2113054];c[2394]=-1;f=c[2439330]|0;g=(f|0)==0;if(!g){i=f;gGC(9706056,i|0,76)|0}i=c[2438118]|0;c[2433530]=i;j=c[3528484]|0;c[2076596]=j;k=c[2417276]|0;c[3541536]=k;c[1836236]=0;gGz(9706056,0,76);if(!g){g=f;gGC(g|0,9706056,76)|0}c[2438118]=i;c[3528484]=j;c[2417276]=k;c[1836236]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){k=0;do{lN(k);mB(k);k=k+1|0;}while((k|0)<(c[2385508]|0))}b[4887148]=0;b[4887132]=0;b[4887208]=0;b[4887184]=0;a[9758008]=0;a[9758232]=0;c[2113156]=0;a[9628264]=0;c[2407033]=0;k=c[3541206]|0;c[3541190]=k;c[3541198]=k;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=k+256;c[3541199]=k+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=k+512;c[3541200]=k+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=k+768;c[3541201]=k+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4}a[9625866]=0;a[9625865]=0;a[9625864]=0;k=0;j=0;i=0;g=0;do{j=((a[9759264+k|0]&1)<<k|j&255)&255;i=((a[9759072+k|0]&1)<<k|i&255)&255;g=((a[9758888+k|0]&1)<<k|g&255)&255;k=k+1|0;}while((k|0)<8);a[9625864]=j;a[9625865]=i;a[9625866]=g;if((j&3)==3){g=j&-4;a[9625864]=g;l=g}else{l=j}if((l&12)==12){a[9625864]=l&-13}if((i&3)==3){l=i&-4;a[9625865]=l;m=l}else{m=i}if((m&12)==12){a[9625865]=m&-13}a[6518328]=1;a[6518152]=1;c[2444107]=0;c[2444106]=0;m=c[2392]|0;if((m|0)>=0){gGz(8452240,0,((m|0)>0?(m<<2)+4|0:4)|0)}c[2113054]=0;m=c[2385548]|0;if((m|0)>0){gGz(9752472,0,((m|0)>1?m<<2:4)|0)}c[2433530]=0;m=0;while(1){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];i=c[3532592]|0;if((i|0)!=0){gGC(9104152,i|0,280)|0}c[2113054]=c[2113060]}i=m+1|0;l=(ag(a[6518328]|0?166666:0,i)|0)/100|0;j=l-(c[2444106]|0)|0;c[2438200]=j;c[2113056]=j;l=RG(j)|0;c[2113054]=(c[2113054]|0)+l;c[2276108]=-1;c[2113056]=-1;c[2444106]=(c[2444106]|0)+l;do{if((m|0)==66|(m|0)==33){c[8452200+(c[2394]<<2)>>2]=8198;c[2276080]=1536;if((c[2276079]|0)>>>0>=1536){break}RH(6)}}while(0);l=c[2394]|0;j=c[14130368+(l<<2)>>2]|0;if((j|0)!=0){gGC(j|0,9104152,280)|0}c[8452240+(l<<2)>>2]=c[2113054];c[2394]=-1;l=c[2439330]|0;if((l|0)!=0){j=l;gGC(9706056,j|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;Sb(ag(a[6518152]|0?596:0,m)|0);j=c[1836236]|0;l=c[9757320+(j<<2)>>2]|0;if((l|0)!=0){g=l;gGC(g|0,9706056,76)|0}c[9752472+(j<<2)>>2]=c[2433530];c[14113936+(j<<2)>>2]=c[2076596];c[9669104+(j<<2)>>2]=c[3541536];c[1836236]=-1;if((i|0)<100){m=i}else{break}}m=c[2439330]|0;if((m|0)!=0){j=m;gGC(9706056,j|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;j=a[6518152]|0?59659:0;m=gGU(j,0,2048e6,0)|0;g=c[2438228]|0;l=gGS(m,K,g,(g|0)<0|0?-1:0)|0;g=l;Sb(j);j=c[2443830]|0;if((j|0)<1073676288){c[2443830]=j-g}j=c[2443831]|0;if((j|0)<1073676288){c[2443831]=j-g}j=(c[3528512]|0)-g|0;c[3528512]=(j|0)<0?0:j;j=c[2112964]|0;if((j|0)!=0){gg[c[3542122]&4095](j,a[9688]|0?534:0)}j=c[1836236]|0;g=c[9757320+(j<<2)>>2]|0;if((g|0)!=0){l=g;gGC(l|0,9706056,76)|0}c[9752472+(j<<2)>>2]=c[2433530];c[14113936+(j<<2)>>2]=c[2076596];c[9669104+(j<<2)>>2]=c[3541536];c[1836236]=-1;if((c[2112968]|0)!=0){j=c[2112926]|0;gGz(j|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);l=c[3530112]|0;g=0;m=c[2439624]|0;k=l;while(1){f=e[m>>1]|0;n=d[591736+(f&15)|0]|0;o=ag(f>>>4&15,n)|0;p=(ag(f>>>12<<8,n)|0)&63488;c[k>>2]=(ag(f>>>8<<3&120,n)|0)&2016|p|o>>>3&31;o=g+1|0;if((o|0)<2048){g=o;m=m+2|0;k=k+4|0}else{break}}k=c[2439582]|0;m=c[3531070]|0;g=0;do{o=g<<4;p=0;do{n=(p<<5)+g|0;f=b[k+(n<<1)>>1]&8191;q=e[k+(n+2048<<1)>>1]|0;n=q>>>5&1;r=q>>>6&1;s=q&15;q=(p<<4)-(e[4887208]|0)|0;t=o-(e[4887184]|0)|0;u=(q|0)<-16?q+1024|0:q;q=(t|0)<-16?t+512|0:t;t=u-64|0;v=q-8|0;do{if((u-81|0)>>>0<351){if((q-25|0)>>>0>=207){w=73148;break}x=(r|0)!=0;if((n|0)==0){if(x){SC(j,f,t,v,s,4,0,m);break}else{Sy(j,f,t,v,s,4,0,m);break}}else{if(x){SE(j,f,t,v,s,4,0,m);break}else{SA(j,f,t,v,s,4,0,m);break}}}else{w=73148}}while(0);do{if((w|0)==73148){w=0;q=(r|0)!=0;if((n|0)==0){if(q){SD(j,f,t,v,s,4,0,m);break}else{Sz(j,f,t,v,s,4,0,m);break}}else{if(q){SF(j,f,t,v,s,4,0,m);break}else{SB(j,f,t,v,s,4,0,m);break}}}}while(0);p=p+1|0;}while((p|0)<64);g=g+1|0;}while((g|0)<32);doM(0);doN(0);doM(1);doN(1);doO();R8(l)}if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];l=c[3532592]|0;if((l|0)!=0){gGC(9104152,l|0,280)|0}c[2113054]=c[2113060]}c[2113050]=8197;c[2276080]=1280;if((c[2276079]|0)>>>0<1280){RH(5);y=c[2394]|0}else{y=0}l=c[14130368+(y<<2)>>2]|0;if((l|0)==0){z=c[2113054]|0;A=8452240+(y<<2)|0;c[A>>2]=z;c[2394]=-1;B=c[2430220]|0;C=c[2443430]|0;gGC(B|0,C|0,2048)|0;return 0}gGC(l|0,9104152,280)|0;z=c[2113054]|0;A=8452240+(y<<2)|0;c[A>>2]=z;c[2394]=-1;B=c[2430220]|0;C=c[2443430]|0;gGC(B|0,C|0,2048)|0;return 0}function doB(a,e){a=a|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;dom(a,e)|0;if((a&64|0)!=0){Ut(0)}if((a&2|0)==0){return 0}a=c[2439330]|0;e=(a|0)==0;if(!e){f=a;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];f=c[3528484]|0;c[2076596]=f;g=c[2417276]|0;c[3541536]=g;c[1836236]=0;h=c[2385844]|0;i=(d[9758008]|0)<<14;j=128;k=128;while(1){c[a+76+(k<<2)>>2]=h+((k<<8)+i);l=j+1&65535;if((l&65535)>191){m=128;n=128;break}else{j=l;k=l&65535}}while(1){k=h+((n<<8)+i)|0;c[a+76+(n+512<<2)>>2]=k;c[a+76+(n+768<<2)>>2]=k;k=m+1&65535;if((k&65535)>191){break}else{m=k;n=k&65535}}if(!e){e=a;gGC(e|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=f;c[2417276]=g;c[1836236]=-1;return 0}function doC(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7263460+(b*112|0)>>2];c[a+104>>2]=c[7263464+(b*112|0)>>2];c[a+108>>2]=c[7263468+(b*112|0)>>2];d=0;return d|0}function doD(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=7263360+(b*112|0);e=0;return e|0}function doE(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7230644+(b*112|0)>>2];c[a+104>>2]=c[7230648+(b*112|0)>>2];c[a+108>>2]=c[7230652+(b*112|0)>>2];d=0;return d|0}function doF(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=7230544+(b*112|0);e=0;return e|0}function doG(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3800756+(b*112|0)>>2];c[a+104>>2]=c[3800760+(b*112|0)>>2];c[a+108>>2]=c[3800764+(b*112|0)>>2];d=0;return d|0}function doH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=3800656+(b*112|0);e=0;return e|0}function doI(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;e=i;i=i+960|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;c[2426792]=0;c[2388036]=0;c[2385844]=524288;c[3541206]=589824;c[2405702]=851968;c[2388058]=851968;c[2385862]=983040;c[2443430]=985088;c[2430220]=987136;c[3527222]=989184;c[2439624]=997376;c[2439584]=999424;c[2439582]=1015808;c[2411788]=1048576;c[2406538]=1048576;c[3531070]=1179648;c[3530980]=1703936;c[3529590]=2752512;c[3530112]=3801088;x=0;while(1){if((x|0)>=1024){break}y=9638528+(x<<2)|0;if((c[y>>2]|0)==0){z=73222;break}else{x=x+1|0}}do{if((z|0)==73222){x=gGq(3809280)|0;c[y>>2]=x;if((x|0)==0){break}c[2426792]=x;gGz(x|0,0,3809280);c[2388036]=x;c[2385844]=x+524288;c[3541206]=x+589824;A=x+851968|0;c[2405702]=A;c[2388058]=A;c[2385862]=x+983040;c[2443430]=x+985088;c[2430220]=x+987136;c[3527222]=x+989184;c[2439624]=x+997376;c[2439584]=x+999424;c[2439582]=x+1015808;A=x+1048576|0;c[2411788]=A;c[2406538]=A;c[3531070]=x+1179648;c[3530980]=x+1703936;c[3529590]=x+2752512;c[3530112]=x+3801088;c[2414336]=x+3809280;x=0;while(1){if((x|0)>=1024){B=0;break}C=9638528+(x<<2)|0;if((c[C>>2]|0)==0){z=73227;break}else{x=x+1|0}}do{if((z|0)==73227){x=gGq(524288)|0;c[C>>2]=x;if((x|0)==0){B=0;break}gGz(x|0,0,524288);B=x}}while(0);c[3529540]=B;if((R6((c[2388036]|0)+1|0,0,2)|0)!=0){D=1;i=e;return D|0}if((R6(c[2388036]|0,1,2)|0)!=0){D=1;i=e;return D|0}if((R6((c[2388036]|0)+262145|0,2,2)|0)!=0){D=1;i=e;return D|0}if((R6((c[2388036]|0)+262144|0,3,2)|0)!=0){D=1;i=e;return D|0}x=c[2385844]|0;if((c[3542200]|0)==0){D=1;i=e;return D|0}A=v+108|0;c[A>>2]=0;E=v+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,4)|0;do{if((c[A>>2]|0)!=0){F=c[E>>2]|0;c[w>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](w,4,0)|0;if((F|0)<1){D=1;i=e;return D|0}if((gzL(x,0,4)|0)==0){break}else{D=1}i=e;return D|0}}while(0);x=c[3529540]|0;if((c[3542200]|0)==0){D=1;i=e;return D|0}E=t+108|0;c[E>>2]=0;A=t+100|0;c[A>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,5)|0;do{if((c[E>>2]|0)!=0){F=c[A>>2]|0;c[u>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](u,5,0)|0;if((F|0)<1){D=1;i=e;return D|0}if((gzL(x,0,5)|0)==0){break}else{D=1}i=e;return D|0}}while(0);x=c[3529540]|0;A=c[2406538]|0;E=0;do{F=E<<6;gGz(A+F|0,0,64);G=E<<7;H=G|4;I=0;while(1){J=H+(c[6669224+(I<<2)>>2]|0)|0;K=(I<<3)+F|0;L=0;do{M=J+(c[612480+(L<<2)>>2]|0)|0;if(((d[x+((M|0)/8|0)|0]|0)&128>>>((M&7)>>>0)|0)!=0){M=A+(K+L)|0;a[M]=a[M]|2}L=L+1|0;}while((L|0)<8);L=I+1|0;if((L|0)<8){I=L}else{N=0;break}}do{I=G+(c[6669224+(N<<2)>>2]|0)|0;H=(N<<3)+F|0;L=0;do{K=I+(c[612480+(L<<2)>>2]|0)|0;if(((d[x+((K|0)/8|0)|0]|0)&128>>>((K&7)>>>0)|0)!=0){K=A+(H+L)|0;a[K]=a[K]|1}L=L+1|0;}while((L|0)<8);N=N+1|0;}while((N|0)<8);E=E+1|0;}while((E|0)<2048);gGz(x|0,0,524288);if((c[3542200]|0)==0){D=1;i=e;return D|0}E=r+108|0;c[E>>2]=0;A=r+100|0;c[A>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,6)|0;do{if((c[E>>2]|0)!=0){F=c[A>>2]|0;c[s>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](s,6,0)|0;if((F|0)<1){D=1;i=e;return D|0}if((gzL(x,0,6)|0)==0){break}else{D=1}i=e;return D|0}}while(0);x=c[3529540]|0;A=c[3531070]|0;E=0;do{F=E<<8;gGz(A+F|0,0,256);G=E<<10;L=0;do{H=1<<3-L;I=(c[687256+(L<<2)>>2]|0)+G|0;K=0;do{J=I+(c[611840+(K<<2)>>2]|0)|0;M=(K<<4)+F|0;O=0;do{P=J+(c[609424+(O<<2)>>2]|0)|0;if(((d[x+((P|0)/8|0)|0]|0)&128>>>((P&7)>>>0)|0)!=0){P=A+(M+O)|0;a[P]=(d[P]|0|H)&255}O=O+1|0;}while((O|0)<16);K=K+1|0;}while((K|0)<16);L=L+1|0;}while((L|0)<4);E=E+1|0;}while((E|0)<2048);gGz(x|0,0,524288);if((c[3542200]|0)==0){D=1;i=e;return D|0}E=p+108|0;c[E>>2]=0;A=p+100|0;c[A>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,7)|0;do{if((c[E>>2]|0)!=0){L=c[A>>2]|0;c[q>>2]=9534384;F=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[F&16383](q,7,0)|0;if((L|0)<1){D=1;i=e;return D|0}if((gzL(x,0,7)|0)==0){break}else{D=1}i=e;return D|0}}while(0);x=c[3529540]|0;A=c[3530980]|0;E=0;do{L=E<<8;gGz(A+L|0,0,256);F=E<<10;G=0;do{K=1<<3-G;H=(c[986384+(G<<2)>>2]|0)+F|0;I=0;do{O=H+(c[611840+(I<<2)>>2]|0)|0;M=(I<<4)+L|0;J=0;do{P=O+(c[609424+(J<<2)>>2]|0)|0;if(((d[x+((P|0)/8|0)|0]|0)&128>>>((P&7)>>>0)|0)!=0){P=A+(M+J)|0;a[P]=(d[P]|0|K)&255}J=J+1|0;}while((J|0)<16);I=I+1|0;}while((I|0)<16);G=G+1|0;}while((G|0)<4);E=E+1|0;}while((E|0)<4096);gGz(x|0,0,524288);if((c[3542200]|0)==0){D=1;i=e;return D|0}E=n+108|0;c[E>>2]=0;A=n+100|0;c[A>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,8)|0;do{if((c[E>>2]|0)!=0){G=c[A>>2]|0;c[o>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](o,8,0)|0;if((G|0)<1){D=1;i=e;return D|0}if((gzL(x,0,8)|0)==0){break}else{D=1}i=e;return D|0}}while(0);x=(c[3529540]|0)+262144|0;if((c[3542200]|0)==0){D=1;i=e;return D|0}A=l+108|0;c[A>>2]=0;E=l+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,9)|0;do{if((c[A>>2]|0)!=0){G=c[E>>2]|0;c[m>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](m,9,0)|0;if((G|0)<1){D=1;i=e;return D|0}if((gzL(x,0,9)|0)==0){break}else{D=1}i=e;return D|0}}while(0);x=c[3529540]|0;E=c[3529590]|0;A=0;do{G=A<<8;gGz(E+G|0,0,256);L=0;do{F=1<<3-L;I=(c[961520+(L<<2)>>2]|0)+G|0;K=0;do{H=I+(c[609008+(K<<2)>>2]|0)|0;J=(K<<4)+G|0;M=0;do{O=H+(c[597864+(M<<2)>>2]|0)|0;if(((d[x+((O|0)/8|0)|0]|0)&128>>>((O&7)>>>0)|0)!=0){O=E+(J+M)|0;a[O]=(d[O]|0|F)&255}M=M+1|0;}while((M|0)<16);K=K+1|0;}while((K|0)<16);L=L+1|0;}while((L|0)<4);A=A+1|0;}while((A|0)<4096);A=c[3541206]|0;if((c[3542200]|0)==0){D=1;i=e;return D|0}E=j+108|0;c[E>>2]=0;x=j+100|0;c[x>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,10)|0;do{if((c[E>>2]|0)!=0){L=c[x>>2]|0;c[k>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](k,10,0)|0;if((L|0)<1){D=1;i=e;return D|0}if((gzL(A,0,10)|0)==0){break}else{D=1}i=e;return D|0}}while(0);A=(c[3541206]|0)+131072|0;if((c[3542200]|0)==0){D=1;i=e;return D|0}x=f+108|0;c[x>>2]=0;E=f+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,11)|0;do{if((c[x>>2]|0)!=0){L=c[E>>2]|0;c[g>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](g,11,0)|0;if((L|0)<1){D=1;i=e;return D|0}if((gzL(A,0,11)|0)==0){break}else{D=1}i=e;return D|0}}while(0);A=c[3529540]|0;E=0;while(1){if((E|0)>=1024){break}Q=9638528+(E<<2)|0;if((c[Q>>2]|0)==(A|0)){z=73305;break}else{E=E+1|0}}if((z|0)==73305){gGr(A);c[Q>>2]=0}c[3529540]=0;fxU(0,425984);if((c[2394]|0)==0){R=c[2112932]|0}else{c[2394]=0;E=c[3532596]|0;c[2112932]=E;x=c[3532592]|0;if((x|0)!=0){gGC(9104152,x|0,280)|0}c[2113054]=c[2113060];R=E}E=c[2388036]|0;x=R|0;L=0;while(1){G=E+L|0;c[x>>2]=G;c[x+131072>>2]=G;G=L+1024|0;if(G>>>0>524287){break}else{x=x+4|0;L=G}}L=c[2443430]|0;c[R+64536>>2]=L;c[R+130072>>2]=L;c[R+195608>>2]=L;x=L+1024|0;c[R+64540>>2]=x;c[R+130076>>2]=x;c[R+195612>>2]=x;x=c[3527222]|0;c[R+64640>>2]=x;c[R+130176>>2]=x;c[R+195712>>2]=x;L=x+1024|0;c[R+64644>>2]=L;c[R+130180>>2]=L;c[R+195716>>2]=L;L=x+2048|0;c[R+64648>>2]=L;c[R+130184>>2]=L;c[R+195720>>2]=L;L=x+3072|0;c[R+64652>>2]=L;c[R+130188>>2]=L;c[R+195724>>2]=L;L=x+4096|0;c[R+64656>>2]=L;c[R+130192>>2]=L;c[R+195728>>2]=L;L=x+5120|0;c[R+64660>>2]=L;c[R+130196>>2]=L;c[R+195732>>2]=L;L=x+6144|0;c[R+64664>>2]=L;c[R+130200>>2]=L;c[R+195736>>2]=L;L=x+7168|0;c[R+64668>>2]=L;c[R+130204>>2]=L;c[R+195740>>2]=L;L=c[2439624]|0;c[R+64704>>2]=L;c[R+130240>>2]=L;c[R+195776>>2]=L;x=L+1024|0;c[R+64708>>2]=x;c[R+130244>>2]=x;c[R+195780>>2]=x;x=c[2439584]|0;c[R+64832>>2]=x;c[R+130368>>2]=x;c[R+195904>>2]=x;L=x+1024|0;c[R+64836>>2]=L;c[R+130372>>2]=L;c[R+195908>>2]=L;L=x+2048|0;c[R+64840>>2]=L;c[R+130376>>2]=L;c[R+195912>>2]=L;L=x+3072|0;c[R+64844>>2]=L;c[R+130380>>2]=L;c[R+195916>>2]=L;L=x+4096|0;c[R+64848>>2]=L;c[R+130384>>2]=L;c[R+195920>>2]=L;L=x+5120|0;c[R+64852>>2]=L;c[R+130388>>2]=L;c[R+195924>>2]=L;L=x+6144|0;c[R+64856>>2]=L;c[R+130392>>2]=L;c[R+195928>>2]=L;L=x+7168|0;c[R+64860>>2]=L;c[R+130396>>2]=L;c[R+195932>>2]=L;L=x+8192|0;c[R+64864>>2]=L;c[R+130400>>2]=L;c[R+195936>>2]=L;L=x+9216|0;c[R+64868>>2]=L;c[R+130404>>2]=L;c[R+195940>>2]=L;L=x+10240|0;c[R+64872>>2]=L;c[R+130408>>2]=L;c[R+195944>>2]=L;L=x+11264|0;c[R+64876>>2]=L;c[R+130412>>2]=L;c[R+195948>>2]=L;L=x+12288|0;c[R+64880>>2]=L;c[R+130416>>2]=L;c[R+195952>>2]=L;L=x+13312|0;c[R+64884>>2]=L;c[R+130420>>2]=L;c[R+195956>>2]=L;L=x+14336|0;c[R+64888>>2]=L;c[R+130424>>2]=L;c[R+195960>>2]=L;L=x+15360|0;c[R+64892>>2]=L;c[R+130428>>2]=L;c[R+195964>>2]=L;L=c[2439582]|0;x=R+64896|0;E=16613376;while(1){A=L+(E-16613376)|0;c[x>>2]=A;c[x+65536>>2]=A;c[x+131072>>2]=A;A=E+1024|0;if(A>>>0>16646143){break}else{x=x+4|0;E=A}}E=c[2388058]|0;x=R+65280|0;L=16711680;while(1){A=E+(L-16711680)|0;c[x>>2]=A;c[x+65536>>2]=A;c[x+131072>>2]=A;A=L+1024|0;if(A>>>0>16777215){break}else{x=x+4|0;L=A}}c[R+196728>>2]=2580;c[R+196608>>2]=2822;L=c[3532592]|0;if((L|0)!=0){gGC(L|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);L=c[2439330]|0;x=(L|0)==0;if(!x){E=L;gGC(9706056,E|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];E=c[3528484]|0;c[2076596]=E;A=c[2417276]|0;c[3541536]=A;c[1836236]=0;c[L+4180>>2]=1122;c[L+4184>>2]=582;G=c[2385844]|0;K=0;F=0;while(1){c[L+76+(F<<2)>>2]=G+(F<<8);I=K+1&65535;if((I&65535)>127){S=0;T=0;break}else{K=I;F=I&65535}}while(1){F=G+(T<<8)|0;c[L+76+(T+512<<2)>>2]=F;c[L+76+(T+768<<2)>>2]=F;F=S+1&65535;if((F&65535)>127){U=128;V=128;break}else{S=F;T=F&65535}}while(1){c[L+76+(V<<2)>>2]=G+(V<<8);F=U+1&65535;if((F&65535)>191){W=128;X=128;break}else{U=F;V=F&65535}}while(1){F=G+(X<<8)|0;c[L+76+(X+512<<2)>>2]=F;c[L+76+(X+768<<2)>>2]=F;F=W+1&65535;if((F&65535)>191){break}else{W=F;X=F&65535}}G=c[2385862]|0;c[L+908>>2]=G;F=G+256|0;c[L+912>>2]=F;K=G+512|0;c[L+916>>2]=K;I=G+768|0;c[L+920>>2]=I;M=G+1024|0;c[L+924>>2]=M;J=G+1280|0;c[L+928>>2]=J;H=G+1536|0;c[L+932>>2]=H;O=G+1792|0;c[L+936>>2]=O;c[L+1932>>2]=G;c[L+1936>>2]=F;c[L+1940>>2]=K;c[L+1944>>2]=I;c[L+1948>>2]=M;c[L+1952>>2]=J;c[L+1956>>2]=H;c[L+1960>>2]=O;c[L+2956>>2]=G;c[L+3980>>2]=G;c[L+2960>>2]=F;c[L+3984>>2]=F;c[L+2964>>2]=K;c[L+3988>>2]=K;c[L+2968>>2]=I;c[L+3992>>2]=I;c[L+2972>>2]=M;c[L+3996>>2]=M;c[L+2976>>2]=J;c[L+4e3>>2]=J;c[L+2980>>2]=H;c[L+4004>>2]=H;c[L+2984>>2]=O;c[L+4008>>2]=O;if(!x){O=L;gGC(O|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=E;c[2417276]=A;c[1836236]=-1;O=c[642608+(c[2436]<<2)>>2]|0;H=c[O+128>>2]|0;if((c[O+52>>2]&4|0)==0){c[2113068]=H;J=c[O+132>>2]|0;c[2113070]=J;c[2443814]=H;c[2440436]=J;Y=H;Z=J}else{c[2113070]=H;J=c[O+132>>2]|0;c[2113068]=J;c[2440436]=H;c[2443814]=J;Y=J;Z=H}H=ag(Y<<1,Z)|0;J=gGq(H)|0;c[2112926]=J;if((J|0)!=0){gGz(J|0,0,H|0)}a[1950792]=1;a[9720896]=-128;Vr(2,3579545,2386,1286,44,0);c[2438228]=3579545;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=571;h[745419]=.4;a[3203368]=1;h[745418]=.4;a[3203360]=1;h[745417]=.4;a[3203352]=1;h[745416]=.4;a[3203344]=1;h[745415]=.4;a[3203336]=1;h[745414]=.4;a[3203328]=1;h[745413]=.4;a[3203320]=1;h[745412]=.4;a[3203312]=1;Ux(0,7575,1);c[2407030]=251;c[2407068]=3;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];H=c[3532592]|0;if((H|0)!=0){gGC(9104152,H|0,280)|0}c[2113054]=c[2113060]}RI();H=c[2394]|0;J=c[14130368+(H<<2)>>2]|0;if((J|0)!=0){gGC(J|0,9104152,280)|0}c[8452240+(H<<2)>>2]=c[2113054];c[2394]=-1;H=c[2439330]|0;J=(H|0)==0;if(!J){O=H;gGC(9706056,O|0,76)|0}O=c[2438118]|0;c[2433530]=O;M=c[3528484]|0;c[2076596]=M;I=c[2417276]|0;c[3541536]=I;c[1836236]=0;gGz(9706056,0,76);if(!J){J=H;gGC(J|0,9706056,76)|0}c[2438118]=O;c[3528484]=M;c[2417276]=I;c[1836236]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){I=0;do{lN(I);mB(I);I=I+1|0;}while((I|0)<(c[2385508]|0))}b[4887148]=0;b[4887132]=0;b[4887208]=0;b[4887184]=0;a[9758008]=0;a[9758232]=0;c[2113156]=0;a[9628264]=0;c[2407033]=0;I=c[3541206]|0;c[3541190]=I;c[3541198]=I;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=I+256;c[3541199]=I+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=I+512;c[3541200]=I+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=I+768;c[3541201]=I+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;D=0;i=e;return D|0}}while(0);c[2426792]=0;D=1;i=e;return D|0}function doJ(b,c){b=b|0;c=c|0;a[9706117]=c&1;return}function doK(a){a=a|0;var b=0,d=0;b=(c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,3579545,0)|0;return a|0}function doL(){return+(+((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)/3579545.0)}function doM(a){a=a|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=c[2439584]|0;f=c[2112926]|0;g=c[3530980]|0;h=0;do{i=h<<4;j=0;do{k=(j<<5)+h|0;l=b[d+(k<<1)>>1]&8191;m=e[d+(k+2048<<1)>>1]|0;k=m>>>5&1;n=m>>>6&1;o=m&15;L88836:do{if((m>>>4&1|0)==(a|0)){p=(j<<4)-(e[4887148]|0)|0;q=i-(e[4887132]|0)|0;r=(p|0)<-16?p+1024|0:p;p=(q|0)<-16?q+512|0:q;q=r-64|0;s=p-8|0;do{if((r-81|0)>>>0<351){if((p-25|0)>>>0>=207){break}t=(n|0)!=0;if((k|0)==0){if(t){SK(f,l,q,s,o,4,15,256,g);break L88836}else{SG(f,l,q,s,o,4,15,256,g);break L88836}}else{if(t){SM(f,l,q,s,o,4,15,256,g);break L88836}else{SI(f,l,q,s,o,4,15,256,g);break L88836}}}}while(0);p=(n|0)!=0;if((k|0)==0){if(p){SL(f,l,q,s,o,4,15,256,g);break}else{SH(f,l,q,s,o,4,15,256,g);break}}else{if(p){SN(f,l,q,s,o,4,15,256,g);break}else{SJ(f,l,q,s,o,4,15,256,g);break}}}}while(0);j=j+1|0;}while((j|0)<64);h=h+1|0;}while((h|0)<32);return}function doN(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;g=c[2430220]|0;h=a[1950792]|0;i=d[9720896]|0;j=c[2112926]|0;k=c[3529590]|0;l=1020;do{m=e[g+((l|1)<<1)>>1]|0;do{if(h){if((f|0)==0){if((m&16|0)==0){break}else{n=73413;break}}else if((f|0)==1){if((m&16|0)==0){n=73413;break}else{break}}else{n=73413;break}}else{n=73413}}while(0);L88871:do{if((n|0)==73413){n=0;o=b[g+(l<<1)>>1]&4095;p=b[g+((l|3)<<1)>>1]&511;q=e[g+((l|2)<<1)>>1]|0;r=q&511;s=r>>>0>256?q|-512:r;r=m&32;q=i&m;t=m&15;u=p-64|0;v=s-8|0;do{if((p-81|0)>>>0<351){if((s-25|0)>>>0>=207){break}w=(q|0)!=0;if((r|0)==0){if(w){SK(j,o,u,v,t,4,15,512,k);break L88871}else{SG(j,o,u,v,t,4,15,512,k);break L88871}}else{if(w){SM(j,o,u,v,t,4,15,512,k);break L88871}else{SI(j,o,u,v,t,4,15,512,k);break L88871}}}}while(0);s=(q|0)!=0;if((r|0)==0){if(s){SL(j,o,u,v,t,4,15,512,k);break}else{SH(j,o,u,v,t,4,15,512,k);break}}else{if(s){SN(j,o,u,v,t,4,15,512,k);break}else{SJ(j,o,u,v,t,4,15,512,k);break}}}}while(0);l=l-4|0;}while((l|0)>-1);return}function doO(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=c[3527222]|0;b=c[2112926]|0;d=c[2406538]|0;f=0;g=0;while(1){h=f<<3;i=h-8|0;if((h-17|0)>>>0<223){h=g;j=0;while(1){k=e[a+(h<<1)>>1]|0;l=k>>>12;m=(k&2048|0)==0;n=k&2047;k=j<<3;o=k-64|0;do{if((k-65|0)>>>0<375){if(m){Sq(b,n,o,i,l,2,3,768,d);break}else{Su(b,n,o,i,l,2,3,768,d);break}}else{if(m){Sr(b,n,o,i,l,2,3,768,d);break}else{Sv(b,n,o,i,l,2,3,768,d);break}}}while(0);l=j+1|0;if((l|0)<64){h=h+1|0;j=l}else{break}}}else{j=g;h=0;while(1){l=e[a+(j<<1)>>1]|0;o=l>>>12;n=l&2047;m=(h<<3)-64|0;if((l&2048|0)==0){Sr(b,n,m,i,o,2,3,768,d)}else{Sv(b,n,m,i,o,2,3,768,d)}o=h+1|0;if((o|0)<64){j=j+1|0;h=o}else{break}}}h=f+1|0;if((h|0)<32){f=h;g=g+64|0}else{break}}return}function doP(a){a=a|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=c[2439584]|0;f=c[2112926]|0;g=c[3530980]|0;h=0;i=0;while(1){j=i<<4;k=h;l=0;while(1){m=k<<1;n=b[d+(m<<1)>>1]&8191;o=e[d+((m|1)<<1)>>1]|0;m=o>>>5&1;p=o>>>6&1;q=o&15;if((o>>>7&1|0)==(a|0)){o=(l<<4)-(e[4887148]|0)|0;r=j-(e[4887132]|0)|0;s=(o|0)<-16?o+1024|0:o;o=(r|0)<-16?r+1024|0:r;r=s-64|0;t=o-8|0;do{if((s-81|0)>>>0<351){if((o-25|0)>>>0>=207){u=73459;break}v=(p|0)!=0;if((m|0)==0){if(v){SK(f,n,r,t,q,4,0,256,g);break}else{SG(f,n,r,t,q,4,0,256,g);break}}else{if(v){SM(f,n,r,t,q,4,0,256,g);break}else{SI(f,n,r,t,q,4,0,256,g);break}}}else{u=73459}}while(0);do{if((u|0)==73459){u=0;o=(p|0)!=0;if((m|0)==0){if(o){SL(f,n,r,t,q,4,0,256,g);break}else{SH(f,n,r,t,q,4,0,256,g);break}}else{if(o){SN(f,n,r,t,q,4,0,256,g);break}else{SJ(f,n,r,t,q,4,0,256,g);break}}}}while(0);w=k+1|0}else{w=k}q=l+1|0;if((q|0)<64){k=w;l=q}else{break}}l=i+1|0;if((l|0)<64){h=w;i=l}else{break}}return}function doQ(b){b=b|0;var c=0,d=0;c=b&65535;if((c|0)==45056){d=a[9658040]|0}else if((c|0)==47104){d=a[9625858]|0}else if((c|0)==43008){d=a[9625856]|0}else if((c|0)==40960){d=a[9625857]|0}else{d=0}return d|0}function doR(b,d){b=b|0;d=d|0;switch(b&65535|0){case 40962:{a[9755200]=a[818408]&1^d;return};case 40961:{a[9755192]=a[818408]&1^d;return};case 39424:{a[9755120]=a[9755120]&2|d&1;return};case 38912:{a[9751080]=d;return};case 40960:{c[2430232]=d&255;return};case 39936:{a[9755120]=a[9755120]&1|d<<1&2;return};default:{return}}}function doS(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if(((e&255)-8|0)>>>0>=2){return}b=d&255;if((e&1|0)==0){c[3542228]=b&15;return}e=c[3542228]|0;if((e|0)>15){return}do{if((e|0)<14){if((e|0)!=13){if((a[14168916+e|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(0,e,b);return}function doT(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5296276+(b*112|0)>>2];c[a+104>>2]=c[5296280+(b*112|0)>>2];c[a+108>>2]=c[5296284+(b*112|0)>>2];d=0;return d|0}function doU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=5296176+(b*112|0);e=0;return e|0}function doV(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1838224+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function doW(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5297296+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function doX(){var b=0;a[9755120]=0;a[9751080]=0;a[9755192]=0;a[9755200]=0;c[2430232]=0;a[818408]=0;b=9759256;c[b>>2]=0;c[b+4>>2]=0;b=9759064;c[b>>2]=0;c[b+4>>2]=0;b=9758880;c[b>>2]=0;c[b+4>>2]=0;gGz(9625856,0,3);a[9658040]=0;a[9624712]=0;a[641008]=1;return do3()|0}function doY(){var b=0,d=0,e=0,f=0;c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}fwZ();c[2113008]=0;c[2076598]=0;c[2383582]=0;b=c[2415038]|0;d=0;while(1){if((d|0)>=1024){break}e=9638528+(d<<2)|0;if((c[e>>2]|0)==(b|0)){f=73537;break}else{d=d+1|0}}if((f|0)==73537){gGr(b);c[e>>2]=0}c[2415038]=0;a[9755120]=0;a[9751080]=0;a[9755192]=0;a[9755200]=0;c[2430232]=0;a[641008]=0;a[818408]=0;e=9759256;c[e>>2]=0;c[e+4>>2]=0;e=9759064;c[e>>2]=0;c[e+4>>2]=0;e=9758880;c[e>>2]=0;c[e+4>>2]=0;gGz(9625856,0,3);a[9658040]=0;a[9624712]=0;return 0}function doZ(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;if((a[9624712]|0)!=0){d=c[2405700]|0;gGz(d|0,0,(c[2411786]|0)-d|0);d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;h=c[2417276]|0;c[3541536]=h;c[1836236]=0;gGz(9706056,0,76);if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=h;c[1836236]=-1;mB(0);a[9755120]=0;a[9751080]=0;a[9755192]=0;a[9755200]=0;c[2430232]=0}a[9625858]=0;a[9625857]=0;a[9625856]=0;h=0;g=0;f=0;e=0;do{g=((a[9759256+h|0]&1)<<h|g&255)&255;f=((a[9759064+h|0]&1)<<h|f&255)&255;e=((a[9758880+h|0]&1)<<h|e&255)&255;h=h+1|0;}while((h|0)<8);a[9625856]=g;a[9625857]=f;a[9625858]=e;e=c[2439330]|0;if((e|0)!=0){f=e;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;f=c[2438118]|0;c[2433530]=f;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;if((a[e+4188|0]|0)==0){e=gfc(51200)|0;i=(c[2433530]|0)+e|0}else{i=f+51200|0}c[2433530]=i;if((c[2430232]|0)==0){j=i}else{if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;i=(c[2433530]|0)+12|0;c[2433530]=i;j=i}i=c[1836236]|0;f=c[9757320+(i<<2)>>2]|0;if((f|0)!=0){e=f;gGC(e|0,9706056,76)|0}c[9752472+(i<<2)>>2]=j;c[14113936+(i<<2)>>2]=c[2076596];c[9669104+(i<<2)>>2]=c[3541536];c[1836236]=-1;i=c[2112964]|0;if((i|0)!=0){mF(9756496,i,a[9688]|0?534:0,0)}if((c[2112968]|0)==0){return 0}do_()|0;return 0}function do_(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;if((a[9733792]|0)!=0){b=c[3527010]|0;e=c[3530110]|0;f=0;do{g=c[b+(f<<2)>>2]|0;c[e+(f<<2)>>2]=g>>>8&2016|g&31|g>>>16&63488;f=f+1|0;}while((f|0)<256);a[9733792]=0}f=a[641008]&1;if((f|0)==0){e=c[2386250]|0;b=c[2387884]|0;g=d[9755120]|0;h=g<<4;i=(g&1|0)==0;j=(g&2|0)!=0;g=c[2112926]|0;k=c[3530894]|0;l=0;do{m=l<<5;n=(l<<3)-16|0;o=0;do{p=o+m|0;q=d[b+p|0]|0;r=q<<2&768|d[e+p|0];p=h|q&15;q=o<<3;do{if(i){if(j){Sl(g,r,q,n,p,2,0,k);break}else{Sj(g,r,q,n,p,2,0,k);break}}else{if(j){Sp(g,r,q,n,p,2,0,k);break}else{Sn(g,r,q,n,p,2,0,k);break}}}while(0);o=o+1|0;}while((o|0)<32);l=l+1|0;}while((l|0)<32);l=(a[9755192]|0)==0;k=((a[9755200]|0)==0)<<31>>31;j=c[3530658]|0;i=c[3530466]|0;o=15;while(1){do{if(!((o|0)==2|(o|0)==0)){n=o+16|0;m=d[e+n|0]|0;p=o+48|0;q=240-(d[e+p|0]|0)|0;r=d[b+n|0]|0;n=h|a[b+p|0]&15;p=(m&2|0)==0;s=m&1;if((o|0)<4){t=2;u=q-16|0;v=m<<2&48|m>>>4}else{t=1;u=q;v=m>>>2}if(l){w=s;x=((t|0)==1?240:224)-r|0}else{w=s^1;x=r}r=k+u|0;s=x-16|0;m=(w|0)!=0;if((t|0)==1){if(m){if(p){SN(g,v,r,s,n,2,0,0,j);break}else{SL(g,v,r,s,n,2,0,0,j);break}}else{if(p){SJ(g,v,r,s,n,2,0,0,j);break}else{SH(g,v,r,s,n,2,0,0,j);break}}}else{if(m){if(p){S1(g,v,r,s,n,2,0,0,i);break}else{S$(g,v,r,s,n,2,0,0,i);break}}else{if(p){SZ(g,v,r,s,n,2,0,0,i);break}else{SX(g,v,r,s,n,2,0,0,i);break}}}}}while(0);if((o|0)>0){o=o-1|0}else{break}}y=c[3530110]|0;R8(y);return 0}else if((f|0)==1){f=c[2386250]|0;o=c[2387884]|0;i=d[9755120]|0;v=i<<4;g=d[9751080]|0;j=(i&1|0)==0;t=(i&2|0)!=0;i=c[2112926]|0;w=c[3530894]|0;x=0;do{u=x<<5;k=x<<3;l=k-g|0;b=(l|0)<-7?l+256|0:l;l=0;do{h=l+u|0;e=d[o+h|0]|0;n=e<<2&768|d[f+h|0];h=v|e&15;e=l<<3;s=((e|0)<192?b:k)-16|0;do{if(j){if(t){Sl(i,n,e,s,h,2,0,w);break}else{Sj(i,n,e,s,h,2,0,w);break}}else{if(t){Sp(i,n,e,s,h,2,0,w);break}else{Sn(i,n,e,s,h,2,0,w);break}}}while(0);l=l+1|0;}while((l|0)<32);x=x+1|0;}while((x|0)<32);x=(a[9755192]|0)==0;w=(a[9755200]|0)!=0|0;t=c[3530658]|0;j=c[3530466]|0;g=15;while(1){do{if(!((g|0)==2|(g|0)==0)){l=((g|0)<8?24:976)+g|0;k=d[f+l|0]|0;b=l+32|0;u=d[o+l|0]|0;l=v|a[o+b|0]&15;h=k&1;if((g|0)<4){z=2;A=k<<2&48|k>>>4}else{z=1;A=k>>>2}if(x){B=h;C=((z|0)==1?240:224)-u|0}else{B=h^1;C=u}u=w+(d[f+b|0]|0)|0;b=C-16|0;h=(B|0)!=0;s=(k&2|0)!=0;if((z|0)==1){if(h){if(s){SN(i,A,u,b,l,2,0,0,t);break}else{SL(i,A,u,b,l,2,0,0,t);break}}else{if(s){SJ(i,A,u,b,l,2,0,0,t);break}else{SH(i,A,u,b,l,2,0,0,t);break}}}else{if(h){if(s){S1(i,A,u,b,l,2,0,0,j);break}else{S$(i,A,u,b,l,2,0,0,j);break}}else{if(s){SZ(i,A,u,b,l,2,0,0,j);break}else{SX(i,A,u,b,l,2,0,0,j);break}}}}}while(0);if((g|0)>0){g=g-1|0}else{break}}y=c[3530110]|0;R8(y);return 0}else{y=c[3530110]|0;R8(y);return 0}return 0}function do$(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;d=i;i=i+48|0;e=d|0;f=d+32|0;g=(b|0)==0;if(!g){c[b>>2]=169736}if((a&96|0)==0){i=d;return 0}gGz(f|0,0,12);h=c[2405700]|0;c[f>>2]=h;c[f+4>>2]=(c[2411786]|0)-h;c[f+12>>2]=162152;gj[c[2076592]&4095](f)|0;fw$(a);f=d+16|0;if((a&64|0)==0){i=d;return 0}do{if(!g){if((c[b>>2]|0)>=169110){break}c[b>>2]=169110}}while(0);if((c[2113008]|0)<=0){i=d;return 0}b=e|0;g=e+4|0;a=e+8|0;h=e+12|0;j=0;do{cC(f|0,531144,(k=i,i=i+8|0,c[k>>2]=j,k)|0)|0;i=k;c[b>>2]=14168888+(j*252|0);c[g>>2]=252;c[a>>2]=0;c[h>>2]=f;gj[c[2076592]&4095](e)|0;j=j+1|0;}while((j|0)<(c[2113008]|0));i=d;return 0}function do0(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3384252+(b*112|0)>>2];c[a+104>>2]=c[3384256+(b*112|0)>>2];c[a+108>>2]=c[3384260+(b*112|0)>>2];d=0;return d|0}function do1(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=3384152+(b*112|0);e=0;return e|0}function do2(){var b=0;a[9755120]=0;a[9751080]=0;a[9755192]=0;a[9755200]=0;c[2430232]=0;b=9759256;c[b>>2]=0;c[b+4>>2]=0;b=9759064;c[b>>2]=0;c[b+4>>2]=0;b=9758880;c[b>>2]=0;c[b+4>>2]=0;gGz(9625856,0,3);a[9658040]=0;a[9624712]=0;a[818408]=1;a[641008]=0;return do3()|0}function do3(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0.0,ah=0,ai=0,aj=0;e=i;i=i+1560|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;B=e+1200|0;C=e+1312|0;D=e+1320|0;E=e+1432|0;F=e+1440|0;G=e+1552|0;c[2415038]=0;c[2385962]=0;c[3531032]=65536;c[3530894]=66048;c[3530658]=98816;c[3530466]=115200;c[3527010]=180736;c[3530110]=181760;c[2439124]=182784;H=a[9688]|0?1068:0;I=H|182784;c[2439125]=I;J=I+H|0;c[2439126]=J;I=J+H|0;H=I|0;c[2405700]=H;c[2386116]=H;c[2386250]=I+2048;c[2386506]=I+3072;c[2387884]=I+3328;H=I+4352|0;c[2411786]=H;c[2414334]=H;I=H;H=0;while(1){if((H|0)>=1024){break}K=9638528+(H<<2)|0;if((c[K>>2]|0)==0){L=73673;break}else{H=H+1|0}}do{if((L|0)==73673){H=gGq(I)|0;c[K>>2]=H;if((H|0)==0){break}gGz(H|0,0,I|0);c[2415038]=H;gGz(H|0,0,I|0);c[2385962]=H;c[3531032]=H+65536;c[3530894]=H+66048;c[3530658]=H+98816;c[3530466]=H+115200;c[3527010]=H+180736;c[3530110]=H+181760;c[2439124]=H+182784;J=a[9688]|0?1068:0;M=J|182784;c[2439125]=H+M;N=M+J|0;c[2439126]=H+N;M=N+J|0;J=H+M|0;c[2405700]=J;c[2386116]=J;c[2386250]=H+(M+2048);c[2386506]=H+(M+3072);c[2387884]=H+(M+3328);J=H+(M+4352)|0;c[2411786]=J;c[2414334]=J;J=a[641008]&1;L89223:do{if((J|0)==1){M=F+108|0;N=F+100|0;O=0;P=H;while(1){Q=P+(O<<12)|0;if((c[3542200]|0)==0){break L89223}c[M>>2]=0;c[N>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](F,O)|0;if((c[M>>2]|0)!=0){R=c[N>>2]|0;c[G>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](G,O,0)|0;if((R|0)<1){break L89223}if((gzL(Q,0,O)|0)!=0){break L89223}}Q=O+1|0;if((Q|0)>=5){T=0;break}O=Q;P=c[2385962]|0}while(1){if((T|0)>=1024){break L89223}U=9638528+(T<<2)|0;if((c[U>>2]|0)==0){break}else{T=T+1|0}}P=gGq(16384)|0;c[U>>2]=P;if((P|0)==0){break}gGz(P|0,0,16384);gGz(P|0,0,8192);if((c[3542200]|0)==0){break}O=D+108|0;c[O>>2]=0;N=D+100|0;c[N>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](D,5)|0;if((c[O>>2]|0)!=0){O=c[N>>2]|0;c[E>>2]=9534384;N=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[N&16383](E,5,0)|0;if((O|0)<1){break}if((gzL(P,0,5)|0)!=0){break}}O=c[3530894]|0;N=0;do{M=N<<6;gGz(O+M|0,0,64);Q=N<<7;R=0;do{S=Q+(c[1238464+(R<<2)>>2]|0)|0;V=(R<<3)+M|0;W=0;do{X=S+(c[612768+(W<<2)>>2]|0)|0;if(((d[P+((X|0)/8|0)|0]|0)&128>>>((X&7)>>>0)|0)!=0){X=O+(V+W)|0;a[X]=a[X]|2}W=W+1|0;}while((W|0)<8);R=R+1|0;}while((R|0)<8);R=Q|4;W=0;do{V=R+(c[1238464+(W<<2)>>2]|0)|0;S=(W<<3)+M|0;X=0;do{Y=V+(c[612768+(X<<2)>>2]|0)|0;if(((d[P+((Y|0)/8|0)|0]|0)&128>>>((Y&7)>>>0)|0)!=0){Y=O+(S+X)|0;a[Y]=a[Y]|1}X=X+1|0;}while((X|0)<8);W=W+1|0;}while((W|0)<8);N=N+1|0;}while((N|0)<512);gGz(P|0,0,16384);if((c[3542200]|0)==0){break}N=B+108|0;c[N>>2]=0;O=B+100|0;c[O>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](B,6)|0;if((c[N>>2]|0)!=0){N=c[O>>2]|0;c[C>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](C,6,0)|0;if((N|0)<1){break}if((gzL(P,0,6)|0)!=0){break}}N=P+8192|0;if((c[3542200]|0)==0){break}O=z+108|0;c[O>>2]=0;W=z+100|0;c[W>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,7)|0;if((c[O>>2]|0)!=0){O=c[W>>2]|0;c[A>>2]=9534384;W=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[W&16383](A,7,0)|0;if((O|0)<1){break}if((gzL(N,0,7)|0)!=0){break}}N=c[3530658]|0;O=0;do{W=O<<8;gGz(N+W|0,0,256);M=0;do{R=W+(c[611776+(M<<2)>>2]|0)|0;Q=(M<<4)+W|0;X=0;do{S=R+(c[601400+(X<<2)>>2]|0)|0;if(((d[P+((S|0)/8|0)|0]|0)&128>>>((S&7)>>>0)|0)!=0){S=N+(Q+X)|0;a[S]=a[S]|2}X=X+1|0;}while((X|0)<16);M=M+1|0;}while((M|0)<16);M=W+65536|0;X=0;do{Q=M+(c[611776+(X<<2)>>2]|0)|0;R=(X<<4)+W|0;S=0;do{V=Q+(c[601400+(S<<2)>>2]|0)|0;if(((d[P+((V|0)/8|0)|0]|0)&128>>>((V&7)>>>0)|0)!=0){V=N+(R+S)|0;a[V]=a[V]|1}S=S+1|0;}while((S|0)<16);X=X+1|0;}while((X|0)<16);O=O+1|0;}while((O|0)<64);O=c[3530466]|0;N=0;while(1){X=N<<10;gGz(O+X|0,0,1024);W=0;do{M=X+(c[703688+(W<<2)>>2]|0)|0;S=(W<<5)+X|0;R=0;do{Q=M+(c[703816+(R<<2)>>2]|0)|0;if(((d[P+((Q|0)/8|0)|0]|0)&128>>>((Q&7)>>>0)|0)!=0){Q=O+(S+R)|0;a[Q]=a[Q]|2}R=R+1|0;}while((R|0)<32);W=W+1|0;}while((W|0)<32);W=X+65536|0;R=0;do{S=W+(c[703688+(R<<2)>>2]|0)|0;M=(R<<5)+X|0;Q=0;do{V=S+(c[703816+(Q<<2)>>2]|0)|0;if(((d[P+((V|0)/8|0)|0]|0)&128>>>((V&7)>>>0)|0)!=0){V=O+(M+Q)|0;a[V]=a[V]|1}Q=Q+1|0;}while((Q|0)<32);R=R+1|0;}while((R|0)<32);R=N+1|0;if((R|0)<64){N=R}else{Z=0;break}}while(1){if((Z|0)>=1024){break}_=9638528+(Z<<2)|0;if((c[_>>2]|0)==(P|0)){L=73725;break}else{Z=Z+1|0}}if((L|0)==73725){gGr(P);c[_>>2]=0}N=c[3531032]|0;if((c[3542200]|0)==0){break}O=x+108|0;c[O>>2]=0;R=x+100|0;c[R>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,8)|0;if((c[O>>2]|0)!=0){O=c[R>>2]|0;c[y>>2]=9534384;R=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[R&16383](y,8,0)|0;if((O|0)<1){break}if((gzL(N,0,8)|0)!=0){break}}N=(c[3531032]|0)+256|0;if((c[3542200]|0)==0){break}O=v+108|0;c[O>>2]=0;R=v+100|0;c[R>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,9)|0;if((c[O>>2]|0)==0){break}O=c[R>>2]|0;c[w>>2]=9534384;gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](w,9,0)|0;if((O|0)<1){break}gzL(N,0,9)|0}else if((J|0)==0){N=t+108|0;O=t+100|0;R=0;X=H;while(1){W=X+(R<<12)|0;if((c[3542200]|0)==0){break L89223}c[N>>2]=0;c[O>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,R)|0;if((c[N>>2]|0)!=0){Q=c[O>>2]|0;c[u>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](u,R,0)|0;if((Q|0)<1){break L89223}if((gzL(W,0,R)|0)!=0){break L89223}}W=R+1|0;if((W|0)>=5){$=0;break}R=W;X=c[2385962]|0}while(1){if(($|0)>=1024){break L89223}aa=9638528+($<<2)|0;if((c[aa>>2]|0)==0){break}else{$=$+1|0}}X=gGq(16384)|0;c[aa>>2]=X;if((X|0)==0){break}gGz(X|0,0,16384);if((c[3542200]|0)==0){break}R=r+108|0;c[R>>2]=0;O=r+100|0;c[O>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,5)|0;if((c[R>>2]|0)!=0){R=c[O>>2]|0;c[s>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](s,5,0)|0;if((R|0)<1){break}if((gzL(X,0,5)|0)!=0){break}}R=X+4096|0;if((c[3542200]|0)==0){break}O=p+108|0;c[O>>2]=0;N=p+100|0;c[N>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,6)|0;if((c[O>>2]|0)!=0){O=c[N>>2]|0;c[q>>2]=9534384;N=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[N&16383](q,6,0)|0;if((O|0)<1){break}if((gzL(R,0,6)|0)!=0){break}}R=c[3530894]|0;O=0;do{N=O<<6;gGz(R+N|0,0,64);P=O<<7;W=0;do{Q=P+(c[1238464+(W<<2)>>2]|0)|0;M=(W<<3)+N|0;S=0;do{V=Q+(c[612768+(S<<2)>>2]|0)|0;if(((d[X+((V|0)/8|0)|0]|0)&128>>>((V&7)>>>0)|0)!=0){V=R+(M+S)|0;a[V]=a[V]|2}S=S+1|0;}while((S|0)<8);W=W+1|0;}while((W|0)<8);W=P|4;S=0;do{M=W+(c[1238464+(S<<2)>>2]|0)|0;Q=(S<<3)+N|0;V=0;do{Y=M+(c[612768+(V<<2)>>2]|0)|0;if(((d[X+((Y|0)/8|0)|0]|0)&128>>>((Y&7)>>>0)|0)!=0){Y=R+(Q+V)|0;a[Y]=a[Y]|1}V=V+1|0;}while((V|0)<8);S=S+1|0;}while((S|0)<8);O=O+1|0;}while((O|0)<512);gGz(X|0,0,16384);if((c[3542200]|0)==0){break}O=n+108|0;c[O>>2]=0;R=n+100|0;c[R>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,7)|0;if((c[O>>2]|0)!=0){O=c[R>>2]|0;c[o>>2]=9534384;R=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[R&16383](o,7,0)|0;if((O|0)<1){break}if((gzL(X,0,7)|0)!=0){break}}O=X+8192|0;if((c[3542200]|0)==0){break}R=l+108|0;c[R>>2]=0;S=l+100|0;c[S>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,8)|0;if((c[R>>2]|0)!=0){R=c[S>>2]|0;c[m>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](m,8,0)|0;if((R|0)<1){break}if((gzL(O,0,8)|0)!=0){break}}O=c[3530658]|0;R=0;do{S=R<<8;gGz(O+S|0,0,256);N=0;do{W=S+(c[611776+(N<<2)>>2]|0)|0;P=(N<<4)+S|0;V=0;do{Q=W+(c[601400+(V<<2)>>2]|0)|0;if(((d[X+((Q|0)/8|0)|0]|0)&128>>>((Q&7)>>>0)|0)!=0){Q=O+(P+V)|0;a[Q]=a[Q]|2}V=V+1|0;}while((V|0)<16);N=N+1|0;}while((N|0)<16);N=S+65536|0;V=0;do{P=N+(c[611776+(V<<2)>>2]|0)|0;W=(V<<4)+S|0;Q=0;do{M=P+(c[601400+(Q<<2)>>2]|0)|0;if(((d[X+((M|0)/8|0)|0]|0)&128>>>((M&7)>>>0)|0)!=0){M=O+(W+Q)|0;a[M]=a[M]|1}Q=Q+1|0;}while((Q|0)<16);V=V+1|0;}while((V|0)<16);R=R+1|0;}while((R|0)<64);R=c[3530466]|0;O=0;while(1){V=O<<10;gGz(R+V|0,0,1024);S=0;do{N=V+(c[703688+(S<<2)>>2]|0)|0;Q=(S<<5)+V|0;W=0;do{P=N+(c[703816+(W<<2)>>2]|0)|0;if(((d[X+((P|0)/8|0)|0]|0)&128>>>((P&7)>>>0)|0)!=0){P=R+(Q+W)|0;a[P]=a[P]|2}W=W+1|0;}while((W|0)<32);S=S+1|0;}while((S|0)<32);S=V+65536|0;W=0;do{Q=S+(c[703688+(W<<2)>>2]|0)|0;N=(W<<5)+V|0;P=0;do{M=Q+(c[703816+(P<<2)>>2]|0)|0;if(((d[X+((M|0)/8|0)|0]|0)&128>>>((M&7)>>>0)|0)!=0){M=R+(N+P)|0;a[M]=a[M]|1}P=P+1|0;}while((P|0)<32);W=W+1|0;}while((W|0)<32);W=O+1|0;if((W|0)<64){O=W}else{ab=0;break}}while(1){if((ab|0)>=1024){break}ac=9638528+(ab<<2)|0;if((c[ac>>2]|0)==(X|0)){L=73785;break}else{ab=ab+1|0}}if((L|0)==73785){gGr(X);c[ac>>2]=0}O=c[3531032]|0;if((c[3542200]|0)==0){break}R=j+108|0;c[R>>2]=0;W=j+100|0;c[W>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,9)|0;if((c[R>>2]|0)!=0){R=c[W>>2]|0;c[k>>2]=9534384;W=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[W&16383](k,9,0)|0;if((R|0)<1){break}if((gzL(O,0,9)|0)!=0){break}}O=(c[3531032]|0)+256|0;if((c[3542200]|0)==0){break}R=f+108|0;c[R>>2]=0;W=f+100|0;c[W>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,10)|0;if((c[R>>2]|0)==0){break}R=c[W>>2]|0;c[g>>2]=9534384;gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](g,10,0)|0;if((R|0)<1){break}gzL(O,0,10)|0}}while(0);H=c[3531032]|0;J=c[3527010]|0;O=0;do{R=d[H+O|0]|0;W=d[H+(O+256)|0]|0;c[J+(O<<2)>>2]=(-(R>>>3&1)&33)+(-(W&1)&71)+(-(W>>>1&1)&151)<<8|(-(W>>>2&1)&71)+(-(W>>>3&1)&151)|(-(R>>>1&1)&71)+(-(R&1)&33)+(-(R>>>2&1)&151)<<16;O=O+1|0;}while((O|0)<256);fwR(0);O=c[2439330]|0;J=(O|0)==0;if(!J){H=O;gGC(9706056,H|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];H=c[3528484]|0;c[2076596]=H;R=c[2417276]|0;c[3541536]=R;c[1836236]=0;W=c[2385962]|0;V=0;S=0;while(1){c[O+76+(S<<2)>>2]=W+(S<<8);P=V+1&65535;if((P&65535)>127){ad=0;ae=0;break}else{V=P;S=P&65535}}while(1){S=W+(ae<<8)|0;c[O+76+(ae+512<<2)>>2]=S;c[O+76+(ae+768<<2)>>2]=S;S=ad+1&65535;if((S&65535)>127){break}else{ad=S;ae=S&65535}}W=c[2386116]|0;c[O+588>>2]=W;S=W+256|0;c[O+592>>2]=S;V=W+512|0;c[O+596>>2]=V;P=W+768|0;c[O+600>>2]=P;N=W+1024|0;c[O+604>>2]=N;Q=W+1280|0;c[O+608>>2]=Q;M=W+1536|0;c[O+612>>2]=M;Y=W+1792|0;c[O+616>>2]=Y;c[O+1612>>2]=W;c[O+1616>>2]=S;c[O+1620>>2]=V;c[O+1624>>2]=P;c[O+1628>>2]=N;c[O+1632>>2]=Q;c[O+1636>>2]=M;c[O+1640>>2]=Y;c[O+2636>>2]=W;c[O+3660>>2]=W;c[O+2640>>2]=S;c[O+3664>>2]=S;c[O+2644>>2]=V;c[O+3668>>2]=V;c[O+2648>>2]=P;c[O+3672>>2]=P;c[O+2652>>2]=N;c[O+3676>>2]=N;c[O+2656>>2]=Q;c[O+3680>>2]=Q;c[O+2660>>2]=M;c[O+3684>>2]=M;c[O+2664>>2]=Y;c[O+3688>>2]=Y;Y=c[2386250]|0;c[O+620>>2]=Y;M=Y+256|0;c[O+624>>2]=M;Q=Y+512|0;c[O+628>>2]=Q;N=Y+768|0;c[O+632>>2]=N;c[O+1644>>2]=Y;c[O+1648>>2]=M;c[O+1652>>2]=Q;c[O+1656>>2]=N;c[O+2668>>2]=Y;c[O+3692>>2]=Y;c[O+2672>>2]=M;c[O+3696>>2]=M;c[O+2676>>2]=Q;c[O+3700>>2]=Q;c[O+2680>>2]=N;c[O+3704>>2]=N;N=c[2386506]|0;c[O+636>>2]=N;c[O+1660>>2]=N;c[O+2684>>2]=N;c[O+3708>>2]=N;N=c[2387884]|0;c[O+652>>2]=N;Q=N+256|0;c[O+656>>2]=Q;M=N+512|0;c[O+660>>2]=M;Y=N+768|0;c[O+664>>2]=Y;c[O+1676>>2]=N;c[O+1680>>2]=Q;c[O+1684>>2]=M;c[O+1688>>2]=Y;c[O+2700>>2]=N;c[O+3724>>2]=N;c[O+2704>>2]=Q;c[O+3728>>2]=Q;c[O+2708>>2]=M;c[O+3732>>2]=M;c[O+2712>>2]=Y;c[O+3736>>2]=Y;c[O+4180>>2]=1502;c[O+4184>>2]=304;c[O+4176>>2]=2936;if(!J){Y=O;gGC(Y|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=H;c[2417276]=R;c[1836236]=-1;Y=a[9680]|0?32e3:0;c[3542220]=11200;if((c[2113008]|0)==0){gGz(14168888,0,252);c[3542223]=Y;gGz(14168896,0,16);c[3542234]=~~((+(Y|0)*32768.0*8.0+75.0e4)/15.0e5);Y=31;af=32767.0;while(1){c[14169012+(Y<<2)>>2]=~~(af+.5);M=Y-1|0;if((M|0)>0){Y=M;af=af/1.188502227}else{break}}c[3542253]=0;h[1771269]=1.0;h[1771270]=1.0;h[1771271]=1.0;c[3542574]=3;c[3542575]=3;c[3542576]=3;mB(0);c[2113008]=(c[2113008]|0)+1}h[1771269]=.5;c[3542574]=3;h[1771270]=.5;c[3542575]=3;h[1771271]=.5;c[3542576]=3;Y=c[642608+(c[2436]<<2)>>2]|0;R=c[Y+128>>2]|0;if((c[Y+52>>2]&4|0)==0){c[2113068]=R;H=c[Y+132>>2]|0;c[2113070]=H;c[2443814]=R;c[2440436]=H;ah=R;ai=H}else{c[2113070]=R;H=c[Y+132>>2]|0;c[2113068]=H;c[2440436]=R;c[2443814]=H;ah=H;ai=R}R=ag(ah<<1,ai)|0;H=gGq(R)|0;c[2112926]=H;if((H|0)!=0){gGz(H|0,0,R|0)}R=c[2405700]|0;gGz(R|0,0,(c[2411786]|0)-R|0);R=c[2439330]|0;H=(R|0)==0;if(!H){Y=R;gGC(9706056,Y|0,76)|0}Y=c[2438118]|0;c[2433530]=Y;O=c[3528484]|0;c[2076596]=O;J=c[2417276]|0;c[3541536]=J;c[1836236]=0;gGz(9706056,0,76);if(!H){H=R;gGC(H|0,9706056,76)|0}c[2438118]=Y;c[3528484]=O;c[2417276]=J;c[1836236]=-1;mB(0);a[9755120]=0;a[9751080]=0;a[9755192]=0;a[9755200]=0;c[2430232]=0;aj=0;i=e;return aj|0}}while(0);c[2415038]=0;aj=1;i=e;return aj|0}function do4(b){b=b|0;var d=0;if((b+26624&65535)>=2048){d=0;return d|0}d=a[(c[2437654]|0)+((b&65535)-38912)|0]|-16;return d|0}function do5(b,c){b=b|0;c=c|0;var d=0;d=b&65535;if((d|0)==45056){a[9733648]=c&1;a[9757872]=(c&255)>>>5&1;a[9720528]=(c&255)>>>6&1;return}else if((d|0)==47104){a[9754720]=c;return}else if((d|0)==43008){a[9733640]=c;return}else{return}}function do6(b,c){b=b|0;c=c|0;var d=0;d=b&255;if((d|0)==65){a[9750672]=c&1;return}else if((d|0)==66){a[9726696]=c&1;return}else if((d|0)==64){a[9754712]=c&1;return}else{return}}function do7(b,c){b=b|0;c=c|0;var d=0;d=b&255;if((d|0)==193){a[9750672]=c&1;return}else if((d|0)==194){a[9726696]=c&1;return}else if((d|0)==192){a[9754712]=c&1;return}else{return}}function do8(b,c){b=b|0;c=c|0;var d=0;d=b&255;if((d|0)==1){a[9750672]=c&1;return}else if((d|0)==2){a[9726696]=c&1;return}else if((d|0)==0){a[9754712]=c&1;return}else{return}}function do9(b,c){b=b|0;c=c|0;var d=0;d=b&255;if((d|0)==9){a[9750672]=c&1;return}else if((d|0)==10){a[9726696]=c&1;return}else if((d|0)==8){a[9754712]=c&1;return}else{return}}function dpa(b){b=b|0;var c=0,d=0;c=b&65535;if((c|0)==49216){d=a[14116097]|0}else if((c|0)==49280){d=a[14116096]|0}else if((c|0)==49152){d=a[14116098]|0}else{d=0}return d|0}function dpb(b){b=b|0;var c=0,d=0;c=b&65535;if((c|0)==49280){d=a[14116097]|0}else if((c|0)==49216){d=a[14116096]|0}else if((c|0)==49344){d=a[14116098]|0}else{d=0}return d|0}function dpc(b){b=b|0;var c=0,d=0;c=b&65535;if((c|0)==32832){d=a[14116097]|0}else if((c|0)==32896){d=a[14116096]|0}else if((c|0)==32768){d=a[14116098]|0}else{d=0}return d|0}function dpd(b){b=b|0;var c=0,d=0;c=b&65535;if((c|0)==62465){d=a[14116097]|0}else if((c|0)==62464){d=a[14116096]|0}else if((c|0)==62466){d=a[14116098]|0}else{d=0}return d|0}function dpe(b){b=b|0;var c=0,d=0;c=b&65535;if((c|0)==63489){d=a[14116097]|0}else if((c|0)==63490){d=a[14116098]|0}else if((c|0)==63488){d=a[14116096]|0}else{d=0}return d|0}function dpf(a,b){a=a|0;b=b|0;return}function dpg(b){b=b|0;var d=0,e=0;if((b&255)!=2){d=0;return d|0}b=c[3542228]|0;if((b|0)>15){d=0;return d|0}do{if((b|0)==15){e=c[3542225]|0;if((e|0)==0){break}a[14168931]=gj[e&4095](0)|0}else if((b|0)==14){e=c[3542224]|0;if((e|0)==0){break}a[14168930]=gj[e&4095](0)|0}}while(0);d=a[14168916+b|0]|0;return d|0}function dph(b){b=b|0;var d=0,e=0;if((b&255)!=66){d=0;return d|0}b=c[3542228]|0;if((b|0)>15){d=0;return d|0}do{if((b|0)==15){e=c[3542225]|0;if((e|0)==0){break}a[14168931]=gj[e&4095](0)|0}else if((b|0)==14){e=c[3542224]|0;if((e|0)==0){break}a[14168930]=gj[e&4095](0)|0}}while(0);d=a[14168916+b|0]|0;return d|0}function dpi(b){b=b|0;var d=0,e=0;if((b&255)!=130){d=0;return d|0}b=c[3542228]|0;if((b|0)>15){d=0;return d|0}do{if((b|0)==15){e=c[3542225]|0;if((e|0)==0){break}a[14168931]=gj[e&4095](0)|0}else if((b|0)==14){e=c[3542224]|0;if((e|0)==0){break}a[14168930]=gj[e&4095](0)|0}}while(0);d=a[14168916+b|0]|0;return d|0}function dpj(b,d){b=b|0;d=d|0;var e=0,f=0;e=b&255;if((e|0)==64){c[3542291]=d&15;return}else if((e|0)==1){b=d&255;f=c[3542228]|0;if((f|0)>15){return}do{if((f|0)<14){if((f|0)!=13){if((a[14168916+f|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(0,f,b);return}else if((e|0)==65){b=d&255;f=c[3542291]|0;if((f|0)>15){return}do{if((f|0)<14){if((f|0)!=13){if((a[14169168+f|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(1,f,b);return}else if((e|0)==0){c[3542228]=d&15;return}else{return}}function dpk(b,d){b=b|0;d=d|0;var e=0,f=0;e=b&255;if((e|0)==65){b=d&255;f=c[3542228]|0;if((f|0)>15){return}do{if((f|0)<14){if((f|0)!=13){if((a[14168916+f|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(0,f,b);return}else if((e|0)==129){b=d&255;f=c[3542291]|0;if((f|0)>15){return}do{if((f|0)<14){if((f|0)!=13){if((a[14169168+f|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(1,f,b);return}else if((e|0)==128){c[3542291]=d&15;return}else if((e|0)==64){c[3542228]=d&15;return}else{return}}function dpl(b,d){b=b|0;d=d|0;var e=0,f=0;e=b&255;if((e|0)==193){b=d&255;f=c[3542291]|0;if((f|0)>15){return}do{if((f|0)<14){if((f|0)!=13){if((a[14169168+f|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(1,f,b);return}else if((e|0)==0){c[3542228]=d&15;return}else if((e|0)==192){c[3542291]=d&15;return}else if((e|0)==1){e=d&255;b=c[3542228]|0;if((b|0)>15){return}do{if((b|0)<14){if((b|0)!=13){if((a[14168916+b|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(0,b,e);return}else{return}}function dpm(b,d){b=b|0;d=d|0;var e=0,f=0;e=b&255;if((e|0)==129){b=d&255;f=c[3542228]|0;if((f|0)>15){return}do{if((f|0)<14){if((f|0)!=13){if((a[14168916+f|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(0,f,b);return}else if((e|0)==132){c[3542291]=d&15;return}else if((e|0)==133){b=d&255;f=c[3542291]|0;if((f|0)>15){return}do{if((f|0)<14){if((f|0)!=13){if((a[14169168+f|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(1,f,b);return}else if((e|0)==128){c[3542228]=d&15;return}else{return}}function dpn(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5616892+(b*112|0)>>2];c[a+104>>2]=c[5616896+(b*112|0)>>2];c[a+108>>2]=c[5616900+(b*112|0)>>2];d=0;return d|0}function dpo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=5616792+(b*112|0);e=0;return e|0}function dpp(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5313800+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dpq(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>42){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5618584+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dpr(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0.0,as=0,at=0,au=0,av=0;e=i;i=i+1320|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;B=e+1200|0;C=e+1312|0;c[2437660]=4;c[2437658]=4;c[2431678]=6;c[2433408]=8192;c[2433406]=8192;c[2430130]=16384;D=c[c[642608+(c[2436]<<2)>>2]>>2]|0;if((fa(D|0,355592)|0)==0){E=74088}else{if((fa(D|0,248832)|0)==0){E=74088}}if((E|0)==74088){c[2437660]=1;c[2437658]=1;c[2431678]=3;c[2433408]=32768;c[2433406]=32768;c[2430130]=32768}do{if((fa(D|0,450944)|0)==0){E=74092}else{if((fa(D|0,405272)|0)==0){E=74092;break}if((fa(D|0,372952)|0)==0){E=74092}}}while(0);if((E|0)==74092){c[2437658]=1}if((fa(D|0,356256)|0)==0){c[2437660]=2;c[2437658]=4;c[2433408]=16384;c[2433406]=8192}do{if((fa(D|0,323584)|0)==0){E=74100}else{if((fa(D|0,314848)|0)==0){E=74100;break}if((fa(D|0,284336)|0)==0){E=74100;break}if((fa(D|0,263024)|0)==0){E=74100;break}if((fa(D|0,246624)|0)==0){E=74100}}}while(0);if((E|0)==74100){c[2437660]=3}do{if((fa(D|0,125456)|0)==0){E=74104}else{if((fa(D|0,233376)|0)==0){E=74104;break}if((fa(D|0,217432)|0)==0){E=74104}}}while(0);if((E|0)==74104){c[2437660]=2;c[2437658]=2;c[2433408]=16384;c[2433406]=16384}if((fa(D|0,584728)|0)==0){c[2437660]=1;c[2437658]=2;c[2433408]=32768;c[2433406]=16384}if((fa(D|0,209984)|0)==0){c[2437660]=1;c[2437658]=1;c[2431678]=3;c[2433408]=32768;c[2433406]=32768;c[2430130]=32768}c[2426790]=0;c[2443304]=0;c[2443302]=32768;c[2443312]=65536;c[2438676]=65792;c[2439466]=66048;c[2429726]=66304;c[2405698]=66336;c[2431676]=66336;c[2443306]=68384;c[2437656]=70432;c[2437654]=72480;c[2437670]=74528;c[2437672]=76576;c[2438682]=78624;c[2411784]=80672;c[3529026]=80672;c[3529020]=97056;c[2443310]=162592;c[2385400]=424736;D=a[9688]|0?6408:0;c[2443314]=D+424736;F=D+425760|0;c[2414332]=F;D=F;F=0;while(1){if((F|0)>=1024){break}G=9638528+(F<<2)|0;if((c[G>>2]|0)==0){E=74112;break}else{F=F+1|0}}do{if((E|0)==74112){F=gGq(D)|0;c[G>>2]=F;if((F|0)==0){break}gGz(F|0,0,D|0);c[2426790]=F;gGz(F|0,0,D|0);c[2443304]=F;c[2443302]=F+32768;c[2443312]=F+65536;c[2438676]=F+65792;c[2439466]=F+66048;c[2429726]=F+66304;H=F+66336|0;c[2405698]=H;c[2431676]=H;c[2443306]=F+68384;c[2437656]=F+70432;c[2437654]=F+72480;c[2437670]=F+74528;c[2437672]=F+76576;c[2438682]=F+78624;H=F+80672|0;c[2411784]=H;c[3529026]=H;c[3529020]=F+97056;c[2443310]=F+162592;c[2385400]=F+424736;H=a[9688]|0?6408:0;c[2443314]=F+(H+424736);c[2414332]=F+(H+425760);H=0;while(1){if((H|0)>=1024){I=0;break}J=9638528+(H<<2)|0;if((c[J>>2]|0)==0){E=74117;break}else{H=H+1|0}}do{if((E|0)==74117){H=gGq(98304)|0;c[J>>2]=H;if((H|0)==0){I=0;break}gGz(H|0,0,98304);I=H}}while(0);c[2443308]=I;H=c[2437660]|0;L89792:do{if((H|0)>0){F=B+108|0;K=B+100|0;L=0;while(1){M=c[2443304]|0;N=M+(ag(c[2433408]|0,L)|0)|0;if((c[3542200]|0)==0){O=1;E=74390;break}c[F>>2]=0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](B,L)|0;if((c[F>>2]|0)!=0){M=c[K>>2]|0;c[C>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](C,L,0)|0;if((M|0)<1){O=1;E=74387;break}if((gzL(N,0,L)|0)!=0){O=1;E=74389;break}}N=L+1|0;M=c[2437660]|0;if((N|0)<(M|0)){L=N}else{Q=M;break L89792}}if((E|0)==74387){i=e;return O|0}else if((E|0)==74389){i=e;return O|0}else if((E|0)==74390){i=e;return O|0}}else{Q=H}}while(0);H=c[2437658]|0;L89806:do{if((H|0)>0){L=z+108|0;K=z+100|0;F=Q;M=Q;while(1){N=c[2443302]|0;P=N+(ag(c[2433406]|0,M-F|0)|0)|0;if((c[3542200]|0)==0){O=1;E=74383;break}c[L>>2]=0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,M)|0;if((c[L>>2]|0)!=0){N=c[K>>2]|0;c[A>>2]=9534384;R=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[R&16383](A,M,0)|0;if((N|0)<1){O=1;E=74386;break}if((gzL(P,0,M)|0)!=0){O=1;E=74384;break}}P=M+1|0;N=c[2437660]|0;R=(c[2437658]|0)+N|0;if((P|0)<(R|0)){F=N;M=P}else{S=R;break L89806}}if((E|0)==74383){i=e;return O|0}else if((E|0)==74384){i=e;return O|0}else if((E|0)==74386){i=e;return O|0}}else{S=H+Q|0}}while(0);H=c[2443308]|0;if((c[3542200]|0)==0){O=1;i=e;return O|0}M=x+108|0;c[M>>2]=0;F=x+100|0;c[F>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,S)|0;do{if((c[M>>2]|0)!=0){K=c[F>>2]|0;c[y>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](y,S,0)|0;if((K|0)<1){O=1;i=e;return O|0}if((gzL(H,0,S)|0)==0){break}else{O=1}i=e;return O|0}}while(0);H=c[2443308]|0;F=c[3529026]|0;M=0;do{K=M<<6;gGz(F+K|0,0,64);L=M<<7;R=0;do{P=L+(c[1238464+(R<<2)>>2]|0)|0;N=(R<<3)+K|0;T=0;do{U=P+(c[612768+(T<<2)>>2]|0)|0;if(((d[H+((U|0)/8|0)|0]|0)&128>>>((U&7)>>>0)|0)!=0){U=F+(N+T)|0;a[U]=a[U]|2}T=T+1|0;}while((T|0)<8);R=R+1|0;}while((R|0)<8);R=L|4;T=0;do{N=R+(c[1238464+(T<<2)>>2]|0)|0;P=(T<<3)+K|0;U=0;do{V=N+(c[612768+(U<<2)>>2]|0)|0;if(((d[H+((V|0)/8|0)|0]|0)&128>>>((V&7)>>>0)|0)!=0){V=F+(P+U)|0;a[V]=a[V]|1}U=U+1|0;}while((U|0)<8);T=T+1|0;}while((T|0)<8);M=M+1|0;}while((M|0)<256);gGz(H|0,0,98304);M=(c[2437658]|0)+1+(c[2437660]|0)|0;if((c[3542200]|0)==0){O=1;i=e;return O|0}F=v+108|0;c[F>>2]=0;T=v+100|0;c[T>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,M)|0;do{if((c[F>>2]|0)!=0){K=c[T>>2]|0;c[w>>2]=9534384;R=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[R&16383](w,M,0)|0;if((K|0)<1){O=1;i=e;return O|0}if((gzL(H,0,M)|0)==0){break}else{O=1}i=e;return O|0}}while(0);M=(c[2443308]|0)+8192|0;H=(c[2437658]|0)+2+(c[2437660]|0)|0;if((c[3542200]|0)==0){O=1;i=e;return O|0}T=t+108|0;c[T>>2]=0;F=t+100|0;c[F>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,H)|0;do{if((c[T>>2]|0)!=0){K=c[F>>2]|0;c[u>>2]=9534384;R=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[R&16383](u,H,0)|0;if((K|0)<1){O=1;i=e;return O|0}if((gzL(M,0,H)|0)==0){break}else{O=1}i=e;return O|0}}while(0);H=(c[2443308]|0)+16384|0;M=(c[2437658]|0)+3+(c[2437660]|0)|0;if((c[3542200]|0)==0){O=1;i=e;return O|0}F=r+108|0;c[F>>2]=0;T=r+100|0;c[T>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,M)|0;do{if((c[F>>2]|0)!=0){K=c[T>>2]|0;c[s>>2]=9534384;R=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[R&16383](s,M,0)|0;if((K|0)<1){O=1;i=e;return O|0}if((gzL(H,0,M)|0)==0){break}else{O=1}i=e;return O|0}}while(0);M=c[2443308]|0;H=c[3529020]|0;T=0;do{F=T<<6;gGz(H+F|0,0,64);K=0;do{R=F+(c[1238464+(K<<2)>>2]|0)|0;L=(K<<3)+F|0;U=0;do{P=R+(c[614800+(U<<2)>>2]|0)|0;if(((d[M+((P|0)/8|0)|0]|0)&128>>>((P&7)>>>0)|0)!=0){P=H+(L+U)|0;a[P]=a[P]|4}U=U+1|0;}while((U|0)<8);K=K+1|0;}while((K|0)<8);K=F+65536|0;U=0;do{L=K+(c[1238464+(U<<2)>>2]|0)|0;R=(U<<3)+F|0;P=0;do{N=L+(c[614800+(P<<2)>>2]|0)|0;if(((d[M+((N|0)/8|0)|0]|0)&128>>>((N&7)>>>0)|0)!=0){N=H+(R+P)|0;a[N]=a[N]|2}P=P+1|0;}while((P|0)<8);U=U+1|0;}while((U|0)<8);U=F+131072|0;K=0;do{P=U+(c[1238464+(K<<2)>>2]|0)|0;R=(K<<3)+F|0;L=0;do{N=P+(c[614800+(L<<2)>>2]|0)|0;if(((d[M+((N|0)/8|0)|0]|0)&128>>>((N&7)>>>0)|0)!=0){N=H+(R+L)|0;a[N]=a[N]|1}L=L+1|0;}while((L|0)<8);K=K+1|0;}while((K|0)<8);T=T+1|0;}while((T|0)<1024);gGz(M|0,0,98304);T=c[2437658]|0;H=c[2437660]|0;K=T+4+H|0;L89912:do{if((K|0)<(H+4+T+(c[2431678]|0)|0)){F=p+108|0;U=p+100|0;L=H;R=T;P=K;N=M;while(1){V=N+(ag(c[2430130]|0,-4-L-R+P|0)|0)|0;if((c[3542200]|0)==0){O=1;E=74392;break}c[F>>2]=0;c[U>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,P)|0;if((c[F>>2]|0)!=0){W=c[U>>2]|0;c[q>>2]=9534384;X=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[X&16383](q,P,0)|0;if((W|0)<1){O=1;E=74403;break}if((gzL(V,0,P)|0)!=0){O=1;E=74379;break}}V=P+1|0;W=c[2437658]|0;X=c[2437660]|0;if((V|0)>=(X+4+W+(c[2431678]|0)|0)){break L89912}L=X;R=W;P=V;N=c[2443308]|0}if((E|0)==74379){i=e;return O|0}else if((E|0)==74392){i=e;return O|0}else if((E|0)==74403){i=e;return O|0}}}while(0);M=c[c[642608+(c[2436]<<2)>>2]>>2]|0;if((fa(M|0,355592)|0)==0){Y=0;E=74176}else{if((fa(M|0,248832)|0)==0){Y=0;E=74176}}L89929:do{if((E|0)==74176){while(1){E=0;if((Y|0)>=1024){Z=0;break}_=9638528+(Y<<2)|0;if((c[_>>2]|0)==0){E=74178;break}else{Y=Y+1|0;E=74176}}do{if((E|0)==74178){M=gGq(98304)|0;c[_>>2]=M;if((M|0)==0){Z=0;break}gGz(M|0,0,98304);Z=M}}while(0);M=c[2443308]|0;gGC(Z|0,M|0,98304)|0;K=M+16384|0;T=Z+8192|0;gGC(K|0,T|0,8192)|0;T=M+8192|0;K=Z+16384|0;gGC(T|0,K|0,8192)|0;K=M+24576|0;T=Z+24576|0;gGC(K|0,T|0,8192)|0;T=M+32768|0;K=Z+32768|0;gGC(T|0,K|0,8192)|0;K=M+49152|0;T=Z+40960|0;gGC(K|0,T|0,8192)|0;T=M+40960|0;K=Z+49152|0;gGC(T|0,K|0,8192)|0;K=M+57344|0;T=Z+57344|0;gGC(K|0,T|0,8192)|0;T=M+65536|0;K=Z+65536|0;gGC(T|0,K|0,8192)|0;K=M+81920|0;T=Z+73728|0;gGC(K|0,T|0,8192)|0;T=M+73728|0;K=Z+81920|0;gGC(T|0,K|0,8192)|0;K=M+90112|0;M=Z+90112|0;gGC(K|0,M|0,8192)|0;M=0;while(1){if((M|0)>=1024){break L89929}$=9638528+(M<<2)|0;if((c[$>>2]|0)==(Z|0)){break}else{M=M+1|0}}gGr(Z);c[$>>2]=0}}while(0);M=c[2443308]|0;K=c[2443310]|0;T=0;do{H=T<<8;gGz(K+H|0,0,256);N=0;do{P=H+(c[611776+(N<<2)>>2]|0)|0;R=(N<<4)+H|0;L=0;do{U=P+(c[601400+(L<<2)>>2]|0)|0;if(((d[M+((U|0)/8|0)|0]|0)&128>>>((U&7)>>>0)|0)!=0){U=K+(R+L)|0;a[U]=a[U]|4}L=L+1|0;}while((L|0)<16);N=N+1|0;}while((N|0)<16);N=H+262144|0;L=0;do{R=N+(c[611776+(L<<2)>>2]|0)|0;P=(L<<4)+H|0;U=0;do{F=R+(c[601400+(U<<2)>>2]|0)|0;if(((d[M+((F|0)/8|0)|0]|0)&128>>>((F&7)>>>0)|0)!=0){F=K+(P+U)|0;a[F]=a[F]|2}U=U+1|0;}while((U|0)<16);L=L+1|0;}while((L|0)<16);L=H+524288|0;N=0;do{U=L+(c[611776+(N<<2)>>2]|0)|0;P=(N<<4)+H|0;R=0;do{F=U+(c[601400+(R<<2)>>2]|0)|0;if(((d[M+((F|0)/8|0)|0]|0)&128>>>((F&7)>>>0)|0)!=0){F=K+(P+R)|0;a[F]=a[F]|1}R=R+1|0;}while((R|0)<16);N=N+1|0;}while((N|0)<16);T=T+1|0;}while((T|0)<1024);T=c[2443312]|0;K=(c[2431678]|0)+4+(c[2437658]|0)+(c[2437660]|0)|0;if((c[3542200]|0)==0){O=1;i=e;return O|0}M=n+108|0;c[M>>2]=0;N=n+100|0;c[N>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,K)|0;do{if((c[M>>2]|0)!=0){H=c[N>>2]|0;c[o>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](o,K,0)|0;if((H|0)<1){O=1;i=e;return O|0}if((gzL(T,0,K)|0)==0){break}else{O=1}i=e;return O|0}}while(0);K=c[2438676]|0;T=(c[2431678]|0)+5+(c[2437658]|0)+(c[2437660]|0)|0;if((c[3542200]|0)==0){O=1;i=e;return O|0}N=l+108|0;c[N>>2]=0;M=l+100|0;c[M>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,T)|0;do{if((c[N>>2]|0)!=0){H=c[M>>2]|0;c[m>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](m,T,0)|0;if((H|0)<1){O=1;i=e;return O|0}if((gzL(K,0,T)|0)==0){break}else{O=1}i=e;return O|0}}while(0);T=c[2439466]|0;K=(c[2431678]|0)+6+(c[2437658]|0)+(c[2437660]|0)|0;if((c[3542200]|0)==0){O=1;i=e;return O|0}M=j+108|0;c[M>>2]=0;N=j+100|0;c[N>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,K)|0;do{if((c[M>>2]|0)!=0){H=c[N>>2]|0;c[k>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](k,K,0)|0;if((H|0)<1){O=1;i=e;return O|0}if((gzL(T,0,K)|0)==0){break}else{O=1}i=e;return O|0}}while(0);K=c[642608+(c[2436]<<2)>>2]|0;T=c[K>>2]|0;do{if((fa(T|0,524272)|0)==0){E=74213}else{if((fa(T|0,473320)|0)==0){E=74213;break}if((fa(T|0,450944)|0)==0){E=74213;break}if((fa(T|0,405272)|0)==0){E=74213;break}if((fa(T|0,372952)|0)==0){E=74213;break}if((fa(T|0,356256)|0)==0){E=74213;break}if((fa(T|0,233376)|0)==0){E=74213;break}if((fa(T|0,217432)|0)==0){E=74213;break}if((fa(T|0,209984)|0)==0){E=74213}}}while(0);do{if((E|0)==74213){T=c[2429726]|0;N=(c[2431678]|0)+7+(c[2437658]|0)+(c[2437660]|0)|0;if((c[3542200]|0)==0){O=1;i=e;return O|0}M=f+108|0;c[M>>2]=0;H=f+100|0;c[H>>2]=0;L=c[K+76>>2]|0;gA[L&16383](f,N)|0;if((c[M>>2]|0)==0){break}M=c[H>>2]|0;c[g>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](g,N,0)|0;if((M|0)<1){O=1;i=e;return O|0}if((gzL(T,0,N)|0)==0){break}else{O=1}i=e;return O|0}}while(0);K=c[2443308]|0;N=0;while(1){if((N|0)>=1024){break}aa=9638528+(N<<2)|0;if((c[aa>>2]|0)==(K|0)){E=74220;break}else{N=N+1|0}}if((E|0)==74220){gGr(K);c[aa>>2]=0}c[2443308]=0;fwR(0);N=c[2439330]|0;T=(N|0)==0;if(!T){M=N;gGC(9706056,M|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];M=c[3528484]|0;c[2076596]=M;H=c[2417276]|0;c[3541536]=H;c[1836236]=0;c[N+4180>>2]=1262;c[N+4184>>2]=1880;L=c[2443304]|0;R=0;P=0;while(1){c[N+76+(P<<2)>>2]=L+(P<<8);U=R+1&65535;if((U&65535)>127){ab=0;ac=0;break}else{R=U;P=U&65535}}while(1){P=L+(ac<<8)|0;c[N+76+(ac+512<<2)>>2]=P;c[N+76+(ac+768<<2)>>2]=P;P=ab+1&65535;if((P&65535)>127){break}else{ab=P;ac=P&65535}}L=c[2437672]|0;c[N+588>>2]=L;P=L+256|0;c[N+592>>2]=P;R=L+512|0;c[N+596>>2]=R;K=L+768|0;c[N+600>>2]=K;U=L+1024|0;c[N+604>>2]=U;F=L+1280|0;c[N+608>>2]=F;V=L+1536|0;c[N+612>>2]=V;W=L+1792|0;c[N+616>>2]=W;c[N+1612>>2]=L;c[N+1616>>2]=P;c[N+1620>>2]=R;c[N+1624>>2]=K;c[N+1628>>2]=U;c[N+1632>>2]=F;c[N+1636>>2]=V;c[N+1640>>2]=W;c[N+2636>>2]=L;c[N+3660>>2]=L;c[N+2640>>2]=P;c[N+3664>>2]=P;c[N+2644>>2]=R;c[N+3668>>2]=R;c[N+2648>>2]=K;c[N+3672>>2]=K;c[N+2652>>2]=U;c[N+3676>>2]=U;c[N+2656>>2]=F;c[N+3680>>2]=F;c[N+2660>>2]=V;c[N+3684>>2]=V;c[N+2664>>2]=W;c[N+3688>>2]=W;W=c[2438682]|0;c[N+620>>2]=W;V=W+256|0;c[N+624>>2]=V;F=W+512|0;c[N+628>>2]=F;U=W+768|0;c[N+632>>2]=U;K=W+1024|0;c[N+636>>2]=K;R=W+1280|0;c[N+640>>2]=R;P=W+1536|0;c[N+644>>2]=P;L=W+1792|0;c[N+648>>2]=L;c[N+1644>>2]=W;c[N+1648>>2]=V;c[N+1652>>2]=F;c[N+1656>>2]=U;c[N+1660>>2]=K;c[N+1664>>2]=R;c[N+1668>>2]=P;c[N+1672>>2]=L;c[N+2668>>2]=W;c[N+3692>>2]=W;c[N+2672>>2]=V;c[N+3696>>2]=V;c[N+2676>>2]=F;c[N+3700>>2]=F;c[N+2680>>2]=U;c[N+3704>>2]=U;c[N+2684>>2]=K;c[N+3708>>2]=K;c[N+2688>>2]=R;c[N+3712>>2]=R;c[N+2692>>2]=P;c[N+3716>>2]=P;c[N+2696>>2]=L;c[N+3720>>2]=L;L=c[2437670]|0;c[N+652>>2]=L;P=L+256|0;c[N+656>>2]=P;R=L+512|0;c[N+660>>2]=R;K=L+768|0;c[N+664>>2]=K;U=L+1024|0;c[N+668>>2]=U;F=L+1280|0;c[N+672>>2]=F;V=L+1536|0;c[N+676>>2]=V;W=L+1792|0;c[N+680>>2]=W;c[N+1676>>2]=L;c[N+1680>>2]=P;c[N+1684>>2]=R;c[N+1688>>2]=K;c[N+1692>>2]=U;c[N+1696>>2]=F;c[N+1700>>2]=V;c[N+1704>>2]=W;c[N+2700>>2]=L;c[N+3724>>2]=L;c[N+2704>>2]=P;c[N+3728>>2]=P;c[N+2708>>2]=R;c[N+3732>>2]=R;c[N+2712>>2]=K;c[N+3736>>2]=K;c[N+2716>>2]=U;c[N+3740>>2]=U;c[N+2720>>2]=F;c[N+3744>>2]=F;c[N+2724>>2]=V;c[N+3748>>2]=V;c[N+2728>>2]=W;c[N+3752>>2]=W;W=c[2437654]|0;c[N+1708>>2]=W;V=W+256|0;c[N+1712>>2]=V;F=W+512|0;c[N+1716>>2]=F;U=W+768|0;c[N+1720>>2]=U;K=W+1024|0;c[N+1724>>2]=K;R=W+1280|0;c[N+1728>>2]=R;P=W+1536|0;c[N+1732>>2]=P;L=W+1792|0;c[N+1736>>2]=L;c[N+2732>>2]=W;c[N+3756>>2]=W;c[N+2736>>2]=V;c[N+3760>>2]=V;c[N+2740>>2]=F;c[N+3764>>2]=F;c[N+2744>>2]=U;c[N+3768>>2]=U;c[N+2748>>2]=K;c[N+3772>>2]=K;c[N+2752>>2]=R;c[N+3776>>2]=R;c[N+2756>>2]=P;c[N+3780>>2]=P;c[N+2760>>2]=L;c[N+3784>>2]=L;L=c[2437656]|0;c[N+716>>2]=L;P=L+256|0;c[N+720>>2]=P;R=L+512|0;c[N+724>>2]=R;K=L+768|0;c[N+728>>2]=K;U=L+1024|0;c[N+732>>2]=U;F=L+1280|0;c[N+736>>2]=F;V=L+1536|0;c[N+740>>2]=V;W=L+1792|0;c[N+744>>2]=W;c[N+1740>>2]=L;c[N+1744>>2]=P;c[N+1748>>2]=R;c[N+1752>>2]=K;c[N+1756>>2]=U;c[N+1760>>2]=F;c[N+1764>>2]=V;c[N+1768>>2]=W;c[N+2764>>2]=L;c[N+3788>>2]=L;c[N+2768>>2]=P;c[N+3792>>2]=P;c[N+2772>>2]=R;c[N+3796>>2]=R;c[N+2776>>2]=K;c[N+3800>>2]=K;c[N+2780>>2]=U;c[N+3804>>2]=U;c[N+2784>>2]=F;c[N+3808>>2]=F;c[N+2788>>2]=V;c[N+3812>>2]=V;c[N+2792>>2]=W;c[N+3816>>2]=W;W=c[2431676]|0;c[N+1036>>2]=W;V=W+256|0;c[N+1040>>2]=V;F=W+512|0;c[N+1044>>2]=F;U=W+768|0;c[N+1048>>2]=U;K=W+1024|0;c[N+1052>>2]=K;R=W+1280|0;c[N+1056>>2]=R;P=W+1536|0;c[N+1060>>2]=P;L=W+1792|0;c[N+1064>>2]=L;c[N+2060>>2]=W;c[N+2064>>2]=V;c[N+2068>>2]=F;c[N+2072>>2]=U;c[N+2076>>2]=K;c[N+2080>>2]=R;c[N+2084>>2]=P;c[N+2088>>2]=L;c[N+3084>>2]=W;c[N+4108>>2]=W;c[N+3088>>2]=V;c[N+4112>>2]=V;c[N+3092>>2]=F;c[N+4116>>2]=F;c[N+3096>>2]=U;c[N+4120>>2]=U;c[N+3100>>2]=K;c[N+4124>>2]=K;c[N+3104>>2]=R;c[N+4128>>2]=R;c[N+3108>>2]=P;c[N+4132>>2]=P;c[N+3112>>2]=L;c[N+4136>>2]=L;if(!T){L=N;gGC(L|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=M;c[2417276]=H;c[1836236]=-1;fwR(1);L=c[2439331]|0;P=(L|0)==0;if(!P){R=L;gGC(9706056,R|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];R=c[3528485]|0;c[2076596]=R;K=c[2417277]|0;c[3541536]=K;c[1836236]=1;c[L+4184>>2]=104;U=L+4172|0;c[U>>2]=3350;F=c[642608+(c[2436]<<2)>>2]|0;V=c[F>>2]|0;do{if((fa(V|0,450944)|0)==0){E=74233}else{if((fa(V|0,405272)|0)==0){E=74233;break}if((fa(V|0,372952)|0)==0){E=74233;break}W=c[2443302]|0;X=0;ad=0;while(1){c[L+76+(ad<<2)>>2]=W+(ad<<8);ae=X+1&65535;if((ae&65535)>127){af=0;ah=0;break}else{X=ae;ad=ae&65535}}while(1){ad=W+(ah<<8)|0;c[L+76+(ah+512<<2)>>2]=ad;c[L+76+(ah+768<<2)>>2]=ad;ad=af+1&65535;if((ad&65535)>127){break}else{af=ad;ah=ad&65535}}}}while(0);if((E|0)==74233){V=c[2443302]|0;H=0;M=0;while(1){c[L+76+(M<<2)>>2]=V+(M<<8);N=H+1&65535;if((N&65535)>31){ai=0;aj=0;break}else{H=N;M=N&65535}}while(1){M=V+(aj<<8)|0;c[L+76+(aj+512<<2)>>2]=M;c[L+76+(aj+768<<2)>>2]=M;M=ai+1&65535;if((M&65535)>31){break}else{ai=M;aj=M&65535}}}if(!P){V=L;gGC(V|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=R;c[2417277]=K;c[1836236]=-1;V=c[F>>2]|0;do{if((fa(V|0,355592)|0)==0){E=74245}else{if((fa(V|0,248832)|0)==0){E=74245;break}if((fa(V|0,125456)|0)==0){E=74245;break}if((fa(V|0,584728)|0)==0){E=74245}else{ak=V}}}while(0);if((E|0)==74245){V=c[2439330]|0;K=(V|0)==0;if(!K){R=V;gGC(9706056,R|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];R=c[3528484]|0;c[2076596]=R;M=c[2417276]|0;c[3541536]=M;c[1836236]=0;c[V+4176>>2]=720;H=c[2431676]|0;c[V+972>>2]=H;N=H+256|0;c[V+976>>2]=N;T=H+512|0;c[V+980>>2]=T;W=H+768|0;c[V+984>>2]=W;ad=H+1024|0;c[V+988>>2]=ad;X=H+1280|0;c[V+992>>2]=X;ae=H+1536|0;c[V+996>>2]=ae;al=H+1792|0;c[V+1e3>>2]=al;c[V+1996>>2]=H;c[V+2e3>>2]=N;c[V+2004>>2]=T;c[V+2008>>2]=W;c[V+2012>>2]=ad;c[V+2016>>2]=X;c[V+2020>>2]=ae;c[V+2024>>2]=al;c[V+3020>>2]=H;c[V+4044>>2]=H;c[V+3024>>2]=N;c[V+4048>>2]=N;c[V+3028>>2]=T;c[V+4052>>2]=T;c[V+3032>>2]=W;c[V+4056>>2]=W;c[V+3036>>2]=ad;c[V+4060>>2]=ad;c[V+3040>>2]=X;c[V+4064>>2]=X;c[V+3044>>2]=ae;c[V+4068>>2]=ae;c[V+3048>>2]=al;c[V+4072>>2]=al;if(!K){K=V;gGC(K|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=R;c[2417276]=M;c[1836236]=-1;if(!P){M=L;gGC(9706056,M|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];M=c[3528485]|0;c[2076596]=M;R=c[2417277]|0;c[3541536]=R;c[1836236]=1;c[L+4180>>2]=2502;c[U>>2]=852;c[L+4176>>2]=3216;c[L+588>>2]=H;c[L+592>>2]=N;c[L+596>>2]=T;c[L+600>>2]=W;c[L+604>>2]=ad;c[L+608>>2]=X;c[L+612>>2]=ae;c[L+616>>2]=al;c[L+1612>>2]=H;c[L+1616>>2]=N;c[L+1620>>2]=T;c[L+1624>>2]=W;c[L+1628>>2]=ad;c[L+1632>>2]=X;c[L+1636>>2]=ae;c[L+1640>>2]=al;c[L+2636>>2]=H;c[L+3660>>2]=H;c[L+2640>>2]=N;c[L+3664>>2]=N;c[L+2644>>2]=T;c[L+3668>>2]=T;c[L+2648>>2]=W;c[L+3672>>2]=W;c[L+2652>>2]=ad;c[L+3676>>2]=ad;c[L+2656>>2]=X;c[L+3680>>2]=X;c[L+2660>>2]=ae;c[L+3684>>2]=ae;c[L+2664>>2]=al;c[L+3688>>2]=al;if(!P){al=L;gGC(al|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=M;c[2417277]=R;c[1836236]=-1;ak=c[F>>2]|0}if((fa(ak|0,524272)|0)==0){R=c[2439330]|0;M=(R|0)==0;if(!M){al=R;gGC(9706056,al|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];al=c[3528484]|0;c[2076596]=al;ae=c[2417276]|0;c[3541536]=ae;c[1836236]=0;c[R+4176>>2]=3154;if(!M){M=R;gGC(M|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=al;c[2417276]=ae;c[1836236]=-1;if(!P){ae=L;gGC(9706056,ae|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];ae=c[3528485]|0;c[2076596]=ae;al=c[2417277]|0;c[3541536]=al;c[1836236]=1;c[L+4180>>2]=1172;c[L+4176>>2]=388;M=c[2431676]|0;c[L+716>>2]=M;R=M+256|0;c[L+720>>2]=R;X=M+512|0;c[L+724>>2]=X;ad=M+768|0;c[L+728>>2]=ad;W=M+1024|0;c[L+732>>2]=W;T=M+1280|0;c[L+736>>2]=T;N=M+1536|0;c[L+740>>2]=N;H=M+1792|0;c[L+744>>2]=H;c[L+1740>>2]=M;c[L+1744>>2]=R;c[L+1748>>2]=X;c[L+1752>>2]=ad;c[L+1756>>2]=W;c[L+1760>>2]=T;c[L+1764>>2]=N;c[L+1768>>2]=H;c[L+2764>>2]=M;c[L+3788>>2]=M;c[L+2768>>2]=R;c[L+3792>>2]=R;c[L+2772>>2]=X;c[L+3796>>2]=X;c[L+2776>>2]=ad;c[L+3800>>2]=ad;c[L+2780>>2]=W;c[L+3804>>2]=W;c[L+2784>>2]=T;c[L+3808>>2]=T;c[L+2788>>2]=N;c[L+3812>>2]=N;c[L+2792>>2]=H;c[L+3816>>2]=H;if(!P){H=L;gGC(H|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=ae;c[2417277]=al;c[1836236]=-1;am=c[F>>2]|0}else{am=ak}if((fa(am|0,473320)|0)==0){al=c[2439330]|0;ae=(al|0)==0;if(!ae){H=al;gGC(9706056,H|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];H=c[3528484]|0;c[2076596]=H;N=c[2417276]|0;c[3541536]=N;c[1836236]=0;c[al+4176>>2]=422;if(!ae){ae=al;gGC(ae|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=H;c[2417276]=N;c[1836236]=-1;if(!P){N=L;gGC(9706056,N|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];N=c[3528485]|0;c[2076596]=N;H=c[2417277]|0;c[3541536]=H;c[1836236]=1;c[L+4180>>2]=1408;c[U>>2]=2928;c[L+4176>>2]=964;ae=c[2431676]|0;c[L+972>>2]=ae;al=ae+256|0;c[L+976>>2]=al;T=ae+512|0;c[L+980>>2]=T;W=ae+768|0;c[L+984>>2]=W;ad=ae+1024|0;c[L+988>>2]=ad;X=ae+1280|0;c[L+992>>2]=X;R=ae+1536|0;c[L+996>>2]=R;M=ae+1792|0;c[L+1e3>>2]=M;c[L+1996>>2]=ae;c[L+2e3>>2]=al;c[L+2004>>2]=T;c[L+2008>>2]=W;c[L+2012>>2]=ad;c[L+2016>>2]=X;c[L+2020>>2]=R;c[L+2024>>2]=M;c[L+3020>>2]=ae;c[L+4044>>2]=ae;c[L+3024>>2]=al;c[L+4048>>2]=al;c[L+3028>>2]=T;c[L+4052>>2]=T;c[L+3032>>2]=W;c[L+4056>>2]=W;c[L+3036>>2]=ad;c[L+4060>>2]=ad;c[L+3040>>2]=X;c[L+4064>>2]=X;c[L+3044>>2]=R;c[L+4068>>2]=R;c[L+3048>>2]=M;c[L+4072>>2]=M;if(!P){M=L;gGC(M|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=N;c[2417277]=H;c[1836236]=-1;an=c[F>>2]|0}else{an=am}do{if((fa(an|0,450944)|0)==0){E=74277}else{if((fa(an|0,405272)|0)==0){E=74277;break}if((fa(an|0,372952)|0)==0){E=74277}else{ao=an}}}while(0);if((E|0)==74277){H=c[2439330]|0;N=(H|0)==0;if(!N){M=H;gGC(9706056,M|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];M=c[3528484]|0;c[2076596]=M;R=c[2417276]|0;c[3541536]=R;c[1836236]=0;c[H+4176>>2]=1882;if(!N){N=H;gGC(N|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=M;c[2417276]=R;c[1836236]=-1;if(!P){R=L;gGC(9706056,R|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];R=c[3528485]|0;c[2076596]=R;M=c[2417277]|0;c[3541536]=M;c[1836236]=1;c[L+4180>>2]=3338;c[L+4176>>2]=204;N=c[2431676]|0;c[L+332>>2]=N;H=N+256|0;c[L+336>>2]=H;X=N+512|0;c[L+340>>2]=X;ad=N+768|0;c[L+344>>2]=ad;W=N+1024|0;c[L+348>>2]=W;T=N+1280|0;c[L+352>>2]=T;al=N+1536|0;c[L+356>>2]=al;ae=N+1792|0;c[L+360>>2]=ae;c[L+1356>>2]=N;c[L+1360>>2]=H;c[L+1364>>2]=X;c[L+1368>>2]=ad;c[L+1372>>2]=W;c[L+1376>>2]=T;c[L+1380>>2]=al;c[L+1384>>2]=ae;c[L+2380>>2]=N;c[L+3404>>2]=N;c[L+2384>>2]=H;c[L+3408>>2]=H;c[L+2388>>2]=X;c[L+3412>>2]=X;c[L+2392>>2]=ad;c[L+3416>>2]=ad;c[L+2396>>2]=W;c[L+3420>>2]=W;c[L+2400>>2]=T;c[L+3424>>2]=T;c[L+2404>>2]=al;c[L+3428>>2]=al;c[L+2408>>2]=ae;c[L+3432>>2]=ae;if(!P){ae=L;gGC(ae|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=R;c[2417277]=M;c[1836236]=-1;ao=c[F>>2]|0}if((fa(ao|0,356256)|0)==0){M=c[2439330]|0;R=(M|0)==0;if(!R){ae=M;gGC(9706056,ae|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];ae=c[3528484]|0;c[2076596]=ae;al=c[2417276]|0;c[3541536]=al;c[1836236]=0;c[M+4176>>2]=1882;if(!R){R=M;gGC(R|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=ae;c[2417276]=al;c[1836236]=-1;if(!P){al=L;gGC(9706056,al|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];al=c[3528485]|0;c[2076596]=al;ae=c[2417277]|0;c[3541536]=ae;c[1836236]=1;c[L+4180>>2]=1236;c[U>>2]=852;c[L+4176>>2]=3216;R=c[2431676]|0;c[L+844>>2]=R;M=R+256|0;c[L+848>>2]=M;T=R+512|0;c[L+852>>2]=T;W=R+768|0;c[L+856>>2]=W;ad=R+1024|0;c[L+860>>2]=ad;X=R+1280|0;c[L+864>>2]=X;H=R+1536|0;c[L+868>>2]=H;N=R+1792|0;c[L+872>>2]=N;c[L+1868>>2]=R;c[L+1872>>2]=M;c[L+1876>>2]=T;c[L+1880>>2]=W;c[L+1884>>2]=ad;c[L+1888>>2]=X;c[L+1892>>2]=H;c[L+1896>>2]=N;c[L+2892>>2]=R;c[L+3916>>2]=R;c[L+2896>>2]=M;c[L+3920>>2]=M;c[L+2900>>2]=T;c[L+3924>>2]=T;c[L+2904>>2]=W;c[L+3928>>2]=W;c[L+2908>>2]=ad;c[L+3932>>2]=ad;c[L+2912>>2]=X;c[L+3936>>2]=X;c[L+2916>>2]=H;c[L+3940>>2]=H;c[L+2920>>2]=N;c[L+3944>>2]=N;if(!P){N=L;gGC(N|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=al;c[2417277]=ae;c[1836236]=-1;ap=c[F>>2]|0}else{ap=ao}do{if((fa(ap|0,323584)|0)==0){E=74301}else{if((fa(ap|0,314848)|0)==0){E=74301;break}if((fa(ap|0,284336)|0)==0){E=74301;break}if((fa(ap|0,263024)|0)==0){E=74301;break}if((fa(ap|0,246624)|0)==0){E=74301}else{aq=ap}}}while(0);if((E|0)==74301){ae=c[2439330]|0;al=(ae|0)==0;if(!al){N=ae;gGC(9706056,N|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];N=c[3528484]|0;c[2076596]=N;H=c[2417276]|0;c[3541536]=H;c[1836236]=0;c[ae+4176>>2]=1882;if(!al){al=ae;gGC(al|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=N;c[2417276]=H;c[1836236]=-1;if(!P){H=L;gGC(9706056,H|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];H=c[3528485]|0;c[2076596]=H;N=c[2417277]|0;c[3541536]=N;c[1836236]=1;c[L+4180>>2]=1172;c[L+4176>>2]=388;al=c[2431676]|0;c[L+716>>2]=al;ae=al+256|0;c[L+720>>2]=ae;X=al+512|0;c[L+724>>2]=X;ad=al+768|0;c[L+728>>2]=ad;W=al+1024|0;c[L+732>>2]=W;T=al+1280|0;c[L+736>>2]=T;M=al+1536|0;c[L+740>>2]=M;R=al+1792|0;c[L+744>>2]=R;c[L+1740>>2]=al;c[L+1744>>2]=ae;c[L+1748>>2]=X;c[L+1752>>2]=ad;c[L+1756>>2]=W;c[L+1760>>2]=T;c[L+1764>>2]=M;c[L+1768>>2]=R;c[L+2764>>2]=al;c[L+3788>>2]=al;c[L+2768>>2]=ae;c[L+3792>>2]=ae;c[L+2772>>2]=X;c[L+3796>>2]=X;c[L+2776>>2]=ad;c[L+3800>>2]=ad;c[L+2780>>2]=W;c[L+3804>>2]=W;c[L+2784>>2]=T;c[L+3808>>2]=T;c[L+2788>>2]=M;c[L+3812>>2]=M;c[L+2792>>2]=R;c[L+3816>>2]=R;if(!P){R=L;gGC(R|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=H;c[2417277]=N;c[1836236]=-1;aq=c[F>>2]|0}do{if((fa(aq|0,233376)|0)==0){E=74313}else{if((fa(aq|0,217432)|0)==0){E=74313;break}if((fa(aq|0,209984)|0)==0){E=74313}}}while(0);if((E|0)==74313){F=c[2439330]|0;N=(F|0)==0;if(!N){H=F;gGC(9706056,H|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];H=c[3528484]|0;c[2076596]=H;R=c[2417276]|0;c[3541536]=R;c[1836236]=0;c[F+4176>>2]=720;M=c[2431676]|0;c[F+972>>2]=M;T=M+256|0;c[F+976>>2]=T;W=M+512|0;c[F+980>>2]=W;ad=M+768|0;c[F+984>>2]=ad;X=M+1024|0;c[F+988>>2]=X;ae=M+1280|0;c[F+992>>2]=ae;al=M+1536|0;c[F+996>>2]=al;K=M+1792|0;c[F+1e3>>2]=K;c[F+1996>>2]=M;c[F+2e3>>2]=T;c[F+2004>>2]=W;c[F+2008>>2]=ad;c[F+2012>>2]=X;c[F+2016>>2]=ae;c[F+2020>>2]=al;c[F+2024>>2]=K;c[F+3020>>2]=M;c[F+4044>>2]=M;c[F+3024>>2]=T;c[F+4048>>2]=T;c[F+3028>>2]=W;c[F+4052>>2]=W;c[F+3032>>2]=ad;c[F+4056>>2]=ad;c[F+3036>>2]=X;c[F+4060>>2]=X;c[F+3040>>2]=ae;c[F+4064>>2]=ae;c[F+3044>>2]=al;c[F+4068>>2]=al;c[F+3048>>2]=K;c[F+4072>>2]=K;if(!N){N=F;gGC(N|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=H;c[2417276]=R;c[1836236]=-1;if(!P){R=L;gGC(9706056,R|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];R=c[3528485]|0;c[2076596]=R;H=c[2417277]|0;c[3541536]=H;c[1836236]=1;c[L+4180>>2]=2502;c[U>>2]=852;c[L+4176>>2]=3216;c[L+588>>2]=M;c[L+592>>2]=T;c[L+596>>2]=W;c[L+600>>2]=ad;c[L+604>>2]=X;c[L+608>>2]=ae;c[L+612>>2]=al;c[L+616>>2]=K;c[L+1612>>2]=M;c[L+1616>>2]=T;c[L+1620>>2]=W;c[L+1624>>2]=ad;c[L+1628>>2]=X;c[L+1632>>2]=ae;c[L+1636>>2]=al;c[L+1640>>2]=K;c[L+2636>>2]=M;c[L+3660>>2]=M;c[L+2640>>2]=T;c[L+3664>>2]=T;c[L+2644>>2]=W;c[L+3668>>2]=W;c[L+2648>>2]=ad;c[L+3672>>2]=ad;c[L+2652>>2]=X;c[L+3676>>2]=X;c[L+2656>>2]=ae;c[L+3680>>2]=ae;c[L+2660>>2]=al;c[L+3684>>2]=al;c[L+2664>>2]=K;c[L+3688>>2]=K;K=c[2443306]|0;c[L+620>>2]=K;al=K+256|0;c[L+624>>2]=al;ae=K+512|0;c[L+628>>2]=ae;X=K+768|0;c[L+632>>2]=X;ad=K+1024|0;c[L+636>>2]=ad;W=K+1280|0;c[L+640>>2]=W;T=K+1536|0;c[L+644>>2]=T;M=K+1792|0;c[L+648>>2]=M;c[L+1644>>2]=K;c[L+1648>>2]=al;c[L+1652>>2]=ae;c[L+1656>>2]=X;c[L+1660>>2]=ad;c[L+1664>>2]=W;c[L+1668>>2]=T;c[L+1672>>2]=M;c[L+2668>>2]=K;c[L+3692>>2]=K;c[L+2672>>2]=al;c[L+3696>>2]=al;c[L+2676>>2]=ae;c[L+3700>>2]=ae;c[L+2680>>2]=X;c[L+3704>>2]=X;c[L+2684>>2]=ad;c[L+3708>>2]=ad;c[L+2688>>2]=W;c[L+3712>>2]=W;c[L+2692>>2]=T;c[L+3716>>2]=T;c[L+2696>>2]=M;c[L+3720>>2]=M;if(!P){M=L;gGC(M|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=R;c[2417277]=H;c[1836236]=-1}H=c[2385400]|0;c[2439118]=H;R=a[9688]|0?534:0;c[2439119]=H+(R<<1);c[2439120]=H+(R<<1<<1);c[2439121]=H+((R*3|0)<<1);c[2439122]=H+(R<<2<<1);c[2439123]=H+((R*5|0)<<1);R=a[9680]|0?32e3:0;c[3542220]=11200;H=c[2113008]|0;if((H|0)==0){gGz(14168888,0,252);c[3542223]=R;c[3542224]=2478;c[3542225]=150;c[3542226]=0;c[3542227]=0;c[3542234]=~~((+(R|0)*32768.0*8.0+768.0e3)/1536.0e3);M=31;ar=32767.0;while(1){c[14169012+(M<<2)>>2]=~~(ar+.5);T=M-1|0;if((T|0)>0){M=T;ar=ar/1.188502227}else{break}}c[3542253]=0;h[1771269]=1.0;h[1771270]=1.0;h[1771271]=1.0;c[3542574]=3;c[3542575]=3;c[3542576]=3;mB(0);M=(c[2113008]|0)+1|0;c[2113008]=M;as=M;at=a[9680]|0?32e3:0}else{as=H;at=R}c[3542220]=11200;if((as|0)==1){gGz(14169140,0,252);c[3542286]=at;gGz(14169148,0,16);c[3542297]=~~((+(at|0)*32768.0*8.0+768.0e3)/1536.0e3);M=31;ar=32767.0;while(1){c[14169264+(M<<2)>>2]=~~(ar+.5);L=M-1|0;if((L|0)>0){M=L;ar=ar/1.188502227}else{break}}c[3542316]=0;h[1771272]=1.0;h[1771273]=1.0;h[1771274]=1.0;c[3542577]=3;c[3542578]=3;c[3542579]=3;mB(1);c[2113008]=(c[2113008]|0)+1}h[1771269]=.3;c[3542574]=3;h[1771270]=.3;c[3542575]=3;h[1771271]=.3;c[3542576]=3;h[1771272]=.3;c[3542577]=3;h[1771273]=.3;c[3542578]=3;h[1771274]=.3;c[3542579]=3;M=c[642608+(c[2436]<<2)>>2]|0;R=c[M+128>>2]|0;if((c[M+52>>2]&4|0)==0){c[2113068]=R;H=c[M+132>>2]|0;c[2113070]=H;c[2443814]=R;c[2440436]=H;au=R;av=H}else{c[2113070]=R;H=c[M+132>>2]|0;c[2113068]=H;c[2440436]=R;c[2443814]=H;au=H;av=R}R=ag(au<<1,av)|0;H=gGq(R)|0;c[2112926]=H;if((H|0)!=0){gGz(H|0,0,R|0)}R=c[2439330]|0;H=(R|0)==0;if(!H){M=R;gGC(9706056,M|0,76)|0}M=c[2438118]|0;c[2433530]=M;L=c[3528484]|0;c[2076596]=L;P=c[2417276]|0;c[3541536]=P;c[1836236]=0;gGz(9706056,0,76);if(!H){H=R;gGC(H|0,9706056,76)|0}c[2438118]=M;c[3528484]=L;c[2417276]=P;c[1836236]=-1;P=c[2439331]|0;L=(P|0)==0;if(!L){M=P;gGC(9706056,M|0,76)|0}M=c[2438119]|0;c[2433530]=M;H=c[3528485]|0;c[2076596]=H;R=c[2417277]|0;c[3541536]=R;c[1836236]=1;gGz(9706056,0,76);if(!L){L=P;gGC(L|0,9706056,76)|0}c[2438119]=M;c[3528485]=H;c[2417277]=R;c[1836236]=-1;mB(0);mB(1);a[9754712]=0;a[9726696]=0;a[9757872]=0;a[9720528]=0;a[9733648]=0;a[9733640]=0;a[9754720]=0;a[9750672]=0;O=0;i=e;return O|0}}while(0);c[2426790]=0;O=1;i=e;return O|0}function dps(){var b=0,d=0,e=0,f=0;fwZ();c[2113008]=0;c[2076598]=0;c[2383582]=0;c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}a[9754712]=0;a[9726696]=0;a[9757872]=0;a[9720528]=0;a[9733648]=0;a[9733640]=0;a[9754720]=0;a[9750672]=0;c[2437660]=0;c[2437658]=0;c[2431678]=0;c[2433408]=0;c[2433406]=0;c[2430130]=0;b=c[2426790]|0;d=0;while(1){if((d|0)>=1024){e=74417;break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==(b|0)){break}else{d=d+1|0}}if((e|0)==74417){c[2426790]=0;return 0}gGr(b);c[f>>2]=0;c[2426790]=0;return 0}function dpt(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;if((a[14116088]|0)!=0){e=c[2439330]|0;f=(e|0)==0;if(!f){g=e;gGC(9706056,g|0,76)|0}g=c[2438118]|0;c[2433530]=g;h=c[3528484]|0;c[2076596]=h;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);if(!f){f=e;gGC(f|0,9706056,76)|0}c[2438118]=g;c[3528484]=h;c[2417276]=i;c[1836236]=-1;i=c[2439331]|0;h=(i|0)==0;if(!h){g=i;gGC(9706056,g|0,76)|0}g=c[2438119]|0;c[2433530]=g;f=c[3528485]|0;c[2076596]=f;e=c[2417277]|0;c[3541536]=e;c[1836236]=1;gGz(9706056,0,76);if(!h){h=i;gGC(h|0,9706056,76)|0}c[2438119]=g;c[3528485]=f;c[2417277]=e;c[1836236]=-1;mB(0);mB(1);a[9754712]=0;a[9726696]=0;a[9757872]=0;a[9720528]=0;a[9733648]=0;a[9733640]=0;a[9754720]=0;a[9750672]=0}a[14116098]=0;a[14116097]=0;a[14116096]=0;e=0;f=0;g=0;h=0;do{f=((a[9750664+e|0]&1)<<e|f&255)&255;g=((a[9750656+e|0]&1)<<e|g&255)&255;h=((a[9750648+e|0]&1)<<e|h&255)&255;e=e+1|0;}while((e|0)<8);a[14116096]=f;a[14116097]=g;a[14116098]=h;if((g&3)==3){f=g&-4;a[14116097]=f;j=f}else{j=g}if((j&12)==12){a[14116097]=j&-13}if((h&3)==3){j=h&-4;a[14116098]=j;k=j}else{k=h}if((k&12)==12){a[14116098]=k&-13}a[6518320]=1;a[6518144]=1;c[2444105]=0;c[2444104]=0;k=0;h=0;L90256:while(1){j=h;while(1){if((j|0)>=10){break L90256}g=c[2439330]|0;if((g|0)!=0){f=g;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;f=c[2438118]|0;c[2433530]=f;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;l=j+1|0;e=(ag(a[6518320]|0?51200:0,l)|0)/10|0;i=c[2444104]|0;m=e-i|0;c[2438198]=m;do{if((m|0)<1){n=0;o=i;p=f}else{if((a[g+4188|0]|0)==0){e=gfc(m)|0;q=(c[2433530]|0)+e|0;c[2433530]=q;n=e;o=c[2444104]|0;p=q;break}else{q=f+m|0;c[2433530]=q;n=m;o=i;p=q;break}}}while(0);c[2444104]=o+n;if((j|0)==9&(a[9754712]|0)!=0){if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;i=(c[2433530]|0)+12|0;c[2433530]=i;r=i}else{r=p}i=c[1836236]|0;m=c[9757320+(i<<2)>>2]|0;if((m|0)!=0){f=m;gGC(f|0,9706056,76)|0}c[9752472+(i<<2)>>2]=r;c[14113936+(i<<2)>>2]=c[2076596];c[9669104+(i<<2)>>2]=c[3541536];c[1836236]=-1;if((a[9726696]|0)!=0){i=c[2439331]|0;if((i|0)!=0){f=i;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;f=c[2438119]|0;c[2433530]=f;c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;m=(ag(a[6518144]|0?51200:0,l)|0)/10|0;g=c[2444105]|0;q=m-g|0;c[2438198]=q;do{if((q|0)<1){s=0;t=g}else{if((a[i+4188|0]|0)==0){m=gfc(q)|0;c[2433530]=(c[2433530]|0)+m;s=m;t=c[2444105]|0;break}else{c[2433530]=f+q;s=q;t=g;break}}}while(0);c[2438198]=s;c[2444105]=t+s;if((j|0)==8|(j|0)==6|(j|0)==4|(j|0)==2){a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0}g=c[1836236]|0;q=c[9757320+(g<<2)>>2]|0;if((q|0)!=0){f=q;gGC(f|0,9706056,76)|0}c[9752472+(g<<2)>>2]=c[2433530];c[14113936+(g<<2)>>2]=c[2076596];c[9669104+(g<<2)>>2]=c[3541536];c[1836236]=-1}u=c[2112964]|0;if((u|0)==0){j=l}else{break}}j=a[9688]|0?534:0;mF(9756472,u+(k<<1<<1)|0,j-k|0,0);k=j;h=l}l=c[2112964]|0;do{if((l|0)!=0){h=a[9688]|0?534:0;if((h|0)==(k|0)){break}mF(9756472,l+(k<<1<<1)|0,h-k|0,0)}}while(0);if((c[2112968]|0)==0){return 0}k=c[2112926]|0;gGz(k|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);l=c[2443312]|0;h=c[2438676]|0;u=c[2439466]|0;s=c[2443314]|0;t=0;do{r=d[l+t|0]|0;p=d[h+t|0]|0;n=d[u+t|0]|0;c[s+(t<<2)>>2]=(-(p>>>1&1)&31)+(-(p&1)&14)+(-(p>>>2&1)&67)+(-(p>>>3&1)&143)<<3&2016|(-(r>>>1&1)&31)+(-(r&1)&14)+(-(r>>>2&1)&67)+(-(r>>>3&1)&143)<<8&63488|((-(n>>>1&1)&31)+(-(n&1)&14)+(-(n>>>2&1)&67)+(-(n>>>3&1)&143)|0)>>>3&31;t=t+1|0;}while((t|0)<256);t=d[9733648]<<8|d[9733640];u=c[2437672]|0;h=c[2438682]|0;l=c[3529020]|0;n=0;r=0;while(1){p=r<<3;o=248-p|0;j=n;g=0;while(1){f=d[h+j|0]|0;q=f<<8&768|d[u+j|0];i=d[9720528]<<4|f>>>4;m=f>>>2&1;e=f>>>3&1;f=g<<3;if((a[9750672]|0)==0){v=e;w=m;x=p-(d[9754720]|0)|0;y=f}else{v=e^1;w=m^1;x=o+(d[9754720]|0)|0;y=504-f|0}f=y-t|0;m=(f|0)<-8?f+512|0:f;f=(x|0)<-8?x+256|0:x;e=(f|0)>264?f-256|0:f;f=m-32|0;z=e-16|0;do{if((m-41|0)>>>0<271){if((e-25|0)>>>0>=207){A=74488;break}B=(v|0)!=0;if((w|0)==0){if(B){Sm(k,q,f,z,i,3,0,l);break}else{Si(k,q,f,z,i,3,0,l);break}}else{if(B){So(k,q,f,z,i,3,0,l);break}else{Sk(k,q,f,z,i,3,0,l);break}}}else{A=74488}}while(0);do{if((A|0)==74488){A=0;e=(v|0)!=0;if((w|0)==0){if(e){Sn(k,q,f,z,i,3,0,l);break}else{Sj(k,q,f,z,i,3,0,l);break}}else{if(e){Sp(k,q,f,z,i,3,0,l);break}else{Sl(k,q,f,z,i,3,0,l);break}}}}while(0);i=g+1|0;if((i|0)<64){j=j+1|0;g=i}else{break}}g=r+1|0;if((g|0)<32){n=n+64|0;r=g}else{break}}r=c[2437656]|0;n=c[2437654]|0;l=c[2437670]|0;w=c[2443310]|0;v=0;do{x=(((v|0)/12|0)<<6)+(((v|0)%12|0)<<1)|0;t=(x|1)+40|0;y=d[n+t|0]<<8&256|d[l+t|0];u=y>>>0>320?y|-512:y;y=x+40|0;x=257-(d[r+y|0]|0)|0;h=x>>>0>240?x-256|0:x;x=a[9750672]|0;g=(x<<24>>24==0?h:240-h|0)-16|0;h=a[r+t|0]&31;L90345:do{if((u-17|0)>>>0<255){t=0;j=x;while(1){o=(t<<7)+y|0;p=d[n+o|0]|0;i=p<<9&512|d[l+o|0]|p<<7&256;o=p&8;z=p&4;p=t<<4;if(j<<24>>24==0){C=p+g|0;D=z;E=o}else{C=g-p|0;D=z>>>2^1;E=o>>>3^1}o=(E|0)==0;z=(D|0)!=0;do{if((C-17|0)>>>0<191){if(o){if(z){SK(k,i,u,C,h,3,0,0,w);break}else{SG(k,i,u,C,h,3,0,0,w);break}}else{if(z){SM(k,i,u,C,h,3,0,0,w);break}else{SI(k,i,u,C,h,3,0,0,w);break}}}else{if(o){if(z){SL(k,i,u,C,h,3,0,0,w);break}else{SH(k,i,u,C,h,3,0,0,w);break}}else{if(z){SN(k,i,u,C,h,3,0,0,w);break}else{SJ(k,i,u,C,h,3,0,0,w);break}}}}while(0);i=t+1|0;if((i|0)>=16){break L90345}t=i;j=a[9750672]|0}}else{j=0;t=x;while(1){i=(j<<7)+y|0;z=d[n+i|0]|0;o=z<<9&512|d[l+i|0]|z<<7&256;i=z&8;p=z&4;z=j<<4;if(t<<24>>24==0){F=z+g|0;G=p;H=i}else{F=g-z|0;G=p>>>2^1;H=i>>>3^1}i=(G|0)!=0;do{if((H|0)==0){if(i){SL(k,o,u,F,h,3,0,0,w);break}else{SH(k,o,u,F,h,3,0,0,w);break}}else{if(i){SN(k,o,u,F,h,3,0,0,w);break}else{SJ(k,o,u,F,h,3,0,0,w);break}}}while(0);o=j+1|0;if((o|0)>=16){break L90345}j=o;t=a[9750672]|0}}}while(0);v=v+1|0;}while((v|0)<24);v=c[2429726]|0;w=c[3529026]|0;F=0;H=0;G=0;n=0;while(1){C=F<<3;D=248-C|0;E=0;r=H;h=G;u=n;while(1){g=d[l+r|0]|0;y=(d[v+(g>>>3)|0]<<1)+(d[9757872]|0)|0;x=E<<3;if((a[9750672]|0)==0){I=u;J=h;K=C;L=x}else{I=1;J=1;K=D;L=280-x|0}x=K-16|0;do{if((L-1|0)>>>0<279){if((K-17|0)>>>0>=215){A=74543;break}t=(I|0)!=0;if((J|0)==0){if(t){Su(k,g,L,x,y,2,0,0,w);break}else{Sq(k,g,L,x,y,2,0,0,w);break}}else{if(t){Sw(k,g,L,x,y,2,0,0,w);break}else{Ss(k,g,L,x,y,2,0,0,w);break}}}else{A=74543}}while(0);do{if((A|0)==74543){A=0;t=(I|0)!=0;if((J|0)==0){if(t){Sv(k,g,L,x,y,2,0,0,w);break}else{Sr(k,g,L,x,y,2,0,0,w);break}}else{if(t){Sx(k,g,L,x,y,2,0,0,w);break}else{St(k,g,L,x,y,2,0,0,w);break}}}}while(0);y=E+1|0;if((y|0)<64){E=y;r=r+1|0;h=J;u=I}else{break}}u=F+1|0;if((u|0)<32){F=u;H=H+64|0;G=J;n=I}else{break}}R8(s);return 0}function dpu(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=i;i=i+240|0;e=d|0;f=d+32|0;g=d+48|0;h=d+64|0;j=d+80|0;k=d+96|0;l=d+112|0;m=d+128|0;n=d+144|0;o=d+160|0;p=d+176|0;q=d+192|0;r=d+208|0;s=d+224|0;t=(b|0)==0;if(!t){c[b>>2]=169588}if((a&32|0)!=0){gGz(s|0,0,12);u=c[2405698]|0;c[s>>2]=u;c[s+4>>2]=(c[2411784]|0)-u;c[s+12>>2]=162152;u=c[2076592]|0;gj[u&4095](s)|0}if((a&64|0)==0){i=d;return 0}fw$(a);a=d+16|0;do{if(!t){if((c[b>>2]|0)>=169110){break}c[b>>2]=169110}}while(0);if((c[2113008]|0)>0){b=e|0;t=e+4|0;s=e+8|0;u=e+12|0;v=0;do{cC(a|0,531144,(w=i,i=i+8|0,c[w>>2]=v,w)|0)|0;i=w;c[b>>2]=14168888+(v*252|0);c[t>>2]=252;c[s>>2]=0;c[u>>2]=a;gj[c[2076592]&4095](e)|0;v=v+1|0;}while((v|0)<(c[2113008]|0))}gGz(r|0,0,12);c[r>>2]=9776416;c[r+4>>2]=8;c[r+12>>2]=212472;gj[c[2076592]&4095](r)|0;gGz(q|0,0,12);c[q>>2]=9752792;c[q+4>>2]=4;c[q+12>>2]=436576;gj[c[2076592]&4095](q)|0;gGz(p|0,0,12);c[p>>2]=9623136;c[p+4>>2]=2;c[p+12>>2]=68680;gj[c[2076592]&4095](p)|0;gGz(o|0,0,12);c[o>>2]=14116096;c[o+4>>2]=3;c[o+12>>2]=67128;gj[c[2076592]&4095](o)|0;gGz(n|0,0,12);c[n>>2]=9754712;c[n+4>>2]=1;c[n+12>>2]=65824;gj[c[2076592]&4095](n)|0;gGz(m|0,0,12);c[m>>2]=9726696;c[m+4>>2]=1;c[m+12>>2]=589304;gj[c[2076592]&4095](m)|0;gGz(l|0,0,12);c[l>>2]=9757872;c[l+4>>2]=1;c[l+12>>2]=587904;gj[c[2076592]&4095](l)|0;gGz(k|0,0,12);c[k>>2]=9720528;c[k+4>>2]=1;c[k+12>>2]=585960;gj[c[2076592]&4095](k)|0;gGz(j|0,0,12);c[j>>2]=9733648;c[j+4>>2]=1;c[j+12>>2]=584096;gj[c[2076592]&4095](j)|0;gGz(h|0,0,12);c[h>>2]=9733640;c[h+4>>2]=1;c[h+12>>2]=582160;gj[c[2076592]&4095](h)|0;gGz(g|0,0,12);c[g>>2]=9754720;c[g+4>>2]=1;c[g+12>>2]=580072;gj[c[2076592]&4095](g)|0;gGz(f|0,0,12);c[f>>2]=9750672;c[f+4>>2]=1;c[f+12>>2]=577800;gj[c[2076592]&4095](f)|0;i=d;return 0}function dpv(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4295116+(b*112|0)>>2];c[a+104>>2]=c[4295120+(b*112|0)>>2];c[a+108>>2]=c[4295124+(b*112|0)>>2];d=0;return d|0}function dpw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=4295016+(b*112|0);e=0;return e|0}function dpx(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4983572+(b*112|0)>>2];c[a+104>>2]=c[4983576+(b*112|0)>>2];c[a+108>>2]=c[4983580+(b*112|0)>>2];d=0;return d|0}function dpy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=4983472+(b*112|0);e=0;return e|0}function dpz(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>42){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4985488+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dpA(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3435852+(b*112|0)>>2];c[a+104>>2]=c[3435856+(b*112|0)>>2];c[a+108>>2]=c[3435860+(b*112|0)>>2];d=0;return d|0}function dpB(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=3435752+(b*112|0);e=0;return e|0}function dpC(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3434060+(b*112|0)>>2];c[a+104>>2]=c[3434064+(b*112|0)>>2];c[a+108>>2]=c[3434068+(b*112|0)>>2];d=0;return d|0}function dpD(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=3433960+(b*112|0);e=0;return e|0}function dpE(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0.0,ao=0,ap=0,aq=0,ar=0;e=i;i=i+1680|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;B=e+1200|0;C=e+1312|0;D=e+1320|0;E=e+1432|0;F=e+1440|0;G=e+1552|0;H=e+1560|0;I=e+1672|0;c[2426790]=0;c[2443304]=0;c[2443302]=32768;c[2443312]=65536;c[2438676]=65792;c[2439466]=66048;c[2429726]=66304;c[2405698]=66336;c[2431676]=66336;c[2443306]=68384;c[2437656]=70432;c[2437654]=72480;c[2437670]=74528;c[2437672]=76576;c[2438682]=78624;c[2411784]=80672;c[3529026]=80672;c[3529020]=97056;c[2443310]=162592;c[2385400]=424736;J=a[9688]|0?6408:0;c[2443314]=J+424736;K=J+425760|0;c[2414332]=K;J=K;K=0;while(1){if((K|0)>=1024){break}L=9638528+(K<<2)|0;if((c[L>>2]|0)==0){M=74629;break}else{K=K+1|0}}do{if((M|0)==74629){K=gGq(J)|0;c[L>>2]=K;if((K|0)==0){break}gGz(K|0,0,J|0);c[2426790]=K;gGz(K|0,0,J|0);c[2443304]=K;c[2443302]=K+32768;c[2443312]=K+65536;c[2438676]=K+65792;c[2439466]=K+66048;c[2429726]=K+66304;N=K+66336|0;c[2405698]=N;c[2431676]=N;c[2443306]=K+68384;c[2437656]=K+70432;c[2437654]=K+72480;c[2437670]=K+74528;c[2437672]=K+76576;c[2438682]=K+78624;N=K+80672|0;c[2411784]=N;c[3529026]=N;c[3529020]=K+97056;c[2443310]=K+162592;c[2385400]=K+424736;N=a[9688]|0?6408:0;c[2443314]=K+(N+424736);c[2414332]=K+(N+425760);N=0;while(1){if((N|0)>=1024){O=0;break}P=9638528+(N<<2)|0;if((c[P>>2]|0)==0){M=74634;break}else{N=N+1|0}}do{if((M|0)==74634){N=gGq(98304)|0;c[P>>2]=N;if((N|0)==0){O=0;break}gGz(N|0,0,98304);O=N}}while(0);c[2443308]=O;N=0;while(1){if((N|0)>=1024){Q=0;break}R=9638528+(N<<2)|0;if((c[R>>2]|0)==0){M=74639;break}else{N=N+1|0}}do{if((M|0)==74639){N=gGq(32768)|0;c[R>>2]=N;if((N|0)==0){Q=0;break}gGz(N|0,0,32768);Q=N}}while(0);if((c[3542200]|0)==0){S=1;i=e;return S|0}N=H+108|0;c[N>>2]=0;K=H+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](H,0)|0;do{if((c[N>>2]|0)!=0){T=c[K>>2]|0;c[I>>2]=9534384;U=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[U&16383](I,0,0)|0;if((T|0)<1){S=1;i=e;return S|0}if((gzL(Q,0,0)|0)==0){break}else{S=1}i=e;return S|0}}while(0);K=c[2443304]|0;N=Q+16384|0;gGC(K|0,N|0,16384)|0;if((c[3542200]|0)==0){S=1;i=e;return S|0}K=F+108|0;c[K>>2]=0;T=F+100|0;c[T>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](F,1)|0;do{if((c[K>>2]|0)!=0){U=c[T>>2]|0;c[G>>2]=9534384;V=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[V&16383](G,1,0)|0;if((U|0)<1){S=1;i=e;return S|0}if((gzL(Q,0,1)|0)==0){break}else{S=1}i=e;return S|0}}while(0);T=(c[2443304]|0)+16384|0;gGC(T|0,N|0,16384)|0;if((c[3542200]|0)==0){S=1;i=e;return S|0}T=D+108|0;c[T>>2]=0;K=D+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](D,2)|0;do{if((c[T>>2]|0)!=0){U=c[K>>2]|0;c[E>>2]=9534384;V=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[V&16383](E,2,0)|0;if((U|0)<1){S=1;i=e;return S|0}if((gzL(Q,0,2)|0)==0){break}else{S=1}i=e;return S|0}}while(0);K=c[2443302]|0;gGC(K|0,N|0,16384)|0;if((c[3542200]|0)==0){S=1;i=e;return S|0}K=B+108|0;c[K>>2]=0;T=B+100|0;c[T>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](B,3)|0;do{if((c[K>>2]|0)!=0){U=c[T>>2]|0;c[C>>2]=9534384;V=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[V&16383](C,3,0)|0;if((U|0)<1){S=1;i=e;return S|0}if((gzL(Q,0,3)|0)==0){break}else{S=1}i=e;return S|0}}while(0);T=(c[2443302]|0)+16384|0;gGC(T|0,N|0,16384)|0;if((c[3542200]|0)==0){S=1;i=e;return S|0}T=z+108|0;c[T>>2]=0;K=z+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,4)|0;do{if((c[T>>2]|0)!=0){U=c[K>>2]|0;c[A>>2]=9534384;V=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[V&16383](A,4,0)|0;if((U|0)<1){S=1;i=e;return S|0}if((gzL(Q,0,4)|0)==0){break}else{S=1}i=e;return S|0}}while(0);K=c[2443308]|0;T=Q+28672|0;gGC(K|0,T|0,4096)|0;T=c[3529026]|0;N=0;do{U=N<<6;gGz(T+U|0,0,64);V=N<<7;W=0;do{X=V+(c[1238464+(W<<2)>>2]|0)|0;Y=(W<<3)+U|0;Z=0;do{_=X+(c[612768+(Z<<2)>>2]|0)|0;if(((d[K+((_|0)/8|0)|0]|0)&128>>>((_&7)>>>0)|0)!=0){_=T+(Y+Z)|0;a[_]=a[_]|2}Z=Z+1|0;}while((Z|0)<8);W=W+1|0;}while((W|0)<8);W=V|4;Z=0;do{Y=W+(c[1238464+(Z<<2)>>2]|0)|0;X=(Z<<3)+U|0;_=0;do{$=Y+(c[612768+(_<<2)>>2]|0)|0;if(((d[K+(($|0)/8|0)|0]|0)&128>>>(($&7)>>>0)|0)!=0){$=T+(X+_)|0;a[$]=a[$]|1}_=_+1|0;}while((_|0)<8);Z=Z+1|0;}while((Z|0)<8);N=N+1|0;}while((N|0)<256);gGz(K|0,0,98304);if((c[3542200]|0)==0){S=1;i=e;return S|0}N=x+108|0;c[N>>2]=0;T=x+100|0;c[T>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,5)|0;do{if((c[N>>2]|0)!=0){Z=c[T>>2]|0;c[y>>2]=9534384;U=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[U&16383](y,5,0)|0;if((Z|0)<1){S=1;i=e;return S|0}if((gzL(Q,0,5)|0)==0){break}else{S=1}i=e;return S|0}}while(0);T=c[2443308]|0;N=Q+24576|0;gGC(T|0,N|0,8192)|0;if((c[3542200]|0)==0){S=1;i=e;return S|0}T=v+108|0;c[T>>2]=0;K=v+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,6)|0;do{if((c[T>>2]|0)!=0){Z=c[K>>2]|0;c[w>>2]=9534384;U=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[U&16383](w,6,0)|0;if((Z|0)<1){S=1;i=e;return S|0}if((gzL(Q,0,6)|0)==0){break}else{S=1}i=e;return S|0}}while(0);K=(c[2443308]|0)+8192|0;gGC(K|0,N|0,8192)|0;if((c[3542200]|0)==0){S=1;i=e;return S|0}K=t+108|0;c[K>>2]=0;T=t+100|0;c[T>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,7)|0;do{if((c[K>>2]|0)!=0){Z=c[T>>2]|0;c[u>>2]=9534384;U=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[U&16383](u,7,0)|0;if((Z|0)<1){S=1;i=e;return S|0}if((gzL(Q,0,7)|0)==0){break}else{S=1}i=e;return S|0}}while(0);T=c[2443308]|0;K=T+16384|0;gGC(K|0,N|0,8192)|0;K=c[3529020]|0;Z=0;do{U=Z<<6;gGz(K+U|0,0,64);W=0;do{V=U+(c[1238464+(W<<2)>>2]|0)|0;_=(W<<3)+U|0;X=0;do{Y=V+(c[614800+(X<<2)>>2]|0)|0;if(((d[T+((Y|0)/8|0)|0]|0)&128>>>((Y&7)>>>0)|0)!=0){Y=K+(_+X)|0;a[Y]=a[Y]|4}X=X+1|0;}while((X|0)<8);W=W+1|0;}while((W|0)<8);W=U+65536|0;X=0;do{_=W+(c[1238464+(X<<2)>>2]|0)|0;V=(X<<3)+U|0;Y=0;do{$=_+(c[614800+(Y<<2)>>2]|0)|0;if(((d[T+(($|0)/8|0)|0]|0)&128>>>(($&7)>>>0)|0)!=0){$=K+(V+Y)|0;a[$]=a[$]|2}Y=Y+1|0;}while((Y|0)<8);X=X+1|0;}while((X|0)<8);X=U+131072|0;W=0;do{Y=X+(c[1238464+(W<<2)>>2]|0)|0;V=(W<<3)+U|0;_=0;do{$=Y+(c[614800+(_<<2)>>2]|0)|0;if(((d[T+(($|0)/8|0)|0]|0)&128>>>(($&7)>>>0)|0)!=0){$=K+(V+_)|0;a[$]=a[$]|1}_=_+1|0;}while((_|0)<8);W=W+1|0;}while((W|0)<8);Z=Z+1|0;}while((Z|0)<1024);gGz(T|0,0,98304);if((c[3542200]|0)==0){S=1;i=e;return S|0}Z=r+108|0;c[Z>>2]=0;K=r+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,8)|0;do{if((c[Z>>2]|0)!=0){N=c[K>>2]|0;c[s>>2]=9534384;W=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[W&16383](s,8,0)|0;if((N|0)<1){S=1;i=e;return S|0}if((gzL(T,0,8)|0)==0){break}else{S=1}i=e;return S|0}}while(0);T=(c[2443308]|0)+32768|0;if((c[3542200]|0)==0){S=1;i=e;return S|0}K=p+108|0;c[K>>2]=0;Z=p+100|0;c[Z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,9)|0;do{if((c[K>>2]|0)!=0){N=c[Z>>2]|0;c[q>>2]=9534384;W=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[W&16383](q,9,0)|0;if((N|0)<1){S=1;i=e;return S|0}if((gzL(T,0,9)|0)==0){break}else{S=1}i=e;return S|0}}while(0);T=(c[2443308]|0)+65536|0;if((c[3542200]|0)==0){S=1;i=e;return S|0}Z=n+108|0;c[Z>>2]=0;K=n+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,10)|0;do{if((c[Z>>2]|0)!=0){N=c[K>>2]|0;c[o>>2]=9534384;W=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[W&16383](o,10,0)|0;if((N|0)<1){S=1;i=e;return S|0}if((gzL(T,0,10)|0)==0){break}else{S=1}i=e;return S|0}}while(0);T=c[2443308]|0;K=c[2443310]|0;Z=0;do{N=Z<<8;gGz(K+N|0,0,256);W=0;do{U=N+(c[611776+(W<<2)>>2]|0)|0;X=(W<<4)+N|0;_=0;do{V=U+(c[601400+(_<<2)>>2]|0)|0;if(((d[T+((V|0)/8|0)|0]|0)&128>>>((V&7)>>>0)|0)!=0){V=K+(X+_)|0;a[V]=a[V]|4}_=_+1|0;}while((_|0)<16);W=W+1|0;}while((W|0)<16);W=N+262144|0;_=0;do{X=W+(c[611776+(_<<2)>>2]|0)|0;U=(_<<4)+N|0;V=0;do{Y=X+(c[601400+(V<<2)>>2]|0)|0;if(((d[T+((Y|0)/8|0)|0]|0)&128>>>((Y&7)>>>0)|0)!=0){Y=K+(U+V)|0;a[Y]=a[Y]|2}V=V+1|0;}while((V|0)<16);_=_+1|0;}while((_|0)<16);_=N+524288|0;W=0;do{V=_+(c[611776+(W<<2)>>2]|0)|0;U=(W<<4)+N|0;X=0;do{Y=V+(c[601400+(X<<2)>>2]|0)|0;if(((d[T+((Y|0)/8|0)|0]|0)&128>>>((Y&7)>>>0)|0)!=0){Y=K+(U+X)|0;a[Y]=a[Y]|1}X=X+1|0;}while((X|0)<16);W=W+1|0;}while((W|0)<16);Z=Z+1|0;}while((Z|0)<1024);Z=c[2443312]|0;if((c[3542200]|0)==0){S=1;i=e;return S|0}K=l+108|0;c[K>>2]=0;T=l+100|0;c[T>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,11)|0;do{if((c[K>>2]|0)!=0){W=c[T>>2]|0;c[m>>2]=9534384;N=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[N&16383](m,11,0)|0;if((W|0)<1){S=1;i=e;return S|0}if((gzL(Z,0,11)|0)==0){break}else{S=1}i=e;return S|0}}while(0);Z=c[2438676]|0;if((c[3542200]|0)==0){S=1;i=e;return S|0}T=j+108|0;c[T>>2]=0;K=j+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,12)|0;do{if((c[T>>2]|0)!=0){W=c[K>>2]|0;c[k>>2]=9534384;N=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[N&16383](k,12,0)|0;if((W|0)<1){S=1;i=e;return S|0}if((gzL(Z,0,12)|0)==0){break}else{S=1}i=e;return S|0}}while(0);Z=c[2439466]|0;if((c[3542200]|0)==0){S=1;i=e;return S|0}K=f+108|0;c[K>>2]=0;T=f+100|0;c[T>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,13)|0;do{if((c[K>>2]|0)!=0){W=c[T>>2]|0;c[g>>2]=9534384;N=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[N&16383](g,13,0)|0;if((W|0)<1){S=1;i=e;return S|0}if((gzL(Z,0,13)|0)==0){break}else{S=1}i=e;return S|0}}while(0);Z=c[2443308]|0;T=0;while(1){if((T|0)>=1024){break}aa=9638528+(T<<2)|0;if((c[aa>>2]|0)==(Z|0)){M=74724;break}else{T=T+1|0}}if((M|0)==74724){gGr(Z);c[aa>>2]=0}c[2443308]=0;T=0;while(1){if((T|0)>=1024){break}ab=9638528+(T<<2)|0;if((c[ab>>2]|0)==(Q|0)){M=74728;break}else{T=T+1|0}}if((M|0)==74728){gGr(Q);c[ab>>2]=0}fwR(0);T=c[2439330]|0;Z=(T|0)==0;if(!Z){K=T;gGC(9706056,K|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];K=c[3528484]|0;c[2076596]=K;W=c[2417276]|0;c[3541536]=W;c[1836236]=0;c[T+4180>>2]=1262;c[T+4184>>2]=1880;N=c[2443304]|0;_=0;X=0;while(1){c[T+76+(X<<2)>>2]=N+(X<<8);U=_+1&65535;if((U&65535)>127){ac=0;ad=0;break}else{_=U;X=U&65535}}while(1){X=N+(ad<<8)|0;c[T+76+(ad+512<<2)>>2]=X;c[T+76+(ad+768<<2)>>2]=X;X=ac+1&65535;if((X&65535)>127){break}else{ac=X;ad=X&65535}}N=c[2437672]|0;c[T+588>>2]=N;X=N+256|0;c[T+592>>2]=X;_=N+512|0;c[T+596>>2]=_;U=N+768|0;c[T+600>>2]=U;V=N+1024|0;c[T+604>>2]=V;Y=N+1280|0;c[T+608>>2]=Y;$=N+1536|0;c[T+612>>2]=$;ae=N+1792|0;c[T+616>>2]=ae;c[T+1612>>2]=N;c[T+1616>>2]=X;c[T+1620>>2]=_;c[T+1624>>2]=U;c[T+1628>>2]=V;c[T+1632>>2]=Y;c[T+1636>>2]=$;c[T+1640>>2]=ae;c[T+2636>>2]=N;c[T+3660>>2]=N;c[T+2640>>2]=X;c[T+3664>>2]=X;c[T+2644>>2]=_;c[T+3668>>2]=_;c[T+2648>>2]=U;c[T+3672>>2]=U;c[T+2652>>2]=V;c[T+3676>>2]=V;c[T+2656>>2]=Y;c[T+3680>>2]=Y;c[T+2660>>2]=$;c[T+3684>>2]=$;c[T+2664>>2]=ae;c[T+3688>>2]=ae;ae=c[2438682]|0;c[T+620>>2]=ae;$=ae+256|0;c[T+624>>2]=$;Y=ae+512|0;c[T+628>>2]=Y;V=ae+768|0;c[T+632>>2]=V;U=ae+1024|0;c[T+636>>2]=U;_=ae+1280|0;c[T+640>>2]=_;X=ae+1536|0;c[T+644>>2]=X;N=ae+1792|0;c[T+648>>2]=N;c[T+1644>>2]=ae;c[T+1648>>2]=$;c[T+1652>>2]=Y;c[T+1656>>2]=V;c[T+1660>>2]=U;c[T+1664>>2]=_;c[T+1668>>2]=X;c[T+1672>>2]=N;c[T+2668>>2]=ae;c[T+3692>>2]=ae;c[T+2672>>2]=$;c[T+3696>>2]=$;c[T+2676>>2]=Y;c[T+3700>>2]=Y;c[T+2680>>2]=V;c[T+3704>>2]=V;c[T+2684>>2]=U;c[T+3708>>2]=U;c[T+2688>>2]=_;c[T+3712>>2]=_;c[T+2692>>2]=X;c[T+3716>>2]=X;c[T+2696>>2]=N;c[T+3720>>2]=N;N=c[2437670]|0;c[T+652>>2]=N;X=N+256|0;c[T+656>>2]=X;_=N+512|0;c[T+660>>2]=_;U=N+768|0;c[T+664>>2]=U;V=N+1024|0;c[T+668>>2]=V;Y=N+1280|0;c[T+672>>2]=Y;$=N+1536|0;c[T+676>>2]=$;ae=N+1792|0;c[T+680>>2]=ae;c[T+1676>>2]=N;c[T+1680>>2]=X;c[T+1684>>2]=_;c[T+1688>>2]=U;c[T+1692>>2]=V;c[T+1696>>2]=Y;c[T+1700>>2]=$;c[T+1704>>2]=ae;c[T+2700>>2]=N;c[T+3724>>2]=N;c[T+2704>>2]=X;c[T+3728>>2]=X;c[T+2708>>2]=_;c[T+3732>>2]=_;c[T+2712>>2]=U;c[T+3736>>2]=U;c[T+2716>>2]=V;c[T+3740>>2]=V;c[T+2720>>2]=Y;c[T+3744>>2]=Y;c[T+2724>>2]=$;c[T+3748>>2]=$;c[T+2728>>2]=ae;c[T+3752>>2]=ae;ae=c[2437654]|0;c[T+1708>>2]=ae;$=ae+256|0;c[T+1712>>2]=$;Y=ae+512|0;c[T+1716>>2]=Y;V=ae+768|0;c[T+1720>>2]=V;U=ae+1024|0;c[T+1724>>2]=U;_=ae+1280|0;c[T+1728>>2]=_;X=ae+1536|0;c[T+1732>>2]=X;N=ae+1792|0;c[T+1736>>2]=N;c[T+2732>>2]=ae;c[T+3756>>2]=ae;c[T+2736>>2]=$;c[T+3760>>2]=$;c[T+2740>>2]=Y;c[T+3764>>2]=Y;c[T+2744>>2]=V;c[T+3768>>2]=V;c[T+2748>>2]=U;c[T+3772>>2]=U;c[T+2752>>2]=_;c[T+3776>>2]=_;c[T+2756>>2]=X;c[T+3780>>2]=X;c[T+2760>>2]=N;c[T+3784>>2]=N;N=c[2437656]|0;c[T+716>>2]=N;X=N+256|0;c[T+720>>2]=X;_=N+512|0;c[T+724>>2]=_;U=N+768|0;c[T+728>>2]=U;V=N+1024|0;c[T+732>>2]=V;Y=N+1280|0;c[T+736>>2]=Y;$=N+1536|0;c[T+740>>2]=$;ae=N+1792|0;c[T+744>>2]=ae;c[T+1740>>2]=N;c[T+1744>>2]=X;c[T+1748>>2]=_;c[T+1752>>2]=U;c[T+1756>>2]=V;c[T+1760>>2]=Y;c[T+1764>>2]=$;c[T+1768>>2]=ae;c[T+2764>>2]=N;c[T+3788>>2]=N;c[T+2768>>2]=X;c[T+3792>>2]=X;c[T+2772>>2]=_;c[T+3796>>2]=_;c[T+2776>>2]=U;c[T+3800>>2]=U;c[T+2780>>2]=V;c[T+3804>>2]=V;c[T+2784>>2]=Y;c[T+3808>>2]=Y;c[T+2788>>2]=$;c[T+3812>>2]=$;c[T+2792>>2]=ae;c[T+3816>>2]=ae;ae=c[2431676]|0;c[T+1036>>2]=ae;$=ae+256|0;c[T+1040>>2]=$;Y=ae+512|0;c[T+1044>>2]=Y;V=ae+768|0;c[T+1048>>2]=V;U=ae+1024|0;c[T+1052>>2]=U;_=ae+1280|0;c[T+1056>>2]=_;X=ae+1536|0;c[T+1060>>2]=X;N=ae+1792|0;c[T+1064>>2]=N;c[T+2060>>2]=ae;c[T+2064>>2]=$;c[T+2068>>2]=Y;c[T+2072>>2]=V;c[T+2076>>2]=U;c[T+2080>>2]=_;c[T+2084>>2]=X;c[T+2088>>2]=N;c[T+3084>>2]=ae;c[T+4108>>2]=ae;c[T+3088>>2]=$;c[T+4112>>2]=$;c[T+3092>>2]=Y;c[T+4116>>2]=Y;c[T+3096>>2]=V;c[T+4120>>2]=V;c[T+3100>>2]=U;c[T+4124>>2]=U;c[T+3104>>2]=_;c[T+4128>>2]=_;c[T+3108>>2]=X;c[T+4132>>2]=X;c[T+3112>>2]=N;c[T+4136>>2]=N;if(!Z){N=T;gGC(N|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=K;c[2417276]=W;c[1836236]=-1;fwR(1);N=c[2439331]|0;X=(N|0)==0;if(!X){_=N;gGC(9706056,_|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];_=c[3528485]|0;c[2076596]=_;U=c[2417277]|0;c[3541536]=U;c[1836236]=1;c[N+4184>>2]=104;V=N+4172|0;c[V>>2]=3350;Y=c[2443302]|0;$=0;ae=0;while(1){c[N+76+(ae<<2)>>2]=Y+(ae<<8);af=$+1&65535;if((af&65535)>127){ah=0;ai=0;break}else{$=af;ae=af&65535}}while(1){ae=Y+(ai<<8)|0;c[N+76+(ai+512<<2)>>2]=ae;c[N+76+(ai+768<<2)>>2]=ae;ae=ah+1&65535;if((ae&65535)>127){break}else{ah=ae;ai=ae&65535}}if(!X){Y=N;gGC(Y|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=_;c[2417277]=U;c[1836236]=-1;Y=c[2439330]|0;ae=(Y|0)==0;if(!ae){$=Y;gGC(9706056,$|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];$=c[3528484]|0;c[2076596]=$;W=c[2417276]|0;c[3541536]=W;c[1836236]=0;c[Y+4176>>2]=720;K=c[2431676]|0;c[Y+972>>2]=K;T=K+256|0;c[Y+976>>2]=T;Z=K+512|0;c[Y+980>>2]=Z;af=K+768|0;c[Y+984>>2]=af;aj=K+1024|0;c[Y+988>>2]=aj;ak=K+1280|0;c[Y+992>>2]=ak;al=K+1536|0;c[Y+996>>2]=al;am=K+1792|0;c[Y+1e3>>2]=am;c[Y+1996>>2]=K;c[Y+2e3>>2]=T;c[Y+2004>>2]=Z;c[Y+2008>>2]=af;c[Y+2012>>2]=aj;c[Y+2016>>2]=ak;c[Y+2020>>2]=al;c[Y+2024>>2]=am;c[Y+3020>>2]=K;c[Y+4044>>2]=K;c[Y+3024>>2]=T;c[Y+4048>>2]=T;c[Y+3028>>2]=Z;c[Y+4052>>2]=Z;c[Y+3032>>2]=af;c[Y+4056>>2]=af;c[Y+3036>>2]=aj;c[Y+4060>>2]=aj;c[Y+3040>>2]=ak;c[Y+4064>>2]=ak;c[Y+3044>>2]=al;c[Y+4068>>2]=al;c[Y+3048>>2]=am;c[Y+4072>>2]=am;if(!ae){ae=Y;gGC(ae|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=$;c[2417276]=W;c[1836236]=-1;if(!X){W=N;gGC(9706056,W|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];W=c[3528485]|0;c[2076596]=W;$=c[2417277]|0;c[3541536]=$;c[1836236]=1;c[N+4180>>2]=2502;c[V>>2]=852;c[N+4176>>2]=3216;c[N+588>>2]=K;c[N+592>>2]=T;c[N+596>>2]=Z;c[N+600>>2]=af;c[N+604>>2]=aj;c[N+608>>2]=ak;c[N+612>>2]=al;c[N+616>>2]=am;c[N+1612>>2]=K;c[N+1616>>2]=T;c[N+1620>>2]=Z;c[N+1624>>2]=af;c[N+1628>>2]=aj;c[N+1632>>2]=ak;c[N+1636>>2]=al;c[N+1640>>2]=am;c[N+2636>>2]=K;c[N+3660>>2]=K;c[N+2640>>2]=T;c[N+3664>>2]=T;c[N+2644>>2]=Z;c[N+3668>>2]=Z;c[N+2648>>2]=af;c[N+3672>>2]=af;c[N+2652>>2]=aj;c[N+3676>>2]=aj;c[N+2656>>2]=ak;c[N+3680>>2]=ak;c[N+2660>>2]=al;c[N+3684>>2]=al;c[N+2664>>2]=am;c[N+3688>>2]=am;if(!X){am=N;gGC(am|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=W;c[2417277]=$;c[1836236]=-1;$=c[2385400]|0;c[2439118]=$;W=a[9688]|0?534:0;c[2439119]=$+(W<<1);c[2439120]=$+(W<<1<<1);c[2439121]=$+((W*3|0)<<1);c[2439122]=$+(W<<2<<1);c[2439123]=$+((W*5|0)<<1);W=a[9680]|0?32e3:0;c[3542220]=11200;$=c[2113008]|0;if(($|0)==0){gGz(14168888,0,252);c[3542223]=W;c[3542224]=2478;c[3542225]=150;c[3542226]=0;c[3542227]=0;c[3542234]=~~((+(W|0)*32768.0*8.0+768.0e3)/1536.0e3);am=31;an=32767.0;while(1){c[14169012+(am<<2)>>2]=~~(an+.5);al=am-1|0;if((al|0)>0){am=al;an=an/1.188502227}else{break}}c[3542253]=0;h[1771269]=1.0;h[1771270]=1.0;h[1771271]=1.0;c[3542574]=3;c[3542575]=3;c[3542576]=3;mB(0);am=(c[2113008]|0)+1|0;c[2113008]=am;ao=am;ap=a[9680]|0?32e3:0}else{ao=$;ap=W}c[3542220]=11200;if((ao|0)==1){gGz(14169140,0,252);c[3542286]=ap;gGz(14169148,0,16);c[3542297]=~~((+(ap|0)*32768.0*8.0+768.0e3)/1536.0e3);am=31;an=32767.0;while(1){c[14169264+(am<<2)>>2]=~~(an+.5);N=am-1|0;if((N|0)>0){am=N;an=an/1.188502227}else{break}}c[3542316]=0;h[1771272]=1.0;h[1771273]=1.0;h[1771274]=1.0;c[3542577]=3;c[3542578]=3;c[3542579]=3;mB(1);c[2113008]=(c[2113008]|0)+1}h[1771269]=.3;c[3542574]=3;h[1771270]=.3;c[3542575]=3;h[1771271]=.3;c[3542576]=3;h[1771272]=.3;c[3542577]=3;h[1771273]=.3;c[3542578]=3;h[1771274]=.3;c[3542579]=3;am=c[642608+(c[2436]<<2)>>2]|0;W=c[am+128>>2]|0;if((c[am+52>>2]&4|0)==0){c[2113068]=W;$=c[am+132>>2]|0;c[2113070]=$;c[2443814]=W;c[2440436]=$;aq=W;ar=$}else{c[2113070]=W;$=c[am+132>>2]|0;c[2113068]=$;c[2440436]=W;c[2443814]=$;aq=$;ar=W}W=ag(aq<<1,ar)|0;$=gGq(W)|0;c[2112926]=$;if(($|0)!=0){gGz($|0,0,W|0)}W=c[2439330]|0;$=(W|0)==0;if(!$){am=W;gGC(9706056,am|0,76)|0}am=c[2438118]|0;c[2433530]=am;N=c[3528484]|0;c[2076596]=N;X=c[2417276]|0;c[3541536]=X;c[1836236]=0;gGz(9706056,0,76);if(!$){$=W;gGC($|0,9706056,76)|0}c[2438118]=am;c[3528484]=N;c[2417276]=X;c[1836236]=-1;X=c[2439331]|0;N=(X|0)==0;if(!N){am=X;gGC(9706056,am|0,76)|0}am=c[2438119]|0;c[2433530]=am;$=c[3528485]|0;c[2076596]=$;W=c[2417277]|0;c[3541536]=W;c[1836236]=1;gGz(9706056,0,76);if(!N){N=X;gGC(N|0,9706056,76)|0}c[2438119]=am;c[3528485]=$;c[2417277]=W;c[1836236]=-1;mB(0);mB(1);a[9754712]=0;a[9726696]=0;a[9757872]=0;a[9720528]=0;a[9733648]=0;a[9733640]=0;a[9754720]=0;a[9750672]=0;S=0;i=e;return S|0}}while(0);c[2426790]=0;S=1;i=e;return S|0}function dpF(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3956276+(b*112|0)>>2];c[a+104>>2]=c[3956280+(b*112|0)>>2];c[a+108>>2]=c[3956284+(b*112|0)>>2];d=0;return d|0}function dpG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=3956176+(b*112|0);e=0;return e|0}function dpH(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>42){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3958752+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dpI(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1923988+(b*112|0)>>2];c[a+104>>2]=c[1923992+(b*112|0)>>2];c[a+108>>2]=c[1923996+(b*112|0)>>2];d=0;return d|0}function dpJ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=1923888+(b*112|0);e=0;return e|0}function dpK(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3878404+(b*112|0)>>2];c[a+104>>2]=c[3878408+(b*112|0)>>2];c[a+108>>2]=c[3878412+(b*112|0)>>2];d=0;return d|0}function dpL(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=3878304+(b*112|0);e=0;return e|0}function dpM(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>36){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3880544+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dpN(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1871988+(b*112|0)>>2];c[a+104>>2]=c[1871992+(b*112|0)>>2];c[a+108>>2]=c[1871996+(b*112|0)>>2];d=0;return d|0}function dpO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=1871888+(b*112|0);e=0;return e|0}function dpP(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5551836+(b*112|0)>>2];c[a+104>>2]=c[5551840+(b*112|0)>>2];c[a+108>>2]=c[5551844+(b*112|0)>>2];d=0;return d|0}function dpQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=5551736+(b*112|0);e=0;return e|0}function dpR(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>23){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6252436+(b*112|0)>>2];c[a+104>>2]=c[6252440+(b*112|0)>>2];c[a+108>>2]=c[6252444+(b*112|0)>>2];d=0;return d|0}function dpS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<24&(d|0)==0)){e=1;return e|0}c[a>>2]=6252336+(b*112|0);e=0;return e|0}function dpT(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>39){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6255024+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dpU(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3410260+(b*112|0)>>2];c[a+104>>2]=c[3410264+(b*112|0)>>2];c[a+108>>2]=c[3410268+(b*112|0)>>2];d=0;return d|0}function dpV(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<21&(d|0)==0)){e=1;return e|0}c[a>>2]=3410160+(b*112|0);e=0;return e|0}function dpW(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>47){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3412512+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dpX(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5100076+(b*112|0)>>2];c[a+104>>2]=c[5100080+(b*112|0)>>2];c[a+108>>2]=c[5100084+(b*112|0)>>2];d=0;return d|0}function dpY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<21&(d|0)==0)){e=1;return e|0}c[a>>2]=5099976+(b*112|0);e=0;return e|0}function dpZ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3782708+(b*112|0)>>2];c[a+104>>2]=c[3782712+(b*112|0)>>2];c[a+108>>2]=c[3782716+(b*112|0)>>2];d=0;return d|0}function dp_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<21&(d|0)==0)){e=1;return e|0}c[a>>2]=3782608+(b*112|0);e=0;return e|0}function dp$(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3780356+(b*112|0)>>2];c[a+104>>2]=c[3780360+(b*112|0)>>2];c[a+108>>2]=c[3780364+(b*112|0)>>2];d=0;return d|0}function dp0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<21&(d|0)==0)){e=1;return e|0}c[a>>2]=3780256+(b*112|0);e=0;return e|0}function dp1(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3777892+(b*112|0)>>2];c[a+104>>2]=c[3777896+(b*112|0)>>2];c[a+108>>2]=c[3777900+(b*112|0)>>2];d=0;return d|0}function dp2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<22&(d|0)==0)){e=1;return e|0}c[a>>2]=3777792+(b*112|0);e=0;return e|0}function dp3(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3381196+(b*112|0)>>2];c[a+104>>2]=c[3381200+(b*112|0)>>2];c[a+108>>2]=c[3381204+(b*112|0)>>2];d=0;return d|0}function dp4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=3381096+(b*112|0);e=0;return e|0}function dp5(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>42){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3383224+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dp6(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[635980+(b*112|0)>>2];c[a+104>>2]=c[635984+(b*112|0)>>2];c[a+108>>2]=c[635988+(b*112|0)>>2];d=0;return d|0}function dp7(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=635880+(b*112|0);e=0;return e|0}function dp8(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7400828+(b*112|0)>>2];c[a+104>>2]=c[7400832+(b*112|0)>>2];c[a+108>>2]=c[7400836+(b*112|0)>>2];d=0;return d|0}function dp9(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=7400728+(b*112|0);e=0;return e|0}function dqa(b){b=b|0;return a[9623136]|0}function dqb(b){b=b|0;return a[9623137]|0}function dqc(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=d&65535;if((f|0)==53248){a[c[3528326]|0]=e;d=c[1836236]|0;g=c[9757320+(d<<2)>>2]|0;if((g|0)!=0){h=g;gGC(h|0,9706056,76)|0}c[9752472+(d<<2)>>2]=c[2433530];c[14113936+(d<<2)>>2]=c[2076596];c[9669104+(d<<2)>>2]=c[3541536];c[1836236]=-1;d=c[2439331]|0;if((d|0)!=0){h=d;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;h=(c[2433530]|0)+12|0;c[2433530]=h;d=c[1836236]|0;g=c[9757320+(d<<2)>>2]|0;if((g|0)!=0){i=g;gGC(i|0,9706056,76)|0}c[9752472+(d<<2)>>2]=h;c[14113936+(d<<2)>>2]=c[2076596];c[9669104+(d<<2)>>2]=c[3541536];c[1836236]=-1;d=c[2439330]|0;if((d|0)!=0){h=d;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;return}else if((f|0)==57344){a[c[3528748]|0]=e&2^2;a[c[2405108]|0]=(e&255)>>>2&1;return}else{return}}function dqd(b){b=b|0;var d=0,e=0;d=b&65535;if((d|0)==57344){a[c[2388386]|0]=0;e=0}else if((d|0)==49152|(d|0)==49153){e=a[9550736+(d&1)|0]|0}else if((d|0)==49155){e=a[c[2415280]|0]|0}else{e=0}return e|0}function dqe(b,d){b=b|0;d=d|0;var e=0,f=0;e=b&65535;if((e|0)==32769){b=d&255;f=c[3542291]|0;if((f|0)>15){return}do{if((f|0)<14){if((f|0)!=13){if((a[14169168+f|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(1,f,b);return}else if((e|0)==24576){c[3542228]=d&15;return}else if((e|0)==32768){c[3542291]=d&15;return}else if((e|0)==24577){e=d&255;b=c[3542228]|0;if((b|0)>15){return}do{if((b|0)<14){if((b|0)!=13){if((a[14168916+b|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(0,b,e);return}else{return}}function dqf(b){b=b|0;var d=0,e=0,f=0;d=b&65535;if((d|0)==24578){b=c[3542228]|0;if((b|0)>15){e=0;return e|0}do{if((b|0)==14){f=c[3542224]|0;if((f|0)==0){break}a[14168930]=gj[f&4095](0)|0}else if((b|0)==15){f=c[3542225]|0;if((f|0)==0){break}a[14168931]=gj[f&4095](0)|0}}while(0);e=a[14168916+b|0]|0;return e|0}else if((d|0)==32770){d=c[3542291]|0;if((d|0)>15){e=0;return e|0}do{if((d|0)==14){b=c[3542287]|0;if((b|0)==0){break}a[14169182]=gj[b&4095](0)|0}else if((d|0)==15){b=c[3542288]|0;if((b|0)==0){break}a[14169183]=gj[b&4095](0)|0}}while(0);e=a[14169168+d|0]|0;return e|0}else{e=0;return e|0}return 0}function dqg(b){b=b|0;return a[c[3528326]|0]|0}function dqh(b,d){b=b|0;d=d|0;a[c[2415280]|0]=d&255;return}function dqi(b){b=b|0;return a[9635456]|0}function dqj(b){b=b|0;return a[9635457]|0}function dqk(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3062692+(b*112|0)>>2];c[a+104>>2]=c[3062696+(b*112|0)>>2];c[a+108>>2]=c[3062700+(b*112|0)>>2];d=0;return d|0}function dql(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=3062592+(b*112|0);e=0;return e|0}function dqm(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1308832+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dqn(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>31){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4228512+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dqo(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0.0,aj=0,ak=0,al=0,am=0;e=i;i=i+1560|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;B=e+1200|0;C=e+1312|0;D=e+1320|0;E=e+1432|0;F=e+1440|0;G=e+1552|0;c[2415036]=0;c[3529254]=0;c[3529210]=65536;c[3530892]=131072;c[3530656]=163840;c[3530108]=196608;c[2439112]=198688;H=a[9688]|0?1068:0;I=H+198688|0;c[2439113]=I;J=I+H|0;c[2439114]=J;I=J+H|0;c[2439115]=I;J=I+H|0;c[2439116]=J;I=J+H|0;c[2439117]=I;J=I+H|0;H=J|0;c[2414744]=H;c[2387882]=H;c[2386248]=J+1024;c[2443478]=J+2048;c[2386504]=J+2304;c[3529342]=J+2560;c[3529300]=J+4608;c[2415280]=J+6656;c[3528326]=J+6657;c[3528748]=J+6658;c[2405108]=J+6659;c[2388386]=J+6660;H=J+6661|0;c[2411782]=H;c[2414330]=H;J=H;H=0;while(1){if((H|0)>=1024){break}K=9638528+(H<<2)|0;if((c[K>>2]|0)==0){L=75152;break}else{H=H+1|0}}do{if((L|0)==75152){H=gGq(J)|0;c[K>>2]=H;if((H|0)==0){break}gGz(H|0,0,J|0);c[2415036]=H;gGz(H|0,0,J|0);c[3529254]=H;c[3529210]=H+65536;c[3530892]=H+131072;c[3530656]=H+163840;c[3530108]=H+196608;c[2439112]=H+198688;I=a[9688]|0?1068:0;M=I+198688|0;c[2439113]=H+M;N=M+I|0;c[2439114]=H+N;M=N+I|0;c[2439115]=H+M;N=M+I|0;c[2439116]=H+N;M=N+I|0;c[2439117]=H+M;N=M+I|0;I=H+N|0;c[2414744]=I;c[2387882]=I;c[2386248]=H+(N+1024);c[2443478]=H+(N+2048);c[2386504]=H+(N+2304);c[3529342]=H+(N+2560);c[3529300]=H+(N+4608);c[2415280]=H+(N+6656);c[3528326]=H+(N+6657);c[3528748]=H+(N+6658);c[2405108]=H+(N+6659);c[2388386]=H+(N+6660);I=H+(N+6661)|0;c[2411782]=I;c[2414330]=I;if((c[3542200]|0)==0){O=1;i=e;return O|0}I=F+108|0;c[I>>2]=0;N=F+100|0;c[N>>2]=0;M=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[M&16383](F,0)|0;do{if((c[I>>2]|0)!=0){M=c[N>>2]|0;c[G>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](G,0,0)|0;if((M|0)<1){O=1;i=e;return O|0}if((gzL(H,0,0)|0)==0){break}else{O=1}i=e;return O|0}}while(0);H=(c[3529254]|0)+4096|0;if((c[3542200]|0)==0){O=1;i=e;return O|0}N=D+108|0;c[N>>2]=0;I=D+100|0;c[I>>2]=0;M=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[M&16383](D,1)|0;do{if((c[N>>2]|0)!=0){M=c[I>>2]|0;c[E>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](E,1,0)|0;if((M|0)<1){O=1;i=e;return O|0}if((gzL(H,0,1)|0)==0){break}else{O=1}i=e;return O|0}}while(0);H=(c[3529254]|0)+8192|0;if((c[3542200]|0)==0){O=1;i=e;return O|0}I=B+108|0;c[I>>2]=0;N=B+100|0;c[N>>2]=0;M=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[M&16383](B,2)|0;do{if((c[I>>2]|0)!=0){M=c[N>>2]|0;c[C>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](C,2,0)|0;if((M|0)<1){O=1;i=e;return O|0}if((gzL(H,0,2)|0)==0){break}else{O=1}i=e;return O|0}}while(0);H=(c[3529254]|0)+12288|0;if((c[3542200]|0)==0){O=1;i=e;return O|0}N=z+108|0;c[N>>2]=0;I=z+100|0;c[I>>2]=0;M=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[M&16383](z,3)|0;do{if((c[N>>2]|0)!=0){M=c[I>>2]|0;c[A>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](A,3,0)|0;if((M|0)<1){O=1;i=e;return O|0}if((gzL(H,0,3)|0)==0){break}else{O=1}i=e;return O|0}}while(0);H=(c[3529254]|0)+16384|0;if((c[3542200]|0)==0){O=1;i=e;return O|0}I=x+108|0;c[I>>2]=0;N=x+100|0;c[N>>2]=0;M=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[M&16383](x,4)|0;do{if((c[I>>2]|0)!=0){M=c[N>>2]|0;c[y>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](y,4,0)|0;if((M|0)<1){O=1;i=e;return O|0}if((gzL(H,0,4)|0)==0){break}else{O=1}i=e;return O|0}}while(0);H=c[642608+(c[2436]<<2)>>2]|0;do{if((fa(c[H>>2]|0,100416)|0)==0){N=(c[3529254]|0)+20480|0;if((c[3542200]|0)==0){O=1;i=e;return O|0}I=v+108|0;c[I>>2]=0;M=v+100|0;c[M>>2]=0;P=c[H+76>>2]|0;gA[P&16383](v,5)|0;if((c[I>>2]|0)==0){Q=1;break}I=c[M>>2]|0;c[w>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](w,5,0)|0;if((I|0)<1){O=1;i=e;return O|0}if((gzL(N,0,5)|0)==0){Q=1;break}else{O=1}i=e;return O|0}else{Q=0}}while(0);H=c[3529210]|0;N=Q+5|0;if((c[3542200]|0)==0){O=1;i=e;return O|0}I=t+108|0;c[I>>2]=0;M=t+100|0;c[M>>2]=0;P=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[P&16383](t,N)|0;do{if((c[I>>2]|0)!=0){P=c[M>>2]|0;c[u>>2]=9534384;R=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[R&16383](u,N,0)|0;if((P|0)<1){O=1;i=e;return O|0}if((gzL(H,0,N)|0)==0){break}else{O=1}i=e;return O|0}}while(0);N=(c[3529210]|0)+8192|0;H=Q|6;if((c[3542200]|0)==0){O=1;i=e;return O|0}M=r+108|0;c[M>>2]=0;I=r+100|0;c[I>>2]=0;P=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[P&16383](r,H)|0;do{if((c[M>>2]|0)!=0){P=c[I>>2]|0;c[s>>2]=9534384;R=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[R&16383](s,H,0)|0;if((P|0)<1){O=1;i=e;return O|0}if((gzL(N,0,H)|0)==0){break}else{O=1}i=e;return O|0}}while(0);H=c[3530892]|0;N=Q+7|0;if((c[3542200]|0)==0){O=1;i=e;return O|0}I=p+108|0;c[I>>2]=0;M=p+100|0;c[M>>2]=0;P=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[P&16383](p,N)|0;do{if((c[I>>2]|0)!=0){P=c[M>>2]|0;c[q>>2]=9534384;R=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[R&16383](q,N,0)|0;if((P|0)<1){O=1;i=e;return O|0}if((gzL(H,0,N)|0)==0){break}else{O=1}i=e;return O|0}}while(0);N=(c[3530892]|0)+4096|0;H=Q|8;if((c[3542200]|0)==0){O=1;i=e;return O|0}M=n+108|0;c[M>>2]=0;I=n+100|0;c[I>>2]=0;P=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[P&16383](n,H)|0;do{if((c[M>>2]|0)!=0){P=c[I>>2]|0;c[o>>2]=9534384;R=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[R&16383](o,H,0)|0;if((P|0)<1){O=1;i=e;return O|0}if((gzL(N,0,H)|0)==0){break}else{O=1}i=e;return O|0}}while(0);H=c[3530656]|0;N=Q+9|0;if((c[3542200]|0)==0){O=1;i=e;return O|0}I=l+108|0;c[I>>2]=0;M=l+100|0;c[M>>2]=0;P=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[P&16383](l,N)|0;do{if((c[I>>2]|0)!=0){P=c[M>>2]|0;c[m>>2]=9534384;R=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[R&16383](m,N,0)|0;if((P|0)<1){O=1;i=e;return O|0}if((gzL(H,0,N)|0)==0){break}else{O=1}i=e;return O|0}}while(0);N=(c[3530656]|0)+4096|0;H=Q|10;if((c[3542200]|0)==0){O=1;i=e;return O|0}M=j+108|0;c[M>>2]=0;I=j+100|0;c[I>>2]=0;P=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[P&16383](j,H)|0;do{if((c[M>>2]|0)!=0){P=c[I>>2]|0;c[k>>2]=9534384;R=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[R&16383](k,H,0)|0;if((P|0)<1){O=1;i=e;return O|0}if((gzL(N,0,H)|0)==0){break}else{O=1}i=e;return O|0}}while(0);H=(c[3530656]|0)+8192|0;N=Q+11|0;if((c[3542200]|0)==0){O=1;i=e;return O|0}I=f+108|0;c[I>>2]=0;M=f+100|0;c[M>>2]=0;P=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[P&16383](f,N)|0;do{if((c[I>>2]|0)==0){S=0}else{P=c[M>>2]|0;c[g>>2]=9534384;R=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[R&16383](g,N,0)|0;if((P|0)<1){O=1;i=e;return O|0}if((gzL(H,0,N)|0)==0){S=0;break}else{O=1}i=e;return O|0}}while(0);while(1){if((S|0)>=1024){break}T=9638528+(S<<2)|0;if((c[T>>2]|0)==0){L=75209;break}else{S=S+1|0}}L91307:do{if((L|0)==75209){N=gGq(12288)|0;c[T>>2]=N;if((N|0)==0){break}gGz(N|0,0,12288);H=c[3530892]|0;gGC(N|0,H|0,8192)|0;M=0;do{I=M<<6;gGz(H+I|0,0,64);P=I+32768|0;R=0;while(1){U=P+(c[609008+(R<<2)>>2]|0)|0;V=(R<<3)+I|0;W=0;do{X=U+(c[614800+(W<<2)>>2]|0)|0;if(((d[N+((X|0)/8|0)|0]|0)&128>>>((X&7)>>>0)|0)!=0){X=H+(V+W)|0;a[X]=a[X]|2}W=W+1|0;}while((W|0)<8);W=R+1|0;if((W|0)<8){R=W}else{Y=0;break}}do{R=I+(c[609008+(Y<<2)>>2]|0)|0;P=(Y<<3)+I|0;W=0;do{V=R+(c[614800+(W<<2)>>2]|0)|0;if(((d[N+((V|0)/8|0)|0]|0)&128>>>((V&7)>>>0)|0)!=0){V=H+(P+W)|0;a[V]=a[V]|1}W=W+1|0;}while((W|0)<8);Y=Y+1|0;}while((Y|0)<8);M=M+1|0;}while((M|0)<512);M=c[3530656]|0;gGC(N|0,M|0,12288)|0;H=0;while(1){I=H<<7;gGz(M+I|0,0,128);W=I+65536|0;P=0;do{R=W+(c[609008+(P<<2)>>2]|0)|0;V=(P<<3)+I|0;U=0;do{X=R+(c[614800+(U<<2)>>2]|0)|0;if(((d[N+((X|0)/8|0)|0]|0)&128>>>((X&7)>>>0)|0)!=0){X=M+(V+U)|0;a[X]=a[X]|4}U=U+1|0;}while((U|0)<8);P=P+1|0;}while((P|0)<16);P=I+32768|0;W=0;while(1){U=P+(c[609008+(W<<2)>>2]|0)|0;V=(W<<3)+I|0;R=0;do{X=U+(c[614800+(R<<2)>>2]|0)|0;if(((d[N+((X|0)/8|0)|0]|0)&128>>>((X&7)>>>0)|0)!=0){X=M+(V+R)|0;a[X]=a[X]|2}R=R+1|0;}while((R|0)<8);R=W+1|0;if((R|0)<16){W=R}else{Z=0;break}}do{W=I+(c[609008+(Z<<2)>>2]|0)|0;P=(Z<<3)+I|0;R=0;do{V=W+(c[614800+(R<<2)>>2]|0)|0;if(((d[N+((V|0)/8|0)|0]|0)&128>>>((V&7)>>>0)|0)!=0){V=M+(P+R)|0;a[V]=a[V]|1}R=R+1|0;}while((R|0)<8);Z=Z+1|0;}while((Z|0)<16);I=H+1|0;if((I|0)<256){H=I}else{_=0;break}}while(1){if((_|0)>=1024){break L91307}$=9638528+(_<<2)|0;if((c[$>>2]|0)==(N|0)){break}else{_=_+1|0}}gGr(N);c[$>>2]=0}}while(0);fwR(0);H=c[2439330]|0;M=(H|0)==0;if(!M){I=H;gGC(9706056,I|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];I=c[3528484]|0;c[2076596]=I;R=c[2417276]|0;c[3541536]=R;c[1836236]=0;P=c[3529254]|0;W=0;V=0;while(1){c[H+76+(V<<2)>>2]=P+(V<<8);U=W+1&65535;if((U&65535)>127){aa=0;ab=0;break}else{W=U;V=U&65535}}while(1){V=P+(ab<<8)|0;c[H+76+(ab+512<<2)>>2]=V;c[H+76+(ab+768<<2)>>2]=V;V=aa+1&65535;if((V&65535)>127){break}else{aa=V;ab=V&65535}}P=c[3529342]|0;c[H+588>>2]=P;V=P+256|0;c[H+592>>2]=V;W=P+512|0;c[H+596>>2]=W;U=P+768|0;c[H+600>>2]=U;X=P+1024|0;c[H+604>>2]=X;ac=P+1280|0;c[H+608>>2]=ac;ad=P+1536|0;c[H+612>>2]=ad;ae=P+1792|0;c[H+616>>2]=ae;c[H+1612>>2]=P;c[H+1616>>2]=V;c[H+1620>>2]=W;c[H+1624>>2]=U;c[H+1628>>2]=X;c[H+1632>>2]=ac;c[H+1636>>2]=ad;c[H+1640>>2]=ae;c[H+2636>>2]=P;c[H+3660>>2]=P;c[H+2640>>2]=V;c[H+3664>>2]=V;c[H+2644>>2]=W;c[H+3668>>2]=W;c[H+2648>>2]=U;c[H+3672>>2]=U;c[H+2652>>2]=X;c[H+3676>>2]=X;c[H+2656>>2]=ac;c[H+3680>>2]=ac;c[H+2660>>2]=ad;c[H+3684>>2]=ad;c[H+2664>>2]=ae;c[H+3688>>2]=ae;ae=c[2386248]|0;c[H+652>>2]=ae;ad=ae+256|0;c[H+656>>2]=ad;ac=ae+512|0;c[H+660>>2]=ac;X=ae+768|0;c[H+664>>2]=X;c[H+1676>>2]=ae;c[H+1680>>2]=ad;c[H+1684>>2]=ac;c[H+1688>>2]=X;c[H+2700>>2]=ae;c[H+3724>>2]=ae;c[H+2704>>2]=ad;c[H+3728>>2]=ad;c[H+2708>>2]=ac;c[H+3732>>2]=ac;c[H+2712>>2]=X;c[H+3736>>2]=X;c[H+668>>2]=ae;c[H+672>>2]=ad;c[H+676>>2]=ac;c[H+680>>2]=X;c[H+1692>>2]=ae;c[H+1696>>2]=ad;c[H+1700>>2]=ac;c[H+1704>>2]=X;c[H+2716>>2]=ae;c[H+3740>>2]=ae;c[H+2720>>2]=ad;c[H+3744>>2]=ad;c[H+2724>>2]=ac;c[H+3748>>2]=ac;c[H+2728>>2]=X;c[H+3752>>2]=X;X=c[2443478]|0;c[H+716>>2]=X;c[H+1740>>2]=X;c[H+2764>>2]=X;c[H+3788>>2]=X;X=c[2386504]|0;c[H+780>>2]=X;c[H+1804>>2]=X;c[H+2828>>2]=X;c[H+3852>>2]=X;X=c[2387882]|0;c[H+1036>>2]=X;ac=X+256|0;c[H+1040>>2]=ac;ad=X+512|0;c[H+1044>>2]=ad;ae=X+768|0;c[H+1048>>2]=ae;c[H+2060>>2]=X;c[H+2064>>2]=ac;c[H+2068>>2]=ad;c[H+2072>>2]=ae;c[H+3084>>2]=X;c[H+4108>>2]=X;c[H+3088>>2]=ac;c[H+4112>>2]=ac;c[H+3092>>2]=ad;c[H+4116>>2]=ad;c[H+3096>>2]=ae;c[H+4120>>2]=ae;c[H+4184>>2]=1864;c[H+4180>>2]=2962;if(!M){ae=H;gGC(ae|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=I;c[2417276]=R;c[1836236]=-1;fwR(1);ae=c[2439331]|0;ad=(ae|0)==0;if(!ad){ac=ae;gGC(9706056,ac|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];ac=c[3528485]|0;c[2076596]=ac;X=c[2417277]|0;c[3541536]=X;c[1836236]=1;U=c[3529210]|0;W=0;V=0;while(1){c[ae+76+(V<<2)>>2]=U+(V<<8);P=W+1&65535;if((P&65535)>47){af=0;ah=0;break}else{W=P;V=P&65535}}while(1){V=U+(ah<<8)|0;c[ae+76+(ah+512<<2)>>2]=V;c[ae+76+(ah+768<<2)>>2]=V;V=af+1&65535;if((V&65535)>47){break}else{af=V;ah=V&65535}}U=c[3529300]|0;c[ae+332>>2]=U;V=U+256|0;c[ae+336>>2]=V;W=U+512|0;c[ae+340>>2]=W;R=U+768|0;c[ae+344>>2]=R;c[ae+1356>>2]=U;c[ae+1360>>2]=V;c[ae+1364>>2]=W;c[ae+1368>>2]=R;c[ae+2380>>2]=U;c[ae+3404>>2]=U;c[ae+2384>>2]=V;c[ae+3408>>2]=V;c[ae+2388>>2]=W;c[ae+3412>>2]=W;c[ae+2392>>2]=R;c[ae+3416>>2]=R;c[ae+4184>>2]=490;c[ae+4180>>2]=828;if(!ad){R=ae;gGC(R|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=ac;c[2417277]=X;c[1836236]=-1;R=a[9680]|0?32e3:0;c[3542220]=11200;W=c[2113008]|0;if((W|0)==0){gGz(14168888,0,252);c[3542223]=R;c[3542224]=0;c[3542225]=438;c[3542226]=2774;c[3542227]=0;c[3542234]=~~((+(R|0)*32768.0*8.0+312500.0)/625.0e3);V=31;ai=32767.0;while(1){c[14169012+(V<<2)>>2]=~~(ai+.5);U=V-1|0;if((U|0)>0){V=U;ai=ai/1.188502227}else{break}}c[3542253]=0;h[1771269]=1.0;h[1771270]=1.0;h[1771271]=1.0;c[3542574]=3;c[3542575]=3;c[3542576]=3;mB(0);V=(c[2113008]|0)+1|0;c[2113008]=V;aj=V;ak=a[9680]|0?32e3:0}else{aj=W;ak=R}c[3542220]=11200;if((aj|0)==1){gGz(14169140,0,252);c[3542286]=ak;c[3542287]=2486;c[3542288]=1154;c[3542289]=0;c[3542290]=0;c[3542297]=~~((+(ak|0)*32768.0*8.0+312500.0)/625.0e3);V=31;ai=32767.0;while(1){c[14169264+(V<<2)>>2]=~~(ai+.5);X=V-1|0;if((X|0)>0){V=X;ai=ai/1.188502227}else{break}}c[3542316]=0;h[1771272]=1.0;h[1771273]=1.0;h[1771274]=1.0;c[3542577]=3;c[3542578]=3;c[3542579]=3;mB(1);c[2113008]=(c[2113008]|0)+1}h[1771269]=.25;c[3542574]=3;h[1771270]=.25;c[3542575]=3;h[1771271]=.25;c[3542576]=3;h[1771272]=.25;c[3542577]=3;h[1771273]=.25;c[3542578]=3;h[1771274]=.25;c[3542579]=3;V=c[642608+(c[2436]<<2)>>2]|0;R=c[V+128>>2]|0;if((c[V+52>>2]&4|0)==0){c[2113068]=R;W=c[V+132>>2]|0;c[2113070]=W;c[2443814]=R;c[2440436]=W;al=R;am=W}else{c[2113070]=R;W=c[V+132>>2]|0;c[2113068]=W;c[2440436]=R;c[2443814]=W;al=W;am=R}R=ag(al<<1,am)|0;W=gGq(R)|0;c[2112926]=W;if((W|0)!=0){gGz(W|0,0,R|0)}a[9624704]=0;R=c[2414744]|0;gGz(R|0,0,(c[2411782]|0)-R|0);R=c[2439330]|0;W=(R|0)==0;if(!W){V=R;gGC(9706056,V|0,76)|0}V=c[2438118]|0;c[2433530]=V;X=c[3528484]|0;c[2076596]=X;ac=c[2417276]|0;c[3541536]=ac;c[1836236]=0;gGz(9706056,0,76);if(!W){W=R;gGC(W|0,9706056,76)|0}c[2438118]=V;c[3528484]=X;c[2417276]=ac;c[1836236]=-1;ac=c[2439331]|0;X=(ac|0)==0;if(!X){V=ac;gGC(9706056,V|0,76)|0}V=c[2438119]|0;c[2433530]=V;W=c[3528485]|0;c[2076596]=W;R=c[2417277]|0;c[3541536]=R;c[1836236]=1;gGz(9706056,0,76);if(!X){X=ac;gGC(X|0,9706056,76)|0}c[2438119]=V;c[3528485]=W;c[2417277]=R;c[1836236]=-1;mB(0);mB(1);O=0;i=e;return O|0}}while(0);c[2415036]=0;O=1;i=e;return O|0}function dqp(){var a=0,b=0,d=0,e=0;c[2113070]=0;c[2113068]=0;a=c[2112926]|0;if((a|0)!=0){gGr(a);c[2112926]=0}fwZ();c[2113008]=0;c[2076598]=0;c[2383582]=0;a=c[2415036]|0;b=0;while(1){if((b|0)>=1024){d=75331;break}e=9638528+(b<<2)|0;if((c[e>>2]|0)==(a|0)){break}else{b=b+1|0}}if((d|0)==75331){c[2415036]=0;return 0}gGr(a);c[e>>2]=0;c[2415036]=0;return 0}function dqq(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((a[9624704]|0)!=0){a[9624704]=0;d=c[2414744]|0;gGz(d|0,0,(c[2411782]|0)-d|0);d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;h=c[2417276]|0;c[3541536]=h;c[1836236]=0;gGz(9706056,0,76);if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=h;c[1836236]=-1;h=c[2439331]|0;g=(h|0)==0;if(!g){f=h;gGC(9706056,f|0,76)|0}f=c[2438119]|0;c[2433530]=f;e=c[3528485]|0;c[2076596]=e;d=c[2417277]|0;c[3541536]=d;c[1836236]=1;gGz(9706056,0,76);if(!g){g=h;gGC(g|0,9706056,76)|0}c[2438119]=f;c[3528485]=e;c[2417277]=d;c[1836236]=-1;mB(0);mB(1)}d=c[2388386]|0;e=a[d]|0;if((e&255)>180){a[9624704]=0;f=c[2414744]|0;gGz(f|0,0,(c[2411782]|0)-f|0);f=c[2439330]|0;g=(f|0)==0;if(!g){h=f;gGC(9706056,h|0,76)|0}h=c[2438118]|0;c[2433530]=h;i=c[3528484]|0;c[2076596]=i;j=c[2417276]|0;c[3541536]=j;c[1836236]=0;gGz(9706056,0,76);if(!g){g=f;gGC(g|0,9706056,76)|0}c[2438118]=h;c[3528484]=i;c[2417276]=j;c[1836236]=-1;j=c[2439331]|0;i=(j|0)==0;if(!i){h=j;gGC(9706056,h|0,76)|0}h=c[2438119]|0;c[2433530]=h;g=c[3528485]|0;c[2076596]=g;f=c[2417277]|0;c[3541536]=f;c[1836236]=1;gGz(9706056,0,76);if(!i){i=j;gGC(i|0,9706056,76)|0}c[2438119]=h;c[3528485]=g;c[2417277]=f;c[1836236]=-1;mB(0);mB(1);f=c[2388386]|0;k=f;l=a[f]|0}else{k=d;l=e}a[k]=l+1&255;a[9550737]=0;a[9550736]=0;l=0;k=0;e=0;do{k=((a[9634080+l|0]&1)<<l|k&255)&255;e=((a[9631864+l|0]&1)<<l|e&255)&255;l=l+1|0;}while((l|0)<8);a[9550736]=k;a[9550737]=e;e=0;k=0;l=0;while(1){d=256-l|0;f=(58333-k|0)/(d|0)|0;g=c[2439330]|0;if((g|0)!=0){h=g;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;h=c[2438118]|0;c[2433530]=h;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;do{if((f|0)<1){m=0}else{if((a[g+4188|0]|0)==0){i=gfc(f)|0;c[2433530]=(c[2433530]|0)+i;m=i;break}else{c[2433530]=h+f;m=f;break}}}while(0);f=m+k|0;if((l|0)==255){a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0}h=c[1836236]|0;g=c[9757320+(h<<2)>>2]|0;if((g|0)!=0){i=g;gGC(i|0,9706056,76)|0}c[9752472+(h<<2)>>2]=c[2433530];c[14113936+(h<<2)>>2]=c[2076596];c[9669104+(h<<2)>>2]=c[3541536];c[1836236]=-1;h=(10416-e|0)/(d|0)|0;i=c[2439331]|0;if((i|0)!=0){g=i;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;g=c[2438119]|0;c[2433530]=g;c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;do{if((h|0)<1){n=0}else{if((a[i+4188|0]|0)==0){j=gfc(h)|0;c[2433530]=(c[2433530]|0)+j;n=j;break}else{c[2433530]=g+h;n=h;break}}}while(0);if((l&63|0)==63){a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0}h=c[1836236]|0;g=c[9757320+(h<<2)>>2]|0;if((g|0)!=0){i=g;gGC(i|0,9706056,76)|0}c[9752472+(h<<2)>>2]=c[2433530];c[14113936+(h<<2)>>2]=c[2076596];c[9669104+(h<<2)>>2]=c[3541536];c[1836236]=-1;h=l+1|0;if((h|0)<256){e=n+e|0;k=f;l=h}else{break}}l=c[2112964]|0;if((l|0)!=0){mF(9756448,l,a[9688]|0?534:0,0)}if((c[2112968]|0)==0){return 0}dqr()|0;return 0}function dqr(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;if((a[9547760]|0)!=0){e=c[3530108]|0;f=0;do{g=f&255;if((f|0)<512){h=f>>>5;if((f&1|0)==0){i=0}else{i=f>>>2&7}j=(((f&2|0)==0?0:h&7)|h&8|i)&255}else{j=g}g=j&255;h=g>>>1;k=h&4^255;c[e+(f<<2)>>2]=(k&-(g>>>2&1))<<3&2016|(-(h&1)|0)>>>3&31|(k&-(g&1))<<8&63488;f=f+1|0;}while((f|0)<520)}f=c[2112926]|0;e=c[2113068]|0;j=c[2113070]|0;gGz(f|0,0,ag(e<<1,j)|0);dqz(0);i=c[2386504]|0;g=c[3528748]|0;k=c[3530656]|0;h=0;do{l=d[i+(h|3)|0]|0;m=d[i+h|0]|0;n=h|2;o=(d[i+n|0]|0)>>>6&1;p=(d[i+(n-4)|0]|0)>>>7;if((a[g]|0)==0){q=p;r=o;s=240-m|0;t=l}else{q=p^1;r=o^1;s=m;t=248-l|0}l=t+2|0;m=s-17|0;o=r*7|0;p=q*15|0;n=d[i+(h|1)|0]<<7;u=0;do{v=m+u|0;w=(u^p)<<3;x=(v|0)<(j|0);y=ag(e,v)|0;z=0;do{A=l+z|0;B=a[k+((z^o|w)+n)|0]|0;C=B&255;do{if((A|v|0)>-1&x){if((A|0)>=(e|0)|B<<24>>24==0){break}b[f+(y+A<<1)>>1]=C|512}}while(0);z=z+1|0;}while((z|0)<8);u=u+1|0;}while((u|0)<16);h=h+4|0;}while((h|0)<256);dqz(1);R8(c[3530108]|0);return 0}function dqs(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;d=i;i=i+48|0;e=d|0;f=d+32|0;g=(b|0)==0;if(!g){c[b>>2]=169624}if((a&96|0)==0){i=d;return 0}gGz(f|0,0,12);h=c[2414744]|0;c[f>>2]=h;c[f+4>>2]=(c[2411782]|0)-h;c[f+12>>2]=162152;gj[c[2076592]&4095](f)|0;fw$(a);f=d+16|0;if((a&64|0)==0){i=d;return 0}do{if(!g){if((c[b>>2]|0)>=169110){break}c[b>>2]=169110}}while(0);if((c[2113008]|0)<=0){i=d;return 0}b=e|0;g=e+4|0;a=e+8|0;h=e+12|0;j=0;do{cC(f|0,531144,(k=i,i=i+8|0,c[k>>2]=j,k)|0)|0;i=k;c[b>>2]=14168888+(j*252|0);c[g>>2]=252;c[a>>2]=0;c[h>>2]=f;gj[c[2076592]&4095](e)|0;j=j+1|0;}while((j|0)<(c[2113008]|0));i=d;return 0}function dqt(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3064036+(b*112|0)>>2];c[a+104>>2]=c[3064040+(b*112|0)>>2];c[a+108>>2]=c[3064044+(b*112|0)>>2];d=0;return d|0}function dqu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=3063936+(b*112|0);e=0;return e|0}function dqv(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2335260+(b*112|0)>>2];c[a+104>>2]=c[2335264+(b*112|0)>>2];c[a+108>>2]=c[2335268+(b*112|0)>>2];d=0;return d|0}function dqw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=2335160+(b*112|0);e=0;return e|0}function dqx(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3530744+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dqy(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6142472+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dqz(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=c[2387882]|0;f=c[2386248]|0;g=c[2405108]|0;h=c[3528748]|0;i=c[2443478]|0;j=c[2112926]|0;k=c[3530892]|0;l=0;do{m=d[e+l|0]|0;do{if((m>>>7|0)==(b|0)){n=(d[g]|0)<<8|(d[f+l|0]|0);o=m&127;p=l>>>2&248;q=p^248;r=a[h]|0;s=(l<<3&248)-(d[i+(30-(q>>>3)+(r&255))|0]|0)|0;t=(s|0)<-7?s+256|0:s;if(r<<24>>24==0){Sr(j,n,q,t-16|0,o,2,0,0,k);break}else{Sx(j,n,p,232-t|0,o,2,0,0,k);break}}}while(0);l=l+1|0;}while((l|0)<1024);return}function dqA(e){e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;switch(e&65535|0){case 14339:{f=a[9658032]|0;return f|0};case 14337:{f=a[9625304]|0;return f|0};case 14341:{if(a[818192]|0){f=0;return f|0}if(a[6517848]|0){a[9626928]=-1;a[9752952]=0;a[9734344]=0;f=0;return f|0}else{f42();f=0;return f|0}break};case 14336:{f=a[9625352]|0;return f|0};case 14340:{if(a[818192]|0){f=0;return f|0}if(!(a[6517848]|0)){a[7396832]=0;f=c[3529006]&255;return f|0}L91631:do{if((a[9752952]|0)==0){e=a[9734344]|0;if((e&255)<6){g=e+1&255;h=a[14114264+(e&255)|0]|0;break}else{f=1;return f|0}}else{a[9752952]=0;a[9734344]=0;e=a[14114264]|0;switch(e&255|0){case 38:{i=d[14114265]|0;a[14114264]=1;a[14114265]=a[595968+i|0]|0;g=1;h=1;break L91631;break};case 68:{i=a[14114267]|0;j=(d[596224+(a[14114266]&3)|0]|0)+((i<<24>>24==0)<<31>>31)+((i&255)>>>2)|0;if((j|0)>33){k=j+192&255}else{k=j&255}a[14114264]=1;a[14114265]=k;g=1;h=1;break L91631;break};case 16:{j=a[638664]|0?-123:0;a[14114264]=j;g=1;h=j;break L91631;break};case 64:{j=d[14114266]<<1;if((d[14114267]|0)<5){i=j+24|0;l=i>>>0>64?64:i&255}else{i=j+6|0;l=i>>>0>32?32:i&255}a[14114264]=1;a[14114265]=l;g=1;h=1;break L91631;break};case 51:{i=d[14114266]|0;a[14114264]=1;a[14114265]=a[595784+(i&15)|0]|0;g=1;h=1;break L91631;break};case 65:{a[14114264]=2;a[14114265]=32;a[14114266]=120;g=1;h=2;break L91631;break};case 85:{i=a[14114268]&3;a[14114264]=3;j=b[595960+(i<<1)>>1]|0;a[14114266]=(j&65535)>>>8&255;a[14114267]=j&255;g=1;h=3;break L91631;break};case 66:{j=a[14114266]&3;i=c[595800+((j<<3)+(d[14114267]|0)+((j>>>0>1)<<31>>31)<<2)>>2]|0;a[14114264]=1;a[14114265]=i&255;g=1;h=1;break L91631;break};default:{g=1;h=e;break L91631}}}}while(0);a[9734344]=g;f=h;return f|0};case 14338:{do{if(a[6517848]|a[818192]){m=1;n=75470}else{h=a[7190960]|0;g=h&1^1;if(a[7396832]|0){if(h){o=0;break}else{m=g;n=75470;break}}else{m=g|2;n=75470;break}}}while(0);if((n|0)==75470){o=(m<<4)-16&255}f=(((a[9625264]|0)+o&255)+(a[9658033]|0)&255)+(a[638024]|0?64:0)&255;return f|0};default:{f=0;return f|0}}return 0}function dqB(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;switch(d&65535|0){case 14341:{d=c[3527424]|0;f=c[2443776]|0;g=((e&1)<<14|32768)-16384|0;h=64;i=64;while(1){j=d+(g+(i<<8))|0;c[f+68+(i<<2)>>2]=j;c[f+68+(i+512<<2)>>2]=j;j=h+1&65535;if((j&65535)>127){break}else{h=j;i=j&65535}}return};case 14336:{a[14119224]=e;return};case 14337:{a[14119225]=e;return};case 14340:{if(a[818192]|0){return}if(!(a[6517848]|0)){c[3527076]=e&255;a[7190960]=1;if((c[2415208]|0)==1){return}c[2415208]=1;b[4830412]=b[4830412]|1;return}a[9734344]=0;i=a[9626928]|0;if(i<<24>>24<0){a[9626928]=0;a[9752952]=1;a[14114264]=e;return}h=i+1&255;a[9626928]=h;f=a[(c[2430460]|0)+(i<<24>>24)|0]^e;if((h<<24>>24|0)==((a[697936]|0?42:0)|0)){a[9626928]=0}h=a[9752952]|0;if((h&255)>=6){return}a[9752952]=h+1&255;a[14114264+(h&255)|0]=f;return};case 14338:{a[9758224]=e;c[3528554]=0;f43(c[2433592]|0);c[2113158]=c[9731360+(c[3528554]<<2)>>2];f44(0);f45(0)|0;a[9660786]=0;f45(0)|0;e=c[3528554]|0;f=(c[2433592]|0)+(e*3148|0)|0;if((f|0)!=0){h=f;gGC(h|0,9660752,48)|0}c[9731360+(e<<2)>>2]=c[2113158];c[3528554]=-1;return};default:{return}}}function dqC(b){b=b|0;return(b<<16>>16==4096?a[9758224]|0:0)|0}function dqD(b,e){b=b|0;e=e|0;var f=0,g=0,h=0;f=b&65535;if((f|0)==10241){b=c[3540986]|0;g=c[b+5876>>2]|0;if((g|0)!=0){gg[g&4095](c[b+5880>>2]|0,0)}lH(b,d[b+5885|0]|0,e&255);return}else if((f|0)==8192){b=(e&255)<<13;g=b-360448|0;h=(b-344064|0)>131072?4096:16384;if((g|0)<=-1){return}if((h+g|0)>=131072){return}c[2438076]=g<<15;c[2438074]=(h>>>1)+g;a[9752288]=4;a[4447320]=1;return}else if((f|0)==10240){a[(c[3540986]|0)+5885|0]=e;return}else{return}}function dqE(b){b=b|0;var c=0,d=0;c=b&2047;if((c|0)==1){d=a[9628440]&a[14108288];return d|0}else if((c|0)==0){b=a[9628448]|0;d=a[14116016]&~b|b&a[14108296];return d|0}else if((c|0)==2){c=a[7190960]&1;b=a[9628432]|0;d=(a[7396832]|0?c:c|2)&~b|b&a[14108280];return d|0}else{d=0;return d|0}return 0}function dqF(b,e){b=b|0;e=e|0;switch(b&2047|0){case 6:{a[9628432]=e;return};case 2:{a[14108280]=e;return};case 4:{a[9628448]=e;return};case 5:{a[9628440]=e;return};case 1:{b=a[9628440]|0;do{if((b&2)!=0){if((e&2)!=0){break}if((a[14108288]&2)==0){break}a[14116016]=c[3527076]&255;if(!(a[7190960]|0)){break}if((c[2415208]|0)!=0){c[2415208]=0}a[7190960]=0}}while(0);do{if((b&4)!=0){if((e&4)==0){break}if((a[14108288]&4)!=0){break}c[3529006]=d[14108296]|0;a[7396832]=1}}while(0);a[14108288]=e;return};case 0:{a[14108296]=e;return};default:{return}}}function dqG(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>25){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7419060+(b*112|0)>>2];c[a+104>>2]=c[7419064+(b*112|0)>>2];c[a+108>>2]=c[7419068+(b*112|0)>>2];d=0;return d|0}function dqH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<26&(d|0)==0)){e=1;return e|0}c[a>>2]=7418960+(b*112|0);e=0;return e|0}function dqI(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6935440+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dqJ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>28){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7445576+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dqK(){return dqU(1)|0}function dqL(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;fvR();c[2113160]=0;d=c[2433592]|0;if((d|0)!=0){gGr(d);c[2433592]=0}if(!(a[6517848]|a[818192])){c[2443666]=0;c[2385780]=0;c[3528996]=0}d=a[7452592]|0;if(d){e=0;f=d&1;while(1){d=14163944+(e<<2)|0;g=c[d>>2]|0;h=c[2113006]|0;if((h|0)==0){i=75627}else{j=h-1|0;c[2113006]=j;if((j|0)==0){i=75627}}if((i|0)==75627){i=0;c[2383474]=0}if((g|0)==0){k=f}else{gGr(g);k=a[7452592]&1}c[d>>2]=0;d=e+1|0;if((d|0)<(k|0)){e=d;f=k}else{break}}}a[7452592]=0;c[2438222]=0;c[2433520]=0;c[2406670]=0;c[3528466]=0;k=c[2406686]|0;if((k|0)!=0){gGr(k);c[2406686]=0}c[2432974]=0;c[2113070]=0;c[2113068]=0;k=c[2112926]|0;if((k|0)!=0){gGr(k);c[2112926]=0}k=c[2426788]|0;f=0;while(1){if((f|0)>=1024){break}l=9638528+(f<<2)|0;if((c[l>>2]|0)==(k|0)){i=75638;break}else{f=f+1|0}}if((i|0)==75638){gGr(k);c[l>>2]=0}c[2426788]=0;a[638664]=0;c[2430460]=0;a[697936]=0;gGz(14114264,0,6);a[9752952]=0;a[9734344]=0;a[9626928]=0;a[818192]=0;a[6517848]=0;c[3527076]=0;c[3529006]=0;a[7190960]=0;a[7396832]=0;a[9628448]=0;a[9628440]=0;a[9628432]=0;a[14108296]=0;a[14108288]=0;a[14108280]=0;a[14116016]=0;a[638024]=0;b[7059612]=0;a[9758224]=0;return 0}function dqM(){var e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0.0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0.0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;if((a[9624696]|0)!=0){dqX()}a[9625304]=-1;a[9625352]=-1;a[9625264]=-100;e=0;f=-1;g=-1;i=-100;do{f=(f&255)-((a[9759248+e|0]&1)<<e)&255;g=(g&255)-((a[9759056+e|0]&1)<<e)&255;i=(i&255)-((a[9758872+e|0]&1)<<e)&255;e=e+1|0;}while((e|0)<8);a[9625352]=f;a[9625304]=g;a[9625264]=i;a[6518312]=1;a[6518136]=1;a[6517888]=1;a[638024]=0;i=c[2113166]|0;if((i|0)>0){gGz(9731400,0,((i|0)>1?i<<2:4)|0)}c[2113164]=0;i=c[2113160]|0;if((i|0)>0){gGz(9731360,0,((i|0)>1?i<<2:4)|0)}c[2113158]=0;i=0;g=0;f=0;while(1){c[3528556]=0;e=c[2433594]|0;c[2443776]=e;L91837:do{if((e|0)!=0){j=e|0;gGC(9660952,j|0,52)|0;switch(a[9660952]|0){case 0:{c[2309668]=638960;break L91837;break};case 5:{c[2309668]=7354992;break L91837;break};case 1:{c[2309668]=634096;break L91837;break};case 2:{c[2309668]=638960;break L91837;break};case 3:{c[2309668]=639984;break L91837;break};case 4:{c[2309668]=7356016;break L91837;break};default:{break L91837}}}}while(0);c[2113164]=c[2432850];j=f+1|0;k=((ag(a[6518312]|0?25e3:0,j)|0)/262|0)-g|0;l=gj[c[e+52>>2]&4095](k)|0;c[2113164]=(c[2113164]|0)+l;k=l+g|0;do{if((f|0)==131|(f|0)==234){l=(c[2384404]|0)==0;c[2384404]=l&1;m=c[(c[2443776]|0)+64>>2]|0;if(l){gg[m&4095](32,1);l=c[(c[2443776]|0)+52>>2]|0;gj[l&4095](0)|0;gg[c[(c[2443776]|0)+64>>2]&4095](32,0);l=c[(c[2443776]|0)+52>>2]|0;gj[l&4095](0)|0;break}else{gg[m&4095](0,1);m=c[(c[2443776]|0)+52>>2]|0;gj[m&4095](0)|0;gg[c[(c[2443776]|0)+64>>2]&4095](0,0);m=c[(c[2443776]|0)+52>>2]|0;gj[m&4095](0)|0;break}}else if((f|0)==182){a[638024]=1}}while(0);e=c[2443776]|0;if((e|0)!=0){m=e|0;gGC(m|0,9660952,52)|0}c[9731400+(c[3528556]<<2)>>2]=c[2113164];c[2443776]=0;c[3528556]=-1;if(a[6517848]|a[818192]){n=i}else{n=(f4Y(((ag(a[6517888]|0?5e4:0,j)|0)/262|0)-i|0)|0)+i|0}c[3528554]=0;f43(c[2433592]|0);c[2113158]=c[9731360+(c[3528554]<<2)>>2];U1(ag(a[6518136]|0?95:0,f)|0);m=c[3528554]|0;o=c[2433592]|0;e=o+(m*3148|0)|0;if((e|0)!=0){l=e;gGC(l|0,9660752,48)|0}c[9731360+(m<<2)>>2]=c[2113158];c[3528554]=-1;if((j|0)<262){i=n;g=k;f=j}else{break}}c[3528554]=0;f43(o);c[2113158]=c[9731360+(c[3528554]<<2)>>2];o=a[6518136]|0?25e3:0;f=gGU(o,0,2048e6,0)|0;g=c[2438222]|0;n=gGS(f,K,g,(g|0)<0|0?-1:0)|0;g=n;U1(o);o=c[2443824]|0;if((o|0)<1073676288){c[2443824]=o-g}o=c[2443825]|0;if((o|0)<1073676288){c[2443825]=o-g}o=(c[3528506]|0)-g|0;c[3528506]=(o|0)<0?0:o;o=c[3528554]|0;g=c[2433592]|0;n=g+(o*3148|0)|0;if((n|0)!=0){f=n;gGC(f|0,9660752,48)|0}c[9731360+(o<<2)>>2]=c[2113158];c[3528554]=0;f43(g);c[2113158]=c[9731360+(c[3528554]<<2)>>2];gg[c[3542114]&4095](c[2112964]|0,a[9688]|0?534:0);if(a[4447320]&a[9688]){g=c[2438070]|0;o=c[2443784]|0;f=c[2438074]|0;n=a[4447304]|0?3:0;i=(n&1|0)==0;m=(n&2|0)==0;p=+h[555914];n=534;l=c[2112964]|0;e=a[9752288]|0;q=c[2438078]|0;r=c[2438080]|0;s=c[2438076]|0;while(1){t=(d[g+(s>>>15)|0]|0)>>>((e&255)>>>0);u=e^4;do{if(e<<24>>24==0){v=o+s|0;c[2438076]=v;if(v>>>15>>>0<f>>>0){w=1;x=v;break}a[4447320]=0;w=0;x=v}else{w=1;x=s}}while(0);j=r+(c[14101464+((q>>15<<4|t&15)<<2)>>2]|0)|0;do{if((j|0)>2047){y=8188.0;z=2047}else{if((j|0)<-2048){y=-8192.0;z=-2048;break}y=+((j&65535)<<2<<16>>16|0);z=j}}while(0);j=(ag(o,c[7045224+((t&7)<<2)>>2]|0)|0)+q|0;k=j>>15;if((k|0)>48){A=1572864}else{A=(k|0)<0?0:j}if(i){B=0}else{B=~~(y*p)}if(m){C=0}else{C=~~(y*p)}j=(b[l>>1]|0)+B|0;if((j|0)<-32768){D=-32768}else{D=(j|0)>32767?32767:j&65535}j=l+2|0;k=(b[j>>1]|0)+C|0;if((k|0)<-32768){E=-32768}else{E=(k|0)>32767?32767:k&65535}b[l>>1]=D;b[j>>1]=E;j=n-1|0;if(w&(j|0)>0){n=j;l=l+4|0;e=u;q=A;r=z;s=x}else{break}}a[9752288]=u;c[2438078]=A;c[2438080]=z}z=c[3528554]|0;A=(c[2433592]|0)+(z*3148|0)|0;if((A|0)!=0){u=A;gGC(u|0,9660752,48)|0}c[9731360+(z<<2)>>2]=c[2113158];c[3528554]=-1;if((c[2112968]|0)==0){return 0}z=c[2112926]|0;gGz(z|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);u=c[2438770]|0;A=c[2438764]|0;x=c[3530106]|0;s=0;do{r=a[u+s|0]|0;q=a[A+s|0]|0;e=(((q&255)<<8|r&255)&65535)>>>4;c[x+(s<<2)>>2]=((q<<4|q&8)&255)>>>3|((r<<4|r&8)&255)<<8&63488|((e<<4&255|e&12)&255)<<3&2016;s=s+1|0;}while((s|0)<256);s=256-(d[14119225]<<8&768|d[14119224])|0;A=c[2443356]|0;u=c[2405822]|0;e=0;r=0;while(1){q=e<<4;if((q-1|0)>>>0<223){l=0;n=r;while(1){w=d[A+(n+1024)|0]|0;E=d[A+n|0]|0;D=w>>>5;C=(l<<4)+s|0;B=(C|0)<-16?C+1024|0:C;C=B-8|0;m=u+(w<<16&458752)|0;if((B-9|0)>>>0<223){Sy(z,E,C,q,D,3,192,m)}else{Sz(z,E,C,q,D,3,192,m)}m=l+1|0;if((m|0)<64){l=m;n=n+1|0}else{break}}}else{n=0;l=r;while(1){t=d[A+(l+1024)|0]|0;m=(n<<4)+s|0;Sz(z,d[A+l|0]|0,((m|0)<-16?m+1024|0:m)-8|0,q,t>>>5,3,192,u+(t<<16&458752)|0);t=n+1|0;if((t|0)<64){n=t;l=l+1|0}else{break}}}l=e+1|0;if((l|0)<16){e=l;r=r+64|0}else{break}}r=c[2443428]|0;e=r+384|0;u=c[3529588]|0;A=r;do{r=240-(d[A]|0)|0;L91926:do{if((r|0)>15){s=d[A+1|0]|0;l=a[A+3|0]|0;n=l&255;q=d[A+2|0]|0;t=s&15;m=s>>>4&3;D=s&64;C=(l&255)>248?n|-256:n;n=C-8|0;L91928:do{if((s&128|0)==0){F=r+16|0;G=q;H=C-25|0}else{l=q&254;E=C-25|0;B=r+16|0;do{if(E>>>0<207){if((r+15|0)>>>0>=223){break}w=q|1;i=u+(t<<16)|0;if((D|0)==0){SG(z,w,n,B,m,3,0,128,i);F=r;G=l;H=E;break L91928}else{SI(z,w,n,B,m,3,0,128,i);F=r;G=l;H=E;break L91928}}}while(0);i=q|1;w=u+(t<<16)|0;if((D|0)==0){SH(z,i,n,B,m,3,0,128,w);F=r;G=l;H=E;break}else{SJ(z,i,n,B,m,3,0,128,w);F=r;G=l;H=E;break}}}while(0);do{if(H>>>0<207){if((F-1|0)>>>0>=223){break}q=u+(t<<16)|0;if((D|0)==0){SG(z,G,n,F,m,3,0,128,q);break L91926}else{SI(z,G,n,F,m,3,0,128,q);break L91926}}}while(0);q=u+(t<<16)|0;if((D|0)==0){SH(z,G,n,F,m,3,0,128,q);break}else{SJ(z,G,n,F,m,3,0,128,q);break}}}while(0);A=A+4|0;}while(A>>>0<e>>>0);e=c[2443354]|0;A=c[2406536]|0;F=0;G=0;while(1){u=F<<3;if((u-1|0)>>>0<231){H=0;r=G;while(1){q=d[e+(r+1024)|0]|0;C=q<<8&768|d[e+r|0];s=q>>>6;q=H<<3;w=q-8|0;if((q-9|0)>>>0<231){Sq(z,C,w,u,s,3,0,0,A)}else{Sr(z,C,w,u,s,3,0,0,A)}s=H+1|0;if((s|0)<32){H=s;r=r+1|0}else{break}}}else{r=0;H=G;while(1){s=d[e+(H+1024)|0]|0;Sr(z,s<<8&768|d[e+H|0],(r<<3)-8|0,u,s>>>6,3,0,0,A);s=r+1|0;if((s|0)<32){r=s;H=H+1|0}else{break}}}H=F+1|0;if((H|0)<32){F=H;G=G+32|0}else{break}}R8(x);return 0}function dqN(a,b){a=a|0;b=b|0;var d=0,e=0;d=i;i=i+16|0;e=d|0;if((b|0)!=0){c[b>>2]=169622}if((a&32|0)==0){i=d;return 0}gGz(e|0,0,12);a=c[2405696]|0;c[e>>2]=a;c[e+4>>2]=(c[2411780]|0)-a;c[e+12>>2]=162152;gj[c[2076592]&4095](e)|0;i=d;return 0}function dqO(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>25){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7260548+(b*112|0)>>2];c[a+104>>2]=c[7260552+(b*112|0)>>2];c[a+108>>2]=c[7260556+(b*112|0)>>2];d=0;return d|0}function dqP(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<26&(d|0)==0)){e=1;return e|0}c[a>>2]=7260448+(b*112|0);e=0;return e|0}function dqQ(){return dqU(2)|0}function dqR(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>24){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7286844+(b*112|0)>>2];c[a+104>>2]=c[7286848+(b*112|0)>>2];c[a+108>>2]=c[7286852+(b*112|0)>>2];d=0;return d|0}function dqS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<25&(d|0)==0)){e=1;return e|0}c[a>>2]=7286744+(b*112|0);e=0;return e|0}function dqT(){return dqU(0)|0}function dqU(b){b=b|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,V=0,W=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0;e=i;i=i+3120|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;B=e+1200|0;C=e+1312|0;D=e+1320|0;E=e+1432|0;F=e+1440|0;G=e+1552|0;H=e+1560|0;I=e+1672|0;J=e+1680|0;K=e+1792|0;L=e+1800|0;M=e+1912|0;N=e+1920|0;O=e+2032|0;P=e+2040|0;Q=e+2152|0;R=e+2160|0;S=e+2272|0;T=e+2280|0;V=e+2392|0;W=e+2400|0;Y=e+2512|0;Z=e+2520|0;_=e+2632|0;$=e+2640|0;aa=e+2752|0;ab=e+2760|0;ac=e+2872|0;ad=e+2880|0;ae=e+2992|0;af=e+3e3|0;ah=e+3112|0;c[2426788]=0;c[3527424]=0;c[3527376]=65536;c[2443516]=98304;c[3527482]=100352;c[2405696]=231424;c[3527432]=231424;c[3527382]=237568;c[2443518]=241664;c[2443428]=241776;c[2443356]=243824;c[2443354]=245872;c[2438770]=247920;c[2438764]=248176;c[2411780]=248432;c[2406536]=248432;c[2405822]=313968;c[3529588]=838256;c[3530106]=1886832;ai=0;while(1){if((ai|0)>=1024){break}aj=9638528+(ai<<2)|0;if((c[aj>>2]|0)==0){ak=75777;break}else{ai=ai+1|0}}do{if((ak|0)==75777){ai=gGq(1887856)|0;c[aj>>2]=ai;if((ai|0)==0){break}c[2426788]=ai;gGz(ai|0,0,1887856);c[3527424]=ai;c[3527376]=ai+65536;c[2443516]=ai+98304;c[3527482]=ai+100352;al=ai+231424|0;c[2405696]=al;c[3527432]=al;c[3527382]=ai+237568;c[2443518]=ai+241664;c[2443428]=ai+241776;c[2443356]=ai+243824;c[2443354]=ai+245872;c[2438770]=ai+247920;c[2438764]=ai+248176;al=ai+248432|0;c[2411780]=al;c[2406536]=al;c[2405822]=ai+313968;c[3529588]=ai+838256;c[3530106]=ai+1886832;c[2414328]=ai+1887856;ai=0;while(1){if((ai|0)>=1024){am=0;break}an=9638528+(ai<<2)|0;if((c[an>>2]|0)==0){ak=75782;break}else{ai=ai+1|0}}do{if((ak|0)==75782){ai=gGq(393216)|0;c[an>>2]=ai;if((ai|0)==0){am=0;break}gGz(ai|0,0,393216);am=ai}}while(0);c[3529538]=am;ai=c[3527424]|0;if((c[3542200]|0)==0){ao=1;i=e;return ao|0}al=af+108|0;c[al>>2]=0;ap=af+100|0;c[ap>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](af,0)|0;do{if((c[al>>2]|0)!=0){aq=c[ap>>2]|0;c[ah>>2]=9534384;ar=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ar&16383](ah,0,0)|0;if((aq|0)<1){ao=1;i=e;return ao|0}if((gzL(ai,0,0)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ai=(c[3527424]|0)+32768|0;if((c[3542200]|0)==0){ao=1;i=e;return ao|0}ap=ad+108|0;c[ap>>2]=0;al=ad+100|0;c[al>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](ad,1)|0;do{if((c[ap>>2]|0)!=0){aq=c[al>>2]|0;c[ae>>2]=9534384;ar=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ar&16383](ae,1,0)|0;if((aq|0)<1){ao=1;i=e;return ao|0}if((gzL(ai,0,1)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ai=c[3527376]|0;if((c[3542200]|0)==0){ao=1;i=e;return ao|0}al=ab+108|0;c[al>>2]=0;ap=ab+100|0;c[ap>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](ab,2)|0;do{if((c[al>>2]|0)!=0){aq=c[ap>>2]|0;c[ac>>2]=9534384;ar=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ar&16383](ac,2,0)|0;if((aq|0)<1){ao=1;i=e;return ao|0}if((gzL(ai,0,2)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ai=c[3529538]|0;if((c[3542200]|0)==0){ao=1;i=e;return ao|0}ap=$+108|0;c[ap>>2]=0;al=$+100|0;c[al>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383]($,3)|0;do{if((c[ap>>2]|0)!=0){aq=c[al>>2]|0;c[aa>>2]=9534384;ar=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ar&16383](aa,3,0)|0;if((aq|0)<1){ao=1;i=e;return ao|0}if((gzL(ai,0,3)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ai=c[3529538]|0;al=c[2406536]|0;ap=0;do{aq=ap<<6;gGz(al+aq|0,0,64);ar=ap<<8;as=ar|2;at=0;do{au=as+(c[1238464+(at<<2)>>2]|0)|0;av=(at<<3)+aq|0;aw=0;do{ax=au+(c[6964280+(aw<<2)>>2]|0)|0;if((d[ai+((ax|0)/8|0)|0]&128>>>((ax&7)>>>0)|0)!=0){ax=al+(av+aw)|0;a[ax]=a[ax]|4}aw=aw+1|0;}while((aw|0)<8);at=at+1|0;}while((at|0)<8);at=ar|4;as=0;do{aw=at+(c[1238464+(as<<2)>>2]|0)|0;av=(as<<3)+aq|0;au=0;do{ax=aw+(c[6964280+(au<<2)>>2]|0)|0;if((d[ai+((ax|0)/8|0)|0]&128>>>((ax&7)>>>0)|0)!=0){ax=al+(av+au)|0;a[ax]=a[ax]|2}au=au+1|0;}while((au|0)<8);as=as+1|0;}while((as|0)<8);as=ar|6;at=0;do{au=as+(c[1238464+(at<<2)>>2]|0)|0;av=(at<<3)+aq|0;aw=0;do{ax=au+(c[6964280+(aw<<2)>>2]|0)|0;if((d[ai+((ax|0)/8|0)|0]&128>>>((ax&7)>>>0)|0)!=0){ax=al+(av+aw)|0;a[ax]=a[ax]|1}aw=aw+1|0;}while((aw|0)<8);at=at+1|0;}while((at|0)<8);ap=ap+1|0;}while((ap|0)<1024);gGz(ai|0,0,393216);if((c[3542200]|0)==0){ao=1;i=e;return ao|0}ap=Z+108|0;c[ap>>2]=0;al=Z+100|0;c[al>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](Z,4)|0;do{if((c[ap>>2]|0)!=0){at=c[al>>2]|0;c[_>>2]=9534384;aq=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aq&16383](_,4,0)|0;if((at|0)<1){ao=1;i=e;return ao|0}if((gzL(ai,0,4)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ai=(c[3529538]|0)+32768|0;if((c[3542200]|0)==0){ao=1;i=e;return ao|0}al=W+108|0;c[al>>2]=0;ap=W+100|0;c[ap>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](W,5)|0;do{if((c[al>>2]|0)!=0){at=c[ap>>2]|0;c[Y>>2]=9534384;aq=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aq&16383](Y,5,0)|0;if((at|0)<1){ao=1;i=e;return ao|0}if((gzL(ai,0,5)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ai=(c[3529538]|0)+65536|0;if((c[3542200]|0)==0){ao=1;i=e;return ao|0}ap=T+108|0;c[ap>>2]=0;al=T+100|0;c[al>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](T,6)|0;do{if((c[ap>>2]|0)!=0){at=c[al>>2]|0;c[V>>2]=9534384;aq=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aq&16383](V,6,0)|0;if((at|0)<1){ao=1;i=e;return ao|0}if((gzL(ai,0,6)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ai=(c[3529538]|0)+98304|0;if((c[3542200]|0)==0){ao=1;i=e;return ao|0}al=R+108|0;c[al>>2]=0;ap=R+100|0;c[ap>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](R,7)|0;do{if((c[al>>2]|0)!=0){at=c[ap>>2]|0;c[S>>2]=9534384;aq=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aq&16383](S,7,0)|0;if((at|0)<1){ao=1;i=e;return ao|0}if((gzL(ai,0,7)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ai=(c[3529538]|0)+131072|0;if((c[3542200]|0)==0){ao=1;i=e;return ao|0}ap=P+108|0;c[ap>>2]=0;al=P+100|0;c[al>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](P,8)|0;do{if((c[ap>>2]|0)!=0){at=c[al>>2]|0;c[Q>>2]=9534384;aq=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aq&16383](Q,8,0)|0;if((at|0)<1){ao=1;i=e;return ao|0}if((gzL(ai,0,8)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ai=(c[3529538]|0)+163840|0;if((c[3542200]|0)==0){ao=1;i=e;return ao|0}al=N+108|0;c[al>>2]=0;ap=N+100|0;c[ap>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](N,9)|0;do{if((c[al>>2]|0)!=0){at=c[ap>>2]|0;c[O>>2]=9534384;aq=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aq&16383](O,9,0)|0;if((at|0)<1){ao=1;i=e;return ao|0}if((gzL(ai,0,9)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ai=c[3529538]|0;ap=c[2405822]|0;al=0;while(1){at=al<<8;gGz(ap+at|0,0,256);aq=al<<9;as=aq|4;ar=0;do{aw=as+(c[609008+(ar<<2)>>2]|0)|0;av=(ar<<4)+at|0;au=0;do{ax=aw+(c[610128+(au<<2)>>2]|0)|0;if((d[ai+((ax|0)/8|0)|0]&128>>>((ax&7)>>>0)|0)!=0){ax=ap+(av+au)|0;a[ax]=a[ax]|4}au=au+1|0;}while((au|0)<16);ar=ar+1|0;}while((ar|0)<16);ar=aq+262144|0;as=0;do{au=ar+(c[609008+(as<<2)>>2]|0)|0;av=(as<<4)+at|0;aw=0;do{ax=au+(c[610128+(aw<<2)>>2]|0)|0;if((d[ai+((ax|0)/8|0)|0]&128>>>((ax&7)>>>0)|0)!=0){ax=ap+(av+aw)|0;a[ax]=a[ax]|2}aw=aw+1|0;}while((aw|0)<16);as=as+1|0;}while((as|0)<16);as=aq+262148|0;ar=0;do{aw=as+(c[609008+(ar<<2)>>2]|0)|0;av=(ar<<4)+at|0;au=0;do{ax=aw+(c[610128+(au<<2)>>2]|0)|0;if((d[ai+((ax|0)/8|0)|0]&128>>>((ax&7)>>>0)|0)!=0){ax=ap+(av+au)|0;a[ax]=a[ax]|1}au=au+1|0;}while((au|0)<16);ar=ar+1|0;}while((ar|0)<16);ar=al+1|0;if((ar|0)<256){al=ar}else{ay=0;break}}while(1){al=(ay<<8)+65536|0;gGz(ap+al|0,0,256);ar=ay<<9;at=0;do{as=ar+(c[609008+(at<<2)>>2]|0)|0;aq=al+(at<<4)|0;au=0;do{av=as+(c[610128+(au<<2)>>2]|0)|0;if((d[ai+((av|0)/8|0)|0]&128>>>((av&7)>>>0)|0)!=0){av=ap+(aq+au)|0;a[av]=a[av]|4}au=au+1|0;}while((au|0)<16);at=at+1|0;}while((at|0)<16);at=ar+393216|0;au=0;do{aq=at+(c[609008+(au<<2)>>2]|0)|0;as=al+(au<<4)|0;av=0;do{aw=aq+(c[610128+(av<<2)>>2]|0)|0;if((d[ai+((aw|0)/8|0)|0]&128>>>((aw&7)>>>0)|0)!=0){aw=ap+(as+av)|0;a[aw]=a[aw]|2}av=av+1|0;}while((av|0)<16);au=au+1|0;}while((au|0)<16);au=ar+393220|0;at=0;do{av=au+(c[609008+(at<<2)>>2]|0)|0;as=al+(at<<4)|0;aq=0;do{aw=av+(c[610128+(aq<<2)>>2]|0)|0;if((d[ai+((aw|0)/8|0)|0]&128>>>((aw&7)>>>0)|0)!=0){aw=ap+(as+aq)|0;a[aw]=a[aw]|1}aq=aq+1|0;}while((aq|0)<16);at=at+1|0;}while((at|0)<16);at=ay+1|0;if((at|0)<256){ay=at}else{az=0;break}}while(1){at=(az<<8)+131072|0;gGz(ap+at|0,0,256);al=az<<9;au=al+131076|0;ar=0;do{aq=au+(c[609008+(ar<<2)>>2]|0)|0;as=at+(ar<<4)|0;av=0;do{aw=aq+(c[610128+(av<<2)>>2]|0)|0;if((d[ai+((aw|0)/8|0)|0]&128>>>((aw&7)>>>0)|0)!=0){aw=ap+(as+av)|0;a[aw]=a[aw]|4}av=av+1|0;}while((av|0)<16);ar=ar+1|0;}while((ar|0)<16);ar=al+524288|0;au=0;do{av=ar+(c[609008+(au<<2)>>2]|0)|0;as=at+(au<<4)|0;aq=0;do{aw=av+(c[610128+(aq<<2)>>2]|0)|0;if((d[ai+((aw|0)/8|0)|0]&128>>>((aw&7)>>>0)|0)!=0){aw=ap+(as+aq)|0;a[aw]=a[aw]|2}aq=aq+1|0;}while((aq|0)<16);au=au+1|0;}while((au|0)<16);au=al+524292|0;ar=0;do{aq=au+(c[609008+(ar<<2)>>2]|0)|0;as=at+(ar<<4)|0;av=0;do{aw=aq+(c[610128+(av<<2)>>2]|0)|0;if((d[ai+((aw|0)/8|0)|0]&128>>>((aw&7)>>>0)|0)!=0){aw=ap+(as+av)|0;a[aw]=a[aw]|1}av=av+1|0;}while((av|0)<16);ar=ar+1|0;}while((ar|0)<16);ar=az+1|0;if((ar|0)<256){az=ar}else{aA=0;break}}while(1){ar=(aA<<8)+196608|0;gGz(ap+ar|0,0,256);at=aA<<9;au=at+131072|0;al=0;do{av=au+(c[609008+(al<<2)>>2]|0)|0;as=ar+(al<<4)|0;aq=0;do{aw=av+(c[610128+(aq<<2)>>2]|0)|0;if((d[ai+((aw|0)/8|0)|0]&128>>>((aw&7)>>>0)|0)!=0){aw=ap+(as+aq)|0;a[aw]=a[aw]|4}aq=aq+1|0;}while((aq|0)<16);al=al+1|0;}while((al|0)<16);al=at+655360|0;au=0;do{aq=al+(c[609008+(au<<2)>>2]|0)|0;as=ar+(au<<4)|0;av=0;do{aw=aq+(c[610128+(av<<2)>>2]|0)|0;if((d[ai+((aw|0)/8|0)|0]&128>>>((aw&7)>>>0)|0)!=0){aw=ap+(as+av)|0;a[aw]=a[aw]|2}av=av+1|0;}while((av|0)<16);au=au+1|0;}while((au|0)<16);au=at+655364|0;al=0;do{av=au+(c[609008+(al<<2)>>2]|0)|0;as=ar+(al<<4)|0;aq=0;do{aw=av+(c[610128+(aq<<2)>>2]|0)|0;if((d[ai+((aw|0)/8|0)|0]&128>>>((aw&7)>>>0)|0)!=0){aw=ap+(as+aq)|0;a[aw]=a[aw]|1}aq=aq+1|0;}while((aq|0)<16);al=al+1|0;}while((al|0)<16);al=aA+1|0;if((al|0)<256){aA=al}else{aB=0;break}}while(1){al=(aB<<8)+262144|0;gGz(ap+al|0,0,256);ar=aB<<9;au=ar|4;at=0;do{aq=au+(c[609008+(at<<2)>>2]|0)|0;as=al+(at<<4)|0;av=0;do{aw=aq+(c[610128+(av<<2)>>2]|0)|0;if((d[ai+(((aw|0)/8|0)+98304)|0]&128>>>((aw&7)>>>0)|0)!=0){aw=ap+(as+av)|0;a[aw]=a[aw]|4}av=av+1|0;}while((av|0)<16);at=at+1|0;}while((at|0)<16);at=ar+262144|0;au=0;do{av=at+(c[609008+(au<<2)>>2]|0)|0;as=al+(au<<4)|0;aq=0;do{aw=av+(c[610128+(aq<<2)>>2]|0)|0;if((d[ai+(((aw|0)/8|0)+98304)|0]&128>>>((aw&7)>>>0)|0)!=0){aw=ap+(as+aq)|0;a[aw]=a[aw]|2}aq=aq+1|0;}while((aq|0)<16);au=au+1|0;}while((au|0)<16);au=ar+262148|0;at=0;do{aq=au+(c[609008+(at<<2)>>2]|0)|0;as=al+(at<<4)|0;av=0;do{aw=aq+(c[610128+(av<<2)>>2]|0)|0;if((d[ai+(((aw|0)/8|0)+98304)|0]&128>>>((aw&7)>>>0)|0)!=0){aw=ap+(as+av)|0;a[aw]=a[aw]|1}av=av+1|0;}while((av|0)<16);at=at+1|0;}while((at|0)<16);at=aB+1|0;if((at|0)<256){aB=at}else{aC=0;break}}while(1){at=(aC<<8)+327680|0;gGz(ap+at|0,0,256);al=aC<<9;au=0;do{ar=al+(c[609008+(au<<2)>>2]|0)|0;av=at+(au<<4)|0;as=0;do{aq=ar+(c[610128+(as<<2)>>2]|0)|0;if((d[ai+(((aq|0)/8|0)+98304)|0]&128>>>((aq&7)>>>0)|0)!=0){aq=ap+(av+as)|0;a[aq]=a[aq]|4}as=as+1|0;}while((as|0)<16);au=au+1|0;}while((au|0)<16);au=al+393216|0;as=0;do{av=au+(c[609008+(as<<2)>>2]|0)|0;ar=at+(as<<4)|0;aq=0;do{aw=av+(c[610128+(aq<<2)>>2]|0)|0;if((d[ai+(((aw|0)/8|0)+98304)|0]&128>>>((aw&7)>>>0)|0)!=0){aw=ap+(ar+aq)|0;a[aw]=a[aw]|2}aq=aq+1|0;}while((aq|0)<16);as=as+1|0;}while((as|0)<16);as=al+393220|0;au=0;do{aq=as+(c[609008+(au<<2)>>2]|0)|0;ar=at+(au<<4)|0;av=0;do{aw=aq+(c[610128+(av<<2)>>2]|0)|0;if((d[ai+(((aw|0)/8|0)+98304)|0]&128>>>((aw&7)>>>0)|0)!=0){aw=ap+(ar+av)|0;a[aw]=a[aw]|1}av=av+1|0;}while((av|0)<16);au=au+1|0;}while((au|0)<16);au=aC+1|0;if((au|0)<256){aC=au}else{aD=0;break}}while(1){au=(aD<<8)+393216|0;gGz(ap+au|0,0,256);at=aD<<9;as=at+131076|0;al=0;do{av=as+(c[609008+(al<<2)>>2]|0)|0;ar=au+(al<<4)|0;aq=0;do{aw=av+(c[610128+(aq<<2)>>2]|0)|0;if((d[ai+(((aw|0)/8|0)+98304)|0]&128>>>((aw&7)>>>0)|0)!=0){aw=ap+(ar+aq)|0;a[aw]=a[aw]|4}aq=aq+1|0;}while((aq|0)<16);al=al+1|0;}while((al|0)<16);al=at+524288|0;as=0;do{aq=al+(c[609008+(as<<2)>>2]|0)|0;ar=au+(as<<4)|0;av=0;do{aw=aq+(c[610128+(av<<2)>>2]|0)|0;if((d[ai+(((aw|0)/8|0)+98304)|0]&128>>>((aw&7)>>>0)|0)!=0){aw=ap+(ar+av)|0;a[aw]=a[aw]|2}av=av+1|0;}while((av|0)<16);as=as+1|0;}while((as|0)<16);as=at+524292|0;al=0;do{av=as+(c[609008+(al<<2)>>2]|0)|0;ar=au+(al<<4)|0;aq=0;do{aw=av+(c[610128+(aq<<2)>>2]|0)|0;if((d[ai+(((aw|0)/8|0)+98304)|0]&128>>>((aw&7)>>>0)|0)!=0){aw=ap+(ar+aq)|0;a[aw]=a[aw]|1}aq=aq+1|0;}while((aq|0)<16);al=al+1|0;}while((al|0)<16);al=aD+1|0;if((al|0)<256){aD=al}else{aE=0;break}}do{al=(aE<<8)+458752|0;gGz(ap+al|0,0,256);au=aE<<9;as=au+131072|0;at=0;do{aq=as+(c[609008+(at<<2)>>2]|0)|0;ar=al+(at<<4)|0;av=0;do{aw=aq+(c[610128+(av<<2)>>2]|0)|0;if((d[ai+(((aw|0)/8|0)+98304)|0]&128>>>((aw&7)>>>0)|0)!=0){aw=ap+(ar+av)|0;a[aw]=a[aw]|4}av=av+1|0;}while((av|0)<16);at=at+1|0;}while((at|0)<16);at=au+655360|0;as=0;do{av=at+(c[609008+(as<<2)>>2]|0)|0;ar=al+(as<<4)|0;aq=0;do{aw=av+(c[610128+(aq<<2)>>2]|0)|0;if((d[ai+(((aw|0)/8|0)+98304)|0]&128>>>((aw&7)>>>0)|0)!=0){aw=ap+(ar+aq)|0;a[aw]=a[aw]|2}aq=aq+1|0;}while((aq|0)<16);as=as+1|0;}while((as|0)<16);as=au+655364|0;at=0;do{aq=as+(c[609008+(at<<2)>>2]|0)|0;ar=al+(at<<4)|0;av=0;do{aw=aq+(c[610128+(av<<2)>>2]|0)|0;if((d[ai+(((aw|0)/8|0)+98304)|0]&128>>>((aw&7)>>>0)|0)!=0){aw=ap+(ar+av)|0;a[aw]=a[aw]|1}av=av+1|0;}while((av|0)<16);at=at+1|0;}while((at|0)<16);aE=aE+1|0;}while((aE|0)<256);gGz(ai|0,0,393216);if((c[3542200]|0)==0){ao=1;i=e;return ao|0}ap=L+108|0;c[ap>>2]=0;at=L+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](L,10)|0;do{if((c[ap>>2]|0)!=0){al=c[at>>2]|0;c[M>>2]=9534384;as=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[as&16383](M,10,0)|0;if((al|0)<1){ao=1;i=e;return ao|0}if((gzL(ai,0,10)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ai=(c[3529538]|0)+32768|0;if((c[3542200]|0)==0){ao=1;i=e;return ao|0}at=J+108|0;c[at>>2]=0;ap=J+100|0;c[ap>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](J,11)|0;do{if((c[at>>2]|0)!=0){al=c[ap>>2]|0;c[K>>2]=9534384;as=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[as&16383](K,11,0)|0;if((al|0)<1){ao=1;i=e;return ao|0}if((gzL(ai,0,11)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ai=(c[3529538]|0)+65536|0;if((c[3542200]|0)==0){ao=1;i=e;return ao|0}ap=H+108|0;c[ap>>2]=0;at=H+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](H,12)|0;do{if((c[ap>>2]|0)!=0){al=c[at>>2]|0;c[I>>2]=9534384;as=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[as&16383](I,12,0)|0;if((al|0)<1){ao=1;i=e;return ao|0}if((gzL(ai,0,12)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ai=(c[3529538]|0)+98304|0;if((c[3542200]|0)==0){ao=1;i=e;return ao|0}at=F+108|0;c[at>>2]=0;ap=F+100|0;c[ap>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](F,13)|0;do{if((c[at>>2]|0)!=0){al=c[ap>>2]|0;c[G>>2]=9534384;as=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[as&16383](G,13,0)|0;if((al|0)<1){ao=1;i=e;return ao|0}if((gzL(ai,0,13)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ai=(c[3529538]|0)+131072|0;if((c[3542200]|0)==0){ao=1;i=e;return ao|0}ap=D+108|0;c[ap>>2]=0;at=D+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](D,14)|0;do{if((c[ap>>2]|0)!=0){al=c[at>>2]|0;c[E>>2]=9534384;as=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[as&16383](E,14,0)|0;if((al|0)<1){ao=1;i=e;return ao|0}if((gzL(ai,0,14)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ai=(c[3529538]|0)+163840|0;if((c[3542200]|0)==0){ao=1;i=e;return ao|0}at=B+108|0;c[at>>2]=0;ap=B+100|0;c[ap>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](B,15)|0;do{if((c[at>>2]|0)!=0){al=c[ap>>2]|0;c[C>>2]=9534384;as=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[as&16383](C,15,0)|0;if((al|0)<1){ao=1;i=e;return ao|0}if((gzL(ai,0,15)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ai=(c[3529538]|0)+196608|0;if((c[3542200]|0)==0){ao=1;i=e;return ao|0}ap=z+108|0;c[ap>>2]=0;at=z+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,16)|0;do{if((c[ap>>2]|0)!=0){al=c[at>>2]|0;c[A>>2]=9534384;as=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[as&16383](A,16,0)|0;if((al|0)<1){ao=1;i=e;return ao|0}if((gzL(ai,0,16)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ai=(c[3529538]|0)+229376|0;if((c[3542200]|0)==0){ao=1;i=e;return ao|0}at=x+108|0;c[at>>2]=0;ap=x+100|0;c[ap>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,17)|0;do{if((c[at>>2]|0)!=0){al=c[ap>>2]|0;c[y>>2]=9534384;as=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[as&16383](y,17,0)|0;if((al|0)<1){ao=1;i=e;return ao|0}if((gzL(ai,0,17)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ai=(c[3529538]|0)+262144|0;if((c[3542200]|0)==0){ao=1;i=e;return ao|0}ap=v+108|0;c[ap>>2]=0;at=v+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,18)|0;do{if((c[ap>>2]|0)!=0){al=c[at>>2]|0;c[w>>2]=9534384;as=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[as&16383](w,18,0)|0;if((al|0)<1){ao=1;i=e;return ao|0}if((gzL(ai,0,18)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ai=(c[3529538]|0)+294912|0;if((c[3542200]|0)==0){ao=1;i=e;return ao|0}at=t+108|0;c[at>>2]=0;ap=t+100|0;c[ap>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,19)|0;do{if((c[at>>2]|0)!=0){al=c[ap>>2]|0;c[u>>2]=9534384;as=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[as&16383](u,19,0)|0;if((al|0)<1){ao=1;i=e;return ao|0}if((gzL(ai,0,19)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ai=(c[3529538]|0)+327680|0;if((c[3542200]|0)==0){ao=1;i=e;return ao|0}ap=r+108|0;c[ap>>2]=0;at=r+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,20)|0;do{if((c[ap>>2]|0)!=0){al=c[at>>2]|0;c[s>>2]=9534384;as=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[as&16383](s,20,0)|0;if((al|0)<1){ao=1;i=e;return ao|0}if((gzL(ai,0,20)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ai=(c[3529538]|0)+360448|0;if((c[3542200]|0)==0){ao=1;i=e;return ao|0}at=p+108|0;c[at>>2]=0;ap=p+100|0;c[ap>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,21)|0;do{if((c[at>>2]|0)!=0){al=c[ap>>2]|0;c[q>>2]=9534384;as=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[as&16383](q,21,0)|0;if((al|0)<1){ao=1;i=e;return ao|0}if((gzL(ai,0,21)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ai=c[3529538]|0;ap=c[3529588]|0;at=0;while(1){al=at<<8;gGz(ap+al|0,0,256);as=at<<9;au=as|4;av=0;do{ar=au+(c[609008+(av<<2)>>2]|0)|0;aq=(av<<4)+al|0;aw=0;do{ax=ar+(c[610128+(aw<<2)>>2]|0)|0;if((d[ai+((ax|0)/8|0)|0]&128>>>((ax&7)>>>0)|0)!=0){ax=ap+(aq+aw)|0;a[ax]=a[ax]|4}aw=aw+1|0;}while((aw|0)<16);av=av+1|0;}while((av|0)<16);av=as+262144|0;au=0;do{aw=av+(c[609008+(au<<2)>>2]|0)|0;aq=(au<<4)+al|0;ar=0;do{ax=aw+(c[610128+(ar<<2)>>2]|0)|0;if((d[ai+((ax|0)/8|0)|0]&128>>>((ax&7)>>>0)|0)!=0){ax=ap+(aq+ar)|0;a[ax]=a[ax]|2}ar=ar+1|0;}while((ar|0)<16);au=au+1|0;}while((au|0)<16);au=as+262148|0;av=0;do{ar=au+(c[609008+(av<<2)>>2]|0)|0;aq=(av<<4)+al|0;aw=0;do{ax=ar+(c[610128+(aw<<2)>>2]|0)|0;if((d[ai+((ax|0)/8|0)|0]&128>>>((ax&7)>>>0)|0)!=0){ax=ap+(aq+aw)|0;a[ax]=a[ax]|1}aw=aw+1|0;}while((aw|0)<16);av=av+1|0;}while((av|0)<16);av=at+1|0;if((av|0)<256){at=av}else{aF=0;break}}while(1){at=(aF<<8)+65536|0;gGz(ap+at|0,0,256);av=aF<<9;al=0;do{au=av+(c[609008+(al<<2)>>2]|0)|0;as=at+(al<<4)|0;aw=0;do{aq=au+(c[610128+(aw<<2)>>2]|0)|0;if((d[ai+((aq|0)/8|0)|0]&128>>>((aq&7)>>>0)|0)!=0){aq=ap+(as+aw)|0;a[aq]=a[aq]|4}aw=aw+1|0;}while((aw|0)<16);al=al+1|0;}while((al|0)<16);al=av+393216|0;aw=0;do{as=al+(c[609008+(aw<<2)>>2]|0)|0;au=at+(aw<<4)|0;aq=0;do{ar=as+(c[610128+(aq<<2)>>2]|0)|0;if((d[ai+((ar|0)/8|0)|0]&128>>>((ar&7)>>>0)|0)!=0){ar=ap+(au+aq)|0;a[ar]=a[ar]|2}aq=aq+1|0;}while((aq|0)<16);aw=aw+1|0;}while((aw|0)<16);aw=av+393220|0;al=0;do{aq=aw+(c[609008+(al<<2)>>2]|0)|0;au=at+(al<<4)|0;as=0;do{ar=aq+(c[610128+(as<<2)>>2]|0)|0;if((d[ai+((ar|0)/8|0)|0]&128>>>((ar&7)>>>0)|0)!=0){ar=ap+(au+as)|0;a[ar]=a[ar]|1}as=as+1|0;}while((as|0)<16);al=al+1|0;}while((al|0)<16);al=aF+1|0;if((al|0)<256){aF=al}else{aG=0;break}}while(1){al=(aG<<8)+131072|0;gGz(ap+al|0,0,256);at=aG<<9;aw=at+131076|0;av=0;do{as=aw+(c[609008+(av<<2)>>2]|0)|0;au=al+(av<<4)|0;aq=0;do{ar=as+(c[610128+(aq<<2)>>2]|0)|0;if((d[ai+((ar|0)/8|0)|0]&128>>>((ar&7)>>>0)|0)!=0){ar=ap+(au+aq)|0;a[ar]=a[ar]|4}aq=aq+1|0;}while((aq|0)<16);av=av+1|0;}while((av|0)<16);av=at+524288|0;aw=0;do{aq=av+(c[609008+(aw<<2)>>2]|0)|0;au=al+(aw<<4)|0;as=0;do{ar=aq+(c[610128+(as<<2)>>2]|0)|0;if((d[ai+((ar|0)/8|0)|0]&128>>>((ar&7)>>>0)|0)!=0){ar=ap+(au+as)|0;a[ar]=a[ar]|2}as=as+1|0;}while((as|0)<16);aw=aw+1|0;}while((aw|0)<16);aw=at+524292|0;av=0;do{as=aw+(c[609008+(av<<2)>>2]|0)|0;au=al+(av<<4)|0;aq=0;do{ar=as+(c[610128+(aq<<2)>>2]|0)|0;if((d[ai+((ar|0)/8|0)|0]&128>>>((ar&7)>>>0)|0)!=0){ar=ap+(au+aq)|0;a[ar]=a[ar]|1}aq=aq+1|0;}while((aq|0)<16);av=av+1|0;}while((av|0)<16);av=aG+1|0;if((av|0)<256){aG=av}else{aH=0;break}}while(1){av=(aH<<8)+196608|0;gGz(ap+av|0,0,256);al=aH<<9;aw=al+131072|0;at=0;do{aq=aw+(c[609008+(at<<2)>>2]|0)|0;au=av+(at<<4)|0;as=0;do{ar=aq+(c[610128+(as<<2)>>2]|0)|0;if((d[ai+((ar|0)/8|0)|0]&128>>>((ar&7)>>>0)|0)!=0){ar=ap+(au+as)|0;a[ar]=a[ar]|4}as=as+1|0;}while((as|0)<16);at=at+1|0;}while((at|0)<16);at=al+655360|0;aw=0;do{as=at+(c[609008+(aw<<2)>>2]|0)|0;au=av+(aw<<4)|0;aq=0;do{ar=as+(c[610128+(aq<<2)>>2]|0)|0;if((d[ai+((ar|0)/8|0)|0]&128>>>((ar&7)>>>0)|0)!=0){ar=ap+(au+aq)|0;a[ar]=a[ar]|2}aq=aq+1|0;}while((aq|0)<16);aw=aw+1|0;}while((aw|0)<16);aw=al+655364|0;at=0;do{aq=aw+(c[609008+(at<<2)>>2]|0)|0;au=av+(at<<4)|0;as=0;do{ar=aq+(c[610128+(as<<2)>>2]|0)|0;if((d[ai+((ar|0)/8|0)|0]&128>>>((ar&7)>>>0)|0)!=0){ar=ap+(au+as)|0;a[ar]=a[ar]|1}as=as+1|0;}while((as|0)<16);at=at+1|0;}while((at|0)<16);at=aH+1|0;if((at|0)<256){aH=at}else{aI=0;break}}while(1){at=(aI<<8)+262144|0;gGz(ap+at|0,0,256);av=aI<<9;aw=av|4;al=0;do{as=aw+(c[609008+(al<<2)>>2]|0)|0;au=at+(al<<4)|0;aq=0;do{ar=as+(c[610128+(aq<<2)>>2]|0)|0;if((d[ai+(((ar|0)/8|0)+98304)|0]&128>>>((ar&7)>>>0)|0)!=0){ar=ap+(au+aq)|0;a[ar]=a[ar]|4}aq=aq+1|0;}while((aq|0)<16);al=al+1|0;}while((al|0)<16);al=av+262144|0;aw=0;do{aq=al+(c[609008+(aw<<2)>>2]|0)|0;au=at+(aw<<4)|0;as=0;do{ar=aq+(c[610128+(as<<2)>>2]|0)|0;if((d[ai+(((ar|0)/8|0)+98304)|0]&128>>>((ar&7)>>>0)|0)!=0){ar=ap+(au+as)|0;a[ar]=a[ar]|2}as=as+1|0;}while((as|0)<16);aw=aw+1|0;}while((aw|0)<16);aw=av+262148|0;al=0;do{as=aw+(c[609008+(al<<2)>>2]|0)|0;au=at+(al<<4)|0;aq=0;do{ar=as+(c[610128+(aq<<2)>>2]|0)|0;if((d[ai+(((ar|0)/8|0)+98304)|0]&128>>>((ar&7)>>>0)|0)!=0){ar=ap+(au+aq)|0;a[ar]=a[ar]|1}aq=aq+1|0;}while((aq|0)<16);al=al+1|0;}while((al|0)<16);al=aI+1|0;if((al|0)<256){aI=al}else{aJ=0;break}}while(1){al=(aJ<<8)+327680|0;gGz(ap+al|0,0,256);at=aJ<<9;aw=0;do{av=at+(c[609008+(aw<<2)>>2]|0)|0;aq=al+(aw<<4)|0;au=0;do{as=av+(c[610128+(au<<2)>>2]|0)|0;if((d[ai+(((as|0)/8|0)+98304)|0]&128>>>((as&7)>>>0)|0)!=0){as=ap+(aq+au)|0;a[as]=a[as]|4}au=au+1|0;}while((au|0)<16);aw=aw+1|0;}while((aw|0)<16);aw=at+393216|0;au=0;do{aq=aw+(c[609008+(au<<2)>>2]|0)|0;av=al+(au<<4)|0;as=0;do{ar=aq+(c[610128+(as<<2)>>2]|0)|0;if((d[ai+(((ar|0)/8|0)+98304)|0]&128>>>((ar&7)>>>0)|0)!=0){ar=ap+(av+as)|0;a[ar]=a[ar]|2}as=as+1|0;}while((as|0)<16);au=au+1|0;}while((au|0)<16);au=at+393220|0;aw=0;do{as=au+(c[609008+(aw<<2)>>2]|0)|0;av=al+(aw<<4)|0;aq=0;do{ar=as+(c[610128+(aq<<2)>>2]|0)|0;if((d[ai+(((ar|0)/8|0)+98304)|0]&128>>>((ar&7)>>>0)|0)!=0){ar=ap+(av+aq)|0;a[ar]=a[ar]|1}aq=aq+1|0;}while((aq|0)<16);aw=aw+1|0;}while((aw|0)<16);aw=aJ+1|0;if((aw|0)<256){aJ=aw}else{aK=0;break}}while(1){aw=(aK<<8)+393216|0;gGz(ap+aw|0,0,256);al=aK<<9;au=al+131076|0;at=0;do{aq=au+(c[609008+(at<<2)>>2]|0)|0;av=aw+(at<<4)|0;as=0;do{ar=aq+(c[610128+(as<<2)>>2]|0)|0;if((d[ai+(((ar|0)/8|0)+98304)|0]&128>>>((ar&7)>>>0)|0)!=0){ar=ap+(av+as)|0;a[ar]=a[ar]|4}as=as+1|0;}while((as|0)<16);at=at+1|0;}while((at|0)<16);at=al+524288|0;au=0;do{as=at+(c[609008+(au<<2)>>2]|0)|0;av=aw+(au<<4)|0;aq=0;do{ar=as+(c[610128+(aq<<2)>>2]|0)|0;if((d[ai+(((ar|0)/8|0)+98304)|0]&128>>>((ar&7)>>>0)|0)!=0){ar=ap+(av+aq)|0;a[ar]=a[ar]|2}aq=aq+1|0;}while((aq|0)<16);au=au+1|0;}while((au|0)<16);au=al+524292|0;at=0;do{aq=au+(c[609008+(at<<2)>>2]|0)|0;av=aw+(at<<4)|0;as=0;do{ar=aq+(c[610128+(as<<2)>>2]|0)|0;if((d[ai+(((ar|0)/8|0)+98304)|0]&128>>>((ar&7)>>>0)|0)!=0){ar=ap+(av+as)|0;a[ar]=a[ar]|1}as=as+1|0;}while((as|0)<16);at=at+1|0;}while((at|0)<16);at=aK+1|0;if((at|0)<256){aK=at}else{aL=0;break}}while(1){at=(aL<<8)+458752|0;gGz(ap+at|0,0,256);aw=aL<<9;au=aw+131072|0;al=0;do{as=au+(c[609008+(al<<2)>>2]|0)|0;av=at+(al<<4)|0;aq=0;do{ar=as+(c[610128+(aq<<2)>>2]|0)|0;if((d[ai+(((ar|0)/8|0)+98304)|0]&128>>>((ar&7)>>>0)|0)!=0){ar=ap+(av+aq)|0;a[ar]=a[ar]|4}aq=aq+1|0;}while((aq|0)<16);al=al+1|0;}while((al|0)<16);al=aw+655360|0;au=0;do{aq=al+(c[609008+(au<<2)>>2]|0)|0;av=at+(au<<4)|0;as=0;do{ar=aq+(c[610128+(as<<2)>>2]|0)|0;if((d[ai+(((ar|0)/8|0)+98304)|0]&128>>>((ar&7)>>>0)|0)!=0){ar=ap+(av+as)|0;a[ar]=a[ar]|2}as=as+1|0;}while((as|0)<16);au=au+1|0;}while((au|0)<16);au=aw+655364|0;al=0;do{as=au+(c[609008+(al<<2)>>2]|0)|0;av=at+(al<<4)|0;aq=0;do{ar=as+(c[610128+(aq<<2)>>2]|0)|0;if((d[ai+(((ar|0)/8|0)+98304)|0]&128>>>((ar&7)>>>0)|0)!=0){ar=ap+(av+aq)|0;a[ar]=a[ar]|1}aq=aq+1|0;}while((aq|0)<16);al=al+1|0;}while((al|0)<16);al=aL+1|0;if((al|0)<256){aL=al}else{aM=0;break}}while(1){al=(aM<<8)+524288|0;gGz(ap+al|0,0,256);at=aM<<9;au=at|4;aw=0;do{aq=au+(c[609008+(aw<<2)>>2]|0)|0;av=al+(aw<<4)|0;as=0;do{ar=aq+(c[610128+(as<<2)>>2]|0)|0;if((d[ai+(((ar|0)/8|0)+196608)|0]&128>>>((ar&7)>>>0)|0)!=0){ar=ap+(av+as)|0;a[ar]=a[ar]|4}as=as+1|0;}while((as|0)<16);aw=aw+1|0;}while((aw|0)<16);aw=at+262144|0;au=0;do{as=aw+(c[609008+(au<<2)>>2]|0)|0;av=al+(au<<4)|0;aq=0;do{ar=as+(c[610128+(aq<<2)>>2]|0)|0;if((d[ai+(((ar|0)/8|0)+196608)|0]&128>>>((ar&7)>>>0)|0)!=0){ar=ap+(av+aq)|0;a[ar]=a[ar]|2}aq=aq+1|0;}while((aq|0)<16);au=au+1|0;}while((au|0)<16);au=at+262148|0;aw=0;do{aq=au+(c[609008+(aw<<2)>>2]|0)|0;av=al+(aw<<4)|0;as=0;do{ar=aq+(c[610128+(as<<2)>>2]|0)|0;if((d[ai+(((ar|0)/8|0)+196608)|0]&128>>>((ar&7)>>>0)|0)!=0){ar=ap+(av+as)|0;a[ar]=a[ar]|1}as=as+1|0;}while((as|0)<16);aw=aw+1|0;}while((aw|0)<16);aw=aM+1|0;if((aw|0)<256){aM=aw}else{aN=0;break}}while(1){aw=(aN<<8)+589824|0;gGz(ap+aw|0,0,256);al=aN<<9;au=0;do{at=al+(c[609008+(au<<2)>>2]|0)|0;as=aw+(au<<4)|0;av=0;do{aq=at+(c[610128+(av<<2)>>2]|0)|0;if((d[ai+(((aq|0)/8|0)+196608)|0]&128>>>((aq&7)>>>0)|0)!=0){aq=ap+(as+av)|0;a[aq]=a[aq]|4}av=av+1|0;}while((av|0)<16);au=au+1|0;}while((au|0)<16);au=al+393216|0;av=0;do{as=au+(c[609008+(av<<2)>>2]|0)|0;at=aw+(av<<4)|0;aq=0;do{ar=as+(c[610128+(aq<<2)>>2]|0)|0;if((d[ai+(((ar|0)/8|0)+196608)|0]&128>>>((ar&7)>>>0)|0)!=0){ar=ap+(at+aq)|0;a[ar]=a[ar]|2}aq=aq+1|0;}while((aq|0)<16);av=av+1|0;}while((av|0)<16);av=al+393220|0;au=0;do{aq=av+(c[609008+(au<<2)>>2]|0)|0;at=aw+(au<<4)|0;as=0;do{ar=aq+(c[610128+(as<<2)>>2]|0)|0;if((d[ai+(((ar|0)/8|0)+196608)|0]&128>>>((ar&7)>>>0)|0)!=0){ar=ap+(at+as)|0;a[ar]=a[ar]|1}as=as+1|0;}while((as|0)<16);au=au+1|0;}while((au|0)<16);au=aN+1|0;if((au|0)<256){aN=au}else{aO=0;break}}while(1){au=(aO<<8)+655360|0;gGz(ap+au|0,0,256);aw=aO<<9;av=aw+131076|0;al=0;do{as=av+(c[609008+(al<<2)>>2]|0)|0;at=au+(al<<4)|0;aq=0;do{ar=as+(c[610128+(aq<<2)>>2]|0)|0;if((d[ai+(((ar|0)/8|0)+196608)|0]&128>>>((ar&7)>>>0)|0)!=0){ar=ap+(at+aq)|0;a[ar]=a[ar]|4}aq=aq+1|0;}while((aq|0)<16);al=al+1|0;}while((al|0)<16);al=aw+524288|0;av=0;do{aq=al+(c[609008+(av<<2)>>2]|0)|0;at=au+(av<<4)|0;as=0;do{ar=aq+(c[610128+(as<<2)>>2]|0)|0;if((d[ai+(((ar|0)/8|0)+196608)|0]&128>>>((ar&7)>>>0)|0)!=0){ar=ap+(at+as)|0;a[ar]=a[ar]|2}as=as+1|0;}while((as|0)<16);av=av+1|0;}while((av|0)<16);av=aw+524292|0;al=0;do{as=av+(c[609008+(al<<2)>>2]|0)|0;at=au+(al<<4)|0;aq=0;do{ar=as+(c[610128+(aq<<2)>>2]|0)|0;if((d[ai+(((ar|0)/8|0)+196608)|0]&128>>>((ar&7)>>>0)|0)!=0){ar=ap+(at+aq)|0;a[ar]=a[ar]|1}aq=aq+1|0;}while((aq|0)<16);al=al+1|0;}while((al|0)<16);al=aO+1|0;if((al|0)<256){aO=al}else{aP=0;break}}while(1){al=(aP<<8)+720896|0;gGz(ap+al|0,0,256);au=aP<<9;av=au+131072|0;aw=0;do{aq=av+(c[609008+(aw<<2)>>2]|0)|0;at=al+(aw<<4)|0;as=0;do{ar=aq+(c[610128+(as<<2)>>2]|0)|0;if((d[ai+(((ar|0)/8|0)+196608)|0]&128>>>((ar&7)>>>0)|0)!=0){ar=ap+(at+as)|0;a[ar]=a[ar]|4}as=as+1|0;}while((as|0)<16);aw=aw+1|0;}while((aw|0)<16);aw=au+655360|0;av=0;do{as=aw+(c[609008+(av<<2)>>2]|0)|0;at=al+(av<<4)|0;aq=0;do{ar=as+(c[610128+(aq<<2)>>2]|0)|0;if((d[ai+(((ar|0)/8|0)+196608)|0]&128>>>((ar&7)>>>0)|0)!=0){ar=ap+(at+aq)|0;a[ar]=a[ar]|2}aq=aq+1|0;}while((aq|0)<16);av=av+1|0;}while((av|0)<16);av=au+655364|0;aw=0;do{aq=av+(c[609008+(aw<<2)>>2]|0)|0;at=al+(aw<<4)|0;as=0;do{ar=aq+(c[610128+(as<<2)>>2]|0)|0;if((d[ai+(((ar|0)/8|0)+196608)|0]&128>>>((ar&7)>>>0)|0)!=0){ar=ap+(at+as)|0;a[ar]=a[ar]|1}as=as+1|0;}while((as|0)<16);aw=aw+1|0;}while((aw|0)<16);aw=aP+1|0;if((aw|0)<256){aP=aw}else{aQ=0;break}}while(1){aw=(aQ<<8)+786432|0;gGz(ap+aw|0,0,256);al=aQ<<9;av=al|4;au=0;do{as=av+(c[609008+(au<<2)>>2]|0)|0;at=aw+(au<<4)|0;aq=0;do{ar=as+(c[610128+(aq<<2)>>2]|0)|0;if((d[ai+(((ar|0)/8|0)+294912)|0]&128>>>((ar&7)>>>0)|0)!=0){ar=ap+(at+aq)|0;a[ar]=a[ar]|4}aq=aq+1|0;}while((aq|0)<16);au=au+1|0;}while((au|0)<16);au=al+262144|0;av=0;do{aq=au+(c[609008+(av<<2)>>2]|0)|0;at=aw+(av<<4)|0;as=0;do{ar=aq+(c[610128+(as<<2)>>2]|0)|0;if((d[ai+(((ar|0)/8|0)+294912)|0]&128>>>((ar&7)>>>0)|0)!=0){ar=ap+(at+as)|0;a[ar]=a[ar]|2}as=as+1|0;}while((as|0)<16);av=av+1|0;}while((av|0)<16);av=al+262148|0;au=0;do{as=av+(c[609008+(au<<2)>>2]|0)|0;at=aw+(au<<4)|0;aq=0;do{ar=as+(c[610128+(aq<<2)>>2]|0)|0;if((d[ai+(((ar|0)/8|0)+294912)|0]&128>>>((ar&7)>>>0)|0)!=0){ar=ap+(at+aq)|0;a[ar]=a[ar]|1}aq=aq+1|0;}while((aq|0)<16);au=au+1|0;}while((au|0)<16);au=aQ+1|0;if((au|0)<256){aQ=au}else{aR=0;break}}while(1){au=(aR<<8)+851968|0;gGz(ap+au|0,0,256);aw=aR<<9;av=0;do{al=aw+(c[609008+(av<<2)>>2]|0)|0;aq=au+(av<<4)|0;at=0;do{as=al+(c[610128+(at<<2)>>2]|0)|0;if((d[ai+(((as|0)/8|0)+294912)|0]&128>>>((as&7)>>>0)|0)!=0){as=ap+(aq+at)|0;a[as]=a[as]|4}at=at+1|0;}while((at|0)<16);av=av+1|0;}while((av|0)<16);av=aw+393216|0;at=0;do{aq=av+(c[609008+(at<<2)>>2]|0)|0;al=au+(at<<4)|0;as=0;do{ar=aq+(c[610128+(as<<2)>>2]|0)|0;if((d[ai+(((ar|0)/8|0)+294912)|0]&128>>>((ar&7)>>>0)|0)!=0){ar=ap+(al+as)|0;a[ar]=a[ar]|2}as=as+1|0;}while((as|0)<16);at=at+1|0;}while((at|0)<16);at=aw+393220|0;av=0;do{as=at+(c[609008+(av<<2)>>2]|0)|0;al=au+(av<<4)|0;aq=0;do{ar=as+(c[610128+(aq<<2)>>2]|0)|0;if((d[ai+(((ar|0)/8|0)+294912)|0]&128>>>((ar&7)>>>0)|0)!=0){ar=ap+(al+aq)|0;a[ar]=a[ar]|1}aq=aq+1|0;}while((aq|0)<16);av=av+1|0;}while((av|0)<16);av=aR+1|0;if((av|0)<256){aR=av}else{aS=0;break}}while(1){av=(aS<<8)+917504|0;gGz(ap+av|0,0,256);au=aS<<9;at=au+131076|0;aw=0;do{aq=at+(c[609008+(aw<<2)>>2]|0)|0;al=av+(aw<<4)|0;as=0;do{ar=aq+(c[610128+(as<<2)>>2]|0)|0;if((d[ai+(((ar|0)/8|0)+294912)|0]&128>>>((ar&7)>>>0)|0)!=0){ar=ap+(al+as)|0;a[ar]=a[ar]|4}as=as+1|0;}while((as|0)<16);aw=aw+1|0;}while((aw|0)<16);aw=au+524288|0;at=0;do{as=aw+(c[609008+(at<<2)>>2]|0)|0;al=av+(at<<4)|0;aq=0;do{ar=as+(c[610128+(aq<<2)>>2]|0)|0;if((d[ai+(((ar|0)/8|0)+294912)|0]&128>>>((ar&7)>>>0)|0)!=0){ar=ap+(al+aq)|0;a[ar]=a[ar]|2}aq=aq+1|0;}while((aq|0)<16);at=at+1|0;}while((at|0)<16);at=au+524292|0;aw=0;do{aq=at+(c[609008+(aw<<2)>>2]|0)|0;al=av+(aw<<4)|0;as=0;do{ar=aq+(c[610128+(as<<2)>>2]|0)|0;if((d[ai+(((ar|0)/8|0)+294912)|0]&128>>>((ar&7)>>>0)|0)!=0){ar=ap+(al+as)|0;a[ar]=a[ar]|1}as=as+1|0;}while((as|0)<16);aw=aw+1|0;}while((aw|0)<16);aw=aS+1|0;if((aw|0)<256){aS=aw}else{aT=0;break}}do{aw=(aT<<8)+983040|0;gGz(ap+aw|0,0,256);av=aT<<9;at=av+131072|0;au=0;do{as=at+(c[609008+(au<<2)>>2]|0)|0;al=aw+(au<<4)|0;aq=0;do{ar=as+(c[610128+(aq<<2)>>2]|0)|0;if((d[ai+(((ar|0)/8|0)+294912)|0]&128>>>((ar&7)>>>0)|0)!=0){ar=ap+(al+aq)|0;a[ar]=a[ar]|4}aq=aq+1|0;}while((aq|0)<16);au=au+1|0;}while((au|0)<16);au=av+655360|0;at=0;do{aq=au+(c[609008+(at<<2)>>2]|0)|0;al=aw+(at<<4)|0;as=0;do{ar=aq+(c[610128+(as<<2)>>2]|0)|0;if((d[ai+(((ar|0)/8|0)+294912)|0]&128>>>((ar&7)>>>0)|0)!=0){ar=ap+(al+as)|0;a[ar]=a[ar]|2}as=as+1|0;}while((as|0)<16);at=at+1|0;}while((at|0)<16);at=av+655364|0;au=0;do{as=at+(c[609008+(au<<2)>>2]|0)|0;al=aw+(au<<4)|0;aq=0;do{ar=as+(c[610128+(aq<<2)>>2]|0)|0;if((d[ai+(((ar|0)/8|0)+294912)|0]&128>>>((ar&7)>>>0)|0)!=0){ar=ap+(al+aq)|0;a[ar]=a[ar]|1}aq=aq+1|0;}while((aq|0)<16);au=au+1|0;}while((au|0)<16);aT=aT+1|0;}while((aT|0)<256);ap=c[3527482]|0;if((c[3542200]|0)==0){ao=1;i=e;return ao|0}ai=n+108|0;c[ai>>2]=0;au=n+100|0;c[au>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,22)|0;do{if((c[ai>>2]|0)!=0){aw=c[au>>2]|0;c[o>>2]=9534384;at=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[at&16383](o,22,0)|0;if((aw|0)<1){ao=1;i=e;return ao|0}if((gzL(ap,0,22)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ap=(c[3527482]|0)+65536|0;if((c[3542200]|0)==0){ao=1;i=e;return ao|0}au=l+108|0;c[au>>2]=0;ai=l+100|0;c[ai>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,23)|0;do{if((c[au>>2]|0)!=0){aw=c[ai>>2]|0;c[m>>2]=9534384;at=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[at&16383](m,23,0)|0;if((aw|0)<1){ao=1;i=e;return ao|0}if((gzL(ap,0,23)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ap=(c[3527482]|0)+98304|0;if((c[3542200]|0)==0){ao=1;i=e;return ao|0}ai=j+108|0;c[ai>>2]=0;au=j+100|0;c[au>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,24)|0;do{if((c[ai>>2]|0)!=0){aw=c[au>>2]|0;c[k>>2]=9534384;at=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[at&16383](k,24,0)|0;if((aw|0)<1){ao=1;i=e;return ao|0}if((gzL(ap,0,24)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ap=c[3529538]|0;au=0;while(1){if((au|0)>=1024){break}aU=9638528+(au<<2)|0;if((c[aU>>2]|0)==(ap|0)){ak=76065;break}else{au=au+1|0}}if((ak|0)==76065){gGr(ap);c[aU>>2]=0}c[3529538]=0;fvI();c[3528556]=0;au=c[2433594]|0;c[2443776]=au;ai=(au|0)==0;L93002:do{if(!ai){aw=au|0;gGC(9660952,aw|0,52)|0;switch(a[9660952]|0){case 0:{c[2309668]=638960;break L93002;break};case 1:{c[2309668]=634096;break L93002;break};case 3:{c[2309668]=639984;break L93002;break};case 4:{c[2309668]=7356016;break L93002;break};case 5:{c[2309668]=7354992;break L93002;break};case 2:{c[2309668]=638960;break L93002;break};default:{break L93002}}}}while(0);ap=c[2432850]|0;c[2113164]=ap;aw=c[3527432]|0;at=0;av=0;while(1){aq=aw+(av<<8)|0;c[au+68+(av<<2)>>2]=aq;c[au+68+(av+256<<2)>>2]=aq;c[au+68+(av+512<<2)>>2]=aq;aq=at+1&65535;if((aq&65535)>23){break}else{at=aq;av=aq&65535}}av=c[2443354]|0;c[au+164>>2]=av;c[au+1188>>2]=av;c[au+2212>>2]=av;at=av+256|0;c[au+168>>2]=at;c[au+1192>>2]=at;c[au+2216>>2]=at;at=av+512|0;c[au+172>>2]=at;c[au+1196>>2]=at;c[au+2220>>2]=at;at=av+768|0;c[au+176>>2]=at;c[au+1200>>2]=at;c[au+2224>>2]=at;at=av+1024|0;c[au+180>>2]=at;c[au+1204>>2]=at;c[au+2228>>2]=at;at=av+1280|0;c[au+184>>2]=at;c[au+1208>>2]=at;c[au+2232>>2]=at;at=av+1536|0;c[au+188>>2]=at;c[au+1212>>2]=at;c[au+2236>>2]=at;at=av+1792|0;c[au+192>>2]=at;c[au+1216>>2]=at;c[au+2240>>2]=at;at=c[2443428]|0;c[au+196>>2]=at;c[au+1220>>2]=at;c[au+2244>>2]=at;av=at+256|0;c[au+200>>2]=av;c[au+1224>>2]=av;c[au+2248>>2]=av;av=at+512|0;c[au+204>>2]=av;c[au+1228>>2]=av;c[au+2252>>2]=av;av=at+768|0;c[au+208>>2]=av;c[au+1232>>2]=av;c[au+2256>>2]=av;av=at+1024|0;c[au+212>>2]=av;c[au+1236>>2]=av;c[au+2260>>2]=av;av=at+1280|0;c[au+216>>2]=av;c[au+1240>>2]=av;c[au+2264>>2]=av;av=at+1536|0;c[au+220>>2]=av;c[au+1244>>2]=av;c[au+2268>>2]=av;av=at+1792|0;c[au+224>>2]=av;c[au+1248>>2]=av;c[au+2272>>2]=av;av=c[2443356]|0;c[au+228>>2]=av;c[au+1252>>2]=av;c[au+2276>>2]=av;at=av+256|0;c[au+232>>2]=at;c[au+1256>>2]=at;c[au+2280>>2]=at;at=av+512|0;c[au+236>>2]=at;c[au+1260>>2]=at;c[au+2284>>2]=at;at=av+768|0;c[au+240>>2]=at;c[au+1264>>2]=at;c[au+2288>>2]=at;at=av+1024|0;c[au+244>>2]=at;c[au+1268>>2]=at;c[au+2292>>2]=at;at=av+1280|0;c[au+248>>2]=at;c[au+1272>>2]=at;c[au+2296>>2]=at;at=av+1536|0;c[au+252>>2]=at;c[au+1276>>2]=at;c[au+2300>>2]=at;at=av+1792|0;c[au+256>>2]=at;c[au+1280>>2]=at;c[au+2304>>2]=at;at=c[2438770]|0;c[au+260>>2]=at;c[au+1284>>2]=at;c[au+2308>>2]=at;at=c[2438764]|0;c[au+264>>2]=at;c[au+1288>>2]=at;c[au+2312>>2]=at;at=c[3527424]|0;av=64;aw=64;while(1){aq=at+((aw<<8)+16384)|0;c[au+68+(aw<<2)>>2]=aq;c[au+68+(aw+512<<2)>>2]=aq;aq=av+1&65535;if((aq&65535)>127){aV=128;aW=128;break}else{av=aq;aw=aq&65535}}while(1){aw=at+((aW<<8)-32768)|0;c[au+68+(aW<<2)>>2]=aw;c[au+68+(aW+512<<2)>>2]=aw;aw=aV+1&65535;if((aw&65535)>255){break}else{aV=aw;aW=aw&65535}}c[au+3148>>2]=246;c[au+3152>>2]=2976;if(!ai){at=au|0;gGC(at|0,9660952,52)|0}c[2432850]=ap;c[2443776]=0;c[3528556]=-1;c[3528554]=-1;c[2113160]=1;at=gGq(3148)|0;aw=at;c[2433592]=aw;if((at|0)!=0){gGz(at|0,0,3148);c[at+3120>>2]=3128;c[at+3124>>2]=1840;c[at+3128>>2]=136;c[at+3132>>2]=1902;c[2432840]=0;av=0;do{c[aw+48+(av<<2)>>2]=0;av=av+1|0;}while((av|0)<768);c[2113158]=0;c[2415198]=0;av=c[2427044]|0;c[9681616+(av<<3)>>2]=809272;c[9681620+(av<<3)>>2]=0;c[2427044]=av+1}c[3528554]=0;f43(at);av=c[3528554]|0;aw=9731360+(av<<2)|0;ap=c[aw>>2]|0;c[2113158]=ap;au=c[3527382]|0;ai=c[2433592]|0;aq=0;al=0;while(1){as=au+(al<<8)|0;c[ai+(av*3148|0)+48+(al<<2)>>2]=as;c[ai+(av*3148|0)+48+(al+256<<2)>>2]=as;c[ai+(av*3148|0)+48+(al+512<<2)>>2]=as;as=aq+1&65535;if((as&65535)>15){break}else{aq=as;al=as&65535}}al=c[3527376]|0;aq=128;au=128;while(1){at=al+((au<<8)-32768)|0;c[ai+(av*3148|0)+48+(au<<2)>>2]=at;c[ai+(av*3148|0)+48+(au+512<<2)>>2]=at;at=aq+1&65535;if((at&65535)>255){break}else{aq=at;au=at&65535}}c[ai+(av*3148|0)+3120>>2]=1558;c[ai+(av*3148|0)+3124>>2]=2006;au=ai+(av*3148|0)|0;if((au|0)!=0){aq=au;gGC(aq|0,9660752,48)|0}c[aw>>2]=ap;c[3528554]=-1;if((b|0)==1){a[6517848]=0;aq=c[2443516]|0;if((c[3542200]|0)==0){ao=1;i=e;return ao|0}au=f+108|0;c[au>>2]=0;al=f+100|0;c[al>>2]=0;at=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[at&16383](f,25)|0;do{if((c[au>>2]|0)!=0){at=c[al>>2]|0;c[g>>2]=9534384;as=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[as&16383](g,25,0)|0;if((at|0)<1){ao=1;i=e;return ao|0}if((gzL(aq,0,25)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);c[2443666]=2047;c[2385780]=7;c[3528996]=3;gGz(9702704,0,32);gGz(9703728,0,32);gGz(9704752,0,32);aq=c[2427044]|0;c[9681616+(aq<<3)>>2]=809328;c[9681620+(aq<<3)>>2]=0;c[2427044]=aq+1;aq=c[2443518]|0;al=2;do{au=aq+((al<<3)-16)|0;c[9702704+(al<<2)>>2]=au;c[9703728+(al<<2)>>2]=au;c[9704752+(al<<2)>>2]=au;al=al+1|0;}while((al|0)<16);al=c[2443516]|0;aq=16;do{au=al+(aq<<3)|0;c[9702704+(aq<<2)>>2]=au;c[9704752+(aq<<2)>>2]=au;aq=aq+1|0;}while((aq|0)<256);c[3528586]=1534;c[2385590]=18}else if((b|0)==2){a[638664]=1;c[2430460]=942608;a[697936]=1;a[6517848]=1}else if((b|0)==0){a[818192]=1}U6(3e6,3426,3444,0);c[2438222]=15e5;c[2433520]=466;c[2406670]=206;c[3528466]=4026;c[2443840]=1364;h[745399]=1.0;a[3203272]=1;a[4447320]=0;c[2438070]=c[3527482];h[555914]=1.0;a[4447304]=1;if(!(a[2179312]|0)){aq=0;do{al=~~+U(+(+X(1.1,+(+(aq|0)))*16.0));au=(al|0)/2|0;ap=(al|0)/4|0;aw=(al|0)/8|0;av=aq<<4;ai=0;do{at=c[604464+(ai<<4)>>2]|0;as=ag(c[604468+(ai<<4)>>2]|0,al)|0;ar=ag(c[604472+(ai<<4)>>2]|0,au)|0;c[14101464+(ai+av<<2)>>2]=ag(as+aw+ar+(ag(c[604476+(ai<<4)>>2]|0,ap)|0)|0,at)|0;ai=ai+1|0;}while((ai|0)<16);aq=aq+1|0;}while((aq|0)<49);a[2179312]=1}c[2438080]=-2;c[2438078]=0;c[2443784]=~~(8.0e3/(a[9680]|0?32.0e3:0.0)*32768.0);aq=c[642608+(c[2436]<<2)>>2]|0;ai=c[aq+128>>2]|0;if((c[aq+52>>2]&4|0)==0){c[2113068]=ai;ap=c[aq+132>>2]|0;c[2113070]=ap;c[2443814]=ai;c[2440436]=ap;aX=ai;aY=ap}else{c[2113070]=ai;ap=c[aq+132>>2]|0;c[2113068]=ap;c[2440436]=ai;c[2443814]=ap;aX=ap;aY=ai}ai=ag(aX<<1,aY)|0;ap=gGq(ai)|0;c[2112926]=ap;if((ap|0)!=0){gGz(ap|0,0,ai|0)}dqX();ao=0;i=e;return ao|0}}while(0);c[2426788]=0;ao=1;i=e;return ao|0}function dqV(b,c){b=b|0;c=c|0;if((c|0)==0){a[9660787]=0;return}else{f44(1);return}}function dqW(a){a=a|0;var b=0,d=0;b=c[2113158]|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,15e5,0)|0;return a|0}function dqX(){var e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;c[3528556]=0;e=c[2433594]|0;c[2443776]=e;L93085:do{if((e|0)!=0){f=e|0;gGC(9660952,f|0,52)|0;switch(a[9660952]|0){case 0:{c[2309668]=638960;break L93085;break};case 1:{c[2309668]=634096;break L93085;break};case 3:{c[2309668]=639984;break L93085;break};case 4:{c[2309668]=7356016;break L93085;break};case 5:{c[2309668]=7354992;break L93085;break};case 2:{c[2309668]=638960;break L93085;break};default:{break L93085}}}}while(0);c[2113164]=c[2432850];gu[c[e+56>>2]&16383]();e=c[2443776]|0;if((e|0)!=0){f=e|0;gGC(f|0,9660952,52)|0}c[9731400+(c[3528556]<<2)>>2]=c[2113164];c[2443776]=0;c[3528556]=-1;c[3528554]=0;f43(c[2433592]|0);f=c[3528554]|0;c[2113158]=c[9731360+(f<<2)>>2];a[9660796]=0;a[9660797]=0;a[9660786]=0;a[9660787]=0;c[2415191]=0;a[9660784]=a[9660784]|80;e=c[2433592]|0;g=c[e+(f*3148|0)+1068>>2]|0;do{if((g|0)==0){i=c[e+(f*3148|0)+3120>>2]|0;if((i|0)==0){j=0;k=0;l=f;m=e;break}n=gj[i&4095](-2)|0;i=c[3528554]|0;o=c[2433592]|0;p=c[o+(i*3148|0)+1068>>2]|0;q=(n&255)<<8;if((p|0)!=0){r=p;s=q;t=i;u=o;v=76516;break}p=c[o+(i*3148|0)+3120>>2]|0;if((p|0)==0){j=0;k=q;l=i;m=o;break}o=gj[p&4095](-1)|0;j=o;k=q;l=c[3528554]|0;m=c[2433592]|0}else{r=g;s=d[g+254|0]<<8;t=f;u=e;v=76516}}while(0);if((v|0)==76516){j=a[r+255|0]|0;k=s;l=t;m=u}u=j&255|k;c[2415188]=u;b[4830376]=u&65535;u=m+(l*3148|0)|0;if((u|0)!=0){m=u;gGC(m|0,9660752,48)|0}c[9731360+(l<<2)>>2]=c[2113158];c[3528554]=-1;if(!(a[6517848]|a[818192])){f42();c[3527076]=0;c[3529006]=0;a[7190960]=0;a[7396832]=0;a[9628448]=0;a[9628440]=0;a[9628432]=0;a[14108296]=0;a[14108288]=0;a[14108280]=0;a[14116016]=0}c[2443825]=1073676288;c[2443824]=1073676288;c[2443817]=1073676288;c[2443816]=1073676288;h[883199]=0.0;c[3528506]=0;lw(c[3540986]|0);if(a[2179312]|0){c[2438080]=-2;c[2438078]=0;a[638024]=0;b[7059612]=0;a[9758224]=0;return}else{w=0}do{l=~~+U(+(+X(1.1,+(+(w|0)))*16.0));m=(l|0)/2|0;u=(l|0)/4|0;k=(l|0)/8|0;j=w<<4;t=0;do{s=c[604464+(t<<4)>>2]|0;r=ag(c[604468+(t<<4)>>2]|0,l)|0;v=ag(c[604472+(t<<4)>>2]|0,m)|0;c[14101464+(t+j<<2)>>2]=ag(r+k+v+(ag(c[604476+(t<<4)>>2]|0,u)|0)|0,s)|0;t=t+1|0;}while((t|0)<16);w=w+1|0;}while((w|0)<49);a[2179312]=1;c[2438080]=-2;c[2438078]=0;a[638024]=0;b[7059612]=0;a[9758224]=0;return}function dqY(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;if((b|0)==45060|(b|0)==45061|(b|0)==61444|(b|0)==61445){return}else if((b|0)==45062|(b|0)==61446){e=~d;a[c[2385724]|0]=e&1;a[c[2385622]|0]=e&2;a[c[3528182]|0]=e&4;a[c[2438898]|0]=e&8;a[c[3528746]|0]=d&64;return}else{e=b&1048560;if(!((e|0)==53248|(e|0)==36864)){return}e=((gD[c[(c[3531864]|0)+24>>2]&8191]()|0)*59659|0|0)/2222|0;f=(c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0;if((e|0)!=(f|0)){c[2443960]=e-f+(c[2443960]|0);UF(e)|0}e=b>>>1&7;if((e|0)==4){do{if(a[7045208]|0){c[2384378]=215;if((c[2384374]|0)!=223){g=-41;break}a[14125144]=-41;a[9706117]=1;g=-41}else{g=c[2384378]&255&-33}}while(0);c[2384374]=223;a[14125144]=g;a[9706117]=1;return}else if((e|0)==0|(e|0)==1){a[9579184+e|0]=d;return}else if((e|0)==6){c[2432768]=0;c[2432908]=1;return}else{return}}}function dqZ(b){b=b|0;var d=0,e=0,f=0;if((b|0)==45056|(b|0)==61440){d=a[9550728]|0;return d|0}else if((b|0)==45058|(b|0)==61442){d=a[9635448]|0;return d|0}else if((b|0)==45059|(b|0)==61443){d=a[9635449]|0;return d|0}else if((b|0)==45057|(b|0)==61441){d=a[9550729]|0;return d|0}else{e=b&1048560;if(!((e|0)==53248|(e|0)==36864)){d=0;return d|0}e=((gD[c[(c[3531864]|0)+24>>2]&8191]()|0)*59659|0|0)/2222|0;f=(c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0;if((e|0)!=(f|0)){c[2443960]=e-f+(c[2443960]|0);UF(e)|0}e=b>>>1&7;if((e|0)==5){d=(c[2432908]|0)!=0|0;return d|0}else if((e|0)==2|(e|0)==3){d=a[9553896+(e-2)|0]|0;return d|0}else{d=-1;return d|0}}return 0}function dq_(b,d){b=b|0;d=d|0;var f=0,g=0,h=0;if((b&1044480|0)==28672){f=b&4095;g=c[2387240]|0;a[g+f|0]=d;h=f>>>1;f=e[g+(h<<1)>>1]|0;g=f>>>4;c[(c[3530104]|0)+(h<<2)>>2]=f>>>11&1|f<<8&2048|g<<3&96|g<<4&224|f>>>8<<4&16;return}if((b|0)!=40960){return}a[c[3526970]|0]=d&1;a[c[3525094]|0]=(d&255)>>>4&1;return}function dq$(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>27){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4727180+(b*112|0)>>2];c[a+104>>2]=c[4727184+(b*112|0)>>2];c[a+108>>2]=c[4727188+(b*112|0)>>2];d=0;return d|0}function dq0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<28&(d|0)==0)){e=1;return e|0}c[a>>2]=4727080+(b*112|0);e=0;return e|0}function dq1(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1949736+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dq2(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>46){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5447776+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dq3(){return dri(4218)|0}function dq4(){var a=0,b=0,d=0,e=0;c[2113070]=0;c[2113068]=0;a=c[2112926]|0;if((a|0)!=0){gGr(a);c[2112926]=0}fyA();TE();a=c[2415034]|0;b=0;while(1){if((b|0)>=1024){d=76614;break}e=9638528+(b<<2)|0;if((c[e>>2]|0)==(a|0)){break}else{b=b+1|0}}if((d|0)==76614){c[2415034]=0;return 0}gGr(a);c[e>>2]=0;c[2415034]=0;return 0}function dq5(){var e=0,f=0,g=0,h=0,i=0;if((a[9624688]|0)!=0){e=c[2414742]|0;gGz(e|0,0,(c[2411778]|0)-e|0);c[1836234]=0;e=c[2439374]|0;c[3531864]=e;gf[c[e>>2]&2047](0);e=c[(c[3531864]|0)+8>>2]|0;gD[e&8191]()|0;c[1836234]=-1;gu[c[(c[3531864]|0)+4>>2]&16383]();c[1836234]=1;e=c[2439375]|0;c[3531864]=e;gf[c[e>>2]&2047](1);e=c[(c[3531864]|0)+8>>2]|0;gD[e&8191]()|0;c[1836234]=-1;gu[c[(c[3531864]|0)+4>>2]&16383]();c[3531864]=0;Ty()}c[2409128]=0;c[2409245]=0;c[2409362]=0;c[2409479]=0;c[2409508]=0;c[2409537]=0;c[2409566]=0;c[2409595]=0;e=c[2385548]|0;if((e|0)>0){gGz(9752472,0,((e|0)>1?e<<2:4)|0)}c[2433530]=0;b[4775364]=-1;e=0;f=-1;g=-1;do{f=((a[9634072+e|0]&1)<<e^f&255)&255;g=((a[9631856+e|0]&1)<<e^g&255)&255;e=e+1|0;}while((e|0)<8);a[9550728]=f;a[9550729]=g;c[2110938]=d[9629793]<<1&2|a[9629792]&1;c[2443960]=0;c[2443986]=0;c[2444036]=0;g=c[2439330]|0;if((g|0)!=0){f=g;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;f=0;do{c[1836234]=0;g=c[2439374]|0;c[3531864]=g;gf[c[g>>2]&2047](0);g=gj[c[(c[3531864]|0)+12>>2]&4095](2222)|0;c[2444036]=(c[2444036]|0)+g;if((f|0)==59){gG[c[(c[3531864]|0)+16>>2]&255](0,50,1);c[1836234]=-1;gu[c[(c[3531864]|0)+4>>2]&16383]();c[1836234]=1;g=c[2439375]|0;c[3531864]=g;gf[c[g>>2]&2047](1);g=gj[c[(c[3531864]|0)+12>>2]&4095](2222)|0;c[2443986]=(c[2443986]|0)+g;gG[c[(c[3531864]|0)+16>>2]&255](0,50,1)}else{c[1836234]=-1;gu[c[(c[3531864]|0)+4>>2]&16383]();c[1836234]=1;g=c[2439375]|0;c[3531864]=g;gf[c[g>>2]&2047](1);g=gj[c[(c[3531864]|0)+12>>2]&4095](2222)|0;c[2443986]=(c[2443986]|0)+g}c[1836234]=-1;gu[c[(c[3531864]|0)+4>>2]&16383]();c[3531864]=0;c[2443960]=(c[2443960]|0)+994;f=f+1|0;UF(f*994|0)|0;}while((f|0)<60);f=c[2438224]|0;g=gGS(-1597636608,28447,f,(f|0)<0|0?-1:0)|0;f=g;UF(59659)|0;g=c[2443826]|0;if((g|0)<1073676288){c[2443826]=g-f}g=c[2443827]|0;if((g|0)<1073676288){c[2443827]=g-f}g=(c[3528508]|0)-f|0;c[3528508]=(g|0)<0?0:g;g=c[2112964]|0;if((g|0)!=0){f=a[9688]|0?534:0;e=c[2438058]&3;if((e|0)==2){gg[c[3542122]&4095](g,f)}else if((e|0)==0){gg[c[3542112]&4095](g,f)}else if((e|0)==1){gg[c[3542124]&4095](g,f)}if((c[2438058]&4|0)!=0){Uu(1,g,f)}Uu(0,g,f)}f=c[1836236]|0;g=c[9757320+(f<<2)>>2]|0;if((g|0)!=0){e=g;gGC(e|0,9706056,76)|0}c[9752472+(f<<2)>>2]=c[2433530];c[14113936+(f<<2)>>2]=c[2076596];c[9669104+(f<<2)>>2]=c[3541536];c[1836236]=-1;if((c[2112968]|0)==0){h=c[2386582]|0;i=c[2386502]|0;gGC(h|0,i|0,2048)|0;return 0}dq6()|0;h=c[2386582]|0;i=c[2386502]|0;gGC(h|0,i|0,2048)|0;return 0}function dq6(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((a[9547752]|0)!=0){b=c[2387240]|0;f=c[3530104]|0;g=0;do{h=e[b+(g<<1)>>1]|0;i=h>>>4;c[f+(g<<2)>>2]=h>>>11&1|h<<8&2048|i<<3&96|i<<4&224|h>>>8<<4&16;g=g+1|0;}while((g|0)<2048);a[9547752]=0}drk(0);drl(0);drk(1);drl(32);drk(2);if((a[c[2385622]|0]|0)==0){j=c[2112926]|0}else{g=c[2386738]|0;f=c[2406504]|0;b=e[g+36>>1]|0;h=e[g+52>>1]|0;i=h<<1&254|e[g+50>>1]<<4&256|h>>>7&1;h=-16-(b<<1&254|e[g+34>>1]<<4&256|b>>>7&1)|0;b=c[3525094]|0;g=c[2112926]|0;k=c[3530464]|0;l=c[2113068]|0;m=c[2113070]|0;n=0;while(1){o=(n>>5<<4)-i|0;p=(o|0)<-15?o+512|0:o;o=(n<<4&496)+h|0;q=(o|0)<-15?o+512|0:o;if((p|0)<(l|0)&(q|0)<(m|0)){o=e[f+(n<<1)>>1]|0;SH(g,d[b]<<12|o&4095,p,q,o>>>12,4,15,512,k)}o=n+1|0;if((o|0)<1024){n=o}else{j=g;break}}}drk(3);g=c[2386334]|0;n=c[3530890]|0;k=64;do{b=e[g+(k<<1)>>1]|0;Sq(j,b>>>6&768|b&255,k<<3&248,(k>>5<<3)-16|0,b>>>8&15,4,15,1280,n);k=k+1|0;}while((k|0)<960);R8(c[3530104]|0);return 0}function dq7(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>27){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2902956+(b*112|0)>>2];c[a+104>>2]=c[2902960+(b*112|0)>>2];c[a+108>>2]=c[2902964+(b*112|0)>>2];d=0;return d|0}function dq8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<28&(d|0)==0)){e=1;return e|0}c[a>>2]=2902856+(b*112|0);e=0;return e|0}function dq9(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>27){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2899820+(b*112|0)>>2];c[a+104>>2]=c[2899824+(b*112|0)>>2];c[a+108>>2]=c[2899828+(b*112|0)>>2];d=0;return d|0}function dra(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<28&(d|0)==0)){e=1;return e|0}c[a>>2]=2899720+(b*112|0);e=0;return e|0}function drb(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>27){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2896684+(b*112|0)>>2];c[a+104>>2]=c[2896688+(b*112|0)>>2];c[a+108>>2]=c[2896692+(b*112|0)>>2];d=0;return d|0}function drc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<28&(d|0)==0)){e=1;return e|0}c[a>>2]=2896584+(b*112|0);e=0;return e|0}function drd(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>27){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4755684+(b*112|0)>>2];c[a+104>>2]=c[4755688+(b*112|0)>>2];c[a+108>>2]=c[4755692+(b*112|0)>>2];d=0;return d|0}function dre(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<28&(d|0)==0)){e=1;return e|0}c[a>>2]=4755584+(b*112|0);e=0;return e|0}function drf(){return dri(6454)|0}function drg(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>27){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4752548+(b*112|0)>>2];c[a+104>>2]=c[4752552+(b*112|0)>>2];c[a+108>>2]=c[4752556+(b*112|0)>>2];d=0;return d|0}function drh(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<28&(d|0)==0)){e=1;return e|0}c[a>>2]=4752448+(b*112|0);e=0;return e|0}function dri(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0;e=i;i=i+1680|0;f=e|0;g=e+112|0;h=e+120|0;j=e+232|0;k=e+240|0;l=e+352|0;m=e+360|0;n=e+472|0;o=e+480|0;p=e+592|0;q=e+600|0;r=e+712|0;s=e+720|0;t=e+832|0;u=e+840|0;v=e+952|0;w=e+960|0;x=e+1072|0;y=e+1080|0;z=e+1192|0;A=e+1200|0;B=e+1312|0;C=e+1320|0;D=e+1432|0;E=e+1440|0;F=e+1552|0;G=e+1560|0;H=e+1672|0;c[2415034]=0;c[3529490]=0;c[3529488]=1048576;c[3532600]=2097152;c[3532604]=2228224;c[3530890]=2359296;c[3530654]=2621440;c[3530464]=4718592;c[3530352]=6815744;c[3541206]=11010048;c[2386668]=11010048;c[3530104]=11141120;c[2414742]=11149312;c[3529494]=11149312;c[3529492]=11177984;c[3527312]=11202560;c[2386334]=11206656;c[2406584]=11208704;c[2406504]=11210752;c[2386738]=11212800;c[2386502]=11214848;c[2386582]=11218944;c[2387240]=11223040;c[3532602]=11227136;c[3526970]=11229184;c[3525094]=11229185;c[2385724]=11229186;c[2385622]=11229187;c[3528182]=11229188;c[2438898]=11229189;c[3528746]=11229190;c[2411778]=11229191;I=0;while(1){if((I|0)>=1024){break}J=9638528+(I<<2)|0;if((c[J>>2]|0)==0){K=76725;break}else{I=I+1|0}}do{if((K|0)==76725){I=gGq(11229191)|0;c[J>>2]=I;if((I|0)==0){break}c[2415034]=I;gGz(I|0,0,11229191);c[3529490]=I;c[3529488]=I+1048576;c[3532600]=I+2097152;c[3532604]=I+2228224;c[3530890]=I+2359296;c[3530654]=I+2621440;c[3530464]=I+4718592;c[3530352]=I+6815744;L=I+11010048|0;c[3541206]=L;c[2386668]=L;c[3530104]=I+11141120;L=I+11149312|0;c[2414742]=L;c[3529494]=L;c[3529492]=I+11177984;c[3527312]=I+11202560;c[2386334]=I+11206656;c[2406584]=I+11208704;c[2406504]=I+11210752;c[2386738]=I+11212800;c[2386502]=I+11214848;c[2386582]=I+11218944;c[2387240]=I+11223040;c[3532602]=I+11227136;c[3526970]=I+11229184;c[3525094]=I+11229185;c[2385724]=I+11229186;c[2385622]=I+11229187;c[3528182]=I+11229188;c[2438898]=I+11229189;c[3528746]=I+11229190;L=I+11229191|0;c[2411778]=L;c[2414326]=L;if((R6(I+655360|0,0,2)|0)!=0){M=1;i=e;return M|0}if((R6((c[3529490]|0)+655361|0,1,2)|0)!=0){M=1;i=e;return M|0}if((R6((c[3529490]|0)+786432|0,2,2)|0)!=0){M=1;i=e;return M|0}if((R6((c[3529490]|0)+786433|0,3,2)|0)!=0){M=1;i=e;return M|0}if((R6((c[3529488]|0)+917504|0,4,2)|0)!=0){M=1;i=e;return M|0}if((R6((c[3529488]|0)+917505|0,5,2)|0)!=0){M=1;i=e;return M|0}I=c[3532600]|0;if((c[3542200]|0)==0){M=1;i=e;return M|0}L=G+108|0;c[L>>2]=0;N=G+100|0;c[N>>2]=0;O=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[O&16383](G,6)|0;do{if((c[L>>2]|0)!=0){O=c[N>>2]|0;c[H>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](H,6,0)|0;if((O|0)<1){M=1;i=e;return M|0}if((gzL(I,0,6)|0)==0){break}else{M=1}i=e;return M|0}}while(0);I=c[3532600]|0;N=I+65536|0;L=I+32768|0;gGC(N|0,L|0,32768)|0;L=I+98304|0;gGC(L|0,I|0,32768)|0;I=c[3530890]|0;if((c[3542200]|0)==0){M=1;i=e;return M|0}L=E+108|0;c[L>>2]=0;N=E+100|0;c[N>>2]=0;O=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[O&16383](E,7)|0;do{if((c[L>>2]|0)!=0){O=c[N>>2]|0;c[F>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](F,7,0)|0;if((O|0)<1){M=1;i=e;return M|0}if((gzL(I,0,7)|0)==0){break}else{M=1}i=e;return M|0}}while(0);I=(c[3530890]|0)+65536|0;if((c[3542200]|0)==0){M=1;i=e;return M|0}N=C+108|0;c[N>>2]=0;L=C+100|0;c[L>>2]=0;O=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[O&16383](C,8)|0;do{if((c[N>>2]|0)!=0){O=c[L>>2]|0;c[D>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](D,8,0)|0;if((O|0)<1){M=1;i=e;return M|0}if((gzL(I,0,8)|0)==0){break}else{M=1}i=e;return M|0}}while(0);I=c[3530654]|0;if((c[3542200]|0)==0){M=1;i=e;return M|0}L=A+108|0;c[L>>2]=0;N=A+100|0;c[N>>2]=0;O=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[O&16383](A,9)|0;do{if((c[L>>2]|0)!=0){O=c[N>>2]|0;c[B>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](B,9,0)|0;if((O|0)<1){M=1;i=e;return M|0}if((gzL(I,0,9)|0)==0){break}else{M=1}i=e;return M|0}}while(0);I=(c[3530654]|0)+262144|0;if((c[3542200]|0)==0){M=1;i=e;return M|0}N=y+108|0;c[N>>2]=0;L=y+100|0;c[L>>2]=0;O=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[O&16383](y,10)|0;do{if((c[N>>2]|0)!=0){O=c[L>>2]|0;c[z>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](z,10,0)|0;if((O|0)<1){M=1;i=e;return M|0}if((gzL(I,0,10)|0)==0){break}else{M=1}i=e;return M|0}}while(0);I=(c[3530654]|0)+524288|0;if((c[3542200]|0)==0){M=1;i=e;return M|0}L=w+108|0;c[L>>2]=0;N=w+100|0;c[N>>2]=0;O=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[O&16383](w,11)|0;do{if((c[L>>2]|0)!=0){O=c[N>>2]|0;c[x>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](x,11,0)|0;if((O|0)<1){M=1;i=e;return M|0}if((gzL(I,0,11)|0)==0){break}else{M=1}i=e;return M|0}}while(0);I=(c[3530654]|0)+786432|0;if((c[3542200]|0)==0){M=1;i=e;return M|0}N=u+108|0;c[N>>2]=0;L=u+100|0;c[L>>2]=0;O=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[O&16383](u,12)|0;do{if((c[N>>2]|0)!=0){O=c[L>>2]|0;c[v>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](v,12,0)|0;if((O|0)<1){M=1;i=e;return M|0}if((gzL(I,0,12)|0)==0){break}else{M=1}i=e;return M|0}}while(0);I=(c[3530654]|0)+1048576|0;if((c[3542200]|0)==0){M=1;i=e;return M|0}L=s+108|0;c[L>>2]=0;N=s+100|0;c[N>>2]=0;O=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[O&16383](s,13)|0;do{if((c[L>>2]|0)!=0){O=c[N>>2]|0;c[t>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](t,13,0)|0;if((O|0)<1){M=1;i=e;return M|0}if((gzL(I,0,13)|0)==0){break}else{M=1}i=e;return M|0}}while(0);I=(c[3530654]|0)+1310720|0;if((c[3542200]|0)==0){M=1;i=e;return M|0}N=q+108|0;c[N>>2]=0;L=q+100|0;c[L>>2]=0;O=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[O&16383](q,14)|0;do{if((c[N>>2]|0)!=0){O=c[L>>2]|0;c[r>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](r,14,0)|0;if((O|0)<1){M=1;i=e;return M|0}if((gzL(I,0,14)|0)==0){break}else{M=1}i=e;return M|0}}while(0);I=c[3530464]|0;if((c[3542200]|0)==0){M=1;i=e;return M|0}L=o+108|0;c[L>>2]=0;N=o+100|0;c[N>>2]=0;O=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[O&16383](o,15)|0;do{if((c[L>>2]|0)!=0){O=c[N>>2]|0;c[p>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](p,15,0)|0;if((O|0)<1){M=1;i=e;return M|0}if((gzL(I,0,15)|0)==0){break}else{M=1}i=e;return M|0}}while(0);I=(c[3530464]|0)+262144|0;if((c[3542200]|0)==0){M=1;i=e;return M|0}N=m+108|0;c[N>>2]=0;L=m+100|0;c[L>>2]=0;O=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[O&16383](m,16)|0;do{if((c[N>>2]|0)!=0){O=c[L>>2]|0;c[n>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](n,16,0)|0;if((O|0)<1){M=1;i=e;return M|0}if((gzL(I,0,16)|0)==0){break}else{M=1}i=e;return M|0}}while(0);I=(c[3530464]|0)+524288|0;if((c[3542200]|0)==0){M=1;i=e;return M|0}L=k+108|0;c[L>>2]=0;N=k+100|0;c[N>>2]=0;O=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[O&16383](k,17)|0;do{if((c[L>>2]|0)!=0){O=c[N>>2]|0;c[l>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](l,17,0)|0;if((O|0)<1){M=1;i=e;return M|0}if((gzL(I,0,17)|0)==0){break}else{M=1}i=e;return M|0}}while(0);I=(c[3530464]|0)+786432|0;if((c[3542200]|0)==0){M=1;i=e;return M|0}N=h+108|0;c[N>>2]=0;L=h+100|0;c[L>>2]=0;O=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[O&16383](h,18)|0;do{if((c[N>>2]|0)!=0){O=c[L>>2]|0;c[j>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](j,18,0)|0;if((O|0)<1){M=1;i=e;return M|0}if((gzL(I,0,18)|0)==0){break}else{M=1}i=e;return M|0}}while(0);if((R6(c[3530352]|0,19,2)|0)!=0){M=1;i=e;return M|0}if((R6((c[3530352]|0)+1|0,20,2)|0)!=0){M=1;i=e;return M|0}if((R6((c[3530352]|0)+524288|0,21,2)|0)!=0){M=1;i=e;return M|0}if((R6((c[3530352]|0)+524289|0,22,2)|0)!=0){M=1;i=e;return M|0}if((R6((c[3530352]|0)+1048576|0,23,2)|0)!=0){M=1;i=e;return M|0}if((R6((c[3530352]|0)+1048577|0,24,2)|0)!=0){M=1;i=e;return M|0}if((R6((c[3530352]|0)+1572864|0,25,2)|0)!=0){M=1;i=e;return M|0}if((R6((c[3530352]|0)+1572865|0,26,2)|0)!=0){M=1;i=e;return M|0}I=c[2386668]|0;if((c[3542200]|0)==0){M=1;i=e;return M|0}L=f+108|0;c[L>>2]=0;N=f+100|0;c[N>>2]=0;O=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[O&16383](f,27)|0;do{if((c[L>>2]|0)==0){Q=0}else{O=c[N>>2]|0;c[g>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](g,27,0)|0;if((O|0)<1){M=1;i=e;return M|0}if((gzL(I,0,27)|0)==0){Q=0;break}else{M=1}i=e;return M|0}}while(0);while(1){if((Q|0)>=1024){break}R=9638528+(Q<<2)|0;if((c[R>>2]|0)==0){K=76799;break}else{Q=Q+1|0}}L93540:do{if((K|0)==76799){I=gGq(2097152)|0;c[R>>2]=I;if((I|0)==0){break}gGz(I|0,0,2097152);N=c[3530890]|0;gGC(I|0,N|0,131072)|0;L=0;do{O=L<<6;gGz(N+O|0,0,64);P=L<<7;S=0;do{T=1<<3-S;U=(c[611616+(S<<2)>>2]|0)+P|0;V=0;do{W=U+(c[608544+(V<<2)>>2]|0)|0;X=(V<<3)+O|0;Y=0;do{Z=W+(c[609552+(Y<<2)>>2]|0)|0;if(((d[I+((Z|0)/8|0)|0]|0)&128>>>((Z&7)>>>0)|0)!=0){Z=N+(X+Y)|0;a[Z]=(d[Z]|0|T)&255}Y=Y+1|0;}while((Y|0)<8);V=V+1|0;}while((V|0)<8);S=S+1|0;}while((S|0)<4);L=L+1|0;}while((L|0)<1024);L=c[3530654]|0;gGC(I|0,L|0,1572864)|0;N=0;do{S=N<<8;gGz(L+S|0,0,256);O=N<<9;P=0;do{V=1<<5-P;T=(c[611376+(P<<2)>>2]|0)+O|0;U=0;do{Y=T+(c[608544+(U<<2)>>2]|0)|0;X=(U<<4)+S|0;W=0;do{Z=Y+(c[609552+(W<<2)>>2]|0)|0;if(((d[I+((Z|0)/8|0)|0]|0)&128>>>((Z&7)>>>0)|0)!=0){Z=L+(X+W)|0;a[Z]=(d[Z]|0|V)&255}W=W+1|0;}while((W|0)<16);U=U+1|0;}while((U|0)<16);P=P+1|0;}while((P|0)<6);N=N+1|0;}while((N|0)<8192);N=c[3530464]|0;gGC(I|0,N|0,1048576)|0;L=0;do{P=L<<8;gGz(N+P|0,0,256);S=L<<9;O=0;do{U=1<<3-O;V=(c[611600+(O<<2)>>2]|0)+S|0;T=0;do{W=V+(c[608544+(T<<2)>>2]|0)|0;X=(T<<4)+P|0;Y=0;do{Z=W+(c[609552+(Y<<2)>>2]|0)|0;if(((d[I+((Z|0)/8|0)|0]|0)&128>>>((Z&7)>>>0)|0)!=0){Z=N+(X+Y)|0;a[Z]=(d[Z]|0|U)&255}Y=Y+1|0;}while((Y|0)<16);T=T+1|0;}while((T|0)<16);O=O+1|0;}while((O|0)<4);L=L+1|0;}while((L|0)<8192);L=c[3530352]|0;gGC(I|0,L|0,2097152)|0;N=0;while(1){O=N<<8;gGz(L+O|0,0,256);P=N<<10;S=0;do{T=1<<3-S;U=(c[687256+(S<<2)>>2]|0)+P|0;V=0;do{Y=U+(c[611840+(V<<2)>>2]|0)|0;X=(V<<4)+O|0;W=0;do{Z=Y+(c[609424+(W<<2)>>2]|0)|0;if(((d[I+((Z|0)/8|0)|0]|0)&128>>>((Z&7)>>>0)|0)!=0){Z=L+(X+W)|0;a[Z]=(d[Z]|0|T)&255}W=W+1|0;}while((W|0)<16);V=V+1|0;}while((V|0)<16);S=S+1|0;}while((S|0)<4);S=N+1|0;if((S|0)<16384){N=S}else{_=0;break}}while(1){if((_|0)>=1024){break L93540}$=9638528+(_<<2)|0;if((c[$>>2]|0)==(I|0)){break}else{_=_+1|0}}gGr(I);c[$>>2]=0}}while(0);fyz(0,8,0);fyz(1,8,0);gu[b&16383]();c[1836234]=1;N=c[2439375]|0;c[3531864]=N;gf[c[N>>2]&2047](1);N=c[3529492]|0;L=c[3531864]|0;c[L+44>>2]=N;c[L+48>>2]=N;c[L+52>>2]=N;c[L+56>>2]=N;c[L+60>>2]=N;c[L+64>>2]=N;c[L+68>>2]=N;c[L+72>>2]=N;c[L+76>>2]=N;c[L+80>>2]=N;c[L+84>>2]=N;c[L+88>>2]=N;c[L+2092>>2]=N;c[L+2096>>2]=N;c[L+2100>>2]=N;c[L+2104>>2]=N;c[L+2108>>2]=N;c[L+2112>>2]=N;c[L+2116>>2]=N;c[L+2120>>2]=N;c[L+2124>>2]=N;c[L+2128>>2]=N;c[L+2132>>2]=N;c[L+2136>>2]=N;c[L+4140>>2]=N;c[L+6188>>2]=N;c[L+4144>>2]=N;c[L+6192>>2]=N;c[L+4148>>2]=N;c[L+6196>>2]=N;c[L+4152>>2]=N;c[L+6200>>2]=N;c[L+4156>>2]=N;c[L+6204>>2]=N;c[L+4160>>2]=N;c[L+6208>>2]=N;c[L+4164>>2]=N;c[L+6212>>2]=N;c[L+4168>>2]=N;c[L+6216>>2]=N;c[L+4172>>2]=N;c[L+6220>>2]=N;c[L+4176>>2]=N;c[L+6224>>2]=N;c[L+4180>>2]=N;c[L+6228>>2]=N;c[L+4184>>2]=N;c[L+6232>>2]=N;N=(c[2406584]|0)-24576|0;c[L+92>>2]=N;c[L+2140>>2]=N;c[L+4188>>2]=N;c[L+6236>>2]=N;N=(c[2406504]|0)-26624|0;c[L+96>>2]=N;c[L+2144>>2]=N;c[L+4192>>2]=N;c[L+6240>>2]=N;N=(c[2387240]|0)-28672|0;c[L+100>>2]=N;c[L+104>>2]=N;c[L+4196>>2]=N;c[L+6244>>2]=N;c[L+4200>>2]=N;c[L+6248>>2]=N;N=(c[3527312]|0)-32768|0;c[L+108>>2]=N;c[L+112>>2]=N;c[L+2156>>2]=N;c[L+2160>>2]=N;c[L+4204>>2]=N;c[L+6252>>2]=N;c[L+4208>>2]=N;c[L+6256>>2]=N;N=c[3529488]|0;S=384;while(1){c[L+44+(S<<2)>>2]=N;O=S+1|0;if((O|0)<512){S=O}else{aa=384;break}}do{c[L+4140+(aa<<2)>>2]=N;c[L+6188+(aa<<2)>>2]=N;aa=aa+1|0;}while((aa|0)<512);c[L+8240>>2]=2086;c[1836234]=-1;gu[c[L+4>>2]&16383]();c[3531864]=0;Tz(0,131072,1e4);N=c[642608+(c[2436]<<2)>>2]|0;S=c[N+128>>2]|0;if((c[N+52>>2]&4|0)==0){c[2113068]=S;O=c[N+132>>2]|0;c[2113070]=O;c[2443814]=S;c[2440436]=O;ab=S;ac=O}else{c[2113070]=S;O=c[N+132>>2]|0;c[2113068]=O;c[2440436]=S;c[2443814]=O;ab=O;ac=S}S=ag(ab<<1,ac)|0;O=gGq(S)|0;c[2112926]=O;if((O|0)!=0){gGz(O|0,0,S|0)}S=c[2414742]|0;gGz(S|0,0,(c[2411778]|0)-S|0);c[1836234]=0;S=c[2439374]|0;c[3531864]=S;gf[c[S>>2]&2047](0);gD[c[(c[3531864]|0)+8>>2]&8191]()|0;c[1836234]=-1;gu[c[(c[3531864]|0)+4>>2]&16383]();c[1836234]=1;S=c[2439375]|0;c[3531864]=S;gf[c[S>>2]&2047](1);gD[c[(c[3531864]|0)+8>>2]&8191]()|0;c[1836234]=-1;gu[c[(c[3531864]|0)+4>>2]&16383]();c[3531864]=0;Ty();M=0;i=e;return M|0}}while(0);c[2415034]=0;M=1;i=e;return M|0}function drj(){var a=0,b=0,d=0,e=0,f=0;c[1836234]=0;a=c[2439374]|0;c[3531864]=a;gf[c[a>>2]&2047](0);a=c[3529494]|0;b=c[3531864]|0;c[b+44>>2]=a;c[b+48>>2]=a;c[b+52>>2]=a;c[b+56>>2]=a;c[b+60>>2]=a;c[b+64>>2]=a;c[b+68>>2]=a;c[b+72>>2]=a;c[b+76>>2]=a;c[b+80>>2]=a;c[b+84>>2]=a;c[b+88>>2]=a;c[b+92>>2]=a;c[b+96>>2]=a;c[b+2092>>2]=a;c[b+2096>>2]=a;c[b+2100>>2]=a;c[b+2104>>2]=a;c[b+2108>>2]=a;c[b+2112>>2]=a;c[b+2116>>2]=a;c[b+2120>>2]=a;c[b+2124>>2]=a;c[b+2128>>2]=a;c[b+2132>>2]=a;c[b+2136>>2]=a;c[b+2140>>2]=a;c[b+2144>>2]=a;c[b+4140>>2]=a;c[b+6188>>2]=a;c[b+4144>>2]=a;c[b+6192>>2]=a;c[b+4148>>2]=a;c[b+6196>>2]=a;c[b+4152>>2]=a;c[b+6200>>2]=a;c[b+4156>>2]=a;c[b+6204>>2]=a;c[b+4160>>2]=a;c[b+6208>>2]=a;c[b+4164>>2]=a;c[b+6212>>2]=a;c[b+4168>>2]=a;c[b+6216>>2]=a;c[b+4172>>2]=a;c[b+6220>>2]=a;c[b+4176>>2]=a;c[b+6224>>2]=a;c[b+4180>>2]=a;c[b+6228>>2]=a;c[b+4184>>2]=a;c[b+6232>>2]=a;c[b+4188>>2]=a;c[b+6236>>2]=a;c[b+4192>>2]=a;c[b+6240>>2]=a;a=(c[2386502]|0)-28672|0;c[b+100>>2]=a;c[b+104>>2]=a;c[b+2148>>2]=a;c[b+2152>>2]=a;c[b+4196>>2]=a;c[b+6244>>2]=a;c[b+4200>>2]=a;c[b+6248>>2]=a;a=(c[2386334]|0)-32768|0;c[b+108>>2]=a;c[b+2156>>2]=a;c[b+4204>>2]=a;c[b+6252>>2]=a;a=(c[2386738]|0)-49152|0;c[b+140>>2]=a;c[b+2188>>2]=a;c[b+4236>>2]=a;c[b+6284>>2]=a;a=(c[3527312]|0)-57344|0;c[b+156>>2]=a;c[b+160>>2]=a;c[b+2204>>2]=a;c[b+2208>>2]=a;c[b+4252>>2]=a;c[b+6300>>2]=a;c[b+4256>>2]=a;c[b+6304>>2]=a;a=c[3529490]|0;d=320;while(1){c[b+44+(d<<2)>>2]=a;e=d+1|0;if((e|0)<512){d=e}else{f=320;break}}do{c[b+4140+(f<<2)>>2]=a;c[b+6188+(f<<2)>>2]=a;f=f+1|0;}while((f|0)<512);c[b+8240>>2]=820;c[b+8236>>2]=2890;c[1836234]=-1;gu[c[b+4>>2]&16383]();c[3531864]=0;return}function drk(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;if((a[c[2438898]|0]|0)==0){return}f=c[2386582]|0;g=c[3528746]|0;h=c[2112926]|0;i=c[3530352]|0;j=2044;do{k=e[f+(j<<1)>>1]|0;l=e[f+((j|1)<<1)>>1]|0;m=e[f+((j|2)<<1)>>1]|0;do{if((b[f+((j|3)<<1)>>1]&3840)==3840){if((m>>>13&3|0)!=(d|0)){break}n=k&8192;o=k&16384;p=k&255;q=(k>>>8&31)+48|0;r=(m&256|0)==0?m&255:m|-256;s=l&16383;if((a[g]|0)==0){t=p;u=o;v=n;w=r}else{t=240-p|0;u=o>>>14^1;v=n>>>13^1;w=240-r|0}r=(v|0)!=0;n=t-16|0;if((u|0)==0){if(r){SJ(h,s,w,n,q,4,15,0,i);break}else{SH(h,s,w,n,q,4,15,0,i);break}}else{if(r){SN(h,s,w,n,q,4,15,0,i);break}else{SL(h,s,w,n,q,4,15,0,i);break}}}}while(0);j=j-4|0;}while((j|0)>-1);return}function drl(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;if((a[c[2385724]|0]|0)==0){if((f|0)!=0){return}g=c[2112926]|0;gGz(g|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);return}g=c[2386738]|0;h=c[2406584]|0;i=e[g+4>>1]|0;j=e[g+20>>1]|0;k=j<<1&254|e[g+18>>1]<<4&256|j>>>7&1;j=c[2113070]|0;if((j|0)<=0){return}l=(i>>>7&1|i<<1&254|e[g+2>>1]<<4&256)+16|0;g=c[2113068]|0;i=c[3526970]|0;m=c[3530654]|0;n=g+16|0;o=0;p=c[2112926]|0;while(1){q=l+o|0;if((g+16|0)>0){r=q>>>4&31;s=q<<4&240;q=0;do{t=q+k|0;u=e[h+((t>>>4<<5&992|r)<<1)>>1]|0;v=(d[i]<<12|u&4095)<<8|s;w=u>>>12<<6;u=q-(t&15)|0;t=0;while(1){do{if((u|0)>-1&(u|0)<(g|0)){x=d[m+(t+v)|0]|0;if((x&32|0)!=(f|0)){break}y=x|w;z=(x&16|0)==0?y:y|1024;b[p+(u<<1)>>1]=(z>>>2&16368|z&15)&65535}}while(0);z=t+1|0;if((z|0)>=16){break}u=u+1|0;t=z}q=q+16|0;}while((q|0)<(n|0))}q=o+1|0;if((q|0)<(j|0)){o=q;p=p+(g<<1)|0}else{break}}return}function drm(){var a=0,b=0,d=0,e=0,f=0;c[1836234]=0;a=c[2439374]|0;c[3531864]=a;gf[c[a>>2]&2047](0);a=c[3529494]|0;b=c[3531864]|0;c[b+44>>2]=a;c[b+48>>2]=a;c[b+52>>2]=a;c[b+56>>2]=a;c[b+60>>2]=a;c[b+64>>2]=a;c[b+68>>2]=a;c[b+72>>2]=a;c[b+76>>2]=a;c[b+80>>2]=a;c[b+84>>2]=a;c[b+88>>2]=a;c[b+92>>2]=a;c[b+96>>2]=a;c[b+2092>>2]=a;c[b+2096>>2]=a;c[b+2100>>2]=a;c[b+2104>>2]=a;c[b+2108>>2]=a;c[b+2112>>2]=a;c[b+2116>>2]=a;c[b+2120>>2]=a;c[b+2124>>2]=a;c[b+2128>>2]=a;c[b+2132>>2]=a;c[b+2136>>2]=a;c[b+2140>>2]=a;c[b+2144>>2]=a;c[b+4140>>2]=a;c[b+6188>>2]=a;c[b+4144>>2]=a;c[b+6192>>2]=a;c[b+4148>>2]=a;c[b+6196>>2]=a;c[b+4152>>2]=a;c[b+6200>>2]=a;c[b+4156>>2]=a;c[b+6204>>2]=a;c[b+4160>>2]=a;c[b+6208>>2]=a;c[b+4164>>2]=a;c[b+6212>>2]=a;c[b+4168>>2]=a;c[b+6216>>2]=a;c[b+4172>>2]=a;c[b+6220>>2]=a;c[b+4176>>2]=a;c[b+6224>>2]=a;c[b+4180>>2]=a;c[b+6228>>2]=a;c[b+4184>>2]=a;c[b+6232>>2]=a;c[b+4188>>2]=a;c[b+6236>>2]=a;c[b+4192>>2]=a;c[b+6240>>2]=a;a=(c[2386502]|0)-28672|0;c[b+100>>2]=a;c[b+104>>2]=a;c[b+2148>>2]=a;c[b+2152>>2]=a;c[b+4196>>2]=a;c[b+6244>>2]=a;c[b+4200>>2]=a;c[b+6248>>2]=a;a=(c[2386738]|0)-32768|0;c[b+108>>2]=a;c[b+2156>>2]=a;c[b+4204>>2]=a;c[b+6252>>2]=a;a=(c[3527312]|0)-40960|0;c[b+124>>2]=a;c[b+128>>2]=a;c[b+2172>>2]=a;c[b+2176>>2]=a;c[b+4220>>2]=a;c[b+6268>>2]=a;c[b+4224>>2]=a;c[b+6272>>2]=a;a=(c[2386334]|0)-49152|0;c[b+140>>2]=a;c[b+2188>>2]=a;c[b+4236>>2]=a;c[b+6284>>2]=a;a=c[3529490]|0;d=320;while(1){c[b+44+(d<<2)>>2]=a;e=d+1|0;if((e|0)<512){d=e}else{f=320;break}}do{c[b+4140+(f<<2)>>2]=a;c[b+6188+(f<<2)>>2]=a;f=f+1|0;}while((f|0)<512);c[b+8240>>2]=820;c[b+8236>>2]=2890;c[1836234]=-1;gu[c[b+4>>2]&16383]();c[3531864]=0;return}function drn(b){b=b|0;var c=0;switch(b&65535|0){case 49152:{c=~a[9625848];break};case 49155:{c=a[9658024]|0;break};case 49153:{c=~a[9625840];break};case 49154:{c=~a[9625832];break};case 49159:{c=(e[4853036]|0)>>>8&255;break};case 49156:{c=a[9658025]|0;break};default:{c=0}}return c|0}function dro(b){b=b|0;var c=0;switch(b&65535|0){case 49156:{c=a[9658025]|0;break};case 49155:{c=a[9658024]|0;break};case 49152:{c=~a[9625848];break};case 49153:{c=~a[9625840];break};case 49154:{c=~a[9625832];break};default:{c=0}}return c|0}function drp(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;switch(b&65535|0){case 55298:{a[9774360]=d;return};case 55299:{a[9759904]=d;return};case 51204:{b=d&28;a[14119344]=b;e=c[3529126]|0;f=c[9757320+(c[1836236]<<2)>>2]|0;g=((b&255)<<12)+32768|0;b=128;h=128;while(1){c[f+76+(h<<2)>>2]=e+(g+(h<<8));i=b+1&65535;if((i&65535)>191){j=128;k=128;break}else{b=i;h=i&65535}}while(1){h=e+(g+(k<<8))|0;c[f+76+(k+512<<2)>>2]=h;c[f+76+(k+768<<2)>>2]=h;h=j+1&65535;if((h&65535)>191){break}else{j=h;k=h&65535}}a[14124232]=d&-128;return};case 51200:{a[9758216]=d;return};case 55302:{a[9626368]=d&16;a[9626360]=d&32;a[9773592]=d&64;return};case 55297:{a[9774409]=d;return};case 55296:{a[9774408]=d;return};case 55300:{a[9759905]=d;return};default:{return}}}function drq(a){a=a|0;return 0}function drr(a,b){a=a|0;b=b|0;return}function drs(b){b=b|0;return(b<<16>>16==-14336?a[9758216]|0:0)|0}function drt(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=b&65535;if((e|0)==57345){lS(0,1,d);return}else if((e|0)==57346){b=c[3541518]|0;f=b+19280|0;a[b+19328|0]=d;g=d&255;if((d&255)<16){c[14168912+(((c[2383582]|0)+1|0)*252|0)>>2]=g&15}if((d-45&255)>=3){return}if((g|0)==47){a[b+19336|0]=0;h=0}else if((g|0)==0){a[b+19336|0]=2;h=2}else if((g|0)==45){i=b+19336|0;j=a[i]|2;a[i]=j;h=j}else if((g|0)==46){g=b+19336|0;j=a[g]|1;a[g]=j;h=j}else{h=a[b+19336|0]|0}b=h&3;h=c[7461744+(b<<2)>>2]|0;lI(f,h,h,c[7461728+(b<<2)>>2]|0);return}else if((e|0)==57347){lS(1,1,d);return}else if((e|0)==57344){e=c[3541518]|0;b=e+256|0;a[e+304|0]=d;h=d&255;if((d&255)<16){c[14168912+((c[2383582]|0)*252|0)>>2]=h&15}if((d-45&255)>=3){return}if((h|0)==45){d=e+312|0;f=a[d]|2;a[d]=f;k=f}else if((h|0)==46){f=e+312|0;d=a[f]|1;a[f]=d;k=d}else if((h|0)==47){a[e+312|0]=0;k=0}else if((h|0)==0){a[e+312|0]=2;k=2}else{k=a[e+312|0]|0}e=k&3;k=c[7461744+(e<<2)>>2]|0;lI(b,k,k,c[7461728+(e<<2)>>2]|0);return}else{return}}function dru(a){a=a|0;return 0}function drv(a,b){a=a|0;b=b|0;return}function drw(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>37){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7414804+(b*112|0)>>2];c[a+104>>2]=c[7414808+(b*112|0)>>2];c[a+108>>2]=c[7414812+(b*112|0)>>2];d=0;return d|0}function drx(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<38&(d|0)==0)){e=1;return e|0}c[a>>2]=7414704+(b*112|0);e=0;return e|0}function dry(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6935136+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function drz(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>54){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7444912+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function drA(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0;e=i;i=i+4200|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;B=e+1200|0;C=e+1312|0;D=e+1320|0;E=e+1432|0;F=e+1440|0;G=e+1552|0;H=e+1560|0;I=e+1672|0;J=e+1680|0;K=e+1792|0;L=e+1800|0;M=e+1912|0;N=e+1920|0;O=e+2032|0;P=e+2040|0;Q=e+2152|0;R=e+2160|0;S=e+2272|0;T=e+2280|0;U=e+2392|0;V=e+2400|0;W=e+2512|0;X=e+2520|0;Y=e+2632|0;Z=e+2640|0;_=e+2752|0;$=e+2760|0;aa=e+2872|0;ab=e+2880|0;ac=e+2992|0;ad=e+3e3|0;ae=e+3112|0;af=e+3120|0;ah=e+3232|0;ai=e+3240|0;aj=e+3352|0;ak=e+3360|0;al=e+3472|0;am=e+3480|0;an=e+3592|0;ao=e+3600|0;ap=e+3712|0;aq=e+3720|0;ar=e+3832|0;as=e+3840|0;at=e+3952|0;au=e+3960|0;av=e+4072|0;aw=e+4080|0;ax=e+4192|0;c[2426786]=0;c[3529126]=0;c[3529114]=196608;c[3529864]=229376;c[2443502]=229632;c[3527344]=229888;c[2432720]=230144;c[2433458]=230400;c[2432724]=230656;c[2437758]=230912;c[2433456]=231168;c[2429760]=231424;c[2429524]=231680;c[2443582]=231936;c[2439974]=264704;c[2405694]=297472;c[3529156]=297472;c[3529146]=301568;c[3527220]=303616;c[2439622]=304640;c[2443426]=305664;c[2411776]=309760;c[2406534]=309760;c[3527478]=440832;c[3531068]=571904;c[3529586]=1096192;c[3530102]=1620480;ay=0;while(1){if((ay|0)>=1024){break}az=9638528+(ay<<2)|0;if((c[az>>2]|0)==0){aA=77058;break}else{ay=ay+1|0}}do{if((aA|0)==77058){ay=gGq(1624064)|0;c[az>>2]=ay;if((ay|0)==0){break}c[2426786]=ay;gGz(ay|0,0,1624064);c[3529126]=ay;c[3529114]=ay+196608;c[3529864]=ay+229376;c[2443502]=ay+229632;c[3527344]=ay+229888;c[2432720]=ay+230144;c[2433458]=ay+230400;c[2432724]=ay+230656;c[2437758]=ay+230912;c[2433456]=ay+231168;c[2429760]=ay+231424;c[2429524]=ay+231680;c[2443582]=ay+231936;c[2439974]=ay+264704;aB=ay+297472|0;c[2405694]=aB;c[3529156]=aB;c[3529146]=ay+301568;c[3527220]=ay+303616;c[2439622]=ay+304640;c[2443426]=ay+305664;aB=ay+309760|0;c[2411776]=aB;c[2406534]=aB;c[3527478]=ay+440832;c[3531068]=ay+571904;c[3529586]=ay+1096192;c[3530102]=ay+1620480;c[2414324]=ay+1624064;ay=0;while(1){if((ay|0)>=1024){aC=0;break}aD=9638528+(ay<<2)|0;if((c[aD>>2]|0)==0){aA=77063;break}else{ay=ay+1|0}}do{if((aA|0)==77063){ay=gGq(262144)|0;c[aD>>2]=ay;if((ay|0)==0){aC=0;break}gGz(ay|0,0,262144);aC=ay}}while(0);c[3529536]=aC;ay=c[3529126]|0;if((c[3542200]|0)==0){aE=1;i=e;return aE|0}aB=aw+108|0;c[aB>>2]=0;aF=aw+100|0;c[aF>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](aw,0)|0;do{if((c[aB>>2]|0)!=0){aG=c[aF>>2]|0;c[ax>>2]=9534384;aH=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aH&16383](ax,0,0)|0;if((aG|0)<1){aE=1;i=e;return aE|0}if((gzL(ay,0,0)|0)==0){break}else{aE=1}i=e;return aE|0}}while(0);ay=(c[3529126]|0)+65536|0;if((c[3542200]|0)==0){aE=1;i=e;return aE|0}aF=au+108|0;c[aF>>2]=0;aB=au+100|0;c[aB>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](au,1)|0;do{if((c[aF>>2]|0)!=0){aG=c[aB>>2]|0;c[av>>2]=9534384;aH=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aH&16383](av,1,0)|0;if((aG|0)<1){aE=1;i=e;return aE|0}if((gzL(ay,0,1)|0)==0){break}else{aE=1}i=e;return aE|0}}while(0);ay=(c[3529126]|0)+131072|0;if((c[3542200]|0)==0){aE=1;i=e;return aE|0}aB=as+108|0;c[aB>>2]=0;aF=as+100|0;c[aF>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](as,2)|0;do{if((c[aB>>2]|0)!=0){aG=c[aF>>2]|0;c[at>>2]=9534384;aH=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aH&16383](at,2,0)|0;if((aG|0)<1){aE=1;i=e;return aE|0}if((gzL(ay,0,2)|0)==0){break}else{aE=1}i=e;return aE|0}}while(0);ay=c[3529114]|0;if((c[3542200]|0)==0){aE=1;i=e;return aE|0}aF=aq+108|0;c[aF>>2]=0;aB=aq+100|0;c[aB>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](aq,3)|0;do{if((c[aF>>2]|0)!=0){aG=c[aB>>2]|0;c[ar>>2]=9534384;aH=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aH&16383](ar,3,0)|0;if((aG|0)<1){aE=1;i=e;return aE|0}if((gzL(ay,0,3)|0)==0){break}else{aE=1}i=e;return aE|0}}while(0);ay=c[3529536]|0;if((c[3542200]|0)==0){aE=1;i=e;return aE|0}aB=ao+108|0;c[aB>>2]=0;aF=ao+100|0;c[aF>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](ao,4)|0;do{if((c[aB>>2]|0)!=0){aG=c[aF>>2]|0;c[ap>>2]=9534384;aH=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aH&16383](ap,4,0)|0;if((aG|0)<1){aE=1;i=e;return aE|0}if((gzL(ay,0,4)|0)==0){break}else{aE=1}i=e;return aE|0}}while(0);ay=c[3529536]|0;aF=c[2406534]|0;aB=0;do{aG=aB<<6;gGz(aF+aG|0,0,64);aH=aB<<7;aI=aH|4;aJ=0;while(1){aK=aI+(c[6669224+(aJ<<2)>>2]|0)|0;aL=(aJ<<3)+aG|0;aM=0;do{aN=aK+(c[612480+(aM<<2)>>2]|0)|0;if(((d[ay+((aN|0)/8|0)|0]|0)&128>>>((aN&7)>>>0)|0)!=0){aN=aF+(aL+aM)|0;a[aN]=a[aN]|2}aM=aM+1|0;}while((aM|0)<8);aM=aJ+1|0;if((aM|0)<8){aJ=aM}else{aO=0;break}}do{aJ=aH+(c[6669224+(aO<<2)>>2]|0)|0;aI=(aO<<3)+aG|0;aM=0;do{aL=aJ+(c[612480+(aM<<2)>>2]|0)|0;if(((d[ay+((aL|0)/8|0)|0]|0)&128>>>((aL&7)>>>0)|0)!=0){aL=aF+(aI+aM)|0;a[aL]=a[aL]|1}aM=aM+1|0;}while((aM|0)<8);aO=aO+1|0;}while((aO|0)<8);aB=aB+1|0;}while((aB|0)<2048);gGz(ay|0,0,262144);if((c[3542200]|0)==0){aE=1;i=e;return aE|0}aB=am+108|0;c[aB>>2]=0;aF=am+100|0;c[aF>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](am,13)|0;do{if((c[aB>>2]|0)!=0){aG=c[aF>>2]|0;c[an>>2]=9534384;aH=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aH&16383](an,13,0)|0;if((aG|0)<1){aE=1;i=e;return aE|0}if((gzL(ay,0,13)|0)==0){break}else{aE=1}i=e;return aE|0}}while(0);ay=(c[3529536]|0)+32768|0;if((c[3542200]|0)==0){aE=1;i=e;return aE|0}aF=ak+108|0;c[aF>>2]=0;aB=ak+100|0;c[aB>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](ak,14)|0;do{if((c[aF>>2]|0)!=0){aG=c[aB>>2]|0;c[al>>2]=9534384;aH=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aH&16383](al,14,0)|0;if((aG|0)<1){aE=1;i=e;return aE|0}if((gzL(ay,0,14)|0)==0){break}else{aE=1}i=e;return aE|0}}while(0);ay=c[3529536]|0;aB=c[3527478]|0;aF=0;do{aG=aF<<10;gGz(aB+aG|0,0,1024);aH=aF<<11;aM=0;do{aI=1<<3-aM;aJ=(c[613264+(aM<<2)>>2]|0)+aH|0;aL=0;do{aK=aJ+(c[609168+(aL<<2)>>2]|0)|0;aN=(aL<<5)+aG|0;aP=0;do{aQ=aK+(c[610736+(aP<<2)>>2]|0)|0;if(((d[ay+((aQ|0)/8|0)|0]|0)&128>>>((aQ&7)>>>0)|0)!=0){aQ=aB+(aN+aP)|0;a[aQ]=(d[aQ]|0|aI)&255}aP=aP+1|0;}while((aP|0)<32);aL=aL+1|0;}while((aL|0)<32);aM=aM+1|0;}while((aM|0)<4);aF=aF+1|0;}while((aF|0)<128);gGz(ay|0,0,262144);if((c[3542200]|0)==0){aE=1;i=e;return aE|0}aF=ai+108|0;c[aF>>2]=0;aB=ai+100|0;c[aB>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](ai,5)|0;do{if((c[aF>>2]|0)!=0){aM=c[aB>>2]|0;c[aj>>2]=9534384;aG=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aG&16383](aj,5,0)|0;if((aM|0)<1){aE=1;i=e;return aE|0}if((gzL(ay,0,5)|0)==0){break}else{aE=1}i=e;return aE|0}}while(0);ay=(c[3529536]|0)+32768|0;if((c[3542200]|0)==0){aE=1;i=e;return aE|0}aB=af+108|0;c[aB>>2]=0;aF=af+100|0;c[aF>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](af,6)|0;do{if((c[aB>>2]|0)!=0){aM=c[aF>>2]|0;c[ah>>2]=9534384;aG=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aG&16383](ah,6,0)|0;if((aM|0)<1){aE=1;i=e;return aE|0}if((gzL(ay,0,6)|0)==0){break}else{aE=1}i=e;return aE|0}}while(0);ay=(c[3529536]|0)+65536|0;if((c[3542200]|0)==0){aE=1;i=e;return aE|0}aF=ad+108|0;c[aF>>2]=0;aB=ad+100|0;c[aB>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](ad,7)|0;do{if((c[aF>>2]|0)!=0){aM=c[aB>>2]|0;c[ae>>2]=9534384;aG=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aG&16383](ae,7,0)|0;if((aM|0)<1){aE=1;i=e;return aE|0}if((gzL(ay,0,7)|0)==0){break}else{aE=1}i=e;return aE|0}}while(0);ay=(c[3529536]|0)+98304|0;if((c[3542200]|0)==0){aE=1;i=e;return aE|0}aB=ab+108|0;c[aB>>2]=0;aF=ab+100|0;c[aF>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](ab,8)|0;do{if((c[aB>>2]|0)!=0){aM=c[aF>>2]|0;c[ac>>2]=9534384;aG=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aG&16383](ac,8,0)|0;if((aM|0)<1){aE=1;i=e;return aE|0}if((gzL(ay,0,8)|0)==0){break}else{aE=1}i=e;return aE|0}}while(0);ay=(c[3529536]|0)+131072|0;if((c[3542200]|0)==0){aE=1;i=e;return aE|0}aF=$+108|0;c[aF>>2]=0;aB=$+100|0;c[aB>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383]($,9)|0;do{if((c[aF>>2]|0)!=0){aM=c[aB>>2]|0;c[aa>>2]=9534384;aG=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aG&16383](aa,9,0)|0;if((aM|0)<1){aE=1;i=e;return aE|0}if((gzL(ay,0,9)|0)==0){break}else{aE=1}i=e;return aE|0}}while(0);ay=(c[3529536]|0)+163840|0;if((c[3542200]|0)==0){aE=1;i=e;return aE|0}aB=Z+108|0;c[aB>>2]=0;aF=Z+100|0;c[aF>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](Z,10)|0;do{if((c[aB>>2]|0)!=0){aM=c[aF>>2]|0;c[_>>2]=9534384;aG=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aG&16383](_,10,0)|0;if((aM|0)<1){aE=1;i=e;return aE|0}if((gzL(ay,0,10)|0)==0){break}else{aE=1}i=e;return aE|0}}while(0);ay=(c[3529536]|0)+196608|0;if((c[3542200]|0)==0){aE=1;i=e;return aE|0}aF=X+108|0;c[aF>>2]=0;aB=X+100|0;c[aB>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](X,11)|0;do{if((c[aF>>2]|0)!=0){aM=c[aB>>2]|0;c[Y>>2]=9534384;aG=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aG&16383](Y,11,0)|0;if((aM|0)<1){aE=1;i=e;return aE|0}if((gzL(ay,0,11)|0)==0){break}else{aE=1}i=e;return aE|0}}while(0);ay=(c[3529536]|0)+229376|0;if((c[3542200]|0)==0){aE=1;i=e;return aE|0}aB=V+108|0;c[aB>>2]=0;aF=V+100|0;c[aF>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](V,12)|0;do{if((c[aB>>2]|0)!=0){aM=c[aF>>2]|0;c[W>>2]=9534384;aG=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aG&16383](W,12,0)|0;if((aM|0)<1){aE=1;i=e;return aE|0}if((gzL(ay,0,12)|0)==0){break}else{aE=1}i=e;return aE|0}}while(0);ay=c[3529536]|0;aF=c[3531068]|0;aB=0;do{aM=aB<<10;gGz(aF+aM|0,0,1024);aG=aB<<11;aH=0;do{aL=1<<3-aH;aI=(c[961472+(aH<<2)>>2]|0)+aG|0;aJ=0;do{aP=aI+(c[609168+(aJ<<2)>>2]|0)|0;aN=(aJ<<5)+aM|0;aK=0;do{aQ=aP+(c[610736+(aK<<2)>>2]|0)|0;if(((d[ay+((aQ|0)/8|0)|0]|0)&128>>>((aQ&7)>>>0)|0)!=0){aQ=aF+(aN+aK)|0;a[aQ]=(d[aQ]|0|aL)&255}aK=aK+1|0;}while((aK|0)<32);aJ=aJ+1|0;}while((aJ|0)<32);aH=aH+1|0;}while((aH|0)<4);aB=aB+1|0;}while((aB|0)<512);gGz(ay|0,0,262144);if((c[3542200]|0)==0){aE=1;i=e;return aE|0}aB=T+108|0;c[aB>>2]=0;aF=T+100|0;c[aF>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](T,15)|0;do{if((c[aB>>2]|0)!=0){aH=c[aF>>2]|0;c[U>>2]=9534384;aM=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aM&16383](U,15,0)|0;if((aH|0)<1){aE=1;i=e;return aE|0}if((gzL(ay,0,15)|0)==0){break}else{aE=1}i=e;return aE|0}}while(0);ay=(c[3529536]|0)+32768|0;if((c[3542200]|0)==0){aE=1;i=e;return aE|0}aF=R+108|0;c[aF>>2]=0;aB=R+100|0;c[aB>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](R,16)|0;do{if((c[aF>>2]|0)!=0){aH=c[aB>>2]|0;c[S>>2]=9534384;aM=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aM&16383](S,16,0)|0;if((aH|0)<1){aE=1;i=e;return aE|0}if((gzL(ay,0,16)|0)==0){break}else{aE=1}i=e;return aE|0}}while(0);ay=(c[3529536]|0)+65536|0;if((c[3542200]|0)==0){aE=1;i=e;return aE|0}aB=P+108|0;c[aB>>2]=0;aF=P+100|0;c[aF>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](P,17)|0;do{if((c[aB>>2]|0)!=0){aH=c[aF>>2]|0;c[Q>>2]=9534384;aM=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aM&16383](Q,17,0)|0;if((aH|0)<1){aE=1;i=e;return aE|0}if((gzL(ay,0,17)|0)==0){break}else{aE=1}i=e;return aE|0}}while(0);ay=(c[3529536]|0)+98304|0;if((c[3542200]|0)==0){aE=1;i=e;return aE|0}aF=N+108|0;c[aF>>2]=0;aB=N+100|0;c[aB>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](N,18)|0;do{if((c[aF>>2]|0)!=0){aH=c[aB>>2]|0;c[O>>2]=9534384;aM=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aM&16383](O,18,0)|0;if((aH|0)<1){aE=1;i=e;return aE|0}if((gzL(ay,0,18)|0)==0){break}else{aE=1}i=e;return aE|0}}while(0);ay=(c[3529536]|0)+131072|0;if((c[3542200]|0)==0){aE=1;i=e;return aE|0}aB=L+108|0;c[aB>>2]=0;aF=L+100|0;c[aF>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](L,19)|0;do{if((c[aB>>2]|0)!=0){aH=c[aF>>2]|0;c[M>>2]=9534384;aM=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aM&16383](M,19,0)|0;if((aH|0)<1){aE=1;i=e;return aE|0}if((gzL(ay,0,19)|0)==0){break}else{aE=1}i=e;return aE|0}}while(0);ay=(c[3529536]|0)+163840|0;if((c[3542200]|0)==0){aE=1;i=e;return aE|0}aF=J+108|0;c[aF>>2]=0;aB=J+100|0;c[aB>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](J,20)|0;do{if((c[aF>>2]|0)!=0){aH=c[aB>>2]|0;c[K>>2]=9534384;aM=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aM&16383](K,20,0)|0;if((aH|0)<1){aE=1;i=e;return aE|0}if((gzL(ay,0,20)|0)==0){break}else{aE=1}i=e;return aE|0}}while(0);ay=(c[3529536]|0)+196608|0;if((c[3542200]|0)==0){aE=1;i=e;return aE|0}aB=H+108|0;c[aB>>2]=0;aF=H+100|0;c[aF>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](H,21)|0;do{if((c[aB>>2]|0)!=0){aH=c[aF>>2]|0;c[I>>2]=9534384;aM=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aM&16383](I,21,0)|0;if((aH|0)<1){aE=1;i=e;return aE|0}if((gzL(ay,0,21)|0)==0){break}else{aE=1}i=e;return aE|0}}while(0);ay=(c[3529536]|0)+229376|0;if((c[3542200]|0)==0){aE=1;i=e;return aE|0}aF=F+108|0;c[aF>>2]=0;aB=F+100|0;c[aB>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](F,22)|0;do{if((c[aF>>2]|0)!=0){aH=c[aB>>2]|0;c[G>>2]=9534384;aM=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aM&16383](G,22,0)|0;if((aH|0)<1){aE=1;i=e;return aE|0}if((gzL(ay,0,22)|0)==0){break}else{aE=1}i=e;return aE|0}}while(0);ay=c[3529536]|0;aB=c[3529586]|0;aF=0;do{aH=aF<<8;gGz(aB+aH|0,0,256);aM=aF<<9;aG=0;do{aJ=1<<3-aG;aL=(c[961472+(aG<<2)>>2]|0)+aM|0;aI=0;do{aK=aL+(c[608544+(aI<<2)>>2]|0)|0;aN=(aI<<4)+aH|0;aP=0;do{aQ=aK+(c[609552+(aP<<2)>>2]|0)|0;if(((d[ay+((aQ|0)/8|0)|0]|0)&128>>>((aQ&7)>>>0)|0)!=0){aQ=aB+(aN+aP)|0;a[aQ]=(d[aQ]|0|aJ)&255}aP=aP+1|0;}while((aP|0)<16);aI=aI+1|0;}while((aI|0)<16);aG=aG+1|0;}while((aG|0)<4);aF=aF+1|0;}while((aF|0)<2048);aF=c[2443582]|0;if((c[3542200]|0)==0){aE=1;i=e;return aE|0}aB=D+108|0;c[aB>>2]=0;ay=D+100|0;c[ay>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](D,23)|0;do{if((c[aB>>2]|0)!=0){aG=c[ay>>2]|0;c[E>>2]=9534384;aH=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aH&16383](E,23,0)|0;if((aG|0)<1){aE=1;i=e;return aE|0}if((gzL(aF,0,23)|0)==0){break}else{aE=1}i=e;return aE|0}}while(0);aF=c[2439974]|0;if((c[3542200]|0)==0){aE=1;i=e;return aE|0}ay=B+108|0;c[ay>>2]=0;aB=B+100|0;c[aB>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](B,24)|0;do{if((c[ay>>2]|0)!=0){aG=c[aB>>2]|0;c[C>>2]=9534384;aH=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aH&16383](C,24,0)|0;if((aG|0)<1){aE=1;i=e;return aE|0}if((gzL(aF,0,24)|0)==0){break}else{aE=1}i=e;return aE|0}}while(0);aF=c[3529864]|0;if((c[3542200]|0)==0){aE=1;i=e;return aE|0}aB=z+108|0;c[aB>>2]=0;ay=z+100|0;c[ay>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,25)|0;do{if((c[aB>>2]|0)!=0){aG=c[ay>>2]|0;c[A>>2]=9534384;aH=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aH&16383](A,25,0)|0;if((aG|0)<1){aE=1;i=e;return aE|0}if((gzL(aF,0,25)|0)==0){break}else{aE=1}i=e;return aE|0}}while(0);aF=c[2443502]|0;if((c[3542200]|0)==0){aE=1;i=e;return aE|0}ay=x+108|0;c[ay>>2]=0;aB=x+100|0;c[aB>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,26)|0;do{if((c[ay>>2]|0)!=0){aG=c[aB>>2]|0;c[y>>2]=9534384;aH=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aH&16383](y,26,0)|0;if((aG|0)<1){aE=1;i=e;return aE|0}if((gzL(aF,0,26)|0)==0){break}else{aE=1}i=e;return aE|0}}while(0);aF=c[3527344]|0;if((c[3542200]|0)==0){aE=1;i=e;return aE|0}aB=v+108|0;c[aB>>2]=0;ay=v+100|0;c[ay>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,27)|0;do{if((c[aB>>2]|0)!=0){aG=c[ay>>2]|0;c[w>>2]=9534384;aH=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aH&16383](w,27,0)|0;if((aG|0)<1){aE=1;i=e;return aE|0}if((gzL(aF,0,27)|0)==0){break}else{aE=1}i=e;return aE|0}}while(0);aF=c[2432720]|0;if((c[3542200]|0)==0){aE=1;i=e;return aE|0}ay=t+108|0;c[ay>>2]=0;aB=t+100|0;c[aB>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,28)|0;do{if((c[ay>>2]|0)!=0){aG=c[aB>>2]|0;c[u>>2]=9534384;aH=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aH&16383](u,28,0)|0;if((aG|0)<1){aE=1;i=e;return aE|0}if((gzL(aF,0,28)|0)==0){break}else{aE=1}i=e;return aE|0}}while(0);aF=c[2437758]|0;if((c[3542200]|0)==0){aE=1;i=e;return aE|0}aB=r+108|0;c[aB>>2]=0;ay=r+100|0;c[ay>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,29)|0;do{if((c[aB>>2]|0)!=0){aG=c[ay>>2]|0;c[s>>2]=9534384;aH=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aH&16383](s,29,0)|0;if((aG|0)<1){aE=1;i=e;return aE|0}if((gzL(aF,0,29)|0)==0){break}else{aE=1}i=e;return aE|0}}while(0);aF=c[2433456]|0;if((c[3542200]|0)==0){aE=1;i=e;return aE|0}ay=p+108|0;c[ay>>2]=0;aB=p+100|0;c[aB>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,30)|0;do{if((c[ay>>2]|0)!=0){aG=c[aB>>2]|0;c[q>>2]=9534384;aH=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aH&16383](q,30,0)|0;if((aG|0)<1){aE=1;i=e;return aE|0}if((gzL(aF,0,30)|0)==0){break}else{aE=1}i=e;return aE|0}}while(0);aF=c[2433458]|0;if((c[3542200]|0)==0){aE=1;i=e;return aE|0}aB=n+108|0;c[aB>>2]=0;ay=n+100|0;c[ay>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,31)|0;do{if((c[aB>>2]|0)!=0){aG=c[ay>>2]|0;c[o>>2]=9534384;aH=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aH&16383](o,31,0)|0;if((aG|0)<1){aE=1;i=e;return aE|0}if((gzL(aF,0,31)|0)==0){break}else{aE=1}i=e;return aE|0}}while(0);aF=c[2432724]|0;if((c[3542200]|0)==0){aE=1;i=e;return aE|0}ay=l+108|0;c[ay>>2]=0;aB=l+100|0;c[aB>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,32)|0;do{if((c[ay>>2]|0)!=0){aG=c[aB>>2]|0;c[m>>2]=9534384;aH=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aH&16383](m,32,0)|0;if((aG|0)<1){aE=1;i=e;return aE|0}if((gzL(aF,0,32)|0)==0){break}else{aE=1}i=e;return aE|0}}while(0);aF=c[2429760]|0;if((c[3542200]|0)==0){aE=1;i=e;return aE|0}aB=j+108|0;c[aB>>2]=0;ay=j+100|0;c[ay>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,33)|0;do{if((c[aB>>2]|0)!=0){aG=c[ay>>2]|0;c[k>>2]=9534384;aH=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aH&16383](k,33,0)|0;if((aG|0)<1){aE=1;i=e;return aE|0}if((gzL(aF,0,33)|0)==0){break}else{aE=1}i=e;return aE|0}}while(0);aF=c[2429524]|0;if((c[3542200]|0)==0){aE=1;i=e;return aE|0}ay=f+108|0;c[ay>>2]=0;aB=f+100|0;c[aB>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,34)|0;do{if((c[ay>>2]|0)!=0){aG=c[aB>>2]|0;c[g>>2]=9534384;aH=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aH&16383](g,34,0)|0;if((aG|0)<1){aE=1;i=e;return aE|0}if((gzL(aF,0,34)|0)==0){break}else{aE=1}i=e;return aE|0}}while(0);aF=c[3529536]|0;aB=0;while(1){if((aB|0)>=1024){break}aR=9638528+(aB<<2)|0;if((c[aR>>2]|0)==(aF|0)){aA=77245;break}else{aB=aB+1|0}}if((aA|0)==77245){gGr(aF);c[aR>>2]=0}c[3529536]=0;fwR(0);aB=c[2439330]|0;ay=(aB|0)==0;if(!ay){aG=aB;gGC(9706056,aG|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];aG=c[3528484]|0;c[2076596]=aG;aH=c[2417276]|0;c[3541536]=aH;c[1836236]=0;c[aB+4180>>2]=1224;c[aB+4184>>2]=3048;c[aB+4172>>2]=2864;c[aB+4176>>2]=2218;aM=c[3529126]|0;aI=0;aJ=0;while(1){c[aB+76+(aJ<<2)>>2]=aM+(aJ<<8);aL=aI+1&65535;if((aL&65535)>127){aS=0;aT=0;break}else{aI=aL;aJ=aL&65535}}while(1){aJ=aM+(aT<<8)|0;c[aB+76+(aT+512<<2)>>2]=aJ;c[aB+76+(aT+768<<2)>>2]=aJ;aJ=aS+1&65535;if((aJ&65535)>127){aU=128;aV=128;break}else{aS=aJ;aT=aJ&65535}}while(1){c[aB+76+(aV<<2)>>2]=aM+((aV<<8)+32768);aJ=aU+1&65535;if((aJ&65535)>191){aW=128;aX=128;break}else{aU=aJ;aV=aJ&65535}}while(1){aJ=aM+((aX<<8)+32768)|0;c[aB+76+(aX+512<<2)>>2]=aJ;c[aB+76+(aX+768<<2)>>2]=aJ;aJ=aW+1&65535;if((aJ&65535)>191){break}else{aW=aJ;aX=aJ&65535}}aM=c[3527220]|0;c[aB+908>>2]=aM;aJ=aM+256|0;c[aB+912>>2]=aJ;aI=aM+512|0;c[aB+916>>2]=aI;aF=aM+768|0;c[aB+920>>2]=aF;c[aB+1932>>2]=aM;c[aB+1936>>2]=aJ;c[aB+1940>>2]=aI;c[aB+1944>>2]=aF;c[aB+2956>>2]=aM;c[aB+3980>>2]=aM;c[aB+2960>>2]=aJ;c[aB+3984>>2]=aJ;c[aB+2964>>2]=aI;c[aB+3988>>2]=aI;c[aB+2968>>2]=aF;c[aB+3992>>2]=aF;aF=c[2439622]|0;c[aB+924>>2]=aF;aI=aF+256|0;c[aB+928>>2]=aI;aJ=aF+512|0;c[aB+932>>2]=aJ;aM=aF+768|0;c[aB+936>>2]=aM;c[aB+1948>>2]=aF;c[aB+1952>>2]=aI;c[aB+1956>>2]=aJ;c[aB+1960>>2]=aM;c[aB+2972>>2]=aF;c[aB+3996>>2]=aF;c[aB+2976>>2]=aI;c[aB+4e3>>2]=aI;c[aB+2980>>2]=aJ;c[aB+4004>>2]=aJ;c[aB+2984>>2]=aM;c[aB+4008>>2]=aM;aM=c[3529156]|0;c[aB+972>>2]=aM;c[aB+976>>2]=aM+256;c[aB+980>>2]=aM+512;c[aB+984>>2]=aM+768;c[aB+988>>2]=aM+1024;c[aB+992>>2]=aM+1280;c[aB+996>>2]=aM+1536;c[aB+1e3>>2]=aM+1792;c[aB+1004>>2]=aM+2048;c[aB+1008>>2]=aM+2304;c[aB+1012>>2]=aM+2560;c[aB+1016>>2]=aM+2816;c[aB+1020>>2]=aM+3072;c[aB+1024>>2]=aM+3328;c[aB+1028>>2]=aM+3584;c[aB+1032>>2]=aM+3840;aJ=224;aI=224;while(1){c[aB+76+(aI+256<<2)>>2]=aM+((aI<<8)-57344);aF=aJ+1&65535;if((aF&65535)>239){aY=224;aZ=224;break}else{aJ=aF;aI=aF&65535}}while(1){aI=aM+((aZ<<8)-57344)|0;c[aB+76+(aZ+512<<2)>>2]=aI;c[aB+76+(aZ+768<<2)>>2]=aI;aI=aY+1&65535;if((aI&65535)>239){break}else{aY=aI;aZ=aI&65535}}aM=c[2443426]|0;c[aB+1036>>2]=aM;c[aB+1040>>2]=aM+256;c[aB+1044>>2]=aM+512;c[aB+1048>>2]=aM+768;c[aB+1052>>2]=aM+1024;c[aB+1056>>2]=aM+1280;c[aB+1060>>2]=aM+1536;c[aB+1064>>2]=aM+1792;c[aB+1068>>2]=aM+2048;c[aB+1072>>2]=aM+2304;c[aB+1076>>2]=aM+2560;c[aB+1080>>2]=aM+2816;c[aB+1084>>2]=aM+3072;c[aB+1088>>2]=aM+3328;c[aB+1092>>2]=aM+3584;c[aB+1096>>2]=aM+3840;aI=240;aJ=240;while(1){c[aB+76+(aJ+256<<2)>>2]=aM+((aJ<<8)-61440);aF=aI+1&65535;if((aF&65535)>255){a_=240;a$=240;break}else{aI=aF;aJ=aF&65535}}while(1){aJ=aM+((a$<<8)-61440)|0;c[aB+76+(a$+512<<2)>>2]=aJ;c[aB+76+(a$+768<<2)>>2]=aJ;aJ=a_+1&65535;if((aJ&65535)>255){break}else{a_=aJ;a$=aJ&65535}}if(!ay){aM=aB;gGC(aM|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=aG;c[2417276]=aH;c[1836236]=-1;fwR(1);aM=c[2439331]|0;aJ=(aM|0)==0;if(!aJ){aI=aM;gGC(9706056,aI|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];aI=c[3528485]|0;c[2076596]=aI;aF=c[2417277]|0;c[3541536]=aF;c[1836236]=1;c[aM+4180>>2]=640;c[aM+4184>>2]=2278;c[aM+4172>>2]=2464;c[aM+4176>>2]=3262;aL=c[3529114]|0;aP=0;aN=0;while(1){c[aM+76+(aN<<2)>>2]=aL+(aN<<8);aK=aP+1&65535;if((aK&65535)>127){a0=0;a1=0;break}else{aP=aK;aN=aK&65535}}while(1){aN=aL+(a1<<8)|0;c[aM+76+(a1+512<<2)>>2]=aN;c[aM+76+(a1+768<<2)>>2]=aN;aN=a0+1&65535;if((aN&65535)>127){break}else{a0=aN;a1=aN&65535}}aL=c[3529146]|0;c[aM+844>>2]=aL;aN=aL+256|0;c[aM+848>>2]=aN;aP=aL+512|0;c[aM+852>>2]=aP;aH=aL+768|0;c[aM+856>>2]=aH;aG=aL+1024|0;c[aM+860>>2]=aG;aB=aL+1280|0;c[aM+864>>2]=aB;ay=aL+1536|0;c[aM+868>>2]=ay;aK=aL+1792|0;c[aM+872>>2]=aK;c[aM+1868>>2]=aL;c[aM+1872>>2]=aN;c[aM+1876>>2]=aP;c[aM+1880>>2]=aH;c[aM+1884>>2]=aG;c[aM+1888>>2]=aB;c[aM+1892>>2]=ay;c[aM+1896>>2]=aK;c[aM+2892>>2]=aL;c[aM+3916>>2]=aL;c[aM+2896>>2]=aN;c[aM+3920>>2]=aN;c[aM+2900>>2]=aP;c[aM+3924>>2]=aP;c[aM+2904>>2]=aH;c[aM+3928>>2]=aH;c[aM+2908>>2]=aG;c[aM+3932>>2]=aG;c[aM+2912>>2]=aB;c[aM+3936>>2]=aB;c[aM+2916>>2]=ay;c[aM+3940>>2]=ay;c[aM+2920>>2]=aK;c[aM+3944>>2]=aK;if(!aJ){aK=aM;gGC(aK|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=aI;c[2417277]=aF;c[1836236]=-1;Vr(2,15e5,0,2870,126,0);c[2438228]=3e6;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=681;h[745419]=.1;a[3203368]=1;h[745418]=.15;a[3203360]=1;h[745417]=.15;a[3203352]=1;h[745416]=.15;a[3203344]=1;h[745415]=.1;a[3203336]=1;h[745414]=.15;a[3203328]=1;h[745413]=.15;a[3203320]=1;h[745412]=.15;a[3203312]=1;aK=c[642608+(c[2436]<<2)>>2]|0;ay=c[aK+128>>2]|0;if((c[aK+52>>2]&4|0)==0){c[2113068]=ay;aB=c[aK+132>>2]|0;c[2113070]=aB;c[2443814]=ay;c[2440436]=aB;a2=ay;a3=aB}else{c[2113070]=ay;aB=c[aK+132>>2]|0;c[2113068]=aB;c[2440436]=ay;c[2443814]=aB;a2=aB;a3=ay}ay=ag(a2<<1,a3)|0;aB=gGq(ay)|0;c[2112926]=aB;if((aB|0)!=0){gGz(aB|0,0,ay|0)}ay=c[2439330]|0;aB=(ay|0)==0;if(!aB){aK=ay;gGC(9706056,aK|0,76)|0}aK=c[2438118]|0;c[2433530]=aK;aG=c[3528484]|0;c[2076596]=aG;aH=c[2417276]|0;c[3541536]=aH;c[1836236]=0;gGz(9706056,0,76);if(!aB){aB=ay;gGC(aB|0,9706056,76)|0}c[2438118]=aK;c[3528484]=aG;c[2417276]=aH;c[1836236]=-1;aH=c[2439331]|0;aG=(aH|0)==0;if(!aG){aK=aH;gGC(9706056,aK|0,76)|0}aK=c[2438119]|0;c[2433530]=aK;aB=c[3528485]|0;c[2076596]=aB;ay=c[2417277]|0;c[3541536]=ay;c[1836236]=1;gGz(9706056,0,76);if(!aG){aG=aH;gGC(aG|0,9706056,76)|0}c[2438119]=aK;c[3528485]=aB;c[2417277]=ay;c[1836236]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){ay=0;do{lN(ay);mB(ay);ay=ay+1|0;}while((ay|0)<(c[2385508]|0))}a[14119344]=0;a[9758216]=0;a[9759904]=0;a[9759905]=0;a[9774408]=0;a[9774409]=0;a[9774360]=0;a[9626360]=0;a[9626368]=0;a[9773592]=0;a[14124232]=0;aE=0;i=e;return aE|0}}while(0);c[2426786]=0;aE=1;i=e;return aE|0}function drB(){var b=0,d=0,e=0,f=0;fwZ();b=c[3541518]|0;if((b|0)!=0){gGr(b|0);c[3541518]=0}if((c[2385508]|0)>0){c[2113008]=0;c[2076598]=0;c[2383582]=0}c[2438228]=0;c[2433526]=0;c[2406676]=0;c[3528472]=0;b=c[2406680]|0;if((b|0)!=0){gGr(b);c[2406680]=0}c[2385508]=0;c[2432978]=0;a[64240]=0;c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}a[14119344]=0;a[9758216]=0;a[9759904]=0;a[9759905]=0;a[9774408]=0;a[9774409]=0;a[9774360]=0;a[9626360]=0;a[9626368]=0;a[9773592]=0;a[14124232]=0;b=c[2426786]|0;d=0;while(1){if((d|0)>=1024){e=77411;break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==(b|0)){break}else{d=d+1|0}}if((e|0)==77411){c[2426786]=0;return 0}gGr(b);c[f>>2]=0;c[2426786]=0;return 0}function drC(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;e=i;i=i+1024|0;f=e|0;if((a[9624680]|0)!=0){g=c[2439330]|0;j=(g|0)==0;if(!j){k=g;gGC(9706056,k|0,76)|0}k=c[2438118]|0;c[2433530]=k;l=c[3528484]|0;c[2076596]=l;m=c[2417276]|0;c[3541536]=m;c[1836236]=0;gGz(9706056,0,76);if(!j){j=g;gGC(j|0,9706056,76)|0}c[2438118]=k;c[3528484]=l;c[2417276]=m;c[1836236]=-1;m=c[2439331]|0;l=(m|0)==0;if(!l){k=m;gGC(9706056,k|0,76)|0}k=c[2438119]|0;c[2433530]=k;j=c[3528485]|0;c[2076596]=j;g=c[2417277]|0;c[3541536]=g;c[1836236]=1;gGz(9706056,0,76);if(!l){l=m;gGC(l|0,9706056,76)|0}c[2438119]=k;c[3528485]=j;c[2417277]=g;c[1836236]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){g=0;do{lN(g);mB(g);g=g+1|0;}while((g|0)<(c[2385508]|0))}a[14119344]=0;a[9758216]=0;a[9759904]=0;a[9759905]=0;a[9774408]=0;a[9774409]=0;a[9774360]=0;a[9626360]=0;a[9626368]=0;a[9773592]=0;a[14124232]=0}a[9625832]=0;a[9625840]=0;a[9625848]=0;g=0;j=0;k=0;l=0;do{j=((a[9759240+g|0]&1)<<g|j&255)&255;k=((a[9759048+g|0]&1)<<g|k&255)&255;l=((a[9758864+g|0]&1)<<g|l&255)&255;g=g+1|0;}while((g|0)<8);a[9625848]=j;a[9625840]=k;a[9625832]=l;if((k&3)==3){j=k&-4;a[9625840]=j;n=j}else{n=k}if((n&12)==12){a[9625840]=n&-13}if((l&3)==3){n=l&-4;a[9625832]=n;o=n}else{o=l}if((o&12)==12){a[9625832]=o&-13}a[6518304]=1;a[6518128]=1;c[2444034]=0;o=c[2385548]|0;if((o|0)>0){gGz(9752472,0,((o|0)>1?o<<2:4)|0)}c[2433530]=0;o=0;while(1){l=c[2439330]|0;if((l|0)!=0){n=l;gGC(9706056,n|0,76)|0}b[4853030]=c[2426515]&65535;n=c[2438118]|0;c[2433530]=n;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;k=o+1|0;j=(ag(a[6518304]|0?1e5:0,k)|0)/100|0;g=c[2444034]|0;m=j-g|0;do{if((m|0)<1){p=0;q=g;r=n}else{if((a[l+4188|0]|0)==0){j=gfc(m)|0;s=(c[2433530]|0)+j|0;c[2433530]=s;p=j;q=c[2444034]|0;r=s;break}else{s=n+m|0;c[2433530]=s;p=m;q=g;r=s;break}}}while(0);c[2444034]=q+p;if((o|0)==95){a[9706117]=1}else if((o|0)==96){a[9706117]=0}g=c[1836236]|0;m=c[9757320+(g<<2)>>2]|0;if((m|0)!=0){n=m;gGC(n|0,9706056,76)|0}c[9752472+(g<<2)>>2]=r;c[14113936+(g<<2)>>2]=c[2076596];c[9669104+(g<<2)>>2]=c[3541536];c[1836236]=-1;g=c[2439331]|0;if((g|0)!=0){n=g;gGC(9706056,n|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;Sb(ag(a[6518128]|0?500:0,o)|0);switch(o|0){case 80:case 60:case 40:case 20:{a[9706117]=1;if((o|0)==21|(o|0)==61|(o|0)==41){t=77453}break};case 81:case 61:case 41:case 21:{t=77453;break};default:{}}if((t|0)==77453){t=0;a[9706117]=0}n=c[1836236]|0;g=c[9757320+(n<<2)>>2]|0;if((g|0)!=0){m=g;gGC(m|0,9706056,76)|0}c[9752472+(n<<2)>>2]=c[2433530];c[14113936+(n<<2)>>2]=c[2076596];c[9669104+(n<<2)>>2]=c[3541536];c[1836236]=-1;if((k|0)<100){o=k}else{break}}o=c[2439331]|0;if((o|0)!=0){t=o;gGC(9706056,t|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;t=a[6518128]|0?5e4:0;o=gGU(t,0,2048e6,0)|0;r=c[2438228]|0;p=gGS(o,K,r,(r|0)<0|0?-1:0)|0;r=p;Sb(t);t=c[2443830]|0;if((t|0)<1073676288){c[2443830]=t-r}t=c[2443831]|0;if((t|0)<1073676288){c[2443831]=t-r}t=(c[3528512]|0)-r|0;c[3528512]=(t|0)<0?0:t;t=c[1836236]|0;r=c[9757320+(t<<2)>>2]|0;if((r|0)!=0){p=r;gGC(p|0,9706056,76)|0}c[9752472+(t<<2)>>2]=c[2433530];c[14113936+(t<<2)>>2]=c[2076596];c[9669104+(t<<2)>>2]=c[3541536];c[1836236]=-1;t=c[2112964]|0;if((t|0)!=0){p=c[2439331]|0;if((p|0)!=0){r=p;gGC(9706056,r|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;gg[c[3542122]&4095](t,a[9688]|0?534:0);t=c[1836236]|0;r=c[9757320+(t<<2)>>2]|0;if((r|0)!=0){p=r;gGC(p|0,9706056,76)|0}c[9752472+(t<<2)>>2]=c[2433530];c[14113936+(t<<2)>>2]=c[2076596];c[9669104+(t<<2)>>2]=c[3541536];c[1836236]=-1}if((c[2112968]|0)==0){i=e;return 0}t=c[2112926]|0;gGz(t|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);p=c[3529864]|0;r=c[2443502]|0;o=c[3527344]|0;q=0;do{n=d[p+q|0]|0;m=d[r+q|0]|0;g=d[o+q|0]|0;c[f+(q<<2)>>2]=(-(m>>>1&1)&31)+(-(m&1)&14)+(-(m>>>2&1)&67)+(-(m>>>3&1)&143)<<3&2016|(-(n>>>1&1)&31)+(-(n&1)&14)+(-(n>>>2&1)&67)+(-(n>>>3&1)&143)<<8&63488|((-(g>>>1&1)&31)+(-(g&1)&14)+(-(g>>>2&1)&67)+(-(g>>>3&1)&143)|0)>>>3&31;q=q+1|0;}while((q|0)<256);q=c[2432720]|0;o=c[3530102]|0;r=0;do{c[o+(r<<2)>>2]=c[f+((a[q+r|0]&15|64)<<2)>>2];r=r+1|0;}while((r|0)<128);r=c[2433456]|0;q=c[2437758]|0;p=128;do{g=p-128|0;c[o+(p<<2)>>2]=c[f+((a[q+g|0]&15|d[r+g|0]<<4&48)<<2)>>2];p=p+1|0;}while((p|0)<384);p=c[2432724]|0;r=c[2433458]|0;q=384;do{g=q-384|0;c[o+(q<<2)>>2]=c[f+((a[r+g|0]&15|d[p+g|0]<<4&48)<<2)>>2];q=q+1|0;}while((q|0)<640);q=c[2429524]|0;p=c[2429760]|0;r=640;do{g=r-640|0;c[o+(r<<2)>>2]=c[f+((d[q+g|0]<<4&112|a[p+g|0]&15|128)<<2)>>2];r=r+1|0;}while((r|0)<896);if((a[9626360]|0)!=0){r=d[9759905]<<8|d[9759904];p=c[2439974]|0;q=c[3527478]|0;f=0;do{g=f<<5;n=g-16|0;m=(g-17|0)>>>0>190;g=0;do{l=(g<<3)+f<<1;s=d[p+(l|1)|0]|0;j=a[p+l|0]&127;l=(s>>>2&15)+24|0;u=(g<<5)-r|0;v=(u|0)<-31?u+65536|0:u;do{if((v|0)<=256){u=(s&64|0)==0;w=(s&128|0)!=0;if((v-1|0)>>>0>222|m){if(u){if(w){ST(t,j,v,n,l,4,0,q);break}else{SP(t,j,v,n,l,4,0,q);break}}else{if(w){SV(t,j,v,n,l,4,0,q);break}else{SR(t,j,v,n,l,4,0,q);break}}}else{if(u){if(w){SS(t,j,v,n,l,4,q);break}else{SO(t,j,v,n,l,4,q);break}}else{if(w){SU(t,j,v,n,l,4,q);break}else{SQ(t,j,v,n,l,4,q);break}}}}}while(0);g=g+1|0;}while((g|0)<2048);f=f+1|0;}while((f|0)<8)}if((a[9773592]|0)!=0){drU(0)}if((a[9626368]|0)!=0){f=(d[9774360]|0)+16&255;q=d[9774409]<<8|d[9774408];r=c[2443582]|0;p=c[3531068]|0;g=0;do{n=(g<<5)-f|0;m=(n|0)<-31?n+256|0:n;n=(m|0)>240;k=(m-1|0)>>>0>190;l=0;do{v=(l<<3)+g<<1;j=d[r+(v|1)|0]|0;s=j<<8&256|d[r+v|0];v=(j>>>2&15)+8|0;w=(l<<5)-q|0;u=(w|0)<-31?w+65536|0:w;do{if(!((u|0)>256|n)){w=(j&64|0)==0;x=(j&128|0)!=0;if((u-1|0)>>>0>222|k){if(w){if(x){S$(t,s,u,m,v,4,0,0,p);break}else{SX(t,s,u,m,v,4,0,0,p);break}}else{if(x){S1(t,s,u,m,v,4,0,0,p);break}else{SZ(t,s,u,m,v,4,0,0,p);break}}}else{if(w){if(x){S_(t,s,u,m,v,4,0,p);break}else{SW(t,s,u,m,v,4,0,0,p);break}}else{if(x){S0(t,s,u,m,v,4,0,p);break}else{SY(t,s,u,m,v,4,0,0,p);break}}}}}while(0);l=l+1|0;}while((l|0)<2048);g=g+1|0;}while((g|0)<8)}if((a[9773592]|0)!=0){drU(1)}if((a[14124232]|0)!=0){g=c[2439622]|0;p=c[3527220]|0;q=c[2406534]|0;r=0;f=0;while(1){l=r<<3;m=l-16|0;k=(l-17|0)>>>0>214;l=0;n=f;while(1){v=d[g+n|0]|0;u=d[p+n|0]|v<<3&1792;s=v&31;v=l<<3;if((v-1|0)>>>0>246|k){Sr(t,u,v,m,s,2,0,0,q)}else{Sq(t,u,v,m,s,2,0,0,q)}s=l+1|0;if((s|0)<32){l=s;n=n+1|0}else{break}}n=r+1|0;if((n|0)<32){r=n;f=f+32|0}else{break}}}R8(o);i=e;return 0}function drD(a,e){a=a|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=i;i=i+192|0;g=f|0;h=f+16|0;j=f+32|0;k=f+48|0;l=f+64|0;m=f+80|0;n=f+96|0;o=f+112|0;p=f+128|0;q=f+144|0;r=f+160|0;s=f+176|0;if((e|0)!=0){c[e>>2]=169586}if((a&32|0)!=0){gGz(s|0,0,12);t=c[2405694]|0;c[s>>2]=t;c[s+4>>2]=(c[2411776]|0)-t;c[s+12>>2]=162152;t=c[2076592]|0;gj[t&4095](s)|0}if((a&64|0)!=0){fw$(a);Vx(a,e);gGz(r|0,0,12);c[r>>2]=9758216;c[r+4>>2]=1;c[r+12>>2]=497064;e=c[2076592]|0;gj[e&4095](r)|0;gGz(q|0,0,12);c[q>>2]=14119344;c[q+4>>2]=1;c[q+12>>2]=511192;r=c[2076592]|0;gj[r&4095](q)|0;gGz(p|0,0,12);c[p>>2]=9759904;c[p+4>>2]=1;c[p+12>>2]=417216;q=c[2076592]|0;gj[q&4095](p)|0;gGz(o|0,0,12);c[o>>2]=9759905;c[o+4>>2]=1;c[o+12>>2]=405104;p=c[2076592]|0;gj[p&4095](o)|0;gGz(n|0,0,12);c[n>>2]=9774408;c[n+4>>2]=1;c[n+12>>2]=394320;o=c[2076592]|0;gj[o&4095](n)|0;gGz(m|0,0,12);c[m>>2]=9774409;c[m+4>>2]=1;c[m+12>>2]=382640;n=c[2076592]|0;gj[n&4095](m)|0;gGz(l|0,0,12);c[l>>2]=9774360;c[l+4>>2]=1;c[l+12>>2]=166776;m=c[2076592]|0;gj[m&4095](l)|0;gGz(k|0,0,12);c[k>>2]=9626360;c[k+4>>2]=1;c[k+12>>2]=363184;l=c[2076592]|0;gj[l&4095](k)|0;gGz(j|0,0,12);c[j>>2]=9626368;c[j+4>>2]=1;c[j+12>>2]=356192;k=c[2076592]|0;gj[k&4095](j)|0;gGz(h|0,0,12);c[h>>2]=9773592;c[h+4>>2]=1;c[h+12>>2]=347944;j=c[2076592]|0;gj[j&4095](h)|0;gGz(g|0,0,12);c[g>>2]=14124232;c[g+4>>2]=1;c[g+12>>2]=340320;h=c[2076592]|0;gj[h&4095](g)|0}if((a&2|0)==0){i=f;return 0}a=c[2439330]|0;g=(a|0)==0;if(!g){h=a;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];h=c[3528484]|0;c[2076596]=h;j=c[2417276]|0;c[3541536]=j;c[1836236]=0;k=c[3529126]|0;l=((d[14119344]|0)<<12)+32768|0;m=128;n=128;while(1){c[a+76+(n<<2)>>2]=k+(l+(n<<8));o=m+1&65535;if((o&65535)>191){u=128;v=128;break}else{m=o;n=o&65535}}while(1){n=k+(l+(v<<8))|0;c[a+76+(v+512<<2)>>2]=n;c[a+76+(v+768<<2)>>2]=n;n=u+1&65535;if((n&65535)>191){break}else{u=n;v=n&65535}}if(!g){g=a;gGC(g|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=h;c[2417276]=j;c[1836236]=-1;i=f;return 0}function drE(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>37){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7226388+(b*112|0)>>2];c[a+104>>2]=c[7226392+(b*112|0)>>2];c[a+108>>2]=c[7226396+(b*112|0)>>2];d=0;return d|0}function drF(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<38&(d|0)==0)){e=1;return e|0}c[a>>2]=7226288+(b*112|0);e=0;return e|0}function drG(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>37){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7256292+(b*112|0)>>2];c[a+104>>2]=c[7256296+(b*112|0)>>2];c[a+108>>2]=c[7256300+(b*112|0)>>2];d=0;return d|0}function drH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<38&(d|0)==0)){e=1;return e|0}c[a>>2]=7256192+(b*112|0);e=0;return e|0}function drI(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>37){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6904836+(b*112|0)>>2];c[a+104>>2]=c[6904840+(b*112|0)>>2];c[a+108>>2]=c[6904844+(b*112|0)>>2];d=0;return d|0}function drJ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<38&(d|0)==0)){e=1;return e|0}c[a>>2]=6904736+(b*112|0);e=0;return e|0}function drK(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>32){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7283148+(b*112|0)>>2];c[a+104>>2]=c[7283152+(b*112|0)>>2];c[a+108>>2]=c[7283156+(b*112|0)>>2];d=0;return d|0}function drL(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<33&(d|0)==0)){e=1;return e|0}c[a>>2]=7283048+(b*112|0);e=0;return e|0}function drM(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0;e=i;i=i+3720|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;B=e+1200|0;C=e+1312|0;D=e+1320|0;E=e+1432|0;F=e+1440|0;G=e+1552|0;H=e+1560|0;I=e+1672|0;J=e+1680|0;K=e+1792|0;L=e+1800|0;M=e+1912|0;N=e+1920|0;O=e+2032|0;P=e+2040|0;Q=e+2152|0;R=e+2160|0;S=e+2272|0;T=e+2280|0;U=e+2392|0;V=e+2400|0;W=e+2512|0;X=e+2520|0;Y=e+2632|0;Z=e+2640|0;_=e+2752|0;$=e+2760|0;aa=e+2872|0;ab=e+2880|0;ac=e+2992|0;ad=e+3e3|0;ae=e+3112|0;af=e+3120|0;ah=e+3232|0;ai=e+3240|0;aj=e+3352|0;ak=e+3360|0;al=e+3472|0;am=e+3480|0;an=e+3592|0;ao=e+3600|0;ap=e+3712|0;c[2426786]=0;c[3529126]=0;c[3529114]=196608;c[3529864]=229376;c[2443502]=229632;c[3527344]=229888;c[2432720]=230144;c[2433458]=230400;c[2432724]=230656;c[2437758]=230912;c[2433456]=231168;c[2429760]=231424;c[2429524]=231680;c[2443582]=231936;c[2439974]=264704;c[2405694]=297472;c[3529156]=297472;c[3529146]=301568;c[3527220]=303616;c[2439622]=304640;c[2443426]=305664;c[2411776]=309760;c[2406534]=309760;c[3527478]=440832;c[3531068]=571904;c[3529586]=1096192;c[3530102]=1620480;aq=0;while(1){if((aq|0)>=1024){break}ar=9638528+(aq<<2)|0;if((c[ar>>2]|0)==0){as=77609;break}else{aq=aq+1|0}}do{if((as|0)==77609){aq=gGq(1624064)|0;c[ar>>2]=aq;if((aq|0)==0){break}c[2426786]=aq;gGz(aq|0,0,1624064);c[3529126]=aq;c[3529114]=aq+196608;c[3529864]=aq+229376;c[2443502]=aq+229632;c[3527344]=aq+229888;c[2432720]=aq+230144;c[2433458]=aq+230400;c[2432724]=aq+230656;c[2437758]=aq+230912;c[2433456]=aq+231168;c[2429760]=aq+231424;c[2429524]=aq+231680;c[2443582]=aq+231936;c[2439974]=aq+264704;at=aq+297472|0;c[2405694]=at;c[3529156]=at;c[3529146]=aq+301568;c[3527220]=aq+303616;c[2439622]=aq+304640;c[2443426]=aq+305664;at=aq+309760|0;c[2411776]=at;c[2406534]=at;c[3527478]=aq+440832;c[3531068]=aq+571904;c[3529586]=aq+1096192;c[3530102]=aq+1620480;c[2414324]=aq+1624064;aq=0;while(1){if((aq|0)>=1024){au=0;break}av=9638528+(aq<<2)|0;if((c[av>>2]|0)==0){as=77614;break}else{aq=aq+1|0}}do{if((as|0)==77614){aq=gGq(262144)|0;c[av>>2]=aq;if((aq|0)==0){au=0;break}gGz(aq|0,0,262144);au=aq}}while(0);c[3529536]=au;aq=c[3529126]|0;if((c[3542200]|0)==0){aw=1;i=e;return aw|0}at=ao+108|0;c[at>>2]=0;ax=ao+100|0;c[ax>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](ao,0)|0;do{if((c[at>>2]|0)!=0){ay=c[ax>>2]|0;c[ap>>2]=9534384;az=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[az&16383](ap,0,0)|0;if((ay|0)<1){aw=1;i=e;return aw|0}if((gzL(aq,0,0)|0)==0){break}else{aw=1}i=e;return aw|0}}while(0);aq=(c[3529126]|0)+65536|0;if((c[3542200]|0)==0){aw=1;i=e;return aw|0}ax=am+108|0;c[ax>>2]=0;at=am+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](am,1)|0;do{if((c[ax>>2]|0)!=0){ay=c[at>>2]|0;c[an>>2]=9534384;az=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[az&16383](an,1,0)|0;if((ay|0)<1){aw=1;i=e;return aw|0}if((gzL(aq,0,1)|0)==0){break}else{aw=1}i=e;return aw|0}}while(0);aq=(c[3529126]|0)+131072|0;if((c[3542200]|0)==0){aw=1;i=e;return aw|0}at=ak+108|0;c[at>>2]=0;ax=ak+100|0;c[ax>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](ak,2)|0;do{if((c[at>>2]|0)!=0){ay=c[ax>>2]|0;c[al>>2]=9534384;az=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[az&16383](al,2,0)|0;if((ay|0)<1){aw=1;i=e;return aw|0}if((gzL(aq,0,2)|0)==0){break}else{aw=1}i=e;return aw|0}}while(0);aq=c[3529114]|0;if((c[3542200]|0)==0){aw=1;i=e;return aw|0}ax=ai+108|0;c[ax>>2]=0;at=ai+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](ai,3)|0;do{if((c[ax>>2]|0)!=0){ay=c[at>>2]|0;c[aj>>2]=9534384;az=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[az&16383](aj,3,0)|0;if((ay|0)<1){aw=1;i=e;return aw|0}if((gzL(aq,0,3)|0)==0){break}else{aw=1}i=e;return aw|0}}while(0);aq=c[3529536]|0;if((c[3542200]|0)==0){aw=1;i=e;return aw|0}at=af+108|0;c[at>>2]=0;ax=af+100|0;c[ax>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](af,4)|0;do{if((c[at>>2]|0)!=0){ay=c[ax>>2]|0;c[ah>>2]=9534384;az=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[az&16383](ah,4,0)|0;if((ay|0)<1){aw=1;i=e;return aw|0}if((gzL(aq,0,4)|0)==0){break}else{aw=1}i=e;return aw|0}}while(0);aq=c[3529536]|0;ax=c[2406534]|0;at=0;do{ay=at<<6;gGz(ax+ay|0,0,64);az=at<<7;aA=az|4;aB=0;while(1){aC=aA+(c[6669224+(aB<<2)>>2]|0)|0;aD=(aB<<3)+ay|0;aE=0;do{aF=aC+(c[612480+(aE<<2)>>2]|0)|0;if(((d[aq+((aF|0)/8|0)|0]|0)&128>>>((aF&7)>>>0)|0)!=0){aF=ax+(aD+aE)|0;a[aF]=a[aF]|2}aE=aE+1|0;}while((aE|0)<8);aE=aB+1|0;if((aE|0)<8){aB=aE}else{aG=0;break}}do{aB=az+(c[6669224+(aG<<2)>>2]|0)|0;aA=(aG<<3)+ay|0;aE=0;do{aD=aB+(c[612480+(aE<<2)>>2]|0)|0;if(((d[aq+((aD|0)/8|0)|0]|0)&128>>>((aD&7)>>>0)|0)!=0){aD=ax+(aA+aE)|0;a[aD]=a[aD]|1}aE=aE+1|0;}while((aE|0)<8);aG=aG+1|0;}while((aG|0)<8);at=at+1|0;}while((at|0)<2048);gGz(aq|0,0,262144);if((c[3542200]|0)==0){aw=1;i=e;return aw|0}at=ad+108|0;c[at>>2]=0;ax=ad+100|0;c[ax>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](ad,9)|0;do{if((c[at>>2]|0)!=0){ay=c[ax>>2]|0;c[ae>>2]=9534384;az=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[az&16383](ae,9,0)|0;if((ay|0)<1){aw=1;i=e;return aw|0}if((gzL(aq,0,9)|0)==0){break}else{aw=1}i=e;return aw|0}}while(0);aq=(c[3529536]|0)+32768|0;if((c[3542200]|0)==0){aw=1;i=e;return aw|0}ax=ab+108|0;c[ax>>2]=0;at=ab+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](ab,10)|0;do{if((c[ax>>2]|0)!=0){ay=c[at>>2]|0;c[ac>>2]=9534384;az=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[az&16383](ac,10,0)|0;if((ay|0)<1){aw=1;i=e;return aw|0}if((gzL(aq,0,10)|0)==0){break}else{aw=1}i=e;return aw|0}}while(0);aq=c[3529536]|0;at=c[3527478]|0;ax=0;do{ay=ax<<10;gGz(at+ay|0,0,1024);az=ax<<11;aE=0;do{aA=1<<3-aE;aB=(c[613264+(aE<<2)>>2]|0)+az|0;aD=0;do{aC=aB+(c[609168+(aD<<2)>>2]|0)|0;aF=(aD<<5)+ay|0;aH=0;do{aI=aC+(c[610736+(aH<<2)>>2]|0)|0;if(((d[aq+((aI|0)/8|0)|0]|0)&128>>>((aI&7)>>>0)|0)!=0){aI=at+(aF+aH)|0;a[aI]=(d[aI]|0|aA)&255}aH=aH+1|0;}while((aH|0)<32);aD=aD+1|0;}while((aD|0)<32);aE=aE+1|0;}while((aE|0)<4);ax=ax+1|0;}while((ax|0)<128);gGz(aq|0,0,262144);if((c[3542200]|0)==0){aw=1;i=e;return aw|0}ax=$+108|0;c[ax>>2]=0;at=$+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383]($,5)|0;do{if((c[ax>>2]|0)!=0){aE=c[at>>2]|0;c[aa>>2]=9534384;ay=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ay&16383](aa,5,0)|0;if((aE|0)<1){aw=1;i=e;return aw|0}if((gzL(aq,0,5)|0)==0){break}else{aw=1}i=e;return aw|0}}while(0);aq=(c[3529536]|0)+65536|0;if((c[3542200]|0)==0){aw=1;i=e;return aw|0}at=Z+108|0;c[at>>2]=0;ax=Z+100|0;c[ax>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](Z,6)|0;do{if((c[at>>2]|0)!=0){aE=c[ax>>2]|0;c[_>>2]=9534384;ay=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ay&16383](_,6,0)|0;if((aE|0)<1){aw=1;i=e;return aw|0}if((gzL(aq,0,6)|0)==0){break}else{aw=1}i=e;return aw|0}}while(0);aq=(c[3529536]|0)+131072|0;if((c[3542200]|0)==0){aw=1;i=e;return aw|0}ax=X+108|0;c[ax>>2]=0;at=X+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](X,7)|0;do{if((c[ax>>2]|0)!=0){aE=c[at>>2]|0;c[Y>>2]=9534384;ay=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ay&16383](Y,7,0)|0;if((aE|0)<1){aw=1;i=e;return aw|0}if((gzL(aq,0,7)|0)==0){break}else{aw=1}i=e;return aw|0}}while(0);aq=(c[3529536]|0)+196608|0;if((c[3542200]|0)==0){aw=1;i=e;return aw|0}at=V+108|0;c[at>>2]=0;ax=V+100|0;c[ax>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](V,8)|0;do{if((c[at>>2]|0)!=0){aE=c[ax>>2]|0;c[W>>2]=9534384;ay=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ay&16383](W,8,0)|0;if((aE|0)<1){aw=1;i=e;return aw|0}if((gzL(aq,0,8)|0)==0){break}else{aw=1}i=e;return aw|0}}while(0);aq=c[3529536]|0;ax=c[3531068]|0;at=0;do{aE=at<<10;gGz(ax+aE|0,0,1024);ay=at<<11;az=0;do{aD=1<<3-az;aA=(c[961472+(az<<2)>>2]|0)+ay|0;aB=0;do{aH=aA+(c[609168+(aB<<2)>>2]|0)|0;aF=(aB<<5)+aE|0;aC=0;do{aI=aH+(c[610736+(aC<<2)>>2]|0)|0;if(((d[aq+((aI|0)/8|0)|0]|0)&128>>>((aI&7)>>>0)|0)!=0){aI=ax+(aF+aC)|0;a[aI]=(d[aI]|0|aD)&255}aC=aC+1|0;}while((aC|0)<32);aB=aB+1|0;}while((aB|0)<32);az=az+1|0;}while((az|0)<4);at=at+1|0;}while((at|0)<512);gGz(aq|0,0,262144);if((c[3542200]|0)==0){aw=1;i=e;return aw|0}at=T+108|0;c[at>>2]=0;ax=T+100|0;c[ax>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](T,11)|0;do{if((c[at>>2]|0)!=0){az=c[ax>>2]|0;c[U>>2]=9534384;aE=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aE&16383](U,11,0)|0;if((az|0)<1){aw=1;i=e;return aw|0}if((gzL(aq,0,11)|0)==0){break}else{aw=1}i=e;return aw|0}}while(0);aq=(c[3529536]|0)+32768|0;if((c[3542200]|0)==0){aw=1;i=e;return aw|0}ax=R+108|0;c[ax>>2]=0;at=R+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](R,12)|0;do{if((c[ax>>2]|0)!=0){az=c[at>>2]|0;c[S>>2]=9534384;aE=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aE&16383](S,12,0)|0;if((az|0)<1){aw=1;i=e;return aw|0}if((gzL(aq,0,12)|0)==0){break}else{aw=1}i=e;return aw|0}}while(0);aq=(c[3529536]|0)+65536|0;if((c[3542200]|0)==0){aw=1;i=e;return aw|0}at=P+108|0;c[at>>2]=0;ax=P+100|0;c[ax>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](P,13)|0;do{if((c[at>>2]|0)!=0){az=c[ax>>2]|0;c[Q>>2]=9534384;aE=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aE&16383](Q,13,0)|0;if((az|0)<1){aw=1;i=e;return aw|0}if((gzL(aq,0,13)|0)==0){break}else{aw=1}i=e;return aw|0}}while(0);aq=(c[3529536]|0)+98304|0;if((c[3542200]|0)==0){aw=1;i=e;return aw|0}ax=N+108|0;c[ax>>2]=0;at=N+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](N,14)|0;do{if((c[ax>>2]|0)!=0){az=c[at>>2]|0;c[O>>2]=9534384;aE=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aE&16383](O,14,0)|0;if((az|0)<1){aw=1;i=e;return aw|0}if((gzL(aq,0,14)|0)==0){break}else{aw=1}i=e;return aw|0}}while(0);aq=(c[3529536]|0)+131072|0;if((c[3542200]|0)==0){aw=1;i=e;return aw|0}at=L+108|0;c[at>>2]=0;ax=L+100|0;c[ax>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](L,15)|0;do{if((c[at>>2]|0)!=0){az=c[ax>>2]|0;c[M>>2]=9534384;aE=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aE&16383](M,15,0)|0;if((az|0)<1){aw=1;i=e;return aw|0}if((gzL(aq,0,15)|0)==0){break}else{aw=1}i=e;return aw|0}}while(0);aq=(c[3529536]|0)+163840|0;if((c[3542200]|0)==0){aw=1;i=e;return aw|0}ax=J+108|0;c[ax>>2]=0;at=J+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](J,16)|0;do{if((c[ax>>2]|0)!=0){az=c[at>>2]|0;c[K>>2]=9534384;aE=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aE&16383](K,16,0)|0;if((az|0)<1){aw=1;i=e;return aw|0}if((gzL(aq,0,16)|0)==0){break}else{aw=1}i=e;return aw|0}}while(0);aq=(c[3529536]|0)+196608|0;if((c[3542200]|0)==0){aw=1;i=e;return aw|0}at=H+108|0;c[at>>2]=0;ax=H+100|0;c[ax>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](H,17)|0;do{if((c[at>>2]|0)!=0){az=c[ax>>2]|0;c[I>>2]=9534384;aE=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aE&16383](I,17,0)|0;if((az|0)<1){aw=1;i=e;return aw|0}if((gzL(aq,0,17)|0)==0){break}else{aw=1}i=e;return aw|0}}while(0);aq=(c[3529536]|0)+229376|0;if((c[3542200]|0)==0){aw=1;i=e;return aw|0}ax=F+108|0;c[ax>>2]=0;at=F+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](F,18)|0;do{if((c[ax>>2]|0)!=0){az=c[at>>2]|0;c[G>>2]=9534384;aE=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aE&16383](G,18,0)|0;if((az|0)<1){aw=1;i=e;return aw|0}if((gzL(aq,0,18)|0)==0){break}else{aw=1}i=e;return aw|0}}while(0);aq=c[3529536]|0;at=c[3529586]|0;ax=0;do{az=ax<<8;gGz(at+az|0,0,256);aE=ax<<9;ay=0;do{aB=1<<3-ay;aD=(c[961472+(ay<<2)>>2]|0)+aE|0;aA=0;do{aC=aD+(c[608544+(aA<<2)>>2]|0)|0;aF=(aA<<4)+az|0;aH=0;do{aI=aC+(c[609552+(aH<<2)>>2]|0)|0;if(((d[aq+((aI|0)/8|0)|0]|0)&128>>>((aI&7)>>>0)|0)!=0){aI=at+(aF+aH)|0;a[aI]=(d[aI]|0|aB)&255}aH=aH+1|0;}while((aH|0)<16);aA=aA+1|0;}while((aA|0)<16);ay=ay+1|0;}while((ay|0)<4);ax=ax+1|0;}while((ax|0)<2048);ax=c[2443582]|0;if((c[3542200]|0)==0){aw=1;i=e;return aw|0}at=D+108|0;c[at>>2]=0;aq=D+100|0;c[aq>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](D,19)|0;do{if((c[at>>2]|0)!=0){ay=c[aq>>2]|0;c[E>>2]=9534384;az=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[az&16383](E,19,0)|0;if((ay|0)<1){aw=1;i=e;return aw|0}if((gzL(ax,0,19)|0)==0){break}else{aw=1}i=e;return aw|0}}while(0);ax=c[2439974]|0;if((c[3542200]|0)==0){aw=1;i=e;return aw|0}aq=B+108|0;c[aq>>2]=0;at=B+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](B,20)|0;do{if((c[aq>>2]|0)!=0){ay=c[at>>2]|0;c[C>>2]=9534384;az=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[az&16383](C,20,0)|0;if((ay|0)<1){aw=1;i=e;return aw|0}if((gzL(ax,0,20)|0)==0){break}else{aw=1}i=e;return aw|0}}while(0);ax=c[3529864]|0;if((c[3542200]|0)==0){aw=1;i=e;return aw|0}at=z+108|0;c[at>>2]=0;aq=z+100|0;c[aq>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,21)|0;do{if((c[at>>2]|0)!=0){ay=c[aq>>2]|0;c[A>>2]=9534384;az=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[az&16383](A,21,0)|0;if((ay|0)<1){aw=1;i=e;return aw|0}if((gzL(ax,0,21)|0)==0){break}else{aw=1}i=e;return aw|0}}while(0);ax=c[2443502]|0;if((c[3542200]|0)==0){aw=1;i=e;return aw|0}aq=x+108|0;c[aq>>2]=0;at=x+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,22)|0;do{if((c[aq>>2]|0)!=0){ay=c[at>>2]|0;c[y>>2]=9534384;az=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[az&16383](y,22,0)|0;if((ay|0)<1){aw=1;i=e;return aw|0}if((gzL(ax,0,22)|0)==0){break}else{aw=1}i=e;return aw|0}}while(0);ax=c[3527344]|0;if((c[3542200]|0)==0){aw=1;i=e;return aw|0}at=v+108|0;c[at>>2]=0;aq=v+100|0;c[aq>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,23)|0;do{if((c[at>>2]|0)!=0){ay=c[aq>>2]|0;c[w>>2]=9534384;az=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[az&16383](w,23,0)|0;if((ay|0)<1){aw=1;i=e;return aw|0}if((gzL(ax,0,23)|0)==0){break}else{aw=1}i=e;return aw|0}}while(0);ax=c[2432720]|0;if((c[3542200]|0)==0){aw=1;i=e;return aw|0}aq=t+108|0;c[aq>>2]=0;at=t+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,24)|0;do{if((c[aq>>2]|0)!=0){ay=c[at>>2]|0;c[u>>2]=9534384;az=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[az&16383](u,24,0)|0;if((ay|0)<1){aw=1;i=e;return aw|0}if((gzL(ax,0,24)|0)==0){break}else{aw=1}i=e;return aw|0}}while(0);ax=c[2437758]|0;if((c[3542200]|0)==0){aw=1;i=e;return aw|0}at=r+108|0;c[at>>2]=0;aq=r+100|0;c[aq>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,25)|0;do{if((c[at>>2]|0)!=0){ay=c[aq>>2]|0;c[s>>2]=9534384;az=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[az&16383](s,25,0)|0;if((ay|0)<1){aw=1;i=e;return aw|0}if((gzL(ax,0,25)|0)==0){break}else{aw=1}i=e;return aw|0}}while(0);ax=c[2433456]|0;if((c[3542200]|0)==0){aw=1;i=e;return aw|0}aq=p+108|0;c[aq>>2]=0;at=p+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,26)|0;do{if((c[aq>>2]|0)!=0){ay=c[at>>2]|0;c[q>>2]=9534384;az=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[az&16383](q,26,0)|0;if((ay|0)<1){aw=1;i=e;return aw|0}if((gzL(ax,0,26)|0)==0){break}else{aw=1}i=e;return aw|0}}while(0);ax=c[2433458]|0;if((c[3542200]|0)==0){aw=1;i=e;return aw|0}at=n+108|0;c[at>>2]=0;aq=n+100|0;c[aq>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,27)|0;do{if((c[at>>2]|0)!=0){ay=c[aq>>2]|0;c[o>>2]=9534384;az=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[az&16383](o,27,0)|0;if((ay|0)<1){aw=1;i=e;return aw|0}if((gzL(ax,0,27)|0)==0){break}else{aw=1}i=e;return aw|0}}while(0);ax=c[2432724]|0;if((c[3542200]|0)==0){aw=1;i=e;return aw|0}aq=l+108|0;c[aq>>2]=0;at=l+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,28)|0;do{if((c[aq>>2]|0)!=0){ay=c[at>>2]|0;c[m>>2]=9534384;az=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[az&16383](m,28,0)|0;if((ay|0)<1){aw=1;i=e;return aw|0}if((gzL(ax,0,28)|0)==0){break}else{aw=1}i=e;return aw|0}}while(0);ax=c[2429760]|0;if((c[3542200]|0)==0){aw=1;i=e;return aw|0}at=j+108|0;c[at>>2]=0;aq=j+100|0;c[aq>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,29)|0;do{if((c[at>>2]|0)!=0){ay=c[aq>>2]|0;c[k>>2]=9534384;az=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[az&16383](k,29,0)|0;if((ay|0)<1){aw=1;i=e;return aw|0}if((gzL(ax,0,29)|0)==0){break}else{aw=1}i=e;return aw|0}}while(0);ax=c[2429524]|0;if((c[3542200]|0)==0){aw=1;i=e;return aw|0}aq=f+108|0;c[aq>>2]=0;at=f+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,30)|0;do{if((c[aq>>2]|0)!=0){ay=c[at>>2]|0;c[g>>2]=9534384;az=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[az&16383](g,30,0)|0;if((ay|0)<1){aw=1;i=e;return aw|0}if((gzL(ax,0,30)|0)==0){break}else{aw=1}i=e;return aw|0}}while(0);ax=c[3529536]|0;at=0;while(1){if((at|0)>=1024){break}aJ=9638528+(at<<2)|0;if((c[aJ>>2]|0)==(ax|0)){as=77780;break}else{at=at+1|0}}if((as|0)==77780){gGr(ax);c[aJ>>2]=0}c[3529536]=0;fwR(0);at=c[2439330]|0;aq=(at|0)==0;if(!aq){ay=at;gGC(9706056,ay|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];ay=c[3528484]|0;c[2076596]=ay;az=c[2417276]|0;c[3541536]=az;c[1836236]=0;c[at+4180>>2]=2850;c[at+4184>>2]=3048;c[at+4172>>2]=2864;c[at+4176>>2]=2218;aE=c[3529126]|0;aA=0;aB=0;while(1){c[at+76+(aB<<2)>>2]=aE+(aB<<8);aD=aA+1&65535;if((aD&65535)>127){aK=0;aL=0;break}else{aA=aD;aB=aD&65535}}while(1){aB=aE+(aL<<8)|0;c[at+76+(aL+512<<2)>>2]=aB;c[at+76+(aL+768<<2)>>2]=aB;aB=aK+1&65535;if((aB&65535)>127){aM=128;aN=128;break}else{aK=aB;aL=aB&65535}}while(1){c[at+76+(aN<<2)>>2]=aE+((aN<<8)+32768);aB=aM+1&65535;if((aB&65535)>191){aO=128;aP=128;break}else{aM=aB;aN=aB&65535}}while(1){aB=aE+((aP<<8)+32768)|0;c[at+76+(aP+512<<2)>>2]=aB;c[at+76+(aP+768<<2)>>2]=aB;aB=aO+1&65535;if((aB&65535)>191){break}else{aO=aB;aP=aB&65535}}aE=c[3527220]|0;c[at+908>>2]=aE;aB=aE+256|0;c[at+912>>2]=aB;aA=aE+512|0;c[at+916>>2]=aA;ax=aE+768|0;c[at+920>>2]=ax;c[at+1932>>2]=aE;c[at+1936>>2]=aB;c[at+1940>>2]=aA;c[at+1944>>2]=ax;c[at+2956>>2]=aE;c[at+3980>>2]=aE;c[at+2960>>2]=aB;c[at+3984>>2]=aB;c[at+2964>>2]=aA;c[at+3988>>2]=aA;c[at+2968>>2]=ax;c[at+3992>>2]=ax;ax=c[2439622]|0;c[at+924>>2]=ax;aA=ax+256|0;c[at+928>>2]=aA;aB=ax+512|0;c[at+932>>2]=aB;aE=ax+768|0;c[at+936>>2]=aE;c[at+1948>>2]=ax;c[at+1952>>2]=aA;c[at+1956>>2]=aB;c[at+1960>>2]=aE;c[at+2972>>2]=ax;c[at+3996>>2]=ax;c[at+2976>>2]=aA;c[at+4e3>>2]=aA;c[at+2980>>2]=aB;c[at+4004>>2]=aB;c[at+2984>>2]=aE;c[at+4008>>2]=aE;aE=c[3529156]|0;c[at+972>>2]=aE;c[at+976>>2]=aE+256;c[at+980>>2]=aE+512;c[at+984>>2]=aE+768;c[at+988>>2]=aE+1024;c[at+992>>2]=aE+1280;c[at+996>>2]=aE+1536;c[at+1e3>>2]=aE+1792;c[at+1004>>2]=aE+2048;c[at+1008>>2]=aE+2304;c[at+1012>>2]=aE+2560;c[at+1016>>2]=aE+2816;c[at+1020>>2]=aE+3072;c[at+1024>>2]=aE+3328;c[at+1028>>2]=aE+3584;c[at+1032>>2]=aE+3840;aB=224;aA=224;while(1){c[at+76+(aA+256<<2)>>2]=aE+((aA<<8)-57344);ax=aB+1&65535;if((ax&65535)>239){aQ=224;aR=224;break}else{aB=ax;aA=ax&65535}}while(1){aA=aE+((aR<<8)-57344)|0;c[at+76+(aR+512<<2)>>2]=aA;c[at+76+(aR+768<<2)>>2]=aA;aA=aQ+1&65535;if((aA&65535)>239){break}else{aQ=aA;aR=aA&65535}}aE=c[2443426]|0;c[at+1036>>2]=aE;c[at+1040>>2]=aE+256;c[at+1044>>2]=aE+512;c[at+1048>>2]=aE+768;c[at+1052>>2]=aE+1024;c[at+1056>>2]=aE+1280;c[at+1060>>2]=aE+1536;c[at+1064>>2]=aE+1792;c[at+1068>>2]=aE+2048;c[at+1072>>2]=aE+2304;c[at+1076>>2]=aE+2560;c[at+1080>>2]=aE+2816;c[at+1084>>2]=aE+3072;c[at+1088>>2]=aE+3328;c[at+1092>>2]=aE+3584;c[at+1096>>2]=aE+3840;aA=240;aB=240;while(1){c[at+76+(aB+256<<2)>>2]=aE+((aB<<8)-61440);ax=aA+1&65535;if((ax&65535)>255){aS=240;aT=240;break}else{aA=ax;aB=ax&65535}}while(1){aB=aE+((aT<<8)-61440)|0;c[at+76+(aT+512<<2)>>2]=aB;c[at+76+(aT+768<<2)>>2]=aB;aB=aS+1&65535;if((aB&65535)>255){break}else{aS=aB;aT=aB&65535}}if(!aq){aE=at;gGC(aE|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=ay;c[2417276]=az;c[1836236]=-1;fwR(1);aE=c[2439331]|0;aB=(aE|0)==0;if(!aB){aA=aE;gGC(9706056,aA|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];aA=c[3528485]|0;c[2076596]=aA;ax=c[2417277]|0;c[3541536]=ax;c[1836236]=1;c[aE+4180>>2]=640;c[aE+4184>>2]=2278;c[aE+4172>>2]=2464;c[aE+4176>>2]=3262;aD=c[3529114]|0;aH=0;aF=0;while(1){c[aE+76+(aF<<2)>>2]=aD+(aF<<8);aC=aH+1&65535;if((aC&65535)>127){aU=0;aV=0;break}else{aH=aC;aF=aC&65535}}while(1){aF=aD+(aV<<8)|0;c[aE+76+(aV+512<<2)>>2]=aF;c[aE+76+(aV+768<<2)>>2]=aF;aF=aU+1&65535;if((aF&65535)>127){break}else{aU=aF;aV=aF&65535}}aD=c[3529146]|0;c[aE+844>>2]=aD;aF=aD+256|0;c[aE+848>>2]=aF;aH=aD+512|0;c[aE+852>>2]=aH;az=aD+768|0;c[aE+856>>2]=az;ay=aD+1024|0;c[aE+860>>2]=ay;at=aD+1280|0;c[aE+864>>2]=at;aq=aD+1536|0;c[aE+868>>2]=aq;aC=aD+1792|0;c[aE+872>>2]=aC;c[aE+1868>>2]=aD;c[aE+1872>>2]=aF;c[aE+1876>>2]=aH;c[aE+1880>>2]=az;c[aE+1884>>2]=ay;c[aE+1888>>2]=at;c[aE+1892>>2]=aq;c[aE+1896>>2]=aC;c[aE+2892>>2]=aD;c[aE+3916>>2]=aD;c[aE+2896>>2]=aF;c[aE+3920>>2]=aF;c[aE+2900>>2]=aH;c[aE+3924>>2]=aH;c[aE+2904>>2]=az;c[aE+3928>>2]=az;c[aE+2908>>2]=ay;c[aE+3932>>2]=ay;c[aE+2912>>2]=at;c[aE+3936>>2]=at;c[aE+2916>>2]=aq;c[aE+3940>>2]=aq;c[aE+2920>>2]=aC;c[aE+3944>>2]=aC;if(!aB){aC=aE;gGC(aC|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=aA;c[2417277]=ax;c[1836236]=-1;Vr(2,15e5,0,2870,126,0);c[2438228]=3e6;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=681;h[745419]=.1;a[3203368]=1;h[745418]=.15;a[3203360]=1;h[745417]=.15;a[3203352]=1;h[745416]=.15;a[3203344]=1;h[745415]=.1;a[3203336]=1;h[745414]=.15;a[3203328]=1;h[745413]=.15;a[3203320]=1;h[745412]=.15;a[3203312]=1;aC=c[642608+(c[2436]<<2)>>2]|0;aq=c[aC+128>>2]|0;if((c[aC+52>>2]&4|0)==0){c[2113068]=aq;at=c[aC+132>>2]|0;c[2113070]=at;c[2443814]=aq;c[2440436]=at;aW=aq;aX=at}else{c[2113070]=aq;at=c[aC+132>>2]|0;c[2113068]=at;c[2440436]=aq;c[2443814]=at;aW=at;aX=aq}aq=ag(aW<<1,aX)|0;at=gGq(aq)|0;c[2112926]=at;if((at|0)!=0){gGz(at|0,0,aq|0)}aq=c[2439330]|0;at=(aq|0)==0;if(!at){aC=aq;gGC(9706056,aC|0,76)|0}aC=c[2438118]|0;c[2433530]=aC;ay=c[3528484]|0;c[2076596]=ay;az=c[2417276]|0;c[3541536]=az;c[1836236]=0;gGz(9706056,0,76);if(!at){at=aq;gGC(at|0,9706056,76)|0}c[2438118]=aC;c[3528484]=ay;c[2417276]=az;c[1836236]=-1;az=c[2439331]|0;ay=(az|0)==0;if(!ay){aC=az;gGC(9706056,aC|0,76)|0}aC=c[2438119]|0;c[2433530]=aC;at=c[3528485]|0;c[2076596]=at;aq=c[2417277]|0;c[3541536]=aq;c[1836236]=1;gGz(9706056,0,76);if(!ay){ay=az;gGC(ay|0,9706056,76)|0}c[2438119]=aC;c[3528485]=at;c[2417277]=aq;c[1836236]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){aq=0;do{lN(aq);mB(aq);aq=aq+1|0;}while((aq|0)<(c[2385508]|0))}a[14119344]=0;a[9758216]=0;a[9759904]=0;a[9759905]=0;a[9774408]=0;a[9774409]=0;a[9774360]=0;a[9626360]=0;a[9626368]=0;a[9773592]=0;a[14124232]=0;aw=0;i=e;return aw|0}}while(0);c[2426786]=0;aw=1;i=e;return aw|0}function drN(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>30){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6916260+(b*112|0)>>2];c[a+104>>2]=c[6916264+(b*112|0)>>2];c[a+108>>2]=c[6916268+(b*112|0)>>2];d=0;return d|0}function drO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<31&(d|0)==0)){e=1;return e|0}c[a>>2]=6916160+(b*112|0);e=0;return e|0}function drP(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0;e=i;i=i+3480|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;B=e+1200|0;C=e+1312|0;D=e+1320|0;E=e+1432|0;F=e+1440|0;G=e+1552|0;H=e+1560|0;I=e+1672|0;J=e+1680|0;K=e+1792|0;L=e+1800|0;M=e+1912|0;N=e+1920|0;O=e+2032|0;P=e+2040|0;Q=e+2152|0;R=e+2160|0;S=e+2272|0;T=e+2280|0;U=e+2392|0;V=e+2400|0;W=e+2512|0;X=e+2520|0;Y=e+2632|0;Z=e+2640|0;_=e+2752|0;$=e+2760|0;aa=e+2872|0;ab=e+2880|0;ac=e+2992|0;ad=e+3e3|0;ae=e+3112|0;af=e+3120|0;ah=e+3232|0;ai=e+3240|0;aj=e+3352|0;ak=e+3360|0;al=e+3472|0;c[2426786]=0;c[3529126]=0;c[3529114]=196608;c[3529864]=229376;c[2443502]=229632;c[3527344]=229888;c[2432720]=230144;c[2433458]=230400;c[2432724]=230656;c[2437758]=230912;c[2433456]=231168;c[2429760]=231424;c[2429524]=231680;c[2443582]=231936;c[2439974]=264704;c[2405694]=297472;c[3529156]=297472;c[3529146]=301568;c[3527220]=303616;c[2439622]=304640;c[2443426]=305664;c[2411776]=309760;c[2406534]=309760;c[3527478]=440832;c[3531068]=571904;c[3529586]=1096192;c[3530102]=1620480;am=0;while(1){if((am|0)>=1024){break}an=9638528+(am<<2)|0;if((c[an>>2]|0)==0){ao=77936;break}else{am=am+1|0}}do{if((ao|0)==77936){am=gGq(1624064)|0;c[an>>2]=am;if((am|0)==0){break}c[2426786]=am;gGz(am|0,0,1624064);c[3529126]=am;c[3529114]=am+196608;c[3529864]=am+229376;c[2443502]=am+229632;c[3527344]=am+229888;c[2432720]=am+230144;c[2433458]=am+230400;c[2432724]=am+230656;c[2437758]=am+230912;c[2433456]=am+231168;c[2429760]=am+231424;c[2429524]=am+231680;c[2443582]=am+231936;c[2439974]=am+264704;ap=am+297472|0;c[2405694]=ap;c[3529156]=ap;c[3529146]=am+301568;c[3527220]=am+303616;c[2439622]=am+304640;c[2443426]=am+305664;ap=am+309760|0;c[2411776]=ap;c[2406534]=ap;c[3527478]=am+440832;c[3531068]=am+571904;c[3529586]=am+1096192;c[3530102]=am+1620480;c[2414324]=am+1624064;am=0;while(1){if((am|0)>=1024){aq=0;break}ar=9638528+(am<<2)|0;if((c[ar>>2]|0)==0){ao=77941;break}else{am=am+1|0}}do{if((ao|0)==77941){am=gGq(262144)|0;c[ar>>2]=am;if((am|0)==0){aq=0;break}gGz(am|0,0,262144);aq=am}}while(0);c[3529536]=aq;am=c[3529126]|0;if((c[3542200]|0)==0){as=1;i=e;return as|0}ap=ak+108|0;c[ap>>2]=0;at=ak+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](ak,0)|0;do{if((c[ap>>2]|0)!=0){au=c[at>>2]|0;c[al>>2]=9534384;av=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[av&16383](al,0,0)|0;if((au|0)<1){as=1;i=e;return as|0}if((gzL(am,0,0)|0)==0){break}else{as=1}i=e;return as|0}}while(0);am=(c[3529126]|0)+65536|0;if((c[3542200]|0)==0){as=1;i=e;return as|0}at=ai+108|0;c[at>>2]=0;ap=ai+100|0;c[ap>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](ai,1)|0;do{if((c[at>>2]|0)!=0){au=c[ap>>2]|0;c[aj>>2]=9534384;av=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[av&16383](aj,1,0)|0;if((au|0)<1){as=1;i=e;return as|0}if((gzL(am,0,1)|0)==0){break}else{as=1}i=e;return as|0}}while(0);am=(c[3529126]|0)+131072|0;if((c[3542200]|0)==0){as=1;i=e;return as|0}ap=af+108|0;c[ap>>2]=0;at=af+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](af,2)|0;do{if((c[ap>>2]|0)!=0){au=c[at>>2]|0;c[ah>>2]=9534384;av=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[av&16383](ah,2,0)|0;if((au|0)<1){as=1;i=e;return as|0}if((gzL(am,0,2)|0)==0){break}else{as=1}i=e;return as|0}}while(0);am=c[3529114]|0;if((c[3542200]|0)==0){as=1;i=e;return as|0}at=ad+108|0;c[at>>2]=0;ap=ad+100|0;c[ap>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](ad,3)|0;do{if((c[at>>2]|0)!=0){au=c[ap>>2]|0;c[ae>>2]=9534384;av=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[av&16383](ae,3,0)|0;if((au|0)<1){as=1;i=e;return as|0}if((gzL(am,0,3)|0)==0){break}else{as=1}i=e;return as|0}}while(0);am=c[3529536]|0;if((c[3542200]|0)==0){as=1;i=e;return as|0}ap=ab+108|0;c[ap>>2]=0;at=ab+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](ab,4)|0;do{if((c[ap>>2]|0)!=0){au=c[at>>2]|0;c[ac>>2]=9534384;av=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[av&16383](ac,4,0)|0;if((au|0)<1){as=1;i=e;return as|0}if((gzL(am,0,4)|0)==0){break}else{as=1}i=e;return as|0}}while(0);am=c[3529536]|0;at=c[2406534]|0;ap=0;do{au=ap<<6;gGz(at+au|0,0,64);av=ap<<7;aw=av|4;ax=0;while(1){ay=aw+(c[6669224+(ax<<2)>>2]|0)|0;az=(ax<<3)+au|0;aA=0;do{aB=ay+(c[612480+(aA<<2)>>2]|0)|0;if(((d[am+((aB|0)/8|0)|0]|0)&128>>>((aB&7)>>>0)|0)!=0){aB=at+(az+aA)|0;a[aB]=a[aB]|2}aA=aA+1|0;}while((aA|0)<8);aA=ax+1|0;if((aA|0)<8){ax=aA}else{aC=0;break}}do{ax=av+(c[6669224+(aC<<2)>>2]|0)|0;aw=(aC<<3)+au|0;aA=0;do{az=ax+(c[612480+(aA<<2)>>2]|0)|0;if(((d[am+((az|0)/8|0)|0]|0)&128>>>((az&7)>>>0)|0)!=0){az=at+(aw+aA)|0;a[az]=a[az]|1}aA=aA+1|0;}while((aA|0)<8);aC=aC+1|0;}while((aC|0)<8);ap=ap+1|0;}while((ap|0)<2048);gGz(am|0,0,262144);if((c[3542200]|0)==0){as=1;i=e;return as|0}ap=$+108|0;c[ap>>2]=0;at=$+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383]($,9)|0;do{if((c[ap>>2]|0)!=0){au=c[at>>2]|0;c[aa>>2]=9534384;av=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[av&16383](aa,9,0)|0;if((au|0)<1){as=1;i=e;return as|0}if((gzL(am,0,9)|0)==0){break}else{as=1}i=e;return as|0}}while(0);am=(c[3529536]|0)+32768|0;if((c[3542200]|0)==0){as=1;i=e;return as|0}at=Z+108|0;c[at>>2]=0;ap=Z+100|0;c[ap>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](Z,10)|0;do{if((c[at>>2]|0)!=0){au=c[ap>>2]|0;c[_>>2]=9534384;av=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[av&16383](_,10,0)|0;if((au|0)<1){as=1;i=e;return as|0}if((gzL(am,0,10)|0)==0){break}else{as=1}i=e;return as|0}}while(0);am=c[3529536]|0;ap=c[3527478]|0;at=0;do{au=at<<10;gGz(ap+au|0,0,1024);av=at<<11;aA=0;do{aw=1<<3-aA;ax=(c[613264+(aA<<2)>>2]|0)+av|0;az=0;do{ay=ax+(c[609168+(az<<2)>>2]|0)|0;aB=(az<<5)+au|0;aD=0;do{aE=ay+(c[610736+(aD<<2)>>2]|0)|0;if(((d[am+((aE|0)/8|0)|0]|0)&128>>>((aE&7)>>>0)|0)!=0){aE=ap+(aB+aD)|0;a[aE]=(d[aE]|0|aw)&255}aD=aD+1|0;}while((aD|0)<32);az=az+1|0;}while((az|0)<32);aA=aA+1|0;}while((aA|0)<4);at=at+1|0;}while((at|0)<128);gGz(am|0,0,262144);at=0;while(1){if((at|0)>=1024){aF=0;break}aG=9638528+(at<<2)|0;if((c[aG>>2]|0)==0){ao=77991;break}else{at=at+1|0}}do{if((ao|0)==77991){at=gGq(262144)|0;c[aG>>2]=at;if((at|0)==0){aF=0;break}gGz(at|0,0,262144);aF=at}}while(0);if((c[3542200]|0)==0){as=1;i=e;return as|0}at=X+108|0;c[at>>2]=0;am=X+100|0;c[am>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](X,5)|0;do{if((c[at>>2]|0)!=0){ap=c[am>>2]|0;c[Y>>2]=9534384;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aA&16383](Y,5,0)|0;if((ap|0)<1){as=1;i=e;return as|0}if((gzL(aF,0,5)|0)==0){break}else{as=1}i=e;return as|0}}while(0);am=aF+65536|0;if((c[3542200]|0)==0){as=1;i=e;return as|0}at=V+108|0;c[at>>2]=0;ap=V+100|0;c[ap>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](V,6)|0;do{if((c[at>>2]|0)!=0){aA=c[ap>>2]|0;c[W>>2]=9534384;au=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[au&16383](W,6,0)|0;if((aA|0)<1){as=1;i=e;return as|0}if((gzL(am,0,6)|0)==0){break}else{as=1}i=e;return as|0}}while(0);ap=aF+131072|0;if((c[3542200]|0)==0){as=1;i=e;return as|0}at=T+108|0;c[at>>2]=0;aA=T+100|0;c[aA>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](T,7)|0;do{if((c[at>>2]|0)!=0){au=c[aA>>2]|0;c[U>>2]=9534384;av=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[av&16383](U,7,0)|0;if((au|0)<1){as=1;i=e;return as|0}if((gzL(ap,0,7)|0)==0){break}else{as=1}i=e;return as|0}}while(0);aA=aF+196608|0;if((c[3542200]|0)==0){as=1;i=e;return as|0}at=R+108|0;c[at>>2]=0;au=R+100|0;c[au>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](R,8)|0;do{if((c[at>>2]|0)!=0){av=c[au>>2]|0;c[S>>2]=9534384;az=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[az&16383](S,8,0)|0;if((av|0)<1){as=1;i=e;return as|0}if((gzL(aA,0,8)|0)==0){break}else{as=1}i=e;return as|0}}while(0);au=c[3529536]|0;gGC(au|0,aF|0,32768)|0;at=au+65536|0;av=aF+32768|0;gGC(at|0,av|0,32768)|0;av=au+32768|0;gGC(av|0,am|0,32768)|0;av=au+98304|0;at=aF+98304|0;gGC(av|0,at|0,32768)|0;at=au+131072|0;gGC(at|0,ap|0,32768)|0;at=au+196608|0;av=aF+163840|0;gGC(at|0,av|0,32768)|0;av=au+163840|0;gGC(av|0,aA|0,32768)|0;av=au+229376|0;at=aF+229376|0;gGC(av|0,at|0,32768)|0;at=0;while(1){if((at|0)>=1024){aH=au;break}aI=9638528+(at<<2)|0;if((c[aI>>2]|0)==(aF|0)){ao=78012;break}else{at=at+1|0}}if((ao|0)==78012){gGr(aF);c[aI>>2]=0;aH=c[3529536]|0}at=c[3531068]|0;au=0;do{aA=au<<10;gGz(at+aA|0,0,1024);ap=au<<11;am=0;do{av=1<<3-am;az=(c[961472+(am<<2)>>2]|0)+ap|0;aw=0;do{ax=az+(c[609168+(aw<<2)>>2]|0)|0;aD=(aw<<5)+aA|0;aB=0;do{ay=ax+(c[610736+(aB<<2)>>2]|0)|0;if(((d[aH+((ay|0)/8|0)|0]|0)&128>>>((ay&7)>>>0)|0)!=0){ay=at+(aD+aB)|0;a[ay]=(d[ay]|0|av)&255}aB=aB+1|0;}while((aB|0)<32);aw=aw+1|0;}while((aw|0)<32);am=am+1|0;}while((am|0)<4);au=au+1|0;}while((au|0)<512);gGz(aH|0,0,262144);if((c[3542200]|0)==0){as=1;i=e;return as|0}au=P+108|0;c[au>>2]=0;at=P+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](P,11)|0;do{if((c[au>>2]|0)!=0){am=c[at>>2]|0;c[Q>>2]=9534384;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aA&16383](Q,11,0)|0;if((am|0)<1){as=1;i=e;return as|0}if((gzL(aH,0,11)|0)==0){break}else{as=1}i=e;return as|0}}while(0);at=(c[3529536]|0)+32768|0;if((c[3542200]|0)==0){as=1;i=e;return as|0}au=N+108|0;c[au>>2]=0;am=N+100|0;c[am>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](N,12)|0;do{if((c[au>>2]|0)!=0){aA=c[am>>2]|0;c[O>>2]=9534384;ap=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ap&16383](O,12,0)|0;if((aA|0)<1){as=1;i=e;return as|0}if((gzL(at,0,12)|0)==0){break}else{as=1}i=e;return as|0}}while(0);at=(c[3529536]|0)+65536|0;if((c[3542200]|0)==0){as=1;i=e;return as|0}am=L+108|0;c[am>>2]=0;au=L+100|0;c[au>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](L,13)|0;do{if((c[am>>2]|0)!=0){aA=c[au>>2]|0;c[M>>2]=9534384;ap=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ap&16383](M,13,0)|0;if((aA|0)<1){as=1;i=e;return as|0}if((gzL(at,0,13)|0)==0){break}else{as=1}i=e;return as|0}}while(0);at=(c[3529536]|0)+131072|0;if((c[3542200]|0)==0){as=1;i=e;return as|0}au=J+108|0;c[au>>2]=0;am=J+100|0;c[am>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](J,14)|0;do{if((c[au>>2]|0)!=0){aA=c[am>>2]|0;c[K>>2]=9534384;ap=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ap&16383](K,14,0)|0;if((aA|0)<1){as=1;i=e;return as|0}if((gzL(at,0,14)|0)==0){break}else{as=1}i=e;return as|0}}while(0);at=(c[3529536]|0)+163840|0;if((c[3542200]|0)==0){as=1;i=e;return as|0}am=H+108|0;c[am>>2]=0;au=H+100|0;c[au>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](H,15)|0;do{if((c[am>>2]|0)!=0){aA=c[au>>2]|0;c[I>>2]=9534384;ap=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ap&16383](I,15,0)|0;if((aA|0)<1){as=1;i=e;return as|0}if((gzL(at,0,15)|0)==0){break}else{as=1}i=e;return as|0}}while(0);at=(c[3529536]|0)+196608|0;if((c[3542200]|0)==0){as=1;i=e;return as|0}au=F+108|0;c[au>>2]=0;am=F+100|0;c[am>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](F,16)|0;do{if((c[au>>2]|0)!=0){aA=c[am>>2]|0;c[G>>2]=9534384;ap=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ap&16383](G,16,0)|0;if((aA|0)<1){as=1;i=e;return as|0}if((gzL(at,0,16)|0)==0){break}else{as=1}i=e;return as|0}}while(0);at=c[3529536]|0;am=c[3529586]|0;au=0;do{aA=au<<8;gGz(am+aA|0,0,256);ap=au<<9;aw=0;do{av=1<<3-aw;az=(c[961472+(aw<<2)>>2]|0)+ap|0;aB=0;do{aD=az+(c[608544+(aB<<2)>>2]|0)|0;ax=(aB<<4)+aA|0;ay=0;do{aE=aD+(c[609552+(ay<<2)>>2]|0)|0;if(((d[at+((aE|0)/8|0)|0]|0)&128>>>((aE&7)>>>0)|0)!=0){aE=am+(ax+ay)|0;a[aE]=(d[aE]|0|av)&255}ay=ay+1|0;}while((ay|0)<16);aB=aB+1|0;}while((aB|0)<16);aw=aw+1|0;}while((aw|0)<4);au=au+1|0;}while((au|0)<2048);au=c[2443582]|0;if((c[3542200]|0)==0){as=1;i=e;return as|0}am=D+108|0;c[am>>2]=0;at=D+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](D,17)|0;do{if((c[am>>2]|0)!=0){aw=c[at>>2]|0;c[E>>2]=9534384;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aA&16383](E,17,0)|0;if((aw|0)<1){as=1;i=e;return as|0}if((gzL(au,0,17)|0)==0){break}else{as=1}i=e;return as|0}}while(0);au=c[3529536]|0;if((c[3542200]|0)==0){as=1;i=e;return as|0}at=B+108|0;c[at>>2]=0;am=B+100|0;c[am>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](B,18)|0;do{if((c[at>>2]|0)!=0){aw=c[am>>2]|0;c[C>>2]=9534384;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aA&16383](C,18,0)|0;if((aw|0)<1){as=1;i=e;return as|0}if((gzL(au,0,18)|0)==0){break}else{as=1}i=e;return as|0}}while(0);au=c[2439974]|0;am=au+24576|0;at=c[3529536]|0;gGC(am|0,at|0,8192)|0;am=au+16384|0;aw=at+8192|0;gGC(am|0,aw|0,8192)|0;aw=au+8192|0;am=at+16384|0;gGC(aw|0,am|0,8192)|0;am=at+24576|0;gGC(au|0,am|0,8192)|0;am=c[3529864]|0;if((c[3542200]|0)==0){as=1;i=e;return as|0}au=z+108|0;c[au>>2]=0;at=z+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,19)|0;do{if((c[au>>2]|0)!=0){aw=c[at>>2]|0;c[A>>2]=9534384;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aA&16383](A,19,0)|0;if((aw|0)<1){as=1;i=e;return as|0}if((gzL(am,0,19)|0)==0){break}else{as=1}i=e;return as|0}}while(0);am=c[2443502]|0;if((c[3542200]|0)==0){as=1;i=e;return as|0}at=x+108|0;c[at>>2]=0;au=x+100|0;c[au>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,20)|0;do{if((c[at>>2]|0)!=0){aw=c[au>>2]|0;c[y>>2]=9534384;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aA&16383](y,20,0)|0;if((aw|0)<1){as=1;i=e;return as|0}if((gzL(am,0,20)|0)==0){break}else{as=1}i=e;return as|0}}while(0);am=c[3527344]|0;if((c[3542200]|0)==0){as=1;i=e;return as|0}au=v+108|0;c[au>>2]=0;at=v+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,21)|0;do{if((c[au>>2]|0)!=0){aw=c[at>>2]|0;c[w>>2]=9534384;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aA&16383](w,21,0)|0;if((aw|0)<1){as=1;i=e;return as|0}if((gzL(am,0,21)|0)==0){break}else{as=1}i=e;return as|0}}while(0);am=c[2432720]|0;if((c[3542200]|0)==0){as=1;i=e;return as|0}at=t+108|0;c[at>>2]=0;au=t+100|0;c[au>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,22)|0;do{if((c[at>>2]|0)!=0){aw=c[au>>2]|0;c[u>>2]=9534384;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aA&16383](u,22,0)|0;if((aw|0)<1){as=1;i=e;return as|0}if((gzL(am,0,22)|0)==0){break}else{as=1}i=e;return as|0}}while(0);am=c[2437758]|0;if((c[3542200]|0)==0){as=1;i=e;return as|0}au=r+108|0;c[au>>2]=0;at=r+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,23)|0;do{if((c[au>>2]|0)!=0){aw=c[at>>2]|0;c[s>>2]=9534384;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aA&16383](s,23,0)|0;if((aw|0)<1){as=1;i=e;return as|0}if((gzL(am,0,23)|0)==0){break}else{as=1}i=e;return as|0}}while(0);am=c[2433456]|0;if((c[3542200]|0)==0){as=1;i=e;return as|0}at=p+108|0;c[at>>2]=0;au=p+100|0;c[au>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,24)|0;do{if((c[at>>2]|0)!=0){aw=c[au>>2]|0;c[q>>2]=9534384;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aA&16383](q,24,0)|0;if((aw|0)<1){as=1;i=e;return as|0}if((gzL(am,0,24)|0)==0){break}else{as=1}i=e;return as|0}}while(0);am=c[2433458]|0;if((c[3542200]|0)==0){as=1;i=e;return as|0}au=n+108|0;c[au>>2]=0;at=n+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,25)|0;do{if((c[au>>2]|0)!=0){aw=c[at>>2]|0;c[o>>2]=9534384;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aA&16383](o,25,0)|0;if((aw|0)<1){as=1;i=e;return as|0}if((gzL(am,0,25)|0)==0){break}else{as=1}i=e;return as|0}}while(0);am=c[2432724]|0;if((c[3542200]|0)==0){as=1;i=e;return as|0}at=l+108|0;c[at>>2]=0;au=l+100|0;c[au>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,26)|0;do{if((c[at>>2]|0)!=0){aw=c[au>>2]|0;c[m>>2]=9534384;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aA&16383](m,26,0)|0;if((aw|0)<1){as=1;i=e;return as|0}if((gzL(am,0,26)|0)==0){break}else{as=1}i=e;return as|0}}while(0);am=c[2429760]|0;if((c[3542200]|0)==0){as=1;i=e;return as|0}au=j+108|0;c[au>>2]=0;at=j+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,27)|0;do{if((c[au>>2]|0)!=0){aw=c[at>>2]|0;c[k>>2]=9534384;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aA&16383](k,27,0)|0;if((aw|0)<1){as=1;i=e;return as|0}if((gzL(am,0,27)|0)==0){break}else{as=1}i=e;return as|0}}while(0);am=c[2429524]|0;if((c[3542200]|0)==0){as=1;i=e;return as|0}at=f+108|0;c[at>>2]=0;au=f+100|0;c[au>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,28)|0;do{if((c[at>>2]|0)!=0){aw=c[au>>2]|0;c[g>>2]=9534384;aA=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aA&16383](g,28,0)|0;if((aw|0)<1){as=1;i=e;return as|0}if((gzL(am,0,28)|0)==0){break}else{as=1}i=e;return as|0}}while(0);am=c[3529536]|0;au=0;while(1){if((au|0)>=1024){break}aJ=9638528+(au<<2)|0;if((c[aJ>>2]|0)==(am|0)){ao=78108;break}else{au=au+1|0}}if((ao|0)==78108){gGr(am);c[aJ>>2]=0}c[3529536]=0;fwR(0);au=c[2439330]|0;at=(au|0)==0;if(!at){aw=au;gGC(9706056,aw|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];aw=c[3528484]|0;c[2076596]=aw;aA=c[2417276]|0;c[3541536]=aA;c[1836236]=0;c[au+4180>>2]=2850;c[au+4184>>2]=3048;c[au+4172>>2]=2864;c[au+4176>>2]=2218;ap=c[3529126]|0;aB=0;av=0;while(1){c[au+76+(av<<2)>>2]=ap+(av<<8);az=aB+1&65535;if((az&65535)>127){aK=0;aL=0;break}else{aB=az;av=az&65535}}while(1){av=ap+(aL<<8)|0;c[au+76+(aL+512<<2)>>2]=av;c[au+76+(aL+768<<2)>>2]=av;av=aK+1&65535;if((av&65535)>127){aM=128;aN=128;break}else{aK=av;aL=av&65535}}while(1){c[au+76+(aN<<2)>>2]=ap+((aN<<8)+32768);av=aM+1&65535;if((av&65535)>191){aO=128;aP=128;break}else{aM=av;aN=av&65535}}while(1){av=ap+((aP<<8)+32768)|0;c[au+76+(aP+512<<2)>>2]=av;c[au+76+(aP+768<<2)>>2]=av;av=aO+1&65535;if((av&65535)>191){break}else{aO=av;aP=av&65535}}ap=c[3527220]|0;c[au+908>>2]=ap;av=ap+256|0;c[au+912>>2]=av;aB=ap+512|0;c[au+916>>2]=aB;am=ap+768|0;c[au+920>>2]=am;c[au+1932>>2]=ap;c[au+1936>>2]=av;c[au+1940>>2]=aB;c[au+1944>>2]=am;c[au+2956>>2]=ap;c[au+3980>>2]=ap;c[au+2960>>2]=av;c[au+3984>>2]=av;c[au+2964>>2]=aB;c[au+3988>>2]=aB;c[au+2968>>2]=am;c[au+3992>>2]=am;am=c[2439622]|0;c[au+924>>2]=am;aB=am+256|0;c[au+928>>2]=aB;av=am+512|0;c[au+932>>2]=av;ap=am+768|0;c[au+936>>2]=ap;c[au+1948>>2]=am;c[au+1952>>2]=aB;c[au+1956>>2]=av;c[au+1960>>2]=ap;c[au+2972>>2]=am;c[au+3996>>2]=am;c[au+2976>>2]=aB;c[au+4e3>>2]=aB;c[au+2980>>2]=av;c[au+4004>>2]=av;c[au+2984>>2]=ap;c[au+4008>>2]=ap;ap=c[3529156]|0;c[au+972>>2]=ap;c[au+976>>2]=ap+256;c[au+980>>2]=ap+512;c[au+984>>2]=ap+768;c[au+988>>2]=ap+1024;c[au+992>>2]=ap+1280;c[au+996>>2]=ap+1536;c[au+1e3>>2]=ap+1792;c[au+1004>>2]=ap+2048;c[au+1008>>2]=ap+2304;c[au+1012>>2]=ap+2560;c[au+1016>>2]=ap+2816;c[au+1020>>2]=ap+3072;c[au+1024>>2]=ap+3328;c[au+1028>>2]=ap+3584;c[au+1032>>2]=ap+3840;av=224;aB=224;while(1){c[au+76+(aB+256<<2)>>2]=ap+((aB<<8)-57344);am=av+1&65535;if((am&65535)>239){aQ=224;aR=224;break}else{av=am;aB=am&65535}}while(1){aB=ap+((aR<<8)-57344)|0;c[au+76+(aR+512<<2)>>2]=aB;c[au+76+(aR+768<<2)>>2]=aB;aB=aQ+1&65535;if((aB&65535)>239){break}else{aQ=aB;aR=aB&65535}}ap=c[2443426]|0;c[au+1036>>2]=ap;c[au+1040>>2]=ap+256;c[au+1044>>2]=ap+512;c[au+1048>>2]=ap+768;c[au+1052>>2]=ap+1024;c[au+1056>>2]=ap+1280;c[au+1060>>2]=ap+1536;c[au+1064>>2]=ap+1792;c[au+1068>>2]=ap+2048;c[au+1072>>2]=ap+2304;c[au+1076>>2]=ap+2560;c[au+1080>>2]=ap+2816;c[au+1084>>2]=ap+3072;c[au+1088>>2]=ap+3328;c[au+1092>>2]=ap+3584;c[au+1096>>2]=ap+3840;aB=240;av=240;while(1){c[au+76+(av+256<<2)>>2]=ap+((av<<8)-61440);am=aB+1&65535;if((am&65535)>255){aS=240;aT=240;break}else{aB=am;av=am&65535}}while(1){av=ap+((aT<<8)-61440)|0;c[au+76+(aT+512<<2)>>2]=av;c[au+76+(aT+768<<2)>>2]=av;av=aS+1&65535;if((av&65535)>255){break}else{aS=av;aT=av&65535}}if(!at){ap=au;gGC(ap|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=aw;c[2417276]=aA;c[1836236]=-1;fwR(1);ap=c[2439331]|0;av=(ap|0)==0;if(!av){aB=ap;gGC(9706056,aB|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];aB=c[3528485]|0;c[2076596]=aB;am=c[2417277]|0;c[3541536]=am;c[1836236]=1;c[ap+4180>>2]=640;c[ap+4184>>2]=2278;c[ap+4172>>2]=2464;c[ap+4176>>2]=3262;az=c[3529114]|0;ay=0;ax=0;while(1){c[ap+76+(ax<<2)>>2]=az+(ax<<8);aD=ay+1&65535;if((aD&65535)>127){aU=0;aV=0;break}else{ay=aD;ax=aD&65535}}while(1){ax=az+(aV<<8)|0;c[ap+76+(aV+512<<2)>>2]=ax;c[ap+76+(aV+768<<2)>>2]=ax;ax=aU+1&65535;if((ax&65535)>127){break}else{aU=ax;aV=ax&65535}}az=c[3529146]|0;c[ap+844>>2]=az;ax=az+256|0;c[ap+848>>2]=ax;ay=az+512|0;c[ap+852>>2]=ay;aA=az+768|0;c[ap+856>>2]=aA;aw=az+1024|0;c[ap+860>>2]=aw;au=az+1280|0;c[ap+864>>2]=au;at=az+1536|0;c[ap+868>>2]=at;aD=az+1792|0;c[ap+872>>2]=aD;c[ap+1868>>2]=az;c[ap+1872>>2]=ax;c[ap+1876>>2]=ay;c[ap+1880>>2]=aA;c[ap+1884>>2]=aw;c[ap+1888>>2]=au;c[ap+1892>>2]=at;c[ap+1896>>2]=aD;c[ap+2892>>2]=az;c[ap+3916>>2]=az;c[ap+2896>>2]=ax;c[ap+3920>>2]=ax;c[ap+2900>>2]=ay;c[ap+3924>>2]=ay;c[ap+2904>>2]=aA;c[ap+3928>>2]=aA;c[ap+2908>>2]=aw;c[ap+3932>>2]=aw;c[ap+2912>>2]=au;c[ap+3936>>2]=au;c[ap+2916>>2]=at;c[ap+3940>>2]=at;c[ap+2920>>2]=aD;c[ap+3944>>2]=aD;if(!av){aD=ap;gGC(aD|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=aB;c[2417277]=am;c[1836236]=-1;Vr(2,15e5,0,2870,126,0);c[2438228]=3e6;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=681;h[745419]=.1;a[3203368]=1;h[745418]=.15;a[3203360]=1;h[745417]=.15;a[3203352]=1;h[745416]=.15;a[3203344]=1;h[745415]=.1;a[3203336]=1;h[745414]=.15;a[3203328]=1;h[745413]=.15;a[3203320]=1;h[745412]=.15;a[3203312]=1;aD=c[642608+(c[2436]<<2)>>2]|0;at=c[aD+128>>2]|0;if((c[aD+52>>2]&4|0)==0){c[2113068]=at;au=c[aD+132>>2]|0;c[2113070]=au;c[2443814]=at;c[2440436]=au;aW=at;aX=au}else{c[2113070]=at;au=c[aD+132>>2]|0;c[2113068]=au;c[2440436]=at;c[2443814]=au;aW=au;aX=at}at=ag(aW<<1,aX)|0;au=gGq(at)|0;c[2112926]=au;if((au|0)!=0){gGz(au|0,0,at|0)}at=c[2439330]|0;au=(at|0)==0;if(!au){aD=at;gGC(9706056,aD|0,76)|0}aD=c[2438118]|0;c[2433530]=aD;aw=c[3528484]|0;c[2076596]=aw;aA=c[2417276]|0;c[3541536]=aA;c[1836236]=0;gGz(9706056,0,76);if(!au){au=at;gGC(au|0,9706056,76)|0}c[2438118]=aD;c[3528484]=aw;c[2417276]=aA;c[1836236]=-1;aA=c[2439331]|0;aw=(aA|0)==0;if(!aw){aD=aA;gGC(9706056,aD|0,76)|0}aD=c[2438119]|0;c[2433530]=aD;au=c[3528485]|0;c[2076596]=au;at=c[2417277]|0;c[3541536]=at;c[1836236]=1;gGz(9706056,0,76);if(!aw){aw=aA;gGC(aw|0,9706056,76)|0}c[2438119]=aD;c[3528485]=au;c[2417277]=at;c[1836236]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){at=0;do{lN(at);mB(at);at=at+1|0;}while((at|0)<(c[2385508]|0))}a[14119344]=0;a[9758216]=0;a[9759904]=0;a[9759905]=0;a[9774408]=0;a[9774409]=0;a[9774360]=0;a[9626360]=0;a[9626368]=0;a[9773592]=0;a[14124232]=0;as=0;i=e;return as|0}}while(0);c[2426786]=0;as=1;i=e;return as|0}function drQ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>37){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6338068+(b*112|0)>>2];c[a+104>>2]=c[6338072+(b*112|0)>>2];c[a+108>>2]=c[6338076+(b*112|0)>>2];d=0;return d|0}function drR(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<38&(d|0)==0)){e=1;return e|0}c[a>>2]=6337968+(b*112|0);e=0;return e|0}function drS(a){a=a|0;return(ag((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0,a)|0)/3e6|0|0}function drT(){return+(+((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)/3.0e6)}function drU(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=(a|0)==0;a=c[2443426]|0;e=c[2112926]|0;f=c[3529586]|0;g=4064;do{h=d[a+(g|1)|0]|0;i=h<<3&1792|(d[a+g|0]|0);j=h&15;k=(d[a+(g|3)|0]|0)-(h<<4&256)|0;h=d[a+(g|2)|0]|0;l=h-16|0;m=j-10|0;L95518:do{if(b){if(m>>>0>=2){break}do{if((k-1|0)>>>0<239){if((h-17|0)>>>0>=207){break}SG(e,i,k,l,j+40|0,4,0,0,f);break L95518}}while(0);SH(e,i,k,l,j+40|0,4,0,0,f)}else{if(m>>>0<=1){break}do{if((k-1|0)>>>0<239){if((h-17|0)>>>0>=207){break}SG(e,i,k,l,j+40|0,4,0,0,f);break L95518}}while(0);SH(e,i,k,l,j+40|0,4,0,0,f)}}while(0);g=g-32|0;}while((g|0)>-1);return}function drV(b){b=b|0;var c=0;switch(b&65535|0){case 49153:{c=~a[9625825];break};case 49152:{c=~a[9625824];break};case 49154:{c=~a[9625826];break};case 49155:{c=a[9658016]|0;break};case 49156:{c=a[9658017]|0;break};default:{c=0}}return c|0}function drW(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0;switch(d&65535|0){case 51211:{a[9774353]=e;return};case 51208:{a[9774400]=e;return};case 51209:{a[9774401]=e;return};case 51204:{a[9759736]=e&-128;if((e&16)==0){return}d=c[1836236]|0;f=c[9757320+(d<<2)>>2]|0;if((f|0)!=0){g=f;gGC(g|0,9706056,76)|0}c[9752472+(d<<2)>>2]=c[2433530];c[14113936+(d<<2)>>2]=c[2076596];c[9669104+(d<<2)>>2]=c[3541536];c[1836236]=-1;d=c[2439331]|0;g=(d|0)==0;if(!g){f=d;gGC(9706056,f|0,76)|0}f=c[2438119]|0;c[2433530]=f;h=c[3528485]|0;c[2076596]=h;i=c[2417277]|0;c[3541536]=i;c[1836236]=1;gGz(9706056,0,76);if(!g){g=d;gGC(g|0,9706056,76)|0}c[2438119]=f;c[3528485]=h;c[2417277]=i;c[1836236]=-1;i=c[2439330]|0;if((i|0)!=0){h=i;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;return};case 51210:{a[9774352]=e;return};case 51200:{a[9758208]=e;return};default:{return}}}function drX(b){b=b|0;var c=0;if(b<<16>>16!=24576){c=0;return c|0}a[9706117]=0;c=a[9758208]|0;return c|0}function drY(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=b&65535;if((e|0)==32770){b=c[3541518]|0;f=b+19280|0;a[b+19328|0]=d;g=d&255;if((d&255)<16){c[14168912+(((c[2383582]|0)+1|0)*252|0)>>2]=g&15}if((d-45&255)>=3){return}if((g|0)==0){a[b+19336|0]=2;h=2}else if((g|0)==46){i=b+19336|0;j=a[i]|1;a[i]=j;h=j}else if((g|0)==47){a[b+19336|0]=0;h=0}else if((g|0)==45){g=b+19336|0;j=a[g]|2;a[g]=j;h=j}else{h=a[b+19336|0]|0}b=h&3;h=c[7461744+(b<<2)>>2]|0;lI(f,h,h,c[7461728+(b<<2)>>2]|0);return}else if((e|0)==32769){lS(0,1,d);return}else if((e|0)==32768){b=c[3541518]|0;h=b+256|0;a[b+304|0]=d;f=d&255;if((d&255)<16){c[14168912+((c[2383582]|0)*252|0)>>2]=f&15}if((d-45&255)>=3){return}if((f|0)==47){a[b+312|0]=0;k=0}else if((f|0)==0){a[b+312|0]=2;k=2}else if((f|0)==45){j=b+312|0;g=a[j]|2;a[j]=g;k=g}else if((f|0)==46){f=b+312|0;g=a[f]|1;a[f]=g;k=g}else{k=a[b+312|0]|0}b=k&3;k=c[7461744+(b<<2)>>2]|0;lI(h,k,k,c[7461728+(b<<2)>>2]|0);return}else if((e|0)==32771){lS(1,1,d);return}else{return}}function drZ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7412340+(b*112|0)>>2];c[a+104>>2]=c[7412344+(b*112|0)>>2];c[a+108>>2]=c[7412348+(b*112|0)>>2];d=0;return d|0}function dr_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<22&(d|0)==0)){e=1;return e|0}c[a>>2]=7412240+(b*112|0);e=0;return e|0}function dr$(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6934832+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dr0(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>43){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7444384+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dr1(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0;e=i;i=i+2280|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;B=e+1200|0;C=e+1312|0;D=e+1320|0;E=e+1432|0;F=e+1440|0;G=e+1552|0;H=e+1560|0;I=e+1672|0;J=e+1680|0;K=e+1792|0;L=e+1800|0;M=e+1912|0;N=e+1920|0;O=e+2032|0;P=e+2040|0;Q=e+2152|0;R=e+2160|0;S=e+2272|0;c[2426784]=0;c[3529124]=0;c[2443346]=49152;c[3529112]=98304;c[3529862]=114688;c[2443500]=114944;c[3527342]=115200;c[2405692]=115456;c[3529154]=115456;c[3529144]=123136;c[2443424]=125184;c[2430218]=125568;c[2439964]=125952;c[2438816]=126976;c[2439946]=128e3;c[2438802]=129024;c[2411774]=130048;c[2406532]=130048;c[2405820]=195584;c[3529584]=457728;c[3530100]=654336;T=0;while(1){if((T|0)>=1024){break}U=9638528+(T<<2)|0;if((c[U>>2]|0)==0){V=78368;break}else{T=T+1|0}}do{if((V|0)==78368){T=gGq(655360)|0;c[U>>2]=T;if((T|0)==0){break}c[2426784]=T;gGz(T|0,0,655360);c[3529124]=T;c[2443346]=T+49152;c[3529112]=T+98304;c[3529862]=T+114688;c[2443500]=T+114944;c[3527342]=T+115200;W=T+115456|0;c[2405692]=W;c[3529154]=W;c[3529144]=T+123136;c[2443424]=T+125184;c[2430218]=T+125568;c[2439964]=T+125952;c[2438816]=T+126976;c[2439946]=T+128e3;c[2438802]=T+129024;W=T+130048|0;c[2411774]=W;c[2406532]=W;c[2405820]=T+195584;c[3529584]=T+457728;c[3530100]=T+654336;c[2414322]=T+655360;T=0;while(1){if((T|0)>=1024){X=0;break}Y=9638528+(T<<2)|0;if((c[Y>>2]|0)==0){V=78373;break}else{T=T+1|0}}do{if((V|0)==78373){T=gGq(98304)|0;c[Y>>2]=T;if((T|0)==0){X=0;break}gGz(T|0,0,98304);X=T}}while(0);c[3529534]=X;T=c[3529124]|0;if((c[3542200]|0)==0){Z=1;i=e;return Z|0}W=R+108|0;c[W>>2]=0;_=R+100|0;c[_>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](R,0)|0;do{if((c[W>>2]|0)!=0){$=c[_>>2]|0;c[S>>2]=9534384;aa=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aa&16383](S,0,0)|0;if(($|0)<1){Z=1;i=e;return Z|0}if((gzL(T,0,0)|0)==0){break}else{Z=1}i=e;return Z|0}}while(0);T=(c[3529124]|0)+32768|0;if((c[3542200]|0)==0){Z=1;i=e;return Z|0}_=P+108|0;c[_>>2]=0;W=P+100|0;c[W>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](P,1)|0;do{if((c[_>>2]|0)!=0){$=c[W>>2]|0;c[Q>>2]=9534384;aa=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aa&16383](Q,1,0)|0;if(($|0)<1){Z=1;i=e;return Z|0}if((gzL(T,0,1)|0)==0){break}else{Z=1}i=e;return Z|0}}while(0);T=c[3529124]|0;if(a[699840]|0){W=c[2443346]|0;_=0;do{$=a[T+_|0]|0;a[W+_|0]=($&255)>>>4&14|$&17|$<<4&-32;_=_+1|0;}while((_|0)<49152)}else{_=c[2443346]|0;a[_]=a[T]|0;W=1;do{$=a[T+W|0]|0;a[_+W|0]=($&255)>>>4&14|$&17|$<<4&-32;W=W+1|0;}while((W|0)<49152)}W=c[3529112]|0;if((c[3542200]|0)==0){Z=1;i=e;return Z|0}_=N+108|0;c[_>>2]=0;T=N+100|0;c[T>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](N,2)|0;do{if((c[_>>2]|0)!=0){$=c[T>>2]|0;c[O>>2]=9534384;aa=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aa&16383](O,2,0)|0;if(($|0)<1){Z=1;i=e;return Z|0}if((gzL(W,0,2)|0)==0){break}else{Z=1}i=e;return Z|0}}while(0);W=c[3529534]|0;if((c[3542200]|0)==0){Z=1;i=e;return Z|0}T=L+108|0;c[T>>2]=0;_=L+100|0;c[_>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](L,3)|0;do{if((c[T>>2]|0)!=0){$=c[_>>2]|0;c[M>>2]=9534384;aa=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aa&16383](M,3,0)|0;if(($|0)<1){Z=1;i=e;return Z|0}if((gzL(W,0,3)|0)==0){break}else{Z=1}i=e;return Z|0}}while(0);W=c[3529534]|0;_=c[2406532]|0;T=0;do{$=T<<6;gGz(_+$|0,0,64);aa=T<<7;ab=aa|4;ac=0;while(1){ad=ab+(c[6669224+(ac<<2)>>2]|0)|0;ae=(ac<<3)+$|0;af=0;do{ah=ad+(c[612480+(af<<2)>>2]|0)|0;if(((d[W+((ah|0)/8|0)|0]|0)&128>>>((ah&7)>>>0)|0)!=0){ah=_+(ae+af)|0;a[ah]=a[ah]|2}af=af+1|0;}while((af|0)<8);af=ac+1|0;if((af|0)<8){ac=af}else{ai=0;break}}do{ac=aa+(c[6669224+(ai<<2)>>2]|0)|0;ab=(ai<<3)+$|0;af=0;do{ae=ac+(c[612480+(af<<2)>>2]|0)|0;if(((d[W+((ae|0)/8|0)|0]|0)&128>>>((ae&7)>>>0)|0)!=0){ae=_+(ab+af)|0;a[ae]=a[ae]|1}af=af+1|0;}while((af|0)<8);ai=ai+1|0;}while((ai|0)<8);T=T+1|0;}while((T|0)<1024);gGz(W|0,0,98304);if((c[3542200]|0)==0){Z=1;i=e;return Z|0}T=J+108|0;c[T>>2]=0;_=J+100|0;c[_>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](J,4)|0;do{if((c[T>>2]|0)!=0){$=c[_>>2]|0;c[K>>2]=9534384;aa=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aa&16383](K,4,0)|0;if(($|0)<1){Z=1;i=e;return Z|0}if((gzL(W,0,4)|0)==0){break}else{Z=1}i=e;return Z|0}}while(0);W=(c[3529534]|0)+16384|0;if((c[3542200]|0)==0){Z=1;i=e;return Z|0}_=H+108|0;c[_>>2]=0;T=H+100|0;c[T>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](H,5)|0;do{if((c[_>>2]|0)!=0){$=c[T>>2]|0;c[I>>2]=9534384;aa=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aa&16383](I,5,0)|0;if(($|0)<1){Z=1;i=e;return Z|0}if((gzL(W,0,5)|0)==0){break}else{Z=1}i=e;return Z|0}}while(0);W=(c[3529534]|0)+32768|0;if((c[3542200]|0)==0){Z=1;i=e;return Z|0}T=F+108|0;c[T>>2]=0;_=F+100|0;c[_>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](F,6)|0;do{if((c[T>>2]|0)!=0){$=c[_>>2]|0;c[G>>2]=9534384;aa=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aa&16383](G,6,0)|0;if(($|0)<1){Z=1;i=e;return Z|0}if((gzL(W,0,6)|0)==0){break}else{Z=1}i=e;return Z|0}}while(0);W=(c[3529534]|0)+49152|0;if((c[3542200]|0)==0){Z=1;i=e;return Z|0}_=D+108|0;c[_>>2]=0;T=D+100|0;c[T>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](D,7)|0;do{if((c[_>>2]|0)!=0){$=c[T>>2]|0;c[E>>2]=9534384;aa=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aa&16383](E,7,0)|0;if(($|0)<1){Z=1;i=e;return Z|0}if((gzL(W,0,7)|0)==0){break}else{Z=1}i=e;return Z|0}}while(0);W=(c[3529534]|0)+65536|0;if((c[3542200]|0)==0){Z=1;i=e;return Z|0}T=B+108|0;c[T>>2]=0;_=B+100|0;c[_>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](B,8)|0;do{if((c[T>>2]|0)!=0){$=c[_>>2]|0;c[C>>2]=9534384;aa=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aa&16383](C,8,0)|0;if(($|0)<1){Z=1;i=e;return Z|0}if((gzL(W,0,8)|0)==0){break}else{Z=1}i=e;return Z|0}}while(0);W=(c[3529534]|0)+81920|0;if((c[3542200]|0)==0){Z=1;i=e;return Z|0}_=z+108|0;c[_>>2]=0;T=z+100|0;c[T>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,9)|0;do{if((c[_>>2]|0)!=0){$=c[T>>2]|0;c[A>>2]=9534384;aa=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aa&16383](A,9,0)|0;if(($|0)<1){Z=1;i=e;return Z|0}if((gzL(W,0,9)|0)==0){break}else{Z=1}i=e;return Z|0}}while(0);W=c[3529534]|0;T=c[2405820]|0;_=0;do{$=_<<8;gGz(T+$|0,0,256);aa=0;do{af=$+(c[609008+(aa<<2)>>2]|0)|0;ab=(aa<<4)+$|0;ac=0;do{ae=af+(c[597864+(ac<<2)>>2]|0)|0;if(((d[W+((ae|0)/8|0)|0]|0)&128>>>((ae&7)>>>0)|0)!=0){ae=T+(ab+ac)|0;a[ae]=a[ae]|4}ac=ac+1|0;}while((ac|0)<16);aa=aa+1|0;}while((aa|0)<16);aa=$+262144|0;ac=0;do{ab=aa+(c[609008+(ac<<2)>>2]|0)|0;af=(ac<<4)+$|0;ae=0;do{ad=ab+(c[597864+(ae<<2)>>2]|0)|0;if(((d[W+((ad|0)/8|0)|0]|0)&128>>>((ad&7)>>>0)|0)!=0){ad=T+(af+ae)|0;a[ad]=a[ad]|2}ae=ae+1|0;}while((ae|0)<16);ac=ac+1|0;}while((ac|0)<16);ac=$+524288|0;aa=0;do{ae=ac+(c[609008+(aa<<2)>>2]|0)|0;af=(aa<<4)+$|0;ab=0;do{ad=ae+(c[597864+(ab<<2)>>2]|0)|0;if(((d[W+((ad|0)/8|0)|0]|0)&128>>>((ad&7)>>>0)|0)!=0){ad=T+(af+ab)|0;a[ad]=a[ad]|1}ab=ab+1|0;}while((ab|0)<16);aa=aa+1|0;}while((aa|0)<16);_=_+1|0;}while((_|0)<1024);gGz(W|0,0,98304);if((c[3542200]|0)==0){Z=1;i=e;return Z|0}_=x+108|0;c[_>>2]=0;T=x+100|0;c[T>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,10)|0;do{if((c[_>>2]|0)!=0){aa=c[T>>2]|0;c[y>>2]=9534384;$=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[$&16383](y,10,0)|0;if((aa|0)<1){Z=1;i=e;return Z|0}if((gzL(W,0,10)|0)==0){break}else{Z=1}i=e;return Z|0}}while(0);W=(c[3529534]|0)+16384|0;if((c[3542200]|0)==0){Z=1;i=e;return Z|0}T=v+108|0;c[T>>2]=0;_=v+100|0;c[_>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,11)|0;do{if((c[T>>2]|0)!=0){aa=c[_>>2]|0;c[w>>2]=9534384;$=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[$&16383](w,11,0)|0;if((aa|0)<1){Z=1;i=e;return Z|0}if((gzL(W,0,11)|0)==0){break}else{Z=1}i=e;return Z|0}}while(0);W=(c[3529534]|0)+32768|0;if((c[3542200]|0)==0){Z=1;i=e;return Z|0}_=t+108|0;c[_>>2]=0;T=t+100|0;c[T>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,12)|0;do{if((c[_>>2]|0)!=0){aa=c[T>>2]|0;c[u>>2]=9534384;$=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[$&16383](u,12,0)|0;if((aa|0)<1){Z=1;i=e;return Z|0}if((gzL(W,0,12)|0)==0){break}else{Z=1}i=e;return Z|0}}while(0);W=(c[3529534]|0)+49152|0;if((c[3542200]|0)==0){Z=1;i=e;return Z|0}T=r+108|0;c[T>>2]=0;_=r+100|0;c[_>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,13)|0;do{if((c[T>>2]|0)!=0){aa=c[_>>2]|0;c[s>>2]=9534384;$=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[$&16383](s,13,0)|0;if((aa|0)<1){Z=1;i=e;return Z|0}if((gzL(W,0,13)|0)==0){break}else{Z=1}i=e;return Z|0}}while(0);W=(c[3529534]|0)+65536|0;if((c[3542200]|0)==0){Z=1;i=e;return Z|0}_=p+108|0;c[_>>2]=0;T=p+100|0;c[T>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,14)|0;do{if((c[_>>2]|0)!=0){aa=c[T>>2]|0;c[q>>2]=9534384;$=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[$&16383](q,14,0)|0;if((aa|0)<1){Z=1;i=e;return Z|0}if((gzL(W,0,14)|0)==0){break}else{Z=1}i=e;return Z|0}}while(0);W=(c[3529534]|0)+81920|0;if((c[3542200]|0)==0){Z=1;i=e;return Z|0}T=n+108|0;c[T>>2]=0;_=n+100|0;c[_>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,15)|0;do{if((c[T>>2]|0)!=0){aa=c[_>>2]|0;c[o>>2]=9534384;$=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[$&16383](o,15,0)|0;if((aa|0)<1){Z=1;i=e;return Z|0}if((gzL(W,0,15)|0)==0){break}else{Z=1}i=e;return Z|0}}while(0);W=c[3529534]|0;_=c[3529584]|0;T=0;do{aa=T<<8;gGz(_+aa|0,0,256);$=T<<9;ac=0;do{ab=1<<3-ac;af=(c[961504+(ac<<2)>>2]|0)+$|0;ae=0;do{ad=af+(c[608544+(ae<<2)>>2]|0)|0;ah=(ae<<4)+aa|0;aj=0;do{ak=ad+(c[609552+(aj<<2)>>2]|0)|0;if(((d[W+((ak|0)/8|0)|0]|0)&128>>>((ak&7)>>>0)|0)!=0){ak=_+(ah+aj)|0;a[ak]=(d[ak]|0|ab)&255}aj=aj+1|0;}while((aj|0)<16);ae=ae+1|0;}while((ae|0)<16);ac=ac+1|0;}while((ac|0)<4);T=T+1|0;}while((T|0)<768);T=c[3529862]|0;if((c[3542200]|0)==0){Z=1;i=e;return Z|0}_=l+108|0;c[_>>2]=0;W=l+100|0;c[W>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,16)|0;do{if((c[_>>2]|0)!=0){ac=c[W>>2]|0;c[m>>2]=9534384;aa=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aa&16383](m,16,0)|0;if((ac|0)<1){Z=1;i=e;return Z|0}if((gzL(T,0,16)|0)==0){break}else{Z=1}i=e;return Z|0}}while(0);T=c[2443500]|0;if((c[3542200]|0)==0){Z=1;i=e;return Z|0}W=j+108|0;c[W>>2]=0;_=j+100|0;c[_>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,17)|0;do{if((c[W>>2]|0)!=0){ac=c[_>>2]|0;c[k>>2]=9534384;aa=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aa&16383](k,17,0)|0;if((ac|0)<1){Z=1;i=e;return Z|0}if((gzL(T,0,17)|0)==0){break}else{Z=1}i=e;return Z|0}}while(0);T=c[3527342]|0;if((c[3542200]|0)==0){Z=1;i=e;return Z|0}_=f+108|0;c[_>>2]=0;W=f+100|0;c[W>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,18)|0;do{if((c[_>>2]|0)!=0){ac=c[W>>2]|0;c[g>>2]=9534384;aa=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aa&16383](g,18,0)|0;if((ac|0)<1){Z=1;i=e;return Z|0}if((gzL(T,0,18)|0)==0){break}else{Z=1}i=e;return Z|0}}while(0);T=c[3529534]|0;W=0;while(1){if((W|0)>=1024){break}al=9638528+(W<<2)|0;if((c[al>>2]|0)==(T|0)){V=78484;break}else{W=W+1|0}}if((V|0)==78484){gGr(T);c[al>>2]=0}c[3529534]=0;fwR(0);W=c[2439330]|0;_=(W|0)==0;if(!_){ac=W;gGC(9706056,ac|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];ac=c[3528484]|0;c[2076596]=ac;aa=c[2417276]|0;c[3541536]=aa;c[1836236]=0;c[W+4180>>2]=982;c[W+4184>>2]=1942;$=c[3529124]|0;ae=0;ab=0;while(1){c[W+76+(ab<<2)>>2]=$+(ab<<8);af=ae+1&65535;if((af&65535)>191){break}else{ae=af;ab=af&65535}}ab=c[2443346]|0;ae=0;T=0;while(1){af=T<<8;c[W+76+(T+512<<2)>>2]=ab+af;c[W+76+(T+768<<2)>>2]=$+af;af=ae+1&65535;if((af&65535)>191){break}else{ae=af;T=af&65535}}T=c[2439946]|0;c[W+908>>2]=T;ae=T+256|0;c[W+912>>2]=ae;$=T+512|0;c[W+916>>2]=$;ab=T+768|0;c[W+920>>2]=ab;c[W+1932>>2]=T;c[W+1936>>2]=ae;c[W+1940>>2]=$;c[W+1944>>2]=ab;c[W+2956>>2]=T;c[W+3980>>2]=T;c[W+2960>>2]=ae;c[W+3984>>2]=ae;c[W+2964>>2]=$;c[W+3988>>2]=$;c[W+2968>>2]=ab;c[W+3992>>2]=ab;ab=c[2438802]|0;c[W+924>>2]=ab;$=ab+256|0;c[W+928>>2]=$;ae=ab+512|0;c[W+932>>2]=ae;T=ab+768|0;c[W+936>>2]=T;c[W+1948>>2]=ab;c[W+1952>>2]=$;c[W+1956>>2]=ae;c[W+1960>>2]=T;c[W+2972>>2]=ab;c[W+3996>>2]=ab;c[W+2976>>2]=$;c[W+4e3>>2]=$;c[W+2980>>2]=ae;c[W+4004>>2]=ae;c[W+2984>>2]=T;c[W+4008>>2]=T;T=c[2439964]|0;c[W+940>>2]=T;ae=T+256|0;c[W+944>>2]=ae;$=T+512|0;c[W+948>>2]=$;ab=T+768|0;c[W+952>>2]=ab;c[W+1964>>2]=T;c[W+1968>>2]=ae;c[W+1972>>2]=$;c[W+1976>>2]=ab;c[W+2988>>2]=T;c[W+4012>>2]=T;c[W+2992>>2]=ae;c[W+4016>>2]=ae;c[W+2996>>2]=$;c[W+4020>>2]=$;c[W+3e3>>2]=ab;c[W+4024>>2]=ab;ab=c[2438816]|0;c[W+956>>2]=ab;$=ab+256|0;c[W+960>>2]=$;ae=ab+512|0;c[W+964>>2]=ae;T=ab+768|0;c[W+968>>2]=T;c[W+1980>>2]=ab;c[W+1984>>2]=$;c[W+1988>>2]=ae;c[W+1992>>2]=T;c[W+3004>>2]=ab;c[W+4028>>2]=ab;c[W+3008>>2]=$;c[W+4032>>2]=$;c[W+3012>>2]=ae;c[W+4036>>2]=ae;c[W+3016>>2]=T;c[W+4040>>2]=T;T=c[3529154]|0;ae=224;$=224;while(1){c[W+76+($<<2)>>2]=T+(($<<8)-57344);ab=ae+1&65535;if((ab&65535)>253){am=224;an=224;break}else{ae=ab;$=ab&65535}}while(1){c[W+76+(an+256<<2)>>2]=T+((an<<8)-57344);$=am+1&65535;if(($&65535)>253){ao=224;ap=224;break}else{am=$;an=$&65535}}while(1){$=T+((ap<<8)-57344)|0;c[W+76+(ap+512<<2)>>2]=$;c[W+76+(ap+768<<2)>>2]=$;$=ao+1&65535;if(($&65535)>253){break}else{ao=$;ap=$&65535}}T=c[2443424]|0;c[W+1092>>2]=T;$=T+256|0;c[W+1096>>2]=$;c[W+2116>>2]=T;c[W+2120>>2]=$;c[W+3140>>2]=T;c[W+4164>>2]=T;c[W+3144>>2]=$;c[W+4168>>2]=$;if(!_){$=W;gGC($|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=ac;c[2417276]=aa;c[1836236]=-1;fwR(1);$=c[2439331]|0;T=($|0)==0;if(!T){ae=$;gGC(9706056,ae|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];ae=c[3528485]|0;c[2076596]=ae;ab=c[2417277]|0;c[3541536]=ab;c[1836236]=1;c[$+4180>>2]=562;c[$+4184>>2]=728;af=c[3529112]|0;aj=0;ah=0;while(1){c[$+76+(ah<<2)>>2]=af+(ah<<8);ad=aj+1&65535;if((ad&65535)>63){aq=0;ar=0;break}else{aj=ad;ah=ad&65535}}while(1){ah=af+(ar<<8)|0;c[$+76+(ar+512<<2)>>2]=ah;c[$+76+(ar+768<<2)>>2]=ah;ah=aq+1&65535;if((ah&65535)>63){break}else{aq=ah;ar=ah&65535}}af=c[3529144]|0;c[$+332>>2]=af;ah=af+256|0;c[$+336>>2]=ah;aj=af+512|0;c[$+340>>2]=aj;aa=af+768|0;c[$+344>>2]=aa;ac=af+1024|0;c[$+348>>2]=ac;W=af+1280|0;c[$+352>>2]=W;_=af+1536|0;c[$+356>>2]=_;ad=af+1792|0;c[$+360>>2]=ad;c[$+1356>>2]=af;c[$+1360>>2]=ah;c[$+1364>>2]=aj;c[$+1368>>2]=aa;c[$+1372>>2]=ac;c[$+1376>>2]=W;c[$+1380>>2]=_;c[$+1384>>2]=ad;c[$+2380>>2]=af;c[$+3404>>2]=af;c[$+2384>>2]=ah;c[$+3408>>2]=ah;c[$+2388>>2]=aj;c[$+3412>>2]=aj;c[$+2392>>2]=aa;c[$+3416>>2]=aa;c[$+2396>>2]=ac;c[$+3420>>2]=ac;c[$+2400>>2]=W;c[$+3424>>2]=W;c[$+2404>>2]=_;c[$+3428>>2]=_;c[$+2408>>2]=ad;c[$+3432>>2]=ad;if(!T){ad=$;gGC(ad|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=ae;c[2417277]=ab;c[1836236]=-1;Vr(2,15e5,0,2574,46,0);c[2438228]=3e6;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=681;h[745419]=.15;a[3203368]=1;h[745418]=.15;a[3203360]=1;h[745417]=.15;a[3203352]=1;h[745416]=.15;a[3203344]=1;h[745415]=.15;a[3203336]=1;h[745414]=.15;a[3203328]=1;h[745413]=.15;a[3203320]=1;h[745412]=.15;a[3203312]=1;ad=c[642608+(c[2436]<<2)>>2]|0;_=c[ad+128>>2]|0;if((c[ad+52>>2]&4|0)==0){c[2113068]=_;W=c[ad+132>>2]|0;c[2113070]=W;c[2443814]=_;c[2440436]=W;as=_;at=W}else{c[2113070]=_;W=c[ad+132>>2]|0;c[2113068]=W;c[2440436]=_;c[2443814]=W;as=W;at=_}_=ag(as<<1,at)|0;W=gGq(_)|0;c[2112926]=W;if((W|0)!=0){gGz(W|0,0,_|0)}_=c[2439330]|0;W=(_|0)==0;if(!W){ad=_;gGC(9706056,ad|0,76)|0}ad=c[2438118]|0;c[2433530]=ad;ac=c[3528484]|0;c[2076596]=ac;aa=c[2417276]|0;c[3541536]=aa;c[1836236]=0;gGz(9706056,0,76);if(!W){W=_;gGC(W|0,9706056,76)|0}c[2438118]=ad;c[3528484]=ac;c[2417276]=aa;c[1836236]=-1;aa=c[2439331]|0;ac=(aa|0)==0;if(!ac){ad=aa;gGC(9706056,ad|0,76)|0}ad=c[2438119]|0;c[2433530]=ad;W=c[3528485]|0;c[2076596]=W;_=c[2417277]|0;c[3541536]=_;c[1836236]=1;gGz(9706056,0,76);if(!ac){ac=aa;gGC(ac|0,9706056,76)|0}c[2438119]=ad;c[3528485]=W;c[2417277]=_;c[1836236]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){_=0;do{lN(_);mB(_);_=_+1|0;}while((_|0)<(c[2385508]|0))}a[9774401]=0;a[9774400]=0;a[9774353]=0;a[9774352]=0;a[9759736]=0;a[9758208]=0;Z=0;i=e;return Z|0}}while(0);c[2426784]=0;Z=1;i=e;return Z|0}function dr2(){var b=0,d=0,e=0,f=0;fwZ();b=c[3541518]|0;if((b|0)!=0){gGr(b|0);c[3541518]=0}if((c[2385508]|0)>0){c[2113008]=0;c[2076598]=0;c[2383582]=0}c[2438228]=0;c[2433526]=0;c[2406676]=0;c[3528472]=0;b=c[2406680]|0;if((b|0)!=0){gGr(b);c[2406680]=0}c[2385508]=0;c[2432978]=0;a[64240]=0;c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}b=c[2426784]|0;d=0;while(1){if((d|0)>=1024){e=78611;break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==(b|0)){break}else{d=d+1|0}}if((e|0)==78611){c[2426784]=0;a[9774401]=0;a[9774400]=0;a[9774353]=0;a[9774352]=0;a[9759736]=0;a[9758208]=0;a[699840]=0;return 0}gGr(b);c[f>>2]=0;c[2426784]=0;a[9774401]=0;a[9774400]=0;a[9774353]=0;a[9774352]=0;a[9759736]=0;a[9758208]=0;a[699840]=0;return 0}function dr3(){var e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,L=0;if((a[9624672]|0)!=0){e=c[2439330]|0;f=(e|0)==0;if(!f){g=e;gGC(9706056,g|0,76)|0}g=c[2438118]|0;c[2433530]=g;i=c[3528484]|0;c[2076596]=i;j=c[2417276]|0;c[3541536]=j;c[1836236]=0;gGz(9706056,0,76);if(!f){f=e;gGC(f|0,9706056,76)|0}c[2438118]=g;c[3528484]=i;c[2417276]=j;c[1836236]=-1;j=c[2439331]|0;i=(j|0)==0;if(!i){g=j;gGC(9706056,g|0,76)|0}g=c[2438119]|0;c[2433530]=g;f=c[3528485]|0;c[2076596]=f;e=c[2417277]|0;c[3541536]=e;c[1836236]=1;gGz(9706056,0,76);if(!i){i=j;gGC(i|0,9706056,76)|0}c[2438119]=g;c[3528485]=f;c[2417277]=e;c[1836236]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){e=0;do{lN(e);mB(e);e=e+1|0;}while((e|0)<(c[2385508]|0))}a[9774401]=0;a[9774400]=0;a[9774353]=0;a[9774352]=0;a[9759736]=0;a[9758208]=0}a[9625826]=0;a[9625825]=0;a[9625824]=0;e=0;f=0;g=0;i=0;do{f=((a[9759232+e|0]&1)<<e|f&255)&255;g=((a[9759040+e|0]&1)<<e|g&255)&255;i=((a[9758856+e|0]&1)<<e|i&255)&255;e=e+1|0;}while((e|0)<8);a[9625824]=f;a[9625825]=g;a[9625826]=i;if((g&3)==3){f=g&-4;a[9625825]=f;k=f}else{k=g}if((k&12)==12){a[9625825]=k&-13}if((i&3)==3){k=i&-4;a[9625826]=k;l=k}else{l=i}if((l&12)==12){a[9625826]=l&-13}a[6518296]=1;a[6518120]=1;c[2444103]=0;c[2444102]=0;l=0;i=0;L96036:while(1){k=i;while(1){if((k|0)>=25){break L96036}g=c[2439330]|0;if((g|0)!=0){f=g;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;f=c[2438118]|0;c[2433530]=f;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;m=k+1|0;e=(ag(a[6518296]|0?66666:0,m)|0)/25|0;j=c[2444102]|0;n=e-j|0;c[2438196]=n;do{if((n|0)<1){o=0;p=j}else{if((a[g+4188|0]|0)==0){e=gfc(n)|0;c[2433530]=(c[2433530]|0)+e;o=e;p=c[2444102]|0;break}else{c[2433530]=f+n;o=n;p=j;break}}}while(0);c[2444102]=p+o;if((k|0)==24){a[14125144]=-41;a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0}j=c[1836236]|0;n=c[9757320+(j<<2)>>2]|0;if((n|0)!=0){f=n;gGC(f|0,9706056,76)|0}c[9752472+(j<<2)>>2]=c[2433530];c[14113936+(j<<2)>>2]=c[2076596];c[9669104+(j<<2)>>2]=c[3541536];c[1836236]=-1;j=c[2439331]|0;if((j|0)!=0){f=j;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;f=c[2438119]|0;c[2433530]=f;c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;n=(ag(a[6518120]|0?5e4:0,m)|0)/25|0;g=c[2444103]|0;e=n-g|0;c[2438196]=e;do{if((e|0)<1){q=0;r=g;s=f}else{if((a[j+4188|0]|0)==0){n=gfc(e)|0;t=(c[2433530]|0)+n|0;c[2433530]=t;q=n;r=c[2444103]|0;s=t;break}else{t=f+e|0;c[2433530]=t;q=e;r=g;s=t;break}}}while(0);c[2438196]=q;c[2444103]=r+q;if((k|0)==20|(k|0)==15|(k|0)==10|(k|0)==5){a[9706117]=1}g=c[1836236]|0;e=c[9757320+(g<<2)>>2]|0;if((e|0)!=0){f=e;gGC(f|0,9706056,76)|0}c[9752472+(g<<2)>>2]=s;c[14113936+(g<<2)>>2]=c[2076596];c[9669104+(g<<2)>>2]=c[3541536];c[1836236]=-1;u=c[2112964]|0;if((u|0)==0){k=m}else{break}}k=a[9688]|0?534:0;g=c[2439331]|0;if((g|0)!=0){f=g;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;gg[c[3542122]&4095](u+(l<<1<<1)|0,k-l|0);f=c[1836236]|0;g=c[9757320+(f<<2)>>2]|0;if((g|0)!=0){e=g;gGC(e|0,9706056,76)|0}c[9752472+(f<<2)>>2]=c[2433530];c[14113936+(f<<2)>>2]=c[2076596];c[9669104+(f<<2)>>2]=c[3541536];c[1836236]=-1;l=k;i=m}m=c[2112964]|0;do{if((m|0)!=0){i=a[9688]|0?534:0;if((i|0)==(l|0)){break}u=c[2439331]|0;if((u|0)!=0){s=u;gGC(9706056,s|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;gg[c[3542122]&4095](m+(l<<1<<1)|0,i-l|0);i=c[1836236]|0;s=c[9757320+(i<<2)>>2]|0;if((s|0)!=0){u=s;gGC(u|0,9706056,76)|0}c[9752472+(i<<2)>>2]=c[2433530];c[14113936+(i<<2)>>2]=c[2076596];c[9669104+(i<<2)>>2]=c[3541536];c[1836236]=-1}}while(0);l=c[2439331]|0;if((l|0)!=0){m=l;gGC(9706056,m|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;m=(a[6518120]|0?5e4:0)-(c[2444103]|0)|0;l=gGU(m,(m|0)<0|0?-1:0,2048e6,0)|0;i=c[2438228]|0;u=gGS(l,K,i,(i|0)<0|0?-1:0)|0;i=u;Sb(m);m=c[2443830]|0;if((m|0)<1073676288){c[2443830]=m-i}m=c[2443831]|0;if((m|0)<1073676288){c[2443831]=m-i}m=(c[3528512]|0)-i|0;c[3528512]=(m|0)<0?0:m;m=c[1836236]|0;i=c[9757320+(m<<2)>>2]|0;if((i|0)!=0){u=i;gGC(u|0,9706056,76)|0}c[9752472+(m<<2)>>2]=c[2433530];c[14113936+(m<<2)>>2]=c[2076596];c[9669104+(m<<2)>>2]=c[3541536];c[1836236]=-1;if((c[2112968]|0)==0){v=c[2430218]|0;w=c[2443424]|0;gGC(v|0,w|0,384)|0;return 0}m=c[2112926]|0;gGz(m|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);u=c[3529862]|0;i=c[2443500]|0;l=c[3527342]|0;s=c[3530100]|0;q=0;do{r=d[u+q|0]|0;o=d[i+q|0]|0;p=d[l+q|0]|0;c[s+(q<<2)>>2]=(-(o>>>1&1)&31)+(-(o&1)&14)+(-(o>>>2&1)&67)+(-(o>>>3&1)&143)<<3&2016|(-(r>>>1&1)&31)+(-(r&1)&14)+(-(r>>>2&1)&67)+(-(r>>>3&1)&143)<<8&63488|((-(p>>>1&1)&31)+(-(p&1)&14)+(-(p>>>2&1)&67)+(-(p>>>3&1)&143)|0)>>>3&31;q=q+1|0;}while((q|0)<256);q=d[9774401]<<8&768|d[9774400];l=-16-(d[9774353]<<8&768|d[9774352])|0;i=c[2438816]|0;u=c[2439964]|0;p=c[2405820]|0;r=0;do{o=(r<<4)+l|0;k=(o|0)<-16?o+512|0:o;o=208-k|0;f=0;do{e=(f<<5)+r|0;g=d[i+e|0]|0;j=d[u+e|0]|g<<2&768;e=g&15;t=g>>>4&1;n=g>>>5&1;g=(f<<4)-q|0;x=(g|0)<-16?g+512|0:g;if((a[9759736]|0)==0){y=n;z=t;A=k;B=x}else{y=n^1;z=t^1;A=o;B=240-x|0}do{if((B-1|0)>>>0<239){if((A-1|0)>>>0>=207){C=78696;break}x=(y|0)!=0;if((z|0)==0){if(x){SC(m,j,B,A,e,3,0,p);break}else{Sy(m,j,B,A,e,3,0,p);break}}else{if(x){SE(m,j,B,A,e,3,0,p);break}else{SA(m,j,B,A,e,3,0,p);break}}}else{C=78696}}while(0);do{if((C|0)==78696){C=0;x=(y|0)!=0;if((z|0)==0){if(x){SD(m,j,B,A,e,3,0,p);break}else{Sz(m,j,B,A,e,3,0,p);break}}else{if(x){SF(m,j,B,A,e,3,0,p);break}else{SB(m,j,B,A,e,3,0,p);break}}}}while(0);f=f+1|0;}while((f|0)<32);r=r+1|0;}while((r|0)<32);r=c[2430218]|0;p=c[3529584]|0;A=380;do{B=d[r+(A|1)|0]|0;z=B>>>6;y=z<<8|d[r+A|0];q=B>>>4&3;u=B&4;i=B&8;l=(d[r+(A|3)|0]|0)-(B<<8&256)|0;B=d[r+(A|2)|0]|0;if((a[9759736]|0)==0){D=B-16|0;E=l;F=i;G=u}else{D=224-B|0;E=240-l|0;F=i>>>3^1;G=u>>>2^1}L96146:do{if((z|0)!=3){do{if((E-1|0)>>>0<239){if((D-1|0)>>>0>=207){break}u=(F|0)!=0;if((G|0)==0){if(u){SK(m,y,E,D,q,4,15,128,p);break L96146}else{SG(m,y,E,D,q,4,15,128,p);break L96146}}else{if(u){SM(m,y,E,D,q,4,15,128,p);break L96146}else{SI(m,y,E,D,q,4,15,128,p);break L96146}}}}while(0);u=(F|0)!=0;if((G|0)==0){if(u){SL(m,y,E,D,q,4,15,128,p);break}else{SH(m,y,E,D,q,4,15,128,p);break}}else{if(u){SN(m,y,E,D,q,4,15,128,p);break}else{SJ(m,y,E,D,q,4,15,128,p);break}}}}while(0);A=A-4|0;}while((A|0)>-1);A=c[2438802]|0;p=c[2439946]|0;D=c[2406532]|0;E=0;G=0;while(1){F=E<<3;q=F-16|0;y=232-F|0;F=G;z=0;while(1){u=d[A+F|0]|0;i=d[p+F|0]|u<<2&768;l=u&15;B=u>>>4&1;f=u>>>5&1;u=z<<3;if((a[9759736]|0)==0){H=f;I=B;J=q;L=u}else{H=f^1;I=B^1;J=y;L=248-u|0}do{if((L-1|0)>>>0<247){if((J-1|0)>>>0>=215){C=78739;break}u=(H|0)!=0;if((I|0)==0){if(u){Su(m,i,L,J,l,2,3,192,D);break}else{Sq(m,i,L,J,l,2,3,192,D);break}}else{if(u){Sw(m,i,L,J,l,2,3,192,D);break}else{Ss(m,i,L,J,l,2,3,192,D);break}}}else{C=78739}}while(0);do{if((C|0)==78739){C=0;u=(H|0)!=0;if((I|0)==0){if(u){Sv(m,i,L,J,l,2,3,192,D);break}else{Sr(m,i,L,J,l,2,3,192,D);break}}else{if(u){Sx(m,i,L,J,l,2,3,192,D);break}else{St(m,i,L,J,l,2,3,192,D);break}}}}while(0);l=z+1|0;if((l|0)>=32){break}F=F+1|0;z=l}z=E+1|0;if((z|0)<32){E=z;G=G+32|0}else{break}}R8(s);v=r;w=c[2443424]|0;gGC(v|0,w|0,384)|0;return 0}function dr4(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;d=i;i=i+144|0;e=d|0;f=d+16|0;g=d+32|0;h=d+48|0;j=d+64|0;k=d+80|0;l=d+96|0;m=d+112|0;n=d+128|0;if((b|0)!=0){c[b>>2]=169619}if((a&32|0)!=0){gGz(n|0,0,12);o=c[2405692]|0;c[n>>2]=o;c[n+4>>2]=(c[2411774]|0)-o;c[n+12>>2]=162152;o=c[2076592]|0;gj[o&4095](n)|0}if((a&64|0)==0){i=d;return 0}fw$(a);Vx(a,b);gGz(m|0,0,12);c[m>>2]=9776408;c[m+4>>2]=8;c[m+12>>2]=212472;gj[c[2076592]&4095](m)|0;gGz(l|0,0,12);c[l>>2]=9752784;c[l+4>>2]=4;c[l+12>>2]=436576;gj[c[2076592]&4095](l)|0;gGz(k|0,0,12);c[k>>2]=9758208;c[k+4>>2]=1;c[k+12>>2]=497064;gj[c[2076592]&4095](k)|0;gGz(j|0,0,12);c[j>>2]=9774400;c[j+4>>2]=2;c[j+12>>2]=169648;gj[c[2076592]&4095](j)|0;gGz(h|0,0,12);c[h>>2]=9774352;c[h+4>>2]=2;c[h+12>>2]=166776;gj[c[2076592]&4095](h)|0;gGz(g|0,0,12);c[g>>2]=9759736;c[g+4>>2]=1;c[g+12>>2]=503888;gj[c[2076592]&4095](g)|0;gGz(f|0,0,12);c[f>>2]=9658016;c[f+4>>2]=2;c[f+12>>2]=483352;gj[c[2076592]&4095](f)|0;gGz(e|0,0,12);c[e>>2]=9625824;c[e+4>>2]=3;c[e+12>>2]=215728;gj[c[2076592]&4095](e)|0;i=d;return 0}function dr5(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7223924+(b*112|0)>>2];c[a+104>>2]=c[7223928+(b*112|0)>>2];c[a+108>>2]=c[7223932+(b*112|0)>>2];d=0;return d|0}function dr6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<22&(d|0)==0)){e=1;return e|0}c[a>>2]=7223824+(b*112|0);e=0;return e|0}function dr7(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7253828+(b*112|0)>>2];c[a+104>>2]=c[7253832+(b*112|0)>>2];c[a+108>>2]=c[7253836+(b*112|0)>>2];d=0;return d|0}function dr8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<22&(d|0)==0)){e=1;return e|0}c[a>>2]=7253728+(b*112|0);e=0;return e|0}function dr9(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7280572+(b*112|0)>>2];c[a+104>>2]=c[7280576+(b*112|0)>>2];c[a+108>>2]=c[7280580+(b*112|0)>>2];d=0;return d|0}function dsa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=7280472+(b*112|0);e=0;return e|0}function dsb(){a[699840]=1;return dr1()|0}function dsc(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6913684+(b*112|0)>>2];c[a+104>>2]=c[6913688+(b*112|0)>>2];c[a+108>>2]=c[6913692+(b*112|0)>>2];d=0;return d|0}function dsd(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=6913584+(b*112|0);e=0;return e|0}function dse(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4990876+(b*112|0)>>2];c[a+104>>2]=c[4990880+(b*112|0)>>2];c[a+108>>2]=c[4990884+(b*112|0)>>2];d=0;return d|0}function dsf(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<22&(d|0)==0)){e=1;return e|0}c[a>>2]=4990776+(b*112|0);e=0;return e|0}function dsg(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3443596+(b*112|0)>>2];c[a+104>>2]=c[3443600+(b*112|0)>>2];c[a+108>>2]=c[3443604+(b*112|0)>>2];d=0;return d|0}function dsh(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<22&(d|0)==0)){e=1;return e|0}c[a>>2]=3443496+(b*112|0);e=0;return e|0}function dsi(a){a=a|0;return(ag((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0,a)|0)/3e6|0|0}function dsj(){return+(+((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)/3.0e6)}function dsk(a,d){a=a|0;d=d|0;if((a&268435200|0)==139264){b[(c[2406304]|0)+(a&254)>>1]=d|-16;return}if((a|0)!=16756736|d<<16>>16==0){return}dsl();return}function dsl(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;c[3528176]=0;b=c[2440178]|0;c[2077636]=b;c[b+8>>2]=-1;b=0;while(1){e=b<<1;f=e+16744448|0;g=c[2112932]|0;h=c[g+(f>>>10<<2)>>2]|0;if(h>>>0>9){i=f&1022;j=(d[h+(i|1)|0]|0)<<8|(d[h+i|0]|0);k=g}else{i=gj[c[g+196688+(h<<2)>>2]&4095](f)|0;j=i;k=c[2112932]|0}i=j&65535;f=e+16748544|0;h=c[k+(f>>>10<<2)>>2]|0;if(h>>>0>9){g=f&1022;l=(d[h+(g|1)|0]|0)<<8|(d[h+g|0]|0);m=k}else{g=gj[c[k+196688+(h<<2)>>2]&4095](f)|0;l=g;m=c[2112932]|0}g=l&65535;f=e+16752640|0;e=c[m+(f>>>10<<2)>>2]|0;if(e>>>0>9){h=f&1022;n=(d[e+(h|1)|0]|0)<<8|(d[e+h|0]|0)}else{n=gj[c[m+196688+(e<<2)>>2]&4095](f)|0}f=n&65535;e=(g&512|0)==0?g&1023:g|-1024;g=(f&512|0)==0?f&1023:f|-1024;if((i&16384|0)!=0){o=78902;break}L96324:do{if((i&8192|0)==0){f=i>>>1&2047;h=(a[642552]|0?25165824:0)-(g<<16)|0;p=c[2077636]|0;c[p>>2]=(a[642560]|0?33554432:0)+(e<<16)>>16;c[p+4>>2]=h>>16;c[p+8>>2]=0;a[p+12|0]=0;h=(c[3528176]|0)+1|0;c[3528176]=h;if((h|0)<=65534){c[2077636]=p+16;c[p+24>>2]=-1}p=f<<1;h=p|16744448;q=c[2112932]|0;r=c[q+(h>>>10<<2)>>2]|0;if(r>>>0>9){s=p&1022;t=(d[r+(s|1)|0]|0)<<8|(d[r+s|0]|0);u=q}else{s=gj[c[q+196688+(r<<2)>>2]&4095](h)|0;t=s;u=c[2112932]|0}s=t&65535;h=p|16748544;r=c[u+(h>>>10<<2)>>2]|0;if(r>>>0>9){v=u}else{q=c[u+196688+(r<<2)>>2]|0;gj[q&4095](h)|0;v=c[2112932]|0}h=p|16752640;q=c[v+(h>>>10<<2)>>2]|0;if(q>>>0>9){r=p&1022;w=(d[q+(r|1)|0]|0)<<8|(d[q+r|0]|0)}else{w=gj[c[v+196688+(q<<2)>>2]&4095](h)|0}h=w&65535;q=(h&512|0)==0?h&1023:h|-1024;h=q+1|0;if((s&65280|0)==0){if((h|0)==0){break}else{x=h;y=f}while(1){x=x-1|0;y=y+1|0;r=y<<1;p=r+16744448|0;z=p&16777214;A=c[2112932]|0;B=c[A+(z>>>10<<2)>>2]|0;if(B>>>0>9){C=p&1022;D=(d[B+(C|1)|0]|0)<<8|(d[B+C|0]|0);E=A}else{C=gj[c[A+196688+(B<<2)>>2]&4095](z)|0;D=C;E=c[2112932]|0}C=r+16748544|0;z=C&16777214;B=c[E+(z>>>10<<2)>>2]|0;if(B>>>0>9){A=C&1022;F=(d[B+(A|1)|0]|0)<<8|(d[B+A|0]|0);G=E}else{A=gj[c[E+196688+(B<<2)>>2]&4095](z)|0;F=A;G=c[2112932]|0}A=F&65535;z=r+16752640|0;r=z&16777214;B=c[G+(r>>>10<<2)>>2]|0;if(B>>>0>9){C=z&1022;H=(d[B+(C|1)|0]|0)<<8|(d[B+C|0]|0)}else{H=gj[c[G+196688+(B<<2)>>2]&4095](r)|0}r=H&65535;B=(a[642552]|0?25165824:0)-(((r&512|0)==0?r&1023:r|64512)+g<<16)|0;r=c[2077636]|0;c[r>>2]=(a[642560]|0?33554432:0)+(((A&512|0)==0?A&1023:A|64512)+e<<16)>>16;c[r+4>>2]=B>>16;c[r+8>>2]=D&63;a[r+12|0]=(D&65535)>>>8&255;B=(c[3528176]|0)+1|0;c[3528176]=B;if((B|0)<=65534){c[2077636]=r+16;c[r+24>>2]=-1}if((x|0)==0){break L96324}}}r=s&63;if((h|0)==0){break}B=(t&65535)>>>8&255;A=f;C=q;while(1){z=A+1|0;p=z<<1;I=p+16744448|0;J=I&16777214;K=c[2112932]|0;L=c[K+(J>>>10<<2)>>2]|0;if(L>>>0>9){M=I&1022;N=(d[L+(M|1)|0]|0)<<8|(d[L+M|0]|0);O=K}else{M=gj[c[K+196688+(L<<2)>>2]&4095](J)|0;N=M;O=c[2112932]|0}M=p+16748544|0;J=M&16777214;L=c[O+(J>>>10<<2)>>2]|0;if(L>>>0>9){K=M&1022;P=(d[L+(K|1)|0]|0)<<8|(d[L+K|0]|0);Q=O}else{K=gj[c[O+196688+(L<<2)>>2]&4095](J)|0;P=K;Q=c[2112932]|0}K=P&65535;J=p+16752640|0;p=J&16777214;L=c[Q+(p>>>10<<2)>>2]|0;if(L>>>0>9){M=J&1022;R=(d[L+(M|1)|0]|0)<<8|(d[L+M|0]|0)}else{R=gj[c[Q+196688+(L<<2)>>2]&4095](p)|0}p=R&65535;L=(a[642552]|0?25165824:0)-(((p&512|0)==0?p&1023:p|64512)+g<<16)|0;p=c[2077636]|0;c[p>>2]=(a[642560]|0?33554432:0)+(((K&512|0)==0?K&1023:K|64512)+e<<16)>>16;c[p+4>>2]=L>>16;L=p+8|0;do{if((N&65535)<256){c[L>>2]=0;a[p+12|0]=0;K=(c[3528176]|0)+1|0;c[3528176]=K;if((K|0)>65534){break}c[2077636]=p+16;c[p+24>>2]=-1}else{c[L>>2]=r;a[p+12|0]=B;K=(c[3528176]|0)+1|0;c[3528176]=K;if((K|0)>65534){break}c[2077636]=p+16;c[p+24>>2]=-1}}while(0);if((C|0)==0){break L96324}A=z;C=C-1|0}}}while(0);e=b+1|0;if((e|0)<2048){b=e}else{o=78901;break}}if((o|0)==78902){return}else if((o|0)==78901){return}}function dsm(b,d){b=b|0;d=d|0;var e=0,f=0;if((b|0)==16756737){if(d<<24>>24==0){return}dsl();return}else if((b|0)==159753){b=c[2433530]|0;e=(((c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0)/4|0)-b-(c[2426530]|0)+(c[2076596]|0)|0;do{if((e|0)>0){if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){f=gfc(e)|0;c[2433530]=(c[2433530]|0)+f;break}else{c[2433530]=e+b;break}}}while(0);a[c[3528324]|0]=d;d=c[2440210]^33;c[2440210]=d;if((d&32|0)==0){return}a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0;return}else{return}}function dsn(a){a=a|0;var b=0;if((a|0)==159748){b=d[9550064]|0|-256}else if((a|0)==159758){c[2388384]=0;b=0}else{b=0}return b|0}function dso(b){b=b|0;var d=0,e=0,f=0;switch(b|0){case 159757:{d=a[9699488]|0;return d|0};case 159753:{b=c[2433530]|0;e=(((c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0)/4|0)-b-(c[2426530]|0)+(c[2076596]|0)|0;do{if((e|0)>0){if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){f=gfc(e)|0;c[2433530]=(c[2433530]|0)+f;break}else{c[2433530]=e+b;break}}}while(0);d=c[2440210]&1;return d|0};case 159745:{d=(a[9660488]|0)-15&255;return d|0};case 159744:{d=(a[9660496]|0)-15&255;return d|0};case 159749:{d=a[9550064]|0;return d|0};default:{d=0;return d|0}}return 0}function dsp(b,d){b=b|0;d=d|0;var e=0,f=0;e=b&65535;switch(e|0){case 36864:{c[2440210]=c[2440210]&-17;return};case 35840:case 35841:case 35842:case 35843:case 35844:case 35845:case 35846:case 35847:{b=e>>>1&3;f=d&255;if((e&1|0)!=0){c[14168912+(b*252|0)>>2]=f&15;return}e=c[14168912+(b*252|0)>>2]|0;if((e|0)>15){return}do{if((e|0)<14){if((e|0)!=13){if((a[14168916+(b*252|0)+e|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(b,e,f);return};default:{return}}}function dsq(b){b=b|0;var d=0,e=0,f=0;d=b&65535;switch(d|0){case 36864:{e=c[2440210]&255&-2;return e|0};case 35840:case 35841:case 35842:case 35843:case 35844:case 35845:case 35846:case 35847:{b=d>>>1&3;d=c[14168912+(b*252|0)>>2]|0;if((d|0)>15){e=0;return e|0}do{if((d|0)==14){f=c[14168896+(b*252|0)>>2]|0;if((f|0)==0){break}a[14168930+(b*252|0)|0]=gj[f&4095](0)|0}else if((d|0)==15){f=c[14168900+(b*252|0)>>2]|0;if((f|0)==0){break}a[14168931+(b*252|0)|0]=gj[f&4095](0)|0}}while(0);e=a[14168916+(b*252|0)+d|0]|0;return e|0};case 34816:{c[2440210]=c[2440210]&-34|1;e=a[c[3528324]|0]|0;return e|0};default:{e=0;return e|0}}return 0}function dsr(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4822676+(b*112|0)>>2];c[a+104>>2]=c[4822680+(b*112|0)>>2];c[a+108>>2]=c[4822684+(b*112|0)>>2];d=0;return d|0}function dss(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=4822576+(b*112|0);e=0;return e|0}function dst(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=2010720+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dsu(){var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0.0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;d=i;i=i+240|0;e=d|0;f=d+112|0;g=d+120|0;j=d+232|0;c[2424]=4e3;c[2415032]=0;c[2388182]=0;c[2385960]=65536;c[2406304]=73728;c[2414740]=74752;c[2388300]=74752;c[2386114]=82944;c[2386284]=84992;c[3528324]=97280;c[2411772]=97281;c[3530098]=97281;k=0;while(1){if((k|0)>=1024){break}l=9638528+(k<<2)|0;if((c[l>>2]|0)==0){m=78993;break}else{k=k+1|0}}do{if((m|0)==78993){k=gGq(162817)|0;c[l>>2]=k;if((k|0)==0){break}c[2415032]=k;gGz(k|0,0,162817);c[2388182]=k;c[2385960]=k+65536;c[2406304]=k+73728;n=k+74752|0;c[2414740]=n;c[2388300]=n;c[2386114]=k+82944;c[2386284]=k+84992;c[3528324]=k+97280;n=k+97281|0;c[2411772]=n;c[3530098]=n;c[2414320]=k+162817;if((R6(k+1|0,0,2)|0)!=0){o=1;i=d;return o|0}if((R6(c[2388182]|0,1,2)|0)!=0){o=1;i=d;return o|0}if((R6((c[2388182]|0)+8193|0,2,2)|0)!=0){o=1;i=d;return o|0}if((R6((c[2388182]|0)+8192|0,3,2)|0)!=0){o=1;i=d;return o|0}if((R6((c[2388182]|0)+16385|0,4,2)|0)!=0){o=1;i=d;return o|0}if((R6((c[2388182]|0)+16384|0,5,2)|0)!=0){o=1;i=d;return o|0}if((R6((c[2388182]|0)+24577|0,6,2)|0)!=0){o=1;i=d;return o|0}if((R6((c[2388182]|0)+24576|0,7,2)|0)!=0){o=1;i=d;return o|0}if((R6((c[2388182]|0)+32769|0,8,2)|0)!=0){o=1;i=d;return o|0}if((R6((c[2388182]|0)+32768|0,9,2)|0)!=0){o=1;i=d;return o|0}if((R6((c[2388182]|0)+40961|0,10,2)|0)!=0){o=1;i=d;return o|0}if((R6((c[2388182]|0)+40960|0,11,2)|0)!=0){o=1;i=d;return o|0}k=c[2385960]|0;if((c[3542200]|0)==0){o=1;i=d;return o|0}n=g+108|0;c[n>>2]=0;p=g+100|0;c[p>>2]=0;q=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[q&16383](g,12)|0;do{if((c[n>>2]|0)!=0){q=c[p>>2]|0;c[j>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](j,12,0)|0;if((q|0)<1){o=1;i=d;return o|0}if((gzL(k,0,12)|0)==0){break}else{o=1}i=d;return o|0}}while(0);k=(c[2385960]|0)+4096|0;if((c[3542200]|0)==0){o=1;i=d;return o|0}p=e+108|0;c[p>>2]=0;n=e+100|0;c[n>>2]=0;q=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[q&16383](e,13)|0;do{if((c[p>>2]|0)!=0){q=c[n>>2]|0;c[f>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](f,13,0)|0;if((q|0)<1){o=1;i=d;return o|0}if((gzL(k,0,13)|0)==0){break}else{o=1}i=d;return o|0}}while(0);fxU(0,425984);if((c[2394]|0)==0){s=c[2112932]|0}else{c[2394]=0;k=c[3532596]|0;c[2112932]=k;n=c[3532592]|0;if((n|0)!=0){gGC(9104152,n|0,280)|0}c[2113054]=c[2113060];s=k}c[s+196856>>2]=3596;k=c[2388182]|0;n=s|0;p=0;while(1){q=k+p|0;c[n>>2]=q;c[n+131072>>2]=q;q=p+1024|0;if(q>>>0>49151){break}else{n=n+4|0;p=q}}p=c[2406304]|0;c[s+544>>2]=p;c[s+131616>>2]=p;p=c[2386284]|0;c[s+65408>>2]=p;c[s+130944>>2]=p;c[s+196480>>2]=p;n=p+1024|0;c[s+65412>>2]=n;c[s+130948>>2]=n;c[s+196484>>2]=n;n=p+2048|0;c[s+65416>>2]=n;c[s+130952>>2]=n;c[s+196488>>2]=n;n=p+3072|0;c[s+65420>>2]=n;c[s+130956>>2]=n;c[s+196492>>2]=n;n=p+4096|0;c[s+65424>>2]=n;c[s+130960>>2]=n;c[s+196496>>2]=n;n=p+5120|0;c[s+65428>>2]=n;c[s+130964>>2]=n;c[s+196500>>2]=n;n=p+6144|0;c[s+65432>>2]=n;c[s+130968>>2]=n;c[s+196504>>2]=n;n=p+7168|0;c[s+65436>>2]=n;c[s+130972>>2]=n;c[s+196508>>2]=n;n=p+8192|0;c[s+65440>>2]=n;c[s+130976>>2]=n;c[s+196512>>2]=n;n=p+9216|0;c[s+65444>>2]=n;c[s+130980>>2]=n;c[s+196516>>2]=n;n=p+10240|0;c[s+65448>>2]=n;c[s+130984>>2]=n;c[s+196520>>2]=n;n=p+11264|0;c[s+65452>>2]=n;c[s+130988>>2]=n;c[s+196524>>2]=n;n=c[2388300]|0;c[s+65504>>2]=n;c[s+131040>>2]=n;c[s+196576>>2]=n;p=n+1024|0;c[s+65508>>2]=p;c[s+131044>>2]=p;c[s+196580>>2]=p;p=n+2048|0;c[s+65512>>2]=p;c[s+131048>>2]=p;c[s+196584>>2]=p;p=n+3072|0;c[s+65516>>2]=p;c[s+131052>>2]=p;c[s+196588>>2]=p;p=n+4096|0;c[s+65520>>2]=p;c[s+131056>>2]=p;c[s+196592>>2]=p;p=n+5120|0;c[s+65524>>2]=p;c[s+131060>>2]=p;c[s+196596>>2]=p;p=n+6144|0;c[s+65528>>2]=p;c[s+131064>>2]=p;c[s+196600>>2]=p;p=n+7168|0;c[s+65532>>2]=p;c[s+131068>>2]=p;c[s+196604>>2]=p;c[s+196728>>2]=1684;c[s+196648>>2]=2486;c[s+196688>>2]=2908;c[s+196608>>2]=92;p=c[3532592]|0;if((p|0)!=0){gGC(p|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);p=c[2439330]|0;n=(p|0)==0;if(!n){k=p;gGC(9706056,k|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];k=c[3528484]|0;c[2076596]=k;q=c[2417276]|0;c[3541536]=q;c[1836236]=0;r=c[2385960]|0;t=0;u=0;while(1){c[p+76+(u<<2)>>2]=r+(u<<8);v=t+1&65535;if((v&65535)>31){w=0;x=0;break}else{t=v;u=v&65535}}while(1){u=r+(x<<8)|0;c[p+76+(x+512<<2)>>2]=u;c[p+76+(x+768<<2)>>2]=u;u=w+1&65535;if((u&65535)>31){break}else{w=u;x=u&65535}}r=c[2386114]|0;c[p+588>>2]=r;u=r+256|0;c[p+592>>2]=u;t=r+512|0;c[p+596>>2]=t;v=r+768|0;c[p+600>>2]=v;y=r+1024|0;c[p+604>>2]=y;z=r+1280|0;c[p+608>>2]=z;A=r+1536|0;c[p+612>>2]=A;B=r+1792|0;c[p+616>>2]=B;c[p+1612>>2]=r;c[p+1616>>2]=u;c[p+1620>>2]=t;c[p+1624>>2]=v;c[p+1628>>2]=y;c[p+1632>>2]=z;c[p+1636>>2]=A;c[p+1640>>2]=B;c[p+2636>>2]=r;c[p+3660>>2]=r;c[p+2640>>2]=u;c[p+3664>>2]=u;c[p+2644>>2]=t;c[p+3668>>2]=t;c[p+2648>>2]=v;c[p+3672>>2]=v;c[p+2652>>2]=y;c[p+3676>>2]=y;c[p+2656>>2]=z;c[p+3680>>2]=z;c[p+2660>>2]=A;c[p+3684>>2]=A;c[p+2664>>2]=B;c[p+3688>>2]=B;c[p+4184>>2]=2870;c[p+4180>>2]=2048;if(!n){B=p;gGC(B|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=k;c[2417276]=q;c[1836236]=-1;B=a[9680]|0?32e3:0;c[3542220]=11200;A=c[2113008]|0;if((A|0)==0){gGz(14168888,0,252);c[3542223]=B;gGz(14168896,0,16);c[3542234]=~~((+(B|0)*32768.0*8.0+1.0e6)/2.0e6);z=31;C=32767.0;while(1){c[14169012+(z<<2)>>2]=~~(C+.5);y=z-1|0;if((y|0)>0){z=y;C=C/1.188502227}else{break}}c[3542253]=0;h[1771269]=1.0;h[1771270]=1.0;h[1771271]=1.0;c[3542574]=3;c[3542575]=3;c[3542576]=3;mB(0);z=(c[2113008]|0)+1|0;c[2113008]=z;D=z;E=a[9680]|0?32e3:0}else{D=A;E=B}c[3542220]=11200;if((D|0)==1){gGz(14169140,0,252);c[3542286]=E;gGz(14169148,0,16);c[3542297]=~~((+(E|0)*32768.0*8.0+1.0e6)/2.0e6);z=31;C=32767.0;while(1){c[14169264+(z<<2)>>2]=~~(C+.5);q=z-1|0;if((q|0)>0){z=q;C=C/1.188502227}else{break}}c[3542316]=0;h[1771272]=1.0;h[1771273]=1.0;h[1771274]=1.0;c[3542577]=3;c[3542578]=3;c[3542579]=3;mB(1);z=(c[2113008]|0)+1|0;c[2113008]=z;F=z;G=a[9680]|0?32e3:0}else{F=D;G=E}c[3542220]=11200;if((F|0)==2){gGz(14169392,0,252);c[3542349]=G;gGz(14169400,0,16);c[3542360]=~~((+(G|0)*32768.0*8.0+1.0e6)/2.0e6);z=31;C=32767.0;while(1){c[14169516+(z<<2)>>2]=~~(C+.5);B=z-1|0;if((B|0)>0){z=B;C=C/1.188502227}else{break}}c[3542379]=0;h[1771275]=1.0;h[1771276]=1.0;h[1771277]=1.0;c[3542580]=3;c[3542581]=3;c[3542582]=3;mB(2);z=(c[2113008]|0)+1|0;c[2113008]=z;H=z;I=a[9680]|0?32e3:0}else{H=F;I=G}c[3542220]=11200;if((H|0)==3){gGz(14169644,0,252);c[3542412]=I;gGz(14169652,0,16);c[3542423]=~~((+(I|0)*32768.0*8.0+1.0e6)/2.0e6);z=31;C=32767.0;while(1){c[14169768+(z<<2)>>2]=~~(C+.5);B=z-1|0;if((B|0)>0){z=B;C=C/1.188502227}else{break}}c[3542442]=0;h[1771278]=1.0;h[1771279]=1.0;h[1771280]=1.0;c[3542583]=3;c[3542584]=3;c[3542585]=3;mB(3);c[2113008]=(c[2113008]|0)+1}h[1771269]=.15;c[3542574]=3;h[1771270]=.15;c[3542575]=3;h[1771271]=.15;c[3542576]=3;h[1771272]=.15;c[3542577]=3;h[1771273]=.15;c[3542578]=3;h[1771274]=.15;c[3542579]=3;h[1771275]=.15;c[3542580]=3;h[1771276]=.15;c[3542581]=3;h[1771277]=.15;c[3542582]=3;h[1771278]=.15;c[3542583]=3;h[1771279]=.15;c[3542584]=3;h[1771280]=.15;c[3542585]=3;z=c[3530098]|0;B=0;do{A=B>>>4&3;q=A<<4|A|A<<6|A<<2;A=B>>>2&3;k=A<<4|A|A<<6|A<<2;A=B&3;p=A<<4|A|A<<6|A<<2;A=B<<8;n=0;do{y=(ag(n,q)|0)/255|0;v=(ag(n,k)|0)/255|0;c[z+(n+A<<2)>>2]=v<<8|y<<16|((ag(n,p)|0)/255|0);n=n+1|0;}while((n|0)<256);B=B+1|0;}while((B|0)<64);B=c[642608+(c[2436]<<2)>>2]|0;z=c[B+128>>2]|0;if((c[B+52>>2]&4|0)==0){c[2113068]=z;n=c[B+132>>2]|0;c[2113070]=n;c[2443814]=z;c[2440436]=n;J=z;K=n}else{c[2113070]=z;n=c[B+132>>2]|0;c[2113068]=n;c[2440436]=z;c[2443814]=n;J=n;K=z}z=ag(J<<1,K)|0;n=gGq(z)|0;c[2112926]=n;if((n|0)!=0){gGz(n|0,0,z|0)}z=gGq(1048576)|0;n=z;c[2440178]=n;gGz(z|0,0,1048576);c[3528176]=0;c[2077636]=n;c[z+8>>2]=-1;a[642560]=1;a[642552]=1;gGz(c[2406304]|0,-1|0,256);z=c[2414740]|0;gGz(z|0,0,(c[2411772]|0)-z|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];z=c[3532592]|0;if((z|0)!=0){gGC(9104152,z|0,280)|0}c[2113054]=c[2113060]}RI();z=c[2394]|0;n=c[14130368+(z<<2)>>2]|0;if((n|0)!=0){gGC(n|0,9104152,280)|0}c[8452240+(z<<2)>>2]=c[2113054];c[2394]=-1;z=c[2439330]|0;n=(z|0)==0;if(!n){B=z;gGC(9706056,B|0,76)|0}B=c[2438118]|0;c[2433530]=B;p=c[3528484]|0;c[2076596]=p;A=c[2417276]|0;c[3541536]=A;c[1836236]=0;gGz(9706056,0,76);if(!n){n=z;gGC(n|0,9706056,76)|0}c[2438118]=B;c[3528484]=p;c[2417276]=A;c[1836236]=-1;mB(0);mB(1);mB(2);mB(3);c[2440210]=0;c[2433490]=0;c[2388384]=0;c[3528176]=0;A=c[2440178]|0;c[2077636]=A;c[A+8>>2]=-1;o=0;i=d;return o|0}}while(0);c[2415032]=0;o=1;i=d;return o|0}function dsv(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}gGr(c[2440178]|0);c[2440178]=0;c[2077636]=0;if((c[2392]|0)>=0){b=0;do{d=14130368+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}d=14130384+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}b=b+1|0;}while((b|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;fwZ();c[2113008]=0;c[2076598]=0;c[2383582]=0;b=c[2415032]|0;d=0;while(1){if((d|0)>=1024){break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==(b|0)){g=79099;break}else{d=d+1|0}}if((g|0)==79099){gGr(b);c[f>>2]=0}c[2415032]=0;a[1006600]=0;f=c[2385388]|0;b=0;while(1){if((b|0)>=1024){break}h=9638528+(b<<2)|0;if((c[h>>2]|0)==(f|0)){g=79103;break}else{b=b+1|0}}if((g|0)==79103){gGr(f);c[h>>2]=0}c[2385388]=0;h=c[2385389]|0;f=0;while(1){if((f|0)>=1024){break}i=9638528+(f<<2)|0;if((c[i>>2]|0)==(h|0)){g=79107;break}else{f=f+1|0}}if((g|0)==79107){gGr(h);c[i>>2]=0}c[2385389]=0;i=c[2385390]|0;h=0;while(1){if((h|0)>=1024){break}j=9638528+(h<<2)|0;if((c[j>>2]|0)==(i|0)){g=79111;break}else{h=h+1|0}}if((g|0)==79111){gGr(i);c[j>>2]=0}c[2385390]=0;j=c[2385391]|0;i=0;while(1){if((i|0)>=1024){break}k=9638528+(i<<2)|0;if((c[k>>2]|0)==(j|0)){g=79115;break}else{i=i+1|0}}if((g|0)==79115){gGr(j);c[k>>2]=0}c[2385391]=0;k=c[2385392]|0;j=0;while(1){if((j|0)>=1024){break}l=9638528+(j<<2)|0;if((c[l>>2]|0)==(k|0)){g=79119;break}else{j=j+1|0}}if((g|0)==79119){gGr(k);c[l>>2]=0}c[2385392]=0;l=c[2385393]|0;k=0;while(1){if((k|0)>=1024){break}m=9638528+(k<<2)|0;if((c[m>>2]|0)==(l|0)){g=79123;break}else{k=k+1|0}}if((g|0)==79123){gGr(l);c[m>>2]=0}c[2385393]=0;m=c[2385394]|0;l=0;while(1){if((l|0)>=1024){break}n=9638528+(l<<2)|0;if((c[n>>2]|0)==(m|0)){g=79127;break}else{l=l+1|0}}if((g|0)==79127){gGr(m);c[n>>2]=0}c[2385394]=0;n=c[2385395]|0;m=0;while(1){if((m|0)>=1024){break}o=9638528+(m<<2)|0;if((c[o>>2]|0)==(n|0)){g=79131;break}else{m=m+1|0}}if((g|0)==79131){gGr(n);c[o>>2]=0}c[2385395]=0;o=c[2385396]|0;n=0;while(1){if((n|0)>=1024){break}p=9638528+(n<<2)|0;if((c[p>>2]|0)==(o|0)){g=79135;break}else{n=n+1|0}}if((g|0)==79135){gGr(o);c[p>>2]=0}c[2385396]=0;p=c[2385397]|0;o=0;while(1){if((o|0)>=1024){break}q=9638528+(o<<2)|0;if((c[q>>2]|0)==(p|0)){g=79139;break}else{o=o+1|0}}if((g|0)==79139){gGr(p);c[q>>2]=0}c[2385397]=0;q=c[2385398]|0;p=0;while(1){if((p|0)>=1024){break}r=9638528+(p<<2)|0;if((c[r>>2]|0)==(q|0)){g=79143;break}else{p=p+1|0}}if((g|0)==79143){gGr(q);c[r>>2]=0}c[2385398]=0;r=c[2385399]|0;q=0;while(1){if((q|0)>=1024){g=79150;break}s=9638528+(q<<2)|0;if((c[s>>2]|0)==(r|0)){break}else{q=q+1|0}}if((g|0)==79150){c[2385399]=0;return 0}gGr(r);c[s>>2]=0;c[2385399]=0;return 0}function dsw(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;if((c[2112964]|0)!=0&(a[1006600]^1)){d=a[9688]|0?1068:0;f=0;while(1){if((f|0)>=1024){g=0;break}h=9638528+(f<<2)|0;if((c[h>>2]|0)==0){i=79155;break}else{f=f+1|0}}do{if((i|0)==79155){f=gGq(d)|0;c[h>>2]=f;if((f|0)==0){g=0;break}gGz(f|0,0,d|0);g=f}}while(0);c[2385388]=g;g=a[9688]|0?1068:0;d=0;while(1){if((d|0)>=1024){j=0;break}k=9638528+(d<<2)|0;if((c[k>>2]|0)==0){i=79160;break}else{d=d+1|0}}do{if((i|0)==79160){d=gGq(g)|0;c[k>>2]=d;if((d|0)==0){j=0;break}gGz(d|0,0,g|0);j=d}}while(0);c[2385389]=j;j=a[9688]|0?1068:0;g=0;while(1){if((g|0)>=1024){l=0;break}m=9638528+(g<<2)|0;if((c[m>>2]|0)==0){i=79165;break}else{g=g+1|0}}do{if((i|0)==79165){g=gGq(j)|0;c[m>>2]=g;if((g|0)==0){l=0;break}gGz(g|0,0,j|0);l=g}}while(0);c[2385390]=l;l=a[9688]|0?1068:0;j=0;while(1){if((j|0)>=1024){n=0;break}o=9638528+(j<<2)|0;if((c[o>>2]|0)==0){i=79170;break}else{j=j+1|0}}do{if((i|0)==79170){j=gGq(l)|0;c[o>>2]=j;if((j|0)==0){n=0;break}gGz(j|0,0,l|0);n=j}}while(0);c[2385391]=n;n=a[9688]|0?1068:0;l=0;while(1){if((l|0)>=1024){p=0;break}q=9638528+(l<<2)|0;if((c[q>>2]|0)==0){i=79175;break}else{l=l+1|0}}do{if((i|0)==79175){l=gGq(n)|0;c[q>>2]=l;if((l|0)==0){p=0;break}gGz(l|0,0,n|0);p=l}}while(0);c[2385392]=p;p=a[9688]|0?1068:0;n=0;while(1){if((n|0)>=1024){r=0;break}s=9638528+(n<<2)|0;if((c[s>>2]|0)==0){i=79180;break}else{n=n+1|0}}do{if((i|0)==79180){n=gGq(p)|0;c[s>>2]=n;if((n|0)==0){r=0;break}gGz(n|0,0,p|0);r=n}}while(0);c[2385393]=r;r=a[9688]|0?1068:0;p=0;while(1){if((p|0)>=1024){t=0;break}u=9638528+(p<<2)|0;if((c[u>>2]|0)==0){i=79185;break}else{p=p+1|0}}do{if((i|0)==79185){p=gGq(r)|0;c[u>>2]=p;if((p|0)==0){t=0;break}gGz(p|0,0,r|0);t=p}}while(0);c[2385394]=t;t=a[9688]|0?1068:0;r=0;while(1){if((r|0)>=1024){v=0;break}w=9638528+(r<<2)|0;if((c[w>>2]|0)==0){i=79190;break}else{r=r+1|0}}do{if((i|0)==79190){r=gGq(t)|0;c[w>>2]=r;if((r|0)==0){v=0;break}gGz(r|0,0,t|0);v=r}}while(0);c[2385395]=v;v=a[9688]|0?1068:0;t=0;while(1){if((t|0)>=1024){x=0;break}y=9638528+(t<<2)|0;if((c[y>>2]|0)==0){i=79195;break}else{t=t+1|0}}do{if((i|0)==79195){t=gGq(v)|0;c[y>>2]=t;if((t|0)==0){x=0;break}gGz(t|0,0,v|0);x=t}}while(0);c[2385396]=x;x=a[9688]|0?1068:0;v=0;while(1){if((v|0)>=1024){z=0;break}A=9638528+(v<<2)|0;if((c[A>>2]|0)==0){i=79200;break}else{v=v+1|0}}do{if((i|0)==79200){v=gGq(x)|0;c[A>>2]=v;if((v|0)==0){z=0;break}gGz(v|0,0,x|0);z=v}}while(0);c[2385397]=z;z=a[9688]|0?1068:0;x=0;while(1){if((x|0)>=1024){B=0;break}C=9638528+(x<<2)|0;if((c[C>>2]|0)==0){i=79205;break}else{x=x+1|0}}do{if((i|0)==79205){x=gGq(z)|0;c[C>>2]=x;if((x|0)==0){B=0;break}gGz(x|0,0,z|0);B=x}}while(0);c[2385398]=B;B=a[9688]|0?1068:0;z=0;while(1){if((z|0)>=1024){D=0;break}E=9638528+(z<<2)|0;if((c[E>>2]|0)==0){i=79210;break}else{z=z+1|0}}do{if((i|0)==79210){z=gGq(B)|0;c[E>>2]=z;if((z|0)==0){D=0;break}gGz(z|0,0,B|0);D=z}}while(0);c[2385399]=D;a[1006600]=1}do{if((a[9624664]|0)==0){D=(c[2388384]|0)+1|0;c[2388384]=D;if((D|0)!=180){break}if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];D=c[3532592]|0;if((D|0)!=0){gGC(9104152,D|0,280)|0}c[2113054]=c[2113060]}RI();D=c[2394]|0;B=c[14130368+(D<<2)>>2]|0;if((B|0)!=0){gGC(B|0,9104152,280)|0}c[8452240+(D<<2)>>2]=c[2113054];c[2394]=-1;D=c[2439330]|0;B=(D|0)==0;if(!B){E=D;gGC(9706056,E|0,76)|0}E=c[2438118]|0;c[2433530]=E;i=c[3528484]|0;c[2076596]=i;z=c[2417276]|0;c[3541536]=z;c[1836236]=0;gGz(9706056,0,76);if(!B){B=D;gGC(B|0,9706056,76)|0}c[2438118]=E;c[3528484]=i;c[2417276]=z;c[1836236]=-1;mB(0);mB(1);mB(2);mB(3);c[2440210]=0;c[2433490]=0;c[2388384]=0;c[3528176]=0;z=c[2440178]|0;c[2077636]=z;c[z+8>>2]=-1}else{z=c[2414740]|0;gGz(z|0,0,(c[2411772]|0)-z|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];z=c[3532592]|0;if((z|0)!=0){gGC(9104152,z|0,280)|0}c[2113054]=c[2113060]}RI();z=c[2394]|0;i=c[14130368+(z<<2)>>2]|0;if((i|0)!=0){gGC(i|0,9104152,280)|0}c[8452240+(z<<2)>>2]=c[2113054];c[2394]=-1;z=c[2439330]|0;i=(z|0)==0;if(!i){E=z;gGC(9706056,E|0,76)|0}E=c[2438118]|0;c[2433530]=E;B=c[3528484]|0;c[2076596]=B;D=c[2417276]|0;c[3541536]=D;c[1836236]=0;gGz(9706056,0,76);if(!i){i=z;gGC(i|0,9706056,76)|0}c[2438118]=E;c[3528484]=B;c[2417276]=D;c[1836236]=-1;mB(0);mB(1);mB(2);mB(3);c[2440210]=0;c[2433490]=0;c[2388384]=0;c[3528176]=0;D=c[2440178]|0;c[2077636]=D;c[D+8>>2]=-1;c[2388384]=1}}while(0);D=c[2392]|0;if((D|0)>=0){gGz(8452240,0,((D|0)>0?(D<<2)+4|0:4)|0)}c[2113054]=0;D=c[2385548]|0;if((D|0)>0){gGz(9752472,0,((D|0)>1?D<<2:4)|0)}c[2433530]=0;a[9550064]=(a[9634064]|-2)^1^a[9634065]<<1&2^a[9634066]<<2&4^a[9634067]<<3&8^a[9634068]<<4&16^a[9634069]<<5&32^a[9634070]<<6&64^a[9634071]<<7;D=((e[4877664]|0)>>>7)+15|0;a[9660496]=(D&255)>>>0>128?0:D&255;D=((e[4877656]|0)>>>7^255)+16|0;a[9660488]=(D&254)>>>0>29?29:D&255;do{if((a[14124896]|0)==0){if((a[14124897]|0)==0){break}a[9699488]=(a[9699488]|0)-4&255}else{a[9699488]=(a[9699488]|0)+4&255}}while(0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];D=c[3532592]|0;if((D|0)!=0){gGC(9104152,D|0,280)|0}c[2113054]=c[2113060]}D=c[2439330]|0;if((D|0)!=0){B=D;gGC(9706056,B|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;B=0;do{c[2113056]=2e3;D=RG(2e3)|0;E=(c[2113054]|0)+D|0;c[2113054]=E;c[2276108]=-1;c[2113056]=-1;do{if((B|0)==99){c[8452200+(c[2394]<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0>=1024){F=E;G=-1;H=-1;break}RH(4);F=c[2113054]|0;G=c[2113056]|0;H=c[2276108]|0}else{F=E;G=-1;H=-1}}while(0);E=c[2433530]|0;D=((G+F-H|0)/4|0)-E-(c[2426530]|0)+(c[2076596]|0)|0;do{if((D|0)>0){if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){i=gfc(D)|0;c[2433530]=(c[2433530]|0)+i;break}else{c[2433530]=D+E;break}}}while(0);E=c[2433490]|0;do{if(((E|0)%40|0|0)==39){D=c[2440210]^16;c[2440210]=D;if((D&16|0)==0){I=E;break}a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0;I=c[2433490]|0}else{I=E}}while(0);B=B+1|0;c[2433490]=I+1;}while((B|0)<100);B=c[2394]|0;I=c[14130368+(B<<2)>>2]|0;if((I|0)!=0){gGC(I|0,9104152,280)|0}c[8452240+(B<<2)>>2]=c[2113054];c[2394]=-1;B=c[1836236]|0;I=c[9757320+(B<<2)>>2]|0;if((I|0)!=0){H=I;gGC(H|0,9706056,76)|0}c[9752472+(B<<2)>>2]=c[2433530];c[14113936+(B<<2)>>2]=c[2076596];c[9669104+(B<<2)>>2]=c[3541536];c[1836236]=-1;B=c[2112964]|0;if((B|0)!=0){mF(9541552,B,a[9688]|0?534:0,0)}if((c[2112968]|0)==0){return 0}dsx()|0;return 0}function dsx(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;d=c[3530098]|0;if((a[9547744]|0)==0){e=d}else{f=0;do{g=f>>>4&3;h=g<<4|g|g<<6|g<<2;g=f>>>2&3;i=g<<4|g|g<<6|g<<2;g=f&3;j=g<<4|g|g<<6|g<<2;g=f<<8;k=0;do{l=(ag(k,h)|0)/255|0;m=(ag(k,i)|0)/255|0;c[d+(k+g<<2)>>2]=m<<8|l<<16|((ag(k,j)|0)/255|0);k=k+1|0;}while((k|0)<256);f=f+1|0;}while((f|0)<64);a[9547744]=0;e=d}d=c[2440178]|0;f=c[2112926]|0;gGz(f|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);if((c[3528176]|0)<=0){R8(e);return 0}k=c[2113068]|0;j=c[2113070]|0;g=0;i=0;h=0;l=d;while(1){d=c[l+8>>2]|0;if((d|0)==-1){n=79312;break}m=c[l+4>>2]|0;o=c[l>>2]|0;p=a[l+12|0]|0;L96911:do{if(p<<24>>24!=0){q=h-o|0;r=g-m|0;s=p&255|d<<8;t=(h|0)!=(o|0);if(!(t|(g|0)==(m|0))){u=(g|0)<(m|0);v=u?m-g|0:r;if(!((h|0)>-1&(k|0)>(h|0)&(v|0)>0)){break}w=s&65535;x=u?g:m;u=1;while(1){if((x|0)>-1&(x|0)<(j|0)){b[f+((ag(k,x)|0)+h<<1)>>1]=w}if((u|0)>=(v|0)){break L96911}x=x+1|0;u=u+1|0}}u=(g|0)!=(m|0);x=t^1;if(!(u|x)){v=(h|0)<(o|0);w=v?o-h|0:q;if(!((g|0)>-1&(j|0)>(g|0))){break}y=ag(k,g)|0;if((w|0)<=0){break}z=s&65535;A=v?h:o;v=1;while(1){if((A|0)>-1&(A|0)<(k|0)){b[f+(A+y<<1)>>1]=z}if((v|0)>=(w|0)){break L96911}A=A+1|0;v=v+1|0}}if(x|u^1){if((o|0)<=-1){break}if(!((k|0)>(o|0)&(m|0)>-1&(j|0)>(m|0))){break}b[f+((ag(k,m)|0)+o<<1)>>1]=s&65535;break}v=(r<<16|0)/(q|0)|0;A=(h|0)>(o|0)?1:-1;if((o|0)==(h|0)){break}w=(m<<16|32768)-(ag(v,o)|0)|0;z=s&65535;y=o;do{y=y+A|0;t=w+(ag(y,v)|0)>>16;do{if((y|0)>-1){if(!((y|0)<(k|0)&(t|0)>-1&(t|0)<(j|0))){break}b[f+((ag(k,t)|0)+y<<1)>>1]=z}}while(0);}while((y|0)!=(h|0))}}while(0);d=i+1|0;if((d|0)<(c[3528176]|0)&(d|0)<65536){g=m;i=d;h=o;l=l+16|0}else{n=79310;break}}if((n|0)==79312){R8(e);return 0}else if((n|0)==79310){R8(e);return 0}return 0}function dsy(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;e=i;i=i+176|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;l=e+80|0;m=e+96|0;n=e+112|0;o=e+128|0;p=e+144|0;q=e+160|0;r=(d|0)==0;if(!r){c[d>>2]=169624}if((b&4|0)!=0){s=q|0;c[s>>2]=c[2388182];t=q+4|0;c[t>>2]=49152;u=q+8|0;c[u>>2]=0;v=q+12|0;c[v>>2]=496208;w=c[2076592]|0;gj[w&4095](q)|0;c[s>>2]=c[2385960];c[t>>2]=8192;c[u>>2]=0;c[v>>2]=501160;v=c[2076592]|0;gj[v&4095](q)|0}if((b&32|0)!=0){v=q|0;c[v>>2]=c[2388300];u=q+4|0;c[u>>2]=8192;t=q+8|0;c[t>>2]=16769024;s=q+12|0;c[s>>2]=484192;w=c[2076592]|0;gj[w&4095](q)|0;c[v>>2]=c[2386284];c[u>>2]=12288;c[t>>2]=16744448;c[s>>2]=77584;w=c[2076592]|0;gj[w&4095](q)|0;c[v>>2]=c[2386114];c[u>>2]=2048;c[t>>2]=0;c[s>>2]=498600;s=c[2076592]|0;gj[s&4095](q)|0}if((b&8|0)!=0){c[q>>2]=c[2406304];c[q+4>>2]=256;c[q+8>>2]=139264;c[q+12>>2]=254016;s=c[2076592]|0;gj[s&4095](q)|0}if((b&64|0)!=0){q=m|0;gGz(l|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){s=m+9|0;m=k;t=k|0;u=k+4|0;v=k+12|0;w=l|0;x=l+4|0;y=l+12|0;z=0;do{gGC(q|0,614896,11)|0;a[s]=z+48&255;A=8452256+(z<<2)|0;gGz(m|0,0,12);c[t>>2]=A;c[u>>2]=4;c[v>>2]=164976;gj[c[2076592]&4095](k)|0;if((c[A>>2]|0)!=0){c[w>>2]=c[14130368+(z<<2)>>2];c[x>>2]=c[8452184+(z<<2)>>2];c[y>>2]=q;A=c[2076592]|0;gj[A&4095](l)|0}z=z+1|0;}while((z|0)<=(c[2392]|0))}fw$(b);z=j|0;do{if(!r){if((c[d>>2]|0)>=169110){break}c[d>>2]=169110}}while(0);if((c[2113008]|0)>0){d=h|0;r=h+4|0;j=h+8|0;l=h+12|0;q=0;do{cC(z|0,531144,(y=i,i=i+8|0,c[y>>2]=q,y)|0)|0;i=y;c[d>>2]=14168888+(q*252|0);c[r>>2]=252;c[j>>2]=0;c[l>>2]=z;gj[c[2076592]&4095](h)|0;q=q+1|0;}while((q|0)<(c[2113008]|0))}q=c[3528324]|0;gGz(p|0,0,12);c[p>>2]=q;c[p+4>>2]=1;c[p+12>>2]=551856;q=c[2076592]|0;gj[q&4095](p)|0;gGz(o|0,0,12);c[o>>2]=9733960;c[o+4>>2]=4;c[o+12>>2]=537400;p=c[2076592]|0;gj[p&4095](o)|0;gGz(n|0,0,12);c[n>>2]=9760840;c[n+4>>2]=4;c[n+12>>2]=524080;o=c[2076592]|0;gj[o&4095](n)|0}if((b&96|0)!=0){gGz(g|0,0,12);c[g>>2]=c[2440178];c[g+4>>2]=1048576;c[g+12>>2]=258912;n=c[2076592]|0;gj[n&4095](g)|0;gGz(f|0,0,12);c[f>>2]=14112704;c[f+4>>2]=4;c[f+12>>2]=525704;g=c[2076592]|0;gj[g&4095](f)|0}if((b&2|0)==0){i=e;return 0}c[2077636]=(c[2440178]|0)+(c[3528176]<<4);i=e;return 0}function dsz(a){a=a|0;return 12}function dsA(a,d){a=a|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;do{if((a&-32768|0)==1048576){if((c[2444212]&1|0)==0){break}b[(c[2386362]|0)+(a&32767)>>1]=(a&2|0)==0?d|-256:d;return}}while(0);if((a&-4096|0)!=4194304){return}b[(c[2387084]|0)+(a&4094)>>1]=d;e=d&65535;d=e>>>7&30;f=d|e>>>14&1;g=e>>>3&30;h=e<<1&30;i=h|e>>>12&1;j=(g|e>>>13&1)<<3|g>>>2;g=a>>>1&2047;c[(c[2406976]|0)+(g<<2)>>2]=i<<3|h>>>2|j<<8|(f<<3|d>>>2)<<16;c[(c[3530096]|0)+(g<<2)>>2]=f<<11|i|j<<3&2016;return}function dsB(b,d){b=b|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;if((b&-32768|0)==1048576&(c[2444212]|0)==1){a[(c[2386362]|0)+(b&32767)|0]=(b&3|0)==3?-1:d;return}if((b&-4096|0)==4194304){f=c[2387084]|0;a[f+(b&4095)|0]=d;g=e[f+(b&4094)>>1]|0;f=g>>>7&30;h=f|g>>>14&1;i=g>>>3&30;j=g<<1&30;k=j|g>>>12&1;l=(i|g>>>13&1)<<3|i>>>2;i=b>>>1&2047;c[(c[2406976]|0)+(i<<2)>>2]=k<<3|j>>>2|l<<8|(h<<3|f>>>2)<<16;c[(c[3530096]|0)+(i<<2)>>2]=h<<11|k|l<<3&2016;return}if((b|0)==786433){l=d&255;c[3528744]=l&8;c[2443704]=l&4;c[2440226]=l<<4&1792;return}else if((b|0)==524288){c[3528322]=d&255;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12;return}else if((b|0)==524295){c[2433666]=d<<24>>24==7?255:0;return}else{return}}function dsC(a){a=a|0;return 0}function dsD(b){b=b|0;var c=0;if((b|0)==983048|(b|0)==983049){c=a[9635441]|0}else if((b|0)==786432|(b|0)==786433){c=a[9550722]|0}else if((b|0)==524288){c=a[9550721]|0}else if((b|0)==917504|(b|0)==917505|(b|0)==950272|(b|0)==950273){c=-1}else if((b|0)==983040|(b|0)==983041){c=a[9635440]|0}else if((b|0)==524289){c=a[9550720]|0}else{c=0}return c|0}function dsE(b){b=b|0;var e=0,f=0,g=0,h=0;if((b|0)==819200){e=(1<<c[2406818]^255)&255;return e|0}else if((b|0)==983048|(b|0)==983049){e=a[9635441]|0;return e|0}else if((b|0)==1015808){e=1;return e|0}else if((b|0)==851968){f=c[2406820]|0;g=(f|0)==8?254:255;h=(f|0)==9?g-2|0:g;g=(f|0)==10?h-4|0:h;h=(f|0)==11?g-8|0:g;g=c[2406818]|0;f=(g|0)==8?h-16|0:h;h=(g|0)==9?f-32|0:f;f=(g|0)==10?h-64|0:h;if((g|0)!=11){e=f&255;return e|0}e=f+128&255;return e|0}else if((b|0)==983040|(b|0)==983041){e=a[9635440]|0;return e|0}else if((b|0)==524289|(b|0)==524291|(b|0)==524293){e=((d[9550720+(b>>>1&3)|0]|0)^c[2433666])&255;return e|0}else if((b|0)==786432){e=(1<<c[2406820]^255)&255;return e|0}else{e=0;return e|0}return 0}function dsF(a,b){a=a|0;b=b|0;return}function dsG(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=b&65535;b=f&255;if((b|0)==128){g=c[2418506]|0;c[2424874]=g;h=g+9|0;g=a[h]|0;a[h]=e<<24>>24!=0|0;if(g<<24>>24==0){return}if((a[(c[2424874]|0)+9|0]|0)!=0){return}Vl();return}else if((b|0)==0|(b|0)==32){g=c[3540984]|0;if((f&32|0)==0){a[g+5885|0]=e;return}f=c[g+5876>>2]|0;if((f|0)!=0){gg[f&4095](c[g+5880>>2]|0,0)}lH(g,d[g+5885|0]|0,e&255);return}else if((b|0)==64){b=c[2418506]|0;a[b+8|0]=e;c[2424874]=b;e=b+10|0;g=a[e]|0;a[e]=0;e=c[2424874]|0;f=e+16|0;do{if((a[f]|g)<<24>>24==0){if((a[e+10|0]|0)==0){i=b;break}if((a[e+9|0]|0)==0){i=b;break}a[f]=2;if(!(a[635136]|0)){i=b;break}h=a[(c[2424874]|0)+11|0]|0;Vk();j=c[2424874]|0;k=a[j+11|0]|0;if(h<<24>>24==k<<24>>24){i=b;break}h=c[j+12>>2]|0;if((h|0)==0){i=b;break}gf[h&2047](k&255);i=c[2418506]|0}else{i=b}}while(0);c[2424874]=i;b=i+10|0;i=a[b]|0;a[b]=1;b=c[2424874]|0;f=b+16|0;if((a[f]|i)<<24>>24!=0){return}if((a[b+10|0]|0)==0){return}if((a[b+9|0]|0)==0){return}a[f]=2;if(!(a[635136]|0)){return}f=a[(c[2424874]|0)+11|0]|0;Vk();b=c[2424874]|0;i=a[b+11|0]|0;if(f<<24>>24==i<<24>>24){return}f=c[b+12>>2]|0;if((f|0)==0){return}gf[f&2047](i&255);return}else{return}}function dsH(a){a=a|0;var b=0;if(a<<16>>16!=-2048){b=0;return b|0}b=c[3528322]&255;return b|0}function dsI(b){b=b|0;var e=0,f=0,g=0;if((b&255)!=0){e=0;return e|0}b=c[3540984]|0;f=(d[b+5887|0]|0|128)&(d[b+5886|0]|0);if((a[b+5884|0]&2)==0){g=f&255}else{g=(a[(c[b+5828>>2]|0)+100|0]&1|f)&255}e=g|6;return e|0}function dsJ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7341260+(b*112|0)>>2];c[a+104>>2]=c[7341264+(b*112|0)>>2];c[a+108>>2]=c[7341268+(b*112|0)>>2];d=0;return d|0}function dsK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=7341160+(b*112|0);e=0;return e|0}function dsL(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6934480+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dsM(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>44){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7387744+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dsN(){return dtn(0)|0}function dsO(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=a[7452584]|0;if(b){d=0;e=b&1;while(1){b=14163936+(d<<2)|0;f=c[b>>2]|0;g=c[2113006]|0;if((g|0)==0){h=79477}else{i=g-1|0;c[2113006]=i;if((i|0)==0){h=79477}}if((h|0)==79477){h=0;c[2383474]=0}if((f|0)==0){j=e}else{gGr(f);j=a[7452584]&1}c[b>>2]=0;b=d+1|0;if((b|0)<(j|0)){d=b;e=j}else{break}}}a[7452584]=0;c[2438224]=0;c[2433522]=0;c[2406672]=0;c[3528468]=0;j=c[2406688]|0;if((j|0)!=0){gGr(j);c[2406688]=0}c[2432972]=0;j=c[2418506]|0;if((j|0)!=0){gGr(j);c[2418506]=0}j=c[2418507]|0;if((j|0)!=0){gGr(j);c[2418507]=0}a[635136]=0;c[2113070]=0;c[2113068]=0;j=c[2112926]|0;if((j|0)!=0){gGr(j);c[2112926]=0}if((c[2392]|0)>=0){j=0;do{e=14130368+(j<<2)|0;d=c[e>>2]|0;if((d|0)!=0){gGr(d);c[e>>2]=0}e=14130384+(j<<2)|0;d=c[e>>2]|0;if((d|0)!=0){gGr(d);c[e>>2]=0}j=j+1|0;}while((j|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;fwZ();j=c[2426782]|0;e=0;while(1){if((e|0)>=1024){h=79501;break}k=9638528+(e<<2)|0;if((c[k>>2]|0)==(j|0)){break}else{e=e+1|0}}if((h|0)==79501){c[2426782]=0;c[2444212]=0;return 0}gGr(j);c[k>>2]=0;c[2426782]=0;c[2444212]=0;return 0}function dsP(){var f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((a[9624656]|0)!=0){a[9624656]=0;a[9547736]=1;f=c[2414738]|0;gGz(f|0,0,(c[2411770]|0)-f|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060]}RI();f=c[2394]|0;g=c[14130368+(f<<2)>>2]|0;if((g|0)!=0){gGC(g|0,9104152,280)|0}c[8452240+(f<<2)>>2]=c[2113054];c[2394]=-1;f=c[2439330]|0;g=(f|0)==0;if(!g){i=f;gGC(9706056,i|0,76)|0}i=c[2438118]|0;c[2433530]=i;j=c[3528484]|0;c[2076596]=j;k=c[2417276]|0;c[3541536]=k;c[1836236]=0;gGz(9706056,0,76);if(!g){g=f;gGC(g|0,9706056,76)|0}c[2438118]=i;c[3528484]=j;c[2417276]=k;c[1836236]=-1;c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;lw(c[3540984]|0);Vl();c[3528322]=0;c[3528744]=0;c[2443704]=0;c[2440226]=0;c[2433666]=0;c[2444141]=0;c[2444140]=0}a[9550722]=-1;a[9550721]=-1;a[9550720]=-1;k=0;j=-1;i=-1;g=-1;do{j=(d[9634056+k|0]<<k^j&255)&255;i=(d[9631848+k|0]<<k^i&255)&255;g=(d[9629784+k|0]<<k^g&255)&255;k=k+1|0;}while((k|0)<8);a[9550720]=j;a[9550721]=i;a[9550722]=g;g=(c[2444140]|0)-(e[4817936]|0)|0;c[2444140]=g;i=g>>>8&254^254;a[9550726]=i&255;g=(c[2444141]|0)-(e[4817937]|0)|0;c[2444141]=g;j=g>>>8&254^254;a[9550727]=j&255;g=c[2444212]|0;do{if((g|0)==3|(g|0)==1){k=i>>>4;f=c[2439408]|0;l=c[2406820]|0;if((k|0)<(f|0)){m=l+1|0;c[2406820]=m;n=m}else{n=l}if((k|0)>(f|0)){f=n-1|0;c[2406820]=f;o=f}else{o=n}c[2439408]=k;do{if((o|0)>11){c[2406820]=0}else{if((o|0)>=0){break}c[2406820]=11}}while(0);k=j>>>4;f=c[2439406]|0;l=c[2406818]|0;if((k|0)<(f|0)){m=l+1|0;c[2406818]=m;p=m}else{p=l}if((k|0)>(f|0)){f=p-1|0;c[2406818]=f;q=f}else{q=p}c[2439406]=k;if((q|0)>11){c[2406818]=0;break}if((q|0)>=0){break}c[2406818]=11}}while(0);q=(g|0)==1?15e4:166666;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060]}g=c[2439330]|0;if((g|0)!=0){p=g;gGC(9706056,p|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;p=c[2392]|0;if((p|0)>=0){gGz(8452240,0,((p|0)>0?(p<<2)+4|0:4)|0)}c[2113054]=0;p=c[2385548]|0;if((p|0)>0){gGz(9752472,0,((p|0)>1?p<<2:4)|0)}c[2433530]=0;c[2113056]=q;p=RG(q)|0;c[2113054]=(c[2113054]|0)+p;c[2276108]=-1;c[2113056]=-1;c[8452200+(c[2394]<<2)>>2]=8193;c[2276080]=256;if((c[2276079]|0)>>>0<256){RH(1)}p=c[2438224]|0;q=gGS(-747372544,31788,p,(p|0)<0|0?-1:0)|0;p=q;UF(66666)|0;q=c[2443826]|0;if((q|0)<1073676288){c[2443826]=q-p}q=c[2443827]|0;if((q|0)<1073676288){c[2443827]=q-p}q=(c[3528508]|0)-p|0;c[3528508]=(q|0)<0?0:q;q=c[2112964]|0;if((q|0)!=0){gg[c[3542112]&4095](q,a[9688]|0?534:0);Vj(0,c[2112964]|0,a[9688]|0?534:0)}q=c[1836236]|0;p=c[9757320+(q<<2)>>2]|0;if((p|0)!=0){g=p;gGC(g|0,9706056,76)|0}c[9752472+(q<<2)>>2]=c[2433530];c[14113936+(q<<2)>>2]=c[2076596];c[9669104+(q<<2)>>2]=c[3541536];c[1836236]=-1;q=c[2394]|0;g=c[14130368+(q<<2)>>2]|0;if((g|0)!=0){gGC(g|0,9104152,280)|0}c[8452240+(q<<2)>>2]=c[2113054];c[2394]=-1;if((c[2112968]|0)==0){return 0}dsQ()|0;return 0}function dsQ(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;if((a[9547736]|0)!=0){d=c[2406976]|0;e=c[3530096]|0;f=0;do{g=c[d+(f<<2)>>2]|0;c[e+(f<<2)>>2]=g>>8<<3&2016|g>>>3&31|g>>16<<8&63488;f=f+1|0;}while((f|0)<2048)}f=ag(c[2113068]|0,c[2113070]|0)|0;if((f|0)>0){e=c[2112926]|0;d=0;do{b[e+(d<<1)>>1]=2047;d=d+1|0;}while((d|0)<(f|0))}f=c[2444212]|0;do{if((f|0)==0){dtt(1,0);dtt(1,2048);dtt(2,0);dtt(2,2048);dtt(0,0);dtt(0,2048);h=c[2386182]|0}else{dtu(8,8192,0);dtu(8,8192,2048);dtu(12,12288,0);dtu(12,12288,2048);dtu(4,4096,0);dtu(4,4096,2048);d=c[2386182]|0;if((f&1|0)==0){h=d;break}e=c[2443558]|0;g=c[2112926]|0;i=c[2408648]|0;j=0;do{k=j<<2&248;l=j>>>3&248;m=(c[3528744]|0)==0;if(m){n=l;o=k}else{n=l^248;o=k^248}k=o-16|0;do{if(k>>>0<=223){l=b[d+(j<<1)>>1]|0;p=l&65535;q=l<<16>>16==-32513;l=q?7:p>>>12;r=q?714:p&4095;if((a[e+r|0]|0)!=0){break}if(m){Sq(g,r,n,k,l,4,0,0,i);break}else{Sw(g,r,n,k,l,4,0,0,i);break}}}while(0);j=j+2|0;}while((j|0)<2048);s=c[3530096]|0;R8(s);return 0}}while(0);n=c[2443558]|0;o=c[2112926]|0;f=c[2408648]|0;j=0;do{i=j<<2&248;g=j>>>3&248;e=(c[3528744]|0)==0;if(e){t=i;u=g}else{t=i^248;u=g^248}g=t-16|0;do{if(g>>>0<=223){i=b[h+(j<<1)>>1]&255|c[2440226];d=b[h+((j|1)<<1)>>1]&15;if((a[n+i|0]|0)!=0){break}if(e){Sq(o,i,u,g,d,4,0,0,f);break}else{Sw(o,i,u,g,d,4,0,0,f);break}}}while(0);j=j+2|0;}while((j|0)<2048);s=c[3530096]|0;R8(s);return 0}function dsR(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;e=i;i=i+272|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;l=e+80|0;m=e+96|0;n=e+112|0;o=e+128|0;p=e+144|0;q=e+160|0;r=e+176|0;s=e+192|0;t=e+208|0;u=e+224|0;v=e+240|0;w=e+256|0;x=(d|0)==0;if(!x){c[d>>2]=169602}do{if((b&32|0)!=0){gGz(w|0,0,12);y=c[2414738]|0;c[w>>2]=y;c[w+4>>2]=(c[2411770]|0)-y;c[w+12>>2]=162152;y=c[2076592]|0;gj[y&4095](w)|0;if((b&2|0)==0){break}a[9547736]=1}}while(0);if((b&64|0)==0){i=e;return 0}w=k|0;gGz(j|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){y=k+9|0;k=h;z=h|0;A=h+4|0;B=h+12|0;C=j|0;D=j+4|0;E=j+12|0;F=0;do{gGC(w|0,614896,11)|0;a[y]=F+48&255;G=8452256+(F<<2)|0;gGz(k|0,0,12);c[z>>2]=G;c[A>>2]=4;c[B>>2]=164976;gj[c[2076592]&4095](h)|0;if((c[G>>2]|0)!=0){c[C>>2]=c[14130368+(F<<2)>>2];c[D>>2]=c[8452184+(F<<2)>>2];c[E>>2]=w;G=c[2076592]|0;gj[G&4095](j)|0}F=F+1|0;}while((F|0)<=(c[2392]|0))}fw$(b);UQ(b,d);b=g|0;if(!x){c[d>>2]=169600}c[2424874]=c[2418506];cC(b|0,100600,(d=i,i=i+8|0,c[d>>2]=0,d)|0)|0;i=d;c[f>>2]=9699496;c[f+4>>2]=80;c[f+8>>2]=0;c[f+12>>2]=b;gj[c[2076592]&4095](f)|0;gGz(v|0,0,12);c[v>>2]=9734664;c[v+4>>2]=4;c[v+12>>2]=531832;gj[c[2076592]&4095](v)|0;gGz(u|0,0,12);c[u>>2]=14113288;c[u+4>>2]=4;c[u+12>>2]=191240;gj[c[2076592]&4095](u)|0;gGz(t|0,0,12);c[t>>2]=14114976;c[t+4>>2]=4;c[t+12>>2]=142288;gj[c[2076592]&4095](t)|0;gGz(s|0,0,12);c[s>>2]=9774816;c[s+4>>2]=4;c[s+12>>2]=528960;gj[c[2076592]&4095](s)|0;gGz(r|0,0,12);c[r>>2]=9760904;c[r+4>>2]=4;c[r+12>>2]=527960;gj[c[2076592]&4095](r)|0;gGz(q|0,0,12);c[q>>2]=9776560;c[q+4>>2]=4;c[q+12>>2]=473856;gj[c[2076592]&4095](q)|0;gGz(p|0,0,12);c[p>>2]=9776564;c[p+4>>2]=4;c[p+12>>2]=472176;gj[c[2076592]&4095](p)|0;gGz(o|0,0,12);c[o>>2]=9627280;c[o+4>>2]=4;c[o+12>>2]=523360;gj[c[2076592]&4095](o)|0;gGz(n|0,0,12);c[n>>2]=9757632;c[n+4>>2]=4;c[n+12>>2]=521368;gj[c[2076592]&4095](n)|0;gGz(m|0,0,12);c[m>>2]=9627272;c[m+4>>2]=4;c[m+12>>2]=519680;gj[c[2076592]&4095](m)|0;gGz(l|0,0,12);c[l>>2]=9757624;c[l+4>>2]=4;c[l+12>>2]=518056;gj[c[2076592]&4095](l)|0;i=e;return 0}function dsS(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7010156+(b*112|0)>>2];c[a+104>>2]=c[7010160+(b*112|0)>>2];c[a+108>>2]=c[7010164+(b*112|0)>>2];d=0;return d|0}function dsT(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=7010056+(b*112|0);e=0;return e|0}function dsU(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>41){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7160544+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dsV(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2314876+(b*112|0)>>2];c[a+104>>2]=c[2314880+(b*112|0)>>2];c[a+108>>2]=c[2314884+(b*112|0)>>2];d=0;return d|0}function dsW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=2314776+(b*112|0);e=0;return e|0}function dsX(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>23){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5344368+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dsY(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>41){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7384016+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dsZ(){return dtn(1)|0}function ds_(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2302444+(b*112|0)>>2];c[a+104>>2]=c[2302448+(b*112|0)>>2];c[a+108>>2]=c[2302452+(b*112|0)>>2];d=0;return d|0}function ds$(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=2302344+(b*112|0);e=0;return e|0}function ds0(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2304012+(b*112|0)>>2];c[a+104>>2]=c[2304016+(b*112|0)>>2];c[a+108>>2]=c[2304020+(b*112|0)>>2];d=0;return d|0}function ds1(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=2303912+(b*112|0);e=0;return e|0}function ds2(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2198132+(b*112|0)>>2];c[a+104>>2]=c[2198136+(b*112|0)>>2];c[a+108>>2]=c[2198140+(b*112|0)>>2];d=0;return d|0}function ds3(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=2198032+(b*112|0);e=0;return e|0}function ds4(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>38){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3357928+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function ds5(){return dtn(2)|0}function ds6(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2200932+(b*112|0)>>2];c[a+104>>2]=c[2200936+(b*112|0)>>2];c[a+108>>2]=c[2200940+(b*112|0)>>2];d=0;return d|0}function ds7(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=2200832+(b*112|0);e=0;return e|0}function ds8(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2196788+(b*112|0)>>2];c[a+104>>2]=c[2196792+(b*112|0)>>2];c[a+108>>2]=c[2196796+(b*112|0)>>2];d=0;return d|0}function ds9(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=2196688+(b*112|0);e=0;return e|0}function dta(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>38){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3358400+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dtb(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2199588+(b*112|0)>>2];c[a+104>>2]=c[2199592+(b*112|0)>>2];c[a+108>>2]=c[2199596+(b*112|0)>>2];d=0;return d|0}function dtc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=2199488+(b*112|0);e=0;return e|0}function dtd(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>27){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5862700+(b*112|0)>>2];c[a+104>>2]=c[5862704+(b*112|0)>>2];c[a+108>>2]=c[5862708+(b*112|0)>>2];d=0;return d|0}function dte(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<28&(d|0)==0)){e=1;return e|0}c[a>>2]=5862600+(b*112|0);e=0;return e|0}function dtf(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>41){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6874200+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dtg(){return dtn(3)|0}function dth(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>27){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4654780+(b*112|0)>>2];c[a+104>>2]=c[4654784+(b*112|0)>>2];c[a+108>>2]=c[4654788+(b*112|0)>>2];d=0;return d|0}function dti(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<28&(d|0)==0)){e=1;return e|0}c[a>>2]=4654680+(b*112|0);e=0;return e|0}function dtj(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>27){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4661052+(b*112|0)>>2];c[a+104>>2]=c[4661056+(b*112|0)>>2];c[a+108>>2]=c[4661060+(b*112|0)>>2];d=0;return d|0}function dtk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<28&(d|0)==0)){e=1;return e|0}c[a>>2]=4660952+(b*112|0);e=0;return e|0}function dtl(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>27){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4657916+(b*112|0)>>2];c[a+104>>2]=c[4657920+(b*112|0)>>2];c[a+108>>2]=c[4657924+(b*112|0)>>2];d=0;return d|0}function dtm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<28&(d|0)==0)){e=1;return e|0}c[a>>2]=4657816+(b*112|0);e=0;return e|0}function dtn(d){d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;e=i;i=i+600|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+488|0;c[2444212]=d;c[2426782]=0;c[2388034]=0;c[2439988]=262144;c[2385842]=524288;c[2408648]=589824;c[2408646]=720896;c[2443558]=7012352;c[2407128]=7014400;c[2414738]=7145472;c[2388056]=7145472;c[2386182]=7161856;c[2386362]=7165952;c[2387084]=7198720;c[2385860]=7202816;c[2406976]=7204864;c[2411770]=7213056;c[3530096]=7213056;d=0;while(1){if((d|0)>=1024){break}r=9638528+(d<<2)|0;if((c[r>>2]|0)==0){s=79799;break}else{d=d+1|0}}do{if((s|0)==79799){d=gGq(7221248)|0;c[r>>2]=d;if((d|0)==0){break}c[2426782]=d;gGz(d|0,0,7221248);c[2388034]=d;c[2439988]=d+262144;t=d+524288|0;c[2385842]=t;u=d+589824|0;c[2408648]=u;v=d+720896|0;c[2408646]=v;c[2443558]=d+7012352;w=d+7014400|0;c[2407128]=w;x=d+7145472|0;c[2414738]=x;c[2388056]=x;c[2386182]=d+7161856;c[2386362]=d+7165952;c[2387084]=d+7198720;c[2385860]=d+7202816;c[2406976]=d+7204864;x=d+7213056|0;c[2411770]=x;c[3530096]=x;c[2414318]=d+7221248;L97548:do{if((gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](p,0,0)|0)==0){x=q+108|0;y=q+100|0;z=n+108|0;A=n+100|0;B=l+108|0;C=l+100|0;D=j+108|0;E=j+100|0;F=f+108|0;G=f+100|0;H=d;I=t;J=u;K=v;L=w;M=0;L97550:while(1){gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](q,M)|0;switch(c[x>>2]&7|0){case 2:{if((c[3542200]|0)==0){N=1;s=79871;break L97550}c[z>>2]=0;c[A>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,M)|0;if((c[z>>2]|0)!=0){O=c[A>>2]|0;c[o>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](o,M,0)|0;if((O|0)<1){N=1;s=79864;break L97550}if((gzL(I,0,M)|0)!=0){N=1;s=79879;break L97550}}Q=M;R=L;S=K;T=J;U=I+(c[y>>2]|0)|0;V=H;break};case 3:{if((c[3542200]|0)==0){N=1;s=79876;break L97550}c[B>>2]=0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,M)|0;if((c[B>>2]|0)!=0){O=c[C>>2]|0;c[m>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](m,M,0)|0;if((O|0)<1){N=1;s=79872;break L97550}if((gzL(J,0,M)|0)!=0){N=1;s=79866;break L97550}}Q=M;R=L;S=K;T=J+(c[y>>2]|0)|0;U=I;V=H;break};case 4:{if((c[3542200]|0)==0){N=1;s=79878;break L97550}c[D>>2]=0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,M)|0;if((c[D>>2]|0)!=0){O=c[E>>2]|0;c[k>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](k,M,0)|0;if((O|0)<1){N=1;s=79875;break L97550}if((gzL(K,0,M)|0)!=0){N=1;s=79882;break L97550}}Q=M;R=L;S=K+(c[y>>2]|0)|0;T=J;U=I;V=H;break};case 5:{if((c[3542200]|0)==0){N=1;s=79880;break L97550}c[F>>2]=0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,M)|0;if((c[F>>2]|0)!=0){O=c[G>>2]|0;c[g>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](g,M,0)|0;if((O|0)<1){N=1;s=79877;break L97550}if((gzL(L,0,M)|0)!=0){N=1;s=79869;break L97550}}Q=M;R=L+(c[y>>2]|0)|0;S=K;T=J;U=I;V=H;break};case 1:{if((R6(H+1|0,M,2)|0)!=0){N=1;s=79883;break L97550}O=M+1|0;if((R6(H,O,2)|0)!=0){N=1;s=79865;break L97550}Q=O;R=L;S=K;T=J;U=I;V=H+(c[y>>2]<<1)|0;break};default:{Q=M;R=L;S=K;T=J;U=I;V=H}}O=Q+1|0;if((gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](p,O,0)|0)==0){H=V;I=U;J=T;K=S;L=R;M=O}else{break L97548}}if((s|0)==79869){i=e;return N|0}else if((s|0)==79880){i=e;return N|0}else if((s|0)==79876){i=e;return N|0}else if((s|0)==79865){i=e;return N|0}else if((s|0)==79879){i=e;return N|0}else if((s|0)==79882){i=e;return N|0}else if((s|0)==79877){i=e;return N|0}else if((s|0)==79875){i=e;return N|0}else if((s|0)==79864){i=e;return N|0}else if((s|0)==79872){i=e;return N|0}else if((s|0)==79866){i=e;return N|0}else if((s|0)==79871){i=e;return N|0}else if((s|0)==79878){i=e;return N|0}else if((s|0)==79883){i=e;return N|0}}}while(0);w=c[2444212]|0;do{if((w|0)==0){if((dts(608272,608208,608144,256)|0)==0){dto();break}else{N=1;i=e;return N|0}}else if((w|0)==2){if((dts(608112,608048,607984,512)|0)==0){dto();break}else{N=1;i=e;return N|0}}else if((w|0)==1){if((dts(608112,608048,607984,512)|0)==0){dtp();break}else{N=1;i=e;return N|0}}else if((w|0)==3){if((dts(605920,605856,605792,256)|0)==0){dtp();break}else{N=1;i=e;return N|0}}}while(0);fwR(0);w=c[2439330]|0;v=(w|0)==0;if(!v){u=w;gGC(9706056,u|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];u=c[3528484]|0;c[2076596]=u;t=c[2417276]|0;c[3541536]=t;c[1836236]=0;d=c[2385842]|0;M=0;L=0;while(1){c[w+76+(L<<2)>>2]=d+(L<<8);K=M+1&65535;if((K&65535)>239){W=0;X=0;break}else{M=K;L=K&65535}}while(1){L=d+(X<<8)|0;c[w+76+(X+512<<2)>>2]=L;c[w+76+(X+768<<2)>>2]=L;L=W+1&65535;if((L&65535)>239){break}else{W=L;X=L&65535}}d=c[2385860]|0;c[w+1036>>2]=d;L=d+256|0;c[w+1040>>2]=L;M=d+512|0;c[w+1044>>2]=M;K=d+768|0;c[w+1048>>2]=K;J=d+1024|0;c[w+1052>>2]=J;I=d+1280|0;c[w+1056>>2]=I;H=d+1536|0;c[w+1060>>2]=H;y=d+1792|0;c[w+1064>>2]=y;c[w+2060>>2]=d;c[w+2064>>2]=L;c[w+2068>>2]=M;c[w+2072>>2]=K;c[w+2076>>2]=J;c[w+2080>>2]=I;c[w+2084>>2]=H;c[w+2088>>2]=y;c[w+3084>>2]=d;c[w+4108>>2]=d;c[w+3088>>2]=L;c[w+4112>>2]=L;c[w+3092>>2]=M;c[w+4116>>2]=M;c[w+3096>>2]=K;c[w+4120>>2]=K;c[w+3100>>2]=J;c[w+4124>>2]=J;c[w+3104>>2]=I;c[w+4128>>2]=I;c[w+3108>>2]=H;c[w+4132>>2]=H;c[w+3112>>2]=y;c[w+4136>>2]=y;c[w+4184>>2]=1698;c[w+4180>>2]=2352;c[w+4172>>2]=2660;c[w+4176>>2]=2154;if(!v){y=w;gGC(y|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=u;c[2417276]=t;c[1836236]=-1;UL(4e6,3046,316,0);c[2438224]=4e6;c[2433522]=3416;c[2406672]=1752;c[3528468]=9362;c[2443842]=511;h[745398]=1.0;a[3203264]=1;y=c[2407128]|0;H=gGq(80)|0;I=H;c[2418506]=I;c[2424874]=I;gGz(H|0,0,80);a[635136]=0;c[H+4>>2]=~~(16.0e4/(a[9680]|0?32.0e3:0.0)*4194304.0);a[H+16|0]=0;if((y|0)==0){a[635136]=1}else{c[H+52>>2]=y}a[H+9|0]=1;a[(c[2424874]|0)+10|0]=1;y=c[2424874]|0;h[y+64>>3]=1.0;c[y+72>>2]=3;Vl();c[2424874]=I;h[H+64>>3]=.5;c[H+72>>2]=3;a[9624656]=0;a[9547736]=1;H=c[2414738]|0;gGz(H|0,0,(c[2411770]|0)-H|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];H=c[3532592]|0;if((H|0)!=0){gGC(9104152,H|0,280)|0}c[2113054]=c[2113060]}RI();H=c[2394]|0;I=c[14130368+(H<<2)>>2]|0;if((I|0)!=0){gGC(I|0,9104152,280)|0}c[8452240+(H<<2)>>2]=c[2113054];c[2394]=-1;H=c[2439330]|0;I=(H|0)==0;if(!I){y=H;gGC(9706056,y|0,76)|0}y=c[2438118]|0;c[2433530]=y;J=c[3528484]|0;c[2076596]=J;K=c[2417276]|0;c[3541536]=K;c[1836236]=0;gGz(9706056,0,76);if(!I){I=H;gGC(I|0,9706056,76)|0}c[2438118]=y;c[3528484]=J;c[2417276]=K;c[1836236]=-1;c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;lw(c[3540984]|0);Vl();c[3528322]=0;c[3528744]=0;c[2443704]=0;c[2440226]=0;c[2433666]=0;c[2444141]=0;c[2444140]=0;K=c[642608+(c[2436]<<2)>>2]|0;J=c[K+128>>2]|0;if((c[K+52>>2]&4|0)==0){c[2113068]=J;y=c[K+132>>2]|0;c[2113070]=y;c[2443814]=J;c[2440436]=y;Y=J;Z=y}else{c[2113070]=J;y=c[K+132>>2]|0;c[2113068]=y;c[2440436]=J;c[2443814]=y;Y=y;Z=J}J=ag(Y<<1,Z)|0;y=gGq(J)|0;c[2112926]=y;if((y|0)==0){N=0;i=e;return N|0}gGz(y|0,0,J|0);N=0;i=e;return N|0}}while(0);c[2426782]=0;N=1;i=e;return N|0}function dto(){var a=0,b=0,d=0,e=0,f=0,g=0;fxU(0,425984);if((c[2394]|0)==0){a=c[2112932]|0}else{c[2394]=0;b=c[3532596]|0;c[2112932]=b;d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];a=b}b=c[2388034]|0;d=a|0;e=0;while(1){f=b+e|0;c[d>>2]=f;c[d+131072>>2]=f;f=e+1024|0;if(f>>>0>262143){break}else{d=d+4|0;e=f}}e=c[2388056]|0;c[a+1024>>2]=e;c[a+66560>>2]=e;c[a+132096>>2]=e;d=e+1024|0;c[a+1028>>2]=d;c[a+66564>>2]=d;c[a+132100>>2]=d;d=e+2048|0;c[a+1032>>2]=d;c[a+66568>>2]=d;c[a+132104>>2]=d;d=e+3072|0;c[a+1036>>2]=d;c[a+66572>>2]=d;c[a+132108>>2]=d;d=e+4096|0;c[a+1040>>2]=d;c[a+66576>>2]=d;c[a+132112>>2]=d;d=e+5120|0;c[a+1044>>2]=d;c[a+66580>>2]=d;c[a+132116>>2]=d;d=e+6144|0;c[a+1048>>2]=d;c[a+66584>>2]=d;c[a+132120>>2]=d;d=e+7168|0;c[a+1052>>2]=d;c[a+66588>>2]=d;c[a+132124>>2]=d;d=e+8192|0;c[a+1056>>2]=d;c[a+66592>>2]=d;c[a+132128>>2]=d;d=e+9216|0;c[a+1060>>2]=d;c[a+66596>>2]=d;c[a+132132>>2]=d;d=e+10240|0;c[a+1064>>2]=d;c[a+66600>>2]=d;c[a+132136>>2]=d;d=e+11264|0;c[a+1068>>2]=d;c[a+66604>>2]=d;c[a+132140>>2]=d;d=e+12288|0;c[a+1072>>2]=d;c[a+66608>>2]=d;c[a+132144>>2]=d;d=e+13312|0;c[a+1076>>2]=d;c[a+66612>>2]=d;c[a+132148>>2]=d;d=e+14336|0;c[a+1080>>2]=d;c[a+66616>>2]=d;c[a+132152>>2]=d;d=e+15360|0;c[a+1084>>2]=d;c[a+66620>>2]=d;c[a+132156>>2]=d;d=c[2386182]|0;c[a+4096>>2]=d;c[a+69632>>2]=d;c[a+135168>>2]=d;e=d+1024|0;c[a+4100>>2]=e;c[a+69636>>2]=e;c[a+135172>>2]=e;e=d+2048|0;c[a+4104>>2]=e;c[a+69640>>2]=e;c[a+135176>>2]=e;e=d+3072|0;c[a+4108>>2]=e;c[a+69644>>2]=e;c[a+135180>>2]=e;e=c[2386362]|0;d=a+8192|0;b=2097152;while(1){f=e+(b-2097152)|0;c[d>>2]=f;c[d+65536>>2]=f;c[d+131072>>2]=f;f=b+1024|0;if(f>>>0>2129919){break}else{d=d+4|0;b=f}}b=c[2387084]|0;c[a+16384>>2]=b;c[a+147456>>2]=b;d=b+1024|0;c[a+16388>>2]=d;c[a+147460>>2]=d;d=b+2048|0;c[a+16392>>2]=d;c[a+147464>>2]=d;d=b+3072|0;c[a+16396>>2]=d;c[a+147468>>2]=d;c[a+196648>>2]=3200;c[a+196728>>2]=2266;c[a+196608>>2]=1858;c[a+196688>>2]=1720;a=c[3532592]|0;if((a|0)==0){g=c[2113054]|0;c[2113060]=g;c[2394]=-1;return}gGC(a|0,9104152,280)|0;g=c[2113054]|0;c[2113060]=g;c[2394]=-1;return}function dtp(){var a=0,b=0,d=0,e=0,f=0,g=0;fxU(0,425984);if((c[2394]|0)==0){a=c[2112932]|0}else{c[2394]=0;b=c[3532596]|0;c[2112932]=b;d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];a=b}b=c[2388034]|0;d=a|0;e=0;while(1){f=b+e|0;c[d>>2]=f;c[d+131072>>2]=f;f=e+1024|0;if(f>>>0>262143){break}else{d=d+4|0;e=f}}e=c[2388056]|0;c[a+1024>>2]=e;c[a+66560>>2]=e;c[a+132096>>2]=e;d=e+1024|0;c[a+1028>>2]=d;c[a+66564>>2]=d;c[a+132100>>2]=d;d=e+2048|0;c[a+1032>>2]=d;c[a+66568>>2]=d;c[a+132104>>2]=d;d=e+3072|0;c[a+1036>>2]=d;c[a+66572>>2]=d;c[a+132108>>2]=d;d=e+4096|0;c[a+1040>>2]=d;c[a+66576>>2]=d;c[a+132112>>2]=d;d=e+5120|0;c[a+1044>>2]=d;c[a+66580>>2]=d;c[a+132116>>2]=d;d=e+6144|0;c[a+1048>>2]=d;c[a+66584>>2]=d;c[a+132120>>2]=d;d=e+7168|0;c[a+1052>>2]=d;c[a+66588>>2]=d;c[a+132124>>2]=d;d=e+8192|0;c[a+1056>>2]=d;c[a+66592>>2]=d;c[a+132128>>2]=d;d=e+9216|0;c[a+1060>>2]=d;c[a+66596>>2]=d;c[a+132132>>2]=d;d=e+10240|0;c[a+1064>>2]=d;c[a+66600>>2]=d;c[a+132136>>2]=d;d=e+11264|0;c[a+1068>>2]=d;c[a+66604>>2]=d;c[a+132140>>2]=d;d=e+12288|0;c[a+1072>>2]=d;c[a+66608>>2]=d;c[a+132144>>2]=d;d=e+13312|0;c[a+1076>>2]=d;c[a+66612>>2]=d;c[a+132148>>2]=d;d=e+14336|0;c[a+1080>>2]=d;c[a+66616>>2]=d;c[a+132152>>2]=d;d=e+15360|0;c[a+1084>>2]=d;c[a+66620>>2]=d;c[a+132156>>2]=d;d=c[2386362]|0;e=a+4096|0;b=1048576;while(1){f=d+(b-1048576)|0;c[e>>2]=f;c[e+131072>>2]=f;f=b+1024|0;if(f>>>0>1081343){break}else{e=e+4|0;b=f}}b=c[2386182]|0;c[a+8192>>2]=b;c[a+73728>>2]=b;c[a+139264>>2]=b;e=b+1024|0;c[a+8196>>2]=e;c[a+73732>>2]=e;c[a+139268>>2]=e;d=b+2048|0;c[a+8200>>2]=d;c[a+73736>>2]=d;c[a+139272>>2]=d;f=b+3072|0;c[a+8204>>2]=f;c[a+73740>>2]=f;c[a+139276>>2]=f;c[a+73744>>2]=b;c[a+73748>>2]=e;c[a+73752>>2]=d;c[a+73756>>2]=f;f=c[2439988]|0;d=a+12288|0;e=3145728;while(1){b=f+(e-3145728)|0;c[d>>2]=b;c[d+131072>>2]=b;b=e+1024|0;if(b>>>0>3407871){break}else{d=d+4|0;e=b}}e=c[2387084]|0;c[a+16384>>2]=e;c[a+147456>>2]=e;d=e+1024|0;c[a+16388>>2]=d;c[a+147460>>2]=d;d=e+2048|0;c[a+16392>>2]=d;c[a+147464>>2]=d;d=e+3072|0;c[a+16396>>2]=d;c[a+147468>>2]=d;c[a+196648>>2]=3200;c[a+196728>>2]=2266;c[a+196608>>2]=3104;c[a+196688>>2]=1720;a=c[3532592]|0;if((a|0)==0){g=c[2113054]|0;c[2113060]=g;c[2394]=-1;return}gGC(a|0,9104152,280)|0;g=c[2113054]|0;c[2113060]=g;c[2394]=-1;return}function dtq(b,c){b=b|0;c=c|0;a[9706117]=(c|0)!=0|0;return}function dtr(a){a=a|0;var b=0,d=0;b=(c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,4e6,0)|0;return a|0}function dts(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;h=0;while(1){if((h|0)>=1024){i=1;j=79948;break}k=9638528+(h<<2)|0;if((c[k>>2]|0)==0){break}else{h=h+1|0}}if((j|0)==79948){return i|0}h=gGq(3145728)|0;c[k>>2]=h;if((h|0)==0){i=1;return i|0}gGz(h|0,0,3145728);k=c[2408648]|0;gGC(h|0,k|0,65536)|0;l=0;do{m=l<<6;gGz(k+m|0,0,64);n=l<<7;o=0;do{p=1<<3-o;q=(c[613104+(o<<2)>>2]|0)+n|0;r=0;do{s=q+(c[1238464+(r<<2)>>2]|0)|0;t=(r<<3)+m|0;u=0;do{v=s+(c[600544+(u<<2)>>2]|0)|0;if((d[h+((v|0)/8|0)|0]&128>>>((v&7)>>>0)|0)!=0){v=k+(t+u)|0;a[v]=(d[v]|p)&255}u=u+1|0;}while((u|0)<8);r=r+1|0;}while((r|0)<8);o=o+1|0;}while((o|0)<4);l=l+1|0;}while((l|0)<2048);l=c[2408646]|0;gGC(h|0,l|0,3145728)|0;o=0;while(1){m=o<<8;gGz(l+m|0,0,256);n=ag(o,g)|0;r=0;do{p=1<<3-r;q=(c[b+(r<<2)>>2]|0)+n|0;u=0;do{t=q+(c[f+(u<<2)>>2]|0)|0;s=(u<<4)+m|0;v=0;do{w=t+(c[e+(v<<2)>>2]|0)|0;if((d[h+((w|0)/8|0)|0]&128>>>((w&7)>>>0)|0)!=0){w=l+(s+v)|0;a[w]=(d[w]|p)&255}v=v+1|0;}while((v|0)<16);u=u+1|0;}while((u|0)<16);r=r+1|0;}while((r|0)<4);r=o+1|0;if((r|0)<24576){o=r}else{x=0;break}}while(1){if((x|0)>=1024){y=k;break}z=9638528+(x<<2)|0;if((c[z>>2]|0)==(h|0)){j=79942;break}else{x=x+1|0}}if((j|0)==79942){gGr(h);c[z>>2]=0;y=c[2408648]|0}z=c[2443558]|0;gGz(z|0,1,2048);h=0;while(1){if((a[y+h|0]|0)==0){A=h}else{a[z+(h>>6)|0]=0;A=h|63}j=A+1|0;if((j|0)<131072){h=j}else{i=0;break}}return i|0}function dtt(a,d){a=a|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;f=c[2386362]|0;g=d+2048|0;h=a<<2;i=h+4|0;j=h+6|0;h=a<<12;a=h+4096|0;k=h+4098|0;h=c[2112926]|0;l=c[2408646]|0;m=d;d=c[3528744]|0;while(1){n=e[f+(j+m>>1<<1)>>1]|0;o=(n>>>12|(e[f+(i+m>>1<<1)>>1]|0)<<4)+256&511;p=768-(n+256&511)|0;if((d|0)==0){q=o-256|0;r=p-512|0}else{q=496-o|0;r=752-p|0}p=a+m|0;o=k+m|0;if((q+15|0)>>>0<271){n=r-16|0;s=0;t=d;while(1){u=b[f+(p+s>>1<<1)>>1]&127;do{if((u|0)!=0){v=e[f+(o+s>>1<<1)>>1]|0;w=v&16384;x=v&16383;if((t|0)==0){y=v&32768;z=w}else{y=v>>>15^1;z=w>>>14^1}if((n+15|0)>>>0>=239){break}w=(z|0)!=0;if((y|0)==0){if(w){SJ(h,x,q,n,u,4,0,0,l);break}else{SH(h,x,q,n,u,4,0,0,l);break}}else{if(w){SN(h,x,q,n,u,4,0,0,l);break}else{SL(h,x,q,n,u,4,0,0,l);break}}}}while(0);u=c[3528744]|0;if((u|0)==0){x=n+16|0;A=(x|0)>256?n-496|0:x}else{x=n-16|0;A=(x|0)<-256?n+496|0:x}x=s+4|0;if((x|0)<128){n=A;s=x;t=u}else{B=u;break}}}else{B=d}t=m+128|0;if((t|0)<(g|0)){m=t;d=B}else{break}}return}function dtu(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;g=c[2386362]|0;h=f+2048|0;i=d+2|0;j=c[2112926]|0;k=c[2408646]|0;l=f;f=c[3528744]|0;while(1){m=l+a|0;n=e[g+(m+2>>1<<1)>>1]|0;o=(n>>>12|(e[g+(m>>1<<1)>>1]|0)<<4)+256&511;m=768-(n+256&511)|0;if((f|0)==0){p=o-256|0;q=m-512|0}else{p=496-o|0;q=752-m|0}m=l+d|0;o=i+l|0;n=(p+15|0)>>>0<271;r=q-16|0;s=0;t=f;L97785:while(1){u=b[g+(m+s>>1<<1)>>1]&127;do{if((u|0)!=0){v=e[g+(o+s>>1<<1)>>1]|0;w=(c[2443704]|0)==0;x=v&32768;y=w?x:0;z=w?0:x;if((t|0)==0){A=z;B=y}else{A=z>>>15^1;B=y>>>15^1}y=v&32767;if(y>>>0>24575){C=t;break L97785}if(!n){break}if((r+15|0)>>>0>=239){break}v=(B|0)!=0;if((A|0)==0){if(v){SJ(j,y,p,r,u,4,0,0,k);break}else{SH(j,y,p,r,u,4,0,0,k);break}}else{if(v){SN(j,y,p,r,u,4,0,0,k);break}else{SL(j,y,p,r,u,4,0,0,k);break}}}}while(0);u=c[3528744]|0;if((u|0)==0){y=r+16|0;D=(y|0)>256?r-496|0:y}else{y=r-16|0;D=(y|0)<-256?r+496|0:y}y=s+4|0;if((y|0)<128){r=D;s=y;t=u}else{C=u;break}}t=l+128|0;if((t|0)<(h|0)){l=t;f=C}else{break}}return}function dtv(b){b=b|0;var c=0,d=0;c=b&255;if((c|0)==0){d=a[9635432]|0}else if((c|0)==1){d=a[9550056]|0}else if((c|0)==2){d=a[9549872]|0}else{d=0}return d|0}function dtw(b,d){b=b|0;d=d|0;var e=0;e=b&255;if((e|0)==6){c[3542228]=d&15;return}else if((e|0)==0){c[2388382]=0;return}else if((e|0)==1){a[c[2438778]|0]=d<<1&16;return}else if((e|0)==2){e=d&255;b=c[3542228]|0;if((b|0)>15){return}do{if((b|0)<14){if((b|0)!=13){if((a[14168916+b|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(0,b,e);return}else{return}}function dtx(b){b=b|0;var c=0,d=0;c=b&65535;switch(c&255|0){case 16:case 17:case 18:case 19:{d=S3(0,c&3)|0;break};case 56:{d=a[9635432]|0;break};default:{d=0}}return d|0}function dty(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=b&65535;switch(f&255|0){case 32:case 33:case 34:case 35:case 36:{b=c[2440006]|0;g=(a[b]|0)+((f&4|0)==0?3:1)&3;a[b]=g;h=c[2385958]|0;i=(g&255)<<16;g=c[9757320+(c[1836236]<<2)>>2]|0;j=0;k=0;while(1){c[g+76+(k<<2)>>2]=h+((k<<8)+i);l=j+1&65535;if((l&65535)>95){break}else{j=l;k=l&65535}}k=d[b]<<16;b=0;j=0;while(1){i=h+((j<<8)+k)|0;c[g+76+(j+512<<2)>>2]=i;c[g+76+(j+768<<2)>>2]=i;i=b+1&65535;if((i&65535)>95){break}else{b=i;j=i&65535}}return};case 52:{j=e&255;b=c[3542228]|0;if((b|0)>15){return}do{if((b|0)<14){if((b|0)!=13){if((a[14168916+b|0]|0)==e<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(0,b,j);return};case 16:case 17:case 18:case 19:{S4(0,f&3,e);return};case 60:{c[3542228]=e&15;return};case 64:{c[2388382]=0;return};default:{return}}}function dtz(){return a[9549872]|0}function dtA(b){b=b|0;var d=0,e=0,f=0,g=0,h=0;d=b&1;a[c[2438854]|0]=d&255;b=d<<12;d=b|24576;e=c[2385958]|0;f=c[9757320+(c[1836236]<<2)>>2]|0;g=d-24576|0;c[f+460>>2]=e+d;c[f+464>>2]=e+(b|24832);c[f+468>>2]=e+(b|25088);c[f+472>>2]=e+(b|25344);c[f+476>>2]=e+(b|25600);c[f+480>>2]=e+(b|25856);c[f+484>>2]=e+(b|26112);c[f+488>>2]=e+(b|26368);c[f+492>>2]=e+(b|26624);c[f+496>>2]=e+(b|26880);c[f+500>>2]=e+(b|27136);c[f+504>>2]=e+(b|27392);c[f+508>>2]=e+(b|27648);c[f+512>>2]=e+(b|27904);c[f+516>>2]=e+(b|28160);c[f+520>>2]=e+(b|28416);b=96;d=96;while(1){h=e+(g+(d<<8))|0;c[f+76+(d+512<<2)>>2]=h;c[f+76+(d+768<<2)>>2]=h;h=b+1&65535;if((h&65535)>111){break}else{b=h;d=h&65535}}return}function dtB(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4544820+(b*112|0)>>2];c[a+104>>2]=c[4544824+(b*112|0)>>2];c[a+108>>2]=c[4544828+(b*112|0)>>2];d=0;return d|0}function dtC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=4544720+(b*112|0);e=0;return e|0}function dtD(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1833440+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dtE(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>24){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5287352+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dtF(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0.0,U=0,V=0;e=i;i=i+960|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;c[2415030]=0;c[2385958]=0;c[3531030]=262144;c[2406974]=262176;c[3530094]=262304;c[2439108]=262432;x=a[9688]|0?1068:0;y=x+262432|0;c[2439109]=y;z=y+x|0;c[2439110]=z;y=z+x|0;x=y|0;c[2414736]=x;c[2386112]=x;c[2386246]=y+4096;c[2438778]=y+36864;c[2440006]=y+36865;c[2438854]=y+36866;x=y+36867|0;c[2411768]=x;c[2414316]=x;y=x;x=0;while(1){if((x|0)>=1024){break}A=9638528+(x<<2)|0;if((c[A>>2]|0)==0){B=80077;break}else{x=x+1|0}}do{if((B|0)==80077){x=gGq(y)|0;c[A>>2]=x;if((x|0)==0){break}gGz(x|0,0,y|0);c[2415030]=x;gGz(x|0,0,y|0);c[2385958]=x;c[3531030]=x+262144;c[2406974]=x+262176;c[3530094]=x+262304;c[2439108]=x+262432;z=a[9688]|0?1068:0;C=z+262432|0;c[2439109]=x+C;D=C+z|0;c[2439110]=x+D;C=D+z|0;z=x+C|0;c[2414736]=z;c[2386112]=z;c[2386246]=x+(C+4096);c[2438778]=x+(C+36864);c[2440006]=x+(C+36865);c[2438854]=x+(C+36866);z=x+(C+36867)|0;c[2411768]=z;c[2414316]=z;if((c[3542200]|0)==0){E=1;i=e;return E|0}z=v+108|0;c[z>>2]=0;C=v+100|0;c[C>>2]=0;D=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[D&16383](v,0)|0;do{if((c[z>>2]|0)!=0){D=c[C>>2]|0;c[w>>2]=9534384;F=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[F&16383](w,0,0)|0;if((D|0)<1){E=1;i=e;return E|0}if((gzL(x,0,0)|0)==0){break}else{E=1}i=e;return E|0}}while(0);x=(c[2385958]|0)+4096|0;if((c[3542200]|0)==0){E=1;i=e;return E|0}C=t+108|0;c[C>>2]=0;z=t+100|0;c[z>>2]=0;D=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[D&16383](t,1)|0;do{if((c[C>>2]|0)!=0){D=c[z>>2]|0;c[u>>2]=9534384;F=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[F&16383](u,1,0)|0;if((D|0)<1){E=1;i=e;return E|0}if((gzL(x,0,1)|0)==0){break}else{E=1}i=e;return E|0}}while(0);x=(c[2385958]|0)+8192|0;if((c[3542200]|0)==0){E=1;i=e;return E|0}z=r+108|0;c[z>>2]=0;C=r+100|0;c[C>>2]=0;D=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[D&16383](r,2)|0;do{if((c[z>>2]|0)!=0){D=c[C>>2]|0;c[s>>2]=9534384;F=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[F&16383](s,2,0)|0;if((D|0)<1){E=1;i=e;return E|0}if((gzL(x,0,2)|0)==0){break}else{E=1}i=e;return E|0}}while(0);x=(c[2385958]|0)+12288|0;if((c[3542200]|0)==0){E=1;i=e;return E|0}C=p+108|0;c[C>>2]=0;z=p+100|0;c[z>>2]=0;D=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[D&16383](p,3)|0;do{if((c[C>>2]|0)!=0){D=c[z>>2]|0;c[q>>2]=9534384;F=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[F&16383](q,3,0)|0;if((D|0)<1){E=1;i=e;return E|0}if((gzL(x,0,3)|0)==0){break}else{E=1}i=e;return E|0}}while(0);x=(c[2385958]|0)+16384|0;if((c[3542200]|0)==0){E=1;i=e;return E|0}z=n+108|0;c[z>>2]=0;C=n+100|0;c[C>>2]=0;D=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[D&16383](n,4)|0;do{if((c[z>>2]|0)!=0){D=c[C>>2]|0;c[o>>2]=9534384;F=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[F&16383](o,4,0)|0;if((D|0)<1){E=1;i=e;return E|0}if((gzL(x,0,4)|0)==0){break}else{E=1}i=e;return E|0}}while(0);x=(c[2385958]|0)+20480|0;if((c[3542200]|0)==0){E=1;i=e;return E|0}C=l+108|0;c[C>>2]=0;z=l+100|0;c[z>>2]=0;D=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[D&16383](l,5)|0;do{if((c[C>>2]|0)!=0){D=c[z>>2]|0;c[m>>2]=9534384;F=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[F&16383](m,5,0)|0;if((D|0)<1){E=1;i=e;return E|0}if((gzL(x,0,5)|0)==0){break}else{E=1}i=e;return E|0}}while(0);x=(c[2385958]|0)+24576|0;if((c[3542200]|0)==0){E=1;i=e;return E|0}z=j+108|0;c[z>>2]=0;C=j+100|0;c[C>>2]=0;D=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[D&16383](j,6)|0;do{if((c[z>>2]|0)!=0){D=c[C>>2]|0;c[k>>2]=9534384;F=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[F&16383](k,6,0)|0;if((D|0)<1){E=1;i=e;return E|0}if((gzL(x,0,6)|0)==0){break}else{E=1}i=e;return E|0}}while(0);x=(c[2385958]|0)+28672|0;if((c[3542200]|0)==0){E=1;i=e;return E|0}C=f+108|0;c[C>>2]=0;z=f+100|0;c[z>>2]=0;D=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[D&16383](f,7)|0;do{if((c[C>>2]|0)!=0){D=c[z>>2]|0;c[g>>2]=9534384;F=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[F&16383](g,7,0)|0;if((D|0)<1){E=1;i=e;return E|0}if((gzL(x,0,7)|0)==0){break}else{E=1}i=e;return E|0}}while(0);dt0(8);fwR(0);x=c[2439330]|0;z=(x|0)==0;if(!z){C=x;gGC(9706056,C|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];C=c[3528484]|0;c[2076596]=C;D=c[2417276]|0;c[3541536]=D;c[1836236]=0;F=c[2385958]|0;G=0;H=0;while(1){c[x+76+(H<<2)>>2]=F+(H<<8);I=G+1&65535;if((I&65535)>119){J=0;K=0;break}else{G=I;H=I&65535}}while(1){H=F+(K<<8)|0;c[x+76+(K+512<<2)>>2]=H;c[x+76+(K+768<<2)>>2]=H;H=J+1&65535;if((H&65535)>119){break}else{J=H;K=H&65535}}F=c[2386112]|0;c[x+556>>2]=F;H=F+256|0;c[x+560>>2]=H;G=F+512|0;c[x+564>>2]=G;I=F+768|0;c[x+568>>2]=I;L=F+1024|0;c[x+572>>2]=L;M=F+1280|0;c[x+576>>2]=M;N=F+1536|0;c[x+580>>2]=N;O=F+1792|0;c[x+584>>2]=O;c[x+1580>>2]=F;c[x+1584>>2]=H;c[x+1588>>2]=G;c[x+1592>>2]=I;c[x+1596>>2]=L;c[x+1600>>2]=M;c[x+1604>>2]=N;c[x+1608>>2]=O;c[x+2604>>2]=F;c[x+3628>>2]=F;c[x+2608>>2]=H;c[x+3632>>2]=H;c[x+2612>>2]=G;c[x+3636>>2]=G;c[x+2616>>2]=I;c[x+3640>>2]=I;c[x+2620>>2]=L;c[x+3644>>2]=L;c[x+2624>>2]=M;c[x+3648>>2]=M;c[x+2628>>2]=N;c[x+3652>>2]=N;c[x+2632>>2]=O;c[x+3656>>2]=O;O=c[2386246]|0;N=128;M=128;while(1){c[x+76+(M<<2)>>2]=O+((M<<8)-32768);L=N+1&65535;if((L&65535)>255){P=128;Q=128;break}else{N=L;M=L&65535}}while(1){c[x+76+(Q+256<<2)>>2]=O+((Q<<8)-32768);M=P+1&65535;if((M&65535)>255){R=128;S=128;break}else{P=M;Q=M&65535}}while(1){M=O+((S<<8)-32768)|0;c[x+76+(S+512<<2)>>2]=M;c[x+76+(S+768<<2)>>2]=M;M=R+1&65535;if((M&65535)>255){break}else{R=M;S=M&65535}}c[x+4172>>2]=512;c[x+4176>>2]=1764;if(!z){O=x;gGC(O|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=C;c[2417276]=D;c[1836236]=-1;O=a[9680]|0?32e3:0;c[3542220]=11200;if((c[2113008]|0)==0){gGz(14168888,0,252);c[3542223]=O;gGz(14168896,0,16);c[3542234]=~~((+(O|0)*32768.0*8.0+1375.0e3)/275.0e4);O=31;T=32767.0;while(1){c[14169012+(O<<2)>>2]=~~(T+.5);M=O-1|0;if((M|0)>0){O=M;T=T/1.188502227}else{break}}c[3542253]=0;h[1771269]=1.0;h[1771270]=1.0;h[1771271]=1.0;c[3542574]=3;c[3542575]=3;c[3542576]=3;mB(0);c[2113008]=(c[2113008]|0)+1}h[1771269]=1.0;c[3542574]=3;h[1771270]=1.0;c[3542575]=3;h[1771271]=1.0;c[3542576]=3;O=c[642608+(c[2436]<<2)>>2]|0;D=c[O+128>>2]|0;if((c[O+52>>2]&4|0)==0){c[2113068]=D;C=c[O+132>>2]|0;c[2113070]=C;c[2443814]=D;c[2440436]=C;U=D;V=C}else{c[2113070]=D;C=c[O+132>>2]|0;c[2113068]=C;c[2440436]=D;c[2443814]=C;U=C;V=D}D=ag(U<<1,V)|0;C=gGq(D)|0;c[2112926]=C;if((C|0)!=0){gGz(C|0,0,D|0)}D=c[2414736]|0;gGz(D|0,0,(c[2411768]|0)-D|0);D=c[2439330]|0;if((D|0)!=0){C=D;gGC(9706056,C|0,76)|0}c[2433530]=c[2438118];C=c[3528484]|0;c[2076596]=C;O=c[2417276]|0;c[3541536]=O;c[1836236]=0;gGz(9706056,0,76);x=c[2385958]|0;z=c[2440006]|0;M=(d[z]|0)<<16;N=0;L=0;while(1){c[D+76+(L<<2)>>2]=x+((L<<8)+M);I=N+1&65535;if((I&65535)>95){break}else{N=I;L=I&65535}}L=(d[z]|0)<<16;N=0;M=0;while(1){I=x+((M<<8)+L)|0;c[D+76+(M+512<<2)>>2]=I;c[D+76+(M+768<<2)>>2]=I;I=N+1&65535;if((I&65535)>95){break}else{N=I;M=I&65535}}a[c[2438854]|0]=0;c[D+460>>2]=x+24576;c[D+464>>2]=x+24832;c[D+468>>2]=x+25088;c[D+472>>2]=x+25344;c[D+476>>2]=x+25600;c[D+480>>2]=x+25856;c[D+484>>2]=x+26112;c[D+488>>2]=x+26368;c[D+492>>2]=x+26624;c[D+496>>2]=x+26880;c[D+500>>2]=x+27136;c[D+504>>2]=x+27392;c[D+508>>2]=x+27648;c[D+512>>2]=x+27904;c[D+516>>2]=x+28160;c[D+520>>2]=x+28416;M=96;N=96;while(1){L=x+(N<<8)|0;c[D+76+(N+512<<2)>>2]=L;c[D+76+(N+768<<2)>>2]=L;L=M+1&65535;if((L&65535)>111){break}else{M=L;N=L&65535}}N=D;gGC(N|0,9706056,76)|0;c[2438118]=c[2433530];c[3528484]=C;c[2417276]=O;c[1836236]=-1;mB(0);c[2388382]=0;E=0;i=e;return E|0}}while(0);c[2415030]=0;E=1;i=e;return E|0}function dtG(){var a=0,b=0,d=0,e=0;c[2113070]=0;c[2113068]=0;a=c[2112926]|0;if((a|0)!=0){gGr(a);c[2112926]=0}c[2113008]=0;c[2076598]=0;c[2383582]=0;fwZ();if((c[3540906]|0)!=0){gGz(9668984,0,81);c[3540906]=0;c[3540904]=0;c[3540902]=0;c[3540900]=0;c[3540898]=0;c[3540896]=0;c[3540894]=0;c[3540892]=0;c[3540890]=0;c[3540888]=0;c[3540886]=0;c[3540884]=0;c[3540882]=0}a=c[2415030]|0;b=0;while(1){if((b|0)>=1024){d=80176;break}e=9638528+(b<<2)|0;if((c[e>>2]|0)==(a|0)){break}else{b=b+1|0}}if((d|0)==80176){c[2415030]=0;return 0}gGr(a);c[e>>2]=0;c[2415030]=0;return 0}function dtH(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=(c[2388382]|0)+1|0;c[2388382]=e;if((e|0)>180){e=c[2439330]|0;if((e|0)!=0){f=e;gGC(9706056,f|0,76)|0}c[2433530]=c[2438118];f=c[3528484]|0;c[2076596]=f;g=c[2417276]|0;c[3541536]=g;c[1836236]=0;gGz(9706056,0,76);h=c[2385958]|0;i=c[2440006]|0;j=d[i]<<16;k=0;l=0;while(1){c[e+76+(l<<2)>>2]=h+((l<<8)+j);m=k+1&65535;if((m&65535)>95){break}else{k=m;l=m&65535}}l=d[i]<<16;i=0;k=0;while(1){j=h+((k<<8)+l)|0;c[e+76+(k+512<<2)>>2]=j;c[e+76+(k+768<<2)>>2]=j;j=i+1&65535;if((j&65535)>95){break}else{i=j;k=j&65535}}a[c[2438854]|0]=0;c[e+460>>2]=h+24576;c[e+464>>2]=h+24832;c[e+468>>2]=h+25088;c[e+472>>2]=h+25344;c[e+476>>2]=h+25600;c[e+480>>2]=h+25856;c[e+484>>2]=h+26112;c[e+488>>2]=h+26368;c[e+492>>2]=h+26624;c[e+496>>2]=h+26880;c[e+500>>2]=h+27136;c[e+504>>2]=h+27392;c[e+508>>2]=h+27648;c[e+512>>2]=h+27904;c[e+516>>2]=h+28160;c[e+520>>2]=h+28416;k=96;i=96;while(1){l=h+(i<<8)|0;c[e+76+(i+512<<2)>>2]=l;c[e+76+(i+768<<2)>>2]=l;l=k+1&65535;if((l&65535)>111){break}else{k=l;i=l&65535}}i=e;gGC(i|0,9706056,76)|0;c[2438118]=c[2433530];c[3528484]=f;c[2417276]=g;c[1836236]=-1;mB(0);c[2388382]=0}if((a[9624648]|0)!=0){g=c[2414736]|0;gGz(g|0,0,(c[2411768]|0)-g|0);g=c[2439330]|0;if((g|0)!=0){f=g;gGC(9706056,f|0,76)|0}c[2433530]=c[2438118];f=c[3528484]|0;c[2076596]=f;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);e=c[2385958]|0;k=c[2440006]|0;h=d[k]<<16;l=0;j=0;while(1){c[g+76+(j<<2)>>2]=e+((j<<8)+h);m=l+1&65535;if((m&65535)>95){break}else{l=m;j=m&65535}}j=d[k]<<16;k=0;l=0;while(1){h=e+((l<<8)+j)|0;c[g+76+(l+512<<2)>>2]=h;c[g+76+(l+768<<2)>>2]=h;h=k+1&65535;if((h&65535)>95){break}else{k=h;l=h&65535}}a[c[2438854]|0]=0;c[g+460>>2]=e+24576;c[g+464>>2]=e+24832;c[g+468>>2]=e+25088;c[g+472>>2]=e+25344;c[g+476>>2]=e+25600;c[g+480>>2]=e+25856;c[g+484>>2]=e+26112;c[g+488>>2]=e+26368;c[g+492>>2]=e+26624;c[g+496>>2]=e+26880;c[g+500>>2]=e+27136;c[g+504>>2]=e+27392;c[g+508>>2]=e+27648;c[g+512>>2]=e+27904;c[g+516>>2]=e+28160;c[g+520>>2]=e+28416;l=96;k=96;while(1){j=e+(k<<8)|0;c[g+76+(k+512<<2)>>2]=j;c[g+76+(k+768<<2)>>2]=j;j=l+1&65535;if((j&65535)>111){break}else{l=j;k=j&65535}}k=g;gGC(k|0,9706056,76)|0;c[2438118]=c[2433530];c[3528484]=f;c[2417276]=i;c[1836236]=-1;mB(0);c[2388382]=0}i=a[9635433]|0;a[9550056]=i;a[9549872]=-1;f=0;k=i;i=-1;do{k=((a[9634048+f|0]&1)<<f^k&255)&255;i=((a[9631840+f|0]&1)<<f^i&255)&255;f=f+1|0;}while((f|0)<8);a[9550056]=k;a[9549872]=i;i=c[2439330]|0;if((i|0)!=0){k=i;gGC(9706056,k|0,76)|0}b[4853030]=c[2426515]&65535;k=c[2438118]|0;c[2433530]=k;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;if((a[i+4188|0]|0)==0){i=gfc(45833)|0;n=(c[2433530]|0)+i|0}else{n=k+45833|0}c[2433530]=n;a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0;n=c[1836236]|0;k=c[9757320+(n<<2)>>2]|0;if((k|0)!=0){i=k;gGC(i|0,9706056,76)|0}c[9752472+(n<<2)>>2]=c[2433530];c[14113936+(n<<2)>>2]=c[2076596];c[9669104+(n<<2)>>2]=c[3541536];c[1836236]=-1;n=c[2112964]|0;if((n|0)!=0){mF(9756432,n,a[9688]|0?534:0,0)}if((c[2112968]|0)==0){return 0}dtI()|0;return 0}function dtI(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((a[9547728]|0)!=0){e=c[2406974]|0;f=c[3530094]|0;g=0;do{h=c[e+(g<<2)>>2]|0;c[f+(g<<2)>>2]=h>>>8<<3&2016|h>>>3&31|h>>>16<<8&63488;g=g+1|0;}while((g|0)<32);a[9547728]=0}g=c[2438778]|0;f=c[2386246]|0;e=c[2113068]|0;h=c[2112926]|0;i=0;while(1){j=((i|0)%136|0)<<1;if((i|0)>32095){k=80223;break}l=f+i|0;m=a[l]&15|d[g];n=ag(e,(i|0)/136|0)|0;b[h+(n+j<<1)>>1]=m;b[h+(n+(j|1)<<1)>>1]=(a[l]&255)>>>4|d[g];l=i+1|0;if((l|0)<32768){i=l}else{k=80222;break}}if((k|0)==80223){o=c[3530094]|0;R8(o);return 0}else if((k|0)==80222){o=c[3530094]|0;R8(o);return 0}return 0}function dtJ(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+64|0;g=f|0;h=f+16|0;j=f+48|0;k=(e|0)==0;if(!k){c[e>>2]=169730}if((b&96|0)==0){i=f;return 0}gGz(j|0,0,12);l=c[2414736]|0;c[j>>2]=l;c[j+4>>2]=(c[2411768]|0)-l;c[j+12>>2]=162152;gj[c[2076592]&4095](j)|0;fw$(b);j=f+32|0;do{if((b&64|0)!=0){do{if(!k){if((c[e>>2]|0)>=169110){break}c[e>>2]=169110}}while(0);if((c[2113008]|0)<=0){break}l=h|0;m=h+4|0;n=h+8|0;o=h+12|0;p=0;do{cC(j|0,531144,(q=i,i=i+8|0,c[q>>2]=p,q)|0)|0;i=q;c[l>>2]=14168888+(p*252|0);c[m>>2]=252;c[n>>2]=0;c[o>>2]=j;gj[c[2076592]&4095](h)|0;p=p+1|0;}while((p|0)<(c[2113008]|0))}}while(0);if((c[3540906]|0)==0){i=f;return 0}gGz(g|0,0,12);c[g>>2]=9668984;c[g+4>>2]=81;c[g+12>>2]=207392;gj[c[2076592]&4095](g)|0;if((b&2|0)==0){i=f;return 0}b=c[2385958]|0;g=c[2440006]|0;h=(d[g]|0)<<16;j=c[9757320+(c[1836236]<<2)>>2]|0;e=0;k=0;while(1){c[j+76+(k<<2)>>2]=b+((k<<8)+h);p=e+1&65535;if((p&65535)>95){break}else{e=p;k=p&65535}}k=(d[g]|0)<<16;g=0;e=0;while(1){h=b+((e<<8)+k)|0;c[j+76+(e+512<<2)>>2]=h;c[j+76+(e+768<<2)>>2]=h;h=g+1&65535;if((h&65535)>95){break}else{g=h;e=h&65535}}e=c[2438854]|0;g=a[e]&1;a[e]=g&255;e=g<<12;g=e|24576;k=g-24576|0;c[j+460>>2]=b+g;c[j+464>>2]=b+(e|24832);c[j+468>>2]=b+(e|25088);c[j+472>>2]=b+(e|25344);c[j+476>>2]=b+(e|25600);c[j+480>>2]=b+(e|25856);c[j+484>>2]=b+(e|26112);c[j+488>>2]=b+(e|26368);c[j+492>>2]=b+(e|26624);c[j+496>>2]=b+(e|26880);c[j+500>>2]=b+(e|27136);c[j+504>>2]=b+(e|27392);c[j+508>>2]=b+(e|27648);c[j+512>>2]=b+(e|27904);c[j+516>>2]=b+(e|28160);c[j+520>>2]=b+(e|28416);e=96;g=96;while(1){h=b+(k+(g<<8))|0;c[j+76+(g+512<<2)>>2]=h;c[j+76+(g+768<<2)>>2]=h;h=e+1&65535;if((h&65535)>111){break}else{e=h;g=h&65535}}i=f;return 0}function dtK(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1185560+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dtL(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2191636+(b*112|0)>>2];c[a+104>>2]=c[2191640+(b*112|0)>>2];c[a+108>>2]=c[2191644+(b*112|0)>>2];d=0;return d|0}function dtM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=2191536+(b*112|0);e=0;return e|0}function dtN(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>24){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3335800+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dtO(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4361884+(b*112|0)>>2];c[a+104>>2]=c[4361888+(b*112|0)>>2];c[a+108>>2]=c[4361892+(b*112|0)>>2];d=0;return d|0}function dtP(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=4361784+(b*112|0);e=0;return e|0}function dtQ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2166068+(b*112|0)>>2];c[a+104>>2]=c[2166072+(b*112|0)>>2];c[a+108>>2]=c[2166076+(b*112|0)>>2];d=0;return d|0}function dtR(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=2165968+(b*112|0);e=0;return e|0}function dtS(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2165060+(b*112|0)>>2];c[a+104>>2]=c[2165064+(b*112|0)>>2];c[a+108>>2]=c[2165068+(b*112|0)>>2];d=0;return d|0}function dtT(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=2164960+(b*112|0);e=0;return e|0}function dtU(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7047372+(b*112|0)>>2];c[a+104>>2]=c[7047376+(b*112|0)>>2];c[a+108>>2]=c[7047380+(b*112|0)>>2];d=0;return d|0}function dtV(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=7047272+(b*112|0);e=0;return e|0}function dtW(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>23){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7202688+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dtX(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>4){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5919820+(b*112|0)>>2];c[a+104>>2]=c[5919824+(b*112|0)>>2];c[a+108>>2]=c[5919828+(b*112|0)>>2];d=0;return d|0}function dtY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<5&(d|0)==0)){e=1;return e|0}c[a>>2]=5919720+(b*112|0);e=0;return e|0}function dtZ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4076984+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dt_(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6353080+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dt$(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0.0,N=0,O=0,P=0;e=i;i=i+480|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;c[2415030]=0;c[2385958]=0;c[3531030]=262144;c[2406974]=262176;c[3530094]=262304;c[2439108]=262432;p=a[9688]|0?1068:0;q=p+262432|0;c[2439109]=q;r=q+p|0;c[2439110]=r;q=r+p|0;p=q|0;c[2414736]=p;c[2386112]=p;c[2386246]=q+4096;c[2438778]=q+36864;c[2440006]=q+36865;c[2438854]=q+36866;p=q+36867|0;c[2411768]=p;c[2414316]=p;q=p;p=0;while(1){if((p|0)>=1024){break}s=9638528+(p<<2)|0;if((c[s>>2]|0)==0){t=80357;break}else{p=p+1|0}}do{if((t|0)==80357){p=gGq(q)|0;c[s>>2]=p;if((p|0)==0){break}gGz(p|0,0,q|0);c[2415030]=p;gGz(p|0,0,q|0);c[2385958]=p;c[3531030]=p+262144;c[2406974]=p+262176;c[3530094]=p+262304;c[2439108]=p+262432;r=a[9688]|0?1068:0;u=r+262432|0;c[2439109]=p+u;v=u+r|0;c[2439110]=p+v;u=v+r|0;r=p+u|0;c[2414736]=r;c[2386112]=r;c[2386246]=p+(u+4096);c[2438778]=p+(u+36864);c[2440006]=p+(u+36865);c[2438854]=p+(u+36866);r=p+(u+36867)|0;c[2411768]=r;c[2414316]=r;if((c[3542200]|0)==0){w=1;i=e;return w|0}r=n+108|0;c[r>>2]=0;u=n+100|0;c[u>>2]=0;v=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[v&16383](n,0)|0;do{if((c[r>>2]|0)!=0){v=c[u>>2]|0;c[o>>2]=9534384;x=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[x&16383](o,0,0)|0;if((v|0)<1){w=1;i=e;return w|0}if((gzL(p,0,0)|0)==0){break}else{w=1}i=e;return w|0}}while(0);p=(c[2385958]|0)+8192|0;if((c[3542200]|0)==0){w=1;i=e;return w|0}u=l+108|0;c[u>>2]=0;r=l+100|0;c[r>>2]=0;v=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[v&16383](l,1)|0;do{if((c[u>>2]|0)!=0){v=c[r>>2]|0;c[m>>2]=9534384;x=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[x&16383](m,1,0)|0;if((v|0)<1){w=1;i=e;return w|0}if((gzL(p,0,1)|0)==0){break}else{w=1}i=e;return w|0}}while(0);p=(c[2385958]|0)+16384|0;if((c[3542200]|0)==0){w=1;i=e;return w|0}r=j+108|0;c[r>>2]=0;u=j+100|0;c[u>>2]=0;v=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[v&16383](j,2)|0;do{if((c[r>>2]|0)!=0){v=c[u>>2]|0;c[k>>2]=9534384;x=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[x&16383](k,2,0)|0;if((v|0)<1){w=1;i=e;return w|0}if((gzL(p,0,2)|0)==0){break}else{w=1}i=e;return w|0}}while(0);p=(c[2385958]|0)+24576|0;if((c[3542200]|0)==0){w=1;i=e;return w|0}u=f+108|0;c[u>>2]=0;r=f+100|0;c[r>>2]=0;v=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[v&16383](f,3)|0;do{if((c[u>>2]|0)!=0){v=c[r>>2]|0;c[g>>2]=9534384;x=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[x&16383](g,3,0)|0;if((v|0)<1){w=1;i=e;return w|0}if((gzL(p,0,3)|0)==0){break}else{w=1}i=e;return w|0}}while(0);dt0(4);p=c[2385958]|0;r=0;while(1){u=p+r|0;v=(d[u]|0)^189;a[u]=(v<<4&16|v&66|v>>>7<<2|v>>>3&1|v>>>2<<7|v>>>4<<5&32|v>>>5<<3&8)&255;v=r+1|0;if((v|0)<32768){r=v}else{y=0;break}}while(1){r=a[p+y|0]|0;a[p+(y+65536)|0]=(r&255)>>>5<<6&64|r&-113|(r&255)>>>4<<5&32|(r&255)>>>6<<4&16;r=y+1|0;if((r|0)<32768){y=r}else{z=0;break}}while(1){r=(d[p+z|0]|0)^1;a[p+(z+131072)|0]=(r<<2&4|r&248|r>>>1&1|r>>>2<<1&2)&255;r=z+1|0;if((r|0)<32768){z=r}else{A=0;break}}do{r=(d[p+A|0]|0)^1;a[p+(A+196608)|0]=(r<<2&4|r&136|r>>>1&1|r>>>5<<6&64|r>>>4<<5&32|r>>>6<<4&16|r>>>2<<1&2)&255;A=A+1|0;}while((A|0)<32768);fwR(0);p=c[2439330]|0;r=(p|0)==0;if(!r){v=p;gGC(9706056,v|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];v=c[3528484]|0;c[2076596]=v;u=c[2417276]|0;c[3541536]=u;c[1836236]=0;x=c[2385958]|0;B=0;C=0;while(1){c[p+76+(C<<2)>>2]=x+(C<<8);D=B+1&65535;if((D&65535)>111){E=0;F=0;break}else{B=D;C=D&65535}}while(1){C=x+(F<<8)|0;c[p+76+(F+512<<2)>>2]=C;c[p+76+(F+768<<2)>>2]=C;C=E+1&65535;if((C&65535)>111){break}else{E=C;F=C&65535}}x=c[2386112]|0;c[p+524>>2]=x;c[p+528>>2]=x+256;c[p+532>>2]=x+512;c[p+536>>2]=x+768;c[p+540>>2]=x+1024;c[p+544>>2]=x+1280;c[p+548>>2]=x+1536;c[p+552>>2]=x+1792;c[p+556>>2]=x+2048;c[p+560>>2]=x+2304;c[p+564>>2]=x+2560;c[p+568>>2]=x+2816;c[p+572>>2]=x+3072;c[p+576>>2]=x+3328;c[p+580>>2]=x+3584;c[p+584>>2]=x+3840;C=112;B=112;while(1){c[p+76+(B+256<<2)>>2]=x+((B<<8)-28672);D=C+1&65535;if((D&65535)>127){G=112;H=112;break}else{C=D;B=D&65535}}while(1){B=x+((H<<8)-28672)|0;c[p+76+(H+512<<2)>>2]=B;c[p+76+(H+768<<2)>>2]=B;B=G+1&65535;if((B&65535)>127){break}else{G=B;H=B&65535}}x=c[2386246]|0;B=128;C=128;while(1){c[p+76+(C<<2)>>2]=x+((C<<8)-32768);D=B+1&65535;if((D&65535)>255){I=128;J=128;break}else{B=D;C=D&65535}}while(1){c[p+76+(J+256<<2)>>2]=x+((J<<8)-32768);C=I+1&65535;if((C&65535)>255){K=128;L=128;break}else{I=C;J=C&65535}}while(1){C=x+((L<<8)-32768)|0;c[p+76+(L+512<<2)>>2]=C;c[p+76+(L+768<<2)>>2]=C;C=K+1&65535;if((C&65535)>255){break}else{K=C;L=C&65535}}c[p+4172>>2]=1446;c[p+4176>>2]=2648;if(!r){x=p;gGC(x|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=v;c[2417276]=u;c[1836236]=-1;x=a[9680]|0?32e3:0;c[3542220]=11200;if((c[2113008]|0)==0){gGz(14168888,0,252);c[3542223]=x;gGz(14168896,0,16);c[3542234]=~~((+(x|0)*32768.0*8.0+1375.0e3)/275.0e4);x=31;M=32767.0;while(1){c[14169012+(x<<2)>>2]=~~(M+.5);C=x-1|0;if((C|0)>0){x=C;M=M/1.188502227}else{break}}c[3542253]=0;h[1771269]=1.0;h[1771270]=1.0;h[1771271]=1.0;c[3542574]=3;c[3542575]=3;c[3542576]=3;mB(0);c[2113008]=(c[2113008]|0)+1}h[1771269]=.25;c[3542574]=3;h[1771270]=.25;c[3542575]=3;h[1771271]=.25;c[3542576]=3;gGz(9668984,0,27);S6(0,27,0);c[3540906]=3558;c[3540896]=1372;x=c[642608+(c[2436]<<2)>>2]|0;u=c[x+128>>2]|0;if((c[x+52>>2]&4|0)==0){c[2113068]=u;v=c[x+132>>2]|0;c[2113070]=v;c[2443814]=u;c[2440436]=v;N=u;O=v}else{c[2113070]=u;v=c[x+132>>2]|0;c[2113068]=v;c[2440436]=u;c[2443814]=v;N=v;O=u}u=ag(N<<1,O)|0;v=gGq(u)|0;c[2112926]=v;if((v|0)!=0){gGz(v|0,0,u|0)}u=c[2414736]|0;gGz(u|0,0,(c[2411768]|0)-u|0);u=c[2439330]|0;if((u|0)!=0){v=u;gGC(9706056,v|0,76)|0}c[2433530]=c[2438118];v=c[3528484]|0;c[2076596]=v;x=c[2417276]|0;c[3541536]=x;c[1836236]=0;gGz(9706056,0,76);p=c[2385958]|0;r=c[2440006]|0;C=(d[r]|0)<<16;B=0;D=0;while(1){c[u+76+(D<<2)>>2]=p+((D<<8)+C);P=B+1&65535;if((P&65535)>95){break}else{B=P;D=P&65535}}D=(d[r]|0)<<16;B=0;C=0;while(1){P=p+((C<<8)+D)|0;c[u+76+(C+512<<2)>>2]=P;c[u+76+(C+768<<2)>>2]=P;P=B+1&65535;if((P&65535)>95){break}else{B=P;C=P&65535}}a[c[2438854]|0]=0;c[u+460>>2]=p+24576;c[u+464>>2]=p+24832;c[u+468>>2]=p+25088;c[u+472>>2]=p+25344;c[u+476>>2]=p+25600;c[u+480>>2]=p+25856;c[u+484>>2]=p+26112;c[u+488>>2]=p+26368;c[u+492>>2]=p+26624;c[u+496>>2]=p+26880;c[u+500>>2]=p+27136;c[u+504>>2]=p+27392;c[u+508>>2]=p+27648;c[u+512>>2]=p+27904;c[u+516>>2]=p+28160;c[u+520>>2]=p+28416;C=96;B=96;while(1){D=p+(B<<8)|0;c[u+76+(B+512<<2)>>2]=D;c[u+76+(B+768<<2)>>2]=D;D=C+1&65535;if((D&65535)>111){break}else{C=D;B=D&65535}}B=u;gGC(B|0,9706056,76)|0;c[2438118]=c[2433530];c[3528484]=v;c[2417276]=x;c[1836236]=-1;mB(0);c[2388382]=0;w=0;i=e;return w|0}}while(0);c[2415030]=0;w=1;i=e;return w|0}function dt0(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=i;i=i+120|0;e=b|0;f=b+112|0;g=c[3531030]|0;gGC(g|0,605952,32)|0;do{if((c[3542200]|0)!=0){h=e+108|0;c[h>>2]=0;j=e+100|0;c[j>>2]=0;k=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[k&16383](e,a)|0;if((c[h>>2]|0)==0){break}h=c[j>>2]|0;c[f>>2]=9534384;j=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[j&16383](f,a,0)|0;if((h|0)<1){break}gzL(g,0,a)|0}}while(0);a=c[3531030]|0;g=c[2406974]|0;f=0;do{e=d[a+f|0]|0;h=e>>>7;j=e>>>6&1;k=e>>>5&1;l=e>>>4&1;m=e>>>3&1;n=e>>>2&1;o=e>>>1&1;p=e&1;c[g+(f<<2)>>2]=h<<20|h<<23|h<<17|p<<6|p<<4|p<<1|o|j<<22|k<<21|j<<19|j<<18|k<<16|l<<15|m<<14|n<<13|l<<12|m<<11|m<<10|l<<9|n<<8|o<<7|o<<5|o<<3|o<<2;f=f+1|0;}while((f|0)<32);i=b;return}function dt1(b){b=b|0;var d=0,e=0;d=b&65535;switch(d|0){case 46338:{e=a[9634041]<<1|a[9634040]|a[9634042]<<2|a[9634043]<<3|a[9634044]<<4|a[9634045]<<5|a[9634046]<<6|a[9634047]<<7;return e|0};case 46342:case 46343:{c[3525074]=a[638600]&1^d&1;e=0;return e|0};case 46336:{e=a[9635424]|0;return e|0};case 46340:{d=a[9629777]<<1|a[9629776]|a[9629778]<<2|a[9629779]<<3|a[9629780]<<4|a[9629781]<<5|a[9629782]<<6|a[9629783]<<7;e=a[673088]|a[673080]?d|64:d;return e|0};case 46337:{d=a[9635425]|0;e=(c[2438254]|0)!=0|a[673088]&(a[9631839]|0)!=0^1?d:d|32;return e|0};case 46339:{e=a[9631833]<<1|a[9631832]|a[9631834]<<2|a[9631835]<<3|a[9631836]<<4|a[9631837]<<5|a[9631838]<<6|a[9631839]<<7;return e|0};case 46341:{e=a[9629009]<<1|a[9629008]|a[9629010]<<2|a[9629011]<<3|a[9629012]<<4|a[9629013]<<5|a[9629014]<<6|a[9629015]<<7;return e|0};default:{if(!(a[638600]&(b&65535)>49151&(b&65535)<53248)){e=0;return e|0}d=b&4095;b=d&3072;if((b|0)==2048){c[9755664+((d&15)<<2)>>2]=d>>>4&15;e=0;return e|0}else if((b|0)==3072){c[2440222]=d&7;c[2432788]=d<<7&31744;e=0;return e|0}else{b=c[2440222]<<15;e=a[(c[2424742]|0)+(c[2432788]|d&1008|c[9755664+((d&15)<<2)>>2]|((d&1024|0)==0?b:b+262144|0))|0]|0;return e|0}}}return 0}function dt2(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=d&65535;if((d+18944&65535)<32){d=(c[2406972]|0)+((f&31)<<2)|0;a[(c[2424768]|0)+f|0]=e;a[14124256]=1;g=~e;h=g&255;i=h&7;j=(g&255)>>>3&255;k=j&7;l=(g&255)>>>6&255;c[d>>2]=i<<18|l|i<<21|h<<15&196608|l<<4|l<<6|l<<2|k<<10|k<<13|j<<7&768;return}if((f|0)==46848){j=e&255;c[3525074]=j>>>7;c[2438254]=j&1;return}else if((f|0)==46080){a[14113280]=e;e=c[1836236]|0;j=c[9757320+(e<<2)>>2]|0;if((j|0)!=0){k=j;gGC(k|0,9706056,76)|0}c[9752472+(e<<2)>>2]=c[2433530];c[14113936+(e<<2)>>2]=c[2076596];c[9669104+(e<<2)>>2]=c[3541536];c[1836236]=-1;e=c[2439331]|0;k=(e|0)==0;if(!k){j=e;gGC(9706056,j|0,76)|0}b[4853030]=c[2426515]&65535;j=c[2438119]|0;c[2433530]=j;l=c[3528485]|0;c[2076596]=l;h=c[2417277]|0;c[3541536]=h;c[1836236]=1;a[9706117]=1;if(!k){k=e;gGC(k|0,9706056,76)|0}c[2438119]=j;c[3528485]=l;c[2417277]=h;c[1836236]=-1;h=c[2439330]|0;if((h|0)!=0){l=h;gGC(9706056,l|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;return}else if((f|0)==46342){c[3525074]=1;return}else{return}}function dt3(b){b=b|0;var d=0,e=0;if((b&255)!=64){d=0;return d|0}b=c[3542228]|0;if((b|0)>15){d=0;return d|0}do{if((b|0)==15){e=c[3542225]|0;if((e|0)==0){break}a[14168931]=gj[e&4095](0)|0}else if((b|0)==14){e=c[3542224]|0;if((e|0)==0){break}a[14168930]=gj[e&4095](0)|0}}while(0);d=a[14168916+b|0]|0;return d|0}function dt4(b,d){b=b|0;d=d|0;var e=0;e=b&255;if((e|0)==128){c[3542228]=d&15;return}else if((e|0)==64){e=d&255;b=c[3542228]|0;if((b|0)>15){return}do{if((b|0)<14){if((b|0)!=13){if((a[14168916+b|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(0,b,e);return}else{return}}function dt5(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7043844+(b*112|0)>>2];c[a+104>>2]=c[7043848+(b*112|0)>>2];c[a+108>>2]=c[7043852+(b*112|0)>>2];d=0;return d|0}function dt6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=7043744+(b*112|0);e=0;return e|0}function dt7(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6270856+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dt8(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>32){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7201816+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dt9(){c[3528190]=128;return du0()|0}function dua(){var b=0,d=0,e=0,f=0,g=0;fwZ();c[2113008]=0;c[2076598]=0;c[2383582]=0;c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}b=c[2385386]|0;d=0;while(1){if((d|0)>=1024){break}e=9638528+(d<<2)|0;if((c[e>>2]|0)==(b|0)){f=80536;break}else{d=d+1|0}}if((f|0)==80536){gGr(b);c[e>>2]=0}c[2385386]=0;e=c[2426780]|0;b=0;while(1){if((b|0)>=1024){break}g=9638528+(b<<2)|0;if((c[g>>2]|0)==(e|0)){f=80540;break}else{b=b+1|0}}if((f|0)==80540){gGr(e);c[g>>2]=0}c[2406972]=0;c[2414462]=0;c[2385386]=0;c[2424742]=0;c[2426830]=0;c[2424754]=0;c[2424768]=0;c[2426780]=0;c[2439106]=0;c[2439105]=0;c[2439104]=0;a[642584]=0;a[673088]=0;a[673080]=0;a[638600]=0;return 0}function dub(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;if((a[9624640]|0)!=0){du3()}if(a[673088]|a[673080]){d=dt1(-19200)|0;e=c[2424768]|0;a[e+46336|0]=d;a[e+46337|0]=dt1(-19199)|0;a[e+46338|0]=dt1(-19198)|0;a[e+46339|0]=dt1(-19197)|0;a[e+46340|0]=dt1(-19196)|0;a[e+46341|0]=dt1(-19195)|0}a[6518288]=1;a[6518112]=1;c[2443984]=0;c[2444032]=0;e=c[2385548]|0;if((e|0)>0){gGz(9752472,0,((e|0)>1?e<<2:4)|0)}c[2433530]=0;e=0;L98518:while(1){if((e|0)>=1e3){break}d=c[2439330]|0;if((d|0)!=0){f=d;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;f=c[2438118]|0;c[2433530]=f;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;g=e+1|0;h=(ag(a[6518288]|0?5e4:0,g)|0)/1e3|0;i=c[2444032]|0;j=h-i|0;do{if((j|0)<1){k=0;l=i}else{if((a[d+4188|0]|0)==0){h=gfc(j)|0;c[2433530]=(c[2433530]|0)+h;k=h;l=c[2444032]|0;break}else{c[2433530]=f+j;k=j;l=i;break}}}while(0);c[2444032]=l+k;do{if(a[673088]|0){if(!((e|0)==333|(e|0)==666)){break}a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0}}while(0);if(a[642584]&(e|0)==500){a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0}do{if((e|0)==999){if(a[673088]|0){if((a[9629783]|0)!=0){break}if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12;break}if(!(a[673080]|0)){a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0;break}if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12}}while(0);i=c[1836236]|0;j=c[9757320+(i<<2)>>2]|0;if((j|0)!=0){f=j;gGC(f|0,9706056,76)|0}c[9752472+(i<<2)>>2]=c[2433530];c[14113936+(i<<2)>>2]=c[2076596];c[9669104+(i<<2)>>2]=c[3541536];c[1836236]=-1;i=c[2439331]|0;if((i|0)!=0){f=i;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;f=c[2438119]|0;c[2433530]=f;c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;j=(ag(a[6518112]|0?25e3:0,g)|0)/1e3|0;d=c[2443984]|0;h=j-d|0;do{if((h|0)<1){m=0;n=d;o=1;p=i;q=f}else{if((a[i+4188|0]|0)==0){j=gfc(h)|0;r=(c[2433530]|0)+j|0;c[2433530]=r;s=c[1836236]|0;m=j;n=c[2443984]|0;o=s;p=c[9757320+(s<<2)>>2]|0;q=r;break}else{r=f+h|0;c[2433530]=r;m=h;n=d;o=1;p=i;q=r;break}}}while(0);c[2443984]=n+m;if((p|0)!=0){i=p;gGC(i|0,9706056,76)|0}c[9752472+(o<<2)>>2]=q;c[14113936+(o<<2)>>2]=c[2076596];c[9669104+(o<<2)>>2]=c[3541536];c[1836236]=-1;if((c[2112964]|0)==0|a[638600]){e=g;continue}i=c[2113008]|0;if((i|0)>0){t=0}else{e=g;continue}while(1){d=t*3|0;mA(t,c[9756416+(d<<2)>>2]|0,c[9756416+(d+1<<2)>>2]|0,c[9756416+(d+2<<2)>>2]|0,0);d=t+1|0;if((d|0)<(i|0)){t=d}else{e=g;continue L98518}}}e=c[2112964]|0;do{if(!((e|0)==0|a[638600])){if(!(a[9688]|0)){break}mF(9756416,e,534,0)}}while(0);if((c[2112968]|0)==0){return 0}duc()|0;return 0}function duc(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;if((a[14124256]|0)!=0){b=c[2406972]|0;e=c[2414462]|0;f=0;do{g=c[b+(f<<2)>>2]|0;c[e+(f<<2)>>2]=g>>>8<<3&2016|g>>>3&31|g>>>16<<8&63488;f=f+1|0;}while((f|0)<256);a[14124256]=0}f=c[2424768]|0;e=a[673088]|a[673080];b=(c[3525074]|0)==0;g=c[2112926]|0;h=c[2426830]|0;i=0;while(1){j=i<<3&248;k=i>>>2&248;l=d[f+(i+48128)|0]|0;if(e){m=l>>>2&14;n=l<<8}else{m=l&7;n=l<<5}l=n&768|d[f+(i+47104)|0];if(b){Sj(g,l,j-16|0,k,m,2,0,h)}else{Sp(g,l,j^248,k^248,m,2,0,h)}k=i+1|0;if((k|0)<1024){i=k}else{o=0;break}}do{i=d[f+(o+45056)|0]|0;m=d[f+((o|1)+45056)|0]|0;n=d[f+((o|3)+45056)|0]|0;if(e){p=n>>>2&14;q=n<<8}else{p=n&7;q=n<<5}k=q&256|d[f+((o|2)+45056)|0];j=n&64;if(b){r=n&128;s=j;t=m;u=248-i|0}else{r=n>>>7^1;s=j>>>6^1;t=248-m|0;u=i}i=u-16|0;m=(s|0)!=0;do{if((r|0)==0){if(m){St(g,k,i,t,p,2,0,0,h);break}else{Sr(g,k,i,t,p,2,0,0,h);break}}else{if(m){Sx(g,k,i,t,p,2,0,0,h);break}else{Sv(g,k,i,t,p,2,0,0,h);break}}}while(0);o=o+4|0;}while((o|0)<128);R8(c[2414462]|0);return 0}function dud(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=i;i=i+112|0;f=e|0;g=e+32|0;h=e+48|0;j=e+64|0;k=e+80|0;l=e+96|0;m=(d|0)==0;if(!m){c[d>>2]=169249}if((b&96|0)==0){i=e;return 0}n=l;gGz(n|0,0,16);o=c[2424768]|0;if(a[673088]|a[673080]){c[l>>2]=o+32768}else{c[l>>2]=o+16384}o=l+4|0;c[o>>2]=4096;p=l+12|0;c[p>>2]=124672;gj[c[2076592]&4095](l)|0;gGz(n|0,0,12);q=l|0;c[q>>2]=(c[2424768]|0)+45056;c[o>>2]=4096;c[p>>2]=151792;gj[c[2076592]&4095](l)|0;gGz(n|0,0,12);c[q>>2]=c[2406972];c[o>>2]=1024;c[p>>2]=426800;gj[c[2076592]&4095](l)|0;gGz(n|0,0,12);c[q>>2]=9755664;c[o>>2]=64;c[p>>2]=462712;gj[c[2076592]&4095](l)|0;fw$(b);l=e+16|0;do{if((b&64|0)!=0){do{if(!m){if((c[d>>2]|0)>=169110){break}c[d>>2]=169110}}while(0);if((c[2113008]|0)<=0){break}p=f|0;o=f+4|0;q=f+8|0;n=f+12|0;r=0;do{cC(l|0,531144,(s=i,i=i+8|0,c[s>>2]=r,s)|0)|0;i=s;c[p>>2]=14168888+(r*252|0);c[o>>2]=252;c[q>>2]=0;c[n>>2]=l;gj[c[2076592]&4095](f)|0;r=r+1|0;}while((r|0)<(c[2113008]|0))}}while(0);gGz(k|0,0,12);c[k>>2]=9731152;c[k+4>>2]=4;c[k+12>>2]=461376;gj[c[2076592]&4095](k)|0;gGz(j|0,0,12);c[j>>2]=9760888;c[j+4>>2]=4;c[j+12>>2]=459720;gj[c[2076592]&4095](j)|0;gGz(h|0,0,12);c[h>>2]=14113280;c[h+4>>2]=1;c[h+12>>2]=191240;gj[c[2076592]&4095](h)|0;gGz(g|0,0,12);c[g>>2]=9753016;c[g+4>>2]=4;c[g+12>>2]=457048;gj[c[2076592]&4095](g)|0;i=e;return 0}function due(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6564636+(b*112|0)>>2];c[a+104>>2]=c[6564640+(b*112|0)>>2];c[a+108>>2]=c[6564644+(b*112|0)>>2];d=0;return d|0}function duf(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=6564536+(b*112|0);e=0;return e|0}function dug(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>32){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6873688+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function duh(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6563180+(b*112|0)>>2];c[a+104>>2]=c[6563184+(b*112|0)>>2];c[a+108>>2]=c[6563188+(b*112|0)>>2];d=0;return d|0}function dui(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=6563080+(b*112|0);e=0;return e|0}function duj(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>32){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6873288+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function duk(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2127932+(b*112|0)>>2];c[a+104>>2]=c[2127936+(b*112|0)>>2];c[a+108>>2]=c[2127940+(b*112|0)>>2];d=0;return d|0}function dul(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=2127832+(b*112|0);e=0;return e|0}function dum(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>32){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3281824+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dun(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c[3528190]=128;d=du0()|0;e=c[2424768]|0;f=c[2424742]|0;g=0;do{h=a[e+g|0]|0;do{if((g&4096|0)==0){a[f+g|0]=((h&255)>>>2<<6&64|h&-87|(h&255)>>>1<<4&16|(h&255)>>>6<<2&4|(h&255)>>>4<<1&2)^-127}else{i=h&32|h<<7|h&8|(h&255)>>>7|(h&255)>>>2<<6&64|(h&255)>>>1<<4&16|(h&255)>>>6<<2&4|(h&255)>>>4<<1&2;j=f+g|0;a[j]=i;if((g&4|0)!=0){break}a[j]=i^-127}}while(0);g=g+1|0;}while((g|0)<16384);g=c[2439330]|0;if((g|0)!=0){h=g;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];h=c[3528484]|0;c[2076596]=h;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;j=0;k=0;while(1){l=k<<8;c[g+76+(k+512<<2)>>2]=f+l;c[g+76+(k+768<<2)>>2]=e+l;l=j+1&65535;if((l&65535)>63){break}else{j=l;k=l&65535}}k=g;gGC(k|0,9706056,76)|0;c[2438118]=c[2433530];c[3528484]=h;c[2417276]=i;c[1836236]=-1;return d|0}function duo(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2053052+(b*112|0)>>2];c[a+104>>2]=c[2053056+(b*112|0)>>2];c[a+108>>2]=c[2053060+(b*112|0)>>2];d=0;return d|0}function dup(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=2052952+(b*112|0);e=0;return e|0}function duq(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1172032+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dur(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>42){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3187240+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dus(){c[3528190]=16;return du0()|0}function dut(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2054620+(b*112|0)>>2];c[a+104>>2]=c[2054624+(b*112|0)>>2];c[a+108>>2]=c[2054628+(b*112|0)>>2];d=0;return d|0}function duu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=2054520+(b*112|0);e=0;return e|0}function duv(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7071044+(b*112|0)>>2];c[a+104>>2]=c[7071048+(b*112|0)>>2];c[a+108>>2]=c[7071052+(b*112|0)>>2];d=0;return d|0}function duw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=7070944+(b*112|0);e=0;return e|0}function dux(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5898788+(b*112|0)>>2];c[a+104>>2]=c[5898792+(b*112|0)>>2];c[a+108>>2]=c[5898796+(b*112|0)>>2];d=0;return d|0}function duy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=5898688+(b*112|0);e=0;return e|0}function duz(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3944312+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function duA(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6308616+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function duB(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2195556+(b*112|0)>>2];c[a+104>>2]=c[2195560+(b*112|0)>>2];c[a+108>>2]=c[2195564+(b*112|0)>>2];d=0;return d|0}function duC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=2195456+(b*112|0);e=0;return e|0}function duD(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1186808+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function duE(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3344376+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function duF(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4353908+(b*112|0)>>2];c[a+104>>2]=c[4353912+(b*112|0)>>2];c[a+108>>2]=c[4353916+(b*112|0)>>2];d=0;return d|0}function duG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=4353808+(b*112|0);e=0;return e|0}function duH(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1653328+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function duI(){a[642584]=1;c[3528190]=128;return du0()|0}function duJ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2123452+(b*112|0)>>2];c[a+104>>2]=c[2123456+(b*112|0)>>2];c[a+108>>2]=c[2123460+(b*112|0)>>2];d=0;return d|0}function duK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=2123352+(b*112|0);e=0;return e|0}function duL(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5857004+(b*112|0)>>2];c[a+104>>2]=c[5857008+(b*112|0)>>2];c[a+108>>2]=c[5857012+(b*112|0)>>2];d=0;return d|0}function duM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=5856904+(b*112|0);e=0;return e|0}function duN(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3843632+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function duO(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>23){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6270528+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function duP(){var b=0,e=0,f=0,g=0,h=0;a[673088]=1;c[3528190]=16;b=du0()|0;e=c[2424792]|0;f=c[2406972]|0;g=0;do{h=d[e+g|0]|0;c[f+(g<<2)>>2]=(-(h>>>3&1)&33)+(-(h>>>4&1)&71)+(-(h>>>5&1)&151)<<8|(-(h>>>6&1)&71)+(-(h>>>7)&151)|(-(h>>>1&1)&71)+(-(h&1)&33)+(-(h>>>2&1)&151)<<16;g=g+1|0;}while((g|0)<256);return b|0}function duQ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2635980+(b*112|0)>>2];c[a+104>>2]=c[2635984+(b*112|0)>>2];c[a+108>>2]=c[2635988+(b*112|0)>>2];d=0;return d|0}function duR(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=2635880+(b*112|0);e=0;return e|0}function duS(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1233520+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function duT(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>26){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3784960+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function duU(){var b=0,e=0,f=0,g=0,h=0;a[673080]=1;c[3528190]=16;b=du0()|0;e=c[2424768]|0;a[e+18|0]=-99;a[e+19|0]=1;e=c[2424792]|0;f=c[2406972]|0;g=0;do{h=d[e+g|0]|0;c[f+(g<<2)>>2]=(-(h>>>3&1)&33)+(-(h>>>4&1)&71)+(-(h>>>5&1)&151)<<8|(-(h>>>6&1)&71)+(-(h>>>7)&151)|(-(h>>>1&1)&71)+(-(h&1)&33)+(-(h>>>2&1)&151)<<16;g=g+1|0;}while((g|0)<256);return b|0}function duV(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6480428+(b*112|0)>>2];c[a+104>>2]=c[6480432+(b*112|0)>>2];c[a+108>>2]=c[6480436+(b*112|0)>>2];d=0;return d|0}function duW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=6480328+(b*112|0);e=0;return e|0}function duX(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4939360+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function duY(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>24){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6671160+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function duZ(){var b=0,d=0,e=0,f=0,g=0,h=0;a[638600]=1;c[3528190]=128;b=du0()|0;d=c[2424768]|0;e=0;do{f=(e&4|0)!=0;g=d+e|0;h=a[g]|0;do{if((e&4096|0)==0){if(f){a[g]=((h&255)>>>2<<6&64|h&-87|(h&255)>>>1<<4&16|(h&255)>>>6<<2&4|(h&255)>>>4<<1&2)^1;break}else{a[g]=h&32|h<<7|h&8|(h&255)>>>7|(h&255)>>>2<<6&64|(h&255)>>>1<<4&16|(h&255)>>>6<<2&4|(h&255)>>>4<<1&2;break}}else{if(f){a[g]=((h&255)>>>2<<6&64|h&-87|(h&255)>>>1<<4&16|(h&255)>>>6<<2&4|(h&255)>>>4<<1&2)^1;break}else{a[g]=(h&32|h<<7|h&8|(h&255)>>>7|(h&255)>>>2<<6&64|(h&255)>>>1<<4&16|(h&255)>>>6<<2&4|(h&255)>>>4<<1&2)^-127;break}}}while(0);e=e+1|0;}while((e|0)<16384);return b|0}function du_(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5661244+(b*112|0)>>2];c[a+104>>2]=c[5661248+(b*112|0)>>2];c[a+108>>2]=c[5661252+(b*112|0)>>2];d=0;return d|0}function du$(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<22&(d|0)==0)){e=1;return e|0}c[a>>2]=5661144+(b*112|0);e=0;return e|0}function du0(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0.0,aD=0,aE=0;e=i;i=i+840|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+728|0;v=0;while(1){if((v|0)>=1024){break}w=9638528+(v<<2)|0;if((c[w>>2]|0)==0){x=80948;break}else{v=v+1|0}}do{if((x|0)==80948){v=gGq(1048576)|0;c[w>>2]=v;if((v|0)==0){break}gGz(v|0,0,1048576);c[2426780]=v;y=gGq(a[9688]|0?3204:0)|0;c[2385386]=y;if((y|0)==0){z=1;i=e;return z|0}c[2424768]=v;y=v+65536|0;c[2424754]=y;A=v+131072|0;c[2426830]=A;B=v+196608|0;c[2424742]=B;c[2424792]=v+720896;c[2406972]=v+786432;c[2414462]=v+790528;C=a[673088]|0;D=a[673080]|0;L98998:do{if((gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](t,0,0)|0)==0){E=u+108|0;F=u+100|0;G=r+108|0;H=r+100|0;I=p+108|0;J=p+100|0;K=n+108|0;L=n+100|0;M=l+108|0;N=l+100|0;O=j+108|0;P=j+100|0;Q=f+108|0;R=f+100|0;S=v;T=y;U=C|D?A:v+139264|0;V=B;W=0;X=0;while(1){gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](u,X)|0;L99002:do{switch(c[E>>2]&7|0){case 3:{if((c[3542200]|0)==0){Y=0;break L98998}c[K>>2]=0;c[L>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,X)|0;if((c[K>>2]|0)!=0){Z=c[L>>2]|0;c[o>>2]=9534384;_=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[_&16383](o,X,0)|0;if((Z|0)<1){Y=0;break L98998}if((gzL(U,0,X)|0)!=0){Y=0;break L98998}}Z=c[F>>2]|0;$=X;aa=W+1|0;ab=V;ac=U+(a[673088]|0?Z+4096|0:Z)|0;ad=T;ae=S;break};case 5:{if((c[3542200]|0)==0){Y=0;break L98998}c[Q>>2]=0;c[R>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,X)|0;if((c[Q>>2]|0)!=0){Z=c[R>>2]|0;c[g>>2]=9534384;_=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[_&16383](g,X,0)|0;if((Z|0)<1){Y=0;break L98998}if((gzL(V,0,X)|0)!=0){Y=0;break L98998}}$=X;aa=W;ab=V+(c[F>>2]|0)|0;ac=U;ad=T;ae=S;break};case 4:{Z=c[2424792]|0;if((c[3542200]|0)==0){Y=0;break L98998}c[M>>2]=0;c[N>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,X)|0;if((c[M>>2]|0)!=0){_=c[N>>2]|0;c[m>>2]=9534384;af=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[af&16383](m,X,0)|0;if((_|0)<1){Y=0;break L98998}if((gzL(Z,0,X)|0)!=0){Y=0;break L98998}}Z=(c[2424792]|0)+512|0;_=X+1|0;if((c[3542200]|0)==0){Y=0;break L98998}c[O>>2]=0;c[P>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,_)|0;if((c[O>>2]|0)!=0){af=c[P>>2]|0;c[k>>2]=9534384;ah=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ah&16383](k,_,0)|0;if((af|0)<1){Y=0;break L98998}if((gzL(Z,0,_)|0)!=0){Y=0;break L98998}}Z=c[2424792]|0;af=0;while(1){ah=Z+af|0;a[ah]=a[Z+(af+512)|0]<<4|a[ah];ah=af+1|0;if((ah|0)<512){af=ah}else{$=_;aa=W;ab=V;ac=U;ad=T;ae=S;break}}break};case 2:{if((c[3542200]|0)==0){Y=0;break L98998}c[I>>2]=0;c[J>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,X)|0;if((c[I>>2]|0)!=0){_=c[J>>2]|0;c[q>>2]=9534384;af=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[af&16383](q,X,0)|0;if((_|0)<1){Y=0;break L98998}if((gzL(T,0,X)|0)!=0){Y=0;break L98998}}$=X;aa=W;ab=V;ac=U;ad=T+(c[F>>2]|0)|0;ae=S;break};case 1:{_=(c[F>>2]|0)==8192;do{if((c[3542200]|0)==0){ai=1}else{c[G>>2]=0;c[H>>2]=0;af=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[af&16383](r,X)|0;if((c[G>>2]|0)==0){ai=0;break}af=c[H>>2]|0;c[s>>2]=9534384;Z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Z&16383](s,X,0)|0;if((af|0)<1){ai=1;break}ai=(gzL(S,0,X)|0)!=0}}while(0);if(_){if(ai){Y=0;break L98998}$=X;aa=W;ab=V;ac=U;ad=T;ae=S+(c[F>>2]|0)|0;break L99002}if(ai){Y=0;break L98998}af=c[F>>2]|0;Z=a[642584]|0;ah=Z&(X|0)==0?af+4096|0:af;if((X|0)!=(Z&1^3|0)){$=X;aa=W;ab=V;ac=U;ad=T;ae=S+ah|0;break L99002}$=X;aa=W;ab=V;ac=U;ad=T;ae=S+(ah+32768)|0;break};default:{$=X;aa=W;ab=V;ac=U;ad=T;ae=S}}}while(0);ah=$+1|0;if((gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](t,ah,0)|0)==0){S=ae;T=ad;U=ac;V=ab;W=aa;X=ah}else{break}}if((aa|0)!=2){Y=0;break}X=c[2426830]|0;W=X+16384|0;V=X+12288|0;gGC(W|0,V|0,4096)|0;gGz(V|0,0,4096);Y=0}else{Y=0}}while(0);while(1){if((Y|0)>=1024){break}aj=9638528+(Y<<2)|0;if((c[aj>>2]|0)==0){x=80994;break}else{Y=Y+1|0}}L99052:do{if((x|0)==80994){B=gGq(24576)|0;c[aj>>2]=B;if((B|0)==0){break}gGz(B|0,0,24576);v=c[2426830]|0;gGC(B|0,v|0,24576)|0;A=0;while(1){D=A<<6;gGz(v+D|0,0,64);C=0;do{y=D+(c[614800+(C<<2)>>2]|0)|0;V=(C<<3)+D|0;W=0;do{X=y+(c[609136+(W<<2)>>2]|0)|0;if(((d[B+((X|0)/8|0)|0]|0)&128>>>((X&7)>>>0)|0)!=0){X=v+(V+W)|0;a[X]=a[X]|4}W=W+1|0;}while((W|0)<8);C=C+1|0;}while((C|0)<8);C=D+65536|0;W=0;do{V=C+(c[614800+(W<<2)>>2]|0)|0;y=(W<<3)+D|0;_=0;do{X=V+(c[609136+(_<<2)>>2]|0)|0;if(((d[B+((X|0)/8|0)|0]|0)&128>>>((X&7)>>>0)|0)!=0){X=v+(y+_)|0;a[X]=a[X]|2}_=_+1|0;}while((_|0)<8);W=W+1|0;}while((W|0)<8);W=D+131072|0;C=0;do{_=W+(c[614800+(C<<2)>>2]|0)|0;y=(C<<3)+D|0;V=0;do{X=_+(c[609136+(V<<2)>>2]|0)|0;if(((d[B+((X|0)/8|0)|0]|0)&128>>>((X&7)>>>0)|0)!=0){X=v+(y+V)|0;a[X]=a[X]|1}V=V+1|0;}while((V|0)<8);C=C+1|0;}while((C|0)<8);C=A+1|0;if((C|0)<1024){A=C}else{ak=0;break}}while(1){if((ak|0)>=1024){break L99052}al=9638528+(ak<<2)|0;if((c[al>>2]|0)==(B|0)){break}else{ak=ak+1|0}}gGr(B);c[al>>2]=0}}while(0);fwR(0);A=c[2439330]|0;v=(A|0)==0;if(!v){C=A;gGC(9706056,C|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];C=c[3528484]|0;c[2076596]=C;D=c[2417276]|0;c[3541536]=D;c[1836236]=0;c[A+4180>>2]=3352;c[A+4184>>2]=100;W=c[2424768]|0;if(a[673088]|a[673080]){V=0;y=0;while(1){c[A+76+(y<<2)>>2]=W+(y<<8);_=V+1&65535;if((_&65535)>143){am=0;an=0;break}else{V=_;y=_&65535}}while(1){y=W+(an<<8)|0;c[A+76+(an+512<<2)>>2]=y;c[A+76+(an+768<<2)>>2]=y;y=am+1&65535;if((y&65535)>143){break}else{am=y;an=y&65535}}c[A+1612>>2]=W+32768;c[A+1616>>2]=W+33024;c[A+1620>>2]=W+33280;c[A+1624>>2]=W+33536;c[A+1628>>2]=W+33792;c[A+1632>>2]=W+34048;c[A+1636>>2]=W+34304;c[A+1640>>2]=W+34560;c[A+1644>>2]=W+34816;c[A+1648>>2]=W+35072;c[A+1652>>2]=W+35328;c[A+1656>>2]=W+35584;c[A+1660>>2]=W+35840;c[A+1664>>2]=W+36096;c[A+1668>>2]=W+36352;c[A+1672>>2]=W+36608;c[A+800>>2]=W+46336}else{y=0;V=0;while(1){c[A+76+(V<<2)>>2]=W+(V<<8);_=y+1&65535;if((_&65535)>63){ao=0;ap=0;break}else{y=_;V=_&65535}}while(1){V=W+(ap<<8)|0;c[A+76+(ap+512<<2)>>2]=V;c[A+76+(ap+768<<2)>>2]=V;V=ao+1&65535;if((V&65535)>63){aq=64;ar=64;break}else{ao=V;ap=V&65535}}while(1){c[A+76+(ar<<2)>>2]=W+(ar<<8);V=aq+1&65535;if((V&65535)>95){as=64;at=64;break}else{aq=V;ar=V&65535}}while(1){c[A+76+(at+256<<2)>>2]=W+(at<<8);V=as+1&65535;if((V&65535)>95){au=64;av=64;break}else{as=V;at=V&65535}}while(1){V=W+(av<<8)|0;c[A+76+(av+512<<2)>>2]=V;c[A+76+(av+768<<2)>>2]=V;V=au+1&65535;if((V&65535)>95){break}else{au=V;av=V&65535}}}V=W+45056|0;c[A+780>>2]=V;c[A+1804>>2]=V;V=W+47104|0;c[A+812>>2]=V;y=W+47360|0;c[A+816>>2]=y;_=W+47616|0;c[A+820>>2]=_;X=W+47872|0;c[A+824>>2]=X;c[A+1836>>2]=V;c[A+1840>>2]=y;c[A+1844>>2]=_;c[A+1848>>2]=X;X=W+48128|0;c[A+828>>2]=X;_=W+48384|0;c[A+832>>2]=_;y=W+48640|0;c[A+836>>2]=y;V=W+48896|0;c[A+840>>2]=V;c[A+1852>>2]=X;c[A+1856>>2]=_;c[A+1860>>2]=y;c[A+1864>>2]=V;if(a[638600]|0){V=208;y=208;while(1){c[A+76+(y<<2)>>2]=W+((y<<8)-4096);_=V+1&65535;if((_&65535)>255){aw=208;ax=208;break}else{V=_;y=_&65535}}while(1){y=W+((ax<<8)-4096)|0;c[A+76+(ax+512<<2)>>2]=y;c[A+76+(ax+768<<2)>>2]=y;y=aw+1&65535;if((y&65535)>255){break}else{aw=y;ax=y&65535}}}else{y=192;V=192;while(1){c[A+76+(V<<2)>>2]=W+(V<<8);_=y+1&65535;if((_&65535)>255){ay=192;az=192;break}else{y=_;V=_&65535}}while(1){V=W+(az<<8)|0;c[A+76+(az+512<<2)>>2]=V;c[A+76+(az+768<<2)>>2]=V;V=ay+1&65535;if((V&65535)>255){break}else{ay=V;az=V&65535}}}if(!v){W=A;gGC(W|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=C;c[2417276]=D;c[1836236]=-1;fwR(1);W=c[2439331]|0;V=(W|0)==0;if(!V){y=W;gGC(9706056,y|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];y=c[3528485]|0;c[2076596]=y;_=c[2417277]|0;c[3541536]=_;c[1836236]=1;c[W+4172>>2]=652;c[W+4176>>2]=3312;X=c[2424754]|0;U=0;T=0;while(1){c[W+76+(T<<2)>>2]=X+(T<<8);S=U+1&65535;if((S&65535)>31){aA=0;aB=0;break}else{U=S;T=S&65535}}while(1){T=X+(aB<<8)|0;c[W+76+(aB+512<<2)>>2]=T;c[W+76+(aB+768<<2)>>2]=T;T=aA+1&65535;if((T&65535)>31){break}else{aA=T;aB=T&65535}}T=X+16384|0;c[W+332>>2]=T;U=X+16640|0;c[W+336>>2]=U;D=X+16896|0;c[W+340>>2]=D;C=X+17152|0;c[W+344>>2]=C;c[W+1356>>2]=T;c[W+1360>>2]=U;c[W+1364>>2]=D;c[W+1368>>2]=C;c[W+2380>>2]=T;c[W+3404>>2]=T;c[W+2384>>2]=U;c[W+3408>>2]=U;c[W+2388>>2]=D;c[W+3412>>2]=D;c[W+2392>>2]=C;c[W+3416>>2]=C;if(!V){C=W;gGC(C|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=y;c[2417277]=_;c[1836236]=-1;C=c[2385386]|0;c[2439104]=C;D=a[9688]|0?534:0;c[2439105]=C+(D<<1);c[2439106]=C+(D<<1<<1);D=a[9680]|0?32e3:0;c[3542220]=11200;if((c[2113008]|0)==0){gGz(14168888,0,252);c[3542223]=D;c[3542224]=320;c[3542225]=3094;c[3542226]=0;c[3542227]=0;c[3542234]=~~((+(D|0)*32768.0*8.0+75.0e4)/15.0e5);D=31;aC=32767.0;while(1){c[14169012+(D<<2)>>2]=~~(aC+.5);C=D-1|0;if((C|0)>0){D=C;aC=aC/1.188502227}else{break}}c[3542253]=0;h[1771269]=1.0;h[1771270]=1.0;h[1771271]=1.0;c[3542574]=3;c[3542575]=3;c[3542576]=3;mB(0);c[2113008]=(c[2113008]|0)+1}h[1771269]=1.0;c[3542574]=3;h[1771270]=1.0;c[3542575]=3;h[1771271]=1.0;c[3542576]=3;D=c[642608+(c[2436]<<2)>>2]|0;_=c[D+128>>2]|0;if((c[D+52>>2]&4|0)==0){c[2113068]=_;y=c[D+132>>2]|0;c[2113070]=y;c[2443814]=_;c[2440436]=y;aD=_;aE=y}else{c[2113070]=_;y=c[D+132>>2]|0;c[2113068]=y;c[2440436]=_;c[2443814]=y;aD=y;aE=_}_=ag(aD<<1,aE)|0;y=gGq(_)|0;c[2112926]=y;if((y|0)!=0){gGz(y|0,0,_|0)}du3();z=0;i=e;return z|0}}while(0);c[2426780]=0;z=1;i=e;return z|0}function du1(b){b=b|0;a[9706117]=0;return a[14113280]|0}function du2(a){a=a|0;return(((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)/(c[3528190]|0)|0)&255|0}function du3(){var b=0,d=0,e=0,f=0,g=0;c[3525074]=0;a[9624640]=0;a[14113280]=0;if(a[673080]|a[673088]){b=c[2424768]|0;gGz(b+32768|0,0,4096);d=b}else{gGz(c[2406972]|0,0,1024);b=c[2424768]|0;gGz(b+16384|0,0,4096);d=b}gGz(d+45056|0,0,4096);gGz((c[2424754]|0)+16384|0,0,1024);gGz(9755664,0,64);c[2440222]=0;c[2432788]=0;c[2438254]=0;a[14113280]=0;d=c[2439330]|0;b=(d|0)==0;if(!b){e=d;gGC(9706056,e|0,76)|0}e=c[2438118]|0;c[2433530]=e;f=c[3528484]|0;c[2076596]=f;g=c[2417276]|0;c[3541536]=g;c[1836236]=0;gGz(9706056,0,76);if(!b){b=d;gGC(b|0,9706056,76)|0}c[2438118]=e;c[3528484]=f;c[2417276]=g;c[1836236]=-1;g=c[2439331]|0;f=(g|0)==0;if(!f){e=g;gGC(9706056,e|0,76)|0}e=c[2438119]|0;c[2433530]=e;b=c[3528485]|0;c[2076596]=b;d=c[2417277]|0;c[3541536]=d;c[1836236]=1;gGz(9706056,0,76);if(f){c[2438119]=e;c[3528485]=b;c[2417277]=d;c[1836236]=-1;mB(0);return}f=g;gGC(f|0,9706056,76)|0;c[2438119]=e;c[3528485]=b;c[2417277]=d;c[1836236]=-1;mB(0);return}function du4(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>1){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4826820+(b*112|0)>>2];c[a+104>>2]=c[4826824+(b*112|0)>>2];c[a+108>>2]=c[4826828+(b*112|0)>>2];d=0;return d|0}function du5(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<2&(d|0)==0)){e=1;return e|0}c[a>>2]=4826720+(b*112|0);e=0;return e|0}function du6(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=2013976+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function du7(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5593800+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function du8(){return dvp(0)|0}function du9(){var a=0,b=0,d=0,e=0;c[2113070]=0;c[2113068]=0;a=c[2112926]|0;if((a|0)!=0){gGr(a);c[2112926]=0}fvR();if((c[3528604]|0)!=0){TT()}a=c[2415028]|0;b=0;while(1){if((b|0)>=1024){d=81109;break}e=9638528+(b<<2)|0;if((c[e>>2]|0)==(a|0)){break}else{b=b+1|0}}if((d|0)==81109){c[2415028]=0;return 0}gGr(a);c[e>>2]=0;c[2415028]=0;return 0}function dva(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;do{if((a[9624632]|0)==0){b=(c[2388380]|0)+1|0;c[2388380]=b;if((b|0)<=179){break}c[3528556]=0;b=c[2433594]|0;c[2443776]=b;L99231:do{if((b|0)!=0){d=b|0;gGC(9660952,d|0,52)|0;switch(a[9660952]|0){case 0:{c[2309668]=638960;break L99231;break};case 1:{c[2309668]=634096;break L99231;break};case 3:{c[2309668]=639984;break L99231;break};case 4:{c[2309668]=7356016;break L99231;break};case 5:{c[2309668]=7354992;break L99231;break};case 2:{c[2309668]=638960;break L99231;break};default:{break L99231}}}}while(0);c[2113164]=c[2432850];gu[c[b+56>>2]&16383]();d=c[2443776]|0;if((d|0)!=0){e=d|0;gGC(e|0,9660952,52)|0}c[9731400+(c[3528556]<<2)>>2]=c[2113164];c[2443776]=0;c[3528556]=-1;a[9660536]=0;a[9771528]=c[2388484]&255;c[2388380]=0;c[2440434]=0}else{e=c[2414734]|0;gGz(e|0,0,(c[2411766]|0)-e|0);c[3528556]=0;e=c[2433594]|0;c[2443776]=e;L99216:do{if((e|0)!=0){d=e|0;gGC(9660952,d|0,52)|0;switch(a[9660952]|0){case 0:{c[2309668]=638960;break L99216;break};case 3:{c[2309668]=639984;break L99216;break};case 4:{c[2309668]=7356016;break L99216;break};case 5:{c[2309668]=7354992;break L99216;break};case 2:{c[2309668]=638960;break L99216;break};case 1:{c[2309668]=634096;break L99216;break};default:{break L99216}}}}while(0);c[2113164]=c[2432850];gu[c[e+56>>2]&16383]();b=c[2443776]|0;if((b|0)!=0){d=b|0;gGC(d|0,9660952,52)|0}c[9731400+(c[3528556]<<2)>>2]=c[2113164];c[2443776]=0;c[3528556]=-1;a[9660536]=0;a[9771528]=c[2388484]&255;c[2440434]=0;c[2388380]=1}}while(0);d=a[9635416]&-68;a[9550048]=d;a[9549864]=0;b=0;f=d;d=0;do{f=((a[9634032+b|0]&1)<<b^f&255)&255;d=((a[9631824+b|0]&1)<<b^d&255)&255;b=b+1|0;}while((b|0)<8);a[9550048]=f;a[9549864]=d;d=c[2440590]|0;c[3528556]=0;f=c[2433594]|0;c[2443776]=f;L99248:do{if((f|0)!=0){b=f|0;gGC(9660952,b|0,52)|0;switch(a[9660952]|0){case 2:{c[2309668]=638960;break L99248;break};case 5:{c[2309668]=7354992;break L99248;break};case 4:{c[2309668]=7356016;break L99248;break};case 0:{c[2309668]=638960;break L99248;break};case 1:{c[2309668]=634096;break L99248;break};case 3:{c[2309668]=639984;break L99248;break};default:{break L99248}}}}while(0);c[2113164]=c[2432850];a[672616]=0;b=(d|0)/15720|0;d=0;g=f;while(1){f=gj[c[g+52>>2]&4095](b)|0;c[2113164]=(c[2113164]|0)+f;f=(d|0)==240;L99260:do{switch(d|0){case 240:case 208:case 176:case 146:case 112:case 80:case 48:case 16:{h=d>>>5&1;if((h|0)==1){gg[c[(c[2443776]|0)+64>>2]&4095](0,1)}else if((h|0)==0){gg[c[(c[2443776]|0)+64>>2]&4095](0,0)}if(!f){i=81153;break L99260}a[672616]=1;j=241;break};default:{i=81153}}}while(0);if((i|0)==81153){i=0;f=d+1|0;if((f|0)<262){j=f}else{break}}d=j;g=c[2443776]|0}g=c[2443776]|0;if((g|0)!=0){j=g|0;gGC(j|0,9660952,52)|0}c[9731400+(c[3528556]<<2)>>2]=c[2113164];c[2443776]=0;c[3528556]=-1;j=c[2112964]|0;if((j|0)!=0&(c[3528604]|0)!=0){g=a[9688]|0?534:0;TQ(0,j,g);TQ(1,j,g);TQ(2,j,g)}if((c[2112968]|0)==0){return 0}dvb()|0;return 0}function dvb(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((a[9547720]|0)!=0){b=c[2387238]|0;e=c[3530092]|0;f=0;do{g=d[b+f|0]|0;h=g>>>5;i=g>>>2&7;j=g&3;c[e+(f<<2)>>2]=h<<10&6144|h<<13|i<<5|i<<8|(j<<6|j<<4|j<<2)>>>3;f=f+1|0;}while((f|0)<256);a[9547720]=0}f=c[2113070]|0;e=c[2386244]|0;b=c[2112926]|0;j=c[2387830]|0;i=c[2113068]|0;h=0;do{g=h<<3&504;k=((h|0)/64|0)<<3;if((g|0)<(i|0)&(k|0)<(f|0)){l=h<<1;m=d[e+(l|1)|0]|0;Si(b,m<<8&1792|d[e+l|0],g,k,m>>>4,4,0,j)}h=h+1|0;}while((h|0)<2048);R8(c[3530092]|0);return 0}function dvc(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;e=i;i=i+208|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;l=e+80|0;m=e+96|0;n=e+112|0;o=e+128|0;p=e+144|0;q=e+160|0;r=e+176|0;s=e+192|0;if((d|0)!=0){c[d>>2]=169767}t=(b&8|0)==0;if(!t){gGz(s|0,0,12);c[s>>2]=c[2406302];c[s+4>>2]=512;c[s+12>>2]=405e3;u=c[2076592]|0;gj[u&4095](s)|0}if((b&96|0)!=0){gGz(s|0,0,12);u=c[2414734]|0;c[s>>2]=u;c[s+4>>2]=(c[2411766]|0)-u;c[s+12>>2]=162152;u=c[2076592]|0;gj[u&4095](s)|0;s=q|0;if((b&64|0)!=0&(c[2113166]|0)>0){u=q+7|0;q=p|0;v=p+4|0;w=p+12|0;x=o;y=o|0;z=o+4|0;A=o+12|0;B=n;C=n|0;D=n+4|0;E=n+12|0;F=m;G=m|0;H=m+4|0;I=m+12|0;J=0;do{K=c[9734376+(J<<2)>>2]|0;L=K+36|0;M=c[L>>2]|0;gGC(s|0,614768,9)|0;a[u]=J+48&255;c[q>>2]=K;c[v>>2]=52;c[w>>2]=s;gj[c[2076592]&4095](p)|0;gGz(x|0,0,12);c[y>>2]=K+3172;c[z>>2]=4;c[A>>2]=165288;gj[c[2076592]&4095](o)|0;gGz(B|0,0,12);c[C>>2]=K+3176;c[D>>2]=4;c[E>>2]=501592;gj[c[2076592]&4095](n)|0;gGz(F|0,0,12);c[G>>2]=K+3180;c[H>>2]=4;c[I>>2]=386080;gj[c[2076592]&4095](m)|0;c[L>>2]=M;J=J+1|0;}while((J|0)<(c[2113166]|0))}if(!t){gGz(l|0,0,12);c[l>>2]=9660536;c[l+4>>2]=1;c[l+12>>2]=182496;t=c[2076592]|0;gj[t&4095](l)|0;gGz(k|0,0,12);c[k>>2]=9771528;c[k+4>>2]=1;c[k+12>>2]=506152;l=c[2076592]|0;gj[l&4095](k)|0;gGz(j|0,0,12);c[j>>2]=9620552;c[j+4>>2]=1;c[j+12>>2]=390048;k=c[2076592]|0;gj[k&4095](j)|0;gGz(h|0,0,12);c[h>>2]=9620512;c[h+4>>2]=1;c[h+12>>2]=303280;j=c[2076592]|0;gj[j&4095](h)|0;gGz(g|0,0,12);c[g>>2]=9620560;c[g+4>>2]=1;c[g+12>>2]=231248;h=c[2076592]|0;gj[h&4095](g)|0;gGz(f|0,0,12);c[f>>2]=9627080;c[f+4>>2]=1;c[f+12>>2]=180320;g=c[2076592]|0;gj[g&4095](f)|0}if((c[3528604]|0)!=0){TU(b,d)}gGz(r|0,0,12);c[r>>2]=9761736;c[r+4>>2]=4;c[r+12>>2]=382576;d=c[2076592]|0;gj[d&4095](r)|0}if((b&2|0)==0){i=e;return 0}a[9547720]=1;i=e;return 0}function dvd(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>1){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3132308+(b*112|0)>>2];c[a+104>>2]=c[3132312+(b*112|0)>>2];c[a+108>>2]=c[3132316+(b*112|0)>>2];d=0;return d|0}function dve(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<2&(d|0)==0)){e=1;return e|0}c[a>>2]=3132208+(b*112|0);e=0;return e|0}function dvf(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>2){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3131972+(b*112|0)>>2];c[a+104>>2]=c[3131976+(b*112|0)>>2];c[a+108>>2]=c[3131980+(b*112|0)>>2];d=0;return d|0}function dvg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<3&(d|0)==0)){e=1;return e|0}c[a>>2]=3131872+(b*112|0);e=0;return e|0}function dvh(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>1){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1616820+(b*112|0)>>2];c[a+104>>2]=c[1616824+(b*112|0)>>2];c[a+108>>2]=c[1616828+(b*112|0)>>2];d=0;return d|0}function dvi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<2&(d|0)==0)){e=1;return e|0}c[a>>2]=1616720+(b*112|0);e=0;return e|0}function dvj(){return dvp(1)|0}function dvk(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>1){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3131748+(b*112|0)>>2];c[a+104>>2]=c[3131752+(b*112|0)>>2];c[a+108>>2]=c[3131756+(b*112|0)>>2];d=0;return d|0}function dvl(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<2&(d|0)==0)){e=1;return e|0}c[a>>2]=3131648+(b*112|0);e=0;return e|0}function dvm(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4261160+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dvn(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>1){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1616596+(b*112|0)>>2];c[a+104>>2]=c[1616600+(b*112|0)>>2];c[a+108>>2]=c[1616604+(b*112|0)>>2];d=0;return d|0}function dvo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<2&(d|0)==0)){e=1;return e|0}c[a>>2]=1616496+(b*112|0);e=0;return e|0}function dvp(b){b=b|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=i;i=i+240|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;c[2415028]=0;c[3531200]=0;c[2387830]=65536;c[3530092]=196608;c[2406302]=197632;c[2414734]=198144;c[2386244]=198144;c[3531210]=202240;c[2387238]=206336;c[2411766]=206592;l=0;while(1){if((l|0)>=1024){break}m=9638528+(l<<2)|0;if((c[m>>2]|0)==0){n=81261;break}else{l=l+1|0}}do{if((n|0)==81261){l=gGq(206592)|0;c[m>>2]=l;if((l|0)==0){break}c[2415028]=l;gGz(l|0,0,206592);c[3531200]=l;c[2387830]=l+65536;c[3530092]=l+196608;c[2406302]=l+197632;o=l+198144|0;c[2414734]=o;c[2386244]=o;c[3531210]=l+202240;c[2387238]=l+206336;o=l+206592|0;c[2411766]=o;c[2414314]=o;if((c[3542200]|0)==0){p=1;i=e;return p|0}o=j+108|0;c[o>>2]=0;q=j+100|0;c[q>>2]=0;r=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[r&16383](j,0)|0;do{if((c[o>>2]|0)!=0){r=c[q>>2]|0;c[k>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](k,0,0)|0;if((r|0)<1){p=1;i=e;return p|0}if((gzL(l,0,0)|0)==0){break}else{p=1}i=e;return p|0}}while(0);l=c[2387830]|0;if((c[3542200]|0)==0){p=1;i=e;return p|0}q=f+108|0;c[q>>2]=0;o=f+100|0;c[o>>2]=0;r=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[r&16383](f,1)|0;do{if((c[q>>2]|0)!=0){r=c[o>>2]|0;c[g>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](g,1,0)|0;if((r|0)<1){p=1;i=e;return p|0}if((gzL(l,0,1)|0)==0){break}else{p=1}i=e;return p|0}}while(0);l=c[2387830]|0;o=131070;do{q=l+((o|0)/2|0)|0;a[l+(o|1)|0]=a[q]&15;a[l+o|0]=(d[q]|0)>>>4;o=o-2|0;}while((o|0)>-1);fvI();c[3528556]=0;o=c[2433594]|0;c[2443776]=o;L99423:do{if((o|0)!=0){l=o|0;gGC(9660952,l|0,52)|0;switch(a[9660952]|0){case 0:{c[2309668]=638960;break L99423;break};case 1:{c[2309668]=634096;break L99423;break};case 4:{c[2309668]=7356016;break L99423;break};case 5:{c[2309668]=7354992;break L99423;break};case 3:{c[2309668]=639984;break L99423;break};case 2:{c[2309668]=638960;break L99423;break};default:{break L99423}}}}while(0);l=c[2432850]|0;c[2113164]=l;q=c[3531210]|0;r=0;s=0;while(1){t=q+(s<<8)|0;c[o+68+(s<<2)>>2]=t;c[o+68+(s+256<<2)>>2]=t;c[o+68+(s+512<<2)>>2]=t;t=r+1&65535;if((t&65535)>15){break}else{r=t;s=t&65535}}s=c[2386244]|0;r=16;q=16;while(1){t=s+((q<<8)-4096)|0;c[o+68+(q<<2)>>2]=t;c[o+68+(q+256<<2)>>2]=t;c[o+68+(q+512<<2)>>2]=t;t=r+1&65535;if((t&65535)>31){break}else{r=t;q=t&65535}}q=c[2387238]|0;c[o+196>>2]=q;c[o+2244>>2]=q;c[o+200>>2]=q;c[o+2248>>2]=q;c[o+204>>2]=q;c[o+2252>>2]=q;c[o+208>>2]=q;c[o+2256>>2]=q;q=c[2406302]|0;c[o+212>>2]=q;c[o+2260>>2]=q;r=q+256|0;c[o+216>>2]=r;c[o+2264>>2]=r;c[o+220>>2]=q;c[o+2268>>2]=q;c[o+224>>2]=r;c[o+2272>>2]=r;r=c[3531200]|0;q=128;s=128;while(1){t=r+(s<<8)|0;c[o+68+(s<<2)>>2]=t;c[o+68+(s+512<<2)>>2]=t;t=q+1&65535;if((t&65535)>255){break}else{q=t;s=t&65535}}c[o+3148>>2]=1050;c[o+3164>>2]=1050;c[o+3168>>2]=1050;c[o+3156>>2]=1050;c[o+3152>>2]=3356;c[o+3160>>2]=3356;s=o|0;gGC(s|0,9660952,52)|0;c[2432850]=l;c[2443776]=0;c[3528556]=-1;gGC(9553936,6996288,144)|0;a[9660536]=0;a[9771528]=3;a[14115672]=(c[2392]|0)!=-1|0;c[3528604]=b;s=(b|0)!=0?1843200:1789772;c[2440590]=s;if((b|0)!=0){TS(0,s,32768,6,0,0);TS(1,c[2440590]|0,32768,6,0,1);TS(2,c[2440590]|0,32768,6,0,1);s=c[2420348]|0;h[s+192>>3]=.5;c[s+200>>2]=3;s=c[2420346]|0;h[s+192>>3]=.5;c[s+200>>2]=3;s=c[2420344]|0;h[s+192>>3]=.5;c[s+200>>2]=3}s=c[642608+(c[2436]<<2)>>2]|0;q=c[s+128>>2]|0;if((c[s+52>>2]&4|0)==0){c[2113068]=q;r=c[s+132>>2]|0;c[2113070]=r;c[2443814]=q;c[2440436]=r;u=q;v=r}else{c[2113070]=q;r=c[s+132>>2]|0;c[2113068]=r;c[2440436]=q;c[2443814]=r;u=r;v=q}q=ag(u<<1,v)|0;r=gGq(q)|0;c[2112926]=r;if((r|0)!=0){gGz(r|0,0,q|0)}gGz(c[2406302]|0,-1|0,512);q=c[2414734]|0;gGz(q|0,0,(c[2411766]|0)-q|0);c[3528556]=0;q=c[2433594]|0;c[2443776]=q;L99452:do{if((q|0)!=0){r=q|0;gGC(9660952,r|0,52)|0;switch(a[9660952]|0){case 1:{c[2309668]=634096;break L99452;break};case 0:{c[2309668]=638960;break L99452;break};case 3:{c[2309668]=639984;break L99452;break};case 4:{c[2309668]=7356016;break L99452;break};case 5:{c[2309668]=7354992;break L99452;break};case 2:{c[2309668]=638960;break L99452;break};default:{break L99452}}}}while(0);c[2113164]=c[2432850];gu[c[q+56>>2]&16383]();l=c[2443776]|0;if((l|0)!=0){o=l|0;gGC(o|0,9660952,52)|0}c[9731400+(c[3528556]<<2)>>2]=c[2113164];c[2443776]=0;c[3528556]=-1;a[9660536]=0;a[9771528]=c[2388484]&255;c[2388380]=0;c[2440434]=0;p=0;i=e;return p|0}}while(0);c[2415028]=0;p=1;i=e;return p|0}function dvq(b){b=b|0;var e=0,f=0,g=0;e=b&65535;if((e&49152|0)==16384){b=a[(c[3531200]|0)+((d[9771528]|0)<<14&16384|e&16383)|0]|0;if((e&8192|0)==0){f=b;return f|0}g=e&8191;Tk(g)|0;f=b;return f|0}b=e&64543;if((b|0)==10248){f=(a[672616]|0?64:0)|a[9550048];return f|0}else if((b|0)==10264){f=a[9549864]|0;return f|0}else{f=0;return f|0}return 0}function dvr(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=b&65535;b=e&64512;if((b|0)==9216){if((c[2440434]|0)!=0){a[(c[2406302]|0)+(e&511)|0]=d}c[2440434]=0;return}else if((b|0)==8192){f=e&255;a[(c[2387238]|0)+f|0]=d;g=d&255;h=g>>>5;i=g>>>2&7;j=g&3;c[(c[3530092]|0)+(f<<2)>>2]=h<<10&6144|h<<13|i<<5|i<<8|(j<<6|j<<4|j<<2)>>>3;return}else{do{if((c[3528604]|0)==0){j=e&64528;if(!((j|0)==10240|(j|0)==10256)){break}return}else{if((e|0)==10242){TR(0,d&255);return}else if((e|0)==10244){TR(1,d&255);return}else if((e|0)==10246){TR(2,d&255);return}else{break}}}while(0);if((b|0)==12288){c[2388380]=0;return}else if((b|0)==13312){c[2440434]=1;return}else if((b|0)==14336){gg[c[(c[2443776]|0)+64>>2]&4095](0,0);return}else{return}}}function dvs(b){b=b|0;var c=0,d=0;c=b&57456;if((c|0)==8240){d=(a[672608]|0?-128:0)|a[9635409]}else if((c|0)==8208){d=a[9550713]|0}else if((c|0)==8224){d=a[9635408]|0}else if((c|0)==8192){d=a[9550712]|0}else{d=0}return d|0}function dvt(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=b&65535;if((e&57440|0)==8288){a[(c[2387236]|0)+(e&31)|0]=d;return}switch(e&57456|0){case 8240:{a[c[3528318]|0]=d;return};case 8224:{a[c[2406640]|0]=d;return};case 8192:{a[c[2438886]|0]=d;return};case 8256:{e=a[9757288]|0;b=e&255;do{if((b&32|0)==0){f=e}else{if((d&32)!=0){f=e;break}g=a[c[3528318]|0]|0;h=g&255;if((b&16|0)!=0){c[3542228]=h&15;f=e;break}i=c[3542228]|0;if((i|0)>15){f=e;break}do{if((i|0)<14){if((i|0)!=13){if((a[14168916+i|0]|0)==g<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(0,i,h);f=a[9757288]|0}}while(0);e=f&255;do{if((e&128|0)!=0&d<<24>>24>-1){f=a[c[3528318]|0]|0;b=f&255;if((e&64|0)!=0){c[3542228]=b&15;break}g=c[3542228]|0;if((g|0)>15){break}do{if((g|0)<14){if((g|0)!=13){if((a[14168916+g|0]|0)==f<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(0,g,b)}}while(0);a[9757288]=d;return};case 8208:{gg[c[(c[2443776]|0)+64>>2]&4095](0,0);return};default:{return}}}function dvu(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2524124+(b*112|0)>>2];c[a+104>>2]=c[2524128+(b*112|0)>>2];c[a+108>>2]=c[2524132+(b*112|0)>>2];d=0;return d|0}function dvv(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=2524024+(b*112|0);e=0;return e|0}function dvw(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6934176+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dvx(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>26){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7444056+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dvy(){var b=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0.0,am=0,an=0,ao=0,ap=0;b=i;i=i+2280|0;e=b|0;f=b+112|0;g=b+120|0;j=b+232|0;k=b+240|0;l=b+352|0;m=b+360|0;n=b+472|0;o=b+480|0;p=b+592|0;q=b+600|0;r=b+712|0;s=b+720|0;t=b+832|0;u=b+840|0;v=b+952|0;w=b+960|0;x=b+1072|0;y=b+1080|0;z=b+1192|0;A=b+1200|0;B=b+1312|0;C=b+1320|0;D=b+1432|0;E=b+1440|0;F=b+1552|0;G=b+1560|0;H=b+1672|0;I=b+1680|0;J=b+1792|0;K=b+1800|0;L=b+1912|0;M=b+1920|0;N=b+2032|0;O=b+2040|0;P=b+2152|0;Q=b+2160|0;R=b+2272|0;c[2424]=5744;c[2415026]=0;c[3531198]=0;c[3530888]=65536;c[3530652]=196608;c[3530462]=327680;c[3531028]=458752;c[3530090]=458784;c[2414732]=459040;c[3531208]=459040;c[2406502]=463136;c[2406582]=465184;c[2387236]=467232;c[3528742]=467264;c[3528318]=467265;c[2406640]=467266;c[2438886]=467267;c[2411764]=467268;c[2386500]=460960;S=0;while(1){if((S|0)>=1024){break}T=9638528+(S<<2)|0;if((c[T>>2]|0)==0){U=81422;break}else{S=S+1|0}}do{if((U|0)==81422){S=gGq(467268)|0;c[T>>2]=S;if((S|0)==0){break}c[2415026]=S;gGz(S|0,0,467268);c[3531198]=S;c[3530888]=S+65536;c[3530652]=S+196608;c[3530462]=S+327680;c[3531028]=S+458752;c[3530090]=S+458784;V=S+459040|0;c[2414732]=V;c[3531208]=V;c[2406502]=S+463136;c[2406582]=S+465184;c[2387236]=S+467232;c[3528742]=S+467264;c[3528318]=S+467265;c[2406640]=S+467266;c[2438886]=S+467267;V=S+467268|0;c[2411764]=V;c[2386500]=S+460960;c[2414312]=V;V=S+16384|0;if((c[3542200]|0)==0){W=1;i=b;return W|0}S=Q+108|0;c[S>>2]=0;X=Q+100|0;c[X>>2]=0;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Y&16383](Q,0)|0;do{if((c[S>>2]|0)!=0){Y=c[X>>2]|0;c[R>>2]=9534384;Z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Z&16383](R,0,0)|0;if((Y|0)<1){W=1;i=b;return W|0}if((gzL(V,0,0)|0)==0){break}else{W=1}i=b;return W|0}}while(0);V=(c[3531198]|0)+24576|0;if((c[3542200]|0)==0){W=1;i=b;return W|0}X=O+108|0;c[X>>2]=0;S=O+100|0;c[S>>2]=0;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Y&16383](O,1)|0;do{if((c[X>>2]|0)!=0){Y=c[S>>2]|0;c[P>>2]=9534384;Z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Z&16383](P,1,0)|0;if((Y|0)<1){W=1;i=b;return W|0}if((gzL(V,0,1)|0)==0){break}else{W=1}i=b;return W|0}}while(0);V=(c[3531198]|0)+32768|0;if((c[3542200]|0)==0){W=1;i=b;return W|0}S=M+108|0;c[S>>2]=0;X=M+100|0;c[X>>2]=0;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Y&16383](M,2)|0;do{if((c[S>>2]|0)!=0){Y=c[X>>2]|0;c[N>>2]=9534384;Z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Z&16383](N,2,0)|0;if((Y|0)<1){W=1;i=b;return W|0}if((gzL(V,0,2)|0)==0){break}else{W=1}i=b;return W|0}}while(0);V=(c[3531198]|0)+40960|0;if((c[3542200]|0)==0){W=1;i=b;return W|0}X=K+108|0;c[X>>2]=0;S=K+100|0;c[S>>2]=0;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Y&16383](K,3)|0;do{if((c[X>>2]|0)!=0){Y=c[S>>2]|0;c[L>>2]=9534384;Z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Z&16383](L,3,0)|0;if((Y|0)<1){W=1;i=b;return W|0}if((gzL(V,0,3)|0)==0){break}else{W=1}i=b;return W|0}}while(0);V=(c[3531198]|0)+49152|0;if((c[3542200]|0)==0){W=1;i=b;return W|0}S=I+108|0;c[S>>2]=0;X=I+100|0;c[X>>2]=0;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Y&16383](I,4)|0;do{if((c[S>>2]|0)!=0){Y=c[X>>2]|0;c[J>>2]=9534384;Z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Z&16383](J,4,0)|0;if((Y|0)<1){W=1;i=b;return W|0}if((gzL(V,0,4)|0)==0){break}else{W=1}i=b;return W|0}}while(0);V=(c[3531198]|0)+57344|0;if((c[3542200]|0)==0){W=1;i=b;return W|0}X=G+108|0;c[X>>2]=0;S=G+100|0;c[S>>2]=0;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Y&16383](G,5)|0;do{if((c[X>>2]|0)!=0){Y=c[S>>2]|0;c[H>>2]=9534384;Z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Z&16383](H,5,0)|0;if((Y|0)<1){W=1;i=b;return W|0}if((gzL(V,0,5)|0)==0){break}else{W=1}i=b;return W|0}}while(0);V=c[3530888]|0;if((c[3542200]|0)==0){W=1;i=b;return W|0}S=E+108|0;c[S>>2]=0;X=E+100|0;c[X>>2]=0;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Y&16383](E,6)|0;do{if((c[S>>2]|0)!=0){Y=c[X>>2]|0;c[F>>2]=9534384;Z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Z&16383](F,6,0)|0;if((Y|0)<1){W=1;i=b;return W|0}if((gzL(V,0,6)|0)==0){break}else{W=1}i=b;return W|0}}while(0);V=(c[3530888]|0)+8192|0;if((c[3542200]|0)==0){W=1;i=b;return W|0}X=C+108|0;c[X>>2]=0;S=C+100|0;c[S>>2]=0;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Y&16383](C,7)|0;do{if((c[X>>2]|0)!=0){Y=c[S>>2]|0;c[D>>2]=9534384;Z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Z&16383](D,7,0)|0;if((Y|0)<1){W=1;i=b;return W|0}if((gzL(V,0,7)|0)==0){break}else{W=1}i=b;return W|0}}while(0);V=(c[3530888]|0)+16384|0;if((c[3542200]|0)==0){W=1;i=b;return W|0}S=A+108|0;c[S>>2]=0;X=A+100|0;c[X>>2]=0;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Y&16383](A,8)|0;do{if((c[S>>2]|0)!=0){Y=c[X>>2]|0;c[B>>2]=9534384;Z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Z&16383](B,8,0)|0;if((Y|0)<1){W=1;i=b;return W|0}if((gzL(V,0,8)|0)==0){break}else{W=1}i=b;return W|0}}while(0);V=(c[3530888]|0)+24576|0;if((c[3542200]|0)==0){W=1;i=b;return W|0}X=y+108|0;c[X>>2]=0;S=y+100|0;c[S>>2]=0;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Y&16383](y,9)|0;do{if((c[X>>2]|0)!=0){Y=c[S>>2]|0;c[z>>2]=9534384;Z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Z&16383](z,9,0)|0;if((Y|0)<1){W=1;i=b;return W|0}if((gzL(V,0,9)|0)==0){break}else{W=1}i=b;return W|0}}while(0);V=(c[3530888]|0)+32768|0;if((c[3542200]|0)==0){W=1;i=b;return W|0}S=w+108|0;c[S>>2]=0;X=w+100|0;c[X>>2]=0;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Y&16383](w,10)|0;do{if((c[S>>2]|0)!=0){Y=c[X>>2]|0;c[x>>2]=9534384;Z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Z&16383](x,10,0)|0;if((Y|0)<1){W=1;i=b;return W|0}if((gzL(V,0,10)|0)==0){break}else{W=1}i=b;return W|0}}while(0);V=(c[3530888]|0)+40960|0;if((c[3542200]|0)==0){W=1;i=b;return W|0}X=u+108|0;c[X>>2]=0;S=u+100|0;c[S>>2]=0;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Y&16383](u,11)|0;do{if((c[X>>2]|0)!=0){Y=c[S>>2]|0;c[v>>2]=9534384;Z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Z&16383](v,11,0)|0;if((Y|0)<1){W=1;i=b;return W|0}if((gzL(V,0,11)|0)==0){break}else{W=1}i=b;return W|0}}while(0);V=c[3530652]|0;if((c[3542200]|0)==0){W=1;i=b;return W|0}S=s+108|0;c[S>>2]=0;X=s+100|0;c[X>>2]=0;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Y&16383](s,12)|0;do{if((c[S>>2]|0)!=0){Y=c[X>>2]|0;c[t>>2]=9534384;Z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Z&16383](t,12,0)|0;if((Y|0)<1){W=1;i=b;return W|0}if((gzL(V,0,12)|0)==0){break}else{W=1}i=b;return W|0}}while(0);V=(c[3530652]|0)+8192|0;if((c[3542200]|0)==0){W=1;i=b;return W|0}X=q+108|0;c[X>>2]=0;S=q+100|0;c[S>>2]=0;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Y&16383](q,13)|0;do{if((c[X>>2]|0)!=0){Y=c[S>>2]|0;c[r>>2]=9534384;Z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Z&16383](r,13,0)|0;if((Y|0)<1){W=1;i=b;return W|0}if((gzL(V,0,13)|0)==0){break}else{W=1}i=b;return W|0}}while(0);V=(c[3530652]|0)+16384|0;if((c[3542200]|0)==0){W=1;i=b;return W|0}S=o+108|0;c[S>>2]=0;X=o+100|0;c[X>>2]=0;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Y&16383](o,14)|0;do{if((c[S>>2]|0)!=0){Y=c[X>>2]|0;c[p>>2]=9534384;Z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Z&16383](p,14,0)|0;if((Y|0)<1){W=1;i=b;return W|0}if((gzL(V,0,14)|0)==0){break}else{W=1}i=b;return W|0}}while(0);V=(c[3530652]|0)+24576|0;if((c[3542200]|0)==0){W=1;i=b;return W|0}X=m+108|0;c[X>>2]=0;S=m+100|0;c[S>>2]=0;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Y&16383](m,15)|0;do{if((c[X>>2]|0)!=0){Y=c[S>>2]|0;c[n>>2]=9534384;Z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Z&16383](n,15,0)|0;if((Y|0)<1){W=1;i=b;return W|0}if((gzL(V,0,15)|0)==0){break}else{W=1}i=b;return W|0}}while(0);V=(c[3530652]|0)+32768|0;if((c[3542200]|0)==0){W=1;i=b;return W|0}S=k+108|0;c[S>>2]=0;X=k+100|0;c[X>>2]=0;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Y&16383](k,16)|0;do{if((c[S>>2]|0)!=0){Y=c[X>>2]|0;c[l>>2]=9534384;Z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Z&16383](l,16,0)|0;if((Y|0)<1){W=1;i=b;return W|0}if((gzL(V,0,16)|0)==0){break}else{W=1}i=b;return W|0}}while(0);V=(c[3530652]|0)+40960|0;if((c[3542200]|0)==0){W=1;i=b;return W|0}X=g+108|0;c[X>>2]=0;S=g+100|0;c[S>>2]=0;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Y&16383](g,17)|0;do{if((c[X>>2]|0)!=0){Y=c[S>>2]|0;c[j>>2]=9534384;Z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Z&16383](j,17,0)|0;if((Y|0)<1){W=1;i=b;return W|0}if((gzL(V,0,17)|0)==0){break}else{W=1}i=b;return W|0}}while(0);V=c[3531028]|0;if((c[3542200]|0)==0){W=1;i=b;return W|0}S=e+108|0;c[S>>2]=0;X=e+100|0;c[X>>2]=0;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Y&16383](e,18)|0;do{if((c[S>>2]|0)==0){_=0}else{Y=c[X>>2]|0;c[f>>2]=9534384;Z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Z&16383](f,18,0)|0;if((Y|0)<1){W=1;i=b;return W|0}if((gzL(V,0,18)|0)==0){_=0;break}else{W=1}i=b;return W|0}}while(0);while(1){if((_|0)>=1024){W=1;U=81603;break}$=9638528+(_<<2)|0;if((c[$>>2]|0)==0){break}else{_=_+1|0}}if((U|0)==81603){i=b;return W|0}V=gGq(65536)|0;c[$>>2]=V;if((V|0)==0){W=1;i=b;return W|0}gGz(V|0,0,65536);X=c[3530888]|0;gGC(V|0,X|0,65536)|0;S=0;do{Y=S<<6;gGz(X+Y|0,0,64);Z=Y+262144|0;aa=0;do{ab=Z+(c[609008+(aa<<2)>>2]|0)|0;ac=(aa<<3)+Y|0;ad=0;do{ae=ab+(c[612640+(ad+8<<2)>>2]|0)|0;if((d[V+((ae|0)/8|0)|0]&128>>>((ae&7)>>>0)|0)!=0){ae=X+(ac+ad)|0;a[ae]=a[ae]|4}ad=ad+1|0;}while((ad|0)<8);aa=aa+1|0;}while((aa|0)<8);aa=Y+131072|0;Z=0;while(1){ad=aa+(c[609008+(Z<<2)>>2]|0)|0;ac=(Z<<3)+Y|0;ab=0;do{ae=ad+(c[612640+(ab+8<<2)>>2]|0)|0;if((d[V+((ae|0)/8|0)|0]&128>>>((ae&7)>>>0)|0)!=0){ae=X+(ac+ab)|0;a[ae]=a[ae]|2}ab=ab+1|0;}while((ab|0)<8);ab=Z+1|0;if((ab|0)<8){Z=ab}else{af=0;break}}do{Z=Y+(c[609008+(af<<2)>>2]|0)|0;aa=(af<<3)+Y|0;ab=0;do{ac=Z+(c[612640+(ab+8<<2)>>2]|0)|0;if((d[V+((ac|0)/8|0)|0]&128>>>((ac&7)>>>0)|0)!=0){ac=X+(aa+ab)|0;a[ac]=a[ac]|1}ab=ab+1|0;}while((ab|0)<8);af=af+1|0;}while((af|0)<8);S=S+1|0;}while((S|0)<2048);S=c[3530462]|0;X=0;do{Y=X<<8;gGz(S+Y|0,0,256);ab=Y+262144|0;aa=0;do{Z=ab+(c[609008+(aa<<2)>>2]|0)|0;ac=(aa<<4)+Y|0;ad=0;do{ae=Z+(c[612640+(ad<<2)>>2]|0)|0;if((d[V+((ae|0)/8|0)|0]&128>>>((ae&7)>>>0)|0)!=0){ae=S+(ac+ad)|0;a[ae]=a[ae]|4}ad=ad+1|0;}while((ad|0)<16);aa=aa+1|0;}while((aa|0)<16);aa=Y+131072|0;ab=0;while(1){ad=aa+(c[609008+(ab<<2)>>2]|0)|0;ac=(ab<<4)+Y|0;Z=0;do{ae=ad+(c[612640+(Z<<2)>>2]|0)|0;if((d[V+((ae|0)/8|0)|0]&128>>>((ae&7)>>>0)|0)!=0){ae=S+(ac+Z)|0;a[ae]=a[ae]|2}Z=Z+1|0;}while((Z|0)<16);Z=ab+1|0;if((Z|0)<16){ab=Z}else{ah=0;break}}do{ab=Y+(c[609008+(ah<<2)>>2]|0)|0;aa=(ah<<4)+Y|0;Z=0;do{ac=ab+(c[612640+(Z<<2)>>2]|0)|0;if((d[V+((ac|0)/8|0)|0]&128>>>((ac&7)>>>0)|0)!=0){ac=S+(aa+Z)|0;a[ac]=a[ac]|1}Z=Z+1|0;}while((Z|0)<16);ah=ah+1|0;}while((ah|0)<16);X=X+1|0;}while((X|0)<512);X=c[3530652]|0;gGC(V|0,X|0,65536)|0;S=0;while(1){Y=S<<8;gGz(X+Y|0,0,256);Z=Y+262144|0;aa=0;do{ab=Z+(c[609008+(aa<<2)>>2]|0)|0;ac=(aa<<4)+Y|0;ad=0;do{ae=ab+(c[612640+(ad<<2)>>2]|0)|0;if((d[V+((ae|0)/8|0)|0]&128>>>((ae&7)>>>0)|0)!=0){ae=X+(ac+ad)|0;a[ae]=a[ae]|4}ad=ad+1|0;}while((ad|0)<16);aa=aa+1|0;}while((aa|0)<16);aa=Y+131072|0;Z=0;while(1){ad=aa+(c[609008+(Z<<2)>>2]|0)|0;ac=(Z<<4)+Y|0;ab=0;do{ae=ad+(c[612640+(ab<<2)>>2]|0)|0;if((d[V+((ae|0)/8|0)|0]&128>>>((ae&7)>>>0)|0)!=0){ae=X+(ac+ab)|0;a[ae]=a[ae]|2}ab=ab+1|0;}while((ab|0)<16);ab=Z+1|0;if((ab|0)<16){Z=ab}else{ai=0;break}}do{Z=Y+(c[609008+(ai<<2)>>2]|0)|0;aa=(ai<<4)+Y|0;ab=0;do{ac=Z+(c[612640+(ab<<2)>>2]|0)|0;if((d[V+((ac|0)/8|0)|0]&128>>>((ac&7)>>>0)|0)!=0){ac=X+(aa+ab)|0;a[ac]=a[ac]|1}ab=ab+1|0;}while((ab|0)<16);ai=ai+1|0;}while((ai|0)<16);Y=S+1|0;if((Y|0)<512){S=Y}else{aj=0;break}}while(1){if((aj|0)>=1024){break}ak=9638528+(aj<<2)|0;if((c[ak>>2]|0)==(V|0)){U=81529;break}else{aj=aj+1|0}}if((U|0)==81529){gGr(V);c[ak>>2]=0}S=c[3531028]|0;X=c[3530090]|0;Y=0;do{ab=d[S+Y|0]|0;c[X+(Y+32<<2)>>2]=(-(ab>>>3&1)&33)+(-(ab>>>4&1)&71)+(-(ab>>>5&1)&151)<<3&2016|((-(ab>>>6&1)&71)+(-(ab>>>7)&151)|0)>>>3&31|(-(ab>>>1&1)&71)+(-(ab&1)&33)+(-(ab>>>2&1)&151)<<8&63488;Y=Y+1|0;}while((Y|0)<32);fvI();c[3528556]=0;Y=c[2433594]|0;c[2443776]=Y;L99892:do{if((Y|0)!=0){X=Y|0;gGC(9660952,X|0,52)|0;switch(a[9660952]|0){case 0:{c[2309668]=638960;break L99892;break};case 1:{c[2309668]=634096;break L99892;break};case 3:{c[2309668]=639984;break L99892;break};case 4:{c[2309668]=7356016;break L99892;break};case 5:{c[2309668]=7354992;break L99892;break};case 2:{c[2309668]=638960;break L99892;break};default:{break L99892}}}}while(0);X=c[2432850]|0;c[2113164]=X;S=c[3531208]|0;V=0;ab=0;while(1){aa=S+(ab<<8)|0;c[Y+68+(ab<<2)>>2]=aa;c[Y+68+(ab+256<<2)>>2]=aa;c[Y+68+(ab+512<<2)>>2]=aa;aa=V+1&65535;if((aa&65535)>15){break}else{V=aa;ab=aa&65535}}ab=c[2406502]|0;c[Y+132>>2]=ab;c[Y+1156>>2]=ab;c[Y+2180>>2]=ab;V=ab+256|0;c[Y+136>>2]=V;c[Y+1160>>2]=V;c[Y+2184>>2]=V;V=ab+512|0;c[Y+140>>2]=V;c[Y+1164>>2]=V;c[Y+2188>>2]=V;V=ab+768|0;c[Y+144>>2]=V;c[Y+1168>>2]=V;c[Y+2192>>2]=V;V=ab+1024|0;c[Y+148>>2]=V;c[Y+1172>>2]=V;c[Y+2196>>2]=V;V=ab+1280|0;c[Y+152>>2]=V;c[Y+1176>>2]=V;c[Y+2200>>2]=V;V=ab+1536|0;c[Y+156>>2]=V;c[Y+1180>>2]=V;c[Y+2204>>2]=V;V=ab+1792|0;c[Y+160>>2]=V;c[Y+1184>>2]=V;c[Y+2208>>2]=V;V=c[2406582]|0;c[Y+164>>2]=V;c[Y+1188>>2]=V;c[Y+2212>>2]=V;ab=V+256|0;c[Y+168>>2]=ab;c[Y+1192>>2]=ab;c[Y+2216>>2]=ab;ab=V+512|0;c[Y+172>>2]=ab;c[Y+1196>>2]=ab;c[Y+2220>>2]=ab;ab=V+768|0;c[Y+176>>2]=ab;c[Y+1200>>2]=ab;c[Y+2224>>2]=ab;ab=V+1024|0;c[Y+180>>2]=ab;c[Y+1204>>2]=ab;c[Y+2228>>2]=ab;ab=V+1280|0;c[Y+184>>2]=ab;c[Y+1208>>2]=ab;c[Y+2232>>2]=ab;ab=V+1536|0;c[Y+188>>2]=ab;c[Y+1212>>2]=ab;c[Y+2236>>2]=ab;ab=V+1792|0;c[Y+192>>2]=ab;c[Y+1216>>2]=ab;c[Y+2240>>2]=ab;ab=c[3531198]|0;V=64;S=64;while(1){aa=ab+(S<<8)|0;c[Y+68+(S<<2)>>2]=aa;c[Y+68+(S+512<<2)>>2]=aa;aa=V+1&65535;if((aa&65535)>255){break}else{V=aa;S=aa&65535}}c[Y+3152>>2]=3140;c[Y+3148>>2]=2094;S=Y|0;gGC(S|0,9660952,52)|0;c[2432850]=X;c[2443776]=0;c[3528556]=-1;S=a[9680]|0?32e3:0;c[3542220]=11200;V=c[2113008]|0;if((V|0)==0){gGz(14168888,0,252);c[3542223]=S;gGz(14168896,0,16);c[3542234]=~~((+(S|0)*32768.0*8.0+75.0e4)/15.0e5);ab=31;al=32767.0;while(1){c[14169012+(ab<<2)>>2]=~~(al+.5);aa=ab-1|0;if((aa|0)>0){ab=aa;al=al/1.188502227}else{break}}c[3542253]=0;h[1771269]=1.0;h[1771270]=1.0;h[1771271]=1.0;c[3542574]=3;c[3542575]=3;c[3542576]=3;mB(0);ab=(c[2113008]|0)+1|0;c[2113008]=ab;am=ab;an=a[9680]|0?32e3:0}else{am=V;an=S}c[3542220]=11200;if((am|0)==1){gGz(14169140,0,252);c[3542286]=an;gGz(14169148,0,16);c[3542297]=~~((+(an|0)*32768.0*8.0+75.0e4)/15.0e5);ab=31;al=32767.0;while(1){c[14169264+(ab<<2)>>2]=~~(al+.5);X=ab-1|0;if((X|0)>0){ab=X;al=al/1.188502227}else{break}}c[3542316]=0;h[1771272]=1.0;h[1771273]=1.0;h[1771274]=1.0;c[3542577]=3;c[3542578]=3;c[3542579]=3;mB(1);c[2113008]=(c[2113008]|0)+1}h[1771269]=.3;c[3542574]=3;h[1771270]=.3;c[3542575]=3;h[1771271]=.3;c[3542576]=3;h[1771272]=.3;c[3542577]=3;h[1771273]=.3;c[3542578]=3;h[1771274]=.3;c[3542579]=3;ab=c[642608+(c[2436]<<2)>>2]|0;S=c[ab+128>>2]|0;if((c[ab+52>>2]&4|0)==0){c[2113068]=S;V=c[ab+132>>2]|0;c[2113070]=V;c[2443814]=S;c[2440436]=V;ao=S;ap=V}else{c[2113070]=S;V=c[ab+132>>2]|0;c[2113068]=V;c[2440436]=S;c[2443814]=V;ao=V;ap=S}S=ag(ao<<1,ap)|0;V=gGq(S)|0;c[2112926]=V;if((V|0)!=0){gGz(V|0,0,S|0)}S=c[2414732]|0;gGz(S|0,0,(c[2411764]|0)-S|0);c[3528556]=0;S=c[2433594]|0;c[2443776]=S;L99927:do{if((S|0)!=0){V=S|0;gGC(9660952,V|0,52)|0;switch(a[9660952]|0){case 4:{c[2309668]=7356016;break L99927;break};case 5:{c[2309668]=7354992;break L99927;break};case 2:{c[2309668]=638960;break L99927;break};case 0:{c[2309668]=638960;break L99927;break};case 1:{c[2309668]=634096;break L99927;break};case 3:{c[2309668]=639984;break L99927;break};default:{break L99927}}}}while(0);c[2113164]=c[2432850];gu[c[S+56>>2]&16383]();V=c[2443776]|0;if((V|0)!=0){ab=V|0;gGC(ab|0,9660952,52)|0}c[9731400+(c[3528556]<<2)>>2]=c[2113164];c[2443776]=0;c[3528556]=-1;mB(0);mB(1);a[9757288]=0;W=0;i=b;return W|0}}while(0);c[2415026]=0;W=1;i=b;return W|0}function dvz(){var a=0,b=0,d=0,e=0,f=0;c[2113070]=0;c[2113068]=0;a=c[2112926]|0;if((a|0)!=0){gGr(a);c[2112926]=0}fvR();c[2113008]=0;c[2076598]=0;c[2383582]=0;a=c[2415026]|0;b=0;while(1){if((b|0)>=1024){break}d=9638528+(b<<2)|0;if((c[d>>2]|0)==(a|0)){e=81668;break}else{b=b+1|0}}if((e|0)==81668){gGr(a);c[d>>2]=0}c[2415026]=0;d=c[3528474]|0;a=0;while(1){if((a|0)>=1024){e=81674;break}f=9638528+(a<<2)|0;if((c[f>>2]|0)==(d|0)){break}else{a=a+1|0}}if((e|0)==81674){c[3528474]=0;return 0}gGr(d);c[f>>2]=0;c[3528474]=0;return 0}function dvA(){var e=0,f=0,g=0,h=0,i=0,j=0;if((a[9624624]|0)!=0){e=c[2414732]|0;gGz(e|0,0,(c[2411764]|0)-e|0);c[3528556]=0;e=c[2433594]|0;c[2443776]=e;L99963:do{if((e|0)!=0){f=e|0;gGC(9660952,f|0,52)|0;switch(a[9660952]|0){case 0:{c[2309668]=638960;break L99963;break};case 5:{c[2309668]=7354992;break L99963;break};case 1:{c[2309668]=634096;break L99963;break};case 2:{c[2309668]=638960;break L99963;break};case 4:{c[2309668]=7356016;break L99963;break};case 3:{c[2309668]=639984;break L99963;break};default:{break L99963}}}}while(0);c[2113164]=c[2432850];gu[c[e+56>>2]&16383]();e=c[2443776]|0;if((e|0)!=0){f=e|0;gGC(f|0,9660952,52)|0}c[9731400+(c[3528556]<<2)>>2]=c[2113164];c[2443776]=0;c[3528556]=-1;mB(0);mB(1);a[9757288]=0}if((c[3528474]|0)==0){f=a[9688]|0?534:0;e=gGq(f*12|0)|0;c[3528474]=e;c[2439098]=e;c[2439099]=e+(f<<1);c[2439100]=e+(f<<1<<1);c[2439101]=e+((f*3|0)<<1);c[2439102]=e+(f<<2<<1);c[2439103]=e+((f*5|0)<<1)}b[4775356]=-1;f=0;e=-1;g=-1;do{e=((a[9634024+f|0]&1)<<f^e&255)&255;g=((a[9631816+f|0]&1)<<f^g&255)&255;f=f+1|0;}while((f|0)<8);a[9550712]=e;a[9550713]=g;a[672608]=1;c[3528556]=0;g=c[2433594]|0;c[2443776]=g;L99983:do{if((g|0)!=0){e=g|0;gGC(9660952,e|0,52)|0;switch(a[9660952]|0){case 0:{c[2309668]=638960;break L99983;break};case 1:{c[2309668]=634096;break L99983;break};case 3:{c[2309668]=639984;break L99983;break};case 4:{c[2309668]=7356016;break L99983;break};case 5:{c[2309668]=7354992;break L99983;break};case 2:{c[2309668]=638960;break L99983;break};default:{break L99983}}}}while(0);c[2113164]=c[2432850];e=0;f=g;while(1){g=gj[c[f+52>>2]&4095](95)|0;c[2113164]=(c[2113164]|0)+g;do{if(((d[9634031]<<7|d[9634030]<<6)&192|0)==0){a[592128]=0;h=81705}else{if(a[592128]|0){h=81705;break}a[592128]=1;gg[c[(c[2443776]|0)+64>>2]&4095](32,1);g=c[(c[2443776]|0)+52>>2]|0;gj[g&4095](0)|0;gg[c[(c[2443776]|0)+64>>2]&4095](32,0);g=c[(c[2443776]|0)+52>>2]|0;gj[g&4095](0)|0;h=81711}}while(0);do{if((h|0)==81705){h=0;if((e|0)==248){i=1}else if((e|0)==8){i=0}else{if((e&15|0)!=0){h=81711;break}gg[c[(c[2443776]|0)+64>>2]&4095](0,1);h=81711;break}a[672608]=i;j=e+1|0}}while(0);if((h|0)==81711){h=0;g=e+1|0;if((g|0)<272){j=g}else{break}}e=j;f=c[2443776]|0}f=c[2443776]|0;if((f|0)!=0){j=f|0;gGC(j|0,9660952,52)|0}c[9731400+(c[3528556]<<2)>>2]=c[2113164];c[2443776]=0;c[3528556]=-1;j=c[2112964]|0;if((j|0)!=0){mF(9756392,j,a[9688]|0?534:0,0)}if((c[2112968]|0)==0){return 0}dvB()|0;return 0}function dvB(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;b=c[2438886]|0;e=c[3528742]|0;a[e]=(a[9635408]<<2^a[b])&-128;if((a[9547712]|0)==0){f=c[3530090]|0}else{g=c[3531028]|0;h=c[3530090]|0;i=0;do{j=d[g+i|0]|0;c[h+(i+32<<2)>>2]=(-(j>>>3&1)&33)+(-(j>>>4&1)&71)+(-(j>>>5&1)&151)<<3&2016|((-(j>>>6&1)&71)+(-(j>>>7)&151)|0)>>>3&31|(-(j>>>1&1)&71)+(-(j&1)&33)+(-(j>>>2&1)&151)<<8&63488;i=i+1|0;}while((i|0)<32);a[9547712]=0;f=h}h=c[2387236]|0;i=0;do{g=d[h+i|0]|0;c[f+(i<<2)>>2]=(-(g>>>3&1)&33)+(-(g>>>4&1)&71)+(-(g>>>5&1)&151)<<3&2016|((-(g>>>6&1)&71)+(-(g>>>7)&151)|0)>>>3&31|(-(g>>>1&1)&71)+(-(g&1)&33)+(-(g>>>2&1)&151)<<8&63488;i=i+1|0;}while((i|0)<32);i=d[b]<<8&1024;h=i|512;g=c[2406640]|0;j=c[2406582]|0;k=c[2112926]|0;l=c[3530652]|0;m=0;do{n=((m|0)/32|0)<<4^240;o=(m<<4&496)-(d[g]|0)|0;p=(o|0)<-15?o+256|0:o;o=d[j+(m+h)|0]<<8&256|d[j+(m+i)|0];q=m&16;if((a[e]|0)==0){r=0;s=q;t=n;u=p}else{r=1;s=q>>>4^1;t=240-n|0;u=240-p|0}p=u-8|0;do{if((s|0)==0){if(r){SB(k,o,t,p,0,3,16,l);break}else{Sz(k,o,t,p,0,3,16,l);break}}else{if(r){SF(k,o,t,p,0,3,16,l);break}else{SD(k,o,t,p,0,3,16,l);break}}}while(0);m=m+1|0;}while((m|0)<512);m=c[2386500]|0;l=c[3530462]|0;t=0;do{r=d[m+t|0]|0;do{if((r&1|0)!=0){s=d[m+(t|1)|0]|r<<4&256;u=r>>>3&1;i=r&4;j=r&2;h=d[m+(t|3)|0]|0;g=240-(d[m+(t|2)|0]|0)&255;if((a[e]|0)==0){v=g;w=240-h|0;x=j;y=i}else{v=240-g|0;w=h;x=j>>>1^1;y=i>>>2^1}i=(y|0)!=0;j=v-8|0;if((x|0)==0){if(i){SJ(k,s,w,j,u,3,0,0,l);break}else{SH(k,s,w,j,u,3,0,0,l);break}}else{if(i){SN(k,s,w,j,u,3,0,0,l);break}else{SL(k,s,w,j,u,3,0,0,l);break}}}}while(0);t=t+4|0;}while((t|0)<96);t=d[b]|0;b=t<<1&2|t>>>1&1;t=c[2406502]|0;l=c[3530888]|0;w=0;do{x=w<<3&248;v=((w|0)/32|0)<<3^248;y=d[t+(w+1024)|0]<<8&1792|d[t+w|0];if((a[e]|0)==0){Sr(k,y,v,x-8|0,b,3,0,32,l)}else{Sx(k,y,248-v|0,240-x|0,b,3,0,32,l)}w=w+1|0;}while((w|0)<1024);R8(f);return 0}function dvC(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;e=i;i=i+144|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;l=e+80|0;m=e+96|0;n=e+112|0;o=e+128|0;p=(d|0)==0;if(!p){c[d>>2]=169762}if((b&96|0)==0){i=e;return 0}gGz(o|0,0,12);q=c[2414732]|0;c[o>>2]=q;c[o+4>>2]=(c[2411764]|0)-q;c[o+12>>2]=162152;gj[c[2076592]&4095](o)|0;o=m|0;q=(b&64|0)==0;if((c[2113166]|0)>0&(q^1)){b=m+7|0;m=l|0;r=l+4|0;s=l+12|0;t=k;u=k|0;v=k+4|0;w=k+12|0;x=j;y=j|0;z=j+4|0;A=j+12|0;B=h;C=h|0;D=h+4|0;E=h+12|0;F=0;do{G=c[9734376+(F<<2)>>2]|0;H=G+36|0;I=c[H>>2]|0;gGC(o|0,614768,9)|0;a[b]=F+48&255;c[m>>2]=G;c[r>>2]=52;c[s>>2]=o;gj[c[2076592]&4095](l)|0;gGz(t|0,0,12);c[u>>2]=G+3172;c[v>>2]=4;c[w>>2]=165288;gj[c[2076592]&4095](k)|0;gGz(x|0,0,12);c[y>>2]=G+3176;c[z>>2]=4;c[A>>2]=501592;gj[c[2076592]&4095](j)|0;gGz(B|0,0,12);c[C>>2]=G+3180;c[D>>2]=4;c[E>>2]=386080;gj[c[2076592]&4095](h)|0;c[H>>2]=I;F=F+1|0;}while((F|0)<(c[2113166]|0))}F=g|0;do{if(!q){do{if(!p){if((c[d>>2]|0)>=169110){break}c[d>>2]=169110}}while(0);if((c[2113008]|0)<=0){break}g=f|0;h=f+4|0;E=f+8|0;D=f+12|0;C=0;do{cC(F|0,531144,(B=i,i=i+8|0,c[B>>2]=C,B)|0)|0;i=B;c[g>>2]=14168888+(C*252|0);c[h>>2]=252;c[E>>2]=0;c[D>>2]=F;gj[c[2076592]&4095](f)|0;C=C+1|0;}while((C|0)<(c[2113008]|0))}}while(0);gGz(n|0,0,12);c[n>>2]=9757288;c[n+4>>2]=1;c[n+12>>2]=584504;gj[c[2076592]&4095](n)|0;i=e;return 0}function dvD(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2526252+(b*112|0)>>2];c[a+104>>2]=c[2526256+(b*112|0)>>2];c[a+108>>2]=c[2526260+(b*112|0)>>2];d=0;return d|0}function dvE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=2526152+(b*112|0);e=0;return e|0}function dvF(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2528380+(b*112|0)>>2];c[a+104>>2]=c[2528384+(b*112|0)>>2];c[a+108>>2]=c[2528388+(b*112|0)>>2];d=0;return d|0}function dvG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<22&(d|0)==0)){e=1;return e|0}c[a>>2]=2528280+(b*112|0);e=0;return e|0}function dvH(e){e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=e&65535;switch(f|0){case 63501:{if((b[4853030]|0)!=1991){e=(d[9753362]|0)-(d[9753360]|0)|0;g=(d[9753363]|0)-(d[9753361]|0)|0;h=e+10|0;i=ag(h,h)|0;h=ag(g,g)|0;j=h+i|0;i=e+7|0;k=g+7|0;l=ag(i,i)|0;i=ag(k,k)|0;k=i+l|0;m=(k|0)<(j|0);n=m?k:j;j=g+10|0;k=ag(e,e)|0;o=(ag(j,j)|0)+k|0;j=(o|0)<(n|0);p=j?o:n;n=e-7|0;o=ag(n,n)|0;n=i+o|0;i=(n|0)<(p|0);q=i?n:p;p=e-10|0;e=h+(ag(p,p)|0)|0;p=(e|0)<(q|0);h=p?e:q;q=g-7|0;e=ag(q,q)|0;q=e+o|0;o=(q|0)<(h|0);n=o?q:h;h=g-10|0;g=(ag(h,h)|0)+k|0;k=(g|0)<(n|0);r=(e+l|0)<((k?g:n)|0)?-32:k?-64:o?-96:p?-128:i?96:j?64:(m&1)<<5;return r|0}m=c[2429446]|0;j=(m>>>6<<2&12|m>>>4&3)^12;i=m<<1;p=i&-512;o=i&30;i=a[592160+((o<<4|p|j)^496)|0]|0;k=a[592160+((30-o<<4)+p|j)|0]|0;j=((k<<24>>24>64?-55:-48)+k&255)+(((i<<24>>24>64?9:0)+i&255)<<4)&255;if((m&63|0)==63){r=j;return r|0}c[2429446]=m+1;r=j;return r|0};case 63499:case 63500:{r=a[9658008+(f-63499)|0]|0;return r|0};case 63496:case 63497:case 63498:{r=a[9657864+(f-63496)|0]|0;return r|0};default:{r=0;return r|0}}return 0}function dvI(b,d){b=b|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=b&65535;if((f&63488|0)==61440){g=c[2387234]|0;a[g+(f&2047)|0]=d;h=f&1023;i=a[g+(h|1024)|0]|0;j=a[g+h|0]|0;g=(j&-16|(j&255)>>>4)&255;k=(j<<4|j&15)&255;j=(i&-16|(i&255)>>>4)&255;c[(c[2406970]|0)+(h<<2)>>2]=k<<8|j|g<<16;c[(c[3530088]|0)+(h<<2)>>2]=k<<3&2016|j>>>3|g<<8&63488;return}if(a[641792]|0){l=(f&65528|0)==63496?b+16&65535:b}else{l=b}b=l&65535;switch(b|0){case 63488:case 63489:case 63496:case 63497:{a[(c[2406816]|0)+(b&1)|0]=d;return};case 63517:{a[9774904]=d;return};case 63492:{a[9719128]=d;return};case 63516:{c[2429446]=(d&255)<<6;return};case 63500:{a[14113264]=d;return};case 63490:case 63491:case 63498:case 63499:{a[(c[2406814]|0)+(b&1)|0]=d;return};case 63501:{a[9774904]=d;return};case 63518:case 63502:{a[14117488]=d;b=c[3529252]|0;l=c[9757320+(c[1836236]<<2)>>2]|0;f=((d&255)>>>1<<14&49152|65536)-32768|0;g=128;j=128;while(1){c[l+76+(j<<2)>>2]=b+(f+(j<<8));k=g+1&65535;if((k&65535)>191){m=128;n=128;break}else{g=k;j=k&65535}}while(1){j=b+(f+(n<<8))|0;c[l+76+(n+512<<2)>>2]=j;c[l+76+(n+768<<2)>>2]=j;j=m+1&65535;if((j&65535)>191){break}else{m=j;n=j&65535}}a[14114960]=d&1^1;a[9731736]=d&8;return};case 63493:{a[9731048]=d;return};case 63513:{n=e[4853030]|0;if((n|0)==12070){a[9753362]=d;return}else if((n|0)==12099){a[9753363]=d;return}else if((n|0)==1093){a[9718720]=-128;a[14113264]=d;return}else if((n|0)==12011){a[9753360]=d;return}else if((n|0)==12041){a[9753361]=d;return}else{return}break};default:{return}}}function dvJ(b,c){b=b|0;c=c|0;var d=0;d=b&65535;switch(d|0){case 57350:{a[9717776]=c;return};case 57344:case 57345:case 57346:case 57347:{lS(d>>>1&1,d&1,c);return};default:{return}}}function dvK(b){b=b|0;var c=0,d=0;c=b&65535;if((c|0)==57350){b=a[9718720]|a[9717776];a[9718720]=0;d=b}else if((c|0)==51200){d=a[14113264]|0}else{d=0}return d|0}function dvL(a,b){a=a|0;b=b|0;var d=0,e=0;if((a&255)!=1){return}a=b&255;c[2415540]=a>>>7;c[2415126]=9662152;if((c[2415542]|0)==4){d=a&15}else{d=a<<1&14}c[2415538]=d;c[2415126]=9662152;d=(c[2415541]|0)!=0;a=c[2415539]|0;if(d|(a|0)==1){e=a}else{c[2415539]=1;e=1}c[2415126]=9662152;if(d|(e|0)==0){return}c[2415539]=0;UC(0);return}function dvM(b){b=b|0;return((b&255)==0?a[9774904]|0:0)|0}function dvN(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2309500+(b*112|0)>>2];c[a+104>>2]=c[2309504+(b*112|0)>>2];c[a+108>>2]=c[2309508+(b*112|0)>>2];d=0;return d|0}function dvO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=2309400+(b*112|0);e=0;return e|0}function dvP(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6933872+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dvQ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>43){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3512632+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dvR(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;b=i;i=i+840|0;d=b|0;e=b+112|0;f=b+120|0;g=b+232|0;h=b+240|0;j=b+352|0;k=b+360|0;l=b+472|0;m=b+480|0;n=b+592|0;o=b+600|0;p=b+712|0;q=b+720|0;r=b+832|0;c[2415024]=0;c[3529252]=0;c[3529208]=131072;c[3529174]=163840;c[3529506]=229376;c[3530886]=262144;c[3530650]=393216;c[3530460]=917504;c[3530350]=1441792;c[3530972]=1572864;c[3530088]=1572896;c[2414730]=1576992;c[3529340]=1576992;c[3529298]=1585184;c[2387234]=1587232;c[2406500]=1589280;c[2406580]=1591328;c[2386498]=1593376;c[2386580]=1593888;c[2406970]=1594400;c[2406816]=1598496;c[2406814]=1598498;c[2411762]=1598500;s=0;while(1){if((s|0)>=1024){break}t=9638528+(s<<2)|0;if((c[t>>2]|0)==0){u=81906;break}else{s=s+1|0}}do{if((u|0)==81906){s=gGq(1598500)|0;c[t>>2]=s;if((s|0)==0){break}c[2415024]=s;gGz(s|0,0,1598500);c[3529252]=s;c[3529208]=s+131072;c[3529174]=s+163840;c[3530886]=s+262144;c[3530650]=s+393216;c[3530460]=s+917504;c[3530350]=s+1441792;c[3530972]=s+1572864;c[3530088]=s+1572896;v=s+1576992|0;c[2414730]=v;c[3529340]=v;c[3529298]=s+1585184;c[2387234]=s+1587232;c[2406500]=s+1589280;c[2406580]=s+1591328;c[2386498]=s+1593376;c[2386580]=s+1593888;c[2406970]=s+1594400;c[2406816]=s+1598496;c[2406814]=s+1598498;v=s+1598500|0;c[2411762]=v;c[2414310]=v;c[3529506]=0;if((c[3542200]|0)==0){w=1;i=b;return w|0}v=q+108|0;c[v>>2]=0;x=q+100|0;c[x>>2]=0;y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[y&16383](q,0)|0;do{if((c[v>>2]|0)!=0){y=c[x>>2]|0;c[r>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](r,0,0)|0;if((y|0)<1){w=1;i=b;return w|0}if((gzL(s,0,0)|0)==0){break}else{w=1}i=b;return w|0}}while(0);s=(c[3529252]|0)+65536|0;if((c[3542200]|0)==0){w=1;i=b;return w|0}x=o+108|0;c[x>>2]=0;v=o+100|0;c[v>>2]=0;y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[y&16383](o,1)|0;do{if((c[x>>2]|0)!=0){y=c[v>>2]|0;c[p>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](p,1,0)|0;if((y|0)<1){w=1;i=b;return w|0}if((gzL(s,0,1)|0)==0){break}else{w=1}i=b;return w|0}}while(0);s=(c[3529252]|0)+98304|0;if((c[3542200]|0)==0){w=1;i=b;return w|0}v=m+108|0;c[v>>2]=0;x=m+100|0;c[x>>2]=0;y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[y&16383](m,2)|0;do{if((c[v>>2]|0)!=0){y=c[x>>2]|0;c[n>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](n,2,0)|0;if((y|0)<1){w=1;i=b;return w|0}if((gzL(s,0,2)|0)==0){break}else{w=1}i=b;return w|0}}while(0);s=c[3529208]|0;if((c[3542200]|0)==0){w=1;i=b;return w|0}x=k+108|0;c[x>>2]=0;v=k+100|0;c[v>>2]=0;y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[y&16383](k,3)|0;do{if((c[x>>2]|0)!=0){y=c[v>>2]|0;c[l>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](l,3,0)|0;if((y|0)<1){w=1;i=b;return w|0}if((gzL(s,0,3)|0)==0){break}else{w=1}i=b;return w|0}}while(0);s=c[3530886]|0;if((c[3542200]|0)==0){w=1;i=b;return w|0}v=h+108|0;c[v>>2]=0;x=h+100|0;c[x>>2]=0;y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[y&16383](h,4)|0;do{if((c[v>>2]|0)!=0){y=c[x>>2]|0;c[j>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](j,4,0)|0;if((y|0)<1){w=1;i=b;return w|0}if((gzL(s,0,4)|0)==0){break}else{w=1}i=b;return w|0}}while(0);s=f+108|0;x=f+100|0;v=0;while(1){y=(c[3530650]|0)+(v<<15)|0;z=v+5|0;if((c[3542200]|0)==0){w=1;u=81963;break}c[s>>2]=0;c[x>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,z)|0;if((c[s>>2]|0)!=0){A=c[x>>2]|0;c[g>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](g,z,0)|0;if((A|0)<1){w=1;u=81951;break}if((gzL(y,0,z)|0)!=0){w=1;u=81952;break}}z=v+1|0;if((z|0)<8){v=z}else{u=81929;break}}if((u|0)==81963){i=b;return w|0}else if((u|0)==81951){i=b;return w|0}else if((u|0)==81952){i=b;return w|0}else if((u|0)==81929){v=d+108|0;x=d+100|0;s=0;while(1){z=(c[3530460]|0)+(s<<15)|0;y=s+13|0;if((c[3542200]|0)==0){w=1;u=81960;break}c[v>>2]=0;c[x>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](d,y)|0;if((c[v>>2]|0)!=0){A=c[x>>2]|0;c[e>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](e,y,0)|0;if((A|0)<1){w=1;u=81949;break}if((gzL(z,0,y)|0)!=0){w=1;u=81950;break}}y=s+1|0;if((y|0)<4){s=y}else{u=81940;break}}if((u|0)==81949){i=b;return w|0}else if((u|0)==81960){i=b;return w|0}else if((u|0)==81950){i=b;return w|0}else if((u|0)==81940){dwq();fwR(0);dwr();fwR(1);dws();s=c[642608+(c[2436]<<2)>>2]|0;x=c[s+128>>2]|0;if((c[s+52>>2]&4|0)==0){c[2113068]=x;v=c[s+132>>2]|0;c[2113070]=v;c[2443814]=x;c[2440436]=v;C=x;D=v}else{c[2113070]=x;v=c[s+132>>2]|0;c[2113068]=v;c[2440436]=x;c[2443814]=v;C=v;D=x}x=ag(C<<1,D)|0;v=gGq(x)|0;c[2112926]=v;if((v|0)!=0){gGz(v|0,0,x|0)}c[2440544]=1e5;a[6518104]=1;a[6517880]=0;dwu();w=0;i=b;return w|0}}}}while(0);c[2415024]=0;w=1;i=b;return w|0}function dvS(){var b=0,d=0,e=0,f=0;c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}fwZ();b=c[3541518]|0;if((b|0)!=0){gGr(b|0);c[3541518]=0}if((c[2385508]|0)>0){c[2113008]=0;c[2076598]=0;c[2383582]=0}c[2438228]=0;c[2433526]=0;c[2406676]=0;c[3528472]=0;b=c[2406680]|0;if((b|0)!=0){gGr(b);c[2406680]=0}c[2385508]=0;c[2432978]=0;a[64240]=0;b=c[2415024]|0;d=0;while(1){if((d|0)>=1024){e=81984;break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==(b|0)){break}else{d=d+1|0}}if((e|0)==81984){c[2415024]=0;a[641792]=0;a[6856296]=0;return 0}gGr(b);c[f>>2]=0;c[2415024]=0;a[641792]=0;a[6856296]=0;return 0}function dvT(){var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;d=i;i=i+272|0;e=d|0;if((a[9624616]|0)!=0){dwu()}gGz(9657864,-1|0,3);f=0;g=-1;h=-1;j=-1;do{g=((a[9634016+f|0]&1)<<f^g&255)&255;h=((a[9631808+f|0]&1)<<f^h&255)&255;j=((a[9629768+f|0]&1)<<f^j&255)&255;f=f+1|0;}while((f|0)<8);a[9657864]=g;a[9657865]=h;a[9657866]=j;if((h&3)==0){g=h|3;a[9657865]=g;k=g}else{k=h}if((k&12)==0){a[9657865]=k|12}if((j&3)==0){k=j|3;a[9657866]=k;l=k}else{l=j}if((l&12)==0){a[9657866]=l|12}if(a[6856296]|0){c[2415126]=9662152;l=c[2415557]|0;j=l&3;if((j|0)==3){m=133}else{m=(6e6/(6e6/((c[2415554]|0)/(c[600992+((l>>>3&1)<<4)+(j<<2)>>2]|0)|0|0)|0|0)|0|0)/((c[2424]|0)/100|0|0)|0}j=0;while(1){l=j+1|0;c[e+(j<<2)>>2]=(ag(l,m)|0)/68|0;if((l|0)<67){j=l}else{n=m;break}}}else{n=16}m=c[2385548]|0;if((m|0)>0){gGz(9752472,0,((m|0)>1?m<<2:4)|0)}c[2433530]=0;m=(n|0)/4|0;j=m-1|0;l=n-1|0;k=0;h=0;g=0;L100381:while(1){f=k;o=h;while(1){if((f|0)>=(n|0)){break L100381}p=c[2439330]|0;if((p|0)!=0){q=p;gGC(9706056,q|0,76)|0}b[4853030]=c[2426515]&65535;q=c[2438118]|0;c[2433530]=q;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;r=f+1|0;s=((ag(c[2440544]|0,r)|0)/(n|0)|0)-o|0;do{if((s|0)<1){t=0}else{if((a[p+4188|0]|0)==0){u=gfc(s)|0;c[2433530]=(c[2433530]|0)+u;t=u;break}else{c[2433530]=q+s;t=s;break}}}while(0);v=t+o|0;do{if((a[9731736]|0)!=0&(f|0)==(l|0)){if(!(a[641792]|0)){a[14125144]=-41;a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0;break}if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12}}while(0);if(a[6856296]|0){UD()}s=c[1836236]|0;q=c[9757320+(s<<2)>>2]|0;if((q|0)!=0){p=q;gGC(p|0,9706056,76)|0}c[9752472+(s<<2)>>2]=c[2433530];c[14113936+(s<<2)>>2]=c[2076596];c[9669104+(s<<2)>>2]=c[3541536];c[1836236]=-1;s=c[2439331]|0;if((s|0)!=0){p=s;gGC(9706056,p|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;Sb(ag(((a[6518104]|0?5e4:0)|0)/(n|0)|0,f)|0);if(((f|0)%(m|0)|0|0)==(j|0)){a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0}p=c[1836236]|0;s=c[9757320+(p<<2)>>2]|0;if((s|0)!=0){q=s;gGC(q|0,9706056,76)|0}c[9752472+(p<<2)>>2]=c[2433530];c[14113936+(p<<2)>>2]=c[2076596];c[9669104+(p<<2)>>2]=c[3541536];c[1836236]=-1;if(a[6856296]|0){break}else{f=r;o=v}}o=c[2439332]|0;if((o|0)!=0){p=o;gGC(9706056,p|0,76)|0}b[4853030]=c[2426515]&65535;p=c[2438120]|0;c[2433530]=p;c[2076596]=c[3528486];c[3541536]=c[2417278];c[1836236]=2;q=((ag(a[6517880]|0?5e4:0,r)|0)/(n|0)|0)-g|0;do{if((q|0)<1){w=0;x=p}else{if((a[o+4188|0]|0)==0){s=gfc(q)|0;u=(c[2433530]|0)+s|0;c[2433530]=u;w=s;x=u;break}else{u=p+q|0;c[2433530]=u;w=q;x=u;break}}}while(0);q=w+g|0;p=0;o=x;while(1){if((f|0)==(c[e+(p<<2)>>2]|0)){a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0;if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){u=gfc(1e3)|0;y=u;z=(c[2433530]|0)+u|0}else{y=1e3;z=(c[2433530]|0)+1e3|0}c[2433530]=z;A=y+q|0;B=z}else{A=q;B=o}u=p+1|0;if((u|0)<67){q=A;p=u;o=B}else{break}}o=c[1836236]|0;p=c[9757320+(o<<2)>>2]|0;if((p|0)!=0){q=p;gGC(q|0,9706056,76)|0}c[9752472+(o<<2)>>2]=B;c[14113936+(o<<2)>>2]=c[2076596];c[9669104+(o<<2)>>2]=c[3541536];c[1836236]=-1;k=r;h=v;g=A}A=c[2439331]|0;if((A|0)!=0){g=A;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;g=a[6518104]|0?5e4:0;A=gGU(g,0,2048e6,0)|0;v=c[2438228]|0;h=gGS(A,K,v,(v|0)<0|0?-1:0)|0;v=h;Sb(g);g=c[2443830]|0;if((g|0)<1073676288){c[2443830]=g-v}g=c[2443831]|0;if((g|0)<1073676288){c[2443831]=g-v}g=(c[3528512]|0)-v|0;c[3528512]=(g|0)<0?0:g;g=c[2112964]|0;do{if((g|0)!=0){gg[c[3542122]&4095](g,a[9688]|0?534:0);if(!(a[6856296]|0)){break}Uz(0,c[2112964]|0,a[9688]|0?534:0)}}while(0);g=c[1836236]|0;v=c[9757320+(g<<2)>>2]|0;if((v|0)!=0){h=v;gGC(h|0,9706056,76)|0}c[9752472+(g<<2)>>2]=c[2433530];c[14113936+(g<<2)>>2]=c[2076596];c[9669104+(g<<2)>>2]=c[3541536];c[1836236]=-1;if((c[2112968]|0)==0){C=c[2386580]|0;D=c[2386498]|0;gGC(C|0,D|0,512)|0;i=d;return 0}dvU()|0;C=c[2386580]|0;D=c[2386498]|0;gGC(C|0,D|0,512)|0;i=d;return 0}function dvU(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;if((a[9547704]|0)!=0){e=c[2406970]|0;f=c[3530088]|0;g=0;do{h=c[e+(g<<2)>>2]|0;c[f+(g<<2)>>2]=h>>8<<3&2016|h>>>3&31|h>>16<<8&63488;g=g+1|0;}while((g|0)<1024)}g=c[3529506]|0;if((g|0)==0){f=c[2406816]|0;e=d[f+1|0]<<8&256|d[f];f=c[2406814]|0;h=-8-(d[f+1|0]<<8&256|d[f])|0;f=c[2406580]|0;i=c[2112926]|0;j=c[3530650]|0;k=c[2113070]|0;l=c[2113068]|0;m=0;do{n=(m>>5<<4)-e|0;o=(m<<4&496)+h|0;p=(n|0)<-15?n+512|0:n;n=(o|0)<-15?o+512|0:o;do{if((p|0)>-16&(n|0)>-16&(n|0)<(k|0)&(p|0)<(l|0)){o=d[f+(m|1024)|0]|0;q=o<<3&1792|d[f+m|0];r=o&7;s=(o&8|0)!=0;if((o&16|0)==0){if(s){SB(i,q,p,n,r,4,0,j);break}else{Sz(i,q,p,n,r,4,0,j);break}}else{if(s){SF(i,q,p,n,r,4,0,j);break}else{SD(i,q,p,n,r,4,0,j);break}}}}while(0);m=m+1|0;}while((m|0)<1024);m=c[2386580]|0;j=c[3530460]|0;f=508;do{h=d[m+(f|3)|0]|0;e=d[m+(f|1)|0]|0;n=e<<8&256;p=h-n|0;r=a[m+(f|2)|0]|0;q=r&255;do{if(!(r<<24>>24==0|(h|0)==(n|0))){s=d[m+f|0]|e<<2&768;o=e>>>3|24;t=((r&255)>248?q|-256:q)-8|0;u=(e&2|0)!=0;if((e&4|0)==0){if(u){SJ(i,s,p,t,o,4,15,0,j);break}else{SH(i,s,p,t,o,4,15,0,j);break}}else{if(u){SN(i,s,p,t,o,4,15,0,j);break}else{SL(i,s,p,t,o,4,15,0,j);break}}}}while(0);f=f-4|0;}while((f|0)>-1);dwx(512);v=l;w=k;x=i}else{i=c[2112926]|0;k=c[3530350]|0;l=c[2113070]|0;f=c[2113068]|0;j=0;do{m=(j<<4&496)-(d[9719128]|0)|0;p=(m|0)<-15?m+512|0:m;m=(j>>5<<4)-8|0;do{if((p|0)>-16&(m|0)>-16&(m|0)<(l|0)&(p|0)<(f|0)){e=(d[9731048]<<5)+(j<<6&30720|j<<1&62)&32767;q=d[g+(e|1)|0]|0;r=q<<1&256|d[g+e|0];e=q&7;n=(q&16|0)!=0;if((q&32|0)==0){if(n){SB(i,r,p,m,e,4,0,k);break}else{Sz(i,r,p,m,e,4,0,k);break}}else{if(n){SF(i,r,p,m,e,4,0,k);break}else{SD(i,r,p,m,e,4,0,k);break}}}}while(0);j=j+1|0;}while((j|0)<512);dwy(0);j=c[2386580]|0;k=a[641792]^1;g=c[3530460]|0;m=380;do{p=d[j+(m|3)|0]|0;e=d[j+(m|1)|0]|0;r=e<<8&256;n=p-r|0;q=a[j+(m|2)|0]|0;h=q&255;do{if(!(q<<24>>24==0|(p|0)==(r|0))){o=e<<2&256|e<<4&512|e<<3&1024|d[j+m|0];t=e&16;s=(t|0)!=0&k;u=e>>>1&7|40;y=((q&255)>248?h|-256:h)-8|0;if((t|0)==0|k){if(s){SN(i,o,n,y,u,4,15,0,g);break}else{SL(i,o,n,y,u,4,15,0,g);break}}else{if(s){SJ(i,o,n,y,u,4,15,0,g);break}else{SH(i,o,n,y,u,4,15,0,g);break}}}}while(0);m=m-4|0;}while((m|0)>-1);dwy(1);dwx(768);v=f;w=l;x=i}if((a[14114960]|0)==0){z=c[3530088]|0;R8(z);return 0}i=ag(w,v)|0;if((i|0)<=1){z=c[3530088]|0;R8(z);return 0}v=x+(i-1<<1)|0;w=b[x>>1]|0;b[x>>1]=b[v>>1]|0;b[v>>1]=w;if((i|0)<=3){z=c[3530088]|0;R8(z);return 0}w=(i|0)/2|0;i=v;v=1;do{i=i-2|0;l=x+(v<<1)|0;f=b[l>>1]|0;b[l>>1]=b[i>>1]|0;b[i>>1]=f;v=v+1|0;}while((v|0)<(w|0));z=c[3530088]|0;R8(z);return 0}function dvV(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;g=i;i=i+192|0;h=g|0;j=g+16|0;k=g+32|0;l=g+48|0;m=g+64|0;n=g+80|0;o=g+96|0;p=g+112|0;q=g+128|0;r=g+144|0;s=g+160|0;t=g+176|0;if((f|0)!=0){c[f>>2]=169618}if((e&32|0)!=0){gGz(t|0,0,12);u=c[2414730]|0;c[t>>2]=u;c[t+4>>2]=(c[2411762]|0)-u;c[t+12>>2]=162152;u=c[2076592]|0;gj[u&4095](t)|0}if((e&64|0)!=0){fw$(e);Vx(e,f);if(a[6856296]|0){UE(e,f)}gGz(s|0,0,12);c[s>>2]=9731736;c[s+4>>2]=1;c[s+12>>2]=139264;f=c[2076592]|0;gj[f&4095](s)|0;gGz(r|0,0,12);c[r>>2]=14113264;c[r+4>>2]=1;c[r+12>>2]=191240;s=c[2076592]|0;gj[s&4095](r)|0;gGz(q|0,0,12);c[q>>2]=9774904;c[q+4>>2]=1;c[q+12>>2]=516864;r=c[2076592]|0;gj[r&4095](q)|0;gGz(p|0,0,12);c[p>>2]=14114960;c[p+4>>2]=1;c[p+12>>2]=142288;q=c[2076592]|0;gj[q&4095](p)|0;gGz(o|0,0,12);c[o>>2]=14117488;c[o+4>>2]=1;c[o+12>>2]=435944;p=c[2076592]|0;gj[p&4095](o)|0;gGz(n|0,0,12);c[n>>2]=9753360;c[n+4>>2]=4;c[n+12>>2]=68600;o=c[2076592]|0;gj[o&4095](n)|0;gGz(m|0,0,12);c[m>>2]=9717784;c[m+4>>2]=4;c[m+12>>2]=67032;n=c[2076592]|0;gj[n&4095](m)|0;gGz(l|0,0,12);c[l>>2]=9717776;c[l+4>>2]=1;c[l+12>>2]=65728;m=c[2076592]|0;gj[m&4095](l)|0;gGz(k|0,0,12);c[k>>2]=9718720;c[k+4>>2]=1;c[k+12>>2]=589208;l=c[2076592]|0;gj[l&4095](k)|0;gGz(j|0,0,12);c[j>>2]=9719128;c[j+4>>2]=1;c[j+12>>2]=587720;k=c[2076592]|0;gj[k&4095](j)|0;gGz(h|0,0,12);c[h>>2]=9731048;c[h+4>>2]=1;c[h+12>>2]=585896;j=c[2076592]|0;gj[j&4095](h)|0}h=c[2439330]|0;j=(h|0)==0;if(!j){k=h;gGC(9706056,k|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];k=c[3528484]|0;c[2076596]=k;l=c[2417276]|0;c[3541536]=l;c[1836236]=0;m=c[3529252]|0;n=((d[14117488]|0)>>>1<<14&49152|65536)-32768|0;o=128;p=128;while(1){c[h+76+(p<<2)>>2]=m+(n+(p<<8));q=o+1&65535;if((q&65535)>191){v=128;w=128;break}else{o=q;p=q&65535}}while(1){p=m+(n+(w<<8))|0;c[h+76+(w+512<<2)>>2]=p;c[h+76+(w+768<<2)>>2]=p;p=v+1&65535;if((p&65535)>191){break}else{v=p;w=p&65535}}if(j){x=c[2433530]|0;c[2438118]=x;c[3528484]=k;c[2417276]=l;c[1836236]=-1;i=g;return 0}j=h;gGC(j|0,9706056,76)|0;x=c[2433530]|0;c[2438118]=x;c[3528484]=k;c[2417276]=l;c[1836236]=-1;i=g;return 0}function dvW(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2318012+(b*112|0)>>2];c[a+104>>2]=c[2318016+(b*112|0)>>2];c[a+108>>2]=c[2318020+(b*112|0)>>2];d=0;return d|0}function dvX(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=2317912+(b*112|0);e=0;return e|0}function dvY(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5790012+(b*112|0)>>2];c[a+104>>2]=c[5790016+(b*112|0)>>2];c[a+108>>2]=c[5790020+(b*112|0)>>2];d=0;return d|0}function dvZ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=5789912+(b*112|0);e=0;return e|0}function dv_(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>39){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6243320+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dv$(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4568668+(b*112|0)>>2];c[a+104>>2]=c[4568672+(b*112|0)>>2];c[a+108>>2]=c[4568676+(b*112|0)>>2];d=0;return d|0}function dv0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=4568568+(b*112|0);e=0;return e|0}function dv1(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2633292+(b*112|0)>>2];c[a+104>>2]=c[2633296+(b*112|0)>>2];c[a+108>>2]=c[2633300+(b*112|0)>>2];d=0;return d|0}function dv2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=2633192+(b*112|0);e=0;return e|0}function dv3(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4566652+(b*112|0)>>2];c[a+104>>2]=c[4566656+(b*112|0)>>2];c[a+108>>2]=c[4566660+(b*112|0)>>2];d=0;return d|0}function dv4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=4566552+(b*112|0);e=0;return e|0}function dv5(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>39){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5298992+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dv6(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>26){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5638340+(b*112|0)>>2];c[a+104>>2]=c[5638344+(b*112|0)>>2];c[a+108>>2]=c[5638348+(b*112|0)>>2];d=0;return d|0}function dv7(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<27&(d|0)==0)){e=1;return e|0}c[a>>2]=5638240+(b*112|0);e=0;return e|0}function dv8(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>35){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3280272+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dv9(){var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;d=i;i=i+1320|0;e=d|0;f=d+112|0;g=d+120|0;j=d+232|0;k=d+240|0;l=d+352|0;m=d+360|0;n=d+472|0;o=d+480|0;p=d+592|0;q=d+600|0;r=d+712|0;s=d+720|0;t=d+832|0;u=d+840|0;v=d+952|0;w=d+960|0;x=d+1072|0;y=d+1080|0;z=d+1192|0;A=d+1200|0;B=d+1312|0;c[2415024]=0;c[3529252]=0;c[3529208]=131072;c[3529174]=163840;c[3529506]=229376;c[3530886]=262144;c[3530650]=393216;c[3530460]=917504;c[3530350]=1441792;c[3530972]=1572864;c[3530088]=1572896;c[2414730]=1576992;c[3529340]=1576992;c[3529298]=1585184;c[2387234]=1587232;c[2406500]=1589280;c[2406580]=1591328;c[2386498]=1593376;c[2386580]=1593888;c[2406970]=1594400;c[2406816]=1598496;c[2406814]=1598498;c[2411762]=1598500;C=0;while(1){if((C|0)>=1024){break}D=9638528+(C<<2)|0;if((c[D>>2]|0)==0){E=82232;break}else{C=C+1|0}}do{if((E|0)==82232){C=gGq(1598500)|0;c[D>>2]=C;if((C|0)==0){break}c[2415024]=C;gGz(C|0,0,1598500);c[3529252]=C;c[3529208]=C+131072;c[3529174]=C+163840;c[3529506]=C+229376;c[3530886]=C+262144;c[3530650]=C+393216;c[3530460]=C+917504;c[3530350]=C+1441792;c[3530972]=C+1572864;c[3530088]=C+1572896;F=C+1576992|0;c[2414730]=F;c[3529340]=F;c[3529298]=C+1585184;c[2387234]=C+1587232;c[2406500]=C+1589280;c[2406580]=C+1591328;c[2386498]=C+1593376;c[2386580]=C+1593888;c[2406970]=C+1594400;c[2406816]=C+1598496;c[2406814]=C+1598498;F=C+1598500|0;c[2411762]=F;c[2414310]=F;if((c[3542200]|0)==0){G=1;i=d;return G|0}F=A+108|0;c[F>>2]=0;H=A+100|0;c[H>>2]=0;I=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[I&16383](A,0)|0;do{if((c[F>>2]|0)!=0){I=c[H>>2]|0;c[B>>2]=9534384;J=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[J&16383](B,0,0)|0;if((I|0)<1){G=1;i=d;return G|0}if((gzL(C,0,0)|0)==0){break}else{G=1}i=d;return G|0}}while(0);C=(c[3529252]|0)+65536|0;if((c[3542200]|0)==0){G=1;i=d;return G|0}H=y+108|0;c[H>>2]=0;F=y+100|0;c[F>>2]=0;I=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[I&16383](y,1)|0;do{if((c[H>>2]|0)!=0){I=c[F>>2]|0;c[z>>2]=9534384;J=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[J&16383](z,1,0)|0;if((I|0)<1){G=1;i=d;return G|0}if((gzL(C,0,1)|0)==0){break}else{G=1}i=d;return G|0}}while(0);C=(c[3529252]|0)+98304|0;if((c[3542200]|0)==0){G=1;i=d;return G|0}F=w+108|0;c[F>>2]=0;H=w+100|0;c[H>>2]=0;I=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[I&16383](w,2)|0;do{if((c[F>>2]|0)!=0){I=c[H>>2]|0;c[x>>2]=9534384;J=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[J&16383](x,2,0)|0;if((I|0)<1){G=1;i=d;return G|0}if((gzL(C,0,2)|0)==0){break}else{G=1}i=d;return G|0}}while(0);C=c[3529208]|0;if((c[3542200]|0)==0){G=1;i=d;return G|0}H=u+108|0;c[H>>2]=0;F=u+100|0;c[F>>2]=0;I=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[I&16383](u,3)|0;do{if((c[H>>2]|0)!=0){I=c[F>>2]|0;c[v>>2]=9534384;J=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[J&16383](v,3,0)|0;if((I|0)<1){G=1;i=d;return G|0}if((gzL(C,0,3)|0)==0){break}else{G=1}i=d;return G|0}}while(0);C=c[3529174]|0;if((c[3542200]|0)==0){G=1;i=d;return G|0}F=s+108|0;c[F>>2]=0;H=s+100|0;c[H>>2]=0;I=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[I&16383](s,4)|0;do{if((c[F>>2]|0)!=0){I=c[H>>2]|0;c[t>>2]=9534384;J=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[J&16383](t,4,0)|0;if((I|0)<1){G=1;i=d;return G|0}if((gzL(C,0,4)|0)==0){break}else{G=1}i=d;return G|0}}while(0);C=c[3530886]|0;if((c[3542200]|0)==0){G=1;i=d;return G|0}H=q+108|0;c[H>>2]=0;F=q+100|0;c[F>>2]=0;I=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[I&16383](q,5)|0;do{if((c[H>>2]|0)!=0){I=c[F>>2]|0;c[r>>2]=9534384;J=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[J&16383](r,5,0)|0;if((I|0)<1){G=1;i=d;return G|0}if((gzL(C,0,5)|0)==0){break}else{G=1}i=d;return G|0}}while(0);C=o+108|0;F=o+100|0;H=m+108|0;I=m+100|0;J=0;while(1){K=J<<15;L=(c[3530650]|0)+K|0;M=J+6|0;if((c[3542200]|0)==0){G=1;E=82305;break}c[C>>2]=0;c[F>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](o,M)|0;if((c[C>>2]|0)!=0){N=c[F>>2]|0;c[p>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](p,M,0)|0;if((N|0)<1){G=1;E=82314;break}if((gzL(L,0,M)|0)!=0){G=1;E=82315;break}}M=(c[3530460]|0)+K|0;K=J+14|0;if((c[3542200]|0)==0){G=1;E=82299;break}c[H>>2]=0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,K)|0;if((c[H>>2]|0)!=0){L=c[I>>2]|0;c[n>>2]=9534384;N=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[N&16383](n,K,0)|0;if((L|0)<1){G=1;E=82320;break}if((gzL(M,0,K)|0)!=0){G=1;E=82297;break}}K=J+1|0;if((K|0)<8){J=K}else{E=82268;break}}if((E|0)==82268){J=c[3530350]|0;if((c[3542200]|0)==0){G=1;i=d;return G|0}I=k+108|0;c[I>>2]=0;H=k+100|0;c[H>>2]=0;F=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[F&16383](k,22)|0;do{if((c[I>>2]|0)!=0){F=c[H>>2]|0;c[l>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](l,22,0)|0;if((F|0)<1){G=1;i=d;return G|0}if((gzL(J,0,22)|0)==0){break}else{G=1}i=d;return G|0}}while(0);J=(c[3530350]|0)+32768|0;if((c[3542200]|0)==0){G=1;i=d;return G|0}H=g+108|0;c[H>>2]=0;I=g+100|0;c[I>>2]=0;F=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[F&16383](g,23)|0;do{if((c[H>>2]|0)!=0){F=c[I>>2]|0;c[j>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](j,23,0)|0;if((F|0)<1){G=1;i=d;return G|0}if((gzL(J,0,23)|0)==0){break}else{G=1}i=d;return G|0}}while(0);J=c[3529506]|0;if((c[3542200]|0)==0){G=1;i=d;return G|0}I=e+108|0;c[I>>2]=0;H=e+100|0;c[H>>2]=0;F=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[F&16383](e,24)|0;do{if((c[I>>2]|0)!=0){F=c[H>>2]|0;c[f>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](f,24,0)|0;if((F|0)<1){G=1;i=d;return G|0}if((gzL(J,0,24)|0)==0){break}else{G=1}i=d;return G|0}}while(0);dwq();J=c[3530972]|0;H=0;do{a[J+H|0]=(1<<H&-260112383|0)!=0|0;H=H+1|0;}while((H|0)<32);fwR(0);dwr();fwR(1);dws();fwR(2);H=c[2439332]|0;J=(H|0)==0;if(!J){I=H;gGC(9706056,I|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438120];I=c[3528486]|0;c[2076596]=I;F=c[2417278]|0;c[3541536]=F;c[1836236]=2;C=c[3529174]|0;K=0;M=0;while(1){c[H+76+(M<<2)>>2]=C+(M<<8);L=K+1&65535;if((L&65535)>255){P=0;Q=0;break}else{K=L;M=L&65535}}while(1){M=C+(Q<<8)|0;c[H+76+(Q+512<<2)>>2]=M;c[H+76+(Q+768<<2)>>2]=M;M=P+1&65535;if((M&65535)>255){break}else{P=M;Q=M&65535}}c[H+4172>>2]=2026;c[H+4176>>2]=2966;if(!J){C=H;gGC(C|0,9706056,76)|0}c[2438120]=c[2433530];c[3528486]=I;c[2417278]=F;c[1836236]=-1;UB(0,2088,455e3,0,7);c[2415126]=9662152;h[1207773]=.5;c[2415548]=3;a[6856296]=1;C=c[642608+(c[2436]<<2)>>2]|0;M=c[C+128>>2]|0;if((c[C+52>>2]&4|0)==0){c[2113068]=M;K=c[C+132>>2]|0;c[2113070]=K;c[2443814]=M;c[2440436]=K;R=M;S=K}else{c[2113070]=M;K=c[C+132>>2]|0;c[2113068]=K;c[2440436]=M;c[2443814]=K;R=K;S=M}M=ag(R<<1,S)|0;K=gGq(M)|0;c[2112926]=K;if((K|0)!=0){gGz(K|0,0,M|0)}c[2440544]=5e4;a[6518104]=1;a[6517880]=1;dwu();G=0;i=d;return G|0}else if((E|0)==82305){i=d;return G|0}else if((E|0)==82314){i=d;return G|0}else if((E|0)==82315){i=d;return G|0}else if((E|0)==82320){i=d;return G|0}else if((E|0)==82297){i=d;return G|0}else if((E|0)==82299){i=d;return G|0}}}while(0);c[2415024]=0;G=1;i=d;return G|0}function dwa(){var b=0,d=0,e=0,f=0,g=0,h=0;c[2415126]=9662152;b=c[2408988]|0;if((b|0)!=0){gGz(9662152,0,3224);d=b;b=0;while(1){if((b|0)>=1024){break}e=9638528+(b<<2)|0;if((c[e>>2]|0)==(d|0)){f=82335;break}else{b=b+1|0}}if((f|0)==82335){gGr(d);c[e>>2]=0}c[2408988]=0}c[2415126]=9665376;e=c[2408989]|0;if((e|0)!=0){gGz(9665376,0,3224);d=e;e=0;while(1){if((e|0)>=1024){break}g=9638528+(e<<2)|0;if((c[g>>2]|0)==(d|0)){f=82341;break}else{e=e+1|0}}if((f|0)==82341){gGr(d);c[g>>2]=0}c[2408989]=0}c[2113070]=0;c[2113068]=0;g=c[2112926]|0;if((g|0)!=0){gGr(g);c[2112926]=0}fwZ();g=c[3541518]|0;if((g|0)!=0){gGr(g|0);c[3541518]=0}if((c[2385508]|0)>0){c[2113008]=0;c[2076598]=0;c[2383582]=0}c[2438228]=0;c[2433526]=0;c[2406676]=0;c[3528472]=0;g=c[2406680]|0;if((g|0)!=0){gGr(g);c[2406680]=0}c[2385508]=0;c[2432978]=0;a[64240]=0;g=c[2415024]|0;d=0;while(1){if((d|0)>=1024){f=82356;break}h=9638528+(d<<2)|0;if((c[h>>2]|0)==(g|0)){break}else{d=d+1|0}}if((f|0)==82356){c[2415024]=0;a[641792]=0;a[6856296]=0;return 0}gGr(g);c[h>>2]=0;c[2415024]=0;a[641792]=0;a[6856296]=0;return 0}function dwb(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>26){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4350884+(b*112|0)>>2];c[a+104>>2]=c[4350888+(b*112|0)>>2];c[a+108>>2]=c[4350892+(b*112|0)>>2];d=0;return d|0}function dwc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<27&(d|0)==0)){e=1;return e|0}c[a>>2]=4350784+(b*112|0);e=0;return e|0}function dwd(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>26){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4344836+(b*112|0)>>2];c[a+104>>2]=c[4344840+(b*112|0)>>2];c[a+108>>2]=c[4344844+(b*112|0)>>2];d=0;return d|0}function dwe(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<27&(d|0)==0)){e=1;return e|0}c[a>>2]=4344736+(b*112|0);e=0;return e|0}function dwf(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>42){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6026600+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dwg(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>26){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4347860+(b*112|0)>>2];c[a+104>>2]=c[4347864+(b*112|0)>>2];c[a+108>>2]=c[4347868+(b*112|0)>>2];d=0;return d|0}function dwh(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<27&(d|0)==0)){e=1;return e|0}c[a>>2]=4347760+(b*112|0);e=0;return e|0}function dwi(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>26){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3122228+(b*112|0)>>2];c[a+104>>2]=c[3122232+(b*112|0)>>2];c[a+108>>2]=c[3122236+(b*112|0)>>2];d=0;return d|0}function dwj(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<27&(d|0)==0)){e=1;return e|0}c[a>>2]=3122128+(b*112|0);e=0;return e|0}function dwk(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>46){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4258464+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dwl(){a[641792]=1;return dv9()|0}function dwm(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>26){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3125252+(b*112|0)>>2];c[a+104>>2]=c[3125256+(b*112|0)>>2];c[a+108>>2]=c[3125260+(b*112|0)>>2];d=0;return d|0}function dwn(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<27&(d|0)==0)){e=1;return e|0}c[a>>2]=3125152+(b*112|0);e=0;return e|0}function dwo(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>26){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3039644+(b*112|0)>>2];c[a+104>>2]=c[3039648+(b*112|0)>>2];c[a+108>>2]=c[3039652+(b*112|0)>>2];d=0;return d|0}function dwp(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<27&(d|0)==0)){e=1;return e|0}c[a>>2]=3039544+(b*112|0);e=0;return e|0}function dwq(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=0;while(1){if((b|0)>=1024){e=82508;break}f=9638528+(b<<2)|0;if((c[f>>2]|0)==0){break}else{b=b+1|0}}if((e|0)==82508){return}b=gGq(262144)|0;c[f>>2]=b;if((b|0)==0){return}gGz(b|0,0,262144);f=c[3530886]|0;gGC(b|0,f|0,32768)|0;g=0;do{h=g<<6;gGz(f+h|0,0,64);i=g<<7;j=0;do{k=i+(c[608544+(j<<2)>>2]|0)|0;l=(j<<3)+h|0;m=0;do{n=k+(c[609552+(m<<2)>>2]|0)|0;if(((d[b+((n|0)/8|0)|0]|0)&128>>>((n&7)>>>0)|0)!=0){n=f+(l+m)|0;a[n]=a[n]|2}m=m+1|0;}while((m|0)<8);j=j+1|0;}while((j|0)<8);j=i|4;m=0;do{l=j+(c[608544+(m<<2)>>2]|0)|0;k=(m<<3)+h|0;n=0;do{o=l+(c[609552+(n<<2)>>2]|0)|0;if(((d[b+((o|0)/8|0)|0]|0)&128>>>((o&7)>>>0)|0)!=0){o=f+(k+n)|0;a[o]=a[o]|1}n=n+1|0;}while((n|0)<8);m=m+1|0;}while((m|0)<8);g=g+1|0;}while((g|0)<2048);g=c[3530650]|0;gGC(b|0,g|0,262144)|0;f=0;do{m=f<<8;gGz(g+m|0,0,256);h=0;do{j=1<<3-h;i=(c[613280+(h<<2)>>2]|0)+m|0;n=0;do{k=i+(c[609008+(n<<2)>>2]|0)|0;l=(n<<4)+m|0;o=0;do{p=k+(c[597864+(o<<2)>>2]|0)|0;if(((d[b+((p|0)/8|0)|0]|0)&128>>>((p&7)>>>0)|0)!=0){p=g+(l+o)|0;a[p]=(d[p]|0|j)&255}o=o+1|0;}while((o|0)<16);n=n+1|0;}while((n|0)<16);h=h+1|0;}while((h|0)<4);f=f+1|0;}while((f|0)<2048);f=c[3530460]|0;gGC(b|0,f|0,262144)|0;if((c[3529506]|0)==0){g=0;while(1){h=g<<8;gGz(f+h|0,0,256);m=g<<9;n=0;do{j=1<<3-n;i=(c[611360+(n<<2)>>2]|0)+m|0;o=0;do{l=i+(c[608544+(o<<2)>>2]|0)|0;k=(o<<4)+h|0;p=0;do{q=l+(c[609552+(p<<2)>>2]|0)|0;if(((d[b+((q|0)/8|0)|0]|0)&128>>>((q&7)>>>0)|0)!=0){q=f+(k+p)|0;a[q]=(d[q]|0|j)&255}p=p+1|0;}while((p|0)<16);o=o+1|0;}while((o|0)<16);n=n+1|0;}while((n|0)<4);n=g+1|0;if((n|0)<1024){g=n}else{r=0;break}}}else{g=0;do{n=g<<8;gGz(f+n|0,0,256);h=g<<9;m=0;do{o=1<<3-m;j=(c[961472+(m<<2)>>2]|0)+h|0;i=0;do{p=j+(c[608544+(i<<2)>>2]|0)|0;k=(i<<4)+n|0;l=0;do{q=p+(c[609552+(l<<2)>>2]|0)|0;if(((d[b+((q|0)/8|0)|0]|0)&128>>>((q&7)>>>0)|0)!=0){q=f+(k+l)|0;a[q]=(d[q]|0|o)&255}l=l+1|0;}while((l|0)<16);i=i+1|0;}while((i|0)<16);m=m+1|0;}while((m|0)<4);g=g+1|0;}while((g|0)<2048);g=c[3530350]|0;gGC(b|0,g|0,65536)|0;f=0;while(1){m=f<<8;gGz(g+m|0,0,256);n=f<<9;h=0;do{i=1<<3-h;o=(c[611120+(h<<2)>>2]|0)+n|0;j=0;do{l=o+(c[608544+(j<<2)>>2]|0)|0;k=(j<<4)+m|0;p=0;do{q=l+(c[609552+(p<<2)>>2]|0)|0;if(((d[b+((q|0)/8|0)|0]|0)&128>>>((q&7)>>>0)|0)!=0){q=g+(k+p)|0;a[q]=(d[q]|0|i)&255}p=p+1|0;}while((p|0)<16);j=j+1|0;}while((j|0)<16);h=h+1|0;}while((h|0)<4);h=f+1|0;if((h|0)<512){f=h}else{r=0;break}}}while(1){if((r|0)>=1024){e=82506;break}s=9638528+(r<<2)|0;if((c[s>>2]|0)==(b|0)){break}else{r=r+1|0}}if((e|0)==82506){return}gGr(b);c[s>>2]=0;return}function dwr(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;a=c[2439330]|0;d=(a|0)==0;if(!d){e=a;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];e=c[3528484]|0;c[2076596]=e;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;g=c[3529252]|0;h=0;i=0;while(1){c[a+76+(i<<2)>>2]=g+(i<<8);j=h+1&65535;if((j&65535)>127){k=0;l=0;break}else{h=j;i=j&65535}}while(1){i=g+(l<<8)|0;c[a+76+(l+512<<2)>>2]=i;c[a+76+(l+768<<2)>>2]=i;i=k+1&65535;if((i&65535)>127){break}else{k=i;l=i&65535}}l=c[3529340]|0;k=192;g=192;while(1){c[a+76+(g<<2)>>2]=l+((g<<8)-49152);i=k+1&65535;if((i&65535)>221){m=192;n=192;break}else{k=i;g=i&65535}}while(1){c[a+76+(n+256<<2)>>2]=l+((n<<8)-49152);g=m+1&65535;if((g&65535)>221){o=192;p=192;break}else{m=g;n=g&65535}}while(1){n=l+((p<<8)-49152)|0;c[a+76+(p+512<<2)>>2]=n;c[a+76+(p+768<<2)>>2]=n;n=o+1&65535;if((n&65535)>221){break}else{o=n;p=n&65535}}p=c[2386498]|0;c[a+964>>2]=p;o=p+256|0;c[a+968>>2]=o;c[a+1988>>2]=p;c[a+1992>>2]=o;c[a+3012>>2]=p;c[a+4036>>2]=p;c[a+3016>>2]=o;c[a+4040>>2]=o;o=c[2406500]|0;c[a+972>>2]=o;p=o+256|0;c[a+976>>2]=p;l=o+512|0;c[a+980>>2]=l;n=o+768|0;c[a+984>>2]=n;m=o+1024|0;c[a+988>>2]=m;g=o+1280|0;c[a+992>>2]=g;k=o+1536|0;c[a+996>>2]=k;i=o+1792|0;c[a+1e3>>2]=i;c[a+1996>>2]=o;c[a+2e3>>2]=p;c[a+2004>>2]=l;c[a+2008>>2]=n;c[a+2012>>2]=m;c[a+2016>>2]=g;c[a+2020>>2]=k;c[a+2024>>2]=i;c[a+3020>>2]=o;c[a+4044>>2]=o;c[a+3024>>2]=p;c[a+4048>>2]=p;c[a+3028>>2]=l;c[a+4052>>2]=l;c[a+3032>>2]=n;c[a+4056>>2]=n;c[a+3036>>2]=m;c[a+4060>>2]=m;c[a+3040>>2]=g;c[a+4064>>2]=g;c[a+3044>>2]=k;c[a+4068>>2]=k;c[a+3048>>2]=i;c[a+4072>>2]=i;i=c[2406580]|0;c[a+1004>>2]=i;k=i+256|0;c[a+1008>>2]=k;g=i+512|0;c[a+1012>>2]=g;m=i+768|0;c[a+1016>>2]=m;n=i+1024|0;c[a+1020>>2]=n;l=i+1280|0;c[a+1024>>2]=l;p=i+1536|0;c[a+1028>>2]=p;o=i+1792|0;c[a+1032>>2]=o;c[a+2028>>2]=i;c[a+2032>>2]=k;c[a+2036>>2]=g;c[a+2040>>2]=m;c[a+2044>>2]=n;c[a+2048>>2]=l;c[a+2052>>2]=p;c[a+2056>>2]=o;c[a+3052>>2]=i;c[a+4076>>2]=i;c[a+3056>>2]=k;c[a+4080>>2]=k;c[a+3060>>2]=g;c[a+4084>>2]=g;c[a+3064>>2]=m;c[a+4088>>2]=m;c[a+3068>>2]=n;c[a+4092>>2]=n;c[a+3072>>2]=l;c[a+4096>>2]=l;c[a+3076>>2]=p;c[a+4100>>2]=p;c[a+3080>>2]=o;c[a+4104>>2]=o;o=c[2387234]|0;c[a+1036>>2]=o;p=o+256|0;c[a+1040>>2]=p;l=o+512|0;c[a+1044>>2]=l;n=o+768|0;c[a+1048>>2]=n;m=o+1024|0;c[a+1052>>2]=m;g=o+1280|0;c[a+1056>>2]=g;k=o+1536|0;c[a+1060>>2]=k;i=o+1792|0;c[a+1064>>2]=i;c[a+3084>>2]=o;c[a+4108>>2]=o;c[a+3088>>2]=p;c[a+4112>>2]=p;c[a+3092>>2]=l;c[a+4116>>2]=l;c[a+3096>>2]=n;c[a+4120>>2]=n;c[a+3100>>2]=m;c[a+4124>>2]=m;c[a+3104>>2]=g;c[a+4128>>2]=g;c[a+3108>>2]=k;c[a+4132>>2]=k;c[a+3112>>2]=i;c[a+4136>>2]=i;c[a+4180>>2]=742;c[a+4184>>2]=940;if(d){q=c[2433530]|0;c[2438118]=q;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}d=a;gGC(d|0,9706056,76)|0;q=c[2433530]|0;c[2438118]=q;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}function dws(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=c[2439331]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];f=c[3528485]|0;c[2076596]=f;g=c[2417277]|0;c[3541536]=g;c[1836236]=1;i=c[3529208]|0;j=0;k=0;while(1){c[d+76+(k<<2)>>2]=i+(k<<8);l=j+1&65535;if((l&65535)>127){m=0;n=0;break}else{j=l;k=l&65535}}while(1){k=i+(n<<8)|0;c[d+76+(n+512<<2)>>2]=k;c[d+76+(n+768<<2)>>2]=k;k=m+1&65535;if((k&65535)>127){break}else{m=k;n=k&65535}}n=c[3529298]|0;c[d+844>>2]=n;m=n+256|0;c[d+848>>2]=m;i=n+512|0;c[d+852>>2]=i;k=n+768|0;c[d+856>>2]=k;j=n+1024|0;c[d+860>>2]=j;l=n+1280|0;c[d+864>>2]=l;o=n+1536|0;c[d+868>>2]=o;p=n+1792|0;c[d+872>>2]=p;c[d+1868>>2]=n;c[d+1872>>2]=m;c[d+1876>>2]=i;c[d+1880>>2]=k;c[d+1884>>2]=j;c[d+1888>>2]=l;c[d+1892>>2]=o;c[d+1896>>2]=p;c[d+2892>>2]=n;c[d+3916>>2]=n;c[d+2896>>2]=m;c[d+3920>>2]=m;c[d+2900>>2]=i;c[d+3924>>2]=i;c[d+2904>>2]=k;c[d+3928>>2]=k;c[d+2908>>2]=j;c[d+3932>>2]=j;c[d+2912>>2]=l;c[d+3936>>2]=l;c[d+2916>>2]=o;c[d+3940>>2]=o;c[d+2920>>2]=p;c[d+3944>>2]=p;c[d+4180>>2]=2640;c[d+4184>>2]=1752;if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=f;c[2417277]=g;c[1836236]=-1;Vr(2,15e5,0,872,96,0);c[2438228]=3e6;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=681;h[745419]=.1;a[3203368]=1;h[745418]=.2;a[3203360]=1;h[745417]=.2;a[3203352]=1;h[745416]=.2;a[3203344]=1;h[745415]=.1;a[3203336]=1;h[745414]=.2;a[3203328]=1;h[745413]=.2;a[3203320]=1;h[745412]=.2;a[3203312]=1;return}function dwt(a){a=a|0;var b=0.0;b=+(a|0)*+((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)/+((c[2440544]|0)*60|0|0);+V(b)>=1.0?b>0.0?(al(+U(b/4294967296.0),4294967295.0)|0)>>>0:~~+af((b- +(~~b>>>0))/4294967296.0)>>>0:0;return~~b>>>0|0}function dwu(){var b=0,d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0;a[9624616]=0;b=c[2414730]|0;gGz(b|0,0,(c[2411762]|0)-b|0);b=c[2439330]|0;d=(b|0)==0;if(!d){e=b;gGC(9706056,e|0,76)|0}c[2433530]=c[2438118];e=c[3528484]|0;c[2076596]=e;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;gGz(9706056,0,76);a[14117488]=0;g=c[3529252]|0;i=128;j=128;while(1){c[b+76+(j<<2)>>2]=g+((j<<8)+32768);k=i+1&65535;if((k&65535)>191){l=128;m=128;break}else{i=k;j=k&65535}}while(1){j=g+((m<<8)+32768)|0;c[b+76+(m+512<<2)>>2]=j;c[b+76+(m+768<<2)>>2]=j;j=l+1&65535;if((j&65535)>191){break}else{l=j;m=j&65535}}if(!d){d=b;gGC(d|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=e;c[2417276]=f;c[1836236]=-1;f=c[2439331]|0;e=(f|0)==0;if(!e){d=f;gGC(9706056,d|0,76)|0}d=c[2438119]|0;c[2433530]=d;b=c[3528485]|0;c[2076596]=b;m=c[2417277]|0;c[3541536]=m;c[1836236]=1;gGz(9706056,0,76);if(!e){e=f;gGC(e|0,9706056,76)|0}c[2438119]=d;c[3528485]=b;c[2417277]=m;c[1836236]=-1;m=a[6856296]|0;if(m){b=c[2439332]|0;d=(b|0)==0;if(!d){e=b;gGC(9706056,e|0,76)|0}e=c[2438120]|0;c[2433530]=e;f=c[3528486]|0;c[2076596]=f;l=c[2417278]|0;c[3541536]=l;c[1836236]=2;gGz(9706056,0,76);if(!d){d=b;gGC(d|0,9706056,76)|0}c[2438120]=e;c[3528486]=f;c[2417278]=l;c[1836236]=-1}c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;do{if((c[2385508]|0)>0){l=0;do{lN(l);mB(l);l=l+1|0;}while((l|0)<(c[2385508]|0));if(a[6856296]|0){break}a[9719128]=0;a[9731048]=0;c[2438340]=0;c[2429446]=0;a[9717776]=0;a[9718720]=0;a[14117488]=0;a[14114960]=0;a[9731736]=0;a[14113264]=0;a[9774904]=0;return}else{if(m){break}a[9719128]=0;a[9731048]=0;c[2438340]=0;c[2429446]=0;a[9717776]=0;a[9718720]=0;a[14117488]=0;a[14114960]=0;a[9731736]=0;a[14113264]=0;a[9774904]=0;return}}while(0);UA();a[9719128]=0;a[9731048]=0;c[2438340]=0;c[2429446]=0;a[9717776]=0;a[9718720]=0;a[14117488]=0;a[14114960]=0;a[9731736]=0;a[14113264]=0;a[9774904]=0;return}function dwv(a){a=a|0;return(ag((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0,a)|0)/3e6|0|0}function dww(){return+(+((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)/3.0e6)}function dwx(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=c[2406500]|0;e=c[2112926]|0;f=c[3530886]|0;g=32;do{h=g<<3&248;i=d[b+(g|1024)|0]|0;j=i<<2&768|(d[b+g|0]|0);k=i&15;l=(g>>5<<3)-8|0;m=(i&16|0)!=0;do{if((i&32|0)==0){if(m){Ss(e,j,h,l,k,2,3,a,f);break}else{Sq(e,j,h,l,k,2,3,a,f);break}}else{if(m){Sw(e,j,h,l,k,2,3,a,f);break}else{Su(e,j,h,l,k,2,3,a,f);break}}}while(0);g=g+1|0;}while((g|0)<992);return}function dwy(e){e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;f=c[2406816]|0;g=d[f+1|0]<<8&256|d[f];f=c[2406814]|0;h=(e|0)==0;i=-8-(d[f+1|0]<<8&256|d[f])|0;f=e<<4;e=c[2406580]|0;j=c[2113070]|0;k=c[2113068]|0;l=a[641792]|0;m=c[3530650]|0;n=c[3530972]|0;o=c[2112926]|0;p=0;do{q=d[e+(p|1024)|0]|0;if(h){r=82574}else{if((q&8|0)!=0){r=82574}}L101133:do{if((r|0)==82574){r=0;s=(p>>5<<4)-g|0;t=(p<<4&496)+i|0;u=(s|0)<-15?s+512|0:s;s=(t|0)<-15?t+512|0:t;if(!((u|0)>-16&(s|0)>-16&(s|0)<(j|0)&(u|0)<(k|0))){break}t=q&7;v=m+((d[e+p|0]|q<<3&1792)<<8)|0;w=(l?t^6:t)<<4|256;if((q&16|0)==0){t=0;x=v;while(1){y=t+s|0;L101152:do{if((y|0)>=0){if((y|0)>=(j|0)){break L101133}z=ag(k,y)|0;A=0;do{B=A+u|0;do{if((B|0)>=0){if((B|0)>=(k|0)){break L101152}C=d[x+A|0]|0;if((a[n+(C+f)|0]|0)!=0){break}b[o+(z+B<<1)>>1]=(C|w)&65535}}while(0);A=A+1|0;}while((A|0)<16)}}while(0);y=t+1|0;if((y|0)<16){t=y;x=x+16|0}else{break}}}else{x=0;t=v;while(1){y=x+s|0;L101139:do{if((y|0)>=0){if((y|0)>=(j|0)){break L101133}A=ag(k,y)|0;z=15;while(1){B=z+u|0;if((B|0)<0){break L101139}do{if((B|0)<(k|0)){C=d[t+(15-z)|0]|0;if((a[n+(C+f)|0]|0)!=0){break}b[o+(A+B<<1)>>1]=(C|w)&65535}}while(0);if((z|0)>0){z=z-1|0}else{break}}}}while(0);y=x+1|0;if((y|0)<16){x=y;t=t+16|0}else{break}}}}}while(0);p=p+1|0;}while((p|0)<1024);return}function dwz(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((b&65535)<8192){a[(c[2386496]|0)+(e&8191)|0]=d;if(b<<16>>16!=8178){return}a[c[2438324]|0]=1;return}if((e&64512|0)==16384){UZ(e&1023,d&255);return}if((e|0)==32768){c[2388378]=0;return}else if((e|0)==34816){a[9660786]=0;return}else if((e|0)==45056|(e|0)==45057|(e|0)==45058|(e|0)==45060|(e|0)==45061|(e|0)==45062){a[(c[2409004]|0)+(e&7)|0]=d;return}else{return}}function dwA(b){b=b|0;var d=0,e=0;d=b&65535;if((d&64512|0)!=16384){e=0;return e|0}e=a[(c[2438116]|0)+(d&1023)|0]|0;return e|0}function dwB(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((e&65504|0)==0){f4S(b&31,d);return}if((e&65408|0)==128){a[(c[2438792]|0)+(e&127)|0]=d;return}if((e&64512|0)!=4096){return}UZ(e&1023,d&255);return}function dwC(b){b=b|0;var d=0,e=0;d=b&65535;if((d&65504|0)==0){e=f4R(b&31)|0;return e|0}if((d&65408|0)==128){e=a[(c[2438792]|0)+(d&127)|0]|0;return e|0}if(b<<16>>16==4357){b=(c[2384530]|0)+1|0;c[2384530]=b;e=b>>>4&255;return e|0}if((d&64512|0)!=4096){e=0;return e|0}e=a[(c[2438116]|0)+(d&1023)|0]|0;return e|0}function dwD(b,d){b=b|0;d=d|0;var e=0;e=b&511;if((e|0)==256){b=d&224;if((b|0)==192){a[c[2442900]|0]=d&1^1;return}else if((b|0)==96){a[c[2385606]|0]=d&7;return}else{return}}else if((e|0)==257){e=d&255;d=a[632536]|0;b=d?2:0;if(!d){return}d=(c[2438060]|0)==(c[1839550]|0);c[14114352+((d?0:b-1|0)<<2)>>2]=e>>>3&1;c[14114352+((d?1:b-2|0)<<2)>>2]=e>>>4&1;return}else{return}}function dwE(b){b=b|0;var e=0,f=0;e=b&511;if((e|0)==257){f=-1}else if((e|0)==256){f=a[9550704+(d[c[2385606]|0]|0)|0]|0}else{f=0}return f|0}function dwF(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3166436+(b*112|0)>>2];c[a+104>>2]=c[3166440+(b*112|0)>>2];c[a+108>>2]=c[3166444+(b*112|0)>>2];d=0;return d|0}function dwG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=3166336+(b*112|0);e=0;return e|0}function dwH(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1312528+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dwI(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>42){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4251096+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dwJ(){return dwW(0)|0}function dwK(){var b=0,d=0,e=0,f=0;c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}gGz(14114352,0,32);R4(0);a[632536]=0;c[2433642]=0;c[2432922]=0;a[632544]=0;c[2394816]=0;a[5804e3]=0;c[2394812]=0;c[2394808]=0;c[2438060]=0;c[2440444]=0;c[1839550]=-1;b=c[2420424]|0;if((b|0)!=0){gGr(b);c[2420424]=0}b=c[2433528]|0;if((b|0)!=0){gGr(b);c[2433528]=0}c[2113160]=0;b=c[2433592]|0;if((b|0)!=0){gGr(b);c[2433592]=0}b=c[2437644]|0;if((b|0)!=0){gGr(b);c[2437644]=0}b=c[2415022]|0;d=0;while(1){if((d|0)>=1024){e=82703;break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==(b|0)){break}else{d=d+1|0}}if((e|0)==82703){c[2415022]=0;c[3541148]=0;return 0}gGr(b);c[f>>2]=0;c[2415022]=0;c[3541148]=0;return 0}function dwL(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;do{if((a[9624608]|0)==0){e=(c[2388378]|0)+1|0;c[2388378]=e;if((e|0)<=180){break}c[3528554]=0;f43(c[2433592]|0);e=c[3528554]|0;c[2113158]=c[9731360+(e<<2)>>2];a[9660796]=0;a[9660797]=0;a[9660786]=0;a[9660787]=0;c[2415191]=0;a[9660784]=a[9660784]|80;f=c[2433592]|0;g=c[f+(e*3148|0)+1068>>2]|0;do{if((g|0)==0){h=c[f+(e*3148|0)+3120>>2]|0;if((h|0)==0){i=0;j=0;k=e;l=f;break}m=gj[h&4095](-2)|0;h=c[3528554]|0;n=c[2433592]|0;o=c[n+(h*3148|0)+1068>>2]|0;p=(m&255)<<8;if((o|0)!=0){q=o;r=p;s=h;t=n;u=82727;break}o=c[n+(h*3148|0)+3120>>2]|0;if((o|0)==0){i=0;j=p;k=h;l=n;break}n=gj[o&4095](-1)|0;i=n;j=p;k=c[3528554]|0;l=c[2433592]|0}else{q=g;r=d[g+254|0]<<8;s=e;t=f;u=82727}}while(0);if((u|0)==82727){i=a[q+255|0]|0;j=r;k=s;l=t}f=i&255|j;c[2415188]=f;b[4830376]=f&65535;f=l+(k*3148|0)|0;if((f|0)!=0){e=f;gGC(e|0,9660752,48)|0}c[9731360+(k<<2)>>2]=c[2113158];c[3528554]=-1;a[9660900]=a[9660900]|16;e=c[2437644]|0;f=c[e+1092>>2]|0;do{if((f|0)==0){g=c[e+3144>>2]|0;if((g|0)==0){v=0;w=0;break}p=gj[g&4095](-2)|0;g=c[2437644]|0;n=c[g+1092>>2]|0;o=(p&255)<<8;if((n|0)!=0){x=n;y=o;u=82736;break}n=c[g+3144>>2]|0;if((n|0)==0){v=0;w=o;break}v=gj[n&4095](-1)|0;w=o}else{x=f;y=d[f+254|0]<<8;u=82736}}while(0);if((u|0)==82736){v=a[x+255|0]|0;w=y}f=v&255|w;c[2415221]=f;b[4830442]=f&65535;a[9660920]=0;a[9660921]=0;a[9660928]=0;a[9660930]=0;a[9660931]=0;c[2415234]=0;gGz(9660901,0,5);c[2415235]=65535;c[2415237]=65535;a[9660932]=a[9660932]|64;gGz(14114352,0,32);R4(0);R4(1);c[2388378]=0}else{f=c[2414728]|0;gGz(f|0,0,(c[2411760]|0)-f|0);c[3528554]=0;f43(c[2433592]|0);f=c[3528554]|0;c[2113158]=c[9731360+(f<<2)>>2];a[9660796]=0;a[9660797]=0;a[9660786]=0;a[9660787]=0;c[2415191]=0;a[9660784]=a[9660784]|80;e=c[2433592]|0;o=c[e+(f*3148|0)+1068>>2]|0;do{if((o|0)==0){n=c[e+(f*3148|0)+3120>>2]|0;if((n|0)==0){z=0;A=0;B=f;C=e;break}g=gj[n&4095](-2)|0;n=c[3528554]|0;p=c[2433592]|0;h=c[p+(n*3148|0)+1068>>2]|0;m=(g&255)<<8;if((h|0)!=0){D=h;E=m;F=n;G=p;u=82709;break}h=c[p+(n*3148|0)+3120>>2]|0;if((h|0)==0){z=0;A=m;B=n;C=p;break}p=gj[h&4095](-1)|0;z=p;A=m;B=c[3528554]|0;C=c[2433592]|0}else{D=o;E=d[o+254|0]<<8;F=f;G=e;u=82709}}while(0);if((u|0)==82709){z=a[D+255|0]|0;A=E;B=F;C=G}e=z&255|A;c[2415188]=e;b[4830376]=e&65535;e=C+(B*3148|0)|0;if((e|0)!=0){f=e;gGC(f|0,9660752,48)|0}c[9731360+(B<<2)>>2]=c[2113158];c[3528554]=-1;a[9660900]=a[9660900]|16;f=c[2437644]|0;e=c[f+1092>>2]|0;do{if((e|0)==0){o=c[f+3144>>2]|0;if((o|0)==0){H=0;I=0;break}m=gj[o&4095](-2)|0;o=c[2437644]|0;p=c[o+1092>>2]|0;h=(m&255)<<8;if((p|0)!=0){J=p;K=h;u=82718;break}p=c[o+3144>>2]|0;if((p|0)==0){H=0;I=h;break}H=gj[p&4095](-1)|0;I=h}else{J=e;K=d[e+254|0]<<8;u=82718}}while(0);if((u|0)==82718){H=a[J+255|0]|0;I=K}e=H&255|I;c[2415221]=e;b[4830442]=e&65535;a[9660920]=0;a[9660921]=0;a[9660928]=0;a[9660930]=0;a[9660931]=0;c[2415234]=0;gGz(9660901,0,5);c[2415235]=65535;c[2415237]=65535;a[9660932]=a[9660932]|64;gGz(14114352,0,32);R4(0);R4(1);c[2388378]=1}}while(0);I=9550704;c[I>>2]=-1;c[I+4>>2]=-1;I=0;H=-1;K=-1;J=-1;do{H=((a[9634008+I|0]&1)<<I^H&255)&255;K=((a[9629760+I|0]&1)<<I^K&255)&255;J=((a[9631800+I|0]&1)<<I^J&255)&255;I=I+1|0;}while((I|0)<8);a[9550708]=H;a[9550709]=K;a[9550710]=J;J=a[9635400]|0;a[9550704]=(J&255)>>>3;K=a[9635401]|0;a[9550705]=J<<2&28|(K&255)>>>6;a[9550706]=(K&255)>>>1&31;a[9550707]=a[9635402]&15|J<<4&16;if((a[c[2442900]|0]|0)!=0){a[9550708]=H|6}H=c[2113160]|0;if((H|0)>0){gGz(9731360,0,((H|0)>1?H<<2:4)|0)}c[2113158]=0;c[2113162]=0;c[2443982]=0;c[2444030]=0;H=0;while(1){c[3528554]=0;f43(c[2433592]|0);c[2113158]=c[9731360+(c[3528554]<<2)>>2];J=H+1|0;K=f45(((J*25600|0|0)/100|0)-(c[2444030]|0)|0)|0;I=(c[2113158]|0)+K|0;c[2113158]=I;c[2444030]=(c[2444030]|0)+K;if((H|0)==99){f44(0);K=c[3528554]|0;u=(c[2433592]|0)+(K*3148|0)|0;if((u|0)!=0){B=u;gGC(B|0,9660752,48)|0}c[9731360+(K<<2)>>2]=c[2113158];c[3528554]=-1;K=f4D(((J*102400|0|0)/100|0)-(c[2443982]|0)|0)|0;c[2113162]=(c[2113162]|0)+K;c[2443982]=(c[2443982]|0)+K;f01();f4D(0)|0;if((a[9660903]|0)!=0){a[9660903]=0}f4D(0)|0}else{K=c[3528554]|0;B=(c[2433592]|0)+(K*3148|0)|0;if((B|0)!=0){u=B;gGC(u|0,9660752,48)|0}c[9731360+(K<<2)>>2]=I;c[3528554]=-1;I=f4D(((J*102400|0|0)/100|0)-(c[2443982]|0)|0)|0;c[2113162]=(c[2113162]|0)+I;c[2443982]=(c[2443982]|0)+I}if((J|0)<100){H=J}else{break}}H=c[2112964]|0;if((H|0)!=0){UX(H,a[9688]|0?534:0)}if((c[2112968]|0)!=0){dwM()|0}H=c[2438324]|0;if((a[H]|0)==0){return 0}J=c[2386496]|0;I=0;do{K=J+(I+6154)|0;u=J+(I+6148)|0;a[K]=a[u]|0;a[K+1|0]=a[u+1|0]|0;a[K+2|0]=a[u+2|0]|0;a[K+3|0]=a[u+3|0]|0;a[K+4|0]=a[u+4|0]|0;a[K+5|0]=a[u+5|0]|0;I=I+16|0;}while((I|0)<2048);a[H]=0;return 0}function dwM(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((a[9547696]|0)!=0){b=c[2406968]|0;e=c[3530086]|0;f=0;do{g=c[b+(f<<2)>>2]|0;c[e+(f<<2)>>2]=g>>8<<3&2016|g>>>3&31|g>>16<<8&63488;f=f+1|0;}while((f|0)<2048);a[9547696]=0}f=a[(c[2386496]|0)+8182|0]&1;e=c[3528738]|0;a[e]=f;R4(f&255);f=(a[c[2409004]|0]&14)==12|0;dwX(f,0);dwY(0);dwX(f^1,1);dwY(1);f=c[2386332]|0;b=c[2112926]|0;g=c[3530884]|0;h=0;do{i=h+2|0;j=i<<5;k=h<<3;l=216-k|0;m=0;do{n=m-2|0;if((n&32|0)==0){o=n+j|0}else{o=(n<<5&992)+i|0}n=d[f+o|0]|0;p=d[f+(o+1024)|0]<<2&508;q=m<<3;if((a[e]|0)==0){Sr(b,n,q,k,p,2,3,0,g)}else{Sr(b,n,280-q|0,l,p,2,3,0,g)}m=m+1|0;}while((m|0)<36);h=h+1|0;}while((h|0)<28);R8(c[3530086]|0);R5();return 0}function dwN(a,b){a=a|0;b=b|0;return 1}function dwO(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3113716+(b*112|0)>>2];c[a+104>>2]=c[3113720+(b*112|0)>>2];c[a+108>>2]=c[3113724+(b*112|0)>>2];d=0;return d|0}function dwP(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=3113616+(b*112|0);e=0;return e|0}function dwQ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2574116+(b*112|0)>>2];c[a+104>>2]=c[2574120+(b*112|0)>>2];c[a+108>>2]=c[2574124+(b*112|0)>>2];d=0;return d|0}function dwR(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=2574016+(b*112|0);e=0;return e|0}function dwS(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>32){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3742256+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dwT(){return dwW(1)|0}function dwU(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1457412+(b*112|0)>>2];c[a+104>>2]=c[1457416+(b*112|0)>>2];c[a+108>>2]=c[1457420+(b*112|0)>>2];d=0;return d|0}function dwV(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=1457312+(b*112|0);e=0;return e|0}function dwW(e){e=e|0;var f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0;f=i;i=i+2280|0;g=f|0;j=f+112|0;k=f+120|0;l=f+232|0;m=f+240|0;n=f+352|0;o=f+360|0;p=f+472|0;q=f+480|0;r=f+592|0;s=f+600|0;t=f+712|0;u=f+720|0;v=f+832|0;w=f+840|0;x=f+952|0;y=f+960|0;z=f+1072|0;A=f+1080|0;B=f+1192|0;C=f+1200|0;D=f+1312|0;E=f+1320|0;F=f+1432|0;G=f+1440|0;H=f+1552|0;I=f+1560|0;J=f+1672|0;K=f+1680|0;L=f+1792|0;M=f+1800|0;N=f+1912|0;O=f+1920|0;P=f+2032|0;Q=f+2040|0;R=f+2152|0;S=f+2160|0;T=f+2272|0;c[2415022]=0;c[3527388]=0;c[2439832]=65536;c[3530884]=131072;c[3530648]=163840;c[3530458]=294912;c[3531026]=425984;c[2406968]=430080;c[3530086]=438272;c[2414728]=446464;c[2438792]=446464;c[2439836]=446592;c[3541148]=448640;c[2386242]=449664;c[2386332]=457856;c[2386496]=459904;c[2442900]=468096;c[2385606]=468097;c[2438324]=468098;c[3528738]=468099;c[2409004]=468100;c[2411760]=468108;U=0;while(1){if((U|0)>=1024){break}V=9638528+(U<<2)|0;if((c[V>>2]|0)==0){W=82831;break}else{U=U+1|0}}do{if((W|0)==82831){U=gGq(468108)|0;c[V>>2]=U;if((U|0)==0){break}c[2415022]=U;gGz(U|0,0,468108);c[3527388]=U;c[2439832]=U+65536;c[3530884]=U+131072;c[3530648]=U+163840;c[3530458]=U+294912;c[3531026]=U+425984;c[2406968]=U+430080;c[3530086]=U+438272;X=U+446464|0;c[2414728]=X;c[2438792]=X;c[2439836]=U+446592;X=U+448640|0;c[3541148]=X;c[2386176]=X;c[2386242]=U+449664;c[2386332]=U+457856;c[2386496]=U+459904;c[2442900]=U+468096;c[2385606]=U+468097;c[2438324]=U+468098;c[3528738]=U+468099;c[2409004]=U+468100;X=U+468108|0;c[2411760]=X;c[2414308]=X;X=U+24576|0;if((c[3542200]|0)==0){Y=1;i=f;return Y|0}U=S+108|0;c[U>>2]=0;Z=S+100|0;c[Z>>2]=0;_=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[_&16383](S,0)|0;do{if((c[U>>2]|0)!=0){_=c[Z>>2]|0;c[T>>2]=9534384;$=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[$&16383](T,0,0)|0;if((_|0)<1){Y=1;i=f;return Y|0}if((gzL(X,0,0)|0)==0){break}else{Y=1}i=f;return Y|0}}while(0);X=(c[3527388]|0)+32768|0;if((c[3542200]|0)==0){Y=1;i=f;return Y|0}Z=Q+108|0;c[Z>>2]=0;U=Q+100|0;c[U>>2]=0;_=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[_&16383](Q,1)|0;do{if((c[Z>>2]|0)!=0){_=c[U>>2]|0;c[R>>2]=9534384;$=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[$&16383](R,1,0)|0;if((_|0)<1){Y=1;i=f;return Y|0}if((gzL(X,0,1)|0)==0){break}else{Y=1}i=f;return Y|0}}while(0);X=(c[3527388]|0)+49152|0;if((c[3542200]|0)==0){Y=1;i=f;return Y|0}U=O+108|0;c[U>>2]=0;Z=O+100|0;c[Z>>2]=0;_=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[_&16383](O,2)|0;do{if((c[U>>2]|0)!=0){_=c[Z>>2]|0;c[P>>2]=9534384;$=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[$&16383](P,2,0)|0;if((_|0)<1){Y=1;i=f;return Y|0}if((gzL(X,0,2)|0)==0){break}else{Y=1}i=f;return Y|0}}while(0);X=(c[2439832]|0)+32768|0;if((c[3542200]|0)==0){Y=1;i=f;return Y|0}Z=M+108|0;c[Z>>2]=0;U=M+100|0;c[U>>2]=0;_=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[_&16383](M,3)|0;do{if((c[Z>>2]|0)!=0){_=c[U>>2]|0;c[N>>2]=9534384;$=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[$&16383](N,3,0)|0;if((_|0)<1){Y=1;i=f;return Y|0}if((gzL(X,0,3)|0)==0){break}else{Y=1}i=f;return Y|0}}while(0);X=(c[2439832]|0)+61440|0;if((c[3542200]|0)==0){Y=1;i=f;return Y|0}U=K+108|0;c[U>>2]=0;Z=K+100|0;c[Z>>2]=0;_=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[_&16383](K,4)|0;do{if((c[U>>2]|0)!=0){_=c[Z>>2]|0;c[L>>2]=9534384;$=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[$&16383](L,4,0)|0;if((_|0)<1){Y=1;i=f;return Y|0}if((gzL(X,0,4)|0)==0){break}else{Y=1}i=f;return Y|0}}while(0);X=c[3530884]|0;if((c[3542200]|0)==0){Y=1;i=f;return Y|0}Z=I+108|0;c[Z>>2]=0;U=I+100|0;c[U>>2]=0;_=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[_&16383](I,5)|0;do{if((c[Z>>2]|0)!=0){_=c[U>>2]|0;c[J>>2]=9534384;$=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[$&16383](J,5,0)|0;if((_|0)<1){Y=1;i=f;return Y|0}if((gzL(X,0,5)|0)==0){break}else{Y=1}i=f;return Y|0}}while(0);X=c[3530648]|0;if((c[3542200]|0)==0){Y=1;i=f;return Y|0}U=G+108|0;c[U>>2]=0;Z=G+100|0;c[Z>>2]=0;_=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[_&16383](G,6)|0;do{if((c[U>>2]|0)!=0){_=c[Z>>2]|0;c[H>>2]=9534384;$=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[$&16383](H,6,0)|0;if((_|0)<1){Y=1;i=f;return Y|0}if((gzL(X,0,6)|0)==0){break}else{Y=1}i=f;return Y|0}}while(0);X=(c[3530648]|0)+16384|0;if((c[3542200]|0)==0){Y=1;i=f;return Y|0}Z=E+108|0;c[Z>>2]=0;U=E+100|0;c[U>>2]=0;_=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[_&16383](E,7)|0;do{if((c[Z>>2]|0)!=0){_=c[U>>2]|0;c[F>>2]=9534384;$=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[$&16383](F,7,0)|0;if((_|0)<1){Y=1;i=f;return Y|0}if((gzL(X,0,7)|0)==0){break}else{Y=1}i=f;return Y|0}}while(0);X=(c[3530648]|0)+32768|0;do{if((e|0)==0){if((c[3542200]|0)==0){Y=1;i=f;return Y|0}U=C+108|0;c[U>>2]=0;Z=C+100|0;c[Z>>2]=0;_=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[_&16383](C,8)|0;do{if((c[U>>2]|0)!=0){_=c[Z>>2]|0;c[D>>2]=9534384;$=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[$&16383](D,8,0)|0;if((_|0)<1){Y=1;i=f;return Y|0}if((gzL(X,0,8)|0)==0){break}else{Y=1}i=f;return Y|0}}while(0);Z=c[3530458]|0;if((c[3542200]|0)==0){Y=1;i=f;return Y|0}U=A+108|0;c[U>>2]=0;_=A+100|0;c[_>>2]=0;$=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[$&16383](A,9)|0;do{if((c[U>>2]|0)!=0){$=c[_>>2]|0;c[B>>2]=9534384;aa=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aa&16383](B,9,0)|0;if(($|0)<1){Y=1;i=f;return Y|0}if((gzL(Z,0,9)|0)==0){break}else{Y=1}i=f;return Y|0}}while(0);Z=(c[3530458]|0)+16384|0;if((c[3542200]|0)==0){Y=1;i=f;return Y|0}_=y+108|0;c[_>>2]=0;U=y+100|0;c[U>>2]=0;$=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[$&16383](y,10)|0;do{if((c[_>>2]|0)!=0){$=c[U>>2]|0;c[z>>2]=9534384;aa=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aa&16383](z,10,0)|0;if(($|0)<1){Y=1;i=f;return Y|0}if((gzL(Z,0,10)|0)==0){break}else{Y=1}i=f;return Y|0}}while(0);Z=(c[3530458]|0)+32768|0;if((c[3542200]|0)==0){Y=1;i=f;return Y|0}U=w+108|0;c[U>>2]=0;_=w+100|0;c[_>>2]=0;$=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[$&16383](w,11)|0;do{if((c[U>>2]|0)!=0){$=c[_>>2]|0;c[x>>2]=9534384;aa=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aa&16383](x,11,0)|0;if(($|0)<1){Y=1;i=f;return Y|0}if((gzL(Z,0,11)|0)==0){break}else{Y=1}i=f;return Y|0}}while(0);Z=(c[3530458]|0)+49152|0;if((c[3542200]|0)==0){Y=1;i=f;return Y|0}_=u+108|0;c[_>>2]=0;U=u+100|0;c[U>>2]=0;$=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[$&16383](u,12)|0;do{if((c[_>>2]|0)!=0){$=c[U>>2]|0;c[v>>2]=9534384;aa=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aa&16383](v,12,0)|0;if(($|0)<1){Y=1;i=f;return Y|0}if((gzL(Z,0,12)|0)==0){break}else{Y=1}i=f;return Y|0}}while(0);Z=c[3531026]|0;if((c[3542200]|0)==0){Y=1;i=f;return Y|0}U=s+108|0;c[U>>2]=0;_=s+100|0;c[_>>2]=0;$=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[$&16383](s,13)|0;do{if((c[U>>2]|0)!=0){$=c[_>>2]|0;c[t>>2]=9534384;aa=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aa&16383](t,13,0)|0;if(($|0)<1){Y=1;i=f;return Y|0}if((gzL(Z,0,13)|0)==0){break}else{Y=1}i=f;return Y|0}}while(0);Z=(c[3531026]|0)+2048|0;if((c[3542200]|0)==0){Y=1;i=f;return Y|0}_=q+108|0;c[_>>2]=0;U=q+100|0;c[U>>2]=0;$=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[$&16383](q,14)|0;if((c[_>>2]|0)==0){break}_=c[U>>2]|0;c[r>>2]=9534384;U=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[U&16383](r,14,0)|0;if((_|0)<1){Y=1;i=f;return Y|0}if((gzL(Z,0,14)|0)==0){break}else{Y=1}i=f;return Y|0}else{gGz(X|0,-1|0,16384);Z=c[3530458]|0;if((c[3542200]|0)==0){Y=1;i=f;return Y|0}_=o+108|0;c[_>>2]=0;U=o+100|0;c[U>>2]=0;$=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[$&16383](o,8)|0;do{if((c[_>>2]|0)!=0){$=c[U>>2]|0;c[p>>2]=9534384;aa=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aa&16383](p,8,0)|0;if(($|0)<1){Y=1;i=f;return Y|0}if((gzL(Z,0,8)|0)==0){break}else{Y=1}i=f;return Y|0}}while(0);Z=(c[3530458]|0)+16384|0;if((c[3542200]|0)==0){Y=1;i=f;return Y|0}U=m+108|0;c[U>>2]=0;_=m+100|0;c[_>>2]=0;$=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[$&16383](m,9)|0;do{if((c[U>>2]|0)!=0){$=c[_>>2]|0;c[n>>2]=9534384;aa=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aa&16383](n,9,0)|0;if(($|0)<1){Y=1;i=f;return Y|0}if((gzL(Z,0,9)|0)==0){break}else{Y=1}i=f;return Y|0}}while(0);Z=c[3531026]|0;if((c[3542200]|0)==0){Y=1;i=f;return Y|0}_=k+108|0;c[_>>2]=0;U=k+100|0;c[U>>2]=0;$=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[$&16383](k,10)|0;do{if((c[_>>2]|0)!=0){$=c[U>>2]|0;c[l>>2]=9534384;aa=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aa&16383](l,10,0)|0;if(($|0)<1){Y=1;i=f;return Y|0}if((gzL(Z,0,10)|0)==0){break}else{Y=1}i=f;return Y|0}}while(0);Z=(c[3531026]|0)+2048|0;if((c[3542200]|0)==0){Y=1;i=f;return Y|0}U=g+108|0;c[U>>2]=0;_=g+100|0;c[_>>2]=0;$=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[$&16383](g,11)|0;if((c[U>>2]|0)==0){break}U=c[_>>2]|0;c[j>>2]=9534384;_=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[_&16383](j,11,0)|0;if((U|0)<1){Y=1;i=f;return Y|0}if((gzL(Z,0,11)|0)==0){break}else{Y=1}i=f;return Y|0}}while(0);X=c[3530648]|0;Z=X+32769|0;U=0;do{_=a[X+(U+32768)|0]|0;a[X+(U+40960)|0]=_<<4;a[X+(U+49152)|0]=_;a[X+(U+57344)|0]=a[Z]<<4;U=U+1|0;}while((U|0)<8192);U=c[3530458]|0;Z=65535;while(1){X=U+Z|0;_=Z<<1;a[U+(_|1)|0]=a[X]&15;a[U+_|0]=(d[X]|0)>>>4;if((Z|0)>0){Z=Z-1|0}else{ab=0;break}}while(1){if((ab|0)>=1024){break}ac=9638528+(ab<<2)|0;if((c[ac>>2]|0)==0){W=82916;break}else{ab=ab+1|0}}L101654:do{if((W|0)==82916){Z=gGq(65536)|0;c[ac>>2]=Z;if((Z|0)==0){break}gGz(Z|0,0,65536);U=c[3530884]|0;gGC(Z|0,U|0,8192)|0;X=0;do{_=X<<6;gGz(U+_|0,0,64);$=X<<7;aa=0;do{ad=$+(c[1238464+(aa<<2)>>2]|0)|0;ae=(aa<<3)+_|0;af=0;do{ah=ad+(c[610928+(af<<2)>>2]|0)|0;if(((d[Z+((ah|0)/8|0)|0]|0)&128>>>((ah&7)>>>0)|0)!=0){ah=U+(ae+af)|0;a[ah]=a[ah]|2}af=af+1|0;}while((af|0)<8);aa=aa+1|0;}while((aa|0)<8);aa=$|4;af=0;do{ae=aa+(c[1238464+(af<<2)>>2]|0)|0;ad=(af<<3)+_|0;ah=0;do{ai=ae+(c[610928+(ah<<2)>>2]|0)|0;if(((d[Z+((ai|0)/8|0)|0]|0)&128>>>((ai&7)>>>0)|0)!=0){ai=U+(ad+ah)|0;a[ai]=a[ai]|1}ah=ah+1|0;}while((ah|0)<8);af=af+1|0;}while((af|0)<8);X=X+1|0;}while((X|0)<512);X=c[3530648]|0;gGC(Z|0,X|0,65536)|0;U=0;while(1){af=U<<6;gGz(X+af|0,0,64);_=U<<7;aa=_+262144|0;$=0;while(1){ah=aa+(c[6669224+($<<2)>>2]|0)|0;ad=($<<3)+af|0;ae=0;do{ai=ah+(c[612480+(ae<<2)>>2]|0)|0;if(((d[Z+((ai|0)/8|0)|0]|0)&128>>>((ai&7)>>>0)|0)!=0){ai=X+(ad+ae)|0;a[ai]=a[ai]|4}ae=ae+1|0;}while((ae|0)<8);ae=$+1|0;if((ae|0)<8){$=ae}else{aj=0;break}}do{$=_+(c[6669224+(aj<<2)>>2]|0)|0;aa=(aj<<3)+af|0;ae=0;do{ad=$+(c[612480+(ae<<2)>>2]|0)|0;if(((d[Z+((ad|0)/8|0)|0]|0)&128>>>((ad&7)>>>0)|0)!=0){ad=X+(aa+ae)|0;a[ad]=a[ad]|2}ae=ae+1|0;}while((ae|0)<8);aj=aj+1|0;}while((aj|0)<8);ae=_|4;aa=0;do{$=ae+(c[6669224+(aa<<2)>>2]|0)|0;ad=(aa<<3)+af|0;ah=0;do{ai=$+(c[612480+(ah<<2)>>2]|0)|0;if(((d[Z+((ai|0)/8|0)|0]|0)&128>>>((ai&7)>>>0)|0)!=0){ai=X+(ad+ah)|0;a[ai]=a[ai]|1}ah=ah+1|0;}while((ah|0)<8);aa=aa+1|0;}while((aa|0)<8);aa=U+1|0;if((aa|0)<1024){U=aa}else{ak=0;break}}while(1){U=(ak<<6)+65536|0;gGz(X+U|0,0,64);aa=ak<<7;af=aa+262144|0;ae=0;while(1){_=af+(c[6669224+(ae<<2)>>2]|0)|0;ah=U+(ae<<3)|0;ad=0;do{$=_+(c[612480+(ad<<2)>>2]|0)|0;if(((d[Z+((($|0)/8|0)+16384)|0]|0)&128>>>(($&7)>>>0)|0)!=0){$=X+(ah+ad)|0;a[$]=a[$]|4}ad=ad+1|0;}while((ad|0)<8);ad=ae+1|0;if((ad|0)<8){ae=ad}else{al=0;break}}do{ae=aa+(c[6669224+(al<<2)>>2]|0)|0;af=U+(al<<3)|0;ad=0;do{ah=ae+(c[612480+(ad<<2)>>2]|0)|0;if(((d[Z+(((ah|0)/8|0)+16384)|0]|0)&128>>>((ah&7)>>>0)|0)!=0){ah=X+(af+ad)|0;a[ah]=a[ah]|2}ad=ad+1|0;}while((ad|0)<8);al=al+1|0;}while((al|0)<8);ad=aa|4;af=0;do{ae=ad+(c[6669224+(af<<2)>>2]|0)|0;ah=U+(af<<3)|0;_=0;do{$=ae+(c[612480+(_<<2)>>2]|0)|0;if(((d[Z+((($|0)/8|0)+16384)|0]|0)&128>>>(($&7)>>>0)|0)!=0){$=X+(ah+_)|0;a[$]=a[$]|1}_=_+1|0;}while((_|0)<8);af=af+1|0;}while((af|0)<8);af=ak+1|0;if((af|0)<1024){ak=af}else{am=0;break}}while(1){if((am|0)>=1024){break L101654}an=9638528+(am<<2)|0;if((c[an>>2]|0)==(Z|0)){break}else{am=am+1|0}}gGr(Z);c[an>>2]=0}}while(0);X=c[3531026]|0;af=c[2406968]|0;U=0;do{ad=d[X+(U+2048)|0]|0;aa=d[X+U|0]|0;c[af+(U<<2)>>2]=(-(aa>>>5&1)&31)+(-(aa>>>7)&143)+(-(aa>>>4&1)&14)+(-(aa>>>6&1)&67)|(-(ad>>>1&1)&31)+(-(ad&1)&14)+(-(ad>>>2&1)&67)+(-(ad>>>3&1)&143)<<16|(-(aa>>>1&1)&31)+(-(aa&1)&14)+(-(aa>>>2&1)&67)+(-(aa>>>3&1)&143)<<8;U=U+1|0;}while((U|0)<2048);a[9547696]=1;c[3528554]=-1;c[2113160]=1;U=gGq(3148)|0;af=U;c[2433592]=af;if((U|0)!=0){gGz(U|0,0,3148);c[U+3120>>2]=3128;c[U+3124>>2]=1840;c[U+3128>>2]=136;c[U+3132>>2]=1902;c[2432840]=0;X=0;do{c[af+48+(X<<2)>>2]=0;X=X+1|0;}while((X|0)<768);c[2113158]=0;c[2415198]=0;X=c[2427044]|0;c[9681616+(X<<3)>>2]=809272;c[9681620+(X<<3)>>2]=0;c[2427044]=X+1}c[3528554]=0;f43(U);X=c[3528554]|0;af=9731360+(X<<2)|0;aa=c[af>>2]|0;c[2113158]=aa;ad=c[2386496]|0;_=c[2433592]|0;ah=0;ae=0;while(1){$=ad+(ae<<8)|0;c[_+(X*3148|0)+48+(ae<<2)>>2]=$;c[_+(X*3148|0)+48+(ae+512<<2)>>2]=$;$=ah+1&65535;if(($&65535)>31){ao=0;ap=0;break}else{ah=$;ae=$&65535}}while(1){c[_+(X*3148|0)+48+(ap+256<<2)>>2]=ad+(ap<<8);ae=ao+1&65535;if((ae&65535)>30){break}else{ao=ae;ap=ae&65535}}ad=c[2386242]|0;ae=32;ah=32;while(1){U=ad+((ah<<8)-8192)|0;c[_+(X*3148|0)+48+(ah<<2)>>2]=U;c[_+(X*3148|0)+48+(ah+256<<2)>>2]=U;c[_+(X*3148|0)+48+(ah+512<<2)>>2]=U;U=ae+1&65535;if((U&65535)>63){break}else{ae=U;ah=U&65535}}ah=c[2386332]|0;c[_+(X*3148|0)+336>>2]=ah;c[_+(X*3148|0)+1360>>2]=ah;c[_+(X*3148|0)+2384>>2]=ah;ae=ah+256|0;c[_+(X*3148|0)+340>>2]=ae;c[_+(X*3148|0)+1364>>2]=ae;c[_+(X*3148|0)+2388>>2]=ae;ae=ah+512|0;c[_+(X*3148|0)+344>>2]=ae;c[_+(X*3148|0)+1368>>2]=ae;c[_+(X*3148|0)+2392>>2]=ae;ae=ah+768|0;c[_+(X*3148|0)+348>>2]=ae;c[_+(X*3148|0)+1372>>2]=ae;c[_+(X*3148|0)+2396>>2]=ae;ae=ah+1024|0;c[_+(X*3148|0)+352>>2]=ae;c[_+(X*3148|0)+1376>>2]=ae;c[_+(X*3148|0)+2400>>2]=ae;ae=ah+1280|0;c[_+(X*3148|0)+356>>2]=ae;c[_+(X*3148|0)+1380>>2]=ae;c[_+(X*3148|0)+2404>>2]=ae;ae=ah+1536|0;c[_+(X*3148|0)+360>>2]=ae;c[_+(X*3148|0)+1384>>2]=ae;c[_+(X*3148|0)+2408>>2]=ae;ae=ah+1792|0;c[_+(X*3148|0)+364>>2]=ae;c[_+(X*3148|0)+1388>>2]=ae;c[_+(X*3148|0)+2412>>2]=ae;ae=c[3527388]|0;ah=96;ad=96;while(1){U=ae+(ad<<8)|0;c[_+(X*3148|0)+48+(ad<<2)>>2]=U;c[_+(X*3148|0)+48+(ad+512<<2)>>2]=U;U=ah+1&65535;if((U&65535)>255){break}else{ah=U;ad=U&65535}}c[_+(X*3148|0)+3124>>2]=1630;c[_+(X*3148|0)+3120>>2]=1862;ad=_+(X*3148|0)|0;if((ad|0)!=0){ah=ad;gGC(ah|0,9660752,48)|0}c[af>>2]=aa;c[3528554]=-1;fwj(2);ah=c[2439832]|0;ad=c[2437644]|0;ae=128;U=128;while(1){$=ah+(U<<8)|0;c[ad+72+(U<<2)>>2]=$;c[ad+72+(U+512<<2)>>2]=$;$=ae+1&65535;if(($&65535)>191){break}else{ae=$;U=$&65535}}U=c[2439836]|0;c[ad+840>>2]=U;c[ad+1864>>2]=U;c[ad+2888>>2]=U;ae=U+256|0;c[ad+844>>2]=ae;c[ad+1868>>2]=ae;c[ad+2892>>2]=ae;ae=U+512|0;c[ad+848>>2]=ae;c[ad+1872>>2]=ae;c[ad+2896>>2]=ae;ae=U+768|0;c[ad+852>>2]=ae;c[ad+1876>>2]=ae;c[ad+2900>>2]=ae;ae=U+1024|0;c[ad+856>>2]=ae;c[ad+1880>>2]=ae;c[ad+2904>>2]=ae;ae=U+1280|0;c[ad+860>>2]=ae;c[ad+1884>>2]=ae;c[ad+2908>>2]=ae;ae=U+1536|0;c[ad+864>>2]=ae;c[ad+1888>>2]=ae;c[ad+2912>>2]=ae;ae=U+1792|0;c[ad+868>>2]=ae;c[ad+1892>>2]=ae;c[ad+2916>>2]=ae;ae=240;U=240;while(1){aa=ah+(U<<8)|0;c[ad+72+(U<<2)>>2]=aa;c[ad+72+(U+512<<2)>>2]=aa;aa=ae+1&65535;if((aa&65535)>255){break}else{ae=aa;U=aa&65535}}c[ad+3144>>2]=1058;c[ad+3148>>2]=2456;c[ad+3160>>2]=990;c[ad+3164>>2]=18;U_(24e3,8);U=c[2420424]|0;h[U+424>>3]=.5;c[U+440>>2]=3;h[U+432>>3]=.5;c[U+444>>2]=3;a[632536]=1;a[632544]=1;c[2394816]=5;a[5804e3]=1;c[2433642]=255;c[2432922]=1;U=c[642608+(c[2436]<<2)>>2]|0;ae=U+52|0;c[2438060]=(c[ae>>2]|0)>>>1&1;gGz(14114352,0,32);R4(0);ah=c[U+128>>2]|0;if((c[ae>>2]&4|0)==0){c[2113068]=ah;ae=c[U+132>>2]|0;c[2113070]=ae;c[2443814]=ah;c[2440436]=ae;aq=ah;ar=ae}else{c[2113070]=ah;ae=c[U+132>>2]|0;c[2113068]=ae;c[2440436]=ah;c[2443814]=ae;aq=ae;ar=ah}ah=ag(aq<<1,ar)|0;ae=gGq(ah)|0;c[2112926]=ae;if((ae|0)!=0){gGz(ae|0,0,ah|0)}ah=c[2414728]|0;gGz(ah|0,0,(c[2411760]|0)-ah|0);c[3528554]=0;f43(c[2433592]|0);ah=c[3528554]|0;c[2113158]=c[9731360+(ah<<2)>>2];a[9660796]=0;a[9660797]=0;a[9660786]=0;a[9660787]=0;c[2415191]=0;a[9660784]=a[9660784]|80;ae=c[2433592]|0;U=c[ae+(ah*3148|0)+1068>>2]|0;do{if((U|0)==0){aa=c[ae+(ah*3148|0)+3120>>2]|0;if((aa|0)==0){as=0;at=0;au=ah;av=ae;break}af=gj[aa&4095](-2)|0;aa=c[3528554]|0;X=c[2433592]|0;_=c[X+(aa*3148|0)+1068>>2]|0;$=(af&255)<<8;if((_|0)!=0){aw=_;ax=$;ay=aa;az=X;W=82969;break}_=c[X+(aa*3148|0)+3120>>2]|0;if((_|0)==0){as=0;at=$;au=aa;av=X;break}X=gj[_&4095](-1)|0;as=X;at=$;au=c[3528554]|0;av=c[2433592]|0}else{aw=U;ax=(d[U+254|0]|0)<<8;ay=ah;az=ae;W=82969}}while(0);if((W|0)==82969){as=a[aw+255|0]|0;at=ax;au=ay;av=az}ae=as&255|at;c[2415188]=ae;b[4830376]=ae&65535;ae=av+(au*3148|0)|0;if((ae|0)!=0){ah=ae;gGC(ah|0,9660752,48)|0}c[9731360+(au<<2)>>2]=c[2113158];c[3528554]=-1;a[9660900]=a[9660900]|16;ah=c[2437644]|0;ae=c[ah+1092>>2]|0;do{if((ae|0)==0){U=c[ah+3144>>2]|0;if((U|0)==0){aA=0;aB=0;break}ad=gj[U&4095](-2)|0;U=c[2437644]|0;$=c[U+1092>>2]|0;X=(ad&255)<<8;if(($|0)!=0){aC=$;aD=X;W=82978;break}$=c[U+3144>>2]|0;if(($|0)==0){aA=0;aB=X;break}aA=gj[$&4095](-1)|0;aB=X}else{aC=ae;aD=(d[ae+254|0]|0)<<8;W=82978}}while(0);if((W|0)==82978){aA=a[aC+255|0]|0;aB=aD}ae=aA&255|aB;c[2415221]=ae;b[4830442]=ae&65535;a[9660920]=0;a[9660921]=0;a[9660928]=0;a[9660930]=0;a[9660931]=0;c[2415234]=0;gGz(9660901,0,5);c[2415235]=65535;c[2415237]=65535;a[9660932]=a[9660932]|64;gGz(14114352,0,32);R4(0);R4(1);c[2388378]=0;Y=0;i=f;return Y|0}}while(0);c[2415022]=0;Y=1;i=f;return Y|0}function dwX(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=c[2386242]|0;g=b<<12;h=b<<2;i=c[2409004]|0;j=(d[i+h|0]<<8|d[i+(h|1)|0])+((b|0)!=0?24:26)&511;k=(d[i+(h|2)|0]|0)+9&255;h=b<<10;b=c[3528738]|0;i=c[2112926]|0;l=c[3530648]|0;m=c[2113068]|0;n=c[2113070]|0;if((e|0)==0){e=0;do{o=(e<<3&504)-j|0;p=(o|0)<-7?o+512|0:o;o=(e>>6<<3)-k|0;q=(o|0)<-7?o+256|0:o;do{if((p|0)<(m|0)&(q|0)<(n|0)){o=e<<1;r=d[f+((o|1)+g)|0]|0;s=d[f+(o+g)|0]|h|r<<8&768;if((a[b]|0)==0){Sj(i,s,p,q,r,3,0,l);break}else{Sp(i,s,280-p|0,216-q|0,r,3,0,l);break}}}while(0);e=e+1|0;}while((e|0)<2048);return}else{e=0;do{q=(e<<3&504)-j|0;p=(q|0)<-7?q+512|0:q;q=(e>>6<<3)-k|0;r=(q|0)<-7?q+256|0:q;do{if((p|0)<(m|0)&(r|0)<(n|0)){q=e<<1;s=d[f+((q|1)+g)|0]|0;o=d[f+(q+g)|0]|h|s<<8&768;if((a[b]|0)==0){Sr(i,o,p,r,s,3,7,0,l);break}else{Sx(i,o,280-p|0,216-r|0,s,3,7,0,l);break}}}while(0);e=e+1|0;}while((e|0)<2048);return}}function dwY(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;e=c[2386496]|0;f=(d[e+8181|0]|0)-(d[e+8180|0]<<8&256)|0;g=240-(d[e+8183|0]|0)|0;h=c[3528738]|0;i=c[2112926]|0;j=c[3530458]|0;k=0;l=e+6144|0;while(1){e=d[l+10|0]|0;if((e&1|0)==(b|0)){m=d[l+12|0]|0;n=(m<<8&256|d[l+13|0])+f|0;o=d[l+14|0]|0;p=e>>>5&1;q=o&1;r=e>>>7;s=o>>>2&1;t=d[l+11|0]<<2|(e&16|0)!=0&(r|0)==0&1;e=(o&16|0)!=0&(s|0)==0?t|2:t;t=s<<4;o=g-(d[l+15|0]|0)-t|0;if((a[h]|0)==0){u=q;v=p;w=o;x=n}else{u=q^1;v=p^1;w=240-t-o|0;x=499-(r<<4)-n|0}n=u&-s;o=v&-r;t=(u|0)==0;p=(v|0)!=0;q=m>>>1;m=0;do{y=((m^n)<<1)+e|0;z=((m<<4)+w&255)+1|0;if(t){A=0;do{B=(A^o)+y&511;C=((A<<4)+x&511)-71|0;if(p){SJ(i,B,C,z,q,4,15,0,j)}else{SH(i,B,C,z,q,4,15,0,j)}A=A+1|0;}while((A|0)<=(r|0))}else{A=0;do{C=(A^o)+y&511;B=((A<<4)+x&511)-71|0;if(p){SN(i,C,B,z,q,4,15,0,j)}else{SL(i,C,B,z,q,4,15,0,j)}A=A+1|0;}while((A|0)<=(r|0))}m=m+1|0;}while((m|0)<=(s|0))}s=k+16|0;if((s|0)<2032){k=s;l=l+16|0}else{break}}return}function dwZ(b,d){b=b|0;d=d|0;var e=0,f=0;e=b&65535;if((e|0)==46592){b=d&255;f=c[3542228]|0;if((f|0)>15){return}do{if((f|0)<14){if((f|0)!=13){if((a[14168916+f|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(0,f,b);return}else if((e|0)==46336){c[3542228]=d&15;return}else{return}}function dw_(b){b=b|0;var c=0,d=0;c=b&65535;if((c|0)==45056){d=a[9635392]|0}else if((c|0)==45568){d=a[9550040]|0}else if((c|0)==46080){d=a[9549856]|0}else if((c|0)==46592){d=a[9635393]|0}else{d=0}return d|0}function dw$(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>5){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6456116+(b*112|0)>>2];c[a+104>>2]=c[6456120+(b*112|0)>>2];c[a+108>>2]=c[6456124+(b*112|0)>>2];d=0;return d|0}function dw0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<6&(d|0)==0)){e=1;return e|0}c[a>>2]=6456016+(b*112|0);e=0;return e|0}function dw1(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4890424+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dw2(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>37){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6640072+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dw3(){var b=0,e=0,f=0,g=0,h=0;b=dxb(0)|0;if((b|0)!=0){return b|0}e=c[2385956]|0;f=0;do{g=e+f|0;h=(d[g]|0)^170;a[g]=(h>>>7<<3|h<<4&16|h>>>5&1|h>>>2<<6&64|h>>>4<<7&128|h>>>6<<5&32|h>>>1<<2&4|h>>>3<<1&2)&255;f=f+1|0;}while((f|0)<16384);return b|0}function dw4(){var a=0,b=0,d=0,e=0;c[2113070]=0;c[2113068]=0;a=c[2112926]|0;if((a|0)!=0){gGr(a);c[2112926]=0}fwZ();c[2113008]=0;c[2076598]=0;c[2383582]=0;a=c[2415020]|0;b=0;while(1){if((b|0)>=1024){d=83161;break}e=9638528+(b<<2)|0;if((c[e>>2]|0)==(a|0)){break}else{b=b+1|0}}if((d|0)==83161){c[2415020]=0;return 0}gGr(a);c[e>>2]=0;c[2415020]=0;return 0}function dw5(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((a[9624600]|0)!=0){a[9624600]=0;c[2444138]=0;d=c[2414726]|0;gGz(d|0,0,(c[2411758]|0)-d|0);d=c[2439330]|0;f=(d|0)==0;if(!f){g=d;gGC(9706056,g|0,76)|0}g=c[2438118]|0;c[2433530]=g;h=c[3528484]|0;c[2076596]=h;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);if(!f){f=d;gGC(f|0,9706056,76)|0}c[2438118]=g;c[3528484]=h;c[2417276]=i;c[1836236]=-1;mB(0)}a[9550040]=(a[9634e3]|-2)^1^a[9634001]<<1&2^a[9634002]<<2&4^a[9634003]<<3&8^a[9634004]<<4&16^a[9634005]<<5&32^a[9634006]<<6&64^a[9634007]<<7;i=(c[2444138]|0)-(e[4817932]|0)|0;c[2444138]=i;a[9549856]=i>>>8&255;i=c[2439330]|0;if((i|0)!=0){h=i;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;h=c[2438118]|0;c[2433530]=h;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;if((a[i+4188|0]|0)==0){g=gfc(5e4)|0;f=c[1836236]|0;j=(c[2433530]|0)+g|0;k=f;l=c[9757320+(f<<2)>>2]|0}else{j=h+5e4|0;k=0;l=i}c[2433530]=j;a[9706117]=1;if((a[l+4188|0]|0)==0){i=gfc(1200)|0;h=c[1836236]|0;m=(c[2433530]|0)+i|0;n=h;o=c[9757320+(h<<2)>>2]|0}else{m=j+1200|0;n=k;o=l}c[2433530]=m;a[9706117]=0;if((o|0)!=0){l=o;gGC(l|0,9706056,76)|0}c[9752472+(n<<2)>>2]=m;c[14113936+(n<<2)>>2]=c[2076596];c[9669104+(n<<2)>>2]=c[3541536];c[1836236]=-1;n=c[2112964]|0;if((n|0)!=0){mF(9756376,n,a[9688]|0?534:0,0)}if((c[2112968]|0)==0){return 0}dw6()|0;return 0}function dw6(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((a[9547688]|0)!=0){e=c[2406966]|0;f=c[e>>2]|0;g=c[3530084]|0;c[g>>2]=f>>>8&2016|f&31|f>>16<<8&63488;f=c[e+4>>2]|0;c[g+4>>2]=f>>>8&2016|f&31|f>>16<<8&63488;f=c[e+8>>2]|0;c[g+8>>2]=f>>>8&2016|f&31|f>>16<<8&63488;f=c[e+12>>2]|0;c[g+12>>2]=f>>>8&2016|f&31|f>>16<<8&63488;f=c[e+16>>2]|0;c[g+16>>2]=f>>>8&2016|f&31|f>>16<<8&63488;f=c[e+20>>2]|0;c[g+20>>2]=f>>>8&2016|f&31|f>>16<<8&63488;f=c[e+24>>2]|0;c[g+24>>2]=f>>>8&2016|f&31|f>>16<<8&63488;f=c[e+28>>2]|0;c[g+28>>2]=f>>>8&2016|f&31|f>>16<<8&63488}f=c[2113068]|0;g=c[2386240]|0;e=c[2112926]|0;h=c[2387828]|0;i=0;do{j=h+(d[g+i|0]<<6)|0;k=e+((ag(f,i<<3&248^248)|0)+(i>>5<<3)<<1)|0;l=0;m=j;while(1){b[k>>1]=d[m]|0;b[k+2>>1]=d[m+1|0]|0;b[k+4>>1]=d[m+2|0]|0;b[k+6>>1]=d[m+3|0]|0;b[k+8>>1]=d[m+4|0]|0;b[k+10>>1]=d[m+5|0]|0;b[k+12>>1]=d[m+6|0]|0;b[k+14>>1]=d[m+7|0]|0;j=l+1|0;n=m+8|0;if((j|0)<8){k=k+(f<<1)|0;l=j;m=n}else{break}}i=i+1|0;}while((i|0)<1024);c[2112928]=n;R8(c[3530084]|0);return 0}function dw7(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;d=i;i=i+64|0;e=d|0;f=d+32|0;g=d+48|0;h=(b|0)==0;if(!h){c[b>>2]=169730}if((a&96|0)==0){i=d;return 0}gGz(g|0,0,12);j=c[2414726]|0;c[g>>2]=j;c[g+4>>2]=(c[2411758]|0)-j;c[g+12>>2]=162152;gj[c[2076592]&4095](g)|0;fw$(a);g=d+16|0;do{if((a&64|0)!=0){do{if(!h){if((c[b>>2]|0)>=169110){break}c[b>>2]=169110}}while(0);if((c[2113008]|0)<=0){break}j=e|0;k=e+4|0;l=e+8|0;m=e+12|0;n=0;do{cC(g|0,531144,(o=i,i=i+8|0,c[o>>2]=n,o)|0)|0;i=o;c[j>>2]=14168888+(n*252|0);c[k>>2]=252;c[l>>2]=0;c[m>>2]=g;gj[c[2076592]&4095](e)|0;n=n+1|0;}while((n|0)<(c[2113008]|0))}}while(0);gGz(f|0,0,12);c[f>>2]=9776552;c[f+4>>2]=4;c[f+12>>2]=99736;gj[c[2076592]&4095](f)|0;i=d;return 0}function dw8(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>5){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5626276+(b*112|0)>>2];c[a+104>>2]=c[5626280+(b*112|0)>>2];c[a+108>>2]=c[5626284+(b*112|0)>>2];d=0;return d|0}function dw9(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<6&(d|0)==0)){e=1;return e|0}c[a>>2]=5626176+(b*112|0);e=0;return e|0}function dxa(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0;b=dxb(2048)|0;if((b|0)!=0){return b|0}e=c[2385956]|0;f=0;do{g=e+f|0;h=d[g]|0;if((f&256|0)==0){i=h^165;j=i>>>7<<1|i<<7&128|i>>>4&1|i>>>2<<6&64|i>>>3<<5&32|i>>>6<<4&16|i>>>1<<3&8|i>>>5<<2&4}else{i=h^74;j=i<<2&4|i>>>7<<6|i>>>6&1|i>>>4<<7&128|i>>>1<<5&32|i>>>3<<4&16|i>>>2<<3&8|i>>>5<<1&2}a[g]=j&255;f=f+1|0;}while((f|0)<16384);return b|0}function dxb(e){e=e|0;var f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0.0,P=0,Q=0;f=i;i=i+720|0;g=f|0;j=f+112|0;k=f+120|0;l=f+232|0;m=f+240|0;n=f+352|0;o=f+360|0;p=f+472|0;q=f+480|0;r=f+592|0;s=f+600|0;t=f+712|0;c[2415020]=0;c[2385956]=0;c[2387828]=32768;c[3531024]=49152;c[2406966]=49184;c[3530084]=49216;c[2414726]=49248;c[2386110]=49248;c[2386240]=50272;c[2411758]=51296;c[2439094]=51296;u=a[9688]|0?1068:0;v=u+51296|0;c[2439095]=v;w=v+u|0;c[2439096]=w;v=w+u|0;c[2414306]=v;u=v;v=0;while(1){if((v|0)>=1024){break}x=9638528+(v<<2)|0;if((c[x>>2]|0)==0){y=83231;break}else{v=v+1|0}}do{if((y|0)==83231){v=gGq(u)|0;c[x>>2]=v;if((v|0)==0){break}gGz(v|0,0,u|0);c[2415020]=v;gGz(v|0,0,u|0);c[2385956]=v;c[2387828]=v+32768;c[3531024]=v+49152;c[2406966]=v+49184;c[3530084]=v+49216;w=v+49248|0;c[2414726]=w;c[2386110]=w;c[2386240]=v+50272;w=v+51296|0;c[2411758]=w;c[2439094]=w;w=a[9688]|0?1068:0;z=w+51296|0;c[2439095]=v+z;A=z+w|0;c[2439096]=v+A;c[2414306]=v+(A+w);if((c[3542200]|0)==0){B=1;i=f;return B|0}w=s+108|0;c[w>>2]=0;A=s+100|0;c[A>>2]=0;z=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[z&16383](s,0)|0;do{if((c[w>>2]|0)!=0){z=c[A>>2]|0;c[t>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](t,0,0)|0;if((z|0)<1){B=1;i=f;return B|0}if((gzL(v,0,0)|0)==0){break}else{B=1}i=f;return B|0}}while(0);v=(c[2385956]|0)+8192|0;if((c[3542200]|0)==0){B=1;i=f;return B|0}A=q+108|0;c[A>>2]=0;w=q+100|0;c[w>>2]=0;z=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[z&16383](q,1)|0;do{if((c[A>>2]|0)!=0){z=c[w>>2]|0;c[r>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](r,1,0)|0;if((z|0)<1){B=1;i=f;return B|0}if((gzL(v,0,1)|0)==0){break}else{B=1}i=f;return B|0}}while(0);v=(c[2387828]|0)+e|0;if((c[3542200]|0)==0){B=1;i=f;return B|0}w=o+108|0;c[w>>2]=0;A=o+100|0;c[A>>2]=0;z=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[z&16383](o,2)|0;do{if((c[w>>2]|0)!=0){z=c[A>>2]|0;c[p>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](p,2,0)|0;if((z|0)<1){B=1;i=f;return B|0}if((gzL(v,0,2)|0)==0){break}else{B=1}i=f;return B|0}}while(0);v=(c[2387828]|0)+(e+4096)|0;if((c[3542200]|0)==0){B=1;i=f;return B|0}A=m+108|0;c[A>>2]=0;w=m+100|0;c[w>>2]=0;z=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[z&16383](m,3)|0;do{if((c[A>>2]|0)!=0){z=c[w>>2]|0;c[n>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](n,3,0)|0;if((z|0)<1){B=1;i=f;return B|0}if((gzL(v,0,3)|0)==0){break}else{B=1}i=f;return B|0}}while(0);v=(c[2387828]|0)+(e+8192)|0;if((c[3542200]|0)==0){B=1;i=f;return B|0}w=k+108|0;c[w>>2]=0;A=k+100|0;c[A>>2]=0;z=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[z&16383](k,4)|0;do{if((c[w>>2]|0)!=0){z=c[A>>2]|0;c[l>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](l,4,0)|0;if((z|0)<1){B=1;i=f;return B|0}if((gzL(v,0,4)|0)==0){break}else{B=1}i=f;return B|0}}while(0);v=c[3531024]|0;if((c[3542200]|0)==0){B=1;i=f;return B|0}A=g+108|0;c[A>>2]=0;w=g+100|0;c[w>>2]=0;z=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[z&16383](g,5)|0;do{if((c[A>>2]|0)!=0){z=c[w>>2]|0;c[j>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](j,5,0)|0;if((z|0)<1){B=1;i=f;return B|0}if((gzL(v,0,5)|0)==0){break}else{B=1}i=f;return B|0}}while(0);v=c[3531024]|0;w=c[2406966]|0;A=8;while(1){z=d[v+A|0]|0;c[w+(A-8<<2)>>2]=((-(z>>>3&1)&77)+(-(z>>>2&1)&115)<<8)+256|(-(z&1)&115)+(-(z>>>7)&54)+(-(z>>>1&1)&84)|((-(z>>>6&1)&77)+(-(z>>>5&1)&115)<<16)+65536;z=A+1|0;if((z|0)<16){A=z}else{D=0;break}}while(1){if((D|0)>=1024){break}E=9638528+(D<<2)|0;if((c[E>>2]|0)==0){y=83261;break}else{D=D+1|0}}L102070:do{if((y|0)==83261){A=gGq(12288)|0;c[E>>2]=A;if((A|0)==0){break}gGz(A|0,0,12288);w=c[2387828]|0;gGC(A|0,w|0,12288)|0;v=0;while(1){z=v<<6;gGz(w+z|0,0,64);C=z+16384|0;F=0;do{G=C+(c[1238464+(F<<2)>>2]|0)|0;H=(F<<3)+z|0;I=0;do{J=G+(c[610352+(I<<2)>>2]|0)|0;if(((d[A+((J|0)/8|0)|0]|0)&128>>>((J&7)>>>0)|0)!=0){J=w+(H+I)|0;a[J]=a[J]|4}I=I+1|0;}while((I|0)<8);F=F+1|0;}while((F|0)<8);F=z+49152|0;C=0;do{I=F+(c[1238464+(C<<2)>>2]|0)|0;H=(C<<3)+z|0;G=0;do{J=I+(c[610352+(G<<2)>>2]|0)|0;if(((d[A+((J|0)/8|0)|0]|0)&128>>>((J&7)>>>0)|0)!=0){J=w+(H+G)|0;a[J]=a[J]|2}G=G+1|0;}while((G|0)<8);C=C+1|0;}while((C|0)<8);C=z+81920|0;F=0;do{G=C+(c[1238464+(F<<2)>>2]|0)|0;H=(F<<3)+z|0;I=0;do{J=G+(c[610352+(I<<2)>>2]|0)|0;if(((d[A+((J|0)/8|0)|0]|0)&128>>>((J&7)>>>0)|0)!=0){J=w+(H+I)|0;a[J]=a[J]|1}I=I+1|0;}while((I|0)<8);F=F+1|0;}while((F|0)<8);F=v+1|0;if((F|0)<256){v=F}else{K=0;break}}while(1){if((K|0)>=1024){break L102070}L=9638528+(K<<2)|0;if((c[L>>2]|0)==(A|0)){break}else{K=K+1|0}}gGr(A);c[L>>2]=0}}while(0);fwR(0);v=c[2439330]|0;w=(v|0)==0;if(!w){F=v;gGC(9706056,F|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];F=c[3528484]|0;c[2076596]=F;z=c[2417276]|0;c[3541536]=z;c[1836236]=0;C=c[2385956]|0;I=0;H=0;while(1){c[v+76+(H<<2)>>2]=C+(H<<8);G=I+1&65535;if((G&65535)>127){M=0;N=0;break}else{I=G;H=G&65535}}while(1){H=C+(N<<8)|0;c[v+76+(N+512<<2)>>2]=H;c[v+76+(N+768<<2)>>2]=H;H=M+1&65535;if((H&65535)>127){break}else{M=H;N=H&65535}}C=c[2386240]|0;c[v+588>>2]=C;H=C+256|0;c[v+592>>2]=H;I=C+512|0;c[v+596>>2]=I;G=C+768|0;c[v+600>>2]=G;c[v+1612>>2]=C;c[v+1616>>2]=H;c[v+1620>>2]=I;c[v+1624>>2]=G;c[v+2636>>2]=C;c[v+3660>>2]=C;c[v+2640>>2]=H;c[v+3664>>2]=H;c[v+2644>>2]=I;c[v+3668>>2]=I;c[v+2648>>2]=G;c[v+3672>>2]=G;c[v+604>>2]=C;c[v+608>>2]=H;c[v+612>>2]=I;c[v+616>>2]=G;c[v+1628>>2]=C;c[v+1632>>2]=H;c[v+1636>>2]=I;c[v+1640>>2]=G;c[v+2652>>2]=C;c[v+3676>>2]=C;c[v+2656>>2]=H;c[v+3680>>2]=H;c[v+2660>>2]=I;c[v+3684>>2]=I;c[v+2664>>2]=G;c[v+3688>>2]=G;c[v+620>>2]=C;c[v+624>>2]=H;c[v+628>>2]=I;c[v+632>>2]=G;c[v+1644>>2]=C;c[v+1648>>2]=H;c[v+1652>>2]=I;c[v+1656>>2]=G;c[v+2668>>2]=C;c[v+3692>>2]=C;c[v+2672>>2]=H;c[v+3696>>2]=H;c[v+2676>>2]=I;c[v+3700>>2]=I;c[v+2680>>2]=G;c[v+3704>>2]=G;c[v+636>>2]=C;c[v+640>>2]=H;c[v+644>>2]=I;c[v+648>>2]=G;c[v+1660>>2]=C;c[v+1664>>2]=H;c[v+1668>>2]=I;c[v+1672>>2]=G;c[v+2684>>2]=C;c[v+3708>>2]=C;c[v+2688>>2]=H;c[v+3712>>2]=H;c[v+2692>>2]=I;c[v+3716>>2]=I;c[v+2696>>2]=G;c[v+3720>>2]=G;G=c[2386110]|0;c[v+716>>2]=G;I=G+256|0;c[v+720>>2]=I;H=G+512|0;c[v+724>>2]=H;C=G+768|0;c[v+728>>2]=C;c[v+1740>>2]=G;c[v+1744>>2]=I;c[v+1748>>2]=H;c[v+1752>>2]=C;c[v+2764>>2]=G;c[v+3788>>2]=G;c[v+2768>>2]=I;c[v+3792>>2]=I;c[v+2772>>2]=H;c[v+3796>>2]=H;c[v+2776>>2]=C;c[v+3800>>2]=C;c[v+4184>>2]=1440;c[v+4180>>2]=722;if(!w){C=v;gGC(C|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=F;c[2417276]=z;c[1836236]=-1;C=a[9680]|0?32e3:0;c[3542220]=11200;if((c[2113008]|0)==0){gGz(14168888,0,252);c[3542223]=C;gGz(14168896,0,16);c[3542234]=~~((+(C|0)*32768.0*8.0+768.0e3)/1536.0e3);C=31;O=32767.0;while(1){c[14169012+(C<<2)>>2]=~~(O+.5);H=C-1|0;if((H|0)>0){C=H;O=O/1.188502227}else{break}}c[3542253]=0;h[1771269]=1.0;h[1771270]=1.0;h[1771271]=1.0;c[3542574]=3;c[3542575]=3;c[3542576]=3;mB(0);c[2113008]=(c[2113008]|0)+1}h[1771269]=.3;c[3542574]=3;h[1771270]=.3;c[3542575]=3;h[1771271]=.3;c[3542576]=3;C=c[642608+(c[2436]<<2)>>2]|0;z=c[C+128>>2]|0;if((c[C+52>>2]&4|0)==0){c[2113068]=z;F=c[C+132>>2]|0;c[2113070]=F;c[2443814]=z;c[2440436]=F;P=z;Q=F}else{c[2113070]=z;F=c[C+132>>2]|0;c[2113068]=F;c[2440436]=z;c[2443814]=F;P=F;Q=z}z=ag(P<<1,Q)|0;F=gGq(z)|0;c[2112926]=F;if((F|0)!=0){gGz(F|0,0,z|0)}a[9624600]=0;c[2444138]=0;z=c[2414726]|0;gGz(z|0,0,(c[2411758]|0)-z|0);z=c[2439330]|0;F=(z|0)==0;if(!F){C=z;gGC(9706056,C|0,76)|0}C=c[2438118]|0;c[2433530]=C;v=c[3528484]|0;c[2076596]=v;w=c[2417276]|0;c[3541536]=w;c[1836236]=0;gGz(9706056,0,76);if(!F){F=z;gGC(F|0,9706056,76)|0}c[2438118]=C;c[3528484]=v;c[2417276]=w;c[1836236]=-1;mB(0);B=0;i=f;return B|0}}while(0);c[2415020]=0;B=1;i=f;return B|0}function dxc(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>50){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2974964+(b*112|0)>>2];c[a+104>>2]=c[2974968+(b*112|0)>>2];c[a+108>>2]=c[2974972+(b*112|0)>>2];d=0;return d|0}function dxd(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<51&(d|0)==0)){e=1;return e|0}c[a>>2]=2974864+(b*112|0);e=0;return e|0}function dxe(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1288088+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dxf(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>61){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4121816+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dxg(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0;e=i;i=i+2040|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;B=e+1200|0;C=e+1312|0;D=e+1320|0;E=e+1432|0;F=e+1440|0;G=e+1552|0;H=e+1560|0;I=e+1672|0;J=e+1680|0;K=e+1792|0;L=e+1800|0;M=e+1912|0;N=e+1920|0;O=e+2032|0;c[2415018]=0;c[3531124]=0;c[3531112]=262144;c[2385954]=393216;c[3530882]=425984;c[3530646]=950272;c[3530456]=1474560;c[3530348]=1998848;c[3530294]=2523136;c[2443388]=4620288;c[2443386]=4628480;c[2443382]=4636672;c[2443378]=4644864;c[3529766]=4645376;c[3529720]=4907520;c[3530082]=5431808;c[2414724]=5464584;c[3531176]=5464584;c[2386494]=5497352;c[3529478]=5501448;c[3529444]=5509640;c[3529410]=5517832;c[2387232]=5526024;c[3529818]=5558792;c[3529814]=5558800;c[3529810]=5558808;c[3531154]=5558816;c[3529844]=5575200;c[3527310]=5579296;c[2386108]=5583392;c[3528314]=5591584;c[2411756]=5591585;P=0;while(1){if((P|0)>=1024){break}Q=9638528+(P<<2)|0;if((c[Q>>2]|0)==0){R=83356;break}else{P=P+1|0}}do{if((R|0)==83356){P=gGq(5591585)|0;c[Q>>2]=P;if((P|0)==0){break}c[2415018]=P;gGz(P|0,0,5591585);c[3531124]=P;c[3531112]=P+262144;c[2385954]=P+393216;c[3530882]=P+425984;c[3530646]=P+950272;c[3530456]=P+1474560;c[3530348]=P+1998848;c[3530294]=P+2523136;c[2443388]=P+4620288;c[2443386]=P+4628480;c[2443382]=P+4636672;c[2443378]=P+4644864;c[3529766]=P+4645376;c[3529720]=P+4907520;c[3530082]=P+5431808;S=P+5464584|0;c[2414724]=S;c[3531176]=S;c[2386494]=P+5497352;c[3529478]=P+5501448;c[3529444]=P+5509640;c[3529410]=P+5517832;c[2387232]=P+5526024;c[3529818]=P+5558792;c[3529814]=P+5558800;c[3529810]=P+5558808;c[3531154]=P+5558816;c[3529844]=P+5575200;c[3527310]=P+5579296;c[2386108]=P+5583392;c[3528314]=P+5591584;S=P+5591585|0;c[2411756]=S;c[2414304]=S;if((R6(P+1|0,0,2)|0)!=0){T=1;i=e;return T|0}if((R6(c[3531124]|0,1,2)|0)!=0){T=1;i=e;return T|0}if((R6((c[3531112]|0)+1|0,2,2)|0)!=0){T=1;i=e;return T|0}if((R6(c[3531112]|0,3,2)|0)!=0){T=1;i=e;return T|0}P=c[2385954]|0;if((c[3542200]|0)==0){T=1;i=e;return T|0}S=N+108|0;c[S>>2]=0;U=N+100|0;c[U>>2]=0;V=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[V&16383](N,4)|0;do{if((c[S>>2]|0)!=0){V=c[U>>2]|0;c[O>>2]=9534384;W=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[W&16383](O,4,0)|0;if((V|0)<1){T=1;i=e;return T|0}if((gzL(P,0,4)|0)==0){break}else{T=1}i=e;return T|0}}while(0);P=c[3529766]|0;if((c[3542200]|0)==0){T=1;i=e;return T|0}U=L+108|0;c[U>>2]=0;S=L+100|0;c[S>>2]=0;V=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[V&16383](L,5)|0;do{if((c[U>>2]|0)!=0){V=c[S>>2]|0;c[M>>2]=9534384;W=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[W&16383](M,5,0)|0;if((V|0)<1){T=1;i=e;return T|0}if((gzL(P,0,5)|0)==0){break}else{T=1}i=e;return T|0}}while(0);P=(c[3529766]|0)+131072|0;if((c[3542200]|0)==0){T=1;i=e;return T|0}S=J+108|0;c[S>>2]=0;U=J+100|0;c[U>>2]=0;V=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[V&16383](J,6)|0;do{if((c[S>>2]|0)!=0){V=c[U>>2]|0;c[K>>2]=9534384;W=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[W&16383](K,6,0)|0;if((V|0)<1){T=1;i=e;return T|0}if((gzL(P,0,6)|0)==0){break}else{T=1}i=e;return T|0}}while(0);P=c[3529720]|0;if((c[3542200]|0)==0){T=1;i=e;return T|0}U=H+108|0;c[U>>2]=0;S=H+100|0;c[S>>2]=0;V=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[V&16383](H,7)|0;do{if((c[U>>2]|0)!=0){V=c[S>>2]|0;c[I>>2]=9534384;W=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[W&16383](I,7,0)|0;if((V|0)<1){T=1;i=e;return T|0}if((gzL(P,0,7)|0)==0){break}else{T=1}i=e;return T|0}}while(0);P=(c[3529720]|0)+131072|0;if((c[3542200]|0)==0){T=1;i=e;return T|0}S=F+108|0;c[S>>2]=0;U=F+100|0;c[U>>2]=0;V=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[V&16383](F,8)|0;do{if((c[S>>2]|0)!=0){V=c[U>>2]|0;c[G>>2]=9534384;W=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[W&16383](G,8,0)|0;if((V|0)<1){T=1;i=e;return T|0}if((gzL(P,0,8)|0)==0){break}else{T=1}i=e;return T|0}}while(0);gGz((c[3529720]|0)+262144|0,-1|0,262144);P=c[3530882]|0;if((c[3542200]|0)==0){T=1;i=e;return T|0}U=D+108|0;c[U>>2]=0;S=D+100|0;c[S>>2]=0;V=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[V&16383](D,9)|0;do{if((c[U>>2]|0)!=0){V=c[S>>2]|0;c[E>>2]=9534384;W=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[W&16383](E,9,0)|0;if((V|0)<1){T=1;i=e;return T|0}if((gzL(P,0,9)|0)==0){break}else{T=1}i=e;return T|0}}while(0);P=(c[3530882]|0)+65536|0;if((c[3542200]|0)==0){T=1;i=e;return T|0}S=B+108|0;c[S>>2]=0;U=B+100|0;c[U>>2]=0;V=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[V&16383](B,10)|0;do{if((c[S>>2]|0)!=0){V=c[U>>2]|0;c[C>>2]=9534384;W=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[W&16383](C,10,0)|0;if((V|0)<1){T=1;i=e;return T|0}if((gzL(P,0,10)|0)==0){break}else{T=1}i=e;return T|0}}while(0);P=(c[3530882]|0)+131072|0;if((c[3542200]|0)==0){T=1;i=e;return T|0}U=z+108|0;c[U>>2]=0;S=z+100|0;c[S>>2]=0;V=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[V&16383](z,11)|0;do{if((c[U>>2]|0)!=0){V=c[S>>2]|0;c[A>>2]=9534384;W=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[W&16383](A,11,0)|0;if((V|0)<1){T=1;i=e;return T|0}if((gzL(P,0,11)|0)==0){break}else{T=1}i=e;return T|0}}while(0);P=(c[3530882]|0)+196608|0;if((c[3542200]|0)==0){T=1;i=e;return T|0}S=x+108|0;c[S>>2]=0;U=x+100|0;c[U>>2]=0;V=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[V&16383](x,12)|0;do{if((c[S>>2]|0)!=0){V=c[U>>2]|0;c[y>>2]=9534384;W=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[W&16383](y,12,0)|0;if((V|0)<1){T=1;i=e;return T|0}if((gzL(P,0,12)|0)==0){break}else{T=1}i=e;return T|0}}while(0);P=c[3530646]|0;if((c[3542200]|0)==0){T=1;i=e;return T|0}U=v+108|0;c[U>>2]=0;S=v+100|0;c[S>>2]=0;V=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[V&16383](v,13)|0;do{if((c[U>>2]|0)!=0){V=c[S>>2]|0;c[w>>2]=9534384;W=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[W&16383](w,13,0)|0;if((V|0)<1){T=1;i=e;return T|0}if((gzL(P,0,13)|0)==0){break}else{T=1}i=e;return T|0}}while(0);P=(c[3530646]|0)+65536|0;if((c[3542200]|0)==0){T=1;i=e;return T|0}S=t+108|0;c[S>>2]=0;U=t+100|0;c[U>>2]=0;V=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[V&16383](t,14)|0;do{if((c[S>>2]|0)!=0){V=c[U>>2]|0;c[u>>2]=9534384;W=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[W&16383](u,14,0)|0;if((V|0)<1){T=1;i=e;return T|0}if((gzL(P,0,14)|0)==0){break}else{T=1}i=e;return T|0}}while(0);P=(c[3530646]|0)+131072|0;if((c[3542200]|0)==0){T=1;i=e;return T|0}U=r+108|0;c[U>>2]=0;S=r+100|0;c[S>>2]=0;V=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[V&16383](r,15)|0;do{if((c[U>>2]|0)!=0){V=c[S>>2]|0;c[s>>2]=9534384;W=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[W&16383](s,15,0)|0;if((V|0)<1){T=1;i=e;return T|0}if((gzL(P,0,15)|0)==0){break}else{T=1}i=e;return T|0}}while(0);P=(c[3530646]|0)+196608|0;if((c[3542200]|0)==0){T=1;i=e;return T|0}S=p+108|0;c[S>>2]=0;U=p+100|0;c[U>>2]=0;V=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[V&16383](p,16)|0;do{if((c[S>>2]|0)!=0){V=c[U>>2]|0;c[q>>2]=9534384;W=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[W&16383](q,16,0)|0;if((V|0)<1){T=1;i=e;return T|0}if((gzL(P,0,16)|0)==0){break}else{T=1}i=e;return T|0}}while(0);P=c[3530456]|0;if((c[3542200]|0)==0){T=1;i=e;return T|0}U=n+108|0;c[U>>2]=0;S=n+100|0;c[S>>2]=0;V=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[V&16383](n,17)|0;do{if((c[U>>2]|0)!=0){V=c[S>>2]|0;c[o>>2]=9534384;W=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[W&16383](o,17,0)|0;if((V|0)<1){T=1;i=e;return T|0}if((gzL(P,0,17)|0)==0){break}else{T=1}i=e;return T|0}}while(0);P=(c[3530456]|0)+65536|0;if((c[3542200]|0)==0){T=1;i=e;return T|0}S=l+108|0;c[S>>2]=0;U=l+100|0;c[U>>2]=0;V=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[V&16383](l,18)|0;do{if((c[S>>2]|0)!=0){V=c[U>>2]|0;c[m>>2]=9534384;W=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[W&16383](m,18,0)|0;if((V|0)<1){T=1;i=e;return T|0}if((gzL(P,0,18)|0)==0){break}else{T=1}i=e;return T|0}}while(0);P=(c[3530456]|0)+131072|0;if((c[3542200]|0)==0){T=1;i=e;return T|0}U=j+108|0;c[U>>2]=0;S=j+100|0;c[S>>2]=0;V=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[V&16383](j,19)|0;do{if((c[U>>2]|0)!=0){V=c[S>>2]|0;c[k>>2]=9534384;W=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[W&16383](k,19,0)|0;if((V|0)<1){T=1;i=e;return T|0}if((gzL(P,0,19)|0)==0){break}else{T=1}i=e;return T|0}}while(0);P=(c[3530456]|0)+196608|0;if((c[3542200]|0)==0){T=1;i=e;return T|0}S=f+108|0;c[S>>2]=0;U=f+100|0;c[U>>2]=0;V=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[V&16383](f,20)|0;do{if((c[S>>2]|0)!=0){V=c[U>>2]|0;c[g>>2]=9534384;W=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[W&16383](g,20,0)|0;if((V|0)<1){T=1;i=e;return T|0}if((gzL(P,0,20)|0)==0){break}else{T=1}i=e;return T|0}}while(0);if((R6((c[3530348]|0)+1|0,21,2)|0)!=0){T=1;i=e;return T|0}if((R6(c[3530348]|0,22,2)|0)!=0){T=1;i=e;return T|0}if((R6((c[3530294]|0)+1572865|0,23,4)|0)!=0){T=1;i=e;return T|0}if((R6((c[3530294]|0)+1572864|0,24,4)|0)!=0){T=1;i=e;return T|0}if((R6((c[3530294]|0)+1572867|0,25,4)|0)!=0){T=1;i=e;return T|0}if((R6((c[3530294]|0)+1572866|0,26,4)|0)!=0){T=1;i=e;return T|0}if((R6((c[3530294]|0)+1048577|0,27,4)|0)!=0){T=1;i=e;return T|0}if((R6((c[3530294]|0)+1048576|0,28,4)|0)!=0){T=1;i=e;return T|0}if((R6((c[3530294]|0)+1048579|0,29,4)|0)!=0){T=1;i=e;return T|0}if((R6((c[3530294]|0)+1048578|0,30,4)|0)!=0){T=1;i=e;return T|0}if((R6((c[3530294]|0)+524289|0,31,4)|0)!=0){T=1;i=e;return T|0}if((R6((c[3530294]|0)+524288|0,32,4)|0)!=0){T=1;i=e;return T|0}if((R6((c[3530294]|0)+524291|0,33,4)|0)!=0){T=1;i=e;return T|0}if((R6((c[3530294]|0)+524290|0,34,4)|0)!=0){T=1;i=e;return T|0}if((R6((c[3530294]|0)+1|0,35,4)|0)!=0){T=1;i=e;return T|0}if((R6(c[3530294]|0,36,4)|0)!=0){T=1;i=e;return T|0}if((R6((c[3530294]|0)+3|0,37,4)|0)!=0){T=1;i=e;return T|0}if((R6((c[3530294]|0)+2|0,38,4)|0)!=0){T=1;i=e;return T|0}P=c[3530882]|0;U=0;while(1){if((U|0)>=1024){X=0;break}Y=9638528+(U<<2)|0;if((c[Y>>2]|0)==0){R=83451;break}else{U=U+1|0}}do{if((R|0)==83451){U=gGq(262144)|0;c[Y>>2]=U;if((U|0)==0){X=0;break}gGz(U|0,0,262144);X=U}}while(0);gGC(X|0,P|0,262144)|0;U=0;while(1){S=U<<6;gGz(P+S|0,0,64);V=0;do{W=1<<3-V;Z=(c[597992+(V<<2)>>2]|0)+S|0;_=0;do{$=Z+(c[1238464+(_<<2)>>2]|0)|0;aa=(_<<3)+S|0;ab=0;do{ac=$+(c[614800+(ab<<2)>>2]|0)|0;if((d[X+((ac|0)/8|0)|0]&128>>>((ac&7)>>>0)|0)!=0){ac=P+(aa+ab)|0;a[ac]=(d[ac]|W)&255}ab=ab+1|0;}while((ab|0)<8);_=_+1|0;}while((_|0)<8);V=V+1|0;}while((V|0)<4);V=U+1|0;if((V|0)<8192){U=V}else{ad=0;break}}while(1){if((ad|0)>=1024){break}ae=9638528+(ad<<2)|0;if((c[ae>>2]|0)==(X|0)){R=83465;break}else{ad=ad+1|0}}if((R|0)==83465){gGr(X);c[ae>>2]=0}U=c[3530646]|0;P=0;while(1){if((P|0)>=1024){af=0;break}ah=9638528+(P<<2)|0;if((c[ah>>2]|0)==0){R=83469;break}else{P=P+1|0}}do{if((R|0)==83469){P=gGq(262144)|0;c[ah>>2]=P;if((P|0)==0){af=0;break}gGz(P|0,0,262144);af=P}}while(0);gGC(af|0,U|0,262144)|0;P=0;while(1){V=P<<6;gGz(U+V|0,0,64);S=0;do{_=1<<3-S;W=(c[597992+(S<<2)>>2]|0)+V|0;Z=0;do{ab=W+(c[1238464+(Z<<2)>>2]|0)|0;aa=(Z<<3)+V|0;$=0;do{ac=ab+(c[614800+($<<2)>>2]|0)|0;if((d[af+((ac|0)/8|0)|0]&128>>>((ac&7)>>>0)|0)!=0){ac=U+(aa+$)|0;a[ac]=(d[ac]|_)&255}$=$+1|0;}while(($|0)<8);Z=Z+1|0;}while((Z|0)<8);S=S+1|0;}while((S|0)<4);S=P+1|0;if((S|0)<8192){P=S}else{ai=0;break}}while(1){if((ai|0)>=1024){break}aj=9638528+(ai<<2)|0;if((c[aj>>2]|0)==(af|0)){R=83483;break}else{ai=ai+1|0}}if((R|0)==83483){gGr(af);c[aj>>2]=0}P=c[3530456]|0;U=0;while(1){if((U|0)>=1024){ak=0;break}al=9638528+(U<<2)|0;if((c[al>>2]|0)==0){R=83487;break}else{U=U+1|0}}do{if((R|0)==83487){U=gGq(262144)|0;c[al>>2]=U;if((U|0)==0){ak=0;break}gGz(U|0,0,262144);ak=U}}while(0);gGC(ak|0,P|0,262144)|0;U=0;while(1){S=U<<6;gGz(P+S|0,0,64);V=0;do{Z=1<<3-V;_=(c[597992+(V<<2)>>2]|0)+S|0;W=0;do{$=_+(c[1238464+(W<<2)>>2]|0)|0;aa=(W<<3)+S|0;ab=0;do{ac=$+(c[614800+(ab<<2)>>2]|0)|0;if((d[ak+((ac|0)/8|0)|0]&128>>>((ac&7)>>>0)|0)!=0){ac=P+(aa+ab)|0;a[ac]=(d[ac]|Z)&255}ab=ab+1|0;}while((ab|0)<8);W=W+1|0;}while((W|0)<8);V=V+1|0;}while((V|0)<4);V=U+1|0;if((V|0)<8192){U=V}else{am=0;break}}while(1){if((am|0)>=1024){break}an=9638528+(am<<2)|0;if((c[an>>2]|0)==(ak|0)){R=83501;break}else{am=am+1|0}}if((R|0)==83501){gGr(ak);c[an>>2]=0}U=c[3530348]|0;P=524286;do{V=U+((P|0)/2|0)|0;a[U+P|0]=(d[V]|0)>>>4;a[U+(P|1)|0]=a[V]&15;P=P-2|0;}while((P|0)>-1);P=c[3530294]|0;V=0;do{S=P+(V<<2)|0;W=c[S>>2]|0;c[S>>2]=W<<16&65536|W>>>27<<31|W>>>31<<15|W>>>4&1|W>>>26<<30&1073741824|W>>>25<<29&536870912|W>>>24<<28&268435456|W>>>19<<27&134217728|W>>>18<<26&67108864|W>>>17<<25&33554432|W>>>16<<24&16777216|W>>>11<<23&8388608|W>>>10<<22&4194304|W>>>9<<21&2097152|W>>>8<<20&1048576|W>>>3<<19&524288|W>>>2<<18&262144|W>>>1<<17&131072|W>>>30<<14&16384|W>>>29<<13&8192|W>>>28<<12&4096|W>>>23<<11&2048|W>>>22<<10&1024|W>>>21<<9&512|W>>>20<<8&256|W>>>15<<7&128|W>>>14<<6&64|W>>>13<<5&32|W>>>12<<4&16|W>>>7<<3&8|W>>>6<<2&4|W>>>5<<1&2;V=V+1|0;}while((V|0)<524288);V=c[3530882]|0;P=c[2443388]|0;gGz(P|0,0,8192);W=0;do{S=P+((W|0)/64|0)|0;a[S]=0;Z=0;_=0;ab=0;while(1){if((a[V+(_+W)|0]|0)==0){ao=Z;ap=ab}else{aa=ab|1;a[S]=aa;ao=Z+1|0;ap=aa}aa=_+1|0;if((aa|0)<64){Z=ao;_=aa;ab=ap}else{break}}if((ao|0)==64){a[S]=ap|2}W=W+64|0;}while((W|0)<524288);W=c[3530646]|0;V=c[2443386]|0;gGz(V|0,0,8192);P=0;do{ab=V+((P|0)/64|0)|0;a[ab]=0;_=0;Z=0;aa=0;while(1){if((a[W+(Z+P)|0]|0)==0){aq=_;ar=aa}else{$=aa|1;a[ab]=$;aq=_+1|0;ar=$}$=Z+1|0;if(($|0)<64){_=aq;Z=$;aa=ar}else{break}}if((aq|0)==64){a[ab]=ar|2}P=P+64|0;}while((P|0)<524288);P=c[3530456]|0;W=c[2443382]|0;gGz(W|0,0,8192);V=0;do{aa=W+((V|0)/64|0)|0;a[aa]=0;Z=0;_=0;S=0;while(1){if((a[P+(_+V)|0]|0)==0){as=Z;at=S}else{$=S|1;a[aa]=$;as=Z+1|0;at=$}$=_+1|0;if(($|0)<64){Z=as;_=$;S=at}else{break}}if((as|0)==64){a[aa]=at|2}V=V+64|0;}while((V|0)<524288);V=c[2443378]|0;gGz(V|0,0,512);P=0;do{W=V+((P|0)/1024|0)|0;a[W]=0;S=0;_=0;Z=0;while(1){if((a[U+(_+P)|0]|0)==0){au=S;av=Z}else{ab=Z|1;a[W]=ab;au=S+1|0;av=ab}ab=_+1|0;if((ab|0)<1024){S=au;_=ab;Z=av}else{break}}if((au|0)==1024){a[W]=av|2}P=P+1024|0;}while((P|0)<524288);fxU(0,425984);if((c[2394]|0)==0){aw=c[2112932]|0}else{c[2394]=0;P=c[3532596]|0;c[2112932]=P;U=c[3532592]|0;if((U|0)!=0){gGC(9104152,U|0,280)|0}c[2113054]=c[2113060];aw=P}P=c[3531124]|0;U=aw|0;V=0;while(1){Z=P+V|0;c[U>>2]=Z;c[U+131072>>2]=Z;Z=V+1024|0;if(Z>>>0>262143){break}else{U=U+4|0;V=Z}}V=c[3531176]|0;U=aw+2048|0;P=524288;while(1){Z=V+(P-524288)|0;c[U>>2]=Z;c[U+65536>>2]=Z;c[U+131072>>2]=Z;Z=P+1024|0;if(Z>>>0>557055){break}else{U=U+4|0;P=Z}}P=c[2386494]|0;c[aw+2560>>2]=P;c[aw+68096>>2]=P;c[aw+133632>>2]=P;U=P+1024|0;c[aw+2564>>2]=U;c[aw+68100>>2]=U;c[aw+133636>>2]=U;U=P+2048|0;c[aw+2568>>2]=U;c[aw+68104>>2]=U;c[aw+133640>>2]=U;U=P+3072|0;c[aw+2572>>2]=U;c[aw+68108>>2]=U;c[aw+133644>>2]=U;U=c[3529478]|0;c[aw+3072>>2]=U;c[aw+68608>>2]=U;c[aw+134144>>2]=U;P=U+1024|0;c[aw+3076>>2]=P;c[aw+68612>>2]=P;c[aw+134148>>2]=P;P=U+2048|0;c[aw+3080>>2]=P;c[aw+68616>>2]=P;c[aw+134152>>2]=P;P=U+3072|0;c[aw+3084>>2]=P;c[aw+68620>>2]=P;c[aw+134156>>2]=P;P=U+4096|0;c[aw+3088>>2]=P;c[aw+68624>>2]=P;c[aw+134160>>2]=P;P=U+5120|0;c[aw+3092>>2]=P;c[aw+68628>>2]=P;c[aw+134164>>2]=P;P=U+6144|0;c[aw+3096>>2]=P;c[aw+68632>>2]=P;c[aw+134168>>2]=P;P=U+7168|0;c[aw+3100>>2]=P;c[aw+68636>>2]=P;c[aw+134172>>2]=P;P=c[3529444]|0;c[aw+3136>>2]=P;c[aw+68672>>2]=P;c[aw+134208>>2]=P;U=P+1024|0;c[aw+3140>>2]=U;c[aw+68676>>2]=U;c[aw+134212>>2]=U;U=P+2048|0;c[aw+3144>>2]=U;c[aw+68680>>2]=U;c[aw+134216>>2]=U;U=P+3072|0;c[aw+3148>>2]=U;c[aw+68684>>2]=U;c[aw+134220>>2]=U;U=P+4096|0;c[aw+3152>>2]=U;c[aw+68688>>2]=U;c[aw+134224>>2]=U;U=P+5120|0;c[aw+3156>>2]=U;c[aw+68692>>2]=U;c[aw+134228>>2]=U;U=P+6144|0;c[aw+3160>>2]=U;c[aw+68696>>2]=U;c[aw+134232>>2]=U;U=P+7168|0;c[aw+3164>>2]=U;c[aw+68700>>2]=U;c[aw+134236>>2]=U;U=c[3529410]|0;c[aw+3200>>2]=U;c[aw+68736>>2]=U;c[aw+134272>>2]=U;P=U+1024|0;c[aw+3204>>2]=P;c[aw+68740>>2]=P;c[aw+134276>>2]=P;P=U+2048|0;c[aw+3208>>2]=P;c[aw+68744>>2]=P;c[aw+134280>>2]=P;P=U+3072|0;c[aw+3212>>2]=P;c[aw+68748>>2]=P;c[aw+134284>>2]=P;P=U+4096|0;c[aw+3216>>2]=P;c[aw+68752>>2]=P;c[aw+134288>>2]=P;P=U+5120|0;c[aw+3220>>2]=P;c[aw+68756>>2]=P;c[aw+134292>>2]=P;P=U+6144|0;c[aw+3224>>2]=P;c[aw+68760>>2]=P;c[aw+134296>>2]=P;P=U+7168|0;c[aw+3228>>2]=P;c[aw+68764>>2]=P;c[aw+134300>>2]=P;P=c[3527310]|0;c[aw+3584>>2]=P;c[aw+69120>>2]=P;c[aw+134656>>2]=P;U=P+1024|0;c[aw+3588>>2]=U;c[aw+69124>>2]=U;c[aw+134660>>2]=U;U=P+2048|0;c[aw+3592>>2]=U;c[aw+69128>>2]=U;c[aw+134664>>2]=U;U=P+3072|0;c[aw+3596>>2]=U;c[aw+69132>>2]=U;c[aw+134668>>2]=U;U=c[2387232]|0;c[aw+4096>>2]=U;c[aw+135168>>2]=U;P=U+1024|0;c[aw+4100>>2]=P;c[aw+135172>>2]=P;P=U+2048|0;c[aw+4104>>2]=P;c[aw+135176>>2]=P;P=U+3072|0;c[aw+4108>>2]=P;c[aw+135180>>2]=P;P=U+4096|0;c[aw+4112>>2]=P;c[aw+135184>>2]=P;P=U+5120|0;c[aw+4116>>2]=P;c[aw+135188>>2]=P;P=U+6144|0;c[aw+4120>>2]=P;c[aw+135192>>2]=P;P=U+7168|0;c[aw+4124>>2]=P;c[aw+135196>>2]=P;P=U+8192|0;c[aw+4128>>2]=P;c[aw+135200>>2]=P;P=U+9216|0;c[aw+4132>>2]=P;c[aw+135204>>2]=P;P=U+10240|0;c[aw+4136>>2]=P;c[aw+135208>>2]=P;P=U+11264|0;c[aw+4140>>2]=P;c[aw+135212>>2]=P;P=U+12288|0;c[aw+4144>>2]=P;c[aw+135216>>2]=P;P=U+13312|0;c[aw+4148>>2]=P;c[aw+135220>>2]=P;P=U+14336|0;c[aw+4152>>2]=P;c[aw+135224>>2]=P;P=U+15360|0;c[aw+4156>>2]=P;c[aw+135228>>2]=P;P=U+16384|0;c[aw+4160>>2]=P;c[aw+69696>>2]=P;c[aw+135232>>2]=P;P=U+17408|0;c[aw+4164>>2]=P;c[aw+69700>>2]=P;c[aw+135236>>2]=P;P=U+18432|0;c[aw+4168>>2]=P;c[aw+69704>>2]=P;c[aw+135240>>2]=P;P=U+19456|0;c[aw+4172>>2]=P;c[aw+69708>>2]=P;c[aw+135244>>2]=P;P=U+20480|0;c[aw+4176>>2]=P;c[aw+69712>>2]=P;c[aw+135248>>2]=P;P=U+21504|0;c[aw+4180>>2]=P;c[aw+69716>>2]=P;c[aw+135252>>2]=P;P=U+22528|0;c[aw+4184>>2]=P;c[aw+69720>>2]=P;c[aw+135256>>2]=P;P=U+23552|0;c[aw+4188>>2]=P;c[aw+69724>>2]=P;c[aw+135260>>2]=P;P=U+24576|0;c[aw+4192>>2]=P;c[aw+69728>>2]=P;c[aw+135264>>2]=P;P=U+25600|0;c[aw+4196>>2]=P;c[aw+69732>>2]=P;c[aw+135268>>2]=P;P=U+26624|0;c[aw+4200>>2]=P;c[aw+69736>>2]=P;c[aw+135272>>2]=P;P=U+27648|0;c[aw+4204>>2]=P;c[aw+69740>>2]=P;c[aw+135276>>2]=P;P=U+28672|0;c[aw+4208>>2]=P;c[aw+69744>>2]=P;c[aw+135280>>2]=P;P=U+29696|0;c[aw+4212>>2]=P;c[aw+69748>>2]=P;c[aw+135284>>2]=P;P=U+30720|0;c[aw+4216>>2]=P;c[aw+69752>>2]=P;c[aw+135288>>2]=P;P=U+31744|0;c[aw+4220>>2]=P;c[aw+69756>>2]=P;c[aw+135292>>2]=P;c[aw+196648>>2]=536;c[aw+196728>>2]=1268;c[aw+196608>>2]=2852;c[aw+196688>>2]=3446;P=c[3532592]|0;if((P|0)!=0){gGC(P|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fxU(1,425984);if((c[2394]|0)==1){ax=c[2112932]|0}else{c[2394]=1;P=c[3532597]|0;c[2112932]=P;U=c[3532593]|0;if((U|0)!=0){gGC(9104152,U|0,280)|0}c[2113054]=c[2113061];ax=P}P=c[3531112]|0;U=ax|0;V=0;while(1){Z=P+V|0;c[U>>2]=Z;c[U+131072>>2]=Z;Z=V+1024|0;if(Z>>>0>131071){break}else{U=U+4|0;V=Z}}V=c[3531154]|0;c[ax+2048>>2]=V;c[ax+67584>>2]=V;c[ax+133120>>2]=V;U=V+1024|0;c[ax+2052>>2]=U;c[ax+67588>>2]=U;c[ax+133124>>2]=U;U=V+2048|0;c[ax+2056>>2]=U;c[ax+67592>>2]=U;c[ax+133128>>2]=U;U=V+3072|0;c[ax+2060>>2]=U;c[ax+67596>>2]=U;c[ax+133132>>2]=U;U=V+4096|0;c[ax+2064>>2]=U;c[ax+67600>>2]=U;c[ax+133136>>2]=U;U=V+5120|0;c[ax+2068>>2]=U;c[ax+67604>>2]=U;c[ax+133140>>2]=U;U=V+6144|0;c[ax+2072>>2]=U;c[ax+67608>>2]=U;c[ax+133144>>2]=U;U=V+7168|0;c[ax+2076>>2]=U;c[ax+67612>>2]=U;c[ax+133148>>2]=U;U=V+8192|0;c[ax+2080>>2]=U;c[ax+67616>>2]=U;c[ax+133152>>2]=U;U=V+9216|0;c[ax+2084>>2]=U;c[ax+67620>>2]=U;c[ax+133156>>2]=U;U=V+10240|0;c[ax+2088>>2]=U;c[ax+67624>>2]=U;c[ax+133160>>2]=U;U=V+11264|0;c[ax+2092>>2]=U;c[ax+67628>>2]=U;c[ax+133164>>2]=U;U=V+12288|0;c[ax+2096>>2]=U;c[ax+67632>>2]=U;c[ax+133168>>2]=U;U=V+13312|0;c[ax+2100>>2]=U;c[ax+67636>>2]=U;c[ax+133172>>2]=U;U=V+14336|0;c[ax+2104>>2]=U;c[ax+67640>>2]=U;c[ax+133176>>2]=U;U=V+15360|0;c[ax+2108>>2]=U;c[ax+67644>>2]=U;c[ax+133180>>2]=U;U=c[3529844]|0;c[ax+3072>>2]=U;c[ax+68608>>2]=U;c[ax+134144>>2]=U;V=U+1024|0;c[ax+3076>>2]=V;c[ax+68612>>2]=V;c[ax+134148>>2]=V;V=U+2048|0;c[ax+3080>>2]=V;c[ax+68616>>2]=V;c[ax+134152>>2]=V;V=U+3072|0;c[ax+3084>>2]=V;c[ax+68620>>2]=V;c[ax+134156>>2]=V;V=c[3527310]|0;c[ax+4096>>2]=V;c[ax+69632>>2]=V;c[ax+135168>>2]=V;U=V+1024|0;c[ax+4100>>2]=U;c[ax+69636>>2]=U;c[ax+135172>>2]=U;U=V+2048|0;c[ax+4104>>2]=U;c[ax+69640>>2]=U;c[ax+135176>>2]=U;U=V+3072|0;c[ax+4108>>2]=U;c[ax+69644>>2]=U;c[ax+135180>>2]=U;U=c[3532593]|0;if((U|0)!=0){gGC(U|0,9104152,280)|0}c[2113061]=c[2113054];c[2394]=-1;fwR(0);U=c[2439330]|0;V=(U|0)==0;if(!V){P=U;gGC(9706056,P|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];P=c[3528484]|0;c[2076596]=P;Z=c[2417276]|0;c[3541536]=Z;c[1836236]=0;_=c[2385954]|0;S=0;aa=0;while(1){c[U+76+(aa<<2)>>2]=_+(aa<<8);ab=S+1&65535;if((ab&65535)>127){ay=0;az=0;break}else{S=ab;aa=ab&65535}}while(1){aa=_+(az<<8)|0;c[U+76+(az+512<<2)>>2]=aa;c[U+76+(az+768<<2)>>2]=aa;aa=ay+1&65535;if((aa&65535)>127){break}else{ay=aa;az=aa&65535}}_=c[2386108]|0;aa=128;S=128;while(1){c[U+76+(S<<2)>>2]=_+((S<<8)-32768);ab=aa+1&65535;if((ab&65535)>159){aA=128;aB=128;break}else{aa=ab;S=ab&65535}}while(1){c[U+76+(aB+256<<2)>>2]=_+((aB<<8)-32768);S=aA+1&65535;if((S&65535)>159){aC=128;aD=128;break}else{aA=S;aB=S&65535}}while(1){S=_+((aD<<8)-32768)|0;c[U+76+(aD+512<<2)>>2]=S;c[U+76+(aD+768<<2)>>2]=S;S=aC+1&65535;if((S&65535)>159){break}else{aC=S;aD=S&65535}}c[U+4184>>2]=3156;c[U+4180>>2]=162;if(!V){_=U;gGC(_|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=P;c[2417276]=Z;c[1836236]=-1;T7(2,c[3529766]|0,262144,c[3529720]|0,524288,182,0);c[2438226]=3579545;c[2433524]=3416;c[2406674]=1752;c[3528470]=9362;c[2443844]=571;h[826309]=1.0;c[2438350]=2;h[826308]=1.0;c[2438348]=2;_=c[642608+(c[2436]<<2)>>2]|0;S=c[_+128>>2]|0;if((c[_+52>>2]&4|0)==0){c[2113068]=S;aa=c[_+132>>2]|0;c[2113070]=aa;c[2443814]=S;c[2440436]=aa;aE=S;aF=aa}else{c[2113070]=S;aa=c[_+132>>2]|0;c[2113068]=aa;c[2440436]=S;c[2443814]=aa;aE=aa;aF=S}S=ag(aE<<1,aF)|0;aa=gGq(S)|0;c[2112926]=aa;if((aa|0)!=0){gGz(aa|0,0,S|0)}S=c[2414724]|0;gGz(S|0,0,(c[2411756]|0)-S|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];S=c[3532592]|0;if((S|0)!=0){gGC(9104152,S|0,280)|0}c[2113054]=c[2113060]}RI();S=c[2394]|0;aa=c[14130368+(S<<2)>>2]|0;if((aa|0)!=0){gGC(aa|0,9104152,280)|0}c[8452240+(S<<2)>>2]=c[2113054];c[2394]=1;c[2112932]=c[3532597];S=c[3532593]|0;if((S|0)!=0){gGC(9104152,S|0,280)|0}c[2113054]=c[2113061];RI();S=c[2394]|0;aa=c[14130368+(S<<2)>>2]|0;if((aa|0)!=0){gGC(aa|0,9104152,280)|0}c[8452240+(S<<2)>>2]=c[2113054];c[2394]=-1;S=c[2439330]|0;aa=(S|0)==0;if(!aa){_=S;gGC(9706056,_|0,76)|0}_=c[2438118]|0;c[2433530]=_;ab=c[3528484]|0;c[2076596]=ab;$=c[2417276]|0;c[3541536]=$;c[1836236]=0;gGz(9706056,0,76);if(!aa){aa=S;gGC(aa|0,9706056,76)|0}c[2438118]=_;c[3528484]=ab;c[2417276]=$;c[1836236]=-1;c[2443829]=1073676288;c[2443828]=1073676288;c[2443821]=1073676288;c[2443820]=1073676288;h[920261]=0.0;c[3528510]=0;if((c[2385514]|0)>0){$=0;do{lw(c[14163952+($<<2)>>2]|0);$=$+1|0;}while(($|0)<(c[2385514]|0))}a[9579120]=0;T=0;i=e;return T|0}}while(0);c[2415018]=0;T=1;i=e;return T|0}function dxh(){var a=0,b=0,d=0,e=0,f=0;c[2113070]=0;c[2113068]=0;a=c[2112926]|0;if((a|0)!=0){gGr(a);c[2112926]=0}if((c[2392]|0)>=0){a=0;do{b=14130368+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}b=14130384+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}a=a+1|0;}while((a|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;fwZ();T6();a=c[2415018]|0;b=0;while(1){if((b|0)>=1024){e=83680;break}f=9638528+(b<<2)|0;if((c[f>>2]|0)==(a|0)){break}else{b=b+1|0}}if((e|0)==83680){c[2415018]=0;return 0}gGr(a);c[f>>2]=0;c[2415018]=0;return 0}function dxi(){var d=0,e=0,f=0,g=0,i=0;if((a[9624592]|0)!=0){d=c[2414724]|0;gGz(d|0,0,(c[2411756]|0)-d|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=1;c[2112932]=c[3532597];d=c[3532593]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113061];RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=i;c[1836236]=-1;c[2443829]=1073676288;c[2443828]=1073676288;c[2443821]=1073676288;c[2443820]=1073676288;h[920261]=0.0;c[3528510]=0;if((c[2385514]|0)>0){i=0;do{lw(c[14163952+(i<<2)>>2]|0);i=i+1|0;}while((i|0)<(c[2385514]|0))}a[9579120]=0}i=c[2392]|0;if((i|0)>=0){gGz(8452240,0,((i|0)>0?(i<<2)+4|0:4)|0)}c[2113054]=0;i=c[2385548]|0;if((i|0)>0){gGz(9752472,0,((i|0)>1?i<<2:4)|0)}c[2433530]=0;b[4775348]=-1;i=0;g=-1;f=-1;do{g=((a[9633992+i|0]&1)<<i^g&255)&255;f=((a[9631792+i|0]&1)<<i^f&255)&255;i=i+1|0;}while((i|0)<8);a[9550696]=g;a[9550697]=f;f=c[2438]|0;g=gGU(f,(f|0)<0|0?-1:0,1e7,0)|0;f=gGS(g,K,15360,0)|0;g=c[2439330]|0;if((g|0)!=0){i=g;gGC(9706056,i|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;i=(f|0)/100|0;f=0;do{if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060]}c[2113056]=i;g=RG(i)|0;e=(c[2113054]|0)+g|0;c[2113054]=e;c[2276108]=-1;c[2113056]=-1;do{if((f|0)==(((c[2113070]|0)*100|0|0)/256|0|0)){c[8452200+(c[2394]<<2)>>2]=4097;c[2276080]=256;if((c[2276079]|0)>>>0>=256){break}RH(1)}}while(0);g=c[2394]|0;d=c[14130368+(g<<2)>>2]|0;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[8452240+(g<<2)>>2]=c[2113054];c[2394]=1;c[2112932]=c[3532597];g=c[3532593]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}g=c[2113061]|0;c[2113054]=g;d=e-g-(c[2113056]|0)+(c[2276108]|0)|0;c[2113056]=d;g=RG(d)|0;c[2113054]=(c[2113054]|0)+g;c[2276108]=-1;c[2113056]=-1;do{if((f|0)==(((c[2113070]|0)*100|0|0)/256|0|0)){c[8452200+(c[2394]<<2)>>2]=8195;c[2276080]=768;if((c[2276079]|0)>>>0>=768){break}RH(3)}}while(0);e=c[2394]|0;g=c[14130368+(e<<2)>>2]|0;if((g|0)!=0){gGC(g|0,9104152,280)|0}c[8452240+(e<<2)>>2]=c[2113054];c[2394]=-1;T2(f*596|0);f=f+1|0;}while((f|0)<100);f=c[2438226]|0;i=gGS(-1597636608,28447,f,(f|0)<0|0?-1:0)|0;f=i;T2(59659);i=c[2443828]|0;if((i|0)<1073676288){c[2443828]=i-f}i=c[2443829]|0;if((i|0)<1073676288){c[2443829]=i-f}i=(c[3528510]|0)-f|0;c[3528510]=(i|0)<0?0:i;i=c[2112964]|0;if((i|0)!=0){gg[c[3542190]&4095](i,a[9688]|0?534:0)}i=c[1836236]|0;f=c[9757320+(i<<2)>>2]|0;if((f|0)!=0){e=f;gGC(e|0,9706056,76)|0}c[9752472+(i<<2)>>2]=c[2433530];c[14113936+(i<<2)>>2]=c[2076596];c[9669104+(i<<2)>>2]=c[3541536];c[1836236]=-1;if((c[2112968]|0)==0){return 0}dxj()|0;return 0}function dxj(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0;if((a[9547680]|0)==0){d=c[3530082]|0}else{f=c[2387232]|0;g=c[3530082]|0;h=0;do{i=e[f+h>>1]|0;j=i>>>5&31;c[g+(((h|0)/2|0)<<2)>>2]=i>>>10&31|i<<11&63488|(j<<3|j>>>2)<<3&2016;h=h+2|0;}while((h|0)<16384);a[9547680]=0;d=g}c[d+32768>>2]=0;g=c[2113068]|0;h=c[2113070]|0;f=ag(h,g)|0;j=c[2112926]|0;if((f|0)>0){i=0;while(1){b[j+(i<<1)>>1]=8192;k=i+1|0;if((k|0)<(f|0)){i=k}else{l=j;break}}}else{l=j}dxl(0);j=c[3529810]|0;dxm(c[3529410]|0,c[3530456]|0,b[j>>1]|0,b[j+4>>1]|0,c[2443382]|0,7168);j=c[3529814]|0;dxm(c[3529444]|0,c[3530646]|0,b[j>>1]|0,b[j+4>>1]|0,c[2443386]|0,6144);dxl(128);j=c[2386494]|0;i=c[3530294]|0;f=0;do{k=b[j+(f<<1)>>1]|0;m=k&65535;if((m&8|0)!=0){n=(k&65535)>>>4&4080;k=e[j+((f|2)<<1)>>1]|0;o=(b[j+((f|4)<<1)>>1]&255)+1|0;p=e[j+((f|5)<<1)>>1]|0;q=e[j+((f|6)<<1)>>1]|0;r=q<<3&120;s=r+8|0;t=q>>>8;q=(p&512|0)==0?p&1023:p|-1024;u=(k&256|0)==0?k&511:k|-512;k=p&32768;p=(k|0)!=0;v=p?r:0;r=p?-8:s;w=(k>>>11^16)-8|0;k=(s|0)/8|0;s=0;x=0;y=0;z=e[j+((f|1)<<1)>>1]|m<<16&458752;while(1){m=x+u|0;if((m|0)>-1&(m|0)<(h|0)){A=ag(g,m)|0;m=0;B=0;C=v;while(1){D=c[i+(((C|0)/8|0)+z<<2)>>2]|0;E=0;F=0;G=B;H=m;L102755:while(1){I=G+q|0;J=(I|0)>-1;K=l+(I+A<<1)|0;L102757:do{if(p){if(!J){L=E;M=F;N=H;while(1){if((L|0)>=8){O=N;break L102755}P=N+t|0;if((P|0)>255){Q=M;R=L;S=P;T=83772;break L102757}U=M+4|0;V=L+1|0;if((P|0)>127){W=P;X=U;Y=V;T=83775;break L102757}else{L=V;M=U;N=P}}}N=(I|0)<(g|0);M=E;L=F;P=H;while(1){if((M|0)>=8){O=P;break L102755}U=D>>>((28-L|0)>>>0)&15;if(U<<16>>16!=0&N){b[K>>1]=U|n}U=P+t|0;if((U|0)>255){Q=L;R=M;S=U;T=83772;break L102757}V=L+4|0;Z=M+1|0;if((U|0)>127){W=U;X=V;Y=Z;T=83775;break}else{M=Z;L=V;P=U}}}else{if(!J){P=E;L=F;M=H;while(1){if((P|0)>=8){O=M;break L102755}N=M+t|0;if((N|0)>255){Q=L;R=P;S=N;T=83772;break L102757}U=L+4|0;V=P+1|0;if((N|0)>127){W=N;X=U;Y=V;T=83775;break L102757}else{P=V;L=U;M=N}}}M=(I|0)<(g|0);L=E;P=F;N=H;while(1){if((L|0)>=8){O=N;break L102755}U=D>>>(P>>>0)&15;if(U<<16>>16!=0&M){b[K>>1]=U|n}U=N+t|0;if((U|0)>255){Q=P;R=L;S=U;T=83772;break L102757}V=P+4|0;Z=L+1|0;if((U|0)>127){W=U;X=V;Y=Z;T=83775;break}else{L=Z;P=V;N=U}}}}while(0);if((T|0)==83772){T=0;_=R;$=Q;aa=S-256|0}else if((T|0)==83775){T=0;_=Y;$=X;aa=W-128|0}E=_;F=$;G=G+1|0;H=aa}H=w+C|0;if((H|0)==(r|0)){break}else{m=O;B=G;C=H}}}C=s+t|0;do{if((C|0)>255){ab=z;ac=y-1|0;ad=x+1|0;ae=C-256|0}else{B=z+k|0;if((C|0)<=127){ab=B;ac=y;ad=x;ae=C;break}ab=B;ac=y;ad=x+1|0;ae=C-128|0}}while(0);C=ac+1|0;if((C|0)<(o|0)){s=ae;x=ad;y=C;z=ab}else{break}}}f=f+8|0;}while((f|0)<2048);f=c[3529818]|0;dxm(c[3529478]|0,c[3530882]|0,b[f>>1]|0,b[f+4>>1]|0,c[2443388]|0,5120);R8(d);return 0}function dxk(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;e=i;i=i+192|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;l=e+80|0;m=e+96|0;n=e+112|0;o=e+128|0;p=e+144|0;q=e+160|0;r=e+176|0;s=r|0;t=r;if((d|0)!=0){c[d>>2]=169767}if((b&4|0)!=0){u=r;c[u>>2]=c[3531124];v=t+4|0;c[v>>2]=262144;w=r+8|0;c[w>>2]=0;x=t+12|0;c[x>>2]=194104;y=c[2076592]|0;gj[y&4095](t)|0;c[u>>2]=c[3531112];c[v>>2]=131072;c[w>>2]=8388608;c[x>>2]=154560;y=c[2076592]|0;gj[y&4095](t)|0;c[u>>2]=c[2385954];c[v>>2]=32768;c[w>>2]=15728640;c[x>>2]=124776;x=c[2076592]|0;gj[x&4095](t)|0}if((b&32|0)!=0){c[s>>2]=0;c[s+4>>2]=0;x=r;c[x>>2]=c[3531176];w=t+4|0;c[w>>2]=32768;v=r+8|0;c[v>>2]=524288;r=t+12|0;c[r>>2]=99672;u=c[2076592]|0;gj[u&4095](t)|0;c[s>>2]=0;c[s+4>>2]=0;c[x>>2]=c[2386494];c[w>>2]=4096;c[v>>2]=655360;c[r>>2]=77208;u=c[2076592]|0;gj[u&4095](t)|0;c[s>>2]=0;c[s+4>>2]=0;c[x>>2]=c[3529478];c[w>>2]=8192;c[v>>2]=786432;c[r>>2]=584384;u=c[2076592]|0;gj[u&4095](t)|0;c[s>>2]=0;c[s+4>>2]=0;c[x>>2]=c[3529444];c[w>>2]=8192;c[v>>2]=802816;c[r>>2]=567824;u=c[2076592]|0;gj[u&4095](t)|0;c[s>>2]=0;c[s+4>>2]=0;c[x>>2]=c[3529478];c[w>>2]=8192;c[v>>2]=819200;c[r>>2]=551456;u=c[2076592]|0;gj[u&4095](t)|0;c[s>>2]=0;c[s+4>>2]=0;c[x>>2]=c[3527310];c[w>>2]=4096;c[v>>2]=917504;c[r>>2]=288280;u=c[2076592]|0;gj[u&4095](t)|0;c[s>>2]=0;c[s+4>>2]=0;c[x>>2]=c[2387232];c[w>>2]=32768;c[v>>2]=1048576;c[r>>2]=523896;u=c[2076592]|0;gj[u&4095](t)|0;c[s>>2]=0;c[s+4>>2]=0;c[x>>2]=c[3529478];c[w>>2]=16384;c[v>>2]=8912896;c[r>>2]=510232;u=c[2076592]|0;gj[u&4095](t)|0;c[s>>2]=0;c[s+4>>2]=0;c[x>>2]=c[3529844];c[w>>2]=4096;c[v>>2]=9175040;c[r>>2]=497640;u=c[2076592]|0;gj[u&4095](t)|0;c[s>>2]=0;c[s+4>>2]=0;c[x>>2]=c[2386108];c[w>>2]=8192;c[v>>2]=15761408;c[r>>2]=485848;r=c[2076592]|0;gj[r&4095](t)|0}if((b&64|0)!=0){t=h|0;gGz(g|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){r=h+9|0;h=f;v=f|0;w=f+4|0;x=f+12|0;s=g|0;u=g+4|0;y=g+12|0;z=0;do{gGC(t|0,614896,11)|0;a[r]=z+48&255;A=8452256+(z<<2)|0;gGz(h|0,0,12);c[v>>2]=A;c[w>>2]=4;c[x>>2]=164976;gj[c[2076592]&4095](f)|0;if((c[A>>2]|0)!=0){c[s>>2]=c[14130368+(z<<2)>>2];c[u>>2]=c[8452184+(z<<2)>>2];c[y>>2]=t;A=c[2076592]|0;gj[A&4095](g)|0}z=z+1|0;}while((z|0)<=(c[2392]|0))}fw$(b);Uc(b,d);gGz(q|0,0,12);c[q>>2]=9579120;c[q+4>>2]=1;c[q+12>>2]=473024;d=c[2076592]|0;gj[d&4095](q)|0;q=c[3528314]|0;gGz(p|0,0,12);c[p>>2]=q;c[p+4>>2]=1;c[p+12>>2]=461600;q=c[2076592]|0;gj[q&4095](p)|0;p=c[3529818]|0;gGz(o|0,0,12);c[o>>2]=p;c[o+4>>2]=2;c[o+12>>2]=450776;p=c[2076592]|0;gj[p&4095](o)|0;o=(c[3529818]|0)+4|0;gGz(n|0,0,12);c[n>>2]=o;c[n+4>>2]=2;c[n+12>>2]=439488;o=c[2076592]|0;gj[o&4095](n)|0;n=c[3529814]|0;gGz(m|0,0,12);c[m>>2]=n;c[m+4>>2]=2;c[m+12>>2]=428336;n=c[2076592]|0;gj[n&4095](m)|0;m=(c[3529814]|0)+4|0;gGz(l|0,0,12);c[l>>2]=m;c[l+4>>2]=2;c[l+12>>2]=417016;m=c[2076592]|0;gj[m&4095](l)|0;l=c[3529810]|0;gGz(k|0,0,12);c[k>>2]=l;c[k+4>>2]=2;c[k+12>>2]=404920;l=c[2076592]|0;gj[l&4095](k)|0;k=(c[3529810]|0)+4|0;gGz(j|0,0,12);c[j>>2]=k;c[j+4>>2]=2;c[j+12>>2]=394040;k=c[2076592]|0;gj[k&4095](j)|0}if((b&2|0)==0){i=e;return 0}a[9547680]=1;i=e;return 0}function dxl(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;g=c[3529844]|0;h=c[2113070]<<2;if((h|0)<=0){return}i=c[3530348]|0;j=c[2112926]|0;k=c[2113068]|0;l=c[2443378]|0;m=(k|0)>0;n=0;do{o=e[g+((n|1)<<1)>>1]|0;L102830:do{if((o&128|0)==(f|0)){p=e[g+(n<<1)>>1]|0;q=p&1023;r=b[g+((n|2)<<1)>>1]&511;s=o<<4&1008|4096;t=r<<10;u=ag(k,(n|0)/4|0)|0;v=a[l+r|0]|0;if(v<<24>>24==0){break}if(q>>>0<513){r=t|q;if(v<<24>>24==3){if(m){w=0}else{break}while(1){b[j+(w+u<<1)>>1]=(d[i+(w+r)|0]|0)+s&65535;w=w+1|0;if((w|0)>=(k|0)){break L102830}}}if(m){x=0}else{break}do{q=a[i+(x+r)|0]|0;if(q<<24>>24!=0){b[j+(x+u<<1)>>1]=(q&255)+s&65535}x=x+1|0;}while((x|0)<(k|0))}else{if(v<<24>>24==3){if(m){y=0}else{break}while(1){b[j+(y+u<<1)>>1]=(d[i+(y+p&1023|t)|0]|0)+s&65535;y=y+1|0;if((y|0)>=(k|0)){break L102830}}}if(m){z=0}else{break}do{v=a[i+(z+p&1023|t)|0]|0;if(v<<24>>24!=0){b[j+(z+u<<1)>>1]=(v&255)+s&65535}z=z+1|0;}while((z|0)<(k|0))}}}while(0);n=n+4|0;}while((n|0)<(h|0));return}function dxm(a,b,f,g,h,i){a=a|0;b=b|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;j=a;a=f&1023;f=g&255;g=c[2112926]|0;k=c[2113068]|0;l=0;do{m=(l<<3&1016)-a|0;n=(m|0)<-7?m+1024|0:m;m=(l>>7<<3)-f|0;o=(m|0)<-7?m+256|0:m;do{if((n|0)<(k|0)){m=c[2113070]|0;if((o|0)>=(m|0)){break}p=e[j+(l<<1)>>1]|0;q=p&8191;r=p>>>7&56|p>>>13;do{if((o|0)>-1){if(!((o|0)<(m-7|0)&(n|0)>-1)){s=0;break}s=(n|0)<(k-7|0)?4:0}else{s=0}}while(0);m=(d[h+q|0]|0)+s|0;if((m|0)==3){Sj(g,q,n,o,r,4,i,b);break}else if((m|0)==5){Sq(g,q,n,o,r,4,0,i,b);break}else if((m|0)==7){Si(g,q,n,o,r,4,i,b);break}else if((m|0)==1){Sr(g,q,n,o,r,4,0,i,b);break}else{break}}}while(0);l=l+1|0;}while((l|0)<4096);return}function dxn(b,d){b=b|0;d=d|0;var f=0,g=0,h=0;if((b&16760832|0)==1048576){f=c[2387232]|0;a[f+(b&16383^1)|0]=d;g=b&16382;h=e[f+g>>1]|0;f=h>>>5&31;c[(c[3530082]|0)+(g>>>1<<2)>>2]=h>>>10&31|h<<11&63488|(f<<3|f>>>2)<<3&2016;return}if((b|0)==1114113){a[c[3528314]|0]=d;a[9706117]=1;return}else if((b|0)==1114119){a[9579120]=(d&255)>>>5&3;return}else if((b|0)==1114125){c[8452200+(c[2394]<<2)>>2]=0;c[2276080]=0;return}else{return}}function dxo(a,d){a=a|0;d=d|0;var e=0,f=0,g=0;if((a&16760832|0)==1048576){e=a&16382;b[(c[2387232]|0)+e>>1]=d;f=d&65535;g=f>>>5&31;c[(c[3530082]|0)+(e>>>1<<2)>>2]=f>>>10&31|f<<11&63488|(g<<3|g>>>2)<<3&2016;return}switch(a|0){case 1114184:case 1114186:case 1114188:{b[(c[3529814]|0)+((a>>>1&3)<<1)>>1]=d;return};case 1114240:case 1114242:case 1114244:{b[(c[3529810]|0)+((a>>>1&3)<<1)>>1]=d;return};case 1114176:case 1114178:case 1114180:{b[(c[3529818]|0)+((a>>>1&3)<<1)>>1]=d;return};default:{return}}}function dxp(b){b=b|0;var c=0,f=0;L102902:do{switch(b|0){case 1114121:{c=a[9550697]|0;break};case 1114119:{c=-1;break};case 1114123:{c=a[9635387]|0;break};case 1114325:{f=d[9579120]|0;if((f|0)==0){c=127-((e[7062208]|0)>>>4&255)&255;break L102902}else if((f|0)==3){c=127-((e[7062212]|0)>>>4&255)&255;break L102902}else if((f|0)==1){c=127-((e[7062204]|0)>>>4&255)&255;break L102902}else if((f|0)==2){c=((a[9626376]|0)!=0)<<31>>31;break L102902}else{c=0;break L102902}break};case 1114114:{c=a[9635386]|0;break};case 1114115:{c=a[9635385]|0;break};case 1114120:{c=-1;break};case 1114122:{c=a[9635388]|0;break};case 1114118:{c=a[9635384]&8|a[9550696]&-9;break};default:{c=0}}}while(0);return c|0}function dxq(a){a=a|0;return 0}function dxr(b,e){b=b|0;e=e|0;var f=0,g=0;f=b&65535;if((f|0)==40960|(f|0)==40961){b=c[3540988]|0;if((f&1|0)==0){a[b+5885|0]=e;return}g=c[b+5876>>2]|0;if((g|0)!=0){gg[g&4095](c[b+5880>>2]|0,0)}lH(b,d[b+5885|0]|0,e&255);return}else if((f|0)==49152|(f|0)==49153){b=c[3540989]|0;if((f&1|0)==0){a[b+5885|0]=e;return}f=c[b+5876>>2]|0;if((f|0)!=0){gg[f&4095](c[b+5880>>2]|0,0)}lH(b,d[b+5885|0]|0,e&255);return}else{return}}function dxs(b){b=b|0;var e=0,f=0,g=0;e=b&65535;if((e|0)==40961){a[9706117]=0;f=a[c[3528314]|0]|0;return f|0}else if((e|0)==40960){b=c[3540988]|0;g=(d[b+5887|0]|0|128)&(d[b+5886|0]|0);if((a[b+5884|0]&2)==0){f=g&255;return f|0}else{f=(a[(c[b+5828>>2]|0)+100|0]&1|g)&255;return f|0}}else if((e|0)==49152|(e|0)==49153){f=lx(c[3540989]|0,e&1)|0;return f|0}else{f=0;return f|0}return 0}function dxt(a){a=a|0;var b=0,d=0;b=(c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,3579545,0)|0;return a|0}function dxu(b){b=b|0;var c=0;switch(b&65535|0){case 49155:{c=a[9658e3]|0;break};case 49154:{c=~a[9625818];break};case 49152:{c=~a[9625816];break};case 49153:{c=~a[9625817];break};case 49156:{c=a[9658001]|0;break};default:{c=0}}return c|0}function dxv(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;switch(d&65535|0){case 51204:{a[9759728]=e&-128;if((e&16)==0){return}d=c[1836236]|0;f=c[9757320+(d<<2)>>2]|0;if((f|0)!=0){g=f;gGC(g|0,9706056,76)|0}c[9752472+(d<<2)>>2]=c[2433530];c[14113936+(d<<2)>>2]=c[2076596];c[9669104+(d<<2)>>2]=c[3541536];c[1836236]=-1;d=c[2439331]|0;g=(d|0)==0;if(!g){f=d;gGC(9706056,f|0,76)|0}f=c[2438119]|0;c[2433530]=f;h=c[3528485]|0;c[2076596]=h;i=c[2417277]|0;c[3541536]=i;c[1836236]=1;gGz(9706056,0,76);if(!g){g=d;gGC(g|0,9706056,76)|0}c[2438119]=f;c[3528485]=h;c[2417277]=i;c[1836236]=-1;i=c[2439330]|0;if((i|0)!=0){h=i;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;return};case 51205:{a[9755104]=e;return};case 51202:{a[14109880]=e;return};case 51203:{a[14109881]=e;return};case 51206:{h=e&3;a[14119336]=h;i=c[3529122]|0;f=(h&255)<<14;h=c[9757320+(c[1836236]<<2)>>2]|0;g=(f|65536)-32768|0;d=128;j=128;while(1){c[h+76+(j<<2)>>2]=i+(g+(j<<8));k=d+1&65535;if((k&65535)>191){break}else{d=k;j=k&65535}}j=f+32768|0;f=128;d=128;while(1){g=i+(j+(d<<8))|0;c[h+76+(d+512<<2)>>2]=g;c[h+76+(d+768<<2)>>2]=g;g=f+1&65535;if((g&65535)>191){break}else{f=g;d=g&65535}}return};case 51200:{a[9758200]=e;return};default:{return}}}function dxw(b){b=b|0;return(b<<16>>16==24576?a[9758200]|0:0)|0}function dxx(b,d){b=b|0;d=d|0;var e=0,f=0;e=b&65535;if((e|0)==49153){b=d&255;f=c[3542291]|0;if((f|0)>15){return}do{if((f|0)<14){if((f|0)!=13){if((a[14169168+f|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(1,f,b);return}else if((e|0)==32769){b=d&255;f=c[3542228]|0;if((f|0)>15){return}do{if((f|0)<14){if((f|0)!=13){if((a[14168916+f|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(0,f,b);return}else if((e|0)==32768){c[3542228]=d&15;return}else if((e|0)==49152){c[3542291]=d&15;return}else{return}}function dxy(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>26){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7409316+(b*112|0)>>2];c[a+104>>2]=c[7409320+(b*112|0)>>2];c[a+108>>2]=c[7409324+(b*112|0)>>2];d=0;return d|0}function dxz(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<27&(d|0)==0)){e=1;return e|0}c[a>>2]=7409216+(b*112|0);e=0;return e|0}function dxA(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6933552+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dxB(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>46){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7443488+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dxC(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0;b=i;i=i+2760|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;l=b+360|0;m=b+472|0;n=b+480|0;o=b+592|0;p=b+600|0;q=b+712|0;r=b+720|0;s=b+832|0;t=b+840|0;u=b+952|0;v=b+960|0;w=b+1072|0;x=b+1080|0;y=b+1192|0;z=b+1200|0;A=b+1312|0;B=b+1320|0;C=b+1432|0;D=b+1440|0;E=b+1552|0;F=b+1560|0;G=b+1672|0;H=b+1680|0;I=b+1792|0;J=b+1800|0;K=b+1912|0;L=b+1920|0;M=b+2032|0;N=b+2040|0;O=b+2152|0;P=b+2160|0;Q=b+2272|0;R=b+2280|0;S=b+2392|0;T=b+2400|0;U=b+2512|0;V=b+2520|0;W=b+2632|0;X=b+2640|0;Y=b+2752|0;c[2426778]=0;c[3529122]=0;c[3529110]=114688;c[3529860]=131072;c[2443498]=131328;c[3527340]=131584;c[2432718]=131840;c[2432716]=132096;c[2429758]=132352;c[2405690]=132608;c[3529152]=132608;c[3529142]=136704;c[2443422]=138752;c[2439944]=138880;c[2439962]=140928;c[2411754]=141952;c[2406530]=141952;c[2405818]=174720;c[3529582]=305792;c[2385384]=436864;Z=a[9688]|0?6408:0;c[3530080]=Z+436864;_=Z|443008|0;c[2414302]=_;Z=_;_=0;while(1){if((_|0)>=1024){break}$=9638528+(_<<2)|0;if((c[$>>2]|0)==0){aa=83996;break}else{_=_+1|0}}do{if((aa|0)==83996){_=gGq(Z)|0;c[$>>2]=_;if((_|0)==0){break}gGz(_|0,0,Z|0);c[2426778]=_;gGz(_|0,0,Z|0);c[3529122]=_;c[3529110]=_+114688;c[3529860]=_+131072;c[2443498]=_+131328;c[3527340]=_+131584;c[2432718]=_+131840;c[2432716]=_+132096;c[2429758]=_+132352;ab=_+132608|0;c[2405690]=ab;c[3529152]=ab;c[3529142]=_+136704;c[2443422]=_+138752;c[2439944]=_+138880;c[2439962]=_+140928;ab=_+141952|0;c[2411754]=ab;c[2406530]=ab;c[2405818]=_+174720;c[3529582]=_+305792;c[2385384]=_+436864;ab=a[9688]|0?6408:0;c[3530080]=_+(ab+436864);c[2414302]=_+(ab|443008);ab=0;while(1){if((ab|0)>=1024){ac=0;break}ad=9638528+(ab<<2)|0;if((c[ad>>2]|0)==0){aa=84001;break}else{ab=ab+1|0}}do{if((aa|0)==84001){ab=gGq(65536)|0;c[ad>>2]=ab;if((ab|0)==0){ac=0;break}gGz(ab|0,0,65536);ac=ab}}while(0);c[3529532]=ac;ab=c[3529122]|0;if((c[3542200]|0)==0){ae=1;i=b;return ae|0}_=X+108|0;c[_>>2]=0;af=X+100|0;c[af>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](X,0)|0;do{if((c[_>>2]|0)!=0){ag=c[af>>2]|0;c[Y>>2]=9534384;ah=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ah&16383](Y,0,0)|0;if((ag|0)<1){ae=1;i=b;return ae|0}if((gzL(ab,0,0)|0)==0){break}else{ae=1}i=b;return ae|0}}while(0);ab=(c[3529122]|0)+16384|0;if((c[3542200]|0)==0){ae=1;i=b;return ae|0}af=V+108|0;c[af>>2]=0;_=V+100|0;c[_>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](V,1)|0;do{if((c[af>>2]|0)!=0){ag=c[_>>2]|0;c[W>>2]=9534384;ah=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ah&16383](W,1,0)|0;if((ag|0)<1){ae=1;i=b;return ae|0}if((gzL(ab,0,1)|0)==0){break}else{ae=1}i=b;return ae|0}}while(0);ab=(c[3529122]|0)+65536|0;if((c[3542200]|0)==0){ae=1;i=b;return ae|0}_=T+108|0;c[_>>2]=0;af=T+100|0;c[af>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](T,2)|0;do{if((c[_>>2]|0)!=0){ag=c[af>>2]|0;c[U>>2]=9534384;ah=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ah&16383](U,2,0)|0;if((ag|0)<1){ae=1;i=b;return ae|0}if((gzL(ab,0,2)|0)==0){break}else{ae=1}i=b;return ae|0}}while(0);ab=(c[3529122]|0)+81920|0;if((c[3542200]|0)==0){ae=1;i=b;return ae|0}af=R+108|0;c[af>>2]=0;_=R+100|0;c[_>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](R,3)|0;do{if((c[af>>2]|0)!=0){ag=c[_>>2]|0;c[S>>2]=9534384;ah=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ah&16383](S,3,0)|0;if((ag|0)<1){ae=1;i=b;return ae|0}if((gzL(ab,0,3)|0)==0){break}else{ae=1}i=b;return ae|0}}while(0);ab=(c[3529122]|0)+98304|0;if((c[3542200]|0)==0){ae=1;i=b;return ae|0}_=P+108|0;c[_>>2]=0;af=P+100|0;c[af>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](P,4)|0;do{if((c[_>>2]|0)!=0){ag=c[af>>2]|0;c[Q>>2]=9534384;ah=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ah&16383](Q,4,0)|0;if((ag|0)<1){ae=1;i=b;return ae|0}if((gzL(ab,0,4)|0)==0){break}else{ae=1}i=b;return ae|0}}while(0);ab=c[3529110]|0;if((c[3542200]|0)==0){ae=1;i=b;return ae|0}af=N+108|0;c[af>>2]=0;_=N+100|0;c[_>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](N,5)|0;do{if((c[af>>2]|0)!=0){ag=c[_>>2]|0;c[O>>2]=9534384;ah=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ah&16383](O,5,0)|0;if((ag|0)<1){ae=1;i=b;return ae|0}if((gzL(ab,0,5)|0)==0){break}else{ae=1}i=b;return ae|0}}while(0);ab=c[3529532]|0;if((c[3542200]|0)==0){ae=1;i=b;return ae|0}_=L+108|0;c[_>>2]=0;af=L+100|0;c[af>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](L,6)|0;do{if((c[_>>2]|0)!=0){ag=c[af>>2]|0;c[M>>2]=9534384;ah=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ah&16383](M,6,0)|0;if((ag|0)<1){ae=1;i=b;return ae|0}if((gzL(ab,0,6)|0)==0){break}else{ae=1}i=b;return ae|0}}while(0);ab=c[3529532]|0;af=c[2406530]|0;_=0;do{ag=_<<6;gGz(af+ag|0,0,64);ah=_<<7;ai=ah|4;aj=0;while(1){ak=ai+(c[6669224+(aj<<2)>>2]|0)|0;al=(aj<<3)+ag|0;am=0;do{an=ak+(c[612480+(am<<2)>>2]|0)|0;if(((d[ab+((an|0)/8|0)|0]|0)&128>>>((an&7)>>>0)|0)!=0){an=af+(al+am)|0;a[an]=a[an]|2}am=am+1|0;}while((am|0)<8);am=aj+1|0;if((am|0)<8){aj=am}else{ao=0;break}}do{aj=ah+(c[6669224+(ao<<2)>>2]|0)|0;ai=(ao<<3)+ag|0;am=0;do{al=aj+(c[612480+(am<<2)>>2]|0)|0;if(((d[ab+((al|0)/8|0)|0]|0)&128>>>((al&7)>>>0)|0)!=0){al=af+(ai+am)|0;a[al]=a[al]|1}am=am+1|0;}while((am|0)<8);ao=ao+1|0;}while((ao|0)<8);_=_+1|0;}while((_|0)<512);gGz(ab|0,0,65536);if((c[3542200]|0)==0){ae=1;i=b;return ae|0}_=J+108|0;c[_>>2]=0;af=J+100|0;c[af>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](J,7)|0;do{if((c[_>>2]|0)!=0){ag=c[af>>2]|0;c[K>>2]=9534384;ah=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ah&16383](K,7,0)|0;if((ag|0)<1){ae=1;i=b;return ae|0}if((gzL(ab,0,7)|0)==0){break}else{ae=1}i=b;return ae|0}}while(0);ab=(c[3529532]|0)+8192|0;if((c[3542200]|0)==0){ae=1;i=b;return ae|0}af=H+108|0;c[af>>2]=0;_=H+100|0;c[_>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](H,8)|0;do{if((c[af>>2]|0)!=0){ag=c[_>>2]|0;c[I>>2]=9534384;ah=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ah&16383](I,8,0)|0;if((ag|0)<1){ae=1;i=b;return ae|0}if((gzL(ab,0,8)|0)==0){break}else{ae=1}i=b;return ae|0}}while(0);ab=(c[3529532]|0)+16384|0;if((c[3542200]|0)==0){ae=1;i=b;return ae|0}_=F+108|0;c[_>>2]=0;af=F+100|0;c[af>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](F,9)|0;do{if((c[_>>2]|0)!=0){ag=c[af>>2]|0;c[G>>2]=9534384;ah=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ah&16383](G,9,0)|0;if((ag|0)<1){ae=1;i=b;return ae|0}if((gzL(ab,0,9)|0)==0){break}else{ae=1}i=b;return ae|0}}while(0);ab=(c[3529532]|0)+24576|0;if((c[3542200]|0)==0){ae=1;i=b;return ae|0}af=D+108|0;c[af>>2]=0;_=D+100|0;c[_>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](D,10)|0;do{if((c[af>>2]|0)!=0){ag=c[_>>2]|0;c[E>>2]=9534384;ah=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ah&16383](E,10,0)|0;if((ag|0)<1){ae=1;i=b;return ae|0}if((gzL(ab,0,10)|0)==0){break}else{ae=1}i=b;return ae|0}}while(0);ab=(c[3529532]|0)+32768|0;if((c[3542200]|0)==0){ae=1;i=b;return ae|0}_=B+108|0;c[_>>2]=0;af=B+100|0;c[af>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](B,11)|0;do{if((c[_>>2]|0)!=0){ag=c[af>>2]|0;c[C>>2]=9534384;ah=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ah&16383](C,11,0)|0;if((ag|0)<1){ae=1;i=b;return ae|0}if((gzL(ab,0,11)|0)==0){break}else{ae=1}i=b;return ae|0}}while(0);ab=(c[3529532]|0)+40960|0;if((c[3542200]|0)==0){ae=1;i=b;return ae|0}af=z+108|0;c[af>>2]=0;_=z+100|0;c[_>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,12)|0;do{if((c[af>>2]|0)!=0){ag=c[_>>2]|0;c[A>>2]=9534384;ah=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ah&16383](A,12,0)|0;if((ag|0)<1){ae=1;i=b;return ae|0}if((gzL(ab,0,12)|0)==0){break}else{ae=1}i=b;return ae|0}}while(0);ab=c[3529532]|0;_=c[2405818]|0;af=0;do{ag=af<<8;gGz(_+ag|0,0,256);ah=0;do{am=ag+(c[609008+(ah<<2)>>2]|0)|0;ai=(ah<<4)+ag|0;aj=0;do{al=am+(c[597864+(aj<<2)>>2]|0)|0;if(((d[ab+((al|0)/8|0)|0]|0)&128>>>((al&7)>>>0)|0)!=0){al=_+(ai+aj)|0;a[al]=a[al]|4}aj=aj+1|0;}while((aj|0)<16);ah=ah+1|0;}while((ah|0)<16);ah=ag+131072|0;aj=0;do{ai=ah+(c[609008+(aj<<2)>>2]|0)|0;am=(aj<<4)+ag|0;al=0;do{ak=ai+(c[597864+(al<<2)>>2]|0)|0;if(((d[ab+((ak|0)/8|0)|0]|0)&128>>>((ak&7)>>>0)|0)!=0){ak=_+(am+al)|0;a[ak]=a[ak]|2}al=al+1|0;}while((al|0)<16);aj=aj+1|0;}while((aj|0)<16);aj=ag+262144|0;ah=0;do{al=aj+(c[609008+(ah<<2)>>2]|0)|0;am=(ah<<4)+ag|0;ai=0;do{ak=al+(c[597864+(ai<<2)>>2]|0)|0;if(((d[ab+((ak|0)/8|0)|0]|0)&128>>>((ak&7)>>>0)|0)!=0){ak=_+(am+ai)|0;a[ak]=a[ak]|1}ai=ai+1|0;}while((ai|0)<16);ah=ah+1|0;}while((ah|0)<16);af=af+1|0;}while((af|0)<512);gGz(ab|0,0,65536);if((c[3542200]|0)==0){ae=1;i=b;return ae|0}af=x+108|0;c[af>>2]=0;_=x+100|0;c[_>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,13)|0;do{if((c[af>>2]|0)!=0){ah=c[_>>2]|0;c[y>>2]=9534384;ag=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ag&16383](y,13,0)|0;if((ah|0)<1){ae=1;i=b;return ae|0}if((gzL(ab,0,13)|0)==0){break}else{ae=1}i=b;return ae|0}}while(0);ab=(c[3529532]|0)+16384|0;if((c[3542200]|0)==0){ae=1;i=b;return ae|0}_=v+108|0;c[_>>2]=0;af=v+100|0;c[af>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,14)|0;do{if((c[_>>2]|0)!=0){ah=c[af>>2]|0;c[w>>2]=9534384;ag=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ag&16383](w,14,0)|0;if((ah|0)<1){ae=1;i=b;return ae|0}if((gzL(ab,0,14)|0)==0){break}else{ae=1}i=b;return ae|0}}while(0);ab=(c[3529532]|0)+32768|0;if((c[3542200]|0)==0){ae=1;i=b;return ae|0}af=t+108|0;c[af>>2]=0;_=t+100|0;c[_>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,15)|0;do{if((c[af>>2]|0)!=0){ah=c[_>>2]|0;c[u>>2]=9534384;ag=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ag&16383](u,15,0)|0;if((ah|0)<1){ae=1;i=b;return ae|0}if((gzL(ab,0,15)|0)==0){break}else{ae=1}i=b;return ae|0}}while(0);ab=(c[3529532]|0)+49152|0;if((c[3542200]|0)==0){ae=1;i=b;return ae|0}_=r+108|0;c[_>>2]=0;af=r+100|0;c[af>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,16)|0;do{if((c[_>>2]|0)!=0){ah=c[af>>2]|0;c[s>>2]=9534384;ag=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ag&16383](s,16,0)|0;if((ah|0)<1){ae=1;i=b;return ae|0}if((gzL(ab,0,16)|0)==0){break}else{ae=1}i=b;return ae|0}}while(0);ab=c[3529532]|0;af=c[3529582]|0;_=0;do{ah=_<<8;gGz(af+ah|0,0,256);ag=_<<9;aj=0;do{ai=1<<3-aj;am=(c[613264+(aj<<2)>>2]|0)+ag|0;al=0;do{ak=am+(c[608544+(al<<2)>>2]|0)|0;an=(al<<4)+ah|0;ap=0;do{aq=ak+(c[609552+(ap<<2)>>2]|0)|0;if(((d[ab+((aq|0)/8|0)|0]|0)&128>>>((aq&7)>>>0)|0)!=0){aq=af+(an+ap)|0;a[aq]=(d[aq]|0|ai)&255}ap=ap+1|0;}while((ap|0)<16);al=al+1|0;}while((al|0)<16);aj=aj+1|0;}while((aj|0)<4);_=_+1|0;}while((_|0)<512);_=c[3529860]|0;if((c[3542200]|0)==0){ae=1;i=b;return ae|0}af=p+108|0;c[af>>2]=0;ab=p+100|0;c[ab>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,17)|0;do{if((c[af>>2]|0)!=0){aj=c[ab>>2]|0;c[q>>2]=9534384;ah=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ah&16383](q,17,0)|0;if((aj|0)<1){ae=1;i=b;return ae|0}if((gzL(_,0,17)|0)==0){break}else{ae=1}i=b;return ae|0}}while(0);_=c[2443498]|0;if((c[3542200]|0)==0){ae=1;i=b;return ae|0}ab=n+108|0;c[ab>>2]=0;af=n+100|0;c[af>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,18)|0;do{if((c[ab>>2]|0)!=0){aj=c[af>>2]|0;c[o>>2]=9534384;ah=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ah&16383](o,18,0)|0;if((aj|0)<1){ae=1;i=b;return ae|0}if((gzL(_,0,18)|0)==0){break}else{ae=1}i=b;return ae|0}}while(0);_=c[3527340]|0;if((c[3542200]|0)==0){ae=1;i=b;return ae|0}af=l+108|0;c[af>>2]=0;ab=l+100|0;c[ab>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,19)|0;do{if((c[af>>2]|0)!=0){aj=c[ab>>2]|0;c[m>>2]=9534384;ah=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ah&16383](m,19,0)|0;if((aj|0)<1){ae=1;i=b;return ae|0}if((gzL(_,0,19)|0)==0){break}else{ae=1}i=b;return ae|0}}while(0);_=c[2432718]|0;if((c[3542200]|0)==0){ae=1;i=b;return ae|0}ab=j+108|0;c[ab>>2]=0;af=j+100|0;c[af>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,20)|0;do{if((c[ab>>2]|0)!=0){aj=c[af>>2]|0;c[k>>2]=9534384;ah=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ah&16383](k,20,0)|0;if((aj|0)<1){ae=1;i=b;return ae|0}if((gzL(_,0,20)|0)==0){break}else{ae=1}i=b;return ae|0}}while(0);_=c[2432716]|0;if((c[3542200]|0)==0){ae=1;i=b;return ae|0}af=g+108|0;c[af>>2]=0;ab=g+100|0;c[ab>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,21)|0;do{if((c[af>>2]|0)!=0){aj=c[ab>>2]|0;c[h>>2]=9534384;ah=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ah&16383](h,21,0)|0;if((aj|0)<1){ae=1;i=b;return ae|0}if((gzL(_,0,21)|0)==0){break}else{ae=1}i=b;return ae|0}}while(0);_=c[2429758]|0;if((c[3542200]|0)==0){ae=1;i=b;return ae|0}ab=e+108|0;c[ab>>2]=0;af=e+100|0;c[af>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,22)|0;do{if((c[ab>>2]|0)!=0){aj=c[af>>2]|0;c[f>>2]=9534384;ah=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ah&16383](f,22,0)|0;if((aj|0)<1){ae=1;i=b;return ae|0}if((gzL(_,0,22)|0)==0){break}else{ae=1}i=b;return ae|0}}while(0);_=c[3529532]|0;af=0;while(1){if((af|0)>=1024){break}ar=9638528+(af<<2)|0;if((c[ar>>2]|0)==(_|0)){aa=84123;break}else{af=af+1|0}}if((aa|0)==84123){gGr(_);c[ar>>2]=0}c[3529532]=0;dxP();ae=0;i=b;return ae|0}}while(0);c[2426778]=0;ae=1;i=b;return ae|0}function dxD(){var b=0,d=0,e=0,f=0;fwZ();c[2113008]=0;c[2076598]=0;c[2383582]=0;c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}a[9755104]=0;a[14109880]=0;a[14109881]=0;a[9759728]=0;a[9758200]=0;a[14119336]=0;b=c[2426778]|0;d=0;while(1){if((d|0)>=1024){e=84222;break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==(b|0)){break}else{d=d+1|0}}if((e|0)==84222){c[2426778]=0;return 0}gGr(b);c[f>>2]=0;c[2426778]=0;return 0}function dxE(){var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=i;i=i+1024|0;f=e|0;if((a[9624584]|0)!=0){g=c[2439330]|0;h=(g|0)==0;if(!h){j=g;gGC(9706056,j|0,76)|0}j=c[2438118]|0;c[2433530]=j;k=c[3528484]|0;c[2076596]=k;l=c[2417276]|0;c[3541536]=l;c[1836236]=0;gGz(9706056,0,76);if(!h){h=g;gGC(h|0,9706056,76)|0}c[2438118]=j;c[3528484]=k;c[2417276]=l;c[1836236]=-1;l=c[2439331]|0;k=(l|0)==0;if(!k){j=l;gGC(9706056,j|0,76)|0}j=c[2438119]|0;c[2433530]=j;h=c[3528485]|0;c[2076596]=h;g=c[2417277]|0;c[3541536]=g;c[1836236]=1;gGz(9706056,0,76);if(!k){k=l;gGC(k|0,9706056,76)|0}c[2438119]=j;c[3528485]=h;c[2417277]=g;c[1836236]=-1;mB(0);mB(1);a[9755104]=0;a[14109880]=0;a[14109881]=0;a[9759728]=0;a[9758200]=0;a[14119336]=0}a[9625818]=0;a[9625817]=0;a[9625816]=0;g=0;h=0;j=0;k=0;do{h=((a[9759224+g|0]&1)<<g|h&255)&255;j=((a[9759032+g|0]&1)<<g|j&255)&255;k=((a[9758848+g|0]&1)<<g|k&255)&255;g=g+1|0;}while((g|0)<8);a[9625816]=h;a[9625817]=j;a[9625818]=k;if((j&3)==3){h=j&-4;a[9625817]=h;m=h}else{m=j}if((m&12)==12){a[9625817]=m&-13}if((k&3)==3){m=k&-4;a[9625818]=m;n=m}else{n=k}if((n&12)==12){a[9625818]=n&-13}a[6518280]=1;a[6518096]=1;c[2444101]=0;c[2444100]=0;n=0;k=0;L103416:while(1){m=k;while(1){if((m|0)>=4){break L103416}j=c[2439330]|0;if((j|0)!=0){h=j;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;h=c[2438118]|0;c[2433530]=h;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;o=m+1|0;g=(ag(a[6518280]|0?66666:0,o)|0)/4|0;l=c[2444100]|0;p=g-l|0;c[2438194]=p;do{if((p|0)<1){q=0;r=l}else{if((a[j+4188|0]|0)==0){g=gfc(p)|0;c[2433530]=(c[2433530]|0)+g;q=g;r=c[2444100]|0;break}else{c[2433530]=h+p;q=p;r=l;break}}}while(0);c[2444100]=r+q;if((m|0)==1){a[14125144]=-49;a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0}else if((m|0)==3){a[14125144]=-41;a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0}l=c[1836236]|0;p=c[9757320+(l<<2)>>2]|0;if((p|0)!=0){h=p;gGC(h|0,9706056,76)|0}c[9752472+(l<<2)>>2]=c[2433530];c[14113936+(l<<2)>>2]=c[2076596];c[9669104+(l<<2)>>2]=c[3541536];c[1836236]=-1;l=c[2439331]|0;if((l|0)!=0){h=l;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;h=c[2438119]|0;c[2433530]=h;c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;p=(ag(a[6518096]|0?5e4:0,o)|0)/4|0;j=c[2444101]|0;g=p-j|0;c[2438194]=g;do{if((g|0)<1){s=0;t=j}else{if((a[l+4188|0]|0)==0){p=gfc(g)|0;c[2433530]=(c[2433530]|0)+p;s=p;t=c[2444101]|0;break}else{c[2433530]=h+g;s=g;t=j;break}}}while(0);c[2438194]=s;c[2444101]=t+s;a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0;j=c[1836236]|0;g=c[9757320+(j<<2)>>2]|0;if((g|0)!=0){h=g;gGC(h|0,9706056,76)|0}c[9752472+(j<<2)>>2]=c[2433530];c[14113936+(j<<2)>>2]=c[2076596];c[9669104+(j<<2)>>2]=c[3541536];c[1836236]=-1;u=c[2112964]|0;if((u|0)==0){m=o}else{break}}m=a[9688]|0?133:0;mF(9756352,u+(n<<1<<1)|0,m,0);n=m+n|0;k=o}o=c[2112964]|0;do{if((o|0)!=0){k=a[9688]|0?534:0;if((k|0)==(n|0)){break}mF(9756352,o+(n<<1<<1)|0,k-n|0,0)}}while(0);if((c[2112968]|0)==0){i=e;return 0}n=c[2112926]|0;gGz(n|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);o=c[3529860]|0;k=c[2443498]|0;u=c[3527340]|0;s=0;do{t=d[o+s|0]|0;q=d[k+s|0]|0;r=d[u+s|0]|0;c[f+(s<<2)>>2]=(-(q>>>1&1)&31)+(-(q&1)&14)+(-(q>>>2&1)&67)+(-(q>>>3&1)&143)<<3&2016|(-(t>>>1&1)&31)+(-(t&1)&14)+(-(t>>>2&1)&67)+(-(t>>>3&1)&143)<<8&63488|((-(r>>>1&1)&31)+(-(r&1)&14)+(-(r>>>2&1)&67)+(-(r>>>3&1)&143)|0)>>>3&31;s=s+1|0;}while((s|0)<256);s=c[2432718]|0;u=c[3530080]|0;k=0;do{c[u+(k<<2)>>2]=c[f+((d[s+k|0]|128)<<2)>>2];k=k+1|0;}while((k|0)<256);k=c[2432716]|0;s=0;do{o=k+s|0;c[u+(s+256<<2)>>2]=c[f+(d[o]<<2)>>2];c[u+(s+512<<2)>>2]=c[f+((d[o]|16)<<2)>>2];c[u+(s+768<<2)>>2]=c[f+((d[o]|32)<<2)>>2];c[u+(s+1024<<2)>>2]=c[f+((d[o]|48)<<2)>>2];s=s+1|0;}while((s|0)<256);s=c[2429758]|0;k=0;do{c[u+(k+1280<<2)>>2]=c[f+((d[s+k|0]|64)<<2)>>2];k=k+1|0;}while((k|0)<256);k=d[14109881]<<8&256|d[14109880];s=c[2439962]|0;f=c[2405818]|0;o=0;do{r=o<<4;t=r-16|0;if((r-17|0)>>>0<207){r=0;do{q=r<<4;m=q+o|0;j=m<<1&992|m&15;m=d[s+(j|16)|0]|0;h=m<<1&256|d[s+j|0];j=m&31;g=q-k|0;q=(g|0)<-16?g+512|0:g;g=(m&32|0)==0;l=(m&64|0)!=0;m=(d[9755104]<<8)+256|0;do{if((q-1|0)>>>0<239){if(g){if(l){SC(n,h,q,t,j,3,m,f);break}else{Sy(n,h,q,t,j,3,m,f);break}}else{if(l){SE(n,h,q,t,j,3,m,f);break}else{SA(n,h,q,t,j,3,m,f);break}}}else{if(g){if(l){SD(n,h,q,t,j,3,m,f);break}else{Sz(n,h,q,t,j,3,m,f);break}}else{if(l){SF(n,h,q,t,j,3,m,f);break}else{SB(n,h,q,t,j,3,m,f);break}}}}while(0);r=r+1|0;}while((r|0)<32)}else{r=0;do{m=r<<4;j=m+o|0;q=j<<1&992|j&15;j=d[s+(q|16)|0]|0;h=j<<1&256|d[s+q|0];q=j&31;l=m-k|0;m=(l|0)<-16?l+512|0:l;l=(j&64|0)!=0;g=(d[9755104]<<8)+256|0;do{if((j&32|0)==0){if(l){SD(n,h,m,t,q,3,g,f);break}else{Sz(n,h,m,t,q,3,g,f);break}}else{if(l){SF(n,h,m,t,q,3,g,f);break}else{SB(n,h,m,t,q,3,g,f);break}}}while(0);r=r+1|0;}while((r|0)<32)}o=o+1|0;}while((o|0)<16);o=c[2443422]|0;f=c[3529582]|0;k=124;do{s=d[o+k|0]|0;r=d[o+(k|1)|0]|0;t=s<<1&256|s&127|r<<2&128;s=r&15;g=(d[o+(k|3)|0]|0)-(r<<4&256)|0;q=r>>>6;r=(d[o+(k|2)|0]|0)-16|0;m=(q|0)==2?3:q;while(1){SH(n,m+t|0,g,r+(m<<4)|0,s,4,15,1280,f);if((m|0)>0){m=m-1|0}else{break}}k=k-4|0;}while((k|0)>-1);k=c[2439944]|0;f=c[2406530]|0;o=0;m=0;while(1){s=o<<3;r=s-16|0;g=(s-17|0)>>>0>214;s=0;t=m;while(1){q=d[k+(t+1024)|0]|0;h=q<<1&256|d[k+t|0];l=q&63;q=s<<3;if((q-1|0)>>>0>246|g){Sr(n,h,q,r,l,2,0,0,f)}else{Sq(n,h,q,r,l,2,0,0,f)}l=s+1|0;if((l|0)<32){s=l;t=t+1|0}else{break}}t=o+1|0;if((t|0)<32){o=t;m=m+32|0}else{break}}R8(u);i=e;return 0}function dxF(a,e){a=a|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;f=i;i=i+192|0;g=f|0;h=f+32|0;j=f+48|0;k=f+64|0;l=f+80|0;m=f+96|0;n=f+112|0;o=f+128|0;p=f+144|0;q=f+160|0;r=f+176|0;s=(e|0)==0;if(!s){c[e>>2]=169586}if((a&32|0)!=0){gGz(r|0,0,12);t=c[2405690]|0;c[r>>2]=t;c[r+4>>2]=(c[2411754]|0)-t;c[r+12>>2]=162152;t=c[2076592]|0;gj[t&4095](r)|0}if((a&64|0)!=0){fw$(a);r=f+16|0;do{if(!s){if((c[e>>2]|0)>=169110){break}c[e>>2]=169110}}while(0);if((c[2113008]|0)>0){e=g|0;s=g+4|0;t=g+8|0;u=g+12|0;v=0;do{cC(r|0,531144,(w=i,i=i+8|0,c[w>>2]=v,w)|0)|0;i=w;c[e>>2]=14168888+(v*252|0);c[s>>2]=252;c[t>>2]=0;c[u>>2]=r;gj[c[2076592]&4095](g)|0;v=v+1|0;}while((v|0)<(c[2113008]|0))}gGz(q|0,0,12);c[q>>2]=9776400;c[q+4>>2]=8;c[q+12>>2]=212472;v=c[2076592]|0;gj[v&4095](q)|0;gGz(p|0,0,12);c[p>>2]=9752776;c[p+4>>2]=4;c[p+12>>2]=436576;q=c[2076592]|0;gj[q&4095](p)|0;gGz(o|0,0,12);c[o>>2]=14119336;c[o+4>>2]=1;c[o+12>>2]=511192;p=c[2076592]|0;gj[p&4095](o)|0;gGz(n|0,0,12);c[n>>2]=9755104;c[n+4>>2]=1;c[n+12>>2]=461584;o=c[2076592]|0;gj[o&4095](n)|0;gGz(m|0,0,12);c[m>>2]=9758200;c[m+4>>2]=1;c[m+12>>2]=497064;n=c[2076592]|0;gj[n&4095](m)|0;gGz(l|0,0,12);c[l>>2]=14109880;c[l+4>>2]=2;c[l+12>>2]=439472;m=c[2076592]|0;gj[m&4095](l)|0;gGz(k|0,0,12);c[k>>2]=9759728;c[k+4>>2]=1;c[k+12>>2]=503888;l=c[2076592]|0;gj[l&4095](k)|0;gGz(j|0,0,12);c[j>>2]=9658e3;c[j+4>>2]=2;c[j+12>>2]=483352;k=c[2076592]|0;gj[k&4095](j)|0;gGz(h|0,0,12);c[h>>2]=9625816;c[h+4>>2]=3;c[h+12>>2]=215728;j=c[2076592]|0;gj[j&4095](h)|0}if((a&2|0)==0){i=f;return 0}a=c[2439330]|0;h=(a|0)==0;if(!h){j=a;gGC(9706056,j|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];j=c[3528484]|0;c[2076596]=j;k=c[2417276]|0;c[3541536]=k;c[1836236]=0;l=c[3529122]|0;m=((d[14119336]|0)<<14)+32768|0;n=128;o=128;while(1){c[a+76+(o<<2)>>2]=l+(m+(o<<8));p=n+1&65535;if((p&65535)>191){x=128;y=128;break}else{n=p;o=p&65535}}while(1){o=l+(m+(y<<8))|0;c[a+76+(y+512<<2)>>2]=o;c[a+76+(y+768<<2)>>2]=o;o=x+1&65535;if((o&65535)>191){break}else{x=o;y=o&65535}}if(!h){h=a;gGC(h|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=j;c[2417276]=k;c[1836236]=-1;i=f;return 0}function dxG(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>26){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7298468+(b*112|0)>>2];c[a+104>>2]=c[7298472+(b*112|0)>>2];c[a+108>>2]=c[7298476+(b*112|0)>>2];d=0;return d|0}function dxH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<27&(d|0)==0)){e=1;return e|0}c[a>>2]=7298368+(b*112|0);e=0;return e|0}function dxI(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6344452+(b*112|0)>>2];c[a+104>>2]=c[6344456+(b*112|0)>>2];c[a+108>>2]=c[6344460+(b*112|0)>>2];d=0;return d|0}function dxJ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=6344352+(b*112|0);e=0;return e|0}function dxK(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0;b=i;i=i+1920|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;l=b+360|0;m=b+472|0;n=b+480|0;o=b+592|0;p=b+600|0;q=b+712|0;r=b+720|0;s=b+832|0;t=b+840|0;u=b+952|0;v=b+960|0;w=b+1072|0;x=b+1080|0;y=b+1192|0;z=b+1200|0;A=b+1312|0;B=b+1320|0;C=b+1432|0;D=b+1440|0;E=b+1552|0;F=b+1560|0;G=b+1672|0;H=b+1680|0;I=b+1792|0;J=b+1800|0;K=b+1912|0;c[2426778]=0;c[3529122]=0;c[3529110]=114688;c[3529860]=131072;c[2443498]=131328;c[3527340]=131584;c[2432718]=131840;c[2432716]=132096;c[2429758]=132352;c[2405690]=132608;c[3529152]=132608;c[3529142]=136704;c[2443422]=138752;c[2439944]=138880;c[2439962]=140928;c[2411754]=141952;c[2406530]=141952;c[2405818]=174720;c[3529582]=305792;c[2385384]=436864;L=a[9688]|0?6408:0;c[3530080]=L+436864;M=L|443008|0;c[2414302]=M;L=M;M=0;while(1){if((M|0)>=1024){break}N=9638528+(M<<2)|0;if((c[N>>2]|0)==0){O=84373;break}else{M=M+1|0}}do{if((O|0)==84373){M=gGq(L)|0;c[N>>2]=M;if((M|0)==0){break}gGz(M|0,0,L|0);c[2426778]=M;gGz(M|0,0,L|0);c[3529122]=M;c[3529110]=M+114688;c[3529860]=M+131072;c[2443498]=M+131328;c[3527340]=M+131584;c[2432718]=M+131840;c[2432716]=M+132096;c[2429758]=M+132352;P=M+132608|0;c[2405690]=P;c[3529152]=P;c[3529142]=M+136704;c[2443422]=M+138752;c[2439944]=M+138880;c[2439962]=M+140928;P=M+141952|0;c[2411754]=P;c[2406530]=P;c[2405818]=M+174720;c[3529582]=M+305792;c[2385384]=M+436864;P=a[9688]|0?6408:0;c[3530080]=M+(P+436864);c[2414302]=M+(P|443008);P=0;while(1){if((P|0)>=1024){Q=0;break}R=9638528+(P<<2)|0;if((c[R>>2]|0)==0){O=84378;break}else{P=P+1|0}}do{if((O|0)==84378){P=gGq(98304)|0;c[R>>2]=P;if((P|0)==0){Q=0;break}gGz(P|0,0,98304);Q=P}}while(0);c[3529532]=Q;P=c[3529122]|0;if((c[3542200]|0)==0){S=1;i=b;return S|0}M=J+108|0;c[M>>2]=0;T=J+100|0;c[T>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](J,0)|0;do{if((c[M>>2]|0)!=0){U=c[T>>2]|0;c[K>>2]=9534384;V=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[V&16383](K,0,0)|0;if((U|0)<1){S=1;i=b;return S|0}if((gzL(P,0,0)|0)==0){break}else{S=1}i=b;return S|0}}while(0);P=(c[3529122]|0)+65536|0;if((c[3542200]|0)==0){S=1;i=b;return S|0}T=H+108|0;c[T>>2]=0;M=H+100|0;c[M>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](H,1)|0;do{if((c[T>>2]|0)!=0){U=c[M>>2]|0;c[I>>2]=9534384;V=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[V&16383](I,1,0)|0;if((U|0)<1){S=1;i=b;return S|0}if((gzL(P,0,1)|0)==0){break}else{S=1}i=b;return S|0}}while(0);P=(c[3529122]|0)+81920|0;if((c[3542200]|0)==0){S=1;i=b;return S|0}M=F+108|0;c[M>>2]=0;T=F+100|0;c[T>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](F,2)|0;do{if((c[M>>2]|0)!=0){U=c[T>>2]|0;c[G>>2]=9534384;V=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[V&16383](G,2,0)|0;if((U|0)<1){S=1;i=b;return S|0}if((gzL(P,0,2)|0)==0){break}else{S=1}i=b;return S|0}}while(0);P=c[3529110]|0;if((c[3542200]|0)==0){S=1;i=b;return S|0}T=D+108|0;c[T>>2]=0;M=D+100|0;c[M>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](D,3)|0;do{if((c[T>>2]|0)!=0){U=c[M>>2]|0;c[E>>2]=9534384;V=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[V&16383](E,3,0)|0;if((U|0)<1){S=1;i=b;return S|0}if((gzL(P,0,3)|0)==0){break}else{S=1}i=b;return S|0}}while(0);P=c[3529532]|0;if((c[3542200]|0)==0){S=1;i=b;return S|0}M=B+108|0;c[M>>2]=0;T=B+100|0;c[T>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](B,4)|0;do{if((c[M>>2]|0)!=0){U=c[T>>2]|0;c[C>>2]=9534384;V=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[V&16383](C,4,0)|0;if((U|0)<1){S=1;i=b;return S|0}if((gzL(P,0,4)|0)==0){break}else{S=1}i=b;return S|0}}while(0);P=c[3529532]|0;T=c[2406530]|0;M=0;do{U=M<<6;gGz(T+U|0,0,64);V=M<<7;W=V|4;X=0;while(1){Y=W+(c[6669224+(X<<2)>>2]|0)|0;Z=(X<<3)+U|0;_=0;do{$=Y+(c[612480+(_<<2)>>2]|0)|0;if(((d[P+(($|0)/8|0)|0]|0)&128>>>(($&7)>>>0)|0)!=0){$=T+(Z+_)|0;a[$]=a[$]|2}_=_+1|0;}while((_|0)<8);_=X+1|0;if((_|0)<8){X=_}else{aa=0;break}}do{X=V+(c[6669224+(aa<<2)>>2]|0)|0;W=(aa<<3)+U|0;_=0;do{Z=X+(c[612480+(_<<2)>>2]|0)|0;if(((d[P+((Z|0)/8|0)|0]|0)&128>>>((Z&7)>>>0)|0)!=0){Z=T+(W+_)|0;a[Z]=a[Z]|1}_=_+1|0;}while((_|0)<8);aa=aa+1|0;}while((aa|0)<8);M=M+1|0;}while((M|0)<512);gGz(P|0,0,65536);if((c[3542200]|0)==0){S=1;i=b;return S|0}M=z+108|0;c[M>>2]=0;T=z+100|0;c[T>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,5)|0;do{if((c[M>>2]|0)!=0){U=c[T>>2]|0;c[A>>2]=9534384;V=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[V&16383](A,5,0)|0;if((U|0)<1){S=1;i=b;return S|0}if((gzL(P,0,5)|0)==0){break}else{S=1}i=b;return S|0}}while(0);P=(c[3529532]|0)+16384|0;if((c[3542200]|0)==0){S=1;i=b;return S|0}T=x+108|0;c[T>>2]=0;M=x+100|0;c[M>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,6)|0;do{if((c[T>>2]|0)!=0){U=c[M>>2]|0;c[y>>2]=9534384;V=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[V&16383](y,6,0)|0;if((U|0)<1){S=1;i=b;return S|0}if((gzL(P,0,6)|0)==0){break}else{S=1}i=b;return S|0}}while(0);P=(c[3529532]|0)+32768|0;if((c[3542200]|0)==0){S=1;i=b;return S|0}M=v+108|0;c[M>>2]=0;T=v+100|0;c[T>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,7)|0;do{if((c[M>>2]|0)!=0){U=c[T>>2]|0;c[w>>2]=9534384;V=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[V&16383](w,7,0)|0;if((U|0)<1){S=1;i=b;return S|0}if((gzL(P,0,7)|0)==0){break}else{S=1}i=b;return S|0}}while(0);P=c[3529532]|0;T=c[2405818]|0;M=0;do{U=M<<8;gGz(T+U|0,0,256);V=0;do{_=U+(c[609008+(V<<2)>>2]|0)|0;W=(V<<4)+U|0;X=0;do{Z=_+(c[597864+(X<<2)>>2]|0)|0;if(((d[P+((Z|0)/8|0)|0]|0)&128>>>((Z&7)>>>0)|0)!=0){Z=T+(W+X)|0;a[Z]=a[Z]|4}X=X+1|0;}while((X|0)<16);V=V+1|0;}while((V|0)<16);V=U+131072|0;X=0;do{W=V+(c[609008+(X<<2)>>2]|0)|0;_=(X<<4)+U|0;Z=0;do{Y=W+(c[597864+(Z<<2)>>2]|0)|0;if(((d[P+((Y|0)/8|0)|0]|0)&128>>>((Y&7)>>>0)|0)!=0){Y=T+(_+Z)|0;a[Y]=a[Y]|2}Z=Z+1|0;}while((Z|0)<16);X=X+1|0;}while((X|0)<16);X=U+262144|0;V=0;do{Z=X+(c[609008+(V<<2)>>2]|0)|0;_=(V<<4)+U|0;W=0;do{Y=Z+(c[597864+(W<<2)>>2]|0)|0;if(((d[P+((Y|0)/8|0)|0]|0)&128>>>((Y&7)>>>0)|0)!=0){Y=T+(_+W)|0;a[Y]=a[Y]|1}W=W+1|0;}while((W|0)<16);V=V+1|0;}while((V|0)<16);M=M+1|0;}while((M|0)<512);gGz(P|0,0,65536);M=P+65536|0;if((c[3542200]|0)==0){S=1;i=b;return S|0}T=t+108|0;c[T>>2]=0;V=t+100|0;c[V>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,8)|0;do{if((c[T>>2]|0)!=0){U=c[V>>2]|0;c[u>>2]=9534384;X=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[X&16383](u,8,0)|0;if((U|0)<1){S=1;i=b;return S|0}if((gzL(M,0,8)|0)==0){break}else{S=1}i=b;return S|0}}while(0);M=c[3529532]|0;V=M+16384|0;T=M+65536|0;gGC(V|0,T|0,16384)|0;V=M+81920|0;gGC(M|0,V|0,16384)|0;if((c[3542200]|0)==0){S=1;i=b;return S|0}V=r+108|0;c[V>>2]=0;M=r+100|0;c[M>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,9)|0;do{if((c[V>>2]|0)!=0){P=c[M>>2]|0;c[s>>2]=9534384;U=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[U&16383](s,9,0)|0;if((P|0)<1){S=1;i=b;return S|0}if((gzL(T,0,9)|0)==0){break}else{S=1}i=b;return S|0}}while(0);T=c[3529532]|0;M=T+49152|0;V=T+65536|0;gGC(M|0,V|0,16384)|0;V=T+32768|0;M=T+81920|0;gGC(V|0,M|0,16384)|0;M=c[3529582]|0;V=0;do{P=V<<8;gGz(M+P|0,0,256);U=V<<9;X=0;do{W=1<<3-X;_=(c[613264+(X<<2)>>2]|0)+U|0;Z=0;do{Y=_+(c[608544+(Z<<2)>>2]|0)|0;$=(Z<<4)+P|0;ab=0;do{ac=Y+(c[609552+(ab<<2)>>2]|0)|0;if(((d[T+((ac|0)/8|0)|0]|0)&128>>>((ac&7)>>>0)|0)!=0){ac=M+($+ab)|0;a[ac]=(d[ac]|0|W)&255}ab=ab+1|0;}while((ab|0)<16);Z=Z+1|0;}while((Z|0)<16);X=X+1|0;}while((X|0)<4);V=V+1|0;}while((V|0)<512);V=c[3529860]|0;if((c[3542200]|0)==0){S=1;i=b;return S|0}M=p+108|0;c[M>>2]=0;T=p+100|0;c[T>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,10)|0;do{if((c[M>>2]|0)!=0){X=c[T>>2]|0;c[q>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](q,10,0)|0;if((X|0)<1){S=1;i=b;return S|0}if((gzL(V,0,10)|0)==0){break}else{S=1}i=b;return S|0}}while(0);V=c[2443498]|0;if((c[3542200]|0)==0){S=1;i=b;return S|0}T=n+108|0;c[T>>2]=0;M=n+100|0;c[M>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,11)|0;do{if((c[T>>2]|0)!=0){X=c[M>>2]|0;c[o>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](o,11,0)|0;if((X|0)<1){S=1;i=b;return S|0}if((gzL(V,0,11)|0)==0){break}else{S=1}i=b;return S|0}}while(0);V=c[3527340]|0;if((c[3542200]|0)==0){S=1;i=b;return S|0}M=l+108|0;c[M>>2]=0;T=l+100|0;c[T>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,12)|0;do{if((c[M>>2]|0)!=0){X=c[T>>2]|0;c[m>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](m,12,0)|0;if((X|0)<1){S=1;i=b;return S|0}if((gzL(V,0,12)|0)==0){break}else{S=1}i=b;return S|0}}while(0);V=c[2432718]|0;if((c[3542200]|0)==0){S=1;i=b;return S|0}T=j+108|0;c[T>>2]=0;M=j+100|0;c[M>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,13)|0;do{if((c[T>>2]|0)!=0){X=c[M>>2]|0;c[k>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](k,13,0)|0;if((X|0)<1){S=1;i=b;return S|0}if((gzL(V,0,13)|0)==0){break}else{S=1}i=b;return S|0}}while(0);V=c[2432716]|0;if((c[3542200]|0)==0){S=1;i=b;return S|0}M=g+108|0;c[M>>2]=0;T=g+100|0;c[T>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,14)|0;do{if((c[M>>2]|0)!=0){X=c[T>>2]|0;c[h>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](h,14,0)|0;if((X|0)<1){S=1;i=b;return S|0}if((gzL(V,0,14)|0)==0){break}else{S=1}i=b;return S|0}}while(0);V=c[2429758]|0;if((c[3542200]|0)==0){S=1;i=b;return S|0}T=e+108|0;c[T>>2]=0;M=e+100|0;c[M>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,15)|0;do{if((c[T>>2]|0)!=0){X=c[M>>2]|0;c[f>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](f,15,0)|0;if((X|0)<1){S=1;i=b;return S|0}if((gzL(V,0,15)|0)==0){break}else{S=1}i=b;return S|0}}while(0);V=c[3529532]|0;M=0;while(1){if((M|0)>=1024){break}ad=9638528+(M<<2)|0;if((c[ad>>2]|0)==(V|0)){O=84472;break}else{M=M+1|0}}if((O|0)==84472){gGr(V);c[ad>>2]=0}c[3529532]=0;dxP();S=0;i=b;return S|0}}while(0);c[2426778]=0;S=1;i=b;return S|0}function dxL(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>26){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7277548+(b*112|0)>>2];c[a+104>>2]=c[7277552+(b*112|0)>>2];c[a+108>>2]=c[7277556+(b*112|0)>>2];d=0;return d|0}function dxM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<27&(d|0)==0)){e=1;return e|0}c[a>>2]=7277448+(b*112|0);e=0;return e|0}function dxN(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>26){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7217428+(b*112|0)>>2];c[a+104>>2]=c[7217432+(b*112|0)>>2];c[a+108>>2]=c[7217436+(b*112|0)>>2];d=0;return d|0}function dxO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<27&(d|0)==0)){e=1;return e|0}c[a>>2]=7217328+(b*112|0);e=0;return e|0}function dxP(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0.0,x=0,y=0,z=0,A=0;fwR(0);d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];f=c[3528484]|0;c[2076596]=f;g=c[2417276]|0;c[3541536]=g;c[1836236]=0;c[d+4180>>2]=1256;c[d+4184>>2]=2818;i=c[3529122]|0;j=0;k=0;while(1){c[d+76+(k<<2)>>2]=i+(k<<8);l=j+1&65535;if((l&65535)>127){m=0;n=0;break}else{j=l;k=l&65535}}while(1){k=i+(n<<8)|0;c[d+76+(n+512<<2)>>2]=k;c[d+76+(n+768<<2)>>2]=k;k=m+1&65535;if((k&65535)>127){o=128;p=128;break}else{m=k;n=k&65535}}while(1){c[d+76+(p<<2)>>2]=i+((p<<8)+32768);n=o+1&65535;if((n&65535)>191){q=128;r=128;break}else{o=n;p=n&65535}}while(1){p=i+((r<<8)+32768)|0;c[d+76+(r+512<<2)>>2]=p;c[d+76+(r+768<<2)>>2]=p;p=q+1&65535;if((p&65535)>191){break}else{q=p;r=p&65535}}r=c[2443422]|0;c[d+892>>2]=r;c[d+1916>>2]=r;c[d+2940>>2]=r;c[d+3964>>2]=r;r=c[2439944]|0;c[d+908>>2]=r;q=r+256|0;c[d+912>>2]=q;i=r+512|0;c[d+916>>2]=i;p=r+768|0;c[d+920>>2]=p;o=r+1024|0;c[d+924>>2]=o;n=r+1280|0;c[d+928>>2]=n;m=r+1536|0;c[d+932>>2]=m;k=r+1792|0;c[d+936>>2]=k;c[d+1932>>2]=r;c[d+1936>>2]=q;c[d+1940>>2]=i;c[d+1944>>2]=p;c[d+1948>>2]=o;c[d+1952>>2]=n;c[d+1956>>2]=m;c[d+1960>>2]=k;c[d+2956>>2]=r;c[d+3980>>2]=r;c[d+2960>>2]=q;c[d+3984>>2]=q;c[d+2964>>2]=i;c[d+3988>>2]=i;c[d+2968>>2]=p;c[d+3992>>2]=p;c[d+2972>>2]=o;c[d+3996>>2]=o;c[d+2976>>2]=n;c[d+4e3>>2]=n;c[d+2980>>2]=m;c[d+4004>>2]=m;c[d+2984>>2]=k;c[d+4008>>2]=k;k=c[2439962]|0;c[d+940>>2]=k;m=k+256|0;c[d+944>>2]=m;n=k+512|0;c[d+948>>2]=n;o=k+768|0;c[d+952>>2]=o;c[d+1964>>2]=k;c[d+1968>>2]=m;c[d+1972>>2]=n;c[d+1976>>2]=o;c[d+2988>>2]=k;c[d+4012>>2]=k;c[d+2992>>2]=m;c[d+4016>>2]=m;c[d+2996>>2]=n;c[d+4020>>2]=n;c[d+3e3>>2]=o;c[d+4024>>2]=o;o=c[3529152]|0;c[d+972>>2]=o;c[d+976>>2]=o+256;c[d+980>>2]=o+512;c[d+984>>2]=o+768;c[d+988>>2]=o+1024;c[d+992>>2]=o+1280;c[d+996>>2]=o+1536;c[d+1e3>>2]=o+1792;c[d+1004>>2]=o+2048;c[d+1008>>2]=o+2304;c[d+1012>>2]=o+2560;c[d+1016>>2]=o+2816;c[d+1020>>2]=o+3072;c[d+1024>>2]=o+3328;c[d+1028>>2]=o+3584;c[d+1032>>2]=o+3840;n=224;m=224;while(1){c[d+76+(m+256<<2)>>2]=o+((m<<8)-57344);k=n+1&65535;if((k&65535)>239){s=224;t=224;break}else{n=k;m=k&65535}}while(1){m=o+((t<<8)-57344)|0;c[d+76+(t+512<<2)>>2]=m;c[d+76+(t+768<<2)>>2]=m;m=s+1&65535;if((m&65535)>239){break}else{s=m;t=m&65535}}if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=f;c[2417276]=g;c[1836236]=-1;fwR(1);g=c[2439331]|0;f=(g|0)==0;if(!f){e=g;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];e=c[3528485]|0;c[2076596]=e;d=c[2417277]|0;c[3541536]=d;c[1836236]=1;c[g+4180>>2]=1346;c[g+4184>>2]=334;t=c[3529110]|0;s=0;o=0;while(1){c[g+76+(o<<2)>>2]=t+(o<<8);m=s+1&65535;if((m&65535)>63){u=0;v=0;break}else{s=m;o=m&65535}}while(1){o=t+(v<<8)|0;c[g+76+(v+512<<2)>>2]=o;c[g+76+(v+768<<2)>>2]=o;o=u+1&65535;if((o&65535)>63){break}else{u=o;v=o&65535}}v=c[3529142]|0;c[g+332>>2]=v;u=v+256|0;c[g+336>>2]=u;t=v+512|0;c[g+340>>2]=t;o=v+768|0;c[g+344>>2]=o;s=v+1024|0;c[g+348>>2]=s;m=v+1280|0;c[g+352>>2]=m;n=v+1536|0;c[g+356>>2]=n;k=v+1792|0;c[g+360>>2]=k;c[g+1356>>2]=v;c[g+1360>>2]=u;c[g+1364>>2]=t;c[g+1368>>2]=o;c[g+1372>>2]=s;c[g+1376>>2]=m;c[g+1380>>2]=n;c[g+1384>>2]=k;c[g+2380>>2]=v;c[g+3404>>2]=v;c[g+2384>>2]=u;c[g+3408>>2]=u;c[g+2388>>2]=t;c[g+3412>>2]=t;c[g+2392>>2]=o;c[g+3416>>2]=o;c[g+2396>>2]=s;c[g+3420>>2]=s;c[g+2400>>2]=m;c[g+3424>>2]=m;c[g+2404>>2]=n;c[g+3428>>2]=n;c[g+2408>>2]=k;c[g+3432>>2]=k;if(!f){f=g;gGC(f|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=e;c[2417277]=d;c[1836236]=-1;d=c[2385384]|0;c[2439088]=d;e=a[9688]|0?534:0;c[2439089]=d+(e<<1);c[2439090]=d+(e<<1<<1);c[2439091]=d+((e*3|0)<<1);c[2439092]=d+(e<<2<<1);c[2439093]=d+((e*5|0)<<1);e=a[9680]|0?32e3:0;c[3542220]=11200;d=c[2113008]|0;if((d|0)==0){gGz(14168888,0,252);c[3542223]=e;gGz(14168896,0,16);c[3542234]=~~((+(e|0)*32768.0*8.0+75.0e4)/15.0e5);f=31;w=32767.0;while(1){c[14169012+(f<<2)>>2]=~~(w+.5);g=f-1|0;if((g|0)>0){f=g;w=w/1.188502227}else{break}}c[3542253]=0;h[1771269]=1.0;h[1771270]=1.0;h[1771271]=1.0;c[3542574]=3;c[3542575]=3;c[3542576]=3;mB(0);f=(c[2113008]|0)+1|0;c[2113008]=f;x=f;y=a[9680]|0?32e3:0}else{x=d;y=e}c[3542220]=11200;if((x|0)==1){gGz(14169140,0,252);c[3542286]=y;gGz(14169148,0,16);c[3542297]=~~((+(y|0)*32768.0*8.0+75.0e4)/15.0e5);y=31;w=32767.0;while(1){c[14169264+(y<<2)>>2]=~~(w+.5);x=y-1|0;if((x|0)>0){y=x;w=w/1.188502227}else{break}}c[3542316]=0;h[1771272]=1.0;h[1771273]=1.0;h[1771274]=1.0;c[3542577]=3;c[3542578]=3;c[3542579]=3;mB(1);c[2113008]=(c[2113008]|0)+1}h[1771269]=.25;c[3542574]=3;h[1771270]=.25;c[3542575]=3;h[1771271]=.25;c[3542576]=3;h[1771272]=.25;c[3542577]=3;h[1771273]=.25;c[3542578]=3;h[1771274]=.25;c[3542579]=3;y=c[642608+(c[2436]<<2)>>2]|0;x=c[y+128>>2]|0;if((c[y+52>>2]&4|0)==0){c[2113068]=x;e=c[y+132>>2]|0;c[2113070]=e;c[2443814]=x;c[2440436]=e;z=x;A=e}else{c[2113070]=x;e=c[y+132>>2]|0;c[2113068]=e;c[2440436]=x;c[2443814]=e;z=e;A=x}x=ag(z<<1,A)|0;A=gGq(x)|0;c[2112926]=A;if((A|0)!=0){gGz(A|0,0,x|0)}x=c[2439330]|0;A=(x|0)==0;if(!A){z=x;gGC(9706056,z|0,76)|0}z=c[2438118]|0;c[2433530]=z;e=c[3528484]|0;c[2076596]=e;y=c[2417276]|0;c[3541536]=y;c[1836236]=0;gGz(9706056,0,76);if(!A){A=x;gGC(A|0,9706056,76)|0}c[2438118]=z;c[3528484]=e;c[2417276]=y;c[1836236]=-1;y=c[2439331]|0;e=(y|0)==0;if(!e){z=y;gGC(9706056,z|0,76)|0}z=c[2438119]|0;c[2433530]=z;A=c[3528485]|0;c[2076596]=A;x=c[2417277]|0;c[3541536]=x;c[1836236]=1;gGz(9706056,0,76);if(e){c[2438119]=z;c[3528485]=A;c[2417277]=x;c[1836236]=-1;mB(0);mB(1);a[9755104]=0;a[14109880]=0;a[14109881]=0;a[9759728]=0;a[9758200]=0;a[14119336]=0;return}e=y;gGC(e|0,9706056,76)|0;c[2438119]=z;c[3528485]=A;c[2417277]=x;c[1836236]=-1;mB(0);mB(1);a[9755104]=0;a[14109880]=0;a[14109881]=0;a[9759728]=0;a[9758200]=0;a[14119336]=0;return}function dxQ(a,b){a=a|0;b=b|0;var d=0;d=a&65535;switch(d|0){case 51200:{c[2430238]=b&255;return};case 51458:case 51459:{a=9755512+((d&1)<<2)|0;c[a>>2]=c[a>>2]&255|(b&255)<<8;return};case 51205:{c[2429568]=b&3;return};case 51204:{c[2430240]=(b&255)>>>7;return};case 51202:case 51203:{a=9755512+((d&1)<<2)|0;c[a>>2]=c[a>>2]&65280|b&255;return};default:{return}}}function dxR(b){b=b|0;var c=0;switch(b&65535|0){case 49152:{c=a[9633985]<<1^~a[9633984]^a[9633986]<<2^a[9633987]<<3^a[9633988]<<4^a[9633989]<<5^a[9633990]<<6^a[9633991]<<7;return c|0};case 49155:{c=a[9635376]|0;return c|0};case 49154:{c=a[9629753]<<1^~a[9629752]^a[9629754]<<2^a[9629755]<<3^a[9629756]<<4;return c|0};case 49156:{c=a[9635377]|0;return c|0};case 49153:{c=a[9631785]<<1^~a[9631784]^a[9631786]<<2^a[9631787]<<3^a[9631788]<<4;return c|0};default:{c=0;return c|0}}return 0}function dxS(b,d){b=b|0;d=d|0;var e=0,f=0;e=b&65535;if(!((e|0)==32768|(e|0)==32769|(e|0)==49152|(e|0)==49153)){return}b=e>>>14&1;f=d&255;if((e&1|0)==0){c[14168912+(b*252|0)>>2]=f&15;return}e=c[14168912+(b*252|0)>>2]|0;if((e|0)>15){return}do{if((e|0)<14){if((e|0)!=13){if((a[14168916+(b*252|0)+e|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(b,e,f);return}function dxT(a){a=a|0;var b=0;if(a<<16>>16!=24576){b=0;return b|0}b=c[2430238]&255;return b|0}function dxU(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>24){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5626948+(b*112|0)>>2];c[a+104>>2]=c[5626952+(b*112|0)>>2];c[a+108>>2]=c[5626956+(b*112|0)>>2];d=0;return d|0}function dxV(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<25&(d|0)==0)){e=1;return e|0}c[a>>2]=5626848+(b*112|0);e=0;return e|0}function dxW(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6933248+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dxX(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>46){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7442920+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dxY(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0.0,af=0,ah=0,ai=0,aj=0;e=i;i=i+720|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;c[2426776]=0;c[2424766]=0;c[2424752]=65536;c[2424860]=86016;c[2424836]=118784;c[2424818]=249856;c[2424790]=315392;c[2406964]=316928;c[3530078]=325120;t=(a[9688]|0?339720:333312)|0;c[2414300]=t;u=t;t=0;while(1){if((t|0)>=1024){break}v=9638528+(t<<2)|0;if((c[v>>2]|0)==0){w=84684;break}else{t=t+1|0}}do{if((w|0)==84684){t=gGq(u)|0;c[v>>2]=t;if((t|0)==0){break}gGz(t|0,0,u|0);c[2426776]=t;gGz(t|0,0,u|0);c[2424766]=t;c[2424752]=t+65536;c[2424860]=t+86016;c[2424836]=t+118784;c[2424818]=t+249856;c[2424790]=t+315392;c[2406964]=t+316928;c[3530078]=t+325120;x=t+333312|0;c[2385382]=x;y=a[9688]|0?534:0;c[2414300]=t+((y*12|0)+333312);c[2439082]=x;c[2439083]=x+(y<<1);c[2439084]=x+(y<<1<<1);c[2439085]=x+((y*3|0)<<1);c[2439086]=x+(y<<2<<1);c[2439087]=x+((y*5|0)<<1);y=r+108|0;x=r+100|0;z=0;A=t;while(1){t=A+(z<<13)|0;if((c[3542200]|0)==0){B=1;w=84836;break}c[y>>2]=0;c[x>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,z)|0;if((c[y>>2]|0)!=0){C=c[x>>2]|0;c[s>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](s,z,0)|0;if((C|0)<1){B=1;w=84828;break}if((gzL(t,0,z)|0)!=0){B=1;w=84833;break}}t=z+1|0;if((t|0)>=5){w=84693;break}z=t;A=c[2424766]|0}if((w|0)==84693){A=c[2424752]|0;if((c[3542200]|0)==0){B=1;i=e;return B|0}z=p+108|0;c[z>>2]=0;x=p+100|0;c[x>>2]=0;y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[y&16383](p,5)|0;do{if((c[z>>2]|0)!=0){y=c[x>>2]|0;c[q>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](q,5,0)|0;if((y|0)<1){B=1;i=e;return B|0}if((gzL(A,0,5)|0)==0){break}else{B=1}i=e;return B|0}}while(0);A=c[2424860]|0;if((c[3542200]|0)==0){B=1;i=e;return B|0}x=n+108|0;c[x>>2]=0;z=n+100|0;c[z>>2]=0;y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[y&16383](n,6)|0;do{if((c[x>>2]|0)!=0){y=c[z>>2]|0;c[o>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](o,6,0)|0;if((y|0)<1){B=1;i=e;return B|0}if((gzL(A,0,6)|0)==0){break}else{B=1}i=e;return B|0}}while(0);A=l+108|0;z=l+100|0;x=0;while(1){y=(c[2424836]|0)+(x<<13)|0;t=x+7|0;if((c[3542200]|0)==0){B=1;w=84817;break}c[A>>2]=0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,t)|0;if((c[A>>2]|0)!=0){C=c[z>>2]|0;c[m>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](m,t,0)|0;if((C|0)<1){B=1;w=84816;break}if((gzL(y,0,t)|0)!=0){B=1;w=84821;break}}t=x+1|0;if((t|0)<6){x=t}else{w=84702;break}}if((w|0)==84816){i=e;return B|0}else if((w|0)==84817){i=e;return B|0}else if((w|0)==84821){i=e;return B|0}else if((w|0)==84702){x=j+108|0;z=j+100|0;A=0;while(1){t=(c[2424818]|0)+(A<<13)|0;y=A+13|0;if((c[3542200]|0)==0){B=1;w=84840;break}c[x>>2]=0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,y)|0;if((c[x>>2]|0)!=0){C=c[z>>2]|0;c[k>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](k,y,0)|0;if((C|0)<1){B=1;w=84818;break}if((gzL(t,0,y)|0)!=0){B=1;w=84824;break}}y=A+1|0;if((y|0)<4){A=y}else{w=84708;break}}if((w|0)==84708){A=f+108|0;z=f+100|0;x=0;while(1){y=(c[2424790]|0)+(x<<8)|0;t=x+17|0;if((c[3542200]|0)==0){B=1;w=84827;break}c[A>>2]=0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,t)|0;if((c[A>>2]|0)!=0){C=c[z>>2]|0;c[g>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](g,t,0)|0;if((C|0)<1){B=1;w=84823;break}if((gzL(y,0,t)|0)!=0){B=1;w=84839;break}}t=x+1|0;if((t|0)<6){x=t}else{E=0;w=84719;break}}if((w|0)==84719){while(1){w=0;if((E|0)>=1024){B=1;w=84825;break}F=9638528+(E<<2)|0;if((c[F>>2]|0)==0){break}else{E=E+1|0;w=84719}}if((w|0)==84825){i=e;return B|0}x=gGq(1024)|0;c[F>>2]=x;if((x|0)==0){B=1;i=e;return B|0}gGz(x|0,0,1024);z=x;A=c[2424790]|0;t=0;do{y=d[A+t|0]|0;C=d[A+(t+256)|0]|0;D=d[A+(t+512)|0]|0;c[z+(t<<2)>>2]=(-(C>>>1&1)&31)+(-(C&1)&14)+(-(C>>>2&1)&67)+(-(C>>>3&1)&143)<<8|(-(y>>>1&1)&31)+(-(y&1)&14)+(-(y>>>2&1)&67)+(-(y>>>3&1)&143)<<16|(-(D>>>1&1)&31)+(-(D&1)&14)+(-(D>>>2&1)&67)+(-(D>>>3&1)&143);t=t+1|0;}while((t|0)<256);t=c[2406964]|0;D=0;while(1){c[t+(D<<2)>>2]=c[z+((d[A+(D+768)|0]|0)+32<<2)>>2];y=D+1|0;if((y|0)<256){D=y}else{G=0;break}}while(1){c[t+(G+256<<2)>>2]=c[z+((d[A+(G+1024)|0]|0)+16<<2)>>2];D=G+1|0;if((D|0)<256){G=D}else{H=0;break}}while(1){D=H+1280|0;y=A+D|0;c[t+(H+1024<<2)>>2]=c[z+((d[y]|0)<<2)>>2];c[t+(D<<2)>>2]=c[z+((d[y]|0)+64<<2)>>2];c[t+(H+1536<<2)>>2]=c[z+((d[y]|0)+128<<2)>>2];c[t+(H+1792<<2)>>2]=c[z+((d[y]|0)+192<<2)>>2];y=H+1|0;if((y|0)<256){H=y}else{I=0;break}}while(1){if((I|0)>=1024){J=0;break}K=9638528+(I<<2)|0;if((c[K>>2]|0)==(x|0)){w=84730;break}else{I=I+1|0}}if((w|0)==84730){gGr(x);c[K>>2]=0;J=0}while(1){if((J|0)>=1024){B=1;w=84832;break}L=9638528+(J<<2)|0;if((c[L>>2]|0)==0){break}else{J=J+1|0}}if((w|0)==84832){i=e;return B|0}x=gGq(49152)|0;c[L>>2]=x;if((x|0)==0){B=1;i=e;return B|0}gGz(x|0,0,49152);z=c[2424860]|0;gGC(x|0,z|0,8192)|0;t=0;do{A=t<<6;gGz(z+A|0,0,64);y=t<<7;D=y|4;C=0;while(1){M=D+(c[608544+(C<<2)>>2]|0)|0;N=(C<<3)+A|0;O=0;do{P=M+(c[609552+(O<<2)>>2]|0)|0;if(((d[x+((P|0)/8|0)|0]|0)&128>>>((P&7)>>>0)|0)!=0){P=z+(N+O)|0;a[P]=a[P]|2}O=O+1|0;}while((O|0)<8);O=C+1|0;if((O|0)<8){C=O}else{Q=0;break}}do{C=y+(c[608544+(Q<<2)>>2]|0)|0;D=(Q<<3)+A|0;O=0;do{N=C+(c[609552+(O<<2)>>2]|0)|0;if(((d[x+((N|0)/8|0)|0]|0)&128>>>((N&7)>>>0)|0)!=0){N=z+(D+O)|0;a[N]=a[N]|1}O=O+1|0;}while((O|0)<8);Q=Q+1|0;}while((Q|0)<8);t=t+1|0;}while((t|0)<512);t=c[2424836]|0;gGC(x|0,t|0,49152)|0;z=0;do{A=z<<8;gGz(t+A|0,0,256);y=0;do{O=A+(c[609008+(y<<2)>>2]|0)|0;D=(y<<4)+A|0;C=0;do{N=O+(c[597864+(C<<2)>>2]|0)|0;if(((d[x+((N|0)/8|0)|0]|0)&128>>>((N&7)>>>0)|0)!=0){N=t+(D+C)|0;a[N]=a[N]|4}C=C+1|0;}while((C|0)<16);y=y+1|0;}while((y|0)<16);y=A+131072|0;C=0;do{D=y+(c[609008+(C<<2)>>2]|0)|0;O=(C<<4)+A|0;N=0;do{M=D+(c[597864+(N<<2)>>2]|0)|0;if(((d[x+((M|0)/8|0)|0]|0)&128>>>((M&7)>>>0)|0)!=0){M=t+(O+N)|0;a[M]=a[M]|2}N=N+1|0;}while((N|0)<16);C=C+1|0;}while((C|0)<16);C=A+262144|0;y=0;do{N=C+(c[609008+(y<<2)>>2]|0)|0;O=(y<<4)+A|0;D=0;do{M=N+(c[597864+(D<<2)>>2]|0)|0;if(((d[x+((M|0)/8|0)|0]|0)&128>>>((M&7)>>>0)|0)!=0){M=t+(O+D)|0;a[M]=a[M]|1}D=D+1|0;}while((D|0)<16);y=y+1|0;}while((y|0)<16);z=z+1|0;}while((z|0)<512);z=c[2424818]|0;gGC(x|0,z|0,32768)|0;t=0;while(1){y=t<<8;gGz(z+y|0,0,256);A=t<<9;C=0;do{D=1<<3-C;O=(c[605936+(C<<2)>>2]|0)+A|0;N=0;do{M=O+(c[608544+(N<<2)>>2]|0)|0;P=(N<<4)+y|0;R=0;do{S=M+(c[609552+(R<<2)>>2]|0)|0;if(((d[x+((S|0)/8|0)|0]|0)&128>>>((S&7)>>>0)|0)!=0){S=z+(P+R)|0;a[S]=(d[S]|0|D)&255}R=R+1|0;}while((R|0)<16);N=N+1|0;}while((N|0)<16);C=C+1|0;}while((C|0)<4);C=t+1|0;if((C|0)<256){t=C}else{T=0;break}}while(1){if((T|0)>=1024){break}U=9638528+(T<<2)|0;if((c[U>>2]|0)==(x|0)){w=84761;break}else{T=T+1|0}}if((w|0)==84761){gGr(x);c[U>>2]=0}fwR(0);t=c[2439330]|0;if((t|0)!=0){z=t;gGC(9706056,z|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];z=c[3528484]|0;c[2076596]=z;C=c[2417276]|0;c[3541536]=C;c[1836236]=0;y=c[2424766]|0;A=0;N=0;while(1){c[t+76+(N<<2)>>2]=y+(N<<8);D=A+1&65535;if((D&65535)>159){V=0;W=0;break}else{A=D;N=D&65535}}while(1){N=y+(W<<8)|0;c[t+76+(W+512<<2)>>2]=N;c[t+76+(W+768<<2)>>2]=N;N=V+1&65535;if((N&65535)>159){break}else{V=N;W=N&65535}}N=y+52224|0;c[t+892>>2]=N;c[t+1916>>2]=N;N=y+53248|0;c[t+908>>2]=N;A=y+53504|0;c[t+912>>2]=A;x=y+53760|0;c[t+916>>2]=x;D=y+54016|0;c[t+920>>2]=D;O=y+54272|0;c[t+924>>2]=O;R=y+54528|0;c[t+928>>2]=R;P=y+54784|0;c[t+932>>2]=P;M=y+55040|0;c[t+936>>2]=M;S=y+55296|0;c[t+940>>2]=S;X=y+55552|0;c[t+944>>2]=X;Y=y+55808|0;c[t+948>>2]=Y;Z=y+56064|0;c[t+952>>2]=Z;_=y+56320|0;c[t+956>>2]=_;$=y+56576|0;c[t+960>>2]=$;aa=y+56832|0;c[t+964>>2]=aa;ab=y+57088|0;c[t+968>>2]=ab;c[t+1932>>2]=N;c[t+1936>>2]=A;c[t+1940>>2]=x;c[t+1944>>2]=D;c[t+1948>>2]=O;c[t+1952>>2]=R;c[t+1956>>2]=P;c[t+1960>>2]=M;c[t+1964>>2]=S;c[t+1968>>2]=X;c[t+1972>>2]=Y;c[t+1976>>2]=Z;c[t+1980>>2]=_;c[t+1984>>2]=$;c[t+1988>>2]=aa;c[t+1992>>2]=ab;ab=y+57344|0;c[t+972>>2]=ab;aa=y+57600|0;c[t+976>>2]=aa;$=y+57856|0;c[t+980>>2]=$;_=y+58112|0;c[t+984>>2]=_;Z=y+58368|0;c[t+988>>2]=Z;Y=y+58624|0;c[t+992>>2]=Y;X=y+58880|0;c[t+996>>2]=X;S=y+59136|0;c[t+1e3>>2]=S;M=y+59392|0;c[t+1004>>2]=M;P=y+59648|0;c[t+1008>>2]=P;R=y+59904|0;c[t+1012>>2]=R;O=y+60160|0;c[t+1016>>2]=O;D=y+60416|0;c[t+1020>>2]=D;x=y+60672|0;c[t+1024>>2]=x;A=y+60928|0;c[t+1028>>2]=A;N=y+61184|0;c[t+1032>>2]=N;c[t+1996>>2]=ab;c[t+2e3>>2]=aa;c[t+2004>>2]=$;c[t+2008>>2]=_;c[t+2012>>2]=Z;c[t+2016>>2]=Y;c[t+2020>>2]=X;c[t+2024>>2]=S;c[t+2028>>2]=M;c[t+2032>>2]=P;c[t+2036>>2]=R;c[t+2040>>2]=O;c[t+2044>>2]=D;c[t+2048>>2]=x;c[t+2052>>2]=A;c[t+2056>>2]=N;N=224;A=224;while(1){x=y+(A<<8)|0;c[t+76+(A+512<<2)>>2]=x;c[t+76+(A+768<<2)>>2]=x;x=N+1&65535;if((x&65535)>239){break}else{N=x;A=x&65535}}c[t+4184>>2]=2452;c[t+4180>>2]=1630;A=t;gGC(A|0,9706056,76)|0;c[2438118]=c[2433530];c[3528484]=z;c[2417276]=C;c[1836236]=-1;fwR(1);A=c[2439331]|0;N=(A|0)==0;if(!N){y=A;gGC(9706056,y|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];y=c[3528485]|0;c[2076596]=y;x=c[2417277]|0;c[3541536]=x;c[1836236]=1;D=c[2424752]|0;O=0;R=0;while(1){c[A+76+(R<<2)>>2]=D+(R<<8);P=O+1&65535;if((P&65535)>31){ac=0;ad=0;break}else{O=P;R=P&65535}}while(1){R=D+(ad<<8)|0;c[A+76+(ad+512<<2)>>2]=R;c[A+76+(ad+768<<2)>>2]=R;R=ac+1&65535;if((R&65535)>31){break}else{ac=R;ad=R&65535}}R=D+16384|0;c[A+332>>2]=R;O=D+16640|0;c[A+336>>2]=O;C=D+16896|0;c[A+340>>2]=C;z=D+17152|0;c[A+344>>2]=z;t=D+17408|0;c[A+348>>2]=t;P=D+17664|0;c[A+352>>2]=P;M=D+17920|0;c[A+356>>2]=M;S=D+18176|0;c[A+360>>2]=S;c[A+1356>>2]=R;c[A+1360>>2]=O;c[A+1364>>2]=C;c[A+1368>>2]=z;c[A+1372>>2]=t;c[A+1376>>2]=P;c[A+1380>>2]=M;c[A+1384>>2]=S;c[A+2380>>2]=R;c[A+3404>>2]=R;c[A+2384>>2]=O;c[A+3408>>2]=O;c[A+2388>>2]=C;c[A+3412>>2]=C;c[A+2392>>2]=z;c[A+3416>>2]=z;c[A+2396>>2]=t;c[A+3420>>2]=t;c[A+2400>>2]=P;c[A+3424>>2]=P;c[A+2404>>2]=M;c[A+3428>>2]=M;c[A+2408>>2]=S;c[A+3432>>2]=S;c[A+4184>>2]=934;c[A+4180>>2]=2812;if(!N){S=A;gGC(S|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=y;c[2417277]=x;c[1836236]=-1;S=a[9680]|0?32e3:0;c[3542220]=11200;M=c[2113008]|0;if((M|0)==0){gGz(14168888,0,252);c[3542223]=S;gGz(14168896,0,16);c[3542234]=~~((+(S|0)*32768.0*8.0+75.0e4)/15.0e5);P=31;ae=32767.0;while(1){c[14169012+(P<<2)>>2]=~~(ae+.5);t=P-1|0;if((t|0)>0){P=t;ae=ae/1.188502227}else{break}}c[3542253]=0;h[1771269]=1.0;h[1771270]=1.0;h[1771271]=1.0;c[3542574]=3;c[3542575]=3;c[3542576]=3;mB(0);P=(c[2113008]|0)+1|0;c[2113008]=P;af=P;ah=a[9680]|0?32e3:0}else{af=M;ah=S}c[3542220]=11200;if((af|0)==1){gGz(14169140,0,252);c[3542286]=ah;gGz(14169148,0,16);c[3542297]=~~((+(ah|0)*32768.0*8.0+75.0e4)/15.0e5);P=31;ae=32767.0;while(1){c[14169264+(P<<2)>>2]=~~(ae+.5);x=P-1|0;if((x|0)>0){P=x;ae=ae/1.188502227}else{break}}c[3542316]=0;h[1771272]=1.0;h[1771273]=1.0;h[1771274]=1.0;c[3542577]=3;c[3542578]=3;c[3542579]=3;mB(1);c[2113008]=(c[2113008]|0)+1}h[1771269]=.25;c[3542574]=3;h[1771270]=.25;c[3542575]=3;h[1771271]=.25;c[3542576]=3;h[1771272]=.25;c[3542577]=3;h[1771273]=.25;c[3542578]=3;h[1771274]=.25;c[3542579]=3;a[9624576]=0;c[2430240]=0;c[2430238]=0;c[2429568]=0;c[2438878]=0;c[2438879]=0;gGz((c[2424766]|0)+52224|0,0,9216);gGz((c[2424752]|0)+16384|0,0,2048);P=c[2439330]|0;S=(P|0)==0;if(!S){M=P;gGC(9706056,M|0,76)|0}M=c[2438118]|0;c[2433530]=M;x=c[3528484]|0;c[2076596]=x;y=c[2417276]|0;c[3541536]=y;c[1836236]=0;gGz(9706056,0,76);if(!S){S=P;gGC(S|0,9706056,76)|0}c[2438118]=M;c[3528484]=x;c[2417276]=y;c[1836236]=-1;mB(0);y=c[2439331]|0;x=(y|0)==0;if(!x){M=y;gGC(9706056,M|0,76)|0}M=c[2438119]|0;c[2433530]=M;S=c[3528485]|0;c[2076596]=S;P=c[2417277]|0;c[3541536]=P;c[1836236]=1;gGz(9706056,0,76);if(!x){x=y;gGC(x|0,9706056,76)|0}c[2438119]=M;c[3528485]=S;c[2417277]=P;c[1836236]=-1;mB(1);P=c[642608+(c[2436]<<2)>>2]|0;S=c[P+128>>2]|0;if((c[P+52>>2]&4|0)==0){c[2113068]=S;M=c[P+132>>2]|0;c[2113070]=M;c[2443814]=S;c[2440436]=M;ai=S;aj=M}else{c[2113070]=S;M=c[P+132>>2]|0;c[2113068]=M;c[2440436]=S;c[2443814]=M;ai=M;aj=S}S=ag(ai<<1,aj)|0;M=gGq(S)|0;c[2112926]=M;if((M|0)==0){B=0;i=e;return B|0}gGz(M|0,0,S|0);B=0;i=e;return B|0}else if((w|0)==84823){i=e;return B|0}else if((w|0)==84827){i=e;return B|0}else if((w|0)==84839){i=e;return B|0}}else if((w|0)==84818){i=e;return B|0}else if((w|0)==84824){i=e;return B|0}else if((w|0)==84840){i=e;return B|0}}}else if((w|0)==84828){i=e;return B|0}else if((w|0)==84833){i=e;return B|0}else if((w|0)==84836){i=e;return B|0}}}while(0);c[2426776]=0;B=1;i=e;return B|0}function dxZ(){var b=0,d=0,e=0,f=0;fwZ();c[2113008]=0;c[2076598]=0;c[2383582]=0;c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}b=c[2426776]|0;d=0;while(1){if((d|0)>=1024){break}e=9638528+(d<<2)|0;if((c[e>>2]|0)==(b|0)){f=84846;break}else{d=d+1|0}}if((f|0)==84846){gGr(b);c[e>>2]=0}c[2424752]=0;c[2424766]=0;c[2426776]=0;c[2424790]=0;c[2424818]=0;c[2424836]=0;c[2424860]=0;gGz(9756328,0,24);c[2406964]=0;c[3530078]=0;a[9547672]=0;c[2430238]=0;c[2438879]=0;c[2438878]=0;c[2429568]=0;c[2430240]=0;return 0}function dx_(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if((a[9624576]|0)==0){d=0;e=66666;f=5e4;g=0}else{a[9624576]=0;c[2430240]=0;c[2430238]=0;c[2429568]=0;c[2438878]=0;c[2438879]=0;gGz((c[2424766]|0)+52224|0,0,9216);gGz((c[2424752]|0)+16384|0,0,2048);h=c[2439330]|0;i=(h|0)==0;if(!i){j=h;gGC(9706056,j|0,76)|0}j=c[2438118]|0;c[2433530]=j;k=c[3528484]|0;c[2076596]=k;l=c[2417276]|0;c[3541536]=l;c[1836236]=0;gGz(9706056,0,76);if(!i){i=h;gGC(i|0,9706056,76)|0}c[2438118]=j;c[3528484]=k;c[2417276]=l;c[1836236]=-1;mB(0);l=c[2439331]|0;k=(l|0)==0;if(!k){j=l;gGC(9706056,j|0,76)|0}j=c[2438119]|0;c[2433530]=j;i=c[3528485]|0;c[2076596]=i;h=c[2417277]|0;c[3541536]=h;c[1836236]=1;gGz(9706056,0,76);if(!k){k=l;gGC(k|0,9706056,76)|0}c[2438119]=j;c[3528485]=i;c[2417277]=h;c[1836236]=-1;mB(1);d=0;e=66666;f=5e4;g=0}while(1){h=c[2439330]|0;if((h|0)!=0){i=h;gGC(9706056,i|0,76)|0}b[4853030]=c[2426515]&65535;i=c[2438118]|0;c[2433530]=i;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;j=8-d|0;k=(e|0)/(j|0)|0;do{if((k|0)<1){m=0}else{if((a[h+4188|0]|0)==0){l=gfc(k)|0;c[2433530]=(c[2433530]|0)+l;m=l;break}else{c[2433530]=i+k;m=k;break}}}while(0);k=e-m|0;if((d|0)==3){a[14125144]=-41;a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0}else if((d|0)==7){a[14125144]=-49;a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0}i=c[1836236]|0;h=c[9757320+(i<<2)>>2]|0;if((h|0)!=0){l=h;gGC(l|0,9706056,76)|0}c[9752472+(i<<2)>>2]=c[2433530];c[14113936+(i<<2)>>2]=c[2076596];c[9669104+(i<<2)>>2]=c[3541536];c[1836236]=-1;i=c[2439331]|0;if((i|0)!=0){l=i;gGC(9706056,l|0,76)|0}b[4853030]=c[2426515]&65535;l=c[2438119]|0;c[2433530]=l;c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;h=(f|0)/(j|0)|0;do{if((h|0)<1){n=0}else{if((a[i+4188|0]|0)==0){o=gfc(h)|0;c[2433530]=(c[2433530]|0)+o;n=o;break}else{c[2433530]=l+h;n=h;break}}}while(0);a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0;h=c[1836236]|0;l=c[9757320+(h<<2)>>2]|0;if((l|0)!=0){i=l;gGC(i|0,9706056,76)|0}c[9752472+(h<<2)>>2]=c[2433530];c[14113936+(h<<2)>>2]=c[2076596];c[9669104+(h<<2)>>2]=c[3541536];c[1836236]=-1;p=c[2112964]|0;q=(p|0)==0;if(q){r=g}else{h=a[9688]|0?66:0;mF(9756328,p+(g<<1<<1)|0,h,0);r=h+g|0}h=d+1|0;if((h|0)<8){d=h;e=k;f=f-n|0;g=r}else{break}}do{if(!q){g=a[9688]|0?534:0;if((g|0)==(r|0)){break}mF(9756328,p+(r<<1<<1)|0,g-r|0,0)}}while(0);if((c[2112968]|0)==0){return 0}dx$()|0;return 0}function dx$(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;if((a[9547672]|0)!=0){e=c[2406964]|0;f=c[3530078]|0;g=0;do{h=c[e+(g<<2)>>2]|0;c[f+(g<<2)>>2]=h>>8<<3&2016|h>>>3&31|h>>16<<8&63488;g=g+1|0;}while((g|0)<2048)}g=c[2424766]|0;f=c[2112926]|0;e=c[2424836]|0;h=0;do{i=(h>>>1&496)-(c[2438879]|0)|0;j=(h<<4&496)-(c[2438878]|0)|0;k=(i|0)<-15?i+512|0:i;i=d[g+(h+56320)|0]|0;l=i<<1&256|d[g+(h+55296)|0];m=c[2429568]<<5|i&31;n=((j|0)<-15?j+512|0:j)-16|0;j=(i&32|0)!=0;do{if((i&64|0)==0){if(j){SB(f,l,k,n,m,3,1024,e);break}else{Sz(f,l,k,n,m,3,1024,e);break}}else{if(j){SF(f,l,k,n,m,3,1024,e);break}else{SD(f,l,k,n,m,3,1024,e);break}}}while(0);h=h+1|0;}while((h|0)<1024);h=c[2424818]|0;e=124;do{m=d[g+(e+52224)|0]|0;n=d[g+(e+52225)|0]|0;k=n&15;l=d[g+(e+52227)|0]|0;j=(d[g+(e+52226)|0]|0)-16|0;i=n>>>6;n=(i|0)==2?3:i;while(1){i=j+(n<<4)|0;o=n+m|0;SH(f,o,l,i,k,4,15,256,h);if((i|0)>240){SH(f,o,l,i-256|0,k,4,15,256,h)}if((n|0)>0){n=n-1|0}else{break}}e=e-4|0;}while((e|0)>-1);e=c[2424860]|0;h=c[2424790]|0;n=64;k=0;while(1){l=k&255;m=l+8|0;j=l|1;i=(m>>>0>j>>>0?m:j)-l|0;l=d[g+(n+54272)|0]|0;j=l<<1&256|d[g+(n+53248)|0];if((j|0)!=32){m=l<<2&252;l=n<<3&248;o=n>>>2&248;p=o-8|0;q=l+8|0;r=e+(j<<6)|0;j=o-16|0;while(1){o=j<<8;s=r;t=l;while(1){u=d[s]|m;if((a[h+(u|768)|0]|0)!=15){b[f+((t|o)<<1)>>1]=u&65535}u=t+1|0;if((u|0)>=(q|0)){break}s=s+1|0;t=u}t=j+1|0;if((t|0)<(p|0)){r=r+i|0;j=t}else{break}}}j=n+1|0;if((j|0)>=960){break}n=j;k=k+8&255}if((c[2430240]|0)==0){v=c[3530078]|0;R8(v);return 0}k=(ag(c[2113070]|0,c[2113068]|0)|0)-1|0;n=k>>1;if((n|0)>0){w=0}else{v=c[3530078]|0;R8(v);return 0}do{h=f+(w<<1)|0;e=b[h>>1]|0;g=f+(k-w<<1)|0;b[h>>1]=b[g>>1]|0;b[g>>1]=e;w=w+1|0;}while((w|0)<(n|0));v=c[3530078]|0;R8(v);return 0}function dx0(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=i;i=i+128|0;e=d|0;f=d+32|0;g=d+48|0;h=d+64|0;j=d+80|0;k=d+96|0;l=d+112|0;m=(b|0)==0;if(!m){c[b>>2]=169249}if((a&96|0)==0){i=d;return 0}gGz(l|0,0,12);n=l|0;c[n>>2]=(c[2424766]|0)+52224;o=l+4|0;c[o>>2]=9216;p=l+12|0;c[p>>2]=77168;gj[c[2076592]&4095](l)|0;c[n>>2]=(c[2424752]|0)+16384;c[o>>2]=2048;c[p>>2]=584312;gj[c[2076592]&4095](l)|0;fw$(a);l=d+16|0;do{if((a&64|0)!=0){do{if(!m){if((c[b>>2]|0)>=169110){break}c[b>>2]=169110}}while(0);if((c[2113008]|0)<=0){break}p=e|0;o=e+4|0;n=e+8|0;q=e+12|0;r=0;do{cC(l|0,531144,(s=i,i=i+8|0,c[s>>2]=r,s)|0)|0;i=s;c[p>>2]=14168888+(r*252|0);c[o>>2]=252;c[n>>2]=0;c[q>>2]=l;gj[c[2076592]&4095](e)|0;r=r+1|0;}while((r|0)<(c[2113008]|0))}}while(0);gGz(k|0,0,12);c[k>>2]=9720960;c[k+4>>2]=4;c[k+12>>2]=567792;gj[c[2076592]&4095](k)|0;gGz(j|0,0,12);c[j>>2]=9720952;c[j+4>>2]=4;c[j+12>>2]=551432;gj[c[2076592]&4095](j)|0;gGz(h|0,0,12);c[h>>2]=9718272;c[h+4>>2]=4;c[h+12>>2]=537096;gj[c[2076592]&4095](h)|0;gGz(g|0,0,12);c[g>>2]=9755512;c[g+4>>2]=4;c[g+12>>2]=523832;gj[c[2076592]&4095](g)|0;gGz(f|0,0,12);c[f>>2]=9755516;c[f+4>>2]=4;c[f+12>>2]=510208;gj[c[2076592]&4095](f)|0;i=d;return 0}function dx1(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>24){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4320884+(b*112|0)>>2];c[a+104>>2]=c[4320888+(b*112|0)>>2];c[a+108>>2]=c[4320892+(b*112|0)>>2];d=0;return d|0}function dx2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<25&(d|0)==0)){e=1;return e|0}c[a>>2]=4320784+(b*112|0);e=0;return e|0}function dx3(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>24){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4318084+(b*112|0)>>2];c[a+104>>2]=c[4318088+(b*112|0)>>2];c[a+108>>2]=c[4318092+(b*112|0)>>2];d=0;return d|0}function dx4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<25&(d|0)==0)){e=1;return e|0}c[a>>2]=4317984+(b*112|0);e=0;return e|0}function dx5(b){b=b|0;var c=0,d=0;c=b&65535;switch(c|0){case 49155:case 49156:{d=a[9635368+(c&1^1)|0]|0;break};case 49152:case 49153:case 49154:{d=a[9550688+(c&3)|0]|0;break};default:{d=0}}return d|0}function dx6(c,d){c=c|0;d=d|0;switch(c&65535|0){case 55301:{b[4859292]=b[4859292]&255|(d&255)<<8;return};case 55303:{a[9720112]=(d&255)>>>4&1;a[9720104]=(d&255)>>>5&1;a[9718576]=(d&255)>>>6&1;return};case 55297:{b[4858828]=b[4858828]&255|(d&255)<<8;return};case 55298:{b[4858832]=b[4858832]&-256|d&255;return};case 51200:{a[9718568]=d;return};case 51204:{a[9718560]=(d&255)>>>7;return};case 55296:{b[4858828]=b[4858828]&-256|d&255;return};case 55299:{b[4858832]=b[4858832]&255|(d&255)<<8;return};case 55300:{b[4859292]=b[4859292]&-256|d&255;return};default:{return}}}function dx7(b){b=b|0;return(b<<16>>16==24576?a[9718568]|0:0)|0}function dx8(b,d){b=b|0;d=d|0;var e=0,f=0;e=b&65535;if((e|0)==32768|(e|0)==32769){b=d&255;if((e&1|0)==0){c[3542228]=b&15;return}f=c[3542228]|0;if((f|0)>15){return}do{if((f|0)<14){if((f|0)!=13){if((a[14168916+f|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(0,f,b);return}else if((e|0)==32770|(e|0)==32771){TR(e&1,d&255);return}else{return}}function dx9(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>23){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2879540+(b*112|0)>>2];c[a+104>>2]=c[2879544+(b*112|0)>>2];c[a+108>>2]=c[2879548+(b*112|0)>>2];d=0;return d|0}function dya(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<24&(d|0)==0)){e=1;return e|0}c[a>>2]=2879440+(b*112|0);e=0;return e|0}function dyb(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6932928+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dyc(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>47){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7442344+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dyd(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0.0,am=0,an=0;e=i;i=i+960|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;c[2426774]=0;c[2424764]=0;c[2424750]=65536;c[2424858]=86016;c[2424834]=118784;c[2424816]=184320;c[2424808]=249856;c[2424802]=315392;c[2424788]=339968;c[2438292]=342016;c[2406962]=342272;c[3530076]=346368;x=(a[9688]|0?353668:350464)|0;c[2414298]=x;y=x;x=0;while(1){if((x|0)>=1024){break}z=9638528+(x<<2)|0;if((c[z>>2]|0)==0){A=186;break}else{x=x+1|0}}do{if((A|0)==186){x=gGq(y)|0;c[z>>2]=x;if((x|0)==0){break}gGz(x|0,0,y|0);c[2426774]=x;gGz(x|0,0,y|0);c[2424764]=x;c[2424750]=x+65536;c[2424858]=x+86016;c[2424834]=x+118784;c[2424816]=x+184320;c[2424808]=x+249856;c[2424802]=x+315392;c[2424788]=x+339968;c[2438292]=x+342016;c[2406962]=x+342272;c[3530076]=x+346368;B=x+350464|0;c[2385380]=B;C=a[9688]|0?534:0;c[2414298]=x+((C*6|0)+350464);c[2439078]=B;c[2439079]=B+(C<<1);c[2439080]=B+(C<<1<<1);C=v+108|0;B=v+100|0;if((c[3542200]|0)==0){D=1;i=e;return D|0}c[C>>2]=0;c[B>>2]=0;E=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[E&16383](v,0)|0;do{if((c[C>>2]|0)!=0){E=c[B>>2]|0;c[w>>2]=9534384;F=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[F&16383](w,0,0)|0;if((E|0)<1){D=1;i=e;return D|0}if((gzL(x,0,0)|0)==0){break}else{D=1}i=e;return D|0}}while(0);x=(c[2424764]|0)+16384|0;if((c[3542200]|0)==0){D=1;i=e;return D|0}c[C>>2]=0;c[B>>2]=0;E=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[E&16383](v,1)|0;do{if((c[C>>2]|0)!=0){E=c[B>>2]|0;c[w>>2]=9534384;F=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[F&16383](w,1,0)|0;if((E|0)<1){D=1;i=e;return D|0}if((gzL(x,0,1)|0)==0){break}else{D=1}i=e;return D|0}}while(0);x=(c[2424764]|0)+32768|0;if((c[3542200]|0)==0){D=1;i=e;return D|0}c[C>>2]=0;c[B>>2]=0;E=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[E&16383](v,2)|0;do{if((c[C>>2]|0)!=0){E=c[B>>2]|0;c[w>>2]=9534384;F=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[F&16383](w,2,0)|0;if((E|0)<1){D=1;i=e;return D|0}if((gzL(x,0,2)|0)==0){break}else{D=1}i=e;return D|0}}while(0);x=c[2424750]|0;if((c[3542200]|0)==0){D=1;i=e;return D|0}B=t+108|0;c[B>>2]=0;C=t+100|0;c[C>>2]=0;E=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[E&16383](t,3)|0;do{if((c[B>>2]|0)!=0){E=c[C>>2]|0;c[u>>2]=9534384;F=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[F&16383](u,3,0)|0;if((E|0)<1){D=1;i=e;return D|0}if((gzL(x,0,3)|0)==0){break}else{D=1}i=e;return D|0}}while(0);x=c[2424858]|0;if((c[3542200]|0)==0){D=1;i=e;return D|0}C=r+108|0;c[C>>2]=0;B=r+100|0;c[B>>2]=0;E=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[E&16383](r,4)|0;do{if((c[C>>2]|0)!=0){E=c[B>>2]|0;c[s>>2]=9534384;F=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[F&16383](s,4,0)|0;if((E|0)<1){D=1;i=e;return D|0}if((gzL(x,0,4)|0)==0){break}else{D=1}i=e;return D|0}}while(0);x=c[2424834]|0;if((c[3542200]|0)==0){D=1;i=e;return D|0}B=p+108|0;c[B>>2]=0;C=p+100|0;c[C>>2]=0;E=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[E&16383](p,5)|0;do{if((c[B>>2]|0)!=0){E=c[C>>2]|0;c[q>>2]=9534384;F=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[F&16383](q,5,0)|0;if((E|0)<1){D=1;i=e;return D|0}if((gzL(x,0,5)|0)==0){break}else{D=1}i=e;return D|0}}while(0);x=n+108|0;C=n+100|0;B=l+108|0;E=l+100|0;F=j+108|0;G=j+100|0;H=0;while(1){I=H<<14;J=(c[2424816]|0)+I|0;K=H+6|0;if((c[3542200]|0)==0){D=1;A=351;break}c[x>>2]=0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,K)|0;if((c[x>>2]|0)!=0){L=c[C>>2]|0;c[o>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](o,K,0)|0;if((L|0)<1){D=1;A=352;break}if((gzL(J,0,K)|0)!=0){D=1;A=353;break}}K=(c[2424808]|0)+I|0;J=H+8|0;if((c[3542200]|0)==0){D=1;A=354;break}c[B>>2]=0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,J)|0;if((c[B>>2]|0)!=0){L=c[E>>2]|0;c[m>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](m,J,0)|0;if((L|0)<1){D=1;A=355;break}if((gzL(K,0,J)|0)!=0){D=1;A=336;break}}J=(c[2424802]|0)+I|0;I=H+10|0;if((c[3542200]|0)==0){D=1;A=337;break}c[F>>2]=0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,I)|0;if((c[F>>2]|0)!=0){K=c[G>>2]|0;c[k>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](k,I,0)|0;if((K|0)<1){D=1;A=338;break}if((gzL(J,0,I)|0)!=0){D=1;A=334;break}}I=H+1|0;if((I|0)<2){H=I}else{A=205;break}}if((A|0)==205){H=f+108|0;G=f+100|0;F=0;while(1){E=(c[2424788]|0)+(F<<8)|0;B=F+12|0;if((c[3542200]|0)==0){D=1;A=356;break}c[H>>2]=0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,B)|0;if((c[H>>2]|0)!=0){C=c[G>>2]|0;c[g>>2]=9534384;x=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[x&16383](g,B,0)|0;if((C|0)<1){D=1;A=357;break}if((gzL(E,0,B)|0)!=0){D=1;A=358;break}}B=F+1|0;if((B|0)<8){F=B}else{N=0;A=224;break}}if((A|0)==224){while(1){A=0;if((N|0)>=1024){D=1;A=359;break}O=9638528+(N<<2)|0;if((c[O>>2]|0)==0){break}else{N=N+1|0;A=224}}if((A|0)==359){i=e;return D|0}F=gGq(32768)|0;c[O>>2]=F;if((F|0)==0){D=1;i=e;return D|0}gGz(F|0,0,32768);G=c[2424858]|0;gGC(F|0,G|0,8192)|0;H=0;do{B=H<<6;gGz(G+B|0,0,64);E=H<<7;C=E|4;x=0;while(1){I=C+(c[609168+(x<<2)>>2]|0)|0;J=(x<<3)+B|0;K=0;do{L=I+(c[610736+(K<<2)>>2]|0)|0;if((d[F+((L|0)/8|0)|0]&128>>>((L&7)>>>0)|0)!=0){L=G+(J+K)|0;a[L]=a[L]|2}K=K+1|0;}while((K|0)<8);K=x+1|0;if((K|0)<8){x=K}else{P=0;break}}do{x=E+(c[609168+(P<<2)>>2]|0)|0;C=(P<<3)+B|0;K=0;do{J=x+(c[610736+(K<<2)>>2]|0)|0;if((d[F+((J|0)/8|0)|0]&128>>>((J&7)>>>0)|0)!=0){J=G+(C+K)|0;a[J]=a[J]|1}K=K+1|0;}while((K|0)<8);P=P+1|0;}while((P|0)<8);H=H+1|0;}while((H|0)<512);H=c[2424834]|0;gGC(F|0,H|0,16384)|0;G=0;do{B=G<<10;gGz(H+B|0,0,1024);E=G<<11;K=E|4;C=0;while(1){x=K+(c[609168+(C<<2)>>2]|0)|0;J=(C<<5)+B|0;I=0;do{L=x+(c[610736+(I<<2)>>2]|0)|0;if((d[F+((L|0)/8|0)|0]&128>>>((L&7)>>>0)|0)!=0){L=H+(J+I)|0;a[L]=a[L]|2}I=I+1|0;}while((I|0)<32);I=C+1|0;if((I|0)<32){C=I}else{Q=0;break}}do{C=E+(c[609168+(Q<<2)>>2]|0)|0;K=(Q<<5)+B|0;I=0;do{J=C+(c[610736+(I<<2)>>2]|0)|0;if((d[F+((J|0)/8|0)|0]&128>>>((J&7)>>>0)|0)!=0){J=H+(K+I)|0;a[J]=a[J]|1}I=I+1|0;}while((I|0)<32);Q=Q+1|0;}while((Q|0)<32);G=G+1|0;}while((G|0)<64);G=c[2424816]|0;gGC(F|0,G|0,32768)|0;H=0;do{B=H<<8;gGz(G+B|0,0,256);E=H<<9;I=0;do{K=1<<3-I;C=(c[605936+(I<<2)>>2]|0)+E|0;J=0;do{x=C+(c[609168+(J<<2)>>2]|0)|0;L=(J<<4)+B|0;M=0;do{R=x+(c[609552+(M<<2)>>2]|0)|0;if((d[F+((R|0)/8|0)|0]&128>>>((R&7)>>>0)|0)!=0){R=G+(L+M)|0;a[R]=(d[R]|K)&255}M=M+1|0;}while((M|0)<16);J=J+1|0;}while((J|0)<16);I=I+1|0;}while((I|0)<4);H=H+1|0;}while((H|0)<256);H=c[2424808]|0;gGC(F|0,H|0,32768)|0;I=0;do{B=I<<8;gGz(H+B|0,0,256);E=I<<9;J=0;do{K=1<<3-J;C=(c[605936+(J<<2)>>2]|0)+E|0;M=0;do{L=C+(c[609168+(M<<2)>>2]|0)|0;x=(M<<4)+B|0;R=0;do{S=L+(c[609552+(R<<2)>>2]|0)|0;if((d[F+((S|0)/8|0)|0]&128>>>((S&7)>>>0)|0)!=0){S=H+(x+R)|0;a[S]=(d[S]|K)&255}R=R+1|0;}while((R|0)<16);M=M+1|0;}while((M|0)<16);J=J+1|0;}while((J|0)<4);I=I+1|0;}while((I|0)<256);I=c[2438292]|0;H=0;while(1){if((a[G+H|0]|0)!=0){a[I+(H>>8)|0]=1}J=H+1|0;if((J|0)<65536){H=J}else{T=0;break}}while(1){if((T|0)>=1024){U=0;break}V=9638528+(T<<2)|0;if((c[V>>2]|0)==(F|0)){A=267;break}else{T=T+1|0}}if((A|0)==267){gGr(F);c[V>>2]=0;U=0}while(1){if((U|0)>=1024){D=1;A=361;break}W=9638528+(U<<2)|0;if((c[W>>2]|0)==0){break}else{U=U+1|0}}if((A|0)==361){i=e;return D|0}F=gGq(1024)|0;c[W>>2]=F;if((F|0)==0){D=1;i=e;return D|0}gGz(F|0,0,1024);H=F;I=c[2424788]|0;G=0;do{J=d[I+G|0]|0;B=d[I+(G+256)|0]|0;E=d[I+(G+512)|0]|0;c[H+(G<<2)>>2]=J<<20|J<<16|B<<12|B<<8|E|E<<4;G=G+1|0;}while((G|0)<256);G=I+768|0;c[2424788]=G;E=c[2406962]|0;c[E>>2]=c[H+((d[G]|192)<<2)>>2];G=1;while(1){c[E+(G<<2)>>2]=c[H+((d[I+(G+768)|0]|192)<<2)>>2];B=G+1|0;if((B|0)<256){G=B}else{X=256;break}}while(1){c[E+(X<<2)>>2]=c[H+(d[I+(X+768)|0]<<2)>>2];G=X+1|0;if((G|0)<512){X=G}else{Y=512;break}}while(1){c[E+(Y<<2)>>2]=c[H+((d[I+(Y+768)|0]|64)<<2)>>2];G=Y+1|0;if((G|0)<768){Y=G}else{Z=768;break}}while(1){c[E+(Z<<2)>>2]=c[H+((d[I+(Z+768)|0]|d[I+(Z+1024)|0]<<4|128)<<2)>>2];G=Z+1|0;if((G|0)<1024){Z=G}else{_=0;break}}while(1){if((_|0)>=1024){break}$=9638528+(_<<2)|0;if((c[$>>2]|0)==(F|0)){A=280;break}else{_=_+1|0}}if((A|0)==280){gGr(F);c[$>>2]=0}fwR(0);I=c[2439330]|0;if((I|0)!=0){H=I;gGC(9706056,H|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];H=c[3528484]|0;c[2076596]=H;E=c[2417276]|0;c[3541536]=E;c[1836236]=0;G=c[2424764]|0;B=0;J=0;while(1){c[I+76+(J<<2)>>2]=G+(J<<8);M=B+1&65535;if((M&65535)>191){aa=0;ab=0;break}else{B=M;J=M&65535}}while(1){J=G+(ab<<8)|0;c[I+76+(ab+512<<2)>>2]=J;c[I+76+(ab+768<<2)>>2]=J;J=aa+1&65535;if((J&65535)>191){break}else{aa=J;ab=J&65535}}J=G+53248|0;c[I+908>>2]=J;B=G+53504|0;c[I+912>>2]=B;F=G+53760|0;c[I+916>>2]=F;M=G+54016|0;c[I+920>>2]=M;K=G+54272|0;c[I+924>>2]=K;C=G+54528|0;c[I+928>>2]=C;R=G+54784|0;c[I+932>>2]=R;x=G+55040|0;c[I+936>>2]=x;c[I+1932>>2]=J;c[I+1936>>2]=B;c[I+1940>>2]=F;c[I+1944>>2]=M;c[I+1948>>2]=K;c[I+1952>>2]=C;c[I+1956>>2]=R;c[I+1960>>2]=x;x=G+57344|0;c[I+972>>2]=x;R=G+57600|0;c[I+976>>2]=R;C=G+57856|0;c[I+980>>2]=C;K=G+58112|0;c[I+984>>2]=K;M=G+58368|0;c[I+988>>2]=M;F=G+58624|0;c[I+992>>2]=F;B=G+58880|0;c[I+996>>2]=B;J=G+59136|0;c[I+1e3>>2]=J;L=G+59392|0;c[I+1004>>2]=L;S=G+59648|0;c[I+1008>>2]=S;ac=G+59904|0;c[I+1012>>2]=ac;ad=G+60160|0;c[I+1016>>2]=ad;ae=G+60416|0;c[I+1020>>2]=ae;af=G+60672|0;c[I+1024>>2]=af;ah=G+60928|0;c[I+1028>>2]=ah;ai=G+61184|0;c[I+1032>>2]=ai;c[I+1996>>2]=x;c[I+2e3>>2]=R;c[I+2004>>2]=C;c[I+2008>>2]=K;c[I+2012>>2]=M;c[I+2016>>2]=F;c[I+2020>>2]=B;c[I+2024>>2]=J;c[I+2028>>2]=L;c[I+2032>>2]=S;c[I+2036>>2]=ac;c[I+2040>>2]=ad;c[I+2044>>2]=ae;c[I+2048>>2]=af;c[I+2052>>2]=ah;c[I+2056>>2]=ai;ai=224;ah=224;while(1){af=G+(ah<<8)|0;c[I+76+(ah+512<<2)>>2]=af;c[I+76+(ah+768<<2)>>2]=af;af=ai+1&65535;if((af&65535)>239){break}else{ai=af;ah=af&65535}}ah=G+61440|0;c[I+1036>>2]=ah;ai=G+61696|0;c[I+1040>>2]=ai;af=G+61952|0;c[I+1044>>2]=af;ae=G+62208|0;c[I+1048>>2]=ae;ad=G+62464|0;c[I+1052>>2]=ad;ac=G+62720|0;c[I+1056>>2]=ac;S=G+62976|0;c[I+1060>>2]=S;L=G+63232|0;c[I+1064>>2]=L;J=G+63488|0;c[I+1068>>2]=J;B=G+63744|0;c[I+1072>>2]=B;F=G+64e3|0;c[I+1076>>2]=F;M=G+64256|0;c[I+1080>>2]=M;K=G+64512|0;c[I+1084>>2]=K;C=G+64768|0;c[I+1088>>2]=C;R=G+65024|0;c[I+1092>>2]=R;x=G+65280|0;c[I+1096>>2]=x;c[I+2060>>2]=ah;c[I+2064>>2]=ai;c[I+2068>>2]=af;c[I+2072>>2]=ae;c[I+2076>>2]=ad;c[I+2080>>2]=ac;c[I+2084>>2]=S;c[I+2088>>2]=L;c[I+2092>>2]=J;c[I+2096>>2]=B;c[I+2100>>2]=F;c[I+2104>>2]=M;c[I+2108>>2]=K;c[I+2112>>2]=C;c[I+2116>>2]=R;c[I+2120>>2]=x;c[I+4184>>2]=950;c[I+4180>>2]=1102;x=I;gGC(x|0,9706056,76)|0;c[2438118]=c[2433530];c[3528484]=H;c[2417276]=E;c[1836236]=-1;fwR(1);x=c[2439331]|0;R=(x|0)==0;if(!R){C=x;gGC(9706056,C|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];C=c[3528485]|0;c[2076596]=C;K=c[2417277]|0;c[3541536]=K;c[1836236]=1;M=c[2424750]|0;F=0;B=0;while(1){c[x+76+(B<<2)>>2]=M+(B<<8);J=F+1&65535;if((J&65535)>63){aj=0;ak=0;break}else{F=J;B=J&65535}}while(1){B=M+(ak<<8)|0;c[x+76+(ak+512<<2)>>2]=B;c[x+76+(ak+768<<2)>>2]=B;B=aj+1&65535;if((B&65535)>63){break}else{aj=B;ak=B&65535}}B=M+16384|0;c[x+332>>2]=B;F=M+16640|0;c[x+336>>2]=F;E=M+16896|0;c[x+340>>2]=E;H=M+17152|0;c[x+344>>2]=H;I=M+17408|0;c[x+348>>2]=I;G=M+17664|0;c[x+352>>2]=G;J=M+17920|0;c[x+356>>2]=J;L=M+18176|0;c[x+360>>2]=L;c[x+1356>>2]=B;c[x+1360>>2]=F;c[x+1364>>2]=E;c[x+1368>>2]=H;c[x+1372>>2]=I;c[x+1376>>2]=G;c[x+1380>>2]=J;c[x+1384>>2]=L;c[x+2380>>2]=B;c[x+3404>>2]=B;c[x+2384>>2]=F;c[x+3408>>2]=F;c[x+2388>>2]=E;c[x+3412>>2]=E;c[x+2392>>2]=H;c[x+3416>>2]=H;c[x+2396>>2]=I;c[x+3420>>2]=I;c[x+2400>>2]=G;c[x+3424>>2]=G;c[x+2404>>2]=J;c[x+3428>>2]=J;c[x+2408>>2]=L;c[x+3432>>2]=L;c[x+4184>>2]=1360;c[x+4180>>2]=3380;if(!R){L=x;gGC(L|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=C;c[2417277]=K;c[1836236]=-1;L=a[9680]|0?32e3:0;c[3542220]=11200;if((c[2113008]|0)==0){gGz(14168888,0,252);c[3542223]=L;gGz(14168896,0,16);c[3542234]=~~((+(L|0)*32768.0*8.0+75.0e4)/15.0e5);L=31;al=32767.0;while(1){c[14169012+(L<<2)>>2]=~~(al+.5);J=L-1|0;if((J|0)>0){L=J;al=al/1.188502227}else{break}}c[3542253]=0;h[1771269]=1.0;h[1771270]=1.0;h[1771271]=1.0;c[3542574]=3;c[3542575]=3;c[3542576]=3;mB(0);c[2113008]=(c[2113008]|0)+1}h[1771269]=.1;c[3542574]=3;h[1771270]=.1;c[3542575]=3;h[1771271]=.1;c[3542576]=3;TS(0,3e6,16384,3,1,0);TS(1,3e6,16384,3,1,1);L=c[2420348]|0;h[L+192>>3]=.36;c[L+200>>2]=3;L=c[2420346]|0;h[L+192>>3]=.36;c[L+200>>2]=3;L=c[642608+(c[2436]<<2)>>2]|0;K=c[L+128>>2]|0;if((c[L+52>>2]&4|0)==0){c[2113068]=K;C=c[L+132>>2]|0;c[2113070]=C;c[2443814]=K;c[2440436]=C;am=K;an=C}else{c[2113070]=K;C=c[L+132>>2]|0;c[2113068]=C;c[2440436]=K;c[2443814]=C;am=C;an=K}K=ag(am<<1,an)|0;C=gGq(K)|0;c[2112926]=C;if((C|0)!=0){gGz(C|0,0,K|0)}a[9624568]=0;gGz((c[2424764]|0)+53248|0,0,12288);gGz((c[2424750]|0)+16384|0,0,2048);a[9718568]=0;a[9718560]=0;a[9718576]=0;a[9720112]=0;a[9720104]=0;b[4858828]=0;b[4858832]=0;b[4859292]=0;K=c[2439330]|0;C=(K|0)==0;if(!C){L=K;gGC(9706056,L|0,76)|0}L=c[2438118]|0;c[2433530]=L;x=c[3528484]|0;c[2076596]=x;R=c[2417276]|0;c[3541536]=R;c[1836236]=0;gGz(9706056,0,76);if(!C){C=K;gGC(C|0,9706056,76)|0}c[2438118]=L;c[3528484]=x;c[2417276]=R;c[1836236]=-1;R=c[2439331]|0;x=(R|0)==0;if(!x){L=R;gGC(9706056,L|0,76)|0}L=c[2438119]|0;c[2433530]=L;C=c[3528485]|0;c[2076596]=C;K=c[2417277]|0;c[3541536]=K;c[1836236]=1;gGz(9706056,0,76);if(!x){x=R;gGC(x|0,9706056,76)|0}c[2438119]=L;c[3528485]=C;c[2417277]=K;c[1836236]=-1;mB(0);D=0;i=e;return D|0}else if((A|0)==356){i=e;return D|0}else if((A|0)==357){i=e;return D|0}else if((A|0)==358){i=e;return D|0}}else if((A|0)==334){i=e;return D|0}else if((A|0)==336){i=e;return D|0}else if((A|0)==337){i=e;return D|0}else if((A|0)==338){i=e;return D|0}else if((A|0)==351){i=e;return D|0}else if((A|0)==352){i=e;return D|0}else if((A|0)==353){i=e;return D|0}else if((A|0)==354){i=e;return D|0}else if((A|0)==355){i=e;return D|0}}}while(0);c[2426774]=0;D=1;i=e;return D|0}function dye(){var b=0,d=0,e=0,f=0;c[2113008]=0;c[2076598]=0;c[2383582]=0;TT();fwZ();c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}b=c[2426774]|0;d=0;while(1){if((d|0)>=1024){break}e=9638528+(d<<2)|0;if((c[e>>2]|0)==(b|0)){f=375;break}else{d=d+1|0}}if((f|0)==375){gGr(b);c[e>>2]=0}c[2424750]=0;c[2424764]=0;c[2426774]=0;c[2424788]=0;c[2424802]=0;c[2424808]=0;c[2424816]=0;c[2424834]=0;c[2424858]=0;gGz(9756312,0,12);c[3530076]=0;c[2406962]=0;c[2438292]=0;a[9547664]=0;return 0}function dyf(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;if((a[9624568]|0)!=0){a[9624568]=0;gGz((c[2424764]|0)+53248|0,0,12288);gGz((c[2424750]|0)+16384|0,0,2048);a[9718568]=0;a[9718560]=0;a[9718576]=0;a[9720112]=0;a[9720104]=0;b[4858828]=0;b[4858832]=0;b[4859292]=0;d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;h=c[2417276]|0;c[3541536]=h;c[1836236]=0;gGz(9706056,0,76);if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=h;c[1836236]=-1;h=c[2439331]|0;g=(h|0)==0;if(!g){f=h;gGC(9706056,f|0,76)|0}f=c[2438119]|0;c[2433530]=f;e=c[3528485]|0;c[2076596]=e;d=c[2417277]|0;c[3541536]=d;c[1836236]=1;gGz(9706056,0,76);if(!g){g=h;gGC(g|0,9706056,76)|0}c[2438119]=f;c[3528485]=e;c[2417277]=d;c[1836236]=-1;mB(0)}a[9550690]=-1;a[9550689]=-1;a[9550688]=-1;d=0;e=-1;f=-1;g=-1;do{e=((a[9633976+d|0]&1)<<d^e&255)&255;f=((a[9631776+d|0]&1)<<d^f&255)&255;g=((a[9629744+d|0]&1)<<d^g&255)&255;d=d+1|0;}while((d|0)<8);a[9550688]=e;a[9550689]=f;a[9550690]=g;g=0;f=0;e=0;while(1){d=c[2439330]|0;if((d|0)!=0){h=d;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;h=c[2438118]|0;c[2433530]=h;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;i=e+1|0;j=((i*66666|0|0)/16|0)-f|0;do{if((j|0)<1){k=0;l=h}else{if((a[d+4188|0]|0)==0){m=gfc(j)|0;n=(c[2433530]|0)+m|0;c[2433530]=n;k=m;l=n;break}else{n=h+j|0;c[2433530]=n;k=j;l=n;break}}}while(0);j=k+f|0;if((e|0)==14){a[14125144]=-41;a[9706117]=1;if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){h=gfc(100)|0;o=h;p=(c[2433530]|0)+h|0}else{o=100;p=l+100|0}c[2433530]=p;a[9706117]=0;q=o+j|0;r=p}else if((e|0)==0){a[14125144]=-49;a[9706117]=1;if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){h=gfc(100)|0;s=h;t=(c[2433530]|0)+h|0}else{s=100;t=l+100|0}c[2433530]=t;a[9706117]=0;q=s+j|0;r=t}else{q=j;r=l}j=c[1836236]|0;h=c[9757320+(j<<2)>>2]|0;if((h|0)!=0){d=h;gGC(d|0,9706056,76)|0}c[9752472+(j<<2)>>2]=r;c[14113936+(j<<2)>>2]=c[2076596];c[9669104+(j<<2)>>2]=c[3541536];c[1836236]=-1;j=c[2439331]|0;if((j|0)!=0){d=j;gGC(9706056,d|0,76)|0}b[4853030]=c[2426515]&65535;d=c[2438119]|0;c[2433530]=d;c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;h=((i*5e4|0|0)/16|0)-g|0;do{if((h|0)<1){u=0}else{if((a[j+4188|0]|0)==0){n=gfc(h)|0;c[2433530]=(c[2433530]|0)+n;u=n;break}else{c[2433530]=d+h;u=h;break}}}while(0);if((e&3|0)==3){a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0}h=c[1836236]|0;d=c[9757320+(h<<2)>>2]|0;if((d|0)!=0){j=d;gGC(j|0,9706056,76)|0}c[9752472+(h<<2)>>2]=c[2433530];c[14113936+(h<<2)>>2]=c[2076596];c[9669104+(h<<2)>>2]=c[3541536];c[1836236]=-1;if((i|0)<16){g=u+g|0;f=q;e=i}else{break}}e=c[2112964]|0;if((e|0)!=0){q=a[9688]|0?534:0;TQ(0,e,q);TQ(1,e,q);mF(9756312,e,q,1)}if((c[2112968]|0)==0){return 0}dyg()|0;return 0}function dyg(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;if((a[9547664]|0)!=0){f=c[2406962]|0;g=c[3530076]|0;h=0;do{i=c[f+(h<<2)>>2]|0;c[g+(h<<2)>>2]=i>>8<<3&2016|i>>>3&31|i>>16<<8&63488;h=h+1|0;}while((h|0)<1024)}if((a[9720112]|0)==0){h=c[2112926]|0;gGz(h|0,0,ag(c[2113068]<<1,c[2113070]|0)|0);j=h}else{h=c[2424802]|0;g=c[2112926]|0;f=c[2424834]|0;i=0;while(1){k=i<<5&480;l=e[4859292]|0;m=l+k|0;n=k-(l&31)|0;do{if((n|0)<=256){l=(i>>>4<<5)-16|0;k=m>>>5&7|l>>>2&56|m>>>1&8064;o=d[h+(k|16384)|0]|0;p=d[h+(k|16448)|0]|0;k=o&63;q=(o&64|0)!=0;if((o&128|0)==0){if(q){SR(g,k,n,l,p,2,256,f);break}else{SP(g,k,n,l,p,2,256,f);break}}else{if(q){SV(g,k,n,l,p,2,256,f);break}else{ST(g,k,n,l,p,2,256,f);break}}}}while(0);n=i+1|0;if((n|0)<128){i=n}else{j=g;break}}}dyk(64);if((a[9720104]|0)!=0){g=c[2424802]|0;i=c[2438292]|0;f=c[2424816]|0;h=0;do{n=h<<4&496;m=h>>5<<4;p=e[4858828]|0;l=p+n|0;k=e[4858832]|0;q=k+m|0;o=n-(p&15)|0;p=k&15;do{if((o|0)<=256){k=d[g+(q&240|l&1792|l>>>4&15|q<<3&14336)|0]|0;if((a[i+k|0]|0)==0){break}SH(j,k,o,m-16-p|0,0,2,0,512,f)}}while(0);h=h+1|0;}while((h|0)<512)}dyk(0);if((a[9718560]|0)==0){r=c[3530076]|0;R8(r);return 0}h=c[2424764]|0;f=c[2424858]|0;i=c[2113070]|0;g=c[2113068]|0;p=c[2424788]|0;m=64;do{o=d[h+(m|54272)|0]|0;q=o<<1&256|d[h+(m|53248)|0];if((q|0)!=36){l=m>>5<<3;k=m<<3&248;n=o<<2&252;o=l-8|0;s=k+8|0;t=k|1;u=(s>>>0>t>>>0?s:t)-k|0;t=f+(q<<6)|0;q=l-16|0;while(1){l=(q|0)<(i|0);v=ag(g,q)|0;w=t;x=k;while(1){do{if((x|q|0)>-1&l&(x|0)<(g|0)){y=d[w]|n;if((a[p+y|0]|0)==15){break}b[j+(v+x<<1)>>1]=y&65535}}while(0);y=x+1|0;if((y|0)>=(s|0)){break}w=w+1|0;x=y}x=q+1|0;if((x|0)<(o|0)){t=t+u|0;q=x}else{break}}}m=m+1|0;}while((m|0)<960);r=c[3530076]|0;R8(r);return 0}function dyh(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=i;i=i+176|0;e=d|0;f=d+32|0;g=d+48|0;h=d+64|0;j=d+80|0;k=d+96|0;l=d+112|0;m=d+128|0;n=d+144|0;o=d+160|0;p=(b|0)==0;if(!p){c[b>>2]=169249}if((a&96|0)==0){i=d;return 0}gGz(o|0,0,12);q=o|0;c[q>>2]=(c[2424764]|0)+53248;r=o+4|0;c[r>>2]=12288;s=o+12|0;c[s>>2]=77168;gj[c[2076592]&4095](o)|0;c[q>>2]=(c[2424750]|0)+16384;c[r>>2]=2048;c[s>>2]=584312;gj[c[2076592]&4095](o)|0;fw$(a);o=d+16|0;do{if((a&64|0)!=0){do{if(!p){if((c[b>>2]|0)>=169110){break}c[b>>2]=169110}}while(0);if((c[2113008]|0)<=0){break}s=e|0;r=e+4|0;q=e+8|0;t=e+12|0;u=0;do{cC(o|0,531144,(v=i,i=i+8|0,c[v>>2]=u,v)|0)|0;i=v;c[s>>2]=14168888+(u*252|0);c[r>>2]=252;c[q>>2]=0;c[t>>2]=o;gj[c[2076592]&4095](e)|0;u=u+1|0;}while((u|0)<(c[2113008]|0))}}while(0);TU(a,b);gGz(n|0,0,12);c[n>>2]=9718568;c[n+4>>2]=1;c[n+12>>2]=567736;gj[c[2076592]&4095](n)|0;gGz(m|0,0,12);c[m>>2]=9718560;c[m+4>>2]=1;c[m+12>>2]=551392;gj[c[2076592]&4095](m)|0;gGz(l|0,0,12);c[l>>2]=9718576;c[l+4>>2]=1;c[l+12>>2]=537064;gj[c[2076592]&4095](l)|0;gGz(k|0,0,12);c[k>>2]=9720112;c[k+4>>2]=1;c[k+12>>2]=523792;gj[c[2076592]&4095](k)|0;gGz(j|0,0,12);c[j>>2]=9720104;c[j+4>>2]=1;c[j+12>>2]=510144;gj[c[2076592]&4095](j)|0;gGz(h|0,0,12);c[h>>2]=9717656;c[h+4>>2]=2;c[h+12>>2]=497600;gj[c[2076592]&4095](h)|0;gGz(g|0,0,12);c[g>>2]=9717664;c[g+4>>2]=2;c[g+12>>2]=485792;gj[c[2076592]&4095](g)|0;gGz(f|0,0,12);c[f>>2]=9718584;c[f+4>>2]=2;c[f+12>>2]=472968;gj[c[2076592]&4095](f)|0;i=d;return 0}function dyi(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>23){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2331004+(b*112|0)>>2];c[a+104>>2]=c[2331008+(b*112|0)>>2];c[a+108>>2]=c[2331012+(b*112|0)>>2];d=0;return d|0}function dyj(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<24&(d|0)==0)){e=1;return e|0}c[a>>2]=2330904+(b*112|0);e=0;return e|0}function dyk(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((a[9718576]|0)==0){return}e=c[2424764]|0;f=c[2112926]|0;g=c[2424808]|0;h=4064;do{i=d[e+(h+61441)|0]|0;do{if((i&64|0)==(b|0)){j=d[e+(h+61440)|0]|0;k=i&15;l=(d[e+(h+61443)|0]|0)-(i<<1&256)|0;m=(d[e+(h+61442)|0]|0)-16|0;n=(i&16|0)!=0;if((i&32|0)==0){if(n){SJ(f,j,l,m,k,4,0,768,g);break}else{SH(f,j,l,m,k,4,0,768,g);break}}else{if(n){SN(f,j,l,m,k,4,0,768,g);break}else{SL(f,j,l,m,k,4,0,768,g);break}}}}while(0);h=h-32|0;}while((h|0)>-1);return}function dyl(b,e){b=b|0;e=e|0;if((b&65535)<=49151){return}a[(c[2405146]|0)+(((d[9638400]|0)>>>3&1)<<14|b&16383)|0]=e;a[9661112]=1;return}function dym(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=b&255;if((f|0)==80){c[3542228]=e&15;return}else if((f|0)==96){b=(e&255)>9?0:e;a[9638408]=b;g=c[2406852]|0;h=c[9757320+(c[1836236]<<2)>>2]|0;i=(d[614784+(b&255)|0]<<14)-32768|0;b=128;j=128;while(1){c[h+76+(j<<2)>>2]=g+(i+(j<<8));k=b+1&65535;if((k&65535)>191){l=128;m=128;break}else{b=k;j=k&65535}}while(1){j=g+(i+(m<<8))|0;c[h+76+(m+512<<2)>>2]=j;c[h+76+(m+768<<2)>>2]=j;j=l+1&65535;if((j&65535)>191){break}else{l=j;m=j&65535}}return}else if((f|0)==81){m=e&255;l=c[3542228]|0;if((l|0)>15){return}do{if((l|0)<14){if((l|0)!=13){if((a[14168916+l|0]|0)==e<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(0,l,m);return}else if((f|0)==112){a[9638400]=e;return}else{return}}function dyn(b){b=b|0;var c=0,d=0;c=b&255;if((c|0)==0){d=(a[9657857]<<2|a[9657856]|a[9657862]<<3|a[9657858]<<4)^24;return d|0}else if((c|0)==16){d=~(a[9657860]<<1|a[9657859]|a[9657861]<<2);return d|0}else if((c|0)==64){d=a[9635360]|0;return d|0}else{d=0;return d|0}return 0}function dyo(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>4){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6499948+(b*112|0)>>2];c[a+104>>2]=c[6499952+(b*112|0)>>2];c[a+108>>2]=c[6499956+(b*112|0)>>2];d=0;return d|0}function dyp(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<5&(d|0)==0)){e=1;return e|0}c[a>>2]=6499848+(b*112|0);e=0;return e|0}function dyq(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6932784+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dyr(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7442224+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dys(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0.0,M=0;e=i;i=i+600|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=0;while(1){if((r|0)>=1024){break}s=9638528+(r<<2)|0;if((c[s>>2]|0)==0){t=563;break}else{r=r+1|0}}do{if((t|0)==563){r=gGq(452704)|0;c[s>>2]=r;if((r|0)==0){break}gGz(r|0,0,452704);c[2426772]=r;r=a[9688]|0?3204:0;u=0;while(1){if((u|0)>=1024){break}v=9638528+(u<<2)|0;if((c[v>>2]|0)==0){t=568;break}else{u=u+1|0}}do{if((t|0)==568){u=gGq(r)|0;c[v>>2]=u;if((u|0)==0){break}gGz(u|0,0,r|0);c[2385378]=u;u=c[2426772]|0;c[2426612]=u;c[2406852]=u+65536;c[2405146]=u+163840;c[2424786]=u+196608;c[2406960]=u+196640;c[3525072]=u+196704;if((c[3542200]|0)==0){w=1;i=e;return w|0}x=p+108|0;c[x>>2]=0;y=p+100|0;c[y>>2]=0;z=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[z&16383](p,0)|0;do{if((c[x>>2]|0)!=0){z=c[y>>2]|0;c[q>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](q,0,0)|0;if((z|0)<1){w=1;i=e;return w|0}if((gzL(u,0,0)|0)==0){break}else{w=1}i=e;return w|0}}while(0);u=c[2426612]|0;y=u+16384|0;gGC(u|0,y|0,16384)|0;y=c[2406852]|0;if((c[3542200]|0)==0){w=1;i=e;return w|0}u=n+108|0;c[u>>2]=0;x=n+100|0;c[x>>2]=0;z=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[z&16383](n,1)|0;do{if((c[u>>2]|0)!=0){z=c[x>>2]|0;c[o>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](o,1,0)|0;if((z|0)<1){w=1;i=e;return w|0}if((gzL(y,0,1)|0)==0){break}else{w=1}i=e;return w|0}}while(0);y=(c[2406852]|0)+32768|0;if((c[3542200]|0)==0){w=1;i=e;return w|0}x=l+108|0;c[x>>2]=0;u=l+100|0;c[u>>2]=0;z=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[z&16383](l,2)|0;do{if((c[x>>2]|0)!=0){z=c[u>>2]|0;c[m>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](m,2,0)|0;if((z|0)<1){w=1;i=e;return w|0}if((gzL(y,0,2)|0)==0){break}else{w=1}i=e;return w|0}}while(0);y=(c[2406852]|0)+65536|0;if((c[3542200]|0)==0){w=1;i=e;return w|0}u=j+108|0;c[u>>2]=0;x=j+100|0;c[x>>2]=0;z=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[z&16383](j,3)|0;do{if((c[u>>2]|0)!=0){z=c[x>>2]|0;c[k>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](k,3,0)|0;if((z|0)<1){w=1;i=e;return w|0}if((gzL(y,0,3)|0)==0){break}else{w=1}i=e;return w|0}}while(0);y=c[2424786]|0;if((c[3542200]|0)==0){w=1;i=e;return w|0}x=f+108|0;c[x>>2]=0;u=f+100|0;c[u>>2]=0;z=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[z&16383](f,4)|0;do{if((c[x>>2]|0)!=0){z=c[u>>2]|0;c[g>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](g,4,0)|0;if((z|0)<1){w=1;i=e;return w|0}if((gzL(y,0,4)|0)==0){break}else{w=1}i=e;return w|0}}while(0);y=c[2406960]|0;u=c[2424786]|0;x=0;while(1){z=d[u]|0;c[y+(x<<2)>>2]=(-(z>>>2&1)&33)+(-(z>>>3&1)&71)+(-(z>>>4&1)&151)<<8|(-(z>>>1&1)&151)+(-(z&1)&71)|(-(z>>>6&1)&71)+(-(z>>>7)&151)+(-(z>>>5&1)&33)<<16;z=x+1|0;if((z|0)<16){u=u+1|0;x=z}else{break}}fwR(0);x=c[2439330]|0;u=(x|0)==0;if(!u){y=x;gGC(9706056,y|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];y=c[3528484]|0;c[2076596]=y;z=c[2417276]|0;c[3541536]=z;c[1836236]=0;c[x+4184>>2]=318;c[x+4172>>2]=1370;c[x+4176>>2]=464;A=c[2426612]|0;B=0;C=0;while(1){c[x+76+(C<<2)>>2]=A+(C<<8);D=B+1&65535;if((D&65535)>63){E=0;F=0;break}else{B=D;C=D&65535}}while(1){C=A+(F<<8)|0;c[x+76+(F+512<<2)>>2]=C;c[x+76+(F+768<<2)>>2]=C;C=E+1&65535;if((C&65535)>63){break}else{E=C;F=C&65535}}C=A+16384|0;c[x+332>>2]=C;B=A+16640|0;c[x+336>>2]=B;D=A+16896|0;c[x+340>>2]=D;G=A+17152|0;c[x+344>>2]=G;H=A+17408|0;c[x+348>>2]=H;I=A+17664|0;c[x+352>>2]=I;J=A+17920|0;c[x+356>>2]=J;K=A+18176|0;c[x+360>>2]=K;c[x+1356>>2]=C;c[x+1360>>2]=B;c[x+1364>>2]=D;c[x+1368>>2]=G;c[x+1372>>2]=H;c[x+1376>>2]=I;c[x+1380>>2]=J;c[x+1384>>2]=K;if(!u){K=x;gGC(K|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=y;c[2417276]=z;c[1836236]=-1;K=c[2385378]|0;c[2439074]=K;J=a[9688]|0?534:0;c[2439075]=K+(J<<1);c[2439076]=K+(J<<1<<1);J=a[9680]|0?32e3:0;c[3542220]=11200;if((c[2113008]|0)==0){gGz(14168888,0,252);c[3542223]=J;gGz(14168896,0,16);c[3542234]=~~((+(J|0)*32768.0*8.0+671164.0)/1342329.0);J=31;L=32767.0;while(1){c[14169012+(J<<2)>>2]=~~(L+.5);K=J-1|0;if((K|0)>0){J=K;L=L/1.188502227}else{break}}c[3542253]=0;h[1771269]=1.0;h[1771270]=1.0;h[1771271]=1.0;c[3542574]=3;c[3542575]=3;c[3542576]=3;mB(0);c[2113008]=(c[2113008]|0)+1;M=c[2439330]|0}else{M=x}h[1771269]=.5;c[3542574]=3;h[1771270]=.5;c[3542575]=3;h[1771271]=.5;c[3542576]=3;a[9661112]=1;a[9638408]=0;a[9638400]=0;a[9624560]=0;J=(M|0)==0;if(!J){z=M;gGC(9706056,z|0,76)|0}z=c[2438118]|0;c[2433530]=z;y=c[3528484]|0;c[2076596]=y;u=c[2417276]|0;c[3541536]=u;c[1836236]=0;gGz(9706056,0,76);if(!J){J=M;gGC(J|0,9706056,76)|0}c[2438118]=z;c[3528484]=y;c[2417276]=u;c[1836236]=-1;mB(0);gGz((c[2426612]|0)+16384|0,0,1024);gGz(c[2405146]|0,0,32768);gGz(c[3525072]|0,0,256e3);w=0;i=e;return w|0}}while(0);c[2385378]=0;w=1;i=e;return w|0}}while(0);c[2426772]=0;w=1;i=e;return w|0}function dyt(){var a=0,b=0,d=0,e=0,f=0;a=c[2426772]|0;b=0;while(1){if((b|0)>=1024){break}d=9638528+(b<<2)|0;if((c[d>>2]|0)==(a|0)){e=630;break}else{b=b+1|0}}if((e|0)==630){gGr(a);c[d>>2]=0}c[2426772]=0;d=c[2385378]|0;a=0;while(1){if((a|0)>=1024){break}f=9638528+(a<<2)|0;if((c[f>>2]|0)==(d|0)){e=634;break}else{a=a+1|0}}if((e|0)==634){gGr(d);c[f>>2]=0}c[3525072]=0;c[2405146]=0;c[2406852]=0;c[2424786]=0;c[2426612]=0;c[2426772]=0;c[2406960]=0;c[2385378]=0;c[2113008]=0;c[2076598]=0;c[2383582]=0;fwZ();return 0}function dyu(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((a[9624560]|0)!=0){a[9661112]=1;a[9638408]=0;a[9638400]=0;a[9624560]=0;e=c[2439330]|0;f=(e|0)==0;if(!f){g=e;gGC(9706056,g|0,76)|0}g=c[2438118]|0;c[2433530]=g;h=c[3528484]|0;c[2076596]=h;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);if(!f){f=e;gGC(f|0,9706056,76)|0}c[2438118]=g;c[3528484]=h;c[2417276]=i;c[1836236]=-1;mB(0);gGz((c[2426612]|0)+16384|0,0,1024);gGz(c[2405146]|0,0,32768);gGz(c[3525072]|0,0,256e3)}i=c[2439330]|0;if((i|0)!=0){h=i;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;h=c[2438118]|0;c[2433530]=h;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;if((a[i+4188|0]|0)==0){i=gfc(66666)|0;j=(c[2433530]|0)+i|0}else{j=h+66666|0}c[2433530]=j;a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0;j=c[1836236]|0;h=c[9757320+(j<<2)>>2]|0;if((h|0)!=0){i=h;gGC(i|0,9706056,76)|0}c[9752472+(j<<2)>>2]=c[2433530];c[14113936+(j<<2)>>2]=c[2076596];c[9669104+(j<<2)>>2]=c[3541536];c[1836236]=-1;j=c[2112964]|0;if((j|0)!=0){mF(9756296,j,a[9688]|0?534:0,0)}j=c[2112968]|0;if((j|0)==0){return 0}i=c[3525072]|0;if((a[9661112]|0)!=0){h=c[2405146]|0;g=c[2406960]|0;f=0;do{e=f*80|0;k=f*320|0;l=0;do{m=l+e|0;n=d[h+m|0]|0;o=d[h+(m+16384)|0]|0;m=l<<2;c[i+((m|3)+k<<2)>>2]=c[g+((n>>>4<<1&2|n&1|o<<2&4|o>>>4<<3&8)<<2)>>2];c[i+((m|2)+k<<2)>>2]=c[g+((n>>>5<<1&2|n>>>1&1|o>>>1<<2&4|o>>>5<<3&8)<<2)>>2];c[i+((m|1)+k<<2)>>2]=c[g+((o&4|n>>>2&1|n>>>6<<1&2|o>>>6<<3&8)<<2)>>2];c[i+(m+k<<2)>>2]=c[g+((n>>>3&1|n>>>7<<1|o>>>7<<3|o>>>3<<2&4)<<2)>>2];l=l+1|0;}while((l|0)<80);f=f+1|0;}while((f|0)<200)}a[9661112]=0;f=c[2113308]|0;g=(f|0)>3;h=(f|0)==2;l=0;do{k=ag(f,l)|0;e=j+k|0;o=c[i+(l<<2)>>2]|0;n=o>>>16<<8&63488|o>>>8<<3&2016;m=n|o>>>3&31;do{if(g){c[e>>2]=m}else{if(h){b[e>>1]=m&65535;break}else{a[e]=m&255;a[j+(k+1)|0]=n>>>8&255;a[j+(k+2)|0]=0;break}}}while(0);l=l+1|0;}while((l|0)<64e3);return 0}function dyv(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+96|0;g=f|0;h=f+32|0;j=f+48|0;k=f+64|0;l=f+80|0;m=(e|0)==0;if(!m){c[e>>2]=169249}if((b&96|0)==0){i=f;return 0}gGz(l|0,0,12);n=l|0;c[n>>2]=c[2405146];o=l+4|0;c[o>>2]=32768;p=l+12|0;c[p>>2]=151792;gj[c[2076592]&4095](l)|0;c[n>>2]=(c[2426612]|0)+16384;c[o>>2]=1024;c[p>>2]=124672;gj[c[2076592]&4095](l)|0;c[n>>2]=c[3525072];c[o>>2]=256e3;c[p>>2]=124672;gj[c[2076592]&4095](l)|0;fw$(b);l=f+16|0;do{if((b&64|0)!=0){do{if(!m){if((c[e>>2]|0)>=169110){break}c[e>>2]=169110}}while(0);if((c[2113008]|0)<=0){break}p=g|0;o=g+4|0;n=g+8|0;q=g+12|0;r=0;do{cC(l|0,531144,(s=i,i=i+8|0,c[s>>2]=r,s)|0)|0;i=s;c[p>>2]=14168888+(r*252|0);c[o>>2]=252;c[n>>2]=0;c[q>>2]=l;gj[c[2076592]&4095](g)|0;r=r+1|0;}while((r|0)<(c[2113008]|0))}}while(0);gGz(k|0,0,12);c[k>>2]=9638408;c[k+4>>2]=1;c[k+12>>2]=99520;gj[c[2076592]&4095](k)|0;gGz(j|0,0,12);c[j>>2]=9638400;c[j+4>>2]=1;c[j+12>>2]=77112;gj[c[2076592]&4095](j)|0;gGz(h|0,0,12);c[h>>2]=9661112;c[h+4>>2]=1;c[h+12>>2]=584304;gj[c[2076592]&4095](h)|0;h=a[9638408]|0;j=(h&255)>9?0:h;a[9638408]=j;h=c[2406852]|0;k=c[9757320+(c[1836236]<<2)>>2]|0;g=((d[614784+(j&255)|0]|0)<<14)-32768|0;j=128;l=128;while(1){c[k+76+(l<<2)>>2]=h+(g+(l<<8));e=j+1&65535;if((e&65535)>191){t=128;u=128;break}else{j=e;l=e&65535}}while(1){l=h+(g+(u<<8))|0;c[k+76+(u+512<<2)>>2]=l;c[k+76+(u+768<<2)>>2]=l;l=t+1&65535;if((l&65535)>191){break}else{t=l;u=l&65535}}i=f;return 0}function dyw(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;if((d&1046528|0)==450560){f=c[2387230]|0;a[f+(d&2047)|0]=e;g=d&2046;h=b[f+g>>1]|0;f=h&255;i=(h&65535)>>>8;h=(f&15|f<<4)&255;j=(f&-16|(f&255)>>>4)&255;f=(i&15|i<<4&255)&255;i=g>>>1;c[(c[2406958]|0)+(i<<2)>>2]=h<<16|j<<8|f;c[(c[3530074]|0)+(i<<2)>>2]=h<<8&63488|j<<3&2016|f>>>3;return}if((d-464910|0)>>>0<1592){if(!(a[7354984]|0)){return}a[(c[2386492]|0)+(d&2047^1)|0]=e;return}if((d-655360|0)>>>0<88){if(a[7354984]|0){return}a[(c[2443476]|0)+(d&1023)|0]=e;return}if((d|0)==479232|(d|0)==479233){a[c[3528312]|0]=e;f=c[2439330]|0;j=(f|0)==0;if(!j){h=f;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;h=c[2438118]|0;c[2433530]=h;i=c[3528484]|0;c[2076596]=i;g=c[2417276]|0;c[3541536]=g;c[1836236]=0;a[9706117]=1;if(!j){j=f;gGC(j|0,9706056,76)|0}c[2438118]=h;c[3528484]=i;c[2417276]=g;c[1836236]=-1;return}else if((d|0)==479236|(d|0)==479237|(d|0)==479238|(d|0)==479239|(d|0)==479240|(d|0)==479241|(d|0)==479242|(d|0)==479243){if(!(a[7354984]|0)){return}a[(c[2443476]|0)+(d-479236)|0]=e;return}else if((d|0)==524301|(d|0)==524300|(d|0)==524288|(d|0)==524289|(d|0)==524290|(d|0)==524291|(d|0)==524292|(d|0)==524293|(d|0)==524294|(d|0)==524295|(d|0)==524296|(d|0)==524297|(d|0)==524298|(d|0)==524299){g=d>>>1&7;if((g|0)==0|(g|0)==1){a[9579176+g|0]=e;return}else if((g|0)==4){if(a[7354984]|0){return}c[2384372]=223;a[14125144]=c[2384376]&255&-33;a[9706117]=1;return}else if((g|0)==6){a[1385968]=0;a[1508048]=1;return}else{return}}else{return}}function dyx(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;if((d&1046528|0)==450560){f=d&2046;b[(c[2387230]|0)+f>>1]=e;g=e&255;h=(e&65535)>>>8;i=(g&15|g<<4)&255;j=(g&-16|(g&255)>>>4)&255;g=(h&15|h<<4&255)&255;h=f>>>1;c[(c[2406958]|0)+(h<<2)>>2]=i<<16|j<<8|g;c[(c[3530074]|0)+(h<<2)>>2]=i<<8&63488|j<<3&2016|g>>>3;return}if((d-464910|0)>>>0<1592){if(!(a[7354984]|0)){return}b[(c[2386492]|0)+(d&2046)>>1]=e;return}if((d-655360|0)>>>0<88){if(a[7354984]|0){return}b[(c[2443476]|0)+(d&1022)>>1]=e;return}if((d|0)==479232){a[c[3528312]|0]=e&255;g=c[2439330]|0;j=(g|0)==0;if(!j){i=g;gGC(9706056,i|0,76)|0}b[4853030]=c[2426515]&65535;i=c[2438118]|0;c[2433530]=i;h=c[3528484]|0;c[2076596]=h;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;a[9706117]=1;if(!j){j=g;gGC(j|0,9706056,76)|0}c[2438118]=i;c[3528484]=h;c[2417276]=f;c[1836236]=-1;return}else if((d|0)==479236|(d|0)==479238|(d|0)==479240|(d|0)==479242){if(!(a[7354984]|0)){return}b[(c[2443476]|0)+(d-479236)>>1]=e;return}else if((d|0)==524301|(d|0)==524288|(d|0)==524289|(d|0)==524290|(d|0)==524291|(d|0)==524292|(d|0)==524293|(d|0)==524294|(d|0)==524295|(d|0)==524296|(d|0)==524297|(d|0)==524298|(d|0)==524299|(d|0)==524300){f=d>>>1&7;if((f|0)==0|(f|0)==1){a[9579176+f|0]=e&255;return}else if((f|0)==4){if(a[7354984]|0){return}c[2384372]=223;a[14125144]=c[2384376]&255&-33;a[9706117]=1;return}else if((f|0)==6){a[1385968]=0;a[1508048]=1;return}else{return}}else{return}}function dyy(c){c=c|0;var d=0,f=0;do{if((c|0)==524288|(c|0)==524289|(c|0)==524290|(c|0)==524291|(c|0)==524292|(c|0)==524293|(c|0)==524294|(c|0)==524295|(c|0)==524296|(c|0)==524297|(c|0)==524298|(c|0)==524299|(c|0)==524300|(c|0)==524301){d=c>>>1&7;if((d|0)==2|(d|0)==3){f=a[9553888+(d-2)|0]|0;break}else if((d|0)==5){f=a[1508048]&1;break}else{f=-1;break}}else if((c|0)==786432|(c|0)==786433){f=a[9635352+(c&1^1)|0]|0}else if((c|0)==786434){f=(e[4817252]|0)>>>8&255}else if((c|0)==786435){f=b[4817252]&255}else if((c|0)==786436){f=(e[4817248]|0)>>>8&255}else if((c|0)==786437){f=b[4817248]&255}else if((c|0)==786447|(c|0)==786446){f=-1}else{f=0}}while(0);return f|0}function dyz(c){c=c|0;var e=0,f=0,g=0;if((c|0)==524288|(c|0)==524289|(c|0)==524290|(c|0)==524291|(c|0)==524292|(c|0)==524293|(c|0)==524294|(c|0)==524295|(c|0)==524296|(c|0)==524297|(c|0)==524298|(c|0)==524299|(c|0)==524300|(c|0)==524301){e=c>>>1&7;if((e|0)==2|(e|0)==3){f=a[9553888+(e-2)|0]|0}else if((e|0)==5){f=a[1508048]&1}else{f=-1}g=f&255}else if((c|0)==786432){g=(d[9635353]|0)<<8|(d[9635352]|0)}else if((c|0)==786434){g=b[4817252]|0}else if((c|0)==786436){g=b[4817248]|0}else if((c|0)==786446){g=-1}else{g=0}return g|0}function dyA(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=b&65535;switch(f|0){case 16385:{c[2384372]=255;c[2384376]=255;a[9706117]=0;return};case 16387:{c[2384372]=255;if((c[2384376]&255|0)!=255){return}a[9706117]=0;return};case 16391:{b=c[2385952]|0;g=c[9757320+(c[1836236]<<2)>>2]|0;h=((e&255)<<15&32768|65536)-32768|0;i=128;j=128;while(1){c[g+76+(j<<2)>>2]=b+(h+(j<<8));k=i+1&65535;if((k&65535)>255){l=128;m=128;break}else{i=k;j=k&65535}}while(1){j=b+(h+(m<<8))|0;c[g+76+(m+512<<2)>>2]=j;c[g+76+(m+768<<2)>>2]=j;j=l+1&65535;if((j&65535)>255){break}else{l=j;m=j&65535}}return};case 16392:{a[(c[3540984]|0)+5885|0]=e;return};case 16393:{m=c[3540984]|0;l=c[m+5876>>2]|0;if((l|0)!=0){gg[l&4095](c[m+5880>>2]|0,0)}lH(m,d[m+5885|0]|0,e&255);return};case 16408:case 16409:{a[9553888+(f&1)|0]=e;return};case 24576:{Uv(0,e);return};case 16384:{a[1508048]=0;a[1385968]=1;return};default:{return}}}function dyB(b){b=b|0;var e=0,f=0,g=0,h=0;e=b&65535;if((e|0)==16392){b=c[3540984]|0;f=(d[b+5887|0]|0|128)&(d[b+5886|0]|0);if((a[b+5884|0]&2)==0){g=f&255}else{g=(a[(c[b+5828>>2]|0)+100|0]&1|f)&255}h=g|6;return h|0}else if((e|0)==16400|(e|0)==16401){h=a[9579176+(e&1)|0]|0;return h|0}else if((e|0)==16402){h=a[1385968]&1;return h|0}else if((e|0)==16403){h=a[9629737]<<1|a[9629736];return h|0}else if((e|0)==24576){h=c[2113156]&255;return h|0}else{h=0;return h|0}return 0}function dyC(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;switch(b&65535|0){case 58368:{a[9733056]=e;return};case 60416:case 60424:{a[(c[3540984]|0)+5885|0]=e;return};case 60417:case 60425:{b=c[3540984]|0;f=c[b+5876>>2]|0;if((f|0)!=0){gg[f&4095](c[b+5880>>2]|0,0)}lH(b,d[b+5885|0]|0,e&255);return};case 57344:{b=e&255;e=c[2385952]|0;f=c[9757320+(c[1836236]<<2)>>2]|0;g=(b<<14&16384|32768)-32768|0;h=128;i=128;while(1){c[f+76+(i<<2)>>2]=e+(g+(i<<8));j=h+1&65535;if((j&65535)>191){k=128;l=128;break}else{h=j;i=j&65535}}while(1){i=e+(g+(l<<8))|0;c[f+76+(l+512<<2)>>2]=i;c[f+76+(l+768<<2)>>2]=i;i=k+1&65535;if((i&65535)>191){break}else{k=i;l=i&65535}}c[2415126]=9662152;c[2415540]=b&8;return};default:{return}}}function dyD(b){b=b|0;var e=0,f=0,g=0,h=0;e=b&65535;if((e|0)==60416){b=c[3540984]|0;f=(d[b+5887|0]|0|128)&(d[b+5886|0]|0);if((a[b+5884|0]&2)==0){g=f&255}else{g=(a[(c[b+5828>>2]|0)+100|0]&1|f)&255}h=g|6;return h|0}else if((e|0)==63488){a[9706117]=0;h=a[c[3528312]|0]|0;return h|0}else{h=0;return h|0}return 0}function dyE(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6988876+(b*112|0)>>2];c[a+104>>2]=c[6988880+(b*112|0)>>2];c[a+108>>2]=c[6988884+(b*112|0)>>2];d=0;return d|0}function dyF(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=6988776+(b*112|0);e=0;return e|0}function dyG(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6027120+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dyH(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>52){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7111328+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dyI(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0;e=i;i=i+1080|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;a[7354984]=0;c[2415016]=0;c[2388180]=0;c[2385952]=393216;c[2443350]=524288;c[3530880]=589824;c[3530644]=851968;c[3530454]=2949120;c[3530346]=3997696;c[2386666]=5046272;c[3530074]=5177344;c[2414722]=5181440;c[2387994]=5181440;c[2387992]=5183488;c[2406498]=5185536;c[2388298]=5187584;c[2386106]=5244928;c[2387230]=5246976;c[2386492]=5249024;c[2386578]=5251072;c[2443476]=5253120;c[3528312]=5254160;c[2406958]=5254161;c[2411752]=5258257;z=0;while(1){if((z|0)>=1024){break}A=9638528+(z<<2)|0;if((c[A>>2]|0)==0){B=870;break}else{z=z+1|0}}do{if((B|0)==870){z=gGq(5258257)|0;c[A>>2]=z;if((z|0)==0){break}c[2415016]=z;gGz(z|0,0,5258257);c[2388180]=z;c[2385952]=z+393216;c[2443350]=z+524288;c[3530880]=z+589824;c[3530644]=z+851968;c[3530454]=z+2949120;c[3530346]=z+3997696;c[2386666]=z+5046272;c[3530074]=z+5177344;C=z+5181440|0;c[2414722]=C;c[2387994]=C;c[2387992]=z+5183488;c[2406498]=z+5185536;c[2388298]=z+5187584;c[2386106]=z+5244928;c[2387230]=z+5246976;c[2386492]=z+5249024;c[2386578]=z+5251072;c[2443476]=z+5253120;c[3528312]=z+5254160;c[2406958]=z+5254161;C=z+5258257|0;c[2411752]=C;c[2414296]=C;if((R6(z+1|0,0,2)|0)!=0){D=1;i=e;return D|0}if((R6(c[2388180]|0,1,2)|0)!=0){D=1;i=e;return D|0}if((R6((c[2388180]|0)+262145|0,2,2)|0)!=0){D=1;i=e;return D|0}if((R6((c[2388180]|0)+262144|0,3,2)|0)!=0){D=1;i=e;return D|0}z=c[2385952]|0;if((c[3542200]|0)==0){D=1;i=e;return D|0}C=x+108|0;c[C>>2]=0;E=x+100|0;c[E>>2]=0;F=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[F&16383](x,4)|0;do{if((c[C>>2]|0)!=0){F=c[E>>2]|0;c[y>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](y,4,0)|0;if((F|0)<1){D=1;i=e;return D|0}if((gzL(z,0,4)|0)==0){break}else{D=1}i=e;return D|0}}while(0);z=(c[2385952]|0)+65536|0;if((c[3542200]|0)==0){D=1;i=e;return D|0}E=v+108|0;c[E>>2]=0;C=v+100|0;c[C>>2]=0;F=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[F&16383](v,5)|0;do{if((c[E>>2]|0)!=0){F=c[C>>2]|0;c[w>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](w,5,0)|0;if((F|0)<1){D=1;i=e;return D|0}if((gzL(z,0,5)|0)==0){break}else{D=1}i=e;return D|0}}while(0);z=c[3530880]|0;if((c[3542200]|0)==0){D=1;i=e;return D|0}C=t+108|0;c[C>>2]=0;E=t+100|0;c[E>>2]=0;F=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[F&16383](t,6)|0;do{if((c[C>>2]|0)!=0){F=c[E>>2]|0;c[u>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](u,6,0)|0;if((F|0)<1){D=1;i=e;return D|0}if((gzL(z,0,6)|0)==0){break}else{D=1}i=e;return D|0}}while(0);z=(c[3530880]|0)+65536|0;if((c[3542200]|0)==0){D=1;i=e;return D|0}E=r+108|0;c[E>>2]=0;C=r+100|0;c[C>>2]=0;F=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[F&16383](r,7)|0;do{if((c[E>>2]|0)!=0){F=c[C>>2]|0;c[s>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](s,7,0)|0;if((F|0)<1){D=1;i=e;return D|0}if((gzL(z,0,7)|0)==0){break}else{D=1}i=e;return D|0}}while(0);z=c[3530644]|0;if((c[3542200]|0)==0){D=1;i=e;return D|0}C=p+108|0;c[C>>2]=0;E=p+100|0;c[E>>2]=0;F=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[F&16383](p,8)|0;do{if((c[C>>2]|0)!=0){F=c[E>>2]|0;c[q>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](q,8,0)|0;if((F|0)<1){D=1;i=e;return D|0}if((gzL(z,0,8)|0)==0){break}else{D=1}i=e;return D|0}}while(0);z=(c[3530644]|0)+524288|0;if((c[3542200]|0)==0){D=1;i=e;return D|0}E=n+108|0;c[E>>2]=0;C=n+100|0;c[C>>2]=0;F=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[F&16383](n,9)|0;do{if((c[E>>2]|0)!=0){F=c[C>>2]|0;c[o>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](o,9,0)|0;if((F|0)<1){D=1;i=e;return D|0}if((gzL(z,0,9)|0)==0){break}else{D=1}i=e;return D|0}}while(0);z=c[3530454]|0;if((c[3542200]|0)==0){D=1;i=e;return D|0}C=l+108|0;c[C>>2]=0;E=l+100|0;c[E>>2]=0;F=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[F&16383](l,10)|0;do{if((c[C>>2]|0)!=0){F=c[E>>2]|0;c[m>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](m,10,0)|0;if((F|0)<1){D=1;i=e;return D|0}if((gzL(z,0,10)|0)==0){break}else{D=1}i=e;return D|0}}while(0);z=c[3530346]|0;if((c[3542200]|0)==0){D=1;i=e;return D|0}E=j+108|0;c[E>>2]=0;C=j+100|0;c[C>>2]=0;F=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[F&16383](j,11)|0;do{if((c[E>>2]|0)!=0){F=c[C>>2]|0;c[k>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](k,11,0)|0;if((F|0)<1){D=1;i=e;return D|0}if((gzL(z,0,11)|0)==0){break}else{D=1}i=e;return D|0}}while(0);z=c[2386666]|0;if((c[3542200]|0)==0){D=1;i=e;return D|0}C=f+108|0;c[C>>2]=0;E=f+100|0;c[E>>2]=0;F=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[F&16383](f,12)|0;do{if((c[C>>2]|0)!=0){F=c[E>>2]|0;c[g>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](g,12,0)|0;if((F|0)<1){D=1;i=e;return D|0}if((gzL(z,0,12)|0)==0){break}else{D=1}i=e;return D|0}}while(0);z=c[2443350]|0;E=c[2385952]|0;C=0;do{F=E+C|0;G=d[F]|0;H=C>>>9;I=H&1;J=C>>>8;K=(J&1&H|0)==0?G:G^128;G=C>>>11;H=G&1;L=C>>>4;M=L&1;N=C>>>1;O=(N&G&M|0)==0?K:K^64;K=(H&N&((J|-2)^1)|0)==0;P=K?O:O^4;Q=C>>>13;R=(C>>>6|-2)^1;S=(Q&1&L&R|0)==0;L=C>>>2;T=I&L&(G^1);G=(S?P:P^2)^T;P=(M&Q|0)==0;if(P){U=G}else{U=G<<1&2|G&252|G>>>1&1}G=(M&J|0)==0;if(G){V=U&255}else{V=(U>>>2<<3&8|U&243|U>>>3<<2&4)&255}a[F]=V;F=C>>>12;J=(F&1&(Q^1)|0)==0?O:O^32;O=(N&1&R|0)==0?J:J^16;J=(L&1&(F^1)|0)==0?O:O^8;O=K?J:J^4;J=(S?O:O^2)^T;if(P){W=J}else{W=J<<1&2|J&252|J>>>1&1}if(G){X=W}else{X=W>>>2<<3&8|W&243|W>>>3<<2&4}if((I&F|0)==0){Y=X}else{Y=X>>>4<<5&32|X&207|X>>>5<<4&16}if((R&H|0)==0){Z=Y&255}else{Z=(Y>>>6<<7|Y&63|Y>>>7<<6&64)&255}a[z+C|0]=Z;C=C+1|0;}while((C|0)<8192);dy2();fxU(0,425984);if((c[2394]|0)==0){_=c[2112932]|0}else{c[2394]=0;C=c[3532596]|0;c[2112932]=C;z=c[3532592]|0;if((z|0)!=0){gGC(9104152,z|0,280)|0}c[2113054]=c[2113060];_=C}C=c[2388180]|0;z=_|0;E=0;while(1){H=C+E|0;c[z>>2]=H;c[z+131072>>2]=H;H=E+1024|0;if(H>>>0>393215){break}else{z=z+4|0;E=H}}E=c[2388298]|0;z=_+1536|0;C=393216;while(1){H=E+(C-393216)|0;c[z>>2]=H;c[z+65536>>2]=H;c[z+131072>>2]=H;H=C+1024|0;if(H>>>0>448511){break}else{z=z+4|0;C=H}}C=c[2386492]|0;c[_+1752>>2]=C;c[_+67288>>2]=C;c[_+132824>>2]=C;z=C+1024|0;c[_+1756>>2]=z;c[_+67292>>2]=z;c[_+132828>>2]=z;z=c[2387230]|0;c[_+1760>>2]=z;c[_+132832>>2]=z;C=z+1024|0;c[_+1764>>2]=C;c[_+132836>>2]=C;C=c[2387994]|0;c[_+1768>>2]=C;c[_+67304>>2]=C;c[_+132840>>2]=C;z=C+1024|0;c[_+1772>>2]=z;c[_+67308>>2]=z;c[_+132844>>2]=z;z=c[2387992]|0;c[_+1776>>2]=z;c[_+67312>>2]=z;c[_+132848>>2]=z;C=z+1024|0;c[_+1780>>2]=C;c[_+67316>>2]=C;c[_+132852>>2]=C;C=c[2406498]|0;c[_+1784>>2]=C;c[_+67320>>2]=C;c[_+132856>>2]=C;z=C+1024|0;c[_+1788>>2]=z;c[_+67324>>2]=z;c[_+132860>>2]=z;z=c[2443476]|0;c[_+2560>>2]=z;c[_+133632>>2]=z;c[_+196648>>2]=1576;c[_+196728>>2]=3010;c[_+196608>>2]=146;c[_+196688>>2]=3254;z=c[3532592]|0;if((z|0)!=0){gGC(z|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);z=c[2439330]|0;if((z|0)!=0){C=z;gGC(9706056,C|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];C=c[3528484]|0;c[2076596]=C;E=c[2417276]|0;c[3541536]=E;c[1836236]=0;H=c[2385952]|0;R=0;F=0;while(1){c[z+76+(F<<2)>>2]=H+(F<<8);I=R+1&65535;if((I&65535)>31){break}else{R=I;F=I&65535}}F=c[2443350]|0;R=0;I=0;while(1){G=I<<8;c[z+76+(I+512<<2)>>2]=F+G;c[z+76+(I+768<<2)>>2]=H+G;G=R+1&65535;if((G&65535)>31){break}else{R=G;I=G&65535}}I=c[2386106]|0;c[z+204>>2]=I;R=I+256|0;c[z+208>>2]=R;H=I+512|0;c[z+212>>2]=H;F=I+768|0;c[z+216>>2]=F;G=I+1024|0;c[z+220>>2]=G;J=I+1280|0;c[z+224>>2]=J;P=I+1536|0;c[z+228>>2]=P;T=I+1792|0;c[z+232>>2]=T;c[z+1228>>2]=I;c[z+1232>>2]=R;c[z+1236>>2]=H;c[z+1240>>2]=F;c[z+1244>>2]=G;c[z+1248>>2]=J;c[z+1252>>2]=P;c[z+1256>>2]=T;c[z+2252>>2]=I;c[z+3276>>2]=I;c[z+2256>>2]=R;c[z+3280>>2]=R;c[z+2260>>2]=H;c[z+3284>>2]=H;c[z+2264>>2]=F;c[z+3288>>2]=F;c[z+2268>>2]=G;c[z+3292>>2]=G;c[z+2272>>2]=J;c[z+3296>>2]=J;c[z+2276>>2]=P;c[z+3300>>2]=P;c[z+2280>>2]=T;c[z+3304>>2]=T;c[z+4184>>2]=2846;c[z+4180>>2]=998;T=z;gGC(T|0,9706056,76)|0;c[2438118]=c[2433530];c[3528484]=C;c[2417276]=E;c[1836236]=-1;UL(3579545,1676,1504,0);c[2438224]=3579545;c[2433522]=3416;c[2406672]=1752;c[3528468]=9362;c[2443842]=571;h[745398]=1.0;a[3203264]=1;Ux(0,7575,1);c[2407030]=102;c[2407068]=3;c[3541206]=c[2386666];T=c[642608+(c[2436]<<2)>>2]|0;P=c[T+128>>2]|0;if((c[T+52>>2]&4|0)==0){c[2113068]=P;J=c[T+132>>2]|0;c[2113070]=J;c[2443814]=P;c[2440436]=J;$=P;aa=J}else{c[2113070]=P;J=c[T+132>>2]|0;c[2113068]=J;c[2440436]=P;c[2443814]=J;$=J;aa=P}P=ag($<<1,aa)|0;J=gGq(P)|0;c[2112926]=J;if((J|0)!=0){gGz(J|0,0,P|0)}dy5();D=0;i=e;return D|0}}while(0);c[2415016]=0;D=1;i=e;return D|0}function dyJ(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}b=a[7452584]|0;if(b){d=0;e=b&1;while(1){b=14163936+(d<<2)|0;f=c[b>>2]|0;g=c[2113006]|0;if((g|0)==0){h=989}else{i=g-1|0;c[2113006]=i;if((i|0)==0){h=989}}if((h|0)==989){h=0;c[2383474]=0}if((f|0)==0){j=e}else{gGr(f);j=a[7452584]&1}c[b>>2]=0;b=d+1|0;if((b|0)<(j|0)){d=b;e=j}else{break}}}a[7452584]=0;c[2438224]=0;c[2433522]=0;c[2406672]=0;c[3528468]=0;j=c[2406688]|0;if((j|0)!=0){gGr(j);c[2406688]=0}c[2432972]=0;do{if(a[7354984]|0){c[2415126]=9662152;j=c[2408988]|0;if((j|0)!=0){gGz(9662152,0,3224);e=j;j=0;while(1){if((j|0)>=1024){break}k=9638528+(j<<2)|0;if((c[k>>2]|0)==(e|0)){h=1e3;break}else{j=j+1|0}}if((h|0)==1e3){gGr(e);c[k>>2]=0}c[2408988]=0}c[2415126]=9665376;j=c[2408989]|0;if((j|0)==0){break}gGz(9665376,0,3224);d=j;j=0;while(1){if((j|0)>=1024){break}l=9638528+(j<<2)|0;if((c[l>>2]|0)==(d|0)){h=1006;break}else{j=j+1|0}}if((h|0)==1006){gGr(d);c[l>>2]=0}c[2408989]=0}else{Uw(0)}}while(0);if((c[2392]|0)>=0){l=0;do{k=14130368+(l<<2)|0;j=c[k>>2]|0;if((j|0)!=0){gGr(j);c[k>>2]=0}k=14130384+(l<<2)|0;j=c[k>>2]|0;if((j|0)!=0){gGr(j);c[k>>2]=0}l=l+1|0;}while((l|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;fwZ();l=c[2415016]|0;k=0;while(1){if((k|0)>=1024){h=1020;break}m=9638528+(k<<2)|0;if((c[m>>2]|0)==(l|0)){break}else{k=k+1|0}}if((h|0)==1020){c[2415016]=0;a[9733056]=0;a[9720192]=0;a[7354984]=0;return 0}gGr(l);c[m>>2]=0;c[2415016]=0;a[9733056]=0;a[9720192]=0;a[7354984]=0;return 0}function dyK(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;if((a[9624552]|0)!=0){dy5()}f=c[2392]|0;if((f|0)>=0){gGz(8452240,0,((f|0)>0?(f<<2)+4|0:4)|0)}c[2113054]=0;f=c[2385548]|0;if((f|0)>0){gGz(9752472,0,((f|0)>1?f<<2:4)|0)}c[2433530]=0;b[4817252]=-1;b[4817248]=-1;f=0;g=-1;h=-1;do{g=((a[9633960+f|0]&1)<<f^g&65535)&65535;h=((a[9631760+f|0]&1)<<f^h&65535)&65535;f=f+1|0;}while((f|0)<16);b[4817252]=g;b[4817248]=h;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];h=c[3532592]|0;if((h|0)!=0){gGC(9104152,h|0,280)|0}c[2113054]=c[2113060]}h=c[2439330]|0;if((h|0)!=0){g=h;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;g=0;h=0;do{f=(166666-h|0)/(512-g|0)|0;c[2113056]=f;i=RG(f)|0;c[2113054]=(c[2113054]|0)+i;c[2276108]=-1;c[2113056]=-1;h=i+h|0;UF(g*116|0)|0;i=g>>1;f=c[2112926]|0;do{if((f|0)!=0){j=i-16|0;if(!(j>>>0<224&(g&1|0)==0)){break}k=c[2443476]|0;l=e[k+12>>1]|0;m=l<<1&254|l>>>7&1|e[k+10>>1]<<4&256;l=e[k+28>>1]|0;n=l<<1&254|l>>>7&1|e[k+26>>1]<<4&256;l=e[k+44>>1]|0;o=l<<1&254|l>>>7&1|e[k+42>>1]<<4&256;l=e[k+60>>1]|0;p=l<<1&254|l>>>7&1|e[k+58>>1]<<4&256;if((b[k+80>>1]&256)==0){k=c[3530346]|0;l=c[2387992]|0;q=p+i<<1&992;r=q+32|0;s=-16-p|0;t=c[2113068]|0;u=ag(t,j)|0;v=q;do{q=(v<<4&496)-o|0;w=(q|0)<-15?q+512|0:q;q=(v>>5<<4)+s|0;x=b[l+(v<<1)>>1]|0;y=(x&65535)>>>8&240;L1417:do{if((w|0)>=-15&(w|0)<(t|0)){z=(j-((q|0)<-15?q+512|0:q)<<4)+((x&65535)<<8&1048320)|0;A=w;B=0;while(1){if((A|0)>-1&(A|0)<(t|0)){b[f+(A+u<<1)>>1]=y|d[k+(z+B)|0]|768}C=B+1|0;if((C|0)>=16){break L1417}A=A+1|0;B=C}}}while(0);v=v+1|0;}while((v|0)<(r|0));r=c[3530454]|0;v=c[2387994]|0;k=n+i<<1&992;l=k+32|0;s=-16-n|0;y=k;do{k=(y<<4&496)-m|0;w=(k|0)<-15?k+512|0:k;k=(y>>5<<4)+s|0;x=b[v+(y<<1)>>1]|0;q=(x&65535)>>>8&240;L1429:do{if((w|0)>=-15&(w|0)<(t|0)){B=(j-((k|0)<-15?k+512|0:k)<<4)+((x&65535)<<8&1048320)|0;A=w;z=0;while(1){C=a[r+(B+z)|0]|0;if(C<<24>>24!=15&(A|0)>-1&(A|0)<(t|0)){b[f+(A+u<<1)>>1]=q|C&255|512}C=z+1|0;if((C|0)>=16){break L1429}A=A+1|0;z=C}}}while(0);y=y+1|0;}while((y|0)<(l|0))}else{l=c[3530454]|0;y=c[2387994]|0;u=n+i<<1&992;t=u+32|0;r=-16-n|0;v=c[2113068]|0;s=ag(v,j)|0;q=u;do{u=(q<<4&496)-m|0;w=(u|0)<-15?u+512|0:u;u=(q>>5<<4)+r|0;x=b[y+(q<<1)>>1]|0;k=(x&65535)>>>8&240;L1393:do{if((w|0)>=-15&(w|0)<(v|0)){z=(j-((u|0)<-15?u+512|0:u)<<4)+((x&65535)<<8&1048320)|0;A=w;B=0;while(1){if((A|0)>-1&(A|0)<(v|0)){b[f+(A+s<<1)>>1]=k|d[l+(z+B)|0]|512}C=B+1|0;if((C|0)>=16){break L1393}A=A+1|0;B=C}}}while(0);q=q+1|0;}while((q|0)<(t|0));t=c[3530346]|0;q=c[2387992]|0;l=p+i<<1&992;y=l+32|0;r=-16-p|0;m=l;do{l=(m<<4&496)-o|0;n=(l|0)<-15?l+512|0:l;l=(m>>5<<4)+r|0;k=b[q+(m<<1)>>1]|0;w=(k&65535)>>>8&240;L1405:do{if((n|0)>=-15&(n|0)<(v|0)){x=(j-((l|0)<-15?l+512|0:l)<<4)+((k&65535)<<8&1048320)|0;u=n;B=0;while(1){A=a[t+(x+B)|0]|0;if(A<<24>>24!=15&(u|0)>-1&(u|0)<(v|0)){b[f+(u+s<<1)>>1]=w|A&255|768}A=B+1|0;if((A|0)>=16){break L1405}u=u+1|0;B=A}}}while(0);m=m+1|0;}while((m|0)<(y|0))}}}while(0);g=g+1|0;}while((g|0)<512);c[8452200+(c[2394]<<2)>>2]=8193;c[2276080]=256;if((c[2276079]|0)>>>0<256){RH(1)}g=c[2438224]|0;h=gGS(-1597636608,28447,g,(g|0)<0|0?-1:0)|0;g=h;UF(59659)|0;h=c[2443826]|0;if((h|0)<1073676288){c[2443826]=h-g}h=c[2443827]|0;if((h|0)<1073676288){c[2443827]=h-g}h=(c[3528508]|0)-g|0;c[3528508]=(h|0)<0?0:h;h=c[1836236]|0;g=c[9757320+(h<<2)>>2]|0;if((g|0)!=0){f=g;gGC(f|0,9706056,76)|0}c[9752472+(h<<2)>>2]=c[2433530];c[14113936+(h<<2)>>2]=c[2076596];c[9669104+(h<<2)>>2]=c[3541536];c[1836236]=-1;h=c[2394]|0;f=c[14130368+(h<<2)>>2]|0;if((f|0)!=0){gGC(f|0,9104152,280)|0}c[8452240+(h<<2)>>2]=c[2113054];c[2394]=-1;if((c[2112968]|0)!=0){dy8();h=c[2406498]|0;f=c[2112926]|0;g=c[3530880]|0;i=64;do{y=e[h+(i<<1)>>1]|0;m=y&4095;if((m|0)!=0){Sq(f,m,i<<3&248,(i>>5<<3)-16|0,y>>>12,4,15,256,g)}i=i+1|0;}while((i|0)<960);R8(c[3530074]|0)}i=c[2112964]|0;if((i|0)==0){D=c[2386578]|0;E=c[2386492]|0;gGC(D|0,E|0,2048)|0;return 0}g=c[2439330]|0;if((g|0)!=0){f=g;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;gg[c[3542112]&4095](i,a[9688]|0?534:0);i=c[1836236]|0;f=c[9757320+(i<<2)>>2]|0;if((f|0)!=0){g=f;gGC(g|0,9706056,76)|0}c[9752472+(i<<2)>>2]=c[2433530];c[14113936+(i<<2)>>2]=c[2076596];c[9669104+(i<<2)>>2]=c[3541536];c[1836236]=-1;Uu(0,c[2112964]|0,a[9688]|0?534:0);D=c[2386578]|0;E=c[2386492]|0;gGC(D|0,E|0,2048)|0;return 0}function dyL(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;a=c[2443476]|0;d=e[a+12>>1]|0;f=d<<1&254|d>>>7&1|(e[a+10>>1]|0)<<4&256;d=e[a+28>>1]|0;g=d<<1&254|d>>>7&1|(e[a+26>>1]|0)<<4&256;d=e[a+44>>1]|0;h=d<<1&254|d>>>7&1|(e[a+42>>1]|0)<<4&256;d=e[a+60>>1]|0;i=d<<1&254|d>>>7&1|(e[a+58>>1]|0)<<4&256;if((b[a+80>>1]&256)==0){a=c[3530346]|0;d=c[2387992]|0;j=i+16&511;k=c[2112926]|0;l=0;do{m=(l<<4&496)-h|0;n=(l>>5<<4)-j|0;o=e[d+(l<<1)>>1]|0;Sz(k,o&4095,(m|0)<-15?m+512|0:m,(n|0)<-15?n+512|0:n,o>>>12,4,768,a);l=l+1|0;}while((l|0)<1024);l=c[3530454]|0;a=c[2387994]|0;d=g+16&511;j=0;while(1){o=(j<<4&496)-f|0;n=(j>>5<<4)-d|0;m=e[a+(j<<1)>>1]|0;SH(k,m&4095,(o|0)<-15?o+512|0:o,(n|0)<-15?n+512|0:n,m>>>12,4,15,512,l);m=j+1|0;if((m|0)<1024){j=m}else{p=k;break}}}else{k=c[3530454]|0;j=c[2387994]|0;l=g+16&511;g=c[2112926]|0;a=0;do{d=(a<<4&496)-f|0;m=(a>>5<<4)-l|0;n=e[j+(a<<1)>>1]|0;Sz(g,n&4095,(d|0)<-15?d+512|0:d,(m|0)<-15?m+512|0:m,n>>>12,4,512,k);a=a+1|0;}while((a|0)<1024);a=c[3530346]|0;k=c[2387992]|0;j=i+16&511;i=0;while(1){l=(i<<4&496)-h|0;f=(i>>5<<4)-j|0;n=e[k+(i<<1)>>1]|0;SH(g,n&4095,(l|0)<-15?l+512|0:l,(f|0)<-15?f+512|0:f,n>>>12,4,15,768,a);n=i+1|0;if((n|0)<1024){i=n}else{p=g;break}}}dy8();g=c[2406498]|0;i=c[3530880]|0;a=64;do{k=e[g+(a<<1)>>1]|0;j=k&4095;if((j|0)!=0){Sq(p,j,a<<3&248,(a>>5<<3)-16|0,k>>>12,4,15,256,i)}a=a+1|0;}while((a|0)<960);R8(c[3530074]|0);return 0}function dyM(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6469756+(b*112|0)>>2];c[a+104>>2]=c[6469760+(b*112|0)>>2];c[a+108>>2]=c[6469764+(b*112|0)>>2];d=0;return d|0}function dyN(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=6469656+(b*112|0);e=0;return e|0}function dyO(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6461692+(b*112|0)>>2];c[a+104>>2]=c[6461696+(b*112|0)>>2];c[a+108>>2]=c[6461700+(b*112|0)>>2];d=0;return d|0}function dyP(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=6461592+(b*112|0);e=0;return e|0}function dyQ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7039364+(b*112|0)>>2];c[a+104>>2]=c[7039368+(b*112|0)>>2];c[a+108>>2]=c[7039372+(b*112|0)>>2];d=0;return d|0}function dyR(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=7039264+(b*112|0);e=0;return e|0}function dyS(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>32){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6550764+(b*112|0)>>2];c[a+104>>2]=c[6550768+(b*112|0)>>2];c[a+108>>2]=c[6550772+(b*112|0)>>2];d=0;return d|0}function dyT(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<33&(d|0)==0)){e=1;return e|0}c[a>>2]=6550664+(b*112|0);e=0;return e|0}function dyU(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4921672+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dyV(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>52){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7111328+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dyW(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;e=i;i=i+600|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;a[7354984]=1;c[2388180]=0;c[2385952]=393216;c[2443350]=524288;c[3530880]=589824;c[3530644]=851968;c[3530454]=2949120;c[3530346]=3997696;c[2386666]=5046272;c[3530074]=5177344;c[2414722]=5181440;c[2387994]=5181440;c[2387992]=5183488;c[2406498]=5185536;c[2388298]=5187584;c[2386106]=5244928;c[2387230]=5246976;c[2386492]=5249024;c[2386578]=5251072;c[2443476]=5253120;c[3528312]=5254160;c[2406958]=5254161;c[2411752]=5258257;r=gGq(5258257)|0;c[2415016]=r;if((r|0)==0){s=1;i=e;return s|0}gGz(r|0,0,5258257);c[2388180]=r;c[2385952]=r+393216;c[2443350]=r+524288;c[3530880]=r+589824;c[3530644]=r+851968;c[3530454]=r+2949120;c[3530346]=r+3997696;c[2386666]=r+5046272;c[3530074]=r+5177344;t=r+5181440|0;c[2414722]=t;c[2387994]=t;c[2387992]=r+5183488;c[2406498]=r+5185536;c[2388298]=r+5187584;c[2386106]=r+5244928;c[2387230]=r+5246976;c[2386492]=r+5249024;c[2386578]=r+5251072;c[2443476]=r+5253120;c[3528312]=r+5254160;c[2406958]=r+5254161;t=r+5258257|0;c[2411752]=t;c[2414296]=t;if((R6(r+1|0,0,2)|0)!=0){s=1;i=e;return s|0}if((R6(c[2388180]|0,1,2)|0)!=0){s=1;i=e;return s|0}if((R6((c[2388180]|0)+262145|0,2,2)|0)!=0){s=1;i=e;return s|0}if((R6((c[2388180]|0)+262144|0,3,2)|0)!=0){s=1;i=e;return s|0}r=p+108|0;t=p+100|0;u=0;while(1){v=(c[3530880]|0)+(u<<15)|0;w=u+5|0;if((c[3542200]|0)==0){s=1;x=1303;break}c[r>>2]=0;c[t>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,w)|0;if((c[r>>2]|0)!=0){y=c[t>>2]|0;c[q>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](q,w,0)|0;if((y|0)<1){s=1;x=1307;break}if((gzL(v,0,w)|0)!=0){s=1;x=1308;break}}w=u+1|0;if((w|0)<4){u=w}else{x=1180;break}}if((x|0)==1180){u=n+108|0;q=n+100|0;t=l+108|0;r=l+100|0;p=j+108|0;w=j+100|0;v=0;while(1){y=(c[3530644]|0)+(v<<17)|0;z=v+9|0;if((c[3542200]|0)==0){s=1;x=1311;break}c[u>>2]=0;c[q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,z)|0;if((c[u>>2]|0)!=0){A=c[q>>2]|0;c[o>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](o,z,0)|0;if((A|0)<1){s=1;x=1310;break}if((gzL(y,0,z)|0)!=0){s=1;x=1304;break}}z=v<<16;y=(c[3530454]|0)+z|0;A=v+17|0;if((c[3542200]|0)==0){s=1;x=1305;break}c[t>>2]=0;c[r>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,A)|0;if((c[t>>2]|0)!=0){B=c[r>>2]|0;c[m>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](m,A,0)|0;if((B|0)<1){s=1;x=1312;break}if((gzL(y,0,A)|0)!=0){s=1;x=1314;break}}A=(c[3530346]|0)+z|0;z=v+25|0;if((c[3542200]|0)==0){s=1;x=1315;break}c[p>>2]=0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,z)|0;if((c[p>>2]|0)!=0){y=c[w>>2]|0;c[k>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](k,z,0)|0;if((y|0)<1){s=1;x=1302;break}if((gzL(A,0,z)|0)!=0){s=1;x=1296;break}}z=v+1|0;if((z|0)<8){v=z}else{x=1199;break}}if((x|0)==1199){v=c[2385952]|0;if((c[3542200]|0)==0){s=1;i=e;return s|0}k=f+108|0;c[k>>2]=0;w=f+100|0;c[w>>2]=0;p=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[p&16383](f,4)|0;do{if((c[k>>2]|0)!=0){f=c[w>>2]|0;c[g>>2]=9534384;p=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[p&16383](g,4,0)|0;if((f|0)<1){s=1;i=e;return s|0}if((gzL(v,0,4)|0)==0){break}else{s=1}i=e;return s|0}}while(0);v=gGq(131072)|0;g=c[3530644]|0;w=0;do{k=g+w|0;a[k]=~a[k];w=w+1|0;}while((w|0)<1048576);w=c[3530454]|0;gGC(v|0,w|0,131072)|0;g=0;do{k=g<<11;f=w+k|0;p=g<<13;j=v+p|0;gGC(f|0,j|0,2048)|0;j=w+(k+65536)|0;f=v+(p|2048)|0;gGC(j|0,f|0,2048)|0;f=w+(k+32768)|0;j=v+(p|4096)|0;gGC(f|0,j|0,2048)|0;j=w+(k+98304)|0;k=v+(p|6144)|0;gGC(j|0,k|0,2048)|0;g=g+1|0;}while((g|0)<16);g=w+131072|0;gGC(v|0,g|0,131072)|0;g=0;do{k=g<<11;j=w+(k+131072)|0;p=g<<13;f=v+p|0;gGC(j|0,f|0,2048)|0;f=w+(k+196608)|0;j=v+(p|2048)|0;gGC(f|0,j|0,2048)|0;j=w+(k+163840)|0;f=v+(p|4096)|0;gGC(j|0,f|0,2048)|0;f=w+(k+229376)|0;k=v+(p|6144)|0;gGC(f|0,k|0,2048)|0;g=g+1|0;}while((g|0)<16);g=w+262144|0;gGC(v|0,g|0,131072)|0;g=0;do{k=g<<11;f=w+(k+262144)|0;p=g<<13;j=v+p|0;gGC(f|0,j|0,2048)|0;j=w+(k+327680)|0;f=v+(p|2048)|0;gGC(j|0,f|0,2048)|0;f=w+(k+294912)|0;j=v+(p|4096)|0;gGC(f|0,j|0,2048)|0;j=w+(k+360448)|0;k=v+(p|6144)|0;gGC(j|0,k|0,2048)|0;g=g+1|0;}while((g|0)<16);g=w+393216|0;gGC(v|0,g|0,131072)|0;g=0;do{k=g<<11;j=w+(k+393216)|0;p=g<<13;f=v+p|0;gGC(j|0,f|0,2048)|0;f=w+(k+458752)|0;j=v+(p|2048)|0;gGC(f|0,j|0,2048)|0;j=w+(k+425984)|0;f=v+(p|4096)|0;gGC(j|0,f|0,2048)|0;f=w+(k+491520)|0;k=v+(p|6144)|0;gGC(f|0,k|0,2048)|0;g=g+1|0;}while((g|0)<16);g=c[3530346]|0;gGC(v|0,g|0,131072)|0;w=0;do{k=w<<11;f=g+k|0;p=w<<13;j=v+p|0;gGC(f|0,j|0,2048)|0;j=g+(k+65536)|0;f=v+(p|2048)|0;gGC(j|0,f|0,2048)|0;f=g+(k+32768)|0;j=v+(p|4096)|0;gGC(f|0,j|0,2048)|0;j=g+(k+98304)|0;k=v+(p|6144)|0;gGC(j|0,k|0,2048)|0;w=w+1|0;}while((w|0)<16);w=g+131072|0;gGC(v|0,w|0,131072)|0;w=0;do{k=w<<11;j=g+(k+131072)|0;p=w<<13;f=v+p|0;gGC(j|0,f|0,2048)|0;f=g+(k+196608)|0;j=v+(p|2048)|0;gGC(f|0,j|0,2048)|0;j=g+(k+163840)|0;f=v+(p|4096)|0;gGC(j|0,f|0,2048)|0;f=g+(k+229376)|0;k=v+(p|6144)|0;gGC(f|0,k|0,2048)|0;w=w+1|0;}while((w|0)<16);w=g+262144|0;gGC(v|0,w|0,131072)|0;w=0;do{k=w<<11;f=g+(k+262144)|0;p=w<<13;j=v+p|0;gGC(f|0,j|0,2048)|0;j=g+(k+327680)|0;f=v+(p|2048)|0;gGC(j|0,f|0,2048)|0;f=g+(k+294912)|0;j=v+(p|4096)|0;gGC(f|0,j|0,2048)|0;j=g+(k+360448)|0;k=v+(p|6144)|0;gGC(j|0,k|0,2048)|0;w=w+1|0;}while((w|0)<16);w=g+393216|0;gGC(v|0,w|0,131072)|0;w=0;do{k=w<<11;j=g+(k+393216)|0;p=w<<13;f=v+p|0;gGC(j|0,f|0,2048)|0;f=g+(k+458752)|0;j=v+(p|2048)|0;gGC(f|0,j|0,2048)|0;j=g+(k+425984)|0;f=v+(p|4096)|0;gGC(j|0,f|0,2048)|0;f=g+(k+491520)|0;k=v+(p|6144)|0;gGC(f|0,k|0,2048)|0;w=w+1|0;}while((w|0)<16);gGr(v);v=0;while(1){if((v|0)>=1024){break}D=9638528+(v<<2)|0;if((c[D>>2]|0)==0){x=1224;break}else{v=v+1|0}}L1647:do{if((x|0)==1224){v=gGq(1048576)|0;c[D>>2]=v;if((v|0)==0){break}gGz(v|0,0,1048576);w=c[3530880]|0;gGC(v|0,w|0,131072)|0;g=0;do{k=g<<6;gGz(w+k|0,0,64);f=0;do{p=1<<3-f;j=(c[605616+(f<<2)>>2]|0)+k|0;m=0;do{r=j+(c[609008+(m<<2)>>2]|0)|0;t=(m<<3)+k|0;l=0;do{o=r+(c[597864+(l<<2)>>2]|0)|0;if(((d[v+((o|0)/8|0)|0]|0)&128>>>((o&7)>>>0)|0)!=0){o=w+(t+l)|0;a[o]=(d[o]|0|p)&255}l=l+1|0;}while((l|0)<8);m=m+1|0;}while((m|0)<8);f=f+1|0;}while((f|0)<4);g=g+1|0;}while((g|0)<4096);g=c[3530644]|0;gGC(v|0,g|0,1048576)|0;w=0;do{f=w<<8;gGz(g+f|0,0,256);k=0;do{m=1<<3-k;p=(c[603744+(k<<2)>>2]|0)+f|0;j=0;do{l=p+(c[609008+(j<<2)>>2]|0)|0;t=(j<<4)+f|0;r=0;do{o=l+(c[597864+(r<<2)>>2]|0)|0;if(((d[v+((o|0)/8|0)|0]|0)&128>>>((o&7)>>>0)|0)!=0){o=g+(t+r)|0;a[o]=(d[o]|0|m)&255}r=r+1|0;}while((r|0)<16);j=j+1|0;}while((j|0)<16);k=k+1|0;}while((k|0)<4);w=w+1|0;}while((w|0)<8192);w=c[3530454]|0;gGC(v|0,w|0,524288)|0;g=0;do{k=g<<8;gGz(w+k|0,0,256);f=g<<6;j=0;do{m=1<<3-j;p=(c[704200+(j<<2)>>2]|0)+f|0;r=0;do{t=p+(c[605424+(r<<2)>>2]|0)|0;l=(r<<4)+k|0;o=0;do{q=t+(c[605552+(o<<2)>>2]|0)|0;if(((d[v+((q|0)/8|0)|0]|0)&128>>>((q&7)>>>0)|0)!=0){q=w+(l+o)|0;a[q]=(d[q]|0|m)&255}o=o+1|0;}while((o|0)<16);r=r+1|0;}while((r|0)<16);j=j+1|0;}while((j|0)<4);g=g+1|0;}while((g|0)<4096);g=c[3530346]|0;gGC(v|0,g|0,524288)|0;w=0;while(1){j=w<<8;gGz(g+j|0,0,256);k=w<<6;f=0;do{r=1<<3-f;m=(c[704200+(f<<2)>>2]|0)+k|0;p=0;do{o=m+(c[605424+(p<<2)>>2]|0)|0;l=(p<<4)+j|0;t=0;do{q=o+(c[605552+(t<<2)>>2]|0)|0;if(((d[v+((q|0)/8|0)|0]|0)&128>>>((q&7)>>>0)|0)!=0){q=g+(l+t)|0;a[q]=(d[q]|0|r)&255}t=t+1|0;}while((t|0)<16);p=p+1|0;}while((p|0)<16);f=f+1|0;}while((f|0)<4);f=w+1|0;if((f|0)<4096){w=f}else{E=0;break}}while(1){if((E|0)>=1024){break L1647}F=9638528+(E<<2)|0;if((c[F>>2]|0)==(v|0)){break}else{E=E+1|0}}gGr(v);c[F>>2]=0}}while(0);fxU(0,425984);if((c[2394]|0)==0){G=c[2112932]|0}else{c[2394]=0;F=c[3532596]|0;c[2112932]=F;E=c[3532592]|0;if((E|0)!=0){gGC(9104152,E|0,280)|0}c[2113054]=c[2113060];G=F}F=c[2388180]|0;E=G|0;D=0;while(1){w=F+D|0;c[E>>2]=w;c[E+131072>>2]=w;w=D+1024|0;if(w>>>0>393215){break}else{E=E+4|0;D=w}}D=c[2388298]|0;E=G+1536|0;F=393216;while(1){w=D+(F-393216)|0;c[E>>2]=w;c[E+65536>>2]=w;c[E+131072>>2]=w;w=F+1024|0;if(w>>>0>450559){break}else{E=E+4|0;F=w}}F=c[2387230]|0;c[G+1760>>2]=F;c[G+132832>>2]=F;E=F+1024|0;c[G+1764>>2]=E;c[G+132836>>2]=E;E=c[2387994]|0;c[G+1768>>2]=E;c[G+67304>>2]=E;c[G+132840>>2]=E;F=E+1024|0;c[G+1772>>2]=F;c[G+67308>>2]=F;c[G+132844>>2]=F;F=c[2387992]|0;c[G+1776>>2]=F;c[G+67312>>2]=F;c[G+132848>>2]=F;E=F+1024|0;c[G+1780>>2]=E;c[G+67316>>2]=E;c[G+132852>>2]=E;E=c[2406498]|0;c[G+1784>>2]=E;c[G+67320>>2]=E;c[G+132856>>2]=E;F=E+1024|0;c[G+1788>>2]=F;c[G+67324>>2]=F;c[G+132860>>2]=F;F=c[2386492]|0;c[G+1816>>2]=F;c[G+132888>>2]=F;c[G+196648>>2]=1576;c[G+196728>>2]=3010;c[G+196608>>2]=146;c[G+196688>>2]=3254;G=c[3532592]|0;if((G|0)!=0){gGC(G|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);G=c[2439330]|0;F=(G|0)==0;if(!F){E=G;gGC(9706056,E|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];E=c[3528484]|0;c[2076596]=E;D=c[2417276]|0;c[3541536]=D;c[1836236]=0;w=c[2385952]|0;g=0;f=0;while(1){c[G+76+(f<<2)>>2]=w+(f<<8);j=g+1&65535;if((j&65535)>127){H=0;I=0;break}else{g=j;f=j&65535}}while(1){f=w+(I<<8)|0;c[G+76+(I+512<<2)>>2]=f;c[G+76+(I+768<<2)>>2]=f;f=H+1&65535;if((f&65535)>127){J=128;K=128;break}else{H=f;I=f&65535}}while(1){c[G+76+(K<<2)>>2]=w+(K<<8);I=J+1&65535;if((I&65535)>191){L=128;M=128;break}else{J=I;K=I&65535}}while(1){K=w+(M<<8)|0;c[G+76+(M+512<<2)>>2]=K;c[G+76+(M+768<<2)>>2]=K;K=L+1&65535;if((K&65535)>191){break}else{L=K;M=K&65535}}M=c[2386106]|0;c[G+1036>>2]=M;L=M+256|0;c[G+1040>>2]=L;w=M+512|0;c[G+1044>>2]=w;K=M+768|0;c[G+1048>>2]=K;J=M+1024|0;c[G+1052>>2]=J;I=M+1280|0;c[G+1056>>2]=I;H=M+1536|0;c[G+1060>>2]=H;f=M+1792|0;c[G+1064>>2]=f;c[G+2060>>2]=M;c[G+2064>>2]=L;c[G+2068>>2]=w;c[G+2072>>2]=K;c[G+2076>>2]=J;c[G+2080>>2]=I;c[G+2084>>2]=H;c[G+2088>>2]=f;c[G+3084>>2]=M;c[G+4108>>2]=M;c[G+3088>>2]=L;c[G+4112>>2]=L;c[G+3092>>2]=w;c[G+4116>>2]=w;c[G+3096>>2]=K;c[G+4120>>2]=K;c[G+3100>>2]=J;c[G+4124>>2]=J;c[G+3104>>2]=I;c[G+4128>>2]=I;c[G+3108>>2]=H;c[G+4132>>2]=H;c[G+3112>>2]=f;c[G+4136>>2]=f;c[G+4184>>2]=518;c[G+4180>>2]=308;if(!F){F=G;gGC(F|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=E;c[2417276]=D;c[1836236]=-1;UL(3579545,0,1598,0);c[2438224]=3579545;c[2433522]=3416;c[2406672]=1752;c[3528468]=9362;c[2443842]=571;h[745398]=1.0;a[3203264]=1;UB(0,1598,384e3,5908,4);c[2415126]=9662152;h[1207773]=.6;c[2415548]=3;D=c[642608+(c[2436]<<2)>>2]|0;E=c[D+128>>2]|0;if((c[D+52>>2]&4|0)==0){c[2113068]=E;F=c[D+132>>2]|0;c[2113070]=F;c[2443814]=E;c[2440436]=F;N=E;O=F}else{c[2113070]=E;F=c[D+132>>2]|0;c[2113068]=F;c[2440436]=E;c[2443814]=F;N=F;O=E}E=ag(N<<1,O)|0;O=gGq(E)|0;c[2112926]=O;if((O|0)!=0){gGz(O|0,0,E|0)}a[9733056]=0;a[9720192]=0;UA();dy5();s=0;i=e;return s|0}else if((x|0)==1296){i=e;return s|0}else if((x|0)==1302){i=e;return s|0}else if((x|0)==1304){i=e;return s|0}else if((x|0)==1305){i=e;return s|0}else if((x|0)==1310){i=e;return s|0}else if((x|0)==1311){i=e;return s|0}else if((x|0)==1312){i=e;return s|0}else if((x|0)==1314){i=e;return s|0}else if((x|0)==1315){i=e;return s|0}}else if((x|0)==1303){i=e;return s|0}else if((x|0)==1307){i=e;return s|0}else if((x|0)==1308){i=e;return s|0}return 0}function dyX(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((a[9624552]|0)!=0){a[9733056]=0;a[9720192]=0;UA();dy5()}c[2415126]=9662152;d=c[2415557]|0;e=d&3;if((e|0)==3){f=133}else{f=(4e6/(4e6/((c[2415554]|0)/(c[600992+((d>>>3&1)<<4)+(e<<2)>>2]|0)|0|0)|0|0)|0|0)/((c[2424]|0)/100|0|0)|0}e=c[2392]|0;if((e|0)>=0){gGz(8452240,0,((e|0)>0?(e<<2)+4|0:4)|0)}c[2113054]=0;e=c[2385548]|0;if((e|0)>0){gGz(9752472,0,((e|0)>1?e<<2:4)|0)}c[2433530]=0;b[4817252]=16191;b[4817248]=-225;e=0;d=16191;g=-225;do{d=((a[9633960+e|0]&1)<<e^d&65535)&65535;g=((a[9631760+e|0]&1)<<e^g&65535)&65535;e=e+1|0;}while((e|0)<16);b[4817252]=d;b[4817248]=g;if((f|0)>0){g=f-1|0;d=0;e=0;while(1){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];h=c[3532592]|0;if((h|0)!=0){gGC(9104152,h|0,280)|0}c[2113054]=c[2113060]}h=e+1|0;i=((h*166666|0|0)/(f|0)|0)-d|0;c[2113056]=i;j=RG(i)|0;c[2113054]=(c[2113054]|0)+j;c[2276108]=-1;c[2113056]=-1;i=j+d|0;do{if((e|0)==(g|0)){c[8452200+(c[2394]<<2)>>2]=8198;c[2276080]=1536;if((c[2276079]|0)>>>0>=1536){break}RH(6)}}while(0);j=c[2394]|0;k=c[14130368+(j<<2)>>2]|0;if((k|0)!=0){gGC(k|0,9104152,280)|0}c[8452240+(j<<2)>>2]=c[2113054];c[2394]=-1;j=c[2439330]|0;if((j|0)!=0){k=j;gGC(9706056,k|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;UF(ag(66666/(f|0)|0,e)|0)|0;UD();k=c[1836236]|0;j=c[9757320+(k<<2)>>2]|0;if((j|0)!=0){l=j;gGC(l|0,9706056,76)|0}c[9752472+(k<<2)>>2]=c[2433530];c[14113936+(k<<2)>>2]=c[2076596];c[9669104+(k<<2)>>2]=c[3541536];c[1836236]=-1;if((h|0)<(f|0)){d=i;e=h}else{break}}}e=c[2439330]|0;if((e|0)!=0){d=e;gGC(9706056,d|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;d=c[2438224]|0;e=gGS(-747372544,31788,d,(d|0)<0|0?-1:0)|0;d=e;UF(66666)|0;e=c[2443826]|0;if((e|0)<1073676288){c[2443826]=e-d}e=c[2443827]|0;if((e|0)<1073676288){c[2443827]=e-d}e=(c[3528508]|0)-d|0;c[3528508]=(e|0)<0?0:e;e=c[2112964]|0;if((e|0)!=0){gg[c[3542112]&4095](e,a[9688]|0?534:0);Uz(0,c[2112964]|0,a[9688]|0?534:0)}e=c[1836236]|0;d=c[9757320+(e<<2)>>2]|0;if((d|0)!=0){f=d;gGC(f|0,9706056,76)|0}c[9752472+(e<<2)>>2]=c[2433530];c[14113936+(e<<2)>>2]=c[2076596];c[9669104+(e<<2)>>2]=c[3541536];c[1836236]=-1;if((c[2112968]|0)==0){m=c[2386578]|0;n=c[2386492]|0;gGC(m|0,n|0,2048)|0;return 0}dyY()|0;m=c[2386578]|0;n=c[2386492]|0;gGC(m|0,n|0,2048)|0;return 0}function dyY(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;a=c[2443476]|0;d=a;f=a+6|0;g=e[f>>1]|0;if((g&8192|0)==0){h=c[3530346]|0;i=c[2387992]|0;j=g+255&511;g=(e[a+4>>1]|0)+17&511;k=c[2112926]|0;l=0;do{m=(l<<4&496)-j|0;n=(l>>5<<4)-g|0;o=e[i+(l<<1)>>1]|0;Sz(k,o&4095,(m|0)<-15?m+512|0:m,(n|0)<-15?n+512|0:n,o>>>12,4,768,h);l=l+1|0;}while((l|0)<1024);l=c[3530454]|0;h=c[2387994]|0;i=(e[a+2>>1]|0)+253&511;g=(e[d>>1]|0)+17&511;j=0;while(1){o=(j<<4&496)-i|0;n=(j>>5<<4)-g|0;m=e[h+(j<<1)>>1]|0;SH(k,m&4095,(o|0)<-15?o+512|0:o,(n|0)<-15?n+512|0:n,m>>>12,4,15,512,l);m=j+1|0;if((m|0)<1024){j=m}else{p=k;break}}}else{k=c[3530454]|0;j=c[2387994]|0;l=(e[a+2>>1]|0)+253&511;h=(e[d>>1]|0)+17&511;d=c[2112926]|0;g=0;do{i=(g<<4&496)-l|0;m=(g>>5<<4)-h|0;n=e[j+(g<<1)>>1]|0;Sz(d,n&4095,(i|0)<-15?i+512|0:i,(m|0)<-15?m+512|0:m,n>>>12,4,512,k);g=g+1|0;}while((g|0)<1024);g=c[3530346]|0;k=c[2387992]|0;j=(e[f>>1]|0)+255&511;f=(e[a+4>>1]|0)+17&511;a=0;while(1){h=(a<<4&496)-j|0;l=(a>>5<<4)-f|0;n=e[k+(a<<1)>>1]|0;SH(d,n&4095,(h|0)<-15?h+512|0:h,(l|0)<-15?l+512|0:l,n>>>12,4,15,768,g);n=a+1|0;if((n|0)<1024){a=n}else{p=d;break}}}d=(c[2386578]|0)+14|0;a=c[3530644]|0;g=0;do{k=b[d+(g<<1)>>1]|0;if(k<<16>>16==-3840){break}f=b[d+((g|2)<<1)>>1]|0;do{if(f<<16>>16!=0){j=e[d+((g|3)<<1)>>1]|0;n=j&511;l=n>>>0>256?j|-512:n;n=k&511;j=e[d+((g|1)<<1)>>1]|0;h=j&8191;m=(f&65535)>>>12;i=(n>>>0>256?752:240)-n-17|0;if((j&16384|0)==0){SH(p,h,l,i,m,4,15,0,a);break}else{SJ(p,h,l,i,m,4,15,0,a);break}}}while(0);g=g+4|0;}while((g|0)<801);g=c[2406498]|0;a=c[3530880]|0;d=64;do{f=e[g+(d<<1)>>1]|0;k=f&4095;if((k|0)!=0){Sq(p,k,d<<3&248,(d>>5<<3)-16|0,f>>>12,4,15,256,a)}d=d+1|0;}while((d|0)<960);R8(c[3530074]|0);return 0}function dyZ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>35){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5839196+(b*112|0)>>2];c[a+104>>2]=c[5839200+(b*112|0)>>2];c[a+108>>2]=c[5839204+(b*112|0)>>2];d=0;return d|0}function dy_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<36&(d|0)==0)){e=1;return e|0}c[a>>2]=5839096+(b*112|0);e=0;return e|0}function dy$(){var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;d=i;i=i+720|0;e=d|0;f=d+112|0;g=d+120|0;j=d+232|0;k=d+240|0;l=d+352|0;m=d+360|0;n=d+472|0;o=d+480|0;p=d+592|0;q=d+600|0;r=d+712|0;a[7354984]=0;c[2415016]=0;c[2388180]=0;c[2385952]=393216;c[2443350]=524288;c[3530880]=589824;c[3530644]=851968;c[3530454]=2949120;c[3530346]=3997696;c[2386666]=5046272;c[3530074]=5177344;c[2414722]=5181440;c[2387994]=5181440;c[2387992]=5183488;c[2406498]=5185536;c[2388298]=5187584;c[2386106]=5244928;c[2387230]=5246976;c[2386492]=5249024;c[2386578]=5251072;c[2443476]=5253120;c[3528312]=5254160;c[2406958]=5254161;c[2411752]=5258257;s=0;while(1){if((s|0)>=1024){break}t=9638528+(s<<2)|0;if((c[t>>2]|0)==0){u=1393;break}else{s=s+1|0}}do{if((u|0)==1393){s=gGq(5258257)|0;c[t>>2]=s;if((s|0)==0){break}c[2415016]=s;gGz(s|0,0,5258257);c[2388180]=s;c[2385952]=s+393216;c[2443350]=s+524288;c[3530880]=s+589824;c[3530644]=s+851968;c[3530454]=s+2949120;c[3530346]=s+3997696;c[2386666]=s+5046272;c[3530074]=s+5177344;v=s+5181440|0;c[2414722]=v;c[2387994]=v;c[2387992]=s+5183488;c[2406498]=s+5185536;c[2388298]=s+5187584;c[2386106]=s+5244928;c[2387230]=s+5246976;c[2386492]=s+5249024;c[2386578]=s+5251072;c[2443476]=s+5253120;c[3528312]=s+5254160;c[2406958]=s+5254161;v=s+5258257|0;c[2411752]=v;c[2414296]=v;if((R6(s+131073|0,0,2)|0)!=0){w=1;i=d;return w|0}if((R6((c[2388180]|0)+131072|0,1,2)|0)!=0){w=1;i=d;return w|0}if((R6((c[2388180]|0)+1|0,2,2)|0)!=0){w=1;i=d;return w|0}if((R6(c[2388180]|0,3,2)|0)!=0){w=1;i=d;return w|0}if((R6((c[2388180]|0)+262145|0,4,2)|0)!=0){w=1;i=d;return w|0}if((R6((c[2388180]|0)+262144|0,5,2)|0)!=0){w=1;i=d;return w|0}s=c[2385952]|0;if((c[3542200]|0)==0){w=1;i=d;return w|0}v=q+108|0;c[v>>2]=0;x=q+100|0;c[x>>2]=0;y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[y&16383](q,6)|0;do{if((c[v>>2]|0)!=0){y=c[x>>2]|0;c[r>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](r,6,0)|0;if((y|0)<1){w=1;i=d;return w|0}if((gzL(s,0,6)|0)==0){break}else{w=1}i=d;return w|0}}while(0);s=(c[2385952]|0)+65536|0;if((c[3542200]|0)==0){w=1;i=d;return w|0}x=o+108|0;c[x>>2]=0;v=o+100|0;c[v>>2]=0;y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[y&16383](o,7)|0;do{if((c[x>>2]|0)!=0){y=c[v>>2]|0;c[p>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](p,7,0)|0;if((y|0)<1){w=1;i=d;return w|0}if((gzL(s,0,7)|0)==0){break}else{w=1}i=d;return w|0}}while(0);s=c[2385952]|0;v=s+8192|0;gGC(s|0,v|0,24576)|0;v=c[3530880]|0;if((c[3542200]|0)==0){w=1;i=d;return w|0}s=m+108|0;c[s>>2]=0;x=m+100|0;c[x>>2]=0;y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[y&16383](m,8)|0;do{if((c[s>>2]|0)!=0){y=c[x>>2]|0;c[n>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](n,8,0)|0;if((y|0)<1){w=1;i=d;return w|0}if((gzL(v,0,8)|0)==0){break}else{w=1}i=d;return w|0}}while(0);v=(c[3530880]|0)+65536|0;if((c[3542200]|0)==0){w=1;i=d;return w|0}x=k+108|0;c[x>>2]=0;s=k+100|0;c[s>>2]=0;y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[y&16383](k,9)|0;do{if((c[x>>2]|0)!=0){y=c[s>>2]|0;c[l>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](l,9,0)|0;if((y|0)<1){w=1;i=d;return w|0}if((gzL(v,0,9)|0)==0){break}else{w=1}i=d;return w|0}}while(0);if((R6(c[3530644]|0,10,2)|0)!=0){w=1;i=d;return w|0}if((R6((c[3530644]|0)+1|0,11,2)|0)!=0){w=1;i=d;return w|0}if((R6((c[3530644]|0)+262144|0,12,2)|0)!=0){w=1;i=d;return w|0}if((R6((c[3530644]|0)+262145|0,13,2)|0)!=0){w=1;i=d;return w|0}if((R6((c[3530644]|0)+524288|0,14,2)|0)!=0){w=1;i=d;return w|0}if((R6((c[3530644]|0)+524289|0,15,2)|0)!=0){w=1;i=d;return w|0}if((R6((c[3530644]|0)+786432|0,16,2)|0)!=0){w=1;i=d;return w|0}if((R6((c[3530644]|0)+786433|0,17,2)|0)!=0){w=1;i=d;return w|0}if((R6((c[3530454]|0)+1|0,18,2)|0)!=0){w=1;i=d;return w|0}if((R6((c[3530454]|0)+131073|0,19,2)|0)!=0){w=1;i=d;return w|0}if((R6((c[3530454]|0)+262145|0,20,2)|0)!=0){w=1;i=d;return w|0}if((R6((c[3530454]|0)+393217|0,21,2)|0)!=0){w=1;i=d;return w|0}if((R6(c[3530454]|0,22,2)|0)!=0){w=1;i=d;return w|0}if((R6((c[3530454]|0)+131072|0,23,2)|0)!=0){w=1;i=d;return w|0}if((R6((c[3530454]|0)+262144|0,24,2)|0)!=0){w=1;i=d;return w|0}if((R6((c[3530454]|0)+393216|0,25,2)|0)!=0){w=1;i=d;return w|0}if((R6((c[3530346]|0)+1|0,26,2)|0)!=0){w=1;i=d;return w|0}if((R6((c[3530346]|0)+131073|0,27,2)|0)!=0){w=1;i=d;return w|0}if((R6((c[3530346]|0)+262145|0,28,2)|0)!=0){w=1;i=d;return w|0}if((R6((c[3530346]|0)+393217|0,29,2)|0)!=0){w=1;i=d;return w|0}if((R6(c[3530346]|0,30,2)|0)!=0){w=1;i=d;return w|0}if((R6((c[3530346]|0)+131072|0,31,2)|0)!=0){w=1;i=d;return w|0}if((R6((c[3530346]|0)+262144|0,32,2)|0)!=0){w=1;i=d;return w|0}if((R6((c[3530346]|0)+393216|0,33,2)|0)!=0){w=1;i=d;return w|0}v=c[2386666]|0;if((c[3542200]|0)==0){w=1;i=d;return w|0}s=g+108|0;c[s>>2]=0;x=g+100|0;c[x>>2]=0;y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[y&16383](g,34)|0;do{if((c[s>>2]|0)!=0){y=c[x>>2]|0;c[j>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](j,34,0)|0;if((y|0)<1){w=1;i=d;return w|0}if((gzL(v,0,34)|0)==0){break}else{w=1}i=d;return w|0}}while(0);v=(c[2386666]|0)+65536|0;if((c[3542200]|0)==0){w=1;i=d;return w|0}x=e+108|0;c[x>>2]=0;s=e+100|0;c[s>>2]=0;y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[y&16383](e,35)|0;do{if((c[x>>2]|0)!=0){y=c[s>>2]|0;c[f>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](f,35,0)|0;if((y|0)<1){w=1;i=d;return w|0}if((gzL(v,0,35)|0)==0){break}else{w=1}i=d;return w|0}}while(0);v=c[2388180]|0;s=0;do{x=v+(s<<1)|0;y=b[x>>1]|0;b[x>>1]=(y&65535)>>>12<<14&16384|y&-20505|(y&65535)>>>14<<12&4096|(y&65535)>>>3<<4&16|(y&65535)>>>4<<3&8;s=s+1|0;}while((s|0)<196608);s=c[2443350]|0;v=c[2385952]|0;gGC(s|0,v|0,8192)|0;y=0;do{a[v+y|0]=a[s+y|0]^85;y=y+1|0;}while((y|0)<8192);dy2();y=0;while(1){if((y|0)>=1024){A=0;break}B=9638528+(y<<2)|0;if((c[B>>2]|0)==0){u=1456;break}else{y=y+1|0}}do{if((u|0)==1456){y=gGq(131072)|0;c[B>>2]=y;if((y|0)==0){A=0;break}gGz(y|0,0,131072);A=y}}while(0);y=c[2386666]|0;gGC(A|0,y|0,131072)|0;a[y]=a[A]|0;s=1;while(1){a[y+s|0]=a[A+(s>>>13<<15&32768|s&16736255|s>>>15<<13&8192)|0]|0;v=s+1|0;if((v|0)<131072){s=v}else{C=0;break}}while(1){if((C|0)>=1024){break}D=9638528+(C<<2)|0;if((c[D>>2]|0)==(A|0)){u=1462;break}else{C=C+1|0}}if((u|0)==1462){gGr(A);c[D>>2]=0}fxU(0,425984);if((c[2394]|0)==0){E=c[2112932]|0}else{c[2394]=0;s=c[3532596]|0;c[2112932]=s;y=c[3532592]|0;if((y|0)!=0){gGC(9104152,y|0,280)|0}c[2113054]=c[2113060];E=s}s=c[2388180]|0;y=E|0;v=0;while(1){x=s+v|0;c[y>>2]=x;c[y+131072>>2]=x;x=v+1024|0;if(x>>>0>393215){break}else{y=y+4|0;v=x}}v=c[2388298]|0;y=E+1536|0;s=393216;while(1){x=v+(s-393216)|0;c[y>>2]=x;c[y+65536>>2]=x;c[y+131072>>2]=x;x=s+1024|0;if(x>>>0>448511){break}else{y=y+4|0;s=x}}s=c[2386492]|0;c[E+1752>>2]=s;c[E+67288>>2]=s;c[E+132824>>2]=s;y=s+1024|0;c[E+1756>>2]=y;c[E+67292>>2]=y;c[E+132828>>2]=y;y=c[2387230]|0;c[E+1760>>2]=y;c[E+132832>>2]=y;s=y+1024|0;c[E+1764>>2]=s;c[E+132836>>2]=s;s=c[2387994]|0;c[E+1768>>2]=s;c[E+67304>>2]=s;c[E+132840>>2]=s;y=s+1024|0;c[E+1772>>2]=y;c[E+67308>>2]=y;c[E+132844>>2]=y;y=c[2387992]|0;c[E+1776>>2]=y;c[E+67312>>2]=y;c[E+132848>>2]=y;s=y+1024|0;c[E+1780>>2]=s;c[E+67316>>2]=s;c[E+132852>>2]=s;s=c[2406498]|0;c[E+1784>>2]=s;c[E+67320>>2]=s;c[E+132856>>2]=s;y=s+1024|0;c[E+1788>>2]=y;c[E+67324>>2]=y;c[E+132860>>2]=y;y=c[2443476]|0;c[E+2560>>2]=y;c[E+133632>>2]=y;c[E+196648>>2]=1576;c[E+196728>>2]=3010;c[E+196608>>2]=146;c[E+196688>>2]=3254;y=c[3532592]|0;if((y|0)!=0){gGC(y|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);y=c[2439330]|0;if((y|0)!=0){s=y;gGC(9706056,s|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];s=c[3528484]|0;c[2076596]=s;v=c[2417276]|0;c[3541536]=v;c[1836236]=0;x=c[2385952]|0;z=0;F=0;while(1){c[y+76+(F<<2)>>2]=x+(F<<8);G=z+1&65535;if((G&65535)>31){break}else{z=G;F=G&65535}}F=c[2443350]|0;z=0;G=0;while(1){H=G<<8;c[y+76+(G+512<<2)>>2]=F+H;c[y+76+(G+768<<2)>>2]=x+H;H=z+1&65535;if((H&65535)>31){break}else{z=H;G=H&65535}}G=c[2386106]|0;c[y+204>>2]=G;z=G+256|0;c[y+208>>2]=z;x=G+512|0;c[y+212>>2]=x;F=G+768|0;c[y+216>>2]=F;H=G+1024|0;c[y+220>>2]=H;I=G+1280|0;c[y+224>>2]=I;J=G+1536|0;c[y+228>>2]=J;K=G+1792|0;c[y+232>>2]=K;c[y+1228>>2]=G;c[y+1232>>2]=z;c[y+1236>>2]=x;c[y+1240>>2]=F;c[y+1244>>2]=H;c[y+1248>>2]=I;c[y+1252>>2]=J;c[y+1256>>2]=K;c[y+2252>>2]=G;c[y+3276>>2]=G;c[y+2256>>2]=z;c[y+3280>>2]=z;c[y+2260>>2]=x;c[y+3284>>2]=x;c[y+2264>>2]=F;c[y+3288>>2]=F;c[y+2268>>2]=H;c[y+3292>>2]=H;c[y+2272>>2]=I;c[y+3296>>2]=I;c[y+2276>>2]=J;c[y+3300>>2]=J;c[y+2280>>2]=K;c[y+3304>>2]=K;c[y+4184>>2]=2846;c[y+4180>>2]=998;K=y;gGC(K|0,9706056,76)|0;c[2438118]=c[2433530];c[3528484]=s;c[2417276]=v;c[1836236]=-1;UL(3579545,1676,1504,0);c[2438224]=3579545;c[2433522]=3416;c[2406672]=1752;c[3528468]=9362;c[2443842]=571;h[745398]=1.0;a[3203264]=1;Ux(0,7575,1);c[2407030]=154;c[2407068]=3;c[3541206]=c[2386666];K=c[642608+(c[2436]<<2)>>2]|0;J=c[K+128>>2]|0;if((c[K+52>>2]&4|0)==0){c[2113068]=J;I=c[K+132>>2]|0;c[2113070]=I;c[2443814]=J;c[2440436]=I;L=J;M=I}else{c[2113070]=J;I=c[K+132>>2]|0;c[2113068]=I;c[2440436]=J;c[2443814]=I;L=I;M=J}J=ag(L<<1,M)|0;I=gGq(J)|0;c[2112926]=I;if((I|0)!=0){gGz(I|0,0,J|0)}dy5();w=0;i=d;return w|0}}while(0);c[2415016]=0;w=1;i=d;return w|0}function dy0(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>32){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6466060+(b*112|0)>>2];c[a+104>>2]=c[6466064+(b*112|0)>>2];c[a+108>>2]=c[6466068+(b*112|0)>>2];d=0;return d|0}function dy1(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<33&(d|0)==0)){e=1;return e|0}c[a>>2]=6465960+(b*112|0);e=0;return e|0}function dy2(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=0;while(1){if((b|0)>=1024){e=1599;break}f=9638528+(b<<2)|0;if((c[f>>2]|0)==0){break}else{b=b+1|0}}if((e|0)==1599){return}b=gGq(1048576)|0;c[f>>2]=b;if((b|0)==0){return}gGz(b|0,0,1048576);f=c[3530880]|0;gGC(b|0,f|0,131072)|0;g=0;do{h=g<<6;gGz(f+h|0,0,64);i=g<<7;j=0;do{k=1<<3-j;l=(c[613072+(j<<2)>>2]|0)+i|0;m=0;do{n=l+(c[609296+(m<<2)>>2]|0)|0;o=(m<<3)+h|0;p=0;do{q=n+(c[6669320+(p<<2)>>2]|0)|0;if(((d[b+((q|0)/8|0)|0]|0)&128>>>((q&7)>>>0)|0)!=0){q=f+(o+p)|0;a[q]=(d[q]|0|k)&255}p=p+1|0;}while((p|0)<8);m=m+1|0;}while((m|0)<8);j=j+1|0;}while((j|0)<4);g=g+1|0;}while((g|0)<4096);g=c[3530644]|0;gGC(b|0,g|0,1048576)|0;f=0;do{j=f<<8;gGz(g+j|0,0,256);h=f<<10;i=0;do{m=1<<3-i;k=(c[611264+(i<<2)>>2]|0)+h|0;l=0;do{p=k+(c[608880+(l<<2)>>2]|0)|0;o=(l<<4)+j|0;n=0;do{q=p+(c[609712+(n<<2)>>2]|0)|0;if(((d[b+((q|0)/8|0)|0]|0)&128>>>((q&7)>>>0)|0)!=0){q=g+(o+n)|0;a[q]=(d[q]|0|m)&255}n=n+1|0;}while((n|0)<16);l=l+1|0;}while((l|0)<16);i=i+1|0;}while((i|0)<4);f=f+1|0;}while((f|0)<8192);f=c[3530454]|0;gGC(b|0,f|0,524288)|0;g=0;do{i=g<<8;gGz(f+i|0,0,256);j=g<<10;h=0;do{l=1<<3-h;m=(c[611264+(h<<2)>>2]|0)+j|0;k=0;do{n=m+(c[608880+(k<<2)>>2]|0)|0;o=(k<<4)+i|0;p=0;do{q=n+(c[609712+(p<<2)>>2]|0)|0;if(((d[b+((q|0)/8|0)|0]|0)&128>>>((q&7)>>>0)|0)!=0){q=f+(o+p)|0;a[q]=(d[q]|0|l)&255}p=p+1|0;}while((p|0)<16);k=k+1|0;}while((k|0)<16);h=h+1|0;}while((h|0)<4);g=g+1|0;}while((g|0)<4096);g=c[3530346]|0;gGC(b|0,g|0,524288)|0;f=0;while(1){h=f<<8;gGz(g+h|0,0,256);i=f<<10;j=0;do{k=1<<3-j;l=(c[611264+(j<<2)>>2]|0)+i|0;m=0;do{p=l+(c[608880+(m<<2)>>2]|0)|0;o=(m<<4)+h|0;n=0;do{q=p+(c[609712+(n<<2)>>2]|0)|0;if(((d[b+((q|0)/8|0)|0]|0)&128>>>((q&7)>>>0)|0)!=0){q=g+(o+n)|0;a[q]=(d[q]|0|k)&255}n=n+1|0;}while((n|0)<16);m=m+1|0;}while((m|0)<16);j=j+1|0;}while((j|0)<4);j=f+1|0;if((j|0)<4096){f=j}else{r=0;break}}while(1){if((r|0)>=1024){e=1597;break}s=9638528+(r<<2)|0;if((c[s>>2]|0)==(b|0)){break}else{r=r+1|0}}if((e|0)==1597){return}gGr(b);c[s>>2]=0;return}function dy3(b,d){b=b|0;d=d|0;if((d|0)!=0){c[2384376]=215;if((c[2384372]|0)!=223){return}a[14125144]=-41;a[9706117]=1;return}c[2384376]=255;d=c[2384372]|0;if((d&255|0)==255){a[9706117]=0;return}if((d|0)!=223){return}a[14125144]=-33;a[9706117]=1;return}function dy4(a){a=a|0;var b=0,d=0;b=(c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,3579545,0)|0;return a|0}function dy5(){var b=0,d=0,e=0,f=0,g=0;a[9624552]=0;b=c[2414722]|0;gGz(b|0,0,(c[2411752]|0)-b|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];b=c[3532592]|0;if((b|0)!=0){gGC(9104152,b|0,280)|0}c[2113054]=c[2113060]}RI();b=c[2394]|0;d=c[14130368+(b<<2)>>2]|0;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[8452240+(b<<2)>>2]=c[2113054];c[2394]=-1;b=c[2439330]|0;d=(b|0)==0;if(!d){e=b;gGC(9706056,e|0,76)|0}e=c[2438118]|0;c[2433530]=e;f=c[3528484]|0;c[2076596]=f;g=c[2417276]|0;c[3541536]=g;c[1836236]=0;gGz(9706056,0,76);if(!(a[7354984]|0)){c[2384372]=255;c[2384376]=255;a[9706117]=0}if(!d){d=b;gGC(d|0,9706056,76)|0}c[2438118]=e;c[3528484]=f;c[2417276]=g;c[1836236]=-1;c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;lw(c[3540984]|0);if(a[7354984]|0){return}c[2113156]=0;a[9628264]=0;c[2407033]=0;g=c[3541206]|0;c[3541190]=g;c[3541198]=g;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=g+256;c[3541199]=g+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=g+512;c[3541200]=g+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=g+768;c[3541201]=g+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;return}function dy6(a){a=a|0;var b=0.0;b=+(a|0)*+((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)/4.0e6;+V(b)>=1.0?b>0.0?(al(+U(b/4294967296.0),4294967295.0)|0)>>>0:~~+af((b- +(~~b>>>0))/4294967296.0)>>>0:0;return~~b>>>0|0}function dy7(){var b=0,d=0,e=0;b=a[9733056]|0;d=b&255;c[2415126]=9662152;if((c[2415542]|0)==4){e=d&15}else{e=d<<1&14}c[2415538]=e;a[9733056]=(b&255)>>>4;b=a[9720192]|0;a[9720192]=b^1;if(b<<24>>24==1){return}if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12;return}function dy8(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;a=c[2386578]|0;d=c[2112926]|0;f=c[3530644]|0;g=1020;do{h=b[a+((g|2)<<1)>>1]|0;i=h&65535;do{if(h<<16>>16!=-4096){j=b[a+(g<<1)>>1]|0;if(j<<16>>16==-1){break}k=j&65535;l=(k&240)+i|0;m=l&511;n=m>>>0>256?l|-512:m;m=(e[a+((g|3)<<1)>>1]|0)+(k<<4&240)|0;k=m&511;l=e[a+((g|1)<<1)>>1]|0;o=l>>>12;p=l&4095|i>>>3&4096;l=(k>>>0>256?m|-512:k)-16|0;if((j&256)==0){SH(d,p,n,l,o,4,15,0,f);break}else{SJ(d,p,n,l,o,4,15,0,f);break}}}while(0);g=g-4|0;}while((g|0)>-1);return}function dy9(a){a=a|0;return 0}function dza(a,b){a=a|0;b=b|0;return}function dzb(b){b=b|0;var c=0;if((b|0)==147458){c=d[9625296]|0}else if((b|0)==147462){c=(d[9657994]|0)<<8|(d[9657993]|0)}else if((b|0)==147456){c=d[9625344]|0}else if((b|0)==147460){c=((a[9657992]|a[9625256])&255)<<8}else{c=0}return c|0}function dzc(c,d){c=c|0;d=d|0;if((c|0)==155650){b[7059608]=d&1023;b[4887152]=(d&65535)>>>13&1;return}else if((c|0)==155652){b[7059592]=d&511;return}else if((c|0)==155660){a[9758192]=(d&255)<<1|1;return}else if((c|0)==155648){b[4879860]=d;return}else{return}}function dzd(d){d=d|0;var e=0,f=0,g=0;do{if((d|0)==458753){e=a[9760146]|0;f=e&255;if((e&255)>=87){g=0;break}e=b[(c[2432728]|0)+(f>>>1<<1)>>1]|0;if((f&1|0)==0){g=(e&65535)>>>8&255;break}else{g=e&255;break}}else{g=0}}while(0);return g|0}function dze(b,c){b=b|0;c=c|0;if((b|0)==458755){a[9760152]=c;return}else if((b|0)==458753){b=a[9760152]|0;if((b-32&255)>=24){return}a[9760144+((b&255)-50)|0]=c;return}else{return}}function dzf(b){b=b|0;var c=0;do{if((b|0)==278532){if(a[6923464]|0){c=d[9625296]|0;break}else{c=((a[9657992]|a[9625256])&255)<<8;break}}else if((b|0)==278534){if(a[6923464]|0){c=d[9625344]|0;break}else{c=(d[9657994]|0)<<8|(d[9657993]|0);break}}else if((b|0)==278530){if(a[6923464]|0){c=((a[9657992]|a[9625256])&255)<<8;break}else{c=d[9625296]|0;break}}else if((b|0)==278528){if(a[6923464]|0){c=(d[9657994]|0)<<8|(d[9657993]|0);break}else{c=d[9625344]|0;break}}else{c=0}}while(0);return c|0}function dzg(c,d){c=c|0;d=d|0;if((c|0)==286724){b[7059592]=d&511;return}else if((c|0)==286732){a[9758192]=(d&255)<<1|1;return}else if((c|0)==286720){b[4879860]=d;return}else if((c|0)==286722){b[7059608]=d&1023;b[4887152]=(d&65535)>>>13&1;return}else{return}}function dzh(b){b=b|0;var c=0,d=0;c=b&255;if((c|0)==4){a[9758192]=0;d=0}else if((c|0)==6){d=a[9758192]|0}else{d=0}return d|0}function dzi(e,f){e=e|0;f=f|0;var g=0,i=0;g=e&255;if((g|0)==0){a[(c[3540986]|0)+5885|0]=f;return}else if((g|0)==3){US(1,gD[c[2385651]&8191]()|0);b[4771288]=~~(+(b[9753784+((f&255)<<1)>>1]|0)*+h[1192823])&65535;return}else if((g|0)==1){e=c[3540986]|0;i=c[e+5876>>2]|0;if((i|0)!=0){gg[i&4095](c[e+5880>>2]|0,0)}lH(e,d[e+5885|0]|0,f&255);return}else if((g|0)==2){US(0,gD[c[2385643]&8191]()|0);b[4771272]=~~(+(b[9753784+((f&255)<<1)>>1]|0)*+h[1192819])&65535;return}else{return}}function dzj(d,e){d=d|0;e=e|0;var f=0,g=0,i=0,j=0,k=0,l=0;f=d&255;if((f|0)==0){d=c[3541518]|0;g=d+256|0;a[d+304|0]=e;i=e&255;if((e&255)<16){c[14168912+((c[2383582]|0)*252|0)>>2]=i&15}if((e-45&255)>=3){return}if((i|0)==0){a[d+312|0]=2;j=2}else if((i|0)==45){k=d+312|0;l=a[k]|2;a[k]=l;j=l}else if((i|0)==46){l=d+312|0;k=a[l]|1;a[l]=k;j=k}else if((i|0)==47){a[d+312|0]=0;j=0}else{j=a[d+312|0]|0}d=j&3;j=c[7461744+(d<<2)>>2]|0;lI(g,j,j,c[7461728+(d<<2)>>2]|0);return}else if((f|0)==1){lS(0,1,e);return}else if((f|0)==3){US(1,gD[c[2385651]&8191]()|0);b[4771288]=~~(+(b[9753784+((e&255)<<1)>>1]|0)*+h[1192823])&65535;return}else if((f|0)==2){US(0,gD[c[2385643]&8191]()|0);b[4771272]=~~(+(b[9753784+((e&255)<<1)>>1]|0)*+h[1192819])&65535;return}else{return}}function dzk(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7407188+(b*112|0)>>2];c[a+104>>2]=c[7407192+(b*112|0)>>2];c[a+108>>2]=c[7407196+(b*112|0)>>2];d=0;return d|0}function dzl(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=7407088+(b*112|0);e=0;return e|0}function dzm(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6932448+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dzn(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>43){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7441696+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dzo(){c[2433364]=2656;return dzY()|0}function dzp(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if((c[2392]|0)>=0){d=0;do{e=14130368+(d<<2)|0;f=c[e>>2]|0;if((f|0)!=0){gGr(f);c[e>>2]=0}e=14130384+(d<<2)|0;f=c[e>>2]|0;if((f|0)!=0){gGr(f);c[e>>2]=0}d=d+1|0;}while((d|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;fwZ();if(a[6923440]|0){d=c[3541518]|0;if((d|0)!=0){gGr(d|0);c[3541518]=0}if((c[2385508]|0)>0){c[2113008]=0;c[2076598]=0;c[2383582]=0}c[2438228]=0;c[2433526]=0;c[2406676]=0;c[3528472]=0;d=c[2406680]|0;if((d|0)!=0){gGr(d);c[2406680]=0}c[2385508]=0;c[2432978]=0;a[64240]=0}else{d=a[7452592]|0;if(d){e=0;f=d&1;while(1){d=14163944+(e<<2)|0;g=c[d>>2]|0;h=c[2113006]|0;if((h|0)==0){i=1793}else{j=h-1|0;c[2113006]=j;if((j|0)==0){i=1793}}if((i|0)==1793){i=0;c[2383474]=0}if((g|0)==0){k=f}else{gGr(g);k=a[7452592]&1}c[d>>2]=0;d=e+1|0;if((d|0)<(k|0)){e=d;f=k}else{break}}}a[7452592]=0;c[2438222]=0;c[2433520]=0;c[2406670]=0;c[3528466]=0;k=c[2406686]|0;if((k|0)!=0){gGr(k);c[2406686]=0}c[2432974]=0}UT();c[2113070]=0;c[2113068]=0;k=c[2112926]|0;if((k|0)!=0){gGr(k);c[2112926]=0}k=c[2426770]|0;f=0;while(1){if((f|0)>=1024){i=1807;break}l=9638528+(f<<2)|0;if((c[l>>2]|0)==(k|0)){break}else{f=f+1|0}}if((i|0)==1807){c[2426770]=0;b[7059608]=0;b[7059592]=0;b[4887152]=0;b[4879860]=0;a[9758192]=0;a[9760152]=0;gGz(9760144,0,6);a[6923440]=0;a[6923464]=0;c[2433364]=0;c[2432728]=0;return 0}gGr(k);c[l>>2]=0;c[2426770]=0;b[7059608]=0;b[7059592]=0;b[4887152]=0;b[4879860]=0;a[9758192]=0;a[9760152]=0;gGz(9760144,0,6);a[6923440]=0;a[6923464]=0;c[2433364]=0;c[2432728]=0;return 0}function dzq(){var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;f=i;i=i+1064|0;g=f|0;h=f+1024|0;if((a[9624544]|0)!=0){dzV()}a[9625296]=-1;a[9625344]=-1;a[9625256]=-33;j=0;k=-1;l=-1;m=-33;do{k=(k&255)-((a[9759216+j|0]&1)<<j)&255;l=(l&255)-((a[9759024+j|0]&1)<<j)&255;m=(m&255)-((a[9758840+j|0]&1)<<j)&255;j=j+1|0;}while((j|0)<8);a[9625344]=k;a[9625296]=l;a[9625256]=m;c[h>>2]=10;c[h+4>>2]=20;c[h+8>>2]=30;c[h+12>>2]=40;c[h+16>>2]=50;c[h+20>>2]=60;c[h+24>>2]=70;c[h+28>>2]=80;c[h+32>>2]=90;m=c[2392]|0;if((m|0)>=0){gGz(8452240,0,((m|0)>0?(m<<2)+4|0:4)|0)}c[2113054]=0;m=c[2385548]|0;if((m|0)>0){gGz(9752472,0,((m|0)>1?m<<2:4)|0)}c[2433530]=0;m=0;l=0;while(1){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];k=c[3532592]|0;if((k|0)!=0){gGC(9104152,k|0,280)|0}c[2113054]=c[2113060]}k=l+1|0;j=((k*133333|0|0)/100|0)-m|0;c[2113056]=j;n=RG(j)|0;c[2113054]=(c[2113054]|0)+n;c[2276108]=-1;c[2113056]=-1;j=n+m|0;do{if((l|0)==99){c[8452200+(c[2394]<<2)>>2]=8193;c[2276080]=256;if((c[2276079]|0)>>>0>=256){break}RH(1)}}while(0);n=c[2394]|0;o=c[14130368+(n<<2)>>2]|0;if((o|0)!=0){gGC(o|0,9104152,280)|0}c[8452240+(n<<2)>>2]=c[2113054];c[2394]=-1;n=c[2439330]|0;if((n|0)!=0){o=n;gGC(9706056,o|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;if(a[6923440]|0){p=0}else{U1(l*666|0);p=0}do{if((l|0)==(c[h+(p<<2)>>2]|0)){a[9706117]=1;if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){o=gfc(4e3)|0;q=(c[2433530]|0)+o|0}else{q=(c[2433530]|0)+4e3|0}c[2433530]=q;a[9706117]=0}p=p+1|0;}while((p|0)<9);o=c[1836236]|0;n=c[9757320+(o<<2)>>2]|0;if((n|0)!=0){r=n;gGC(r|0,9706056,76)|0}c[9752472+(o<<2)>>2]=c[2433530];c[14113936+(o<<2)>>2]=c[2076596];c[9669104+(o<<2)>>2]=c[3541536];c[1836236]=-1;if((k|0)<100){m=j;l=k}else{break}}l=c[2439330]|0;if((l|0)!=0){m=l;gGC(9706056,m|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;if(a[6923440]|0){m=c[2438228]|0;l=gGS(-747372544,31788,m,(m|0)<0|0?-1:0)|0;m=l;Sb(66666);l=c[2443830]|0;if((l|0)<1073676288){c[2443830]=l-m}l=c[2443831]|0;if((l|0)<1073676288){c[2443831]=l-m}l=(c[3528512]|0)-m|0;c[3528512]=(l|0)<0?0:l}else{l=c[2438222]|0;m=gGS(-747372544,31788,l,(l|0)<0|0?-1:0)|0;l=m;U1(66666);m=c[2443824]|0;if((m|0)<1073676288){c[2443824]=m-l}m=c[2443825]|0;if((m|0)<1073676288){c[2443825]=m-l}m=(c[3528506]|0)-l|0;c[3528506]=(m|0)<0?0:m}m=c[2112964]|0;if((m|0)!=0){if(a[6923440]|0){gg[c[3542122]&4095](m,a[9688]|0?534:0)}else{gg[c[3542114]&4095](m,a[9688]|0?534:0)}UR(c[2112964]|0,a[9688]|0?534:0)}m=c[1836236]|0;l=c[9757320+(m<<2)>>2]|0;if((l|0)!=0){p=l;gGC(p|0,9706056,76)|0}c[9752472+(m<<2)>>2]=c[2433530];c[14113936+(m<<2)>>2]=c[2076596];c[9669104+(m<<2)>>2]=c[3541536];c[1836236]=-1;if((c[2112968]|0)==0){i=f;return 0}m=c[2112926]|0;gGz(m|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);if((a[9773960]|0)!=0){p=c[2406284]|0;l=0;do{q=a[p+l|0]|0;h=a[p+(l+256)|0]|0;o=a[p+(l+512)|0]|0;c[g+(l<<2)>>2]=((h<<4|h&12)&255)<<3&2016|((q<<4|q&8)&255)<<8&63488|((o<<4|o&8)&255)>>>3;l=l+1|0;}while((l|0)<256);l=c[3530072]|0;c[l>>2]=c[g>>2];c[l+4>>2]=c[g+4>>2];c[l+8>>2]=c[g+8>>2];c[l+12>>2]=c[g+12>>2];c[l+16>>2]=c[g+16>>2];c[l+20>>2]=c[g+20>>2];c[l+24>>2]=c[g+24>>2];c[l+28>>2]=c[g+28>>2];c[l+32>>2]=c[g+32>>2];c[l+36>>2]=c[g+36>>2];c[l+40>>2]=c[g+40>>2];c[l+44>>2]=c[g+44>>2];c[l+48>>2]=c[g+48>>2];c[l+52>>2]=c[g+52>>2];c[l+56>>2]=c[g+56>>2];c[l+60>>2]=c[g+60>>2];o=0;while(1){c[l+(o+16<<2)>>2]=c[g+((o&15|((o&8|0)==0?o:o>>>2)&48|192)<<2)>>2];q=o+1|0;if((q|0)<256){o=q}else{s=0;break}}do{if((s&128|0)==0){t=a[p+((s>>4)+768)|0]&15|s<<4&48}else{t=a[p+((s>>4)+768)|0]&15|s<<2&48}c[l+((s<<8&3840|s>>>4&255)+272<<2)>>2]=c[g+((t&127|128)<<2)>>2];s=s+1|0;}while((s|0)<4096);a[9773960]=0}if((b[4887152]|0)==0){s=c[2439960]|0;t=c[2405816]|0;g=0;do{l=g<<4;p=0;do{o=e[s+((p<<5)+g<<1)>>1]|0;q=(o>>>11)+1|0;h=o&1023;o=(p<<4)-(e[7059608]|0)|0;r=l-(e[7059592]|0)|0;n=(o|0)<-16?o+1024|0:o;o=(r|0)<-16?r+512|0:r;L2525:do{if((b[4879860]|0)==0){r=o-16|0;do{if((n-17|0)>>>0<223){if((o-33|0)>>>0>=191){break}Sy(m,h,n,r,q,4,0,t);break L2525}}while(0);Sz(m,h,n,r,q,4,0,t)}else{u=240-n|0;v=240-o|0;w=v-16|0;do{if((u-17|0)>>>0<223){if((v-33|0)>>>0>=191){break}SE(m,h,u,w,q,4,0,t);break L2525}}while(0);SF(m,h,u,w,q,4,0,t)}}while(0);p=p+1|0;}while((p|0)<64);g=g+1|0;}while((g|0)<32)}g=a[6923464]|0;t=g?15:0;s=c[2433442]|0;p=c[3529580]|0;l=8;k=c[2443420]|0;while(1){j=b[k+2>>1]&255;q=e[k+4>>1]|0;h=q&4;o=q&8;n=q>>>4;v=(b[k+6>>1]&255)-128+(q<<8&256)|0;r=b[k>>1]&255;x=(q&2|0)!=0;if(g){y=x?j|512:j;z=(q&16|0)==0?y:y|256;y=z>>>1&126;A=d[s+(((z&512|0)==0?y:y|128)|z>>>8&1)|0]<<4&240|n&14;B=z}else{z=x?j|256:j;A=d[s+(z>>>1)|0]<<4&240|n&15;B=z}z=A+17|0;if((b[4879860]|0)==0){C=240-r|0;D=v;E=o;F=h}else{C=r;D=240-v|0;E=o>>>3^1;F=h>>>2^1}h=C-16|0;do{if((D-17|0)>>>0<223){if((C-33|0)>>>0>=191){G=1900;break}o=(E|0)!=0;if((F|0)==0){if(o){SK(m,B,D,h,z,4,t,0,p);break}else{SG(m,B,D,h,z,4,t,0,p);break}}else{if(o){SM(m,B,D,h,z,4,t,0,p);break}else{SI(m,B,D,h,z,4,t,0,p);break}}}else{G=1900}}while(0);do{if((G|0)==1900){G=0;o=(E|0)!=0;if((F|0)==0){if(o){SL(m,B,D,h,z,4,t,0,p);break}else{SH(m,B,D,h,z,4,t,0,p);break}}else{if(o){SN(m,B,D,h,z,4,t,0,p);break}else{SJ(m,B,D,h,z,4,t,0,p);break}}}}while(0);if((l|0)>=512){break}l=l+8|0;k=k+8|0}k=c[2439942]|0;l=c[2406528]|0;p=0;do{t=p<<3;D=t-16|0;B=248-t|0;F=B-16|0;E=(t-25|0)>>>0<207;L2576:do{if((B-25|0)>>>0<207){t=E^1;G=0;do{C=b[k+((G<<5)+p<<1)>>1]&255;A=G<<3;do{if((b[4879860]|0)==0){if((A-9|0)>>>0>238|t){Sr(m,C,A,D,0,4,15,0,l);break}else{Sq(m,C,A,D,0,4,15,0,l);break}}else{s=248-A|0;if((s-9|0)>>>0<239){Sw(m,C,s,F,0,4,15,0,l);break}else{Sx(m,C,s,F,0,4,15,0,l);break}}}while(0);G=G+1|0;}while((G|0)<64)}else{if(E){H=0}else{G=0;while(1){t=b[k+((G<<5)+p<<1)>>1]&255;C=G<<3;if((b[4879860]|0)==0){Sr(m,t,C,D,0,4,15,0,l)}else{Sx(m,t,248-C|0,F,0,4,15,0,l)}G=G+1|0;if((G|0)>=64){break L2576}}}do{G=b[k+((H<<5)+p<<1)>>1]&255;C=H<<3;do{if((b[4879860]|0)==0){if((C-9|0)>>>0<239){Sq(m,G,C,D,0,4,15,0,l);break}else{Sr(m,G,C,D,0,4,15,0,l);break}}else{Sx(m,G,248-C|0,F,0,4,15,0,l)}}while(0);H=H+1|0;}while((H|0)<64)}}while(0);p=p+1|0;}while((p|0)<32);R8(c[3530072]|0);i=f;return 0}function dzr(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;e=i;i=i+192|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;l=e+80|0;m=e+96|0;n=e+112|0;o=e+128|0;p=e+144|0;q=e+160|0;r=e+176|0;s=(d|0)==0;if(!s){c[d>>2]=169753}if((b&32|0)!=0){gGz(r|0,0,12);t=c[2405688]|0;c[r>>2]=t;c[r+4>>2]=(c[2411750]|0)-t;c[r+12>>2]=162152;t=c[2076592]|0;gj[t&4095](r)|0}if((b&64|0)==0){i=e;return 0}r=j|0;gGz(h|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){t=j+9|0;j=g;u=g|0;v=g+4|0;w=g+12|0;x=h|0;y=h+4|0;z=h+12|0;A=0;do{gGC(r|0,614896,11)|0;a[t]=A+48&255;B=8452256+(A<<2)|0;gGz(j|0,0,12);c[u>>2]=B;c[v>>2]=4;c[w>>2]=164976;gj[c[2076592]&4095](g)|0;if((c[B>>2]|0)!=0){c[x>>2]=c[14130368+(A<<2)>>2];c[y>>2]=c[8452184+(A<<2)>>2];c[z>>2]=r;B=c[2076592]|0;gj[B&4095](h)|0}A=A+1|0;}while((A|0)<=(c[2392]|0))}fw$(b);if(a[6923440]|0){Vx(b,d)}else{Vb(b,d)}if(!s){c[d>>2]=169753}if((c[2405758]|0)>0){d=f;s=f|0;A=f+4|0;h=f+12|0;r=0;do{gGz(d|0,0,12);c[s>>2]=9542544+(r<<5);c[A>>2]=2;c[h>>2]=119040;gj[c[2076592]&4095](f)|0;r=r+1|0;}while((r|0)<(c[2405758]|0))}gGz(q|0,0,12);c[q>>2]=14119216;c[q+4>>2]=2;c[q+12>>2]=577712;gj[c[2076592]&4095](q)|0;gGz(p|0,0,12);c[p>>2]=14119184;c[p+4>>2]=2;c[p+12>>2]=576584;gj[c[2076592]&4095](p)|0;gGz(o|0,0,12);c[o>>2]=9774304;c[o+4>>2]=2;c[o+12>>2]=575384;gj[c[2076592]&4095](o)|0;gGz(n|0,0,12);c[n>>2]=9759720;c[n+4>>2]=2;c[n+12>>2]=503888;gj[c[2076592]&4095](n)|0;gGz(m|0,0,12);c[m>>2]=9758192;c[m+4>>2]=1;c[m+12>>2]=497064;gj[c[2076592]&4095](m)|0;gGz(l|0,0,12);c[l>>2]=9760152;c[l+4>>2]=1;c[l+12>>2]=571664;gj[c[2076592]&4095](l)|0;gGz(k|0,0,12);c[k>>2]=9760144;c[k+4>>2]=6;c[k+12>>2]=569280;gj[c[2076592]&4095](k)|0;if((b&2|0)==0){i=e;return 0}a[9773960]=1;i=e;return 0}function dzs(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7243524+(b*112|0)>>2];c[a+104>>2]=c[7243528+(b*112|0)>>2];c[a+108>>2]=c[7243532+(b*112|0)>>2];d=0;return d|0}function dzt(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=7243424+(b*112|0);e=0;return e|0}function dzu(){c[2433364]=868;return dzY()|0}function dzv(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7295892+(b*112|0)>>2];c[a+104>>2]=c[7295896+(b*112|0)>>2];c[a+108>>2]=c[7295900+(b*112|0)>>2];d=0;return d|0}function dzw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=7295792+(b*112|0);e=0;return e|0}function dzx(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7246100+(b*112|0)>>2];c[a+104>>2]=c[7246104+(b*112|0)>>2];c[a+108>>2]=c[7246108+(b*112|0)>>2];d=0;return d|0}function dzy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<22&(d|0)==0)){e=1;return e|0}c[a>>2]=7246e3+(b*112|0);e=0;return e|0}function dzz(){c[2433364]=1172;a[6923440]=1;return dzY()|0}function dzA(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6440980+(b*112|0)>>2];c[a+104>>2]=c[6440984+(b*112|0)>>2];c[a+108>>2]=c[6440988+(b*112|0)>>2];d=0;return d|0}function dzB(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<21&(d|0)==0)){e=1;return e|0}c[a>>2]=6440880+(b*112|0);e=0;return e|0}function dzC(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4282128+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dzD(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>43){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6443232+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dzE(){c[2433364]=1770;c[2432728]=5616704;return dzS()|0}function dzF(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4282564+(b*112|0)>>2];c[a+104>>2]=c[4282568+(b*112|0)>>2];c[a+108>>2]=c[4282572+(b*112|0)>>2];d=0;return d|0}function dzG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<21&(d|0)==0)){e=1;return e|0}c[a>>2]=4282464+(b*112|0);e=0;return e|0}function dzH(){c[2433364]=1770;c[2432728]=2020824;return dzS()|0}function dzI(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5354204+(b*112|0)>>2];c[a+104>>2]=c[5354208+(b*112|0)>>2];c[a+108>>2]=c[5354212+(b*112|0)>>2];d=0;return d|0}function dzJ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<22&(d|0)==0)){e=1;return e|0}c[a>>2]=5354104+(b*112|0);e=0;return e|0}function dzK(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6932448+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dzL(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>42){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5356568+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dzM(){c[2433364]=2582;c[2432728]=3865288;a[6923464]=1;return dzS()|0}function dzN(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3862924+(b*112|0)>>2];c[a+104>>2]=c[3862928+(b*112|0)>>2];c[a+108>>2]=c[3862932+(b*112|0)>>2];d=0;return d|0}function dzO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<22&(d|0)==0)){e=1;return e|0}c[a>>2]=3862824+(b*112|0);e=0;return e|0}function dzP(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4215308+(b*112|0)>>2];c[a+104>>2]=c[4215312+(b*112|0)>>2];c[a+108>>2]=c[4215316+(b*112|0)>>2];d=0;return d|0}function dzQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<21&(d|0)==0)){e=1;return e|0}c[a>>2]=4215208+(b*112|0);e=0;return e|0}function dzR(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;b=i;i=i+2040|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;l=b+360|0;m=b+472|0;n=b+480|0;o=b+592|0;p=b+600|0;q=b+712|0;r=b+720|0;s=b+832|0;t=b+840|0;u=b+952|0;v=b+960|0;w=b+1072|0;x=b+1080|0;y=b+1192|0;z=b+1200|0;A=b+1312|0;B=b+1320|0;C=b+1432|0;D=b+1440|0;E=b+1552|0;F=b+1560|0;G=b+1672|0;H=b+1680|0;I=b+1792|0;J=b+1800|0;K=b+1912|0;L=b+1920|0;M=b+2032|0;N=0;while(1){if((N|0)>=1024){O=0;break}P=9638528+(N<<2)|0;if((c[P>>2]|0)==0){Q=2092;break}else{N=N+1|0}}do{if((Q|0)==2092){N=gGq(131072)|0;c[P>>2]=N;if((N|0)==0){O=0;break}gGz(N|0,0,131072);O=N}}while(0);c[3529530]=O;if((R6((c[2388032]|0)+1|0,0,2)|0)!=0){R=1;i=b;return R|0}if((R6(c[2388032]|0,1,2)|0)!=0){R=1;i=b;return R|0}if((R6((c[2388032]|0)+65537|0,2,2)|0)!=0){R=1;i=b;return R|0}if((R6((c[2388032]|0)+65536|0,3,2)|0)!=0){R=1;i=b;return R|0}O=c[2385840]|0;if((c[3542200]|0)==0){R=1;i=b;return R|0}P=L+108|0;c[P>>2]=0;N=L+100|0;c[N>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](L,4)|0;do{if((c[P>>2]|0)!=0){L=c[N>>2]|0;c[M>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](M,4,0)|0;if((L|0)<1){R=1;i=b;return R|0}if((gzL(O,0,4)|0)==0){break}else{R=1}i=b;return R|0}}while(0);O=(c[2385840]|0)+16384|0;if((c[3542200]|0)==0){R=1;i=b;return R|0}M=J+108|0;c[M>>2]=0;N=J+100|0;c[N>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](J,5)|0;do{if((c[M>>2]|0)!=0){J=c[N>>2]|0;c[K>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](K,5,0)|0;if((J|0)<1){R=1;i=b;return R|0}if((gzL(O,0,5)|0)==0){break}else{R=1}i=b;return R|0}}while(0);O=(c[2385840]|0)+32768|0;if((c[3542200]|0)==0){R=1;i=b;return R|0}K=H+108|0;c[K>>2]=0;N=H+100|0;c[N>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](H,6)|0;do{if((c[K>>2]|0)!=0){H=c[N>>2]|0;c[I>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](I,6,0)|0;if((H|0)<1){R=1;i=b;return R|0}if((gzL(O,0,6)|0)==0){break}else{R=1}i=b;return R|0}}while(0);O=c[3529530]|0;gGz(O|0,0,131072);if((c[3542200]|0)==0){R=1;i=b;return R|0}I=F+108|0;c[I>>2]=0;N=F+100|0;c[N>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](F,7)|0;do{if((c[I>>2]|0)!=0){F=c[N>>2]|0;c[G>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](G,7,0)|0;if((F|0)<1){R=1;i=b;return R|0}if((gzL(O,0,7)|0)==0){break}else{R=1}i=b;return R|0}}while(0);O=c[3529530]|0;G=c[2406528]|0;N=0;do{I=N<<6;gGz(G+I|0,0,64);F=N<<8;K=0;do{H=1<<3-K;M=(c[703416+(K<<2)>>2]|0)+F|0;J=0;do{P=M+(c[1183816+(J<<2)>>2]|0)|0;L=(J<<3)+I|0;S=0;do{T=P+(c[1183848+(S<<2)>>2]|0)|0;if(((d[O+((T|0)/8|0)|0]|0)&128>>>((T&7)>>>0)|0)!=0){T=G+(L+S)|0;a[T]=(d[T]|0|H)&255}S=S+1|0;}while((S|0)<8);J=J+1|0;}while((J|0)<8);K=K+1|0;}while((K|0)<4);N=N+1|0;}while((N|0)<256);gGz(O|0,0,131072);if((c[3542200]|0)==0){R=1;i=b;return R|0}N=D+108|0;c[N>>2]=0;G=D+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](D,8)|0;do{if((c[N>>2]|0)!=0){D=c[G>>2]|0;c[E>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](E,8,0)|0;if((D|0)<1){R=1;i=b;return R|0}if((gzL(O,0,8)|0)==0){break}else{R=1}i=b;return R|0}}while(0);O=(c[3529530]|0)+32768|0;if((c[3542200]|0)==0){R=1;i=b;return R|0}E=B+108|0;c[E>>2]=0;G=B+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](B,9)|0;do{if((c[E>>2]|0)!=0){B=c[G>>2]|0;c[C>>2]=9534384;N=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[N&16383](C,9,0)|0;if((B|0)<1){R=1;i=b;return R|0}if((gzL(O,0,9)|0)==0){break}else{R=1}i=b;return R|0}}while(0);O=(c[3529530]|0)+65536|0;if((c[3542200]|0)==0){R=1;i=b;return R|0}C=z+108|0;c[C>>2]=0;G=z+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,10)|0;do{if((c[C>>2]|0)!=0){z=c[G>>2]|0;c[A>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](A,10,0)|0;if((z|0)<1){R=1;i=b;return R|0}if((gzL(O,0,10)|0)==0){break}else{R=1}i=b;return R|0}}while(0);O=(c[3529530]|0)+98304|0;if((c[3542200]|0)==0){R=1;i=b;return R|0}A=x+108|0;c[A>>2]=0;G=x+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,11)|0;do{if((c[A>>2]|0)!=0){x=c[G>>2]|0;c[y>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](y,11,0)|0;if((x|0)<1){R=1;i=b;return R|0}if((gzL(O,0,11)|0)==0){break}else{R=1}i=b;return R|0}}while(0);O=c[3529530]|0;y=c[2405816]|0;G=0;do{A=G<<8;gGz(y+A|0,0,256);x=G<<10;C=0;do{z=1<<3-C;E=(c[703416+(C<<2)>>2]|0)+x|0;B=0;do{N=E+(c[611904+(B<<2)>>2]|0)|0;D=(B<<4)+A|0;K=0;do{I=N+(c[612512+(K<<2)>>2]|0)|0;if(((d[O+((I|0)/8|0)|0]|0)&128>>>((I&7)>>>0)|0)!=0){I=y+(D+K)|0;a[I]=(d[I]|0|z)&255}K=K+1|0;}while((K|0)<16);B=B+1|0;}while((B|0)<16);C=C+1|0;}while((C|0)<4);G=G+1|0;}while((G|0)<1024);gGz(O|0,0,131072);if((c[3542200]|0)==0){R=1;i=b;return R|0}G=v+108|0;c[G>>2]=0;y=v+100|0;c[y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,12)|0;do{if((c[G>>2]|0)!=0){v=c[y>>2]|0;c[w>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](w,12,0)|0;if((v|0)<1){R=1;i=b;return R|0}if((gzL(O,0,12)|0)==0){break}else{R=1}i=b;return R|0}}while(0);O=(c[3529530]|0)+32768|0;if((c[3542200]|0)==0){R=1;i=b;return R|0}w=t+108|0;c[w>>2]=0;y=t+100|0;c[y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,13)|0;do{if((c[w>>2]|0)!=0){t=c[y>>2]|0;c[u>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](u,13,0)|0;if((t|0)<1){R=1;i=b;return R|0}if((gzL(O,0,13)|0)==0){break}else{R=1}i=b;return R|0}}while(0);O=(c[3529530]|0)+65536|0;if((c[3542200]|0)==0){R=1;i=b;return R|0}u=r+108|0;c[u>>2]=0;y=r+100|0;c[y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,14)|0;do{if((c[u>>2]|0)!=0){r=c[y>>2]|0;c[s>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](s,14,0)|0;if((r|0)<1){R=1;i=b;return R|0}if((gzL(O,0,14)|0)==0){break}else{R=1}i=b;return R|0}}while(0);O=(c[3529530]|0)+98304|0;if((c[3542200]|0)==0){R=1;i=b;return R|0}s=p+108|0;c[s>>2]=0;y=p+100|0;c[y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,15)|0;do{if((c[s>>2]|0)!=0){p=c[y>>2]|0;c[q>>2]=9534384;u=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[u&16383](q,15,0)|0;if((p|0)<1){R=1;i=b;return R|0}if((gzL(O,0,15)|0)==0){break}else{R=1}i=b;return R|0}}while(0);O=c[3529530]|0;q=c[3529580]|0;y=0;do{s=y<<8;gGz(q+s|0,0,256);p=y<<9;u=0;do{r=1<<3-u;w=(c[703416+(u<<2)>>2]|0)+p|0;t=0;do{G=w+(c[611840+(t<<2)>>2]|0)|0;v=(t<<4)+s|0;C=0;do{A=G+(c[704080+(C<<2)>>2]|0)|0;if(((d[O+((A|0)/8|0)|0]|0)&128>>>((A&7)>>>0)|0)!=0){A=q+(v+C)|0;a[A]=(d[A]|0|r)&255}C=C+1|0;}while((C|0)<16);t=t+1|0;}while((t|0)<16);u=u+1|0;}while((u|0)<4);y=y+1|0;}while((y|0)<1024);y=c[2406284]|0;if((c[3542200]|0)==0){R=1;i=b;return R|0}q=n+108|0;c[q>>2]=0;O=n+100|0;c[O>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,16)|0;do{if((c[q>>2]|0)!=0){n=c[O>>2]|0;c[o>>2]=9534384;u=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[u&16383](o,16,0)|0;if((n|0)<1){R=1;i=b;return R|0}if((gzL(y,0,16)|0)==0){break}else{R=1}i=b;return R|0}}while(0);y=(c[2406284]|0)+256|0;if((c[3542200]|0)==0){R=1;i=b;return R|0}o=l+108|0;c[o>>2]=0;O=l+100|0;c[O>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,17)|0;do{if((c[o>>2]|0)!=0){l=c[O>>2]|0;c[m>>2]=9534384;q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[q&16383](m,17,0)|0;if((l|0)<1){R=1;i=b;return R|0}if((gzL(y,0,17)|0)==0){break}else{R=1}i=b;return R|0}}while(0);y=(c[2406284]|0)+512|0;if((c[3542200]|0)==0){R=1;i=b;return R|0}m=j+108|0;c[m>>2]=0;O=j+100|0;c[O>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,18)|0;do{if((c[m>>2]|0)!=0){j=c[O>>2]|0;c[k>>2]=9534384;o=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[o&16383](k,18,0)|0;if((j|0)<1){R=1;i=b;return R|0}if((gzL(y,0,18)|0)==0){break}else{R=1}i=b;return R|0}}while(0);y=(c[2406284]|0)+768|0;if((c[3542200]|0)==0){R=1;i=b;return R|0}k=g+108|0;c[k>>2]=0;O=g+100|0;c[O>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,19)|0;do{if((c[k>>2]|0)!=0){g=c[O>>2]|0;c[h>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](h,19,0)|0;if((g|0)<1){R=1;i=b;return R|0}if((gzL(y,0,19)|0)==0){break}else{R=1}i=b;return R|0}}while(0);y=c[2433442]|0;if((c[3542200]|0)==0){R=1;i=b;return R|0}h=e+108|0;c[h>>2]=0;O=e+100|0;c[O>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,20)|0;do{if((c[h>>2]|0)!=0){e=c[O>>2]|0;c[f>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](f,20,0)|0;if((e|0)<1){R=1;i=b;return R|0}if((gzL(y,0,20)|0)==0){break}else{R=1}i=b;return R|0}}while(0);y=c[3529530]|0;f=0;while(1){if((f|0)>=1024){break}U=9638528+(f<<2)|0;if((c[U>>2]|0)==(y|0)){Q=2199;break}else{f=f+1|0}}if((Q|0)==2199){gGr(y);c[U>>2]=0}c[3529530]=0;R=0;i=b;return R|0}function dzS(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;c[2426770]=0;c[2388032]=0;c[2385840]=131072;c[2406284]=180224;c[2433442]=181248;c[2405688]=181504;c[2443420]=185600;c[2439960]=193792;c[2439942]=197888;c[2385858]=201984;c[2411750]=206080;c[2406528]=206080;c[2405816]=222464;c[3529580]=484608;c[3530072]=746752;d=0;while(1){if((d|0)>=1024){break}e=9638528+(d<<2)|0;if((c[e>>2]|0)==0){f=2261;break}else{d=d+1|0}}do{if((f|0)==2261){d=gGq(764224)|0;c[e>>2]=d;if((d|0)==0){break}c[2426770]=d;gGz(d|0,0,764224);c[2388032]=d;c[2385840]=d+131072;c[2406284]=d+180224;c[2433442]=d+181248;g=d+181504|0;c[2405688]=g;c[2388054]=g;c[2443420]=d+185600;c[2439960]=d+193792;c[2439942]=d+197888;c[2385858]=d+201984;g=d+206080|0;c[2411750]=g;c[2406528]=g;c[2405816]=d+222464;c[3529580]=d+484608;c[3530072]=d+746752;c[2414294]=d+764224;if((gD[c[2433364]&8191]()|0)!=0){i=1;return i|0}fxU(0,425984);if((c[2394]|0)==0){j=c[2112932]|0}else{c[2394]=0;d=c[3532596]|0;c[2112932]=d;g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060];j=d}d=c[2388032]|0;g=j|0;k=0;while(1){l=d+k|0;c[g>>2]=l;c[g+131072>>2]=l;l=k+1024|0;if(l>>>0>131071){break}else{g=g+4|0;k=l}}k=c[2443420]|0;c[j+1024>>2]=k;c[j+66560>>2]=k;c[j+132096>>2]=k;g=k+1024|0;c[j+1028>>2]=g;c[j+66564>>2]=g;c[j+132100>>2]=g;g=k+2048|0;c[j+1032>>2]=g;c[j+66568>>2]=g;c[j+132104>>2]=g;g=k+3072|0;c[j+1036>>2]=g;c[j+66572>>2]=g;c[j+132108>>2]=g;g=c[2439960]|0;c[j+1056>>2]=g;c[j+66592>>2]=g;c[j+132128>>2]=g;k=g+1024|0;c[j+1060>>2]=k;c[j+66596>>2]=k;c[j+132132>>2]=k;k=g+2048|0;c[j+1064>>2]=k;c[j+66600>>2]=k;c[j+132136>>2]=k;k=g+3072|0;c[j+1068>>2]=k;c[j+66604>>2]=k;c[j+132140>>2]=k;k=c[2439942]|0;c[j+1280>>2]=k;c[j+66816>>2]=k;c[j+132352>>2]=k;g=k+1024|0;c[j+1284>>2]=g;c[j+66820>>2]=g;c[j+132356>>2]=g;g=k+2048|0;c[j+1288>>2]=g;c[j+66824>>2]=g;c[j+132360>>2]=g;g=k+3072|0;c[j+1292>>2]=g;c[j+66828>>2]=g;c[j+132364>>2]=g;c[j+196688>>2]=1176;c[j+196728>>2]=2160;c[j+196608>>2]=486;c[j+196648>>2]=3244;g=c[3532592]|0;if((g|0)!=0){gGC(g|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);g=c[2439330]|0;k=(g|0)==0;if(!k){d=g;gGC(9706056,d|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];d=c[3528484]|0;c[2076596]=d;l=c[2417276]|0;c[3541536]=l;c[1836236]=0;c[g+4172>>2]=768;c[g+4176>>2]=1838;m=c[2385840]|0;n=0;o=0;while(1){c[g+76+(o<<2)>>2]=m+(o<<8);p=n+1&65535;if((p&65535)>191){q=0;r=0;break}else{n=p;o=p&65535}}while(1){o=m+(r<<8)|0;c[g+76+(r+512<<2)>>2]=o;c[g+76+(r+768<<2)>>2]=o;o=q+1&65535;if((o&65535)>191){break}else{q=o;r=o&65535}}m=c[2385858]|0;c[g+844>>2]=m;c[g+848>>2]=m+256;c[g+852>>2]=m+512;c[g+856>>2]=m+768;c[g+860>>2]=m+1024;c[g+864>>2]=m+1280;c[g+868>>2]=m+1536;c[g+872>>2]=m+1792;c[g+876>>2]=m+2048;c[g+880>>2]=m+2304;c[g+884>>2]=m+2560;c[g+888>>2]=m+2816;c[g+892>>2]=m+3072;c[g+896>>2]=m+3328;c[g+900>>2]=m+3584;c[g+904>>2]=m+3840;o=192;n=192;while(1){c[g+76+(n+256<<2)>>2]=m+((n<<8)-49152);p=o+1&65535;if((p&65535)>207){s=192;t=192;break}else{o=p;n=p&65535}}while(1){n=m+((t<<8)-49152)|0;c[g+76+(t+512<<2)>>2]=n;c[g+76+(t+768<<2)>>2]=n;n=s+1&65535;if((n&65535)>207){break}else{s=n;t=n&65535}}if(!k){m=g;gGC(m|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=d;c[2417276]=l;c[1836236]=-1;U6(4e6,0,2314,0);c[2438222]=4e6;c[2433520]=3416;c[2406670]=1752;c[3528466]=9362;c[2443840]=511;h[745399]=1.0;a[3203272]=1;c[2405758]=1;gGz(9542544,0,32);c[2385641]=1;h[1192819]=1.0;c[2385642]=3;c[2385643]=4324;m=0;do{n=m*257|0;b[9732544+(m<<1)>>1]=((n|0)/2|0)&65535;b[9753784+(m<<1)>>1]=n+32768&65535;m=m+1|0;}while((m|0)<256);c[3528842]=1;c[2405758]=2;gGz(9542576,0,32);c[2385649]=1;h[1192823]=1.0;c[2385650]=3;c[2385651]=4324;m=0;do{l=m*257|0;b[9732544+(m<<1)>>1]=((l|0)/2|0)&65535;b[9753784+(m<<1)>>1]=l+32768&65535;m=m+1|0;}while((m|0)<256);c[3528842]=1;h[1192819]=.5;c[2385642]=3;h[1192823]=.5;c[2385650]=3;m=c[642608+(c[2436]<<2)>>2]|0;l=c[m+128>>2]|0;if((c[m+52>>2]&4|0)==0){c[2113068]=l;d=c[m+132>>2]|0;c[2113070]=d;c[2443814]=l;c[2440436]=d;u=l;v=d}else{c[2113070]=l;d=c[m+132>>2]|0;c[2113068]=d;c[2440436]=l;c[2443814]=d;u=d;v=l}l=ag(u<<1,v)|0;d=gGq(l)|0;c[2112926]=d;if((d|0)!=0){gGz(d|0,0,l|0)}a[9773960]=1;dzV();i=0;return i|0}}while(0);c[2426770]=0;i=1;return i|0}function dzT(a){a=a|0;var b=0,d=0;b=(c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,4e6,0)|0;return a|0}function dzU(){return~~((a[9688]|0?534.0:0.0)*(+((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)/(4.0e6/(+(c[2424]|0)/100.0))))|0}function dzV(){var d=0,e=0,f=0,g=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;d=c[2439330]|0;if((d|0)!=0){e=d;gGC(9706056,e|0,76)|0}c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;gGz(9706056,0,76);do{if(a[6923440]|0){c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){f=0}else{break}do{lN(f);mB(f);f=f+1|0;}while((f|0)<(c[2385508]|0))}else{c[2443825]=1073676288;c[2443824]=1073676288;c[2443817]=1073676288;c[2443816]=1073676288;h[883199]=0.0;c[3528506]=0;lw(c[3540986]|0)}}while(0);f=c[1836236]|0;e=c[9757320+(f<<2)>>2]|0;if((e|0)!=0){d=e;gGC(d|0,9706056,76)|0}c[9752472+(f<<2)>>2]=c[2433530];c[14113936+(f<<2)>>2]=c[2076596];c[9669104+(f<<2)>>2]=c[3541536];c[1836236]=-1;f=c[2405758]|0;if((f|0)>0){g=0}else{b[7059608]=0;b[7059592]=0;b[4887152]=0;b[4879860]=0;a[9758192]=0;a[9760152]=0;gGz(9760144,0,6);return}do{c[9542560+(g<<5)>>2]=0;b[9542544+(g<<5)>>1]=0;g=g+1|0;}while((g|0)<(f|0));b[7059608]=0;b[7059592]=0;b[4887152]=0;b[4879860]=0;a[9758192]=0;a[9760152]=0;gGz(9760144,0,6);return}function dzW(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;b=i;i=i+1920|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;l=b+360|0;m=b+472|0;n=b+480|0;o=b+592|0;p=b+600|0;q=b+712|0;r=b+720|0;s=b+832|0;t=b+840|0;u=b+952|0;v=b+960|0;w=b+1072|0;x=b+1080|0;y=b+1192|0;z=b+1200|0;A=b+1312|0;B=b+1320|0;C=b+1432|0;D=b+1440|0;E=b+1552|0;F=b+1560|0;G=b+1672|0;H=b+1680|0;I=b+1792|0;J=b+1800|0;K=b+1912|0;L=0;while(1){if((L|0)>=1024){M=0;break}N=9638528+(L<<2)|0;if((c[N>>2]|0)==0){O=2321;break}else{L=L+1|0}}do{if((O|0)==2321){L=gGq(131072)|0;c[N>>2]=L;if((L|0)==0){M=0;break}gGz(L|0,0,131072);M=L}}while(0);c[3529530]=M;if((R6((c[2388032]|0)+1|0,0,2)|0)!=0){P=1;i=b;return P|0}if((R6(c[2388032]|0,1,2)|0)!=0){P=1;i=b;return P|0}if((R6((c[2388032]|0)+65537|0,2,2)|0)!=0){P=1;i=b;return P|0}if((R6((c[2388032]|0)+65536|0,3,2)|0)!=0){P=1;i=b;return P|0}M=c[2385840]|0;if((c[3542200]|0)==0){P=1;i=b;return P|0}N=J+108|0;c[N>>2]=0;L=J+100|0;c[L>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](J,4)|0;do{if((c[N>>2]|0)!=0){J=c[L>>2]|0;c[K>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](K,4,0)|0;if((J|0)<1){P=1;i=b;return P|0}if((gzL(M,0,4)|0)==0){break}else{P=1}i=b;return P|0}}while(0);M=(c[2385840]|0)+16384|0;if((c[3542200]|0)==0){P=1;i=b;return P|0}K=H+108|0;c[K>>2]=0;L=H+100|0;c[L>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](H,5)|0;do{if((c[K>>2]|0)!=0){H=c[L>>2]|0;c[I>>2]=9534384;N=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[N&16383](I,5,0)|0;if((H|0)<1){P=1;i=b;return P|0}if((gzL(M,0,5)|0)==0){break}else{P=1}i=b;return P|0}}while(0);M=(c[2385840]|0)+32768|0;if((c[3542200]|0)==0){P=1;i=b;return P|0}I=F+108|0;c[I>>2]=0;L=F+100|0;c[L>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](F,6)|0;do{if((c[I>>2]|0)!=0){F=c[L>>2]|0;c[G>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](G,6,0)|0;if((F|0)<1){P=1;i=b;return P|0}if((gzL(M,0,6)|0)==0){break}else{P=1}i=b;return P|0}}while(0);M=c[3529530]|0;gGz(M|0,0,131072);if((c[3542200]|0)==0){P=1;i=b;return P|0}G=D+108|0;c[G>>2]=0;L=D+100|0;c[L>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](D,7)|0;do{if((c[G>>2]|0)!=0){D=c[L>>2]|0;c[E>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](E,7,0)|0;if((D|0)<1){P=1;i=b;return P|0}if((gzL(M,0,7)|0)==0){break}else{P=1}i=b;return P|0}}while(0);M=c[3529530]|0;E=c[2406528]|0;L=0;do{G=L<<6;gGz(E+G|0,0,64);D=L<<8;I=0;do{F=1<<3-I;K=(c[703416+(I<<2)>>2]|0)+D|0;H=0;do{N=K+(c[1183816+(H<<2)>>2]|0)|0;J=(H<<3)+G|0;Q=0;do{R=N+(c[1183848+(Q<<2)>>2]|0)|0;if(((d[M+((R|0)/8|0)|0]|0)&128>>>((R&7)>>>0)|0)!=0){R=E+(J+Q)|0;a[R]=(d[R]|0|F)&255}Q=Q+1|0;}while((Q|0)<8);H=H+1|0;}while((H|0)<8);I=I+1|0;}while((I|0)<4);L=L+1|0;}while((L|0)<256);gGz(M|0,0,131072);if((c[3542200]|0)==0){P=1;i=b;return P|0}L=B+108|0;c[L>>2]=0;E=B+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](B,8)|0;do{if((c[L>>2]|0)!=0){B=c[E>>2]|0;c[C>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](C,8,0)|0;if((B|0)<1){P=1;i=b;return P|0}if((gzL(M,0,8)|0)==0){break}else{P=1}i=b;return P|0}}while(0);M=(c[3529530]|0)+32768|0;if((c[3542200]|0)==0){P=1;i=b;return P|0}C=z+108|0;c[C>>2]=0;E=z+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,9)|0;do{if((c[C>>2]|0)!=0){z=c[E>>2]|0;c[A>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](A,9,0)|0;if((z|0)<1){P=1;i=b;return P|0}if((gzL(M,0,9)|0)==0){break}else{P=1}i=b;return P|0}}while(0);M=(c[3529530]|0)+65536|0;if((c[3542200]|0)==0){P=1;i=b;return P|0}A=x+108|0;c[A>>2]=0;E=x+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,10)|0;do{if((c[A>>2]|0)!=0){x=c[E>>2]|0;c[y>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](y,10,0)|0;if((x|0)<1){P=1;i=b;return P|0}if((gzL(M,0,10)|0)==0){break}else{P=1}i=b;return P|0}}while(0);M=c[3529530]|0;y=c[2405816]|0;E=0;do{A=E<<8;gGz(y+A|0,0,256);x=E<<10;C=0;do{z=1<<3-C;L=(c[703416+(C<<2)>>2]|0)+x|0;B=0;do{I=L+(c[611904+(B<<2)>>2]|0)|0;G=(B<<4)+A|0;D=0;do{H=I+(c[612512+(D<<2)>>2]|0)|0;if(((d[M+((H|0)/8|0)|0]|0)&128>>>((H&7)>>>0)|0)!=0){H=y+(G+D)|0;a[H]=(d[H]|0|z)&255}D=D+1|0;}while((D|0)<16);B=B+1|0;}while((B|0)<16);C=C+1|0;}while((C|0)<4);E=E+1|0;}while((E|0)<1024);gGz(M|0,0,131072);if((c[3542200]|0)==0){P=1;i=b;return P|0}E=v+108|0;c[E>>2]=0;y=v+100|0;c[y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,11)|0;do{if((c[E>>2]|0)!=0){v=c[y>>2]|0;c[w>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](w,11,0)|0;if((v|0)<1){P=1;i=b;return P|0}if((gzL(M,0,11)|0)==0){break}else{P=1}i=b;return P|0}}while(0);M=(c[3529530]|0)+16384|0;if((c[3542200]|0)==0){P=1;i=b;return P|0}w=t+108|0;c[w>>2]=0;y=t+100|0;c[y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,12)|0;do{if((c[w>>2]|0)!=0){t=c[y>>2]|0;c[u>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](u,12,0)|0;if((t|0)<1){P=1;i=b;return P|0}if((gzL(M,0,12)|0)==0){break}else{P=1}i=b;return P|0}}while(0);M=(c[3529530]|0)+32768|0;if((c[3542200]|0)==0){P=1;i=b;return P|0}u=r+108|0;c[u>>2]=0;y=r+100|0;c[y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,13)|0;do{if((c[u>>2]|0)!=0){r=c[y>>2]|0;c[s>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](s,13,0)|0;if((r|0)<1){P=1;i=b;return P|0}if((gzL(M,0,13)|0)==0){break}else{P=1}i=b;return P|0}}while(0);M=(c[3529530]|0)+49152|0;if((c[3542200]|0)==0){P=1;i=b;return P|0}s=p+108|0;c[s>>2]=0;y=p+100|0;c[y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,14)|0;do{if((c[s>>2]|0)!=0){p=c[y>>2]|0;c[q>>2]=9534384;u=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[u&16383](q,14,0)|0;if((p|0)<1){P=1;i=b;return P|0}if((gzL(M,0,14)|0)==0){break}else{P=1}i=b;return P|0}}while(0);M=c[3529530]|0;q=c[3529580]|0;y=0;do{s=y<<8;gGz(q+s|0,0,256);p=y<<9;u=0;do{r=1<<3-u;w=(c[703416+(u<<2)>>2]|0)+p|0;t=0;do{E=w+(c[611840+(t<<2)>>2]|0)|0;v=(t<<4)+s|0;C=0;do{A=E+(c[4969752+(C<<2)>>2]|0)|0;if(((d[M+((A|0)/8|0)|0]|0)&128>>>((A&7)>>>0)|0)!=0){A=q+(v+C)|0;a[A]=(d[A]|0|r)&255}C=C+1|0;}while((C|0)<16);t=t+1|0;}while((t|0)<16);u=u+1|0;}while((u|0)<4);y=y+1|0;}while((y|0)<512);y=c[2406284]|0;if((c[3542200]|0)==0){P=1;i=b;return P|0}q=n+108|0;c[q>>2]=0;M=n+100|0;c[M>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,15)|0;do{if((c[q>>2]|0)!=0){n=c[M>>2]|0;c[o>>2]=9534384;u=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[u&16383](o,15,0)|0;if((n|0)<1){P=1;i=b;return P|0}if((gzL(y,0,15)|0)==0){break}else{P=1}i=b;return P|0}}while(0);y=(c[2406284]|0)+256|0;if((c[3542200]|0)==0){P=1;i=b;return P|0}o=l+108|0;c[o>>2]=0;M=l+100|0;c[M>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,16)|0;do{if((c[o>>2]|0)!=0){l=c[M>>2]|0;c[m>>2]=9534384;q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[q&16383](m,16,0)|0;if((l|0)<1){P=1;i=b;return P|0}if((gzL(y,0,16)|0)==0){break}else{P=1}i=b;return P|0}}while(0);y=(c[2406284]|0)+512|0;if((c[3542200]|0)==0){P=1;i=b;return P|0}m=j+108|0;c[m>>2]=0;M=j+100|0;c[M>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,17)|0;do{if((c[m>>2]|0)!=0){j=c[M>>2]|0;c[k>>2]=9534384;o=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[o&16383](k,17,0)|0;if((j|0)<1){P=1;i=b;return P|0}if((gzL(y,0,17)|0)==0){break}else{P=1}i=b;return P|0}}while(0);y=(c[2406284]|0)+768|0;if((c[3542200]|0)==0){P=1;i=b;return P|0}k=g+108|0;c[k>>2]=0;M=g+100|0;c[M>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,18)|0;do{if((c[k>>2]|0)!=0){g=c[M>>2]|0;c[h>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](h,18,0)|0;if((g|0)<1){P=1;i=b;return P|0}if((gzL(y,0,18)|0)==0){break}else{P=1}i=b;return P|0}}while(0);y=c[2433442]|0;if((c[3542200]|0)==0){P=1;i=b;return P|0}h=e+108|0;c[h>>2]=0;M=e+100|0;c[M>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,19)|0;do{if((c[h>>2]|0)!=0){e=c[M>>2]|0;c[f>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](f,19,0)|0;if((e|0)<1){P=1;i=b;return P|0}if((gzL(y,0,19)|0)==0){break}else{P=1}i=b;return P|0}}while(0);y=c[3529530]|0;f=0;while(1){if((f|0)>=1024){break}S=9638528+(f<<2)|0;if((c[S>>2]|0)==(y|0)){O=2424;break}else{f=f+1|0}}if((O|0)==2424){gGr(y);c[S>>2]=0}c[3529530]=0;P=0;i=b;return P|0}function dzX(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;b=i;i=i+1680|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;l=b+360|0;m=b+472|0;n=b+480|0;o=b+592|0;p=b+600|0;q=b+712|0;r=b+720|0;s=b+832|0;t=b+840|0;u=b+952|0;v=b+960|0;w=b+1072|0;x=b+1080|0;y=b+1192|0;z=b+1200|0;A=b+1312|0;B=b+1320|0;C=b+1432|0;D=b+1440|0;E=b+1552|0;F=b+1560|0;G=b+1672|0;H=0;while(1){if((H|0)>=1024){I=0;break}J=9638528+(H<<2)|0;if((c[J>>2]|0)==0){K=2483;break}else{H=H+1|0}}do{if((K|0)==2483){H=gGq(65536)|0;c[J>>2]=H;if((H|0)==0){I=0;break}gGz(H|0,0,65536);I=H}}while(0);c[3529530]=I;if((R6(c[2388032]|0,0,2)|0)!=0){L=1;i=b;return L|0}if((R6((c[2388032]|0)+1|0,1,2)|0)!=0){L=1;i=b;return L|0}if((R6((c[2388032]|0)+32768|0,2,2)|0)!=0){L=1;i=b;return L|0}if((R6((c[2388032]|0)+32769|0,3,2)|0)!=0){L=1;i=b;return L|0}if((R6((c[2388032]|0)+65536|0,4,2)|0)!=0){L=1;i=b;return L|0}if((R6((c[2388032]|0)+65537|0,5,2)|0)!=0){L=1;i=b;return L|0}if((R6((c[2388032]|0)+98304|0,6,2)|0)!=0){L=1;i=b;return L|0}if((R6((c[2388032]|0)+98305|0,7,2)|0)!=0){L=1;i=b;return L|0}I=c[2385840]|0;if((c[3542200]|0)==0){L=1;i=b;return L|0}J=F+108|0;c[J>>2]=0;H=F+100|0;c[H>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](F,8)|0;do{if((c[J>>2]|0)!=0){F=c[H>>2]|0;c[G>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](G,8,0)|0;if((F|0)<1){L=1;i=b;return L|0}if((gzL(I,0,8)|0)==0){break}else{L=1}i=b;return L|0}}while(0);I=(c[2385840]|0)+16384|0;if((c[3542200]|0)==0){L=1;i=b;return L|0}G=D+108|0;c[G>>2]=0;H=D+100|0;c[H>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](D,9)|0;do{if((c[G>>2]|0)!=0){D=c[H>>2]|0;c[E>>2]=9534384;J=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[J&16383](E,9,0)|0;if((D|0)<1){L=1;i=b;return L|0}if((gzL(I,0,9)|0)==0){break}else{L=1}i=b;return L|0}}while(0);gGz((c[2385840]|0)+32768|0,-1|0,16384);I=c[3529530]|0;gGz(I|0,0,65536);if((c[3542200]|0)==0){L=1;i=b;return L|0}E=B+108|0;c[E>>2]=0;H=B+100|0;c[H>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](B,10)|0;do{if((c[E>>2]|0)!=0){B=c[H>>2]|0;c[C>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](C,10,0)|0;if((B|0)<1){L=1;i=b;return L|0}if((gzL(I,0,10)|0)==0){break}else{L=1}i=b;return L|0}}while(0);I=c[3529530]|0;C=c[2406528]|0;H=0;do{E=H<<6;gGz(C+E|0,0,64);B=H<<8;G=0;do{D=1<<3-G;J=(c[703416+(G<<2)>>2]|0)+B|0;F=0;do{M=J+(c[1183816+(F<<2)>>2]|0)|0;N=(F<<3)+E|0;O=0;do{P=M+(c[1183848+(O<<2)>>2]|0)|0;if(((d[I+((P|0)/8|0)|0]|0)&128>>>((P&7)>>>0)|0)!=0){P=C+(N+O)|0;a[P]=(d[P]|0|D)&255}O=O+1|0;}while((O|0)<8);F=F+1|0;}while((F|0)<8);G=G+1|0;}while((G|0)<4);H=H+1|0;}while((H|0)<256);gGz(I|0,0,65536);if((c[3542200]|0)==0){L=1;i=b;return L|0}H=z+108|0;c[H>>2]=0;C=z+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,11)|0;do{if((c[H>>2]|0)!=0){z=c[C>>2]|0;c[A>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](A,11,0)|0;if((z|0)<1){L=1;i=b;return L|0}if((gzL(I,0,11)|0)==0){break}else{L=1}i=b;return L|0}}while(0);I=(c[3529530]|0)+32768|0;if((c[3542200]|0)==0){L=1;i=b;return L|0}A=x+108|0;c[A>>2]=0;C=x+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,12)|0;do{if((c[A>>2]|0)!=0){x=c[C>>2]|0;c[y>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](y,12,0)|0;if((x|0)<1){L=1;i=b;return L|0}if((gzL(I,0,12)|0)==0){break}else{L=1}i=b;return L|0}}while(0);I=c[3529530]|0;y=c[2405816]|0;C=0;do{A=C<<8;gGz(y+A|0,0,256);x=C<<10;H=0;do{z=1<<3-H;G=(c[703416+(H<<2)>>2]|0)+x|0;E=0;do{B=G+(c[611904+(E<<2)>>2]|0)|0;F=(E<<4)+A|0;D=0;do{J=B+(c[612512+(D<<2)>>2]|0)|0;if(((d[I+((J|0)/8|0)|0]|0)&128>>>((J&7)>>>0)|0)!=0){J=y+(F+D)|0;a[J]=(d[J]|0|z)&255}D=D+1|0;}while((D|0)<16);E=E+1|0;}while((E|0)<16);H=H+1|0;}while((H|0)<4);C=C+1|0;}while((C|0)<512);gGz(I|0,0,65536);if((c[3542200]|0)==0){L=1;i=b;return L|0}C=v+108|0;c[C>>2]=0;y=v+100|0;c[y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,13)|0;do{if((c[C>>2]|0)!=0){v=c[y>>2]|0;c[w>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](w,13,0)|0;if((v|0)<1){L=1;i=b;return L|0}if((gzL(I,0,13)|0)==0){break}else{L=1}i=b;return L|0}}while(0);I=(c[3529530]|0)+16384|0;if((c[3542200]|0)==0){L=1;i=b;return L|0}w=t+108|0;c[w>>2]=0;y=t+100|0;c[y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,14)|0;do{if((c[w>>2]|0)!=0){t=c[y>>2]|0;c[u>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](u,14,0)|0;if((t|0)<1){L=1;i=b;return L|0}if((gzL(I,0,14)|0)==0){break}else{L=1}i=b;return L|0}}while(0);I=(c[3529530]|0)+32768|0;if((c[3542200]|0)==0){L=1;i=b;return L|0}u=r+108|0;c[u>>2]=0;y=r+100|0;c[y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,15)|0;do{if((c[u>>2]|0)!=0){r=c[y>>2]|0;c[s>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](s,15,0)|0;if((r|0)<1){L=1;i=b;return L|0}if((gzL(I,0,15)|0)==0){break}else{L=1}i=b;return L|0}}while(0);I=(c[3529530]|0)+49152|0;if((c[3542200]|0)==0){L=1;i=b;return L|0}s=p+108|0;c[s>>2]=0;y=p+100|0;c[y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,16)|0;do{if((c[s>>2]|0)!=0){p=c[y>>2]|0;c[q>>2]=9534384;u=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[u&16383](q,16,0)|0;if((p|0)<1){L=1;i=b;return L|0}if((gzL(I,0,16)|0)==0){break}else{L=1}i=b;return L|0}}while(0);I=c[3529530]|0;q=c[3529580]|0;y=0;do{s=y<<8;gGz(q+s|0,0,256);p=y<<9;u=0;do{r=1<<3-u;w=(c[703416+(u<<2)>>2]|0)+p|0;t=0;do{C=w+(c[611840+(t<<2)>>2]|0)|0;v=(t<<4)+s|0;H=0;do{A=C+(c[4969752+(H<<2)>>2]|0)|0;if(((d[I+((A|0)/8|0)|0]|0)&128>>>((A&7)>>>0)|0)!=0){A=q+(v+H)|0;a[A]=(d[A]|0|r)&255}H=H+1|0;}while((H|0)<16);t=t+1|0;}while((t|0)<16);u=u+1|0;}while((u|0)<4);y=y+1|0;}while((y|0)<512);y=c[2406284]|0;if((c[3542200]|0)==0){L=1;i=b;return L|0}q=n+108|0;c[q>>2]=0;I=n+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,17)|0;do{if((c[q>>2]|0)!=0){n=c[I>>2]|0;c[o>>2]=9534384;u=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[u&16383](o,17,0)|0;if((n|0)<1){L=1;i=b;return L|0}if((gzL(y,0,17)|0)==0){break}else{L=1}i=b;return L|0}}while(0);y=(c[2406284]|0)+256|0;if((c[3542200]|0)==0){L=1;i=b;return L|0}o=l+108|0;c[o>>2]=0;I=l+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,18)|0;do{if((c[o>>2]|0)!=0){l=c[I>>2]|0;c[m>>2]=9534384;q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[q&16383](m,18,0)|0;if((l|0)<1){L=1;i=b;return L|0}if((gzL(y,0,18)|0)==0){break}else{L=1}i=b;return L|0}}while(0);y=(c[2406284]|0)+512|0;if((c[3542200]|0)==0){L=1;i=b;return L|0}m=j+108|0;c[m>>2]=0;I=j+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,19)|0;do{if((c[m>>2]|0)!=0){j=c[I>>2]|0;c[k>>2]=9534384;o=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[o&16383](k,19,0)|0;if((j|0)<1){L=1;i=b;return L|0}if((gzL(y,0,19)|0)==0){break}else{L=1}i=b;return L|0}}while(0);y=(c[2406284]|0)+768|0;if((c[3542200]|0)==0){L=1;i=b;return L|0}k=g+108|0;c[k>>2]=0;I=g+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,20)|0;do{if((c[k>>2]|0)!=0){g=c[I>>2]|0;c[h>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](h,20,0)|0;if((g|0)<1){L=1;i=b;return L|0}if((gzL(y,0,20)|0)==0){break}else{L=1}i=b;return L|0}}while(0);y=c[2433442]|0;if((c[3542200]|0)==0){L=1;i=b;return L|0}h=e+108|0;c[h>>2]=0;I=e+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,21)|0;do{if((c[h>>2]|0)!=0){e=c[I>>2]|0;c[f>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](f,21,0)|0;if((e|0)<1){L=1;i=b;return L|0}if((gzL(y,0,21)|0)==0){break}else{L=1}i=b;return L|0}}while(0);y=c[3529530]|0;f=0;while(1){if((f|0)>=1024){break}Q=9638528+(f<<2)|0;if((c[Q>>2]|0)==(y|0)){K=2582;break}else{f=f+1|0}}if((K|0)==2582){gGr(y);c[Q>>2]=0}c[3529530]=0;L=0;i=b;return L|0}function dzY(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;c[2426770]=0;c[2388032]=0;c[2385840]=131072;c[2406284]=180224;c[2433442]=181248;c[2405688]=181504;c[2443420]=185600;c[2439960]=193792;c[2439942]=197888;c[2385858]=201984;c[2411750]=206080;c[2406528]=206080;c[2405816]=222464;c[3529580]=484608;c[3530072]=746752;d=0;while(1){if((d|0)>=1024){break}e=9638528+(d<<2)|0;if((c[e>>2]|0)==0){f=2639;break}else{d=d+1|0}}do{if((f|0)==2639){d=gGq(764224)|0;c[e>>2]=d;if((d|0)==0){break}c[2426770]=d;gGz(d|0,0,764224);c[2388032]=d;c[2385840]=d+131072;c[2406284]=d+180224;c[2433442]=d+181248;g=d+181504|0;c[2405688]=g;c[2388054]=g;c[2443420]=d+185600;c[2439960]=d+193792;c[2439942]=d+197888;c[2385858]=d+201984;g=d+206080|0;c[2411750]=g;c[2406528]=g;c[2405816]=d+222464;c[3529580]=d+484608;c[3530072]=d+746752;c[2414294]=d+764224;if((gD[c[2433364]&8191]()|0)!=0){i=1;return i|0}fxU(0,425984);if((c[2394]|0)==0){j=c[2112932]|0}else{c[2394]=0;d=c[3532596]|0;c[2112932]=d;g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060];j=d}d=c[2388032]|0;g=j|0;k=0;while(1){l=d+k|0;c[g>>2]=l;c[g+131072>>2]=l;l=k+1024|0;if(l>>>0>131071){break}else{g=g+4|0;k=l}}k=c[2443420]|0;c[j+512>>2]=k;c[j+66048>>2]=k;c[j+131584>>2]=k;g=k+1024|0;c[j+516>>2]=g;c[j+66052>>2]=g;c[j+131588>>2]=g;g=k+2048|0;c[j+520>>2]=g;c[j+66056>>2]=g;c[j+131592>>2]=g;g=k+3072|0;c[j+524>>2]=g;c[j+66060>>2]=g;c[j+131596>>2]=g;g=k+4096|0;c[j+528>>2]=g;c[j+66064>>2]=g;c[j+131600>>2]=g;g=k+5120|0;c[j+532>>2]=g;c[j+66068>>2]=g;c[j+131604>>2]=g;g=k+6144|0;c[j+536>>2]=g;c[j+66072>>2]=g;c[j+131608>>2]=g;g=k+7168|0;c[j+540>>2]=g;c[j+66076>>2]=g;c[j+131612>>2]=g;g=c[2439960]|0;c[j+544>>2]=g;c[j+66080>>2]=g;c[j+131616>>2]=g;k=g+1024|0;c[j+548>>2]=k;c[j+66084>>2]=k;c[j+131620>>2]=k;k=g+2048|0;c[j+552>>2]=k;c[j+66088>>2]=k;c[j+131624>>2]=k;k=g+3072|0;c[j+556>>2]=k;c[j+66092>>2]=k;c[j+131628>>2]=k;k=c[2439942]|0;c[j+640>>2]=k;c[j+66176>>2]=k;c[j+131712>>2]=k;g=k+1024|0;c[j+644>>2]=g;c[j+66180>>2]=g;c[j+131716>>2]=g;c[j+196688>>2]=2054;c[j+196728>>2]=3202;c[j+196608>>2]=3302;c[j+196648>>2]=1628;g=c[3532592]|0;if((g|0)!=0){gGC(g|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);g=c[2439330]|0;k=(g|0)==0;if(!k){d=g;gGC(9706056,d|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];d=c[3528484]|0;c[2076596]=d;l=c[2417276]|0;c[3541536]=l;c[1836236]=0;c[g+4172>>2]=768;m=a[6923440]|0;c[g+4176>>2]=m?76:1838;n=c[2385840]|0;o=0;p=0;while(1){c[g+76+(p<<2)>>2]=n+(p<<8);q=o+1&65535;if((q&65535)>191){r=0;s=0;break}else{o=q;p=q&65535}}while(1){p=n+(s<<8)|0;c[g+76+(s+512<<2)>>2]=p;c[g+76+(s+768<<2)>>2]=p;p=r+1&65535;if((p&65535)>191){break}else{r=p;s=p&65535}}n=c[2385858]|0;c[g+844>>2]=n;c[g+848>>2]=n+256;c[g+852>>2]=n+512;c[g+856>>2]=n+768;c[g+860>>2]=n+1024;c[g+864>>2]=n+1280;c[g+868>>2]=n+1536;c[g+872>>2]=n+1792;c[g+876>>2]=n+2048;c[g+880>>2]=n+2304;c[g+884>>2]=n+2560;c[g+888>>2]=n+2816;c[g+892>>2]=n+3072;c[g+896>>2]=n+3328;c[g+900>>2]=n+3584;c[g+904>>2]=n+3840;p=192;o=192;while(1){c[g+76+(o+256<<2)>>2]=n+((o<<8)-49152);q=p+1&65535;if((q&65535)>207){t=192;u=192;break}else{p=q;o=q&65535}}while(1){o=n+((u<<8)-49152)|0;c[g+76+(u+512<<2)>>2]=o;c[g+76+(u+768<<2)>>2]=o;o=t+1&65535;if((o&65535)>207){break}else{t=o;u=o&65535}}if(!k){n=g;gGC(n|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=d;c[2417276]=l;c[1836236]=-1;if(m){Vr(1,4e6,0,2314,36,0);c[2438228]=4e6;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=511;h[745419]=.4;a[3203368]=1;h[745418]=.2;a[3203360]=1;h[745417]=.2;a[3203352]=1;h[745416]=.2;a[3203344]=1}else{U6(4e6,0,2314,0);c[2438222]=4e6;c[2433520]=3416;c[2406670]=1752;c[3528466]=9362;c[2443840]=511;h[745399]=1.0;a[3203272]=1}c[2405758]=1;gGz(9542544,0,32);c[2385641]=1;h[1192819]=1.0;c[2385642]=3;c[2385643]=4324;n=0;do{o=n*257|0;b[9732544+(n<<1)>>1]=((o|0)/2|0)&65535;b[9753784+(n<<1)>>1]=o+32768&65535;n=n+1|0;}while((n|0)<256);c[3528842]=1;c[2405758]=2;gGz(9542576,0,32);c[2385649]=1;h[1192823]=1.0;c[2385650]=3;c[2385651]=4324;n=0;do{m=n*257|0;b[9732544+(n<<1)>>1]=((m|0)/2|0)&65535;b[9753784+(n<<1)>>1]=m+32768&65535;n=n+1|0;}while((n|0)<256);c[3528842]=1;h[1192819]=.5;c[2385642]=3;h[1192823]=.5;c[2385650]=3;n=c[642608+(c[2436]<<2)>>2]|0;m=c[n+128>>2]|0;if((c[n+52>>2]&4|0)==0){c[2113068]=m;l=c[n+132>>2]|0;c[2113070]=l;c[2443814]=m;c[2440436]=l;v=m;w=l}else{c[2113070]=m;l=c[n+132>>2]|0;c[2113068]=l;c[2440436]=m;c[2443814]=l;v=l;w=m}m=ag(v<<1,w)|0;l=gGq(m)|0;c[2112926]=l;if((l|0)!=0){gGz(l|0,0,m|0)}a[9773960]=1;dzV();i=0;return i|0}}while(0);c[2426770]=0;i=1;return i|0}function dzZ(){return+(+((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)/4.0e6)}function dz_(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;b=i;i=i+1800|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;l=b+360|0;m=b+472|0;n=b+480|0;o=b+592|0;p=b+600|0;q=b+712|0;r=b+720|0;s=b+832|0;t=b+840|0;u=b+952|0;v=b+960|0;w=b+1072|0;x=b+1080|0;y=b+1192|0;z=b+1200|0;A=b+1312|0;B=b+1320|0;C=b+1432|0;D=b+1440|0;E=b+1552|0;F=b+1560|0;G=b+1672|0;H=b+1680|0;I=b+1792|0;J=0;while(1){if((J|0)>=1024){K=0;break}L=9638528+(J<<2)|0;if((c[L>>2]|0)==0){M=2682;break}else{J=J+1|0}}do{if((M|0)==2682){J=gGq(65536)|0;c[L>>2]=J;if((J|0)==0){K=0;break}gGz(J|0,0,65536);K=J}}while(0);c[3529530]=K;if((R6(c[2388032]|0,0,2)|0)!=0){N=1;i=b;return N|0}if((R6((c[2388032]|0)+1|0,1,2)|0)!=0){N=1;i=b;return N|0}if((R6((c[2388032]|0)+32768|0,2,2)|0)!=0){N=1;i=b;return N|0}if((R6((c[2388032]|0)+32769|0,3,2)|0)!=0){N=1;i=b;return N|0}if((R6((c[2388032]|0)+65536|0,4,2)|0)!=0){N=1;i=b;return N|0}if((R6((c[2388032]|0)+65537|0,5,2)|0)!=0){N=1;i=b;return N|0}if((R6((c[2388032]|0)+98304|0,6,2)|0)!=0){N=1;i=b;return N|0}if((R6((c[2388032]|0)+98305|0,7,2)|0)!=0){N=1;i=b;return N|0}K=c[2385840]|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}L=H+108|0;c[L>>2]=0;J=H+100|0;c[J>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](H,8)|0;do{if((c[L>>2]|0)!=0){H=c[J>>2]|0;c[I>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](I,8,0)|0;if((H|0)<1){N=1;i=b;return N|0}if((gzL(K,0,8)|0)==0){break}else{N=1}i=b;return N|0}}while(0);K=(c[2385840]|0)+16384|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}I=F+108|0;c[I>>2]=0;J=F+100|0;c[J>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](F,9)|0;do{if((c[I>>2]|0)!=0){F=c[J>>2]|0;c[G>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](G,9,0)|0;if((F|0)<1){N=1;i=b;return N|0}if((gzL(K,0,9)|0)==0){break}else{N=1}i=b;return N|0}}while(0);K=(c[2385840]|0)+32768|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}G=D+108|0;c[G>>2]=0;J=D+100|0;c[J>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](D,10)|0;do{if((c[G>>2]|0)!=0){D=c[J>>2]|0;c[E>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](E,10,0)|0;if((D|0)<1){N=1;i=b;return N|0}if((gzL(K,0,10)|0)==0){break}else{N=1}i=b;return N|0}}while(0);K=c[3529530]|0;gGz(K|0,0,65536);if((c[3542200]|0)==0){N=1;i=b;return N|0}E=B+108|0;c[E>>2]=0;J=B+100|0;c[J>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](B,11)|0;do{if((c[E>>2]|0)!=0){B=c[J>>2]|0;c[C>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](C,11,0)|0;if((B|0)<1){N=1;i=b;return N|0}if((gzL(K,0,11)|0)==0){break}else{N=1}i=b;return N|0}}while(0);K=c[3529530]|0;C=c[2406528]|0;J=0;do{E=J<<6;gGz(C+E|0,0,64);B=J<<8;G=0;do{D=1<<3-G;I=(c[703416+(G<<2)>>2]|0)+B|0;F=0;do{L=I+(c[1183816+(F<<2)>>2]|0)|0;H=(F<<3)+E|0;O=0;do{P=L+(c[1183848+(O<<2)>>2]|0)|0;if(((d[K+((P|0)/8|0)|0]|0)&128>>>((P&7)>>>0)|0)!=0){P=C+(H+O)|0;a[P]=(d[P]|0|D)&255}O=O+1|0;}while((O|0)<8);F=F+1|0;}while((F|0)<8);G=G+1|0;}while((G|0)<4);J=J+1|0;}while((J|0)<256);gGz(K|0,0,65536);if((c[3542200]|0)==0){N=1;i=b;return N|0}J=z+108|0;c[J>>2]=0;C=z+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,12)|0;do{if((c[J>>2]|0)!=0){z=c[C>>2]|0;c[A>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](A,12,0)|0;if((z|0)<1){N=1;i=b;return N|0}if((gzL(K,0,12)|0)==0){break}else{N=1}i=b;return N|0}}while(0);K=(c[3529530]|0)+32768|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}A=x+108|0;c[A>>2]=0;C=x+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,13)|0;do{if((c[A>>2]|0)!=0){x=c[C>>2]|0;c[y>>2]=9534384;J=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[J&16383](y,13,0)|0;if((x|0)<1){N=1;i=b;return N|0}if((gzL(K,0,13)|0)==0){break}else{N=1}i=b;return N|0}}while(0);K=c[3529530]|0;y=c[2405816]|0;C=0;do{A=C<<8;gGz(y+A|0,0,256);x=C<<10;J=0;do{z=1<<3-J;G=(c[703416+(J<<2)>>2]|0)+x|0;E=0;do{B=G+(c[611904+(E<<2)>>2]|0)|0;F=(E<<4)+A|0;D=0;do{I=B+(c[612512+(D<<2)>>2]|0)|0;if(((d[K+((I|0)/8|0)|0]|0)&128>>>((I&7)>>>0)|0)!=0){I=y+(F+D)|0;a[I]=(d[I]|0|z)&255}D=D+1|0;}while((D|0)<16);E=E+1|0;}while((E|0)<16);J=J+1|0;}while((J|0)<4);C=C+1|0;}while((C|0)<512);gGz(K|0,0,65536);if((c[3542200]|0)==0){N=1;i=b;return N|0}C=v+108|0;c[C>>2]=0;y=v+100|0;c[y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,14)|0;do{if((c[C>>2]|0)!=0){v=c[y>>2]|0;c[w>>2]=9534384;J=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[J&16383](w,14,0)|0;if((v|0)<1){N=1;i=b;return N|0}if((gzL(K,0,14)|0)==0){break}else{N=1}i=b;return N|0}}while(0);K=(c[3529530]|0)+16384|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}w=t+108|0;c[w>>2]=0;y=t+100|0;c[y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,15)|0;do{if((c[w>>2]|0)!=0){t=c[y>>2]|0;c[u>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](u,15,0)|0;if((t|0)<1){N=1;i=b;return N|0}if((gzL(K,0,15)|0)==0){break}else{N=1}i=b;return N|0}}while(0);K=(c[3529530]|0)+32768|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}u=r+108|0;c[u>>2]=0;y=r+100|0;c[y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,16)|0;do{if((c[u>>2]|0)!=0){r=c[y>>2]|0;c[s>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](s,16,0)|0;if((r|0)<1){N=1;i=b;return N|0}if((gzL(K,0,16)|0)==0){break}else{N=1}i=b;return N|0}}while(0);K=(c[3529530]|0)+49152|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}s=p+108|0;c[s>>2]=0;y=p+100|0;c[y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,17)|0;do{if((c[s>>2]|0)!=0){p=c[y>>2]|0;c[q>>2]=9534384;u=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[u&16383](q,17,0)|0;if((p|0)<1){N=1;i=b;return N|0}if((gzL(K,0,17)|0)==0){break}else{N=1}i=b;return N|0}}while(0);K=c[3529530]|0;q=c[3529580]|0;y=0;do{s=y<<8;gGz(q+s|0,0,256);p=y<<9;u=0;do{r=1<<3-u;w=(c[703416+(u<<2)>>2]|0)+p|0;t=0;do{C=w+(c[611840+(t<<2)>>2]|0)|0;v=(t<<4)+s|0;J=0;do{A=C+(c[4969752+(J<<2)>>2]|0)|0;if(((d[K+((A|0)/8|0)|0]|0)&128>>>((A&7)>>>0)|0)!=0){A=q+(v+J)|0;a[A]=(d[A]|0|r)&255}J=J+1|0;}while((J|0)<16);t=t+1|0;}while((t|0)<16);u=u+1|0;}while((u|0)<4);y=y+1|0;}while((y|0)<512);y=c[2406284]|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}q=n+108|0;c[q>>2]=0;K=n+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,18)|0;do{if((c[q>>2]|0)!=0){n=c[K>>2]|0;c[o>>2]=9534384;u=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[u&16383](o,18,0)|0;if((n|0)<1){N=1;i=b;return N|0}if((gzL(y,0,18)|0)==0){break}else{N=1}i=b;return N|0}}while(0);y=(c[2406284]|0)+256|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}o=l+108|0;c[o>>2]=0;K=l+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,19)|0;do{if((c[o>>2]|0)!=0){l=c[K>>2]|0;c[m>>2]=9534384;q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[q&16383](m,19,0)|0;if((l|0)<1){N=1;i=b;return N|0}if((gzL(y,0,19)|0)==0){break}else{N=1}i=b;return N|0}}while(0);y=(c[2406284]|0)+512|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}m=j+108|0;c[m>>2]=0;K=j+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,20)|0;do{if((c[m>>2]|0)!=0){j=c[K>>2]|0;c[k>>2]=9534384;o=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[o&16383](k,20,0)|0;if((j|0)<1){N=1;i=b;return N|0}if((gzL(y,0,20)|0)==0){break}else{N=1}i=b;return N|0}}while(0);y=(c[2406284]|0)+768|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}k=g+108|0;c[k>>2]=0;K=g+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,21)|0;do{if((c[k>>2]|0)!=0){g=c[K>>2]|0;c[h>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](h,21,0)|0;if((g|0)<1){N=1;i=b;return N|0}if((gzL(y,0,21)|0)==0){break}else{N=1}i=b;return N|0}}while(0);y=c[2433442]|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}h=e+108|0;c[h>>2]=0;K=e+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,22)|0;do{if((c[h>>2]|0)!=0){e=c[K>>2]|0;c[f>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](f,22,0)|0;if((e|0)<1){N=1;i=b;return N|0}if((gzL(y,0,22)|0)==0){break}else{N=1}i=b;return N|0}}while(0);y=c[3529530]|0;f=0;while(1){if((f|0)>=1024){break}Q=9638528+(f<<2)|0;if((c[Q>>2]|0)==(y|0)){M=2785;break}else{f=f+1|0}}if((M|0)==2785){gGr(y);c[Q>>2]=0}c[3529530]=0;N=0;i=b;return N|0}function dz$(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;b=i;i=i+1800|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;l=b+360|0;m=b+472|0;n=b+480|0;o=b+592|0;p=b+600|0;q=b+712|0;r=b+720|0;s=b+832|0;t=b+840|0;u=b+952|0;v=b+960|0;w=b+1072|0;x=b+1080|0;y=b+1192|0;z=b+1200|0;A=b+1312|0;B=b+1320|0;C=b+1432|0;D=b+1440|0;E=b+1552|0;F=b+1560|0;G=b+1672|0;H=b+1680|0;I=b+1792|0;J=0;while(1){if((J|0)>=1024){K=0;break}L=9638528+(J<<2)|0;if((c[L>>2]|0)==0){M=2845;break}else{J=J+1|0}}do{if((M|0)==2845){J=gGq(65536)|0;c[L>>2]=J;if((J|0)==0){K=0;break}gGz(J|0,0,65536);K=J}}while(0);c[3529530]=K;if((R6(c[2388032]|0,0,2)|0)!=0){N=1;i=b;return N|0}if((R6((c[2388032]|0)+1|0,1,2)|0)!=0){N=1;i=b;return N|0}if((R6((c[2388032]|0)+65536|0,2,2)|0)!=0){N=1;i=b;return N|0}if((R6((c[2388032]|0)+65537|0,3,2)|0)!=0){N=1;i=b;return N|0}K=c[2385840]|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}L=H+108|0;c[L>>2]=0;J=H+100|0;c[J>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](H,4)|0;do{if((c[L>>2]|0)!=0){H=c[J>>2]|0;c[I>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](I,4,0)|0;if((H|0)<1){N=1;i=b;return N|0}if((gzL(K,0,4)|0)==0){break}else{N=1}i=b;return N|0}}while(0);K=(c[2385840]|0)+16384|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}I=F+108|0;c[I>>2]=0;J=F+100|0;c[J>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](F,5)|0;do{if((c[I>>2]|0)!=0){F=c[J>>2]|0;c[G>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](G,5,0)|0;if((F|0)<1){N=1;i=b;return N|0}if((gzL(K,0,5)|0)==0){break}else{N=1}i=b;return N|0}}while(0);K=(c[2385840]|0)+32768|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}G=D+108|0;c[G>>2]=0;J=D+100|0;c[J>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](D,6)|0;do{if((c[G>>2]|0)!=0){D=c[J>>2]|0;c[E>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](E,6,0)|0;if((D|0)<1){N=1;i=b;return N|0}if((gzL(K,0,6)|0)==0){break}else{N=1}i=b;return N|0}}while(0);K=c[3529530]|0;gGz(K|0,0,65536);if((c[3542200]|0)==0){N=1;i=b;return N|0}E=B+108|0;c[E>>2]=0;J=B+100|0;c[J>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](B,7)|0;do{if((c[E>>2]|0)!=0){B=c[J>>2]|0;c[C>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](C,7,0)|0;if((B|0)<1){N=1;i=b;return N|0}if((gzL(K,0,7)|0)==0){break}else{N=1}i=b;return N|0}}while(0);K=c[3529530]|0;C=c[2406528]|0;J=0;do{E=J<<6;gGz(C+E|0,0,64);B=J<<8;G=0;do{D=1<<3-G;I=(c[703416+(G<<2)>>2]|0)+B|0;F=0;do{L=I+(c[1183816+(F<<2)>>2]|0)|0;H=(F<<3)+E|0;O=0;do{P=L+(c[1183848+(O<<2)>>2]|0)|0;if(((d[K+((P|0)/8|0)|0]|0)&128>>>((P&7)>>>0)|0)!=0){P=C+(H+O)|0;a[P]=(d[P]|0|D)&255}O=O+1|0;}while((O|0)<8);F=F+1|0;}while((F|0)<8);G=G+1|0;}while((G|0)<4);J=J+1|0;}while((J|0)<256);gGz(K|0,0,65536);if((c[3542200]|0)==0){N=1;i=b;return N|0}J=z+108|0;c[J>>2]=0;C=z+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,8)|0;do{if((c[J>>2]|0)!=0){z=c[C>>2]|0;c[A>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](A,8,0)|0;if((z|0)<1){N=1;i=b;return N|0}if((gzL(K,0,8)|0)==0){break}else{N=1}i=b;return N|0}}while(0);K=(c[3529530]|0)+32768|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}A=x+108|0;c[A>>2]=0;C=x+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,9)|0;do{if((c[A>>2]|0)!=0){x=c[C>>2]|0;c[y>>2]=9534384;J=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[J&16383](y,9,0)|0;if((x|0)<1){N=1;i=b;return N|0}if((gzL(K,0,9)|0)==0){break}else{N=1}i=b;return N|0}}while(0);K=c[3529530]|0;y=c[2405816]|0;C=0;do{A=C<<8;gGz(y+A|0,0,256);x=C<<10;J=0;do{z=1<<3-J;G=(c[703416+(J<<2)>>2]|0)+x|0;E=0;do{B=G+(c[611904+(E<<2)>>2]|0)|0;F=(E<<4)+A|0;D=0;do{I=B+(c[612512+(D<<2)>>2]|0)|0;if(((d[K+((I|0)/8|0)|0]|0)&128>>>((I&7)>>>0)|0)!=0){I=y+(F+D)|0;a[I]=(d[I]|0|z)&255}D=D+1|0;}while((D|0)<16);E=E+1|0;}while((E|0)<16);J=J+1|0;}while((J|0)<4);C=C+1|0;}while((C|0)<512);gGz(K|0,0,65536);if((c[3542200]|0)==0){N=1;i=b;return N|0}C=v+108|0;c[C>>2]=0;y=v+100|0;c[y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,10)|0;do{if((c[C>>2]|0)!=0){v=c[y>>2]|0;c[w>>2]=9534384;J=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[J&16383](w,10,0)|0;if((v|0)<1){N=1;i=b;return N|0}if((gzL(K,0,10)|0)==0){break}else{N=1}i=b;return N|0}}while(0);K=(c[3529530]|0)+16384|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}w=t+108|0;c[w>>2]=0;y=t+100|0;c[y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,11)|0;do{if((c[w>>2]|0)!=0){t=c[y>>2]|0;c[u>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](u,11,0)|0;if((t|0)<1){N=1;i=b;return N|0}if((gzL(K,0,11)|0)==0){break}else{N=1}i=b;return N|0}}while(0);K=(c[3529530]|0)+32768|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}u=r+108|0;c[u>>2]=0;y=r+100|0;c[y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,12)|0;do{if((c[u>>2]|0)!=0){r=c[y>>2]|0;c[s>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](s,12,0)|0;if((r|0)<1){N=1;i=b;return N|0}if((gzL(K,0,12)|0)==0){break}else{N=1}i=b;return N|0}}while(0);K=(c[3529530]|0)+49152|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}s=p+108|0;c[s>>2]=0;y=p+100|0;c[y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,13)|0;do{if((c[s>>2]|0)!=0){p=c[y>>2]|0;c[q>>2]=9534384;u=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[u&16383](q,13,0)|0;if((p|0)<1){N=1;i=b;return N|0}if((gzL(K,0,13)|0)==0){break}else{N=1}i=b;return N|0}}while(0);K=c[3529530]|0;q=c[3529580]|0;y=0;do{s=y<<8;gGz(q+s|0,0,256);p=y<<9;u=0;do{r=1<<3-u;w=(c[703416+(u<<2)>>2]|0)+p|0;t=0;do{C=w+(c[611840+(t<<2)>>2]|0)|0;v=(t<<4)+s|0;J=0;do{A=C+(c[4969752+(J<<2)>>2]|0)|0;if(((d[K+((A|0)/8|0)|0]|0)&128>>>((A&7)>>>0)|0)!=0){A=q+(v+J)|0;a[A]=(d[A]|0|r)&255}J=J+1|0;}while((J|0)<16);t=t+1|0;}while((t|0)<16);u=u+1|0;}while((u|0)<4);y=y+1|0;}while((y|0)<512);y=c[2406284]|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}q=n+108|0;c[q>>2]=0;K=n+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,14)|0;do{if((c[q>>2]|0)!=0){n=c[K>>2]|0;c[o>>2]=9534384;u=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[u&16383](o,14,0)|0;if((n|0)<1){N=1;i=b;return N|0}if((gzL(y,0,14)|0)==0){break}else{N=1}i=b;return N|0}}while(0);y=(c[2406284]|0)+256|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}o=l+108|0;c[o>>2]=0;K=l+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,15)|0;do{if((c[o>>2]|0)!=0){l=c[K>>2]|0;c[m>>2]=9534384;q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[q&16383](m,15,0)|0;if((l|0)<1){N=1;i=b;return N|0}if((gzL(y,0,15)|0)==0){break}else{N=1}i=b;return N|0}}while(0);y=(c[2406284]|0)+512|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}m=j+108|0;c[m>>2]=0;K=j+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,16)|0;do{if((c[m>>2]|0)!=0){j=c[K>>2]|0;c[k>>2]=9534384;o=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[o&16383](k,16,0)|0;if((j|0)<1){N=1;i=b;return N|0}if((gzL(y,0,16)|0)==0){break}else{N=1}i=b;return N|0}}while(0);y=(c[2406284]|0)+768|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}k=g+108|0;c[k>>2]=0;K=g+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,17)|0;do{if((c[k>>2]|0)!=0){g=c[K>>2]|0;c[h>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](h,17,0)|0;if((g|0)<1){N=1;i=b;return N|0}if((gzL(y,0,17)|0)==0){break}else{N=1}i=b;return N|0}}while(0);y=c[2433442]|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}h=e+108|0;c[h>>2]=0;K=e+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,18)|0;do{if((c[h>>2]|0)!=0){e=c[K>>2]|0;c[f>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](f,18,0)|0;if((e|0)<1){N=1;i=b;return N|0}if((gzL(y,0,18)|0)==0){break}else{N=1}i=b;return N|0}}while(0);y=c[3529530]|0;f=0;while(1){if((f|0)>=1024){break}Q=9638528+(f<<2)|0;if((c[Q>>2]|0)==(y|0)){M=2944;break}else{f=f+1|0}}if((M|0)==2944){gGr(y);c[Q>>2]=0}c[3529530]=0;N=0;i=b;return N|0}function dz0(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=b&65535;switch(e|0){case 55298:case 55299:{a[9731776]=d;return};case 51200:{a[14113240]=d;return};case 55296:case 55297:{a[9731784+(e&1)|0]=d;return};case 51204:{e=(d&255)>>>2&3;if((c[2439210]|0)!=(e|0)){c[2439210]=e;b=c[2424762]|0;f=c[9757320+(c[1836236]<<2)>>2]|0;g=(e<<14|65536)-32768|0;e=128;h=128;while(1){c[f+76+(h<<2)>>2]=b+(g+(h<<8));i=e+1&65535;if((i&65535)>191){j=128;k=128;break}else{e=i;h=i&65535}}while(1){h=b+(g+(k<<8))|0;c[f+76+(k+512<<2)>>2]=h;c[f+76+(k+768<<2)>>2]=h;h=j+1&65535;if((h&65535)>191){break}else{j=h;k=h&65535}}}a[14114944]=d&64;a[9681680]=d&-128;return};case 55302:{a[9774832]=d&7;a[9698792]=d&16;a[9660648]=d&32;return};default:{return}}}function dz1(b){b=b|0;var c=0;switch(b&65535|0){case 49153:{c=a[9631753]<<1^~a[9631752]^a[9631754]<<2^a[9631755]<<3^a[9631756]<<4^a[9631757]<<5^a[9631758]<<6^a[9631759]<<7;return c|0};case 49156:{c=a[9635345]|0;return c|0};case 50377:{c=-1;return c|0};case 49155:{c=a[9635344]|0;return c|0};case 49154:{c=a[9629729]<<1^~a[9629728]^a[9629730]<<2^a[9629731]<<3^a[9629732]<<4^a[9629733]<<5^a[9629734]<<6^a[9629735]<<7;return c|0};case 49152:{c=a[9633953]<<1^~a[9633952]^a[9633954]<<2^a[9633955]<<3^a[9633956]<<4^a[9633957]<<5^a[9633958]<<6^a[9633959]<<7|8;return c|0};case 50378:case 50379:{c=0;return c|0};default:{c=0;return c|0}}return 0}function dz2(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=b&65535;if((e|0)==57344){b=c[3541518]|0;f=b+256|0;a[b+304|0]=d;g=d&255;if((d&255)<16){c[14168912+((c[2383582]|0)*252|0)>>2]=g&15}if((d-45&255)>=3){return}if((g|0)==47){a[b+312|0]=0;h=0}else if((g|0)==45){i=b+312|0;j=a[i]|2;a[i]=j;h=j}else if((g|0)==46){j=b+312|0;i=a[j]|1;a[j]=i;h=i}else if((g|0)==0){a[b+312|0]=2;h=2}else{h=a[b+312|0]|0}b=h&3;h=c[7461744+(b<<2)>>2]|0;lI(f,h,h,c[7461728+(b<<2)>>2]|0);return}else if((e|0)==57347){lS(1,1,d);return}else if((e|0)==57346){b=c[3541518]|0;h=b+19280|0;a[b+19328|0]=d;f=d&255;if((d&255)<16){c[14168912+(((c[2383582]|0)+1|0)*252|0)>>2]=f&15}if((d-45&255)>=3){return}if((f|0)==47){a[b+19336|0]=0;k=0}else if((f|0)==0){a[b+19336|0]=2;k=2}else if((f|0)==46){g=b+19336|0;i=a[g]|1;a[g]=i;k=i}else if((f|0)==45){f=b+19336|0;i=a[f]|2;a[f]=i;k=i}else{k=a[b+19336|0]|0}b=k&3;k=c[7461744+(b<<2)>>2]|0;lI(h,k,k,c[7461728+(b<<2)>>2]|0);return}else if((e|0)==57345){lS(0,1,d);return}else{return}}function dz3(b){b=b|0;return(b<<16>>16==-14336?a[14113240]|0:0)|0}function dz4(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>31){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2792956+(b*112|0)>>2];c[a+104>>2]=c[2792960+(b*112|0)>>2];c[a+108>>2]=c[2792964+(b*112|0)>>2];d=0;return d|0}function dz5(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<32&(d|0)==0)){e=1;return e|0}c[a>>2]=2792856+(b*112|0);e=0;return e|0}function dz6(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6932096+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dz7(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=8){if((a|0)==0){d=0;return d|0}e=a;f=7441584+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}f=b-9|0;if(f>>>0>38){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;a=2796440+(f*12|0)|0;c[b>>2]=c[a>>2];c[b+4>>2]=c[a+4>>2];c[b+8>>2]=c[a+8>>2];d=0;return d|0}function dz8(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0;e=i;i=i+2104|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;c[2426768]=0;c[2424762]=0;c[2424748]=131072;c[2426616]=163840;c[2424856]=180224;c[2424832]=245760;c[2424814]=770048;c[2424806]=1294336;c[2424784]=1327104;c[2405148]=1329152;c[2406956]=1331200;c[2414460]=1334272;A=0;while(1){if((A|0)>=1024){break}B=9638528+(A<<2)|0;if((c[B>>2]|0)==0){C=3097;break}else{A=A+1|0}}do{if((C|0)==3097){A=gGq(1337344)|0;c[B>>2]=A;if((A|0)==0){break}c[2426768]=A;gGz(A|0,0,1337344);c[2424762]=A;c[2424748]=A+131072;c[2426616]=A+163840;c[2424856]=A+180224;c[2424832]=A+245760;c[2424814]=A+770048;c[2424806]=A+1294336;c[2424784]=A+1327104;c[2405148]=A+1329152;c[2406956]=A+1331200;c[2414460]=A+1334272;c[2414292]=A+1337344;if((c[3542200]|0)==0){D=1;i=e;return D|0}E=x+108|0;c[E>>2]=0;F=x+100|0;c[F>>2]=0;G=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[G&16383](x,0)|0;do{if((c[E>>2]|0)!=0){G=c[F>>2]|0;c[y>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](y,0,0)|0;if((G|0)<1){D=1;i=e;return D|0}if((gzL(A,0,0)|0)==0){break}else{D=1}i=e;return D|0}}while(0);A=(c[2424762]|0)+65536|0;if((c[3542200]|0)==0){D=1;i=e;return D|0}F=v+108|0;c[F>>2]=0;E=v+100|0;c[E>>2]=0;G=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[G&16383](v,1)|0;do{if((c[F>>2]|0)!=0){G=c[E>>2]|0;c[w>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](w,1,0)|0;if((G|0)<1){D=1;i=e;return D|0}if((gzL(A,0,1)|0)==0){break}else{D=1}i=e;return D|0}}while(0);A=(c[2424762]|0)+98304|0;if((c[3542200]|0)==0){D=1;i=e;return D|0}E=t+108|0;c[E>>2]=0;F=t+100|0;c[F>>2]=0;G=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[G&16383](t,2)|0;do{if((c[E>>2]|0)!=0){G=c[F>>2]|0;c[u>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](u,2,0)|0;if((G|0)<1){D=1;i=e;return D|0}if((gzL(A,0,2)|0)==0){break}else{D=1}i=e;return D|0}}while(0);A=c[2424748]|0;if((c[3542200]|0)==0){D=1;i=e;return D|0}F=r+108|0;c[F>>2]=0;E=r+100|0;c[E>>2]=0;G=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[G&16383](r,3)|0;do{if((c[F>>2]|0)!=0){G=c[E>>2]|0;c[s>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](s,3,0)|0;if((G|0)<1){D=1;i=e;return D|0}if((gzL(A,0,3)|0)==0){break}else{D=1}i=e;return D|0}}while(0);A=c[2424856]|0;if((c[3542200]|0)==0){D=1;i=e;return D|0}E=p+108|0;c[E>>2]=0;F=p+100|0;c[F>>2]=0;G=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[G&16383](p,4)|0;do{if((c[E>>2]|0)!=0){G=c[F>>2]|0;c[q>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](q,4,0)|0;if((G|0)<1){D=1;i=e;return D|0}if((gzL(A,0,4)|0)==0){break}else{D=1}i=e;return D|0}}while(0);A=c[2424806]|0;if((c[3542200]|0)==0){D=1;i=e;return D|0}F=n+108|0;c[F>>2]=0;E=n+100|0;c[E>>2]=0;G=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[G&16383](n,21)|0;do{if((c[F>>2]|0)!=0){G=c[E>>2]|0;c[o>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](o,21,0)|0;if((G|0)<1){D=1;i=e;return D|0}if((gzL(A,0,21)|0)==0){break}else{D=1}i=e;return D|0}}while(0);A=l+108|0;E=l+100|0;F=j+108|0;G=j+100|0;H=f+108|0;I=f+100|0;J=0;while(1){K=J<<15;L=(c[2424832]|0)+K|0;M=J+5|0;if((c[3542200]|0)==0){D=1;C=3210;break}c[A>>2]=0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,M)|0;if((c[A>>2]|0)!=0){N=c[E>>2]|0;c[m>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](m,M,0)|0;if((N|0)<1){D=1;C=3230;break}if((gzL(L,0,M)|0)!=0){D=1;C=3235;break}}M=(c[2424814]|0)+K|0;K=J+13|0;if((c[3542200]|0)==0){D=1;C=3234;break}c[F>>2]=0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,K)|0;if((c[F>>2]|0)!=0){L=c[G>>2]|0;c[k>>2]=9534384;N=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[N&16383](k,K,0)|0;if((L|0)<1){D=1;C=3217;break}if((gzL(M,0,K)|0)!=0){D=1;C=3237;break}}K=(c[2424784]|0)+(J<<8)|0;M=J+22|0;if((c[3542200]|0)==0){D=1;C=3233;break}c[H>>2]=0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,M)|0;if((c[H>>2]|0)!=0){L=c[I>>2]|0;c[g>>2]=9534384;N=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[N&16383](g,M,0)|0;if((L|0)<1){D=1;C=3238;break}if((gzL(K,0,M)|0)!=0){D=1;C=3221;break}}M=J+1|0;if((M|0)<8){J=M}else{P=0;C=3137;break}}if((C|0)==3137){while(1){C=0;if((P|0)>=1024){break}Q=9638528+(P<<2)|0;if((c[Q>>2]|0)==0){C=3139;break}else{P=P+1|0;C=3137}}do{if((C|0)==3139){J=gGq(524288)|0;c[Q>>2]=J;if((J|0)==0){break}gGz(J|0,0,524288);I=c[2424856]|0;gGC(J|0,I|0,16384)|0;H=0;do{G=H<<6;gGz(I+G|0,0,64);F=H<<7;E=F|4;A=0;while(1){M=E+(c[596744+(A<<2)>>2]|0)|0;K=(A<<3)+G|0;L=0;do{N=M+(c[596776+(L<<2)>>2]|0)|0;if((d[J+((N|0)/8|0)|0]&128>>>((N&7)>>>0)|0)!=0){N=I+(K+L)|0;a[N]=a[N]|2}L=L+1|0;}while((L|0)<8);L=A+1|0;if((L|0)<8){A=L}else{R=0;break}}do{A=F+(c[596744+(R<<2)>>2]|0)|0;E=(R<<3)+G|0;L=0;do{K=A+(c[596776+(L<<2)>>2]|0)|0;if((d[J+((K|0)/8|0)|0]&128>>>((K&7)>>>0)|0)!=0){K=I+(E+L)|0;a[K]=a[K]|1}L=L+1|0;}while((L|0)<8);R=R+1|0;}while((R|0)<8);H=H+1|0;}while((H|0)<1024);H=c[2424832]|0;gGC(J|0,H|0,262144)|0;I=0;do{G=I<<10;gGz(H+G|0,0,1024);F=I<<11;L=0;do{E=1<<3-L;A=(c[961472+(L<<2)>>2]|0)+F|0;K=0;do{M=A+(c[609168+(K<<2)>>2]|0)|0;N=(K<<5)+G|0;O=0;do{S=M+(c[610736+(O<<2)>>2]|0)|0;if((d[J+((S|0)/8|0)|0]&128>>>((S&7)>>>0)|0)!=0){S=H+(N+O)|0;a[S]=(d[S]|E)&255}O=O+1|0;}while((O|0)<32);K=K+1|0;}while((K|0)<32);L=L+1|0;}while((L|0)<4);I=I+1|0;}while((I|0)<512);I=c[2424814]|0;gGC(J|0,I|0,262144)|0;H=0;while(1){L=H<<8;gGz(I+L|0,0,256);G=H<<9;F=0;do{K=1<<3-F;E=(c[961472+(F<<2)>>2]|0)+G|0;A=0;do{O=E+(c[609168+(A<<2)>>2]|0)|0;N=(A<<4)+L|0;M=0;do{S=O+(c[609552+(M<<2)>>2]|0)|0;if((d[J+((S|0)/8|0)|0]&128>>>((S&7)>>>0)|0)!=0){S=I+(N+M)|0;a[S]=(d[S]|K)&255}M=M+1|0;}while((M|0)<16);A=A+1|0;}while((A|0)<16);F=F+1|0;}while((F|0)<4);F=H+1|0;if((F|0)<2048){H=F}else{T=0;break}}while(1){if((T|0)>=1024){U=I;break}V=9638528+(T<<2)|0;if((c[V>>2]|0)==(J|0)){C=3169;break}else{T=T+1|0}}if((C|0)==3169){gGr(J);c[V>>2]=0;U=c[2424814]|0}I=c[2405148]|0;gGz(I|0,1,2048);H=0;do{if((a[U+H|0]|0)!=0){a[I+(H>>8)|0]=0}H=H+1|0;}while((H|0)<524288)}}while(0);H=c[2424784]|0;I=0;do{J=a[H+I|0]|0;F=a[H+(I+256)|0]|0;L=a[H+(I+512)|0]|0;c[z+(I<<2)>>2]=((F&15|F<<4)&255)<<8|((J&15|J<<4)&255)<<16|(L&15|L<<4)&255;I=I+1|0;}while((I|0)<256);I=c[2406956]|0;L=0;do{c[I+(L<<2)>>2]=c[z+((d[H+(L+768)|0]|64)<<2)>>2];c[I+(L+256<<2)>>2]=c[z+((d[H+(L+1280)|0]<<4&48|d[H+(L+1024)|0])<<2)>>2];c[I+(L+512<<2)>>2]=c[z+((d[H+(L+1536)|0]|d[H+(L+1792)|0]<<4&112|128)<<2)>>2];L=L+1|0;}while((L|0)<256);fwR(0);L=c[2439330]|0;if((L|0)!=0){H=L;gGC(9706056,H|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];H=c[3528484]|0;c[2076596]=H;I=c[2417276]|0;c[3541536]=I;c[1836236]=0;J=c[2424762]|0;F=0;G=0;while(1){c[L+76+(G<<2)>>2]=J+(G<<8);A=F+1&65535;if((A&65535)>127){W=0;X=0;break}else{F=A;G=A&65535}}while(1){G=J+(X<<8)|0;c[L+76+(X+512<<2)>>2]=G;c[L+76+(X+768<<2)>>2]=G;G=W+1&65535;if((G&65535)>127){Y=128;Z=128;break}else{W=G;X=G&65535}}while(1){c[L+76+(Z<<2)>>2]=J+((Z<<8)+32768);G=Y+1&65535;if((G&65535)>191){_=128;$=128;break}else{Y=G;Z=G&65535}}while(1){G=J+(($<<8)+32768)|0;c[L+76+($+512<<2)>>2]=G;c[L+76+($+768<<2)>>2]=G;G=_+1&65535;if((G&65535)>191){break}else{_=G;$=G&65535}}J=c[2426616]|0;c[L+908>>2]=J;G=J+256|0;c[L+912>>2]=G;F=J+512|0;c[L+916>>2]=F;A=J+768|0;c[L+920>>2]=A;K=J+1024|0;c[L+924>>2]=K;E=J+1280|0;c[L+928>>2]=E;M=J+1536|0;c[L+932>>2]=M;N=J+1792|0;c[L+936>>2]=N;c[L+1932>>2]=J;c[L+1936>>2]=G;c[L+1940>>2]=F;c[L+1944>>2]=A;c[L+1948>>2]=K;c[L+1952>>2]=E;c[L+1956>>2]=M;c[L+1960>>2]=N;c[L+972>>2]=J+4096;c[L+976>>2]=J+4352;c[L+980>>2]=J+4608;c[L+984>>2]=J+4864;c[L+988>>2]=J+5120;c[L+992>>2]=J+5376;c[L+996>>2]=J+5632;c[L+1e3>>2]=J+5888;c[L+1004>>2]=J+6144;c[L+1008>>2]=J+6400;c[L+1012>>2]=J+6656;c[L+1016>>2]=J+6912;c[L+1020>>2]=J+7168;c[L+1024>>2]=J+7424;c[L+1028>>2]=J+7680;c[L+1032>>2]=J+7936;N=224;M=224;while(1){c[L+76+(M+256<<2)>>2]=J+((M<<8)-53248);E=N+1&65535;if((E&65535)>239){aa=224;ab=224;break}else{N=E;M=E&65535}}while(1){M=J+((ab<<8)-53248)|0;c[L+76+(ab+512<<2)>>2]=M;c[L+76+(ab+768<<2)>>2]=M;M=aa+1&65535;if((M&65535)>239){break}else{aa=M;ab=M&65535}}c[L+1036>>2]=J+8192;c[L+1040>>2]=J+8448;c[L+1044>>2]=J+8704;c[L+1048>>2]=J+8960;c[L+1052>>2]=J+9216;c[L+1056>>2]=J+9472;c[L+1060>>2]=J+9728;c[L+1064>>2]=J+9984;c[L+1068>>2]=J+10240;c[L+1072>>2]=J+10496;c[L+1076>>2]=J+10752;c[L+1080>>2]=J+11008;c[L+1084>>2]=J+11264;c[L+1088>>2]=J+11520;c[L+1092>>2]=J+11776;c[L+1096>>2]=J+12032;M=240;N=240;while(1){c[L+76+(N+256<<2)>>2]=J+((N<<8)-53248);E=M+1&65535;if((E&65535)>255){break}else{M=E;N=E&65535}}c[L+4180>>2]=2922;c[L+4184>>2]=1120;N=L;gGC(N|0,9706056,76)|0;c[2438118]=c[2433530];c[3528484]=H;c[2417276]=I;c[1836236]=-1;fwR(1);N=c[2439331]|0;M=(N|0)==0;if(!M){J=N;gGC(9706056,J|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];J=c[3528485]|0;c[2076596]=J;E=c[2417277]|0;c[3541536]=E;c[1836236]=1;K=c[2424748]|0;A=0;F=0;while(1){c[N+76+(F<<2)>>2]=K+(F<<8);G=A+1&65535;if((G&65535)>127){ac=0;ad=0;break}else{A=G;F=G&65535}}while(1){F=K+(ad<<8)|0;c[N+76+(ad+512<<2)>>2]=F;c[N+76+(ad+768<<2)>>2]=F;F=ac+1&65535;if((F&65535)>127){break}else{ac=F;ad=F&65535}}K=c[2426616]|0;F=K+12288|0;c[N+844>>2]=F;A=K+12544|0;c[N+848>>2]=A;I=K+12800|0;c[N+852>>2]=I;H=K+13056|0;c[N+856>>2]=H;L=K+13312|0;c[N+860>>2]=L;G=K+13568|0;c[N+864>>2]=G;O=K+13824|0;c[N+868>>2]=O;S=K+14080|0;c[N+872>>2]=S;c[N+1868>>2]=F;c[N+1872>>2]=A;c[N+1876>>2]=I;c[N+1880>>2]=H;c[N+1884>>2]=L;c[N+1888>>2]=G;c[N+1892>>2]=O;c[N+1896>>2]=S;c[N+2892>>2]=F;c[N+3916>>2]=F;c[N+2896>>2]=A;c[N+3920>>2]=A;c[N+2900>>2]=I;c[N+3924>>2]=I;c[N+2904>>2]=H;c[N+3928>>2]=H;c[N+2908>>2]=L;c[N+3932>>2]=L;c[N+2912>>2]=G;c[N+3936>>2]=G;c[N+2916>>2]=O;c[N+3940>>2]=O;c[N+2920>>2]=S;c[N+3944>>2]=S;c[N+4180>>2]=2264;c[N+4184>>2]=132;if(!M){S=N;gGC(S|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=J;c[2417277]=E;c[1836236]=-1;S=c[642608+(c[2436]<<2)>>2]|0;O=c[S+128>>2]|0;if((c[S+52>>2]&4|0)==0){c[2113068]=O;G=c[S+132>>2]|0;c[2113070]=G;c[2443814]=O;c[2440436]=G;ae=O;af=G}else{c[2113070]=O;G=c[S+132>>2]|0;c[2113068]=G;c[2440436]=O;c[2443814]=G;ae=G;af=O}O=ag(ae<<1,af)|0;G=gGq(O)|0;c[2112926]=G;if((G|0)!=0){gGz(G|0,0,O|0)}Vr(2,15e5,0,2420,62,0);c[2438228]=3e6;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=681;h[745419]=.14;a[3203368]=1;h[745418]=.22;a[3203360]=1;h[745417]=.22;a[3203352]=1;h[745416]=.22;a[3203344]=1;h[745415]=.14;a[3203336]=1;h[745414]=.22;a[3203328]=1;h[745413]=.22;a[3203320]=1;h[745412]=.22;a[3203312]=1;dAk();D=0;i=e;return D|0}else if((C|0)==3210){i=e;return D|0}else if((C|0)==3217){i=e;return D|0}else if((C|0)==3221){i=e;return D|0}else if((C|0)==3230){i=e;return D|0}else if((C|0)==3233){i=e;return D|0}else if((C|0)==3234){i=e;return D|0}else if((C|0)==3235){i=e;return D|0}else if((C|0)==3237){i=e;return D|0}else if((C|0)==3238){i=e;return D|0}}}while(0);c[2426768]=0;D=1;i=e;return D|0}function dz9(){var b=0,d=0,e=0,f=0;c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}fwZ();b=c[3541518]|0;if((b|0)!=0){gGr(b|0);c[3541518]=0}if((c[2385508]|0)>0){c[2113008]=0;c[2076598]=0;c[2383582]=0}c[2438228]=0;c[2433526]=0;c[2406676]=0;c[3528472]=0;b=c[2406680]|0;if((b|0)!=0){gGr(b);c[2406680]=0}c[2385508]=0;c[2432978]=0;a[64240]=0;b=c[2426768]|0;d=0;while(1){if((d|0)>=1024){break}e=9638528+(d<<2)|0;if((c[e>>2]|0)==(b|0)){f=3250;break}else{d=d+1|0}}if((f|0)==3250){gGr(b);c[e>>2]=0}c[2426616]=0;c[2424748]=0;c[2424762]=0;c[2426768]=0;c[2424784]=0;c[2424806]=0;c[2424814]=0;c[2424832]=0;c[2424856]=0;c[2405148]=0;c[2414460]=0;c[2406956]=0;e=c[2439210]&255;a[14114944]=e;a[14113240]=e;a[9660648]=0;a[9698792]=0;a[9681680]=0;a[9774832]=0;a[9731785]=0;a[9731784]=0;a[9731776]=0;return 0}function dAa(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;if((a[9624536]|0)!=0){dAk()}d=c[2385548]|0;if((d|0)>0){gGz(9752472,0,((d|0)>1?d<<2:4)|0)}c[2433530]=0;d=0;e=0;f=0;g=0;L4428:while(1){h=e;i=f;j=g;while(1){if((h|0)>=25){break L4428}k=c[2439330]|0;if((k|0)!=0){l=k;gGC(9706056,l|0,76)|0}b[4853030]=c[2426515]&65535;l=c[2438118]|0;c[2433530]=l;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;m=h+1|0;n=((m*66666|0|0)/25|0)-i|0;do{if((n|0)<1){o=0;p=l}else{if((a[k+4188|0]|0)==0){q=gfc(n)|0;r=(c[2433530]|0)+q|0;c[2433530]=r;o=q;p=r;break}else{r=l+n|0;c[2433530]=r;o=n;p=r;break}}}while(0);s=o+i|0;if((h|0)==20){a[9706117]=1}else if((h|0)==21){a[9706117]=0}n=c[1836236]|0;l=c[9757320+(n<<2)>>2]|0;if((l|0)!=0){k=l;gGC(k|0,9706056,76)|0}c[9752472+(n<<2)>>2]=p;c[14113936+(n<<2)>>2]=c[2076596];c[9669104+(n<<2)>>2]=c[3541536];c[1836236]=-1;n=c[2439331]|0;if((n|0)!=0){k=n;gGC(9706056,k|0,76)|0}b[4853030]=c[2426515]&65535;k=c[2438119]|0;c[2433530]=k;c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;l=((m*5e4|0|0)/25|0)-j|0;do{if((l|0)<1){t=0}else{if((a[n+4188|0]|0)==0){r=gfc(l)|0;c[2433530]=(c[2433530]|0)+r;t=r;break}else{c[2433530]=k+l;t=l;break}}}while(0);u=t+j|0;Sb(h*2e3|0);switch(h|0){case 20:case 15:case 10:case 5:{a[9706117]=1;if((h|0)==6|(h|0)==16|(h|0)==11){v=3278}break};case 21:case 16:case 11:case 6:{v=3278;break};default:{}}if((v|0)==3278){v=0;a[9706117]=0}l=c[1836236]|0;k=c[9757320+(l<<2)>>2]|0;if((k|0)!=0){n=k;gGC(n|0,9706056,76)|0}c[9752472+(l<<2)>>2]=c[2433530];c[14113936+(l<<2)>>2]=c[2076596];c[9669104+(l<<2)>>2]=c[3541536];c[1836236]=-1;w=c[2112964]|0;if((w|0)==0){h=m;i=s;j=u}else{break}}j=a[9688]|0?534:0;i=c[2439331]|0;if((i|0)!=0){h=i;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;gg[c[3542122]&4095](w+(d<<1<<1)|0,j-d|0);h=c[1836236]|0;i=c[9757320+(h<<2)>>2]|0;if((i|0)!=0){l=i;gGC(l|0,9706056,76)|0}c[9752472+(h<<2)>>2]=c[2433530];c[14113936+(h<<2)>>2]=c[2076596];c[9669104+(h<<2)>>2]=c[3541536];c[1836236]=-1;d=j;e=m;f=s;g=u}u=c[2439331]|0;if((u|0)!=0){g=u;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;g=c[2438228]|0;u=gGS(-610271232,23841,g,(g|0)<0|0?-1:0)|0;g=u;Sb(5e4);u=c[2443830]|0;if((u|0)<1073676288){c[2443830]=u-g}u=c[2443831]|0;if((u|0)<1073676288){c[2443831]=u-g}u=(c[3528512]|0)-g|0;c[3528512]=(u|0)<0?0:u;u=c[1836236]|0;g=c[9757320+(u<<2)>>2]|0;if((g|0)!=0){s=g;gGC(s|0,9706056,76)|0}c[9752472+(u<<2)>>2]=c[2433530];c[14113936+(u<<2)>>2]=c[2076596];c[9669104+(u<<2)>>2]=c[3541536];c[1836236]=-1;u=c[2112964]|0;do{if((u|0)!=0){s=a[9688]|0?534:0;if((s|0)==(d|0)){break}g=c[2439331]|0;if((g|0)!=0){f=g;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;gg[c[3542122]&4095](u+(d<<1<<1)|0,s-d|0);s=c[1836236]|0;f=c[9757320+(s<<2)>>2]|0;if((f|0)!=0){g=f;gGC(g|0,9706056,76)|0}c[9752472+(s<<2)>>2]=c[2433530];c[14113936+(s<<2)>>2]=c[2076596];c[9669104+(s<<2)>>2]=c[3541536];c[1836236]=-1}}while(0);if((c[2112968]|0)==0){return 0}dAb()|0;return 0}function dAb(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;if((a[14124248]|0)!=0){e=c[2406956]|0;f=c[2414460]|0;g=0;do{h=c[e+(g<<2)>>2]|0;c[f+(g<<2)>>2]=h>>>8<<3&2016|h>>>3&31|h>>>16<<8&63488;g=g+1|0;}while((g|0)<768)}if((a[9698792]|0)==0){g=c[2112926]|0;gGz(g|0,0,114688);i=g}else{g=(d[9731785]<<8|d[9731784])&65535;f=g&31;e=c[2112926]|0;h=c[2424832]|0;j=0;k=(c[2424806]|0)+(g>>>1&32752)|0;while(1){g=d[k+1|0]|0;l=g<<8&256|d[k];m=g>>>2&15;n=g&128;o=g&64;g=(j<<5&224)-(d[9731776]|0)|0;p=(j>>>3<<5)-f|0;if((a[14114944]|0)==0){q=p;r=g;s=o;t=n}else{q=224-p|0;r=224-g|0;s=o^64;t=n^128}n=r-16|0;o=(s|0)!=0;do{if((t|0)==0){if(o){SR(e,l,q,n,m,4,256,h);break}else{SP(e,l,q,n,m,4,256,h);break}}else{if(o){SV(e,l,q,n,m,4,256,h);break}else{ST(e,l,q,n,m,4,256,h);break}}}while(0);m=j+1|0;if((m|0)<80){j=m;k=k+2|0}else{i=e;break}}}if((a[9660648]|0)!=0){e=c[2426616]|0;k=c[2405148]|0;j=c[2424814]|0;h=4064;do{q=d[e+(h+8193)|0]|0;t=q>>>6;s=d[e+(h+8192)|0]|0;r=q&15;f=q&16;m=(d[e+(h+8195)|0]|0)-(q<<3&256)|0;q=a[e+(h+8194)|0]|0;n=q&255;do{if(!(q<<24>>24==0|(q&255)>239)){if((t|0)==3){u=(d[9774832]|0)+3|0}else{u=t}l=u<<8|s;if((a[k+l|0]|0)!=0){break}if((a[14114944]|0)==0){v=n;w=m;x=f;y=0}else{v=240-n|0;w=240-m|0;x=f>>>4^1;y=1}o=v-16|0;if((x|0)==0){if(y){SJ(i,l,w,o,r,4,0,512,j);break}else{SH(i,l,w,o,r,4,0,512,j);break}}else{if(y){SN(i,l,w,o,r,4,0,512,j);break}else{SL(i,l,w,o,r,4,0,512,j);break}}}}while(0);h=h-32|0;}while((h|0)>-1)}if((a[9681680]|0)==0){z=c[2414460]|0;R8(z);return 0}h=c[2426616]|0;j=c[2424856]|0;w=c[2406956]|0;y=0;x=0;while(1){v=x&255;k=v+8|0;u=v|1;e=(k>>>0>u>>>0?k:u)-v|0;v=y<<3&248;u=y>>>2&248;k=d[h+(y+1024)|0]<<2;r=(k&896)+(d[h+y|0]|0)|0;L4554:do{if((r|0)!=36){f=j+(r<<6)|0;m=k&124;if((a[14114944]|0)==0){n=u-8|0;s=v+8|0;t=f;q=u-16|0;while(1){o=q<<8;if((q|0)<=223){l=t;g=v;while(1){do{if(!((g|q|0)<0|(g|0)>255)){p=d[l]|m;if((c[w+(p<<2)>>2]|0)==0){break}b[i+((g|o)<<1)>>1]=p&65535}}while(0);p=g+1|0;if((p|0)<(s|0)){l=l+1|0;g=p}else{break}}}g=q+1|0;if((g|0)<(n|0)){t=t+e|0;q=g}else{break L4554}}}q=240-u|0;t=240-v|0;n=q-8|0;s=q-1|0;q=t|7;if((q|0)<(t|0)){g=s;while(1){g=g-1|0;if((g|0)<(n|0)){break L4554}}}else{A=f;B=s}while(1){g=B<<8;if((B|0)>223){l=A;o=q;while(1){p=o-1|0;C=l+1|0;if((p|0)<(t|0)){D=C;break}else{l=C;o=p}}}else{o=A;l=q;while(1){do{if(!((l|B|0)<0|(l|0)>255)){p=d[o]|m;if((c[w+(p<<2)>>2]|0)==0){break}b[i+((l|g)<<1)>>1]=p&65535}}while(0);p=l-1|0;C=o+1|0;if((p|0)<(t|0)){D=C;break}else{o=C;l=p}}}l=B-1|0;if((l|0)<(n|0)){break}else{A=D;B=l}}}}while(0);v=y+1|0;if((v|0)>=1024){break}y=v;x=x+8&255}z=c[2414460]|0;R8(z);return 0}function dAc(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=i;i=i+176|0;e=d|0;f=d+16|0;g=d+32|0;h=d+48|0;j=d+64|0;k=d+80|0;l=d+96|0;m=d+112|0;n=d+128|0;o=d+144|0;p=d+160|0;if((b|0)!=0){c[b>>2]=169249}if((a&96|0)==0){i=d;return 0}gGz(p|0,0,12);c[p>>2]=c[2426616];c[p+4>>2]=16384;c[p+12>>2]=162152;gj[c[2076592]&4095](p)|0;fw$(a);Vx(a,b);gGz(o|0,0,12);c[o>>2]=14113240;c[o+4>>2]=1;c[o+12>>2]=191240;gj[c[2076592]&4095](o)|0;gGz(n|0,0,12);c[n>>2]=14114944;c[n+4>>2]=1;c[n+12>>2]=142288;gj[c[2076592]&4095](n)|0;gGz(m|0,0,12);c[m>>2]=9756840;c[m+4>>2]=4;c[m+12>>2]=209656;gj[c[2076592]&4095](m)|0;gGz(l|0,0,12);c[l>>2]=9774832;c[l+4>>2]=1;c[l+12>>2]=204616;gj[c[2076592]&4095](l)|0;gGz(k|0,0,12);c[k>>2]=9681680;c[k+4>>2]=1;c[k+12>>2]=198528;gj[c[2076592]&4095](k)|0;gGz(j|0,0,12);c[j>>2]=9698792;c[j+4>>2]=1;c[j+12>>2]=193048;gj[c[2076592]&4095](j)|0;gGz(h|0,0,12);c[h>>2]=9660648;c[h+4>>2]=1;c[h+12>>2]=187088;gj[c[2076592]&4095](h)|0;gGz(g|0,0,12);c[g>>2]=9731784;c[g+4>>2]=1;c[g+12>>2]=181824;gj[c[2076592]&4095](g)|0;gGz(f|0,0,12);c[f>>2]=9731785;c[f+4>>2]=1;c[f+12>>2]=177352;gj[c[2076592]&4095](f)|0;gGz(e|0,0,12);c[e>>2]=9731776;c[e+4>>2]=1;c[e+12>>2]=173544;gj[c[2076592]&4095](e)|0;i=d;return 0}function dAd(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>31){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2789372+(b*112|0)>>2];c[a+104>>2]=c[2789376+(b*112|0)>>2];c[a+108>>2]=c[2789380+(b*112|0)>>2];d=0;return d|0}function dAe(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<32&(d|0)==0)){e=1;return e|0}c[a>>2]=2789272+(b*112|0);e=0;return e|0}function dAf(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>31){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2785788+(b*112|0)>>2];c[a+104>>2]=c[2785792+(b*112|0)>>2];c[a+108>>2]=c[2785796+(b*112|0)>>2];d=0;return d|0}function dAg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<32&(d|0)==0)){e=1;return e|0}c[a>>2]=2785688+(b*112|0);e=0;return e|0}function dAh(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>31){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2797012+(b*112|0)>>2];c[a+104>>2]=c[2797016+(b*112|0)>>2];c[a+108>>2]=c[2797020+(b*112|0)>>2];d=0;return d|0}function dAi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<32&(d|0)==0)){e=1;return e|0}c[a>>2]=2796912+(b*112|0);e=0;return e|0}function dAj(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=8){if((a|0)==0){d=0;return d|0}e=a;f=2800496+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}f=b-9|0;if(f>>>0>38){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;a=2796440+(f*12|0)|0;c[b>>2]=c[a>>2];c[b+4>>2]=c[a+4>>2];c[b+8>>2]=c[a+8>>2];d=0;return d|0}function dAk(){var b=0,d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0;a[9624536]=0;gGz(c[2426616]|0,0,16384);c[2439210]=-1;a[14113240]=0;a[14114944]=0;a[9774832]=0;a[9660648]=0;a[9698792]=0;a[9681680]=0;a[9731785]=0;a[9731784]=0;a[9731776]=0;b=c[2439330]|0;d=(b|0)==0;if(!d){e=b;gGC(9706056,e|0,76)|0}c[2433530]=c[2438118];e=c[3528484]|0;c[2076596]=e;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;gGz(9706056,0,76);c[2439210]=0;g=c[2424762]|0;i=128;j=128;while(1){c[b+76+(j<<2)>>2]=g+((j<<8)+32768);k=i+1&65535;if((k&65535)>191){l=128;m=128;break}else{i=k;j=k&65535}}while(1){j=g+((m<<8)+32768)|0;c[b+76+(m+512<<2)>>2]=j;c[b+76+(m+768<<2)>>2]=j;j=l+1&65535;if((j&65535)>191){break}else{l=j;m=j&65535}}if(!d){d=b;gGC(d|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=e;c[2417276]=f;c[1836236]=-1;f=c[2439331]|0;e=(f|0)==0;if(!e){d=f;gGC(9706056,d|0,76)|0}d=c[2438119]|0;c[2433530]=d;b=c[3528485]|0;c[2076596]=b;m=c[2417277]|0;c[3541536]=m;c[1836236]=1;gGz(9706056,0,76);if(!e){e=f;gGC(e|0,9706056,76)|0}c[2438119]=d;c[3528485]=b;c[2417277]=m;c[1836236]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){n=0}else{return}do{lN(n);mB(n);n=n+1|0;}while((n|0)<(c[2385508]|0));return}function dAl(a){a=a|0;var b=0,d=0;b=(c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,3e6,0)|0;return a|0}function dAm(){return+(+((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)/3.0e6)}function dAn(e,f){e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;g=e&65535;if((g&65520|0)==30720){h=e&255;switch(h&15|0){case 0:case 1:case 2:case 3:case 4:case 5:case 6:case 7:{e=a[9660736]|0;i=e<<24>>24==0;j=f&255;if(i){b[9776640+(h<<1)>>1]=j}else{k=9776640+(h<<1)|0;b[k>>1]=b[k>>1]|j<<8}do{if((a[9642624]|0)<0){if((h-4|0)>>>0>=2){break}if(i){b[9776640+(h+2<<1)>>1]=j;break}else{k=9776640+(h+2<<1)|0;b[k>>1]=b[k>>1]|j<<8;break}}}while(0);a[9660736]=e^1;return};case 8:{a[9642624]=f;return};default:{return}}}switch(g|0){case 32131:{a[c[2443706]|0]=f&1;return};case 32003:{c[181814]=(c[181814]&-33|(f&255)<<5&32)^32;return};case 32004:{c[181810]=f&1^1;return};case 31744:{a[c[3528308]|0]=f^15;return};case 31872:{a[c[2405106]|0]=f&1;return};case 32134:case 32135:{e=1<<(g&1);if((f&1)==0){j=c[2440368]|0;a[j]=d[j]&(e^255)&255;return}else{j=c[2440368]|0;a[j]=(d[j]|e)&255;return}break};case 32e3:case 32001:case 32002:{e=g&3;g=9537536+(e<<2)|0;j=f&255;if((c[g>>2]|0)==(j|0)){return}do{if(f<<24>>24!=0){if((e|0)!=0){h=e+2|0;if((c[2439194]|0)<=(h|0)){break}i=c[2406652]|0;c[3528400]=i+(h*40|0);if((a[i+(h*40|0)+14|0]&1)!=0){break}a[i+(h*40|0)+12|0]=1;c[i+(h*40|0)+8>>2]=0;break}h=c[2384392]|0;i=c[602368+(h<<2)>>2]|0;do{if((c[2439194]|0)>(i|0)){k=c[2406652]|0;c[3528400]=k+(i*40|0);if((a[k+(i*40|0)+14|0]&1)!=0){break}a[k+(i*40|0)+12|0]=1;c[k+(i*40|0)+8>>2]=0}}while(0);i=h+1|0;c[2384392]=i;if((i|0)!=7){break}c[2384392]=0}}while(0);c[g>>2]=j;return};case 32133:{j=a[9660744]|0;if((f&1)==0){g=j&-4;a[9660744]=g;l=g}else{b[4771176]=b[4888320]|0;g=b[4888321]|0;b[4813476]=g&16383;a[9579200]=(g&65535)>>>14&255;g=a[9579192]|0;e=j|3;a[9660744]=e;b[4771177]=b[4888322]|0;j=b[4888323]|0;b[4813477]=j&16383;a[9579201]=(j&65535)>>>14&255;a[9579192]=g&-4;l=e}if((l&15&d[9642624])<<16>>16==0){return}do{gj[c[2444166]&4095](4)|0;Tb();}while((a[9660744]&15&d[9642624])<<16>>16!=0);return};case 32005:{c[181812]=f&1^1;return};case 32130:{a[c[3528734]|0]=f&1^1;return};case 32132:{a[c[2394726]|0]=f&1;return};case 32128:{fJ$(f<<24>>24!=0|0);return};default:{return}}}function dAo(b){b=b|0;var d=0,f=0,g=0,h=0,i=0;d=b&65535;if((d&65520|0)==30720){f=b&255;switch(f&15|0){case 8:{b=a[9579192]|0;a[9579192]=b&-16;g=b;return g|0};case 0:case 1:case 2:case 3:case 4:case 5:case 6:case 7:{b=a[9660736]|0;h=(e[9776640+(f<<1)>>1]|0)>>>((b<<24>>24!=0?8:0)>>>0)&255;a[9660736]=b^1;g=h;return g|0};default:{g=-1;return g|0}}}if((d|0)==32128){g=a[9635336]|0;return g|0}else if((d|0)==31872){g=a[9550681]|0;return g|0}else if((d|0)==32e3){h=a[9550682]|0;if((h&16)==0){i=h&-65}else{i=h&47|-128}g=(c[2385560]<<6|i&255)&255;return g|0}else if((d|0)==31744){g=a[9550680]|0;return g|0}else{g=0;return g|0}return 0}function dAp(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;switch(b&65535|0){case 31744:{a[c[3528308]|0]=d;return};case 32128:{e=d&255;if((c[2384320]|0)==(e|0)){return}f=c[2439194]|0;if(d<<24>>24!=0&(f|0)>7){g=c[2406652]|0;c[3528400]=g+280;a[g+292|0]=0;c[g+288>>2]=0;h=3566}else{if((f|0)>6){h=3566}}do{if((h|0)==3566){f=c[2406652]|0;c[3528400]=f+240;if((a[f+254|0]&1)!=0){break}a[f+252|0]=1;c[f+248>>2]=0}}while(0);c[2384320]=e;return};case 32e3:{e=d&255;if((c[2384332]|0)==(e|0)){return}f=d<<24>>24!=0;g=c[2440828]|0;do{if(f&(g|0)==0){i=c[2384330]|0;j=(c[602368+(i<<2)>>2]|0)+3|0;do{if((c[2439194]|0)>(j|0)){k=c[2406652]|0;c[3528400]=k+(j*40|0);if((a[k+(j*40|0)+14|0]&1)!=0){break}a[k+(j*40|0)+12|0]=1;c[k+(j*40|0)+8>>2]=0}}while(0);j=i+1|0;c[2384330]=j;if((j|0)!=7){break}c[2384330]=0}else{if(!(f&(g|0)==1)){break}j=c[2384330]|0;k=(c[602368+(j<<2)>>2]|0)+8|0;do{if((c[2439194]|0)>(k|0)){l=c[2406652]|0;c[3528400]=l+(k*40|0);if((a[l+(k*40|0)+14|0]&1)!=0){break}a[l+(k*40|0)+12|0]=1;c[l+(k*40|0)+8>>2]=0}}while(0);k=j+1|0;c[2384330]=k;if((k|0)!=7){break}c[2384330]=0}}while(0);c[2384332]=e;return};case 32129:{e=d&255;if((c[2384318]|0)==(e|0)){return}do{if(d<<24>>24!=0&(c[2439194]|0)>7){g=c[2406652]|0;c[3528400]=g+280;if((a[g+294|0]&1)!=0){break}a[g+292|0]=1;c[g+288>>2]=0}}while(0);c[2384318]=e;return};case 32003:{e=d&255;if((c[2384324]|0)==(e|0)){return}do{if(d<<24>>24!=0&(c[2439194]|0)>2){g=c[2406652]|0;c[3528400]=g+80;if((a[g+94|0]&1)!=0){break}a[g+92|0]=1;c[g+88>>2]=0}}while(0);c[2384324]=e;return};case 32006:{e=d&255;if((c[2384322]|0)==(e|0)){return}g=c[2439194]|0;do{if(d<<24>>24==0){m=g;h=3557}else{if((g|0)<=7){break}f=c[2406652]|0;c[3528400]=f+280;a[f+292|0]=0;c[f+288>>2]=0;m=g;h=3557}}while(0);do{if((h|0)==3557){if((m|0)<=11){break}g=c[2406652]|0;c[3528400]=g+440;if((a[g+454|0]&1)!=0){break}a[g+452|0]=1;c[g+448>>2]=0}}while(0);c[2384322]=e;return};case 32002:{e=d&255;if((c[2384326]|0)==(e|0)){return}m=c[2439194]|0;if(d<<24>>24!=0&(m|0)>7){g=c[2406652]|0;c[3528400]=g+280;a[g+292|0]=0;c[g+288>>2]=0;h=3545}else{if((m|0)>1){h=3545}}do{if((h|0)==3545){m=c[2406652]|0;c[3528400]=m+40;if((a[m+54|0]&1)!=0){break}a[m+52|0]=1;c[m+48>>2]=0}}while(0);c[2384326]=e;return};case 32007:{c[2440828]=d&255;return};case 32001:{e=d&255;if((c[2384328]|0)==(e|0)){return}do{if(d<<24>>24!=0&(c[2439194]|0)>0){h=c[2406652]|0;c[3528400]=h;if((a[h+14|0]&1)!=0){break}a[h+12|0]=1;c[h+8>>2]=0}}while(0);c[2384328]=e;return};case 31873:{c[181814]=(c[181814]&-65|(d&255)<<6&64)^64;return};default:{dAn(b,d);return}}}function dAq(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((e|0)==31872){a[c[3528630]|0]=d;return}else if((e|0)==32129){a[c[2444196]|0]=d&1;return}else{dAn(b,d);return}}function dAr(b,e){b=b|0;e=e|0;var f=0;f=b&65535;switch(f|0){case 32391:case 32390:{b=1<<(f&1);if((e&1)==0){f=c[2440368]|0;a[f]=(d[f]|0)&(b^255)&255;return}else{f=c[2440368]|0;a[f]=(d[f]|0|b)&255;return}break};case 32385:{a[c[2405106]|0]=e&1;return};case 32388:{a[c[2394726]|0]=e&1;return};case 32386:{a[c[3528734]|0]=e&1^1;return};case 32387:{a[c[2443706]|0]=e&1;return};default:{return}}}function dAs(b){b=b|0;var c=0,d=0;c=b&65535;if((c|0)==32128){d=a[9635337]|0}else if((c|0)==31872){d=a[9550681]|0}else if((c|0)==32e3){d=a[9635336]|0}else if((c|0)==31744){d=a[9550680]|0}else{d=0}return d|0}function dAt(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=a&65535;if((d|0)==51200){e=b&255;c[2415256]=e&1;f=e>>>2&1;c[3528406]=f^1;if((f|0)==0){c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2]}Tr(e>>>1&1);return}else if((d|0)==57344){d=(b&255)<<15&32768;c[3528812]=d;e=c[2385950]|0;f=c[9757320+(c[1836236]<<2)>>2]|0;g=0;h=0;while(1){c[f+76+(h<<2)>>2]=e+((h<<8)+d);i=g+1&65535;if((i&65535)>95){j=0;k=0;break}else{g=i;h=i&65535}}while(1){h=e+((k<<8)+d)|0;c[f+76+(k+512<<2)>>2]=h;c[f+76+(k+768<<2)>>2]=h;h=j+1&65535;if((h&65535)>95){break}else{j=h;k=h&65535}}k=d-32768|0;d=128;j=128;while(1){c[f+76+(j<<2)>>2]=e+(k+(j<<8));h=d+1&65535;if((h&65535)>199){l=201;m=201;break}else{d=h;j=h&65535}}while(1){c[f+76+(m<<2)>>2]=e+(k+(m<<8));j=l+1&65535;if((j&65535)>255){n=128;o=128;break}else{l=j;m=j&65535}}while(1){m=e+(k+(o<<8))|0;c[f+76+(o+512<<2)>>2]=m;c[f+76+(o+768<<2)>>2]=m;m=n+1&65535;if((m&65535)>255){break}else{n=m;o=m&65535}}return}else{dAn(a,b);return}}function dAu(b){b=b|0;var d=0,f=0,g=0,h=0,i=0;d=b&65535;if((d&65280|0)==51200){if(b<<16>>16!=-14336){f=a[(c[2385950]|0)+((c[3528812]|0)+(d&32767))|0]|0;return f|0}if((c[2406632]|0)!=0){f=(c[2432962]|0)>>>((c[(c[2420380]|0)+4>>2]|0)>>>0)&1;return f|0}g=c[2443744]|0;if((g|0)<=0){f=1;return f|0}c[2443744]=g-1;f=0;return f|0}if((d&65520|0)==30720){g=b&255;switch(g&15|0){case 8:{b=a[9579192]|0;a[9579192]=b&-16;f=b;return f|0};case 0:case 1:case 2:case 3:case 4:case 5:case 6:case 7:{b=a[9660736]|0;h=(e[9776640+(g<<1)>>1]|0)>>>((b<<24>>24!=0?8:0)>>>0)&255;a[9660736]=b^1;f=h;return f|0};default:{f=-1;return f|0}}}if((d|0)==31744){f=a[9550680]|0;return f|0}else if((d|0)==32e3){h=a[9550682]|0;if((h&16)==0){i=h&-65}else{i=h&47|-128}f=(c[2385560]<<6|i&255)&255;return f|0}else if((d|0)==32128){f=a[9635336]|0;return f|0}else if((d|0)==31872){f=a[9550681]|0;return f|0}else{f=0;return f|0}return 0}function dAv(b){b=b|0;return a[(c[3529764]|0)+(b&4095)|0]|0}function dAw(b){b=b|0;var d=0,e=0;do{if(b>>>0<256){d=c[2420366]|0;if((d&64|0)!=0&(b|0)==32){e=a[c[3528308]|0]|0;break}else{e=a[(c[3529764]|0)+(b&255|d<<8&1792|4096)|0]|0;break}}else{if((b|0)==257){e=-1;break}else if((b|0)==273){e=c[181810]&255;break}else if((b|0)==272){e=c[181812]&255;break}else if((b|0)==258){e=c[181814]&255;break}else{e=0;break}}}while(0);return e|0}function dAx(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2405124+(b*112|0)>>2];c[a+104>>2]=c[2405128+(b*112|0)>>2];c[a+108>>2]=c[2405132+(b*112|0)>>2];d=0;return d|0}function dAy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=2405024+(b*112|0);e=0;return e|0}function dAz(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1206272+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dAA(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3582168+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dAB(){var a=0,d=0,e=0,f=0,g=0;a=dBX(3984,6434,0)|0;if((a|0)!=0){return a|0}d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];f=c[3528484]|0;c[2076596]=f;g=c[2417276]|0;c[3541536]=g;c[1836236]=0;c[d+4184>>2]=1294;if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=f;c[2417276]=g;c[1836236]=-1;return a|0}function dAC(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=i;i=i+128|0;d=b|0;c[2113070]=0;c[2113068]=0;e=c[2112926]|0;if((e|0)!=0){gGr(e);c[2112926]=0}fwZ();e=c[2426620]|0;if((e|0)!=0){gGr(e);c[2426620]=0}c[2440608]=0;e=c[2439194]|0;f=c[2406652]|0;if((e|0)>0){g=0;h=f;j=e;while(1){e=h+(g*40|0)|0;c[3528400]=e;k=c[e>>2]|0;if((k|0)==0){l=j;m=h}else{gGr(k);c[c[3528400]>>2]=0;l=c[2439194]|0;m=c[2406652]|0}k=g+1|0;if((k|0)<(l|0)){g=k;h=m;j=l}else{n=m;break}}}else{n=f}if((n|0)!=0){gGr(n);c[2406652]=0}c[3528400]=0;c[2439194]=0;c[2442914]=0;UT();n=d|0;d=c[c[642608+(c[2436]<<2)>>2]>>2]|0;be(n|0,128,179600,(f=i,i=i+24|0,c[f>>2]=9374064,c[f+8>>2]=47,c[f+16>>2]=d,f)|0)|0;i=f;a[1040128]=0;f=c[2420380]|0;d=c[f>>2]|0;m=c[f+4>>2]|0;f=fw(n|0,389440)|0;if((f|0)!=0){n=m>>3<<d&1023;cj(14100392,n|0,1,f|0)|0;aY(f|0)|0}f=c[2415014]|0;n=0;while(1){if((n|0)>=1024){o=3734;break}p=9638528+(n<<2)|0;if((c[p>>2]|0)==(f|0)){break}else{n=n+1|0}}if((o|0)==3734){c[2415014]=0;i=b;return 0}gGr(f);c[p>>2]=0;c[2415014]=0;i=b;return 0}function dAD(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;if((a[9624528]|0)!=0){d=c[2414720]|0;gGz(d|0,0,(c[2411748]|0)-d|0);d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=i;c[1836236]=-1;b[4859110]=0;a[9718225]=0;a[9718224]=0;a[9718226]=8;a[9718229]=-1;a[9718230]=-1;a[9718227]=0;a[9718237]=0;a[9718236]=0;a[9718249]=0;a[9718238]=0;gGz(9718242,0,6);i=c[2439194]|0;if((i|0)>0){g=c[2406652]|0;f=0;do{j=g+(f*40|0)|0;e=g+(f*40|0)+12|0;a[e]=0;d=g+(f*40|0)+8|0;c[d>>2]=0;k=a[g+(f*40|0)+14|0]|0;do{if((k&2)!=0&(i|0)>(f|0)){if((k&4)==0){a[g+(f*40|0)+13|0]=1}if((k&1)!=0){break}a[e]=1;c[d>>2]=0}}while(0);f=f+1|0;}while((f|0)<(i|0));c[3528400]=j}j=c[2405758]|0;if((j|0)>0){i=0;do{c[9542560+(i<<5)>>2]=0;b[9542544+(i<<5)>>1]=0;i=i+1|0;}while((i|0)<(j|0))}a[9579192]=a[9579192]&-16;a[9642624]=0;c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2]}h[1214783]=0.0;gGz(9550680,0,3);j=0;i=0;f=0;g=0;do{i=((a[9633944+j|0]&1)<<j^i&255)&255;f=((a[9631744+j|0]&1)<<j^f&255)&255;g=((a[9629720+j|0]&1)<<j^g&255)&255;j=j+1|0;}while((j|0)<8);a[9550680]=i;a[9550681]=f;a[9550682]=g;g=c[2439330]|0;if((g|0)!=0){f=g;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;f=c[2438118]|0;c[2433530]=f;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;if((a[g+4188|0]|0)==0){g=gfc(5120)|0;l=(c[2433530]|0)+g|0}else{l=f+5120|0}c[2433530]=l;fJ_(666)|0;if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){l=gfc(5120)|0;m=(c[2433530]|0)+l|0}else{m=(c[2433530]|0)+5120|0}c[2433530]=m;fJ_(666)|0;if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){m=gfc(5120)|0;n=(c[2433530]|0)+m|0}else{n=(c[2433530]|0)+5120|0}c[2433530]=n;fJ_(666)|0;if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){n=gfc(5120)|0;o=(c[2433530]|0)+n|0}else{o=(c[2433530]|0)+5120|0}c[2433530]=o;fJ_(666)|0;if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){o=gfc(5120)|0;p=(c[2433530]|0)+o|0}else{p=(c[2433530]|0)+5120|0}c[2433530]=p;fJ_(666)|0;if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){p=gfc(5120)|0;q=(c[2433530]|0)+p|0}else{q=(c[2433530]|0)+5120|0}c[2433530]=q;fJ_(666)|0;if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){q=gfc(5120)|0;r=(c[2433530]|0)+q|0}else{r=(c[2433530]|0)+5120|0}c[2433530]=r;fJ_(666)|0;if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){r=gfc(5120)|0;s=(c[2433530]|0)+r|0}else{s=(c[2433530]|0)+5120|0}c[2433530]=s;fJ_(666)|0;if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){s=gfc(5120)|0;t=(c[2433530]|0)+s|0}else{t=(c[2433530]|0)+5120|0}c[2433530]=t;fJ_(666)|0;if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){t=gfc(5120)|0;u=(c[2433530]|0)+t|0}else{u=(c[2433530]|0)+5120|0}c[2433530]=u;fJ_(666)|0;if((a[c[2394726]|0]|0)!=0){if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12}u=c[1836236]|0;t=c[9757320+(u<<2)>>2]|0;if((t|0)!=0){s=t;gGC(s|0,9706056,76)|0}c[9752472+(u<<2)>>2]=c[2433530];c[14113936+(u<<2)>>2]=c[2076596];c[9669104+(u<<2)>>2]=c[3541536];c[1836236]=-1;u=c[2112964]|0;if((u|0)!=0){UR(u,a[9688]|0?534:0);Vg(c[2112964]|0,a[9688]|0?534:0)}if((c[2112968]|0)==0){return 0}u=c[(c[642608+(c[2436]<<2)>>2]|0)+112>>2]|0;if((u|0)==0){return 0}gD[u&8191]()|0;return 0}function dAE(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if((a[9547656]|0)!=0){gu[c[2433460]&16383]();a[9547656]=0}e=c[2386238]|0;f=c[2405106]|0;g=c[3531022]|0;h=c[2440368]|0;i=c[2112926]|0;j=c[3530878]|0;k=64;do{l=k&31;Si(i,d[f]<<8|d[e+k|0],l<<3,(((k|0)/32|0)<<3)-16|0,d[h]<<4|a[g+((((k|0)/128|0)<<5)+(l|512))|0]&15,2,0,j);k=k+1|0;}while((k|0)<960);k=c[3530070]|0;c[k+1024>>2]=63488;c[k+1028>>2]=31;k=c[3530452]|0;j=16;g=1024;h=a[k+1024|0]|0;do{e=h&255;f=e<<2&508;do{if(f>>>0<256){if((e&128|0)==0){if((a[c[2444196]|0]|0)==0){break}i=(ag(c[2113068]|0,j-16|0)|0)+f|0;b[(c[2112926]|0)+(i<<1)>>1]=257;break}else{if(((cT()|0)&1|0)==0){break}i=(ag(c[2113068]|0,j-16|0)|0)+f|0;b[(c[2112926]|0)+(i<<1)>>1]=256;break}}}while(0);g=g+1|0;h=a[k+g|0]|0;j=(f>>>0>=((h&255)<<2&508)>>>0)+j|0;}while((j|0)<241);dCj(127,64,1,0);R8(c[3530070]|0);return 0}function dAF(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1428292+(b*112|0)>>2];c[a+104>>2]=c[1428296+(b*112|0)>>2];c[a+108>>2]=c[1428300+(b*112|0)>>2];d=0;return d|0}function dAG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=1428192+(b*112|0);e=0;return e|0}function dAH(){var a=0,d=0,e=0,f=0,g=0;a=dBX(1668,6434,0)|0;if((a|0)!=0){return a|0}d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];f=c[3528484]|0;c[2076596]=f;g=c[2417276]|0;c[3541536]=g;c[1836236]=0;c[d+4184>>2]=1294;if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=f;c[2417276]=g;c[1836236]=-1;return a|0}function dAI(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6587684+(b*112|0)>>2];c[a+104>>2]=c[6587688+(b*112|0)>>2];c[a+108>>2]=c[6587692+(b*112|0)>>2];d=0;return d|0}function dAJ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=6587584+(b*112|0);e=0;return e|0}function dAK(a,b){a=a|0;b=b|0;var d=0;do{if(b>>>0>5){d=1}else{if((a|0)==0){d=0;break}c[a+100>>2]=c[4052908+(b*104|0)>>2];d=0}}while(0);return d|0}function dAL(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<6&(d|0)==0)){e=1;return e|0}c[a>>2]=4052808+(b*104|0);e=0;return e|0}function dAM(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5455336+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dAN(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6943712+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dAO(){return dBX(202,6434,0)|0}function dAP(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if((a[9547656]|0)!=0){gu[c[2433460]&16383]();a[9547656]=0}b=c[2386238]|0;e=c[2405106]|0;f=c[3531022]|0;g=c[2440368]|0;h=c[2112926]|0;i=c[3530878]|0;j=64;do{k=j&31;Si(h,d[e]<<8|d[b+j|0],k<<3,(((j|0)/32|0)<<3)-16|0,d[g]<<4|a[f+((((j|0)/128|0)<<5)+(k|512))|0]&15,2,0,i);j=j+1|0;}while((j|0)<960);dCj(127,64,1,0);R8(c[3530070]|0);return 0}function dAQ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5908172+(b*112|0)>>2];c[a+104>>2]=c[5908176+(b*112|0)>>2];c[a+108>>2]=c[5908180+(b*112|0)>>2];d=0;return d|0}function dAR(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=5908072+(b*112|0);e=0;return e|0}function dAS(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5909852+(b*112|0)>>2];c[a+104>>2]=c[5909856+(b*112|0)>>2];c[a+108>>2]=c[5909860+(b*112|0)>>2];d=0;return d|0}function dAT(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=5909752+(b*112|0);e=0;return e|0}function dAU(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4739684+(b*112|0)>>2];c[a+104>>2]=c[4739688+(b*112|0)>>2];c[a+108>>2]=c[4739692+(b*112|0)>>2];d=0;return d|0}function dAV(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=4739584+(b*112|0);e=0;return e|0}function dAW(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2938788+(b*112|0)>>2];c[a+104>>2]=c[2938792+(b*112|0)>>2];c[a+108>>2]=c[2938796+(b*112|0)>>2];d=0;return d|0}function dAX(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=2938688+(b*112|0);e=0;return e|0}function dAY(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5911532+(b*112|0)>>2];c[a+104>>2]=c[5911536+(b*112|0)>>2];c[a+108>>2]=c[5911540+(b*112|0)>>2];d=0;return d|0}function dAZ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=5911432+(b*112|0);e=0;return e|0}function dA_(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6346632+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dA$(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5906380+(b*112|0)>>2];c[a+104>>2]=c[5906384+(b*112|0)>>2];c[a+108>>2]=c[5906388+(b*112|0)>>2];d=0;return d|0}function dA0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=5906280+(b*112|0);e=0;return e|0}function dA1(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;a=dBX(3402,6434,0)|0;if((a|0)!=0){return a|0}d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];f=c[3528484]|0;c[2076596]=f;g=c[2417276]|0;c[3541536]=g;c[1836236]=0;c[d+4184>>2]=876;c[d+4180>>2]=2976;c[3528812]=0;h=c[2385950]|0;i=0;j=0;while(1){c[d+76+(j<<2)>>2]=h+(j<<8);k=i+1&65535;if((k&65535)>95){l=0;m=0;break}else{i=k;j=k&65535}}while(1){j=h+(m<<8)|0;c[d+76+(m+512<<2)>>2]=j;c[d+76+(m+768<<2)>>2]=j;j=l+1&65535;if((j&65535)>95){n=128;o=128;break}else{l=j;m=j&65535}}while(1){c[d+76+(o<<2)>>2]=h+((o<<8)-32768);m=n+1&65535;if((m&65535)>199){p=201;q=201;break}else{n=m;o=m&65535}}while(1){c[d+76+(q<<2)>>2]=h+((q<<8)-32768);o=p+1&65535;if((o&65535)>255){r=128;s=128;break}else{p=o;q=o&65535}}while(1){q=h+((s<<8)-32768)|0;c[d+76+(s+512<<2)>>2]=q;c[d+76+(s+768<<2)>>2]=q;q=r+1&65535;if((q&65535)>255){break}else{r=q;s=q&65535}}if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=f;c[2417276]=g;c[1836236]=-1;return a|0}function dA2(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2934084+(b*112|0)>>2];c[a+104>>2]=c[2934088+(b*112|0)>>2];c[a+108>>2]=c[2934092+(b*112|0)>>2];d=0;return d|0}function dA3(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=2933984+(b*112|0);e=0;return e|0}function dA4(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4738228+(b*112|0)>>2];c[a+104>>2]=c[4738232+(b*112|0)>>2];c[a+108>>2]=c[4738236+(b*112|0)>>2];d=0;return d|0}function dA5(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=4738128+(b*112|0);e=0;return e|0}function dA6(a,b){a=a|0;b=b|0;var d=0;do{if(b>>>0>12){d=1}else{if((a|0)==0){d=0;break}c[a+100>>2]=c[1281540+(b*104|0)>>2];d=0}}while(0);return d|0}function dA7(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=1281440+(b*104|0);e=0;return e|0}function dA8(){return dBX(3288,6434,0)|0}function dA9(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2935876+(b*112|0)>>2];c[a+104>>2]=c[2935880+(b*112|0)>>2];c[a+108>>2]=c[2935884+(b*112|0)>>2];d=0;return d|0}function dBa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=2935776+(b*112|0);e=0;return e|0}function dBb(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1563372+(b*112|0)>>2];c[a+104>>2]=c[1563376+(b*112|0)>>2];c[a+108>>2]=c[1563380+(b*112|0)>>2];d=0;return d|0}function dBc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=1563272+(b*112|0);e=0;return e|0}function dBd(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2937332+(b*112|0)>>2];c[a+104>>2]=c[2937336+(b*112|0)>>2];c[a+108>>2]=c[2937340+(b*112|0)>>2];d=0;return d|0}function dBe(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=2937232+(b*112|0);e=0;return e|0}function dBf(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5843228+(b*112|0)>>2];c[a+104>>2]=c[5843232+(b*112|0)>>2];c[a+108>>2]=c[5843236+(b*112|0)>>2];d=0;return d|0}function dBg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=5843128+(b*112|0);e=0;return e|0}function dBh(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4744836+(b*112|0)>>2];c[a+104>>2]=c[4744840+(b*112|0)>>2];c[a+108>>2]=c[4744844+(b*112|0)>>2];d=0;return d|0}function dBi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=4744736+(b*112|0);e=0;return e|0}function dBj(){return dBX(3902,6434,0)|0}function dBk(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2459956+(b*112|0)>>2];c[a+104>>2]=c[2459960+(b*112|0)>>2];c[a+108>>2]=c[2459964+(b*112|0)>>2];d=0;return d|0}function dBl(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=2459856+(b*112|0);e=0;return e|0}function dBm(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5455336+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dBn(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3625712+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dBo(){return dBX(2278,6434,1)|0}function dBp(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if((a[9547656]|0)!=0){gu[c[2433460]&16383]();a[9547656]=0}b=c[2386238]|0;e=c[2405106]|0;f=c[3531022]|0;g=c[2440368]|0;h=c[2112926]|0;i=c[3530878]|0;j=64;do{k=j&31;Si(h,d[e]<<8|d[b+j|0],k<<3,(((j|0)/32|0)<<3)-16|0,d[g]<<4|a[f+((((j|0)/128|0)<<5)+(k|512))|0]&15,2,0,i);j=j+1|0;}while((j|0)<960);dCj(255,0,0,1);R8(c[3530070]|0);return 0}function dBq(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5913212+(b*112|0)>>2];c[a+104>>2]=c[5913216+(b*112|0)>>2];c[a+108>>2]=c[5913220+(b*112|0)>>2];d=0;return d|0}function dBr(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=5913112+(b*112|0);e=0;return e|0}function dBs(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4053432+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dBt(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>36){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6346912+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dBu(){var a=0,d=0,e=0,f=0,g=0;a=dBX(2548,4830,3)|0;if((a|0)!=0){return a|0}d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];f=c[3528484]|0;c[2076596]=f;g=c[2417276]|0;c[3541536]=g;c[1836236]=0;c[d+4184>>2]=2376;c[d+4180>>2]=2334;if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=f;c[2417276]=g;c[1836236]=-1;return a|0}function dBv(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4741364+(b*112|0)>>2];c[a+104>>2]=c[4741368+(b*112|0)>>2];c[a+108>>2]=c[4741372+(b*112|0)>>2];d=0;return d|0}function dBw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=4741264+(b*112|0);e=0;return e|0}function dBx(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4743156+(b*112|0)>>2];c[a+104>>2]=c[4743160+(b*112|0)>>2];c[a+108>>2]=c[4743164+(b*112|0)>>2];d=0;return d|0}function dBy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=4743056+(b*112|0);e=0;return e|0}function dBz(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5455576+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dBA(){return dBX(436,4830,1)|0}function dBB(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2768532+(b*112|0)>>2];c[a+104>>2]=c[2768536+(b*112|0)>>2];c[a+108>>2]=c[2768540+(b*112|0)>>2];d=0;return d|0}function dBC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=2768432+(b*112|0);e=0;return e|0}function dBD(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3873424+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dBE(){c[2432782]=1;return dB3(5004)|0}function dBF(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c[2113070]=0;c[2113068]=0;a=c[2112926]|0;if((a|0)!=0){gGr(a);c[2112926]=0}gGz(8443768,0,6208);gGz(9718136,0,38);gGz(9669136,0,152);a=c[2426620]|0;if((a|0)!=0){gGr(a);c[2426620]=0}c[2440608]=0;a=c[2439194]|0;b=c[2406652]|0;if((a|0)>0){d=0;e=b;f=a;while(1){a=e+(d*40|0)|0;c[3528400]=a;g=c[a>>2]|0;if((g|0)==0){h=f;i=e}else{gGr(g);c[c[3528400]>>2]=0;h=c[2439194]|0;i=c[2406652]|0}g=d+1|0;if((g|0)<(h|0)){d=g;e=i;f=h}else{j=i;break}}}else{j=b}if((j|0)!=0){gGr(j);c[2406652]=0}c[3528400]=0;c[2439194]=0;c[2442914]=0;UT();j=c[2415014]|0;b=0;while(1){if((b|0)>=1024){k=4201;break}l=9638528+(b<<2)|0;if((c[l>>2]|0)==(j|0)){break}else{b=b+1|0}}if((k|0)==4201){c[2415014]=0;c[2432782]=0;return 0}gGr(j);c[l>>2]=0;c[2415014]=0;c[2432782]=0;return 0}function dBG(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0;if((a[9624528]|0)!=0){d=c[2414720]|0;gGz(d|0,0,(c[2411748]|0)-d|0);c[2110940]=8443768;gGz(9718136,0,38);a[9718144]=10;a[9718145]=0;gGC(9669136,9718136,38)|0;c[2444]=-1;b[4859110]=0;a[9718225]=0;a[9718224]=0;a[9718226]=8;a[9718229]=-1;a[9718230]=-1;a[9718227]=0;a[9718237]=0;a[9718236]=0;a[9718249]=0;a[9718238]=0;gGz(9718242,0,6);d=c[2439194]|0;if((d|0)>0){e=c[2406652]|0;f=0;do{g=e+(f*40|0)|0;i=e+(f*40|0)+12|0;a[i]=0;j=e+(f*40|0)+8|0;c[j>>2]=0;k=a[e+(f*40|0)+14|0]|0;do{if((k&2)!=0&(d|0)>(f|0)){if((k&4)==0){a[e+(f*40|0)+13|0]=1}if((k&1)!=0){break}a[i]=1;c[j>>2]=0}}while(0);f=f+1|0;}while((f|0)<(d|0));c[3528400]=g}g=c[2405758]|0;if((g|0)>0){d=0;do{c[9542560+(d<<5)>>2]=0;b[9542544+(d<<5)>>1]=0;d=d+1|0;}while((d|0)<(g|0))}a[9579192]=a[9579192]&-16;a[9642624]=0;a[9757080]=0}h[1214783]=0.0;gGz(9550680,0,3);g=0;d=0;f=0;e=0;do{d=((a[9633944+g|0]&1)<<g^d&255)&255;f=((a[9631744+g|0]&1)<<g^f&255)&255;e=((a[9629720+g|0]&1)<<g^e&255)&255;g=g+1|0;}while((g|0)<8);a[9550680]=d;a[9550681]=f;a[9550682]=e;c[2110940]=8443768;c[2444]=0;gGC(9718136,9669136,38)|0;a[672600]=0;e=0;while(1){geH(800)|0;fJ_(208)|0;if((e|0)==30){a[672600]=1;geG(0);geH(10)|0;a[9718172]=0;e=31;continue}else{f=e+1|0;if((f|0)<32){e=f;continue}else{break}}}e=9669136+((c[2444]|0)*38|0)|0;gGC(e|0,9718136,38)|0;c[2444]=-1;e=c[2112964]|0;if((e|0)!=0){UR(e,a[9688]|0?534:0);Vg(c[2112964]|0,a[9688]|0?534:0)}if((c[2112968]|0)==0){return 0}e=c[(c[642608+(c[2436]<<2)>>2]|0)+112>>2]|0;if((e|0)==0){return 0}gD[e&8191]()|0;return 0}function dBH(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5869532+(b*112|0)>>2];c[a+104>>2]=c[5869536+(b*112|0)>>2];c[a+108>>2]=c[5869540+(b*112|0)>>2];d=0;return d|0}function dBI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=5869432+(b*112|0);e=0;return e|0}function dBJ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3873152+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dBK(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6276808+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dBL(){c[2432782]=2;return dB3(2694)|0}function dBM(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4671132+(b*112|0)>>2];c[a+104>>2]=c[4671136+(b*112|0)>>2];c[a+108>>2]=c[4671140+(b*112|0)>>2];d=0;return d|0}function dBN(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=4671032+(b*112|0);e=0;return e|0}function dBO(){c[2432782]=2;return dB3(26)|0}function dBP(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=(a[9734728]|0)+((b&1)==0?1:15)&255;b=d&15;a[9734728]=b;if((b-8&255)>=4){return 0}b=c[2385950]|0;e=(d&255)<<14&49152|65536;d=c[9757320+(c[1836236]<<2)>>2]|0;f=0;g=0;while(1){c[d+76+(g<<2)>>2]=b+((g<<8)+e);h=f+1&65535;if((h&65535)>63){i=0;j=0;break}else{f=h;g=h&65535}}while(1){g=b+((j<<8)+e)|0;c[d+76+(j+512<<2)>>2]=g;c[d+76+(j+768<<2)>>2]=g;g=i+1&65535;if((g&65535)>63){break}else{i=g;j=g&65535}}return 0}function dBQ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4732892+(b*112|0)>>2];c[a+104>>2]=c[4732896+(b*112|0)>>2];c[a+108>>2]=c[4732900+(b*112|0)>>2];d=0;return d|0}function dBR(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=4732792+(b*112|0);e=0;return e|0}function dBS(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>23){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5450488+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dBT(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a[9734728]=9;d=dBX(842,6434,0)|0;if((d|0)!=0){return d|0}e=c[2439330]|0;f=(e|0)==0;if(!f){g=e;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];g=c[3528484]|0;c[2076596]=g;h=c[2417276]|0;c[3541536]=h;c[1836236]=0;c[e+4172>>2]=1518;i=c[2385950]|0;j=0;k=0;while(1){c[e+76+(k<<2)>>2]=i+((k<<8)+81920);l=j+1&65535;if((l&65535)>63){m=0;n=0;break}else{j=l;k=l&65535}}while(1){k=i+((n<<8)+81920)|0;c[e+76+(n+512<<2)>>2]=k;c[e+76+(n+768<<2)>>2]=k;k=m+1&65535;if((k&65535)>63){break}else{m=k;n=k&65535}}gGz(9706056,0,76);if(!f){f=e;gGC(f|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=g;c[2417276]=h;c[1836236]=-1;return d|0}function dBU(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4730316+(b*112|0)>>2];c[a+104>>2]=c[4730320+(b*112|0)>>2];c[a+108>>2]=c[4730324+(b*112|0)>>2];d=0;return d|0}function dBV(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=4730216+(b*112|0);e=0;return e|0}function dBW(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a[9734728]=9;d=dBX(842,6434,0)|0;if((d|0)!=0){return d|0}e=c[2439330]|0;f=(e|0)==0;if(!f){g=e;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];g=c[3528484]|0;c[2076596]=g;h=c[2417276]|0;c[3541536]=h;c[1836236]=0;c[e+4184>>2]=1214;c[e+4172>>2]=1518;i=c[2385950]|0;j=0;k=0;while(1){c[e+76+(k<<2)>>2]=i+((k<<8)+81920);l=j+1&65535;if((l&65535)>63){m=0;n=0;break}else{j=l;k=l&65535}}while(1){k=i+((n<<8)+81920)|0;c[e+76+(n+512<<2)>>2]=k;c[e+76+(n+768<<2)>>2]=k;k=m+1&65535;if((k&65535)>63){break}else{m=k;n=k&65535}}gGz(9706056,0,76);if(!f){f=e;gGC(f|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=g;c[2417276]=h;c[1836236]=-1;return d|0}function dBX(d,e,f){d=d|0;e=e|0;f=f|0;var g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;c[2415014]=0;c[3531220]=0;c[2385950]=0;c[3529764]=131072;c[3529718]=139264;c[3530878]=147456;c[3530642]=180224;c[3530452]=245760;c[3531022]=247808;c[2387342]=248576;c[2386746]=249088;c[3530070]=251136;c[2414720]=252168;c[3531222]=252168;c[2386104]=252168;c[2386490]=256264;c[2386238]=259080;c[3528308]=260104;c[2405106]=260105;c[2443706]=260106;c[2440368]=260107;c[3528734]=260108;c[2394726]=260109;c[3528630]=260110;c[2444196]=260111;c[2411748]=260112;g=0;while(1){if((g|0)>=1024){break}i=9638528+(g<<2)|0;if((c[i>>2]|0)==0){j=4335;break}else{g=g+1|0}}do{if((j|0)==4335){g=gGq(260112)|0;c[i>>2]=g;if((g|0)==0){break}c[2415014]=g;gGz(g|0,0,260112);c[3531220]=g;c[2385950]=g;c[3529764]=g+131072;c[3529718]=g+139264;c[3530878]=g+147456;c[3530642]=g+180224;c[3530452]=g+245760;c[3531022]=g+247808;c[2387342]=g+248576;c[2386746]=g+249088;c[3530070]=g+251136;k=g+252168|0;c[2414720]=k;c[3531222]=k;c[2386104]=k;c[2386490]=g+256264;c[2386238]=g+259080;c[3528308]=g+260104;c[2405106]=g+260105;c[2443706]=g+260106;c[2440368]=g+260107;c[3528734]=g+260108;c[2394726]=g+260109;c[3528630]=g+260110;c[2444196]=g+260111;k=g+260112|0;c[2411748]=k;c[2414290]=k;fwR(0);k=c[2439330]|0;g=(k|0)==0;if(!g){l=k;gGC(9706056,l|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];l=c[3528484]|0;c[2076596]=l;m=c[2417276]|0;c[3541536]=m;c[1836236]=0;n=c[2385950]|0;o=0;p=0;while(1){c[k+76+(p<<2)>>2]=n+(p<<8);q=o+1&65535;if((q&65535)>95){r=0;s=0;break}else{o=q;p=q&65535}}while(1){p=n+(s<<8)|0;c[k+76+(s+512<<2)>>2]=p;c[k+76+(s+768<<2)>>2]=p;p=r+1&65535;if((p&65535)>95){break}else{r=p;s=p&65535}}p=c[2386104]|0;c[k+460>>2]=p;o=p+256|0;c[k+464>>2]=o;q=p+512|0;c[k+468>>2]=q;t=p+768|0;c[k+472>>2]=t;u=p+1024|0;c[k+476>>2]=u;v=p+1280|0;c[k+480>>2]=v;w=p+1536|0;c[k+484>>2]=w;x=p+1792|0;c[k+488>>2]=x;y=p+2048|0;c[k+492>>2]=y;if((f&2|0)==0){c[k+496>>2]=p+2304;c[k+500>>2]=p+2560;c[k+504>>2]=p+2816;c[k+508>>2]=p+3072;c[k+512>>2]=p+3328;c[k+516>>2]=p+3584;c[k+520>>2]=p+3840;z=96;A=96;while(1){c[k+76+(A+256<<2)>>2]=p+((A<<8)-24576);B=z+1&65535;if((B&65535)>111){C=96;D=96;break}else{z=B;A=B&65535}}while(1){A=p+((D<<8)-24576)|0;c[k+76+(D+512<<2)>>2]=A;c[k+76+(D+768<<2)>>2]=A;A=C+1&65535;if((A&65535)>111){break}else{C=A;D=A&65535}}A=c[2386490]|0;c[k+524>>2]=A;z=A+256|0;c[k+528>>2]=z;B=A+512|0;c[k+532>>2]=B;E=A+768|0;c[k+536>>2]=E;c[k+1548>>2]=A;c[k+1552>>2]=z;c[k+1556>>2]=B;c[k+1560>>2]=E;c[k+2572>>2]=A;c[k+3596>>2]=A;c[k+2576>>2]=z;c[k+3600>>2]=z;c[k+2580>>2]=B;c[k+3604>>2]=B;c[k+2584>>2]=E;c[k+3608>>2]=E}else{c[k+1484>>2]=p;c[k+1488>>2]=o;c[k+1492>>2]=q;c[k+1496>>2]=t;c[k+1500>>2]=u;c[k+1504>>2]=v;c[k+1508>>2]=w;c[k+1512>>2]=x;c[k+1516>>2]=y;c[k+2508>>2]=p;c[k+3532>>2]=p;c[k+2512>>2]=o;c[k+3536>>2]=o;c[k+2516>>2]=q;c[k+3540>>2]=q;c[k+2520>>2]=t;c[k+3544>>2]=t;c[k+2524>>2]=u;c[k+3548>>2]=u;c[k+2528>>2]=v;c[k+3552>>2]=v;c[k+2532>>2]=w;c[k+3556>>2]=w;c[k+2536>>2]=x;c[k+3560>>2]=x;c[k+2540>>2]=y;c[k+3564>>2]=y;E=c[2386490]|0;c[k+496>>2]=E;B=E+256|0;c[k+500>>2]=B;z=E+512|0;c[k+504>>2]=z;A=E+768|0;c[k+508>>2]=A;F=E+1024|0;c[k+512>>2]=F;G=E+1280|0;c[k+516>>2]=G;H=E+1536|0;c[k+520>>2]=H;I=E+1792|0;c[k+524>>2]=I;J=E+2048|0;c[k+528>>2]=J;K=E+2304|0;c[k+532>>2]=K;L=E+2560|0;c[k+536>>2]=L;c[k+1520>>2]=E;c[k+1524>>2]=B;c[k+1528>>2]=z;c[k+1532>>2]=A;c[k+1536>>2]=F;c[k+1540>>2]=G;c[k+1544>>2]=H;c[k+1548>>2]=I;c[k+1552>>2]=J;c[k+1556>>2]=K;c[k+1560>>2]=L;c[k+2544>>2]=E;c[k+3568>>2]=E;c[k+2548>>2]=B;c[k+3572>>2]=B;c[k+2552>>2]=z;c[k+3576>>2]=z;c[k+2556>>2]=A;c[k+3580>>2]=A;c[k+2560>>2]=F;c[k+3584>>2]=F;c[k+2564>>2]=G;c[k+3588>>2]=G;c[k+2568>>2]=H;c[k+3592>>2]=H;c[k+2572>>2]=I;c[k+3596>>2]=I;c[k+2576>>2]=J;c[k+3600>>2]=J;c[k+2580>>2]=K;c[k+3604>>2]=K;c[k+2584>>2]=L;c[k+3608>>2]=L}L=c[2386238]|0;c[k+540>>2]=L;K=L+256|0;c[k+544>>2]=K;J=L+512|0;c[k+548>>2]=J;I=L+768|0;c[k+552>>2]=I;c[k+1564>>2]=L;c[k+1568>>2]=K;c[k+1572>>2]=J;c[k+1576>>2]=I;c[k+2588>>2]=L;c[k+3612>>2]=L;c[k+2592>>2]=K;c[k+3616>>2]=K;c[k+2596>>2]=J;c[k+3620>>2]=J;c[k+2600>>2]=I;c[k+3624>>2]=I;if((f&1|0)!=0){I=128;J=128;while(1){c[k+76+(J<<2)>>2]=n+(J<<8);K=I+1&65535;if((K&65535)>255){M=128;N=128;break}else{I=K;J=K&65535}}while(1){J=n+(N<<8)|0;c[k+76+(N+512<<2)>>2]=J;c[k+76+(N+768<<2)>>2]=J;J=M+1&65535;if((J&65535)>255){break}else{M=J;N=J&65535}}}c[k+4184>>2]=636;c[k+4180>>2]=2050;if(!g){n=k;gGC(n|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=l;c[2417276]=m;c[1836236]=-1;n=gGq(128)|0;c[2426620]=n;c[2429563]=0;a[9718232]=0;a[9718233]=127;b[4859117]=2048;gGz(n|0,0,128);a[9718241]=0;c[3541286]=60;c[3541284]=886;c[3541282]=1788;c[3541290]=1788;c[3541288]=1788;c[2405758]=1;gGz(9542544,0,32);c[2385641]=1;h[1192819]=1.0;c[2385642]=3;c[2385643]=1884;n=0;do{J=n*257|0;b[9732544+(n<<1)>>1]=((J|0)/2|0)&65535;b[9753784+(n<<1)>>1]=J+32768&65535;n=n+1|0;}while((n|0)<256);c[3528842]=0;h[1192819]=.75;c[2385642]=3;Vf(1);n=c[2439194]|0;if((n|0)>0){m=c[2406652]|0;l=0;while(1){h[m+(l*40|0)+16>>3]=.75;c[m+(l*40|0)+32>>2]=3;k=l+1|0;if((k|0)<(n|0)){l=k}else{break}}c[3528400]=m+(l*40|0);k=0;while(1){h[m+(k*40|0)+24>>3]=.75;c[m+(k*40|0)+36>>2]=3;g=k+1|0;if((g|0)<(n|0)){k=g}else{break}}c[3528400]=m+(k*40|0)}c[2438248]=2860;c[2433588]=3160;c[2439260]=1420;c[2438240]=1670;c[2439261]=3608;c[2438241]=888;c[2439262]=1420;c[2438242]=888;c[2439263]=1420;c[2438243]=888;c[2444166]=1310;Tq(1116240);do{if((d|0)!=0){if((gD[d&8191]()|0)==0){break}else{O=1}return O|0}}while(0);if((e|0)!=0){c[2433460]=e;gu[e&16383]()}dB0();k=c[642608+(c[2436]<<2)>>2]|0;m=c[k+128>>2]|0;if((c[k+52>>2]&4|0)==0){c[2113068]=m;n=c[k+132>>2]|0;c[2113070]=n;c[2443814]=m;c[2440436]=n;P=m;Q=n}else{c[2113070]=m;n=c[k+132>>2]|0;c[2113068]=n;c[2440436]=m;c[2443814]=n;P=n;Q=m}m=ag(P<<1,Q)|0;n=gGq(m)|0;c[2112926]=n;if((n|0)!=0){gGz(n|0,0,m|0)}m=c[2414720]|0;gGz(m|0,0,(c[2411748]|0)-m|0);m=c[2439330]|0;n=(m|0)==0;if(!n){k=m;gGC(9706056,k|0,76)|0}k=c[2438118]|0;c[2433530]=k;l=c[3528484]|0;c[2076596]=l;g=c[2417276]|0;c[3541536]=g;c[1836236]=0;gGz(9706056,0,76);if(!n){n=m;gGC(n|0,9706056,76)|0}c[2438118]=k;c[3528484]=l;c[2417276]=g;c[1836236]=-1;b[4859110]=0;a[9718225]=0;a[9718224]=0;a[9718226]=8;a[9718229]=-1;a[9718230]=-1;a[9718227]=0;a[9718237]=0;a[9718236]=0;a[9718249]=0;a[9718238]=0;gGz(9718242,0,6);g=c[2439194]|0;if((g|0)>0){l=c[2406652]|0;k=0;do{R=l+(k*40|0)|0;n=l+(k*40|0)+12|0;a[n]=0;m=l+(k*40|0)+8|0;c[m>>2]=0;J=a[l+(k*40|0)+14|0]|0;do{if((J&2)!=0&(g|0)>(k|0)){if((J&4)==0){a[l+(k*40|0)+13|0]=1}if((J&1)!=0){break}a[n]=1;c[m>>2]=0}}while(0);k=k+1|0;}while((k|0)<(g|0));c[3528400]=R}g=c[2405758]|0;if((g|0)>0){k=0;do{c[9542560+(k<<5)>>2]=0;b[9542544+(k<<5)>>1]=0;k=k+1|0;}while((k|0)<(g|0))}a[9579192]=a[9579192]&-16;a[9642624]=0;c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];O=0;return O|0}}while(0);c[2415014]=0;O=1;return O|0}function dBY(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;b=i;i=i+1440|0;d=b|0;e=b+112|0;f=b+120|0;g=b+232|0;h=b+240|0;j=b+352|0;k=b+360|0;l=b+472|0;m=b+480|0;n=b+592|0;o=b+600|0;p=b+712|0;q=b+720|0;r=b+832|0;s=b+840|0;t=b+952|0;u=b+960|0;v=b+1072|0;w=b+1080|0;x=b+1192|0;y=b+1200|0;z=b+1312|0;A=b+1320|0;B=b+1432|0;C=c[2385950]|0;if((c[3542200]|0)==0){D=1;i=b;return D|0}E=A+108|0;c[E>>2]=0;F=A+100|0;c[F>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](A,0)|0;do{if((c[E>>2]|0)!=0){A=c[F>>2]|0;c[B>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](B,0,0)|0;if((A|0)<1){D=1;i=b;return D|0}if((gzL(C,0,0)|0)==0){break}else{D=1}i=b;return D|0}}while(0);C=(c[2385950]|0)+8192|0;if((c[3542200]|0)==0){D=1;i=b;return D|0}B=y+108|0;c[B>>2]=0;F=y+100|0;c[F>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](y,1)|0;do{if((c[B>>2]|0)!=0){y=c[F>>2]|0;c[z>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](z,1,0)|0;if((y|0)<1){D=1;i=b;return D|0}if((gzL(C,0,1)|0)==0){break}else{D=1}i=b;return D|0}}while(0);C=c[3529764]|0;if((c[3542200]|0)==0){D=1;i=b;return D|0}z=w+108|0;c[z>>2]=0;F=w+100|0;c[F>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](w,2)|0;do{if((c[z>>2]|0)!=0){w=c[F>>2]|0;c[x>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](x,2,0)|0;if((w|0)<1){D=1;i=b;return D|0}if((gzL(C,0,2)|0)==0){break}else{D=1}i=b;return D|0}}while(0);C=c[3529764]|0;x=C+2048|0;gGC(x|0,C|0,2048)|0;gGz(C+4096|0,0,2048);C=c[3530878]|0;if((c[3542200]|0)==0){D=1;i=b;return D|0}x=u+108|0;c[x>>2]=0;F=u+100|0;c[F>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](u,3)|0;do{if((c[x>>2]|0)!=0){u=c[F>>2]|0;c[v>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](v,3,0)|0;if((u|0)<1){D=1;i=b;return D|0}if((gzL(C,0,3)|0)==0){break}else{D=1}i=b;return D|0}}while(0);C=(c[3530878]|0)+4096|0;if((c[3542200]|0)==0){D=1;i=b;return D|0}v=s+108|0;c[v>>2]=0;F=s+100|0;c[F>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](s,4)|0;do{if((c[v>>2]|0)!=0){s=c[F>>2]|0;c[t>>2]=9534384;x=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[x&16383](t,4,0)|0;if((s|0)<1){D=1;i=b;return D|0}if((gzL(C,0,4)|0)==0){break}else{D=1}i=b;return D|0}}while(0);C=c[3530878]|0;t=C+2048|0;gGC(t|0,C|0,2048)|0;t=C+6144|0;F=C+4096|0;gGC(t|0,F|0,2048)|0;F=c[3530642]|0;if((c[3542200]|0)==0){D=1;i=b;return D|0}t=q+108|0;c[t>>2]=0;C=q+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](q,5)|0;do{if((c[t>>2]|0)!=0){q=c[C>>2]|0;c[r>>2]=9534384;v=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[v&16383](r,5,0)|0;if((q|0)<1){D=1;i=b;return D|0}if((gzL(F,0,5)|0)==0){break}else{D=1}i=b;return D|0}}while(0);F=(c[3530642]|0)+4096|0;if((c[3542200]|0)==0){D=1;i=b;return D|0}r=o+108|0;c[r>>2]=0;C=o+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](o,6)|0;do{if((c[r>>2]|0)!=0){o=c[C>>2]|0;c[p>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](p,6,0)|0;if((o|0)<1){D=1;i=b;return D|0}if((gzL(F,0,6)|0)==0){break}else{D=1}i=b;return D|0}}while(0);F=(c[3530642]|0)+8192|0;if((c[3542200]|0)==0){D=1;i=b;return D|0}p=m+108|0;c[p>>2]=0;C=m+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,7)|0;do{if((c[p>>2]|0)!=0){m=c[C>>2]|0;c[n>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](n,7,0)|0;if((m|0)<1){D=1;i=b;return D|0}if((gzL(F,0,7)|0)==0){break}else{D=1}i=b;return D|0}}while(0);F=(c[3530642]|0)+12288|0;if((c[3542200]|0)==0){D=1;i=b;return D|0}n=k+108|0;c[n>>2]=0;C=k+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,8)|0;do{if((c[n>>2]|0)!=0){k=c[C>>2]|0;c[l>>2]=9534384;p=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[p&16383](l,8,0)|0;if((k|0)<1){D=1;i=b;return D|0}if((gzL(F,0,8)|0)==0){break}else{D=1}i=b;return D|0}}while(0);F=c[3531022]|0;if((c[3542200]|0)==0){D=1;i=b;return D|0}l=h+108|0;c[l>>2]=0;C=h+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](h,9)|0;do{if((c[l>>2]|0)!=0){h=c[C>>2]|0;c[j>>2]=9534384;n=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[n&16383](j,9,0)|0;if((h|0)<1){D=1;i=b;return D|0}if((gzL(F,0,9)|0)==0){break}else{D=1}i=b;return D|0}}while(0);F=(c[3531022]|0)+256|0;if((c[3542200]|0)==0){D=1;i=b;return D|0}j=f+108|0;c[j>>2]=0;C=f+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,10)|0;do{if((c[j>>2]|0)!=0){f=c[C>>2]|0;c[g>>2]=9534384;l=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[l&16383](g,10,0)|0;if((f|0)<1){D=1;i=b;return D|0}if((gzL(F,0,10)|0)==0){break}else{D=1}i=b;return D|0}}while(0);F=(c[3531022]|0)+512|0;if((c[3542200]|0)==0){D=1;i=b;return D|0}g=d+108|0;c[g>>2]=0;C=d+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](d,11)|0;do{if((c[g>>2]|0)!=0){d=c[C>>2]|0;c[e>>2]=9534384;j=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[j&16383](e,11,0)|0;if((d|0)<1){D=1;i=b;return D|0}if((gzL(F,0,11)|0)==0){break}else{D=1}i=b;return D|0}}while(0);F=c[2385950]|0;e=0;while(1){C=a[F+e|0]^-3;a[F+(e+65536)|0]=C<<3&8|C&-64|(C&255)>>>5&1|(C&255)>>>1<<5&32|(C&255)>>>3<<4&16|(C&255)>>>4<<2&4|(C&255)>>>2<<1&2;C=e+1|0;if((C|0)<16384){e=C}else{H=0;break}}while(1){e=a[F+H|0]^-65;a[F+(H+81920)|0]=e<<3&8|e&-128|(e&255)>>>5&1|(e&255)>>>1<<6&64|(e&255)>>>4<<5&32|(e&255)>>>3<<4&16|(e&255)>>>6<<2&4|(e&255)>>>2<<1&2;e=H+1|0;if((e|0)<16384){H=e}else{I=0;break}}while(1){H=a[F+I|0]^117;a[F+(I+98304)|0]=H<<4&16|H&-56|(H&255)>>>5&1|(H&255)>>>1<<5&32|(H&255)>>>4<<2&4|(H&255)>>>2<<1&2;H=I+1|0;if((H|0)<16384){I=H}else{J=0;break}}while(1){I=a[F+J|0]^55;a[F+(J+114688)|0]=I<<4&16|I&-120|(I&255)>>>5&1|(I&255)>>>1<<6&64|(I&255)>>>4<<5&32|(I&255)>>>6<<2&4|(I&255)>>>2<<1&2;I=J+1|0;if((I|0)<16384){J=I}else{D=0;break}}i=b;return D|0}function dBZ(){var a=0,b=0,e=0,f=0,g=0;a=c[3531022]|0;b=c[3530070]|0;e=0;do{f=d[a+(e+256)|0]|0;g=d[a+e|0]|0;c[b+(e<<2)>>2]=((-(f>>>2&1)&71^255)-((-(f>>>3&1)&151)+(-(f>>>1&1)&33))<<8&63488|(-(g>>>1&1)&168|-(g&1)&80)>>>3|(-(f&1)&151^255)-(-(g>>>3&1)&71)-(-(g>>>2&1)&33)<<3&2016)^31;e=e+1|0;}while((e|0)<256);return}function dB_(a,d){a=a|0;d=d|0;var e=0,f=0.0;if((a|0)==257){e=~~(+(d&255|0)*+ad(+(-0.0- +h[85167])));US(0,gD[c[2385643]&8191]()|0);b[4771272]=~~(+(b[9732544+((e&255)<<1)>>1]|0)*+h[1192819])&65535;if((c[2415288]|0)==0){f=0.0}else{f=+h[85167]+.001}h[85167]=f;return}else if((a|0)==258){a=d&255;c[2415288]=a>>>7^1;c[2420366]=a&71;c[2385560]=a>>>4&1^1;return}else{return}}function dB$(){return~~((a[9688]|0?534.0:0.0)*(+(~~+h[1214783]+(c[2429636]|0)-(c[2440608]|0)|0)/(4.0e5/(+(c[2424]|0)/100.0))))|0}function dB0(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=0;while(1){if((b|0)>=1024){e=4529;break}f=9638528+(b<<2)|0;if((c[f>>2]|0)==0){break}else{b=b+1|0}}if((e|0)==4529){return}b=gGq(16384)|0;c[f>>2]=b;if((b|0)==0){return}gGz(b|0,0,16384);f=c[3530878]|0;gGC(b|0,f|0,8192)|0;g=0;do{h=g<<6;gGz(f+h|0,0,64);i=h+32768|0;j=0;while(1){k=i+(c[609008+(j<<2)>>2]|0)|0;l=(j<<3)+h|0;m=0;do{n=k+(c[610960+(m<<2)>>2]|0)|0;if(((d[b+((n|0)/8|0)|0]|0)&128>>>((n&7)>>>0)|0)!=0){n=f+(l+m)|0;a[n]=a[n]|2}m=m+1|0;}while((m|0)<8);m=j+1|0;if((m|0)<8){j=m}else{o=0;break}}do{j=h+(c[609008+(o<<2)>>2]|0)|0;i=(o<<3)+h|0;m=0;do{l=j+(c[610960+(m<<2)>>2]|0)|0;if(((d[b+((l|0)/8|0)|0]|0)&128>>>((l&7)>>>0)|0)!=0){l=f+(i+m)|0;a[l]=a[l]|1}m=m+1|0;}while((m|0)<8);o=o+1|0;}while((o|0)<8);g=g+1|0;}while((g|0)<512);g=c[3530642]|0;gGC(b|0,g|0,16384)|0;o=0;while(1){f=o<<8;gGz(g+f|0,0,256);h=o<<7;m=h+65536|0;i=0;while(1){j=m+(c[609008+(i<<2)>>2]|0)|0;l=(i<<4)+f|0;k=0;do{n=j+(c[610256+(k<<2)>>2]|0)|0;if(((d[b+((n|0)/8|0)|0]|0)&128>>>((n&7)>>>0)|0)!=0){n=g+(l+k)|0;a[n]=a[n]|2}k=k+1|0;}while((k|0)<16);k=i+1|0;if((k|0)<16){i=k}else{p=0;break}}do{i=h+(c[609008+(p<<2)>>2]|0)|0;m=(p<<4)+f|0;k=0;do{l=i+(c[610256+(k<<2)>>2]|0)|0;if(((d[b+((l|0)/8|0)|0]|0)&128>>>((l&7)>>>0)|0)!=0){l=g+(m+k)|0;a[l]=a[l]|1}k=k+1|0;}while((k|0)<16);p=p+1|0;}while((p|0)<16);f=o+1|0;if((f|0)<256){o=f}else{q=0;break}}while(1){if((q|0)>=1024){e=4528;break}r=9638528+(q<<2)|0;if((c[r>>2]|0)==(b|0)){break}else{q=q+1|0}}if((e|0)==4528){return}gGr(b);c[r>>2]=0;return}function dB1(b,c){b=b|0;c=c|0;a[9542520]=c;return}function dB2(b){b=b|0;return a[9542520]|0}function dB3(e){e=e|0;var f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;c[2415014]=0;c[3531220]=0;c[2385950]=0;c[3529764]=131072;c[3529718]=139264;c[3530878]=147456;c[3530642]=180224;c[3530452]=245760;c[3531022]=247808;c[2387342]=248576;c[2386746]=249088;c[3530070]=251136;c[2414720]=252168;c[3531222]=252168;c[2386104]=252168;c[2386490]=256264;c[2386238]=259080;c[3528308]=260104;c[2405106]=260105;c[2443706]=260106;c[2440368]=260107;c[3528734]=260108;c[2394726]=260109;c[3528630]=260110;c[2444196]=260111;c[2411748]=260112;f=0;while(1){if((f|0)>=1024){break}g=9638528+(f<<2)|0;if((c[g>>2]|0)==0){i=4537;break}else{f=f+1|0}}do{if((i|0)==4537){f=gGq(260112)|0;c[g>>2]=f;if((f|0)==0){break}c[2415014]=f;gGz(f|0,0,260112);c[3531220]=f;c[2385950]=f;c[3529764]=f+131072;c[3529718]=f+139264;c[3530878]=f+147456;c[3530642]=f+180224;c[3530452]=f+245760;c[3531022]=f+247808;j=f+248576|0;c[2387342]=j;k=f+249088|0;c[2386746]=k;c[3530070]=f+251136;l=f+252168|0;c[2414720]=l;c[3531222]=l;c[2386104]=l;c[2386490]=f+256264;c[2386238]=f+259080;c[3528308]=f+260104;c[2405106]=f+260105;c[2443706]=f+260106;c[2440368]=f+260107;c[3528734]=f+260108;c[2394726]=f+260109;c[3528630]=f+260110;c[2444196]=f+260111;l=f+260112|0;c[2411748]=l;c[2414290]=l;do{if((e|0)==0){m=j;n=k}else{if((gD[e&8191]()|0)==0){m=c[2387342]|0;n=c[2386746]|0;break}else{o=1;return o|0}}}while(0);c[2433460]=6434;k=0;do{c[n+((d[m+k|0]|0)<<2)>>2]=k;k=k+1|0;}while((k|0)<512);dB0();gGz(8443768,0,1552);gGz(9669136,0,38);k=c[2427044]|0;c[9681616+(k<<3)>>2]=728712;c[9681620+(k<<3)>>2]=0;c[2427044]=k+1;c[2110940]=8443768;c[2444]=0;gGC(9718136,9669136,38)|0;k=c[3531220]|0;j=0;do{l=k+(j<<8)|0;c[8443784+(j<<2)>>2]=l;c[8444808+(j<<2)>>2]=l;j=j+1|0;}while((j|0)<16);j=c[3531222]|0;c[2110962]=j;c[2111090]=j;c[2111218]=j;l=j+256|0;c[2110963]=l;c[2111091]=l;c[2111219]=l;l=j+512|0;c[2110964]=l;c[2111092]=l;c[2111220]=l;l=j+768|0;c[2110965]=l;c[2111093]=l;c[2111221]=l;l=c[2386490]|0;c[2110968]=l;c[2111096]=l;c[2111224]=l;j=l+256|0;c[2110969]=j;c[2111097]=j;c[2111225]=j;j=c[2386238]|0;c[2110970]=j;c[2111098]=j;c[2111226]=j;f=j+256|0;c[2110971]=f;c[2111099]=f;c[2111227]=f;f=j+512|0;c[2110972]=f;c[2111100]=f;c[2111228]=f;f=j+768|0;c[2110973]=f;c[2111101]=f;c[2111229]=f;f=l+1024|0;c[2110974]=f;c[2111102]=f;c[2111230]=f;f=l+1280|0;c[2110975]=f;c[2111103]=f;c[2111231]=f;f=l+1536|0;c[2110976]=f;c[2111104]=f;c[2111232]=f;f=32;while(1){l=k+(f<<8)|0;c[8443784+(f<<2)>>2]=l;c[8444808+(f<<2)>>2]=l;l=f+1|0;if((l|0)<48){f=l}else{p=64;break}}while(1){f=k+(p<<8)|0;c[8443784+(p<<2)>>2]=f;c[8444808+(p<<2)>>2]=f;f=p+1|0;if((f|0)<80){p=f}else{q=96;break}}do{f=k+(q<<8)|0;c[8443784+(q<<2)>>2]=f;c[8444808+(q<<2)>>2]=f;q=q+1|0;}while((q|0)<112);c[2112494]=2900;c[2110943]=1716;c[2110942]=3006;c[2110945]=1040;c[2110944]=1930;gGC(9669136,9718136,38)|0;c[2444]=-1;k=gGq(128)|0;c[2426620]=k;c[2429563]=0;a[9718232]=0;a[9718233]=127;b[4859117]=2048;gGz(k|0,0,128);a[9718241]=0;c[3541286]=60;c[3541284]=886;c[3541282]=1788;c[3541290]=1788;c[3541288]=1788;c[2405758]=1;gGz(9542544,0,32);c[2385641]=1;h[1192819]=1.0;c[2385642]=3;c[2385643]=1884;k=0;do{f=k*257|0;b[9732544+(k<<1)>>1]=((f|0)/2|0)&65535;b[9753784+(k<<1)>>1]=f+32768&65535;k=k+1|0;}while((k|0)<256);c[3528842]=0;h[1192819]=.75;c[2385642]=3;Vf(1);k=c[2439194]|0;if((k|0)>0){f=c[2406652]|0;l=0;while(1){h[f+(l*40|0)+16>>3]=.75;c[f+(l*40|0)+32>>2]=3;j=l+1|0;if((j|0)<(k|0)){l=j}else{break}}c[3528400]=f+(l*40|0);j=0;while(1){h[f+(j*40|0)+24>>3]=.75;c[f+(j*40|0)+36>>2]=3;r=j+1|0;if((r|0)<(k|0)){j=r}else{break}}c[3528400]=f+(j*40|0)}c[2444166]=2070;c[2438248]=254;c[2433588]=3056;c[2439260]=1420;c[2438240]=1670;c[2439261]=3608;c[2438241]=888;c[2439262]=1420;c[2438242]=888;c[2439263]=1420;c[2438243]=888;k=c[642608+(c[2436]<<2)>>2]|0;l=c[k+128>>2]|0;if((c[k+52>>2]&4|0)==0){c[2113068]=l;r=c[k+132>>2]|0;c[2113070]=r;c[2443814]=l;c[2440436]=r;s=l;t=r}else{c[2113070]=l;r=c[k+132>>2]|0;c[2113068]=r;c[2440436]=l;c[2443814]=r;s=r;t=l}l=ag(s<<1,t)|0;r=gGq(l)|0;c[2112926]=r;if((r|0)!=0){gGz(r|0,0,l|0)}l=c[2414720]|0;gGz(l|0,0,(c[2411748]|0)-l|0);c[2110940]=8443768;gGz(9718136,0,38);a[9718144]=10;a[9718145]=0;gGC(9669136,9718136,38)|0;c[2444]=-1;b[4859110]=0;a[9718225]=0;a[9718224]=0;a[9718226]=8;a[9718229]=-1;a[9718230]=-1;a[9718227]=0;a[9718237]=0;a[9718236]=0;a[9718249]=0;a[9718238]=0;gGz(9718242,0,6);l=c[2439194]|0;if((l|0)>0){r=c[2406652]|0;k=0;do{u=r+(k*40|0)|0;v=r+(k*40|0)+12|0;a[v]=0;w=r+(k*40|0)+8|0;c[w>>2]=0;x=a[r+(k*40|0)+14|0]|0;do{if((x&2)!=0&(l|0)>(k|0)){if((x&4)==0){a[r+(k*40|0)+13|0]=1}if((x&1)!=0){break}a[v]=1;c[w>>2]=0}}while(0);k=k+1|0;}while((k|0)<(l|0));c[3528400]=u}l=c[2405758]|0;if((l|0)>0){k=0;do{c[9542560+(k<<5)>>2]=0;b[9542544+(k<<5)>>1]=0;k=k+1|0;}while((k|0)<(l|0))}a[9579192]=a[9579192]&-16;a[9642624]=0;a[9757080]=0;o=0;return o|0}}while(0);c[2415014]=0;o=1;return o|0}function dB4(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0;if((dB5()|0)==0){a=0}else{b=1;return b|0}while(1){if((a|0)>=1024){d=0;break}e=9638528+(a<<2)|0;if((c[e>>2]|0)==0){f=4582;break}else{a=a+1|0}}do{if((f|0)==4582){a=gGq(16384)|0;c[e>>2]=a;if((a|0)==0){d=0;break}gGz(a|0,0,16384);d=a}}while(0);e=c[3531220]|0;gGC(d|0,e|0,16384)|0;a=e+3072|0;gGC(a|0,e|0,1024)|0;a=e+2048|0;g=d+1024|0;gGC(a|0,g|0,1024)|0;g=e+1024|0;a=d+2048|0;gGC(g|0,a|0,1024)|0;a=d+3072|0;gGC(e|0,a|0,1024)|0;a=e+8192|0;g=d+4096|0;gGC(a|0,g|0,4096)|0;g=e+16384|0;a=d+8192|0;gGC(g|0,a|0,4096)|0;a=e+24576|0;e=d+12288|0;gGC(a|0,e|0,4096)|0;e=0;while(1){if((e|0)>=1024){b=0;f=4590;break}h=9638528+(e<<2)|0;if((c[h>>2]|0)==(d|0)){break}else{e=e+1|0}}if((f|0)==4590){return b|0}gGr(d);c[h>>2]=0;b=0;return b|0}function dB5(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;a=i;i=i+1560|0;b=a|0;d=a+112|0;e=a+120|0;f=a+232|0;g=a+240|0;h=a+352|0;j=a+360|0;k=a+472|0;l=a+480|0;m=a+592|0;n=a+600|0;o=a+712|0;p=a+720|0;q=a+832|0;r=a+840|0;s=a+952|0;t=a+960|0;u=a+1072|0;v=a+1080|0;w=a+1192|0;x=a+1200|0;y=a+1312|0;z=a+1320|0;A=a+1432|0;B=a+1440|0;C=a+1552|0;D=c[3531220]|0;if((c[3542200]|0)==0){E=1;i=a;return E|0}F=B+108|0;c[F>>2]=0;G=B+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](B,0)|0;do{if((c[F>>2]|0)!=0){B=c[G>>2]|0;c[C>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](C,0,0)|0;if((B|0)<1){E=1;i=a;return E|0}if((gzL(D,0,0)|0)==0){break}else{E=1}i=a;return E|0}}while(0);D=(c[3531220]|0)+8192|0;if((c[3542200]|0)==0){E=1;i=a;return E|0}C=z+108|0;c[C>>2]=0;G=z+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,1)|0;do{if((c[C>>2]|0)!=0){z=c[G>>2]|0;c[A>>2]=9534384;F=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[F&16383](A,1,0)|0;if((z|0)<1){E=1;i=a;return E|0}if((gzL(D,0,1)|0)==0){break}else{E=1}i=a;return E|0}}while(0);D=c[3529764]|0;if((c[3542200]|0)==0){E=1;i=a;return E|0}A=x+108|0;c[A>>2]=0;G=x+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,2)|0;do{if((c[A>>2]|0)!=0){x=c[G>>2]|0;c[y>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](y,2,0)|0;if((x|0)<1){E=1;i=a;return E|0}if((gzL(D,0,2)|0)==0){break}else{E=1}i=a;return E|0}}while(0);D=c[3529764]|0;y=D+2048|0;gGC(y|0,D|0,2048)|0;gGz(D+4096|0,-1|0,2048);D=c[3530878]|0;if((c[3542200]|0)==0){E=1;i=a;return E|0}y=v+108|0;c[y>>2]=0;G=v+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,3)|0;do{if((c[y>>2]|0)!=0){v=c[G>>2]|0;c[w>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](w,3,0)|0;if((v|0)<1){E=1;i=a;return E|0}if((gzL(D,0,3)|0)==0){break}else{E=1}i=a;return E|0}}while(0);D=(c[3530878]|0)+4096|0;if((c[3542200]|0)==0){E=1;i=a;return E|0}w=t+108|0;c[w>>2]=0;G=t+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,4)|0;do{if((c[w>>2]|0)!=0){t=c[G>>2]|0;c[u>>2]=9534384;y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[y&16383](u,4,0)|0;if((t|0)<1){E=1;i=a;return E|0}if((gzL(D,0,4)|0)==0){break}else{E=1}i=a;return E|0}}while(0);D=c[3530642]|0;if((c[3542200]|0)==0){E=1;i=a;return E|0}u=r+108|0;c[u>>2]=0;G=r+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,5)|0;do{if((c[u>>2]|0)!=0){r=c[G>>2]|0;c[s>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](s,5,0)|0;if((r|0)<1){E=1;i=a;return E|0}if((gzL(D,0,5)|0)==0){break}else{E=1}i=a;return E|0}}while(0);D=(c[3530642]|0)+4096|0;if((c[3542200]|0)==0){E=1;i=a;return E|0}s=p+108|0;c[s>>2]=0;G=p+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,6)|0;do{if((c[s>>2]|0)!=0){p=c[G>>2]|0;c[q>>2]=9534384;u=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[u&16383](q,6,0)|0;if((p|0)<1){E=1;i=a;return E|0}if((gzL(D,0,6)|0)==0){break}else{E=1}i=a;return E|0}}while(0);D=(c[3530642]|0)+8192|0;if((c[3542200]|0)==0){E=1;i=a;return E|0}q=n+108|0;c[q>>2]=0;G=n+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,7)|0;do{if((c[q>>2]|0)!=0){n=c[G>>2]|0;c[o>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](o,7,0)|0;if((n|0)<1){E=1;i=a;return E|0}if((gzL(D,0,7)|0)==0){break}else{E=1}i=a;return E|0}}while(0);D=(c[3530642]|0)+12288|0;if((c[3542200]|0)==0){E=1;i=a;return E|0}o=l+108|0;c[o>>2]=0;G=l+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,8)|0;do{if((c[o>>2]|0)!=0){l=c[G>>2]|0;c[m>>2]=9534384;q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[q&16383](m,8,0)|0;if((l|0)<1){E=1;i=a;return E|0}if((gzL(D,0,8)|0)==0){break}else{E=1}i=a;return E|0}}while(0);D=c[3531022]|0;if((c[3542200]|0)==0){E=1;i=a;return E|0}m=j+108|0;c[m>>2]=0;G=j+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,9)|0;do{if((c[m>>2]|0)!=0){j=c[G>>2]|0;c[k>>2]=9534384;o=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[o&16383](k,9,0)|0;if((j|0)<1){E=1;i=a;return E|0}if((gzL(D,0,9)|0)==0){break}else{E=1}i=a;return E|0}}while(0);D=(c[3531022]|0)+256|0;if((c[3542200]|0)==0){E=1;i=a;return E|0}k=g+108|0;c[k>>2]=0;G=g+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,10)|0;do{if((c[k>>2]|0)!=0){g=c[G>>2]|0;c[h>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](h,10,0)|0;if((g|0)<1){E=1;i=a;return E|0}if((gzL(D,0,10)|0)==0){break}else{E=1}i=a;return E|0}}while(0);D=(c[3531022]|0)+512|0;if((c[3542200]|0)==0){E=1;i=a;return E|0}h=e+108|0;c[h>>2]=0;G=e+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,11)|0;do{if((c[h>>2]|0)!=0){e=c[G>>2]|0;c[f>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](f,11,0)|0;if((e|0)<1){E=1;i=a;return E|0}if((gzL(D,0,11)|0)==0){break}else{E=1}i=a;return E|0}}while(0);D=c[2387342]|0;if((c[3542200]|0)==0){E=1;i=a;return E|0}f=b+108|0;c[f>>2]=0;G=b+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](b,12)|0;if((c[f>>2]|0)==0){E=0;i=a;return E|0}f=c[G>>2]|0;c[d>>2]=9534384;gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](d,12,0)|0;if((f|0)<1){E=1;i=a;return E|0}E=(gzL(D,0,12)|0)!=0|0;i=a;return E|0}function dB6(a){a=a|0;return 3}function dB7(e,f){e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;g=e&65535;if((e&65535)>8191){h=e&8191;i=h&65535;j=c[2110940]|0;k=c[j+528+(i>>>8<<2)>>2]|0;if((k|0)!=0){a[k+(i&255)|0]=f;return}i=c[j+4>>2]|0;if((i|0)==0){return}gg[i&4095](h,f);return}if((g&65408|0)==7936){a[(c[2386490]|0)+(g&1023|1024)|0]=f;return}if((g&65520|0)==8064){h=e&255;switch(h&15|0){case 0:case 1:case 2:case 3:case 4:case 5:case 6:case 7:{e=a[9660736]|0;i=e<<24>>24==0;j=f&255;if(i){b[9776640+(h<<1)>>1]=j}else{k=9776640+(h<<1)|0;b[k>>1]=b[k>>1]|j<<8}do{if((a[9642624]|0)<0){if((h-4|0)>>>0>=2){break}if(i){b[9776640+(h+2<<1)>>1]=j;break}else{k=9776640+(h+2<<1)|0;b[k>>1]=b[k>>1]|j<<8;break}}}while(0);a[9660736]=e^1;return};case 8:{a[9642624]=f;return};default:{return}}}switch(g|0){case 5507:{a[c[2443706]|0]=f&1;return};case 5504:{fJ$(f<<24>>24!=0|0);return};case 5511:case 5510:{e=1<<(g&1);if((f&1)==0){g=c[2440368]|0;a[g]=d[g]&(e^255)&255;return}else{g=c[2440368]|0;a[g]=(d[g]|e)&255;return}break};case 5120:{a[c[3528308]|0]=f^15;return};case 5509:{e=a[9660744]|0;if((f&1)==0){g=e&-4;a[9660744]=g;l=g}else{b[4771176]=b[4888320]|0;g=b[4888321]|0;b[4813476]=g&16383;a[9579200]=(g&65535)>>>14&255;g=a[9579192]|0;j=e|3;a[9660744]=j;b[4771177]=b[4888322]|0;e=b[4888323]|0;b[4813477]=e&16383;a[9579201]=(e&65535)>>>14&255;a[9579192]=g&-4;l=j}if((l&15&d[9642624])<<16>>16==0){return}do{gj[c[2444166]&4095](4)|0;Tb();}while((a[9660744]&15&d[9642624])<<16>>16!=0);return};case 5506:{a[c[3528734]|0]=f&1^1;return};default:{return}}}function dB8(b){b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0;d=b&65535;if((b&65535)>8191){f=b&8191;g=f&65535;h=c[2110940]|0;i=c[h+16+(g>>>8<<2)>>2]|0;if((i|0)!=0){j=a[i+(g&255)|0]|0;return j|0}g=c[h>>2]|0;if((g|0)==0){j=0;return j|0}j=gj[g&4095](f)|0;return j|0}if((d&65408|0)==7936){j=a[(c[2386490]|0)+(d&1023|1024)|0]|0;return j|0}if((d&65520|0)==8064){f=b&255;switch(f&15|0){case 0:case 1:case 2:case 3:case 4:case 5:case 6:case 7:{g=a[9660736]|0;h=(e[9776640+(f<<1)>>1]|0)>>>((g<<24>>24!=0?8:0)>>>0)&255;a[9660736]=g^1;j=h;return j|0};case 8:{h=a[9579192]|0;a[9579192]=h&-16;j=h;return j|0};default:{j=-1;return j|0}}}h=((d&65152|0)==5120?b&-128:b)&65535;if((h|0)==5120){j=a[9550680]|0;return j|0}else if((h|0)==5376){b=a[9550682]|0;if((b&16)==0){k=b&-65}else{k=b&47|-128}j=(c[2385560]<<6|k&255)&255;return j|0}else if((h|0)==5248){j=a[9550681]|0;return j|0}else if((h|0)==5504){j=a[9635336]|0;return j|0}else{j=0;return j|0}return 0}function dB9(b,c){b=b|0;c=c|0;var d=0;d=b&65535;if((d|0)==257){a[9757080]=c;return}else if((d|0)==259){a[9626944]=c;if(c<<24>>24==0){return}a[9757080]=-5;return}else{return}}function dCa(b){b=b|0;var d=0,e=0,f=0,g=0;d=b&65535;do{if((d|0)==0){b=(a[9626944]|0)!=0;e=a[9757080]|0;if((c[2432782]|0)==2){if(b){f=e;break}a[9757080]=e-1&255;f=e;break}else{if(!b){f=e;break}a[9757080]=e-1&255;f=e;break}}else if((d|0)==258){g=4786}else if((d|0)==1){e=c[2432782]|0;if((e|0)==2){b=a[9757080]|0;a[9757080]=b-1&255;f=b;break}else if((e|0)!=1){g=4786;break}e=c[2438260]|0;if((a[9757080]|0)<0){f=e&255;break}else{b=e+1|0;c[2438260]=b;f=b&255;break}}else{f=0}}while(0);if((g|0)==4786){f=a[672600]|0?0:-128}return f|0}function dCb(b){b=b|0;var d=0,e=0,f=0,g=0;d=b&65535;b=c[(c[2386746]|0)+(d>>>10<<2)>>2]<<7&31744|d&1023;e=c[2110940]|0;f=c[e+16+(b>>>8<<2)>>2]|0;if((f|0)!=0){g=a[f+(d&255)|0]|0;return g|0}d=c[e>>2]|0;if((d|0)==0){g=0;return g|0}g=gj[d&4095](b&65535)|0;return g|0}function dCc(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;e=b&65535;b=c[(c[2386746]|0)+(e>>>10<<2)>>2]<<7&31744|e&1023;f=c[2110940]|0;g=c[f+528+(b>>>8<<2)>>2]|0;if((g|0)!=0){a[g+(e&255)|0]=d;return}e=c[f+4>>2]|0;if((e|0)==0){return}gg[e&4095](b&65535,d);return}function dCd(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;if((dB5()|0)==0){b=0}else{d=1;return d|0}while(1){if((b|0)>=1024){e=0;break}f=9638528+(b<<2)|0;if((c[f>>2]|0)==0){g=4807;break}else{b=b+1|0}}do{if((g|0)==4807){b=gGq(16384)|0;c[f>>2]=b;if((b|0)==0){e=0;break}gGz(b|0,0,16384);e=b}}while(0);f=c[3531220]|0;gGC(e|0,f|0,16384)|0;b=f+3072|0;gGC(b|0,f|0,1024)|0;b=f+2048|0;h=e+1024|0;gGC(b|0,h|0,1024)|0;h=f+1024|0;b=e+2048|0;gGC(h|0,b|0,1024)|0;b=e+3072|0;gGC(f|0,b|0,1024)|0;b=f+8192|0;h=e+4096|0;gGC(b|0,h|0,3584)|0;h=f+28160|0;b=e+7680|0;gGC(h|0,b|0,512)|0;b=f+16384|0;h=e+8192|0;gGC(b|0,h|0,4096)|0;h=f+24576|0;b=e+12288|0;gGC(h|0,b|0,3584)|0;b=f+11776|0;h=e+15872|0;gGC(b|0,h|0,512)|0;h=0;while(1){if((h|0)>=1024){i=f;break}j=9638528+(h<<2)|0;if((c[j>>2]|0)==(e|0)){g=4812;break}else{h=h+1|0}}if((g|0)==4812){gGr(e);c[j>>2]=0;i=c[3531220]|0}j=0;while(1){if((j&4096|0)==0){e=i+j|0;g=a[e]|0;a[e]=(g&255)>>>1&8|g&-25|g<<1&16}g=j+1|0;if((g|0)<32768){j=g}else{d=0;break}}return d|0}function dCe(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;a=i;i=i+1800|0;b=a|0;d=a+112|0;e=a+120|0;f=a+232|0;g=a+240|0;h=a+352|0;j=a+360|0;k=a+472|0;l=a+480|0;m=a+592|0;n=a+600|0;o=a+712|0;p=a+720|0;q=a+832|0;r=a+840|0;s=a+952|0;t=a+960|0;u=a+1072|0;v=a+1080|0;w=a+1192|0;x=a+1200|0;y=a+1312|0;z=a+1320|0;A=a+1432|0;B=a+1440|0;C=a+1552|0;D=a+1560|0;E=a+1672|0;F=a+1680|0;G=a+1792|0;H=c[3531220]|0;if((c[3542200]|0)==0){I=1;i=a;return I|0}J=F+108|0;c[J>>2]=0;K=F+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](F,0)|0;do{if((c[J>>2]|0)!=0){F=c[K>>2]|0;c[G>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](G,0,0)|0;if((F|0)<1){I=1;i=a;return I|0}if((gzL(H,0,0)|0)==0){break}else{I=1}i=a;return I|0}}while(0);H=(c[3531220]|0)+8192|0;if((c[3542200]|0)==0){I=1;i=a;return I|0}G=D+108|0;c[G>>2]=0;K=D+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](D,1)|0;do{if((c[G>>2]|0)!=0){D=c[K>>2]|0;c[E>>2]=9534384;J=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[J&16383](E,1,0)|0;if((D|0)<1){I=1;i=a;return I|0}if((gzL(H,0,1)|0)==0){break}else{I=1}i=a;return I|0}}while(0);H=(c[3531220]|0)+16384|0;if((c[3542200]|0)==0){I=1;i=a;return I|0}E=B+108|0;c[E>>2]=0;K=B+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](B,2)|0;do{if((c[E>>2]|0)!=0){B=c[K>>2]|0;c[C>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](C,2,0)|0;if((B|0)<1){I=1;i=a;return I|0}if((gzL(H,0,2)|0)==0){break}else{I=1}i=a;return I|0}}while(0);H=(c[3531220]|0)+24576|0;if((c[3542200]|0)==0){I=1;i=a;return I|0}C=z+108|0;c[C>>2]=0;K=z+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,3)|0;do{if((c[C>>2]|0)!=0){z=c[K>>2]|0;c[A>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](A,3,0)|0;if((z|0)<1){I=1;i=a;return I|0}if((gzL(H,0,3)|0)==0){break}else{I=1}i=a;return I|0}}while(0);H=c[3529764]|0;if((c[3542200]|0)==0){I=1;i=a;return I|0}A=x+108|0;c[A>>2]=0;K=x+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,4)|0;do{if((c[A>>2]|0)!=0){x=c[K>>2]|0;c[y>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](y,4,0)|0;if((x|0)<1){I=1;i=a;return I|0}if((gzL(H,0,4)|0)==0){break}else{I=1}i=a;return I|0}}while(0);H=c[3529764]|0;y=H+2048|0;gGC(y|0,H|0,2048)|0;gGz(H+4096|0,-1|0,2048);H=c[3530878]|0;if((c[3542200]|0)==0){I=1;i=a;return I|0}y=v+108|0;c[y>>2]=0;K=v+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,5)|0;do{if((c[y>>2]|0)!=0){v=c[K>>2]|0;c[w>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](w,5,0)|0;if((v|0)<1){I=1;i=a;return I|0}if((gzL(H,0,5)|0)==0){break}else{I=1}i=a;return I|0}}while(0);H=(c[3530878]|0)+4096|0;if((c[3542200]|0)==0){I=1;i=a;return I|0}w=t+108|0;c[w>>2]=0;K=t+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,6)|0;do{if((c[w>>2]|0)!=0){t=c[K>>2]|0;c[u>>2]=9534384;y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[y&16383](u,6,0)|0;if((t|0)<1){I=1;i=a;return I|0}if((gzL(H,0,6)|0)==0){break}else{I=1}i=a;return I|0}}while(0);H=c[3530642]|0;if((c[3542200]|0)==0){I=1;i=a;return I|0}u=r+108|0;c[u>>2]=0;K=r+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,7)|0;do{if((c[u>>2]|0)!=0){r=c[K>>2]|0;c[s>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](s,7,0)|0;if((r|0)<1){I=1;i=a;return I|0}if((gzL(H,0,7)|0)==0){break}else{I=1}i=a;return I|0}}while(0);H=(c[3530642]|0)+4096|0;if((c[3542200]|0)==0){I=1;i=a;return I|0}s=p+108|0;c[s>>2]=0;K=p+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,8)|0;do{if((c[s>>2]|0)!=0){p=c[K>>2]|0;c[q>>2]=9534384;u=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[u&16383](q,8,0)|0;if((p|0)<1){I=1;i=a;return I|0}if((gzL(H,0,8)|0)==0){break}else{I=1}i=a;return I|0}}while(0);H=(c[3530642]|0)+8192|0;if((c[3542200]|0)==0){I=1;i=a;return I|0}q=n+108|0;c[q>>2]=0;K=n+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,9)|0;do{if((c[q>>2]|0)!=0){n=c[K>>2]|0;c[o>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](o,9,0)|0;if((n|0)<1){I=1;i=a;return I|0}if((gzL(H,0,9)|0)==0){break}else{I=1}i=a;return I|0}}while(0);H=(c[3530642]|0)+12288|0;if((c[3542200]|0)==0){I=1;i=a;return I|0}o=l+108|0;c[o>>2]=0;K=l+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,10)|0;do{if((c[o>>2]|0)!=0){l=c[K>>2]|0;c[m>>2]=9534384;q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[q&16383](m,10,0)|0;if((l|0)<1){I=1;i=a;return I|0}if((gzL(H,0,10)|0)==0){break}else{I=1}i=a;return I|0}}while(0);H=c[3531022]|0;if((c[3542200]|0)==0){I=1;i=a;return I|0}m=j+108|0;c[m>>2]=0;K=j+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,11)|0;do{if((c[m>>2]|0)!=0){j=c[K>>2]|0;c[k>>2]=9534384;o=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[o&16383](k,11,0)|0;if((j|0)<1){I=1;i=a;return I|0}if((gzL(H,0,11)|0)==0){break}else{I=1}i=a;return I|0}}while(0);H=(c[3531022]|0)+256|0;if((c[3542200]|0)==0){I=1;i=a;return I|0}k=g+108|0;c[k>>2]=0;K=g+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,12)|0;do{if((c[k>>2]|0)!=0){g=c[K>>2]|0;c[h>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](h,12,0)|0;if((g|0)<1){I=1;i=a;return I|0}if((gzL(H,0,12)|0)==0){break}else{I=1}i=a;return I|0}}while(0);H=(c[3531022]|0)+512|0;if((c[3542200]|0)==0){I=1;i=a;return I|0}h=e+108|0;c[h>>2]=0;K=e+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,13)|0;do{if((c[h>>2]|0)!=0){e=c[K>>2]|0;c[f>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](f,13,0)|0;if((e|0)<1){I=1;i=a;return I|0}if((gzL(H,0,13)|0)==0){break}else{I=1}i=a;return I|0}}while(0);H=c[2387342]|0;if((c[3542200]|0)==0){I=1;i=a;return I|0}f=b+108|0;c[f>>2]=0;K=b+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](b,14)|0;if((c[f>>2]|0)==0){I=0;i=a;return I|0}f=c[K>>2]|0;c[d>>2]=9534384;gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](d,14,0)|0;if((f|0)<1){I=1;i=a;return I|0}I=(gzL(H,0,14)|0)!=0|0;i=a;return I|0}
function d1I(e){e=e|0;var f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0.0,aF=0.0,aG=0,aH=0,aI=0;f=i;i=i+2568|0;g=f|0;j=f+112|0;k=f+120|0;l=f+232|0;m=f+240|0;n=f+352|0;o=f+360|0;p=f+472|0;q=f+480|0;r=f+592|0;s=f+600|0;t=f+712|0;u=f+720|0;v=f+832|0;w=f+840|0;x=f+952|0;y=f+960|0;z=f+1072|0;A=f+1080|0;B=f+1192|0;C=f+1200|0;D=f+1312|0;E=f+1320|0;F=f+1432|0;G=f+1440|0;H=f+1552|0;I=f+1560|0;J=f+1672|0;K=f+1680|0;L=f+1792|0;M=f+1800|0;N=f+1912|0;O=f+1920|0;P=f+2032|0;Q=f+2040|0;R=f+2152|0;S=f+2160|0;T=f+2272|0;U=f+2280|0;V=f+2392|0;W=f+2400|0;X=f+2432|0;Y=f+2496|0;Z=f+2560|0;c[2414974]=0;c[3531122]=0;c[3531110]=5242880;c[2385928]=5373952;c[3530850]=5505024;c[3530614]=7602176;c[3530436]=11796480;c[3530336]=13893632;c[2386652]=22282240;c[3530022]=24379392;c[3531072]=24383492;c[2438814]=24387588;c[2406554]=24389636;c[2414678]=26486788;c[3531166]=26486788;c[3531144]=26503172;c[3527306]=26519556;c[3529096]=26523652;c[2387208]=26785796;c[2443484]=26789892;c[2386218]=26798084;c[3527260]=26802180;c[3527258]=26806276;c[2443448]=26807300;c[2443446]=26840068;c[2386082]=26856452;c[2433512]=26858500;c[3528282]=26858501;c[3528698]=26858502;c[2406750]=26858503;c[2394688]=26858504;c[3529366]=26858505;c[2443572]=26858506;c[2443564]=26858508;c[2387986]=26858510;c[2411680]=26858542;_=0;while(1){if((_|0)>=1024){break}$=9638528+(_<<2)|0;if((c[$>>2]|0)==0){aa=40535;break}else{_=_+1|0}}do{if((aa|0)==40535){_=gGq(26858542)|0;c[$>>2]=_;if((_|0)==0){break}c[2414974]=_;gGz(_|0,0,26858542);c[3531122]=_;c[3531110]=_+5242880;c[2385928]=_+5373952;c[3530850]=_+5505024;c[3530614]=_+7602176;c[3530436]=_+11796480;c[3530336]=_+13893632;c[2386652]=_+22282240;c[3530022]=_+24379392;c[3531072]=_+24383492;c[2438814]=_+24387588;c[2406554]=_+24389636;ab=_+26486788|0;c[2414678]=ab;c[3531166]=ab;c[3531144]=_+26503172;c[3527306]=_+26519556;c[3529096]=_+26523652;c[2387208]=_+26785796;c[2443484]=_+26789892;c[2386218]=_+26798084;c[3527260]=_+26802180;c[3527258]=_+26806276;c[2443448]=_+26807300;c[2443446]=_+26840068;c[2386082]=_+26856452;c[2433512]=_+26858500;c[3528282]=_+26858501;c[3528698]=_+26858502;c[2406750]=_+26858503;c[2394688]=_+26858504;c[3529366]=_+26858505;c[2443572]=_+26858506;c[2443564]=_+26858508;c[2387986]=_+26858510;ab=_+26858542|0;c[2411680]=ab;c[2414220]=ab;ab=(e|0)!=0;L53612:do{if(ab){a[5766496]=1;if((R6(_+1|0,0,2)|0)!=0){ac=1;i=f;return ac|0}if((R6(c[3531122]|0,1,2)|0)!=0){ac=1;i=f;return ac|0}ad=(c[3531122]|0)+3145728|0;if((c[3542200]|0)==0){ac=1;i=f;return ac|0}ae=U+108|0;c[ae>>2]=0;af=U+100|0;c[af>>2]=0;ah=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ah&16383](U,2)|0;do{if((c[ae>>2]|0)!=0){ah=c[af>>2]|0;c[V>>2]=9534384;ai=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ai&16383](V,2,0)|0;if((ah|0)<1){ac=1;i=f;return ac|0}if((gzL(ad,0,2)|0)==0){break}else{ac=1}i=f;return ac|0}}while(0);ad=c[3531122]|0;af=ad+1048576|0;ae=ad+4194304|0;gGC(af|0,ae|0,1048576)|0;ae=ad+2097152|0;af=ad+3145728|0;gGC(ae|0,af|0,1048576)|0;af=c[3531110]|0;if((c[3542200]|0)==0){ac=1;i=f;return ac|0}ae=S+108|0;c[ae>>2]=0;ad=S+100|0;c[ad>>2]=0;ah=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ah&16383](S,3)|0;do{if((c[ae>>2]|0)!=0){ah=c[ad>>2]|0;c[T>>2]=9534384;ai=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ai&16383](T,3,0)|0;if((ah|0)<1){ac=1;i=f;return ac|0}if((gzL(af,0,3)|0)==0){break}else{ac=1}i=f;return ac|0}}while(0);af=c[2385928]|0;if((c[3542200]|0)==0){ac=1;i=f;return ac|0}ad=Q+108|0;c[ad>>2]=0;ae=Q+100|0;c[ae>>2]=0;ah=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ah&16383](Q,4)|0;do{if((c[ad>>2]|0)!=0){ah=c[ae>>2]|0;c[R>>2]=9534384;ai=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ai&16383](R,4,0)|0;if((ah|0)<1){ac=1;i=f;return ac|0}if((gzL(af,0,4)|0)==0){break}else{ac=1}i=f;return ac|0}}while(0);af=c[3530850]|0;if((c[3542200]|0)==0){ac=1;i=f;return ac|0}ae=O+108|0;c[ae>>2]=0;ad=O+100|0;c[ad>>2]=0;ah=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ah&16383](O,5)|0;do{if((c[ae>>2]|0)!=0){ah=c[ad>>2]|0;c[P>>2]=9534384;ai=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ai&16383](P,5,0)|0;if((ah|0)<1){ac=1;i=f;return ac|0}if((gzL(af,0,5)|0)==0){break}else{ac=1}i=f;return ac|0}}while(0);af=c[3530614]|0;if((c[3542200]|0)==0){ac=1;i=f;return ac|0}ad=M+108|0;c[ad>>2]=0;ae=M+100|0;c[ae>>2]=0;ah=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ah&16383](M,6)|0;do{if((c[ad>>2]|0)!=0){ah=c[ae>>2]|0;c[N>>2]=9534384;ai=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ai&16383](N,6,0)|0;if((ah|0)<1){ac=1;i=f;return ac|0}if((gzL(af,0,6)|0)==0){break}else{ac=1}i=f;return ac|0}}while(0);af=c[3530336]|0;if((c[3542200]|0)==0){ac=1;i=f;return ac|0}ae=K+108|0;c[ae>>2]=0;ad=K+100|0;c[ad>>2]=0;ah=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ah&16383](K,7)|0;do{if((c[ae>>2]|0)!=0){ah=c[ad>>2]|0;c[L>>2]=9534384;ai=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ai&16383](L,7,0)|0;if((ah|0)<1){ac=1;i=f;return ac|0}if((gzL(af,0,7)|0)==0){break}else{ac=1}i=f;return ac|0}}while(0);af=(c[3530336]|0)+1048576|0;if((c[3542200]|0)==0){ac=1;i=f;return ac|0}ad=I+108|0;c[ad>>2]=0;ae=I+100|0;c[ae>>2]=0;ah=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ah&16383](I,8)|0;do{if((c[ad>>2]|0)!=0){ah=c[ae>>2]|0;c[J>>2]=9534384;ai=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ai&16383](J,8,0)|0;if((ah|0)<1){ac=1;i=f;return ac|0}if((gzL(af,0,8)|0)==0){break}else{ac=1}i=f;return ac|0}}while(0);af=(c[3530336]|0)+2097152|0;if((c[3542200]|0)==0){ac=1;i=f;return ac|0}ae=G+108|0;c[ae>>2]=0;ad=G+100|0;c[ad>>2]=0;ah=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ah&16383](G,9)|0;do{if((c[ae>>2]|0)!=0){ah=c[ad>>2]|0;c[H>>2]=9534384;ai=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ai&16383](H,9,0)|0;if((ah|0)<1){ac=1;i=f;return ac|0}if((gzL(af,0,9)|0)==0){break}else{ac=1}i=f;return ac|0}}while(0);af=(c[3530336]|0)+3145728|0;if((c[3542200]|0)==0){ac=1;i=f;return ac|0}ad=E+108|0;c[ad>>2]=0;ae=E+100|0;c[ae>>2]=0;ah=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ah&16383](E,10)|0;do{if((c[ad>>2]|0)!=0){ah=c[ae>>2]|0;c[F>>2]=9534384;ai=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ai&16383](F,10,0)|0;if((ah|0)<1){ac=1;i=f;return ac|0}if((gzL(af,0,10)|0)==0){break}else{ac=1}i=f;return ac|0}}while(0);af=c[2386652]|0;if((c[3542200]|0)==0){ac=1;i=f;return ac|0}ae=C+108|0;c[ae>>2]=0;ad=C+100|0;c[ad>>2]=0;ah=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ah&16383](C,11)|0;do{if((c[ae>>2]|0)!=0){ah=c[ad>>2]|0;c[D>>2]=9534384;ai=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ai&16383](D,11,0)|0;if((ah|0)<1){ac=1;i=f;return ac|0}if((gzL(af,0,11)|0)==0){break}else{ac=1}i=f;return ac|0}}while(0);af=(c[2386652]|0)+1048576|0;if((c[3542200]|0)==0){ac=1;i=f;return ac|0}ad=A+108|0;c[ad>>2]=0;ae=A+100|0;c[ae>>2]=0;ah=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ah&16383](A,12)|0;do{if((c[ad>>2]|0)!=0){ah=c[ae>>2]|0;c[B>>2]=9534384;ai=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ai&16383](B,12,0)|0;if((ah|0)<1){ac=1;i=f;return ac|0}if((gzL(af,0,12)|0)==0){break}else{ac=1}i=f;return ac|0}}while(0);af=W;ae=X;ad=Y;gGC(af|0,613168,32)|0;gGC(ae|0,610544,64)|0;gGC(ad|0,611904,64)|0;ad=0;while(1){if((ad|0)>=1024){break L53612}aj=9638528+(ad<<2)|0;if((c[aj>>2]|0)==0){break}else{ad=ad+1|0}}ad=gGq(4194304)|0;c[aj>>2]=ad;if((ad|0)==0){break}gGz(ad|0,0,4194304);ae=c[3530614]|0;af=0;while(1){ah=a[ae+af|0]|0;a[ad+(af^1)|0]=ah<<4|(ah&255)>>>4;ah=af+1|0;if((ah|0)<2097152){af=ah}else{ak=0;break}}do{af=ak<<8;gGz(ae+af|0,0,256);ah=ak<<10;ai=0;do{al=1<<3-ai;am=(c[W+(ai<<2)>>2]|0)+ah|0;an=0;do{ao=am+(c[Y+(an<<2)>>2]|0)|0;ap=(an<<4)+af|0;aq=0;do{ar=ao+(c[X+(aq<<2)>>2]|0)|0;if(((d[ad+((ar|0)/8|0)|0]|0)&128>>>((ar&7)>>>0)|0)!=0){ar=ae+(ap+aq)|0;a[ar]=(d[ar]|0|al)&255}aq=aq+1|0;}while((aq|0)<16);an=an+1|0;}while((an|0)<16);ai=ai+1|0;}while((ai|0)<4);ak=ak+1|0;}while((ak|0)<16384);ae=c[3530336]|0;gGC(ad|0,ae|0,4194304)|0;ai=0;while(1){af=ai<<8;gGz(ae+af|0,0,256);ah=ai<<10;an=0;do{al=1<<3-an;am=(c[W+(an<<2)>>2]|0)+ah|0;aq=0;do{ap=am+(c[Y+(aq<<2)>>2]|0)|0;ao=(aq<<4)+af|0;ar=0;do{as=ap+(c[X+(ar<<2)>>2]|0)|0;if(((d[ad+((as|0)/8|0)|0]|0)&128>>>((as&7)>>>0)|0)!=0){as=ae+(ao+ar)|0;a[as]=(d[as]|0|al)&255}ar=ar+1|0;}while((ar|0)<16);aq=aq+1|0;}while((aq|0)<16);an=an+1|0;}while((an|0)<4);an=ai+1|0;if((an|0)<32768){ai=an}else{at=0;break}}while(1){if((at|0)>=1024){break L53612}au=9638528+(at<<2)|0;if((c[au>>2]|0)==(ad|0)){break}else{at=at+1|0}}gGr(ad);c[au>>2]=0}else{if((c[3542200]|0)==0){ac=1;i=f;return ac|0}ai=y+108|0;c[ai>>2]=0;ae=y+100|0;c[ae>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](y,0)|0;do{if((c[ai>>2]|0)!=0){an=c[ae>>2]|0;c[z>>2]=9534384;af=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[af&16383](z,0,0)|0;if((an|0)<1){ac=1;i=f;return ac|0}if((gzL(_,0,0)|0)==0){break}else{ac=1}i=f;return ac|0}}while(0);if((R6((c[3531122]|0)+1048576|0,1,2)|0)!=0){ac=1;i=f;return ac|0}if((R6((c[3531122]|0)+1048577|0,2,2)|0)!=0){ac=1;i=f;return ac|0}if((R6((c[3531122]|0)+1572864|0,3,2)|0)!=0){ac=1;i=f;return ac|0}if((R6((c[3531122]|0)+1572865|0,4,2)|0)!=0){ac=1;i=f;return ac|0}if((R6((c[3531122]|0)+2097152|0,5,2)|0)!=0){ac=1;i=f;return ac|0}if((R6((c[3531122]|0)+2097153|0,6,2)|0)!=0){ac=1;i=f;return ac|0}if((R6((c[3531122]|0)+2621440|0,7,2)|0)!=0){ac=1;i=f;return ac|0}if((R6((c[3531122]|0)+2621441|0,8,2)|0)!=0){ac=1;i=f;return ac|0}ae=(c[3531122]|0)+3145728|0;if((c[3542200]|0)==0){ac=1;i=f;return ac|0}ai=w+108|0;c[ai>>2]=0;ad=w+100|0;c[ad>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](w,9)|0;do{if((c[ai>>2]|0)!=0){an=c[ad>>2]|0;c[x>>2]=9534384;af=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[af&16383](x,9,0)|0;if((an|0)<1){ac=1;i=f;return ac|0}if((gzL(ae,0,9)|0)==0){break}else{ac=1}i=f;return ac|0}}while(0);ae=(c[3531122]|0)+4194304|0;if((c[3542200]|0)==0){ac=1;i=f;return ac|0}ad=u+108|0;c[ad>>2]=0;ai=u+100|0;c[ai>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](u,10)|0;do{if((c[ad>>2]|0)!=0){an=c[ai>>2]|0;c[v>>2]=9534384;af=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[af&16383](v,10,0)|0;if((an|0)<1){ac=1;i=f;return ac|0}if((gzL(ae,0,10)|0)==0){break}else{ac=1}i=f;return ac|0}}while(0);ae=c[3531110]|0;if((c[3542200]|0)==0){ac=1;i=f;return ac|0}ai=s+108|0;c[ai>>2]=0;ad=s+100|0;c[ad>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](s,11)|0;do{if((c[ai>>2]|0)!=0){an=c[ad>>2]|0;c[t>>2]=9534384;af=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[af&16383](t,11,0)|0;if((an|0)<1){ac=1;i=f;return ac|0}if((gzL(ae,0,11)|0)==0){break}else{ac=1}i=f;return ac|0}}while(0);ae=c[2385928]|0;if((c[3542200]|0)==0){ac=1;i=f;return ac|0}ad=q+108|0;c[ad>>2]=0;ai=q+100|0;c[ai>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](q,12)|0;do{if((c[ad>>2]|0)!=0){an=c[ai>>2]|0;c[r>>2]=9534384;af=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[af&16383](r,12,0)|0;if((an|0)<1){ac=1;i=f;return ac|0}if((gzL(ae,0,12)|0)==0){break}else{ac=1}i=f;return ac|0}}while(0);ae=c[3530850]|0;if((c[3542200]|0)==0){ac=1;i=f;return ac|0}ai=o+108|0;c[ai>>2]=0;ad=o+100|0;c[ad>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](o,13)|0;do{if((c[ai>>2]|0)!=0){an=c[ad>>2]|0;c[p>>2]=9534384;af=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[af&16383](p,13,0)|0;if((an|0)<1){ac=1;i=f;return ac|0}if((gzL(ae,0,13)|0)==0){break}else{ac=1}i=f;return ac|0}}while(0);ae=(c[3530850]|0)+1048576|0;if((c[3542200]|0)==0){ac=1;i=f;return ac|0}ad=m+108|0;c[ad>>2]=0;ai=m+100|0;c[ai>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,14)|0;do{if((c[ad>>2]|0)!=0){an=c[ai>>2]|0;c[n>>2]=9534384;af=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[af&16383](n,14,0)|0;if((an|0)<1){ac=1;i=f;return ac|0}if((gzL(ae,0,14)|0)==0){break}else{ac=1}i=f;return ac|0}}while(0);if((R6(c[3530614]|0,15,2)|0)!=0){ac=1;i=f;return ac|0}if((R6((c[3530614]|0)+1|0,16,2)|0)!=0){ac=1;i=f;return ac|0}ae=c[3530614]|0;ai=0;do{ad=ae+(ai|1)|0;an=a[ad]|0;af=ae+(ai|2)|0;a[ad]=a[af]|0;a[af]=an;ai=ai+4|0;}while((ai|0)<1048576);if((R6(c[3530436]|0,17,2)|0)!=0){ac=1;i=f;return ac|0}if((R6((c[3530436]|0)+1|0,18,2)|0)!=0){ac=1;i=f;return ac|0}ai=c[3530436]|0;ae=0;do{an=ai+(ae|1)|0;af=a[an]|0;ad=ai+(ae|2)|0;a[an]=a[ad]|0;a[ad]=af;ae=ae+4|0;}while((ae|0)<524288);ae=c[2386652]|0;if((c[3542200]|0)==0){ac=1;i=f;return ac|0}ai=k+108|0;c[ai>>2]=0;af=k+100|0;c[af>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,19)|0;do{if((c[ai>>2]|0)!=0){ad=c[af>>2]|0;c[l>>2]=9534384;an=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[an&16383](l,19,0)|0;if((ad|0)<1){ac=1;i=f;return ac|0}if((gzL(ae,0,19)|0)==0){break}else{ac=1}i=f;return ac|0}}while(0);ae=(c[2386652]|0)+1048576|0;if((c[3542200]|0)==0){ac=1;i=f;return ac|0}af=g+108|0;c[af>>2]=0;ai=g+100|0;c[ai>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,20)|0;do{if((c[af>>2]|0)!=0){ad=c[ai>>2]|0;c[j>>2]=9534384;an=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[an&16383](j,20,0)|0;if((ad|0)<1){ac=1;i=f;return ac|0}if((gzL(ae,0,20)|0)==0){break}else{ac=1}i=f;return ac|0}}while(0);ae=W;ai=X;af=Y;gGC(ae|0,613168,32)|0;gGC(ai|0,612512,64)|0;gGC(af|0,611904,64)|0;af=0;while(1){if((af|0)>=1024){break L53612}av=9638528+(af<<2)|0;if((c[av>>2]|0)==0){break}else{af=af+1|0}}af=gGq(1048576)|0;c[av>>2]=af;if((af|0)==0){break}gGz(af|0,0,1048576);ai=c[3530614]|0;gGC(af|0,ai|0,1048576)|0;ae=0;do{ad=ae<<8;gGz(ai+ad|0,0,256);an=ae<<10;ah=0;do{aq=1<<3-ah;al=(c[W+(ah<<2)>>2]|0)+an|0;am=0;do{ar=al+(c[Y+(am<<2)>>2]|0)|0;ao=(am<<4)+ad|0;ap=0;do{as=ar+(c[X+(ap<<2)>>2]|0)|0;if(((d[af+((as|0)/8|0)|0]|0)&128>>>((as&7)>>>0)|0)!=0){as=ai+(ao+ap)|0;a[as]=(d[as]|0|aq)&255}ap=ap+1|0;}while((ap|0)<16);am=am+1|0;}while((am|0)<16);ah=ah+1|0;}while((ah|0)<4);ae=ae+1|0;}while((ae|0)<8192);ae=c[3530436]|0;gGC(af|0,ae|0,524288)|0;ai=0;while(1){ah=ai<<8;gGz(ae+ah|0,0,256);ad=ai<<10;an=0;do{am=1<<3-an;aq=(c[W+(an<<2)>>2]|0)+ad|0;al=0;do{ap=aq+(c[Y+(al<<2)>>2]|0)|0;ao=(al<<4)+ah|0;ar=0;do{as=ap+(c[X+(ar<<2)>>2]|0)|0;if(((d[af+((as|0)/8|0)|0]|0)&128>>>((as&7)>>>0)|0)!=0){as=ae+(ao+ar)|0;a[as]=(d[as]|0|am)&255}ar=ar+1|0;}while((ar|0)<16);al=al+1|0;}while((al|0)<16);an=an+1|0;}while((an|0)<4);an=ai+1|0;if((an|0)<4096){ai=an}else{aw=0;break}}while(1){if((aw|0)>=1024){break L53612}ax=9638528+(aw<<2)|0;if((c[ax>>2]|0)==(af|0)){break}else{aw=aw+1|0}}gGr(af);c[ax>>2]=0}}while(0);fxU(0,425984);if((c[2394]|0)==0){ay=c[2112932]|0}else{c[2394]=0;_=c[3532596]|0;c[2112932]=_;ai=c[3532592]|0;if((ai|0)!=0){gGC(9104152,ai|0,280)|0}c[2113054]=c[2113060];ay=_}_=c[3531122]|0;ai=ay|0;ae=0;while(1){an=_+ae|0;c[ai>>2]=an;c[ai+131072>>2]=an;an=ae+1024|0;if(an>>>0>262143){break}else{ai=ai+4|0;ae=an}}ae=ay+4096|0;ai=1048576;while(1){an=_+ai|0;c[ae>>2]=an;c[ae+131072>>2]=an;an=ai+1024|0;if(an>>>0>3145727){break}else{ae=ae+4|0;ai=an}}ai=c[2443484]|0;c[ay+53248>>2]=ai;c[ay+184320>>2]=ai;ae=ai+1024|0;c[ay+53252>>2]=ae;c[ay+184324>>2]=ae;an=ai+2048|0;c[ay+53256>>2]=an;c[ay+184328>>2]=an;ah=ai+3072|0;c[ay+53260>>2]=ah;c[ay+184332>>2]=ah;ad=ai+4096|0;c[ay+53264>>2]=ad;c[ay+184336>>2]=ad;al=ai+5120|0;c[ay+53268>>2]=al;c[ay+184340>>2]=al;am=ai+6144|0;c[ay+53272>>2]=am;c[ay+184344>>2]=am;aq=ai+7168|0;c[ay+53276>>2]=aq;c[ay+184348>>2]=aq;c[ay+53280>>2]=ai;c[ay+184352>>2]=ai;c[ay+53284>>2]=ae;c[ay+184356>>2]=ae;c[ay+53288>>2]=an;c[ay+184360>>2]=an;c[ay+53292>>2]=ah;c[ay+184364>>2]=ah;c[ay+53296>>2]=ad;c[ay+184368>>2]=ad;c[ay+53300>>2]=al;c[ay+184372>>2]=al;c[ay+53304>>2]=am;c[ay+184376>>2]=am;c[ay+53308>>2]=aq;c[ay+184380>>2]=aq;c[ay+53312>>2]=ai;c[ay+184384>>2]=ai;c[ay+53316>>2]=ae;c[ay+184388>>2]=ae;c[ay+53320>>2]=an;c[ay+184392>>2]=an;c[ay+53324>>2]=ah;c[ay+184396>>2]=ah;c[ay+53328>>2]=ad;c[ay+184400>>2]=ad;c[ay+53332>>2]=al;c[ay+184404>>2]=al;c[ay+53336>>2]=am;c[ay+184408>>2]=am;c[ay+53340>>2]=aq;c[ay+184412>>2]=aq;c[ay+53344>>2]=ai;c[ay+184416>>2]=ai;c[ay+53348>>2]=ae;c[ay+184420>>2]=ae;c[ay+53352>>2]=an;c[ay+184424>>2]=an;c[ay+53356>>2]=ah;c[ay+184428>>2]=ah;c[ay+53360>>2]=ad;c[ay+184432>>2]=ad;c[ay+53364>>2]=al;c[ay+184436>>2]=al;c[ay+53368>>2]=am;c[ay+184440>>2]=am;c[ay+53372>>2]=aq;c[ay+184444>>2]=aq;if(ab){aq=c[2443448]|0;am=ay+40960|0;al=10485760;while(1){ad=aq+(al-10485760)|0;c[am>>2]=ad;c[am+65536>>2]=ad;c[am+131072>>2]=ad;ad=al+1024|0;if(ad>>>0>10518527){break}else{am=am+4|0;al=ad}}al=c[3527260]|0;c[ay+57344>>2]=al;c[ay+122880>>2]=al;c[ay+188416>>2]=al;am=al+1024|0;c[ay+57348>>2]=am;c[ay+122884>>2]=am;c[ay+188420>>2]=am;am=al+2048|0;c[ay+57352>>2]=am;c[ay+122888>>2]=am;c[ay+188424>>2]=am;am=al+3072|0;c[ay+57356>>2]=am;c[ay+122892>>2]=am;c[ay+188428>>2]=am}else{am=ay+40960|0;al=10485760;while(1){aq=_+(al-7340032)|0;c[am>>2]=aq;c[am+131072>>2]=aq;aq=al+1024|0;if(aq>>>0>12582911){break}else{am=am+4|0;al=aq}}al=c[3529096]|0;am=ay+49152|0;_=12582912;while(1){aq=al+(_-12582912)|0;c[am>>2]=aq;c[am+131072>>2]=aq;aq=_+1024|0;if(aq>>>0>12845055){break}else{am=am+4|0;_=aq}}_=c[2443448]|0;c[ay+57344>>2]=_;c[ay+122880>>2]=_;c[ay+188416>>2]=_;am=_+1024|0;c[ay+57348>>2]=am;c[ay+122884>>2]=am;c[ay+188420>>2]=am;am=_+2048|0;c[ay+57352>>2]=am;c[ay+122888>>2]=am;c[ay+188424>>2]=am;am=_+3072|0;c[ay+57356>>2]=am;c[ay+122892>>2]=am;c[ay+188428>>2]=am;am=_+4096|0;c[ay+57360>>2]=am;c[ay+122896>>2]=am;c[ay+188432>>2]=am;am=_+5120|0;c[ay+57364>>2]=am;c[ay+122900>>2]=am;c[ay+188436>>2]=am;am=_+6144|0;c[ay+57368>>2]=am;c[ay+122904>>2]=am;c[ay+188440>>2]=am;am=_+7168|0;c[ay+57372>>2]=am;c[ay+122908>>2]=am;c[ay+188444>>2]=am;am=_+8192|0;c[ay+57376>>2]=am;c[ay+122912>>2]=am;c[ay+188448>>2]=am;am=_+9216|0;c[ay+57380>>2]=am;c[ay+122916>>2]=am;c[ay+188452>>2]=am;am=_+10240|0;c[ay+57384>>2]=am;c[ay+122920>>2]=am;c[ay+188456>>2]=am;am=_+11264|0;c[ay+57388>>2]=am;c[ay+122924>>2]=am;c[ay+188460>>2]=am;am=_+12288|0;c[ay+57392>>2]=am;c[ay+122928>>2]=am;c[ay+188464>>2]=am;am=_+13312|0;c[ay+57396>>2]=am;c[ay+122932>>2]=am;c[ay+188468>>2]=am;am=_+14336|0;c[ay+57400>>2]=am;c[ay+122936>>2]=am;c[ay+188472>>2]=am;am=_+15360|0;c[ay+57404>>2]=am;c[ay+122940>>2]=am;c[ay+188476>>2]=am;am=c[2443446]|0;c[ay+57408>>2]=am;c[ay+122944>>2]=am;c[ay+188480>>2]=am;_=am+1024|0;c[ay+57412>>2]=_;c[ay+122948>>2]=_;c[ay+188484>>2]=_;_=am+2048|0;c[ay+57416>>2]=_;c[ay+122952>>2]=_;c[ay+188488>>2]=_;_=am+3072|0;c[ay+57420>>2]=_;c[ay+122956>>2]=_;c[ay+188492>>2]=_;_=am+4096|0;c[ay+57424>>2]=_;c[ay+122960>>2]=_;c[ay+188496>>2]=_;_=am+5120|0;c[ay+57428>>2]=_;c[ay+122964>>2]=_;c[ay+188500>>2]=_;_=am+6144|0;c[ay+57432>>2]=_;c[ay+122968>>2]=_;c[ay+188504>>2]=_;_=am+7168|0;c[ay+57436>>2]=_;c[ay+122972>>2]=_;c[ay+188508>>2]=_;_=am+8192|0;c[ay+57440>>2]=_;c[ay+122976>>2]=_;c[ay+188512>>2]=_;_=am+9216|0;c[ay+57444>>2]=_;c[ay+122980>>2]=_;c[ay+188516>>2]=_;_=am+10240|0;c[ay+57448>>2]=_;c[ay+122984>>2]=_;c[ay+188520>>2]=_;_=am+11264|0;c[ay+57452>>2]=_;c[ay+122988>>2]=_;c[ay+188524>>2]=_;_=am+12288|0;c[ay+57456>>2]=_;c[ay+122992>>2]=_;c[ay+188528>>2]=_;_=am+13312|0;c[ay+57460>>2]=_;c[ay+122996>>2]=_;c[ay+188532>>2]=_;_=am+14336|0;c[ay+57464>>2]=_;c[ay+123e3>>2]=_;c[ay+188536>>2]=_;_=am+15360|0;c[ay+57468>>2]=_;c[ay+123004>>2]=_;c[ay+188540>>2]=_;_=c[3527260]|0;c[ay+61440>>2]=_;c[ay+126976>>2]=_;c[ay+192512>>2]=_;_=c[3527258]|0;c[ay+61696>>2]=_;c[ay+127232>>2]=_;c[ay+192768>>2]=_}_=c[3531166]|0;c[ay+65408>>2]=_;c[ay+130944>>2]=_;c[ay+196480>>2]=_;am=_+1024|0;c[ay+65412>>2]=am;c[ay+130948>>2]=am;c[ay+196484>>2]=am;am=_+2048|0;c[ay+65416>>2]=am;c[ay+130952>>2]=am;c[ay+196488>>2]=am;am=_+3072|0;c[ay+65420>>2]=am;c[ay+130956>>2]=am;c[ay+196492>>2]=am;am=_+4096|0;c[ay+65424>>2]=am;c[ay+130960>>2]=am;c[ay+196496>>2]=am;am=_+5120|0;c[ay+65428>>2]=am;c[ay+130964>>2]=am;c[ay+196500>>2]=am;am=_+6144|0;c[ay+65432>>2]=am;c[ay+130968>>2]=am;c[ay+196504>>2]=am;am=_+7168|0;c[ay+65436>>2]=am;c[ay+130972>>2]=am;c[ay+196508>>2]=am;am=_+8192|0;c[ay+65440>>2]=am;c[ay+130976>>2]=am;c[ay+196512>>2]=am;am=_+9216|0;c[ay+65444>>2]=am;c[ay+130980>>2]=am;c[ay+196516>>2]=am;am=_+10240|0;c[ay+65448>>2]=am;c[ay+130984>>2]=am;c[ay+196520>>2]=am;am=_+11264|0;c[ay+65452>>2]=am;c[ay+130988>>2]=am;c[ay+196524>>2]=am;am=_+12288|0;c[ay+65456>>2]=am;c[ay+130992>>2]=am;c[ay+196528>>2]=am;am=_+13312|0;c[ay+65460>>2]=am;c[ay+130996>>2]=am;c[ay+196532>>2]=am;am=_+14336|0;c[ay+65464>>2]=am;c[ay+131e3>>2]=am;c[ay+196536>>2]=am;am=_+15360|0;c[ay+65468>>2]=am;c[ay+131004>>2]=am;c[ay+196540>>2]=am;am=c[3527306]|0;c[ay+65472>>2]=am;c[ay+131008>>2]=am;c[ay+196544>>2]=am;_=am+1024|0;c[ay+65476>>2]=_;c[ay+131012>>2]=_;c[ay+196548>>2]=_;_=am+2048|0;c[ay+65480>>2]=_;c[ay+131016>>2]=_;c[ay+196552>>2]=_;_=am+3072|0;c[ay+65484>>2]=_;c[ay+131020>>2]=_;c[ay+196556>>2]=_;_=c[2386218]|0;c[ay+65488>>2]=_;c[ay+131024>>2]=_;c[ay+196560>>2]=_;am=_+1024|0;c[ay+65492>>2]=am;c[ay+131028>>2]=am;c[ay+196564>>2]=am;am=_+2048|0;c[ay+65496>>2]=am;c[ay+131032>>2]=am;c[ay+196568>>2]=am;am=_+3072|0;c[ay+65500>>2]=am;c[ay+131036>>2]=am;c[ay+196572>>2]=am;am=c[2387208]|0;c[ay+65504>>2]=am;c[ay+131040>>2]=am;c[ay+196576>>2]=am;_=am+1024|0;c[ay+65508>>2]=_;c[ay+131044>>2]=_;c[ay+196580>>2]=_;_=am+2048|0;c[ay+65512>>2]=_;c[ay+131048>>2]=_;c[ay+196584>>2]=_;_=am+3072|0;c[ay+65516>>2]=_;c[ay+131052>>2]=_;c[ay+196588>>2]=_;c[ay+196728>>2]=370;c[ay+196648>>2]=1542;c[ay+196688>>2]=3600;c[ay+196608>>2]=2770;_=c[3532592]|0;if((_|0)!=0){gGC(_|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fxU(1,425984);if((c[2394]|0)==1){az=c[2112932]|0}else{c[2394]=1;_=c[3532597]|0;c[2112932]=_;am=c[3532593]|0;if((am|0)!=0){gGC(9104152,am|0,280)|0}c[2113054]=c[2113061];az=_}_=c[3531110]|0;am=az|0;al=0;while(1){aq=_+al|0;c[am>>2]=aq;c[am+131072>>2]=aq;aq=al+1024|0;if(aq>>>0>131071){break}else{am=am+4|0;al=aq}}al=c[3531144]|0;c[az+65408>>2]=al;c[az+130944>>2]=al;c[az+196480>>2]=al;am=al+1024|0;c[az+65412>>2]=am;c[az+130948>>2]=am;c[az+196484>>2]=am;am=al+2048|0;c[az+65416>>2]=am;c[az+130952>>2]=am;c[az+196488>>2]=am;am=al+3072|0;c[az+65420>>2]=am;c[az+130956>>2]=am;c[az+196492>>2]=am;am=al+4096|0;c[az+65424>>2]=am;c[az+130960>>2]=am;c[az+196496>>2]=am;am=al+5120|0;c[az+65428>>2]=am;c[az+130964>>2]=am;c[az+196500>>2]=am;am=al+6144|0;c[az+65432>>2]=am;c[az+130968>>2]=am;c[az+196504>>2]=am;am=al+7168|0;c[az+65436>>2]=am;c[az+130972>>2]=am;c[az+196508>>2]=am;am=al+8192|0;c[az+65440>>2]=am;c[az+130976>>2]=am;c[az+196512>>2]=am;am=al+9216|0;c[az+65444>>2]=am;c[az+130980>>2]=am;c[az+196516>>2]=am;am=al+10240|0;c[az+65448>>2]=am;c[az+130984>>2]=am;c[az+196520>>2]=am;am=al+11264|0;c[az+65452>>2]=am;c[az+130988>>2]=am;c[az+196524>>2]=am;am=al+12288|0;c[az+65456>>2]=am;c[az+130992>>2]=am;c[az+196528>>2]=am;am=al+13312|0;c[az+65460>>2]=am;c[az+130996>>2]=am;c[az+196532>>2]=am;am=al+14336|0;c[az+65464>>2]=am;c[az+131e3>>2]=am;c[az+196536>>2]=am;am=al+15360|0;c[az+65468>>2]=am;c[az+131004>>2]=am;c[az+196540>>2]=am;am=c[3527306]|0;c[az+65472>>2]=am;c[az+131008>>2]=am;c[az+196544>>2]=am;al=am+1024|0;c[az+65476>>2]=al;c[az+131012>>2]=al;c[az+196548>>2]=al;al=am+2048|0;c[az+65480>>2]=al;c[az+131016>>2]=al;c[az+196552>>2]=al;al=am+3072|0;c[az+65484>>2]=al;c[az+131020>>2]=al;c[az+196556>>2]=al;al=c[3532593]|0;if((al|0)!=0){gGC(al|0,9104152,280)|0}c[2113061]=c[2113054];c[2394]=-1;fwR(0);al=c[2439330]|0;am=(al|0)==0;if(!am){_=al;gGC(9706056,_|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];_=c[3528484]|0;c[2076596]=_;aq=c[2417276]|0;c[3541536]=aq;c[1836236]=0;ab=c[2385928]|0;ad=0;ah=0;while(1){c[al+76+(ah<<2)>>2]=ab+(ah<<8);an=ad+1&65535;if((an&65535)>119){aA=0;aB=0;break}else{ad=an;ah=an&65535}}while(1){ah=ab+(aB<<8)|0;c[al+76+(aB+512<<2)>>2]=ah;c[al+76+(aB+768<<2)>>2]=ah;ah=aA+1&65535;if((ah&65535)>119){break}else{aA=ah;aB=ah&65535}}ah=c[2386082]|0;c[al+556>>2]=ah;ad=ah+256|0;c[al+560>>2]=ad;an=ah+512|0;c[al+564>>2]=an;ae=ah+768|0;c[al+568>>2]=ae;ai=ah+1024|0;c[al+572>>2]=ai;ar=ah+1280|0;c[al+576>>2]=ar;ao=ah+1536|0;c[al+580>>2]=ao;ap=ah+1792|0;c[al+584>>2]=ap;c[al+1580>>2]=ah;c[al+1584>>2]=ad;c[al+1588>>2]=an;c[al+1592>>2]=ae;c[al+1596>>2]=ai;c[al+1600>>2]=ar;c[al+1604>>2]=ao;c[al+1608>>2]=ap;c[al+2604>>2]=ah;c[al+3628>>2]=ah;c[al+2608>>2]=ad;c[al+3632>>2]=ad;c[al+2612>>2]=an;c[al+3636>>2]=an;c[al+2616>>2]=ae;c[al+3640>>2]=ae;c[al+2620>>2]=ai;c[al+3644>>2]=ai;c[al+2624>>2]=ar;c[al+3648>>2]=ar;c[al+2628>>2]=ao;c[al+3652>>2]=ao;c[al+2632>>2]=ap;c[al+3656>>2]=ap;ap=128;ao=128;while(1){c[al+76+(ao<<2)>>2]=ab+(ao<<8);ar=ap+1&65535;if((ar&65535)>255){aC=128;aD=128;break}else{ap=ar;ao=ar&65535}}while(1){ao=ab+(aD<<8)|0;c[al+76+(aD+512<<2)>>2]=ao;c[al+76+(aD+768<<2)>>2]=ao;ao=aC+1&65535;if((ao&65535)>255){break}else{aC=ao;aD=ao&65535}}c[al+4176>>2]=2956;c[al+4172>>2]=2226;if(!am){ab=al;gGC(ab|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=_;c[2417276]=aq;c[1836236]=-1;c[Z>>2]=1048576;ab=c[2386652]|0;TW(ab+1048576|0,Z,ab,Z,378,74,92);c[2438228]=5e6;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=408;h[745406]=1.0;c[2436786]=1;h[745405]=1.0;c[2436784]=2;h[745404]=.25;a[3203280]=1;b[7055036]=-1;ab=1;do{aE=15.0/+(ab|0);ao=0;do{aF=aE*+(ao|0);if(aF<16.0){aG=~~aF&65535}else{aG=-1}b[14110072+(ab*66|0)+(ao<<1)>>1]=aG;ao=ao+1|0;}while((ao|0)<16);ab=ab+1|0;}while((ab|0)<32);ab=c[642608+(c[2436]<<2)>>2]|0;aq=c[ab+128>>2]|0;if((c[ab+52>>2]&4|0)==0){c[2113068]=aq;_=c[ab+132>>2]|0;c[2113070]=_;c[2443814]=aq;c[2440436]=_;aH=aq;aI=_}else{c[2113070]=aq;_=c[ab+132>>2]|0;c[2113068]=_;c[2440436]=aq;c[2443814]=_;aH=_;aI=aq}aq=ag(aH<<1,aI)|0;_=gGq(aq)|0;c[2112926]=_;if((_|0)!=0){gGz(_|0,0,aq|0)}a[9624248]=0;aq=c[2414678]|0;gGz(aq|0,0,(c[2411680]|0)-aq|0);gGz(c[3531072]|0,1,4096);gGz(c[2438814]|0,1,2048);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];aq=c[3532592]|0;if((aq|0)!=0){gGC(9104152,aq|0,280)|0}c[2113054]=c[2113060]}RI();aq=c[2394]|0;_=c[14130368+(aq<<2)>>2]|0;if((_|0)!=0){gGC(_|0,9104152,280)|0}c[8452240+(aq<<2)>>2]=c[2113054];c[2394]=1;c[2112932]=c[3532597];aq=c[3532593]|0;if((aq|0)!=0){gGC(9104152,aq|0,280)|0}c[2113054]=c[2113061];RI();aq=c[2394]|0;_=c[14130368+(aq<<2)>>2]|0;if((_|0)!=0){gGC(_|0,9104152,280)|0}c[8452240+(aq<<2)>>2]=c[2113054];c[2394]=-1;aq=c[2439330]|0;_=(aq|0)==0;if(!_){ab=aq;gGC(9706056,ab|0,76)|0}ab=c[2438118]|0;c[2433530]=ab;al=c[3528484]|0;c[2076596]=al;am=c[2417276]|0;c[3541536]=am;c[1836236]=0;gGz(9706056,0,76);if(!_){_=aq;gGC(_|0,9706056,76)|0}c[2438118]=ab;c[3528484]=al;c[2417276]=am;c[1836236]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;l6(0);ac=0;i=f;return ac|0}}while(0);c[2414974]=0;ac=1;i=f;return ac|0}function d1J(b,c){b=b|0;c=c|0;a[9706117]=(c|0)!=0|0;return}function d1K(a){a=a|0;var b=0,d=0;b=(c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,5e6,0)|0;return a|0}function d1L(){return+(+((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)/5.0e6)}function d1M(a,d,f,g){a=a|0;d=d|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;h=a;i=d;d=(e[a+1020>>1]|0)<<2;if(d>>>0<512){j=d}else{return}do{d=e[h+((j|2)<<1)>>1]|0;if((d&128|0)!=0){a=e[h+(j<<1)>>1]|0;k=e[h+((j|1)<<1)>>1]|0;l=d>>>8&7;m=d&2048;n=d>>>12&7;o=d&32768;p=d&15|g;d=16-((c[607560+(k>>>12<<2)>>2]|0)/8|0)|0;q=16-((c[607560+(a>>>12<<2)>>2]|0)/8|0)|0;r=(o|0)==0;s=a+16|0;a=(m|0)==0;t=k+16|0;k=(l|0)==4;u=(l|0)==5;v=(l|0)==6|0;w=l+1+((l|0)==2)|0;x=0;y=e[h+((j|3)<<1)>>1]|0;while(1){z=(s+(ag(r?x:n-x|0,q)|0)&511)-24|0;if(a){A=0;B=y;while(1){C=((ag(A,d)|0)+t&511)-16|0;d1H(f,b[i+((B&8191)<<1)>>1]&8191,p,C,z,d,q,0,o);C=A+1|0;if((C|0)>(l|0)){break}else{A=C;B=B+1|0}}}else{B=0;A=y;while(1){C=((ag(l-B|0,d)|0)+t&511)-16|0;d1H(f,b[i+((A&8191)<<1)>>1]&8191,p,C,z,d,q,m,o);C=B+1|0;if((C|0)>(l|0)){break}else{B=C;A=A+1|0}}}A=w+y|0;B=k?A+3|0:A;A=x+1|0;if((A|0)>(n|0)){break}else{x=A;y=(u?B+2|0:B)+v|0}}}j=j+4|0;}while((j|0)<512);return}function d1N(b,d){b=b|0;d=d|0;var e=0,f=0;if((b&268435440|0)!=655360){return}e=b>>>1&7;if((e|0)==6){c[2432768]=0;c[2432908]=1;return}else if((e|0)==4){do{if(a[7045208]|0){c[2384378]=215;if((c[2384374]|0)!=223){f=-41;break}a[14125144]=-41;a[9706117]=1;f=-41}else{f=c[2384378]&255&-33}}while(0);c[2384374]=223;a[14125144]=f;a[9706117]=1;return}else if((e|0)==0|(e|0)==1){a[9579184+e|0]=d;return}else{return}}function d1O(d,e){d=d|0;e=e|0;var f=0,g=0;if((d&268435440|0)!=655360){if((d&268435328|0)!=786432){return}b[(c[2443472]|0)+(d&126)>>1]=e;return}f=e&255;e=d>>>1&7;if((e|0)==4){do{if(a[7045208]|0){c[2384378]=215;if((c[2384374]|0)!=223){g=-41;break}a[14125144]=-41;a[9706117]=1;g=-41}else{g=c[2384378]&255&-33}}while(0);c[2384374]=223;a[14125144]=g;a[9706117]=1;return}else if((e|0)==0|(e|0)==1){a[9579184+e|0]=f;return}else if((e|0)==6){c[2432768]=0;c[2432908]=1;return}else{return}}function d1P(b){b=b|0;var d=0,e=0;do{if((b&268435440|0)==655360){d=b>>>1&7;if((d|0)==5){e=(c[2432908]|0)!=0|0;break}else if((d|0)==2|(d|0)==3){e=a[9553896+(d-2)|0]|0;break}else{e=-1;break}}else{e=0}}while(0);return e|0}function d1Q(e){e=e|0;var f=0,g=0,h=0;if((e&268435440|0)==655360){f=e>>>1&7;if((f|0)==2|(f|0)==3){g=a[9553896+(f-2)|0]|0}else if((f|0)==5){g=(c[2432908]|0)!=0|0}else{g=-1}h=g&255;return h|0}if((e|0)==917508){h=b[4775266]|0;return h|0}else if((e|0)==917506){h=b[4775265]|0;return h|0}else if((e|0)==917504){h=(d[9635129]|0)<<8|(d[9635128]|0);return h|0}else{h=0;return h|0}return 0}function d1R(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3065380+(b*112|0)>>2];c[a+104>>2]=c[3065384+(b*112|0)>>2];c[a+108>>2]=c[3065388+(b*112|0)>>2];d=0;return d|0}function d1S(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=3065280+(b*112|0);e=0;return e|0}function d1T(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1309824+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function d1U(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>79){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4233568+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function d1V(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0;b=i;i=i+3360|0;d=b|0;e=b+112|0;f=b+120|0;g=b+232|0;h=b+240|0;j=b+352|0;k=b+360|0;l=b+472|0;m=b+480|0;n=b+592|0;o=b+600|0;p=b+712|0;q=b+720|0;r=b+832|0;s=b+840|0;t=b+952|0;u=b+960|0;v=b+1072|0;w=b+1080|0;x=b+1192|0;y=b+1200|0;z=b+1312|0;A=b+1320|0;B=b+1432|0;C=b+1440|0;D=b+1552|0;E=b+1560|0;F=b+1672|0;G=b+1680|0;H=b+1792|0;I=b+1800|0;J=b+1912|0;K=b+1920|0;L=b+2032|0;M=b+2040|0;N=b+2152|0;O=b+2160|0;P=b+2272|0;Q=b+2280|0;R=b+2392|0;S=b+2400|0;T=b+2512|0;U=b+2520|0;V=b+2632|0;W=b+2640|0;X=b+2752|0;Y=b+2760|0;Z=b+2872|0;_=b+2880|0;$=b+2992|0;aa=b+3e3|0;ab=b+3112|0;ac=b+3120|0;ad=b+3232|0;ae=b+3240|0;af=b+3352|0;c[2414972]=0;c[2388162]=0;c[3532600]=524288;c[2385926]=524288;c[3530434]=655360;c[3530848]=2752512;c[3530612]=3014656;c[3541206]=5111808;c[2386650]=5111808;c[3530020]=5373952;c[2414676]=5382144;c[2388288]=5382144;c[3531142]=5429248;c[2387206]=5466112;c[2386464]=5470208;c[2406568]=5474304;c[2405798]=5478400;c[2406490]=5488640;c[2443472]=5492736;c[3532602]=5492864;c[2411678]=5494912;ah=0;while(1){if((ah|0)>=1024){break}ai=9638528+(ah<<2)|0;if((c[ai>>2]|0)==0){aj=40929;break}else{ah=ah+1|0}}do{if((aj|0)==40929){ah=gGq(5494912)|0;c[ai>>2]=ah;if((ah|0)==0){break}c[2414972]=ah;gGz(ah|0,0,5494912);c[2388162]=ah;ak=ah+524288|0;c[3532600]=ak;c[2385926]=ak;c[3530434]=ah+655360;c[3530848]=ah+2752512;c[3530612]=ah+3014656;ak=ah+5111808|0;c[3541206]=ak;c[2386650]=ak;c[3530020]=ah+5373952;ak=ah+5382144|0;c[2414676]=ak;c[2388288]=ak;c[3531142]=ah+5429248;c[2387206]=ah+5466112;c[2386464]=ah+5470208;c[2406568]=ah+5474304;c[2405798]=ah+5478400;c[2406490]=ah+5488640;c[2443472]=ah+5492736;ak=ah+5492864|0;c[3532602]=ak;c[2386080]=ak;ak=ah+5494912|0;c[2411678]=ak;c[2414218]=ak;ak=(fa(c[c[642608+(c[2436]<<2)>>2]>>2]|0,75760)|0)==0;al=(R6(ah,0,2)|0)!=0;if(ak){if(al){am=1;i=b;return am|0}if((R6((c[2388162]|0)+1|0,1,2)|0)!=0){am=1;i=b;return am|0}if((R6((c[2388162]|0)+262144|0,2,2)|0)!=0){am=1;i=b;return am|0}if((R6((c[2388162]|0)+262145|0,3,2)|0)!=0){am=1;i=b;return am|0}ak=c[2385926]|0;if((c[3542200]|0)==0){am=1;i=b;return am|0}ah=ae+108|0;c[ah>>2]=0;an=ae+100|0;c[an>>2]=0;ao=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ao&16383](ae,4)|0;do{if((c[ah>>2]|0)!=0){ao=c[an>>2]|0;c[af>>2]=9534384;ap=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ap&16383](af,4,0)|0;if((ao|0)<1){am=1;i=b;return am|0}if((gzL(ak,0,4)|0)==0){break}else{am=1}i=b;return am|0}}while(0);ak=c[2385926]|0;an=ak+65536|0;ah=ak+32768|0;gGC(an|0,ah|0,32768)|0;an=ak+98304|0;gGC(an|0,ah|0,32768)|0;ah=0;while(1){if((ah|0)>=1024){aq=0;break}ar=9638528+(ah<<2)|0;if((c[ar>>2]|0)==0){aj=40943;break}else{ah=ah+1|0}}do{if((aj|0)==40943){ah=gGq(65536)|0;c[ar>>2]=ah;if((ah|0)==0){aq=0;break}gGz(ah|0,0,65536);aq=ah}}while(0);if((c[3542200]|0)==0){am=1;i=b;return am|0}ah=ac+108|0;c[ah>>2]=0;an=ac+100|0;c[an>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](ac,5)|0;do{if((c[ah>>2]|0)!=0){ak=c[an>>2]|0;c[ad>>2]=9534384;ao=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ao&16383](ad,5,0)|0;if((ak|0)<1){am=1;i=b;return am|0}if((gzL(aq,0,5)|0)==0){break}else{am=1}i=b;return am|0}}while(0);an=c[3530848]|0;ah=aq+32768|0;gGC(an|0,ah|0,32768)|0;if((c[3542200]|0)==0){am=1;i=b;return am|0}an=aa+108|0;c[an>>2]=0;ak=aa+100|0;c[ak>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](aa,6)|0;do{if((c[an>>2]|0)!=0){ao=c[ak>>2]|0;c[ab>>2]=9534384;ap=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ap&16383](ab,6,0)|0;if((ao|0)<1){am=1;i=b;return am|0}if((gzL(aq,0,6)|0)==0){break}else{am=1}i=b;return am|0}}while(0);ak=(c[3530848]|0)+32768|0;gGC(ak|0,ah|0,32768)|0;if((c[3542200]|0)==0){am=1;i=b;return am|0}ak=_+108|0;c[ak>>2]=0;an=_+100|0;c[an>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](_,7)|0;do{if((c[ak>>2]|0)!=0){ao=c[an>>2]|0;c[$>>2]=9534384;ap=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ap&16383]($,7,0)|0;if((ao|0)<1){am=1;i=b;return am|0}if((gzL(aq,0,7)|0)==0){break}else{am=1}i=b;return am|0}}while(0);an=(c[3530848]|0)+65536|0;gGC(an|0,ah|0,32768)|0;if((c[3542200]|0)==0){am=1;i=b;return am|0}an=Y+108|0;c[an>>2]=0;ak=Y+100|0;c[ak>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](Y,8)|0;do{if((c[an>>2]|0)!=0){ao=c[ak>>2]|0;c[Z>>2]=9534384;ap=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ap&16383](Z,8,0)|0;if((ao|0)<1){am=1;i=b;return am|0}if((gzL(aq,0,8)|0)==0){break}else{am=1}i=b;return am|0}}while(0);ak=(c[3530848]|0)+98304|0;gGC(ak|0,ah|0,32768)|0;ak=0;while(1){if((ak|0)>=1024){break}as=9638528+(ak<<2)|0;if((c[as>>2]|0)==(aq|0)){aj=40964;break}else{ak=ak+1|0}}if((aj|0)==40964){gGr(aq);c[as>>2]=0}ak=(c[3530612]|0)+131072|0;if((c[3542200]|0)==0){am=1;i=b;return am|0}ah=W+108|0;c[ah>>2]=0;an=W+100|0;c[an>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](W,9)|0;do{if((c[ah>>2]|0)!=0){ao=c[an>>2]|0;c[X>>2]=9534384;ap=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ap&16383](X,9,0)|0;if((ao|0)<1){am=1;i=b;return am|0}if((gzL(ak,0,9)|0)==0){break}else{am=1}i=b;return am|0}}while(0);ak=(c[3530612]|0)+393216|0;if((c[3542200]|0)==0){am=1;i=b;return am|0}an=U+108|0;c[an>>2]=0;ah=U+100|0;c[ah>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](U,10)|0;do{if((c[an>>2]|0)!=0){ao=c[ah>>2]|0;c[V>>2]=9534384;ap=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ap&16383](V,10,0)|0;if((ao|0)<1){am=1;i=b;return am|0}if((gzL(ak,0,10)|0)==0){break}else{am=1}i=b;return am|0}}while(0);ak=(c[3530612]|0)+655360|0;if((c[3542200]|0)==0){am=1;i=b;return am|0}ah=S+108|0;c[ah>>2]=0;an=S+100|0;c[an>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](S,11)|0;do{if((c[ah>>2]|0)!=0){ao=c[an>>2]|0;c[T>>2]=9534384;ap=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ap&16383](T,11,0)|0;if((ao|0)<1){am=1;i=b;return am|0}if((gzL(ak,0,11)|0)==0){break}else{am=1}i=b;return am|0}}while(0);ak=(c[3530612]|0)+917504|0;if((c[3542200]|0)==0){am=1;i=b;return am|0}an=Q+108|0;c[an>>2]=0;ah=Q+100|0;c[ah>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](Q,12)|0;do{if((c[an>>2]|0)!=0){ao=c[ah>>2]|0;c[R>>2]=9534384;ap=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ap&16383](R,12,0)|0;if((ao|0)<1){am=1;i=b;return am|0}if((gzL(ak,0,12)|0)==0){break}else{am=1}i=b;return am|0}}while(0);ak=c[3530612]|0;if((c[3542200]|0)==0){am=1;i=b;return am|0}ah=O+108|0;c[ah>>2]=0;an=O+100|0;c[an>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](O,13)|0;do{if((c[ah>>2]|0)!=0){ao=c[an>>2]|0;c[P>>2]=9534384;ap=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ap&16383](P,13,0)|0;if((ao|0)<1){am=1;i=b;return am|0}if((gzL(ak,0,13)|0)==0){break}else{am=1}i=b;return am|0}}while(0);ak=(c[3530612]|0)+262144|0;if((c[3542200]|0)==0){am=1;i=b;return am|0}an=M+108|0;c[an>>2]=0;ah=M+100|0;c[ah>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](M,14)|0;do{if((c[an>>2]|0)!=0){ao=c[ah>>2]|0;c[N>>2]=9534384;ap=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ap&16383](N,14,0)|0;if((ao|0)<1){am=1;i=b;return am|0}if((gzL(ak,0,14)|0)==0){break}else{am=1}i=b;return am|0}}while(0);ak=(c[3530612]|0)+524288|0;if((c[3542200]|0)==0){am=1;i=b;return am|0}ah=K+108|0;c[ah>>2]=0;an=K+100|0;c[an>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](K,15)|0;do{if((c[ah>>2]|0)!=0){ao=c[an>>2]|0;c[L>>2]=9534384;ap=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ap&16383](L,15,0)|0;if((ao|0)<1){am=1;i=b;return am|0}if((gzL(ak,0,15)|0)==0){break}else{am=1}i=b;return am|0}}while(0);ak=(c[3530612]|0)+786432|0;if((c[3542200]|0)==0){am=1;i=b;return am|0}an=I+108|0;c[an>>2]=0;ah=I+100|0;c[ah>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](I,16)|0;do{if((c[an>>2]|0)!=0){ao=c[ah>>2]|0;c[J>>2]=9534384;ap=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ap&16383](J,16,0)|0;if((ao|0)<1){am=1;i=b;return am|0}if((gzL(ak,0,16)|0)==0){break}else{am=1}i=b;return am|0}}while(0);ak=c[3530434]|0;if((c[3542200]|0)==0){am=1;i=b;return am|0}ah=G+108|0;c[ah>>2]=0;an=G+100|0;c[an>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](G,17)|0;do{if((c[ah>>2]|0)!=0){ao=c[an>>2]|0;c[H>>2]=9534384;ap=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ap&16383](H,17,0)|0;if((ao|0)<1){am=1;i=b;return am|0}if((gzL(ak,0,17)|0)==0){break}else{am=1}i=b;return am|0}}while(0);ak=(c[3530434]|0)+131072|0;if((c[3542200]|0)==0){am=1;i=b;return am|0}an=E+108|0;c[an>>2]=0;ah=E+100|0;c[ah>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](E,18)|0;do{if((c[an>>2]|0)!=0){ao=c[ah>>2]|0;c[F>>2]=9534384;ap=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ap&16383](F,18,0)|0;if((ao|0)<1){am=1;i=b;return am|0}if((gzL(ak,0,18)|0)==0){break}else{am=1}i=b;return am|0}}while(0);ak=(c[3530434]|0)+262144|0;if((c[3542200]|0)==0){am=1;i=b;return am|0}ah=C+108|0;c[ah>>2]=0;an=C+100|0;c[an>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](C,19)|0;do{if((c[ah>>2]|0)!=0){ao=c[an>>2]|0;c[D>>2]=9534384;ap=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ap&16383](D,19,0)|0;if((ao|0)<1){am=1;i=b;return am|0}if((gzL(ak,0,19)|0)==0){break}else{am=1}i=b;return am|0}}while(0);ak=(c[3530434]|0)+393216|0;if((c[3542200]|0)==0){am=1;i=b;return am|0}an=A+108|0;c[an>>2]=0;ah=A+100|0;c[ah>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](A,20)|0;do{if((c[an>>2]|0)!=0){ao=c[ah>>2]|0;c[B>>2]=9534384;ap=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ap&16383](B,20,0)|0;if((ao|0)<1){am=1;i=b;return am|0}if((gzL(ak,0,20)|0)==0){break}else{am=1}i=b;return am|0}}while(0);ak=(c[3530434]|0)+524288|0;if((c[3542200]|0)==0){am=1;i=b;return am|0}ah=y+108|0;c[ah>>2]=0;an=y+100|0;c[an>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](y,21)|0;do{if((c[ah>>2]|0)!=0){ao=c[an>>2]|0;c[z>>2]=9534384;ap=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ap&16383](z,21,0)|0;if((ao|0)<1){am=1;i=b;return am|0}if((gzL(ak,0,21)|0)==0){break}else{am=1}i=b;return am|0}}while(0);ak=(c[3530434]|0)+655360|0;if((c[3542200]|0)==0){am=1;i=b;return am|0}an=w+108|0;c[an>>2]=0;ah=w+100|0;c[ah>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](w,22)|0;do{if((c[an>>2]|0)!=0){ao=c[ah>>2]|0;c[x>>2]=9534384;ap=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ap&16383](x,22,0)|0;if((ao|0)<1){am=1;i=b;return am|0}if((gzL(ak,0,22)|0)==0){break}else{am=1}i=b;return am|0}}while(0);ak=(c[3530434]|0)+786432|0;if((c[3542200]|0)==0){am=1;i=b;return am|0}ah=u+108|0;c[ah>>2]=0;an=u+100|0;c[an>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](u,23)|0;do{if((c[ah>>2]|0)!=0){ao=c[an>>2]|0;c[v>>2]=9534384;ap=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ap&16383](v,23,0)|0;if((ao|0)<1){am=1;i=b;return am|0}if((gzL(ak,0,23)|0)==0){break}else{am=1}i=b;return am|0}}while(0);ak=(c[3530434]|0)+917504|0;if((c[3542200]|0)==0){am=1;i=b;return am|0}an=s+108|0;c[an>>2]=0;ah=s+100|0;c[ah>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](s,24)|0;do{if((c[an>>2]|0)!=0){ao=c[ah>>2]|0;c[t>>2]=9534384;ap=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ap&16383](t,24,0)|0;if((ao|0)<1){am=1;i=b;return am|0}if((gzL(ak,0,24)|0)==0){break}else{am=1}i=b;return am|0}}while(0);ak=c[2386650]|0;if((c[3542200]|0)==0){am=1;i=b;return am|0}ah=q+108|0;c[ah>>2]=0;an=q+100|0;c[an>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](q,25)|0;do{if((c[ah>>2]|0)!=0){ao=c[an>>2]|0;c[r>>2]=9534384;ap=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ap&16383](r,25,0)|0;if((ao|0)<1){am=1;i=b;return am|0}if((gzL(ak,0,25)|0)==0){break}else{am=1}i=b;return am|0}}while(0);d17();fxU(0,425984);if((c[2394]|0)==0){at=c[2112932]|0}else{c[2394]=0;ak=c[3532596]|0;c[2112932]=ak;an=c[3532592]|0;if((an|0)!=0){gGC(9104152,an|0,280)|0}c[2113054]=c[2113060];at=ak}ak=c[2388162]|0;an=at|0;ah=0;while(1){ao=ak+ah|0;c[an>>2]=ao;c[an+131072>>2]=ao;ao=ah+1024|0;if(ao>>>0>524287){break}else{an=an+4|0;ah=ao}}ah=c[2388288]|0;an=at+2048|0;ak=524288;while(1){ao=ah+(ak-524288)|0;c[an>>2]=ao;c[an+65536>>2]=ao;c[an+131072>>2]=ao;ao=ak+1024|0;if(ao>>>0>569343){break}else{an=an+4|0;ak=ao}}ak=c[2386464]|0;c[at+2224>>2]=ak;c[at+67760>>2]=ak;c[at+133296>>2]=ak;an=ak+1024|0;c[at+2228>>2]=an;c[at+67764>>2]=an;c[at+133300>>2]=an;an=ak+2048|0;c[at+2232>>2]=an;c[at+67768>>2]=an;c[at+133304>>2]=an;an=ak+3072|0;c[at+2236>>2]=an;c[at+67772>>2]=an;c[at+133308>>2]=an;an=c[2406568]|0;c[at+2240>>2]=an;c[at+67776>>2]=an;c[at+133312>>2]=an;ak=an+1024|0;c[at+2244>>2]=ak;c[at+67780>>2]=ak;c[at+133316>>2]=ak;ak=an+2048|0;c[at+2248>>2]=ak;c[at+67784>>2]=ak;c[at+133320>>2]=ak;ak=an+3072|0;c[at+2252>>2]=ak;c[at+67788>>2]=ak;c[at+133324>>2]=ak;ak=c[2406490]|0;c[at+2256>>2]=ak;c[at+67792>>2]=ak;c[at+133328>>2]=ak;an=ak+1024|0;c[at+2260>>2]=an;c[at+67796>>2]=an;c[at+133332>>2]=an;an=c[2405798]|0;c[at+2264>>2]=an;c[at+67800>>2]=an;c[at+133336>>2]=an;ak=an+1024|0;c[at+2268>>2]=ak;c[at+67804>>2]=ak;c[at+133340>>2]=ak;ak=an+2048|0;c[at+2272>>2]=ak;c[at+67808>>2]=ak;c[at+133344>>2]=ak;ak=an+3072|0;c[at+2276>>2]=ak;c[at+67812>>2]=ak;c[at+133348>>2]=ak;ak=an+4096|0;c[at+2280>>2]=ak;c[at+67816>>2]=ak;c[at+133352>>2]=ak;ak=an+5120|0;c[at+2284>>2]=ak;c[at+67820>>2]=ak;c[at+133356>>2]=ak;ak=an+6144|0;c[at+2288>>2]=ak;c[at+67824>>2]=ak;c[at+133360>>2]=ak;ak=an+7168|0;c[at+2292>>2]=ak;c[at+67828>>2]=ak;c[at+133364>>2]=ak;ak=an+8192|0;c[at+2296>>2]=ak;c[at+67832>>2]=ak;c[at+133368>>2]=ak;ak=an+9216|0;c[at+2300>>2]=ak;c[at+67836>>2]=ak;c[at+133372>>2]=ak;ak=ah+45056|0;c[at+3088>>2]=ak;c[at+68624>>2]=ak;c[at+134160>>2]=ak;ak=ah+46080|0;c[at+3092>>2]=ak;c[at+68628>>2]=ak;c[at+134164>>2]=ak;ak=c[3531142]|0;an=at+4608|0;ao=1179648;while(1){ap=ak+(ao-1179648)|0;c[an>>2]=ap;c[an+65536>>2]=ap;c[an+131072>>2]=ap;ap=ao+1024|0;if(ap>>>0>1212415){break}else{an=an+4|0;ao=ap}}ao=c[2387206]|0;c[at+4736>>2]=ao;c[at+70272>>2]=ao;c[at+135808>>2]=ao;an=ao+1024|0;c[at+4740>>2]=an;c[at+70276>>2]=an;c[at+135812>>2]=an;an=ak+34816|0;c[at+4744>>2]=an;c[at+70280>>2]=an;c[at+135816>>2]=an;an=ak+35840|0;c[at+4748>>2]=an;c[at+70284>>2]=an;c[at+135820>>2]=an;an=c[3532592]|0;if((an|0)!=0){gGC(an|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;c[2443928]=2}else{if(al){am=1;i=b;return am|0}if((R6((c[2388162]|0)+1|0,1,2)|0)!=0){am=1;i=b;return am|0}if((R6((c[2388162]|0)+262144|0,2,2)|0)!=0){am=1;i=b;return am|0}if((R6((c[2388162]|0)+262145|0,3,2)|0)!=0){am=1;i=b;return am|0}an=c[2385926]|0;if((c[3542200]|0)==0){am=1;i=b;return am|0}ao=o+108|0;c[ao>>2]=0;ah=o+100|0;c[ah>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](o,4)|0;do{if((c[ao>>2]|0)!=0){ap=c[ah>>2]|0;c[p>>2]=9534384;au=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[au&16383](p,4,0)|0;if((ap|0)<1){am=1;i=b;return am|0}if((gzL(an,0,4)|0)==0){break}else{am=1}i=b;return am|0}}while(0);an=c[2385926]|0;ah=an+65536|0;ao=an+32768|0;gGC(ah|0,ao|0,32768)|0;ah=an+98304|0;gGC(ah|0,ao|0,32768)|0;ao=c[3530848]|0;if((c[3542200]|0)==0){am=1;i=b;return am|0}ah=m+108|0;c[ah>>2]=0;an=m+100|0;c[an>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,5)|0;do{if((c[ah>>2]|0)!=0){al=c[an>>2]|0;c[n>>2]=9534384;ak=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ak&16383](n,5,0)|0;if((al|0)<1){am=1;i=b;return am|0}if((gzL(ao,0,5)|0)==0){break}else{am=1}i=b;return am|0}}while(0);ao=(c[3530848]|0)+65536|0;if((c[3542200]|0)==0){am=1;i=b;return am|0}an=k+108|0;c[an>>2]=0;ah=k+100|0;c[ah>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,6)|0;do{if((c[an>>2]|0)!=0){al=c[ah>>2]|0;c[l>>2]=9534384;ak=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ak&16383](l,6,0)|0;if((al|0)<1){am=1;i=b;return am|0}if((gzL(ao,0,6)|0)==0){break}else{am=1}i=b;return am|0}}while(0);ao=c[3530612]|0;if((c[3542200]|0)==0){am=1;i=b;return am|0}ah=h+108|0;c[ah>>2]=0;an=h+100|0;c[an>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](h,7)|0;do{if((c[ah>>2]|0)!=0){al=c[an>>2]|0;c[j>>2]=9534384;ak=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ak&16383](j,7,0)|0;if((al|0)<1){am=1;i=b;return am|0}if((gzL(ao,0,7)|0)==0){break}else{am=1}i=b;return am|0}}while(0);ao=c[3530434]|0;if((c[3542200]|0)==0){am=1;i=b;return am|0}an=f+108|0;c[an>>2]=0;ah=f+100|0;c[ah>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,8)|0;do{if((c[an>>2]|0)!=0){al=c[ah>>2]|0;c[g>>2]=9534384;ak=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ak&16383](g,8,0)|0;if((al|0)<1){am=1;i=b;return am|0}if((gzL(ao,0,8)|0)==0){break}else{am=1}i=b;return am|0}}while(0);ao=c[2386650]|0;if((c[3542200]|0)==0){am=1;i=b;return am|0}ah=d+108|0;c[ah>>2]=0;an=d+100|0;c[an>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](d,9)|0;do{if((c[ah>>2]|0)!=0){al=c[an>>2]|0;c[e>>2]=9534384;ak=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ak&16383](e,9,0)|0;if((al|0)<1){am=1;i=b;return am|0}if((gzL(ao,0,9)|0)==0){break}else{am=1}i=b;return am|0}}while(0);d17();c[2443928]=0;if((fa(c[c[642608+(c[2436]<<2)>>2]>>2]|0,535632)|0)==0){c[2443928]=1}fxU(0,425984);if((c[2394]|0)==0){av=c[2112932]|0}else{c[2394]=0;ao=c[3532596]|0;c[2112932]=ao;an=c[3532592]|0;if((an|0)!=0){gGC(9104152,an|0,280)|0}c[2113054]=c[2113060];av=ao}ao=c[2388162]|0;an=av|0;ah=0;while(1){al=ao+ah|0;c[an>>2]=al;c[an+131072>>2]=al;al=ah+1024|0;if(al>>>0>524287){break}else{an=an+4|0;ah=al}}ah=c[2388288]|0;an=av+2048|0;ao=524288;while(1){al=ah+(ao-524288)|0;c[an>>2]=al;c[an+65536>>2]=al;c[an+131072>>2]=al;al=ao+1024|0;if(al>>>0>569343){break}else{an=an+4|0;ao=al}}ao=c[2386464]|0;c[av+2224>>2]=ao;c[av+67760>>2]=ao;c[av+133296>>2]=ao;an=ao+1024|0;c[av+2228>>2]=an;c[av+67764>>2]=an;c[av+133300>>2]=an;an=ao+2048|0;c[av+2232>>2]=an;c[av+67768>>2]=an;c[av+133304>>2]=an;an=ao+3072|0;c[av+2236>>2]=an;c[av+67772>>2]=an;c[av+133308>>2]=an;an=c[2406568]|0;c[av+2240>>2]=an;c[av+67776>>2]=an;c[av+133312>>2]=an;ao=an+1024|0;c[av+2244>>2]=ao;c[av+67780>>2]=ao;c[av+133316>>2]=ao;ao=an+2048|0;c[av+2248>>2]=ao;c[av+67784>>2]=ao;c[av+133320>>2]=ao;ao=an+3072|0;c[av+2252>>2]=ao;c[av+67788>>2]=ao;c[av+133324>>2]=ao;ao=c[2406490]|0;c[av+2256>>2]=ao;c[av+67792>>2]=ao;c[av+133328>>2]=ao;an=ao+1024|0;c[av+2260>>2]=an;c[av+67796>>2]=an;c[av+133332>>2]=an;an=c[2405798]|0;c[av+2264>>2]=an;c[av+67800>>2]=an;c[av+133336>>2]=an;ao=an+1024|0;c[av+2268>>2]=ao;c[av+67804>>2]=ao;c[av+133340>>2]=ao;ao=an+2048|0;c[av+2272>>2]=ao;c[av+67808>>2]=ao;c[av+133344>>2]=ao;ao=an+3072|0;c[av+2276>>2]=ao;c[av+67812>>2]=ao;c[av+133348>>2]=ao;ao=c[2387206]|0;c[av+2280>>2]=ao;c[av+67816>>2]=ao;c[av+133352>>2]=ao;an=ao+1024|0;c[av+2284>>2]=an;c[av+67820>>2]=an;c[av+133356>>2]=an;an=ao+2048|0;c[av+2288>>2]=an;c[av+67824>>2]=an;c[av+133360>>2]=an;an=ao+3072|0;c[av+2292>>2]=an;c[av+67828>>2]=an;c[av+133364>>2]=an;an=ah+45056|0;c[av+2296>>2]=an;c[av+67832>>2]=an;c[av+133368>>2]=an;an=ah+46080|0;c[av+2300>>2]=an;c[av+67836>>2]=an;c[av+133372>>2]=an;c[av+196648>>2]=174;c[av+196728>>2]=2646;c[av+196608>>2]=1162;c[av+196688>>2]=2686;an=c[3532592]|0;if((an|0)!=0){gGC(an|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1}Tz(0,0,7575);an=c[642608+(c[2436]<<2)>>2]|0;ao=c[an+128>>2]|0;if((c[an+52>>2]&4|0)==0){c[2113068]=ao;al=c[an+132>>2]|0;c[2113070]=al;c[2443814]=ao;c[2440436]=al;aw=ao;ax=al}else{c[2113070]=ao;al=c[an+132>>2]|0;c[2113068]=al;c[2440436]=ao;c[2443814]=al;aw=al;ax=ao}ao=ag(aw<<1,ax)|0;al=gGq(ao)|0;c[2112926]=al;if((al|0)!=0){gGz(al|0,0,ao|0)}a[9624240]=0;ao=c[2414676]|0;gGz(ao|0,0,(c[2411678]|0)-ao|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];ao=c[3532592]|0;if((ao|0)!=0){gGC(9104152,ao|0,280)|0}c[2113054]=c[2113060]}RI();ao=c[2394]|0;al=c[14130368+(ao<<2)>>2]|0;if((al|0)!=0){gGC(al|0,9104152,280)|0}c[8452240+(ao<<2)>>2]=c[2113054];c[2394]=-1;Ty();am=0;i=b;return am|0}}while(0);c[2414972]=0;am=1;i=b;return am|0}function d1W(){var a=0,b=0,d=0,e=0,f=0;c[2113070]=0;c[2113068]=0;a=c[2112926]|0;if((a|0)!=0){gGr(a);c[2112926]=0}if((c[2392]|0)>=0){a=0;do{b=14130368+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}b=14130384+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}a=a+1|0;}while((a|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;TE();a=c[2414972]|0;b=0;while(1){if((b|0)>=1024){e=41209;break}f=9638528+(b<<2)|0;if((c[f>>2]|0)==(a|0)){break}else{b=b+1|0}}if((e|0)==41209){c[2414972]=0;c[2443928]=0;return 0}gGr(a);c[f>>2]=0;c[2414972]=0;c[2443928]=0;return 0}function d1X(){var e=0,f=0,g=0,h=0,i=0,j=0;if((a[9624240]|0)!=0){a[9624240]=0;e=c[2414676]|0;gGz(e|0,0,(c[2411678]|0)-e|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060]}RI();e=c[2394]|0;f=c[14130368+(e<<2)>>2]|0;if((f|0)!=0){gGC(f|0,9104152,280)|0}c[8452240+(e<<2)>>2]=c[2113054];c[2394]=-1;Ty()}e=c[2385548]|0;if((e|0)>0){gGz(9752472,0,((e|0)>1?e<<2:4)|0)}c[2433530]=0;gGz(9550528,-1|0,6);e=0;f=-1;g=-1;do{f=((a[9631384+e|0]&1)<<e^f&65535)&65535;g=((a[9629592+e|0]&1)<<e^g&65535)&65535;e=e+1|0;}while((e|0)<16);b[4775265]=f;b[4775266]=g;if((c[2443928]|0)==2){g=c[2388288]|0;b[g+45056>>1]=d[9635129]<<8|d[9635128];b[g+45058>>1]=b[4775265]|0;b[g+45060>>1]=b[4775266]|0}c[2110938]=d[9633529]<<1|d[9633528];if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060]}g=c[2439330]|0;if((g|0)!=0){f=g;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;f=0;do{c[2113056]=166;g=RG(166)|0;c[2113054]=(c[2113054]|0)+g;c[2276108]=-1;c[2113056]=-1;f=f+1|0;UF(f*59|0)|0;}while((f|0)<1e3);f=c[2443928]|0;do{if((f|0)==0){c[8452200+(c[2394]<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0>=1024){break}RH(4);h=c[2443928]|0;i=41236}else{h=f;i=41236}}while(0);do{if((i|0)==41236){if((h|0)==1){c[8452200+(c[2394]<<2)>>2]=8194;c[2276080]=512;if((c[2276079]|0)>>>0>=512){break}RH(2);j=c[2443928]|0}else{j=h}if((j|0)!=2){break}c[8452200+(c[2394]<<2)>>2]=8198;c[2276080]=1536;if((c[2276079]|0)>>>0>=1536){break}RH(6)}}while(0);j=c[2438224]|0;h=gGS(-1597636608,28447,j,(j|0)<0|0?-1:0)|0;j=h;UF(59659)|0;h=c[2443826]|0;if((h|0)<1073676288){c[2443826]=h-j}h=c[2443827]|0;if((h|0)<1073676288){c[2443827]=h-j}h=(c[3528508]|0)-j|0;c[3528508]=(h|0)<0?0:h;h=c[2112964]|0;if((h|0)!=0){j=a[9688]|0?534:0;i=c[2438058]&3;if((i|0)==2){gg[c[3542122]&4095](h,j)}else if((i|0)==0){gg[c[3542112]&4095](h,j)}else if((i|0)==1){gg[c[3542124]&4095](h,j)}if((c[2438058]&4|0)!=0){Uu(1,h,j)}Uu(0,h,j)}j=c[1836236]|0;h=c[9757320+(j<<2)>>2]|0;if((h|0)!=0){i=h;gGC(i|0,9706056,76)|0}c[9752472+(j<<2)>>2]=c[2433530];c[14113936+(j<<2)>>2]=c[2076596];c[9669104+(j<<2)>>2]=c[3541536];c[1836236]=-1;j=c[2394]|0;i=c[14130368+(j<<2)>>2]|0;if((i|0)!=0){gGC(i|0,9104152,280)|0}c[8452240+(j<<2)>>2]=c[2113054];c[2394]=-1;if((c[2112968]|0)==0){return 0}d1Y()|0;return 0}function d1Y(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((a[9547496]|0)!=0){d=c[2387206]|0;f=c[3530020]|0;g=0;do{h=b[d+(g<<1)>>1]|0;i=h&255;j=(h&65535)>>>4;k=(h&65535)>>>8;c[f+(g<<2)>>2]=((k&8|k<<4&255)&255)>>>3|((i&8|i<<4)&255)<<8&63488|((j&12|j<<4&255)&255)<<3&2016;g=g+1|0;}while((g|0)<2048)}g=c[2443472]|0;f=16>>>((c[2443928]&1)>>>0);d=b[g+(f<<1)>>1]&511;j=c[2406568]|0;i=-16-(b[g+(f+1<<1)>>1]&255)|0;k=c[3530612]|0;h=c[2112926]|0;l=c[2113068]|0;m=c[2113070]|0;n=0;do{o=(n<<4&496)-d|0;p=(o|0)<-15?o+512|0:o;o=(n>>5<<4)+i|0;q=(o|0)<-15?o+256|0:o;if((p|0)<(l|0)&(q|0)<(m|0)){o=e[j+(n<<1)>>1]|0;Sz(h,o&4095,p,q,o>>>12,4,1024,k)}n=n+1|0;}while((n|0)<512);d16(1);n=b[g+(f+2<<1)>>1]&511;j=c[2406490]|0;i=-16-(b[g+(f+3<<1)>>1]&255)|0;f=0;do{g=(f<<4&496)-n|0;d=(g|0)<-15?g+512|0:g;g=(f>>5<<4)+i|0;o=(g|0)<-15?g+256|0:g;if((d|0)<(l|0)&(o|0)<(m|0)){g=e[j+(f<<1)>>1]|0;SH(h,g&4095|4096,d,o,g>>>12,4,15,1280,k)}f=f+1|0;}while((f|0)<512);d16(0);f=c[2405798]|0;k=c[3530848]|0;j=64;do{m=e[f+(j<<1)>>1]|0;l=m&4095;if((l|0)!=0){Sq(h,l,j<<3&248,(j>>5<<3)-16|0,m>>>12,4,15,1792,k)}j=j+1|0;}while((j|0)<960);R8(c[3530020]|0);return 0}function d1Z(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=i;i=i+64|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;if((d|0)!=0){c[d>>2]=169734}if((b&32|0)!=0){gGz(j|0,0,12);k=c[2414676]|0;c[j>>2]=k;c[j+4>>2]=(c[2411678]|0)-k;c[j+12>>2]=162152;k=c[2076592]|0;gj[k&4095](j)|0}if((b&64|0)==0){i=e;return 0}j=h|0;gGz(g|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){k=h+9|0;h=f;l=f|0;m=f+4|0;n=f+12|0;o=g|0;p=g+4|0;q=g+12|0;r=0;do{gGC(j|0,614896,11)|0;a[k]=r+48&255;s=8452256+(r<<2)|0;gGz(h|0,0,12);c[l>>2]=s;c[m>>2]=4;c[n>>2]=164976;gj[c[2076592]&4095](f)|0;if((c[s>>2]|0)!=0){c[o>>2]=c[14130368+(r<<2)>>2];c[p>>2]=c[8452184+(r<<2)>>2];c[q>>2]=j;s=c[2076592]|0;gj[s&4095](g)|0}r=r+1|0;}while((r|0)<=(c[2392]|0))}TF(d,b);i=e;return 0}function d1_(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1609340+(b*112|0)>>2];c[a+104>>2]=c[1609344+(b*112|0)>>2];c[a+108>>2]=c[1609348+(b*112|0)>>2];d=0;return d|0}function d1$(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=1609240+(b*112|0);e=0;return e|0}function d10(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1608220+(b*112|0)>>2];c[a+104>>2]=c[1608224+(b*112|0)>>2];c[a+108>>2]=c[1608228+(b*112|0)>>2];d=0;return d|0}function d11(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=1608120+(b*112|0);e=0;return e|0}function d12(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2268236+(b*112|0)>>2];c[a+104>>2]=c[2268240+(b*112|0)>>2];c[a+108>>2]=c[2268244+(b*112|0)>>2];d=0;return d|0}function d13(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=2268136+(b*112|0);e=0;return e|0}function d14(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1193432+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function d15(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>79){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3437656+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function d16(a){a=a|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;d=c[2386464]|0;f=c[2112926]|0;g=c[3530434]|0;h=2044;do{i=e[d+(h<<1)>>1]|0;do{if((i&32768|0)==0){if((i>>>11&1|0)!=(a|0)){break}j=i>>>7&7;k=i>>>4&7;l=e[d+((h|2)<<1)>>1]|0;m=l&511;n=e[d+((h|3)<<1)>>1]|0;o=n&511;p=m>>>0>255?l|-512:m;m=(o>>>0>255?n|-512:o)-16|0;o=i&15;n=(i&16384|0)==0;l=(i&8192|0)!=0;q=b[d+((h|1)<<1)>>1]&8191;r=0;while(1){s=(j-r<<4)+p|0;t=(r<<4)+p|0;if(n){u=q;v=0;while(1){w=(v<<4)+m|0;if(l){SJ(f,u,s,w,o,4,15,0,g)}else{SH(f,u,t,w,o,4,15,0,g)}w=u+1&8191;x=v+1|0;if((x|0)>(k|0)){y=w;break}else{u=w;v=x}}}else{v=q;u=0;while(1){x=(k-u<<4)+m|0;if(l){SN(f,v,s,x,o,4,15,0,g)}else{SL(f,v,t,x,o,4,15,0,g)}x=v+1&8191;w=u+1|0;if((w|0)>(k|0)){y=x;break}else{v=x;u=w}}}u=r+1|0;if((u|0)>(j|0)){break}else{q=y;r=u}}}}while(0);h=h-4|0;}while((h|0)>-1);return}function d17(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=0;while(1){if((b|0)>=1024){e=41398;break}f=9638528+(b<<2)|0;if((c[f>>2]|0)==0){break}else{b=b+1|0}}if((e|0)==41398){return}b=gGq(1048576)|0;c[f>>2]=b;if((b|0)==0){return}gGz(b|0,0,1048576);f=c[3530848]|0;gGC(b|0,f|0,131072)|0;g=0;do{h=g<<6;gGz(f+h|0,0,64);i=g<<7;j=0;do{k=1<<3-j;l=(c[611488+(j<<2)>>2]|0)+i|0;m=0;do{n=l+(c[6669224+(m<<2)>>2]|0)|0;o=(m<<3)+h|0;p=0;do{q=n+(c[6669320+(p<<2)>>2]|0)|0;if(((d[b+((q|0)/8|0)|0]|0)&128>>>((q&7)>>>0)|0)!=0){q=f+(o+p)|0;a[q]=(d[q]|0|k)&255}p=p+1|0;}while((p|0)<8);m=m+1|0;}while((m|0)<8);j=j+1|0;}while((j|0)<4);g=g+1|0;}while((g|0)<4096);g=c[3530612]|0;gGC(b|0,g|0,1048576)|0;f=0;do{j=f<<8;gGz(g+j|0,0,256);h=f<<10;i=0;do{m=1<<3-i;k=(c[611264+(i<<2)>>2]|0)+h|0;l=0;do{p=k+(c[611840+(l<<2)>>2]|0)|0;o=(l<<4)+j|0;n=0;do{q=p+(c[609712+(n<<2)>>2]|0)|0;if(((d[b+((q|0)/8|0)|0]|0)&128>>>((q&7)>>>0)|0)!=0){q=g+(o+n)|0;a[q]=(d[q]|0|m)&255}n=n+1|0;}while((n|0)<16);l=l+1|0;}while((l|0)<16);i=i+1|0;}while((i|0)<4);f=f+1|0;}while((f|0)<8192);f=c[3530434]|0;gGC(b|0,f|0,1048576)|0;g=0;while(1){i=g<<8;gGz(f+i|0,0,256);j=g<<10;h=0;do{l=1<<3-h;m=(c[611264+(h<<2)>>2]|0)+j|0;k=0;do{n=m+(c[611840+(k<<2)>>2]|0)|0;o=(k<<4)+i|0;p=0;do{q=n+(c[609712+(p<<2)>>2]|0)|0;if(((d[b+((q|0)/8|0)|0]|0)&128>>>((q&7)>>>0)|0)!=0){q=f+(o+p)|0;a[q]=(d[q]|0|l)&255}p=p+1|0;}while((p|0)<16);k=k+1|0;}while((k|0)<16);h=h+1|0;}while((h|0)<4);h=g+1|0;if((h|0)<8192){g=h}else{r=0;break}}while(1){if((r|0)>=1024){e=41399;break}s=9638528+(r<<2)|0;if((c[s>>2]|0)==(b|0)){break}else{r=r+1|0}}if((e|0)==41399){return}gGr(b);c[s>>2]=0;return}function d18(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;gGz(9771920,0,1204);c[2442985]=1;c[2442980]=c[3541150];b=c[3541518]|0;a[b+304|0]=47;a[b+312|0]=0;lI(b+256|0,24,24,1);d=0;e=b;while(1){b=a[619696+d|0]|0;f=c[2442983]|0;g=d|1;h=e+(f*19024|0)+256|0;a[e+(f*19024|0)+304|0]=b;i=b&255;if((b&255)<16){c[14168912+(((c[2383582]|0)+f|0)*252|0)>>2]=i&15}if((b-45&255)<3){if((i|0)==46){b=e+(f*19024|0)+312|0;j=a[b]|1;a[b]=j;k=j}else if((i|0)==0){a[e+(f*19024|0)+312|0]=2;k=2}else if((i|0)==45){j=e+(f*19024|0)+312|0;b=a[j]|2;a[j]=b;k=b}else if((i|0)==47){a[e+(f*19024|0)+312|0]=0;k=0}else{k=a[e+(f*19024|0)+312|0]|0}f=k&3;i=c[7461744+(f<<2)>>2]|0;lI(h,i,i,c[7461728+(f<<2)>>2]|0)}f=d+2|0;lS(c[2442983]|0,1,a[619696+g|0]|0);if((f|0)==46){break}d=f;e=c[3541518]|0}a[9771945]=0;d19(0);c[2442982]=0;return}function d19(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=c[2442980]|0;if((b&128|0)==0){f=(d[e+61409|0]|0)<<8|(d[e+61408|0]|0)}else{f=(d[e+61411|0]|0)<<8|(d[e+61410|0]|0)}g=(f&65535)+(b<<1&254)|0;b=a[e+g|0]|0;f=b&255;h=f>>>7;i=(h|0)!=0?c[2442985]|0:c[2442984]|0;if((f&127|0)==0){Uv(i,120);return}f=d[e+(g+1)|0]|0;g=f&3;e=a[9771945]|0;do{if((f&128|0)==0){j=e&255;k=1<<(g|h<<2);if((k&j|0)==0){l=k;m=j;break}return}else{l=1<<(g|h<<2);m=e&255}}while(0);a[9771945]=(l|m)&255;Uv(i,8<<g&255);m=(h|0)==0?c[3541154]|0:c[3541152]|0;h=f>>>2&3;if((h|0)!=3){l=m+131072|0;e=m+((h<<17)+262144)|0;gGC(l|0,e|0,131072)|0}Uv(i,b|-128);Uv(i,(16<<g|f>>>4&7)&255);return}function d2a(a){a=a|0;var c=0,e=0;c=a-6291456|0;do{if(c>>>0<4){e=d[9635120+(c>>>1^1)|0]|0}else{if((a|0)==11534336){e=b[4775256]|0;break}else if((a|0)==11534340){e=b[4775258]^255^(d[9635122]|0);break}else if((a|0)==11534338){e=b[4775257]|0;break}else{e=0;break}}}while(0);return e|0}function d2b(c){c=c|0;var d=0,e=0;d=c-6291456|0;L54859:do{if(d>>>0<4){e=a[9635120+(d>>>1^1)|0]|0}else{switch(c|0){case 11534340:case 11534341:{e=a[9635122]^~(b[4775258]&255);break L54859;break};case 11534338:case 11534339:{e=b[4775257]&255;break L54859;break};case 11534336:case 11534337:{e=b[4775256]&255;break L54859;break};default:{e=0;break L54859}}}}while(0);return e|0}function d2c(a,d){a=a|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;if((a-8388608|0)>>>0<6){b[(c[2438730]|0)+(a&6)>>1]=d;return}if((a-5242880|0)>>>0>=6){return}b[(c[2443352]|0)+(a&6)>>1]=d;if((a|0)==5242882){e=(d&65535)>>>3&7;if((e|0)==(c[2430248]|0)){return}f=c[2387027]|0;c[2430248]=e;if((f|0)==4194304){g=c[2386648]|0;h=g+524288|0;i=g+((e|0)==0?1048576:(e<<19)+524288|0)|0;gGC(h|0,i|0,524288)|0;return}else if((f|0)==2097152|(f|0)==1572864){i=e<<18;h=e>>>0>2?i+262144|0:i;if((h+262144|0)>(f|0)){return}f=c[2386648]|0;i=f+786432|0;e=f+h|0;gGC(i|0,e|0,262144)|0;return}else{return}}else if((a|0)==5242880){c[(c[2076600]|0)+8>>2]=d&32;return}else{return}}function d2d(b,d){b=b|0;d=d|0;if((b-8388608|0)>>>0<6){a[(c[2438730]|0)+(b&7^1)|0]=d;return}if((b-5242880|0)>>>0>=6){return}a[(c[2443352]|0)+(b&7^1)|0]=d;return}function d2e(a){a=a|0;var c=0,e=0;c=a-6291456|0;L54902:do{if(c>>>0<4){e=d[9635120+(c>>>1^1)|0]|0}else{switch(a|0){case 11534338:case 11534339:{e=b[4775257]|0;break L54902;break};case 11534344:case 11534345:{e=b[4775259]|0;break L54902;break};case 11534336:case 11534337:{e=b[4775256]|0;break L54902;break};case 11534340:case 11534341:{e=b[4775258]^255^(d[9635122]|0);break L54902;break};case 11534346:case 11534347:{e=b[4775260]|0;break L54902;break};case 11534348:case 11534349:{e=221;break L54902;break};default:{e=0;break L54902}}}}while(0);return e|0}function d2f(c){c=c|0;var d=0,e=0;d=c-6291456|0;L54914:do{if(d>>>0<4){e=a[9635120+(d>>>1^1)|0]|0}else{switch(c|0){case 11534346:case 11534347:{e=b[4775260]&255;break L54914;break};case 11534338:case 11534339:{e=b[4775257]&255;break L54914;break};case 11534344:case 11534345:{e=b[4775259]&255;break L54914;break};case 11534336:case 11534337:{e=b[4775256]&255;break L54914;break};case 11534340:case 11534341:{e=a[9635122]^~(b[4775258]&255);break L54914;break};case 11534348:case 11534349:{e=-35;break L54914;break};default:{e=0;break L54914}}}}while(0);return e|0}function d2g(a,d){a=a|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;if((a-5242880|0)>>>0>=6){return}b[(c[2443352]|0)+(a&6)>>1]=d;if((a|0)==5242882){e=(d&65535)>>>3&7;if((e|0)==(c[2430248]|0)){return}f=c[2387027]|0;c[2430248]=e;if((f|0)==2097152|(f|0)==1572864){g=e<<18;h=e>>>0>2?g+262144|0:g;if((h+262144|0)>(f|0)){return}g=c[2386648]|0;i=g+786432|0;j=g+h|0;gGC(i|0,j|0,262144)|0;return}else if((f|0)==4194304){f=c[2386648]|0;j=f+524288|0;i=f+((e|0)==0?1048576:(e<<19)+524288|0)|0;gGC(j|0,i|0,524288)|0;return}else{return}}else if((a|0)==5242880){c[(c[2076600]|0)+8>>2]=d&32;return}else{return}}function d2h(b,d){b=b|0;d=d|0;if((b-5242880|0)>>>0>=6){return}a[(c[2443352]|0)+(b&7^1)|0]=d;return}function d2i(a){a=a|0;var e=0,f=0,g=0;e=a-3145728|0;do{if(e>>>0<4){f=d[9635120+(e>>>1^1)|0]|0}else{g=a-4194312|0;if(g>>>0<4){f=d[9635120+(g>>>1^1)|0]|0;break}g=a-6291456|0;if(g>>>0<4){f=d[9635120+(g>>>1^1)|0]|0;break}if((a|0)==4194306){f=b[4775257]|0;break}else if((a|0)==4194308){f=b[4775258]^255^(d[9635122]|0);break}else if((a|0)==4194316){c[2388366]=0;f=255;break}else if((a|0)==4194304){f=b[4775256]|0;break}else if((a|0)==5242886){f=b[4775259]|0;break}else{f=0;break}}}while(0);return f|0}function d2j(d){d=d|0;var e=0,f=0,g=0;e=d-3145728|0;do{if(e>>>0<4){f=a[9635120+(e>>>1^1)|0]|0}else{g=d-4194312|0;if(g>>>0<4){f=a[9635120+(g>>>1^1)|0]|0;break}g=d-6291456|0;if(g>>>0<4){f=a[9635120+(g>>>1^1)|0]|0;break}if((d|0)==4194316|(d|0)==4194317){c[2388366]=0;f=-1;break}else if((d|0)==5242886|(d|0)==5242887){f=b[4775259]&255;break}else if((d|0)==4194306|(d|0)==4194307){f=b[4775257]&255;break}else if((d|0)==4194304|(d|0)==4194305){f=b[4775256]&255;break}else if((d|0)==4194308|(d|0)==4194309){f=a[9635122]^~(b[4775258]&255);break}else{f=0;break}}}while(0);return f|0}function d2k(a,d){a=a|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;if((a-5242880|0)>>>0<6){b[(c[2443352]|0)+(a&6)>>1]=d;if((a|0)==5242882){e=(d&65535)>>>3&7;if((e|0)==(c[2430248]|0)){return}f=c[2387027]|0;c[2430248]=e;if((f|0)==4194304){g=c[2386648]|0;h=g+524288|0;i=g+((e|0)==0?1048576:(e<<19)+524288|0)|0;gGC(h|0,i|0,524288)|0;return}else if((f|0)==2097152|(f|0)==1572864){i=e<<18;h=e>>>0>2?i+262144|0:i;if((h+262144|0)>(f|0)){return}f=c[2386648]|0;i=f+786432|0;e=f+h|0;gGC(i|0,e|0,262144)|0;return}else{return}}else if((a|0)==5242880){c[(c[2076600]|0)+8>>2]=d&32;return}else{return}}if((a-9437184|0)>>>0<6){b[(c[2438730]|0)+(a&6)>>1]=d;return}if((a-9469952|0)>>>0<6){b[(c[2438730]|0)+(a&6)>>1]=d;return}if((a-10485760|0)>>>0<6){b[(c[2438730]|0)+(a&6)>>1]=d;return}if((a-9961472|0)>>>0<6){b[(c[2438728]|0)+(a&6)>>1]=d;return}if((a-9474048|0)>>>0<6){b[(c[2438728]|0)+(a&6)>>1]=d;return}if((a-11010048|0)>>>0<6){b[(c[2438728]|0)+(a&6)>>1]=d;return}if(!((a|0)==4194304|(a|0)==4194316)){return}c[2388366]=0;return}function d2l(b,d){b=b|0;d=d|0;if((b-5242880|0)>>>0<6){a[(c[2443352]|0)+(b&7^1)|0]=d;return}if((b-9437184|0)>>>0<6){a[(c[2438730]|0)+(b&7^1)|0]=d;return}if((b-9469952|0)>>>0<6){a[(c[2438730]|0)+(b&7^1)|0]=d;return}if((b-10485760|0)>>>0<6){a[(c[2438730]|0)+(b&7^1)|0]=d;return}if((b-9961472|0)>>>0<6){a[(c[2438728]|0)+(b&7^1)|0]=d;return}if((b-9474048|0)>>>0<6){a[(c[2438728]|0)+(b&7^1)|0]=d;return}if((b-11010048|0)>>>0<6){a[(c[2438728]|0)+(b&7^1)|0]=d;return}if(!((b|0)==4194304|(b|0)==4194305|(b|0)==4194316|(b|0)==4194317)){return}c[2388366]=0;return}function d2m(a,d){a=a|0;d=d|0;if((a-11534336|0)>>>0<6){b[(c[2438730]|0)+(a&6)>>1]=d;return}if((a-12058624|0)>>>0<6){b[(c[2438728]|0)+(a&6)>>1]=d;return}switch(a|0){case 5242882:case 5242883:{b[(c[2443352]|0)+4>>1]=d;return};case 5242880:case 5242881:{b[c[2443352]>>1]=d;return};case 5242884:case 5242885:{b[(c[2443352]|0)+2>>1]=d;return};default:{return}}}function d2n(b,d){b=b|0;d=d|0;if((b-11534336|0)>>>0<6){a[(c[2438730]|0)+(b&7^1)|0]=d;return}if((b-12058624|0)>>>0<6){a[(c[2438728]|0)+(b&7^1)|0]=d;return}switch(b|0){case 5242880:case 5242881:{a[(c[2443352]|0)+(b&1^1)|0]=d;return};case 5242882:case 5242883:{a[(c[2443352]|0)+(b&1^5)|0]=d;return};case 5242884:case 5242885:{a[(c[2443352]|0)+(b&1^3)|0]=d;return};default:{return}}}function d2o(a){a=a|0;var c=0,e=0;c=a-5242884|0;do{if(c>>>0<4){e=d[9635120+(c>>>1^1)|0]|0}else{if((a|0)==5242889){e=b[4775258]^255^(d[9635122]|0);break}else if((a|0)==5242882){e=b[4775257]|0;break}else if((a|0)==5242892){e=-1;break}else if((a|0)==5242880){e=b[4775256]|0;break}else{e=0;break}}}while(0);return e|0}function d2p(c){c=c|0;var d=0,e=0;d=c-5242884|0;L55112:do{if(d>>>0<4){e=a[9635120+(d>>>1^1)|0]|0}else{switch(c|0){case 5242892:case 5242893:{e=-1;break L55112;break};case 5242880:case 5242881:{e=b[4775256]&255;break L55112;break};case 5242882:case 5242883:{e=b[4775257]&255;break L55112;break};case 5242889:case 5242890:{e=a[9635122]^~(b[4775258]&255);break L55112;break};default:{e=0;break L55112}}}}while(0);return e|0}function d2q(a){a=a|0;var e=0,f=0,g=0;e=a-3145728|0;do{if(e>>>0<4){f=d[9635120+(e>>>1^1)|0]|0}else{g=a-5242888|0;if(g>>>0<4){f=d[9635120+(g>>>1^1)|0]|0;break}if((a|0)==5242884){f=b[4775258]^255^(d[9635122]|0);break}else if((a|0)==5242880){f=b[4775256]|0;break}else if((a|0)==5242892){c[2388366]=0;f=-1;break}else if((a|0)==5242882){f=b[4775257]|0;break}else{if((a&-16|0)!=6291456){f=0;break}g=a>>>1&7;if((g|0)==7){f=8;break}else if((g|0)==1){f=8;break}else if((g|0)==5){f=8;break}else if((g|0)==3){f=8;break}else{f=0;break}}}}while(0);return f|0}function d2r(d){d=d|0;var e=0,f=0,g=0;e=d-3145728|0;L55142:do{if(e>>>0<4){f=a[9635120+(e>>>1^1)|0]|0}else{g=d-5242888|0;if(g>>>0<4){f=a[9635120+(g>>>1^1)|0]|0;break}switch(d|0){case 5242882:case 5242883:{f=b[4775257]&255;break L55142;break};case 5242884:case 5242885:{f=a[9635122]^~(b[4775258]&255);break L55142;break};case 5242880:case 5242881:{f=b[4775256]&255;break L55142;break};case 5242892:case 5242893:{c[2388366]=0;f=-1;break L55142;break};default:{if((d&-16|0)!=6291456){f=0;break L55142}g=d>>>1&7;if((g|0)==3){f=8;break L55142}else if((g|0)==1){f=8;break L55142}else if((g|0)==5){f=8;break L55142}else if((g|0)==7){f=8;break L55142}else{f=0;break L55142}}}}}while(0);return f|0}function d2s(a,d){a=a|0;d=d|0;var e=0,f=0,g=0;if((a-6291456|0)>>>0>=6){if((a-9437184|0)>>>0<6){b[(c[2438730]|0)+(a&6)>>1]=d;return}if((a-9961472|0)>>>0<6){b[(c[2438728]|0)+(a&6)>>1]=d;return}if((a|0)!=5242892){return}c[2388366]=0;return}b[(c[2443352]|0)+(a&6)>>1]=d;if((a|0)==6291456){c[(c[2076600]|0)+8>>2]=d&32;return}else if((a|0)==6291458){a=(d&65535)>>>3&7;if((a|0)==(c[2430248]|0)){return}d=c[2387027]|0;c[2430248]=a;if((d|0)==4194304){e=c[2386648]|0;f=e+524288|0;g=e+((a|0)==0?1048576:(a<<19)+524288|0)|0;gGC(f|0,g|0,524288)|0;return}else if((d|0)==2097152|(d|0)==1572864){g=a<<18;f=a>>>0>2?g+262144|0:g;if((f+262144|0)>(d|0)){return}d=c[2386648]|0;g=d+786432|0;a=d+f|0;gGC(g|0,a|0,262144)|0;return}else{return}}else{return}}function d2t(b,d){b=b|0;d=d|0;if((b-6291456|0)>>>0<6){a[(c[2443352]|0)+(b&7^1)|0]=d;return}if((b-9437184|0)>>>0<6){a[(c[2438730]|0)+(b&7^1)|0]=d;return}if((b-9961472|0)>>>0<6){a[(c[2438728]|0)+(b&7^1)|0]=d;return}if((b-5242892|0)>>>0>=2){return}c[2388366]=0;return}function d2u(a){a=a|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=a-3145728|0;if(f>>>0<4){g=d[9635120+(f>>>1^1)|0]|0;return g|0}if((a|0)==5242884){f=(e[4775258]|0)^255^(d[9635122]|0);h=c[2430468]|0;i=c[200284]|0;do{if((h|0)==1&(i|0)!=-1){if(((c[2113222]|0)-i|0)<=2){j=41732;break}c[2430468]=2;c[200284]=-1;k=f&65535}else{j=41732}}while(0);do{if((j|0)==41732){i=f&65535;if((h|0)==2){k=i;break}else{g=i}return g|0}}while(0);c[2430468]=0;g=k&-3;return g|0}else if((a|0)==2097152){c[2426996]=0;g=0;return g|0}else if((a|0)==1048576){k=c[2426996]|0;h=b[685088+(k<<1)>>1]|0;f=k+1|0;c[2426996]=(f|0)>15?15:f;g=h;return g|0}else if((a|0)==5242880){g=b[4775256]|0;return g|0}else if((a|0)==5242882){g=b[4775257]|0;return g|0}else{if((a&-512|0)!=9437184){g=0;return g|0}h=a>>>1&255;a=9721024+(h<<1)|0;f=b[a>>1]|0;b[a>>1]=b[9708368+(h<<1)>>1]|0;g=f;return g|0}return 0}function d2v(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;g=f-3145728|0;if(g>>>0<4){h=a[9635120+(g>>>1^1)|0]|0;return h|0}if((f|0)==2097152|(f|0)==2097153){c[2426996]=0;h=0;return h|0}else if((f|0)==5242884|(f|0)==5242885){g=(e[4775258]|0)^255^(d[9635122]|0);i=c[2430468]|0;j=c[200284]|0;do{if((i|0)==1&(j|0)!=-1){if(((c[2113222]|0)-j|0)<=2){k=41756;break}c[2430468]=2;c[200284]=-1;l=g&255}else{k=41756}}while(0);do{if((k|0)==41756){j=g&255;if((i|0)==2){l=j;break}else{h=j}return h|0}}while(0);c[2430468]=0;h=l&-3;return h|0}else if((f|0)==5242882|(f|0)==5242883){h=b[4775257]&255;return h|0}else if((f|0)==1048576|(f|0)==1048577){l=c[2426996]|0;i=b[685088+(l<<1)>>1]|0;g=l+1|0;c[2426996]=(g|0)>15?15:g;h=i&255;return h|0}else if((f|0)==5242880|(f|0)==5242881){h=b[4775256]&255;return h|0}else{if((f&-512|0)!=9437184){h=0;return h|0}i=f>>>1&255;f=9721024+(i<<1)|0;g=b[f>>1]|0;b[f>>1]=b[9708368+(i<<1)>>1]|0;h=g&255;return h|0}return 0}function d2w(a,d){a=a|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;if((a-4194304|0)>>>0>=6){do{if((a|0)==9437186){if((d&16)==0|(c[2430468]|0)!=0){break}c[2430468]=1;c[200284]=c[2113222];e=41781}else{e=41781}}while(0);do{if((e|0)==41781){if((a&-512|0)==9437184){break}return}}while(0);e=a>>>1&255;f=9721024+(e<<1)|0;b[9708368+(e<<1)>>1]=b[f>>1]|0;b[f>>1]=d;return}b[(c[2443352]|0)+(a&6)>>1]=d;if((a|0)==4194306){f=(d&65535)>>>3&7;if((f|0)==(c[2430248]|0)){return}e=c[2387027]|0;c[2430248]=f;if((e|0)==4194304){g=c[2386648]|0;h=g+524288|0;i=g+((f|0)==0?1048576:(f<<19)+524288|0)|0;gGC(h|0,i|0,524288)|0;return}else if((e|0)==2097152|(e|0)==1572864){i=f<<18;h=f>>>0>2?i+262144|0:i;if((h+262144|0)>(e|0)){return}e=c[2386648]|0;i=e+786432|0;f=e+h|0;gGC(i|0,f|0,262144)|0;return}else{return}}else if((a|0)==4194304){c[(c[2076600]|0)+8>>2]=d&32;return}else{return}}function d2x(d,e){d=d|0;e=e|0;var f=0;if((d-4194304|0)>>>0<6){a[(c[2443352]|0)+(d&7^1)|0]=e;return}do{if((d-9437186|0)>>>0<2){if((e&16)==0|(c[2430468]|0)!=0){break}c[2430468]=1;c[200284]=c[2113222]}}while(0);if((d&-512|0)!=9437184){return}f=d>>>1&255;d=9721024+(f<<1)|0;b[9708368+(f<<1)>>1]=b[d>>1]|0;b[d>>1]=e&255;return}function d2y(a,d){a=a|0;d=d|0;if((a-8388608|0)>>>0>=6){return}b[(c[2438730]|0)+(a&6)>>1]=d;return}function d2z(b,d){b=b|0;d=d|0;if((b-8388608|0)>>>0<6){a[(c[2438730]|0)+(b&7^1)|0]=d;return}if((b-4194304|0)>>>0>=8){return}a[(c[2388460]|0)+(b>>>1&3)|0]=d;return}function d2A(a,b){a=a|0;b=b|0;var d=0;if((a&-2|0)!=15728640){return}a=b&65535;if((a&4|0)!=0){c[2384360]=0;return}b=a&1;d=c[2384358]|0;if((b|0)==(d|0)){return}if((d|0)==0){d=c[2384360]|0;if((d|0)==2){c[2439278]=c[2439278]&2|a>>>1}else if((d|0)==3){c[2439278]=c[2439278]&1|a&2}else if(!((d|0)==0|(d|0)==1)){c[2439280]=12-d}c[2384360]=d+1}c[2384358]=b;return}function d2B(a,b){a=a|0;b=b|0;var d=0;if((a&-2|0)!=15728640){return}a=b&255;if((a&4|0)!=0){c[2384360]=0;return}b=a&1;d=c[2384358]|0;if((b|0)==(d|0)){return}if((d|0)==0){d=c[2384360]|0;if((d|0)==2){c[2439278]=c[2439278]&2|a>>>1}else if((d|0)==3){c[2439278]=c[2439278]&1|a&2}else if(!((d|0)==0|(d|0)==1)){c[2439280]=12-d}c[2384360]=d+1}c[2384358]=b;return}function d2C(a){a=a|0;return(e[9755400+(c[2439278]<<1)>>1]|0)>>>((c[2439280]|0)>>>0)&1|0}function d2D(a){a=a|0;return(e[9755400+(c[2439278]<<1)>>1]|0)>>>((c[2439280]|0)>>>0)&1|0}function d2E(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0;if((b&65535)<=61439){return}e=c[2076600]|0;f=c[e+4>>2]^b&4095;b=f>>>3;g=e+12+f|0;do{if(f>>>0<128&(f&7|0)==0){if((a[g]&1)!=0){h=g;break}if((d&1)==0){h=g;break}c[e+16396+(b<<2)>>2]=0;c[e+16460+(b<<2)>>2]=0;h=g}else{h=g}}while(0);a[h]=d;return}function d2F(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=b>>>1&8191;f=c[2076600]|0;if((b&1|0)==0){a[f+8204+e|0]=d;return}b=c[f+4>>2]^e;e=b>>>3;g=f+12+b|0;do{if(b>>>0<128&(b&7|0)==0){if((a[g]&1)!=0){h=g;break}if((d&1)==0){h=g;break}c[f+16396+(e<<2)>>2]=0;c[f+16460+(e<<2)>>2]=0;h=g}else{h=g}}while(0);a[h]=d;return}function d2G(b){b=b|0;var d=0,e=0;if((b&65535)<=61439){d=0;return d|0}e=c[2076600]|0;d=a[(c[e+4>>2]^b&4095)+(e+12)|0]|0;return d|0}function d2H(a,b){a=a|0;b=b|0;var c=0;c=a&65535;if((c&252)>>>0>=4){return}md(0,c&3,b);return}function d2I(b){b=b|0;var d=0,e=0,f=0,g=0.0,i=0.0;d=b&65535;switch(d&255|0){case 192:{a[9706117]=0;e=a[c[3528280]|0]|0;return e|0};case 0:case 1:case 2:case 3:{b=d&3;d=c[3541512]|0;if((b|0)==0){f=d+552|0;g=+h[f>>3];do{if(g!=0.0){i=+h[6675];if(g-(i+ +gC[c[2429842]&255]())<=0.0){h[f>>3]=0.0;break}e=a[d+563|0]|-128;return e|0}}while(0);e=a[d+563|0]|0;return e|0}else if((b|0)==1|(b|0)==2|(b|0)==3){b=d+552|0;g=+h[b>>3];do{if(g!=0.0){i=+h[6675];if(g-(i+ +gC[c[2429842]&255]())<=0.0){h[b>>3]=0.0;break}e=a[d+563|0]|-128;return e|0}}while(0);e=a[d+563|0]|0;return e|0}else{e=0;return e|0}break};default:{e=0;return e|0}}return 0}function d2J(a,b){a=a|0;b=b|0;return}function d2K(b,d){b=b|0;d=d|0;if(!((b|0)==12582912|(b|0)==11534344)){return}a[c[3528280]|0]=d;a[9706117]=1;return}function d2L(a,b){a=a|0;b=b|0;if(a<<16>>16!=-26624){return}Uv(0,b);return}function d2M(b){b=b|0;var d=0,e=0;d=b&65535;if((d|0)==38912){e=c[2113156]&255}else if((d|0)==40960){a[9706117]=0;e=a[c[3528280]|0]|0}else{e=0}return e|0}function d2N(a){a=a|0;var e=0,f=0;do{if((a-4194304|0)>>>0<2){c[2388366]=0;e=-1}else{if((a&268435424|0)!=10485760){f=a-6291456|0;if(f>>>0>=4){e=0;break}e=d[9635120+(f>>>1^1)|0]|0;break}f=a&30;if((f|0)==0){e=b[4775256]|0;break}else if((f|0)==8){e=b[4775258]^255^(d[9635122]|0);break}else if((f|0)==24){e=-1;break}else if((f|0)==2){e=b[4775257]|0;break}else{e=0;break}}}while(0);return e|0}function d2O(e){e=e|0;var f=0,g=0,h=0;if((e|0)==4194304|(e|0)==4194305){c[2388366]=0;f=-1;return f|0}else if((e|0)==11534336|(e|0)==11534337){g=c[2384514]^128;c[2384514]=g;f=g&255;return f|0}else{if((e&268435424|0)!=10485760){g=e-6291456|0;if(g>>>0>=4){f=0;return f|0}f=a[9635120+(g>>>1^1)|0]|0;return f|0}g=e&30;if((g|0)==24){h=-1}else if((g|0)==8){h=b[4775258]^255^(d[9635122]|0)}else if((g|0)==0){h=b[4775256]|0}else if((g|0)==2){h=b[4775257]|0}else{h=0}f=(h&65535)>>>((e<<3&8^8)>>>0)&255;return f|0}return 0}function d2P(d,e){d=d|0;e=e|0;if((d-8388608|0)>>>0<6){b[(c[2438730]|0)+(d&6)>>1]=e;return}if((d&-2|0)!=11534336){return}a[c[3528280]|0]=e&255;return}function d2Q(b,d){b=b|0;d=d|0;if((b-8388608|0)>>>0<6){a[(c[2438730]|0)+(b&7^1)|0]=d;return}if((b&-2|0)!=11534336){return}a[c[3528280]|0]=d;return}function d2R(b){b=b|0;var d=0,e=0;d=c[2432966]|0;if((a[d+248|0]|0)!=-93){e=a[d+(b&511^1)|0]|0;return e|0}if((b-2097408|0)>>>0>=12){e=0;return e|0}e=a[279e3+(b>>>1&7)|0]|0;return e|0}function d2S(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=(e[4775256]|0)^65535;g=(e[4775257]|0)^65535;h=(e[4775258]|0)^65280^(d[9635122]|0);i=b&4094;if((i|0)==10){b=f>>>3&1;j=(f&4|0)==0?b:b|2;b=(f&1|0)==0?j:j|4;j=(f&2|0)==0?b:b|8;b=(f&16|0)==0?j:j|16;j=(f&32|0)!=0;k=j?(j?b|32:b)|64:b;b=(f&128|0)==0?k:k|-128;k=(b&12)==12?b&-13:b;b=c[3527304]|0;a[b+10|0]=(k&3)==3?k&-4:k;l=b;m=l+i|0;n=a[m]|0;return n|0}else if((i|0)==104){b=h&128;k=h&64;if((c[2384426]|0)!=(b|0)){j=(c[3527304]|0)+104|0;a[j]=(d[j]|0)+(b>>>7)&255}if((c[2384424]|0)==(k|0)){j=c[3527304]|0;o=j;p=a[j+104|0]|0}else{j=c[3527304]|0;q=j+104|0;r=(d[q]|0)+(k>>>6)&255;a[q]=r;o=j;p=r}if((p&255)>9){a[o+104|0]=9}c[2384426]=b;c[2384424]=k;a[614920]=1;l=o;m=l+i|0;n=a[m]|0;return n|0}else if((i|0)==20){o=c[3527304]|0;k=f&128;f=(k|0)!=0;b=f?4:0;p=g&128;r=(p|0)!=0;j=r?b|8:b;b=(h&32|0)==0?j:j|16;a[o+20|0]=(h&16|0)==0?b:b|32;do{if(!((k|0)==(c[2384422]|0)|f)){b=o+104|0;h=a[b]|0;if(!(h<<24>>24!=0&a[614920])){break}a[b]=h-1&255;a[614920]=0}}while(0);do{if(!((p|0)==(c[2384420]|0)|r)){f=o+104|0;h=a[f]|0;if(!(h<<24>>24!=0&a[614920])){break}a[f]=h-1&255;a[614920]=0}}while(0);c[2384422]=k;c[2384420]=p;l=o;m=l+i|0;n=a[m]|0;return n|0}else if((i|0)==16){o=g>>>3&1;p=(g&4|0)==0?o:o|2;o=(g&1|0)==0?p:p|4;p=(g&2|0)==0?o:o|8;o=(g&16|0)==0?p:p|16;p=(g&32|0)!=0;k=p?(p?o|32:o)|64:o;o=(g&128|0)==0?k:k|-128;k=(o&12)==12?o&-13:o;o=c[3527304]|0;a[o+16|0]=(k&3)==3?k&-4:k;l=o;m=l+i|0;n=a[m]|0;return n|0}else{l=c[3527304]|0;m=l+i|0;n=a[m]|0;return n|0}return 0}function d2T(a){a=a|0;return(d2S(a)|0)&255|0}function d2U(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=~(b[4775256]&255);h=~(b[4775257]&255);i=(e[4775258]|0)^65280^(d[9635122]|0);j=f&4094;L55532:do{switch(j|0){case 112:{k=i&128;l=i&64;if((c[2384418]|0)!=(k|0)){m=(c[3527304]|0)+112|0;a[m]=(d[m]|0)+(k>>>7)&255}if((c[2384416]|0)==(l|0)){m=c[3527304]|0;n=m;o=a[m+112|0]|0}else{m=c[3527304]|0;p=m+112|0;q=(d[p]|0)+(l>>>6)&255;a[p]=q;n=m;o=q}if((o&255)>9){a[n+112|0]=9}c[2384418]=k;c[2384416]=l;break};case 212:{l=(c[3527304]|0)+212|0;k=(i&16|0)==0;a[l]=k?-9:-25;if((i&32|0)==0){break L55532}a[l]=k?-41:-57;break};case 222:{k=c[3527304]|0;a[k+222|0]=-65;r=k;s=r+j|0;t=a[s]|0;return t|0};case 224:{k=h&255;l=h&1;q=(k&2|0)==0?l:l|2;l=(k&4|0)==0?q:q|4;q=(k&8|0)==0?l:l|8;l=(k&16|0)==0?q:q|16;q=(k&32|0)!=0;m=q?(q?l|32:l)|64:l;l=(k&128|0)==0?m:m|-128;m=(l&12)==12?l&-13:l;l=c[3527304]|0;a[l+224|0]=~((m&3)==3?m&-4:m);r=l;s=r+j|0;t=a[s]|0;return t|0};case 216:{l=g&255;m=g&1;k=(l&2|0)==0?m:m|2;m=(l&4|0)==0?k:k|4;k=(l&8|0)==0?m:m|8;m=(l&16|0)==0?k:k|16;k=(l&32|0)!=0;q=k?(k?m|32:m)|64:m;m=(l&128|0)==0?q:q|-128;q=(m&12)==12?m&-13:m;m=c[3527304]|0;a[m+216|0]=~((q&3)==3?q&-4:q);r=m;s=r+j|0;t=a[s]|0;return t|0};case 2:{m=c[3527304]|0;a[m+2|0]=49;r=m;s=r+j|0;t=a[s]|0;return t|0};case 220:{m=c[3527304]|0;a[m+220|0]=15;r=m;s=r+j|0;t=a[s]|0;return t|0};case 214:{m=c[3527304]|0;a[m+214|0]=-1;r=m;s=r+j|0;t=a[s]|0;return t|0};default:{}}}while(0);g=j-448|0;if(g>>>0>=31){r=c[3527304]|0;s=r+j|0;t=a[s]|0;return t|0}h=c[2430242]|0;if((h|0)<2){i=c[3527304]|0;a[i+j|0]=1-h+(((g|0)/2|0)*15|0)&255;if((j|0)!=478){r=i;s=r+j|0;t=a[s]|0;return t|0}c[2430242]=(c[2430242]|0)+1;r=i;s=r+j|0;t=a[s]|0;return t|0}else{i=f>>>1&15;f=c[3527304]|0;a[f+j|0]=(i<<4|i)&255;if((j|0)!=476){r=f;s=r+j|0;t=a[s]|0;return t|0}c[2430242]=(c[2430242]|0)+1;r=f;s=r+j|0;t=a[s]|0;return t|0}return 0}function d2V(a){a=a|0;var b=0;b=a&4094;d2U(b)|0;return d[(c[3527304]|0)+b|0]|0|0}function d2W(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=(e[4775256]|0)^65535;g=(e[4775257]|0)^65535;h=(e[4775258]|0)^65280^(d[9635122]|0);i=b&4094;switch(i|0){case 104:{j=h&1;k=h&2;if((c[2384414]|0)!=(j|0)){l=(c[3527304]|0)+104|0;a[l]=(d[l]|0)+j&255}if((c[2384412]|0)==(k|0)){l=c[3527304]|0;m=l;n=a[l+104|0]|0}else{l=c[3527304]|0;o=l+104|0;p=(d[o]|0)+(k>>>1)&255;a[o]=p;m=l;n=p}if((n&255)>9){a[m+104|0]=9}c[2384414]=j;c[2384412]=k;a[614912]=1;break};case 20:{k=c[3527304]|0;j=f&128;m=(j|0)!=0;n=m?4:0;p=g&128;l=(p|0)!=0;o=l?n|8:n;n=(h&32|0)==0?o:o|16;a[k+20|0]=(h&16|0)==0?n:n|32;do{if(!((j|0)==(c[2384410]|0)|m)){n=k+104|0;h=a[n]|0;if(!(h<<24>>24!=0&a[614912])){break}a[n]=h-1&255;a[614912]=0}}while(0);do{if(!((p|0)==(c[2384408]|0)|l)){m=k+104|0;h=a[m]|0;if(!((h&255)>1&a[614912])){break}a[m]=h-2&255;a[614912]=0}}while(0);c[2384410]=j;c[2384408]=p;break};case 0:{p=c[3527304]|0;a[p]=0;q=p;r=q+i|0;s=a[r]|0;return s|0};case 10:{p=f>>>1&1;j=(f&1|0)==0?p:p|2;p=(f&4|0)==0?j:j|4;j=(f&8|0)==0?p:p|8;p=(f&16|0)==0?j:j|16;j=(f&32|0)!=0;k=j?(j?p|32:p)|64:p;p=(f&128|0)==0?k:k|-128;k=(p&12)==12?p&-13:p;p=c[3527304]|0;a[p+10|0]=(k&3)==3?k&-4:k;q=p;r=q+i|0;s=a[r]|0;return s|0};case 2:{p=c[3527304]|0;a[p+2|0]=49;q=p;r=q+i|0;s=a[r]|0;return s|0};case 16:{p=g>>>1&1;k=(g&1|0)==0?p:p|2;p=(g&4|0)==0?k:k|4;k=(g&8|0)==0?p:p|8;p=(g&16|0)==0?k:k|16;k=(g&32|0)!=0;j=k?(k?p|32:p)|64:p;p=(g&128|0)==0?j:j|-128;j=(p&12)==12?p&-13:p;p=c[3527304]|0;a[p+16|0]=(j&3)==3?j&-4:j;q=p;r=q+i|0;s=a[r]|0;return s|0};default:{}}do{if((i|0)==168&a[614912]){if((f&128|0)==0){p=g&128;if((p|0)==0){break}j=c[3527304]|0;a[j+168|0]=0;t=p;u=j;v=8}else{j=c[3527304]|0;a[j+168|0]=4;t=g&128;u=j;v=12}if((t|0)==0){break}a[u+168|0]=v}}while(0);v=i-448|0;if(v>>>0>=31){q=c[3527304]|0;r=q+i|0;s=a[r]|0;return s|0}u=c[2430242]|0;if((u|0)<2){t=c[3527304]|0;a[t+i|0]=1-u+(((v|0)/2|0)*15|0)&255;if((i|0)!=478){q=t;r=q+i|0;s=a[r]|0;return s|0}c[2430242]=(c[2430242]|0)+1;q=t;r=q+i|0;s=a[r]|0;return s|0}else{t=b>>>1&15;b=c[3527304]|0;a[b+i|0]=(t<<4|t)&255;if((i|0)!=476){q=b;r=q+i|0;s=a[r]|0;return s|0}c[2430242]=(c[2430242]|0)+1;q=b;r=q+i|0;s=a[r]|0;return s|0}return 0}function d2X(a){a=a|0;var b=0;b=a&4094;d2W(b)|0;return d[(c[3527304]|0)+b|0]|0|0}function d2Y(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=b&4094;b=c[3527304]|0;a[b+f|0]=e&255;if((f|0)!=1024){return}if((e&255)==0){return}else{g=0}while(1){if((g|0)>=256){h=42088;break}i=g+512|0;j=b+i|0;if((a[j]|0)==0){break}else{g=g+16|0}}if((h|0)==42088){return}if((i|0)==0){return}i=(d[b+1024|0]|0)*11|0;a[j]=-127;j=c[2386356]|0;a[b+(g+514)|0]=a[j+(i+516)|0]|0;a[b+(g+516)|0]=a[j+(i+517)|0]|0;a[b+(g+520)|0]=a[j+(i+518)|0]|0;return}function d2Z(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=b&4094;b=c[3527304]|0;a[b+f|0]=e;if((f|0)!=1024|e<<24>>24==0){return}else{g=0}while(1){if((g|0)>=256){h=42095;break}i=g+512|0;j=b+i|0;if((a[j]|0)==0){break}else{g=g+16|0}}if((h|0)==42095){return}if((i|0)==0){return}i=(d[b+1024|0]|0)*11|0;a[j]=-127;j=c[2386356]|0;a[b+(g+514)|0]=a[j+(i+516)|0]|0;a[b+(g+516)|0]=a[j+(i+517)|0]|0;a[b+(g+520)|0]=a[j+(i+518)|0]|0;return}function d2_(a){a=a|0;var c=0,e=0;L55661:do{switch(a|0){case 6356994:case 6356995:{c=-1;break};case 6356992:case 6356993:{c=b[4775256]|0;break};case 6356996:case 6356997:{c=b[4775257]|0;break};default:{e=a-6488064|0;if(e>>>0>=4){c=0;break L55661}c=d[9635120+(e>>>1^1)|0]|0}}}while(0);return c|0}function d2$(c){c=c|0;var d=0,e=0;L55668:do{switch(c|0){case 6356994:case 6356995:{d=-1;break};case 6356992:case 6356993:{d=b[4775256]&255;break};case 6356996:case 6356997:{d=b[4775257]&255;break};default:{e=c-6488064|0;if(e>>>0>=4){d=0;break L55668}d=a[9635120+(e>>>1^1)|0]|0}}}while(0);return d|0}function d20(b,d){b=b|0;d=d|0;if((b-9437184|0)>>>0<6){a[(c[2438728]|0)+(b&7^1)|0]=d;return}if((b-9961472|0)>>>0<6){a[(c[2438730]|0)+(b&7^1)|0]=d;return}if((b|0)==6651904|(b|0)==6651905){Uv(0,d);return}else if((b|0)==6619136|(b|0)==6619137){a[(c[3540984]|0)+5885|0]=d;return}else{return}}function d21(d,e){d=d|0;e=e|0;if((d-9437184|0)>>>0<6){b[(c[2438728]|0)+(d&6)>>1]=e;return}if((d-9961472|0)>>>0<6){b[(c[2438730]|0)+(d&6)>>1]=e;return}if((d|0)==6651904|(d|0)==6651905){Uv(0,e&255);return}else if((d|0)==6619136|(d|0)==6619137){a[(c[3540984]|0)+5885|0]=e&255;return}else{return}}function d22(a,b){a=a|0;b=b|0;if((a&-2|0)!=5242886){return}Uv(0,b);return}function d23(a){a=a|0;return c[2113156]&255|0}function d24(b){b=b|0;return a[(c[2406298]|0)+(b&1022)|0]|0}function d25(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>23){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1277264+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function d26(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}c[3530846]=0;c[3530610]=0;c[3530432]=0;gGz(9774592,0,12);if((c[2392]|0)>=0){b=0;do{d=14130368+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}d=14130384+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}b=b+1|0;}while((b|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;fwZ();c[2113302]=0;a[801640]=0;c[2440576]=0;c[2440574]=0;gGz(14168784,0,16);gGz(14168768,0,16);b=c[2076600]|0;if((b|0)!=0){gGr(b);c[2076600]=0}b=c[3541512]|0;if((b|0)!=0){gGr(b|0);c[3541512]=0}c[2438228]=0;c[2433526]=0;c[2406676]=0;c[3528472]=0;b=c[2406692]|0;if((b|0)!=0){gGr(b);c[2406692]=0}c[2385512]=0;c[2432976]=0;b=a[7452584]|0;if(b){d=0;e=b&1;while(1){b=14163936+(d<<2)|0;f=c[b>>2]|0;g=c[2113006]|0;if((g|0)==0){h=42169}else{i=g-1|0;c[2113006]=i;if((i|0)==0){h=42169}}if((h|0)==42169){h=0;c[2383474]=0}if((f|0)==0){j=e}else{gGr(f);j=a[7452584]&1}c[b>>2]=0;b=d+1|0;if((b|0)<(j|0)){d=b;e=j}else{break}}}a[7452584]=0;c[2438224]=0;c[2433522]=0;c[2406672]=0;c[3528468]=0;j=c[2406688]|0;if((j|0)!=0){gGr(j);c[2406688]=0}c[2432972]=0;Uw(0);c[3541206]=0;j=c[2414970]|0;e=0;while(1){if((e|0)>=1024){break}k=9638528+(e<<2)|0;if((c[k>>2]|0)==(j|0)){h=42178;break}else{e=e+1|0}}if((h|0)==42178){gGr(j);c[k>>2]=0}c[2414970]=0;a[5750792]=0;a[627160]=0;a[2093440]=0;c[1623868]=6e3;k=c[2437764]|0;j=0;while(1){if((j|0)>=1024){break}l=9638528+(j<<2)|0;if((c[l>>2]|0)==(k|0)){h=42182;break}else{j=j+1|0}}if((h|0)==42182){gGr(k);c[l>>2]=0}c[2437764]=0;l=c[2437766]|0;k=0;while(1){if((k|0)>=1024){break}m=9638528+(k<<2)|0;if((c[m>>2]|0)==(l|0)){h=42186;break}else{k=k+1|0}}if((h|0)==42186){gGr(l);c[m>>2]=0}c[2437766]=0;m=c[2437765]|0;l=0;while(1){if((l|0)>=1024){h=42193;break}n=9638528+(l<<2)|0;if((c[n>>2]|0)==(m|0)){break}else{l=l+1|0}}if((h|0)==42193){c[2437765]=0;return 0}gGr(m);c[n>>2]=0;c[2437765]=0;return 0}function d27(){d6n(4508);return 0}function d28(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[2387204]|0;b=c[2387028]|0;do{if((b|0)==0){d=a}else{f=c[3531002]|0;if((b|0)<=1){d=f;break}g=f+1024|0;gGC(g|0,a|0,512)|0;gGC(f|0,a|0,512)|0;d=f}}while(0);a=d;d=(c[642608+(c[2436]<<2)>>2]|0)+124|0;if((c[d>>2]|0)<=0){h=c[3530018]|0;d6R(1);R8(h);return 0}b=c[2406932]|0;f=c[3530018]|0;g=0;while(1){i=e[a+(c[b+(g<<2)>>2]<<1)>>1]|0;j=i>>>5&31;c[f+(g<<2)>>2]=i>>>10<<11&63488|i&31|(j<<3|j>>>2)<<3&2016;j=g+1|0;if((j|0)<(c[d>>2]|0)){g=j}else{h=f;break}}d6R(1);R8(h);return 0}function d29(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;e=i;i=i+240|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;l=e+80|0;m=e+96|0;n=e+112|0;o=e+128|0;p=e+144|0;q=e+160|0;r=e+176|0;s=e+192|0;t=e+208|0;u=e+224|0;v=(d|0)==0;if(!v){c[d>>2]=169736}if((b&32|0)!=0){gGz(u|0,0,12);w=c[2414674]|0;c[u>>2]=w;c[u+4>>2]=(c[2411674]|0)-w;c[u+12>>2]=162152;w=c[2076592]|0;gj[w&4095](u)|0}if((b&8|0)!=0){gGz(u|0,0,12);c[u>>2]=c[2406298];c[u+4>>2]=1024;c[u+12>>2]=361568;w=c[2076592]|0;gj[w&4095](u)|0}if((b&64|0)!=0){u=o|0;gGz(n|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){w=o+9|0;o=m;x=m|0;y=m+4|0;z=m+12|0;A=n|0;B=n+4|0;C=n+12|0;D=0;do{gGC(u|0,614896,11)|0;a[w]=D+48&255;E=8452256+(D<<2)|0;gGz(o|0,0,12);c[x>>2]=E;c[y>>2]=4;c[z>>2]=164976;gj[c[2076592]&4095](m)|0;if((c[E>>2]|0)!=0){c[A>>2]=c[14130368+(D<<2)>>2];c[B>>2]=c[8452184+(D<<2)>>2];c[C>>2]=u;E=c[2076592]|0;gj[E&4095](n)|0}D=D+1|0;}while((D|0)<=(c[2392]|0))}fw$(b);if(!v){c[d>>2]=169586}gGz(l|0,0,12);c[l>>2]=c[2076600];c[l+4>>2]=16584;c[l+12>>2]=157696;D=c[2076592]|0;gj[D&4095](l)|0;UQ(b,d);do{if(!v){if((c[d>>2]|0)>=169249){break}c[d>>2]=169249}}while(0);gGz(j|0,0,12);c[j>>2]=9775320;c[j+4>>2]=8;c[j+12>>2]=111920;d=c[2076592]|0;gj[d&4095](j)|0;gGz(h|0,0,12);c[h>>2]=9775288;c[h+4>>2]=8;c[h+12>>2]=478936;j=c[2076592]|0;gj[j&4095](h)|0;gGz(g|0,0,12);c[g>>2]=53400;c[g+4>>2]=8;c[g+12>>2]=398448;h=c[2076592]|0;gj[h&4095](g)|0;gGz(f|0,0,12);c[f>>2]=14114048;c[f+4>>2]=4;c[f+12>>2]=287368;g=c[2076592]|0;gj[g&4095](f)|0;gGz(k|0,0,12);c[k>>2]=9734152;c[k+4>>2]=4;c[k+12>>2]=139856;f=c[2076592]|0;gj[f&4095](k)|0;Ut(0);gGz(t|0,0,12);c[t>>2]=9720992;c[t+4>>2]=4;c[t+12>>2]=132480;k=c[2076592]|0;gj[k&4095](t)|0;gGz(s|0,0,12);c[s>>2]=9717360;c[s+4>>2]=4;c[s+12>>2]=132200;t=c[2076592]|0;gj[t&4095](s)|0;gGz(r|0,0,12);c[r>>2]=9720968;c[r+4>>2]=4;c[r+12>>2]=132e3;s=c[2076592]|0;gj[s&4095](r)|0;gGz(q|0,0,12);c[q>>2]=9757120;c[q+4>>2]=4;c[q+12>>2]=131912;r=c[2076592]|0;gj[r&4095](q)|0;gGz(p|0,0,12);c[p>>2]=9757112;c[p+4>>2]=4;c[p+12>>2]=131808;q=c[2076592]|0;gj[q&4095](p)|0}if((b&2|0)==0){i=e;return 0}b=(c[2430248]|0)>>>3&7;p=c[2387027]|0;c[2430248]=b;if((p|0)==4194304){q=c[2386648]|0;r=q+524288|0;s=q+((b|0)==0?1048576:(b<<19)+524288|0)|0;gGC(r|0,s|0,524288)|0;i=e;return 0}else if((p|0)==2097152|(p|0)==1572864){s=b<<18;r=b>>>0>2?s+262144|0:s;if((r+262144|0)>(p|0)){i=e;return 0}p=c[2386648]|0;s=p+786432|0;b=p+r|0;gGC(s|0,b|0,262144)|0;i=e;return 0}else{i=e;return 0}return 0}function d3a(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>25){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2913820+(b*112|0)>>2];c[a+104>>2]=c[2913824+(b*112|0)>>2];c[a+108>>2]=c[2913828+(b*112|0)>>2];d=0;return d|0}function d3b(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<26&(d|0)==0)){e=1;return e|0}c[a>>2]=2913720+(b*112|0);e=0;return e|0}function d3c(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>47){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4044984+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function d3d(){c[2443648]=0;c[2443649]=0;c[2443650]=0;c[2442920]=2;c[2442921]=2;c[2442918]=-2;return d6o(3220,8e6,258,1,0,1,-1)|0}function d3e(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[2387204]|0;b=c[2387028]|0;do{if((b|0)==0){d=a}else{f=c[3531002]|0;if((b|0)<=1){d=f;break}g=f+1024|0;gGC(g|0,a|0,512)|0;gGC(f|0,a|0,512)|0;d=f}}while(0);a=d;d=(c[642608+(c[2436]<<2)>>2]|0)+124|0;if((c[d>>2]|0)<=0){h=c[3530018]|0;d6R(0);R8(h);return 0}b=c[2406932]|0;f=c[3530018]|0;g=0;while(1){i=e[a+(c[b+(g<<2)>>2]<<1)>>1]|0;j=i>>>5&31;c[f+(g<<2)>>2]=i>>>10<<11&63488|i&31|(j<<3|j>>>2)<<3&2016;j=g+1|0;if((j|0)<(c[d>>2]|0)){g=j}else{h=f;break}}d6R(0);R8(h);return 0}function d3f(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2410164+(b*112|0)>>2];c[a+104>>2]=c[2410168+(b*112|0)>>2];c[a+108>>2]=c[2410172+(b*112|0)>>2];d=0;return d|0}function d3g(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=2410064+(b*112|0);e=0;return e|0}function d3h(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1207136+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function d3i(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>33){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3583712+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function d3j(){c[2443648]=0;c[2443649]=0;c[2443650]=0;c[2442920]=1;c[2442921]=1;c[2442918]=-1;return d6o(3220,8e6,258,1,0,1,-1)|0}function d3k(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7327252+(b*112|0)>>2];c[a+104>>2]=c[7327256+(b*112|0)>>2];c[a+108>>2]=c[7327260+(b*112|0)>>2];d=0;return d|0}function d3l(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=7327152+(b*112|0);e=0;return e|0}function d3m(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6671464+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function d3n(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>26){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7368504+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function d3o(){c[2443648]=0;c[2443649]=0;c[2443650]=0;c[2442920]=0;c[2442921]=0;c[2442918]=-2;return d6o(3220,8e6,513,1,0,1,-1)|0}function d3p(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>4){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2411284+(b*112|0)>>2];c[a+104>>2]=c[2411288+(b*112|0)>>2];c[a+108>>2]=c[2411292+(b*112|0)>>2];d=0;return d|0}function d3q(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<5&(d|0)==0)){e=1;return e|0}c[a>>2]=2411184+(b*112|0);e=0;return e|0}function d3r(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1207424+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function d3s(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>39){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3584120+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function d3t(){c[2443648]=0;c[2443649]=0;c[2443650]=0;c[2442920]=0;c[2442921]=0;c[2442918]=-1;return d6o(3220,16e6,258,1,0,2,-1)|0}function d3u(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6594828+(b*112|0)>>2];c[a+104>>2]=c[6594832+(b*112|0)>>2];c[a+108>>2]=c[6594836+(b*112|0)>>2];d=0;return d|0}function d3v(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=6594728+(b*112|0);e=0;return e|0}function d3w(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>28){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5506344+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function d3x(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>50){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6959736+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function d3y(){c[2442920]=1;c[2442921]=1;c[2442918]=-1;c[2443648]=0;c[2443649]=1024;c[2443650]=512;return d6o(10988,16e6,258,0,0,2,2)|0}function d3z(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5924804+(b*112|0)>>2];c[a+104>>2]=c[5924808+(b*112|0)>>2];c[a+108>>2]=c[5924812+(b*112|0)>>2];d=0;return d|0}function d3A(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=5924704+(b*112|0);e=0;return e|0}function d3B(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6494564+(b*112|0)>>2];c[a+104>>2]=c[6494568+(b*112|0)>>2];c[a+108>>2]=c[6494572+(b*112|0)>>2];d=0;return d|0}function d3C(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=6494464+(b*112|0);e=0;return e|0}function d3D(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5099608+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function d3E(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>48){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6810864+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function d3F(){var b=0,d=0,e=0,f=0,g=0;c[2442920]=0;c[2442921]=0;c[2442918]=-2;c[2443648]=0;c[2443649]=1024;c[2443650]=512;b=d6o(3872,16e6,258,0,0,2,2)|0;if((b|0)!=0){return b|0}d=c[2388160]|0;e=d+1048576|0;f=d+262144|0;gGC(e|0,f|0,262144)|0;gGz(f|0,0,262144);f=0;e=c[2386648]|0;while(1){d=a[e]|0;g=e+1|0;a[e]=a[g]|0;a[g]=d;d=f+1|0;if((d|0)<524288){f=d;e=e+2|0}else{break}}return b|0}function d3G(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5726548+(b*112|0)>>2];c[a+104>>2]=c[5726552+(b*112|0)>>2];c[a+108>>2]=c[5726556+(b*112|0)>>2];d=0;return d|0}function d3H(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=5726448+(b*112|0);e=0;return e|0}function d3I(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2885812+(b*112|0)>>2];c[a+104>>2]=c[2885816+(b*112|0)>>2];c[a+108>>2]=c[2885820+(b*112|0)>>2];d=0;return d|0}function d3J(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=2885712+(b*112|0);e=0;return e|0}function d3K(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1273512+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function d3L(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>48){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4020696+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function d3M(){var a=0,b=0,d=0,e=0;c[2442920]=3;c[2442921]=4;c[2442918]=0;c[2443648]=0;c[2443649]=1024;c[2443650]=512;a=d6o(3872,16e6,258,0,0,2,2)|0;if((a|0)!=0){return a|0}b=c[2386648]|0;d=b+1048576|0;e=b+786432|0;gGC(d|0,e|0,1310720)|0;return a|0}function d3N(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2074276+(b*112|0)>>2];c[a+104>>2]=c[2074280+(b*112|0)>>2];c[a+108>>2]=c[2074284+(b*112|0)>>2];d=0;return d|0}function d3O(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=2074176+(b*112|0);e=0;return e|0}function d3P(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>23){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1173264+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function d3Q(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>41){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3230864+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function d3R(){c[2442920]=0;c[2442921]=0;c[2442918]=0;c[2443648]=0;c[2443649]=1024;c[2443650]=512;return d6o(3872,16e6,516,0,0,2,2)|0}function d3S(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4307900+(b*112|0)>>2];c[a+104>>2]=c[4307904+(b*112|0)>>2];c[a+108>>2]=c[4307908+(b*112|0)>>2];d=0;return d|0}function d3T(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=4307800+(b*112|0);e=0;return e|0}function d3U(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1632280+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function d3V(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>38){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4855488+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function d3W(){var a=0,b=0,d=0,e=0,f=0,g=0;c[2442920]=0;c[2442921]=0;c[2442918]=-1;c[2443648]=0;c[2443649]=1024;c[2443650]=512;a=d6o(3872,16e6,896,0,0,3,2)|0;if((a|0)!=0){return a|0}b=c[2406932]|0;d=0;do{e=d<<4;f=d<<6;g=0;do{c[b+((g|f)+1024<<2)>>2]=g+e&511|1024;g=g+1|0;}while((g|0)<64);d=d+1|0;}while((d|0)<32);return a|0}function d3X(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2564980+(b*112|0)>>2];c[a+104>>2]=c[2564984+(b*112|0)>>2];c[a+108>>2]=c[2564988+(b*112|0)>>2];d=0;return d|0}function d3Y(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=2564880+(b*112|0);e=0;return e|0}function d3Z(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1273512+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function d3_(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>43){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3695232+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function d3$(){var a=0,b=0,d=0;c[1623868]=5666;c[2442920]=0;c[2442921]=0;c[2442918]=-2;c[2443648]=0;c[2443649]=1024;c[2443650]=512;a=d6o(122,16e6,1026,1,0,2,2)|0;if((a|0)!=0){return a|0}b=c[2388160]|0;d=b+524288|0;gGG(b+1048576|0,d|0,1048576);gGz(d|0,0,524288);return a|0}function d30(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1456340+(b*112|0)>>2];c[a+104>>2]=c[1456344+(b*112|0)>>2];c[a+108>>2]=c[1456348+(b*112|0)>>2];d=0;return d|0}function d31(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=1456240+(b*112|0);e=0;return e|0}function d32(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>42){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3695760+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function d33(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>4){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2517892+(b*112|0)>>2];c[a+104>>2]=c[2517896+(b*112|0)>>2];c[a+108>>2]=c[2517900+(b*112|0)>>2];d=0;return d|0}function d34(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<5&(d|0)==0)){e=1;return e|0}c[a>>2]=2517792+(b*112|0);e=0;return e|0}function d35(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1225480+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function d36(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>41){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3668768+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function d37(){c[2442920]=0;c[2442921]=0;c[2442918]=0;c[2443648]=0;c[2443649]=0;c[2443650]=0;return d6o(10548,16e6,896,0,0,-1,-1)|0}function d38(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[2387204]|0;b=c[2387028]|0;do{if((b|0)==0){d=a}else{f=c[3531002]|0;if((b|0)<=1){d=f;break}g=f+1024|0;gGC(g|0,a|0,512)|0;gGC(f|0,a|0,512)|0;d=f}}while(0);a=d;d=(c[642608+(c[2436]<<2)>>2]|0)+124|0;if((c[d>>2]|0)>0){b=c[2406932]|0;f=c[3530018]|0;g=0;while(1){h=e[a+(c[b+(g<<2)>>2]<<1)>>1]|0;i=h>>>5&31;c[f+(g<<2)>>2]=h>>>10<<11&63488|h&31|(i<<3|i>>>2)<<3&2016;i=g+1|0;if((i|0)<(c[d>>2]|0)){g=i}else{j=f;break}}}else{j=c[3530018]|0}f=c[2112926]|0;gGz(f|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);d6T();R8(j);return 0}function d39(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>4){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2104908+(b*112|0)>>2];c[a+104>>2]=c[2104912+(b*112|0)>>2];c[a+108>>2]=c[2104916+(b*112|0)>>2];d=0;return d|0}function d4a(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<5&(d|0)==0)){e=1;return e|0}c[a>>2]=2104808+(b*112|0);e=0;return e|0}function d4b(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1273512+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function d4c(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>41){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3272896+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function d4d(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>4){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2727300+(b*112|0)>>2];c[a+104>>2]=c[2727304+(b*112|0)>>2];c[a+108>>2]=c[2727308+(b*112|0)>>2];d=0;return d|0}function d4e(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<5&(d|0)==0)){e=1;return e|0}c[a>>2]=2727200+(b*112|0);e=0;return e|0}function d4f(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1273512+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function d4g(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>36){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3837248+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function d4h(){c[2442920]=0;c[2442921]=0;c[2442918]=-2;c[2443648]=0;c[2443649]=1024;c[2443650]=512;return d6o(1512,16e6,640,0,0,2,2)|0}function d4i(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>5){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2631500+(b*112|0)>>2];c[a+104>>2]=c[2631504+(b*112|0)>>2];c[a+108>>2]=c[2631508+(b*112|0)>>2];d=0;return d|0}function d4j(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<6&(d|0)==0)){e=1;return e|0}c[a>>2]=2631400+(b*112|0);e=0;return e|0}function d4k(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1273512+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function d4l(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>47){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3776016+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function d4m(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0;c[2442920]=0;c[2442921]=0;c[2442918]=0;c[2443648]=0;c[2443649]=512;c[2443650]=2560;a=d6o(9234,16e6,640,0,0,3,3)|0;if((a|0)!=0){return a|0}b=c[2406932]|0;d=0;do{e=d<<4;f=d<<6;g=0;do{h=g+e&511;i=g|f;c[b+(i+512<<2)>>2]=h|1024;c[b+(i+2560<<2)>>2]=h|512;g=g+1|0;}while((g|0)<64);d=d+1|0;}while((d|0)<32);return a|0}function d4n(){var a=0,b=0,d=0,e=0;a=c[3530432]|0;b=0;while(1){if((b|0)>=1024){break}d=9638528+(b<<2)|0;if((c[d>>2]|0)==(a|0)){e=42695;break}else{b=b+1|0}}if((e|0)==42695){gGr(a);c[d>>2]=0}c[3530432]=0;d26()|0;return 0}function d4o(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6985404+(b*112|0)>>2];c[a+104>>2]=c[6985408+(b*112|0)>>2];c[a+108>>2]=c[6985412+(b*112|0)>>2];d=0;return d|0}function d4p(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=6985304+(b*112|0);e=0;return e|0}function d4q(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>35){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5992776+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function d4r(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>50){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7094728+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function d4s(){c[2442920]=0;c[2442921]=0;c[2442918]=0;c[2443648]=0;c[2443649]=0;c[2443650]=0;return d6o(1070,8e6,640,0,0,-1,-1)|0}function d4t(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2155036+(b*112|0)>>2];c[a+104>>2]=c[2155040+(b*112|0)>>2];c[a+108>>2]=c[2155044+(b*112|0)>>2];d=0;return d|0}function d4u(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=2154936+(b*112|0);e=0;return e|0}function d4v(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1273512+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function d4w(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>68){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3313704+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function d4x(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>3){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4827044+(b*112|0)>>2];c[a+104>>2]=c[4827048+(b*112|0)>>2];c[a+108>>2]=c[4827052+(b*112|0)>>2];d=0;return d|0}function d4y(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<4&(d|0)==0)){e=1;return e|0}c[a>>2]=4826944+(b*112|0);e=0;return e|0}function d4z(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1207424+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function d4A(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>44){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5593920+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function d4B(){c[2442920]=0;c[2442921]=0;c[2442918]=0;c[2443648]=0;c[2443649]=0;c[2443650]=0;return d6o(6536,16e6,513,0,0,-1,-1)|0}function d4C(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>4){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3067060+(b*112|0)>>2];c[a+104>>2]=c[3067064+(b*112|0)>>2];c[a+108>>2]=c[3067068+(b*112|0)>>2];d=0;return d|0}function d4D(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<5&(d|0)==0)){e=1;return e|0}c[a>>2]=3066960+(b*112|0);e=0;return e|0}function d4E(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1273512+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function d4F(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>39){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4238232+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function d4G(){c[2442920]=0;c[2442921]=0;c[2442918]=0;c[2443648]=0;c[2443649]=0;c[2443650]=0;return d6o(7614,8e6,896,0,0,-1,-1)|0}function d4H(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2057212+(b*112|0)>>2];c[a+104>>2]=c[2057216+(b*112|0)>>2];c[a+108>>2]=c[2057220+(b*112|0)>>2];d=0;return d|0}function d4I(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=2057112+(b*112|0);e=0;return e|0}function d4J(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1172224+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function d4K(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>43){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3187760+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function d4L(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0;c[2442920]=0;c[2442921]=0;c[2442918]=-2;c[2443648]=0;c[2443649]=512;c[2443650]=2560;a=d6o(9606,16e6,516,0,0,3,3)|0;if((a|0)!=0){return a|0}b=c[2406932]|0;d=0;do{e=d<<4&448;f=d<<6;g=0;do{h=g+e&511;i=g|f;c[b+(i+512<<2)>>2]=h|1024;c[b+(i+2560<<2)>>2]=h|512;g=g+1|0;}while((g|0)<64);d=d+1|0;}while((d|0)<32);return a|0}function d4M(){var a=0,b=0;d28()|0;a=(c[642608+(c[2436]<<2)>>2]|0)+56|0;if((c[a>>2]|0)>0){b=0}else{return 0}do{R7(b,c[14168784+(b<<2)>>2]>>8,c[14168768+(b<<2)>>2]>>8);b=b+1|0;}while((b|0)<(c[a>>2]|0));return 0}function d4N(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2805748+(b*112|0)>>2];c[a+104>>2]=c[2805752+(b*112|0)>>2];c[a+108>>2]=c[2805756+(b*112|0)>>2];d=0;return d|0}function d4O(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=2805648+(b*112|0);e=0;return e|0}function d4P(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5099608+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function d4Q(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>51){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3883848+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function d4R(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0;c[2442920]=0;c[2442921]=0;c[2442918]=-2;c[2443648]=0;c[2443649]=512;c[2443650]=2560;a=d6o(11376,16e6,516,0,0,3,3)|0;if((a|0)!=0){return a|0}b=c[2406932]|0;d=0;do{e=d<<4&448;f=d<<6;g=0;do{h=g+e&511;i=g|f;c[b+(i+512<<2)>>2]=h|1024;c[b+(i+2560<<2)>>2]=h|512;g=g+1|0;}while((g|0)<64);d=d+1|0;}while((d|0)<32);return a|0}function d4S(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4802228+(b*112|0)>>2];c[a+104>>2]=c[4802232+(b*112|0)>>2];c[a+108>>2]=c[4802236+(b*112|0)>>2];d=0;return d|0}function d4T(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=4802128+(b*112|0);e=0;return e|0}function d4U(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>23){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1277264+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function d4V(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>48){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5571768+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function d4W(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0;c[2442920]=0;c[2442921]=0;c[2442918]=0;c[2443648]=0;c[2443649]=2560;c[2443650]=512;a=d6o(5886,16e6,516,1,0,4,4)|0;if((a|0)!=0){return a|0}b=c[2406932]|0;d=0;do{e=d<<4;f=d<<6;g=0;do{h=g|f;c[b+(h+512<<2)>>2]=(g&15|e)+512;c[b+(h+2560<<2)>>2]=g+1024;g=g+1|0;}while((g|0)<64);d=d+1|0;}while((d|0)<32);return a|0}function d4X(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>31){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3075908+(b*112|0)>>2];c[a+104>>2]=c[3075912+(b*112|0)>>2];c[a+108>>2]=c[3075916+(b*112|0)>>2];d=0;return d|0}function d4Y(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<32&(d|0)==0)){e=1;return e|0}c[a>>2]=3075808+(b*112|0);e=0;return e|0}function d4Z(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0;c[2442920]=0;c[2442921]=8;c[2442918]=-2;c[2443648]=0;c[2443649]=2560;c[2443650]=512;a=d6o(1302,16e6,516,1,0,4,4)|0;if((a|0)!=0){return a|0}b=c[2406932]|0;d=0;do{e=d<<4;f=d<<6;g=0;do{h=g|f;c[b+(h+512<<2)>>2]=(g&15|e)+512;c[b+(h+2560<<2)>>2]=g+1024;g=g+1|0;}while((g|0)<64);d=d+1|0;}while((d|0)<32);return a|0}function d4_(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2497796+(b*112|0)>>2];c[a+104>>2]=c[2497800+(b*112|0)>>2];c[a+108>>2]=c[2497804+(b*112|0)>>2];d=0;return d|0}function d4$(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=2497696+(b*112|0);e=0;return e|0}function d40(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1224504+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function d41(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>31){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3657696+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function d42(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;b=i;i=i+240|0;d=b|0;e=b+112|0;f=b+120|0;g=b+232|0;a[5750792]=1;a[2093440]=1;c[2442920]=2;c[2442921]=2;c[2442918]=-1;c[2443648]=0;c[2443649]=1024;c[2443650]=512;h=d6o(3914,16e6,513,0,0,2,2)|0;if((h|0)!=0){j=h;i=b;return j|0}h=c[2388160]|0;gGz(h|0,0,2097152);if((c[3542200]|0)==0){j=1;i=b;return j|0}k=f+108|0;c[k>>2]=0;l=f+100|0;c[l>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,0)|0;do{if((c[k>>2]|0)!=0){f=c[l>>2]|0;c[g>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](g,0,0)|0;if((f|0)<1){j=1;i=b;return j|0}if((gzL(h,0,0)|0)==0){break}else{j=1}i=b;return j|0}}while(0);h=(c[2388160]|0)+1048576|0;if((c[3542200]|0)==0){j=1;i=b;return j|0}g=d+108|0;c[g>>2]=0;l=d+100|0;c[l>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](d,1)|0;do{if((c[g>>2]|0)!=0){d=c[l>>2]|0;c[e>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](e,1,0)|0;if((d|0)<1){j=1;i=b;return j|0}if((gzL(h,0,1)|0)==0){break}else{j=1}i=b;return j|0}}while(0);h=c[3530846]|0;e=0;while(1){l=h+e|0;a[l]=a[l]^15;l=e+1|0;if((l|0)<4194304){e=l}else{j=0;break}}i=b;return j|0}function d43(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0;a=c[2387204]|0;b=c[2387028]|0;do{if((b|0)==0){d=a}else{f=c[3531002]|0;if((b|0)<=1){d=f;break}g=f+1024|0;gGC(g|0,a|0,512)|0;gGC(f|0,a|0,512)|0;d=f}}while(0);a=d;d=(c[642608+(c[2436]<<2)>>2]|0)+124|0;if((c[d>>2]|0)<=0){h=c[3530018]|0;d6R(1);R8(h);return 0}b=c[2406932]|0;f=c[3530018]|0;g=0;while(1){i=e[a+(c[b+(g<<2)>>2]<<1)>>1]|0;j=i>>>5&31;c[f+(g<<2)>>2]=i>>>10<<11&63488|i&31|(j<<3|j>>>2)<<3&2016;j=g+1|0;if((j|0)<(c[d>>2]|0)){g=j}else{h=f;break}}d6R(1);R8(h);return 0}function d44(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2124572+(b*112|0)>>2];c[a+104>>2]=c[2124576+(b*112|0)>>2];c[a+108>>2]=c[2124580+(b*112|0)>>2];d=0;return d|0}function d45(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=2124472+(b*112|0);e=0;return e|0}function d46(){a[5750792]=1;c[2442920]=0;c[2442921]=0;c[2442918]=-1;c[2443648]=0;c[2443649]=1024;c[2443650]=512;return d6o(7152,16e6,896,0,0,2,2)|0}function d47(){d6n(12370);return 0}function d48(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>4){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2472100+(b*112|0)>>2];c[a+104>>2]=c[2472104+(b*112|0)>>2];c[a+108>>2]=c[2472108+(b*112|0)>>2];d=0;return d|0}function d49(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<5&(d|0)==0)){e=1;return e|0}c[a>>2]=2472e3+(b*112|0);e=0;return e|0}function d5a(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1273512+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function d5b(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>33){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3638408+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function d5c(){var a=0,b=0,d=0;c[2442920]=0;c[2442921]=0;c[2442918]=0;c[2443648]=0;c[2443649]=0;c[2443650]=0;a=d6o(10814,8e6,513,0,0,-1,-1)|0;if((a|0)!=0){return a|0}b=c[2386648]|0;d=b+524288|0;gGC(d|0,b|0,524288)|0;return a|0}function d5d(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7013860+(b*112|0)>>2];c[a+104>>2]=c[7013864+(b*112|0)>>2];c[a+108>>2]=c[7013868+(b*112|0)>>2];d=0;return d|0}function d5e(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=7013760+(b*112|0);e=0;return e|0}function d5f(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6188472+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function d5g(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>46){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7162296+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function d5h(){c[2442920]=0;c[2442921]=0;c[2442918]=0;c[2443648]=0;c[2443649]=0;c[2443650]=0;return d6o(10814,7159090,513,0,5,-1,-1)|0}function d5i(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4622428+(b*112|0)>>2];c[a+104>>2]=c[4622432+(b*112|0)>>2];c[a+108>>2]=c[4622436+(b*112|0)>>2];d=0;return d|0}function d5j(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=4622328+(b*112|0);e=0;return e|0}function d5k(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1866208+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function d5l(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>38){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5333336+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function d5m(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2741652+(b*112|0)>>2];c[a+104>>2]=c[2741656+(b*112|0)>>2];c[a+108>>2]=c[2741660+(b*112|0)>>2];d=0;return d|0}function d5n(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=2741552+(b*112|0);e=0;return e|0}function d5o(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1238128+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function d5p(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>44){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3843872+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function d5q(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0;c[2442920]=1;c[2442921]=1;c[2442918]=-1;c[2443648]=0;c[2443649]=512;c[2443650]=2560;a=d6o(3872,16e6,258,0,0,3,3)|0;if((a|0)!=0){return a|0}b=c[2406932]|0;d=0;do{e=d<<4;f=d<<6;g=0;do{h=g+e&511;i=g|f;c[b+(i+512<<2)>>2]=h|1024;c[b+(i+2560<<2)>>2]=h|512;g=g+1|0;}while((g|0)<64);d=d+1|0;}while((d|0)<32);d=c[2388160]|0;b=d+1048576|0;g=d+524288|0;gGC(b|0,g|0,524288)|0;gGz(g|0,0,524288);return a|0}function d5r(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1095340+(b*112|0)>>2];c[a+104>>2]=c[1095344+(b*112|0)>>2];c[a+108>>2]=c[1095348+(b*112|0)>>2];d=0;return d|0}function d5s(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=1095240+(b*112|0);e=0;return e|0}function d5t(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1526908+(b*112|0)>>2];c[a+104>>2]=c[1526912+(b*112|0)>>2];c[a+108>>2]=c[1526916+(b*112|0)>>2];d=0;return d|0}function d5u(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=1526808+(b*112|0);e=0;return e|0}function d5v(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0;c[2442920]=1;c[2442921]=1;c[2442918]=-1;c[2443648]=0;c[2443649]=512;c[2443650]=2560;a=d6o(140,16e6,258,0,0,3,3)|0;if((a|0)!=0){return a|0}b=c[2406932]|0;d=0;do{e=d<<4;f=d<<6;g=0;do{h=g+e&511;i=g|f;c[b+(i+512<<2)>>2]=h|1024;c[b+(i+2560<<2)>>2]=h|512;g=g+1|0;}while((g|0)<64);d=d+1|0;}while((d|0)<32);return a|0}function d5w(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2877300+(b*112|0)>>2];c[a+104>>2]=c[2877304+(b*112|0)>>2];c[a+108>>2]=c[2877308+(b*112|0)>>2];d=0;return d|0}function d5x(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=2877200+(b*112|0);e=0;return e|0}function d5y(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1271784+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function d5z(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>56){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3997624+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function d5A(){var b=0,d=0,e=0,f=0,g=0,h=0;a[2093440]=1;c[2442920]=0;c[2442921]=0;c[2442918]=-2;c[2443648]=0;c[2443649]=1024;c[2443650]=512;b=d6o(11986,16e6,258,0,0,3,2)|0;if((b|0)!=0){return b|0}d=c[2406932]|0;e=0;do{f=e<<4;g=e<<6;h=0;do{c[d+((h|g)+1024<<2)>>2]=h+f&511|1024;h=h+1|0;}while((h|0)<64);e=e+1|0;}while((e|0)<32);if((c[2437766]|0)!=0){return b|0}c[2437766]=c[2437765];return b|0}function d5B(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>5){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2255308+(b*112|0)>>2];c[a+104>>2]=c[2255312+(b*112|0)>>2];c[a+108>>2]=c[2255316+(b*112|0)>>2];d=0;return d|0}function d5C(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<6&(d|0)==0)){e=1;return e|0}c[a>>2]=2255208+(b*112|0);e=0;return e|0}function d5D(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6188472+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function d5E(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>43){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3418600+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function d5F(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5625380+(b*112|0)>>2];c[a+104>>2]=c[5625384+(b*112|0)>>2];c[a+108>>2]=c[5625388+(b*112|0)>>2];d=0;return d|0}function d5G(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=5625280+(b*112|0);e=0;return e|0}function d5H(){c[2442920]=0;c[2442921]=0;c[2442918]=0;c[2443648]=0;c[2443649]=0;c[2443650]=0;return d6o(9164,8e6,640,0,6,-1,-1)|0}function d5I(){d6n(9428);return 0}function d5J(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2193876+(b*112|0)>>2];c[a+104>>2]=c[2193880+(b*112|0)>>2];c[a+108>>2]=c[2193884+(b*112|0)>>2];d=0;return d|0}function d5K(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=2193776+(b*112|0);e=0;return e|0}function d5L(){c[2442920]=0;c[2442921]=0;c[2442918]=0;c[2443648]=0;c[2443649]=0;c[2443650]=0;return d6o(9164,8e6,640,0,7,-1,-1)|0}function d5M(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2103340+(b*112|0)>>2];c[a+104>>2]=c[2103344+(b*112|0)>>2];c[a+108>>2]=c[2103348+(b*112|0)>>2];d=0;return d|0}function d5N(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=2103240+(b*112|0);e=0;return e|0}function d5O(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5099608+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function d5P(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>58){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3270392+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function d5Q(){c[2442920]=0;c[2442921]=0;c[2442918]=-2;c[2443648]=0;c[2443649]=1024;c[2443650]=512;return d6o(6926,16e6,513,0,0,2,2)|0}function d5R(){d6n(3636);return 0}function d5S(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2925012+(b*112|0)>>2];c[a+104>>2]=c[2925016+(b*112|0)>>2];c[a+108>>2]=c[2925020+(b*112|0)>>2];d=0;return d|0}function d5T(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=2924912+(b*112|0);e=0;return e|0}function d5U(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>23){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1280448+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function d5V(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>45){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4049232+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function d5W(){var a=0,b=0;c[1623868]=5742;c[2442920]=0;c[2442921]=0;c[2442918]=-1;c[2443648]=0;c[2443649]=0;c[2443650]=0;a=d6o(11528,8e6,258,0,0,1,-1)|0;b=c[2076600]|0;h[b+16560>>3]=.5;c[b+16576>>2]=1;h[b+16568>>3]=.5;c[b+16580>>2]=1;return a|0}function d5X(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1560540+(b*112|0)>>2];c[a+104>>2]=c[1560544+(b*112|0)>>2];c[a+108>>2]=c[1560548+(b*112|0)>>2];d=0;return d|0}function d5Y(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=1560440+(b*112|0);e=0;return e|0}function d5Z(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3156020+(b*112|0)>>2];c[a+104>>2]=c[3156024+(b*112|0)>>2];c[a+108>>2]=c[3156028+(b*112|0)>>2];d=0;return d|0}function d5_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=3155920+(b*112|0);e=0;return e|0}function d5$(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1830072+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function d50(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>44){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4276072+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function d51(){c[2442920]=0;c[2442921]=1;c[2442918]=-2;c[2443648]=0;c[2443649]=0;c[2443650]=0;return d6o(4984,8e6,896,0,0,1,-1)|0}function d52(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4540788+(b*112|0)>>2];c[a+104>>2]=c[4540792+(b*112|0)>>2];c[a+108>>2]=c[4540796+(b*112|0)>>2];d=0;return d|0}function d53(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=4540688+(b*112|0);e=0;return e|0}function d54(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>45){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5282112+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function d55(){var a=0,d=0;c[2442920]=0;c[2442921]=0;c[2442918]=16;c[2443648]=0;c[2443649]=0;c[2443650]=0;a=d6o(4984,8e6,896,0,0,1,-1)|0;if((a|0)!=0){return a|0}d=c[2388160]|0;b[d+568092>>1]=20081;b[d+568094>>1]=20081;b[d+568096>>1]=20081;return a|0}function d56(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2113716+(b*112|0)>>2];c[a+104>>2]=c[2113720+(b*112|0)>>2];c[a+108>>2]=c[2113724+(b*112|0)>>2];d=0;return d|0}function d57(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=2113616+(b*112|0);e=0;return e|0}function d58(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1178456+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function d59(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>45){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3276936+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function d6a(){a[627160]=1;c[2442920]=0;c[2442921]=0;c[2442918]=0;c[2443648]=0;c[2443649]=0;c[2443650]=0;return d6o(560,8e6,896,0,0,1,-1)|0}function d6b(){d6n(9526);return 0}function d6c(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3036084+(b*112|0)>>2];c[a+104>>2]=c[3036088+(b*112|0)>>2];c[a+108>>2]=c[3036092+(b*112|0)>>2];d=0;return d|0}function d6d(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=3035984+(b*112|0);e=0;return e|0}function d6e(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>23){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1300136+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function d6f(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>44){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4190560+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function d6g(){var b=0,d=0;c[1623868]=5742;a[2093440]=1;c[2443648]=0;c[2443649]=0;c[2443650]=0;c[2442920]=-1;c[2442921]=2;c[2442918]=-3;b=d6o(4682,8e6,32896,0,0,1,-1)|0;d=c[2076600]|0;h[d+16560>>3]=.5;c[d+16576>>2]=1;h[d+16568>>3]=.5;c[d+16580>>2]=1;return b|0}function d6h(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3003524+(b*112|0)>>2];c[a+104>>2]=c[3003528+(b*112|0)>>2];c[a+108>>2]=c[3003532+(b*112|0)>>2];d=0;return d|0}function d6i(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=3003424+(b*112|0);e=0;return e|0}function d6j(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1290488+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function d6k(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>42){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4142264+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function d6l(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0;c[2443648]=0;c[2443649]=2560;c[2443650]=512;c[2442920]=6;c[2442921]=0;c[2442918]=-4;a=d6o(9812,16e6,32896,0,5,4,4)|0;if((a|0)!=0){return a|0}b=c[2406932]|0;d=0;do{e=d<<4&448;f=d<<6;g=0;do{h=g+e&511;i=g|f;c[b+(i+512<<2)>>2]=h|1024;c[b+(i+2560<<2)>>2]=h|512;g=g+1|0;}while((g|0)<64);d=d+1|0;}while((d|0)<32);return a|0}function d6m(){d6n(4160);return 0}function d6n(e){e=e|0;var f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;if((a[9624224]|0)!=0){f=c[2414674]|0;gGz(f|0,0,(c[2411674]|0)-f|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060]}RI();f=c[2394]|0;g=c[14130368+(f<<2)>>2]|0;if((g|0)!=0){gGC(g|0,9104152,280)|0}c[8452240+(f<<2)>>2]=c[2113054];c[2394]=-1;f=c[2439330]|0;g=(f|0)==0;if(!g){i=f;gGC(9706056,i|0,76)|0}i=c[2438118]|0;c[2433530]=i;j=c[3528484]|0;c[2076596]=j;k=c[2417276]|0;c[3541536]=k;c[1836236]=0;gGz(9706056,0,76);if(!g){g=f;gGC(g|0,9706056,76)|0}c[2438118]=i;c[3528484]=j;c[2417276]=k;c[1836236]=-1;k=c[2076600]|0;c[k+8>>2]=1;gGz(k+16528|0,0,32);gGz(k+12|0,0,16512);c[2113156]=0;a[9628264]=0;c[2407033]=0;k=c[3541206]|0;c[3541190]=k;c[3541198]=k;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=k+256;c[3541199]=k+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=k+512;c[3541200]=k+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=k+768;c[3541201]=k+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385512]|0)>0){k=0;do{mc(k);k=k+1|0;}while((k|0)<(c[2385512]|0))}c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;lw(c[3540984]|0);c[2388366]=0;c[2430242]=0}do{if(a[2093440]|0){k=(c[2388366]|0)+1|0;c[2388366]=k;if((k|0)<=179){break}if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];k=c[3532592]|0;if((k|0)!=0){gGC(9104152,k|0,280)|0}c[2113054]=c[2113060]}RI();k=c[2394]|0;j=c[14130368+(k<<2)>>2]|0;if((j|0)!=0){gGC(j|0,9104152,280)|0}c[8452240+(k<<2)>>2]=c[2113054];c[2394]=-1;k=c[2439330]|0;j=(k|0)==0;if(!j){i=k;gGC(9706056,i|0,76)|0}i=c[2438118]|0;c[2433530]=i;g=c[3528484]|0;c[2076596]=g;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;gGz(9706056,0,76);if(!j){j=k;gGC(j|0,9706056,76)|0}c[2438118]=i;c[3528484]=g;c[2417276]=f;c[1836236]=-1;f=c[2076600]|0;c[f+8>>2]=1;gGz(f+16528|0,0,32);gGz(f+12|0,0,16512);c[2113156]=0;a[9628264]=0;c[2407033]=0;f=c[3541206]|0;c[3541190]=f;c[3541198]=f;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=f+256;c[3541199]=f+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=f+512;c[3541200]=f+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=f+768;c[3541201]=f+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385512]|0)>0){f=0;do{mc(f);f=f+1|0;}while((f|0)<(c[2385512]|0))}c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;lw(c[3540984]|0);c[2388366]=0;c[2430242]=0}}while(0);gGz(9550512,-1|0,14);f=0;g=-1;i=-1;j=-1;k=-1;l=-1;do{g=((a[9633496+f|0]&1)<<f^g&65535)&65535;i=((a[9631352+f|0]&1)<<f^i&65535)&65535;j=((a[9629576+f|0]&1)<<f^j&65535)&65535;k=((a[9628968+f|0]&1)<<f^k&65535)&65535;l=((a[9628736+f|0]&1)<<f^l&65535)&65535;f=f+1|0;}while((f|0)<16);b[4775256]=g;b[4775257]=i;b[4775258]=j;b[4775259]=k;b[4775260]=l;b[4775261]=-1;b[4775262]=-1;l=c[2408963]|0;k=(c[3542196]|0)+(c[2408962]<<16>>16)|0;c[3542196]=k;j=(c[3542192]|0)+(l<<16>>16)|0;c[3542192]=j;if((k|0)<-2048){c[3542196]=-2048;m=-2048}else{m=k}k=(c[2440576]<<8)-2048|0;if((m|0)>(k|0)){c[3542196]=k;n=k}else{n=m}if((j|0)<-2048){c[3542192]=-2048;o=-2048}else{o=j}j=(c[2440574]<<8)-2048|0;if((o|0)>(j|0)){c[3542192]=j;p=j}else{p=o}o=c[2408965]|0;m=(c[3542197]|0)+(c[2408964]<<16>>16)|0;c[3542197]=m;l=(c[3542193]|0)+(o<<16>>16)|0;c[3542193]=l;if((m|0)<-2048){c[3542197]=-2048;q=-2048}else{q=m}if((q|0)>(k|0)){c[3542197]=k;r=k}else{r=q}if((l|0)<-2048){c[3542193]=-2048;s=-2048}else{s=l}if((s|0)>(j|0)){c[3542193]=j;t=j}else{t=s}b[4877700]=189-~~(+(n>>8|0)*.3333333432674408)&255;b[4877701]=~~(+(p>>8|0)*.4285714328289032)+72&255;b[4877702]=189-~~(+(r>>8|0)*.3333333432674408)&255;b[4877703]=~~(+(t>>8|0)*.4285714328289032)+72&255;gu[e&16383]();do{if((c[2112968]|0)!=0){e=c[(c[642608+(c[2436]<<2)>>2]|0)+112>>2]|0;if((e|0)==0){break}gD[e&8191]()|0}}while(0);if((c[2438322]|0)==0){return}e=d[(c[3529656]|0)+1538|0]|0;if((e&32|0)!=0){return}t=c[3529638]|0;r=t+8192|0;if((e&64|0)==0){gGC(r|0,t|0,8192)|0;return}else{gGC(t|0,r|0,8192)|0;return}}function d6o(b,d,e,f,g,i,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;c[2424]=~~(+(c[1623868]|0)/100.0*100.0);d6q(0)|0;c[2414970]=0;d6r();k=c[2414214]|0;l=0;while(1){if((l|0)>=1024){break}m=9638528+(l<<2)|0;if((c[m>>2]|0)==0){n=43513;break}else{l=l+1|0}}do{if((n|0)==43513){l=gGq(k)|0;c[m>>2]=l;if((l|0)==0){break}gGz(l|0,0,k|0);c[2414970]=l;gGz(l|0,0,k|0);d6r();if((d6q(1)|0)!=0){o=1;return o|0}fwR(0);Ux(0,7575,0);c[2407030]=256;c[2407068]=3;if((b|0)!=0){gu[b&16383]()}d6s(g,c[3530846]|0,0);d6s(i,c[3530610]|0,1);d6s(j,c[3530432]|0,2);c[2405120]=d;c[2406742]=e;c[2438322]=f;l=gGq(16584)|0;c[2076600]=l;c[l+16524>>2]=16e6;c[l>>2]=15625;c[l+4>>2]=0;h[l+16560>>3]=1.0;c[l+16576>>2]=1;h[l+16568>>3]=1.0;c[l+16580>>2]=2;UL(4e6,0,1152,0);c[2438224]=16e6;c[2433522]=4710;c[2406672]=148;c[3528468]=444;c[2443842]=127;h[745398]=1.0;a[3203264]=1;Uo(1,4e6,1720,44,134,1);c[2438228]=4e6;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=511;h[745403]=.3;c[2436782]=1;h[745402]=.3;c[2436780]=2;l=c[642608+(c[2436]<<2)>>2]|0;p=c[l+128>>2]|0;if((c[l+52>>2]&4|0)==0){c[2113068]=p;q=c[l+132>>2]|0;c[2113070]=q;c[2443814]=p;c[2440436]=q;r=p;s=q}else{c[2113070]=p;q=c[l+132>>2]|0;c[2113068]=q;c[2440436]=p;c[2443814]=q;r=q;s=p}p=ag(r<<1,s)|0;q=gGq(p)|0;c[2112926]=q;if((q|0)!=0){gGz(q|0,0,p|0)}p=c[642608+(c[2436]<<2)>>2]|0;q=p+124|0;if((c[q>>2]|0)>0){l=c[2406932]|0;t=0;do{c[l+(t<<2)>>2]=t;t=t+1|0;}while((t|0)<(c[q>>2]|0))}c[2442916]=(256-(c[2113070]|0)|0)/2|0;c[2113302]=2;a[801640]=0;q=c[p+128>>2]|0;if((c[p+52>>2]&4|0)==0){c[2440576]=q;t=c[p+132>>2]|0;c[2440574]=t;u=q;v=t}else{c[2440574]=q;t=c[p+132>>2]|0;c[2440576]=t;u=t;v=q}q=(((u|0)/2|0)<<8)-1792|0;t=(((v|0)/2|0)<<8)-2048|0;c[3542196]=q;c[3542192]=t;c[3542197]=q;c[3542193]=t;c[3542198]=q;c[3542194]=t;c[3542199]=q;c[3542195]=t;t=c[2414674]|0;gGz(t|0,0,(c[2411674]|0)-t|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];t=c[3532592]|0;if((t|0)!=0){gGC(9104152,t|0,280)|0}c[2113054]=c[2113060]}RI();t=c[2394]|0;q=c[14130368+(t<<2)>>2]|0;if((q|0)!=0){gGC(q|0,9104152,280)|0}c[8452240+(t<<2)>>2]=c[2113054];c[2394]=-1;t=c[2439330]|0;q=(t|0)==0;if(!q){l=t;gGC(9706056,l|0,76)|0}l=c[2438118]|0;c[2433530]=l;w=c[3528484]|0;c[2076596]=w;x=c[2417276]|0;c[3541536]=x;c[1836236]=0;gGz(9706056,0,76);if(!q){q=t;gGC(q|0,9706056,76)|0}c[2438118]=l;c[3528484]=w;c[2417276]=x;c[1836236]=-1;x=c[2076600]|0;c[x+8>>2]=1;gGz(x+16528|0,0,32);gGz(x+12|0,0,16512);c[2113156]=0;a[9628264]=0;c[2407033]=0;x=c[3541206]|0;c[3541190]=x;c[3541198]=x;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=x+256;c[3541199]=x+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=x+512;c[3541200]=x+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=x+768;c[3541201]=x+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385512]|0)>0){x=0;do{mc(x);x=x+1|0;}while((x|0)<(c[2385512]|0))}c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;lw(c[3540984]|0);c[2388366]=0;c[2430242]=0;o=0;return o|0}}while(0);c[2414970]=0;o=1;return o|0}function d6p(b){b=b|0;var d=0,e=0,f=0,g=0;d=b>>>1&8191;e=c[2076600]|0;if((b&1|0)==0){f=e+8204+d|0;g=a[f]|0;return g|0}f=(c[e+4>>2]^d)+(e+12)|0;g=a[f]|0;return g|0}function d6q(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;b=i;i=i+504|0;d=b|0;e=b+112|0;f=b+120|0;g=b+232|0;h=b+240|0;j=b+248|0;k=b+360|0;l=b+472|0;m=b+480|0;c[l>>2]=c[2388160];c[l+4>>2]=c[2386356];n=m|0;c[n>>2]=c[3530846];o=m+4|0;c[o>>2]=c[3530610];p=m+8|0;c[p>>2]=c[3530432];q=m+12|0;c[q>>2]=c[2386648];r=m+16|0;c[r>>2]=c[3531002];L57350:do{if((gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](h,0,0)|0)==0){s=j+108|0;t=(a|0)!=0;u=j+100|0;v=t^1;w=k+108|0;x=k+100|0;y=(a|0)==0;z=d+108|0;A=d+100|0;B=f+108|0;C=f+100|0;D=0;L57352:while(1){gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,D)|0;E=D+1|0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,E)|0;F=c[s>>2]|0;G=F&7;L57354:do{if(G>>>0>2|(G|0)==0){H=G-3|0;if(H>>>0>=5){I=D;break}if((F&8|0)==0){J=m+(H<<2)|0;K=c[J>>2]|0;do{if(t){if((c[3542200]|0)==0){L=1;M=43595;break L57352}c[z>>2]=0;c[A>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](d,D)|0;if((c[z>>2]|0)==0){break}N=c[A>>2]|0;c[e>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](e,D,0)|0;if((N|0)<1){L=1;M=43593;break L57352}if((gzL(K,0,D)|0)!=0){L=1;M=43594;break L57352}}}while(0);c[J>>2]=K+(c[u>>2]|0);I=D;break}if(t){if((R6(c[m+(H<<2)>>2]|0,D,2)|0)!=0){L=1;M=43590;break L57352}P=c[s>>2]|0}else{P=F}N=(P&16|0)!=0;if(N|v){Q=N?D:E;R=c[m+(H<<2)>>2]|0}else{N=c[m+(H<<2)>>2]|0;if((R6(N+1|0,E,2)|0)==0){Q=E;R=N}else{L=1;M=43597;break L57352}}c[m+(H<<2)>>2]=R+(c[u>>2]<<1);I=Q}else{N=F&1^1;do{if((c[w>>2]&7|0)==1){O=c[x>>2]|0;if((O|0)!=(c[u>>2]|0)){break}S=l+(N<<2)|0;T=c[S>>2]|0;if(y){U=O}else{if((R6(T,E,2)|0)!=0){L=1;M=43596;break L57352}if((R6(T+1|0,D,2)|0)!=0){L=1;M=43588;break L57352}U=c[u>>2]|0}c[S>>2]=T+(U<<1);I=E;break L57354}}while(0);H=l+(N<<2)|0;K=c[H>>2]|0;do{if(!y){if((c[3542200]|0)==0){L=1;M=43592;break L57352}c[B>>2]=0;c[C>>2]=0;J=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[J&16383](f,D)|0;if((c[B>>2]|0)==0){break}J=c[C>>2]|0;c[g>>2]=9534384;T=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[T&16383](g,D,0)|0;if((J|0)<1){L=1;M=43589;break L57352}if((gzL(K,0,D)|0)!=0){L=1;M=43586;break L57352}}}while(0);c[H>>2]=K+(c[u>>2]|0);I=D}}while(0);D=I+1|0;if((gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](h,D,0)|0)!=0){break L57350}}if((M|0)==43588){i=b;return L|0}else if((M|0)==43589){i=b;return L|0}else if((M|0)==43590){i=b;return L|0}else if((M|0)==43592){i=b;return L|0}else if((M|0)==43593){i=b;return L|0}else if((M|0)==43586){i=b;return L|0}else if((M|0)==43594){i=b;return L|0}else if((M|0)==43595){i=b;return L|0}else if((M|0)==43596){i=b;return L|0}else if((M|0)==43597){i=b;return L|0}}}while(0);if((a|0)!=0){L=0;i=b;return L|0}c[2387024]=(c[n>>2]|0)-(c[3530846]|0);c[2387025]=(c[o>>2]|0)-(c[3530610]|0);c[2387026]=(c[p>>2]|0)-(c[3530432]|0);c[2387027]=(c[q>>2]|0)-(c[2386648]|0);c[2387028]=(c[r>>2]|0)-(c[3531002]|0);L=0;i=b;return L|0}function d6r(){var a=0,b=0,d=0,e=0;a=c[2414970]|0;c[2388160]=a;c[2386356]=a+2097152;c[3530432]=a+2424832;b=(c[2387026]<<1)+2424832|0;c[3530610]=a+b;d=b+(c[2387025]<<1)|0;c[3530846]=a+d;b=d+(c[2387024]<<1)|0;c[3531002]=a+b;d=b+2048|0;b=a+d|0;c[3541206]=b;c[3531862]=b;c[2386648]=b;b=(c[2387027]|0)+1048576+d|0;c[2406932]=a+b;d=c[(c[642608+(c[2436]<<2)>>2]|0)+124>>2]<<2;e=d+b|0;c[3530018]=a+e;b=d+e|0;c[2406298]=a+b;e=a+(b+1024)|0;c[2414674]=e;c[2388286]=e;c[3531132]=a+(b+1049600);c[2386360]=a+(b+1180672);c[2387204]=a+(b+1184768);c[3529656]=a+(b+1188864);c[3529638]=a+(b+1190912);c[3529470]=a+(b+1272832);c[2438730]=a+(b+1338368);c[3529436]=a+(b+1338376);c[2438728]=a+(b+1403912);c[2443352]=a+(b+1403920);c[3528280]=a+(b+1403928);c[2388460]=a+(b+1403929);c[2443688]=a+(b+1403933);c[3527304]=a+(b+1403937);e=a+(b+1408033)|0;c[2411674]=e;c[2414214]=e;return}function d6s(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;g=i;i=i+96|0;h=g|0;j=g+16|0;k=g+32|0;l=g+56|0;m=g+80|0;n=9751056+(f<<2)|0;c[n>>2]=0;o=c[9548096+(f<<2)>>2]|0;if((o|0)==0){c[14123872+(f<<2)>>2]=1;i=g;return}if((b|0)==-1){i=g;return}p=o<<3;q=(p|0)/2|0;c[h>>2]=q+8;c[h+4>>2]=q;c[h+8>>2]=8;c[h+12>>2]=0;c[j>>2]=0;c[j+4>>2]=4;c[j+8>>2]=q;r=q+4|0;c[j+12>>2]=r;s=(p|0)/3|0;c[k>>2]=0;c[k+4>>2]=4;c[k+8>>2]=s;c[k+12>>2]=s+4;t=s<<1;c[k+16>>2]=t;c[k+20>>2]=t+4;c[l>>2]=q;c[l+4>>2]=r;c[l+8>>2]=8;c[l+12>>2]=12;c[l+16>>2]=0;c[l+20>>2]=4;r=(p|0)/4|0;c[m>>2]=0;c[m+4>>2]=r;c[m+8>>2]=r<<1;c[m+12>>2]=r*3|0;r=0;while(1){if((r|0)>=1024){u=43714;break}v=9638528+(r<<2)|0;if((c[v>>2]|0)==0){break}else{r=r+1|0}}if((u|0)==43714){i=g;return}r=gGq(o)|0;c[v>>2]=r;if((r|0)==0){i=g;return}gGz(r|0,0,o|0);gGC(r|0,e|0,o)|0;switch(b|0){case 4:{b=(p|0)/1536|0;if((p|0)>1535){p=0;do{v=p<<8;gGz(e+v|0,0,256);q=p<<9;t=0;do{s=1<<5-t;w=(c[k+(t<<2)>>2]|0)+q|0;x=0;do{y=w+(c[611712+(x<<2)>>2]|0)|0;z=(x<<4)+v|0;A=0;do{B=y+(c[613600+(A<<2)>>2]|0)|0;if((d[r+((B|0)/8|0)|0]&128>>>((B&7)>>>0)|0)!=0){B=e+(z+A)|0;a[B]=(d[B]|s)&255}A=A+1|0;}while((A|0)<16);x=x+1|0;}while((x|0)<16);t=t+1|0;}while((t|0)<6);p=p+1|0;}while((p|0)<(b|0))}p=14123872+(f<<2)|0;c[p>>2]=b;c[14109960+(f<<2)>>2]=6;C=p;break};case 0:{p=o<<1;b=(p|0)/256|0;if((p|0)>255){p=0;do{k=p<<8;gGz(e+k|0,0,256);t=p<<9;v=0;do{q=1<<3-v;x=(c[h+(v<<2)>>2]|0)+t|0;s=0;do{w=x+(c[597800+(s<<2)>>2]|0)|0;A=(s<<4)+k|0;z=0;do{y=w+(c[597864+(z<<2)>>2]|0)|0;if((d[r+((y|0)/8|0)|0]&128>>>((y&7)>>>0)|0)!=0){y=e+(A+z)|0;a[y]=(d[y]|q)&255}z=z+1|0;}while((z|0)<16);s=s+1|0;}while((s|0)<16);v=v+1|0;}while((v|0)<4);p=p+1|0;}while((p|0)<(b|0))}p=14123872+(f<<2)|0;c[p>>2]=b;c[14109960+(f<<2)>>2]=4;C=p;break};case 6:{p=o<<1;b=(p|0)/256|0;if((p|0)>255){p=0;do{h=p<<8;gGz(e+h|0,0,256);v=0;do{k=1<<3-v;t=(c[m+(v<<2)>>2]|0)+h|0;s=0;do{q=t+(c[613408+(s<<2)>>2]|0)|0;x=(s<<4)+h|0;z=0;do{A=q+(c[601400+(z<<2)>>2]|0)|0;if((d[r+((A|0)/8|0)|0]&128>>>((A&7)>>>0)|0)!=0){A=e+(x+z)|0;a[A]=(d[A]|k)&255}z=z+1|0;}while((z|0)<16);s=s+1|0;}while((s|0)<16);v=v+1|0;}while((v|0)<4);p=p+1|0;}while((p|0)<(b|0))}p=14123872+(f<<2)|0;c[p>>2]=b;c[14109960+(f<<2)>>2]=4;C=p;break};case 5:{p=o<<1;b=(p|0)/256|0;if((p|0)>255){p=0;do{v=p<<8;gGz(e+v|0,0,256);h=0;do{s=1<<3-h;k=(c[m+(h<<2)>>2]|0)+v|0;t=0;do{z=k+(c[611776+(t<<2)>>2]|0)|0;x=(t<<4)+v|0;q=0;do{A=z+(c[601400+(q<<2)>>2]|0)|0;if((d[r+((A|0)/8|0)|0]&128>>>((A&7)>>>0)|0)!=0){A=e+(x+q)|0;a[A]=(d[A]|s)&255}q=q+1|0;}while((q|0)<16);t=t+1|0;}while((t|0)<16);h=h+1|0;}while((h|0)<4);p=p+1|0;}while((p|0)<(b|0))}p=14123872+(f<<2)|0;c[p>>2]=b;c[14109960+(f<<2)>>2]=4;C=p;break};case 2:{p=o<<1;b=(p|0)/256|0;if((p|0)>255){p=0;do{h=p<<8;gGz(e+h|0,0,256);v=p<<10;t=0;do{s=1<<3-t;k=(c[l+(t+2<<2)>>2]|0)+v|0;q=0;do{x=k+(c[613472+(q<<2)>>2]|0)|0;z=(q<<4)+h|0;A=0;do{w=x+(c[613536+(A<<2)>>2]|0)|0;if((d[r+((w|0)/8|0)|0]&128>>>((w&7)>>>0)|0)!=0){w=e+(z+A)|0;a[w]=(d[w]|s)&255}A=A+1|0;}while((A|0)<16);q=q+1|0;}while((q|0)<16);t=t+1|0;}while((t|0)<4);p=p+1|0;}while((p|0)<(b|0))}p=14123872+(f<<2)|0;c[p>>2]=b;c[14109960+(f<<2)>>2]=4;C=p;break};case 1:{p=o<<1;b=(p|0)/256|0;if((p|0)>255){p=0;do{t=p<<8;gGz(e+t|0,0,256);h=p<<9;v=0;do{q=1<<3-v;s=(c[j+(v<<2)>>2]|0)+h|0;k=0;do{A=s+(c[611712+(k<<2)>>2]|0)|0;z=(k<<4)+t|0;x=0;do{w=A+(c[613600+(x<<2)>>2]|0)|0;if((d[r+((w|0)/8|0)|0]&128>>>((w&7)>>>0)|0)!=0){w=e+(z+x)|0;a[w]=(d[w]|q)&255}x=x+1|0;}while((x|0)<16);k=k+1|0;}while((k|0)<16);v=v+1|0;}while((v|0)<4);p=p+1|0;}while((p|0)<(b|0))}p=14123872+(f<<2)|0;c[p>>2]=b;c[14109960+(f<<2)>>2]=4;C=p;break};case 3:{p=(o|0)/256|0;if((o|0)>255){b=0;do{j=b<<8;gGz(e+j|0,0,256);v=b<<10;t=0;do{h=1<<5-t;k=(c[l+(t<<2)>>2]|0)+v|0;q=0;do{s=k+(c[613472+(q<<2)>>2]|0)|0;x=(q<<4)+j|0;z=0;do{A=s+(c[613536+(z<<2)>>2]|0)|0;if((d[r+((A|0)/8|0)|0]&128>>>((A&7)>>>0)|0)!=0){A=e+(x+z)|0;a[A]=(d[A]|h)&255}z=z+1|0;}while((z|0)<16);q=q+1|0;}while((q|0)<16);t=t+1|0;}while((t|0)<6);b=b+1|0;}while((b|0)<(p|0))}b=14123872+(f<<2)|0;c[b>>2]=p;c[14109960+(f<<2)>>2]=6;C=b;break};case 7:{b=o<<1;o=(b|0)/256|0;if((b|0)>255){b=0;do{p=b<<8;gGz(e+p|0,0,256);l=0;do{t=1<<3-l;j=(c[m+(l<<2)>>2]|0)+p|0;v=0;do{q=j+(c[613344+(v<<2)>>2]|0)|0;h=(v<<4)+p|0;k=0;do{z=q+(c[601400+(k<<2)>>2]|0)|0;if((d[r+((z|0)/8|0)|0]&128>>>((z&7)>>>0)|0)!=0){z=e+(h+k)|0;a[z]=(d[z]|t)&255}k=k+1|0;}while((k|0)<16);v=v+1|0;}while((v|0)<16);l=l+1|0;}while((l|0)<4);b=b+1|0;}while((b|0)<(o|0))}b=14123872+(f<<2)|0;c[b>>2]=o;c[14109960+(f<<2)>>2]=4;C=b;break};default:{C=14123872+(f<<2)|0}}f=0;while(1){if((f|0)>=1024){break}D=9638528+(f<<2)|0;if((c[D>>2]|0)==(r|0)){u=43699;break}else{f=f+1|0}}if((u|0)==43699){gGr(r);c[D>>2]=0}D=c[C>>2]|0;C=0;while(1){if((C|0)>=1024){E=0;break}F=9638528+(C<<2)|0;if((c[F>>2]|0)==0){u=43703;break}else{C=C+1|0}}do{if((u|0)==43703){C=gGq(D)|0;c[F>>2]=C;if((C|0)==0){E=0;break}gGz(C|0,0,D|0);E=C}}while(0);c[n>>2]=E;n=D<<8;if((n|0)>0){G=0}else{i=g;return}do{D=E+(G>>8)|0;a[D]=1;F=0;while(1){if((F|0)>=256){break}if((a[e+(F+G)|0]|0)==0){F=F+1|0}else{u=43709;break}}if((u|0)==43709){u=0;a[D]=0}G=G+256|0;}while((G|0)<(n|0));i=g;return}function d6t(a){a=a|0;var b=0,d=0;b=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,16e6,0)|0;return a|0}function d6u(b,c){b=b|0;c=c|0;if((c|0)==0){a[9706117]=0;return}if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;return}function d6v(a){a=a|0;var b=0,d=0;b=(c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,4e6,0)|0;return a|0}function d6w(){return+(+((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)/4.0e6)}function d6x(){var b=0,d=0,e=0,f=0;b=((c[2405120]|0)*100|0|0)/(c[1623868]|0)|0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}d=(b|0)/6|0;c[2113056]=d;b=RG(d)|0;c[2113054]=(c[2113054]|0)+b;c[2276108]=-1;c[2113056]=-1;c[8452200+(c[2394]<<2)>>2]=8194;c[2276080]=512;if((c[2276079]|0)>>>0<512){RH(2)}c[2113056]=d;b=RG(d)|0;c[2113054]=(c[2113054]|0)+b;c[2276108]=-1;c[2113056]=-1;c[8452200+(c[2394]<<2)>>2]=8194;c[2276080]=512;if((c[2276079]|0)>>>0<512){RH(2)}c[2113056]=d;b=RG(d)|0;c[2113054]=(c[2113054]|0)+b;c[2276108]=-1;c[2113056]=-1;c[8452200+(c[2394]<<2)>>2]=8194;c[2276080]=512;if((c[2276079]|0)>>>0<512){RH(2)}c[2113056]=d;b=RG(d)|0;c[2113054]=(c[2113054]|0)+b;c[2276108]=-1;c[2113056]=-1;c[8452200+(c[2394]<<2)>>2]=8194;c[2276080]=512;if((c[2276079]|0)>>>0<512){RH(2)}c[2113056]=d;b=RG(d)|0;c[2113054]=(c[2113054]|0)+b;c[2276108]=-1;c[2113056]=-1;c[8452200+(c[2394]<<2)>>2]=8194;c[2276080]=512;if((c[2276079]|0)>>>0<512){RH(2)}c[2113056]=d;b=RG(d)|0;c[2113054]=(c[2113054]|0)+b;c[2276108]=-1;c[2113056]=-1;c[8452200+(c[2394]<<2)>>2]=8193;c[2276080]=256;if((c[2276079]|0)>>>0<256){RH(1)}gu[c[3528468]&16383]();c[2443834]=0;b=c[2112964]|0;if((b|0)!=0){Uu(0,b,a[9688]|0?534:0)}b=c[2394]|0;d=c[14130368+(b<<2)>>2]|0;if((d|0)==0){e=c[2113054]|0;f=8452240+(b<<2)|0;c[f>>2]=e;c[2394]=-1;return}gGC(d|0,9104152,280)|0;e=c[2113054]|0;f=8452240+(b<<2)|0;c[f>>2]=e;c[2394]=-1;return}function d6y(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;fxU(0,425984);if((c[2394]|0)==0){a=c[2112932]|0}else{c[2394]=0;d=c[3532596]|0;c[2112932]=d;e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060];a=d}d=c[2388160]|0;e=a|0;f=0;while(1){g=d+f|0;c[e>>2]=g;c[e+131072>>2]=g;g=f+1024|0;if(g>>>0>524287){break}else{e=e+4|0;f=g}}f=c[2388286]|0;e=a+16384|0;g=4194304;while(1){h=f+(g-4194304)|0;c[e>>2]=h;c[e+65536>>2]=h;c[e+131072>>2]=h;h=g+1024|0;if(h>>>0>4259839){break}else{e=e+4|0;g=h}}g=c[2387204]|0;c[a+25604>>2]=g;c[a+91140>>2]=g;c[a+156676>>2]=g;e=g+1024|0;c[a+25608>>2]=e;c[a+91144>>2]=e;c[a+156680>>2]=e;e=g+2048|0;c[a+25612>>2]=e;c[a+91148>>2]=e;c[a+156684>>2]=e;e=c[3529436]|0;c[a+32768>>2]=e;c[a+98304>>2]=e;c[a+163840>>2]=e;g=e+1024|0;c[a+32772>>2]=g;c[a+98308>>2]=g;c[a+163844>>2]=g;g=e+2048|0;c[a+32776>>2]=g;c[a+98312>>2]=g;c[a+163848>>2]=g;g=e+3072|0;c[a+32780>>2]=g;c[a+98316>>2]=g;c[a+163852>>2]=g;g=e+4096|0;c[a+32784>>2]=g;c[a+98320>>2]=g;c[a+163856>>2]=g;g=e+5120|0;c[a+32788>>2]=g;c[a+98324>>2]=g;c[a+163860>>2]=g;g=e+6144|0;c[a+32792>>2]=g;c[a+98328>>2]=g;c[a+163864>>2]=g;g=e+7168|0;c[a+32796>>2]=g;c[a+98332>>2]=g;c[a+163868>>2]=g;g=e+8192|0;c[a+32800>>2]=g;c[a+98336>>2]=g;c[a+163872>>2]=g;g=e+9216|0;c[a+32804>>2]=g;c[a+98340>>2]=g;c[a+163876>>2]=g;g=e+10240|0;c[a+32808>>2]=g;c[a+98344>>2]=g;c[a+163880>>2]=g;g=e+11264|0;c[a+32812>>2]=g;c[a+98348>>2]=g;c[a+163884>>2]=g;g=e+12288|0;c[a+32816>>2]=g;c[a+98352>>2]=g;c[a+163888>>2]=g;g=e+13312|0;c[a+32820>>2]=g;c[a+98356>>2]=g;c[a+163892>>2]=g;g=e+14336|0;c[a+32824>>2]=g;c[a+98360>>2]=g;c[a+163896>>2]=g;g=e+15360|0;c[a+32828>>2]=g;c[a+98364>>2]=g;c[a+163900>>2]=g;g=c[3529470]|0;c[a+34816>>2]=g;c[a+100352>>2]=g;c[a+165888>>2]=g;e=g+1024|0;c[a+34820>>2]=e;c[a+100356>>2]=e;c[a+165892>>2]=e;e=g+2048|0;c[a+34824>>2]=e;c[a+100360>>2]=e;c[a+165896>>2]=e;e=g+3072|0;c[a+34828>>2]=e;c[a+100364>>2]=e;c[a+165900>>2]=e;e=g+4096|0;c[a+34832>>2]=e;c[a+100368>>2]=e;c[a+165904>>2]=e;e=g+5120|0;c[a+34836>>2]=e;c[a+100372>>2]=e;c[a+165908>>2]=e;e=g+6144|0;c[a+34840>>2]=e;c[a+100376>>2]=e;c[a+165912>>2]=e;e=g+7168|0;c[a+34844>>2]=e;c[a+100380>>2]=e;c[a+165916>>2]=e;e=g+8192|0;c[a+34848>>2]=e;c[a+100384>>2]=e;c[a+165920>>2]=e;e=g+9216|0;c[a+34852>>2]=e;c[a+100388>>2]=e;c[a+165924>>2]=e;e=g+10240|0;c[a+34856>>2]=e;c[a+100392>>2]=e;c[a+165928>>2]=e;e=g+11264|0;c[a+34860>>2]=e;c[a+100396>>2]=e;c[a+165932>>2]=e;e=g+12288|0;c[a+34864>>2]=e;c[a+100400>>2]=e;c[a+165936>>2]=e;e=g+13312|0;c[a+34868>>2]=e;c[a+100404>>2]=e;c[a+165940>>2]=e;e=g+14336|0;c[a+34872>>2]=e;c[a+100408>>2]=e;c[a+165944>>2]=e;e=g+15360|0;c[a+34876>>2]=e;c[a+100412>>2]=e;c[a+165948>>2]=e;e=c[3529656]|0;c[a+40960>>2]=e;c[a+106496>>2]=e;c[a+172032>>2]=e;g=e+1024|0;c[a+40964>>2]=g;c[a+106500>>2]=g;c[a+172036>>2]=g;g=c[3529638]|0;c[a+45056>>2]=g;c[a+110592>>2]=g;c[a+176128>>2]=g;e=g+1024|0;c[a+45060>>2]=e;c[a+110596>>2]=e;c[a+176132>>2]=e;e=g+2048|0;c[a+45064>>2]=e;c[a+110600>>2]=e;c[a+176136>>2]=e;e=g+3072|0;c[a+45068>>2]=e;c[a+110604>>2]=e;c[a+176140>>2]=e;e=g+4096|0;c[a+45072>>2]=e;c[a+110608>>2]=e;c[a+176144>>2]=e;e=g+5120|0;c[a+45076>>2]=e;c[a+110612>>2]=e;c[a+176148>>2]=e;e=g+6144|0;c[a+45080>>2]=e;c[a+110616>>2]=e;c[a+176152>>2]=e;e=g+7168|0;c[a+45084>>2]=e;c[a+110620>>2]=e;c[a+176156>>2]=e;e=g+8192|0;c[a+45088>>2]=e;c[a+110624>>2]=e;c[a+176160>>2]=e;e=g+9216|0;c[a+45092>>2]=e;c[a+110628>>2]=e;c[a+176164>>2]=e;e=g+10240|0;c[a+45096>>2]=e;c[a+110632>>2]=e;c[a+176168>>2]=e;e=g+11264|0;c[a+45100>>2]=e;c[a+110636>>2]=e;c[a+176172>>2]=e;e=g+12288|0;c[a+45104>>2]=e;c[a+110640>>2]=e;c[a+176176>>2]=e;e=g+13312|0;c[a+45108>>2]=e;c[a+110644>>2]=e;c[a+176180>>2]=e;e=g+14336|0;c[a+45112>>2]=e;c[a+110648>>2]=e;c[a+176184>>2]=e;e=g+15360|0;c[a+45116>>2]=e;c[a+110652>>2]=e;c[a+176188>>2]=e;c[a+196728>>2]=802;c[a+196648>>2]=462;c[a+196688>>2]=2444;c[a+196608>>2]=566;a=c[3532592]|0;if((a|0)==0){i=c[2113054]|0;c[2113060]=i;c[2394]=-1;j=d+4216|0;k=j;b[k>>1]=20081;d6z();return}gGC(a|0,9104152,280)|0;i=c[2113054]|0;c[2113060]=i;c[2394]=-1;j=d+4216|0;k=j;b[k>>1]=20081;d6z();return}function d6z(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[2387025]|0;d=0;while(1){if((d|0)>=1024){e=0;break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==0){g=43769;break}else{d=d+1|0}}do{if((g|0)==43769){d=gGq(b)|0;c[f>>2]=d;if((d|0)==0){e=0;break}gGz(d|0,0,b|0);e=d}}while(0);f=c[3530610]|0;d=f+262144|0;h=(b|0)==1048576;if(h){b=f+524288|0;gGC(d|0,b|0,524288)|0;i=0}else{i=0}do{b=i<<1;a[e+(i+262144)|0]=a[f+(b+262144)|0]|0;a[e+i|0]=a[f+((b|1)+262144)|0]|0;i=i+1|0;}while((i|0)<262144);gGC(d|0,e|0,524288)|0;d=c[3530432]|0;i=d+262144|0;if(h){h=d+524288|0;gGC(i|0,h|0,524288)|0;j=0}else{j=0}do{h=j<<1;a[e+(j+262144)|0]=a[d+(h+262144)|0]|0;a[e+j|0]=a[d+((h|1)+262144)|0]|0;j=j+1|0;}while((j|0)<262144);gGC(i|0,e|0,524288)|0;c[2387026]=786432;c[2387025]=786432;i=0;while(1){if((i|0)>=1024){g=43782;break}k=9638528+(i<<2)|0;if((c[k>>2]|0)==(e|0)){break}else{i=i+1|0}}if((g|0)==43782){return}gGr(e);c[k>>2]=0;return}function d6A(){var a=0,b=0,d=0,e=0,f=0,g=0;fxU(0,425984);if((c[2394]|0)==0){a=c[2112932]|0}else{c[2394]=0;b=c[3532596]|0;c[2112932]=b;d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];a=b}b=c[2388160]|0;d=a|0;e=0;while(1){f=b+e|0;c[d>>2]=f;c[d+131072>>2]=f;f=e+1024|0;if(f>>>0>655359){break}else{d=d+4|0;e=f}}e=c[3531132]|0;c[a+8192>>2]=e;c[a+73728>>2]=e;c[a+139264>>2]=e;d=e+1024|0;c[a+8196>>2]=d;c[a+73732>>2]=d;c[a+139268>>2]=d;d=e+2048|0;c[a+8200>>2]=d;c[a+73736>>2]=d;c[a+139272>>2]=d;d=e+3072|0;c[a+8204>>2]=d;c[a+73740>>2]=d;c[a+139276>>2]=d;d=c[2387204]|0;c[a+28672>>2]=d;c[a+94208>>2]=d;c[a+159744>>2]=d;d=c[3529470]|0;e=a+36864|0;b=9437184;while(1){f=d+(b-9437184)|0;c[e>>2]=f;c[e+65536>>2]=f;c[e+131072>>2]=f;f=b+1024|0;if(f>>>0>9457663){break}else{e=e+4|0;b=f}}b=c[3529656]|0;c[a+53248>>2]=b;c[a+118784>>2]=b;c[a+184320>>2]=b;e=b+1024|0;c[a+53252>>2]=e;c[a+118788>>2]=e;c[a+184324>>2]=e;e=c[3529638]|0;c[a+57344>>2]=e;c[a+122880>>2]=e;c[a+188416>>2]=e;b=e+1024|0;c[a+57348>>2]=b;c[a+122884>>2]=b;c[a+188420>>2]=b;b=e+2048|0;c[a+57352>>2]=b;c[a+122888>>2]=b;c[a+188424>>2]=b;b=e+3072|0;c[a+57356>>2]=b;c[a+122892>>2]=b;c[a+188428>>2]=b;b=e+4096|0;c[a+57360>>2]=b;c[a+122896>>2]=b;c[a+188432>>2]=b;b=e+5120|0;c[a+57364>>2]=b;c[a+122900>>2]=b;c[a+188436>>2]=b;b=e+6144|0;c[a+57368>>2]=b;c[a+122904>>2]=b;c[a+188440>>2]=b;b=e+7168|0;c[a+57372>>2]=b;c[a+122908>>2]=b;c[a+188444>>2]=b;b=e+8192|0;c[a+57376>>2]=b;c[a+122912>>2]=b;c[a+188448>>2]=b;b=e+9216|0;c[a+57380>>2]=b;c[a+122916>>2]=b;c[a+188452>>2]=b;b=e+10240|0;c[a+57384>>2]=b;c[a+122920>>2]=b;c[a+188456>>2]=b;b=e+11264|0;c[a+57388>>2]=b;c[a+122924>>2]=b;c[a+188460>>2]=b;b=e+12288|0;c[a+57392>>2]=b;c[a+122928>>2]=b;c[a+188464>>2]=b;b=e+13312|0;c[a+57396>>2]=b;c[a+122932>>2]=b;c[a+188468>>2]=b;b=e+14336|0;c[a+57400>>2]=b;c[a+122936>>2]=b;c[a+188472>>2]=b;b=e+15360|0;c[a+57404>>2]=b;c[a+122940>>2]=b;c[a+188476>>2]=b;b=c[2388286]|0;e=a+65280|0;d=16711680;while(1){f=b+(d-16711680)|0;c[e>>2]=f;c[e+65536>>2]=f;c[e+131072>>2]=f;f=d+1024|0;if(f>>>0>16777215){break}else{e=e+4|0;d=f}}c[a+196728>>2]=2886;c[a+196648>>2]=424;c[a+196688>>2]=612;c[a+196608>>2]=2396;a=c[3532592]|0;if((a|0)==0){g=c[2113054]|0;c[2113060]=g;c[2394]=-1;return}gGC(a|0,9104152,280)|0;g=c[2113054]|0;c[2113060]=g;c[2394]=-1;return}function d6B(){var a=0,b=0,d=0;a=((c[2405120]|0)*100|0|0)/(c[1623868]|0)|0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];b=c[3532592]|0;if((b|0)!=0){gGC(9104152,b|0,280)|0}c[2113054]=c[2113060]}b=(a|0)/10|0;a=0;do{c[2113056]=b;d=RG(b)|0;c[2113054]=(c[2113054]|0)+d;c[2276108]=-1;c[2113056]=-1;d=(a&1|0)!=0;do{if(d&(a|0)==1){c[8452200+(c[2394]<<2)>>2]=8194;c[2276080]=512;if((c[2276079]|0)>>>0>=512){break}RH(2)}}while(0);do{if(d&(a|0)!=1){c[8452200+(c[2394]<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0>=1024){break}RH(4)}}while(0);a=a+1|0;}while((a|0)<10);a=c[2394]|0;b=c[14130368+(a<<2)>>2]|0;if((b|0)!=0){gGC(b|0,9104152,280)|0}c[8452240+(a<<2)>>2]=c[2113054];c[2394]=-1;if((c[2112964]|0)==0){return}TV();return}function d6C(){var b=0,d=0,e=0,f=0;d6D();if((c[2394]|0)==0){b=c[2112932]|0;d=c[3532592]|0}else{c[2394]=0;e=c[3532596]|0;c[2112932]=e;f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];b=e;d=f}c[b+73728>>2]=c[2406298];c[b+8192>>2]=2;c[b+196616>>2]=1830;c[b+45056>>2]=3;c[b+110592>>2]=3;c[b+45060>>2]=3;c[b+110596>>2]=3;c[b+45064>>2]=3;c[b+110600>>2]=3;c[b+45068>>2]=3;c[b+110604>>2]=3;c[b+196620>>2]=772;c[b+196700>>2]=2636;c[b+196740>>2]=980;c[b+196660>>2]=2730;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;d=0;b=c[2388160]|0;while(1){f=a[b]|0;e=b+1|0;a[b]=a[e]|0;a[e]=f;f=d+1|0;if((f|0)<262144){d=f;b=b+2|0}else{break}}return}function d6D(){var a=0,b=0,d=0,e=0,f=0,g=0;c[2432966]=c[2406298];fxU(0,425984);if((c[2394]|0)==0){a=c[2112932]|0}else{c[2394]=0;b=c[3532596]|0;c[2112932]=b;d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];a=b}b=c[2388160]|0;d=a|0;e=0;while(1){f=b+e|0;c[d>>2]=f;c[d+131072>>2]=f;f=e+1024|0;if(f>>>0>655359){break}else{d=d+4|0;e=f}}e=c[2387204]|0;c[a+28672>>2]=e;c[a+94208>>2]=e;c[a+159744>>2]=e;e=c[3529470]|0;c[a+36864>>2]=e;c[a+102400>>2]=e;c[a+167936>>2]=e;d=e+1024|0;c[a+36868>>2]=d;c[a+102404>>2]=d;c[a+167940>>2]=d;d=e+2048|0;c[a+36872>>2]=d;c[a+102408>>2]=d;c[a+167944>>2]=d;d=e+3072|0;c[a+36876>>2]=d;c[a+102412>>2]=d;c[a+167948>>2]=d;d=e+4096|0;c[a+36880>>2]=d;c[a+102416>>2]=d;c[a+167952>>2]=d;d=e+5120|0;c[a+36884>>2]=d;c[a+102420>>2]=d;c[a+167956>>2]=d;d=e+6144|0;c[a+36888>>2]=d;c[a+102424>>2]=d;c[a+167960>>2]=d;d=e+7168|0;c[a+36892>>2]=d;c[a+102428>>2]=d;c[a+167964>>2]=d;d=e+8192|0;c[a+36896>>2]=d;c[a+102432>>2]=d;c[a+167968>>2]=d;d=e+9216|0;c[a+36900>>2]=d;c[a+102436>>2]=d;c[a+167972>>2]=d;d=e+10240|0;c[a+36904>>2]=d;c[a+102440>>2]=d;c[a+167976>>2]=d;d=e+11264|0;c[a+36908>>2]=d;c[a+102444>>2]=d;c[a+167980>>2]=d;d=e+12288|0;c[a+36912>>2]=d;c[a+102448>>2]=d;c[a+167984>>2]=d;d=e+13312|0;c[a+36916>>2]=d;c[a+102452>>2]=d;c[a+167988>>2]=d;d=e+14336|0;c[a+36920>>2]=d;c[a+102456>>2]=d;c[a+167992>>2]=d;d=e+15360|0;c[a+36924>>2]=d;c[a+102460>>2]=d;c[a+167996>>2]=d;d=c[3527304]|0;c[a+110592>>2]=d;c[a+110596>>2]=d+1024;c[a+110600>>2]=d+2048;c[a+110604>>2]=d+3072;d=c[3529656]|0;c[a+53248>>2]=d;c[a+118784>>2]=d;c[a+184320>>2]=d;e=d+1024|0;c[a+53252>>2]=e;c[a+118788>>2]=e;c[a+184324>>2]=e;e=c[3529638]|0;c[a+57344>>2]=e;c[a+122880>>2]=e;c[a+188416>>2]=e;d=e+1024|0;c[a+57348>>2]=d;c[a+122884>>2]=d;c[a+188420>>2]=d;d=e+2048|0;c[a+57352>>2]=d;c[a+122888>>2]=d;c[a+188424>>2]=d;d=e+3072|0;c[a+57356>>2]=d;c[a+122892>>2]=d;c[a+188428>>2]=d;d=e+4096|0;c[a+57360>>2]=d;c[a+122896>>2]=d;c[a+188432>>2]=d;d=e+5120|0;c[a+57364>>2]=d;c[a+122900>>2]=d;c[a+188436>>2]=d;d=e+6144|0;c[a+57368>>2]=d;c[a+122904>>2]=d;c[a+188440>>2]=d;d=e+7168|0;c[a+57372>>2]=d;c[a+122908>>2]=d;c[a+188444>>2]=d;d=e+8192|0;c[a+57376>>2]=d;c[a+122912>>2]=d;c[a+188448>>2]=d;d=e+9216|0;c[a+57380>>2]=d;c[a+122916>>2]=d;c[a+188452>>2]=d;d=e+10240|0;c[a+57384>>2]=d;c[a+122920>>2]=d;c[a+188456>>2]=d;d=e+11264|0;c[a+57388>>2]=d;c[a+122924>>2]=d;c[a+188460>>2]=d;d=e+12288|0;c[a+57392>>2]=d;c[a+122928>>2]=d;c[a+188464>>2]=d;d=e+13312|0;c[a+57396>>2]=d;c[a+122932>>2]=d;c[a+188468>>2]=d;d=e+14336|0;c[a+57400>>2]=d;c[a+122936>>2]=d;c[a+188472>>2]=d;d=e+15360|0;c[a+57404>>2]=d;c[a+122940>>2]=d;c[a+188476>>2]=d;d=c[2388286]|0;e=a+61440|0;b=15728640;while(1){f=d+(b-15728640)|0;c[e>>2]=f;c[e+65536>>2]=f;c[e+131072>>2]=f;f=b+1024|0;if(f>>>0>16777215){break}else{e=e+4|0;b=f}}c[a+196728>>2]=24;c[a+196648>>2]=3020;c[a+196688>>2]=2842;c[a+196608>>2]=1824;c[a+4096>>2]=1;c[a+69632>>2]=1;c[a+4100>>2]=1;c[a+69636>>2]=1;c[a+4104>>2]=1;c[a+69640>>2]=1;c[a+4108>>2]=1;c[a+69644>>2]=1;c[a+4112>>2]=1;c[a+69648>>2]=1;c[a+4116>>2]=1;c[a+69652>>2]=1;c[a+4120>>2]=1;c[a+69656>>2]=1;c[a+4124>>2]=1;c[a+69660>>2]=1;c[a+4128>>2]=1;c[a+69664>>2]=1;c[a+4132>>2]=1;c[a+69668>>2]=1;c[a+4136>>2]=1;c[a+69672>>2]=1;c[a+4140>>2]=1;c[a+69676>>2]=1;c[a+4144>>2]=1;c[a+69680>>2]=1;c[a+4148>>2]=1;c[a+69684>>2]=1;c[a+4152>>2]=1;c[a+69688>>2]=1;c[a+4156>>2]=1;c[a+69692>>2]=1;c[a+196692>>2]=286;c[a+196612>>2]=1084;c[a+196732>>2]=3428;c[a+196652>>2]=3130;c[a+73728>>2]=c[2432966];c[a+8192>>2]=2;c[a+196616>>2]=1974;c[a+45056>>2]=3;c[a+45060>>2]=3;c[a+45064>>2]=3;c[a+45068>>2]=3;c[a+196620>>2]=1952;c[a+196700>>2]=1254;a=c[3532592]|0;if((a|0)==0){g=c[2113054]|0;c[2113060]=g;c[2394]=-1;return}gGC(a|0,9104152,280)|0;g=c[2113054]|0;c[2113060]=g;c[2394]=-1;return}function d6E(){var a=0,b=0,d=0,e=0,f=0;d6D();if((c[2394]|0)==0){a=c[2112932]|0;b=c[3532592]|0}else{c[2394]=0;d=c[3532596]|0;c[2112932]=d;e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060];a=d;b=e}c[a+196620>>2]=2500;c[a+196700>>2]=3556;if((b|0)==0){f=c[2113054]|0;c[2113060]=f;c[2394]=-1;return}gGC(b|0,9104152,280)|0;f=c[2113054]|0;c[2113060]=f;c[2394]=-1;return}function d6F(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[1623868]|0;e=((c[2405120]|0)*100|0|0)/(d|0)|0;f=4e8/(d|0)|0;d=c[2385548]|0;if((d|0)>0){gGz(9752472,0,((d|0)>1?d<<2:4)|0)}c[2433530]=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}d=c[2439330]|0;if((d|0)!=0){g=d;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;g=(e|0)/10|0;e=(f|0)/10|0;d=0;do{c[2113056]=g;h=RG(g)|0;c[2113054]=(c[2113054]|0)+h;c[2276108]=-1;c[2113056]=-1;Sb(ag(d,e)|0);do{if((d|0)==9|(d|0)==4){h=c[2406742]>>(((d|0)/5|0)<<3&8);if((h&128|0)!=0){break}i=h&255;c[8452200+(c[2394]<<2)>>2]=i|8192;h=c[2276080]|0;j=i<<8;c[2276080]=j;if((h|0)!=1792&(i|0)==7){RH(7);break}if(j>>>0<=(c[2276079]|0)>>>0){break}RH(i)}}while(0);d=d+1|0;}while((d|0)<10);d=gGU(f,(f|0)<0|0?-1:0,2048e6,0)|0;e=c[2438228]|0;g=gGS(d,K,e,(e|0)<0|0?-1:0)|0;e=g;Sb(f);f=c[2443830]|0;if((f|0)<1073676288){c[2443830]=f-e}f=c[2443831]|0;if((f|0)<1073676288){c[2443831]=f-e}f=(c[3528512]|0)-e|0;c[3528512]=(f|0)<0?0:f;f=c[2112964]|0;if((f|0)!=0){TV();gg[c[3542116]&4095](f,a[9688]|0?534:0)}f=c[1836236]|0;e=c[9757320+(f<<2)>>2]|0;if((e|0)!=0){g=e;gGC(g|0,9706056,76)|0}c[9752472+(f<<2)>>2]=c[2433530];c[14113936+(f<<2)>>2]=c[2076596];c[9669104+(f<<2)>>2]=c[3541536];c[1836236]=-1;f=c[2394]|0;g=c[14130368+(f<<2)>>2]|0;if((g|0)==0){k=c[2113054]|0;l=8452240+(f<<2)|0;c[l>>2]=k;c[2394]=-1;return}gGC(g|0,9104152,280)|0;k=c[2113054]|0;l=8452240+(f<<2)|0;c[l>>2]=k;c[2394]=-1;return}function d6G(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;fxU(0,425984);if((c[2394]|0)==0){d=c[2112932]|0}else{c[2394]=0;e=c[3532596]|0;c[2112932]=e;f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];d=e}e=c[2388160]|0;f=d|0;g=0;while(1){h=e+g|0;c[f>>2]=h;c[f+131072>>2]=h;h=g+1024|0;if(h>>>0>1048575){break}else{f=f+4|0;g=h}}g=c[2388286]|0;f=d+8192|0;e=2097152;while(1){h=g+(e-2097152)|0;c[f>>2]=h;c[f+65536>>2]=h;c[f+131072>>2]=h;h=e+1024|0;if(h>>>0>2162687){break}else{f=f+4|0;e=h}}e=c[2387204]|0;c[d+28676>>2]=e;c[d+94212>>2]=e;c[d+159748>>2]=e;f=e+1024|0;c[d+28680>>2]=f;c[d+94216>>2]=f;c[d+159752>>2]=f;f=e+2048|0;c[d+28684>>2]=f;c[d+94220>>2]=f;c[d+159756>>2]=f;f=c[3529470]|0;c[d+32768>>2]=f;c[d+98304>>2]=f;c[d+163840>>2]=f;e=f+1024|0;c[d+32772>>2]=e;c[d+98308>>2]=e;c[d+163844>>2]=e;e=f+2048|0;c[d+32776>>2]=e;c[d+98312>>2]=e;c[d+163848>>2]=e;e=f+3072|0;c[d+32780>>2]=e;c[d+98316>>2]=e;c[d+163852>>2]=e;e=f+4096|0;c[d+32784>>2]=e;c[d+98320>>2]=e;c[d+163856>>2]=e;e=f+5120|0;c[d+32788>>2]=e;c[d+98324>>2]=e;c[d+163860>>2]=e;e=f+6144|0;c[d+32792>>2]=e;c[d+98328>>2]=e;c[d+163864>>2]=e;e=f+7168|0;c[d+32796>>2]=e;c[d+98332>>2]=e;c[d+163868>>2]=e;e=f+8192|0;c[d+32800>>2]=e;c[d+98336>>2]=e;c[d+163872>>2]=e;e=f+9216|0;c[d+32804>>2]=e;c[d+98340>>2]=e;c[d+163876>>2]=e;e=f+10240|0;c[d+32808>>2]=e;c[d+98344>>2]=e;c[d+163880>>2]=e;e=f+11264|0;c[d+32812>>2]=e;c[d+98348>>2]=e;c[d+163884>>2]=e;e=f+12288|0;c[d+32816>>2]=e;c[d+98352>>2]=e;c[d+163888>>2]=e;e=f+13312|0;c[d+32820>>2]=e;c[d+98356>>2]=e;c[d+163892>>2]=e;e=f+14336|0;c[d+32824>>2]=e;c[d+98360>>2]=e;c[d+163896>>2]=e;e=f+15360|0;c[d+32828>>2]=e;c[d+98364>>2]=e;c[d+163900>>2]=e;e=c[3529436]|0;c[d+34816>>2]=e;c[d+100352>>2]=e;c[d+165888>>2]=e;f=e+1024|0;c[d+34820>>2]=f;c[d+100356>>2]=f;c[d+165892>>2]=f;f=e+2048|0;c[d+34824>>2]=f;c[d+100360>>2]=f;c[d+165896>>2]=f;f=e+3072|0;c[d+34828>>2]=f;c[d+100364>>2]=f;c[d+165900>>2]=f;f=e+4096|0;c[d+34832>>2]=f;c[d+100368>>2]=f;c[d+165904>>2]=f;f=e+5120|0;c[d+34836>>2]=f;c[d+100372>>2]=f;c[d+165908>>2]=f;f=e+6144|0;c[d+34840>>2]=f;c[d+100376>>2]=f;c[d+165912>>2]=f;f=e+7168|0;c[d+34844>>2]=f;c[d+100380>>2]=f;c[d+165916>>2]=f;f=e+8192|0;c[d+34848>>2]=f;c[d+100384>>2]=f;c[d+165920>>2]=f;f=e+9216|0;c[d+34852>>2]=f;c[d+100388>>2]=f;c[d+165924>>2]=f;f=e+10240|0;c[d+34856>>2]=f;c[d+100392>>2]=f;c[d+165928>>2]=f;f=e+11264|0;c[d+34860>>2]=f;c[d+100396>>2]=f;c[d+165932>>2]=f;f=e+12288|0;c[d+34864>>2]=f;c[d+100400>>2]=f;c[d+165936>>2]=f;f=e+13312|0;c[d+34868>>2]=f;c[d+100404>>2]=f;c[d+165940>>2]=f;f=e+14336|0;c[d+34872>>2]=f;c[d+100408>>2]=f;c[d+165944>>2]=f;f=e+15360|0;c[d+34876>>2]=f;c[d+100412>>2]=f;c[d+165948>>2]=f;f=c[3529656]|0;c[d+40960>>2]=f;c[d+106496>>2]=f;c[d+172032>>2]=f;e=f+1024|0;c[d+40964>>2]=e;c[d+106500>>2]=e;c[d+172036>>2]=e;e=c[3529638]|0;c[d+45056>>2]=e;c[d+110592>>2]=e;c[d+176128>>2]=e;f=e+1024|0;c[d+45060>>2]=f;c[d+110596>>2]=f;c[d+176132>>2]=f;f=e+2048|0;c[d+45064>>2]=f;c[d+110600>>2]=f;c[d+176136>>2]=f;f=e+3072|0;c[d+45068>>2]=f;c[d+110604>>2]=f;c[d+176140>>2]=f;f=e+4096|0;c[d+45072>>2]=f;c[d+110608>>2]=f;c[d+176144>>2]=f;f=e+5120|0;c[d+45076>>2]=f;c[d+110612>>2]=f;c[d+176148>>2]=f;f=e+6144|0;c[d+45080>>2]=f;c[d+110616>>2]=f;c[d+176152>>2]=f;f=e+7168|0;c[d+45084>>2]=f;c[d+110620>>2]=f;c[d+176156>>2]=f;f=e+8192|0;c[d+45088>>2]=f;c[d+110624>>2]=f;c[d+176160>>2]=f;f=e+9216|0;c[d+45092>>2]=f;c[d+110628>>2]=f;c[d+176164>>2]=f;f=e+10240|0;c[d+45096>>2]=f;c[d+110632>>2]=f;c[d+176168>>2]=f;f=e+11264|0;c[d+45100>>2]=f;c[d+110636>>2]=f;c[d+176172>>2]=f;f=e+12288|0;c[d+45104>>2]=f;c[d+110640>>2]=f;c[d+176176>>2]=f;f=e+13312|0;c[d+45108>>2]=f;c[d+110644>>2]=f;c[d+176180>>2]=f;f=e+14336|0;c[d+45112>>2]=f;c[d+110648>>2]=f;c[d+176184>>2]=f;f=e+15360|0;c[d+45116>>2]=f;c[d+110652>>2]=f;c[d+176188>>2]=f;c[d+196728>>2]=324;c[d+196648>>2]=510;c[d+196688>>2]=2842;c[d+196608>>2]=1824;c[d+114688>>2]=1;c[d+196732>>2]=2666;c[d+196652>>2]=624;d=c[3532592]|0;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;d=c[2439330]|0;f=(d|0)==0;if(!f){e=d;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];e=c[3528484]|0;c[2076596]=e;g=c[2417276]|0;c[3541536]=g;c[1836236]=0;h=c[2386356]|0;i=0;j=0;while(1){c[d+76+(j<<2)>>2]=h+(j<<8);k=i+1&65535;if((k&65535)>223){l=0;m=0;break}else{i=k;j=k&65535}}while(1){j=h+(m<<8)|0;c[d+76+(m+512<<2)>>2]=j;c[d+76+(m+768<<2)>>2]=j;j=l+1&65535;if((j&65535)>223){break}else{l=j;m=j&65535}}m=c[2386360]|0;c[d+972>>2]=m;c[d+976>>2]=m+256;c[d+980>>2]=m+512;c[d+984>>2]=m+768;c[d+988>>2]=m+1024;c[d+992>>2]=m+1280;c[d+996>>2]=m+1536;c[d+1e3>>2]=m+1792;c[d+1004>>2]=m+2048;c[d+1008>>2]=m+2304;c[d+1012>>2]=m+2560;c[d+1016>>2]=m+2816;c[d+1020>>2]=m+3072;c[d+1024>>2]=m+3328;c[d+1028>>2]=m+3584;c[d+1032>>2]=m+3840;l=224;h=224;while(1){c[d+76+(h+256<<2)>>2]=m+((h<<8)-57344);j=l+1&65535;if((j&65535)>239){n=224;o=224;break}else{l=j;h=j&65535}}while(1){h=m+((o<<8)-57344)|0;c[d+76+(o+512<<2)>>2]=h;c[d+76+(o+768<<2)>>2]=h;h=n+1&65535;if((h&65535)>239){break}else{n=h;o=h&65535}}c[d+4184>>2]=88;c[d+4180>>2]=366;c[d+4176>>2]=350;c[d+4172>>2]=3414;if(!f){f=d;gGC(f|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=e;c[2417276]=g;c[1836236]=-1;g=c[3530846]|0;e=0;do{f=g+e|0;a[f]=~a[f];e=e+1|0;}while((e|0)<4194304);return}function d6H(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d6I();if((c[2394]|0)==0){d=c[2112932]|0;e=c[3532592]|0}else{c[2394]=0;f=c[3532596]|0;c[2112932]=f;g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060];d=f;e=g}g=c[2388286]|0;c[d+4096>>2]=g+524288;c[d+4100>>2]=g+525312;c[d+4104>>2]=g+526336;c[d+4108>>2]=g+527360;c[d+4112>>2]=g+528384;c[d+4116>>2]=g+529408;c[d+4120>>2]=g+530432;c[d+4124>>2]=g+531456;c[d+4128>>2]=g+532480;c[d+4132>>2]=g+533504;c[d+4136>>2]=g+534528;c[d+4140>>2]=g+535552;c[d+4144>>2]=g+536576;c[d+4148>>2]=g+537600;c[d+4152>>2]=g+538624;c[d+4156>>2]=g+539648;c[d+110592>>2]=1;c[d+196732>>2]=2666;c[d+196652>>2]=624;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;e=c[2388160]|0;d=0;do{f=0;do{a[g+f|0]=a[e+(f&1|d|f<<2&8|f>>>1&6)|0]|0;f=f+1|0;}while((f|0)<16);f=e+d|0;gGC(f|0,g|0,16)|0;d=d+16|0;}while((d|0)<131072);d=c[2439330]|0;g=(d|0)==0;if(!g){e=d;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];e=c[3528484]|0;c[2076596]=e;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;h=c[2386356]|0;i=0;j=0;while(1){c[d+76+(j<<2)>>2]=h+(j<<8);k=i+1&65535;if((k&65535)>127){l=0;m=0;break}else{i=k;j=k&65535}}while(1){j=h+(m<<8)|0;c[d+76+(m+512<<2)>>2]=j;c[d+76+(m+768<<2)>>2]=j;j=l+1&65535;if((j&65535)>127){break}else{l=j;m=j&65535}}m=c[2386360]|0;c[d+588>>2]=m;l=m+256|0;c[d+592>>2]=l;h=m+512|0;c[d+596>>2]=h;j=m+768|0;c[d+600>>2]=j;i=m+1024|0;c[d+604>>2]=i;k=m+1280|0;c[d+608>>2]=k;n=m+1536|0;c[d+612>>2]=n;o=m+1792|0;c[d+616>>2]=o;c[d+1612>>2]=m;c[d+1616>>2]=l;c[d+1620>>2]=h;c[d+1624>>2]=j;c[d+1628>>2]=i;c[d+1632>>2]=k;c[d+1636>>2]=n;c[d+1640>>2]=o;c[d+2636>>2]=m;c[d+3660>>2]=m;c[d+2640>>2]=l;c[d+3664>>2]=l;c[d+2644>>2]=h;c[d+3668>>2]=h;c[d+2648>>2]=j;c[d+3672>>2]=j;c[d+2652>>2]=i;c[d+3676>>2]=i;c[d+2656>>2]=k;c[d+3680>>2]=k;c[d+2660>>2]=n;c[d+3684>>2]=n;c[d+2664>>2]=o;c[d+3688>>2]=o;c[d+4184>>2]=178;c[d+4180>>2]=1116;if(g){p=c[2433530]|0;c[2438118]=p;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}g=d;gGC(g|0,9706056,76)|0;p=c[2433530]|0;c[2438118]=p;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}function d6I(){var a=0,b=0,d=0,e=0,f=0,g=0;fxU(0,425984);if((c[2394]|0)==0){a=c[2112932]|0}else{c[2394]=0;b=c[3532596]|0;c[2112932]=b;d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];a=b}b=c[2388160]|0;d=a|0;e=0;while(1){f=b+e|0;c[d>>2]=f;c[d+131072>>2]=f;f=e+1024|0;if(f>>>0>65535){break}else{d=d+4|0;e=f}}e=c[2387204]|0;c[a+28672>>2]=e;c[a+94208>>2]=e;c[a+159744>>2]=e;d=e+1024|0;c[a+28676>>2]=d;c[a+94212>>2]=d;c[a+159748>>2]=d;d=e+2048|0;c[a+28680>>2]=d;c[a+94216>>2]=d;c[a+159752>>2]=d;d=e+3072|0;c[a+28684>>2]=d;c[a+94220>>2]=d;c[a+159756>>2]=d;d=c[3529656]|0;c[a+53248>>2]=d;c[a+118784>>2]=d;c[a+184320>>2]=d;e=d+1024|0;c[a+53252>>2]=e;c[a+118788>>2]=e;c[a+184324>>2]=e;e=c[3529638]|0;d=a+57344|0;b=14680064;while(1){f=e+(b-14680064)|0;c[d>>2]=f;c[d+65536>>2]=f;c[d+131072>>2]=f;f=b+1024|0;if(f>>>0>14712831){break}else{d=d+4|0;b=f}}b=c[2388286]|0;c[a+65472>>2]=b;c[a+131008>>2]=b;c[a+196544>>2]=b;d=b+1024|0;c[a+65476>>2]=d;c[a+131012>>2]=d;c[a+196548>>2]=d;d=b+2048|0;c[a+65480>>2]=d;c[a+131016>>2]=d;c[a+196552>>2]=d;d=b+3072|0;c[a+65484>>2]=d;c[a+131020>>2]=d;c[a+196556>>2]=d;d=b+4096|0;c[a+65488>>2]=d;c[a+131024>>2]=d;c[a+196560>>2]=d;d=b+5120|0;c[a+65492>>2]=d;c[a+131028>>2]=d;c[a+196564>>2]=d;d=b+6144|0;c[a+65496>>2]=d;c[a+131032>>2]=d;c[a+196568>>2]=d;d=b+7168|0;c[a+65500>>2]=d;c[a+131036>>2]=d;c[a+196572>>2]=d;d=b+8192|0;c[a+65504>>2]=d;c[a+131040>>2]=d;c[a+196576>>2]=d;d=b+9216|0;c[a+65508>>2]=d;c[a+131044>>2]=d;c[a+196580>>2]=d;d=b+10240|0;c[a+65512>>2]=d;c[a+131048>>2]=d;c[a+196584>>2]=d;d=b+11264|0;c[a+65516>>2]=d;c[a+131052>>2]=d;c[a+196588>>2]=d;d=b+12288|0;c[a+65520>>2]=d;c[a+131056>>2]=d;c[a+196592>>2]=d;d=b+13312|0;c[a+65524>>2]=d;c[a+131060>>2]=d;c[a+196596>>2]=d;d=b+14336|0;c[a+65528>>2]=d;c[a+131064>>2]=d;c[a+196600>>2]=d;d=b+15360|0;c[a+65532>>2]=d;c[a+131068>>2]=d;c[a+196604>>2]=d;c[a+196728>>2]=2628;c[a+196648>>2]=524;c[a+196688>>2]=950;c[a+196608>>2]=436;c[a+4096>>2]=1;c[a+69632>>2]=1;c[a+4100>>2]=1;c[a+69636>>2]=1;c[a+4104>>2]=1;c[a+69640>>2]=1;c[a+4108>>2]=1;c[a+69644>>2]=1;c[a+4112>>2]=1;c[a+69648>>2]=1;c[a+4116>>2]=1;c[a+69652>>2]=1;c[a+4120>>2]=1;c[a+69656>>2]=1;c[a+4124>>2]=1;c[a+69660>>2]=1;c[a+4128>>2]=1;c[a+69664>>2]=1;c[a+4132>>2]=1;c[a+69668>>2]=1;c[a+4136>>2]=1;c[a+69672>>2]=1;c[a+4140>>2]=1;c[a+69676>>2]=1;c[a+4144>>2]=1;c[a+69680>>2]=1;c[a+4148>>2]=1;c[a+69684>>2]=1;c[a+4152>>2]=1;c[a+69688>>2]=1;c[a+4156>>2]=1;c[a+69692>>2]=1;c[a+196692>>2]=286;c[a+196612>>2]=1084;c[a+196732>>2]=3428;c[a+196652>>2]=3130;a=c[3532592]|0;if((a|0)==0){g=c[2113054]|0;c[2113060]=g;c[2394]=-1;return}gGC(a|0,9104152,280)|0;g=c[2113054]|0;c[2113060]=g;c[2394]=-1;return}function d6J(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=c[1623868]|0;e=((c[2405120]|0)*100|0|0)/(d|0)|0;f=4e8/(d|0)|0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}d=c[2439330]|0;if((d|0)!=0){g=d;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;g=(e|0)/10|0;e=(f|0)/10|0;d=(f|0)<10;f=0;do{c[2113056]=g;h=RG(g)|0;c[2113054]=(c[2113054]|0)+h;c[2276108]=-1;c[2113056]=-1;do{if(!d){if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){h=gfc(e)|0;c[2433530]=(c[2433530]|0)+h;break}else{c[2433530]=(c[2433530]|0)+e;break}}}while(0);do{if((f|0)==9|(f|0)==4){h=c[2406742]>>(((f|0)/5|0)<<3&8);if((h&128|0)!=0){break}i=h&255;c[8452200+(c[2394]<<2)>>2]=i|8192;h=c[2276080]|0;j=i<<8;c[2276080]=j;if((h|0)!=1792&(i|0)==7){RH(7);break}if(j>>>0<=(c[2276079]|0)>>>0){break}RH(i)}}while(0);f=f+1|0;}while((f|0)<10);f=c[1836236]|0;e=c[9757320+(f<<2)>>2]|0;if((e|0)!=0){d=e;gGC(d|0,9706056,76)|0}c[9752472+(f<<2)>>2]=c[2433530];c[14113936+(f<<2)>>2]=c[2076596];c[9669104+(f<<2)>>2]=c[3541536];c[1836236]=-1;f=c[2394]|0;d=c[14130368+(f<<2)>>2]|0;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[8452240+(f<<2)>>2]=c[2113054];c[2394]=-1;f=c[2112964]|0;if((f|0)==0){return}Uu(0,f,a[9688]|0?534:0);return}function d6K(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;fxU(0,425984);if((c[2394]|0)==0){a=c[2112932]|0}else{c[2394]=0;b=c[3532596]|0;c[2112932]=b;d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];a=b}b=c[2388160]|0;d=a|0;e=0;while(1){f=b+e|0;c[d>>2]=f;c[d+131072>>2]=f;f=e+1024|0;if(f>>>0>1048575){break}else{d=d+4|0;e=f}}e=c[2388286]|0;d=a+8192|0;b=2097152;while(1){f=e+(b-2097152)|0;c[d>>2]=f;c[d+65536>>2]=f;c[d+131072>>2]=f;f=b+1024|0;if(f>>>0>2359295){break}else{d=d+4|0;b=f}}b=c[2387204]|0;c[a+24580>>2]=b;c[a+90116>>2]=b;c[a+155652>>2]=b;d=b+1024|0;c[a+24584>>2]=d;c[a+90120>>2]=d;c[a+155656>>2]=d;d=b+2048|0;c[a+24588>>2]=d;c[a+90124>>2]=d;c[a+155660>>2]=d;d=c[3531132]|0;b=a+24592|0;e=6295552;while(1){f=d+(e-6295552)|0;c[b>>2]=f;c[b+65536>>2]=f;c[b+131072>>2]=f;f=e+1024|0;if(f>>>0>6360063){break}else{b=b+4|0;e=f}}e=c[3529470]|0;b=a+32768|0;d=8388608;while(1){f=e+(d-8388608)|0;c[b>>2]=f;c[b+65536>>2]=f;c[b+131072>>2]=f;f=d+1024|0;if(f>>>0>8454143){break}else{b=b+4|0;d=f}}d=c[3529436]|0;b=a+34816|0;e=8912896;while(1){f=d+(e-8912896)|0;c[b>>2]=f;c[b+65536>>2]=f;c[b+131072>>2]=f;f=e+1024|0;if(f>>>0>8978431){break}else{b=b+4|0;e=f}}e=c[3529656]|0;c[a+40960>>2]=e;c[a+106496>>2]=e;c[a+172032>>2]=e;b=e+1024|0;c[a+40964>>2]=b;c[a+106500>>2]=b;c[a+172036>>2]=b;b=c[3529638]|0;e=a+45056|0;d=11534336;while(1){f=b+(d-11534336)|0;c[e>>2]=f;c[e+65536>>2]=f;c[e+131072>>2]=f;f=d+1024|0;if(f>>>0>11616255){break}else{e=e+4|0;d=f}}c[a+196728>>2]=324;c[a+196648>>2]=510;c[a+196688>>2]=2842;c[a+196608>>2]=1824;c[a+57344>>2]=1;c[a+122880>>2]=1;c[a+57348>>2]=1;c[a+122884>>2]=1;c[a+57352>>2]=1;c[a+122888>>2]=1;c[a+57356>>2]=1;c[a+122892>>2]=1;c[a+57360>>2]=1;c[a+122896>>2]=1;c[a+57364>>2]=1;c[a+122900>>2]=1;c[a+57368>>2]=1;c[a+122904>>2]=1;c[a+57372>>2]=1;c[a+122908>>2]=1;c[a+57376>>2]=1;c[a+122912>>2]=1;c[a+57380>>2]=1;c[a+122916>>2]=1;c[a+57384>>2]=1;c[a+122920>>2]=1;c[a+57388>>2]=1;c[a+122924>>2]=1;c[a+57392>>2]=1;c[a+122928>>2]=1;c[a+57396>>2]=1;c[a+122932>>2]=1;c[a+57400>>2]=1;c[a+122936>>2]=1;c[a+57404>>2]=1;c[a+122940>>2]=1;c[a+196692>>2]=286;c[a+196612>>2]=1084;c[a+196732>>2]=3428;c[a+196652>>2]=3130;a=c[3532592]|0;if((a|0)==0){g=c[2113054]|0;c[2113060]=g;c[2394]=-1;h=c[2386648]|0;i=h+1048576|0;gGC(i|0,h|0,524288)|0;j=h+524288|0;gGC(h|0,j|0,1048576)|0;return}gGC(a|0,9104152,280)|0;g=c[2113054]|0;c[2113060]=g;c[2394]=-1;h=c[2386648]|0;i=h+1048576|0;gGC(i|0,h|0,524288)|0;j=h+524288|0;gGC(h|0,j|0,1048576)|0;return}function d6L(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;a=i;i=i+240|0;b=a|0;d=a+112|0;e=a+120|0;f=a+232|0;fxU(0,425984);if((c[2394]|0)==0){g=c[2112932]|0}else{c[2394]=0;h=c[3532596]|0;c[2112932]=h;j=c[3532592]|0;if((j|0)!=0){gGC(9104152,j|0,280)|0}c[2113054]=c[2113060];g=h}h=c[2388160]|0;j=g|0;k=0;while(1){l=h+k|0;c[j>>2]=l;c[j+131072>>2]=l;l=k+1024|0;if(l>>>0>2097151){break}else{j=j+4|0;k=l}}k=c[2388286]|0;j=g+8192|0;l=2097152;while(1){m=k+(l-2097152)|0;c[j>>2]=m;c[j+65536>>2]=m;c[j+131072>>2]=m;m=l+1024|0;if(m>>>0>2228223){break}else{j=j+4|0;l=m}}l=c[3531132]|0;j=g+12288|0;k=3145728;while(1){m=l+(k-3145728)|0;c[j>>2]=m;c[j+65536>>2]=m;c[j+131072>>2]=m;m=k+1024|0;if(m>>>0>3211263){break}else{j=j+4|0;k=m}}k=g+28672|0;j=7340032;while(1){m=l+(j-7274496)|0;c[k>>2]=m;c[k+65536>>2]=m;c[k+131072>>2]=m;m=j+1024|0;if(m>>>0>7386111){break}else{k=k+4|0;j=m}}j=c[2387204]|0;c[g+28852>>2]=j;c[g+94388>>2]=j;c[g+159924>>2]=j;k=j+1024|0;c[g+28856>>2]=k;c[g+94392>>2]=k;c[g+159928>>2]=k;k=j+2048|0;c[g+28860>>2]=k;c[g+94396>>2]=k;c[g+159932>>2]=k;k=l+114688|0;c[g+28864>>2]=k;c[g+94400>>2]=k;c[g+159936>>2]=k;k=l+115712|0;c[g+28868>>2]=k;c[g+94404>>2]=k;c[g+159940>>2]=k;k=l+116736|0;c[g+28872>>2]=k;c[g+94408>>2]=k;c[g+159944>>2]=k;k=l+117760|0;c[g+28876>>2]=k;c[g+94412>>2]=k;c[g+159948>>2]=k;k=l+118784|0;c[g+28880>>2]=k;c[g+94416>>2]=k;c[g+159952>>2]=k;k=l+119808|0;c[g+28884>>2]=k;c[g+94420>>2]=k;c[g+159956>>2]=k;k=l+120832|0;c[g+28888>>2]=k;c[g+94424>>2]=k;c[g+159960>>2]=k;k=l+121856|0;c[g+28892>>2]=k;c[g+94428>>2]=k;c[g+159964>>2]=k;k=l+122880|0;c[g+28896>>2]=k;c[g+94432>>2]=k;c[g+159968>>2]=k;k=l+123904|0;c[g+28900>>2]=k;c[g+94436>>2]=k;c[g+159972>>2]=k;k=l+124928|0;c[g+28904>>2]=k;c[g+94440>>2]=k;c[g+159976>>2]=k;k=l+125952|0;c[g+28908>>2]=k;c[g+94444>>2]=k;c[g+159980>>2]=k;k=l+126976|0;c[g+28912>>2]=k;c[g+94448>>2]=k;c[g+159984>>2]=k;k=l+128e3|0;c[g+28916>>2]=k;c[g+94452>>2]=k;c[g+159988>>2]=k;k=l+129024|0;c[g+28920>>2]=k;c[g+94456>>2]=k;c[g+159992>>2]=k;k=l+130048|0;c[g+28924>>2]=k;c[g+94460>>2]=k;c[g+159996>>2]=k;k=c[3529470]|0;c[g+32768>>2]=k;c[g+98304>>2]=k;c[g+163840>>2]=k;l=k+1024|0;c[g+32772>>2]=l;c[g+98308>>2]=l;c[g+163844>>2]=l;l=k+2048|0;c[g+32776>>2]=l;c[g+98312>>2]=l;c[g+163848>>2]=l;l=k+3072|0;c[g+32780>>2]=l;c[g+98316>>2]=l;c[g+163852>>2]=l;l=k+4096|0;c[g+32784>>2]=l;c[g+98320>>2]=l;c[g+163856>>2]=l;l=k+5120|0;c[g+32788>>2]=l;c[g+98324>>2]=l;c[g+163860>>2]=l;l=k+6144|0;c[g+32792>>2]=l;c[g+98328>>2]=l;c[g+163864>>2]=l;l=k+7168|0;c[g+32796>>2]=l;c[g+98332>>2]=l;c[g+163868>>2]=l;l=k+8192|0;c[g+32800>>2]=l;c[g+98336>>2]=l;c[g+163872>>2]=l;l=k+9216|0;c[g+32804>>2]=l;c[g+98340>>2]=l;c[g+163876>>2]=l;l=k+10240|0;c[g+32808>>2]=l;c[g+98344>>2]=l;c[g+163880>>2]=l;l=k+11264|0;c[g+32812>>2]=l;c[g+98348>>2]=l;c[g+163884>>2]=l;l=k+12288|0;c[g+32816>>2]=l;c[g+98352>>2]=l;c[g+163888>>2]=l;l=k+13312|0;c[g+32820>>2]=l;c[g+98356>>2]=l;c[g+163892>>2]=l;l=k+14336|0;c[g+32824>>2]=l;c[g+98360>>2]=l;c[g+163896>>2]=l;l=k+15360|0;c[g+32828>>2]=l;c[g+98364>>2]=l;c[g+163900>>2]=l;l=c[3529436]|0;c[g+32832>>2]=l;c[g+98368>>2]=l;c[g+163904>>2]=l;k=l+1024|0;c[g+32836>>2]=k;c[g+98372>>2]=k;c[g+163908>>2]=k;k=l+2048|0;c[g+32840>>2]=k;c[g+98376>>2]=k;c[g+163912>>2]=k;k=l+3072|0;c[g+32844>>2]=k;c[g+98380>>2]=k;c[g+163916>>2]=k;k=l+4096|0;c[g+32848>>2]=k;c[g+98384>>2]=k;c[g+163920>>2]=k;k=l+5120|0;c[g+32852>>2]=k;c[g+98388>>2]=k;c[g+163924>>2]=k;k=l+6144|0;c[g+32856>>2]=k;c[g+98392>>2]=k;c[g+163928>>2]=k;k=l+7168|0;c[g+32860>>2]=k;c[g+98396>>2]=k;c[g+163932>>2]=k;k=l+8192|0;c[g+32864>>2]=k;c[g+98400>>2]=k;c[g+163936>>2]=k;k=l+9216|0;c[g+32868>>2]=k;c[g+98404>>2]=k;c[g+163940>>2]=k;k=l+10240|0;c[g+32872>>2]=k;c[g+98408>>2]=k;c[g+163944>>2]=k;k=l+11264|0;c[g+32876>>2]=k;c[g+98412>>2]=k;c[g+163948>>2]=k;k=l+12288|0;c[g+32880>>2]=k;c[g+98416>>2]=k;c[g+163952>>2]=k;k=l+13312|0;c[g+32884>>2]=k;c[g+98420>>2]=k;c[g+163956>>2]=k;k=l+14336|0;c[g+32888>>2]=k;c[g+98424>>2]=k;c[g+163960>>2]=k;k=l+15360|0;c[g+32892>>2]=k;c[g+98428>>2]=k;c[g+163964>>2]=k;k=g+34880|0;j=8929280;while(1){m=l+(j-8912896)|0;c[k>>2]=m;c[k+65536>>2]=m;c[k+131072>>2]=m;m=j+1024|0;if(m>>>0>8978431){break}else{k=k+4|0;j=m}}j=c[3529656]|0;c[g+41120>>2]=j;c[g+106656>>2]=j;c[g+172192>>2]=j;k=j+1024|0;c[g+41124>>2]=k;c[g+106660>>2]=k;c[g+172196>>2]=k;k=c[3529638]|0;c[g+45248>>2]=k;c[g+110784>>2]=k;c[g+176320>>2]=k;j=k+1024|0;c[g+45252>>2]=j;c[g+110788>>2]=j;c[g+176324>>2]=j;j=k+2048|0;c[g+45256>>2]=j;c[g+110792>>2]=j;c[g+176328>>2]=j;j=k+3072|0;c[g+45260>>2]=j;c[g+110796>>2]=j;c[g+176332>>2]=j;j=k+4096|0;c[g+45264>>2]=j;c[g+110800>>2]=j;c[g+176336>>2]=j;j=k+5120|0;c[g+45268>>2]=j;c[g+110804>>2]=j;c[g+176340>>2]=j;j=k+6144|0;c[g+45272>>2]=j;c[g+110808>>2]=j;c[g+176344>>2]=j;j=k+7168|0;c[g+45276>>2]=j;c[g+110812>>2]=j;c[g+176348>>2]=j;j=k+8192|0;c[g+45280>>2]=j;c[g+110816>>2]=j;c[g+176352>>2]=j;j=k+9216|0;c[g+45284>>2]=j;c[g+110820>>2]=j;c[g+176356>>2]=j;j=k+10240|0;c[g+45288>>2]=j;c[g+110824>>2]=j;c[g+176360>>2]=j;j=k+11264|0;c[g+45292>>2]=j;c[g+110828>>2]=j;c[g+176364>>2]=j;j=k+12288|0;c[g+45296>>2]=j;c[g+110832>>2]=j;c[g+176368>>2]=j;j=k+13312|0;c[g+45300>>2]=j;c[g+110836>>2]=j;c[g+176372>>2]=j;j=k+14336|0;c[g+45304>>2]=j;c[g+110840>>2]=j;c[g+176376>>2]=j;j=k+15360|0;c[g+45308>>2]=j;c[g+110844>>2]=j;c[g+176380>>2]=j;c[g+196728>>2]=324;c[g+196648>>2]=510;c[g+196688>>2]=2842;c[g+196608>>2]=1824;c[g+49152>>2]=1;c[g+114688>>2]=1;c[g+49156>>2]=1;c[g+114692>>2]=1;c[g+49160>>2]=1;c[g+114696>>2]=1;c[g+49164>>2]=1;c[g+114700>>2]=1;c[g+49168>>2]=1;c[g+114704>>2]=1;c[g+49172>>2]=1;c[g+114708>>2]=1;c[g+49176>>2]=1;c[g+114712>>2]=1;c[g+49180>>2]=1;c[g+114716>>2]=1;c[g+49184>>2]=1;c[g+114720>>2]=1;c[g+49188>>2]=1;c[g+114724>>2]=1;c[g+49192>>2]=1;c[g+114728>>2]=1;c[g+49196>>2]=1;c[g+114732>>2]=1;c[g+49200>>2]=1;c[g+114736>>2]=1;c[g+49204>>2]=1;c[g+114740>>2]=1;c[g+49208>>2]=1;c[g+114744>>2]=1;c[g+49212>>2]=1;c[g+114748>>2]=1;c[g+196692>>2]=286;c[g+196612>>2]=1084;c[g+196732>>2]=3428;c[g+196652>>2]=3130;g=c[3532592]|0;if((g|0)!=0){gGC(g|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;do{if((c[3542200]|0)!=0){g=b+108|0;c[g>>2]=0;j=b+100|0;c[j>>2]=0;k=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[k&16383](b,0)|0;if((c[g>>2]|0)==0){break}g=c[j>>2]|0;c[d>>2]=9534384;j=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[j&16383](d,0,0)|0;if((g|0)<1){break}gzL(h,0,0)|0}}while(0);h=(c[2388160]|0)+1048576|0;if((c[3542200]|0)==0){n=c[3530610]|0;o=n+4194304|0;c[3530432]=o;c[2387026]=2097152;c[2387025]=2097152;p=n+1048576|0;gGC(o|0,p|0,1048576)|0;q=n+5242880|0;r=n+3145728|0;gGC(q|0,r|0,1048576)|0;s=n+2097152|0;gGC(p|0,s|0,1048576)|0;i=a;return}d=e+108|0;c[d>>2]=0;b=e+100|0;c[b>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,1)|0;if((c[d>>2]|0)==0){n=c[3530610]|0;o=n+4194304|0;c[3530432]=o;c[2387026]=2097152;c[2387025]=2097152;p=n+1048576|0;gGC(o|0,p|0,1048576)|0;q=n+5242880|0;r=n+3145728|0;gGC(q|0,r|0,1048576)|0;s=n+2097152|0;gGC(p|0,s|0,1048576)|0;i=a;return}d=c[b>>2]|0;c[f>>2]=9534384;gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](f,1,0)|0;if((d|0)<1){n=c[3530610]|0;o=n+4194304|0;c[3530432]=o;c[2387026]=2097152;c[2387025]=2097152;p=n+1048576|0;gGC(o|0,p|0,1048576)|0;q=n+5242880|0;r=n+3145728|0;gGC(q|0,r|0,1048576)|0;s=n+2097152|0;gGC(p|0,s|0,1048576)|0;i=a;return}gzL(h,0,1)|0;n=c[3530610]|0;o=n+4194304|0;c[3530432]=o;c[2387026]=2097152;c[2387025]=2097152;p=n+1048576|0;gGC(o|0,p|0,1048576)|0;q=n+5242880|0;r=n+3145728|0;gGC(q|0,r|0,1048576)|0;s=n+2097152|0;gGC(p|0,s|0,1048576)|0;i=a;return}function d6M(){var a=0,b=0,d=0,e=0,f=0,g=0;fxU(0,425984);if((c[2394]|0)==0){a=c[2112932]|0}else{c[2394]=0;b=c[3532596]|0;c[2112932]=b;d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];a=b}b=c[2388160]|0;d=a|0;e=0;while(1){f=b+e|0;c[d>>2]=f;c[d+131072>>2]=f;f=e+1024|0;if(f>>>0>2097151){break}else{d=d+4|0;e=f}}e=c[2388286]|0;d=a+8192|0;b=2097152;while(1){f=e+(b-2097152)|0;c[d>>2]=f;c[d+65536>>2]=f;c[d+131072>>2]=f;f=b+1024|0;if(f>>>0>2228223){break}else{d=d+4|0;b=f}}b=c[3531132]|0;d=a+12288|0;e=3145728;while(1){f=b+(e-3145728)|0;c[d>>2]=f;c[d+65536>>2]=f;c[d+131072>>2]=f;f=e+1024|0;if(f>>>0>3211263){break}else{d=d+4|0;e=f}}e=b+65536|0;c[a+28672>>2]=e;c[a+94208>>2]=e;c[a+159744>>2]=e;e=c[2387204]|0;c[a+28676>>2]=e;c[a+94212>>2]=e;c[a+159748>>2]=e;d=e+1024|0;c[a+28680>>2]=d;c[a+94216>>2]=d;c[a+159752>>2]=d;d=e+2048|0;c[a+28684>>2]=d;c[a+94220>>2]=d;c[a+159756>>2]=d;d=a+28688|0;e=7344128;while(1){f=b+(e-7274496)|0;c[d>>2]=f;c[d+65536>>2]=f;c[d+131072>>2]=f;f=e+1024|0;if(f>>>0>7405567){break}else{d=d+4|0;e=f}}e=c[3529470]|0;d=a+32768|0;b=8388608;while(1){f=e+(b-8388608)|0;c[d>>2]=f;c[d+65536>>2]=f;c[d+131072>>2]=f;f=b+1024|0;if(f>>>0>8454143){break}else{d=d+4|0;b=f}}b=c[3529436]|0;d=a+34816|0;e=8912896;while(1){f=b+(e-8912896)|0;c[d>>2]=f;c[d+65536>>2]=f;c[d+131072>>2]=f;f=e+1024|0;if(f>>>0>8978431){break}else{d=d+4|0;e=f}}e=c[3529656]|0;c[a+40960>>2]=e;c[a+106496>>2]=e;c[a+172032>>2]=e;d=e+1024|0;c[a+40964>>2]=d;c[a+106500>>2]=d;c[a+172036>>2]=d;d=c[3529638]|0;e=a+45056|0;b=11534336;while(1){f=d+(b-11534336)|0;c[e>>2]=f;c[e+65536>>2]=f;c[e+131072>>2]=f;f=b+1024|0;if(f>>>0>11616255){break}else{e=e+4|0;b=f}}c[a+196728>>2]=324;c[a+196648>>2]=510;c[a+196688>>2]=2842;c[a+196608>>2]=1824;c[a+49152>>2]=1;c[a+114688>>2]=1;c[a+49156>>2]=1;c[a+114692>>2]=1;c[a+49160>>2]=1;c[a+114696>>2]=1;c[a+49164>>2]=1;c[a+114700>>2]=1;c[a+49168>>2]=1;c[a+114704>>2]=1;c[a+49172>>2]=1;c[a+114708>>2]=1;c[a+49176>>2]=1;c[a+114712>>2]=1;c[a+49180>>2]=1;c[a+114716>>2]=1;c[a+49184>>2]=1;c[a+114720>>2]=1;c[a+49188>>2]=1;c[a+114724>>2]=1;c[a+49192>>2]=1;c[a+114728>>2]=1;c[a+49196>>2]=1;c[a+114732>>2]=1;c[a+49200>>2]=1;c[a+114736>>2]=1;c[a+49204>>2]=1;c[a+114740>>2]=1;c[a+49208>>2]=1;c[a+114744>>2]=1;c[a+49212>>2]=1;c[a+114748>>2]=1;c[a+196692>>2]=286;c[a+196612>>2]=1084;c[a+196732>>2]=3428;c[a+196652>>2]=3130;a=c[3532592]|0;if((a|0)==0){g=c[2113054]|0;c[2113060]=g;c[2394]=-1;return}gGC(a|0,9104152,280)|0;g=c[2113054]|0;c[2113060]=g;c[2394]=-1;return}function d6N(){var a=0,b=0,d=0,e=0,f=0,g=0;fxU(0,425984);if((c[2394]|0)==0){a=c[2112932]|0}else{c[2394]=0;b=c[3532596]|0;c[2112932]=b;d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];a=b}b=c[2388160]|0;d=a|0;e=0;while(1){f=b+e|0;c[d>>2]=f;c[d+131072>>2]=f;f=e+1024|0;if(f>>>0>262143){break}else{d=d+4|0;e=f}}e=c[2406298]|0;c[a+32768>>2]=e;c[a+98304>>2]=e;c[a+163840>>2]=e;e=c[2387204]|0;c[a+45056>>2]=e;c[a+110592>>2]=e;c[a+176128>>2]=e;d=e+1024|0;c[a+45060>>2]=d;c[a+110596>>2]=d;c[a+176132>>2]=d;d=e+2048|0;c[a+45064>>2]=d;c[a+110600>>2]=d;c[a+176136>>2]=d;d=e+3072|0;c[a+45068>>2]=d;c[a+110604>>2]=d;c[a+176140>>2]=d;d=c[3529638]|0;c[a+49152>>2]=d;c[a+114688>>2]=d;c[a+180224>>2]=d;e=d+1024|0;c[a+49156>>2]=e;c[a+114692>>2]=e;c[a+180228>>2]=e;e=d+2048|0;c[a+49160>>2]=e;c[a+114696>>2]=e;c[a+180232>>2]=e;e=d+3072|0;c[a+49164>>2]=e;c[a+114700>>2]=e;c[a+180236>>2]=e;e=d+4096|0;c[a+49168>>2]=e;c[a+114704>>2]=e;c[a+180240>>2]=e;e=d+5120|0;c[a+49172>>2]=e;c[a+114708>>2]=e;c[a+180244>>2]=e;e=d+6144|0;c[a+49176>>2]=e;c[a+114712>>2]=e;c[a+180248>>2]=e;e=d+7168|0;c[a+49180>>2]=e;c[a+114716>>2]=e;c[a+180252>>2]=e;e=d+8192|0;c[a+49184>>2]=e;c[a+114720>>2]=e;c[a+180256>>2]=e;e=d+9216|0;c[a+49188>>2]=e;c[a+114724>>2]=e;c[a+180260>>2]=e;e=d+10240|0;c[a+49192>>2]=e;c[a+114728>>2]=e;c[a+180264>>2]=e;e=d+11264|0;c[a+49196>>2]=e;c[a+114732>>2]=e;c[a+180268>>2]=e;e=d+12288|0;c[a+49200>>2]=e;c[a+114736>>2]=e;c[a+180272>>2]=e;e=d+13312|0;c[a+49204>>2]=e;c[a+114740>>2]=e;c[a+180276>>2]=e;e=d+14336|0;c[a+49208>>2]=e;c[a+114744>>2]=e;c[a+180280>>2]=e;e=d+15360|0;c[a+49212>>2]=e;c[a+114748>>2]=e;c[a+180284>>2]=e;e=c[3529656]|0;c[a+57344>>2]=e;c[a+122880>>2]=e;c[a+188416>>2]=e;d=e+1024|0;c[a+57348>>2]=d;c[a+122884>>2]=d;c[a+188420>>2]=d;d=c[2388286]|0;e=a+61440|0;b=15728640;while(1){f=d+(b-15728640)|0;c[e>>2]=f;c[e+65536>>2]=f;c[e+131072>>2]=f;f=b+1024|0;if(f>>>0>15794175){break}else{e=e+4|0;b=f}}c[a+196728>>2]=3078;c[a+196648>>2]=364;c[a+196688>>2]=548;c[a+196608>>2]=574;c[a+40960>>2]=1;c[a+106496>>2]=1;c[a+40964>>2]=1;c[a+106500>>2]=1;c[a+40968>>2]=1;c[a+106504>>2]=1;c[a+40972>>2]=1;c[a+106508>>2]=1;c[a+40976>>2]=1;c[a+106512>>2]=1;c[a+40980>>2]=1;c[a+106516>>2]=1;c[a+40984>>2]=1;c[a+106520>>2]=1;c[a+40988>>2]=1;c[a+106524>>2]=1;c[a+40992>>2]=1;c[a+106528>>2]=1;c[a+40996>>2]=1;c[a+106532>>2]=1;c[a+41e3>>2]=1;c[a+106536>>2]=1;c[a+41004>>2]=1;c[a+106540>>2]=1;c[a+41008>>2]=1;c[a+106544>>2]=1;c[a+41012>>2]=1;c[a+106548>>2]=1;c[a+41016>>2]=1;c[a+106552>>2]=1;c[a+41020>>2]=1;c[a+106556>>2]=1;c[a+196692>>2]=286;c[a+196612>>2]=1084;c[a+196732>>2]=3428;c[a+196652>>2]=3130;a=c[3532592]|0;if((a|0)==0){g=c[2113054]|0;c[2113060]=g;c[2394]=-1;return}gGC(a|0,9104152,280)|0;g=c[2113054]|0;c[2113060]=g;c[2394]=-1;return}function d6O(){var b=0,d=0,e=0,f=0,g=0;b=((c[2405120]|0)*100|0|0)/(c[1623868]|0)|0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}d=(b|0)/10|0;b=0;do{c[2113056]=d;e=RG(d)|0;c[2113054]=(c[2113054]|0)+e;c[2276108]=-1;c[2113056]=-1;do{if((b|0)==9|(b|0)==4){e=c[2406742]>>(((b|0)/5|0)<<3&8);if((e&128|0)!=0){break}f=e&255;c[8452200+(c[2394]<<2)>>2]=f|8192;e=c[2276080]|0;g=f<<8;c[2276080]=g;if((e|0)!=1792&(f|0)==7){RH(7);break}if(g>>>0<=(c[2276079]|0)>>>0){break}RH(f)}}while(0);b=b+1|0;}while((b|0)<10);b=c[2394]|0;d=c[14130368+(b<<2)>>2]|0;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[8452240+(b<<2)>>2]=c[2113054];c[2394]=-1;b=c[2112964]|0;if((b|0)==0){return}Uu(0,b,a[9688]|0?534:0);return}function d6P(){var a=0,b=0,d=0,e=0;d6Q();if((c[2394]|0)==0){a=c[2112932]|0;b=c[3532592]|0}else{c[2394]=0;d=c[3532596]|0;c[2112932]=d;e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060];a=d;b=e}c[a+20480>>2]=2;c[a+86016>>2]=2;c[a+196616>>2]=2146;c[a+196656>>2]=520;if((b|0)!=0){gGC(b|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;Uw(0);Ux(0,6e3,0);c[2407030]=256;c[2407068]=3;b=c[2388160]|0;a=b+1048576|0;e=b+524288|0;gGC(a|0,e|0,524288)|0;gGz(e|0,0,524288);return}function d6Q(){var a=0,b=0,d=0,e=0,f=0,g=0;fxU(0,425984);if((c[2394]|0)==0){a=c[2112932]|0}else{c[2394]=0;b=c[3532596]|0;c[2112932]=b;d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];a=b}b=c[2388160]|0;d=a|0;e=0;while(1){f=b+e|0;c[d>>2]=f;c[d+131072>>2]=f;f=e+1024|0;if(f>>>0>2097151){break}else{d=d+4|0;e=f}}e=c[2388286]|0;d=a+8192|0;b=2097152;while(1){f=e+(b-2097152)|0;c[d>>2]=f;c[d+65536>>2]=f;c[d+131072>>2]=f;f=b+1024|0;if(f>>>0>2162687){break}else{d=d+4|0;b=f}}b=c[3529470]|0;c[a+32768>>2]=b;c[a+98304>>2]=b;c[a+163840>>2]=b;d=b+1024|0;c[a+32772>>2]=d;c[a+98308>>2]=d;c[a+163844>>2]=d;d=b+2048|0;c[a+32776>>2]=d;c[a+98312>>2]=d;c[a+163848>>2]=d;d=b+3072|0;c[a+32780>>2]=d;c[a+98316>>2]=d;c[a+163852>>2]=d;d=b+4096|0;c[a+32784>>2]=d;c[a+98320>>2]=d;c[a+163856>>2]=d;d=b+5120|0;c[a+32788>>2]=d;c[a+98324>>2]=d;c[a+163860>>2]=d;d=b+6144|0;c[a+32792>>2]=d;c[a+98328>>2]=d;c[a+163864>>2]=d;d=b+7168|0;c[a+32796>>2]=d;c[a+98332>>2]=d;c[a+163868>>2]=d;d=b+8192|0;c[a+32800>>2]=d;c[a+98336>>2]=d;c[a+163872>>2]=d;d=b+9216|0;c[a+32804>>2]=d;c[a+98340>>2]=d;c[a+163876>>2]=d;d=b+10240|0;c[a+32808>>2]=d;c[a+98344>>2]=d;c[a+163880>>2]=d;d=b+11264|0;c[a+32812>>2]=d;c[a+98348>>2]=d;c[a+163884>>2]=d;d=b+12288|0;c[a+32816>>2]=d;c[a+98352>>2]=d;c[a+163888>>2]=d;d=b+13312|0;c[a+32820>>2]=d;c[a+98356>>2]=d;c[a+163892>>2]=d;d=b+14336|0;c[a+32824>>2]=d;c[a+98360>>2]=d;c[a+163896>>2]=d;d=b+15360|0;c[a+32828>>2]=d;c[a+98364>>2]=d;c[a+163900>>2]=d;d=c[3529436]|0;c[a+34816>>2]=d;c[a+100352>>2]=d;c[a+165888>>2]=d;b=d+1024|0;c[a+34820>>2]=b;c[a+100356>>2]=b;c[a+165892>>2]=b;b=d+2048|0;c[a+34824>>2]=b;c[a+100360>>2]=b;c[a+165896>>2]=b;b=d+3072|0;c[a+34828>>2]=b;c[a+100364>>2]=b;c[a+165900>>2]=b;b=d+4096|0;c[a+34832>>2]=b;c[a+100368>>2]=b;c[a+165904>>2]=b;b=d+5120|0;c[a+34836>>2]=b;c[a+100372>>2]=b;c[a+165908>>2]=b;b=d+6144|0;c[a+34840>>2]=b;c[a+100376>>2]=b;c[a+165912>>2]=b;b=d+7168|0;c[a+34844>>2]=b;c[a+100380>>2]=b;c[a+165916>>2]=b;b=d+8192|0;c[a+34848>>2]=b;c[a+100384>>2]=b;c[a+165920>>2]=b;b=d+9216|0;c[a+34852>>2]=b;c[a+100388>>2]=b;c[a+165924>>2]=b;b=d+10240|0;c[a+34856>>2]=b;c[a+100392>>2]=b;c[a+165928>>2]=b;b=d+11264|0;c[a+34860>>2]=b;c[a+100396>>2]=b;c[a+165932>>2]=b;b=d+12288|0;c[a+34864>>2]=b;c[a+100400>>2]=b;c[a+165936>>2]=b;b=d+13312|0;c[a+34868>>2]=b;c[a+100404>>2]=b;c[a+165940>>2]=b;b=d+14336|0;c[a+34872>>2]=b;c[a+100408>>2]=b;c[a+165944>>2]=b;b=d+15360|0;c[a+34876>>2]=b;c[a+100412>>2]=b;c[a+165948>>2]=b;b=c[3529656]|0;c[a+40960>>2]=b;c[a+106496>>2]=b;c[a+172032>>2]=b;d=b+1024|0;c[a+40964>>2]=d;c[a+106500>>2]=d;c[a+172036>>2]=d;d=c[3529638]|0;c[a+45056>>2]=d;c[a+110592>>2]=d;c[a+176128>>2]=d;b=d+1024|0;c[a+45060>>2]=b;c[a+110596>>2]=b;c[a+176132>>2]=b;b=d+2048|0;c[a+45064>>2]=b;c[a+110600>>2]=b;c[a+176136>>2]=b;b=d+3072|0;c[a+45068>>2]=b;c[a+110604>>2]=b;c[a+176140>>2]=b;b=d+4096|0;c[a+45072>>2]=b;c[a+110608>>2]=b;c[a+176144>>2]=b;b=d+5120|0;c[a+45076>>2]=b;c[a+110612>>2]=b;c[a+176148>>2]=b;b=d+6144|0;c[a+45080>>2]=b;c[a+110616>>2]=b;c[a+176152>>2]=b;b=d+7168|0;c[a+45084>>2]=b;c[a+110620>>2]=b;c[a+176156>>2]=b;b=d+8192|0;c[a+45088>>2]=b;c[a+110624>>2]=b;c[a+176160>>2]=b;b=d+9216|0;c[a+45092>>2]=b;c[a+110628>>2]=b;c[a+176164>>2]=b;b=d+10240|0;c[a+45096>>2]=b;c[a+110632>>2]=b;c[a+176168>>2]=b;b=d+11264|0;c[a+45100>>2]=b;c[a+110636>>2]=b;c[a+176172>>2]=b;b=d+12288|0;c[a+45104>>2]=b;c[a+110640>>2]=b;c[a+176176>>2]=b;b=d+13312|0;c[a+45108>>2]=b;c[a+110644>>2]=b;c[a+176180>>2]=b;b=d+14336|0;c[a+45112>>2]=b;c[a+110648>>2]=b;c[a+176184>>2]=b;b=d+15360|0;c[a+45116>>2]=b;c[a+110652>>2]=b;c[a+176188>>2]=b;b=c[2387204]|0;c[a+49156>>2]=b;c[a+114692>>2]=b;c[a+180228>>2]=b;d=b+1024|0;c[a+49160>>2]=d;c[a+114696>>2]=d;c[a+180232>>2]=d;d=b+2048|0;c[a+49164>>2]=d;c[a+114700>>2]=d;c[a+180236>>2]=d;c[a+196728>>2]=324;c[a+196648>>2]=510;c[a+196688>>2]=2842;c[a+196608>>2]=1824;c[a+28672>>2]=1;c[a+94208>>2]=1;c[a+28676>>2]=1;c[a+94212>>2]=1;c[a+28680>>2]=1;c[a+94216>>2]=1;c[a+28684>>2]=1;c[a+94220>>2]=1;c[a+28688>>2]=1;c[a+94224>>2]=1;c[a+28692>>2]=1;c[a+94228>>2]=1;c[a+28696>>2]=1;c[a+94232>>2]=1;c[a+28700>>2]=1;c[a+94236>>2]=1;c[a+28704>>2]=1;c[a+94240>>2]=1;c[a+28708>>2]=1;c[a+94244>>2]=1;c[a+28712>>2]=1;c[a+94248>>2]=1;c[a+28716>>2]=1;c[a+94252>>2]=1;c[a+28720>>2]=1;c[a+94256>>2]=1;c[a+28724>>2]=1;c[a+94260>>2]=1;c[a+28728>>2]=1;c[a+94264>>2]=1;c[a+28732>>2]=1;c[a+94268>>2]=1;c[a+196692>>2]=286;c[a+196612>>2]=1084;c[a+196732>>2]=3428;c[a+196652>>2]=3130;a=c[3532592]|0;if((a|0)==0){g=c[2113054]|0;c[2113060]=g;c[2394]=-1;return}gGC(a|0,9104152,280)|0;g=c[2113054]|0;c[2113060]=g;c[2394]=-1;return}function d6R(a){a=a|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=c[2438730]|0;f=c[2438728]|0;g=e[f>>1]|0;h=e[f+2>>1]|0;i=16-(c[2442918]|0)|0;j=i+(e[d>>1]|0)|0;k=(257-(c[2113070]|0)|0)/2|0;l=(e[d+2>>1]|0)-k|0;m=(a|0)==0;if(m){n=h;o=g;p=0}else{n=h-k|0;o=i+g|0;p=e[(c[2443352]|0)+2>>1]|0}g=(b[d+4>>1]&8)==0?-3:-2;d=(b[f+4>>1]&8)==0;f=g&-5;i=d?(d?g:f)&-9:f;f=m?i&243:i;i=c[2112926]|0;gGz(i|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);if((p&1|0)==0){if((f&1|0)!=0){d6S(c[3529470]|0,c[3530610]|0,1,1,j,l)}if((f&2|0)!=0){d6S((c[3529470]|0)+8192|0,c[3530610]|0,1,1,j,l)}i=(p&2|0)==0;if(!i){d6T()}if((f&4|0)!=0){d6S(c[3529436]|0,c[3530432]|0,2,0,o,n)}if((f&8|0)!=0){d6S((c[3529436]|0)+8192|0,c[3530432]|0,2,0,o,n)}if(!i){return}d6T();return}else{if((f&4|0)!=0){d6S(c[3529436]|0,c[3530432]|0,2,1,o,n)}if((f&8|0)!=0){d6S((c[3529436]|0)+8192|0,c[3530432]|0,2,1,o,n)}n=(p&2|0)==0;if(!n){d6T()}if((f&1|0)!=0){d6S(c[3529470]|0,c[3530610]|0,1,0,j,l)}if((f&2|0)!=0){d6S((c[3529470]|0)+8192|0,c[3530610]|0,1,0,j,l)}if(!n){return}d6T();return}}function d6S(f,g,h,i,j,k){f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;l=c[14123872+(h<<2)>>2]|0;m=c[14109960+(h<<2)>>2]|0;n=c[9774592+(h<<2)>>2]|0;o=(c[2442918]|0)+j&1023;j=(c[2442916]|0)+k&511;k=f;f=(i|0)!=0;p=(m|0)==6;q=i*4095|0;i=9751056+(h<<2)|0;h=c[2443688]|0;r=a[627160]|0;s=c[2388460]|0;t=c[2112926]|0;u=c[2113068]|0;v=c[2113070]|0;w=0;do{x=(w<<4&1008)-o|0;y=(x|0)<-15?x+1024|0:x;x=(w>>6<<4)-j|0;z=(x|0)<-15?x+512|0:x;L58149:do{if((y|0)<(u|0)&(z|0)<(v|0)){x=e[k+(w<<1)>>1]|0;A=b[k+(w+2048<<1)>>1]&31;B=c[h>>2]|0;C=B+(x&16383)|0;do{if(r){if((C&15872|0)!=15872){D=C;break}D=(d[s+(C>>>7&3)|0]|0)>>>1<<7|B+x&127}else{D=C}}while(0);C=(D|0)%(l|0)|0;if(!f){if((a[(c[i>>2]|0)+C|0]|0)!=0){break}}B=x&32768;E=x&16384;if(p){F=(A<<6)+n|0;G=(E|0)==0?0:240;H=(B|0)==0?G:G|15;G=C<<8;I=z;J=0;while(1){if((I|0)>-1&(I|0)<(v|0)){K=J<<4;L=ag(u,I)|0;M=y;N=0;while(1){do{if((M|0)>=0&(M|0)<(u|0)){O=d[g+((N+K^H)+G)|0]|0;if((O|0)==(q|0)){break}b[t+(L+M<<1)>>1]=F+O&65535}}while(0);O=N+1|0;if((O|0)<16){M=M+1|0;N=O}else{break}}}N=J+1|0;if((N|0)>=16){break L58149}I=I+1|0;J=N}}J=(E|0)!=0;I=(B|0)!=0;if(f){if(J){if(I){SF(t,C,y,z,A,m,n,g);break}else{SD(t,C,y,z,A,m,n,g);break}}else{if(I){SB(t,C,y,z,A,m,n,g);break}else{Sz(t,C,y,z,A,m,n,g);break}}}else{if(J){if(I){SN(t,C,y,z,A,m,0,n,g);break}else{SL(t,C,y,z,A,m,0,n,g);break}}else{if(I){SJ(t,C,y,z,A,m,0,n,g);break}else{SH(t,C,y,z,A,m,0,n,g);break}}}}}while(0);w=w+1|0;}while((w|0)<2048);return}function d6T(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;d=c[3529656]|0;f=d;g=b[d+1536>>1]|0;h=e[d+1538>>1]|0;i=c[3529638]|0;j=(h^64^h<<1)<<6&4096;k=g&65535;l=k&64;m=h&15;h=e[d+1542>>1]<<8&65280|b[d+1540>>1]&255;d=k&15;if((d|0)==6){n=8}else if((d|0)==1){n=4}else{n=0}d=(l|0)==0;k=(m|0)==1?16:m;if((k|0)==0){o=c[2437764]|0;p=c[2442916]|0;q=c[2112926]|0;r=c[3527490]|0;s=c[3530846]|0}else{m=j|1024;t=j|1536;u=-(l>>>5)|1;l=c[2437764]|0;v=c[2442916]|0;w=c[2112926]|0;x=c[3527490]|0;y=c[3530846]|0;z=0;while(1){A=z<<5;B=b[f+(((A+1032|0)/2|0)<<1)>>1]&255;C=z+n<<5&480;D=u-(b[f+(((A+1024|0)/2|0)<<1)>>1]&255)|0;A=(1<<z&h|0)==0;if(d){E=D+16|0;F=0;do{G=F+C|0;H=e[i+(G+m<<1)>>1]|0;I=e[i+(G+t<<1)>>1]|0;G=(F<<4&16)+B|0;J=I>>>11;K=(I>>>9<<14&49152|H&16383|0)%(c[3530968]|0)|0;do{if((a[l+K|0]|0)==0){I=((A?G:G+256|0)+16&511)-16|0;L=(E+(((F|0)/2|0)<<4)-v&255)-16|0;M=(H&32768|0)!=0;if((H&16384|0)==0){if(M){SJ(w,K,I,L,J,x,0,0,y);break}else{SH(w,K,I,L,J,x,0,0,y);break}}else{if(M){SN(w,K,I,L,J,x,0,0,y);break}else{SL(w,K,I,L,J,x,0,0,y);break}}}}while(0);F=F+1|0;}while((F|0)<32)}else{F=256-D|0;if(A){E=B+16|0;J=0;do{K=J+C|0;H=e[i+(K+m<<1)>>1]|0;G=e[i+(K+t<<1)>>1]|0;K=G>>>11;L=(G>>>9<<14&49152|H&16383|0)%(c[3530968]|0)|0;do{if((a[l+L|0]|0)==0){G=(E+(J<<4&16)&511)-16|0;I=((((J|0)/2|0)*-16|0)+F-v&255)-16|0;M=(H&32768|0)==0;if((H&16384|0)==0){if(M){SN(w,L,G,I,K,x,0,0,y);break}else{SL(w,L,G,I,K,x,0,0,y);break}}else{if(M){SJ(w,L,G,I,K,x,0,0,y);break}else{SH(w,L,G,I,K,x,0,0,y);break}}}}while(0);J=J+1|0;}while((J|0)<32)}else{J=B+272|0;E=0;do{A=E+C|0;D=e[i+(A+m<<1)>>1]|0;K=e[i+(A+t<<1)>>1]|0;A=K>>>11;L=(K>>>9<<14&49152|D&16383|0)%(c[3530968]|0)|0;do{if((a[l+L|0]|0)==0){K=(J+(E<<4&16)&511)-16|0;H=((((E|0)/2|0)*-16|0)+F-v&255)-16|0;I=(D&32768|0)==0;if((D&16384|0)==0){if(I){SN(w,L,K,H,A,x,0,0,y);break}else{SL(w,L,K,H,A,x,0,0,y);break}}else{if(I){SJ(w,L,K,H,A,x,0,0,y);break}else{SH(w,L,K,H,A,x,0,0,y);break}}}}while(0);E=E+1|0;}while((E|0)<32)}}E=z+1|0;if((E|0)<(k|0)){z=E}else{o=l;p=v;q=w;r=x;s=y;break}}}y=g&64;g=y<<16>>16==0;x=j|512;w=(c[9771680+(((y&65535)>>>6&65535)<<2)>>2]|0)+16|0;y=a[5750792]|0?34:2;v=511;while(1){l=e[i+(v+j<<1)>>1]|0;z=e[i+(v+x<<1)>>1]|0;k=b[f+(v<<1)>>1]&255;t=l&16384;m=z>>>11;if(g){N=t;O=l&32768;P=k}else{N=t>>>14^1;O=l>>>15^1;P=496-k-(c[2113070]|0)|0}k=(z>>>9<<14&49152|l&16383|0)%(c[3530968]|0)|0;do{if((a[o+k|0]|0)==0){l=(w+z&511)-16|0;t=(y-P-p&255)-16|0;d=(O|0)!=0;h=c[2443648]|0;if((N|0)==0){if(d){SJ(q,k,l,t,m,r,0,h,s);break}else{SH(q,k,l,t,m,r,0,h,s);break}}else{if(d){SN(q,k,l,t,m,r,0,h,s);break}else{SL(q,k,l,t,m,r,0,h,s);break}}}}while(0);if((v|0)>0){v=v-1|0}else{break}}return}function d6U(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;fxU(0,425984);if((c[2394]|0)==0){a=c[2112932]|0}else{c[2394]=0;b=c[3532596]|0;c[2112932]=b;d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];a=b}b=c[2388160]|0;d=a|0;e=0;while(1){f=b+e|0;c[d>>2]=f;c[d+131072>>2]=f;f=e+1024|0;if(f>>>0>2097151){break}else{d=d+4|0;e=f}}e=c[2388286]|0;d=a+8192|0;f=2097152;while(1){g=e+(f-2097152)|0;c[d>>2]=g;c[d+65536>>2]=g;c[d+131072>>2]=g;g=f+1024|0;if(g>>>0>2228223){break}else{d=d+4|0;f=g}}f=c[3531132]|0;d=a+12288|0;g=3145728;while(1){h=f+(g-3145728)|0;c[d>>2]=h;c[d+65536>>2]=h;c[d+131072>>2]=h;h=g+1024|0;if(h>>>0>3211263){break}else{d=d+4|0;g=h}}g=f+65536|0;c[a+28672>>2]=g;c[a+94208>>2]=g;c[a+159744>>2]=g;g=c[2387204]|0;c[a+28676>>2]=g;c[a+94212>>2]=g;c[a+159748>>2]=g;d=g+1024|0;c[a+28680>>2]=d;c[a+94216>>2]=d;c[a+159752>>2]=d;d=g+2048|0;c[a+28684>>2]=d;c[a+94220>>2]=d;c[a+159756>>2]=d;d=a+28688|0;g=7344128;while(1){h=f+(g-7274496)|0;c[d>>2]=h;c[d+65536>>2]=h;c[d+131072>>2]=h;h=g+1024|0;if(h>>>0>7405567){break}else{d=d+4|0;g=h}}g=c[3529470]|0;d=a+32768|0;f=8388608;while(1){h=g+(f-8388608)|0;c[d>>2]=h;c[d+65536>>2]=h;c[d+131072>>2]=h;h=f+1024|0;if(h>>>0>8454143){break}else{d=d+4|0;f=h}}f=c[3529436]|0;d=a+34816|0;g=8912896;while(1){h=f+(g-8912896)|0;c[d>>2]=h;c[d+65536>>2]=h;c[d+131072>>2]=h;h=g+1024|0;if(h>>>0>8978431){break}else{d=d+4|0;g=h}}g=c[3529656]|0;c[a+40960>>2]=g;c[a+106496>>2]=g;c[a+172032>>2]=g;d=g+1024|0;c[a+40964>>2]=d;c[a+106500>>2]=d;c[a+172036>>2]=d;c[a+108544>>2]=e+131072;e=c[3529638]|0;c[a+45056>>2]=e;c[a+110592>>2]=e;c[a+176128>>2]=e;d=e+1024|0;c[a+45060>>2]=d;c[a+110596>>2]=d;c[a+176132>>2]=d;d=e+2048|0;c[a+45064>>2]=d;c[a+110600>>2]=d;c[a+176136>>2]=d;d=e+3072|0;c[a+45068>>2]=d;c[a+110604>>2]=d;c[a+176140>>2]=d;d=e+4096|0;c[a+45072>>2]=d;c[a+110608>>2]=d;c[a+176144>>2]=d;d=e+5120|0;c[a+45076>>2]=d;c[a+110612>>2]=d;c[a+176148>>2]=d;d=e+6144|0;c[a+45080>>2]=d;c[a+110616>>2]=d;c[a+176152>>2]=d;d=e+7168|0;c[a+45084>>2]=d;c[a+110620>>2]=d;c[a+176156>>2]=d;d=e+8192|0;c[a+45088>>2]=d;c[a+110624>>2]=d;c[a+176160>>2]=d;d=e+9216|0;c[a+45092>>2]=d;c[a+110628>>2]=d;c[a+176164>>2]=d;d=e+10240|0;c[a+45096>>2]=d;c[a+110632>>2]=d;c[a+176168>>2]=d;d=e+11264|0;c[a+45100>>2]=d;c[a+110636>>2]=d;c[a+176172>>2]=d;d=e+12288|0;c[a+45104>>2]=d;c[a+110640>>2]=d;c[a+176176>>2]=d;d=e+13312|0;c[a+45108>>2]=d;c[a+110644>>2]=d;c[a+176180>>2]=d;d=e+14336|0;c[a+45112>>2]=d;c[a+110648>>2]=d;c[a+176184>>2]=d;d=e+15360|0;c[a+45116>>2]=d;c[a+110652>>2]=d;c[a+176188>>2]=d;c[a+196728>>2]=324;c[a+196648>>2]=510;c[a+196688>>2]=2842;c[a+196608>>2]=1824;c[a+49152>>2]=1;c[a+114688>>2]=1;c[a+49156>>2]=1;c[a+114692>>2]=1;c[a+49160>>2]=1;c[a+114696>>2]=1;c[a+49164>>2]=1;c[a+114700>>2]=1;c[a+49168>>2]=1;c[a+114704>>2]=1;c[a+49172>>2]=1;c[a+114708>>2]=1;c[a+49176>>2]=1;c[a+114712>>2]=1;c[a+49180>>2]=1;c[a+114716>>2]=1;c[a+49184>>2]=1;c[a+114720>>2]=1;c[a+49188>>2]=1;c[a+114724>>2]=1;c[a+49192>>2]=1;c[a+114728>>2]=1;c[a+49196>>2]=1;c[a+114732>>2]=1;c[a+49200>>2]=1;c[a+114736>>2]=1;c[a+49204>>2]=1;c[a+114740>>2]=1;c[a+49208>>2]=1;c[a+114744>>2]=1;c[a+49212>>2]=1;c[a+114748>>2]=1;c[a+196692>>2]=286;c[a+196612>>2]=1084;c[a+196732>>2]=3428;c[a+196652>>2]=3130;a=c[3532592]|0;if((a|0)!=0){gGC(a|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;gGG(b+1048576|0,b+524288|0,1048576);b=0;while(1){if((b|0)>=1024){i=0;break}j=9638528+(b<<2)|0;if((c[j>>2]|0)==0){k=44240;break}else{b=b+1|0}}do{if((k|0)==44240){b=gGq(2359296)|0;c[j>>2]=b;if((b|0)==0){i=0;break}gGz(b|0,0,2359296);i=b}}while(0);j=c[2386648]|0;gGC(i|0,j|0,131072)|0;b=i+1310720|0;a=j+131072|0;gGC(b|0,a|0,131072)|0;a=i+131072|0;b=j+262144|0;gGC(a|0,b|0,131072)|0;b=i+1441792|0;a=j+393216|0;gGC(b|0,a|0,131072)|0;a=i+262144|0;b=j+524288|0;gGC(a|0,b|0,131072)|0;b=i+1572864|0;a=j+655360|0;gGC(b|0,a|0,131072)|0;a=i+393216|0;b=j+786432|0;gGC(a|0,b|0,131072)|0;b=i+1703936|0;a=j+917504|0;gGC(b|0,a|0,131072)|0;a=i+524288|0;b=j+1048576|0;gGC(a|0,b|0,131072)|0;b=i+1835008|0;a=j+1179648|0;gGC(b|0,a|0,131072)|0;a=i+655360|0;b=j+1310720|0;gGC(a|0,b|0,131072)|0;b=i+1966080|0;a=j+1441792|0;gGC(b|0,a|0,131072)|0;a=i+1048576|0;b=j+1572864|0;gGC(a|0,b|0,131072)|0;b=i+2097152|0;a=j+1703936|0;gGC(b|0,a|0,131072)|0;a=i+1179648|0;b=j+1835008|0;gGC(a|0,b|0,131072)|0;b=i+2228224|0;a=j+1966080|0;gGC(b|0,a|0,131072)|0;gGC(j|0,i|0,2359296)|0;j=0;while(1){if((j|0)>=1024){k=44248;break}l=9638528+(j<<2)|0;if((c[l>>2]|0)==(i|0)){break}else{j=j+1|0}}if((k|0)==44248){return}gGr(i);c[l>>2]=0;return}function d6V(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;fxU(0,425984);if((c[2394]|0)==0){a=c[2112932]|0}else{c[2394]=0;b=c[3532596]|0;c[2112932]=b;d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];a=b}b=c[2388160]|0;d=a|0;e=0;while(1){f=b+e|0;c[d>>2]=f;c[d+131072>>2]=f;f=e+1024|0;if(f>>>0>2097151){break}else{d=d+4|0;e=f}}e=c[2388286]|0;d=a+8192|0;f=2097152;while(1){g=e+(f-2097152)|0;c[d>>2]=g;c[d+65536>>2]=g;c[d+131072>>2]=g;g=f+1024|0;if(g>>>0>2228223){break}else{d=d+4|0;f=g}}f=c[3531132]|0;d=a+12288|0;e=3145728;while(1){g=f+(e-3145728)|0;c[d>>2]=g;c[d+65536>>2]=g;c[d+131072>>2]=g;g=e+1024|0;if(g>>>0>3211263){break}else{d=d+4|0;e=g}}e=f+65536|0;c[a+28672>>2]=e;c[a+94208>>2]=e;c[a+159744>>2]=e;e=c[2387204]|0;c[a+28676>>2]=e;c[a+94212>>2]=e;c[a+159748>>2]=e;d=e+1024|0;c[a+28680>>2]=d;c[a+94216>>2]=d;c[a+159752>>2]=d;d=e+2048|0;c[a+28684>>2]=d;c[a+94220>>2]=d;c[a+159756>>2]=d;d=a+28688|0;e=7344128;while(1){g=f+(e-7274496)|0;c[d>>2]=g;c[d+65536>>2]=g;c[d+131072>>2]=g;g=e+1024|0;if(g>>>0>7405567){break}else{d=d+4|0;e=g}}e=c[3529656]|0;c[a+32768>>2]=e;c[a+98304>>2]=e;c[a+163840>>2]=e;d=e+1024|0;c[a+32772>>2]=d;c[a+98308>>2]=d;c[a+163844>>2]=d;d=c[3529638]|0;c[a+36864>>2]=d;c[a+102400>>2]=d;c[a+167936>>2]=d;e=d+1024|0;c[a+36868>>2]=e;c[a+102404>>2]=e;c[a+167940>>2]=e;e=d+2048|0;c[a+36872>>2]=e;c[a+102408>>2]=e;c[a+167944>>2]=e;e=d+3072|0;c[a+36876>>2]=e;c[a+102412>>2]=e;c[a+167948>>2]=e;e=d+4096|0;c[a+36880>>2]=e;c[a+102416>>2]=e;c[a+167952>>2]=e;e=d+5120|0;c[a+36884>>2]=e;c[a+102420>>2]=e;c[a+167956>>2]=e;e=d+6144|0;c[a+36888>>2]=e;c[a+102424>>2]=e;c[a+167960>>2]=e;e=d+7168|0;c[a+36892>>2]=e;c[a+102428>>2]=e;c[a+167964>>2]=e;e=d+8192|0;c[a+36896>>2]=e;c[a+102432>>2]=e;c[a+167968>>2]=e;e=d+9216|0;c[a+36900>>2]=e;c[a+102436>>2]=e;c[a+167972>>2]=e;e=d+10240|0;c[a+36904>>2]=e;c[a+102440>>2]=e;c[a+167976>>2]=e;e=d+11264|0;c[a+36908>>2]=e;c[a+102444>>2]=e;c[a+167980>>2]=e;e=d+12288|0;c[a+36912>>2]=e;c[a+102448>>2]=e;c[a+167984>>2]=e;e=d+13312|0;c[a+36916>>2]=e;c[a+102452>>2]=e;c[a+167988>>2]=e;e=d+14336|0;c[a+36920>>2]=e;c[a+102456>>2]=e;c[a+167992>>2]=e;e=d+15360|0;c[a+36924>>2]=e;c[a+102460>>2]=e;c[a+167996>>2]=e;e=c[3529470]|0;d=a+45056|0;f=11534336;while(1){g=e+(f-11534336)|0;c[d>>2]=g;c[d+65536>>2]=g;c[d+131072>>2]=g;g=f+1024|0;if(g>>>0>11599871){break}else{d=d+4|0;f=g}}f=c[3529436]|0;d=a+47104|0;e=12058624;while(1){g=f+(e-12058624)|0;c[d>>2]=g;c[d+65536>>2]=g;c[d+131072>>2]=g;g=e+1024|0;if(g>>>0>12124159){break}else{d=d+4|0;e=g}}c[a+196728>>2]=324;c[a+196648>>2]=510;c[a+196688>>2]=2842;c[a+196608>>2]=1824;c[a+49152>>2]=1;c[a+114688>>2]=1;c[a+49156>>2]=1;c[a+114692>>2]=1;c[a+49160>>2]=1;c[a+114696>>2]=1;c[a+49164>>2]=1;c[a+114700>>2]=1;c[a+49168>>2]=1;c[a+114704>>2]=1;c[a+49172>>2]=1;c[a+114708>>2]=1;c[a+49176>>2]=1;c[a+114712>>2]=1;c[a+49180>>2]=1;c[a+114716>>2]=1;c[a+49184>>2]=1;c[a+114720>>2]=1;c[a+49188>>2]=1;c[a+114724>>2]=1;c[a+49192>>2]=1;c[a+114728>>2]=1;c[a+49196>>2]=1;c[a+114732>>2]=1;c[a+49200>>2]=1;c[a+114736>>2]=1;c[a+49204>>2]=1;c[a+114740>>2]=1;c[a+49208>>2]=1;c[a+114744>>2]=1;c[a+49212>>2]=1;c[a+114748>>2]=1;c[a+196692>>2]=286;c[a+196612>>2]=1084;c[a+196732>>2]=3428;c[a+196652>>2]=3130;a=c[3532592]|0;if((a|0)==0){h=c[2113054]|0;c[2113060]=h;c[2394]=-1;i=b+1048576|0;j=b+524288|0;gGG(i|0,j|0,1048576);k=c[2386648]|0;l=k+1048576|0;m=k+786432|0;gGG(l|0,m|0,786432);d6z();return}gGC(a|0,9104152,280)|0;h=c[2113054]|0;c[2113060]=h;c[2394]=-1;i=b+1048576|0;j=b+524288|0;gGG(i|0,j|0,1048576);k=c[2386648]|0;l=k+1048576|0;m=k+786432|0;gGG(l|0,m|0,786432);d6z();return}function d6W(){var a=0,b=0,d=0;d6M();a=c[2386648]|0;b=a+1048576|0;d=a+524288|0;gGC(b|0,d|0,524288)|0;gGG(a|0,d|0,1048576);return}function d6X(){var a=0,b=0,d=0,e=0;d6M();if((c[2394]|0)==0){a=c[2112932]|0;b=c[3532592]|0}else{c[2394]=0;d=c[3532596]|0;c[2112932]=d;e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060];a=d;b=e}c[a+61440>>2]=2;c[a+126976>>2]=2;c[a+196696>>2]=460;c[a+196616>>2]=2412;c[a+196736>>2]=1468;c[a+196656>>2]=3402;if((b|0)!=0){gGC(b|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;b=c[2386648]|0;a=b+1048576|0;e=b+524288|0;gGC(a|0,e|0,2621440)|0;return}function d6Y(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0;fxU(0,425984);if((c[2394]|0)==0){a=c[2112932]|0}else{c[2394]=0;b=c[3532596]|0;c[2112932]=b;d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];a=b}b=c[2388160]|0;d=a|0;e=0;while(1){f=b+e|0;c[d>>2]=f;c[d+131072>>2]=f;f=e+1024|0;if(f>>>0>262143){break}else{d=d+4|0;e=f}}e=c[2387204]|0;c[a+45056>>2]=e;c[a+110592>>2]=e;c[a+176128>>2]=e;d=e+1024|0;c[a+45060>>2]=d;c[a+110596>>2]=d;c[a+176132>>2]=d;d=e+2048|0;c[a+45064>>2]=d;c[a+110600>>2]=d;c[a+176136>>2]=d;d=e+3072|0;c[a+45068>>2]=d;c[a+110604>>2]=d;c[a+176140>>2]=d;d=c[3529638]|0;c[a+49152>>2]=d;c[a+114688>>2]=d;c[a+180224>>2]=d;e=d+1024|0;c[a+49156>>2]=e;c[a+114692>>2]=e;c[a+180228>>2]=e;e=d+2048|0;c[a+49160>>2]=e;c[a+114696>>2]=e;c[a+180232>>2]=e;e=d+3072|0;c[a+49164>>2]=e;c[a+114700>>2]=e;c[a+180236>>2]=e;e=d+4096|0;c[a+49168>>2]=e;c[a+114704>>2]=e;c[a+180240>>2]=e;e=d+5120|0;c[a+49172>>2]=e;c[a+114708>>2]=e;c[a+180244>>2]=e;e=d+6144|0;c[a+49176>>2]=e;c[a+114712>>2]=e;c[a+180248>>2]=e;e=d+7168|0;c[a+49180>>2]=e;c[a+114716>>2]=e;c[a+180252>>2]=e;e=d+8192|0;c[a+49184>>2]=e;c[a+114720>>2]=e;c[a+180256>>2]=e;e=d+9216|0;c[a+49188>>2]=e;c[a+114724>>2]=e;c[a+180260>>2]=e;e=d+10240|0;c[a+49192>>2]=e;c[a+114728>>2]=e;c[a+180264>>2]=e;e=d+11264|0;c[a+49196>>2]=e;c[a+114732>>2]=e;c[a+180268>>2]=e;e=d+12288|0;c[a+49200>>2]=e;c[a+114736>>2]=e;c[a+180272>>2]=e;e=d+13312|0;c[a+49204>>2]=e;c[a+114740>>2]=e;c[a+180276>>2]=e;e=d+14336|0;c[a+49208>>2]=e;c[a+114744>>2]=e;c[a+180280>>2]=e;e=d+15360|0;c[a+49212>>2]=e;c[a+114748>>2]=e;c[a+180284>>2]=e;e=c[3529656]|0;c[a+57344>>2]=e;c[a+122880>>2]=e;c[a+188416>>2]=e;d=e+1024|0;c[a+57348>>2]=d;c[a+122884>>2]=d;c[a+188420>>2]=d;d=c[2388286]|0;e=a+61440|0;b=15728640;while(1){f=d+(b-15728640)|0;c[e>>2]=f;c[e+65536>>2]=f;c[e+131072>>2]=f;f=b+1024|0;if(f>>>0>15753215){break}else{e=e+4|0;b=f}}c[a+196728>>2]=2628;c[a+196648>>2]=524;c[a+196688>>2]=442;c[a+196608>>2]=2154;c[a+40960>>2]=1;c[a+106496>>2]=1;c[a+40964>>2]=1;c[a+106500>>2]=1;c[a+40968>>2]=1;c[a+106504>>2]=1;c[a+40972>>2]=1;c[a+106508>>2]=1;c[a+40976>>2]=1;c[a+106512>>2]=1;c[a+40980>>2]=1;c[a+106516>>2]=1;c[a+40984>>2]=1;c[a+106520>>2]=1;c[a+40988>>2]=1;c[a+106524>>2]=1;c[a+40992>>2]=1;c[a+106528>>2]=1;c[a+40996>>2]=1;c[a+106532>>2]=1;c[a+41e3>>2]=1;c[a+106536>>2]=1;c[a+41004>>2]=1;c[a+106540>>2]=1;c[a+41008>>2]=1;c[a+106544>>2]=1;c[a+41012>>2]=1;c[a+106548>>2]=1;c[a+41016>>2]=1;c[a+106552>>2]=1;c[a+41020>>2]=1;c[a+106556>>2]=1;c[a+196692>>2]=286;c[a+196612>>2]=1084;c[a+196732>>2]=3428;c[a+196652>>2]=3130;a=c[3532592]|0;if((a|0)==0){g=c[2113054]|0;c[2113060]=g;c[2394]=-1;h=c[2386648]|0;i=h+524288|0;gGC(i|0,h|0,524288)|0;return}gGC(a|0,9104152,280)|0;g=c[2113054]|0;c[2113060]=g;c[2394]=-1;h=c[2386648]|0;i=h+524288|0;gGC(i|0,h|0,524288)|0;return}function d6Z(){var a=0,b=0,d=0,e=0,f=0,g=0;fxU(0,425984);if((c[2394]|0)==0){a=c[2112932]|0}else{c[2394]=0;b=c[3532596]|0;c[2112932]=b;d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];a=b}b=c[2388160]|0;d=a|0;e=0;while(1){f=b+e|0;c[d>>2]=f;c[d+131072>>2]=f;f=e+1024|0;if(f>>>0>1048575){break}else{d=d+4|0;e=f}}e=c[2387204]|0;c[a+28672>>2]=e;c[a+94208>>2]=e;c[a+159744>>2]=e;d=e+1024|0;c[a+28676>>2]=d;c[a+94212>>2]=d;c[a+159748>>2]=d;d=e+2048|0;c[a+28680>>2]=d;c[a+94216>>2]=d;c[a+159752>>2]=d;d=e+3072|0;c[a+28684>>2]=d;c[a+94220>>2]=d;c[a+159756>>2]=d;d=c[2388286]|0;e=a+36864|0;b=9437184;while(1){f=d+(b-9437184)|0;c[e>>2]=f;c[e+65536>>2]=f;c[e+131072>>2]=f;f=b+1024|0;if(f>>>0>10485759){break}else{e=e+4|0;b=f}}b=c[3529656]|0;c[a+40960>>2]=b;c[a+106496>>2]=b;c[a+172032>>2]=b;e=b+1024|0;c[a+40964>>2]=e;c[a+106500>>2]=e;c[a+172036>>2]=e;e=c[3529638]|0;c[a+57344>>2]=e;c[a+122880>>2]=e;c[a+188416>>2]=e;b=e+1024|0;c[a+57348>>2]=b;c[a+122884>>2]=b;c[a+188420>>2]=b;b=e+2048|0;c[a+57352>>2]=b;c[a+122888>>2]=b;c[a+188424>>2]=b;b=e+3072|0;c[a+57356>>2]=b;c[a+122892>>2]=b;c[a+188428>>2]=b;b=e+4096|0;c[a+57360>>2]=b;c[a+122896>>2]=b;c[a+188432>>2]=b;b=e+5120|0;c[a+57364>>2]=b;c[a+122900>>2]=b;c[a+188436>>2]=b;b=e+6144|0;c[a+57368>>2]=b;c[a+122904>>2]=b;c[a+188440>>2]=b;b=e+7168|0;c[a+57372>>2]=b;c[a+122908>>2]=b;c[a+188444>>2]=b;b=e+8192|0;c[a+57376>>2]=b;c[a+122912>>2]=b;c[a+188448>>2]=b;b=e+9216|0;c[a+57380>>2]=b;c[a+122916>>2]=b;c[a+188452>>2]=b;b=e+10240|0;c[a+57384>>2]=b;c[a+122920>>2]=b;c[a+188456>>2]=b;b=e+11264|0;c[a+57388>>2]=b;c[a+122924>>2]=b;c[a+188460>>2]=b;b=e+12288|0;c[a+57392>>2]=b;c[a+122928>>2]=b;c[a+188464>>2]=b;b=e+13312|0;c[a+57396>>2]=b;c[a+122932>>2]=b;c[a+188468>>2]=b;b=e+14336|0;c[a+57400>>2]=b;c[a+122936>>2]=b;c[a+188472>>2]=b;b=e+15360|0;c[a+57404>>2]=b;c[a+122940>>2]=b;c[a+188476>>2]=b;c[a+196728>>2]=2628;c[a+196648>>2]=524;c[a+196688>>2]=950;c[a+196608>>2]=436;c[a+4096>>2]=1;c[a+69632>>2]=1;c[a+4100>>2]=1;c[a+69636>>2]=1;c[a+4104>>2]=1;c[a+69640>>2]=1;c[a+4108>>2]=1;c[a+69644>>2]=1;c[a+4112>>2]=1;c[a+69648>>2]=1;c[a+4116>>2]=1;c[a+69652>>2]=1;c[a+4120>>2]=1;c[a+69656>>2]=1;c[a+4124>>2]=1;c[a+69660>>2]=1;c[a+4128>>2]=1;c[a+69664>>2]=1;c[a+4132>>2]=1;c[a+69668>>2]=1;c[a+4136>>2]=1;c[a+69672>>2]=1;c[a+4140>>2]=1;c[a+69676>>2]=1;c[a+4144>>2]=1;c[a+69680>>2]=1;c[a+4148>>2]=1;c[a+69684>>2]=1;c[a+4152>>2]=1;c[a+69688>>2]=1;c[a+4156>>2]=1;c[a+69692>>2]=1;c[a+196692>>2]=286;c[a+196612>>2]=1084;c[a+196732>>2]=3428;c[a+196652>>2]=3130;a=c[3532592]|0;if((a|0)==0){g=c[2113054]|0;c[2113060]=g;c[2394]=-1;return}gGC(a|0,9104152,280)|0;g=c[2113054]|0;c[2113060]=g;c[2394]=-1;return}function d6_(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;fxU(0,425984);if((c[2394]|0)==0){a=c[2112932]|0}else{c[2394]=0;b=c[3532596]|0;c[2112932]=b;d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];a=b}b=c[2388160]|0;d=a|0;e=0;while(1){f=b+e|0;c[d>>2]=f;c[d+131072>>2]=f;f=e+1024|0;if(f>>>0>1048575){break}else{d=d+4|0;e=f}}e=c[2388286]|0;d=a+8192|0;b=2097152;while(1){f=e+(b-2097152)|0;c[d>>2]=f;c[d+65536>>2]=f;c[d+131072>>2]=f;f=b+1024|0;if(f>>>0>2162687){break}else{d=d+4|0;b=f}}b=c[3531132]|0;d=b+65536|0;c[a+28672>>2]=d;c[a+94208>>2]=d;c[a+159744>>2]=d;d=c[2387204]|0;c[a+28676>>2]=d;c[a+94212>>2]=d;c[a+159748>>2]=d;e=d+1024|0;c[a+28680>>2]=e;c[a+94216>>2]=e;c[a+159752>>2]=e;e=d+2048|0;c[a+28684>>2]=e;c[a+94220>>2]=e;c[a+159756>>2]=e;e=b+69632|0;c[a+28688>>2]=e;c[a+94224>>2]=e;c[a+159760>>2]=e;e=b+70656|0;c[a+28692>>2]=e;c[a+94228>>2]=e;c[a+159764>>2]=e;e=b+71680|0;c[a+28696>>2]=e;c[a+94232>>2]=e;c[a+159768>>2]=e;e=b+72704|0;c[a+28700>>2]=e;c[a+94236>>2]=e;c[a+159772>>2]=e;e=b+73728|0;c[a+28704>>2]=e;c[a+94240>>2]=e;c[a+159776>>2]=e;e=b+74752|0;c[a+28708>>2]=e;c[a+94244>>2]=e;c[a+159780>>2]=e;e=b+75776|0;c[a+28712>>2]=e;c[a+94248>>2]=e;c[a+159784>>2]=e;e=b+76800|0;c[a+28716>>2]=e;c[a+94252>>2]=e;c[a+159788>>2]=e;e=b+77824|0;c[a+28720>>2]=e;c[a+94256>>2]=e;c[a+159792>>2]=e;e=b+78848|0;c[a+28724>>2]=e;c[a+94260>>2]=e;c[a+159796>>2]=e;e=b+79872|0;c[a+28728>>2]=e;c[a+94264>>2]=e;c[a+159800>>2]=e;e=b+80896|0;c[a+28732>>2]=e;c[a+94268>>2]=e;c[a+159804>>2]=e;e=c[3529470]|0;b=a+32768|0;d=8388608;while(1){f=e+(d-8388608)|0;c[b>>2]=f;c[b+65536>>2]=f;c[b+131072>>2]=f;f=d+1024|0;if(f>>>0>8421375){break}else{b=b+4|0;d=f}}d=c[3529436]|0;b=a+34816|0;e=8912896;while(1){f=d+(e-8912896)|0;c[b>>2]=f;c[b+65536>>2]=f;c[b+131072>>2]=f;f=e+1024|0;if(f>>>0>8945663){break}else{b=b+4|0;e=f}}e=c[3529656]|0;c[a+40960>>2]=e;c[a+106496>>2]=e;c[a+172032>>2]=e;b=e+1024|0;c[a+40964>>2]=b;c[a+106500>>2]=b;c[a+172036>>2]=b;b=c[3529638]|0;e=a+45056|0;d=11534336;while(1){f=b+(d-11534336)|0;c[e>>2]=f;c[e+65536>>2]=f;c[e+131072>>2]=f;f=d+1024|0;if(f>>>0>11567103){break}else{e=e+4|0;d=f}}c[a+196728>>2]=3036;c[a+196648>>2]=110;c[a+196688>>2]=442;c[a+196608>>2]=2154;c[a+53248>>2]=1;c[a+118784>>2]=1;c[a+53252>>2]=1;c[a+118788>>2]=1;c[a+53256>>2]=1;c[a+118792>>2]=1;c[a+53260>>2]=1;c[a+118796>>2]=1;c[a+53264>>2]=1;c[a+118800>>2]=1;c[a+53268>>2]=1;c[a+118804>>2]=1;c[a+53272>>2]=1;c[a+118808>>2]=1;c[a+53276>>2]=1;c[a+118812>>2]=1;c[a+53280>>2]=1;c[a+118816>>2]=1;c[a+53284>>2]=1;c[a+118820>>2]=1;c[a+53288>>2]=1;c[a+118824>>2]=1;c[a+53292>>2]=1;c[a+118828>>2]=1;c[a+53296>>2]=1;c[a+118832>>2]=1;c[a+53300>>2]=1;c[a+118836>>2]=1;c[a+53304>>2]=1;c[a+118840>>2]=1;c[a+53308>>2]=1;c[a+118844>>2]=1;c[a+196692>>2]=286;c[a+196612>>2]=1084;c[a+196732>>2]=3428;c[a+196652>>2]=3130;a=c[3532592]|0;if((a|0)!=0){gGC(a|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;a=0;while(1){if((a|0)>=1024){g=0;h=44331;break}i=9638528+(a<<2)|0;if((c[i>>2]|0)==0){break}else{a=a+1|0}}if((h|0)==44331){c[3530432]=g;c[2387026]=2097152;c[2387025]=2097152;j=c[3530846]|0;k=j+2097152|0;gGC(k|0,j|0,1048576)|0;l=j+1048576|0;gGC(j|0,l|0,2097152)|0;m=c[3530610]|0;n=m+1048576|0;gGC(g|0,n|0,1048576)|0;o=g+1048576|0;p=m+3145728|0;gGC(o|0,p|0,1048576)|0;q=m+2097152|0;gGC(n|0,q|0,1048576)|0;return}h=gGq(2097152)|0;c[i>>2]=h;if((h|0)==0){g=0;c[3530432]=g;c[2387026]=2097152;c[2387025]=2097152;j=c[3530846]|0;k=j+2097152|0;gGC(k|0,j|0,1048576)|0;l=j+1048576|0;gGC(j|0,l|0,2097152)|0;m=c[3530610]|0;n=m+1048576|0;gGC(g|0,n|0,1048576)|0;o=g+1048576|0;p=m+3145728|0;gGC(o|0,p|0,1048576)|0;q=m+2097152|0;gGC(n|0,q|0,1048576)|0;return}gGz(h|0,0,2097152);g=h;c[3530432]=g;c[2387026]=2097152;c[2387025]=2097152;j=c[3530846]|0;k=j+2097152|0;gGC(k|0,j|0,1048576)|0;l=j+1048576|0;gGC(j|0,l|0,2097152)|0;m=c[3530610]|0;n=m+1048576|0;gGC(g|0,n|0,1048576)|0;o=g+1048576|0;p=m+3145728|0;gGC(o|0,p|0,1048576)|0;q=m+2097152|0;gGC(n|0,q|0,1048576)|0;return}function d6$(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;fxU(0,425984);if((c[2394]|0)==0){a=c[2112932]|0}else{c[2394]=0;b=c[3532596]|0;c[2112932]=b;d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];a=b}b=c[2388160]|0;d=a|0;e=0;while(1){f=b+e|0;c[d>>2]=f;c[d+131072>>2]=f;f=e+1024|0;if(f>>>0>1048575){break}else{d=d+4|0;e=f}}e=c[2388286]|0;d=a+8192|0;b=2097152;while(1){f=e+(b-2097152)|0;c[d>>2]=f;c[d+65536>>2]=f;c[d+131072>>2]=f;f=b+1024|0;if(f>>>0>2162687){break}else{d=d+4|0;b=f}}b=c[3531132]|0;d=b+65536|0;c[a+28672>>2]=d;c[a+94208>>2]=d;c[a+159744>>2]=d;d=c[2387204]|0;c[a+28676>>2]=d;c[a+94212>>2]=d;c[a+159748>>2]=d;e=d+1024|0;c[a+28680>>2]=e;c[a+94216>>2]=e;c[a+159752>>2]=e;e=d+2048|0;c[a+28684>>2]=e;c[a+94220>>2]=e;c[a+159756>>2]=e;e=b+69632|0;c[a+28688>>2]=e;c[a+94224>>2]=e;c[a+159760>>2]=e;e=b+70656|0;c[a+28692>>2]=e;c[a+94228>>2]=e;c[a+159764>>2]=e;e=b+71680|0;c[a+28696>>2]=e;c[a+94232>>2]=e;c[a+159768>>2]=e;e=b+72704|0;c[a+28700>>2]=e;c[a+94236>>2]=e;c[a+159772>>2]=e;e=b+73728|0;c[a+28704>>2]=e;c[a+94240>>2]=e;c[a+159776>>2]=e;e=b+74752|0;c[a+28708>>2]=e;c[a+94244>>2]=e;c[a+159780>>2]=e;e=b+75776|0;c[a+28712>>2]=e;c[a+94248>>2]=e;c[a+159784>>2]=e;e=b+76800|0;c[a+28716>>2]=e;c[a+94252>>2]=e;c[a+159788>>2]=e;e=b+77824|0;c[a+28720>>2]=e;c[a+94256>>2]=e;c[a+159792>>2]=e;e=b+78848|0;c[a+28724>>2]=e;c[a+94260>>2]=e;c[a+159796>>2]=e;e=b+79872|0;c[a+28728>>2]=e;c[a+94264>>2]=e;c[a+159800>>2]=e;e=b+80896|0;c[a+28732>>2]=e;c[a+94268>>2]=e;c[a+159804>>2]=e;e=c[3529470]|0;b=a+32768|0;d=8388608;while(1){f=e+(d-8388608)|0;c[b>>2]=f;c[b+65536>>2]=f;c[b+131072>>2]=f;f=d+1024|0;if(f>>>0>8421375){break}else{b=b+4|0;d=f}}d=c[3529436]|0;b=a+34816|0;e=8912896;while(1){f=d+(e-8912896)|0;c[b>>2]=f;c[b+65536>>2]=f;c[b+131072>>2]=f;f=e+1024|0;if(f>>>0>8945663){break}else{b=b+4|0;e=f}}e=c[3529656]|0;c[a+40960>>2]=e;c[a+106496>>2]=e;c[a+172032>>2]=e;b=e+1024|0;c[a+40964>>2]=b;c[a+106500>>2]=b;c[a+172036>>2]=b;b=c[3529638]|0;e=a+45056|0;d=11534336;while(1){f=b+(d-11534336)|0;c[e>>2]=f;c[e+65536>>2]=f;c[e+131072>>2]=f;f=d+1024|0;if(f>>>0>11567103){break}else{e=e+4|0;d=f}}c[a+196728>>2]=3036;c[a+196648>>2]=110;c[a+196688>>2]=2224;c[a+196608>>2]=2856;c[a+53248>>2]=1;c[a+118784>>2]=1;c[a+53252>>2]=1;c[a+118788>>2]=1;c[a+53256>>2]=1;c[a+118792>>2]=1;c[a+53260>>2]=1;c[a+118796>>2]=1;c[a+53264>>2]=1;c[a+118800>>2]=1;c[a+53268>>2]=1;c[a+118804>>2]=1;c[a+53272>>2]=1;c[a+118808>>2]=1;c[a+53276>>2]=1;c[a+118812>>2]=1;c[a+53280>>2]=1;c[a+118816>>2]=1;c[a+53284>>2]=1;c[a+118820>>2]=1;c[a+53288>>2]=1;c[a+118824>>2]=1;c[a+53292>>2]=1;c[a+118828>>2]=1;c[a+53296>>2]=1;c[a+118832>>2]=1;c[a+53300>>2]=1;c[a+118836>>2]=1;c[a+53304>>2]=1;c[a+118840>>2]=1;c[a+53308>>2]=1;c[a+118844>>2]=1;c[a+196692>>2]=286;c[a+196612>>2]=1084;c[a+196732>>2]=3428;c[a+196652>>2]=3130;a=c[3532592]|0;if((a|0)==0){g=c[2113054]|0;c[2113060]=g;c[2394]=-1;h=c[3530610]|0;i=h+524288|0;c[3530432]=i;j=c[2387025]|0;k=(j|0)/2|0;c[2387025]=k;c[2387026]=k;l=h+262144|0;gGC(i|0,l|0,262144)|0;return}gGC(a|0,9104152,280)|0;g=c[2113054]|0;c[2113060]=g;c[2394]=-1;h=c[3530610]|0;i=h+524288|0;c[3530432]=i;j=c[2387025]|0;k=(j|0)/2|0;c[2387025]=k;c[2387026]=k;l=h+262144|0;gGC(i|0,l|0,262144)|0;return}function d60(){var a=0,b=0,d=0,e=0,f=0,g=0;fxU(0,425984);if((c[2394]|0)==0){a=c[2112932]|0}else{c[2394]=0;b=c[3532596]|0;c[2112932]=b;d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];a=b}b=c[2388160]|0;d=a|0;e=0;while(1){f=b+e|0;c[d>>2]=f;c[d+131072>>2]=f;f=e+1024|0;if(f>>>0>262143){break}else{d=d+4|0;e=f}}e=c[2388286]|0;d=a+8192|0;b=2097152;while(1){f=e+(b-2097152)|0;c[d>>2]=f;c[d+65536>>2]=f;c[d+131072>>2]=f;f=b+1024|0;if(f>>>0>2162687){break}else{d=d+4|0;b=f}}b=c[2387204]|0;c[a+12288>>2]=b;c[a+77824>>2]=b;c[a+143360>>2]=b;d=b+1024|0;c[a+12292>>2]=d;c[a+77828>>2]=d;c[a+143364>>2]=d;d=b+2048|0;c[a+12296>>2]=d;c[a+77832>>2]=d;c[a+143368>>2]=d;d=b+3072|0;c[a+12300>>2]=d;c[a+77836>>2]=d;c[a+143372>>2]=d;d=c[3529656]|0;c[a+40960>>2]=d;c[a+106496>>2]=d;c[a+172032>>2]=d;b=d+1024|0;c[a+40964>>2]=b;c[a+106500>>2]=b;c[a+172036>>2]=b;b=c[3529638]|0;c[a+45056>>2]=b;c[a+110592>>2]=b;c[a+176128>>2]=b;d=b+1024|0;c[a+45060>>2]=d;c[a+110596>>2]=d;c[a+176132>>2]=d;d=b+2048|0;c[a+45064>>2]=d;c[a+110600>>2]=d;c[a+176136>>2]=d;d=b+3072|0;c[a+45068>>2]=d;c[a+110604>>2]=d;c[a+176140>>2]=d;d=b+4096|0;c[a+45072>>2]=d;c[a+110608>>2]=d;c[a+176144>>2]=d;d=b+5120|0;c[a+45076>>2]=d;c[a+110612>>2]=d;c[a+176148>>2]=d;d=b+6144|0;c[a+45080>>2]=d;c[a+110616>>2]=d;c[a+176152>>2]=d;d=b+7168|0;c[a+45084>>2]=d;c[a+110620>>2]=d;c[a+176156>>2]=d;d=b+8192|0;c[a+45088>>2]=d;c[a+110624>>2]=d;c[a+176160>>2]=d;d=b+9216|0;c[a+45092>>2]=d;c[a+110628>>2]=d;c[a+176164>>2]=d;d=b+10240|0;c[a+45096>>2]=d;c[a+110632>>2]=d;c[a+176168>>2]=d;d=b+11264|0;c[a+45100>>2]=d;c[a+110636>>2]=d;c[a+176172>>2]=d;d=b+12288|0;c[a+45104>>2]=d;c[a+110640>>2]=d;c[a+176176>>2]=d;d=b+13312|0;c[a+45108>>2]=d;c[a+110644>>2]=d;c[a+176180>>2]=d;d=b+14336|0;c[a+45112>>2]=d;c[a+110648>>2]=d;c[a+176184>>2]=d;d=b+15360|0;c[a+45116>>2]=d;c[a+110652>>2]=d;c[a+176188>>2]=d;c[a+196728>>2]=324;c[a+196648>>2]=510;c[a+196688>>2]=2842;c[a+196608>>2]=1824;c[a+49152>>2]=1;c[a+114688>>2]=1;c[a+49156>>2]=1;c[a+114692>>2]=1;c[a+49160>>2]=1;c[a+114696>>2]=1;c[a+49164>>2]=1;c[a+114700>>2]=1;c[a+49168>>2]=1;c[a+114704>>2]=1;c[a+49172>>2]=1;c[a+114708>>2]=1;c[a+49176>>2]=1;c[a+114712>>2]=1;c[a+49180>>2]=1;c[a+114716>>2]=1;c[a+49184>>2]=1;c[a+114720>>2]=1;c[a+49188>>2]=1;c[a+114724>>2]=1;c[a+49192>>2]=1;c[a+114728>>2]=1;c[a+49196>>2]=1;c[a+114732>>2]=1;c[a+49200>>2]=1;c[a+114736>>2]=1;c[a+49204>>2]=1;c[a+114740>>2]=1;c[a+49208>>2]=1;c[a+114744>>2]=1;c[a+49212>>2]=1;c[a+114748>>2]=1;c[a+196692>>2]=286;c[a+196612>>2]=1084;c[a+196732>>2]=3428;c[a+196652>>2]=3130;a=c[3532592]|0;if((a|0)==0){g=c[2113054]|0;c[2113060]=g;c[2394]=-1;return}gGC(a|0,9104152,280)|0;g=c[2113054]|0;c[2113060]=g;c[2394]=-1;return}function d61(){var a=0,b=0,d=0,e=0,f=0,g=0;fxU(0,425984);if((c[2394]|0)==0){a=c[2112932]|0}else{c[2394]=0;b=c[3532596]|0;c[2112932]=b;d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];a=b}b=c[2388160]|0;d=a|0;e=0;while(1){f=b+e|0;c[d>>2]=f;c[d+131072>>2]=f;f=e+1024|0;if(f>>>0>2097151){break}else{d=d+4|0;e=f}}e=c[2388286]|0;d=a+8192|0;b=2097152;while(1){f=e+(b-2097152)|0;c[d>>2]=f;c[d+65536>>2]=f;c[d+131072>>2]=f;f=b+1024|0;if(f>>>0>2162687){break}else{d=d+4|0;b=f}}b=a+8448|0;d=2162688;while(1){f=e+(d-2162688)|0;c[b>>2]=f;c[b+65536>>2]=f;c[b+131072>>2]=f;f=d+1024|0;if(f>>>0>2228223){break}else{b=b+4|0;d=f}}d=a+8704|0;b=2228224;while(1){f=e+(b-2228224)|0;c[d>>2]=f;c[d+65536>>2]=f;c[d+131072>>2]=f;f=b+1024|0;if(f>>>0>2293759){break}else{d=d+4|0;b=f}}b=a+8960|0;d=2293760;while(1){f=e+(d-2293760)|0;c[b>>2]=f;c[b+65536>>2]=f;c[b+131072>>2]=f;f=d+1024|0;if(f>>>0>2359295){break}else{b=b+4|0;d=f}}d=a+9216|0;b=2359296;while(1){f=e+(b-2359296)|0;c[d>>2]=f;c[d+65536>>2]=f;c[d+131072>>2]=f;f=b+1024|0;if(f>>>0>2424831){break}else{d=d+4|0;b=f}}b=a+9472|0;d=2424832;while(1){f=e+(d-2424832)|0;c[b>>2]=f;c[b+65536>>2]=f;c[b+131072>>2]=f;f=d+1024|0;if(f>>>0>2490367){break}else{b=b+4|0;d=f}}d=a+9728|0;b=2490368;while(1){f=e+(b-2490368)|0;c[d>>2]=f;c[d+65536>>2]=f;c[d+131072>>2]=f;f=b+1024|0;if(f>>>0>2555903){break}else{d=d+4|0;b=f}}b=a+9984|0;d=2555904;while(1){f=e+(d-2555904)|0;c[b>>2]=f;c[b+65536>>2]=f;c[b+131072>>2]=f;f=d+1024|0;if(f>>>0>2621439){break}else{b=b+4|0;d=f}}d=c[2387204]|0;c[a+28676>>2]=d;c[a+94212>>2]=d;c[a+159748>>2]=d;b=d+1024|0;c[a+28680>>2]=b;c[a+94216>>2]=b;c[a+159752>>2]=b;b=d+2048|0;c[a+28684>>2]=b;c[a+94220>>2]=b;c[a+159756>>2]=b;b=c[3529656]|0;c[a+32768>>2]=b;c[a+98304>>2]=b;c[a+163840>>2]=b;d=b+1024|0;c[a+32772>>2]=d;c[a+98308>>2]=d;c[a+163844>>2]=d;d=c[3529638]|0;c[a+36864>>2]=d;c[a+102400>>2]=d;c[a+167936>>2]=d;b=d+1024|0;c[a+36868>>2]=b;c[a+102404>>2]=b;c[a+167940>>2]=b;b=d+2048|0;c[a+36872>>2]=b;c[a+102408>>2]=b;c[a+167944>>2]=b;b=d+3072|0;c[a+36876>>2]=b;c[a+102412>>2]=b;c[a+167948>>2]=b;b=d+4096|0;c[a+36880>>2]=b;c[a+102416>>2]=b;c[a+167952>>2]=b;b=d+5120|0;c[a+36884>>2]=b;c[a+102420>>2]=b;c[a+167956>>2]=b;b=d+6144|0;c[a+36888>>2]=b;c[a+102424>>2]=b;c[a+167960>>2]=b;b=d+7168|0;c[a+36892>>2]=b;c[a+102428>>2]=b;c[a+167964>>2]=b;b=d+8192|0;c[a+36896>>2]=b;c[a+102432>>2]=b;c[a+167968>>2]=b;b=d+9216|0;c[a+36900>>2]=b;c[a+102436>>2]=b;c[a+167972>>2]=b;b=d+10240|0;c[a+36904>>2]=b;c[a+102440>>2]=b;c[a+167976>>2]=b;b=d+11264|0;c[a+36908>>2]=b;c[a+102444>>2]=b;c[a+167980>>2]=b;b=d+12288|0;c[a+36912>>2]=b;c[a+102448>>2]=b;c[a+167984>>2]=b;b=d+13312|0;c[a+36916>>2]=b;c[a+102452>>2]=b;c[a+167988>>2]=b;b=d+14336|0;c[a+36920>>2]=b;c[a+102456>>2]=b;c[a+167992>>2]=b;b=d+15360|0;c[a+36924>>2]=b;c[a+102460>>2]=b;c[a+167996>>2]=b;b=c[3529470]|0;d=a+40960|0;e=10485760;while(1){f=b+(e-10485760)|0;c[d>>2]=f;c[d+65536>>2]=f;c[d+131072>>2]=f;f=e+1024|0;if(f>>>0>10551295){break}else{d=d+4|0;e=f}}e=c[3529436]|0;d=a+43008|0;b=11010048;while(1){f=e+(b-11010048)|0;c[d>>2]=f;c[d+65536>>2]=f;c[d+131072>>2]=f;f=b+1024|0;if(f>>>0>11075583){break}else{d=d+4|0;b=f}}c[a+196728>>2]=662;c[a+196648>>2]=300;c[a+196688>>2]=2842;c[a+196608>>2]=1824;c[a+49152>>2]=1;c[a+114688>>2]=1;c[a+49156>>2]=1;c[a+114692>>2]=1;c[a+49160>>2]=1;c[a+114696>>2]=1;c[a+49164>>2]=1;c[a+114700>>2]=1;c[a+49168>>2]=1;c[a+114704>>2]=1;c[a+49172>>2]=1;c[a+114708>>2]=1;c[a+49176>>2]=1;c[a+114712>>2]=1;c[a+49180>>2]=1;c[a+114716>>2]=1;c[a+49184>>2]=1;c[a+114720>>2]=1;c[a+49188>>2]=1;c[a+114724>>2]=1;c[a+49192>>2]=1;c[a+114728>>2]=1;c[a+49196>>2]=1;c[a+114732>>2]=1;c[a+49200>>2]=1;c[a+114736>>2]=1;c[a+49204>>2]=1;c[a+114740>>2]=1;c[a+49208>>2]=1;c[a+114744>>2]=1;c[a+49212>>2]=1;c[a+114748>>2]=1;c[a+196692>>2]=286;c[a+196612>>2]=1084;c[a+196732>>2]=3428;c[a+196652>>2]=3130;a=c[3532592]|0;if((a|0)==0){g=c[2113054]|0;c[2113060]=g;c[2394]=-1;return}gGC(a|0,9104152,280)|0;g=c[2113054]|0;c[2113060]=g;c[2394]=-1;return}function d62(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0;fxU(0,425984);if((c[2394]|0)==0){a=c[2112932]|0}else{c[2394]=0;b=c[3532596]|0;c[2112932]=b;d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];a=b}b=c[2388160]|0;d=a|0;e=0;while(1){f=b+e|0;c[d>>2]=f;c[d+131072>>2]=f;f=e+1024|0;if(f>>>0>1048575){break}else{d=d+4|0;e=f}}e=c[2388286]|0;d=a+4096|0;b=1048576;while(1){f=e+(b-1048576)|0;c[d>>2]=f;c[d+65536>>2]=f;c[d+131072>>2]=f;f=b+1024|0;if(f>>>0>1114111){break}else{d=d+4|0;b=f}}b=e+65536|0;c[a+28672>>2]=b;c[a+94208>>2]=b;c[a+159744>>2]=b;b=c[2387204]|0;c[a+28676>>2]=b;c[a+94212>>2]=b;c[a+159748>>2]=b;d=b+1024|0;c[a+28680>>2]=d;c[a+94216>>2]=d;c[a+159752>>2]=d;d=b+2048|0;c[a+28684>>2]=d;c[a+94220>>2]=d;c[a+159756>>2]=d;d=c[3531132]|0;b=a+28688|0;f=7344128;while(1){g=d+(f-7344128)|0;c[b>>2]=g;c[b+65536>>2]=g;c[b+131072>>2]=g;g=f+1024|0;if(g>>>0>7405567){break}else{b=b+4|0;f=g}}f=c[3529470]|0;b=a+32768|0;d=8388608;while(1){g=f+(d-8388608)|0;c[b>>2]=g;c[b+65536>>2]=g;c[b+131072>>2]=g;g=d+1024|0;if(g>>>0>8454143){break}else{b=b+4|0;d=g}}d=c[3529436]|0;b=a+34816|0;f=8912896;while(1){g=d+(f-8912896)|0;c[b>>2]=g;c[b+65536>>2]=g;c[b+131072>>2]=g;g=f+1024|0;if(g>>>0>8978431){break}else{b=b+4|0;f=g}}f=c[3529656]|0;c[a+40960>>2]=f;c[a+106496>>2]=f;c[a+172032>>2]=f;b=f+1024|0;c[a+40964>>2]=b;c[a+106500>>2]=b;c[a+172036>>2]=b;c[a+108544>>2]=e+131072;e=c[3529638]|0;b=a+45056|0;f=11534336;while(1){d=e+(f-11534336)|0;c[b>>2]=d;c[b+65536>>2]=d;c[b+131072>>2]=d;d=f+1024|0;if(d>>>0>11616255){break}else{b=b+4|0;f=d}}c[a+196728>>2]=324;c[a+196648>>2]=510;c[a+196688>>2]=2842;c[a+196608>>2]=1824;c[a+49152>>2]=1;c[a+114688>>2]=1;c[a+49156>>2]=1;c[a+114692>>2]=1;c[a+49160>>2]=1;c[a+114696>>2]=1;c[a+49164>>2]=1;c[a+114700>>2]=1;c[a+49168>>2]=1;c[a+114704>>2]=1;c[a+49172>>2]=1;c[a+114708>>2]=1;c[a+49176>>2]=1;c[a+114712>>2]=1;c[a+49180>>2]=1;c[a+114716>>2]=1;c[a+49184>>2]=1;c[a+114720>>2]=1;c[a+49188>>2]=1;c[a+114724>>2]=1;c[a+49192>>2]=1;c[a+114728>>2]=1;c[a+49196>>2]=1;c[a+114732>>2]=1;c[a+49200>>2]=1;c[a+114736>>2]=1;c[a+49204>>2]=1;c[a+114740>>2]=1;c[a+49208>>2]=1;c[a+114744>>2]=1;c[a+49212>>2]=1;c[a+114748>>2]=1;c[a+196692>>2]=286;c[a+196612>>2]=1084;c[a+196732>>2]=3428;c[a+196652>>2]=3130;a=c[3532592]|0;if((a|0)==0){h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return}gGC(a|0,9104152,280)|0;h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return}function d63(){var a=0,b=0,d=0,e=0,f=0,g=0;fxU(0,425984);if((c[2394]|0)==0){a=c[2112932]|0}else{c[2394]=0;b=c[3532596]|0;c[2112932]=b;d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];a=b}b=c[2388160]|0;d=a|0;e=0;while(1){f=b+e|0;c[d>>2]=f;c[d+131072>>2]=f;f=e+1024|0;if(f>>>0>786431){break}else{d=d+4|0;e=f}}e=c[2387204]|0;c[a+28672>>2]=e;c[a+94208>>2]=e;c[a+159744>>2]=e;e=c[3529470]|0;c[a+36864>>2]=e;c[a+102400>>2]=e;c[a+167936>>2]=e;d=e+1024|0;c[a+36868>>2]=d;c[a+102404>>2]=d;c[a+167940>>2]=d;d=e+2048|0;c[a+36872>>2]=d;c[a+102408>>2]=d;c[a+167944>>2]=d;d=e+3072|0;c[a+36876>>2]=d;c[a+102412>>2]=d;c[a+167948>>2]=d;d=e+4096|0;c[a+36880>>2]=d;c[a+102416>>2]=d;c[a+167952>>2]=d;d=e+5120|0;c[a+36884>>2]=d;c[a+102420>>2]=d;c[a+167956>>2]=d;d=e+6144|0;c[a+36888>>2]=d;c[a+102424>>2]=d;c[a+167960>>2]=d;d=e+7168|0;c[a+36892>>2]=d;c[a+102428>>2]=d;c[a+167964>>2]=d;d=e+8192|0;c[a+36896>>2]=d;c[a+102432>>2]=d;c[a+167968>>2]=d;d=e+9216|0;c[a+36900>>2]=d;c[a+102436>>2]=d;c[a+167972>>2]=d;d=e+10240|0;c[a+36904>>2]=d;c[a+102440>>2]=d;c[a+167976>>2]=d;d=e+11264|0;c[a+36908>>2]=d;c[a+102444>>2]=d;c[a+167980>>2]=d;d=e+12288|0;c[a+36912>>2]=d;c[a+102448>>2]=d;c[a+167984>>2]=d;d=e+13312|0;c[a+36916>>2]=d;c[a+102452>>2]=d;c[a+167988>>2]=d;d=e+14336|0;c[a+36920>>2]=d;c[a+102456>>2]=d;c[a+167992>>2]=d;d=e+15360|0;c[a+36924>>2]=d;c[a+102460>>2]=d;c[a+167996>>2]=d;d=c[3529656]|0;c[a+53248>>2]=d;c[a+118784>>2]=d;c[a+184320>>2]=d;e=d+1024|0;c[a+53252>>2]=e;c[a+118788>>2]=e;c[a+184324>>2]=e;e=c[3529638]|0;c[a+57344>>2]=e;c[a+122880>>2]=e;c[a+188416>>2]=e;d=e+1024|0;c[a+57348>>2]=d;c[a+122884>>2]=d;c[a+188420>>2]=d;d=e+2048|0;c[a+57352>>2]=d;c[a+122888>>2]=d;c[a+188424>>2]=d;d=e+3072|0;c[a+57356>>2]=d;c[a+122892>>2]=d;c[a+188428>>2]=d;d=e+4096|0;c[a+57360>>2]=d;c[a+122896>>2]=d;c[a+188432>>2]=d;d=e+5120|0;c[a+57364>>2]=d;c[a+122900>>2]=d;c[a+188436>>2]=d;d=e+6144|0;c[a+57368>>2]=d;c[a+122904>>2]=d;c[a+188440>>2]=d;d=e+7168|0;c[a+57372>>2]=d;c[a+122908>>2]=d;c[a+188444>>2]=d;d=e+8192|0;c[a+57376>>2]=d;c[a+122912>>2]=d;c[a+188448>>2]=d;d=e+9216|0;c[a+57380>>2]=d;c[a+122916>>2]=d;c[a+188452>>2]=d;d=e+10240|0;c[a+57384>>2]=d;c[a+122920>>2]=d;c[a+188456>>2]=d;d=e+11264|0;c[a+57388>>2]=d;c[a+122924>>2]=d;c[a+188460>>2]=d;d=e+12288|0;c[a+57392>>2]=d;c[a+122928>>2]=d;c[a+188464>>2]=d;d=e+13312|0;c[a+57396>>2]=d;c[a+122932>>2]=d;c[a+188468>>2]=d;d=e+14336|0;c[a+57400>>2]=d;c[a+122936>>2]=d;c[a+188472>>2]=d;d=e+15360|0;c[a+57404>>2]=d;c[a+122940>>2]=d;c[a+188476>>2]=d;d=c[2388286]|0;e=a+61440|0;b=15728640;while(1){f=d+(b-15728640)|0;c[e>>2]=f;c[e+65536>>2]=f;c[e+131072>>2]=f;f=b+1024|0;if(f>>>0>15794175){break}else{e=e+4|0;b=f}}b=d+65536|0;c[a+65472>>2]=b;c[a+131008>>2]=b;c[a+196544>>2]=b;b=d+66560|0;c[a+65476>>2]=b;c[a+131012>>2]=b;c[a+196548>>2]=b;b=d+67584|0;c[a+65480>>2]=b;c[a+131016>>2]=b;c[a+196552>>2]=b;b=d+68608|0;c[a+65484>>2]=b;c[a+131020>>2]=b;c[a+196556>>2]=b;b=d+69632|0;c[a+65488>>2]=b;c[a+131024>>2]=b;c[a+196560>>2]=b;b=d+70656|0;c[a+65492>>2]=b;c[a+131028>>2]=b;c[a+196564>>2]=b;b=d+71680|0;c[a+65496>>2]=b;c[a+131032>>2]=b;c[a+196568>>2]=b;b=d+72704|0;c[a+65500>>2]=b;c[a+131036>>2]=b;c[a+196572>>2]=b;b=d+73728|0;c[a+65504>>2]=b;c[a+131040>>2]=b;c[a+196576>>2]=b;b=d+74752|0;c[a+65508>>2]=b;c[a+131044>>2]=b;c[a+196580>>2]=b;b=d+75776|0;c[a+65512>>2]=b;c[a+131048>>2]=b;c[a+196584>>2]=b;b=d+76800|0;c[a+65516>>2]=b;c[a+131052>>2]=b;c[a+196588>>2]=b;b=d+77824|0;c[a+65520>>2]=b;c[a+131056>>2]=b;c[a+196592>>2]=b;b=d+78848|0;c[a+65524>>2]=b;c[a+131060>>2]=b;c[a+196596>>2]=b;b=d+79872|0;c[a+65528>>2]=b;c[a+131064>>2]=b;c[a+196600>>2]=b;b=d+80896|0;c[a+65532>>2]=b;c[a+131068>>2]=b;c[a+196604>>2]=b;c[a+196728>>2]=2232;c[a+196648>>2]=2468;c[a+196688>>2]=3540;c[a+196608>>2]=1234;c[a+4096>>2]=1;c[a+69632>>2]=1;c[a+4100>>2]=1;c[a+69636>>2]=1;c[a+4104>>2]=1;c[a+69640>>2]=1;c[a+4108>>2]=1;c[a+69644>>2]=1;c[a+4112>>2]=1;c[a+69648>>2]=1;c[a+4116>>2]=1;c[a+69652>>2]=1;c[a+4120>>2]=1;c[a+69656>>2]=1;c[a+4124>>2]=1;c[a+69660>>2]=1;c[a+4128>>2]=1;c[a+69664>>2]=1;c[a+4132>>2]=1;c[a+69668>>2]=1;c[a+4136>>2]=1;c[a+69672>>2]=1;c[a+4140>>2]=1;c[a+69676>>2]=1;c[a+4144>>2]=1;c[a+69680>>2]=1;c[a+4148>>2]=1;c[a+69684>>2]=1;c[a+4152>>2]=1;c[a+69688>>2]=1;c[a+4156>>2]=1;c[a+69692>>2]=1;c[a+196692>>2]=286;c[a+196612>>2]=1084;c[a+196732>>2]=3428;c[a+196652>>2]=3130;a=c[3532592]|0;if((a|0)==0){g=c[2113054]|0;c[2113060]=g;c[2394]=-1;return}gGC(a|0,9104152,280)|0;g=c[2113054]|0;c[2113060]=g;c[2394]=-1;return}function d64(){var a=0,b=0,d=0,e=0,f=0;a=((c[2405120]|0)*100|0|0)/(c[1623868]|0)|0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];b=c[3532592]|0;if((b|0)!=0){gGC(9104152,b|0,280)|0}c[2113054]=c[2113060]}b=(a|0)/10|0;a=0;do{c[2113056]=b;d=RG(b)|0;c[2113054]=(c[2113054]|0)+d;c[2276108]=-1;c[2113056]=-1;do{if((a|0)==9|(a|0)==4){d=c[2406742]>>(((a|0)/5|0)<<3&8);if((d&128|0)!=0){break}e=d&255;c[8452200+(c[2394]<<2)>>2]=e|8192;d=c[2276080]|0;f=e<<8;c[2276080]=f;if((d|0)!=1792&(e|0)==7){RH(7);break}if(f>>>0<=(c[2276079]|0)>>>0){break}RH(e)}}while(0);a=a+1|0;}while((a|0)<10);a=c[2394]|0;b=c[14130368+(a<<2)>>2]|0;if((b|0)!=0){gGC(b|0,9104152,280)|0}c[8452240+(a<<2)>>2]=c[2113054];c[2394]=-1;if((c[2112964]|0)==0){return}TV();return}function d65(d){d=d|0;var f=0;switch(d|0){case 12582912:{f=(e[4775252]|0)>>>8&255;break};case 12582914:{f=-1;break};case 12582949:{f=c[2113156]&255;break};case 12582915:{f=b[4775253]&255;break};case 12582917:{f=a[9635112]|0;break};case 12582913:{f=b[4775252]&255;break};case 12582957:{f=c[(c[3531464]|0)+4240>>2]&255;break};case 12582916:{f=a[9635113]|0;break};case 12582961:{f=c[2113157]&255;break};default:{f=0}}return f|0}function d66(b,d){b=b|0;d=d|0;var e=0;if((b|0)==12582949){Uv(0,d);return}else if((b|0)==12582961){Uv(1,d);return}else if((b|0)==12582957){e=c[2113304]|0;a[14168504+e|0]=d;mv(0,e,d&255);return}else if((b|0)==12582953){c[2113304]=d&255;return}else{return}}function d67(a,d){a=a|0;d=d|0;var e=0;if((a&-16384|0)==6291456){b[(c[2387202]|0)+(a&16382)>>1]=d;c[(c[3530016]|0)+((a>>>2&4095)<<2)>>2]=((d&65535)>>>10<<3&248)<<8|((d&255)<<3&255)>>>3|(((d&65535)>>>5<<3&255|(d&65535)>>>7&4)&255)<<3&2016;return}e=a-12583180|0;if(e>>>0>=24){return}b[(c[3529562]|0)+(e>>>1<<1)>>1]=d;return}function d68(a,b){a=a|0;b=b|0;if((a&-16384|0)!=6291456){return}c[(c[2387202]|0)+(a&16380)>>2]=b;c[(c[3530016]|0)+((a>>>2&4095)<<2)>>2]=b>>>26<<11&63488|b>>>16&31|((b>>>21<<3&255|b>>>23&4)&255)<<3&2016;return}function d69(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2279052+(b*112|0)>>2];c[a+104>>2]=c[2279056+(b*112|0)>>2];c[a+108>>2]=c[2279060+(b*112|0)>>2];d=0;return d|0}function d7a(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=2278952+(b*112|0);e=0;return e|0}function d7b(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6928e3+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function d7c(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>34){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7436792+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function d7d(){var b=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0;b=i;i=i+2040|0;e=b|0;f=b+112|0;g=b+120|0;j=b+232|0;k=b+240|0;l=b+352|0;m=b+360|0;n=b+472|0;o=b+480|0;p=b+592|0;q=b+600|0;r=b+712|0;s=b+720|0;t=b+832|0;u=b+840|0;v=b+952|0;w=b+960|0;x=b+1072|0;y=b+1080|0;z=b+1192|0;A=b+1200|0;B=b+1312|0;C=b+1320|0;D=b+1432|0;E=b+1440|0;F=b+1552|0;G=b+1560|0;H=b+1672|0;I=b+1680|0;J=b+1792|0;K=b+1800|0;L=b+1912|0;M=b+1920|0;N=b+2032|0;O=0;while(1){if((O|0)>=1024){break}P=9638528+(O<<2)|0;if((c[P>>2]|0)==0){Q=44519;break}else{O=O+1|0}}do{if((Q|0)==44519){O=gGq(33554432)|0;c[P>>2]=O;if((O|0)==0){break}gGz(O|0,0,33554432);c[2387818]=O;O=a[6346592]|0?10485760:6291456;R=0;while(1){if((R|0)>=1024){S=1;Q=44760;break}T=9638528+(R<<2)|0;if((c[T>>2]|0)==0){break}else{R=R+1|0}}if((Q|0)==44760){i=b;return S|0}R=gGq(O)|0;c[T>>2]=R;if((R|0)==0){S=1;i=b;return S|0}gGz(R|0,0,O|0);L58677:do{if(a[6346592]|0){if((c[3542200]|0)==0){S=1;i=b;return S|0}U=M+108|0;c[U>>2]=0;V=M+100|0;c[V>>2]=0;W=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[W&16383](M,2)|0;do{if((c[U>>2]|0)!=0){W=c[V>>2]|0;c[N>>2]=9534384;X=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[X&16383](N,2,0)|0;if((W|0)<1){S=1;i=b;return S|0}if((gzL(R,0,2)|0)==0){break}else{S=1}i=b;return S|0}}while(0);V=R+2097152|0;if((c[3542200]|0)==0){S=1;i=b;return S|0}U=K+108|0;c[U>>2]=0;W=K+100|0;c[W>>2]=0;X=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[X&16383](K,3)|0;do{if((c[U>>2]|0)!=0){X=c[W>>2]|0;c[L>>2]=9534384;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Y&16383](L,3,0)|0;if((X|0)<1){S=1;i=b;return S|0}if((gzL(V,0,3)|0)==0){break}else{S=1}i=b;return S|0}}while(0);W=R+4194304|0;if((c[3542200]|0)==0){S=1;i=b;return S|0}U=I+108|0;c[U>>2]=0;X=I+100|0;c[X>>2]=0;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Y&16383](I,4)|0;do{if((c[U>>2]|0)==0){Z=0}else{Y=c[X>>2]|0;c[J>>2]=9534384;_=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[_&16383](J,4,0)|0;if((Y|0)<1){S=1;i=b;return S|0}if((gzL(W,0,4)|0)==0){Z=0;break}else{S=1}i=b;return S|0}}while(0);do{X=R+Z|0;a[X]=~a[X];Z=Z+1|0;}while((Z|0)<6291456);X=c[2387818]|0;U=0;do{Y=U<<8;gGz(X+Y|0,0,256);_=U<<9;$=0;do{aa=1<<5-$;ab=(c[602632+($<<2)>>2]|0)+_|0;ac=0;do{ad=ab+(c[611840+(ac<<2)>>2]|0)|0;ae=(ac<<4)+Y|0;af=0;do{ah=ad+(c[6669352+(af<<2)>>2]|0)|0;if((d[R+((ah|0)/8|0)|0]&128>>>((ah&7)>>>0)|0)!=0){ah=X+(ae+af)|0;a[ah]=(d[ah]|aa)&255}af=af+1|0;}while((af|0)<16);ac=ac+1|0;}while((ac|0)<16);$=$+1|0;}while(($|0)<6);U=U+1|0;}while((U|0)<32768);U=R+6291456|0;if((c[3542200]|0)==0){S=1;i=b;return S|0}X=G+108|0;c[X>>2]=0;$=G+100|0;c[$>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](G,2)|0;do{if((c[X>>2]|0)!=0){Y=c[$>>2]|0;c[H>>2]=9534384;_=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[_&16383](H,2,0)|0;if((Y|0)<1){S=1;i=b;return S|0}if((gzL(U,0,2)|0)==0){break}else{S=1}i=b;return S|0}}while(0);$=R+8388608|0;gGC(R|0,$|0,2097152)|0;if((c[3542200]|0)==0){S=1;i=b;return S|0}X=E+108|0;c[X>>2]=0;Y=E+100|0;c[Y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](E,3)|0;do{if((c[X>>2]|0)!=0){_=c[Y>>2]|0;c[F>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](F,3,0)|0;if((_|0)<1){S=1;i=b;return S|0}if((gzL(U,0,3)|0)==0){break}else{S=1}i=b;return S|0}}while(0);gGC(V|0,$|0,2097152)|0;if((c[3542200]|0)==0){S=1;i=b;return S|0}Y=C+108|0;c[Y>>2]=0;X=C+100|0;c[X>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](C,4)|0;do{if((c[Y>>2]|0)!=0){_=c[X>>2]|0;c[D>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](D,4,0)|0;if((_|0)<1){S=1;i=b;return S|0}if((gzL(U,0,4)|0)==0){break}else{S=1}i=b;return S|0}}while(0);gGC(W|0,$|0,2097152)|0;U=0;do{X=R+U|0;a[X]=~a[X];U=U+1|0;}while((U|0)<6291456);U=c[2387818]|0;$=0;do{X=($<<8)+8388608|0;gGz(U+X|0,0,256);Y=$<<9;_=0;do{ac=1<<5-_;aa=(c[602632+(_<<2)>>2]|0)+Y|0;ab=0;do{af=aa+(c[611840+(ab<<2)>>2]|0)|0;ae=X+(ab<<4)|0;ad=0;do{ah=af+(c[6669352+(ad<<2)>>2]|0)|0;if((d[R+((ah|0)/8|0)|0]&128>>>((ah&7)>>>0)|0)!=0){ah=U+(ae+ad)|0;a[ah]=(d[ah]|ac)&255}ad=ad+1|0;}while((ad|0)<16);ab=ab+1|0;}while((ab|0)<16);_=_+1|0;}while((_|0)<6);$=$+1|0;}while(($|0)<32768);if((c[3542200]|0)==0){S=1;i=b;return S|0}$=A+108|0;c[$>>2]=0;U=A+100|0;c[U>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](A,5)|0;do{if((c[$>>2]|0)!=0){_=c[U>>2]|0;c[B>>2]=9534384;X=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[X&16383](B,5,0)|0;if((_|0)<1){S=1;i=b;return S|0}if((gzL(R,0,5)|0)==0){break}else{S=1}i=b;return S|0}}while(0);if((c[3542200]|0)==0){S=1;i=b;return S|0}U=y+108|0;c[U>>2]=0;$=y+100|0;c[$>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](y,6)|0;do{if((c[U>>2]|0)!=0){_=c[$>>2]|0;c[z>>2]=9534384;X=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[X&16383](z,6,0)|0;if((_|0)<1){S=1;i=b;return S|0}if((gzL(V,0,6)|0)==0){break}else{S=1}i=b;return S|0}}while(0);if((c[3542200]|0)==0){S=1;i=b;return S|0}$=w+108|0;c[$>>2]=0;U=w+100|0;c[U>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](w,7)|0;do{if((c[$>>2]|0)==0){ai=0}else{_=c[U>>2]|0;c[x>>2]=9534384;X=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[X&16383](x,7,0)|0;if((_|0)<1){S=1;i=b;return S|0}if((gzL(W,0,7)|0)==0){ai=0;break}else{S=1}i=b;return S|0}}while(0);do{U=R+ai|0;a[U]=~a[U];ai=ai+1|0;}while((ai|0)<6291456);U=c[2387818]|0;$=0;do{_=($<<8)+16777216|0;gGz(U+_|0,0,256);X=$<<9;Y=0;do{ab=1<<5-Y;ac=(c[602632+(Y<<2)>>2]|0)+X|0;aa=0;do{ad=ac+(c[611840+(aa<<2)>>2]|0)|0;ae=_+(aa<<4)|0;af=0;do{ah=ad+(c[6669352+(af<<2)>>2]|0)|0;if((d[R+((ah|0)/8|0)|0]&128>>>((ah&7)>>>0)|0)!=0){ah=U+(ae+af)|0;a[ah]=(d[ah]|ab)&255}af=af+1|0;}while((af|0)<16);aa=aa+1|0;}while((aa|0)<16);Y=Y+1|0;}while((Y|0)<6);$=$+1|0;}while(($|0)<32768);if((c[3542200]|0)==0){S=1;i=b;return S|0}$=u+108|0;c[$>>2]=0;U=u+100|0;c[U>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](u,8)|0;do{if((c[$>>2]|0)!=0){Y=c[U>>2]|0;c[v>>2]=9534384;_=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[_&16383](v,8,0)|0;if((Y|0)<1){S=1;i=b;return S|0}if((gzL(R,0,8)|0)==0){break}else{S=1}i=b;return S|0}}while(0);if((c[3542200]|0)==0){S=1;i=b;return S|0}U=m+108|0;c[U>>2]=0;$=m+100|0;c[$>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,9)|0;do{if((c[U>>2]|0)!=0){Y=c[$>>2]|0;c[n>>2]=9534384;_=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[_&16383](n,9,0)|0;if((Y|0)<1){S=1;i=b;return S|0}if((gzL(V,0,9)|0)==0){break}else{S=1}i=b;return S|0}}while(0);if((c[3542200]|0)==0){S=1;i=b;return S|0}V=k+108|0;c[V>>2]=0;$=k+100|0;c[$>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,10)|0;do{if((c[V>>2]|0)==0){aj=0}else{U=c[$>>2]|0;c[l>>2]=9534384;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Y&16383](l,10,0)|0;if((U|0)<1){S=1;i=b;return S|0}if((gzL(W,0,10)|0)==0){aj=0;break}else{S=1}i=b;return S|0}}while(0);do{W=R+aj|0;a[W]=~a[W];aj=aj+1|0;}while((aj|0)<6291456);W=c[2387818]|0;$=0;while(1){V=($<<8)+25165824|0;gGz(W+V|0,0,256);U=$<<9;Y=0;do{_=1<<5-Y;X=(c[602632+(Y<<2)>>2]|0)+U|0;aa=0;do{ab=X+(c[611840+(aa<<2)>>2]|0)|0;ac=V+(aa<<4)|0;af=0;do{ae=ab+(c[6669352+(af<<2)>>2]|0)|0;if((d[R+((ae|0)/8|0)|0]&128>>>((ae&7)>>>0)|0)!=0){ae=W+(ac+af)|0;a[ae]=(d[ae]|_)&255}af=af+1|0;}while((af|0)<16);aa=aa+1|0;}while((aa|0)<16);Y=Y+1|0;}while((Y|0)<6);Y=$+1|0;if((Y|0)<32768){$=Y}else{ak=0;break}}}else{$=R+2097152|0;W=R+4194304|0;Y=s+108|0;V=s+100|0;U=q+108|0;aa=q+100|0;_=o+108|0;X=o+100|0;af=0;while(1){ac=af*3|0;ab=ac+2|0;if((c[3542200]|0)==0){S=1;Q=44754;break}c[Y>>2]=0;c[V>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](s,ab)|0;if((c[Y>>2]|0)!=0){ae=c[V>>2]|0;c[t>>2]=9534384;ad=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ad&16383](t,ab,0)|0;if((ae|0)<1){S=1;Q=44755;break}if((gzL(R,0,ab)|0)!=0){S=1;Q=44756;break}}ab=ac+3|0;if((c[3542200]|0)==0){S=1;Q=44725;break}c[U>>2]=0;c[aa>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](q,ab)|0;if((c[U>>2]|0)!=0){ae=c[aa>>2]|0;c[r>>2]=9534384;ad=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ad&16383](r,ab,0)|0;if((ae|0)<1){S=1;Q=44726;break}if((gzL($,0,ab)|0)!=0){S=1;Q=44709;break}}ab=ac+4|0;if((c[3542200]|0)==0){S=1;Q=44710;break}c[_>>2]=0;c[X>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](o,ab)|0;if((c[_>>2]|0)==0){al=0}else{ac=c[X>>2]|0;c[p>>2]=9534384;ae=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ae&16383](p,ab,0)|0;if((ac|0)<1){S=1;Q=44711;break}if((gzL(W,0,ab)|0)==0){al=0}else{S=1;Q=44712;break}}do{ab=R+al|0;a[ab]=~a[ab];al=al+1|0;}while((al|0)<6291456);ab=c[2387818]|0;ac=af<<23;ae=0;do{ad=(ae<<8)+ac|0;gGz(ab+ad|0,0,256);ah=ae<<9;am=0;do{an=1<<5-am;ao=(c[602632+(am<<2)>>2]|0)+ah|0;ap=0;do{aq=ao+(c[611840+(ap<<2)>>2]|0)|0;ar=ad+(ap<<4)|0;as=0;do{at=aq+(c[6669352+(as<<2)>>2]|0)|0;if((d[R+((at|0)/8|0)|0]&128>>>((at&7)>>>0)|0)!=0){at=ab+(ar+as)|0;a[at]=(d[at]|an)&255}as=as+1|0;}while((as|0)<16);ap=ap+1|0;}while((ap|0)<16);am=am+1|0;}while((am|0)<6);ae=ae+1|0;}while((ae|0)<32768);ae=af+1|0;if((ae|0)<4){af=ae}else{ak=0;break L58677}}if((Q|0)==44709){i=b;return S|0}else if((Q|0)==44710){i=b;return S|0}else if((Q|0)==44711){i=b;return S|0}else if((Q|0)==44712){i=b;return S|0}else if((Q|0)==44725){i=b;return S|0}else if((Q|0)==44726){i=b;return S|0}else if((Q|0)==44754){i=b;return S|0}else if((Q|0)==44755){i=b;return S|0}else if((Q|0)==44756){i=b;return S|0}}}while(0);while(1){if((ak|0)>=1024){au=0;break}av=9638528+(ak<<2)|0;if((c[av>>2]|0)==(R|0)){Q=44627;break}else{ak=ak+1|0}}if((Q|0)==44627){gGr(R);c[av>>2]=0;au=0}while(1){if((au|0)>=1024){break}aw=9638528+(au<<2)|0;if((c[aw>>2]|0)==0){Q=44630;break}else{au=au+1|0}}do{if((Q|0)==44630){R=gGq(131072)|0;c[aw>>2]=R;if((R|0)==0){break}c[3527246]=R;gGz(R|0,0,131072);O=c[2387818]|0;af=0;W=0;while(1){if((a[O+af|0]|0)==0){ax=W}else{X=R+(af>>8)|0;a[X]=a[X]|1;ax=W+1|0}do{if((af&255|0)==255){if((ax|0)!=256){ay=0;break}X=R+(af>>8)|0;a[X]=a[X]|2;ay=0}else{ay=ax}}while(0);X=af+1|0;if((X|0)<33554432){af=X;W=ay}else{break}}W=c[2414968]|0;c[2388158]=W;af=W+2097152|0;c[3541206]=af;c[3529762]=af;c[3529716]=W+2621440;c[3530016]=W+2883584;af=W+2899972|0;c[2414672]=af;c[2386462]=af;c[2387202]=W+2904068;c[2386216]=W+2920452;c[2388284]=W+2969604;c[3529562]=W+3100676;af=W+3100740|0;c[2411672]=af;c[2414212]=af;W=af;af=0;while(1){if((af|0)>=1024){break}az=9638528+(af<<2)|0;if((c[az>>2]|0)==0){Q=44661;break}else{af=af+1|0}}do{if((Q|0)==44661){af=gGq(W)|0;c[az>>2]=af;if((af|0)==0){break}gGz(af|0,0,W|0);c[2414968]=af;gGz(af|0,0,W|0);c[2388158]=af;R=af+2097152|0;c[3541206]=R;c[3529762]=R;c[3529716]=af+2621440;c[3530016]=af+2883584;R=af+2899972|0;c[2414672]=R;c[2386462]=R;c[2387202]=af+2904068;c[2386216]=af+2920452;c[2388284]=af+2969604;c[3529562]=af+3100676;R=af+3100740|0;c[2411672]=R;c[2414212]=R;if((R6(af,0,2)|0)!=0){S=1;i=b;return S|0}if((R6((c[2388158]|0)+1|0,1,2)|0)!=0){S=1;i=b;return S|0}af=c[2388158]|0;R=0;do{O=af+(R|1)|0;X=a[O]|0;_=af+(R|2)|0;a[O]=a[_]|0;a[_]=X;R=R+4|0;}while((R|0)<2097152);R=c[3529762]|0;if((c[3542200]|0)==0){S=1;i=b;return S|0}af=g+108|0;c[af>>2]=0;X=g+100|0;c[X>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,14)|0;do{if((c[af>>2]|0)!=0){_=c[X>>2]|0;c[j>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](j,14,0)|0;if((_|0)<1){S=1;i=b;return S|0}if((gzL(R,0,14)|0)==0){break}else{S=1}i=b;return S|0}}while(0);R=c[3529716]|0;if((c[3542200]|0)==0){S=1;i=b;return S|0}X=e+108|0;c[X>>2]=0;af=e+100|0;c[af>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,15)|0;do{if((c[X>>2]|0)!=0){_=c[af>>2]|0;c[f>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](f,15,0)|0;if((_|0)<1){S=1;i=b;return S|0}if((gzL(R,0,15)|0)==0){break}else{S=1}i=b;return S|0}}while(0);fxU(0,110018592);if((c[2394]|0)==0){aA=c[2112932]|0}else{c[2394]=0;R=c[3532596]|0;c[2112932]=R;af=c[3532592]|0;if((af|0)!=0){gGC(9104152,af|0,280)|0}c[2113054]=c[2113060];aA=R}R=c[2388158]|0;af=aA|0;X=0;while(1){_=R+X|0;c[af>>2]=_;c[af+131072>>2]=_;_=X+1024|0;if(_>>>0>2097151){break}else{af=af+4|0;X=_}}X=c[2386462]|0;c[aA+16576>>2]=X;c[aA+82112>>2]=X;c[aA+147648>>2]=X;af=X+1024|0;c[aA+16580>>2]=af;c[aA+82116>>2]=af;c[aA+147652>>2]=af;af=X+2048|0;c[aA+16584>>2]=af;c[aA+82120>>2]=af;c[aA+147656>>2]=af;af=X+3072|0;c[aA+16588>>2]=af;c[aA+82124>>2]=af;c[aA+147660>>2]=af;af=c[2387202]|0;c[aA+24576>>2]=af;c[aA+155648>>2]=af;X=af+1024|0;c[aA+24580>>2]=X;c[aA+155652>>2]=X;X=af+2048|0;c[aA+24584>>2]=X;c[aA+155656>>2]=X;X=af+3072|0;c[aA+24588>>2]=X;c[aA+155660>>2]=X;X=af+4096|0;c[aA+24592>>2]=X;c[aA+155664>>2]=X;X=af+5120|0;c[aA+24596>>2]=X;c[aA+155668>>2]=X;X=af+6144|0;c[aA+24600>>2]=X;c[aA+155672>>2]=X;X=af+7168|0;c[aA+24604>>2]=X;c[aA+155676>>2]=X;X=af+8192|0;c[aA+24608>>2]=X;c[aA+155680>>2]=X;X=af+9216|0;c[aA+24612>>2]=X;c[aA+155684>>2]=X;X=af+10240|0;c[aA+24616>>2]=X;c[aA+155688>>2]=X;X=af+11264|0;c[aA+24620>>2]=X;c[aA+155692>>2]=X;X=af+12288|0;c[aA+24624>>2]=X;c[aA+155696>>2]=X;X=af+13312|0;c[aA+24628>>2]=X;c[aA+155700>>2]=X;X=af+14336|0;c[aA+24632>>2]=X;c[aA+155704>>2]=X;X=af+15360|0;c[aA+24636>>2]=X;c[aA+155708>>2]=X;X=c[2386216]|0;af=aA+32768|0;R=8388608;while(1){_=X+(R-8388608)|0;c[af>>2]=_;c[af+65536>>2]=_;c[af+131072>>2]=_;_=R+1024|0;if(_>>>0>8437759){break}else{af=af+4|0;R=_}}R=c[2388284]|0;af=aA+65024|0;X=16646144;while(1){_=R+(X-16646144)|0;c[af>>2]=_;c[af+65536>>2]=_;c[af+131072>>2]=_;_=X+1024|0;if(_>>>0>16777215){break}else{af=af+4|0;X=_}}c[aA+196648>>2]=780;c[aA+196728>>2]=3370;c[aA+196808>>2]=52;c[aA+196608>>2]=2836;X=c[3532592]|0;if((X|0)!=0){gGC(X|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;X=a[9680]|0;af=X?32e3:0;if(X){if(a[9624]|0){X=af*3|0;R=55930;while(1){if((R|0)>(X|0)){R=R>>1}else{aB=1222;aC=R;break}}}else{aB=2462;aC=af}c[2429380]=aC;c[3542124]=aB;mw(3579545,aC);R=gGq(262144)|0;c[2406684]=R;gGz(R|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(3579545,11025)}h[745421]=1.0;c[2436794]=1;h[745420]=1.0;c[2436792]=2;Ux(0,8e3,1);Ux(1,16e3,1);c[2407030]=115;c[2407068]=3;c[2407069]=115;c[2407107]=3;a[9624216]=0;R=c[2414672]|0;gGz(R|0,0,(c[2411672]|0)-R|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];R=c[3532592]|0;if((R|0)!=0){gGC(9104152,R|0,280)|0}c[2113054]=c[2113060]}RI();R=c[2394]|0;X=c[14130368+(R<<2)>>2]|0;if((X|0)!=0){gGC(X|0,9104152,280)|0}c[8452240+(R<<2)>>2]=c[2113054];c[2394]=-1;mx(0);c[2113156]=0;a[9628264]=0;c[2407033]=0;gGz(c[2430118]|0,0,16384);c[2407041]=4;gGz(c[2430119]|0,0,16384);c[2407049]=4;gGz(c[2430120]|0,0,16384);c[2407057]=4;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2113157]=0;a[9628420]=0;c[2407072]=0;gGz(c[2430122]|0,0,16384);c[2407080]=4;gGz(c[2430123]|0,0,16384);c[2407088]=4;gGz(c[2430124]|0,0,16384);c[2407096]=4;gGz(c[2430125]|0,0,16384);c[2407104]=4;R=c[3529762]|0;X=c[3529716]|0;c[3541190]=R;c[3541198]=R;c[3541194]=X;c[3541202]=X;c[3541191]=R+256;c[3541199]=R+65536;c[3541195]=X+256;c[3541203]=X+65536;c[3541192]=R+512;c[3541200]=R+131072;c[3541196]=X+512;c[3541204]=X+131072;c[3541193]=R+768;c[3541201]=R+196608;c[3541197]=X+768;c[3541205]=X+196608;X=c[642608+(c[2436]<<2)>>2]|0;R=c[X+128>>2]|0;if((c[X+52>>2]&4|0)==0){c[2113068]=R;_=c[X+132>>2]|0;c[2113070]=_;c[2443814]=R;c[2440436]=_;aD=R;aE=_}else{c[2113070]=R;_=c[X+132>>2]|0;c[2113068]=_;c[2440436]=R;c[2443814]=_;aD=_;aE=R}R=ag(aD<<1,aE)|0;_=gGq(R)|0;c[2112926]=_;if((_|0)==0){S=0;i=b;return S|0}gGz(_|0,0,R|0);S=0;i=b;return S|0}}while(0);c[2414968]=0;S=1;i=b;return S|0}}while(0);c[3527246]=0;S=1;i=b;return S|0}}while(0);c[2387818]=0;S=1;i=b;return S|0}function d7e(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;if((c[2392]|0)>=0){b=0;do{d=14130368+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}d=14130384+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}b=b+1|0;}while((b|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;b=c[3531464]|0;c[b+44344>>2]=0;c[b+44348>>2]=0;if((b|0)!=0){gGr(b);c[3531464]=0}b=c[2406684]|0;if((b|0)!=0){gGr(b);c[2406684]=0}Uw(0);Uw(1);c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}b=c[2414968]|0;d=0;while(1){if((d|0)>=1024){break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==(b|0)){g=44781;break}else{d=d+1|0}}if((g|0)==44781){gGr(b);c[f>>2]=0}c[2414968]=0;f=c[2387818]|0;b=0;while(1){if((b|0)>=1024){break}h=9638528+(b<<2)|0;if((c[h>>2]|0)==(f|0)){g=44785;break}else{b=b+1|0}}if((g|0)==44785){gGr(f);c[h>>2]=0}c[2387818]=0;h=c[3527246]|0;f=0;while(1){if((f|0)>=1024){g=44792;break}i=9638528+(f<<2)|0;if((c[i>>2]|0)==(h|0)){break}else{f=f+1|0}}if((g|0)==44792){c[3527246]=0;a[9547480]=0;a[6346592]=0;return 0}gGr(h);c[i>>2]=0;c[3527246]=0;a[9547480]=0;a[6346592]=0;return 0}function d7f(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;if((a[9624216]|0)!=0){a[9624216]=0;e=c[2414672]|0;gGz(e|0,0,(c[2411672]|0)-e|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060]}RI();e=c[2394]|0;f=c[14130368+(e<<2)>>2]|0;if((f|0)!=0){gGC(f|0,9104152,280)|0}c[8452240+(e<<2)>>2]=c[2113054];c[2394]=-1;mx(0);c[2113156]=0;a[9628264]=0;c[2407033]=0;gGz(c[2430118]|0,0,16384);c[2407041]=4;gGz(c[2430119]|0,0,16384);c[2407049]=4;gGz(c[2430120]|0,0,16384);c[2407057]=4;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2113157]=0;a[9628420]=0;c[2407072]=0;gGz(c[2430122]|0,0,16384);c[2407080]=4;gGz(c[2430123]|0,0,16384);c[2407088]=4;gGz(c[2430124]|0,0,16384);c[2407096]=4;gGz(c[2430125]|0,0,16384);c[2407104]=4;e=c[3529762]|0;f=c[3529716]|0;c[3541190]=e;c[3541198]=e;c[3541194]=f;c[3541202]=f;c[3541191]=e+256;c[3541199]=e+65536;c[3541195]=f+256;c[3541203]=f+65536;c[3541192]=e+512;c[3541200]=e+131072;c[3541196]=f+512;c[3541204]=f+131072;c[3541193]=e+768;c[3541201]=e+196608;c[3541197]=f+768;c[3541205]=f+196608}b[4775253]=-1;b[4775252]=-1;f=0;e=-1;g=-1;do{e=(d[9633480+f|0]<<f^e&65535)&65535;g=(d[9631336+f|0]<<f^g&65535)&65535;f=f+1|0;}while((f|0)<16);b[4775252]=e;b[4775253]=d[9631340]<<6^g;if((e&192)==0){g=e|192;b[4775252]=g;h=g}else{h=e}if((h&48)==0){e=h|48;b[4775252]=e;i=e}else{i=h}if((i&65535)<16384){h=i|-16384;b[4775252]=h;j=h}else{j=i}if((j&12288)==0){b[4775252]=j|12288}j=c[2438]|0;i=gGU(j,(j|0)<0|0?-1:0,16e6,0)|0;j=gGS(i,K,15360,0)|0;i=j;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];j=c[3532592]|0;if((j|0)!=0){gGC(9104152,j|0,280)|0}c[2113054]=c[2113060]}c[2113056]=i;j=RG(i)|0;c[2113054]=(c[2113054]|0)+j;c[2276108]=-1;c[2113056]=-1;j=c[2394]|0;c[8452200+(j<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0<1024){RH(4);k=c[2394]|0}else{k=j}j=c[14130368+(k<<2)>>2]|0;if((j|0)!=0){gGC(j|0,9104152,280)|0}c[8452240+(k<<2)>>2]=c[2113054];c[2394]=-1;k=c[2112964]|0;if((k|0)!=0){gg[c[3542124]&4095](k,a[9688]|0?534:0);k=c[2112964]|0;j=a[9688]|0?534:0;Uu(0,k,j);Uu(1,k,j)}if((c[2112968]|0)==0){return 0}d7g()|0;return 0}function d7g(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=c[2113308]|0;if((d[9547480]|0|0)!=(e|0)){f=c[2387202]|0;g=c[3530016]|0;h=0;do{i=b[f+(h<<1)>>1]|0;c[g+(((h|0)/2|0)<<2)>>2]=((i&65535)>>>10<<3&248)<<8|((i&255)<<3&255)>>>3|(((i&65535)>>>5<<3&255|(i&65535)>>>7&4)&255)<<3&2016;h=h+2|0;}while((h|0)<8192);c[g+16384>>2]=63519;a[9547480]=e&255}e=c[2113068]|0;g=c[2113070]|0;h=ag(g,e)|0;if((h|0)>0){f=c[2112926]|0;i=0;do{b[f+(i<<1)>>1]=1984;i=i+1|0;}while((i|0)<(h|0))}h=c[3529562]|0;i=c[2386216]|0;f=i;j=-50-(b[h>>1]&1023)|0;k=-16-(b[h+2>>1]&1023)|0;l=0;do{m=(l<<4&1008)+j|0;n=(l>>>2&1008)+k|0;o=(n|0)<-15?n+1024|0:n;n=(m|0)<-15?m+1024|0:m;if((n|0)<(e|0)&(o|0)<(g|0)){m=c[f+(l<<2)>>2]|0;p=m>>>16;d7m((m&65535)+98304|0,n,o,p&31,p&128)}l=l+1|0;}while((l|0)<4096);d7l(0);l=i+16384|0;f=-50-(b[h+10>>1]&1023)|0;k=-16-(b[h+20>>1]&1023)|0;j=0;do{p=(j<<4&1008)+f|0;o=(j>>>2&1008)+k|0;n=(o|0)<-15?o+1024|0:o;o=(p|0)<-15?p+1024|0:p;if((o|0)<(e|0)&(n|0)<(g|0)){p=c[l+(j<<2)>>2]|0;m=p>>>16;d7m((p&65535)+98304|0,o,n,m&31,m&128)}j=j+1|0;}while((j|0)<4096);d7l(4096);j=i+32768|0;i=-50-(b[h+8>>1]&1023)|0;l=-16-(b[h+4>>1]&1023)|0;h=0;do{k=(h<<4&1008)+i|0;f=(h>>>2&1008)+l|0;m=(f|0)<-15?f+1024|0:f;f=(k|0)<-15?k+1024|0:k;if((f|0)<(e|0)&(m|0)<(g|0)){k=c[j+(h<<2)>>2]|0;n=k>>>16;d7m((k&65535)+98304|0,f,m,n&31,n&128)}h=h+1|0;}while((h|0)<4096);R8(c[3530016]|0);return 0}function d7h(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=i;i=i+128|0;g=f|0;h=f+16|0;j=f+32|0;k=f+48|0;l=f+64|0;m=f+80|0;n=f+96|0;o=f+112|0;if((e|0)!=0){c[e>>2]=169602}if((b&32|0)!=0){gGz(o|0,0,12);e=c[2414672]|0;c[o>>2]=e;c[o+4>>2]=(c[2411672]|0)-e;c[o+12>>2]=162152;e=c[2076592]|0;gj[e&4095](o)|0}if((b&64|0)==0){i=f;return 0}o=l|0;gGz(k|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){e=l+9|0;l=j;p=j|0;q=j+4|0;r=j+12|0;s=k|0;t=k+4|0;u=k+12|0;v=0;do{gGC(o|0,614896,11)|0;a[e]=v+48&255;w=8452256+(v<<2)|0;gGz(l|0,0,12);c[p>>2]=w;c[q>>2]=4;c[r>>2]=164976;gj[c[2076592]&4095](j)|0;if((c[w>>2]|0)!=0){c[s>>2]=c[14130368+(v<<2)>>2];c[t>>2]=c[8452184+(v<<2)>>2];c[u>>2]=o;w=c[2076592]|0;gj[w&4095](k)|0}v=v+1|0;}while((v|0)<=(c[2392]|0))}gGz(h|0,0,12);c[h>>2]=8453216;c[h+4>>2]=4;c[h+12>>2]=107480;gj[c[2076592]&4095](h)|0;gGz(g|0,0,12);c[g>>2]=14168504;c[g+4>>2]=256;c[g+12>>2]=476464;gj[c[2076592]&4095](g)|0;if((b&2|0)!=0){b=0;do{mv(0,b,d[14168504+b|0]|0);b=b+1|0;}while((b|0)<256)}Ut(0);Ut(1);gGz(n|0,0,12);c[n>>2]=9550504;c[n+4>>2]=2;c[n+12>>2]=96856;gj[c[2076592]&4095](n)|0;gGz(m|0,0,12);c[m>>2]=9550506;c[m+4>>2]=2;c[m+12>>2]=75696;gj[c[2076592]&4095](m)|0;i=f;return 0}function d7i(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1391876+(b*112|0)>>2];c[a+104>>2]=c[1391880+(b*112|0)>>2];c[a+108>>2]=c[1391884+(b*112|0)>>2];d=0;return d|0}function d7j(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=1391776+(b*112|0);e=0;return e|0}function d7k(){a[6346592]=1;return d7d()|0}function d7l(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=c[2386462]|0;d=b;e=b+4096|0;b=d;while(1){if(b>>>0>=e>>>0){break}if((c[b+4>>2]&-16777216|0)==-16777216){break}else{b=b+8|0}}e=b-8|0;if(e>>>0<d>>>0){return}else{f=e}do{e=c[f>>2]|0;b=(e&511)-50|0;g=e>>>16;e=g-16|0;h=c[f+4>>2]|0;i=h>>>16;j=i<<1&65536|h&65535;f=f-8|0;L59181:do{if((i&4096|0)==(a|0)){if((g|0)==0|(e|0)>223){break}k=i&63;l=(h>>>24&15)+1|0;if((i&128|0)==0){m=0;while(1){n=(m<<4|8)+b|0;if((n+15|0)>>>0<=394){d7m(m+j|0,n,e,k,0)}m=m+1|0;if((m|0)>=(l|0)){break L59181}}}m=j+l|0;n=l;do{o=((n<<4)-16|8)+b|0;if((o+15|0)>>>0<=394){d7m(m-n|0,o,e,k,1)}n=n-1|0;}while((n|0)>0)}}while(0);}while(f>>>0>=d>>>0);return}function d7m(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;h=a[(c[3527246]|0)+b|0]|0;if(h<<24>>24==0){return}i=d>>>0<353&e>>>0<209;j=(h&2)==0;h=c[2112926]|0;k=c[2387818]|0;if((g|0)==0){if(i){if(j){SG(h,b,d,e,f,6,0,0,k);return}else{Sy(h,b,d,e,f,6,0,k);return}}else{if(j){SH(h,b,d,e,f,6,0,0,k);return}else{Sz(h,b,d,e,f,6,0,k);return}}}else{if(i){if(j){SI(h,b,d,e,f,6,0,0,k);return}else{SA(h,b,d,e,f,6,0,k);return}}else{if(j){SJ(h,b,d,e,f,6,0,0,k);return}else{SB(h,b,d,e,f,6,0,k);return}}}}function d7n(b){b=b|0;var c=0;if((b|0)==1048576){c=~a[9625738]}else if((b|0)==1048577){c=~a[9625736]}else if((b|0)==1048583){c=~a[9625739]}else if((b|0)==1048579){c=~a[9625737]}else{c=0}return c|0}function d7o(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;if((d|0)!=1048579){return}a[9758168]=e;e=c[2439330]|0;if((e|0)!=0){d=e;gGC(9706056,d|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;d=c[2433530]|0;c[2433530]=d+12;e=c[1836236]|0;f=c[9757320+(e<<2)>>2]|0;if((a[f+4188|0]|0)==0){g=gfc(100)|0;h=c[1836236]|0;i=g;j=(c[2433530]|0)+g|0;k=h;l=c[9757320+(h<<2)>>2]|0}else{i=100;j=d+112|0;k=e;l=f}c[2433530]=j;c[2444085]=(c[2444085]|0)+i;if((l|0)!=0){i=l;gGC(i|0,9706056,76)|0}c[9752472+(k<<2)>>2]=j;c[14113936+(k<<2)>>2]=c[2076596];c[9669104+(k<<2)>>2]=c[3541536];c[1836236]=-1;return}function d7p(a){a=a|0;var b=0;if((a|0)==1048580){b=(d[9657961]|0)<<8|(d[9657960]|0)}else if((a|0)==1048578){b=~(d[9625737]|0)}else{b=0}return b|0}function d7q(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;if((d|0)==786434){b[4887124]=e&511;return}else if((d|0)==786432){b[4887140]=e&511;return}else if((d|0)==1048576){b[4814252]=e;return}else if((d|0)==786438){b[4887172]=e&511;return}else if((d|0)==786436){b[4887196]=e&511;return}else if((d|0)==786444){b[4879940]=e&511;return}else if((d|0)==1048578){a[9758168]=e&255;e=c[2439330]|0;if((e|0)!=0){d=e;gGC(9706056,d|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;d=c[2433530]|0;c[2433530]=d+12;e=c[1836236]|0;f=c[9757320+(e<<2)>>2]|0;if((a[f+4188|0]|0)==0){g=gfc(100)|0;h=c[1836236]|0;i=g;j=(c[2433530]|0)+g|0;k=h;l=c[9757320+(h<<2)>>2]|0}else{i=100;j=d+112|0;k=e;l=f}c[2433530]=j;c[2444085]=(c[2444085]|0)+i;if((l|0)!=0){i=l;gGC(i|0,9706056,76)|0}c[9752472+(k<<2)>>2]=j;c[14113936+(k<<2)>>2]=c[2076596];c[9669104+(k<<2)>>2]=c[3541536];c[1836236]=-1;return}else{return}}function d7r(b){b=b|0;var c=0;switch(b|0){case 1572866:{c=a[9657961]|0;break};case 1572864:{c=(-17-(a[9625737]|0)&255)+(a[9657960]&16)&255;break};case 1572867:{c=~a[9625738];break};case 1572869:{c=~a[9625739];break};case 1572865:{c=~a[9625736];break};default:{c=0}}return c|0}function d7s(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;if((d|0)!=1310723){return}a[9758168]=e;e=c[2439330]|0;if((e|0)!=0){d=e;gGC(9706056,d|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;d=c[2433530]|0;c[2433530]=d+12;e=c[1836236]|0;f=c[9757320+(e<<2)>>2]|0;if((a[f+4188|0]|0)==0){g=gfc(100)|0;h=c[1836236]|0;i=g;j=(c[2433530]|0)+g|0;k=h;l=c[9757320+(h<<2)>>2]|0}else{i=100;j=d+112|0;k=e;l=f}c[2433530]=j;c[2444085]=(c[2444085]|0)+i;if((l|0)!=0){i=l;gGC(i|0,9706056,76)|0}c[9752472+(k<<2)>>2]=j;c[14113936+(k<<2)>>2]=c[2076596];c[9669104+(k<<2)>>2]=c[3541536];c[1836236]=-1;return}function d7t(b){b=b|0;var c=0;if((b|0)==1572864){c=(((239-(d[9625737]|0)&65535)+(a[9657960]&16)&65535)<<8|(d[9625736]|0))^255;return c|0}else if((b|0)==1572868){c=(d[9625739]|0|(d[9657962]|0)<<8)^255;return c|0}else if((b|0)==1572870){c=(d[9657963]|0)<<8|255;return c|0}else{c=0;return c|0}return 0}function d7u(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((d|0)==1310720){b[4814252]=e;return}else if((d|0)==786434){b[4887124]=e&511;return}else if((d|0)==786444){b[4879940]=e&511;return}else if((d|0)==786438){b[4887172]=e&511;return}else if((d|0)==786436){b[4887196]=e&511;return}else if((d|0)==1310722){a[9758168]=e&255;f=c[2439330]|0;if((f|0)!=0){g=f;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;g=c[2433530]|0;c[2433530]=g+12;f=c[1836236]|0;h=c[9757320+(f<<2)>>2]|0;if((a[h+4188|0]|0)==0){i=gfc(100)|0;j=c[1836236]|0;k=i;l=(c[2433530]|0)+i|0;m=j;n=c[9757320+(j<<2)>>2]|0}else{k=100;l=g+112|0;m=f;n=h}c[2433530]=l;c[2444085]=(c[2444085]|0)+k;if((n|0)!=0){k=n;gGC(k|0,9706056,76)|0}c[9752472+(m<<2)>>2]=l;c[14113936+(m<<2)>>2]=c[2076596];c[9669104+(m<<2)>>2]=c[3541536];c[1836236]=-1;return}else if((d|0)==786432){b[4887140]=e&511;return}else{return}}function d7v(b){b=b|0;var d=0,e=0;d=b&65535;if((d|0)==57344){e=a[9758168]|0}else if((d|0)==55296){e=c[2113156]&255}else if((d|0)==51201){e=c[(c[3531464]|0)+4240>>2]&255}else{e=0}return e|0}function d7w(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;e=b&65535;if((e|0)==55296){Uv(0,d);return}else if((e|0)==51200){c[2113304]=d&255;return}else if((e|0)==59392){b=d&1;a[14121008]=b;f=c[3541206]|0;g=(c[2433468]|0)+((b&255)<<18)|0;gGC(f|0,g|0,262144)|0;return}else if((e|0)==51201){e=c[2113304]|0;a[14168504+e|0]=d;mv(0,e,d&255);return}else{return}}function d7x(b){b=b|0;var c=0,d=0;L59374:do{switch(b|0){case 1572869:{c=~a[9625739];break};case 1572865:{c=~a[9625736];break};case 1572867:{c=~a[9625738];break};case 1572864:{d=a[9625737]|0;if((a[9545152]|0)==0){c=(-17-d&255)+(a[9657960]&16)&255;break L59374}else{c=(-25-d&255)+(a[9657960]&16)&255;break L59374}break};case 1572868:{c=a[9657962]|0;break};default:{c=0}}}while(0);return c|0}function d7y(a,c){a=a|0;c=c|0;if((a|0)==786445){b[4879940]=c&255;return}else if((a|0)==1310721){b[4814252]=c&255;return}else{return}}function d7z(b){b=b|0;var c=0,e=0;if((b|0)==1572864){c=d[9625737]|0;if((a[9545152]|0)==0){e=((239-c+(a[9657960]&16)<<8|d[9625736])^255)&65535;return e|0}else{e=((231-c+(a[9657960]&16)<<8|d[9625736])^255)&65535;return e|0}}else if((b|0)==1572866){e=(d[9625738]|d[9657961]<<8)^255;return e|0}else if((b|0)==1572870){e=d[9657963]<<8|255;return e|0}else if((b|0)==1572868){e=(d[9625739]|d[9657962]<<8)^255;return e|0}else{e=0;return e|0}return 0}function d7A(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((d|0)==1310720){b[4814252]=e;return}else if((d|0)==786436){b[4887196]=e&511;return}else if((d|0)==786434){b[4887124]=e&511;return}else if((d|0)==786432){b[4887140]=e&511;return}else if((d|0)==1310722){a[9758168]=e&255;f=c[2439330]|0;if((f|0)!=0){g=f;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;g=c[2433530]|0;c[2433530]=g+12;f=c[1836236]|0;h=c[9757320+(f<<2)>>2]|0;if((a[h+4188|0]|0)==0){i=gfc(100)|0;j=c[1836236]|0;k=i;l=(c[2433530]|0)+i|0;m=j;n=c[9757320+(j<<2)>>2]|0}else{k=100;l=g+112|0;m=f;n=h}c[2433530]=l;c[2444085]=(c[2444085]|0)+k;if((n|0)!=0){k=n;gGC(k|0,9706056,76)|0}c[9752472+(m<<2)>>2]=l;c[14113936+(m<<2)>>2]=c[2076596];c[9669104+(m<<2)>>2]=c[3541536];c[1836236]=-1;return}else if((d|0)==786438){b[4887172]=e&511;return}else if((d|0)==786444){b[4879940]=e&511;return}else{return}}function d7B(b){b=b|0;var d=0,e=0;d=b&65535;if((d|0)==34817){e=c[(c[3531464]|0)+4240>>2]&255}else if((d|0)==38912){e=c[2113156]&255}else if((d|0)==40960){e=a[9758168]|0}else{e=0}return e|0}function d7C(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((e|0)==34817){b=c[2113304]|0;a[14168504+b|0]=d;mv(0,b,d&255);return}else if((e|0)==34816){c[2113304]=d&255;return}else if((e|0)==38912){Uv(0,d);return}else{return}}function d7D(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7405284+(b*112|0)>>2];c[a+104>>2]=c[7405288+(b*112|0)>>2];c[a+108>>2]=c[7405292+(b*112|0)>>2];d=0;return d|0}function d7E(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=7405184+(b*112|0);e=0;return e|0}function d7F(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>31){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6927488+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function d7G(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>37){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7436336+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function d7H(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0;e=i;i=i+1680|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;B=e+1200|0;C=e+1312|0;D=e+1320|0;E=e+1432|0;F=e+1440|0;G=e+1552|0;H=e+1560|0;I=e+1672|0;c[2424]=5700;c[2426726]=0;c[2388028]=0;c[2385834]=524288;c[3541206]=589824;c[2433468]=851968;c[2405660]=1376256;c[2388048]=1376256;c[2385852]=1394688;c[2439940]=1396736;c[2443414]=1400832;c[2439958]=1404928;c[2439614]=1406976;c[2411670]=1408512;c[2405812]=1408512;c[3529574]=3505664;c[3530014]=8224256;J=0;while(1){if((J|0)>=1024){break}K=9638528+(J<<2)|0;if((c[K>>2]|0)==0){L=45140;break}else{J=J+1|0}}do{if((L|0)==45140){J=gGq(8230400)|0;c[K>>2]=J;if((J|0)==0){break}c[2426726]=J;gGz(J|0,0,8230400);c[2388028]=J;c[2385834]=J+524288;c[3541206]=J+589824;c[2433468]=J+851968;M=J+1376256|0;c[2405660]=M;c[2388048]=M;c[2385852]=J+1394688;c[2439940]=J+1396736;c[2443414]=J+1400832;c[2439958]=J+1404928;c[2439614]=J+1406976;M=J+1408512|0;c[2411670]=M;c[2405812]=M;c[3529574]=J+3505664;c[3530014]=J+8224256;c[2414210]=J+8230400;J=0;while(1){if((J|0)>=1024){N=0;break}O=9638528+(J<<2)|0;if((c[O>>2]|0)==0){L=45145;break}else{J=J+1|0}}do{if((L|0)==45145){J=gGq(4194304)|0;c[O>>2]=J;if((J|0)==0){N=0;break}gGz(J|0,0,4194304);N=J}}while(0);c[3529522]=N;if((R6(c[2388028]|0,0,2)|0)!=0){P=1;i=e;return P|0}if((R6((c[2388028]|0)+1|0,1,2)|0)!=0){P=1;i=e;return P|0}J=c[2385834]|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}M=H+108|0;c[M>>2]=0;Q=H+100|0;c[Q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](H,2)|0;do{if((c[M>>2]|0)!=0){R=c[Q>>2]|0;c[I>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](I,2,0)|0;if((R|0)<1){P=1;i=e;return P|0}if((gzL(J,0,2)|0)==0){break}else{P=1}i=e;return P|0}}while(0);J=c[3529522]|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}Q=F+108|0;c[Q>>2]=0;M=F+100|0;c[M>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](F,3)|0;do{if((c[Q>>2]|0)!=0){R=c[M>>2]|0;c[G>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](G,3,0)|0;if((R|0)<1){P=1;i=e;return P|0}if((gzL(J,0,3)|0)==0){break}else{P=1}i=e;return P|0}}while(0);J=(c[3529522]|0)+262144|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}M=D+108|0;c[M>>2]=0;Q=D+100|0;c[Q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](D,4)|0;do{if((c[M>>2]|0)!=0){R=c[Q>>2]|0;c[E>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](E,4,0)|0;if((R|0)<1){P=1;i=e;return P|0}if((gzL(J,0,4)|0)==0){break}else{P=1}i=e;return P|0}}while(0);J=(c[3529522]|0)+524288|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}Q=B+108|0;c[Q>>2]=0;M=B+100|0;c[M>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](B,5)|0;do{if((c[Q>>2]|0)!=0){R=c[M>>2]|0;c[C>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](C,5,0)|0;if((R|0)<1){P=1;i=e;return P|0}if((gzL(J,0,5)|0)==0){break}else{P=1}i=e;return P|0}}while(0);J=(c[3529522]|0)+786432|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}M=z+108|0;c[M>>2]=0;Q=z+100|0;c[Q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,6)|0;do{if((c[M>>2]|0)!=0){R=c[Q>>2]|0;c[A>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](A,6,0)|0;if((R|0)<1){P=1;i=e;return P|0}if((gzL(J,0,6)|0)==0){break}else{P=1}i=e;return P|0}}while(0);J=c[3529522]|0;Q=c[2405812]|0;M=0;do{R=M<<8;gGz(Q+R|0,0,256);S=0;do{T=1<<3-S;U=(c[611056+(S<<2)>>2]|0)+R|0;V=0;do{W=U+(c[609008+(V<<2)>>2]|0)|0;X=(V<<4)+R|0;Y=0;do{Z=W+(c[597864+(Y<<2)>>2]|0)|0;if(((d[J+((Z|0)/8|0)|0]|0)&128>>>((Z&7)>>>0)|0)!=0){Z=Q+(X+Y)|0;a[Z]=(d[Z]|0|T)&255}Y=Y+1|0;}while((Y|0)<16);V=V+1|0;}while((V|0)<16);S=S+1|0;}while((S|0)<4);M=M+1|0;}while((M|0)<8192);gGz(J|0,0,4194304);if((c[3542200]|0)==0){P=1;i=e;return P|0}M=x+108|0;c[M>>2]=0;Q=x+100|0;c[Q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,7)|0;do{if((c[M>>2]|0)!=0){S=c[Q>>2]|0;c[y>>2]=9534384;R=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[R&16383](y,7,0)|0;if((S|0)<1){P=1;i=e;return P|0}if((gzL(J,0,7)|0)==0){break}else{P=1}i=e;return P|0}}while(0);J=(c[3529522]|0)+524288|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}Q=v+108|0;c[Q>>2]=0;M=v+100|0;c[M>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,8)|0;do{if((c[Q>>2]|0)!=0){S=c[M>>2]|0;c[w>>2]=9534384;R=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[R&16383](w,8,0)|0;if((S|0)<1){P=1;i=e;return P|0}if((gzL(J,0,8)|0)==0){break}else{P=1}i=e;return P|0}}while(0);J=(c[3529522]|0)+1048576|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}M=t+108|0;c[M>>2]=0;Q=t+100|0;c[Q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,9)|0;do{if((c[M>>2]|0)!=0){S=c[Q>>2]|0;c[u>>2]=9534384;R=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[R&16383](u,9,0)|0;if((S|0)<1){P=1;i=e;return P|0}if((gzL(J,0,9)|0)==0){break}else{P=1}i=e;return P|0}}while(0);J=(c[3529522]|0)+1572864|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}Q=r+108|0;c[Q>>2]=0;M=r+100|0;c[M>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,10)|0;do{if((c[Q>>2]|0)!=0){S=c[M>>2]|0;c[s>>2]=9534384;R=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[R&16383](s,10,0)|0;if((S|0)<1){P=1;i=e;return P|0}if((gzL(J,0,10)|0)==0){break}else{P=1}i=e;return P|0}}while(0);J=(c[3529522]|0)+2097152|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}M=p+108|0;c[M>>2]=0;Q=p+100|0;c[Q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,11)|0;do{if((c[M>>2]|0)!=0){S=c[Q>>2]|0;c[q>>2]=9534384;R=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[R&16383](q,11,0)|0;if((S|0)<1){P=1;i=e;return P|0}if((gzL(J,0,11)|0)==0){break}else{P=1}i=e;return P|0}}while(0);J=(c[3529522]|0)+2621440|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}Q=n+108|0;c[Q>>2]=0;M=n+100|0;c[M>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,12)|0;do{if((c[Q>>2]|0)!=0){S=c[M>>2]|0;c[o>>2]=9534384;R=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[R&16383](o,12,0)|0;if((S|0)<1){P=1;i=e;return P|0}if((gzL(J,0,12)|0)==0){break}else{P=1}i=e;return P|0}}while(0);J=(c[3529522]|0)+3145728|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}M=l+108|0;c[M>>2]=0;Q=l+100|0;c[Q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,13)|0;do{if((c[M>>2]|0)!=0){S=c[Q>>2]|0;c[m>>2]=9534384;R=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[R&16383](m,13,0)|0;if((S|0)<1){P=1;i=e;return P|0}if((gzL(J,0,13)|0)==0){break}else{P=1}i=e;return P|0}}while(0);J=(c[3529522]|0)+3670016|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}Q=j+108|0;c[Q>>2]=0;M=j+100|0;c[M>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,14)|0;do{if((c[Q>>2]|0)!=0){S=c[M>>2]|0;c[k>>2]=9534384;R=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[R&16383](k,14,0)|0;if((S|0)<1){P=1;i=e;return P|0}if((gzL(J,0,14)|0)==0){break}else{P=1}i=e;return P|0}}while(0);J=c[3529522]|0;M=c[3529574]|0;Q=0;do{S=Q<<8;gGz(M+S|0,0,256);R=0;do{V=1<<3-R;T=(c[611552+(R<<2)>>2]|0)+S|0;U=0;do{Y=T+(c[609008+(U<<2)>>2]|0)|0;X=(U<<4)+S|0;W=0;do{Z=Y+(c[597864+(W<<2)>>2]|0)|0;if(((d[J+((Z|0)/8|0)|0]|0)&128>>>((Z&7)>>>0)|0)!=0){Z=M+(X+W)|0;a[Z]=(d[Z]|0|V)&255}W=W+1|0;}while((W|0)<16);U=U+1|0;}while((U|0)<16);R=R+1|0;}while((R|0)<4);Q=Q+1|0;}while((Q|0)<18432);Q=c[2433468]|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}M=f+108|0;c[M>>2]=0;J=f+100|0;c[J>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,15)|0;do{if((c[M>>2]|0)!=0){R=c[J>>2]|0;c[g>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](g,15,0)|0;if((R|0)<1){P=1;i=e;return P|0}if((gzL(Q,0,15)|0)==0){break}else{P=1}i=e;return P|0}}while(0);Q=c[3541206]|0;J=c[2433468]|0;gGC(Q|0,J|0,262144)|0;J=c[3529522]|0;Q=0;while(1){if((Q|0)>=1024){break}_=9638528+(Q<<2)|0;if((c[_>>2]|0)==(J|0)){L=45228;break}else{Q=Q+1|0}}if((L|0)==45228){gGr(J);c[_>>2]=0}c[3529522]=0;fxU(0,425984);if((c[2394]|0)==0){$=c[2112932]|0}else{c[2394]=0;Q=c[3532596]|0;c[2112932]=Q;M=c[3532592]|0;if((M|0)!=0){gGC(9104152,M|0,280)|0}c[2113054]=c[2113060];$=Q}Q=c[2388028]|0;M=$|0;R=0;while(1){S=Q+R|0;c[M>>2]=S;c[M+131072>>2]=S;S=R+1024|0;if(S>>>0>524287){break}else{M=M+4|0;R=S}}R=c[2439940]|0;c[$+2048>>2]=R;c[$+67584>>2]=R;c[$+133120>>2]=R;M=R+1024|0;c[$+2052>>2]=M;c[$+67588>>2]=M;c[$+133124>>2]=M;M=R+2048|0;c[$+2056>>2]=M;c[$+67592>>2]=M;c[$+133128>>2]=M;M=R+3072|0;c[$+2060>>2]=M;c[$+67596>>2]=M;c[$+133132>>2]=M;M=c[2439958]|0;c[$+2080>>2]=M;c[$+67616>>2]=M;c[$+133152>>2]=M;R=M+1024|0;c[$+2084>>2]=R;c[$+67620>>2]=R;c[$+133156>>2]=R;R=c[2439614]|0;c[$+5120>>2]=R;c[$+70656>>2]=R;c[$+136192>>2]=R;M=R+1024|0;c[$+5124>>2]=M;c[$+70660>>2]=M;c[$+136196>>2]=M;M=c[2443414]|0;c[$+6144>>2]=M;c[$+71680>>2]=M;c[$+137216>>2]=M;R=M+1024|0;c[$+6148>>2]=R;c[$+71684>>2]=R;c[$+137220>>2]=R;R=M+2048|0;c[$+6152>>2]=R;c[$+71688>>2]=R;c[$+137224>>2]=R;R=M+3072|0;c[$+6156>>2]=R;c[$+71692>>2]=R;c[$+137228>>2]=R;R=c[2388048]|0;c[$+7168>>2]=R;c[$+72704>>2]=R;c[$+138240>>2]=R;M=R+1024|0;c[$+7172>>2]=M;c[$+72708>>2]=M;c[$+138244>>2]=M;M=R+2048|0;c[$+7176>>2]=M;c[$+72712>>2]=M;c[$+138248>>2]=M;M=R+3072|0;c[$+7180>>2]=M;c[$+72716>>2]=M;c[$+138252>>2]=M;M=R+4096|0;c[$+7184>>2]=M;c[$+72720>>2]=M;c[$+138256>>2]=M;M=R+5120|0;c[$+7188>>2]=M;c[$+72724>>2]=M;c[$+138260>>2]=M;M=R+6144|0;c[$+7192>>2]=M;c[$+72728>>2]=M;c[$+138264>>2]=M;M=R+7168|0;c[$+7196>>2]=M;c[$+72732>>2]=M;c[$+138268>>2]=M;M=R+8192|0;c[$+7200>>2]=M;c[$+72736>>2]=M;c[$+138272>>2]=M;M=R+9216|0;c[$+7204>>2]=M;c[$+72740>>2]=M;c[$+138276>>2]=M;M=R+10240|0;c[$+7208>>2]=M;c[$+72744>>2]=M;c[$+138280>>2]=M;M=R+11264|0;c[$+7212>>2]=M;c[$+72748>>2]=M;c[$+138284>>2]=M;M=R+12288|0;c[$+7216>>2]=M;c[$+72752>>2]=M;c[$+138288>>2]=M;M=R+13312|0;c[$+7220>>2]=M;c[$+72756>>2]=M;c[$+138292>>2]=M;M=R+14336|0;c[$+7224>>2]=M;c[$+72760>>2]=M;c[$+138296>>2]=M;M=R+15360|0;c[$+7228>>2]=M;c[$+72764>>2]=M;c[$+138300>>2]=M;c[$+196688>>2]=56;c[$+196728>>2]=3388;c[$+196608>>2]=1680;c[$+196648>>2]=632;M=c[3532592]|0;if((M|0)!=0){gGC(M|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);M=c[2439330]|0;R=(M|0)==0;if(!R){Q=M;gGC(9706056,Q|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];Q=c[3528484]|0;c[2076596]=Q;J=c[2417276]|0;c[3541536]=J;c[1836236]=0;c[M+4180>>2]=346;c[M+4184>>2]=1674;S=c[2385834]|0;U=0;V=0;while(1){c[M+76+(V<<2)>>2]=S+(V<<8);T=U+1&65535;if((T&65535)>191){aa=0;ab=0;break}else{U=T;V=T&65535}}while(1){V=S+(ab<<8)|0;c[M+76+(ab+512<<2)>>2]=V;c[M+76+(ab+768<<2)>>2]=V;V=aa+1&65535;if((V&65535)>191){break}else{aa=V;ab=V&65535}}S=c[2385852]|0;c[M+844>>2]=S;V=S+256|0;c[M+848>>2]=V;U=S+512|0;c[M+852>>2]=U;T=S+768|0;c[M+856>>2]=T;W=S+1024|0;c[M+860>>2]=W;X=S+1280|0;c[M+864>>2]=X;Y=S+1536|0;c[M+868>>2]=Y;Z=S+1792|0;c[M+872>>2]=Z;c[M+1868>>2]=S;c[M+1872>>2]=V;c[M+1876>>2]=U;c[M+1880>>2]=T;c[M+1884>>2]=W;c[M+1888>>2]=X;c[M+1892>>2]=Y;c[M+1896>>2]=Z;c[M+2892>>2]=S;c[M+3916>>2]=S;c[M+2896>>2]=V;c[M+3920>>2]=V;c[M+2900>>2]=U;c[M+3924>>2]=U;c[M+2904>>2]=T;c[M+3928>>2]=T;c[M+2908>>2]=W;c[M+3932>>2]=W;c[M+2912>>2]=X;c[M+3936>>2]=X;c[M+2916>>2]=Y;c[M+3940>>2]=Y;c[M+2920>>2]=Z;c[M+3944>>2]=Z;if(!R){Z=M;gGC(Z|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=Q;c[2417276]=J;c[1836236]=-1;Z=a[9680]|0;Y=Z?32e3:0;if(Z){if(a[9624]|0){Z=Y*3|0;X=55930;while(1){if((X|0)>(Z|0)){X=X>>1}else{ac=1222;ad=X;break}}}else{ac=2462;ad=Y}c[2429380]=ad;c[3542124]=ac;mw(3579545,ad);X=gGq(262144)|0;c[2406684]=X;gGz(X|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(3579545,11025)}c[(c[3531464]|0)+44344>>2]=1148;h[745421]=.5;c[2436794]=1;h[745420]=.5;c[2436792]=2;Ux(0,7575,1);c[2407030]=384;c[2407068]=3;c[2443626]=5156;X=c[642608+(c[2436]<<2)>>2]|0;Z=c[X+128>>2]|0;if((c[X+52>>2]&4|0)==0){c[2113068]=Z;J=c[X+132>>2]|0;c[2113070]=J;c[2443814]=Z;c[2440436]=J;ae=Z;af=J}else{c[2113070]=Z;J=c[X+132>>2]|0;c[2113068]=J;c[2440436]=Z;c[2443814]=J;ae=J;af=Z}Z=ag(ae<<1,af)|0;J=gGq(Z)|0;c[2112926]=J;if((J|0)!=0){gGz(J|0,0,Z|0)}if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];Z=c[3532592]|0;if((Z|0)!=0){gGC(9104152,Z|0,280)|0}c[2113054]=c[2113060]}RI();Z=c[2394]|0;J=c[14130368+(Z<<2)>>2]|0;if((J|0)!=0){gGC(J|0,9104152,280)|0}c[8452240+(Z<<2)>>2]=c[2113054];c[2394]=-1;Z=c[2439330]|0;J=(Z|0)==0;if(!J){X=Z;gGC(9706056,X|0,76)|0}X=c[2438118]|0;c[2433530]=X;Q=c[3528484]|0;c[2076596]=Q;M=c[2417276]|0;c[3541536]=M;c[1836236]=0;gGz(9706056,0,76);if(!J){J=Z;gGC(J|0,9706056,76)|0}c[2438118]=X;c[3528484]=Q;c[2417276]=M;c[1836236]=-1;mx(0);c[2113156]=0;a[9628264]=0;c[2407033]=0;M=c[3541206]|0;c[3541190]=M;c[3541198]=M;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=M+256;c[3541199]=M+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=M+512;c[3541200]=M+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=M+768;c[3541201]=M+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;b[4879940]=0;b[4887196]=0;b[4887172]=0;b[4887140]=0;b[4887124]=0;b[4814252]=0;a[9758168]=0;a[14121008]=0;a[9545152]=0;P=0;i=e;return P|0}}while(0);c[2426726]=0;P=1;i=e;return P|0}function d7I(){var d=0,e=0,f=0,g=0,h=0;if((c[2392]|0)>=0){d=0;do{e=14130368+(d<<2)|0;f=c[e>>2]|0;if((f|0)!=0){gGr(f);c[e>>2]=0}e=14130384+(d<<2)|0;f=c[e>>2]|0;if((f|0)!=0){gGr(f);c[e>>2]=0}d=d+1|0;}while((d|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;fwZ();d=c[3531464]|0;c[d+44344>>2]=0;c[d+44348>>2]=0;if((d|0)!=0){gGr(d);c[3531464]=0}d=c[2406684]|0;if((d|0)!=0){gGr(d);c[2406684]=0}Uw(0);c[2113070]=0;c[2113068]=0;d=c[2112926]|0;if((d|0)!=0){gGr(d);c[2112926]=0}c[2443626]=0;b[4879940]=0;b[4887196]=0;b[4887172]=0;b[4887140]=0;b[4887124]=0;b[4814252]=0;a[9758168]=0;a[14121008]=0;a[9545152]=0;d=c[2426726]|0;e=0;while(1){if((e|0)>=1024){g=45332;break}h=9638528+(e<<2)|0;if((c[h>>2]|0)==(d|0)){break}else{e=e+1|0}}if((g|0)==45332){c[2426726]=0;return 0}gGr(d);c[h>>2]=0;c[2426726]=0;return 0}function d7J(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;if((a[9624208]|0)!=0){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;h=c[2417276]|0;c[3541536]=h;c[1836236]=0;gGz(9706056,0,76);if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=h;c[1836236]=-1;mx(0);c[2113156]=0;a[9628264]=0;c[2407033]=0;h=c[3541206]|0;c[3541190]=h;c[3541198]=h;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=h+256;c[3541199]=h+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=h+512;c[3541200]=h+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=h+768;c[3541201]=h+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;b[4879940]=0;b[4887196]=0;b[4887172]=0;b[4887140]=0;b[4887124]=0;b[4814252]=0;a[9758168]=0;a[14121008]=0;a[9545152]=0}c[2406434]=0;h=0;g=0;f=0;e=0;d=0;do{g=((a[9759184+h|0]&1)<<h|g&255)&255;f=((a[9758992+h|0]&1)<<h|f&255)&255;e=((a[9758808+h|0]&1)<<h|e&255)&255;d=((a[9758736+h|0]&1)<<h|d&255)&255;h=h+1|0;}while((h|0)<8);a[9625736]=g;a[9625737]=f;a[9625738]=e;a[9625739]=d;if((g&3)==3){f=g&-4;a[9625736]=f;i=f}else{i=g}if((i&12)==12){a[9625736]=i&-13}if((e&3)==3){i=e&-4;a[9625738]=i;j=i}else{j=e}if((j&12)==12){a[9625738]=j&-13}if((d&3)==3){j=d&-4;a[9625739]=j;k=j}else{k=d}if((k&12)==12){a[9625739]=k&-13}a[6518240]=1;a[6518024]=1;c[2444085]=0;c[2444084]=0;k=c[2392]|0;if((k|0)>=0){gGz(8452240,0,((k|0)>0?(k<<2)+4|0:4)|0)}c[2113054]=0;k=c[2385548]|0;if((k|0)>0){gGz(9752472,0,((k|0)>1?k<<2:4)|0)}c[2433530]=0;a[9545152]=0;k=0;d=0;L59807:while(1){j=d;while(1){e=(j|0)<10;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];i=c[3532592]|0;if((i|0)!=0){gGC(9104152,i|0,280)|0}c[2113054]=c[2113060]}if(!e){break L59807}l=j+1|0;e=(ag(a[6518240]|0?2e5:0,l)|0)/10|0;i=e-(c[2444084]|0)|0;c[2438188]=i;c[2113056]=i;e=RG(i)|0;c[2113054]=(c[2113054]|0)+e;c[2276108]=-1;c[2113056]=-1;c[2444084]=(c[2444084]|0)+e;if((j|0)==5){c[8452200+(c[2394]<<2)>>2]=8197;c[2276080]=1280;if((c[2276079]|0)>>>0<1280){RH(5)}a[9545152]=1}e=c[2394]|0;i=c[14130368+(e<<2)>>2]|0;if((i|0)!=0){gGC(i|0,9104152,280)|0}c[8452240+(e<<2)>>2]=c[2113054];c[2394]=-1;e=c[2439330]|0;if((e|0)!=0){i=e;gGC(9706056,i|0,76)|0}b[4853030]=c[2426515]&65535;i=c[2438118]|0;c[2433530]=i;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;g=(ag(a[6518024]|0?59659:0,l)|0)/10|0;f=c[2444085]|0;h=g-f|0;c[2438188]=h;do{if((h|0)<1){m=0;n=f;o=0;p=e;q=i}else{if((a[e+4188|0]|0)==0){g=gfc(h)|0;r=(c[2433530]|0)+g|0;c[2433530]=r;s=c[1836236]|0;m=g;n=c[2444085]|0;o=s;p=c[9757320+(s<<2)>>2]|0;q=r;break}else{r=i+h|0;c[2433530]=r;m=h;n=f;o=0;p=e;q=r;break}}}while(0);c[2438188]=m;c[2444085]=n+m;if((p|0)!=0){e=p;gGC(e|0,9706056,76)|0}c[9752472+(o<<2)>>2]=q;c[14113936+(o<<2)>>2]=c[2076596];c[9669104+(o<<2)>>2]=c[3541536];c[1836236]=-1;t=c[2112964]|0;if((t|0)==0){j=l}else{break}}j=a[9688]|0?53:0;e=t+(k<<1<<1)|0;f=c[2439330]|0;if((f|0)!=0){h=f;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;gg[c[3542124]&4095](e,j);h=c[1836236]|0;f=c[9757320+(h<<2)>>2]|0;if((f|0)!=0){i=f;gGC(i|0,9706056,76)|0}c[9752472+(h<<2)>>2]=c[2433530];c[14113936+(h<<2)>>2]=c[2076596];c[9669104+(h<<2)>>2]=c[3541536];c[1836236]=-1;Uu(0,e,j);k=j+k|0;d=l}c[2113050]=8198;c[2276080]=1536;if((c[2276079]|0)>>>0<1536){RH(6);u=c[2394]|0}else{u=0}l=c[14130368+(u<<2)>>2]|0;if((l|0)!=0){gGC(l|0,9104152,280)|0}c[8452240+(u<<2)>>2]=c[2113054];c[2394]=-1;u=c[2112964]|0;do{if((u|0)!=0){l=a[9688]|0?534:0;d=l-k|0;t=u+(k<<1<<1)|0;if((l|0)==(k|0)){break}l=c[2439330]|0;if((l|0)!=0){o=l;gGC(9706056,o|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;gg[c[3542124]&4095](t,d);o=c[1836236]|0;l=c[9757320+(o<<2)>>2]|0;if((l|0)!=0){q=l;gGC(q|0,9706056,76)|0}c[9752472+(o<<2)>>2]=c[2433530];c[14113936+(o<<2)>>2]=c[2076596];c[9669104+(o<<2)>>2]=c[3541536];c[1836236]=-1;Uu(0,t,d)}}while(0);if((c[2112968]|0)==0){return 0}gu[c[2443626]&16383]();return 0}function d7K(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;f=i;i=i+304|0;g=f|0;h=f+16|0;j=f+32|0;k=f+48|0;l=f+64|0;m=f+80|0;n=f+96|0;o=f+112|0;p=f+128|0;q=f+144|0;r=f+160|0;s=f+176|0;t=f+192|0;u=f+208|0;v=f+224|0;w=f+240|0;x=f+256|0;y=f+272|0;z=f+288|0;if((e|0)!=0){c[e>>2]=169588}if((b&32|0)!=0){gGz(z|0,0,12);e=c[2405660]|0;c[z>>2]=e;c[z+4>>2]=(c[2411670]|0)-e;c[z+12>>2]=162152;e=c[2076592]|0;gj[e&4095](z)|0}if((b&64|0)==0){A=b&2}else{z=l|0;gGz(k|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){e=l+9|0;l=j;B=j|0;C=j+4|0;D=j+12|0;E=k|0;F=k+4|0;G=k+12|0;H=0;do{gGC(z|0,614896,11)|0;a[e]=H+48&255;I=8452256+(H<<2)|0;gGz(l|0,0,12);c[B>>2]=I;c[C>>2]=4;c[D>>2]=164976;gj[c[2076592]&4095](j)|0;if((c[I>>2]|0)!=0){c[E>>2]=c[14130368+(H<<2)>>2];c[F>>2]=c[8452184+(H<<2)>>2];c[G>>2]=z;I=c[2076592]|0;gj[I&4095](k)|0}H=H+1|0;}while((H|0)<=(c[2392]|0))}fw$(b);gGz(h|0,0,12);c[h>>2]=8453216;c[h+4>>2]=4;c[h+12>>2]=107480;H=c[2076592]|0;gj[H&4095](h)|0;gGz(g|0,0,12);c[g>>2]=14168504;c[g+4>>2]=256;c[g+12>>2]=476464;h=c[2076592]|0;gj[h&4095](g)|0;g=b&2;if((g|0)!=0){b=0;do{mv(0,b,d[14168504+b|0]|0);b=b+1|0;}while((b|0)<256)}Ut(0);gGz(y|0,0,12);c[y>>2]=9776336;c[y+4>>2]=8;c[y+12>>2]=212472;b=c[2076592]|0;gj[b&4095](y)|0;gGz(x|0,0,12);c[x>>2]=9752752;c[x+4>>2]=4;c[x+12>>2]=436576;y=c[2076592]|0;gj[y&4095](x)|0;gGz(w|0,0,12);c[w>>2]=9657960;c[w+4>>2]=4;c[w+12>>2]=483352;x=c[2076592]|0;gj[x&4095](w)|0;gGz(v|0,0,12);c[v>>2]=9625736;c[v+4>>2]=4;c[v+12>>2]=215728;w=c[2076592]|0;gj[w&4095](v)|0;gGz(u|0,0,12);c[u>>2]=9759880;c[u+4>>2]=2;c[u+12>>2]=173280;v=c[2076592]|0;gj[v&4095](u)|0;gGz(t|0,0,12);c[t>>2]=9774392;c[t+4>>2]=2;c[t+12>>2]=169648;u=c[2076592]|0;gj[u&4095](t)|0;gGz(s|0,0,12);c[s>>2]=9774344;c[s+4>>2]=2;c[s+12>>2]=166776;t=c[2076592]|0;gj[t&4095](s)|0;gGz(r|0,0,12);c[r>>2]=9774280;c[r+4>>2]=2;c[r+12>>2]=163920;s=c[2076592]|0;gj[s&4095](r)|0;gGz(q|0,0,12);c[q>>2]=9774248;c[q+4>>2]=2;c[q+12>>2]=160104;r=c[2076592]|0;gj[r&4095](q)|0;gGz(p|0,0,12);c[p>>2]=9628504;c[p+4>>2]=2;c[p+12>>2]=371048;q=c[2076592]|0;gj[q&4095](p)|0;gGz(o|0,0,12);c[o>>2]=9758168;c[o+4>>2]=1;c[o+12>>2]=497064;p=c[2076592]|0;gj[p&4095](o)|0;gGz(n|0,0,12);c[n>>2]=14121008;c[n+4>>2]=1;c[n+12>>2]=491248;o=c[2076592]|0;gj[o&4095](n)|0;gGz(m|0,0,12);c[m>>2]=9545152;c[m+4>>2]=1;c[m+12>>2]=449152;n=c[2076592]|0;gj[n&4095](m)|0;A=g}if((A|0)==0){i=f;return 0}A=c[3541206]|0;g=(c[2433468]|0)+((d[14121008]|0)<<18)|0;gGC(A|0,g|0,262144)|0;i=f;return 0}function d7L(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7251924+(b*112|0)>>2];c[a+104>>2]=c[7251928+(b*112|0)>>2];c[a+108>>2]=c[7251932+(b*112|0)>>2];d=0;return d|0}function d7M(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=7251824+(b*112|0);e=0;return e|0}function d7N(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>33){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7239716+(b*112|0)>>2];c[a+104>>2]=c[7239720+(b*112|0)>>2];c[a+108>>2]=c[7239724+(b*112|0)>>2];d=0;return d|0}function d7O(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<34&(d|0)==0)){e=1;return e|0}c[a>>2]=7239616+(b*112|0);e=0;return e|0}function d7P(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0;e=i;i=i+3720|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;B=e+1200|0;C=e+1312|0;D=e+1320|0;E=e+1432|0;F=e+1440|0;G=e+1552|0;H=e+1560|0;I=e+1672|0;J=e+1680|0;K=e+1792|0;L=e+1800|0;M=e+1912|0;N=e+1920|0;O=e+2032|0;P=e+2040|0;Q=e+2152|0;R=e+2160|0;S=e+2272|0;T=e+2280|0;U=e+2392|0;V=e+2400|0;W=e+2512|0;X=e+2520|0;Y=e+2632|0;Z=e+2640|0;_=e+2752|0;$=e+2760|0;aa=e+2872|0;ab=e+2880|0;ac=e+2992|0;ad=e+3e3|0;ae=e+3112|0;af=e+3120|0;ah=e+3232|0;ai=e+3240|0;aj=e+3352|0;ak=e+3360|0;al=e+3472|0;am=e+3480|0;an=e+3592|0;ao=e+3600|0;ap=e+3712|0;c[2424]=5700;c[2426726]=0;c[2388028]=0;c[2385834]=524288;c[3541206]=589824;c[2433468]=851968;c[2405660]=1376256;c[2388048]=1376256;c[2385852]=1394688;c[2439940]=1396736;c[2443414]=1400832;c[2439958]=1404928;c[2439614]=1406976;c[2411670]=1408512;c[2405812]=1408512;c[3529574]=3505664;c[3530014]=8224256;aq=0;while(1){if((aq|0)>=1024){break}ar=9638528+(aq<<2)|0;if((c[ar>>2]|0)==0){as=45452;break}else{aq=aq+1|0}}do{if((as|0)==45452){aq=gGq(8230400)|0;c[ar>>2]=aq;if((aq|0)==0){break}c[2426726]=aq;gGz(aq|0,0,8230400);c[2388028]=aq;c[2385834]=aq+524288;c[3541206]=aq+589824;c[2433468]=aq+851968;at=aq+1376256|0;c[2405660]=at;c[2388048]=at;c[2385852]=aq+1394688;c[2439940]=aq+1396736;c[2443414]=aq+1400832;c[2439958]=aq+1404928;c[2439614]=aq+1406976;at=aq+1408512|0;c[2411670]=at;c[2405812]=at;c[3529574]=aq+3505664;c[3530014]=aq+8224256;c[2414210]=aq+8230400;aq=0;while(1){if((aq|0)>=1024){au=0;break}av=9638528+(aq<<2)|0;if((c[av>>2]|0)==0){as=45457;break}else{aq=aq+1|0}}do{if((as|0)==45457){aq=gGq(4194304)|0;c[av>>2]=aq;if((aq|0)==0){au=0;break}gGz(aq|0,0,4194304);au=aq}}while(0);c[3529522]=au;if((R6(c[2388028]|0,0,2)|0)!=0){aw=1;i=e;return aw|0}if((R6((c[2388028]|0)+1|0,1,2)|0)!=0){aw=1;i=e;return aw|0}aq=c[2385834]|0;if((c[3542200]|0)==0){aw=1;i=e;return aw|0}at=ao+108|0;c[at>>2]=0;ax=ao+100|0;c[ax>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](ao,2)|0;do{if((c[at>>2]|0)!=0){ay=c[ax>>2]|0;c[ap>>2]=9534384;az=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[az&16383](ap,2,0)|0;if((ay|0)<1){aw=1;i=e;return aw|0}if((gzL(aq,0,2)|0)==0){break}else{aw=1}i=e;return aw|0}}while(0);aq=c[3529522]|0;if((c[3542200]|0)==0){aw=1;i=e;return aw|0}ax=am+108|0;c[ax>>2]=0;at=am+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](am,3)|0;do{if((c[ax>>2]|0)!=0){ay=c[at>>2]|0;c[an>>2]=9534384;az=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[az&16383](an,3,0)|0;if((ay|0)<1){aw=1;i=e;return aw|0}if((gzL(aq,0,3)|0)==0){break}else{aw=1}i=e;return aw|0}}while(0);aq=(c[3529522]|0)+131072|0;if((c[3542200]|0)==0){aw=1;i=e;return aw|0}at=ak+108|0;c[at>>2]=0;ax=ak+100|0;c[ax>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](ak,4)|0;do{if((c[at>>2]|0)!=0){ay=c[ax>>2]|0;c[al>>2]=9534384;az=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[az&16383](al,4,0)|0;if((ay|0)<1){aw=1;i=e;return aw|0}if((gzL(aq,0,4)|0)==0){break}else{aw=1}i=e;return aw|0}}while(0);aq=(c[3529522]|0)+262144|0;if((c[3542200]|0)==0){aw=1;i=e;return aw|0}ax=ai+108|0;c[ax>>2]=0;at=ai+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](ai,5)|0;do{if((c[ax>>2]|0)!=0){ay=c[at>>2]|0;c[aj>>2]=9534384;az=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[az&16383](aj,5,0)|0;if((ay|0)<1){aw=1;i=e;return aw|0}if((gzL(aq,0,5)|0)==0){break}else{aw=1}i=e;return aw|0}}while(0);aq=(c[3529522]|0)+393216|0;if((c[3542200]|0)==0){aw=1;i=e;return aw|0}at=af+108|0;c[at>>2]=0;ax=af+100|0;c[ax>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](af,6)|0;do{if((c[at>>2]|0)!=0){ay=c[ax>>2]|0;c[ah>>2]=9534384;az=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[az&16383](ah,6,0)|0;if((ay|0)<1){aw=1;i=e;return aw|0}if((gzL(aq,0,6)|0)==0){break}else{aw=1}i=e;return aw|0}}while(0);aq=(c[3529522]|0)+524288|0;if((c[3542200]|0)==0){aw=1;i=e;return aw|0}ax=ad+108|0;c[ax>>2]=0;at=ad+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](ad,7)|0;do{if((c[ax>>2]|0)!=0){ay=c[at>>2]|0;c[ae>>2]=9534384;az=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[az&16383](ae,7,0)|0;if((ay|0)<1){aw=1;i=e;return aw|0}if((gzL(aq,0,7)|0)==0){break}else{aw=1}i=e;return aw|0}}while(0);aq=(c[3529522]|0)+655360|0;if((c[3542200]|0)==0){aw=1;i=e;return aw|0}at=ab+108|0;c[at>>2]=0;ax=ab+100|0;c[ax>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](ab,8)|0;do{if((c[at>>2]|0)!=0){ay=c[ax>>2]|0;c[ac>>2]=9534384;az=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[az&16383](ac,8,0)|0;if((ay|0)<1){aw=1;i=e;return aw|0}if((gzL(aq,0,8)|0)==0){break}else{aw=1}i=e;return aw|0}}while(0);aq=(c[3529522]|0)+786432|0;if((c[3542200]|0)==0){aw=1;i=e;return aw|0}ax=$+108|0;c[ax>>2]=0;at=$+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383]($,9)|0;do{if((c[ax>>2]|0)!=0){ay=c[at>>2]|0;c[aa>>2]=9534384;az=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[az&16383](aa,9,0)|0;if((ay|0)<1){aw=1;i=e;return aw|0}if((gzL(aq,0,9)|0)==0){break}else{aw=1}i=e;return aw|0}}while(0);aq=(c[3529522]|0)+917504|0;if((c[3542200]|0)==0){aw=1;i=e;return aw|0}at=Z+108|0;c[at>>2]=0;ax=Z+100|0;c[ax>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](Z,10)|0;do{if((c[at>>2]|0)!=0){ay=c[ax>>2]|0;c[_>>2]=9534384;az=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[az&16383](_,10,0)|0;if((ay|0)<1){aw=1;i=e;return aw|0}if((gzL(aq,0,10)|0)==0){break}else{aw=1}i=e;return aw|0}}while(0);aq=c[3529522]|0;ax=c[2405812]|0;at=0;do{ay=at<<8;gGz(ax+ay|0,0,256);az=0;do{aA=1<<3-az;aB=(c[611056+(az<<2)>>2]|0)+ay|0;aC=0;do{aD=aB+(c[609008+(aC<<2)>>2]|0)|0;aE=(aC<<4)+ay|0;aF=0;do{aG=aD+(c[597864+(aF<<2)>>2]|0)|0;if(((d[aq+((aG|0)/8|0)|0]|0)&128>>>((aG&7)>>>0)|0)!=0){aG=ax+(aE+aF)|0;a[aG]=(d[aG]|0|aA)&255}aF=aF+1|0;}while((aF|0)<16);aC=aC+1|0;}while((aC|0)<16);az=az+1|0;}while((az|0)<4);at=at+1|0;}while((at|0)<8192);gGz(aq|0,0,4194304);if((c[3542200]|0)==0){aw=1;i=e;return aw|0}at=X+108|0;c[at>>2]=0;ax=X+100|0;c[ax>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](X,11)|0;do{if((c[at>>2]|0)!=0){az=c[ax>>2]|0;c[Y>>2]=9534384;ay=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ay&16383](Y,11,0)|0;if((az|0)<1){aw=1;i=e;return aw|0}if((gzL(aq,0,11)|0)==0){break}else{aw=1}i=e;return aw|0}}while(0);aq=(c[3529522]|0)+131072|0;if((c[3542200]|0)==0){aw=1;i=e;return aw|0}ax=V+108|0;c[ax>>2]=0;at=V+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](V,12)|0;do{if((c[ax>>2]|0)!=0){az=c[at>>2]|0;c[W>>2]=9534384;ay=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ay&16383](W,12,0)|0;if((az|0)<1){aw=1;i=e;return aw|0}if((gzL(aq,0,12)|0)==0){break}else{aw=1}i=e;return aw|0}}while(0);aq=(c[3529522]|0)+262144|0;if((c[3542200]|0)==0){aw=1;i=e;return aw|0}at=T+108|0;c[at>>2]=0;ax=T+100|0;c[ax>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](T,13)|0;do{if((c[at>>2]|0)!=0){az=c[ax>>2]|0;c[U>>2]=9534384;ay=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ay&16383](U,13,0)|0;if((az|0)<1){aw=1;i=e;return aw|0}if((gzL(aq,0,13)|0)==0){break}else{aw=1}i=e;return aw|0}}while(0);aq=(c[3529522]|0)+393216|0;if((c[3542200]|0)==0){aw=1;i=e;return aw|0}ax=R+108|0;c[ax>>2]=0;at=R+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](R,14)|0;do{if((c[ax>>2]|0)!=0){az=c[at>>2]|0;c[S>>2]=9534384;ay=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ay&16383](S,14,0)|0;if((az|0)<1){aw=1;i=e;return aw|0}if((gzL(aq,0,14)|0)==0){break}else{aw=1}i=e;return aw|0}}while(0);aq=(c[3529522]|0)+1048576|0;if((c[3542200]|0)==0){aw=1;i=e;return aw|0}at=P+108|0;c[at>>2]=0;ax=P+100|0;c[ax>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](P,15)|0;do{if((c[at>>2]|0)!=0){az=c[ax>>2]|0;c[Q>>2]=9534384;ay=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ay&16383](Q,15,0)|0;if((az|0)<1){aw=1;i=e;return aw|0}if((gzL(aq,0,15)|0)==0){break}else{aw=1}i=e;return aw|0}}while(0);aq=(c[3529522]|0)+1179648|0;if((c[3542200]|0)==0){aw=1;i=e;return aw|0}ax=N+108|0;c[ax>>2]=0;at=N+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](N,16)|0;do{if((c[ax>>2]|0)!=0){az=c[at>>2]|0;c[O>>2]=9534384;ay=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ay&16383](O,16,0)|0;if((az|0)<1){aw=1;i=e;return aw|0}if((gzL(aq,0,16)|0)==0){break}else{aw=1}i=e;return aw|0}}while(0);aq=(c[3529522]|0)+1310720|0;if((c[3542200]|0)==0){aw=1;i=e;return aw|0}at=L+108|0;c[at>>2]=0;ax=L+100|0;c[ax>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](L,17)|0;do{if((c[at>>2]|0)!=0){az=c[ax>>2]|0;c[M>>2]=9534384;ay=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ay&16383](M,17,0)|0;if((az|0)<1){aw=1;i=e;return aw|0}if((gzL(aq,0,17)|0)==0){break}else{aw=1}i=e;return aw|0}}while(0);aq=(c[3529522]|0)+1441792|0;if((c[3542200]|0)==0){aw=1;i=e;return aw|0}ax=J+108|0;c[ax>>2]=0;at=J+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](J,18)|0;do{if((c[ax>>2]|0)!=0){az=c[at>>2]|0;c[K>>2]=9534384;ay=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ay&16383](K,18,0)|0;if((az|0)<1){aw=1;i=e;return aw|0}if((gzL(aq,0,18)|0)==0){break}else{aw=1}i=e;return aw|0}}while(0);aq=(c[3529522]|0)+2097152|0;if((c[3542200]|0)==0){aw=1;i=e;return aw|0}at=H+108|0;c[at>>2]=0;ax=H+100|0;c[ax>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](H,19)|0;do{if((c[at>>2]|0)!=0){az=c[ax>>2]|0;c[I>>2]=9534384;ay=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ay&16383](I,19,0)|0;if((az|0)<1){aw=1;i=e;return aw|0}if((gzL(aq,0,19)|0)==0){break}else{aw=1}i=e;return aw|0}}while(0);aq=(c[3529522]|0)+2228224|0;if((c[3542200]|0)==0){aw=1;i=e;return aw|0}ax=F+108|0;c[ax>>2]=0;at=F+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](F,20)|0;do{if((c[ax>>2]|0)!=0){az=c[at>>2]|0;c[G>>2]=9534384;ay=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ay&16383](G,20,0)|0;if((az|0)<1){aw=1;i=e;return aw|0}if((gzL(aq,0,20)|0)==0){break}else{aw=1}i=e;return aw|0}}while(0);aq=(c[3529522]|0)+2359296|0;if((c[3542200]|0)==0){aw=1;i=e;return aw|0}at=D+108|0;c[at>>2]=0;ax=D+100|0;c[ax>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](D,21)|0;do{if((c[at>>2]|0)!=0){az=c[ax>>2]|0;c[E>>2]=9534384;ay=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ay&16383](E,21,0)|0;if((az|0)<1){aw=1;i=e;return aw|0}if((gzL(aq,0,21)|0)==0){break}else{aw=1}i=e;return aw|0}}while(0);aq=(c[3529522]|0)+2490368|0;if((c[3542200]|0)==0){aw=1;i=e;return aw|0}ax=B+108|0;c[ax>>2]=0;at=B+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](B,22)|0;do{if((c[ax>>2]|0)!=0){az=c[at>>2]|0;c[C>>2]=9534384;ay=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ay&16383](C,22,0)|0;if((az|0)<1){aw=1;i=e;return aw|0}if((gzL(aq,0,22)|0)==0){break}else{aw=1}i=e;return aw|0}}while(0);aq=(c[3529522]|0)+3145728|0;if((c[3542200]|0)==0){aw=1;i=e;return aw|0}at=z+108|0;c[at>>2]=0;ax=z+100|0;c[ax>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,23)|0;do{if((c[at>>2]|0)!=0){az=c[ax>>2]|0;c[A>>2]=9534384;ay=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ay&16383](A,23,0)|0;if((az|0)<1){aw=1;i=e;return aw|0}if((gzL(aq,0,23)|0)==0){break}else{aw=1}i=e;return aw|0}}while(0);aq=(c[3529522]|0)+3276800|0;if((c[3542200]|0)==0){aw=1;i=e;return aw|0}ax=x+108|0;c[ax>>2]=0;at=x+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,24)|0;do{if((c[ax>>2]|0)!=0){az=c[at>>2]|0;c[y>>2]=9534384;ay=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ay&16383](y,24,0)|0;if((az|0)<1){aw=1;i=e;return aw|0}if((gzL(aq,0,24)|0)==0){break}else{aw=1}i=e;return aw|0}}while(0);aq=(c[3529522]|0)+3407872|0;if((c[3542200]|0)==0){aw=1;i=e;return aw|0}at=v+108|0;c[at>>2]=0;ax=v+100|0;c[ax>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,25)|0;do{if((c[at>>2]|0)!=0){az=c[ax>>2]|0;c[w>>2]=9534384;ay=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ay&16383](w,25,0)|0;if((az|0)<1){aw=1;i=e;return aw|0}if((gzL(aq,0,25)|0)==0){break}else{aw=1}i=e;return aw|0}}while(0);aq=(c[3529522]|0)+3538944|0;if((c[3542200]|0)==0){aw=1;i=e;return aw|0}ax=t+108|0;c[ax>>2]=0;at=t+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,26)|0;do{if((c[ax>>2]|0)!=0){az=c[at>>2]|0;c[u>>2]=9534384;ay=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ay&16383](u,26,0)|0;if((az|0)<1){aw=1;i=e;return aw|0}if((gzL(aq,0,26)|0)==0){break}else{aw=1}i=e;return aw|0}}while(0);aq=(c[3529522]|0)+524288|0;if((c[3542200]|0)==0){aw=1;i=e;return aw|0}at=r+108|0;c[at>>2]=0;ax=r+100|0;c[ax>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,27)|0;do{if((c[at>>2]|0)!=0){az=c[ax>>2]|0;c[s>>2]=9534384;ay=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ay&16383](s,27,0)|0;if((az|0)<1){aw=1;i=e;return aw|0}if((gzL(aq,0,27)|0)==0){break}else{aw=1}i=e;return aw|0}}while(0);aq=(c[3529522]|0)+1572864|0;if((c[3542200]|0)==0){aw=1;i=e;return aw|0}ax=p+108|0;c[ax>>2]=0;at=p+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,28)|0;do{if((c[ax>>2]|0)!=0){az=c[at>>2]|0;c[q>>2]=9534384;ay=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ay&16383](q,28,0)|0;if((az|0)<1){aw=1;i=e;return aw|0}if((gzL(aq,0,28)|0)==0){break}else{aw=1}i=e;return aw|0}}while(0);aq=(c[3529522]|0)+2621440|0;if((c[3542200]|0)==0){aw=1;i=e;return aw|0}at=n+108|0;c[at>>2]=0;ax=n+100|0;c[ax>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,29)|0;do{if((c[at>>2]|0)!=0){az=c[ax>>2]|0;c[o>>2]=9534384;ay=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ay&16383](o,29,0)|0;if((az|0)<1){aw=1;i=e;return aw|0}if((gzL(aq,0,29)|0)==0){break}else{aw=1}i=e;return aw|0}}while(0);aq=(c[3529522]|0)+3670016|0;if((c[3542200]|0)==0){aw=1;i=e;return aw|0}ax=l+108|0;c[ax>>2]=0;at=l+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,30)|0;do{if((c[ax>>2]|0)!=0){az=c[at>>2]|0;c[m>>2]=9534384;ay=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ay&16383](m,30,0)|0;if((az|0)<1){aw=1;i=e;return aw|0}if((gzL(aq,0,30)|0)==0){break}else{aw=1}i=e;return aw|0}}while(0);aq=c[3529522]|0;at=c[3529574]|0;ax=0;do{az=ax<<8;gGz(at+az|0,0,256);ay=0;do{aC=1<<3-ay;aA=(c[611552+(ay<<2)>>2]|0)+az|0;aB=0;do{aF=aA+(c[609008+(aB<<2)>>2]|0)|0;aE=(aB<<4)+az|0;aD=0;do{aG=aF+(c[597864+(aD<<2)>>2]|0)|0;if(((d[aq+((aG|0)/8|0)|0]|0)&128>>>((aG&7)>>>0)|0)!=0){aG=at+(aE+aD)|0;a[aG]=(d[aG]|0|aC)&255}aD=aD+1|0;}while((aD|0)<16);aB=aB+1|0;}while((aB|0)<16);ay=ay+1|0;}while((ay|0)<4);ax=ax+1|0;}while((ax|0)<18432);ax=c[2433468]|0;if((c[3542200]|0)==0){aw=1;i=e;return aw|0}at=j+108|0;c[at>>2]=0;aq=j+100|0;c[aq>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,31)|0;do{if((c[at>>2]|0)!=0){ay=c[aq>>2]|0;c[k>>2]=9534384;az=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[az&16383](k,31,0)|0;if((ay|0)<1){aw=1;i=e;return aw|0}if((gzL(ax,0,31)|0)==0){break}else{aw=1}i=e;return aw|0}}while(0);ax=(c[2433468]|0)+262144|0;if((c[3542200]|0)==0){aw=1;i=e;return aw|0}aq=f+108|0;c[aq>>2]=0;at=f+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,32)|0;do{if((c[aq>>2]|0)!=0){ay=c[at>>2]|0;c[g>>2]=9534384;az=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[az&16383](g,32,0)|0;if((ay|0)<1){aw=1;i=e;return aw|0}if((gzL(ax,0,32)|0)==0){break}else{aw=1}i=e;return aw|0}}while(0);ax=c[3541206]|0;at=c[2433468]|0;gGC(ax|0,at|0,262144)|0;at=c[3529522]|0;ax=0;while(1){if((ax|0)>=1024){break}aH=9638528+(ax<<2)|0;if((c[aH>>2]|0)==(at|0)){as=45608;break}else{ax=ax+1|0}}if((as|0)==45608){gGr(at);c[aH>>2]=0}c[3529522]=0;fxU(0,425984);if((c[2394]|0)==0){aI=c[2112932]|0}else{c[2394]=0;ax=c[3532596]|0;c[2112932]=ax;aq=c[3532592]|0;if((aq|0)!=0){gGC(9104152,aq|0,280)|0}c[2113054]=c[2113060];aI=ax}ax=c[2388028]|0;aq=aI|0;ay=0;while(1){az=ax+ay|0;c[aq>>2]=az;c[aq+131072>>2]=az;az=ay+1024|0;if(az>>>0>524287){break}else{aq=aq+4|0;ay=az}}ay=c[2439940]|0;c[aI+2048>>2]=ay;c[aI+67584>>2]=ay;c[aI+133120>>2]=ay;aq=ay+1024|0;c[aI+2052>>2]=aq;c[aI+67588>>2]=aq;c[aI+133124>>2]=aq;aq=ay+2048|0;c[aI+2056>>2]=aq;c[aI+67592>>2]=aq;c[aI+133128>>2]=aq;aq=ay+3072|0;c[aI+2060>>2]=aq;c[aI+67596>>2]=aq;c[aI+133132>>2]=aq;aq=c[2439958]|0;c[aI+2080>>2]=aq;c[aI+67616>>2]=aq;c[aI+133152>>2]=aq;ay=aq+1024|0;c[aI+2084>>2]=ay;c[aI+67620>>2]=ay;c[aI+133156>>2]=ay;ay=c[2439614]|0;c[aI+5120>>2]=ay;c[aI+70656>>2]=ay;c[aI+136192>>2]=ay;aq=ay+1024|0;c[aI+5124>>2]=aq;c[aI+70660>>2]=aq;c[aI+136196>>2]=aq;aq=c[2443414]|0;c[aI+6144>>2]=aq;c[aI+71680>>2]=aq;c[aI+137216>>2]=aq;ay=aq+1024|0;c[aI+6148>>2]=ay;c[aI+71684>>2]=ay;c[aI+137220>>2]=ay;ay=aq+2048|0;c[aI+6152>>2]=ay;c[aI+71688>>2]=ay;c[aI+137224>>2]=ay;ay=aq+3072|0;c[aI+6156>>2]=ay;c[aI+71692>>2]=ay;c[aI+137228>>2]=ay;ay=c[2388048]|0;c[aI+7168>>2]=ay;c[aI+72704>>2]=ay;c[aI+138240>>2]=ay;aq=ay+1024|0;c[aI+7172>>2]=aq;c[aI+72708>>2]=aq;c[aI+138244>>2]=aq;aq=ay+2048|0;c[aI+7176>>2]=aq;c[aI+72712>>2]=aq;c[aI+138248>>2]=aq;aq=ay+3072|0;c[aI+7180>>2]=aq;c[aI+72716>>2]=aq;c[aI+138252>>2]=aq;aq=ay+4096|0;c[aI+7184>>2]=aq;c[aI+72720>>2]=aq;c[aI+138256>>2]=aq;aq=ay+5120|0;c[aI+7188>>2]=aq;c[aI+72724>>2]=aq;c[aI+138260>>2]=aq;aq=ay+6144|0;c[aI+7192>>2]=aq;c[aI+72728>>2]=aq;c[aI+138264>>2]=aq;aq=ay+7168|0;c[aI+7196>>2]=aq;c[aI+72732>>2]=aq;c[aI+138268>>2]=aq;aq=ay+8192|0;c[aI+7200>>2]=aq;c[aI+72736>>2]=aq;c[aI+138272>>2]=aq;aq=ay+9216|0;c[aI+7204>>2]=aq;c[aI+72740>>2]=aq;c[aI+138276>>2]=aq;aq=ay+10240|0;c[aI+7208>>2]=aq;c[aI+72744>>2]=aq;c[aI+138280>>2]=aq;aq=ay+11264|0;c[aI+7212>>2]=aq;c[aI+72748>>2]=aq;c[aI+138284>>2]=aq;aq=ay+12288|0;c[aI+7216>>2]=aq;c[aI+72752>>2]=aq;c[aI+138288>>2]=aq;aq=ay+13312|0;c[aI+7220>>2]=aq;c[aI+72756>>2]=aq;c[aI+138292>>2]=aq;aq=ay+14336|0;c[aI+7224>>2]=aq;c[aI+72760>>2]=aq;c[aI+138296>>2]=aq;aq=ay+15360|0;c[aI+7228>>2]=aq;c[aI+72764>>2]=aq;c[aI+138300>>2]=aq;c[aI+196688>>2]=56;c[aI+196728>>2]=3388;c[aI+196608>>2]=1680;c[aI+196648>>2]=632;aq=c[3532592]|0;if((aq|0)!=0){gGC(aq|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);aq=c[2439330]|0;ay=(aq|0)==0;if(!ay){ax=aq;gGC(9706056,ax|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];ax=c[3528484]|0;c[2076596]=ax;at=c[2417276]|0;c[3541536]=at;c[1836236]=0;c[aq+4180>>2]=346;c[aq+4184>>2]=1674;az=c[2385834]|0;aB=0;aC=0;while(1){c[aq+76+(aC<<2)>>2]=az+(aC<<8);aA=aB+1&65535;if((aA&65535)>191){aJ=0;aK=0;break}else{aB=aA;aC=aA&65535}}while(1){aC=az+(aK<<8)|0;c[aq+76+(aK+512<<2)>>2]=aC;c[aq+76+(aK+768<<2)>>2]=aC;aC=aJ+1&65535;if((aC&65535)>191){break}else{aJ=aC;aK=aC&65535}}az=c[2385852]|0;c[aq+844>>2]=az;aC=az+256|0;c[aq+848>>2]=aC;aB=az+512|0;c[aq+852>>2]=aB;aA=az+768|0;c[aq+856>>2]=aA;aD=az+1024|0;c[aq+860>>2]=aD;aE=az+1280|0;c[aq+864>>2]=aE;aF=az+1536|0;c[aq+868>>2]=aF;aG=az+1792|0;c[aq+872>>2]=aG;c[aq+1868>>2]=az;c[aq+1872>>2]=aC;c[aq+1876>>2]=aB;c[aq+1880>>2]=aA;c[aq+1884>>2]=aD;c[aq+1888>>2]=aE;c[aq+1892>>2]=aF;c[aq+1896>>2]=aG;c[aq+2892>>2]=az;c[aq+3916>>2]=az;c[aq+2896>>2]=aC;c[aq+3920>>2]=aC;c[aq+2900>>2]=aB;c[aq+3924>>2]=aB;c[aq+2904>>2]=aA;c[aq+3928>>2]=aA;c[aq+2908>>2]=aD;c[aq+3932>>2]=aD;c[aq+2912>>2]=aE;c[aq+3936>>2]=aE;c[aq+2916>>2]=aF;c[aq+3940>>2]=aF;c[aq+2920>>2]=aG;c[aq+3944>>2]=aG;if(!ay){aG=aq;gGC(aG|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=ax;c[2417276]=at;c[1836236]=-1;aG=a[9680]|0;aF=aG?32e3:0;if(aG){if(a[9624]|0){aG=aF*3|0;aE=55930;while(1){if((aE|0)>(aG|0)){aE=aE>>1}else{aL=1222;aM=aE;break}}}else{aL=2462;aM=aF}c[2429380]=aM;c[3542124]=aL;mw(3579545,aM);aE=gGq(262144)|0;c[2406684]=aE;gGz(aE|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(3579545,11025)}c[(c[3531464]|0)+44344>>2]=1148;h[745421]=.5;c[2436794]=1;h[745420]=.5;c[2436792]=2;Ux(0,7575,1);c[2407030]=384;c[2407068]=3;c[2443626]=5156;aE=c[642608+(c[2436]<<2)>>2]|0;aG=c[aE+128>>2]|0;if((c[aE+52>>2]&4|0)==0){c[2113068]=aG;at=c[aE+132>>2]|0;c[2113070]=at;c[2443814]=aG;c[2440436]=at;aN=aG;aO=at}else{c[2113070]=aG;at=c[aE+132>>2]|0;c[2113068]=at;c[2440436]=aG;c[2443814]=at;aN=at;aO=aG}aG=ag(aN<<1,aO)|0;at=gGq(aG)|0;c[2112926]=at;if((at|0)!=0){gGz(at|0,0,aG|0)}if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];aG=c[3532592]|0;if((aG|0)!=0){gGC(9104152,aG|0,280)|0}c[2113054]=c[2113060]}RI();aG=c[2394]|0;at=c[14130368+(aG<<2)>>2]|0;if((at|0)!=0){gGC(at|0,9104152,280)|0}c[8452240+(aG<<2)>>2]=c[2113054];c[2394]=-1;aG=c[2439330]|0;at=(aG|0)==0;if(!at){aE=aG;gGC(9706056,aE|0,76)|0}aE=c[2438118]|0;c[2433530]=aE;ax=c[3528484]|0;c[2076596]=ax;aq=c[2417276]|0;c[3541536]=aq;c[1836236]=0;gGz(9706056,0,76);if(!at){at=aG;gGC(at|0,9706056,76)|0}c[2438118]=aE;c[3528484]=ax;c[2417276]=aq;c[1836236]=-1;mx(0);c[2113156]=0;a[9628264]=0;c[2407033]=0;aq=c[3541206]|0;c[3541190]=aq;c[3541198]=aq;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=aq+256;c[3541199]=aq+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=aq+512;c[3541200]=aq+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=aq+768;c[3541201]=aq+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;b[4879940]=0;b[4887196]=0;b[4887172]=0;b[4887140]=0;b[4887124]=0;b[4814252]=0;a[9758168]=0;a[14121008]=0;a[9545152]=0;aw=0;i=e;return aw|0}}while(0);c[2426726]=0;aw=1;i=e;return aw|0}function d7Q(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>30){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7274076+(b*112|0)>>2];c[a+104>>2]=c[7274080+(b*112|0)>>2];c[a+108>>2]=c[7274084+(b*112|0)>>2];d=0;return d|0}function d7R(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<31&(d|0)==0)){e=1;return e|0}c[a>>2]=7273976+(b*112|0);e=0;return e|0}function d7S(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>37){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7293352+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function d7T(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0;e=i;i=i+3240|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;B=e+1200|0;C=e+1312|0;D=e+1320|0;E=e+1432|0;F=e+1440|0;G=e+1552|0;H=e+1560|0;I=e+1672|0;J=e+1680|0;K=e+1792|0;L=e+1800|0;M=e+1912|0;N=e+1920|0;O=e+2032|0;P=e+2040|0;Q=e+2152|0;R=e+2160|0;S=e+2272|0;T=e+2280|0;U=e+2392|0;V=e+2400|0;W=e+2512|0;X=e+2520|0;Y=e+2632|0;Z=e+2640|0;_=e+2752|0;$=e+2760|0;aa=e+2872|0;ab=e+2880|0;ac=e+2992|0;ad=e+3e3|0;ae=e+3112|0;af=e+3120|0;ah=e+3232|0;c[2424]=5700;c[2426726]=0;c[2388028]=0;c[2385834]=524288;c[3541206]=589824;c[2433468]=851968;c[2405660]=1376256;c[2388048]=1376256;c[2385852]=1394688;c[2439940]=1396736;c[2443414]=1400832;c[2439958]=1404928;c[2439614]=1406976;c[2411670]=1408512;c[2405812]=1408512;c[3529574]=3505664;c[3530014]=8224256;ai=0;while(1){if((ai|0)>=1024){break}aj=9638528+(ai<<2)|0;if((c[aj>>2]|0)==0){ak=45767;break}else{ai=ai+1|0}}do{if((ak|0)==45767){ai=gGq(8230400)|0;c[aj>>2]=ai;if((ai|0)==0){break}c[2426726]=ai;gGz(ai|0,0,8230400);c[2388028]=ai;c[2385834]=ai+524288;c[3541206]=ai+589824;c[2433468]=ai+851968;al=ai+1376256|0;c[2405660]=al;c[2388048]=al;c[2385852]=ai+1394688;c[2439940]=ai+1396736;c[2443414]=ai+1400832;c[2439958]=ai+1404928;c[2439614]=ai+1406976;al=ai+1408512|0;c[2411670]=al;c[2405812]=al;c[3529574]=ai+3505664;c[3530014]=ai+8224256;c[2414210]=ai+8230400;ai=0;while(1){if((ai|0)>=1024){am=0;break}an=9638528+(ai<<2)|0;if((c[an>>2]|0)==0){ak=45772;break}else{ai=ai+1|0}}do{if((ak|0)==45772){ai=gGq(4194304)|0;c[an>>2]=ai;if((ai|0)==0){am=0;break}gGz(ai|0,0,4194304);am=ai}}while(0);c[3529522]=am;if((R6(c[2388028]|0,0,2)|0)!=0){ao=1;i=e;return ao|0}if((R6((c[2388028]|0)+1|0,1,2)|0)!=0){ao=1;i=e;return ao|0}if((R6((c[2388028]|0)+262144|0,2,2)|0)!=0){ao=1;i=e;return ao|0}ai=c[2385834]|0;if((c[3542200]|0)==0){ao=1;i=e;return ao|0}al=af+108|0;c[al>>2]=0;ap=af+100|0;c[ap>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](af,3)|0;do{if((c[al>>2]|0)!=0){aq=c[ap>>2]|0;c[ah>>2]=9534384;ar=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ar&16383](ah,3,0)|0;if((aq|0)<1){ao=1;i=e;return ao|0}if((gzL(ai,0,3)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ai=c[3529522]|0;if((c[3542200]|0)==0){ao=1;i=e;return ao|0}ap=ad+108|0;c[ap>>2]=0;al=ad+100|0;c[al>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](ad,4)|0;do{if((c[ap>>2]|0)!=0){aq=c[al>>2]|0;c[ae>>2]=9534384;ar=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ar&16383](ae,4,0)|0;if((aq|0)<1){ao=1;i=e;return ao|0}if((gzL(ai,0,4)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ai=(c[3529522]|0)+262144|0;if((c[3542200]|0)==0){ao=1;i=e;return ao|0}al=ab+108|0;c[al>>2]=0;ap=ab+100|0;c[ap>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](ab,5)|0;do{if((c[al>>2]|0)!=0){aq=c[ap>>2]|0;c[ac>>2]=9534384;ar=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ar&16383](ac,5,0)|0;if((aq|0)<1){ao=1;i=e;return ao|0}if((gzL(ai,0,5)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ai=(c[3529522]|0)+524288|0;if((c[3542200]|0)==0){ao=1;i=e;return ao|0}ap=$+108|0;c[ap>>2]=0;al=$+100|0;c[al>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383]($,6)|0;do{if((c[ap>>2]|0)!=0){aq=c[al>>2]|0;c[aa>>2]=9534384;ar=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ar&16383](aa,6,0)|0;if((aq|0)<1){ao=1;i=e;return ao|0}if((gzL(ai,0,6)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ai=(c[3529522]|0)+786432|0;if((c[3542200]|0)==0){ao=1;i=e;return ao|0}al=Z+108|0;c[al>>2]=0;ap=Z+100|0;c[ap>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](Z,7)|0;do{if((c[al>>2]|0)!=0){aq=c[ap>>2]|0;c[_>>2]=9534384;ar=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ar&16383](_,7,0)|0;if((aq|0)<1){ao=1;i=e;return ao|0}if((gzL(ai,0,7)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ai=c[3529522]|0;ap=c[2405812]|0;al=0;do{aq=al<<8;gGz(ap+aq|0,0,256);ar=0;do{as=1<<3-ar;at=(c[611056+(ar<<2)>>2]|0)+aq|0;au=0;do{av=at+(c[609008+(au<<2)>>2]|0)|0;aw=(au<<4)+aq|0;ax=0;do{ay=av+(c[597864+(ax<<2)>>2]|0)|0;if(((d[ai+((ay|0)/8|0)|0]|0)&128>>>((ay&7)>>>0)|0)!=0){ay=ap+(aw+ax)|0;a[ay]=(d[ay]|0|as)&255}ax=ax+1|0;}while((ax|0)<16);au=au+1|0;}while((au|0)<16);ar=ar+1|0;}while((ar|0)<4);al=al+1|0;}while((al|0)<8192);gGz(ai|0,0,4194304);if((c[3542200]|0)==0){ao=1;i=e;return ao|0}al=X+108|0;c[al>>2]=0;ap=X+100|0;c[ap>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](X,8)|0;do{if((c[al>>2]|0)!=0){ar=c[ap>>2]|0;c[Y>>2]=9534384;aq=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aq&16383](Y,8,0)|0;if((ar|0)<1){ao=1;i=e;return ao|0}if((gzL(ai,0,8)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ai=(c[3529522]|0)+131072|0;if((c[3542200]|0)==0){ao=1;i=e;return ao|0}ap=V+108|0;c[ap>>2]=0;al=V+100|0;c[al>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](V,9)|0;do{if((c[ap>>2]|0)!=0){ar=c[al>>2]|0;c[W>>2]=9534384;aq=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aq&16383](W,9,0)|0;if((ar|0)<1){ao=1;i=e;return ao|0}if((gzL(ai,0,9)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ai=(c[3529522]|0)+262144|0;if((c[3542200]|0)==0){ao=1;i=e;return ao|0}al=T+108|0;c[al>>2]=0;ap=T+100|0;c[ap>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](T,10)|0;do{if((c[al>>2]|0)!=0){ar=c[ap>>2]|0;c[U>>2]=9534384;aq=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aq&16383](U,10,0)|0;if((ar|0)<1){ao=1;i=e;return ao|0}if((gzL(ai,0,10)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ai=(c[3529522]|0)+393216|0;if((c[3542200]|0)==0){ao=1;i=e;return ao|0}ap=R+108|0;c[ap>>2]=0;al=R+100|0;c[al>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](R,11)|0;do{if((c[ap>>2]|0)!=0){ar=c[al>>2]|0;c[S>>2]=9534384;aq=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aq&16383](S,11,0)|0;if((ar|0)<1){ao=1;i=e;return ao|0}if((gzL(ai,0,11)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ai=(c[3529522]|0)+524288|0;if((c[3542200]|0)==0){ao=1;i=e;return ao|0}al=P+108|0;c[al>>2]=0;ap=P+100|0;c[ap>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](P,12)|0;do{if((c[al>>2]|0)!=0){ar=c[ap>>2]|0;c[Q>>2]=9534384;aq=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aq&16383](Q,12,0)|0;if((ar|0)<1){ao=1;i=e;return ao|0}if((gzL(ai,0,12)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ai=(c[3529522]|0)+1048576|0;if((c[3542200]|0)==0){ao=1;i=e;return ao|0}ap=N+108|0;c[ap>>2]=0;al=N+100|0;c[al>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](N,13)|0;do{if((c[ap>>2]|0)!=0){ar=c[al>>2]|0;c[O>>2]=9534384;aq=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aq&16383](O,13,0)|0;if((ar|0)<1){ao=1;i=e;return ao|0}if((gzL(ai,0,13)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ai=(c[3529522]|0)+1179648|0;if((c[3542200]|0)==0){ao=1;i=e;return ao|0}al=L+108|0;c[al>>2]=0;ap=L+100|0;c[ap>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](L,14)|0;do{if((c[al>>2]|0)!=0){ar=c[ap>>2]|0;c[M>>2]=9534384;aq=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aq&16383](M,14,0)|0;if((ar|0)<1){ao=1;i=e;return ao|0}if((gzL(ai,0,14)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ai=(c[3529522]|0)+1310720|0;if((c[3542200]|0)==0){ao=1;i=e;return ao|0}ap=J+108|0;c[ap>>2]=0;al=J+100|0;c[al>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](J,15)|0;do{if((c[ap>>2]|0)!=0){ar=c[al>>2]|0;c[K>>2]=9534384;aq=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aq&16383](K,15,0)|0;if((ar|0)<1){ao=1;i=e;return ao|0}if((gzL(ai,0,15)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ai=(c[3529522]|0)+1441792|0;if((c[3542200]|0)==0){ao=1;i=e;return ao|0}al=H+108|0;c[al>>2]=0;ap=H+100|0;c[ap>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](H,16)|0;do{if((c[al>>2]|0)!=0){ar=c[ap>>2]|0;c[I>>2]=9534384;aq=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aq&16383](I,16,0)|0;if((ar|0)<1){ao=1;i=e;return ao|0}if((gzL(ai,0,16)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ai=(c[3529522]|0)+1572864|0;if((c[3542200]|0)==0){ao=1;i=e;return ao|0}ap=F+108|0;c[ap>>2]=0;al=F+100|0;c[al>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](F,17)|0;do{if((c[ap>>2]|0)!=0){ar=c[al>>2]|0;c[G>>2]=9534384;aq=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aq&16383](G,17,0)|0;if((ar|0)<1){ao=1;i=e;return ao|0}if((gzL(ai,0,17)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ai=(c[3529522]|0)+2097152|0;if((c[3542200]|0)==0){ao=1;i=e;return ao|0}al=D+108|0;c[al>>2]=0;ap=D+100|0;c[ap>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](D,18)|0;do{if((c[al>>2]|0)!=0){ar=c[ap>>2]|0;c[E>>2]=9534384;aq=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aq&16383](E,18,0)|0;if((ar|0)<1){ao=1;i=e;return ao|0}if((gzL(ai,0,18)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ai=(c[3529522]|0)+2228224|0;if((c[3542200]|0)==0){ao=1;i=e;return ao|0}ap=B+108|0;c[ap>>2]=0;al=B+100|0;c[al>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](B,19)|0;do{if((c[ap>>2]|0)!=0){ar=c[al>>2]|0;c[C>>2]=9534384;aq=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aq&16383](C,19,0)|0;if((ar|0)<1){ao=1;i=e;return ao|0}if((gzL(ai,0,19)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ai=(c[3529522]|0)+2359296|0;if((c[3542200]|0)==0){ao=1;i=e;return ao|0}al=z+108|0;c[al>>2]=0;ap=z+100|0;c[ap>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,20)|0;do{if((c[al>>2]|0)!=0){ar=c[ap>>2]|0;c[A>>2]=9534384;aq=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aq&16383](A,20,0)|0;if((ar|0)<1){ao=1;i=e;return ao|0}if((gzL(ai,0,20)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ai=(c[3529522]|0)+2490368|0;if((c[3542200]|0)==0){ao=1;i=e;return ao|0}ap=x+108|0;c[ap>>2]=0;al=x+100|0;c[al>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,21)|0;do{if((c[ap>>2]|0)!=0){ar=c[al>>2]|0;c[y>>2]=9534384;aq=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aq&16383](y,21,0)|0;if((ar|0)<1){ao=1;i=e;return ao|0}if((gzL(ai,0,21)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ai=(c[3529522]|0)+2621440|0;if((c[3542200]|0)==0){ao=1;i=e;return ao|0}al=v+108|0;c[al>>2]=0;ap=v+100|0;c[ap>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,22)|0;do{if((c[al>>2]|0)!=0){ar=c[ap>>2]|0;c[w>>2]=9534384;aq=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aq&16383](w,22,0)|0;if((ar|0)<1){ao=1;i=e;return ao|0}if((gzL(ai,0,22)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ai=(c[3529522]|0)+3145728|0;if((c[3542200]|0)==0){ao=1;i=e;return ao|0}ap=t+108|0;c[ap>>2]=0;al=t+100|0;c[al>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,23)|0;do{if((c[ap>>2]|0)!=0){ar=c[al>>2]|0;c[u>>2]=9534384;aq=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aq&16383](u,23,0)|0;if((ar|0)<1){ao=1;i=e;return ao|0}if((gzL(ai,0,23)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ai=(c[3529522]|0)+3276800|0;if((c[3542200]|0)==0){ao=1;i=e;return ao|0}al=r+108|0;c[al>>2]=0;ap=r+100|0;c[ap>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,24)|0;do{if((c[al>>2]|0)!=0){ar=c[ap>>2]|0;c[s>>2]=9534384;aq=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aq&16383](s,24,0)|0;if((ar|0)<1){ao=1;i=e;return ao|0}if((gzL(ai,0,24)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ai=(c[3529522]|0)+3407872|0;if((c[3542200]|0)==0){ao=1;i=e;return ao|0}ap=p+108|0;c[ap>>2]=0;al=p+100|0;c[al>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,25)|0;do{if((c[ap>>2]|0)!=0){ar=c[al>>2]|0;c[q>>2]=9534384;aq=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aq&16383](q,25,0)|0;if((ar|0)<1){ao=1;i=e;return ao|0}if((gzL(ai,0,25)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ai=(c[3529522]|0)+3538944|0;if((c[3542200]|0)==0){ao=1;i=e;return ao|0}al=n+108|0;c[al>>2]=0;ap=n+100|0;c[ap>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,26)|0;do{if((c[al>>2]|0)!=0){ar=c[ap>>2]|0;c[o>>2]=9534384;aq=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aq&16383](o,26,0)|0;if((ar|0)<1){ao=1;i=e;return ao|0}if((gzL(ai,0,26)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ai=(c[3529522]|0)+3670016|0;if((c[3542200]|0)==0){ao=1;i=e;return ao|0}ap=l+108|0;c[ap>>2]=0;al=l+100|0;c[al>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,27)|0;do{if((c[ap>>2]|0)!=0){ar=c[al>>2]|0;c[m>>2]=9534384;aq=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aq&16383](m,27,0)|0;if((ar|0)<1){ao=1;i=e;return ao|0}if((gzL(ai,0,27)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ai=c[3529522]|0;al=c[3529574]|0;ap=0;do{ar=ap<<8;gGz(al+ar|0,0,256);aq=0;do{au=1<<3-aq;as=(c[611552+(aq<<2)>>2]|0)+ar|0;at=0;do{ax=as+(c[609008+(at<<2)>>2]|0)|0;aw=(at<<4)+ar|0;av=0;do{ay=ax+(c[597864+(av<<2)>>2]|0)|0;if(((d[ai+((ay|0)/8|0)|0]|0)&128>>>((ay&7)>>>0)|0)!=0){ay=al+(aw+av)|0;a[ay]=(d[ay]|0|au)&255}av=av+1|0;}while((av|0)<16);at=at+1|0;}while((at|0)<16);aq=aq+1|0;}while((aq|0)<4);ap=ap+1|0;}while((ap|0)<18432);ap=c[2433468]|0;if((c[3542200]|0)==0){ao=1;i=e;return ao|0}al=j+108|0;c[al>>2]=0;ai=j+100|0;c[ai>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,28)|0;do{if((c[al>>2]|0)!=0){aq=c[ai>>2]|0;c[k>>2]=9534384;ar=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ar&16383](k,28,0)|0;if((aq|0)<1){ao=1;i=e;return ao|0}if((gzL(ap,0,28)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ap=(c[2433468]|0)+262144|0;if((c[3542200]|0)==0){ao=1;i=e;return ao|0}ai=f+108|0;c[ai>>2]=0;al=f+100|0;c[al>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,29)|0;do{if((c[ai>>2]|0)!=0){aq=c[al>>2]|0;c[g>>2]=9534384;ar=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ar&16383](g,29,0)|0;if((aq|0)<1){ao=1;i=e;return ao|0}if((gzL(ap,0,29)|0)==0){break}else{ao=1}i=e;return ao|0}}while(0);ap=c[3541206]|0;al=c[2433468]|0;gGC(ap|0,al|0,262144)|0;al=c[3529522]|0;ap=0;while(1){if((ap|0)>=1024){break}az=9638528+(ap<<2)|0;if((c[az>>2]|0)==(al|0)){ak=45908;break}else{ap=ap+1|0}}if((ak|0)==45908){gGr(al);c[az>>2]=0}c[3529522]=0;fxU(0,425984);if((c[2394]|0)==0){aA=c[2112932]|0}else{c[2394]=0;ap=c[3532596]|0;c[2112932]=ap;ai=c[3532592]|0;if((ai|0)!=0){gGC(9104152,ai|0,280)|0}c[2113054]=c[2113060];aA=ap}ap=c[2388028]|0;ai=aA|0;aq=0;while(1){ar=ap+aq|0;c[ai>>2]=ar;c[ai+131072>>2]=ar;ar=aq+1024|0;if(ar>>>0>524287){break}else{ai=ai+4|0;aq=ar}}aq=c[2439940]|0;c[aA+2048>>2]=aq;c[aA+67584>>2]=aq;c[aA+133120>>2]=aq;ai=aq+1024|0;c[aA+2052>>2]=ai;c[aA+67588>>2]=ai;c[aA+133124>>2]=ai;ai=aq+2048|0;c[aA+2056>>2]=ai;c[aA+67592>>2]=ai;c[aA+133128>>2]=ai;ai=aq+3072|0;c[aA+2060>>2]=ai;c[aA+67596>>2]=ai;c[aA+133132>>2]=ai;ai=c[2443414]|0;c[aA+2064>>2]=ai;c[aA+67600>>2]=ai;c[aA+133136>>2]=ai;aq=ai+1024|0;c[aA+2068>>2]=aq;c[aA+67604>>2]=aq;c[aA+133140>>2]=aq;aq=ai+2048|0;c[aA+2072>>2]=aq;c[aA+67608>>2]=aq;c[aA+133144>>2]=aq;aq=ai+3072|0;c[aA+2076>>2]=aq;c[aA+67612>>2]=aq;c[aA+133148>>2]=aq;aq=c[2439958]|0;c[aA+2080>>2]=aq;c[aA+67616>>2]=aq;c[aA+133152>>2]=aq;ai=aq+1024|0;c[aA+2084>>2]=ai;c[aA+67620>>2]=ai;c[aA+133156>>2]=ai;ai=c[2439614]|0;c[aA+4096>>2]=ai;c[aA+69632>>2]=ai;c[aA+135168>>2]=ai;aq=ai+1024|0;c[aA+4100>>2]=aq;c[aA+69636>>2]=aq;c[aA+135172>>2]=aq;aq=c[2388048]|0;c[aA+7168>>2]=aq;c[aA+72704>>2]=aq;c[aA+138240>>2]=aq;ai=aq+1024|0;c[aA+7172>>2]=ai;c[aA+72708>>2]=ai;c[aA+138244>>2]=ai;ai=aq+2048|0;c[aA+7176>>2]=ai;c[aA+72712>>2]=ai;c[aA+138248>>2]=ai;ai=aq+3072|0;c[aA+7180>>2]=ai;c[aA+72716>>2]=ai;c[aA+138252>>2]=ai;ai=aq+4096|0;c[aA+7184>>2]=ai;c[aA+72720>>2]=ai;c[aA+138256>>2]=ai;ai=aq+5120|0;c[aA+7188>>2]=ai;c[aA+72724>>2]=ai;c[aA+138260>>2]=ai;ai=aq+6144|0;c[aA+7192>>2]=ai;c[aA+72728>>2]=ai;c[aA+138264>>2]=ai;ai=aq+7168|0;c[aA+7196>>2]=ai;c[aA+72732>>2]=ai;c[aA+138268>>2]=ai;ai=aq+8192|0;c[aA+7200>>2]=ai;c[aA+72736>>2]=ai;c[aA+138272>>2]=ai;ai=aq+9216|0;c[aA+7204>>2]=ai;c[aA+72740>>2]=ai;c[aA+138276>>2]=ai;ai=aq+10240|0;c[aA+7208>>2]=ai;c[aA+72744>>2]=ai;c[aA+138280>>2]=ai;ai=aq+11264|0;c[aA+7212>>2]=ai;c[aA+72748>>2]=ai;c[aA+138284>>2]=ai;ai=aq+12288|0;c[aA+7216>>2]=ai;c[aA+72752>>2]=ai;c[aA+138288>>2]=ai;ai=aq+13312|0;c[aA+7220>>2]=ai;c[aA+72756>>2]=ai;c[aA+138292>>2]=ai;ai=aq+14336|0;c[aA+7224>>2]=ai;c[aA+72760>>2]=ai;c[aA+138296>>2]=ai;ai=aq+15360|0;c[aA+7228>>2]=ai;c[aA+72764>>2]=ai;c[aA+138300>>2]=ai;c[aA+196688>>2]=1004;c[aA+196728>>2]=3368;c[aA+196608>>2]=2882;c[aA+196648>>2]=3390;ai=c[3532592]|0;if((ai|0)!=0){gGC(ai|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);ai=c[2439330]|0;aq=(ai|0)==0;if(!aq){ap=ai;gGC(9706056,ap|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];ap=c[3528484]|0;c[2076596]=ap;al=c[2417276]|0;c[3541536]=al;c[1836236]=0;c[ai+4180>>2]=346;c[ai+4184>>2]=1674;ar=c[2385834]|0;at=0;au=0;while(1){c[ai+76+(au<<2)>>2]=ar+(au<<8);as=at+1&65535;if((as&65535)>191){aB=0;aC=0;break}else{at=as;au=as&65535}}while(1){au=ar+(aC<<8)|0;c[ai+76+(aC+512<<2)>>2]=au;c[ai+76+(aC+768<<2)>>2]=au;au=aB+1&65535;if((au&65535)>191){break}else{aB=au;aC=au&65535}}ar=c[2385852]|0;c[ai+844>>2]=ar;au=ar+256|0;c[ai+848>>2]=au;at=ar+512|0;c[ai+852>>2]=at;as=ar+768|0;c[ai+856>>2]=as;av=ar+1024|0;c[ai+860>>2]=av;aw=ar+1280|0;c[ai+864>>2]=aw;ax=ar+1536|0;c[ai+868>>2]=ax;ay=ar+1792|0;c[ai+872>>2]=ay;c[ai+1868>>2]=ar;c[ai+1872>>2]=au;c[ai+1876>>2]=at;c[ai+1880>>2]=as;c[ai+1884>>2]=av;c[ai+1888>>2]=aw;c[ai+1892>>2]=ax;c[ai+1896>>2]=ay;c[ai+2892>>2]=ar;c[ai+3916>>2]=ar;c[ai+2896>>2]=au;c[ai+3920>>2]=au;c[ai+2900>>2]=at;c[ai+3924>>2]=at;c[ai+2904>>2]=as;c[ai+3928>>2]=as;c[ai+2908>>2]=av;c[ai+3932>>2]=av;c[ai+2912>>2]=aw;c[ai+3936>>2]=aw;c[ai+2916>>2]=ax;c[ai+3940>>2]=ax;c[ai+2920>>2]=ay;c[ai+3944>>2]=ay;if(!aq){ay=ai;gGC(ay|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=ap;c[2417276]=al;c[1836236]=-1;ay=a[9680]|0;ax=ay?32e3:0;if(ay){if(a[9624]|0){ay=ax*3|0;aw=55930;while(1){if((aw|0)>(ay|0)){aw=aw>>1}else{aD=1222;aE=aw;break}}}else{aD=2462;aE=ax}c[2429380]=aE;c[3542124]=aD;mw(3579545,aE);aw=gGq(262144)|0;c[2406684]=aw;gGz(aw|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(3579545,11025)}c[(c[3531464]|0)+44344>>2]=1148;h[745421]=.5;c[2436794]=1;h[745420]=.5;c[2436792]=2;Ux(0,7575,1);c[2407030]=384;c[2407068]=3;c[2443626]=5156;aw=c[642608+(c[2436]<<2)>>2]|0;ay=c[aw+128>>2]|0;if((c[aw+52>>2]&4|0)==0){c[2113068]=ay;al=c[aw+132>>2]|0;c[2113070]=al;c[2443814]=ay;c[2440436]=al;aF=ay;aG=al}else{c[2113070]=ay;al=c[aw+132>>2]|0;c[2113068]=al;c[2440436]=ay;c[2443814]=al;aF=al;aG=ay}ay=ag(aF<<1,aG)|0;al=gGq(ay)|0;c[2112926]=al;if((al|0)!=0){gGz(al|0,0,ay|0)}if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];ay=c[3532592]|0;if((ay|0)!=0){gGC(9104152,ay|0,280)|0}c[2113054]=c[2113060]}RI();ay=c[2394]|0;al=c[14130368+(ay<<2)>>2]|0;if((al|0)!=0){gGC(al|0,9104152,280)|0}c[8452240+(ay<<2)>>2]=c[2113054];c[2394]=-1;ay=c[2439330]|0;al=(ay|0)==0;if(!al){aw=ay;gGC(9706056,aw|0,76)|0}aw=c[2438118]|0;c[2433530]=aw;ap=c[3528484]|0;c[2076596]=ap;ai=c[2417276]|0;c[3541536]=ai;c[1836236]=0;gGz(9706056,0,76);if(!al){al=ay;gGC(al|0,9706056,76)|0}c[2438118]=aw;c[3528484]=ap;c[2417276]=ai;c[1836236]=-1;mx(0);c[2113156]=0;a[9628264]=0;c[2407033]=0;ai=c[3541206]|0;c[3541190]=ai;c[3541198]=ai;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=ai+256;c[3541199]=ai+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=ai+512;c[3541200]=ai+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=ai+768;c[3541201]=ai+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;b[4879940]=0;b[4887196]=0;b[4887172]=0;b[4887140]=0;b[4887124]=0;b[4814252]=0;a[9758168]=0;a[14121008]=0;a[9545152]=0;ao=0;i=e;return ao|0}}while(0);c[2426726]=0;ao=1;i=e;return ao|0}function d7U(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6387148+(b*112|0)>>2];c[a+104>>2]=c[6387152+(b*112|0)>>2];c[a+108>>2]=c[6387156+(b*112|0)>>2];d=0;return d|0}function d7V(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=6387048+(b*112|0);e=0;return e|0}function d7W(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>40){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6389176+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function d7X(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0;e=i;i=i+5040|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;B=e+1200|0;C=e+1312|0;D=e+1320|0;E=e+1432|0;F=e+1440|0;G=e+1552|0;H=e+1560|0;I=e+1672|0;J=e+1680|0;K=e+1792|0;L=e+1800|0;M=e+1912|0;N=e+1920|0;O=e+2032|0;P=e+2040|0;Q=e+2152|0;R=e+2160|0;S=e+2272|0;T=e+2280|0;U=e+2392|0;V=e+2400|0;W=e+2512|0;X=e+2520|0;Y=e+2632|0;Z=e+2640|0;_=e+2752|0;$=e+2760|0;aa=e+2872|0;ab=e+2880|0;ac=e+2992|0;ad=e+3e3|0;ae=e+3112|0;af=e+3120|0;ah=e+3232|0;ai=e+3240|0;aj=e+3352|0;ak=e+3360|0;al=e+3472|0;am=e+3480|0;an=e+3592|0;ao=e+3600|0;ap=e+3712|0;aq=e+3720|0;ar=e+3832|0;as=e+3840|0;at=e+3952|0;au=e+3960|0;av=e+4072|0;aw=e+4080|0;ax=e+4192|0;ay=e+4200|0;az=e+4312|0;aA=e+4320|0;aB=e+4432|0;aC=e+4440|0;aD=e+4552|0;aE=e+4560|0;aF=e+4672|0;aG=e+4680|0;aH=e+4792|0;aI=e+4800|0;aJ=e+4912|0;aK=e+4920|0;aL=e+5032|0;c[2424]=5700;c[2426726]=0;c[2388028]=0;c[2385834]=524288;c[3541206]=589824;c[2433468]=851968;c[2405660]=1376256;c[2388048]=1376256;c[2385852]=1394688;c[2439940]=1396736;c[2443414]=1400832;c[2439958]=1404928;c[2439614]=1406976;c[2411670]=1408512;c[2405812]=1408512;c[3529574]=3505664;c[3530014]=8224256;aM=0;while(1){if((aM|0)>=1024){break}aN=9638528+(aM<<2)|0;if((c[aN>>2]|0)==0){aO=46056;break}else{aM=aM+1|0}}do{if((aO|0)==46056){aM=gGq(8230400)|0;c[aN>>2]=aM;if((aM|0)==0){break}c[2426726]=aM;gGz(aM|0,0,8230400);c[2388028]=aM;c[2385834]=aM+524288;c[3541206]=aM+589824;c[2433468]=aM+851968;aP=aM+1376256|0;c[2405660]=aP;c[2388048]=aP;c[2385852]=aM+1394688;c[2439940]=aM+1396736;c[2443414]=aM+1400832;c[2439958]=aM+1404928;c[2439614]=aM+1406976;aP=aM+1408512|0;c[2411670]=aP;c[2405812]=aP;c[3529574]=aM+3505664;c[3530014]=aM+8224256;c[2414210]=aM+8230400;aM=0;while(1){if((aM|0)>=1024){aQ=0;break}aR=9638528+(aM<<2)|0;if((c[aR>>2]|0)==0){aO=46061;break}else{aM=aM+1|0}}do{if((aO|0)==46061){aM=gGq(4194304)|0;c[aR>>2]=aM;if((aM|0)==0){aQ=0;break}gGz(aM|0,0,4194304);aQ=aM}}while(0);c[3529522]=aQ;if((R6(c[2388028]|0,0,2)|0)!=0){aS=1;i=e;return aS|0}if((R6((c[2388028]|0)+1|0,1,2)|0)!=0){aS=1;i=e;return aS|0}if((R6((c[2388028]|0)+262144|0,2,2)|0)!=0){aS=1;i=e;return aS|0}aM=c[2385834]|0;if((c[3542200]|0)==0){aS=1;i=e;return aS|0}aP=aK+108|0;c[aP>>2]=0;aT=aK+100|0;c[aT>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](aK,3)|0;do{if((c[aP>>2]|0)!=0){aU=c[aT>>2]|0;c[aL>>2]=9534384;aV=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aV&16383](aL,3,0)|0;if((aU|0)<1){aS=1;i=e;return aS|0}if((gzL(aM,0,3)|0)==0){break}else{aS=1}i=e;return aS|0}}while(0);aM=c[3529522]|0;if((c[3542200]|0)==0){aS=1;i=e;return aS|0}aT=aI+108|0;c[aT>>2]=0;aP=aI+100|0;c[aP>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](aI,4)|0;do{if((c[aT>>2]|0)!=0){aU=c[aP>>2]|0;c[aJ>>2]=9534384;aV=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aV&16383](aJ,4,0)|0;if((aU|0)<1){aS=1;i=e;return aS|0}if((gzL(aM,0,4)|0)==0){break}else{aS=1}i=e;return aS|0}}while(0);aM=(c[3529522]|0)+262144|0;if((c[3542200]|0)==0){aS=1;i=e;return aS|0}aP=aG+108|0;c[aP>>2]=0;aT=aG+100|0;c[aT>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](aG,5)|0;do{if((c[aP>>2]|0)!=0){aU=c[aT>>2]|0;c[aH>>2]=9534384;aV=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aV&16383](aH,5,0)|0;if((aU|0)<1){aS=1;i=e;return aS|0}if((gzL(aM,0,5)|0)==0){break}else{aS=1}i=e;return aS|0}}while(0);aM=(c[3529522]|0)+524288|0;if((c[3542200]|0)==0){aS=1;i=e;return aS|0}aT=aE+108|0;c[aT>>2]=0;aP=aE+100|0;c[aP>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](aE,6)|0;do{if((c[aT>>2]|0)!=0){aU=c[aP>>2]|0;c[aF>>2]=9534384;aV=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aV&16383](aF,6,0)|0;if((aU|0)<1){aS=1;i=e;return aS|0}if((gzL(aM,0,6)|0)==0){break}else{aS=1}i=e;return aS|0}}while(0);aM=(c[3529522]|0)+786432|0;if((c[3542200]|0)==0){aS=1;i=e;return aS|0}aP=aC+108|0;c[aP>>2]=0;aT=aC+100|0;c[aT>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](aC,7)|0;do{if((c[aP>>2]|0)!=0){aU=c[aT>>2]|0;c[aD>>2]=9534384;aV=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aV&16383](aD,7,0)|0;if((aU|0)<1){aS=1;i=e;return aS|0}if((gzL(aM,0,7)|0)==0){break}else{aS=1}i=e;return aS|0}}while(0);aM=c[642608+(c[2436]<<2)>>2]|0;do{if((fa(c[aM>>2]|0,449792)|0)==0){aT=(c[3529522]|0)+1048576|0;if((c[3542200]|0)==0){aS=1;i=e;return aS|0}aP=aA+108|0;c[aP>>2]=0;aU=aA+100|0;c[aU>>2]=0;aV=c[aM+76>>2]|0;gA[aV&16383](aA,8)|0;do{if((c[aP>>2]|0)!=0){aV=c[aU>>2]|0;c[aB>>2]=9534384;aW=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aW&16383](aB,8,0)|0;if((aV|0)<1){aS=1;i=e;return aS|0}if((gzL(aT,0,8)|0)==0){break}else{aS=1}i=e;return aS|0}}while(0);aT=(c[3529522]|0)+1310720|0;if((c[3542200]|0)==0){aS=1;i=e;return aS|0}aU=ay+108|0;c[aU>>2]=0;aP=ay+100|0;c[aP>>2]=0;aV=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aV&16383](ay,9)|0;do{if((c[aU>>2]|0)!=0){aV=c[aP>>2]|0;c[az>>2]=9534384;aW=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aW&16383](az,9,0)|0;if((aV|0)<1){aS=1;i=e;return aS|0}if((gzL(aT,0,9)|0)==0){break}else{aS=1}i=e;return aS|0}}while(0);aT=(c[3529522]|0)+1572864|0;if((c[3542200]|0)==0){aS=1;i=e;return aS|0}aP=aw+108|0;c[aP>>2]=0;aU=aw+100|0;c[aU>>2]=0;aV=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aV&16383](aw,10)|0;do{if((c[aP>>2]|0)!=0){aV=c[aU>>2]|0;c[ax>>2]=9534384;aW=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aW&16383](ax,10,0)|0;if((aV|0)<1){aS=1;i=e;return aS|0}if((gzL(aT,0,10)|0)==0){break}else{aS=1}i=e;return aS|0}}while(0);aT=(c[3529522]|0)+1835008|0;if((c[3542200]|0)==0){aS=1;i=e;return aS|0}aU=au+108|0;c[aU>>2]=0;aP=au+100|0;c[aP>>2]=0;aV=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aV&16383](au,11)|0;if((c[aU>>2]|0)==0){break}aU=c[aP>>2]|0;c[av>>2]=9534384;aP=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aP&16383](av,11,0)|0;if((aU|0)<1){aS=1;i=e;return aS|0}if((gzL(aT,0,11)|0)==0){break}else{aS=1}i=e;return aS|0}}while(0);aM=c[3529522]|0;aT=c[2405812]|0;aU=0;do{aP=aU<<8;gGz(aT+aP|0,0,256);aV=0;do{aW=1<<3-aV;aX=(c[611056+(aV<<2)>>2]|0)+aP|0;aY=0;do{aZ=aX+(c[609008+(aY<<2)>>2]|0)|0;a_=(aY<<4)+aP|0;a$=0;do{a0=aZ+(c[597864+(a$<<2)>>2]|0)|0;if(((d[aM+((a0|0)/8|0)|0]|0)&128>>>((a0&7)>>>0)|0)!=0){a0=aT+(a_+a$)|0;a[a0]=(d[a0]|0|aW)&255}a$=a$+1|0;}while((a$|0)<16);aY=aY+1|0;}while((aY|0)<16);aV=aV+1|0;}while((aV|0)<4);aU=aU+1|0;}while((aU|0)<8192);gGz(aM|0,0,4194304);aU=c[642608+(c[2436]<<2)>>2]|0;do{if((fa(c[aU>>2]|0,449792)|0)==0){if((c[3542200]|0)==0){aS=1;i=e;return aS|0}aT=as+108|0;c[aT>>2]=0;aV=as+100|0;c[aV>>2]=0;aP=c[aU+76>>2]|0;gA[aP&16383](as,12)|0;do{if((c[aT>>2]|0)!=0){aP=c[aV>>2]|0;c[at>>2]=9534384;aY=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aY&16383](at,12,0)|0;if((aP|0)<1){aS=1;i=e;return aS|0}if((gzL(aM,0,12)|0)==0){break}else{aS=1}i=e;return aS|0}}while(0);aV=(c[3529522]|0)+131072|0;if((c[3542200]|0)==0){aS=1;i=e;return aS|0}aT=aq+108|0;c[aT>>2]=0;aP=aq+100|0;c[aP>>2]=0;aY=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aY&16383](aq,13)|0;do{if((c[aT>>2]|0)!=0){aY=c[aP>>2]|0;c[ar>>2]=9534384;aW=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aW&16383](ar,13,0)|0;if((aY|0)<1){aS=1;i=e;return aS|0}if((gzL(aV,0,13)|0)==0){break}else{aS=1}i=e;return aS|0}}while(0);aV=(c[3529522]|0)+262144|0;if((c[3542200]|0)==0){aS=1;i=e;return aS|0}aP=ao+108|0;c[aP>>2]=0;aT=ao+100|0;c[aT>>2]=0;aY=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aY&16383](ao,14)|0;do{if((c[aP>>2]|0)!=0){aY=c[aT>>2]|0;c[ap>>2]=9534384;aW=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aW&16383](ap,14,0)|0;if((aY|0)<1){aS=1;i=e;return aS|0}if((gzL(aV,0,14)|0)==0){break}else{aS=1}i=e;return aS|0}}while(0);aV=(c[3529522]|0)+393216|0;if((c[3542200]|0)==0){aS=1;i=e;return aS|0}aT=am+108|0;c[aT>>2]=0;aP=am+100|0;c[aP>>2]=0;aY=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aY&16383](am,15)|0;do{if((c[aT>>2]|0)!=0){aY=c[aP>>2]|0;c[an>>2]=9534384;aW=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aW&16383](an,15,0)|0;if((aY|0)<1){aS=1;i=e;return aS|0}if((gzL(aV,0,15)|0)==0){break}else{aS=1}i=e;return aS|0}}while(0);aV=(c[3529522]|0)+524288|0;if((c[3542200]|0)==0){aS=1;i=e;return aS|0}aP=ak+108|0;c[aP>>2]=0;aT=ak+100|0;c[aT>>2]=0;aY=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aY&16383](ak,16)|0;do{if((c[aP>>2]|0)!=0){aY=c[aT>>2]|0;c[al>>2]=9534384;aW=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aW&16383](al,16,0)|0;if((aY|0)<1){aS=1;i=e;return aS|0}if((gzL(aV,0,16)|0)==0){break}else{aS=1}i=e;return aS|0}}while(0);aV=(c[3529522]|0)+1048576|0;if((c[3542200]|0)==0){aS=1;i=e;return aS|0}aT=ai+108|0;c[aT>>2]=0;aP=ai+100|0;c[aP>>2]=0;aY=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aY&16383](ai,17)|0;do{if((c[aT>>2]|0)!=0){aY=c[aP>>2]|0;c[aj>>2]=9534384;aW=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aW&16383](aj,17,0)|0;if((aY|0)<1){aS=1;i=e;return aS|0}if((gzL(aV,0,17)|0)==0){break}else{aS=1}i=e;return aS|0}}while(0);aV=(c[3529522]|0)+1179648|0;if((c[3542200]|0)==0){aS=1;i=e;return aS|0}aP=af+108|0;c[aP>>2]=0;aT=af+100|0;c[aT>>2]=0;aY=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aY&16383](af,18)|0;do{if((c[aP>>2]|0)!=0){aY=c[aT>>2]|0;c[ah>>2]=9534384;aW=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aW&16383](ah,18,0)|0;if((aY|0)<1){aS=1;i=e;return aS|0}if((gzL(aV,0,18)|0)==0){break}else{aS=1}i=e;return aS|0}}while(0);aV=(c[3529522]|0)+1310720|0;if((c[3542200]|0)==0){aS=1;i=e;return aS|0}aT=ad+108|0;c[aT>>2]=0;aP=ad+100|0;c[aP>>2]=0;aY=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aY&16383](ad,19)|0;do{if((c[aT>>2]|0)!=0){aY=c[aP>>2]|0;c[ae>>2]=9534384;aW=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aW&16383](ae,19,0)|0;if((aY|0)<1){aS=1;i=e;return aS|0}if((gzL(aV,0,19)|0)==0){break}else{aS=1}i=e;return aS|0}}while(0);aV=(c[3529522]|0)+1441792|0;if((c[3542200]|0)==0){aS=1;i=e;return aS|0}aP=ab+108|0;c[aP>>2]=0;aT=ab+100|0;c[aT>>2]=0;aY=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aY&16383](ab,20)|0;do{if((c[aP>>2]|0)!=0){aY=c[aT>>2]|0;c[ac>>2]=9534384;aW=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aW&16383](ac,20,0)|0;if((aY|0)<1){aS=1;i=e;return aS|0}if((gzL(aV,0,20)|0)==0){break}else{aS=1}i=e;return aS|0}}while(0);aV=(c[3529522]|0)+1572864|0;if((c[3542200]|0)==0){aS=1;i=e;return aS|0}aT=$+108|0;c[aT>>2]=0;aP=$+100|0;c[aP>>2]=0;aY=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aY&16383]($,21)|0;do{if((c[aT>>2]|0)!=0){aY=c[aP>>2]|0;c[aa>>2]=9534384;aW=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aW&16383](aa,21,0)|0;if((aY|0)<1){aS=1;i=e;return aS|0}if((gzL(aV,0,21)|0)==0){break}else{aS=1}i=e;return aS|0}}while(0);aV=(c[3529522]|0)+2097152|0;if((c[3542200]|0)==0){aS=1;i=e;return aS|0}aP=Z+108|0;c[aP>>2]=0;aT=Z+100|0;c[aT>>2]=0;aY=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aY&16383](Z,22)|0;do{if((c[aP>>2]|0)!=0){aY=c[aT>>2]|0;c[_>>2]=9534384;aW=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aW&16383](_,22,0)|0;if((aY|0)<1){aS=1;i=e;return aS|0}if((gzL(aV,0,22)|0)==0){break}else{aS=1}i=e;return aS|0}}while(0);aV=(c[3529522]|0)+2228224|0;if((c[3542200]|0)==0){aS=1;i=e;return aS|0}aT=X+108|0;c[aT>>2]=0;aP=X+100|0;c[aP>>2]=0;aY=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aY&16383](X,23)|0;do{if((c[aT>>2]|0)!=0){aY=c[aP>>2]|0;c[Y>>2]=9534384;aW=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aW&16383](Y,23,0)|0;if((aY|0)<1){aS=1;i=e;return aS|0}if((gzL(aV,0,23)|0)==0){break}else{aS=1}i=e;return aS|0}}while(0);aV=(c[3529522]|0)+2359296|0;if((c[3542200]|0)==0){aS=1;i=e;return aS|0}aP=V+108|0;c[aP>>2]=0;aT=V+100|0;c[aT>>2]=0;aY=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aY&16383](V,24)|0;do{if((c[aP>>2]|0)!=0){aY=c[aT>>2]|0;c[W>>2]=9534384;aW=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aW&16383](W,24,0)|0;if((aY|0)<1){aS=1;i=e;return aS|0}if((gzL(aV,0,24)|0)==0){break}else{aS=1}i=e;return aS|0}}while(0);aV=(c[3529522]|0)+2490368|0;if((c[3542200]|0)==0){aS=1;i=e;return aS|0}aT=T+108|0;c[aT>>2]=0;aP=T+100|0;c[aP>>2]=0;aY=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aY&16383](T,25)|0;do{if((c[aT>>2]|0)!=0){aY=c[aP>>2]|0;c[U>>2]=9534384;aW=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aW&16383](U,25,0)|0;if((aY|0)<1){aS=1;i=e;return aS|0}if((gzL(aV,0,25)|0)==0){break}else{aS=1}i=e;return aS|0}}while(0);aV=(c[3529522]|0)+2621440|0;if((c[3542200]|0)==0){aS=1;i=e;return aS|0}aP=R+108|0;c[aP>>2]=0;aT=R+100|0;c[aT>>2]=0;aY=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aY&16383](R,26)|0;do{if((c[aP>>2]|0)!=0){aY=c[aT>>2]|0;c[S>>2]=9534384;aW=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aW&16383](S,26,0)|0;if((aY|0)<1){aS=1;i=e;return aS|0}if((gzL(aV,0,26)|0)==0){break}else{aS=1}i=e;return aS|0}}while(0);aV=(c[3529522]|0)+3145728|0;if((c[3542200]|0)==0){aS=1;i=e;return aS|0}aT=P+108|0;c[aT>>2]=0;aP=P+100|0;c[aP>>2]=0;aY=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aY&16383](P,27)|0;do{if((c[aT>>2]|0)!=0){aY=c[aP>>2]|0;c[Q>>2]=9534384;aW=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aW&16383](Q,27,0)|0;if((aY|0)<1){aS=1;i=e;return aS|0}if((gzL(aV,0,27)|0)==0){break}else{aS=1}i=e;return aS|0}}while(0);aV=(c[3529522]|0)+3276800|0;if((c[3542200]|0)==0){aS=1;i=e;return aS|0}aP=N+108|0;c[aP>>2]=0;aT=N+100|0;c[aT>>2]=0;aY=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aY&16383](N,28)|0;do{if((c[aP>>2]|0)!=0){aY=c[aT>>2]|0;c[O>>2]=9534384;aW=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aW&16383](O,28,0)|0;if((aY|0)<1){aS=1;i=e;return aS|0}if((gzL(aV,0,28)|0)==0){break}else{aS=1}i=e;return aS|0}}while(0);aV=(c[3529522]|0)+3407872|0;if((c[3542200]|0)==0){aS=1;i=e;return aS|0}aT=L+108|0;c[aT>>2]=0;aP=L+100|0;c[aP>>2]=0;aY=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aY&16383](L,29)|0;do{if((c[aT>>2]|0)!=0){aY=c[aP>>2]|0;c[M>>2]=9534384;aW=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aW&16383](M,29,0)|0;if((aY|0)<1){aS=1;i=e;return aS|0}if((gzL(aV,0,29)|0)==0){break}else{aS=1}i=e;return aS|0}}while(0);aV=(c[3529522]|0)+3538944|0;if((c[3542200]|0)==0){aS=1;i=e;return aS|0}aP=J+108|0;c[aP>>2]=0;aT=J+100|0;c[aT>>2]=0;aY=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aY&16383](J,30)|0;do{if((c[aP>>2]|0)!=0){aY=c[aT>>2]|0;c[K>>2]=9534384;aW=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aW&16383](K,30,0)|0;if((aY|0)<1){aS=1;i=e;return aS|0}if((gzL(aV,0,30)|0)==0){break}else{aS=1}i=e;return aS|0}}while(0);aV=(c[3529522]|0)+3670016|0;if((c[3542200]|0)==0){aS=1;i=e;return aS|0}aT=H+108|0;c[aT>>2]=0;aP=H+100|0;c[aP>>2]=0;aY=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aY&16383](H,31)|0;if((c[aT>>2]|0)==0){break}aT=c[aP>>2]|0;c[I>>2]=9534384;aP=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aP&16383](I,31,0)|0;if((aT|0)<1){aS=1;i=e;return aS|0}if((gzL(aV,0,31)|0)==0){break}else{aS=1}i=e;return aS|0}else{if((c[3542200]|0)==0){aS=1;i=e;return aS|0}aV=F+108|0;c[aV>>2]=0;aT=F+100|0;c[aT>>2]=0;aP=c[aU+76>>2]|0;gA[aP&16383](F,8)|0;do{if((c[aV>>2]|0)!=0){aP=c[aT>>2]|0;c[G>>2]=9534384;aY=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aY&16383](G,8,0)|0;if((aP|0)<1){aS=1;i=e;return aS|0}if((gzL(aM,0,8)|0)==0){break}else{aS=1}i=e;return aS|0}}while(0);aT=(c[3529522]|0)+524288|0;if((c[3542200]|0)==0){aS=1;i=e;return aS|0}aV=D+108|0;c[aV>>2]=0;aP=D+100|0;c[aP>>2]=0;aY=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aY&16383](D,9)|0;do{if((c[aV>>2]|0)!=0){aY=c[aP>>2]|0;c[E>>2]=9534384;aW=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aW&16383](E,9,0)|0;if((aY|0)<1){aS=1;i=e;return aS|0}if((gzL(aT,0,9)|0)==0){break}else{aS=1}i=e;return aS|0}}while(0);aT=(c[3529522]|0)+1048576|0;if((c[3542200]|0)==0){aS=1;i=e;return aS|0}aP=B+108|0;c[aP>>2]=0;aV=B+100|0;c[aV>>2]=0;aY=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aY&16383](B,10)|0;do{if((c[aP>>2]|0)!=0){aY=c[aV>>2]|0;c[C>>2]=9534384;aW=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aW&16383](C,10,0)|0;if((aY|0)<1){aS=1;i=e;return aS|0}if((gzL(aT,0,10)|0)==0){break}else{aS=1}i=e;return aS|0}}while(0);aT=(c[3529522]|0)+1572864|0;if((c[3542200]|0)==0){aS=1;i=e;return aS|0}aV=z+108|0;c[aV>>2]=0;aP=z+100|0;c[aP>>2]=0;aY=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aY&16383](z,11)|0;do{if((c[aV>>2]|0)!=0){aY=c[aP>>2]|0;c[A>>2]=9534384;aW=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aW&16383](A,11,0)|0;if((aY|0)<1){aS=1;i=e;return aS|0}if((gzL(aT,0,11)|0)==0){break}else{aS=1}i=e;return aS|0}}while(0);aT=(c[3529522]|0)+2097152|0;if((c[3542200]|0)==0){aS=1;i=e;return aS|0}aP=x+108|0;c[aP>>2]=0;aV=x+100|0;c[aV>>2]=0;aY=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aY&16383](x,12)|0;do{if((c[aP>>2]|0)!=0){aY=c[aV>>2]|0;c[y>>2]=9534384;aW=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aW&16383](y,12,0)|0;if((aY|0)<1){aS=1;i=e;return aS|0}if((gzL(aT,0,12)|0)==0){break}else{aS=1}i=e;return aS|0}}while(0);aT=(c[3529522]|0)+2621440|0;if((c[3542200]|0)==0){aS=1;i=e;return aS|0}aV=v+108|0;c[aV>>2]=0;aP=v+100|0;c[aP>>2]=0;aY=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aY&16383](v,13)|0;do{if((c[aV>>2]|0)!=0){aY=c[aP>>2]|0;c[w>>2]=9534384;aW=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aW&16383](w,13,0)|0;if((aY|0)<1){aS=1;i=e;return aS|0}if((gzL(aT,0,13)|0)==0){break}else{aS=1}i=e;return aS|0}}while(0);aT=(c[3529522]|0)+3145728|0;if((c[3542200]|0)==0){aS=1;i=e;return aS|0}aP=t+108|0;c[aP>>2]=0;aV=t+100|0;c[aV>>2]=0;aY=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aY&16383](t,14)|0;do{if((c[aP>>2]|0)!=0){aY=c[aV>>2]|0;c[u>>2]=9534384;aW=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aW&16383](u,14,0)|0;if((aY|0)<1){aS=1;i=e;return aS|0}if((gzL(aT,0,14)|0)==0){break}else{aS=1}i=e;return aS|0}}while(0);aT=(c[3529522]|0)+3670016|0;if((c[3542200]|0)==0){aS=1;i=e;return aS|0}aV=r+108|0;c[aV>>2]=0;aP=r+100|0;c[aP>>2]=0;aY=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aY&16383](r,15)|0;if((c[aV>>2]|0)==0){break}aV=c[aP>>2]|0;c[s>>2]=9534384;aP=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aP&16383](s,15,0)|0;if((aV|0)<1){aS=1;i=e;return aS|0}if((gzL(aT,0,15)|0)==0){break}else{aS=1}i=e;return aS|0}}while(0);aM=c[3529522]|0;aU=c[3529574]|0;aT=0;do{aV=aT<<8;gGz(aU+aV|0,0,256);aP=0;do{aY=1<<3-aP;aW=(c[611552+(aP<<2)>>2]|0)+aV|0;aX=0;do{a$=aW+(c[609008+(aX<<2)>>2]|0)|0;a_=(aX<<4)+aV|0;aZ=0;do{a0=a$+(c[597864+(aZ<<2)>>2]|0)|0;if(((d[aM+((a0|0)/8|0)|0]|0)&128>>>((a0&7)>>>0)|0)!=0){a0=aU+(a_+aZ)|0;a[a0]=(d[a0]|0|aY)&255}aZ=aZ+1|0;}while((aZ|0)<16);aX=aX+1|0;}while((aX|0)<16);aP=aP+1|0;}while((aP|0)<4);aT=aT+1|0;}while((aT|0)<18432);aT=c[642608+(c[2436]<<2)>>2]|0;aU=c[aT>>2]|0;do{if((fa(aU|0,471632)|0)==0){gGz(aM|0,0,4194304);if((c[3542200]|0)==0){aS=1;i=e;return aS|0}aP=p+108|0;c[aP>>2]=0;aV=p+100|0;c[aV>>2]=0;aX=c[aT+76>>2]|0;gA[aX&16383](p,16)|0;do{if((c[aP>>2]|0)!=0){aX=c[aV>>2]|0;c[q>>2]=9534384;aY=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aY&16383](q,16,0)|0;if((aX|0)<1){aS=1;i=e;return aS|0}if((gzL(aM,0,16)|0)==0){break}else{aS=1}i=e;return aS|0}}while(0);aV=c[3541206]|0;aP=aV+131072|0;aX=c[3529522]|0;gGC(aP|0,aX|0,131072)|0;aP=aX+131072|0;gGC(aV|0,aP|0,131072)|0}else{aP=(fa(aU|0,449792)|0)==0;aV=c[3541206]|0;if(aP){if((c[3542200]|0)==0){aS=1;i=e;return aS|0}aP=n+108|0;c[aP>>2]=0;aX=n+100|0;c[aX>>2]=0;aY=c[aT+76>>2]|0;gA[aY&16383](n,32)|0;do{if((c[aP>>2]|0)!=0){aY=c[aX>>2]|0;c[o>>2]=9534384;aW=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aW&16383](o,32,0)|0;if((aY|0)<1){aS=1;i=e;return aS|0}if((gzL(aV,0,32)|0)==0){break}else{aS=1}i=e;return aS|0}}while(0);aX=(c[3541206]|0)+131072|0;if((c[3542200]|0)==0){aS=1;i=e;return aS|0}aP=l+108|0;c[aP>>2]=0;aY=l+100|0;c[aY>>2]=0;aW=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aW&16383](l,33)|0;if((c[aP>>2]|0)==0){break}aP=c[aY>>2]|0;c[m>>2]=9534384;aY=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aY&16383](m,33,0)|0;if((aP|0)<1){aS=1;i=e;return aS|0}if((gzL(aX,0,33)|0)==0){break}else{aS=1}i=e;return aS|0}else{if((c[3542200]|0)==0){aS=1;i=e;return aS|0}aX=j+108|0;c[aX>>2]=0;aP=j+100|0;c[aP>>2]=0;aY=c[aT+76>>2]|0;gA[aY&16383](j,16)|0;do{if((c[aX>>2]|0)!=0){aY=c[aP>>2]|0;c[k>>2]=9534384;aW=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aW&16383](k,16,0)|0;if((aY|0)<1){aS=1;i=e;return aS|0}if((gzL(aV,0,16)|0)==0){break}else{aS=1}i=e;return aS|0}}while(0);aV=(c[3541206]|0)+131072|0;if((c[3542200]|0)==0){aS=1;i=e;return aS|0}aP=f+108|0;c[aP>>2]=0;aX=f+100|0;c[aX>>2]=0;aY=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aY&16383](f,17)|0;if((c[aP>>2]|0)==0){break}aP=c[aX>>2]|0;c[g>>2]=9534384;aX=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aX&16383](g,17,0)|0;if((aP|0)<1){aS=1;i=e;return aS|0}if((gzL(aV,0,17)|0)==0){break}else{aS=1}i=e;return aS|0}}}while(0);aT=c[2433468]|0;aU=c[3541206]|0;gGC(aT|0,aU|0,262144)|0;aU=c[3529522]|0;aT=0;while(1){if((aT|0)>=1024){break}a1=9638528+(aT<<2)|0;if((c[a1>>2]|0)==(aU|0)){aO=46262;break}else{aT=aT+1|0}}if((aO|0)==46262){gGr(aU);c[a1>>2]=0}c[3529522]=0;fxU(0,425984);if((c[2394]|0)==0){a2=c[2112932]|0}else{c[2394]=0;aT=c[3532596]|0;c[2112932]=aT;aM=c[3532592]|0;if((aM|0)!=0){gGC(9104152,aM|0,280)|0}c[2113054]=c[2113060];a2=aT}aT=c[2388028]|0;aM=a2|0;aV=0;while(1){aP=aT+aV|0;c[aM>>2]=aP;c[aM+131072>>2]=aP;aP=aV+1024|0;if(aP>>>0>524287){break}else{aM=aM+4|0;aV=aP}}aV=c[2439940]|0;c[a2+2048>>2]=aV;c[a2+67584>>2]=aV;c[a2+133120>>2]=aV;aM=aV+1024|0;c[a2+2052>>2]=aM;c[a2+67588>>2]=aM;c[a2+133124>>2]=aM;aM=aV+2048|0;c[a2+2056>>2]=aM;c[a2+67592>>2]=aM;c[a2+133128>>2]=aM;aM=aV+3072|0;c[a2+2060>>2]=aM;c[a2+67596>>2]=aM;c[a2+133132>>2]=aM;aM=c[2443414]|0;c[a2+2064>>2]=aM;c[a2+67600>>2]=aM;c[a2+133136>>2]=aM;aV=aM+1024|0;c[a2+2068>>2]=aV;c[a2+67604>>2]=aV;c[a2+133140>>2]=aV;aV=aM+2048|0;c[a2+2072>>2]=aV;c[a2+67608>>2]=aV;c[a2+133144>>2]=aV;aV=aM+3072|0;c[a2+2076>>2]=aV;c[a2+67612>>2]=aV;c[a2+133148>>2]=aV;aV=c[2439958]|0;c[a2+2080>>2]=aV;c[a2+67616>>2]=aV;c[a2+133152>>2]=aV;aM=aV+1024|0;c[a2+2084>>2]=aM;c[a2+67620>>2]=aM;c[a2+133156>>2]=aM;aM=c[2388048]|0;c[a2+2088>>2]=aM;c[a2+67624>>2]=aM;c[a2+133160>>2]=aM;aV=aM+1024|0;c[a2+2092>>2]=aV;c[a2+67628>>2]=aV;c[a2+133164>>2]=aV;aV=c[2439614]|0;c[a2+4096>>2]=aV;c[a2+69632>>2]=aV;c[a2+135168>>2]=aV;aT=aV+1024|0;c[a2+4100>>2]=aT;c[a2+69636>>2]=aT;c[a2+135172>>2]=aT;aT=aM+2048|0;c[a2+7168>>2]=aT;c[a2+72704>>2]=aT;c[a2+138240>>2]=aT;aT=aM+3072|0;c[a2+7172>>2]=aT;c[a2+72708>>2]=aT;c[a2+138244>>2]=aT;aT=aM+4096|0;c[a2+7176>>2]=aT;c[a2+72712>>2]=aT;c[a2+138248>>2]=aT;aT=aM+5120|0;c[a2+7180>>2]=aT;c[a2+72716>>2]=aT;c[a2+138252>>2]=aT;aT=aM+6144|0;c[a2+7184>>2]=aT;c[a2+72720>>2]=aT;c[a2+138256>>2]=aT;aT=aM+7168|0;c[a2+7188>>2]=aT;c[a2+72724>>2]=aT;c[a2+138260>>2]=aT;aT=aM+8192|0;c[a2+7192>>2]=aT;c[a2+72728>>2]=aT;c[a2+138264>>2]=aT;aT=aM+9216|0;c[a2+7196>>2]=aT;c[a2+72732>>2]=aT;c[a2+138268>>2]=aT;aT=aM+10240|0;c[a2+7200>>2]=aT;c[a2+72736>>2]=aT;c[a2+138272>>2]=aT;aT=aM+11264|0;c[a2+7204>>2]=aT;c[a2+72740>>2]=aT;c[a2+138276>>2]=aT;aT=aM+12288|0;c[a2+7208>>2]=aT;c[a2+72744>>2]=aT;c[a2+138280>>2]=aT;aT=aM+13312|0;c[a2+7212>>2]=aT;c[a2+72748>>2]=aT;c[a2+138284>>2]=aT;aT=aM+14336|0;c[a2+7216>>2]=aT;c[a2+72752>>2]=aT;c[a2+138288>>2]=aT;aT=aM+15360|0;c[a2+7220>>2]=aT;c[a2+72756>>2]=aT;c[a2+138292>>2]=aT;aT=aM+16384|0;c[a2+7224>>2]=aT;c[a2+72760>>2]=aT;c[a2+138296>>2]=aT;aT=aM+17408|0;c[a2+7228>>2]=aT;c[a2+72764>>2]=aT;c[a2+138300>>2]=aT;c[a2+196688>>2]=646;c[a2+196728>>2]=2640;c[a2+196608>>2]=380;c[a2+196648>>2]=292;aT=c[3532592]|0;if((aT|0)!=0){gGC(aT|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);aT=c[2439330]|0;aM=(aT|0)==0;if(!aM){aV=aT;gGC(9706056,aV|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];aV=c[3528484]|0;c[2076596]=aV;aU=c[2417276]|0;c[3541536]=aU;c[1836236]=0;c[aT+4180>>2]=1514;c[aT+4184>>2]=2128;aP=c[2385834]|0;aX=0;aY=0;while(1){c[aT+76+(aY<<2)>>2]=aP+(aY<<8);aW=aX+1&65535;if((aW&65535)>127){a3=0;a4=0;break}else{aX=aW;aY=aW&65535}}while(1){aY=aP+(a4<<8)|0;c[aT+76+(a4+512<<2)>>2]=aY;c[aT+76+(a4+768<<2)>>2]=aY;aY=a3+1&65535;if((aY&65535)>127){break}else{a3=aY;a4=aY&65535}}aP=c[2385852]|0;c[aT+588>>2]=aP;aY=aP+256|0;c[aT+592>>2]=aY;aX=aP+512|0;c[aT+596>>2]=aX;aW=aP+768|0;c[aT+600>>2]=aW;aZ=aP+1024|0;c[aT+604>>2]=aZ;a_=aP+1280|0;c[aT+608>>2]=a_;a$=aP+1536|0;c[aT+612>>2]=a$;a0=aP+1792|0;c[aT+616>>2]=a0;c[aT+1612>>2]=aP;c[aT+1616>>2]=aY;c[aT+1620>>2]=aX;c[aT+1624>>2]=aW;c[aT+1628>>2]=aZ;c[aT+1632>>2]=a_;c[aT+1636>>2]=a$;c[aT+1640>>2]=a0;c[aT+2636>>2]=aP;c[aT+3660>>2]=aP;c[aT+2640>>2]=aY;c[aT+3664>>2]=aY;c[aT+2644>>2]=aX;c[aT+3668>>2]=aX;c[aT+2648>>2]=aW;c[aT+3672>>2]=aW;c[aT+2652>>2]=aZ;c[aT+3676>>2]=aZ;c[aT+2656>>2]=a_;c[aT+3680>>2]=a_;c[aT+2660>>2]=a$;c[aT+3684>>2]=a$;c[aT+2664>>2]=a0;c[aT+3688>>2]=a0;if(!aM){a0=aT;gGC(a0|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=aV;c[2417276]=aU;c[1836236]=-1;a0=a[9680]|0;a$=a0?32e3:0;if(a0){if(a[9624]|0){a0=a$*3|0;a_=55930;while(1){if((a_|0)>(a0|0)){a_=a_>>1}else{a5=1222;a6=a_;break}}}else{a5=2462;a6=a$}c[2429380]=a6;c[3542124]=a5;mw(3579545,a6);a_=gGq(262144)|0;c[2406684]=a_;gGz(a_|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(3579545,11025)}c[(c[3531464]|0)+44344>>2]=1148;h[745421]=1.2;c[2436794]=1;h[745420]=1.2;c[2436792]=2;Ux(0,7575,1);c[2407030]=205;c[2407068]=3;c[2443626]=2216;a_=c[642608+(c[2436]<<2)>>2]|0;a0=c[a_+128>>2]|0;if((c[a_+52>>2]&4|0)==0){c[2113068]=a0;aU=c[a_+132>>2]|0;c[2113070]=aU;c[2443814]=a0;c[2440436]=aU;a7=a0;a8=aU}else{c[2113070]=a0;aU=c[a_+132>>2]|0;c[2113068]=aU;c[2440436]=a0;c[2443814]=aU;a7=aU;a8=a0}a0=ag(a7<<1,a8)|0;aU=gGq(a0)|0;c[2112926]=aU;if((aU|0)!=0){gGz(aU|0,0,a0|0)}if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];a0=c[3532592]|0;if((a0|0)!=0){gGC(9104152,a0|0,280)|0}c[2113054]=c[2113060]}RI();a0=c[2394]|0;aU=c[14130368+(a0<<2)>>2]|0;if((aU|0)!=0){gGC(aU|0,9104152,280)|0}c[8452240+(a0<<2)>>2]=c[2113054];c[2394]=-1;a0=c[2439330]|0;aU=(a0|0)==0;if(!aU){a_=a0;gGC(9706056,a_|0,76)|0}a_=c[2438118]|0;c[2433530]=a_;aV=c[3528484]|0;c[2076596]=aV;aT=c[2417276]|0;c[3541536]=aT;c[1836236]=0;gGz(9706056,0,76);if(!aU){aU=a0;gGC(aU|0,9706056,76)|0}c[2438118]=a_;c[3528484]=aV;c[2417276]=aT;c[1836236]=-1;mx(0);c[2113156]=0;a[9628264]=0;c[2407033]=0;aT=c[3541206]|0;c[3541190]=aT;c[3541198]=aT;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=aT+256;c[3541199]=aT+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=aT+512;c[3541200]=aT+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=aT+768;c[3541201]=aT+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;b[4879940]=0;b[4887196]=0;b[4887172]=0;b[4887140]=0;b[4887124]=0;b[4814252]=0;a[9758168]=0;a[14121008]=0;a[9545152]=0;aS=0;i=e;return aS|0}}while(0);c[2426726]=0;aS=1;i=e;return aS|0}function d7Y(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5515420+(b*112|0)>>2];c[a+104>>2]=c[5515424+(b*112|0)>>2];c[a+108>>2]=c[5515428+(b*112|0)>>2];d=0;return d|0}function d7Z(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=5515320+(b*112|0);e=0;return e|0}function d7_(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5511388+(b*112|0)>>2];c[a+104>>2]=c[5511392+(b*112|0)>>2];c[a+108>>2]=c[5511396+(b*112|0)>>2];d=0;return d|0}function d7$(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=5511288+(b*112|0);e=0;return e|0}function d70(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5513516+(b*112|0)>>2];c[a+104>>2]=c[5513520+(b*112|0)>>2];c[a+108>>2]=c[5513524+(b*112|0)>>2];d=0;return d|0}function d71(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=5513416+(b*112|0);e=0;return e|0}function d72(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>33){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4129164+(b*112|0)>>2];c[a+104>>2]=c[4129168+(b*112|0)>>2];c[a+108>>2]=c[4129172+(b*112|0)>>2];d=0;return d|0}function d73(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<34&(d|0)==0)){e=1;return e|0}c[a>>2]=4129064+(b*112|0);e=0;return e|0}function d74(b){b=b|0;a[9706117]=(b|0)!=0|0;return}function d75(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a=c[2112926]|0;gGz(a|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);a=c[3530014]|0;d=0;e=c[2439614]|0;f=a;while(1){g=b[e>>1]|0;h=g&255;i=(g&65535)>>>4;j=(g&65535)>>>8;c[f>>2]=((j<<4&255|j&8)&255)>>>3|((h<<4|h&8)&255)<<8&63488|((i<<4&255|i&12)&255)<<3&2016;i=d+1|0;if((i|0)<1536){d=i;e=e+2|0;f=f+4|0}else{break}}if((b[4814252]&8)==0){d78(1);d76(0);d77();R8(a);return}else{d76(1);d77();d78(0);R8(a);return}}function d76(a){a=a|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=c[2439940]|0;f=(a|0)==0;a=c[2112926]|0;g=c[2405812]|0;h=0;i=0;while(1){j=i<<4;if(f){k=h;l=0;while(1){m=k<<1;n=e[d+(m<<1)>>1]|0;o=b[d+((m|1)<<1)>>1]&8191;m=n&15;p=n&64;n=(l<<4)-(e[4887140]|0)|0;q=j-(e[4887124]|0)|0;r=(n|0)<-16?n+512|0:n;n=(q|0)<-16?q+512|0:q;q=n-8|0;do{if((r-17|0)>>>0<287){if((n-25|0)>>>0>=207){s=46494;break}if((p|0)==0){SG(a,o,r,q,m,4,0,256,g);break}else{SI(a,o,r,q,m,4,0,256,g);break}}else{s=46494}}while(0);do{if((s|0)==46494){s=0;if((p|0)==0){SH(a,o,r,q,m,4,0,256,g);break}else{SJ(a,o,r,q,m,4,0,256,g);break}}}while(0);m=l+1|0;if((m|0)<32){k=k+1|0;l=m}else{break}}}else{l=h;k=0;while(1){m=l<<1;q=e[d+(m<<1)>>1]|0;r=b[d+((m|1)<<1)>>1]&8191;m=q&15;o=q&64;q=(k<<4)-(e[4887140]|0)|0;p=j-(e[4887124]|0)|0;n=(q|0)<-16?q+512|0:q;q=(p|0)<-16?p+512|0:p;p=q-8|0;do{if((n-17|0)>>>0<287){if((q-25|0)>>>0>=207){s=46506;break}if((o|0)==0){Sy(a,r,n,p,m,4,256,g);break}else{SA(a,r,n,p,m,4,256,g);break}}else{s=46506}}while(0);do{if((s|0)==46506){s=0;if((o|0)==0){Sz(a,r,n,p,m,4,256,g);break}else{SB(a,r,n,p,m,4,256,g);break}}}while(0);m=k+1|0;if((m|0)<32){l=l+1|0;k=m}else{break}}}k=i+1|0;if((k|0)<32){h=h+32|0;i=k}else{break}}return}function d77(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;a=c[2443414]|0;d=a+4096|0;f=c[2112926]|0;g=c[3529574]|0;h=a;do{a=e[h+2>>1]|0;if((a&1|0)!=0){i=b[h+4>>1]&255|(e[h+6>>1]|0)<<8&65280;j=b[h+8>>1]&15;k=b[h+10>>1]&255;l=a>>>5&7;m=(a&4|0)==0?k:k|256;k=m>>>0>383?m|-512:m;m=(a&16|0)==0;n=(a&8|0)!=0;o=((a&2|0)==0?232:487)-(b[h>>1]&255)|0;a=0;do{p=a+i|0;q=o-(a<<4)|0;do{if(m){if(n){SL(f,p,k,q,j,4,0,0,g);break}else{SH(f,p,k,q,j,4,0,0,g);break}}else{if(n){SN(f,p,k,q,j,4,0,0,g);break}else{SJ(f,p,k,q,j,4,0,0,g);break}}}while(0);a=a+1|0;}while((a|0)<=(l|0))}h=h+16|0;}while(h>>>0<d>>>0);return}function d78(a){a=a|0;var b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=c[2439958]|0;d=(a|0)==0;a=c[2112926]|0;f=c[2405812]|0;g=0;h=0;while(1){i=g<<4;j=h;k=0;while(1){l=e[b+(j<<1)>>1]|0;m=(e[4879940]|0)<<12&4096|l&4095;n=l>>>12;l=(k<<4)-(e[4887196]|0)|0;o=i-(e[4887172]|0)|0;p=(l|0)<-16?l+512|0:l;l=(o|0)<-16?o+512|0:o;o=l-8|0;q=(p-17|0)>>>0<287;L61434:do{if(d){do{if(q){if((l-25|0)>>>0>=207){break}SG(a,m,p,o,n,4,0,512,f);break L61434}}while(0);SH(a,m,p,o,n,4,0,512,f)}else{do{if(q){if((l-25|0)>>>0>=207){break}Sy(a,m,p,o,n,4,512,f);break L61434}}while(0);Sz(a,m,p,o,n,4,512,f)}}while(0);n=k+1|0;if((n|0)<32){j=j+1|0;k=n}else{break}}k=g+1|0;if((k|0)<32){g=k;h=h+32|0}else{break}}return}function d79(){var a=0,d=0,e=0,f=0,g=0;a=c[2112926]|0;gGz(a|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);a=c[3530014]|0;d=0;e=c[2439614]|0;f=a;while(1){g=b[e>>1]|0;c[f>>2]=((g&65535)>>>10<<3&248)>>>3|((g&255)<<3&255)<<8|(((g&65535)>>>7&4|(g&65535)>>>5<<3&255)&255)<<3&2016;g=d+1|0;if((g|0)<1536){d=g;e=e+2|0;f=f+4|0}else{break}}f=b[4814252]&96;if((f|0)==64){d78(1);d76(0);d77();R8(a);return}else if((f|0)==96){d76(1);d78(0);d77();R8(a);return}else{d78(1);d77();d76(0);R8(a);return}}function d8a(b){b=b|0;var c=0;if((b|0)==7340053){c=~a[9625712]}else if((b|0)==7340051){c=~a[9625720]}else{c=0}return c|0}function d8b(b,c){b=b|0;c=c|0;if((b|0)!=7340063){return}a[9750992]=c;a[6923448]=1;return}function d8c(a){a=a|0;var b=0;if((a|0)==7340048){b=~(d[9625728]|0)}else if((a|0)==7340060){b=d[9657953]|0|-256}else if((a|0)==7340058){b=d[9657952]|0|-256}else{b=0}return b|0}function d8d(a,d){a=a|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;if((a-5246976|0)>>>0<4096|(a-5259264|0)>>>0<49152){return}if((a-7864320|0)>>>0<2048){e=a>>>1&1023;b[(c[2439612]|0)+(e<<1)>>1]=d;f=d&65535;g=f>>>3;h=(f>>>11&30|g&1)&255;i=(f>>>7&30|f>>>2&1)&255;j=(g&30|f>>>1&1)&255;c[(c[3530012]|0)+(e<<2)>>2]=(((i&255)>>>2|i<<3)&255)<<3&2016|(((j&255)>>>2|j<<3)&255)>>>3|(((h&255)>>>2|h<<3)&255)<<8&63488;return}switch(a|0){case 5308426:{b[4887120]=d&511;return};case 5308424:{b[4887136]=d+6&511;return};case 5308420:{b[4887192]=-4-d&65535;return};case 5308418:{b[4877608]=d&255;return};case 5308416:{b[4877612]=d+2&511;return};case 5308422:{b[4887168]=-d&511;b[7054948]=d&512;b[4879944]=d&1024;return};default:{return}}}function d8e(a){a=a|0;return 0}function d8f(b,c){b=b|0;c=c|0;if((b|0)!=7340063){return}a[9750992]=c;a[6923448]=1;return}function d8g(a){a=a|0;var b=0;switch(a|0){case 7340052:{b=~(d[9625712]|0);break};case 7340050:{b=~(d[9625720]|0);break};case 7340058:{b=d[9657952]|0|-256;break};case 7340060:{b=d[9657953]|0|-256;break};case 7340048:{b=~(d[9625728]|0);break};default:{b=0}}return b|0}function d8h(a,d){a=a|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;if((a-7864320|0)>>>0<2048){e=a>>>1&1023;b[(c[2439612]|0)+(e<<1)>>1]=d;f=d&65535;g=f>>>3;h=(f>>>11&30|g&1)&255;i=(f>>>7&30|f>>>2&1)&255;j=(g&30|f>>>1&1)&255;c[(c[3530012]|0)+(e<<2)>>2]=(((i&255)>>>2|i<<3)&255)<<3&2016|(((j&255)>>>2|j<<3)&255)>>>3|(((h&255)>>>2|h<<3)&255)<<8&63488;return}switch(a|0){case 5308424:{b[4887136]=d+6&511;return};case 5308422:{b[4887168]=2-d&511;b[7054948]=d&512;b[4879944]=d&1024;return};case 5308416:{b[4877612]=d+2&511;return};case 5308418:{b[4877608]=d&255;return};case 5308420:{b[4887192]=-d&65535;return};case 5308426:{b[4887120]=d&511;return};default:{return}}}function d8i(b){b=b|0;var d=0,e=0,f=0;switch(b|0){case 3145749:{b=(63-(a[9625712]|0)&255)+(a[638008]|0?0:64)&255;do{if((c[2406632]|0)==0){d=c[2443744]|0;if((d|0)<=0){e=-128;break}c[2443744]=d-1;e=0}else{e=(1<<c[(c[2420380]|0)+4>>2]&c[2432962]|0)!=0?-128:0}}while(0);f=b+e&255;return f|0};case 3145745:{f=~a[9625728];return f|0};case 3145757:{f=a[9657953]|0;return f|0};case 3145755:{f=a[9657952]|0;return f|0};case 3145747:{f=~a[9625720];return f|0};default:{f=0;return f|0}}return 0}function d8j(b,d){b=b|0;d=d|0;var e=0,f=0;if((b|0)==3145749){e=d&255;f=e&1;c[3528406]=f^1;if((f|0)==0){c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2]}c[2415256]=e&4;Tr(e>>>1&1);return}else if((b|0)==3145759){a[9750992]=d;a[6923448]=1;return}else{return}}function d8k(a){a=a|0;return 0}function d8l(a,d){a=a|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;if((a-2621440|0)>>>0<2048){e=a>>>1&1023;b[(c[2439612]|0)+(e<<1)>>1]=d;f=d&65535;g=f>>>3;h=(f>>>11&30|g&1)&255;i=(f>>>7&30|f>>>2&1)&255;j=(g&30|f>>>1&1)&255;c[(c[3530012]|0)+(e<<2)>>2]=(((i&255)>>>2|i<<3)&255)<<3&2016|(((j&255)>>>2|j<<3)&255)>>>3|(((h&255)>>>2|h<<3)&255)<<8&63488;return}switch(a|0){case 1114112:{b[4877612]=d+14&511;return};case 1114124:{b[4875508]=d&1;return};case 1114120:{b[4887192]=d+14&511;return};case 1114118:{b[4887120]=d&511;return};case 1114114:{b[4877608]=d&511;return};case 1114116:{b[4887136]=d+14&511;return};case 1114122:{b[4887168]=d&511;return};default:{return}}}function d8m(b){b=b|0;var d=0,e=0;d=b&65535;do{if((d|0)==2){if(!(a[6923448]|0)){e=64;break}a[6923448]=0;e=0}else if((d|0)==1){b=a[9758536]&56;if((b|0)==48){e=a[9750992]|0;break}else if((b|0)==40){e=c[2113156]&15;break}else{e=0;break}}else{e=0}}while(0);return e|0}function d8n(b,e){b=b|0;e=e|0;var f=0,g=0,h=0;f=b&255;if((f|0)==0){if(!(a[1276728]|0)){return}b=e&255;g=b&7;if((d[9758528]|0|0)==(g|0)){return}a[9758528]=g&255;g=(b<<18&1835008)-262144|0;if((g|0)>=786432){return}b=c[3541206]|0;h=(c[2439654]|0)+g|0;gGC(b|0,h|0,262144)|0;return}else if((f|0)==1){a[9758544]=e;return}else if((f|0)==2){a[9758536]=e;if((e&56)!=24){return}Uv(0,a[9758544]|0);return}else{return}}function d8o(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5573396+(b*112|0)>>2];c[a+104>>2]=c[5573400+(b*112|0)>>2];c[a+108>>2]=c[5573404+(b*112|0)>>2];d=0;return d|0}function d8p(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=5573296+(b*112|0);e=0;return e|0}function d8q(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=2003296+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function d8r(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>40){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5574640+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function d8s(){var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0;e=i;i=i+1080|0;f=e|0;g=e+112|0;h=e+120|0;j=e+232|0;k=e+240|0;l=e+352|0;m=e+360|0;n=e+472|0;o=e+480|0;p=e+592|0;q=e+600|0;r=e+712|0;s=e+720|0;t=e+832|0;u=e+840|0;v=e+952|0;w=e+960|0;x=e+1072|0;c[2439986]=1048576;a[1276728]=0;c[3527364]=8192;a[7303744]=1;c[3527368]=8192;c[3527464]=64;c[2439648]=1024;c[2439528]=1024;c[2426724]=0;c[2388014]=0;c[3541206]=1048576;c[2439654]=1310720;c[2387050]=1310720;c[2405658]=1314816;c[2388018]=1314816;c[2443412]=1380352;c[2443368]=1384448;c[2443362]=1417216;c[2439956]=1433600;c[2439612]=1957888;c[2411668]=1959936;c[3529572]=1959936;c[2405810]=3008512;c[2406520]=5105664;c[3530012]=5629952;y=0;while(1){if((y|0)>=1024){break}z=9638528+(y<<2)|0;if((c[z>>2]|0)==0){A=46714;break}else{y=y+1|0}}do{if((A|0)==46714){y=gGq(5634048)|0;c[z>>2]=y;if((y|0)==0){break}c[2426724]=y;gGz(y|0,0,5634048);c[2388014]=y;B=c[2439986]|0;c[3541206]=y+B;C=B+262144|0;c[2439654]=y+C;B=(a[1276728]|0?786432:0)+C|0;c[2387050]=y+B;C=y+(B+4096)|0;c[2405658]=C;c[2388018]=C;c[2443412]=y+(B+69632);c[2443368]=y+(B+73728);c[2443362]=y+(B+106496);c[2439956]=y+(B+122880);c[2439612]=y+(B+647168);C=B+649216|0;B=y+C|0;c[2411668]=B;c[3529572]=B;B=C+(ag(c[2439528]|0,c[2439648]|0)|0)|0;c[2405810]=y+B;C=(ag(a[7303744]|0?256:0,c[3527364]|0)|0)+B|0;c[2406520]=y+C;B=C+(ag(c[3527464]|0,c[3527368]|0)|0)|0;c[3530012]=y+B;c[2414208]=y+(B+4096);B=0;while(1){if((B|0)>=1024){D=0;break}E=9638528+(B<<2)|0;if((c[E>>2]|0)==0){A=46719;break}else{B=B+1|0}}do{if((A|0)==46719){B=gGq(1048576)|0;c[E>>2]=B;if((B|0)==0){D=0;break}gGz(B|0,0,1048576);D=B}}while(0);c[3529556]=D;if((R6((c[2388014]|0)+1|0,0,2)|0)!=0){F=1;i=e;return F|0}if((R6(c[2388014]|0,1,2)|0)!=0){F=1;i=e;return F|0}if((fvF(c[2387050]|0,2,11596)|0)!=0){F=1;i=e;return F|0}B=c[3529556]|0;if((c[3542200]|0)==0){F=1;i=e;return F|0}y=w+108|0;c[y>>2]=0;C=w+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](w,3)|0;do{if((c[y>>2]|0)!=0){G=c[C>>2]|0;c[x>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](x,3,0)|0;if((G|0)<1){F=1;i=e;return F|0}if((gzL(B,0,3)|0)==0){break}else{F=1}i=e;return F|0}}while(0);B=(c[3529556]|0)+262144|0;if((c[3542200]|0)==0){F=1;i=e;return F|0}C=u+108|0;c[C>>2]=0;y=u+100|0;c[y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](u,4)|0;do{if((c[C>>2]|0)!=0){G=c[y>>2]|0;c[v>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](v,4,0)|0;if((G|0)<1){F=1;i=e;return F|0}if((gzL(B,0,4)|0)==0){break}else{F=1}i=e;return F|0}}while(0);B=(c[3529556]|0)+524288|0;if((c[3542200]|0)==0){F=1;i=e;return F|0}y=s+108|0;c[y>>2]=0;C=s+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](s,5)|0;do{if((c[y>>2]|0)!=0){G=c[C>>2]|0;c[t>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](t,5,0)|0;if((G|0)<1){F=1;i=e;return F|0}if((gzL(B,0,5)|0)==0){break}else{F=1}i=e;return F|0}}while(0);B=(c[3529556]|0)+786432|0;if((c[3542200]|0)==0){F=1;i=e;return F|0}C=q+108|0;c[C>>2]=0;y=q+100|0;c[y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](q,6)|0;do{if((c[C>>2]|0)!=0){G=c[y>>2]|0;c[r>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](r,6,0)|0;if((G|0)<1){F=1;i=e;return F|0}if((gzL(B,0,6)|0)==0){break}else{F=1}i=e;return F|0}}while(0);B=c[3527364]|0;y=c[3529556]|0;C=c[2405810]|0;if((B|0)>0){G=0;do{H=G<<8;gGz(C+H|0,0,256);I=0;do{J=1<<3-I;K=(c[603744+(I<<2)>>2]|0)+H|0;L=0;do{M=K+(c[609008+(L<<2)>>2]|0)|0;N=(L<<4)+H|0;O=0;do{P=M+(c[597864+(O<<2)>>2]|0)|0;if(((d[y+((P|0)/8|0)|0]|0)&128>>>((P&7)>>>0)|0)!=0){P=C+(N+O)|0;a[P]=(d[P]|0|J)&255}O=O+1|0;}while((O|0)<16);L=L+1|0;}while((L|0)<16);I=I+1|0;}while((I|0)<4);G=G+1|0;}while((G|0)<(B|0))}B=c[3527368]|0;G=c[2406520]|0;if((B|0)>0){C=0;do{I=C<<6;gGz(G+I|0,0,64);H=C<<8;L=0;do{J=1<<3-L;K=(c[603744+(L<<2)>>2]|0)+H|0;O=0;do{N=K+(c[1238464+(O<<2)>>2]|0)|0;M=(O<<3)+I|0;P=0;do{Q=N+(c[614800+(P<<2)>>2]|0)|0;if(((d[y+((Q|0)/8|0)|0]|0)&128>>>((Q&7)>>>0)|0)!=0){Q=G+(M+P)|0;a[Q]=(d[Q]|0|J)&255}P=P+1|0;}while((P|0)<8);O=O+1|0;}while((O|0)<8);L=L+1|0;}while((L|0)<4);C=C+1|0;}while((C|0)<(B|0))}gGz(y|0,0,1048576);if((c[3542200]|0)==0){F=1;i=e;return F|0}B=o+108|0;c[B>>2]=0;C=o+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](o,7)|0;do{if((c[B>>2]|0)!=0){G=c[C>>2]|0;c[p>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](p,7,0)|0;if((G|0)<1){F=1;i=e;return F|0}if((gzL(y,0,7)|0)==0){break}else{F=1}i=e;return F|0}}while(0);y=(c[3529556]|0)+131072|0;if((c[3542200]|0)==0){F=1;i=e;return F|0}C=m+108|0;c[C>>2]=0;B=m+100|0;c[B>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,8)|0;do{if((c[C>>2]|0)!=0){G=c[B>>2]|0;c[n>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](n,8,0)|0;if((G|0)<1){F=1;i=e;return F|0}if((gzL(y,0,8)|0)==0){break}else{F=1}i=e;return F|0}}while(0);y=(c[3529556]|0)+262144|0;if((c[3542200]|0)==0){F=1;i=e;return F|0}B=k+108|0;c[B>>2]=0;C=k+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,9)|0;do{if((c[B>>2]|0)!=0){G=c[C>>2]|0;c[l>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](l,9,0)|0;if((G|0)<1){F=1;i=e;return F|0}if((gzL(y,0,9)|0)==0){break}else{F=1}i=e;return F|0}}while(0);y=(c[3529556]|0)+393216|0;if((c[3542200]|0)==0){F=1;i=e;return F|0}C=h+108|0;c[C>>2]=0;B=h+100|0;c[B>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](h,10)|0;do{if((c[C>>2]|0)!=0){G=c[B>>2]|0;c[j>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](j,10,0)|0;if((G|0)<1){F=1;i=e;return F|0}if((gzL(y,0,10)|0)==0){break}else{F=1}i=e;return F|0}}while(0);y=c[2439648]|0;B=c[3529556]|0;C=c[3529572]|0;if((y|0)>0){G=0;while(1){L=G<<10;gGz(C+L|0,0,1024);I=0;do{H=1<<3-I;O=(c[704200+(I<<2)>>2]|0)+L|0;J=0;do{K=O+(c[1276472+(J<<2)>>2]|0)|0;P=(J<<5)+L|0;M=0;do{N=K+(c[1276600+(M<<2)>>2]|0)|0;if(((d[B+((N|0)/8|0)|0]|0)&128>>>((N&7)>>>0)|0)!=0){N=C+(P+M)|0;a[N]=(d[N]|0|H)&255}M=M+1|0;}while((M|0)<32);J=J+1|0;}while((J|0)<32);I=I+1|0;}while((I|0)<4);I=G+1|0;if((I|0)<(y|0)){G=I}else{R=0;break}}}else{R=0}while(1){if((R|0)>=1024){break}S=9638528+(R<<2)|0;if((c[S>>2]|0)==(B|0)){A=46788;break}else{R=R+1|0}}if((A|0)==46788){gGr(B);c[S>>2]=0}c[3529556]=0;G=c[3541206]|0;if((c[3542200]|0)==0){F=1;i=e;return F|0}y=f+108|0;c[y>>2]=0;C=f+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,11)|0;do{if((c[y>>2]|0)!=0){I=c[C>>2]|0;c[g>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](g,11,0)|0;if((I|0)<1){F=1;i=e;return F|0}if((gzL(G,0,11)|0)==0){break}else{F=1}i=e;return F|0}}while(0);c[2424]=5800;fxU(0,425984);if((c[2394]|0)==0){T=c[2112932]|0}else{c[2394]=0;G=c[3532596]|0;c[2112932]=G;C=c[3532592]|0;if((C|0)!=0){gGC(9104152,C|0,280)|0}c[2113054]=c[2113060];T=G}G=c[2388014]|0;C=T|0;y=0;while(1){B=G+y|0;c[C>>2]=B;c[C+131072>>2]=B;B=y+1024|0;if(B>>>0>1048575){break}else{C=C+4|0;y=B}}y=c[2443412]|0;c[T+17408>>2]=y;c[T+82944>>2]=y;c[T+148480>>2]=y;y=c[2443362]|0;c[T+20480>>2]=y;c[T+86016>>2]=y;c[T+151552>>2]=y;C=y+1024|0;c[T+20484>>2]=C;c[T+86020>>2]=C;c[T+151556>>2]=C;C=y+2048|0;c[T+20488>>2]=C;c[T+86024>>2]=C;c[T+151560>>2]=C;C=y+3072|0;c[T+20492>>2]=C;c[T+86028>>2]=C;c[T+151564>>2]=C;C=c[2443368]|0;c[T+20512>>2]=C;c[T+86048>>2]=C;c[T+151584>>2]=C;y=C+1024|0;c[T+20516>>2]=y;c[T+86052>>2]=y;c[T+151588>>2]=y;y=C+2048|0;c[T+20520>>2]=y;c[T+86056>>2]=y;c[T+151592>>2]=y;y=C+3072|0;c[T+20524>>2]=y;c[T+86060>>2]=y;c[T+151596>>2]=y;y=C+4096|0;c[T+20528>>2]=y;c[T+86064>>2]=y;c[T+151600>>2]=y;y=C+5120|0;c[T+20532>>2]=y;c[T+86068>>2]=y;c[T+151604>>2]=y;y=C+6144|0;c[T+20536>>2]=y;c[T+86072>>2]=y;c[T+151608>>2]=y;y=C+7168|0;c[T+20540>>2]=y;c[T+86076>>2]=y;c[T+151612>>2]=y;y=c[2439956]|0;C=T+24576|0;G=6291456;while(1){B=y+(G-6291456)|0;c[C>>2]=B;c[C+65536>>2]=B;c[C+131072>>2]=B;B=G+1024|0;if(B>>>0>6815743){break}else{C=C+4|0;G=B}}G=c[2439612]|0;c[T+30720>>2]=G;c[T+30724>>2]=G+1024;G=c[2388018]|0;C=T+65280|0;y=16711680;while(1){B=G+(y-16711680)|0;c[C>>2]=B;c[C+65536>>2]=B;c[C+131072>>2]=B;B=y+1024|0;if(B>>>0>16777215){break}else{C=C+4|0;y=B}}c[T+196608>>2]=372;c[T+196688>>2]=1982;c[T+196648>>2]=1718;c[T+196728>>2]=772;y=c[3532592]|0;if((y|0)!=0){gGC(y|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;y=c[2387050]|0;c[2396]=93271;c[2394714]=93271;a[14113648]=127;c[2427090]=2047;b[4859088]=2047;b[4859091]=b[4887388]|0;a[9718188]=-1;a[9718189]=-1;a[9718190]=-1;a[9718181]=63;a[9718206]=-1;a[9718208]=a[9718208]|-128;a[9718209]=a[9718209]&15;b[4859098]=0;c[3526934]=0;a[9638440]=0;c[2444184]=0;a[9718207]=a[9718207]&7|24;c[355e3]=2047;a[1428184]=0;c[2440230]=y;y=0;while(1){if((y|0)>=1024){U=0;break}V=9638528+(y<<2)|0;if((c[V>>2]|0)==0){A=46809;break}else{y=y+1|0}}do{if((A|0)==46809){y=gGq(128)|0;c[V>>2]=y;if((y|0)==0){U=0;break}gGz(y|0,0,128);U=y}}while(0);c[2440232]=U;c[2112948]=2594;c[2112946]=774;Ux(0,7575,0);c[2407030]=256;c[2407068]=3;c[2443624]=10426;a[638648]=0;y=c[642608+(c[2436]<<2)>>2]|0;C=c[y+128>>2]|0;if((c[y+52>>2]&4|0)==0){c[2113068]=C;G=c[y+132>>2]|0;c[2113070]=G;c[2443814]=C;c[2440436]=G;W=C;X=G}else{c[2113070]=C;G=c[y+132>>2]|0;c[2113068]=G;c[2440436]=C;c[2443814]=G;W=G;X=C}C=ag(W<<1,X)|0;G=gGq(C)|0;c[2112926]=G;if((G|0)!=0){gGz(G|0,0,C|0)}if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];C=c[3532592]|0;if((C|0)!=0){gGC(9104152,C|0,280)|0}c[2113054]=c[2113060]}RI();C=c[2394]|0;G=c[14130368+(C<<2)>>2]|0;if((G|0)!=0){gGC(G|0,9104152,280)|0}c[8452240+(C<<2)>>2]=c[2113054];c[2394]=-1;gd6(c[2396]|0);c[2113156]=0;a[9628264]=0;c[2407033]=0;C=c[3541206]|0;c[3541190]=C;c[3541198]=C;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=C+256;c[3541199]=C+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=C+512;c[3541200]=C+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=C+768;c[3541201]=C+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;if(a[5450480]|0){c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2]}b[4887136]=0;b[4887120]=0;b[4877612]=0;b[4877608]=0;b[7054948]=0;b[4879944]=0;b[4887192]=0;b[4887168]=0;a[9750992]=0;a[6923448]=0;a[9758536]=0;a[9758544]=0;a[9758528]=0;F=0;i=e;return F|0}}while(0);c[2426724]=0;F=1;i=e;return F|0}function d8t(){var d=0,e=0,f=0,g=0,h=0,i=0;if((c[2392]|0)>=0){d=0;do{e=14130368+(d<<2)|0;f=c[e>>2]|0;if((f|0)!=0){gGr(f);c[e>>2]=0}e=14130384+(d<<2)|0;f=c[e>>2]|0;if((f|0)!=0){gGr(f);c[e>>2]=0}d=d+1|0;}while((d|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;c[2440230]=0;c[2396]=-1;d=c[2440232]|0;e=0;while(1){if((e|0)>=1024){break}g=9638528+(e<<2)|0;if((c[g>>2]|0)==(d|0)){h=46867;break}else{e=e+1|0}}if((h|0)==46867){gGr(d);c[g>>2]=0}c[2440232]=0;Uw(0);c[2113070]=0;c[2113068]=0;g=c[2112926]|0;if((g|0)!=0){gGr(g);c[2112926]=0}g=c[2426724]|0;d=0;while(1){if((d|0)>=1024){break}i=9638528+(d<<2)|0;if((c[i>>2]|0)==(g|0)){h=46873;break}else{d=d+1|0}}if((h|0)==46873){gGr(g);c[i>>2]=0}c[2426724]=0;b[4887136]=0;b[4887120]=0;b[4877612]=0;b[4877608]=0;b[7054948]=0;b[4879944]=0;b[4887192]=0;b[4887168]=0;b[4875508]=0;a[638008]=0;a[5450480]=0;a[9750992]=0;a[6923448]=0;a[9758536]=0;a[9758544]=0;a[9758528]=0;c[2439986]=0;a[1276728]=0;c[3527364]=0;a[7303744]=0;c[3527368]=0;c[3527464]=0;c[2439648]=0;c[2439528]=0;a[638648]=0;c[2443624]=0;return 0}function d8u(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a[638008]=0;if((a[9624200]|0)!=0){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;gd6(c[2396]|0);c[2113156]=0;a[9628264]=0;c[2407033]=0;d=c[3541206]|0;c[3541190]=d;c[3541198]=d;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=d+256;c[3541199]=d+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=d+512;c[3541200]=d+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=d+768;c[3541201]=d+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;if(a[5450480]|0){c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2]}b[4887136]=0;b[4887120]=0;b[4877612]=0;b[4877608]=0;b[7054948]=0;b[4879944]=0;b[4887192]=0;b[4887168]=0;a[9750992]=0;a[6923448]=0;a[9758536]=0;a[9758544]=0;a[9758528]=0}a[9625712]=0;a[9625720]=0;a[9625728]=0;d=0;e=0;f=0;g=0;do{e=((a[9759176+d|0]&1)<<d|e&255)&255;f=((a[9758984+d|0]&1)<<d|f&255)&255;g=((a[9758800+d|0]&1)<<d|g&255)&255;d=d+1|0;}while((d|0)<8);a[9625728]=e;a[9625720]=f;a[9625712]=g;if((f&3)==3){e=f&-4;a[9625720]=e;h=e}else{h=f}if((h&12)==12){a[9625720]=h&-13}if((g&3)==3){h=g&-4;a[9625712]=h;i=h}else{i=g}if((i&12)==12){a[9625712]=i&-13}a[6518232]=1;a[6518016]=1;c[2443972]=0;c[2444020]=0;i=c[2392]|0;if((i|0)>=0){gGz(8452240,0,((i|0)>0?(i<<2)+4|0:4)|0)}c[2113054]=0;if((c[2394]|0)==0){j=0;k=0}else{c[2394]=0;c[2112932]=c[3532596];i=c[3532592]|0;if((i|0)!=0){gGC(9104152,i|0,280)|0}c[2113054]=c[2113060];j=0;k=0}L61918:while(1){i=k;while(1){if((i|0)>=100){break L61918}l=i+1|0;g=(ag(a[6518232]|0?206896:0,l)|0)/100|0;h=g-(c[2444020]|0)|0;c[2113056]=h;g=RG(h)|0;c[2113054]=(c[2113054]|0)+g;c[2276108]=-1;c[2113056]=-1;c[2444020]=(c[2444020]|0)+g;do{if((i|0)==90){a[638008]=1;g=a[638648]|0?6:2;c[8452200+(c[2394]<<2)>>2]=g|8192;h=g<<8;c[2276080]=h;if(h>>>0<=(c[2276079]|0)>>>0){break}RH(g)}}while(0);g=(ag(a[6518016]|0?51724:0,l)|0)/100|0;h=gd4(g-(c[2443972]|0)|0)|0;c[2443972]=(c[2443972]|0)+h;m=c[2112964]|0;if((m|0)==0){i=l}else{break}}i=a[9688]|0?5:0;Uu(0,m+(j<<1<<1)|0,i);j=i+j|0;k=l}l=c[2394]|0;k=c[14130368+(l<<2)>>2]|0;if((k|0)!=0){gGC(k|0,9104152,280)|0}c[8452240+(l<<2)>>2]=c[2113054];c[2394]=-1;l=c[2112964]|0;do{if((l|0)!=0){k=a[9688]|0?534:0;if((k|0)==(j|0)){break}Uu(0,l+(j<<1<<1)|0,k-j|0)}}while(0);if((c[2112968]|0)==0){return 0}gu[c[2443624]&16383]();return 0}function d8v(a,b){a=a|0;b=b|0;var d=0,e=0;d=i;i=i+16|0;e=d|0;if((b|0)!=0){c[b>>2]=10025}if((a&32|0)==0){i=d;return 0}gGz(e|0,0,12);a=c[2405658]|0;c[e>>2]=a;c[e+4>>2]=(c[2411668]|0)-a;c[e+12>>2]=162152;gj[c[2076592]&4095](e)|0;i=d;return 0}function d8w(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5422212+(b*112|0)>>2];c[a+104>>2]=c[5422216+(b*112|0)>>2];c[a+108>>2]=c[5422220+(b*112|0)>>2];d=0;return d|0}function d8x(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=5422112+(b*112|0);e=0;return e|0}function d8y(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1938480+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function d8z(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>50){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5423904+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function d8A(){var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;e=i;i=i+1080|0;f=e|0;g=e+112|0;h=e+120|0;j=e+232|0;k=e+240|0;l=e+352|0;m=e+360|0;n=e+472|0;o=e+480|0;p=e+592|0;q=e+600|0;r=e+712|0;s=e+720|0;t=e+832|0;u=e+840|0;v=e+952|0;w=e+960|0;x=e+1072|0;c[2439986]=3145728;a[1276728]=1;c[3527364]=16384;a[7303744]=1;c[3527368]=16384;c[3527464]=256;c[2439648]=16384;c[2439528]=256;c[2426724]=0;c[2388014]=0;c[3541206]=3145728;c[2439654]=3407872;c[2387050]=4194304;c[2405658]=4198400;c[2388018]=4198400;c[2443412]=4263936;c[2443368]=4268032;c[2443362]=4300800;c[2439956]=4317184;c[2439612]=4841472;c[2411668]=4843520;c[3529572]=4843520;c[2405810]=9037824;c[2406520]=13232128;c[3530012]=17426432;y=0;while(1){if((y|0)>=1024){break}z=9638528+(y<<2)|0;if((c[z>>2]|0)==0){A=46954;break}else{y=y+1|0}}do{if((A|0)==46954){y=gGq(17430528)|0;c[z>>2]=y;if((y|0)==0){break}c[2426724]=y;gGz(y|0,0,17430528);c[2388014]=y;B=c[2439986]|0;c[3541206]=y+B;C=B+262144|0;c[2439654]=y+C;B=(a[1276728]|0?786432:0)+C|0;c[2387050]=y+B;C=y+(B+4096)|0;c[2405658]=C;c[2388018]=C;c[2443412]=y+(B+69632);c[2443368]=y+(B+73728);c[2443362]=y+(B+106496);c[2439956]=y+(B+122880);c[2439612]=y+(B+647168);C=B+649216|0;B=y+C|0;c[2411668]=B;c[3529572]=B;B=C+(ag(c[2439528]|0,c[2439648]|0)|0)|0;c[2405810]=y+B;C=(ag(a[7303744]|0?256:0,c[3527364]|0)|0)+B|0;c[2406520]=y+C;B=C+(ag(c[3527464]|0,c[3527368]|0)|0)|0;c[3530012]=y+B;c[2414208]=y+(B+4096);B=0;while(1){if((B|0)>=1024){D=0;break}E=9638528+(B<<2)|0;if((c[E>>2]|0)==0){A=46959;break}else{B=B+1|0}}do{if((A|0)==46959){B=gGq(2097152)|0;c[E>>2]=B;if((B|0)==0){D=0;break}gGz(B|0,0,2097152);D=B}}while(0);c[3529556]=D;if((R6(c[2388014]|0,0,2)|0)!=0){F=1;i=e;return F|0}if((R6((c[2388014]|0)+1|0,1,2)|0)!=0){F=1;i=e;return F|0}if((R6((c[2388014]|0)+1048576|0,2,2)|0)!=0){F=1;i=e;return F|0}if((R6((c[2388014]|0)+1048577|0,3,2)|0)!=0){F=1;i=e;return F|0}if((R6((c[2388014]|0)+2097152|0,4,2)|0)!=0){F=1;i=e;return F|0}if((R6((c[2388014]|0)+2097153|0,5,2)|0)!=0){F=1;i=e;return F|0}if((fvF(c[2387050]|0,6,11596)|0)!=0){F=1;i=e;return F|0}B=c[3529556]|0;if((c[3542200]|0)==0){F=1;i=e;return F|0}y=w+108|0;c[y>>2]=0;C=w+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](w,7)|0;do{if((c[y>>2]|0)!=0){G=c[C>>2]|0;c[x>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](x,7,0)|0;if((G|0)<1){F=1;i=e;return F|0}if((gzL(B,0,7)|0)==0){break}else{F=1}i=e;return F|0}}while(0);B=(c[3529556]|0)+524288|0;if((c[3542200]|0)==0){F=1;i=e;return F|0}C=u+108|0;c[C>>2]=0;y=u+100|0;c[y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](u,8)|0;do{if((c[C>>2]|0)!=0){G=c[y>>2]|0;c[v>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](v,8,0)|0;if((G|0)<1){F=1;i=e;return F|0}if((gzL(B,0,8)|0)==0){break}else{F=1}i=e;return F|0}}while(0);B=(c[3529556]|0)+1048576|0;if((c[3542200]|0)==0){F=1;i=e;return F|0}y=s+108|0;c[y>>2]=0;C=s+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](s,9)|0;do{if((c[y>>2]|0)!=0){G=c[C>>2]|0;c[t>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](t,9,0)|0;if((G|0)<1){F=1;i=e;return F|0}if((gzL(B,0,9)|0)==0){break}else{F=1}i=e;return F|0}}while(0);B=(c[3529556]|0)+1572864|0;if((c[3542200]|0)==0){F=1;i=e;return F|0}C=q+108|0;c[C>>2]=0;y=q+100|0;c[y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](q,10)|0;do{if((c[C>>2]|0)!=0){G=c[y>>2]|0;c[r>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](r,10,0)|0;if((G|0)<1){F=1;i=e;return F|0}if((gzL(B,0,10)|0)==0){break}else{F=1}i=e;return F|0}}while(0);B=c[3527364]|0;y=c[3529556]|0;C=c[2405810]|0;if((B|0)>0){G=0;do{H=G<<8;gGz(C+H|0,0,256);I=0;do{J=1<<3-I;K=(c[601464+(I<<2)>>2]|0)+H|0;L=0;do{M=K+(c[609008+(L<<2)>>2]|0)|0;N=(L<<4)+H|0;O=0;do{P=M+(c[597864+(O<<2)>>2]|0)|0;if(((d[y+((P|0)/8|0)|0]|0)&128>>>((P&7)>>>0)|0)!=0){P=C+(N+O)|0;a[P]=(d[P]|0|J)&255}O=O+1|0;}while((O|0)<16);L=L+1|0;}while((L|0)<16);I=I+1|0;}while((I|0)<4);G=G+1|0;}while((G|0)<(B|0))}B=c[3527368]|0;G=c[2406520]|0;if((B|0)>0){C=0;do{I=C<<8;gGz(G+I|0,0,256);H=0;do{L=1<<3-H;J=(c[601464+(H<<2)>>2]|0)+I|0;K=0;do{O=J+(c[609008+(K<<2)>>2]|0)|0;N=(K<<4)+I|0;M=0;do{P=O+(c[597864+(M<<2)>>2]|0)|0;if(((d[y+((P|0)/8|0)|0]|0)&128>>>((P&7)>>>0)|0)!=0){P=G+(N+M)|0;a[P]=(d[P]|0|L)&255}M=M+1|0;}while((M|0)<16);K=K+1|0;}while((K|0)<16);H=H+1|0;}while((H|0)<4);C=C+1|0;}while((C|0)<(B|0))}gGz(y|0,0,2097152);if((c[3542200]|0)==0){F=1;i=e;return F|0}B=o+108|0;c[B>>2]=0;C=o+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](o,11)|0;do{if((c[B>>2]|0)!=0){G=c[C>>2]|0;c[p>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](p,11,0)|0;if((G|0)<1){F=1;i=e;return F|0}if((gzL(y,0,11)|0)==0){break}else{F=1}i=e;return F|0}}while(0);y=(c[3529556]|0)+524288|0;if((c[3542200]|0)==0){F=1;i=e;return F|0}C=m+108|0;c[C>>2]=0;B=m+100|0;c[B>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,12)|0;do{if((c[C>>2]|0)!=0){G=c[B>>2]|0;c[n>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](n,12,0)|0;if((G|0)<1){F=1;i=e;return F|0}if((gzL(y,0,12)|0)==0){break}else{F=1}i=e;return F|0}}while(0);y=(c[3529556]|0)+1048576|0;if((c[3542200]|0)==0){F=1;i=e;return F|0}B=k+108|0;c[B>>2]=0;C=k+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,13)|0;do{if((c[B>>2]|0)!=0){G=c[C>>2]|0;c[l>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](l,13,0)|0;if((G|0)<1){F=1;i=e;return F|0}if((gzL(y,0,13)|0)==0){break}else{F=1}i=e;return F|0}}while(0);y=(c[3529556]|0)+1572864|0;if((c[3542200]|0)==0){F=1;i=e;return F|0}C=h+108|0;c[C>>2]=0;B=h+100|0;c[B>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](h,14)|0;do{if((c[C>>2]|0)!=0){G=c[B>>2]|0;c[j>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](j,14,0)|0;if((G|0)<1){F=1;i=e;return F|0}if((gzL(y,0,14)|0)==0){break}else{F=1}i=e;return F|0}}while(0);y=c[2439648]|0;B=c[3529556]|0;C=c[3529572]|0;if((y|0)>0){G=0;do{H=G<<8;gGz(C+H|0,0,256);I=0;do{K=1<<3-I;L=(c[601464+(I<<2)>>2]|0)+H|0;J=0;do{M=L+(c[609008+(J<<2)>>2]|0)|0;N=(J<<4)+H|0;O=0;do{P=M+(c[597864+(O<<2)>>2]|0)|0;if(((d[B+((P|0)/8|0)|0]|0)&128>>>((P&7)>>>0)|0)!=0){P=C+(N+O)|0;a[P]=(d[P]|0|K)&255}O=O+1|0;}while((O|0)<16);J=J+1|0;}while((J|0)<16);I=I+1|0;}while((I|0)<4);G=G+1|0;}while((G|0)<(y|0))}if((c[3542200]|0)==0){F=1;i=e;return F|0}y=f+108|0;c[y>>2]=0;G=f+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,15)|0;do{if((c[y>>2]|0)!=0){C=c[G>>2]|0;c[g>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](g,15,0)|0;if((C|0)<1){F=1;i=e;return F|0}if((gzL(B,0,15)|0)==0){break}else{F=1}i=e;return F|0}}while(0);B=c[2439654]|0;G=c[3529556]|0;gGC(B|0,G|0,131072)|0;y=B+131072|0;C=G+131072|0;gGC(y|0,C|0,131072)|0;C=B+262144|0;gGC(C|0,G|0,131072)|0;C=B+393216|0;y=G+262144|0;gGC(C|0,y|0,131072)|0;y=B+524288|0;gGC(y|0,G|0,131072)|0;y=B+655360|0;C=G+393216|0;gGC(y|0,C|0,131072)|0;C=0;while(1){if((C|0)>=1024){Q=B;break}R=9638528+(C<<2)|0;if((c[R>>2]|0)==(G|0)){A=47037;break}else{C=C+1|0}}if((A|0)==47037){gGr(G);c[R>>2]=0;Q=c[2439654]|0}c[3529556]=0;C=c[3541206]|0;gGC(C|0,Q|0,262144)|0;c[2424]=5800;fxU(0,425984);if((c[2394]|0)==0){S=c[2112932]|0}else{c[2394]=0;C=c[3532596]|0;c[2112932]=C;B=c[3532592]|0;if((B|0)!=0){gGC(9104152,B|0,280)|0}c[2113054]=c[2113060];S=C}C=c[2388014]|0;B=S|0;y=0;while(1){I=C+y|0;c[B>>2]=I;c[B+131072>>2]=I;I=y+1024|0;if(I>>>0>3145727){break}else{B=B+4|0;y=I}}y=c[2443412]|0;c[S+17408>>2]=y;c[S+82944>>2]=y;c[S+148480>>2]=y;B=y+1024|0;c[S+17412>>2]=B;c[S+82948>>2]=B;c[S+148484>>2]=B;B=y+2048|0;c[S+17416>>2]=B;c[S+82952>>2]=B;c[S+148488>>2]=B;B=y+3072|0;c[S+17420>>2]=B;c[S+82956>>2]=B;c[S+148492>>2]=B;B=c[2443362]|0;c[S+20480>>2]=B;c[S+86016>>2]=B;c[S+151552>>2]=B;y=B+1024|0;c[S+20484>>2]=y;c[S+86020>>2]=y;c[S+151556>>2]=y;y=B+2048|0;c[S+20488>>2]=y;c[S+86024>>2]=y;c[S+151560>>2]=y;y=B+3072|0;c[S+20492>>2]=y;c[S+86028>>2]=y;c[S+151564>>2]=y;y=c[2443368]|0;c[S+20496>>2]=y;c[S+86032>>2]=y;c[S+151568>>2]=y;B=y+1024|0;c[S+20500>>2]=B;c[S+86036>>2]=B;c[S+151572>>2]=B;B=y+2048|0;c[S+20504>>2]=B;c[S+86040>>2]=B;c[S+151576>>2]=B;B=y+3072|0;c[S+20508>>2]=B;c[S+86044>>2]=B;c[S+151580>>2]=B;B=c[2439956]|0;y=S+24576|0;C=6291456;while(1){G=B+(C-6291456)|0;c[y>>2]=G;c[y+65536>>2]=G;c[y+131072>>2]=G;G=C+1024|0;if(G>>>0>6815743){break}else{y=y+4|0;C=G}}C=c[2439612]|0;c[S+30720>>2]=C;c[S+30724>>2]=C+1024;C=c[2388018]|0;y=S+65280|0;B=16711680;while(1){G=C+(B-16711680)|0;c[y>>2]=G;c[y+65536>>2]=G;c[y+131072>>2]=G;G=B+1024|0;if(G>>>0>16777215){break}else{y=y+4|0;B=G}}c[S+196608>>2]=3166;c[S+196688>>2]=2826;c[S+196648>>2]=1346;c[S+196728>>2]=2614;B=c[3532592]|0;if((B|0)!=0){gGC(B|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;B=c[2387050]|0;c[2396]=93271;c[2394714]=93271;a[14113648]=127;c[2427090]=2047;b[4859088]=2047;b[4859091]=b[4887388]|0;a[9718188]=-1;a[9718189]=-1;a[9718190]=-1;a[9718181]=63;a[9718206]=-1;a[9718208]=a[9718208]|-128;a[9718209]=a[9718209]&15;b[4859098]=0;c[3526934]=0;a[9638440]=0;c[2444184]=0;a[9718207]=a[9718207]&7|24;c[355e3]=2047;a[1428184]=0;c[2440230]=B;B=0;while(1){if((B|0)>=1024){T=0;break}U=9638528+(B<<2)|0;if((c[U>>2]|0)==0){A=47054;break}else{B=B+1|0}}do{if((A|0)==47054){B=gGq(128)|0;c[U>>2]=B;if((B|0)==0){T=0;break}gGz(B|0,0,128);T=B}}while(0);c[2440232]=T;c[2112948]=2594;c[2112946]=774;Ux(0,7575,0);c[2407030]=256;c[2407068]=3;c[2443624]=148;a[638648]=0;B=c[642608+(c[2436]<<2)>>2]|0;y=c[B+128>>2]|0;if((c[B+52>>2]&4|0)==0){c[2113068]=y;C=c[B+132>>2]|0;c[2113070]=C;c[2443814]=y;c[2440436]=C;V=y;W=C}else{c[2113070]=y;C=c[B+132>>2]|0;c[2113068]=C;c[2440436]=y;c[2443814]=C;V=C;W=y}y=ag(V<<1,W)|0;C=gGq(y)|0;c[2112926]=C;if((C|0)!=0){gGz(C|0,0,y|0)}if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];y=c[3532592]|0;if((y|0)!=0){gGC(9104152,y|0,280)|0}c[2113054]=c[2113060]}RI();y=c[2394]|0;C=c[14130368+(y<<2)>>2]|0;if((C|0)!=0){gGC(C|0,9104152,280)|0}c[8452240+(y<<2)>>2]=c[2113054];c[2394]=-1;gd6(c[2396]|0);c[2113156]=0;a[9628264]=0;c[2407033]=0;y=c[3541206]|0;c[3541190]=y;c[3541198]=y;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=y+256;c[3541199]=y+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=y+512;c[3541200]=y+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=y+768;c[3541201]=y+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;if(a[5450480]|0){c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2]}b[4887136]=0;b[4887120]=0;b[4877612]=0;b[4877608]=0;b[7054948]=0;b[4879944]=0;b[4887192]=0;b[4887168]=0;a[9750992]=0;a[6923448]=0;a[9758536]=0;a[9758544]=0;a[9758528]=0;F=0;i=e;return F|0}}while(0);c[2426724]=0;F=1;i=e;return F|0}function d8B(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4004300+(b*112|0)>>2];c[a+104>>2]=c[4004304+(b*112|0)>>2];c[a+108>>2]=c[4004308+(b*112|0)>>2];d=0;return d|0}function d8C(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=4004200+(b*112|0);e=0;return e|0}function d8D(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5348860+(b*112|0)>>2];c[a+104>>2]=c[5348864+(b*112|0)>>2];c[a+108>>2]=c[5348868+(b*112|0)>>2];d=0;return d|0}function d8E(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=5348760+(b*112|0);e=0;return e|0}function d8F(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1870608+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function d8G(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>45){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5350104+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function d8H(){var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;e=i;i=i+120|0;f=e|0;g=e+112|0;c[2439986]=1048576;a[1276728]=0;c[3527364]=16384;a[7303744]=1;c[3527368]=65536;c[3527464]=64;c[2439648]=4096;c[2439528]=256;c[2426724]=0;c[2388014]=0;c[3541206]=1048576;c[2439654]=1310720;c[2387050]=1310720;c[2405658]=1314816;c[2388018]=1314816;c[2443412]=1380352;c[2443368]=1384448;c[2443362]=1417216;c[2439956]=1433600;c[2439612]=1957888;c[2411668]=1959936;c[3529572]=1959936;c[2405810]=3008512;c[2406520]=7202816;c[3530012]=11397120;h=0;while(1){if((h|0)>=1024){break}j=9638528+(h<<2)|0;if((c[j>>2]|0)==0){k=47148;break}else{h=h+1|0}}do{if((k|0)==47148){h=gGq(11401216)|0;c[j>>2]=h;if((h|0)==0){break}c[2426724]=h;gGz(h|0,0,11401216);c[2388014]=h;l=c[2439986]|0;c[3541206]=h+l;m=l+262144|0;c[2439654]=h+m;l=(a[1276728]|0?786432:0)+m|0;c[2387050]=h+l;m=h+(l+4096)|0;c[2405658]=m;c[2388018]=m;c[2443412]=h+(l+69632);c[2443368]=h+(l+73728);c[2443362]=h+(l+106496);c[2439956]=h+(l+122880);c[2439612]=h+(l+647168);m=l+649216|0;l=h+m|0;c[2411668]=l;c[3529572]=l;l=m+(ag(c[2439528]|0,c[2439648]|0)|0)|0;c[2405810]=h+l;m=(ag(a[7303744]|0?256:0,c[3527364]|0)|0)+l|0;c[2406520]=h+m;l=m+(ag(c[3527464]|0,c[3527368]|0)|0)|0;c[3530012]=h+l;c[2414208]=h+(l+4096);l=0;while(1){if((l|0)>=1024){n=0;break}o=9638528+(l<<2)|0;if((c[o>>2]|0)==0){k=47153;break}else{l=l+1|0}}do{if((k|0)==47153){l=gGq(2097152)|0;c[o>>2]=l;if((l|0)==0){n=0;break}gGz(l|0,0,2097152);n=l}}while(0);c[3529556]=n;if((R6((c[2388014]|0)+1|0,0,2)|0)!=0){p=1;i=e;return p|0}if((R6(c[2388014]|0,1,2)|0)!=0){p=1;i=e;return p|0}if((fvF(c[2387050]|0,2,11596)|0)!=0){p=1;i=e;return p|0}if((R6(c[3529556]|0,3,2)|0)!=0){p=1;i=e;return p|0}if((R6((c[3529556]|0)+1|0,4,2)|0)!=0){p=1;i=e;return p|0}if((R6((c[3529556]|0)+1048576|0,5,2)|0)!=0){p=1;i=e;return p|0}if((R6((c[3529556]|0)+1048577|0,6,2)|0)!=0){p=1;i=e;return p|0}l=c[3529556]|0;h=l+524288|0;m=l+131072|0;gGC(h|0,m|0,131072)|0;gGz(m|0,0,131072);m=l+1572864|0;h=l+1179648|0;gGC(m|0,h|0,131072)|0;gGz(h|0,0,131072);h=c[3527364]|0;m=c[2405810]|0;if((h|0)>0){q=0;do{r=q<<8;gGz(m+r|0,0,256);s=q<<9;t=0;do{u=1<<3-t;v=(c[687296+(t<<2)>>2]|0)+s|0;w=0;do{x=v+(c[608544+(w<<2)>>2]|0)|0;y=(w<<4)+r|0;z=0;do{A=x+(c[6669416+(z<<2)>>2]|0)|0;if(((d[l+((A|0)/8|0)|0]|0)&128>>>((A&7)>>>0)|0)!=0){A=m+(y+z)|0;a[A]=(d[A]|0|u)&255}z=z+1|0;}while((z|0)<16);w=w+1|0;}while((w|0)<16);t=t+1|0;}while((t|0)<4);q=q+1|0;}while((q|0)<(h|0))}h=c[3527368]|0;q=c[2406520]|0;if((h|0)>0){m=0;do{t=m<<6;gGz(q+t|0,0,64);r=m<<7;s=0;do{w=1<<3-s;u=(c[687296+(s<<2)>>2]|0)+r|0;v=0;do{z=u+(c[6669224+(v<<2)>>2]|0)|0;y=(v<<3)+t|0;x=0;do{A=z+(c[614800+(x<<2)>>2]|0)|0;if(((d[l+((A|0)/8|0)|0]|0)&128>>>((A&7)>>>0)|0)!=0){A=q+(y+x)|0;a[A]=(d[A]|0|w)&255}x=x+1|0;}while((x|0)<8);v=v+1|0;}while((v|0)<8);s=s+1|0;}while((s|0)<4);m=m+1|0;}while((m|0)<(h|0))}gGz(l|0,0,2097152);if((R6(l,7,2)|0)!=0){p=1;i=e;return p|0}if((R6((c[3529556]|0)+1|0,8,2)|0)!=0){p=1;i=e;return p|0}if((R6((c[3529556]|0)+262144|0,9,2)|0)!=0){p=1;i=e;return p|0}if((R6((c[3529556]|0)+262145|0,10,2)|0)!=0){p=1;i=e;return p|0}h=c[2439648]|0;m=c[3529556]|0;q=c[3529572]|0;if((h|0)>0){s=0;while(1){t=s<<8;gGz(q+t|0,0,256);r=s<<9;v=0;do{w=1<<3-v;u=(c[683256+(v<<2)>>2]|0)+r|0;x=0;do{y=u+(c[608544+(x<<2)>>2]|0)|0;z=(x<<4)+t|0;A=0;do{B=y+(c[6669416+(A<<2)>>2]|0)|0;if(((d[m+((B|0)/8|0)|0]|0)&128>>>((B&7)>>>0)|0)!=0){B=q+(z+A)|0;a[B]=(d[B]|0|w)&255}A=A+1|0;}while((A|0)<16);x=x+1|0;}while((x|0)<16);v=v+1|0;}while((v|0)<4);v=s+1|0;if((v|0)<(h|0)){s=v}else{C=0;break}}}else{C=0}while(1){if((C|0)>=1024){break}D=9638528+(C<<2)|0;if((c[D>>2]|0)==(m|0)){k=47198;break}else{C=C+1|0}}if((k|0)==47198){gGr(m);c[D>>2]=0}c[3529556]=0;s=c[3541206]|0;if((c[3542200]|0)==0){p=1;i=e;return p|0}h=f+108|0;c[h>>2]=0;q=f+100|0;c[q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,11)|0;do{if((c[h>>2]|0)!=0){l=c[q>>2]|0;c[g>>2]=9534384;v=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[v&16383](g,11,0)|0;if((l|0)<1){p=1;i=e;return p|0}if((gzL(s,0,11)|0)==0){break}else{p=1}i=e;return p|0}}while(0);c[2424]=5800;fxU(0,425984);if((c[2394]|0)==0){E=c[2112932]|0}else{c[2394]=0;s=c[3532596]|0;c[2112932]=s;q=c[3532592]|0;if((q|0)!=0){gGC(9104152,q|0,280)|0}c[2113054]=c[2113060];E=s}s=c[2388014]|0;q=E|0;h=0;while(1){m=s+h|0;c[q>>2]=m;c[q+131072>>2]=m;m=h+1024|0;if(m>>>0>262143){break}else{q=q+4|0;h=m}}h=c[2439956]|0;c[E+4096>>2]=h;c[E+69632>>2]=h;c[E+135168>>2]=h;q=h+1024|0;c[E+4100>>2]=q;c[E+69636>>2]=q;c[E+135172>>2]=q;q=h+2048|0;c[E+4104>>2]=q;c[E+69640>>2]=q;c[E+135176>>2]=q;q=h+3072|0;c[E+4108>>2]=q;c[E+69644>>2]=q;c[E+135180>>2]=q;q=h+4096|0;c[E+4112>>2]=q;c[E+69648>>2]=q;c[E+135184>>2]=q;q=h+5120|0;c[E+4116>>2]=q;c[E+69652>>2]=q;c[E+135188>>2]=q;q=h+6144|0;c[E+4120>>2]=q;c[E+69656>>2]=q;c[E+135192>>2]=q;q=h+7168|0;c[E+4124>>2]=q;c[E+69660>>2]=q;c[E+135196>>2]=q;q=h+8192|0;c[E+4128>>2]=q;c[E+69664>>2]=q;c[E+135200>>2]=q;q=h+9216|0;c[E+4132>>2]=q;c[E+69668>>2]=q;c[E+135204>>2]=q;q=h+10240|0;c[E+4136>>2]=q;c[E+69672>>2]=q;c[E+135208>>2]=q;q=h+11264|0;c[E+4140>>2]=q;c[E+69676>>2]=q;c[E+135212>>2]=q;q=h+12288|0;c[E+4144>>2]=q;c[E+69680>>2]=q;c[E+135216>>2]=q;q=h+13312|0;c[E+4148>>2]=q;c[E+69684>>2]=q;c[E+135220>>2]=q;q=h+14336|0;c[E+4152>>2]=q;c[E+69688>>2]=q;c[E+135224>>2]=q;q=h+15360|0;c[E+4156>>2]=q;c[E+69692>>2]=q;c[E+135228>>2]=q;q=c[2443362]|0;c[E+4160>>2]=q;c[E+69696>>2]=q;c[E+135232>>2]=q;h=q+1024|0;c[E+4164>>2]=h;c[E+69700>>2]=h;c[E+135236>>2]=h;h=q+2048|0;c[E+4168>>2]=h;c[E+69704>>2]=h;c[E+135240>>2]=h;h=q+3072|0;c[E+4172>>2]=h;c[E+69708>>2]=h;c[E+135244>>2]=h;h=q+4096|0;c[E+4176>>2]=h;c[E+69712>>2]=h;c[E+135248>>2]=h;h=q+5120|0;c[E+4180>>2]=h;c[E+69716>>2]=h;c[E+135252>>2]=h;h=q+6144|0;c[E+4184>>2]=h;c[E+69720>>2]=h;c[E+135256>>2]=h;h=q+7168|0;c[E+4188>>2]=h;c[E+69724>>2]=h;c[E+135260>>2]=h;h=q+8192|0;c[E+4192>>2]=h;c[E+69728>>2]=h;c[E+135264>>2]=h;h=q+9216|0;c[E+4196>>2]=h;c[E+69732>>2]=h;c[E+135268>>2]=h;h=q+10240|0;c[E+4200>>2]=h;c[E+69736>>2]=h;c[E+135272>>2]=h;h=q+11264|0;c[E+4204>>2]=h;c[E+69740>>2]=h;c[E+135276>>2]=h;h=q+12288|0;c[E+4208>>2]=h;c[E+69744>>2]=h;c[E+135280>>2]=h;h=q+13312|0;c[E+4212>>2]=h;c[E+69748>>2]=h;c[E+135284>>2]=h;h=q+14336|0;c[E+4216>>2]=h;c[E+69752>>2]=h;c[E+135288>>2]=h;h=q+15360|0;c[E+4220>>2]=h;c[E+69756>>2]=h;c[E+135292>>2]=h;h=c[2443368]|0;q=E+4224|0;s=1081344;while(1){m=h+(s-1081344)|0;c[q>>2]=m;c[q+65536>>2]=m;c[q+131072>>2]=m;m=s+1024|0;if(m>>>0>1114111){break}else{q=q+4|0;s=m}}s=c[2443412]|0;c[E+8192>>2]=s;c[E+73728>>2]=s;c[E+139264>>2]=s;q=s+1024|0;c[E+8196>>2]=q;c[E+73732>>2]=q;c[E+139268>>2]=q;q=s+2048|0;c[E+8200>>2]=q;c[E+73736>>2]=q;c[E+139272>>2]=q;q=s+3072|0;c[E+8204>>2]=q;c[E+73740>>2]=q;c[E+139276>>2]=q;q=c[2439612]|0;c[E+10240>>2]=q;c[E+10244>>2]=q+1024;q=c[2388018]|0;s=E+65280|0;h=16711680;while(1){m=q+(h-16711680)|0;c[s>>2]=m;c[s+65536>>2]=m;c[s+131072>>2]=m;m=h+1024|0;if(m>>>0>16777215){break}else{s=s+4|0;h=m}}c[E+196608>>2]=3588;c[E+196688>>2]=2346;c[E+196648>>2]=328;c[E+196728>>2]=2354;h=c[3532592]|0;if((h|0)!=0){gGC(h|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;h=c[2387050]|0;c[2396]=93271;c[2394714]=93271;a[14113648]=127;c[2427090]=2047;b[4859088]=2047;b[4859091]=b[4887388]|0;a[9718188]=-1;a[9718189]=-1;a[9718190]=-1;a[9718181]=63;a[9718206]=-1;a[9718208]=a[9718208]|-128;a[9718209]=a[9718209]&15;b[4859098]=0;c[3526934]=0;a[9638440]=0;c[2444184]=0;a[9718207]=a[9718207]&7|24;c[355e3]=2047;a[1428184]=0;c[2440230]=h;h=0;while(1){if((h|0)>=1024){F=0;break}G=9638528+(h<<2)|0;if((c[G>>2]|0)==0){k=47219;break}else{h=h+1|0}}do{if((k|0)==47219){h=gGq(128)|0;c[G>>2]=h;if((h|0)==0){F=0;break}gGz(h|0,0,128);F=h}}while(0);c[2440232]=F;c[2112948]=2594;c[2112946]=774;Ux(0,7575,0);c[2407030]=256;c[2407068]=3;Tq(801280);c[2443624]=11002;a[638648]=1;a[5450480]=1;h=c[642608+(c[2436]<<2)>>2]|0;s=c[h+128>>2]|0;if((c[h+52>>2]&4|0)==0){c[2113068]=s;q=c[h+132>>2]|0;c[2113070]=q;c[2443814]=s;c[2440436]=q;H=s;I=q}else{c[2113070]=s;q=c[h+132>>2]|0;c[2113068]=q;c[2440436]=s;c[2443814]=q;H=q;I=s}s=ag(H<<1,I)|0;q=gGq(s)|0;c[2112926]=q;if((q|0)!=0){gGz(q|0,0,s|0)}if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];s=c[3532592]|0;if((s|0)!=0){gGC(9104152,s|0,280)|0}c[2113054]=c[2113060]}RI();s=c[2394]|0;q=c[14130368+(s<<2)>>2]|0;if((q|0)!=0){gGC(q|0,9104152,280)|0}c[8452240+(s<<2)>>2]=c[2113054];c[2394]=-1;gd6(c[2396]|0);c[2113156]=0;a[9628264]=0;c[2407033]=0;s=c[3541206]|0;c[3541190]=s;c[3541198]=s;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=s+256;c[3541199]=s+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=s+512;c[3541200]=s+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=s+768;c[3541201]=s+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;if(a[5450480]|0){c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2]}b[4887136]=0;b[4887120]=0;b[4877612]=0;b[4877608]=0;b[7054948]=0;b[4879944]=0;b[4887192]=0;b[4887168]=0;a[9750992]=0;a[6923448]=0;a[9758536]=0;a[9758544]=0;a[9758528]=0;p=0;i=e;return p|0}}while(0);c[2426724]=0;p=1;i=e;return p|0}function d8I(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;a=c[2112926]|0;gGz(a|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);if((b[4875508]|0)==0){d=c[3530012]|0;R8(d);return}d8J(0);d8J(1);d8K(2,4096,16,2,-9,-8);d8K(2,4096,16,1,-9,-8);d8K(2,4096,16,0,-9,-8);f=(c[2113070]|0)-8|0;g=c[2443368]|0;h=e[4877612]|0;i=e[4877608]|0;j=c[2406520]|0;k=0;l=0;while(1){m=(l<<6)-i|0;n=((m|0)<-8?m+512|0:m)-16|0;m=(n|0)>8;o=(n|0)<(f|0);p=k;q=0;while(1){r=e[g+(p<<1)>>1]|0;s=r>>>13;t=(r&16383)+38912|0;r=(q<<6)-h|0;u=(r|0)<-8?r+512|0:r;if((u-9|0)>>>0<303&m&o){Sq(a,t,u,n,s,4,0,256,j)}else{Sr(a,t,u,n,s,4,0,256,j)}s=q+1|0;if((s|0)<64){p=p+1|0;q=s}else{break}}q=l+1|0;if((q|0)<64){k=k+64|0;l=q}else{break}}d=c[3530012]|0;R8(d);return}function d8J(a){a=a|0;var b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;b=(c[2113070]|0)-16|0;d=(a|0)==1;f=d?c[2443362]|0:c[2439956]|0;g=(a|0)==0;a=e[4887136]|0;h=e[4887120]|0;i=c[2112926]|0;j=c[2405810]|0;k=0;l=0;while(1){m=(k<<4)-h|0;n=((m|0)<-16?m+512|0:m)-16|0;m=(n|0)>16;o=(n|0)<(b|0);L62421:do{if(d){p=l;q=0;while(1){r=e[f+(p<<1)>>1]|0;s=r&8191|8192;t=r>>>13|8;r=(q<<4)-a|0;u=(r|0)<-16?r+512|0:r;r=u-17|0;do{if(g){if(r>>>0<287&m&o){Sy(i,s,u,n,t,4,0,j);break}else{Sz(i,s,u,n,t,4,0,j);break}}}while(0);if(r>>>0<287&m&o){SG(i,s,u,n,t,4,0,0,j)}else{SH(i,s,u,n,t,4,0,0,j)}v=q+1|0;if((v|0)>=32){break L62421}p=p+1|0;q=v}}else{q=l;p=0;while(1){v=e[f+(q<<1)>>1]|0;w=v&8191;x=v>>>13;v=(p<<4)-a|0;y=(v|0)<-16?v+512|0:v;do{if(g){if((y-17|0)>>>0<287&m&o){Sy(i,w,y,n,x,4,0,j);break}else{Sz(i,w,y,n,x,4,0,j);break}}}while(0);x=p+1|0;if((x|0)>=32){break L62421}q=q+1|0;p=x}}}while(0);n=k+1|0;if((n|0)<32){k=n;l=l+32|0}else{break}}return}function d8K(a,d,f,g,h,i){a=a|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;j=c[2443412]|0;k=(c[2113070]|0)-f|0;if((d|0)<=0){return}l=(g|0)==-1;m=248-f|0;n=h-23|0;h=i-16|0;i=(f|0)==32;o=(c[2439648]|0)-1|0;p=c[2112926]|0;q=c[3529572]|0;r=0;while(1){s=b[j+((r|3)-4<<1)>>1]|0;t=s&65535;if(s<<16>>16==8192){u=47308;break}s=e[j+((r|1)<<1)>>1]|0;v=s>>>15;w=s>>>9;x=w&31;if((v|0)==0){y=(w&12|0)==12?2:0}else{y=v}L62456:do{if((y|0)==(g|0)|l){v=t&16384;w=(e[j+((r|2)<<1)>>1]|0)>>>(a>>>0)&o;z=n+(s&511)|0;A=h+(m-t&255)|0;if((f|0)==16){B=(v|0)==0;do{if((z-17|0)>>>0<287&(A|0)>16&(A|0)<(k|0)){if(B){SG(p,w,z,A,x,4,0,512,q);break L62456}else{SI(p,w,z,A,x,4,0,512,q);break}}else{if(B){SH(p,w,z,A,x,4,0,512,q);break}else{SJ(p,w,z,A,x,4,0,512,q);break}}}while(0);if(!i){break}}else if((f|0)!=32){break}B=(v|0)==0;if((z-33|0)>>>0<255&(A|0)>32&(A|0)<(k|0)){if(B){SW(p,w,z,A,x,4,0,512,q);break}else{SY(p,w,z,A,x,4,0,512,q);break}}else{if(B){SX(p,w,z,A,x,4,0,512,q);break}else{SZ(p,w,z,A,x,4,0,512,q);break}}}}while(0);x=r+4|0;if((x|0)<(d|0)){r=x}else{u=47307;break}}if((u|0)==47308){return}else if((u|0)==47307){return}}function d8L(){var a=0;a=c[2112926]|0;gGz(a|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);d8M();d8K(2,3328,16,2,0,0);if((b[7054948]|0)!=0){d8N()}d8K(2,3328,16,1,0,0);d8O(32,16);d8K(2,3328,16,0,0,0);R8(c[3530012]|0);return}function d8M(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;a=(c[2113070]|0)-16|0;b=c[2443362]|0;d=e[4887136]|0;f=e[4887120]|0;g=c[2112926]|0;h=c[2405810]|0;i=0;j=0;while(1){k=(j<<4)-f|0;l=((k|0)<-16?k+512|0:k)-16|0;k=(l|0)>16;m=(l|0)<(a|0);n=i;o=0;while(1){p=n<<1;q=e[b+(p<<1)>>1]|0;r=e[b+((p|1)<<1)>>1]|0;p=(o<<4)-d|0;s=(p|0)<-16?p+512|0:p;if((s-17|0)>>>0<287&k&m){Sy(g,q,s,l,r,4,0,h)}else{Sz(g,q,s,l,r,4,0,h)}r=o+1|0;if((r|0)<32){n=n+1|0;o=r}else{break}}o=j+1|0;if((o|0)<32){i=i+32|0;j=o}else{break}}return}function d8N(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;a=c[2439956]|0;d=(b[4879944]|0)==0;f=e[4887168]|0;g=e[4887192]|0;h=c[2113070]|0;i=c[2113068]|0;j=c[2112926]|0;k=0;l=0;while(1){m=k+496|0;L62502:do{if((k&1|0)==0){n=((k|0)/2|0)+496+f&511;o=(n|0)<(h|0);p=ag(i,n)|0;n=f+m&511;q=(n|0)<(h|0);r=ag(i,n)|0;n=0;s=l;while(1){t=b[a+(s<<1)>>1]&255;do{if((t|0)!=0){if(!d){u=g+n&511;if(!(u>>>0<320&q)){break}b[j+(r+u<<1)>>1]=(t|256)&65535;break}if((n&1|0)!=0){break}u=g+((n|0)/2|0)&511;if(!(u>>>0<320&o)){break}b[j+(p+u<<1)>>1]=(t|256)&65535}}while(0);t=n+1|0;if((t|0)<512){n=t;s=s+1|0}else{break}}}else{s=f+m&511;n=(s|0)<(h|0);p=ag(i,s)|0;s=0;o=l;while(1){r=b[a+(o<<1)>>1]&255;do{if(!((r|0)==0|d)){q=g+s&511;if(!(q>>>0<320&n)){break}b[j+(p+q<<1)>>1]=(r|256)&65535}}while(0);r=s+1|0;if((r|0)>=512){break L62502}s=r;o=o+1|0}}}while(0);m=k+1|0;if((m|0)<512){k=m;l=l+512|0}else{break}}return}function d8O(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;d=(c[2113070]|0)-b|0;f=c[2443368]|0;g=(a|0)>0;h=ag(b,a)|0;i=e[4877612]|0;j=e[4877608]|0;k=c[2112926]|0;l=c[2406520]|0;m=0;n=0;while(1){if(g){o=(ag(n,b)|0)-j|0;p=((o|0)<-8?o+256|0:o)-16|0;o=(p|0)>8;q=(p|0)<(d|0);r=(p|0)>16;s=m;t=0;while(1){u=s<<1;v=e[f+(u<<1)>>1]|0;w=e[f+((u|1)<<1)>>1]|0;u=(ag(t,b)|0)-i|0;x=((u|0)<-8?h:0)+u|0;do{if((b|0)==8){if((x-9|0)>>>0<303&o&q){Sq(k,v,x,p,w,4,0,128,l);break}else{Sr(k,v,x,p,w,4,0,128,l);break}}else if((b|0)==16){if((x-17|0)>>>0<287&r&q){SG(k,v,x,p,w,4,0,128,l);break}else{SH(k,v,x,p,w,4,0,128,l);break}}}while(0);w=t+1|0;if((w|0)>=(a|0)){break}s=s+1|0;t=w}y=m+a|0}else{y=m}t=n+1|0;if((t|0)<32){m=y;n=t}else{break}}return}function d8P(){var a=0;a=c[2112926]|0;gGz(a|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);d8M();if((b[7054948]|0)!=0){d8N()}d8K(4,1024,32,-1,0,0);d8O(64,8);R8(c[3530012]|0);return}function d8Q(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;if((b|0)==4194305|(b|0)==4194307){Uv(0,d);return}if((b&-16|0)!=5242880){return}c[2420432]=9668920;L62558:do{switch(b>>>1&7|0){case 5:{c[2417237]=c[2417237]&65535|(d&255)<<16&983040;break};case 3:{c[2417237]=c[2417237]&1048320|d&255;break};case 2:{c[2417236]=c[2417236]&65535|(d&255)<<16&983040;break};case 1:{c[2417236]=c[2417236]&983295|(d&255)<<8;break};case 4:{c[2417237]=c[2417237]&983295|(d&255)<<8;break};case 6:{c[2420432]=9668920;e=c[2417236]|0;f=c[2417237]|0;g=(a[9668920]|0)!=0;if(e>>>0<f>>>0){if(g){break L62558}a[9668920]=1;c[2417231]=e;c[2417232]=0;c[2417233]=(f-e<<1)+2;a[9668952]=0;c[2417234]=-2;c[2417235]=0;break L62558}else{if(!g){break L62558}a[9668920]=0;break L62558}break};case 0:{c[2417236]=c[2417236]&1048320|d&255;break};default:{}}}while(0);c[2417236]=c[2417236]&1048575;c[2417237]=c[2417237]&1048575;return}function d8R(b,d){b=b|0;d=d|0;var e=0,f=0;if((b|0)!=2097152){return}b=d&65535;c[2420432]=9668920;do{if((b&64|0)==0){if((a[9668920]|0)==0){break}a[9668920]=0;a[9668952]=0}else{d=c[2417236]|0;e=c[2417237]|0;f=(a[9668920]|0)!=0;if(d>>>0<e>>>0){if(f){break}a[9668920]=1;c[2417231]=d;c[2417232]=0;c[2417233]=(e-d<<1)+2;a[9668952]=0;c[2417234]=-2;c[2417235]=0;break}else{if(!f){break}a[9668920]=0;break}}}while(0);c[2420432]=9668920;if((b&16|0)==0){c[2417239]=0;return}else{c[2417239]=1048576;return}}function d8S(a){a=a|0;var b=0;if((a|0)!=4194305){b=0;return b|0}b=c[2113156]&255;return b|0}function d8T(f){f=f|0;var g=0,h=0;if((f|0)==2097152){g=b[4775248]|0;return g|0}else if((f|0)==3276782){g=((a[9635105]&8)!=0?128:0)|((a[9635104]&8)!=0?64:0);return g|0}else if((f|0)==2097154){g=b[4775249]|0;return g|0}else if((f|0)==3276790){g=((a[9635105]&4)!=0?128:0)|((a[9635104]&4)!=0?64:0);return g|0}else if((f|0)==3276734){g=((a[9635105]&32)!=0?128:0)|((a[9635104]&32)!=0?64:0);return g|0}else if((f|0)==3276794){g=((a[9635105]&2)!=0?128:0)|((a[9635104]&2)!=0?64:0);return g|0}else if((f|0)==3276766){g=((a[9635105]&16)!=0?128:0)|((a[9635104]&16)!=0?64:0);return g|0}else if((f|0)==3276796){g=((a[9635105]&1)!=0?128:0)|((a[9635104]&1)!=0?64:0);return g|0}else if((f|0)==3276670){g=((a[9635105]&64)!=0?128:0)|((a[9635104]&64)!=0?64:0);return g|0}else if((f|0)==3276542){g=((a[9635105]|0)<0?128:0)|((a[9635104]|0)<0?64:0);return g|0}else{if((f&-65536|0)!=1441792){g=0;return g|0}h=(e[(c[3529390]|0)+170>>1]<<16&8323072|f&65534)<<1;f=c[2387816]|0;g=d[f+(h|1)|0]<<8|d[f+h|0]<<12|d[f+(h|2)|0]<<4|d[f+(h|3)|0];return g|0}return 0}function d8U(d,e){d=d|0;e=e|0;var f=0;f=c[2387200]|0;a[f+(d&16383^1)|0]=e;e=d&16382;if((d&8192|0)==0){return}d=b[f+e>>1]|0;f=e>>>1;if(d<<16>>16==0){c[2405126]=f}c[(c[3530010]|0)+((f&4095)<<2)>>2]=((d&65535)>>>6<<3&65535)<<8&63488|((d&65535)>>>11<<3&65535)<<3|((d&65535)>>>1<<3&65535)>>>3&31;return}function d8V(a,d){a=a|0;d=d|0;var e=0;e=a&16382;b[(c[2387200]|0)+e>>1]=d;if((a&8192|0)==0){return}a=e>>>1;if(d<<16>>16==0){c[2405126]=a}c[(c[3530010]|0)+((a&4095)<<2)>>2]=((d&65535)>>>6<<3&65535)<<8&63488|((d&65535)>>>11<<3&65535)<<3|((d&65535)>>>1<<3&65535)>>>3&31;return}function d8W(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5631540+(b*112|0)>>2];c[a+104>>2]=c[5631544+(b*112|0)>>2];c[a+108>>2]=c[5631548+(b*112|0)>>2];d=0;return d|0}function d8X(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=5631440+(b*112|0);e=0;return e|0}function d8Y(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>23){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=2094792+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function d8Z(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>32){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5632336+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function d8_(){var b=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;b=i;i=i+240|0;e=b|0;f=b+112|0;g=b+120|0;j=b+232|0;c[2414966]=0;c[2388156]=0;c[2387816]=1048576;c[3541206]=17825792;c[3529760]=17825792;c[3529714]=18874368;c[3530010]=20971520;c[2387042]=20987904;c[2414670]=21131264;c[2388282]=21131264;c[2387200]=21196800;c[2386460]=21213184;c[2386352]=21229568;c[2387348]=21360640;c[2387346]=21491712;c[3529560]=21622784;c[3529390]=21624832;c[2411666]=21628928;k=0;while(1){if((k|0)>=1024){break}l=9638528+(k<<2)|0;if((c[l>>2]|0)==0){m=47467;break}else{k=k+1|0}}do{if((m|0)==47467){k=gGq(21628928)|0;c[l>>2]=k;if((k|0)==0){break}c[2414966]=k;gGz(k|0,0,21628928);c[2388156]=k;c[2387816]=k+1048576;n=k+17825792|0;c[3541206]=n;c[3529760]=n;c[3529714]=k+18874368;c[3530010]=k+20971520;c[2387042]=k+20987904;n=k+21131264|0;c[2414670]=n;c[2388282]=n;c[2387200]=k+21196800;c[2386460]=k+21213184;c[2386352]=k+21229568;c[2387348]=k+21360640;c[2387346]=k+21491712;c[3529560]=k+21622784;c[3529390]=k+21624832;n=k+21628928|0;c[2411666]=n;c[2414206]=n;if((R6(k,0,2)|0)!=0){o=1;i=b;return o|0}if((R6((c[2388156]|0)+1|0,1,2)|0)!=0){o=1;i=b;return o|0}if((R6((c[2387816]|0)+2|0,2,4)|0)!=0){o=1;i=b;return o|0}if((R6(c[2387816]|0,3,4)|0)!=0){o=1;i=b;return o|0}if((R6((c[2387816]|0)+3|0,4,4)|0)!=0){o=1;i=b;return o|0}if((R6((c[2387816]|0)+1|0,5,4)|0)!=0){o=1;i=b;return o|0}k=c[3529760]|0;if((c[3542200]|0)==0){o=1;i=b;return o|0}n=g+108|0;c[n>>2]=0;p=g+100|0;c[p>>2]=0;q=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[q&16383](g,6)|0;do{if((c[n>>2]|0)!=0){q=c[p>>2]|0;c[j>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](j,6,0)|0;if((q|0)<1){o=1;i=b;return o|0}if((gzL(k,0,6)|0)==0){break}else{o=1}i=b;return o|0}}while(0);k=c[3529714]|0;if((c[3542200]|0)==0){o=1;i=b;return o|0}p=e+108|0;c[p>>2]=0;n=e+100|0;c[n>>2]=0;q=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[q&16383](e,7)|0;do{if((c[p>>2]|0)!=0){q=c[n>>2]|0;c[f>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](f,7,0)|0;if((q|0)<1){o=1;i=b;return o|0}if((gzL(k,0,7)|0)==0){break}else{o=1}i=b;return o|0}}while(0);k=c[2387816]|0;n=k+8388609|0;p=k+8388610|0;q=k+8388611|0;r=k+8388612|0;s=k+8388613|0;t=k+8388614|0;u=k+8388615|0;v=k+8388608|0;w=v;x=0;do{y=k+x|0;a[v]=a[y]|0;a[n]=a[k+(x|4)|0]|0;a[p]=a[k+(x|1)|0]|0;a[q]=a[k+(x|5)|0]|0;a[r]=a[k+(x|2)|0]|0;a[s]=a[k+(x|6)|0]|0;a[t]=a[k+(x|3)|0]|0;a[u]=a[k+(x|7)|0]|0;z=y;y=w|0;A=w+4|0;B=d[A]|d[A+1|0]<<8|d[A+2|0]<<16|d[A+3|0]<<24|0;A=z|0;C=d[y]|d[y+1|0]<<8|d[y+2|0]<<16|d[y+3|0]<<24|0;a[A]=C&255;C=C>>8;a[A+1|0]=C&255;C=C>>8;a[A+2|0]=C&255;C=C>>8;a[A+3|0]=C&255;A=z+4|0;C=B;a[A]=C&255;C=C>>8;a[A+1|0]=C&255;C=C>>8;a[A+2|0]=C&255;C=C>>8;a[A+3|0]=C&255;x=x+8|0;}while((x|0)<8388608);a[k+16777215|0]=(d[k+8388607|0]|0)>>>4;x=16777215;do{x=x-1|0;a[k+x|0]=(d[k+((x|0)/2|0)|0]|0)>>>((x<<2&4)>>>0)&15;}while((x|0)>0);fxU(0,425984);if((c[2394]|0)==0){D=c[2112932]|0}else{c[2394]=0;x=c[3532596]|0;c[2112932]=x;k=c[3532592]|0;if((k|0)!=0){gGC(9104152,k|0,280)|0}c[2113054]=c[2113060];D=x}x=c[2388156]|0;k=D|0;w=0;while(1){u=x+w|0;c[k>>2]=u;c[k+131072>>2]=u;u=w+1024|0;if(u>>>0>1048575){break}else{k=k+4|0;w=u}}w=c[2386352]|0;k=D+4096|0;x=1048576;while(1){u=w+(x-1048576)|0;c[k>>2]=u;c[k+65536>>2]=u;c[k+131072>>2]=u;u=x+1024|0;if(u>>>0>1179647){break}else{k=k+4|0;x=u}}x=c[2387348]|0;k=D+4608|0;w=1179648;while(1){u=x+(w-1179648)|0;c[k>>2]=u;c[k+65536>>2]=u;c[k+131072>>2]=u;u=w+1024|0;if(u>>>0>1310719){break}else{k=k+4|0;w=u}}w=c[2387346]|0;k=D+5120|0;x=1310720;while(1){u=w+(x-1310720)|0;c[k>>2]=u;c[k+65536>>2]=u;c[k+131072>>2]=u;u=x+1024|0;if(u>>>0>1441791){break}else{k=k+4|0;x=u}}x=c[2387200]|0;c[D+5888>>2]=x;k=D+71424|0;c[k>>2]=x;c[D+136960>>2]=x;w=x+1024|0;c[D+5892>>2]=w;u=D+71428|0;c[u>>2]=w;c[D+136964>>2]=w;w=x+2048|0;c[D+5896>>2]=w;t=D+71432|0;c[t>>2]=w;c[D+136968>>2]=w;w=x+3072|0;c[D+5900>>2]=w;s=D+71436|0;c[s>>2]=w;c[D+136972>>2]=w;w=x+4096|0;c[D+5904>>2]=w;r=D+71440|0;c[r>>2]=w;c[D+136976>>2]=w;w=x+5120|0;c[D+5908>>2]=w;q=D+71444|0;c[q>>2]=w;c[D+136980>>2]=w;w=x+6144|0;c[D+5912>>2]=w;p=D+71448|0;c[p>>2]=w;c[D+136984>>2]=w;w=x+7168|0;c[D+5916>>2]=w;n=D+71452|0;c[n>>2]=w;c[D+136988>>2]=w;w=x+8192|0;c[D+5920>>2]=w;v=D+71456|0;c[v>>2]=w;c[D+136992>>2]=w;w=x+9216|0;c[D+5924>>2]=w;A=D+71460|0;c[A>>2]=w;c[D+136996>>2]=w;w=x+10240|0;c[D+5928>>2]=w;B=D+71464|0;c[B>>2]=w;c[D+137e3>>2]=w;w=x+11264|0;c[D+5932>>2]=w;z=D+71468|0;c[z>>2]=w;c[D+137004>>2]=w;w=x+12288|0;c[D+5936>>2]=w;y=D+71472|0;c[y>>2]=w;c[D+137008>>2]=w;w=x+13312|0;c[D+5940>>2]=w;E=D+71476|0;c[E>>2]=w;c[D+137012>>2]=w;w=x+14336|0;c[D+5944>>2]=w;F=D+71480|0;c[F>>2]=w;c[D+137016>>2]=w;w=x+15360|0;c[D+5948>>2]=w;x=D+71484|0;c[x>>2]=w;c[D+137020>>2]=w;w=c[2386460]|0;c[D+5952>>2]=w;c[D+71488>>2]=w;c[D+137024>>2]=w;G=w+1024|0;c[D+5956>>2]=G;c[D+71492>>2]=G;c[D+137028>>2]=G;G=w+2048|0;c[D+5960>>2]=G;c[D+71496>>2]=G;c[D+137032>>2]=G;G=w+3072|0;c[D+5964>>2]=G;c[D+71500>>2]=G;c[D+137036>>2]=G;G=w+4096|0;c[D+5968>>2]=G;c[D+71504>>2]=G;c[D+137040>>2]=G;G=w+5120|0;c[D+5972>>2]=G;c[D+71508>>2]=G;c[D+137044>>2]=G;G=w+6144|0;c[D+5976>>2]=G;c[D+71512>>2]=G;c[D+137048>>2]=G;G=w+7168|0;c[D+5980>>2]=G;c[D+71516>>2]=G;c[D+137052>>2]=G;G=w+8192|0;c[D+5984>>2]=G;c[D+71520>>2]=G;c[D+137056>>2]=G;G=w+9216|0;c[D+5988>>2]=G;c[D+71524>>2]=G;c[D+137060>>2]=G;G=w+10240|0;c[D+5992>>2]=G;c[D+71528>>2]=G;c[D+137064>>2]=G;G=w+11264|0;c[D+5996>>2]=G;c[D+71532>>2]=G;c[D+137068>>2]=G;G=w+12288|0;c[D+6e3>>2]=G;c[D+71536>>2]=G;c[D+137072>>2]=G;G=w+13312|0;c[D+6004>>2]=G;c[D+71540>>2]=G;c[D+137076>>2]=G;G=w+14336|0;c[D+6008>>2]=G;c[D+71544>>2]=G;c[D+137080>>2]=G;G=w+15360|0;c[D+6012>>2]=G;c[D+71548>>2]=G;c[D+137084>>2]=G;G=c[3529560]|0;c[D+6016>>2]=G;c[D+71552>>2]=G;c[D+137088>>2]=G;w=G+1024|0;c[D+6020>>2]=w;c[D+71556>>2]=w;c[D+137092>>2]=w;w=c[3529390]|0;c[D+6024>>2]=w;c[D+71560>>2]=w;c[D+137096>>2]=w;G=w+1024|0;c[D+6028>>2]=G;c[D+71564>>2]=G;c[D+137100>>2]=G;G=w+2048|0;c[D+6032>>2]=G;c[D+71568>>2]=G;c[D+137104>>2]=G;G=w+3072|0;c[D+6036>>2]=G;c[D+71572>>2]=G;c[D+137108>>2]=G;G=c[2388282]|0;w=D+65280|0;H=16711680;while(1){I=G+(H-16711680)|0;c[w>>2]=I;c[w+65536>>2]=I;c[w+131072>>2]=I;I=H+1024|0;if(I>>>0>16777215){break}else{w=w+4|0;H=I}}c[D+196648>>2]=1366;c[D+196728>>2]=438;c[D+196608>>2]=508;c[D+196688>>2]=2360;c[k>>2]=1;c[u>>2]=1;c[t>>2]=1;c[s>>2]=1;c[r>>2]=1;c[q>>2]=1;c[p>>2]=1;c[n>>2]=1;c[v>>2]=1;c[A>>2]=1;c[B>>2]=1;c[z>>2]=1;c[y>>2]=1;c[E>>2]=1;c[F>>2]=1;c[x>>2]=1;c[D+196652>>2]=1748;c[D+196732>>2]=2052;H=c[3532592]|0;if((H|0)!=0){gGC(H|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;H=c[3529714]|0;c[2420432]=9668920;w=0;do{G=~~+U(+(+X(1.1,+(+(w|0)))*16.0));I=(G|0)/2|0;J=(G|0)/4|0;K=(G|0)/8|0;L=w<<4;M=0;do{N=c[604464+(M<<4)>>2]|0;O=ag(c[604468+(M<<4)>>2]|0,G)|0;P=ag(c[604472+(M<<4)>>2]|0,I)|0;c[14104600+(M+L<<2)>>2]=ag(O+K+P+(ag(c[604476+(M<<4)>>2]|0,J)|0)|0,N)|0;M=M+1|0;}while((M|0)<16);w=w+1|0;}while((w|0)<49);c[2417236]=0;c[2417237]=0;a[9668952]=0;c[2417239]=0;c[2417240]=H;c[2417234]=-2;c[2417241]=200;h[1208621]=1.0;c[2417244]=3;c[2417245]=0;if((c[2420362]|0)==0){c[2420362]=gGq(400)|0}c[2420432]=9668920;h[1208621]=.5;c[2417244]=3;Ux(0,1e4,1);c[2407030]=192;c[2407068]=3;w=c[642608+(c[2436]<<2)>>2]|0;x=c[w+128>>2]|0;if((c[w+52>>2]&4|0)==0){c[2113068]=x;F=c[w+132>>2]|0;c[2113070]=F;c[2443814]=x;c[2440436]=F;Q=x;R=F}else{c[2113070]=x;F=c[w+132>>2]|0;c[2113068]=F;c[2440436]=x;c[2443814]=F;Q=F;R=x}x=ag(Q<<1,R)|0;F=gGq(x)|0;c[2112926]=F;if((F|0)!=0){gGz(F|0,0,x|0)}x=c[2414670]|0;gGz(x|0,0,(c[2411666]|0)-x|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];x=c[3532592]|0;if((x|0)!=0){gGC(9104152,x|0,280)|0}c[2113054]=c[2113060]}RI();x=c[2394]|0;F=c[14130368+(x<<2)>>2]|0;if((F|0)!=0){gGC(F|0,9104152,280)|0}c[8452240+(x<<2)>>2]=c[2113054];c[2394]=-1;c[2420432]=9668920;if((a[9668920]|0)!=0){a[9668920]=0;a[9668952]=0}c[2113156]=0;a[9628264]=0;c[2407033]=0;x=c[3541206]|0;c[3541190]=x;c[3541198]=x;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=x+256;c[3541199]=x+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=x+512;c[3541200]=x+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=x+768;c[3541201]=x+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;o=0;i=b;return o|0}}while(0);c[2414966]=0;o=1;i=b;return o|0}function d8$(){var a=0,b=0,d=0,e=0,f=0;c[2113070]=0;c[2113068]=0;a=c[2112926]|0;if((a|0)!=0){gGr(a);c[2112926]=0}Uw(0);c[2420432]=9668920;gGz(9668920,0,64);a=c[2420362]|0;if((a|0)!=0){gGr(a);c[2420362]=0}if((c[2392]|0)>=0){a=0;do{b=14130368+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}b=14130384+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}a=a+1|0;}while((a|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;a=c[2414966]|0;b=0;while(1){if((b|0)>=1024){e=47554;break}f=9638528+(b<<2)|0;if((c[f>>2]|0)==(a|0)){break}else{b=b+1|0}}if((e|0)==47554){c[2414966]=0;c[3541206]=0;return 0}gGr(a);c[f>>2]=0;c[2414966]=0;c[3541206]=0;return 0}function d80(){var f=0,g=0,i=0,j=0,k=0.0,l=0.0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;if((a[9624192]|0)!=0){f=c[2414670]|0;gGz(f|0,0,(c[2411666]|0)-f|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060]}RI();f=c[2394]|0;g=c[14130368+(f<<2)>>2]|0;if((g|0)!=0){gGC(g|0,9104152,280)|0}c[8452240+(f<<2)>>2]=c[2113054];c[2394]=-1;c[2420432]=9668920;if((a[9668920]|0)!=0){a[9668920]=0;a[9668952]=0}c[2113156]=0;a[9628264]=0;c[2407033]=0;f=c[3541206]|0;c[3541190]=f;c[3541198]=f;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=f+256;c[3541199]=f+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=f+512;c[3541200]=f+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=f+768;c[3541201]=f+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4}c[2387624]=-1;f=0;g=-1;i=-1;do{g=((a[9633464+f|0]&1)<<f^g&65535)&65535;i=((a[9631320+f|0]&1)<<f^i&65535)&65535;f=f+1|0;}while((f|0)<16);b[4775248]=g;b[4775249]=i;i=c[2438]|0;g=gGU(i,(i|0)<0|0?-1:0,16e6,0)|0;i=gGS(g,K,15360,0)|0;g=i;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];i=c[3532592]|0;if((i|0)!=0){gGC(9104152,i|0,280)|0}c[2113054]=c[2113060]}c[2113056]=g;i=RG(g)|0;c[2113054]=(c[2113054]|0)+i;c[2276108]=-1;c[2113056]=-1;i=c[2394]|0;c[8452200+(i<<2)>>2]=8193;c[2276080]=256;if((c[2276079]|0)>>>0<256){RH(1);j=c[2394]|0}else{j=i}i=c[14130368+(j<<2)>>2]|0;if((i|0)!=0){gGC(i|0,9104152,280)|0}c[8452240+(j<<2)>>2]=c[2113054];c[2394]=-1;j=c[2112964]|0;if((j|0)!=0){i=a[9688]|0;g=i?534:0;c[2420432]=9668920;k=+(c[2417241]|0);f=~~(+((g>>>0)/534|0|0)*k);l=k/534.0;m=c[2420362]|0;if((a[9668920]|0)==0){n=m;o=f}else{p=c[2417240]|0;q=(c[2417231]|0)+(c[2417239]|0)|0;r=c[2417232]|0;s=c[2417234]|0;t=c[2417233]|0;u=c[2417235]|0;k=+h[1208621];L62835:do{if((f|0)==0){v=m;w=0;x=u;y=r;z=s}else{A=s;B=r;C=u;D=f;E=m;while(1){F=(d[p+(q+((B|0)/2|0))|0]|0)>>>((B<<2&4^4)>>>0);G=(c[14104600+((F&15|C<<4)<<2)>>2]|0)+A|0;if((G|0)>2047){H=2047}else{H=(G|0)<-2048?-2048:G}G=(c[7045224+((F&7)<<2)>>2]|0)+C|0;if((G|0)>48){I=48}else{I=(G|0)<0?0:G}J=E+2|0;b[E>>1]=~~(k*+(H<<4|0))&65535;L=D-1|0;M=B+1|0;if((M|0)<(t|0)){N=I;O=M;P=H}else{if((a[9668952]|0)==0){break}else{N=0;O=0;P=-2}}if((L|0)==0){v=J;w=0;x=N;y=O;z=P;break L62835}else{A=P;B=O;C=N;D=L;E=J}}a[9668920]=0;v=J;w=L;x=I;y=M;z=H}}while(0);c[2417232]=y;c[2417234]=z;c[2417235]=x;n=v;o=w}if((o|0)!=0){gGz(n|0,0,o<<1|0)}L62853:do{if(i){o=j;k=0.0;n=1;while(1){w=c[2417244]|0;if((w&1|0)==0){Q=0}else{Q=~~(+(b[m+(~~k<<1)>>1]|0)*+h[1208621])}if((w&2|0)==0){R=0}else{R=~~(+(b[m+(~~k<<1)>>1]|0)*+h[1208621])}if((Q|0)<-32768){S=-32768}else{S=(Q|0)>32767?32767:Q}if((R|0)<-32768){T=-32768}else{T=(R|0)>32767?32767:R}if((c[2417245]|0)==0){b[o>>1]=S&65535;b[o+2>>1]=T&65535}else{b[o>>1]=(e[o>>1]|0)+S&65535;w=o+2|0;b[w>>1]=(e[w>>1]|0)+T&65535}if((n|0)>=(g|0)){break L62853}o=o+4|0;k=l+k;n=n+1|0}}}while(0);Uu(0,j,g)}if((c[2112968]|0)==0){return 0}d81()|0;return 0}function d81(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;if((a[9547472]|0)!=0){d=c[2387200]|0;f=c[3530010]|0;g=8192;do{if((g&8192|0)!=0){h=b[d+g>>1]|0;i=(g|0)/2|0;if(h<<16>>16==0){c[2405126]=i}c[f+((i&4095)<<2)>>2]=((h&65535)>>>6<<3&65535)<<8&63488|((h&65535)>>>11<<3&65535)<<3|((h&65535)>>>1<<3&65535)>>>3&31}g=g+2|0;}while((g|0)<16384);a[9547472]=0}g=c[2113068]|0;f=c[2113070]|0;d=ag(f,g)|0;if((d|0)>0){h=c[2112926]|0;i=c[2387042]|0;j=0;do{b[h+(j<<1)>>1]=c[2405126]&65535;b[i+(j<<1)>>1]=0;j=j+1|0;}while((j|0)<(d|0))}d85(c[2387348]|0,16);d85(c[2387346]|0,0);d=c[3529390]|0;j=c[2386460]|0;i=c[2387816]|0;h=b[d+3840>>1]&511;if((h|0)==0){k=c[2112926]|0}else{l=b[d+3848>>1]<<8&3840;m=d+3842|0;d=j+((h<<2)-4<<1)|0;n=c[2112926]|0;o=c[2387042]|0;p=0;while(1){q=(b[m>>1]|0)<0;r=q?4:-4;s=1;t=q?j:d;while(1){q=e[t>>1]|0;u=q>>>11;do{if((u|0)!=31&(u|0)==(p|0)){v=e[m>>1]|0;w=e[t+2>>1]|0;x=b[t+4>>1]|0;y=x&65535;z=y>>>11<<3&56;A=z+8|0;B=y>>>8<<3&56;C=B+8|0;D=c[607640+(w>>>10<<2)>>2]<<8;E=(y<<16&983040|e[t+6>>1])<<6;if((E-2+(ag(((A|0)/2|0)<<1,C)|0)|0)>=16777216){F=t;break}G=w&1023;w=G-64|0;H=q&2047;I=H-64|0;J=y&16384;K=y&32768;y=x&240|l;x=ag(A,D)|0;L=ag(C,D)|0;D=c[607928+((v>>>(((v&32768|0)==0&p>>>0>(v&31)>>>0?10:8)>>>0)&3)<<2)>>2]|0;v=L+32768>>16;L=x+32768>>16;do{if(!((v|0)==0|(L|0)==0)){x=L+I|0;if((x|0)<0){break}M=v+w|0;if(!((M|0)>-1&(g|0)>(I|0)&(f|0)>(w|0))){break}if((J|0)==0){N=0}else{N=ag(B|7,A)|0}if((K|0)==0){O=N}else{O=z|N|7}P=(C<<12|0)/(v|0)|0;Q=(A<<12|0)/(L|0)|0;R=(w|0)<0?64-G|0:0;S=(I|0)<0?64-H|0:0;T=(M|0)<(f|0)?v:f-w|0;M=(x|0)<(g|0)?L:g-I|0;x=(ag(g,R+w|0)|0)+I|0;if((R|0)>=(T|0)){break}U=D&65535;if((S|0)>=(M|0)){break}V=n+(x<<1)|0;W=o+(x<<1)|0;x=R;while(1){R=ag((ag(x,P)|0)>>12,A)|0;X=S;do{Y=a[i+((((ag(X,Q)|0)>>12)+R^O)+E)|0]|0;Z=Y&255;do{if(Y<<24>>24!=15){_=W+(X<<1)|0;if((e[_>>1]&D|0)!=0){break}b[V+(X<<1)>>1]=y|Z;b[_>>1]=U}}while(0);X=X+1|0;}while((X|0)<(M|0));X=x+1|0;if((X|0)<(T|0)){V=V+(g<<1)|0;W=W+(g<<1)|0;x=X}else{break}}}}while(0);F=t+(r<<1)|0}else{F=t+(r<<1)|0}}while(0);if((s|0)>=(h|0)){break}s=s+1|0;t=F}t=p+1|0;if((t|0)<32){p=t}else{k=n;break}}}n=c[2386352]|0;p=c[3529560]|0;F=0;do{h=F<<3;O=F<<8;o=0;do{N=o<<3;do{if((h|0)<(f|0)&(N|0)<(g|0)){l=e[n+((o|O)<<1)>>1]|0;if((l&32768|0)!=0){break}m=l>>>3&4094;d=e[p+(m<<1)>>1]|0;Sr(k,(d<<16|e[p+((m|1)<<1)>>1])&262128|l&15,N,h,d>>>4&31,4,15,3584,i)}}while(0);o=o+1|0;}while((o|0)<40);F=F+1|0;}while((F|0)<28);R8(c[3530010]|0);return 0}function d82(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;e=i;i=i+240|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;l=e+80|0;m=e+96|0;n=e+112|0;o=e+128|0;p=e+144|0;q=e+160|0;r=e+176|0;s=e+192|0;t=e+208|0;u=e+224|0;if((d|0)!=0){c[d>>2]=169736}if((b&32|0)!=0){gGz(u|0,0,12);d=c[2414670]|0;c[u>>2]=d;c[u+4>>2]=(c[2411666]|0)-d;c[u+12>>2]=162152;d=c[2076592]|0;gj[d&4095](u)|0}if((b&64|0)==0){i=e;return 0}b=s|0;gGz(r|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){u=s+9|0;s=q;d=q|0;v=q+4|0;w=q+12|0;x=r|0;y=r+4|0;z=r+12|0;A=0;do{gGC(b|0,614896,11)|0;a[u]=A+48&255;B=8452256+(A<<2)|0;gGz(s|0,0,12);c[d>>2]=B;c[v>>2]=4;c[w>>2]=164976;gj[c[2076592]&4095](q)|0;if((c[B>>2]|0)!=0){c[x>>2]=c[14130368+(A<<2)>>2];c[y>>2]=c[8452184+(A<<2)>>2];c[z>>2]=b;B=c[2076592]|0;gj[B&4095](r)|0}A=A+1|0;}while((A|0)<=(c[2392]|0))}c[2420432]=9668920;gGz(p|0,0,12);c[p>>2]=9668920;c[p+4>>2]=1;c[p+12>>2]=166792;gj[c[2076592]&4095](p)|0;p=(c[2420432]|0)+4|0;gGz(o|0,0,12);c[o>>2]=p;c[o+4>>2]=4;c[o+12>>2]=501920;gj[c[2076592]&4095](o)|0;o=(c[2420432]|0)+8|0;gGz(n|0,0,12);c[n>>2]=o;c[n+4>>2]=4;c[n+12>>2]=386264;gj[c[2076592]&4095](n)|0;n=(c[2420432]|0)+12|0;gGz(m|0,0,12);c[m>>2]=n;c[m+4>>2]=4;c[m+12>>2]=300600;gj[c[2076592]&4095](m)|0;m=(c[2420432]|0)+16|0;gGz(l|0,0,12);c[l>>2]=m;c[l+4>>2]=4;c[l+12>>2]=229200;gj[c[2076592]&4095](l)|0;l=(c[2420432]|0)+20|0;gGz(k|0,0,12);c[k>>2]=l;c[k+4>>2]=4;c[k+12>>2]=178640;gj[c[2076592]&4095](k)|0;k=(c[2420432]|0)+24|0;gGz(j|0,0,12);c[j>>2]=k;c[j+4>>2]=4;c[j+12>>2]=143632;gj[c[2076592]&4095](j)|0;j=(c[2420432]|0)+28|0;gGz(h|0,0,12);c[h>>2]=j;c[h+4>>2]=4;c[h+12>>2]=115352;gj[c[2076592]&4095](h)|0;h=(c[2420432]|0)+32|0;gGz(g|0,0,12);c[g>>2]=h;c[g+4>>2]=1;c[g+12>>2]=90288;gj[c[2076592]&4095](g)|0;g=(c[2420432]|0)+36|0;gGz(f|0,0,12);c[f>>2]=g;c[f+4>>2]=4;c[f+12>>2]=70312;gj[c[2076592]&4095](f)|0;Ut(0);gGz(t|0,0,12);c[t>>2]=9620504;c[t+4>>2]=4;c[t+12>>2]=582800;gj[c[2076592]&4095](t)|0;a[9547472]=1;i=e;return 0}function d83(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4327268+(b*112|0)>>2];c[a+104>>2]=c[4327272+(b*112|0)>>2];c[a+108>>2]=c[4327276+(b*112|0)>>2];d=0;return d|0}function d84(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=4327168+(b*112|0);e=0;return e|0}function d85(a,d){a=a|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=a;a=c[3529560]|0;g=(c[3529390]|0)+(d+106)|0;d=c[2112926]|0;h=c[2387816]|0;i=c[2113070]|0;j=c[2113068]|0;k=0;do{l=k>>8<<4;m=(k<<4&4080)-(b[g>>1]&4095)|0;n=(m|0)<-15?m+4096|0:m;do{if((l|0)<(i|0)&(n|0)<(j|0)){m=e[f+(k<<1)>>1]|0;if((m&32768|0)!=0){break}o=m>>>3&4094;p=e[a+(o<<1)>>1]|0;SH(d,(p<<16|(e[a+((o|1)<<1)>>1]|0))>>>2&65520|m&15,n,l,p>>>4&255,4,15,0,h)}}while(0);k=k+1|0;}while((k|0)<65536);return}function d86(e,f){e=e|0;f=f|0;var g=0,h=0,i=0;if((e&16776192|0)==1088512){g=c[2388280]|0;a[g+(e&65535^1)|0]=f;if(!(a[638952]|0)){return}a[g+40600|0]=4;a[g+40601|0]=0;a[g+40602|0]=0;a[g+40603|0]=0;return}if((e&16760832|0)==8388608){g=c[2387198]|0;a[g+(e&16383)|0]=f;h=e&16382;i=b[g+h>>1]|0;c[(c[3530008]|0)+(h>>>1<<2)>>2]=((i&65535)>>>10<<3&248)<<8|((i&255)<<3&255)>>>3|(((i&65535)>>>5<<3&255|(i&65535)>>>7&4)&255)<<3&2016;return}if((e|0)==10485760|(e|0)==10485761){Uv(0,f);return}else if((e|0)==6291456|(e|0)==6291457){e=c[3530250]|0;i=f&64;if((d[e]|0|0)==(i|0)){return}a[e]=i&255;e=c[3541206]|0;f=(c[2386646]|0)+(i<<12)|0;gGC(e|0,f|0,262144)|0;return}else{return}}function d87(e,f){e=e|0;f=f|0;var g=0,h=0,i=0;if((e&16776192|0)==1088512){g=c[2388280]|0;b[g+(e&65534)>>1]=f;if(!(a[638952]|0)){return}a[g+40600|0]=4;a[g+40601|0]=0;a[g+40602|0]=0;a[g+40603|0]=0;return}if((e&16760832|0)==8388608){g=e&16382;b[(c[2387198]|0)+g>>1]=f;c[(c[3530008]|0)+(g>>>1<<2)>>2]=((f&65535)>>>10<<3&248)<<8|((f&255)<<3&255)>>>3|(((f&65535)>>>5<<3&255|(f&65535)>>>7&4)&255)<<3&2016;return}if((e|0)==7340032){b[c[3529800]>>1]=f&511;return}else if((e|0)==6291456){g=c[3530250]|0;h=f&64;if((d[g]|0|0)==(h|0)){return}a[g]=h&255;g=c[3541206]|0;i=(c[2386646]|0)+(h<<12)|0;gGC(g|0,i|0,262144)|0;return}else if((e|0)==10485760){Uv(0,f&255);return}else{return}}function d88(b){b=b|0;var d=0,f=0;if(a[638952]|0){d=c[2388280]|0;a[d+40600|0]=4;a[d+40601|0]=0;a[d+40602|0]=0;a[d+40603|0]=0}if((b|0)==3145728|(b|0)==3145729){f=(e[4774996]|0)>>>((b<<3&8^8)>>>0)&255;return f|0}else if((b|0)==10485761){f=c[2113156]&255;return f|0}else if((b|0)==4194304|(b|0)==4194305){f=(e[4774912]|0)>>>((b<<3&8^8)>>>0)&255;return f|0}else{f=0;return f|0}return 0}function d89(d){d=d|0;var e=0,f=0;if(a[638952]|0){e=c[2388280]|0;a[e+40600|0]=4;a[e+40601|0]=0;a[e+40602|0]=0;a[e+40603|0]=0}if((d|0)==3145728){f=b[4774996]|0;return f|0}else if((d|0)==4194304){f=b[4774912]|0;return f|0}else{f=0;return f|0}return 0}function d9a(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4480060+(b*112|0)>>2];c[a+104>>2]=c[4480064+(b*112|0)>>2];c[a+108>>2]=c[4480068+(b*112|0)>>2];d=0;return d|0}function d9b(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=4479960+(b*112|0);e=0;return e|0}function d9c(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1787304+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function d9d(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>3){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5144320+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function d9e(){var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0;e=i;i=i+360|0;f=e|0;g=e+112|0;h=e+120|0;j=e+232|0;k=e+240|0;l=e+352|0;c[2414964]=0;c[2388154]=0;c[3530844]=1048576;c[3530608]=5242880;c[3541206]=9437184;c[2386646]=9699328;c[3530008]=10223616;c[2414668]=10256384;c[2388280]=10256384;c[2387198]=10321920;c[2386458]=10338304;c[3530262]=10340352;c[3529800]=10360832;c[3530250]=10360834;c[2411664]=10360835;m=0;while(1){if((m|0)>=1024){break}n=9638528+(m<<2)|0;if((c[n>>2]|0)==0){o=47773;break}else{m=m+1|0}}do{if((o|0)==47773){m=gGq(10360835)|0;c[n>>2]=m;if((m|0)==0){break}c[2414964]=m;gGz(m|0,0,10360835);c[2388154]=m;c[3530844]=m+1048576;c[3530608]=m+5242880;c[3541206]=m+9437184;c[2386646]=m+9699328;c[3530008]=m+10223616;p=m+10256384|0;c[2414668]=p;c[2388280]=p;c[2387198]=m+10321920;c[2386458]=m+10338304;c[3530262]=m+10340352;c[3529800]=m+10360832;c[3530250]=m+10360834;p=m+10360835|0;c[2411664]=p;c[2414204]=p;if((R6(m+1|0,0,2)|0)!=0){q=1;i=e;return q|0}if((R6(c[2388154]|0,1,2)|0)!=0){q=1;i=e;return q|0}m=k+108|0;p=k+100|0;r=h+108|0;s=h+100|0;t=0;while(1){u=t<<19;v=(c[3530844]|0)+u|0;w=t+2|0;if((c[3542200]|0)==0){q=1;o=47887;break}c[m>>2]=0;c[p>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,w)|0;if((c[m>>2]|0)!=0){x=c[p>>2]|0;c[l>>2]=9534384;y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[y&16383](l,w,0)|0;if((x|0)<1){q=1;o=47886;break}if((gzL(v,0,w)|0)!=0){q=1;o=47890;break}}w=(c[3530608]|0)+u|0;u=t+6|0;if((c[3542200]|0)==0){q=1;o=47896;break}c[r>>2]=0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](h,u)|0;if((c[r>>2]|0)!=0){v=c[s>>2]|0;c[j>>2]=9534384;x=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[x&16383](j,u,0)|0;if((v|0)<1){q=1;o=47894;break}if((gzL(w,0,u)|0)!=0){q=1;o=47895;break}}u=t+1|0;if((u|0)<4){t=u}else{o=47787;break}}if((o|0)==47896){i=e;return q|0}else if((o|0)==47886){i=e;return q|0}else if((o|0)==47887){i=e;return q|0}else if((o|0)==47787){t=c[2386646]|0;if((c[3542200]|0)==0){q=1;i=e;return q|0}s=f+108|0;c[s>>2]=0;r=f+100|0;c[r>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,10)|0;do{if((c[s>>2]|0)==0){z=0}else{p=c[r>>2]|0;c[g>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](g,10,0)|0;if((p|0)<1){q=1;i=e;return q|0}if((gzL(t,0,10)|0)==0){z=0;break}else{q=1}i=e;return q|0}}while(0);while(1){if((z|0)>=1024){A=0;break}B=9638528+(z<<2)|0;if((c[B>>2]|0)==0){o=47793;break}else{z=z+1|0}}do{if((o|0)==47793){t=gGq(1048576)|0;c[B>>2]=t;if((t|0)==0){A=0;break}gGz(t|0,0,1048576);A=t}}while(0);t=A;r=c[2388154]|0;s=r;gGC(A|0,r|0,1048576)|0;r=0;while(1){p=r>>>4<<17&131072|r&16515072;m=r>>>8&1;u=r>>>3&1;w=r>>>14&1;v=r>>>2&1;x=r>>>15&1;y=r>>>17&1;C=r&1;D=r>>>9&1;E=r>>>13&1;F=r>>>10&1;G=r>>>5&1;H=r>>>16&1;I=r>>>7&1;J=r>>>12&1;K=r>>>6&1;L=r>>>1&1;M=r>>>11&1;N=b[t+((M|C<<10|m<<16|u<<15|w<<14|v<<13|x<<12|y<<11|D<<9|E<<8|F<<7|G<<6|H<<5|I<<4|J<<3|K<<2|L<<1|p)<<1)>>1]|0;O=b[t+((v|C<<8|F<<16|L<<15|M<<14|J<<13|G<<12|D<<11|y<<10|w<<9|E<<7|K<<6|x<<5|m<<4|u<<3|H<<2|I<<1|p)<<1)>>1]|0;b[s+(r<<1)>>1]=(N&65535)>>>3&1|N<<1&2|(N&65535)>>>2<<6&64|(N&65535)>>>4<<7&128|(N&65535)>>>7<<5&32|(N&65535)>>>1<<4&16|(N&65535)>>>6<<3&8|(N&65535)>>>5<<2&4|((O&65535)>>>10&1|(O&65535)>>>15<<5|(O&65535)>>>12<<6&64|(O&65535)>>>9<<7&128|(O&65535)>>>8<<4&16|(O&65535)>>>11<<3&8|(O&65535)>>>13<<2&4|(O&65535)>>>14<<1&2)<<8;O=r+1|0;if((O|0)<524288){r=O}else{P=0;break}}while(1){if((P|0)>=1024){Q=0;break}R=9638528+(P<<2)|0;if((c[R>>2]|0)==(A|0)){o=47799;break}else{P=P+1|0}}if((o|0)==47799){gGr(A);c[R>>2]=0;Q=0}while(1){if((Q|0)>=1024){S=0;break}T=9638528+(Q<<2)|0;if((c[T>>2]|0)==0){o=47802;break}else{Q=Q+1|0}}do{if((o|0)==47802){r=gGq(2097152)|0;c[T>>2]=r;if((r|0)==0){S=0;break}gGz(r|0,0,2097152);S=r}}while(0);r=c[3530844]|0;gGC(S|0,r|0,2097152)|0;s=0;while(1){t=s<<2&4|s&16515144|s>>>8&1|s>>>10<<17&131072|s>>>2<<16&65536|s>>>5<<15&32768|s>>>9<<14&16384|s>>>7<<13&8192|s>>>13<<12&4096|s>>>16<<11&2048|s>>>14<<10&1024|s>>>11<<9&512|s>>>4<<8&256|s>>>1<<7&128|s>>>12<<5&32|s>>>17<<4&16|s>>>15<<1&2;O=a[S+s|0]|0;a[r+t|0]=(O&255)>>>2<<7|O&2|O<<4&16|(O&255)>>>7<<3|(O&255)>>>6&1|(O&255)>>>3<<6&64|(O&255)>>>4<<5&32|(O&255)>>>5<<2&4;O=a[S+(s+524288)|0]|0;a[r+(t+524288)|0]=(O&255)>>>7<<5|(O&255)>>>4<<7|O<<1&2|(O&255)>>>3&1|(O&255)>>>2<<6&64|(O&255)>>>1<<4&16|(O&255)>>>6<<3&8|(O&255)>>>5<<2&4;O=a[S+(s+1048576)|0]|0;a[r+(t+1048576)|0]=(O&255)>>>1<<7|O&8|(O&255)>>>7<<5|O<<4&16|(O&255)>>>2&1|(O&255)>>>4<<6&64|(O&255)>>>5<<2&4|(O&255)>>>6<<1&2;O=a[S+(s+1572864)|0]|0;a[r+(t+1572864)|0]=(O&255)>>>2<<7|O&2|O<<4&16|(O&255)>>>7<<3|(O&255)>>>6&1|(O&255)>>>3<<6&64|(O&255)>>>4<<5&32|(O&255)>>>5<<2&4;O=s+1|0;if((O|0)<524288){s=O}else{U=0;break}}while(1){if((U|0)>=1024){V=0;break}W=9638528+(U<<2)|0;if((c[W>>2]|0)==(S|0)){o=47808;break}else{U=U+1|0}}if((o|0)==47808){gGr(S);c[W>>2]=0;V=0}while(1){if((V|0)>=1024){X=0;break}Y=9638528+(V<<2)|0;if((c[Y>>2]|0)==0){o=47811;break}else{V=V+1|0}}do{if((o|0)==47811){s=gGq(2097152)|0;c[Y>>2]=s;if((s|0)==0){X=0;break}gGz(s|0,0,2097152);X=s}}while(0);s=c[3530608]|0;gGC(X|0,s|0,2097152)|0;r=0;while(1){O=r<<11&2048|r&16663040|r>>>15&1|r>>>5<<16&65536|r>>>12<<15&32768|r>>>8<<13&8192|r>>>3<<12&4096|r>>>7<<10&1024|r>>>16<<8&256|r>>>4<<7&128|r>>>2<<6&64|r>>>6<<5&32|r>>>11<<4&16|r>>>13<<3&8|r>>>1<<2&4|r>>>10<<1&2;t=a[X+r|0]|0;a[s+O|0]=(t&255)>>>7<<5|(t&255)>>>4<<7|t<<1&2|(t&255)>>>3&1|(t&255)>>>2<<6&64|(t&255)>>>1<<4&16|(t&255)>>>6<<3&8|(t&255)>>>5<<2&4;t=a[X+(r+524288)|0]|0;a[s+(O+524288)|0]=(t&255)>>>1<<7|t&8|(t&255)>>>7<<5|t<<4&16|(t&255)>>>2&1|(t&255)>>>4<<6&64|(t&255)>>>5<<2&4|(t&255)>>>6<<1&2;t=a[X+(r+1048576)|0]|0;a[s+(O+1048576)|0]=(t&255)>>>2<<7|t&2|t<<4&16|(t&255)>>>7<<3|(t&255)>>>6&1|(t&255)>>>3<<6&64|(t&255)>>>4<<5&32|(t&255)>>>5<<2&4;t=a[X+(r+1572864)|0]|0;a[s+(O+1572864)|0]=(t&255)>>>7<<5|(t&255)>>>4<<7|t<<1&2|(t&255)>>>3&1|(t&255)>>>2<<6&64|(t&255)>>>1<<4&16|(t&255)>>>6<<3&8|(t&255)>>>5<<2&4;t=r+1|0;if((t|0)<524288){r=t}else{Z=0;break}}while(1){if((Z|0)>=1024){_=0;break}$=9638528+(Z<<2)|0;if((c[$>>2]|0)==(X|0)){o=47817;break}else{Z=Z+1|0}}if((o|0)==47817){gGr(X);c[$>>2]=0;_=0}while(1){if((_|0)>=1024){aa=0;break}ab=9638528+(_<<2)|0;if((c[ab>>2]|0)==0){o=47820;break}else{_=_+1|0}}do{if((o|0)==47820){r=gGq(524288)|0;c[ab>>2]=r;if((r|0)==0){aa=0;break}gGz(r|0,0,524288);aa=r}}while(0);r=c[2386646]|0;gGC(aa|0,r|0,524288)|0;s=0;while(1){t=a[aa+s|0]|0;a[r+(s<<6&64|s&16252962|s>>>9&1|s>>>10<<18&262144|s>>>16<<17&131072|s>>>13<<16&65536|s>>>8<<15&32768|s>>>4<<14&16384|s>>>7<<13&8192|s>>>11<<12&4096|s>>>14<<11&2048|s>>>17<<10&1024|s>>>12<<9&512|s>>>6<<8&256|s>>>2<<7&128|s>>>18<<4&16|s>>>15<<3&8|s>>>3<<2&4)|0]=(t&255)>>>2<<7|t&2|t<<4&16|(t&255)>>>7<<3|(t&255)>>>6&1|(t&255)>>>3<<6&64|(t&255)>>>4<<5&32|(t&255)>>>5<<2&4;t=s+1|0;if((t|0)<524288){s=t}else{ac=0;break}}while(1){if((ac|0)>=1024){ad=0;break}ae=9638528+(ac<<2)|0;if((c[ae>>2]|0)==(aa|0)){o=47826;break}else{ac=ac+1|0}}if((o|0)==47826){gGr(aa);c[ae>>2]=0;ad=0}while(1){if((ad|0)>=1024){break}af=9638528+(ad<<2)|0;if((c[af>>2]|0)==0){o=47829;break}else{ad=ad+1|0}}L63177:do{if((o|0)==47829){s=gGq(2097152)|0;c[af>>2]=s;if((s|0)==0){break}gGz(s|0,0,2097152);r=c[3530844]|0;gGC(s|0,r|0,2097152)|0;t=0;do{O=t<<6;gGz(r+O|0,0,64);N=0;do{p=1<<3-N;I=(c[601464+(N<<2)>>2]|0)+O|0;H=0;do{u=I+(c[1238464+(H<<2)>>2]|0)|0;m=(H<<3)+O|0;x=0;do{K=u+(c[612704+(x<<2)>>2]|0)|0;if(((d[s+((K|0)/8|0)|0]|0)&128>>>((K&7)>>>0)|0)!=0){K=r+(m+x)|0;a[K]=(d[K]|0|p)&255}x=x+1|0;}while((x|0)<8);H=H+1|0;}while((H|0)<8);N=N+1|0;}while((N|0)<4);t=t+1|0;}while((t|0)<65536);t=c[3530608]|0;gGC(s|0,t|0,2097152)|0;r=0;while(1){N=r<<8;gGz(t+N|0,0,256);O=0;do{H=1<<3-O;p=(c[601464+(O<<2)>>2]|0)+N|0;I=0;do{x=p+(c[608544+(I<<2)>>2]|0)|0;m=(I<<4)+N|0;u=0;do{K=x+(c[612704+(u<<2)>>2]|0)|0;if(((d[s+((K|0)/8|0)|0]|0)&128>>>((K&7)>>>0)|0)!=0){K=t+(m+u)|0;a[K]=(d[K]|0|H)&255}u=u+1|0;}while((u|0)<16);I=I+1|0;}while((I|0)<16);O=O+1|0;}while((O|0)<4);O=r+1|0;if((O|0)<16384){r=O}else{ah=0;break}}while(1){if((ah|0)>=1024){break L63177}ai=9638528+(ah<<2)|0;if((c[ai>>2]|0)==(s|0)){break}else{ah=ah+1|0}}gGr(s);c[ai>>2]=0}}while(0);if((fa(c[c[642608+(c[2436]<<2)>>2]>>2]|0,268032)|0)==0){b[(c[2388154]|0)+25280>>1]=24582}else{a[638952]=1}fxU(0,425984);if((c[2394]|0)==0){aj=c[2112932]|0}else{c[2394]=0;r=c[3532596]|0;c[2112932]=r;t=c[3532592]|0;if((t|0)!=0){gGC(9104152,t|0,280)|0}c[2113054]=c[2113060];aj=r}r=c[2388154]|0;t=aj|0;O=0;while(1){N=r+O|0;c[t>>2]=N;c[t+131072>>2]=N;N=O+1024|0;if(N>>>0>1048575){break}else{t=t+4|0;O=N}}O=c[2388280]|0;t=aj+4096|0;r=1048576;while(1){N=O+(r-1048576)|0;c[t>>2]=N;c[t+65536>>2]=N;c[t+131072>>2]=N;N=r+1024|0;if(N>>>0>1088511){break}else{t=t+4|0;r=N}}fx$(O+39936|0,1088512,1089535,a[638952]|0?5:7);r=aj+4256|0;t=1089536;while(1){N=O+(t-1048576)|0;c[r>>2]=N;c[r+65536>>2]=N;c[r+131072>>2]=N;N=t+1024|0;if(N>>>0>1114111){break}else{r=r+4|0;t=N}}t=c[2386458]|0;c[aj+20480>>2]=t;c[aj+86016>>2]=t;c[aj+151552>>2]=t;r=t+1024|0;c[aj+20484>>2]=r;c[aj+86020>>2]=r;c[aj+151556>>2]=r;r=c[2387198]|0;c[aj+32768>>2]=r;c[aj+163840>>2]=r;t=r+1024|0;c[aj+32772>>2]=t;c[aj+163844>>2]=t;t=r+2048|0;c[aj+32776>>2]=t;c[aj+163848>>2]=t;t=r+3072|0;c[aj+32780>>2]=t;c[aj+163852>>2]=t;t=r+4096|0;c[aj+32784>>2]=t;c[aj+163856>>2]=t;t=r+5120|0;c[aj+32788>>2]=t;c[aj+163860>>2]=t;t=r+6144|0;c[aj+32792>>2]=t;c[aj+163864>>2]=t;t=r+7168|0;c[aj+32796>>2]=t;c[aj+163868>>2]=t;t=r+8192|0;c[aj+32800>>2]=t;c[aj+163872>>2]=t;t=r+9216|0;c[aj+32804>>2]=t;c[aj+163876>>2]=t;t=r+10240|0;c[aj+32808>>2]=t;c[aj+163880>>2]=t;t=r+11264|0;c[aj+32812>>2]=t;c[aj+163884>>2]=t;t=r+12288|0;c[aj+32816>>2]=t;c[aj+163888>>2]=t;t=r+13312|0;c[aj+32820>>2]=t;c[aj+163892>>2]=t;t=r+14336|0;c[aj+32824>>2]=t;c[aj+163896>>2]=t;t=r+15360|0;c[aj+32828>>2]=t;c[aj+163900>>2]=t;t=c[3530262]|0;r=aj+36864|0;O=9437184;while(1){N=t+(O-9437184)|0;c[r>>2]=N;c[r+65536>>2]=N;c[r+131072>>2]=N;N=O+1024|0;if(N>>>0>9457663){break}else{r=r+4|0;O=N}}c[aj+196648>>2]=1248;c[aj+196728>>2]=1824;c[aj+196608>>2]=2902;c[aj+196688>>2]=758;O=c[3532592]|0;if((O|0)!=0){gGC(O|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;Ux(0,7797,0);c[2407030]=256;c[2407068]=3;O=c[642608+(c[2436]<<2)>>2]|0;r=c[O+128>>2]|0;if((c[O+52>>2]&4|0)==0){c[2113068]=r;t=c[O+132>>2]|0;c[2113070]=t;c[2443814]=r;c[2440436]=t;ak=r;al=t}else{c[2113070]=r;t=c[O+132>>2]|0;c[2113068]=t;c[2440436]=r;c[2443814]=t;ak=t;al=r}r=ag(ak<<1,al)|0;t=gGq(r)|0;c[2112926]=t;if((t|0)!=0){gGz(t|0,0,r|0)}a[9624184]=0;r=c[2414668]|0;gGz(r|0,0,(c[2411664]|0)-r|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];r=c[3532592]|0;if((r|0)!=0){gGC(9104152,r|0,280)|0}c[2113054]=c[2113060]}RI();r=c[2394]|0;t=c[14130368+(r<<2)>>2]|0;if((t|0)!=0){gGC(t|0,9104152,280)|0}c[8452240+(r<<2)>>2]=c[2113054];c[2394]=-1;c[2113156]=0;a[9628264]=0;c[2407033]=0;r=c[3541206]|0;c[3541190]=r;c[3541198]=r;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=r+256;c[3541199]=r+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=r+512;c[3541200]=r+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=r+768;c[3541201]=r+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;a[c[3530250]|0]=0;t=c[2386646]|0;gGC(r|0,t|0,262144)|0;q=0;i=e;return q|0}else if((o|0)==47890){i=e;return q|0}else if((o|0)==47894){i=e;return q|0}else if((o|0)==47895){i=e;return q|0}}}while(0);c[2414964]=0;q=1;i=e;return q|0}function d9f(){var b=0,d=0,e=0,f=0,g=0;c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}if((c[2392]|0)>=0){b=0;do{d=14130368+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}d=14130384+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}b=b+1|0;}while((b|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;Uw(0);b=c[2414964]|0;d=0;while(1){if((d|0)>=1024){f=47910;break}g=9638528+(d<<2)|0;if((c[g>>2]|0)==(b|0)){break}else{d=d+1|0}}if((f|0)==47910){c[2414964]=0;c[3541206]=0;a[638952]=0;return 0}gGr(b);c[g>>2]=0;c[2414964]=0;c[3541206]=0;a[638952]=0;return 0}function d9g(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if((a[9624184]|0)!=0){a[9624184]=0;e=c[2414668]|0;gGz(e|0,0,(c[2411664]|0)-e|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060]}RI();e=c[2394]|0;f=c[14130368+(e<<2)>>2]|0;if((f|0)!=0){gGC(f|0,9104152,280)|0}c[8452240+(e<<2)>>2]=c[2113054];c[2394]=-1;c[2113156]=0;a[9628264]=0;c[2407033]=0;e=c[3541206]|0;c[3541190]=e;c[3541198]=e;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=e+256;c[3541199]=e+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=e+512;c[3541200]=e+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=e+768;c[3541201]=e+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;a[c[3530250]|0]=0;f=c[2386646]|0;gGC(e|0,f|0,262144)|0}b[4774996]=-1;f=d[9635096]|3;b[4774912]=f;e=0;g=-1;h=f;do{g=((a[9633448+e|0]&1)<<e^g&65535)&65535;h=((a[9631304+e|0]&1)<<e^h&65535)&65535;e=e+1|0;}while((e|0)<16);b[4774996]=g;b[4774912]=h;if((c[2394]|0)==0){i=0;j=0}else{c[2394]=0;c[2112932]=c[3532596];h=c[3532592]|0;if((h|0)!=0){gGC(9104152,h|0,280)|0}c[2113054]=c[2113060];i=0;j=0}while(1){c[2113056]=26666;h=RG(26666)|0;c[2113054]=(c[2113054]|0)+h;c[2276108]=-1;c[2113056]=-1;h=c[2112964]|0;if((h|0)==0){k=j}else{g=a[9688]|0?53:0;Uu(0,h+(j<<1<<1)|0,g);k=g+j|0}g=i+1|0;if((g|0)<10){i=g;j=k}else{break}}j=c[2394]|0;c[8452200+(j<<2)>>2]=8193;c[2276080]=256;if((c[2276079]|0)>>>0<256){RH(1);l=c[2394]|0}else{l=j}j=c[14130368+(l<<2)>>2]|0;if((j|0)!=0){gGC(j|0,9104152,280)|0}c[8452240+(l<<2)>>2]=c[2113054];c[2394]=-1;l=c[2112964]|0;if((l|0)!=0){Uu(0,l+(k<<1<<1)|0,(a[9688]|0?534:0)-k|0)}if((c[2112968]|0)==0){return 0}d9h()|0;return 0}function d9h(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;if((a[9547464]|0)!=0){d=c[2387198]|0;f=c[3530008]|0;g=0;do{h=b[d+g>>1]|0;c[f+(g>>1<<2)>>2]=((h&65535)>>>10<<3&248)<<8|((h&255)<<3&255)>>>3|(((h&65535)>>>5<<3&255|(h&65535)>>>7&4)&255)<<3&2016;g=g+2|0;}while((g|0)<16384)}g=c[3530262]|0;f=g+10880|0;d=c[3529800]|0;h=c[2112926]|0;i=c[3530844]|0;j=0;do{k=(j>>5<<3)-(e[d>>1]|0)|0;l=(k|0)<-15?k+512|0:k;k=(j<<3&248)-16|0;do{if(k>>>0<=223){if((l+15|0)>>>0>302){break}m=j<<1;Sj(h,e[f+(m<<1)>>1]|0,l,k,(e[f+((m|1)<<1)>>1]|0)+256|0,4,0,i)}}while(0);j=j+1|0;}while((j|0)<2048);j=g+4992|0;f=0;do{k=(f>>5<<3)-(e[d>>1]|0)|0;l=(k|0)<-15?k+512|0:k;k=(f<<3&248)-16|0;do{if(k>>>0<=223){if((l+15|0)>>>0>302){break}m=f<<1;n=b[j+(m<<1)>>1]|0;o=b[j+((m|1)<<1)>>1]|0;if((o|n)<<16>>16==0){break}Sr(h,n&65535,l,k,(o&65535)+128|0,4,0,0,i)}}while(0);f=f+1|0;}while((f|0)<2048);f=c[2386458]|0;j=f+2048|0;d=c[3530608]|0;k=f+8|0;do{f=(e[k+2>>1]|0)-32|0;l=e[k-2>>1]|0;if((l&32768|0)!=0){break}o=e[k+4>>1]|0;n=o>>>2;m=b[k>>1]&255;p=242-l-16|0;l=(o&2|0)!=0;do{if((o&1|0)==0){if(l){SJ(h,n,f,p,m,4,0,6144,d);break}else{SH(h,n,f,p,m,4,0,6144,d);break}}else{if(l){SN(h,n,f,p,m,4,0,6144,d);break}else{SL(h,n,f,p,m,4,0,6144,d);break}}}while(0);k=k+8|0;}while(k>>>0<j>>>0);j=g+384|0;g=0;do{k=g>>5<<3;d=(g<<3&248)-16|0;do{if(!(d>>>0>223|(k|0)>287)){m=g<<1;p=b[j+(m<<1)>>1]|0;f=b[j+((m|1)<<1)>>1]|0;if((f|p)<<16>>16==0){break}Sr(h,p&65535,k,d,f&65535,4,0,0,i)}}while(0);g=g+1|0;}while((g|0)<1152);R8(c[3530008]|0);return 0}function d9i(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;e=i;i=i+64|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;if((d|0)!=0){c[d>>2]=169624}if((b&32|0)!=0){gGz(j|0,0,12);d=c[2414668]|0;c[j>>2]=d;c[j+4>>2]=(c[2411664]|0)-d;c[j+12>>2]=162152;d=c[2076592]|0;gj[d&4095](j)|0}if((b&64|0)==0){k=c[3530250]|0;l=a[k]|0;m=l&255;n=c[3541206]|0;o=c[2386646]|0;p=m<<12;q=o+p|0;gGC(n|0,q|0,262144)|0;i=e;return 0}b=h|0;gGz(g|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){j=h+9|0;h=f;d=f|0;r=f+4|0;s=f+12|0;t=g|0;u=g+4|0;v=g+12|0;w=0;do{gGC(b|0,614896,11)|0;a[j]=w+48&255;x=8452256+(w<<2)|0;gGz(h|0,0,12);c[d>>2]=x;c[r>>2]=4;c[s>>2]=164976;gj[c[2076592]&4095](f)|0;if((c[x>>2]|0)!=0){c[t>>2]=c[14130368+(w<<2)>>2];c[u>>2]=c[8452184+(w<<2)>>2];c[v>>2]=b;x=c[2076592]|0;gj[x&4095](g)|0}w=w+1|0;}while((w|0)<=(c[2392]|0))}Ut(0);k=c[3530250]|0;l=a[k]|0;m=l&255;n=c[3541206]|0;o=c[2386646]|0;p=m<<12;q=o+p|0;gGC(n|0,q|0,262144)|0;i=e;return 0}function d9j(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6571844+(b*112|0)>>2];c[a+104>>2]=c[6571848+(b*112|0)>>2];c[a+108>>2]=c[6571852+(b*112|0)>>2];d=0;return d|0}function d9k(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=6571744+(b*112|0);e=0;return e|0}function d9l(b){b=b|0;var d=0;switch(b|0){case 7340037:{d=a[9549984]|0;break};case 7340047:{d=c[2113156]&255;break};case 7340035:{d=a[9635089]|0;break};case 7340033:{d=a[9635088]|0;break};case 7340039:{d=a[9549816]|0;break};default:{d=0}}return d|0}function d9m(a){a=a|0;return 0}function d9n(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;if((a|0)==7340045){d=b&3;if((c[2385596]|0)==(d|0)){return}c[2385596]=d;e=c[2426534]|0;f=e+131072|0;g=e+((d<<17)+262144)|0;gGC(f|0,g|0,131072)|0;return}else if((a|0)==7340047){Uv(0,b);return}else{return}}function d9o(a,d){a=a|0;d=d|0;var e=0,f=0,g=0;if((a&16775168|0)!=2097152){return}b[(c[2411918]|0)+(a&2046)>>1]=d;e=a>>>1&1023;a=d&65535;d=a>>>10&31;f=a>>>5&31;g=a&31;a=f<<3|f>>>2;c[(c[2406930]|0)+(e<<2)>>2]=g<<3|g>>>2|a<<8|(d<<3|d>>>2)<<16;c[(c[3530006]|0)+(e<<2)>>2]=d<<11|g|a<<3&2016;return}function d9p(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5904244+(b*112|0)>>2];c[a+104>>2]=c[5904248+(b*112|0)>>2];c[a+108>>2]=c[5904252+(b*112|0)>>2];d=0;return d|0}function d9q(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=5904144+(b*112|0);e=0;return e|0}function d9r(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6927184+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function d9s(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>43){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7435808+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function d9t(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;b=i;i=i+240|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;c[2426720]=0;c[2426602]=0;c[2424848]=262144;c[2424824]=2359296;c[2426534]=4456448;c[3530006]=5242880;c[2405656]=5246976;c[2411220]=5246976;c[2411918]=5255168;c[2411224]=5257216;c[2406804]=5261312;c[2406930]=5277696;c[2411662]=5281792;j=0;while(1){if((j|0)>=1024){break}k=9638528+(j<<2)|0;if((c[k>>2]|0)==0){l=48047;break}else{j=j+1|0}}do{if((l|0)==48047){j=gGq(5281792)|0;c[k>>2]=j;if((j|0)==0){break}c[2426720]=j;gGz(j|0,0,5281792);c[2426602]=j;c[2424848]=j+262144;c[2424824]=j+2359296;c[2426534]=j+4456448;c[3530006]=j+5242880;m=j+5246976|0;c[2405656]=m;c[2411220]=m;c[2411918]=j+5255168;c[2411224]=j+5257216;c[2406804]=j+5261312;c[2406930]=j+5277696;m=j+5281792|0;c[2411662]=m;c[2414200]=m;if((R6(j,0,2)|0)!=0){n=1;i=b;return n|0}if((R6((c[2426602]|0)+1|0,1,2)|0)!=0){n=1;i=b;return n|0}j=g+108|0;m=g+100|0;o=0;while(1){p=(c[2424848]|0)+(o<<18)|0;q=o+2|0;if((c[3542200]|0)==0){n=1;l=48114;break}c[j>>2]=0;c[m>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,q)|0;if((c[j>>2]|0)!=0){r=c[m>>2]|0;c[h>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](h,q,0)|0;if((r|0)<1){n=1;l=48109;break}if((gzL(p,0,q)|0)!=0){n=1;l=48116;break}}q=o+1|0;if((q|0)<4){o=q}else{l=48057;break}}if((l|0)==48109){i=b;return n|0}else if((l|0)==48114){i=b;return n|0}else if((l|0)==48116){i=b;return n|0}else if((l|0)==48057){o=c[2426534]|0;if((c[3542200]|0)==0){n=1;i=b;return n|0}m=e+108|0;c[m>>2]=0;j=e+100|0;c[j>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,6)|0;do{if((c[m>>2]|0)!=0){q=c[j>>2]|0;c[f>>2]=9534384;p=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[p&16383](f,6,0)|0;if((q|0)<1){n=1;i=b;return n|0}if((gzL(o,0,6)|0)==0){break}else{n=1}i=b;return n|0}}while(0);o=c[2426534]|0;j=o+262144|0;gGC(j|0,o|0,524288)|0;j=o+131072|0;gGC(j|0,o|0,131072)|0;c[3541206]=o;o=0;while(1){if((o|0)>=1024){n=1;l=48120;break}t=9638528+(o<<2)|0;if((c[t>>2]|0)==0){break}else{o=o+1|0}}if((l|0)==48120){i=b;return n|0}o=gGq(1048576)|0;c[t>>2]=o;if((o|0)==0){n=1;i=b;return n|0}gGz(o|0,0,1048576);j=c[2424848]|0;gGC(o|0,j|0,1048576)|0;m=0;do{q=m<<6;gGz(j+q|0,0,64);p=0;do{r=1<<3-p;s=(c[611056+(p<<2)>>2]|0)+q|0;u=0;do{v=s+(c[609008+(u<<2)>>2]|0)|0;w=(u<<3)+q|0;x=0;do{y=v+(c[597864+(x<<2)>>2]|0)|0;if(((d[o+((y|0)/8|0)|0]|0)&128>>>((y&7)>>>0)|0)!=0){y=j+(w+x)|0;a[y]=(d[y]|0|r)&255}x=x+1|0;}while((x|0)<8);u=u+1|0;}while((u|0)<8);p=p+1|0;}while((p|0)<4);m=m+1|0;}while((m|0)<32768);m=c[2424824]|0;j=0;while(1){p=j<<8;gGz(m+p|0,0,256);q=0;do{u=1<<3-q;r=(c[611056+(q<<2)>>2]|0)+p|0;s=0;do{x=r+(c[609008+(s<<2)>>2]|0)|0;w=(s<<4)+p|0;v=0;do{y=x+(c[597864+(v<<2)>>2]|0)|0;if(((d[o+((y|0)/8|0)|0]|0)&128>>>((y&7)>>>0)|0)!=0){y=m+(w+v)|0;a[y]=(d[y]|0|u)&255}v=v+1|0;}while((v|0)<16);s=s+1|0;}while((s|0)<16);q=q+1|0;}while((q|0)<4);q=j+1|0;if((q|0)<8192){j=q}else{z=0;break}}while(1){if((z|0)>=1024){break}A=9638528+(z<<2)|0;if((c[A>>2]|0)==(o|0)){l=48087;break}else{z=z+1|0}}if((l|0)==48087){gGr(o);c[A>>2]=0}fxU(0,425984);if((c[2394]|0)==0){B=c[2112932]|0}else{c[2394]=0;j=c[3532596]|0;c[2112932]=j;m=c[3532592]|0;if((m|0)!=0){gGC(9104152,m|0,280)|0}c[2113054]=c[2113060];B=j}j=c[2426602]|0;m=B|0;q=0;while(1){p=j+q|0;c[m>>2]=p;c[m+131072>>2]=p;p=q+1024|0;if(p>>>0>262143){break}else{m=m+4|0;q=p}}q=c[2411220]|0;c[B+4096>>2]=q;c[B+69632>>2]=q;c[B+135168>>2]=q;m=q+1024|0;c[B+4100>>2]=m;c[B+69636>>2]=m;c[B+135172>>2]=m;m=q+2048|0;c[B+4104>>2]=m;c[B+69640>>2]=m;c[B+135176>>2]=m;m=q+3072|0;c[B+4108>>2]=m;c[B+69644>>2]=m;c[B+135180>>2]=m;m=q+4096|0;c[B+4112>>2]=m;c[B+69648>>2]=m;c[B+135184>>2]=m;m=q+5120|0;c[B+4116>>2]=m;c[B+69652>>2]=m;c[B+135188>>2]=m;m=q+6144|0;c[B+4120>>2]=m;c[B+69656>>2]=m;c[B+135192>>2]=m;m=q+7168|0;c[B+4124>>2]=m;c[B+69660>>2]=m;c[B+135196>>2]=m;m=c[2411224]|0;c[B+17408>>2]=m;c[B+82944>>2]=m;c[B+148480>>2]=m;q=m+1024|0;c[B+17412>>2]=q;c[B+82948>>2]=q;c[B+148484>>2]=q;q=m+2048|0;c[B+17416>>2]=q;c[B+82952>>2]=q;c[B+148488>>2]=q;q=m+3072|0;c[B+17420>>2]=q;c[B+82956>>2]=q;c[B+148492>>2]=q;q=c[2406804]|0;c[B+65472>>2]=q;c[B+131008>>2]=q;c[B+196544>>2]=q;m=q+1024|0;c[B+65476>>2]=m;c[B+131012>>2]=m;c[B+196548>>2]=m;m=q+2048|0;c[B+65480>>2]=m;c[B+131016>>2]=m;c[B+196552>>2]=m;m=q+3072|0;c[B+65484>>2]=m;c[B+131020>>2]=m;c[B+196556>>2]=m;m=q+4096|0;c[B+65488>>2]=m;c[B+131024>>2]=m;c[B+196560>>2]=m;m=q+5120|0;c[B+65492>>2]=m;c[B+131028>>2]=m;c[B+196564>>2]=m;m=q+6144|0;c[B+65496>>2]=m;c[B+131032>>2]=m;c[B+196568>>2]=m;m=q+7168|0;c[B+65500>>2]=m;c[B+131036>>2]=m;c[B+196572>>2]=m;m=q+8192|0;c[B+65504>>2]=m;c[B+131040>>2]=m;c[B+196576>>2]=m;m=q+9216|0;c[B+65508>>2]=m;c[B+131044>>2]=m;c[B+196580>>2]=m;m=q+10240|0;c[B+65512>>2]=m;c[B+131048>>2]=m;c[B+196584>>2]=m;m=q+11264|0;c[B+65516>>2]=m;c[B+131052>>2]=m;c[B+196588>>2]=m;m=q+12288|0;c[B+65520>>2]=m;c[B+131056>>2]=m;c[B+196592>>2]=m;m=q+13312|0;c[B+65524>>2]=m;c[B+131060>>2]=m;c[B+196596>>2]=m;m=q+14336|0;c[B+65528>>2]=m;c[B+131064>>2]=m;c[B+196600>>2]=m;m=q+15360|0;c[B+65532>>2]=m;c[B+131068>>2]=m;c[B+196604>>2]=m;c[B+196648>>2]=3032;c[B+196728>>2]=242;c[B+196608>>2]=268;c[B+196688>>2]=3306;m=c[3532592]|0;if((m|0)!=0){gGC(m|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;Ux(0,12310,0);c[2407030]=205;c[2407068]=3;a[9624176]=0;gGz(c[2411220]|0,0,8192);gGz(c[2411918]|0,0,2048);gGz(c[2411224]|0,0,4096);gGz(c[2406804]|0,0,16384);gGz(c[2406930]|0,0,4096);a[9547456]=1;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];m=c[3532592]|0;if((m|0)!=0){gGC(9104152,m|0,280)|0}c[2113054]=c[2113060]}RI();m=c[2394]|0;q=c[14130368+(m<<2)>>2]|0;if((q|0)!=0){gGC(q|0,9104152,280)|0}c[8452240+(m<<2)>>2]=c[2113054];c[2394]=-1;c[2385596]=0;c[2113156]=0;a[9628264]=0;c[2407033]=0;m=c[3541206]|0;c[3541190]=m;c[3541198]=m;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=m+256;c[3541199]=m+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=m+512;c[3541200]=m+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=m+768;c[3541201]=m+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;m=c[642608+(c[2436]<<2)>>2]|0;q=c[m+128>>2]|0;if((c[m+52>>2]&4|0)==0){c[2113068]=q;j=c[m+132>>2]|0;c[2113070]=j;c[2443814]=q;c[2440436]=j;C=q;D=j}else{c[2113070]=q;j=c[m+132>>2]|0;c[2113068]=j;c[2440436]=q;c[2443814]=j;C=j;D=q}q=ag(C<<1,D)|0;j=gGq(q)|0;c[2112926]=j;if((j|0)==0){n=0;i=b;return n|0}gGz(j|0,0,q|0);n=0;i=b;return n|0}}}while(0);c[2426720]=0;n=1;i=b;return n|0}function d9u(){var a=0,b=0,d=0,e=0,f=0;if((c[2392]|0)>=0){a=0;do{b=14130368+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}b=14130384+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}a=a+1|0;}while((a|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;c[2113070]=0;c[2113068]=0;a=c[2112926]|0;if((a|0)!=0){gGr(a);c[2112926]=0}Uw(0);a=c[2426720]|0;b=0;while(1){if((b|0)>=1024){e=48136;break}f=9638528+(b<<2)|0;if((c[f>>2]|0)==(a|0)){break}else{b=b+1|0}}if((e|0)==48136){c[2426720]=0;c[3541206]=0;return 0}gGr(a);c[f>>2]=0;c[2426720]=0;c[3541206]=0;return 0}function d9v(){var b=0,d=0,e=0,f=0;if((a[9624176]|0)!=0){a[9624176]=0;gGz(c[2411220]|0,0,8192);gGz(c[2411918]|0,0,2048);gGz(c[2411224]|0,0,4096);gGz(c[2406804]|0,0,16384);gGz(c[2406930]|0,0,4096);a[9547456]=1;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];b=c[3532592]|0;if((b|0)!=0){gGC(9104152,b|0,280)|0}c[2113054]=c[2113060]}RI();b=c[2394]|0;d=c[14130368+(b<<2)>>2]|0;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[8452240+(b<<2)>>2]=c[2113054];c[2394]=-1;c[2385596]=0;c[2113156]=0;a[9628264]=0;c[2407033]=0;b=c[3541206]|0;c[3541190]=b;c[3541198]=b;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=b+256;c[3541199]=b+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=b+512;c[3541200]=b+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=b+768;c[3541201]=b+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4}a[9549816]=-1;a[9549984]=-1;b=0;d=-1;e=-1;do{d=((a[9633440+b|0]&1)<<b^d&255)&255;e=((a[9631296+b|0]&1)<<b^e&255)&255;b=b+1|0;}while((b|0)<8);a[9549984]=d;a[9549816]=e;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060]}c[2113056]=2e5;e=RG(2e5)|0;c[2113054]=(c[2113054]|0)+e;c[2276108]=-1;c[2113056]=-1;e=c[2394]|0;c[8452200+(e<<2)>>2]=8198;c[2276080]=1536;if((c[2276079]|0)>>>0<1536){RH(6);f=c[2394]|0}else{f=e}e=c[14130368+(f<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(f<<2)>>2]=c[2113054];c[2394]=-1;f=c[2112964]|0;if((f|0)!=0){Uu(0,f,a[9688]|0?534:0)}if((c[2112968]|0)==0){return 0}d9w()|0;return 0}function d9w(){var b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;if((a[9547456]|0)!=0){b=c[2406930]|0;d=c[3530006]|0;f=0;do{g=c[b+(f<<2)>>2]|0;c[d+(f<<2)>>2]=g>>8<<3&2016|g>>>3&31|g>>16<<8&63488;f=f+1|0;}while((f|0)<768)}f=c[2411220]|0;d=f+4096|0;b=f;f=c[2112926]|0;g=c[2424824]|0;h=0;do{i=h<<4&496;j=h>>>1&496;do{if(!(i>>>0>320|j>>>0<16)){k=j-16|0;l=e[d+(h<<1)>>1]|0;Sz(f,l&4095,i,k,l>>>12,4,0,g);l=e[b+(h<<1)>>1]|0;m=l&4095;if((m|0)==0){break}SH(f,m,i,k,l>>>12,4,0,512,g)}}while(0);h=h+1|0;}while((h|0)<512);h=c[2411224]|0;g=c[2424848]|0;b=3;do{d=e[h+(b+2<<1)>>1]|0;i=e[h+(b<<1)>>1]|0;j=e[h+(b+3<<1)>>1]|0;l=d>>>9&15;k=i>>>9;m=k&4;n=(m|0)==0?j&65532:j;j=2-(m>>>2)|0;m=(k&32|0)==0;o=j-1|0;p=(k&64|0)!=0;k=(d&511)-9|0;d=(240-i&255)-16|0;i=0;do{q=d+(i<<3)|0;r=c[607896+((p?o-i|0:i)<<2)>>2]|0;if(m){if(p){s=0;do{Sv(f,(c[607904+(s<<2)>>2]|0)+n+r|0,(s<<3)+k|0,q,l,4,0,256,g);s=s+1|0;}while((s|0)<(j|0))}else{s=0;do{Sr(f,(c[607904+(s<<2)>>2]|0)+n+r|0,(s<<3)+k|0,q,l,4,0,256,g);s=s+1|0;}while((s|0)<(j|0))}}else{if(p){s=0;do{Sx(f,(c[607904+(o-s<<2)>>2]|0)+n+r|0,(s<<3)+k|0,q,l,4,0,256,g);s=s+1|0;}while((s|0)<(j|0))}else{s=0;do{St(f,(c[607904+(o-s<<2)>>2]|0)+n+r|0,(s<<3)+k|0,q,l,4,0,256,g);s=s+1|0;}while((s|0)<(j|0))}}i=i+1|0;}while((i|0)<(j|0));b=b+4|0;}while((b|0)<2048);R8(c[3530006]|0);return 0}function d9x(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=i;i=i+80|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;if((d|0)!=0){c[d>>2]=169249}do{if((b&32|0)!=0){gGz(k|0,0,12);d=c[2405656]|0;c[k>>2]=d;c[k+4>>2]=(c[2411662]|0)-d;c[k+12>>2]=162152;d=c[2076592]|0;gj[d&4095](k)|0;if((b&2|0)==0){break}a[9547456]=1}}while(0);if((b&64|0)==0){i=e;return 0}k=h|0;gGz(g|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){d=h+9|0;h=f;l=f|0;m=f+4|0;n=f+12|0;o=g|0;p=g+4|0;q=g+12|0;r=0;do{gGC(k|0,614896,11)|0;a[d]=r+48&255;s=8452256+(r<<2)|0;gGz(h|0,0,12);c[l>>2]=s;c[m>>2]=4;c[n>>2]=164976;gj[c[2076592]&4095](f)|0;if((c[s>>2]|0)!=0){c[o>>2]=c[14130368+(r<<2)>>2];c[p>>2]=c[8452184+(r<<2)>>2];c[q>>2]=k;s=c[2076592]|0;gj[s&4095](g)|0}r=r+1|0;}while((r|0)<=(c[2392]|0))}Ut(0);gGz(j|0,0,12);c[j>>2]=9542384;c[j+4>>2]=4;c[j+12>>2]=150896;gj[c[2076592]&4095](j)|0;if((b&2|0)==0){i=e;return 0}b=c[2385596]&3;c[2385596]=b;j=c[2426534]|0;r=j+131072|0;g=j+((b<<17)+262144)|0;gGC(r|0,g|0,131072)|0;i=e;return 0}function d9y(b){b=b|0;var c=0;switch(b|0){case 16777125:{c=~a[9625690];break};case 16777133:{c=a[2461424]&1;break};case 16777129:{c=~a[9625692];break};case 16777127:{c=~a[9625691];break};case 16777121:{c=~a[9625688];break};case 16777123:{c=~a[9625689];break};case 16777135:{c=~a[9625693];break};default:{c=0}}return c|0}function d9z(b,d){b=b|0;d=d|0;var e=0,f=0;if((b&16711680|0)==1703936){e=b&65535;if(e>>>0>=2048){return}a[(c[2411430]|0)+(e^1)|0]=d;return}if((b|0)!=16777153){return}a[2461424]=1;b=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;e=a[6518008]|0;f=gGU(b,(b|0)<0|0?-1:0,e?66666:0,e?0:0)|0;e=gGS(f,K,166666,0)|0;f=e;if((f|0)<=((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)){return}Sb(f);a[9775456]=d;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12;return}function d9A(d,e){d=d|0;e=e|0;var f=0,g=0,h=0;if((d&16711680|0)==1703936){f=d&65535;if(f>>>0<2048){b[(c[2411430]|0)+f>>1]=e}g=e&65535;h=g>>>2&248;b[(c[2385764]|0)+(f>>>1<<1)>>1]=(g>>>7<<8&63488|g&31|(h>>>5|h)<<3&2016)&65535;return}switch(d|0){case 16777104:{b[7057640]=e;return};case 16777090:{a[14115930]=(e&65535)>>>8&255;a[14115931]=e&255;return};case 16777088:{a[14115928]=(e&65535)>>>8&255;a[14115929]=e&255;return};case 16777094:{a[14115934]=(e&65535)>>>8&255;a[14115935]=e&255;return};case 16777096:{b[7057652]=e;return};case 16777092:{a[14115932]=(e&65535)>>>8&255;a[14115933]=e&255;return};default:{return}}}function d9B(b){b=b|0;var d=0,e=0,f=0.0,g=0.0,i=0,j=0,k=0;d=b&255;if((d|0)==0){b=c[3541514]|0;e=b+552|0;f=+h[e>>3];do{if(f!=0.0){g=+h[6675];if(f-(g+ +gC[c[2429842]&255]())>0.0){i=a[b+563|0]|-128;break}else{h[e>>3]=0.0;j=48247;break}}else{j=48247}}while(0);if((j|0)==48247){i=a[b+563|0]|0}k=i&-125;return k|0}else if((d|0)==2){k=a[(c[3541514]|0)+20904|0]|0;return k|0}else if((d|0)==12){k=a[9775456]|0;return k|0}else{k=0;return k|0}return 0}function d9C(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=b&65535;switch(e&255|0){case 4:{b=d&3;if((b|0)==(c[2433572]|0)){return}f=c[2411308]|0;g=c[9757320+(c[1836236]<<2)>>2]|0;h=(b<<15)+32768|0;i=128;j=128;while(1){c[g+76+(j<<2)>>2]=f+(h+(j<<8));k=i+1&65535;if((k&65535)>255){l=128;m=128;break}else{i=k;j=k&65535}}while(1){j=f+(h+(m<<8))|0;c[g+76+(m+512<<2)>>2]=j;c[g+76+(m+768<<2)>>2]=j;j=l+1&65535;if((j&65535)>255){break}else{l=j;m=j&65535}}c[2433572]=b;return};case 0:case 1:case 2:case 3:{l7(e&3,d);return};case 8:{a[2461424]=0;return};default:{return}}}function d9D(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4853860+(b*112|0)>>2];c[a+104>>2]=c[4853864+(b*112|0)>>2];c[a+108>>2]=c[4853868+(b*112|0)>>2];d=0;return d|0}function d9E(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=4853760+(b*112|0);e=0;return e|0}function d9F(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1626544+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function d9G(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=47){if((a|0)==0){d=0;return d|0}e=a;f=4854656+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}f=b-48|0;if(f>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;a=3183584+(f*12|0)|0;c[b>>2]=c[a>>2];c[b+4>>2]=c[a+4>>2];c[b+8>>2]=c[a+8>>2];d=0;return d|0}function d9H(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;e=i;i=i+960|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;c[2418150]=0;c[2411308]=524288;c[2418084]=720896;c[2408970]=720960;c[2406830]=2818112;c[2388318]=2818368;c[2388316]=4915520;c[2406834]=5964096;c[3527032]=262144;c[2406832]=6226240;c[3527030]=1048576;c[2405652]=7274816;c[2411430]=7274816;c[2385752]=7276864;c[2406900]=7280960;c[2406898]=7289152;c[2406876]=7297344;c[2406872]=7330112;c[2418264]=7338304;c[2411350]=7403840;c[2411658]=7405888;c[2385764]=7405888;x=gGq(7407936)|0;c[2426718]=x;if((x|0)==0){y=1;i=e;return y|0}gGz(x|0,0,7407936);c[2418150]=x;c[2411308]=x+524288;c[2418084]=x+720896;c[2408970]=x+720960;c[2406830]=x+2818112;c[2388318]=x+2818368;z=x+4915520|0;c[2406828]=z;c[2388316]=z;c[2406834]=x+5964096;c[3527032]=262144;c[2406832]=x+6226240;z=x+7274816|0;c[3527030]=1048576;c[2405652]=z;c[2411430]=z;c[2385752]=x+7276864;c[2406900]=x+7280960;c[2406898]=x+7289152;c[2406876]=x+7297344;c[2406872]=x+7330112;c[2418264]=x+7338304;c[2411350]=x+7403840;z=x+7405888|0;c[2411658]=z;c[2385764]=z;c[2414198]=x+7407936;if((c[3542200]|0)==0){y=1;i=e;return y|0}z=v+108|0;c[z>>2]=0;A=v+100|0;c[A>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,0)|0;do{if((c[z>>2]|0)!=0){v=c[A>>2]|0;c[w>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](w,0,0)|0;if((v|0)<1){y=1;i=e;return y|0}if((gzL(x,0,0)|0)==0){break}else{y=1}i=e;return y|0}}while(0);x=c[2418084]|0;do{if((c[3542200]|0)!=0){w=t+108|0;c[w>>2]=0;A=t+100|0;c[A>>2]=0;z=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[z&16383](t,1)|0;if((c[w>>2]|0)==0){break}w=c[A>>2]|0;c[u>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](u,1,0)|0;if((w|0)<1){break}gzL(x,0,1)|0}}while(0);x=(c[2418084]|0)+524288|0;do{if((c[3542200]|0)!=0){u=r+108|0;c[u>>2]=0;t=r+100|0;c[t>>2]=0;w=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[w&16383](r,2)|0;if((c[u>>2]|0)==0){break}u=c[t>>2]|0;c[s>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](s,2,0)|0;if((u|0)<1){break}gzL(x,0,2)|0}}while(0);x=c[2418084]|0;s=c[2408970]|0;r=32767;while(1){u=r<<5;t=r<<6;w=7;while(1){A=w<<2;z=x+((A|2)+u)|0;v=(w<<3)+t|0;a[s+(v|7)|0]=a[z]&15;a[s+(v|6)|0]=(d[z]|0)>>>4;z=x+((A|3)+u)|0;a[s+(v|5)|0]=a[z]&15;a[s+(v|4)|0]=(d[z]|0)>>>4;z=x+(A+u)|0;a[s+(v|3)|0]=a[z]&15;a[s+(v|2)|0]=(d[z]|0)>>>4;z=x+((A|1)+u)|0;a[s+(v|1)|0]=a[z]&15;a[s+v|0]=(d[z]|0)>>>4;if((w|0)<=0){break}w=w-1|0}if((r|0)>0){r=r-1|0}else{break}}r=c[2406830]|0;do{if((c[3542200]|0)!=0){s=p+108|0;c[s>>2]=0;x=p+100|0;c[x>>2]=0;w=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[w&16383](p,3)|0;if((c[s>>2]|0)==0){break}s=c[x>>2]|0;c[q>>2]=9534384;x=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[x&16383](q,3,0)|0;if((s|0)<1){break}gzL(r,0,3)|0}}while(0);r=(c[2406830]|0)+1048576|0;do{if((c[3542200]|0)!=0){q=n+108|0;c[q>>2]=0;p=n+100|0;c[p>>2]=0;s=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[s&16383](n,4)|0;if((c[q>>2]|0)==0){break}q=c[p>>2]|0;c[o>>2]=9534384;p=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[p&16383](o,4,0)|0;if((q|0)<1){break}gzL(r,0,4)|0}}while(0);r=c[2388318]|0;o=c[2406830]|0;n=12287;while(1){q=n<<7;p=n<<8;s=15;while(1){x=s<<3;w=o+((x|6)+q)|0;u=(s<<4)+p|0;a[r+(u|15)|0]=a[w]&15;a[r+(u|14)|0]=(d[w]|0)>>>4;w=o+((x|7)+q)|0;a[r+(u|13)|0]=a[w]&15;a[r+(u|12)|0]=(d[w]|0)>>>4;w=o+((x|4)+q)|0;a[r+(u|11)|0]=a[w]&15;a[r+(u|10)|0]=(d[w]|0)>>>4;w=o+((x|5)+q)|0;a[r+(u|9)|0]=a[w]&15;a[r+(u|8)|0]=(d[w]|0)>>>4;w=o+((x|2)+q)|0;a[r+(u|7)|0]=a[w]&15;a[r+(u|6)|0]=(d[w]|0)>>>4;w=o+((x|3)+q)|0;a[r+(u|5)|0]=a[w]&15;a[r+(u|4)|0]=(d[w]|0)>>>4;w=o+(x+q)|0;a[r+(u|3)|0]=a[w]&15;a[r+(u|2)|0]=(d[w]|0)>>>4;w=o+((x|1)+q)|0;a[r+(u|1)|0]=a[w]&15;a[r+u|0]=(d[w]|0)>>>4;if((s|0)>0){s=s-1|0}else{break}}if((n|0)>0){n=n-1|0}else{break}}n=(c[2411308]|0)+65536|0;if((c[3542200]|0)==0){y=1;i=e;return y|0}r=l+108|0;c[r>>2]=0;o=l+100|0;c[o>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,5)|0;do{if((c[r>>2]|0)!=0){l=c[o>>2]|0;c[m>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](m,5,0)|0;if((l|0)<1){y=1;i=e;return y|0}if((gzL(n,0,5)|0)==0){break}else{y=1}i=e;return y|0}}while(0);n=c[2411308]|0;m=n+65536|0;gGC(n|0,m|0,65536)|0;m=c[2406834]|0;do{if((c[3542200]|0)!=0){n=j+108|0;c[n>>2]=0;o=j+100|0;c[o>>2]=0;r=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[r&16383](j,6)|0;if((c[n>>2]|0)==0){break}n=c[o>>2]|0;c[k>>2]=9534384;o=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[o&16383](k,6,0)|0;if((n|0)<1){break}gzL(m,0,6)|0}}while(0);m=c[2406832]|0;do{if((c[3542200]|0)!=0){k=f+108|0;c[k>>2]=0;j=f+100|0;c[j>>2]=0;n=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[n&16383](f,7)|0;if((c[k>>2]|0)==0){break}k=c[j>>2]|0;c[g>>2]=9534384;j=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[j&16383](g,7,0)|0;if((k|0)<1){break}gzL(m,0,7)|0}}while(0);fxU(0,425984);if((c[2394]|0)==0){C=c[2112932]|0}else{c[2394]=0;m=c[3532596]|0;c[2112932]=m;g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060];C=m}m=c[2418150]|0;g=C|0;f=0;while(1){k=m+f|0;c[g>>2]=k;c[g+131072>>2]=k;k=f+1024|0;if(k>>>0>524287){break}else{g=g+4|0;f=k}}f=c[2411430]|0;c[C+6656>>2]=f;c[C+137728>>2]=f;g=f+1024|0;c[C+6660>>2]=g;c[C+137732>>2]=g;g=c[2385752]|0;f=g;c[C+6912>>2]=f;c[C+72448>>2]=f;c[C+137984>>2]=f;f=g+1024|0;c[C+6916>>2]=f;c[C+72452>>2]=f;c[C+137988>>2]=f;f=g+2048|0;c[C+6920>>2]=f;c[C+72456>>2]=f;c[C+137992>>2]=f;f=g+3072|0;c[C+6924>>2]=f;c[C+72460>>2]=f;c[C+137996>>2]=f;f=c[2406900]|0;g=f;c[C+6944>>2]=g;c[C+72480>>2]=g;c[C+138016>>2]=g;g=f+1024|0;c[C+6948>>2]=g;c[C+72484>>2]=g;c[C+138020>>2]=g;g=f+2048|0;c[C+6952>>2]=g;c[C+72488>>2]=g;c[C+138024>>2]=g;g=f+3072|0;c[C+6956>>2]=g;c[C+72492>>2]=g;c[C+138028>>2]=g;g=f+4096|0;c[C+6960>>2]=g;c[C+72496>>2]=g;c[C+138032>>2]=g;g=f+5120|0;c[C+6964>>2]=g;c[C+72500>>2]=g;c[C+138036>>2]=g;g=f+6144|0;c[C+6968>>2]=g;c[C+72504>>2]=g;c[C+138040>>2]=g;g=f+7168|0;c[C+6972>>2]=g;c[C+72508>>2]=g;c[C+138044>>2]=g;g=c[2406898]|0;f=g;c[C+6976>>2]=f;c[C+72512>>2]=f;c[C+138048>>2]=f;f=g+1024|0;c[C+6980>>2]=f;c[C+72516>>2]=f;c[C+138052>>2]=f;f=g+2048|0;c[C+6984>>2]=f;c[C+72520>>2]=f;c[C+138056>>2]=f;f=g+3072|0;c[C+6988>>2]=f;c[C+72524>>2]=f;c[C+138060>>2]=f;f=g+4096|0;c[C+6992>>2]=f;c[C+72528>>2]=f;c[C+138064>>2]=f;f=g+5120|0;c[C+6996>>2]=f;c[C+72532>>2]=f;c[C+138068>>2]=f;f=g+6144|0;c[C+7e3>>2]=f;c[C+72536>>2]=f;c[C+138072>>2]=f;f=g+7168|0;c[C+7004>>2]=f;c[C+72540>>2]=f;c[C+138076>>2]=f;f=c[2406876]|0;g=C+7168|0;m=1835008;while(1){k=f+(m-1835008)|0;c[g>>2]=k;c[g+65536>>2]=k;c[g+131072>>2]=k;k=m+1024|0;if(k>>>0>1867775){break}else{g=g+4|0;m=k}}m=c[2406872]|0;g=m;c[C+7424>>2]=g;c[C+72960>>2]=g;c[C+138496>>2]=g;g=m+1024|0;c[C+7428>>2]=g;c[C+72964>>2]=g;c[C+138500>>2]=g;g=m+2048|0;c[C+7432>>2]=g;c[C+72968>>2]=g;c[C+138504>>2]=g;g=m+3072|0;c[C+7436>>2]=g;c[C+72972>>2]=g;c[C+138508>>2]=g;g=m+4096|0;c[C+7440>>2]=g;c[C+72976>>2]=g;c[C+138512>>2]=g;g=m+5120|0;c[C+7444>>2]=g;c[C+72980>>2]=g;c[C+138516>>2]=g;g=m+6144|0;c[C+7448>>2]=g;c[C+72984>>2]=g;c[C+138520>>2]=g;g=m+7168|0;c[C+7452>>2]=g;c[C+72988>>2]=g;c[C+138524>>2]=g;g=c[2418264]|0;m=C+65264|0;f=16707584;while(1){k=g+(f-16707584)|0;c[m>>2]=k;c[m+65536>>2]=k;c[m+131072>>2]=k;k=f+1024|0;if(k>>>0>16773119){break}else{m=m+4|0;f=k}}c[C+196608>>2]=1382;c[C+196728>>2]=2310;c[C+196648>>2]=1532;C=c[3532592]|0;if((C|0)!=0){gGC(C|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);C=c[2439330]|0;f=(C|0)==0;if(!f){m=C;gGC(9706056,m|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];m=c[3528484]|0;c[2076596]=m;g=c[2417276]|0;c[3541536]=g;c[1836236]=0;k=c[2411308]|0;j=0;n=0;while(1){c[C+76+(n<<2)>>2]=k+(n<<8);o=j+1&65535;if((o&65535)>119){D=0;E=0;break}else{j=o;n=o&65535}}while(1){n=k+(E<<8)|0;c[C+76+(E+512<<2)>>2]=n;c[C+76+(E+768<<2)>>2]=n;n=D+1&65535;if((n&65535)>119){break}else{D=n;E=n&65535}}E=c[2411350]|0;c[C+556>>2]=E;D=E+256|0;c[C+560>>2]=D;k=E+512|0;c[C+564>>2]=k;n=E+768|0;c[C+568>>2]=n;j=E+1024|0;c[C+572>>2]=j;o=E+1280|0;c[C+576>>2]=o;r=E+1536|0;c[C+580>>2]=r;l=E+1792|0;c[C+584>>2]=l;c[C+1580>>2]=E;c[C+1584>>2]=D;c[C+1588>>2]=k;c[C+1592>>2]=n;c[C+1596>>2]=j;c[C+1600>>2]=o;c[C+1604>>2]=r;c[C+1608>>2]=l;c[C+2604>>2]=E;c[C+3628>>2]=E;c[C+2608>>2]=D;c[C+3632>>2]=D;c[C+2612>>2]=k;c[C+3636>>2]=k;c[C+2616>>2]=n;c[C+3640>>2]=n;c[C+2620>>2]=j;c[C+3644>>2]=j;c[C+2624>>2]=o;c[C+3648>>2]=o;c[C+2628>>2]=r;c[C+3652>>2]=r;c[C+2632>>2]=l;c[C+3656>>2]=l;c[C+4172>>2]=334;c[C+4176>>2]=1636;if(!f){f=C;gGC(f|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=m;c[2417276]=g;c[1836236]=-1;TW(c[2406832]|0,14108120,c[2406834]|0,14108128,2450,3506,58);c[2438228]=4e6;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=511;h[745406]=1.0;c[2436786]=1;h[745405]=1.0;c[2436784]=2;h[745404]=.25;a[3203280]=1;c[2433572]=-1;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060]}c[2113050]=0;c[2276080]=0;RI();g=c[2394]|0;m=c[14130368+(g<<2)>>2]|0;if((m|0)!=0){gGC(m|0,9104152,280)|0}c[8452240+(g<<2)>>2]=c[2113054];c[2394]=-1;g=c[2439330]|0;m=(g|0)==0;if(!m){f=g;gGC(9706056,f|0,76)|0}c[2433530]=c[2438118];f=c[3528484]|0;c[2076596]=f;C=c[2417276]|0;c[3541536]=C;c[1836236]=0;gGz(9706056,0,76);if((c[2433572]|0)!=0){l=c[2411308]|0;r=128;o=128;while(1){c[g+76+(o<<2)>>2]=l+((o<<8)+32768);j=r+1&65535;if((j&65535)>255){F=128;G=128;break}else{r=j;o=j&65535}}while(1){o=l+((G<<8)+32768)|0;c[g+76+(G+512<<2)>>2]=o;c[g+76+(G+768<<2)>>2]=o;o=F+1&65535;if((o&65535)>255){break}else{F=o;G=o&65535}}c[2433572]=0}if(!m){m=g;gGC(m|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=f;c[2417276]=C;c[1836236]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;l6(0);C=14115928;c[C>>2]=0;c[C+4>>2]=0;y=0;i=e;return y|0}function d9I(){var b=0,d=0,e=0,f=0,g=0;b=c[3541514]|0;if((b|0)!=0){gGr(b|0);c[3541514]=0}c[2113008]=0;c[2076598]=0;c[2383582]=0;c[2438228]=0;c[2433526]=0;c[2406676]=0;c[3528472]=0;b=c[2406698]|0;if((b|0)!=0){gGr(b);c[2406698]=0}b=c[2385412]|0;if((b|0)!=0){gGr(b);c[2385412]=0}a[64232]=0;fwZ();if((c[2392]|0)>=0){b=0;do{d=14130368+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}d=14130384+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}b=b+1|0;}while((b|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;b=c[2426718]|0;d=0;while(1){if((d|0)>=1024){f=48405;break}g=9638528+(d<<2)|0;if((c[g>>2]|0)==(b|0)){break}else{d=d+1|0}}if((f|0)==48405){c[2426718]=0;return 0}gGr(b);c[g>>2]=0;c[2426718]=0;return 0}function d9J(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0;if((a[9624168]|0)!=0){c[2433572]=-1;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}c[2113050]=0;c[2276080]=0;RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}c[2433530]=c[2438118];f=c[3528484]|0;c[2076596]=f;g=c[2417276]|0;c[3541536]=g;c[1836236]=0;gGz(9706056,0,76);if((c[2433572]|0)!=0){i=c[2411308]|0;j=128;k=128;while(1){c[d+76+(k<<2)>>2]=i+((k<<8)+32768);l=j+1&65535;if((l&65535)>255){m=128;n=128;break}else{j=l;k=l&65535}}while(1){k=i+((n<<8)+32768)|0;c[d+76+(n+512<<2)>>2]=k;c[d+76+(n+768<<2)>>2]=k;k=m+1&65535;if((k&65535)>255){break}else{m=k;n=k&65535}}c[2433572]=0}if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=f;c[2417276]=g;c[1836236]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;l6(0);g=14115928;c[g>>2]=0;c[g+4>>2]=0}a[9625688]=0;a[9625689]=0;a[9625690]=0;g=0;f=0;e=0;d=0;do{f=((a[9633432+g|0]&1)<<g|f&255)&255;e=((a[9631288+g|0]&1)<<g|e&255)&255;d=((a[9551808+g|0]&1)<<g|d&255)&255;g=g+1|0;}while((g|0)<8);a[9625688]=f;a[9625689]=e;a[9625690]=d;d=c[2392]|0;if((d|0)>=0){gGz(8452240,0,((d|0)>0?(d<<2)+4|0:4)|0)}c[2113054]=0;d=c[2385548]|0;if((d|0)>0){gGz(9752472,0,((d|0)>1?d<<2:4)|0)}c[2433530]=0;a[6518008]=1;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}d=c[2439330]|0;if((d|0)!=0){e=d;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;c[2113056]=166666;e=RG(166666)|0;c[2113054]=(c[2113054]|0)+e;c[2276108]=-1;c[2113056]=-1;c[8452200+(c[2394]<<2)>>2]=8193;c[2276080]=256;if((c[2276079]|0)>>>0<256){RH(1)}e=a[6518008]|0?66666:0;d=gGU(e,0,2048e6,0)|0;f=c[2438228]|0;g=gGS(d,K,f,(f|0)<0|0?-1:0)|0;f=g;Sb(e);e=c[2443830]|0;if((e|0)<1073676288){c[2443830]=e-f}e=c[2443831]|0;if((e|0)<1073676288){c[2443831]=e-f}e=(c[3528512]|0)-f|0;c[3528512]=(e|0)<0?0:e;e=c[2112964]|0;if((e|0)!=0){gg[c[3542118]&4095](e,a[9688]|0?534:0)}e=c[1836236]|0;f=c[9757320+(e<<2)>>2]|0;if((f|0)!=0){g=f;gGC(g|0,9706056,76)|0}c[9752472+(e<<2)>>2]=c[2433530];c[14113936+(e<<2)>>2]=c[2076596];c[9669104+(e<<2)>>2]=c[3541536];c[1836236]=-1;e=c[2394]|0;g=c[14130368+(e<<2)>>2]|0;if((g|0)!=0){gGC(g|0,9104152,280)|0}c[8452240+(e<<2)>>2]=c[2113054];c[2394]=-1;if((c[2112968]|0)==0){return 0}d9K()|0;return 0}function d9K(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;f=c[2406900]|0;g=c[2385764]|0;h=c[2385752]|0;i=b[7057652]&511;j=c[2408970]|0;k=c[2112968]|0;l=0;m=0;n=0;while(1){o=(m|0)==64;p=(o&1)+l|0;q=o?0:m;o=(q<<3)-(e[h>>1]|0)|0;r=o+18|0;s=(r|0)<-191?o+530|0:r;r=(p<<3)-i|0;o=(r|0)<-287?r+512|0:r;r=s+7|0;L64011:do{if(r>>>0<=326){if((o+7|0)>>>0>230){break}t=b[f+(n<<1)>>1]|0;u=t&65535;v=j+(((d[14115928+(u>>>11&3)|0]|0)<<11|u&2047)<<6)|0;u=(t&65535)>>>9&112;t=k+((o*320|0)+s<<1)|0;if(s>>>0<312&o>>>0<216){w=u&65535;x=v;y=t;z=0;while(1){b[y>>1]=b[g+((d[x]|0|w)<<1)>>1]|0;b[y+2>>1]=b[g+((d[x+1|0]|0|w)<<1)>>1]|0;b[y+4>>1]=b[g+((d[x+2|0]|0|w)<<1)>>1]|0;b[y+6>>1]=b[g+((d[x+3|0]|0|w)<<1)>>1]|0;b[y+8>>1]=b[g+((d[x+4|0]|0|w)<<1)>>1]|0;b[y+10>>1]=b[g+((d[x+5|0]|0|w)<<1)>>1]|0;b[y+12>>1]=b[g+((d[x+6|0]|0|w)<<1)>>1]|0;b[y+14>>1]=b[g+((d[x+7|0]|0|w)<<1)>>1]|0;A=z+1|0;if((A|0)<8){x=x+8|0;y=y+640|0;z=A}else{break L64011}}}z=u&65535;y=(s+1|0)>>>0<320;x=(s+2|0)>>>0<320;w=(s+3|0)>>>0<320;A=(s+4|0)>>>0<320;B=(s+5|0)>>>0<320;C=(s+6|0)>>>0<320;D=r>>>0<320;if(s>>>0<320){E=v;F=t;G=0;while(1){do{if((G+o|0)>>>0<224){b[F>>1]=b[g+((d[E]|0|z)<<1)>>1]|0;if(y){b[F+2>>1]=b[g+((d[E+1|0]|0|z)<<1)>>1]|0}if(x){b[F+4>>1]=b[g+((d[E+2|0]|0|z)<<1)>>1]|0}if(w){b[F+6>>1]=b[g+((d[E+3|0]|0|z)<<1)>>1]|0}if(A){b[F+8>>1]=b[g+((d[E+4|0]|0|z)<<1)>>1]|0}if(B){b[F+10>>1]=b[g+((d[E+5|0]|0|z)<<1)>>1]|0}if(C){b[F+12>>1]=b[g+((d[E+6|0]|0|z)<<1)>>1]|0}if(!D){break}b[F+14>>1]=b[g+((d[E+7|0]|0|z)<<1)>>1]|0}}while(0);H=G+1|0;if((H|0)<8){E=E+8|0;F=F+640|0;G=H}else{break}}}else{G=v;F=t;E=0;while(1){do{if((E+o|0)>>>0<224){if(y){b[F+2>>1]=b[g+((d[G+1|0]|0|z)<<1)>>1]|0}if(x){b[F+4>>1]=b[g+((d[G+2|0]|0|z)<<1)>>1]|0}if(w){b[F+6>>1]=b[g+((d[G+3|0]|0|z)<<1)>>1]|0}if(A){b[F+8>>1]=b[g+((d[G+4|0]|0|z)<<1)>>1]|0}if(B){b[F+10>>1]=b[g+((d[G+5|0]|0|z)<<1)>>1]|0}if(C){b[F+12>>1]=b[g+((d[G+6|0]|0|z)<<1)>>1]|0}if(!D){break}b[F+14>>1]=b[g+((d[G+7|0]|0|z)<<1)>>1]|0}}while(0);u=E+1|0;if((u|0)<8){G=G+8|0;F=F+640|0;E=u}else{break}}}}}while(0);o=n+1|0;if((o|0)>=4096){break}l=p;m=q+1|0;n=o}eaM(0);eaM(1);n=c[2406898]|0;m=h+1024|0;h=b[7057640]&511;l=0;f=0;i=0;while(1){o=(f|0)==64;s=(o&1)+l|0;r=o?0:f;o=(r<<3)-(e[m>>1]|0)|0;E=o+20|0;F=(E|0)<-191?o+532|0:E;E=(s<<3)-h|0;o=(E|0)<-287?E+512|0:E;E=F+7|0;L64073:do{if(E>>>0<=326){if((o+7|0)>>>0>230){break}G=b[n+(i<<1)>>1]|0;z=G&65535;D=j+(((d[14115928+(z>>>11&3|4)|0]|0)<<11|z&2047)<<6)|0;z=(G&65535)>>>9&112;G=k+((o*320|0)+F<<1)|0;if(F>>>0<312&o>>>0<216){C=z&65535;B=D;A=G;w=0;while(1){x=a[B]|0;if(x<<24>>24!=15){b[A>>1]=b[g+((C|x&255|256)<<1)>>1]|0}x=a[B+1|0]|0;if(x<<24>>24!=15){b[A+2>>1]=b[g+((C|x&255|256)<<1)>>1]|0}x=a[B+2|0]|0;if(x<<24>>24!=15){b[A+4>>1]=b[g+((C|x&255|256)<<1)>>1]|0}x=a[B+3|0]|0;if(x<<24>>24!=15){b[A+6>>1]=b[g+((C|x&255|256)<<1)>>1]|0}x=a[B+4|0]|0;if(x<<24>>24!=15){b[A+8>>1]=b[g+((C|x&255|256)<<1)>>1]|0}x=a[B+5|0]|0;if(x<<24>>24!=15){b[A+10>>1]=b[g+((C|x&255|256)<<1)>>1]|0}x=a[B+6|0]|0;if(x<<24>>24!=15){b[A+12>>1]=b[g+((C|x&255|256)<<1)>>1]|0}x=a[B+7|0]|0;if(x<<24>>24!=15){b[A+14>>1]=b[g+((C|x&255|256)<<1)>>1]|0}x=w+1|0;if((x|0)<8){B=B+8|0;A=A+640|0;w=x}else{break L64073}}}w=(F|0)>-1;A=(F|0)<320;B=z&65535;C=(F+1|0)>>>0>319;x=(F+2|0)>>>0>319;y=(F+3|0)>>>0>319;t=(F+4|0)>>>0>319;v=(F+5|0)>>>0>319;u=(F+6|0)>>>0>319;H=E>>>0>319;I=D;J=G;K=0;while(1){do{if((K+o|0)>>>0<224){L=a[I]|0;if(w&L<<24>>24!=15&A){b[J>>1]=b[g+((B|L&255|256)<<1)>>1]|0}L=a[I+1|0]|0;if(!(L<<24>>24==15|C)){b[J+2>>1]=b[g+((B|L&255|256)<<1)>>1]|0}L=a[I+2|0]|0;if(!(L<<24>>24==15|x)){b[J+4>>1]=b[g+((B|L&255|256)<<1)>>1]|0}L=a[I+3|0]|0;if(!(L<<24>>24==15|y)){b[J+6>>1]=b[g+((B|L&255|256)<<1)>>1]|0}L=a[I+4|0]|0;if(!(L<<24>>24==15|t)){b[J+8>>1]=b[g+((B|L&255|256)<<1)>>1]|0}L=a[I+5|0]|0;if(!(L<<24>>24==15|v)){b[J+10>>1]=b[g+((B|L&255|256)<<1)>>1]|0}L=a[I+6|0]|0;if(!(L<<24>>24==15|u)){b[J+12>>1]=b[g+((B|L&255|256)<<1)>>1]|0}L=a[I+7|0]|0;if(L<<24>>24==15|H){break}b[J+14>>1]=b[g+((B|L&255|256)<<1)>>1]|0}}while(0);L=K+1|0;if((L|0)<8){I=I+8|0;J=J+640|0;K=L}else{break}}}}while(0);o=i+1|0;if((o|0)>=4096){break}l=s;f=r+1|0;i=o}eaM(2);eaM(3);return 0}function d9L(d,f){d=d|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;g=i;i=i+128|0;h=g|0;j=g+16|0;k=g+32|0;l=g+48|0;m=g+64|0;n=g+80|0;o=g+96|0;p=g+112|0;if((f|0)!=0){c[f>>2]=169585}do{if((d&32|0)!=0){gGz(p|0,0,12);q=c[2405652]|0;c[p>>2]=q;c[p+4>>2]=(c[2411658]|0)-q;c[p+12>>2]=162152;q=c[2076592]|0;gj[q&4095](p)|0;if((d&2|0)==0){break}q=c[2385764]|0;r=0;s=c[2411430]|0;while(1){t=e[s>>1]|0;u=t>>>2&248;b[q>>1]=(t>>>7<<8&63488|t&31|(u>>>5|u)<<3&2016)&65535;u=r+1|0;if((u|0)<1024){q=q+2|0;r=u;s=s+2|0}else{break}}}}while(0);if((d&64|0)==0){i=g;return 0}p=k|0;gGz(j|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){s=k+9|0;k=h;r=h|0;q=h+4|0;u=h+12|0;t=j|0;v=j+4|0;w=j+12|0;x=0;do{gGC(p|0,614896,11)|0;a[s]=x+48&255;y=8452256+(x<<2)|0;gGz(k|0,0,12);c[r>>2]=y;c[q>>2]=4;c[u>>2]=164976;gj[c[2076592]&4095](h)|0;if((c[y>>2]|0)!=0){c[t>>2]=c[14130368+(x<<2)>>2];c[v>>2]=c[8452184+(x<<2)>>2];c[w>>2]=p;y=c[2076592]|0;gj[y&4095](j)|0}x=x+1|0;}while((x|0)<=(c[2392]|0))}x=c[2439330]|0;if((x|0)!=0){j=x;gGC(9706056,j|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;fw$(d);j=c[1836236]|0;x=c[9757320+(j<<2)>>2]|0;if((x|0)!=0){p=x;gGC(p|0,9706056,76)|0}c[9752472+(j<<2)>>2]=c[2433530];c[14113936+(j<<2)>>2]=c[2076596];c[9669104+(j<<2)>>2]=c[3541536];c[1836236]=-1;gGz(o|0,0,12);c[o>>2]=14115928;c[o+4>>2]=8;c[o+12>>2]=434592;gj[c[2076592]&4095](o)|0;gGz(n|0,0,12);c[n>>2]=9625688;c[n+4>>2]=10;c[n+12>>2]=215728;gj[c[2076592]&4095](n)|0;T0(d,f);gGz(m|0,0,12);c[m>>2]=9775456;c[m+4>>2]=1;c[m+12>>2]=495376;gj[c[2076592]&4095](m)|0;gGz(l|0,0,12);c[l>>2]=9734288;c[l+4>>2]=4;c[l+12>>2]=432072;gj[c[2076592]&4095](l)|0;if((d&2|0)==0){i=g;return 0}d=c[2433572]|0;c[2433572]=-1;l=d&3;d=c[2411308]|0;m=c[9757320+(c[1836236]<<2)>>2]|0;f=(l<<15)+32768|0;n=128;o=128;while(1){c[m+76+(o<<2)>>2]=d+(f+(o<<8));j=n+1&65535;if((j&65535)>255){z=128;A=128;break}else{n=j;o=j&65535}}while(1){o=d+(f+(A<<8))|0;c[m+76+(A+512<<2)>>2]=o;c[m+76+(A+768<<2)>>2]=o;o=z+1&65535;if((o&65535)>255){break}else{z=o;A=o&65535}}c[2433572]=l;i=g;return 0}function d9M(b){b=b|0;var c=0;switch(b&1048575|0){case 1044487:{c=a[2461424]&1;break};case 1044482:{c=-1;break};case 1044483:{c=~a[9625689];break};case 1044489:{c=~a[9625690];break};case 1044485:{c=~a[9625692];break};case 1044481:{c=~a[9625688];break};case 1044480:{c=~a[9625691];break};case 1044484:{c=~a[9625693];break};default:{c=0}}return c|0}function d9N(b,d){b=b|0;d=d|0;var e=0,f=0;if((b&1044480|0)==1040384){a[(c[2411430]|0)+(b&2047^1)|0]=d;return}if((b&1048575|0)!=1044494){return}a[2461424]=1;b=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;e=a[6518008]|0;f=gGU(b,(b|0)<0|0?-1:0,e?66666:0,e?0:0)|0;e=gGS(f,K,166666,0)|0;f=e;if((f|0)<=((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)){return}Sb(f);a[9775456]=d;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12;return}function d9O(d,e){d=d|0;e=e|0;var f=0,g=0,h=0;if((d&1044480|0)==1040384){f=d&2046;b[(c[2411430]|0)+f>>1]=e;g=e&65535;h=g>>>2&248;b[(c[2385764]|0)+(f>>>1<<1)>>1]=(g>>>7<<8&63488|g&31|(h>>>5|h)<<3&2016)&65535;return}switch(d&1048575|0){case 1044488:{a[14115928]=e&15;a[14115929]=(e&65535)>>>4&15;a[14115930]=(e&65535)>>>8&15;a[14115931]=(e&65535)>>>12&255;return};case 1044490:{a[14115932]=e&15;a[14115933]=(e&65535)>>>4&15;a[14115934]=(e&65535)>>>8&15;a[14115935]=(e&65535)>>>12&255;return};case 1044482:{b[7057652]=e;return};case 1044484:{b[7057644]=e;return};case 1044486:{b[7057640]=e;return};default:{return}}}function d9P(b){b=b|0;var d=0,e=0,f=0.0,g=0.0,i=0,j=0,k=0;d=b&255;if((d|0)==24){b=c[3541514]|0;e=b+552|0;f=+h[e>>3];do{if(f!=0.0){g=+h[6675];if(f-(g+ +gC[c[2429842]&255]())>0.0){i=a[b+563|0]|-128;break}else{h[e>>3]=0.0;j=48607;break}}else{j=48607}}while(0);if((j|0)==48607){i=a[b+563|0]|0}k=i&-125;return k|0}else if((d|0)==26){k=a[(c[3541514]|0)+20904|0]|0;return k|0}else if((d|0)==20){k=a[9775456]|0;return k|0}else{k=0;return k|0}return 0}function d9Q(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=b&65535;switch(e&255|0){case 20:{a[2461424]=0;return};case 24:case 25:case 26:case 27:{l7(e&3,d);return};case 0:{e=d&3;if((e|0)==(c[2433572]|0)){return}d=c[2411308]|0;b=c[9757320+(c[1836236]<<2)>>2]|0;f=(e<<15)+32768|0;g=128;h=128;while(1){c[b+76+(h<<2)>>2]=d+(f+(h<<8));i=g+1&65535;if((i&65535)>255){j=128;k=128;break}else{g=i;h=i&65535}}while(1){h=d+(f+(k<<8))|0;c[b+76+(k+512<<2)>>2]=h;c[b+76+(k+768<<2)>>2]=h;h=j+1&65535;if((h&65535)>255){break}else{j=h;k=h&65535}}c[2433572]=e;return};default:{return}}}function d9R(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2117860+(b*112|0)>>2];c[a+104>>2]=c[2117864+(b*112|0)>>2];c[a+108>>2]=c[2117868+(b*112|0)>>2];d=0;return d|0}function d9S(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=2117760+(b*112|0);e=0;return e|0}function d9T(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>23){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=998672+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function d9U(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>43){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=2119552+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function d9V(){var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;d=i;i=i+1200|0;e=d|0;f=d+112|0;g=d+120|0;j=d+232|0;k=d+240|0;l=d+352|0;m=d+360|0;n=d+472|0;o=d+480|0;p=d+592|0;q=d+600|0;r=d+712|0;s=d+720|0;t=d+832|0;u=d+840|0;v=d+952|0;w=d+960|0;x=d+1072|0;y=d+1080|0;z=d+1192|0;c[2426718]=0;c[2418150]=0;c[2411308]=786432;c[2418084]=983040;c[2408970]=983104;c[2406830]=3604544;c[2388318]=3604800;c[2388316]=7799104;c[2406834]=9896256;c[3527032]=131072;c[2406832]=10027328;c[3527030]=1048576;c[2405652]=11075904;c[2406900]=11075904;c[2406898]=11084096;c[2406876]=11092288;c[2406872]=11108672;c[2406870]=11125056;c[2385752]=11127104;c[2437018]=8191;c[2437016]=8191;c[2437012]=16383;c[2437010]=8191;c[2418264]=11131200;c[2411430]=11213120;c[2411350]=11215168;c[2411658]=11217216;c[2385764]=11217216;A=0;while(1){if((A|0)>=1024){break}B=9638528+(A<<2)|0;if((c[B>>2]|0)==0){C=48658;break}else{A=A+1|0}}do{if((C|0)==48658){A=gGq(11219264)|0;c[B>>2]=A;if((A|0)==0){break}c[2426718]=A;gGz(A|0,0,11219264);c[2418150]=A;c[2411308]=A+786432;c[2418084]=A+983040;c[2408970]=A+983104;c[2406830]=A+3604544;c[2388318]=A+3604800;D=A+7799104|0;c[2406828]=D;c[2388316]=D;c[2406834]=A+9896256;c[3527032]=131072;c[2406832]=A+10027328;D=A+11075904|0;c[3527030]=1048576;c[2405652]=D;c[2406900]=D;c[2406898]=A+11084096;c[2406876]=A+11092288;c[2406872]=A+11108672;c[2406870]=A+11125056;c[2385752]=A+11127104;c[2437018]=8191;c[2437016]=8191;c[2437012]=16383;c[2437010]=8191;c[2418264]=A+11131200;c[2411430]=A+11213120;c[2411350]=A+11215168;D=A+11217216|0;c[2411658]=D;c[2385764]=D;c[2414198]=A+11219264;if((c[3542200]|0)==0){E=1;i=d;return E|0}D=y+108|0;c[D>>2]=0;F=y+100|0;c[F>>2]=0;G=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[G&16383](y,0)|0;do{if((c[D>>2]|0)!=0){G=c[F>>2]|0;c[z>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](z,0,0)|0;if((G|0)<1){E=1;i=d;return E|0}if((gzL(A,0,0)|0)==0){break}else{E=1}i=d;return E|0}}while(0);A=(c[2418150]|0)+262144|0;if((c[3542200]|0)==0){E=1;i=d;return E|0}F=w+108|0;c[F>>2]=0;D=w+100|0;c[D>>2]=0;G=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[G&16383](w,1)|0;do{if((c[F>>2]|0)!=0){G=c[D>>2]|0;c[x>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](x,1,0)|0;if((G|0)<1){E=1;i=d;return E|0}if((gzL(A,0,1)|0)==0){break}else{E=1}i=d;return E|0}}while(0);A=(c[2418150]|0)+524288|0;if((c[3542200]|0)==0){E=1;i=d;return E|0}D=u+108|0;c[D>>2]=0;F=u+100|0;c[F>>2]=0;G=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[G&16383](u,2)|0;do{if((c[D>>2]|0)!=0){G=c[F>>2]|0;c[v>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](v,2,0)|0;if((G|0)<1){E=1;i=d;return E|0}if((gzL(A,0,2)|0)==0){break}else{E=1}i=d;return E|0}}while(0);A=c[2418084]|0;do{if((c[3542200]|0)!=0){F=s+108|0;c[F>>2]=0;D=s+100|0;c[D>>2]=0;G=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[G&16383](s,3)|0;if((c[F>>2]|0)==0){break}F=c[D>>2]|0;c[t>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](t,3,0)|0;if((F|0)<1){break}gzL(A,0,3)|0}}while(0);A=(c[2418084]|0)+524288|0;do{if((c[3542200]|0)!=0){F=q+108|0;c[F>>2]=0;D=q+100|0;c[D>>2]=0;G=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[G&16383](q,4)|0;if((c[F>>2]|0)==0){break}F=c[D>>2]|0;c[r>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](r,4,0)|0;if((F|0)<1){break}gzL(A,0,4)|0}}while(0);A=(c[2418084]|0)+655360|0;do{if((c[3542200]|0)!=0){F=o+108|0;c[F>>2]=0;D=o+100|0;c[D>>2]=0;G=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[G&16383](o,5)|0;if((c[F>>2]|0)==0){break}F=c[D>>2]|0;c[p>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](p,5,0)|0;if((F|0)<1){break}gzL(A,0,5)|0}}while(0);A=(c[2418084]|0)+1179648|0;do{if((c[3542200]|0)!=0){F=m+108|0;c[F>>2]=0;D=m+100|0;c[D>>2]=0;G=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[G&16383](m,6)|0;if((c[F>>2]|0)==0){break}F=c[D>>2]|0;c[n>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](n,6,0)|0;if((F|0)<1){break}gzL(A,0,6)|0}}while(0);eaF(81920);A=c[2406830]|0;R6(A,7,2)|0;A=(c[2406830]|0)+1|0;R6(A,9,2)|0;A=(c[2406830]|0)+1048576|0;R6(A,8,2)|0;A=(c[2406830]|0)+1048577|0;R6(A,10,2)|0;A=(c[2406830]|0)+2097152|0;R6(A,11,2)|0;A=(c[2406830]|0)+2097153|0;R6(A,12,2)|0;eaL(c[2388318]|0,c[2406830]|0,24576);A=(c[2411308]|0)+65536|0;if((c[3542200]|0)==0){E=1;i=d;return E|0}F=k+108|0;c[F>>2]=0;D=k+100|0;c[D>>2]=0;G=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[G&16383](k,13)|0;do{if((c[F>>2]|0)!=0){G=c[D>>2]|0;c[l>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](l,13,0)|0;if((G|0)<1){E=1;i=d;return E|0}if((gzL(A,0,13)|0)==0){break}else{E=1}i=d;return E|0}}while(0);A=c[2411308]|0;D=A+65536|0;gGC(A|0,D|0,65536)|0;D=c[2406834]|0;do{if((c[3542200]|0)!=0){A=g+108|0;c[A>>2]=0;F=g+100|0;c[F>>2]=0;G=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[G&16383](g,14)|0;if((c[A>>2]|0)==0){break}A=c[F>>2]|0;c[j>>2]=9534384;F=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[F&16383](j,14,0)|0;if((A|0)<1){break}gzL(D,0,14)|0}}while(0);D=c[2406832]|0;do{if((c[3542200]|0)!=0){A=e+108|0;c[A>>2]=0;F=e+100|0;c[F>>2]=0;G=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[G&16383](e,15)|0;if((c[A>>2]|0)==0){break}A=c[F>>2]|0;c[f>>2]=9534384;F=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[F&16383](f,15,0)|0;if((A|0)<1){break}gzL(D,0,15)|0}}while(0);fxU(0,425984);if((c[2394]|0)==0){I=c[2112932]|0}else{c[2394]=0;D=c[3532596]|0;c[2112932]=D;A=c[3532592]|0;if((A|0)!=0){gGC(9104152,A|0,280)|0}c[2113054]=c[2113060];I=D}D=c[2418150]|0;A=I|0;F=0;while(1){G=D+F|0;c[A>>2]=G;c[A+131072>>2]=G;G=F+1024|0;if(G>>>0>786431){break}else{A=A+4|0;F=G}}F=c[2418264]|0;A=I+3072|0;D=786432;while(1){G=F+(D-786432)|0;c[A>>2]=G;c[A+65536>>2]=G;c[A+131072>>2]=G;G=D+1024|0;if(G>>>0>851967){break}else{A=A+4|0;D=G}}D=c[2406900]|0;A=D;c[I+3328>>2]=A;c[I+68864>>2]=A;c[I+134400>>2]=A;A=D+1024|0;c[I+3332>>2]=A;c[I+68868>>2]=A;c[I+134404>>2]=A;A=D+2048|0;c[I+3336>>2]=A;c[I+68872>>2]=A;c[I+134408>>2]=A;A=D+3072|0;c[I+3340>>2]=A;c[I+68876>>2]=A;c[I+134412>>2]=A;A=D+4096|0;c[I+3344>>2]=A;c[I+68880>>2]=A;c[I+134416>>2]=A;A=D+5120|0;c[I+3348>>2]=A;c[I+68884>>2]=A;c[I+134420>>2]=A;A=D+6144|0;c[I+3352>>2]=A;c[I+68888>>2]=A;c[I+134424>>2]=A;A=D+7168|0;c[I+3356>>2]=A;c[I+68892>>2]=A;c[I+134428>>2]=A;A=c[2406898]|0;D=A;c[I+3360>>2]=D;c[I+68896>>2]=D;c[I+134432>>2]=D;D=A+1024|0;c[I+3364>>2]=D;c[I+68900>>2]=D;c[I+134436>>2]=D;D=A+2048|0;c[I+3368>>2]=D;c[I+68904>>2]=D;c[I+134440>>2]=D;D=A+3072|0;c[I+3372>>2]=D;c[I+68908>>2]=D;c[I+134444>>2]=D;D=A+4096|0;c[I+3376>>2]=D;c[I+68912>>2]=D;c[I+134448>>2]=D;D=A+5120|0;c[I+3380>>2]=D;c[I+68916>>2]=D;c[I+134452>>2]=D;D=A+6144|0;c[I+3384>>2]=D;c[I+68920>>2]=D;c[I+134456>>2]=D;D=A+7168|0;c[I+3388>>2]=D;c[I+68924>>2]=D;c[I+134460>>2]=D;D=c[2406876]|0;A=D;c[I+3584>>2]=A;c[I+69120>>2]=A;c[I+134656>>2]=A;A=D+1024|0;c[I+3588>>2]=A;c[I+69124>>2]=A;c[I+134660>>2]=A;A=D+2048|0;c[I+3592>>2]=A;c[I+69128>>2]=A;c[I+134664>>2]=A;A=D+3072|0;c[I+3596>>2]=A;c[I+69132>>2]=A;c[I+134668>>2]=A;A=D+4096|0;c[I+3600>>2]=A;c[I+69136>>2]=A;c[I+134672>>2]=A;A=D+5120|0;c[I+3604>>2]=A;c[I+69140>>2]=A;c[I+134676>>2]=A;A=D+6144|0;c[I+3608>>2]=A;c[I+69144>>2]=A;c[I+134680>>2]=A;A=D+7168|0;c[I+3612>>2]=A;c[I+69148>>2]=A;c[I+134684>>2]=A;A=D+8192|0;c[I+3616>>2]=A;c[I+69152>>2]=A;c[I+134688>>2]=A;A=D+9216|0;c[I+3620>>2]=A;c[I+69156>>2]=A;c[I+134692>>2]=A;A=D+10240|0;c[I+3624>>2]=A;c[I+69160>>2]=A;c[I+134696>>2]=A;A=D+11264|0;c[I+3628>>2]=A;c[I+69164>>2]=A;c[I+134700>>2]=A;A=D+12288|0;c[I+3632>>2]=A;c[I+69168>>2]=A;c[I+134704>>2]=A;A=D+13312|0;c[I+3636>>2]=A;c[I+69172>>2]=A;c[I+134708>>2]=A;A=D+14336|0;c[I+3640>>2]=A;c[I+69176>>2]=A;c[I+134712>>2]=A;A=D+15360|0;c[I+3644>>2]=A;c[I+69180>>2]=A;c[I+134716>>2]=A;A=c[2406872]|0;D=A;c[I+3648>>2]=D;c[I+69184>>2]=D;c[I+134720>>2]=D;D=A+1024|0;c[I+3652>>2]=D;c[I+69188>>2]=D;c[I+134724>>2]=D;D=A+2048|0;c[I+3656>>2]=D;c[I+69192>>2]=D;c[I+134728>>2]=D;D=A+3072|0;c[I+3660>>2]=D;c[I+69196>>2]=D;c[I+134732>>2]=D;D=A+4096|0;c[I+3664>>2]=D;c[I+69200>>2]=D;c[I+134736>>2]=D;D=A+5120|0;c[I+3668>>2]=D;c[I+69204>>2]=D;c[I+134740>>2]=D;D=A+6144|0;c[I+3672>>2]=D;c[I+69208>>2]=D;c[I+134744>>2]=D;D=A+7168|0;c[I+3676>>2]=D;c[I+69212>>2]=D;c[I+134748>>2]=D;D=A+8192|0;c[I+3680>>2]=D;c[I+69216>>2]=D;c[I+134752>>2]=D;D=A+9216|0;c[I+3684>>2]=D;c[I+69220>>2]=D;c[I+134756>>2]=D;D=A+10240|0;c[I+3688>>2]=D;c[I+69224>>2]=D;c[I+134760>>2]=D;D=A+11264|0;c[I+3692>>2]=D;c[I+69228>>2]=D;c[I+134764>>2]=D;D=A+12288|0;c[I+3696>>2]=D;c[I+69232>>2]=D;c[I+134768>>2]=D;D=A+13312|0;c[I+3700>>2]=D;c[I+69236>>2]=D;c[I+134772>>2]=D;D=A+14336|0;c[I+3704>>2]=D;c[I+69240>>2]=D;c[I+134776>>2]=D;D=A+15360|0;c[I+3708>>2]=D;c[I+69244>>2]=D;c[I+134780>>2]=D;D=F+65536|0;c[I+3968>>2]=D;c[I+69504>>2]=D;c[I+135040>>2]=D;A=F+66560|0;c[I+3972>>2]=A;c[I+69508>>2]=A;c[I+135044>>2]=A;G=F+67584|0;c[I+3976>>2]=G;c[I+69512>>2]=G;c[I+135048>>2]=G;H=F+68608|0;c[I+3980>>2]=H;c[I+69516>>2]=H;c[I+135052>>2]=H;J=F+69632|0;c[I+3984>>2]=J;c[I+69520>>2]=J;c[I+135056>>2]=J;K=F+70656|0;c[I+3988>>2]=K;c[I+69524>>2]=K;c[I+135060>>2]=K;L=F+71680|0;c[I+3992>>2]=L;c[I+69528>>2]=L;c[I+135064>>2]=L;M=F+72704|0;c[I+3996>>2]=M;c[I+69532>>2]=M;c[I+135068>>2]=M;N=F+73728|0;c[I+4e3>>2]=N;c[I+69536>>2]=N;c[I+135072>>2]=N;O=F+74752|0;c[I+4004>>2]=O;c[I+69540>>2]=O;c[I+135076>>2]=O;P=F+75776|0;c[I+4008>>2]=P;c[I+69544>>2]=P;c[I+135080>>2]=P;Q=F+76800|0;c[I+4012>>2]=Q;c[I+69548>>2]=Q;c[I+135084>>2]=Q;R=F+77824|0;c[I+4016>>2]=R;c[I+69552>>2]=R;c[I+135088>>2]=R;S=F+78848|0;c[I+4020>>2]=S;c[I+69556>>2]=S;c[I+135092>>2]=S;T=F+79872|0;c[I+4024>>2]=T;c[I+69560>>2]=T;c[I+135096>>2]=T;U=F+80896|0;c[I+4028>>2]=U;c[I+69564>>2]=U;c[I+135100>>2]=U;c[I+65408>>2]=D;c[I+130944>>2]=D;c[I+196480>>2]=D;c[I+65412>>2]=A;c[I+130948>>2]=A;c[I+196484>>2]=A;c[I+65416>>2]=G;c[I+130952>>2]=G;c[I+196488>>2]=G;c[I+65420>>2]=H;c[I+130956>>2]=H;c[I+196492>>2]=H;c[I+65424>>2]=J;c[I+130960>>2]=J;c[I+196496>>2]=J;c[I+65428>>2]=K;c[I+130964>>2]=K;c[I+196500>>2]=K;c[I+65432>>2]=L;c[I+130968>>2]=L;c[I+196504>>2]=L;c[I+65436>>2]=M;c[I+130972>>2]=M;c[I+196508>>2]=M;c[I+65440>>2]=N;c[I+130976>>2]=N;c[I+196512>>2]=N;c[I+65444>>2]=O;c[I+130980>>2]=O;c[I+196516>>2]=O;c[I+65448>>2]=P;c[I+130984>>2]=P;c[I+196520>>2]=P;c[I+65452>>2]=Q;c[I+130988>>2]=Q;c[I+196524>>2]=Q;c[I+65456>>2]=R;c[I+130992>>2]=R;c[I+196528>>2]=R;c[I+65460>>2]=S;c[I+130996>>2]=S;c[I+196532>>2]=S;c[I+65464>>2]=T;c[I+131e3>>2]=T;c[I+196536>>2]=T;c[I+65468>>2]=U;c[I+131004>>2]=U;c[I+196540>>2]=U;U=c[2406870]|0;T=U;S=c[2112932]|0;c[S+4032>>2]=T;c[S+69568>>2]=T;c[S+135104>>2]=T;R=U+1024|0;c[S+4036>>2]=R;c[S+69572>>2]=R;c[S+135108>>2]=R;c[S+65472>>2]=T;c[S+131008>>2]=T;c[S+196544>>2]=T;c[S+65476>>2]=R;c[S+131012>>2]=R;c[S+196548>>2]=R;R=c[2385752]|0;T=R;c[S+4048>>2]=T;c[S+69584>>2]=T;c[S+135120>>2]=T;U=R+1024|0;c[S+4052>>2]=U;c[S+69588>>2]=U;c[S+135124>>2]=U;Q=R+2048|0;c[S+4056>>2]=Q;c[S+69592>>2]=Q;c[S+135128>>2]=Q;P=R+3072|0;c[S+4060>>2]=P;c[S+69596>>2]=P;c[S+135132>>2]=P;c[S+65488>>2]=T;c[S+131024>>2]=T;c[S+196560>>2]=T;c[S+65492>>2]=U;c[S+131028>>2]=U;c[S+196564>>2]=U;c[S+65496>>2]=Q;c[S+131032>>2]=Q;c[S+196568>>2]=Q;c[S+65500>>2]=P;c[S+131036>>2]=P;c[S+196572>>2]=P;P=c[2411430]|0;c[S+4064>>2]=P;c[S+135136>>2]=P;Q=P+1024|0;c[S+4068>>2]=Q;c[S+135140>>2]=Q;c[S+196608>>2]=2168;c[S+196728>>2]=568;c[S+196648>>2]=2340;S=c[2394]|0;Q=c[14130368+(S<<2)>>2]|0;if((Q|0)!=0){gGC(Q|0,9104152,280)|0}c[8452240+(S<<2)>>2]=c[2113054];c[2394]=-1;fwR(0);S=c[2439330]|0;Q=(S|0)==0;if(!Q){P=S;gGC(9706056,P|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];P=c[3528484]|0;c[2076596]=P;U=c[2417276]|0;c[3541536]=U;c[1836236]=0;T=c[2411308]|0;R=0;O=0;while(1){c[S+76+(O<<2)>>2]=T+(O<<8);N=R+1&65535;if((N&65535)>119){V=0;W=0;break}else{R=N;O=N&65535}}while(1){O=T+(W<<8)|0;c[S+76+(W+512<<2)>>2]=O;c[S+76+(W+768<<2)>>2]=O;O=V+1&65535;if((O&65535)>119){break}else{V=O;W=O&65535}}T=c[2411350]|0;c[S+556>>2]=T;O=T+256|0;c[S+560>>2]=O;R=T+512|0;c[S+564>>2]=R;F=T+768|0;c[S+568>>2]=F;N=T+1024|0;c[S+572>>2]=N;M=T+1280|0;c[S+576>>2]=M;L=T+1536|0;c[S+580>>2]=L;K=T+1792|0;c[S+584>>2]=K;c[S+1580>>2]=T;c[S+1584>>2]=O;c[S+1588>>2]=R;c[S+1592>>2]=F;c[S+1596>>2]=N;c[S+1600>>2]=M;c[S+1604>>2]=L;c[S+1608>>2]=K;c[S+2604>>2]=T;c[S+3628>>2]=T;c[S+2608>>2]=O;c[S+3632>>2]=O;c[S+2612>>2]=R;c[S+3636>>2]=R;c[S+2616>>2]=F;c[S+3640>>2]=F;c[S+2620>>2]=N;c[S+3644>>2]=N;c[S+2624>>2]=M;c[S+3648>>2]=M;c[S+2628>>2]=L;c[S+3652>>2]=L;c[S+2632>>2]=K;c[S+3656>>2]=K;c[S+4172>>2]=284;c[S+4176>>2]=1092;if(!Q){K=S;gGC(K|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=P;c[2417276]=U;c[1836236]=-1;TW(c[2406832]|0,14108120,c[2406834]|0,14108128,2450,3506,58);c[2438228]=4e6;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=511;h[745406]=1.0;c[2436786]=1;h[745405]=1.0;c[2436784]=2;h[745404]=.25;a[3203280]=1;c[2433572]=-1;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];K=c[3532592]|0;if((K|0)!=0){gGC(9104152,K|0,280)|0}c[2113054]=c[2113060]}c[2113050]=0;c[2276080]=0;RI();K=c[2394]|0;L=c[14130368+(K<<2)>>2]|0;if((L|0)!=0){gGC(L|0,9104152,280)|0}c[8452240+(K<<2)>>2]=c[2113054];c[2394]=-1;K=c[2439330]|0;L=(K|0)==0;if(!L){M=K;gGC(9706056,M|0,76)|0}c[2433530]=c[2438118];M=c[3528484]|0;c[2076596]=M;N=c[2417276]|0;c[3541536]=N;c[1836236]=0;gGz(9706056,0,76);if((c[2433572]|0)!=0){F=c[2411308]|0;R=128;O=128;while(1){c[K+76+(O<<2)>>2]=F+((O<<8)+32768);T=R+1&65535;if((T&65535)>255){X=128;Y=128;break}else{R=T;O=T&65535}}while(1){O=F+((Y<<8)+32768)|0;c[K+76+(Y+512<<2)>>2]=O;c[K+76+(Y+768<<2)>>2]=O;O=X+1&65535;if((O&65535)>255){break}else{X=O;Y=O&65535}}c[2433572]=0}if(!L){F=K;gGC(F|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=M;c[2417276]=N;c[1836236]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;l6(0);F=14115928;c[F>>2]=0;c[F+4>>2]=0;E=0;i=d;return E|0}}while(0);c[2426718]=0;E=1;i=d;return E|0}function d9W(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0;if((a[9624168]|0)!=0){c[2433572]=-1;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}c[2113050]=0;c[2276080]=0;RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}c[2433530]=c[2438118];f=c[3528484]|0;c[2076596]=f;g=c[2417276]|0;c[3541536]=g;c[1836236]=0;gGz(9706056,0,76);if((c[2433572]|0)!=0){i=c[2411308]|0;j=128;k=128;while(1){c[d+76+(k<<2)>>2]=i+((k<<8)+32768);l=j+1&65535;if((l&65535)>255){m=128;n=128;break}else{j=l;k=l&65535}}while(1){k=i+((n<<8)+32768)|0;c[d+76+(n+512<<2)>>2]=k;c[d+76+(n+768<<2)>>2]=k;k=m+1&65535;if((k&65535)>255){break}else{m=k;n=k&65535}}c[2433572]=0}if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=f;c[2417276]=g;c[1836236]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;l6(0);g=14115928;c[g>>2]=0;c[g+4>>2]=0}c[2406422]=0;g=0;f=0;e=0;d=0;n=0;do{f=((a[9633432+g|0]&1)<<g|f&255)&255;e=((a[9631288+g|0]&1)<<g|e&255)&255;d=((a[9629568+g|0]&1)<<g|d&255)&255;n=((a[9551808+g|0]&1)<<g|n&255)&255;g=g+1|0;}while((g|0)<8);a[9625688]=f;a[9625689]=e;a[9625690]=d;a[9625691]=n;n=c[2392]|0;if((n|0)>=0){gGz(8452240,0,((n|0)>0?(n<<2)+4|0:4)|0)}c[2113054]=0;n=c[2385548]|0;if((n|0)>0){gGz(9752472,0,((n|0)>1?n<<2:4)|0)}c[2433530]=0;a[6518008]=1;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];n=c[3532592]|0;if((n|0)!=0){gGC(9104152,n|0,280)|0}c[2113054]=c[2113060]}n=c[2439330]|0;if((n|0)!=0){d=n;gGC(9706056,d|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;c[2113056]=166666;d=RG(166666)|0;c[2113054]=(c[2113054]|0)+d;c[2276108]=-1;c[2113056]=-1;c[8452200+(c[2394]<<2)>>2]=8193;c[2276080]=256;if((c[2276079]|0)>>>0<256){RH(1)}d=a[6518008]|0?66666:0;n=gGU(d,0,2048e6,0)|0;e=c[2438228]|0;f=gGS(n,K,e,(e|0)<0|0?-1:0)|0;e=f;Sb(d);d=c[2443830]|0;if((d|0)<1073676288){c[2443830]=d-e}d=c[2443831]|0;if((d|0)<1073676288){c[2443831]=d-e}d=(c[3528512]|0)-e|0;c[3528512]=(d|0)<0?0:d;d=c[2112964]|0;if((d|0)!=0){gg[c[3542118]&4095](d,a[9688]|0?534:0)}d=c[1836236]|0;e=c[9757320+(d<<2)>>2]|0;if((e|0)!=0){f=e;gGC(f|0,9706056,76)|0}c[9752472+(d<<2)>>2]=c[2433530];c[14113936+(d<<2)>>2]=c[2076596];c[9669104+(d<<2)>>2]=c[3541536];c[1836236]=-1;d=c[2394]|0;f=c[14130368+(d<<2)>>2]|0;if((f|0)!=0){gGC(f|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;if((c[2112968]|0)==0){return 0}d9X()|0;return 0}function d9X(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;e=c[2406900]|0;f=c[2408970]|0;g=c[2385764]|0;h=(c[2385752]|0)+14|0;i=b[7057652]&511;j=c[2112968]|0;k=0;l=0;m=0;while(1){n=(l|0)==64;o=(n&1)+k|0;p=n?0:l;n=(p<<3)-(b[h>>1]&511)|0;q=n-11|0;r=(q|0)<-159?n+501|0:q;q=(o<<3)-i|0;n=q-2|0;s=(n|0)<-271?q+510|0:n;n=r+7|0;L64477:do{if(n>>>0<=358){if((s+7|0)>>>0>246){break}q=b[e+(m<<1)>>1]|0;t=q&65535;u=f+(((d[14115928+(t>>>11&3)|0]|0)<<11|t&2047)<<6)|0;t=(q&65535)>>>9&112;q=j+((s*352|0)+r<<1)|0;if(r>>>0<344&s>>>0<232){v=t&65535;w=u;x=q;y=0;while(1){b[x>>1]=b[g+((d[w]|0|v)<<1)>>1]|0;b[x+2>>1]=b[g+((d[w+1|0]|0|v)<<1)>>1]|0;b[x+4>>1]=b[g+((d[w+2|0]|0|v)<<1)>>1]|0;b[x+6>>1]=b[g+((d[w+3|0]|0|v)<<1)>>1]|0;b[x+8>>1]=b[g+((d[w+4|0]|0|v)<<1)>>1]|0;b[x+10>>1]=b[g+((d[w+5|0]|0|v)<<1)>>1]|0;b[x+12>>1]=b[g+((d[w+6|0]|0|v)<<1)>>1]|0;b[x+14>>1]=b[g+((d[w+7|0]|0|v)<<1)>>1]|0;z=y+1|0;if((z|0)<8){w=w+8|0;x=x+704|0;y=z}else{break L64477}}}y=r>>>0<352;x=t&65535;w=(r+1|0)>>>0<352;v=(r+2|0)>>>0<352;z=(r+3|0)>>>0<352;A=(r+4|0)>>>0<352;B=(r+5|0)>>>0<352;C=(r+6|0)>>>0<352;D=n>>>0<352;E=u;F=q;G=0;while(1){do{if((G+s|0)>>>0<240){if(y){b[F>>1]=b[g+((d[E]|0|x)<<1)>>1]|0}if(w){b[F+2>>1]=b[g+((d[E+1|0]|0|x)<<1)>>1]|0}if(v){b[F+4>>1]=b[g+((d[E+2|0]|0|x)<<1)>>1]|0}if(z){b[F+6>>1]=b[g+((d[E+3|0]|0|x)<<1)>>1]|0}if(A){b[F+8>>1]=b[g+((d[E+4|0]|0|x)<<1)>>1]|0}if(B){b[F+10>>1]=b[g+((d[E+5|0]|0|x)<<1)>>1]|0}if(C){b[F+12>>1]=b[g+((d[E+6|0]|0|x)<<1)>>1]|0}if(!D){break}b[F+14>>1]=b[g+((d[E+7|0]|0|x)<<1)>>1]|0}}while(0);H=G+1|0;if((H|0)<8){E=E+8|0;F=F+704|0;G=H}else{break}}}}while(0);s=m+1|0;if((s|0)>=4096){break}k=o;l=p+1|0;m=s}m=c[2406898]|0;l=b[7057644]&511;k=b[7057640]&511;e=0;i=0;h=0;while(1){s=(i|0)==64;n=(s&1)+e|0;r=s?0:i;s=(r<<3)-l|0;G=s+7|0;F=(G|0)<-159?s+519|0:G;G=(n<<3)-k|0;s=G-2|0;E=(s|0)<-271?G+510|0:s;s=F+7|0;L64517:do{if(s>>>0<=358){if((E+7|0)>>>0>246){break}G=b[m+(h<<1)>>1]|0;x=G&65535;D=f+((((d[14115928+(x>>>11&3|4)|0]|0)<<11|x&2047)<<6)+1310720)|0;x=(G&65535)>>>9&112;G=j+((E*352|0)+F<<1)|0;if(F>>>0<344&E>>>0<232){C=x&65535;B=D;A=G;z=0;while(1){v=a[B]|0;if(v<<24>>24!=15){b[A>>1]=b[g+((C|v&255|256)<<1)>>1]|0}v=a[B+1|0]|0;if(v<<24>>24!=15){b[A+2>>1]=b[g+((C|v&255|256)<<1)>>1]|0}v=a[B+2|0]|0;if(v<<24>>24!=15){b[A+4>>1]=b[g+((C|v&255|256)<<1)>>1]|0}v=a[B+3|0]|0;if(v<<24>>24!=15){b[A+6>>1]=b[g+((C|v&255|256)<<1)>>1]|0}v=a[B+4|0]|0;if(v<<24>>24!=15){b[A+8>>1]=b[g+((C|v&255|256)<<1)>>1]|0}v=a[B+5|0]|0;if(v<<24>>24!=15){b[A+10>>1]=b[g+((C|v&255|256)<<1)>>1]|0}v=a[B+6|0]|0;if(v<<24>>24!=15){b[A+12>>1]=b[g+((C|v&255|256)<<1)>>1]|0}v=a[B+7|0]|0;if(v<<24>>24!=15){b[A+14>>1]=b[g+((C|v&255|256)<<1)>>1]|0}v=z+1|0;if((v|0)<8){B=B+8|0;A=A+704|0;z=v}else{break L64517}}}z=(F|0)>-1;A=(F|0)<352;B=x&65535;C=(F+1|0)>>>0>351;v=(F+2|0)>>>0>351;w=(F+3|0)>>>0>351;y=(F+4|0)>>>0>351;q=(F+5|0)>>>0>351;u=(F+6|0)>>>0>351;t=s>>>0>351;H=D;I=G;J=0;while(1){do{if((J+E|0)>>>0<240){K=a[H]|0;if(z&K<<24>>24!=15&A){b[I>>1]=b[g+((B|K&255|256)<<1)>>1]|0}K=a[H+1|0]|0;if(!(K<<24>>24==15|C)){b[I+2>>1]=b[g+((B|K&255|256)<<1)>>1]|0}K=a[H+2|0]|0;if(!(K<<24>>24==15|v)){b[I+4>>1]=b[g+((B|K&255|256)<<1)>>1]|0}K=a[H+3|0]|0;if(!(K<<24>>24==15|w)){b[I+6>>1]=b[g+((B|K&255|256)<<1)>>1]|0}K=a[H+4|0]|0;if(!(K<<24>>24==15|y)){b[I+8>>1]=b[g+((B|K&255|256)<<1)>>1]|0}K=a[H+5|0]|0;if(!(K<<24>>24==15|q)){b[I+10>>1]=b[g+((B|K&255|256)<<1)>>1]|0}K=a[H+6|0]|0;if(!(K<<24>>24==15|u)){b[I+12>>1]=b[g+((B|K&255|256)<<1)>>1]|0}K=a[H+7|0]|0;if(K<<24>>24==15|t){break}b[I+14>>1]=b[g+((B|K&255|256)<<1)>>1]|0}}while(0);K=J+1|0;if((K|0)<8){H=H+8|0;I=I+704|0;J=K}else{break}}}}while(0);E=h+1|0;if((E|0)>=4096){break}e=n;i=r+1|0;h=E}eaK(0,0);eaK(0,-1);eaK(1,0);eaK(1,-1);return 0}function d9Y(b){b=b|0;var c=0;switch(b&1048575|0){case 1044483:{c=~a[9625689];break};case 1044485:{c=~a[9625690];break};case 1044484:{c=~a[9625693];break};case 1044481:{c=~a[9625688];break};case 1044487:{c=~a[9625691];break};case 1044482:case 1044486:{c=-1;break};case 1044489:{c=~a[9625694];break};case 1044480:{c=~a[9625692];break};case 1044491:{c=a[2461424]&1;break};case 1044488:{c=~a[9625695];break};default:{c=0}}return c|0}function d9Z(b,d){b=b|0;d=d|0;var e=0,f=0;e=b&1048575;if((e|0)==1044482){a[14115928]=d&1;a[14115929]=(d&255)>>>3&1;return}else if((e|0)==1044487){a[2461424]=1;e=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;b=a[6518008]|0;f=gGU(e,(e|0)<0|0?-1:0,b?66666:0,b?0:0)|0;b=gGS(f,K,166666,0)|0;f=b;if((f|0)<=((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)){return}Sb(f);a[9775456]=d;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12;return}else{return}}function d9_(a,d){a=a|0;d=d|0;var e=0,f=0,g=0;if((a&1044480|0)==1040384){e=a&2047;b[(c[2411430]|0)+e>>1]=d;f=d&65535;g=f>>>2&248;b[(c[2385764]|0)+(e>>>1<<1)>>1]=(f>>>7<<8&63488|f&31|(g>>>5|g)<<3&2016)&65535;return}g=a&1048575;if((g|0)==1044490){b[7057652]=d;return}else if((g|0)==1044492){b[7057644]=d;return}else if((g|0)==1044488){b[7057660]=d;return}else if((g|0)==1044494){b[7057640]=d;return}else{return}}function d9$(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2718220+(b*112|0)>>2];c[a+104>>2]=c[2718224+(b*112|0)>>2];c[a+108>>2]=c[2718228+(b*112|0)>>2];d=0;return d|0}function d90(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=2718120+(b*112|0);e=0;return e|0}function d91(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>42){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1090544+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function d92(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>46){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=2719576+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function d93(){var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;d=i;i=i+840|0;e=d|0;f=d+112|0;g=d+120|0;j=d+232|0;k=d+240|0;l=d+352|0;m=d+360|0;n=d+472|0;o=d+480|0;p=d+592|0;q=d+600|0;r=d+712|0;s=d+720|0;t=d+832|0;c[2426718]=0;c[2418150]=0;c[2411308]=524288;c[2418084]=720896;c[2408970]=720960;c[2406830]=2818112;c[2388318]=2818368;c[2388316]=11206976;c[2406834]=13304128;c[3527032]=524288;c[2406832]=13828416;c[3527030]=1048576;c[2405652]=14876992;c[2406900]=14876992;c[2406898]=14885184;c[2406876]=14893376;c[2406872]=14958912;c[2406870]=15024448;c[2418264]=15026496;c[2411430]=15108416;c[2411350]=15110464;c[2437018]=32767;c[2437016]=32767;c[2437012]=32767;c[2437010]=8191;c[2411658]=15112512;c[2385764]=15112512;u=0;while(1){if((u|0)>=1024){break}v=9638528+(u<<2)|0;if((c[v>>2]|0)==0){w=48932;break}else{u=u+1|0}}do{if((w|0)==48932){u=gGq(15114560)|0;c[v>>2]=u;if((u|0)==0){break}c[2426718]=u;gGz(u|0,0,15114560);c[2418150]=u;c[2411308]=u+524288;c[2418084]=u+720896;c[2408970]=u+720960;c[2406830]=u+2818112;c[2388318]=u+2818368;x=u+11206976|0;c[2406828]=x;c[2388316]=x;c[2406834]=u+13304128;c[3527032]=524288;c[2406832]=u+13828416;x=u+14876992|0;c[3527030]=1048576;c[2405652]=x;c[2406900]=x;c[2406898]=u+14885184;c[2406876]=u+14893376;c[2406872]=u+14958912;c[2406870]=u+15024448;c[2418264]=u+15026496;c[2411430]=u+15108416;c[2411350]=u+15110464;x=u+15112512|0;c[2437018]=32767;c[2437016]=32767;c[2437012]=32767;c[2437010]=8191;c[2411658]=x;c[2385764]=x;c[2414198]=u+15114560;if((c[3542200]|0)==0){y=1;i=d;return y|0}x=s+108|0;c[x>>2]=0;z=s+100|0;c[z>>2]=0;A=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[A&16383](s,0)|0;do{if((c[x>>2]|0)!=0){A=c[z>>2]|0;c[t>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](t,0,0)|0;if((A|0)<1){y=1;i=d;return y|0}if((gzL(u,0,0)|0)==0){break}else{y=1}i=d;return y|0}}while(0);u=(c[2418150]|0)+262144|0;if((c[3542200]|0)==0){y=1;i=d;return y|0}z=q+108|0;c[z>>2]=0;x=q+100|0;c[x>>2]=0;A=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[A&16383](q,1)|0;do{if((c[z>>2]|0)!=0){A=c[x>>2]|0;c[r>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](r,1,0)|0;if((A|0)<1){y=1;i=d;return y|0}if((gzL(u,0,1)|0)==0){break}else{y=1}i=d;return y|0}}while(0);u=c[2418084]|0;do{if((c[3542200]|0)!=0){x=o+108|0;c[x>>2]=0;z=o+100|0;c[z>>2]=0;A=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[A&16383](o,2)|0;if((c[x>>2]|0)==0){break}x=c[z>>2]|0;c[p>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](p,2,0)|0;if((x|0)<1){break}gzL(u,0,2)|0}}while(0);u=(c[2418084]|0)+524288|0;do{if((c[3542200]|0)!=0){x=m+108|0;c[x>>2]=0;z=m+100|0;c[z>>2]=0;A=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[A&16383](m,3)|0;if((c[x>>2]|0)==0){break}x=c[z>>2]|0;c[n>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](n,3,0)|0;if((x|0)<1){break}gzL(u,0,3)|0}}while(0);eaF(65536);u=c[2406830]|0;R6(u,4,2)|0;u=(c[2406830]|0)+1|0;R6(u,6,2)|0;u=(c[2406830]|0)+2097152|0;R6(u,5,2)|0;u=(c[2406830]|0)+2097153|0;R6(u,7,2)|0;u=(c[2406830]|0)+4194304|0;R6(u,8,2)|0;u=(c[2406830]|0)+4194305|0;R6(u,9,2)|0;eaL(c[2388318]|0,c[2406830]|0,40960);u=(c[2411308]|0)+65536|0;if((c[3542200]|0)==0){y=1;i=d;return y|0}x=k+108|0;c[x>>2]=0;z=k+100|0;c[z>>2]=0;A=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[A&16383](k,10)|0;do{if((c[x>>2]|0)!=0){A=c[z>>2]|0;c[l>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](l,10,0)|0;if((A|0)<1){y=1;i=d;return y|0}if((gzL(u,0,10)|0)==0){break}else{y=1}i=d;return y|0}}while(0);u=c[2411308]|0;z=u+65536|0;gGC(u|0,z|0,65536)|0;z=c[2406834]|0;do{if((c[3542200]|0)!=0){u=g+108|0;c[u>>2]=0;x=g+100|0;c[x>>2]=0;A=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[A&16383](g,11)|0;if((c[u>>2]|0)==0){break}u=c[x>>2]|0;c[j>>2]=9534384;x=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[x&16383](j,11,0)|0;if((u|0)<1){break}gzL(z,0,11)|0}}while(0);z=c[2406832]|0;do{if((c[3542200]|0)!=0){u=e+108|0;c[u>>2]=0;x=e+100|0;c[x>>2]=0;A=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[A&16383](e,12)|0;if((c[u>>2]|0)==0){break}u=c[x>>2]|0;c[f>>2]=9534384;x=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[x&16383](f,12,0)|0;if((u|0)<1){break}gzL(z,0,12)|0}}while(0);fxU(0,425984);if((c[2394]|0)==0){C=c[2112932]|0}else{c[2394]=0;z=c[3532596]|0;c[2112932]=z;u=c[3532592]|0;if((u|0)!=0){gGC(9104152,u|0,280)|0}c[2113054]=c[2113060];C=z}z=c[2418150]|0;u=C|0;x=0;while(1){A=z+x|0;c[u>>2]=A;c[u+131072>>2]=A;A=x+1024|0;if(A>>>0>524287){break}else{u=u+4|0;x=A}}x=c[2406900]|0;u=x;c[C+2048>>2]=u;c[C+67584>>2]=u;c[C+133120>>2]=u;u=x+1024|0;c[C+2052>>2]=u;c[C+67588>>2]=u;c[C+133124>>2]=u;u=x+2048|0;c[C+2056>>2]=u;c[C+67592>>2]=u;c[C+133128>>2]=u;u=x+3072|0;c[C+2060>>2]=u;c[C+67596>>2]=u;c[C+133132>>2]=u;u=x+4096|0;c[C+2064>>2]=u;c[C+67600>>2]=u;c[C+133136>>2]=u;u=x+5120|0;c[C+2068>>2]=u;c[C+67604>>2]=u;c[C+133140>>2]=u;u=x+6144|0;c[C+2072>>2]=u;c[C+67608>>2]=u;c[C+133144>>2]=u;u=x+7168|0;c[C+2076>>2]=u;c[C+67612>>2]=u;c[C+133148>>2]=u;u=c[2406898]|0;x=u;c[C+2080>>2]=x;c[C+67616>>2]=x;c[C+133152>>2]=x;x=u+1024|0;c[C+2084>>2]=x;c[C+67620>>2]=x;c[C+133156>>2]=x;x=u+2048|0;c[C+2088>>2]=x;c[C+67624>>2]=x;c[C+133160>>2]=x;x=u+3072|0;c[C+2092>>2]=x;c[C+67628>>2]=x;c[C+133164>>2]=x;x=u+4096|0;c[C+2096>>2]=x;c[C+67632>>2]=x;c[C+133168>>2]=x;x=u+5120|0;c[C+2100>>2]=x;c[C+67636>>2]=x;c[C+133172>>2]=x;x=u+6144|0;c[C+2104>>2]=x;c[C+67640>>2]=x;c[C+133176>>2]=x;x=u+7168|0;c[C+2108>>2]=x;c[C+67644>>2]=x;c[C+133180>>2]=x;x=c[2406876]|0;u=C+2560|0;z=655360;while(1){A=x+(z-655360)|0;c[u>>2]=A;c[u+65536>>2]=A;c[u+131072>>2]=A;A=z+1024|0;if(A>>>0>720895){break}else{u=u+4|0;z=A}}z=c[2406872]|0;u=C+2816|0;x=720896;while(1){A=z+(x-720896)|0;c[u>>2]=A;c[u+65536>>2]=A;c[u+131072>>2]=A;A=x+1024|0;if(A>>>0>786431){break}else{u=u+4|0;x=A}}x=c[2418264]|0;u=C+3072|0;z=786432;while(1){A=x+(z-786432)|0;c[u>>2]=A;c[u+65536>>2]=A;c[u+131072>>2]=A;A=z+1024|0;if(A>>>0>851967){break}else{u=u+4|0;z=A}}z=x+65536|0;c[C+3968>>2]=z;c[C+69504>>2]=z;c[C+135040>>2]=z;u=x+66560|0;c[C+3972>>2]=u;c[C+69508>>2]=u;c[C+135044>>2]=u;A=x+67584|0;c[C+3976>>2]=A;c[C+69512>>2]=A;c[C+135048>>2]=A;B=x+68608|0;c[C+3980>>2]=B;c[C+69516>>2]=B;c[C+135052>>2]=B;D=x+69632|0;c[C+3984>>2]=D;c[C+69520>>2]=D;c[C+135056>>2]=D;E=x+70656|0;c[C+3988>>2]=E;c[C+69524>>2]=E;c[C+135060>>2]=E;F=x+71680|0;c[C+3992>>2]=F;c[C+69528>>2]=F;c[C+135064>>2]=F;G=x+72704|0;c[C+3996>>2]=G;c[C+69532>>2]=G;c[C+135068>>2]=G;H=x+73728|0;c[C+4e3>>2]=H;c[C+69536>>2]=H;c[C+135072>>2]=H;I=x+74752|0;c[C+4004>>2]=I;c[C+69540>>2]=I;c[C+135076>>2]=I;J=x+75776|0;c[C+4008>>2]=J;c[C+69544>>2]=J;c[C+135080>>2]=J;K=x+76800|0;c[C+4012>>2]=K;c[C+69548>>2]=K;c[C+135084>>2]=K;L=x+77824|0;c[C+4016>>2]=L;c[C+69552>>2]=L;c[C+135088>>2]=L;M=x+78848|0;c[C+4020>>2]=M;c[C+69556>>2]=M;c[C+135092>>2]=M;N=x+79872|0;c[C+4024>>2]=N;c[C+69560>>2]=N;c[C+135096>>2]=N;O=x+80896|0;c[C+4028>>2]=O;c[C+69564>>2]=O;c[C+135100>>2]=O;c[C+65408>>2]=z;c[C+130944>>2]=z;c[C+196480>>2]=z;c[C+65412>>2]=u;c[C+130948>>2]=u;c[C+196484>>2]=u;c[C+65416>>2]=A;c[C+130952>>2]=A;c[C+196488>>2]=A;c[C+65420>>2]=B;c[C+130956>>2]=B;c[C+196492>>2]=B;c[C+65424>>2]=D;c[C+130960>>2]=D;c[C+196496>>2]=D;c[C+65428>>2]=E;c[C+130964>>2]=E;c[C+196500>>2]=E;c[C+65432>>2]=F;c[C+130968>>2]=F;c[C+196504>>2]=F;c[C+65436>>2]=G;c[C+130972>>2]=G;c[C+196508>>2]=G;c[C+65440>>2]=H;c[C+130976>>2]=H;c[C+196512>>2]=H;c[C+65444>>2]=I;c[C+130980>>2]=I;c[C+196516>>2]=I;c[C+65448>>2]=J;c[C+130984>>2]=J;c[C+196520>>2]=J;c[C+65452>>2]=K;c[C+130988>>2]=K;c[C+196524>>2]=K;c[C+65456>>2]=L;c[C+130992>>2]=L;c[C+196528>>2]=L;c[C+65460>>2]=M;c[C+130996>>2]=M;c[C+196532>>2]=M;c[C+65464>>2]=N;c[C+131e3>>2]=N;c[C+196536>>2]=N;c[C+65468>>2]=O;c[C+131004>>2]=O;c[C+196540>>2]=O;O=c[2406870]|0;N=O;c[C+4032>>2]=N;c[C+69568>>2]=N;c[C+135104>>2]=N;N=O+1024|0;c[C+4036>>2]=N;c[C+69572>>2]=N;c[C+135108>>2]=N;N=c[2411430]|0;c[C+4064>>2]=N;c[C+135136>>2]=N;O=N+1024|0;c[C+4068>>2]=O;c[C+135140>>2]=O;c[C+196608>>2]=3494;c[C+196728>>2]=870;c[C+196648>>2]=216;O=c[3532592]|0;if((O|0)!=0){gGC(O|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);O=c[2439330]|0;N=(O|0)==0;if(!N){M=O;gGC(9706056,M|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];M=c[3528484]|0;c[2076596]=M;L=c[2417276]|0;c[3541536]=L;c[1836236]=0;K=c[2411308]|0;J=0;I=0;while(1){c[O+76+(I<<2)>>2]=K+(I<<8);H=J+1&65535;if((H&65535)>119){P=0;Q=0;break}else{J=H;I=H&65535}}while(1){I=K+(Q<<8)|0;c[O+76+(Q+512<<2)>>2]=I;c[O+76+(Q+768<<2)>>2]=I;I=P+1&65535;if((I&65535)>119){break}else{P=I;Q=I&65535}}K=c[2411350]|0;c[O+556>>2]=K;I=K+256|0;c[O+560>>2]=I;J=K+512|0;c[O+564>>2]=J;x=K+768|0;c[O+568>>2]=x;H=K+1024|0;c[O+572>>2]=H;G=K+1280|0;c[O+576>>2]=G;F=K+1536|0;c[O+580>>2]=F;E=K+1792|0;c[O+584>>2]=E;c[O+1580>>2]=K;c[O+1584>>2]=I;c[O+1588>>2]=J;c[O+1592>>2]=x;c[O+1596>>2]=H;c[O+1600>>2]=G;c[O+1604>>2]=F;c[O+1608>>2]=E;c[O+2604>>2]=K;c[O+3628>>2]=K;c[O+2608>>2]=I;c[O+3632>>2]=I;c[O+2612>>2]=J;c[O+3636>>2]=J;c[O+2616>>2]=x;c[O+3640>>2]=x;c[O+2620>>2]=H;c[O+3644>>2]=H;c[O+2624>>2]=G;c[O+3648>>2]=G;c[O+2628>>2]=F;c[O+3652>>2]=F;c[O+2632>>2]=E;c[O+3656>>2]=E;c[O+4172>>2]=284;c[O+4176>>2]=1092;if(!N){E=O;gGC(E|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=M;c[2417276]=L;c[1836236]=-1;TW(c[2406832]|0,14108120,c[2406834]|0,14108128,2450,3506,58);c[2438228]=4e6;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=511;h[745406]=1.0;c[2436786]=1;h[745405]=1.0;c[2436784]=2;h[745404]=.25;a[3203280]=1;c[2433572]=-1;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];E=c[3532592]|0;if((E|0)!=0){gGC(9104152,E|0,280)|0}c[2113054]=c[2113060]}c[2113050]=0;c[2276080]=0;RI();E=c[2394]|0;F=c[14130368+(E<<2)>>2]|0;if((F|0)!=0){gGC(F|0,9104152,280)|0}c[8452240+(E<<2)>>2]=c[2113054];c[2394]=-1;E=c[2439330]|0;F=(E|0)==0;if(!F){G=E;gGC(9706056,G|0,76)|0}c[2433530]=c[2438118];G=c[3528484]|0;c[2076596]=G;H=c[2417276]|0;c[3541536]=H;c[1836236]=0;gGz(9706056,0,76);if((c[2433572]|0)!=0){x=c[2411308]|0;J=128;I=128;while(1){c[E+76+(I<<2)>>2]=x+((I<<8)+32768);K=J+1&65535;if((K&65535)>255){R=128;S=128;break}else{J=K;I=K&65535}}while(1){I=x+((S<<8)+32768)|0;c[E+76+(S+512<<2)>>2]=I;c[E+76+(S+768<<2)>>2]=I;I=R+1&65535;if((I&65535)>255){break}else{R=I;S=I&65535}}c[2433572]=0}if(!F){x=E;gGC(x|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=G;c[2417276]=H;c[1836236]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;l6(0);x=14115928;c[x>>2]=0;c[x+4>>2]=0;y=0;i=d;return y|0}}while(0);c[2426718]=0;y=1;i=d;return y|0}function d94(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0;if((a[9624168]|0)!=0){c[2433572]=-1;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}c[2113050]=0;c[2276080]=0;RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}c[2433530]=c[2438118];f=c[3528484]|0;c[2076596]=f;g=c[2417276]|0;c[3541536]=g;c[1836236]=0;gGz(9706056,0,76);if((c[2433572]|0)!=0){i=c[2411308]|0;j=128;k=128;while(1){c[d+76+(k<<2)>>2]=i+((k<<8)+32768);l=j+1&65535;if((l&65535)>255){m=128;n=128;break}else{j=l;k=l&65535}}while(1){k=i+((n<<8)+32768)|0;c[d+76+(n+512<<2)>>2]=k;c[d+76+(n+768<<2)>>2]=k;k=m+1&65535;if((k&65535)>255){break}else{m=k;n=k&65535}}c[2433572]=0}if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=f;c[2417276]=g;c[1836236]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;l6(0);g=14115928;c[g>>2]=0;c[g+4>>2]=0}gGz(9625688,0,6);g=0;f=0;e=0;d=0;n=0;do{f=((a[9633432+g|0]&1)<<g|f&255)&255;e=((a[9631288+g|0]&1)<<g|e&255)&255;d=((a[9629568+g|0]&1)<<g|d&255)&255;n=((a[9628960+g|0]&1)<<g|n&255)&255;g=g+1|0;}while((g|0)<8);a[9625688]=f;a[9625689]=e;a[9625690]=d;a[9625691]=n;n=a[9551813]<<1&2|a[9551812]&1|a[9551814]<<2&4|a[9551815]<<3&8;a[9625692]=a[9551809]<<1&2|a[9551808]&1|a[9551810]<<2&4|a[9551811]<<3&8;a[9625693]=n;n=c[2392]|0;if((n|0)>=0){gGz(8452240,0,((n|0)>0?(n<<2)+4|0:4)|0)}c[2113054]=0;n=c[2385548]|0;if((n|0)>0){gGz(9752472,0,((n|0)>1?n<<2:4)|0)}c[2433530]=0;a[6518008]=1;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];n=c[3532592]|0;if((n|0)!=0){gGC(9104152,n|0,280)|0}c[2113054]=c[2113060]}n=c[2439330]|0;if((n|0)!=0){d=n;gGC(9706056,d|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;c[2113056]=166666;d=RG(166666)|0;c[2113054]=(c[2113054]|0)+d;c[2276108]=-1;c[2113056]=-1;c[8452200+(c[2394]<<2)>>2]=8193;c[2276080]=256;if((c[2276079]|0)>>>0<256){RH(1)}d=a[6518008]|0?66666:0;n=gGU(d,0,2048e6,0)|0;e=c[2438228]|0;f=gGS(n,K,e,(e|0)<0|0?-1:0)|0;e=f;Sb(d);d=c[2443830]|0;if((d|0)<1073676288){c[2443830]=d-e}d=c[2443831]|0;if((d|0)<1073676288){c[2443831]=d-e}d=(c[3528512]|0)-e|0;c[3528512]=(d|0)<0?0:d;d=c[2112964]|0;if((d|0)!=0){gg[c[3542118]&4095](d,a[9688]|0?534:0)}d=c[1836236]|0;e=c[9757320+(d<<2)>>2]|0;if((e|0)!=0){f=e;gGC(f|0,9706056,76)|0}c[9752472+(d<<2)>>2]=c[2433530];c[14113936+(d<<2)>>2]=c[2076596];c[9669104+(d<<2)>>2]=c[3541536];c[1836236]=-1;d=c[2394]|0;f=c[14130368+(d<<2)>>2]|0;if((f|0)!=0){gGC(f|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;if((c[2112968]|0)==0){return 0}d95()|0;return 0}function d95(){var a=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;a=c[2406900]|0;f=c[2408970]|0;g=c[2385764]|0;h=(e[7057660]|0)+8&511;i=b[7057652]&511;j=c[2112968]|0;k=0;l=0;m=0;while(1){n=(l|0)==64;o=(n&1)+k|0;p=n?0:l;n=(p<<3)-h|0;q=(n|0)<-159?n+512|0:n;n=(o<<3)-i|0;r=(n|0)<-271?n+512|0:n;n=q+7|0;L64835:do{if(n>>>0<=358){if((r+7|0)>>>0>246){break}s=b[a+(m<<1)>>1]|0;t=f+(((d[14115928]|0)<<13|s&8191)<<6)|0;u=(s&65535)>>>9&112;s=j+((r*352|0)+q<<1)|0;if(q>>>0<344&r>>>0<232){v=u&65535;w=t;x=s;y=0;while(1){b[x>>1]=b[g+((d[w]|0|v)<<1)>>1]|0;b[x+2>>1]=b[g+((d[w+1|0]|0|v)<<1)>>1]|0;b[x+4>>1]=b[g+((d[w+2|0]|0|v)<<1)>>1]|0;b[x+6>>1]=b[g+((d[w+3|0]|0|v)<<1)>>1]|0;b[x+8>>1]=b[g+((d[w+4|0]|0|v)<<1)>>1]|0;b[x+10>>1]=b[g+((d[w+5|0]|0|v)<<1)>>1]|0;b[x+12>>1]=b[g+((d[w+6|0]|0|v)<<1)>>1]|0;b[x+14>>1]=b[g+((d[w+7|0]|0|v)<<1)>>1]|0;z=y+1|0;if((z|0)<8){w=w+8|0;x=x+704|0;y=z}else{break L64835}}}y=q>>>0<352;x=u&65535;w=(q+1|0)>>>0<352;v=(q+2|0)>>>0<352;z=(q+3|0)>>>0<352;A=(q+4|0)>>>0<352;B=(q+5|0)>>>0<352;C=(q+6|0)>>>0<352;D=n>>>0<352;E=t;F=s;G=0;while(1){do{if((G+r|0)>>>0<240){if(y){b[F>>1]=b[g+((d[E]|0|x)<<1)>>1]|0}if(w){b[F+2>>1]=b[g+((d[E+1|0]|0|x)<<1)>>1]|0}if(v){b[F+4>>1]=b[g+((d[E+2|0]|0|x)<<1)>>1]|0}if(z){b[F+6>>1]=b[g+((d[E+3|0]|0|x)<<1)>>1]|0}if(A){b[F+8>>1]=b[g+((d[E+4|0]|0|x)<<1)>>1]|0}if(B){b[F+10>>1]=b[g+((d[E+5|0]|0|x)<<1)>>1]|0}if(C){b[F+12>>1]=b[g+((d[E+6|0]|0|x)<<1)>>1]|0}if(!D){break}b[F+14>>1]=b[g+((d[E+7|0]|0|x)<<1)>>1]|0}}while(0);H=G+1|0;if((H|0)<8){E=E+8|0;F=F+704|0;G=H}else{break}}}}while(0);r=m+1|0;if((r|0)>=4096){break}k=o;l=p+1|0;m=r}eaJ(c[2406898]|0,f+1048576|0,g+512|0);eaK(0,0);eaK(0,-1);eaK(1,0);eaK(1,-1);return 0}function d96(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2720244+(b*112|0)>>2];c[a+104>>2]=c[2720248+(b*112|0)>>2];c[a+108>>2]=c[2720252+(b*112|0)>>2];d=0;return d|0}function d97(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=2720144+(b*112|0);e=0;return e|0}function d98(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2721700+(b*112|0)>>2];c[a+104>>2]=c[2721704+(b*112|0)>>2];c[a+108>>2]=c[2721708+(b*112|0)>>2];d=0;return d|0}function d99(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=2721600+(b*112|0);e=0;return e|0}function eaa(a){a=a|0;var b=0;if((a|0)==16773122){b=~(d[9625689]|0);return b|0}else if((a|0)==16773124){b=~((d[9625692]|0)<<8|(d[9625691]|0));return b|0}else if((a|0)==16773120){b=~((d[9625690]|0)<<8|(d[9625688]|0));return b|0}else{b=0;return b|0}return 0}function eab(b,d){b=b|0;d=d|0;var e=0,f=0;if((b|0)!=16773127){return}a[2461424]=1;b=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;e=a[6518008]|0;f=gGU(b,(b|0)<0|0?-1:0,e?66666:0,e?0:0)|0;e=gGS(f,K,166666,0)|0;f=e;if((f|0)<=((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)){return}Sb(f);a[9775456]=d;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12;return}function eac(d,e){d=d|0;e=e|0;var f=0,g=0,h=0;if((d&16773120|0)==16769024){f=d&2047;b[(c[2411430]|0)+f>>1]=e;g=e&65535;h=g>>>2&248;b[(c[2385764]|0)+(f>>>1<<1)>>1]=(g>>>7<<8&63488|g&31|(h>>>5|h)<<3&2016)&65535;return}if((d|0)==16773122){b[7057644]=e;return}else if((d|0)==16773120){a[14115928]=e&7;a[14115929]=(e&65535)>>>3&7;return}else{return}}function ead(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>26){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2236164+(b*112|0)>>2];c[a+104>>2]=c[2236168+(b*112|0)>>2];c[a+108>>2]=c[2236172+(b*112|0)>>2];d=0;return d|0}function eae(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<27&(d|0)==0)){e=1;return e|0}c[a>>2]=2236064+(b*112|0);e=0;return e|0}function eaf(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1006248+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eag(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=40){if((a|0)==0){d=0;return d|0}e=a;f=2239088+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}f=b-41|0;if(f>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;a=1386192+(f*12|0)|0;c[b>>2]=c[a>>2];c[b+4>>2]=c[a+4>>2];c[b+8>>2]=c[a+8>>2];d=0;return d|0}function eah(){var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;d=i;i=i+1080|0;e=d|0;f=d+112|0;g=d+120|0;j=d+232|0;k=d+240|0;l=d+352|0;m=d+360|0;n=d+472|0;o=d+480|0;p=d+592|0;q=d+600|0;r=d+712|0;s=d+720|0;t=d+832|0;u=d+840|0;v=d+952|0;w=d+960|0;x=d+1072|0;c[2426718]=0;c[2418150]=0;c[2411308]=262144;c[2418084]=458752;c[2408970]=458816;c[2406830]=5701696;c[2388318]=5701952;c[2388316]=7799104;c[2406832]=11993408;c[2406834]=11993408;c[3527032]=1048576;c[3527030]=1048576;c[2406872]=13041984;c[2406876]=13173056;c[2405652]=13189440;c[2406900]=13189440;c[2406898]=13193536;c[2418264]=13201728;c[2406870]=13218112;c[2385752]=13220160;c[2411430]=13220672;c[2411350]=13222720;c[2437018]=8191;c[2437016]=65535;c[2437012]=8191;c[2437010]=16383;c[2411658]=13224768;c[2385764]=13224768;y=0;while(1){if((y|0)>=1024){break}z=9638528+(y<<2)|0;if((c[z>>2]|0)==0){A=49172;break}else{y=y+1|0}}do{if((A|0)==49172){y=gGq(13226816)|0;c[z>>2]=y;if((y|0)==0){break}c[2426718]=y;gGz(y|0,0,13226816);c[2418150]=y;c[2411308]=y+262144;c[2418084]=y+458752;c[2408970]=y+458816;c[2406830]=y+5701696;B=y+11993408|0;c[2388318]=y+5701952;C=y+7799104|0;c[2406828]=C;c[2388316]=C;c[2406832]=B;c[2406834]=B;c[3527032]=1048576;c[3527030]=1048576;c[2406872]=y+13041984;c[2406876]=y+13173056;B=y+13189440|0;c[2405652]=B;c[2406900]=B;c[2406898]=y+13193536;c[2418264]=y+13201728;c[2406870]=y+13218112;c[2385752]=y+13220160;c[2411430]=y+13220672;c[2411350]=y+13222720;B=y+13224768|0;c[2437018]=8191;c[2437016]=65535;c[2437012]=8191;c[2437010]=16383;c[2411658]=B;c[2385764]=B;c[2414198]=y+13226816;if((R6(y+1|0,0,2)|0)!=0){D=1;i=d;return D|0}if((R6(c[2418150]|0,1,2)|0)!=0){D=1;i=d;return D|0}if((R6((c[2418150]|0)+131073|0,2,2)|0)!=0){D=1;i=d;return D|0}if((R6((c[2418150]|0)+131072|0,3,2)|0)!=0){D=1;i=d;return D|0}y=c[2418084]|0;do{if((c[3542200]|0)!=0){B=w+108|0;c[B>>2]=0;C=w+100|0;c[C>>2]=0;E=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[E&16383](w,4)|0;if((c[B>>2]|0)==0){break}B=c[C>>2]|0;c[x>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](x,4,0)|0;if((B|0)<1){break}gzL(y,0,4)|0}}while(0);y=(c[2418084]|0)+524288|0;do{if((c[3542200]|0)!=0){B=u+108|0;c[B>>2]=0;C=u+100|0;c[C>>2]=0;E=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[E&16383](u,5)|0;if((c[B>>2]|0)==0){break}B=c[C>>2]|0;c[v>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](v,5,0)|0;if((B|0)<1){break}gzL(y,0,5)|0}}while(0);y=(c[2418084]|0)+1048576|0;do{if((c[3542200]|0)!=0){B=s+108|0;c[B>>2]=0;C=s+100|0;c[C>>2]=0;E=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[E&16383](s,6)|0;if((c[B>>2]|0)==0){break}B=c[C>>2]|0;c[t>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](t,6,0)|0;if((B|0)<1){break}gzL(y,0,6)|0}}while(0);y=(c[2418084]|0)+1572864|0;do{if((c[3542200]|0)!=0){B=q+108|0;c[B>>2]=0;C=q+100|0;c[C>>2]=0;E=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[E&16383](q,7)|0;if((c[B>>2]|0)==0){break}B=c[C>>2]|0;c[r>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](r,7,0)|0;if((B|0)<1){break}gzL(y,0,7)|0}}while(0);y=(c[2418084]|0)+2097152|0;do{if((c[3542200]|0)!=0){B=o+108|0;c[B>>2]=0;C=o+100|0;c[C>>2]=0;E=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[E&16383](o,8)|0;if((c[B>>2]|0)==0){break}B=c[C>>2]|0;c[p>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](p,8,0)|0;if((B|0)<1){break}gzL(y,0,8)|0}}while(0);eaF(81920);y=c[2406830]|0;R6(y,9,2)|0;y=(c[2406830]|0)+1|0;R6(y,10,2)|0;y=(c[2406830]|0)+1048576|0;R6(y,11,2)|0;y=(c[2406830]|0)+1048577|0;R6(y,13,2)|0;y=(c[2406830]|0)+2097152|0;R6(y,12,2)|0;y=(c[2406830]|0)+2097153|0;R6(y,14,2)|0;eaL(c[2388318]|0,c[2406830]|0,24576);y=(c[2406872]|0)+1|0;R6(y,15,2)|0;y=c[2406872]|0;R6(y,16,2)|0;y=c[2411308]|0;if((c[3542200]|0)==0){D=1;i=d;return D|0}B=m+108|0;c[B>>2]=0;C=m+100|0;c[C>>2]=0;E=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[E&16383](m,17)|0;do{if((c[B>>2]|0)!=0){E=c[C>>2]|0;c[n>>2]=9534384;F=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[F&16383](n,17,0)|0;if((E|0)<1){D=1;i=d;return D|0}if((gzL(y,0,17)|0)==0){break}else{D=1}i=d;return D|0}}while(0);y=(c[2411308]|0)+32768|0;if((c[3542200]|0)==0){D=1;i=d;return D|0}C=k+108|0;c[C>>2]=0;B=k+100|0;c[B>>2]=0;E=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[E&16383](k,18)|0;do{if((c[C>>2]|0)!=0){E=c[B>>2]|0;c[l>>2]=9534384;F=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[F&16383](l,18,0)|0;if((E|0)<1){D=1;i=d;return D|0}if((gzL(y,0,18)|0)==0){break}else{D=1}i=d;return D|0}}while(0);y=c[2406832]|0;do{if((c[3542200]|0)!=0){B=g+108|0;c[B>>2]=0;C=g+100|0;c[C>>2]=0;E=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[E&16383](g,19)|0;if((c[B>>2]|0)==0){break}B=c[C>>2]|0;c[j>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](j,19,0)|0;if((B|0)<1){break}gzL(y,0,19)|0}}while(0);y=(c[2406832]|0)+524288|0;do{if((c[3542200]|0)!=0){B=e+108|0;c[B>>2]=0;C=e+100|0;c[C>>2]=0;E=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[E&16383](e,20)|0;if((c[B>>2]|0)==0){break}B=c[C>>2]|0;c[f>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](f,20,0)|0;if((B|0)<1){break}gzL(y,0,20)|0}}while(0);fxU(0,425984);if((c[2394]|0)==0){G=c[2112932]|0}else{c[2394]=0;y=c[3532596]|0;c[2112932]=y;B=c[3532592]|0;if((B|0)!=0){gGC(9104152,B|0,280)|0}c[2113054]=c[2113060];G=y}y=c[2418150]|0;B=G|0;C=0;while(1){E=y+C|0;c[B>>2]=E;c[B+131072>>2]=E;E=C+1024|0;if(E>>>0>327679){break}else{B=B+4|0;C=E}}C=c[2406900]|0;B=C;c[G+2048>>2]=B;c[G+67584>>2]=B;c[G+133120>>2]=B;B=C+1024|0;c[G+2052>>2]=B;c[G+67588>>2]=B;c[G+133124>>2]=B;B=C+2048|0;c[G+2056>>2]=B;c[G+67592>>2]=B;c[G+133128>>2]=B;B=C+3072|0;c[G+2060>>2]=B;c[G+67596>>2]=B;c[G+133132>>2]=B;B=c[2406898]|0;C=B;c[G+2080>>2]=C;c[G+67616>>2]=C;c[G+133152>>2]=C;C=B+1024|0;c[G+2084>>2]=C;c[G+67620>>2]=C;c[G+133156>>2]=C;C=B+2048|0;c[G+2088>>2]=C;c[G+67624>>2]=C;c[G+133160>>2]=C;C=B+3072|0;c[G+2092>>2]=C;c[G+67628>>2]=C;c[G+133164>>2]=C;C=B+4096|0;c[G+2096>>2]=C;c[G+67632>>2]=C;c[G+133168>>2]=C;C=B+5120|0;c[G+2100>>2]=C;c[G+67636>>2]=C;c[G+133172>>2]=C;C=B+6144|0;c[G+2104>>2]=C;c[G+67640>>2]=C;c[G+133176>>2]=C;C=B+7168|0;c[G+2108>>2]=C;c[G+67644>>2]=C;c[G+133180>>2]=C;C=c[2418264]|0;c[G+65408>>2]=C;c[G+130944>>2]=C;c[G+196480>>2]=C;B=C+1024|0;c[G+65412>>2]=B;c[G+130948>>2]=B;c[G+196484>>2]=B;B=C+2048|0;c[G+65416>>2]=B;c[G+130952>>2]=B;c[G+196488>>2]=B;B=C+3072|0;c[G+65420>>2]=B;c[G+130956>>2]=B;c[G+196492>>2]=B;B=C+4096|0;c[G+65424>>2]=B;c[G+130960>>2]=B;c[G+196496>>2]=B;B=C+5120|0;c[G+65428>>2]=B;c[G+130964>>2]=B;c[G+196500>>2]=B;B=C+6144|0;c[G+65432>>2]=B;c[G+130968>>2]=B;c[G+196504>>2]=B;B=C+7168|0;c[G+65436>>2]=B;c[G+130972>>2]=B;c[G+196508>>2]=B;B=C+8192|0;c[G+65440>>2]=B;c[G+130976>>2]=B;c[G+196512>>2]=B;B=C+9216|0;c[G+65444>>2]=B;c[G+130980>>2]=B;c[G+196516>>2]=B;B=C+10240|0;c[G+65448>>2]=B;c[G+130984>>2]=B;c[G+196520>>2]=B;B=C+11264|0;c[G+65452>>2]=B;c[G+130988>>2]=B;c[G+196524>>2]=B;B=C+12288|0;c[G+65456>>2]=B;c[G+130992>>2]=B;c[G+196528>>2]=B;B=C+13312|0;c[G+65460>>2]=B;c[G+130996>>2]=B;c[G+196532>>2]=B;B=C+14336|0;c[G+65464>>2]=B;c[G+131e3>>2]=B;c[G+196536>>2]=B;B=C+15360|0;c[G+65468>>2]=B;c[G+131004>>2]=B;c[G+196540>>2]=B;B=c[2406870]|0;C=B;c[G+65472>>2]=C;c[G+131008>>2]=C;c[G+196544>>2]=C;C=B+1024|0;c[G+65476>>2]=C;c[G+131012>>2]=C;c[G+196548>>2]=C;C=c[2385752]|0;c[G+65488>>2]=C;c[G+131024>>2]=C;c[G+196560>>2]=C;C=c[2411430]|0;c[G+65504>>2]=C;c[G+196576>>2]=C;B=C+1024|0;c[G+65508>>2]=B;c[G+196580>>2]=B;c[G+196688>>2]=730;c[G+196728>>2]=1182;c[G+196648>>2]=1626;B=c[3532592]|0;if((B|0)!=0){gGC(B|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);B=c[2439330]|0;C=(B|0)==0;if(!C){y=B;gGC(9706056,y|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];y=c[3528484]|0;c[2076596]=y;E=c[2417276]|0;c[3541536]=E;c[1836236]=0;F=c[2411308]|0;H=0;I=0;while(1){c[B+76+(I<<2)>>2]=F+(I<<8);J=H+1&65535;if((J&65535)>119){K=0;L=0;break}else{H=J;I=J&65535}}while(1){I=F+(L<<8)|0;c[B+76+(L+512<<2)>>2]=I;c[B+76+(L+768<<2)>>2]=I;I=K+1&65535;if((I&65535)>119){break}else{K=I;L=I&65535}}F=c[2411350]|0;c[B+556>>2]=F;I=F+256|0;c[B+560>>2]=I;H=F+512|0;c[B+564>>2]=H;J=F+768|0;c[B+568>>2]=J;M=F+1024|0;c[B+572>>2]=M;N=F+1280|0;c[B+576>>2]=N;O=F+1536|0;c[B+580>>2]=O;P=F+1792|0;c[B+584>>2]=P;c[B+1580>>2]=F;c[B+1584>>2]=I;c[B+1588>>2]=H;c[B+1592>>2]=J;c[B+1596>>2]=M;c[B+1600>>2]=N;c[B+1604>>2]=O;c[B+1608>>2]=P;c[B+2604>>2]=F;c[B+3628>>2]=F;c[B+2608>>2]=I;c[B+3632>>2]=I;c[B+2612>>2]=H;c[B+3636>>2]=H;c[B+2616>>2]=J;c[B+3640>>2]=J;c[B+2620>>2]=M;c[B+3644>>2]=M;c[B+2624>>2]=N;c[B+3648>>2]=N;c[B+2628>>2]=O;c[B+3652>>2]=O;c[B+2632>>2]=P;c[B+3656>>2]=P;c[B+4172>>2]=284;c[B+4176>>2]=1092;if(!C){P=B;gGC(P|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=y;c[2417276]=E;c[1836236]=-1;TW(c[2406832]|0,14108120,c[2406834]|0,14108128,2450,3506,58);c[2438228]=4e6;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=511;h[745406]=1.0;c[2436786]=1;h[745405]=1.0;c[2436784]=2;h[745404]=.25;a[3203280]=1;b[7057644]=0;P=c[2406876]|0;O=0;do{b[P+((O&65535)<<1)>>1]=O;O=O+1&65535;}while((O&65535)<8192);c[2433572]=-1;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];O=c[3532592]|0;if((O|0)!=0){gGC(9104152,O|0,280)|0}c[2113054]=c[2113060]}c[2113050]=0;c[2276080]=0;RI();O=c[2394]|0;P=c[14130368+(O<<2)>>2]|0;if((P|0)!=0){gGC(P|0,9104152,280)|0}c[8452240+(O<<2)>>2]=c[2113054];c[2394]=-1;O=c[2439330]|0;P=(O|0)==0;if(!P){E=O;gGC(9706056,E|0,76)|0}c[2433530]=c[2438118];E=c[3528484]|0;c[2076596]=E;y=c[2417276]|0;c[3541536]=y;c[1836236]=0;gGz(9706056,0,76);if((c[2433572]|0)!=0){B=c[2411308]|0;C=128;N=128;while(1){c[O+76+(N<<2)>>2]=B+((N<<8)+32768);M=C+1&65535;if((M&65535)>255){Q=128;R=128;break}else{C=M;N=M&65535}}while(1){N=B+((R<<8)+32768)|0;c[O+76+(R+512<<2)>>2]=N;c[O+76+(R+768<<2)>>2]=N;N=Q+1&65535;if((N&65535)>255){break}else{Q=N;R=N&65535}}c[2433572]=0}if(!P){B=O;gGC(B|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=E;c[2417276]=y;c[1836236]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;l6(0);B=14115928;c[B>>2]=0;c[B+4>>2]=0;D=0;i=d;return D|0}}while(0);c[2426718]=0;D=1;i=d;return D|0}function eai(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0;if((a[9624168]|0)!=0){c[2433572]=-1;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}c[2113050]=0;c[2276080]=0;RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}c[2433530]=c[2438118];f=c[3528484]|0;c[2076596]=f;g=c[2417276]|0;c[3541536]=g;c[1836236]=0;gGz(9706056,0,76);if((c[2433572]|0)!=0){i=c[2411308]|0;j=128;k=128;while(1){c[d+76+(k<<2)>>2]=i+((k<<8)+32768);l=j+1&65535;if((l&65535)>255){m=128;n=128;break}else{j=l;k=l&65535}}while(1){k=i+((n<<8)+32768)|0;c[d+76+(n+512<<2)>>2]=k;c[d+76+(n+768<<2)>>2]=k;k=m+1&65535;if((k&65535)>255){break}else{m=k;n=k&65535}}c[2433572]=0}if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=f;c[2417276]=g;c[1836236]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;l6(0);g=14115928;c[g>>2]=0;c[g+4>>2]=0}a[9625688]=0;a[9625689]=0;a[9625690]=0;g=0;f=0;e=0;d=0;do{f=((a[9633432+g|0]&1)<<g|f&255)&255;e=((a[9631288+g|0]&1)<<g|e&255)&255;d=((a[9551808+g|0]&1)<<g|d&255)&255;g=g+1|0;}while((g|0)<8);a[9625688]=f;a[9625689]=e;a[9625690]=d;d=c[2392]|0;if((d|0)>=0){gGz(8452240,0,((d|0)>0?(d<<2)+4|0:4)|0)}c[2113054]=0;d=c[2385548]|0;if((d|0)>0){gGz(9752472,0,((d|0)>1?d<<2:4)|0)}c[2433530]=0;a[6518008]=1;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}d=c[2439330]|0;if((d|0)!=0){e=d;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;c[2113056]=166666;e=RG(166666)|0;c[2113054]=(c[2113054]|0)+e;c[2276108]=-1;c[2113056]=-1;c[8452200+(c[2394]<<2)>>2]=8193;c[2276080]=256;if((c[2276079]|0)>>>0<256){RH(1)}e=a[6518008]|0?66666:0;d=gGU(e,0,2048e6,0)|0;f=c[2438228]|0;g=gGS(d,K,f,(f|0)<0|0?-1:0)|0;f=g;Sb(e);e=c[2443830]|0;if((e|0)<1073676288){c[2443830]=e-f}e=c[2443831]|0;if((e|0)<1073676288){c[2443831]=e-f}e=(c[3528512]|0)-f|0;c[3528512]=(e|0)<0?0:e;e=c[2112964]|0;if((e|0)!=0){gg[c[3542118]&4095](e,a[9688]|0?534:0)}e=c[1836236]|0;f=c[9757320+(e<<2)>>2]|0;if((f|0)!=0){g=f;gGC(g|0,9706056,76)|0}c[9752472+(e<<2)>>2]=c[2433530];c[14113936+(e<<2)>>2]=c[2076596];c[9669104+(e<<2)>>2]=c[3541536];c[1836236]=-1;e=c[2394]|0;g=c[14130368+(e<<2)>>2]|0;if((g|0)!=0){gGC(g|0,9104152,280)|0}c[8452240+(e<<2)>>2]=c[2113054];c[2394]=-1;if((c[2112968]|0)==0){return 0}eaj()|0;return 0}function eaj(){var a=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;a=c[2406900]|0;e=c[2408970]|0;f=c[2385764]|0;g=c[2385752]|0;h=c[2112968]|0;i=0;j=0;k=0;while(1){l=(j|0)==64;m=(l&1)+i|0;n=l?0:j;l=m<<3;o=(n<<3)-(b[g+(l<<1)>>1]&511)|0;p=(o|0)<-159?o+512|0:o;o=p+7|0;L65163:do{if(o>>>0<=358){if((l|7)>>>0>246){break}q=b[a+(k<<1)>>1]|0;r=e+(((d[14115928]|0)<<12|q&4095)<<6)|0;s=(q&65535)>>>8&240;q=h+(p+(m*2816|0)<<1)|0;if(p>>>0<344&l>>>0<232){t=s&65535;u=r;v=q;w=0;while(1){b[v>>1]=b[f+((d[u]|0|t)<<1)>>1]|0;b[v+2>>1]=b[f+((d[u+1|0]|0|t)<<1)>>1]|0;b[v+4>>1]=b[f+((d[u+2|0]|0|t)<<1)>>1]|0;b[v+6>>1]=b[f+((d[u+3|0]|0|t)<<1)>>1]|0;b[v+8>>1]=b[f+((d[u+4|0]|0|t)<<1)>>1]|0;b[v+10>>1]=b[f+((d[u+5|0]|0|t)<<1)>>1]|0;b[v+12>>1]=b[f+((d[u+6|0]|0|t)<<1)>>1]|0;b[v+14>>1]=b[f+((d[u+7|0]|0|t)<<1)>>1]|0;x=w+1|0;if((x|0)<8){u=u+8|0;v=v+704|0;w=x}else{break L65163}}}w=p>>>0<352;v=s&65535;u=(p+1|0)>>>0<352;t=(p+2|0)>>>0<352;x=(p+3|0)>>>0<352;y=(p+4|0)>>>0<352;z=(p+5|0)>>>0<352;A=(p+6|0)>>>0<352;B=o>>>0<352;C=r;D=q;E=0;while(1){do{if((E+l|0)>>>0<240){if(w){b[D>>1]=b[f+((d[C]|0|v)<<1)>>1]|0}if(u){b[D+2>>1]=b[f+((d[C+1|0]|0|v)<<1)>>1]|0}if(t){b[D+4>>1]=b[f+((d[C+2|0]|0|v)<<1)>>1]|0}if(x){b[D+6>>1]=b[f+((d[C+3|0]|0|v)<<1)>>1]|0}if(y){b[D+8>>1]=b[f+((d[C+4|0]|0|v)<<1)>>1]|0}if(z){b[D+10>>1]=b[f+((d[C+5|0]|0|v)<<1)>>1]|0}if(A){b[D+12>>1]=b[f+((d[C+6|0]|0|v)<<1)>>1]|0}if(!B){break}b[D+14>>1]=b[f+((d[C+7|0]|0|v)<<1)>>1]|0}}while(0);F=E+1|0;if((F|0)<8){C=C+8|0;D=D+704|0;E=F}else{break}}}}while(0);l=k+1|0;if((l|0)>=4096){break}i=m;j=n+1|0;k=l}eaJ(c[2406898]|0,e+2097152|0,f+512|0);eaK(1,-1);eaK(1,0);eaK(0,0);eaK(0,-1);return 0}function eak(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>26){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2233140+(b*112|0)>>2];c[a+104>>2]=c[2233144+(b*112|0)>>2];c[a+108>>2]=c[2233148+(b*112|0)>>2];d=0;return d|0}function eal(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<27&(d|0)==0)){e=1;return e|0}c[a>>2]=2233040+(b*112|0);e=0;return e|0}function eam(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=40){if((a|0)==0){d=0;return d|0}e=a;f=2239088+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}f=b-41|0;if(f>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;a=1385976+(f*12|0)|0;c[b>>2]=c[a>>2];c[b+4>>2]=c[a+4>>2];c[b+8>>2]=c[a+8>>2];d=0;return d|0}function ean(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>26){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2239684+(b*112|0)>>2];c[a+104>>2]=c[2239688+(b*112|0)>>2];c[a+108>>2]=c[2239692+(b*112|0)>>2];d=0;return d|0}function eao(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<27&(d|0)==0)){e=1;return e|0}c[a>>2]=2239584+(b*112|0);e=0;return e|0}function eap(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=40){if((a|0)==0){d=0;return d|0}e=a;f=2239088+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}f=b-41|0;if(f>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;a=1386408+(f*12|0)|0;c[b>>2]=c[a>>2];c[b+4>>2]=c[a+4>>2];c[b+8>>2]=c[a+8>>2];d=0;return d|0}function eaq(b){b=b|0;var d=0,e=0,f=0;d=i;switch(b|0){case 1040385:{e=~a[9625688];break};case 1040384:{e=~a[9625690];break};case 1040387:{e=~a[9625689];break};case 1040386:{e=-1;break};case 1040389:{e=~a[9625691];break};case 1040393:{e=~a[9625693];break};case 1040391:{e=a[2461424]&1;break};case 1040388:{e=~a[9625692];break};default:{bw(415384,(f=i,i=i+8|0,c[f>>2]=b,f)|0)|0;i=f;e=0}}i=d;return e|0}function ear(a){a=a|0;var b=0,d=0;b=i;bw(403800,(d=i,i=i+8|0,c[d>>2]=a,d)|0)|0;i=d;i=b;return 0}function eas(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;if((b&1044480|0)==1036288){a[(c[2411430]|0)+(b&2047^1)|0]=d;i=e;return}if((b|0)==1040398){a[2461424]=1;f=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;g=a[6518008]|0;h=gGU(f,(f|0)<0|0?-1:0,g?66666:0,g?0:0)|0;g=gGS(h,K,166666,0)|0;h=g;if((h|0)<=((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)){i=e;return}Sb(h);a[9775456]=d;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12;i=e;return}else if((b|0)==1040385|(b|0)==1041409|(b|0)==1041411){i=e;return}else{bw(392920,(h=i,i=i+16|0,c[h>>2]=d&255,c[h+8>>2]=b,h)|0)|0;i=h;i=e;return}}function eat(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;if((d&1044480|0)==1036288){g=d&2046;b[(c[2411430]|0)+g>>1]=e;h=e&65535;j=h>>>2&248;b[(c[2385764]|0)+(g>>>1<<1)>>1]=(h>>>7<<8&63488|h&31|(j>>>5|j)<<3&2016)&65535;i=f;return}switch(d|0){case 1040386:{b[7057652]=e;i=f;return};case 1040396:{i=f;return};case 1040390:{b[7057640]=e;i=f;return};case 1040394:{a[14115932]=e&15;a[14115933]=(e&65535)>>>4&15;a[14115934]=(e&65535)>>>8&15;a[14115935]=(e&65535)>>>12&255;i=f;return};case 1040392:{a[14115928]=e&15;a[14115929]=(e&65535)>>>4&15;a[14115930]=(e&65535)>>>8&15;a[14115931]=(e&65535)>>>12&255;i=f;return};case 1040388:{b[7057644]=e;i=f;return};default:{bw(171448,(j=i,i=i+16|0,c[j>>2]=e&65535,c[j+8>>2]=d,j)|0)|0;i=j;i=f;return}}}function eau(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3182452+(b*112|0)>>2];c[a+104>>2]=c[3182456+(b*112|0)>>2];c[a+108>>2]=c[3182460+(b*112|0)>>2];d=0;return d|0}function eav(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=3182352+(b*112|0);e=0;return e|0}function eaw(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=47){if((a|0)==0){d=0;return d|0}e=a;f=4854656+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}f=b-48|0;if(f>>>0>3){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;a=1626496+(f*12|0)|0;c[b>>2]=c[a>>2];c[b+4>>2]=c[a+4>>2];c[b+8>>2]=c[a+8>>2];d=0;return d|0}function eax(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;e=i;i=i+600|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;c[2426718]=0;c[2418150]=0;c[2411308]=524288;c[2418084]=720896;c[2408970]=720960;c[2406830]=2818112;c[2388318]=2818368;c[2388316]=4915520;c[2406834]=5964096;c[3527032]=262144;c[2406832]=6226240;c[3527030]=1048576;c[2405652]=7274816;c[2418264]=7274816;c[2406900]=7356736;c[2406898]=7364928;c[2406876]=7373120;c[2406872]=7389504;c[2406870]=7405888;c[2411430]=7407936;c[2385752]=7409984;c[2437018]=8191;c[2437016]=8191;c[2437012]=8191;c[2437010]=4095;c[2411350]=7414080;c[2411658]=7416128;c[2385764]=7416128;r=0;while(1){if((r|0)>=1024){break}s=9638528+(r<<2)|0;if((c[s>>2]|0)==0){t=49453;break}else{r=r+1|0}}do{if((t|0)==49453){r=gGq(7418176)|0;c[s>>2]=r;if((r|0)==0){break}c[2426718]=r;gGz(r|0,0,7418176);c[2418150]=r;c[2411308]=r+524288;c[2418084]=r+720896;c[2408970]=r+720960;c[2406830]=r+2818112;c[2388318]=r+2818368;u=r+4915520|0;c[2406828]=u;c[2388316]=u;c[2406834]=r+5964096;c[3527032]=262144;c[2406832]=r+6226240;u=r+7274816|0;c[3527030]=1048576;c[2405652]=u;c[2418264]=u;c[2406900]=r+7356736;c[2406898]=r+7364928;c[2406876]=r+7373120;c[2406872]=r+7389504;c[2406870]=r+7405888;c[2411430]=r+7407936;c[2385752]=r+7409984;c[2437018]=8191;c[2437016]=8191;c[2437012]=8191;c[2437010]=4095;c[2411350]=r+7414080;u=r+7416128|0;c[2411658]=u;c[2385764]=u;c[2414198]=r+7418176;if((R6(r+1|0,0,2)|0)!=0){v=1;i=e;return v|0}if((R6(c[2418150]|0,1,2)|0)!=0){v=1;i=e;return v|0}r=c[2418084]|0;do{if((c[3542200]|0)!=0){u=p+108|0;c[u>>2]=0;w=p+100|0;c[w>>2]=0;x=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[x&16383](p,2)|0;if((c[u>>2]|0)==0){break}u=c[w>>2]|0;c[q>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](q,2,0)|0;if((u|0)<1){break}gzL(r,0,2)|0}}while(0);r=(c[2418084]|0)+524288|0;do{if((c[3542200]|0)!=0){u=n+108|0;c[u>>2]=0;w=n+100|0;c[w>>2]=0;x=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[x&16383](n,3)|0;if((c[u>>2]|0)==0){break}u=c[w>>2]|0;c[o>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](o,3,0)|0;if((u|0)<1){break}gzL(r,0,3)|0}}while(0);eaF(32768);r=c[2406830]|0;R6(r,4,2)|0;r=(c[2406830]|0)+1|0;R6(r,5,2)|0;r=(c[2406830]|0)+1048576|0;R6(r,6,2)|0;r=(c[2406830]|0)+1048577|0;R6(r,7,2)|0;r=c[2388318]|0;u=c[2406830]|0;w=12287;while(1){x=w<<7;y=w<<8;z=15;while(1){A=z<<3;B=u+((A|5)+x)|0;C=(z<<4)+y|0;a[r+(C|15)|0]=(d[B]|0)>>>4;a[r+(C|14)|0]=a[B]&15;B=u+((A|7)+x)|0;a[r+(C|13)|0]=(d[B]|0)>>>4;a[r+(C|12)|0]=a[B]&15;B=u+((A|4)+x)|0;a[r+(C|11)|0]=(d[B]|0)>>>4;a[r+(C|10)|0]=a[B]&15;B=u+((A|6)+x)|0;a[r+(C|9)|0]=(d[B]|0)>>>4;a[r+(C|8)|0]=a[B]&15;B=u+((A|1)+x)|0;a[r+(C|7)|0]=(d[B]|0)>>>4;a[r+(C|6)|0]=a[B]&15;B=u+((A|3)+x)|0;a[r+(C|5)|0]=(d[B]|0)>>>4;a[r+(C|4)|0]=a[B]&15;B=u+(A+x)|0;a[r+(C|3)|0]=(d[B]|0)>>>4;a[r+(C|2)|0]=a[B]&15;B=u+((A|2)+x)|0;a[r+(C|1)|0]=(d[B]|0)>>>4;a[r+C|0]=a[B]&15;if((z|0)>0){z=z-1|0}else{break}}if((w|0)>0){w=w-1|0}else{break}}w=(c[2411308]|0)+65536|0;if((c[3542200]|0)==0){v=1;i=e;return v|0}r=l+108|0;c[r>>2]=0;u=l+100|0;c[u>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,8)|0;do{if((c[r>>2]|0)!=0){z=c[u>>2]|0;c[m>>2]=9534384;x=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[x&16383](m,8,0)|0;if((z|0)<1){v=1;i=e;return v|0}if((gzL(w,0,8)|0)==0){break}else{v=1}i=e;return v|0}}while(0);w=c[2411308]|0;u=w+65536|0;gGC(w|0,u|0,65536)|0;u=c[2406834]|0;do{if((c[3542200]|0)!=0){w=j+108|0;c[w>>2]=0;r=j+100|0;c[r>>2]=0;z=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[z&16383](j,9)|0;if((c[w>>2]|0)==0){break}w=c[r>>2]|0;c[k>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](k,9,0)|0;if((w|0)<1){break}gzL(u,0,9)|0}}while(0);u=c[2406832]|0;do{if((c[3542200]|0)!=0){w=f+108|0;c[w>>2]=0;r=f+100|0;c[r>>2]=0;z=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[z&16383](f,10)|0;if((c[w>>2]|0)==0){break}w=c[r>>2]|0;c[g>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](g,10,0)|0;if((w|0)<1){break}gzL(u,0,10)|0}}while(0);fxU(0,425984);if((c[2394]|0)==0){D=c[2112932]|0}else{c[2394]=0;u=c[3532596]|0;c[2112932]=u;w=c[3532592]|0;if((w|0)!=0){gGC(9104152,w|0,280)|0}c[2113054]=c[2113060];D=u}u=c[2418150]|0;w=D|0;r=0;while(1){z=u+r|0;c[w>>2]=z;c[w+131072>>2]=z;z=r+1024|0;if(z>>>0>524287){break}else{w=w+4|0;r=z}}r=c[2418264]|0;w=D+3072|0;u=786432;while(1){z=r+(u-786432)|0;c[w>>2]=z;c[w+65536>>2]=z;c[w+131072>>2]=z;z=u+1024|0;if(z>>>0>851967){break}else{w=w+4|0;u=z}}u=c[2406900]|0;w=u;c[D+3328>>2]=w;c[D+68864>>2]=w;c[D+134400>>2]=w;w=u+1024|0;c[D+3332>>2]=w;c[D+68868>>2]=w;c[D+134404>>2]=w;w=u+2048|0;c[D+3336>>2]=w;c[D+68872>>2]=w;c[D+134408>>2]=w;w=u+3072|0;c[D+3340>>2]=w;c[D+68876>>2]=w;c[D+134412>>2]=w;w=u+4096|0;c[D+3344>>2]=w;c[D+68880>>2]=w;c[D+134416>>2]=w;w=u+5120|0;c[D+3348>>2]=w;c[D+68884>>2]=w;c[D+134420>>2]=w;w=u+6144|0;c[D+3352>>2]=w;c[D+68888>>2]=w;c[D+134424>>2]=w;w=u+7168|0;c[D+3356>>2]=w;c[D+68892>>2]=w;c[D+134428>>2]=w;w=c[2406898]|0;u=w;c[D+3360>>2]=u;c[D+68896>>2]=u;c[D+134432>>2]=u;u=w+1024|0;c[D+3364>>2]=u;c[D+68900>>2]=u;c[D+134436>>2]=u;u=w+2048|0;c[D+3368>>2]=u;c[D+68904>>2]=u;c[D+134440>>2]=u;u=w+3072|0;c[D+3372>>2]=u;c[D+68908>>2]=u;c[D+134444>>2]=u;u=w+4096|0;c[D+3376>>2]=u;c[D+68912>>2]=u;c[D+134448>>2]=u;u=w+5120|0;c[D+3380>>2]=u;c[D+68916>>2]=u;c[D+134452>>2]=u;u=w+6144|0;c[D+3384>>2]=u;c[D+68920>>2]=u;c[D+134456>>2]=u;u=w+7168|0;c[D+3388>>2]=u;c[D+68924>>2]=u;c[D+134460>>2]=u;u=c[2406876]|0;w=u;c[D+3584>>2]=w;c[D+69120>>2]=w;c[D+134656>>2]=w;w=u+1024|0;c[D+3588>>2]=w;c[D+69124>>2]=w;c[D+134660>>2]=w;w=u+2048|0;c[D+3592>>2]=w;c[D+69128>>2]=w;c[D+134664>>2]=w;w=u+3072|0;c[D+3596>>2]=w;c[D+69132>>2]=w;c[D+134668>>2]=w;w=u+4096|0;c[D+3600>>2]=w;c[D+69136>>2]=w;c[D+134672>>2]=w;w=u+5120|0;c[D+3604>>2]=w;c[D+69140>>2]=w;c[D+134676>>2]=w;w=u+6144|0;c[D+3608>>2]=w;c[D+69144>>2]=w;c[D+134680>>2]=w;w=u+7168|0;c[D+3612>>2]=w;c[D+69148>>2]=w;c[D+134684>>2]=w;w=u+8192|0;c[D+3616>>2]=w;c[D+69152>>2]=w;c[D+134688>>2]=w;w=u+9216|0;c[D+3620>>2]=w;c[D+69156>>2]=w;c[D+134692>>2]=w;w=u+10240|0;c[D+3624>>2]=w;c[D+69160>>2]=w;c[D+134696>>2]=w;w=u+11264|0;c[D+3628>>2]=w;c[D+69164>>2]=w;c[D+134700>>2]=w;w=u+12288|0;c[D+3632>>2]=w;c[D+69168>>2]=w;c[D+134704>>2]=w;w=u+13312|0;c[D+3636>>2]=w;c[D+69172>>2]=w;c[D+134708>>2]=w;w=u+14336|0;c[D+3640>>2]=w;c[D+69176>>2]=w;c[D+134712>>2]=w;w=u+15360|0;c[D+3644>>2]=w;c[D+69180>>2]=w;c[D+134716>>2]=w;w=c[2406872]|0;u=w;c[D+3648>>2]=u;c[D+69184>>2]=u;c[D+134720>>2]=u;u=w+1024|0;c[D+3652>>2]=u;c[D+69188>>2]=u;c[D+134724>>2]=u;u=w+2048|0;c[D+3656>>2]=u;c[D+69192>>2]=u;c[D+134728>>2]=u;u=w+3072|0;c[D+3660>>2]=u;c[D+69196>>2]=u;c[D+134732>>2]=u;u=w+4096|0;c[D+3664>>2]=u;c[D+69200>>2]=u;c[D+134736>>2]=u;u=w+5120|0;c[D+3668>>2]=u;c[D+69204>>2]=u;c[D+134740>>2]=u;u=w+6144|0;c[D+3672>>2]=u;c[D+69208>>2]=u;c[D+134744>>2]=u;u=w+7168|0;c[D+3676>>2]=u;c[D+69212>>2]=u;c[D+134748>>2]=u;u=w+8192|0;c[D+3680>>2]=u;c[D+69216>>2]=u;c[D+134752>>2]=u;u=w+9216|0;c[D+3684>>2]=u;c[D+69220>>2]=u;c[D+134756>>2]=u;u=w+10240|0;c[D+3688>>2]=u;c[D+69224>>2]=u;c[D+134760>>2]=u;u=w+11264|0;c[D+3692>>2]=u;c[D+69228>>2]=u;c[D+134764>>2]=u;u=w+12288|0;c[D+3696>>2]=u;c[D+69232>>2]=u;c[D+134768>>2]=u;u=w+13312|0;c[D+3700>>2]=u;c[D+69236>>2]=u;c[D+134772>>2]=u;u=w+14336|0;c[D+3704>>2]=u;c[D+69240>>2]=u;c[D+134776>>2]=u;u=w+15360|0;c[D+3708>>2]=u;c[D+69244>>2]=u;c[D+134780>>2]=u;u=r+65536|0;c[D+3968>>2]=u;c[D+69504>>2]=u;c[D+135040>>2]=u;u=r+66560|0;c[D+3972>>2]=u;c[D+69508>>2]=u;c[D+135044>>2]=u;u=r+67584|0;c[D+3976>>2]=u;c[D+69512>>2]=u;c[D+135048>>2]=u;u=r+68608|0;c[D+3980>>2]=u;c[D+69516>>2]=u;c[D+135052>>2]=u;u=r+69632|0;c[D+3984>>2]=u;c[D+69520>>2]=u;c[D+135056>>2]=u;u=r+70656|0;c[D+3988>>2]=u;c[D+69524>>2]=u;c[D+135060>>2]=u;u=r+71680|0;c[D+3992>>2]=u;c[D+69528>>2]=u;c[D+135064>>2]=u;u=r+72704|0;c[D+3996>>2]=u;c[D+69532>>2]=u;c[D+135068>>2]=u;u=r+73728|0;c[D+4e3>>2]=u;c[D+69536>>2]=u;c[D+135072>>2]=u;u=r+74752|0;c[D+4004>>2]=u;c[D+69540>>2]=u;c[D+135076>>2]=u;u=r+75776|0;c[D+4008>>2]=u;c[D+69544>>2]=u;c[D+135080>>2]=u;u=r+76800|0;c[D+4012>>2]=u;c[D+69548>>2]=u;c[D+135084>>2]=u;u=r+77824|0;c[D+4016>>2]=u;c[D+69552>>2]=u;c[D+135088>>2]=u;u=r+78848|0;c[D+4020>>2]=u;c[D+69556>>2]=u;c[D+135092>>2]=u;u=r+79872|0;c[D+4024>>2]=u;c[D+69560>>2]=u;c[D+135096>>2]=u;u=r+80896|0;c[D+4028>>2]=u;c[D+69564>>2]=u;c[D+135100>>2]=u;u=c[2406870]|0;w=u;c[D+4032>>2]=w;c[D+69568>>2]=w;c[D+135104>>2]=w;w=u+1024|0;c[D+4036>>2]=w;c[D+69572>>2]=w;c[D+135108>>2]=w;w=c[2411430]|0;u=c[2112932]|0;c[u+4048>>2]=w;c[u+135120>>2]=w;z=w+1024|0;c[u+4052>>2]=z;c[u+135124>>2]=z;z=c[2385752]|0;w=z;c[u+4080>>2]=w;c[u+69616>>2]=w;c[u+135152>>2]=w;w=z+1024|0;c[u+4084>>2]=w;c[u+69620>>2]=w;c[u+135156>>2]=w;w=z+2048|0;c[u+4088>>2]=w;c[u+69624>>2]=w;c[u+135160>>2]=w;w=z+3072|0;c[u+4092>>2]=w;c[u+69628>>2]=w;c[u+135164>>2]=w;c[u+196688>>2]=816;c[u+196608>>2]=2382;c[u+196728>>2]=3418;c[u+196648>>2]=1354;u=c[2394]|0;w=c[14130368+(u<<2)>>2]|0;if((w|0)!=0){gGC(w|0,9104152,280)|0}c[8452240+(u<<2)>>2]=c[2113054];c[2394]=-1;fwR(0);u=c[2439330]|0;w=(u|0)==0;if(!w){z=u;gGC(9706056,z|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];z=c[3528484]|0;c[2076596]=z;x=c[2417276]|0;c[3541536]=x;c[1836236]=0;y=c[2411308]|0;B=0;C=0;while(1){c[u+76+(C<<2)>>2]=y+(C<<8);A=B+1&65535;if((A&65535)>119){E=0;F=0;break}else{B=A;C=A&65535}}while(1){C=y+(F<<8)|0;c[u+76+(F+512<<2)>>2]=C;c[u+76+(F+768<<2)>>2]=C;C=E+1&65535;if((C&65535)>119){break}else{E=C;F=C&65535}}y=c[2411350]|0;c[u+556>>2]=y;C=y+256|0;c[u+560>>2]=C;B=y+512|0;c[u+564>>2]=B;r=y+768|0;c[u+568>>2]=r;A=y+1024|0;c[u+572>>2]=A;G=y+1280|0;c[u+576>>2]=G;H=y+1536|0;c[u+580>>2]=H;I=y+1792|0;c[u+584>>2]=I;c[u+1580>>2]=y;c[u+1584>>2]=C;c[u+1588>>2]=B;c[u+1592>>2]=r;c[u+1596>>2]=A;c[u+1600>>2]=G;c[u+1604>>2]=H;c[u+1608>>2]=I;c[u+2604>>2]=y;c[u+3628>>2]=y;c[u+2608>>2]=C;c[u+3632>>2]=C;c[u+2612>>2]=B;c[u+3636>>2]=B;c[u+2616>>2]=r;c[u+3640>>2]=r;c[u+2620>>2]=A;c[u+3644>>2]=A;c[u+2624>>2]=G;c[u+3648>>2]=G;c[u+2628>>2]=H;c[u+3652>>2]=H;c[u+2632>>2]=I;c[u+3656>>2]=I;c[u+4172>>2]=334;c[u+4176>>2]=1636;if(!w){I=u;gGC(I|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=z;c[2417276]=x;c[1836236]=-1;TW(c[2406832]|0,14108120,c[2406834]|0,14108128,2450,3506,58);c[2438228]=4e6;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=511;h[745406]=1.0;c[2436786]=1;h[745405]=1.0;c[2436784]=2;h[745404]=.25;a[3203280]=1;c[2433572]=-1;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];I=c[3532592]|0;if((I|0)!=0){gGC(9104152,I|0,280)|0}c[2113054]=c[2113060]}c[2113050]=0;c[2276080]=0;RI();I=c[2394]|0;H=c[14130368+(I<<2)>>2]|0;if((H|0)!=0){gGC(H|0,9104152,280)|0}c[8452240+(I<<2)>>2]=c[2113054];c[2394]=-1;I=c[2439330]|0;H=(I|0)==0;if(!H){G=I;gGC(9706056,G|0,76)|0}c[2433530]=c[2438118];G=c[3528484]|0;c[2076596]=G;A=c[2417276]|0;c[3541536]=A;c[1836236]=0;gGz(9706056,0,76);if((c[2433572]|0)!=0){r=c[2411308]|0;B=128;C=128;while(1){c[I+76+(C<<2)>>2]=r+((C<<8)+32768);y=B+1&65535;if((y&65535)>255){J=128;K=128;break}else{B=y;C=y&65535}}while(1){C=r+((K<<8)+32768)|0;c[I+76+(K+512<<2)>>2]=C;c[I+76+(K+768<<2)>>2]=C;C=J+1&65535;if((C&65535)>255){break}else{J=C;K=C&65535}}c[2433572]=0}if(!H){r=I;gGC(r|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=G;c[2417276]=A;c[1836236]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;l6(0);r=14115928;c[r>>2]=0;c[r+4>>2]=0;v=0;i=e;return v|0}}while(0);c[2426718]=0;v=1;i=e;return v|0}function eay(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0;if((a[9624168]|0)!=0){c[2433572]=-1;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}c[2113050]=0;c[2276080]=0;RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}c[2433530]=c[2438118];f=c[3528484]|0;c[2076596]=f;g=c[2417276]|0;c[3541536]=g;c[1836236]=0;gGz(9706056,0,76);if((c[2433572]|0)!=0){i=c[2411308]|0;j=128;k=128;while(1){c[d+76+(k<<2)>>2]=i+((k<<8)+32768);l=j+1&65535;if((l&65535)>255){m=128;n=128;break}else{j=l;k=l&65535}}while(1){k=i+((n<<8)+32768)|0;c[d+76+(n+512<<2)>>2]=k;c[d+76+(n+768<<2)>>2]=k;k=m+1&65535;if((k&65535)>255){break}else{m=k;n=k&65535}}c[2433572]=0}if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=f;c[2417276]=g;c[1836236]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;l6(0);g=14115928;c[g>>2]=0;c[g+4>>2]=0}a[9625688]=0;a[9625689]=0;a[9625690]=0;g=0;f=0;e=0;d=0;do{f=((a[9633432+g|0]&1)<<g|f&255)&255;e=((a[9631288+g|0]&1)<<g|e&255)&255;d=((a[9551808+g|0]&1)<<g|d&255)&255;g=g+1|0;}while((g|0)<8);a[9625688]=f;a[9625689]=e;a[9625690]=d;d=c[2392]|0;if((d|0)>=0){gGz(8452240,0,((d|0)>0?(d<<2)+4|0:4)|0)}c[2113054]=0;d=c[2385548]|0;if((d|0)>0){gGz(9752472,0,((d|0)>1?d<<2:4)|0)}c[2433530]=0;a[6518008]=1;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}d=c[2439330]|0;if((d|0)!=0){e=d;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;c[2113056]=166666;e=RG(166666)|0;c[2113054]=(c[2113054]|0)+e;c[2276108]=-1;c[2113056]=-1;c[8452200+(c[2394]<<2)>>2]=8193;c[2276080]=256;if((c[2276079]|0)>>>0<256){RH(1)}e=a[6518008]|0?66666:0;d=gGU(e,0,2048e6,0)|0;f=c[2438228]|0;g=gGS(d,K,f,(f|0)<0|0?-1:0)|0;f=g;Sb(e);e=c[2443830]|0;if((e|0)<1073676288){c[2443830]=e-f}e=c[2443831]|0;if((e|0)<1073676288){c[2443831]=e-f}e=(c[3528512]|0)-f|0;c[3528512]=(e|0)<0?0:e;e=c[2112964]|0;if((e|0)!=0){gg[c[3542118]&4095](e,a[9688]|0?534:0)}e=c[1836236]|0;f=c[9757320+(e<<2)>>2]|0;if((f|0)!=0){g=f;gGC(g|0,9706056,76)|0}c[9752472+(e<<2)>>2]=c[2433530];c[14113936+(e<<2)>>2]=c[2076596];c[9669104+(e<<2)>>2]=c[3541536];c[1836236]=-1;e=c[2394]|0;g=c[14130368+(e<<2)>>2]|0;if((g|0)!=0){gGC(g|0,9104152,280)|0}c[8452240+(e<<2)>>2]=c[2113054];c[2394]=-1;if((c[2112968]|0)==0){return 0}eaz()|0;return 0}function eaz(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;f=c[2406900]|0;g=c[2408970]|0;h=c[2385764]|0;i=(c[2385752]|0)+14|0;j=(e[7057652]|0)+2&511;k=c[2112968]|0;l=0;m=0;n=0;while(1){o=(m|0)==64;p=(o&1)+l|0;q=o?0:m;o=(q<<3)-(b[i>>1]&511)|0;r=(o|0)<-191?o+512|0:o;o=(p<<3)-j|0;s=(o|0)<-287?o+512|0:o;o=r+7|0;L65505:do{if(o>>>0<=326){if((s+7|0)>>>0>230){break}t=b[f+(n<<1)>>1]|0;u=t&65535;v=g+(((d[14115928+(u>>>11&3)|0]|0)<<11|u&2047)<<6)|0;u=(t&65535)>>>9&112;t=k+((s*320|0)+r<<1)|0;if(r>>>0<312&s>>>0<216){w=u&65535;x=v;y=t;z=0;while(1){b[y>>1]=b[h+((d[x]|0|w)<<1)>>1]|0;b[y+2>>1]=b[h+((d[x+1|0]|0|w)<<1)>>1]|0;b[y+4>>1]=b[h+((d[x+2|0]|0|w)<<1)>>1]|0;b[y+6>>1]=b[h+((d[x+3|0]|0|w)<<1)>>1]|0;b[y+8>>1]=b[h+((d[x+4|0]|0|w)<<1)>>1]|0;b[y+10>>1]=b[h+((d[x+5|0]|0|w)<<1)>>1]|0;b[y+12>>1]=b[h+((d[x+6|0]|0|w)<<1)>>1]|0;b[y+14>>1]=b[h+((d[x+7|0]|0|w)<<1)>>1]|0;A=z+1|0;if((A|0)<8){x=x+8|0;y=y+640|0;z=A}else{break L65505}}}z=r>>>0<320;y=u&65535;x=(r+1|0)>>>0<320;w=(r+2|0)>>>0<320;A=(r+3|0)>>>0<320;B=(r+4|0)>>>0<320;C=(r+5|0)>>>0<320;D=(r+6|0)>>>0<320;E=o>>>0<320;F=v;G=t;H=0;while(1){do{if((H+s|0)>>>0<224){if(z){b[G>>1]=b[h+((d[F]|0|y)<<1)>>1]|0}if(x){b[G+2>>1]=b[h+((d[F+1|0]|0|y)<<1)>>1]|0}if(w){b[G+4>>1]=b[h+((d[F+2|0]|0|y)<<1)>>1]|0}if(A){b[G+6>>1]=b[h+((d[F+3|0]|0|y)<<1)>>1]|0}if(B){b[G+8>>1]=b[h+((d[F+4|0]|0|y)<<1)>>1]|0}if(C){b[G+10>>1]=b[h+((d[F+5|0]|0|y)<<1)>>1]|0}if(D){b[G+12>>1]=b[h+((d[F+6|0]|0|y)<<1)>>1]|0}if(!E){break}b[G+14>>1]=b[h+((d[F+7|0]|0|y)<<1)>>1]|0}}while(0);I=H+1|0;if((I|0)<8){F=F+8|0;G=G+640|0;H=I}else{break}}}}while(0);s=n+1|0;if((s|0)>=4096){break}l=p;m=q+1|0;n=s}n=c[2406898]|0;m=(e[7057644]|0)+5&511;l=(e[7057640]|0)+2&511;f=0;j=0;i=0;while(1){s=(j|0)==64;o=(s&1)+f|0;r=s?0:j;s=(r<<3)-m|0;H=(s|0)<-191?s+512|0:s;s=(o<<3)-l|0;G=(s|0)<-287?s+512|0:s;s=H+7|0;L65545:do{if(s>>>0<=326){if((G+7|0)>>>0>230){break}F=b[n+(i<<1)>>1]|0;y=F&65535;E=g+((((d[14115928+(y>>>11&3|4)|0]|0)<<11|y&2047)<<6)+1048576)|0;y=(F&65535)>>>9&112;F=k+((G*320|0)+H<<1)|0;if(H>>>0<312&G>>>0<216){D=y&65535;C=E;B=F;A=0;while(1){w=a[C]|0;if(w<<24>>24!=15){b[B>>1]=b[h+((D|w&255|256)<<1)>>1]|0}w=a[C+1|0]|0;if(w<<24>>24!=15){b[B+2>>1]=b[h+((D|w&255|256)<<1)>>1]|0}w=a[C+2|0]|0;if(w<<24>>24!=15){b[B+4>>1]=b[h+((D|w&255|256)<<1)>>1]|0}w=a[C+3|0]|0;if(w<<24>>24!=15){b[B+6>>1]=b[h+((D|w&255|256)<<1)>>1]|0}w=a[C+4|0]|0;if(w<<24>>24!=15){b[B+8>>1]=b[h+((D|w&255|256)<<1)>>1]|0}w=a[C+5|0]|0;if(w<<24>>24!=15){b[B+10>>1]=b[h+((D|w&255|256)<<1)>>1]|0}w=a[C+6|0]|0;if(w<<24>>24!=15){b[B+12>>1]=b[h+((D|w&255|256)<<1)>>1]|0}w=a[C+7|0]|0;if(w<<24>>24!=15){b[B+14>>1]=b[h+((D|w&255|256)<<1)>>1]|0}w=A+1|0;if((w|0)<8){C=C+8|0;B=B+640|0;A=w}else{break L65545}}}A=(H|0)>-1;B=(H|0)<352;C=y&65535;D=(H+1|0)>>>0>351;w=(H+2|0)>>>0>351;x=(H+3|0)>>>0>351;z=(H+4|0)>>>0>351;t=(H+5|0)>>>0>351;v=(H+6|0)>>>0>351;u=s>>>0>351;I=E;J=F;K=0;while(1){do{if((K+G|0)>>>0<224){L=a[I]|0;if(A&L<<24>>24!=15&B){b[J>>1]=b[h+((C|L&255|256)<<1)>>1]|0}L=a[I+1|0]|0;if(!(L<<24>>24==15|D)){b[J+2>>1]=b[h+((C|L&255|256)<<1)>>1]|0}L=a[I+2|0]|0;if(!(L<<24>>24==15|w)){b[J+4>>1]=b[h+((C|L&255|256)<<1)>>1]|0}L=a[I+3|0]|0;if(!(L<<24>>24==15|x)){b[J+6>>1]=b[h+((C|L&255|256)<<1)>>1]|0}L=a[I+4|0]|0;if(!(L<<24>>24==15|z)){b[J+8>>1]=b[h+((C|L&255|256)<<1)>>1]|0}L=a[I+5|0]|0;if(!(L<<24>>24==15|t)){b[J+10>>1]=b[h+((C|L&255|256)<<1)>>1]|0}L=a[I+6|0]|0;if(!(L<<24>>24==15|v)){b[J+12>>1]=b[h+((C|L&255|256)<<1)>>1]|0}L=a[I+7|0]|0;if(L<<24>>24==15|u){break}b[J+14>>1]=b[h+((C|L&255|256)<<1)>>1]|0}}while(0);L=K+1|0;if((L|0)<8){I=I+8|0;J=J+640|0;K=L}else{break}}}}while(0);G=i+1|0;if((G|0)>=4096){break}f=o;j=r+1|0;i=G}eaE(0,0);eaE(0,-1);eaE(1,0);eaE(1,-1);return 0}function eaA(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3181220+(b*112|0)>>2];c[a+104>>2]=c[3181224+(b*112|0)>>2];c[a+108>>2]=c[3181228+(b*112|0)>>2];d=0;return d|0}function eaB(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=3181120+(b*112|0);e=0;return e|0}function eaC(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4387980+(b*112|0)>>2];c[a+104>>2]=c[4387984+(b*112|0)>>2];c[a+108>>2]=c[4387988+(b*112|0)>>2];d=0;return d|0}function eaD(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=4387880+(b*112|0);e=0;return e|0}function eaE(d,f){d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0;g=d<<9;h=c[2406870]|0;i=((e[h+((g|510)<<1)>>1]|0)<<2)+g|0;j=g|504;if((i|0)>(j|0)){return}g=(f|0)==0|0;k=(d|0)==0;d=c[2437018]|0;l=c[2406876]|0;m=c[2437012]|0;n=c[2388318]|0;o=c[2385764]|0;p=o+1024|0;q=c[2112968]|0;r=c[2437016]|0;s=c[2406872]|0;t=c[2437010]|0;u=c[2388316]|0;v=o+1536|0;o=i;do{i=e[h+(o+2<<1)>>1]|0;do{if((i&128|0)!=0){w=i>>>4;if(((w&1^1)&f|0)!=0){break}if((w&g|0)!=0){break}w=e[h+(o+1<<1)>>1]|0;x=i>>>8&7;y=e[h+(o<<1)>>1]|0;z=i>>>12&7;A=i<<4&240;B=32-(w>>>12)|0;C=32-(y>>>12)|0;D=(i&32768|0)==0;E=y+16|0;y=(i&2048|0)==0;F=w+16|0;w=(x|0)==4;G=(x|0)==5;H=(x|0)==6|0;I=x+1+((x|0)==2)|0;J=0;K=e[h+(o+3<<1)>>1]|0;while(1){L=E+((ag(D?J:z-J|0,C)|0)/2|0)&511;M=L-17|0;N=M*320|0;O=M>>>0>207;P=(L-2|0)>>>0>238;L=0;Q=K;while(1){R=F+((ag(y?L:x-L|0,B)|0)/2|0)&511;S=R-24|0;if(k){T=p;U=n+((m&(e[l+((d&Q)<<1)>>1]|0))<<8)|0}else{T=v;U=u+((t&(e[s+((r&Q)<<1)>>1]|0))<<8)|0}V=S+N|0;W=q+(V<<1)|0;do{if(S>>>0>303|O){X=R-9|0;if(X>>>0>334|P){break}if(D){Y=(S|0)>-1;Z=(S|0)<320;if(y){_=(R-23|0)>>>0>319;$=(R-22|0)>>>0>319;aa=(R-21|0)>>>0>319;ab=(R-20|0)>>>0>319;ac=(R-19|0)>>>0>319;ad=(R-18|0)>>>0>319;ae=(R-17|0)>>>0>319;af=(R-16|0)>>>0>319;ah=(R-15|0)>>>0>319;ai=(R-14|0)>>>0>319;aj=(R-13|0)>>>0>319;ak=(R-12|0)>>>0>319;al=(R-11|0)>>>0>319;am=(R-10|0)>>>0>319;an=X>>>0>319;ao=W;ap=U;aq=0;while(1){do{if((aq+M|0)>>>0<224){ar=a[ap]|0;if(ar<<24>>24!=15&Y&Z){b[ao>>1]=b[T+((ar&255|A)<<1)>>1]|0}ar=a[ap+1|0]|0;if(!(ar<<24>>24==15|_)){b[ao+2>>1]=b[T+((ar&255|A)<<1)>>1]|0}ar=a[ap+2|0]|0;if(!(ar<<24>>24==15|$)){b[ao+4>>1]=b[T+((ar&255|A)<<1)>>1]|0}ar=a[ap+3|0]|0;if(!(ar<<24>>24==15|aa)){b[ao+6>>1]=b[T+((ar&255|A)<<1)>>1]|0}ar=a[ap+4|0]|0;if(!(ar<<24>>24==15|ab)){b[ao+8>>1]=b[T+((ar&255|A)<<1)>>1]|0}ar=a[ap+5|0]|0;if(!(ar<<24>>24==15|ac)){b[ao+10>>1]=b[T+((ar&255|A)<<1)>>1]|0}ar=a[ap+6|0]|0;if(!(ar<<24>>24==15|ad)){b[ao+12>>1]=b[T+((ar&255|A)<<1)>>1]|0}ar=a[ap+7|0]|0;if(!(ar<<24>>24==15|ae)){b[ao+14>>1]=b[T+((ar&255|A)<<1)>>1]|0}ar=a[ap+8|0]|0;if(!(ar<<24>>24==15|af)){b[ao+16>>1]=b[T+((ar&255|A)<<1)>>1]|0}ar=a[ap+9|0]|0;if(!(ar<<24>>24==15|ah)){b[ao+18>>1]=b[T+((ar&255|A)<<1)>>1]|0}ar=a[ap+10|0]|0;if(!(ar<<24>>24==15|ai)){b[ao+20>>1]=b[T+((ar&255|A)<<1)>>1]|0}ar=a[ap+11|0]|0;if(!(ar<<24>>24==15|aj)){b[ao+22>>1]=b[T+((ar&255|A)<<1)>>1]|0}ar=a[ap+12|0]|0;if(!(ar<<24>>24==15|ak)){b[ao+24>>1]=b[T+((ar&255|A)<<1)>>1]|0}ar=a[ap+13|0]|0;if(!(ar<<24>>24==15|al)){b[ao+26>>1]=b[T+((ar&255|A)<<1)>>1]|0}ar=a[ap+14|0]|0;if(!(ar<<24>>24==15|am)){b[ao+28>>1]=b[T+((ar&255|A)<<1)>>1]|0}ar=a[ap+15|0]|0;if(ar<<24>>24==15|an){break}b[ao+30>>1]=b[T+((ar&255|A)<<1)>>1]|0}}while(0);ar=aq+1|0;if((ar|0)<16){ao=ao+640|0;ap=ap+16|0;aq=ar}else{break}}}else{aq=X>>>0>319;ap=(R-10|0)>>>0>319;ao=(R-11|0)>>>0>319;an=(R-12|0)>>>0>319;am=(R-13|0)>>>0>319;al=(R-14|0)>>>0>319;ak=(R-15|0)>>>0>319;aj=(R-16|0)>>>0>319;ai=(R-17|0)>>>0>319;ah=(R-18|0)>>>0>319;af=(R-19|0)>>>0>319;ae=(R-20|0)>>>0>319;ad=(R-21|0)>>>0>319;ac=(R-22|0)>>>0>319;ab=(R-23|0)>>>0>319;aa=W;$=U;_=0;while(1){do{if((_+M|0)>>>0<224){ar=a[$]|0;if(!(ar<<24>>24==15|aq)){b[aa+30>>1]=b[T+((ar&255|A)<<1)>>1]|0}ar=a[$+1|0]|0;if(!(ar<<24>>24==15|ap)){b[aa+28>>1]=b[T+((ar&255|A)<<1)>>1]|0}ar=a[$+2|0]|0;if(!(ar<<24>>24==15|ao)){b[aa+26>>1]=b[T+((ar&255|A)<<1)>>1]|0}ar=a[$+3|0]|0;if(!(ar<<24>>24==15|an)){b[aa+24>>1]=b[T+((ar&255|A)<<1)>>1]|0}ar=a[$+4|0]|0;if(!(ar<<24>>24==15|am)){b[aa+22>>1]=b[T+((ar&255|A)<<1)>>1]|0}ar=a[$+5|0]|0;if(!(ar<<24>>24==15|al)){b[aa+20>>1]=b[T+((ar&255|A)<<1)>>1]|0}ar=a[$+6|0]|0;if(!(ar<<24>>24==15|ak)){b[aa+18>>1]=b[T+((ar&255|A)<<1)>>1]|0}ar=a[$+7|0]|0;if(!(ar<<24>>24==15|aj)){b[aa+16>>1]=b[T+((ar&255|A)<<1)>>1]|0}ar=a[$+8|0]|0;if(!(ar<<24>>24==15|ai)){b[aa+14>>1]=b[T+((ar&255|A)<<1)>>1]|0}ar=a[$+9|0]|0;if(!(ar<<24>>24==15|ah)){b[aa+12>>1]=b[T+((ar&255|A)<<1)>>1]|0}ar=a[$+10|0]|0;if(!(ar<<24>>24==15|af)){b[aa+10>>1]=b[T+((ar&255|A)<<1)>>1]|0}ar=a[$+11|0]|0;if(!(ar<<24>>24==15|ae)){b[aa+8>>1]=b[T+((ar&255|A)<<1)>>1]|0}ar=a[$+12|0]|0;if(!(ar<<24>>24==15|ad)){b[aa+6>>1]=b[T+((ar&255|A)<<1)>>1]|0}ar=a[$+13|0]|0;if(!(ar<<24>>24==15|ac)){b[aa+4>>1]=b[T+((ar&255|A)<<1)>>1]|0}ar=a[$+14|0]|0;if(!(ar<<24>>24==15|ab)){b[aa+2>>1]=b[T+((ar&255|A)<<1)>>1]|0}ar=a[$+15|0]|0;if(!(ar<<24>>24!=15&Y&Z)){break}b[aa>>1]=b[T+((ar&255|A)<<1)>>1]|0}}while(0);ar=_+1|0;if((ar|0)<16){aa=aa+640|0;$=$+16|0;_=ar}else{break}}}}else{_=q+(V+4800<<1)|0;$=(S|0)>-1;aa=(S|0)<320;if(y){Z=(R-23|0)>>>0>319;Y=(R-22|0)>>>0>319;ab=(R-21|0)>>>0>319;ac=(R-20|0)>>>0>319;ad=(R-19|0)>>>0>319;ae=(R-18|0)>>>0>319;af=(R-17|0)>>>0>319;ah=(R-16|0)>>>0>319;ai=(R-15|0)>>>0>319;aj=(R-14|0)>>>0>319;ak=(R-13|0)>>>0>319;al=(R-12|0)>>>0>319;am=(R-11|0)>>>0>319;an=(R-10|0)>>>0>319;ao=X>>>0>319;ap=_;aq=U;ar=15;while(1){do{if((ar+M|0)>>>0<224){as=a[aq]|0;if(as<<24>>24!=15&$&aa){b[ap>>1]=b[T+((as&255|A)<<1)>>1]|0}as=a[aq+1|0]|0;if(!(as<<24>>24==15|Z)){b[ap+2>>1]=b[T+((as&255|A)<<1)>>1]|0}as=a[aq+2|0]|0;if(!(as<<24>>24==15|Y)){b[ap+4>>1]=b[T+((as&255|A)<<1)>>1]|0}as=a[aq+3|0]|0;if(!(as<<24>>24==15|ab)){b[ap+6>>1]=b[T+((as&255|A)<<1)>>1]|0}as=a[aq+4|0]|0;if(!(as<<24>>24==15|ac)){b[ap+8>>1]=b[T+((as&255|A)<<1)>>1]|0}as=a[aq+5|0]|0;if(!(as<<24>>24==15|ad)){b[ap+10>>1]=b[T+((as&255|A)<<1)>>1]|0}as=a[aq+6|0]|0;if(!(as<<24>>24==15|ae)){b[ap+12>>1]=b[T+((as&255|A)<<1)>>1]|0}as=a[aq+7|0]|0;if(!(as<<24>>24==15|af)){b[ap+14>>1]=b[T+((as&255|A)<<1)>>1]|0}as=a[aq+8|0]|0;if(!(as<<24>>24==15|ah)){b[ap+16>>1]=b[T+((as&255|A)<<1)>>1]|0}as=a[aq+9|0]|0;if(!(as<<24>>24==15|ai)){b[ap+18>>1]=b[T+((as&255|A)<<1)>>1]|0}as=a[aq+10|0]|0;if(!(as<<24>>24==15|aj)){b[ap+20>>1]=b[T+((as&255|A)<<1)>>1]|0}as=a[aq+11|0]|0;if(!(as<<24>>24==15|ak)){b[ap+22>>1]=b[T+((as&255|A)<<1)>>1]|0}as=a[aq+12|0]|0;if(!(as<<24>>24==15|al)){b[ap+24>>1]=b[T+((as&255|A)<<1)>>1]|0}as=a[aq+13|0]|0;if(!(as<<24>>24==15|am)){b[ap+26>>1]=b[T+((as&255|A)<<1)>>1]|0}as=a[aq+14|0]|0;if(!(as<<24>>24==15|an)){b[ap+28>>1]=b[T+((as&255|A)<<1)>>1]|0}as=a[aq+15|0]|0;if(as<<24>>24==15|ao){break}b[ap+30>>1]=b[T+((as&255|A)<<1)>>1]|0}}while(0);if((ar|0)>0){ap=ap-640|0;aq=aq+16|0;ar=ar-1|0}else{break}}}else{ar=X>>>0>319;aq=(R-10|0)>>>0>319;ap=(R-11|0)>>>0>319;ao=(R-12|0)>>>0>319;an=(R-13|0)>>>0>319;am=(R-14|0)>>>0>319;al=(R-15|0)>>>0>319;ak=(R-16|0)>>>0>319;aj=(R-17|0)>>>0>319;ai=(R-18|0)>>>0>319;ah=(R-19|0)>>>0>319;af=(R-20|0)>>>0>319;ae=(R-21|0)>>>0>319;ad=(R-22|0)>>>0>319;ac=(R-23|0)>>>0>319;ab=_;Y=U;Z=15;while(1){do{if((Z+M|0)>>>0<224){as=a[Y]|0;if(!(as<<24>>24==15|ar)){b[ab+30>>1]=b[T+((as&255|A)<<1)>>1]|0}as=a[Y+1|0]|0;if(!(as<<24>>24==15|aq)){b[ab+28>>1]=b[T+((as&255|A)<<1)>>1]|0}as=a[Y+2|0]|0;if(!(as<<24>>24==15|ap)){b[ab+26>>1]=b[T+((as&255|A)<<1)>>1]|0}as=a[Y+3|0]|0;if(!(as<<24>>24==15|ao)){b[ab+24>>1]=b[T+((as&255|A)<<1)>>1]|0}as=a[Y+4|0]|0;if(!(as<<24>>24==15|an)){b[ab+22>>1]=b[T+((as&255|A)<<1)>>1]|0}as=a[Y+5|0]|0;if(!(as<<24>>24==15|am)){b[ab+20>>1]=b[T+((as&255|A)<<1)>>1]|0}as=a[Y+6|0]|0;if(!(as<<24>>24==15|al)){b[ab+18>>1]=b[T+((as&255|A)<<1)>>1]|0}as=a[Y+7|0]|0;if(!(as<<24>>24==15|ak)){b[ab+16>>1]=b[T+((as&255|A)<<1)>>1]|0}as=a[Y+8|0]|0;if(!(as<<24>>24==15|aj)){b[ab+14>>1]=b[T+((as&255|A)<<1)>>1]|0}as=a[Y+9|0]|0;if(!(as<<24>>24==15|ai)){b[ab+12>>1]=b[T+((as&255|A)<<1)>>1]|0}as=a[Y+10|0]|0;if(!(as<<24>>24==15|ah)){b[ab+10>>1]=b[T+((as&255|A)<<1)>>1]|0}as=a[Y+11|0]|0;if(!(as<<24>>24==15|af)){b[ab+8>>1]=b[T+((as&255|A)<<1)>>1]|0}as=a[Y+12|0]|0;if(!(as<<24>>24==15|ae)){b[ab+6>>1]=b[T+((as&255|A)<<1)>>1]|0}as=a[Y+13|0]|0;if(!(as<<24>>24==15|ad)){b[ab+4>>1]=b[T+((as&255|A)<<1)>>1]|0}as=a[Y+14|0]|0;if(!(as<<24>>24==15|ac)){b[ab+2>>1]=b[T+((as&255|A)<<1)>>1]|0}as=a[Y+15|0]|0;if(!(as<<24>>24!=15&$&aa)){break}b[ab>>1]=b[T+((as&255|A)<<1)>>1]|0}}while(0);if((Z|0)>0){ab=ab-640|0;Y=Y+16|0;Z=Z-1|0}else{break}}}}}else{if(D){if(y){Z=W;Y=U;ab=0;while(1){aa=a[Y]|0;if(aa<<24>>24!=15){b[Z>>1]=b[T+((aa&255|A)<<1)>>1]|0}aa=a[Y+1|0]|0;if(aa<<24>>24!=15){b[Z+2>>1]=b[T+((aa&255|A)<<1)>>1]|0}aa=a[Y+2|0]|0;if(aa<<24>>24!=15){b[Z+4>>1]=b[T+((aa&255|A)<<1)>>1]|0}aa=a[Y+3|0]|0;if(aa<<24>>24!=15){b[Z+6>>1]=b[T+((aa&255|A)<<1)>>1]|0}aa=a[Y+4|0]|0;if(aa<<24>>24!=15){b[Z+8>>1]=b[T+((aa&255|A)<<1)>>1]|0}aa=a[Y+5|0]|0;if(aa<<24>>24!=15){b[Z+10>>1]=b[T+((aa&255|A)<<1)>>1]|0}aa=a[Y+6|0]|0;if(aa<<24>>24!=15){b[Z+12>>1]=b[T+((aa&255|A)<<1)>>1]|0}aa=a[Y+7|0]|0;if(aa<<24>>24!=15){b[Z+14>>1]=b[T+((aa&255|A)<<1)>>1]|0}aa=a[Y+8|0]|0;if(aa<<24>>24!=15){b[Z+16>>1]=b[T+((aa&255|A)<<1)>>1]|0}aa=a[Y+9|0]|0;if(aa<<24>>24!=15){b[Z+18>>1]=b[T+((aa&255|A)<<1)>>1]|0}aa=a[Y+10|0]|0;if(aa<<24>>24!=15){b[Z+20>>1]=b[T+((aa&255|A)<<1)>>1]|0}aa=a[Y+11|0]|0;if(aa<<24>>24!=15){b[Z+22>>1]=b[T+((aa&255|A)<<1)>>1]|0}aa=a[Y+12|0]|0;if(aa<<24>>24!=15){b[Z+24>>1]=b[T+((aa&255|A)<<1)>>1]|0}aa=a[Y+13|0]|0;if(aa<<24>>24!=15){b[Z+26>>1]=b[T+((aa&255|A)<<1)>>1]|0}aa=a[Y+14|0]|0;if(aa<<24>>24!=15){b[Z+28>>1]=b[T+((aa&255|A)<<1)>>1]|0}aa=a[Y+15|0]|0;if(aa<<24>>24!=15){b[Z+30>>1]=b[T+((aa&255|A)<<1)>>1]|0}aa=ab+1|0;if((aa|0)<16){Z=Z+640|0;Y=Y+16|0;ab=aa}else{break}}}else{ab=W;Y=U;Z=0;while(1){aa=a[Y]|0;if(aa<<24>>24!=15){b[ab+30>>1]=b[T+((aa&255|A)<<1)>>1]|0}aa=a[Y+1|0]|0;if(aa<<24>>24!=15){b[ab+28>>1]=b[T+((aa&255|A)<<1)>>1]|0}aa=a[Y+2|0]|0;if(aa<<24>>24!=15){b[ab+26>>1]=b[T+((aa&255|A)<<1)>>1]|0}aa=a[Y+3|0]|0;if(aa<<24>>24!=15){b[ab+24>>1]=b[T+((aa&255|A)<<1)>>1]|0}aa=a[Y+4|0]|0;if(aa<<24>>24!=15){b[ab+22>>1]=b[T+((aa&255|A)<<1)>>1]|0}aa=a[Y+5|0]|0;if(aa<<24>>24!=15){b[ab+20>>1]=b[T+((aa&255|A)<<1)>>1]|0}aa=a[Y+6|0]|0;if(aa<<24>>24!=15){b[ab+18>>1]=b[T+((aa&255|A)<<1)>>1]|0}aa=a[Y+7|0]|0;if(aa<<24>>24!=15){b[ab+16>>1]=b[T+((aa&255|A)<<1)>>1]|0}aa=a[Y+8|0]|0;if(aa<<24>>24!=15){b[ab+14>>1]=b[T+((aa&255|A)<<1)>>1]|0}aa=a[Y+9|0]|0;if(aa<<24>>24!=15){b[ab+12>>1]=b[T+((aa&255|A)<<1)>>1]|0}aa=a[Y+10|0]|0;if(aa<<24>>24!=15){b[ab+10>>1]=b[T+((aa&255|A)<<1)>>1]|0}aa=a[Y+11|0]|0;if(aa<<24>>24!=15){b[ab+8>>1]=b[T+((aa&255|A)<<1)>>1]|0}aa=a[Y+12|0]|0;if(aa<<24>>24!=15){b[ab+6>>1]=b[T+((aa&255|A)<<1)>>1]|0}aa=a[Y+13|0]|0;if(aa<<24>>24!=15){b[ab+4>>1]=b[T+((aa&255|A)<<1)>>1]|0}aa=a[Y+14|0]|0;if(aa<<24>>24!=15){b[ab+2>>1]=b[T+((aa&255|A)<<1)>>1]|0}aa=a[Y+15|0]|0;if(aa<<24>>24!=15){b[ab>>1]=b[T+((aa&255|A)<<1)>>1]|0}aa=Z+1|0;if((aa|0)<16){ab=ab+640|0;Y=Y+16|0;Z=aa}else{break}}}}else{Z=q+(V+4800<<1)|0;if(y){Y=Z;ab=U;aa=0;while(1){$=a[ab]|0;if($<<24>>24!=15){b[Y>>1]=b[T+(($&255|A)<<1)>>1]|0}$=a[ab+1|0]|0;if($<<24>>24!=15){b[Y+2>>1]=b[T+(($&255|A)<<1)>>1]|0}$=a[ab+2|0]|0;if($<<24>>24!=15){b[Y+4>>1]=b[T+(($&255|A)<<1)>>1]|0}$=a[ab+3|0]|0;if($<<24>>24!=15){b[Y+6>>1]=b[T+(($&255|A)<<1)>>1]|0}$=a[ab+4|0]|0;if($<<24>>24!=15){b[Y+8>>1]=b[T+(($&255|A)<<1)>>1]|0}$=a[ab+5|0]|0;if($<<24>>24!=15){b[Y+10>>1]=b[T+(($&255|A)<<1)>>1]|0}$=a[ab+6|0]|0;if($<<24>>24!=15){b[Y+12>>1]=b[T+(($&255|A)<<1)>>1]|0}$=a[ab+7|0]|0;if($<<24>>24!=15){b[Y+14>>1]=b[T+(($&255|A)<<1)>>1]|0}$=a[ab+8|0]|0;if($<<24>>24!=15){b[Y+16>>1]=b[T+(($&255|A)<<1)>>1]|0}$=a[ab+9|0]|0;if($<<24>>24!=15){b[Y+18>>1]=b[T+(($&255|A)<<1)>>1]|0}$=a[ab+10|0]|0;if($<<24>>24!=15){b[Y+20>>1]=b[T+(($&255|A)<<1)>>1]|0}$=a[ab+11|0]|0;if($<<24>>24!=15){b[Y+22>>1]=b[T+(($&255|A)<<1)>>1]|0}$=a[ab+12|0]|0;if($<<24>>24!=15){b[Y+24>>1]=b[T+(($&255|A)<<1)>>1]|0}$=a[ab+13|0]|0;if($<<24>>24!=15){b[Y+26>>1]=b[T+(($&255|A)<<1)>>1]|0}$=a[ab+14|0]|0;if($<<24>>24!=15){b[Y+28>>1]=b[T+(($&255|A)<<1)>>1]|0}$=a[ab+15|0]|0;if($<<24>>24!=15){b[Y+30>>1]=b[T+(($&255|A)<<1)>>1]|0}$=aa+1|0;if(($|0)<16){Y=Y-640|0;ab=ab+16|0;aa=$}else{break}}}else{aa=Z;ab=U;Y=0;while(1){$=a[ab]|0;if($<<24>>24!=15){b[aa+30>>1]=b[T+(($&255|A)<<1)>>1]|0}$=a[ab+1|0]|0;if($<<24>>24!=15){b[aa+28>>1]=b[T+(($&255|A)<<1)>>1]|0}$=a[ab+2|0]|0;if($<<24>>24!=15){b[aa+26>>1]=b[T+(($&255|A)<<1)>>1]|0}$=a[ab+3|0]|0;if($<<24>>24!=15){b[aa+24>>1]=b[T+(($&255|A)<<1)>>1]|0}$=a[ab+4|0]|0;if($<<24>>24!=15){b[aa+22>>1]=b[T+(($&255|A)<<1)>>1]|0}$=a[ab+5|0]|0;if($<<24>>24!=15){b[aa+20>>1]=b[T+(($&255|A)<<1)>>1]|0}$=a[ab+6|0]|0;if($<<24>>24!=15){b[aa+18>>1]=b[T+(($&255|A)<<1)>>1]|0}$=a[ab+7|0]|0;if($<<24>>24!=15){b[aa+16>>1]=b[T+(($&255|A)<<1)>>1]|0}$=a[ab+8|0]|0;if($<<24>>24!=15){b[aa+14>>1]=b[T+(($&255|A)<<1)>>1]|0}$=a[ab+9|0]|0;if($<<24>>24!=15){b[aa+12>>1]=b[T+(($&255|A)<<1)>>1]|0}$=a[ab+10|0]|0;if($<<24>>24!=15){b[aa+10>>1]=b[T+(($&255|A)<<1)>>1]|0}$=a[ab+11|0]|0;if($<<24>>24!=15){b[aa+8>>1]=b[T+(($&255|A)<<1)>>1]|0}$=a[ab+12|0]|0;if($<<24>>24!=15){b[aa+6>>1]=b[T+(($&255|A)<<1)>>1]|0}$=a[ab+13|0]|0;if($<<24>>24!=15){b[aa+4>>1]=b[T+(($&255|A)<<1)>>1]|0}$=a[ab+14|0]|0;if($<<24>>24!=15){b[aa+2>>1]=b[T+(($&255|A)<<1)>>1]|0}$=a[ab+15|0]|0;if($<<24>>24!=15){b[aa>>1]=b[T+(($&255|A)<<1)>>1]|0}$=Y+1|0;if(($|0)<16){aa=aa-640|0;ab=ab+16|0;Y=$}else{break}}}}}}while(0);V=L+1|0;if((V|0)>(x|0)){break}else{L=V;Q=Q+1|0}}Q=I+K|0;L=w?Q+3|0:Q;Q=J+1|0;if((Q|0)>(z|0)){break}else{J=Q;K=(G?L+2|0:L)+H|0}}}}while(0);o=o+4|0;}while((o|0)<=(j|0));return}function eaF(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if((b|0)<=0){return}e=c[2418084]|0;f=c[2408970]|0;g=b;do{g=g-1|0;b=g<<5;h=g<<6;i=7;while(1){j=i<<2;k=e+((j|3)+b)|0;l=(i<<3)+h|0;a[f+(l|7)|0]=(d[k]|0)>>>4;a[f+(l|6)|0]=a[k]&15;k=e+((j|2)+b)|0;a[f+(l|5)|0]=(d[k]|0)>>>4;a[f+(l|4)|0]=a[k]&15;k=e+((j|1)+b)|0;a[f+(l|3)|0]=(d[k]|0)>>>4;a[f+(l|2)|0]=a[k]&15;k=e+(j+b)|0;a[f+(l|1)|0]=(d[k]|0)>>>4;a[f+l|0]=a[k]&15;if((i|0)>0){i=i-1|0}else{break}}}while((g|0)>0);return}function eaG(b,c){b=b|0;c=c|0;a[9706117]=(c|0)!=0|0;return}function eaH(a){a=a|0;var b=0,d=0;b=(c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,4e6,0)|0;return a|0}function eaI(){return+(+((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)/4.0e6)}function eaJ(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;i=(e[7057644]|0)+4&511;j=b[7057640]&511;k=c[2112968]|0;l=0;m=0;n=0;while(1){o=(m|0)==64;p=(o&1)+l|0;q=o?0:m;o=(q<<3)-i|0;r=(o|0)<-159?o+512|0:o;o=(p<<3)-j|0;s=(o|0)<-271?o+512|0:o;o=r+7|0;L66093:do{if(o>>>0<=358){if((s+7|0)>>>0>246){break}t=b[f+(n<<1)>>1]|0;u=g+(((d[14115929]|0)<<13|t&8191)<<6)|0;v=(t&65535)>>>9&112;t=k+((s*352|0)+r<<1)|0;if(r>>>0<344&s>>>0<232){w=v&65535;x=u;y=t;z=0;while(1){A=a[x]|0;if(A<<24>>24!=15){b[y>>1]=b[h+((A&255|w)<<1)>>1]|0}A=a[x+1|0]|0;if(A<<24>>24!=15){b[y+2>>1]=b[h+((A&255|w)<<1)>>1]|0}A=a[x+2|0]|0;if(A<<24>>24!=15){b[y+4>>1]=b[h+((A&255|w)<<1)>>1]|0}A=a[x+3|0]|0;if(A<<24>>24!=15){b[y+6>>1]=b[h+((A&255|w)<<1)>>1]|0}A=a[x+4|0]|0;if(A<<24>>24!=15){b[y+8>>1]=b[h+((A&255|w)<<1)>>1]|0}A=a[x+5|0]|0;if(A<<24>>24!=15){b[y+10>>1]=b[h+((A&255|w)<<1)>>1]|0}A=a[x+6|0]|0;if(A<<24>>24!=15){b[y+12>>1]=b[h+((A&255|w)<<1)>>1]|0}A=a[x+7|0]|0;if(A<<24>>24!=15){b[y+14>>1]=b[h+((A&255|w)<<1)>>1]|0}A=z+1|0;if((A|0)<8){x=x+8|0;y=y+704|0;z=A}else{break L66093}}}z=(r|0)>-1;y=(r|0)<352;x=v&65535;w=(r+1|0)>>>0>351;A=(r+2|0)>>>0>351;B=(r+3|0)>>>0>351;C=(r+4|0)>>>0>351;D=(r+5|0)>>>0>351;E=(r+6|0)>>>0>351;F=o>>>0>351;G=u;H=t;I=0;while(1){do{if((I+s|0)>>>0<240){J=a[G]|0;if(z&J<<24>>24!=15&y){b[H>>1]=b[h+((J&255|x)<<1)>>1]|0}J=a[G+1|0]|0;if(!(J<<24>>24==15|w)){b[H+2>>1]=b[h+((J&255|x)<<1)>>1]|0}J=a[G+2|0]|0;if(!(J<<24>>24==15|A)){b[H+4>>1]=b[h+((J&255|x)<<1)>>1]|0}J=a[G+3|0]|0;if(!(J<<24>>24==15|B)){b[H+6>>1]=b[h+((J&255|x)<<1)>>1]|0}J=a[G+4|0]|0;if(!(J<<24>>24==15|C)){b[H+8>>1]=b[h+((J&255|x)<<1)>>1]|0}J=a[G+5|0]|0;if(!(J<<24>>24==15|D)){b[H+10>>1]=b[h+((J&255|x)<<1)>>1]|0}J=a[G+6|0]|0;if(!(J<<24>>24==15|E)){b[H+12>>1]=b[h+((J&255|x)<<1)>>1]|0}J=a[G+7|0]|0;if(J<<24>>24==15|F){break}b[H+14>>1]=b[h+((J&255|x)<<1)>>1]|0}}while(0);J=I+1|0;if((J|0)<8){G=G+8|0;H=H+704|0;I=J}else{break}}}}while(0);s=n+1|0;if((s|0)>=4096){break}l=p;m=q+1|0;n=s}return}function eaK(d,f){d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0;g=d<<9;h=c[2406870]|0;i=((e[h+((g|510)<<1)>>1]|0)<<2)+g|0;j=g|504;if((i|0)>(j|0)){return}g=(f|0)==0|0;k=(d|0)==0;d=c[2437018]|0;l=c[2406876]|0;m=c[2437012]|0;n=c[2388318]|0;o=c[2385764]|0;p=o+1024|0;q=c[2112968]|0;r=c[2437016]|0;s=c[2406872]|0;t=c[2437010]|0;u=c[2388316]|0;v=o+1536|0;o=i;do{i=e[h+(o+2<<1)>>1]|0;do{if((i&128|0)!=0){w=i>>>4;if(((w&1^1)&f|0)!=0){break}if((w&g|0)!=0){break}w=e[h+(o+1<<1)>>1]|0;x=i>>>8&7;y=e[h+(o<<1)>>1]|0;z=i>>>12&7;A=i<<4&240;B=32-(w>>>12)|0;C=32-(y>>>12)|0;D=(i&32768|0)==0;E=y+16|0;y=(i&2048|0)==0;F=w+16|0;w=(x|0)==4;G=(x|0)==5;H=(x|0)==6|0;I=x+1+((x|0)==2)|0;J=0;K=e[h+(o+3<<1)>>1]|0;while(1){L=E+((ag(D?J:z-J|0,C)|0)/2|0)&511;M=L-16|0;N=M*352|0;O=M>>>0>223;P=(L-1|0)>>>0>254;L=0;Q=K;while(1){R=F+((ag(y?L:x-L|0,B)|0)/2|0)&511;S=R-24|0;if(k){T=p;U=n+((m&(e[l+((d&Q)<<1)>>1]|0))<<8)|0}else{T=v;U=u+((t&(e[s+((r&Q)<<1)>>1]|0))<<8)|0}V=S+N|0;W=q+(V<<1)|0;do{if(S>>>0>335|O){X=R-9|0;if(X>>>0>366|P){break}if(D){Y=(S|0)>-1;Z=(S|0)<352;if(y){_=(R-23|0)>>>0>351;$=(R-22|0)>>>0>351;aa=(R-21|0)>>>0>351;ab=(R-20|0)>>>0>351;ac=(R-19|0)>>>0>351;ad=(R-18|0)>>>0>351;ae=(R-17|0)>>>0>351;af=(R-16|0)>>>0>351;ah=(R-15|0)>>>0>351;ai=(R-14|0)>>>0>351;aj=(R-13|0)>>>0>351;ak=(R-12|0)>>>0>351;al=(R-11|0)>>>0>351;am=(R-10|0)>>>0>351;an=X>>>0>351;ao=W;ap=U;aq=0;while(1){do{if((aq+M|0)>>>0<240){ar=a[ap]|0;if(ar<<24>>24!=15&Y&Z){b[ao>>1]=b[T+((ar&255|A)<<1)>>1]|0}ar=a[ap+1|0]|0;if(!(ar<<24>>24==15|_)){b[ao+2>>1]=b[T+((ar&255|A)<<1)>>1]|0}ar=a[ap+2|0]|0;if(!(ar<<24>>24==15|$)){b[ao+4>>1]=b[T+((ar&255|A)<<1)>>1]|0}ar=a[ap+3|0]|0;if(!(ar<<24>>24==15|aa)){b[ao+6>>1]=b[T+((ar&255|A)<<1)>>1]|0}ar=a[ap+4|0]|0;if(!(ar<<24>>24==15|ab)){b[ao+8>>1]=b[T+((ar&255|A)<<1)>>1]|0}ar=a[ap+5|0]|0;if(!(ar<<24>>24==15|ac)){b[ao+10>>1]=b[T+((ar&255|A)<<1)>>1]|0}ar=a[ap+6|0]|0;if(!(ar<<24>>24==15|ad)){b[ao+12>>1]=b[T+((ar&255|A)<<1)>>1]|0}ar=a[ap+7|0]|0;if(!(ar<<24>>24==15|ae)){b[ao+14>>1]=b[T+((ar&255|A)<<1)>>1]|0}ar=a[ap+8|0]|0;if(!(ar<<24>>24==15|af)){b[ao+16>>1]=b[T+((ar&255|A)<<1)>>1]|0}ar=a[ap+9|0]|0;if(!(ar<<24>>24==15|ah)){b[ao+18>>1]=b[T+((ar&255|A)<<1)>>1]|0}ar=a[ap+10|0]|0;if(!(ar<<24>>24==15|ai)){b[ao+20>>1]=b[T+((ar&255|A)<<1)>>1]|0}ar=a[ap+11|0]|0;if(!(ar<<24>>24==15|aj)){b[ao+22>>1]=b[T+((ar&255|A)<<1)>>1]|0}ar=a[ap+12|0]|0;if(!(ar<<24>>24==15|ak)){b[ao+24>>1]=b[T+((ar&255|A)<<1)>>1]|0}ar=a[ap+13|0]|0;if(!(ar<<24>>24==15|al)){b[ao+26>>1]=b[T+((ar&255|A)<<1)>>1]|0}ar=a[ap+14|0]|0;if(!(ar<<24>>24==15|am)){b[ao+28>>1]=b[T+((ar&255|A)<<1)>>1]|0}ar=a[ap+15|0]|0;if(ar<<24>>24==15|an){break}b[ao+30>>1]=b[T+((ar&255|A)<<1)>>1]|0}}while(0);ar=aq+1|0;if((ar|0)<16){ao=ao+704|0;ap=ap+16|0;aq=ar}else{break}}}else{aq=X>>>0>351;ap=(R-10|0)>>>0>351;ao=(R-11|0)>>>0>351;an=(R-12|0)>>>0>351;am=(R-13|0)>>>0>351;al=(R-14|0)>>>0>351;ak=(R-15|0)>>>0>351;aj=(R-16|0)>>>0>351;ai=(R-17|0)>>>0>351;ah=(R-18|0)>>>0>351;af=(R-19|0)>>>0>351;ae=(R-20|0)>>>0>351;ad=(R-21|0)>>>0>351;ac=(R-22|0)>>>0>351;ab=(R-23|0)>>>0>351;aa=W;$=U;_=0;while(1){do{if((_+M|0)>>>0<240){ar=a[$]|0;if(!(ar<<24>>24==15|aq)){b[aa+30>>1]=b[T+((ar&255|A)<<1)>>1]|0}ar=a[$+1|0]|0;if(!(ar<<24>>24==15|ap)){b[aa+28>>1]=b[T+((ar&255|A)<<1)>>1]|0}ar=a[$+2|0]|0;if(!(ar<<24>>24==15|ao)){b[aa+26>>1]=b[T+((ar&255|A)<<1)>>1]|0}ar=a[$+3|0]|0;if(!(ar<<24>>24==15|an)){b[aa+24>>1]=b[T+((ar&255|A)<<1)>>1]|0}ar=a[$+4|0]|0;if(!(ar<<24>>24==15|am)){b[aa+22>>1]=b[T+((ar&255|A)<<1)>>1]|0}ar=a[$+5|0]|0;if(!(ar<<24>>24==15|al)){b[aa+20>>1]=b[T+((ar&255|A)<<1)>>1]|0}ar=a[$+6|0]|0;if(!(ar<<24>>24==15|ak)){b[aa+18>>1]=b[T+((ar&255|A)<<1)>>1]|0}ar=a[$+7|0]|0;if(!(ar<<24>>24==15|aj)){b[aa+16>>1]=b[T+((ar&255|A)<<1)>>1]|0}ar=a[$+8|0]|0;if(!(ar<<24>>24==15|ai)){b[aa+14>>1]=b[T+((ar&255|A)<<1)>>1]|0}ar=a[$+9|0]|0;if(!(ar<<24>>24==15|ah)){b[aa+12>>1]=b[T+((ar&255|A)<<1)>>1]|0}ar=a[$+10|0]|0;if(!(ar<<24>>24==15|af)){b[aa+10>>1]=b[T+((ar&255|A)<<1)>>1]|0}ar=a[$+11|0]|0;if(!(ar<<24>>24==15|ae)){b[aa+8>>1]=b[T+((ar&255|A)<<1)>>1]|0}ar=a[$+12|0]|0;if(!(ar<<24>>24==15|ad)){b[aa+6>>1]=b[T+((ar&255|A)<<1)>>1]|0}ar=a[$+13|0]|0;if(!(ar<<24>>24==15|ac)){b[aa+4>>1]=b[T+((ar&255|A)<<1)>>1]|0}ar=a[$+14|0]|0;if(!(ar<<24>>24==15|ab)){b[aa+2>>1]=b[T+((ar&255|A)<<1)>>1]|0}ar=a[$+15|0]|0;if(!(ar<<24>>24!=15&Y&Z)){break}b[aa>>1]=b[T+((ar&255|A)<<1)>>1]|0}}while(0);ar=_+1|0;if((ar|0)<16){aa=aa+704|0;$=$+16|0;_=ar}else{break}}}}else{_=q+(V+5280<<1)|0;$=(S|0)>-1;aa=(S|0)<352;if(y){Z=(R-23|0)>>>0>351;Y=(R-22|0)>>>0>351;ab=(R-21|0)>>>0>351;ac=(R-20|0)>>>0>351;ad=(R-19|0)>>>0>351;ae=(R-18|0)>>>0>351;af=(R-17|0)>>>0>351;ah=(R-16|0)>>>0>351;ai=(R-15|0)>>>0>351;aj=(R-14|0)>>>0>351;ak=(R-13|0)>>>0>351;al=(R-12|0)>>>0>351;am=(R-11|0)>>>0>351;an=(R-10|0)>>>0>351;ao=X>>>0>351;ap=_;aq=U;ar=15;while(1){do{if((ar+M|0)>>>0<240){as=a[aq]|0;if(as<<24>>24!=15&$&aa){b[ap>>1]=b[T+((as&255|A)<<1)>>1]|0}as=a[aq+1|0]|0;if(!(as<<24>>24==15|Z)){b[ap+2>>1]=b[T+((as&255|A)<<1)>>1]|0}as=a[aq+2|0]|0;if(!(as<<24>>24==15|Y)){b[ap+4>>1]=b[T+((as&255|A)<<1)>>1]|0}as=a[aq+3|0]|0;if(!(as<<24>>24==15|ab)){b[ap+6>>1]=b[T+((as&255|A)<<1)>>1]|0}as=a[aq+4|0]|0;if(!(as<<24>>24==15|ac)){b[ap+8>>1]=b[T+((as&255|A)<<1)>>1]|0}as=a[aq+5|0]|0;if(!(as<<24>>24==15|ad)){b[ap+10>>1]=b[T+((as&255|A)<<1)>>1]|0}as=a[aq+6|0]|0;if(!(as<<24>>24==15|ae)){b[ap+12>>1]=b[T+((as&255|A)<<1)>>1]|0}as=a[aq+7|0]|0;if(!(as<<24>>24==15|af)){b[ap+14>>1]=b[T+((as&255|A)<<1)>>1]|0}as=a[aq+8|0]|0;if(!(as<<24>>24==15|ah)){b[ap+16>>1]=b[T+((as&255|A)<<1)>>1]|0}as=a[aq+9|0]|0;if(!(as<<24>>24==15|ai)){b[ap+18>>1]=b[T+((as&255|A)<<1)>>1]|0}as=a[aq+10|0]|0;if(!(as<<24>>24==15|aj)){b[ap+20>>1]=b[T+((as&255|A)<<1)>>1]|0}as=a[aq+11|0]|0;if(!(as<<24>>24==15|ak)){b[ap+22>>1]=b[T+((as&255|A)<<1)>>1]|0}as=a[aq+12|0]|0;if(!(as<<24>>24==15|al)){b[ap+24>>1]=b[T+((as&255|A)<<1)>>1]|0}as=a[aq+13|0]|0;if(!(as<<24>>24==15|am)){b[ap+26>>1]=b[T+((as&255|A)<<1)>>1]|0}as=a[aq+14|0]|0;if(!(as<<24>>24==15|an)){b[ap+28>>1]=b[T+((as&255|A)<<1)>>1]|0}as=a[aq+15|0]|0;if(as<<24>>24==15|ao){break}b[ap+30>>1]=b[T+((as&255|A)<<1)>>1]|0}}while(0);if((ar|0)>0){ap=ap-704|0;aq=aq+16|0;ar=ar-1|0}else{break}}}else{ar=X>>>0>351;aq=(R-10|0)>>>0>351;ap=(R-11|0)>>>0>351;ao=(R-12|0)>>>0>351;an=(R-13|0)>>>0>351;am=(R-14|0)>>>0>351;al=(R-15|0)>>>0>351;ak=(R-16|0)>>>0>351;aj=(R-17|0)>>>0>351;ai=(R-18|0)>>>0>351;ah=(R-19|0)>>>0>351;af=(R-20|0)>>>0>351;ae=(R-21|0)>>>0>351;ad=(R-22|0)>>>0>351;ac=(R-23|0)>>>0>351;ab=_;Y=U;Z=15;while(1){do{if((Z+M|0)>>>0<240){as=a[Y]|0;if(!(as<<24>>24==15|ar)){b[ab+30>>1]=b[T+((as&255|A)<<1)>>1]|0}as=a[Y+1|0]|0;if(!(as<<24>>24==15|aq)){b[ab+28>>1]=b[T+((as&255|A)<<1)>>1]|0}as=a[Y+2|0]|0;if(!(as<<24>>24==15|ap)){b[ab+26>>1]=b[T+((as&255|A)<<1)>>1]|0}as=a[Y+3|0]|0;if(!(as<<24>>24==15|ao)){b[ab+24>>1]=b[T+((as&255|A)<<1)>>1]|0}as=a[Y+4|0]|0;if(!(as<<24>>24==15|an)){b[ab+22>>1]=b[T+((as&255|A)<<1)>>1]|0}as=a[Y+5|0]|0;if(!(as<<24>>24==15|am)){b[ab+20>>1]=b[T+((as&255|A)<<1)>>1]|0}as=a[Y+6|0]|0;if(!(as<<24>>24==15|al)){b[ab+18>>1]=b[T+((as&255|A)<<1)>>1]|0}as=a[Y+7|0]|0;if(!(as<<24>>24==15|ak)){b[ab+16>>1]=b[T+((as&255|A)<<1)>>1]|0}as=a[Y+8|0]|0;if(!(as<<24>>24==15|aj)){b[ab+14>>1]=b[T+((as&255|A)<<1)>>1]|0}as=a[Y+9|0]|0;if(!(as<<24>>24==15|ai)){b[ab+12>>1]=b[T+((as&255|A)<<1)>>1]|0}as=a[Y+10|0]|0;if(!(as<<24>>24==15|ah)){b[ab+10>>1]=b[T+((as&255|A)<<1)>>1]|0}as=a[Y+11|0]|0;if(!(as<<24>>24==15|af)){b[ab+8>>1]=b[T+((as&255|A)<<1)>>1]|0}as=a[Y+12|0]|0;if(!(as<<24>>24==15|ae)){b[ab+6>>1]=b[T+((as&255|A)<<1)>>1]|0}as=a[Y+13|0]|0;if(!(as<<24>>24==15|ad)){b[ab+4>>1]=b[T+((as&255|A)<<1)>>1]|0}as=a[Y+14|0]|0;if(!(as<<24>>24==15|ac)){b[ab+2>>1]=b[T+((as&255|A)<<1)>>1]|0}as=a[Y+15|0]|0;if(!(as<<24>>24!=15&$&aa)){break}b[ab>>1]=b[T+((as&255|A)<<1)>>1]|0}}while(0);if((Z|0)>0){ab=ab-704|0;Y=Y+16|0;Z=Z-1|0}else{break}}}}}else{if(D){if(y){Z=W;Y=U;ab=0;while(1){aa=a[Y]|0;if(aa<<24>>24!=15){b[Z>>1]=b[T+((aa&255|A)<<1)>>1]|0}aa=a[Y+1|0]|0;if(aa<<24>>24!=15){b[Z+2>>1]=b[T+((aa&255|A)<<1)>>1]|0}aa=a[Y+2|0]|0;if(aa<<24>>24!=15){b[Z+4>>1]=b[T+((aa&255|A)<<1)>>1]|0}aa=a[Y+3|0]|0;if(aa<<24>>24!=15){b[Z+6>>1]=b[T+((aa&255|A)<<1)>>1]|0}aa=a[Y+4|0]|0;if(aa<<24>>24!=15){b[Z+8>>1]=b[T+((aa&255|A)<<1)>>1]|0}aa=a[Y+5|0]|0;if(aa<<24>>24!=15){b[Z+10>>1]=b[T+((aa&255|A)<<1)>>1]|0}aa=a[Y+6|0]|0;if(aa<<24>>24!=15){b[Z+12>>1]=b[T+((aa&255|A)<<1)>>1]|0}aa=a[Y+7|0]|0;if(aa<<24>>24!=15){b[Z+14>>1]=b[T+((aa&255|A)<<1)>>1]|0}aa=a[Y+8|0]|0;if(aa<<24>>24!=15){b[Z+16>>1]=b[T+((aa&255|A)<<1)>>1]|0}aa=a[Y+9|0]|0;if(aa<<24>>24!=15){b[Z+18>>1]=b[T+((aa&255|A)<<1)>>1]|0}aa=a[Y+10|0]|0;if(aa<<24>>24!=15){b[Z+20>>1]=b[T+((aa&255|A)<<1)>>1]|0}aa=a[Y+11|0]|0;if(aa<<24>>24!=15){b[Z+22>>1]=b[T+((aa&255|A)<<1)>>1]|0}aa=a[Y+12|0]|0;if(aa<<24>>24!=15){b[Z+24>>1]=b[T+((aa&255|A)<<1)>>1]|0}aa=a[Y+13|0]|0;if(aa<<24>>24!=15){b[Z+26>>1]=b[T+((aa&255|A)<<1)>>1]|0}aa=a[Y+14|0]|0;if(aa<<24>>24!=15){b[Z+28>>1]=b[T+((aa&255|A)<<1)>>1]|0}aa=a[Y+15|0]|0;if(aa<<24>>24!=15){b[Z+30>>1]=b[T+((aa&255|A)<<1)>>1]|0}aa=ab+1|0;if((aa|0)<16){Z=Z+704|0;Y=Y+16|0;ab=aa}else{break}}}else{ab=W;Y=U;Z=0;while(1){aa=a[Y]|0;if(aa<<24>>24!=15){b[ab+30>>1]=b[T+((aa&255|A)<<1)>>1]|0}aa=a[Y+1|0]|0;if(aa<<24>>24!=15){b[ab+28>>1]=b[T+((aa&255|A)<<1)>>1]|0}aa=a[Y+2|0]|0;if(aa<<24>>24!=15){b[ab+26>>1]=b[T+((aa&255|A)<<1)>>1]|0}aa=a[Y+3|0]|0;if(aa<<24>>24!=15){b[ab+24>>1]=b[T+((aa&255|A)<<1)>>1]|0}aa=a[Y+4|0]|0;if(aa<<24>>24!=15){b[ab+22>>1]=b[T+((aa&255|A)<<1)>>1]|0}aa=a[Y+5|0]|0;if(aa<<24>>24!=15){b[ab+20>>1]=b[T+((aa&255|A)<<1)>>1]|0}aa=a[Y+6|0]|0;if(aa<<24>>24!=15){b[ab+18>>1]=b[T+((aa&255|A)<<1)>>1]|0}aa=a[Y+7|0]|0;if(aa<<24>>24!=15){b[ab+16>>1]=b[T+((aa&255|A)<<1)>>1]|0}aa=a[Y+8|0]|0;if(aa<<24>>24!=15){b[ab+14>>1]=b[T+((aa&255|A)<<1)>>1]|0}aa=a[Y+9|0]|0;if(aa<<24>>24!=15){b[ab+12>>1]=b[T+((aa&255|A)<<1)>>1]|0}aa=a[Y+10|0]|0;if(aa<<24>>24!=15){b[ab+10>>1]=b[T+((aa&255|A)<<1)>>1]|0}aa=a[Y+11|0]|0;if(aa<<24>>24!=15){b[ab+8>>1]=b[T+((aa&255|A)<<1)>>1]|0}aa=a[Y+12|0]|0;if(aa<<24>>24!=15){b[ab+6>>1]=b[T+((aa&255|A)<<1)>>1]|0}aa=a[Y+13|0]|0;if(aa<<24>>24!=15){b[ab+4>>1]=b[T+((aa&255|A)<<1)>>1]|0}aa=a[Y+14|0]|0;if(aa<<24>>24!=15){b[ab+2>>1]=b[T+((aa&255|A)<<1)>>1]|0}aa=a[Y+15|0]|0;if(aa<<24>>24!=15){b[ab>>1]=b[T+((aa&255|A)<<1)>>1]|0}aa=Z+1|0;if((aa|0)<16){ab=ab+704|0;Y=Y+16|0;Z=aa}else{break}}}}else{Z=q+(V+5280<<1)|0;if(y){Y=Z;ab=U;aa=0;while(1){$=a[ab]|0;if($<<24>>24!=15){b[Y>>1]=b[T+(($&255|A)<<1)>>1]|0}$=a[ab+1|0]|0;if($<<24>>24!=15){b[Y+2>>1]=b[T+(($&255|A)<<1)>>1]|0}$=a[ab+2|0]|0;if($<<24>>24!=15){b[Y+4>>1]=b[T+(($&255|A)<<1)>>1]|0}$=a[ab+3|0]|0;if($<<24>>24!=15){b[Y+6>>1]=b[T+(($&255|A)<<1)>>1]|0}$=a[ab+4|0]|0;if($<<24>>24!=15){b[Y+8>>1]=b[T+(($&255|A)<<1)>>1]|0}$=a[ab+5|0]|0;if($<<24>>24!=15){b[Y+10>>1]=b[T+(($&255|A)<<1)>>1]|0}$=a[ab+6|0]|0;if($<<24>>24!=15){b[Y+12>>1]=b[T+(($&255|A)<<1)>>1]|0}$=a[ab+7|0]|0;if($<<24>>24!=15){b[Y+14>>1]=b[T+(($&255|A)<<1)>>1]|0}$=a[ab+8|0]|0;if($<<24>>24!=15){b[Y+16>>1]=b[T+(($&255|A)<<1)>>1]|0}$=a[ab+9|0]|0;if($<<24>>24!=15){b[Y+18>>1]=b[T+(($&255|A)<<1)>>1]|0}$=a[ab+10|0]|0;if($<<24>>24!=15){b[Y+20>>1]=b[T+(($&255|A)<<1)>>1]|0}$=a[ab+11|0]|0;if($<<24>>24!=15){b[Y+22>>1]=b[T+(($&255|A)<<1)>>1]|0}$=a[ab+12|0]|0;if($<<24>>24!=15){b[Y+24>>1]=b[T+(($&255|A)<<1)>>1]|0}$=a[ab+13|0]|0;if($<<24>>24!=15){b[Y+26>>1]=b[T+(($&255|A)<<1)>>1]|0}$=a[ab+14|0]|0;if($<<24>>24!=15){b[Y+28>>1]=b[T+(($&255|A)<<1)>>1]|0}$=a[ab+15|0]|0;if($<<24>>24!=15){b[Y+30>>1]=b[T+(($&255|A)<<1)>>1]|0}$=aa+1|0;if(($|0)<16){Y=Y-704|0;ab=ab+16|0;aa=$}else{break}}}else{aa=Z;ab=U;Y=0;while(1){$=a[ab]|0;if($<<24>>24!=15){b[aa+30>>1]=b[T+(($&255|A)<<1)>>1]|0}$=a[ab+1|0]|0;if($<<24>>24!=15){b[aa+28>>1]=b[T+(($&255|A)<<1)>>1]|0}$=a[ab+2|0]|0;if($<<24>>24!=15){b[aa+26>>1]=b[T+(($&255|A)<<1)>>1]|0}$=a[ab+3|0]|0;if($<<24>>24!=15){b[aa+24>>1]=b[T+(($&255|A)<<1)>>1]|0}$=a[ab+4|0]|0;if($<<24>>24!=15){b[aa+22>>1]=b[T+(($&255|A)<<1)>>1]|0}$=a[ab+5|0]|0;if($<<24>>24!=15){b[aa+20>>1]=b[T+(($&255|A)<<1)>>1]|0}$=a[ab+6|0]|0;if($<<24>>24!=15){b[aa+18>>1]=b[T+(($&255|A)<<1)>>1]|0}$=a[ab+7|0]|0;if($<<24>>24!=15){b[aa+16>>1]=b[T+(($&255|A)<<1)>>1]|0}$=a[ab+8|0]|0;if($<<24>>24!=15){b[aa+14>>1]=b[T+(($&255|A)<<1)>>1]|0}$=a[ab+9|0]|0;if($<<24>>24!=15){b[aa+12>>1]=b[T+(($&255|A)<<1)>>1]|0}$=a[ab+10|0]|0;if($<<24>>24!=15){b[aa+10>>1]=b[T+(($&255|A)<<1)>>1]|0}$=a[ab+11|0]|0;if($<<24>>24!=15){b[aa+8>>1]=b[T+(($&255|A)<<1)>>1]|0}$=a[ab+12|0]|0;if($<<24>>24!=15){b[aa+6>>1]=b[T+(($&255|A)<<1)>>1]|0}$=a[ab+13|0]|0;if($<<24>>24!=15){b[aa+4>>1]=b[T+(($&255|A)<<1)>>1]|0}$=a[ab+14|0]|0;if($<<24>>24!=15){b[aa+2>>1]=b[T+(($&255|A)<<1)>>1]|0}$=a[ab+15|0]|0;if($<<24>>24!=15){b[aa>>1]=b[T+(($&255|A)<<1)>>1]|0}$=Y+1|0;if(($|0)<16){aa=aa-704|0;ab=ab+16|0;Y=$}else{break}}}}}}while(0);V=L+1|0;if((V|0)>(x|0)){break}else{L=V;Q=Q+1|0}}Q=I+K|0;L=w?Q+3|0:Q;Q=J+1|0;if((Q|0)>(z|0)){break}else{J=Q;K=(G?L+2|0:L)+H|0}}}}while(0);o=o+4|0;}while((o|0)<=(j|0));return}function eaL(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;if((e|0)>0){f=e}else{return}do{f=f-1|0;e=f<<7;g=f<<8;h=15;while(1){i=h<<3;j=c+((i|7)+e)|0;k=(h<<4)+g|0;a[b+(k|15)|0]=(d[j]|0)>>>4;a[b+(k|14)|0]=a[j]&15;j=c+((i|5)+e)|0;a[b+(k|13)|0]=(d[j]|0)>>>4;a[b+(k|12)|0]=a[j]&15;j=c+((i|6)+e)|0;a[b+(k|11)|0]=(d[j]|0)>>>4;a[b+(k|10)|0]=a[j]&15;j=c+((i|4)+e)|0;a[b+(k|9)|0]=(d[j]|0)>>>4;a[b+(k|8)|0]=a[j]&15;j=c+((i|3)+e)|0;a[b+(k|7)|0]=(d[j]|0)>>>4;a[b+(k|6)|0]=a[j]&15;j=c+((i|1)+e)|0;a[b+(k|5)|0]=(d[j]|0)>>>4;a[b+(k|4)|0]=a[j]&15;j=c+((i|2)+e)|0;a[b+(k|3)|0]=(d[j]|0)>>>4;a[b+(k|2)|0]=a[j]&15;j=c+(i+e)|0;a[b+(k|1)|0]=(d[j]|0)>>>4;a[b+k|0]=a[j]&15;if((h|0)>0){h=h-1|0}else{break}}}while((f|0)>0);return}function eaM(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0;f=d<<12;d=c[2406872]|0;g=c[2406876]|0;h=c[2112968]|0;i=c[2388318]|0;j=c[2385764]|0;k=j+1024|0;l=c[2388316]|0;m=j+1536|0;j=0;while(1){n=e[d+(j<<1)>>1]|0;if((n&32768|0)!=0){o=50607;break}p=n<<2&4092;n=e[d+((p|2)<<1)>>1]|0;if((n&12288|0)==(f|0)){q=e[d+((p|1)<<1)>>1]|0;r=q>>>9&7;s=q>>>12;t=e[d+(p<<1)>>1]|0;u=t>>>9&7;v=t>>>12;w=n>>>4&240;x=b[d+((p|3)<<1)>>1]&16383;p=((ag(r,s)|0)+2|0)>>>2;y=32-s|0;s=32-v|0;z=(n&32768|0)==0;A=t+16+(((ag(u,v)|0)+2|0)>>>2)|0;v=(n&16384|0)==0;n=q+16+p|0;p=r+1|0;q=0;t=x;while(1){x=A+((ag(z?q:u-q|0,s)|0)/2|0)&511;B=x-16|0;C=B*320|0;D=B>>>0>207;E=(x-1|0)>>>0>238;x=0;F=t;while(1){G=n+((ag(v?x:r-x|0,y)|0)/2|0)&511;H=G-16|0;I=(F&8192|0)==0;J=I?k:m;K=(I?i:l)+((b[g+(F<<1)>>1]&8191)<<8)|0;I=H+C|0;L=h+(I<<1)|0;do{if(H>>>0>303|D){M=G-1|0;if(M>>>0>334|E){break}if(z){N=(H|0)>-1;O=(H|0)<320;if(v){P=(G-15|0)>>>0>319;Q=(G-14|0)>>>0>319;R=(G-13|0)>>>0>319;S=(G-12|0)>>>0>319;T=(G-11|0)>>>0>319;U=(G-10|0)>>>0>319;V=(G-9|0)>>>0>319;W=(G-8|0)>>>0>319;X=(G-7|0)>>>0>319;Y=(G-6|0)>>>0>319;Z=(G-5|0)>>>0>319;_=(G-4|0)>>>0>319;$=(G-3|0)>>>0>319;aa=(G-2|0)>>>0>319;ab=M>>>0>319;ac=L;ad=K;ae=0;while(1){do{if((ae+B|0)>>>0<224){af=a[ad]|0;if(af<<24>>24!=15&N&O){b[ac>>1]=b[J+((af&255|w)<<1)>>1]|0}af=a[ad+1|0]|0;if(!(af<<24>>24==15|P)){b[ac+2>>1]=b[J+((af&255|w)<<1)>>1]|0}af=a[ad+2|0]|0;if(!(af<<24>>24==15|Q)){b[ac+4>>1]=b[J+((af&255|w)<<1)>>1]|0}af=a[ad+3|0]|0;if(!(af<<24>>24==15|R)){b[ac+6>>1]=b[J+((af&255|w)<<1)>>1]|0}af=a[ad+4|0]|0;if(!(af<<24>>24==15|S)){b[ac+8>>1]=b[J+((af&255|w)<<1)>>1]|0}af=a[ad+5|0]|0;if(!(af<<24>>24==15|T)){b[ac+10>>1]=b[J+((af&255|w)<<1)>>1]|0}af=a[ad+6|0]|0;if(!(af<<24>>24==15|U)){b[ac+12>>1]=b[J+((af&255|w)<<1)>>1]|0}af=a[ad+7|0]|0;if(!(af<<24>>24==15|V)){b[ac+14>>1]=b[J+((af&255|w)<<1)>>1]|0}af=a[ad+8|0]|0;if(!(af<<24>>24==15|W)){b[ac+16>>1]=b[J+((af&255|w)<<1)>>1]|0}af=a[ad+9|0]|0;if(!(af<<24>>24==15|X)){b[ac+18>>1]=b[J+((af&255|w)<<1)>>1]|0}af=a[ad+10|0]|0;if(!(af<<24>>24==15|Y)){b[ac+20>>1]=b[J+((af&255|w)<<1)>>1]|0}af=a[ad+11|0]|0;if(!(af<<24>>24==15|Z)){b[ac+22>>1]=b[J+((af&255|w)<<1)>>1]|0}af=a[ad+12|0]|0;if(!(af<<24>>24==15|_)){b[ac+24>>1]=b[J+((af&255|w)<<1)>>1]|0}af=a[ad+13|0]|0;if(!(af<<24>>24==15|$)){b[ac+26>>1]=b[J+((af&255|w)<<1)>>1]|0}af=a[ad+14|0]|0;if(!(af<<24>>24==15|aa)){b[ac+28>>1]=b[J+((af&255|w)<<1)>>1]|0}af=a[ad+15|0]|0;if(af<<24>>24==15|ab){break}b[ac+30>>1]=b[J+((af&255|w)<<1)>>1]|0}}while(0);af=ae+1|0;if((af|0)<16){ac=ac+640|0;ad=ad+16|0;ae=af}else{break}}}else{ae=M>>>0>319;ad=(G-2|0)>>>0>319;ac=(G-3|0)>>>0>319;ab=(G-4|0)>>>0>319;aa=(G-5|0)>>>0>319;$=(G-6|0)>>>0>319;_=(G-7|0)>>>0>319;Z=(G-8|0)>>>0>319;Y=(G-9|0)>>>0>319;X=(G-10|0)>>>0>319;W=(G-11|0)>>>0>319;V=(G-12|0)>>>0>319;U=(G-13|0)>>>0>319;T=(G-14|0)>>>0>319;S=(G-15|0)>>>0>319;R=L;Q=K;P=0;while(1){do{if((P+B|0)>>>0<224){af=a[Q]|0;if(!(af<<24>>24==15|ae)){b[R+30>>1]=b[J+((af&255|w)<<1)>>1]|0}af=a[Q+1|0]|0;if(!(af<<24>>24==15|ad)){b[R+28>>1]=b[J+((af&255|w)<<1)>>1]|0}af=a[Q+2|0]|0;if(!(af<<24>>24==15|ac)){b[R+26>>1]=b[J+((af&255|w)<<1)>>1]|0}af=a[Q+3|0]|0;if(!(af<<24>>24==15|ab)){b[R+24>>1]=b[J+((af&255|w)<<1)>>1]|0}af=a[Q+4|0]|0;if(!(af<<24>>24==15|aa)){b[R+22>>1]=b[J+((af&255|w)<<1)>>1]|0}af=a[Q+5|0]|0;if(!(af<<24>>24==15|$)){b[R+20>>1]=b[J+((af&255|w)<<1)>>1]|0}af=a[Q+6|0]|0;if(!(af<<24>>24==15|_)){b[R+18>>1]=b[J+((af&255|w)<<1)>>1]|0}af=a[Q+7|0]|0;if(!(af<<24>>24==15|Z)){b[R+16>>1]=b[J+((af&255|w)<<1)>>1]|0}af=a[Q+8|0]|0;if(!(af<<24>>24==15|Y)){b[R+14>>1]=b[J+((af&255|w)<<1)>>1]|0}af=a[Q+9|0]|0;if(!(af<<24>>24==15|X)){b[R+12>>1]=b[J+((af&255|w)<<1)>>1]|0}af=a[Q+10|0]|0;if(!(af<<24>>24==15|W)){b[R+10>>1]=b[J+((af&255|w)<<1)>>1]|0}af=a[Q+11|0]|0;if(!(af<<24>>24==15|V)){b[R+8>>1]=b[J+((af&255|w)<<1)>>1]|0}af=a[Q+12|0]|0;if(!(af<<24>>24==15|U)){b[R+6>>1]=b[J+((af&255|w)<<1)>>1]|0}af=a[Q+13|0]|0;if(!(af<<24>>24==15|T)){b[R+4>>1]=b[J+((af&255|w)<<1)>>1]|0}af=a[Q+14|0]|0;if(!(af<<24>>24==15|S)){b[R+2>>1]=b[J+((af&255|w)<<1)>>1]|0}af=a[Q+15|0]|0;if(!(af<<24>>24!=15&N&O)){break}b[R>>1]=b[J+((af&255|w)<<1)>>1]|0}}while(0);af=P+1|0;if((af|0)<16){R=R+640|0;Q=Q+16|0;P=af}else{break}}}}else{P=h+(I+4800<<1)|0;Q=(H|0)>-1;R=(H|0)<320;if(v){O=(G-15|0)>>>0>319;N=(G-14|0)>>>0>319;S=(G-13|0)>>>0>319;T=(G-12|0)>>>0>319;U=(G-11|0)>>>0>319;V=(G-10|0)>>>0>319;W=(G-9|0)>>>0>319;X=(G-8|0)>>>0>319;Y=(G-7|0)>>>0>319;Z=(G-6|0)>>>0>319;_=(G-5|0)>>>0>319;$=(G-4|0)>>>0>319;aa=(G-3|0)>>>0>319;ab=(G-2|0)>>>0>319;ac=M>>>0>319;ad=P;ae=K;af=15;while(1){do{if((af+B|0)>>>0<224){ah=a[ae]|0;if(ah<<24>>24!=15&Q&R){b[ad>>1]=b[J+((ah&255|w)<<1)>>1]|0}ah=a[ae+1|0]|0;if(!(ah<<24>>24==15|O)){b[ad+2>>1]=b[J+((ah&255|w)<<1)>>1]|0}ah=a[ae+2|0]|0;if(!(ah<<24>>24==15|N)){b[ad+4>>1]=b[J+((ah&255|w)<<1)>>1]|0}ah=a[ae+3|0]|0;if(!(ah<<24>>24==15|S)){b[ad+6>>1]=b[J+((ah&255|w)<<1)>>1]|0}ah=a[ae+4|0]|0;if(!(ah<<24>>24==15|T)){b[ad+8>>1]=b[J+((ah&255|w)<<1)>>1]|0}ah=a[ae+5|0]|0;if(!(ah<<24>>24==15|U)){b[ad+10>>1]=b[J+((ah&255|w)<<1)>>1]|0}ah=a[ae+6|0]|0;if(!(ah<<24>>24==15|V)){b[ad+12>>1]=b[J+((ah&255|w)<<1)>>1]|0}ah=a[ae+7|0]|0;if(!(ah<<24>>24==15|W)){b[ad+14>>1]=b[J+((ah&255|w)<<1)>>1]|0}ah=a[ae+8|0]|0;if(!(ah<<24>>24==15|X)){b[ad+16>>1]=b[J+((ah&255|w)<<1)>>1]|0}ah=a[ae+9|0]|0;if(!(ah<<24>>24==15|Y)){b[ad+18>>1]=b[J+((ah&255|w)<<1)>>1]|0}ah=a[ae+10|0]|0;if(!(ah<<24>>24==15|Z)){b[ad+20>>1]=b[J+((ah&255|w)<<1)>>1]|0}ah=a[ae+11|0]|0;if(!(ah<<24>>24==15|_)){b[ad+22>>1]=b[J+((ah&255|w)<<1)>>1]|0}ah=a[ae+12|0]|0;if(!(ah<<24>>24==15|$)){b[ad+24>>1]=b[J+((ah&255|w)<<1)>>1]|0}ah=a[ae+13|0]|0;if(!(ah<<24>>24==15|aa)){b[ad+26>>1]=b[J+((ah&255|w)<<1)>>1]|0}ah=a[ae+14|0]|0;if(!(ah<<24>>24==15|ab)){b[ad+28>>1]=b[J+((ah&255|w)<<1)>>1]|0}ah=a[ae+15|0]|0;if(ah<<24>>24==15|ac){break}b[ad+30>>1]=b[J+((ah&255|w)<<1)>>1]|0}}while(0);if((af|0)>0){ad=ad-640|0;ae=ae+16|0;af=af-1|0}else{break}}}else{af=M>>>0>319;ae=(G-2|0)>>>0>319;ad=(G-3|0)>>>0>319;ac=(G-4|0)>>>0>319;ab=(G-5|0)>>>0>319;aa=(G-6|0)>>>0>319;$=(G-7|0)>>>0>319;_=(G-8|0)>>>0>319;Z=(G-9|0)>>>0>319;Y=(G-10|0)>>>0>319;X=(G-11|0)>>>0>319;W=(G-12|0)>>>0>319;V=(G-13|0)>>>0>319;U=(G-14|0)>>>0>319;T=(G-15|0)>>>0>319;S=P;N=K;O=15;while(1){do{if((O+B|0)>>>0<224){ah=a[N]|0;if(!(ah<<24>>24==15|af)){b[S+30>>1]=b[J+((ah&255|w)<<1)>>1]|0}ah=a[N+1|0]|0;if(!(ah<<24>>24==15|ae)){b[S+28>>1]=b[J+((ah&255|w)<<1)>>1]|0}ah=a[N+2|0]|0;if(!(ah<<24>>24==15|ad)){b[S+26>>1]=b[J+((ah&255|w)<<1)>>1]|0}ah=a[N+3|0]|0;if(!(ah<<24>>24==15|ac)){b[S+24>>1]=b[J+((ah&255|w)<<1)>>1]|0}ah=a[N+4|0]|0;if(!(ah<<24>>24==15|ab)){b[S+22>>1]=b[J+((ah&255|w)<<1)>>1]|0}ah=a[N+5|0]|0;if(!(ah<<24>>24==15|aa)){b[S+20>>1]=b[J+((ah&255|w)<<1)>>1]|0}ah=a[N+6|0]|0;if(!(ah<<24>>24==15|$)){b[S+18>>1]=b[J+((ah&255|w)<<1)>>1]|0}ah=a[N+7|0]|0;if(!(ah<<24>>24==15|_)){b[S+16>>1]=b[J+((ah&255|w)<<1)>>1]|0}ah=a[N+8|0]|0;if(!(ah<<24>>24==15|Z)){b[S+14>>1]=b[J+((ah&255|w)<<1)>>1]|0}ah=a[N+9|0]|0;if(!(ah<<24>>24==15|Y)){b[S+12>>1]=b[J+((ah&255|w)<<1)>>1]|0}ah=a[N+10|0]|0;if(!(ah<<24>>24==15|X)){b[S+10>>1]=b[J+((ah&255|w)<<1)>>1]|0}ah=a[N+11|0]|0;if(!(ah<<24>>24==15|W)){b[S+8>>1]=b[J+((ah&255|w)<<1)>>1]|0}ah=a[N+12|0]|0;if(!(ah<<24>>24==15|V)){b[S+6>>1]=b[J+((ah&255|w)<<1)>>1]|0}ah=a[N+13|0]|0;if(!(ah<<24>>24==15|U)){b[S+4>>1]=b[J+((ah&255|w)<<1)>>1]|0}ah=a[N+14|0]|0;if(!(ah<<24>>24==15|T)){b[S+2>>1]=b[J+((ah&255|w)<<1)>>1]|0}ah=a[N+15|0]|0;if(!(ah<<24>>24!=15&Q&R)){break}b[S>>1]=b[J+((ah&255|w)<<1)>>1]|0}}while(0);if((O|0)>0){S=S-640|0;N=N+16|0;O=O-1|0}else{break}}}}}else{if(z){if(v){O=L;N=K;S=0;while(1){R=a[N]|0;if(R<<24>>24!=15){b[O>>1]=b[J+((R&255|w)<<1)>>1]|0}R=a[N+1|0]|0;if(R<<24>>24!=15){b[O+2>>1]=b[J+((R&255|w)<<1)>>1]|0}R=a[N+2|0]|0;if(R<<24>>24!=15){b[O+4>>1]=b[J+((R&255|w)<<1)>>1]|0}R=a[N+3|0]|0;if(R<<24>>24!=15){b[O+6>>1]=b[J+((R&255|w)<<1)>>1]|0}R=a[N+4|0]|0;if(R<<24>>24!=15){b[O+8>>1]=b[J+((R&255|w)<<1)>>1]|0}R=a[N+5|0]|0;if(R<<24>>24!=15){b[O+10>>1]=b[J+((R&255|w)<<1)>>1]|0}R=a[N+6|0]|0;if(R<<24>>24!=15){b[O+12>>1]=b[J+((R&255|w)<<1)>>1]|0}R=a[N+7|0]|0;if(R<<24>>24!=15){b[O+14>>1]=b[J+((R&255|w)<<1)>>1]|0}R=a[N+8|0]|0;if(R<<24>>24!=15){b[O+16>>1]=b[J+((R&255|w)<<1)>>1]|0}R=a[N+9|0]|0;if(R<<24>>24!=15){b[O+18>>1]=b[J+((R&255|w)<<1)>>1]|0}R=a[N+10|0]|0;if(R<<24>>24!=15){b[O+20>>1]=b[J+((R&255|w)<<1)>>1]|0}R=a[N+11|0]|0;if(R<<24>>24!=15){b[O+22>>1]=b[J+((R&255|w)<<1)>>1]|0}R=a[N+12|0]|0;if(R<<24>>24!=15){b[O+24>>1]=b[J+((R&255|w)<<1)>>1]|0}R=a[N+13|0]|0;if(R<<24>>24!=15){b[O+26>>1]=b[J+((R&255|w)<<1)>>1]|0}R=a[N+14|0]|0;if(R<<24>>24!=15){b[O+28>>1]=b[J+((R&255|w)<<1)>>1]|0}R=a[N+15|0]|0;if(R<<24>>24!=15){b[O+30>>1]=b[J+((R&255|w)<<1)>>1]|0}R=S+1|0;if((R|0)<16){O=O+640|0;N=N+16|0;S=R}else{break}}}else{S=L;N=K;O=0;while(1){R=a[N]|0;if(R<<24>>24!=15){b[S+30>>1]=b[J+((R&255|w)<<1)>>1]|0}R=a[N+1|0]|0;if(R<<24>>24!=15){b[S+28>>1]=b[J+((R&255|w)<<1)>>1]|0}R=a[N+2|0]|0;if(R<<24>>24!=15){b[S+26>>1]=b[J+((R&255|w)<<1)>>1]|0}R=a[N+3|0]|0;if(R<<24>>24!=15){b[S+24>>1]=b[J+((R&255|w)<<1)>>1]|0}R=a[N+4|0]|0;if(R<<24>>24!=15){b[S+22>>1]=b[J+((R&255|w)<<1)>>1]|0}R=a[N+5|0]|0;if(R<<24>>24!=15){b[S+20>>1]=b[J+((R&255|w)<<1)>>1]|0}R=a[N+6|0]|0;if(R<<24>>24!=15){b[S+18>>1]=b[J+((R&255|w)<<1)>>1]|0}R=a[N+7|0]|0;if(R<<24>>24!=15){b[S+16>>1]=b[J+((R&255|w)<<1)>>1]|0}R=a[N+8|0]|0;if(R<<24>>24!=15){b[S+14>>1]=b[J+((R&255|w)<<1)>>1]|0}R=a[N+9|0]|0;if(R<<24>>24!=15){b[S+12>>1]=b[J+((R&255|w)<<1)>>1]|0}R=a[N+10|0]|0;if(R<<24>>24!=15){b[S+10>>1]=b[J+((R&255|w)<<1)>>1]|0}R=a[N+11|0]|0;if(R<<24>>24!=15){b[S+8>>1]=b[J+((R&255|w)<<1)>>1]|0}R=a[N+12|0]|0;if(R<<24>>24!=15){b[S+6>>1]=b[J+((R&255|w)<<1)>>1]|0}R=a[N+13|0]|0;if(R<<24>>24!=15){b[S+4>>1]=b[J+((R&255|w)<<1)>>1]|0}R=a[N+14|0]|0;if(R<<24>>24!=15){b[S+2>>1]=b[J+((R&255|w)<<1)>>1]|0}R=a[N+15|0]|0;if(R<<24>>24!=15){b[S>>1]=b[J+((R&255|w)<<1)>>1]|0}R=O+1|0;if((R|0)<16){S=S+640|0;N=N+16|0;O=R}else{break}}}}else{O=h+(I+4800<<1)|0;if(v){N=O;S=K;R=0;while(1){Q=a[S]|0;if(Q<<24>>24!=15){b[N>>1]=b[J+((Q&255|w)<<1)>>1]|0}Q=a[S+1|0]|0;if(Q<<24>>24!=15){b[N+2>>1]=b[J+((Q&255|w)<<1)>>1]|0}Q=a[S+2|0]|0;if(Q<<24>>24!=15){b[N+4>>1]=b[J+((Q&255|w)<<1)>>1]|0}Q=a[S+3|0]|0;if(Q<<24>>24!=15){b[N+6>>1]=b[J+((Q&255|w)<<1)>>1]|0}Q=a[S+4|0]|0;if(Q<<24>>24!=15){b[N+8>>1]=b[J+((Q&255|w)<<1)>>1]|0}Q=a[S+5|0]|0;if(Q<<24>>24!=15){b[N+10>>1]=b[J+((Q&255|w)<<1)>>1]|0}Q=a[S+6|0]|0;if(Q<<24>>24!=15){b[N+12>>1]=b[J+((Q&255|w)<<1)>>1]|0}Q=a[S+7|0]|0;if(Q<<24>>24!=15){b[N+14>>1]=b[J+((Q&255|w)<<1)>>1]|0}Q=a[S+8|0]|0;if(Q<<24>>24!=15){b[N+16>>1]=b[J+((Q&255|w)<<1)>>1]|0}Q=a[S+9|0]|0;if(Q<<24>>24!=15){b[N+18>>1]=b[J+((Q&255|w)<<1)>>1]|0}Q=a[S+10|0]|0;if(Q<<24>>24!=15){b[N+20>>1]=b[J+((Q&255|w)<<1)>>1]|0}Q=a[S+11|0]|0;if(Q<<24>>24!=15){b[N+22>>1]=b[J+((Q&255|w)<<1)>>1]|0}Q=a[S+12|0]|0;if(Q<<24>>24!=15){b[N+24>>1]=b[J+((Q&255|w)<<1)>>1]|0}Q=a[S+13|0]|0;if(Q<<24>>24!=15){b[N+26>>1]=b[J+((Q&255|w)<<1)>>1]|0}Q=a[S+14|0]|0;if(Q<<24>>24!=15){b[N+28>>1]=b[J+((Q&255|w)<<1)>>1]|0}Q=a[S+15|0]|0;if(Q<<24>>24!=15){b[N+30>>1]=b[J+((Q&255|w)<<1)>>1]|0}Q=R+1|0;if((Q|0)<16){N=N-640|0;S=S+16|0;R=Q}else{break}}}else{R=O;S=K;N=0;while(1){Q=a[S]|0;if(Q<<24>>24!=15){b[R+30>>1]=b[J+((Q&255|w)<<1)>>1]|0}Q=a[S+1|0]|0;if(Q<<24>>24!=15){b[R+28>>1]=b[J+((Q&255|w)<<1)>>1]|0}Q=a[S+2|0]|0;if(Q<<24>>24!=15){b[R+26>>1]=b[J+((Q&255|w)<<1)>>1]|0}Q=a[S+3|0]|0;if(Q<<24>>24!=15){b[R+24>>1]=b[J+((Q&255|w)<<1)>>1]|0}Q=a[S+4|0]|0;if(Q<<24>>24!=15){b[R+22>>1]=b[J+((Q&255|w)<<1)>>1]|0}Q=a[S+5|0]|0;if(Q<<24>>24!=15){b[R+20>>1]=b[J+((Q&255|w)<<1)>>1]|0}Q=a[S+6|0]|0;if(Q<<24>>24!=15){b[R+18>>1]=b[J+((Q&255|w)<<1)>>1]|0}Q=a[S+7|0]|0;if(Q<<24>>24!=15){b[R+16>>1]=b[J+((Q&255|w)<<1)>>1]|0}Q=a[S+8|0]|0;if(Q<<24>>24!=15){b[R+14>>1]=b[J+((Q&255|w)<<1)>>1]|0}Q=a[S+9|0]|0;if(Q<<24>>24!=15){b[R+12>>1]=b[J+((Q&255|w)<<1)>>1]|0}Q=a[S+10|0]|0;if(Q<<24>>24!=15){b[R+10>>1]=b[J+((Q&255|w)<<1)>>1]|0}Q=a[S+11|0]|0;if(Q<<24>>24!=15){b[R+8>>1]=b[J+((Q&255|w)<<1)>>1]|0}Q=a[S+12|0]|0;if(Q<<24>>24!=15){b[R+6>>1]=b[J+((Q&255|w)<<1)>>1]|0}Q=a[S+13|0]|0;if(Q<<24>>24!=15){b[R+4>>1]=b[J+((Q&255|w)<<1)>>1]|0}Q=a[S+14|0]|0;if(Q<<24>>24!=15){b[R+2>>1]=b[J+((Q&255|w)<<1)>>1]|0}Q=a[S+15|0]|0;if(Q<<24>>24!=15){b[R>>1]=b[J+((Q&255|w)<<1)>>1]|0}Q=N+1|0;if((Q|0)<16){R=R-640|0;S=S+16|0;N=Q}else{break}}}}}}while(0);J=x+1|0;if((J|0)>(r|0)){break}else{x=J;F=F+1|0}}F=q+1|0;if((F|0)>(u|0)){break}else{q=F;t=p+t|0}}}t=j+1|0;if((t|0)<1024){j=t}else{o=50608;break}}if((o|0)==50607){return}else if((o|0)==50608){return}}function eaN(d,e){d=d|0;e=e|0;var f=0;if((d&268435200|0)==5286144){f=d&192;if((f|0)==0){b[4854080]=(b[4854080]|0)+1&65535;return}else if((f|0)==192){b[4854080]=0;return}else{return}}if((d|0)==5253632){b[(c[2406638]|0)+2>>1]=e;return}else if((d|0)==5255168){b[c[2394700]>>1]=e;return}else if((d|0)==5254144){b[(c[2406638]|0)+4>>1]=e;return}else if((d|0)==5275648|(d|0)==5275650|(d|0)==5275652|(d|0)==5275654){S4(1,d>>>1&3,e&255);return}else if((d|0)==5251584){b[(c[2406648]|0)+2>>1]=e;return}else if((d|0)==5259264){f=c[3528278]|0;a[f]=(e&65535)>>>8&255;a[f+1|0]=e&255;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12;return}else if((d|0)==5252096){b[(c[2406648]|0)+4>>1]=e;return}else if((d|0)==5253120){b[c[2406638]>>1]=e;return}else if((d|0)==5267456|(d|0)==5267458|(d|0)==5267460|(d|0)==5267462){S4(0,d>>>1&3,e&255);return}else if((d|0)==5254656){b[(c[2406638]|0)+6>>1]=e;return}else if((d|0)==5252608){b[(c[2406648]|0)+6>>1]=e;return}else if((d|0)==5251072){b[c[2406648]>>1]=e;return}else{return}}function eaO(a,b){a=a|0;b=b|0;return}function eaP(a){a=a|0;var b=0,d=0;do{if((a&268435200|0)==5286144){b=e[4854080]|0;if((b&17|0)==1|(b&6|0)==2){d=16;break}d=(b&9|0)==8?16:0}else{if((a|0)==5257216){d=c[2432920]&65535;break}else if((a|0)==5258752){d=c[2432919]&65535;break}else if((a|0)==5267456|(a|0)==5267458|(a|0)==5267460|(a|0)==5267462){d=(S3(0,a>>>1&3)|0)&255;break}else if((a|0)==5275648|(a|0)==5275650|(a|0)==5275652|(a|0)==5275654){d=(S3(1,a>>>1&3)|0)&255;break}else if((a|0)==5258240){d=c[2432918]&65535;break}else if((a|0)==5257728){d=c[2432921]&65535;break}else{d=0;break}}}while(0);return d|0}function eaQ(a){a=a|0;var b=0;if((a|0)==5267457|(a|0)==5267459|(a|0)==5267461|(a|0)==5267463){b=S3(0,a>>>1&3)|0}else if((a|0)==5275649|(a|0)==5275651|(a|0)==5275653|(a|0)==5275655){b=S3(1,a>>>1&3)|0}else{b=0}return b|0}function eaR(b,e){b=b|0;e=e|0;var f=0,g=0,h=0;f=b&65535;if((f|0)==4096|(f|0)==4097){b=c[3540984]|0;if((f&1|0)==0){a[b+5885|0]=e;return}g=c[b+5876>>2]|0;if((g|0)!=0){gg[g&4095](c[b+5880>>2]|0,0)}lH(b,d[b+5885|0]|0,e&255);return}else if((f|0)==24576){b=e&255;g=c[2406702]|0;h=b&2;if((a[g]|0)==(h|0)){return}a[g]=h&255;h=c[3529758]|0;g=h+(b<<18&524288|262144)|0;gGC(h|0,g|0,262144)|0;return}else if((f|0)==28675|(f|0)==28676|(f|0)==28677){g=f&3;if((g|0)==2){Vy(gj[c[2426988]&4095](a[9680]|0?32e3:0)|0);mp(e);return}else if((g|0)==0){Vy(gj[c[2426988]&4095](a[9680]|0?32e3:0)|0);mo(e);return}else{return}}else if((f|0)==8192){Uv(0,e);return}else if((f|0)==29696){Uv(0,e);return}else if((f|0)==28672|(f|0)==28673|(f|0)==28674){g=f&3;if((g|0)==0){a[14127336]=e;return}else if((g|0)==1){a[14127337]=e;return}else if((g|0)==2){a[14127338]=e;return}else{return}}else if((f|0)==30720){Uv(1,e);return}else{return}}function eaS(b){b=b|0;var d=0,e=0;d=b&65535;if((d|0)==30720){e=c[2113157]&255;return e|0}else if((d|0)==16384){e=a[(c[3528278]|0)+1|0]|0;return e|0}else if((d|0)==8192){e=c[2113156]&255;return e|0}else if((d|0)==12288){e=a[c[3528278]|0]|0;return e|0}else if((d|0)==28672){Vy(gj[c[2426988]&4095](a[9680]|0?32e3:0)|0);e=((c[3531833]|0)==1?-128:0)|a[14127331];return e|0}else if((d|0)==29696){e=c[2113156]&255;return e|0}else{e=0;return e|0}return 0}function eaT(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4571692+(b*112|0)>>2];c[a+104>>2]=c[4571696+(b*112|0)>>2];c[a+108>>2]=c[4571700+(b*112|0)>>2];d=0;return d|0}function eaU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=4571592+(b*112|0);e=0;return e|0}function eaV(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1844064+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eaW(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5299560+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eaX(){return ebb(1146,1)|0}function eaY(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;i=i+128|0;d=b|0;c[2113070]=0;c[2113068]=0;e=c[2112926]|0;if((e|0)!=0){gGr(e);c[2112926]=0}c[2438228]=0;c[2433526]=0;c[2406676]=0;c[3528472]=0;e=c[2406678]|0;if((e|0)!=0){gGr(e);c[2406678]=0}e=a[7452584]|0;if(e){f=0;g=e&1;while(1){e=14163936+(f<<2)|0;h=c[e>>2]|0;j=c[2113006]|0;if((j|0)==0){k=50745}else{l=j-1|0;c[2113006]=l;if((l|0)==0){k=50745}}if((k|0)==50745){k=0;c[2383474]=0}if((h|0)==0){m=g}else{gGr(h);m=a[7452584]&1}c[e>>2]=0;e=f+1|0;if((e|0)<(m|0)){f=e;g=m}else{break}}}a[7452584]=0;c[2438224]=0;c[2433522]=0;c[2406672]=0;c[3528468]=0;m=c[2406688]|0;if((m|0)!=0){gGr(m);c[2406688]=0}c[2432972]=0;Uw(0);Uw(1);gGz(9668984,0,81);c[3540906]=0;c[3540904]=0;c[3540902]=0;c[3540900]=0;c[3540898]=0;c[3540896]=0;c[3540894]=0;c[3540892]=0;c[3540890]=0;c[3540888]=0;c[3540886]=0;c[3540884]=0;c[3540882]=0;c[2113302]=0;a[801640]=0;c[2440576]=0;c[2440574]=0;gGz(14168784,0,16);gGz(14168768,0,16);if((c[2392]|0)>=0){m=0;do{g=14130368+(m<<2)|0;f=c[g>>2]|0;if((f|0)!=0){gGr(f);c[g>>2]=0}g=14130384+(m<<2)|0;f=c[g>>2]|0;if((f|0)!=0){gGr(f);c[g>>2]=0}m=m+1|0;}while((m|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;fwZ();m=d|0;d=c[c[642608+(c[2436]<<2)>>2]>>2]|0;be(m|0,128,179600,(g=i,i=i+24|0,c[g>>2]=9374064,c[g+8>>2]=47,c[g+16>>2]=d,g)|0)|0;i=g;a[1040128]=0;g=c[2420380]|0;d=c[g>>2]|0;f=c[g+4>>2]|0;g=fw(m|0,389440)|0;if((g|0)!=0){m=f>>3<<d&1023;cj(14100392,m|0,1,g|0)|0;aY(g|0)|0}g=c[2414962]|0;m=0;while(1){if((m|0)>=1024){k=50765;break}n=9638528+(m<<2)|0;if((c[n>>2]|0)==(g|0)){break}else{m=m+1|0}}if((k|0)==50765){c[2414962]=0;i=b;return 0}gGr(g);c[n>>2]=0;c[2414962]=0;i=b;return 0}function eaZ(){var d=0,e=0,f=0,g=0,h=0,i=0;if((a[9624152]|0)!=0){ebp()}ebr();d=c[2392]|0;if((d|0)>=0){gGz(8452240,0,((d|0)>0?(d<<2)+4|0:4)|0)}c[2113054]=0;d=c[2385548]|0;if((d|0)>0){gGz(9752472,0,((d|0)>1?d<<2:4)|0)}c[2433530]=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}d=c[2439330]|0;if((d|0)!=0){e=d;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;e=0;d=0;while(1){f=d+1|0;g=((f*166666|0|0)/50|0)-e|0;c[2113056]=g;h=RG(g)|0;c[2113054]=(c[2113054]|0)+h;c[2276108]=-1;c[2113056]=-1;g=h+e|0;do{if((d|0)==49){c[8452200+(c[2394]<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0>=1024){break}RH(4)}}while(0);UF(d*1666|0)|0;if((f|0)<50){e=g;d=f}else{break}}d=c[2438224]|0;e=gGS(1163526144,39736,d,(d|0)<0|0?-1:0)|0;d=e;UF(83333)|0;e=c[2443826]|0;if((e|0)<1073676288){c[2443826]=e-d}e=c[2443827]|0;if((e|0)<1073676288){c[2443827]=e-d}e=(c[3528508]|0)-d|0;c[3528508]=(e|0)<0?0:e;e=c[2112964]|0;if((e|0)!=0){gg[c[3542112]&4095](e,a[9688]|0?534:0);Uu(0,c[2112964]|0,a[9688]|0?534:0)}e=c[1836236]|0;d=c[9757320+(e<<2)>>2]|0;if((d|0)!=0){h=d;gGC(h|0,9706056,76)|0}c[9752472+(e<<2)>>2]=c[2433530];c[14113936+(e<<2)>>2]=c[2076596];c[9669104+(e<<2)>>2]=c[3541536];c[1836236]=-1;e=c[2394]|0;h=c[14130368+(e<<2)>>2]|0;if((h|0)!=0){gGC(h|0,9104152,280)|0}c[8452240+(e<<2)>>2]=c[2113054];c[2394]=-1;if((c[2112968]|0)==0){return 0}ea6()|0;e=(c[642608+(c[2436]<<2)>>2]|0)+56|0;if((c[e>>2]|0)>0){i=0}else{return 0}do{R7(i,c[14168784+(i<<2)>>2]>>8,c[14168768+(i<<2)>>2]>>8);i=i+1|0;}while((i|0)<(c[e>>2]|0));return 0}function ea_(){var a=0,b=0;ea6()|0;a=(c[642608+(c[2436]<<2)>>2]|0)+56|0;if((c[a>>2]|0)>0){b=0}else{return 0}do{R7(b,c[14168784+(b<<2)>>2]>>8,c[14168768+(b<<2)>>2]>>8);b=b+1|0;}while((b|0)<(c[a>>2]|0));return 0}function ea$(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;e=i;i=i+272|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;l=e+80|0;m=e+96|0;n=e+112|0;o=e+128|0;p=e+144|0;q=e+160|0;r=e+176|0;s=e+192|0;t=e+208|0;u=e+224|0;v=e+240|0;w=e+256|0;x=(d|0)==0;if(!x){c[d>>2]=169736}if((b&96|0)!=0){gGz(w|0,0,12);y=c[2414666]|0;c[w>>2]=y;c[w+4>>2]=(c[2411656]|0)-y;c[w+12>>2]=196728;y=c[2076592]|0;gj[y&4095](w)|0;w=o|0;y=(b&64|0)==0;do{if(!y){gGz(n|0,0,16);c[2394]=-1;if((c[2392]|0)<0){break}z=o+9|0;A=m;B=m|0;C=m+4|0;D=m+12|0;E=n|0;F=n+4|0;G=n+12|0;H=0;do{gGC(w|0,614896,11)|0;a[z]=H+48&255;I=8452256+(H<<2)|0;gGz(A|0,0,12);c[B>>2]=I;c[C>>2]=4;c[D>>2]=164976;gj[c[2076592]&4095](m)|0;if((c[I>>2]|0)!=0){c[E>>2]=c[14130368+(H<<2)>>2];c[F>>2]=c[8452184+(H<<2)>>2];c[G>>2]=w;I=c[2076592]|0;gj[I&4095](n)|0}H=H+1|0;}while((H|0)<=(c[2392]|0))}}while(0);fw$(b);do{if(!x){if((c[d>>2]|0)>=169249){break}c[d>>2]=169249}}while(0);if(!y){gGz(l|0,0,12);c[l>>2]=9775320;c[l+4>>2]=8;c[l+12>>2]=111920;y=c[2076592]|0;gj[y&4095](l)|0;gGz(k|0,0,12);c[k>>2]=9775288;c[k+4>>2]=8;c[k+12>>2]=478936;l=c[2076592]|0;gj[l&4095](k)|0;gGz(j|0,0,12);c[j>>2]=53400;c[j+4>>2]=8;c[j+12>>2]=398448;k=c[2076592]|0;gj[k&4095](j)|0;gGz(h|0,0,12);c[h>>2]=14114048;c[h+4>>2]=4;c[h+12>>2]=287368;j=c[2076592]|0;gj[j&4095](h)|0}gGz(g|0,0,12);c[g>>2]=14168784;c[g+4>>2]=16;c[g+12>>2]=249744;h=c[2076592]|0;gj[h&4095](g)|0;gGz(f|0,0,12);c[f>>2]=14168768;c[f+4>>2]=16;c[f+12>>2]=524320;g=c[2076592]|0;gj[g&4095](f)|0;Ts(b,d);gGz(v|0,0,12);c[v>>2]=9732448;c[v+4>>2]=1;c[v+12>>2]=562992;d=c[2076592]|0;gj[d&4095](v)|0;gGz(u|0,0,12);c[u>>2]=9718480;c[u+4>>2]=1;c[u+12>>2]=561360;v=c[2076592]|0;gj[v&4095](u)|0;gGz(t|0,0,12);c[t>>2]=9708160;c[t+4>>2]=2;c[t+12>>2]=560136;u=c[2076592]|0;gj[u&4095](t)|0;gGz(s|0,0,12);c[s>>2]=9731680;c[s+4>>2]=4;c[s+12>>2]=558704;t=c[2076592]|0;gj[t&4095](s)|0;gGz(r|0,0,12);c[r>>2]=9731672;c[r+4>>2]=4;c[r+12>>2]=557288;s=c[2076592]|0;gj[s&4095](r)|0;gGz(q|0,0,12);c[q>>2]=9731684;c[q+4>>2]=4;c[q+12>>2]=556e3;r=c[2076592]|0;gj[r&4095](q)|0;gGz(p|0,0,12);c[p>>2]=9731676;c[p+4>>2]=4;c[p+12>>2]=554488;q=c[2076592]|0;gj[q&4095](p)|0}if((b&2|0)==0){i=e;return 0}b=c[2406702]|0;p=a[b]|0;a[b]=-1;q=p&2;a[b]=q;b=c[3529758]|0;p=b+((q&255)<<18|262144)|0;gGC(b|0,p|0,262144)|0;i=e;return 0}function ea0(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3168116+(b*112|0)>>2];c[a+104>>2]=c[3168120+(b*112|0)>>2];c[a+108>>2]=c[3168124+(b*112|0)>>2];d=0;return d|0}function ea1(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=3168016+(b*112|0);e=0;return e|0}function ea2(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>29){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1325864+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function ea3(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>66){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4291392+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function ea4(){return ebb(2154,0)|0}function ea5(){var d=0,e=0,f=0,g=0,h=0;if((a[9624152]|0)!=0){ebp()}ebr();d=c[2392]|0;if((d|0)>=0){gGz(8452240,0,((d|0)>0?(d<<2)+4|0:4)|0)}c[2113054]=0;d=c[2385548]|0;if((d|0)>0){gGz(9752472,0,((d|0)>1?d<<2:4)|0)}c[2433530]=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}d=c[2439330]|0;if((d|0)!=0){e=d;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;e=0;d=0;while(1){f=d+1|0;g=((f*166666|0|0)/1e3|0)-e|0;c[2113056]=g;h=RG(g)|0;c[2113054]=(c[2113054]|0)+h;c[2276108]=-1;c[2113056]=-1;g=h+e|0;do{if((d|0)==999){c[8452200+(c[2394]<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0>=1024){break}RH(4)}}while(0);Sb(d*83|0);if((f|0)<1e3){e=g;d=f}else{break}}d=c[2438228]|0;e=gGS(1163526144,39736,d,(d|0)<0|0?-1:0)|0;d=e;Sb(83333);e=c[2443830]|0;if((e|0)<1073676288){c[2443830]=e-d}e=c[2443831]|0;if((e|0)<1073676288){c[2443831]=e-d}e=(c[3528512]|0)-d|0;c[3528512]=(e|0)<0?0:e;e=c[2112964]|0;if((e|0)!=0){d=a[9688]|0?534:0;Vy(d);Uu(0,e,d);Uu(1,e,d)}d=c[1836236]|0;e=c[9757320+(d<<2)>>2]|0;if((e|0)!=0){h=e;gGC(h|0,9706056,76)|0}c[9752472+(d<<2)>>2]=c[2433530];c[14113936+(d<<2)>>2]=c[2076596];c[9669104+(d<<2)>>2]=c[3541536];c[1836236]=-1;d=c[2394]|0;h=c[14130368+(d<<2)>>2]|0;if((h|0)!=0){gGC(h|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;if((c[2112968]|0)==0){return 0}ea6()|0;return 0}function ea6(){var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0;f=i;i=i+16|0;g=f|0;h=c[2387196]|0;j=c[3530004]|0;k=0;do{l=e[h+(k<<1)>>1]|0;m=l>>>4&15;n=l>>>8;c[j+(k<<2)>>2]=(n&8|n<<4)>>>3&31|(l&8|l<<4)<<8&63488|(m<<4|m)<<3&2016;k=k+1|0;}while((k|0)<2048);c[j+8192>>2]=65535;k=(a[9718480]|0)==0;h=c[2113068]|0;m=c[2113070]|0;l=ag(m,h)|0;n=(l|0)>0;if(!k){if(n){k=c[2112926]|0;o=0;do{b[k+(o<<1)>>1]=2048;o=o+1|0;}while((o|0)<(l|0))}R8(j);i=f;return 0}if(n){n=c[3525358]|0;o=c[3525357]|0;k=c[3525356]|0;p=c[3525355]|0;q=c[3525354]|0;r=0;do{b[n+(r<<1)>>1]=63;b[o+(r<<1)>>1]=63;b[k+(r<<1)>>1]=63;b[p+(r<<1)>>1]=63;b[q+(r<<1)>>1]=63;r=r+1|0;}while((r|0)<(l|0))}l=c[2386734]|0;r=l;q=m<<1;p=l+2|0;l=0;while(1){if((l|0)>=(q|0)){s=50911;break}if(((b[p>>1]^b[r+((l|1)<<1)>>1])&2047)==0){l=l+2|0}else{s=50897;break}}L67409:do{if((s|0)==50897){l=c[3530842]|0;ebq(c[3529468]|0,l,8,256,64,1280,3,0);p=c[3529434]|0;if((m|0)<=0){t=l;break}q=(c[2406638]|0)+2|0;k=(c[2406648]|0)+2|0;o=c[3530606]|0;n=c[2439512]|0;u=0;v=c[3525355]|0;while(1){w=(e[q>>1]|0)+u|0;if((h+16|0)>0){x=r+((u<<1|1)<<1)|0;y=w>>>4<<7&3968;z=w<<4&240;w=z^240;A=0;do{B=(e[k>>1]|0)+A+(e[x>>1]|0)|0;C=(B>>>4&127|y)<<1;D=b[p+(C<<1)>>1]|0;E=D&65535;F=e[p+((C|1)<<1)>>1]<<8&8388352|((E&16384|0)==0?z:w);L67418:do{if((a[n+(F>>>4)|0]|0)==0){C=(E&32768|0)==0?0:15;G=D<<2&448|(D&65535)>>>9<<11&14336;H=0;I=A-(B&15)|0;while(1){do{if((I|0)>-1&(I|0)<(h|0)){J=a[o+((H^C)+F)|0]|0;if(J<<24>>24==63){break}b[v+(I<<1)>>1]=G|J&255|1536}}while(0);J=H+1|0;if((J|0)>=16){break L67418}H=J;I=I+1|0}}}while(0);A=A+16|0;}while((A|0)<(h+16|0))}A=u+1|0;if((A|0)>=(m|0)){t=l;break L67409}u=A;v=v+(h<<1)|0}}else if((s|0)==50911){v=c[3530842]|0;ebq(c[3529468]|0,v,8,256,64,1280,3,0);ebq(c[3529434]|0,c[3530606]|0,16,128,32,1536,7,1);t=v}}while(0);ebq(c[3529408]|0,c[3530430]|0,32,64,16,1792,3,2);ebq(c[3529402]|0,t,8,64,32,1024,15,3);t=c[2386456]|0;s=c[2439511]|0;r=c[3525358]|0;v=c[3530334]|0;u=0;do{l=e[t+((u|1)<<1)>>1]|0;if((l&256|0)!=0){break}o=e[t+(u<<1)>>1]|0;n=l&32768;p=l&16384;k=l&15;q=k+1|0;A=o>>>12;w=(n|0)!=0;z=(n>>>14^2)-1|0;n=w?-1:q;y=w?k:0;k=(p|0)!=0;x=(p>>>13^2)-1|0;p=k?-1:A+1|0;F=(e[t+((u|3)<<1)>>1]|0)-24|0;B=(o&2047)-(o&2048)|0;o=-(q<<4)|1;q=(l>>>9<<5&224|l>>>4&15)<<6;l=e[t+((u|2)<<1)>>1]|0;D=k?A:0;while(1){A=(D<<4)+B|0;E=ag(h,A+15|0)|0;I=ag(h,A)|0;H=l;G=y;do{do{if((a[s+H|0]|0)==0){C=F+(G<<4)|0;J=v+(H<<8)|0;c[2112928]=J;if(k){K=r+(E+C<<1)|0;if(!w){L=K;M=15;N=J;while(1){O=M+A|0;if((O|0)>=(m|0)|(O|0)<0){P=N}else{O=0;while(1){Q=O+C|0;do{if((Q|0)>-1&(Q|0)<(h|0)){R=a[N+O|0]|0;if(R<<24>>24==63){break}b[L+(O<<1)>>1]=(R&255|q)&65535}}while(0);Q=O+1|0;if((Q|0)<16){O=Q}else{P=N;break}}}S=P+16|0;if((M|0)<=0){break}L=L+(-h<<1)|0;M=M-1|0;N=S}c[2112928]=S;break}N=C+16|0;M=K;L=15;O=J;while(1){Q=L+A|0;if((Q|0)>=(m|0)|(Q|0)<0){T=O}else{Q=0;R=0;while(1){U=N+R|0;do{if((U|0)>0&(U-1|0)<(h|0)){V=a[O+Q|0]|0;if(V<<24>>24==63){break}b[M+(R+15<<1)>>1]=(V&255|q)&65535}}while(0);U=Q+1|0;V=~Q;if((U|0)<16){Q=U;R=V}else{T=O;break}}}W=T+16|0;if((L|0)<=0){break}M=M+(-h<<1)|0;L=L-1|0;O=W}c[2112928]=W;break}else{O=r+(I+C<<1)|0;if(!w){L=O;M=0;N=J;while(1){K=M+A|0;if((K|0)>=(m|0)|(K|0)<0){X=N}else{K=0;while(1){R=K+C|0;do{if((R|0)>-1&(R|0)<(h|0)){Q=a[N+K|0]|0;if(Q<<24>>24==63){break}b[L+(K<<1)>>1]=(Q&255|q)&65535}}while(0);R=K+1|0;if((R|0)<16){K=R}else{X=N;break}}}K=M+1|0;Y=X+16|0;if((K|0)>=16){break}L=L+(h<<1)|0;M=K;N=Y}c[2112928]=Y;break}N=C+16|0;M=O;L=0;K=J;while(1){R=L+A|0;if((R|0)>=(m|0)|(R|0)<0){Z=K}else{R=0;Q=0;while(1){V=N+Q|0;do{if((V|0)>0&(V-1|0)<(h|0)){U=a[K+R|0]|0;if(U<<24>>24==63){break}b[M+(Q+15<<1)>>1]=(U&255|q)&65535}}while(0);V=R+1|0;U=~R;if((V|0)<16){R=V;Q=U}else{Z=K;break}}}Q=L+1|0;_=Z+16|0;if((Q|0)>=16){break}M=M+(h<<1)|0;L=Q;K=_}c[2112928]=_;break}}}while(0);G=z+G|0;H=H+16|0;}while((G|0)!=(n|0));G=x+D|0;if((G|0)==(p|0)){break}else{l=H+o|0;D=G}}u=u+4|0;}while((u|0)<1024);u=c[2387040]|0;if((m|0)>0){_=g+2|0;Z=g+8|0;Y=g|0;X=g+6|0;W=g+4|0;T=c[2112926]|0;S=0;P=c[3525354]|0;v=c[3525355]|0;s=c[3525356]|0;t=c[3525357]|0;D=r;while(1){if((h|0)>0){r=T;o=1;l=P;p=v;x=s;n=t;z=D;while(1){q=l+2|0;w=b[l>>1]|0;b[Y>>1]=w;k=w<<16>>16==63|0;F=p+2|0;y=b[p>>1]|0;b[_>>1]=y;B=y<<16>>16==63?k|2:k;k=x+2|0;G=b[x>>1]|0;b[W>>1]=G;A=G<<16>>16==63?B|4:B;B=n+2|0;G=b[n>>1]|0;b[X>>1]=G;I=G<<16>>16==63?A|16:A;A=z+2|0;E=b[z>>1]|0;b[Z>>1]=E;K=r+2|0;b[r>>1]=b[g+(d[614064+(b[u+((((y&65535)>>>11<<5|w&30720|(G&65535)>>>11<<14|(E&65535)>>>11<<8|(E<<16>>16==63?I|8:I))&32767)<<1)>>1]&7)|0]<<1)>>1]&2047;if((o|0)<(h|0)){r=K;o=o+1|0;l=q;p=F;x=k;n=B;z=A}else{$=K;aa=q;ab=F;ac=k;ad=B;ae=A;break}}}else{$=T;aa=P;ab=v;ac=s;ad=t;ae=D}z=S+1|0;if((z|0)<(m|0)){T=$;S=z;P=aa;v=ab;s=ac;t=ad;D=ae}else{break}}}R8(j);i=f;return 0}function ea7(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1619236+(b*112|0)>>2];c[a+104>>2]=c[1619240+(b*112|0)>>2];c[a+108>>2]=c[1619244+(b*112|0)>>2];d=0;return d|0}function ea8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=1619136+(b*112|0);e=0;return e|0}function ea9(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=66){if((a|0)==0){d=0;return d|0}e=a;f=4291392+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}if((b|0)!=67){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;c[b>>2]=c[511914];c[b+4>>2]=c[511915];c[b+8>>2]=c[511916];d=0;return d|0}function eba(){return ebb(616,0)|0}function ebb(e,f){e=e|0;f=f|0;var g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0;g=i;i=i+344|0;j=g|0;k=g+24|0;l=g+88|0;m=g+216|0;c[2414962]=0;c[2388152]=0;c[2385924]=2097152;c[3530842]=2162688;c[3530606]=6356992;c[3530430]=14745600;c[3530334]=23134208;c[2439508]=39911424;c[2439509]=39976960;c[2439510]=40009728;c[2439511]=40017920;c[2439512]=40083456;c[3541206]=40607744;c[3529758]=40607744;c[3529712]=41656320;c[3529690]=41918464;c[3530004]=44015616;c[3525354]=44023812;c[3525355]=44238852;c[3525356]=44453892;c[3525357]=44668932;c[3525358]=44883972;c[2414666]=45099012;c[2388278]=45099012;c[2387040]=45164548;c[3529468]=45230084;c[3529434]=45295620;c[3529408]=45312004;c[3529402]=45328388;c[2386734]=45336580;c[2386456]=45338628;c[3529854]=45340676;c[2387196]=45341700;c[2386078]=45345796;c[2406648]=45349892;c[2406638]=45349900;c[2394700]=45349908;c[3528278]=45349910;c[2406702]=45349912;c[2411656]=45349913;n=0;while(1){if((n|0)>=1024){break}o=9638528+(n<<2)|0;if((c[o>>2]|0)==0){p=50994;break}else{n=n+1|0}}do{if((p|0)==50994){n=gGq(45349913)|0;c[o>>2]=n;if((n|0)==0){break}c[2414962]=n;gGz(n|0,0,45349913);c[2388152]=n;c[2385924]=n+2097152;q=n+2162688|0;c[3530842]=q;c[3530606]=n+6356992;c[3530430]=n+14745600;c[3530334]=n+23134208;c[2439508]=n+39911424;c[2439509]=n+39976960;c[2439510]=n+40009728;c[2439511]=n+40017920;c[2439512]=n+40083456;r=n+40607744|0;c[3541206]=r;c[3529758]=r;c[3529712]=n+41656320;c[3529690]=n+41918464;c[3530004]=n+44015616;c[3525354]=n+44023812;c[3525355]=n+44238852;c[3525356]=n+44453892;c[3525357]=n+44668932;c[3525358]=n+44883972;r=n+45099012|0;c[2414666]=r;c[2388278]=r;c[2387040]=n+45164548;c[3529468]=n+45230084;c[3529434]=n+45295620;c[3529408]=n+45312004;c[3529402]=n+45328388;c[2386734]=n+45336580;c[2386456]=n+45338628;c[3529854]=n+45340676;c[2387196]=n+45341700;c[2386078]=n+45345796;c[2406648]=n+45349892;c[2406638]=n+45349900;c[2394700]=n+45349908;c[3528278]=n+45349910;c[2406702]=n+45349912;r=n+45349913|0;c[2411656]=r;c[2414196]=r;do{if((e|0)==0){s=q}else{if((gD[e&8191]()|0)==0){s=c[3530842]|0;break}else{t=1;i=g;return t|0}}}while(0);q=k;r=l;n=m;u=j|0;c[u>>2]=16777224;v=j+4|0;c[v>>2]=16777216;w=j+8|0;c[w>>2]=8388616;x=j+12|0;c[x>>2]=8388608;y=j+16|0;c[y>>2]=8;z=j+20|0;c[z>>2]=0;gGC(q|0,6669416,64)|0;gGC(r|0,613880,128)|0;gGC(n|0,609168,128)|0;A=0;while(1){if((A|0)>=1024){break}B=9638528+(A<<2)|0;if((c[B>>2]|0)==0){p=51002;break}else{A=A+1|0}}L67555:do{if((p|0)==51002){A=gGq(3145728)|0;c[B>>2]=A;if((A|0)==0){break}gGz(A|0,0,3145728);gGC(A|0,s|0,3145728)|0;C=0;while(1){D=C<<6;gGz(s+D|0,0,64);E=C<<7;F=0;do{G=1<<5-F;H=(c[j+(F<<2)>>2]|0)+E|0;I=0;do{J=H+(c[m+(I<<2)>>2]|0)|0;K=(I<<3)+D|0;L=0;do{M=J+(c[k+(L<<2)>>2]|0)|0;if((d[A+((M|0)/8|0)|0]&128>>>((M&7)>>>0)|0)!=0){M=s+(K+L)|0;a[M]=(d[M]|G)&255}L=L+1|0;}while((L|0)<8);I=I+1|0;}while((I|0)<8);F=F+1|0;}while((F|0)<6);F=C+1|0;if((F|0)<65536){C=F}else{N=0;break}}while(1){if((N|0)>=1024){break L67555}O=9638528+(N<<2)|0;if((c[O>>2]|0)==(A|0)){break}else{N=N+1|0}}gGr(A);c[O>>2]=0}}while(0);C=c[3530430]|0;F=c[3530606]|0;c[u>>2]=33554440;c[v>>2]=33554432;c[w>>2]=16777224;c[x>>2]=16777216;c[y>>2]=8;c[z>>2]=0;gGC(q|0,6669416,64)|0;gGC(r|0,613880,128)|0;gGC(n|0,609168,128)|0;D=0;while(1){if((D|0)>=1024){break}P=9638528+(D<<2)|0;if((c[P>>2]|0)==0){p=51019;break}else{D=D+1|0}}L67580:do{if((p|0)==51019){D=gGq(6291456)|0;c[P>>2]=D;if((D|0)==0){break}gGz(D|0,0,6291456);gGC(D|0,C|0,6291456)|0;E=0;while(1){I=E<<8;gGz(F+I|0,0,256);G=E<<9;H=0;do{L=1<<5-H;K=(c[j+(H<<2)>>2]|0)+G|0;J=0;do{M=K+(c[m+(J<<2)>>2]|0)|0;Q=(J<<4)+I|0;R=0;do{S=M+(c[k+(R<<2)>>2]|0)|0;if((d[D+((S|0)/8|0)|0]&128>>>((S&7)>>>0)|0)!=0){S=F+(Q+R)|0;a[S]=(d[S]|L)&255}R=R+1|0;}while((R|0)<16);J=J+1|0;}while((J|0)<16);H=H+1|0;}while((H|0)<6);H=E+1|0;if((H|0)<32768){E=H}else{T=0;break}}while(1){if((T|0)>=1024){break L67580}U=9638528+(T<<2)|0;if((c[U>>2]|0)==(D|0)){break}else{T=T+1|0}}gGr(D);c[U>>2]=0}}while(0);F=c[3530430]|0;c[u>>2]=33554440;c[v>>2]=33554432;c[w>>2]=16777224;c[x>>2]=16777216;c[y>>2]=8;c[z>>2]=0;gGC(q|0,6669416,64)|0;gGC(r|0,613880,128)|0;gGC(n|0,609168,128)|0;C=0;while(1){if((C|0)>=1024){break}V=9638528+(C<<2)|0;if((c[V>>2]|0)==0){p=51036;break}else{C=C+1|0}}L67605:do{if((p|0)==51036){C=gGq(6291456)|0;c[V>>2]=C;if((C|0)==0){break}gGz(C|0,0,6291456);gGC(C|0,F|0,6291456)|0;E=0;while(1){A=E<<10;gGz(F+A|0,0,1024);H=E<<11;I=0;do{G=1<<5-I;J=(c[j+(I<<2)>>2]|0)+H|0;L=0;do{K=J+(c[m+(L<<2)>>2]|0)|0;R=(L<<5)+A|0;Q=0;do{M=K+(c[l+(Q<<2)>>2]|0)|0;if((d[C+((M|0)/8|0)|0]&128>>>((M&7)>>>0)|0)!=0){M=F+(R+Q)|0;a[M]=(d[M]|G)&255}Q=Q+1|0;}while((Q|0)<32);L=L+1|0;}while((L|0)<32);I=I+1|0;}while((I|0)<6);I=E+1|0;if((I|0)<8192){E=I}else{W=0;break}}while(1){if((W|0)>=1024){break L67605}X=9638528+(W<<2)|0;if((c[X>>2]|0)==(C|0)){break}else{W=W+1|0}}gGr(C);c[X>>2]=0}}while(0);F=c[3530334]|0;c[u>>2]=67108872;c[v>>2]=67108864;c[w>>2]=33554440;c[x>>2]=33554432;c[y>>2]=8;c[z>>2]=0;gGC(q|0,6669416,64)|0;gGC(r|0,613880,128)|0;gGC(n|0,609168,128)|0;E=0;while(1){if((E|0)>=1024){break}Y=9638528+(E<<2)|0;if((c[Y>>2]|0)==0){p=51053;break}else{E=E+1|0}}L67630:do{if((p|0)==51053){E=gGq(12582912)|0;c[Y>>2]=E;if((E|0)==0){break}gGz(E|0,0,12582912);gGC(E|0,F|0,12582912)|0;n=0;while(1){r=n<<8;gGz(F+r|0,0,256);q=n<<9;z=0;do{y=1<<5-z;x=(c[j+(z<<2)>>2]|0)+q|0;w=0;do{v=x+(c[m+(w<<2)>>2]|0)|0;u=(w<<4)+r|0;D=0;do{I=v+(c[k+(D<<2)>>2]|0)|0;if((d[E+((I|0)/8|0)|0]&128>>>((I&7)>>>0)|0)!=0){I=F+(u+D)|0;a[I]=(d[I]|y)&255}D=D+1|0;}while((D|0)<16);w=w+1|0;}while((w|0)<16);z=z+1|0;}while((z|0)<6);z=n+1|0;if((z|0)<65536){n=z}else{Z=0;break}}while(1){if((Z|0)>=1024){break L67630}_=9638528+(Z<<2)|0;if((c[_>>2]|0)==(E|0)){break}else{Z=Z+1|0}}gGr(E);c[_>>2]=0}}while(0);F=c[3530842]|0;n=c[2439508]|0;C=0;do{z=n+((C|0)/64|0)|0;a[z]=1;r=0;while(1){if((r|0)>=64){break}if((a[F+(r+C)|0]|0)==63){r=r+1|0}else{p=51071;break}}if((p|0)==51071){p=0;a[z]=0}C=C+64|0;}while((C|0)<4194304);C=c[3530606]|0;F=c[2439509]|0;n=0;do{r=F+((n|0)/256|0)|0;a[r]=1;E=0;while(1){if((E|0)>=256){break}if((a[C+(E+n)|0]|0)==63){E=E+1|0}else{p=51077;break}}if((p|0)==51077){p=0;a[r]=0}n=n+256|0;}while((n|0)<8388608);n=c[3530430]|0;F=c[2439510]|0;E=0;do{z=F+((E|0)/1024|0)|0;a[z]=1;q=0;while(1){if((q|0)>=1024){break}if((a[n+(q+E)|0]|0)==63){q=q+1|0}else{p=51083;break}}if((p|0)==51083){p=0;a[z]=0}E=E+1024|0;}while((E|0)<8388608);E=c[3530334]|0;n=c[2439511]|0;F=0;do{q=n+((F|0)/256|0)|0;a[q]=1;r=0;while(1){if((r|0)>=256){break}if((a[E+(r+F)|0]|0)==63){r=r+1|0}else{p=51089;break}}if((p|0)==51089){p=0;a[q]=0}F=F+256|0;}while((F|0)<16777216);F=c[2439512]|0;E=0;do{n=F+((E|0)/16|0)|0;a[n]=1;r=0;while(1){if((r|0)>=16){break}if((a[C+(r+E)|0]|0)==63){r=r+1|0}else{p=51095;break}}if((p|0)==51095){p=0;a[n]=0}E=E+16|0;}while((E|0)<8388608);fxU(0,425984);if((c[2394]|0)==0){$=c[2112932]|0}else{c[2394]=0;E=c[3532596]|0;c[2112932]=E;C=c[3532592]|0;if((C|0)!=0){gGC(9104152,C|0,280)|0}c[2113054]=c[2113060];$=E}E=c[2388152]|0;C=$|0;F=0;while(1){r=E+F|0;c[C>>2]=r;c[C+131072>>2]=r;r=F+1024|0;if(r>>>0>2097151){break}else{C=C+4|0;F=r}}F=c[2388278]|0;C=$+8192|0;E=2097152;while(1){r=F+(E-2097152)|0;c[C>>2]=r;c[C+65536>>2]=r;c[C+131072>>2]=r;r=E+1024|0;if(r>>>0>2162687){break}else{C=C+4|0;E=r}}E=c[2387040]|0;C=$+8448|0;F=2162688;while(1){r=E+(F-2162688)|0;c[C>>2]=r;c[C+65536>>2]=r;c[C+131072>>2]=r;r=F+1024|0;if(r>>>0>2228223){break}else{C=C+4|0;F=r}}F=c[3529468]|0;C=$+12288|0;E=3145728;while(1){r=F+(E-3145728)|0;c[C>>2]=r;c[C+65536>>2]=r;c[C+131072>>2]=r;r=E+1024|0;if(r>>>0>3211263){break}else{C=C+4|0;E=r}}E=c[3529434]|0;c[$+12544>>2]=E;c[$+78080>>2]=E;c[$+143616>>2]=E;C=E+1024|0;c[$+12548>>2]=C;c[$+78084>>2]=C;c[$+143620>>2]=C;C=E+2048|0;c[$+12552>>2]=C;c[$+78088>>2]=C;c[$+143624>>2]=C;C=E+3072|0;c[$+12556>>2]=C;c[$+78092>>2]=C;c[$+143628>>2]=C;C=E+4096|0;c[$+12560>>2]=C;c[$+78096>>2]=C;c[$+143632>>2]=C;C=E+5120|0;c[$+12564>>2]=C;c[$+78100>>2]=C;c[$+143636>>2]=C;C=E+6144|0;c[$+12568>>2]=C;c[$+78104>>2]=C;c[$+143640>>2]=C;C=E+7168|0;c[$+12572>>2]=C;c[$+78108>>2]=C;c[$+143644>>2]=C;C=E+8192|0;c[$+12576>>2]=C;c[$+78112>>2]=C;c[$+143648>>2]=C;C=E+9216|0;c[$+12580>>2]=C;c[$+78116>>2]=C;c[$+143652>>2]=C;C=E+10240|0;c[$+12584>>2]=C;c[$+78120>>2]=C;c[$+143656>>2]=C;C=E+11264|0;c[$+12588>>2]=C;c[$+78124>>2]=C;c[$+143660>>2]=C;C=E+12288|0;c[$+12592>>2]=C;c[$+78128>>2]=C;c[$+143664>>2]=C;C=E+13312|0;c[$+12596>>2]=C;c[$+78132>>2]=C;c[$+143668>>2]=C;C=E+14336|0;c[$+12600>>2]=C;c[$+78136>>2]=C;c[$+143672>>2]=C;C=E+15360|0;c[$+12604>>2]=C;c[$+78140>>2]=C;c[$+143676>>2]=C;C=c[3529408]|0;c[$+12608>>2]=C;c[$+78144>>2]=C;c[$+143680>>2]=C;E=C+1024|0;c[$+12612>>2]=E;c[$+78148>>2]=E;c[$+143684>>2]=E;E=C+2048|0;c[$+12616>>2]=E;c[$+78152>>2]=E;c[$+143688>>2]=E;E=C+3072|0;c[$+12620>>2]=E;c[$+78156>>2]=E;c[$+143692>>2]=E;E=C+4096|0;c[$+12624>>2]=E;c[$+78160>>2]=E;c[$+143696>>2]=E;E=C+5120|0;c[$+12628>>2]=E;c[$+78164>>2]=E;c[$+143700>>2]=E;E=C+6144|0;c[$+12632>>2]=E;c[$+78168>>2]=E;c[$+143704>>2]=E;E=C+7168|0;c[$+12636>>2]=E;c[$+78172>>2]=E;c[$+143708>>2]=E;E=C+8192|0;c[$+12640>>2]=E;c[$+78176>>2]=E;c[$+143712>>2]=E;E=C+9216|0;c[$+12644>>2]=E;c[$+78180>>2]=E;c[$+143716>>2]=E;E=C+10240|0;c[$+12648>>2]=E;c[$+78184>>2]=E;c[$+143720>>2]=E;E=C+11264|0;c[$+12652>>2]=E;c[$+78188>>2]=E;c[$+143724>>2]=E;E=C+12288|0;c[$+12656>>2]=E;c[$+78192>>2]=E;c[$+143728>>2]=E;E=C+13312|0;c[$+12660>>2]=E;c[$+78196>>2]=E;c[$+143732>>2]=E;E=C+14336|0;c[$+12664>>2]=E;c[$+78200>>2]=E;c[$+143736>>2]=E;E=C+15360|0;c[$+12668>>2]=E;c[$+78204>>2]=E;c[$+143740>>2]=E;E=c[3529402]|0;c[$+12672>>2]=E;c[$+78208>>2]=E;c[$+143744>>2]=E;C=E+1024|0;c[$+12676>>2]=C;c[$+78212>>2]=C;c[$+143748>>2]=C;C=E+2048|0;c[$+12680>>2]=C;c[$+78216>>2]=C;c[$+143752>>2]=C;C=E+3072|0;c[$+12684>>2]=C;c[$+78220>>2]=C;c[$+143756>>2]=C;C=E+4096|0;c[$+12688>>2]=C;c[$+78224>>2]=C;c[$+143760>>2]=C;C=E+5120|0;c[$+12692>>2]=C;c[$+78228>>2]=C;c[$+143764>>2]=C;C=E+6144|0;c[$+12696>>2]=C;c[$+78232>>2]=C;c[$+143768>>2]=C;C=E+7168|0;c[$+12700>>2]=C;c[$+78236>>2]=C;c[$+143772>>2]=C;C=c[2386734]|0;c[$+12736>>2]=C;c[$+78272>>2]=C;c[$+143808>>2]=C;E=C+1024|0;c[$+12740>>2]=E;c[$+78276>>2]=E;c[$+143812>>2]=E;E=c[2386456]|0;c[$+16384>>2]=E;c[$+81920>>2]=E;c[$+147456>>2]=E;C=E+1024|0;c[$+16388>>2]=C;c[$+81924>>2]=C;c[$+147460>>2]=C;C=c[2387196]|0;c[$+20480>>2]=C;c[$+86016>>2]=C;c[$+151552>>2]=C;E=C+1024|0;c[$+20484>>2]=E;c[$+86020>>2]=E;c[$+151556>>2]=E;E=C+2048|0;c[$+20488>>2]=E;c[$+86024>>2]=E;c[$+151560>>2]=E;E=C+3072|0;c[$+20492>>2]=E;c[$+86028>>2]=E;c[$+151564>>2]=E;E=c[3529854]|0;c[$+20664>>2]=E;c[$+86200>>2]=E;c[$+151736>>2]=E;c[$+196728>>2]=686;c[$+196648>>2]=3114;c[$+196688>>2]=3120;c[$+196608>>2]=458;E=c[3532592]|0;if((E|0)!=0){gGC(E|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);E=c[2439330]|0;C=(E|0)==0;if(!C){F=E;gGC(9706056,F|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];F=c[3528484]|0;c[2076596]=F;r=c[2417276]|0;c[3541536]=r;c[1836236]=0;q=c[2385924]|0;z=0;w=0;while(1){c[E+76+(w<<2)>>2]=q+(w<<8);y=z+1&65535;if((y&65535)>239){aa=0;ab=0;break}else{z=y;w=y&65535}}while(1){w=q+(ab<<8)|0;c[E+76+(ab+512<<2)>>2]=w;c[E+76+(ab+768<<2)>>2]=w;w=aa+1&65535;if((w&65535)>239){break}else{aa=w;ab=w&65535}}q=c[2386078]|0;c[E+1036>>2]=q;c[E+1040>>2]=q+256;c[E+1044>>2]=q+512;c[E+1048>>2]=q+768;c[E+1052>>2]=q+1024;c[E+1056>>2]=q+1280;c[E+1060>>2]=q+1536;c[E+1064>>2]=q+1792;c[E+1068>>2]=q+2048;c[E+1072>>2]=q+2304;c[E+1076>>2]=q+2560;c[E+1080>>2]=q+2816;c[E+1084>>2]=q+3072;c[E+1088>>2]=q+3328;c[E+1092>>2]=q+3584;c[E+1096>>2]=q+3840;w=240;z=240;while(1){c[E+76+(z+256<<2)>>2]=q+((z<<8)-61440);y=w+1&65535;if((y&65535)>255){ac=240;ad=240;break}else{w=y;z=y&65535}}while(1){z=q+((ad<<8)-61440)|0;c[E+76+(ad+512<<2)>>2]=z;c[E+76+(ad+768<<2)>>2]=z;z=ac+1&65535;if((z&65535)>255){break}else{ac=z;ad=z&65535}}c[E+4176>>2]=2390;c[E+4172>>2]=376;if(!C){q=E;gGC(q|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=F;c[2417276]=r;c[1836236]=-1;Vz(c[3529690]|0,2778,1922);h[607289]=.5;c[2433120]=3;h[607288]=.5;c[2433118]=3;c[2438228]=5e6;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=408;UL(3579545,2778,1922,0);c[2438224]=5e6;c[2433522]=3416;c[2406672]=1752;c[3528468]=9362;c[2443842]=408;h[745398]=1.0;a[3203264]=1;Ux(0,7575,1);Ux(1,7575,1);c[2407030]=256;c[2407068]=3;c[2407069]=256;c[2407107]=3;gGz(9668984,0,27);S6(0,27,0);gGz(9669011,0,27);S6(1,27,0);if((f|0)==0){c[3540906]=3224;c[3540902]=4498;c[3540898]=190;c[3540896]=1352}else{c[3540906]=456;c[3540898]=1322;c[3540902]=3346}c[3540894]=982;c[3540892]=938;c[3540890]=2594;Tq(690096);q=c[642608+(c[2436]<<2)>>2]|0;z=c[q+128>>2]|0;if((c[q+52>>2]&4|0)==0){c[2113068]=z;w=c[q+132>>2]|0;c[2113070]=w;c[2443814]=z;c[2440436]=w;ae=z;af=w}else{c[2113070]=z;w=c[q+132>>2]|0;c[2113068]=w;c[2440436]=z;c[2443814]=w;ae=w;af=z}z=ag(ae<<1,af)|0;w=gGq(z)|0;c[2112926]=w;if((w|0)!=0){gGz(w|0,0,z|0)}c[2113302]=2;a[801640]=0;z=c[642608+(c[2436]<<2)>>2]|0;w=c[z+128>>2]|0;if((c[z+52>>2]&4|0)==0){c[2440576]=w;q=c[z+132>>2]|0;c[2440574]=q;ah=w;ai=q}else{c[2440574]=w;q=c[z+132>>2]|0;c[2440576]=q;ah=q;ai=w}w=(((ah|0)/2|0)<<8)-1792|0;q=(((ai|0)/2|0)<<8)-2048|0;c[3542196]=w;c[3542192]=q;c[3542197]=w;c[3542193]=q;c[3542198]=w;c[3542194]=q;c[3542199]=w;c[3542195]=q;ebp();t=0;i=g;return t|0}}while(0);c[2414962]=0;t=1;i=g;return t|0}function ebc(){var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;d=i;i=i+1680|0;e=d|0;f=d+112|0;g=d+120|0;h=d+232|0;j=d+240|0;k=d+352|0;l=d+360|0;m=d+472|0;n=d+480|0;o=d+592|0;p=d+600|0;q=d+712|0;r=d+720|0;s=d+832|0;t=d+840|0;u=d+952|0;v=d+960|0;w=d+1072|0;x=d+1080|0;y=d+1192|0;z=d+1200|0;A=d+1312|0;B=d+1320|0;C=d+1432|0;D=d+1440|0;E=d+1552|0;F=d+1560|0;G=d+1672|0;H=c[2388152]|0;if((c[3542200]|0)==0){I=1;i=d;return I|0}J=F+108|0;c[J>>2]=0;K=F+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](F,0)|0;do{if((c[J>>2]|0)!=0){F=c[K>>2]|0;c[G>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](G,0,0)|0;if((F|0)<1){I=1;i=d;return I|0}if((gzL(H,0,0)|0)==0){break}else{I=1}i=d;return I|0}}while(0);H=c[2388152]|0;G=0;K=H;while(1){J=a[K]|0;F=K+1|0;a[K]=a[F]|0;a[F]=J;J=G+1|0;if((J|0)<1048576){G=J;K=K+2|0}else{break}}if((R6(H+1|0,1,2)|0)!=0){I=1;i=d;return I|0}if((R6(c[2388152]|0,2,2)|0)!=0){I=1;i=d;return I|0}H=c[2385924]|0;if((c[3542200]|0)==0){I=1;i=d;return I|0}K=D+108|0;c[K>>2]=0;G=D+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](D,3)|0;do{if((c[K>>2]|0)!=0){D=c[G>>2]|0;c[E>>2]=9534384;J=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[J&16383](E,3,0)|0;if((D|0)<1){I=1;i=d;return I|0}if((gzL(H,0,3)|0)==0){break}else{I=1}i=d;return I|0}}while(0);H=c[3530842]|0;if((c[3542200]|0)==0){I=1;i=d;return I|0}E=B+108|0;c[E>>2]=0;G=B+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](B,4)|0;do{if((c[E>>2]|0)!=0){B=c[G>>2]|0;c[C>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](C,4,0)|0;if((B|0)<1){I=1;i=d;return I|0}if((gzL(H,0,4)|0)==0){break}else{I=1}i=d;return I|0}}while(0);H=(c[3530842]|0)+1048576|0;if((c[3542200]|0)==0){I=1;i=d;return I|0}C=z+108|0;c[C>>2]=0;G=z+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,5)|0;do{if((c[C>>2]|0)!=0){z=c[G>>2]|0;c[A>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](A,5,0)|0;if((z|0)<1){I=1;i=d;return I|0}if((gzL(H,0,5)|0)==0){break}else{I=1}i=d;return I|0}}while(0);H=(c[3530842]|0)+2097152|0;if((c[3542200]|0)==0){I=1;i=d;return I|0}A=x+108|0;c[A>>2]=0;G=x+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,6)|0;do{if((c[A>>2]|0)!=0){x=c[G>>2]|0;c[y>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](y,6,0)|0;if((x|0)<1){I=1;i=d;return I|0}if((gzL(H,0,6)|0)==0){break}else{I=1}i=d;return I|0}}while(0);H=c[3530430]|0;if((c[3542200]|0)==0){I=1;i=d;return I|0}y=v+108|0;c[y>>2]=0;G=v+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,7)|0;do{if((c[y>>2]|0)!=0){v=c[G>>2]|0;c[w>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](w,7,0)|0;if((v|0)<1){I=1;i=d;return I|0}if((gzL(H,0,7)|0)==0){break}else{I=1}i=d;return I|0}}while(0);H=(c[3530430]|0)+2097152|0;if((c[3542200]|0)==0){I=1;i=d;return I|0}w=t+108|0;c[w>>2]=0;G=t+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,8)|0;do{if((c[w>>2]|0)!=0){t=c[G>>2]|0;c[u>>2]=9534384;y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[y&16383](u,8,0)|0;if((t|0)<1){I=1;i=d;return I|0}if((gzL(H,0,8)|0)==0){break}else{I=1}i=d;return I|0}}while(0);H=(c[3530430]|0)+4194304|0;if((c[3542200]|0)==0){I=1;i=d;return I|0}u=r+108|0;c[u>>2]=0;G=r+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,9)|0;do{if((c[u>>2]|0)!=0){r=c[G>>2]|0;c[s>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](s,9,0)|0;if((r|0)<1){I=1;i=d;return I|0}if((gzL(H,0,9)|0)==0){break}else{I=1}i=d;return I|0}}while(0);H=c[3530334]|0;if((c[3542200]|0)==0){I=1;i=d;return I|0}s=p+108|0;c[s>>2]=0;G=p+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,10)|0;do{if((c[s>>2]|0)!=0){p=c[G>>2]|0;c[q>>2]=9534384;u=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[u&16383](q,10,0)|0;if((p|0)<1){I=1;i=d;return I|0}if((gzL(H,0,10)|0)==0){break}else{I=1}i=d;return I|0}}while(0);H=(c[3530334]|0)+4194304|0;if((c[3542200]|0)==0){I=1;i=d;return I|0}q=n+108|0;c[q>>2]=0;G=n+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,11)|0;do{if((c[q>>2]|0)!=0){n=c[G>>2]|0;c[o>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](o,11,0)|0;if((n|0)<1){I=1;i=d;return I|0}if((gzL(H,0,11)|0)==0){break}else{I=1}i=d;return I|0}}while(0);H=(c[3530334]|0)+8388608|0;if((c[3542200]|0)==0){I=1;i=d;return I|0}o=l+108|0;c[o>>2]=0;G=l+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,12)|0;do{if((c[o>>2]|0)!=0){l=c[G>>2]|0;c[m>>2]=9534384;q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[q&16383](m,12,0)|0;if((l|0)<1){I=1;i=d;return I|0}if((gzL(H,0,12)|0)==0){break}else{I=1}i=d;return I|0}}while(0);H=(c[3529758]|0)+262144|0;if((c[3542200]|0)==0){I=1;i=d;return I|0}m=j+108|0;c[m>>2]=0;G=j+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,13)|0;do{if((c[m>>2]|0)!=0){j=c[G>>2]|0;c[k>>2]=9534384;o=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[o&16383](k,13,0)|0;if((j|0)<1){I=1;i=d;return I|0}if((gzL(H,0,13)|0)==0){break}else{I=1}i=d;return I|0}}while(0);H=c[3529712]|0;if((c[3542200]|0)==0){I=1;i=d;return I|0}k=g+108|0;c[k>>2]=0;G=g+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,14)|0;do{if((c[k>>2]|0)!=0){g=c[G>>2]|0;c[h>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](h,14,0)|0;if((g|0)<1){I=1;i=d;return I|0}if((gzL(H,0,14)|0)==0){break}else{I=1}i=d;return I|0}}while(0);H=c[3529690]|0;if((c[3542200]|0)==0){I=1;i=d;return I|0}h=e+108|0;c[h>>2]=0;G=e+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,15)|0;do{if((c[h>>2]|0)!=0){e=c[G>>2]|0;c[f>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](f,15,0)|0;if((e|0)<1){I=1;i=d;return I|0}if((gzL(H,0,15)|0)==0){break}else{I=1}i=d;return I|0}}while(0);H=c[2388152]|0;b[H+42320>>1]=24594;b[H+43220>>1]=24594;b[H+44170>>1]=24594;b[H+74936>>1]=24594;b[H+75836>>1]=24594;b[H+76786>>1]=24594;b[H+99862>>1]=24594;b[H+100762>>1]=24594;b[H+101712>>1]=24594;b[H+143592>>1]=24594;b[H+144492>>1]=24594;b[H+145442>>1]=24594;b[H+179450>>1]=24594;b[H+180350>>1]=24594;b[H+181300>>1]=24594;I=0;i=d;return I|0}function ebd(b,c){b=b|0;c=c|0;b=(c|0)!=0|0;if((b|0)==0){a[9706117]=0;return}else if((b|0)==1){a[9706117]=1;return}else{return}}function ebe(a){a=a|0;var b=0,d=0;b=(c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,5e6,0)|0;return a|0}function ebf(){var d=0,e=0,f=0;d=a[9635080]&79;do{if((c[2406632]|0)==0){e=c[2443744]|0;if((e|0)<=0){f=-128;break}c[2443744]=e-1;f=0}else{f=(1<<c[(c[2420380]|0)+4>>2]&c[2432962]|0)!=0?-128:0}}while(0);return f|d|b[4775244]&48|0}function ebg(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=d&255;g=c[2384306]|0;h=c[2113068]|0;i=c[2113070]|0;do{if((f&4|0)!=0){if((g&4|0)!=0){break}j=e[4877696]|0;k=j-60|0;c[2432920]=j;j=e[4877688]|0;c[2432918]=j;l=k>>>0>414?0:k;if((l|0)!=0){if(!((b[793968+(l<<1)>>1]|0)>=(h|0)|(j|0)>(i|0))){break}}c[2432918]=0;c[2432920]=0}}while(0);do{if((f&8|0)!=0){if((g&8|0)!=0){break}j=e[4877692]|0;l=j-60|0;c[2432921]=j;j=e[4877684]|0;c[2432919]=j;k=l>>>0>414?0:l;if((k|0)!=0){if(!((b[793968+(k<<1)>>1]|0)>=(h|0)|(j|0)>(i|0))){break}}c[2432919]=0;c[2432921]=0}}while(0);c[2415256]=f&64;i=f>>>4&1;c[3528406]=i^1;if((i|0)!=0){m=f>>>5;n=m&1;Tr(n);o=d&-128;a[9718480]=o;c[2384306]=f;return}c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];m=f>>>5;n=m&1;Tr(n);o=d&-128;a[9718480]=o;c[2384306]=f;return}function ebh(){return b[4775242]&255|0}function ebi(){var b=0,c=0;b=a[9732448]&112;if((b|0)==80){c=a[9635082]|0}else if((b|0)==48){c=a[9635080]|0}else if((b|0)==96){c=a[9635081]|0}else{c=-1}return c|0}function ebj(){var a=0,d=0,e=0,f=0;a=b[4775242]&255&-2;if((c[2406632]|0)!=0){d=(1<<c[(c[2420380]|0)+4>>2]&c[2432962]|0)!=0|0;e=d|a;return e|0}f=c[2443744]|0;if((f|0)<=0){d=1;e=d|a;return e|0}c[2443744]=f-1;d=0;e=d|a;return e|0}function ebk(b){b=b|0;var d=0,e=0,f=0;d=b&255;a[9718480]=(b&255)>>>1&1^1;c[2415256]=d&128;b=d>>>5&1;c[3528406]=b^1;if((b|0)!=0){e=d>>>6;f=e&1;Tr(f);return}c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];e=d>>>6;f=e&1;Tr(f);return}function ebl(b){b=b|0;a[9732448]=b;return}function ebm(){return b[4775240]&255|0}function ebn(){return b[4775241]&255|0}function ebo(){return b[4775243]&255|0}function ebp(){var d=0,e=0,f=0,g=0,i=0;d=c[2414666]|0;gGz(d|0,0,(c[2411656]|0)-d|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=i;c[1836236]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;lw(c[3540984]|0);c[2113156]=0;a[9628264]=0;c[2407033]=0;i=c[3541206]|0;c[3541190]=i;c[3541198]=i;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=i+256;c[3541199]=i+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=i+512;c[3541200]=i+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=i+768;c[3541201]=i+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2113157]=0;a[9628420]=0;c[2407072]=0;g=i+1048576|0;c[3541194]=g;c[3541202]=g;gGz(c[2430122]|0,0,16384);c[2407080]=4;c[3541195]=i+1048832;c[3541203]=i+1114112;gGz(c[2430123]|0,0,16384);c[2407088]=4;c[3541196]=i+1049088;c[3541204]=i+1179648;gGz(c[2430124]|0,0,16384);c[2407096]=4;c[3541197]=i+1049344;c[3541205]=i+1245184;gGz(c[2430125]|0,0,16384);c[2407104]=4;i=c[2406702]|0;a[i]=-1;a[i]=0;i=c[3529758]|0;g=i+262144|0;gGC(i|0,g|0,262144)|0;c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];a[9732448]=0;a[9718480]=0;if((dW(c[c[642608+(c[2436]<<2)>>2]>>2]|0,150880,8)|0)==0){g=c[2388152]|0;b[g+2612>>1]=a[9635083]&1|28672;b[g+2616>>1]=(a[9635083]&255)>>>1&1|28672;b[g+2620>>1]=(a[9635083]&255)>>>2&1|28672;return}if(a[1040128]|0){return}gGC(14100392,614680,48)|0;return}function ebq(d,f,g,h,i,j,k,l){d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;m=ag(h,g)|0;h=ag(i,g)|0;if((g|0)==32){n=8191}else{n=(g|0)==16?32767:65535}i=d;if((h|0)<=0){return}d=(j|0)/64|0;j=1-g|0;o=14101416+(l<<2)|0;if((m|0)<=0){p=0;do{p=p+g|0;}while((p|0)<(h|0));return}p=ag(g,g)|0;q=(g|0)>0;r=g-1|0;s=c[9758032+(l<<2)>>2]|0;t=(c[2406648]|0)+(l<<1)|0;u=(c[2406638]|0)+(l<<1)|0;l=c[2113068]|0;v=c[2113070]|0;w=0;x=0;while(1){y=0;z=w;do{A=z<<1;B=e[i+((A|1)<<1)>>1]&n;do{if((a[s+B|0]|0)==0){C=e[i+(A<<1)>>1]|0;D=y-((e[t>>1]|0)%(m|0)|0)|0;E=((D|0)<(j|0)?m:0)+D|0;D=x-((e[u>>1]|0)%(h|0)|0)|0;F=((D|0)<(j|0)?h:0)+D|0;if(!((E|0)<(l|0)&(F|0)<(v|0))){break}D=(C&32768|0)!=0;G=c[o>>2]|0;H=(C>>>4&k)+d+(C>>>9<<5&224)<<6;I=f+(ag(p,B)|0)|0;c[2112928]=I;if((C&16384|0)==0){if(D){if(!q){break}C=E+g|0;J=G+((ag(l,F)|0)+E<<1)|0;K=0;L=I;while(1){M=K+F|0;if((M|0)>=(v|0)|(M|0)<0){N=L}else{M=0;O=0;while(1){P=C+O|0;do{if((P|0)>0&(P-1|0)<(l|0)){Q=a[L+M|0]|0;if(Q<<24>>24==63){break}b[J+(r+O<<1)>>1]=(Q&255|H)&65535}}while(0);P=M+1|0;Q=~M;if((P|0)<(g|0)){M=P;O=Q}else{N=L;break}}}O=K+1|0;R=N+g|0;if((O|0)>=(g|0)){break}J=J+(l<<1)|0;K=O;L=R}c[2112928]=R;break}else{if(!q){break}L=G+((ag(l,F)|0)+E<<1)|0;K=0;J=I;while(1){C=K+F|0;if((C|0)>=(v|0)|(C|0)<0){S=J}else{C=0;while(1){O=C+E|0;do{if((O|0)>-1&(O|0)<(l|0)){M=a[J+C|0]|0;if(M<<24>>24==63){break}b[L+(C<<1)>>1]=(M&255|H)&65535}}while(0);O=C+1|0;if((O|0)<(g|0)){C=O}else{S=J;break}}}C=K+1|0;T=S+g|0;if((C|0)>=(g|0)){break}L=L+(l<<1)|0;K=C;J=T}c[2112928]=T;break}}else{if(D){if(!q){break}J=E+g|0;K=G+((ag(l,F+r|0)|0)+E<<1)|0;L=g;C=I;while(1){O=L-1|0;M=O+F|0;if((M|0)>=(v|0)|(M|0)<0){U=C}else{M=0;Q=0;while(1){P=J+Q|0;do{if((P|0)>0&(P-1|0)<(l|0)){V=a[C+M|0]|0;if(V<<24>>24==63){break}b[K+(Q+r<<1)>>1]=(V&255|H)&65535}}while(0);P=M+1|0;V=~M;if((P|0)<(g|0)){M=P;Q=V}else{U=C;break}}}W=U+g|0;if((O|0)<=0){break}K=K+(-l<<1)|0;L=O;C=W}c[2112928]=W;break}else{if(!q){break}C=G+((ag(l,r+F|0)|0)+E<<1)|0;L=g;K=I;while(1){J=L-1|0;D=J+F|0;if((D|0)>=(v|0)|(D|0)<0){X=K}else{D=0;while(1){Q=D+E|0;do{if((Q|0)>-1&(Q|0)<(l|0)){M=a[K+D|0]|0;if(M<<24>>24==63){break}b[C+(D<<1)>>1]=(M&255|H)&65535}}while(0);Q=D+1|0;if((Q|0)<(g|0)){D=Q}else{X=K;break}}}Y=X+g|0;if((J|0)<=0){break}C=C+(-l<<1)|0;L=J;K=Y}c[2112928]=Y;break}}}}while(0);y=y+g|0;z=z+1|0;}while((y|0)<(m|0));y=x+g|0;if((y|0)<(h|0)){w=z;x=y}else{break}}return}function ebr(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;gGz(9550480,-1|0,10);d=0;e=-1;f=-1;g=-1;h=-1;i=-1;do{e=((a[9633400+d|0]&1)<<d^e&65535)&65535;f=((a[9631272+d|0]&1)<<d^f&65535)&65535;g=((a[9629552+d|0]&1)<<d^g&65535)&65535;h=((a[9628944+d|0]&1)<<d^h&65535)&65535;i=((a[9628720+d|0]&1)<<d^i&65535)&65535;d=d+1|0;}while((d|0)<16);b[4775240]=e;b[4775241]=f;b[4775242]=g;b[4775243]=h;b[4775244]=i;i=c[2408959]|0;h=(c[3542196]|0)+(c[2408958]<<16>>16)|0;c[3542196]=h;g=(c[3542192]|0)+(i<<16>>16)|0;c[3542192]=g;if((h|0)<-2048){c[3542196]=-2048;j=-2048}else{j=h}h=(c[2440576]<<8)-2048|0;if((j|0)>(h|0)){c[3542196]=h;k=h}else{k=j}if((g|0)<-2048){c[3542192]=-2048;l=-2048}else{l=g}g=(c[2440574]<<8)-2048|0;if((l|0)>(g|0)){c[3542192]=g;m=g}else{m=l}l=c[2408961]|0;j=(c[3542197]|0)+(c[2408960]<<16>>16)|0;c[3542197]=j;i=(c[3542193]|0)+(l<<16>>16)|0;c[3542193]=i;if((j|0)<-2048){c[3542197]=-2048;n=-2048}else{n=j}if((n|0)>(h|0)){c[3542197]=h;o=h}else{o=n}if((i|0)<-2048){c[3542193]=-2048;p=-2048}else{p=i}if((p|0)>(g|0)){c[3542193]=g;q=g}else{q=p}b[4877696]=~~(+((k>>8)+8|0)/448.0*412.0)+60&65535;b[4877688]=~~(+((m>>8)+8|0)/224.0*224.0)&255;b[4877692]=~~(+((o>>8)+8|0)/448.0*412.0)+60&65535;b[4877684]=~~(+((q>>8)+8|0)/224.0*224.0)&255;return}function ebs(){var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;d=i;i=i+1680|0;e=d|0;f=d+112|0;g=d+120|0;h=d+232|0;j=d+240|0;k=d+352|0;l=d+360|0;m=d+472|0;n=d+480|0;o=d+592|0;p=d+600|0;q=d+712|0;r=d+720|0;s=d+832|0;t=d+840|0;u=d+952|0;v=d+960|0;w=d+1072|0;x=d+1080|0;y=d+1192|0;z=d+1200|0;A=d+1312|0;B=d+1320|0;C=d+1432|0;D=d+1440|0;E=d+1552|0;F=d+1560|0;G=d+1672|0;H=c[2388152]|0;if((c[3542200]|0)==0){I=1;i=d;return I|0}J=F+108|0;c[J>>2]=0;K=F+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](F,0)|0;do{if((c[J>>2]|0)!=0){F=c[K>>2]|0;c[G>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](G,0,0)|0;if((F|0)<1){I=1;i=d;return I|0}if((gzL(H,0,0)|0)==0){break}else{I=1}i=d;return I|0}}while(0);H=0;G=c[2388152]|0;while(1){K=a[G]|0;J=G+1|0;a[G]=a[J]|0;a[J]=K;K=H+1|0;if((K|0)<1048576){H=K;G=G+2|0}else{break}}G=c[2385924]|0;if((c[3542200]|0)==0){I=1;i=d;return I|0}H=D+108|0;c[H>>2]=0;K=D+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](D,1)|0;do{if((c[H>>2]|0)!=0){D=c[K>>2]|0;c[E>>2]=9534384;J=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[J&16383](E,1,0)|0;if((D|0)<1){I=1;i=d;return I|0}if((gzL(G,0,1)|0)==0){break}else{I=1}i=d;return I|0}}while(0);G=c[3530842]|0;if((c[3542200]|0)==0){I=1;i=d;return I|0}E=B+108|0;c[E>>2]=0;K=B+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](B,2)|0;do{if((c[E>>2]|0)!=0){B=c[K>>2]|0;c[C>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](C,2,0)|0;if((B|0)<1){I=1;i=d;return I|0}if((gzL(G,0,2)|0)==0){break}else{I=1}i=d;return I|0}}while(0);G=(c[3530842]|0)+1048576|0;if((c[3542200]|0)==0){I=1;i=d;return I|0}C=z+108|0;c[C>>2]=0;K=z+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,3)|0;do{if((c[C>>2]|0)!=0){z=c[K>>2]|0;c[A>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](A,3,0)|0;if((z|0)<1){I=1;i=d;return I|0}if((gzL(G,0,3)|0)==0){break}else{I=1}i=d;return I|0}}while(0);G=(c[3530842]|0)+2097152|0;if((c[3542200]|0)==0){I=1;i=d;return I|0}A=x+108|0;c[A>>2]=0;K=x+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,4)|0;do{if((c[A>>2]|0)!=0){x=c[K>>2]|0;c[y>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](y,4,0)|0;if((x|0)<1){I=1;i=d;return I|0}if((gzL(G,0,4)|0)==0){break}else{I=1}i=d;return I|0}}while(0);G=c[3530430]|0;if((c[3542200]|0)==0){I=1;i=d;return I|0}y=v+108|0;c[y>>2]=0;K=v+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,5)|0;do{if((c[y>>2]|0)!=0){v=c[K>>2]|0;c[w>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](w,5,0)|0;if((v|0)<1){I=1;i=d;return I|0}if((gzL(G,0,5)|0)==0){break}else{I=1}i=d;return I|0}}while(0);G=(c[3530430]|0)+2097152|0;if((c[3542200]|0)==0){I=1;i=d;return I|0}w=t+108|0;c[w>>2]=0;K=t+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,6)|0;do{if((c[w>>2]|0)!=0){t=c[K>>2]|0;c[u>>2]=9534384;y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[y&16383](u,6,0)|0;if((t|0)<1){I=1;i=d;return I|0}if((gzL(G,0,6)|0)==0){break}else{I=1}i=d;return I|0}}while(0);G=(c[3530430]|0)+4194304|0;if((c[3542200]|0)==0){I=1;i=d;return I|0}u=r+108|0;c[u>>2]=0;K=r+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,7)|0;do{if((c[u>>2]|0)!=0){r=c[K>>2]|0;c[s>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](s,7,0)|0;if((r|0)<1){I=1;i=d;return I|0}if((gzL(G,0,7)|0)==0){break}else{I=1}i=d;return I|0}}while(0);G=c[3530334]|0;if((c[3542200]|0)==0){I=1;i=d;return I|0}s=p+108|0;c[s>>2]=0;K=p+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,8)|0;do{if((c[s>>2]|0)!=0){p=c[K>>2]|0;c[q>>2]=9534384;u=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[u&16383](q,8,0)|0;if((p|0)<1){I=1;i=d;return I|0}if((gzL(G,0,8)|0)==0){break}else{I=1}i=d;return I|0}}while(0);G=(c[3530334]|0)+4194304|0;if((c[3542200]|0)==0){I=1;i=d;return I|0}q=n+108|0;c[q>>2]=0;K=n+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,9)|0;do{if((c[q>>2]|0)!=0){n=c[K>>2]|0;c[o>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](o,9,0)|0;if((n|0)<1){I=1;i=d;return I|0}if((gzL(G,0,9)|0)==0){break}else{I=1}i=d;return I|0}}while(0);G=(c[3530334]|0)+8388608|0;if((c[3542200]|0)==0){I=1;i=d;return I|0}o=l+108|0;c[o>>2]=0;K=l+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,10)|0;do{if((c[o>>2]|0)!=0){l=c[K>>2]|0;c[m>>2]=9534384;q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[q&16383](m,10,0)|0;if((l|0)<1){I=1;i=d;return I|0}if((gzL(G,0,10)|0)==0){break}else{I=1}i=d;return I|0}}while(0);G=(c[3529758]|0)+262144|0;if((c[3542200]|0)==0){I=1;i=d;return I|0}m=j+108|0;c[m>>2]=0;K=j+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,11)|0;do{if((c[m>>2]|0)!=0){j=c[K>>2]|0;c[k>>2]=9534384;o=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[o&16383](k,11,0)|0;if((j|0)<1){I=1;i=d;return I|0}if((gzL(G,0,11)|0)==0){break}else{I=1}i=d;return I|0}}while(0);G=c[3529712]|0;if((c[3542200]|0)==0){I=1;i=d;return I|0}k=g+108|0;c[k>>2]=0;K=g+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,12)|0;do{if((c[k>>2]|0)!=0){g=c[K>>2]|0;c[h>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](h,12,0)|0;if((g|0)<1){I=1;i=d;return I|0}if((gzL(G,0,12)|0)==0){break}else{I=1}i=d;return I|0}}while(0);G=c[3529690]|0;if((c[3542200]|0)==0){I=1;i=d;return I|0}h=e+108|0;c[h>>2]=0;K=e+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,13)|0;do{if((c[h>>2]|0)!=0){e=c[K>>2]|0;c[f>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](f,13,0)|0;if((e|0)<1){I=1;i=d;return I|0}if((gzL(G,0,13)|0)==0){break}else{I=1}i=d;return I|0}}while(0);G=c[2388152]|0;b[G+42328>>1]=24594;b[G+43228>>1]=24594;b[G+44178>>1]=24594;b[G+74956>>1]=24594;b[G+75856>>1]=24594;b[G+76806>>1]=24594;b[G+99882>>1]=24594;b[G+100782>>1]=24594;b[G+101732>>1]=24594;b[G+143612>>1]=24594;b[G+144512>>1]=24594;b[G+145462>>1]=24594;b[G+179470>>1]=24594;b[G+180370>>1]=24594;b[G+181320>>1]=24594;I=0;i=d;return I|0}function ebt(){var a=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;a=i;i=i+1680|0;d=a|0;e=a+112|0;f=a+120|0;g=a+232|0;h=a+240|0;j=a+352|0;k=a+360|0;l=a+472|0;m=a+480|0;n=a+592|0;o=a+600|0;p=a+712|0;q=a+720|0;r=a+832|0;s=a+840|0;t=a+952|0;u=a+960|0;v=a+1072|0;w=a+1080|0;x=a+1192|0;y=a+1200|0;z=a+1312|0;A=a+1320|0;B=a+1432|0;C=a+1440|0;D=a+1552|0;E=a+1560|0;F=a+1672|0;if((R6((c[2388152]|0)+1|0,0,2)|0)!=0){G=1;i=a;return G|0}if((R6(c[2388152]|0,1,2)|0)!=0){G=1;i=a;return G|0}H=c[2385924]|0;if((c[3542200]|0)==0){G=1;i=a;return G|0}I=E+108|0;c[I>>2]=0;J=E+100|0;c[J>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](E,2)|0;do{if((c[I>>2]|0)!=0){E=c[J>>2]|0;c[F>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](F,2,0)|0;if((E|0)<1){G=1;i=a;return G|0}if((gzL(H,0,2)|0)==0){break}else{G=1}i=a;return G|0}}while(0);H=c[3530842]|0;if((c[3542200]|0)==0){G=1;i=a;return G|0}F=C+108|0;c[F>>2]=0;J=C+100|0;c[J>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](C,3)|0;do{if((c[F>>2]|0)!=0){C=c[J>>2]|0;c[D>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](D,3,0)|0;if((C|0)<1){G=1;i=a;return G|0}if((gzL(H,0,3)|0)==0){break}else{G=1}i=a;return G|0}}while(0);H=(c[3530842]|0)+1048576|0;if((c[3542200]|0)==0){G=1;i=a;return G|0}D=A+108|0;c[D>>2]=0;J=A+100|0;c[J>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](A,4)|0;do{if((c[D>>2]|0)!=0){A=c[J>>2]|0;c[B>>2]=9534384;F=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[F&16383](B,4,0)|0;if((A|0)<1){G=1;i=a;return G|0}if((gzL(H,0,4)|0)==0){break}else{G=1}i=a;return G|0}}while(0);H=(c[3530842]|0)+2097152|0;if((c[3542200]|0)==0){G=1;i=a;return G|0}B=y+108|0;c[B>>2]=0;J=y+100|0;c[J>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](y,5)|0;do{if((c[B>>2]|0)!=0){y=c[J>>2]|0;c[z>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](z,5,0)|0;if((y|0)<1){G=1;i=a;return G|0}if((gzL(H,0,5)|0)==0){break}else{G=1}i=a;return G|0}}while(0);H=c[3530430]|0;if((c[3542200]|0)==0){G=1;i=a;return G|0}z=w+108|0;c[z>>2]=0;J=w+100|0;c[J>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](w,6)|0;do{if((c[z>>2]|0)!=0){w=c[J>>2]|0;c[x>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](x,6,0)|0;if((w|0)<1){G=1;i=a;return G|0}if((gzL(H,0,6)|0)==0){break}else{G=1}i=a;return G|0}}while(0);H=(c[3530430]|0)+2097152|0;if((c[3542200]|0)==0){G=1;i=a;return G|0}x=u+108|0;c[x>>2]=0;J=u+100|0;c[J>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](u,7)|0;do{if((c[x>>2]|0)!=0){u=c[J>>2]|0;c[v>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](v,7,0)|0;if((u|0)<1){G=1;i=a;return G|0}if((gzL(H,0,7)|0)==0){break}else{G=1}i=a;return G|0}}while(0);H=(c[3530430]|0)+4194304|0;if((c[3542200]|0)==0){G=1;i=a;return G|0}v=s+108|0;c[v>>2]=0;J=s+100|0;c[J>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](s,8)|0;do{if((c[v>>2]|0)!=0){s=c[J>>2]|0;c[t>>2]=9534384;x=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[x&16383](t,8,0)|0;if((s|0)<1){G=1;i=a;return G|0}if((gzL(H,0,8)|0)==0){break}else{G=1}i=a;return G|0}}while(0);H=c[3530334]|0;if((c[3542200]|0)==0){G=1;i=a;return G|0}t=q+108|0;c[t>>2]=0;J=q+100|0;c[J>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](q,9)|0;do{if((c[t>>2]|0)!=0){q=c[J>>2]|0;c[r>>2]=9534384;v=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[v&16383](r,9,0)|0;if((q|0)<1){G=1;i=a;return G|0}if((gzL(H,0,9)|0)==0){break}else{G=1}i=a;return G|0}}while(0);H=(c[3530334]|0)+2097152|0;if((c[3542200]|0)==0){G=1;i=a;return G|0}r=o+108|0;c[r>>2]=0;J=o+100|0;c[J>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](o,10)|0;do{if((c[r>>2]|0)!=0){o=c[J>>2]|0;c[p>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](p,10,0)|0;if((o|0)<1){G=1;i=a;return G|0}if((gzL(H,0,10)|0)==0){break}else{G=1}i=a;return G|0}}while(0);H=(c[3530334]|0)+4194304|0;if((c[3542200]|0)==0){G=1;i=a;return G|0}p=m+108|0;c[p>>2]=0;J=m+100|0;c[J>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,11)|0;do{if((c[p>>2]|0)!=0){m=c[J>>2]|0;c[n>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](n,11,0)|0;if((m|0)<1){G=1;i=a;return G|0}if((gzL(H,0,11)|0)==0){break}else{G=1}i=a;return G|0}}while(0);H=(c[3530334]|0)+6291456|0;if((c[3542200]|0)==0){G=1;i=a;return G|0}n=k+108|0;c[n>>2]=0;J=k+100|0;c[J>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,12)|0;do{if((c[n>>2]|0)!=0){k=c[J>>2]|0;c[l>>2]=9534384;p=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[p&16383](l,12,0)|0;if((k|0)<1){G=1;i=a;return G|0}if((gzL(H,0,12)|0)==0){break}else{G=1}i=a;return G|0}}while(0);H=(c[3530334]|0)+8388608|0;if((c[3542200]|0)==0){G=1;i=a;return G|0}l=h+108|0;c[l>>2]=0;J=h+100|0;c[J>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](h,13)|0;do{if((c[l>>2]|0)!=0){h=c[J>>2]|0;c[j>>2]=9534384;n=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[n&16383](j,13,0)|0;if((h|0)<1){G=1;i=a;return G|0}if((gzL(H,0,13)|0)==0){break}else{G=1}i=a;return G|0}}while(0);H=(c[3530334]|0)+10485760|0;if((c[3542200]|0)==0){G=1;i=a;return G|0}j=f+108|0;c[j>>2]=0;J=f+100|0;c[J>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,14)|0;do{if((c[j>>2]|0)!=0){f=c[J>>2]|0;c[g>>2]=9534384;l=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[l&16383](g,14,0)|0;if((f|0)<1){G=1;i=a;return G|0}if((gzL(H,0,14)|0)==0){break}else{G=1}i=a;return G|0}}while(0);H=(c[3529758]|0)+262144|0;if((c[3542200]|0)==0){G=1;i=a;return G|0}g=d+108|0;c[g>>2]=0;J=d+100|0;c[J>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](d,15)|0;do{if((c[g>>2]|0)!=0){d=c[J>>2]|0;c[e>>2]=9534384;j=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[j&16383](e,15,0)|0;if((d|0)<1){G=1;i=a;return G|0}if((gzL(H,0,15)|0)==0){break}else{G=1}i=a;return G|0}}while(0);H=c[2388152]|0;e=0;while(1){if((e&288|0)==256|(e&2560|0)==2048){J=H+(e<<1)|0;b[J>>1]=b[J>>1]^16}J=e+1|0;if((J|0)<524288){e=J}else{G=0;break}}i=a;return G|0}function ebu(b,e){b=b|0;e=e|0;var f=0,g=0;f=b&65535;if((f&63488|0)!=49152){return}b=c[2387194]|0;a[b+(f&2047)|0]=e;e=f&2046;f=d[b+(e|1)|0]|0;g=d[b+e|0]|0;b=(f<<8|g)>>>5&31;c[(c[3530002]|0)+(e>>>1<<2)>>2]=f>>>2<<11&63488|g&31|(b<<3|b>>>2)<<3&2016;return}function ebv(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=d&255;if((f|0)==3){d=c[1836236]|0;g=c[9757320+(d<<2)>>2]|0;if((g|0)!=0){h=g;gGC(h|0,9706056,76)|0}c[9752472+(d<<2)>>2]=c[2433530];c[14113936+(d<<2)>>2]=c[2076596];c[9669104+(d<<2)>>2]=c[3541536];c[1836236]=-1;d=c[2439331]|0;h=(d|0)==0;if(!h){g=d;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;g=c[2438119]|0;c[2433530]=g;i=c[3528485]|0;c[2076596]=i;j=c[2417277]|0;c[3541536]=j;c[1836236]=1;a[9706117]=1;if(!h){h=d;gGC(h|0,9706056,76)|0}c[2438119]=g;c[3528485]=i;c[2417277]=j;c[1836236]=-1;j=c[2439330]|0;if((j|0)!=0){i=j;gGC(9706056,i|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;a[c[3528276]|0]=e;return}else if((f|0)==1){a[9620408]=e&51;return}else if((f|0)==0){ebw(e&255);return}else{return}}function ebw(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=b&1;a[9578760]=d;if(d<<24>>24==0){d=c[2386214]|0;b=c[9757320+(c[1836236]<<2)>>2]|0;c[b+908>>2]=d;c[b+912>>2]=d+256;c[b+916>>2]=d+512;c[b+920>>2]=d+768;c[b+924>>2]=d+1024;c[b+928>>2]=d+1280;c[b+932>>2]=d+1536;c[b+936>>2]=d+1792;c[b+940>>2]=d+2048;c[b+944>>2]=d+2304;c[b+948>>2]=d+2560;c[b+952>>2]=d+2816;c[b+956>>2]=d+3072;c[b+960>>2]=d+3328;c[b+964>>2]=d+3584;c[b+968>>2]=d+3840;e=208;f=208;while(1){c[b+76+(f+256<<2)>>2]=d+((f<<8)-53248);g=e+1&65535;if((g&65535)>223){h=208;i=208;break}else{e=g;f=g&65535}}while(1){f=d+((i<<8)-53248)|0;c[b+76+(i+512<<2)>>2]=f;c[b+76+(i+768<<2)>>2]=f;f=h+1&65535;if((f&65535)>223){break}else{h=f;i=f&65535}}return}else{i=c[2386454]|0;h=c[9757320+(c[1836236]<<2)>>2]|0;c[h+908>>2]=i;c[h+912>>2]=i+256;c[h+916>>2]=i+512;c[h+920>>2]=i+768;c[h+924>>2]=i+1024;c[h+928>>2]=i+1280;c[h+932>>2]=i+1536;c[h+936>>2]=i+1792;c[h+940>>2]=i+2048;c[h+944>>2]=i+2304;c[h+948>>2]=i+2560;c[h+952>>2]=i+2816;c[h+956>>2]=i+3072;c[h+960>>2]=i+3328;c[h+964>>2]=i+3584;c[h+968>>2]=i+3840;b=208;d=208;while(1){c[h+76+(d+256<<2)>>2]=i+((d<<8)-53248);f=b+1&65535;if((f&65535)>223){j=208;k=208;break}else{b=f;d=f&65535}}while(1){d=i+((k<<8)-53248)|0;c[h+76+(k+512<<2)>>2]=d;c[h+76+(k+768<<2)>>2]=d;d=j+1&65535;if((d&65535)>223){break}else{j=d;k=d&65535}}return}}function ebx(b){b=b|0;var c=0;switch(b&255|0){case 3:{c=a[9550474]|0;break};case 1:{c=a[9550472]|0;break};case 6:{c=-1;break};case 4:{c=a[9635073]|0;break};case 2:{c=a[9550473]|0;break};case 0:{c=a[9635072]|0;break};default:{c=0}}return c|0}function eby(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;e=b&65535;if((e|0)==57345){a[9578896]=d;b=c[3529756]|0;f=(d&255)>>>4<<18&262144;g=b+f|0;c[3541206]=g;c[3541190]=g;c[3541198]=g;c[3541191]=b+(f|256);c[3541199]=b+(f|65536);c[3541192]=b+(f|512);c[3541200]=b+(f|131072);c[3541193]=b+(f|768);c[3541201]=b+(f|196608);return}else if((e|0)==57348){Uv(0,d);return}else{return}}function ebz(b){b=b|0;var d=0,e=0;d=b&65535;if((d|0)==57348){e=c[2113156]&255}else if((d|0)==57345){e=a[9578896]|0}else if((d|0)==57344){a[9706117]=0;e=a[c[3528276]|0]|0}else{e=0}return e|0}function ebA(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4722924+(b*112|0)>>2];c[a+104>>2]=c[4722928+(b*112|0)>>2];c[a+108>>2]=c[4722932+(b*112|0)>>2];d=0;return d|0}function ebB(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=4722824+(b*112|0);e=0;return e|0}function ebC(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1942728+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function ebD(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5435384+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function ebE(){var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0;e=i;i=i+1320|0;f=e|0;g=e+112|0;h=e+120|0;j=e+232|0;k=e+240|0;l=e+352|0;m=e+360|0;n=e+472|0;o=e+480|0;p=e+592|0;q=e+600|0;r=e+712|0;s=e+720|0;t=e+832|0;u=e+840|0;v=e+952|0;w=e+960|0;x=e+1072|0;y=e+1080|0;z=e+1192|0;A=e+1200|0;B=e+1312|0;c[2424]=5800;c[2414960]=0;c[3529240]=0;c[3529196]=131072;c[3530840]=196608;c[3530604]=2293760;c[3529756]=3342336;c[3530002]=3866624;c[2414664]=3870720;c[3529328]=3870720;c[2386214]=3878912;c[2386454]=3883008;c[2387870]=3887104;c[2387194]=3889152;c[3529288]=3891200;c[3528276]=3895296;c[2411654]=3895297;C=0;while(1){if((C|0)>=1024){break}D=9638528+(C<<2)|0;if((c[D>>2]|0)==0){E=51683;break}else{C=C+1|0}}do{if((E|0)==51683){C=gGq(3895297)|0;c[D>>2]=C;if((C|0)==0){break}c[2414960]=C;gGz(C|0,0,3895297);c[3529240]=C;c[3529196]=C+131072;c[3530840]=C+196608;c[3530604]=C+2293760;c[3529756]=C+3342336;c[3530002]=C+3866624;F=C+3870720|0;c[2414664]=F;c[3529328]=F;c[2386214]=C+3878912;c[2386454]=C+3883008;c[2387870]=C+3887104;c[2387194]=C+3889152;c[3529288]=C+3891200;c[3528276]=C+3895296;F=C+3895297|0;c[2411654]=F;c[2414194]=F;if((c[3542200]|0)==0){G=1;i=e;return G|0}F=A+108|0;c[F>>2]=0;H=A+100|0;c[H>>2]=0;I=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[I&16383](A,0)|0;do{if((c[F>>2]|0)!=0){I=c[H>>2]|0;c[B>>2]=9534384;J=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[J&16383](B,0,0)|0;if((I|0)<1){G=1;i=e;return G|0}if((gzL(C,0,0)|0)==0){break}else{G=1}i=e;return G|0}}while(0);C=c[3529196]|0;if((c[3542200]|0)==0){G=1;i=e;return G|0}H=y+108|0;c[H>>2]=0;F=y+100|0;c[F>>2]=0;I=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[I&16383](y,1)|0;do{if((c[H>>2]|0)!=0){I=c[F>>2]|0;c[z>>2]=9534384;J=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[J&16383](z,1,0)|0;if((I|0)<1){G=1;i=e;return G|0}if((gzL(C,0,1)|0)==0){break}else{G=1}i=e;return G|0}}while(0);C=c[3530840]|0;if((c[3542200]|0)==0){G=1;i=e;return G|0}F=w+108|0;c[F>>2]=0;H=w+100|0;c[H>>2]=0;I=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[I&16383](w,2)|0;do{if((c[F>>2]|0)!=0){I=c[H>>2]|0;c[x>>2]=9534384;J=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[J&16383](x,2,0)|0;if((I|0)<1){G=1;i=e;return G|0}if((gzL(C,0,2)|0)==0){break}else{G=1}i=e;return G|0}}while(0);C=(c[3530840]|0)+262144|0;if((c[3542200]|0)==0){G=1;i=e;return G|0}H=u+108|0;c[H>>2]=0;F=u+100|0;c[F>>2]=0;I=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[I&16383](u,3)|0;do{if((c[H>>2]|0)!=0){I=c[F>>2]|0;c[v>>2]=9534384;J=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[J&16383](v,3,0)|0;if((I|0)<1){G=1;i=e;return G|0}if((gzL(C,0,3)|0)==0){break}else{G=1}i=e;return G|0}}while(0);C=(c[3530840]|0)+524288|0;if((c[3542200]|0)==0){G=1;i=e;return G|0}F=s+108|0;c[F>>2]=0;H=s+100|0;c[H>>2]=0;I=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[I&16383](s,4)|0;do{if((c[F>>2]|0)!=0){I=c[H>>2]|0;c[t>>2]=9534384;J=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[J&16383](t,4,0)|0;if((I|0)<1){G=1;i=e;return G|0}if((gzL(C,0,4)|0)==0){break}else{G=1}i=e;return G|0}}while(0);C=(c[3530840]|0)+786432|0;if((c[3542200]|0)==0){G=1;i=e;return G|0}H=q+108|0;c[H>>2]=0;F=q+100|0;c[F>>2]=0;I=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[I&16383](q,5)|0;do{if((c[H>>2]|0)!=0){I=c[F>>2]|0;c[r>>2]=9534384;J=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[J&16383](r,5,0)|0;if((I|0)<1){G=1;i=e;return G|0}if((gzL(C,0,5)|0)==0){break}else{G=1}i=e;return G|0}}while(0);C=c[3530604]|0;if((c[3542200]|0)==0){G=1;i=e;return G|0}F=o+108|0;c[F>>2]=0;H=o+100|0;c[H>>2]=0;I=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[I&16383](o,6)|0;do{if((c[F>>2]|0)!=0){I=c[H>>2]|0;c[p>>2]=9534384;J=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[J&16383](p,6,0)|0;if((I|0)<1){G=1;i=e;return G|0}if((gzL(C,0,6)|0)==0){break}else{G=1}i=e;return G|0}}while(0);C=(c[3530604]|0)+262144|0;if((c[3542200]|0)==0){G=1;i=e;return G|0}H=m+108|0;c[H>>2]=0;F=m+100|0;c[F>>2]=0;I=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[I&16383](m,7)|0;do{if((c[H>>2]|0)!=0){I=c[F>>2]|0;c[n>>2]=9534384;J=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[J&16383](n,7,0)|0;if((I|0)<1){G=1;i=e;return G|0}if((gzL(C,0,7)|0)==0){break}else{G=1}i=e;return G|0}}while(0);C=(c[3530604]|0)+524288|0;if((c[3542200]|0)==0){G=1;i=e;return G|0}F=k+108|0;c[F>>2]=0;H=k+100|0;c[H>>2]=0;I=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[I&16383](k,8)|0;do{if((c[F>>2]|0)!=0){I=c[H>>2]|0;c[l>>2]=9534384;J=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[J&16383](l,8,0)|0;if((I|0)<1){G=1;i=e;return G|0}if((gzL(C,0,8)|0)==0){break}else{G=1}i=e;return G|0}}while(0);C=(c[3530604]|0)+786432|0;if((c[3542200]|0)==0){G=1;i=e;return G|0}H=h+108|0;c[H>>2]=0;F=h+100|0;c[F>>2]=0;I=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[I&16383](h,9)|0;do{if((c[H>>2]|0)!=0){I=c[F>>2]|0;c[j>>2]=9534384;J=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[J&16383](j,9,0)|0;if((I|0)<1){G=1;i=e;return G|0}if((gzL(C,0,9)|0)==0){break}else{G=1}i=e;return G|0}}while(0);C=c[3529756]|0;if((c[3542200]|0)==0){G=1;i=e;return G|0}F=f+108|0;c[F>>2]=0;H=f+100|0;c[H>>2]=0;I=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[I&16383](f,10)|0;do{if((c[F>>2]|0)==0){K=0}else{I=c[H>>2]|0;c[g>>2]=9534384;J=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[J&16383](g,10,0)|0;if((I|0)<1){G=1;i=e;return G|0}if((gzL(C,0,10)|0)==0){K=0;break}else{G=1}i=e;return G|0}}while(0);while(1){if((K|0)>=1024){break}L=9638528+(K<<2)|0;if((c[L>>2]|0)==0){E=51731;break}else{K=K+1|0}}L68605:do{if((E|0)==51731){C=gGq(1048576)|0;c[L>>2]=C;if((C|0)==0){break}gGz(C|0,0,1048576);H=c[3530840]|0;F=0;while(1){a[C+F|0]=~a[H+F|0];I=F+1|0;if((I|0)<1048576){F=I}else{M=0;break}}do{F=M<<6;gGz(H+F|0,0,64);I=0;do{J=1<<3-I;N=(c[613216+(I<<2)>>2]|0)+F|0;O=0;do{P=N+(c[609008+(O<<2)>>2]|0)|0;Q=(O<<3)+F|0;R=0;do{S=P+(c[614800+(R<<2)>>2]|0)|0;if(((d[C+((S|0)/8|0)|0]|0)&128>>>((S&7)>>>0)|0)!=0){S=H+(Q+R)|0;a[S]=(d[S]|0|J)&255}R=R+1|0;}while((R|0)<8);O=O+1|0;}while((O|0)<8);I=I+1|0;}while((I|0)<4);M=M+1|0;}while((M|0)<32768);H=c[3530604]|0;I=0;while(1){a[C+I|0]=~a[H+I|0];F=I+1|0;if((F|0)<1048576){I=F}else{T=0;break}}while(1){I=T<<8;gGz(H+I|0,0,256);F=0;do{O=1<<3-F;J=(c[613216+(F<<2)>>2]|0)+I|0;N=0;do{R=J+(c[609008+(N<<2)>>2]|0)|0;Q=(N<<4)+I|0;P=0;do{S=R+(c[609904+(P<<2)>>2]|0)|0;if(((d[C+((S|0)/8|0)|0]|0)&128>>>((S&7)>>>0)|0)!=0){S=H+(Q+P)|0;a[S]=(d[S]|0|O)&255}P=P+1|0;}while((P|0)<16);N=N+1|0;}while((N|0)<16);F=F+1|0;}while((F|0)<4);F=T+1|0;if((F|0)<4096){T=F}else{U=0;break}}while(1){if((U|0)>=1024){break L68605}V=9638528+(U<<2)|0;if((c[V>>2]|0)==(C|0)){break}else{U=U+1|0}}gGr(C);c[V>>2]=0}}while(0);fwR(0);H=c[2439330]|0;F=(H|0)==0;if(!F){I=H;gGC(9706056,I|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];I=c[3528484]|0;c[2076596]=I;N=c[2417276]|0;c[3541536]=N;c[1836236]=0;O=c[3529240]|0;J=0;P=0;while(1){c[H+76+(P<<2)>>2]=O+(P<<8);Q=J+1&65535;if((Q&65535)>127){W=0;X=0;break}else{J=Q;P=Q&65535}}while(1){P=O+(X<<8)|0;c[H+76+(X+512<<2)>>2]=P;c[H+76+(X+768<<2)>>2]=P;P=W+1&65535;if((P&65535)>127){break}else{W=P;X=P&65535}}O=c[2387194]|0;c[H+844>>2]=O;P=O+256|0;c[H+848>>2]=P;J=O+512|0;c[H+852>>2]=J;Q=O+768|0;c[H+856>>2]=Q;R=O+1024|0;c[H+860>>2]=R;S=O+1280|0;c[H+864>>2]=S;Y=O+1536|0;c[H+868>>2]=Y;Z=O+1792|0;c[H+872>>2]=Z;c[H+2892>>2]=O;c[H+3916>>2]=O;c[H+2896>>2]=P;c[H+3920>>2]=P;c[H+2900>>2]=J;c[H+3924>>2]=J;c[H+2904>>2]=Q;c[H+3928>>2]=Q;c[H+2908>>2]=R;c[H+3932>>2]=R;c[H+2912>>2]=S;c[H+3936>>2]=S;c[H+2916>>2]=Y;c[H+3940>>2]=Y;c[H+2920>>2]=Z;c[H+3944>>2]=Z;Z=c[2387870]|0;c[H+876>>2]=Z;Y=Z+256|0;c[H+880>>2]=Y;S=Z+512|0;c[H+884>>2]=S;R=Z+768|0;c[H+888>>2]=R;Q=Z+1024|0;c[H+892>>2]=Q;J=Z+1280|0;c[H+896>>2]=J;P=Z+1536|0;c[H+900>>2]=P;O=Z+1792|0;c[H+904>>2]=O;c[H+1900>>2]=Z;c[H+1904>>2]=Y;c[H+1908>>2]=S;c[H+1912>>2]=R;c[H+1916>>2]=Q;c[H+1920>>2]=J;c[H+1924>>2]=P;c[H+1928>>2]=O;c[H+2924>>2]=Z;c[H+3948>>2]=Z;c[H+2928>>2]=Y;c[H+3952>>2]=Y;c[H+2932>>2]=S;c[H+3956>>2]=S;c[H+2936>>2]=R;c[H+3960>>2]=R;c[H+2940>>2]=Q;c[H+3964>>2]=Q;c[H+2944>>2]=J;c[H+3968>>2]=J;c[H+2948>>2]=P;c[H+3972>>2]=P;c[H+2952>>2]=O;c[H+3976>>2]=O;O=c[2386214]|0;c[H+908>>2]=O;c[H+912>>2]=O+256;c[H+916>>2]=O+512;c[H+920>>2]=O+768;c[H+924>>2]=O+1024;c[H+928>>2]=O+1280;c[H+932>>2]=O+1536;c[H+936>>2]=O+1792;c[H+940>>2]=O+2048;c[H+944>>2]=O+2304;c[H+948>>2]=O+2560;c[H+952>>2]=O+2816;c[H+956>>2]=O+3072;c[H+960>>2]=O+3328;c[H+964>>2]=O+3584;c[H+968>>2]=O+3840;P=208;J=208;while(1){c[H+76+(J+256<<2)>>2]=O+((J<<8)-53248);Q=P+1&65535;if((Q&65535)>223){_=208;$=208;break}else{P=Q;J=Q&65535}}while(1){J=O+(($<<8)-53248)|0;c[H+76+($+512<<2)>>2]=J;c[H+76+($+768<<2)>>2]=J;J=_+1&65535;if((J&65535)>223){break}else{_=J;$=J&65535}}O=c[3529328]|0;J=224;P=224;while(1){c[H+76+(P<<2)>>2]=O+((P<<8)-57344);Q=J+1&65535;if((Q&65535)>255){aa=224;ab=224;break}else{J=Q;P=Q&65535}}while(1){c[H+76+(ab+256<<2)>>2]=O+((ab<<8)-57344);P=aa+1&65535;if((P&65535)>255){ac=224;ad=224;break}else{aa=P;ab=P&65535}}while(1){P=O+((ad<<8)-57344)|0;c[H+76+(ad+512<<2)>>2]=P;c[H+76+(ad+768<<2)>>2]=P;P=ac+1&65535;if((P&65535)>255){break}else{ac=P;ad=P&65535}}c[H+4184>>2]=36;c[H+4176>>2]=2834;c[H+4172>>2]=2746;if(!F){O=H;gGC(O|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=I;c[2417276]=N;c[1836236]=-1;fwR(1);O=c[2439331]|0;P=(O|0)==0;if(!P){J=O;gGC(9706056,J|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];J=c[3528485]|0;c[2076596]=J;Q=c[2417277]|0;c[3541536]=Q;c[1836236]=1;R=c[3529196]|0;S=0;Y=0;while(1){c[O+76+(Y<<2)>>2]=R+(Y<<8);Z=S+1&65535;if((Z&65535)>127){ae=0;af=0;break}else{S=Z;Y=Z&65535}}while(1){Y=R+(af<<8)|0;c[O+76+(af+512<<2)>>2]=Y;c[O+76+(af+768<<2)>>2]=Y;Y=ae+1&65535;if((Y&65535)>127){break}else{ae=Y;af=Y&65535}}R=c[3529288]|0;c[O+1036>>2]=R;c[O+1040>>2]=R+256;c[O+1044>>2]=R+512;c[O+1048>>2]=R+768;c[O+1052>>2]=R+1024;c[O+1056>>2]=R+1280;c[O+1060>>2]=R+1536;c[O+1064>>2]=R+1792;c[O+1068>>2]=R+2048;c[O+1072>>2]=R+2304;c[O+1076>>2]=R+2560;c[O+1080>>2]=R+2816;c[O+1084>>2]=R+3072;c[O+1088>>2]=R+3328;c[O+1092>>2]=R+3584;c[O+1096>>2]=R+3840;Y=240;S=240;while(1){c[O+76+(S+256<<2)>>2]=R+((S<<8)-61440);N=Y+1&65535;if((N&65535)>255){ah=240;ai=240;break}else{Y=N;S=N&65535}}while(1){S=R+((ai<<8)-61440)|0;c[O+76+(ai+512<<2)>>2]=S;c[O+76+(ai+768<<2)>>2]=S;S=ah+1&65535;if((S&65535)>255){break}else{ah=S;ai=S&65535}}c[O+4184>>2]=1408;c[O+4180>>2]=2834;if(!P){R=O;gGC(R|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=J;c[2417277]=Q;c[1836236]=-1;Ux(0,8e3,0);c[2407030]=256;c[2407068]=3;R=c[642608+(c[2436]<<2)>>2]|0;S=c[R+128>>2]|0;if((c[R+52>>2]&4|0)==0){c[2113068]=S;Y=c[R+132>>2]|0;c[2113070]=Y;c[2443814]=S;c[2440436]=Y;aj=S;ak=Y}else{c[2113070]=S;Y=c[R+132>>2]|0;c[2113068]=Y;c[2440436]=S;c[2443814]=Y;aj=Y;ak=S}S=ag(aj<<1,ak)|0;Y=gGq(S)|0;c[2112926]=Y;if((Y|0)!=0){gGz(Y|0,0,S|0)}S=c[2414664]|0;gGz(S|0,0,(c[2411654]|0)-S|0);S=c[2439330]|0;Y=(S|0)==0;if(!Y){R=S;gGC(9706056,R|0,76)|0}R=c[2438118]|0;c[2433530]=R;N=c[3528484]|0;c[2076596]=N;I=c[2417276]|0;c[3541536]=I;c[1836236]=0;gGz(9706056,0,76);if(!Y){Y=S;gGC(Y|0,9706056,76)|0}c[2438118]=R;c[3528484]=N;c[2417276]=I;c[1836236]=-1;I=c[2439331]|0;N=(I|0)==0;if(!N){R=I;gGC(9706056,R|0,76)|0}R=c[2438119]|0;c[2433530]=R;Y=c[3528485]|0;c[2076596]=Y;S=c[2417277]|0;c[3541536]=S;c[1836236]=1;gGz(9706056,0,76);if(!N){N=I;gGC(N|0,9706056,76)|0}c[2438119]=R;c[3528485]=Y;c[2417277]=S;c[1836236]=-1;S=c[3529756]|0;c[3541206]=S;c[2113156]=0;a[9628264]=0;c[2407033]=0;c[3541190]=S;c[3541198]=S;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=S+256;c[3541199]=S+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=S+512;c[3541200]=S+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=S+768;c[3541201]=S+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;a[9578896]=0;a[9578760]=0;a[9620408]=0;G=0;i=e;return G|0}}while(0);c[2414960]=0;G=1;i=e;return G|0}function ebF(){var a=0,b=0,d=0,e=0;c[2113070]=0;c[2113068]=0;a=c[2112926]|0;if((a|0)!=0){gGr(a);c[2112926]=0}Uw(0);c[3541206]=0;fwZ();a=c[2414960]|0;b=0;while(1){if((b|0)>=1024){d=51838;break}e=9638528+(b<<2)|0;if((c[e>>2]|0)==(a|0)){break}else{b=b+1|0}}if((d|0)==51838){c[2414960]=0;return 0}gGr(a);c[e>>2]=0;c[2414960]=0;return 0}function ebG(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if((a[9624144]|0)!=0){d=c[2414664]|0;gGz(d|0,0,(c[2411654]|0)-d|0);d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;h=c[2417276]|0;c[3541536]=h;c[1836236]=0;gGz(9706056,0,76);if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=h;c[1836236]=-1;h=c[2439331]|0;g=(h|0)==0;if(!g){f=h;gGC(9706056,f|0,76)|0}f=c[2438119]|0;c[2433530]=f;e=c[3528485]|0;c[2076596]=e;d=c[2417277]|0;c[3541536]=d;c[1836236]=1;gGz(9706056,0,76);if(!g){g=h;gGC(g|0,9706056,76)|0}c[2438119]=f;c[3528485]=e;c[2417277]=d;c[1836236]=-1;d=c[3529756]|0;c[3541206]=d;c[2113156]=0;a[9628264]=0;c[2407033]=0;c[3541190]=d;c[3541198]=d;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=d+256;c[3541199]=d+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=d+512;c[3541200]=d+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=d+768;c[3541201]=d+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;a[9578896]=0;a[9578760]=0;a[9620408]=0}gGz(9550472,-1|0,3);d=0;e=-1;f=-1;g=-1;do{e=((a[9633392+d|0]&1)<<d^e&255)&255;f=((a[9631264+d|0]&1)<<d^f&255)&255;g=((a[9629544+d|0]&1)<<d^g&255)&255;d=d+1|0;}while((d|0)<8);a[9550472]=e;a[9550473]=f;a[9550474]=g;g=0;do{f=c[2439330]|0;if((f|0)!=0){e=f;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;e=c[2438118]|0;c[2433530]=e;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;if((a[f+4188|0]|0)==0){f=gfc(1e4)|0;i=(c[2433530]|0)+f|0}else{i=e+1e4|0}c[2433530]=i;if((g|0)==9){a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0}e=c[1836236]|0;f=c[9757320+(e<<2)>>2]|0;if((f|0)!=0){d=f;gGC(d|0,9706056,76)|0}c[9752472+(e<<2)>>2]=c[2433530];c[14113936+(e<<2)>>2]=c[2076596];c[9669104+(e<<2)>>2]=c[3541536];c[1836236]=-1;e=c[2439331]|0;if((e|0)!=0){d=e;gGC(9706056,d|0,76)|0}b[4853030]=c[2426515]&65535;d=c[2438119]|0;c[2433530]=d;c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;if((a[e+4188|0]|0)==0){f=gfc(1e4)|0;h=c[1836236]|0;j=(c[2433530]|0)+f|0;k=h;l=c[9757320+(h<<2)>>2]|0}else{j=d+1e4|0;k=1;l=e}c[2433530]=j;if((l|0)!=0){e=l;gGC(e|0,9706056,76)|0}c[9752472+(k<<2)>>2]=j;c[14113936+(k<<2)>>2]=c[2076596];c[9669104+(k<<2)>>2]=c[3541536];c[1836236]=-1;g=g+1|0;}while((g|0)<10);g=c[2112964]|0;if((g|0)!=0){Uu(0,g,a[9688]|0?534:0)}if((c[2112968]|0)==0){return 0}ebH()|0;return 0}function ebH(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if((a[9547440]|0)!=0){b=c[2387194]|0;e=c[3530002]|0;f=0;do{g=d[b+(f|1)|0]|0;h=d[b+f|0]|0;i=(g<<8|h)>>>5&31;c[e+(((f|0)/2|0)<<2)>>2]=g>>>2<<11&63488|h&31|(i<<3|i>>>2)<<3&2016;f=f+2|0;}while((f|0)<2048);a[9547440]=0}f=c[2113070]|0;e=c[2386214]|0;b=c[2387870]|0;i=c[2112926]|0;h=c[3530840]|0;g=c[2113068]|0;j=0;do{k=(j<<3&504)-64|0;l=(j>>6<<3)-8|0;if((k|0)<(g|0)&(((l|0)>=(f|0)|(l|0)<0|(k|0)<0)^1)){m=j<<1;n=d[e+(m|1)|0]<<8;o=n&16128|d[e+m|0];m=a[b+j|0]&63;do{if((n&8192|0)==0){p=o}else{q=d[9620408]|0;if((q&2|0)==0){p=o;break}p=(8192<<(q&1))+o|0}}while(0);Si(i,p,k,l,m,4,0,h)}j=j+1|0;}while((j|0)<2048);j=c[2386454]|0;h=c[3530604]|0;p=4032;do{b=d[j+(p|1)|0]|0;e=b&224;f=e<<3|d[j+p|0];g=d[j+(p|3)|0]|b<<4&256;o=(d[j+(p|2)|0]|0)+8&255;do{if((e|0)==0){r=f}else{n=d[9620408]|0;if((n&32|0)==0){r=f;break}r=(1024<<(n&1))+f|0}}while(0);SH(i,r,g-64|0,o-16|0,b&15,4,15,0,h);p=p-32|0;}while((p|0)>-1);R8(c[3530002]|0);return 0}function ebI(a,e){a=a|0;e=e|0;var f=0,g=0,h=0,j=0,k=0;f=i;i=i+64|0;g=f|0;h=f+16|0;j=f+32|0;k=f+48|0;if((e|0)!=0){c[e>>2]=169735}if((a&32|0)!=0){gGz(k|0,0,12);e=c[2414664]|0;c[k>>2]=e;c[k+4>>2]=(c[2411654]|0)-e;c[k+12>>2]=162152;e=c[2076592]|0;gj[e&4095](k)|0}if((a&64|0)!=0){fw$(a);Ut(0);gGz(j|0,0,12);c[j>>2]=9578896;c[j+4>>2]=1;c[j+12>>2]=253176;k=c[2076592]|0;gj[k&4095](j)|0;gGz(h|0,0,12);c[h>>2]=9620408;c[h+4>>2]=1;c[h+12>>2]=492016;j=c[2076592]|0;gj[j&4095](h)|0;gGz(g|0,0,12);c[g>>2]=9578760;c[g+4>>2]=1;c[g+12>>2]=96480;h=c[2076592]|0;gj[h&4095](g)|0}if((a&2|0)==0){i=f;return 0}a=c[2439330]|0;g=(a|0)==0;if(!g){h=a;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];h=c[3528484]|0;c[2076596]=h;j=c[2417276]|0;c[3541536]=j;c[1836236]=0;ebw(d[9578760]|0);if(!g){g=a;gGC(g|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=h;c[2417276]=j;c[1836236]=-1;j=c[3529756]|0;h=(d[9578896]|0)>>>4<<18&262144;g=j+h|0;c[3541206]=g;c[3541190]=g;c[3541198]=g;c[3541191]=j+(h|256);c[3541199]=j+(h|65536);c[3541192]=j+(h|512);c[3541200]=j+(h|131072);c[3541193]=j+(h|768);c[3541201]=j+(h|196608);i=f;return 0}function ebJ(a){a=a|0;var b=0;if((a|0)!=1048639){b=0;return b|0}b=c[2113156]&255;return b|0}function ebK(a){a=a|0;var b=0;if((a|0)==1048584){b=~(d[9625684]|0)}else if((a|0)==1048578){b=~((d[9625683]|0)<<8|(d[9625682]|0))}else if((a|0)==1048576){b=~(d[9625680]|0)}else if((a|0)==1048586){b=~(d[9625686]|0)}else{b=0}return b|0}function ebL(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;if((a|0)==1048625){d=b&7;if((c[159658]|0)==(d|0)){return}c[159658]=d;e=c[3541206]|0;f=e+196608|0;g=e+((d<<16)+262144)|0;gGC(f|0,g|0,65536)|0;return}else if((a|0)==1048639){Uv(0,b);return}else{return}}function ebM(a,d){a=a|0;d=d|0;if((a|0)==1048638){Uv(0,d&255);return}else if((a|0)==1048600){c[2385212]=(d&65535)<<11;return}else if((a|0)==1048606){b[7056548]=d&255;return}else if((a|0)==1245186){b[(c[2406858]|0)+2>>1]=d;return}else if((a|0)==1245184){b[c[2406858]>>1]=d;return}else if((a|0)==1245188){b[(c[2406858]|0)+4>>1]=d;return}else if((a|0)==1245190){b[(c[2406858]|0)+6>>1]=d;return}else{return}}function ebN(a,d){a=a|0;d=d|0;var e=0;e=(a-1179648|0)>>>1;b[(c[2411428]|0)+(e<<1)>>1]=d;a=d&65535;c[(c[2385762]|0)+(e<<2)>>2]=a<<8&2048|a&61440|(a<<2&8|a&240)>>>3|(a>>>4&240|a<<1&8|a>>>9&4)<<3&2016;return}function ebO(a){a=a|0;var c=0;if(a<<16>>16!=-8192){c=0;return c|0}c=b[7056548]&255;return c|0}function ebP(b){b=b|0;var e=0,f=0,g=0,i=0,j=0.0,k=0.0;e=b&255;if((e|0)==1){if((c[2405114]|0)!=1){f=0;return f|0}if((d[(c[3541518]|0)+304|0]|0)>=16){f=0;return f|0}b=c[2383582]|0;g=c[14168912+(b*252|0)>>2]|0;if((g|0)>15){f=0;return f|0}do{if((g|0)==14){i=c[14168896+(b*252|0)>>2]|0;if((i|0)==0){break}a[14168930+(b*252|0)|0]=gj[i&4095](0)|0}else if((g|0)==15){i=c[14168900+(b*252|0)>>2]|0;if((i|0)==0){break}a[14168931+(b*252|0)|0]=gj[i&4095](0)|0}}while(0);f=a[14168916+(b*252|0)+g|0]|0;return f|0}else if((e|0)==136){f=c[2113157]&255;return f|0}else if((e|0)==0){if((c[2405114]|0)!=1){f=1;return f|0}g=c[3541518]|0;b=g+296|0;j=+h[b>>3];do{if(j!=0.0){k=+h[6675];if(j-(k+ +gC[c[2429842]&255]())<=0.0){h[b>>3]=0.0;break}f=a[g+307|0]|-128;return f|0}}while(0);f=a[g+307|0]|0;return f|0}else if((e|0)==128){f=c[2113156]&255;return f|0}else{f=0;return f|0}return 0}function ebQ(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;switch(b&255|0){case 1:{if((c[2405114]|0)!=1){return}lS(0,1,d);return};case 136:{Uv(1,d);return};case 145:{b=c[3541206]|0;e=(d&255)<<16;c[3541191]=b+(e|256);c[3541199]=b+e;return};case 151:{e=c[3541206]|0;b=((d&255)<<16)+2097152|0;c[3541197]=e+(b|768);c[3541205]=e+b;return};case 146:{b=c[3541206]|0;e=(d&255)<<16;c[3541192]=b+(e|512);c[3541200]=b+e;return};case 0:{if((c[2405114]|0)!=1){return}e=c[3541518]|0;b=e+256|0;a[e+304|0]=d;f=d&255;if((d&255)<16){c[14168912+((c[2383582]|0)*252|0)>>2]=f&15}if((d-45&255)>=3){return}if((f|0)==45){g=e+312|0;h=a[g]|2;a[g]=h;i=h}else if((f|0)==47){a[e+312|0]=0;i=0}else if((f|0)==0){a[e+312|0]=2;i=2}else if((f|0)==46){f=e+312|0;h=a[f]|1;a[f]=h;i=h}else{i=a[e+312|0]|0}e=i&3;i=c[7461744+(e<<2)>>2]|0;lI(b,i,i,c[7461728+(e<<2)>>2]|0);return};case 148:{e=(c[3541206]|0)+(((d&255)<<16)+2097152)|0;c[3541194]=e;c[3541202]=e;return};case 147:{e=c[3541206]|0;i=(d&255)<<16;c[3541193]=e+(i|768);c[3541201]=e+i;return};case 144:{i=(c[3541206]|0)+((d&255)<<16)|0;c[3541190]=i;c[3541198]=i;return};case 128:{Uv(0,d);return};case 149:{i=c[3541206]|0;e=((d&255)<<16)+2097152|0;c[3541195]=i+(e|256);c[3541203]=i+e;return};case 150:{e=c[3541206]|0;i=((d&255)<<16)+2097152|0;c[3541196]=e+(i|512);c[3541204]=e+i;return};default:{return}}}function ebR(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2434580+(b*112|0)>>2];c[a+104>>2]=c[2434584+(b*112|0)>>2];c[a+108>>2]=c[2434588+(b*112|0)>>2];d=0;return d|0}function ebS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<22&(d|0)==0)){e=1;return e|0}c[a>>2]=2434480+(b*112|0);e=0;return e|0}function ebT(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>24){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1027248+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function ebU(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=24){if((a|0)==0){d=0;return d|0}e=a;f=2436944+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}f=b-25|0;if(f>>>0>23){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;a=2445008+(f*12|0)|0;c[b>>2]=c[a>>2];c[b+4>>2]=c[a+4>>2];c[b+8>>2]=c[a+8>>2];d=0;return d|0}function ebV(){var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0;d=i;i=i+2640|0;e=d|0;f=d+112|0;g=d+120|0;j=d+232|0;k=d+240|0;l=d+352|0;m=d+360|0;n=d+472|0;o=d+480|0;p=d+592|0;q=d+600|0;r=d+712|0;s=d+720|0;t=d+832|0;u=d+840|0;v=d+952|0;w=d+960|0;x=d+1072|0;y=d+1080|0;z=d+1192|0;A=d+1200|0;B=d+1312|0;C=d+1320|0;D=d+1432|0;E=d+1440|0;F=d+1552|0;G=d+1560|0;H=d+1672|0;I=d+1680|0;J=d+1792|0;K=d+1800|0;L=d+1912|0;M=d+1920|0;N=d+2032|0;O=d+2040|0;P=d+2152|0;Q=d+2160|0;R=d+2272|0;S=d+2280|0;T=d+2392|0;U=d+2400|0;V=d+2512|0;W=d+2520|0;X=d+2632|0;c[2385592]=4194304;Y=c[c[642608+(c[2436]<<2)>>2]>>2]|0;do{if((fa(Y|0,263136)|0)==0){Z=52055}else{if((fa(Y|0,188192)|0)==0){Z=52055;break}if((fa(Y|0,96408)|0)==0){c[2405114]=2;c[2385592]=589824;_=589824;break}if((fa(Y|0,582672)|0)==0){c[2405114]=3;_=4194304;break}else{$=1;i=d;return $|0}}}while(0);if((Z|0)==52055){c[2405114]=1;_=4194304}c[2426716]=0;c[2411336]=0;c[2411306]=1048576;c[2418082]=1179648;c[2418078]=6422528;c[2411316]=7471104;c[3541206]=24248320;Y=_+24248320|0;c[2405650]=Y;c[2411348]=Y;c[2411428]=_+24256512;c[2418188]=_+24260608;c[2418180]=_+24276992;c[2411372]=_+24281088;c[2406858]=_+24346624;Y=_+24346632|0;c[2411652]=Y;c[2385762]=Y;Y=_+24354824|0;c[2414192]=Y;_=Y;Y=0;while(1){if((Y|0)>=1024){break}aa=9638528+(Y<<2)|0;if((c[aa>>2]|0)==0){Z=52063;break}else{Y=Y+1|0}}do{if((Z|0)==52063){Y=gGq(_)|0;c[aa>>2]=Y;if((Y|0)==0){break}gGz(Y|0,0,_|0);c[2426716]=Y;gGz(Y|0,0,_|0);c[2411336]=Y;c[2411306]=Y+1048576;c[2418082]=Y+1179648;c[2418078]=Y+6422528;c[2411316]=Y+7471104;c[3541206]=Y+24248320;ab=c[2385592]|0;ac=Y+(ab+24248320)|0;c[2405650]=ac;c[2411348]=ac;c[2411428]=Y+(ab+24256512);c[2418188]=Y+(ab+24260608);c[2418180]=Y+(ab+24276992);c[2411372]=Y+(ab+24281088);c[2406858]=Y+(ab+24346624);ac=Y+(ab+24346632)|0;c[2411652]=ac;c[2385762]=ac;c[2414192]=Y+(ab+24354824);ab=0;while(1){if((ab|0)>=1024){$=1;Z=52220;break}ad=9638528+(ab<<2)|0;if((c[ad>>2]|0)==0){break}else{ab=ab+1|0}}if((Z|0)==52220){i=d;return $|0}ab=gGq(2097152)|0;c[ad>>2]=ab;if((ab|0)==0){$=1;i=d;return $|0}gGz(ab|0,0,2097152);Y=c[2405114]|0;do{if((Y|0)==2){ac=c[2411336]|0;if((c[3542200]|0)==0){$=1;i=d;return $|0}ae=G+108|0;c[ae>>2]=0;af=G+100|0;c[af>>2]=0;ah=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ah&16383](G,0)|0;do{if((c[ae>>2]|0)!=0){ah=c[af>>2]|0;c[H>>2]=9534384;ai=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ai&16383](H,0,0)|0;if((ah|0)<1){$=1;i=d;return $|0}if((gzL(ac,0,0)|0)==0){break}else{$=1}i=d;return $|0}}while(0);ac=(c[2411336]|0)+524288|0;if((c[3542200]|0)==0){$=1;i=d;return $|0}af=E+108|0;c[af>>2]=0;ae=E+100|0;c[ae>>2]=0;ah=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ah&16383](E,1)|0;do{if((c[af>>2]|0)!=0){ah=c[ae>>2]|0;c[F>>2]=9534384;ai=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ai&16383](F,1,0)|0;if((ah|0)<1){$=1;i=d;return $|0}if((gzL(ac,0,1)|0)==0){break}else{$=1}i=d;return $|0}}while(0);eb5(ab,c[2418082]|0,2,2097152);eb5(ab,(c[2418082]|0)+4194304|0,3,524288);ac=c[2418078]|0;do{if((c[3542200]|0)!=0){ae=C+108|0;c[ae>>2]=0;af=C+100|0;c[af>>2]=0;ah=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ah&16383](C,4)|0;if((c[ae>>2]|0)==0){break}ae=c[af>>2]|0;c[D>>2]=9534384;af=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[af&16383](D,4,0)|0;if((ae|0)<1){break}gzL(ac,0,4)|0}}while(0);eb6(ab,c[2411316]|0,5,2097152);eb6(ab,(c[2411316]|0)+4194304|0,6,2097152);eb6(ab,(c[2411316]|0)+8388608|0,7,2097152);eb6(ab,(c[2411316]|0)+12582912|0,8,2097152);ac=(c[3541206]|0)+65536|0;do{if((c[3542200]|0)!=0){ae=A+108|0;c[ae>>2]=0;af=A+100|0;c[af>>2]=0;ah=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ah&16383](A,9)|0;if((c[ae>>2]|0)==0){break}ae=c[af>>2]|0;c[B>>2]=9534384;af=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[af&16383](B,9,0)|0;if((ae|0)<1){break}gzL(ac,0,9)|0}}while(0);ac=c[3541206]|0;ae=ac+65536|0;gGC(ac|0,ae|0,196608)|0;aj=0}else if((Y|0)==1){ae=c[2411336]|0;if((c[3542200]|0)==0){$=1;i=d;return $|0}ac=W+108|0;c[ac>>2]=0;af=W+100|0;c[af>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](W,0)|0;do{if((c[ac>>2]|0)!=0){ah=c[af>>2]|0;c[X>>2]=9534384;ai=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ai&16383](X,0,0)|0;if((ah|0)<1){$=1;i=d;return $|0}if((gzL(ae,0,0)|0)==0){break}else{$=1}i=d;return $|0}}while(0);ae=(c[2411336]|0)+524288|0;if((c[3542200]|0)==0){$=1;i=d;return $|0}af=U+108|0;c[af>>2]=0;ac=U+100|0;c[ac>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](U,1)|0;do{if((c[af>>2]|0)!=0){ah=c[ac>>2]|0;c[V>>2]=9534384;ai=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ai&16383](V,1,0)|0;if((ah|0)<1){$=1;i=d;return $|0}if((gzL(ae,0,1)|0)==0){break}else{$=1}i=d;return $|0}}while(0);ae=c[2411306]|0;if((c[3542200]|0)==0){$=1;i=d;return $|0}ac=S+108|0;c[ac>>2]=0;af=S+100|0;c[af>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](S,2)|0;do{if((c[ac>>2]|0)!=0){ah=c[af>>2]|0;c[T>>2]=9534384;ai=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ai&16383](T,2,0)|0;if((ah|0)<1){$=1;i=d;return $|0}if((gzL(ae,0,2)|0)==0){break}else{$=1}i=d;return $|0}}while(0);eb5(ab,c[2418082]|0,3,1048576);eb5(ab,(c[2418082]|0)+2097152|0,4,1048576);eb5(ab,(c[2418082]|0)+4194304|0,5,524288);ae=c[2418078]|0;do{if((c[3542200]|0)!=0){af=Q+108|0;c[af>>2]=0;ac=Q+100|0;c[ac>>2]=0;ah=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ah&16383](Q,6)|0;if((c[af>>2]|0)==0){break}af=c[ac>>2]|0;c[R>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](R,6,0)|0;if((af|0)<1){break}gzL(ae,0,6)|0}}while(0);eb6(ab,c[2411316]|0,7,1048576);eb6(ab,(c[2411316]|0)+2097152|0,8,1048576);eb6(ab,(c[2411316]|0)+4194304|0,9,1048576);eb6(ab,(c[2411316]|0)+6291456|0,10,1048576);eb6(ab,(c[2411316]|0)+8388608|0,11,1048576);eb6(ab,(c[2411316]|0)+10485760|0,12,1048576);eb6(ab,(c[2411316]|0)+12582912|0,13,1048576);eb6(ab,(c[2411316]|0)+14680064|0,14,1048576);ae=c[3541206]|0;do{if((c[3542200]|0)!=0){af=O+108|0;c[af>>2]=0;ac=O+100|0;c[ac>>2]=0;ah=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ah&16383](O,15)|0;if((c[af>>2]|0)==0){break}af=c[ac>>2]|0;c[P>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](P,15,0)|0;if((af|0)<1){break}gzL(ae,0,15)|0}}while(0);ae=(c[3541206]|0)+1048576|0;do{if((c[3542200]|0)!=0){af=M+108|0;c[af>>2]=0;ac=M+100|0;c[ac>>2]=0;ah=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ah&16383](M,16)|0;if((c[af>>2]|0)==0){break}af=c[ac>>2]|0;c[N>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](N,16,0)|0;if((af|0)<1){break}gzL(ae,0,16)|0}}while(0);ae=(c[3541206]|0)+2097152|0;do{if((c[3542200]|0)!=0){af=K+108|0;c[af>>2]=0;ac=K+100|0;c[ac>>2]=0;ah=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ah&16383](K,17)|0;if((c[af>>2]|0)==0){break}af=c[ac>>2]|0;c[L>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](L,17,0)|0;if((af|0)<1){break}gzL(ae,0,17)|0}}while(0);ae=(c[3541206]|0)+3145728|0;if((c[3542200]|0)==0){aj=0;break}af=I+108|0;c[af>>2]=0;ac=I+100|0;c[ac>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](I,18)|0;if((c[af>>2]|0)==0){aj=0;break}af=c[ac>>2]|0;c[J>>2]=9534384;gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](J,18,0)|0;if((af|0)<1){aj=0;break}gzL(ae,0,18)|0;aj=0}else if((Y|0)==3){if((R6((c[2411336]|0)+1|0,0,2)|0)!=0){$=1;i=d;return $|0}if((R6(c[2411336]|0,1,2)|0)!=0){$=1;i=d;return $|0}ae=c[2411306]|0;if((c[3542200]|0)==0){$=1;i=d;return $|0}af=y+108|0;c[af>>2]=0;ac=y+100|0;c[ac>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](y,2)|0;do{if((c[af>>2]|0)!=0){ah=c[ac>>2]|0;c[z>>2]=9534384;ai=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ai&16383](z,2,0)|0;if((ah|0)<1){$=1;i=d;return $|0}if((gzL(ae,0,2)|0)==0){break}else{$=1}i=d;return $|0}}while(0);eb5(ab,c[2418082]|0,3,524288);eb5(ab,(c[2418082]|0)+1048576|0,4,524288);eb5(ab,(c[2418082]|0)+2097152|0,5,524288);eb5(ab,(c[2418082]|0)+3145728|0,6,524288);eb5(ab,(c[2418082]|0)+4194304|0,7,524288);ae=c[2418078]|0;do{if((c[3542200]|0)!=0){ac=w+108|0;c[ac>>2]=0;af=w+100|0;c[af>>2]=0;ah=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ah&16383](w,8)|0;if((c[ac>>2]|0)==0){break}ac=c[af>>2]|0;c[x>>2]=9534384;af=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[af&16383](x,8,0)|0;if((ac|0)<1){break}gzL(ae,0,8)|0}}while(0);eb6(ab,c[2411316]|0,0,1048576);eb6(ab,(c[2411316]|0)+2097152|0,1,1048576);eb6(ab,(c[2411316]|0)+4194304|0,2,1048576);eb6(ab,(c[2411316]|0)+6291456|0,3,1048576);eb6(ab,(c[2411316]|0)+8388608|0,4,1048576);eb6(ab,(c[2411316]|0)+10485760|0,5,1048576);eb6(ab,(c[2411316]|0)+12582912|0,6,1048576);eb6(ab,(c[2411316]|0)+14680064|0,7,1048576);ae=c[3541206]|0;do{if((c[3542200]|0)!=0){ac=u+108|0;c[ac>>2]=0;af=u+100|0;c[af>>2]=0;ah=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ah&16383](u,25)|0;if((c[ac>>2]|0)==0){break}ac=c[af>>2]|0;c[v>>2]=9534384;af=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[af&16383](v,25,0)|0;if((ac|0)<1){break}gzL(ae,0,25)|0}}while(0);ae=(c[3541206]|0)+524288|0;do{if((c[3542200]|0)!=0){ac=s+108|0;c[ac>>2]=0;af=s+100|0;c[af>>2]=0;ah=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ah&16383](s,26)|0;if((c[ac>>2]|0)==0){break}ac=c[af>>2]|0;c[t>>2]=9534384;af=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[af&16383](t,26,0)|0;if((ac|0)<1){break}gzL(ae,0,26)|0}}while(0);ae=(c[3541206]|0)+1048576|0;do{if((c[3542200]|0)!=0){ac=q+108|0;c[ac>>2]=0;af=q+100|0;c[af>>2]=0;ah=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ah&16383](q,27)|0;if((c[ac>>2]|0)==0){break}ac=c[af>>2]|0;c[r>>2]=9534384;af=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[af&16383](r,27,0)|0;if((ac|0)<1){break}gzL(ae,0,27)|0}}while(0);ae=(c[3541206]|0)+1572864|0;do{if((c[3542200]|0)!=0){ac=o+108|0;c[ac>>2]=0;af=o+100|0;c[af>>2]=0;ah=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ah&16383](o,28)|0;if((c[ac>>2]|0)==0){break}ac=c[af>>2]|0;c[p>>2]=9534384;af=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[af&16383](p,28,0)|0;if((ac|0)<1){break}gzL(ae,0,28)|0}}while(0);ae=(c[3541206]|0)+2097152|0;do{if((c[3542200]|0)!=0){ac=m+108|0;c[ac>>2]=0;af=m+100|0;c[af>>2]=0;ah=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ah&16383](m,29)|0;if((c[ac>>2]|0)==0){break}ac=c[af>>2]|0;c[n>>2]=9534384;af=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[af&16383](n,29,0)|0;if((ac|0)<1){break}gzL(ae,0,29)|0}}while(0);ae=(c[3541206]|0)+2621440|0;do{if((c[3542200]|0)!=0){ac=k+108|0;c[ac>>2]=0;af=k+100|0;c[af>>2]=0;ah=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ah&16383](k,30)|0;if((c[ac>>2]|0)==0){break}ac=c[af>>2]|0;c[l>>2]=9534384;af=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[af&16383](l,30,0)|0;if((ac|0)<1){break}gzL(ae,0,30)|0}}while(0);ae=(c[3541206]|0)+3145728|0;do{if((c[3542200]|0)!=0){ac=g+108|0;c[ac>>2]=0;af=g+100|0;c[af>>2]=0;ah=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ah&16383](g,31)|0;if((c[ac>>2]|0)==0){break}ac=c[af>>2]|0;c[j>>2]=9534384;af=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[af&16383](j,31,0)|0;if((ac|0)<1){break}gzL(ae,0,31)|0}}while(0);ae=(c[3541206]|0)+3670016|0;if((c[3542200]|0)==0){aj=0;break}ac=e+108|0;c[ac>>2]=0;af=e+100|0;c[af>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,32)|0;if((c[ac>>2]|0)==0){aj=0;break}ac=c[af>>2]|0;c[f>>2]=9534384;gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](f,32,0)|0;if((ac|0)<1){aj=0;break}gzL(ae,0,32)|0;aj=0}else{aj=0}}while(0);while(1){if((aj|0)>=1024){break}ak=9638528+(aj<<2)|0;if((c[ak>>2]|0)==(ab|0)){Z=52163;break}else{aj=aj+1|0}}if((Z|0)==52163){gGr(ab);c[ak>>2]=0}fxU(0,425984);if((c[2394]|0)==0){al=c[2112932]|0}else{c[2394]=0;Y=c[3532596]|0;c[2112932]=Y;ae=c[3532592]|0;if((ae|0)!=0){gGC(9104152,ae|0,280)|0}c[2113054]=c[2113060];al=Y}Y=c[2411336]|0;ae=al|0;ac=0;while(1){af=Y+ac|0;c[ae>>2]=af;c[ae+131072>>2]=af;af=ac+1024|0;if(af>>>0>1048575){break}else{ae=ae+4|0;ac=af}}ac=c[2411428]|0;ae=ac;c[al+4608>>2]=ae;c[al+135680>>2]=ae;ae=ac+1024|0;c[al+4612>>2]=ae;c[al+135684>>2]=ae;ae=ac+2048|0;c[al+4616>>2]=ae;c[al+135688>>2]=ae;ae=ac+3072|0;c[al+4620>>2]=ae;c[al+135692>>2]=ae;ae=c[2418188]|0;ac=ae;c[al+5120>>2]=ac;c[al+70656>>2]=ac;c[al+136192>>2]=ac;ac=ae+1024|0;c[al+5124>>2]=ac;c[al+70660>>2]=ac;c[al+136196>>2]=ac;ac=ae+2048|0;c[al+5128>>2]=ac;c[al+70664>>2]=ac;c[al+136200>>2]=ac;ac=ae+3072|0;c[al+5132>>2]=ac;c[al+70668>>2]=ac;c[al+136204>>2]=ac;ac=ae+4096|0;c[al+5136>>2]=ac;c[al+70672>>2]=ac;c[al+136208>>2]=ac;ac=ae+5120|0;c[al+5140>>2]=ac;c[al+70676>>2]=ac;c[al+136212>>2]=ac;ac=ae+6144|0;c[al+5144>>2]=ac;c[al+70680>>2]=ac;c[al+136216>>2]=ac;ac=ae+7168|0;c[al+5148>>2]=ac;c[al+70684>>2]=ac;c[al+136220>>2]=ac;ac=ae+8192|0;c[al+5152>>2]=ac;c[al+70688>>2]=ac;c[al+136224>>2]=ac;ac=ae+9216|0;c[al+5156>>2]=ac;c[al+70692>>2]=ac;c[al+136228>>2]=ac;ac=ae+10240|0;c[al+5160>>2]=ac;c[al+70696>>2]=ac;c[al+136232>>2]=ac;ac=ae+11264|0;c[al+5164>>2]=ac;c[al+70700>>2]=ac;c[al+136236>>2]=ac;ac=ae+12288|0;c[al+5168>>2]=ac;c[al+70704>>2]=ac;c[al+136240>>2]=ac;ac=ae+13312|0;c[al+5172>>2]=ac;c[al+70708>>2]=ac;c[al+136244>>2]=ac;ac=ae+14336|0;c[al+5176>>2]=ac;c[al+70712>>2]=ac;c[al+136248>>2]=ac;ac=ae+15360|0;c[al+5180>>2]=ac;c[al+70716>>2]=ac;c[al+136252>>2]=ac;ac=c[2418180]|0;ae=ac;c[al+5888>>2]=ae;c[al+71424>>2]=ae;c[al+136960>>2]=ae;Y=ac+1024|0;c[al+5892>>2]=Y;c[al+71428>>2]=Y;c[al+136964>>2]=Y;ab=ac+2048|0;c[al+5896>>2]=ab;c[al+71432>>2]=ab;c[al+136968>>2]=ab;af=ac+3072|0;c[al+5900>>2]=af;c[al+71436>>2]=af;c[al+136972>>2]=af;c[al+5904>>2]=ae;c[al+71440>>2]=ae;c[al+136976>>2]=ae;c[al+5908>>2]=Y;c[al+71444>>2]=Y;c[al+136980>>2]=Y;c[al+5912>>2]=ab;c[al+71448>>2]=ab;c[al+136984>>2]=ab;c[al+5916>>2]=af;c[al+71452>>2]=af;c[al+136988>>2]=af;af=c[2411372]|0;ab=al+6144|0;Y=1572864;while(1){ae=af+(Y-1572864)|0;c[ab>>2]=ae;c[ab+65536>>2]=ae;c[ab+131072>>2]=ae;ae=Y+1024|0;if(ae>>>0>1638399){break}else{ab=ab+4|0;Y=ae}}c[al+70144>>2]=1;c[al+70148>>2]=1;c[al+70152>>2]=1;c[al+70156>>2]=1;c[al+196688>>2]=402;c[al+196608>>2]=1860;c[al+196728>>2]=3396;c[al+196648>>2]=3050;c[al+196732>>2]=1312;Y=c[3532592]|0;if((Y|0)!=0){gGC(Y|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;if((c[2405114]|0)==2){Z=52188}else{fwR(0);Y=c[2439330]|0;ab=(Y|0)==0;if(!ab){af=Y;gGC(9706056,af|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];af=c[3528484]|0;c[2076596]=af;ae=c[2417276]|0;c[3541536]=ae;c[1836236]=0;c[Y+4180>>2]=260;c[Y+4172>>2]=3284;c[Y+4176>>2]=2480;ac=c[2411306]|0;ah=0;ai=0;while(1){c[Y+76+(ai<<2)>>2]=ac+(ai<<8);am=ah+1&65535;if((am&65535)>191){an=0;ao=0;break}else{ah=am;ai=am&65535}}while(1){ai=ac+(ao<<8)|0;c[Y+76+(ao+512<<2)>>2]=ai;c[Y+76+(ao+768<<2)>>2]=ai;ai=an+1&65535;if((ai&65535)>191){break}else{an=ai;ao=ai&65535}}ac=c[2411348]|0;ai=192;ah=192;while(1){c[Y+76+(ah<<2)>>2]=ac+((ah<<8)-49152);am=ai+1&65535;if((am&65535)>223){ap=192;aq=192;break}else{ai=am;ah=am&65535}}while(1){c[Y+76+(aq+256<<2)>>2]=ac+((aq<<8)-49152);ah=ap+1&65535;if((ah&65535)>223){ar=192;as=192;break}else{ap=ah;aq=ah&65535}}while(1){ah=ac+((as<<8)-49152)|0;c[Y+76+(as+512<<2)>>2]=ah;c[Y+76+(as+768<<2)>>2]=ah;ah=ar+1&65535;if((ah&65535)>223){break}else{ar=ah;as=ah&65535}}if(!ab){ac=Y;gGC(ac|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=af;c[2417276]=ae;c[1836236]=-1;ac=c[2405114]|0;if((ac|0)==2){Z=52188}else{at=ac}}if((Z|0)==52188){Ux(0,6e3,0);c[2407030]=256;c[2407068]=3;at=c[2405114]|0}if((at|0)==1){Vr(1,15e5,2658,2430,116,0);c[2438228]=6e6;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=340;h[745419]=2.0;a[3203368]=1;h[745418]=2.0;a[3203360]=1;h[745417]=2.0;a[3203352]=1;h[745416]=2.0;a[3203344]=1;c[2424]=5600;Ux(0,24242,1);Ux(1,24242,1);c[2407030]=38;c[2407068]=3;c[2407069]=38;c[2407107]=3;au=c[2405114]|0}else{au=at}if((au|0)==3){Ux(0,24242,1);Ux(1,24242,1);c[2407030]=38;c[2407068]=3;c[2407069]=38;c[2407107]=3}ac=c[642608+(c[2436]<<2)>>2]|0;ah=c[ac+128>>2]|0;if((c[ac+52>>2]&4|0)==0){c[2113068]=ah;ai=c[ac+132>>2]|0;c[2113070]=ai;c[2443814]=ah;c[2440436]=ai;av=ah;aw=ai}else{c[2113070]=ah;ai=c[ac+132>>2]|0;c[2113068]=ai;c[2440436]=ah;c[2443814]=ai;av=ai;aw=ah}ah=ag(av<<1,aw)|0;ai=gGq(ah)|0;c[2112926]=ai;if((ai|0)!=0){gGz(ai|0,0,ah|0)}eb4();$=0;i=d;return $|0}}while(0);c[2426716]=0;$=1;i=d;return $|0}function ebW(){var b=0,d=0,e=0,f=0,g=0;c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}if((c[2392]|0)>=0){b=0;do{d=14130368+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}d=14130384+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}b=b+1|0;}while((b|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;Uw(0);if((c[2405114]|0)!=2){Uw(1);if((c[2405114]|0)==1){b=c[3541518]|0;if((b|0)!=0){gGr(b|0);c[3541518]=0}if((c[2385508]|0)>0){c[2113008]=0;c[2076598]=0;c[2383582]=0}c[2438228]=0;c[2433526]=0;c[2406676]=0;c[3528472]=0;b=c[2406680]|0;if((b|0)!=0){gGr(b);c[2406680]=0}c[2385508]=0;c[2432978]=0;a[64240]=0}fwZ()}b=c[2426716]|0;d=0;while(1){if((d|0)>=1024){f=52248;break}g=9638528+(d<<2)|0;if((c[g>>2]|0)==(b|0)){break}else{d=d+1|0}}if((f|0)==52248){c[2426716]=0;return 0}gGr(b);c[g>>2]=0;c[2426716]=0;return 0}function ebX(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;if((a[9624136]|0)!=0){eb4()}a[9625680]=0;a[9625682]=0;a[9625683]=0;d=0;f=0;g=0;h=0;do{f=((a[9633384+d|0]&1)<<d|f&255)&255;g=((a[9631256+d|0]&1)<<d|g&255)&255;h=((a[9551800+d|0]&1)<<d|h&255)&255;d=d+1|0;}while((d|0)<8);a[9625682]=f;a[9625683]=g;a[9625680]=h;h=c[2438]|0;g=gGU(h,(h|0)<0|0?-1:0,12e6,0)|0;h=K;f=gGS(g,h,14336,0)|0;c[2440526]=f;f=c[2405114]|0;if((f|0)==3){d=gGS(g,h,15360,0)|0;c[2440526]=d}a[6518e3]=1;c[2443970]=0;c[2444018]=0;d=c[2392]|0;if((d|0)>=0){gGz(8452240,0,((d|0)>0?(d<<2)+4|0:4)|0)}c[2113054]=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}if((f|0)==2){d=gGS(g,h,15360,0)|0;h=d;c[2440526]=h;c[2113056]=h;d=RG(h)|0;c[2113054]=(c[2113054]|0)+d;c[2276108]=-1;c[2113056]=-1;c[8452200+(c[2394]<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0<1024){RH(4)}d=c[2112964]|0;if((d|0)!=0){Uu(0,d,a[9688]|0?534:0)}i=c[2405114]|0}else{d=c[2385548]|0;if((d|0)>0){gGz(9752472,0,((d|0)>1?d<<2:4)|0)}c[2433530]=0;d=c[2439330]|0;if((d|0)!=0){h=d;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;i=f}if((i|0)==1){f=0;while(1){h=f+1|0;d=(ag(c[2440526]|0,h)|0)/200|0;g=d-(c[2444018]|0)|0;c[2113056]=g;d=RG(g)|0;c[2113054]=(c[2113054]|0)+d;c[2276108]=-1;c[2113056]=-1;c[2444018]=(c[2444018]|0)+d;Sb(ag(a[6518e3]|0?500:0,f)|0);if((h|0)<200){f=h}else{break}}c[8452200+(c[2394]<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0<1024){RH(4)}j=c[2405114]|0}else{j=i}do{if((j|0)==3){i=0;while(1){f=i+1|0;h=(ag(c[2440526]|0,f)|0)/200|0;d=h-(c[2444018]|0)|0;c[2113056]=d;h=RG(d)|0;c[2113054]=(c[2113054]|0)+h;c[2276108]=-1;c[2113056]=-1;c[2444018]=(c[2444018]|0)+h;h=(ag(a[6518e3]|0?1e5:0,f)|0)/200|0;d=c[2443970]|0;g=h-d|0;do{if((g|0)<1){k=0;l=d}else{if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){h=gfc(g)|0;c[2433530]=(c[2433530]|0)+h;k=h;l=c[2443970]|0;break}else{c[2433530]=(c[2433530]|0)+g;k=g;l=d;break}}}while(0);c[2443970]=l+k;if((i&180|0)==0){a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0}if((f|0)<200){i=f}else{break}}c[8452200+(c[2394]<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0>=1024){break}RH(4)}}while(0);k=c[2394]|0;l=c[14130368+(k<<2)>>2]|0;if((l|0)!=0){gGC(l|0,9104152,280)|0}c[8452240+(k<<2)>>2]=c[2113054];c[2394]=-1;k=c[2405114]|0;if((k|0)==1){l=a[6518e3]|0?1e5:0;j=gGU(l,0,2048e6,0)|0;i=c[2438228]|0;d=gGS(j,K,i,(i|0)<0|0?-1:0)|0;i=d;Sb(l);l=c[2443830]|0;if((l|0)<1073676288){c[2443830]=l-i}l=c[2443831]|0;if((l|0)<1073676288){c[2443831]=l-i}l=(c[3528512]|0)-i|0;c[3528512]=(l|0)<0?0:l;l=c[2112964]|0;if((l|0)!=0){gg[c[3542122]&4095](l,a[9688]|0?534:0);l=c[2112964]|0;i=a[9688]|0?534:0;Uu(0,l,i);Uu(1,l,i)}i=c[1836236]|0;l=c[9757320+(i<<2)>>2]|0;if((l|0)!=0){d=l;gGC(d|0,9706056,76)|0}c[9752472+(i<<2)>>2]=c[2433530];c[14113936+(i<<2)>>2]=c[2076596];c[9669104+(i<<2)>>2]=c[3541536];c[1836236]=-1;m=c[2405114]|0}else{m=k}if((m|0)==3){m=(a[6518e3]|0?1e5:0)-(c[2443970]|0)|0;do{if((m|0)>=1){if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){k=gfc(m)|0;c[2433530]=(c[2433530]|0)+k;break}else{c[2433530]=(c[2433530]|0)+m;break}}}while(0);m=c[2112964]|0;if((m|0)!=0){k=a[9688]|0;gGz(m|0,0,(k?2136:0)|0);i=k?534:0;Uu(0,m,i);Uu(1,m,i)}i=c[1836236]|0;m=c[9757320+(i<<2)>>2]|0;if((m|0)!=0){k=m;gGC(k|0,9706056,76)|0}c[9752472+(i<<2)>>2]=c[2433530];c[14113936+(i<<2)>>2]=c[2076596];c[9669104+(i<<2)>>2]=c[3541536];c[1836236]=-1}if((c[2112968]|0)==0){return 0}if((a[9753344]|0)!=0){i=c[2411428]|0;k=0;do{m=e[i+(k<<1)>>1]|0;c[(c[2385762]|0)+(k<<2)>>2]=m<<8&2048|m&61440|(m<<2&8|m&240)>>>3|(m>>>4&240|m<<1&8|m>>>9&4)<<3&2016;k=k+1|0;}while((k|0)<2048);a[9753344]=0}k=c[2112926]|0;gGz(k|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);i=c[2406858]|0;m=i+2|0;d=i+6|0;l=i+4|0;j=c[2418188]|0;g=c[2418082]|0;h=8191;while(1){n=(h>>8<<8&1792|h&240)+32-(e[i>>1]<<8&65280|b[m>>1]&255)|0;o=(h<<4&240|h>>12<<8)-16-(e[l>>1]<<8&65280|b[d>>1]&255)|0;do{if((n+15|0)>>>0<=334){if((o+15|0)>>>0>238){break}p=e[j+(h<<1)>>1]|0;q=(p&2047)+(c[2385212]|0)|0;r=p>>>7&16|p>>>12;if(n>>>0<305&o>>>0<209){Sy(k,q,n,o,r,4,0,g);break}else{Sz(k,q,n,o,r,4,0,g);break}}}while(0);if((h|0)<=0){break}h=h-1|0}h=c[2411372]|0;g=h+36864|0;j=c[2411316]|0;d=h+32768|0;do{if((b[d>>1]&1)!=0){h=e[d+2>>1]|0;l=e[d+8>>1]|0;m=e[d+12>>1]|0;i=b[d+14>>1]&63;o=(h&15)+1|0;n=(h>>>4&15)+1|0;r=l&1023;q=(r>>>0>511?l|-1024:r)+32|0;r=m&1023;l=(r>>>0>511?m|-1024:r)-16|0;r=(h&4096|0)==0;m=b[d+6>>1]&32767|h<<7&32768;h=0;while(1){p=q+(h<<4)|0;if(p>>>0<305){s=m;t=0;while(1){u=(t<<4)+l|0;do{if(u>>>0<209){if(r){SG(k,s,p,u,i,4,15,1024,j);break}else{SI(k,s,p,u,i,4,15,1024,j);break}}else{if(r){SH(k,s,p,u,i,4,15,1024,j);break}else{SJ(k,s,p,u,i,4,15,1024,j);break}}}while(0);u=t+1|0;if((u|0)<(n|0)){s=s+1|0;t=u}else{break}}}else{if(r){t=m;s=0;while(1){SH(k,t,p,(s<<4)+l|0,i,4,15,1024,j);f=s+1|0;if((f|0)<(n|0)){t=t+1|0;s=f}else{break}}}else{s=m;t=0;while(1){SJ(k,s,p,(t<<4)+l|0,i,4,15,1024,j);f=t+1|0;if((f|0)<(n|0)){s=s+1|0;t=f}else{break}}}}t=h+1|0;if((t|0)<(o|0)){m=m+n|0;h=t}else{break}}}d=d+16|0;}while(d>>>0<g>>>0);g=c[2418180]|0;d=c[2418078]|0;j=0;do{h=j>>>2&16376;n=h+32|0;m=(j<<3&248)-16|0;o=n>>>0>320?h-480|0:n;do{if(!(o>>>0>312|m>>>0>216)){n=b[g+(j<<1)>>1]|0;h=n&4095;if((h|0)==0){break}i=((n&65535)>>>8&240|512)&65535;n=d+(h<<5)|0;h=k+(o+(m*320|0)<<1)|0;l=0;while(1){r=a[n]|0;q=(r&255)>>>4;if((q|0)==15){v=r}else{b[h>>1]=(q|i)&65535;v=a[n]|0}q=v&15;if((q|0)!=15){b[h+2>>1]=(q|i)&65535}q=n+1|0;r=a[q]|0;t=(r&255)>>>4;if((t|0)==15){w=r}else{b[h+4>>1]=(t|i)&65535;w=a[q]|0}q=w&15;if((q|0)!=15){b[h+6>>1]=(q|i)&65535}q=n+2|0;t=a[q]|0;r=(t&255)>>>4;if((r|0)==15){x=t}else{b[h+8>>1]=(r|i)&65535;x=a[q]|0}q=x&15;if((q|0)!=15){b[h+10>>1]=(q|i)&65535}q=n+3|0;r=a[q]|0;t=(r&255)>>>4;if((t|0)==15){y=r}else{b[h+12>>1]=(t|i)&65535;y=a[q]|0}q=y&15;if((q|0)!=15){b[h+14>>1]=(q|i)&65535}q=l+1|0;if((q|0)<8){n=n+4|0;h=h+640|0;l=q}else{break}}}}while(0);j=j+1|0;}while((j|0)<2048);R8(c[2385762]|0);return 0}function ebY(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;e=i;i=i+144|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;l=e+80|0;m=e+96|0;n=e+112|0;o=e+128|0;if((d|0)!=0){c[d>>2]=169585}if((b&32|0)!=0){gGz(o|0,0,12);p=c[2405650]|0;c[o>>2]=p;c[o+4>>2]=(c[2411652]|0)-p;c[o+12>>2]=162152;p=c[2076592]|0;gj[p&4095](o)|0}if((b&64|0)==0){i=e;return 0}o=h|0;gGz(g|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){p=h+9|0;h=f;q=f|0;r=f+4|0;s=f+12|0;t=g|0;u=g+4|0;v=g+12|0;w=0;do{gGC(o|0,614896,11)|0;a[p]=w+48&255;x=8452256+(w<<2)|0;gGz(h|0,0,12);c[q>>2]=x;c[r>>2]=4;c[s>>2]=164976;gj[c[2076592]&4095](f)|0;if((c[x>>2]|0)!=0){c[t>>2]=c[14130368+(w<<2)>>2];c[u>>2]=c[8452184+(w<<2)>>2];c[v>>2]=o;x=c[2076592]|0;gj[x&4095](g)|0}w=w+1|0;}while((w|0)<=(c[2392]|0))}do{if((c[2405114]|0)!=2){fw$(b);if((c[2405114]|0)!=1){break}Vx(b,d)}}while(0);Ut(0);if((c[2405114]|0)!=2){Ut(1)}gGz(n|0,0,12);c[n>>2]=9542368;c[n+4>>2]=4;c[n+12>>2]=269256;gj[c[2076592]&4095](n)|0;gGz(m|0,0,12);c[m>>2]=14113096;c[m+4>>2]=2;c[m+12>>2]=191240;gj[c[2076592]&4095](m)|0;if((c[2405114]|0)==2){gGz(l|0,0,12);c[l>>2]=638632;c[l+4>>2]=4;c[l+12>>2]=253176;m=c[2076592]|0;gj[m&4095](l)|0}gGz(k|0,0,12);c[k>>2]=9540848;c[k+4>>2]=4;c[k+12>>2]=245488;gj[c[2076592]&4095](k)|0;gGz(j|0,0,12);c[j>>2]=9543048;c[j+4>>2]=4;c[j+12>>2]=541944;gj[c[2076592]&4095](j)|0;if((b&2|0)==0){i=e;return 0}a[9753344]=1;if((c[2405114]|0)!=2){i=e;return 0}b=c[3541206]|0;j=b+196608|0;k=b+((c[159658]<<16)+262144)|0;gGC(j|0,k|0,65536)|0;i=e;return 0}function ebZ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2437348+(b*112|0)>>2];c[a+104>>2]=c[2437352+(b*112|0)>>2];c[a+108>>2]=c[2437356+(b*112|0)>>2];d=0;return d|0}function eb_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<22&(d|0)==0)){e=1;return e|0}c[a>>2]=2437248+(b*112|0);e=0;return e|0}function eb$(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=24){if((a|0)==0){d=0;return d|0}e=a;f=2436944+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}f=b-25|0;if(f>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;a=2439712+(f*12|0)|0;c[b>>2]=c[a>>2];c[b+4>>2]=c[a+4>>2];c[b+8>>2]=c[a+8>>2];d=0;return d|0}function eb0(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2443988+(b*112|0)>>2];c[a+104>>2]=c[2443992+(b*112|0)>>2];c[a+108>>2]=c[2443996+(b*112|0)>>2];d=0;return d|0}function eb1(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=2443888+(b*112|0);e=0;return e|0}function eb2(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>34){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2440068+(b*112|0)>>2];c[a+104>>2]=c[2440072+(b*112|0)>>2];c[a+108>>2]=c[2440076+(b*112|0)>>2];d=0;return d|0}function eb3(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<35&(d|0)==0)){e=1;return e|0}c[a>>2]=2439968+(b*112|0);e=0;return e|0}function eb4(){var b=0,d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];b=c[3532592]|0;if((b|0)!=0){gGC(9104152,b|0,280)|0}c[2113054]=c[2113060]}c[2113050]=0;c[2276080]=0;RI();b=c[2394]|0;d=c[14130368+(b<<2)>>2]|0;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[8452240+(b<<2)>>2]=c[2113054];c[2394]=-1;c[2113156]=0;a[9628264]=0;c[2407033]=0;b=c[3541206]|0;c[3541190]=b;c[3541198]=b;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=b+256;c[3541199]=b+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=b+512;c[3541200]=b+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=b+768;c[3541201]=b+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;d=c[2405114]|0;if((d|0)==2){return}e=c[2439330]|0;f=(e|0)==0;if(!f){g=e;gGC(9706056,g|0,76)|0}g=c[2438118]|0;c[2433530]=g;i=c[3528484]|0;c[2076596]=i;j=c[2417276]|0;c[3541536]=j;c[1836236]=0;gGz(9706056,0,76);if(!f){f=e;gGC(f|0,9706056,76)|0}c[2438118]=g;c[3528484]=i;c[2417276]=j;c[1836236]=-1;do{if((d|0)==1){c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){k=0}else{l=b;break}do{lN(k);mB(k);k=k+1|0;}while((k|0)<(c[2385508]|0));l=c[3541206]|0}else{l=b}}while(0);c[2113157]=0;a[9628420]=0;c[2407072]=0;b=l+1048576|0;c[3541194]=b;c[3541202]=b;gGz(c[2430122]|0,0,16384);c[2407080]=4;c[3541195]=l+1048832;c[3541203]=l+1114112;gGz(c[2430123]|0,0,16384);c[2407088]=4;c[3541196]=l+1049088;c[3541204]=l+1179648;gGz(c[2430124]|0,0,16384);c[2407096]=4;c[3541197]=l+1049344;c[3541205]=l+1245184;gGz(c[2430125]|0,0,16384);c[2407104]=4;return}function eb5(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;h=i;i=i+120|0;j=h|0;k=h+112|0;do{if((c[3542200]|0)!=0){l=j+108|0;c[l>>2]=0;m=j+100|0;c[m>>2]=0;n=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[n&16383](j,f)|0;if((c[l>>2]|0)==0){break}l=c[m>>2]|0;c[k>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](k,f,0)|0;if((l|0)<1){break}gzL(b,0,f)|0}}while(0);f=(g|0)/128|0;if((g|0)>127){o=e;p=b;q=0}else{i=h;return}while(1){b=o;e=p;g=0;while(1){a[b]=(d[e]|0)>>>4;a[b+1|0]=a[e]&15;k=e+1|0;a[b+2|0]=(d[k]|0)>>>4;a[b+3|0]=a[k]&15;k=e+2|0;a[b+4|0]=(d[k]|0)>>>4;a[b+5|0]=a[k]&15;k=e+3|0;a[b+6|0]=(d[k]|0)>>>4;a[b+7|0]=a[k]&15;k=e+64|0;a[b+8|0]=(d[k]|0)>>>4;a[b+9|0]=a[k]&15;k=e+65|0;a[b+10|0]=(d[k]|0)>>>4;a[b+11|0]=a[k]&15;k=e+66|0;a[b+12|0]=(d[k]|0)>>>4;a[b+13|0]=a[k]&15;k=e+67|0;a[b+14|0]=(d[k]|0)>>>4;a[b+15|0]=a[k]&15;k=g+1|0;if((k|0)<16){b=b+16|0;e=e+4|0;g=k}else{break}}g=q+1|0;if((g|0)<(f|0)){o=o+256|0;p=p+128|0;q=g}else{break}}i=h;return}function eb6(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;h=i;i=i+120|0;j=h|0;k=h+112|0;do{if((c[2405114]|0)==3){l=f<<1;m=l+9|0;R6(b,m,2)|0;m=b+1|0;n=l+10|0;R6(m,n,2)|0}else{if((c[3542200]|0)==0){break}n=j+108|0;c[n>>2]=0;m=j+100|0;c[m>>2]=0;l=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[l&16383](j,f)|0;if((c[n>>2]|0)==0){break}n=c[m>>2]|0;c[k>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](k,f,0)|0;if((n|0)<1){break}gzL(b,0,f)|0}}while(0);f=(g|0)/128|0;if((g|0)>127){o=e;p=b;q=0}else{i=h;return}while(1){b=o;e=p;g=0;while(1){k=e+1|0;a[b]=(d[k]|0)>>>4;a[b+1|0]=a[k]&15;a[b+2|0]=(d[e]|0)>>>4;a[b+3|0]=a[e]&15;k=e+3|0;a[b+4|0]=(d[k]|0)>>>4;a[b+5|0]=a[k]&15;k=e+2|0;a[b+6|0]=(d[k]|0)>>>4;a[b+7|0]=a[k]&15;k=e+65|0;a[b+8|0]=(d[k]|0)>>>4;a[b+9|0]=a[k]&15;k=e+64|0;a[b+10|0]=(d[k]|0)>>>4;a[b+11|0]=a[k]&15;k=e+67|0;a[b+12|0]=(d[k]|0)>>>4;a[b+13|0]=a[k]&15;k=e+66|0;a[b+14|0]=(d[k]|0)>>>4;a[b+15|0]=a[k]&15;k=g+1|0;if((k|0)<16){b=b+16|0;e=e+4|0;g=k}else{break}}g=q+1|0;if((g|0)<(f|0)){o=o+256|0;p=p+128|0;q=g}else{break}}i=h;return}function eb7(b,c){b=b|0;c=c|0;a[9706117]=c&1;return}function eb8(a){a=a|0;var b=0,d=0;b=(c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,6e6,0)|0;return a|0}function eb9(){return+(+((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)/6.0e6)}function eca(a,b){a=a|0;b=b|0;return}function ecb(d,e){d=d|0;e=e|0;if((d|0)==2097152|(d|0)==2097154|(d|0)==2097156){b[(c[2439580]|0)+((d>>>1&3)<<1)>>1]=e;return}else if((d|0)==11534336|(d|0)==11534338|(d|0)==11534340|(d|0)==11534342|(d|0)==11534344|(d|0)==11534346|(d|0)==11534348|(d|0)==11534350){b[(c[3529388]|0)+((d>>>1&7)<<1)>>1]=e;return}else if((d|0)==11534360){c[2388364]=0;return}else if((d|0)==12582912){a[c[3528272]|0]=e&255;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12;return}else if((d|0)==3145728|(d|0)==3145730|(d|0)==3145732){b[(c[2439578]|0)+((d>>>1&3)<<1)>>1]=e;return}else{return}}function ecc(a){a=a|0;var c=0;if((a|0)==8388611){c=b[4774904]&255}else if((a|0)==8388608){c=(e[4774988]|0)>>>8&255}else if((a|0)==8388610){c=(e[4774904]|0)>>>8&255}else if((a|0)==8388609){c=b[4774988]&255}else{c=0}return c|0}function ecd(a){a=a|0;var e=0;if((a|0)==8388610){e=b[4774904]|0}else if((a|0)==11534366){c[2388364]=0;e=3072}else if((a|0)==10485760){e=(d[9635064]|0)<<8|255}else if((a|0)==10485762){e=(d[9635065]|0)<<8|255}else if((a|0)==8388608){e=b[4774988]|0}else if((a|0)==12582912){e=d[c[2443722]|0]|0}else{e=0}return e|0}function ece(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=b&65535;switch(e|0){case 61440:{a[c[2443934]|0]=d;b=c[2385922]|0;f=(d&255)<<14;g=16384<<(a[673560]&1)>>>8;h=c[9757320+(c[1836236]<<2)>>2]|0;i=g&255;if((i&65535)>191){return}j=g&255;g=i;while(1){k=g&65535;c[h+76+(k<<2)>>2]=b+((k-j<<8)+f);k=g+1&65535;if((k&65535)>191){l=i;break}else{g=k}}do{g=l&65535;i=b+((g-j<<8)+f)|0;c[h+76+(g+512<<2)>>2]=i;c[h+76+(g+768<<2)>>2]=i;l=l+1&65535;}while((l&65535)<=191);return};case 57344:case 57345:case 57346:case 57347:{l7(e&3,d);return};default:{return}}}function ecf(a){a=a|0;var b=0,c=0;b=a&65535;if((b|0)==57344|(b|0)==57346){c=l8(b&2)|0}else{c=0}return c|0}function ecg(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=b&65535;switch(e&255|0){case 128:{a[c[2443722]|0]=d;return};case 0:case 1:case 2:case 3:{l7(e&3,d);return};case 64:{a[c[2443934]|0]=d;e=c[2385922]|0;b=(d&255)<<14;d=16384<<(a[673560]&1)>>>8;f=c[9757320+(c[1836236]<<2)>>2]|0;g=d&255;if((g&65535)>191){return}h=d&255;d=g;while(1){i=d&65535;c[f+76+(i<<2)>>2]=e+((i-h<<8)+b);i=d+1&65535;if((i&65535)>191){j=g;break}else{d=i}}do{d=j&65535;g=e+((d-h<<8)+b)|0;c[f+76+(d+512<<2)>>2]=g;c[f+76+(d+768<<2)>>2]=g;j=j+1&65535;}while((j&65535)<=191);return};default:{return}}}function ech(b){b=b|0;var d=0,e=0;d=b&65535;switch(d&255|0){case 4:case 5:case 6:case 7:{e=l8(d&3)|0;break};case 128:{e=a[c[3528272]|0]|0;break};default:{e=0}}return e|0}function eci(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4556356+(b*112|0)>>2];c[a+104>>2]=c[4556360+(b*112|0)>>2];c[a+108>>2]=c[4556364+(b*112|0)>>2];d=0;return d|0}function ecj(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=4556256+(b*112|0);e=0;return e|0}function eck(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1836832+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function ecl(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>42){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5287656+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function ecm(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0;e=i;i=i+1088|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;c[2414958]=0;c[2388150]=0;c[2385922]=1048576;c[3530838]=1310720;c[3530602]=7602176;c[3530428]=10747904;c[2386644]=15990784;c[353e4]=17039360;c[2439592]=17055748;c[2414662]=17127428;c[2388276]=17127428;c[2386076]=17192964;c[3529466]=17201156;c[3529432]=17209348;c[2387192]=17217540;c[2386452]=17229828;c[2386566]=17295364;c[2439580]=17328132;c[2439578]=17328140;c[3529388]=17328148;c[2443374]=17328164;c[2443934]=17328180;c[3528272]=17328181;c[2443722]=17328182;c[2411650]=17328183;A=0;while(1){if((A|0)>=1024){break}B=9638528+(A<<2)|0;if((c[B>>2]|0)==0){C=52575;break}else{A=A+1|0}}do{if((C|0)==52575){A=gGq(17328183)|0;c[B>>2]=A;if((A|0)==0){break}c[2414958]=A;gGz(A|0,0,17328183);c[2388150]=A;c[2385922]=A+1048576;c[3530838]=A+1310720;c[3530602]=A+7602176;c[3530428]=A+10747904;c[2386644]=A+15990784;c[353e4]=A+17039360;c[2439592]=A+17055748;D=A+17127428|0;c[2414662]=D;c[2388276]=D;c[2386076]=A+17192964;c[3529466]=A+17201156;c[3529432]=A+17209348;c[2387192]=A+17217540;c[2386452]=A+17229828;c[2386566]=A+17295364;c[2439580]=A+17328132;c[2439578]=A+17328140;c[3529388]=A+17328148;c[2443374]=A+17328164;c[2443934]=A+17328180;c[3528272]=A+17328181;c[2443722]=A+17328182;D=A+17328183|0;c[2411650]=D;c[2414190]=D;if((R6(A+1|0,0,2)|0)!=0){E=1;i=e;return E|0}if((R6(c[2388150]|0,1,2)|0)!=0){E=1;i=e;return E|0}A=c[2385922]|0;if((c[3542200]|0)==0){E=1;i=e;return E|0}D=x+108|0;c[D>>2]=0;F=x+100|0;c[F>>2]=0;G=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[G&16383](x,2)|0;do{if((c[D>>2]|0)!=0){G=c[F>>2]|0;c[y>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](y,2,0)|0;if((G|0)<1){E=1;i=e;return E|0}if((gzL(A,0,2)|0)==0){break}else{E=1}i=e;return E|0}}while(0);if((R6(c[3530838]|0,3,2)|0)!=0){E=1;i=e;return E|0}if((R6((c[3530838]|0)+1|0,4,2)|0)!=0){E=1;i=e;return E|0}if((R6((c[3530838]|0)+2097152|0,5,2)|0)!=0){E=1;i=e;return E|0}if((R6((c[3530838]|0)+2097153|0,6,2)|0)!=0){E=1;i=e;return E|0}if((R6((c[3530838]|0)+4194304|0,7,2)|0)!=0){E=1;i=e;return E|0}if((R6((c[3530838]|0)+4194305|0,8,2)|0)!=0){E=1;i=e;return E|0}A=c[2386644]|0;if((c[3542200]|0)==0){E=1;i=e;return E|0}F=v+108|0;c[F>>2]=0;D=v+100|0;c[D>>2]=0;G=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[G&16383](v,13)|0;do{if((c[F>>2]|0)!=0){G=c[D>>2]|0;c[w>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](w,13,0)|0;if((G|0)<1){E=1;i=e;return E|0}if((gzL(A,0,13)|0)==0){break}else{E=1}i=e;return E|0}}while(0);A=(a[(c[2385922]|0)+131072|0]|0)==0;D=c[3530602]|0;do{if((c[3542200]|0)==0){I=1}else{F=t+108|0;c[F>>2]=0;G=t+100|0;c[G>>2]=0;H=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[H&16383](t,9)|0;if((c[F>>2]|0)==0){I=0;break}F=c[G>>2]|0;c[u>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](u,9,0)|0;if((F|0)<1){I=1;break}I=(gzL(D,0,9)|0)!=0}}while(0);do{if(A){if(I){E=1;i=e;return E|0}D=c[3530428]|0;if((c[3542200]|0)==0){E=1;i=e;return E|0}F=l+108|0;c[F>>2]=0;G=l+100|0;c[G>>2]=0;H=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[H&16383](l,10)|0;do{if((c[F>>2]|0)!=0){H=c[G>>2]|0;c[m>>2]=9534384;J=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[J&16383](m,10,0)|0;if((H|0)<1){E=1;i=e;return E|0}if((gzL(D,0,10)|0)==0){break}else{E=1}i=e;return E|0}}while(0);D=(c[3530428]|0)+1048576|0;if((c[3542200]|0)==0){E=1;i=e;return E|0}G=j+108|0;c[G>>2]=0;F=j+100|0;c[F>>2]=0;H=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[H&16383](j,11)|0;do{if((c[G>>2]|0)!=0){H=c[F>>2]|0;c[k>>2]=9534384;J=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[J&16383](k,11,0)|0;if((H|0)<1){E=1;i=e;return E|0}if((gzL(D,0,11)|0)==0){break}else{E=1}i=e;return E|0}}while(0);D=(c[3530428]|0)+2097152|0;if((c[3542200]|0)==0){E=1;i=e;return E|0}F=f+108|0;c[F>>2]=0;G=f+100|0;c[G>>2]=0;H=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[H&16383](f,12)|0;if((c[F>>2]|0)==0){K=0;break}F=c[G>>2]|0;c[g>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](g,12,0)|0;if((F|0)<1){E=1;i=e;return E|0}if((gzL(D,0,12)|0)==0){K=0;break}else{E=1}i=e;return E|0}else{if(I){E=1;i=e;return E|0}D=(c[3530602]|0)+1048576|0;if((c[3542200]|0)==0){E=1;i=e;return E|0}F=r+108|0;c[F>>2]=0;G=r+100|0;c[G>>2]=0;H=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[H&16383](r,10)|0;do{if((c[F>>2]|0)!=0){H=c[G>>2]|0;c[s>>2]=9534384;J=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[J&16383](s,10,0)|0;if((H|0)<1){E=1;i=e;return E|0}if((gzL(D,0,10)|0)==0){break}else{E=1}i=e;return E|0}}while(0);D=c[3530428]|0;if((c[3542200]|0)==0){E=1;i=e;return E|0}G=p+108|0;c[G>>2]=0;F=p+100|0;c[F>>2]=0;H=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[H&16383](p,11)|0;do{if((c[G>>2]|0)!=0){H=c[F>>2]|0;c[q>>2]=9534384;J=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[J&16383](q,11,0)|0;if((H|0)<1){E=1;i=e;return E|0}if((gzL(D,0,11)|0)==0){break}else{E=1}i=e;return E|0}}while(0);D=(c[3530428]|0)+1048576|0;if((c[3542200]|0)==0){E=1;i=e;return E|0}F=n+108|0;c[F>>2]=0;G=n+100|0;c[G>>2]=0;H=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[H&16383](n,12)|0;if((c[F>>2]|0)==0){K=1;break}F=c[G>>2]|0;c[o>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](o,12,0)|0;if((F|0)<1){E=1;i=e;return E|0}if((gzL(D,0,12)|0)==0){K=1;break}else{E=1}i=e;return E|0}}while(0);a[673560]=K;A=0;while(1){if((A|0)>=1024){break}L=9638528+(A<<2)|0;if((c[L>>2]|0)==0){C=52627;break}else{A=A+1|0}}L69795:do{if((C|0)==52627){A=gGq(2621440)|0;c[L>>2]=A;if((A|0)==0){break}gGz(A|0,0,2621440);D=c[3530602]|0;gGC(A|0,D|0,1572864)|0;F=0;do{G=F<<8;gGz(D+G|0,0,256);H=F<<10;J=0;do{M=1<<3-J;N=(c[703416+(J<<2)>>2]|0)+H|0;O=0;do{P=N+(c[3946808+(O<<2)>>2]|0)|0;Q=(O<<4)+G|0;R=0;do{S=P+(c[3946872+(R<<2)>>2]|0)|0;if((d[A+((S|0)/8|0)|0]&128>>>((S&7)>>>0)|0)!=0){S=D+(Q+R)|0;a[S]=(d[S]|M)&255}R=R+1|0;}while((R|0)<16);O=O+1|0;}while((O|0)<16);J=J+1|0;}while((J|0)<4);F=F+1|0;}while((F|0)<12288);F=c[3530428]|0;gGC(A|0,F|0,2621440)|0;D=0;while(1){J=D<<8;gGz(F+J|0,0,256);G=D<<10;H=0;do{O=1<<3-H;M=(c[703416+(H<<2)>>2]|0)+G|0;N=0;do{R=M+(c[3946808+(N<<2)>>2]|0)|0;Q=(N<<4)+J|0;P=0;do{S=R+(c[3946872+(P<<2)>>2]|0)|0;if((d[A+((S|0)/8|0)|0]&128>>>((S&7)>>>0)|0)!=0){S=F+(Q+P)|0;a[S]=(d[S]|O)&255}P=P+1|0;}while((P|0)<16);N=N+1|0;}while((N|0)<16);H=H+1|0;}while((H|0)<4);H=D+1|0;if((H|0)<20480){D=H}else{T=0;break}}while(1){if((T|0)>=1024){break L69795}U=9638528+(T<<2)|0;if((c[U>>2]|0)==(A|0)){break}else{T=T+1|0}}gGr(A);c[U>>2]=0}}while(0);fxU(0,425984);if((c[2394]|0)==0){V=c[2112932]|0}else{c[2394]=0;D=c[3532596]|0;c[2112932]=D;F=c[3532592]|0;if((F|0)!=0){gGC(9104152,F|0,280)|0}c[2113054]=c[2113060];V=D}D=c[2388150]|0;F=V|0;H=0;while(1){J=D+H|0;c[F>>2]=J;c[F+131072>>2]=J;J=H+1024|0;if(J>>>0>1048575){break}else{F=F+4|0;H=J}}H=c[2388276]|0;F=V+4096|0;D=1048576;while(1){J=H+(D-1048576)|0;c[F>>2]=J;c[F+65536>>2]=J;c[F+131072>>2]=J;J=D+1024|0;if(J>>>0>1114111){break}else{F=F+4|0;D=J}}D=c[3529466]|0;c[V+16384>>2]=D;c[V+81920>>2]=D;c[V+147456>>2]=D;F=D+1024|0;c[V+16388>>2]=F;c[V+81924>>2]=F;c[V+147460>>2]=F;F=D+2048|0;c[V+16392>>2]=F;c[V+81928>>2]=F;c[V+147464>>2]=F;F=D+3072|0;c[V+16396>>2]=F;c[V+81932>>2]=F;c[V+147468>>2]=F;F=D+4096|0;c[V+16400>>2]=F;c[V+81936>>2]=F;c[V+147472>>2]=F;F=D+5120|0;c[V+16404>>2]=F;c[V+81940>>2]=F;c[V+147476>>2]=F;F=D+6144|0;c[V+16408>>2]=F;c[V+81944>>2]=F;c[V+147480>>2]=F;F=D+7168|0;c[V+16412>>2]=F;c[V+81948>>2]=F;c[V+147484>>2]=F;F=c[3529432]|0;c[V+20480>>2]=F;c[V+86016>>2]=F;c[V+151552>>2]=F;D=F+1024|0;c[V+20484>>2]=D;c[V+86020>>2]=D;c[V+151556>>2]=D;D=F+2048|0;c[V+20488>>2]=D;c[V+86024>>2]=D;c[V+151560>>2]=D;D=F+3072|0;c[V+20492>>2]=D;c[V+86028>>2]=D;c[V+151564>>2]=D;D=F+4096|0;c[V+20496>>2]=D;c[V+86032>>2]=D;c[V+151568>>2]=D;D=F+5120|0;c[V+20500>>2]=D;c[V+86036>>2]=D;c[V+151572>>2]=D;D=F+6144|0;c[V+20504>>2]=D;c[V+86040>>2]=D;c[V+151576>>2]=D;D=F+7168|0;c[V+20508>>2]=D;c[V+86044>>2]=D;c[V+151580>>2]=D;D=c[2387192]|0;c[V+24576>>2]=D;c[V+90112>>2]=D;c[V+155648>>2]=D;F=D+1024|0;c[V+24580>>2]=F;c[V+90116>>2]=F;c[V+155652>>2]=F;F=D+2048|0;c[V+24584>>2]=F;c[V+90120>>2]=F;c[V+155656>>2]=F;F=D+3072|0;c[V+24588>>2]=F;c[V+90124>>2]=F;c[V+155660>>2]=F;F=D+4096|0;c[V+24592>>2]=F;c[V+90128>>2]=F;c[V+155664>>2]=F;F=D+5120|0;c[V+24596>>2]=F;c[V+90132>>2]=F;c[V+155668>>2]=F;F=D+6144|0;c[V+24600>>2]=F;c[V+90136>>2]=F;c[V+155672>>2]=F;F=D+7168|0;c[V+24604>>2]=F;c[V+90140>>2]=F;c[V+155676>>2]=F;F=D+8192|0;c[V+24608>>2]=F;c[V+90144>>2]=F;c[V+155680>>2]=F;F=D+9216|0;c[V+24612>>2]=F;c[V+90148>>2]=F;c[V+155684>>2]=F;F=D+10240|0;c[V+24616>>2]=F;c[V+90152>>2]=F;c[V+155688>>2]=F;F=D+11264|0;c[V+24620>>2]=F;c[V+90156>>2]=F;c[V+155692>>2]=F;F=c[2386452]|0;D=V+28672|0;H=7340032;while(1){J=F+(H-7340032)|0;c[D>>2]=J;c[D+65536>>2]=J;c[D+131072>>2]=J;J=H+1024|0;if(J>>>0>7405567){break}else{D=D+4|0;H=J}}c[V+196648>>2]=2970;c[V+196728>>2]=2186;c[V+196608>>2]=3186;c[V+196688>>2]=2586;H=c[3532592]|0;if((H|0)!=0){gGC(H|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);H=c[2439330]|0;D=(H|0)==0;if(!D){F=H;gGC(9706056,F|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];F=c[3528484]|0;c[2076596]=F;J=c[2417276]|0;c[3541536]=J;c[1836236]=0;G=c[2385922]|0;N=0;O=0;while(1){c[H+76+(O<<2)>>2]=G+(O<<8);M=N+1&65535;if((M&65535)>127){W=0;X=0;break}else{N=M;O=M&65535}}while(1){O=G+(X<<8)|0;c[H+76+(X+512<<2)>>2]=O;c[H+76+(X+768<<2)>>2]=O;O=W+1&65535;if((O&65535)>127){break}else{W=O;X=O&65535}}G=c[2386076]|0;O=192;N=192;while(1){c[H+76+(N<<2)>>2]=G+((N<<8)-49152);M=O+1&65535;if((M&65535)>223){Y=192;Z=192;break}else{O=M;N=M&65535}}while(1){c[H+76+(Z+256<<2)>>2]=G+((Z<<8)-49152);N=Y+1&65535;if((N&65535)>223){_=192;$=192;break}else{Y=N;Z=N&65535}}while(1){N=G+(($<<8)-49152)|0;c[H+76+($+512<<2)>>2]=N;c[H+76+($+768<<2)>>2]=N;N=_+1&65535;if((N&65535)>223){break}else{_=N;$=N&65535}}c[H+4184>>2]=756;c[H+4180>>2]=994;c[H+4172>>2]=1390;c[H+4176>>2]=3310;if(!D){G=H;gGC(G|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=F;c[2417276]=J;c[1836236]=-1;c[z>>2]=a[673560]|0?1048576:524288;G=c[2386644]|0;TW(G,z,G,z,54,1730,120);c[2438228]=4e6;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=511;h[745406]=2.0;c[2436786]=1;h[745405]=2.0;c[2436784]=2;h[745404]=1.28;a[3203280]=1;G=c[642608+(c[2436]<<2)>>2]|0;N=c[G+128>>2]|0;if((c[G+52>>2]&4|0)==0){c[2113068]=N;O=c[G+132>>2]|0;c[2113070]=O;c[2443814]=N;c[2440436]=O;aa=N;ab=O}else{c[2113070]=N;O=c[G+132>>2]|0;c[2113068]=O;c[2440436]=N;c[2443814]=O;aa=O;ab=N}N=ag(aa<<1,ab)|0;O=gGq(N)|0;c[2112926]=O;if((O|0)!=0){gGz(O|0,0,N|0)}a[9624128]=0;N=c[2414662]|0;gGz(N|0,0,(c[2411650]|0)-N|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];N=c[3532592]|0;if((N|0)!=0){gGC(9104152,N|0,280)|0}c[2113054]=c[2113060]}RI();N=c[2394]|0;O=c[14130368+(N<<2)>>2]|0;if((O|0)!=0){gGC(O|0,9104152,280)|0}c[8452240+(N<<2)>>2]=c[2113054];c[2394]=-1;N=c[2439330]|0;O=(N|0)==0;if(!O){G=N;gGC(9706056,G|0,76)|0}c[2433530]=c[2438118];G=c[3528484]|0;c[2076596]=G;M=c[2417276]|0;c[3541536]=M;c[1836236]=0;gGz(9706056,0,76);a[c[2443934]|0]=1;P=c[2385922]|0;Q=16384<<(a[673560]&1)>>>8;R=Q&255;if((R&65535)<=191){S=Q&255;Q=R;while(1){ac=Q&65535;c[N+76+(ac<<2)>>2]=P+((ac-S<<8)+16384);ac=Q+1&65535;if((ac&65535)>191){ad=R;break}else{Q=ac}}do{Q=ad&65535;R=P+((Q-S<<8)+16384)|0;c[N+76+(Q+512<<2)>>2]=R;c[N+76+(Q+768<<2)>>2]=R;ad=ad+1&65535;}while((ad&65535)<=191)}if(!O){S=N;gGC(S|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=G;c[2417276]=M;c[1836236]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;l6(0);c[2388364]=0;E=0;i=e;return E|0}}while(0);c[2414958]=0;E=1;i=e;return E|0}function ecn(){var b=0,d=0,e=0,f=0,g=0;c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}if((c[2392]|0)>=0){b=0;do{d=14130368+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}d=14130384+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}b=b+1|0;}while((b|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;fwZ();b=c[3541514]|0;if((b|0)!=0){gGr(b|0);c[3541514]=0}c[2113008]=0;c[2076598]=0;c[2383582]=0;c[2438228]=0;c[2433526]=0;c[2406676]=0;c[3528472]=0;b=c[2406698]|0;if((b|0)!=0){gGr(b);c[2406698]=0}b=c[2385412]|0;if((b|0)!=0){gGr(b);c[2385412]=0}a[64232]=0;b=c[2414958]|0;d=0;while(1){if((d|0)>=1024){f=52751;break}g=9638528+(d<<2)|0;if((c[g>>2]|0)==(b|0)){break}else{d=d+1|0}}if((f|0)==52751){c[2414958]=0;return 0}gGr(b);c[g>>2]=0;c[2414958]=0;return 0}function eco(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((a[9624128]|0)!=0){a[9624128]=0;d=c[2414662]|0;gGz(d|0,0,(c[2411650]|0)-d|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}c[2433530]=c[2438118];f=c[3528484]|0;c[2076596]=f;g=c[2417276]|0;c[3541536]=g;c[1836236]=0;gGz(9706056,0,76);a[c[2443934]|0]=1;i=c[2385922]|0;j=16384<<(a[673560]&1)>>>8;k=j&255;if((k&65535)<=191){l=j&255;j=k;while(1){m=j&65535;c[d+76+(m<<2)>>2]=i+((m-l<<8)+16384);m=j+1&65535;if((m&65535)>191){n=k;break}else{j=m}}do{j=n&65535;k=i+((j-l<<8)+16384)|0;c[d+76+(j+512<<2)>>2]=k;c[d+76+(j+768<<2)>>2]=k;n=n+1&65535;}while((n&65535)<=191)}if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=f;c[2417276]=g;c[1836236]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;l6(0);c[2388364]=0}b[4774904]=-1;b[4774988]=-1;g=0;f=-1;e=-1;do{f=((a[9633368+g|0]&1)<<g^f&65535)&65535;e=((a[9631240+g|0]&1)<<g^e&65535)&65535;g=g+1|0;}while((g|0)<16);b[4774904]=e;b[4774988]=(a[673560]&1)<<11^f;a[6518224]=1;a[6517992]=1;c[2444081]=0;f=c[2392]|0;if((f|0)>=0){gGz(8452240,0,((f|0)>0?(f<<2)+4|0:4)|0)}c[2113054]=0;f=c[2385548]|0;if((f|0)>0){gGz(9752472,0,((f|0)>1?f<<2:4)|0)}c[2433530]=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060]}f=c[2439330]|0;if((f|0)!=0){e=f;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;e=(c[2388364]|0)+1|0;c[2388364]=e;if((e|0)==180){RI();gGz(9706056,0,76);c[2388364]=0;o=a[6518224]|0?266666:0}else{o=266666}c[2113056]=o;e=RG(o)|0;c[2113054]=(c[2113054]|0)+e;c[2276108]=-1;c[2113056]=-1;c[8452200+(c[2394]<<2)>>2]=8193;c[2276080]=256;if((c[2276079]|0)>>>0<256){RH(1)}e=a[6517992]|0?66666:0;o=gGU(e,0,2048e6,0)|0;f=c[2438228]|0;g=gGS(o,K,f,(f|0)<0|0?-1:0)|0;f=g;Sb(e);e=c[2443830]|0;if((e|0)<1073676288){c[2443830]=e-f}e=c[2443831]|0;if((e|0)<1073676288){c[2443831]=e-f}e=(c[3528512]|0)-f|0;c[3528512]=(e|0)<0?0:e;e=c[2112964]|0;if((e|0)!=0){gg[c[3542118]&4095](e,a[9688]|0?534:0)}e=c[1836236]|0;f=c[9757320+(e<<2)>>2]|0;if((f|0)!=0){g=f;gGC(g|0,9706056,76)|0}c[9752472+(e<<2)>>2]=c[2433530];c[14113936+(e<<2)>>2]=c[2076596];c[9669104+(e<<2)>>2]=c[3541536];c[1836236]=-1;e=c[2394]|0;g=c[14130368+(e<<2)>>2]|0;if((g|0)!=0){gGC(g|0,9104152,280)|0}c[8452240+(e<<2)>>2]=c[2113054];c[2394]=-1;if((c[2112968]|0)==0){return 0}ecp()|0;return 0}function ecp(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;if((a[9547432]|0)!=0){f=c[2387192]|0;g=c[353e4]|0;h=0;do{i=b[f+h>>1]|0;c[g+(((h|0)/2|0)<<2)>>2]=((i&65535)>>>5<<3&248)<<8|((i&255)<<3&255)>>>3|(((i&65535)>>>10<<3&255|(i&65535)>>>12&4)&255)<<3&2016;h=h+2|0;}while((h|0)<8192);c[g+16384>>2]=0}g=ag(c[2113070]|0,c[2113068]|0)|0;if((g|0)>0){h=c[2112926]|0;f=c[2439592]|0;i=0;do{b[h+(i<<1)>>1]=4096;a[f+i|0]=0;i=i+1|0;}while((i|0)<(g|0))}g=c[3529466]|0;i=c[3530602]|0;f=c[2439580]|0;ecE(g,i,f,0,12288);h=c[3529432]|0;j=c[3530428]|0;k=c[2439578]|0;ecE(h,j,k,0,20480);ecE(g,i,f,1,12288);ecE(h,j,k,1,20480);ecE(g,i,f,2,12288);ecE(h,j,k,2,20480);ecE(g,i,f,3,12288);ecE(h,j,k,3,20480);k=c[2386566]|0;j=c[3529388]|0;h=c[2443374]|0;if((b[h+4>>1]|0)==1){l=k+16384|0;m=k+32760|0}else{l=k;m=k+16376|0}f=m;m=497-(e[j+2>>1]|0)|0;i=388-(e[j>>1]|0)|0;g=c[3530838]|0;n=c[2112926]|0;o=c[2439592]|0;p=l;do{l=b[p>>1]|0;q=l&65535;r=q>>>14;s=q>>>4&1008;t=e[p+4>>1]|0;u=b[p+6>>1]|0;v=u&65535;w=v>>>8&240;x=t>>>8&240;y=(t&512|0)==0?t&1023:t|-1024;t=(v&512|0)==0?v&1023:v|-1024;do{if(u<<16>>16!=l<<16>>16){v=q&128;z=q&64;A=(v|0)==0;B=(v>>>6^2)-1|0;v=A?x:-1;C=A?0:x-1|0;A=(z|0)==0;D=(z>>>5^2)-1|0;z=A?w:-1;E=A?0:w-1|0;if((E|0)==(z|0)){break}A=m+t|0;F=(C|0)==(v|0);G=i+y|0;H=e[p+2>>1]<<8;I=E;while(1){E=A+I|0;do{if(E>>>0<224){J=E*320|0;if(F){K=H;break}else{L=H;M=C}while(1){N=G+M|0;do{if(N>>>0<320){O=N+J|0;if((d[o+O|0]|0)>>>0>=r>>>0){P=L;break}Q=(L|0)>10485759?0:L;R=d[g+(Q>>1)|0]|0;S=((Q&1|0)==0?R:R>>>4)&15;if((S|0)==0){P=Q;break}b[n+(O<<1)>>1]=(S|s)&65535;P=Q}else{P=L}}while(0);N=P+1|0;Q=B+M|0;if((Q|0)==(v|0)){K=N;break}else{L=N;M=Q}}}else{K=H+x|0}}while(0);E=D+I|0;if((E|0)==(z|0)){break}else{H=K;I=E}}}}while(0);p=p+8|0;}while(p>>>0<f>>>0);f=c[2386452]|0;gGC(k|0,f|0,32768)|0;f=h;h=j;gGC(f|0,h|0,16)|0;R8(c[353e4]|0);return 0}function ecq(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;g=i;i=i+96|0;h=g|0;j=g+16|0;k=g+32|0;l=g+48|0;m=g+64|0;n=g+80|0;if((f|0)!=0){c[f>>2]=169730}if((e&32|0)!=0){gGz(n|0,0,12);o=c[2414662]|0;c[n>>2]=o;c[n+4>>2]=(c[2411650]|0)-o;c[n+12>>2]=162152;o=c[2076592]|0;gj[o&4095](n)|0}if((e&64|0)!=0){n=k|0;gGz(j|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){o=k+9|0;k=h;p=h|0;q=h+4|0;r=h+12|0;s=j|0;t=j+4|0;u=j+12|0;v=0;do{gGC(n|0,614896,11)|0;a[o]=v+48&255;w=8452256+(v<<2)|0;gGz(k|0,0,12);c[p>>2]=w;c[q>>2]=4;c[r>>2]=164976;gj[c[2076592]&4095](h)|0;if((c[w>>2]|0)!=0){c[s>>2]=c[14130368+(v<<2)>>2];c[t>>2]=c[8452184+(v<<2)>>2];c[u>>2]=n;w=c[2076592]|0;gj[w&4095](j)|0}v=v+1|0;}while((v|0)<=(c[2392]|0))}fw$(e);T0(e,f);gGz(m|0,0,12);c[m>>2]=9776324;c[m+4>>2]=4;c[m+12>>2]=321856;f=c[2076592]|0;gj[f&4095](m)|0;gGz(l|0,0,12);c[l>>2]=9553456;c[l+4>>2]=4;c[l+12>>2]=102144;m=c[2076592]|0;gj[m&4095](l)|0}if((e&2|0)==0){i=g;return 0}e=c[2439330]|0;l=(e|0)==0;if(!l){m=e;gGC(9706056,m|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];m=c[3528484]|0;c[2076596]=m;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;v=c[2385922]|0;j=(d[c[2443934]|0]|0)<<14;n=16384<<(a[673560]&1)>>>8;u=n&255;if((u&65535)<=191){t=n&255;n=u;while(1){s=n&65535;c[e+76+(s<<2)>>2]=v+((s-t<<8)+j);s=n+1&65535;if((s&65535)>191){x=u;break}else{n=s}}do{n=x&65535;u=v+((n-t<<8)+j)|0;c[e+76+(n+512<<2)>>2]=u;c[e+76+(n+768<<2)>>2]=u;x=x+1&65535;}while((x&65535)<=191)}if(!l){l=e;gGC(l|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=m;c[2417276]=f;c[1836236]=-1;i=g;return 0}function ecr(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2604468+(b*112|0)>>2];c[a+104>>2]=c[2604472+(b*112|0)>>2];c[a+108>>2]=c[2604476+(b*112|0)>>2];d=0;return d|0}function ecs(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=2604368+(b*112|0);e=0;return e|0}function ect(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7069252+(b*112|0)>>2];c[a+104>>2]=c[7069256+(b*112|0)>>2];c[a+108>>2]=c[7069260+(b*112|0)>>2];d=0;return d|0}function ecu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=7069152+(b*112|0);e=0;return e|0}function ecv(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7020788+(b*112|0)>>2];c[a+104>>2]=c[7020792+(b*112|0)>>2];c[a+108>>2]=c[7020796+(b*112|0)>>2];d=0;return d|0}function ecw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=7020688+(b*112|0);e=0;return e|0}function ecx(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6199040+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function ecy(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>37){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7163760+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function ecz(){var a=0;a=ecm()|0;if((a|0)!=0){return a|0}b[(c[2388150]|0)+290>>1]=326;return a|0}function ecA(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6514388+(b*112|0)>>2];c[a+104>>2]=c[6514392+(b*112|0)>>2];c[a+108>>2]=c[6514396+(b*112|0)>>2];d=0;return d|0}function ecB(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=6514288+(b*112|0);e=0;return e|0}function ecC(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6512820+(b*112|0)>>2];c[a+104>>2]=c[6512824+(b*112|0)>>2];c[a+108>>2]=c[6512828+(b*112|0)>>2];d=0;return d|0}function ecD(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=6512720+(b*112|0);e=0;return e|0}function ecE(d,f,g,h,i){d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;j=d;d=c[2112926]|0;k=c[2439592]|0;l=g+2|0;m=b[l>>1]|0;n=m&65535;o=n+33|0;p=e[g>>1]|0;q=p+108|0;r=q&511;do{if((n&16384|0)==0){if((p&16384|0)!=0){break}s=o&15;t=q&15;u=g+4|0;v=h&255;w=c[2113070]|0;x=c[2113068]|0;y=0;do{z=y-s|0;A=y+o<<2&1984;if((z|0)>-16){B=(z|0)<(w|0);C=0;do{D=C-t|0;L70167:do{if((D|0)>-16&B&(D|0)<(x|0)){E=(C+q|0)>>>3&62|A;F=b[j+(E<<1)>>1]|0;if(((F&65535)>>>14|0)!=(h|0)){break}G=b[j+((E|1)<<1)>>1]|0;E=G&65535;if(!(G<<16>>16!=0&(E|0)<(i|0))){break}G=(b[u>>1]<<6&192|(F&65535)>>>8&63)<<4;F=f+(E<<8)|0;E=0;H=z;while(1){L70173:do{if((H|0)>=0){if((H|0)>=(w|0)){break L70167}I=ag(x,H)|0;J=0;K=D;while(1){do{if((K|0)>-1&(K|0)<(x|0)){L=a[F+J|0]|0;if(L<<24>>24==0){break}M=K+I|0;b[d+(M<<1)>>1]=L&255|G;a[k+M|0]=v}}while(0);M=J+1|0;if((M|0)>=16){break L70173}J=M;K=K+1|0}}}while(0);K=E+1|0;if((K|0)<16){F=F+16|0;E=K;H=H+1|0}else{break}}}}while(0);C=C+16|0;}while((C|0)<335)}y=y+16|0;}while((y|0)<239);return}}while(0);q=g+4|0;p=h&255;n=c[2113068]|0;y=0;v=k;k=d;d=m;while(1){m=y+o&511;if((d&16384)==0){N=m}else{N=b[j+((m<<1|2049)<<1)>>1]&511}if((b[g>>1]&16384)==0){O=r}else{O=(e[j+((N<<1|2048)<<1)>>1]|0)+r|0}m=O>>>4;x=N>>>4<<5;w=N<<4&240;u=O&15;t=0;do{s=((t>>>4)+m&31|x)<<1;C=b[j+(s<<1)>>1]|0;do{if(((C&65535)>>>14|0)==(h|0)){z=b[j+((s|1)<<1)>>1]|0;A=z&65535;if(!(z<<16>>16!=0&(A|0)<(i|0))){break}z=b[q>>1]<<10&3072|(C&65535)>>>4&1008;B=A<<8|w;A=t-u|0;D=0;do{H=D+A|0;do{if((H|0)>-1&(H|0)<(n|0)){E=a[f+(D+B)|0]|0;if(E<<24>>24==0){break}b[k+(H<<1)>>1]=z|E&255;a[v+H|0]=p}}while(0);D=D+1|0;}while((D|0)<16)}}while(0);t=t+16|0;}while((t|0)<336);t=y+1|0;if((t|0)>=224){break}y=t;v=v+320|0;k=k+640|0;d=b[l>>1]|0}return}function ecF(b,c){b=b|0;c=c|0;a[9706117]=(c|0)!=0|0;return}function ecG(a){a=a|0;var b=0,d=0;b=(c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,4e6,0)|0;return a|0}function ecH(){return+(+((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)/4.0e6)}function ecI(a){a=a|0;var b=0;if((a|0)==5242880){b=c[2113157]&65535}else if((a|0)==4718592){b=(d[9625669]|0)<<8|(d[9625668]|0)}else if((a|0)==4456448){b=(d[9625667]|0)<<8|(d[9625666]|0)}else if((a|0)==4194304){b=(d[9625665]|0)<<8|(d[9625664]|0)}else if((a|0)==4980736){b=c[2113156]&65535}else{b=0}return b|0}function ecJ(a,b){a=a|0;b=b|0;if((a|0)==5242880){Uv(1,b);return}else if((a|0)==4980736){Uv(0,b);return}else{return}}function ecK(a,d){a=a|0;d=d|0;if((a|0)==3670016){b[c[2406636]>>1]=d;return}else if((a|0)==3932160){ecL((d&65535)>>>1&1,(d&65535)>>>2&1);return}else if((a|0)==3407872){b[c[2406646]>>1]=d;return}else{return}}function ecL(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;e=c[2385594]|0;if((a[e]|0)!=b<<24>>24){a[e]=b;f=c[3541206]|0;g=(b&255)<<18;b=f+g|0;c[3541190]=b;c[3541198]=b;c[3541191]=f+(g|256);c[3541199]=f+(g|65536);c[3541192]=f+(g|512);c[3541200]=f+(g|131072);c[3541193]=f+(g|768);c[3541201]=f+(g|196608)}g=e+1|0;if((a[g]|0)==d<<24>>24){return}a[g]=d;g=c[3541206]|0;e=(d&255)<<18;d=g+(e+524288)|0;c[3541194]=d;c[3541202]=d;c[3541195]=g+(e+524544);c[3541203]=g+(e+589824);c[3541196]=g+(e+524800);c[3541204]=g+(e+655360);c[3541197]=g+(e+525056);c[3541205]=g+(e+720896);return}function ecM(a,d){a=a|0;d=d|0;var e=0;e=a>>>1&2047;b[(c[2411426]|0)+(e<<1)>>1]=d;if(e>>>0>=512){return}a=d&65535;d=a>>>2&248;c[(c[2385760]|0)+(e<<2)>>2]=a>>>10&31|a<<11&63488|(d>>>5|d)<<3&2016;return}function ecN(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1631236+(b*112|0)>>2];c[a+104>>2]=c[1631240+(b*112|0)>>2];c[a+108>>2]=c[1631244+(b*112|0)>>2];d=0;return d|0}function ecO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=1631136+(b*112|0);e=0;return e|0}function ecP(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=946480+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function ecQ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>29){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1631920+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function ecR(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;b=i;i=i+360|0;d=b|0;e=b+112|0;f=b+120|0;g=b+232|0;h=b+240|0;j=b+352|0;c[2426714]=0;c[2411334]=0;c[2418080]=1048576;c[2411314]=3145728;c[3541206]=7340032;c[2385760]=8388608;c[2405648]=8390656;c[2411906]=8390656;c[2411426]=8521728;c[2406878]=8525824;c[2406874]=8529920;c[2418186]=8534016;c[2385594]=8538112;c[2406646]=8538114;c[2406636]=8538116;c[2411648]=8538118;k=0;while(1){if((k|0)>=1024){break}l=9638528+(k<<2)|0;if((c[l>>2]|0)==0){m=53034;break}else{k=k+1|0}}do{if((m|0)==53034){k=gGq(8538118)|0;c[l>>2]=k;if((k|0)==0){break}c[2426714]=k;gGz(k|0,0,8538118);c[2411334]=k;c[2418080]=k+1048576;c[2411314]=k+3145728;c[3541206]=k+7340032;c[2385760]=k+8388608;n=k+8390656|0;c[2405648]=n;c[2411906]=n;c[2411426]=k+8521728;c[2406878]=k+8525824;c[2406874]=k+8529920;c[2418186]=k+8534016;c[2385594]=k+8538112;c[2406646]=k+8538114;c[2406636]=k+8538116;n=k+8538118|0;c[2411648]=n;c[2414188]=n;if((R6(k,0,2)|0)!=0){o=1;i=b;return o|0}if((R6((c[2411334]|0)+1|0,1,2)|0)!=0){o=1;i=b;return o|0}if((R6(c[2411314]|0,2,2)|0)!=0){o=1;i=b;return o|0}if((R6((c[2411314]|0)+1|0,3,2)|0)!=0){o=1;i=b;return o|0}k=c[2418080]|0;if((c[3542200]|0)==0){o=1;i=b;return o|0}n=h+108|0;c[n>>2]=0;p=h+100|0;c[p>>2]=0;q=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[q&16383](h,4)|0;do{if((c[n>>2]|0)!=0){q=c[p>>2]|0;c[j>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](j,4,0)|0;if((q|0)<1){o=1;i=b;return o|0}if((gzL(k,0,4)|0)==0){break}else{o=1}i=b;return o|0}}while(0);k=c[3541206]|0;if((c[3542200]|0)==0){o=1;i=b;return o|0}p=f+108|0;c[p>>2]=0;n=f+100|0;c[n>>2]=0;q=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[q&16383](f,5)|0;do{if((c[p>>2]|0)!=0){q=c[n>>2]|0;c[g>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](g,5,0)|0;if((q|0)<1){o=1;i=b;return o|0}if((gzL(k,0,5)|0)==0){break}else{o=1}i=b;return o|0}}while(0);k=(c[3541206]|0)+524288|0;if((c[3542200]|0)==0){o=1;i=b;return o|0}n=d+108|0;c[n>>2]=0;p=d+100|0;c[p>>2]=0;q=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[q&16383](d,6)|0;do{if((c[n>>2]|0)!=0){q=c[p>>2]|0;c[e>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](e,6,0)|0;if((q|0)<1){o=1;i=b;return o|0}if((gzL(k,0,6)|0)==0){break}else{o=1}i=b;return o|0}}while(0);k=c[2411314]|0;p=0;do{n=k+(p|2)|0;q=a[n]|0;r=k+(p|1)|0;a[n]=a[r]|0;a[r]=q;p=p+4|0;}while((p|0)<4194304);fxU(0,425984);if((c[2394]|0)==0){s=c[2112932]|0}else{c[2394]=0;p=c[3532596]|0;c[2112932]=p;k=c[3532592]|0;if((k|0)!=0){gGC(9104152,k|0,280)|0}c[2113054]=c[2113060];s=p}p=c[2411334]|0;k=s|0;q=0;while(1){r=p+q|0;c[k>>2]=r;c[k+131072>>2]=r;r=q+1024|0;if(r>>>0>1048575){break}else{k=k+4|0;q=r}}q=c[2411906]|0;k=s+4096|0;p=1048576;while(1){r=q+(p-1048576)|0;c[k>>2]=r;c[k+65536>>2]=r;c[k+131072>>2]=r;r=p+1024|0;if(r>>>0>1114111){break}else{k=k+4|0;p=r}}p=c[2411426]|0;k=p;c[s+8192>>2]=k;c[s+139264>>2]=k;k=p+1024|0;c[s+8196>>2]=k;c[s+139268>>2]=k;k=p+2048|0;c[s+8200>>2]=k;c[s+139272>>2]=k;k=p+3072|0;c[s+8204>>2]=k;c[s+139276>>2]=k;c[s+73728>>2]=1;c[s+73732>>2]=1;c[s+73736>>2]=1;c[s+73740>>2]=1;k=c[2406878]|0;p=k;c[s+9216>>2]=p;c[s+74752>>2]=p;c[s+140288>>2]=p;p=k+1024|0;c[s+9220>>2]=p;c[s+74756>>2]=p;c[s+140292>>2]=p;p=k+2048|0;c[s+9224>>2]=p;c[s+74760>>2]=p;c[s+140296>>2]=p;p=k+3072|0;c[s+9228>>2]=p;c[s+74764>>2]=p;c[s+140300>>2]=p;p=c[2406874]|0;k=p;c[s+10240>>2]=k;c[s+75776>>2]=k;c[s+141312>>2]=k;k=p+1024|0;c[s+10244>>2]=k;c[s+75780>>2]=k;c[s+141316>>2]=k;k=p+2048|0;c[s+10248>>2]=k;c[s+75784>>2]=k;c[s+141320>>2]=k;k=p+3072|0;c[s+10252>>2]=k;c[s+75788>>2]=k;c[s+141324>>2]=k;k=c[2418186]|0;p=k;c[s+11264>>2]=p;c[s+76800>>2]=p;c[s+142336>>2]=p;p=k+1024|0;c[s+11268>>2]=p;c[s+76804>>2]=p;c[s+142340>>2]=p;p=k+2048|0;c[s+11272>>2]=p;c[s+76808>>2]=p;c[s+142344>>2]=p;p=k+3072|0;c[s+11276>>2]=p;c[s+76812>>2]=p;c[s+142348>>2]=p;p=s+35840|0;k=9175040;while(1){r=q+(k-9109504)|0;c[p>>2]=r;c[p+65536>>2]=r;c[p+131072>>2]=r;r=k+1024|0;if(r>>>0>9240575){break}else{p=p+4|0;k=r}}c[s+196688>>2]=904;c[s+196728>>2]=1130;c[s+196648>>2]=164;c[s+196732>>2]=134;k=c[3532592]|0;if((k|0)!=0){gGC(k|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;Ux(0,7500,1);Ux(1,7500,1);c[2407030]=256;c[2407068]=3;c[2407069]=256;c[2407107]=3;k=c[642608+(c[2436]<<2)>>2]|0;p=c[k+128>>2]|0;if((c[k+52>>2]&4|0)==0){c[2113068]=p;q=c[k+132>>2]|0;c[2113070]=q;c[2443814]=p;c[2440436]=q;t=p;u=q}else{c[2113070]=p;q=c[k+132>>2]|0;c[2113068]=q;c[2440436]=p;c[2443814]=q;t=q;u=p}p=ag(t<<1,u)|0;q=gGq(p)|0;c[2112926]=q;if((q|0)!=0){gGz(q|0,0,p|0)}if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];p=c[3532592]|0;if((p|0)!=0){gGC(9104152,p|0,280)|0}c[2113054]=c[2113060]}RI();p=c[2394]|0;q=c[14130368+(p<<2)>>2]|0;if((q|0)!=0){gGC(q|0,9104152,280)|0}c[8452240+(p<<2)>>2]=c[2113054];c[2394]=-1;c[2113156]=0;a[9628264]=0;c[2407033]=0;p=c[3541206]|0;c[3541190]=p;c[3541198]=p;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=p+256;c[3541199]=p+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=p+512;c[3541200]=p+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=p+768;c[3541201]=p+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2113157]=0;a[9628420]=0;c[2407072]=0;q=p+1048576|0;c[3541194]=q;c[3541202]=q;gGz(c[2430122]|0,0,16384);c[2407080]=4;c[3541195]=p+1048832;c[3541203]=p+1114112;gGz(c[2430123]|0,0,16384);c[2407088]=4;c[3541196]=p+1049088;c[3541204]=p+1179648;gGz(c[2430124]|0,0,16384);c[2407096]=4;c[3541197]=p+1049344;c[3541205]=p+1245184;gGz(c[2430125]|0,0,16384);c[2407104]=4;p=c[2385594]|0;a[p]=1;a[p+1|0]=1;ecL(0,0);o=0;i=b;return o|0}}while(0);c[2426714]=0;o=1;i=b;return o|0}function ecS(){var a=0,b=0,d=0,e=0,f=0;c[2113070]=0;c[2113068]=0;a=c[2112926]|0;if((a|0)!=0){gGr(a);c[2112926]=0}if((c[2392]|0)>=0){a=0;do{b=14130368+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}b=14130384+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}a=a+1|0;}while((a|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;Uw(0);Uw(1);a=c[2426714]|0;b=0;while(1){if((b|0)>=1024){e=53108;break}f=9638528+(b<<2)|0;if((c[f>>2]|0)==(a|0)){break}else{b=b+1|0}}if((e|0)==53108){c[2426714]=0;return 0}gGr(a);c[f>>2]=0;c[2426714]=0;return 0}function ecT(){var b=0,d=0,e=0,f=0,g=0;if((a[9624120]|0)!=0){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];b=c[3532592]|0;if((b|0)!=0){gGC(9104152,b|0,280)|0}c[2113054]=c[2113060]}RI();b=c[2394]|0;d=c[14130368+(b<<2)>>2]|0;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[8452240+(b<<2)>>2]=c[2113054];c[2394]=-1;c[2113156]=0;a[9628264]=0;c[2407033]=0;b=c[3541206]|0;c[3541190]=b;c[3541198]=b;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=b+256;c[3541199]=b+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=b+512;c[3541200]=b+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=b+768;c[3541201]=b+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2113157]=0;a[9628420]=0;c[2407072]=0;d=b+1048576|0;c[3541194]=d;c[3541202]=d;gGz(c[2430122]|0,0,16384);c[2407080]=4;c[3541195]=b+1048832;c[3541203]=b+1114112;gGz(c[2430123]|0,0,16384);c[2407088]=4;c[3541196]=b+1049088;c[3541204]=b+1179648;gGz(c[2430124]|0,0,16384);c[2407096]=4;c[3541197]=b+1049344;c[3541205]=b+1245184;gGz(c[2430125]|0,0,16384);c[2407104]=4;b=c[2385594]|0;a[b]=1;a[b+1|0]=1;ecL(0,0)}c[2406416]=-1;b=0;d=-1;e=-1;f=-1;do{d=((a[9633360+b|0]&1)<<b^d&255)&255;e=((a[9631232+b|0]&1)<<b^e&255)&255;f=((a[9551792+b|0]&1)<<b^f&255)&255;b=b+1|0;}while((b|0)<8);a[9625664]=d;a[9625665]=e;a[9625666]=f;f=c[2438]|0;e=gGU(f,(f|0)<0|0?-1:0,16e6,0)|0;f=gGS(e,K,15360,0)|0;e=f;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060]}c[2113056]=e;f=RG(e)|0;c[2113054]=(c[2113054]|0)+f;c[2276108]=-1;c[2113056]=-1;f=c[2394]|0;c[8452200+(f<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0<1024){RH(4);g=c[2394]|0}else{g=f}f=c[14130368+(g<<2)>>2]|0;if((f|0)!=0){gGC(f|0,9104152,280)|0}c[8452240+(g<<2)>>2]=c[2113054];c[2394]=-1;g=c[2112964]|0;if((g|0)!=0){f=a[9688]|0;gGz(g|0,0,(f?2136:0)|0);e=f?534:0;Uu(0,g,e);Uu(1,g,e)}if((c[2112968]|0)==0){return 0}ecU()|0;return 0}function ecU(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((a[9753336]|0)!=0){d=c[2411426]|0;f=c[2385760]|0;g=0;do{h=e[d+(g<<1)>>1]|0;i=h>>>2&248;c[f+(g<<2)>>2]=h>>>10&31|h<<11&63488|(i>>>5|i)<<3&2016;g=g+1|0;}while((g|0)<512);a[9753336]=0}g=c[2406646]|0;f=c[2406636]|0;d=c[2418186]|0;i=c[2112926]|0;h=c[2418080]|0;j=0;do{k=(j<<4&496)-(e[g>>1]|0)|0;l=(k|0)<-191?k+512|0:k;k=(((j|0)/32|0)<<4)-(e[f>>1]|0)|0;do{if((l+15|0)>>>0<=334){if((k+15|0)>>>0>238){break}m=b[d+(j<<1)>>1]&8191;if(l>>>0<305&k>>>0<209){Sy(i,m,l,k,0,8,0,h);break}else{Sz(i,m,l,k,0,8,0,h);break}}}while(0);j=j+1|0;}while((j|0)<2048);j=c[2406878]|0;h=c[2406874]|0;d=c[2411314]|0;f=0;do{g=e[j+(f<<1)>>1]|0;k=g&255;l=e[h+(f<<1)>>1]|0;m=l>>>1&16383;n=l<<8&256|g>>>8;l=n>>>0>335?n|-512:n;n=k>>>0>239?g|-256:k;do{if(l>>>0<305){if((n-1|0)>>>0>=208){o=53150;break}SG(i,m,l,n,0,8,0,256,d)}else{o=53150}}while(0);do{if((o|0)==53150){o=0;if((l+16|0)>>>0>=336){break}if((n+16|0)>>>0>=240){break}SH(i,m,l,n,0,8,0,256,d)}}while(0);f=f+1|0;}while((f|0)<2048);R8(c[2385760]|0);return 0}function ecV(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=i;i=i+64|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;if((d|0)!=0){c[d>>2]=169585}if((b&32|0)!=0){gGz(j|0,0,12);d=c[2405648]|0;c[j>>2]=d;c[j+4>>2]=(c[2411648]|0)-d;c[j+12>>2]=162152;d=c[2076592]|0;gj[d&4095](j)|0}if((b&64|0)==0){i=e;return 0}j=h|0;gGz(g|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){d=h+9|0;h=f;k=f|0;l=f+4|0;m=f+12|0;n=g|0;o=g+4|0;p=g+12|0;q=0;do{gGC(j|0,614896,11)|0;a[d]=q+48&255;r=8452256+(q<<2)|0;gGz(h|0,0,12);c[k>>2]=r;c[l>>2]=4;c[m>>2]=164976;gj[c[2076592]&4095](f)|0;if((c[r>>2]|0)!=0){c[n>>2]=c[14130368+(q<<2)>>2];c[o>>2]=c[8452184+(q<<2)>>2];c[p>>2]=j;r=c[2076592]|0;gj[r&4095](g)|0}q=q+1|0;}while((q|0)<=(c[2392]|0))}Ut(0);Ut(1);if((b&2|0)==0){i=e;return 0}b=c[2385594]|0;q=a[b]|0;g=b+1|0;j=a[g]|0;a[b]=-1;a[g]=-1;ecL(q,j);a[9753336]=1;i=e;return 0}function ecW(d,f){d=d|0;f=f|0;var g=0,h=0,i=0;if((d&-1024|0)==16760832){g=c[2386450]|0;a[g+(d&1023^1)|0]=f;if((d&1022|0)!=1020){return}if((b[g+1016>>1]|0)!=0){return}if((b[g+1018>>1]|0)!=0){return}if((b[g+1022>>1]|0)!=0){return}gGz(g|0,0,1020);return}if((d&-4096|0)==16769024){g=c[2387190]|0;a[g+(d&4095^1)|0]=f;h=d&4094;i=e[g+h>>1]|0;g=i>>>5&31;c[(c[3529998]|0)+(h>>>1<<2)>>2]=i>>>10<<11&63488|i&31|(g<<3|g>>>2)<<3&2016;return}if((d|0)==16773123){g=c[2405100]|0;a[g]=(f&255)>>>4;a[g+1|0]=f&15;return}else if((d|0)==16773129){g=(((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)*-5|0)+((c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)<<1)|0;if(g>>>0>5){Sb((g>>>0)/5|0)}a[c[2433510]|0]=-128;a[c[3528270]|0]=f;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12;return}else if((d|0)==16773121){a[c[3526940]|0]=f&3;a[c[2440228]|0]=(f&255)>>>3&1;a[c[2438894]|0]=(f&255)>>>5&1;a[c[3528696]|0]=f&-128;return}else{return}}function ecX(a,d){a=a|0;d=d|0;var e=0,f=0,g=0;if((a&-1024|0)!=16760832){if((a&-4096|0)==16769024){e=a&4094;b[(c[2387190]|0)+e>>1]=d;f=d&65535;g=f>>>5&31;c[(c[3529998]|0)+(e>>>1<<2)>>2]=f>>>10<<11&63488|f&31|(g<<3|g>>>2)<<3&2016;return}if((a|0)==16773124){b[c[2408994]>>1]=d-14&65535;return}else if((a|0)==16773126){b[(c[2408994]|0)+2>>1]=d;return}else{return}}g=c[2386450]|0;f=a&1022;b[g+f>>1]=d;if((f|0)!=1020){return}if((b[g+1016>>1]|0)!=0){return}if((b[g+1018>>1]|0)!=0){return}if((b[g+1022>>1]|0)!=0){return}gGz(g|0,0,1020);return}function ecY(b){b=b|0;var d=0;switch(b|0){case 16773127:{d=~a[9550468];return d|0};case 16773129:{b=(((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)*-5|0)+((c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)<<1)|0;if(b>>>0>5){Sb((b>>>0)/5|0)}d=a[c[2433510]|0]|a[9550464]&127;return d|0};case 16773133:{d=a[9635056]|0;return d|0};case 16773131:{d=~a[9550469];return d|0};case 16773125:{d=~a[9550467];return d|0};case 16773121:{d=~a[9550465];return d|0};case 16773135:{d=a[9635057]|0;return d|0};case 16773123:{d=~a[9550466];return d|0};default:{d=0;return d|0}}return 0}function ecZ(a){a=a|0;return 0}function ec_(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=b&65535;switch(e&255|0){case 0:{a[c[3528390]|0]=d;b=c[2385920]|0;f=c[9757320+(c[1836236]<<2)>>2]|0;g=((d&255)<<15&98304)-32768|0;h=128;i=128;while(1){c[f+76+(i<<2)>>2]=b+(g+(i<<8));j=h+1&65535;if((j&65535)>255){k=128;l=128;break}else{h=j;i=j&65535}}while(1){i=b+(g+(l<<8))|0;c[f+76+(l+512<<2)>>2]=i;c[f+76+(l+768<<2)>>2]=i;i=k+1&65535;if((i&65535)>255){break}else{k=i;l=i&65535}}return};case 8:case 9:case 10:case 11:{l7(e&3,d);return};case 24:{a[c[2433510]|0]=0;return};default:{return}}}function ec$(b){b=b|0;var d=0,e=0,f=0.0,g=0.0,i=0,j=0;d=b&255;if((d|0)==16){e=a[c[3528270]|0]|0;return e|0}else if((d|0)==10){e=a[(c[3541514]|0)+20904|0]|0;return e|0}else if((d|0)==8){d=c[3541514]|0;b=d+552|0;f=+h[b>>3];do{if(f!=0.0){g=+h[6675];if(f-(g+ +gC[c[2429842]&255]())>0.0){i=a[d+563|0]|-128;break}else{h[b>>3]=0.0;j=53257;break}}else{j=53257}}while(0);if((j|0)==53257){i=a[d+563|0]|0}e=i&-125;return e|0}else{e=0;return e|0}return 0}function ec0(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2092308+(b*112|0)>>2];c[a+104>>2]=c[2092312+(b*112|0)>>2];c[a+108>>2]=c[2092316+(b*112|0)>>2];d=0;return d|0}function ec1(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=2092208+(b*112|0);e=0;return e|0}function ec2(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1174256+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function ec3(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>52){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3248552+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function ec4(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;e=i;i=i+856|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+848|0;c[2414956]=0;c[2388148]=0;c[2385920]=1572864;c[3530836]=1703936;c[3530600]=4849664;c[3529754]=6946816;c[3529710]=7471104;c[3529998]=8519680;c[2414660]=8527872;c[2388274]=8527872;c[2387190]=8544256;c[2386450]=8548352;c[2386212]=8549376;c[2387032]=8553472;c[2386074]=8684544;c[3528270]=8686592;c[2433510]=8686593;c[3528696]=8686594;c[3528390]=8686595;c[2405100]=8686596;c[3526940]=8686598;c[2438894]=8686599;c[2440228]=8686600;c[2408994]=8686601;c[2411646]=8686605;x=0;while(1){if((x|0)>=1024){break}y=9638528+(x<<2)|0;if((c[y>>2]|0)==0){z=53295;break}else{x=x+1|0}}do{if((z|0)==53295){x=gGq(8686605)|0;c[y>>2]=x;if((x|0)==0){break}c[2414956]=x;gGz(x|0,0,8686605);c[2388148]=x;c[2385920]=x+1572864;c[3530836]=x+1703936;c[3530600]=x+4849664;c[3529754]=x+6946816;c[3529710]=x+7471104;c[3529998]=x+8519680;A=x+8527872|0;c[2414660]=A;c[2388274]=A;c[2387190]=x+8544256;c[2386450]=x+8548352;c[2386212]=x+8549376;c[2387032]=x+8553472;c[2386074]=x+8684544;c[3528270]=x+8686592;c[2433510]=x+8686593;c[3528696]=x+8686594;c[3528390]=x+8686595;c[2405100]=x+8686596;c[3526940]=x+8686598;c[2438894]=x+8686599;c[2440228]=x+8686600;c[2408994]=x+8686601;A=x+8686605|0;c[2411646]=A;c[2414186]=A;A=(dW(c[c[642608+(c[2436]<<2)>>2]>>2]|0,259072,8)|0)==0;c[2433492]=A?8:0;if((R6(x+1|0,0,2)|0)!=0){B=1;i=e;return B|0}if((R6(c[2388148]|0,1,2)|0)!=0){B=1;i=e;return B|0}if((R6((c[2388148]|0)+1048577|0,2,2)|0)!=0){B=1;i=e;return B|0}if((R6((c[2388148]|0)+1048576|0,3,2)|0)!=0){B=1;i=e;return B|0}x=c[2385920]|0;if((c[3542200]|0)==0){B=1;i=e;return B|0}A=t+108|0;c[A>>2]=0;C=t+100|0;c[C>>2]=0;D=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[D&16383](t,4)|0;do{if((c[A>>2]|0)!=0){D=c[C>>2]|0;c[u>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](u,4,0)|0;if((D|0)<1){B=1;i=e;return B|0}if((gzL(x,0,4)|0)==0){break}else{B=1}i=e;return B|0}}while(0);x=c[3529754]|0;if((c[3542200]|0)==0){B=1;i=e;return B|0}C=r+108|0;c[C>>2]=0;A=r+100|0;c[A>>2]=0;D=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[D&16383](r,5)|0;do{if((c[C>>2]|0)!=0){D=c[A>>2]|0;c[s>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](s,5,0)|0;if((D|0)<1){B=1;i=e;return B|0}if((gzL(x,0,5)|0)==0){break}else{B=1}i=e;return B|0}}while(0);x=c[3529710]|0;if((c[3542200]|0)==0){B=1;i=e;return B|0}A=p+108|0;c[A>>2]=0;C=p+100|0;c[C>>2]=0;D=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[D&16383](p,6)|0;do{if((c[A>>2]|0)!=0){D=c[C>>2]|0;c[q>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](q,6,0)|0;if((D|0)<1){B=1;i=e;return B|0}if((gzL(x,0,6)|0)==0){break}else{B=1}i=e;return B|0}}while(0);x=(c[3529710]|0)+524288|0;if((c[3542200]|0)==0){B=1;i=e;return B|0}C=n+108|0;c[C>>2]=0;A=n+100|0;c[A>>2]=0;D=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[D&16383](n,7)|0;do{if((c[C>>2]|0)!=0){D=c[A>>2]|0;c[o>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](o,7,0)|0;if((D|0)<1){B=1;i=e;return B|0}if((gzL(x,0,7)|0)==0){break}else{B=1}i=e;return B|0}}while(0);if((R6(c[3530600]|0,8,2)|0)!=0){B=1;i=e;return B|0}if((R6((c[3530600]|0)+1|0,9,2)|0)!=0){B=1;i=e;return B|0}x=c[3530836]|0;if((c[3542200]|0)==0){B=1;i=e;return B|0}A=l+108|0;c[A>>2]=0;C=l+100|0;c[C>>2]=0;D=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[D&16383](l,10)|0;do{if((c[A>>2]|0)!=0){D=c[C>>2]|0;c[m>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](m,10,0)|0;if((D|0)<1){B=1;i=e;return B|0}if((gzL(x,0,10)|0)==0){break}else{B=1}i=e;return B|0}}while(0);do{if((c[2433492]|0)==0){x=(c[3530836]|0)+524288|0;if((c[3542200]|0)==0){B=1;i=e;return B|0}C=j+108|0;c[C>>2]=0;A=j+100|0;c[A>>2]=0;D=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[D&16383](j,11)|0;do{if((c[C>>2]|0)!=0){D=c[A>>2]|0;c[k>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](k,11,0)|0;if((D|0)<1){B=1;i=e;return B|0}if((gzL(x,0,11)|0)==0){break}else{B=1}i=e;return B|0}}while(0);x=(c[3530836]|0)+1048576|0;if((c[3542200]|0)==0){B=1;i=e;return B|0}A=f+108|0;c[A>>2]=0;C=f+100|0;c[C>>2]=0;D=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[D&16383](f,12)|0;if((c[A>>2]|0)==0){break}A=c[C>>2]|0;c[g>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](g,12,0)|0;if((A|0)<1){B=1;i=e;return B|0}if((gzL(x,0,12)|0)==0){break}else{B=1}i=e;return B|0}else{b[(c[2388148]|0)+47390>>1]=0}}while(0);x=c[3530600]|0;A=0;do{C=x+(A|1)|0;D=a[C]|0;E=x+(A|2)|0;a[C]=a[E]|0;a[E]=D;A=A+4|0;}while((A|0)<1048576);A=c[3530836]|0;D=1572864;while(1){E=D-1|0;C=A+E|0;F=E<<1;a[A+(F|1)|0]=(d[C]|0)>>>4;a[A+F|0]=a[C]&15;if((E|0)>0){D=E}else{G=1048576;break}}do{G=G-1|0;D=x+G|0;A=G<<1;a[x+(A|1)|0]=(d[D]|0)>>>4;a[x+A|0]=a[D]&15;}while((G|0)>0);fxU(0,425984);if((c[2394]|0)==0){H=c[2112932]|0}else{c[2394]=0;x=c[3532596]|0;c[2112932]=x;D=c[3532592]|0;if((D|0)!=0){gGC(9104152,D|0,280)|0}c[2113054]=c[2113060];H=x}x=c[2388148]|0;D=H|0;A=0;while(1){E=x+A|0;c[D>>2]=E;c[D+131072>>2]=E;E=A+1024|0;if(E>>>0>262143){break}else{D=D+4|0;A=E}}A=H+4096|0;D=1048576;while(1){E=x+D|0;c[A>>2]=E;c[A+131072>>2]=E;E=D+1024|0;if(E>>>0>1572863){break}else{A=A+4|0;D=E}}D=c[2387032]|0;A=H+32768|0;x=8388608;while(1){E=D+(x-8388608)|0;c[A>>2]=E;c[A+65536>>2]=E;c[A+131072>>2]=E;E=x+1024|0;if(E>>>0>8519679){break}else{A=A+4|0;x=E}}x=c[2388274]|0;c[H+65408>>2]=x;c[H+130944>>2]=x;c[H+196480>>2]=x;A=x+1024|0;c[H+65412>>2]=A;c[H+130948>>2]=A;c[H+196484>>2]=A;A=x+2048|0;c[H+65416>>2]=A;c[H+130952>>2]=A;c[H+196488>>2]=A;A=x+3072|0;c[H+65420>>2]=A;c[H+130956>>2]=A;c[H+196492>>2]=A;A=x+4096|0;c[H+65424>>2]=A;c[H+130960>>2]=A;c[H+196496>>2]=A;A=x+5120|0;c[H+65428>>2]=A;c[H+130964>>2]=A;c[H+196500>>2]=A;A=x+6144|0;c[H+65432>>2]=A;c[H+130968>>2]=A;c[H+196504>>2]=A;A=x+7168|0;c[H+65436>>2]=A;c[H+130972>>2]=A;c[H+196508>>2]=A;A=x+8192|0;c[H+65440>>2]=A;c[H+130976>>2]=A;c[H+196512>>2]=A;A=x+9216|0;c[H+65444>>2]=A;c[H+130980>>2]=A;c[H+196516>>2]=A;A=x+10240|0;c[H+65448>>2]=A;c[H+130984>>2]=A;c[H+196520>>2]=A;A=x+11264|0;c[H+65452>>2]=A;c[H+130988>>2]=A;c[H+196524>>2]=A;A=x+12288|0;c[H+65456>>2]=A;c[H+130992>>2]=A;c[H+196528>>2]=A;A=x+13312|0;c[H+65460>>2]=A;c[H+130996>>2]=A;c[H+196532>>2]=A;A=x+14336|0;c[H+65464>>2]=A;c[H+131e3>>2]=A;c[H+196536>>2]=A;A=x+15360|0;c[H+65468>>2]=A;c[H+131004>>2]=A;c[H+196540>>2]=A;A=c[2386450]|0;c[H+65472>>2]=A;c[H+196544>>2]=A;A=c[2386212]|0;c[H+65488>>2]=A;c[H+131024>>2]=A;c[H+196560>>2]=A;x=A+1024|0;c[H+65492>>2]=x;c[H+131028>>2]=x;c[H+196564>>2]=x;x=A+2048|0;c[H+65496>>2]=x;c[H+131032>>2]=x;c[H+196568>>2]=x;x=A+3072|0;c[H+65500>>2]=x;c[H+131036>>2]=x;c[H+196572>>2]=x;x=c[2387190]|0;c[H+65504>>2]=x;c[H+196576>>2]=x;A=x+1024|0;c[H+65508>>2]=A;c[H+196580>>2]=A;A=x+2048|0;c[H+65512>>2]=A;c[H+196584>>2]=A;A=x+3072|0;c[H+65516>>2]=A;c[H+196588>>2]=A;c[H+196648>>2]=3406;c[H+196728>>2]=2724;c[H+196608>>2]=1434;c[H+196688>>2]=1804;A=c[3532592]|0;if((A|0)!=0){gGC(A|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);A=c[2439330]|0;x=(A|0)==0;if(!x){D=A;gGC(9706056,D|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];D=c[3528484]|0;c[2076596]=D;E=c[2417276]|0;c[3541536]=E;c[1836236]=0;C=c[2385920]|0;F=0;I=0;while(1){c[A+76+(I<<2)>>2]=C+(I<<8);J=F+1&65535;if((J&65535)>119){K=0;L=0;break}else{F=J;I=J&65535}}while(1){I=C+(L<<8)|0;c[A+76+(L+512<<2)>>2]=I;c[A+76+(L+768<<2)>>2]=I;I=K+1&65535;if((I&65535)>119){break}else{K=I;L=I&65535}}C=c[2386074]|0;c[A+556>>2]=C;I=C+256|0;c[A+560>>2]=I;F=C+512|0;c[A+564>>2]=F;J=C+768|0;c[A+568>>2]=J;M=C+1024|0;c[A+572>>2]=M;N=C+1280|0;c[A+576>>2]=N;O=C+1536|0;c[A+580>>2]=O;P=C+1792|0;c[A+584>>2]=P;c[A+1580>>2]=C;c[A+1584>>2]=I;c[A+1588>>2]=F;c[A+1592>>2]=J;c[A+1596>>2]=M;c[A+1600>>2]=N;c[A+1604>>2]=O;c[A+1608>>2]=P;c[A+2604>>2]=C;c[A+3628>>2]=C;c[A+2608>>2]=I;c[A+3632>>2]=I;c[A+2612>>2]=F;c[A+3636>>2]=F;c[A+2616>>2]=J;c[A+3640>>2]=J;c[A+2620>>2]=M;c[A+3644>>2]=M;c[A+2624>>2]=N;c[A+3648>>2]=N;c[A+2628>>2]=O;c[A+3652>>2]=O;c[A+2632>>2]=P;c[A+3656>>2]=P;c[A+4176>>2]=1458;c[A+4172>>2]=726;if(!x){P=A;gGC(P|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=D;c[2417276]=E;c[1836236]=-1;c[v>>2]=1048576;c[w>>2]=524288;TW(c[3529710]|0,v,c[3529754]|0,w,32,850,132);c[2438228]=4e6;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=511;h[745406]=.75;c[2436786]=3;h[745405]=.75;c[2436784]=3;h[745404]=.25;a[3203280]=1;P=c[642608+(c[2436]<<2)>>2]|0;O=c[P+128>>2]|0;if((c[P+52>>2]&4|0)==0){c[2113068]=O;N=c[P+132>>2]|0;c[2113070]=N;c[2443814]=O;c[2440436]=N;Q=O;R=N}else{c[2113070]=O;N=c[P+132>>2]|0;c[2113068]=N;c[2440436]=O;c[2443814]=N;Q=N;R=O}O=ag(Q<<1,R)|0;N=gGq(O)|0;c[2112926]=N;if((N|0)!=0){gGz(N|0,0,O|0)}O=c[2414660]|0;gGz(O|0,0,(c[2411646]|0)-O|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];O=c[3532592]|0;if((O|0)!=0){gGC(9104152,O|0,280)|0}c[2113054]=c[2113060]}RI();O=c[2394]|0;N=c[14130368+(O<<2)>>2]|0;if((N|0)!=0){gGC(N|0,9104152,280)|0}c[8452240+(O<<2)>>2]=c[2113054];c[2394]=-1;O=c[2439330]|0;N=(O|0)==0;if(!N){P=O;gGC(9706056,P|0,76)|0}P=c[2438118]|0;c[2433530]=P;M=c[3528484]|0;c[2076596]=M;J=c[2417276]|0;c[3541536]=J;c[1836236]=0;gGz(9706056,0,76);if(!N){N=O;gGC(N|0,9706056,76)|0}c[2438118]=P;c[3528484]=M;c[2417276]=J;c[1836236]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;l6(0);B=0;i=e;return B|0}}while(0);c[2414956]=0;B=1;i=e;return B|0}function ec5(){var b=0,d=0,e=0,f=0,g=0;c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}b=c[3541514]|0;if((b|0)!=0){gGr(b|0);c[3541514]=0}c[2113008]=0;c[2076598]=0;c[2383582]=0;c[2438228]=0;c[2433526]=0;c[2406676]=0;c[3528472]=0;b=c[2406698]|0;if((b|0)!=0){gGr(b);c[2406698]=0}b=c[2385412]|0;if((b|0)!=0){gGr(b);c[2385412]=0}a[64232]=0;fwZ();if((c[2392]|0)>=0){b=0;do{d=14130368+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}d=14130384+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}b=b+1|0;}while((b|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;b=c[2414956]|0;d=0;while(1){if((d|0)>=1024){f=53423;break}g=9638528+(d<<2)|0;if((c[g>>2]|0)==(b|0)){break}else{d=d+1|0}}if((f|0)==53423){c[2414956]=0;return 0}gGr(b);c[g>>2]=0;c[2414956]=0;return 0}function ec6(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0;if((a[9624112]|0)!=0){d=c[2414660]|0;gGz(d|0,0,(c[2411646]|0)-d|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=i;c[1836236]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;l6(0)}i=c[2392]|0;if((i|0)>=0){gGz(8452240,0,((i|0)>0?(i<<2)+4|0:4)|0)}c[2113054]=0;i=c[2385548]|0;if((i|0)>0){gGz(9752472,0,((i|0)>1?i<<2:4)|0)}c[2433530]=0;a[9550464]=-1;gGz(9550465,0,5);i=0;g=-1;f=0;e=0;do{g=((a[9633352+i|0]&1)<<i^g&255)&255;f=((a[9631224+i|0]&1)<<i|f&255)&255;e=((a[9629536+i|0]&1)<<i|e&255)&255;i=i+1|0;}while((i|0)<8);a[9550464]=g;a[9550465]=f;a[9550466]=e;if((f&3)==3){g=f&-4;a[9550465]=g;j=g}else{j=f}if((j&12)==12){a[9550465]=j&-13}if((e&3)==3){j=e&-4;a[9550466]=j;k=j}else{k=e}if((k&12)==12){a[9550466]=k&-13}if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];k=c[3532592]|0;if((k|0)!=0){gGC(9104152,k|0,280)|0}c[2113054]=c[2113060]}k=c[2439330]|0;if((k|0)!=0){e=k;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;c[2113056]=166666;e=RG(166666)|0;c[2113054]=(c[2113054]|0)+e;c[2276108]=-1;c[2113056]=-1;c[8452200+(c[2394]<<2)>>2]=8193;c[2276080]=256;if((c[2276079]|0)>>>0<256){RH(1)}e=c[2438228]|0;k=gGS(-747372544,31788,e,(e|0)<0|0?-1:0)|0;e=k;Sb(66666);k=c[2443830]|0;if((k|0)<1073676288){c[2443830]=k-e}k=c[2443831]|0;if((k|0)<1073676288){c[2443831]=k-e}k=(c[3528512]|0)-e|0;c[3528512]=(k|0)<0?0:k;k=c[2112964]|0;if((k|0)!=0){gg[c[3542118]&4095](k,a[9688]|0?534:0)}k=c[1836236]|0;e=c[9757320+(k<<2)>>2]|0;if((e|0)!=0){j=e;gGC(j|0,9706056,76)|0}c[9752472+(k<<2)>>2]=c[2433530];c[14113936+(k<<2)>>2]=c[2076596];c[9669104+(k<<2)>>2]=c[3541536];c[1836236]=-1;k=c[2394]|0;j=c[14130368+(k<<2)>>2]|0;if((j|0)!=0){gGC(j|0,9104152,280)|0}c[8452240+(k<<2)>>2]=c[2113054];c[2394]=-1;if((c[2112968]|0)==0){return 0}ec7()|0;return 0}function ec7(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;if((a[9547424]|0)!=0){f=c[2387190]|0;g=c[3529998]|0;h=0;do{i=e[f+h>>1]|0;j=i>>>5&31;c[g+(((h|0)/2|0)<<2)>>2]=i>>>10<<11&63488|i&31|(j<<3|j>>>2)<<3&2016;h=h+2|0;}while((h|0)<4096);a[9547424]=0}h=c[2112926]|0;gGz(h|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);g=(d[c[2440228]|0]<<8)+1024|0;f=c[2387032]|0;j=c[2433492]|0;i=j<<8;if((i|0)<65536){k=c[2113070]|0;l=c[2113068]|0;m=i;do{i=m<<1&510;n=i-15|0;o=(m>>8)-j|0;p=e[f+(m<<1)>>1]|0;do{if((o|0)<(k|0)&(o|0)>-1&(n|0)>-1){if((n|0)<(l|0)){b[h+((ag(l,o)|0)+n<<1)>>1]=(p>>>8|g)&65535;q=i-14|0}else{q=n}if(!((q|0)>-1&(q|0)<(l|0))){break}b[h+((ag(l,o)|0)+q<<1)>>1]=(p&255|g)&65535}}while(0);m=m+1|0;}while((m|0)<65536)}m=c[2408994]|0;g=b[m>>1]&511;q=b[m+2>>1]&255;m=c[2386212]|0;l=d[c[3526940]|0]<<3&120;k=c[2405100]|0;f=c[3530836]|0;p=0;do{o=(p<<3&504)-g|0;n=(p>>6<<3)-q|0;i=e[m+(p<<1)>>1]|0;Sr(h,d[k+(i>>>12&1)|0]<<12|i&4095,((o|0)<-7?o+512|0:o)-15|0,((n|0)<-7?n+256|0:n)-j|0,i>>>13|l,4,15,0,f);p=p+1|0;}while((p|0)<2048);p=c[2386450]|0;f=c[2438894]|0;l=c[3530600]|0;k=0;do{m=e[p+(k<<1)>>1]|0;q=e[p+((k|1)<<1)>>1]|0;g=e[p+((k|2)<<1)>>1]|0;i=b[p+((k|3)<<1)>>1]&8191;n=(d[f]<<4|g&15)+96|0;o=(m&511)+1-j|0;r=q&511;s=r-9|0;t=m>>>12;m=q>>>12;q=m|t;u=g>>>12&7;v=u+1|0;w=g>>>8&7;x=w+1|0;if((g&128|0)!=0){y=16-((d[607624+m|0]|0)>>>3)|0;m=16-((d[607624+t|0]|0)>>>3)|0;t=(s|0)>511?r-521|0:s;s=(o|0)>511?o-512|0:o;o=g&34816;if((o|0)==2048){g=(q|0)==0;r=n<<4;z=y<<12;A=m<<12;B=(x|0)==5;C=(x|0)==6;D=(x|0)==7|0;E=((x|0)==3)+x|0;F=i;G=0;while(1){H=(G<<4)+s|0;I=(ag(G,m)|0)+s|0;J=F;K=0;while(1){L=w-K|0;if(g){SJ(h,J,(L<<4)+t|0,H,n,4,15,0,l)}else{S2(h,l,J,r,15,(ag(L,y)|0)+t|0,I,1,0,z,A)}L=K+1|0;if((L|0)<(x|0)){J=J+1|0;K=L}else{break}}K=E+F|0;J=B?K+3|0:K;K=G+1|0;if((K|0)<(v|0)){F=(C?J+2|0:J)+D|0;G=K}else{break}}}else if((o|0)==32768){G=(q|0)==0;D=n<<4;C=y<<12;F=m<<12;B=(x|0)==5;E=(x|0)==6;A=(x|0)==7|0;z=((x|0)==3)+x|0;r=i;g=0;while(1){K=u-g|0;J=(K<<4)+s|0;I=(ag(K,m)|0)+s|0;K=r;H=0;while(1){if(G){SL(h,K,(H<<4)+t|0,J,n,4,15,0,l)}else{S2(h,l,K,D,15,(ag(H,y)|0)+t|0,I,0,1,C,F)}L=H+1|0;if((L|0)<(x|0)){K=K+1|0;H=L}else{break}}H=z+r|0;K=B?H+3|0:H;H=g+1|0;if((H|0)<(v|0)){r=(E?K+2|0:K)+A|0;g=H}else{break}}}else if((o|0)==0){g=(q|0)==0;A=n<<4;E=y<<12;r=m<<12;B=(x|0)==5;z=(x|0)==6;F=(x|0)==7|0;C=((x|0)==3)+x|0;D=i;G=0;while(1){H=(G<<4)+s|0;K=(ag(G,m)|0)+s|0;I=D;J=0;while(1){if(g){SH(h,I,(J<<4)+t|0,H,n,4,15,0,l)}else{S2(h,l,I,A,15,(ag(J,y)|0)+t|0,K,0,0,E,r)}L=J+1|0;if((L|0)<(x|0)){I=I+1|0;J=L}else{break}}J=C+D|0;I=B?J+3|0:J;J=G+1|0;if((J|0)<(v|0)){D=(z?I+2|0:I)+F|0;G=J}else{break}}}else{G=n<<4;F=y<<12;z=m<<12;D=(x|0)==5;B=(x|0)==6;C=(x|0)==7|0;r=((x|0)==3)+x|0;if((q|0)==0){E=i;A=0;while(1){g=(u-A<<4)+s|0;o=E;J=0;while(1){SN(h,o,(w-J<<4)+t|0,g,n,4,15,0,l);I=J+1|0;if((I|0)<(x|0)){o=o+1|0;J=I}else{break}}J=E+r|0;o=D?J+3|0:J;J=A+1|0;if((J|0)<(v|0)){E=(B?o+2|0:o)+C|0;A=J}else{break}}}else{A=i;E=0;while(1){n=(ag(u-E|0,m)|0)+s|0;q=A;J=0;while(1){S2(h,l,q,G,15,(ag(w-J|0,y)|0)+t|0,n,1,1,F,z);o=J+1|0;if((o|0)<(x|0)){q=q+1|0;J=o}else{break}}J=A+r|0;q=D?J+3|0:J;J=E+1|0;if((J|0)<(v|0)){A=(B?q+2|0:q)+C|0;E=J}else{break}}}}}k=k+4|0;}while((k|0)<508);R8(c[3529998]|0);return 0}function ec8(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;g=i;i=i+64|0;h=g|0;j=g+16|0;k=g+32|0;l=g+48|0;if((f|0)!=0){c[f>>2]=169735}if((e&32|0)!=0){gGz(l|0,0,12);m=c[2414660]|0;c[l>>2]=m;c[l+4>>2]=(c[2411646]|0)-m;c[l+12>>2]=162152;m=c[2076592]|0;gj[m&4095](l)|0}if((e&64|0)!=0){l=k|0;gGz(j|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){m=k+9|0;k=h;n=h|0;o=h+4|0;p=h+12|0;q=j|0;r=j+4|0;s=j+12|0;t=0;do{gGC(l|0,614896,11)|0;a[m]=t+48&255;u=8452256+(t<<2)|0;gGz(k|0,0,12);c[n>>2]=u;c[o>>2]=4;c[p>>2]=164976;gj[c[2076592]&4095](h)|0;if((c[u>>2]|0)!=0){c[q>>2]=c[14130368+(t<<2)>>2];c[r>>2]=c[8452184+(t<<2)>>2];c[s>>2]=l;u=c[2076592]|0;gj[u&4095](j)|0}t=t+1|0;}while((t|0)<=(c[2392]|0))}fw$(e);T0(e,f)}if((e&2|0)==0){i=g;return 0}e=c[2439330]|0;f=(e|0)==0;if(!f){t=e;gGC(9706056,t|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];t=c[3528484]|0;c[2076596]=t;j=c[2417276]|0;c[3541536]=j;c[1836236]=0;l=c[2385920]|0;s=((d[c[3528390]|0]|0)<<15&98304)-32768|0;r=128;q=128;while(1){c[e+76+(q<<2)>>2]=l+(s+(q<<8));h=r+1&65535;if((h&65535)>255){v=128;w=128;break}else{r=h;q=h&65535}}while(1){q=l+(s+(w<<8))|0;c[e+76+(w+512<<2)>>2]=q;c[e+76+(w+768<<2)>>2]=q;q=v+1&65535;if((q&65535)>255){break}else{v=q;w=q&65535}}if(!f){f=e;gGC(f|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=t;c[2417276]=j;c[1836236]=-1;i=g;return 0}function ec9(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1339732+(b*112|0)>>2];c[a+104>>2]=c[1339736+(b*112|0)>>2];c[a+108>>2]=c[1339740+(b*112|0)>>2];d=0;return d|0}function eda(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=1339632+(b*112|0);e=0;return e|0}function edb(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4464564+(b*112|0)>>2];c[a+104>>2]=c[4464568+(b*112|0)>>2];c[a+108>>2]=c[4464572+(b*112|0)>>2];d=0;return d|0}function edc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=4464464+(b*112|0);e=0;return e|0}function edd(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1761152+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function ede(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5126040+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function edf(b,c){b=b|0;c=c|0;a[9706117]=(c|0)!=0|0;return}function edg(a){a=a|0;var b=0,d=0;b=(c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,4e6,0)|0;return a|0}function edh(){return+(+((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)/4.0e6)}function edi(e,f){e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;if((e|0)==8912904){a[c[2430246]|0]=f&3;return}else if((e|0)==15204352){g=(f&65535)>>>8;switch(d[9721016]|0|0){case 4:{h=a[9708104]|0;if((h&255)>4){a[9721016]=5;a[9731160]=0;return}i=(h&255)+((c[2433500]|0)+12)|0;if((d[i]|0|0)==(g|0)){a[9708104]=h+1&255;j=a[i]|0}else{j=-1}a[9731160]=j;return};case 3:{j=a[9708104]|0;i=j&255;if((j&255)>16){a[9721016]=4;a[9731160]=0;a[9708104]=0;return}if((d[592136+(i-1)|0]|0|0)==(g|0)){a[9708104]=j+1&255;k=a[592136+i|0]|0}else{k=-1}a[9731160]=k;return};case 0:{if((g|0)!=19){return}a[9721016]=1;a[9731160]=a[c[2433500]|0]|0;a[9708104]=0;return};case 2:{k=a[9708104]|0;i=k&255;j=c[(c[2433500]|0)+8>>2]|0;if(i>>>0>=((d[j]|0)+2|0)>>>0){a[9721016]=3;a[9731160]=16;a[9708104]=1;return}if((d[j+(i-1)|0]|0|0)==(g|0)){a[9708104]=k+1&255;l=a[j+i|0]|0}else{l=-1}a[9731160]=l;return};case 1:{l=a[9708104]|0;i=c[2433500]|0;if((l&255)<(d[i|0]|0)){a[9708104]=l+1&255;a[9731160]=((d[(c[i+4>>2]|0)+(l&255)|0]|0|0)!=(g|0))<<31>>31;return}else{a[9721016]=2;a[9731160]=a[c[i+8>>2]|0]|0;a[9708104]=1;return}break};default:{return}}}else if((e|0)==8912930){c[2388362]=0;return}else if((e|0)==13107200|(e|0)==13107202|(e|0)==13107204){b[(c[2387898]|0)+(e&6)>>1]=f;return}else if((e|0)==8912896|(e|0)==8912898){b[(c[2388012]|0)+(e&2)>>1]=f;return}else if((e|0)==12582912|(e|0)==12582914|(e|0)==12582916){b[(c[2387900]|0)+(e&6)>>1]=f;return}else if((e|0)==11010048|(e|0)==11010050|(e|0)==11010052){b[(c[2388010]|0)+(e&6)>>1]=f;return}else if((e|0)==11534336|(e|0)==11534338|(e|0)==11534340){b[(c[2388e3]|0)+(e&6)>>1]=f;return}else if((e|0)==10485760){e=f&65535;c[2415256]=e&2048;f=e>>>9&1;c[3528406]=f^1;if((f|0)==0){c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2]}Tr(e>>>10&1);return}else{return}}function edj(a,b){a=a|0;b=b|0;return}function edk(e){e=e|0;var f=0,g=0;do{if((e|0)==13631490){f=b[4775229]|0}else if((e|0)==8912896){f=a[672568]&1}else if((e|0)==13631488){f=b[4775228]|0}else if((e|0)==14155776){if((c[2406632]|0)!=0){f=(c[2432962]|0)>>>((c[(c[2420380]|0)+4>>2]|0)>>>0)<<11&2048;break}g=c[2443744]|0;if((g|0)<=0){f=2048;break}c[2443744]=g-1;f=0}else if((e|0)==16252928){g=d[9731160]|0;a[9731160]=-1;f=g<<8}else{f=0}}while(0);return f|0}function edl(a){a=a|0;return 0}function edm(a,d){a=a|0;d=d|0;var f=0,g=0,h=0,i=0,j=0;if((a&16744448|0)==9437184){f=a&32766;b[(c[2387188]|0)+f>>1]=d;g=f>>>1;f=d&65535;h=f>>>5&31;i=f>>>10&31;j=f&31;f=i<<3|i>>>2;c[(c[3529996]|0)+(g<<2)>>2]=h<<11|j|f<<3&2016;c[(c[2443504]|0)+(g<<2)>>2]=j<<3|j>>>2|f<<8|(h<<3|h>>>2)<<16;return}if((a&16773120|0)!=9961472){return}h=c[2387188]|0;f=a&4094;b[h+(f|32768)>>1]=d;d=f>>>1|16384;f=e[h+(d<<1)>>1]|0;h=f>>>5&31;a=f>>>10&31;j=f&31;f=a<<3|a>>>2;c[(c[3529996]|0)+(d<<2)>>2]=h<<11|j|f<<3&2016;c[(c[2443504]|0)+(d<<2)>>2]=j<<3|j>>>2|f<<8|(h<<3|h>>>2)<<16;return}function edn(b,d){b=b|0;d=d|0;var f=0,g=0,h=0,i=0,j=0;if((b&16744448|0)==9437184){f=c[2387188]|0;a[f+(b&32767^1)|0]=d;g=b>>>1&16383;h=e[f+(g<<1)>>1]|0;f=h>>>5&31;i=h>>>10&31;j=h&31;h=i<<3|i>>>2;c[(c[3529996]|0)+(g<<2)>>2]=f<<11|j|h<<3&2016;c[(c[2443504]|0)+(g<<2)>>2]=j<<3|j>>>2|h<<8|(f<<3|f>>>2)<<16;return}if((b&16773120|0)!=9961472){return}f=c[2387188]|0;a[f+(b&4095^32769)|0]=d;d=b>>>1&2047|16384;b=e[f+(d<<1)>>1]|0;f=b>>>5&31;h=b>>>10&31;j=b&31;b=h<<3|h>>>2;c[(c[3529996]|0)+(d<<2)>>2]=f<<11|j|b<<3&2016;c[(c[2443504]|0)+(d<<2)>>2]=j<<3|j>>>2|b<<8|(f<<3|f>>>2)<<16;return}function edo(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5918252+(b*112|0)>>2];c[a+104>>2]=c[5918256+(b*112|0)>>2];c[a+108>>2]=c[5918260+(b*112|0)>>2];d=0;return d|0}function edp(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=5918152+(b*112|0);e=0;return e|0}function edq(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6926832+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function edr(){return edC(536,33554432,7062072,1)|0}function eds(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;b=i;i=i+128|0;c[2113070]=0;c[2113068]=0;d=c[2112926]|0;if((d|0)!=0){gGr(d);c[2112926]=0}d=b|0;e=c[c[642608+(c[2436]<<2)>>2]>>2]|0;be(d|0,128,179600,(f=i,i=i+24|0,c[f>>2]=9374064,c[f+8>>2]=47,c[f+16>>2]=e,f)|0)|0;i=f;a[1040128]=0;f=c[2420380]|0;e=c[f>>2]|0;g=c[f+4>>2]|0;f=fw(d|0,389440)|0;if((f|0)!=0){d=g>>3<<e&1023;cj(14100392,d|0,1,f|0)|0;aY(f|0)|0}if((c[2392]|0)>=0){f=0;do{d=14130368+(f<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}d=14130384+(f<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}f=f+1|0;}while((f|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;f=c[2386364]|0;d=0;while(1){if((d|0)>=1024){break}h=9638528+(d<<2)|0;if((c[h>>2]|0)==(f|0)){j=53699;break}else{d=d+1|0}}if((j|0)==53699){gGr(f);c[h>>2]=0}c[2386364]=0;h=c[2414954]|0;f=0;while(1){if((f|0)>=1024){j=53706;break}k=9638528+(f<<2)|0;if((c[k>>2]|0)==(h|0)){break}else{f=f+1|0}}if((j|0)==53706){c[2414954]=0;i=b;return 0}gGr(h);c[k>>2]=0;c[2414954]=0;i=b;return 0}function edt(){var d=0,e=0,f=0,g=0,h=0,i=0;d=c[2392]|0;if((d|0)>=0){gGz(8452240,0,((d|0)>0?(d<<2)+4|0:4)|0)}c[2113054]=0;d=(c[2388362]|0)+1|0;c[2388362]=d;if((d|0)>399){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];a[9708104]=0;a[9721016]=0;a[9731160]=-1;c[2388362]=0}if((a[9624104]|0)!=0){d=c[2414658]|0;gGz(d|0,0,(c[2411644]|0)-d|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];a[9708104]=0;a[9721016]=0;a[9731160]=-1;c[2388362]=0}c[2387614]=-1;d=0;e=-1;f=-1;do{e=((a[9633336+d|0]&1)<<d^e&65535)&65535;f=((a[9631208+d|0]&1)<<d^f&65535)&65535;d=d+1|0;}while((d|0)<16);b[4775228]=e;b[4775229]=f;if((e&3)==0){d=e|3;b[4775228]=d;g=d}else{g=e}if((g&12)==0){b[4775228]=g|12}if((f&3)==0){g=f|3;b[4775229]=g;h=g}else{h=f}if((h&12)==0){b[4775229]=h|12}h=c[2438]|0;f=gGU(h,(h|0)<0|0?-1:0,278503,0)|0;h=gGS(f,K,256,0)|0;f=h;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];h=c[3532592]|0;if((h|0)!=0){gGC(9104152,h|0,280)|0}c[2113054]=c[2113060]}a[672568]=1;h=(f|0)/256|0;f=0;while(1){if((f|0)!=240){c[2113056]=h;g=RG(h)|0;i=(c[2113054]|0)+g|0;c[2113054]=i;c[2276108]=-1;c[2113056]=-1;g=f+1|0;if((g|0)<256){f=g;continue}else{break}}a[672568]=0;c[8452200+(c[2394]<<2)>>2]=4097;c[2276080]=256;if((c[2276079]|0)>>>0<256){RH(1)}c[2113056]=h;g=RG(h)|0;c[2113054]=(c[2113054]|0)+g;c[2276108]=-1;c[2113056]=-1;f=241}f=c[2394]|0;c[8452200+(f<<2)>>2]=0;c[2276080]=0;h=c[14130368+(f<<2)>>2]|0;if((h|0)!=0){gGC(h|0,9104152,280)|0}c[8452240+(f<<2)>>2]=i;c[2394]=-1;if((c[2112968]|0)==0){return 0}edu()|0;return 0}function edu(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;if((a[9547416]|0)!=0){f=c[2387188]|0;g=c[3529996]|0;h=c[2443504]|0;i=0;do{j=e[f+(i<<1)>>1]|0;k=j>>>5&31;l=j>>>10&31;m=j&31;j=l<<3|l>>>2;c[g+(i<<2)>>2]=k<<11|m|j<<3&2016;c[h+(i<<2)>>2]=m<<3|m>>>2|j<<8|(k<<3|k>>>2)<<16;i=i+1|0;}while((i|0)<18432);a[9547416]=0}i=c[2112926]|0;gGz(i|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);if((c[2411216]|0)==0){edE(c[2387984]|0,c[3530598]|0,c[2387898]|0,16,104,0)}edE(c[2387980]|0,c[3530426]|0,c[2388010]|0,17,106,16384);edE(c[2387974]|0,c[3530332]|0,c[2388e3]|0,17,106,32768);h=c[2386330]|0;g=c[3530834]|0;f=c[2113068]|0;k=0;do{j=k<<3&504;m=k>>6<<3;L71254:do{if((j|0)<(f|0)){l=c[2113070]|0;if((m|0)>=(l|0)){break}n=k<<1;o=e[h+(n<<1)>>1]|0;p=b[h+((n|1)<<1)>>1]&32767;n=o&63;q=o&128;r=o&64;if((p|0)==0){break}do{if((j|0)<=(f-8|0)&(m|0)>-1){if((m|0)>(l-8|0)){break}o=(r|0)!=0;if((q|0)==0){if(o){Ss(i,p,j,m,n,4,0,50176,g);break L71254}else{Sq(i,p,j,m,n,4,0,50176,g);break L71254}}else{if(o){Sw(i,p,j,m,n,4,0,50176,g);break L71254}else{Su(i,p,j,m,n,4,0,50176,g);break L71254}}}}while(0);l=(r|0)!=0;if((q|0)==0){if(l){St(i,p,j,m,n,4,0,50176,g);break}else{Sr(i,p,j,m,n,4,0,50176,g);break}}else{if(l){Sx(i,p,j,m,n,4,0,50176,g);break}else{Sv(i,p,j,m,n,4,0,50176,g);break}}}}while(0);k=k+1|0;}while((k|0)<4096);k=c[2439516]|0;g=c[2112968]|0;h=c[2387188]|0;m=c[2113308]|0;j=c[3529996]|0;l=(m|0)>3;o=(m|0)==2;s=c[2443504]|0;t=0;do{u=e[k+(t<<1)>>1]|0;v=u&16383;L71284:do{if((v|0)==0){w=ag(m,t)|0;x=g+w|0;y=c[j+((b[i+(t<<1)>>1]&2047|16384)<<2)>>2]|0;if(l){c[x>>2]=y;break}if(o){b[x>>1]=y&65535;break}else{a[x]=y&255;a[g+(w+1)|0]=y>>>8&255;a[g+(w+2)|0]=y>>>16&255;break}}else{y=e[i+(t<<1)>>1]|0;w=y&2047|16384;do{if((b[h+(w<<1)>>1]|0)<0){if((b[h+(v<<1)>>1]|0)>=0){break}x=c[s+(w<<2)>>2]|0;z=c[s+(v<<2)>>2]|0;A=ag(m,t)|0;B=g+A|0;C=((z&16711680)+(x&16711680)|0)>>>17<<8&63488|((z&65280)+(x&65280)|0)>>>9<<3&2016;D=C|((z&255)+(x&255)|0)>>>4&31;if(l){c[B>>2]=D;break L71284}if(o){b[B>>1]=D&65535;break L71284}else{a[B]=D&255;a[g+(A+1)|0]=C>>>8&255;a[g+(A+2)|0]=0;break L71284}}}while(0);n=ag(m,t)|0;p=g+n|0;if((u&49152)>>>0<(y&49152)>>>0){q=c[j+(w<<2)>>2]|0;if(l){c[p>>2]=q;break}if(o){b[p>>1]=q&65535;break}else{a[p]=q&255;a[g+(n+1)|0]=q>>>8&255;a[g+(n+2)|0]=q>>>16&255;break}}else{q=c[j+(v<<2)>>2]|0;if(l){c[p>>2]=q;break}if(o){b[p>>1]=q&65535;break}else{a[p]=q&255;a[g+(n+1)|0]=q>>>8&255;a[g+(n+2)|0]=q>>>16&255;break}}}}while(0);t=t+1|0;}while((t|0)<76800);t=c[2388012]|0;g=e[t>>1]|0;o=e[t+2>>1]|0;gGz(k|0,0,153600);t=(c[2386448]|0)+(d[c[2430246]|0]<<14)|0;l=386-g|0;g=1-o|0;o=c[2113070]|0;j=c[2386364]|0;m=0;do{s=(e[t+(m<<1)>>1]|0)+l|0;h=(e[t+((m|1)<<1)>>1]|0)+g|0;i=b[t+((m|2)<<1)>>1]&4095;v=b[t+((m|3)<<1)>>1]&4095;u=e[t+((m|4)<<1)>>1]|0;q=u&64;n=u&128;p=(u<<16&983040|e[t+((m|5)<<1)>>1])<<8;r=e[t+((m|6)<<1)>>1]|0;A=r<<4&4080;C=r>>>4&4080;L71322:do{if(!((u&32768|0)!=0|(i|0)==0|(v|0)==0)){r=(s&512|0)==0;D=r?s&1023:s|-1024;B=(h&256|0)==0?h&511:h|-512;x=u<<10&49152|u&16128;z=(o|0)>(B|0)&(f|0)>(D|0)&(A|0)!=0;if(!((i|0)==256&(v|0)==256)){if(!z){break}E=(n|0)==0;F=(C|0)==0;G=(q|0)==0;H=D-1+((ag(C,i)|0)>>>8)|0;I=B-1+((ag(A,v)|0)>>>8)|0;J=j+p|0;K=0;while(1){L=ag(K,v)|0;if(E){M=((L|0)/256|0)+B|0}else{M=I+((L|0)/-256|0)|0}do{if(M>>>0<=239){L=ag(f,M)|0;if(F){break}if(G){N=0;do{O=((ag(N,i)|0)/256|0)+D|0;do{if(O>>>0<320){P=a[J+N|0]|0;if(P<<24>>24==0){break}b[k+(O+L<<1)>>1]=(P&255|x)&65535}}while(0);N=N+1|0;}while((N|0)<(C|0))}else{N=0;do{O=H+((ag(N,i)|0)/-256|0)|0;do{if(O>>>0<320){P=a[J+N|0]|0;if(P<<24>>24==0){break}b[k+(O+L<<1)>>1]=(P&255|x)&65535}}while(0);N=N+1|0;}while((N|0)<(C|0))}}}while(0);N=K+1|0;if((N|0)<(A|0)){J=J+C|0;K=N}else{break L71322}}}if(!z){break}K=(n|0)==0;J=(q|0)==0;H=(C|0)!=0;G=D-1+C|0;F=B-1+A|0;I=r&(C+D|0)<(f|0);E=0;w=j+p|0;while(1){y=K?E+B|0:F-E|0;L71354:do{if(y>>>0<=239){N=ag(f,y)|0;if(I){if(J){L=N+D|0;if(H){Q=0}else{break}while(1){O=a[w+Q|0]|0;if(O<<24>>24!=0){b[k+(L+Q<<1)>>1]=(O&255|x)&65535}Q=Q+1|0;if((Q|0)>=(C|0)){break L71354}}}if(!H){break}L=N+G|0;O=0;do{P=a[w+O|0]|0;if(P<<24>>24!=0){b[k+(L-O<<1)>>1]=(P&255|x)&65535}O=O+1|0;}while((O|0)<(C|0))}else{if(!H){break}if(J){O=0;do{L=O+D|0;do{if(L>>>0<320){P=a[w+O|0]|0;if(P<<24>>24==0){break}b[k+(L+N<<1)>>1]=(P&255|x)&65535}}while(0);O=O+1|0;}while((O|0)<(C|0))}else{O=0;do{L=G-O|0;do{if(L>>>0<320){P=a[w+O|0]|0;if(P<<24>>24==0){break}b[k+(L+N<<1)>>1]=(P&255|x)&65535}}while(0);O=O+1|0;}while((O|0)<(C|0))}}}}while(0);y=E+1|0;if((y|0)<(A|0)){E=y;w=w+C|0}else{break}}}}while(0);m=m+8|0;}while((m|0)<8192);return 0}function edv(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=i;i=i+112|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;l=e+80|0;m=e+96|0;if((d|0)!=0){c[d>>2]=169730}a[9547416]=1;if((b&4|0)!=0){c[m>>2]=c[2388146];c[m+4>>2]=1048576;c[m+8>>2]=0;c[m+12>>2]=496208;n=c[2076592]|0;gj[n&4095](m)|0}if((b&32|0)!=0){n=m|0;c[n>>2]=c[2388272];o=m+4|0;c[o>>2]=65536;p=m+8|0;c[p>>2]=2097152;q=m+12|0;c[q>>2]=484192;r=c[2076592]|0;gj[r&4095](m)|0;c[n>>2]=c[2387984];c[o>>2]=4096;c[p>>2]=3145728;c[q>>2]=471408;r=c[2076592]|0;gj[r&4095](m)|0;c[n>>2]=c[2443612];c[o>>2]=1024;c[p>>2]=3149824;c[q>>2]=460248;r=c[2076592]|0;gj[r&4095](m)|0;c[n>>2]=c[2387980];c[o>>2]=4096;c[p>>2]=4194304;c[q>>2]=449360;r=c[2076592]|0;gj[r&4095](m)|0;c[n>>2]=c[2443610];c[o>>2]=1024;c[p>>2]=4198400;c[q>>2]=438040;r=c[2076592]|0;gj[r&4095](m)|0;c[n>>2]=c[2387974];c[o>>2]=4096;c[p>>2]=5242880;c[q>>2]=427120;r=c[2076592]|0;gj[r&4095](m)|0;c[n>>2]=c[2443608];c[o>>2]=1024;c[p>>2]=5246976;c[q>>2]=415192;r=c[2076592]|0;gj[r&4095](m)|0;c[n>>2]=c[2386330];c[o>>2]=16384;c[p>>2]=7340032;c[q>>2]=403728;r=c[2076592]|0;gj[r&4095](m)|0;c[n>>2]=c[2386448];c[o>>2]=4096;c[p>>2]=8388608;c[q>>2]=392744;r=c[2076592]|0;gj[r&4095](m)|0;c[n>>2]=c[2388012];c[o>>2]=4;c[p>>2]=8912896;c[q>>2]=381424;r=c[2076592]|0;gj[r&4095](m)|0;c[n>>2]=c[2387188];c[o>>2]=32768;c[p>>2]=9437184;c[q>>2]=371232;r=c[2076592]|0;gj[r&4095](m)|0;c[n>>2]=c[2387188];c[o>>2]=4096;c[p>>2]=9961472;c[q>>2]=362048;r=c[2076592]|0;gj[r&4095](m)|0;c[n>>2]=c[2388010];c[o>>2]=6;c[p>>2]=11010048;c[q>>2]=355200;r=c[2076592]|0;gj[r&4095](m)|0;c[n>>2]=c[2388e3];c[o>>2]=6;c[p>>2]=11534336;c[q>>2]=346976;r=c[2076592]|0;gj[r&4095](m)|0;c[n>>2]=c[2387900];c[o>>2]=6;c[p>>2]=12582912;c[q>>2]=338928;r=c[2076592]|0;gj[r&4095](m)|0;c[n>>2]=c[2387898];c[o>>2]=6;c[p>>2]=13107200;c[q>>2]=331280;q=c[2076592]|0;gj[q&4095](m)|0}if((b&64|0)==0){i=e;return 0}m=h|0;gGz(g|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){q=h+9|0;h=f;p=f|0;o=f+4|0;n=f+12|0;r=g|0;s=g+4|0;t=g+12|0;u=0;do{gGC(m|0,614896,11)|0;a[q]=u+48&255;v=8452256+(u<<2)|0;gGz(h|0,0,12);c[p>>2]=v;c[o>>2]=4;c[n>>2]=164976;gj[c[2076592]&4095](f)|0;if((c[v>>2]|0)!=0){c[r>>2]=c[14130368+(u<<2)>>2];c[s>>2]=c[8452184+(u<<2)>>2];c[t>>2]=m;v=c[2076592]|0;gj[v&4095](g)|0}u=u+1|0;}while((u|0)<=(c[2392]|0))}Ts(b,d);gGz(l|0,0,12);c[l>>2]=9708104;c[l+4>>2]=1;c[l+12>>2]=322408;gj[c[2076592]&4095](l)|0;gGz(k|0,0,12);c[k>>2]=9721016;c[k+4>>2]=1;c[k+12>>2]=312992;gj[c[2076592]&4095](k)|0;gGz(j|0,0,12);c[j>>2]=9731160;c[j+4>>2]=1;c[j+12>>2]=304976;gj[c[2076592]&4095](j)|0;i=e;return 0}function edw(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2140060+(b*112|0)>>2];c[a+104>>2]=c[2140064+(b*112|0)>>2];c[a+108>>2]=c[2140068+(b*112|0)>>2];d=0;return d|0}function edx(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<21&(d|0)==0)){e=1;return e|0}c[a>>2]=2139960+(b*112|0);e=0;return e|0}function edy(){return edC(2928,67108864,5653248,0)|0}function edz(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1355044+(b*112|0)>>2];c[a+104>>2]=c[1355048+(b*112|0)>>2];c[a+108>>2]=c[1355052+(b*112|0)>>2];d=0;return d|0}function edA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<21&(d|0)==0)){e=1;return e|0}c[a>>2]=1354944+(b*112|0);e=0;return e|0}function edB(){return edC(2928,67108864,4356048,0)|0}function edC(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;h=i;i=i+144|0;j=h|0;k=h+16|0;l=h+80|0;c[2414954]=0;c[2388146]=0;c[3530834]=1048576;c[3530598]=3145728;c[3530426]=5242880;c[3530332]=7340032;c[3529996]=9437184;c[2443504]=9510912;c[2439516]=9584640;c[2414658]=9738240;c[2388272]=9738240;c[2386448]=9803776;c[2387188]=9869312;c[2386330]=9906176;c[2387984]=9922560;c[2443612]=9926656;c[2387980]=9927680;c[2443610]=9931776;c[2387974]=9932800;c[2443608]=9936896;c[2430246]=9937920;c[2388012]=9937921;c[2388010]=9937925;c[2388e3]=9937931;c[2387900]=9937937;c[2387898]=9937943;c[2411644]=9937949;m=0;while(1){if((m|0)>=1024){break}n=9638528+(m<<2)|0;if((c[n>>2]|0)==0){o=53897;break}else{m=m+1|0}}do{if((o|0)==53897){m=gGq(9937949)|0;c[n>>2]=m;if((m|0)==0){break}c[2414954]=m;gGz(m|0,0,9937949);c[2388146]=m;c[3530834]=m+1048576;c[3530598]=m+3145728;c[3530426]=m+5242880;c[3530332]=m+7340032;c[3529996]=m+9437184;c[2443504]=m+9510912;c[2439516]=m+9584640;p=m+9738240|0;c[2414658]=p;c[2388272]=p;c[2386448]=m+9803776;c[2387188]=m+9869312;c[2386330]=m+9906176;c[2387984]=m+9922560;c[2443612]=m+9926656;c[2387980]=m+9927680;c[2443610]=m+9931776;c[2387974]=m+9932800;c[2443608]=m+9936896;c[2430246]=m+9937920;c[2388012]=m+9937921;c[2388010]=m+9937925;c[2388e3]=m+9937931;c[2387900]=m+9937937;c[2387898]=m+9937943;p=m+9937949|0;c[2411644]=p;c[2414184]=p;p=0;while(1){if((p|0)>=1024){break}q=9638528+(p<<2)|0;if((c[q>>2]|0)==0){o=53902;break}else{p=p+1|0}}do{if((o|0)==53902){p=gGq(e)|0;c[q>>2]=p;if((p|0)==0){break}gGz(p|0,0,e|0);c[2386364]=p;do{if((b|0)==0){r=p}else{if((gD[b&8191]()|0)==0){r=c[2386364]|0;break}else{s=1;i=h;return s|0}}}while(0);if((e|0)>0){p=0;do{m=r+(p|2)|0;t=a[m]|0;u=r+(p|3)|0;v=a[u]|0;w=r+p|0;x=a[w]|0;y=r+(p|1)|0;z=a[y]|0;a[w]=(v&255)>>>4|t&-16;a[y]=v&15|t<<4;a[m]=(z&255)>>>4|x&-16;a[u]=z&15|x<<4;p=p+4|0;}while((p|0)<(e|0))}p=c[3530834]|0;x=1048575;while(1){z=p+x|0;u=x<<1;a[p+u|0]=(d[z]|0)>>>4;a[p+(u|1)|0]=a[z]&15;if((x|0)>0){x=x-1|0}else{break}}x=c[3530598]|0;p=j;z=k;u=l;c[p>>2]=c[175854];c[p+4>>2]=c[175855];c[p+8>>2]=c[175856];c[p+12>>2]=c[175857];gGC(z|0,3946872,64)|0;gGC(u|0,3946808,64)|0;m=0;while(1){if((m|0)>=1024){A=0;break}B=9638528+(m<<2)|0;if((c[B>>2]|0)==0){o=53914;break}else{m=m+1|0}}do{if((o|0)==53914){m=gGq(1048576)|0;c[B>>2]=m;if((m|0)==0){A=0;break}gGz(m|0,0,1048576);A=m}}while(0);gGC(A|0,x|0,1048576)|0;m=0;while(1){t=m<<8;gGz(x+t|0,0,256);v=m<<10;y=0;do{w=1<<3-y;C=(c[j+(y<<2)>>2]|0)+v|0;D=0;do{E=C+(c[l+(D<<2)>>2]|0)|0;F=(D<<4)+t|0;G=0;do{H=E+(c[k+(G<<2)>>2]|0)|0;if(((d[A+((H|0)/8|0)|0]|0)&128>>>((H&7)>>>0)|0)!=0){H=x+(F+G)|0;a[H]=(d[H]|0|w)&255}G=G+1|0;}while((G|0)<16);D=D+1|0;}while((D|0)<16);y=y+1|0;}while((y|0)<4);y=m+1|0;if((y|0)<8192){m=y}else{I=0;break}}while(1){if((I|0)>=1024){break}J=9638528+(I<<2)|0;if((c[J>>2]|0)==(A|0)){o=53928;break}else{I=I+1|0}}if((o|0)==53928){gGr(A);c[J>>2]=0}m=c[3530426]|0;c[p>>2]=c[175854];c[p+4>>2]=c[175855];c[p+8>>2]=c[175856];c[p+12>>2]=c[175857];gGC(z|0,3946872,64)|0;gGC(u|0,3946808,64)|0;x=0;while(1){if((x|0)>=1024){K=0;break}L=9638528+(x<<2)|0;if((c[L>>2]|0)==0){o=53932;break}else{x=x+1|0}}do{if((o|0)==53932){x=gGq(1048576)|0;c[L>>2]=x;if((x|0)==0){K=0;break}gGz(x|0,0,1048576);K=x}}while(0);gGC(K|0,m|0,1048576)|0;x=0;while(1){y=x<<8;gGz(m+y|0,0,256);t=x<<10;v=0;do{D=1<<3-v;w=(c[j+(v<<2)>>2]|0)+t|0;C=0;do{G=w+(c[l+(C<<2)>>2]|0)|0;F=(C<<4)+y|0;E=0;do{H=G+(c[k+(E<<2)>>2]|0)|0;if(((d[K+((H|0)/8|0)|0]|0)&128>>>((H&7)>>>0)|0)!=0){H=m+(F+E)|0;a[H]=(d[H]|0|D)&255}E=E+1|0;}while((E|0)<16);C=C+1|0;}while((C|0)<16);v=v+1|0;}while((v|0)<4);v=x+1|0;if((v|0)<8192){x=v}else{M=0;break}}while(1){if((M|0)>=1024){break}N=9638528+(M<<2)|0;if((c[N>>2]|0)==(K|0)){o=53946;break}else{M=M+1|0}}if((o|0)==53946){gGr(K);c[N>>2]=0}x=c[3530332]|0;c[p>>2]=c[175854];c[p+4>>2]=c[175855];c[p+8>>2]=c[175856];c[p+12>>2]=c[175857];gGC(z|0,3946872,64)|0;gGC(u|0,3946808,64)|0;m=0;while(1){if((m|0)>=1024){O=0;break}P=9638528+(m<<2)|0;if((c[P>>2]|0)==0){o=53950;break}else{m=m+1|0}}do{if((o|0)==53950){m=gGq(1048576)|0;c[P>>2]=m;if((m|0)==0){O=0;break}gGz(m|0,0,1048576);O=m}}while(0);gGC(O|0,x|0,1048576)|0;m=0;while(1){u=m<<8;gGz(x+u|0,0,256);z=m<<10;p=0;do{v=1<<3-p;y=(c[j+(p<<2)>>2]|0)+z|0;t=0;do{C=y+(c[l+(t<<2)>>2]|0)|0;D=(t<<4)+u|0;w=0;do{E=C+(c[k+(w<<2)>>2]|0)|0;if(((d[O+((E|0)/8|0)|0]|0)&128>>>((E&7)>>>0)|0)!=0){E=x+(D+w)|0;a[E]=(d[E]|0|v)&255}w=w+1|0;}while((w|0)<16);t=t+1|0;}while((t|0)<16);p=p+1|0;}while((p|0)<4);p=m+1|0;if((p|0)<8192){m=p}else{Q=0;break}}while(1){if((Q|0)>=1024){break}R=9638528+(Q<<2)|0;if((c[R>>2]|0)==(O|0)){o=53964;break}else{Q=Q+1|0}}if((o|0)==53964){gGr(O);c[R>>2]=0}fxU(0,425984);if((c[2394]|0)==0){S=c[2112932]|0}else{c[2394]=0;m=c[3532596]|0;c[2112932]=m;x=c[3532592]|0;if((x|0)!=0){gGC(9104152,x|0,280)|0}c[2113054]=c[2113060];S=m}m=c[2388146]|0;x=S|0;p=0;while(1){u=m+p|0;c[x>>2]=u;c[x+131072>>2]=u;u=p+1024|0;if(u>>>0>1048575){break}else{x=x+4|0;p=u}}p=c[2388272]|0;x=S+8192|0;m=2097152;while(1){u=p+(m-2097152)|0;c[x>>2]=u;c[x+65536>>2]=u;c[x+131072>>2]=u;u=m+1024|0;if(u>>>0>2162687){break}else{x=x+4|0;m=u}}m=c[2387984]|0;c[S+12288>>2]=m;c[S+77824>>2]=m;c[S+143360>>2]=m;x=m+1024|0;c[S+12292>>2]=x;c[S+77828>>2]=x;c[S+143364>>2]=x;x=m+2048|0;c[S+12296>>2]=x;c[S+77832>>2]=x;c[S+143368>>2]=x;x=m+3072|0;c[S+12300>>2]=x;c[S+77836>>2]=x;c[S+143372>>2]=x;x=c[2443612]|0;c[S+12304>>2]=x;c[S+77840>>2]=x;c[S+143376>>2]=x;x=c[2387980]|0;c[S+16384>>2]=x;c[S+81920>>2]=x;c[S+147456>>2]=x;m=x+1024|0;c[S+16388>>2]=m;c[S+81924>>2]=m;c[S+147460>>2]=m;m=x+2048|0;c[S+16392>>2]=m;c[S+81928>>2]=m;c[S+147464>>2]=m;m=x+3072|0;c[S+16396>>2]=m;c[S+81932>>2]=m;c[S+147468>>2]=m;m=c[2443610]|0;c[S+16400>>2]=m;c[S+81936>>2]=m;c[S+147472>>2]=m;m=c[2387974]|0;c[S+20480>>2]=m;c[S+86016>>2]=m;c[S+151552>>2]=m;x=m+1024|0;c[S+20484>>2]=x;c[S+86020>>2]=x;c[S+151556>>2]=x;x=m+2048|0;c[S+20488>>2]=x;c[S+86024>>2]=x;c[S+151560>>2]=x;x=m+3072|0;c[S+20492>>2]=x;c[S+86028>>2]=x;c[S+151564>>2]=x;x=c[2443608]|0;c[S+20496>>2]=x;c[S+86032>>2]=x;c[S+151568>>2]=x;x=c[2386330]|0;c[S+28672>>2]=x;c[S+94208>>2]=x;c[S+159744>>2]=x;m=x+1024|0;c[S+28676>>2]=m;c[S+94212>>2]=m;c[S+159748>>2]=m;m=x+2048|0;c[S+28680>>2]=m;c[S+94216>>2]=m;c[S+159752>>2]=m;m=x+3072|0;c[S+28684>>2]=m;c[S+94220>>2]=m;c[S+159756>>2]=m;m=x+4096|0;c[S+28688>>2]=m;c[S+94224>>2]=m;c[S+159760>>2]=m;m=x+5120|0;c[S+28692>>2]=m;c[S+94228>>2]=m;c[S+159764>>2]=m;m=x+6144|0;c[S+28696>>2]=m;c[S+94232>>2]=m;c[S+159768>>2]=m;m=x+7168|0;c[S+28700>>2]=m;c[S+94236>>2]=m;c[S+159772>>2]=m;m=x+8192|0;c[S+28704>>2]=m;c[S+94240>>2]=m;c[S+159776>>2]=m;m=x+9216|0;c[S+28708>>2]=m;c[S+94244>>2]=m;c[S+159780>>2]=m;m=x+10240|0;c[S+28712>>2]=m;c[S+94248>>2]=m;c[S+159784>>2]=m;m=x+11264|0;c[S+28716>>2]=m;c[S+94252>>2]=m;c[S+159788>>2]=m;m=x+12288|0;c[S+28720>>2]=m;c[S+94256>>2]=m;c[S+159792>>2]=m;m=x+13312|0;c[S+28724>>2]=m;c[S+94260>>2]=m;c[S+159796>>2]=m;m=x+14336|0;c[S+28728>>2]=m;c[S+94264>>2]=m;c[S+159800>>2]=m;m=x+15360|0;c[S+28732>>2]=m;c[S+94268>>2]=m;c[S+159804>>2]=m;m=c[2386448]|0;x=S+32768|0;p=8388608;while(1){u=m+(p-8388608)|0;c[x>>2]=u;c[x+65536>>2]=u;c[x+131072>>2]=u;u=p+1024|0;if(u>>>0>8454143){break}else{x=x+4|0;p=u}}p=c[2387188]|0;x=S+36864|0;m=x;u=9437184;while(1){z=p+(u-9437184)|0;c[m>>2]=z;c[m+131072>>2]=z;z=u+1024|0;if(z>>>0>9469951){break}else{m=m+4|0;u=z}}u=p+32768|0;c[S+38912>>2]=u;c[S+169984>>2]=u;u=p+33792|0;c[S+38916>>2]=u;c[S+169988>>2]=u;u=p+34816|0;c[S+38920>>2]=u;c[S+169992>>2]=u;u=p+35840|0;c[S+38924>>2]=u;c[S+169996>>2]=u;c[S+196728>>2]=1832;c[S+196648>>2]=2794;c[S+196688>>2]=996;c[S+196608>>2]=808;u=x;m=9437184;while(1){c[u+65536>>2]=1;z=m+1024|0;if(z>>>0>9965567){break}else{u=u+4|0;m=z}}c[S+196732>>2]=2488;c[S+196652>>2]=2824;m=c[3532592]|0;if((m|0)!=0){gGC(m|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;c[2411216]=g;c[2433500]=f;Tq(690056);c[2424]=5744;m=c[642608+(c[2436]<<2)>>2]|0;u=c[m+128>>2]|0;if((c[m+52>>2]&4|0)==0){c[2113068]=u;x=c[m+132>>2]|0;c[2113070]=x;c[2443814]=u;c[2440436]=x;T=u;U=x}else{c[2113070]=u;x=c[m+132>>2]|0;c[2113068]=x;c[2440436]=u;c[2443814]=x;T=x;U=u}u=ag(T<<1,U)|0;x=gGq(u)|0;c[2112926]=x;if((x|0)!=0){gGz(x|0,0,u|0)}u=c[2414658]|0;gGz(u|0,0,(c[2411644]|0)-u|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];u=c[3532592]|0;if((u|0)!=0){gGC(9104152,u|0,280)|0}c[2113054]=c[2113060]}RI();u=c[2394]|0;x=c[14130368+(u<<2)>>2]|0;if((x|0)!=0){gGC(x|0,9104152,280)|0}c[8452240+(u<<2)>>2]=c[2113054];c[2394]=-1;c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];a[9708104]=0;a[9721016]=0;a[9731160]=-1;c[2388362]=0;s=0;i=h;return s|0}}while(0);c[2386364]=0;s=1;i=h;return s|0}}while(0);c[2414954]=0;s=1;i=h;return s|0}function edD(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;a=i;i=i+480|0;b=a|0;d=a+112|0;e=a+120|0;f=a+232|0;g=a+240|0;h=a+352|0;j=a+360|0;k=a+472|0;if((R6((c[2388146]|0)+1|0,0,2)|0)!=0){l=1;i=a;return l|0}if((R6(c[2388146]|0,1,2)|0)!=0){l=1;i=a;return l|0}if((R6(c[2386364]|0,3,2)|0)!=0){l=1;i=a;return l|0}if((R6((c[2386364]|0)+1|0,4,2)|0)!=0){l=1;i=a;return l|0}if((R6((c[2386364]|0)+8388608|0,5,2)|0)!=0){l=1;i=a;return l|0}if((R6((c[2386364]|0)+8388609|0,6,2)|0)!=0){l=1;i=a;return l|0}if((R6((c[2386364]|0)+16777216|0,7,2)|0)!=0){l=1;i=a;return l|0}if((R6((c[2386364]|0)+16777217|0,8,2)|0)!=0){l=1;i=a;return l|0}if((R6((c[2386364]|0)+33554433|0,9,2)|0)!=0){l=1;i=a;return l|0}if((R6((c[2386364]|0)+41943041|0,10,2)|0)!=0){l=1;i=a;return l|0}if((R6((c[2386364]|0)+50331649|0,11,2)|0)!=0){l=1;i=a;return l|0}m=c[3530834]|0;if((c[3542200]|0)==0){l=1;i=a;return l|0}n=j+108|0;c[n>>2]=0;o=j+100|0;c[o>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,12)|0;do{if((c[n>>2]|0)!=0){j=c[o>>2]|0;c[k>>2]=9534384;p=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[p&16383](k,12,0)|0;if((j|0)<1){l=1;i=a;return l|0}if((gzL(m,0,12)|0)==0){break}else{l=1}i=a;return l|0}}while(0);m=c[3530834]|0;k=m+524288|0;gGC(k|0,m|0,524288)|0;m=c[3530598]|0;if((c[3542200]|0)==0){l=1;i=a;return l|0}k=g+108|0;c[k>>2]=0;o=g+100|0;c[o>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,13)|0;do{if((c[k>>2]|0)!=0){g=c[o>>2]|0;c[h>>2]=9534384;n=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[n&16383](h,13,0)|0;if((g|0)<1){l=1;i=a;return l|0}if((gzL(m,0,13)|0)==0){break}else{l=1}i=a;return l|0}}while(0);m=c[3530426]|0;if((c[3542200]|0)==0){l=1;i=a;return l|0}h=e+108|0;c[h>>2]=0;o=e+100|0;c[o>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,14)|0;do{if((c[h>>2]|0)!=0){e=c[o>>2]|0;c[f>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](f,14,0)|0;if((e|0)<1){l=1;i=a;return l|0}if((gzL(m,0,14)|0)==0){break}else{l=1}i=a;return l|0}}while(0);m=c[3530332]|0;if((c[3542200]|0)==0){l=1;i=a;return l|0}f=b+108|0;c[f>>2]=0;o=b+100|0;c[o>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](b,15)|0;if((c[f>>2]|0)==0){l=0;i=a;return l|0}f=c[o>>2]|0;c[d>>2]=9534384;gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](d,15,0)|0;if((f|0)<1){l=1;i=a;return l|0}l=(gzL(m,0,15)|0)!=0|0;i=a;return l|0}function edE(a,d,f,g,h,i){a=a|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;j=a;a=(e[f>>1]|0)+h&511;h=(e[f+2>>1]|0)+g&511;g=c[2112926]|0;f=c[2113068]|0;k=0;do{l=(k<<4&496)-a|0;m=(l|0)<-15?l+512|0:l;l=(k>>5<<4)-h|0;n=(l|0)<-15?l+512|0:l;L71670:do{if((m|0)<(f|0)){l=c[2113070]|0;if((n|0)>=(l|0)){break}o=k<<1;p=e[j+(o<<1)>>1]|0;q=b[j+((o|1)<<1)>>1]&8191;o=p&63;r=p&128;s=p&64;if((q|0)==0){break}do{if((m|0)>-1){if(!((m|0)<=(f-16|0)&(n|0)>-1)){break}if((n|0)>(l-16|0)){break}p=(s|0)!=0;if((r|0)==0){if(p){SI(g,q,m,n,o,4,0,i,d);break L71670}else{SG(g,q,m,n,o,4,0,i,d);break L71670}}else{if(p){SM(g,q,m,n,o,4,0,i,d);break L71670}else{SK(g,q,m,n,o,4,0,i,d);break L71670}}}}while(0);l=(s|0)!=0;if((r|0)==0){if(l){SJ(g,q,m,n,o,4,0,i,d);break}else{SH(g,q,m,n,o,4,0,i,d);break}}else{if(l){SN(g,q,m,n,o,4,0,i,d);break}else{SL(g,q,m,n,o,4,0,i,d);break}}}}while(0);k=k+1|0;}while((k|0)<1024);return}function edF(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;a=i;i=i+360|0;b=a|0;d=a+112|0;e=a+120|0;f=a+232|0;g=a+240|0;h=a+352|0;if((R6((c[2388146]|0)+1|0,0,2)|0)!=0){j=1;i=a;return j|0}if((R6(c[2388146]|0,1,2)|0)!=0){j=1;i=a;return j|0}if((R6(c[2386364]|0,3,2)|0)!=0){j=1;i=a;return j|0}if((R6((c[2386364]|0)+1|0,4,2)|0)!=0){j=1;i=a;return j|0}if((R6((c[2386364]|0)+8388609|0,5,2)|0)!=0){j=1;i=a;return j|0}if((R6((c[2386364]|0)+16777217|0,6,2)|0)!=0){j=1;i=a;return j|0}k=c[3530834]|0;if((c[3542200]|0)==0){j=1;i=a;return j|0}l=g+108|0;c[l>>2]=0;m=g+100|0;c[m>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,7)|0;do{if((c[l>>2]|0)!=0){g=c[m>>2]|0;c[h>>2]=9534384;n=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[n&16383](h,7,0)|0;if((g|0)<1){j=1;i=a;return j|0}if((gzL(k,0,7)|0)==0){break}else{j=1}i=a;return j|0}}while(0);k=c[3530426]|0;if((c[3542200]|0)==0){j=1;i=a;return j|0}h=e+108|0;c[h>>2]=0;m=e+100|0;c[m>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,8)|0;do{if((c[h>>2]|0)!=0){e=c[m>>2]|0;c[f>>2]=9534384;l=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[l&16383](f,8,0)|0;if((e|0)<1){j=1;i=a;return j|0}if((gzL(k,0,8)|0)==0){break}else{j=1}i=a;return j|0}}while(0);k=c[3530332]|0;if((c[3542200]|0)==0){j=1;i=a;return j|0}f=b+108|0;c[f>>2]=0;m=b+100|0;c[m>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](b,9)|0;if((c[f>>2]|0)==0){j=0;i=a;return j|0}f=c[m>>2]|0;c[d>>2]=9534384;gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](d,9,0)|0;if((f|0)<1){j=1;i=a;return j|0}j=(gzL(k,0,9)|0)!=0|0;i=a;return j|0}function edG(b,d){b=b|0;d=d|0;if((b|0)!=11010065){return}a[c[3528268]|0]=d;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12;return}function edH(c){c=c|0;var d=0;switch(c|0){case 11010049:{d=b[4775224]&255;break};case 11010097:{d=a[9635048]|0;break};case 11010065:{d=b[4775225]&255;break};case 11010081:{d=b[4775226]&255^3;break};case 11010113:{d=a[9635049]|0;break};default:{d=0}}return d|0}function edI(a,d){a=a|0;d=d|0;var e=0,f=0;e=a&2046;b[(c[2387186]|0)+e>>1]=d;a=d&65535;d=a>>>8;f=a>>>4&15;c[(c[3529994]|0)+((e>>>1|32768)<<2)>>2]=(d&8|d<<4)>>>3&31|(a&8|a<<4)<<8&63488|(f<<4|f)<<3&2016;return}function edJ(b,d){b=b|0;d=d|0;var f=0,g=0;f=c[2387186]|0;a[f+(b&2047^1)|0]=d;d=b&2046;b=e[f+d>>1]|0;f=b>>>8;g=b>>>4&15;c[(c[3529994]|0)+((d>>>1|32768)<<2)>>2]=(f&8|f<<4)>>>3&31|(b&8|b<<4)<<8&63488|(g<<4|g)<<3&2016;return}function edK(b,e){b=b|0;e=e|0;var f=0;f=b&65535;if((f|0)==63488){Uv(0,e);return}else if((f|0)==63504|(f|0)==63505){b=c[3540984]|0;if((f&1|0)==0){a[b+5885|0]=e;return}f=c[b+5876>>2]|0;if((f|0)!=0){gg[f&4095](c[b+5880>>2]|0,0)}lH(b,d[b+5885|0]|0,e&255);return}else{return}}function edL(b){b=b|0;var d=0,e=0;d=b&65535;if((d|0)==64544){e=a[c[3528268]|0]|0}else if((d|0)==63504|(d|0)==63505){e=lx(c[3540984]|0,d&1)|0|6}else if((d|0)==63488){e=c[2113156]&255}else{e=0}return e|0}function edM(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2841724+(b*112|0)>>2];c[a+104>>2]=c[2841728+(b*112|0)>>2];c[a+108>>2]=c[2841732+(b*112|0)>>2];d=0;return d|0}function edN(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=2841624+(b*112|0);e=0;return e|0}function edO(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1259904+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function edP(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>43){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3926560+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function edQ(){return edY(0)|0}function edR(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;Uw(0);b=a[7452584]|0;if(b){d=0;e=b&1;while(1){b=14163936+(d<<2)|0;f=c[b>>2]|0;g=c[2113006]|0;if((g|0)==0){h=54173}else{i=g-1|0;c[2113006]=i;if((i|0)==0){h=54173}}if((h|0)==54173){h=0;c[2383474]=0}if((f|0)==0){j=e}else{gGr(f);j=a[7452584]&1}c[b>>2]=0;b=d+1|0;if((b|0)<(j|0)){d=b;e=j}else{break}}}a[7452584]=0;c[2438224]=0;c[2433522]=0;c[2406672]=0;c[3528468]=0;j=c[2406688]|0;if((j|0)!=0){gGr(j);c[2406688]=0}c[2432972]=0;if((c[2392]|0)>=0){j=0;do{e=14130368+(j<<2)|0;d=c[e>>2]|0;if((d|0)!=0){gGr(d);c[e>>2]=0}e=14130384+(j<<2)|0;d=c[e>>2]|0;if((d|0)!=0){gGr(d);c[e>>2]=0}j=j+1|0;}while((j|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;fwZ();c[2113070]=0;c[2113068]=0;j=c[2112926]|0;if((j|0)!=0){gGr(j);c[2112926]=0}j=c[2414952]|0;e=0;while(1){if((e|0)>=1024){h=54192;break}k=9638528+(e<<2)|0;if((c[k>>2]|0)==(j|0)){break}else{e=e+1|0}}if((h|0)==54192){c[2414952]=0;return 0}gGr(j);c[k>>2]=0;c[2414952]=0;return 0}function edS(){var e=0,f=0,g=0,i=0,j=0;if((a[9624096]|0)!=0){e=c[2414656]|0;gGz(e|0,0,(c[2411642]|0)-e|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060]}RI();e=c[2394]|0;f=c[14130368+(e<<2)>>2]|0;if((f|0)!=0){gGC(f|0,9104152,280)|0}c[8452240+(e<<2)>>2]=c[2113054];c[2394]=-1;e=c[2439330]|0;f=(e|0)==0;if(!f){g=e;gGC(9706056,g|0,76)|0}g=c[2438118]|0;c[2433530]=g;i=c[3528484]|0;c[2076596]=i;j=c[2417276]|0;c[3541536]=j;c[1836236]=0;gGz(9706056,0,76);if(!f){f=e;gGC(f|0,9706056,76)|0}c[2438118]=g;c[3528484]=i;c[2417276]=j;c[1836236]=-1;c[2113156]=0;a[9628264]=0;c[2407033]=0;j=c[3541206]|0;c[3541190]=j;c[3541198]=j;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=j+256;c[3541199]=j+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=j+512;c[3541200]=j+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=j+768;c[3541201]=j+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;lw(c[3540984]|0)}j=c[2385548]|0;if((j|0)>0){gGz(9752472,0,((j|0)>1?j<<2:4)|0)}c[2433530]=0;gGz(9550448,-1|0,6);j=0;i=-1;g=-1;f=-1;do{i=(d[9633328+j|0]<<j^i&65535)&65535;g=(d[9631200+j|0]<<j^g&65535)&65535;f=(d[9629528+j|0]<<j^f&65535)&65535;j=j+1|0;}while((j|0)<8);b[4775224]=i;b[4775225]=g;b[4775226]=f;if((c[2444208]|0)!=0){b[4775225]=g&207|(g&65535)>>>1&16|32}if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060]}g=c[2439330]|0;if((g|0)!=0){f=g;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;c[2113056]=16666;f=RG(16666)|0;c[2113054]=(c[2113054]|0)+f;c[2276108]=-1;c[2113056]=-1;UF(6666)|0;c[2113056]=16666;f=RG(16666)|0;c[2113054]=(c[2113054]|0)+f;c[2276108]=-1;c[2113056]=-1;UF(13332)|0;c[2113056]=16666;f=RG(16666)|0;c[2113054]=(c[2113054]|0)+f;c[2276108]=-1;c[2113056]=-1;UF(19998)|0;c[2113056]=16666;f=RG(16666)|0;c[2113054]=(c[2113054]|0)+f;c[2276108]=-1;c[2113056]=-1;UF(26664)|0;c[2113056]=16666;f=RG(16666)|0;c[2113054]=(c[2113054]|0)+f;c[2276108]=-1;c[2113056]=-1;UF(33330)|0;c[2113056]=16666;f=RG(16666)|0;c[2113054]=(c[2113054]|0)+f;c[2276108]=-1;c[2113056]=-1;UF(39996)|0;c[2113056]=16666;f=RG(16666)|0;c[2113054]=(c[2113054]|0)+f;c[2276108]=-1;c[2113056]=-1;UF(46662)|0;c[2113056]=16666;f=RG(16666)|0;c[2113054]=(c[2113054]|0)+f;c[2276108]=-1;c[2113056]=-1;UF(53328)|0;c[2113056]=16666;f=RG(16666)|0;c[2113054]=(c[2113054]|0)+f;c[2276108]=-1;c[2113056]=-1;UF(59994)|0;c[2113056]=16666;f=RG(16666)|0;c[2113054]=(c[2113054]|0)+f;c[2276108]=-1;c[2113056]=-1;c[8452200+(c[2394]<<2)>>2]=8195;c[2276080]=768;if((c[2276079]|0)>>>0<768){RH(3)}UF(66660)|0;f=c[2438224]|0;g=gGS(-747372544,31788,f,(f|0)<0|0?-1:0)|0;f=g;UF(66666)|0;g=c[2443826]|0;if((g|0)<1073676288){c[2443826]=g-f}g=c[2443827]|0;if((g|0)<1073676288){c[2443827]=g-f}g=(c[3528508]|0)-f|0;c[3528508]=(g|0)<0?0:g;g=c[2112964]|0;if((g|0)!=0){gg[c[3542112]&4095](g,a[9688]|0?534:0);Uu(0,c[2112964]|0,a[9688]|0?534:0)}g=c[1836236]|0;f=c[9757320+(g<<2)>>2]|0;if((f|0)!=0){i=f;gGC(i|0,9706056,76)|0}c[9752472+(g<<2)>>2]=c[2433530];c[14113936+(g<<2)>>2]=c[2076596];c[9669104+(g<<2)>>2]=c[3541536];c[1836236]=-1;g=c[2394]|0;i=c[14130368+(g<<2)>>2]|0;if((i|0)!=0){gGC(i|0,9104152,280)|0}c[8452240+(g<<2)>>2]=c[2113054];c[2394]=-1;if((c[2112968]|0)==0){return 0}edT()|0;return 0}function edT(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;if((a[9547408]|0)!=0){d=c[3529994]|0;f=0;do{c[d+(f<<2)>>2]=f>>>5<<11&63488|f&31|(f>>>10<<3|f>>>12&4)<<3&2016;f=f+1|0;}while((f|0)<32768);f=c[2387186]|0;g=0;do{h=e[f+g>>1]|0;i=h>>>8;j=h>>>4&15;c[d+((g>>>1|32768)<<2)>>2]=(i&8|i<<4)>>>3&31|(h&8|h<<4)<<8&63488|(j<<4|j)<<3&2016;g=g+2|0;}while((g|0)<2048);a[9547408]=0}g=c[2112926]|0;d=c[2113068]|0;f=(c[3529430]|0)+16384|0;j=g;h=0;while(1){if((d|0)>0){i=0;do{b[j+(i<<1)>>1]=(e[f+(i<<1)>>1]|0)>>>1;i=i+1|0;}while((i|0)<(d|0))}i=h+1|0;if((i|0)<224){f=f+1024|0;j=j+(d<<1)|0;h=i}else{break}}ed$(0);h=c[3529464]|0;j=c[2387868]|0;f=c[3530832]|0;i=0;L71929:while(1){k=i<<4&1008;l=(((i|0)/64|0)<<3)-16|0;do{if(!((k|0)>=(d|0)|(l|0)<0)){if((l|0)>=(c[2113070]|0)){m=54253;break L71929}n=e[j+(i<<1)>>1]|0;o=n>>>4&15;if((n&8|0)!=0){break}n=e[h+(i<<1)>>1]<<1&16382;Sr(g,n,k,l,o,4,0,33280,f);Sr(g,n|1,k|8,l,o,4,0,33280,f)}}while(0);l=i+1|0;if((l|0)<2048){i=l}else{m=54252;break}}if((m|0)==54252){ed$(32);p=c[3529994]|0;R8(p);return 0}else if((m|0)==54253){ed$(32);p=c[3529994]|0;R8(p);return 0}return 0}function edU(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=i;i=i+64|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;if((d|0)!=0){c[d>>2]=169624}if((b&96|0)==0){i=e;return 0}gGz(j|0,0,12);k=c[2414656]|0;c[j>>2]=k;c[j+4>>2]=(c[2411642]|0)-k;c[j+12>>2]=162152;gj[c[2076592]&4095](j)|0;j=h|0;do{if((b&64|0)!=0){gGz(g|0,0,16);c[2394]=-1;if((c[2392]|0)<0){break}k=h+9|0;l=f;m=f|0;n=f+4|0;o=f+12|0;p=g|0;q=g+4|0;r=g+12|0;s=0;do{gGC(j|0,614896,11)|0;a[k]=s+48&255;t=8452256+(s<<2)|0;gGz(l|0,0,12);c[m>>2]=t;c[n>>2]=4;c[o>>2]=164976;gj[c[2076592]&4095](f)|0;if((c[t>>2]|0)!=0){c[p>>2]=c[14130368+(s<<2)>>2];c[q>>2]=c[8452184+(s<<2)>>2];c[r>>2]=j;t=c[2076592]|0;gj[t&4095](g)|0}s=s+1|0;}while((s|0)<=(c[2392]|0))}}while(0);fw$(b);UQ(b,d);Ut(0);i=e;return 0}function edV(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2754532+(b*112|0)>>2];c[a+104>>2]=c[2754536+(b*112|0)>>2];c[a+108>>2]=c[2754540+(b*112|0)>>2];d=0;return d|0}function edW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=2754432+(b*112|0);e=0;return e|0}function edX(){return edY(1)|0}function edY(e){e=e|0;var f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;f=i;i=i+240|0;g=f|0;j=f+112|0;k=f+120|0;l=f+232|0;c[2414952]=0;c[2388144]=0;c[2385918]=4194304;c[3530832]=4259840;c[3530596]=5308416;c[3541206]=5832704;c[2386642]=5832704;c[3529994]=6094848;c[2414656]=6230016;c[3531164]=6230016;c[3531140]=6246400;c[3529464]=6279168;c[3529430]=6295552;c[2387868]=6557696;c[2386446]=6561792;c[2387186]=6565888;c[2386072]=6567936;c[3528268]=6569984;c[2411642]=6569985;m=0;while(1){if((m|0)>=1024){break}n=9638528+(m<<2)|0;if((c[n>>2]|0)==0){o=54283;break}else{m=m+1|0}}do{if((o|0)==54283){m=gGq(6569985)|0;c[n>>2]=m;if((m|0)==0){break}c[2414952]=m;gGz(m|0,0,6569985);c[2388144]=m;c[2385918]=m+4194304;c[3530832]=m+4259840;c[3530596]=m+5308416;p=m+5832704|0;c[3541206]=p;c[2386642]=p;c[3529994]=m+6094848;p=m+6230016|0;c[2414656]=p;c[3531164]=p;c[3531140]=m+6246400;c[3529464]=m+6279168;c[3529430]=m+6295552;c[2387868]=m+6557696;c[2386446]=m+6561792;c[2387186]=m+6565888;c[2386072]=m+6567936;c[3528268]=m+6569984;p=m+6569985|0;c[2411642]=p;c[2414182]=p;if((R6(m+1|0,0,2)|0)!=0){q=1;i=f;return q|0}if((R6(c[2388144]|0,1,2)|0)!=0){q=1;i=f;return q|0}if((R6((c[2388144]|0)+1048577|0,2,2)|0)!=0){q=1;i=f;return q|0}if((R6((c[2388144]|0)+1048576|0,3,2)|0)!=0){q=1;i=f;return q|0}if((R6((c[2388144]|0)+2097153|0,4,2)|0)!=0){q=1;i=f;return q|0}if((R6((c[2388144]|0)+2097152|0,5,2)|0)!=0){q=1;i=f;return q|0}if((R6((c[2388144]|0)+3145729|0,6,2)|0)!=0){q=1;i=f;return q|0}if((R6((c[2388144]|0)+3145728|0,7,2)|0)!=0){q=1;i=f;return q|0}m=c[2385918]|0;if((c[3542200]|0)==0){q=1;i=f;return q|0}p=k+108|0;c[p>>2]=0;r=k+100|0;c[r>>2]=0;s=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[s&16383](k,8)|0;do{if((c[p>>2]|0)!=0){s=c[r>>2]|0;c[l>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](l,8,0)|0;if((s|0)<1){q=1;i=f;return q|0}if((gzL(m,0,8)|0)==0){break}else{q=1}i=f;return q|0}}while(0);if((R6(c[3530832]|0,9,2)|0)!=0){q=1;i=f;return q|0}if((R6((c[3530832]|0)+1|0,10,2)|0)!=0){q=1;i=f;return q|0}if((R6(c[3530596]|0,11,2)|0)!=0){q=1;i=f;return q|0}if((R6((c[3530596]|0)+1|0,12,2)|0)!=0){q=1;i=f;return q|0}m=c[2386642]|0;if((c[3542200]|0)==0){q=1;i=f;return q|0}r=g+108|0;c[r>>2]=0;p=g+100|0;c[p>>2]=0;s=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[s&16383](g,13)|0;do{if((c[r>>2]|0)!=0){s=c[p>>2]|0;c[j>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](j,13,0)|0;if((s|0)<1){q=1;i=f;return q|0}if((gzL(m,0,13)|0)==0){break}else{q=1}i=f;return q|0}}while(0);m=c[3530832]|0;p=1048576;r=1048574;while(1){s=m+((r|0)/2|0)|0;a[m+(p-1)|0]=a[s]&15;a[m+r|0]=(d[s]|0)>>>4;s=r-2|0;if((s|0)>-1){p=r;r=s}else{break}}r=c[3530596]|0;p=524288;m=524286;while(1){s=r+((m|0)/2|0)|0;a[r+(p-1)|0]=a[s]&15;a[r+m|0]=(d[s]|0)>>>4;s=m-2|0;if((s|0)>-1){p=m;m=s}else{break}}m=c[3529994]|0;p=0;do{c[m+(p<<2)>>2]=p>>>5<<11&63488|p&31|(p>>>10<<3|p>>>12&4)<<3&2016;p=p+1|0;}while((p|0)<32768);fxU(0,425984);if((c[2394]|0)==0){u=c[2112932]|0}else{c[2394]=0;p=c[3532596]|0;c[2112932]=p;m=c[3532592]|0;if((m|0)!=0){gGC(9104152,m|0,280)|0}c[2113054]=c[2113060];u=p}p=c[2388144]|0;m=u|0;r=0;while(1){s=p+r|0;c[m>>2]=s;c[m+131072>>2]=s;s=r+1024|0;if(s>>>0>4194303){break}else{m=m+4|0;r=s}}r=c[3531164]|0;c[u+28672>>2]=r;c[u+94208>>2]=r;c[u+159744>>2]=r;m=r+1024|0;c[u+28676>>2]=m;c[u+94212>>2]=m;c[u+159748>>2]=m;p=r+2048|0;c[u+28680>>2]=p;c[u+94216>>2]=p;c[u+159752>>2]=p;s=r+3072|0;c[u+28684>>2]=s;c[u+94220>>2]=s;c[u+159756>>2]=s;t=r+4096|0;c[u+28688>>2]=t;c[u+94224>>2]=t;c[u+159760>>2]=t;v=r+5120|0;c[u+28692>>2]=v;c[u+94228>>2]=v;c[u+159764>>2]=v;w=r+6144|0;c[u+28696>>2]=w;c[u+94232>>2]=w;c[u+159768>>2]=w;x=r+7168|0;c[u+28700>>2]=x;c[u+94236>>2]=x;c[u+159772>>2]=x;y=r+8192|0;c[u+28704>>2]=y;c[u+94240>>2]=y;c[u+159776>>2]=y;z=r+9216|0;c[u+28708>>2]=z;c[u+94244>>2]=z;c[u+159780>>2]=z;A=r+10240|0;c[u+28712>>2]=A;c[u+94248>>2]=A;c[u+159784>>2]=A;B=r+11264|0;c[u+28716>>2]=B;c[u+94252>>2]=B;c[u+159788>>2]=B;C=r+12288|0;c[u+28720>>2]=C;c[u+94256>>2]=C;c[u+159792>>2]=C;D=r+13312|0;c[u+28724>>2]=D;c[u+94260>>2]=D;c[u+159796>>2]=D;E=r+14336|0;c[u+28728>>2]=E;c[u+94264>>2]=E;c[u+159800>>2]=E;F=r+15360|0;c[u+28732>>2]=F;c[u+94268>>2]=F;c[u+159804>>2]=F;G=c[3531140]|0;H=u+28800|0;I=7372800;while(1){J=G+(I-7372800)|0;c[H>>2]=J;c[H+65536>>2]=J;c[H+131072>>2]=J;J=I+1024|0;if(J>>>0>7405567){break}else{H=H+4|0;I=J}}c[u+32768>>2]=r;c[u+98304>>2]=r;c[u+163840>>2]=r;c[u+32772>>2]=m;c[u+98308>>2]=m;c[u+163844>>2]=m;c[u+32776>>2]=p;c[u+98312>>2]=p;c[u+163848>>2]=p;c[u+32780>>2]=s;c[u+98316>>2]=s;c[u+163852>>2]=s;c[u+32784>>2]=t;c[u+98320>>2]=t;c[u+163856>>2]=t;c[u+32788>>2]=v;c[u+98324>>2]=v;c[u+163860>>2]=v;c[u+32792>>2]=w;c[u+98328>>2]=w;c[u+163864>>2]=w;c[u+32796>>2]=x;c[u+98332>>2]=x;c[u+163868>>2]=x;c[u+32800>>2]=y;c[u+98336>>2]=y;c[u+163872>>2]=y;c[u+32804>>2]=z;c[u+98340>>2]=z;c[u+163876>>2]=z;c[u+32808>>2]=A;c[u+98344>>2]=A;c[u+163880>>2]=A;c[u+32812>>2]=B;c[u+98348>>2]=B;c[u+163884>>2]=B;c[u+32816>>2]=C;c[u+98352>>2]=C;c[u+163888>>2]=C;c[u+32820>>2]=D;c[u+98356>>2]=D;c[u+163892>>2]=D;c[u+32824>>2]=E;c[u+98360>>2]=E;c[u+163896>>2]=E;c[u+32828>>2]=F;c[u+98364>>2]=F;c[u+163900>>2]=F;I=u+32896|0;H=8421376;while(1){J=G+(H-8421376)|0;c[I>>2]=J;c[I+65536>>2]=J;c[I+131072>>2]=J;J=H+1024|0;if(J>>>0>8454143){break}else{I=I+4|0;H=J}}H=c[2386446]|0;c[u+34816>>2]=H;c[u+100352>>2]=H;c[u+165888>>2]=H;I=H+1024|0;c[u+34820>>2]=I;c[u+100356>>2]=I;c[u+165892>>2]=I;I=H+2048|0;c[u+34824>>2]=I;c[u+100360>>2]=I;c[u+165896>>2]=I;I=H+3072|0;c[u+34828>>2]=I;c[u+100364>>2]=I;c[u+165900>>2]=I;I=c[2387868]|0;c[u+36864>>2]=I;c[u+102400>>2]=I;c[u+167936>>2]=I;H=I+1024|0;c[u+36868>>2]=H;c[u+102404>>2]=H;c[u+167940>>2]=H;H=I+2048|0;c[u+36872>>2]=H;c[u+102408>>2]=H;c[u+167944>>2]=H;H=I+3072|0;c[u+36876>>2]=H;c[u+102412>>2]=H;c[u+167948>>2]=H;H=c[3529464]|0;c[u+36928>>2]=H;c[u+102464>>2]=H;c[u+168e3>>2]=H;I=H+1024|0;c[u+36932>>2]=I;c[u+102468>>2]=I;c[u+168004>>2]=I;I=H+2048|0;c[u+36936>>2]=I;c[u+102472>>2]=I;c[u+168008>>2]=I;I=H+3072|0;c[u+36940>>2]=I;c[u+102476>>2]=I;c[u+168012>>2]=I;I=c[3529430]|0;H=u+38912|0;G=9961472;while(1){F=I+(G-9961472)|0;c[H>>2]=F;c[H+65536>>2]=F;c[H+131072>>2]=F;F=G+1024|0;if(F>>>0>10223615){break}else{H=H+4|0;G=F}}G=c[2387186]|0;c[u+40976>>2]=G;c[u+172048>>2]=G;H=G+1024|0;c[u+40980>>2]=H;c[u+172052>>2]=H;c[u+106512>>2]=1;c[u+106516>>2]=1;c[u+196648>>2]=2734;c[u+196608>>2]=2778;c[u+196652>>2]=2306;c[u+196732>>2]=1234;H=c[3532592]|0;if((H|0)!=0){gGC(H|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);H=c[2439330]|0;G=(H|0)==0;if(!G){I=H;gGC(9706056,I|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];I=c[3528484]|0;c[2076596]=I;F=c[2417276]|0;c[3541536]=F;c[1836236]=0;E=c[2385918]|0;D=0;C=0;while(1){c[H+76+(C<<2)>>2]=E+(C<<8);B=D+1&65535;if((B&65535)>239){K=0;L=0;break}else{D=B;C=B&65535}}while(1){C=E+(L<<8)|0;c[H+76+(L+512<<2)>>2]=C;c[H+76+(L+768<<2)>>2]=C;C=K+1&65535;if((C&65535)>239){break}else{K=C;L=C&65535}}E=c[2386072]|0;c[H+1036>>2]=E;C=E+256|0;c[H+1040>>2]=C;D=E+512|0;c[H+1044>>2]=D;B=E+768|0;c[H+1048>>2]=B;A=E+1024|0;c[H+1052>>2]=A;z=E+1280|0;c[H+1056>>2]=z;y=E+1536|0;c[H+1060>>2]=y;x=E+1792|0;c[H+1064>>2]=x;c[H+2060>>2]=E;c[H+2064>>2]=C;c[H+2068>>2]=D;c[H+2072>>2]=B;c[H+2076>>2]=A;c[H+2080>>2]=z;c[H+2084>>2]=y;c[H+2088>>2]=x;c[H+3084>>2]=E;c[H+4108>>2]=E;c[H+3088>>2]=C;c[H+4112>>2]=C;c[H+3092>>2]=D;c[H+4116>>2]=D;c[H+3096>>2]=B;c[H+4120>>2]=B;c[H+3100>>2]=A;c[H+4124>>2]=A;c[H+3104>>2]=z;c[H+4128>>2]=z;c[H+3108>>2]=y;c[H+4132>>2]=y;c[H+3112>>2]=x;c[H+4136>>2]=x;c[H+4184>>2]=2972;c[H+4180>>2]=2394;if(!G){x=H;gGC(x|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=I;c[2417276]=F;c[1836236]=-1;UL(3579545,1124,670,0);c[2438224]=4e6;c[2433522]=3416;c[2406672]=1752;c[3528468]=9362;c[2443842]=511;h[745398]=1.0;a[3203264]=1;Ux(0,8e3,1);c[2407030]=128;c[2407068]=3;c[2444208]=e;x=c[642608+(c[2436]<<2)>>2]|0;y=c[x+128>>2]|0;if((c[x+52>>2]&4|0)==0){c[2113068]=y;z=c[x+132>>2]|0;c[2113070]=z;c[2443814]=y;c[2440436]=z;M=y;N=z}else{c[2113070]=y;z=c[x+132>>2]|0;c[2113068]=z;c[2440436]=y;c[2443814]=z;M=z;N=y}y=ag(M<<1,N)|0;z=gGq(y)|0;c[2112926]=z;if((z|0)!=0){gGz(z|0,0,y|0)}y=c[2414656]|0;gGz(y|0,0,(c[2411642]|0)-y|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];y=c[3532592]|0;if((y|0)!=0){gGC(9104152,y|0,280)|0}c[2113054]=c[2113060]}RI();y=c[2394]|0;z=c[14130368+(y<<2)>>2]|0;if((z|0)!=0){gGC(z|0,9104152,280)|0}c[8452240+(y<<2)>>2]=c[2113054];c[2394]=-1;y=c[2439330]|0;z=(y|0)==0;if(!z){x=y;gGC(9706056,x|0,76)|0}x=c[2438118]|0;c[2433530]=x;A=c[3528484]|0;c[2076596]=A;B=c[2417276]|0;c[3541536]=B;c[1836236]=0;gGz(9706056,0,76);if(!z){z=y;gGC(z|0,9706056,76)|0}c[2438118]=x;c[3528484]=A;c[2417276]=B;c[1836236]=-1;c[2113156]=0;a[9628264]=0;c[2407033]=0;B=c[3541206]|0;c[3541190]=B;c[3541198]=B;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=B+256;c[3541199]=B+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=B+512;c[3541200]=B+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=B+768;c[3541201]=B+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;lw(c[3540984]|0);q=0;i=f;return q|0}}while(0);c[2414952]=0;q=1;i=f;return q|0}function edZ(b,c){b=b|0;c=c|0;a[9706117]=(c|0)!=0|0;return}function ed_(a){a=a|0;var b=0,d=0;b=(c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,4e6,0)|0;return a|0}function ed$(a){a=a|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=c[2386446]|0;f=c[2112926]|0;g=c[3530596]|0;h=(c[2113222]&1|0)==0;i=2040;do{j=e[d+(i<<1)>>1]|0;do{if((j&4|0)!=0){if(!(((j&64|0)==0|h^1)&(j&32|0)==(a|0))){break}k=b[d+((i|1)<<1)>>1]&16383;l=e[d+((i|2)<<1)>>1]|0;m=(e[d+((i|3)<<1)>>1]|0)-16|0;n=e[d+((i|4)<<1)>>1]|0;o=1<<(l&3);p=l>>>4&15;if((o|0)<=0){break}l=(j&1|0)==0;q=o-1|0;r=(j&2|0)!=0;s=0;do{t=(s<<1&2)+k+(s<<2&8)+(s<<3&32)|0;u=((r?q-s|0:s)<<3)+m|0;if(l){v=0;do{w=(v<<3)+n|0;x=(v&1)+t+(v<<1&4)+(v<<2&16)|0;if(r){Sv(f,x,w,u,p,4,0,32768,g)}else{Sr(f,x,w,u,p,4,0,32768,g)}v=v+1|0;}while((v|0)<(o|0))}else{v=0;do{w=(q-v<<3)+n|0;x=(v&1)+t+(v<<1&4)+(v<<2&16)|0;if(r){Sx(f,x,w,u,p,4,0,32768,g)}else{St(f,x,w,u,p,4,0,32768,g)}v=v+1|0;}while((v|0)<(o|0))}s=s+1|0;}while((s|0)<(o|0))}}while(0);i=i-8|0;}while((i|0)>-1);return}function ed0(b){b=b|0;a[9706117]=(b|0)!=0|0;return}function ed1(a){a=a|0;var d=0,e=0;if((a|0)==1376320){d=((gj[c[(c[2112932]|0)+196608>>2]&4095](1376320)|0)&255)<<8;e=(gj[c[(c[2112932]|0)+196608>>2]&4095](1376321)|0)&255|d;return e|0}else if((a|0)==1376304){d=((gj[c[(c[2112932]|0)+196608>>2]&4095](1376304)|0)&255)<<8;e=(gj[c[(c[2112932]|0)+196608>>2]&4095](1376305)|0)&255|d;return e|0}else if((a|0)==1376336){e=b[4879e3]|0;return e|0}else{e=0;return e|0}return 0}function ed2(b){b=b|0;var c=0;if((b|0)==1376304|(b|0)==1376305){c=a[14108833]|0}else if((b|0)==1376320|(b|0)==1376321){c=a[14108832]|0}else{c=0}return c|0}function ed3(a,b){a=a|0;b=b|0;if((a|0)==1441822){c[2405418]=b&65535;return}else if((a|0)==1376272){gg[c[(c[2112932]|0)+196648>>2]&4095](1376272,(b&65535)>>>8&255);gg[c[(c[2112932]|0)+196648>>2]&4095](1376273,b&255);return}else if((a|0)==1441804){c[2405424]=b&65535;return}else if((a|0)==1441810){c[2405422]=b&65535;return}else if((a|0)==1441816){c[2405420]=b&65535;return}else if((a|0)==1441792){c[3527508]=b&65535;return}else{return}}function ed4(d,e){d=d|0;e=e|0;var f=0,g=0;if((d|0)!=1376273){return}c[2430204]=e&255;e=c[2439330]|0;if((e|0)!=0){d=e;gGC(9706056,d|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;d=(c[2433530]|0)+12|0;c[2433530]=d;e=c[1836236]|0;f=c[9757320+(e<<2)>>2]|0;if((f|0)!=0){g=f;gGC(g|0,9706056,76)|0}c[9752472+(e<<2)>>2]=d;c[14113936+(e<<2)>>2]=c[2076596];c[9669104+(e<<2)>>2]=c[3541536];c[1836236]=-1;return}function ed5(a){a=a|0;var d=0,e=0;if((a|0)==1376288){d=b[4879001]|0;return d|0}else if((a|0)==1376320){e=((gj[c[(c[2112932]|0)+196608>>2]&4095](1376320)|0)&255)<<8;d=(gj[c[(c[2112932]|0)+196608>>2]&4095](1376321)|0)&255|e;return d|0}else if((a|0)==1376336){d=b[4879e3]|0;return d|0}else if((a|0)==1376304){a=((gj[c[(c[2112932]|0)+196608>>2]&4095](1376304)|0)&255)<<8;d=(gj[c[(c[2112932]|0)+196608>>2]&4095](1376305)|0)&255|a;return d|0}else{d=0;return d|0}return 0}function ed6(b){b=b|0;var c=0;if((b|0)==1376304|(b|0)==1376305){c=a[14108833]|0}else if((b|0)==1376320|(b|0)==1376321){c=a[14108832]|0}else{c=0}return c|0}function ed7(a,b){a=a|0;b=b|0;switch(a|0){case 1441816:{c[2405420]=b&65535;return};case 1441810:{c[2405422]=b&65535;return};case 1441822:{c[2405418]=b&65535;return};case 1441798:{c[3527500]=b&65535;return};case 1441804:{c[2405424]=b&65535;return};case 1441792:{c[3527508]=b&65535;return};default:{return}}}function ed8(d,e){d=d|0;e=e|0;var f=0,g=0;if((d|0)!=1376273){return}c[2430204]=e&255;e=c[2439330]|0;if((e|0)!=0){d=e;gGC(9706056,d|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;d=(c[2433530]|0)+12|0;c[2433530]=d;e=c[1836236]|0;f=c[9757320+(e<<2)>>2]|0;if((f|0)!=0){g=f;gGC(g|0,9706056,76)|0}c[9752472+(e<<2)>>2]=d;c[14113936+(e<<2)>>2]=c[2076596];c[9669104+(e<<2)>>2]=c[3541536];c[1836236]=-1;return}function ed9(a){a=a|0;var b=0,d=0;b=a&65535;if((b|0)==64517){d=c[(c[3531464]|0)+4240>>2]&255}else if((b|0)==64520){d=c[2430204]&255}else if((b|0)==64512){d=c[2113156]&255}else{d=0}return d|0}function eea(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((e|0)==64516){c[2113304]=d&255;return}else if((e|0)==64512){Uv(0,d);return}else if((e|0)==64517){e=c[2113304]|0;a[14168504+e|0]=d;mv(0,e,d&255);return}else{return}}function eeb(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;e=i;i=i+360|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=c[c[642608+(c[2436]<<2)>>2]>>2]|0;if((fa(n|0,256656)|0)==0){a[673152]=1}if((fa(n|0,525568)|0)==0){a[680488]=1;o=1}else{o=a[680488]|0}c[2426712]=0;c[3527204]=0;c[2438714]=524288;c[3541206]=589824;c[2405646]=720896;n=a[673152]|o;c[3527206]=720896;o=n?761856:774144;c[2437720]=n?741376:761856;c[2433430]=n?745472:765952;c[2432698]=n?749568:768e3;c[2432694]=n?753664:770048;c[2430216]=n?757760:772096;c[2432696]=o;c[2430206]=o+4096;c[2438716]=o+12288;n=o+61442|0;c[2411640]=n;c[2432700]=n;c[2430208]=o+323586;c[2429746]=o+2420738;c[2437718]=o+4517890;n=o+4550658|0;c[2414180]=n;o=n;n=0;while(1){if((n|0)>=1024){break}p=9638528+(n<<2)|0;if((c[p>>2]|0)==0){q=54492;break}else{n=n+1|0}}do{if((q|0)==54492){n=gGq(o)|0;c[p>>2]=n;if((n|0)==0){break}gGz(n|0,0,o|0);c[2426712]=n;gGz(n|0,0,o|0);c[3527204]=n;c[2438714]=n+524288;c[3541206]=n+589824;r=n+720896|0;c[2405646]=r;s=a[673152]|a[680488];c[3527206]=r;if(s){c[2437720]=n+741376;c[2433430]=n+745472;c[2432698]=n+749568;c[2432694]=n+753664;c[2430216]=n+757760;t=n+761856|0}else{c[2437720]=n+761856;c[2433430]=n+765952;c[2432698]=n+768e3;c[2432694]=n+770048;c[2430216]=n+772096;t=n+774144|0}c[2432696]=t;c[2430206]=t+4096;c[2438716]=t+12288;n=t+61442|0;c[2411640]=n;c[2432700]=n;c[2430208]=t+323586;c[2429746]=t+2420738;c[2437718]=t+4517890;c[2414180]=t+4550658;n=0;while(1){if((n|0)>=1024){u=0;break}v=9638528+(n<<2)|0;if((c[v>>2]|0)==0){q=54500;break}else{n=n+1|0}}do{if((q|0)==54500){n=gGq(1048576)|0;c[v>>2]=n;if((n|0)==0){u=0;break}gGz(n|0,0,1048576);u=n}}while(0);c[2437716]=u;if((R6((c[3527204]|0)+1|0,0,2)|0)!=0){w=1;i=e;return w|0}if((R6(c[3527204]|0,1,2)|0)!=0){w=1;i=e;return w|0}n=c[2437716]|0;gGz(n|0,0,1048576);if((c[3542200]|0)==0){w=1;i=e;return w|0}s=l+108|0;c[s>>2]=0;r=l+100|0;c[r>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,2)|0;do{if((c[s>>2]|0)!=0){x=c[r>>2]|0;c[m>>2]=9534384;y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[y&16383](m,2,0)|0;if((x|0)<1){w=1;i=e;return w|0}if((gzL(n,0,2)|0)==0){break}else{w=1}i=e;return w|0}}while(0);n=c[2437716]|0;r=c[2432700]|0;s=0;do{x=s<<6;gGz(r+x|0,0,64);y=s<<8;z=0;do{A=1<<3-z;B=(c[703416+(z<<2)>>2]|0)+y|0;C=0;do{D=B+(c[1183816+(C<<2)>>2]|0)|0;E=(C<<3)+x|0;F=0;do{G=D+(c[1934976+(F<<2)>>2]|0)|0;if(((d[n+((G|0)/8|0)|0]|0)&128>>>((G&7)>>>0)|0)!=0){G=r+(E+F)|0;a[G]=(d[G]|0|A)&255}F=F+1|0;}while((F|0)<8);C=C+1|0;}while((C|0)<8);z=z+1|0;}while((z|0)<4);s=s+1|0;}while((s|0)<4096);gGz(n|0,0,1048576);if((R6(n,3,2)|0)!=0){w=1;i=e;return w|0}if((R6((c[2437716]|0)+1|0,4,2)|0)!=0){w=1;i=e;return w|0}s=c[2437716]|0;r=c[2430208]|0;z=0;do{x=z<<8;gGz(r+x|0,0,256);y=z<<10;C=0;do{A=1<<3-C;B=(c[703416+(C<<2)>>2]|0)+y|0;F=0;do{E=B+(c[3946808+(F<<2)>>2]|0)|0;D=(F<<4)+x|0;G=0;do{H=E+(c[3946872+(G<<2)>>2]|0)|0;if(((d[s+((H|0)/8|0)|0]|0)&128>>>((H&7)>>>0)|0)!=0){H=r+(D+G)|0;a[H]=(d[H]|0|A)&255}G=G+1|0;}while((G|0)<16);F=F+1|0;}while((F|0)<16);C=C+1|0;}while((C|0)<4);z=z+1|0;}while((z|0)<8192);gGz(s|0,0,1048576);if((R6(s,5,2)|0)!=0){w=1;i=e;return w|0}if((R6((c[2437716]|0)+1|0,6,2)|0)!=0){w=1;i=e;return w|0}z=c[2437716]|0;r=c[2429746]|0;n=0;while(1){C=n<<6;gGz(r+C|0,0,64);x=n<<8;y=0;do{F=1<<3-y;A=(c[703416+(y<<2)>>2]|0)+x|0;B=0;do{G=A+(c[1183816+(B<<2)>>2]|0)|0;D=(B<<3)+C|0;E=0;do{H=G+(c[1934976+(E<<2)>>2]|0)|0;if(((d[z+((H|0)/8|0)|0]|0)&128>>>((H&7)>>>0)|0)!=0){H=r+(D+E)|0;a[H]=(d[H]|0|F)&255}E=E+1|0;}while((E|0)<8);B=B+1|0;}while((B|0)<8);y=y+1|0;}while((y|0)<4);y=n+1|0;if((y|0)<32768){n=y}else{I=0;break}}while(1){if((I|0)>=1024){break}J=9638528+(I<<2)|0;if((c[J>>2]|0)==(z|0)){q=54544;break}else{I=I+1|0}}if((q|0)==54544){gGr(z);c[J>>2]=0}c[2437716]=0;n=c[2438714]|0;if((c[3542200]|0)==0){w=1;i=e;return w|0}r=j+108|0;c[r>>2]=0;s=j+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,7)|0;do{if((c[r>>2]|0)!=0){y=c[s>>2]|0;c[k>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](k,7,0)|0;if((y|0)<1){w=1;i=e;return w|0}if((gzL(n,0,7)|0)==0){break}else{w=1}i=e;return w|0}}while(0);n=c[3541206]|0;if((c[3542200]|0)==0){w=1;i=e;return w|0}s=f+108|0;c[s>>2]=0;r=f+100|0;c[r>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,8)|0;do{if((c[s>>2]|0)!=0){z=c[r>>2]|0;c[g>>2]=9534384;y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[y&16383](g,8,0)|0;if((z|0)<1){w=1;i=e;return w|0}if((gzL(n,0,8)|0)==0){break}else{w=1}i=e;return w|0}}while(0);fxU(0,425984);if((c[2394]|0)==0){K=c[2112932]|0}else{c[2394]=0;n=c[3532596]|0;c[2112932]=n;r=c[3532592]|0;if((r|0)!=0){gGC(9104152,r|0,280)|0}c[2113054]=c[2113060];K=n}n=dW(c[c[642608+(c[2436]<<2)>>2]>>2]|0,406416,8)|0;r=c[3527204]|0;s=K|0;z=0;while(1){y=r+z|0;c[s>>2]=y;c[s+131072>>2]=y;y=z+1024|0;if(y>>>0>524287){break}else{s=s+4|0;z=y}}z=c[3527206]|0;c[K+4096>>2]=z;c[K+69632>>2]=z;c[K+135168>>2]=z;s=z+1024|0;c[K+4100>>2]=s;c[K+69636>>2]=s;c[K+135172>>2]=s;s=z+2048|0;c[K+4104>>2]=s;c[K+69640>>2]=s;c[K+135176>>2]=s;s=z+3072|0;c[K+4108>>2]=s;c[K+69644>>2]=s;c[K+135180>>2]=s;s=z+4096|0;c[K+4112>>2]=s;c[K+69648>>2]=s;c[K+135184>>2]=s;s=z+5120|0;c[K+4116>>2]=s;c[K+69652>>2]=s;c[K+135188>>2]=s;s=z+6144|0;c[K+4120>>2]=s;c[K+69656>>2]=s;c[K+135192>>2]=s;s=z+7168|0;c[K+4124>>2]=s;c[K+69660>>2]=s;c[K+135196>>2]=s;s=z+8192|0;c[K+4128>>2]=s;c[K+69664>>2]=s;c[K+135200>>2]=s;s=z+9216|0;c[K+4132>>2]=s;c[K+69668>>2]=s;c[K+135204>>2]=s;s=z+10240|0;c[K+4136>>2]=s;c[K+69672>>2]=s;c[K+135208>>2]=s;s=z+11264|0;c[K+4140>>2]=s;c[K+69676>>2]=s;c[K+135212>>2]=s;s=z+12288|0;c[K+4144>>2]=s;c[K+69680>>2]=s;c[K+135216>>2]=s;s=z+13312|0;c[K+4148>>2]=s;c[K+69684>>2]=s;c[K+135220>>2]=s;s=z+14336|0;c[K+4152>>2]=s;c[K+69688>>2]=s;c[K+135224>>2]=s;s=z+15360|0;c[K+4156>>2]=s;c[K+69692>>2]=s;c[K+135228>>2]=s;s=c[2437720]|0;c[K+4352>>2]=s;c[K+69888>>2]=s;c[K+135424>>2]=s;r=s+1024|0;c[K+4356>>2]=r;c[K+69892>>2]=r;c[K+135428>>2]=r;r=s+2048|0;c[K+4360>>2]=r;c[K+69896>>2]=r;c[K+135432>>2]=r;r=s+3072|0;c[K+4364>>2]=r;c[K+69900>>2]=r;c[K+135436>>2]=r;r=c[2433430]|0;c[K+4608>>2]=r;c[K+70144>>2]=r;c[K+135680>>2]=r;s=r+1024|0;c[K+4612>>2]=s;c[K+70148>>2]=s;c[K+135684>>2]=s;if((n|0)==0){s=c[2432698]|0;c[K+4616>>2]=s;c[K+70152>>2]=s;c[K+135688>>2]=s;y=s+1024|0;c[K+4620>>2]=y;c[K+70156>>2]=y;c[K+135692>>2]=y;y=c[2432694]|0;c[K+4624>>2]=y;c[K+70160>>2]=y;c[K+135696>>2]=y;s=y+1024|0;c[K+4628>>2]=s;c[K+70164>>2]=s;c[K+135700>>2]=s;s=c[2430216]|0;c[K+4632>>2]=s;c[K+70168>>2]=s;c[K+135704>>2]=s;y=s+1024|0;c[K+4636>>2]=y;c[K+70172>>2]=y;c[K+135708>>2]=y;y=K+4640|0;s=1187840;while(1){C=z+(s-1171456)|0;c[y>>2]=C;c[y+65536>>2]=C;c[y+131072>>2]=C;C=s+1024|0;if(C>>>0>1212415){break}else{y=y+4|0;s=C}}s=c[2432696]|0;c[K+4864>>2]=s;c[K+70400>>2]=s;c[K+135936>>2]=s;y=s+1024|0;c[K+4868>>2]=y;c[K+70404>>2]=y;c[K+135940>>2]=y;y=s+2048|0;c[K+4872>>2]=y;c[K+70408>>2]=y;c[K+135944>>2]=y;y=s+3072|0;c[K+4876>>2]=y;c[K+70412>>2]=y;c[K+135948>>2]=y;y=c[2430206]|0;c[K+5120>>2]=y;c[K+70656>>2]=y;c[K+136192>>2]=y;s=y+1024|0;c[K+5124>>2]=s;c[K+70660>>2]=s;c[K+136196>>2]=s;s=y+2048|0;c[K+5128>>2]=s;c[K+70664>>2]=s;c[K+136200>>2]=s;s=y+3072|0;c[K+5132>>2]=s;c[K+70668>>2]=s;c[K+136204>>2]=s;s=y+4096|0;c[K+5136>>2]=s;c[K+70672>>2]=s;c[K+136208>>2]=s;s=y+5120|0;c[K+5140>>2]=s;c[K+70676>>2]=s;c[K+136212>>2]=s;s=y+6144|0;c[K+5144>>2]=s;c[K+70680>>2]=s;c[K+136216>>2]=s;s=y+7168|0;c[K+5148>>2]=s;c[K+70684>>2]=s;c[K+136220>>2]=s;c[K+196688>>2]=3012;c[K+196728>>2]=724;c[K+196608>>2]=1594;c[K+196648>>2]=1652}else{s=r+2048|0;c[K+4616>>2]=s;c[K+70152>>2]=s;c[K+135688>>2]=s;s=r+3072|0;c[K+4620>>2]=s;c[K+70156>>2]=s;c[K+135692>>2]=s;s=c[2432698]|0;c[K+4624>>2]=s;c[K+70160>>2]=s;c[K+135696>>2]=s;y=s+1024|0;c[K+4628>>2]=y;c[K+70164>>2]=y;c[K+135700>>2]=y;y=s+2048|0;c[K+4632>>2]=y;c[K+70168>>2]=y;c[K+135704>>2]=y;y=s+3072|0;c[K+4636>>2]=y;c[K+70172>>2]=y;c[K+135708>>2]=y;y=c[2432694]|0;c[K+4640>>2]=y;c[K+70176>>2]=y;c[K+135712>>2]=y;s=y+1024|0;c[K+4644>>2]=s;c[K+70180>>2]=s;c[K+135716>>2]=s;s=y+2048|0;c[K+4648>>2]=s;c[K+70184>>2]=s;c[K+135720>>2]=s;s=y+3072|0;c[K+4652>>2]=s;c[K+70188>>2]=s;c[K+135724>>2]=s;s=c[2430216]|0;c[K+4656>>2]=s;c[K+70192>>2]=s;c[K+135728>>2]=s;y=s+1024|0;c[K+4660>>2]=y;c[K+70196>>2]=y;c[K+135732>>2]=y;y=s+2048|0;c[K+4664>>2]=y;c[K+70200>>2]=y;c[K+135736>>2]=y;y=s+3072|0;c[K+4668>>2]=y;c[K+70204>>2]=y;c[K+135740>>2]=y;y=z+16384|0;c[K+4672>>2]=y;c[K+70208>>2]=y;c[K+135744>>2]=y;y=z+17408|0;c[K+4676>>2]=y;c[K+70212>>2]=y;c[K+135748>>2]=y;y=z+18432|0;c[K+4680>>2]=y;c[K+70216>>2]=y;c[K+135752>>2]=y;y=z+19456|0;c[K+4684>>2]=y;c[K+70220>>2]=y;c[K+135756>>2]=y;y=c[2432696]|0;c[K+4864>>2]=y;c[K+70400>>2]=y;c[K+135936>>2]=y;s=y+1024|0;c[K+4868>>2]=s;c[K+70404>>2]=s;c[K+135940>>2]=s;s=y+2048|0;c[K+4872>>2]=s;c[K+70408>>2]=s;c[K+135944>>2]=s;s=y+3072|0;c[K+4876>>2]=s;c[K+70412>>2]=s;c[K+135948>>2]=s;s=c[2430206]|0;c[K+5120>>2]=s;c[K+70656>>2]=s;c[K+136192>>2]=s;y=s+1024|0;c[K+5124>>2]=y;c[K+70660>>2]=y;c[K+136196>>2]=y;y=s+2048|0;c[K+5128>>2]=y;c[K+70664>>2]=y;c[K+136200>>2]=y;y=s+3072|0;c[K+5132>>2]=y;c[K+70668>>2]=y;c[K+136204>>2]=y;y=s+4096|0;c[K+5136>>2]=y;c[K+70672>>2]=y;c[K+136208>>2]=y;y=s+5120|0;c[K+5140>>2]=y;c[K+70676>>2]=y;c[K+136212>>2]=y;y=s+6144|0;c[K+5144>>2]=y;c[K+70680>>2]=y;c[K+136216>>2]=y;y=s+7168|0;c[K+5148>>2]=y;c[K+70684>>2]=y;c[K+136220>>2]=y;c[K+196688>>2]=2214;c[K+196728>>2]=2612;c[K+196608>>2]=1160;c[K+196648>>2]=1420}y=c[3532592]|0;if((y|0)!=0){gGC(y|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);y=c[2439330]|0;if((y|0)!=0){s=y;gGC(9706056,s|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];s=c[3528484]|0;c[2076596]=s;n=c[2417276]|0;c[3541536]=n;c[1836236]=0;C=c[2438714]|0;x=0;B=0;while(1){c[y+76+(B<<2)>>2]=C+(B<<8);F=x+1&65535;if((F&65535)>239){L=0;M=0;break}else{x=F;B=F&65535}}while(1){B=C+(M<<8)|0;c[y+76+(M+512<<2)>>2]=B;c[y+76+(M+768<<2)>>2]=B;B=L+1&65535;if((B&65535)>239){break}else{L=B;M=B&65535}}C=c[2438716]|0;c[y+1036>>2]=C;B=C+256|0;c[y+1040>>2]=B;x=C+512|0;c[y+1044>>2]=x;z=C+768|0;c[y+1048>>2]=z;r=C+1024|0;c[y+1052>>2]=r;F=C+1280|0;c[y+1056>>2]=F;A=C+1536|0;c[y+1060>>2]=A;E=C+1792|0;c[y+1064>>2]=E;D=C+2048|0;c[y+1068>>2]=D;G=C+2304|0;c[y+1072>>2]=G;H=C+2560|0;c[y+1076>>2]=H;N=C+2816|0;c[y+1080>>2]=N;c[y+2060>>2]=C;c[y+2064>>2]=B;c[y+2068>>2]=x;c[y+2072>>2]=z;c[y+2076>>2]=r;c[y+2080>>2]=F;c[y+2084>>2]=A;c[y+2088>>2]=E;c[y+2092>>2]=D;c[y+2096>>2]=G;c[y+2100>>2]=H;c[y+2104>>2]=N;N=240;H=240;while(1){G=C+((H<<8)-61440)|0;c[y+76+(H+512<<2)>>2]=G;c[y+76+(H+768<<2)>>2]=G;G=N+1&65535;if((G&65535)>251){break}else{N=G;H=G&65535}}H=C+49152|0;c[y+1096>>2]=H;c[y+2120>>2]=H;c[y+3144>>2]=H;c[y+4168>>2]=H;c[y+4180>>2]=1614;c[y+4184>>2]=736;H=y;gGC(H|0,9706056,76)|0;c[2438118]=c[2433530];c[3528484]=s;c[2417276]=n;c[1836236]=-1;H=a[9680]|0;N=H?32e3:0;if(H){if(a[9624]|0){H=N*3|0;G=62500;while(1){if((G|0)>(H|0)){G=G>>1}else{O=1222;P=G;break}}}else{O=2462;P=N}c[2429380]=P;c[3542124]=O;mw(4e6,P);G=gGq(262144)|0;c[2406684]=G;gGz(G|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(4e6,11025)}c[(c[3531464]|0)+44344>>2]=224;h[745421]=.6;c[2436794]=1;h[745420]=.6;c[2436792]=2;Ux(0,7575,1);c[2407030]=102;c[2407068]=3;G=c[642608+(c[2436]<<2)>>2]|0;H=c[G+128>>2]|0;if((c[G+52>>2]&4|0)==0){c[2113068]=H;n=c[G+132>>2]|0;c[2113070]=n;c[2443814]=H;c[2440436]=n;Q=H;R=n}else{c[2113070]=H;n=c[G+132>>2]|0;c[2113068]=n;c[2440436]=H;c[2443814]=n;Q=n;R=H}H=ag(Q<<1,R)|0;n=gGq(H)|0;c[2112926]=n;if((n|0)!=0){gGz(n|0,0,H|0)}c[2405418]=0;c[2405420]=0;c[2405422]=0;c[2405424]=0;c[3527500]=0;c[3527508]=0;c[2430204]=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];H=c[3532592]|0;if((H|0)!=0){gGC(9104152,H|0,280)|0}c[2113054]=c[2113060]}RI();H=c[2394]|0;n=c[14130368+(H<<2)>>2]|0;if((n|0)!=0){gGC(n|0,9104152,280)|0}c[8452240+(H<<2)>>2]=c[2113054];c[2394]=-1;H=c[2439330]|0;n=(H|0)==0;if(!n){G=H;gGC(9706056,G|0,76)|0}G=c[2438118]|0;c[2433530]=G;s=c[3528484]|0;c[2076596]=s;y=c[2417276]|0;c[3541536]=y;c[1836236]=0;gGz(9706056,0,76);if(!n){n=H;gGC(n|0,9706056,76)|0}c[2438118]=G;c[3528484]=s;c[2417276]=y;c[1836236]=-1;c[2113156]=0;a[9628264]=0;c[2407033]=0;y=c[3541206]|0;c[3541190]=y;c[3541198]=y;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=y+256;c[3541199]=y+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=y+512;c[3541200]=y+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=y+768;c[3541201]=y+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;mx(0);w=0;i=e;return w|0}}while(0);c[2426712]=0;w=1;i=e;return w|0}function eec(){var b=0,d=0,e=0,f=0,g=0;b=c[3531464]|0;c[b+44344>>2]=0;c[b+44348>>2]=0;if((b|0)!=0){gGr(b);c[3531464]=0}b=c[2406684]|0;if((b|0)!=0){gGr(b);c[2406684]=0}Uw(0);if((c[2392]|0)>=0){b=0;do{d=14130368+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}d=14130384+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}b=b+1|0;}while((b|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;fwZ();c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}b=c[2426712]|0;d=0;while(1){if((d|0)>=1024){f=54631;break}g=9638528+(d<<2)|0;if((c[g>>2]|0)==(b|0)){break}else{d=d+1|0}}if((f|0)==54631){c[2426712]=0;a[673152]=0;a[680488]=0;return 0}gGr(b);c[g>>2]=0;c[2426712]=0;a[673152]=0;a[680488]=0;return 0}function eed(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;a=c[2437720]|0;b=c[2112926]|0;e=c[2432700]|0;f=0;g=0;while(1){h=f<<3;i=0;j=g;while(1){k=d[a+(j|1)|0]|0;l=k>>>4;m=k<<8&3840|(d[a+j|0]|0);k=(i<<3)-(c[3527508]|0)&511;n=h-(c[3527500]|0)&255;do{if((k-8|0)>>>0<240){if((n-8|0)>>>0>=208){o=54638;break}Sq(b,m,k,n,l,4,0,256,e)}else{o=54638}}while(0);if((o|0)==54638){o=0;Sr(b,m,k,n,l,4,0,256,e)}p=i+1|0;if((p|0)<64){i=p;j=j+2|0}else{break}}j=f+1|0;if((j|0)<32){f=j;g=g+128|0}else{break}}return}function eee(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;g=c[2432696]|0;h=a[680488]|0;i=c[2112926]|0;j=c[2429746]|0;k=0;do{l=b[g+(k<<1)>>1]|0;do{if((l&4)!=0){m=e[g+((k|1)<<1)>>1]|0;n=e[g+((k|2)<<1)>>1]|0;o=n>>>4&15;p=1<<(n&3);if(h){q=p}else{q=1<<(n>>>2&3)}n=(p|0)>1?m&65534:m;m=(q|0)>1?n&65533:n;n=(p|0)>3?m&65531:m;m=(q|0)>3?n&65527:n;n=(p|0)>7?m&65519:m;m=(q|0)>7?n&-33:n;n=l&65535;r=b[g+((k|4)<<1)>>1]|0;s=r&65535;t=r<<16>>16<0?s|-65536:s;s=b[g+((k|3)<<1)>>1]|0;r=s&65535;u=s<<16>>16<0?r|-65536:r;if(!((n>>>6&3|0)==(f|0)&(q|0)>0)){break}r=(p|0)>0;s=(n&1|0)!=0;v=p-1|0;w=(n&2|0)!=0;n=q-1|0;x=0;do{L72470:do{if(r){y=((w?n-x|0:x)<<3)+u|0;z=y-16|0;A=(y-24|0)>>>0>207;y=0;do{B=((s?v-y|0:y)<<3)+t|0;C=(d[596808+(x<<3)+y|0]|0)+m|0;if((C|0)>32767){break L72470}do{if((B-8|0)>>>0>239|A){if(s){if(w){Sx(i,C,B,z,o,4,0,0,j);break}else{St(i,C,B,z,o,4,0,0,j);break}}else{if(w){Sv(i,C,B,z,o,4,0,0,j);break}else{Sr(i,C,B,z,o,4,0,0,j);break}}}else{if(s){if(w){Sw(i,C,B,z,o,4,0,0,j);break}else{Ss(i,C,B,z,o,4,0,0,j);break}}else{if(w){Su(i,C,B,z,o,4,0,0,j);break}else{Sq(i,C,B,z,o,4,0,0,j);break}}}}while(0);y=y+1|0;}while((y|0)<(p|0))}}while(0);x=x+1|0;}while((x|0)<(q|0))}}while(0);k=k+8|0;}while((k|0)<2048);return}function eef(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;if((a[9757992]|0)!=0){c[2405418]=0;c[2405420]=0;c[2405422]=0;c[2405424]=0;c[3527500]=0;c[3527508]=0;c[2430204]=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060]}RI();f=c[2394]|0;g=c[14130368+(f<<2)>>2]|0;if((g|0)!=0){gGC(g|0,9104152,280)|0}c[8452240+(f<<2)>>2]=c[2113054];c[2394]=-1;f=c[2439330]|0;g=(f|0)==0;if(!g){h=f;gGC(9706056,h|0,76)|0}h=c[2438118]|0;c[2433530]=h;i=c[3528484]|0;c[2076596]=i;j=c[2417276]|0;c[3541536]=j;c[1836236]=0;gGz(9706056,0,76);if(!g){g=f;gGC(g|0,9706056,76)|0}c[2438118]=h;c[3528484]=i;c[2417276]=j;c[1836236]=-1;c[2113156]=0;a[9628264]=0;c[2407033]=0;j=c[3541206]|0;c[3541190]=j;c[3541198]=j;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=j+256;c[3541199]=j+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=j+512;c[3541200]=j+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=j+768;c[3541201]=j+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;mx(0)}b[4879001]=16383;b[4879e3]=16383;j=0;i=16383;while(1){k=(i&65535)-((a[9720848+j|0]&1)<<j)|0;h=j+1|0;if((h|0)<14){j=h;i=k&65535}else{break}}b[4879e3]=(d[9720862]<<14&16384|k|d[9720863]<<15)&65535;b[4879001]=(((((a[9720840]&1^16383)-(d[9720841]<<1&2)&65535)-(d[9720842]<<2&4)&65535)-(d[9720843]<<3&8)&65535)-(d[9720844]<<4&16)&65535)-(d[9720845]<<5&32)&65535;a[6518216]=1;a[6517984]=1;c[2444079]=0;c[2444078]=0;k=c[2392]|0;if((k|0)>=0){gGz(8452240,0,((k|0)>0?(k<<2)+4|0:4)|0)}c[2113054]=0;if((c[2394]|0)==0){l=0;m=0}else{c[2394]=0;c[2112932]=c[3532596];k=c[3532592]|0;if((k|0)!=0){gGC(9104152,k|0,280)|0}c[2113054]=c[2113060];l=0;m=0}L72530:while(1){k=m;do{if((k|0)>=10){break L72530}k=k+1|0;i=(ag(a[6518216]|0?2e5:0,k)|0)/10|0;j=i-(c[2444078]|0)|0;c[2438186]=j;c[2113056]=j;i=RG(j)|0;c[2113054]=(c[2113054]|0)+i;c[2276108]=-1;c[2113056]=-1;c[2444078]=(c[2444078]|0)+i;i=c[2439330]|0;if((i|0)!=0){j=i;gGC(9706056,j|0,76)|0}b[4853030]=c[2426515]&65535;j=c[2438118]|0;c[2433530]=j;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;h=(ag(a[6517984]|0?66666:0,k)|0)/10|0;g=c[2444079]|0;f=h-g|0;c[2438186]=f;do{if((f|0)<1){n=0;o=g;p=0;q=i;r=j}else{if((a[i+4188|0]|0)==0){h=gfc(f)|0;s=(c[2433530]|0)+h|0;c[2433530]=s;t=c[1836236]|0;n=h;o=c[2444079]|0;p=t;q=c[9757320+(t<<2)>>2]|0;r=s;break}else{s=j+f|0;c[2433530]=s;n=f;o=g;p=0;q=i;r=s;break}}}while(0);c[2438186]=n;c[2444079]=o+n;if((q|0)!=0){i=q;gGC(i|0,9706056,76)|0}c[9752472+(p<<2)>>2]=r;c[14113936+(p<<2)>>2]=c[2076596];c[9669104+(p<<2)>>2]=c[3541536];c[1836236]=-1;u=c[2112964]|0;}while((u|0)==0);i=a[9688]|0?53:0;g=u+(l<<1<<1)|0;f=c[2439330]|0;if((f|0)!=0){j=f;gGC(9706056,j|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;gg[c[3542124]&4095](g,i);j=c[1836236]|0;f=c[9757320+(j<<2)>>2]|0;if((f|0)!=0){s=f;gGC(s|0,9706056,76)|0}c[9752472+(j<<2)>>2]=c[2433530];c[14113936+(j<<2)>>2]=c[2076596];c[9669104+(j<<2)>>2]=c[3541536];c[1836236]=-1;Uu(0,g,i);l=i+l|0;m=k}m=c[2394]|0;c[8452200+(m<<2)>>2]=8197;c[2276080]=1280;if((c[2276079]|0)>>>0<1280){RH(5);v=c[2394]|0}else{v=m}m=c[14130368+(v<<2)>>2]|0;if((m|0)!=0){gGC(m|0,9104152,280)|0}c[8452240+(v<<2)>>2]=c[2113054];c[2394]=-1;v=c[2112964]|0;do{if((v|0)!=0){m=a[9688]|0?534:0;u=m-l|0;p=v+(l<<1<<1)|0;if((m|0)==(l|0)){break}m=c[2439330]|0;if((m|0)!=0){r=m;gGC(9706056,r|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;gg[c[3542124]&4095](p,u);r=c[1836236]|0;m=c[9757320+(r<<2)>>2]|0;if((m|0)!=0){q=m;gGC(q|0,9706056,76)|0}c[9752472+(r<<2)>>2]=c[2433530];c[14113936+(r<<2)>>2]=c[2076596];c[9669104+(r<<2)>>2]=c[3541536];c[1836236]=-1;Uu(0,p,u)}}while(0);if((c[2112968]|0)==0){return 0}l=c[2430206]|0;v=c[2437718]|0;if(a[673152]|a[680488]){u=0;p=l;r=v;while(1){q=e[p>>1]|0;m=q>>>4&15;n=q>>>8;c[r>>2]=(n<<4|n&8)>>>3&31|(q<<4|q&8)<<8&63488|(m<<4|m)<<3&2016;m=u+1|0;if((m|0)<8192){u=m;p=p+2|0;r=r+4|0}else{break}}r=ag(c[2113068]|0,c[2113070]|0)|0;if((r|0)>0){p=c[2112926]|0;u=0;do{b[p+(u<<1)>>1]=768;u=u+1|0;}while((u|0)<(r|0))}eee(3);r=c[2432694]|0;u=c[2430216]|0;p=c[2112926]|0;m=c[2430208]|0;q=0;n=0;while(1){o=q<<4;i=0;g=n;while(1){j=d[r+(g|1)|0]<<8&7936|d[r+g|0];s=a[u+g|0]&15;f=(i<<4)-(c[2405420]|0)|0;t=o-(c[2405418]|0)|0;h=f&511;w=t&511;x=h>>>0>495?f|-512:h;h=w>>>0>495?t|-512:w;w=h-16|0;do{if((x-16|0)>>>0<224){if((h-32|0)>>>0>=192){y=54728;break}SG(p,j,x,w,s,4,0,768,m)}else{y=54728}}while(0);if((y|0)==54728){y=0;SH(p,j,x,w,s,4,0,768,m)}h=i+1|0;if((h|0)<64){i=h;g=g+2|0}else{break}}g=q+1|0;if((g|0)<32){q=g;n=n+128|0}else{break}}eee(2);n=c[2433430]|0;q=c[2432698]|0;u=0;r=0;while(1){g=u<<4;i=0;o=r;while(1){k=d[n+(o|1)|0]<<8&7936|d[n+o|0];h=a[q+o|0]&15;t=(i<<4)-(c[2405424]|0)|0;f=g-(c[2405422]|0)|0;z=t&511;A=f&511;B=z>>>0>495?t|-512:z;z=A>>>0>495?f|-512:A;A=z-16|0;do{if((B-16|0)>>>0<224){if((z-32|0)>>>0>=192){y=54736;break}SG(p,k,B,A,h,4,0,512,m)}else{y=54736}}while(0);if((y|0)==54736){y=0;SH(p,k,B,A,h,4,0,512,m)}z=i+1|0;if((z|0)<64){i=z;o=o+2|0}else{break}}o=u+1|0;if((o|0)<32){u=o;r=r+128|0}else{break}}eee(1);eed();eee(0);R8(v);return 0}else{r=0;u=l;l=v;while(1){m=e[u>>1]|0;p=m>>>4&15;q=m>>>8;c[l>>2]=(q<<4|q&8)>>>3&31|(m<<4|m&8)<<8&63488|(p<<4|p)<<3&2016;p=r+1|0;if((p|0)<8192){r=p;u=u+2|0;l=l+4|0}else{break}}l=ag(c[2113068]|0,c[2113070]|0)|0;if((l|0)>0){u=c[2112926]|0;r=0;do{b[u+(r<<1)>>1]=768;r=r+1|0;}while((r|0)<(l|0))}eee(3);l=c[2432694]|0;r=c[2430216]|0;u=c[2112926]|0;p=c[2430208]|0;m=0;q=0;while(1){n=m<<4;o=0;i=q;while(1){g=d[l+(i|1)|0]<<8&7936|d[l+i|0];z=a[r+i|0]&15;s=(o<<4)-(c[2405420]|0)|0;w=n-(c[2405418]|0)|0;x=s&511;j=w&511;f=x>>>0>495?s|-512:x;x=j>>>0>495?w|-512:j;j=x-16|0;do{if((f-16|0)>>>0<224){if((x-32|0)>>>0>=192){y=54749;break}SG(u,g,f,j,z,4,0,768,p)}else{y=54749}}while(0);if((y|0)==54749){y=0;SH(u,g,f,j,z,4,0,768,p)}x=o+1|0;if((x|0)<32){o=x;i=i+2|0}else{break}}i=m+1|0;if((i|0)<32){m=i;q=q+64|0}else{break}}eee(2);q=c[2433430]|0;m=c[2432698]|0;r=0;l=0;while(1){i=r<<4;o=0;n=l;while(1){x=d[q+(n|1)|0]<<8&7936|d[q+n|0];h=a[m+n|0]&15;A=(o<<4)-(c[2405424]|0)|0;B=i-(c[2405422]|0)|0;k=A&511;w=B&511;s=k>>>0>495?A|-512:k;k=w>>>0>495?B|-512:w;w=k-16|0;do{if((s-16|0)>>>0<224){if((k-32|0)>>>0>=192){y=54757;break}SG(u,x,s,w,h,4,0,512,p)}else{y=54757}}while(0);if((y|0)==54757){y=0;SH(u,x,s,w,h,4,0,512,p)}k=o+1|0;if((k|0)<32){o=k;n=n+2|0}else{break}}n=r+1|0;if((n|0)<32){r=n;l=l+64|0}else{break}}eee(1);eed();eee(0);R8(v);return 0}return 0}function eeg(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3941532+(b*112|0)>>2];c[a+104>>2]=c[3941536+(b*112|0)>>2];c[a+108>>2]=c[3941540+(b*112|0)>>2];d=0;return d|0}function eeh(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=3941432+(b*112|0);e=0;return e|0}function eei(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1264216+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eej(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>43){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3942440+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eek(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;f=i;i=i+272|0;g=f|0;h=f+16|0;j=f+32|0;k=f+48|0;l=f+64|0;m=f+80|0;n=f+96|0;o=f+112|0;p=f+128|0;q=f+144|0;r=f+160|0;s=f+176|0;t=f+192|0;u=f+208|0;v=f+224|0;w=f+240|0;x=f+256|0;if((e|0)!=0){c[e>>2]=10564}if((b&32|0)!=0){gGz(x|0,0,12);e=c[2405646]|0;c[x>>2]=e;c[x+4>>2]=(c[2411640]|0)-e;c[x+12>>2]=162152;e=c[2076592]|0;gj[e&4095](x)|0}if((b&64|0)==0){i=f;return 0}x=l|0;gGz(k|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){e=l+9|0;l=j;y=j|0;z=j+4|0;A=j+12|0;B=k|0;C=k+4|0;D=k+12|0;E=0;do{gGC(x|0,614896,11)|0;a[e]=E+48&255;F=8452256+(E<<2)|0;gGz(l|0,0,12);c[y>>2]=F;c[z>>2]=4;c[A>>2]=164976;gj[c[2076592]&4095](j)|0;if((c[F>>2]|0)!=0){c[B>>2]=c[14130368+(E<<2)>>2];c[C>>2]=c[8452184+(E<<2)>>2];c[D>>2]=x;F=c[2076592]|0;gj[F&4095](k)|0}E=E+1|0;}while((E|0)<=(c[2392]|0))}fw$(b);Ut(0);gGz(h|0,0,12);c[h>>2]=8453216;c[h+4>>2]=4;c[h+12>>2]=107480;gj[c[2076592]&4095](h)|0;gGz(g|0,0,12);c[g>>2]=14168504;c[g+4>>2]=256;c[g+12>>2]=476464;gj[c[2076592]&4095](g)|0;if((b&2|0)!=0){b=0;do{mv(0,b,d[14168504+b|0]|0);b=b+1|0;}while((b|0)<256)}gGz(w|0,0,12);c[w>>2]=9720816;c[w+4>>2]=4;c[w+12>>2]=87824;gj[c[2076592]&4095](w)|0;gGz(v|0,0,12);c[v>>2]=9758e3;c[v+4>>2]=4;c[v+12>>2]=85816;gj[c[2076592]&4095](v)|0;gGz(u|0,0,12);c[u>>2]=14108832;c[u+4>>2]=2;c[u+12>>2]=83928;gj[c[2076592]&4095](u)|0;gGz(t|0,0,12);c[t>>2]=14110032;c[t+4>>2]=4;c[t+12>>2]=147384;gj[c[2076592]&4095](t)|0;gGz(s|0,0,12);c[s>>2]=1411e4;c[s+4>>2]=4;c[s+12>>2]=117784;gj[c[2076592]&4095](s)|0;gGz(r|0,0,12);c[r>>2]=9621696;c[r+4>>2]=4;c[r+12>>2]=78616;gj[c[2076592]&4095](r)|0;gGz(q|0,0,12);c[q>>2]=9621688;c[q+4>>2]=4;c[q+12>>2]=76632;gj[c[2076592]&4095](q)|0;gGz(p|0,0,12);c[p>>2]=9621680;c[p+4>>2]=4;c[p+12>>2]=74352;gj[c[2076592]&4095](p)|0;gGz(o|0,0,12);c[o>>2]=9621672;c[o+4>>2]=4;c[o+12>>2]=71944;gj[c[2076592]&4095](o)|0;gGz(n|0,0,12);c[n>>2]=9776312;c[n+4>>2]=8;c[n+12>>2]=212472;gj[c[2076592]&4095](n)|0;gGz(m|0,0,12);c[m>>2]=9752744;c[m+4>>2]=4;c[m+12>>2]=436576;gj[c[2076592]&4095](m)|0;i=f;return 0}function eel(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1913812+(b*112|0)>>2];c[a+104>>2]=c[1913816+(b*112|0)>>2];c[a+108>>2]=c[1913820+(b*112|0)>>2];d=0;return d|0}function eem(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=1913712+(b*112|0);e=0;return e|0}function een(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6289356+(b*112|0)>>2];c[a+104>>2]=c[6289360+(b*112|0)>>2];c[a+108>>2]=c[6289364+(b*112|0)>>2];d=0;return d|0}function eeo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=6289256+(b*112|0);e=0;return e|0}function eep(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>30){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6290264+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eeq(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7159228+(b*112|0)>>2];c[a+104>>2]=c[7159232+(b*112|0)>>2];c[a+108>>2]=c[7159236+(b*112|0)>>2];d=0;return d|0}function eer(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=7159128+(b*112|0);e=0;return e|0}function ees(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6147512+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eet(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>33){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7160136+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eeu(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=c>>>7&1;f=c>>>8<<1&2|e;g=c>>>12&1;h=c>>>2&1;i=g<<1|h;if((f|0)==2){j=d>>>11&1|d<<6&64|d>>>13<<14&16384|d>>>2<<15&32768|d>>>15<<13&8192|d>>>1<<12&4096|d>>>12<<11&2048|d>>>8<<10&1024|d>>>14<<9&512|d>>>4<<8&256|d>>>6<<7&128|d>>>9<<5&32|d>>>5<<4&16|d>>>10<<3&8|d>>>7<<2&4|d>>>3<<1&2}else if((f|0)==1){j=d>>>2&1|d<<6&64|d>>>10<<14&16384|d>>>14<<15&32768|d>>>4<<13&8192|d>>>15<<12&4096|d>>>1<<11&2048|d>>>6<<10&1024|d>>>12<<9&512|d>>>11<<8&256|d>>>8<<7&128|d>>>9<<5&32|d>>>13<<4&16|d>>>7<<3&8|d>>>3<<2&4|d>>>5<<1&2}else if((f|0)==3){j=d>>>5&1|d<<8&256|d>>>8<<14&16384|d>>>3<<15&32768|d>>>1<<13&8192|d>>>13<<12&4096|d>>>14<<11&2048|d>>>4<<10&1024|d>>>15<<9&512|d>>>10<<7&128|d>>>2<<6&64|d>>>7<<5&32|d>>>12<<4&16|d>>>6<<3&8|d>>>11<<2&4|d>>>9<<1&2}else if((f|0)==0){j=d<<13&8192|d&256|d>>>9&1|d>>>2<<14&16384|d>>>1<<15&32768|d>>>14<<12&4096|d>>>12<<11&2048|d>>>15<<10&1024|d>>>4<<9&512|d>>>13<<7&128|d>>>7<<6&64|d>>>3<<5&32|d>>>6<<4&16|d>>>11<<3&8|d>>>5<<2&4|d>>>10<<1&2}else{j=0}f=j^16936;if((i|0)==1){j=c>>>1&1;k=(f+((c&1|b&8|b>>>15<<5|b>>>8<<4&16|j<<1|j<<2)^a)&63|f&65472)^a;l=h|b>>>4<<1&2|c>>>14<<2&4|g<<4|k>>>1<<3&8;m=k}else if((i|0)==3){l=b>>>5<<2&4|h|b>>>10<<4&16|c>>>9<<1&2|c>>>1<<3&8;m=(f+((b>>>9<<1&2|b&1|b>>>6<<2&4|b>>>2<<4&16|c>>>11<<5|c>>>4<<3&8)^a)&63|f&65472)^a}else if((i|0)==0){h=(f+(a^58)&63|f&65472)^a;l=d>>>5<<2&4|d>>>9&1|h&16|h>>>2<<1&2|h>>>5<<3&8;m=h}else if((i|0)==2){i=(f+((b>>>5&1|b&8|b>>>14<<5|b>>>7<<2&4|b>>>13<<4&16|c>>>5<<1&2)^a)&63|f&65472)^a;l=c>>>6<<1&2|b>>>6&1|c>>>15<<2&4|e<<4|i<<3&8;m=i}else{l=a;m=(f+a&63|f&65472)^a}f=l^a;l=((f<<6)+m&1984|m&63|(f<<11)+m&63488)^(a<<6|a<<11);return l>>>15&1|l<<13&8192|l>>>6<<14&16384|l>>>2<<15&32768|l>>>11<<12&4096|l>>>14<<11&2048|l>>>12<<10&1024|l>>>7<<9&512|l>>>10<<8&256|l>>>5<<7&128|l>>>4<<6&64|l>>>8<<5&32|l>>>3<<4&16|l>>>9<<3&8|l>>>1<<2&4|l>>>13<<1&2|0}function eev(a,d){a=a|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;if((a&16760832|0)==1048576){e=a&16382;f=e>>>1;g=d&65535;h=c[2426998]|0;i=c[2276056]|0;do{if((c[2384558]|0)==(i|0)){if(((c[2384564]|0)+1|0)!=(f|0)){j=54880;break}c[2384558]=0;k=eeu(h,c[2384560]|0,c[2384562]|0,g)|0}else{j=54880}}while(0);if((j|0)==54880){c[2384558]=i;c[2384564]=f;c[2384560]=g;f=eeu(h,0,0,g)|0;c[2384562]=f;k=f}b[(c[2386210]|0)+e>>1]=k&65535;return}if((a|0)==1081344|(a|0)==1081345|(a|0)==1081346|(a|0)==1081347|(a|0)==1081348|(a|0)==1081349|(a|0)==1081350|(a|0)==1081351){b[(c[3529386]|0)+(a&6)>>1]=d;return}else if((a|0)==7340047|(a|0)==7340046){Uv(0,d&255);return}else if((a|0)==7340044|(a|0)==7340045){a=d&15;if((c[2394740]|0)==(a|0)){return}c[2394740]=a;d=c[2386640]|0;k=d+196608|0;e=d+((a<<16)+262144)|0;gGC(k|0,e|0,65536)|0;return}else{return}}function eew(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0;if((b&16760832|0)==1048576){return}if((b|0)==7340045|(b|0)==7340044){e=d&15;if((c[2394740]|0)==(e|0)){return}c[2394740]=e;f=c[2386640]|0;g=f+196608|0;h=f+((e<<16)+262144)|0;gGC(g|0,h|0,65536)|0;return}else if((b|0)==7340047|(b|0)==7340046){if((c[2439274]|0)==0){Uv(0,d);return}else{a[c[3528266]|0]=d;f44(1);f45(0)|0;a[9660787]=0;f45(0)|0;return}}else{return}}function eex(a){a=a|0;var e=0;switch(a|0){case 7340038:case 7340039:{e=b[4775221]|0;break};case 7340040:case 7340041:{e=b[4775222]|0;break};case 7340032:case 7340033:{e=d[9635041]|0;break};case 7340034:case 7340035:{e=d[9635040]|0;break};case 7340046:case 7340047:{e=c[2113156]&65535;break};case 7340036:case 7340037:{e=b[4775220]|0;break};default:{e=0}}return e|0}function eey(d){d=d|0;var e=0;switch(d|0){case 7340040:case 7340041:{e=b[4775222]&255;break};case 7340036:case 7340037:{e=b[4775220]&255;break};case 7340034:case 7340035:{e=a[9635040]|0;break};case 7340038:case 7340039:{e=b[4775221]&255;break};case 7340046:case 7340047:{e=c[2113156]&255;break};case 7340032:case 7340033:{e=a[9635041]|0;break};default:{e=0}}return e|0}function eez(a,d){a=a|0;d=d|0;var e=0;if((a&16775168|0)!=2097152){return}e=a&2046;b[(c[2387184]|0)+e>>1]=d;a=d&65535;d=a>>>5&31;c[(c[3529992]|0)+(e>>>1<<2)>>2]=a>>>10&31|a<<11&63488|(d<<3|d>>>2)<<3&2016;return}function eeA(b,d){b=b|0;d=d|0;var f=0;if((b&16775168|0)!=2097152){return}f=c[2387184]|0;a[f+(b&2047^1)|0]=d;d=b&2046;b=e[f+d>>1]|0;f=b>>>5&31;c[(c[3529992]|0)+(d>>>1<<2)>>2]=b>>>10&31|b<<11&63488|(f<<3|f>>>2)<<3&2016;return}function eeB(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3089124+(b*112|0)>>2];c[a+104>>2]=c[3089128+(b*112|0)>>2];c[a+108>>2]=c[3089132+(b*112|0)>>2];d=0;return d|0}function eeC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=3089024+(b*112|0);e=0;return e|0}function eeD(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1311360+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eeE(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>52){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4240040+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eeF(){return ee3(2494,0,1)|0}function eeG(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}b=a[7452584]|0;if(b){d=0;e=b&1;while(1){b=14163936+(d<<2)|0;f=c[b>>2]|0;g=c[2113006]|0;if((g|0)==0){h=54967}else{i=g-1|0;c[2113006]=i;if((i|0)==0){h=54967}}if((h|0)==54967){h=0;c[2383474]=0}if((f|0)==0){j=e}else{gGr(f);j=a[7452584]&1}c[b>>2]=0;b=d+1|0;if((b|0)<(j|0)){d=b;e=j}else{break}}}a[7452584]=0;c[2438224]=0;c[2433522]=0;c[2406672]=0;c[3528468]=0;j=c[2406688]|0;if((j|0)!=0){gGr(j);c[2406688]=0}c[2432972]=0;Uw(0);c[3541206]=0;if((c[2392]|0)>=0){j=0;do{e=14130368+(j<<2)|0;d=c[e>>2]|0;if((d|0)!=0){gGr(d);c[e>>2]=0}e=14130384+(j<<2)|0;d=c[e>>2]|0;if((d|0)!=0){gGr(d);c[e>>2]=0}j=j+1|0;}while((j|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;c[2113160]=0;j=c[2433592]|0;if((j|0)!=0){gGr(j);c[2433592]=0}j=c[2414950]|0;e=0;while(1){if((e|0)>=1024){h=54986;break}k=9638528+(e<<2)|0;if((c[k>>2]|0)==(j|0)){break}else{e=e+1|0}}if((h|0)==54986){c[2414950]=0;return 0}gGr(j);c[k>>2]=0;c[2414950]=0;return 0}function eeH(){var e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;if((a[9624088]|0)!=0){e=c[2414654]|0;gGz(e|0,0,(c[2411638]|0)-e|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060]}RI();e=c[2394]|0;f=c[14130368+(e<<2)>>2]|0;if((f|0)!=0){gGC(f|0,9104152,280)|0}c[8452240+(e<<2)>>2]=c[2113054];c[2394]=-1;c[3528554]=0;f43(c[2433592]|0);e=c[3528554]|0;c[2113158]=c[9731360+(e<<2)>>2];a[9660796]=0;a[9660797]=0;a[9660786]=0;a[9660787]=0;c[2415191]=0;a[9660784]=a[9660784]|80;f=c[2433592]|0;g=c[f+(e*3148|0)+1068>>2]|0;do{if((g|0)==0){i=c[f+(e*3148|0)+3120>>2]|0;if((i|0)==0){j=0;k=0;l=e;m=f;break}n=gj[i&4095](-2)|0;i=c[3528554]|0;o=c[2433592]|0;p=c[o+(i*3148|0)+1068>>2]|0;q=(n&255)<<8;if((p|0)!=0){r=p;s=q;t=i;u=o;v=54999;break}p=c[o+(i*3148|0)+3120>>2]|0;if((p|0)==0){j=0;k=q;l=i;m=o;break}o=gj[p&4095](-1)|0;j=o;k=q;l=c[3528554]|0;m=c[2433592]|0}else{r=g;s=d[g+254|0]<<8;t=e;u=f;v=54999}}while(0);if((v|0)==54999){j=a[r+255|0]|0;k=s;l=t;m=u}u=j&255|k;c[2415188]=u;b[4830376]=u&65535;u=m+(l*3148|0)|0;if((u|0)!=0){m=u;gGC(m|0,9660752,48)|0}c[9731360+(l<<2)>>2]=c[2113158];c[3528554]=-1;c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;lw(c[3540984]|0);c[2113156]=0;a[9628264]=0;c[2407033]=0;l=c[3541206]|0;c[3541190]=l;c[3541198]=l;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=l+256;c[3541199]=l+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=l+512;c[3541200]=l+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=l+768;c[3541201]=l+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;l=c[2386640]|0;m=l+262144|0;gGC(l|0,m|0,196608)|0;c[2394740]=3;m=l+196608|0;u=l+458752|0;gGC(m|0,u|0,65536)|0}u=c[2113160]|0;if((u|0)>0){gGz(9731360,0,((u|0)>1?u<<2:4)|0)}c[2113158]=0;gGz(9550440,-1|0,6);u=0;m=-1;l=-1;k=-1;do{m=((a[9633312+u|0]&1)<<u^m&65535)&65535;l=((a[9631184+u|0]&1)<<u^l&65535)&65535;k=((a[9629512+u|0]&1)<<u^k&65535)&65535;u=u+1|0;}while((u|0)<16);b[4775220]=m;b[4775221]=l;b[4775222]=a[9635042]&2|k&-3;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];k=c[3532592]|0;if((k|0)!=0){gGC(9104152,k|0,280)|0}c[2113054]=c[2113060]}c[3528554]=0;f43(c[2433592]|0);c[2113158]=c[9731360+(c[3528554]<<2)>>2];c[2113056]=166666;k=RG(166666)|0;c[2113054]=(c[2113054]|0)+k;c[2276108]=-1;c[2113056]=-1;c[8452200+(c[2394]<<2)>>2]=8198;c[2276080]=1536;if((c[2276079]|0)>>>0<1536){RH(6)}if((c[2112964]|0)!=0){k=c[2438224]|0;l=gGS(-1078853632,17616,k,(k|0)<0|0?-1:0)|0;k=l;UF(36945)|0;l=c[2443826]|0;if((l|0)<1073676288){c[2443826]=l-k}l=c[2443827]|0;if((l|0)<1073676288){c[2443827]=l-k}l=(c[3528508]|0)-k|0;c[3528508]=(l|0)<0?0:l;gg[c[3542112]&4095](c[2112964]|0,a[9688]|0?534:0);Uu(0,c[2112964]|0,a[9688]|0?534:0)}l=c[2394]|0;k=c[14130368+(l<<2)>>2]|0;if((k|0)!=0){gGC(k|0,9104152,280)|0}c[8452240+(l<<2)>>2]=c[2113054];c[2394]=-1;l=c[3528554]|0;k=(c[2433592]|0)+(l*3148|0)|0;if((k|0)!=0){m=k;gGC(m|0,9660752,48)|0}c[9731360+(l<<2)>>2]=c[2113158];c[3528554]=-1;if((c[2112968]|0)==0){return 0}eeI()|0;return 0}function eeI(){var b=0,d=0,f=0,g=0,h=0,i=0;if((a[9547400]|0)==0){b=c[3529992]|0}else{d=c[2387184]|0;f=c[3529992]|0;g=0;do{h=e[d+g>>1]|0;i=h>>>5&31;c[f+(g>>>1<<2)>>2]=h>>>10&31|h<<11&63488|(i<<3|i>>>2)<<3&2016;g=g+2|0;}while((g|0)<2048);a[9547400]=0;b=f}gGz(c[2439590]|0,0,76800);f=c[2112926]|0;gGz(f|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);efa(4096,255,3,0);efa(0,255,3,0);efa(4096,65281,3,1);efa(0,65281,3,1);efa(4096,255,2,1);efa(0,255,2,1);efa(4096,65281,2,2);efa(0,65281,2,2);efa(4096,255,1,2);efa(0,255,1,2);efa(4096,65281,1,4);efa(0,65281,1,4);efa(4096,255,0,4);efa(0,255,0,4);efa(4096,65281,0,8);efa(0,65281,0,8);efb();R8(b);return 0}function eeJ(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;e=i;i=i+160|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;l=e+80|0;m=e+96|0;n=e+112|0;o=e+128|0;p=e+144|0;if((d|0)!=0){c[d>>2]=169624}if((b&32|0)!=0){gGz(p|0,0,12);q=c[2414654]|0;c[p>>2]=q;c[p+4>>2]=(c[2411638]|0)-q;c[p+12>>2]=162152;q=c[2076592]|0;gj[q&4095](p)|0}if((b&64|0)!=0){p=n|0;gGz(m|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){q=n+9|0;n=l;r=l|0;s=l+4|0;t=l+12|0;u=m|0;v=m+4|0;w=m+12|0;x=0;do{gGC(p|0,614896,11)|0;a[q]=x+48&255;y=8452256+(x<<2)|0;gGz(n|0,0,12);c[r>>2]=y;c[s>>2]=4;c[t>>2]=164976;gj[c[2076592]&4095](l)|0;if((c[y>>2]|0)!=0){c[u>>2]=c[14130368+(x<<2)>>2];c[v>>2]=c[8452184+(x<<2)>>2];c[w>>2]=p;y=c[2076592]|0;gj[y&4095](m)|0}x=x+1|0;}while((x|0)<=(c[2392]|0))}x=k|0;if((c[2113160]|0)>0){m=k+7|0;k=j|0;p=j+4|0;w=j+12|0;v=h;u=h|0;l=h+4|0;t=h+12|0;s=g;r=g|0;n=g+4|0;q=g+12|0;y=f;z=f|0;A=f+4|0;B=f+12|0;C=0;do{D=c[2433592]|0;E=D+(C*3148|0)+40|0;F=c[E>>2]|0;gGC(x|0,614752,9)|0;a[m]=C+48&255;c[k>>2]=D+(C*3148|0);c[p>>2]=48;c[w>>2]=x;gj[c[2076592]&4095](j)|0;gGz(v|0,0,12);c[u>>2]=D+(C*3148|0)+3136;c[l>>2]=4;c[t>>2]=165288;gj[c[2076592]&4095](h)|0;gGz(s|0,0,12);c[r>>2]=D+(C*3148|0)+3140;c[n>>2]=4;c[q>>2]=501592;gj[c[2076592]&4095](g)|0;gGz(y|0,0,12);c[z>>2]=D+(C*3148|0)+3144;c[A>>2]=4;c[B>>2]=386080;gj[c[2076592]&4095](f)|0;c[E>>2]=F;C=C+1|0;}while((C|0)<(c[2113160]|0))}UQ(b,d);Ut(0);gGz(o|0,0,12);c[o>>2]=9578960;c[o+4>>2]=4;c[o+12>>2]=573936;d=c[2076592]|0;gj[d&4095](o)|0}if((b&2|0)==0){i=e;return 0}b=c[2394740]&15;c[2394740]=b;o=c[2386640]|0;d=o+196608|0;C=o+((b<<16)+262144)|0;gGC(d|0,C|0,65536)|0;i=e;return 0}function eeK(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2615444+(b*112|0)>>2];c[a+104>>2]=c[2615448+(b*112|0)>>2];c[a+108>>2]=c[2615452+(b*112|0)>>2];d=0;return d|0}function eeL(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=2615344+(b*112|0);e=0;return e|0}function eeM(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6926528+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eeN(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>39){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3766656+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eeO(){return ee3(3818,0,0)|0}function eeP(){var e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;if((a[9624088]|0)!=0){e=c[2414654]|0;gGz(e|0,0,(c[2411638]|0)-e|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060]}RI();e=c[2394]|0;f=c[14130368+(e<<2)>>2]|0;if((f|0)!=0){gGC(f|0,9104152,280)|0}c[8452240+(e<<2)>>2]=c[2113054];c[2394]=-1;c[3528554]=0;f43(c[2433592]|0);e=c[3528554]|0;c[2113158]=c[9731360+(e<<2)>>2];a[9660796]=0;a[9660797]=0;a[9660786]=0;a[9660787]=0;c[2415191]=0;a[9660784]=a[9660784]|80;f=c[2433592]|0;g=c[f+(e*3148|0)+1068>>2]|0;do{if((g|0)==0){i=c[f+(e*3148|0)+3120>>2]|0;if((i|0)==0){j=0;k=0;l=e;m=f;break}n=gj[i&4095](-2)|0;i=c[3528554]|0;o=c[2433592]|0;p=c[o+(i*3148|0)+1068>>2]|0;q=(n&255)<<8;if((p|0)!=0){r=p;s=q;t=i;u=o;v=55093;break}p=c[o+(i*3148|0)+3120>>2]|0;if((p|0)==0){j=0;k=q;l=i;m=o;break}o=gj[p&4095](-1)|0;j=o;k=q;l=c[3528554]|0;m=c[2433592]|0}else{r=g;s=d[g+254|0]<<8;t=e;u=f;v=55093}}while(0);if((v|0)==55093){j=a[r+255|0]|0;k=s;l=t;m=u}u=j&255|k;c[2415188]=u;b[4830376]=u&65535;u=m+(l*3148|0)|0;if((u|0)!=0){m=u;gGC(m|0,9660752,48)|0}c[9731360+(l<<2)>>2]=c[2113158];c[3528554]=-1;c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;lw(c[3540984]|0);c[2113156]=0;a[9628264]=0;c[2407033]=0;l=c[3541206]|0;c[3541190]=l;c[3541198]=l;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=l+256;c[3541199]=l+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=l+512;c[3541200]=l+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=l+768;c[3541201]=l+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;l=c[2386640]|0;m=l+262144|0;gGC(l|0,m|0,196608)|0;c[2394740]=3;m=l+196608|0;u=l+458752|0;gGC(m|0,u|0,65536)|0}gGz(9550440,-1|0,6);u=0;m=-1;l=-1;k=-1;do{m=((a[9633312+u|0]&1)<<u^m&65535)&65535;l=((a[9631184+u|0]&1)<<u^l&65535)&65535;k=((a[9629512+u|0]&1)<<u^k&65535)&65535;u=u+1|0;}while((u|0)<16);b[4775220]=m;b[4775221]=l;b[4775222]=k;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];k=c[3532592]|0;if((k|0)!=0){gGC(9104152,k|0,280)|0}c[2113054]=c[2113060]}c[2113056]=2e5;k=RG(2e5)|0;c[2113054]=(c[2113054]|0)+k;c[2276108]=-1;c[2113056]=-1;k=c[2394]|0;c[8452200+(k<<2)>>2]=8198;c[2276080]=1536;if((c[2276079]|0)>>>0<1536){RH(6);w=c[2394]|0}else{w=k}k=c[14130368+(w<<2)>>2]|0;if((k|0)!=0){gGC(k|0,9104152,280)|0}c[8452240+(w<<2)>>2]=c[2113054];c[2394]=-1;w=c[2112964]|0;if((w|0)!=0){Uu(0,w,a[9688]|0?534:0)}if((c[2112968]|0)==0){return 0}eeQ()|0;return 0}function eeQ(){var b=0,d=0,f=0,g=0,h=0,i=0;if((a[9547400]|0)==0){b=c[3529992]|0}else{d=c[2387184]|0;f=c[3529992]|0;g=0;do{h=e[d+g>>1]|0;i=h>>>5&31;c[f+(g>>>1<<2)>>2]=h>>>10&31|h<<11&63488|(i<<3|i>>>2)<<3&2016;g=g+2|0;}while((g|0)<2048);a[9547400]=0;b=f}gGz(c[2439590]|0,0,76800);f=c[2112926]|0;gGz(f|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);efa(4096,1,3,0);efa(0,1,3,0);efa(4096,1,2,1);efa(0,1,2,1);efa(4096,1,1,2);efa(0,1,1,2);efa(4096,1,0,4);efa(0,1,0,4);efb();R8(b);return 0}function eeR(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4812084+(b*112|0)>>2];c[a+104>>2]=c[4812088+(b*112|0)>>2];c[a+108>>2]=c[4812092+(b*112|0)>>2];d=0;return d|0}function eeS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=4811984+(b*112|0);e=0;return e|0}function eeT(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>41){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5572792+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eeU(){return ee3(2284,0,0)|0}function eeV(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3087780+(b*112|0)>>2];c[a+104>>2]=c[3087784+(b*112|0)>>2];c[a+108>>2]=c[3087788+(b*112|0)>>2];d=0;return d|0}function eeW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=3087680+(b*112|0);e=0;return e|0}function eeX(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5664940+(b*112|0)>>2];c[a+104>>2]=c[5664944+(b*112|0)>>2];c[a+108>>2]=c[5664948+(b*112|0)>>2];d=0;return d|0}function eeY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=5664840+(b*112|0);e=0;return e|0}function eeZ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>41){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6056192+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function ee_(){return ee3(3818,15,0)|0}function ee$(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6476476+(b*112|0)>>2];c[a+104>>2]=c[6476480+(b*112|0)>>2];c[a+108>>2]=c[6476484+(b*112|0)>>2];d=0;return d|0}function ee0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=6476376+(b*112|0);e=0;return e|0}function ee1(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>38){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6669488+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function ee2(){return ee3(350,14,0)|0}function ee3(e,f,g){e=e|0;f=f|0;g=g|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;c[2414950]=0;c[2388142]=0;c[3531190]=1048576;c[3530830]=1114112;c[3530594]=5308416;c[3541206]=9502720;c[2386640]=9502720;c[2414654]=10813440;c[2387184]=10813440;c[2388270]=10815488;c[2386210]=10881024;c[2386444]=10897408;c[3529386]=10901504;c[3531192]=10901512;c[3528266]=10903560;c[2411638]=10903561;c[3529992]=10903561;c[2439590]=10907657;i=0;while(1){if((i|0)>=1024){break}j=9638528+(i<<2)|0;if((c[j>>2]|0)==0){k=55197;break}else{i=i+1|0}}do{if((k|0)==55197){i=gGq(10984457)|0;c[j>>2]=i;if((i|0)==0){break}c[2414950]=i;gGz(i|0,0,10984457);c[2388142]=i;c[3531190]=i+1048576;c[3530830]=i+1114112;c[3530594]=i+5308416;l=i+9502720|0;c[3541206]=l;c[2386640]=l;l=i+10813440|0;c[2414654]=l;c[2387184]=l;c[2388270]=i+10815488;c[2386210]=i+10881024;c[2386444]=i+10897408;c[3529386]=i+10901504;c[3531192]=i+10901512;c[3528266]=i+10903560;l=i+10903561|0;c[2411638]=l;c[3529992]=l;c[2439590]=i+10907657;c[2414178]=i+10984457;L73172:do{if((e|0)!=0){if((gD[e&8191]()|0)==0){m=0}else{n=1;return n|0}while(1){if((m|0)>=1024){break L73172}o=9638528+(m<<2)|0;if((c[o>>2]|0)==0){break}else{m=m+1|0}}i=gGq(4194304)|0;c[o>>2]=i;if((i|0)==0){break}gGz(i|0,0,4194304);l=c[3530830]|0;gGC(i|0,l|0,4194304)|0;p=0;do{q=p<<6;gGz(l+q|0,0,64);r=0;do{s=1<<3-r;t=(c[611552+(r<<2)>>2]|0)+q|0;u=0;do{v=t+(c[609008+(u<<2)>>2]|0)|0;w=(u<<3)+q|0;x=0;do{y=v+(c[597864+(x<<2)>>2]|0)|0;if(((d[i+((y|0)/8|0)|0]|0)&128>>>((y&7)>>>0)|0)!=0){y=l+(w+x)|0;a[y]=(d[y]|0|s)&255}x=x+1|0;}while((x|0)<8);u=u+1|0;}while((u|0)<8);r=r+1|0;}while((r|0)<4);p=p+1|0;}while((p|0)<65536);p=c[3530594]|0;l=0;while(1){r=l<<8;gGz(p+r|0,0,256);q=0;do{u=1<<3-q;s=(c[611328+(q<<2)>>2]|0)+r|0;t=0;do{x=s+(c[609008+(t<<2)>>2]|0)|0;w=(t<<4)+r|0;v=0;do{y=x+(c[597864+(v<<2)>>2]|0)|0;if(((d[i+((y|0)/8|0)|0]|0)&128>>>((y&7)>>>0)|0)!=0){y=p+(w+v)|0;a[y]=(d[y]|0|u)&255}v=v+1|0;}while((v|0)<16);t=t+1|0;}while((t|0)<16);q=q+1|0;}while((q|0)<4);q=l+1|0;if((q|0)<16384){l=q}else{z=0;break}}while(1){if((z|0)>=1024){break L73172}A=9638528+(z<<2)|0;if((c[A>>2]|0)==(i|0)){break}else{z=z+1|0}}gGr(i);c[A>>2]=0}}while(0);fxU(0,425984);if((c[2394]|0)==0){B=c[2112932]|0}else{c[2394]=0;l=c[3532596]|0;c[2112932]=l;p=c[3532592]|0;if((p|0)!=0){gGC(9104152,p|0,280)|0}c[2113054]=c[2113060];B=l}l=c[2388142]|0;p=B|0;q=0;while(1){r=l+q|0;c[p>>2]=r;c[p+131072>>2]=r;r=q+1024|0;if(r>>>0>1048575){break}else{p=p+4|0;q=r}}fx$(c[2386210]|0,1048576,1064959,(f|0)!=0?5:7);q=c[2387184]|0;c[B+8192>>2]=q;c[B+139264>>2]=q;p=q+1024|0;c[B+8196>>2]=p;c[B+139268>>2]=p;p=c[2386444]|0;c[B+17408>>2]=p;c[B+82944>>2]=p;c[B+148480>>2]=p;q=p+1024|0;c[B+17412>>2]=q;c[B+82948>>2]=q;c[B+148484>>2]=q;q=p+2048|0;c[B+17416>>2]=q;c[B+82952>>2]=q;c[B+148488>>2]=q;q=p+3072|0;c[B+17420>>2]=q;c[B+82956>>2]=q;c[B+148492>>2]=q;q=c[2388270]|0;p=B+65280|0;l=16711680;while(1){r=q+(l-16711680)|0;c[p>>2]=r;c[p+65536>>2]=r;c[p+131072>>2]=r;r=l+1024|0;if(r>>>0>16777215){break}else{p=p+4|0;l=r}}c[B+196728>>2]=2476;c[B+196648>>2]=3358;c[B+196688>>2]=2540;c[B+196608>>2]=650;c[B+73728>>2]=1;c[B+73732>>2]=1;c[B+196732>>2]=1178;c[B+196652>>2]=1662;l=c[3532592]|0;if((l|0)!=0){gGC(l|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;c[2439274]=(g|0)!=0;c[3528554]=-1;c[2113160]=1;l=gGq(3148)|0;p=l;c[2433592]=p;if((l|0)!=0){gGz(l|0,0,3148);c[l+3120>>2]=3128;c[l+3124>>2]=1840;c[l+3128>>2]=136;c[l+3132>>2]=1902;c[2432840]=0;q=0;do{c[p+48+(q<<2)>>2]=0;q=q+1|0;}while((q|0)<768);c[2113158]=0;c[2415198]=0;q=c[2427044]|0;c[9681616+(q<<3)>>2]=809272;c[9681620+(q<<3)>>2]=0;c[2427044]=q+1}c[3528554]=0;f43(l);q=c[3528554]|0;p=9731360+(q<<2)|0;r=c[p>>2]|0;c[2113158]=r;t=c[3531192]|0;u=c[2433592]|0;c[u+(q*3148|0)+48>>2]=t;c[u+(q*3148|0)+1072>>2]=t;c[u+(q*3148|0)+2096>>2]=t;s=t+256|0;c[u+(q*3148|0)+52>>2]=s;c[u+(q*3148|0)+1076>>2]=s;c[u+(q*3148|0)+2100>>2]=s;s=t+512|0;c[u+(q*3148|0)+56>>2]=s;c[u+(q*3148|0)+1080>>2]=s;c[u+(q*3148|0)+2104>>2]=s;s=t+768|0;c[u+(q*3148|0)+60>>2]=s;c[u+(q*3148|0)+1084>>2]=s;c[u+(q*3148|0)+2108>>2]=s;s=t+1024|0;c[u+(q*3148|0)+64>>2]=s;c[u+(q*3148|0)+1088>>2]=s;c[u+(q*3148|0)+2112>>2]=s;s=t+1280|0;c[u+(q*3148|0)+68>>2]=s;c[u+(q*3148|0)+1092>>2]=s;c[u+(q*3148|0)+2116>>2]=s;s=t+1536|0;c[u+(q*3148|0)+72>>2]=s;c[u+(q*3148|0)+1096>>2]=s;c[u+(q*3148|0)+2120>>2]=s;s=t+1792|0;c[u+(q*3148|0)+76>>2]=s;c[u+(q*3148|0)+1100>>2]=s;c[u+(q*3148|0)+2124>>2]=s;s=c[3531190]|0;t=12;v=12;while(1){w=s+(v<<8)|0;c[u+(q*3148|0)+48+(v<<2)>>2]=w;c[u+(q*3148|0)+48+(v+512<<2)>>2]=w;w=t+1&65535;if((w&65535)>255){break}else{t=w;v=w&65535}}c[u+(q*3148|0)+3120>>2]=2516;c[u+(q*3148|0)+3124>>2]=2400;v=u+(q*3148|0)|0;if((v|0)!=0){t=v;gGC(t|0,9660752,48)|0}c[p>>2]=r;c[3528554]=-1;UL(358e4,0,3152,0);c[2438224]=2216750;c[2433522]=1224;c[2406672]=206;c[3528468]=4026;c[2443842]=922;h[745398]=1.0;a[3203264]=1;Ux(0,8e3,(c[2439274]|0)!=0);c[2407030]=256;c[2407068]=3;c[2426998]=f;t=c[642608+(c[2436]<<2)>>2]|0;v=c[t+128>>2]|0;if((c[t+52>>2]&4|0)==0){c[2113068]=v;s=c[t+132>>2]|0;c[2113070]=s;c[2443814]=v;c[2440436]=s;C=v;D=s}else{c[2113070]=v;s=c[t+132>>2]|0;c[2113068]=s;c[2440436]=v;c[2443814]=s;C=s;D=v}v=ag(C<<1,D)|0;s=gGq(v)|0;c[2112926]=s;if((s|0)!=0){gGz(s|0,0,v|0)}v=c[2414654]|0;gGz(v|0,0,(c[2411638]|0)-v|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];v=c[3532592]|0;if((v|0)!=0){gGC(9104152,v|0,280)|0}c[2113054]=c[2113060]}RI();v=c[2394]|0;s=c[14130368+(v<<2)>>2]|0;if((s|0)!=0){gGC(s|0,9104152,280)|0}c[8452240+(v<<2)>>2]=c[2113054];c[2394]=-1;c[3528554]=0;f43(c[2433592]|0);v=c[3528554]|0;c[2113158]=c[9731360+(v<<2)>>2];a[9660796]=0;a[9660797]=0;a[9660786]=0;a[9660787]=0;c[2415191]=0;a[9660784]=a[9660784]|80;s=c[2433592]|0;t=c[s+(v*3148|0)+1068>>2]|0;do{if((t|0)==0){l=c[s+(v*3148|0)+3120>>2]|0;if((l|0)==0){E=0;F=0;G=v;H=s;break}w=gj[l&4095](-2)|0;l=c[3528554]|0;x=c[2433592]|0;y=c[x+(l*3148|0)+1068>>2]|0;I=(w&255)<<8;if((y|0)!=0){J=y;K=I;L=l;M=x;k=55261;break}y=c[x+(l*3148|0)+3120>>2]|0;if((y|0)==0){E=0;F=I;G=l;H=x;break}x=gj[y&4095](-1)|0;E=x;F=I;G=c[3528554]|0;H=c[2433592]|0}else{J=t;K=(d[t+254|0]|0)<<8;L=v;M=s;k=55261}}while(0);if((k|0)==55261){E=a[J+255|0]|0;F=K;G=L;H=M}s=E&255|F;c[2415188]=s;b[4830376]=s&65535;s=H+(G*3148|0)|0;if((s|0)!=0){v=s;gGC(v|0,9660752,48)|0}c[9731360+(G<<2)>>2]=c[2113158];c[3528554]=-1;c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;lw(c[3540984]|0);c[2113156]=0;a[9628264]=0;c[2407033]=0;v=c[3541206]|0;c[3541190]=v;c[3541198]=v;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=v+256;c[3541199]=v+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=v+512;c[3541200]=v+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=v+768;c[3541201]=v+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;v=c[2386640]|0;s=v+262144|0;gGC(v|0,s|0,196608)|0;c[2394740]=3;s=v+196608|0;t=v+458752|0;gGC(s|0,t|0,65536)|0;n=0;return n|0}}while(0);c[2414950]=0;n=1;return n|0}function ee4(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=i;i=i+600|0;d=b|0;e=b+112|0;f=b+120|0;g=b+232|0;h=b+240|0;j=b+352|0;k=b+360|0;l=b+472|0;m=b+480|0;n=b+592|0;if((R6((c[2388142]|0)+1|0,0,2)|0)!=0){o=1;i=b;return o|0}if((R6(c[2388142]|0,1,2)|0)!=0){o=1;i=b;return o|0}p=(c[3530594]|0)+3145728|0;if((c[3542200]|0)==0){o=1;i=b;return o|0}q=m+108|0;c[q>>2]=0;r=m+100|0;c[r>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,2)|0;do{if((c[q>>2]|0)!=0){m=c[r>>2]|0;c[n>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](n,2,0)|0;if((m|0)<1){o=1;i=b;return o|0}if((gzL(p,0,2)|0)==0){break}else{o=1}i=b;return o|0}}while(0);p=(c[3530594]|0)+2097152|0;if((c[3542200]|0)==0){o=1;i=b;return o|0}n=k+108|0;c[n>>2]=0;r=k+100|0;c[r>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,3)|0;do{if((c[n>>2]|0)!=0){k=c[r>>2]|0;c[l>>2]=9534384;q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[q&16383](l,3,0)|0;if((k|0)<1){o=1;i=b;return o|0}if((gzL(p,0,3)|0)==0){break}else{o=1}i=b;return o|0}}while(0);p=(c[3530594]|0)+1048576|0;if((c[3542200]|0)==0){o=1;i=b;return o|0}l=h+108|0;c[l>>2]=0;r=h+100|0;c[r>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](h,4)|0;do{if((c[l>>2]|0)!=0){h=c[r>>2]|0;c[j>>2]=9534384;n=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[n&16383](j,4,0)|0;if((h|0)<1){o=1;i=b;return o|0}if((gzL(p,0,4)|0)==0){break}else{o=1}i=b;return o|0}}while(0);p=c[3530594]|0;if((c[3542200]|0)==0){o=1;i=b;return o|0}j=f+108|0;c[j>>2]=0;r=f+100|0;c[r>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,5)|0;do{if((c[j>>2]|0)!=0){f=c[r>>2]|0;c[g>>2]=9534384;l=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[l&16383](g,5,0)|0;if((f|0)<1){o=1;i=b;return o|0}if((gzL(p,0,5)|0)==0){break}else{o=1}i=b;return o|0}}while(0);p=c[3530594]|0;g=c[3530830]|0;r=0;do{a[g+(r>>>1&262144|r&15990783|r<<1&524288)|0]=a[p+r|0]|0;r=r+1|0;}while((r|0)<4194304);r=(c[2386640]|0)+262144|0;if((c[3542200]|0)==0){o=1;i=b;return o|0}p=d+108|0;c[p>>2]=0;g=d+100|0;c[g>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](d,6)|0;if((c[p>>2]|0)==0){o=0;i=b;return o|0}p=c[g>>2]|0;c[e>>2]=9534384;gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](e,6,0)|0;if((p|0)<1){o=1;i=b;return o|0}o=(gzL(r,0,6)|0)!=0|0;i=b;return o|0}function ee5(b){b=b|0;var d=0,e=0;d=b&65535;switch(d|0){case 2560:case 2561:{e=lx(c[3540984]|0,d&1)|0|6;break};case 2048:case 2049:{e=c[2113156]&255;break};case 2816:{e=a[c[3528266]|0]|0;break};default:{e=0}}return e|0}function ee6(b,e){b=b|0;e=e|0;var f=0,g=0;f=b&65535;if((f|0)==2560|(f|0)==2561){b=c[3540984]|0;if((f&1|0)==0){a[b+5885|0]=e;return}g=c[b+5876>>2]|0;if((g|0)!=0){gg[g&4095](c[b+5880>>2]|0,0)}lH(b,d[b+5885|0]|0,e&255);return}else if((f|0)==2048|(f|0)==2049){Uv(0,e);return}else{return}}function ee7(a){a=a|0;var b=0,d=0;b=c[2113158]|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,2216750,0)|0;return a|0}function ee8(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;a=i;i=i+1200|0;b=a|0;d=a+112|0;e=a+120|0;f=a+232|0;g=a+240|0;h=a+352|0;j=a+360|0;k=a+472|0;l=a+480|0;m=a+592|0;n=a+600|0;o=a+712|0;p=a+720|0;q=a+832|0;r=a+840|0;s=a+952|0;t=a+960|0;u=a+1072|0;v=a+1080|0;w=a+1192|0;if((R6((c[2388142]|0)+1|0,0,2)|0)!=0){x=1;i=a;return x|0}if((R6(c[2388142]|0,1,2)|0)!=0){x=1;i=a;return x|0}y=c[3530830]|0;if((c[3542200]|0)==0){x=1;i=a;return x|0}z=v+108|0;c[z>>2]=0;A=v+100|0;c[A>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,2)|0;do{if((c[z>>2]|0)!=0){v=c[A>>2]|0;c[w>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](w,2,0)|0;if((v|0)<1){x=1;i=a;return x|0}if((gzL(y,0,2)|0)==0){break}else{x=1}i=a;return x|0}}while(0);y=(c[3530830]|0)+524288|0;if((c[3542200]|0)==0){x=1;i=a;return x|0}w=t+108|0;c[w>>2]=0;A=t+100|0;c[A>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,2)|0;do{if((c[w>>2]|0)!=0){t=c[A>>2]|0;c[u>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](u,2,0)|0;if((t|0)<1){x=1;i=a;return x|0}if((gzL(y,0,2)|0)==0){break}else{x=1}i=a;return x|0}}while(0);y=(c[3530830]|0)+1048576|0;if((c[3542200]|0)==0){x=1;i=a;return x|0}u=r+108|0;c[u>>2]=0;A=r+100|0;c[A>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,3)|0;do{if((c[u>>2]|0)!=0){r=c[A>>2]|0;c[s>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](s,3,0)|0;if((r|0)<1){x=1;i=a;return x|0}if((gzL(y,0,3)|0)==0){break}else{x=1}i=a;return x|0}}while(0);y=(c[3530830]|0)+1572864|0;if((c[3542200]|0)==0){x=1;i=a;return x|0}s=p+108|0;c[s>>2]=0;A=p+100|0;c[A>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,3)|0;do{if((c[s>>2]|0)!=0){p=c[A>>2]|0;c[q>>2]=9534384;u=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[u&16383](q,3,0)|0;if((p|0)<1){x=1;i=a;return x|0}if((gzL(y,0,3)|0)==0){break}else{x=1}i=a;return x|0}}while(0);y=(c[3530830]|0)+2097152|0;if((c[3542200]|0)==0){x=1;i=a;return x|0}q=n+108|0;c[q>>2]=0;A=n+100|0;c[A>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,4)|0;do{if((c[q>>2]|0)!=0){n=c[A>>2]|0;c[o>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](o,4,0)|0;if((n|0)<1){x=1;i=a;return x|0}if((gzL(y,0,4)|0)==0){break}else{x=1}i=a;return x|0}}while(0);y=(c[3530830]|0)+2621440|0;if((c[3542200]|0)==0){x=1;i=a;return x|0}o=l+108|0;c[o>>2]=0;A=l+100|0;c[A>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,4)|0;do{if((c[o>>2]|0)!=0){l=c[A>>2]|0;c[m>>2]=9534384;q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[q&16383](m,4,0)|0;if((l|0)<1){x=1;i=a;return x|0}if((gzL(y,0,4)|0)==0){break}else{x=1}i=a;return x|0}}while(0);y=(c[3530830]|0)+3145728|0;if((c[3542200]|0)==0){x=1;i=a;return x|0}m=j+108|0;c[m>>2]=0;A=j+100|0;c[A>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,5)|0;do{if((c[m>>2]|0)!=0){j=c[A>>2]|0;c[k>>2]=9534384;o=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[o&16383](k,5,0)|0;if((j|0)<1){x=1;i=a;return x|0}if((gzL(y,0,5)|0)==0){break}else{x=1}i=a;return x|0}}while(0);y=(c[3530830]|0)+3670016|0;if((c[3542200]|0)==0){x=1;i=a;return x|0}k=g+108|0;c[k>>2]=0;A=g+100|0;c[A>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,5)|0;do{if((c[k>>2]|0)!=0){g=c[A>>2]|0;c[h>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](h,5,0)|0;if((g|0)<1){x=1;i=a;return x|0}if((gzL(y,0,5)|0)==0){break}else{x=1}i=a;return x|0}}while(0);y=(c[2386640]|0)+262144|0;if((c[3542200]|0)==0){x=1;i=a;return x|0}h=e+108|0;c[h>>2]=0;A=e+100|0;c[A>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,6)|0;do{if((c[h>>2]|0)!=0){e=c[A>>2]|0;c[f>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](f,6,0)|0;if((e|0)<1){x=1;i=a;return x|0}if((gzL(y,0,6)|0)==0){break}else{x=1}i=a;return x|0}}while(0);y=(c[2386640]|0)+786432|0;if((c[3542200]|0)==0){x=1;i=a;return x|0}f=b+108|0;c[f>>2]=0;A=b+100|0;c[A>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](b,6)|0;if((c[f>>2]|0)==0){x=0;i=a;return x|0}f=c[A>>2]|0;c[d>>2]=9534384;gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](d,6,0)|0;if((f|0)<1){x=1;i=a;return x|0}x=(gzL(y,0,6)|0)!=0|0;i=a;return x|0}function ee9(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;b=i;i=i+1200|0;d=b|0;e=b+112|0;f=b+120|0;g=b+232|0;h=b+240|0;j=b+352|0;k=b+360|0;l=b+472|0;m=b+480|0;n=b+592|0;o=b+600|0;p=b+712|0;q=b+720|0;r=b+832|0;s=b+840|0;t=b+952|0;u=b+960|0;v=b+1072|0;w=b+1080|0;x=b+1192|0;if((R6((c[2388142]|0)+1|0,0,2)|0)!=0){y=1;i=b;return y|0}if((R6(c[2388142]|0,1,2)|0)!=0){y=1;i=b;return y|0}z=c[3530594]|0;if((c[3542200]|0)==0){y=1;i=b;return y|0}A=w+108|0;c[A>>2]=0;B=w+100|0;c[B>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](w,3)|0;do{if((c[A>>2]|0)!=0){w=c[B>>2]|0;c[x>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](x,3,0)|0;if((w|0)<1){y=1;i=b;return y|0}if((gzL(z,0,3)|0)==0){break}else{y=1}i=b;return y|0}}while(0);z=(c[3530594]|0)+524288|0;if((c[3542200]|0)==0){y=1;i=b;return y|0}x=u+108|0;c[x>>2]=0;B=u+100|0;c[B>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](u,2)|0;do{if((c[x>>2]|0)!=0){u=c[B>>2]|0;c[v>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](v,2,0)|0;if((u|0)<1){y=1;i=b;return y|0}if((gzL(z,0,2)|0)==0){break}else{y=1}i=b;return y|0}}while(0);z=(c[3530594]|0)+1048576|0;if((c[3542200]|0)==0){y=1;i=b;return y|0}v=s+108|0;c[v>>2]=0;B=s+100|0;c[B>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](s,5)|0;do{if((c[v>>2]|0)!=0){s=c[B>>2]|0;c[t>>2]=9534384;x=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[x&16383](t,5,0)|0;if((s|0)<1){y=1;i=b;return y|0}if((gzL(z,0,5)|0)==0){break}else{y=1}i=b;return y|0}}while(0);z=(c[3530594]|0)+1572864|0;if((c[3542200]|0)==0){y=1;i=b;return y|0}t=q+108|0;c[t>>2]=0;B=q+100|0;c[B>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](q,4)|0;do{if((c[t>>2]|0)!=0){q=c[B>>2]|0;c[r>>2]=9534384;v=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[v&16383](r,4,0)|0;if((q|0)<1){y=1;i=b;return y|0}if((gzL(z,0,4)|0)==0){break}else{y=1}i=b;return y|0}}while(0);z=(c[3530594]|0)+2097152|0;if((c[3542200]|0)==0){y=1;i=b;return y|0}r=o+108|0;c[r>>2]=0;B=o+100|0;c[B>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](o,7)|0;do{if((c[r>>2]|0)!=0){o=c[B>>2]|0;c[p>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](p,7,0)|0;if((o|0)<1){y=1;i=b;return y|0}if((gzL(z,0,7)|0)==0){break}else{y=1}i=b;return y|0}}while(0);z=(c[3530594]|0)+2621440|0;if((c[3542200]|0)==0){y=1;i=b;return y|0}p=m+108|0;c[p>>2]=0;B=m+100|0;c[B>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,6)|0;do{if((c[p>>2]|0)!=0){m=c[B>>2]|0;c[n>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](n,6,0)|0;if((m|0)<1){y=1;i=b;return y|0}if((gzL(z,0,6)|0)==0){break}else{y=1}i=b;return y|0}}while(0);z=(c[3530594]|0)+3145728|0;if((c[3542200]|0)==0){y=1;i=b;return y|0}n=k+108|0;c[n>>2]=0;B=k+100|0;c[B>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,9)|0;do{if((c[n>>2]|0)!=0){k=c[B>>2]|0;c[l>>2]=9534384;p=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[p&16383](l,9,0)|0;if((k|0)<1){y=1;i=b;return y|0}if((gzL(z,0,9)|0)==0){break}else{y=1}i=b;return y|0}}while(0);z=(c[3530594]|0)+3670016|0;if((c[3542200]|0)==0){y=1;i=b;return y|0}l=h+108|0;c[l>>2]=0;B=h+100|0;c[B>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](h,8)|0;do{if((c[l>>2]|0)!=0){h=c[B>>2]|0;c[j>>2]=9534384;n=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[n&16383](j,8,0)|0;if((h|0)<1){y=1;i=b;return y|0}if((gzL(z,0,8)|0)==0){break}else{y=1}i=b;return y|0}}while(0);z=c[3530594]|0;j=c[3530830]|0;B=0;do{a[j+(B>>>1&262144|B&15990783|B<<1&524288)|0]=a[z+B|0]|0;B=B+1|0;}while((B|0)<4194304);B=(c[2386640]|0)+262144|0;if((c[3542200]|0)==0){y=1;i=b;return y|0}z=f+108|0;c[z>>2]=0;j=f+100|0;c[j>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,10)|0;do{if((c[z>>2]|0)!=0){f=c[j>>2]|0;c[g>>2]=9534384;l=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[l&16383](g,10,0)|0;if((f|0)<1){y=1;i=b;return y|0}if((gzL(B,0,10)|0)==0){break}else{y=1}i=b;return y|0}}while(0);B=(c[2386640]|0)+786432|0;if((c[3542200]|0)==0){y=1;i=b;return y|0}g=d+108|0;c[g>>2]=0;j=d+100|0;c[j>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](d,11)|0;if((c[g>>2]|0)==0){y=0;i=b;return y|0}g=c[j>>2]|0;c[e>>2]=9534384;gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](e,11,0)|0;if((g|0)<1){y=1;i=b;return y|0}y=(gzL(B,0,11)|0)!=0|0;i=b;return y|0}function efa(f,g,h,i){f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;j=c[3529386]|0;k=((f|0)/4096|0)<<2;l=(c[2386210]|0)+f|0;m=(e[j+k>>1]|0)+16&511;n=(e[j+(k|2)>>1]|0)+((f|0)!=0?0:4)&511;f=i&255;i=c[2113068]|0;k=c[2113070]|0;j=c[3530594]|0;o=c[2112926]|0;p=c[2439590]|0;q=0;do{r=q<<1;s=e[l+(r<<1)>>1]|0;t=e[l+((r|1)<<1)>>1]|0;r=s>>>2;u=s&2;v=s&1;s=t<<4&1008;L73575:do{if((t>>>6&3|0)==(h|0)){w=(q<<4&496)-n|0;x=(w|0)<-15?w+512|0:w;w=(q>>5<<4)-m|0;y=(w|0)<-15?w+512|0:w;if(!((x|0)<(i|0)&(y|0)<(k|0))){break}w=(u|0)==0?0:240;z=(v|0)==0?w:w|15;w=r<<8;A=y;y=0;while(1){L73580:do{if((A|0)>=0){if((A|0)>=(k|0)){break L73575}B=ag(i,A)|0;C=y<<4;D=0;E=x;while(1){do{if((E|0)>=0){if((E|0)>=(i|0)){break L73580}F=d[j+(((D|C)^z)+w)|0]|0;if((1<<F&g|0)!=0){break}G=E+B|0;b[o+(G<<1)>>1]=(F|s)&65535;a[p+G|0]=f}}while(0);G=D+1|0;if((G|0)<16){D=G;E=E+1|0}else{break}}}}while(0);E=y+1|0;if((E|0)<16){A=A+1|0;y=E}else{break}}}}while(0);q=q+1|0;}while((q|0)<1024);return}function efb(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;f=c[2386444]|0;g=c[2113068]|0;h=c[2113070]|0;i=c[3530830]|0;j=c[2112926]|0;k=c[2439590]|0;l=2043;do{m=e[f+(l+2<<1)>>1]|0;n=m&511;o=e[f+(l<<1)>>1]|0;p=240-o&255;q=e[f+(l+3<<1)>>1]|0;r=m>>>9&63;m=o>>>9;s=m&32;t=m&64;u=r>>>0>55?4:o>>>12&3;if((u|0)==2){v=65532}else if((u|0)==3){v=65534}else if((u|0)==0){v=65280}else if((u|0)==1){v=65520}else{v=0}u=m&4;m=2-(u>>>2)|0;o=(u|0)==0?q&65532:q;q=(s|0)==0;u=(t|0)==0;w=r<<4;r=n-15|0;n=p-16|0;p=((t|0)!=0?56:0)|((s|0)!=0?7:0);s=m-1|0;t=0;do{x=n+(t<<3)|0;y=(x|0)>-8;z=(u?t:s-t|0)+o|0;A=(h|0)>(x|0);if(q){B=0;do{C=(B<<3)+r|0;L73607:do{if(y&(C|0)>-8&(g|0)>(C|0)&A){D=z+(B<<1)<<6;E=x;F=0;while(1){L73611:do{if((E|0)>-1&(E|0)<(h|0)){G=ag(g,E)|0;H=F<<3;I=0;J=C;while(1){do{if((J|0)>-1&(J|0)<(g|0)){K=a[i+((I+H^p)+D)|0]|0;if(K<<24>>24==0){break}L=J+G|0;M=k+L|0;if((1<<(d[M]|0)&v|0)!=0){break}b[j+(L<<1)>>1]=(K&255|w)&65535;a[M]=15}}while(0);M=I+1|0;if((M|0)>=8){break L73611}I=M;J=J+1|0}}}while(0);J=F+1|0;if((J|0)>=8){break L73607}E=E+1|0;F=J}}}while(0);B=B+1|0;}while((B|0)<(m|0))}else{B=0;do{C=(B<<3)+r|0;L73626:do{if(y&(C|0)>-8&(g|0)>(C|0)&A){F=z+(s-B<<1)<<6;E=x;D=0;while(1){L73630:do{if((E|0)>-1&(E|0)<(h|0)){J=ag(g,E)|0;I=D<<3;G=0;H=C;while(1){do{if((H|0)>-1&(H|0)<(g|0)){M=a[i+((G+I^p)+F)|0]|0;if(M<<24>>24==0){break}K=H+J|0;L=k+K|0;if((1<<(d[L]|0)&v|0)!=0){break}b[j+(K<<1)>>1]=(M&255|w)&65535;a[L]=15}}while(0);L=G+1|0;if((L|0)>=8){break L73630}G=L;H=H+1|0}}}while(0);H=D+1|0;if((H|0)>=8){break L73626}E=E+1|0;D=H}}}while(0);B=B+1|0;}while((B|0)<(m|0))}t=t+1|0;}while((t|0)<(m|0));l=l-4|0;}while((l|0)>2);return}function efc(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0;a=i;i=i+120|0;b=a|0;d=a+112|0;e=c[3531190]|0;if((c[3542200]|0)==0){f=1;i=a;return f|0}g=b+108|0;c[g>>2]=0;h=b+100|0;c[h>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](b,7)|0;do{if((c[g>>2]|0)!=0){b=c[h>>2]|0;c[d>>2]=9534384;j=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[j&16383](d,7,0)|0;if((b|0)<1){f=1;i=a;return f|0}if((gzL(e,0,7)|0)==0){break}else{f=1}i=a;return f|0}}while(0);f=ee8()|0;i=a;return f|0}function efd(b,e){b=b|0;e=e|0;var f=0,g=0;if((b|0)==1048580){a[c[3529782]|0]=e&1;f=c[3541206]|0;g=(c[2386638]|0)+((e&255)<<18&262144^262144)|0;gGC(f|0,g|0,262144)|0;return}else if((b|0)==3145742){a[(c[3530976]|0)+(d[c[3528838]|0]|0)|0]=e&15;return}else if((b|0)==3145728){a[c[3528838]|0]=e&3;return}else{return}}function efe(d,e){d=d|0;e=e|0;if((d|0)==1048576){a[c[3528264]|0]=e&255;return}else if((d|0)==3145730|(d|0)==3145734){b[(c[3529788]|0)+((d>>>2&1)<<1)>>1]=e&1023;return}else if((d|0)==3145732|(d|0)==3145736){b[(c[3529784]|0)+((d>>>3&1)<<1)>>1]=e+8&511;return}else{return}}function eff(a){a=a|0;var b=0;if((a|0)!=1572866){b=0;return b|0}b=(e[4775217]|0)>>>8&255;return b|0}function efg(a){a=a|0;var c=0;if((a|0)==1572868){c=b[4775218]|0}else if((a|0)==1572864){c=b[4775216]|0}else{c=0}return c|0}function efh(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((e|0)==49152){c[2113304]=d&255;return}else if((e|0)==49153){b=c[2113304]|0;a[14168504+b|0]=d;mv(0,b,d&255);return}else if((e|0)==49154|(e|0)==49155){Uv(0,d);return}else{return}}function efi(b){b=b|0;var d=0,e=0;d=b&65535;if((d|0)==49158){e=a[c[3528264]|0]|0;return e|0}else if((d|0)==49153){e=c[(c[3531464]|0)+4240>>2]&255;return e|0}else{e=0;return e|0}return 0}function efj(b){b=b|0;a[9706117]=(b|0)!=0|0;return}function efk(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5878972+(b*112|0)>>2];c[a+104>>2]=c[5878976+(b*112|0)>>2];c[a+108>>2]=c[5878980+(b*112|0)>>2];d=0;return d|0}function efl(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=5878872+(b*112|0);e=0;return e|0}function efm(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3898664+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function efn(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>35){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6288600+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function efo(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;e=i;i=i+1200|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;c[2414948]=0;c[2388140]=0;c[2385916]=524288;c[3530828]=557056;c[3530592]=4751360;c[3541206]=8945664;c[2386638]=9207808;c[3529990]=9732096;c[2414652]=9735168;c[2388268]=9735168;c[2387182]=9800704;c[2406488]=9802752;c[2406566]=9806848;c[2386442]=9810944;c[2386070]=9812992;c[3529788]=9815040;c[3529784]=9815044;c[3530976]=9815048;c[3529782]=9815052;c[3528838]=9815053;c[3528264]=9815054;c[2411636]=9815055;B=0;while(1){if((B|0)>=1024){break}C=9638528+(B<<2)|0;if((c[C>>2]|0)==0){D=55621;break}else{B=B+1|0}}do{if((D|0)==55621){B=gGq(9815055)|0;c[C>>2]=B;if((B|0)==0){break}c[2414948]=B;gGz(B|0,0,9815055);c[2388140]=B;c[2385916]=B+524288;c[3530828]=B+557056;c[3530592]=B+4751360;c[3541206]=B+8945664;c[2386638]=B+9207808;c[3529990]=B+9732096;E=B+9735168|0;c[2414652]=E;c[2388268]=E;c[2387182]=B+9800704;c[2406488]=B+9802752;c[2406566]=B+9806848;c[2386442]=B+9810944;c[2386070]=B+9812992;c[3529788]=B+9815040;c[3529784]=B+9815044;c[3530976]=B+9815048;c[3529782]=B+9815052;c[3528838]=B+9815053;c[3528264]=B+9815054;E=B+9815055|0;c[2411636]=E;c[2414176]=E;if((R6(B+1|0,0,2)|0)!=0){F=1;i=e;return F|0}if((R6(c[2388140]|0,1,2)|0)!=0){F=1;i=e;return F|0}B=c[2385916]|0;if((c[3542200]|0)==0){F=1;i=e;return F|0}E=z+108|0;c[E>>2]=0;G=z+100|0;c[G>>2]=0;H=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[H&16383](z,2)|0;do{if((c[E>>2]|0)!=0){H=c[G>>2]|0;c[A>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](A,2,0)|0;if((H|0)<1){F=1;i=e;return F|0}if((gzL(B,0,2)|0)==0){break}else{F=1}i=e;return F|0}}while(0);B=c[3530592]|0;if((c[3542200]|0)==0){F=1;i=e;return F|0}G=x+108|0;c[G>>2]=0;E=x+100|0;c[E>>2]=0;H=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[H&16383](x,3)|0;do{if((c[G>>2]|0)!=0){H=c[E>>2]|0;c[y>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](y,3,0)|0;if((H|0)<1){F=1;i=e;return F|0}if((gzL(B,0,3)|0)==0){break}else{F=1}i=e;return F|0}}while(0);B=(c[3530592]|0)+524288|0;if((c[3542200]|0)==0){F=1;i=e;return F|0}E=v+108|0;c[E>>2]=0;G=v+100|0;c[G>>2]=0;H=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[H&16383](v,4)|0;do{if((c[E>>2]|0)!=0){H=c[G>>2]|0;c[w>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](w,4,0)|0;if((H|0)<1){F=1;i=e;return F|0}if((gzL(B,0,4)|0)==0){break}else{F=1}i=e;return F|0}}while(0);B=(c[3530592]|0)+1048576|0;if((c[3542200]|0)==0){F=1;i=e;return F|0}G=t+108|0;c[G>>2]=0;E=t+100|0;c[E>>2]=0;H=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[H&16383](t,5)|0;do{if((c[G>>2]|0)!=0){H=c[E>>2]|0;c[u>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](u,5,0)|0;if((H|0)<1){F=1;i=e;return F|0}if((gzL(B,0,5)|0)==0){break}else{F=1}i=e;return F|0}}while(0);B=(c[3530592]|0)+1572864|0;if((c[3542200]|0)==0){F=1;i=e;return F|0}E=r+108|0;c[E>>2]=0;G=r+100|0;c[G>>2]=0;H=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[H&16383](r,6)|0;do{if((c[E>>2]|0)!=0){H=c[G>>2]|0;c[s>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](s,6,0)|0;if((H|0)<1){F=1;i=e;return F|0}if((gzL(B,0,6)|0)==0){break}else{F=1}i=e;return F|0}}while(0);B=c[3530592]|0;G=c[3530828]|0;E=0;do{a[G+((E>>>1&917504|E&131071|E<<3&1048576)^16)|0]=a[B+E|0]|0;E=E+1|0;}while((E|0)<2097152);if((c[3542200]|0)==0){F=1;i=e;return F|0}E=p+108|0;c[E>>2]=0;G=p+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,7)|0;do{if((c[E>>2]|0)!=0){H=c[G>>2]|0;c[q>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](q,7,0)|0;if((H|0)<1){F=1;i=e;return F|0}if((gzL(B,0,7)|0)==0){break}else{F=1}i=e;return F|0}}while(0);B=(c[3530592]|0)+524288|0;if((c[3542200]|0)==0){F=1;i=e;return F|0}G=n+108|0;c[G>>2]=0;E=n+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,8)|0;do{if((c[G>>2]|0)!=0){H=c[E>>2]|0;c[o>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](o,8,0)|0;if((H|0)<1){F=1;i=e;return F|0}if((gzL(B,0,8)|0)==0){break}else{F=1}i=e;return F|0}}while(0);B=(c[3530592]|0)+1048576|0;if((c[3542200]|0)==0){F=1;i=e;return F|0}E=l+108|0;c[E>>2]=0;G=l+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,9)|0;do{if((c[E>>2]|0)!=0){H=c[G>>2]|0;c[m>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](m,9,0)|0;if((H|0)<1){F=1;i=e;return F|0}if((gzL(B,0,9)|0)==0){break}else{F=1}i=e;return F|0}}while(0);B=(c[3530592]|0)+1572864|0;if((c[3542200]|0)==0){F=1;i=e;return F|0}G=j+108|0;c[G>>2]=0;E=j+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,10)|0;do{if((c[G>>2]|0)!=0){H=c[E>>2]|0;c[k>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](k,10,0)|0;if((H|0)<1){F=1;i=e;return F|0}if((gzL(B,0,10)|0)==0){break}else{F=1}i=e;return F|0}}while(0);B=c[2386638]|0;if((c[3542200]|0)==0){F=1;i=e;return F|0}E=f+108|0;c[E>>2]=0;G=f+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,11)|0;do{if((c[E>>2]|0)!=0){H=c[G>>2]|0;c[g>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](g,11,0)|0;if((H|0)<1){F=1;i=e;return F|0}if((gzL(B,0,11)|0)==0){break}else{F=1}i=e;return F|0}}while(0);B=c[3541206]|0;G=c[2386638]|0;gGC(B|0,G|0,262144)|0;G=0;while(1){if((G|0)>=1024){break}J=9638528+(G<<2)|0;if((c[J>>2]|0)==0){D=55670;break}else{G=G+1|0}}L73851:do{if((D|0)==55670){G=gGq(2097152)|0;c[J>>2]=G;if((G|0)==0){break}gGz(G|0,0,2097152);B=c[3530828]|0;gGC(G|0,B|0,2097152)|0;E=0;do{H=E<<8;gGz(B+H|0,0,256);I=0;do{K=1<<3-I;L=(c[613200+(I<<2)>>2]|0)+H|0;M=0;do{N=L+(c[609008+(M<<2)>>2]|0)|0;O=(M<<4)+H|0;P=0;do{Q=N+(c[612640+(P<<2)>>2]|0)|0;if(((d[G+((Q|0)/8|0)|0]|0)&128>>>((Q&7)>>>0)|0)!=0){Q=B+(O+P)|0;a[Q]=(d[Q]|0|K)&255}P=P+1|0;}while((P|0)<16);M=M+1|0;}while((M|0)<16);I=I+1|0;}while((I|0)<4);E=E+1|0;}while((E|0)<16384);E=c[3530592]|0;gGC(G|0,E|0,2097152)|0;B=0;while(1){I=B<<8;gGz(E+I|0,0,256);H=0;do{M=1<<3-H;K=(c[613200+(H<<2)>>2]|0)+I|0;L=0;do{P=K+(c[609008+(L<<2)>>2]|0)|0;O=(L<<4)+I|0;N=0;do{Q=P+(c[612640+(N<<2)>>2]|0)|0;if(((d[G+((Q|0)/8|0)|0]|0)&128>>>((Q&7)>>>0)|0)!=0){Q=E+(O+N)|0;a[Q]=(d[Q]|0|M)&255}N=N+1|0;}while((N|0)<16);L=L+1|0;}while((L|0)<16);H=H+1|0;}while((H|0)<4);H=B+1|0;if((H|0)<16384){B=H}else{R=0;break}}while(1){if((R|0)>=1024){break L73851}S=9638528+(R<<2)|0;if((c[S>>2]|0)==(G|0)){break}else{R=R+1|0}}gGr(G);c[S>>2]=0}}while(0);fxU(0,425984);if((c[2394]|0)==0){T=c[2112932]|0}else{c[2394]=0;B=c[3532596]|0;c[2112932]=B;E=c[3532592]|0;if((E|0)!=0){gGC(9104152,E|0,280)|0}c[2113054]=c[2113060];T=B}B=c[2388140]|0;E=T|0;H=0;while(1){I=B+H|0;c[E>>2]=I;c[E+131072>>2]=I;I=H+1024|0;if(I>>>0>524287){break}else{E=E+4|0;H=I}}H=c[2388268]|0;E=T+4608|0;B=1179648;while(1){I=H+(B-1179648)|0;c[E>>2]=I;c[E+65536>>2]=I;c[E+131072>>2]=I;I=B+1024|0;if(I>>>0>1245183){break}else{E=E+4|0;B=I}}B=c[2387182]|0;c[T+5120>>2]=B;c[T+70656>>2]=B;c[T+136192>>2]=B;E=B+1024|0;c[T+5124>>2]=E;c[T+70660>>2]=E;c[T+136196>>2]=E;E=c[2386442]|0;c[T+5632>>2]=E;c[T+71168>>2]=E;c[T+136704>>2]=E;B=E+1024|0;c[T+5636>>2]=B;c[T+71172>>2]=B;c[T+136708>>2]=B;B=c[2406488]|0;c[T+12800>>2]=B;c[T+78336>>2]=B;c[T+143872>>2]=B;E=B+1024|0;c[T+12804>>2]=E;c[T+78340>>2]=E;c[T+143876>>2]=E;E=B+2048|0;c[T+12808>>2]=E;c[T+78344>>2]=E;c[T+143880>>2]=E;E=B+3072|0;c[T+12812>>2]=E;c[T+78348>>2]=E;c[T+143884>>2]=E;E=c[2406566]|0;c[T+12832>>2]=E;c[T+78368>>2]=E;c[T+143904>>2]=E;B=E+1024|0;c[T+12836>>2]=B;c[T+78372>>2]=B;c[T+143908>>2]=B;B=E+2048|0;c[T+12840>>2]=B;c[T+78376>>2]=B;c[T+143912>>2]=B;B=E+3072|0;c[T+12844>>2]=B;c[T+78380>>2]=B;c[T+143916>>2]=B;c[T+196728>>2]=1990;c[T+196648>>2]=1544;c[T+196688>>2]=1126;c[T+196608>>2]=340;B=c[3532592]|0;if((B|0)!=0){gGC(B|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);B=c[2439330]|0;E=(B|0)==0;if(!E){H=B;gGC(9706056,H|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];H=c[3528484]|0;c[2076596]=H;I=c[2417276]|0;c[3541536]=I;c[1836236]=0;L=c[2385916]|0;M=0;K=0;while(1){c[B+76+(K<<2)>>2]=L+(K<<8);N=M+1&65535;if((N&65535)>127){U=0;V=0;break}else{M=N;K=N&65535}}while(1){K=L+(V<<8)|0;c[B+76+(V+512<<2)>>2]=K;c[B+76+(V+768<<2)>>2]=K;K=U+1&65535;if((K&65535)>127){break}else{U=K;V=K&65535}}L=c[2386070]|0;c[B+908>>2]=L;K=L+256|0;c[B+912>>2]=K;M=L+512|0;c[B+916>>2]=M;N=L+768|0;c[B+920>>2]=N;O=L+1024|0;c[B+924>>2]=O;P=L+1280|0;c[B+928>>2]=P;Q=L+1536|0;c[B+932>>2]=Q;W=L+1792|0;c[B+936>>2]=W;c[B+1932>>2]=L;c[B+1936>>2]=K;c[B+1940>>2]=M;c[B+1944>>2]=N;c[B+1948>>2]=O;c[B+1952>>2]=P;c[B+1956>>2]=Q;c[B+1960>>2]=W;c[B+2956>>2]=L;c[B+3980>>2]=L;c[B+2960>>2]=K;c[B+3984>>2]=K;c[B+2964>>2]=M;c[B+3988>>2]=M;c[B+2968>>2]=N;c[B+3992>>2]=N;c[B+2972>>2]=O;c[B+3996>>2]=O;c[B+2976>>2]=P;c[B+4e3>>2]=P;c[B+2980>>2]=Q;c[B+4004>>2]=Q;c[B+2984>>2]=W;c[B+4008>>2]=W;c[B+4184>>2]=322;c[B+4180>>2]=1082;if(!E){W=B;gGC(W|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=H;c[2417276]=I;c[1836236]=-1;W=a[9680]|0;Q=W?32e3:0;if(W){if(a[9624]|0){W=Q*3|0;P=55930;while(1){if((P|0)>(W|0)){P=P>>1}else{X=1222;Y=P;break}}}else{X=2462;Y=Q}c[2429380]=Y;c[3542124]=X;mw(3579545,Y);P=gGq(262144)|0;c[2406684]=P;gGz(P|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(3579545,11025)}c[(c[3531464]|0)+44344>>2]=1378;h[745421]=.8;c[2436794]=3;h[745420]=.8;c[2436792]=3;Ux(0,7575,1);c[2407030]=154;c[2407068]=3;P=c[642608+(c[2436]<<2)>>2]|0;W=c[P+128>>2]|0;if((c[P+52>>2]&4|0)==0){c[2113068]=W;I=c[P+132>>2]|0;c[2113070]=I;c[2443814]=W;c[2440436]=I;Z=W;_=I}else{c[2113070]=W;I=c[P+132>>2]|0;c[2113068]=I;c[2440436]=W;c[2443814]=I;Z=I;_=W}W=ag(Z<<1,_)|0;I=gGq(W)|0;c[2112926]=I;if((I|0)!=0){gGz(I|0,0,W|0)}a[9624080]=0;W=c[2414652]|0;gGz(W|0,0,(c[2411636]|0)-W|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];W=c[3532592]|0;if((W|0)!=0){gGC(9104152,W|0,280)|0}c[2113054]=c[2113060]}RI();W=c[2394]|0;I=c[14130368+(W<<2)>>2]|0;if((I|0)!=0){gGC(I|0,9104152,280)|0}c[8452240+(W<<2)>>2]=c[2113054];c[2394]=-1;W=c[2439330]|0;I=(W|0)==0;if(!I){P=W;gGC(9706056,P|0,76)|0}P=c[2438118]|0;c[2433530]=P;H=c[3528484]|0;c[2076596]=H;B=c[2417276]|0;c[3541536]=B;c[1836236]=0;gGz(9706056,0,76);if(!I){I=W;gGC(I|0,9706056,76)|0}c[2438118]=P;c[3528484]=H;c[2417276]=B;c[1836236]=-1;c[2113156]=0;a[9628264]=0;c[2407033]=0;B=c[3541206]|0;c[3541190]=B;c[3541198]=B;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=B+256;c[3541199]=B+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=B+512;c[3541200]=B+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=B+768;c[3541201]=B+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;mx(0);a[c[3529782]|0]=1;B=c[3541206]|0;H=c[2386638]|0;gGC(B|0,H|0,262144)|0;F=0;i=e;return F|0}}while(0);c[2414948]=0;F=1;i=e;return F|0}function efp(){var a=0,b=0,d=0,e=0,f=0;c[2113070]=0;c[2113068]=0;a=c[2112926]|0;if((a|0)!=0){gGr(a);c[2112926]=0}a=c[3531464]|0;c[a+44344>>2]=0;c[a+44348>>2]=0;if((a|0)!=0){gGr(a);c[3531464]=0}a=c[2406684]|0;if((a|0)!=0){gGr(a);c[2406684]=0}Uw(0);if((c[2392]|0)>=0){a=0;do{b=14130368+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}b=14130384+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}a=a+1|0;}while((a|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;fwZ();a=c[2414948]|0;b=0;while(1){if((b|0)>=1024){e=55787;break}f=9638528+(b<<2)|0;if((c[f>>2]|0)==(a|0)){break}else{b=b+1|0}}if((e|0)==55787){c[2414948]=0;c[3541206]=0;return 0}gGr(a);c[f>>2]=0;c[2414948]=0;c[3541206]=0;return 0}function efq(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;if((a[9624080]|0)!=0){a[9624080]=0;e=c[2414652]|0;gGz(e|0,0,(c[2411636]|0)-e|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060]}RI();e=c[2394]|0;f=c[14130368+(e<<2)>>2]|0;if((f|0)!=0){gGC(f|0,9104152,280)|0}c[8452240+(e<<2)>>2]=c[2113054];c[2394]=-1;e=c[2439330]|0;f=(e|0)==0;if(!f){g=e;gGC(9706056,g|0,76)|0}g=c[2438118]|0;c[2433530]=g;h=c[3528484]|0;c[2076596]=h;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);if(!f){f=e;gGC(f|0,9706056,76)|0}c[2438118]=g;c[3528484]=h;c[2417276]=i;c[1836236]=-1;c[2113156]=0;a[9628264]=0;c[2407033]=0;i=c[3541206]|0;c[3541190]=i;c[3541198]=i;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=i+256;c[3541199]=i+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=i+512;c[3541200]=i+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=i+768;c[3541201]=i+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;mx(0);a[c[3529782]|0]=1;i=c[3541206]|0;h=c[2386638]|0;gGC(i|0,h|0,262144)|0}c[2387608]=-1;h=0;i=-1;g=-1;do{i=((a[9633296+h|0]&1)<<h^i&65535)&65535;g=((a[9631168+h|0]&1)<<h^g&65535)&65535;h=h+1|0;}while((h|0)<16);b[4775216]=i;b[4775217]=g;b[4775218]=d[9635033]<<8|d[9635032];if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060]}g=c[2439330]|0;if((g|0)!=0){i=g;gGC(9706056,i|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;i=c[2392]|0;if((i|0)>=0){gGz(8452240,0,((i|0)>0?(i<<2)+4|0:4)|0)}c[2113054]=0;i=c[2385548]|0;if((i|0)>0){gGz(9752472,0,((i|0)>1?i<<2:4)|0)}c[2433530]=0;i=0;g=0;h=0;f=0;while(1){e=10-f|0;j=(238636-h|0)/(e|0)|0;c[2113056]=j;k=RG(j)|0;c[2113054]=(c[2113054]|0)+k;c[2276108]=-1;c[2113056]=-1;j=k+h|0;k=(1e5-g|0)/(e|0)|0;do{if((k|0)<1){l=0}else{if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){e=gfc(k)|0;c[2433530]=(c[2433530]|0)+e;l=e;break}else{c[2433530]=(c[2433530]|0)+k;l=k;break}}}while(0);k=c[2112964]|0;if((k|0)==0){m=i;n=0}else{e=a[9688]|0?53:0;o=i<<1;gg[c[3542124]&4095](k+(o<<1)|0,e);k=c[2112964]|0;Uu(0,k+(o<<1)|0,e);m=e+i|0;n=k}k=f+1|0;if((k|0)<10){i=m;g=l+g|0;h=j;f=k}else{break}}c[8452200+(c[2394]<<2)>>2]=8198;c[2276080]=1536;if((c[2276079]|0)>>>0<1536){RH(6);p=c[2112964]|0}else{p=n}do{if((p|0)!=0){n=(a[9688]|0?534:0)-m|0;if((n|0)<=0){break}f=m<<1;gg[c[3542124]&4095](p+(f<<1)|0,n);Uu(0,(c[2112964]|0)+(f<<1)|0,n)}}while(0);p=c[1836236]|0;m=c[9757320+(p<<2)>>2]|0;if((m|0)!=0){n=m;gGC(n|0,9706056,76)|0}c[9752472+(p<<2)>>2]=c[2433530];c[14113936+(p<<2)>>2]=c[2076596];c[9669104+(p<<2)>>2]=c[3541536];c[1836236]=-1;p=c[2394]|0;n=c[14130368+(p<<2)>>2]|0;if((n|0)!=0){gGC(n|0,9104152,280)|0}c[8452240+(p<<2)>>2]=c[2113054];c[2394]=-1;if((c[2112968]|0)==0){return 0}efr()|0;return 0}function efr(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((a[9547392]|0)!=0){f=c[2387182]|0;g=c[3529990]|0;h=0;do{i=b[f+(h<<1)>>1]|0;c[g+(h<<2)>>2]=((i&65535)>>>10<<3&248)<<8|((i&255)<<3&255)>>>3|(((i&65535)>>>5<<3&255|(i&65535)>>>7&4)&255)<<3&2016;h=h+1|0;}while((h|0)<768)}h=c[3529788]|0;g=c[3529784]|0;f=e[g+2>>1]|0;i=c[2406566]|0;j=-5-(e[h+2>>1]|0)|0;k=c[3530976]|0;l=c[2112926]|0;m=c[3530828]|0;n=0;do{o=(n<<4&1008)+j|0;p=(n>>6<<4)-f|0;q=e[i+((n>>>1&992|n&31|n<<5&1024)<<1)>>1]|0;SH(l,d[k+(q>>>10&3)|0]<<10|q&1023,(o|0)<-15?o+1024|0:o,(p|0)<-15?p+512|0:p,q>>>12|32,4,-1,0,m);n=n+1|0;}while((n|0)<2048);n=e[g>>1]|0;g=c[2406488]|0;i=~e[h>>1];h=0;do{f=(h<<4&1008)+i|0;j=(h>>6<<4)-n|0;q=e[g+((h>>>1&992|h&31|h<<5&1024)<<1)>>1]|0;SH(l,d[k+(q>>>10&3)|0]<<10|q&1023,(f|0)<-15?f+1024|0:f,(j|0)<-15?j+512|0:j,q>>>12|16,4,0,0,m);h=h+1|0;}while((h|0)<2048);h=c[2386442]|0;m=c[3530592]|0;k=0;do{g=e[h+((k|2)<<1)>>1]|0;n=315-(g+16&511)|0;i=e[h+(k<<1)>>1]|0;q=i+8|0;j=b[h+((k|1)<<1)>>1]&16383;f=g>>>9;g=1<<(i>>>9&3);if((g|0)>0){p=(i&8192|0)!=0;o=j-1+g|0;if((i&16384|0)==0){if(p){i=0;do{SJ(l,i+j|0,n,257-((g-i<<4)+q&511)|0,f,4,0,0,m);i=i+1|0;}while((i|0)<(g|0))}else{i=0;do{SH(l,i+j|0,n,257-((g-i<<4)+q&511)|0,f,4,0,0,m);i=i+1|0;}while((i|0)<(g|0))}}else{if(p){i=0;do{SN(l,o-i|0,n,257-((g-i<<4)+q&511)|0,f,4,0,0,m);i=i+1|0;}while((i|0)<(g|0))}else{i=0;do{SL(l,o-i|0,n,257-((g-i<<4)+q&511)|0,f,4,0,0,m);i=i+1|0;}while((i|0)<(g|0))}}}k=k+4|0;}while((k|0)<1024);R8(c[3529990]|0);return 0}function efs(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+96|0;g=f|0;h=f+16|0;j=f+32|0;k=f+48|0;l=f+64|0;m=f+80|0;if((e|0)!=0){c[e>>2]=169730}if((b&32|0)!=0){gGz(m|0,0,12);e=c[2414652]|0;c[m>>2]=e;c[m+4>>2]=(c[2411636]|0)-e;c[m+12>>2]=162152;e=c[2076592]|0;gj[e&4095](m)|0}if((b&64|0)==0){i=f;return 0}m=l|0;gGz(k|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){e=l+9|0;l=j;n=j|0;o=j+4|0;p=j+12|0;q=k|0;r=k+4|0;s=k+12|0;t=0;do{gGC(m|0,614896,11)|0;a[e]=t+48&255;u=8452256+(t<<2)|0;gGz(l|0,0,12);c[n>>2]=u;c[o>>2]=4;c[p>>2]=164976;gj[c[2076592]&4095](j)|0;if((c[u>>2]|0)!=0){c[q>>2]=c[14130368+(t<<2)>>2];c[r>>2]=c[8452184+(t<<2)>>2];c[s>>2]=m;u=c[2076592]|0;gj[u&4095](k)|0}t=t+1|0;}while((t|0)<=(c[2392]|0))}fw$(b);gGz(h|0,0,12);c[h>>2]=8453216;c[h+4>>2]=4;c[h+12>>2]=107480;gj[c[2076592]&4095](h)|0;gGz(g|0,0,12);c[g>>2]=14168504;c[g+4>>2]=256;c[g+12>>2]=476464;gj[c[2076592]&4095](g)|0;if((b&2|0)!=0){b=0;do{mv(0,b,d[14168504+b|0]|0);b=b+1|0;}while((b|0)<256)}Ut(0);b=c[3529782]|0;g=a[b]|0;a[b]=g&1;b=c[3541206]|0;h=(c[2386638]|0)+((g&255)<<18&262144^262144)|0;gGC(b|0,h|0,262144)|0;i=f;return 0}function eft(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4474348+(b*112|0)>>2];c[a+104>>2]=c[4474352+(b*112|0)>>2];c[a+108>>2]=c[4474356+(b*112|0)>>2];d=0;return d|0}function efu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=4474248+(b*112|0);e=0;return e|0}function efv(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;if((d&15728640|0)!=0){f=d&1048575;g=c[2112932]|0;h=c[g+((f>>>10|16384)<<2)>>2]|0;if(h>>>0>9){i=d&1023;a[h+i|0]=e&255;a[h+(i+1)|0]=(e&65535)>>>8&255;return}else{gg[c[g+196728+(h<<2)>>2]&4095](f,e);return}}if((d|0)==393216|(d|0)==393218|(d|0)==393220|(d|0)==393222){f=d&6;h=c[3527302]|0;a[h+f|0]=(e&65535)>>>8&255;a[h+(f|1)|0]=e&255;if(a[672816]|0){if((f|0)!=0){return}c[2415252]=0;g=a[h]|0;if((g&255)<16){i=(g&255)<<2;c[2415252]=i;j=i|2}else{j=2}if((a[h+1|0]|0)!=0){c[2415252]=j}c[2385414]=1;return}else{if((f|0)!=2){return}if((c[2415208]|0)!=1){c[2415208]=1;b[4830412]=b[4830412]|1}f4Y(0)|0;if((c[2415208]|0)!=0){c[2415208]=0}c[2385414]=0;return}}else if((d|0)==950272|(d|0)==950274){b[(c[2386722]|0)+((d>>>1&1)<<1)>>1]=e;return}else{return}}function efw(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;if((b&15728640|0)!=0){e=b&1048575;f=c[2112932]|0;g=c[f+((e>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(b&1023^1)|0]=d;return}else{gg[c[f+196648+(g<<2)>>2]&4095](e,d);return}}if((b|0)==933888){a[c[3528694]|0]=d&2;return}else if((b|0)==933890){a[c[3528262]|0]=d;return}else{return}}function efx(e){e=e|0;var f=0,g=0,h=0,i=0,j=0;if((e&15728640|0)!=0){f=e&1048575;g=c[2112932]|0;h=c[g+(f>>>10<<2)>>2]|0;if(h>>>0>9){i=e&1023;j=(d[h+(i+1)|0]|0)<<8|(d[h+i|0]|0);return j|0}else{j=gj[c[g+196688+(h<<2)>>2]&4095](f)|0;return j|0}}if((e|0)==393216){j=c[2415252]&65535;return j|0}else if((e|0)==933890){j=(a[672560]|0?1024:0)^b[4775213];return j|0}else if((e|0)==933892){j=(d[9635025]|0)<<8|(d[9635024]|0);return j|0}else if((e|0)==393222){if((c[2385414]|0)==0){j=255;return j|0}c[2385414]=0;j=0;return j|0}else if((e|0)==393218|(e|0)==393220){f=e&6;h=c[3527302]|0;j=(d[h+(f|1)|0]|0)<<8|(d[h+f|0]|0);return j|0}else if((e|0)==933888){j=b[4775212]|0;return j|0}else{j=0;return j|0}return 0}function efy(b){b=b|0;var d=0,f=0,g=0,h=0;if((b&15728640|0)==0){if((b|0)!=933890){d=0;return d|0}d=((a[672560]|0?1024:0)^(e[4775213]|0))>>>8&255;return d|0}f=b&1048575;g=c[2112932]|0;h=c[g+(f>>>10<<2)>>2]|0;if(h>>>0>9){d=a[h+(b&1023^1)|0]|0;return d|0}else{d=gj[c[g+196608+(h<<2)>>2]&4095](f)|0;return d|0}return 0}function efz(a,b){a=a|0;b=b|0;var c=0;c=a&65535;a=c&255;if((a|0)==0|(a|0)==1){lS(0,c&1,b);return}else if((a|0)==128|(a|0)==129){lS(1,c&1,b);return}else{return}}function efA(b){b=b|0;var d=0;if(b<<16>>16!=-8192){d=0;return d|0}d=a[c[3528262]|0]|0;return d|0}function efB(b,e){b=b|0;e=e|0;var f=0,g=0;f=b&65535;switch(f|0){case 2:{b=c[3527302]|0;g=b+2|0;do{if((a[g]&2)==0){if((e&2)==0){break}c[2415252]=(d[b+1|0]|0)<<8|(d[b]|0);c[2385414]=1}}while(0);a[g]=e;return};case 0:case 1:case 3:case 4:case 5:case 6:case 7:{a[(c[3527302]|0)+f|0]=e;return};default:{return}}}function efC(b){b=b|0;var d=0;if((b&65535)>=8){d=0;return d|0}d=a[(c[3527302]|0)+(b&65535)|0]|0;return d|0}function efD(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4468188+(b*112|0)>>2];c[a+104>>2]=c[4468192+(b*112|0)>>2];c[a+108>>2]=c[4468196+(b*112|0)>>2];d=0;return d|0}function efE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=4468088+(b*112|0);e=0;return e|0}function efF(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1765552+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function efG(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>31){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5139e3+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function efH(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0;e=i;i=i+1440|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;B=e+1200|0;C=e+1312|0;D=e+1320|0;E=e+1432|0;c[2414946]=0;c[2388138]=0;c[2385914]=131072;c[2387324]=196608;c[3530826]=200704;c[3530590]=331776;c[3530424]=856064;c[3530330]=1380352;c[3529988]=1445888;c[2414650]=1448192;c[2388266]=1448192;c[2387180]=1464576;c[2386440]=1466624;c[2386208]=1470720;c[2386068]=1472768;c[2387336]=1474816;c[3527302]=1474944;c[2386722]=1474952;c[3528262]=1474956;c[3528694]=1474957;c[2411634]=1474958;F=0;while(1){if((F|0)>=1024){break}G=9638528+(F<<2)|0;if((c[G>>2]|0)==0){H=56011;break}else{F=F+1|0}}do{if((H|0)==56011){F=gGq(1474958)|0;c[G>>2]=F;if((F|0)==0){break}c[2414946]=F;gGz(F|0,0,1474958);c[2388138]=F;c[2385914]=F+131072;c[2387324]=F+196608;c[3530826]=F+200704;c[3530590]=F+331776;c[3530424]=F+856064;c[3530330]=F+1380352;c[3529988]=F+1445888;I=F+1448192|0;c[2414650]=I;c[2388266]=I;c[2387180]=F+1464576;c[2386440]=F+1466624;c[2386208]=F+1470720;c[2386068]=F+1472768;c[2387336]=F+1474816;c[3527302]=F+1474944;c[2386722]=F+1474952;c[3528262]=F+1474956;c[3528694]=F+1474957;I=F+1474958|0;c[2411634]=I;c[2414172]=I;if((R6(F+1|0,0,2)|0)!=0){J=1;i=e;return J|0}if((R6(c[2388138]|0,1,2)|0)!=0){J=1;i=e;return J|0}F=c[2385914]|0;if((c[3542200]|0)==0){J=1;i=e;return J|0}I=D+108|0;c[I>>2]=0;K=D+100|0;c[K>>2]=0;L=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[L&16383](D,2)|0;do{if((c[I>>2]|0)!=0){L=c[K>>2]|0;c[E>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](E,2,0)|0;if((L|0)<1){J=1;i=e;return J|0}if((gzL(F,0,2)|0)==0){break}else{J=1}i=e;return J|0}}while(0);F=c[2387324]|0;do{if((c[3542200]|0)!=0){K=B+108|0;c[K>>2]=0;I=B+100|0;c[I>>2]=0;L=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[L&16383](B,3)|0;if((c[K>>2]|0)==0){break}K=c[I>>2]|0;c[C>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](C,3,0)|0;if((K|0)<1){break}gzL(F,0,3)|0}}while(0);F=c[3530826]|0;if((c[3542200]|0)==0){J=1;i=e;return J|0}K=z+108|0;c[K>>2]=0;I=z+100|0;c[I>>2]=0;L=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[L&16383](z,4)|0;do{if((c[K>>2]|0)!=0){L=c[I>>2]|0;c[A>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](A,4,0)|0;if((L|0)<1){J=1;i=e;return J|0}if((gzL(F,0,4)|0)==0){break}else{J=1}i=e;return J|0}}while(0);F=c[3530590]|0;if((c[3542200]|0)==0){J=1;i=e;return J|0}I=x+108|0;c[I>>2]=0;K=x+100|0;c[K>>2]=0;L=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[L&16383](x,5)|0;do{if((c[I>>2]|0)!=0){L=c[K>>2]|0;c[y>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](y,5,0)|0;if((L|0)<1){J=1;i=e;return J|0}if((gzL(F,0,5)|0)==0){break}else{J=1}i=e;return J|0}}while(0);F=(c[3530590]|0)+65536|0;if((c[3542200]|0)==0){J=1;i=e;return J|0}K=v+108|0;c[K>>2]=0;I=v+100|0;c[I>>2]=0;L=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[L&16383](v,6)|0;do{if((c[K>>2]|0)!=0){L=c[I>>2]|0;c[w>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](w,6,0)|0;if((L|0)<1){J=1;i=e;return J|0}if((gzL(F,0,6)|0)==0){break}else{J=1}i=e;return J|0}}while(0);F=(c[3530590]|0)+131072|0;if((c[3542200]|0)==0){J=1;i=e;return J|0}I=t+108|0;c[I>>2]=0;K=t+100|0;c[K>>2]=0;L=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[L&16383](t,7)|0;do{if((c[I>>2]|0)!=0){L=c[K>>2]|0;c[u>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](u,7,0)|0;if((L|0)<1){J=1;i=e;return J|0}if((gzL(F,0,7)|0)==0){break}else{J=1}i=e;return J|0}}while(0);F=(c[3530590]|0)+196608|0;if((c[3542200]|0)==0){J=1;i=e;return J|0}K=r+108|0;c[K>>2]=0;I=r+100|0;c[I>>2]=0;L=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[L&16383](r,8)|0;do{if((c[K>>2]|0)!=0){L=c[I>>2]|0;c[s>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](s,8,0)|0;if((L|0)<1){J=1;i=e;return J|0}if((gzL(F,0,8)|0)==0){break}else{J=1}i=e;return J|0}}while(0);F=c[3530424]|0;if((c[3542200]|0)==0){J=1;i=e;return J|0}I=p+108|0;c[I>>2]=0;K=p+100|0;c[K>>2]=0;L=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[L&16383](p,9)|0;do{if((c[I>>2]|0)!=0){L=c[K>>2]|0;c[q>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](q,9,0)|0;if((L|0)<1){J=1;i=e;return J|0}if((gzL(F,0,9)|0)==0){break}else{J=1}i=e;return J|0}}while(0);F=(c[3530424]|0)+65536|0;if((c[3542200]|0)==0){J=1;i=e;return J|0}K=n+108|0;c[K>>2]=0;I=n+100|0;c[I>>2]=0;L=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[L&16383](n,10)|0;do{if((c[K>>2]|0)!=0){L=c[I>>2]|0;c[o>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](o,10,0)|0;if((L|0)<1){J=1;i=e;return J|0}if((gzL(F,0,10)|0)==0){break}else{J=1}i=e;return J|0}}while(0);F=(c[3530424]|0)+131072|0;if((c[3542200]|0)==0){J=1;i=e;return J|0}I=l+108|0;c[I>>2]=0;K=l+100|0;c[K>>2]=0;L=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[L&16383](l,11)|0;do{if((c[I>>2]|0)!=0){L=c[K>>2]|0;c[m>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](m,11,0)|0;if((L|0)<1){J=1;i=e;return J|0}if((gzL(F,0,11)|0)==0){break}else{J=1}i=e;return J|0}}while(0);F=(c[3530424]|0)+196608|0;if((c[3542200]|0)==0){J=1;i=e;return J|0}K=j+108|0;c[K>>2]=0;I=j+100|0;c[I>>2]=0;L=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[L&16383](j,12)|0;do{if((c[K>>2]|0)!=0){L=c[I>>2]|0;c[k>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](k,12,0)|0;if((L|0)<1){J=1;i=e;return J|0}if((gzL(F,0,12)|0)==0){break}else{J=1}i=e;return J|0}}while(0);F=c[3530330]|0;if((c[3542200]|0)==0){J=1;i=e;return J|0}I=f+108|0;c[I>>2]=0;K=f+100|0;c[K>>2]=0;L=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[L&16383](f,13)|0;do{if((c[I>>2]|0)==0){N=0}else{L=c[K>>2]|0;c[g>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](g,13,0)|0;if((L|0)<1){J=1;i=e;return J|0}if((gzL(F,0,13)|0)==0){N=0;break}else{J=1}i=e;return J|0}}while(0);while(1){if((N|0)>=1024){break}O=9638528+(N<<2)|0;if((c[O>>2]|0)==0){H=56065;break}else{N=N+1|0}}L74387:do{if((H|0)==56065){F=gGq(262144)|0;c[O>>2]=F;if((F|0)==0){break}gGz(F|0,0,262144);K=c[3530826]|0;gGC(F|0,K|0,32768)|0;I=0;do{L=I<<6;gGz(K+L|0,0,64);M=I<<7;P=M|4;Q=0;while(1){R=P+(c[609168+(Q<<2)>>2]|0)|0;S=(Q<<3)+L|0;T=0;do{U=R+(c[610736+(T<<2)>>2]|0)|0;if(((d[F+((U|0)/8|0)|0]|0)&128>>>((U&7)>>>0)|0)!=0){U=K+(S+T)|0;a[U]=a[U]|2}T=T+1|0;}while((T|0)<8);T=Q+1|0;if((T|0)<8){Q=T}else{V=0;break}}do{Q=M+(c[609168+(V<<2)>>2]|0)|0;P=(V<<3)+L|0;T=0;do{S=Q+(c[610736+(T<<2)>>2]|0)|0;if(((d[F+((S|0)/8|0)|0]|0)&128>>>((S&7)>>>0)|0)!=0){S=K+(P+T)|0;a[S]=a[S]|1}T=T+1|0;}while((T|0)<8);V=V+1|0;}while((V|0)<8);I=I+1|0;}while((I|0)<2048);I=c[3530590]|0;gGC(F|0,I|0,262144)|0;K=0;do{L=K<<8;gGz(I+L|0,0,256);M=0;do{T=1<<3-M;P=(c[611312+(M<<2)>>2]|0)+L|0;Q=0;do{S=P+(c[609008+(Q<<2)>>2]|0)|0;R=(Q<<4)+L|0;U=0;do{W=S+(c[597864+(U<<2)>>2]|0)|0;if(((d[F+((W|0)/8|0)|0]|0)&128>>>((W&7)>>>0)|0)!=0){W=I+(R+U)|0;a[W]=(d[W]|0|T)&255}U=U+1|0;}while((U|0)<16);Q=Q+1|0;}while((Q|0)<16);M=M+1|0;}while((M|0)<4);K=K+1|0;}while((K|0)<2048);K=c[3530424]|0;gGC(F|0,K|0,262144)|0;I=0;while(1){M=I<<10;gGz(K+M|0,0,1024);L=I<<11;Q=0;do{T=1<<3-Q;P=(c[611296+(Q<<2)>>2]|0)+L|0;U=0;do{R=P+(c[609168+(U<<2)>>2]|0)|0;S=(U<<5)+M|0;W=0;do{X=R+(c[610736+(W<<2)>>2]|0)|0;if(((d[F+((X|0)/8|0)|0]|0)&128>>>((X&7)>>>0)|0)!=0){X=K+(S+W)|0;a[X]=(d[X]|0|T)&255}W=W+1|0;}while((W|0)<32);U=U+1|0;}while((U|0)<32);Q=Q+1|0;}while((Q|0)<4);Q=I+1|0;if((Q|0)<512){I=Q}else{Y=0;break}}while(1){if((Y|0)>=1024){break L74387}Z=9638528+(Y<<2)|0;if((c[Z>>2]|0)==(F|0)){break}else{Y=Y+1|0}}gGr(F);c[Z>>2]=0}}while(0);fxU(0,425984);if((c[2394]|0)==0){_=c[2112932]|0}else{c[2394]=0;I=c[3532596]|0;c[2112932]=I;K=c[3532592]|0;if((K|0)!=0){gGC(9104152,K|0,280)|0}c[2113054]=c[2113060];_=I}I=c[2388138]|0;K=_|0;Q=0;while(1){M=I+Q|0;c[K>>2]=M;c[K+131072>>2]=M;M=Q+1024|0;if(M>>>0>131071){break}else{K=K+4|0;Q=M}}Q=c[2386440]|0;c[_+3592>>2]=Q;c[_+69128>>2]=Q;c[_+134664>>2]=Q;K=Q+1024|0;c[_+3596>>2]=K;c[_+69132>>2]=K;c[_+134668>>2]=K;K=Q+2048|0;c[_+3600>>2]=K;c[_+69136>>2]=K;c[_+134672>>2]=K;K=Q+3072|0;c[_+3604>>2]=K;c[_+69140>>2]=K;c[_+134676>>2]=K;K=c[2386208]|0;c[_+3776>>2]=K;c[_+69312>>2]=K;c[_+134848>>2]=K;Q=K+1024|0;c[_+3780>>2]=Q;c[_+69316>>2]=Q;c[_+134852>>2]=Q;Q=c[2387180]|0;c[_+3968>>2]=Q;c[_+69504>>2]=Q;c[_+135040>>2]=Q;K=Q+1024|0;c[_+3972>>2]=K;c[_+69508>>2]=K;c[_+135044>>2]=K;K=c[2388266]|0;c[_+4032>>2]=K;c[_+69568>>2]=K;c[_+135104>>2]=K;Q=K+1024|0;c[_+4036>>2]=Q;c[_+69572>>2]=Q;c[_+135108>>2]=Q;Q=K+2048|0;c[_+4040>>2]=Q;c[_+69576>>2]=Q;c[_+135112>>2]=Q;Q=K+3072|0;c[_+4044>>2]=Q;c[_+69580>>2]=Q;c[_+135116>>2]=Q;Q=K+4096|0;c[_+4048>>2]=Q;c[_+69584>>2]=Q;c[_+135120>>2]=Q;Q=K+5120|0;c[_+4052>>2]=Q;c[_+69588>>2]=Q;c[_+135124>>2]=Q;Q=K+6144|0;c[_+4056>>2]=Q;c[_+69592>>2]=Q;c[_+135128>>2]=Q;Q=K+7168|0;c[_+4060>>2]=Q;c[_+69596>>2]=Q;c[_+135132>>2]=Q;Q=K+8192|0;c[_+4064>>2]=Q;c[_+69600>>2]=Q;c[_+135136>>2]=Q;Q=K+9216|0;c[_+4068>>2]=Q;c[_+69604>>2]=Q;c[_+135140>>2]=Q;Q=K+10240|0;c[_+4072>>2]=Q;c[_+69608>>2]=Q;c[_+135144>>2]=Q;Q=K+11264|0;c[_+4076>>2]=Q;c[_+69612>>2]=Q;c[_+135148>>2]=Q;Q=K+12288|0;c[_+4080>>2]=Q;c[_+69616>>2]=Q;c[_+135152>>2]=Q;Q=K+13312|0;c[_+4084>>2]=Q;c[_+69620>>2]=Q;c[_+135156>>2]=Q;Q=K+14336|0;c[_+4088>>2]=Q;c[_+69624>>2]=Q;c[_+135160>>2]=Q;Q=K+15360|0;c[_+4092>>2]=Q;c[_+69628>>2]=Q;c[_+135164>>2]=Q;c[_+196728>>2]=2732;c[_+196648>>2]=3024;c[_+196688>>2]=712;c[_+196608>>2]=2138;Q=c[3532592]|0;if((Q|0)!=0){gGC(Q|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);Q=c[2439330]|0;K=(Q|0)==0;if(!K){I=Q;gGC(9706056,I|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];I=c[3528484]|0;c[2076596]=I;M=c[2417276]|0;c[3541536]=M;c[1836236]=0;L=c[2385914]|0;U=0;T=0;while(1){c[Q+76+(T<<2)>>2]=L+(T<<8);P=U+1&65535;if((P&65535)>127){$=0;aa=0;break}else{U=P;T=P&65535}}while(1){T=L+(aa<<8)|0;c[Q+76+(aa+512<<2)>>2]=T;c[Q+76+(aa+768<<2)>>2]=T;T=$+1&65535;if((T&65535)>127){break}else{$=T;aa=T&65535}}L=c[2386068]|0;T=L+256|0;U=L+512|0;P=L+768|0;W=L+1024|0;S=L+1280|0;R=L+1536|0;X=L+1792|0;c[Q+1868>>2]=L;c[Q+1872>>2]=T;c[Q+1876>>2]=U;c[Q+1880>>2]=P;c[Q+1884>>2]=W;c[Q+1888>>2]=S;c[Q+1892>>2]=R;c[Q+1896>>2]=X;c[Q+844>>2]=L;c[Q+848>>2]=T;c[Q+852>>2]=U;c[Q+856>>2]=P;c[Q+860>>2]=W;c[Q+864>>2]=S;c[Q+868>>2]=R;c[Q+872>>2]=X;c[Q+4180>>2]=1548;c[Q+4176>>2]=2030;if(!K){X=Q;gGC(X|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=I;c[2417276]=M;c[1836236]=-1;c[2443666]=4095;c[2385780]=15;c[3528996]=4;gGz(9702704,0,64);gGz(9703728,0,64);gGz(9704752,0,64);X=c[2427044]|0;c[9681616+(X<<3)>>2]=809328;c[9681620+(X<<3)>>2]=0;c[2427044]=X+1;X=c[2387336]|0;R=1;do{S=X+((R<<4)-16)|0;c[9702704+(R<<2)>>2]=S;c[9703728+(R<<2)>>2]=S;c[9704752+(R<<2)>>2]=S;R=R+1|0;}while((R|0)<8);R=c[2387324]|0;X=8;do{M=R+(X<<4)|0;c[9702704+(X<<2)>>2]=M;c[9704752+(X<<2)>>2]=M;X=X+1|0;}while((X|0)<256);c[3528586]=2838;c[2385590]=2904;Vr(2,2e6,1372,2804,8,0);c[2438228]=4e6;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=511;h[745419]=.4;a[3203368]=1;h[745418]=.4;a[3203360]=1;h[745417]=.4;a[3203352]=1;h[745416]=.4;a[3203344]=1;h[745415]=.4;a[3203336]=1;h[745414]=.4;a[3203328]=1;h[745413]=.4;a[3203320]=1;h[745412]=.4;a[3203312]=1;X=c[642608+(c[2436]<<2)>>2]|0;R=c[X+128>>2]|0;if((c[X+52>>2]&4|0)==0){c[2113068]=R;M=c[X+132>>2]|0;c[2113070]=M;c[2443814]=R;c[2440436]=M;ab=R;ac=M}else{c[2113070]=R;M=c[X+132>>2]|0;c[2113068]=M;c[2440436]=R;c[2443814]=M;ab=M;ac=R}R=ag(ab<<1,ac)|0;M=gGq(R)|0;c[2112926]=M;if((M|0)!=0){gGz(M|0,0,R|0)}a[9624072]=0;R=c[2414650]|0;gGz(R|0,0,(c[2411634]|0)-R|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];R=c[3532592]|0;if((R|0)!=0){gGC(9104152,R|0,280)|0}c[2113054]=c[2113060]}RI();R=c[2394]|0;M=c[14130368+(R<<2)>>2]|0;if((M|0)!=0){gGC(M|0,9104152,280)|0}c[8452240+(R<<2)>>2]=c[2113054];c[2394]=-1;R=c[2439330]|0;M=(R|0)==0;if(!M){X=R;gGC(9706056,X|0,76)|0}X=c[2438118]|0;c[2433530]=X;I=c[3528484]|0;c[2076596]=I;Q=c[2417276]|0;c[3541536]=Q;c[1836236]=0;gGz(9706056,0,76);if(!M){M=R;gGC(M|0,9706056,76)|0}c[2438118]=X;c[3528484]=I;c[2417276]=Q;c[1836236]=-1;f42();c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){Q=0;do{lN(Q);mB(Q);Q=Q+1|0;}while((Q|0)<(c[2385508]|0))}c[2415252]=1024;c[2385414]=0;J=0;i=e;return J|0}}while(0);c[2414946]=0;J=1;i=e;return J|0}function efI(){var b=0,d=0,e=0,f=0,g=0;c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}if((c[2392]|0)>=0){b=0;do{d=14130368+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}d=14130384+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}b=b+1|0;}while((b|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;fwZ();c[2443666]=0;c[2385780]=0;c[3528996]=0;b=c[3541518]|0;if((b|0)!=0){gGr(b|0);c[3541518]=0}if((c[2385508]|0)>0){c[2113008]=0;c[2076598]=0;c[2383582]=0}c[2438228]=0;c[2433526]=0;c[2406676]=0;c[3528472]=0;b=c[2406680]|0;if((b|0)!=0){gGr(b);c[2406680]=0}c[2385508]=0;c[2432978]=0;a[64240]=0;b=c[2414946]|0;d=0;while(1){if((d|0)>=1024){f=56197;break}g=9638528+(d<<2)|0;if((c[g>>2]|0)==(b|0)){break}else{d=d+1|0}}if((f|0)==56197){c[2414946]=0;a[672816]=0;return 0}gGr(b);c[g>>2]=0;c[2414946]=0;a[672816]=0;return 0}function efJ(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0;if((a[9624072]|0)!=0){a[9624072]=0;d=c[2414650]|0;gGz(d|0,0,(c[2411634]|0)-d|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=i;c[1836236]=-1;f42();c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){i=0;do{lN(i);mB(i);i=i+1|0;}while((i|0)<(c[2385508]|0))}c[2415252]=1024;c[2385414]=0}i=c[2385548]|0;if((i|0)>0){gGz(9752472,0,((i|0)>1?i<<2:4)|0)}c[2433530]=0;c[2387606]=-1;i=0;g=-1;f=-1;do{g=((a[9633280+i|0]&1)<<i^g&65535)&65535;f=((a[9631152+i|0]&1)<<i^f&65535)&65535;i=i+1|0;}while((i|0)<16);b[4775212]=g;b[4775213]=f;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060]}f=c[2439330]|0;if((f|0)!=0){g=f;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;a[672560]=0;g=0;do{do{if((g|0)==240){j=0;k=56226}else if((g|0)==16){j=1;k=56226}else{c[2113056]=520;f=RG(520)|0;c[2113054]=(c[2113054]|0)+f;c[2276108]=-1;c[2113056]=-1;if((g|0)!=255){break}c[8452200+(c[2394]<<2)>>2]=8194;c[2276080]=512;if((c[2276079]|0)>>>0>=512){break}RH(2)}}while(0);if((k|0)==56226){k=0;a[672560]=j;c[2113056]=520;f=RG(520)|0;c[2113054]=(c[2113054]|0)+f;c[2276108]=-1;c[2113056]=-1}if(!(a[672816]|0)){f4Y(260)|0}Sb(g*260|0);g=g+1|0;}while((g|0)<256);if((c[2112964]|0)!=0){g=c[2438228]|0;j=gGS(-747372544,31788,g,(g|0)<0|0?-1:0)|0;g=j;Sb(66666);j=c[2443830]|0;if((j|0)<1073676288){c[2443830]=j-g}j=c[2443831]|0;if((j|0)<1073676288){c[2443831]=j-g}j=(c[3528512]|0)-g|0;c[3528512]=(j|0)<0?0:j;gg[c[3542122]&4095](c[2112964]|0,a[9688]|0?534:0)}j=c[1836236]|0;g=c[9757320+(j<<2)>>2]|0;if((g|0)!=0){k=g;gGC(k|0,9706056,76)|0}c[9752472+(j<<2)>>2]=c[2433530];c[14113936+(j<<2)>>2]=c[2076596];c[9669104+(j<<2)>>2]=c[3541536];c[1836236]=-1;j=c[2394]|0;k=c[14130368+(j<<2)>>2]|0;if((k|0)!=0){gGC(k|0,9104152,280)|0}c[8452240+(j<<2)>>2]=c[2113054];c[2394]=-1;if((c[2112968]|0)==0){return 0}efK()|0;return 0}function efK(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;if((a[9547384]|0)!=0){f=c[2387180]|0;g=c[3529988]|0;h=256;do{i=b[f+(h<<1)>>1]|0;j=i&255;k=(i&65535)>>>8;l=(i&65535)>>>4;c[g+(h-256<<2)>>2]=((l&12|l<<4&255)&255)<<3&2016|((j&8|j<<4)&255)>>>3|((k&8|k<<4&255)&255)<<8&63488;h=h+1|0;}while((h|0)<832)}h=c[2386722]|0;g=b[h>>1]&4095;f=3856-(e[h+2>>1]|0)&2047;h=c[3530330]|0;k=c[2112926]|0;j=c[3530424]|0;l=c[2113070]|0;i=c[2113068]|0;m=0;do{n=m>>7;o=(n<<5)-f|0;p=(o|0)<-31?o+2048|0:o;o=(m<<5&4064)-g|0;q=(o|0)<-31?o+4096|0:o;do{if((p|0)<(l|0)&(q|0)<(i|0)){o=~n;r=(m<<3&960|m&7|o<<3&56|o<<7&7168)<<1;o=d[h+(r|1)|0]|0;s=o<<2&256|d[h+r|0];r=o&15;if((o&32|0)==0){SP(k,s,q,p,r,4,0,j);break}else{SR(k,s,q,p,r,4,0,j);break}}}while(0);m=m+1|0;}while((m|0)<8192);m=c[2386440]|0;j=c[3528694]|0;h=c[3530590]|0;i=2044;do{g=e[m+((i|3)<<1)>>1]|0;f=g&511;do{if((f|0)!=384){p=f>>>0>255?g|-512:f;q=e[m+((i|2)<<1)>>1]|0;n=e[m+((i|1)<<1)>>1]|0;r=n>>>2&15;s=b[m+(i<<1)>>1]&2047;o=n&2;t=n&1;if((a[j]|0)==0){u=t;v=o;w=p;x=240-q|0}else{u=t^1;v=o>>>1^1;w=240-p|0;x=q}q=x-16|0;p=(v|0)!=0;if((u|0)==0){if(p){SJ(k,s,w,q,r,4,15,256,h);break}else{SH(k,s,w,q,r,4,15,256,h);break}}else{if(p){SN(k,s,w,q,r,4,15,256,h);break}else{SL(k,s,w,q,r,4,15,256,h);break}}}}while(0);i=i-4|0;}while((i|0)>-1);i=c[2386208]|0;h=c[3530826]|0;w=0;do{u=w<<3&248;v=(w>>5<<3)-16|0;do{if((v|0)>-1&(v|0)<(l|0)){x=e[i+(w<<1)>>1]|0;j=x>>>6&768|x&255|x>>>3&1024;m=x>>>8&15;if((x&4096|0)==0){Sq(k,j,u,v,m,2,3,512,h);break}else{Su(k,j,u,v,m,2,3,512,h);break}}}while(0);w=w+1|0;}while((w|0)<1024);R8(c[3529988]|0);return 0}function efL(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=i;i=i+112|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;l=e+80|0;m=e+96|0;if((d|0)!=0){c[d>>2]=169735}if((b&32|0)!=0){gGz(m|0,0,12);n=c[2414650]|0;c[m>>2]=n;c[m+4>>2]=(c[2411634]|0)-n;c[m+12>>2]=162152;n=c[2076592]|0;gj[n&4095](m)|0}if((b&64|0)==0){i=e;return 0}m=j|0;gGz(h|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){n=j+9|0;j=g;o=g|0;p=g+4|0;q=g+12|0;r=h|0;s=h+4|0;t=h+12|0;u=0;do{gGC(m|0,614896,11)|0;a[n]=u+48&255;v=8452256+(u<<2)|0;gGz(j|0,0,12);c[o>>2]=v;c[p>>2]=4;c[q>>2]=164976;gj[c[2076592]&4095](g)|0;if((c[v>>2]|0)!=0){c[r>>2]=c[14130368+(u<<2)>>2];c[s>>2]=c[8452184+(u<<2)>>2];c[t>>2]=m;v=c[2076592]|0;gj[v&4095](h)|0}u=u+1|0;}while((u|0)<=(c[2392]|0))}fw$(b);u=c[2415207]|0;gGz(f|0,0,12);c[f>>2]=9660800;c[f+4>>2]=76;c[f+12>>2]=162384;gj[c[2076592]&4095](f)|0;c[2415207]=u;Vx(b,d);gGz(l|0,0,12);c[l>>2]=9541656;c[l+4>>2]=4;c[l+12>>2]=104832;gj[c[2076592]&4095](l)|0;gGz(k|0,0,12);c[k>>2]=9661008;c[k+4>>2]=4;c[k+12>>2]=102088;gj[c[2076592]&4095](k)|0;i=e;return 0}function efM(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2422708+(b*112|0)>>2];c[a+104>>2]=c[2422712+(b*112|0)>>2];c[a+108>>2]=c[2422716+(b*112|0)>>2];d=0;return d|0}function efN(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=2422608+(b*112|0);e=0;return e|0}function efO(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2421028+(b*112|0)>>2];c[a+104>>2]=c[2421032+(b*112|0)>>2];c[a+108>>2]=c[2421036+(b*112|0)>>2];d=0;return d|0}function efP(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=2420928+(b*112|0);e=0;return e|0}function efQ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5946452+(b*112|0)>>2];c[a+104>>2]=c[5946456+(b*112|0)>>2];c[a+108>>2]=c[5946460+(b*112|0)>>2];d=0;return d|0}function efR(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=5946352+(b*112|0);e=0;return e|0}function efS(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4243192+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function efT(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>34){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6419944+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function efU(){a[672816]=1;return efH()|0}function efV(b,c){b=b|0;c=c|0;a[9706117]=c&1;return}function efW(a){a=a|0;var b=0,d=0;b=(c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,4e6,0)|0;return a|0}function efX(){return+(+((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)/4.0e6)}function efY(a){a=a|0;var b=0;if((a|0)!=4194305){b=0;return b|0}b=c[2113156]&255;return b|0}function efZ(a){a=a|0;var b=0;if((a|0)==8388612){b=~((d[9625661]|0)<<8|(d[9625660]|0));return b|0}else if((a|0)==8388608){b=~((d[9625657]|0)<<8|(d[9625656]|0));return b|0}else if((a|0)==8388610){b=~((d[9625659]|0)<<8|(d[9625658]|0));return b|0}else{b=0;return b|0}return 0}function ef_(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;if((a|0)==9437184){d=b&15;c[2406810]=d;e=c[2411320]|0;f=e+196608|0;g=e+((d<<16)+262144)|0;gGC(f|0,g|0,65536)|0;return}else if((a|0)==4194305){Uv(0,b);return}else{return}}function ef$(a){a=a|0;var b=0;if((a|0)==8388614|(a|0)==8388616){b=(cT()|0)&255}else if((a|0)==13107200|(a|0)==13631488|(a|0)==15728640|(a|0)==16252928){b=c[2113156]&255}else if((a|0)==8388618|(a|0)==8388620){b=(cT()|0)&255}else{b=0}return b|0}function ef0(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;if((a|0)==9437184|(a|0)==9437185){d=b&15;c[2406810]=d;e=c[2411320]|0;f=e+196608|0;g=e+((d<<16)+262144)|0;gGC(f|0,g|0,65536)|0;return}else if((a|0)==12582912|(a|0)==13107200|(a|0)==13631488|(a|0)==15728640|(a|0)==16252928){Uv(0,b);return}else{return}}function ef1(a,d){a=a|0;d=d|0;var e=0;e=a-5767168|0;if(e>>>0>=16384){return}a=e>>>1<<3;e=c[2418184]|0;b[e+(a<<1)>>1]=d;b[e+((a|1)<<1)>>1]=d;b[e+((a|2)<<1)>>1]=d;b[e+((a|3)<<1)>>1]=d;b[e+((a|4)<<1)>>1]=d;b[e+((a|5)<<1)>>1]=d;b[e+((a|6)<<1)>>1]=d;c[2411898]=e;b[e+((a|7)<<1)>>1]=d;return}function ef2(a){a=a|0;var b=0,d=0;if((a|0)==8388612){b=((gj[c[(c[2112932]|0)+196608>>2]&4095](8388612)|0)&255)<<8;d=(gj[c[(c[2112932]|0)+196608>>2]&4095](8388613)|0)&255|b;return d|0}else if((a|0)==8388610){b=((gj[c[(c[2112932]|0)+196608>>2]&4095](8388610)|0)&255)<<8;d=(gj[c[(c[2112932]|0)+196608>>2]&4095](8388611)|0)&255|b;return d|0}else if((a|0)==8388608){a=((gj[c[(c[2112932]|0)+196608>>2]&4095](8388608)|0)&255)<<8;d=(gj[c[(c[2112932]|0)+196608>>2]&4095](8388609)|0)&255|a;return d|0}else{d=0;return d|0}return 0}function ef3(b){b=b|0;var d=0;if((b|0)==8388609){d=~a[9625656]}else if((b|0)==12582912|(b|0)==13631488){d=c[2113156]&255}else if((b|0)==8388612|(b|0)==8388613){d=~a[9625661]}else if((b|0)==8388610){d=~a[9625659]}else if((b|0)==8388608){d=~a[9625657]}else if((b|0)==8388611){d=~a[9625658]}else{d=0}return d|0}function ef4(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=c[2411326]|0;e=c[2406598]|0;f=8191;while(1){g=f<<7;h=g|35;i=f<<8;j=g|34;k=g|33;l=g|32;m=8;n=15;while(1){o=(n|0)==7?0:m;p=o+n<<2;q=b+(p+h)|0;r=(n<<4)+i|0;a[e+(r|15)|0]=a[q]&15;a[e+(r|14)|0]=(d[q]|0)>>>4;q=b+(p+j)|0;a[e+(r|13)|0]=a[q]&15;a[e+(r|12)|0]=(d[q]|0)>>>4;q=b+(p+k)|0;a[e+(r|11)|0]=a[q]&15;a[e+(r|10)|0]=(d[q]|0)>>>4;q=b+(p+l)|0;a[e+(r|9)|0]=a[q]&15;a[e+(r|8)|0]=(d[q]|0)>>>4;q=b+((p|3)+g)|0;a[e+(r|7)|0]=a[q]&15;a[e+(r|6)|0]=(d[q]|0)>>>4;q=b+((p|2)+g)|0;a[e+(r|5)|0]=a[q]&15;a[e+(r|4)|0]=(d[q]|0)>>>4;q=b+((p|1)+g)|0;a[e+(r|3)|0]=a[q]&15;a[e+(r|2)|0]=(d[q]|0)>>>4;q=b+(p+g)|0;a[e+(r|1)|0]=a[q]&15;a[e+r|0]=(d[q]|0)>>>4;if((n|0)>0){m=o;n=n-1|0}else{break}}if((f|0)>0){f=f-1|0}else{break}}return}function ef5(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3927188+(b*112|0)>>2];c[a+104>>2]=c[3927192+(b*112|0)>>2];c[a+108>>2]=c[3927196+(b*112|0)>>2];d=0;return d|0}function ef6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=3927088+(b*112|0);e=0;return e|0}function ef7(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1260048+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function ef8(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>27){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3928544+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function ef9(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=i;i=i+360|0;d=b|0;e=b+112|0;f=b+120|0;g=b+232|0;h=b+240|0;j=b+352|0;c[2426708]=0;c[2411332]=0;c[2411326]=4194304;c[2406598]=4194560;c[2411320]=6291712;c[2405642]=7602432;c[2418178]=7602432;c[2418184]=7733504;c[2411424]=7864576;c[2411370]=7866624;c[2411630]=7885056;c[2385758]=7885056;c[2385766]=7889152;c[2414170]=8020224;k=0;while(1){if((k|0)>=1024){break}l=9638528+(k<<2)|0;if((c[l>>2]|0)==0){m=56433;break}else{k=k+1|0}}do{if((m|0)==56433){k=gGq(8020224)|0;c[l>>2]=k;if((k|0)==0){break}c[2426708]=k;gGz(k|0,0,8020224);c[2411332]=k;c[2411326]=k+4194304;c[2406598]=k+4194560;c[2411320]=k+6291712;n=k+7602432|0;c[2405642]=n;c[2418178]=n;c[2418184]=k+7733504;c[2411424]=k+7864576;c[2411370]=k+7866624;n=k+7885056|0;c[2411630]=n;c[2385758]=n;c[2385766]=k+7889152;c[2414170]=k+8020224;if((R6(k+1|0,0,2)|0)!=0){o=1;i=b;return o|0}if((R6(c[2411332]|0,1,2)|0)!=0){o=1;i=b;return o|0}if((R6((c[2411332]|0)+1|0,2,2)|0)!=0){o=1;i=b;return o|0}if((R6(c[2411332]|0,3,2)|0)!=0){o=1;i=b;return o|0}if((R6((c[2411332]|0)+1048576|0,4,2)|0)!=0){o=1;i=b;return o|0}if((R6((c[2411332]|0)+1048577|0,5,2)|0)!=0){o=1;i=b;return o|0}if((R6((c[2411332]|0)+2097152|0,6,2)|0)!=0){o=1;i=b;return o|0}if((R6((c[2411332]|0)+2097153|0,7,2)|0)!=0){o=1;i=b;return o|0}if((R6((c[2411332]|0)+3145728|0,8,2)|0)!=0){o=1;i=b;return o|0}if((R6((c[2411332]|0)+3145729|0,9,2)|0)!=0){o=1;i=b;return o|0}k=c[2411326]|0;if((c[3542200]|0)==0){o=1;i=b;return o|0}n=h+108|0;c[n>>2]=0;p=h+100|0;c[p>>2]=0;q=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[q&16383](h,10)|0;do{if((c[n>>2]|0)!=0){q=c[p>>2]|0;c[j>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](j,10,0)|0;if((q|0)<1){o=1;i=b;return o|0}if((gzL(k,0,10)|0)==0){break}else{o=1}i=b;return o|0}}while(0);ef4();k=(c[2411320]|0)+262144|0;do{if((c[3542200]|0)!=0){p=f+108|0;c[p>>2]=0;n=f+100|0;c[n>>2]=0;q=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[q&16383](f,11)|0;if((c[p>>2]|0)==0){break}p=c[n>>2]|0;c[g>>2]=9534384;n=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[n&16383](g,11,0)|0;if((p|0)<1){break}gzL(k,0,11)|0}}while(0);k=(c[2411320]|0)+786432|0;do{if((c[3542200]|0)!=0){p=d+108|0;c[p>>2]=0;n=d+100|0;c[n>>2]=0;q=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[q&16383](d,12)|0;if((c[p>>2]|0)==0){break}p=c[n>>2]|0;c[e>>2]=9534384;n=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[n&16383](e,12,0)|0;if((p|0)<1){break}gzL(k,0,12)|0}}while(0);k=c[2411320]|0;p=k+262144|0;gGC(k|0,p|0,262144)|0;fxU(0,425984);if((c[2394]|0)==0){s=c[2112932]|0}else{c[2394]=0;p=c[3532596]|0;c[2112932]=p;k=c[3532592]|0;if((k|0)!=0){gGC(9104152,k|0,280)|0}c[2113054]=c[2113060];s=p}p=c[2411332]|0;k=s|0;n=0;while(1){q=p+n|0;c[k>>2]=q;c[k+131072>>2]=q;q=n+1024|0;if(q>>>0>4194303){break}else{k=k+4|0;n=q}}n=c[2418178]|0;k=s+20480|0;p=5242880;while(1){q=n+(p-5242880)|0;c[k>>2]=q;c[k+65536>>2]=q;c[k+131072>>2]=q;q=p+1024|0;if(q>>>0>5373951){break}else{k=k+4|0;p=q}}p=c[2418184]|0;k=s+20992|0;n=5373952;while(1){q=p+(n-5373952)|0;c[k>>2]=q;c[k+65536>>2]=q;c[k+131072>>2]=q;q=n+1024|0;if(q>>>0>5505023){break}else{k=k+4|0;n=q}}n=c[2411424]|0;k=n;c[s+24576>>2]=k;c[s+90112>>2]=k;c[s+155648>>2]=k;k=n+1024|0;c[s+24580>>2]=k;c[s+90116>>2]=k;c[s+155652>>2]=k;k=c[2411370]|0;n=k;c[s+28672>>2]=n;c[s+94208>>2]=n;c[s+159744>>2]=n;n=k+1024|0;c[s+28676>>2]=n;c[s+94212>>2]=n;c[s+159748>>2]=n;n=k+2048|0;c[s+28680>>2]=n;c[s+94216>>2]=n;c[s+159752>>2]=n;n=k+3072|0;c[s+28684>>2]=n;c[s+94220>>2]=n;c[s+159756>>2]=n;n=k+4096|0;c[s+28688>>2]=n;c[s+94224>>2]=n;c[s+159760>>2]=n;n=k+5120|0;c[s+28692>>2]=n;c[s+94228>>2]=n;c[s+159764>>2]=n;n=k+6144|0;c[s+28696>>2]=n;c[s+94232>>2]=n;c[s+159768>>2]=n;n=k+7168|0;c[s+28700>>2]=n;c[s+94236>>2]=n;c[s+159772>>2]=n;n=k+8192|0;c[s+28704>>2]=n;c[s+94240>>2]=n;c[s+159776>>2]=n;n=k+9216|0;c[s+28708>>2]=n;c[s+94244>>2]=n;c[s+159780>>2]=n;n=k+10240|0;c[s+28712>>2]=n;c[s+94248>>2]=n;c[s+159784>>2]=n;n=k+11264|0;c[s+28716>>2]=n;c[s+94252>>2]=n;c[s+159788>>2]=n;n=k+12288|0;c[s+28720>>2]=n;c[s+94256>>2]=n;c[s+159792>>2]=n;n=k+13312|0;c[s+28724>>2]=n;c[s+94260>>2]=n;c[s+159796>>2]=n;n=k+14336|0;c[s+28728>>2]=n;c[s+94264>>2]=n;c[s+159800>>2]=n;n=k+15360|0;c[s+28732>>2]=n;c[s+94268>>2]=n;c[s+159804>>2]=n;n=k+16384|0;c[s+28736>>2]=n;c[s+94272>>2]=n;c[s+159808>>2]=n;n=k+17408|0;c[s+28740>>2]=n;c[s+94276>>2]=n;c[s+159812>>2]=n;c[s+196688>>2]=2100;c[s+196608>>2]=2492;c[s+196648>>2]=2072;n=c[3532592]|0;if((n|0)!=0){gGC(n|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;c[3541206]=c[2411320];Ux(0,12e3,0);c[2407030]=256;c[2407068]=3;a[14130536]=1;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];n=c[3532592]|0;if((n|0)!=0){gGC(9104152,n|0,280)|0}c[2113054]=c[2113060]}c[2113050]=0;c[2276080]=0;RI();n=c[2394]|0;k=c[14130368+(n<<2)>>2]|0;if((k|0)!=0){gGC(k|0,9104152,280)|0}c[8452240+(n<<2)>>2]=c[2113054];c[2394]=-1;c[2406810]=0;c[2113156]=0;a[9628264]=0;c[2407033]=0;n=c[3541206]|0;c[3541190]=n;c[3541198]=n;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=n+256;c[3541199]=n+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=n+512;c[3541200]=n+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=n+768;c[3541201]=n+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;o=0;i=b;return o|0}}while(0);c[2426708]=0;o=1;i=b;return o|0}function ega(){var b=0,d=0,e=0,f=0,g=0;if((c[2392]|0)>=0){b=0;do{d=14130368+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}d=14130384+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}b=b+1|0;}while((b|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;Uw(0);b=c[2426708]|0;d=0;while(1){if((d|0)>=1024){f=56504;break}g=9638528+(d<<2)|0;if((c[g>>2]|0)==(b|0)){break}else{d=d+1|0}}if((f|0)==56504){c[2426708]=0;a[14130536]=0;return 0}gGr(b);c[g>>2]=0;c[2426708]=0;a[14130536]=0;return 0}function egb(){var b=0,d=0,e=0;if((a[9624064]|0)!=0){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];b=c[3532592]|0;if((b|0)!=0){gGC(9104152,b|0,280)|0}c[2113054]=c[2113060]}c[2113050]=0;c[2276080]=0;RI();b=c[2394]|0;d=c[14130368+(b<<2)>>2]|0;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[8452240+(b<<2)>>2]=c[2113054];c[2394]=-1;c[2406810]=0;c[2113156]=0;a[9628264]=0;c[2407033]=0;b=c[3541206]|0;c[3541190]=b;c[3541198]=b;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=b+256;c[3541199]=b+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=b+512;c[3541200]=b+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=b+768;c[3541201]=b+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4}b=a[9631145]<<1&2|a[9631144]&1|a[9631146]<<2&4|a[9631147]<<3&8|a[9631148]<<4&16;a[9625657]=a[9633273]<<1&2|a[9633272]&1|a[9633274]<<2&4|a[9633275]<<3&8|a[9633276]<<4&16;a[9625659]=b;a[9625661]=a[9551785]<<1&2|a[9551784]&1|a[9551786]<<2&4|a[9551787]<<3&8|a[9551788]<<4&16|a[9551789]<<5&32|a[9551790]<<6&64;b=c[2438]|0;d=gGU(b,(b|0)<0|0?-1:0,12e6,0)|0;b=gGS(d,K,15360,0)|0;d=b;c[2440524]=d;b=c[2392]|0;if((b|0)>=0){gGz(8452240,0,((b|0)>0?(b<<2)+4|0:4)|0)}c[2113054]=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];b=c[3532592]|0;if((b|0)!=0){gGC(9104152,b|0,280)|0}c[2113054]=c[2113060]}b=(d|0)/2|0;c[2113056]=b;d=RG(b)|0;c[2113054]=(c[2113054]|0)+d;c[2276108]=-1;c[2113056]=-1;c[8452200+(c[2394]<<2)>>2]=8195;c[2276080]=768;if((c[2276079]|0)>>>0<768){RH(3)}d=(c[2440524]|0)/2|0;c[2113056]=d;b=RG(d)|0;c[2113054]=(c[2113054]|0)+b;c[2276108]=-1;c[2113056]=-1;b=c[2394]|0;c[8452200+(b<<2)>>2]=8197;c[2276080]=1280;if((c[2276079]|0)>>>0<1280){RH(5);e=c[2394]|0}else{e=b}b=c[14130368+(e<<2)>>2]|0;if((b|0)!=0){gGC(b|0,9104152,280)|0}c[8452240+(e<<2)>>2]=c[2113054];c[2394]=-1;if((c[2112968]|0)!=0){egc()|0}e=c[2112964]|0;if((e|0)==0){return 0}Uu(0,e,a[9688]|0?534:0);return 0}function egc(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;if((a[14130536]|0)!=0){d=0;do{c[(c[2385766]|0)+(d<<2)>>2]=((d&255)<<3&255)>>>3|d>>>5<<11&63488|((d>>>12&4|d>>>10<<3&255)&255)<<3&2016;d=d+1|0;}while((d|0)<32768);a[14130536]=0}d=c[2411424]|0;f=0;do{g=b[d+(f<<1)>>1]|0;c[(c[2385758]|0)+(f<<2)>>2]=((g&65535)>>>1<<3&248)>>>3|((g&65535)>>>6<<3&248)<<8|(((g&65535)>>>11<<3|(g&65535)>>>13)&65535)<<3&2016;f=f+1|0;}while((f|0)<1024);f=0;d=c[2418178]|0;g=c[2418184]|0;h=(c[2112968]|0)+114686|0;while(1){i=0;j=d;k=g;l=h;while(1){m=b[j>>1]|0;if(m<<16>>16==0){n=(c[2385766]|0)+((e[k>>1]|0)>>>1<<2)|0}else{n=(c[2385758]|0)+((m&65535)<<2)|0}b[l>>1]=c[n>>2]&65535;m=i+1|0;if((m|0)<256){i=m;j=j+2|0;k=k+2|0;l=l-2|0}else{break}}l=f+1|0;if((l|0)<224){f=l;d=d+512|0;g=g+512|0;h=h-512|0}else{break}}h=c[2411370]|0;g=0;d=0;f=0;while(1){n=e[h+((d|3)<<1)>>1]|0;l=(e[h+((d|4)<<1)>>1]|0)-(n<<8&256)|0;k=(e[h+((d|5)<<1)>>1]|0)+(n<<7&256)|0;if((n&4|0)==0){o=l;p=k}else{o=l+f|0;p=k+g|0}k=e[h+((d|7)<<1)>>1]|0;egT((k<<8&7936)+(e[h+((d|6)<<1)>>1]|0)|0,n&240,k&128,k&64,240-o|0,224-p|0);k=d+8|0;if((k|0)<9216){g=p;d=k;f=o}else{break}}return 0}function egd(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;e=i;i=i+128|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;l=e+80|0;m=e+96|0;n=e+112|0;if((d|0)!=0){c[d>>2]=169585}if((b&96|0)==0){i=e;return 0}gGz(n|0,0,12);d=c[2405642]|0;c[n>>2]=d;c[n+4>>2]=(c[2411630]|0)-d;c[n+12>>2]=162152;gj[c[2076592]&4095](n)|0;n=h|0;do{if((b&64|0)!=0){gGz(g|0,0,16);c[2394]=-1;if((c[2392]|0)<0){break}d=h+9|0;o=f;p=f|0;q=f+4|0;r=f+12|0;s=g|0;t=g+4|0;u=g+12|0;v=0;do{gGC(n|0,614896,11)|0;a[d]=v+48&255;w=8452256+(v<<2)|0;gGz(o|0,0,12);c[p>>2]=w;c[q>>2]=4;c[r>>2]=164976;gj[c[2076592]&4095](f)|0;if((c[w>>2]|0)!=0){c[s>>2]=c[14130368+(v<<2)>>2];c[t>>2]=c[8452184+(v<<2)>>2];c[u>>2]=n;w=c[2076592]|0;gj[w&4095](g)|0}v=v+1|0;}while((v|0)<=(c[2392]|0))}}while(0);Ut(0);gGz(m|0,0,12);c[m>>2]=9627240;c[m+4>>2]=4;c[m+12>>2]=544168;gj[c[2076592]&4095](m)|0;gGz(l|0,0,12);c[l>>2]=9625656;c[l+4>>2]=6;c[l+12>>2]=215728;gj[c[2076592]&4095](l)|0;gGz(k|0,0,12);c[k>>2]=9543032;c[k+4>>2]=4;c[k+12>>2]=541944;gj[c[2076592]&4095](k)|0;gGz(j|0,0,12);c[j>>2]=9543064;c[j+4>>2]=4;c[j+12>>2]=541032;gj[c[2076592]&4095](j)|0;if((b&2|0)==0){i=e;return 0}b=c[2411320]|0;j=b+196608|0;k=b+((c[2406810]<<16)+262144)|0;gGC(j|0,k|0,65536)|0;i=e;return 0}function ege(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3994924+(b*112|0)>>2];c[a+104>>2]=c[3994928+(b*112|0)>>2];c[a+108>>2]=c[3994932+(b*112|0)>>2];d=0;return d|0}function egf(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=3994824+(b*112|0);e=0;return e|0}function egg(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=13){if((a|0)==0){d=0;return d|0}e=a;f=6960352+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}f=b-14|0;if(f>>>0>42){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;a=3996728+(f*12|0)|0;c[b>>2]=c[a>>2];c[b+4>>2]=c[a+4>>2];c[b+8>>2]=c[a+8>>2];d=0;return d|0}function egh(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=i;i=i+360|0;d=b|0;e=b+112|0;f=b+120|0;g=b+232|0;h=b+240|0;j=b+352|0;c[2426708]=0;egS();k=c[2414170]|0;l=0;while(1){if((l|0)>=1024){break}m=9638528+(l<<2)|0;if((c[m>>2]|0)==0){n=56592;break}else{l=l+1|0}}do{if((n|0)==56592){l=gGq(k)|0;c[m>>2]=l;if((l|0)==0){break}gGz(l|0,0,k|0);c[2426708]=l;gGz(l|0,0,k|0);egS();if((R6((c[2411332]|0)+1|0,0,2)|0)!=0){o=1;i=b;return o|0}if((R6(c[2411332]|0,1,2)|0)!=0){o=1;i=b;return o|0}if((R6((c[2411332]|0)+1048577|0,2,2)|0)!=0){o=1;i=b;return o|0}if((R6((c[2411332]|0)+1048576|0,3,2)|0)!=0){o=1;i=b;return o|0}if((R6((c[2411332]|0)+2097153|0,4,2)|0)!=0){o=1;i=b;return o|0}if((R6((c[2411332]|0)+2097152|0,5,2)|0)!=0){o=1;i=b;return o|0}if((R6((c[2411332]|0)+3145729|0,6,2)|0)!=0){o=1;i=b;return o|0}if((R6((c[2411332]|0)+3145728|0,7,2)|0)!=0){o=1;i=b;return o|0}if((R6((c[2411332]|0)+4194305|0,8,2)|0)!=0){o=1;i=b;return o|0}if((R6((c[2411332]|0)+4194304|0,9,2)|0)!=0){o=1;i=b;return o|0}l=c[2411326]|0;if((c[3542200]|0)==0){o=1;i=b;return o|0}p=h+108|0;c[p>>2]=0;q=h+100|0;c[q>>2]=0;r=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[r&16383](h,10)|0;do{if((c[p>>2]|0)!=0){r=c[q>>2]|0;c[j>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](j,10,0)|0;if((r|0)<1){o=1;i=b;return o|0}if((gzL(l,0,10)|0)==0){break}else{o=1}i=b;return o|0}}while(0);ef4();l=(c[2411320]|0)+262144|0;do{if((c[3542200]|0)!=0){q=f+108|0;c[q>>2]=0;p=f+100|0;c[p>>2]=0;r=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[r&16383](f,11)|0;if((c[q>>2]|0)==0){break}q=c[p>>2]|0;c[g>>2]=9534384;p=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[p&16383](g,11,0)|0;if((q|0)<1){break}gzL(l,0,11)|0}}while(0);l=(c[2411320]|0)+786432|0;do{if((c[3542200]|0)!=0){q=d+108|0;c[q>>2]=0;p=d+100|0;c[p>>2]=0;r=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[r&16383](d,12)|0;if((c[q>>2]|0)==0){break}q=c[p>>2]|0;c[e>>2]=9534384;p=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[p&16383](e,12,0)|0;if((q|0)<1){break}gzL(l,0,12)|0}}while(0);l=c[2411320]|0;q=l+262144|0;gGC(l|0,q|0,262144)|0;fxU(0,425984);if((c[2394]|0)==0){t=c[2112932]|0}else{c[2394]=0;q=c[3532596]|0;c[2112932]=q;l=c[3532592]|0;if((l|0)!=0){gGC(9104152,l|0,280)|0}c[2113054]=c[2113060];t=q}q=c[2411332]|0;l=t|0;p=0;while(1){r=q+p|0;c[l>>2]=r;c[l+131072>>2]=r;r=p+1024|0;if(r>>>0>5242879){break}else{l=l+4|0;p=r}}p=c[2418178]|0;l=t+20480|0;q=5242880;while(1){r=p+(q-5242880)|0;c[l>>2]=r;c[l+65536>>2]=r;c[l+131072>>2]=r;r=q+1024|0;if(r>>>0>5373951){break}else{l=l+4|0;q=r}}q=c[2418184]|0;l=t+20992|0;p=5373952;while(1){r=q+(p-5373952)|0;c[l>>2]=r;c[l+65536>>2]=r;c[l+131072>>2]=r;r=p+1024|0;if(r>>>0>5505023){break}else{l=l+4|0;p=r}}p=c[2411898]|0;l=p;c[t+22528>>2]=l;c[t+88064>>2]=l;c[t+153600>>2]=l;l=p+1024|0;c[t+22532>>2]=l;c[t+88068>>2]=l;c[t+153604>>2]=l;l=p+2048|0;c[t+22536>>2]=l;c[t+88072>>2]=l;c[t+153608>>2]=l;l=p+3072|0;c[t+22540>>2]=l;c[t+88076>>2]=l;c[t+153612>>2]=l;l=p+4096|0;c[t+22544>>2]=l;c[t+88080>>2]=l;c[t+153616>>2]=l;l=p+5120|0;c[t+22548>>2]=l;c[t+88084>>2]=l;c[t+153620>>2]=l;l=p+6144|0;c[t+22552>>2]=l;c[t+88088>>2]=l;c[t+153624>>2]=l;l=p+7168|0;c[t+22556>>2]=l;c[t+88092>>2]=l;c[t+153628>>2]=l;l=p+8192|0;c[t+22560>>2]=l;c[t+88096>>2]=l;c[t+153632>>2]=l;l=p+9216|0;c[t+22564>>2]=l;c[t+88100>>2]=l;c[t+153636>>2]=l;l=p+10240|0;c[t+22568>>2]=l;c[t+88104>>2]=l;c[t+153640>>2]=l;l=p+11264|0;c[t+22572>>2]=l;c[t+88108>>2]=l;c[t+153644>>2]=l;l=p+12288|0;c[t+22576>>2]=l;c[t+88112>>2]=l;c[t+153648>>2]=l;l=p+13312|0;c[t+22580>>2]=l;c[t+88116>>2]=l;c[t+153652>>2]=l;l=p+14336|0;c[t+22584>>2]=l;c[t+88120>>2]=l;c[t+153656>>2]=l;l=p+15360|0;c[t+22588>>2]=l;c[t+88124>>2]=l;c[t+153660>>2]=l;l=c[2411424]|0;p=l;c[t+24576>>2]=p;c[t+90112>>2]=p;c[t+155648>>2]=p;p=l+1024|0;c[t+24580>>2]=p;c[t+90116>>2]=p;c[t+155652>>2]=p;p=l+2048|0;c[t+24584>>2]=p;c[t+90120>>2]=p;c[t+155656>>2]=p;p=l+3072|0;c[t+24588>>2]=p;c[t+90124>>2]=p;c[t+155660>>2]=p;p=c[2411904]|0;c[t+92160>>2]=p;l=c[2411370]|0;q=l;c[t+28672>>2]=q;c[t+94208>>2]=q;c[t+159744>>2]=q;q=l+1024|0;c[t+28676>>2]=q;c[t+94212>>2]=q;c[t+159748>>2]=q;q=l+2048|0;c[t+28680>>2]=q;c[t+94216>>2]=q;c[t+159752>>2]=q;q=l+3072|0;c[t+28684>>2]=q;c[t+94220>>2]=q;c[t+159756>>2]=q;c[t+96256>>2]=p+32;q=p+64|0;p=t+51200|0;l=13107200;while(1){r=q+(l-13107200)|0;c[p>>2]=r;c[p+65536>>2]=r;c[p+131072>>2]=r;r=l+1024|0;if(r>>>0>13172735){break}else{p=p+4|0;l=r}}c[t+196688>>2]=2100;c[t+196608>>2]=1038;c[t+196648>>2]=26;l=c[3532592]|0;if((l|0)!=0){gGC(l|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;c[3541206]=c[2411320];Ux(0,12e3,0);c[2407030]=256;c[2407068]=3;a[14130536]=1;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];l=c[3532592]|0;if((l|0)!=0){gGC(9104152,l|0,280)|0}c[2113054]=c[2113060]}c[2113050]=0;c[2276080]=0;RI();l=c[2394]|0;p=c[14130368+(l<<2)>>2]|0;if((p|0)!=0){gGC(p|0,9104152,280)|0}c[8452240+(l<<2)>>2]=c[2113054];c[2394]=-1;c[2406810]=0;c[2113156]=0;a[9628264]=0;c[2407033]=0;l=c[3541206]|0;c[3541190]=l;c[3541198]=l;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=l+256;c[3541199]=l+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=l+512;c[3541200]=l+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=l+768;c[3541201]=l+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;o=0;i=b;return o|0}}while(0);c[2426708]=0;o=1;i=b;return o|0}function egi(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if((a[9624064]|0)!=0){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];b=c[3532592]|0;if((b|0)!=0){gGC(9104152,b|0,280)|0}c[2113054]=c[2113060]}c[2113050]=0;c[2276080]=0;RI();b=c[2394]|0;d=c[14130368+(b<<2)>>2]|0;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[8452240+(b<<2)>>2]=c[2113054];c[2394]=-1;c[2406810]=0;c[2113156]=0;a[9628264]=0;c[2407033]=0;b=c[3541206]|0;c[3541190]=b;c[3541198]=b;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=b+256;c[3541199]=b+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=b+512;c[3541200]=b+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=b+768;c[3541201]=b+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4}b=a[9633273]<<1&2|a[9633272]&1;d=a[9631145]<<1&2|a[9631144]&1;e=a[9633274]<<2&4|b|a[9633275]<<3&8|a[9633276]<<4&16;f=a[9631146]<<2&4|d|a[9631147]<<3&8|a[9631148]<<4&16;a[9625657]=e;a[9625659]=f;a[9625661]=a[9551785]<<1&2|a[9551784]&1|a[9551786]<<2&4|a[9551787]<<3&8|a[9551788]<<4&16|a[9551789]<<5&32|a[9551790]<<6&64;if(b<<24>>24==3){b=e&28;a[9625657]=b;g=b}else{g=e}if((g&12)==12){a[9625657]=g&-13}if(d<<24>>24==3){d=f&28;a[9625659]=d;h=d}else{h=f}if((h&12)==12){a[9625659]=h&-13}h=c[c[642608+(c[2436]<<2)>>2]>>2]|0;do{if((fa(h|0,564752)|0)==0){i=56674}else{if((fa(h|0,371080)|0)==0){i=56674;break}if((fa(h|0,346848)|0)==0){i=56674;break}if((fa(h|0,330936)|0)==0){i=56674;break}f=c[2438]|0;d=gGU(f,(f|0)<0|0?-1:0,1e7,0)|0;j=K;k=d}}while(0);if((i|0)==56674){i=c[2438]|0;h=gGU(i,(i|0)<0|0?-1:0,12e6,0)|0;j=K;k=h}h=gGS(k,j,15360,0)|0;j=h;c[2440524]=j;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];h=c[3532592]|0;if((h|0)!=0){gGC(9104152,h|0,280)|0}c[2113054]=c[2113060]}h=c[2392]|0;if((h|0)>=0){gGz(8452240,0,((h|0)>0?(h<<2)+4|0:4)|0)}c[2113054]=0;h=(j|0)/4|0;c[2113056]=h;j=RG(h)|0;c[2113054]=(c[2113054]|0)+j;c[2276108]=-1;c[2113056]=-1;c[8452200+(c[2394]<<2)>>2]=8195;c[2276080]=768;if((c[2276079]|0)>>>0<768){RH(3)}j=(c[2440524]|0)/4|0;c[2113056]=j;h=RG(j)|0;c[2113054]=(c[2113054]|0)+h;c[2276108]=-1;c[2113056]=-1;c[8452200+(c[2394]<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0<1024){RH(4)}h=(c[2440524]|0)/4|0;c[2113056]=h;j=RG(h)|0;c[2113054]=(c[2113054]|0)+j;c[2276108]=-1;c[2113056]=-1;c[8452200+(c[2394]<<2)>>2]=8197;c[2276080]=1280;if((c[2276079]|0)>>>0<1280){RH(5)}j=(c[2440524]|0)/4|0;c[2113056]=j;h=RG(j)|0;j=(c[2113054]|0)+h|0;c[2113054]=j;c[2276108]=-1;c[2113056]=-1;h=c[2394]|0;k=c[14130368+(h<<2)>>2]|0;if((k|0)!=0){gGC(k|0,9104152,280)|0}c[8452240+(h<<2)>>2]=j;c[2394]=-1;j=c[2112964]|0;if((j|0)!=0){Uu(0,j,a[9688]|0?534:0)}if((c[2112968]|0)==0){return 0}egj()|0;return 0}function egj(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;if((a[14130536]|0)!=0){d=0;do{c[(c[2385766]|0)+(d<<2)>>2]=((d&255)<<3&255)>>>3|d>>>5<<11&63488|((d>>>12&4|d>>>10<<3&255)&255)<<3&2016;d=d+1|0;}while((d|0)<32768);a[14130536]=0}d=c[2411424]|0;f=0;do{g=b[d+(f<<1)>>1]|0;c[(c[2385758]|0)+(f<<2)>>2]=((g&65535)>>>1<<3&248)>>>3|((g&65535)>>>6<<3&248)<<8|(((g&65535)>>>11<<3|(g&65535)>>>13)&65535)<<3&2016;f=f+1|0;}while((f|0)<1024);f=c[2418178]|0;d=0;g=c[2418184]|0;h=(c[2112968]|0)+114686|0;while(1){i=f;j=0;k=g;l=h;while(1){m=b[i>>1]|0;if(m<<16>>16==0){n=(c[2385766]|0)+((e[k>>1]|0)>>>1<<2)|0}else{n=(c[2385758]|0)+((m&65535)<<2)|0}b[l>>1]=c[n>>2]&65535;m=j+1|0;if((m|0)<256){i=i+2|0;j=m;k=k+2|0;l=l-2|0}else{break}}l=d+1|0;if((l|0)<224){f=f+512|0;d=l;g=g+512|0;h=h-512|0}else{break}}h=c[2411370]|0;g=0;d=0;f=0;do{n=e[h+(f<<1)>>1]|0;l=(e[h+((f|2)<<1)>>1]|0)>>>6;if((n&24576|0)==24576){o=((e[h+((f|3)<<1)>>1]|0)>>>6)+d|0;p=l+g|0}else{o=(e[h+((f|3)<<1)>>1]|0)>>>6;p=l}g=(p&511)-(p&512)|0;d=(o&511)-(o&512)|0;egT(b[h+((f|1)<<1)>>1]&8191,n<<2&240,n&2,n&1,240-g|0,208-d|0);f=f+4|0;}while((f|0)<2048);return 0}function egk(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1936676+(b*112|0)>>2];c[a+104>>2]=c[1936680+(b*112|0)>>2];c[a+108>>2]=c[1936684+(b*112|0)>>2];d=0;return d|0}function egl(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=1936576+(b*112|0);e=0;return e|0}function egm(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3336204+(b*112|0)>>2];c[a+104>>2]=c[3336208+(b*112|0)>>2];c[a+108>>2]=c[3336212+(b*112|0)>>2];d=0;return d|0}function egn(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=3336104+(b*112|0);e=0;return e|0}function ego(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5224700+(b*112|0)>>2];c[a+104>>2]=c[5224704+(b*112|0)>>2];c[a+108>>2]=c[5224708+(b*112|0)>>2];d=0;return d|0}function egp(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=5224600+(b*112|0);e=0;return e|0}function egq(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3667412+(b*112|0)>>2];c[a+104>>2]=c[3667416+(b*112|0)>>2];c[a+108>>2]=c[3667420+(b*112|0)>>2];d=0;return d|0}function egr(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=3667312+(b*112|0);e=0;return e|0}function egs(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3988676+(b*112|0)>>2];c[a+104>>2]=c[3988680+(b*112|0)>>2];c[a+108>>2]=c[3988684+(b*112|0)>>2];d=0;return d|0}function egt(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=3988576+(b*112|0);e=0;return e|0}function egu(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5269844+(b*112|0)>>2];c[a+104>>2]=c[5269848+(b*112|0)>>2];c[a+108>>2]=c[5269852+(b*112|0)>>2];d=0;return d|0}function egv(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=5269744+(b*112|0);e=0;return e|0}function egw(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=13){if((a|0)==0){d=0;return d|0}e=a;f=6960352+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}f=b-14|0;if(f>>>0>39){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;a=5270976+(f*12|0)|0;c[b>>2]=c[a>>2];c[b+4>>2]=c[a+4>>2];c[b+8>>2]=c[a+8>>2];d=0;return d|0}function egx(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=i;i=i+360|0;d=b|0;e=b+112|0;f=b+120|0;g=b+232|0;h=b+240|0;j=b+352|0;c[2426708]=0;egS();k=c[2414170]|0;l=0;while(1){if((l|0)>=1024){break}m=9638528+(l<<2)|0;if((c[m>>2]|0)==0){n=56802;break}else{l=l+1|0}}do{if((n|0)==56802){l=gGq(k)|0;c[m>>2]=l;if((l|0)==0){break}gGz(l|0,0,k|0);c[2426708]=l;gGz(l|0,0,k|0);egS();if((R6((c[2411332]|0)+1|0,0,2)|0)!=0){o=1;i=b;return o|0}if((R6(c[2411332]|0,1,2)|0)!=0){o=1;i=b;return o|0}if((R6((c[2411332]|0)+1048577|0,2,2)|0)!=0){o=1;i=b;return o|0}if((R6((c[2411332]|0)+1048576|0,3,2)|0)!=0){o=1;i=b;return o|0}if((R6((c[2411332]|0)+2097153|0,4,2)|0)!=0){o=1;i=b;return o|0}if((R6((c[2411332]|0)+2097152|0,5,2)|0)!=0){o=1;i=b;return o|0}if((R6((c[2411332]|0)+3145729|0,6,2)|0)!=0){o=1;i=b;return o|0}if((R6((c[2411332]|0)+3145728|0,7,2)|0)!=0){o=1;i=b;return o|0}l=c[2411326]|0;if((c[3542200]|0)==0){o=1;i=b;return o|0}p=h+108|0;c[p>>2]=0;q=h+100|0;c[q>>2]=0;r=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[r&16383](h,8)|0;do{if((c[p>>2]|0)!=0){r=c[q>>2]|0;c[j>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](j,8,0)|0;if((r|0)<1){o=1;i=b;return o|0}if((gzL(l,0,8)|0)==0){break}else{o=1}i=b;return o|0}}while(0);ef4();l=(c[2411320]|0)+262144|0;do{if((c[3542200]|0)!=0){q=f+108|0;c[q>>2]=0;p=f+100|0;c[p>>2]=0;r=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[r&16383](f,9)|0;if((c[q>>2]|0)==0){break}q=c[p>>2]|0;c[g>>2]=9534384;p=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[p&16383](g,9,0)|0;if((q|0)<1){break}gzL(l,0,9)|0}}while(0);l=(c[2411320]|0)+786432|0;do{if((c[3542200]|0)!=0){q=d+108|0;c[q>>2]=0;p=d+100|0;c[p>>2]=0;r=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[r&16383](d,10)|0;if((c[q>>2]|0)==0){break}q=c[p>>2]|0;c[e>>2]=9534384;p=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[p&16383](e,10,0)|0;if((q|0)<1){break}gzL(l,0,10)|0}}while(0);l=c[2411320]|0;q=l+262144|0;gGC(l|0,q|0,262144)|0;fxU(0,425984);if((c[2394]|0)==0){t=c[2112932]|0}else{c[2394]=0;q=c[3532596]|0;c[2112932]=q;l=c[3532592]|0;if((l|0)!=0){gGC(9104152,l|0,280)|0}c[2113054]=c[2113060];t=q}q=c[2411332]|0;l=t|0;p=0;while(1){r=q+p|0;c[l>>2]=r;c[l+131072>>2]=r;r=p+1024|0;if(r>>>0>5242879){break}else{l=l+4|0;p=r}}p=c[2418178]|0;l=t+20480|0;q=5242880;while(1){r=p+(q-5242880)|0;c[l>>2]=r;c[l+65536>>2]=r;c[l+131072>>2]=r;r=q+1024|0;if(r>>>0>5373951){break}else{l=l+4|0;q=r}}q=c[2418184]|0;l=t+20992|0;p=5373952;while(1){r=q+(p-5373952)|0;c[l>>2]=r;c[l+65536>>2]=r;c[l+131072>>2]=r;r=p+1024|0;if(r>>>0>5505023){break}else{l=l+4|0;p=r}}p=c[2411898]|0;l=p;c[t+22528>>2]=l;c[t+88064>>2]=l;c[t+153600>>2]=l;l=p+1024|0;c[t+22532>>2]=l;c[t+88068>>2]=l;c[t+153604>>2]=l;l=p+2048|0;c[t+22536>>2]=l;c[t+88072>>2]=l;c[t+153608>>2]=l;l=p+3072|0;c[t+22540>>2]=l;c[t+88076>>2]=l;c[t+153612>>2]=l;l=p+4096|0;c[t+22544>>2]=l;c[t+88080>>2]=l;c[t+153616>>2]=l;l=p+5120|0;c[t+22548>>2]=l;c[t+88084>>2]=l;c[t+153620>>2]=l;l=p+6144|0;c[t+22552>>2]=l;c[t+88088>>2]=l;c[t+153624>>2]=l;l=p+7168|0;c[t+22556>>2]=l;c[t+88092>>2]=l;c[t+153628>>2]=l;l=p+8192|0;c[t+22560>>2]=l;c[t+88096>>2]=l;c[t+153632>>2]=l;l=p+9216|0;c[t+22564>>2]=l;c[t+88100>>2]=l;c[t+153636>>2]=l;l=p+10240|0;c[t+22568>>2]=l;c[t+88104>>2]=l;c[t+153640>>2]=l;l=p+11264|0;c[t+22572>>2]=l;c[t+88108>>2]=l;c[t+153644>>2]=l;l=p+12288|0;c[t+22576>>2]=l;c[t+88112>>2]=l;c[t+153648>>2]=l;l=p+13312|0;c[t+22580>>2]=l;c[t+88116>>2]=l;c[t+153652>>2]=l;l=p+14336|0;c[t+22584>>2]=l;c[t+88120>>2]=l;c[t+153656>>2]=l;l=p+15360|0;c[t+22588>>2]=l;c[t+88124>>2]=l;c[t+153660>>2]=l;l=c[2411424]|0;p=l;c[t+24576>>2]=p;c[t+90112>>2]=p;c[t+155648>>2]=p;p=l+1024|0;c[t+24580>>2]=p;c[t+90116>>2]=p;c[t+155652>>2]=p;p=l+2048|0;c[t+24584>>2]=p;c[t+90120>>2]=p;c[t+155656>>2]=p;p=l+3072|0;c[t+24588>>2]=p;c[t+90124>>2]=p;c[t+155660>>2]=p;p=c[2411370]|0;l=p;c[t+28672>>2]=l;c[t+94208>>2]=l;c[t+159744>>2]=l;l=p+1024|0;c[t+28676>>2]=l;c[t+94212>>2]=l;c[t+159748>>2]=l;l=p+2048|0;c[t+28680>>2]=l;c[t+94216>>2]=l;c[t+159752>>2]=l;l=p+3072|0;c[t+28684>>2]=l;c[t+94220>>2]=l;c[t+159756>>2]=l;l=c[2411904]|0;p=l;q=t+49152|0;r=12582912;while(1){s=p+(r-12582912)|0;c[q>>2]=s;c[q+65536>>2]=s;c[q+131072>>2]=s;s=r+1024|0;if(s>>>0>12648447){break}else{q=q+4|0;r=s}}r=l+65536|0;c[t+26624>>2]=r;c[t+92160>>2]=r;c[t+157696>>2]=r;r=l+65568|0;c[t+30720>>2]=r;c[t+96256>>2]=r;c[t+161792>>2]=r;c[t+196688>>2]=2100;c[t+196608>>2]=1038;c[t+196648>>2]=26;r=c[3532592]|0;if((r|0)!=0){gGC(r|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;c[3541206]=c[2411320];Ux(0,12e3,0);c[2407030]=256;c[2407068]=3;a[14130536]=1;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];r=c[3532592]|0;if((r|0)!=0){gGC(9104152,r|0,280)|0}c[2113054]=c[2113060]}c[2113050]=0;c[2276080]=0;RI();r=c[2394]|0;q=c[14130368+(r<<2)>>2]|0;if((q|0)!=0){gGC(q|0,9104152,280)|0}c[8452240+(r<<2)>>2]=c[2113054];c[2394]=-1;c[2406810]=0;c[2113156]=0;a[9628264]=0;c[2407033]=0;r=c[3541206]|0;c[3541190]=r;c[3541198]=r;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=r+256;c[3541199]=r+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=r+512;c[3541200]=r+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=r+768;c[3541201]=r+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;o=0;i=b;return o|0}}while(0);c[2426708]=0;o=1;i=b;return o|0}function egy(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3733548+(b*112|0)>>2];c[a+104>>2]=c[3733552+(b*112|0)>>2];c[a+108>>2]=c[3733556+(b*112|0)>>2];d=0;return d|0}function egz(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=3733448+(b*112|0);e=0;return e|0}function egA(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3990132+(b*112|0)>>2];c[a+104>>2]=c[3990136+(b*112|0)>>2];c[a+108>>2]=c[3990140+(b*112|0)>>2];d=0;return d|0}function egB(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=3990032+(b*112|0);e=0;return e|0}function egC(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;b=i;i=i+480|0;d=b|0;e=b+112|0;f=b+120|0;g=b+232|0;h=b+240|0;j=b+352|0;k=b+360|0;l=b+472|0;c[2426708]=0;egS();m=c[2414170]|0;n=0;while(1){if((n|0)>=1024){break}o=9638528+(n<<2)|0;if((c[o>>2]|0)==0){p=56887;break}else{n=n+1|0}}do{if((p|0)==56887){n=gGq(m)|0;c[o>>2]=n;if((n|0)==0){break}gGz(n|0,0,m|0);c[2426708]=n;gGz(n|0,0,m|0);egS();if((R6((c[2411332]|0)+1|0,0,2)|0)!=0){q=1;i=b;return q|0}if((R6(c[2411332]|0,1,2)|0)!=0){q=1;i=b;return q|0}if((R6((c[2411332]|0)+1048577|0,2,2)|0)!=0){q=1;i=b;return q|0}if((R6((c[2411332]|0)+1048576|0,3,2)|0)!=0){q=1;i=b;return q|0}if((R6((c[2411332]|0)+2097153|0,4,2)|0)!=0){q=1;i=b;return q|0}if((R6((c[2411332]|0)+2097152|0,5,2)|0)!=0){q=1;i=b;return q|0}if((R6((c[2411332]|0)+3145729|0,6,2)|0)!=0){q=1;i=b;return q|0}if((R6((c[2411332]|0)+3145728|0,7,2)|0)!=0){q=1;i=b;return q|0}if((R6((c[2411332]|0)+4194305|0,8,2)|0)!=0){q=1;i=b;return q|0}if((R6((c[2411332]|0)+4194304|0,9,2)|0)!=0){q=1;i=b;return q|0}n=c[2411326]|0;if((c[3542200]|0)==0){q=1;i=b;return q|0}r=k+108|0;c[r>>2]=0;s=k+100|0;c[s>>2]=0;t=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[t&16383](k,10)|0;do{if((c[r>>2]|0)!=0){t=c[s>>2]|0;c[l>>2]=9534384;u=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[u&16383](l,10,0)|0;if((t|0)<1){q=1;i=b;return q|0}if((gzL(n,0,10)|0)==0){break}else{q=1}i=b;return q|0}}while(0);n=(c[2411326]|0)+524288|0;if((c[3542200]|0)==0){q=1;i=b;return q|0}s=h+108|0;c[s>>2]=0;r=h+100|0;c[r>>2]=0;t=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[t&16383](h,11)|0;do{if((c[s>>2]|0)!=0){t=c[r>>2]|0;c[j>>2]=9534384;u=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[u&16383](j,11,0)|0;if((t|0)<1){q=1;i=b;return q|0}if((gzL(n,0,11)|0)==0){break}else{q=1}i=b;return q|0}}while(0);ef4();n=(c[2411320]|0)+262144|0;do{if((c[3542200]|0)!=0){r=f+108|0;c[r>>2]=0;s=f+100|0;c[s>>2]=0;t=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[t&16383](f,12)|0;if((c[r>>2]|0)==0){break}r=c[s>>2]|0;c[g>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](g,12,0)|0;if((r|0)<1){break}gzL(n,0,12)|0}}while(0);n=(c[2411320]|0)+786432|0;do{if((c[3542200]|0)!=0){r=d+108|0;c[r>>2]=0;s=d+100|0;c[s>>2]=0;t=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[t&16383](d,13)|0;if((c[r>>2]|0)==0){break}r=c[s>>2]|0;c[e>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](e,13,0)|0;if((r|0)<1){break}gzL(n,0,13)|0}}while(0);n=c[2411320]|0;r=n+262144|0;gGC(n|0,r|0,262144)|0;fxU(0,425984);if((c[2394]|0)==0){v=c[2112932]|0}else{c[2394]=0;r=c[3532596]|0;c[2112932]=r;n=c[3532592]|0;if((n|0)!=0){gGC(9104152,n|0,280)|0}c[2113054]=c[2113060];v=r}r=c[2411332]|0;n=v|0;s=0;while(1){t=r+s|0;c[n>>2]=t;c[n+131072>>2]=t;t=s+1024|0;if(t>>>0>5242879){break}else{n=n+4|0;s=t}}s=c[2418178]|0;n=v+20480|0;r=5242880;while(1){t=s+(r-5242880)|0;c[n>>2]=t;c[n+65536>>2]=t;c[n+131072>>2]=t;t=r+1024|0;if(t>>>0>5373951){break}else{n=n+4|0;r=t}}r=c[2418184]|0;n=v+20992|0;s=5373952;while(1){t=r+(s-5373952)|0;c[n>>2]=t;c[n+65536>>2]=t;c[n+131072>>2]=t;t=s+1024|0;if(t>>>0>5505023){break}else{n=n+4|0;s=t}}s=c[2411898]|0;n=s;c[v+22528>>2]=n;c[v+88064>>2]=n;c[v+153600>>2]=n;n=s+1024|0;c[v+22532>>2]=n;c[v+88068>>2]=n;c[v+153604>>2]=n;n=s+2048|0;c[v+22536>>2]=n;c[v+88072>>2]=n;c[v+153608>>2]=n;n=s+3072|0;c[v+22540>>2]=n;c[v+88076>>2]=n;c[v+153612>>2]=n;n=s+4096|0;c[v+22544>>2]=n;c[v+88080>>2]=n;c[v+153616>>2]=n;n=s+5120|0;c[v+22548>>2]=n;c[v+88084>>2]=n;c[v+153620>>2]=n;n=s+6144|0;c[v+22552>>2]=n;c[v+88088>>2]=n;c[v+153624>>2]=n;n=s+7168|0;c[v+22556>>2]=n;c[v+88092>>2]=n;c[v+153628>>2]=n;n=s+8192|0;c[v+22560>>2]=n;c[v+88096>>2]=n;c[v+153632>>2]=n;n=s+9216|0;c[v+22564>>2]=n;c[v+88100>>2]=n;c[v+153636>>2]=n;n=s+10240|0;c[v+22568>>2]=n;c[v+88104>>2]=n;c[v+153640>>2]=n;n=s+11264|0;c[v+22572>>2]=n;c[v+88108>>2]=n;c[v+153644>>2]=n;n=s+12288|0;c[v+22576>>2]=n;c[v+88112>>2]=n;c[v+153648>>2]=n;n=s+13312|0;c[v+22580>>2]=n;c[v+88116>>2]=n;c[v+153652>>2]=n;n=s+14336|0;c[v+22584>>2]=n;c[v+88120>>2]=n;c[v+153656>>2]=n;n=s+15360|0;c[v+22588>>2]=n;c[v+88124>>2]=n;c[v+153660>>2]=n;n=c[2411424]|0;s=n;c[v+24576>>2]=s;c[v+90112>>2]=s;c[v+155648>>2]=s;s=n+1024|0;c[v+24580>>2]=s;c[v+90116>>2]=s;c[v+155652>>2]=s;s=n+2048|0;c[v+24584>>2]=s;c[v+90120>>2]=s;c[v+155656>>2]=s;s=n+3072|0;c[v+24588>>2]=s;c[v+90124>>2]=s;c[v+155660>>2]=s;s=c[2411370]|0;n=s;c[v+28672>>2]=n;c[v+94208>>2]=n;c[v+159744>>2]=n;n=s+1024|0;c[v+28676>>2]=n;c[v+94212>>2]=n;c[v+159748>>2]=n;n=s+2048|0;c[v+28680>>2]=n;c[v+94216>>2]=n;c[v+159752>>2]=n;n=s+3072|0;c[v+28684>>2]=n;c[v+94220>>2]=n;c[v+159756>>2]=n;n=c[2411904]|0;s=n;r=v+63488|0;t=16252928;while(1){u=s+(t-16252928)|0;c[r>>2]=u;c[r+65536>>2]=u;c[r+131072>>2]=u;u=t+1024|0;if(u>>>0>16318463){break}else{r=r+4|0;t=u}}t=n+65536|0;c[v+26624>>2]=t;c[v+92160>>2]=t;c[v+157696>>2]=t;t=n+65568|0;c[v+30720>>2]=t;c[v+96256>>2]=t;c[v+161792>>2]=t;c[v+196688>>2]=2100;c[v+196608>>2]=1038;c[v+196648>>2]=26;t=c[3532592]|0;if((t|0)!=0){gGC(t|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;c[3541206]=c[2411320];Ux(0,12e3,0);c[2407030]=256;c[2407068]=3;a[14130536]=1;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];t=c[3532592]|0;if((t|0)!=0){gGC(9104152,t|0,280)|0}c[2113054]=c[2113060]}c[2113050]=0;c[2276080]=0;RI();t=c[2394]|0;r=c[14130368+(t<<2)>>2]|0;if((r|0)!=0){gGC(r|0,9104152,280)|0}c[8452240+(t<<2)>>2]=c[2113054];c[2394]=-1;c[2406810]=0;c[2113156]=0;a[9628264]=0;c[2407033]=0;t=c[3541206]|0;c[3541190]=t;c[3541198]=t;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=t+256;c[3541199]=t+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=t+512;c[3541200]=t+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=t+768;c[3541201]=t+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;q=0;i=b;return q|0}}while(0);c[2426708]=0;q=1;i=b;return q|0}function egD(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1935108+(b*112|0)>>2];c[a+104>>2]=c[1935112+(b*112|0)>>2];c[a+108>>2]=c[1935116+(b*112|0)>>2];d=0;return d|0}function egE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=1935008+(b*112|0);e=0;return e|0}function egF(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3234668+(b*112|0)>>2];c[a+104>>2]=c[3234672+(b*112|0)>>2];c[a+108>>2]=c[3234676+(b*112|0)>>2];d=0;return d|0}function egG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=3234568+(b*112|0);e=0;return e|0}function egH(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;b=i;i=i+720|0;d=b|0;e=b+112|0;f=b+120|0;g=b+232|0;h=b+240|0;j=b+352|0;k=b+360|0;l=b+472|0;m=b+480|0;n=b+592|0;o=b+600|0;p=b+712|0;c[2426708]=0;egS();q=c[2414170]|0;r=0;while(1){if((r|0)>=1024){break}s=9638528+(r<<2)|0;if((c[s>>2]|0)==0){t=56983;break}else{r=r+1|0}}do{if((t|0)==56983){r=gGq(q)|0;c[s>>2]=r;if((r|0)==0){break}gGz(r|0,0,q|0);c[2426708]=r;gGz(r|0,0,q|0);egS();if((R6((c[2411332]|0)+1|0,0,2)|0)!=0){u=1;i=b;return u|0}if((R6(c[2411332]|0,1,2)|0)!=0){u=1;i=b;return u|0}r=(c[2411332]|0)+1048576|0;if((c[3542200]|0)==0){u=1;i=b;return u|0}v=o+108|0;c[v>>2]=0;w=o+100|0;c[w>>2]=0;x=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[x&16383](o,2)|0;do{if((c[v>>2]|0)!=0){x=c[w>>2]|0;c[p>>2]=9534384;y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[y&16383](p,2,0)|0;if((x|0)<1){u=1;i=b;return u|0}if((gzL(r,0,2)|0)==0){break}else{u=1}i=b;return u|0}}while(0);r=(c[2411332]|0)+3145728|0;if((c[3542200]|0)==0){u=1;i=b;return u|0}w=m+108|0;c[w>>2]=0;v=m+100|0;c[v>>2]=0;x=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[x&16383](m,3)|0;do{if((c[w>>2]|0)!=0){x=c[v>>2]|0;c[n>>2]=9534384;y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[y&16383](n,3,0)|0;if((x|0)<1){u=1;i=b;return u|0}if((gzL(r,0,3)|0)==0){break}else{u=1}i=b;return u|0}}while(0);r=c[2411326]|0;if((c[3542200]|0)==0){u=1;i=b;return u|0}v=k+108|0;c[v>>2]=0;w=k+100|0;c[w>>2]=0;x=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[x&16383](k,4)|0;do{if((c[v>>2]|0)!=0){x=c[w>>2]|0;c[l>>2]=9534384;y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[y&16383](l,4,0)|0;if((x|0)<1){u=1;i=b;return u|0}if((gzL(r,0,4)|0)==0){break}else{u=1}i=b;return u|0}}while(0);r=(c[2411326]|0)+524288|0;if((c[3542200]|0)==0){u=1;i=b;return u|0}w=h+108|0;c[w>>2]=0;v=h+100|0;c[v>>2]=0;x=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[x&16383](h,5)|0;do{if((c[w>>2]|0)!=0){x=c[v>>2]|0;c[j>>2]=9534384;y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[y&16383](j,5,0)|0;if((x|0)<1){u=1;i=b;return u|0}if((gzL(r,0,5)|0)==0){break}else{u=1}i=b;return u|0}}while(0);ef4();r=(c[2411320]|0)+262144|0;do{if((c[3542200]|0)!=0){v=f+108|0;c[v>>2]=0;w=f+100|0;c[w>>2]=0;x=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[x&16383](f,6)|0;if((c[v>>2]|0)==0){break}v=c[w>>2]|0;c[g>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](g,6,0)|0;if((v|0)<1){break}gzL(r,0,6)|0}}while(0);r=(c[2411320]|0)+786432|0;do{if((c[3542200]|0)!=0){v=d+108|0;c[v>>2]=0;w=d+100|0;c[w>>2]=0;x=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[x&16383](d,7)|0;if((c[v>>2]|0)==0){break}v=c[w>>2]|0;c[e>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](e,7,0)|0;if((v|0)<1){break}gzL(r,0,7)|0}}while(0);r=c[2411320]|0;v=r+262144|0;gGC(r|0,v|0,262144)|0;fxU(0,425984);if((c[2394]|0)==0){z=c[2112932]|0}else{c[2394]=0;v=c[3532596]|0;c[2112932]=v;r=c[3532592]|0;if((r|0)!=0){gGC(9104152,r|0,280)|0}c[2113054]=c[2113060];z=v}v=c[2411332]|0;r=z|0;w=0;while(1){x=v+w|0;c[r>>2]=x;c[r+131072>>2]=x;x=w+1024|0;if(x>>>0>5242879){break}else{r=r+4|0;w=x}}w=c[2418178]|0;r=z+20480|0;v=5242880;while(1){x=w+(v-5242880)|0;c[r>>2]=x;c[r+65536>>2]=x;c[r+131072>>2]=x;x=v+1024|0;if(x>>>0>5373951){break}else{r=r+4|0;v=x}}v=c[2418184]|0;r=z+20992|0;w=5373952;while(1){x=v+(w-5373952)|0;c[r>>2]=x;c[r+65536>>2]=x;c[r+131072>>2]=x;x=w+1024|0;if(x>>>0>5505023){break}else{r=r+4|0;w=x}}w=c[2411898]|0;r=w;c[z+22528>>2]=r;c[z+88064>>2]=r;c[z+153600>>2]=r;r=w+1024|0;c[z+22532>>2]=r;c[z+88068>>2]=r;c[z+153604>>2]=r;r=w+2048|0;c[z+22536>>2]=r;c[z+88072>>2]=r;c[z+153608>>2]=r;r=w+3072|0;c[z+22540>>2]=r;c[z+88076>>2]=r;c[z+153612>>2]=r;r=w+4096|0;c[z+22544>>2]=r;c[z+88080>>2]=r;c[z+153616>>2]=r;r=w+5120|0;c[z+22548>>2]=r;c[z+88084>>2]=r;c[z+153620>>2]=r;r=w+6144|0;c[z+22552>>2]=r;c[z+88088>>2]=r;c[z+153624>>2]=r;r=w+7168|0;c[z+22556>>2]=r;c[z+88092>>2]=r;c[z+153628>>2]=r;r=w+8192|0;c[z+22560>>2]=r;c[z+88096>>2]=r;c[z+153632>>2]=r;r=w+9216|0;c[z+22564>>2]=r;c[z+88100>>2]=r;c[z+153636>>2]=r;r=w+10240|0;c[z+22568>>2]=r;c[z+88104>>2]=r;c[z+153640>>2]=r;r=w+11264|0;c[z+22572>>2]=r;c[z+88108>>2]=r;c[z+153644>>2]=r;r=w+12288|0;c[z+22576>>2]=r;c[z+88112>>2]=r;c[z+153648>>2]=r;r=w+13312|0;c[z+22580>>2]=r;c[z+88116>>2]=r;c[z+153652>>2]=r;r=w+14336|0;c[z+22584>>2]=r;c[z+88120>>2]=r;c[z+153656>>2]=r;r=w+15360|0;c[z+22588>>2]=r;c[z+88124>>2]=r;c[z+153660>>2]=r;r=c[2411424]|0;w=r;c[z+24576>>2]=w;c[z+90112>>2]=w;c[z+155648>>2]=w;w=r+1024|0;c[z+24580>>2]=w;c[z+90116>>2]=w;c[z+155652>>2]=w;w=r+2048|0;c[z+24584>>2]=w;c[z+90120>>2]=w;c[z+155656>>2]=w;w=r+3072|0;c[z+24588>>2]=w;c[z+90124>>2]=w;c[z+155660>>2]=w;w=c[2411370]|0;r=w;c[z+28672>>2]=r;c[z+94208>>2]=r;c[z+159744>>2]=r;r=w+1024|0;c[z+28676>>2]=r;c[z+94212>>2]=r;c[z+159748>>2]=r;r=w+2048|0;c[z+28680>>2]=r;c[z+94216>>2]=r;c[z+159752>>2]=r;r=w+3072|0;c[z+28684>>2]=r;c[z+94220>>2]=r;c[z+159756>>2]=r;r=c[2411904]|0;w=r;v=z+63488|0;x=16252928;while(1){y=w+(x-16252928)|0;c[v>>2]=y;c[v+65536>>2]=y;c[v+131072>>2]=y;y=x+1024|0;if(y>>>0>16318463){break}else{v=v+4|0;x=y}}x=r+65536|0;c[z+26624>>2]=x;c[z+92160>>2]=x;c[z+157696>>2]=x;x=r+65568|0;c[z+30720>>2]=x;c[z+96256>>2]=x;c[z+161792>>2]=x;c[z+196688>>2]=2100;c[z+196608>>2]=1038;c[z+196648>>2]=26;x=c[3532592]|0;if((x|0)!=0){gGC(x|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;c[3541206]=c[2411320];Ux(0,12e3,0);c[2407030]=256;c[2407068]=3;a[14130536]=1;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];x=c[3532592]|0;if((x|0)!=0){gGC(9104152,x|0,280)|0}c[2113054]=c[2113060]}c[2113050]=0;c[2276080]=0;RI();x=c[2394]|0;v=c[14130368+(x<<2)>>2]|0;if((v|0)!=0){gGC(v|0,9104152,280)|0}c[8452240+(x<<2)>>2]=c[2113054];c[2394]=-1;c[2406810]=0;c[2113156]=0;a[9628264]=0;c[2407033]=0;x=c[3541206]|0;c[3541190]=x;c[3541198]=x;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=x+256;c[3541199]=x+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=x+512;c[3541200]=x+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=x+768;c[3541201]=x+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;u=0;i=b;return u|0}}while(0);c[2426708]=0;u=1;i=b;return u|0}function egI(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>4){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3929548+(b*112|0)>>2];c[a+104>>2]=c[3929552+(b*112|0)>>2];c[a+108>>2]=c[3929556+(b*112|0)>>2];d=0;return d|0}function egJ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<5&(d|0)==0)){e=1;return e|0}c[a>>2]=3929448+(b*112|0);e=0;return e|0}function egK(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1260352+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function egL(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>31){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3930008+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function egM(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=i;i=i+360|0;d=b|0;e=b+112|0;f=b+120|0;g=b+232|0;h=b+240|0;j=b+352|0;c[2426708]=0;egS();k=c[2414170]|0;l=0;while(1){if((l|0)>=1024){break}m=9638528+(l<<2)|0;if((c[m>>2]|0)==0){n=57079;break}else{l=l+1|0}}do{if((n|0)==57079){l=gGq(k)|0;c[m>>2]=l;if((l|0)==0){break}gGz(l|0,0,k|0);c[2426708]=l;gGz(l|0,0,k|0);egS();if((R6((c[2411332]|0)+1|0,0,2)|0)!=0){o=1;i=b;return o|0}if((R6(c[2411332]|0,1,2)|0)!=0){o=1;i=b;return o|0}l=c[2411326]|0;if((c[3542200]|0)==0){o=1;i=b;return o|0}p=h+108|0;c[p>>2]=0;q=h+100|0;c[q>>2]=0;r=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[r&16383](h,2)|0;do{if((c[p>>2]|0)!=0){r=c[q>>2]|0;c[j>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](j,2,0)|0;if((r|0)<1){o=1;i=b;return o|0}if((gzL(l,0,2)|0)==0){break}else{o=1}i=b;return o|0}}while(0);ef4();l=(c[2411320]|0)+262144|0;do{if((c[3542200]|0)!=0){q=f+108|0;c[q>>2]=0;p=f+100|0;c[p>>2]=0;r=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[r&16383](f,3)|0;if((c[q>>2]|0)==0){break}q=c[p>>2]|0;c[g>>2]=9534384;p=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[p&16383](g,3,0)|0;if((q|0)<1){break}gzL(l,0,3)|0}}while(0);l=(c[2411320]|0)+786432|0;do{if((c[3542200]|0)!=0){q=d+108|0;c[q>>2]=0;p=d+100|0;c[p>>2]=0;r=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[r&16383](d,4)|0;if((c[q>>2]|0)==0){break}q=c[p>>2]|0;c[e>>2]=9534384;p=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[p&16383](e,4,0)|0;if((q|0)<1){break}gzL(l,0,4)|0}}while(0);l=c[2411320]|0;q=l+262144|0;gGC(l|0,q|0,262144)|0;fxU(0,425984);if((c[2394]|0)==0){t=c[2112932]|0}else{c[2394]=0;q=c[3532596]|0;c[2112932]=q;l=c[3532592]|0;if((l|0)!=0){gGC(9104152,l|0,280)|0}c[2113054]=c[2113060];t=q}q=c[2411332]|0;l=t|0;p=0;while(1){r=q+p|0;c[l>>2]=r;c[l+131072>>2]=r;r=p+1024|0;if(r>>>0>1048575){break}else{l=l+4|0;p=r}}p=c[2418178]|0;l=t+20480|0;q=5242880;while(1){r=p+(q-5242880)|0;c[l>>2]=r;c[l+65536>>2]=r;c[l+131072>>2]=r;r=q+1024|0;if(r>>>0>5373951){break}else{l=l+4|0;q=r}}q=c[2418184]|0;l=t+20992|0;p=5373952;while(1){r=q+(p-5373952)|0;c[l>>2]=r;c[l+65536>>2]=r;c[l+131072>>2]=r;r=p+1024|0;if(r>>>0>5505023){break}else{l=l+4|0;p=r}}p=c[2411424]|0;l=p;c[t+24576>>2]=l;c[t+90112>>2]=l;c[t+155648>>2]=l;l=p+1024|0;c[t+24580>>2]=l;c[t+90116>>2]=l;c[t+155652>>2]=l;l=p+2048|0;c[t+24584>>2]=l;c[t+90120>>2]=l;c[t+155656>>2]=l;l=p+3072|0;c[t+24588>>2]=l;c[t+90124>>2]=l;c[t+155660>>2]=l;l=c[2411370]|0;p=l;c[t+28672>>2]=p;c[t+94208>>2]=p;c[t+159744>>2]=p;p=l+1024|0;c[t+28676>>2]=p;c[t+94212>>2]=p;c[t+159748>>2]=p;p=l+2048|0;c[t+28680>>2]=p;c[t+94216>>2]=p;c[t+159752>>2]=p;p=l+3072|0;c[t+28684>>2]=p;c[t+94220>>2]=p;c[t+159756>>2]=p;p=c[2411904]|0;l=p;c[t+26624>>2]=l;c[t+92160>>2]=l;c[t+157696>>2]=l;l=p+32|0;c[t+30720>>2]=l;c[t+96256>>2]=l;c[t+161792>>2]=l;l=p+64|0;p=t+59392|0;q=15204352;while(1){r=l+(q-15204352)|0;c[p>>2]=r;c[p+65536>>2]=r;c[p+131072>>2]=r;r=q+1024|0;if(r>>>0>15269887){break}else{p=p+4|0;q=r}}c[t+196688>>2]=2386;c[t+196608>>2]=586;c[t+196728>>2]=2806;c[t+196648>>2]=26;q=c[3532592]|0;if((q|0)!=0){gGC(q|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;c[3541206]=c[2411320];Ux(0,12e3,0);c[2407030]=256;c[2407068]=3;a[14130536]=1;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];q=c[3532592]|0;if((q|0)!=0){gGC(9104152,q|0,280)|0}c[2113054]=c[2113060]}c[2113050]=0;c[2276080]=0;RI();q=c[2394]|0;p=c[14130368+(q<<2)>>2]|0;if((p|0)!=0){gGC(p|0,9104152,280)|0}c[8452240+(q<<2)>>2]=c[2113054];c[2394]=-1;c[2406810]=0;c[2113156]=0;a[9628264]=0;c[2407033]=0;q=c[3541206]|0;c[3541190]=q;c[3541198]=q;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=q+256;c[3541199]=q+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=q+512;c[3541200]=q+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=q+768;c[3541201]=q+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;o=0;i=b;return o|0}}while(0);c[2426708]=0;o=1;i=b;return o|0}function egN(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;if((a[9624064]|0)!=0){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];b=c[3532592]|0;if((b|0)!=0){gGC(9104152,b|0,280)|0}c[2113054]=c[2113060]}c[2113050]=0;c[2276080]=0;RI();b=c[2394]|0;d=c[14130368+(b<<2)>>2]|0;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[8452240+(b<<2)>>2]=c[2113054];c[2394]=-1;c[2406810]=0;c[2113156]=0;a[9628264]=0;c[2407033]=0;b=c[3541206]|0;c[3541190]=b;c[3541198]=b;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=b+256;c[3541199]=b+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=b+512;c[3541200]=b+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=b+768;c[3541201]=b+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4}a[9625657]=0;a[9625659]=0;a[9625661]=0;b=0;d=0;e=0;do{d=((a[9633272+b|0]&1)<<b|d&255)&255;e=((a[9631144+b|0]&1)<<b|e&255)&255;b=b+1|0;}while((b|0)<8);a[9625657]=d;a[9625659]=e;a[9625661]=a[9551785]<<1&2|a[9551784]&1|a[9551786]<<2&4|a[9551787]<<3&8|a[9551788]<<4&16|a[9551789]<<5&32|a[9551790]<<6&64;e=c[2438]|0;d=gGU(e,(e|0)<0|0?-1:0,12e6,0)|0;e=gGS(d,K,15360,0)|0;d=e;c[2440524]=d;c[2444016]=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060]}e=(d|0)/4|0;c[2113056]=e;d=RG(e)|0;e=(c[2113054]|0)+d|0;c[2113054]=e;c[2276108]=-1;c[2113056]=-1;b=(c[2444016]|0)+d|0;c[2444016]=b;d=c[2394]|0;f=c[14130368+(d<<2)>>2]|0;if((f|0)!=0){gGC(f|0,9104152,280)|0}c[8452240+(d<<2)>>2]=e;c[2394]=0;c[2112932]=c[3532596];e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060];e=((c[2440524]<<1|0)/4|0)-b|0;c[2113056]=e;b=RG(e)|0;c[2113054]=(c[2113054]|0)+b;c[2276108]=-1;c[2113056]=-1;c[2444016]=(c[2444016]|0)+b;b=c[2394]|0;c[8452200+(b<<2)>>2]=8195;c[2276080]=768;if((c[2276079]|0)>>>0<768){RH(3);g=c[2394]|0}else{g=b}b=c[14130368+(g<<2)>>2]|0;if((b|0)!=0){gGC(b|0,9104152,280)|0}c[8452240+(g<<2)>>2]=c[2113054];c[2394]=0;c[2112932]=c[3532596];g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060];g=(((c[2440524]|0)*3|0|0)/4|0)-(c[2444016]|0)|0;c[2113056]=g;b=RG(g)|0;c[2113054]=(c[2113054]|0)+b;c[2276108]=-1;c[2113056]=-1;c[2444016]=(c[2444016]|0)+b;b=c[2394]|0;c[8452200+(b<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0<1024){RH(4);h=c[2394]|0}else{h=b}b=c[14130368+(h<<2)>>2]|0;if((b|0)!=0){gGC(b|0,9104152,280)|0}c[8452240+(h<<2)>>2]=c[2113054];c[2394]=0;c[2112932]=c[3532596];h=c[3532592]|0;if((h|0)!=0){gGC(9104152,h|0,280)|0}c[2113054]=c[2113060];h=(c[2440524]|0)-(c[2444016]|0)|0;c[2113056]=h;b=RG(h)|0;c[2113054]=(c[2113054]|0)+b;c[2276108]=-1;c[2113056]=-1;c[2444016]=(c[2444016]|0)+b;b=c[2394]|0;c[8452200+(b<<2)>>2]=8197;c[2276080]=1280;if((c[2276079]|0)>>>0<1280){RH(5);i=c[2394]|0}else{i=b}b=c[14130368+(i<<2)>>2]|0;if((b|0)!=0){gGC(b|0,9104152,280)|0}c[8452240+(i<<2)>>2]=c[2113054];c[2394]=-1;i=c[2112964]|0;if((i|0)!=0){Uu(0,i,a[9688]|0?534:0)}if((c[2112968]|0)==0){return 0}egj()|0;return 0}function egO(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5959836+(b*112|0)>>2];c[a+104>>2]=c[5959840+(b*112|0)>>2];c[a+108>>2]=c[5959844+(b*112|0)>>2];d=0;return d|0}function egP(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=5959736+(b*112|0);e=0;return e|0}function egQ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5961080+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function egR(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=i;i=i+120|0;d=b|0;e=b+112|0;c[2426708]=0;egS();f=c[2414170]|0;g=0;while(1){if((g|0)>=1024){break}h=9638528+(g<<2)|0;if((c[h>>2]|0)==0){j=57188;break}else{g=g+1|0}}do{if((j|0)==57188){g=gGq(f)|0;c[h>>2]=g;if((g|0)==0){break}gGz(g|0,0,f|0);c[2426708]=g;gGz(g|0,0,f|0);egS();if((R6((c[2411332]|0)+1|0,0,2)|0)!=0){k=1;i=b;return k|0}if((R6(c[2411332]|0,1,2)|0)!=0){k=1;i=b;return k|0}if((R6((c[2411332]|0)+1048577|0,2,2)|0)!=0){k=1;i=b;return k|0}if((R6((c[2411332]|0)+1048576|0,3,2)|0)!=0){k=1;i=b;return k|0}if((R6((c[2411332]|0)+2097153|0,4,2)|0)!=0){k=1;i=b;return k|0}if((R6((c[2411332]|0)+2097152|0,5,2)|0)!=0){k=1;i=b;return k|0}if((R6((c[2411332]|0)+3145729|0,6,2)|0)!=0){k=1;i=b;return k|0}if((R6((c[2411332]|0)+3145728|0,7,2)|0)!=0){k=1;i=b;return k|0}if((R6((c[2411332]|0)+4194305|0,8,2)|0)!=0){k=1;i=b;return k|0}if((R6((c[2411332]|0)+4194304|0,9,2)|0)!=0){k=1;i=b;return k|0}g=c[2411326]|0;if((c[3542200]|0)==0){k=1;i=b;return k|0}l=d+108|0;c[l>>2]=0;m=d+100|0;c[m>>2]=0;n=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[n&16383](d,10)|0;do{if((c[l>>2]|0)!=0){n=c[m>>2]|0;c[e>>2]=9534384;o=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[o&16383](e,10,0)|0;if((n|0)<1){k=1;i=b;return k|0}if((gzL(g,0,10)|0)==0){break}else{k=1}i=b;return k|0}}while(0);ef4();fxU(0,425984);if((c[2394]|0)==0){p=c[2112932]|0}else{c[2394]=0;g=c[3532596]|0;c[2112932]=g;m=c[3532592]|0;if((m|0)!=0){gGC(9104152,m|0,280)|0}c[2113054]=c[2113060];p=g}g=c[2411332]|0;m=p|0;l=0;while(1){n=g+l|0;c[m>>2]=n;c[m+131072>>2]=n;n=l+1024|0;if(n>>>0>5242879){break}else{m=m+4|0;l=n}}l=c[2418178]|0;m=p+20480|0;g=5242880;while(1){n=l+(g-5242880)|0;c[m>>2]=n;c[m+65536>>2]=n;c[m+131072>>2]=n;n=g+1024|0;if(n>>>0>5373951){break}else{m=m+4|0;g=n}}g=c[2418184]|0;m=p+20992|0;l=5373952;while(1){n=g+(l-5373952)|0;c[m>>2]=n;c[m+65536>>2]=n;c[m+131072>>2]=n;n=l+1024|0;if(n>>>0>5505023){break}else{m=m+4|0;l=n}}l=c[2411898]|0;m=l;c[p+22528>>2]=m;c[p+88064>>2]=m;c[p+153600>>2]=m;m=l+1024|0;c[p+22532>>2]=m;c[p+88068>>2]=m;c[p+153604>>2]=m;m=l+2048|0;c[p+22536>>2]=m;c[p+88072>>2]=m;c[p+153608>>2]=m;m=l+3072|0;c[p+22540>>2]=m;c[p+88076>>2]=m;c[p+153612>>2]=m;m=l+4096|0;c[p+22544>>2]=m;c[p+88080>>2]=m;c[p+153616>>2]=m;m=l+5120|0;c[p+22548>>2]=m;c[p+88084>>2]=m;c[p+153620>>2]=m;m=l+6144|0;c[p+22552>>2]=m;c[p+88088>>2]=m;c[p+153624>>2]=m;m=l+7168|0;c[p+22556>>2]=m;c[p+88092>>2]=m;c[p+153628>>2]=m;m=l+8192|0;c[p+22560>>2]=m;c[p+88096>>2]=m;c[p+153632>>2]=m;m=l+9216|0;c[p+22564>>2]=m;c[p+88100>>2]=m;c[p+153636>>2]=m;m=l+10240|0;c[p+22568>>2]=m;c[p+88104>>2]=m;c[p+153640>>2]=m;m=l+11264|0;c[p+22572>>2]=m;c[p+88108>>2]=m;c[p+153644>>2]=m;m=l+12288|0;c[p+22576>>2]=m;c[p+88112>>2]=m;c[p+153648>>2]=m;m=l+13312|0;c[p+22580>>2]=m;c[p+88116>>2]=m;c[p+153652>>2]=m;m=l+14336|0;c[p+22584>>2]=m;c[p+88120>>2]=m;c[p+153656>>2]=m;m=l+15360|0;c[p+22588>>2]=m;c[p+88124>>2]=m;c[p+153660>>2]=m;m=c[2411424]|0;l=m;c[p+24576>>2]=l;c[p+90112>>2]=l;c[p+155648>>2]=l;l=m+1024|0;c[p+24580>>2]=l;c[p+90116>>2]=l;c[p+155652>>2]=l;l=m+2048|0;c[p+24584>>2]=l;c[p+90120>>2]=l;c[p+155656>>2]=l;l=m+3072|0;c[p+24588>>2]=l;c[p+90124>>2]=l;c[p+155660>>2]=l;l=c[2411370]|0;m=l;c[p+28672>>2]=m;c[p+94208>>2]=m;c[p+159744>>2]=m;m=l+1024|0;c[p+28676>>2]=m;c[p+94212>>2]=m;c[p+159748>>2]=m;m=l+2048|0;c[p+28680>>2]=m;c[p+94216>>2]=m;c[p+159752>>2]=m;m=l+3072|0;c[p+28684>>2]=m;c[p+94220>>2]=m;c[p+159756>>2]=m;m=c[2411904]|0;l=m;g=p+51200|0;n=13107200;while(1){o=l+(n-13107200)|0;c[g>>2]=o;c[g+65536>>2]=o;c[g+131072>>2]=o;o=n+1024|0;if(o>>>0>13172735){break}else{g=g+4|0;n=o}}n=m+65536|0;c[p+26624>>2]=n;c[p+92160>>2]=n;c[p+157696>>2]=n;n=m+65568|0;c[p+30720>>2]=n;c[p+96256>>2]=n;c[p+161792>>2]=n;c[p+196688>>2]=2386;c[p+196608>>2]=586;c[p+196648>>2]=26;n=c[3532592]|0;if((n|0)!=0){gGC(n|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;c[3541206]=c[2411320];Ux(0,8e3,0);c[2407030]=256;c[2407068]=3;a[14130536]=1;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];n=c[3532592]|0;if((n|0)!=0){gGC(9104152,n|0,280)|0}c[2113054]=c[2113060]}c[2113050]=0;c[2276080]=0;RI();n=c[2394]|0;g=c[14130368+(n<<2)>>2]|0;if((g|0)!=0){gGC(g|0,9104152,280)|0}c[8452240+(n<<2)>>2]=c[2113054];c[2394]=-1;c[2406810]=0;c[2113156]=0;a[9628264]=0;c[2407033]=0;n=c[3541206]|0;c[3541190]=n;c[3541198]=n;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=n+256;c[3541199]=n+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=n+512;c[3541200]=n+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=n+768;c[3541201]=n+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;k=0;i=b;return k|0}}while(0);c[2426708]=0;k=1;i=b;return k|0}function egS(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[2426708]|0;b=c[c[642608+(c[2436]<<2)>>2]>>2]|0;d=(fa(b|0,304544)|0)==0;c[2411332]=a;e=d?a+1048576|0:a+5242880|0;do{if((fa(b|0,371080)|0)==0){f=57245}else{if((fa(b|0,346848)|0)==0){f=57245;break}if((fa(b|0,330936)|0)==0){f=57245;break}c[2411326]=e;g=e+1048832|0}}while(0);if((f|0)==57245){c[2411326]=e;g=e+2097408|0}c[2406598]=e+256;c[2411320]=g;e=g+1310720|0;c[2405642]=e;c[2411904]=e;c[2418178]=g+1376320;c[2418184]=g+1507392;c[2411424]=g+1638464;c[2411370]=g+1642560;c[2411898]=g+1646656;e=g+1663040|0;c[2411630]=e;c[2385758]=e;c[2385766]=g+1667136;c[2414170]=g+1798208;return}function egT(d,e,f,g,h,i){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;j=c[2112968]|0;k=(c[2406598]|0)+(d<<8)|0;d=c[2385758]|0;l=(i<<8)+h|0;m=j+(l<<1)|0;if(!(h>>>0>239|i>>>0>207)){if((g|0)==0){n=j+(l+3840<<1)|0;if((f|0)==0){o=k;p=n;q=0;while(1){r=a[o]|0;if(r<<24>>24!=0){b[p+30>>1]=c[d+((r&255|e)+256<<2)>>2]&65535}r=a[o+1|0]|0;if(r<<24>>24!=0){b[p+28>>1]=c[d+((r&255|e)+256<<2)>>2]&65535}r=a[o+2|0]|0;if(r<<24>>24!=0){b[p+26>>1]=c[d+((r&255|e)+256<<2)>>2]&65535}r=a[o+3|0]|0;if(r<<24>>24!=0){b[p+24>>1]=c[d+((r&255|e)+256<<2)>>2]&65535}r=a[o+4|0]|0;if(r<<24>>24!=0){b[p+22>>1]=c[d+((r&255|e)+256<<2)>>2]&65535}r=a[o+5|0]|0;if(r<<24>>24!=0){b[p+20>>1]=c[d+((r&255|e)+256<<2)>>2]&65535}r=a[o+6|0]|0;if(r<<24>>24!=0){b[p+18>>1]=c[d+((r&255|e)+256<<2)>>2]&65535}r=a[o+7|0]|0;if(r<<24>>24!=0){b[p+16>>1]=c[d+((r&255|e)+256<<2)>>2]&65535}r=a[o+8|0]|0;if(r<<24>>24!=0){b[p+14>>1]=c[d+((r&255|e)+256<<2)>>2]&65535}r=a[o+9|0]|0;if(r<<24>>24!=0){b[p+12>>1]=c[d+((r&255|e)+256<<2)>>2]&65535}r=a[o+10|0]|0;if(r<<24>>24!=0){b[p+10>>1]=c[d+((r&255|e)+256<<2)>>2]&65535}r=a[o+11|0]|0;if(r<<24>>24!=0){b[p+8>>1]=c[d+((r&255|e)+256<<2)>>2]&65535}r=a[o+12|0]|0;if(r<<24>>24!=0){b[p+6>>1]=c[d+((r&255|e)+256<<2)>>2]&65535}r=a[o+13|0]|0;if(r<<24>>24!=0){b[p+4>>1]=c[d+((r&255|e)+256<<2)>>2]&65535}r=a[o+14|0]|0;if(r<<24>>24!=0){b[p+2>>1]=c[d+((r&255|e)+256<<2)>>2]&65535}r=a[o+15|0]|0;if(r<<24>>24!=0){b[p>>1]=c[d+((r&255|e)+256<<2)>>2]&65535}r=q+1|0;if((r|0)<16){o=o+16|0;p=p-512|0;q=r}else{break}}return}else{q=k;p=n;n=0;while(1){o=a[q]|0;if(o<<24>>24!=0){b[p>>1]=c[d+((o&255|e)+256<<2)>>2]&65535}o=a[q+1|0]|0;if(o<<24>>24!=0){b[p+2>>1]=c[d+((o&255|e)+256<<2)>>2]&65535}o=a[q+2|0]|0;if(o<<24>>24!=0){b[p+4>>1]=c[d+((o&255|e)+256<<2)>>2]&65535}o=a[q+3|0]|0;if(o<<24>>24!=0){b[p+6>>1]=c[d+((o&255|e)+256<<2)>>2]&65535}o=a[q+4|0]|0;if(o<<24>>24!=0){b[p+8>>1]=c[d+((o&255|e)+256<<2)>>2]&65535}o=a[q+5|0]|0;if(o<<24>>24!=0){b[p+10>>1]=c[d+((o&255|e)+256<<2)>>2]&65535}o=a[q+6|0]|0;if(o<<24>>24!=0){b[p+12>>1]=c[d+((o&255|e)+256<<2)>>2]&65535}o=a[q+7|0]|0;if(o<<24>>24!=0){b[p+14>>1]=c[d+((o&255|e)+256<<2)>>2]&65535}o=a[q+8|0]|0;if(o<<24>>24!=0){b[p+16>>1]=c[d+((o&255|e)+256<<2)>>2]&65535}o=a[q+9|0]|0;if(o<<24>>24!=0){b[p+18>>1]=c[d+((o&255|e)+256<<2)>>2]&65535}o=a[q+10|0]|0;if(o<<24>>24!=0){b[p+20>>1]=c[d+((o&255|e)+256<<2)>>2]&65535}o=a[q+11|0]|0;if(o<<24>>24!=0){b[p+22>>1]=c[d+((o&255|e)+256<<2)>>2]&65535}o=a[q+12|0]|0;if(o<<24>>24!=0){b[p+24>>1]=c[d+((o&255|e)+256<<2)>>2]&65535}o=a[q+13|0]|0;if(o<<24>>24!=0){b[p+26>>1]=c[d+((o&255|e)+256<<2)>>2]&65535}o=a[q+14|0]|0;if(o<<24>>24!=0){b[p+28>>1]=c[d+((o&255|e)+256<<2)>>2]&65535}o=a[q+15|0]|0;if(o<<24>>24!=0){b[p+30>>1]=c[d+((o&255|e)+256<<2)>>2]&65535}o=n+1|0;if((o|0)<16){q=q+16|0;p=p-512|0;n=o}else{break}}return}}else{if((f|0)==0){n=k;p=m;q=0;while(1){o=a[n]|0;if(o<<24>>24!=0){b[p+30>>1]=c[d+((o&255|e)+256<<2)>>2]&65535}o=a[n+1|0]|0;if(o<<24>>24!=0){b[p+28>>1]=c[d+((o&255|e)+256<<2)>>2]&65535}o=a[n+2|0]|0;if(o<<24>>24!=0){b[p+26>>1]=c[d+((o&255|e)+256<<2)>>2]&65535}o=a[n+3|0]|0;if(o<<24>>24!=0){b[p+24>>1]=c[d+((o&255|e)+256<<2)>>2]&65535}o=a[n+4|0]|0;if(o<<24>>24!=0){b[p+22>>1]=c[d+((o&255|e)+256<<2)>>2]&65535}o=a[n+5|0]|0;if(o<<24>>24!=0){b[p+20>>1]=c[d+((o&255|e)+256<<2)>>2]&65535}o=a[n+6|0]|0;if(o<<24>>24!=0){b[p+18>>1]=c[d+((o&255|e)+256<<2)>>2]&65535}o=a[n+7|0]|0;if(o<<24>>24!=0){b[p+16>>1]=c[d+((o&255|e)+256<<2)>>2]&65535}o=a[n+8|0]|0;if(o<<24>>24!=0){b[p+14>>1]=c[d+((o&255|e)+256<<2)>>2]&65535}o=a[n+9|0]|0;if(o<<24>>24!=0){b[p+12>>1]=c[d+((o&255|e)+256<<2)>>2]&65535}o=a[n+10|0]|0;if(o<<24>>24!=0){b[p+10>>1]=c[d+((o&255|e)+256<<2)>>2]&65535}o=a[n+11|0]|0;if(o<<24>>24!=0){b[p+8>>1]=c[d+((o&255|e)+256<<2)>>2]&65535}o=a[n+12|0]|0;if(o<<24>>24!=0){b[p+6>>1]=c[d+((o&255|e)+256<<2)>>2]&65535}o=a[n+13|0]|0;if(o<<24>>24!=0){b[p+4>>1]=c[d+((o&255|e)+256<<2)>>2]&65535}o=a[n+14|0]|0;if(o<<24>>24!=0){b[p+2>>1]=c[d+((o&255|e)+256<<2)>>2]&65535}o=a[n+15|0]|0;if(o<<24>>24!=0){b[p>>1]=c[d+((o&255|e)+256<<2)>>2]&65535}o=q+1|0;if((o|0)<16){n=n+16|0;p=p+512|0;q=o}else{break}}return}else{q=k;p=m;n=0;while(1){o=a[q]|0;if(o<<24>>24!=0){b[p>>1]=c[d+((o&255|e)+256<<2)>>2]&65535}o=a[q+1|0]|0;if(o<<24>>24!=0){b[p+2>>1]=c[d+((o&255|e)+256<<2)>>2]&65535}o=a[q+2|0]|0;if(o<<24>>24!=0){b[p+4>>1]=c[d+((o&255|e)+256<<2)>>2]&65535}o=a[q+3|0]|0;if(o<<24>>24!=0){b[p+6>>1]=c[d+((o&255|e)+256<<2)>>2]&65535}o=a[q+4|0]|0;if(o<<24>>24!=0){b[p+8>>1]=c[d+((o&255|e)+256<<2)>>2]&65535}o=a[q+5|0]|0;if(o<<24>>24!=0){b[p+10>>1]=c[d+((o&255|e)+256<<2)>>2]&65535}o=a[q+6|0]|0;if(o<<24>>24!=0){b[p+12>>1]=c[d+((o&255|e)+256<<2)>>2]&65535}o=a[q+7|0]|0;if(o<<24>>24!=0){b[p+14>>1]=c[d+((o&255|e)+256<<2)>>2]&65535}o=a[q+8|0]|0;if(o<<24>>24!=0){b[p+16>>1]=c[d+((o&255|e)+256<<2)>>2]&65535}o=a[q+9|0]|0;if(o<<24>>24!=0){b[p+18>>1]=c[d+((o&255|e)+256<<2)>>2]&65535}o=a[q+10|0]|0;if(o<<24>>24!=0){b[p+20>>1]=c[d+((o&255|e)+256<<2)>>2]&65535}o=a[q+11|0]|0;if(o<<24>>24!=0){b[p+22>>1]=c[d+((o&255|e)+256<<2)>>2]&65535}o=a[q+12|0]|0;if(o<<24>>24!=0){b[p+24>>1]=c[d+((o&255|e)+256<<2)>>2]&65535}o=a[q+13|0]|0;if(o<<24>>24!=0){b[p+26>>1]=c[d+((o&255|e)+256<<2)>>2]&65535}o=a[q+14|0]|0;if(o<<24>>24!=0){b[p+28>>1]=c[d+((o&255|e)+256<<2)>>2]&65535}o=a[q+15|0]|0;if(o<<24>>24!=0){b[p+30>>1]=c[d+((o&255|e)+256<<2)>>2]&65535}o=n+1|0;if((o|0)<16){q=q+16|0;p=p+512|0;n=o}else{break}}return}}}n=h+15|0;if(n>>>0>270){return}if((i+15|0)>>>0>238){return}if((g|0)==0){g=j+(l+3840<<1)|0;l=(h|0)>-1;j=(h|0)<256;if((f|0)==0){p=n>>>0>255;q=(h+14|0)>>>0>255;o=(h+13|0)>>>0>255;r=(h+12|0)>>>0>255;s=(h+11|0)>>>0>255;t=(h+10|0)>>>0>255;u=(h+9|0)>>>0>255;v=(h+8|0)>>>0>255;w=(h+7|0)>>>0>255;x=(h+6|0)>>>0>255;y=(h+5|0)>>>0>255;z=(h+4|0)>>>0>255;A=(h+3|0)>>>0>255;B=(h+2|0)>>>0>255;C=(h+1|0)>>>0>255;D=k;E=g;F=15;while(1){do{if((F+i|0)>>>0<224){G=a[D]|0;if(!(G<<24>>24==0|p)){b[E+30>>1]=c[d+((G&255|e)+256<<2)>>2]&65535}G=a[D+1|0]|0;if(!(G<<24>>24==0|q)){b[E+28>>1]=c[d+((G&255|e)+256<<2)>>2]&65535}G=a[D+2|0]|0;if(!(G<<24>>24==0|o)){b[E+26>>1]=c[d+((G&255|e)+256<<2)>>2]&65535}G=a[D+3|0]|0;if(!(G<<24>>24==0|r)){b[E+24>>1]=c[d+((G&255|e)+256<<2)>>2]&65535}G=a[D+4|0]|0;if(!(G<<24>>24==0|s)){b[E+22>>1]=c[d+((G&255|e)+256<<2)>>2]&65535}G=a[D+5|0]|0;if(!(G<<24>>24==0|t)){b[E+20>>1]=c[d+((G&255|e)+256<<2)>>2]&65535}G=a[D+6|0]|0;if(!(G<<24>>24==0|u)){b[E+18>>1]=c[d+((G&255|e)+256<<2)>>2]&65535}G=a[D+7|0]|0;if(!(G<<24>>24==0|v)){b[E+16>>1]=c[d+((G&255|e)+256<<2)>>2]&65535}G=a[D+8|0]|0;if(!(G<<24>>24==0|w)){b[E+14>>1]=c[d+((G&255|e)+256<<2)>>2]&65535}G=a[D+9|0]|0;if(!(G<<24>>24==0|x)){b[E+12>>1]=c[d+((G&255|e)+256<<2)>>2]&65535}G=a[D+10|0]|0;if(!(G<<24>>24==0|y)){b[E+10>>1]=c[d+((G&255|e)+256<<2)>>2]&65535}G=a[D+11|0]|0;if(!(G<<24>>24==0|z)){b[E+8>>1]=c[d+((G&255|e)+256<<2)>>2]&65535}G=a[D+12|0]|0;if(!(G<<24>>24==0|A)){b[E+6>>1]=c[d+((G&255|e)+256<<2)>>2]&65535}G=a[D+13|0]|0;if(!(G<<24>>24==0|B)){b[E+4>>1]=c[d+((G&255|e)+256<<2)>>2]&65535}G=a[D+14|0]|0;if(!(G<<24>>24==0|C)){b[E+2>>1]=c[d+((G&255|e)+256<<2)>>2]&65535}G=a[D+15|0]|0;if(!(G<<24>>24!=0&l&j)){break}b[E>>1]=c[d+((G&255|e)+256<<2)>>2]&65535}}while(0);if((F|0)>0){D=D+16|0;E=E-512|0;F=F-1|0}else{break}}return}else{F=(h+1|0)>>>0>255;E=(h+2|0)>>>0>255;D=(h+3|0)>>>0>255;C=(h+4|0)>>>0>255;B=(h+5|0)>>>0>255;A=(h+6|0)>>>0>255;z=(h+7|0)>>>0>255;y=(h+8|0)>>>0>255;x=(h+9|0)>>>0>255;w=(h+10|0)>>>0>255;v=(h+11|0)>>>0>255;u=(h+12|0)>>>0>255;t=(h+13|0)>>>0>255;s=(h+14|0)>>>0>255;r=n>>>0>255;o=k;q=g;g=15;while(1){do{if((g+i|0)>>>0<224){p=a[o]|0;if(p<<24>>24!=0&l&j){b[q>>1]=c[d+((p&255|e)+256<<2)>>2]&65535}p=a[o+1|0]|0;if(!(p<<24>>24==0|F)){b[q+2>>1]=c[d+((p&255|e)+256<<2)>>2]&65535}p=a[o+2|0]|0;if(!(p<<24>>24==0|E)){b[q+4>>1]=c[d+((p&255|e)+256<<2)>>2]&65535}p=a[o+3|0]|0;if(!(p<<24>>24==0|D)){b[q+6>>1]=c[d+((p&255|e)+256<<2)>>2]&65535}p=a[o+4|0]|0;if(!(p<<24>>24==0|C)){b[q+8>>1]=c[d+((p&255|e)+256<<2)>>2]&65535}p=a[o+5|0]|0;if(!(p<<24>>24==0|B)){b[q+10>>1]=c[d+((p&255|e)+256<<2)>>2]&65535}p=a[o+6|0]|0;if(!(p<<24>>24==0|A)){b[q+12>>1]=c[d+((p&255|e)+256<<2)>>2]&65535}p=a[o+7|0]|0;if(!(p<<24>>24==0|z)){b[q+14>>1]=c[d+((p&255|e)+256<<2)>>2]&65535}p=a[o+8|0]|0;if(!(p<<24>>24==0|y)){b[q+16>>1]=c[d+((p&255|e)+256<<2)>>2]&65535}p=a[o+9|0]|0;if(!(p<<24>>24==0|x)){b[q+18>>1]=c[d+((p&255|e)+256<<2)>>2]&65535}p=a[o+10|0]|0;if(!(p<<24>>24==0|w)){b[q+20>>1]=c[d+((p&255|e)+256<<2)>>2]&65535}p=a[o+11|0]|0;if(!(p<<24>>24==0|v)){b[q+22>>1]=c[d+((p&255|e)+256<<2)>>2]&65535}p=a[o+12|0]|0;if(!(p<<24>>24==0|u)){b[q+24>>1]=c[d+((p&255|e)+256<<2)>>2]&65535}p=a[o+13|0]|0;if(!(p<<24>>24==0|t)){b[q+26>>1]=c[d+((p&255|e)+256<<2)>>2]&65535}p=a[o+14|0]|0;if(!(p<<24>>24==0|s)){b[q+28>>1]=c[d+((p&255|e)+256<<2)>>2]&65535}p=a[o+15|0]|0;if(p<<24>>24==0|r){break}b[q+30>>1]=c[d+((p&255|e)+256<<2)>>2]&65535}}while(0);if((g|0)>0){o=o+16|0;q=q-512|0;g=g-1|0}else{break}}return}}else{g=(h|0)>-1;q=(h|0)<256;if((f|0)==0){f=n>>>0>255;o=(h+14|0)>>>0>255;r=(h+13|0)>>>0>255;s=(h+12|0)>>>0>255;t=(h+11|0)>>>0>255;u=(h+10|0)>>>0>255;v=(h+9|0)>>>0>255;w=(h+8|0)>>>0>255;x=(h+7|0)>>>0>255;y=(h+6|0)>>>0>255;z=(h+5|0)>>>0>255;A=(h+4|0)>>>0>255;B=(h+3|0)>>>0>255;C=(h+2|0)>>>0>255;D=(h+1|0)>>>0>255;E=k;F=m;j=0;while(1){do{if((j+i|0)>>>0<224){l=a[E]|0;if(!(l<<24>>24==0|f)){b[F+30>>1]=c[d+((l&255|e)+256<<2)>>2]&65535}l=a[E+1|0]|0;if(!(l<<24>>24==0|o)){b[F+28>>1]=c[d+((l&255|e)+256<<2)>>2]&65535}l=a[E+2|0]|0;if(!(l<<24>>24==0|r)){b[F+26>>1]=c[d+((l&255|e)+256<<2)>>2]&65535}l=a[E+3|0]|0;if(!(l<<24>>24==0|s)){b[F+24>>1]=c[d+((l&255|e)+256<<2)>>2]&65535}l=a[E+4|0]|0;if(!(l<<24>>24==0|t)){b[F+22>>1]=c[d+((l&255|e)+256<<2)>>2]&65535}l=a[E+5|0]|0;if(!(l<<24>>24==0|u)){b[F+20>>1]=c[d+((l&255|e)+256<<2)>>2]&65535}l=a[E+6|0]|0;if(!(l<<24>>24==0|v)){b[F+18>>1]=c[d+((l&255|e)+256<<2)>>2]&65535}l=a[E+7|0]|0;if(!(l<<24>>24==0|w)){b[F+16>>1]=c[d+((l&255|e)+256<<2)>>2]&65535}l=a[E+8|0]|0;if(!(l<<24>>24==0|x)){b[F+14>>1]=c[d+((l&255|e)+256<<2)>>2]&65535}l=a[E+9|0]|0;if(!(l<<24>>24==0|y)){b[F+12>>1]=c[d+((l&255|e)+256<<2)>>2]&65535}l=a[E+10|0]|0;if(!(l<<24>>24==0|z)){b[F+10>>1]=c[d+((l&255|e)+256<<2)>>2]&65535}l=a[E+11|0]|0;if(!(l<<24>>24==0|A)){b[F+8>>1]=c[d+((l&255|e)+256<<2)>>2]&65535}l=a[E+12|0]|0;if(!(l<<24>>24==0|B)){b[F+6>>1]=c[d+((l&255|e)+256<<2)>>2]&65535}l=a[E+13|0]|0;if(!(l<<24>>24==0|C)){b[F+4>>1]=c[d+((l&255|e)+256<<2)>>2]&65535}l=a[E+14|0]|0;if(!(l<<24>>24==0|D)){b[F+2>>1]=c[d+((l&255|e)+256<<2)>>2]&65535}l=a[E+15|0]|0;if(!(l<<24>>24!=0&g&q)){break}b[F>>1]=c[d+((l&255|e)+256<<2)>>2]&65535}}while(0);l=j+1|0;if((l|0)<16){E=E+16|0;F=F+512|0;j=l}else{break}}return}else{j=(h+1|0)>>>0>255;F=(h+2|0)>>>0>255;E=(h+3|0)>>>0>255;D=(h+4|0)>>>0>255;C=(h+5|0)>>>0>255;B=(h+6|0)>>>0>255;A=(h+7|0)>>>0>255;z=(h+8|0)>>>0>255;y=(h+9|0)>>>0>255;x=(h+10|0)>>>0>255;w=(h+11|0)>>>0>255;v=(h+12|0)>>>0>255;u=(h+13|0)>>>0>255;t=(h+14|0)>>>0>255;h=n>>>0>255;n=k;k=m;m=0;while(1){do{if((m+i|0)>>>0<224){s=a[n]|0;if(s<<24>>24!=0&g&q){b[k>>1]=c[d+((s&255|e)+256<<2)>>2]&65535}s=a[n+1|0]|0;if(!(s<<24>>24==0|j)){b[k+2>>1]=c[d+((s&255|e)+256<<2)>>2]&65535}s=a[n+2|0]|0;if(!(s<<24>>24==0|F)){b[k+4>>1]=c[d+((s&255|e)+256<<2)>>2]&65535}s=a[n+3|0]|0;if(!(s<<24>>24==0|E)){b[k+6>>1]=c[d+((s&255|e)+256<<2)>>2]&65535}s=a[n+4|0]|0;if(!(s<<24>>24==0|D)){b[k+8>>1]=c[d+((s&255|e)+256<<2)>>2]&65535}s=a[n+5|0]|0;if(!(s<<24>>24==0|C)){b[k+10>>1]=c[d+((s&255|e)+256<<2)>>2]&65535}s=a[n+6|0]|0;if(!(s<<24>>24==0|B)){b[k+12>>1]=c[d+((s&255|e)+256<<2)>>2]&65535}s=a[n+7|0]|0;if(!(s<<24>>24==0|A)){b[k+14>>1]=c[d+((s&255|e)+256<<2)>>2]&65535}s=a[n+8|0]|0;if(!(s<<24>>24==0|z)){b[k+16>>1]=c[d+((s&255|e)+256<<2)>>2]&65535}s=a[n+9|0]|0;if(!(s<<24>>24==0|y)){b[k+18>>1]=c[d+((s&255|e)+256<<2)>>2]&65535}s=a[n+10|0]|0;if(!(s<<24>>24==0|x)){b[k+20>>1]=c[d+((s&255|e)+256<<2)>>2]&65535}s=a[n+11|0]|0;if(!(s<<24>>24==0|w)){b[k+22>>1]=c[d+((s&255|e)+256<<2)>>2]&65535}s=a[n+12|0]|0;if(!(s<<24>>24==0|v)){b[k+24>>1]=c[d+((s&255|e)+256<<2)>>2]&65535}s=a[n+13|0]|0;if(!(s<<24>>24==0|u)){b[k+26>>1]=c[d+((s&255|e)+256<<2)>>2]&65535}s=a[n+14|0]|0;if(!(s<<24>>24==0|t)){b[k+28>>1]=c[d+((s&255|e)+256<<2)>>2]&65535}s=a[n+15|0]|0;if(s<<24>>24==0|h){break}b[k+30>>1]=c[d+((s&255|e)+256<<2)>>2]&65535}}while(0);s=m+1|0;if((s|0)<16){n=n+16|0;k=k+512|0;m=s}else{break}}return}}}function egU(b){b=b|0;var c=0;switch(b|0){case 1310752:{c=(d[9657937]|0)>>>2&48|-49-(a[9625652]|0)&255;break};case 1310757:{c=~a[9625650];break};case 1310753:{c=~a[9625648];break};case 1310759:{c=~a[9625651];break};case 1310758:{c=((a[9545144]|0)==0?-4:-5)|(d[9657936]|0)>>>6;break};case 1310755:{c=~a[9625649];break};default:{c=0}}return c|0}function egV(a,d){a=a|0;d=d|0;var e=0;e=a-786432|0;if(e>>>0<8192){b[(c[2437772]|0)+(e>>>1<<1)>>1]=d&255;return}if((a|0)!=1310737){return}b[4814248]=d&255;return}function egW(e){e=e|0;var f=0,g=0;f=e-1572864|0;if(f>>>0<65536){g=b[(c[2439610]|0)+((f>>>1&15|f>>>3&8176)<<1)>>1]|0;return g|0}if((e|0)==1310758){g=(((a[9545144]|0)==0?-1024:-2048)|d[9625651]|d[9657936]<<2&768)^255;return g|0}else if((e|0)==1310756){g=(d[9657936]<<8&16128|d[9625650])^255;return g|0}else if((e|0)==1310752){g=(d[9625652]<<8&-12544|d[9625648]|d[9657937]<<6&12288)^-12289;return g|0}else if((e|0)==1310754){g=(d[9657937]<<8&16128|d[9625649])^255;return g|0}else{g=0;return g|0}return 0}function egX(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=d-786432|0;if(f>>>0<8192){b[(c[2437772]|0)+(f>>>1<<1)>>1]=e;return}f=d-1572864|0;if(f>>>0<65536){b[(c[2439610]|0)+((f>>>1&15|f>>>3&8176)<<1)>>1]=e;return}if((d-1179648|0)>>>0<8192){return}if((d|0)==1048576){b[4879968]=e&511;return}else if((d|0)==1310736){b[4814248]=e;return}else if((d|0)==1310732){a[9758160]=e&255;f=c[2439330]|0;if((f|0)!=0){g=f;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;g=c[2433530]|0;c[2433530]=g+12;f=c[1836236]|0;h=c[9757320+(f<<2)>>2]|0;if((a[h+4188|0]|0)==0){i=gfc(100)|0;j=c[1836236]|0;k=i;l=(c[2433530]|0)+i|0;m=j;n=c[9757320+(j<<2)>>2]|0}else{k=100;l=g+112|0;m=f;n=h}c[2433530]=l;c[2444077]=(c[2444077]|0)+k;if((n|0)!=0){k=n;gGC(k|0,9706056,76)|0}c[9752472+(m<<2)>>2]=l;c[14113936+(m<<2)>>2]=c[2076596];c[9669104+(m<<2)>>2]=c[3541536];c[1836236]=-1;return}else if((d|0)==1048580){b[4879960]=e&511;return}else if((d|0)==1048582){b[4879956]=e&511;return}else if((d|0)==1048578){b[4879964]=e&511;return}else{return}}function egY(b){b=b|0;var d=0,e=0;d=b&65535;if((d|0)==51201){e=c[(c[3531464]|0)+4240>>2]&255}else if((d|0)==57344){e=a[9758160]|0}else if((d|0)==55296){e=c[2113156]&255}else{e=0}return e|0}function egZ(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;e=b&65535;if((e|0)==59392){b=d&1;a[14120992]=b;f=c[3541206]|0;g=(c[2433466]|0)+((b&255)<<18)|0;gGC(f|0,g|0,262144)|0;return}else if((e|0)==55296){Uv(0,d);return}else if((e|0)==51200){c[2113304]=d&255;return}else if((e|0)==51201){e=c[2113304]|0;a[14168504+e|0]=d;mv(0,e,d&255);return}else{return}}function eg_(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7403604+(b*112|0)>>2];c[a+104>>2]=c[7403608+(b*112|0)>>2];c[a+108>>2]=c[7403612+(b*112|0)>>2];d=0;return d|0}function eg$(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=7403504+(b*112|0);e=0;return e|0}function eg0(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>32){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6926e3+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eg1(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>41){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7435304+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eg2(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0;e=i;i=i+1560|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;B=e+1200|0;C=e+1312|0;D=e+1320|0;E=e+1432|0;F=e+1440|0;G=e+1552|0;H=(fa(c[c[642608+(c[2436]<<2)>>2]>>2]|0,95552)|0)==0;I=H?2:0;c[2426706]=0;c[2388026]=0;c[2385832]=524288;c[3541206]=589824;c[2433466]=851968;c[2405640]=1376256;c[2388046]=1376256;c[2385850]=1392640;c[2437772]=1394688;c[2443410]=1402880;c[2433440]=1411072;c[2438820]=1419264;c[2438818]=1423360;c[2439610]=1427456;c[2411628]=1443840;c[2406518]=1443840;c[2405808]=1705984;c[3529570]=2754560;c[3529986]=19531776;H=0;while(1){if((H|0)>=1024){break}J=9638528+(H<<2)|0;if((c[J>>2]|0)==0){K=57647;break}else{H=H+1|0}}do{if((K|0)==57647){H=gGq(19564544)|0;c[J>>2]=H;if((H|0)==0){break}c[2426706]=H;gGz(H|0,0,19564544);c[2388026]=H;c[2385832]=H+524288;c[3541206]=H+589824;c[2433466]=H+851968;L=H+1376256|0;c[2405640]=L;c[2388046]=L;c[2385850]=H+1392640;c[2437772]=H+1394688;c[2443410]=H+1402880;c[2433440]=H+1411072;c[2438820]=H+1419264;c[2438818]=H+1423360;c[2439610]=H+1427456;L=H+1443840|0;c[2411628]=L;c[2406518]=L;c[2405808]=H+1705984;c[3529570]=H+2754560;c[3529986]=H+19531776;c[2414168]=H+19564544;H=0;while(1){if((H|0)>=1024){M=0;break}N=9638528+(H<<2)|0;if((c[N>>2]|0)==0){K=57652;break}else{H=H+1|0}}do{if((K|0)==57652){H=gGq(8388608)|0;c[N>>2]=H;if((H|0)==0){M=0;break}gGz(H|0,0,8388608);M=H}}while(0);c[3529520]=M;if((R6(c[2388026]|0,0,2)|0)!=0){O=1;i=e;return O|0}if((R6((c[2388026]|0)+1|0,1,2)|0)!=0){O=1;i=e;return O|0}H=c[2385832]|0;if((c[3542200]|0)==0){O=1;i=e;return O|0}L=F+108|0;c[L>>2]=0;P=F+100|0;c[P>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](F,2)|0;do{if((c[L>>2]|0)!=0){Q=c[P>>2]|0;c[G>>2]=9534384;R=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[R&16383](G,2,0)|0;if((Q|0)<1){O=1;i=e;return O|0}if((gzL(H,0,2)|0)==0){break}else{O=1}i=e;return O|0}}while(0);H=c[3529520]|0;if((c[3542200]|0)==0){O=1;i=e;return O|0}P=D+108|0;c[P>>2]=0;L=D+100|0;c[L>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](D,3)|0;do{if((c[P>>2]|0)!=0){Q=c[L>>2]|0;c[E>>2]=9534384;R=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[R&16383](E,3,0)|0;if((Q|0)<1){O=1;i=e;return O|0}if((gzL(H,0,3)|0)==0){break}else{O=1}i=e;return O|0}}while(0);H=c[3529520]|0;L=c[2406518]|0;P=0;do{Q=P<<6;gGz(L+Q|0,0,64);R=P<<8;S=0;do{T=1<<3-S;U=(c[1983672+(S<<2)>>2]|0)+R|0;V=0;do{W=U+(c[1238464+(V<<2)>>2]|0)|0;X=(V<<3)+Q|0;Y=0;do{Z=W+(c[6964280+(Y<<2)>>2]|0)|0;if(((d[H+((Z|0)/8|0)|0]|0)&128>>>((Z&7)>>>0)|0)!=0){Z=L+(X+Y)|0;a[Z]=(d[Z]|0|T)&255}Y=Y+1|0;}while((Y|0)<8);V=V+1|0;}while((V|0)<8);S=S+1|0;}while((S|0)<4);P=P+1|0;}while((P|0)<4096);gGz(H|0,0,8388608);P=c[642608+(c[2436]<<2)>>2]|0;L=H+262144|0;do{if((fa(c[P>>2]|0,95552)|0)==0){if((R6(L,4,2)|0)!=0){O=1;i=e;return O|0}if((R6((c[3529520]|0)+262145|0,5,2)|0)!=0){O=1;i=e;return O|0}if((R6(c[3529520]|0,6,2)|0)!=0){O=1;i=e;return O|0}if((R6((c[3529520]|0)+1|0,7,2)|0)==0){break}else{O=1}i=e;return O|0}else{if((c[3542200]|0)==0){O=1;i=e;return O|0}S=B+108|0;c[S>>2]=0;Q=B+100|0;c[Q>>2]=0;R=c[P+76>>2]|0;gA[R&16383](B,4)|0;do{if((c[S>>2]|0)!=0){R=c[Q>>2]|0;c[C>>2]=9534384;V=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[V&16383](C,4,0)|0;if((R|0)<1){O=1;i=e;return O|0}if((gzL(L,0,4)|0)==0){break}else{O=1}i=e;return O|0}}while(0);Q=c[3529520]|0;if((c[3542200]|0)==0){O=1;i=e;return O|0}S=z+108|0;c[S>>2]=0;R=z+100|0;c[R>>2]=0;V=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[V&16383](z,5)|0;if((c[S>>2]|0)==0){break}S=c[R>>2]|0;c[A>>2]=9534384;R=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[R&16383](A,5,0)|0;if((S|0)<1){O=1;i=e;return O|0}if((gzL(Q,0,5)|0)==0){break}else{O=1}i=e;return O|0}}while(0);L=c[3529520]|0;P=c[2405808]|0;H=0;do{Q=H<<8;gGz(P+Q|0,0,256);S=H<<9;R=0;do{V=1<<3-R;T=(c[1658016+(R<<2)>>2]|0)+S|0;U=0;do{Y=T+(c[608544+(U<<2)>>2]|0)|0;X=(U<<4)+Q|0;W=0;do{Z=Y+(c[6669416+(W<<2)>>2]|0)|0;if(((d[L+((Z|0)/8|0)|0]|0)&128>>>((Z&7)>>>0)|0)!=0){Z=P+(X+W)|0;a[Z]=(d[Z]|0|V)&255}W=W+1|0;}while((W|0)<16);U=U+1|0;}while((U|0)<16);R=R+1|0;}while((R|0)<4);H=H+1|0;}while((H|0)<4096);gGz(L|0,0,8388608);H=I+6|0;if((c[3542200]|0)==0){O=1;i=e;return O|0}P=x+108|0;c[P>>2]=0;R=x+100|0;c[R>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,H)|0;do{if((c[P>>2]|0)!=0){Q=c[R>>2]|0;c[y>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](y,H,0)|0;if((Q|0)<1){O=1;i=e;return O|0}if((gzL(L,0,H)|0)==0){break}else{O=1}i=e;return O|0}}while(0);H=(c[3529520]|0)+1048576|0;L=I+7|0;if((c[3542200]|0)==0){O=1;i=e;return O|0}R=v+108|0;c[R>>2]=0;P=v+100|0;c[P>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,L)|0;do{if((c[R>>2]|0)!=0){Q=c[P>>2]|0;c[w>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](w,L,0)|0;if((Q|0)<1){O=1;i=e;return O|0}if((gzL(H,0,L)|0)==0){break}else{O=1}i=e;return O|0}}while(0);L=(c[3529520]|0)+2097152|0;H=I|8;if((c[3542200]|0)==0){O=1;i=e;return O|0}P=t+108|0;c[P>>2]=0;R=t+100|0;c[R>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,H)|0;do{if((c[P>>2]|0)!=0){Q=c[R>>2]|0;c[u>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](u,H,0)|0;if((Q|0)<1){O=1;i=e;return O|0}if((gzL(L,0,H)|0)==0){break}else{O=1}i=e;return O|0}}while(0);H=(c[3529520]|0)+3145728|0;L=I|9;if((c[3542200]|0)==0){O=1;i=e;return O|0}R=r+108|0;c[R>>2]=0;P=r+100|0;c[P>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,L)|0;do{if((c[R>>2]|0)!=0){Q=c[P>>2]|0;c[s>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](s,L,0)|0;if((Q|0)<1){O=1;i=e;return O|0}if((gzL(H,0,L)|0)==0){break}else{O=1}i=e;return O|0}}while(0);L=(c[3529520]|0)+4194304|0;H=I+10|0;if((c[3542200]|0)==0){O=1;i=e;return O|0}P=p+108|0;c[P>>2]=0;R=p+100|0;c[R>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,H)|0;do{if((c[P>>2]|0)!=0){Q=c[R>>2]|0;c[q>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](q,H,0)|0;if((Q|0)<1){O=1;i=e;return O|0}if((gzL(L,0,H)|0)==0){break}else{O=1}i=e;return O|0}}while(0);H=(c[3529520]|0)+5242880|0;L=I+11|0;if((c[3542200]|0)==0){O=1;i=e;return O|0}R=n+108|0;c[R>>2]=0;P=n+100|0;c[P>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,L)|0;do{if((c[R>>2]|0)!=0){Q=c[P>>2]|0;c[o>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](o,L,0)|0;if((Q|0)<1){O=1;i=e;return O|0}if((gzL(H,0,L)|0)==0){break}else{O=1}i=e;return O|0}}while(0);L=(c[3529520]|0)+6291456|0;H=I|12;if((c[3542200]|0)==0){O=1;i=e;return O|0}P=l+108|0;c[P>>2]=0;R=l+100|0;c[R>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,H)|0;do{if((c[P>>2]|0)!=0){Q=c[R>>2]|0;c[m>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](m,H,0)|0;if((Q|0)<1){O=1;i=e;return O|0}if((gzL(L,0,H)|0)==0){break}else{O=1}i=e;return O|0}}while(0);H=(c[3529520]|0)+7340032|0;L=I|13;if((c[3542200]|0)==0){O=1;i=e;return O|0}R=j+108|0;c[R>>2]=0;P=j+100|0;c[P>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,L)|0;do{if((c[R>>2]|0)!=0){Q=c[P>>2]|0;c[k>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](k,L,0)|0;if((Q|0)<1){O=1;i=e;return O|0}if((gzL(H,0,L)|0)==0){break}else{O=1}i=e;return O|0}}while(0);L=c[3529520]|0;H=c[3529570]|0;P=0;do{R=P<<8;gGz(H+R|0,0,256);Q=0;do{S=1<<3-Q;U=(c[961440+(Q<<2)>>2]|0)+R|0;V=0;do{T=U+(c[609008+(V<<2)>>2]|0)|0;W=(V<<4)+R|0;X=0;do{Y=T+(c[597864+(X<<2)>>2]|0)|0;if(((d[L+((Y|0)/8|0)|0]|0)&128>>>((Y&7)>>>0)|0)!=0){Y=H+(W+X)|0;a[Y]=(d[Y]|0|S)&255}X=X+1|0;}while((X|0)<16);V=V+1|0;}while((V|0)<16);Q=Q+1|0;}while((Q|0)<4);P=P+1|0;}while((P|0)<65536);P=c[2433466]|0;H=I+14|0;if((c[3542200]|0)==0){O=1;i=e;return O|0}L=f+108|0;c[L>>2]=0;Q=f+100|0;c[Q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,H)|0;do{if((c[L>>2]|0)!=0){R=c[Q>>2]|0;c[g>>2]=9534384;V=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[V&16383](g,H,0)|0;if((R|0)<1){O=1;i=e;return O|0}if((gzL(P,0,H)|0)==0){break}else{O=1}i=e;return O|0}}while(0);H=c[3541206]|0;P=c[2433466]|0;gGC(H|0,P|0,262144)|0;P=c[3529520]|0;H=0;while(1){if((H|0)>=1024){break}_=9638528+(H<<2)|0;if((c[_>>2]|0)==(P|0)){K=57746;break}else{H=H+1|0}}if((K|0)==57746){gGr(P);c[_>>2]=0}c[3529520]=0;fxU(0,425984);if((c[2394]|0)==0){$=c[2112932]|0}else{c[2394]=0;H=c[3532596]|0;c[2112932]=H;Q=c[3532592]|0;if((Q|0)!=0){gGC(9104152,Q|0,280)|0}c[2113054]=c[2113060];$=H}H=c[2388026]|0;Q=$|0;L=0;while(1){R=H+L|0;c[Q>>2]=R;c[Q+131072>>2]=R;R=L+1024|0;if(R>>>0>524287){break}else{Q=Q+4|0;L=R}}L=c[2438820]|0;c[$+2048>>2]=L;c[$+67584>>2]=L;c[$+133120>>2]=L;Q=L+1024|0;c[$+2052>>2]=Q;c[$+67588>>2]=Q;c[$+133124>>2]=Q;Q=L+2048|0;c[$+2056>>2]=Q;c[$+67592>>2]=Q;c[$+133128>>2]=Q;Q=L+3072|0;c[$+2060>>2]=Q;c[$+67596>>2]=Q;c[$+133132>>2]=Q;Q=c[2438818]|0;c[$+2080>>2]=Q;c[$+67616>>2]=Q;c[$+133152>>2]=Q;L=Q+1024|0;c[$+2084>>2]=L;c[$+67620>>2]=L;c[$+133156>>2]=L;L=Q+2048|0;c[$+2088>>2]=L;c[$+67624>>2]=L;c[$+133160>>2]=L;L=Q+3072|0;c[$+2092>>2]=L;c[$+67628>>2]=L;c[$+133164>>2]=L;L=c[2437772]|0;c[$+3072>>2]=L;c[$+134144>>2]=L;Q=L+1024|0;c[$+3076>>2]=Q;c[$+134148>>2]=Q;Q=L+2048|0;c[$+3080>>2]=Q;c[$+134152>>2]=Q;Q=L+3072|0;c[$+3084>>2]=Q;c[$+134156>>2]=Q;Q=L+4096|0;c[$+3088>>2]=Q;c[$+134160>>2]=Q;Q=L+5120|0;c[$+3092>>2]=Q;c[$+134164>>2]=Q;Q=L+6144|0;c[$+3096>>2]=Q;c[$+134168>>2]=Q;Q=L+7168|0;c[$+3100>>2]=Q;c[$+134172>>2]=Q;Q=c[2443410]|0;c[$+3104>>2]=Q;c[$+68640>>2]=Q;c[$+134176>>2]=Q;L=Q+1024|0;c[$+3108>>2]=L;c[$+68644>>2]=L;c[$+134180>>2]=L;L=Q+2048|0;c[$+3112>>2]=L;c[$+68648>>2]=L;c[$+134184>>2]=L;L=Q+3072|0;c[$+3116>>2]=L;c[$+68652>>2]=L;c[$+134188>>2]=L;L=Q+4096|0;c[$+3120>>2]=L;c[$+68656>>2]=L;c[$+134192>>2]=L;L=Q+5120|0;c[$+3124>>2]=L;c[$+68660>>2]=L;c[$+134196>>2]=L;L=Q+6144|0;c[$+3128>>2]=L;c[$+68664>>2]=L;c[$+134200>>2]=L;L=Q+7168|0;c[$+3132>>2]=L;c[$+68668>>2]=L;c[$+134204>>2]=L;L=c[2388046]|0;c[$+7168>>2]=L;c[$+72704>>2]=L;c[$+138240>>2]=L;Q=L+1024|0;c[$+7172>>2]=Q;c[$+72708>>2]=Q;c[$+138244>>2]=Q;Q=L+2048|0;c[$+7176>>2]=Q;c[$+72712>>2]=Q;c[$+138248>>2]=Q;Q=L+3072|0;c[$+7180>>2]=Q;c[$+72716>>2]=Q;c[$+138252>>2]=Q;Q=L+4096|0;c[$+7184>>2]=Q;c[$+72720>>2]=Q;c[$+138256>>2]=Q;Q=L+5120|0;c[$+7188>>2]=Q;c[$+72724>>2]=Q;c[$+138260>>2]=Q;Q=L+6144|0;c[$+7192>>2]=Q;c[$+72728>>2]=Q;c[$+138264>>2]=Q;Q=L+7168|0;c[$+7196>>2]=Q;c[$+72732>>2]=Q;c[$+138268>>2]=Q;Q=L+8192|0;c[$+7200>>2]=Q;c[$+72736>>2]=Q;c[$+138272>>2]=Q;Q=L+9216|0;c[$+7204>>2]=Q;c[$+72740>>2]=Q;c[$+138276>>2]=Q;Q=L+10240|0;c[$+7208>>2]=Q;c[$+72744>>2]=Q;c[$+138280>>2]=Q;Q=L+11264|0;c[$+7212>>2]=Q;c[$+72748>>2]=Q;c[$+138284>>2]=Q;Q=L+12288|0;c[$+7216>>2]=Q;c[$+72752>>2]=Q;c[$+138288>>2]=Q;Q=L+13312|0;c[$+7220>>2]=Q;c[$+72756>>2]=Q;c[$+138292>>2]=Q;Q=L+14336|0;c[$+7224>>2]=Q;c[$+72760>>2]=Q;c[$+138296>>2]=Q;Q=L+15360|0;c[$+7228>>2]=Q;c[$+72764>>2]=Q;c[$+138300>>2]=Q;c[$+196688>>2]=2806;c[$+196728>>2]=396;c[$+196608>>2]=2936;c[$+196648>>2]=2302;Q=c[3532592]|0;if((Q|0)!=0){gGC(Q|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);Q=c[2439330]|0;L=(Q|0)==0;if(!L){H=Q;gGC(9706056,H|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];H=c[3528484]|0;c[2076596]=H;P=c[2417276]|0;c[3541536]=P;c[1836236]=0;c[Q+4180>>2]=774;c[Q+4184>>2]=188;R=c[2385832]|0;V=0;S=0;while(1){c[Q+76+(S<<2)>>2]=R+(S<<8);U=V+1&65535;if((U&65535)>191){aa=0;ab=0;break}else{V=U;S=U&65535}}while(1){S=R+(ab<<8)|0;c[Q+76+(ab+512<<2)>>2]=S;c[Q+76+(ab+768<<2)>>2]=S;S=aa+1&65535;if((S&65535)>191){break}else{aa=S;ab=S&65535}}R=c[2385850]|0;c[Q+844>>2]=R;S=R+256|0;c[Q+848>>2]=S;V=R+512|0;c[Q+852>>2]=V;U=R+768|0;c[Q+856>>2]=U;X=R+1024|0;c[Q+860>>2]=X;W=R+1280|0;c[Q+864>>2]=W;T=R+1536|0;c[Q+868>>2]=T;Y=R+1792|0;c[Q+872>>2]=Y;c[Q+1868>>2]=R;c[Q+1872>>2]=S;c[Q+1876>>2]=V;c[Q+1880>>2]=U;c[Q+1884>>2]=X;c[Q+1888>>2]=W;c[Q+1892>>2]=T;c[Q+1896>>2]=Y;c[Q+2892>>2]=R;c[Q+3916>>2]=R;c[Q+2896>>2]=S;c[Q+3920>>2]=S;c[Q+2900>>2]=V;c[Q+3924>>2]=V;c[Q+2904>>2]=U;c[Q+3928>>2]=U;c[Q+2908>>2]=X;c[Q+3932>>2]=X;c[Q+2912>>2]=W;c[Q+3936>>2]=W;c[Q+2916>>2]=T;c[Q+3940>>2]=T;c[Q+2920>>2]=Y;c[Q+3944>>2]=Y;if(!L){Y=Q;gGC(Y|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=H;c[2417276]=P;c[1836236]=-1;Y=a[9680]|0;T=Y?32e3:0;if(Y){if(a[9624]|0){Y=T*3|0;W=55930;while(1){if((W|0)>(Y|0)){W=W>>1}else{ac=1222;ad=W;break}}}else{ac=2462;ad=T}c[2429380]=ad;c[3542124]=ac;mw(3579545,ad);W=gGq(262144)|0;c[2406684]=W;gGz(W|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(3579545,11025)}c[(c[3531464]|0)+44344>>2]=164;h[745421]=.45;c[2436794]=3;h[745420]=.45;c[2436792]=3;Ux(0,7759,1);c[2407030]=230;c[2407068]=3;a[1950784]=0;a[6346624]=0;a[6346616]=0;a[6346608]=0;W=c[642608+(c[2436]<<2)>>2]|0;if((fa(c[W>>2]|0,95552)|0)==0){a[1950784]=1;a[6346624]=1;a[6346616]=1;a[6346608]=1}Y=c[W+128>>2]|0;if((c[W+52>>2]&4|0)==0){c[2113068]=Y;P=c[W+132>>2]|0;c[2113070]=P;c[2443814]=Y;c[2440436]=P;ae=Y;af=P}else{c[2113070]=Y;P=c[W+132>>2]|0;c[2113068]=P;c[2440436]=Y;c[2443814]=P;ae=P;af=Y}Y=ag(ae<<1,af)|0;P=gGq(Y)|0;c[2112926]=P;if((P|0)!=0){gGz(P|0,0,Y|0)}if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];Y=c[3532592]|0;if((Y|0)!=0){gGC(9104152,Y|0,280)|0}c[2113054]=c[2113060]}RI();Y=c[2394]|0;P=c[14130368+(Y<<2)>>2]|0;if((P|0)!=0){gGC(P|0,9104152,280)|0}c[8452240+(Y<<2)>>2]=c[2113054];c[2394]=-1;Y=c[2439330]|0;P=(Y|0)==0;if(!P){W=Y;gGC(9706056,W|0,76)|0}W=c[2438118]|0;c[2433530]=W;H=c[3528484]|0;c[2076596]=H;Q=c[2417276]|0;c[3541536]=Q;c[1836236]=0;gGz(9706056,0,76);if(!P){P=Y;gGC(P|0,9706056,76)|0}c[2438118]=W;c[3528484]=H;c[2417276]=Q;c[1836236]=-1;mx(0);c[2113156]=0;a[9628264]=0;c[2407033]=0;Q=c[3541206]|0;c[3541190]=Q;c[3541198]=Q;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=Q+256;c[3541199]=Q+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=Q+512;c[3541200]=Q+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=Q+768;c[3541201]=Q+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;a[9545144]=0;b[4879968]=0;b[4879964]=0;b[4879960]=0;b[4879956]=0;b[4814248]=0;a[14120992]=0;a[9758160]=0;O=0;i=e;return O|0}}while(0);c[2426706]=0;O=1;i=e;return O|0}function eg3(){var d=0,e=0,f=0,g=0,h=0;if((c[2392]|0)>=0){d=0;do{e=14130368+(d<<2)|0;f=c[e>>2]|0;if((f|0)!=0){gGr(f);c[e>>2]=0}e=14130384+(d<<2)|0;f=c[e>>2]|0;if((f|0)!=0){gGr(f);c[e>>2]=0}d=d+1|0;}while((d|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;fwZ();d=c[3531464]|0;c[d+44344>>2]=0;c[d+44348>>2]=0;if((d|0)!=0){gGr(d);c[3531464]=0}d=c[2406684]|0;if((d|0)!=0){gGr(d);c[2406684]=0}Uw(0);c[2113070]=0;c[2113068]=0;d=c[2112926]|0;if((d|0)!=0){gGr(d);c[2112926]=0}a[9545144]=0;b[4879968]=0;b[4879964]=0;b[4879960]=0;b[4879956]=0;b[4814248]=0;a[14120992]=0;a[9758160]=0;a[1950784]=0;a[6346624]=0;a[6346616]=0;a[6346608]=0;d=c[2426706]|0;e=0;while(1){if((e|0)>=1024){g=57852;break}h=9638528+(e<<2)|0;if((c[h>>2]|0)==(d|0)){break}else{e=e+1|0}}if((g|0)==57852){c[2426706]=0;return 0}gGr(d);c[h>>2]=0;c[2426706]=0;return 0}function eg4(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;if((a[9624048]|0)!=0){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;h=c[2417276]|0;c[3541536]=h;c[1836236]=0;gGz(9706056,0,76);if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=h;c[1836236]=-1;mx(0);c[2113156]=0;a[9628264]=0;c[2407033]=0;h=c[3541206]|0;c[3541190]=h;c[3541198]=h;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=h+256;c[3541199]=h+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=h+512;c[3541200]=h+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=h+768;c[3541201]=h+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;a[9545144]=0;b[4879968]=0;b[4879964]=0;b[4879960]=0;b[4879956]=0;b[4814248]=0;a[14120992]=0;a[9758160]=0}gGz(9625648,0,5);h=0;g=0;f=0;e=0;d=0;i=0;do{g=((a[9759168+h|0]&1)<<h|g&255)&255;f=((a[9758976+h|0]&1)<<h|f&255)&255;e=((a[9758792+h|0]&1)<<h|e&255)&255;d=((a[9758728+h|0]&1)<<h|d&255)&255;i=((a[9758696+h|0]&1)<<h|i&255)&255;h=h+1|0;}while((h|0)<8);a[9625648]=g;a[9625649]=f;a[9625650]=e;a[9625651]=d;a[9625652]=i;if((g&3)==3){i=g&-4;a[9625648]=i;j=i}else{j=g}if((j&12)==12){a[9625648]=j&-13}if((f&3)==3){j=f&-4;a[9625649]=j;k=j}else{k=f}if((k&12)==12){a[9625649]=k&-13}if((e&3)==3){k=e&-4;a[9625650]=k;l=k}else{l=e}if((l&12)==12){a[9625650]=l&-13}if((d&3)==3){l=d&-4;a[9625651]=l;m=l}else{m=d}if((m&12)==12){a[9625651]=m&-13}a[6518208]=1;a[6517976]=1;c[2444077]=0;c[2444076]=0;m=c[2392]|0;if((m|0)>=0){gGz(8452240,0,((m|0)>0?(m<<2)+4|0:4)|0)}c[2113054]=0;m=c[2385548]|0;if((m|0)>0){gGz(9752472,0,((m|0)>1?m<<2:4)|0)}c[2433530]=0;a[9545144]=0;m=0;d=0;L76812:while(1){l=d;while(1){e=(l|0)<10;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];k=c[3532592]|0;if((k|0)!=0){gGC(9104152,k|0,280)|0}c[2113054]=c[2113060]}if(!e){break L76812}n=l+1|0;e=(ag(a[6518208]|0?2e5:0,n)|0)/10|0;k=e-(c[2444076]|0)|0;c[2438184]=k;c[2113056]=k;e=RG(k)|0;c[2113054]=(c[2113054]|0)+e;c[2276108]=-1;c[2113056]=-1;c[2444076]=(c[2444076]|0)+e;if((l|0)==5){c[8452200+(c[2394]<<2)>>2]=8194;c[2276080]=512;if((c[2276079]|0)>>>0<512){RH(2)}a[9545144]=1}e=c[2394]|0;k=c[14130368+(e<<2)>>2]|0;if((k|0)!=0){gGC(k|0,9104152,280)|0}c[8452240+(e<<2)>>2]=c[2113054];c[2394]=-1;e=c[2439330]|0;if((e|0)!=0){k=e;gGC(9706056,k|0,76)|0}b[4853030]=c[2426515]&65535;k=c[2438118]|0;c[2433530]=k;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;f=(ag(a[6517976]|0?59659:0,n)|0)/10|0;j=c[2444077]|0;g=f-j|0;c[2438184]=g;do{if((g|0)<1){o=0;p=j;q=0;r=e;s=k}else{if((a[e+4188|0]|0)==0){f=gfc(g)|0;i=(c[2433530]|0)+f|0;c[2433530]=i;h=c[1836236]|0;o=f;p=c[2444077]|0;q=h;r=c[9757320+(h<<2)>>2]|0;s=i;break}else{i=k+g|0;c[2433530]=i;o=g;p=j;q=0;r=e;s=i;break}}}while(0);c[2438184]=o;c[2444077]=p+o;if((r|0)!=0){e=r;gGC(e|0,9706056,76)|0}c[9752472+(q<<2)>>2]=s;c[14113936+(q<<2)>>2]=c[2076596];c[9669104+(q<<2)>>2]=c[3541536];c[1836236]=-1;t=c[2112964]|0;if((t|0)==0){l=n}else{break}}l=a[9688]|0?53:0;e=t+(m<<1<<1)|0;j=c[2439330]|0;if((j|0)!=0){g=j;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;gg[c[3542124]&4095](e,l);g=c[1836236]|0;j=c[9757320+(g<<2)>>2]|0;if((j|0)!=0){k=j;gGC(k|0,9706056,76)|0}c[9752472+(g<<2)>>2]=c[2433530];c[14113936+(g<<2)>>2]=c[2076596];c[9669104+(g<<2)>>2]=c[3541536];c[1836236]=-1;Uu(0,e,l);m=l+m|0;d=n}c[2113050]=8195;c[2276080]=768;if((c[2276079]|0)>>>0<768){RH(3);u=c[2394]|0}else{u=0}n=c[14130368+(u<<2)>>2]|0;if((n|0)!=0){gGC(n|0,9104152,280)|0}c[8452240+(u<<2)>>2]=c[2113054];c[2394]=-1;u=c[2112964]|0;do{if((u|0)!=0){n=a[9688]|0?534:0;d=n-m|0;t=u+(m<<1<<1)|0;if((n|0)==(m|0)){break}n=c[2439330]|0;if((n|0)!=0){q=n;gGC(9706056,q|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;gg[c[3542124]&4095](t,d);q=c[1836236]|0;n=c[9757320+(q<<2)>>2]|0;if((n|0)!=0){s=n;gGC(s|0,9706056,76)|0}c[9752472+(q<<2)>>2]=c[2433530];c[14113936+(q<<2)>>2]=c[2076596];c[9669104+(q<<2)>>2]=c[3541536];c[1836236]=-1;Uu(0,t,d)}}while(0);if((c[2112968]|0)==0){v=c[2433440]|0;w=c[2443410]|0;gGC(v|0,w|0,8192)|0;return 0}m=c[2112926]|0;gGz(m|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);m=c[3529986]|0;u=0;d=c[2439610]|0;t=m;while(1){q=b[d>>1]|0;s=q&255;n=(q&65535)>>>4;r=(q&65535)>>>8;c[t>>2]=((r<<4&255|r&8)&255)>>>3|((s<<4|s&8)&255)<<8&63488|((n<<4&255|n&12)&255)<<3&2016;n=u+1|0;if((n|0)<8192){u=n;d=d+2|0;t=t+4|0}else{break}}t=b[4814248]|0;if(t<<16>>16==123){ehe(1);ehf(0);ehg();ehh();x=b[4814248]|0}else{x=t}if(x<<16>>16==124){ehe(1);ehg();ehf(0);ehh();y=b[4814248]|0}else{y=x}if(y<<16>>16==120){ehf(1);ehe(0);ehg();ehh()}R8(m);v=c[2433440]|0;w=c[2443410]|0;gGC(v|0,w|0,8192)|0;return 0}function eg5(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;f=i;i=i+288|0;g=f|0;h=f+16|0;j=f+32|0;k=f+48|0;l=f+64|0;m=f+80|0;n=f+96|0;o=f+112|0;p=f+128|0;q=f+144|0;r=f+160|0;s=f+176|0;t=f+192|0;u=f+208|0;v=f+224|0;w=f+240|0;x=f+256|0;y=f+272|0;if((e|0)!=0){c[e>>2]=169588}if((b&32|0)!=0){gGz(y|0,0,12);e=c[2405640]|0;c[y>>2]=e;c[y+4>>2]=(c[2411628]|0)-e;c[y+12>>2]=162152;e=c[2076592]|0;gj[e&4095](y)|0}if((b&64|0)==0){z=b&2}else{y=l|0;gGz(k|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){e=l+9|0;l=j;A=j|0;B=j+4|0;C=j+12|0;D=k|0;E=k+4|0;F=k+12|0;G=0;do{gGC(y|0,614896,11)|0;a[e]=G+48&255;H=8452256+(G<<2)|0;gGz(l|0,0,12);c[A>>2]=H;c[B>>2]=4;c[C>>2]=164976;gj[c[2076592]&4095](j)|0;if((c[H>>2]|0)!=0){c[D>>2]=c[14130368+(G<<2)>>2];c[E>>2]=c[8452184+(G<<2)>>2];c[F>>2]=y;H=c[2076592]|0;gj[H&4095](k)|0}G=G+1|0;}while((G|0)<=(c[2392]|0))}fw$(b);gGz(h|0,0,12);c[h>>2]=8453216;c[h+4>>2]=4;c[h+12>>2]=107480;G=c[2076592]|0;gj[G&4095](h)|0;gGz(g|0,0,12);c[g>>2]=14168504;c[g+4>>2]=256;c[g+12>>2]=476464;h=c[2076592]|0;gj[h&4095](g)|0;g=b&2;if((g|0)!=0){b=0;do{mv(0,b,d[14168504+b|0]|0);b=b+1|0;}while((b|0)<256)}Ut(0);gGz(x|0,0,12);c[x>>2]=9776304;c[x+4>>2]=8;c[x+12>>2]=212472;b=c[2076592]|0;gj[b&4095](x)|0;gGz(w|0,0,12);c[w>>2]=9752736;c[w+4>>2]=4;c[w+12>>2]=436576;x=c[2076592]|0;gj[x&4095](w)|0;gGz(v|0,0,12);c[v>>2]=9657936;c[v+4>>2]=2;c[v+12>>2]=483352;w=c[2076592]|0;gj[w&4095](v)|0;gGz(u|0,0,12);c[u>>2]=9625648;c[u+4>>2]=5;c[u+12>>2]=215728;v=c[2076592]|0;gj[v&4095](u)|0;gGz(t|0,0,12);c[t>>2]=9545144;c[t+4>>2]=1;c[t+12>>2]=449152;u=c[2076592]|0;gj[u&4095](t)|0;gGz(s|0,0,12);c[s>>2]=14120992;c[s+4>>2]=1;c[s+12>>2]=491248;t=c[2076592]|0;gj[t&4095](s)|0;gGz(r|0,0,12);c[r>>2]=9758160;c[r+4>>2]=1;c[r+12>>2]=497064;s=c[2076592]|0;gj[s&4095](r)|0;gGz(q|0,0,12);c[q>>2]=9759936;c[q+4>>2]=2;c[q+12>>2]=414504;r=c[2076592]|0;gj[r&4095](q)|0;gGz(p|0,0,12);c[p>>2]=9759928;c[p+4>>2]=2;c[p+12>>2]=403560;q=c[2076592]|0;gj[q&4095](p)|0;gGz(o|0,0,12);c[o>>2]=9759920;c[o+4>>2]=2;c[o+12>>2]=392416;p=c[2076592]|0;gj[p&4095](o)|0;gGz(n|0,0,12);c[n>>2]=9759912;c[n+4>>2]=2;c[n+12>>2]=380984;o=c[2076592]|0;gj[o&4095](n)|0;gGz(m|0,0,12);c[m>>2]=9628496;c[m+4>>2]=2;c[m+12>>2]=371048;n=c[2076592]|0;gj[n&4095](m)|0;z=g}if((z|0)==0){i=f;return 0}z=c[3541206]|0;g=(c[2433466]|0)+((d[14120992]|0)<<18)|0;gGC(z|0,g|0,262144)|0;i=f;return 0}function eg6(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7294212+(b*112|0)>>2];c[a+104>>2]=c[7294216+(b*112|0)>>2];c[a+108>>2]=c[7294220+(b*112|0)>>2];d=0;return d|0}function eg7(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=7294112+(b*112|0);e=0;return e|0}function eg8(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7272172+(b*112|0)>>2];c[a+104>>2]=c[7272176+(b*112|0)>>2];c[a+108>>2]=c[7272180+(b*112|0)>>2];d=0;return d|0}function eg9(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=7272072+(b*112|0);e=0;return e|0}function eha(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7250244+(b*112|0)>>2];c[a+104>>2]=c[7250248+(b*112|0)>>2];c[a+108>>2]=c[7250252+(b*112|0)>>2];d=0;return d|0}function ehb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=7250144+(b*112|0);e=0;return e|0}function ehc(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7248564+(b*112|0)>>2];c[a+104>>2]=c[7248568+(b*112|0)>>2];c[a+108>>2]=c[7248572+(b*112|0)>>2];d=0;return d|0}function ehd(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=7248464+(b*112|0);e=0;return e|0}function ehe(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=c[2438820]|0;if((b[4814248]|0)==120){g=9759928;h=(a[6346624]|0?-4:0)+(e[4879968]|0)|0}else{g=9759912;h=(a[6346624]|0?-4:0)+(e[4879960]|0)|0}i=e[g>>1]|0;g=(d|0)==0;d=c[2112926]|0;j=c[2405808]|0;k=0;l=0;while(1){m=(l<<4)-i|0;n=(m|0)<-16?m+512|0:m;m=n-8|0;o=(n-25|0)>>>0>206;n=k;p=0;while(1){q=n<<1;r=b[f+((q|1)<<1)>>1]&4095;s=e[f+(q<<1)>>1]|0;q=s&15;t=(p<<4)-h|0;u=(t|0)<-16?t+512|0:t;t=(u-17|0)>>>0>286|o;v=(s&64|0)==0;w=(s&128|0)!=0;do{if(g){if(t){if(v){if(w){SL(d,r,u,m,q,4,0,4096,j);break}else{SH(d,r,u,m,q,4,0,4096,j);break}}else{if(w){SN(d,r,u,m,q,4,0,4096,j);break}else{SJ(d,r,u,m,q,4,0,4096,j);break}}}else{if(v){if(w){SK(d,r,u,m,q,4,0,4096,j);break}else{SG(d,r,u,m,q,4,0,4096,j);break}}else{if(w){SM(d,r,u,m,q,4,0,4096,j);break}else{SI(d,r,u,m,q,4,0,4096,j);break}}}}else{if(t){if(v){if(w){SD(d,r,u,m,q,4,4096,j);break}else{Sz(d,r,u,m,q,4,4096,j);break}}else{if(w){SF(d,r,u,m,q,4,4096,j);break}else{SB(d,r,u,m,q,4,4096,j);break}}}else{if(v){if(w){SC(d,r,u,m,q,4,4096,j);break}else{Sy(d,r,u,m,q,4,4096,j);break}}else{if(w){SE(d,r,u,m,q,4,4096,j);break}else{SA(d,r,u,m,q,4,4096,j);break}}}}}while(0);q=p+1|0;if((q|0)<32){n=n+1|0;p=q}else{break}}p=l+1|0;if((p|0)<32){k=k+32|0;l=p}else{break}}return}function ehf(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=c[2438818]|0;if((b[4814248]|0)==120){g=9759912;h=(a[6346616]|0?-4:0)+(e[4879960]|0)|0}else{g=9759928;h=(a[6346608]|0?-2:0)+(e[4879968]|0)|0}i=e[g>>1]|0;g=(d|0)==0;d=c[2112926]|0;j=c[2405808]|0;k=0;l=0;while(1){m=(l<<4)-i|0;n=(m|0)<-16?m+512|0:m;m=n-8|0;o=(n-9|0)>>>0<223;L77027:do{if(g){n=o^1;p=k;q=0;while(1){r=e[f+(p<<1)>>1]|0;s=r&4095;t=r>>>12;r=(q<<4)-h|0;u=(r|0)<-16?r+512|0:r;if((u-1|0)>>>0>302|n){SH(d,s,u,m,t,4,0,3072,j)}else{SG(d,s,u,m,t,4,0,3072,j)}t=q+1|0;if((t|0)<32){p=p+1|0;q=t}else{break}}}else{if(o){v=k;w=0}else{q=k;p=0;while(1){n=e[f+(q<<1)>>1]|0;t=(p<<4)-h|0;Sz(d,n&4095,(t|0)<-16?t+512|0:t,m,n>>>12,4,3072,j);n=p+1|0;if((n|0)<32){q=q+1|0;p=n}else{break L77027}}}while(1){p=e[f+(v<<1)>>1]|0;q=p&4095;n=p>>>12;p=(w<<4)-h|0;t=(p|0)<-16?p+512|0:p;if((t-1|0)>>>0<303){Sy(d,q,t,m,n,4,3072,j)}else{Sz(d,q,t,m,n,4,3072,j)}n=w+1|0;if((n|0)<32){v=v+1|0;w=n}else{break}}}}while(0);m=l+1|0;if((m|0)<32){k=k+32|0;l=m}else{break}}return}function ehg(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=c[2433440]|0;f=d+8192|0;g=a[1950784]|0?2:0;h=c[2112926]|0;i=c[3529570]|0;j=d;do{d=e[j+2>>1]|0;if((d&1|0)!=0){k=b[j+10>>1]&255|d<<6&256;l=(k>>>0>496?k|-512:k)+g|0;k=(256-(b[j>>1]&255|d<<7&256)&511)-24|0;m=d>>>5&7;n=m+1|0;o=(e[j+6>>1]|0)<<8&65280|b[j+4>>1]&255;p=b[j+8>>1]&15;q=(d&8|0)!=0;r=k-(m<<4)|0;m=(d&16|0)==0;d=0;do{s=d<<4;t=q?r+s|0:k-s|0;s=d+o|0;do{if(m){if(q){SL(h,s,l,t,p,4,0,1024,i);break}else{SH(h,s,l,t,p,4,0,1024,i);break}}else{if(q){SN(h,s,l,t,p,4,0,1024,i);break}else{SJ(h,s,l,t,p,4,0,1024,i);break}}}while(0);d=d+1|0;}while((d|0)<(n|0))}j=j+16|0;}while(j>>>0<f>>>0);return}function ehh(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=c[2437772]|0;d=c[2112926]|0;f=c[2406518]|0;g=0;h=0;while(1){i=h<<3;j=i-8|0;k=(i-9|0)>>>0>230;i=g;l=0;while(1){m=i<<1;n=e[a+((m|1)<<1)>>1]|0;o=n<<8&3840|b[a+(m<<1)>>1]&255;m=n>>>4&15;n=l<<3;if((n-1|0)>>>0>310|k){Sr(d,o,n,j,m,4,0,0,f)}else{Sq(d,o,n,j,m,4,0,0,f)}m=l+1|0;if((m|0)<64){i=i+1|0;l=m}else{break}}l=h+1|0;if((l|0)<32){g=g+64|0;h=l}else{break}}return}function ehi(b){b=b|0;a[9706117]=(b|0)!=0|0;return}function ehj(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0;if((b&-2048)<<16>>16!=-32768){return}f=b&2047;b=c[2387178]|0;g=b+f|0;if((a[g]|0)==e<<24>>24){return}a[g]=e;e=d[b+(f&2046)|0]|0;g=e>>>4;h=f>>>1;i=e>>>3&1|d[b+(f|1)|0]<<8&2048|e<<4&16|(g<<4|g<<3)&224;c[(c[3529984]|0)+(h<<2)>>2]=i;if((i|0)!=0){return}c[3526946]=h;return}function ehk(e,f){e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=e&255;if((g|0)==7){a[c[2438302]|0]=f&1^1;return}else if((g|0)==19){a[c[3528260]|0]=f;e=c[1836236]|0;h=c[9757320+(e<<2)>>2]|0;if((h|0)!=0){i=h;gGC(i|0,9706056,76)|0}c[9752472+(e<<2)>>2]=c[2433530];c[14113936+(e<<2)>>2]=c[2076596];c[9669104+(e<<2)>>2]=c[3541536];c[1836236]=-1;e=c[2439331]|0;i=(e|0)==0;if(!i){h=e;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;h=c[2438119]|0;c[2433530]=h;j=c[3528485]|0;c[2076596]=j;k=c[2417277]|0;c[3541536]=k;c[1836236]=1;a[9706117]=1;if(!i){i=e;gGC(i|0,9706056,76)|0}c[2438119]=h;c[3528485]=j;c[2417277]=k;c[1836236]=-1;k=c[2439330]|0;if((k|0)!=0){j=k;gGC(9706056,j|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;return}else if((g|0)==18){j=(f&255)<9?f:9;k=c[2417268]|0;a[k]=j;h=c[3529238]|0;i=c[9757320+(c[1836236]<<2)>>2]|0;e=(c[614600+((j&255)<<2)>>2]|0)-49152|0;j=192;l=192;while(1){c[i+76+(l<<2)>>2]=h+(e+(l<<8));m=j+1&65535;if((m&65535)>255){break}else{j=m;l=m&65535}}l=(c[614600+((d[k]|0)<<2)>>2]|0)-49152|0;k=192;j=192;while(1){e=h+(l+(j<<8))|0;c[i+76+(j+512<<2)>>2]=e;c[i+76+(j+768<<2)>>2]=e;e=k+1&65535;if((e&65535)>255){break}else{k=e;j=e&65535}}return}else if((g|0)==23){g=f&1;f=(c[2417268]|0)+1|0;a[f]=g;j=c[2386206]|0;k=(g&255)<<12;g=c[9757320+(c[1836236]<<2)>>2]|0;c[g+652>>2]=j+k;c[g+656>>2]=j+(k|256);c[g+660>>2]=j+(k|512);c[g+664>>2]=j+(k|768);c[g+668>>2]=j+(k|1024);c[g+672>>2]=j+(k|1280);c[g+676>>2]=j+(k|1536);c[g+680>>2]=j+(k|1792);c[g+684>>2]=j+(k|2048);c[g+688>>2]=j+(k|2304);c[g+692>>2]=j+(k|2560);c[g+696>>2]=j+(k|2816);c[g+700>>2]=j+(k|3072);c[g+704>>2]=j+(k|3328);c[g+708>>2]=j+(k|3584);c[g+712>>2]=j+(k|3840);k=((d[f]|0)<<12)-36864|0;i=144;l=144;while(1){c[g+76+(l+256<<2)>>2]=j+(k+(l<<8));h=i+1&65535;if((h&65535)>159){break}else{i=h;l=h&65535}}l=((d[f]|0)<<12)-36864|0;f=144;i=144;while(1){k=j+(l+(i<<8))|0;c[g+76+(i+512<<2)>>2]=k;c[g+76+(i+768<<2)>>2]=k;k=f+1&65535;if((k&65535)>159){break}else{f=k;i=k&65535}}return}else{return}}function ehl(b){b=b|0;var c=0;switch(b&255|0){case 17:{c=a[9550417]|0;break};case 20:{c=a[9635017]|0;break};case 18:{c=a[9550418]|0;break};case 16:{c=a[9550416]|0;break};case 19:{c=a[9635016]|0;break};default:{c=0}}return c|0}function ehm(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;e=b&65535;if((e|0)==36864){b=d&3;a[(c[2417268]|0)+2|0]=b;f=c[2386636]|0;g=(b&255)<<18;b=f+g|0;c[3541206]=b;c[3541190]=b;c[3541198]=b;c[3541191]=f+(g|256);c[3541199]=f+(g|65536);c[3541192]=f+(g|512);c[3541200]=f+(g|131072);c[3541193]=f+(g|768);c[3541201]=f+(g|196608);return}else if((e|0)==38912){Uv(0,d);return}else{return}}function ehn(b){b=b|0;var d=0,e=0;d=b&65535;if((d|0)==38912){e=c[2113156]&255}else if((d|0)==40960){a[9706117]=0;e=a[c[3528260]|0]|0}else{e=0}return e|0}function eho(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2243940+(b*112|0)>>2];c[a+104>>2]=c[2243944+(b*112|0)>>2];c[a+108>>2]=c[2243948+(b*112|0)>>2];d=0;return d|0}function ehp(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=2243840+(b*112|0);e=0;return e|0}function ehq(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1188440+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function ehr(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>57){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3394088+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function ehs(){var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0;e=i;i=i+1080|0;f=e|0;g=e+112|0;h=e+120|0;j=e+232|0;k=e+240|0;l=e+352|0;m=e+360|0;n=e+472|0;o=e+480|0;p=e+592|0;q=e+600|0;r=e+712|0;s=e+720|0;t=e+832|0;u=e+840|0;v=e+952|0;w=e+960|0;x=e+1072|0;c[2414944]=0;c[3529238]=0;c[3529194]=589824;c[3530824]=655360;c[3530588]=1703936;c[2386636]=2228224;c[3529984]=3276800;c[2414648]=3280896;c[3529326]=3280896;c[3529286]=3289088;c[2386206]=3291136;c[2387178]=3299328;c[3531100]=3301376;c[3528260]=3303424;c[2438302]=3303425;c[2417268]=3303426;c[2411626]=3303429;y=0;while(1){if((y|0)>=1024){break}z=9638528+(y<<2)|0;if((c[z>>2]|0)==0){A=58166;break}else{y=y+1|0}}do{if((A|0)==58166){y=gGq(3303429)|0;c[z>>2]=y;if((y|0)==0){break}c[2414944]=y;gGz(y|0,0,3303429);c[3529238]=y;c[3529194]=y+589824;c[3530824]=y+655360;c[3530588]=y+1703936;c[2386636]=y+2228224;c[3529984]=y+3276800;B=y+3280896|0;c[2414648]=B;c[3529326]=B;c[3529286]=y+3289088;c[2386206]=y+3291136;c[2387178]=y+3299328;c[3531100]=y+3301376;c[3528260]=y+3303424;c[2438302]=y+3303425;c[2417268]=y+3303426;B=y+3303429|0;c[2411626]=B;c[2414166]=B;if((c[3542200]|0)==0){C=1;i=e;return C|0}B=w+108|0;c[B>>2]=0;D=w+100|0;c[D>>2]=0;E=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[E&16383](w,0)|0;do{if((c[B>>2]|0)!=0){E=c[D>>2]|0;c[x>>2]=9534384;F=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[F&16383](x,0,0)|0;if((E|0)<1){C=1;i=e;return C|0}if((gzL(y,0,0)|0)==0){break}else{C=1}i=e;return C|0}}while(0);y=c[3529238]|0;gGG(y+65536|0,y+32768|0,491520);y=c[3529194]|0;if((c[3542200]|0)==0){C=1;i=e;return C|0}D=u+108|0;c[D>>2]=0;B=u+100|0;c[B>>2]=0;E=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[E&16383](u,1)|0;do{if((c[D>>2]|0)!=0){E=c[B>>2]|0;c[v>>2]=9534384;F=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[F&16383](v,1,0)|0;if((E|0)<1){C=1;i=e;return C|0}if((gzL(y,0,1)|0)==0){break}else{C=1}i=e;return C|0}}while(0);y=c[3530824]|0;if((c[3542200]|0)==0){C=1;i=e;return C|0}B=s+108|0;c[B>>2]=0;D=s+100|0;c[D>>2]=0;E=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[E&16383](s,2)|0;do{if((c[B>>2]|0)!=0){E=c[D>>2]|0;c[t>>2]=9534384;F=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[F&16383](t,2,0)|0;if((E|0)<1){C=1;i=e;return C|0}if((gzL(y,0,2)|0)==0){break}else{C=1}i=e;return C|0}}while(0);y=c[2386636]|0;D=c[3530824]|0;gGC(y|0,D|0,131072)|0;B=y+262144|0;gGC(B|0,D|0,131072)|0;B=y+524288|0;gGC(B|0,D|0,131072)|0;B=y+786432|0;gGC(B|0,D|0,131072)|0;B=y+131072|0;gGC(B|0,D|0,131072)|0;B=y+393216|0;E=D+131072|0;gGC(B|0,E|0,131072)|0;E=y+655360|0;B=D+262144|0;gGC(E|0,B|0,131072)|0;B=y+917504|0;y=D+393216|0;gGC(B|0,y|0,131072)|0;if((c[3542200]|0)==0){C=1;i=e;return C|0}y=q+108|0;c[y>>2]=0;B=q+100|0;c[B>>2]=0;E=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[E&16383](q,3)|0;do{if((c[y>>2]|0)!=0){E=c[B>>2]|0;c[r>>2]=9534384;F=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[F&16383](r,3,0)|0;if((E|0)<1){C=1;i=e;return C|0}if((gzL(D,0,3)|0)==0){break}else{C=1}i=e;return C|0}}while(0);D=(c[3530824]|0)+131072|0;if((c[3542200]|0)==0){C=1;i=e;return C|0}B=o+108|0;c[B>>2]=0;y=o+100|0;c[y>>2]=0;E=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[E&16383](o,4)|0;do{if((c[B>>2]|0)!=0){E=c[y>>2]|0;c[p>>2]=9534384;F=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[F&16383](p,4,0)|0;if((E|0)<1){C=1;i=e;return C|0}if((gzL(D,0,4)|0)==0){break}else{C=1}i=e;return C|0}}while(0);D=(c[3530824]|0)+262144|0;if((c[3542200]|0)==0){C=1;i=e;return C|0}y=m+108|0;c[y>>2]=0;B=m+100|0;c[B>>2]=0;E=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[E&16383](m,5)|0;do{if((c[y>>2]|0)!=0){E=c[B>>2]|0;c[n>>2]=9534384;F=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[F&16383](n,5,0)|0;if((E|0)<1){C=1;i=e;return C|0}if((gzL(D,0,5)|0)==0){break}else{C=1}i=e;return C|0}}while(0);D=(c[3530824]|0)+393216|0;if((c[3542200]|0)==0){C=1;i=e;return C|0}B=k+108|0;c[B>>2]=0;y=k+100|0;c[y>>2]=0;E=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[E&16383](k,6)|0;do{if((c[B>>2]|0)!=0){E=c[y>>2]|0;c[l>>2]=9534384;F=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[F&16383](l,6,0)|0;if((E|0)<1){C=1;i=e;return C|0}if((gzL(D,0,6)|0)==0){break}else{C=1}i=e;return C|0}}while(0);D=c[3530588]|0;if((c[3542200]|0)==0){C=1;i=e;return C|0}y=h+108|0;c[y>>2]=0;B=h+100|0;c[B>>2]=0;E=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[E&16383](h,7)|0;do{if((c[y>>2]|0)!=0){E=c[B>>2]|0;c[j>>2]=9534384;F=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[F&16383](j,7,0)|0;if((E|0)<1){C=1;i=e;return C|0}if((gzL(D,0,7)|0)==0){break}else{C=1}i=e;return C|0}}while(0);D=(c[3530588]|0)+131072|0;if((c[3542200]|0)==0){C=1;i=e;return C|0}B=f+108|0;c[B>>2]=0;y=f+100|0;c[y>>2]=0;E=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[E&16383](f,8)|0;do{if((c[B>>2]|0)==0){G=0}else{E=c[y>>2]|0;c[g>>2]=9534384;F=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[F&16383](g,8,0)|0;if((E|0)<1){C=1;i=e;return C|0}if((gzL(D,0,8)|0)==0){G=0;break}else{C=1}i=e;return C|0}}while(0);while(1){if((G|0)>=1024){break}H=9638528+(G<<2)|0;if((c[H>>2]|0)==0){A=58206;break}else{G=G+1|0}}L77270:do{if((A|0)==58206){D=gGq(524288)|0;c[H>>2]=D;if((D|0)==0){break}gGz(D|0,0,524288);y=c[3530824]|0;B=0;while(1){a[D+B|0]=~a[y+B|0];E=B+1|0;if((E|0)<524288){B=E}else{I=0;break}}do{B=I<<6;gGz(y+B|0,0,64);E=0;do{F=1<<3-E;J=(c[611536+(E<<2)>>2]|0)+B|0;K=0;do{L=J+(c[609136+(K<<2)>>2]|0)|0;M=(K<<3)+B|0;N=0;do{O=L+(c[614800+(N<<2)>>2]|0)|0;if(((d[D+((O|0)/8|0)|0]|0)&128>>>((O&7)>>>0)|0)!=0){O=y+(M+N)|0;a[O]=(d[O]|0|F)&255}N=N+1|0;}while((N|0)<8);K=K+1|0;}while((K|0)<8);E=E+1|0;}while((E|0)<4);I=I+1|0;}while((I|0)<16384);y=c[3530588]|0;E=0;while(1){a[D+E|0]=~a[y+E|0];B=E+1|0;if((B|0)<262144){E=B}else{P=0;break}}while(1){E=P<<8;gGz(y+E|0,0,256);B=P<<9;K=0;do{F=1<<3-K;J=(c[611296+(K<<2)>>2]|0)+B|0;N=0;do{M=J+(c[608752+(N<<2)>>2]|0)|0;L=(N<<4)+E|0;O=0;do{Q=M+(c[609840+(O<<2)>>2]|0)|0;if(((d[D+((Q|0)/8|0)|0]|0)&128>>>((Q&7)>>>0)|0)!=0){Q=y+(L+O)|0;a[Q]=(d[Q]|0|F)&255}O=O+1|0;}while((O|0)<16);N=N+1|0;}while((N|0)<16);K=K+1|0;}while((K|0)<4);K=P+1|0;if((K|0)<2048){P=K}else{R=0;break}}while(1){if((R|0)>=1024){break L77270}S=9638528+(R<<2)|0;if((c[S>>2]|0)==(D|0)){break}else{R=R+1|0}}gGr(D);c[S>>2]=0}}while(0);fwR(0);y=c[2439330]|0;K=(y|0)==0;if(!K){E=y;gGC(9706056,E|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];E=c[3528484]|0;c[2076596]=E;B=c[2417276]|0;c[3541536]=B;c[1836236]=0;N=c[3529238]|0;F=0;J=0;while(1){c[y+76+(J<<2)>>2]=N+(J<<8);O=F+1&65535;if((O&65535)>127){T=0;U=0;break}else{F=O;J=O&65535}}while(1){J=N+(U<<8)|0;c[y+76+(U+512<<2)>>2]=J;c[y+76+(U+768<<2)>>2]=J;J=T+1&65535;if((J&65535)>127){break}else{T=J;U=J&65535}}N=c[2387178]|0;c[y+588>>2]=N;J=N+256|0;c[y+592>>2]=J;F=N+512|0;c[y+596>>2]=F;O=N+768|0;c[y+600>>2]=O;L=N+1024|0;c[y+604>>2]=L;M=N+1280|0;c[y+608>>2]=M;Q=N+1536|0;c[y+612>>2]=Q;V=N+1792|0;c[y+616>>2]=V;c[y+2636>>2]=N;c[y+3660>>2]=N;c[y+2640>>2]=J;c[y+3664>>2]=J;c[y+2644>>2]=F;c[y+3668>>2]=F;c[y+2648>>2]=O;c[y+3672>>2]=O;c[y+2652>>2]=L;c[y+3676>>2]=L;c[y+2656>>2]=M;c[y+3680>>2]=M;c[y+2660>>2]=Q;c[y+3684>>2]=Q;c[y+2664>>2]=V;c[y+3688>>2]=V;V=c[3531100]|0;c[y+620>>2]=V;Q=V+256|0;c[y+624>>2]=Q;M=V+512|0;c[y+628>>2]=M;L=V+768|0;c[y+632>>2]=L;O=V+1024|0;c[y+636>>2]=O;F=V+1280|0;c[y+640>>2]=F;J=V+1536|0;c[y+644>>2]=J;N=V+1792|0;c[y+648>>2]=N;c[y+1644>>2]=V;c[y+1648>>2]=Q;c[y+1652>>2]=M;c[y+1656>>2]=L;c[y+1660>>2]=O;c[y+1664>>2]=F;c[y+1668>>2]=J;c[y+1672>>2]=N;c[y+2668>>2]=V;c[y+3692>>2]=V;c[y+2672>>2]=Q;c[y+3696>>2]=Q;c[y+2676>>2]=M;c[y+3700>>2]=M;c[y+2680>>2]=L;c[y+3704>>2]=L;c[y+2684>>2]=O;c[y+3708>>2]=O;c[y+2688>>2]=F;c[y+3712>>2]=F;c[y+2692>>2]=J;c[y+3716>>2]=J;c[y+2696>>2]=N;c[y+3720>>2]=N;N=c[3529326]|0;J=160;F=160;while(1){c[y+76+(F<<2)>>2]=N+((F<<8)-40960);O=J+1&65535;if((O&65535)>191){W=160;X=160;break}else{J=O;F=O&65535}}while(1){c[y+76+(X+256<<2)>>2]=N+((X<<8)-40960);F=W+1&65535;if((F&65535)>191){Y=160;Z=160;break}else{W=F;X=F&65535}}while(1){F=N+((Z<<8)-40960)|0;c[y+76+(Z+512<<2)>>2]=F;c[y+76+(Z+768<<2)>>2]=F;F=Y+1&65535;if((F&65535)>191){break}else{Y=F;Z=F&65535}}c[y+4184>>2]=2152;c[y+4176>>2]=30;c[y+4172>>2]=1192;if(!K){N=y;gGC(N|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=E;c[2417276]=B;c[1836236]=-1;fwR(1);N=c[2439331]|0;F=(N|0)==0;if(!F){J=N;gGC(9706056,J|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];J=c[3528485]|0;c[2076596]=J;O=c[2417277]|0;c[3541536]=O;c[1836236]=1;L=c[3529194]|0;M=0;Q=0;while(1){c[N+76+(Q<<2)>>2]=L+(Q<<8);V=M+1&65535;if((V&65535)>127){_=0;$=0;break}else{M=V;Q=V&65535}}while(1){Q=L+($<<8)|0;c[N+76+($+512<<2)>>2]=Q;c[N+76+($+768<<2)>>2]=Q;Q=_+1&65535;if((Q&65535)>127){break}else{_=Q;$=Q&65535}}L=c[3529286]|0;c[N+588>>2]=L;Q=L+256|0;c[N+592>>2]=Q;M=L+512|0;c[N+596>>2]=M;B=L+768|0;c[N+600>>2]=B;E=L+1024|0;c[N+604>>2]=E;y=L+1280|0;c[N+608>>2]=y;K=L+1536|0;c[N+612>>2]=K;V=L+1792|0;c[N+616>>2]=V;c[N+1612>>2]=L;c[N+1616>>2]=Q;c[N+1620>>2]=M;c[N+1624>>2]=B;c[N+1628>>2]=E;c[N+1632>>2]=y;c[N+1636>>2]=K;c[N+1640>>2]=V;c[N+2636>>2]=L;c[N+3660>>2]=L;c[N+2640>>2]=Q;c[N+3664>>2]=Q;c[N+2644>>2]=M;c[N+3668>>2]=M;c[N+2648>>2]=B;c[N+3672>>2]=B;c[N+2652>>2]=E;c[N+3676>>2]=E;c[N+2656>>2]=y;c[N+3680>>2]=y;c[N+2660>>2]=K;c[N+3684>>2]=K;c[N+2664>>2]=V;c[N+3688>>2]=V;c[N+4184>>2]=1196;c[N+4180>>2]=1216;if(!F){V=N;gGC(V|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=J;c[2417277]=O;c[1836236]=-1;Ux(0,8500,0);c[2407030]=256;c[2407068]=3;V=c[2414648]|0;gGz(V|0,0,(c[2411626]|0)-V|0);V=c[2439330]|0;if((V|0)!=0){K=V;gGC(9706056,K|0,76)|0}c[2433530]=c[2438118];K=c[3528484]|0;c[2076596]=K;y=c[2417276]|0;c[3541536]=y;c[1836236]=0;gGz(9706056,0,76);E=c[2417268]|0;a[E]=0;B=c[3529238]|0;M=192;Q=192;while(1){c[V+76+(Q<<2)>>2]=B+((Q<<8)+147456);L=M+1&65535;if((L&65535)>255){break}else{M=L;Q=L&65535}}Q=(c[614600+((d[E]|0)<<2)>>2]|0)-49152|0;M=192;O=192;while(1){J=B+(Q+(O<<8))|0;c[V+76+(O+512<<2)>>2]=J;c[V+76+(O+768<<2)>>2]=J;J=M+1&65535;if((J&65535)>255){break}else{M=J;O=J&65535}}O=E+1|0;a[O]=0;M=c[2386206]|0;c[V+652>>2]=M;c[V+656>>2]=M+256;c[V+660>>2]=M+512;c[V+664>>2]=M+768;c[V+668>>2]=M+1024;c[V+672>>2]=M+1280;c[V+676>>2]=M+1536;c[V+680>>2]=M+1792;c[V+684>>2]=M+2048;c[V+688>>2]=M+2304;c[V+692>>2]=M+2560;c[V+696>>2]=M+2816;c[V+700>>2]=M+3072;c[V+704>>2]=M+3328;c[V+708>>2]=M+3584;c[V+712>>2]=M+3840;Q=((d[O]|0)<<12)-36864|0;B=144;J=144;while(1){c[V+76+(J+256<<2)>>2]=M+(Q+(J<<8));N=B+1&65535;if((N&65535)>159){break}else{B=N;J=N&65535}}J=((d[O]|0)<<12)-36864|0;B=144;Q=144;while(1){N=M+(J+(Q<<8))|0;c[V+76+(Q+512<<2)>>2]=N;c[V+76+(Q+768<<2)>>2]=N;N=B+1&65535;if((N&65535)>159){break}else{B=N;Q=N&65535}}Q=V;gGC(Q|0,9706056,76)|0;c[2438118]=c[2433530];c[3528484]=K;c[2417276]=y;c[1836236]=-1;Q=c[2439331]|0;B=(Q|0)==0;if(!B){J=Q;gGC(9706056,J|0,76)|0}J=c[2438119]|0;c[2433530]=J;M=c[3528485]|0;c[2076596]=M;O=c[2417277]|0;c[3541536]=O;c[1836236]=1;gGz(9706056,0,76);if(!B){B=Q;gGC(B|0,9706056,76)|0}c[2438119]=J;c[3528485]=M;c[2417277]=O;c[1836236]=-1;a[E+2|0]=1;O=c[2386636]|0;M=O+262144|0;c[3541206]=M;c[2113156]=0;a[9628264]=0;c[2407033]=0;c[3541190]=M;c[3541198]=M;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=O+262400;c[3541199]=O+327680;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=O+262656;c[3541200]=O+393216;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=O+262912;c[3541201]=O+458752;gGz(c[2430121]|0,0,16384);c[2407065]=4;O=c[642608+(c[2436]<<2)>>2]|0;M=c[O+128>>2]|0;if((c[O+52>>2]&4|0)==0){c[2113068]=M;J=c[O+132>>2]|0;c[2113070]=J;c[2443814]=M;c[2440436]=J;aa=M;ab=J}else{c[2113070]=M;J=c[O+132>>2]|0;c[2113068]=J;c[2440436]=M;c[2443814]=J;aa=J;ab=M}M=ag(aa<<1,ab)|0;J=gGq(M)|0;c[2112926]=J;if((J|0)==0){C=0;i=e;return C|0}gGz(J|0,0,M|0);C=0;i=e;return C|0}}while(0);c[2414944]=0;C=1;i=e;return C|0}function eht(){var a=0,b=0,d=0,e=0;c[2113070]=0;c[2113068]=0;a=c[2112926]|0;if((a|0)!=0){gGr(a);c[2112926]=0}fwZ();Uw(0);a=c[2414944]|0;b=0;while(1){if((b|0)>=1024){d=58308;break}e=9638528+(b<<2)|0;if((c[e>>2]|0)==(a|0)){break}else{b=b+1|0}}if((d|0)==58308){c[2414944]=0;c[3541206]=0;return 0}gGr(a);c[e>>2]=0;c[2414944]=0;c[3541206]=0;return 0}function ehu(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if((a[9624040]|0)!=0){e=c[2414648]|0;gGz(e|0,0,(c[2411626]|0)-e|0);e=c[2439330]|0;if((e|0)!=0){f=e;gGC(9706056,f|0,76)|0}c[2433530]=c[2438118];f=c[3528484]|0;c[2076596]=f;g=c[2417276]|0;c[3541536]=g;c[1836236]=0;gGz(9706056,0,76);h=c[2417268]|0;a[h]=0;i=c[3529238]|0;j=192;k=192;while(1){c[e+76+(k<<2)>>2]=i+((k<<8)+147456);l=j+1&65535;if((l&65535)>255){break}else{j=l;k=l&65535}}k=(c[614600+(d[h]<<2)>>2]|0)-49152|0;j=192;l=192;while(1){m=i+(k+(l<<8))|0;c[e+76+(l+512<<2)>>2]=m;c[e+76+(l+768<<2)>>2]=m;m=j+1&65535;if((m&65535)>255){break}else{j=m;l=m&65535}}l=h+1|0;a[l]=0;j=c[2386206]|0;c[e+652>>2]=j;c[e+656>>2]=j+256;c[e+660>>2]=j+512;c[e+664>>2]=j+768;c[e+668>>2]=j+1024;c[e+672>>2]=j+1280;c[e+676>>2]=j+1536;c[e+680>>2]=j+1792;c[e+684>>2]=j+2048;c[e+688>>2]=j+2304;c[e+692>>2]=j+2560;c[e+696>>2]=j+2816;c[e+700>>2]=j+3072;c[e+704>>2]=j+3328;c[e+708>>2]=j+3584;c[e+712>>2]=j+3840;k=(d[l]<<12)-36864|0;i=144;m=144;while(1){c[e+76+(m+256<<2)>>2]=j+(k+(m<<8));n=i+1&65535;if((n&65535)>159){break}else{i=n;m=n&65535}}m=(d[l]<<12)-36864|0;l=144;i=144;while(1){k=j+(m+(i<<8))|0;c[e+76+(i+512<<2)>>2]=k;c[e+76+(i+768<<2)>>2]=k;k=l+1&65535;if((k&65535)>159){break}else{l=k;i=k&65535}}i=e;gGC(i|0,9706056,76)|0;c[2438118]=c[2433530];c[3528484]=f;c[2417276]=g;c[1836236]=-1;g=c[2439331]|0;f=(g|0)==0;if(!f){i=g;gGC(9706056,i|0,76)|0}i=c[2438119]|0;c[2433530]=i;e=c[3528485]|0;c[2076596]=e;l=c[2417277]|0;c[3541536]=l;c[1836236]=1;gGz(9706056,0,76);if(!f){f=g;gGC(f|0,9706056,76)|0}c[2438119]=i;c[3528485]=e;c[2417277]=l;c[1836236]=-1;a[h+2|0]=1;h=c[2386636]|0;l=h+262144|0;c[3541206]=l;c[2113156]=0;a[9628264]=0;c[2407033]=0;c[3541190]=l;c[3541198]=l;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=h+262400;c[3541199]=h+327680;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=h+262656;c[3541200]=h+393216;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=h+262912;c[3541201]=h+458752;gGz(c[2430121]|0,0,16384);c[2407065]=4}gGz(9550416,-1|0,3);h=0;l=-1;e=-1;i=-1;do{l=(d[9633248+h|0]<<h^l&255)&255;e=(d[9631120+h|0]<<h^e&255)&255;i=(d[9629504+h|0]<<h^i&255)&255;h=h+1|0;}while((h|0)<8);a[9550416]=l;a[9550417]=e;a[9550418]=i;i=0;do{e=c[2439330]|0;if((e|0)!=0){l=e;gGC(9706056,l|0,76)|0}b[4853030]=c[2426515]&65535;l=c[2438118]|0;c[2433530]=l;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;if((a[e+4188|0]|0)==0){e=gfc(1e4)|0;o=(c[2433530]|0)+e|0}else{o=l+1e4|0}c[2433530]=o;if((i|0)==9){a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0}l=c[1836236]|0;e=c[9757320+(l<<2)>>2]|0;if((e|0)!=0){h=e;gGC(h|0,9706056,76)|0}c[9752472+(l<<2)>>2]=c[2433530];c[14113936+(l<<2)>>2]=c[2076596];c[9669104+(l<<2)>>2]=c[3541536];c[1836236]=-1;l=c[2439331]|0;if((l|0)!=0){h=l;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;h=c[2438119]|0;c[2433530]=h;c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;if((a[l+4188|0]|0)==0){e=gfc(1e4)|0;f=c[1836236]|0;p=(c[2433530]|0)+e|0;q=f;r=c[9757320+(f<<2)>>2]|0}else{p=h+1e4|0;q=1;r=l}c[2433530]=p;if((r|0)!=0){l=r;gGC(l|0,9706056,76)|0}c[9752472+(q<<2)>>2]=p;c[14113936+(q<<2)>>2]=c[2076596];c[9669104+(q<<2)>>2]=c[3541536];c[1836236]=-1;i=i+1|0;}while((i|0)<10);i=c[2112964]|0;if((i|0)!=0){Uu(0,i,a[9688]|0?534:0)}if((c[2112968]|0)==0){return 0}ehv()|0;return 0}function ehv(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if((a[9547376]|0)!=0){e=c[3529984]|0;f=c[2387178]|0;g=0;do{h=d[f+g|0]|0;i=h>>>4;j=(g|0)/2|0;k=h>>>3&1|d[f+(g|1)|0]<<8&2048|h<<4&16|(i<<4|i<<3)&224;c[e+(j<<2)>>2]=k;if((k|0)==0){c[3526946]=j}g=g+2|0;}while((g|0)<2048);a[9547376]=0}if((a[c[2438302]|0]|0)==0){g=ag(c[2113070]|0,c[2113068]|0)|0;if((g|0)<=0){l=c[3529984]|0;R8(l);return 0}e=c[3526946]&65535;f=c[2112926]|0;j=0;do{b[f+(j<<1)>>1]=e;j=j+1|0;}while((j|0)<(g|0));l=c[3529984]|0;R8(l);return 0}g=c[2113070]|0;j=c[2386206]|0;e=c[3531100]|0;f=c[2112926]|0;k=c[3530824]|0;i=c[2113068]|0;h=0;do{m=(((h|0)/32|0)<<3)+192&504;n=(h<<3)+248&248;do{if((m|0)<(i|0)&(n|0)<(g|0)){o=h<<1;p=d[j+o|0]<<8&16128|d[j+(o|1)|0];o=d[e+(h^1024)|0]|0;q=o&63;if((o&128|0)==0){Si(f,p,m,n,q,4,0,k);break}else{Sk(f,p,m,n,q,4,0,k);break}}}while(0);h=h+1|0;}while((h|0)<2048);h=c[3530588]|0;k=4096;while(1){e=a[j+(k|2)|0]|0;g=e&255;i=g<<3&1792|d[j+(k|1)|0];n=d[j+k|0]|g<<4&256;m=e<<24>>24==0;if(!((n|0)==0|m^1)){r=58377;break}if(!(m&(i|0)==0)){SH(f,i,440-n|0,(d[j+(k|3)|0]|0)-8|0,g&15,4,15,0,h)}g=k+4|0;if((g|0)<8192){k=g}else{r=58376;break}}if((r|0)==58377){l=c[3529984]|0;R8(l);return 0}else if((r|0)==58376){l=c[3529984]|0;R8(l);return 0}return 0}function ehw(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=i;i=i+16|0;h=g|0;if((f|0)!=0){c[f>>2]=169735}if((e&32|0)!=0){gGz(h|0,0,12);f=c[2414648]|0;c[h>>2]=f;c[h+4>>2]=(c[2411626]|0)-f;c[h+12>>2]=162152;f=c[2076592]|0;gj[f&4095](h)|0}if((e&64|0)!=0){fw$(e);Ut(0)}if((e&2|0)==0){i=g;return 0}e=c[2439330]|0;if((e|0)!=0){h=e;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];h=c[3528484]|0;c[2076596]=h;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;j=c[2417268]|0;k=a[j]|0;l=(k&255)<9?k:9;a[j]=l;k=c[3529238]|0;m=(c[614600+((l&255)<<2)>>2]|0)-49152|0;l=192;n=192;while(1){c[e+76+(n<<2)>>2]=k+(m+(n<<8));o=l+1&65535;if((o&65535)>255){break}else{l=o;n=o&65535}}n=(c[614600+((d[j]|0)<<2)>>2]|0)-49152|0;l=192;m=192;while(1){o=k+(n+(m<<8))|0;c[e+76+(m+512<<2)>>2]=o;c[e+76+(m+768<<2)>>2]=o;o=l+1&65535;if((o&65535)>255){break}else{l=o;m=o&65535}}m=j+1|0;l=a[m]&1;a[m]=l;n=c[2386206]|0;k=(l&255)<<12;c[e+652>>2]=n+k;c[e+656>>2]=n+(k|256);c[e+660>>2]=n+(k|512);c[e+664>>2]=n+(k|768);c[e+668>>2]=n+(k|1024);c[e+672>>2]=n+(k|1280);c[e+676>>2]=n+(k|1536);c[e+680>>2]=n+(k|1792);c[e+684>>2]=n+(k|2048);c[e+688>>2]=n+(k|2304);c[e+692>>2]=n+(k|2560);c[e+696>>2]=n+(k|2816);c[e+700>>2]=n+(k|3072);c[e+704>>2]=n+(k|3328);c[e+708>>2]=n+(k|3584);c[e+712>>2]=n+(k|3840);k=((d[m]|0)<<12)-36864|0;l=144;o=144;while(1){c[e+76+(o+256<<2)>>2]=n+(k+(o<<8));p=l+1&65535;if((p&65535)>159){break}else{l=p;o=p&65535}}o=((d[m]|0)<<12)-36864|0;m=144;l=144;while(1){k=n+(o+(l<<8))|0;c[e+76+(l+512<<2)>>2]=k;c[e+76+(l+768<<2)>>2]=k;k=m+1&65535;if((k&65535)>159){break}else{m=k;l=k&65535}}l=e;gGC(l|0,9706056,76)|0;c[2438118]=c[2433530];c[3528484]=h;c[2417276]=f;c[1836236]=-1;f=j+2|0;j=a[f]&3;a[f]=j;f=c[2386636]|0;h=(j&255)<<18;j=f+h|0;c[3541206]=j;c[3541190]=j;c[3541198]=j;c[3541191]=f+(h|256);c[3541199]=f+(h|65536);c[3541192]=f+(h|512);c[3541200]=f+(h|131072);c[3541193]=f+(h|768);c[3541201]=f+(h|196608);a[9547376]=1;i=g;return 0}function ehx(b){b=b|0;var d=0;switch(b|0){case 499715:{d=a[9549800]|0;break};case 499717:{d=a[9635008]|0;break};case 499714:{d=a[9549712]|0;break};case 499719:{d=c[2420364]&255;break};case 499716:{d=a[9635009]|0;break};case 499713:{d=a[9549968]|0;break};default:{d=0}}return d|0}function ehy(a){a=a|0;var b=0;if((a|0)==499716){b=(d[9635009]|0)<<8|(d[9635008]|0)}else if((a|0)==499714){b=(d[9549712]|0)<<8|(d[9549800]|0)}else if((a|0)==499712){b=d[9549968]|0}else{b=0}return b|0}function ehz(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;if((d&-8192|0)==491520){f=d&8191;g=c[2387176]|0;a[g+(f^1)|0]=e;h=f>>>1;f=b[g+(d&8190)>>1]|0;g=f&255;i=(f&65535)>>>8;j=(f&65535)>>>4;f=(g<<4|g&15)&255;g=(j<<4&255|j&15)&255;j=(i<<4&255|i&15)&255;c[(c[2406928]|0)+(h<<2)>>2]=j|f<<16|g<<8;c[(c[3529982]|0)+(h<<2)>>2]=j>>>3|f<<8&63488|g<<3&2016;return}if((d|0)==499726){a[14113032]=e;a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0;return}else if((d|0)==501762|(d|0)==501763){a[14113032]=e;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12;return}else if((d|0)==501764){d=e&255;switch(d&240|0){case 48:{c[2420364]=(c[(c[3528600]|0)+(c[2405088]<<2)>>2]|0)>>>12&15|64;return};case 80:{c[2420364]=(c[(c[3528600]|0)+(c[2405088]<<2)>>2]|0)>>>4&15|96;return};case 96:{c[2420364]=c[(c[3528600]|0)+(c[2405088]<<2)>>2]&15|112;return};case 64:{c[2420364]=(c[(c[3528600]|0)+(c[2405088]<<2)>>2]|0)>>>8&15|80;return};case 16:{c[2405088]=d<<4&240;c[2420364]=16;return};case 0:{c[2420364]=0;return};case 32:{e=c[2405088]|d&15;c[2405088]=e;d=c[(c[3528600]|0)+(e<<2)>>2]|0;if((d|0)==-2){c[3528600]=1521528;c[2444174]=1;k=c[1521528+(e<<2)>>2]|0}else{k=d}if((k|0)==-1){c[2405088]=0}c[2420364]=32;return};default:{return}}}else{return}}function ehA(a,d){a=a|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;if((a&-8192|0)==491520){e=a&8190;b[(c[2387176]|0)+e>>1]=d;f=e>>>1;e=d&255;g=(d&65535)>>>8;h=(d&65535)>>>4;i=(e<<4|e&15)&255;e=(h<<4&255|h&15)&255;h=(g<<4&255|g&15)&255;c[(c[2406928]|0)+(f<<2)>>2]=h|i<<16|e<<8;c[(c[3529982]|0)+(f<<2)>>2]=h>>>3|i<<8&63488|e<<3&2016;return}e=a&-2;if((e|0)==520198){c[3525088]=(d&65535)+252&1023;return}else if((e|0)==500484){c[3526954]=d&511;return}else if((e|0)==520196){c[3525080]=d&511;return}else if((e|0)==499972){c[2443682]=d&511;return}else if((e|0)==501768){c[3528692]=d&1;return}else if((e|0)==500236){c[3525088]=d&1023;return}else if((e|0)==520194){c[3526962]=(d&65535)+248&1023;return}else if((e|0)==500492){c[3526962]=d&1023;return}else if((e|0)==520192){c[3526954]=d&511;return}else if((e|0)==500228){c[3525080]=d&511;return}else if((e|0)==499980){c[2443684]=d&1023;return}else{return}}function ehB(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;switch(b&65535|0){case 63504:{b=c[3541518]|0;e=b+256|0;a[b+304|0]=d;f=d&255;if((d&255)<16){c[14168912+((c[2383582]|0)*252|0)>>2]=f&15}if((d-45&255)>=3){return}if((f|0)==45){g=b+312|0;h=a[g]|2;a[g]=h;i=h}else if((f|0)==47){a[b+312|0]=0;i=0}else if((f|0)==0){a[b+312|0]=2;i=2}else if((f|0)==46){f=b+312|0;h=a[f]|1;a[f]=h;i=h}else{i=a[b+312|0]|0}b=i&3;i=c[7461744+(b<<2)>>2]|0;lI(e,i,i,c[7461728+(b<<2)>>2]|0);return};case 63505:{lS(0,1,d);return};case 63521:{lS(1,1,d);return};case 63488:{Uv(0,d);return};case 63520:{b=c[3541518]|0;i=b+19280|0;a[b+19328|0]=d;e=d&255;if((d&255)<16){c[14168912+(((c[2383582]|0)+1|0)*252|0)>>2]=e&15}if((d-45&255)>=3){return}if((e|0)==46){d=b+19336|0;h=a[d]|1;a[d]=h;j=h}else if((e|0)==47){a[b+19336|0]=0;j=0}else if((e|0)==45){h=b+19336|0;d=a[h]|2;a[h]=d;j=d}else if((e|0)==0){a[b+19336|0]=2;j=2}else{j=a[b+19336|0]|0}b=j&3;j=c[7461744+(b<<2)>>2]|0;lI(i,j,j,c[7461728+(b<<2)>>2]|0);return};default:{return}}}function ehC(b){b=b|0;var d=0,e=0;d=b&65535;if((d|0)==63488){e=c[2113156]&255}else if((d|0)==64544){e=a[14113032]|0}else{e=0}return e|0}function ehD(b,d){b=b|0;d=d|0;var e=0;e=b&255;if((e|0)==128){Uv(0,d);return}else if((e|0)==1){b=c[2113304]|0;a[14168504+b|0]=d;mv(0,b,d&255);return}else if((e|0)==0){c[2113304]=d&255;return}else{return}}function ehE(b){b=b|0;var d=0,e=0;d=b&255;if((d|0)==1){e=c[(c[3531464]|0)+4240>>2]&255}else if((d|0)==192){e=a[14113032]|0}else if((d|0)==128){e=c[2113156]&255}else{e=0}return e|0}function ehF(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4398620+(b*112|0)>>2];c[a+104>>2]=c[4398624+(b*112|0)>>2];c[a+108>>2]=c[4398628+(b*112|0)>>2];d=0;return d|0}function ehG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=4398520+(b*112|0);e=0;return e|0}function ehH(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6925664+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function ehI(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>35){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6307512+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function ehJ(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0;e=i;i=i+840|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+728|0;c[2426704]=0;c[2388136]=0;c[2385912]=262144;c[3530822]=327680;c[3530586]=458752;c[3530422]=1507328;c[3530328]=2555904;c[2439924]=4653056;c[2439922]=4655104;c[2439920]=4659200;c[3541206]=4663296;c[3529982]=4925440;c[2414646]=4941824;c[2388264]=4941824;c[3529462]=4958208;c[3529428]=4962304;c[3529406]=4970496;c[2386438]=4978688;c[2387176]=4986880;c[2386066]=4995072;c[2406928]=4997120;c[2411624]=5013504;v=0;while(1){if((v|0)>=1024){break}w=9638528+(v<<2)|0;if((c[w>>2]|0)==0){x=58552;break}else{v=v+1|0}}do{if((x|0)==58552){v=gGq(5013504)|0;c[w>>2]=v;if((v|0)==0){break}c[2426704]=v;gGz(v|0,0,5013504);c[2388136]=v;y=v+262144|0;c[2385912]=y;z=v+327680|0;c[3530822]=z;A=v+458752|0;c[3530586]=A;B=v+1507328|0;c[3530422]=B;C=v+2555904|0;c[3530328]=C;c[2439924]=v+4653056;c[2439922]=v+4655104;c[2439920]=v+4659200;D=v+4663296|0;c[3541206]=D;c[3529982]=v+4925440;E=v+4941824|0;c[2414646]=E;c[2388264]=E;c[3529462]=v+4958208;c[3529428]=v+4962304;c[3529406]=v+4970496;c[2386438]=v+4978688;c[2387176]=v+4986880;c[2386066]=v+4995072;c[2406928]=v+4997120;E=v+5013504|0;c[2411624]=E;c[2414164]=E;L77685:do{if((gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](t,0,0)|0)==0){E=u+108|0;F=u+100|0;G=r+108|0;H=r+100|0;I=p+108|0;J=p+100|0;K=n+108|0;L=n+100|0;M=l+108|0;N=l+100|0;O=j+108|0;P=j+100|0;Q=f+108|0;R=f+100|0;S=v;T=y;U=z;V=A;W=B;X=C;Y=D;Z=0;L77687:while(1){gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](u,Z)|0;switch(c[E>>2]&7|0){case 2:{if((c[3542200]|0)==0){_=1;x=58741;break L77687}c[G>>2]=0;c[H>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,Z)|0;if((c[G>>2]|0)!=0){$=c[H>>2]|0;c[s>>2]=9534384;aa=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aa&16383](s,Z,0)|0;if(($|0)<1){_=1;x=58745;break L77687}if((gzL(T,0,Z)|0)!=0){_=1;x=58742;break L77687}}ab=Z;ac=Y;ad=X;ae=W;af=V;ah=U;ai=T+(c[F>>2]|0)|0;aj=S;break};case 3:{if((c[3542200]|0)==0){_=1;x=58746;break L77687}c[I>>2]=0;c[J>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,Z)|0;if((c[I>>2]|0)!=0){$=c[J>>2]|0;c[q>>2]=9534384;aa=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aa&16383](q,Z,0)|0;if(($|0)<1){_=1;x=58757;break L77687}if((gzL(U,0,Z)|0)!=0){_=1;x=58761;break L77687}}ab=Z;ac=Y;ad=X;ae=W;af=V;ah=U+(c[F>>2]|0)|0;ai=T;aj=S;break};case 7:{if((c[3542200]|0)==0){_=1;x=58749;break L77687}c[Q>>2]=0;c[R>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,Z)|0;if((c[Q>>2]|0)!=0){$=c[R>>2]|0;c[g>>2]=9534384;aa=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aa&16383](g,Z,0)|0;if(($|0)<1){_=1;x=58740;break L77687}if((gzL(Y,0,Z)|0)!=0){_=1;x=58737;break L77687}}ab=Z;ac=Y+(c[F>>2]|0)|0;ad=X;ae=W;af=V;ah=U;ai=T;aj=S;break};case 1:{if((R6(S+1|0,Z,2)|0)!=0){_=1;x=58750;break L77687}$=Z+1|0;if((R6(S,$,2)|0)!=0){_=1;x=58747;break L77687}ab=$;ac=Y;ad=X;ae=W;af=V;ah=U;ai=T;aj=S+(c[F>>2]<<1)|0;break};case 6:{if((c[3542200]|0)==0){_=1;x=58751;break L77687}c[O>>2]=0;c[P>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,Z)|0;if((c[O>>2]|0)!=0){$=c[P>>2]|0;c[k>>2]=9534384;aa=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aa&16383](k,Z,0)|0;if(($|0)<1){_=1;x=58755;break L77687}if((gzL(X,0,Z)|0)!=0){_=1;x=58756;break L77687}}ab=Z;ac=Y;ad=X+(c[F>>2]|0)|0;ae=W;af=V;ah=U;ai=T;aj=S;break};case 4:{if((c[3542200]|0)==0){_=1;x=58752;break L77687}c[K>>2]=0;c[L>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,Z)|0;if((c[K>>2]|0)!=0){$=c[L>>2]|0;c[o>>2]=9534384;aa=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aa&16383](o,Z,0)|0;if(($|0)<1){_=1;x=58759;break L77687}if((gzL(V,0,Z)|0)!=0){_=1;x=58760;break L77687}}ab=Z;ac=Y;ad=X;ae=W;af=V+(c[F>>2]|0)|0;ah=U;ai=T;aj=S;break};case 5:{if((c[3542200]|0)==0){_=1;x=58758;break L77687}c[M>>2]=0;c[N>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,Z)|0;if((c[M>>2]|0)!=0){$=c[N>>2]|0;c[m>>2]=9534384;aa=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aa&16383](m,Z,0)|0;if(($|0)<1){_=1;x=58743;break L77687}if((gzL(W,0,Z)|0)!=0){_=1;x=58744;break L77687}}ab=Z;ac=Y;ad=X;ae=W+(c[F>>2]|0)|0;af=V;ah=U;ai=T;aj=S;break};default:{ab=Z;ac=Y;ad=X;ae=W;af=V;ah=U;ai=T;aj=S}}$=ab+1|0;if((gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](t,$,0)|0)==0){S=aj;T=ai;U=ah;V=af;W=ae;X=ad;Y=ac;Z=$}else{break L77685}}if((x|0)==58737){i=e;return _|0}else if((x|0)==58740){i=e;return _|0}else if((x|0)==58741){i=e;return _|0}else if((x|0)==58742){i=e;return _|0}else if((x|0)==58743){i=e;return _|0}else if((x|0)==58744){i=e;return _|0}else if((x|0)==58745){i=e;return _|0}else if((x|0)==58746){i=e;return _|0}else if((x|0)==58747){i=e;return _|0}else if((x|0)==58749){i=e;return _|0}else if((x|0)==58750){i=e;return _|0}else if((x|0)==58751){i=e;return _|0}else if((x|0)==58752){i=e;return _|0}else if((x|0)==58755){i=e;return _|0}else if((x|0)==58756){i=e;return _|0}else if((x|0)==58757){i=e;return _|0}else if((x|0)==58758){i=e;return _|0}else if((x|0)==58759){i=e;return _|0}else if((x|0)==58760){i=e;return _|0}else if((x|0)==58761){i=e;return _|0}}}while(0);D=(c[2420386]|0)==1;C=0;while(1){if((C|0)>=1024){ak=0;break}al=9638528+(C<<2)|0;if((c[al>>2]|0)==0){x=58594;break}else{C=C+1|0}}do{if((x|0)==58594){C=gGq(1048576)|0;c[al>>2]=C;if((C|0)==0){ak=0;break}gGz(C|0,0,1048576);ak=C}}while(0);C=(ak|0)==0;if(D){if(C){_=1;i=e;return _|0}B=c[2388136]|0;gGC(ak|0,B|0,262144)|0;a[B]=a[ak]|0;A=1;do{a[B+A|0]=a[ak+(A>>>15<<16&65536|A&16678911|A>>>16<<15&32768)|0]|0;A=A+1|0;}while((A|0)<262144);A=c[3530586]|0;B=0;while(1){a[ak+B|0]=a[A+(B>>>16<<17&131072|B&16572423|B>>>17<<16&65536|B>>>4<<12&4096|B>>>3<<11&2048|B>>>12<<10&1024|B>>>11<<9&512|B>>>10<<8&256|B>>>9<<7&128|B>>>8<<6&64|B>>>7<<5&32|B>>>6<<4&16|B>>>5<<3&8)|0]|0;D=B+1|0;if((D|0)<1048576){B=D}else{am=0;break}}do{B=am<<8;gGz(A+B|0,0,256);D=0;do{z=1<<3-D;y=(c[603744+(D<<2)>>2]|0)+B|0;v=0;do{Z=y+(c[609008+(v<<2)>>2]|0)|0;Y=(v<<4)+B|0;X=0;do{W=Z+(c[597864+(X<<2)>>2]|0)|0;if((d[ak+((W|0)/8|0)|0]&128>>>((W&7)>>>0)|0)!=0){W=A+(Y+X)|0;a[W]=(d[W]|z)&255}X=X+1|0;}while((X|0)<16);v=v+1|0;}while((v|0)<16);D=D+1|0;}while((D|0)<4);am=am+1|0;}while((am|0)<8192);A=c[3530328]|0;gGC(ak|0,A|0,1048576)|0;D=0;while(1){B=ak+D|0;a[B]=~a[B];B=D+1|0;if((B|0)<1048576){D=B}else{an=0;break}}do{D=an<<8;gGz(A+D|0,0,256);B=0;do{v=1<<3-B;z=(c[603744+(B<<2)>>2]|0)+D|0;y=0;do{X=z+(c[609008+(y<<2)>>2]|0)|0;Y=(y<<4)+D|0;Z=0;do{W=X+(c[597864+(Z<<2)>>2]|0)|0;if((d[ak+((W|0)/8|0)|0]&128>>>((W&7)>>>0)|0)!=0){W=A+(Y+Z)|0;a[W]=(d[W]|v)&255}Z=Z+1|0;}while((Z|0)<16);y=y+1|0;}while((y|0)<16);B=B+1|0;}while((B|0)<4);an=an+1|0;}while((an|0)<8192);A=c[3530822]|0;gGC(ak|0,A|0,65536)|0;B=0;while(1){D=B<<6;gGz(A+D|0,0,64);y=B<<8;v=0;do{z=1<<3-v;Z=(c[703416+(v<<2)>>2]|0)+y|0;Y=0;do{X=Z+(c[1183816+(Y<<2)>>2]|0)|0;W=(Y<<3)+D|0;V=0;do{U=X+(c[1934976+(V<<2)>>2]|0)|0;if((d[ak+((U|0)/8|0)|0]&128>>>((U&7)>>>0)|0)!=0){U=A+(W+V)|0;a[U]=(d[U]|z)&255}V=V+1|0;}while((V|0)<8);Y=Y+1|0;}while((Y|0)<8);v=v+1|0;}while((v|0)<4);v=B+1|0;if((v|0)<2048){B=v}else{ao=0;break}}while(1){if((ao|0)>=1024){ap=A;break}aq=9638528+(ao<<2)|0;if((c[aq>>2]|0)==(ak|0)){x=58634;break}else{ao=ao+1|0}}if((x|0)==58634){gGr(ak);c[aq>>2]=0;ap=c[3530822]|0}A=c[2439924]|0;gGz(A|0,2,2048);B=0;do{v=ap+B|0;D=B>>6;y=A+D|0;Y=a[y]|0;if((a[v]|0)==15){ar=Y;x=58638}else{z=Y|1;a[y]=z;if((a[v]|0)==15){ar=z;x=58638}}if((x|0)==58638){x=0;a[A+D|0]=ar&-3}B=B+1|0;}while((B|0)<131072);gGz(c[2439922]|0,3,4096);B=c[2439920]|0;gGz(B|0,2,4096);A=c[3530422]|0;D=0;do{z=A+D|0;v=D>>8;y=B+v|0;Y=a[y]|0;if((a[z]|0)==15){as=Y;x=58643}else{Z=Y|1;a[y]=Z;if((a[z]|0)==15){as=Z;x=58643}}if((x|0)==58643){x=0;a[B+v|0]=as&-3}D=D+1|0;}while((D|0)<1048576)}else{if(C){_=1;i=e;return _|0}D=c[3530822]|0;gGC(ak|0,D|0,65536)|0;B=0;do{A=B<<6;gGz(D+A|0,0,64);v=B<<8;Z=0;do{z=1<<3-Z;y=(c[703416+(Z<<2)>>2]|0)+v|0;Y=0;do{V=y+(c[3946808+(Y<<2)>>2]|0)|0;W=(Y<<3)+A|0;X=0;do{U=V+(c[3946872+(X<<2)>>2]|0)|0;if((d[ak+((U|0)/8|0)|0]&128>>>((U&7)>>>0)|0)!=0){U=D+(W+X)|0;a[U]=(d[U]|z)&255}X=X+1|0;}while((X|0)<8);Y=Y+1|0;}while((Y|0)<8);Z=Z+1|0;}while((Z|0)<4);B=B+1|0;}while((B|0)<2048);B=c[3530586]|0;gGC(ak|0,B|0,524288)|0;C=0;do{Z=C<<8;gGz(B+Z|0,0,256);A=C<<10;v=0;do{Y=1<<3-v;z=(c[703416+(v<<2)>>2]|0)+A|0;y=0;do{X=z+(c[3946808+(y<<2)>>2]|0)|0;W=(y<<4)+Z|0;V=0;do{U=X+(c[3946872+(V<<2)>>2]|0)|0;if((d[ak+((U|0)/8|0)|0]&128>>>((U&7)>>>0)|0)!=0){U=B+(W+V)|0;a[U]=(d[U]|Y)&255}V=V+1|0;}while((V|0)<16);y=y+1|0;}while((y|0)<16);v=v+1|0;}while((v|0)<4);C=C+1|0;}while((C|0)<4096);C=c[3530422]|0;gGC(ak|0,C|0,524288)|0;B=0;do{v=B<<8;gGz(C+v|0,0,256);Z=B<<10;A=0;do{y=1<<3-A;Y=(c[703416+(A<<2)>>2]|0)+Z|0;z=0;do{V=Y+(c[3946808+(z<<2)>>2]|0)|0;W=(z<<4)+v|0;X=0;do{U=V+(c[3946872+(X<<2)>>2]|0)|0;if((d[ak+((U|0)/8|0)|0]&128>>>((U&7)>>>0)|0)!=0){U=C+(W+X)|0;a[U]=(d[U]|y)&255}X=X+1|0;}while((X|0)<16);z=z+1|0;}while((z|0)<16);A=A+1|0;}while((A|0)<4);B=B+1|0;}while((B|0)<4096);B=c[3530328]|0;gGC(ak|0,B|0,1048576)|0;C=0;while(1){A=C<<6;gGz(B+A|0,0,64);v=C<<7;Z=0;do{z=1<<3-Z;y=(c[703416+(Z<<2)>>2]|0)+v|0;Y=0;do{X=y+(c[6669224+(Y<<2)>>2]|0)|0;W=(Y<<3)+A|0;V=0;do{U=X+(c[613232+(V<<2)>>2]|0)|0;if((d[ak+((U|0)/8|0)|0]&128>>>((U&7)>>>0)|0)!=0){U=B+(W+V)|0;a[U]=(d[U]|z)&255}V=V+1|0;}while((V|0)<8);Y=Y+1|0;}while((Y|0)<8);Z=Z+1|0;}while((Z|0)<4);Z=C+1|0;if((Z|0)<32768){C=Z}else{at=0;break}}while(1){if((at|0)>=1024){au=D;break}av=9638528+(at<<2)|0;if((c[av>>2]|0)==(ak|0)){x=58688;break}else{at=at+1|0}}if((x|0)==58688){gGr(ak);c[av>>2]=0;au=c[3530822]|0}D=c[2439924]|0;gGz(D|0,2,2048);C=0;do{B=au+C|0;Z=C>>6;A=D+Z|0;v=a[A]|0;if((a[B]|0)==0){aw=v;x=58692}else{Y=v|1;a[A]=Y;if((a[B]|0)==0){aw=Y;x=58692}}if((x|0)==58692){x=0;a[D+Z|0]=aw&-3}C=C+1|0;}while((C|0)<131072);C=c[2439922]|0;gGz(C|0,2,4096);D=c[2439920]|0;gGz(D|0,2,4096);Z=c[3530586]|0;Y=c[3530422]|0;B=0;do{A=Z+B|0;v=B>>8;z=C+v|0;y=a[z]|0;if((a[A]|0)==0){ax=y;x=58697}else{V=y|1;a[z]=V;if((a[A]|0)==0){ax=V;x=58697}}if((x|0)==58697){x=0;a[C+v|0]=ax&-3}V=Y+B|0;A=D+v|0;z=a[A]|0;if((a[V]|0)==0){ay=z;x=58700}else{y=z|1;a[A]=y;if((a[V]|0)==0){ay=y;x=58700}}if((x|0)==58700){x=0;a[D+v|0]=ay&-3}B=B+1|0;}while((B|0)<1048576)}fxU(0,425984);if((c[2394]|0)==0){az=c[2112932]|0}else{c[2394]=0;B=c[3532596]|0;c[2112932]=B;D=c[3532592]|0;if((D|0)!=0){gGC(9104152,D|0,280)|0}c[2113054]=c[2113060];az=B}B=c[2388136]|0;D=az|0;Y=0;while(1){C=B+Y|0;c[D>>2]=C;c[D+131072>>2]=C;C=Y+1024|0;if(C>>>0>262143){break}else{D=D+4|0;Y=C}}Y=c[2388264]|0;c[az+1536>>2]=Y;c[az+67072>>2]=Y;c[az+132608>>2]=Y;D=Y+1024|0;c[az+1540>>2]=D;c[az+67076>>2]=D;c[az+132612>>2]=D;D=Y+2048|0;c[az+1544>>2]=D;c[az+67080>>2]=D;c[az+132616>>2]=D;D=Y+3072|0;c[az+1548>>2]=D;c[az+67084>>2]=D;c[az+132620>>2]=D;D=Y+4096|0;c[az+1552>>2]=D;c[az+67088>>2]=D;c[az+132624>>2]=D;D=Y+5120|0;c[az+1556>>2]=D;c[az+67092>>2]=D;c[az+132628>>2]=D;D=Y+6144|0;c[az+1560>>2]=D;c[az+67096>>2]=D;c[az+132632>>2]=D;D=Y+7168|0;c[az+1564>>2]=D;c[az+67100>>2]=D;c[az+132636>>2]=D;D=Y+8192|0;c[az+1568>>2]=D;c[az+67104>>2]=D;c[az+132640>>2]=D;D=Y+9216|0;c[az+1572>>2]=D;c[az+67108>>2]=D;c[az+132644>>2]=D;D=Y+10240|0;c[az+1576>>2]=D;c[az+67112>>2]=D;c[az+132648>>2]=D;D=Y+11264|0;c[az+1580>>2]=D;c[az+67116>>2]=D;c[az+132652>>2]=D;D=Y+12288|0;c[az+1584>>2]=D;c[az+67120>>2]=D;c[az+132656>>2]=D;D=Y+13312|0;c[az+1588>>2]=D;c[az+67124>>2]=D;c[az+132660>>2]=D;D=Y+14336|0;c[az+1592>>2]=D;c[az+67128>>2]=D;c[az+132664>>2]=D;D=Y+15360|0;c[az+1596>>2]=D;c[az+67132>>2]=D;c[az+132668>>2]=D;D=c[3529462]|0;c[az+1792>>2]=D;c[az+67328>>2]=D;c[az+132864>>2]=D;Y=D+1024|0;c[az+1796>>2]=Y;c[az+67332>>2]=Y;c[az+132868>>2]=Y;Y=D+2048|0;c[az+1800>>2]=Y;c[az+67336>>2]=Y;c[az+132872>>2]=Y;Y=D+3072|0;c[az+1804>>2]=Y;c[az+67340>>2]=Y;c[az+132876>>2]=Y;Y=c[3529428]|0;c[az+1824>>2]=Y;c[az+67360>>2]=Y;c[az+132896>>2]=Y;D=Y+1024|0;c[az+1828>>2]=D;c[az+67364>>2]=D;c[az+132900>>2]=D;D=Y+2048|0;c[az+1832>>2]=D;c[az+67368>>2]=D;c[az+132904>>2]=D;D=Y+3072|0;c[az+1836>>2]=D;c[az+67372>>2]=D;c[az+132908>>2]=D;D=Y+4096|0;c[az+1840>>2]=D;c[az+67376>>2]=D;c[az+132912>>2]=D;D=Y+5120|0;c[az+1844>>2]=D;c[az+67380>>2]=D;c[az+132916>>2]=D;D=Y+6144|0;c[az+1848>>2]=D;c[az+67384>>2]=D;c[az+132920>>2]=D;D=Y+7168|0;c[az+1852>>2]=D;c[az+67388>>2]=D;c[az+132924>>2]=D;D=c[3529406]|0;c[az+1856>>2]=D;c[az+67392>>2]=D;c[az+132928>>2]=D;Y=D+1024|0;c[az+1860>>2]=Y;c[az+67396>>2]=Y;c[az+132932>>2]=Y;Y=D+2048|0;c[az+1864>>2]=Y;c[az+67400>>2]=Y;c[az+132936>>2]=Y;Y=D+3072|0;c[az+1868>>2]=Y;c[az+67404>>2]=Y;c[az+132940>>2]=Y;Y=D+4096|0;c[az+1872>>2]=Y;c[az+67408>>2]=Y;c[az+132944>>2]=Y;Y=D+5120|0;c[az+1876>>2]=Y;c[az+67412>>2]=Y;c[az+132948>>2]=Y;Y=D+6144|0;c[az+1880>>2]=Y;c[az+67416>>2]=Y;c[az+132952>>2]=Y;Y=D+7168|0;c[az+1884>>2]=Y;c[az+67420>>2]=Y;c[az+132956>>2]=Y;Y=c[2386438]|0;c[az+1888>>2]=Y;c[az+67424>>2]=Y;c[az+132960>>2]=Y;D=Y+1024|0;c[az+1892>>2]=D;c[az+67428>>2]=D;c[az+132964>>2]=D;D=Y+2048|0;c[az+1896>>2]=D;c[az+67432>>2]=D;c[az+132968>>2]=D;D=Y+3072|0;c[az+1900>>2]=D;c[az+67436>>2]=D;c[az+132972>>2]=D;D=Y+4096|0;c[az+1904>>2]=D;c[az+67440>>2]=D;c[az+132976>>2]=D;D=Y+5120|0;c[az+1908>>2]=D;c[az+67444>>2]=D;c[az+132980>>2]=D;D=Y+6144|0;c[az+1912>>2]=D;c[az+67448>>2]=D;c[az+132984>>2]=D;D=Y+7168|0;c[az+1916>>2]=D;c[az+67452>>2]=D;c[az+132988>>2]=D;D=c[2387176]|0;c[az+1920>>2]=D;c[az+132992>>2]=D;Y=D+1024|0;c[az+1924>>2]=Y;c[az+132996>>2]=Y;Y=D+2048|0;c[az+1928>>2]=Y;c[az+133e3>>2]=Y;Y=D+3072|0;c[az+1932>>2]=Y;c[az+133004>>2]=Y;Y=D+4096|0;c[az+1936>>2]=Y;c[az+133008>>2]=Y;Y=D+5120|0;c[az+1940>>2]=Y;c[az+133012>>2]=Y;Y=D+6144|0;c[az+1944>>2]=Y;c[az+133016>>2]=Y;Y=D+7168|0;c[az+1948>>2]=Y;c[az+133020>>2]=Y;c[az+196648>>2]=2320;c[az+196728>>2]=556;c[az+196608>>2]=2370;c[az+196688>>2]=2524;Y=c[3532592]|0;if((Y|0)!=0){gGC(Y|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);Y=c[2439330]|0;D=(Y|0)==0;if(!D){B=Y;gGC(9706056,B|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];B=c[3528484]|0;c[2076596]=B;C=c[2417276]|0;c[3541536]=C;c[1836236]=0;Z=(c[2420386]|0)==1;v=c[2385912]|0;if(Z){y=0;V=0;while(1){c[Y+76+(V<<2)>>2]=v+(V<<8);A=y+1&65535;if((A&65535)>247){aA=0;aB=0;break}else{y=A;V=A&65535}}while(1){V=v+(aB<<8)|0;c[Y+76+(aB+512<<2)>>2]=V;c[Y+76+(aB+768<<2)>>2]=V;V=aA+1&65535;if((V&65535)>247){break}else{aA=V;aB=V&65535}}V=c[2386066]|0;c[Y+1068>>2]=V;y=V+256|0;c[Y+1072>>2]=y;A=V+512|0;c[Y+1076>>2]=A;z=V+768|0;c[Y+1080>>2]=z;W=V+1024|0;c[Y+1084>>2]=W;X=V+1280|0;c[Y+1088>>2]=X;U=V+1536|0;c[Y+1092>>2]=U;T=V+1792|0;c[Y+1096>>2]=T;c[Y+2092>>2]=V;c[Y+2096>>2]=y;c[Y+2100>>2]=A;c[Y+2104>>2]=z;c[Y+2108>>2]=W;c[Y+2112>>2]=X;c[Y+2116>>2]=U;c[Y+2120>>2]=T;c[Y+3116>>2]=V;c[Y+4140>>2]=V;c[Y+3120>>2]=y;c[Y+4144>>2]=y;c[Y+3124>>2]=A;c[Y+4148>>2]=A;c[Y+3128>>2]=z;c[Y+4152>>2]=z;c[Y+3132>>2]=W;c[Y+4156>>2]=W;c[Y+3136>>2]=X;c[Y+4160>>2]=X;c[Y+3140>>2]=U;c[Y+4164>>2]=U;c[Y+3144>>2]=T;c[Y+4168>>2]=T;c[Y+4176>>2]=2656;c[Y+4172>>2]=888}else{T=0;U=0;while(1){c[Y+76+(U<<2)>>2]=v+(U<<8);X=T+1&65535;if((X&65535)>239){aC=0;aD=0;break}else{T=X;U=X&65535}}while(1){U=v+(aD<<8)|0;c[Y+76+(aD+512<<2)>>2]=U;c[Y+76+(aD+768<<2)>>2]=U;U=aC+1&65535;if((U&65535)>239){break}else{aC=U;aD=U&65535}}v=c[2386066]|0;c[Y+1036>>2]=v;U=v+256|0;c[Y+1040>>2]=U;T=v+512|0;c[Y+1044>>2]=T;X=v+768|0;c[Y+1048>>2]=X;W=v+1024|0;c[Y+1052>>2]=W;z=v+1280|0;c[Y+1056>>2]=z;A=v+1536|0;c[Y+1060>>2]=A;y=v+1792|0;c[Y+1064>>2]=y;c[Y+2060>>2]=v;c[Y+2064>>2]=U;c[Y+2068>>2]=T;c[Y+2072>>2]=X;c[Y+2076>>2]=W;c[Y+2080>>2]=z;c[Y+2084>>2]=A;c[Y+2088>>2]=y;c[Y+3084>>2]=v;c[Y+4108>>2]=v;c[Y+3088>>2]=U;c[Y+4112>>2]=U;c[Y+3092>>2]=T;c[Y+4116>>2]=T;c[Y+3096>>2]=X;c[Y+4120>>2]=X;c[Y+3100>>2]=W;c[Y+4124>>2]=W;c[Y+3104>>2]=z;c[Y+4128>>2]=z;c[Y+3108>>2]=A;c[Y+4132>>2]=A;c[Y+3112>>2]=y;c[Y+4136>>2]=y;c[Y+4184>>2]=2434;c[Y+4180>>2]=1656}if(!D){y=Y;gGC(y|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=B;c[2417276]=C;c[1836236]=-1;if(Z){y=a[9680]|0;A=y?32e3:0;if(y){if(a[9624]|0){y=A*3|0;z=62500;while(1){if((z|0)>(y|0)){z=z>>1}else{aE=1222;aF=z;break}}}else{aE=2462;aF=A}c[2429380]=aF;c[3542124]=aE;mw(4e6,aF);z=gGq(262144)|0;c[2406684]=z;gGz(z|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(4e6,11025)}h[745421]=.4;c[2436794]=3;h[745420]=.4;c[2436792]=3}else{Vr(2,4e6,504,3176,18,0);c[2438228]=4e6;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=511;h[745419]=.6;a[3203368]=1;h[745418]=.15;a[3203360]=1;h[745417]=.15;a[3203352]=1;h[745416]=.15;a[3203344]=1;h[745415]=.6;a[3203336]=1;h[745414]=.15;a[3203328]=1;h[745413]=.15;a[3203320]=1;h[745412]=.15;a[3203312]=1}Ux(0,7575,1);c[2407030]=51;c[2407068]=3;eig();z=c[642608+(c[2436]<<2)>>2]|0;y=c[z+128>>2]|0;if((c[z+52>>2]&4|0)==0){c[2113068]=y;Z=c[z+132>>2]|0;c[2113070]=Z;c[2443814]=y;c[2440436]=Z;aG=y;aH=Z}else{c[2113070]=y;Z=c[z+132>>2]|0;c[2113068]=Z;c[2440436]=y;c[2443814]=Z;aG=Z;aH=y}y=ag(aG<<1,aH)|0;Z=gGq(y)|0;c[2112926]=Z;if((Z|0)==0){_=0;i=e;return _|0}gGz(Z|0,0,y|0);_=0;i=e;return _|0}}while(0);c[2426704]=0;_=1;i=e;return _|0}function ehK(){var b=0,d=0,e=0,f=0,g=0;if((c[2392]|0)>=0){b=0;do{d=14130368+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}d=14130384+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}b=b+1|0;}while((b|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;fwZ();Uw(0);do{if((c[2420386]|0)==1){b=c[3531464]|0;c[b+44344>>2]=0;c[b+44348>>2]=0;if((b|0)!=0){gGr(b);c[3531464]=0}b=c[2406684]|0;if((b|0)==0){break}gGr(b);c[2406684]=0}else{b=c[3541518]|0;if((b|0)!=0){gGr(b|0);c[3541518]=0}if((c[2385508]|0)>0){c[2113008]=0;c[2076598]=0;c[2383582]=0}c[2438228]=0;c[2433526]=0;c[2406676]=0;c[3528472]=0;b=c[2406680]|0;if((b|0)!=0){gGr(b);c[2406680]=0}c[2385508]=0;c[2432978]=0;a[64240]=0}}while(0);c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}b=c[2426704]|0;d=0;while(1){if((d|0)>=1024){f=58788;break}g=9638528+(d<<2)|0;if((c[g>>2]|0)==(b|0)){break}else{d=d+1|0}}if((f|0)==58788){c[2426704]=0;c[2420386]=0;return 0}gGr(b);c[g>>2]=0;c[2426704]=0;c[2420386]=0;return 0}function ehL(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if((a[9624032]|0)!=0){eig()}d=c[2385548]|0;if((d|0)>0){gGz(9752472,0,((d|0)>1?d<<2:4)|0)}c[2433530]=0;a[9549712]=-1;a[9549800]=-1;a[9549968]=-1;d=0;e=-1;f=-1;g=-1;do{e=((a[9633240+d|0]&1)<<d^e&255)&255;f=((a[9631112+d|0]&1)<<d^f&255)&255;g=((a[9629496+d|0]&1)<<d^g&255)&255;d=d+1|0;}while((d|0)<8);a[9549968]=e;a[9549800]=f;a[9549712]=g;g=(c[2420386]|0)==1?166666:153600;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060]}f=c[2439330]|0;if((f|0)!=0){e=f;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;e=0;f=0;d=0;h=0;L78037:while(1){i=f;j=d;k=h;while(1){if((i|0)>=10){break L78037}l=i+1|0;m=((ag(l,g)|0)/10|0)-j|0;c[2113056]=m;n=RG(m)|0;c[2113054]=(c[2113054]|0)+n;c[2276108]=-1;c[2113056]=-1;o=n+j|0;do{if((i|0)==9){c[8452200+(c[2394]<<2)>>2]=8197;c[2276080]=1280;if((c[2276079]|0)>>>0>=1280){break}RH(5)}}while(0);if((c[2420386]|0)==1){n=((l*66666|0|0)/10|0)-k|0;do{if((n|0)<1){p=0}else{if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){m=gfc(n)|0;c[2433530]=(c[2433530]|0)+m;p=m;break}else{c[2433530]=(c[2433530]|0)+n;p=n;break}}}while(0);q=p+k|0}else{Sb(i*6666|0);q=k}r=c[2112964]|0;if((r|0)!=0&(c[2420386]|0)==1){break}else{i=l;j=o;k=q}}k=a[9688]|0?53:0;j=r+(e<<1<<1)|0;gg[c[3542124]&4095](j,k);Uu(0,j,k);e=k+e|0;f=l;d=o;h=q}if((c[2420386]|0)!=1){q=c[2438228]|0;h=gGS(-747372544,31788,q,(q|0)<0|0?-1:0)|0;q=h;Sb(66666);h=c[2443830]|0;if((h|0)<1073676288){c[2443830]=h-q}h=c[2443831]|0;if((h|0)<1073676288){c[2443831]=h-q}h=(c[3528512]|0)-q|0;c[3528512]=(h|0)<0?0:h}h=c[2112964]|0;do{if((h|0)!=0){if((c[2420386]|0)!=1){gg[c[3542122]&4095](h,a[9688]|0?534:0);Uu(0,c[2112964]|0,a[9688]|0?534:0);break}q=a[9688]|0?534:0;o=q-e|0;d=h+(e<<1<<1)|0;if((q|0)==(e|0)){break}gg[c[3542124]&4095](d,o);Uu(0,d,o)}}while(0);e=c[1836236]|0;h=c[9757320+(e<<2)>>2]|0;if((h|0)!=0){o=h;gGC(o|0,9706056,76)|0}c[9752472+(e<<2)>>2]=c[2433530];c[14113936+(e<<2)>>2]=c[2076596];c[9669104+(e<<2)>>2]=c[3541536];c[1836236]=-1;e=c[2394]|0;o=c[14130368+(e<<2)>>2]|0;if((o|0)!=0){gGC(o|0,9104152,280)|0}c[8452240+(e<<2)>>2]=c[2113054];c[2394]=-1;if((c[2112968]|0)==0){return 0}if((c[2420386]|0)==1){eib()|0;return 0}else{ehM()|0;return 0}return 0}function ehM(){var d=0,e=0,f=0,g=0;if((a[9547368]|0)!=0){d=c[2406928]|0;e=c[3529982]|0;f=0;do{g=c[d+(f<<2)>>2]|0;c[e+(f<<2)>>2]=g>>8<<3&2016|g>>>3&31|g>>16<<8&63488;f=f+1|0;}while((f|0)<4096)}f=ag(c[2113070]|0,c[2113068]|0)|0;if((f|0)>0){e=c[2112926]|0;d=0;do{b[e+(d<<1)>>1]=512;d=d+1|0;}while((d|0)<(f|0))}eif(3);eic(c[3529406]|0,c[3530586]|0,768,c[3526962]&65535,c[3526954]&65535,c[2439922]|0,0);eif(2);eic(c[3529428]|0,c[3530422]|0,512,c[3525088]&65535,c[3525080]&65535,c[2439920]|0,0);eif(1);eie(256,0);eif(0);R8(c[3529982]|0);return 0}function ehN(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;f=i;i=i+272|0;g=f|0;h=f+16|0;j=f+32|0;k=f+48|0;l=f+64|0;m=f+80|0;n=f+96|0;o=f+112|0;p=f+128|0;q=f+144|0;r=f+160|0;s=f+176|0;t=f+192|0;u=f+208|0;v=f+224|0;w=f+240|0;x=f+256|0;if((e|0)!=0){c[e>>2]=169251}if((b&96|0)!=0){gGz(x|0,0,12);y=c[2414646]|0;c[x>>2]=y;c[x+4>>2]=(c[2411624]|0)-y;c[x+12>>2]=196728;y=c[2076592]|0;gj[y&4095](x)|0}if((b&64|0)==0){i=f;return 0}x=l|0;gGz(k|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){y=l+9|0;l=j;z=j|0;A=j+4|0;B=j+12|0;C=k|0;D=k+4|0;E=k+12|0;F=0;do{gGC(x|0,614896,11)|0;a[y]=F+48&255;G=8452256+(F<<2)|0;gGz(l|0,0,12);c[z>>2]=G;c[A>>2]=4;c[B>>2]=164976;gj[c[2076592]&4095](j)|0;if((c[G>>2]|0)!=0){c[C>>2]=c[14130368+(F<<2)>>2];c[D>>2]=c[8452184+(F<<2)>>2];c[E>>2]=x;G=c[2076592]|0;gj[G&4095](k)|0}F=F+1|0;}while((F|0)<=(c[2392]|0))}fw$(b);Ut(0);do{if((c[2420386]|0)==1){gGz(h|0,0,12);c[h>>2]=8453216;c[h+4>>2]=4;c[h+12>>2]=107480;F=c[2076592]|0;gj[F&4095](h)|0;gGz(g|0,0,12);c[g>>2]=14168504;c[g+4>>2]=256;c[g+12>>2]=476464;F=c[2076592]|0;gj[F&4095](g)|0;if((b&2|0)==0){break}else{H=0}do{mv(0,H,d[14168504+H|0]|0);H=H+1|0;}while((H|0)<256)}else{Vx(b,e)}}while(0);gGz(w|0,0,12);c[w>>2]=9681456;c[w+4>>2]=4;c[w+12>>2]=566992;gj[c[2076592]&4095](w)|0;gGz(v|0,0,12);c[v>>2]=9620352;c[v+4>>2]=4;c[v+12>>2]=564576;gj[c[2076592]&4095](v)|0;gGz(u|0,0,12);c[u>>2]=9776696;c[u+4>>2]=4;c[u+12>>2]=562960;gj[c[2076592]&4095](u)|0;gGz(t|0,0,12);c[t>>2]=9774736;c[t+4>>2]=4;c[t+12>>2]=561320;gj[c[2076592]&4095](t)|0;gGz(s|0,0,12);c[s>>2]=9774728;c[s+4>>2]=4;c[s+12>>2]=560080;gj[c[2076592]&4095](s)|0;gGz(r|0,0,12);c[r>>2]=14100352;c[r+4>>2]=4;c[r+12>>2]=558672;gj[c[2076592]&4095](r)|0;gGz(q|0,0,12);c[q>>2]=14100320;c[q+4>>2]=4;c[q+12>>2]=557256;gj[c[2076592]&4095](q)|0;gGz(p|0,0,12);c[p>>2]=14107848;c[p+4>>2]=4;c[p+12>>2]=555984;gj[c[2076592]&4095](p)|0;gGz(o|0,0,12);c[o>>2]=14107816;c[o+4>>2]=4;c[o+12>>2]=554432;gj[c[2076592]&4095](o)|0;gGz(n|0,0,12);c[n>>2]=14113032;c[n+4>>2]=1;c[n+12>>2]=191240;gj[c[2076592]&4095](n)|0;gGz(m|0,0,12);c[m>>2]=14114768;c[m+4>>2]=4;c[m+12>>2]=142288;gj[c[2076592]&4095](m)|0;if((c[2444174]|0)==0){i=f;return 0}c[3528600]=1521528;i=f;return 0}function ehO(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2288892+(b*112|0)>>2];c[a+104>>2]=c[2288896+(b*112|0)>>2];c[a+108>>2]=c[2288900+(b*112|0)>>2];d=0;return d|0}function ehP(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=2288792+(b*112|0);e=0;return e|0}function ehQ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5894916+(b*112|0)>>2];c[a+104>>2]=c[5894920+(b*112|0)>>2];c[a+108>>2]=c[5894924+(b*112|0)>>2];d=0;return d|0}function ehR(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<21&(d|0)==0)){e=1;return e|0}c[a>>2]=5894816+(b*112|0);e=0;return e|0}function ehS(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2353740+(b*112|0)>>2];c[a+104>>2]=c[2353744+(b*112|0)>>2];c[a+108>>2]=c[2353748+(b*112|0)>>2];d=0;return d|0}function ehT(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=2353640+(b*112|0);e=0;return e|0}function ehU(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2356316+(b*112|0)>>2];c[a+104>>2]=c[2356320+(b*112|0)>>2];c[a+108>>2]=c[2356324+(b*112|0)>>2];d=0;return d|0}function ehV(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<21&(d|0)==0)){e=1;return e|0}c[a>>2]=2356216+(b*112|0);e=0;return e|0}function ehW(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2090852+(b*112|0)>>2];c[a+104>>2]=c[2090856+(b*112|0)>>2];c[a+108>>2]=c[2090860+(b*112|0)>>2];d=0;return d|0}function ehX(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=2090752+(b*112|0);e=0;return e|0}function ehY(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>50){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3247936+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function ehZ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4355028+(b*112|0)>>2];c[a+104>>2]=c[4355032+(b*112|0)>>2];c[a+108>>2]=c[4355036+(b*112|0)>>2];d=0;return d|0}function eh_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=4354928+(b*112|0);e=0;return e|0}function eh$(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>34){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4927368+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eh0(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4378908+(b*112|0)>>2];c[a+104>>2]=c[4378912+(b*112|0)>>2];c[a+108>>2]=c[4378916+(b*112|0)>>2];d=0;return d|0}function eh1(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=4378808+(b*112|0);e=0;return e|0}function eh2(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5117928+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eh3(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>53){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6811968+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eh4(){c[2420386]=2;return ehJ()|0}function eh5(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6498828+(b*112|0)>>2];c[a+104>>2]=c[6498832+(b*112|0)>>2];c[a+108>>2]=c[6498836+(b*112|0)>>2];d=0;return d|0}function eh6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=6498728+(b*112|0);e=0;return e|0}function eh7(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2918300+(b*112|0)>>2];c[a+104>>2]=c[2918304+(b*112|0)>>2];c[a+108>>2]=c[2918308+(b*112|0)>>2];d=0;return d|0}function eh8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<22&(d|0)==0)){e=1;return e|0}c[a>>2]=2918200+(b*112|0);e=0;return e|0}function eh9(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>32){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4048736+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eia(){var a=0;c[2420386]=1;a=ehJ()|0;c[2407030]=128;c[2407068]=3;return a|0}function eib(){var d=0,e=0,f=0,g=0;if((a[9547368]|0)!=0){d=c[2406928]|0;e=c[3529982]|0;f=0;do{g=c[d+(f<<2)>>2]|0;c[e+(f<<2)>>2]=g>>8<<3&2016|g>>>3&31|g>>16<<8&63488;f=f+1|0;}while((f|0)<4096)}f=ag(c[2113070]|0,c[2113068]|0)|0;if((f|0)>0){e=c[2112926]|0;d=0;do{b[e+(d<<1)>>1]=0;d=d+1|0;}while((d|0)<(f|0))}eic(c[3529406]|0,c[3530586]|0,768,c[3526962]&65535,c[3526954]&65535,c[2439922]|0,-1);eid(32);eic(c[3529428]|0,c[3530422]|0,512,c[3525088]&65535,c[3525080]&65535,c[2439920]|0,15);eid(0);eie(0,15);R8(c[3529982]|0);return 0}function eic(a,f,g,h,i,j,k){a=a|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;l=h&65535;h=i&65535;i=(c[2420386]|0)==2&(g|0)==768;m=c[2112926]|0;n=0;do{o=(n<<4&1008)-l|0;p=(n>>6<<4)-h|0;q=(o|0)<-15?o+1024|0:o;o=(p|0)<-15?p+512|0:p;do{if(!((o|0)>255|(q|0)>255)){p=c[3528692]|0;if((p|0)==0){r=o;s=q}else{r=239-o|0;s=239-q|0}t=r-16|0;u=b[a+(n+2048<<1)>>1]&4095;v=e[a+(n<<1)>>1]|0;w=v>>>4&15;if(i){x=w|v<<4&128}else{x=w}w=d[j+u|0]|0;v=(w&1|0)==0;if(t>>>0<209&s>>>0<241){if(v){break}y=(p|0)!=0;if((w&2|0)==0){if(y){SM(m,u,s,t,x,4,k,g,f);break}else{SG(m,u,s,t,x,4,k,g,f);break}}else{if(y){SE(m,u,s,t,x,4,g,f);break}else{Sy(m,u,s,t,x,4,g,f);break}}}else{if(v){break}v=(p|0)!=0;if((w&2|0)==0){if(v){SN(m,u,s,t,x,4,k,g,f);break}else{SH(m,u,s,t,x,4,k,g,f);break}}else{if(v){SF(m,u,s,t,x,4,g,f);break}else{Sz(m,u,s,t,x,4,g,f);break}}}}}while(0);n=n+1|0;}while((n|0)<2048);return}function eid(a){a=a|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=c[2386438]|0;f=c[2112926]|0;g=c[3530328]|0;h=1020;do{i=e[d+((h|3)<<1)>>1]|0;do{if((i&32|0)==(a|0)){j=b[d+(h<<1)>>1]&255|i<<8&7936;k=e[d+((h|2)<<1)>>1]|0;l=e[d+(h+1024<<1)>>1]|0;m=l&15;n=(l&128|0)==0?k&255:k|-256;k=n+256|0;l=256-(b[d+((h|1)<<1)>>1]&255)-28|0;o=(i&64|0)!=0;if((i&128|0)==0){if(o){SJ(f,j,k,l,m,4,15,256,g);if((k|0)<=496){break}SJ(f,j,n-256|0,l,m,4,15,256,g);break}else{SH(f,j,k,l,m,4,15,256,g);if((k|0)<=496){break}SH(f,j,n-256|0,l,m,4,15,256,g);break}}else{if(o){SN(f,j,k,l,m,4,15,256,g);if((k|0)<=496){break}SN(f,j,n-256|0,l,m,4,15,256,g);break}else{SL(f,j,k,l,m,4,15,256,g);if((k|0)<=496){break}SL(f,j,n-256|0,l,m,4,15,256,g);break}}}}while(0);h=h-4|0;}while((h|0)>-1);return}function eie(a,f){a=a|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=c[3529462]|0;h=c[2439924]|0;i=c[2112926]|0;j=c[3530822]|0;k=0;do{l=k<<3&248;m=k>>>2&248;n=c[3528692]|0;if((n|0)==0){o=l;p=m}else{o=248-l|0;p=248-m|0}m=o-(c[2443684]|0)|0;l=p-16-(c[2443682]|0)|0;q=b[g+(k+1024<<1)>>1]&2047;r=(e[g+(k<<1)>>1]|0)>>>4&15;do{if((q|0)!=0){s=d[h+q|0]|0;t=(s&1|0)==0;if(l>>>0<217&m>>>0<249){if(t){break}u=(n|0)!=0;if((s&2|0)==0){if(u){Sw(i,q,m,l,r,4,f,a,j);break}else{Sq(i,q,m,l,r,4,f,a,j);break}}else{if(u){So(i,q,m,l,r,4,a,j);break}else{Si(i,q,m,l,r,4,a,j);break}}}else{if(t){break}t=(n|0)!=0;if((s&2|0)==0){if(t){Sx(i,q,m,l,r,4,f,a,j);break}else{Sr(i,q,m,l,r,4,f,a,j);break}}else{if(t){Sp(i,q,m,l,r,4,a,j);break}else{Sj(i,q,m,l,r,4,a,j);break}}}}}while(0);k=k+1|0;}while((k|0)<1024);return}function eif(a){a=a|0;var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;b=c[2420386]&2;f=c[2112926]|0;g=c[3530328]|0;h=(c[2113222]&1|0)==0;i=c[2386438]|0;j=0;while(1){k=e[i>>1]|0;do{if((k&4|0)!=0){if((k>>>6&3|0)!=(a|0)){break}l=k&1;m=k&2;n=e[i+4>>1]|0;o=1<<(n&3);p=1<<(n>>>(b>>>0)&3);q=((o|0)>2?32760:32764)&(e[i+2>>1]|0);r=e[i+6>>1]|0;s=r&511;t=e[i+8>>1]|0;u=t&511;if(!((k&32|0)==0|h)){break}v=n>>>4&15;n=u>>>0>255?t|-512:u;u=s>>>0>255?r|-512:s;if((c[3528692]|0)==0){w=n;x=u;y=m;z=l}else{s=256-(o<<3)-n|0;n=256-(p<<3)-u|0;w=(s|0)<-255?s+512|0:s;x=(n|0)<-255?n+512|0:n;y=m>>>1^1;z=l^1}if((p|0)<=0){break}l=(o|0)>0;m=(z|0)!=0;n=o+536870911|0;s=(y|0)!=0;u=p+536870911|0;r=0;do{if(l){t=((s?u-r|0:r)<<3)+x|0;A=t-16|0;B=(t-1|0)>>>0>238;t=A>>>0<209;C=0;do{D=((m?n-C|0:C)<<3)+w|0;do{if(!((D+15|0)>>>0>270|B)){E=(d[596808+(r<<3)+C|0]|0)+q|0;if(D>>>0<241&t){if(s){if(m){Sw(f,E,D,A,v,4,0,0,g);break}else{Su(f,E,D,A,v,4,0,0,g);break}}else{if(m){Ss(f,E,D,A,v,4,0,0,g);break}else{Sq(f,E,D,A,v,4,0,0,g);break}}}else{if(s){if(m){Sx(f,E,D,A,v,4,0,0,g);break}else{Sv(f,E,D,A,v,4,0,0,g);break}}else{if(m){St(f,E,D,A,v,4,0,0,g);break}else{Sr(f,E,D,A,v,4,0,0,g);break}}}}}while(0);C=C+1|0;}while((C|0)<(o|0))}r=r+1|0;}while((r|0)<(p|0))}}while(0);k=j+1|0;if((k|0)<256){i=i+16|0;j=k}else{break}}return}function eig(){var b=0,d=0,e=0,f=0,g=0,i=0;b=c[2414646]|0;gGz(b|0,0,(c[2411624]|0)-b|0);a[14113032]=0;c[2443684]=0;c[2443682]=0;c[3525088]=0;c[3525080]=0;c[3526962]=0;c[3526954]=0;c[3528692]=0;c[2444174]=0;c[3528600]=(c[2420386]|0)==2?5838072:727264;c[2420364]=0;c[2405088]=0;a[9624032]=0;a[9547368]=1;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];b=c[3532592]|0;if((b|0)!=0){gGC(9104152,b|0,280)|0}c[2113054]=c[2113060]}RI();b=c[2394]|0;d=c[14130368+(b<<2)>>2]|0;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[8452240+(b<<2)>>2]=c[2113054];c[2394]=-1;b=c[2439330]|0;d=(b|0)==0;if(!d){e=b;gGC(9706056,e|0,76)|0}e=c[2438118]|0;c[2433530]=e;f=c[3528484]|0;c[2076596]=f;g=c[2417276]|0;c[3541536]=g;c[1836236]=0;gGz(9706056,0,76);if(!d){d=b;gGC(d|0,9706056,76)|0}c[2438118]=e;c[3528484]=f;c[2417276]=g;c[1836236]=-1;c[2113156]=0;a[9628264]=0;c[2407033]=0;g=c[3541206]|0;c[3541190]=g;c[3541198]=g;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=g+256;c[3541199]=g+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=g+512;c[3541200]=g+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=g+768;c[3541201]=g+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;if((c[2420386]|0)==1){mx(0);c[2113222]=0;return}c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){i=0}else{c[2113222]=0;return}do{lN(i);mB(i);i=i+1|0;}while((i|0)<(c[2385508]|0));c[2113222]=0;return}function eih(b,c){b=b|0;c=c|0;a[9706117]=c&1;return}function eii(a){a=a|0;var b=0,d=0;b=(c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,4e6,0)|0;return a|0}function eij(){return+(+((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)/4.0e6)}function eik(b){b=b|0;var d=0,e=0;d=b&65535;if((d|0)==49153){e=~a[9543144]}else if((d|0)==49152){e=a[9628112]|0}else if((d|0)==49154){e=c[2113156]&255}else{e=0}return e|0}function eil(b,e){b=b|0;e=e|0;var f=0,g=0;f=b&65535;if((f|0)==49155){c[2420358]=e&255;return}else if((f|0)==49154){Uv(0,e);return}else{if((b+28672&65535)>=512){return}b=f-36864|0;f=c[2438642]|0;a[f+b|0]=e;e=((d[f+(b&-2)|0]|0)<<8|(d[f+(b|1)|0]|0))&65535;f=e>>>8&15;g=e>>>4&15;c[(c[3527066]|0)+(((b|0)/2|0)<<2)>>2]=(g<<4|g)<<3&2016|(e<<4|e&8)>>>3&31|(f<<4|f)<<8&63488;return}}function eim(){var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;e=i;i=i+240|0;f=e|0;g=e+112|0;h=e+120|0;j=e+232|0;c[2426702]=0;c[2407024]=0;c[3541206]=65536;c[2405638]=327680;c[2407026]=327680;c[2438646]=335872;c[2438648]=337920;c[2438642]=339968;c[2411622]=340480;c[2385782]=340480;c[3527066]=1389056;k=0;while(1){if((k|0)>=1024){break}l=9638528+(k<<2)|0;if((c[l>>2]|0)==0){m=59150;break}else{k=k+1|0}}do{if((m|0)==59150){k=gGq(1390080)|0;c[l>>2]=k;if((k|0)==0){break}c[2426702]=k;gGz(k|0,0,1390080);c[2407024]=k;c[3541206]=k+65536;n=k+327680|0;c[2405638]=n;c[2407026]=n;c[2438646]=k+335872;c[2438648]=k+337920;c[2438642]=k+339968;n=k+340480|0;c[2411622]=n;c[2385782]=n;c[3527066]=k+1389056;c[2414162]=k+1390080;k=0;while(1){if((k|0)>=1024){o=0;break}p=9638528+(k<<2)|0;if((c[p>>2]|0)==0){m=59155;break}else{k=k+1|0}}do{if((m|0)==59155){k=gGq(524288)|0;c[p>>2]=k;if((k|0)==0){o=0;break}gGz(k|0,0,524288);o=k}}while(0);c[3527064]=o;k=c[2407024]|0;if((c[3542200]|0)==0){q=1;i=e;return q|0}n=h+108|0;c[n>>2]=0;r=h+100|0;c[r>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](h,0)|0;do{if((c[n>>2]|0)!=0){s=c[r>>2]|0;c[j>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](j,0,0)|0;if((s|0)<1){q=1;i=e;return q|0}if((gzL(k,0,0)|0)==0){break}else{q=1}i=e;return q|0}}while(0);if((R6(c[3527064]|0,1,2)|0)!=0){q=1;i=e;return q|0}if((R6((c[3527064]|0)+1|0,2,2)|0)!=0){q=1;i=e;return q|0}k=c[3527064]|0;r=c[2385782]|0;n=0;while(1){s=n<<6;gGz(r+s|0,0,64);t=n<<8;u=0;do{v=1<<3-u;w=(c[703416+(u<<2)>>2]|0)+t|0;x=0;do{y=w+(c[1183816+(x<<2)>>2]|0)|0;z=(x<<3)+s|0;A=0;do{B=y+(c[1934976+(A<<2)>>2]|0)|0;if(((d[k+((B|0)/8|0)|0]|0)&128>>>((B&7)>>>0)|0)!=0){B=r+(z+A)|0;a[B]=(d[B]|0|v)&255}A=A+1|0;}while((A|0)<8);x=x+1|0;}while((x|0)<8);u=u+1|0;}while((u|0)<4);u=n+1|0;if((u|0)<16384){n=u}else{C=0;break}}while(1){if((C|0)>=1024){break}D=9638528+(C<<2)|0;if((c[D>>2]|0)==(k|0)){m=59175;break}else{C=C+1|0}}if((m|0)==59175){gGr(k);c[D>>2]=0}c[3527064]=0;n=c[3541206]|0;if((c[3542200]|0)==0){q=1;i=e;return q|0}r=f+108|0;c[r>>2]=0;u=f+100|0;c[u>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,3)|0;do{if((c[r>>2]|0)!=0){s=c[u>>2]|0;c[g>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](g,3,0)|0;if((s|0)<1){q=1;i=e;return q|0}if((gzL(n,0,3)|0)==0){break}else{q=1}i=e;return q|0}}while(0);fwR(0);n=c[2439330]|0;u=(n|0)==0;if(!u){r=n;gGC(9706056,r|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];r=c[3528484]|0;c[2076596]=r;k=c[2417276]|0;c[3541536]=k;c[1836236]=0;s=c[2407024]|0;t=0;x=0;while(1){c[n+76+(x<<2)>>2]=s+(x<<8);v=t+1&65535;if((v&65535)>127){E=0;F=0;break}else{t=v;x=v&65535}}while(1){x=s+(F<<8)|0;c[n+76+(F+512<<2)>>2]=x;c[n+76+(F+768<<2)>>2]=x;x=E+1&65535;if((x&65535)>127){break}else{E=x;F=x&65535}}s=c[2438646]|0;c[n+588>>2]=s;x=s+256|0;c[n+592>>2]=x;t=s+512|0;c[n+596>>2]=t;v=s+768|0;c[n+600>>2]=v;w=s+1024|0;c[n+604>>2]=w;A=s+1280|0;c[n+608>>2]=A;z=s+1536|0;c[n+612>>2]=z;y=s+1792|0;c[n+616>>2]=y;c[n+1612>>2]=s;c[n+1616>>2]=x;c[n+1620>>2]=t;c[n+1624>>2]=v;c[n+1628>>2]=w;c[n+1632>>2]=A;c[n+1636>>2]=z;c[n+1640>>2]=y;c[n+2636>>2]=s;c[n+3660>>2]=s;c[n+2640>>2]=x;c[n+3664>>2]=x;c[n+2644>>2]=t;c[n+3668>>2]=t;c[n+2648>>2]=v;c[n+3672>>2]=v;c[n+2652>>2]=w;c[n+3676>>2]=w;c[n+2656>>2]=A;c[n+3680>>2]=A;c[n+2660>>2]=z;c[n+3684>>2]=z;c[n+2664>>2]=y;c[n+3688>>2]=y;y=c[2438648]|0;c[n+620>>2]=y;z=y+256|0;c[n+624>>2]=z;A=y+512|0;c[n+628>>2]=A;w=y+768|0;c[n+632>>2]=w;v=y+1024|0;c[n+636>>2]=v;t=y+1280|0;c[n+640>>2]=t;x=y+1536|0;c[n+644>>2]=x;s=y+1792|0;c[n+648>>2]=s;c[n+1644>>2]=y;c[n+1648>>2]=z;c[n+1652>>2]=A;c[n+1656>>2]=w;c[n+1660>>2]=v;c[n+1664>>2]=t;c[n+1668>>2]=x;c[n+1672>>2]=s;c[n+2668>>2]=y;c[n+3692>>2]=y;c[n+2672>>2]=z;c[n+3696>>2]=z;c[n+2676>>2]=A;c[n+3700>>2]=A;c[n+2680>>2]=w;c[n+3704>>2]=w;c[n+2684>>2]=v;c[n+3708>>2]=v;c[n+2688>>2]=t;c[n+3712>>2]=t;c[n+2692>>2]=x;c[n+3716>>2]=x;c[n+2696>>2]=s;c[n+3720>>2]=s;s=c[2407026]|0;x=224;t=224;while(1){c[n+76+(t<<2)>>2]=s+((t<<8)-57344);v=x+1&65535;if((v&65535)>255){G=224;H=224;break}else{x=v;t=v&65535}}while(1){c[n+76+(H+256<<2)>>2]=s+((H<<8)-57344);t=G+1&65535;if((t&65535)>255){I=224;J=224;break}else{G=t;H=t&65535}}while(1){t=s+((J<<8)-57344)|0;c[n+76+(J+512<<2)>>2]=t;c[n+76+(J+768<<2)>>2]=t;t=I+1&65535;if((t&65535)>255){break}else{I=t;J=t&65535}}c[n+4180>>2]=1888;c[n+4184>>2]=1878;if(!u){s=n;gGC(s|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=r;c[2417276]=k;c[1836236]=-1;Ux(0,8e3,0);c[2407030]=256;c[2407068]=3;s=c[642608+(c[2436]<<2)>>2]|0;t=c[s+128>>2]|0;if((c[s+52>>2]&4|0)==0){c[2113068]=t;x=c[s+132>>2]|0;c[2113070]=x;c[2443814]=t;c[2440436]=x;K=t;L=x}else{c[2113070]=t;x=c[s+132>>2]|0;c[2113068]=x;c[2440436]=t;c[2443814]=x;K=x;L=t}t=ag(K<<1,L)|0;x=gGq(t)|0;c[2112926]=x;if((x|0)!=0){gGz(x|0,0,t|0)}c[2420358]=0;t=c[2439330]|0;x=(t|0)==0;if(!x){s=t;gGC(9706056,s|0,76)|0}s=c[2438118]|0;c[2433530]=s;v=c[3528484]|0;c[2076596]=v;w=c[2417276]|0;c[3541536]=w;c[1836236]=0;gGz(9706056,0,76);if(!x){x=t;gGC(x|0,9706056,76)|0}c[2438118]=s;c[3528484]=v;c[2417276]=w;c[1836236]=-1;c[2113156]=0;a[9628264]=0;c[2407033]=0;w=c[3541206]|0;c[3541190]=w;c[3541198]=w;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=w+256;c[3541199]=w+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=w+512;c[3541200]=w+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=w+768;c[3541201]=w+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;q=0;i=e;return q|0}}while(0);c[2426702]=0;q=1;i=e;return q|0}function ein(){var a=0,b=0,d=0,e=0;Uw(0);fwZ();c[2113070]=0;c[2113068]=0;a=c[2112926]|0;if((a|0)!=0){gGr(a);c[2112926]=0}a=c[2426702]|0;b=0;while(1){if((b|0)>=1024){d=59220;break}e=9638528+(b<<2)|0;if((c[e>>2]|0)==(a|0)){break}else{b=b+1|0}}if((d|0)==59220){c[2426702]=0;c[2420358]=0;return 0}gGr(a);c[e>>2]=0;c[2426702]=0;c[2420358]=0;return 0}function eio(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if((a[9543136]|0)==0){e=c[2439330]|0}else{c[2420358]=0;f=c[2439330]|0;g=(f|0)==0;if(!g){h=f;gGC(9706056,h|0,76)|0}h=c[2438118]|0;c[2433530]=h;i=c[3528484]|0;c[2076596]=i;j=c[2417276]|0;c[3541536]=j;c[1836236]=0;gGz(9706056,0,76);if(!g){g=f;gGC(g|0,9706056,76)|0}c[2438118]=h;c[3528484]=i;c[2417276]=j;c[1836236]=-1;c[2113156]=0;a[9628264]=0;c[2407033]=0;j=c[3541206]|0;c[3541190]=j;c[3541198]=j;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=j+256;c[3541199]=j+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=j+512;c[3541200]=j+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=j+768;c[3541201]=j+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;e=f}f=a[9754578]<<2&4;j=a[9754579]<<3&8;i=a[9754577]<<1&2|a[9754576]&1|f|j|a[9754580]<<4&16|a[9754581]<<5&32|a[9754582]<<6&64|a[9754583]<<7;h=(j|f)<<24>>24==12?i&-13:i;a[9543144]=(h&48)==48?h&-49:h;if((e|0)!=0){h=e;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;h=c[2438118]|0;c[2433530]=h;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;if((a[e+4188|0]|0)==0){e=gfc(133333)|0;k=(c[2433530]|0)+e|0}else{k=h+133333|0}c[2433530]=k;a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0;k=c[1836236]|0;h=c[9757320+(k<<2)>>2]|0;if((h|0)!=0){e=h;gGC(e|0,9706056,76)|0}c[9752472+(k<<2)>>2]=c[2433530];c[14113936+(k<<2)>>2]=c[2076596];c[9669104+(k<<2)>>2]=c[3541536];c[1836236]=-1;if((c[2112968]|0)!=0){k=c[2438648]|0;e=c[2112926]|0;h=c[2385782]|0;i=0;f=0;while(1){j=i<<3;g=j-16|0;if((j-24|0)>>>0<208){j=0;l=f;while(1){m=l<<1;n=d[k+m|0]|0;o=n<<8;p=n>>>4;n=o&3840|d[k+(m|1)|0];if((o&3584|0)==3584){q=c[2420358]<<9|n&511}else{q=n}n=j<<3;if((n-8|0)>>>0<240){Si(e,q,n,g,p,4,0,h)}else{Sj(e,q,n,g,p,4,0,h)}p=j+1|0;if((p|0)<32){j=p;l=l+1|0}else{break}}}else{l=0;j=f;while(1){p=j<<1;n=d[k+p|0]|0;o=n<<8;m=o&3840|d[k+(p|1)|0];if((o&3584|0)==3584){r=c[2420358]<<9|m&511}else{r=m}Sj(e,r,l<<3,g,n>>>4,4,0,h);n=l+1|0;if((n|0)<32){l=n;j=j+1|0}else{break}}}j=i+1|0;if((j|0)<32){i=j;f=f+32|0}else{break}}f=c[2438646]|0;i=0;r=0;while(1){k=i<<3;q=k-16|0;if((k-24|0)>>>0<208){k=0;j=r;while(1){l=j<<1;g=d[f+l|0]|0;n=g>>>4;m=g<<8&3840|d[f+(l|1)|0];l=k<<3;if((l-8|0)>>>0<240){Sq(e,m,l,q,n,4,0,0,h)}else{Sr(e,m,l,q,n,4,0,0,h)}n=k+1|0;if((n|0)<32){k=n;j=j+1|0}else{break}}}else{j=0;k=r;while(1){n=k<<1;l=d[f+n|0]|0;Sr(e,l<<8&3840|d[f+(n|1)|0],j<<3,q,l>>>4,4,0,0,h);l=j+1|0;if((l|0)<32){j=l;k=k+1|0}else{break}}}k=i+1|0;if((k|0)<32){i=k;r=r+32|0}else{break}}R8(c[3527066]|0)}r=c[2112964]|0;if((r|0)==0){return 0}Uu(0,r,a[9688]|0?534:0);return 0}function eip(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>3){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7166972+(b*112|0)>>2];c[a+104>>2]=c[7166976+(b*112|0)>>2];c[a+108>>2]=c[7166980+(b*112|0)>>2];d=0;return d|0}function eiq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<4&(d|0)==0)){e=1;return e|0}c[a>>2]=7166872+(b*112|0);e=0;return e|0}function eir(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6208024+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eis(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7167320+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eit(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;d=i;i=i+64|0;e=d|0;f=d+16|0;g=d+32|0;h=d+48|0;if((b|0)!=0){c[b>>2]=10562}if((a&32|0)!=0){b=h;gGz(b|0,0,12);j=c[2405638]|0;k=h|0;c[k>>2]=j;l=h+4|0;c[l>>2]=(c[2411622]|0)-j;j=h+12|0;c[j>>2]=162152;m=c[2076592]|0;gj[m&4095](h)|0;gGz(b|0,0,12);c[k>>2]=c[3527066];c[l>>2]=1024;c[j>>2]=426800;j=c[2076592]|0;gj[j&4095](h)|0}if((a&64|0)==0){i=d;return 0}fw$(a);Ut(0);gGz(g|0,0,12);c[g>>2]=9543144;c[g+4>>2]=1;c[g+12>>2]=414472;gj[c[2076592]&4095](g)|0;gGz(f|0,0,12);c[f>>2]=9628112;c[f+4>>2]=1;c[f+12>>2]=403488;gj[c[2076592]&4095](f)|0;gGz(e|0,0,12);c[e>>2]=9681432;c[e+4>>2]=4;c[e+12>>2]=392256;gj[c[2076592]&4095](e)|0;i=d;return 0}function eiu(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>3){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6828508+(b*112|0)>>2];c[a+104>>2]=c[6828512+(b*112|0)>>2];c[a+108>>2]=c[6828516+(b*112|0)>>2];d=0;return d|0}function eiv(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<4&(d|0)==0)){e=1;return e|0}c[a>>2]=6828408+(b*112|0);e=0;return e|0}function eiw(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6828856+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eix(e,f){e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;if((e-16773152|0)>>>0<32){b[(c[3530974]|0)+((e>>>1&15)<<1)>>1]=f;return}if((e&268427264|0)!=13631488){return}g=e&8190;b[(c[3529426]|0)+g>>1]=f;e=(f&65535)>>>12<<4;h=(c[3530584]|0)+(((d[c[2394686]|0]|0)<<12|f&4095)<<8)|0;f=(c[2406552]|0)+((g>>>7<<14|g<<3&1008)<<1)|0;g=0;while(1){i=h;j=0;while(1){k=a[i]|0;b[f+(j<<1)>>1]=e|(k<<24>>24==15?-257:k&255)|256;k=j+1|0;if((k|0)<16){i=i+1|0;j=k}else{break}}j=g+1|0;if((j|0)<16){h=h+16|0;f=f+2048|0;g=j}else{break}}return}function eiy(e,f){e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((e&268427264|0)==13631488){g=c[3529426]|0;a[g+(e&8191^1)|0]=f;h=e>>>1&4095;i=b[g+(h<<1)>>1]|0;g=(i&65535)>>>12<<4;j=(c[3530584]|0)+((d[c[2394686]|0]<<12|i&4095)<<8)|0;i=(c[2406552]|0)+((h>>>6<<14|h<<4&1008)<<1)|0;h=0;while(1){k=j;l=0;while(1){m=a[k]|0;b[i+(l<<1)>>1]=g|(m<<24>>24==15?-257:m&255)|256;m=l+1|0;if((m|0)<16){k=k+1|0;l=m}else{break}}l=h+1|0;if((l|0)<16){j=j+16|0;i=i+2048|0;h=l}else{break}}return}if((e|0)==16773129){a[c[2433508]|0]=1;a[c[3528256]|0]=f;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12;return}else if((e|0)==16760833){a[c[2394686]|0]=f;return}else if((e|0)==16773121){a[c[2440612]|0]=f&-33;a[c[3528690]|0]=f&32;return}else{return}}function eiz(a){a=a|0;return 0}function eiA(d){d=d|0;var f=0;switch(d|0){case 16773121:{f=b[4775200]&255;break};case 16773135:{f=b[4775202]&255;break};case 16773126:{f=a[c[2433508]|0]<<7|a[9635003];break};case 16773120:{f=(e[4775200]|0)>>>8&255;break};case 16773123:{f=b[4775201]&255;break};case 16773122:{f=(e[4775201]|0)>>>8&255;break};case 16773125:{f=a[9635e3]|0;break};case 16773131:{f=a[9635002]|0;break};case 16773124:{f=a[9635001]|0;break};default:{f=0}}return f|0}function eiB(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=b&65535;switch(e&255|0){case 4:{a[c[2433508]|0]=0;return};case 8:case 9:case 10:case 11:{l7(e&3,d);return};case 0:{a[c[3528520]|0]=d&3;e=c[2385910]|0;b=c[9757320+(c[1836236]<<2)>>2]|0;f=((d&255)<<15&98304)-32768|0;d=128;g=128;while(1){c[b+76+(g<<2)>>2]=e+(f+(g<<8));h=d+1&65535;if((h&65535)>255){i=128;j=128;break}else{d=h;g=h&65535}}while(1){g=e+(f+(j<<8))|0;c[b+76+(j+512<<2)>>2]=g;c[b+76+(j+768<<2)>>2]=g;g=i+1&65535;if((g&65535)>255){break}else{i=g;j=g&65535}}return};default:{return}}}function eiC(b){b=b|0;var d=0,e=0;d=b&65535;switch(d&255|0){case 4:{e=a[c[3528256]|0]|0;break};case 8:case 9:case 10:case 11:{e=l8(d&3)|0;break};default:{e=0}}return e|0}function eiD(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2994900+(b*112|0)>>2];c[a+104>>2]=c[2994904+(b*112|0)>>2];c[a+108>>2]=c[2994908+(b*112|0)>>2];d=0;return d|0}function eiE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=2994800+(b*112|0);e=0;return e|0}function eiF(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>33){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1288680+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eiG(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>83){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4139960+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eiH(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0;e=i;i=i+1448|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;B=e+1200|0;C=e+1312|0;D=e+1320|0;E=e+1432|0;F=e+1440|0;c[2414942]=0;c[2388134]=0;c[2385910]=3145728;c[3530820]=3276800;c[3530584]=4325376;c[3530420]=12713984;c[2386634]=21102592;c[3529980]=23199744;c[2406552]=23203844;c[2414644]=25300996;c[2388262]=25300996;c[2387174]=25366532;c[3529426]=25370628;c[3529404]=25378820;c[3529636]=25382916;c[3529610]=25391108;c[3527272]=25456644;c[3527268]=25464836;c[3527270]=25530372;c[3527266]=25538564;c[2386064]=25604100;c[3528520]=25606148;c[2394686]=25606149;c[3528256]=25606150;c[3528690]=25606151;c[2440612]=25606152;c[2433508]=25606153;c[3530974]=25606154;c[2411620]=25606186;G=0;while(1){if((G|0)>=1024){break}H=9638528+(G<<2)|0;if((c[H>>2]|0)==0){I=59400;break}else{G=G+1|0}}do{if((I|0)==59400){G=gGq(25606186)|0;c[H>>2]=G;if((G|0)==0){break}c[2414942]=G;gGz(G|0,0,25606186);c[2388134]=G;c[2385910]=G+3145728;c[3530820]=G+3276800;c[3530584]=G+4325376;c[3530420]=G+12713984;c[2386634]=G+21102592;c[3529980]=G+23199744;c[2406552]=G+23203844;J=G+25300996|0;c[2414644]=J;c[2388262]=J;c[2387174]=G+25366532;c[3529426]=G+25370628;c[3529404]=G+25378820;c[3529636]=G+25382916;c[3529610]=G+25391108;c[3527272]=G+25456644;c[3527268]=G+25464836;c[3527270]=G+25530372;c[3527266]=G+25538564;c[2386064]=G+25604100;c[3528520]=G+25606148;c[2394686]=G+25606149;c[3528256]=G+25606150;c[3528690]=G+25606151;c[2440612]=G+25606152;c[2433508]=G+25606153;c[3530974]=G+25606154;J=G+25606186|0;c[2411620]=J;c[2414160]=J;if((c[3542200]|0)==0){K=1;i=e;return K|0}J=D+108|0;c[J>>2]=0;L=D+100|0;c[L>>2]=0;M=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[M&16383](D,0)|0;do{if((c[J>>2]|0)!=0){M=c[L>>2]|0;c[E>>2]=9534384;N=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[N&16383](E,0,0)|0;if((M|0)<1){K=1;i=e;return K|0}if((gzL(G,0,0)|0)==0){break}else{K=1}i=e;return K|0}}while(0);G=(c[2388134]|0)+1048576|0;if((c[3542200]|0)==0){K=1;i=e;return K|0}L=B+108|0;c[L>>2]=0;J=B+100|0;c[J>>2]=0;M=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[M&16383](B,1)|0;do{if((c[L>>2]|0)!=0){M=c[J>>2]|0;c[C>>2]=9534384;N=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[N&16383](C,1,0)|0;if((M|0)<1){K=1;i=e;return K|0}if((gzL(G,0,1)|0)==0){break}else{K=1}i=e;return K|0}}while(0);G=(c[2388134]|0)+2097152|0;if((c[3542200]|0)==0){K=1;i=e;return K|0}J=z+108|0;c[J>>2]=0;L=z+100|0;c[L>>2]=0;M=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[M&16383](z,2)|0;do{if((c[J>>2]|0)!=0){M=c[L>>2]|0;c[A>>2]=9534384;N=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[N&16383](A,2,0)|0;if((M|0)<1){K=1;i=e;return K|0}if((gzL(G,0,2)|0)==0){break}else{K=1}i=e;return K|0}}while(0);G=c[2385910]|0;if((c[3542200]|0)==0){K=1;i=e;return K|0}L=x+108|0;c[L>>2]=0;J=x+100|0;c[J>>2]=0;M=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[M&16383](x,3)|0;do{if((c[L>>2]|0)!=0){M=c[J>>2]|0;c[y>>2]=9534384;N=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[N&16383](y,3,0)|0;if((M|0)<1){K=1;i=e;return K|0}if((gzL(G,0,3)|0)==0){break}else{K=1}i=e;return K|0}}while(0);G=c[3530820]|0;if((c[3542200]|0)==0){K=1;i=e;return K|0}J=v+108|0;c[J>>2]=0;L=v+100|0;c[L>>2]=0;M=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[M&16383](v,4)|0;do{if((c[J>>2]|0)!=0){M=c[L>>2]|0;c[w>>2]=9534384;N=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[N&16383](w,4,0)|0;if((M|0)<1){K=1;i=e;return K|0}if((gzL(G,0,4)|0)==0){break}else{K=1}i=e;return K|0}}while(0);G=c[3530584]|0;if((c[3542200]|0)==0){K=1;i=e;return K|0}L=t+108|0;c[L>>2]=0;J=t+100|0;c[J>>2]=0;M=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[M&16383](t,5)|0;do{if((c[L>>2]|0)!=0){M=c[J>>2]|0;c[u>>2]=9534384;N=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[N&16383](u,5,0)|0;if((M|0)<1){K=1;i=e;return K|0}if((gzL(G,0,5)|0)==0){break}else{K=1}i=e;return K|0}}while(0);G=(c[3530584]|0)+1048576|0;if((c[3542200]|0)==0){K=1;i=e;return K|0}J=r+108|0;c[J>>2]=0;L=r+100|0;c[L>>2]=0;M=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[M&16383](r,6)|0;do{if((c[J>>2]|0)!=0){M=c[L>>2]|0;c[s>>2]=9534384;N=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[N&16383](s,6,0)|0;if((M|0)<1){K=1;i=e;return K|0}if((gzL(G,0,6)|0)==0){break}else{K=1}i=e;return K|0}}while(0);G=(c[3530584]|0)+2097152|0;if((c[3542200]|0)==0){K=1;i=e;return K|0}L=p+108|0;c[L>>2]=0;J=p+100|0;c[J>>2]=0;M=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[M&16383](p,7)|0;do{if((c[L>>2]|0)!=0){M=c[J>>2]|0;c[q>>2]=9534384;N=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[N&16383](q,7,0)|0;if((M|0)<1){K=1;i=e;return K|0}if((gzL(G,0,7)|0)==0){break}else{K=1}i=e;return K|0}}while(0);G=c[3530420]|0;if((c[3542200]|0)==0){K=1;i=e;return K|0}J=n+108|0;c[J>>2]=0;L=n+100|0;c[L>>2]=0;M=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[M&16383](n,8)|0;do{if((c[J>>2]|0)!=0){M=c[L>>2]|0;c[o>>2]=9534384;N=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[N&16383](o,8,0)|0;if((M|0)<1){K=1;i=e;return K|0}if((gzL(G,0,8)|0)==0){break}else{K=1}i=e;return K|0}}while(0);G=(c[3530420]|0)+2097152|0;if((c[3542200]|0)==0){K=1;i=e;return K|0}L=l+108|0;c[L>>2]=0;J=l+100|0;c[J>>2]=0;M=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[M&16383](l,9)|0;do{if((c[L>>2]|0)!=0){M=c[J>>2]|0;c[m>>2]=9534384;N=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[N&16383](m,9,0)|0;if((M|0)<1){K=1;i=e;return K|0}if((gzL(G,0,9)|0)==0){break}else{K=1}i=e;return K|0}}while(0);G=c[2386634]|0;if((c[3542200]|0)==0){K=1;i=e;return K|0}J=j+108|0;c[J>>2]=0;L=j+100|0;c[L>>2]=0;M=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[M&16383](j,10)|0;do{if((c[J>>2]|0)!=0){M=c[L>>2]|0;c[k>>2]=9534384;N=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[N&16383](k,10,0)|0;if((M|0)<1){K=1;i=e;return K|0}if((gzL(G,0,10)|0)==0){break}else{K=1}i=e;return K|0}}while(0);G=(c[2386634]|0)+1048576|0;if((c[3542200]|0)==0){K=1;i=e;return K|0}L=f+108|0;c[L>>2]=0;J=f+100|0;c[J>>2]=0;M=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[M&16383](f,11)|0;do{if((c[L>>2]|0)==0){O=0}else{M=c[J>>2]|0;c[g>>2]=9534384;N=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[N&16383](g,11,0)|0;if((M|0)<1){K=1;i=e;return K|0}if((gzL(G,0,11)|0)==0){O=0;break}else{K=1}i=e;return K|0}}while(0);while(1){if((O|0)>=1024){break}P=9638528+(O<<2)|0;if((c[P>>2]|0)==0){I=59452;break}else{O=O+1|0}}L78925:do{if((I|0)==59452){G=gGq(4194304)|0;c[P>>2]=G;if((G|0)==0){break}gGz(G|0,0,4194304);J=c[3530584]|0;L=0;while(1){M=a[J+L|0]|0;a[G+(L^1)|0]=M<<4|(M&255)>>>4;M=L+1|0;if((M|0)<3145728){L=M}else{Q=0;break}}do{L=Q<<8;gGz(J+L|0,0,256);M=Q<<10;N=0;do{R=1<<3-N;S=(c[613168+(N<<2)>>2]|0)+M|0;T=0;do{U=S+(c[611904+(T<<2)>>2]|0)|0;V=(T<<4)+L|0;W=0;do{X=U+(c[612512+(W<<2)>>2]|0)|0;if(((d[G+((X|0)/8|0)|0]|0)&128>>>((X&7)>>>0)|0)!=0){X=J+(V+W)|0;a[X]=(d[X]|0|R)&255}W=W+1|0;}while((W|0)<16);T=T+1|0;}while((T|0)<16);N=N+1|0;}while((N|0)<4);Q=Q+1|0;}while((Q|0)<24576);J=c[3530420]|0;gGC(G|0,J|0,4194304)|0;N=0;while(1){L=N<<8;gGz(J+L|0,0,256);M=N<<10;T=0;do{R=1<<3-T;S=(c[613168+(T<<2)>>2]|0)+M|0;W=0;do{V=S+(c[611904+(W<<2)>>2]|0)|0;U=(W<<4)+L|0;X=0;do{Y=V+(c[612512+(X<<2)>>2]|0)|0;if(((d[G+((Y|0)/8|0)|0]|0)&128>>>((Y&7)>>>0)|0)!=0){Y=J+(U+X)|0;a[Y]=(d[Y]|0|R)&255}X=X+1|0;}while((X|0)<16);W=W+1|0;}while((W|0)<16);T=T+1|0;}while((T|0)<4);T=N+1|0;if((T|0)<32768){N=T}else{Z=0;break}}while(1){if((Z|0)>=1024){break L78925}_=9638528+(Z<<2)|0;if((c[_>>2]|0)==(G|0)){break}else{Z=Z+1|0}}gGr(G);c[_>>2]=0}}while(0);fxU(0,425984);if((c[2394]|0)==0){$=c[2112932]|0}else{c[2394]=0;N=c[3532596]|0;c[2112932]=N;J=c[3532592]|0;if((J|0)!=0){gGC(9104152,J|0,280)|0}c[2113054]=c[2113060];$=N}N=c[2388134]|0;J=$|0;T=0;while(1){L=N+T|0;c[J>>2]=L;c[J+131072>>2]=L;L=T+1024|0;if(L>>>0>524287){break}else{J=J+4|0;T=L}}T=$+12288|0;J=3145728;while(1){L=N+(J-2097152)|0;c[T>>2]=L;c[T+131072>>2]=L;L=J+1024|0;if(L>>>0>4194303){break}else{T=T+4|0;J=L}}J=$+16384|0;T=4194304;while(1){L=N+(T-2097152)|0;c[J>>2]=L;c[J+131072>>2]=L;L=T+1024|0;if(L>>>0>5242879){break}else{J=J+4|0;T=L}}T=$+20480|0;J=5242880;while(1){L=N+(J-3145728)|0;c[T>>2]=L;c[T+131072>>2]=L;L=J+1024|0;if(L>>>0>6291455){break}else{T=T+4|0;J=L}}J=c[3529610]|0;T=$+40960|0;N=10485760;while(1){L=J+(N-10485760)|0;c[T>>2]=L;c[T+65536>>2]=L;c[T+131072>>2]=L;L=N+1024|0;if(L>>>0>10551295){break}else{T=T+4|0;N=L}}N=c[3529426]|0;c[$+53248>>2]=N;c[$+184320>>2]=N;T=N+1024|0;c[$+53252>>2]=T;c[$+184324>>2]=T;T=N+2048|0;c[$+53256>>2]=T;c[$+184328>>2]=T;T=N+3072|0;c[$+53260>>2]=T;c[$+184332>>2]=T;T=N+4096|0;c[$+53264>>2]=T;c[$+184336>>2]=T;T=N+5120|0;c[$+53268>>2]=T;c[$+184340>>2]=T;T=N+6144|0;c[$+53272>>2]=T;c[$+184344>>2]=T;T=N+7168|0;c[$+53276>>2]=T;c[$+184348>>2]=T;T=c[3529636]|0;c[$+57344>>2]=T;c[$+122880>>2]=T;c[$+188416>>2]=T;N=T+1024|0;c[$+57348>>2]=N;c[$+122884>>2]=N;c[$+188420>>2]=N;N=T+2048|0;c[$+57352>>2]=N;c[$+122888>>2]=N;c[$+188424>>2]=N;N=T+3072|0;c[$+57356>>2]=N;c[$+122892>>2]=N;c[$+188428>>2]=N;N=T+4096|0;c[$+57360>>2]=N;c[$+122896>>2]=N;c[$+188432>>2]=N;N=T+5120|0;c[$+57364>>2]=N;c[$+122900>>2]=N;c[$+188436>>2]=N;N=T+6144|0;c[$+57368>>2]=N;c[$+122904>>2]=N;c[$+188440>>2]=N;N=T+7168|0;c[$+57372>>2]=N;c[$+122908>>2]=N;c[$+188444>>2]=N;N=c[2388262]|0;T=$+65024|0;J=16646144;while(1){L=N+(J-16646144)|0;c[T>>2]=L;c[T+65536>>2]=L;c[T+131072>>2]=L;L=J+1024|0;if(L>>>0>16711679){break}else{T=T+4|0;J=L}}J=c[3529404]|0;c[$+65488>>2]=J;c[$+131024>>2]=J;c[$+196560>>2]=J;T=J+1024|0;c[$+65492>>2]=T;c[$+131028>>2]=T;c[$+196564>>2]=T;T=J+2048|0;c[$+65496>>2]=T;c[$+131032>>2]=T;c[$+196568>>2]=T;T=J+3072|0;c[$+65500>>2]=T;c[$+131036>>2]=T;c[$+196572>>2]=T;T=c[2387174]|0;c[$+65504>>2]=T;c[$+131040>>2]=T;c[$+196576>>2]=T;J=T+1024|0;c[$+65508>>2]=J;c[$+131044>>2]=J;c[$+196580>>2]=J;J=T+2048|0;c[$+65512>>2]=J;c[$+131048>>2]=J;c[$+196584>>2]=J;J=T+3072|0;c[$+65516>>2]=J;c[$+131052>>2]=J;c[$+196588>>2]=J;c[$+196728>>2]=452;c[$+196648>>2]=3030;c[$+196688>>2]=2152;c[$+196608>>2]=344;J=c[3532592]|0;if((J|0)!=0){gGC(J|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);J=c[2439330]|0;T=(J|0)==0;if(!T){N=J;gGC(9706056,N|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];N=c[3528484]|0;c[2076596]=N;L=c[2417276]|0;c[3541536]=L;c[1836236]=0;M=c[2385910]|0;W=0;R=0;while(1){c[J+76+(R<<2)>>2]=M+(R<<8);S=W+1&65535;if((S&65535)>119){aa=0;ab=0;break}else{W=S;R=S&65535}}while(1){R=M+(ab<<8)|0;c[J+76+(ab+512<<2)>>2]=R;c[J+76+(ab+768<<2)>>2]=R;R=aa+1&65535;if((R&65535)>119){break}else{aa=R;ab=R&65535}}R=c[2386064]|0;c[J+556>>2]=R;W=R+256|0;c[J+560>>2]=W;S=R+512|0;c[J+564>>2]=S;X=R+768|0;c[J+568>>2]=X;U=R+1024|0;c[J+572>>2]=U;V=R+1280|0;c[J+576>>2]=V;Y=R+1536|0;c[J+580>>2]=Y;ac=R+1792|0;c[J+584>>2]=ac;c[J+1580>>2]=R;c[J+1584>>2]=W;c[J+1588>>2]=S;c[J+1592>>2]=X;c[J+1596>>2]=U;c[J+1600>>2]=V;c[J+1604>>2]=Y;c[J+1608>>2]=ac;c[J+2604>>2]=R;c[J+3628>>2]=R;c[J+2608>>2]=W;c[J+3632>>2]=W;c[J+2612>>2]=S;c[J+3636>>2]=S;c[J+2616>>2]=X;c[J+3640>>2]=X;c[J+2620>>2]=U;c[J+3644>>2]=U;c[J+2624>>2]=V;c[J+3648>>2]=V;c[J+2628>>2]=Y;c[J+3652>>2]=Y;c[J+2632>>2]=ac;c[J+3656>>2]=ac;ac=128;Y=128;while(1){c[J+76+(Y<<2)>>2]=M+((Y<<8)+32768);V=ac+1&65535;if((V&65535)>255){ad=128;ae=128;break}else{ac=V;Y=V&65535}}while(1){c[J+76+(ae+256<<2)>>2]=M+((ae<<8)+32768);Y=ad+1&65535;if((Y&65535)>255){af=128;ah=128;break}else{ad=Y;ae=Y&65535}}while(1){Y=M+((ah<<8)+32768)|0;c[J+76+(ah+512<<2)>>2]=Y;c[J+76+(ah+768<<2)>>2]=Y;Y=af+1&65535;if((Y&65535)>255){break}else{af=Y;ah=Y&65535}}c[J+4176>>2]=1110;c[J+4172>>2]=3238;if(!T){M=J;gGC(M|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=N;c[2417276]=L;c[1836236]=-1;c[F>>2]=1048576;M=c[2386634]|0;TW(M+1048576|0,F,M,F,3440,2786,136);c[2438228]=4e6;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=511;h[745406]=1.0;c[2436786]=1;h[745405]=1.0;c[2436784]=2;h[745404]=.25;a[3203280]=1;M=c[642608+(c[2436]<<2)>>2]|0;Y=c[M+128>>2]|0;if((c[M+52>>2]&4|0)==0){c[2113068]=Y;ac=c[M+132>>2]|0;c[2113070]=ac;c[2443814]=Y;c[2440436]=ac;ai=Y;aj=ac}else{c[2113070]=Y;ac=c[M+132>>2]|0;c[2113068]=ac;c[2440436]=Y;c[2443814]=ac;ai=ac;aj=Y}Y=ag(ai<<1,aj)|0;ac=gGq(Y)|0;c[2112926]=ac;if((ac|0)!=0){gGz(ac|0,0,Y|0)}a[9624024]=0;Y=c[2414644]|0;gGz(Y|0,0,(c[2411620]|0)-Y|0);gGz(c[2406552]|0,-1|0,2097152);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];Y=c[3532592]|0;if((Y|0)!=0){gGC(9104152,Y|0,280)|0}c[2113054]=c[2113060]}RI();Y=c[2394]|0;ac=c[14130368+(Y<<2)>>2]|0;if((ac|0)!=0){gGC(ac|0,9104152,280)|0}c[8452240+(Y<<2)>>2]=c[2113054];c[2394]=-1;Y=c[2439330]|0;ac=(Y|0)==0;if(!ac){M=Y;gGC(9706056,M|0,76)|0}M=c[2438118]|0;c[2433530]=M;V=c[3528484]|0;c[2076596]=V;U=c[2417276]|0;c[3541536]=U;c[1836236]=0;gGz(9706056,0,76);if(!ac){ac=Y;gGC(ac|0,9706056,76)|0}c[2438118]=M;c[3528484]=V;c[2417276]=U;c[1836236]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;l6(0);K=0;i=e;return K|0}}while(0);c[2414942]=0;K=1;i=e;return K|0}function eiI(){var b=0,d=0,e=0,f=0,g=0;c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}b=c[3541514]|0;if((b|0)!=0){gGr(b|0);c[3541514]=0}c[2113008]=0;c[2076598]=0;c[2383582]=0;c[2438228]=0;c[2433526]=0;c[2406676]=0;c[3528472]=0;b=c[2406698]|0;if((b|0)!=0){gGr(b);c[2406698]=0}b=c[2385412]|0;if((b|0)!=0){gGr(b);c[2385412]=0}a[64232]=0;if((c[2392]|0)>=0){b=0;do{d=14130368+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}d=14130384+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}b=b+1|0;}while((b|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;fwZ();b=c[2414942]|0;d=0;while(1){if((d|0)>=1024){f=59581;break}g=9638528+(d<<2)|0;if((c[g>>2]|0)==(b|0)){break}else{d=d+1|0}}if((f|0)==59581){c[2414942]=0;return 0}gGr(b);c[g>>2]=0;c[2414942]=0;return 0}function eiJ(){var e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;if((a[9624024]|0)!=0){a[9624024]=0;e=c[2414644]|0;gGz(e|0,0,(c[2411620]|0)-e|0);gGz(c[2406552]|0,-1|0,2097152);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060]}RI();e=c[2394]|0;f=c[14130368+(e<<2)>>2]|0;if((f|0)!=0){gGC(f|0,9104152,280)|0}c[8452240+(e<<2)>>2]=c[2113054];c[2394]=-1;e=c[2439330]|0;f=(e|0)==0;if(!f){g=e;gGC(9706056,g|0,76)|0}g=c[2438118]|0;c[2433530]=g;i=c[3528484]|0;c[2076596]=i;j=c[2417276]|0;c[3541536]=j;c[1836236]=0;gGz(9706056,0,76);if(!f){f=e;gGC(f|0,9706056,76)|0}c[2438118]=g;c[3528484]=i;c[2417276]=j;c[1836236]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;l6(0)}j=c[2392]|0;if((j|0)>=0){gGz(8452240,0,((j|0)>0?(j<<2)+4|0:4)|0)}c[2113054]=0;j=c[2385548]|0;if((j|0)>0){gGz(9752472,0,((j|0)>1?j<<2:4)|0)}c[2433530]=0;gGz(9550400,-1|0,12);j=0;i=-1;g=-1;f=-1;do{i=((a[9633224+j|0]&1)<<j^i&65535)&65535;g=((a[9631096+j|0]&1)<<j^g&65535)&65535;f=((a[9629480+j|0]&1)<<j^f&65535)&65535;j=j+1|0;}while((j|0)<16);b[4775200]=i;b[4775201]=g;b[4775202]=f;b[4775203]=d[9635001]<<8|d[9635e3];b[4775204]=d[9635002]|0;b[4775205]=d[9635003]<<8;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060]}f=c[2439330]|0;if((f|0)!=0){g=f;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;c[2113056]=266666;g=RG(266666)|0;c[2113054]=(c[2113054]|0)+g;c[2276108]=-1;c[2113056]=-1;c[8452200+(c[2394]<<2)>>2]=8193;c[2276080]=256;if((c[2276079]|0)>>>0<256){RH(1)}g=c[2438228]|0;f=gGS(-747372544,31788,g,(g|0)<0|0?-1:0)|0;g=f;Sb(66666);f=c[2443830]|0;if((f|0)<1073676288){c[2443830]=f-g}f=c[2443831]|0;if((f|0)<1073676288){c[2443831]=f-g}f=(c[3528512]|0)-g|0;c[3528512]=(f|0)<0?0:f;f=c[2112964]|0;if((f|0)!=0){gg[c[3542118]&4095](f,a[9688]|0?534:0)}f=c[1836236]|0;g=c[9757320+(f<<2)>>2]|0;if((g|0)!=0){i=g;gGC(i|0,9706056,76)|0}c[9752472+(f<<2)>>2]=c[2433530];c[14113936+(f<<2)>>2]=c[2076596];c[9669104+(f<<2)>>2]=c[3541536];c[1836236]=-1;f=c[2394]|0;i=c[14130368+(f<<2)>>2]|0;if((i|0)!=0){gGC(i|0,9104152,280)|0}c[8452240+(f<<2)>>2]=c[2113054];c[2394]=-1;if((c[2112968]|0)==0){k=c[3527270]|0;l=c[3527272]|0;gGC(k|0,l|0,8192)|0;m=c[3529636]|0;gGC(l|0,m|0,8192)|0;n=c[3527266]|0;o=c[3527268]|0;gGC(n|0,o|0,65536)|0;p=c[3529610]|0;gGC(o|0,p|0,65536)|0;return 0}eiK()|0;k=c[3527270]|0;l=c[3527272]|0;gGC(k|0,l|0,8192)|0;m=c[3529636]|0;gGC(l|0,m|0,8192)|0;n=c[3527266]|0;o=c[3527268]|0;gGC(n|0,o|0,65536)|0;p=c[3529610]|0;gGC(o|0,p|0,65536)|0;return 0}function eiK(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;if((a[9547360]|0)!=0){d=c[2387174]|0;e=c[3529980]|0;f=0;do{g=b[d+(f<<1)>>1]|0;c[e+(f<<2)>>2]=((g&65535)>>>5<<3&65535)>>>3&31|((g&255)<<3&255)<<8|(((g&65535)>>>10<<3&255|(g&65535)>>>12&4)&255)<<3&2016;f=f+1|0;}while((f|0)<1024);c[e+4096>>2]=0}e=c[2440612]|0;f=a[e]|0;d=ag(c[2113070]|0,c[2113068]|0)|0;g=(d|0)>0;if((f&4)!=0){if(g){h=c[2112926]|0;i=0;do{b[h+(i<<1)>>1]=1024;i=i+1|0;}while((i|0)<(d|0))}R8(c[3529980]|0);return 0}if(g){g=c[2112926]|0;i=0;do{b[g+(i<<1)>>1]=511;i=i+1|0;}while((i|0)<(d|0));j=a[e]|0}else{j=f}f=j&251;if((f|0)==0){eiO();j=c[3529404]|0;e=c[2112926]|0;d=c[3530820]|0;i=0;do{g=i<<3&504;do{if(g>>>0<=319){h=b[j+(i<<1)>>1]&16383;if((h|0)==0){break}Sq(e,h,g,i>>6<<3,0,4,255,0,d)}}while(0);i=i+1|0;}while((i|0)<1792);eiP()}else if((f|0)==1|(f|0)==2){f=c[3529404]|0;i=c[2112926]|0;d=c[3530820]|0;e=0;do{j=e<<3&504;do{if(j>>>0<=319){g=b[f+(e<<1)>>1]&16383;if((g|0)==0){break}Sq(i,g,j,e>>6<<3,0,4,255,0,d)}}while(0);e=e+1|0;}while((e|0)<1792);eiP();eiO()}R8(c[3529980]|0);return 0}function eiL(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;g=i;i=i+64|0;h=g|0;j=g+16|0;k=g+32|0;l=g+48|0;if((f|0)!=0){c[f>>2]=169730}if((e&32|0)!=0){gGz(l|0,0,12);m=c[2414644]|0;c[l>>2]=m;c[l+4>>2]=(c[2411620]|0)-m;c[l+12>>2]=162152;m=c[2076592]|0;gj[m&4095](l)|0}if((e&64|0)!=0){l=k|0;gGz(j|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){m=k+9|0;k=h;n=h|0;o=h+4|0;p=h+12|0;q=j|0;r=j+4|0;s=j+12|0;t=0;do{gGC(l|0,614896,11)|0;a[m]=t+48&255;u=8452256+(t<<2)|0;gGz(k|0,0,12);c[n>>2]=u;c[o>>2]=4;c[p>>2]=164976;gj[c[2076592]&4095](h)|0;if((c[u>>2]|0)!=0){c[q>>2]=c[14130368+(t<<2)>>2];c[r>>2]=c[8452184+(t<<2)>>2];c[s>>2]=l;u=c[2076592]|0;gj[u&4095](j)|0}t=t+1|0;}while((t|0)<=(c[2392]|0))}fw$(e);T0(e,f)}if((e&2|0)==0){i=g;return 0}e=c[3529426]|0;f=c[2394686]|0;t=c[3530584]|0;j=c[2406552]|0;l=0;do{s=b[e+(l<<1)>>1]|0;r=(s&65535)>>>12<<4;q=t+(((d[f]|0)<<12|s&4095)<<8)|0;s=j+((l>>>6<<14|l<<4&1008)<<1)|0;h=0;while(1){p=q;o=0;while(1){n=a[p]|0;b[s+(o<<1)>>1]=r|(n<<24>>24==15?-257:n&255)|256;n=o+1|0;if((n|0)<16){p=p+1|0;o=n}else{break}}o=h+1|0;if((o|0)<16){q=q+16|0;s=s+2048|0;h=o}else{break}}l=l+1|0;}while((l|0)<4096);l=c[2439330]|0;j=(l|0)==0;if(!j){f=l;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];f=c[3528484]|0;c[2076596]=f;t=c[2417276]|0;c[3541536]=t;c[1836236]=0;e=c[3528520]|0;h=a[e]|0;a[e]=h&3;e=c[2385910]|0;s=((h&255)<<15&98304)-32768|0;h=128;q=128;while(1){c[l+76+(q<<2)>>2]=e+(s+(q<<8));r=h+1&65535;if((r&65535)>255){v=128;w=128;break}else{h=r;q=r&65535}}while(1){q=e+(s+(w<<8))|0;c[l+76+(w+512<<2)>>2]=q;c[l+76+(w+768<<2)>>2]=q;q=v+1&65535;if((q&65535)>255){break}else{v=q;w=q&65535}}if(!j){j=l;gGC(j|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=f;c[2417276]=t;c[1836236]=-1;i=g;return 0}function eiM(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1588364+(b*112|0)>>2];c[a+104>>2]=c[1588368+(b*112|0)>>2];c[a+108>>2]=c[1588372+(b*112|0)>>2];d=0;return d|0}function eiN(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=1588264+(b*112|0);e=0;return e|0}function eiO(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;a=c[3527272]|0;d=c[3527268]|0;f=c[2112926]|0;g=c[3530420]|0;h=0;while(1){i=e[a+(h<<1)>>1]|0;if((i&16384|0)!=0){j=59711;break}k=h+1|0;l=i<<2&4092;i=e[a+((l|1)<<1)>>1]|0;m=i>>>9&7;n=e[a+(l<<1)>>1]|0;o=n>>>9&7;p=e[a+((l|2)<<1)>>1]|0;q=p&16384;r=p&32768;s=b[a+((l|3)<<1)>>1]&32767;l=16-((c[607560+(i>>>12<<2)>>2]|0)/8|0)|0;t=16-((c[607560+(n>>>12<<2)>>2]|0)/8|0)|0;u=(r|0)==0;v=n+16|0;n=i+16|0;i=(p&8447|0)==0?p>>>8<<4&496|512:528;p=l<<12;w=t<<12;x=m+1|0;if((q|0)==0){y=s;z=0;while(1){A=((ag(u?z:o-z|0,t)|0)+v&511)-16|0;B=y;C=0;while(1){D=((ag(C,l)|0)+n&511)-16|0;S2(f,g,b[d+((B&32767)<<1)>>1]&32767,i,15,D,A,0,r,p,w);D=C+1|0;if((D|0)>(m|0)){break}else{B=B+1|0;C=D}}C=z+1|0;if((C|0)>(o|0)){break}else{y=y+x|0;z=C}}}else{if(u){z=s;y=0;while(1){C=((ag(y,t)|0)+v&511)-16|0;B=z;A=0;while(1){D=((ag(m-A|0,l)|0)+n&511)-16|0;S2(f,g,b[d+((B&32767)<<1)>>1]&32767,i,15,D,C,q,0,p,w);D=A+1|0;if((D|0)>(m|0)){break}else{B=B+1|0;A=D}}A=y+1|0;if((A|0)>(o|0)){break}else{z=z+x|0;y=A}}}else{y=s;z=0;while(1){u=((ag(o-z|0,t)|0)+v&511)-16|0;A=y;B=0;while(1){C=((ag(m-B|0,l)|0)+n&511)-16|0;S2(f,g,b[d+((A&32767)<<1)>>1]&32767,i,15,C,u,q,r,p,w);C=B+1|0;if((C|0)>(m|0)){break}else{A=A+1|0;B=C}}B=z+1|0;if((B|0)>(o|0)){break}else{y=y+x|0;z=B}}}}if((k|0)<1024){h=k}else{j=59710;break}}if((j|0)==59711){return}else if((j|0)==59710){return}}function eiP(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;a=c[3530974]|0;d=b[a+4>>1]|0;e=b[a+6>>1]|0;f=b[a+8>>1]|0;g=b[a+10>>1]|0;h=b[a+12>>1]|0;if((h&16384)==0){i=e;j=d}else{i=e<<8;j=d<<8}if((h&64)==0){k=g;l=f}else{k=g<<8;l=f<<8}f=l<<5;g=k<<5;h=j<<5;d=i<<5;e=c[2406552]|0;m=c[2113070]|0;if((m|0)<=0){return}n=c[2113068]|0;o=c[2112926]|0;p=(i*21|0)+(b[a+2>>1]<<8)+(k*48|0)<<5;k=0;i=(j*21|0)+(b[a>>1]<<8)+(l*48|0)<<5;while(1){if((n|0)>0){l=o;a=i;j=p;q=0;while(1){r=b[e+((j>>>16<<10&1047552|a>>>16&1023)<<1)>>1]|0;if(r<<16>>16!=-1){b[l>>1]=r}r=q+1|0;s=l+2|0;if((r|0)<(n|0)){l=s;a=a+f|0;j=j+g|0;q=r}else{t=s;break}}}else{t=o}q=k+1|0;if((q|0)<(m|0)){o=t;p=p+d|0;k=q;i=i+h|0}else{break}}return}function eiQ(b,c){b=b|0;c=c|0;a[9706117]=(c|0)!=0|0;return}function eiR(a){a=a|0;var b=0,d=0;b=(c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,4e6,0)|0;return a|0}function eiS(){return+(+((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)/4.0e6)}function eiT(d,e){d=d|0;e=e|0;switch(d|0){case 8388948:{a[c[2437792]|0]=e&255;return};case 8388876:case 8388878:{b[(c[2408992]|0)+((d>>>1&1|2)<<1)>>1]=e&1023;return};case 8388884:case 8388886:{b[(c[2408992]|0)+((d>>>1&1)<<1)>>1]=e&1023;return};default:{return}}}function eiU(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0;if((b|0)==8388992|(b|0)==8388993){e=d&3;if((c[2385296]|0)==(e|0)){return}c[2385296]=e;f=c[2386632]|0;g=f+131072|0;h=f+((e<<17)+262144)|0;gGC(g|0,h|0,131072)|0;return}else if((b|0)==8389e3|(b|0)==8389001){if(!(a[7045216]|0)){Uv(0,d);return}if(d<<24>>24==58){return}a[c[3528254]|0]=d;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;return}else{return}}function eiV(a){a=a|0;var c=0;if((a|0)==8388608){c=b[4775196]|0}else if((a|0)==8388632){c=b[4775197]|0}else{c=0}return c|0}function eiW(b){b=b|0;var d=0;switch(b|0){case 8388608:case 8388609:{d=(e[4775196]|0)>>>((b<<3&8^8)>>>0)&255;break};case 8389e3:case 8389001:{d=c[2113156]&255;break};case 8388634:case 8388635:{d=a[9634992]|0;break};case 8388632:case 8388633:{d=(e[4775197]|0)>>>((b<<3&8^8)>>>0)&255;break};case 8388636:case 8388637:{d=a[9634993]|0;break};default:{d=0}}return d|0}function eiX(b,e){b=b|0;e=e|0;var f=0,g=0;f=b&255;if((f|0)==17){b=c[3540984]|0;g=c[b+5876>>2]|0;if((g|0)!=0){gg[g&4095](c[b+5880>>2]|0,0)}lH(b,d[b+5885|0]|0,e&255);return}else if((f|0)==16){a[(c[3540984]|0)+5885|0]=e;return}else if((f|0)==28){Uv(0,e);return}else{return}}function eiY(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;e=b&255;if((e|0)==16){b=c[3540984]|0;f=(d[b+5887|0]|0|128)&(d[b+5886|0]|0);if((a[b+5884|0]&2)==0){g=f&255}else{g=(a[(c[b+5828>>2]|0)+100|0]&1|f)&255}h=g|6;return h|0}else if((e|0)==17){g=c[3540984]|0;f=d[g+5885|0]|0;do{if((f|0)==15){if((a[g+5884|0]&2)==0){i=0;break}i=lq(c[g+5828>>2]|0)|0}else if((f|0)==5){if((a[g+5884|0]&4)==0){i=0;break}b=c[g+5848>>2]|0;if((b|0)==0){i=0;break}i=gj[b&4095](c[g+5856>>2]|0)|0}else if((f|0)==26){i=a[g+5884|0]<<6&-128}else if((f|0)==25){if((a[g+5884|0]&8)==0){i=0;break}b=c[g+5836>>2]|0;if((b|0)==0){i=0;break}i=gj[b&4095](c[g+5844>>2]|0)|0}else{i=-1}}while(0);h=i|6;return h|0}else if((e|0)==24){a[9706115]=0;h=a[c[3528254]|0]|0;return h|0}else if((e|0)==28){h=c[2113156]&255;return h|0}else{h=0;return h|0}return 0}function eiZ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2627692+(b*112|0)>>2];c[a+104>>2]=c[2627696+(b*112|0)>>2];c[a+108>>2]=c[2627700+(b*112|0)>>2];d=0;return d|0}function ei_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=2627592+(b*112|0);e=0;return e|0}function ei$(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1233104+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function ei0(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>29){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3775656+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function ei1(){return ejo(0)|0}function ei2(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;Uw(0);b=a[7452584]|0;if(b){d=0;e=b&1;while(1){b=14163936+(d<<2)|0;f=c[b>>2]|0;g=c[2113006]|0;if((g|0)==0){h=59830}else{i=g-1|0;c[2113006]=i;if((i|0)==0){h=59830}}if((h|0)==59830){h=0;c[2383474]=0}if((f|0)==0){j=e}else{gGr(f);j=a[7452584]&1}c[b>>2]=0;b=d+1|0;if((b|0)<(j|0)){d=b;e=j}else{break}}}a[7452584]=0;c[2438224]=0;c[2433522]=0;c[2406672]=0;c[3528468]=0;j=c[2406688]|0;if((j|0)!=0){gGr(j);c[2406688]=0}c[2432972]=0;if((c[2392]|0)>=0){j=0;do{e=14130368+(j<<2)|0;d=c[e>>2]|0;if((d|0)!=0){gGr(d);c[e>>2]=0}e=14130384+(j<<2)|0;d=c[e>>2]|0;if((d|0)!=0){gGr(d);c[e>>2]=0}j=j+1|0;}while((j|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;fwZ();c[2113070]=0;c[2113068]=0;j=c[2112926]|0;if((j|0)!=0){gGr(j);c[2112926]=0}j=c[2414940]|0;e=0;while(1){if((e|0)>=1024){h=59850;break}k=9638528+(e<<2)|0;if((c[k>>2]|0)==(j|0)){break}else{e=e+1|0}}if((h|0)==59850){c[2414940]=0;a[7045216]=0;return 0}gGr(j);c[k>>2]=0;c[2414940]=0;a[7045216]=0;return 0}function ei3(){var e=0,f=0,g=0,i=0,j=0,k=0;if((a[9624008]|0)!=0){a[9624008]=0;e=c[2414642]|0;gGz(e|0,0,(c[2411616]|0)-e|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060]}RI();e=c[2394]|0;f=c[14130368+(e<<2)>>2]|0;if((f|0)!=0){gGC(f|0,9104152,280)|0}c[8452240+(e<<2)>>2]=c[2113054];c[2394]=-1;e=c[2439330]|0;f=(e|0)==0;if(!f){g=e;gGC(9706056,g|0,76)|0}g=c[2438118]|0;c[2433530]=g;i=c[3528484]|0;c[2076596]=i;j=c[2417276]|0;c[3541536]=j;c[1836236]=0;gGz(9706056,0,76);if(!f){f=e;gGC(f|0,9706056,76)|0}c[2438118]=g;c[3528484]=i;c[2417276]=j;c[1836236]=-1;c[2113156]=0;a[9628264]=0;c[2407033]=0;j=c[3541206]|0;c[3541190]=j;c[3541198]=j;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=j+256;c[3541199]=j+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=j+512;c[3541200]=j+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=j+768;c[3541201]=j+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;lw(c[3540984]|0);j=c[2386632]|0;i=j+262144|0;gGC(j|0,i|0,262144)|0;c[2385296]=1}i=c[2385548]|0;if((i|0)>0){gGz(9752472,0,((i|0)>1?i<<2:4)|0)}c[2433530]=0;c[2387598]=-1;i=0;j=-1;g=-1;do{j=(d[9633192+i|0]<<i^j&65535)&65535;g=(d[9631064+i|0]<<i^g&65535)&65535;i=i+1|0;}while((i|0)<16);b[4775196]=j;b[4775197]=g;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060]}g=c[2439330]|0;if((g|0)!=0){j=g;gGC(9706056,j|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;j=0;do{c[2113056]=26666;g=RG(26666)|0;c[2113054]=(c[2113054]|0)+g;c[2276108]=-1;c[2113056]=-1;do{if((j|0)==9){c[8452200+(c[2394]<<2)>>2]=8194;c[2276080]=512;if((c[2276079]|0)>>>0>=512){break}RH(2)}}while(0);if(a[7045216]|0){g=(j*5e3|0)+5e3|0;UF(g)|0}j=j+1|0;}while((j|0)<10);if(a[7045216]|0){j=c[2438224]|0;g=gGS(-610271232,23841,j,(j|0)<0|0?-1:0)|0;j=g;UF(5e4)|0;g=c[2443826]|0;if((g|0)<1073676288){c[2443826]=g-j}g=c[2443827]|0;if((g|0)<1073676288){c[2443827]=g-j}g=(c[3528508]|0)-j|0;c[3528508]=(g|0)<0?0:g}g=c[2112964]|0;if((g|0)!=0){if(a[7045216]|0){gg[c[3542112]&4095](g,a[9688]|0?534:0);k=c[2112964]|0}else{k=g}Uu(0,k,a[9688]|0?534:0)}k=c[1836236]|0;g=c[9757320+(k<<2)>>2]|0;if((g|0)!=0){j=g;gGC(j|0,9706056,76)|0}c[9752472+(k<<2)>>2]=c[2433530];c[14113936+(k<<2)>>2]=c[2076596];c[9669104+(k<<2)>>2]=c[3541536];c[1836236]=-1;k=c[2394]|0;j=c[14130368+(k<<2)>>2]|0;if((j|0)!=0){gGC(j|0,9104152,280)|0}c[8452240+(k<<2)>>2]=c[2113054];c[2394]=-1;if((c[2112968]|0)==0){return 0}ei4()|0;return 0}function ei4(){var d=0,e=0,f=0,g=0,h=0,i=0;if((a[9547352]|0)!=0){d=c[2387172]|0;e=c[3529978]|0;f=0;do{g=(f|0)==512?4096:f;h=b[d+(g<<1)>>1]|0;c[e+(g<<2)>>2]=((h&65535)>>>10<<3&248)<<8|((h&255)<<3&255)>>>3|(((h&65535)>>>5<<3&255|(h&65535)>>>7&4)&255)<<3&2016;f=g+1|0;}while((f|0)<8192)}f=a[c[2437792]|0]&12;if((f|0)==4){ejr(0,1);ejs(1);ejr(0,0);ejs(2);ejr(1,0);ejs(3);ejs(0);i=c[3529978]|0;R8(i);return 0}else if((f|0)==8){ejr(1,1);ejs(1);ejr(1,0);ejs(2);ejr(0,0);ejs(3);ejs(0);i=c[3529978]|0;R8(i);return 0}else{i=c[3529978]|0;R8(i);return 0}return 0}function ei5(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=i;i=i+80|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;if((d|0)!=0){c[d>>2]=169735}if((b&96|0)==0){i=e;return 0}gGz(k|0,0,12);l=c[2414642]|0;c[k>>2]=l;c[k+4>>2]=(c[2411616]|0)-l;c[k+12>>2]=162152;gj[c[2076592]&4095](k)|0;k=h|0;do{if((b&64|0)!=0){gGz(g|0,0,16);c[2394]=-1;if((c[2392]|0)<0){break}l=h+9|0;m=f;n=f|0;o=f+4|0;p=f+12|0;q=g|0;r=g+4|0;s=g+12|0;t=0;do{gGC(k|0,614896,11)|0;a[l]=t+48&255;u=8452256+(t<<2)|0;gGz(m|0,0,12);c[n>>2]=u;c[o>>2]=4;c[p>>2]=164976;gj[c[2076592]&4095](f)|0;if((c[u>>2]|0)!=0){c[q>>2]=c[14130368+(t<<2)>>2];c[r>>2]=c[8452184+(t<<2)>>2];c[s>>2]=k;u=c[2076592]|0;gj[u&4095](g)|0}t=t+1|0;}while((t|0)<=(c[2392]|0))}}while(0);fw$(b);UQ(b,d);Ut(0);gGz(j|0,0,12);c[j>>2]=9541184;c[j+4>>2]=4;c[j+12>>2]=572696;gj[c[2076592]&4095](j)|0;j=c[2385296]|0;c[2385296]=-1;if((j|0)==-1){i=e;return 0}c[2385296]=j;d=c[2386632]|0;b=d+131072|0;g=d+((j<<17)+262144)|0;gGC(b|0,g|0,131072)|0;i=e;return 0}function ei6(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1508524+(b*112|0)>>2];c[a+104>>2]=c[1508528+(b*112|0)>>2];c[a+108>>2]=c[1508532+(b*112|0)>>2];d=0;return d|0}function ei7(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=1508424+(b*112|0);e=0;return e|0}function ei8(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>34){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1839712+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function ei9(){return ejo(1)|0}function eja(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2466908+(b*112|0)>>2];c[a+104>>2]=c[2466912+(b*112|0)>>2];c[a+108>>2]=c[2466916+(b*112|0)>>2];d=0;return d|0}function ejb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=2466808+(b*112|0);e=0;return e|0}function ejc(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>37){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3631232+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function ejd(){return ejo(2)|0}function eje(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2286332+(b*112|0)>>2];c[a+104>>2]=c[2286336+(b*112|0)>>2];c[a+108>>2]=c[2286340+(b*112|0)>>2];d=0;return d|0}function ejf(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=2286232+(b*112|0);e=0;return e|0}function ejg(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>30){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3447024+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function ejh(){return ejo(3)|0}function eji(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3061460+(b*112|0)>>2];c[a+104>>2]=c[3061464+(b*112|0)>>2];c[a+108>>2]=c[3061468+(b*112|0)>>2];d=0;return d|0}function ejj(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=3061360+(b*112|0);e=0;return e|0}function ejk(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1308240+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function ejl(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>29){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4218536+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function ejm(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1606988+(b*112|0)>>2];c[a+104>>2]=c[1606992+(b*112|0)>>2];c[a+108>>2]=c[1606996+(b*112|0)>>2];d=0;return d|0}function ejn(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=1606888+(b*112|0);e=0;return e|0}function ejo(e){e=e|0;var f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;f=i;i=i+840|0;g=f|0;j=f+112|0;k=f+120|0;l=f+232|0;m=f+240|0;n=f+352|0;o=f+360|0;p=f+472|0;q=f+480|0;r=f+592|0;s=f+600|0;t=f+712|0;u=f+720|0;v=f+832|0;c[2414940]=0;c[2388132]=0;c[2385908]=524288;c[3530818]=589824;c[3530582]=4784128;c[3541206]=6881280;c[2386632]=6881280;c[3529978]=7667712;c[2414642]=7700480;c[2388260]=7700480;c[3529460]=7766016;c[3529424]=7782400;c[2386436]=7798784;c[2387172]=7802880;c[2386062]=7819264;c[2408992]=7821312;c[3528254]=7821320;c[2437792]=7821321;c[2411616]=7821322;w=0;while(1){if((w|0)>=1024){break}x=9638528+(w<<2)|0;if((c[x>>2]|0)==0){y=60025;break}else{w=w+1|0}}do{if((y|0)==60025){w=gGq(7821322)|0;c[x>>2]=w;if((w|0)==0){break}c[2414940]=w;gGz(w|0,0,7821322);c[2388132]=w;c[2385908]=w+524288;c[3530818]=w+589824;c[3530582]=w+4784128;z=w+6881280|0;c[3541206]=z;c[2386632]=z;c[3529978]=w+7667712;z=w+7700480|0;c[2414642]=z;c[2388260]=z;c[3529460]=w+7766016;c[3529424]=w+7782400;c[2386436]=w+7798784;c[2387172]=w+7802880;c[2386062]=w+7819264;c[2408992]=w+7821312;c[3528254]=w+7821320;c[2437792]=w+7821321;z=w+7821322|0;c[2411616]=z;c[2414158]=z;if((R6(w+1|0,0,2)|0)!=0){A=1;i=f;return A|0}if((R6(c[2388132]|0,1,2)|0)!=0){A=1;i=f;return A|0}w=c[3530818]|0;gGz(w|0,-1|0,4194304);do{if((e|0)==1){z=c[2385908]|0;if((c[3542200]|0)==0){A=1;i=f;return A|0}B=s+108|0;c[B>>2]=0;C=s+100|0;c[C>>2]=0;D=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[D&16383](s,2)|0;do{if((c[B>>2]|0)!=0){D=c[C>>2]|0;c[t>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](t,2,0)|0;if((D|0)<1){A=1;i=f;return A|0}if((gzL(z,0,2)|0)==0){break}else{A=1}i=f;return A|0}}while(0);if((R6(c[3530818]|0,3,4)|0)!=0){A=1;i=f;return A|0}if((R6((c[3530818]|0)+1|0,4,4)|0)!=0){A=1;i=f;return A|0}if((R6((c[3530818]|0)+2|0,5,4)|0)!=0){A=1;i=f;return A|0}if((R6((c[3530818]|0)+3|0,6,4)|0)!=0){A=1;i=f;return A|0}if((R6((c[3530818]|0)+2097152|0,7,4)|0)!=0){A=1;i=f;return A|0}if((R6((c[3530818]|0)+2097153|0,8,4)|0)!=0){A=1;i=f;return A|0}if((R6((c[3530818]|0)+2097154|0,9,4)|0)!=0){A=1;i=f;return A|0}if((R6((c[3530818]|0)+2097155|0,10,4)|0)==0){a[7045216]=1;F=11;break}else{A=1;i=f;return A|0}}else if((e|0)==2){if((R6(w,2,4)|0)!=0){A=1;i=f;return A|0}if((R6((c[3530818]|0)+1|0,3,4)|0)!=0){A=1;i=f;return A|0}if((R6((c[3530818]|0)+2|0,4,4)|0)!=0){A=1;i=f;return A|0}if((R6((c[3530818]|0)+3|0,5,4)|0)!=0){A=1;i=f;return A|0}if((R6((c[3530818]|0)+2097152|0,6,4)|0)!=0){A=1;i=f;return A|0}if((R6((c[3530818]|0)+2097153|0,7,4)|0)!=0){A=1;i=f;return A|0}if((R6((c[3530818]|0)+2097154|0,8,4)|0)!=0){A=1;i=f;return A|0}if((R6((c[3530818]|0)+2097155|0,9,4)|0)==0){F=10;break}else{A=1}i=f;return A|0}else if((e|0)==0){z=c[2385908]|0;if((c[3542200]|0)==0){A=1;i=f;return A|0}C=u+108|0;c[C>>2]=0;B=u+100|0;c[B>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](u,2)|0;do{if((c[C>>2]|0)!=0){D=c[B>>2]|0;c[v>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](v,2,0)|0;if((D|0)<1){A=1;i=f;return A|0}if((gzL(z,0,2)|0)==0){break}else{A=1}i=f;return A|0}}while(0);if((R6(c[3530818]|0,3,4)|0)!=0){A=1;i=f;return A|0}if((R6((c[3530818]|0)+1|0,4,4)|0)!=0){A=1;i=f;return A|0}if((R6((c[3530818]|0)+2|0,5,4)|0)!=0){A=1;i=f;return A|0}if((R6((c[3530818]|0)+3|0,6,4)|0)==0){a[7045216]=1;F=7;break}else{A=1;i=f;return A|0}}else if((e|0)==3){if((R6(w,2,4)|0)!=0){A=1;i=f;return A|0}if((R6((c[3530818]|0)+1|0,3,4)|0)!=0){A=1;i=f;return A|0}if((R6((c[3530818]|0)+2|0,4,4)|0)!=0){A=1;i=f;return A|0}if((R6((c[3530818]|0)+3|0,5,4)|0)==0){F=6;break}else{A=1}i=f;return A|0}else{F=0}}while(0);w=c[3530582]|0;if((c[3542200]|0)==0){A=1;i=f;return A|0}z=q+108|0;c[z>>2]=0;B=q+100|0;c[B>>2]=0;C=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[C&16383](q,F)|0;do{if((c[z>>2]|0)!=0){C=c[B>>2]|0;c[r>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](r,F,0)|0;if((C|0)<1){A=1;i=f;return A|0}if((gzL(w,0,F)|0)==0){break}else{A=1}i=f;return A|0}}while(0);w=(c[3530582]|0)+262144|0;B=F+1|0;if((c[3542200]|0)==0){A=1;i=f;return A|0}z=o+108|0;c[z>>2]=0;C=o+100|0;c[C>>2]=0;D=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[D&16383](o,B)|0;do{if((c[z>>2]|0)!=0){D=c[C>>2]|0;c[p>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](p,B,0)|0;if((D|0)<1){A=1;i=f;return A|0}if((gzL(w,0,B)|0)==0){break}else{A=1}i=f;return A|0}}while(0);B=(c[3530582]|0)+524288|0;w=F+2|0;if((c[3542200]|0)==0){A=1;i=f;return A|0}C=m+108|0;c[C>>2]=0;z=m+100|0;c[z>>2]=0;D=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[D&16383](m,w)|0;do{if((c[C>>2]|0)!=0){D=c[z>>2]|0;c[n>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](n,w,0)|0;if((D|0)<1){A=1;i=f;return A|0}if((gzL(B,0,w)|0)==0){break}else{A=1}i=f;return A|0}}while(0);w=(c[3530582]|0)+786432|0;B=F+3|0;if((c[3542200]|0)==0){A=1;i=f;return A|0}z=k+108|0;c[z>>2]=0;C=k+100|0;c[C>>2]=0;D=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[D&16383](k,B)|0;do{if((c[z>>2]|0)!=0){D=c[C>>2]|0;c[l>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](l,B,0)|0;if((D|0)<1){A=1;i=f;return A|0}if((gzL(w,0,B)|0)==0){break}else{A=1}i=f;return A|0}}while(0);B=(c[2386632]|0)+262144|0;w=F+4|0;if((c[3542200]|0)==0){A=1;i=f;return A|0}C=g+108|0;c[C>>2]=0;z=g+100|0;c[z>>2]=0;D=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[D&16383](g,w)|0;do{if((c[C>>2]|0)==0){G=0}else{D=c[z>>2]|0;c[j>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](j,w,0)|0;if((D|0)<1){A=1;i=f;return A|0}if((gzL(B,0,w)|0)==0){G=0;break}else{A=1}i=f;return A|0}}while(0);while(1){if((G|0)>=1024){break}H=9638528+(G<<2)|0;if((c[H>>2]|0)==0){y=60086;break}else{G=G+1|0}}L79783:do{if((y|0)==60086){w=gGq(4194304)|0;c[H>>2]=w;if((w|0)==0){break}gGz(w|0,0,4194304);B=c[3530818]|0;z=0;while(1){a[w+z|0]=a[B+(z>>>1&3|z&-8|z<<2&4)|0]|0;C=z+1|0;if((C|0)<4194304){z=C}else{I=0;break}}do{z=I<<8;gGz(B+z|0,0,256);C=I<<11;D=0;do{E=1<<7-D;J=(c[611504+(D<<2)>>2]|0)+C|0;K=0;do{L=J+(c[609072+(K<<2)>>2]|0)|0;M=(K<<4)+z|0;N=0;do{O=L+(c[601400+(N<<2)>>2]|0)|0;if(((d[w+((O|0)/8|0)|0]|0)&128>>>((O&7)>>>0)|0)!=0){O=B+(M+N)|0;a[O]=(d[O]|0|E)&255}N=N+1|0;}while((N|0)<16);K=K+1|0;}while((K|0)<16);D=D+1|0;}while((D|0)<8);I=I+1|0;}while((I|0)<16384);B=c[3530582]|0;gGC(w|0,B|0,1048576)|0;D=0;while(1){z=D<<8;gGz(B+z|0,0,256);C=0;do{K=1<<3-C;E=(c[611280+(C<<2)>>2]|0)+z|0;J=0;do{N=E+(c[608544+(J<<2)>>2]|0)|0;M=(J<<4)+z|0;L=0;do{O=N+(c[609776+(L<<2)>>2]|0)|0;if(((d[w+((O|0)/8|0)|0]|0)&128>>>((O&7)>>>0)|0)!=0){O=B+(M+L)|0;a[O]=(d[O]|0|K)&255}L=L+1|0;}while((L|0)<16);J=J+1|0;}while((J|0)<16);C=C+1|0;}while((C|0)<4);C=D+1|0;if((C|0)<8192){D=C}else{P=0;break}}while(1){if((P|0)>=1024){break L79783}Q=9638528+(P<<2)|0;if((c[Q>>2]|0)==(w|0)){break}else{P=P+1|0}}gGr(w);c[Q>>2]=0}}while(0);fxU(0,425984);if((c[2394]|0)==0){R=c[2112932]|0}else{c[2394]=0;D=c[3532596]|0;c[2112932]=D;B=c[3532592]|0;if((B|0)!=0){gGC(9104152,B|0,280)|0}c[2113054]=c[2113060];R=D}D=c[2388132]|0;B=R|0;C=0;while(1){z=D+C|0;c[B>>2]=z;c[B+131072>>2]=z;z=C+1024|0;if(z>>>0>524287){break}else{B=B+4|0;C=z}}C=c[2387172]|0;c[R+36864>>2]=C;c[R+102400>>2]=C;c[R+167936>>2]=C;B=C+1024|0;c[R+36868>>2]=B;c[R+102404>>2]=B;c[R+167940>>2]=B;B=C+2048|0;c[R+36872>>2]=B;c[R+102408>>2]=B;c[R+167944>>2]=B;B=C+3072|0;c[R+36876>>2]=B;c[R+102412>>2]=B;c[R+167948>>2]=B;B=C+4096|0;c[R+36880>>2]=B;c[R+102416>>2]=B;c[R+167952>>2]=B;B=C+5120|0;c[R+36884>>2]=B;c[R+102420>>2]=B;c[R+167956>>2]=B;B=C+6144|0;c[R+36888>>2]=B;c[R+102424>>2]=B;c[R+167960>>2]=B;B=C+7168|0;c[R+36892>>2]=B;c[R+102428>>2]=B;c[R+167964>>2]=B;B=C+8192|0;c[R+36896>>2]=B;c[R+102432>>2]=B;c[R+167968>>2]=B;B=C+9216|0;c[R+36900>>2]=B;c[R+102436>>2]=B;c[R+167972>>2]=B;B=C+10240|0;c[R+36904>>2]=B;c[R+102440>>2]=B;c[R+167976>>2]=B;B=C+11264|0;c[R+36908>>2]=B;c[R+102444>>2]=B;c[R+167980>>2]=B;B=C+12288|0;c[R+36912>>2]=B;c[R+102448>>2]=B;c[R+167984>>2]=B;B=C+13312|0;c[R+36916>>2]=B;c[R+102452>>2]=B;c[R+167988>>2]=B;B=C+14336|0;c[R+36920>>2]=B;c[R+102456>>2]=B;c[R+167992>>2]=B;B=C+15360|0;c[R+36924>>2]=B;c[R+102460>>2]=B;c[R+167996>>2]=B;B=c[3529424]|0;c[R+36992>>2]=B;c[R+102528>>2]=B;c[R+168064>>2]=B;C=B+1024|0;c[R+36996>>2]=C;c[R+102532>>2]=C;c[R+168068>>2]=C;C=B+2048|0;c[R+37e3>>2]=C;c[R+102536>>2]=C;c[R+168072>>2]=C;C=B+3072|0;c[R+37004>>2]=C;c[R+102540>>2]=C;c[R+168076>>2]=C;C=B+4096|0;c[R+37008>>2]=C;c[R+102544>>2]=C;c[R+168080>>2]=C;C=B+5120|0;c[R+37012>>2]=C;c[R+102548>>2]=C;c[R+168084>>2]=C;C=B+6144|0;c[R+37016>>2]=C;c[R+102552>>2]=C;c[R+168088>>2]=C;C=B+7168|0;c[R+37020>>2]=C;c[R+102556>>2]=C;c[R+168092>>2]=C;C=B+8192|0;c[R+37024>>2]=C;c[R+102560>>2]=C;c[R+168096>>2]=C;C=B+9216|0;c[R+37028>>2]=C;c[R+102564>>2]=C;c[R+168100>>2]=C;C=B+10240|0;c[R+37032>>2]=C;c[R+102568>>2]=C;c[R+168104>>2]=C;C=B+11264|0;c[R+37036>>2]=C;c[R+102572>>2]=C;c[R+168108>>2]=C;C=B+12288|0;c[R+37040>>2]=C;c[R+102576>>2]=C;c[R+168112>>2]=C;C=B+13312|0;c[R+37044>>2]=C;c[R+102580>>2]=C;c[R+168116>>2]=C;C=B+14336|0;c[R+37048>>2]=C;c[R+102584>>2]=C;c[R+168120>>2]=C;C=B+15360|0;c[R+37052>>2]=C;c[R+102588>>2]=C;c[R+168124>>2]=C;C=c[3529460]|0;c[R+37056>>2]=C;c[R+102592>>2]=C;c[R+168128>>2]=C;B=C+1024|0;c[R+37060>>2]=B;c[R+102596>>2]=B;c[R+168132>>2]=B;B=C+2048|0;c[R+37064>>2]=B;c[R+102600>>2]=B;c[R+168136>>2]=B;B=C+3072|0;c[R+37068>>2]=B;c[R+102604>>2]=B;c[R+168140>>2]=B;B=C+4096|0;c[R+37072>>2]=B;c[R+102608>>2]=B;c[R+168144>>2]=B;B=C+5120|0;c[R+37076>>2]=B;c[R+102612>>2]=B;c[R+168148>>2]=B;B=C+6144|0;c[R+37080>>2]=B;c[R+102616>>2]=B;c[R+168152>>2]=B;B=C+7168|0;c[R+37084>>2]=B;c[R+102620>>2]=B;c[R+168156>>2]=B;B=C+8192|0;c[R+37088>>2]=B;c[R+102624>>2]=B;c[R+168160>>2]=B;B=C+9216|0;c[R+37092>>2]=B;c[R+102628>>2]=B;c[R+168164>>2]=B;B=C+10240|0;c[R+37096>>2]=B;c[R+102632>>2]=B;c[R+168168>>2]=B;B=C+11264|0;c[R+37100>>2]=B;c[R+102636>>2]=B;c[R+168172>>2]=B;B=C+12288|0;c[R+37104>>2]=B;c[R+102640>>2]=B;c[R+168176>>2]=B;B=C+13312|0;c[R+37108>>2]=B;c[R+102644>>2]=B;c[R+168180>>2]=B;B=C+14336|0;c[R+37112>>2]=B;c[R+102648>>2]=B;c[R+168184>>2]=B;B=C+15360|0;c[R+37116>>2]=B;c[R+102652>>2]=B;c[R+168188>>2]=B;B=c[2386436]|0;c[R+37120>>2]=B;c[R+102656>>2]=B;c[R+168192>>2]=B;C=B+1024|0;c[R+37124>>2]=C;c[R+102660>>2]=C;c[R+168196>>2]=C;C=B+2048|0;c[R+37128>>2]=C;c[R+102664>>2]=C;c[R+168200>>2]=C;C=B+3072|0;c[R+37132>>2]=C;c[R+102668>>2]=C;c[R+168204>>2]=C;C=c[2388260]|0;B=R+65280|0;D=16711680;while(1){z=C+(D-16711680)|0;c[B>>2]=z;c[B+65536>>2]=z;c[B+131072>>2]=z;z=D+1024|0;if(z>>>0>16777215){break}else{B=B+4|0;D=z}}c[R+196728>>2]=2996;c[R+196648>>2]=2708;c[R+196688>>2]=2400;c[R+196608>>2]=3040;D=c[3532592]|0;if((D|0)!=0){gGC(D|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);D=c[2439330]|0;B=(D|0)==0;if(!B){C=D;gGC(9706056,C|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];C=c[3528484]|0;c[2076596]=C;z=c[2417276]|0;c[3541536]=z;c[1836236]=0;J=c[2385908]|0;K=0;E=0;while(1){c[D+76+(E<<2)>>2]=J+(E<<8);L=K+1&65535;if((L&65535)>223){S=0;T=0;break}else{K=L;E=L&65535}}while(1){E=J+(T<<8)|0;c[D+76+(T+512<<2)>>2]=E;c[D+76+(T+768<<2)>>2]=E;E=S+1&65535;if((E&65535)>223){break}else{S=E;T=E&65535}}J=c[2386062]|0;c[D+972>>2]=J;E=J+256|0;c[D+976>>2]=E;K=J+512|0;c[D+980>>2]=K;L=J+768|0;c[D+984>>2]=L;M=J+1024|0;c[D+988>>2]=M;N=J+1280|0;c[D+992>>2]=N;O=J+1536|0;c[D+996>>2]=O;U=J+1792|0;c[D+1e3>>2]=U;c[D+1996>>2]=J;c[D+2e3>>2]=E;c[D+2004>>2]=K;c[D+2008>>2]=L;c[D+2012>>2]=M;c[D+2016>>2]=N;c[D+2020>>2]=O;c[D+2024>>2]=U;c[D+3020>>2]=J;c[D+4044>>2]=J;c[D+3024>>2]=E;c[D+4048>>2]=E;c[D+3028>>2]=K;c[D+4052>>2]=K;c[D+3032>>2]=L;c[D+4056>>2]=L;c[D+3036>>2]=M;c[D+4060>>2]=M;c[D+3040>>2]=N;c[D+4064>>2]=N;c[D+3044>>2]=O;c[D+4068>>2]=O;c[D+3048>>2]=U;c[D+4072>>2]=U;c[D+4176>>2]=2736;c[D+4172>>2]=3558;if(!B){U=D;gGC(U|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=C;c[2417276]=z;c[1836236]=-1;UL(4e6,16,1180,0);c[2438224]=3e6;c[2433522]=3416;c[2406672]=1752;c[3528468]=9362;c[2443842]=681;h[745398]=.8;a[3203264]=1;U=a[7045216]|0;Ux(0,U?8e3:7575,U);c[2407030]=~~((a[7045216]|0?204.8:256.0)+.5);c[2407068]=3;U=c[642608+(c[2436]<<2)>>2]|0;O=c[U+128>>2]|0;if((c[U+52>>2]&4|0)==0){c[2113068]=O;N=c[U+132>>2]|0;c[2113070]=N;c[2443814]=O;c[2440436]=N;V=O;W=N}else{c[2113070]=O;N=c[U+132>>2]|0;c[2113068]=N;c[2440436]=O;c[2443814]=N;V=N;W=O}O=ag(V<<1,W)|0;N=gGq(O)|0;c[2112926]=N;if((N|0)!=0){gGz(N|0,0,O|0)}a[9624008]=0;O=c[2414642]|0;gGz(O|0,0,(c[2411616]|0)-O|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];O=c[3532592]|0;if((O|0)!=0){gGC(9104152,O|0,280)|0}c[2113054]=c[2113060]}RI();O=c[2394]|0;N=c[14130368+(O<<2)>>2]|0;if((N|0)!=0){gGC(N|0,9104152,280)|0}c[8452240+(O<<2)>>2]=c[2113054];c[2394]=-1;O=c[2439330]|0;N=(O|0)==0;if(!N){U=O;gGC(9706056,U|0,76)|0}U=c[2438118]|0;c[2433530]=U;M=c[3528484]|0;c[2076596]=M;L=c[2417276]|0;c[3541536]=L;c[1836236]=0;gGz(9706056,0,76);if(!N){N=O;gGC(N|0,9706056,76)|0}c[2438118]=U;c[3528484]=M;c[2417276]=L;c[1836236]=-1;c[2113156]=0;a[9628264]=0;c[2407033]=0;L=c[3541206]|0;c[3541190]=L;c[3541198]=L;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=L+256;c[3541199]=L+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=L+512;c[3541200]=L+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=L+768;c[3541201]=L+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;lw(c[3540984]|0);L=c[2386632]|0;M=L+262144|0;gGC(L|0,M|0,262144)|0;c[2385296]=1;A=0;i=f;return A|0}}while(0);c[2414940]=0;A=1;i=f;return A|0}function ejp(b,c){b=b|0;c=c|0;a[9706117]=(c|0)!=0|0;return}function ejq(a){a=a|0;var b=0,d=0;b=(c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,3e6,0)|0;return a|0}function ejr(d,f){d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=d<<1;h=c[2408992]|0;i=(d|0)!=0;d=i?c[3529424]|0:c[3529460]|0;j=(i?-56:-52)-(e[h+(g<<1)>>1]|0)+(a[7045216]|0?-32:0)|0;i=-16-(e[h+((g|1)<<1)>>1]|0)|0;g=c[2112926]|0;h=c[3530818]|0;k=c[2113068]|0;l=c[2113070]|0;if((f|0)==0){f=0;do{m=f<<4;n=f>>6;o=(m&1008)+j|0;p=(o|0)<-15?o+1024|0:o;o=(n<<4)+i|0;q=(o|0)<-15?o+1024|0:o;do{if((p|0)<(k|0)&(q|0)<(l|0)){o=(m&768|f&3072|n&15|m&240)<<1;r=b[d+(o<<1)>>1]&16383;s=e[d+((o|1)<<1)>>1]|0;o=s&15;if((s&32|0)==0){SH(g,r,p,q,o,8,255,4096,h);break}else{SJ(g,r,p,q,o,8,255,4096,h);break}}}while(0);f=f+1|0;}while((f|0)<4096);return}else{f=0;do{q=f<<4;p=f>>6;m=(q&1008)+j|0;n=(m|0)<-15?m+1024|0:m;m=(p<<4)+i|0;o=(m|0)<-15?m+1024|0:m;do{if((n|0)<(k|0)&(o|0)<(l|0)){m=(q&768|f&3072|p&15|q&240)<<1;r=b[d+(m<<1)>>1]&16383;s=e[d+((m|1)<<1)>>1]|0;m=s&15;if((s&32|0)==0){Sz(g,r,n,o,m,8,4096,h);break}else{SB(g,r,n,o,m,8,4096,h);break}}}while(0);f=f+1|0;}while((f|0)<4096);return}}function ejs(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((a[c[2437792]|0]&3|0)!=(d|0)){return}d=a[7045216]|0?96:64;f=c[2386436]|0;g=c[2112926]|0;h=c[3530582]|0;i=0;do{j=(e[f+(i<<1)>>1]|0)-d|0;k=(e[f+((i|1)<<1)>>1]|0)-15|0;l=b[f+((i|2)<<1)>>1]&8191;m=e[f+((i|3)<<1)>>1]|0;n=(m&32|0)!=0;o=m&31;do{if((m&64|0)==0){if(n){SJ(g,l,j,k,o,4,15,0,h);break}else{SH(g,l,j,k,o,4,15,0,h);break}}else{if(n){SN(g,l,j,k,o,4,15,0,h);break}else{SL(g,l,j,k,o,4,15,0,h);break}}}while(0);i=i+4|0;}while((i|0)<2048);return}function ejt(d,e){d=d|0;e=e|0;var f=0,g=0;f=d&16777200;if((f|0)!=655360){if((d&16775168|0)==643072){c[2405098]=(e&65535)<<12&4096;return}if((f|0)==786464){b[(c[2408990]|0)+((d>>>1&7)<<1)>>1]=e;return}if((d|0)!=786460){return}c[3528632]=e&65535;return}f=d>>>1&7;if((f|0)==0|(f|0)==1){a[9579184+f|0]=e&255;return}else if((f|0)==6){c[2432768]=0;c[2432908]=1;return}else if((f|0)==4){do{if(a[7045208]|0){c[2384378]=215;if((c[2384374]|0)!=223){g=-41;break}a[14125144]=-41;a[9706117]=1;g=-41}else{g=c[2384378]&255&-33}}while(0);c[2384374]=223;a[14125144]=g;a[9706117]=1;return}else{return}}function eju(e){e=e|0;var f=0,g=0,h=0;do{if((e&16777200|0)==655360){f=e>>>1&7;if((f|0)==2|(f|0)==3){g=a[9553896+(f-2)|0]|0}else if((f|0)==5){g=(c[2432908]|0)!=0|0}else{g=-1}h=g&255}else{if((e|0)==917506){h=b[4775193]|0;break}else if((e|0)==917508){h=b[4775194]|0;break}else if((e|0)==917504){h=(d[9634985]|0)<<8|(d[9634984]|0);break}else if((e|0)==786460){h=c[3528632]&65535;break}else{h=0;break}}}while(0);return h|0}function ejv(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7064004+(b*112|0)>>2];c[a+104>>2]=c[7064008+(b*112|0)>>2];c[a+108>>2]=c[7064012+(b*112|0)>>2];d=0;return d|0}function ejw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=7063904+(b*112|0);e=0;return e|0}function ejx(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6378136+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function ejy(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7313808+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function ejz(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0;b=i;i=i+1560|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;l=b+360|0;m=b+472|0;n=b+480|0;o=b+592|0;p=b+600|0;q=b+712|0;r=b+720|0;s=b+832|0;t=b+840|0;u=b+952|0;v=b+960|0;w=b+1072|0;x=b+1080|0;y=b+1192|0;z=b+1200|0;A=b+1312|0;B=b+1320|0;C=b+1432|0;D=b+1440|0;E=b+1552|0;c[2414938]=0;c[2388130]=0;c[3532600]=524288;c[2385906]=524288;c[3530816]=655360;c[3530580]=917504;c[3530418]=1966080;c[3530326]=3014656;c[3530292]=5111808;c[3529976]=9306112;c[3541206]=9314304;c[2386630]=9314304;c[2414640]=9576448;c[2386434]=9576448;c[2406564]=9578496;c[2406308]=9580544;c[2406486]=9582592;c[2405796]=9584640;c[2388258]=9588736;c[2387170]=9637888;c[2408990]=9641984;c[3532602]=9642e3;c[2411614]=9644048;F=0;while(1){if((F|0)>=1024){break}G=9638528+(F<<2)|0;if((c[G>>2]|0)==0){H=60288;break}else{F=F+1|0}}do{if((H|0)==60288){F=gGq(9644048)|0;c[G>>2]=F;if((F|0)==0){break}c[2414938]=F;gGz(F|0,0,9644048);c[2388130]=F;I=F+524288|0;c[3532600]=I;c[2385906]=I;c[3530816]=F+655360;c[3530580]=F+917504;c[3530418]=F+1966080;c[3530326]=F+3014656;c[3530292]=F+5111808;c[3529976]=F+9306112;I=F+9314304|0;c[3541206]=I;c[2386630]=I;I=F+9576448|0;c[2414640]=I;c[2386434]=I;c[2406564]=F+9578496;c[2406308]=F+9580544;c[2406486]=F+9582592;c[2405796]=F+9584640;c[2388258]=F+9588736;c[2387170]=F+9637888;c[2408990]=F+9641984;I=F+9642e3|0;c[3532602]=I;c[2386060]=I;I=F+9644048|0;c[2411614]=I;c[2414154]=I;if((R6(F+1|0,0,2)|0)!=0){J=1;i=b;return J|0}if((R6(c[2388130]|0,1,2)|0)!=0){J=1;i=b;return J|0}if((R6((c[2388130]|0)+262145|0,2,2)|0)!=0){J=1;i=b;return J|0}if((R6((c[2388130]|0)+262144|0,3,2)|0)!=0){J=1;i=b;return J|0}F=c[2385906]|0;if((c[3542200]|0)==0){J=1;i=b;return J|0}I=D+108|0;c[I>>2]=0;K=D+100|0;c[K>>2]=0;L=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[L&16383](D,4)|0;do{if((c[I>>2]|0)!=0){L=c[K>>2]|0;c[E>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](E,4,0)|0;if((L|0)<1){J=1;i=b;return J|0}if((gzL(F,0,4)|0)==0){break}else{J=1}i=b;return J|0}}while(0);F=c[2385906]|0;K=F+65536|0;I=F+32768|0;gGC(K|0,I|0,32768)|0;K=F+98304|0;gGC(K|0,I|0,32768)|0;I=c[3530816]|0;if((c[3542200]|0)==0){J=1;i=b;return J|0}K=B+108|0;c[K>>2]=0;F=B+100|0;c[F>>2]=0;L=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[L&16383](B,5)|0;do{if((c[K>>2]|0)!=0){L=c[F>>2]|0;c[C>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](C,5,0)|0;if((L|0)<1){J=1;i=b;return J|0}if((gzL(I,0,5)|0)==0){break}else{J=1}i=b;return J|0}}while(0);I=(c[3530816]|0)+65536|0;if((c[3542200]|0)==0){J=1;i=b;return J|0}F=z+108|0;c[F>>2]=0;K=z+100|0;c[K>>2]=0;L=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[L&16383](z,6)|0;do{if((c[F>>2]|0)!=0){L=c[K>>2]|0;c[A>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](A,6,0)|0;if((L|0)<1){J=1;i=b;return J|0}if((gzL(I,0,6)|0)==0){break}else{J=1}i=b;return J|0}}while(0);I=c[3530580]|0;if((c[3542200]|0)==0){J=1;i=b;return J|0}K=x+108|0;c[K>>2]=0;F=x+100|0;c[F>>2]=0;L=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[L&16383](x,7)|0;do{if((c[K>>2]|0)!=0){L=c[F>>2]|0;c[y>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](y,7,0)|0;if((L|0)<1){J=1;i=b;return J|0}if((gzL(I,0,7)|0)==0){break}else{J=1}i=b;return J|0}}while(0);I=c[3530418]|0;if((c[3542200]|0)==0){J=1;i=b;return J|0}F=v+108|0;c[F>>2]=0;K=v+100|0;c[K>>2]=0;L=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[L&16383](v,8)|0;do{if((c[F>>2]|0)!=0){L=c[K>>2]|0;c[w>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](w,8,0)|0;if((L|0)<1){J=1;i=b;return J|0}if((gzL(I,0,8)|0)==0){break}else{J=1}i=b;return J|0}}while(0);I=c[3530326]|0;if((c[3542200]|0)==0){J=1;i=b;return J|0}K=t+108|0;c[K>>2]=0;F=t+100|0;c[F>>2]=0;L=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[L&16383](t,9)|0;do{if((c[K>>2]|0)!=0){L=c[F>>2]|0;c[u>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](u,9,0)|0;if((L|0)<1){J=1;i=b;return J|0}if((gzL(I,0,9)|0)==0){break}else{J=1}i=b;return J|0}}while(0);I=c[642608+(c[2436]<<2)>>2]|0;F=(fa(c[I>>2]|0,186768)|0)==0;K=c[3530292]|0;do{if((c[3542200]|0)==0){N=1}else{L=r+108|0;c[L>>2]=0;M=r+100|0;c[M>>2]=0;O=c[I+76>>2]|0;gA[O&16383](r,10)|0;if((c[L>>2]|0)==0){N=0;break}L=c[M>>2]|0;c[s>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](s,10,0)|0;if((L|0)<1){N=1;break}N=(gzL(K,0,10)|0)!=0}}while(0);do{if(F){if(N){J=1;i=b;return J|0}K=(c[3530292]|0)+1048576|0;if((c[3542200]|0)==0){J=1;i=b;return J|0}I=p+108|0;c[I>>2]=0;L=p+100|0;c[L>>2]=0;M=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[M&16383](p,11)|0;do{if((c[I>>2]|0)!=0){M=c[L>>2]|0;c[q>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](q,11,0)|0;if((M|0)<1){J=1;i=b;return J|0}if((gzL(K,0,11)|0)==0){break}else{J=1}i=b;return J|0}}while(0);K=c[2386630]|0;if((c[3542200]|0)==0){J=1;i=b;return J|0}L=n+108|0;c[L>>2]=0;I=n+100|0;c[I>>2]=0;M=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[M&16383](n,12)|0;do{if((c[L>>2]|0)!=0){M=c[I>>2]|0;c[o>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](o,12,0)|0;if((M|0)<1){J=1;i=b;return J|0}if((gzL(K,0,12)|0)==0){break}else{J=1}i=b;return J|0}}while(0);a[7045200]=1;P=0}else{if(N){J=1;i=b;return J|0}K=(c[3530292]|0)+524288|0;if((c[3542200]|0)==0){J=1;i=b;return J|0}I=l+108|0;c[I>>2]=0;L=l+100|0;c[L>>2]=0;M=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[M&16383](l,11)|0;do{if((c[I>>2]|0)!=0){M=c[L>>2]|0;c[m>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](m,11,0)|0;if((M|0)<1){J=1;i=b;return J|0}if((gzL(K,0,11)|0)==0){break}else{J=1}i=b;return J|0}}while(0);K=(c[3530292]|0)+1048576|0;if((c[3542200]|0)==0){J=1;i=b;return J|0}L=j+108|0;c[L>>2]=0;I=j+100|0;c[I>>2]=0;M=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[M&16383](j,12)|0;do{if((c[L>>2]|0)!=0){M=c[I>>2]|0;c[k>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](k,12,0)|0;if((M|0)<1){J=1;i=b;return J|0}if((gzL(K,0,12)|0)==0){break}else{J=1}i=b;return J|0}}while(0);K=(c[3530292]|0)+1572864|0;if((c[3542200]|0)==0){J=1;i=b;return J|0}I=g+108|0;c[I>>2]=0;L=g+100|0;c[L>>2]=0;M=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[M&16383](g,13)|0;do{if((c[I>>2]|0)!=0){M=c[L>>2]|0;c[h>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](h,13,0)|0;if((M|0)<1){J=1;i=b;return J|0}if((gzL(K,0,13)|0)==0){break}else{J=1}i=b;return J|0}}while(0);K=c[2386630]|0;if((c[3542200]|0)==0){J=1;i=b;return J|0}L=e+108|0;c[L>>2]=0;I=e+100|0;c[I>>2]=0;M=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[M&16383](e,14)|0;if((c[L>>2]|0)==0){P=0;break}L=c[I>>2]|0;c[f>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](f,14,0)|0;if((L|0)<1){J=1;i=b;return J|0}if((gzL(K,0,14)|0)==0){P=0;break}else{J=1}i=b;return J|0}}while(0);while(1){if((P|0)>=1024){break}Q=9638528+(P<<2)|0;if((c[Q>>2]|0)==0){H=60352;break}else{P=P+1|0}}L80139:do{if((H|0)==60352){F=gGq(2097152)|0;c[Q>>2]=F;if((F|0)==0){break}gGz(F|0,0,2097152);K=c[3530816]|0;gGC(F|0,K|0,131072)|0;L=0;do{I=L<<6;gGz(K+I|0,0,64);M=L<<7;O=0;do{R=1<<3-O;S=(c[611488+(O<<2)>>2]|0)+M|0;T=0;do{U=S+(c[6669224+(T<<2)>>2]|0)|0;V=(T<<3)+I|0;W=0;do{X=U+(c[6669320+(W<<2)>>2]|0)|0;if(((d[F+((X|0)/8|0)|0]|0)&128>>>((X&7)>>>0)|0)!=0){X=K+(V+W)|0;a[X]=(d[X]|0|R)&255}W=W+1|0;}while((W|0)<8);T=T+1|0;}while((T|0)<8);O=O+1|0;}while((O|0)<4);L=L+1|0;}while((L|0)<4096);L=c[3530580]|0;gGC(F|0,L|0,524288)|0;K=0;do{O=K<<8;gGz(L+O|0,0,256);I=K<<10;M=0;do{T=1<<3-M;R=(c[611264+(M<<2)>>2]|0)+I|0;S=0;do{W=R+(c[611840+(S<<2)>>2]|0)|0;V=(S<<4)+O|0;U=0;do{X=W+(c[609712+(U<<2)>>2]|0)|0;if(((d[F+((X|0)/8|0)|0]|0)&128>>>((X&7)>>>0)|0)!=0){X=L+(V+U)|0;a[X]=(d[X]|0|T)&255}U=U+1|0;}while((U|0)<16);S=S+1|0;}while((S|0)<16);M=M+1|0;}while((M|0)<4);K=K+1|0;}while((K|0)<4096);K=c[3530418]|0;gGC(F|0,K|0,524288)|0;L=0;do{M=L<<8;gGz(K+M|0,0,256);O=L<<10;I=0;do{S=1<<3-I;T=(c[611264+(I<<2)>>2]|0)+O|0;R=0;do{U=T+(c[611840+(R<<2)>>2]|0)|0;V=(R<<4)+M|0;W=0;do{X=U+(c[609712+(W<<2)>>2]|0)|0;if(((d[F+((X|0)/8|0)|0]|0)&128>>>((X&7)>>>0)|0)!=0){X=K+(V+W)|0;a[X]=(d[X]|0|S)&255}W=W+1|0;}while((W|0)<16);R=R+1|0;}while((R|0)<16);I=I+1|0;}while((I|0)<4);L=L+1|0;}while((L|0)<4096);L=c[3530326]|0;gGC(F|0,L|0,1048576)|0;K=0;do{I=K<<8;gGz(L+I|0,0,256);M=K<<10;O=0;do{R=1<<3-O;S=(c[611264+(O<<2)>>2]|0)+M|0;T=0;do{W=S+(c[611840+(T<<2)>>2]|0)|0;V=(T<<4)+I|0;U=0;do{X=W+(c[609712+(U<<2)>>2]|0)|0;if(((d[F+((X|0)/8|0)|0]|0)&128>>>((X&7)>>>0)|0)!=0){X=L+(V+U)|0;a[X]=(d[X]|0|R)&255}U=U+1|0;}while((U|0)<16);T=T+1|0;}while((T|0)<16);O=O+1|0;}while((O|0)<4);K=K+1|0;}while((K|0)<8192);K=c[3530292]|0;gGC(F|0,K|0,2097152)|0;L=0;while(1){O=L<<8;gGz(K+O|0,0,256);I=L<<10;M=0;do{T=1<<3-M;R=(c[611264+(M<<2)>>2]|0)+I|0;S=0;do{U=R+(c[611840+(S<<2)>>2]|0)|0;V=(S<<4)+O|0;W=0;do{X=U+(c[609712+(W<<2)>>2]|0)|0;if(((d[F+((X|0)/8|0)|0]|0)&128>>>((X&7)>>>0)|0)!=0){X=K+(V+W)|0;a[X]=(d[X]|0|T)&255}W=W+1|0;}while((W|0)<16);S=S+1|0;}while((S|0)<16);M=M+1|0;}while((M|0)<4);M=L+1|0;if((M|0)<16384){L=M}else{Y=0;break}}while(1){if((Y|0)>=1024){break L80139}Z=9638528+(Y<<2)|0;if((c[Z>>2]|0)==(F|0)){break}else{Y=Y+1|0}}gGr(F);c[Z>>2]=0}}while(0);fxU(0,425984);if((c[2394]|0)==0){_=c[2112932]|0}else{c[2394]=0;L=c[3532596]|0;c[2112932]=L;K=c[3532592]|0;if((K|0)!=0){gGC(9104152,K|0,280)|0}c[2113054]=c[2113060];_=L}L=c[2388130]|0;K=_|0;M=0;while(1){O=L+M|0;c[K>>2]=O;c[K+131072>>2]=O;O=M+1024|0;if(O>>>0>524287){break}else{K=K+4|0;M=O}}M=c[2388258]|0;K=_+2048|0;L=524288;while(1){O=M+(L-524288)|0;c[K>>2]=O;c[K+65536>>2]=O;c[K+131072>>2]=O;O=L+1024|0;if(O>>>0>573439){break}else{K=K+4|0;L=O}}L=c[2406564]|0;c[_+2240>>2]=L;c[_+67776>>2]=L;c[_+133312>>2]=L;K=L+1024|0;c[_+2244>>2]=K;c[_+67780>>2]=K;c[_+133316>>2]=K;K=c[2406486]|0;c[_+2248>>2]=K;c[_+67784>>2]=K;c[_+133320>>2]=K;L=K+1024|0;c[_+2252>>2]=L;c[_+67788>>2]=L;c[_+133324>>2]=L;L=c[2406308]|0;c[_+2256>>2]=L;c[_+67792>>2]=L;c[_+133328>>2]=L;K=L+1024|0;c[_+2260>>2]=K;c[_+67796>>2]=K;c[_+133332>>2]=K;K=c[2405796]|0;c[_+2264>>2]=K;c[_+67800>>2]=K;c[_+133336>>2]=K;L=K+1024|0;c[_+2268>>2]=L;c[_+67804>>2]=L;c[_+133340>>2]=L;L=K+2048|0;c[_+2272>>2]=L;c[_+67808>>2]=L;c[_+133344>>2]=L;L=K+3072|0;c[_+2276>>2]=L;c[_+67812>>2]=L;c[_+133348>>2]=L;L=c[2387170]|0;c[_+2280>>2]=L;c[_+67816>>2]=L;c[_+133352>>2]=L;K=L+1024|0;c[_+2284>>2]=K;c[_+67820>>2]=K;c[_+133356>>2]=K;K=L+2048|0;c[_+2288>>2]=K;c[_+67824>>2]=K;c[_+133360>>2]=K;K=L+3072|0;c[_+2292>>2]=K;c[_+67828>>2]=K;c[_+133364>>2]=K;K=c[2386434]|0;c[_+2296>>2]=K;c[_+67832>>2]=K;c[_+133368>>2]=K;L=K+1024|0;c[_+2300>>2]=L;c[_+67836>>2]=L;c[_+133372>>2]=L;c[_+196728>>2]=3464;c[_+196688>>2]=1650;L=c[3532592]|0;if((L|0)!=0){gGC(L|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;Tz(a[7045200]&1,0,1e4);L=c[642608+(c[2436]<<2)>>2]|0;K=c[L+128>>2]|0;if((c[L+52>>2]&4|0)==0){c[2113068]=K;M=c[L+132>>2]|0;c[2113070]=M;c[2443814]=K;c[2440436]=M;$=K;aa=M}else{c[2113070]=K;M=c[L+132>>2]|0;c[2113068]=M;c[2440436]=K;c[2443814]=M;$=M;aa=K}K=ag($<<1,aa)|0;M=gGq(K)|0;c[2112926]=M;if((M|0)!=0){gGz(M|0,0,K|0)}a[9624e3]=0;K=c[2414640]|0;gGz(K|0,0,(c[2411614]|0)-K|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];K=c[3532592]|0;if((K|0)!=0){gGC(9104152,K|0,280)|0}c[2113054]=c[2113060]}RI();K=c[2394]|0;M=c[14130368+(K<<2)>>2]|0;if((M|0)!=0){gGC(M|0,9104152,280)|0}c[8452240+(K<<2)>>2]=c[2113054];c[2394]=-1;Ty();c[2405098]=0;c[3528632]=0;J=0;i=b;return J|0}}while(0);c[2414938]=0;J=1;i=b;return J|0}function ejA(){var b=0,d=0,e=0,f=0,g=0;c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}if((c[2392]|0)>=0){b=0;do{d=14130368+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}d=14130384+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}b=b+1|0;}while((b|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;TE();b=c[2414938]|0;d=0;while(1){if((d|0)>=1024){f=60488;break}g=9638528+(d<<2)|0;if((c[g>>2]|0)==(b|0)){break}else{d=d+1|0}}if((f|0)==60488){c[2414938]=0;a[7045200]=0;return 0}gGr(b);c[g>>2]=0;c[2414938]=0;a[7045200]=0;return 0}function ejB(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if((a[9624e3]|0)!=0){a[9624e3]=0;e=c[2414640]|0;gGz(e|0,0,(c[2411614]|0)-e|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060]}RI();e=c[2394]|0;f=c[14130368+(e<<2)>>2]|0;if((f|0)!=0){gGC(f|0,9104152,280)|0}c[8452240+(e<<2)>>2]=c[2113054];c[2394]=-1;Ty();c[2405098]=0;c[3528632]=0}e=c[2385548]|0;if((e|0)>0){gGz(9752472,0,((e|0)>1?e<<2:4)|0)}c[2433530]=0;gGz(9550384,-1|0,6);e=0;f=-1;g=-1;do{f=((a[9631048+e|0]&1)<<e^f&65535)&65535;g=((a[9629464+e|0]&1)<<e^g&65535)&65535;e=e+1|0;}while((e|0)<16);b[4775193]=f;b[4775194]=g;c[2110938]=d[9633177]<<1|d[9633176];if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060]}g=c[2439330]|0;if((g|0)!=0){f=g;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;if(a[7045200]|0){f=0;g=0;while(1){c[2113056]=1666;e=RG(1666)|0;c[2113054]=(c[2113054]|0)+e;c[2276108]=-1;c[2113056]=-1;if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){e=gfc(596)|0;h=(c[2433530]|0)+e|0}else{h=(c[2433530]|0)+596|0}c[2433530]=h;e=c[2112964]|0;if((e|0)==0){i=g}else{j=a[9688]|0?5:0;k=e+(g<<1<<1)|0;e=c[2438058]&3;if((e|0)==1){gg[c[3542124]&4095](k,j)}else if((e|0)==0){gg[c[3542112]&4095](k,j)}else if((e|0)==2){gg[c[3542122]&4095](k,j)}if((c[2438058]&4|0)!=0){Uu(1,k,j)}Uu(0,k,j);i=j+g|0}j=f+1|0;if((j|0)<100){f=j;g=i}else{l=i;break}}}else{i=0;do{c[2113056]=1666;g=RG(1666)|0;c[2113054]=(c[2113054]|0)+g;c[2276108]=-1;c[2113056]=-1;UF(i*596|0)|0;i=i+1|0;}while((i|0)<100);i=c[2438224]|0;g=gGS(-1597636608,28447,i,(i|0)<0|0?-1:0)|0;i=g;UF(59659)|0;g=c[2443826]|0;if((g|0)<1073676288){c[2443826]=g-i}g=c[2443827]|0;if((g|0)<1073676288){c[2443827]=g-i}g=(c[3528508]|0)-i|0;c[3528508]=(g|0)<0?0:g;l=0}c[8452200+(c[2394]<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0<1024){RH(4)}g=c[2112964]|0;i=a[9688]|0?534:0;do{if((g|0)==0|a[7045200]){if((i|0)==(l|0)){break}f=i-l|0;h=g+(l<<1<<1)|0;j=c[2438058]&3;if((j|0)==2){gg[c[3542122]&4095](h,f)}else if((j|0)==0){gg[c[3542112]&4095](h,f)}else if((j|0)==1){gg[c[3542124]&4095](h,f)}if((c[2438058]&4|0)!=0){Uu(1,h,f)}Uu(0,h,f)}else{f=c[2438058]&3;if((f|0)==0){gg[c[3542112]&4095](g,i)}else if((f|0)==1){gg[c[3542124]&4095](g,i)}else if((f|0)==2){gg[c[3542122]&4095](g,i)}if((c[2438058]&4|0)!=0){Uu(1,g,i)}Uu(0,g,i)}}while(0);i=c[1836236]|0;g=c[9757320+(i<<2)>>2]|0;if((g|0)!=0){l=g;gGC(l|0,9706056,76)|0}c[9752472+(i<<2)>>2]=c[2433530];c[14113936+(i<<2)>>2]=c[2076596];c[9669104+(i<<2)>>2]=c[3541536];c[1836236]=-1;i=c[2394]|0;l=c[14130368+(i<<2)>>2]|0;if((l|0)!=0){gGC(l|0,9104152,280)|0}c[8452240+(i<<2)>>2]=c[2113054];c[2394]=-1;if((c[2112968]|0)==0){return 0}i=c[(c[642608+(c[2436]<<2)>>2]|0)+112>>2]|0;if((i|0)==0){return 0}gD[i&8191]()|0;return 0}function ejC(){ejJ(0,0);return 0}function ejD(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=i;i=i+96|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;l=e+80|0;if((d|0)!=0){c[d>>2]=169734}if((b&32|0)!=0){gGz(l|0,0,12);m=c[2414640]|0;c[l>>2]=m;c[l+4>>2]=(c[2411614]|0)-m;c[l+12>>2]=162152;m=c[2076592]|0;gj[m&4095](l)|0}if((b&64|0)==0){i=e;return 0}l=h|0;gGz(g|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){m=h+9|0;h=f;n=f|0;o=f+4|0;p=f+12|0;q=g|0;r=g+4|0;s=g+12|0;t=0;do{gGC(l|0,614896,11)|0;a[m]=t+48&255;u=8452256+(t<<2)|0;gGz(h|0,0,12);c[n>>2]=u;c[o>>2]=4;c[p>>2]=164976;gj[c[2076592]&4095](f)|0;if((c[u>>2]|0)!=0){c[q>>2]=c[14130368+(t<<2)>>2];c[r>>2]=c[8452184+(t<<2)>>2];c[s>>2]=l;u=c[2076592]|0;gj[u&4095](g)|0}t=t+1|0;}while((t|0)<=(c[2392]|0))}TF(d,b);gGz(k|0,0,12);c[k>>2]=9620392;c[k+4>>2]=4;c[k+12>>2]=492016;gj[c[2076592]&4095](k)|0;gGz(j|0,0,12);c[j>>2]=14114528;c[j+4>>2]=4;c[j+12>>2]=276232;gj[c[2076592]&4095](j)|0;i=e;return 0}function ejE(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2316444+(b*112|0)>>2];c[a+104>>2]=c[2316448+(b*112|0)>>2];c[a+108>>2]=c[2316452+(b*112|0)>>2];d=0;return d|0}function ejF(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=2316344+(b*112|0);e=0;return e|0}function ejG(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>43){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3516016+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function ejH(){var a=0,d=0;a=ejz()|0;if((a|0)!=0){return a|0}d=c[2388130]|0;b[d+1246>>1]=16965;b[d+1248>>1]=20081;b[d+1250>>1]=20081;b[d+4950>>1]=20081;b[d+4952>>1]=20081;return a|0}function ejI(){ejJ(128,16);return 0}function ejJ(d,f){d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;if((a[9547344]|0)!=0){g=c[2387170]|0;h=c[3529976]|0;i=0;do{j=b[g+(i<<1)>>1]|0;c[h+(i<<2)>>2]=((j&65535)>>>10<<3&65535)>>>3&31|((j&255)<<3&255)<<8|(((j&65535)>>>5<<3&255|(j&65535)>>>7&4)&255)<<3&2016;i=i+1|0;}while((i|0)<2048)}do{if((c[3528632]&1|0)==0){i=c[3530580]|0;h=c[2408990]|0;g=(e[h>>1]|0)+d&511;j=(e[h+2>>1]|0)+f&511;h=c[2406564]|0;k=c[2112926]|0;l=c[2113070]|0;m=c[2113068]|0;n=0;while(1){o=(n<<4&496)-g|0;p=(o|0)<-15?o+512|0:o;o=(n>>5<<4)-j|0;q=(o|0)<-15?o+512|0:o;o=e[h+(n<<1)>>1]|0;if((q|0)<(l|0)&(p|0)<(m|0)){Sz(k,o&4095,p,q,o>>>12,4,1024,i)}o=n+1|0;if((o|0)<1024){n=o}else{r=l;s=m;break}}}else{m=c[2113068]|0;l=c[2113070]|0;n=ag(l,m)|0;if((n|0)<=0){r=l;s=m;break}i=c[2112926]|0;k=0;while(1){b[i+(k<<1)>>1]=15;h=k+1|0;if((h|0)<(n|0)){k=h}else{r=l;s=m;break}}}}while(0);ejK(2,f);if((c[3528632]&2|0)==0){m=c[3530326]|0;l=c[2408990]|0;k=c[2405098]|0;n=(e[l+4>>1]|0)+d&511;i=(e[l+6>>1]|0)+f&511;l=c[2406308]|0;h=c[2112926]|0;j=0;do{g=(j<<4&496)-n|0;o=(g|0)<-15?g+512|0:g;g=(j>>5<<4)-i|0;q=(g|0)<-15?g+512|0:g;g=e[l+(j<<1)>>1]|0;if((q|0)<(r|0)&(o|0)<(s|0)){SH(h,g&4095|k,o,q,g>>>12,4,15,1280,m)}j=j+1|0;}while((j|0)<1024)}ejK(1,f);if((c[3528632]&4|0)==0){j=c[3530418]|0;m=c[2408990]|0;k=(e[m+8>>1]|0)+d&511;h=(e[m+10>>1]|0)+f&511;m=c[2406486]|0;l=c[2112926]|0;i=0;do{n=(i<<4&496)-k|0;g=(n|0)<-15?n+512|0:n;n=(i>>5<<4)-h|0;q=(n|0)<-15?n+512|0:n;n=e[m+(i<<1)>>1]|0;if((q|0)<(r|0)&(g|0)<(s|0)){SH(l,n&4095,g,q,n>>>12,4,15,1536,j)}i=i+1|0;}while((i|0)<1024)}ejK(0,f);i=c[2405796]|0;j=c[2112926]|0;l=c[3530816]|0;m=0;do{h=(m<<3&504)-d|0;k=(h|0)<-7?h+512|0:h;h=(m>>6<<3)-f|0;n=(h|0)<-7?h+256|0:h;if((k|0)<(s|0)&(n|0)<(r|0)){h=e[i+(m<<1)>>1]|0;Sr(j,h&4095,k,n,h>>>12,4,15,1792,l)}m=m+1|0;}while((m|0)<2048);ejK(3,f);R8(c[3529976]|0);return}function ejK(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;d=c[2386434]|0;f=1024;do{g=e[d+(f<<1)>>1]|0;do{if((g&32768|0)!=0){h=e[d+((f|1)<<1)>>1]|0;if((h>>>14|0)!=(a|0)){break}i=e[d+((f|3)<<1)>>1]|0;j=e[d+((f|2)<<1)>>1]|0;k=(j&32768|0)==0?j&511:j|-512;j=g&63;l=g&16384;m=g&8192;n=g>>>7&7;o=n+1|0;p=g>>>10&7;q=p+1|0;r=((i&32768|0)==0?i&511:i|-512)-b|0;i=g&24576;s=(i|0)==0;t=h&16383;h=0;while(1){u=(h<<4)+k|0;v=(p-h<<4)+k|0;if(s){w=t;x=0;while(1){y=(x<<4)+r|0;ejL(w,j,u,y,l,m);ejL(w,j,u,y+512|0,l,m);ejL(w,j,u,y-512|0,l,m);y=w+1&16383;z=x+1|0;if((z|0)<(o|0)){w=y;x=z}else{A=y;break}}}else{x=t;w=0;while(1){if((i|0)==16384){y=(w<<4)+r|0;ejL(x,j,v,y,l,m);ejL(x,j,v,y+512|0,l,m);ejL(x,j,v,y-512|0,l,m)}else if((i|0)==8192){y=(n-w<<4)+r|0;ejL(x,j,u,y,l,m);ejL(x,j,u,y+512|0,l,m);ejL(x,j,u,y-512|0,l,m)}else{y=(n-w<<4)+r|0;ejL(x,j,v,y,l,m);ejL(x,j,v,y+512|0,l,m);ejL(x,j,v,y-512|0,l,m)}y=x+1&16383;z=w+1|0;if((z|0)<(o|0)){x=y;w=z}else{A=y;break}}}w=h+1|0;if((w|0)<(q|0)){t=A;h=w}else{break}}}}while(0);f=f-4|0;}while((f|0)>-1);return}function ejL(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;if(!((e|0)>-16&(d|0)>-16&(c[2113068]|0)>(d|0)&(c[2113070]|0)>(e|0))){return}h=(f|0)!=0;f=c[2112926]|0;i=c[3530292]|0;if((g|0)==0){if(h){SJ(f,a,d,e,b,4,15,0,i);return}else{SH(f,a,d,e,b,4,15,0,i);return}}else{if(h){SN(f,a,d,e,b,4,15,0,i);return}else{SL(f,a,d,e,b,4,15,0,i);return}}}function ejM(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((e&61440|0)!=49152){return}a[(c[2386432]|0)+(e&4095)|0]=d;a[(c[2439602]|0)+((b<<3&2040|b&2048|(b&65535)>>>8&7)&65535)|0]=d;return}function ejN(b){b=b|0;var e=0,f=0,g=0,h=0;e=b&65535;if((e&61440|0)!=57344){f=0;return f|0}b=e&4095;if((b|0)==4064){c[2388360]=180;f=0;return f|0}else if((b|0)==4082|(b|0)==4083){g=c[2387866]|0;h=ag((d[g+4083|0]|0)<<8|(d[g+4082|0]|0),(d[g+4081|0]|0)<<8|(d[g+4080|0]|0))|0;if((e&1|0)==0){f=h&255;return f|0}else{f=h>>>8&255;return f|0}}else if((b|0)==4084){f=(cT()|0)&255;return f|0}else{f=a[(c[2387866]|0)+b|0]|0;return f|0}return 0}function ejO(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=d&255;if((f|0)==2){d=c[1836236]|0;g=c[9757320+(d<<2)>>2]|0;if((g|0)!=0){h=g;gGC(h|0,9706056,76)|0}c[9752472+(d<<2)>>2]=c[2433530];c[14113936+(d<<2)>>2]=c[2076596];c[9669104+(d<<2)>>2]=c[3541536];c[1836236]=-1;d=c[2439331]|0;if((d|0)!=0){h=d;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;h=(c[2433530]|0)+12|0;c[2433530]=h;d=c[1836236]|0;g=c[9757320+(d<<2)>>2]|0;if((g|0)!=0){i=g;gGC(i|0,9706056,76)|0}c[9752472+(d<<2)>>2]=h;c[14113936+(d<<2)>>2]=c[2076596];c[9669104+(d<<2)>>2]=c[3541536];c[1836236]=-1;d=c[2439330]|0;if((d|0)!=0){h=d;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;return}else if((f|0)==0){f=c[3529236]|0;h=c[9757320+(c[1836236]<<2)>>2]|0;d=((e&255)<<14&114688)-32768|0;e=128;i=128;while(1){c[h+76+(i<<2)>>2]=f+(d+(i<<8));g=e+1&65535;if((g&65535)>191){j=128;k=128;break}else{e=g;i=g&65535}}while(1){i=f+(d+(k<<8))|0;c[h+76+(k+512<<2)>>2]=i;c[h+76+(k+768<<2)>>2]=i;i=j+1&65535;if((i&65535)>191){break}else{j=i;k=i&65535}}return}else{return}}function ejP(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=d&65535;switch(f&255|0){case 2:{a[c[3528252]|0]=e;a[c[2440208]|0]=1;d=c[1836236]|0;g=c[9757320+(d<<2)>>2]|0;if((g|0)!=0){h=g;gGC(h|0,9706056,76)|0}c[9752472+(d<<2)>>2]=c[2433530];c[14113936+(d<<2)>>2]=c[2076596];c[9669104+(d<<2)>>2]=c[3541536];c[1836236]=-1;d=c[2439332]|0;if((d|0)!=0){h=d;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438120];c[2076596]=c[3528486];c[3541536]=c[2417278];c[1836236]=2;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;h=(c[2433530]|0)+12|0;c[2433530]=h;d=c[1836236]|0;g=c[9757320+(d<<2)>>2]|0;if((g|0)!=0){i=g;gGC(i|0,9706056,76)|0}c[9752472+(d<<2)>>2]=h;c[14113936+(d<<2)>>2]=c[2076596];c[9669104+(d<<2)>>2]=c[3541536];c[1836236]=-1;d=c[2439331]|0;if((d|0)!=0){h=d;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;return};case 0:{h=c[3529192]|0;d=e&255;i=c[9757320+(c[1836236]<<2)>>2]|0;g=(d<<14&114688)-32768|0;j=128;k=128;while(1){c[i+76+(k<<2)>>2]=h+(g+(k<<8));l=j+1&65535;if((l&65535)>191){m=128;n=128;break}else{j=l;k=l&65535}}while(1){k=h+(g+(n<<8))|0;c[i+76+(n+512<<2)>>2]=k;c[i+76+(n+768<<2)>>2]=k;k=m+1&65535;if((k&65535)>191){break}else{m=k;n=k&65535}}a[c[3528688]|0]=e&16;c[2438932]=d&32;return};case 40:{a[c[2442892]|0]=e&12^12;return};case 4:case 6:case 8:case 10:case 12:{a[(c[2439576]|0)+(((f&15)-4|0)/2|0)|0]=e;return};default:{return}}}function ejQ(b){b=b|0;var d=0;switch(b&255|0){case 32:{d=a[9550376]|0;return d|0};case 34:{d=a[9550377]|0;return d|0};case 36:{d=a[c[2442892]|0]|a[9550378];return d|0};case 2:{a[c[2438902]|0]=0;d=a[c[2443720]|0]|0;return d|0};case 14:{d=((a[c[2440208]|0]<<1)+5&255)-(a[c[2438902]|0]|0)&255;return d|0};default:{d=0;return d|0}}return 0}function ejR(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;switch(b&255|0){case 2:{b=c[3541518]|0;e=b+256|0;a[b+304|0]=d;f=d&255;if((d&255)<16){c[14168912+((c[2383582]|0)*252|0)>>2]=f&15}if((d-45&255)>=3){return}if((f|0)==0){a[b+312|0]=2;g=2}else if((f|0)==45){h=b+312|0;i=a[h]|2;a[h]=i;g=i}else if((f|0)==47){a[b+312|0]=0;g=0}else if((f|0)==46){f=b+312|0;i=a[f]|1;a[f]=i;g=i}else{g=a[b+312|0]|0}b=g&3;g=c[7461744+(b<<2)>>2]|0;lI(e,g,g,c[7461728+(b<<2)>>2]|0);return};case 0:{b=c[3529170]|0;g=c[9757320+(c[1836236]<<2)>>2]|0;e=((d&255)<<14&114688)-32768|0;i=128;f=128;while(1){c[g+76+(f<<2)>>2]=b+(e+(f<<8));h=i+1&65535;if((h&65535)>191){j=128;k=128;break}else{i=h;f=h&65535}}while(1){f=b+(e+(k<<8))|0;c[g+76+(k+512<<2)>>2]=f;c[g+76+(k+768<<2)>>2]=f;f=j+1&65535;if((f&65535)>191){break}else{j=f;k=f&65535}}return};case 3:{lS(0,1,d);return};case 6:{a[c[2443720]|0]=d;a[c[2438902]|0]=1;return};case 4:{Uv(0,d);return};default:{return}}}function ejS(b){b=b|0;var e=0,f=0,g=0.0,i=0.0,j=0,k=0;e=b&255;if((e|0)==2){b=c[3541518]|0;f=b+296|0;g=+h[f>>3];do{if(g!=0.0){i=+h[6675];if(g-(i+ +gC[c[2429842]&255]())<=0.0){h[f>>3]=0.0;break}j=a[b+307|0]|-128;return j|0}}while(0);j=a[b+307|0]|0;return j|0}else if((e|0)==3){if((d[(c[3541518]|0)+304|0]|0)>=16){j=0;return j|0}b=c[2383582]|0;f=c[14168912+(b*252|0)>>2]|0;if((f|0)>15){j=0;return j|0}do{if((f|0)==14){k=c[14168896+(b*252|0)>>2]|0;if((k|0)==0){break}a[14168930+(b*252|0)|0]=gj[k&4095](0)|0}else if((f|0)==15){k=c[14168900+(b*252|0)>>2]|0;if((k|0)==0){break}a[14168931+(b*252|0)|0]=gj[k&4095](0)|0}}while(0);j=a[14168916+(b*252|0)+f|0]|0;return j|0}else if((e|0)==4){j=c[2113156]&255;return j|0}else if((e|0)==6){a[c[2440208]|0]=0;j=a[c[3528252]|0]|0;return j|0}else{j=0;return j|0}return 0}function ejT(b){b=b|0;return a[9634976]|0}function ejU(b){b=b|0;return a[9634977]|0}function ejV(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3172820+(b*112|0)>>2];c[a+104>>2]=c[3172824+(b*112|0)>>2];c[a+108>>2]=c[3172828+(b*112|0)>>2];d=0;return d|0}function ejW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=3172720+(b*112|0);e=0;return e|0}function ejX(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1326344+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function ejY(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>41){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4296808+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function ejZ(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0;e=i;i=i+1680|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;B=e+1200|0;C=e+1312|0;D=e+1320|0;E=e+1432|0;F=e+1440|0;G=e+1552|0;H=e+1560|0;I=e+1672|0;c[3528602]=c[(c[642608+(c[2436]<<2)>>2]|0)+52>>2]&32;c[2414936]=0;c[3529236]=0;c[3529192]=131072;c[3529170]=262144;c[3530814]=393216;c[3530578]=1441792;c[3541206]=5636096;c[2386628]=5636096;c[3529974]=5898240;c[2414638]=5902336;c[3529458]=5902336;c[3529422]=5904384;c[3529324]=5906432;c[3529284]=5910528;c[3529268]=5914624;c[3527300]=5922816;c[2387866]=5926912;c[2439602]=5931008;c[2386432]=5935104;c[2387168]=5939200;c[2439576]=5943296;c[3528252]=5943302;c[2443720]=5943303;c[2440208]=5943304;c[2438902]=5943305;c[2442892]=5943306;c[3528688]=5943307;c[2411612]=5943308;J=0;while(1){if((J|0)>=1024){break}K=9638528+(J<<2)|0;if((c[K>>2]|0)==0){L=60806;break}else{J=J+1|0}}do{if((L|0)==60806){J=gGq(5943308)|0;c[K>>2]=J;if((J|0)==0){break}c[2414936]=J;gGz(J|0,0,5943308);c[3529236]=J;c[3529192]=J+131072;c[3529170]=J+262144;c[3530814]=J+393216;c[3530578]=J+1441792;M=J+5636096|0;c[3541206]=M;c[2386628]=M;c[3529974]=J+5898240;M=J+5902336|0;c[2414638]=M;c[3529458]=M;c[3529422]=J+5904384;c[3529324]=J+5906432;c[3529284]=J+5910528;c[3529268]=J+5914624;c[3527300]=J+5922816;c[2387866]=J+5926912;c[2439602]=J+5931008;c[2386432]=J+5935104;c[2387168]=J+5939200;c[2439576]=J+5943296;c[3528252]=J+5943302;c[2443720]=J+5943303;c[2440208]=J+5943304;c[2438902]=J+5943305;c[2442892]=J+5943306;c[3528688]=J+5943307;M=J+5943308|0;c[2411612]=M;c[2414152]=M;if((c[3542200]|0)==0){N=1;i=e;return N|0}M=H+108|0;c[M>>2]=0;O=H+100|0;c[O>>2]=0;P=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[P&16383](H,0)|0;do{if((c[M>>2]|0)!=0){P=c[O>>2]|0;c[I>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](I,0,0)|0;if((P|0)<1){N=1;i=e;return N|0}if((gzL(J,0,0)|0)==0){break}else{N=1}i=e;return N|0}}while(0);J=c[3529192]|0;if((c[3542200]|0)==0){N=1;i=e;return N|0}O=F+108|0;c[O>>2]=0;M=F+100|0;c[M>>2]=0;P=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[P&16383](F,1)|0;do{if((c[O>>2]|0)!=0){P=c[M>>2]|0;c[G>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](G,1,0)|0;if((P|0)<1){N=1;i=e;return N|0}if((gzL(J,0,1)|0)==0){break}else{N=1}i=e;return N|0}}while(0);J=c[3529170]|0;if((c[3542200]|0)==0){N=1;i=e;return N|0}M=D+108|0;c[M>>2]=0;O=D+100|0;c[O>>2]=0;P=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[P&16383](D,2)|0;do{if((c[M>>2]|0)!=0){P=c[O>>2]|0;c[E>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](E,2,0)|0;if((P|0)<1){N=1;i=e;return N|0}if((gzL(J,0,2)|0)==0){break}else{N=1}i=e;return N|0}}while(0);J=c[3530814]|0;do{if((c[3528602]|0)==0){if((c[3542200]|0)==0){N=1;i=e;return N|0}O=n+108|0;c[O>>2]=0;M=n+100|0;c[M>>2]=0;P=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[P&16383](n,4)|0;do{if((c[O>>2]|0)!=0){P=c[M>>2]|0;c[o>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](o,4,0)|0;if((P|0)<1){N=1;i=e;return N|0}if((gzL(J,0,4)|0)==0){break}else{N=1}i=e;return N|0}}while(0);M=c[3530578]|0;if((c[3542200]|0)==0){N=1;i=e;return N|0}O=l+108|0;c[O>>2]=0;P=l+100|0;c[P>>2]=0;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Q&16383](l,5)|0;do{if((c[O>>2]|0)!=0){Q=c[P>>2]|0;c[m>>2]=9534384;R=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[R&16383](m,5,0)|0;if((Q|0)<1){N=1;i=e;return N|0}if((gzL(M,0,5)|0)==0){break}else{N=1}i=e;return N|0}}while(0);M=(c[3530578]|0)+524288|0;if((c[3542200]|0)==0){N=1;i=e;return N|0}P=j+108|0;c[P>>2]=0;O=j+100|0;c[O>>2]=0;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Q&16383](j,6)|0;do{if((c[P>>2]|0)!=0){Q=c[O>>2]|0;c[k>>2]=9534384;R=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[R&16383](k,6,0)|0;if((Q|0)<1){N=1;i=e;return N|0}if((gzL(M,0,6)|0)==0){break}else{N=1}i=e;return N|0}}while(0);M=c[2386628]|0;if((c[3542200]|0)==0){N=1;i=e;return N|0}O=f+108|0;c[O>>2]=0;P=f+100|0;c[P>>2]=0;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Q&16383](f,7)|0;if((c[O>>2]|0)==0){S=0;break}O=c[P>>2]|0;c[g>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](g,7,0)|0;if((O|0)<1){N=1;i=e;return N|0}if((gzL(M,0,7)|0)==0){S=0;break}else{N=1}i=e;return N|0}else{if((R6(J,3,2)|0)!=0){N=1;i=e;return N|0}if((R6((c[3530814]|0)+1|0,4,2)|0)!=0){N=1;i=e;return N|0}if((R6((c[3530814]|0)+262144|0,5,2)|0)!=0){N=1;i=e;return N|0}if((R6((c[3530814]|0)+262145|0,6,2)|0)!=0){N=1;i=e;return N|0}M=c[3530578]|0;if((c[3542200]|0)==0){N=1;i=e;return N|0}O=B+108|0;c[O>>2]=0;P=B+100|0;c[P>>2]=0;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Q&16383](B,7)|0;do{if((c[O>>2]|0)!=0){Q=c[P>>2]|0;c[C>>2]=9534384;R=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[R&16383](C,7,0)|0;if((Q|0)<1){N=1;i=e;return N|0}if((gzL(M,0,7)|0)==0){break}else{N=1}i=e;return N|0}}while(0);M=(c[3530578]|0)+131072|0;if((c[3542200]|0)==0){N=1;i=e;return N|0}P=z+108|0;c[P>>2]=0;O=z+100|0;c[O>>2]=0;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Q&16383](z,8)|0;do{if((c[P>>2]|0)!=0){Q=c[O>>2]|0;c[A>>2]=9534384;R=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[R&16383](A,8,0)|0;if((Q|0)<1){N=1;i=e;return N|0}if((gzL(M,0,8)|0)==0){break}else{N=1}i=e;return N|0}}while(0);M=(c[3530578]|0)+262144|0;if((c[3542200]|0)==0){N=1;i=e;return N|0}O=x+108|0;c[O>>2]=0;P=x+100|0;c[P>>2]=0;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Q&16383](x,9)|0;do{if((c[O>>2]|0)!=0){Q=c[P>>2]|0;c[y>>2]=9534384;R=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[R&16383](y,9,0)|0;if((Q|0)<1){N=1;i=e;return N|0}if((gzL(M,0,9)|0)==0){break}else{N=1}i=e;return N|0}}while(0);M=(c[3530578]|0)+393216|0;if((c[3542200]|0)==0){N=1;i=e;return N|0}P=v+108|0;c[P>>2]=0;O=v+100|0;c[O>>2]=0;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Q&16383](v,10)|0;do{if((c[P>>2]|0)!=0){Q=c[O>>2]|0;c[w>>2]=9534384;R=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[R&16383](w,10,0)|0;if((Q|0)<1){N=1;i=e;return N|0}if((gzL(M,0,10)|0)==0){break}else{N=1}i=e;return N|0}}while(0);M=(c[3530578]|0)+524288|0;if((c[3542200]|0)==0){N=1;i=e;return N|0}O=t+108|0;c[O>>2]=0;P=t+100|0;c[P>>2]=0;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Q&16383](t,11)|0;do{if((c[O>>2]|0)!=0){Q=c[P>>2]|0;c[u>>2]=9534384;R=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[R&16383](u,11,0)|0;if((Q|0)<1){N=1;i=e;return N|0}if((gzL(M,0,11)|0)==0){break}else{N=1}i=e;return N|0}}while(0);M=c[2386628]|0;if((c[3542200]|0)==0){N=1;i=e;return N|0}P=r+108|0;c[P>>2]=0;O=r+100|0;c[O>>2]=0;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Q&16383](r,12)|0;do{if((c[P>>2]|0)!=0){Q=c[O>>2]|0;c[s>>2]=9534384;R=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[R&16383](s,12,0)|0;if((Q|0)<1){N=1;i=e;return N|0}if((gzL(M,0,12)|0)==0){break}else{N=1}i=e;return N|0}}while(0);M=(c[2386628]|0)+131072|0;if((c[3542200]|0)==0){N=1;i=e;return N|0}O=p+108|0;c[O>>2]=0;P=p+100|0;c[P>>2]=0;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Q&16383](p,13)|0;if((c[O>>2]|0)==0){S=0;break}O=c[P>>2]|0;c[q>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](q,13,0)|0;if((O|0)<1){N=1;i=e;return N|0}if((gzL(M,0,13)|0)==0){S=0;break}else{N=1}i=e;return N|0}}while(0);while(1){if((S|0)>=1024){break}T=9638528+(S<<2)|0;if((c[T>>2]|0)==0){L=60871;break}else{S=S+1|0}}L80839:do{if((L|0)==60871){J=gGq(1048576)|0;c[T>>2]=J;if((J|0)==0){break}gGz(J|0,0,1048576);M=c[3530814]|0;O=0;while(1){P=a[M+O|0]|0;a[J+O|0]=P<<4|(P&255)>>>4;P=O+1|0;if((P|0)<524288){O=P}else{U=0;break}}do{O=U<<8;gGz(M+O|0,0,256);P=U<<10;Q=0;do{R=1<<3-Q;V=(c[703416+(Q<<2)>>2]|0)+P|0;W=0;do{X=V+(c[3946808+(W<<2)>>2]|0)|0;Y=(W<<4)+O|0;Z=0;do{_=X+(c[3946872+(Z<<2)>>2]|0)|0;if(((d[J+((_|0)/8|0)|0]|0)&128>>>((_&7)>>>0)|0)!=0){_=M+(Y+Z)|0;a[_]=(d[_]|0|R)&255}Z=Z+1|0;}while((Z|0)<16);W=W+1|0;}while((W|0)<16);Q=Q+1|0;}while((Q|0)<4);U=U+1|0;}while((U|0)<4096);M=c[3530578]|0;gGC(J|0,M|0,1048576)|0;Q=0;while(1){O=Q<<8;gGz(M+O|0,0,256);P=Q<<10;W=0;do{R=1<<3-W;V=(c[703416+(W<<2)>>2]|0)+P|0;Z=0;do{Y=V+(c[3946808+(Z<<2)>>2]|0)|0;X=(Z<<4)+O|0;_=0;do{$=Y+(c[3946872+(_<<2)>>2]|0)|0;if(((d[J+(($|0)/8|0)|0]|0)&128>>>(($&7)>>>0)|0)!=0){$=M+(X+_)|0;a[$]=(d[$]|0|R)&255}_=_+1|0;}while((_|0)<16);Z=Z+1|0;}while((Z|0)<16);W=W+1|0;}while((W|0)<4);W=Q+1|0;if((W|0)<8192){Q=W}else{aa=0;break}}while(1){if((aa|0)>=1024){break L80839}ab=9638528+(aa<<2)|0;if((c[ab>>2]|0)==(J|0)){break}else{aa=aa+1|0}}gGr(J);c[ab>>2]=0}}while(0);fwR(0);Q=c[2439330]|0;M=(Q|0)==0;if(!M){W=Q;gGC(9706056,W|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];W=c[3528484]|0;c[2076596]=W;O=c[2417276]|0;c[3541536]=O;c[1836236]=0;P=c[3529236]|0;Z=0;R=0;while(1){c[Q+76+(R<<2)>>2]=P+(R<<8);V=Z+1&65535;if((V&65535)>127){ac=0;ad=0;break}else{Z=V;R=V&65535}}while(1){R=P+(ad<<8)|0;c[Q+76+(ad+512<<2)>>2]=R;c[Q+76+(ad+768<<2)>>2]=R;R=ac+1&65535;if((R&65535)>127){break}else{ac=R;ad=R&65535}}P=c[2386432]|0;c[Q+844>>2]=P;c[Q+848>>2]=P+256;c[Q+852>>2]=P+512;c[Q+856>>2]=P+768;c[Q+860>>2]=P+1024;c[Q+864>>2]=P+1280;c[Q+868>>2]=P+1536;c[Q+872>>2]=P+1792;c[Q+876>>2]=P+2048;c[Q+880>>2]=P+2304;c[Q+884>>2]=P+2560;c[Q+888>>2]=P+2816;c[Q+892>>2]=P+3072;c[Q+896>>2]=P+3328;c[Q+900>>2]=P+3584;c[Q+904>>2]=P+3840;R=192;Z=192;while(1){V=P+((Z<<8)-49152)|0;c[Q+76+(Z+512<<2)>>2]=V;c[Q+76+(Z+768<<2)>>2]=V;V=R+1&65535;if((V&65535)>207){break}else{R=V;Z=V&65535}}Z=c[3529324]|0;c[Q+908>>2]=Z;c[Q+912>>2]=Z+256;c[Q+916>>2]=Z+512;c[Q+920>>2]=Z+768;c[Q+924>>2]=Z+1024;c[Q+928>>2]=Z+1280;c[Q+932>>2]=Z+1536;c[Q+936>>2]=Z+1792;c[Q+940>>2]=Z+2048;c[Q+944>>2]=Z+2304;c[Q+948>>2]=Z+2560;c[Q+952>>2]=Z+2816;c[Q+956>>2]=Z+3072;c[Q+960>>2]=Z+3328;c[Q+964>>2]=Z+3584;c[Q+968>>2]=Z+3840;R=208;P=208;while(1){c[Q+76+(P+256<<2)>>2]=Z+((P<<8)-53248);V=R+1&65535;if((V&65535)>223){ae=208;af=208;break}else{R=V;P=V&65535}}while(1){P=Z+((af<<8)-53248)|0;c[Q+76+(af+512<<2)>>2]=P;c[Q+76+(af+768<<2)>>2]=P;P=ae+1&65535;if((P&65535)>223){break}else{ae=P;af=P&65535}}if((c[3528602]|0)!=0){Z=c[2387866]|0;c[Q+972>>2]=Z;c[Q+976>>2]=Z+256;c[Q+980>>2]=Z+512;c[Q+984>>2]=Z+768;c[Q+988>>2]=Z+1024;c[Q+992>>2]=Z+1280;c[Q+996>>2]=Z+1536;c[Q+1e3>>2]=Z+1792;c[Q+1004>>2]=Z+2048;c[Q+1008>>2]=Z+2304;c[Q+1012>>2]=Z+2560;c[Q+1016>>2]=Z+2816;c[Q+1020>>2]=Z+3072;c[Q+1024>>2]=Z+3328;c[Q+1028>>2]=Z+3584;c[Q+1032>>2]=Z+3840}Z=c[2387866]|0;P=224;R=224;while(1){c[Q+76+(R+256<<2)>>2]=Z+((R<<8)-57344);V=P+1&65535;if((V&65535)>239){ah=224;ai=224;break}else{P=V;R=V&65535}}while(1){R=Z+((ai<<8)-57344)|0;c[Q+76+(ai+512<<2)>>2]=R;c[Q+76+(ai+768<<2)>>2]=R;R=ah+1&65535;if((R&65535)>239){break}else{ah=R;ai=R&65535}}Z=c[3527300]|0;c[Q+1036>>2]=Z;c[Q+1040>>2]=Z+256;c[Q+1044>>2]=Z+512;c[Q+1048>>2]=Z+768;c[Q+1052>>2]=Z+1024;c[Q+1056>>2]=Z+1280;c[Q+1060>>2]=Z+1536;c[Q+1064>>2]=Z+1792;c[Q+1068>>2]=Z+2048;c[Q+1072>>2]=Z+2304;c[Q+1076>>2]=Z+2560;c[Q+1080>>2]=Z+2816;c[Q+1084>>2]=Z+3072;c[Q+1088>>2]=Z+3328;c[Q+1092>>2]=Z+3584;c[Q+1096>>2]=Z+3840;R=240;P=240;while(1){c[Q+76+(P+256<<2)>>2]=Z+((P<<8)-61440);V=R+1&65535;if((V&65535)>255){aj=240;ak=240;break}else{R=V;P=V&65535}}while(1){P=Z+((ak<<8)-61440)|0;c[Q+76+(ak+512<<2)>>2]=P;c[Q+76+(ak+768<<2)>>2]=P;P=aj+1&65535;if((P&65535)>255){break}else{aj=P;ak=P&65535}}c[Q+4184>>2]=2528;c[Q+4180>>2]=1602;c[Q+4176>>2]=288;if(!M){Z=Q;gGC(Z|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=W;c[2417276]=O;c[1836236]=-1;fwR(1);Z=c[2439331]|0;P=(Z|0)==0;if(!P){R=Z;gGC(9706056,R|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];R=c[3528485]|0;c[2076596]=R;V=c[2417277]|0;c[3541536]=V;c[1836236]=1;_=c[3529192]|0;X=0;Y=0;while(1){c[Z+76+(Y<<2)>>2]=_+(Y<<8);$=X+1&65535;if(($&65535)>127){al=0;am=0;break}else{X=$;Y=$&65535}}while(1){Y=_+(am<<8)|0;c[Z+76+(am+512<<2)>>2]=Y;c[Z+76+(am+768<<2)>>2]=Y;Y=al+1&65535;if((Y&65535)>127){break}else{al=Y;am=Y&65535}}_=c[3529422]|0;c[Z+844>>2]=_;Y=_+256|0;c[Z+848>>2]=Y;X=_+512|0;c[Z+852>>2]=X;O=_+768|0;c[Z+856>>2]=O;W=_+1024|0;c[Z+860>>2]=W;Q=_+1280|0;c[Z+864>>2]=Q;M=_+1536|0;c[Z+868>>2]=M;$=_+1792|0;c[Z+872>>2]=$;c[Z+1868>>2]=_;c[Z+1872>>2]=Y;c[Z+1876>>2]=X;c[Z+1880>>2]=O;c[Z+1884>>2]=W;c[Z+1888>>2]=Q;c[Z+1892>>2]=M;c[Z+1896>>2]=$;c[Z+2892>>2]=_;c[Z+3916>>2]=_;c[Z+2896>>2]=Y;c[Z+3920>>2]=Y;c[Z+2900>>2]=X;c[Z+3924>>2]=X;c[Z+2904>>2]=O;c[Z+3928>>2]=O;c[Z+2908>>2]=W;c[Z+3932>>2]=W;c[Z+2912>>2]=Q;c[Z+3936>>2]=Q;c[Z+2916>>2]=M;c[Z+3940>>2]=M;c[Z+2920>>2]=$;c[Z+3944>>2]=$;$=c[3529458]|0;c[Z+876>>2]=$;M=$+256|0;c[Z+880>>2]=M;Q=$+512|0;c[Z+884>>2]=Q;W=$+768|0;c[Z+888>>2]=W;O=$+1024|0;c[Z+892>>2]=O;X=$+1280|0;c[Z+896>>2]=X;Y=$+1536|0;c[Z+900>>2]=Y;_=$+1792|0;c[Z+904>>2]=_;c[Z+1900>>2]=$;c[Z+1904>>2]=M;c[Z+1908>>2]=Q;c[Z+1912>>2]=W;c[Z+1916>>2]=O;c[Z+1920>>2]=X;c[Z+1924>>2]=Y;c[Z+1928>>2]=_;c[Z+2924>>2]=$;c[Z+3948>>2]=$;c[Z+2928>>2]=M;c[Z+3952>>2]=M;c[Z+2932>>2]=Q;c[Z+3956>>2]=Q;c[Z+2936>>2]=W;c[Z+3960>>2]=W;c[Z+2940>>2]=O;c[Z+3964>>2]=O;c[Z+2944>>2]=X;c[Z+3968>>2]=X;c[Z+2948>>2]=Y;c[Z+3972>>2]=Y;c[Z+2952>>2]=_;c[Z+3976>>2]=_;_=c[2387168]|0;c[Z+908>>2]=_;c[Z+912>>2]=_+256;c[Z+916>>2]=_+512;c[Z+920>>2]=_+768;c[Z+924>>2]=_+1024;c[Z+928>>2]=_+1280;c[Z+932>>2]=_+1536;c[Z+936>>2]=_+1792;c[Z+940>>2]=_+2048;c[Z+944>>2]=_+2304;c[Z+948>>2]=_+2560;c[Z+952>>2]=_+2816;c[Z+956>>2]=_+3072;c[Z+960>>2]=_+3328;c[Z+964>>2]=_+3584;c[Z+968>>2]=_+3840;Y=208;X=208;while(1){c[Z+76+(X+256<<2)>>2]=_+((X<<8)-53248);O=Y+1&65535;if((O&65535)>223){an=208;ao=208;break}else{Y=O;X=O&65535}}while(1){X=_+((ao<<8)-53248)|0;c[Z+76+(ao+512<<2)>>2]=X;c[Z+76+(ao+768<<2)>>2]=X;X=an+1&65535;if((X&65535)>223){break}else{an=X;ao=X&65535}}_=c[3529284]|0;c[Z+972>>2]=_;c[Z+976>>2]=_+256;c[Z+980>>2]=_+512;c[Z+984>>2]=_+768;c[Z+988>>2]=_+1024;c[Z+992>>2]=_+1280;c[Z+996>>2]=_+1536;c[Z+1e3>>2]=_+1792;c[Z+1004>>2]=_+2048;c[Z+1008>>2]=_+2304;c[Z+1012>>2]=_+2560;c[Z+1016>>2]=_+2816;c[Z+1020>>2]=_+3072;c[Z+1024>>2]=_+3328;c[Z+1028>>2]=_+3584;c[Z+1032>>2]=_+3840;X=224;Y=224;while(1){c[Z+76+(Y+256<<2)>>2]=_+((Y<<8)-57344);O=X+1&65535;if((O&65535)>239){ap=224;aq=224;break}else{X=O;Y=O&65535}}while(1){Y=_+((aq<<8)-57344)|0;c[Z+76+(aq+512<<2)>>2]=Y;c[Z+76+(aq+768<<2)>>2]=Y;Y=ap+1&65535;if((Y&65535)>239){break}else{ap=Y;aq=Y&65535}}_=c[3527300]|0;c[Z+1036>>2]=_;c[Z+1040>>2]=_+256;c[Z+1044>>2]=_+512;c[Z+1048>>2]=_+768;c[Z+1052>>2]=_+1024;c[Z+1056>>2]=_+1280;c[Z+1060>>2]=_+1536;c[Z+1064>>2]=_+1792;c[Z+1068>>2]=_+2048;c[Z+1072>>2]=_+2304;c[Z+1076>>2]=_+2560;c[Z+1080>>2]=_+2816;c[Z+1084>>2]=_+3072;c[Z+1088>>2]=_+3328;c[Z+1092>>2]=_+3584;c[Z+1096>>2]=_+3840;Y=240;X=240;while(1){c[Z+76+(X+256<<2)>>2]=_+((X<<8)-61440);O=Y+1&65535;if((O&65535)>255){ar=240;as=240;break}else{Y=O;X=O&65535}}while(1){X=_+((as<<8)-61440)|0;c[Z+76+(as+512<<2)>>2]=X;c[Z+76+(as+768<<2)>>2]=X;X=ar+1&65535;if((X&65535)>255){break}else{ar=X;as=X&65535}}c[Z+4176>>2]=708;c[Z+4172>>2]=724;if(!P){_=Z;gGC(_|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=R;c[2417277]=V;c[1836236]=-1;fwR(2);_=c[2439332]|0;X=(_|0)==0;if(!X){Y=_;gGC(9706056,Y|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438120];Y=c[3528486]|0;c[2076596]=Y;O=c[2417278]|0;c[3541536]=O;c[1836236]=2;W=c[3529170]|0;Q=0;M=0;while(1){c[_+76+(M<<2)>>2]=W+(M<<8);$=Q+1&65535;if(($&65535)>127){at=0;au=0;break}else{Q=$;M=$&65535}}while(1){M=W+(au<<8)|0;c[_+76+(au+512<<2)>>2]=M;c[_+76+(au+768<<2)>>2]=M;M=at+1&65535;if((M&65535)>127){break}else{at=M;au=M&65535}}W=c[3529268]|0;M=192;Q=192;while(1){c[_+76+(Q<<2)>>2]=W+((Q<<8)-49152);V=M+1&65535;if((V&65535)>223){av=192;aw=192;break}else{M=V;Q=V&65535}}while(1){c[_+76+(aw+256<<2)>>2]=W+((aw<<8)-49152);Q=av+1&65535;if((Q&65535)>223){ax=192;ay=192;break}else{av=Q;aw=Q&65535}}while(1){Q=W+((ay<<8)-49152)|0;c[_+76+(ay+512<<2)>>2]=Q;c[_+76+(ay+768<<2)>>2]=Q;Q=ax+1&65535;if((Q&65535)>223){break}else{ax=Q;ay=Q&65535}}c[_+4176>>2]=1574;c[_+4172>>2]=928;if(!X){W=_;gGC(W|0,9706056,76)|0}c[2438120]=c[2433530];c[3528486]=Y;c[2417278]=O;c[1836236]=-1;Vr(1,3e6,0,2984,102,0);c[3542224]=1410;c[3542225]=2742;c[3542226]=0;c[3542227]=0;c[2438228]=6e6;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=340;h[745419]=.5;a[3203368]=1;h[745418]=.25;a[3203360]=1;h[745417]=.25;a[3203352]=1;h[745416]=.25;a[3203344]=1;Ux(0,22727,1);c[2407030]=205;c[2407068]=3;W=c[642608+(c[2436]<<2)>>2]|0;Q=c[W+128>>2]|0;if((c[W+52>>2]&4|0)==0){c[2113068]=Q;M=c[W+132>>2]|0;c[2113070]=M;c[2443814]=Q;c[2440436]=M;az=Q;aA=M}else{c[2113070]=Q;M=c[W+132>>2]|0;c[2113068]=M;c[2440436]=Q;c[2443814]=M;az=M;aA=Q}Q=ag(az<<1,aA)|0;M=gGq(Q)|0;c[2112926]=M;if((M|0)!=0){gGz(M|0,0,Q|0)}Q=c[3530578]|0;c[2443748]=c[2439602];a[2469272]=1;c[2443750]=Q;a[706352]=1;Q=c[642608+(c[2436]<<2)>>2]|0;M=c[Q+128>>2]|0;if((c[Q+52>>2]&4|0)==0){c[2113068]=M;W=c[Q+132>>2]|0;c[2113070]=W;aB=M;aC=W}else{c[2113070]=M;W=c[Q+132>>2]|0;c[2113068]=W;aB=W;aC=M}c[2440364]=gGq(ag(aC<<1,aB)|0)|0;c[2438932]=1;ej8(1);N=0;i=e;return N|0}}while(0);c[2414936]=0;N=1;i=e;return N|0}function ej_(){var b=0,d=0,e=0,f=0;b=c[2440364]|0;if((b|0)!=0){gGr(b);c[2440364]=0}c[2443750]=0;c[2443748]=0;c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}fwZ();Uw(0);b=c[3541518]|0;if((b|0)!=0){gGr(b|0);c[3541518]=0}if((c[2385508]|0)>0){c[2113008]=0;c[2076598]=0;c[2383582]=0}c[2438228]=0;c[2433526]=0;c[2406676]=0;c[3528472]=0;b=c[2406680]|0;if((b|0)!=0){gGr(b);c[2406680]=0}c[2385508]=0;c[2432978]=0;a[64240]=0;b=c[2414936]|0;d=0;while(1){if((d|0)>=1024){e=61017;break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==(b|0)){break}else{d=d+1|0}}if((e|0)==61017){c[2414936]=0;return 0}gGr(b);c[f>>2]=0;c[2414936]=0;return 0}function ej$(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;if((a[9623992]|0)!=0){ej8(1)}e=c[2388360]|0;if((c[3528602]|e|0)==0){ej8(0);f=c[2388360]|0}else{f=e}c[2388360]=f-1;f=c[2385548]|0;if((f|0)>0){gGz(9752472,0,((f|0)>1?f<<2:4)|0)}c[2433530]=0;gGz(9550376,-1|0,3);f=0;e=-1;g=-1;h=-1;do{e=((a[9633168+f|0]&1)<<f^e&255)&255;g=((a[9631040+f|0]&1)<<f^g&255)&255;h=((a[9629456+f|0]&1)<<f^h&255)&255;f=f+1|0;}while((f|0)<8);a[9550376]=e;a[9550377]=g;a[9550378]=h;h=0;g=0;e=0;while(1){f=e+1|0;i=f*1e3|0;j=c[2439330]|0;if((j|0)!=0){k=j;gGC(9706056,k|0,76)|0}b[4853030]=c[2426515]&65535;k=c[2438118]|0;c[2433530]=k;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;l=i-g|0;do{if((l|0)<1){m=0}else{if((a[j+4188|0]|0)==0){n=gfc(l)|0;c[2433530]=(c[2433530]|0)+n;m=n;break}else{c[2433530]=k+l;m=l;break}}}while(0);l=m+g|0;k=(e|0)==99;if((e|0)==99|(e|0)==49){j=c[2430476]^2;c[2430476]=j;a[14125144]=j&255;a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0}j=c[1836236]|0;n=c[9757320+(j<<2)>>2]|0;if((n|0)!=0){o=n;gGC(o|0,9706056,76)|0}c[9752472+(j<<2)>>2]=c[2433530];c[14113936+(j<<2)>>2]=c[2076596];c[9669104+(j<<2)>>2]=c[3541536];c[1836236]=-1;j=c[2439331]|0;if((j|0)!=0){o=j;gGC(9706056,o|0,76)|0}b[4853030]=c[2426515]&65535;o=c[2438119]|0;c[2433530]=o;c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;n=i-h|0;do{if((n|0)<1){p=0}else{if((a[j+4188|0]|0)==0){q=gfc(n)|0;c[2433530]=(c[2433530]|0)+q;p=q;break}else{c[2433530]=o+n;p=n;break}}}while(0);n=p+h|0;if((e|0)==99|(e|0)==49){o=c[2430474]^2;c[2430474]=o;a[14125144]=o&255;a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0}o=c[1836236]|0;j=c[9757320+(o<<2)>>2]|0;if((j|0)!=0){i=j;gGC(i|0,9706056,76)|0}c[9752472+(o<<2)>>2]=c[2433530];c[14113936+(o<<2)>>2]=c[2076596];c[9669104+(o<<2)>>2]=c[3541536];c[1836236]=-1;o=c[2439332]|0;if((o|0)!=0){i=o;gGC(9706056,i|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438120];c[2076596]=c[3528486];c[3541536]=c[2417278];c[1836236]=2;Sb(n);if(k){a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0}i=c[1836236]|0;o=c[9757320+(i<<2)>>2]|0;if((o|0)!=0){j=o;gGC(j|0,9706056,76)|0}c[9752472+(i<<2)>>2]=c[2433530];c[14113936+(i<<2)>>2]=c[2076596];c[9669104+(i<<2)>>2]=c[3541536];c[1836236]=-1;if((f|0)<100){h=n;g=l;e=f}else{break}}e=c[2439332]|0;if((e|0)!=0){g=e;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438120];c[2076596]=c[3528486];c[3541536]=c[2417278];c[1836236]=2;g=c[2438228]|0;e=gGS(-1220542464,47683,g,(g|0)<0|0?-1:0)|0;g=e;Sb(1e5);e=c[2443830]|0;if((e|0)<1073676288){c[2443830]=e-g}e=c[2443831]|0;if((e|0)<1073676288){c[2443831]=e-g}e=(c[3528512]|0)-g|0;c[3528512]=(e|0)<0?0:e;e=c[2112964]|0;if((e|0)!=0){gg[c[3542122]&4095](e,a[9688]|0?534:0);Uu(0,c[2112964]|0,a[9688]|0?534:0)}e=c[1836236]|0;g=c[9757320+(e<<2)>>2]|0;if((g|0)!=0){h=g;gGC(h|0,9706056,76)|0}c[9752472+(e<<2)>>2]=c[2433530];c[14113936+(e<<2)>>2]=c[2076596];c[9669104+(e<<2)>>2]=c[3541536];c[1836236]=-1;if((c[2112968]|0)!=0){ej0()|0}e=c[2440364]|0;if((c[2438932]|0)!=0){gGz(e|0,0,ag(c[2113068]<<1,c[2113070]|0)|0)}h=c[2443748]|0;g=(c[2112890]|0)==0;p=a[2469272]|0?-16:0;m=a[706352]|0?512:0;n=c[2443750]|0;i=0;j=0;o=0;while(1){q=d[h+(j|7)|0]|0;r=q<<8&16128|d[h+(j|6)|0];s=d[h+(j|5)|0]|0;t=d[h+(j|4)|0]|0;u=d[h+(j|3)|0]|0;v=q&64;w=(u&1|0)==0?t:t|256;t=(u&2|0)==0?s:s|256;if((u&4|0)==0){x=w;y=t}else{x=w+o|0;y=t+i|0}if(g){z=q&128;A=v;B=x;C=y}else{z=q>>>7^1;A=v>>>6^1;B=240-x|0;C=240-y|0}v=p+C|0;q=(B&256|0)==0?B&511:B|-512;t=(v&256|0)==0?v&511:v|-512;do{if(!((q|0)>=(c[2113068]|0)|(q|0)<-15)){if((t|0)>=(c[2113070]|0)|(t|0)<-15){break}v=(z|0)!=0;w=u>>>4;if((A|0)==0){if(v){SJ(e,r,q,t,w,4,0,m,n);break}else{SH(e,r,q,t,w,4,0,m,n);break}}else{if(v){SN(e,r,q,t,w,4,0,m,n);break}else{SL(e,r,q,t,w,4,0,m,n);break}}}}while(0);t=j+8|0;if((t|0)<4096){i=y;j=t;o=x}else{break}}return 0}function ej0(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=c[2387168]|0;f=c[3529974]|0;g=0;do{h=a[e+(g|1)|0]|0;i=a[e+g|0]|0;c[f+(((g|0)/2|0)<<2)>>2]=(((h&255)>>>2<<3|(h&255)>>>4&4)&255)<<3&2016|(i<<3&255)>>>3|((h&255)<<8|i&255)>>>5<<11&63488;g=g+2|0;}while((g|0)<1536);ej7(c[3529458]|0,3,6,2,5,0);ej7(c[3529422]|0,1,8,0,7,1);c[2112890]=d[c[3528688]|0]|0;g=c[2112926]|0;e=c[2113068]|0;i=c[2113070]|0;if((ag(i,e)|0)<=0){R8(f);return 0}h=c[2440364]|0;j=0;do{k=b[h+(j<<1)>>1]|0;if(k<<16>>16!=0){b[g+(j<<1)>>1]=k&1023}j=j+1|0;}while((j|0)<(ag(e,i)|0));R8(f);return 0}function ej1(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=i;i=i+16|0;e=d|0;if((b|0)!=0){c[b>>2]=169735}if((a&96|0)==0){i=d;return 0}gGz(e|0,0,12);f=c[2414638]|0;c[e>>2]=f;c[e+4>>2]=(c[2411612]|0)-f;c[e+12>>2]=162152;gj[c[2076592]&4095](e)|0;fw$(a);Vx(a,b);Ut(0);i=d;return 0}function ej2(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1622788+(b*112|0)>>2];c[a+104>>2]=c[1622792+(b*112|0)>>2];c[a+108>>2]=c[1622796+(b*112|0)>>2];d=0;return d|0}function ej3(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=1622688+(b*112|0);e=0;return e|0}function ej4(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>30){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4297312+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function ej5(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1623684+(b*112|0)>>2];c[a+104>>2]=c[1623688+(b*112|0)>>2];c[a+108>>2]=c[1623692+(b*112|0)>>2];d=0;return d|0}function ej6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=1623584+(b*112|0);e=0;return e|0}function ej7(b,e,f,g,h,i){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0;j=c[2439576]|0;k=~d[j+4|0];l=k<<f&256|d[j+e|0];e=k<<h&256|d[j+g|0];g=c[3528688]|0;if((a[g]|0)==0){m=l+364|0;n=e+272|0}else{m=l+106|0;n=e+527|0}e=m&511;m=n&511;n=c[2112926]|0;l=c[3530814]|0;j=c[2113068]|0;h=c[2113070]|0;if((i|0)==0){i=0;do{k=(i<<4&496)-e|0;f=(k|0)<-15?k+512|0:k;k=(i>>5<<4)-m|0;o=(k|0)<-15?k+512|0:k;do{if((f|0)<(j|0)&(o|0)<(h|0)){k=d[b+(i+1024)|0]|0;p=k<<8&3840|d[b+i|0];if((a[g]|0)==0){Sz(n,p,f,o,k>>>4,4,256,l);break}else{SF(n,p,240-f|0,240-o|0,k>>>4,4,256,l);break}}}while(0);i=i+1|0;}while((i|0)<1024);return}else{i=0;do{o=(i<<4&496)-e|0;f=(o|0)<-15?o+512|0:o;o=(i>>5<<4)-m|0;k=(o|0)<-15?o+512|0:o;do{if((f|0)<(j|0)&(k|0)<(h|0)){o=d[b+(i+1024)|0]|0;p=o<<8&3840|d[b+i|0];if((a[g]|0)==0){SH(n,p,f,k,o>>>4,4,0,0,l);break}else{SN(n,p,240-f|0,240-k|0,o>>>4,4,0,0,l);break}}}while(0);i=i+1|0;}while((i|0)<1024);return}}function ej8(d){d=d|0;var e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;if((d|0)!=0){d=c[2414638]|0;gGz(d|0,0,(c[2411612]|0)-d|0)}d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=i;c[1836236]=-1;i=c[2439331]|0;g=(i|0)==0;if(!g){f=i;gGC(9706056,f|0,76)|0}f=c[2438119]|0;c[2433530]=f;e=c[3528485]|0;c[2076596]=e;d=c[2417277]|0;c[3541536]=d;c[1836236]=1;gGz(9706056,0,76);if(!g){g=i;gGC(g|0,9706056,76)|0}c[2438119]=f;c[3528485]=e;c[2417277]=d;c[1836236]=-1;d=c[2439332]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438120]|0;c[2433530]=f;g=c[3528486]|0;c[2076596]=g;i=c[2417278]|0;c[3541536]=i;c[1836236]=2;gGz(9706056,0,76);if(!e){j=d;gGC(j|0,9706056,76)|0}c[2438120]=f;c[3528486]=g;c[2417278]=i;c[1836236]=-1;c[2113156]=0;a[9628264]=0;c[2407033]=0;j=c[3541206]|0;c[3541190]=j;c[3541198]=j;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=j+256;c[3541199]=j+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=j+512;c[3541200]=j+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=j+768;c[3541201]=j+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;if(!e){e=d;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=f;c[2076596]=g;c[3541536]=i;c[1836236]=2;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){i=0;do{lN(i);mB(i);i=i+1|0;}while((i|0)<(c[2385508]|0));i=c[1836236]|0;k=i;l=c[9757320+(i<<2)>>2]|0}else{k=2;l=d}if((l|0)==0){m=c[2433530]|0;n=9752472+(k<<2)|0;c[n>>2]=m;o=c[2076596]|0;p=14113936+(k<<2)|0;c[p>>2]=o;q=c[3541536]|0;r=9669104+(k<<2)|0;c[r>>2]=q;c[1836236]=-1;c[2430476]=255;c[2430474]=253;c[2388360]=180;s=gb(0)|0;eC(s|0);return}d=l;gGC(d|0,9706056,76)|0;m=c[2433530]|0;n=9752472+(k<<2)|0;c[n>>2]=m;o=c[2076596]|0;p=14113936+(k<<2)|0;c[p>>2]=o;q=c[3541536]|0;r=9669104+(k<<2)|0;c[r>>2]=q;c[1836236]=-1;c[2430476]=255;c[2430474]=253;c[2388360]=180;s=gb(0)|0;eC(s|0);return}function ej9(a){a=a|0;var b=0,d=0;b=(c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,6e6,0)|0;return a|0}function eka(){return+(+((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)/6.0e6)}function ekb(a){a=a|0;var b=0;switch(a|0){case 524296:case 524297:{b=(e[4774852]|0)>>>((a<<3&8^8)>>>0)&255;return b|0};case 524290:case 524291:{b=(e[4774896]|0)>>>((a<<3&8^8)>>>0)&255;return b|0};case 524298:case 524299:{b=(e[4774836]|0)>>>((a<<3&8^8)>>>0)&255;return b|0};case 524288:case 524289:{b=(e[4774980]|0)>>>((a<<3&8^8)>>>0)&255;return b|0};default:{b=0;return b|0}}return 0}function ekc(a){a=a|0;var c=0;if((a|0)==524290){c=b[4774896]|0}else if((a|0)==524288){c=b[4774980]|0}else if((a|0)==524296){c=b[4774852]|0}else if((a|0)==524298){c=b[4774836]|0}else{c=0}return c|0}function ekd(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((d&1048064|0)==557056){f=d&510;b[(c[2387166]|0)+f>>1]=e;g=e&65535;h=g>>>3;i=(e&65535)>>>11&255&30;j=i|h&1;k=(e&65535)>>>7&255&30;l=h&30;h=l|g>>>1&1;m=(k|g>>>2&1)<<3|k>>>2;k=f>>>1;c[(c[2406926]|0)+(k<<2)>>2]=h<<3|l>>>2|m<<8|(j<<3|i>>>2)<<16;c[(c[3529972]|0)+(k<<2)>>2]=j<<11|h|m<<3&2016;return}if((d|0)==540672){a[14113e3]=(e&65535)>>>8&255;a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0;return}else if((d|0)==737280){a[9553832]=e&7;return}else{return}}function eke(b,c){b=b|0;c=c|0;if((b|0)==737281){a[9553832]=c&7;return}else if((b|0)==540672){a[14113e3]=c;a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0;return}else{return}}function ekf(a,b){a=a|0;b=b|0;if(a<<16>>16!=-26624){return}Uv(0,b);return}function ekg(b){b=b|0;var d=0,e=0;d=b&65535;if((d|0)==40960){e=a[14113e3]|0}else if((d|0)==38912){e=c[2113156]&255}else{e=0}return e|0}function ekh(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>5){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2059788+(b*112|0)>>2];c[a+104>>2]=c[2059792+(b*112|0)>>2];c[a+108>>2]=c[2059796+(b*112|0)>>2];d=0;return d|0}function eki(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<6&(d|0)==0)){e=1;return e|0}c[a>>2]=2059688+(b*112|0);e=0;return e|0}function ekj(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6925312+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function ekk(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>28){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7434952+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function ekl(){var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;e=i;i=i+480|0;f=e|0;g=e+112|0;h=e+120|0;j=e+232|0;k=e+240|0;l=e+352|0;m=e+360|0;n=e+472|0;c[2414934]=0;c[2388128]=0;c[2385904]=131072;c[2387814]=163840;c[3541206]=1212416;c[2386626]=1212416;c[3529972]=1474560;c[2414636]=1475584;c[2388256]=1475584;c[2387166]=1541120;c[2386204]=1541632;c[2386058]=1558016;c[2406926]=1560064;c[2411610]=1561088;o=0;while(1){if((o|0)>=1024){break}p=9638528+(o<<2)|0;if((c[p>>2]|0)==0){q=61247;break}else{o=o+1|0}}do{if((q|0)==61247){o=gGq(1561088)|0;c[p>>2]=o;if((o|0)==0){break}c[2414934]=o;gGz(o|0,0,1561088);c[2388128]=o;c[2385904]=o+131072;c[2387814]=o+163840;r=o+1212416|0;c[3541206]=r;c[2386626]=r;c[3529972]=o+1474560;r=o+1475584|0;c[2414636]=r;c[2388256]=r;c[2387166]=o+1541120;c[2386204]=o+1541632;c[2386058]=o+1558016;c[2406926]=o+1560064;r=o+1561088|0;c[2411610]=r;c[2414150]=r;if((R6(o+1|0,0,2)|0)!=0){s=1;i=e;return s|0}if((R6(c[2388128]|0,1,2)|0)!=0){s=1;i=e;return s|0}o=c[2385904]|0;if((c[3542200]|0)==0){s=1;i=e;return s|0}r=m+108|0;c[r>>2]=0;t=m+100|0;c[t>>2]=0;u=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[u&16383](m,2)|0;do{if((c[r>>2]|0)!=0){u=c[t>>2]|0;c[n>>2]=9534384;v=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[v&16383](n,2,0)|0;if((u|0)<1){s=1;i=e;return s|0}if((gzL(o,0,2)|0)==0){break}else{s=1}i=e;return s|0}}while(0);o=c[2387814]|0;if((c[3542200]|0)==0){s=1;i=e;return s|0}t=k+108|0;c[t>>2]=0;r=k+100|0;c[r>>2]=0;u=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[u&16383](k,3)|0;do{if((c[t>>2]|0)!=0){u=c[r>>2]|0;c[l>>2]=9534384;v=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[v&16383](l,3,0)|0;if((u|0)<1){s=1;i=e;return s|0}if((gzL(o,0,3)|0)==0){break}else{s=1}i=e;return s|0}}while(0);o=c[2386626]|0;if((c[3542200]|0)==0){s=1;i=e;return s|0}r=h+108|0;c[r>>2]=0;t=h+100|0;c[t>>2]=0;u=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[u&16383](h,4)|0;do{if((c[r>>2]|0)!=0){u=c[t>>2]|0;c[j>>2]=9534384;v=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[v&16383](j,4,0)|0;if((u|0)<1){s=1;i=e;return s|0}if((gzL(o,0,4)|0)==0){break}else{s=1}i=e;return s|0}}while(0);o=(c[2386626]|0)+131072|0;if((c[3542200]|0)==0){s=1;i=e;return s|0}t=f+108|0;c[t>>2]=0;r=f+100|0;c[r>>2]=0;u=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[u&16383](f,5)|0;do{if((c[t>>2]|0)==0){w=0}else{u=c[r>>2]|0;c[g>>2]=9534384;v=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[v&16383](g,5,0)|0;if((u|0)<1){s=1;i=e;return s|0}if((gzL(o,0,5)|0)==0){w=0;break}else{s=1}i=e;return s|0}}while(0);while(1){if((w|0)>=1024){break}x=9638528+(w<<2)|0;if((c[x>>2]|0)==0){q=61269;break}else{w=w+1|0}}L81334:do{if((q|0)==61269){o=gGq(524288)|0;c[x>>2]=o;if((o|0)==0){break}gGz(o|0,0,524288);r=c[2387814]|0;gGC(o|0,r|0,524288)|0;t=0;while(1){u=t<<6;gGz(r+u|0,0,64);v=t<<8;y=0;do{z=1<<3-y;A=(c[703416+(y<<2)>>2]|0)+v|0;B=0;do{C=A+(c[1183816+(B<<2)>>2]|0)|0;D=(B<<3)+u|0;E=0;do{F=C+(c[1934976+(E<<2)>>2]|0)|0;if(((d[o+((F|0)/8|0)|0]|0)&128>>>((F&7)>>>0)|0)!=0){F=r+(D+E)|0;a[F]=(d[F]|0|z)&255}E=E+1|0;}while((E|0)<8);B=B+1|0;}while((B|0)<8);y=y+1|0;}while((y|0)<4);y=t+1|0;if((y|0)<16384){t=y}else{G=0;break}}while(1){if((G|0)>=1024){break L81334}H=9638528+(G<<2)|0;if((c[H>>2]|0)==(o|0)){break}else{G=G+1|0}}gGr(o);c[H>>2]=0}}while(0);fxU(0,425984);if((c[2394]|0)==0){I=c[2112932]|0}else{c[2394]=0;t=c[3532596]|0;c[2112932]=t;r=c[3532592]|0;if((r|0)!=0){gGC(9104152,r|0,280)|0}c[2113054]=c[2113060];I=t}t=c[2388128]|0;r=I|0;y=0;while(1){u=t+y|0;c[r>>2]=u;c[r+131072>>2]=u;u=y+1024|0;if(u>>>0>131071){break}else{r=r+4|0;y=u}}y=c[2387166]|0;c[I+2176>>2]=y;c[I+133248>>2]=y;y=c[2386204]|0;r=y-512|0;c[I+2508>>2]=r;c[I+68044>>2]=r;c[I+133580>>2]=r;r=y+512|0;c[I+2512>>2]=r;c[I+68048>>2]=r;c[I+133584>>2]=r;r=y+1536|0;c[I+2516>>2]=r;c[I+68052>>2]=r;c[I+133588>>2]=r;r=y+2560|0;c[I+2520>>2]=r;c[I+68056>>2]=r;c[I+133592>>2]=r;r=y+3584|0;c[I+2524>>2]=r;c[I+68060>>2]=r;c[I+133596>>2]=r;r=y+4608|0;c[I+2528>>2]=r;c[I+68064>>2]=r;c[I+133600>>2]=r;r=y+5632|0;c[I+2532>>2]=r;c[I+68068>>2]=r;c[I+133604>>2]=r;r=y+6656|0;c[I+2536>>2]=r;c[I+68072>>2]=r;c[I+133608>>2]=r;r=y+7680|0;c[I+2540>>2]=r;c[I+68076>>2]=r;c[I+133612>>2]=r;r=y+8704|0;c[I+2544>>2]=r;c[I+68080>>2]=r;c[I+133616>>2]=r;r=y+9728|0;c[I+2548>>2]=r;c[I+68084>>2]=r;c[I+133620>>2]=r;r=y+10752|0;c[I+2552>>2]=r;c[I+68088>>2]=r;c[I+133624>>2]=r;r=y+11776|0;c[I+2556>>2]=r;c[I+68092>>2]=r;c[I+133628>>2]=r;r=c[2388256]|0;y=I+3072|0;t=786432;while(1){u=r+(t-786432)|0;c[y>>2]=u;c[y+65536>>2]=u;c[y+131072>>2]=u;u=t+1024|0;if(u>>>0>851967){break}else{y=y+4|0;t=u}}c[I+196648>>2]=2e3;c[I+196728>>2]=1982;c[I+196608>>2]=2720;c[I+196688>>2]=844;t=c[3532592]|0;if((t|0)!=0){gGC(t|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);t=c[2439330]|0;y=(t|0)==0;if(!y){r=t;gGC(9706056,r|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];r=c[3528484]|0;c[2076596]=r;u=c[2417276]|0;c[3541536]=u;c[1836236]=0;v=c[2385904]|0;B=0;z=0;while(1){c[t+76+(z<<2)>>2]=v+(z<<8);A=B+1&65535;if((A&65535)>127){J=0;K=0;break}else{B=A;z=A&65535}}while(1){z=v+(K<<8)|0;c[t+76+(K+512<<2)>>2]=z;c[t+76+(K+768<<2)>>2]=z;z=J+1&65535;if((z&65535)>127){break}else{J=z;K=z&65535}}v=c[2386058]|0;c[t+588>>2]=v;z=v+256|0;c[t+592>>2]=z;B=v+512|0;c[t+596>>2]=B;A=v+768|0;c[t+600>>2]=A;E=v+1024|0;c[t+604>>2]=E;D=v+1280|0;c[t+608>>2]=D;C=v+1536|0;c[t+612>>2]=C;F=v+1792|0;c[t+616>>2]=F;c[t+1612>>2]=v;c[t+1616>>2]=z;c[t+1620>>2]=B;c[t+1624>>2]=A;c[t+1628>>2]=E;c[t+1632>>2]=D;c[t+1636>>2]=C;c[t+1640>>2]=F;c[t+2636>>2]=v;c[t+3660>>2]=v;c[t+2640>>2]=z;c[t+3664>>2]=z;c[t+2644>>2]=B;c[t+3668>>2]=B;c[t+2648>>2]=A;c[t+3672>>2]=A;c[t+2652>>2]=E;c[t+3676>>2]=E;c[t+2656>>2]=D;c[t+3680>>2]=D;c[t+2660>>2]=C;c[t+3684>>2]=C;c[t+2664>>2]=F;c[t+3688>>2]=F;c[t+4184>>2]=342;c[t+4180>>2]=1338;if(!y){F=t;gGC(F|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=r;c[2417276]=u;c[1836236]=-1;Ux(0,8e3,0);c[2407030]=256;c[2407068]=3;F=c[642608+(c[2436]<<2)>>2]|0;C=c[F+128>>2]|0;if((c[F+52>>2]&4|0)==0){c[2113068]=C;D=c[F+132>>2]|0;c[2113070]=D;c[2443814]=C;c[2440436]=D;L=C;M=D}else{c[2113070]=C;D=c[F+132>>2]|0;c[2113068]=D;c[2440436]=C;c[2443814]=D;L=D;M=C}C=ag(L<<1,M)|0;D=gGq(C)|0;c[2112926]=D;if((D|0)!=0){gGz(D|0,0,C|0)}a[9623984]=0;C=c[2414636]|0;gGz(C|0,0,(c[2411610]|0)-C|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];C=c[3532592]|0;if((C|0)!=0){gGC(9104152,C|0,280)|0}c[2113054]=c[2113060]}RI();C=c[2394]|0;D=c[14130368+(C<<2)>>2]|0;if((D|0)!=0){gGC(D|0,9104152,280)|0}c[8452240+(C<<2)>>2]=c[2113054];c[2394]=-1;C=c[2439330]|0;D=(C|0)==0;if(!D){F=C;gGC(9706056,F|0,76)|0}F=c[2438118]|0;c[2433530]=F;E=c[3528484]|0;c[2076596]=E;A=c[2417276]|0;c[3541536]=A;c[1836236]=0;gGz(9706056,0,76);if(!D){D=C;gGC(D|0,9706056,76)|0}c[2438118]=F;c[3528484]=E;c[2417276]=A;c[1836236]=-1;a[14113e3]=0;a[9553832]=0;s=0;i=e;return s|0}}while(0);c[2414934]=0;s=1;i=e;return s|0}function ekm(){var a=0,b=0,d=0,e=0,f=0;c[2113070]=0;c[2113068]=0;a=c[2112926]|0;if((a|0)!=0){gGr(a);c[2112926]=0}Uw(0);if((c[2392]|0)>=0){a=0;do{b=14130368+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}b=14130384+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}a=a+1|0;}while((a|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;fwZ();a=c[2414934]|0;b=0;while(1){if((b|0)>=1024){e=61347;break}f=9638528+(b<<2)|0;if((c[f>>2]|0)==(a|0)){break}else{b=b+1|0}}if((e|0)==61347){c[2414934]=0;c[3541206]=0;return 0}gGr(a);c[f>>2]=0;c[2414934]=0;c[3541206]=0;return 0}function ekn(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;if((a[9623984]|0)!=0){a[9623984]=0;e=c[2414636]|0;gGz(e|0,0,(c[2411610]|0)-e|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060]}RI();e=c[2394]|0;f=c[14130368+(e<<2)>>2]|0;if((f|0)!=0){gGC(f|0,9104152,280)|0}c[8452240+(e<<2)>>2]=c[2113054];c[2394]=-1;e=c[2439330]|0;f=(e|0)==0;if(!f){g=e;gGC(9706056,g|0,76)|0}g=c[2438118]|0;c[2433530]=g;h=c[3528484]|0;c[2076596]=h;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);if(!f){f=e;gGC(f|0,9706056,76)|0}c[2438118]=g;c[3528484]=h;c[2417276]=i;c[1836236]=-1;a[14113e3]=0;a[9553832]=0}b[4774980]=-1;b[4774896]=-1;b[4774852]=d[9634969]<<8|255;i=d[9634968]|-256;b[4774836]=i;h=0;g=-1;f=-1;e=i;do{g=((a[9633152+h|0]&1)<<h^g&65535)&65535;f=((a[9631024+h|0]&1)<<h^f&65535)&65535;e=((a[9628928+h|0]&1)<<h^e&65535)&65535;h=h+1|0;}while((h|0)<16);b[4774980]=g;b[4774896]=f;b[4774836]=e;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060]}e=c[2439330]|0;if((e|0)!=0){f=e;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;c[2113056]=16666;f=RG(16666)|0;c[2113054]=(c[2113054]|0)+f;c[2276108]=-1;c[2113056]=-1;if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){e=gfc(1666)|0;j=e;k=(c[2433530]|0)+e|0}else{j=1666;k=(c[2433530]|0)+1666|0}c[2433530]=k;k=(166666-f|0)/9|0;c[2113056]=k;e=RG(k)|0;c[2113054]=(c[2113054]|0)+e;c[2276108]=-1;c[2113056]=-1;k=e+f|0;f=16666-j|0;e=(f|0)/9|0;do{if((f|0)<9){l=0}else{if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){g=gfc(e)|0;c[2433530]=(c[2433530]|0)+g;l=g;break}else{c[2433530]=(c[2433530]|0)+e;l=e;break}}}while(0);e=l+j|0;j=(166666-k|0)/8|0;c[2113056]=j;l=RG(j)|0;c[2113054]=(c[2113054]|0)+l;c[2276108]=-1;c[2113056]=-1;j=l+k|0;k=16666-e|0;l=(k|0)/8|0;do{if((k|0)<8){m=0}else{if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){f=gfc(l)|0;c[2433530]=(c[2433530]|0)+f;m=f;break}else{c[2433530]=(c[2433530]|0)+l;m=l;break}}}while(0);l=m+e|0;e=(166666-j|0)/7|0;c[2113056]=e;m=RG(e)|0;c[2113054]=(c[2113054]|0)+m;c[2276108]=-1;c[2113056]=-1;e=m+j|0;j=16666-l|0;m=(j|0)/7|0;do{if((j|0)<7){n=0}else{if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){k=gfc(m)|0;c[2433530]=(c[2433530]|0)+k;n=k;break}else{c[2433530]=(c[2433530]|0)+m;n=m;break}}}while(0);m=n+l|0;l=(166666-e|0)/6|0;c[2113056]=l;n=RG(l)|0;c[2113054]=(c[2113054]|0)+n;c[2276108]=-1;c[2113056]=-1;l=n+e|0;e=16666-m|0;n=(e|0)/6|0;do{if((e|0)<6){o=0}else{if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){j=gfc(n)|0;c[2433530]=(c[2433530]|0)+j;o=j;break}else{c[2433530]=(c[2433530]|0)+n;o=n;break}}}while(0);n=o+m|0;m=(166666-l|0)/5|0;c[2113056]=m;o=RG(m)|0;c[2113054]=(c[2113054]|0)+o;c[2276108]=-1;c[2113056]=-1;m=o+l|0;l=16666-n|0;o=(l|0)/5|0;do{if((l|0)<5){p=0}else{if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){e=gfc(o)|0;c[2433530]=(c[2433530]|0)+e;p=e;break}else{c[2433530]=(c[2433530]|0)+o;p=o;break}}}while(0);o=p+n|0;n=(166666-m|0)/4|0;c[2113056]=n;p=RG(n)|0;c[2113054]=(c[2113054]|0)+p;c[2276108]=-1;c[2113056]=-1;n=p+m|0;m=16666-o|0;p=(m|0)/4|0;do{if((m|0)<4){q=0}else{if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){l=gfc(p)|0;c[2433530]=(c[2433530]|0)+l;q=l;break}else{c[2433530]=(c[2433530]|0)+p;q=p;break}}}while(0);p=q+o|0;o=(166666-n|0)/3|0;c[2113056]=o;q=RG(o)|0;c[2113054]=(c[2113054]|0)+q;c[2276108]=-1;c[2113056]=-1;o=q+n|0;n=16666-p|0;q=(n|0)/3|0;do{if((n|0)<3){r=0}else{if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){m=gfc(q)|0;c[2433530]=(c[2433530]|0)+m;r=m;break}else{c[2433530]=(c[2433530]|0)+q;r=q;break}}}while(0);q=166666-o|0;o=(q|0)/2|0;c[2113056]=o;n=RG(o)|0;c[2113054]=(c[2113054]|0)+n;c[2276108]=-1;c[2113056]=-1;o=16666-(r+p)|0;p=(o|0)/2|0;do{if((o|0)<2){s=0}else{if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){r=gfc(p)|0;c[2433530]=(c[2433530]|0)+r;s=r;break}else{c[2433530]=(c[2433530]|0)+p;s=p;break}}}while(0);p=q-n|0;c[2113056]=p;n=RG(p)|0;c[2113054]=(c[2113054]|0)+n;c[2276108]=-1;c[2113056]=-1;n=o-s|0;do{if((n|0)>=1){if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){s=gfc(n)|0;c[2433530]=(c[2433530]|0)+s;break}else{c[2433530]=(c[2433530]|0)+n;break}}}while(0);n=c[2112964]|0;if((n|0)!=0){Uu(0,n,a[9688]|0?534:0)}c[8452200+(c[2394]<<2)>>2]=8193;c[2276080]=256;if((c[2276079]|0)>>>0<256){RH(1)}n=c[1836236]|0;s=c[9757320+(n<<2)>>2]|0;if((s|0)!=0){o=s;gGC(o|0,9706056,76)|0}c[9752472+(n<<2)>>2]=c[2433530];c[14113936+(n<<2)>>2]=c[2076596];c[9669104+(n<<2)>>2]=c[3541536];c[1836236]=-1;n=c[2394]|0;o=c[14130368+(n<<2)>>2]|0;if((o|0)!=0){gGC(o|0,9104152,280)|0}c[8452240+(n<<2)>>2]=c[2113054];c[2394]=-1;if((c[2112968]|0)==0){return 0}eko()|0;return 0}function eko(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((a[9547336]|0)!=0){b=c[2406926]|0;f=c[3529972]|0;g=0;do{h=c[b+(g<<2)>>2]|0;c[f+(g<<2)>>2]=h>>8<<3&2016|h>>>3&31|h>>16<<8&63488;g=g+1|0;}while((g|0)<256)}g=c[2386204]|0;f=c[2113070]|0;b=c[2112926]|0;h=c[2387814]|0;i=c[2113068]|0;j=0;do{k=(j<<3&248)-16|0;l=(j>>5<<3)-8|0;if((k|l|0)>-1&(k|0)<(f|0)&(l|0)<(i|0)){m=e[g+(j<<1)>>1]|0;Si(b,ag(d[9553832]|0,m&2048)|0|m&2047,l,k,m>>>12,4,0,h)}j=j+1|0;}while((j|0)<2048);R8(c[3529972]|0);return 0}function ekp(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=i;i=i+96|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;l=e+80|0;if((d|0)!=0){c[d>>2]=169618}if((b&32|0)!=0){gGz(l|0,0,12);d=c[2414636]|0;c[l>>2]=d;c[l+4>>2]=(c[2411610]|0)-d;c[l+12>>2]=162152;d=c[2076592]|0;gj[d&4095](l)|0}if((b&64|0)==0){i=e;return 0}l=h|0;gGz(g|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){d=h+9|0;h=f;m=f|0;n=f+4|0;o=f+12|0;p=g|0;q=g+4|0;r=g+12|0;s=0;do{gGC(l|0,614896,11)|0;a[d]=s+48&255;t=8452256+(s<<2)|0;gGz(h|0,0,12);c[m>>2]=t;c[n>>2]=4;c[o>>2]=164976;gj[c[2076592]&4095](f)|0;if((c[t>>2]|0)!=0){c[p>>2]=c[14130368+(s<<2)>>2];c[q>>2]=c[8452184+(s<<2)>>2];c[r>>2]=l;t=c[2076592]|0;gj[t&4095](g)|0}s=s+1|0;}while((s|0)<=(c[2392]|0))}fw$(b);Ut(0);gGz(k|0,0,12);c[k>>2]=14113e3;c[k+4>>2]=1;c[k+12>>2]=191240;gj[c[2076592]&4095](k)|0;gGz(j|0,0,12);c[j>>2]=9553832;c[j+4>>2]=1;c[j+12>>2]=581968;gj[c[2076592]&4095](j)|0;i=e;return 0}function ekq(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>5){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2635308+(b*112|0)>>2];c[a+104>>2]=c[2635312+(b*112|0)>>2];c[a+108>>2]=c[2635316+(b*112|0)>>2];d=0;return d|0}function ekr(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<6&(d|0)==0)){e=1;return e|0}c[a>>2]=2635208+(b*112|0);e=0;return e|0}function eks(b,d){b=b|0;d=d|0;a[(c[3527034]|0)+(b&1023^1)|0]=d;return}function ekt(a,d){a=a|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0.0,k=0,l=0;e=a&1023;a=c[3527034]|0;b[a+(e>>>1<<1)>>1]=d;if((e|0)==544){d=b[a+544>>1]|0;f=b[a+548>>1]|0;g=b[a+550>>1]|0;c[2438051]=0;c[2427059]=0;h=d&65535;d=h>>>4&3;if((d|0)==2){i=g}else if((d|0)==1){i=f}else{return}if((h&49152|0)!=0|i<<16>>16==0){return}f=h>>>10&15;j=16666666.0/(f>>>0>8?256.0:+(1<<f|0))/+(i&65535|0);if(!((h&2|0)==0&j!=0.0)){return}c[2438051]=~~(16666666.0/j);return}else if((e|0)==576){h=b[a+576>>1]|0;i=b[a+580>>1]|0;f=b[a+582>>1]|0;c[2438052]=0;c[2427060]=0;d=h&65535;h=d>>>4&3;if((h|0)==2){k=f}else if((h|0)==1){k=i}else{return}if((d&49152|0)!=0|k<<16>>16==0){return}i=d>>>10&15;j=16666666.0/(i>>>0>8?256.0:+(1<<i|0))/+(k&65535|0);if(!((d&2|0)==0&j!=0.0)){return}c[2438052]=~~(16666666.0/j);return}else if((e|0)==512){e=b[a+512>>1]|0;d=b[a+516>>1]|0;k=b[a+518>>1]|0;c[2438050]=0;c[2427058]=0;a=e&65535;e=a>>>4&3;if((e|0)==1){l=d}else if((e|0)==2){l=k}else{return}if((a&49152|0)!=0|l<<16>>16==0){return}k=a>>>10&15;j=16666666.0/(k>>>0>8?256.0:+(1<<k|0))/+(l&65535|0);if(!((a&2|0)==0&j!=0.0)){return}c[2438050]=~~(16666666.0/j);return}else{return}}function eku(a){a=a|0;return 0}function ekv(a){a=a|0;var b=0;if((a|0)==7340044){b=-1}else if((a|0)==6291458){b=~(d[9625636]|0)}else if((a|0)==7340034){b=~(d[9625633]|0)}else if((a|0)==7340036){b=~(d[9625634]|0)}else if((a|0)==7340032){b=~(d[9625632]|0)}else if((a|0)==6291456){b=~(d[9625635]|0)}else{b=0}return b|0}function ekw(a,b){a=a|0;b=b|0;return}function ekx(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;switch(a|0){case 14680094:case 14680080:case 14680082:case 14680084:case 14680086:case 14680088:case 14680090:case 14680092:{break};default:{return}}d=(a-14680080|0)>>>1;a=c[3531862]|0;e=a+(d<<17)|0;f=b&65535;b=a+((f<<17)+1048576)|0;gGC(e|0,b|0,131072)|0;c[(c[2076600]|0)+16528+(d<<2)>>2]=f;return}function eky(a){a=a|0;return 0}function ekz(a){a=a|0;var b=0;b=a>>>1&131071;a=c[2076600]|0;return d[(c[a+4>>2]^b)+(a+12)|0]|0|(d[a+8204+b|0]|0)<<8|0}function ekA(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=b>>>1&8191;f=c[2076600]|0;if((b&1|0)!=0){a[f+8204+e|0]=d;return}b=c[f+4>>2]^e;e=b>>>3;g=f+12+b|0;do{if(b>>>0<128&(b&7|0)==0){if((a[g]&1)!=0){h=g;break}if((d&1)==0){h=g;break}c[f+16396+(e<<2)>>2]=0;c[f+16460+(e<<2)>>2]=0;h=g}else{h=g}}while(0);a[h]=d;return}function ekB(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=b>>>1&8191;b=c[2076600]|0;a[b+8204+e|0]=(d&65535)>>>8&255;f=c[b+4>>2]^e;e=f>>>3;g=b+12+f|0;do{if(f>>>0<128&(f&7|0)==0){if((a[g]&1)!=0){h=g;break}if((d&1)==0){h=g;break}c[b+16396+(e<<2)>>2]=0;c[b+16460+(e<<2)>>2]=0;h=g}else{h=g}}while(0);a[h]=d&255;return}function ekC(a,b){a=a|0;b=b|0;return}function ekD(a,d){a=a|0;d=d|0;var e=0;e=a>>>1&32767;b[(c[2411422]|0)+(e<<1)>>1]=d;a=d&65535;d=a>>>2&248;c[(c[2414528]|0)+(e<<2)>>2]=a>>>7<<8&63488|a&31|(d>>>5|d)<<3&2016;return}function ekE(a,b){a=a|0;b=b|0;return}function ekF(a,b){a=a|0;b=b|0;return}function ekG(a){a=a|0;return c[9718296+(a<<2)>>2]|0}function ekH(a){a=a|0;return 0}function ekI(a){a=a|0;var b=0;L81660:do{switch(a|0){case 6291712:{b=~(d[9625634]|0);break};case 6291456:case 6291458:{switch(d[9733432]|0|0){case 4:{b=~(d[9625637]|0);break L81660;break};case 16:{b=~(d[9625639]|0);break L81660;break};case 8:{b=~(d[9625638]|0);break L81660;break};case 1:{b=~(d[9625632]|0);break L81660;break};case 2:{b=~(d[9625633]|0);break L81660;break};default:{b=-1;break L81660}}break};case 6292224:{b=~(d[9625635]|0);break};case 6291462:{b=-1;break};case 6292226:{b=~(d[9625636]|0);break};default:{b=0}}}while(0);return b|0}function ekJ(a,b){a=a|0;b=b|0;return}function ekK(b,d){b=b|0;d=d|0;var e=0,f=0;switch(b|0){case 6291460:{a[9733432]=d&255;return};case 6292224:case 6292226:case 6292228:case 6292230:case 6292232:case 6292234:case 6292236:case 6292238:{e=b>>>1&7;b=c[3531862]|0;f=d&65535;gGC(b+(e<<17)|0,b+((f<<17)+1048576)|0,131072)|0;c[(c[2076600]|0)+16528+(e<<2)>>2]=f;return};default:{return}}}function ekL(a){a=a|0;return 0}function ekM(a){a=a|0;var b=0;switch(a|0){case 7340034:{b=~(d[9625633]|0);break};case 7340038:{b=-1;break};case 7340036:{b=~(d[9625634]|0);break};case 7340802:{b=~(d[9625636]|0);break};case 7340800:{b=~(d[9625635]|0);break};case 7340032:{b=~(d[9625632]|0);break};default:{b=0}}return b|0}function ekN(a,b){a=a|0;b=b|0;return}function ekO(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;switch(a|0){case 7340830:case 7340816:case 7340818:case 7340820:case 7340822:case 7340824:case 7340826:case 7340828:{break};default:{return}}d=a>>>1&7;a=c[3531862]|0;e=a+(d<<17)|0;f=b&65535;b=a+((f<<17)+1048576)|0;gGC(e|0,b|0,131072)|0;c[(c[2076600]|0)+16528+(d<<2)>>2]=f;return}function ekP(a){a=a|0;return 0}function ekQ(a){a=a|0;var b=0;switch(a|0){case 6291458:{b=~(d[9625633]|0);break};case 6291460:{b=~(d[9625634]|0);break};case 6291462:{b=-1;break};case 6292224:{b=~(d[9625635]|0);break};case 6292226:{b=~(d[9625636]|0);break};case 6291456:{b=~(d[9625632]|0);break};default:{b=0}}return b|0}function ekR(a,b){a=a|0;b=b|0;return}function ekS(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;switch(a|0){case 6292238:case 6292224:case 6292226:case 6292228:case 6292230:case 6292232:case 6292234:case 6292236:{break};default:{return}}d=a>>>1&7;a=c[3531862]|0;e=a+(d<<17)|0;f=b&65535;b=a+((f<<17)+1048576)|0;gGC(e|0,b|0,131072)|0;c[(c[2076600]|0)+16528+(d<<2)>>2]=f;return}function ekT(a){a=a|0;return 0}function ekU(a){a=a|0;var f=0,g=0;if((a|0)==4195074){f=~(d[9625636]|0);return f|0}else if((a|0)==5242886){f=-1;return f|0}else if((a|0)==5242882){f=~(d[9625633]|0);return f|0}else if((a|0)==5242880){f=~(d[9625632]|0);return f|0}else if((a|0)==5242884){g=b[4769100]^128;b[4769100]=g;f=~(d[9625634]|0|g);return f|0}else if((a|0)==4195072){f=~(d[9625635]|0);return f|0}else if((a|0)==7340032){a=c[2411902]|0;f=d[(c[2411330]|0)+(((e[a+47638>>1]|0)<<16|(e[a+47640>>1]|0))-2)|0]|0;return f|0}else{f=0;return f|0}return 0}function ekV(a,b){a=a|0;b=b|0;return}function ekW(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;switch(a|0){case 4195072:case 4195074:case 4195076:case 4195078:case 4195080:case 4195082:case 4195084:case 4195086:{break};default:{return}}d=a>>>1&7;a=c[3531862]|0;e=a+(d<<17)|0;f=b&65535;b=a+((f<<17)+1048576)|0;gGC(e|0,b|0,131072)|0;c[(c[2076600]|0)+16528+(d<<2)>>2]=f;return}function ekX(a){a=a|0;return 0}function ekY(a){a=a|0;var b=0;if((a|0)==6291456){b=~(d[9625632]|0)}else if((a|0)==5243650){b=~(d[9625636]|0)}else if((a|0)==6291460){b=~(d[9625634]|0)}else if((a|0)==6291462){b=-1}else if((a|0)==5243648){b=~(d[9625635]|0)}else if((a|0)==6291458){b=~(d[9625633]|0)}else{b=0}return b|0}function ekZ(a,b){a=a|0;b=b|0;return}function ek_(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;switch(a|0){case 5243648:case 5243650:case 5243652:case 5243654:case 5243656:case 5243658:case 5243660:case 5243662:{break};default:{return}}d=a>>>1&7;a=c[3531862]|0;e=a+(d<<17)|0;f=b&65535;b=a+((f<<17)+1048576)|0;gGC(e|0,b|0,131072)|0;c[(c[2076600]|0)+16528+(d<<2)>>2]=f;return}function ek$(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;if((a|0)==7340044|(a|0)==8388608){return}else if((a|0)==16776458){d=b&65535;c[2415256]=d&1;e=d>>>2&1;c[3528406]=e^1;if((e|0)==0){c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2]}Tr(d>>>1&1);return}else if((a|0)==14680080|(a|0)==14680082|(a|0)==14680084|(a|0)==14680086|(a|0)==14680088|(a|0)==14680090|(a|0)==14680092|(a|0)==14680094){d=a>>>1&7;e=c[3531862]|0;f=e+(d<<17)|0;g=b&65535;h=e+((g<<17)+1048576)|0;gGC(f|0,h|0,131072)|0;c[(c[2076600]|0)+16528+(d<<2)>>2]=g;return}else{if((a&16776192|0)!=16776192){return}ekt(a,b);return}}function ek0(b,d){b=b|0;d=d|0;if((b&16776192|0)!=16776192){return}a[(c[3527034]|0)+(b&1023^1)|0]=d;return}function ek1(e){e=e|0;var f=0,g=0;do{if((e|0)==16776458){if((c[2406632]|0)!=0){f=(c[2432962]|0)>>>((c[(c[2420380]|0)+4>>2]|0)>>>0)<<3&8;break}g=c[2443744]|0;if((g|0)<=0){f=8;break}c[2443744]=g-1;f=0}else if((e|0)==6291458){f=d[9625636]|0|-256}else if((e|0)==7340034){f=~(d[9625633]|0)}else if((e|0)==7340032){f=~(d[9625632]|0)}else if((e|0)==7340036){f=(a[9625639]&32|a[9625634]&223)^-33}else if((e|0)==7340042){f=~(d[9625638]|0)}else if((e|0)==6291456){f=d[9625635]|0|-256}else if((e|0)==7340040){f=~(d[9625637]|0)}else{if((e&16776192|0)!=16776192){f=0;break}f=b[(c[3527034]|0)+((e>>>1&511)<<1)>>1]|0}}while(0);return f|0}function ek2(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if((a&16777200|0)!=4195072){return}d=a>>>1&7;a=c[3531862]|0;e=a+(d<<17)|0;f=b&65535;b=a+((f<<17)+1048576)|0;gGC(e|0,b|0,131072)|0;c[(c[2076600]|0)+16528+(d<<2)>>2]=f;return}function ek3(a){a=a|0;var b=0;if((a|0)==4194306){b=d[9625632]|0|-256}else if((a|0)==7340036){b=d[9625635]|0|-256}else if((a|0)==4194304){b=d[9625638]|0|-256}else if((a|0)==5242880){b=(d[9755352]|0)<<8|(d[9755360]|0)}else if((a|0)==16776458){b=d[9625639]|0|-256}else if((a|0)==7340034){b=d[9625634]|0|-256}else if((a|0)==7340032){b=d[9625633]|0|-256}else if((a|0)==5767168){b=(d[9755336]|0)<<8|(d[9755344]|0)}else{b=0}return b|0}function ek4(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4692284+(b*112|0)>>2];c[a+104>>2]=c[4692288+(b*112|0)>>2];c[a+108>>2]=c[4692292+(b*112|0)>>2];d=0;return d|0}function ek5(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=4692184+(b*112|0);e=0;return e|0}function ek6(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1537952+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function ek7(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>54){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4693640+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function ek8(){var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;d=i;i=i+1080|0;e=d|0;f=d+112|0;g=d+120|0;j=d+232|0;k=d+240|0;l=d+352|0;m=d+360|0;n=d+472|0;o=d+480|0;p=d+592|0;q=d+600|0;r=d+712|0;s=d+720|0;t=d+832|0;u=d+840|0;v=d+952|0;w=d+960|0;x=d+1072|0;c[2426698]=0;c[2411330]=0;c[2411324]=2097152;c[3531862]=35651584;c[2405634]=37748736;c[2411902]=37748736;c[3528980]=37814272;if(a[642480]|0){c[2418170]=37863424}c[2411368]=37928960;c[2385744]=38191104;c[2411422]=38453248;c[3527034]=38518784;c[2406856]=38519808;c[2411608]=38519872;c[2414528]=38519872;y=0;while(1){if((y|0)>=1024){break}z=9638528+(y<<2)|0;if((c[z>>2]|0)==0){A=61692;break}else{y=y+1|0}}do{if((A|0)==61692){y=gGq(38650944)|0;c[z>>2]=y;if((y|0)==0){break}c[2426698]=y;gGz(y|0,0,38650944);c[2411330]=y;c[2411324]=y+2097152;c[3531862]=y+35651584;B=y+37748736|0;c[2405634]=B;c[2411902]=B;c[3528980]=y+37814272;if(a[642480]|0){c[2418170]=y+37863424}c[2411368]=y+37928960;c[2385744]=y+38191104;c[2411422]=y+38453248;c[3527034]=y+38518784;c[2406856]=y+38519808;B=y+38519872|0;c[2411608]=B;c[2414528]=B;c[2414148]=y+38650944;if((R6(y+1|0,0,2)|0)!=0){C=1;i=d;return C|0}if((R6(c[2411330]|0,1,2)|0)!=0){C=1;i=d;return C|0}if((R6((c[2411330]|0)+1048577|0,2,2)|0)!=0){C=1;i=d;return C|0}if((R6((c[2411330]|0)+1048576|0,3,2)|0)==0){D=0}else{C=1;i=d;return C|0}while(1){if((D|0)>=1024){E=0;break}F=9638528+(D<<2)|0;if((c[F>>2]|0)==0){A=61702;break}else{D=D+1|0}}do{if((A|0)==61702){y=gGq(8388608)|0;c[F>>2]=y;if((y|0)==0){E=0;break}gGz(y|0,0,8388608);E=y}}while(0);y=E+2097152|0;B=E+6291456|0;do{if((c[3542200]|0)!=0){G=w+108|0;c[G>>2]=0;H=w+100|0;c[H>>2]=0;I=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[I&16383](w,5)|0;if((c[G>>2]|0)==0){break}G=c[H>>2]|0;c[x>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](x,5,0)|0;if((G|0)<1){break}gzL(y,0,5)|0}}while(0);gGC(B|0,y|0,2097152)|0;do{if((c[3542200]|0)!=0){G=u+108|0;c[G>>2]=0;H=u+100|0;c[H>>2]=0;I=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[I&16383](u,4)|0;if((c[G>>2]|0)==0){break}G=c[H>>2]|0;c[v>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](v,4,0)|0;if((G|0)<1){break}gzL(E,0,4)|0}}while(0);emf(E,4194304,0);do{if((c[3542200]|0)!=0){G=s+108|0;c[G>>2]=0;H=s+100|0;c[H>>2]=0;I=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[I&16383](s,7)|0;if((c[G>>2]|0)==0){break}G=c[H>>2]|0;c[t>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](t,7,0)|0;if((G|0)<1){break}gzL(y,0,7)|0}}while(0);gGC(B|0,y|0,2097152)|0;do{if((c[3542200]|0)!=0){G=q+108|0;c[G>>2]=0;H=q+100|0;c[H>>2]=0;I=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[I&16383](q,6)|0;if((c[G>>2]|0)==0){break}G=c[H>>2]|0;c[r>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](r,6,0)|0;if((G|0)<1){break}gzL(E,0,6)|0}}while(0);emf(E,4194304,2);do{if((c[3542200]|0)!=0){G=o+108|0;c[G>>2]=0;H=o+100|0;c[H>>2]=0;I=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[I&16383](o,9)|0;if((c[G>>2]|0)==0){break}G=c[H>>2]|0;c[p>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](p,9,0)|0;if((G|0)<1){break}gzL(y,0,9)|0}}while(0);gGC(B|0,y|0,2097152)|0;do{if((c[3542200]|0)!=0){G=m+108|0;c[G>>2]=0;H=m+100|0;c[H>>2]=0;I=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[I&16383](m,8)|0;if((c[G>>2]|0)==0){break}G=c[H>>2]|0;c[n>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](n,8,0)|0;if((G|0)<1){break}gzL(E,0,8)|0}}while(0);emf(E,4194304,4);do{if((c[3542200]|0)!=0){G=k+108|0;c[G>>2]=0;H=k+100|0;c[H>>2]=0;I=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[I&16383](k,11)|0;if((c[G>>2]|0)==0){break}G=c[H>>2]|0;c[l>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](l,11,0)|0;if((G|0)<1){break}gzL(y,0,11)|0}}while(0);gGC(B|0,y|0,2097152)|0;do{if((c[3542200]|0)!=0){G=g+108|0;c[G>>2]=0;H=g+100|0;c[H>>2]=0;I=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[I&16383](g,10)|0;if((c[G>>2]|0)==0){break}G=c[H>>2]|0;c[j>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](j,10,0)|0;if((G|0)<1){break}gzL(E,0,10)|0}}while(0);emf(E,4194304,6);y=0;while(1){if((y|0)>=1024){break}J=9638528+(y<<2)|0;if((c[J>>2]|0)==(E|0)){A=61739;break}else{y=y+1|0}}if((A|0)==61739){gGr(E);c[J>>2]=0}y=(c[3531862]|0)+1048576|0;do{if((c[3542200]|0)!=0){B=e+108|0;c[B>>2]=0;G=e+100|0;c[G>>2]=0;H=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[H&16383](e,12)|0;if((c[B>>2]|0)==0){break}B=c[G>>2]|0;c[f>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](f,12,0)|0;if((B|0)<1){break}gzL(y,0,12)|0}}while(0);fxU(0,425984);if((c[2394]|0)==0){K=c[2112932]|0}else{c[2394]=0;y=c[3532596]|0;c[2112932]=y;B=c[3532592]|0;if((B|0)!=0){gGC(9104152,B|0,280)|0}c[2113054]=c[2113060];K=y}y=c[2411330]|0;B=K|0;G=0;while(1){H=y+G|0;c[B>>2]=H;c[B+131072>>2]=H;H=G+1024|0;if(H>>>0>2097151){break}else{B=B+4|0;G=H}}G=c[2411902]|0;B=K+8192|0;y=2097152;while(1){H=G+(y-2097152)|0;c[B>>2]=H;c[B+65536>>2]=H;c[B+131072>>2]=H;H=y+1024|0;if(H>>>0>2162687){break}else{B=B+4|0;y=H}}y=c[3528980]|0;B=K+12352|0;G=3162112;while(1){H=y+(G-3162112)|0;c[B>>2]=H;c[B+65536>>2]=H;c[B+131072>>2]=H;H=G+1024|0;if(H>>>0>3211263){break}else{B=B+4|0;G=H}}G=c[2411368]|0;B=K+49152|0;y=12582912;while(1){H=G+(y-12582912)|0;c[B>>2]=H;c[B+65536>>2]=H;c[B+131072>>2]=H;H=y+1024|0;if(H>>>0>12845055){break}else{B=B+4|0;y=H}}y=c[2411422]|0;B=K+50176|0;G=B;H=12845056;while(1){I=y+(H-12845056)|0;c[G>>2]=I;c[G+131072>>2]=I;I=H+1024|0;if(I>>>0>12910591){break}else{G=G+4|0;H=I}}H=c[2406856]|0;c[K+50688>>2]=H;c[K+116224>>2]=H;c[K+181760>>2]=H;H=c[3527034]|0;c[K+65532>>2]=H;c[K+196604>>2]=H;c[K+45056>>2]=1;c[K+110592>>2]=1;c[K+45060>>2]=1;c[K+110596>>2]=1;c[K+45064>>2]=1;c[K+110600>>2]=1;c[K+45068>>2]=1;c[K+110604>>2]=1;c[K+45072>>2]=1;c[K+110608>>2]=1;c[K+45076>>2]=1;c[K+110612>>2]=1;c[K+45080>>2]=1;c[K+110616>>2]=1;c[K+45084>>2]=1;c[K+110620>>2]=1;c[K+45088>>2]=1;c[K+110624>>2]=1;c[K+45092>>2]=1;c[K+110628>>2]=1;c[K+45096>>2]=1;c[K+110632>>2]=1;c[K+45100>>2]=1;c[K+110636>>2]=1;c[K+45104>>2]=1;c[K+110640>>2]=1;c[K+45108>>2]=1;c[K+110644>>2]=1;c[K+45112>>2]=1;c[K+110648>>2]=1;c[K+45116>>2]=1;c[K+110652>>2]=1;H=B;G=12845056;while(1){c[H+65536>>2]=2;y=G+1024|0;if(y>>>0>12910591){break}else{H=H+4|0;G=y}}G=K+50432|0;H=12910592;while(1){c[G+65536>>2]=3;B=H+1024|0;if(B>>>0>12976127){break}else{G=G+4|0;H=B}}c[K+131068>>2]=4;c[K+196688>>2]=3370;c[K+196608>>2]=3246;c[K+196728>>2]=554;c[K+196648>>2]=56;c[K+196692>>2]=286;c[K+196612>>2]=1754;c[K+196732>>2]=3428;c[K+196652>>2]=2034;c[K+196736>>2]=1972;c[K+196656>>2]=1402;c[K+196740>>2]=2548;c[K+196660>>2]=2776;c[K+196744>>2]=1920;c[K+196664>>2]=1710;c[K+196856>>2]=202;H=c[3532592]|0;if((H|0)!=0){gGC(H|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;H=c[642608+(c[2436]<<2)>>2]|0;G=c[H+128>>2]|0;if((c[H+52>>2]&4|0)==0){c[2113068]=G;B=c[H+132>>2]|0;c[2113070]=B;c[2443814]=G;c[2440436]=B;L=G;M=B}else{c[2113070]=G;B=c[H+132>>2]|0;c[2113068]=B;c[2440436]=G;c[2443814]=B;L=B;M=G}G=ag(L<<1,M)|0;B=gGq(G)|0;c[2112926]=B;if((B|0)!=0){gGz(B|0,0,G|0)}a[642544]=0;c[2415132]=128;c[2415130]=128;c[2439290]=524288;G=gGq(16584)|0;c[2076600]=G;c[G+16524>>2]=16666666;c[G>>2]=16276;c[G+4>>2]=0;h[G+16560>>3]=1.0;c[G+16576>>2]=1;h[G+16568>>3]=1.0;c[G+16580>>2]=2;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];G=c[3532592]|0;if((G|0)!=0){gGC(9104152,G|0,280)|0}c[2113054]=c[2113060]}RI();G=c[2394]|0;B=c[14130368+(G<<2)>>2]|0;if((B|0)!=0){gGC(B|0,9104152,280)|0}c[8452240+(G<<2)>>2]=c[2113054];c[2394]=-1;if((fa(c[c[642608+(c[2436]<<2)>>2]>>2]|0,361672)|0)!=0){C=0;i=d;return C|0}c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];if(a[1040128]|0){C=0;i=d;return C|0}b[7050196]=28680;C=0;i=d;return C|0}}while(0);c[2426698]=0;C=1;i=d;return C|0}function ek9(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;i=i+128|0;d=b|0;if((c[2392]|0)>=0){e=0;do{f=14130368+(e<<2)|0;g=c[f>>2]|0;if((g|0)!=0){gGr(g);c[f>>2]=0}f=14130384+(e<<2)|0;g=c[f>>2]|0;if((g|0)!=0){gGr(g);c[f>>2]=0}e=e+1|0;}while((e|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;e=c[2076600]|0;if((e|0)!=0){gGr(e);c[2076600]=0}c[2113070]=0;c[2113068]=0;e=c[2112926]|0;if((e|0)!=0){gGr(e);c[2112926]=0}e=c[2426698]|0;f=0;while(1){if((f|0)>=1024){break}h=9638528+(f<<2)|0;if((c[h>>2]|0)==(e|0)){j=61801;break}else{f=f+1|0}}if((j|0)==61801){gGr(e);c[h>>2]=0}c[2426698]=0;h=c[c[642608+(c[2436]<<2)>>2]>>2]|0;do{if((fa(h|0,361672)|0)==0){e=d|0;be(e|0,128,179600,(j=i,i=i+24|0,c[j>>2]=9374064,c[j+8>>2]=47,c[j+16>>2]=h,j)|0)|0;i=j;a[1040128]=0;j=c[2420380]|0;f=c[j>>2]|0;g=c[j+4>>2]|0;j=fw(e|0,389440)|0;if((j|0)==0){break}e=g>>3<<f&1023;cj(14100392,e|0,1,j|0)|0;aY(j|0)|0}}while(0);if((c[2113302]|0)==0){a[642480]=0;i=b;return 0}c[2113302]=0;a[801640]=0;c[2440576]=0;c[2440574]=0;gGz(14168784,0,16);gGz(14168768,0,16);a[642480]=0;i=b;return 0}function ela(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;do{if((a[9623976]|0)!=0){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;if((fa(c[c[642608+(c[2436]<<2)>>2]>>2]|0,361672)|0)!=0){break}c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];if(a[1040128]|0){break}b[7050196]=28680}}while(0);a[9625632]=0;a[9625633]=0;a[9625634]=0;a[9625637]=0;a[9625638]=0;d=0;e=0;f=0;g=0;h=0;i=0;do{e=((a[9633144+d|0]&1)<<d|e&255)&255;f=((a[9631016+d|0]&1)<<d|f&255)&255;g=((a[9551776+d|0]&1)<<d|g&255)&255;h=((a[9629448+d|0]&1)<<d|h&255)&255;i=((a[9628920+d|0]&1)<<d|i&255|(a[9628712+d|0]&1)<<d)&255;d=d+1|0;}while((d|0)<8);a[9625632]=e;a[9625633]=f;a[9625634]=g;a[9625637]=h;a[9625638]=i;i=c[2392]|0;if((i|0)>=0){gGz(8452240,0,((i|0)>0?(i<<2)+4|0:4)|0)}c[2113054]=0;if((c[2394]|0)==0){j=0;k=8680;l=0}else{c[2394]=0;c[2112932]=c[3532596];i=c[3532592]|0;if((i|0)!=0){gGC(9104152,i|0,280)|0}c[2113054]=c[2113060];j=0;k=8680;l=0}while(1){i=k-j|0;c[2113056]=i;h=RG(i)|0;c[2113054]=(c[2113054]|0)+h;c[2276108]=-1;c[2113056]=-1;i=c[2438050]|0;do{if((i|0)!=0){g=(c[2427058]|0)+h|0;c[2427058]=g;if((g|0)<(i|0)){break}c[2438050]=0;c[2427058]=0;el6(0)}}while(0);i=c[2438051]|0;do{if((i|0)!=0){g=(c[2427059]|0)+h|0;c[2427059]=g;if((g|0)<(i|0)){break}c[2438051]=0;c[2427059]=0;el6(1)}}while(0);i=c[2438052]|0;do{if((i|0)!=0){g=(c[2427060]|0)+h|0;c[2427060]=g;if((g|0)<(i|0)){break}c[2438052]=0;c[2427060]=0;el6(2)}}while(0);i=l+1|0;if((i|0)<32){j=h+j|0;k=k+8680|0;l=i}else{break}}l=c[3527034]|0;do{if((b[l+148>>1]&1)==0){k=b[l+128>>1]&7;c[9718296+(k<<2)>>2]=b[l+154>>1]&224;c[8452200+(c[2394]<<2)>>2]=k|8192;j=c[2276080]|0;i=k<<8;c[2276080]=i;if((j|0)!=1792&(k|0)==7){RH(7);break}if(i>>>0<=(c[2276079]|0)>>>0){break}RH(k)}}while(0);l=c[2394]|0;k=c[14130368+(l<<2)>>2]|0;if((k|0)!=0){gGC(k|0,9104152,280)|0}c[8452240+(l<<2)>>2]=c[2113054];c[2394]=-1;if((c[2112968]|0)!=0){el7()}if((c[2112964]|0)==0){return 0}TV();return 0}function elb(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;e=i;i=i+176|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;l=e+80|0;m=e+96|0;n=e+112|0;o=e+128|0;p=e+144|0;q=e+160|0;r=(d|0)==0;if(!r){c[d>>2]=169585}if((b&32|0)!=0){gGz(q|0,0,12);s=c[2405634]|0;c[q>>2]=s;c[q+4>>2]=(c[2411608]|0)-s;c[q+12>>2]=162152;s=c[2076592]|0;gj[s&4095](q)|0}if((b&64|0)==0){i=e;return 0}q=l|0;gGz(k|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){s=l+9|0;l=j;t=j|0;u=j+4|0;v=j+12|0;w=k|0;x=k+4|0;y=k+12|0;z=0;do{gGC(q|0,614896,11)|0;a[s]=z+48&255;A=8452256+(z<<2)|0;gGz(l|0,0,12);c[t>>2]=A;c[u>>2]=4;c[v>>2]=164976;gj[c[2076592]&4095](j)|0;if((c[A>>2]|0)!=0){c[w>>2]=c[14130368+(z<<2)>>2];c[x>>2]=c[8452184+(z<<2)>>2];c[y>>2]=q;A=c[2076592]|0;gj[A&4095](k)|0}z=z+1|0;}while((z|0)<=(c[2392]|0))}if(!r){c[d>>2]=169586}gGz(h|0,0,12);c[h>>2]=c[2076600];c[h+4>>2]=16584;c[h+12>>2]=157696;gj[c[2076592]&4095](h)|0;gGz(g|0,0,12);c[g>>2]=14168784;c[g+4>>2]=16;c[g+12>>2]=249744;gj[c[2076592]&4095](g)|0;gGz(f|0,0,12);c[f>>2]=14168768;c[f+4>>2]=16;c[f+12>>2]=524320;gj[c[2076592]&4095](f)|0;gGz(p|0,0,12);c[p>>2]=9625632;c[p+4>>2]=8;c[p+12>>2]=215728;gj[c[2076592]&4095](p)|0;gGz(o|0,0,12);c[o>>2]=9752200;c[o+4>>2]=12;c[o+12>>2]=354648;gj[c[2076592]&4095](o)|0;gGz(n|0,0,12);c[n>>2]=9708232;c[n+4>>2]=12;c[n+12>>2]=353360;gj[c[2076592]&4095](n)|0;gGz(m|0,0,12);c[m>>2]=9718296;c[m+4>>2]=32;c[m+12>>2]=352544;gj[c[2076592]&4095](m)|0;if((b&2|0)==0){i=e;return 0}a[9753328]=1;b=c[3531862]|0;m=c[2076600]|0;n=b+((c[m+16528>>2]<<17)+1048576)|0;gGC(b|0,n|0,131072)|0;n=b+131072|0;o=b+((c[m+16532>>2]<<17)+1048576)|0;gGC(n|0,o|0,131072)|0;o=b+262144|0;n=b+((c[m+16536>>2]<<17)+1048576)|0;gGC(o|0,n|0,131072)|0;n=b+393216|0;o=b+((c[m+16540>>2]<<17)+1048576)|0;gGC(n|0,o|0,131072)|0;o=b+524288|0;n=b+((c[m+16544>>2]<<17)+1048576)|0;gGC(o|0,n|0,131072)|0;n=b+655360|0;o=b+((c[m+16548>>2]<<17)+1048576)|0;gGC(n|0,o|0,131072)|0;o=b+786432|0;n=b+((c[m+16552>>2]<<17)+1048576)|0;gGC(o|0,n|0,131072)|0;n=b+917504|0;o=b+((c[m+16556>>2]<<17)+1048576)|0;gGC(n|0,o|0,131072)|0;i=e;return 0}function elc(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2571348+(b*112|0)>>2];c[a+104>>2]=c[2571352+(b*112|0)>>2];c[a+108>>2]=c[2571356+(b*112|0)>>2];d=0;return d|0}function eld(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=2571248+(b*112|0);e=0;return e|0}function ele(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>32){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1044288+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function elf(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>43){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=2572480+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function elg(){var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;d=i;i=i+840|0;e=d|0;f=d+112|0;g=d+120|0;j=d+232|0;k=d+240|0;l=d+352|0;m=d+360|0;n=d+472|0;o=d+480|0;p=d+592|0;q=d+600|0;r=d+712|0;s=d+720|0;t=d+832|0;c[2426698]=0;c[2411330]=0;c[2411324]=2097152;c[3531862]=35651584;c[2405634]=40894464;c[2411902]=40894464;c[3528980]=4096e4;if(a[642480]|0){c[2418170]=4096e4}c[2411368]=41025536;c[2385744]=41287680;c[2411422]=41549824;c[3527034]=41615360;c[2406856]=41616384;c[2411608]=41616448;c[2414528]=41616448;u=0;while(1){if((u|0)>=1024){break}v=9638528+(u<<2)|0;if((c[v>>2]|0)==0){w=61901;break}else{u=u+1|0}}do{if((w|0)==61901){u=gGq(41747520)|0;c[v>>2]=u;if((u|0)==0){break}c[2426698]=u;gGz(u|0,0,41747520);c[2411330]=u;c[2411324]=u+2097152;c[3531862]=u+35651584;x=u+40894464|0;c[2405634]=x;c[2411902]=x;x=u+4096e4|0;c[3528980]=x;if(a[642480]|0){c[2418170]=x}c[2411368]=u+41025536;c[2385744]=u+41287680;c[2411422]=u+41549824;c[3527034]=u+41615360;c[2406856]=u+41616384;x=u+41616448|0;c[2411608]=x;c[2414528]=x;c[2414148]=u+41747520;if((R6(u+1|0,0,2)|0)!=0){y=1;i=d;return y|0}if((R6(c[2411330]|0,1,2)|0)!=0){y=1;i=d;return y|0}if((R6((c[2411330]|0)+1048577|0,2,2)|0)!=0){y=1;i=d;return y|0}if((R6((c[2411330]|0)+1048576|0,3,2)|0)==0){z=0}else{y=1;i=d;return y|0}while(1){if((z|0)>=1024){A=0;break}B=9638528+(z<<2)|0;if((c[B>>2]|0)==0){w=61911;break}else{z=z+1|0}}do{if((w|0)==61911){u=gGq(8388608)|0;c[B>>2]=u;if((u|0)==0){A=0;break}gGz(u|0,0,8388608);A=u}}while(0);u=A+4194304|0;do{if((c[3542200]|0)!=0){x=s+108|0;c[x>>2]=0;C=s+100|0;c[C>>2]=0;D=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[D&16383](s,4)|0;if((c[x>>2]|0)==0){break}x=c[C>>2]|0;c[t>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](t,4,0)|0;if((x|0)<1){break}gzL(A,0,4)|0}}while(0);do{if((c[3542200]|0)!=0){x=q+108|0;c[x>>2]=0;C=q+100|0;c[C>>2]=0;D=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[D&16383](q,5)|0;if((c[x>>2]|0)==0){break}x=c[C>>2]|0;c[r>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](r,5,0)|0;if((x|0)<1){break}gzL(u,0,5)|0}}while(0);emf(A,4194304,0);do{if((c[3542200]|0)!=0){x=o+108|0;c[x>>2]=0;C=o+100|0;c[C>>2]=0;D=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[D&16383](o,6)|0;if((c[x>>2]|0)==0){break}x=c[C>>2]|0;c[p>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](p,6,0)|0;if((x|0)<1){break}gzL(A,0,6)|0}}while(0);do{if((c[3542200]|0)!=0){x=m+108|0;c[x>>2]=0;C=m+100|0;c[C>>2]=0;D=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[D&16383](m,7)|0;if((c[x>>2]|0)==0){break}x=c[C>>2]|0;c[n>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](n,7,0)|0;if((x|0)<1){break}gzL(u,0,7)|0}}while(0);emf(A,4194304,2);do{if((c[3542200]|0)!=0){x=k+108|0;c[x>>2]=0;C=k+100|0;c[C>>2]=0;D=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[D&16383](k,8)|0;if((c[x>>2]|0)==0){break}x=c[C>>2]|0;c[l>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](l,8,0)|0;if((x|0)<1){break}gzL(A,0,8)|0}}while(0);do{if((c[3542200]|0)!=0){x=g+108|0;c[x>>2]=0;C=g+100|0;c[C>>2]=0;D=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[D&16383](g,9)|0;if((c[x>>2]|0)==0){break}x=c[C>>2]|0;c[j>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](j,9,0)|0;if((x|0)<1){break}gzL(u,0,9)|0}}while(0);emf(A,4194304,4);u=0;while(1){if((u|0)>=1024){break}E=9638528+(u<<2)|0;if((c[E>>2]|0)==(A|0)){w=61940;break}else{u=u+1|0}}if((w|0)==61940){gGr(A);c[E>>2]=0}u=(c[3531862]|0)+1048576|0;do{if((c[3542200]|0)!=0){x=e+108|0;c[x>>2]=0;C=e+100|0;c[C>>2]=0;D=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[D&16383](e,10)|0;if((c[x>>2]|0)==0){break}x=c[C>>2]|0;c[f>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](f,10,0)|0;if((x|0)<1){break}gzL(u,0,10)|0}}while(0);fxU(0,425984);if((c[2394]|0)==0){F=c[2112932]|0}else{c[2394]=0;u=c[3532596]|0;c[2112932]=u;x=c[3532592]|0;if((x|0)!=0){gGC(9104152,x|0,280)|0}c[2113054]=c[2113060];F=u}u=c[2411330]|0;x=F|0;C=0;while(1){D=u+C|0;c[x>>2]=D;c[x+131072>>2]=D;D=C+1024|0;if(D>>>0>2097151){break}else{x=x+4|0;C=D}}C=c[2411902]|0;x=F+8192|0;u=2097152;while(1){D=C+(u-2097152)|0;c[x>>2]=D;c[x+65536>>2]=D;c[x+131072>>2]=D;D=u+1024|0;if(D>>>0>2162687){break}else{x=x+4|0;u=D}}u=c[2411368]|0;x=F+49152|0;C=12582912;while(1){D=u+(C-12582912)|0;c[x>>2]=D;c[x+65536>>2]=D;c[x+131072>>2]=D;D=C+1024|0;if(D>>>0>12845055){break}else{x=x+4|0;C=D}}C=c[2411422]|0;x=F+50176|0;u=x;D=12845056;while(1){G=C+(D-12845056)|0;c[u>>2]=G;c[u+131072>>2]=G;G=D+1024|0;if(G>>>0>12910591){break}else{u=u+4|0;D=G}}D=c[2406856]|0;c[F+50688>>2]=D;c[F+116224>>2]=D;c[F+181760>>2]=D;D=c[3527034]|0;c[F+65532>>2]=D;c[F+196604>>2]=D;c[F+45056>>2]=1;c[F+110592>>2]=1;c[F+45060>>2]=1;c[F+110596>>2]=1;c[F+45064>>2]=1;c[F+110600>>2]=1;c[F+45068>>2]=1;c[F+110604>>2]=1;c[F+45072>>2]=1;c[F+110608>>2]=1;c[F+45076>>2]=1;c[F+110612>>2]=1;c[F+45080>>2]=1;c[F+110616>>2]=1;c[F+45084>>2]=1;c[F+110620>>2]=1;c[F+45088>>2]=1;c[F+110624>>2]=1;c[F+45092>>2]=1;c[F+110628>>2]=1;c[F+45096>>2]=1;c[F+110632>>2]=1;c[F+45100>>2]=1;c[F+110636>>2]=1;c[F+45104>>2]=1;c[F+110640>>2]=1;c[F+45108>>2]=1;c[F+110644>>2]=1;c[F+45112>>2]=1;c[F+110648>>2]=1;c[F+45116>>2]=1;c[F+110652>>2]=1;D=x;u=12845056;while(1){c[D+65536>>2]=2;C=u+1024|0;if(C>>>0>12910591){break}else{D=D+4|0;u=C}}c[F+131068>>2]=3;c[F+196688>>2]=1476;c[F+196608>>2]=2160;c[F+196728>>2]=2844;c[F+196648>>2]=2314;c[F+196692>>2]=286;c[F+196612>>2]=1754;c[F+196732>>2]=3428;c[F+196652>>2]=2034;c[F+196736>>2]=1972;c[F+196656>>2]=1402;c[F+196740>>2]=1920;c[F+196660>>2]=1710;c[F+196856>>2]=202;u=c[3532592]|0;if((u|0)!=0){gGC(u|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;u=c[642608+(c[2436]<<2)>>2]|0;D=c[u+128>>2]|0;if((c[u+52>>2]&4|0)==0){c[2113068]=D;x=c[u+132>>2]|0;c[2113070]=x;c[2443814]=D;c[2440436]=x;H=D;I=x}else{c[2113070]=D;x=c[u+132>>2]|0;c[2113068]=x;c[2440436]=D;c[2443814]=x;H=x;I=D}D=ag(H<<1,I)|0;x=gGq(D)|0;c[2112926]=x;if((x|0)!=0){gGz(x|0,0,D|0)}a[642544]=0;c[2415132]=64;c[2415130]=128;c[2439290]=524288;D=gGq(16584)|0;c[2076600]=D;c[D+16524>>2]=16666666;c[D>>2]=16276;c[D+4>>2]=0;h[D+16560>>3]=1.0;c[D+16576>>2]=1;h[D+16568>>3]=1.0;c[D+16580>>2]=2;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];D=c[3532592]|0;if((D|0)!=0){gGC(9104152,D|0,280)|0}c[2113054]=c[2113060]}RI();D=c[2394]|0;x=c[14130368+(D<<2)>>2]|0;if((x|0)!=0){gGC(x|0,9104152,280)|0}c[8452240+(D<<2)>>2]=c[2113054];c[2394]=-1;if((fa(c[c[642608+(c[2436]<<2)>>2]>>2]|0,361672)|0)!=0){y=0;i=d;return y|0}c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];if(a[1040128]|0){y=0;i=d;return y|0}b[7050196]=28680;y=0;i=d;return y|0}}while(0);c[2426698]=0;y=1;i=d;return y|0}function elh(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4522452+(b*112|0)>>2];c[a+104>>2]=c[4522456+(b*112|0)>>2];c[a+108>>2]=c[4522460+(b*112|0)>>2];d=0;return d|0}function eli(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=4522352+(b*112|0);e=0;return e|0}function elj(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1454064+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function elk(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=35){if((a|0)==0){d=0;return d|0}e=a;f=2533880+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}f=b-36|0;if(f>>>0>2){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;a=4523808+(f*12|0)|0;c[b>>2]=c[a>>2];c[b+4>>2]=c[a+4>>2];c[b+8>>2]=c[a+8>>2];d=0;return d|0}function ell(){var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;d=i;i=i+1080|0;e=d|0;f=d+112|0;g=d+120|0;j=d+232|0;k=d+240|0;l=d+352|0;m=d+360|0;n=d+472|0;o=d+480|0;p=d+592|0;q=d+600|0;r=d+712|0;s=d+720|0;t=d+832|0;u=d+840|0;v=d+952|0;w=d+960|0;x=d+1072|0;c[2426698]=0;c[2411330]=0;c[2411324]=2097152;c[3531862]=18874368;c[2405634]=22020096;c[2411902]=22020096;c[3528980]=22085632;if(a[642480]|0){c[2418170]=22085632}c[2411368]=22151168;c[2385744]=22413312;c[2411422]=22675456;c[3527034]=22740992;c[2406856]=22742016;c[2411608]=22742080;c[2414528]=22742080;y=0;while(1){if((y|0)>=1024){break}z=9638528+(y<<2)|0;if((c[z>>2]|0)==0){A=62021;break}else{y=y+1|0}}do{if((A|0)==62021){y=gGq(22873152)|0;c[z>>2]=y;if((y|0)==0){break}c[2426698]=y;gGz(y|0,0,22873152);c[2411330]=y;c[2411324]=y+2097152;c[3531862]=y+18874368;B=y+22020096|0;c[2405634]=B;c[2411902]=B;B=y+22085632|0;c[3528980]=B;if(a[642480]|0){c[2418170]=B}c[2411368]=y+22151168;c[2385744]=y+22413312;c[2411422]=y+22675456;c[3527034]=y+22740992;c[2406856]=y+22742016;B=y+22742080|0;c[2411608]=B;c[2414528]=B;c[2414148]=y+22873152;if((R6(y+1|0,0,2)|0)!=0){C=1;i=d;return C|0}if((R6(c[2411330]|0,1,2)|0)!=0){C=1;i=d;return C|0}if((R6((c[2411330]|0)+1048577|0,2,2)|0)!=0){C=1;i=d;return C|0}if((R6((c[2411330]|0)+1048576|0,3,2)|0)==0){D=0}else{C=1;i=d;return C|0}while(1){if((D|0)>=1024){E=0;break}F=9638528+(D<<2)|0;if((c[F>>2]|0)==0){A=62031;break}else{D=D+1|0}}do{if((A|0)==62031){y=gGq(4194304)|0;c[F>>2]=y;if((y|0)==0){E=0;break}gGz(y|0,0,4194304);E=y}}while(0);y=E+2097152|0;do{if((c[3542200]|0)!=0){B=w+108|0;c[B>>2]=0;G=w+100|0;c[G>>2]=0;H=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[H&16383](w,4)|0;if((c[B>>2]|0)==0){break}B=c[G>>2]|0;c[x>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](x,4,0)|0;if((B|0)<1){break}gzL(E,0,4)|0}}while(0);do{if((c[3542200]|0)!=0){B=u+108|0;c[B>>2]=0;G=u+100|0;c[G>>2]=0;H=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[H&16383](u,5)|0;if((c[B>>2]|0)==0){break}B=c[G>>2]|0;c[v>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](v,5,0)|0;if((B|0)<1){break}gzL(y,0,5)|0}}while(0);emf(E,2097152,0);do{if((c[3542200]|0)!=0){B=s+108|0;c[B>>2]=0;G=s+100|0;c[G>>2]=0;H=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[H&16383](s,6)|0;if((c[B>>2]|0)==0){break}B=c[G>>2]|0;c[t>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](t,6,0)|0;if((B|0)<1){break}gzL(E,0,6)|0}}while(0);do{if((c[3542200]|0)!=0){B=q+108|0;c[B>>2]=0;G=q+100|0;c[G>>2]=0;H=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[H&16383](q,7)|0;if((c[B>>2]|0)==0){break}B=c[G>>2]|0;c[r>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](r,7,0)|0;if((B|0)<1){break}gzL(y,0,7)|0}}while(0);emf(E,2097152,2);do{if((c[3542200]|0)!=0){B=o+108|0;c[B>>2]=0;G=o+100|0;c[G>>2]=0;H=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[H&16383](o,8)|0;if((c[B>>2]|0)==0){break}B=c[G>>2]|0;c[p>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](p,8,0)|0;if((B|0)<1){break}gzL(E,0,8)|0}}while(0);do{if((c[3542200]|0)!=0){B=m+108|0;c[B>>2]=0;G=m+100|0;c[G>>2]=0;H=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[H&16383](m,9)|0;if((c[B>>2]|0)==0){break}B=c[G>>2]|0;c[n>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](n,9,0)|0;if((B|0)<1){break}gzL(y,0,9)|0}}while(0);emf(E,2097152,4);do{if((c[3542200]|0)!=0){B=k+108|0;c[B>>2]=0;G=k+100|0;c[G>>2]=0;H=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[H&16383](k,10)|0;if((c[B>>2]|0)==0){break}B=c[G>>2]|0;c[l>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](l,10,0)|0;if((B|0)<1){break}gzL(E,0,10)|0}}while(0);do{if((c[3542200]|0)!=0){B=g+108|0;c[B>>2]=0;G=g+100|0;c[G>>2]=0;H=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[H&16383](g,11)|0;if((c[B>>2]|0)==0){break}B=c[G>>2]|0;c[j>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](j,11,0)|0;if((B|0)<1){break}gzL(y,0,11)|0}}while(0);emf(E,2097152,6);y=0;while(1){if((y|0)>=1024){break}I=9638528+(y<<2)|0;if((c[I>>2]|0)==(E|0)){A=62068;break}else{y=y+1|0}}if((A|0)==62068){gGr(E);c[I>>2]=0}y=(c[3531862]|0)+1048576|0;do{if((c[3542200]|0)!=0){B=e+108|0;c[B>>2]=0;G=e+100|0;c[G>>2]=0;H=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[H&16383](e,12)|0;if((c[B>>2]|0)==0){break}B=c[G>>2]|0;c[f>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](f,12,0)|0;if((B|0)<1){break}gzL(y,0,12)|0}}while(0);fxU(0,425984);if((c[2394]|0)==0){J=c[2112932]|0}else{c[2394]=0;y=c[3532596]|0;c[2112932]=y;B=c[3532592]|0;if((B|0)!=0){gGC(9104152,B|0,280)|0}c[2113054]=c[2113060];J=y}y=c[2411330]|0;B=J|0;G=0;while(1){H=y+G|0;c[B>>2]=H;c[B+131072>>2]=H;H=G+1024|0;if(H>>>0>2097151){break}else{B=B+4|0;G=H}}G=c[2411902]|0;B=J+8192|0;y=2097152;while(1){H=G+(y-2097152)|0;c[B>>2]=H;c[B+65536>>2]=H;c[B+131072>>2]=H;H=y+1024|0;if(H>>>0>2162687){break}else{B=B+4|0;y=H}}y=c[2411368]|0;B=J+49152|0;G=12582912;while(1){H=y+(G-12582912)|0;c[B>>2]=H;c[B+65536>>2]=H;c[B+131072>>2]=H;H=G+1024|0;if(H>>>0>12845055){break}else{B=B+4|0;G=H}}G=c[2411422]|0;B=J+50176|0;y=B;H=12845056;while(1){K=G+(H-12845056)|0;c[y>>2]=K;c[y+131072>>2]=K;K=H+1024|0;if(K>>>0>12910591){break}else{y=y+4|0;H=K}}H=c[2406856]|0;c[J+50688>>2]=H;c[J+116224>>2]=H;c[J+181760>>2]=H;H=c[3527034]|0;c[J+65532>>2]=H;c[J+196604>>2]=H;c[J+45056>>2]=1;c[J+110592>>2]=1;c[J+45060>>2]=1;c[J+110596>>2]=1;c[J+45064>>2]=1;c[J+110600>>2]=1;c[J+45068>>2]=1;c[J+110604>>2]=1;c[J+45072>>2]=1;c[J+110608>>2]=1;c[J+45076>>2]=1;c[J+110612>>2]=1;c[J+45080>>2]=1;c[J+110616>>2]=1;c[J+45084>>2]=1;c[J+110620>>2]=1;c[J+45088>>2]=1;c[J+110624>>2]=1;c[J+45092>>2]=1;c[J+110628>>2]=1;c[J+45096>>2]=1;c[J+110632>>2]=1;c[J+45100>>2]=1;c[J+110636>>2]=1;c[J+45104>>2]=1;c[J+110640>>2]=1;c[J+45108>>2]=1;c[J+110644>>2]=1;c[J+45112>>2]=1;c[J+110648>>2]=1;c[J+45116>>2]=1;c[J+110652>>2]=1;H=B;y=12845056;while(1){c[H+65536>>2]=2;G=y+1024|0;if(G>>>0>12910591){break}else{H=H+4|0;y=G}}c[J+131068>>2]=3;c[J+196688>>2]=1884;c[J+196608>>2]=2254;c[J+196728>>2]=176;c[J+196648>>2]=2286;c[J+196692>>2]=286;c[J+196612>>2]=1754;c[J+196732>>2]=3428;c[J+196652>>2]=2034;c[J+196736>>2]=1972;c[J+196656>>2]=1402;c[J+196740>>2]=1920;c[J+196660>>2]=1710;c[J+196856>>2]=202;y=c[3532592]|0;if((y|0)!=0){gGC(y|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;y=c[642608+(c[2436]<<2)>>2]|0;H=c[y+128>>2]|0;if((c[y+52>>2]&4|0)==0){c[2113068]=H;B=c[y+132>>2]|0;c[2113070]=B;c[2443814]=H;c[2440436]=B;L=H;M=B}else{c[2113070]=H;B=c[y+132>>2]|0;c[2113068]=B;c[2440436]=H;c[2443814]=B;L=B;M=H}H=ag(L<<1,M)|0;B=gGq(H)|0;c[2112926]=B;if((B|0)!=0){gGz(B|0,0,H|0)}a[642544]=1;c[2415132]=0;c[2415130]=0;c[2439290]=262144;H=gGq(16584)|0;c[2076600]=H;c[H+16524>>2]=16666666;c[H>>2]=16276;c[H+4>>2]=0;h[H+16560>>3]=1.0;c[H+16576>>2]=1;h[H+16568>>3]=1.0;c[H+16580>>2]=2;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];H=c[3532592]|0;if((H|0)!=0){gGC(9104152,H|0,280)|0}c[2113054]=c[2113060]}RI();H=c[2394]|0;B=c[14130368+(H<<2)>>2]|0;if((B|0)!=0){gGC(B|0,9104152,280)|0}c[8452240+(H<<2)>>2]=c[2113054];c[2394]=-1;if((fa(c[c[642608+(c[2436]<<2)>>2]>>2]|0,361672)|0)!=0){C=0;i=d;return C|0}c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];if(a[1040128]|0){C=0;i=d;return C|0}b[7050196]=28680;C=0;i=d;return C|0}}while(0);c[2426698]=0;C=1;i=d;return C|0}function elm(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2532524+(b*112|0)>>2];c[a+104>>2]=c[2532528+(b*112|0)>>2];c[a+108>>2]=c[2532532+(b*112|0)>>2];d=0;return d|0}function eln(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=2532424+(b*112|0);e=0;return e|0}function elo(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>35){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=2533880+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function elp(){var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;d=i;i=i+1080|0;e=d|0;f=d+112|0;g=d+120|0;j=d+232|0;k=d+240|0;l=d+352|0;m=d+360|0;n=d+472|0;o=d+480|0;p=d+592|0;q=d+600|0;r=d+712|0;s=d+720|0;t=d+832|0;u=d+840|0;v=d+952|0;w=d+960|0;x=d+1072|0;c[2426698]=0;c[2411330]=0;c[2411324]=2097152;c[3531862]=27262976;c[2405634]=32505856;c[2411902]=32505856;c[3528980]=32571392;if(a[642480]|0){c[2418170]=32571392}c[2411368]=32636928;c[2385744]=32899072;c[2411422]=33161216;c[3527034]=33226752;c[2406856]=33227776;c[2411608]=33227840;c[2414528]=33227840;y=0;while(1){if((y|0)>=1024){break}z=9638528+(y<<2)|0;if((c[z>>2]|0)==0){A=62137;break}else{y=y+1|0}}do{if((A|0)==62137){y=gGq(33358912)|0;c[z>>2]=y;if((y|0)==0){break}c[2426698]=y;gGz(y|0,0,33358912);c[2411330]=y;c[2411324]=y+2097152;c[3531862]=y+27262976;B=y+32505856|0;c[2405634]=B;c[2411902]=B;B=y+32571392|0;c[3528980]=B;if(a[642480]|0){c[2418170]=B}c[2411368]=y+32636928;c[2385744]=y+32899072;c[2411422]=y+33161216;c[3527034]=y+33226752;c[2406856]=y+33227776;B=y+33227840|0;c[2411608]=B;c[2414528]=B;c[2414148]=y+33358912;if((R6(y+1|0,0,2)|0)!=0){C=1;i=d;return C|0}if((R6(c[2411330]|0,1,2)|0)!=0){C=1;i=d;return C|0}if((R6((c[2411330]|0)+1048577|0,2,2)|0)!=0){C=1;i=d;return C|0}if((R6((c[2411330]|0)+1048576|0,3,2)|0)==0){D=0}else{C=1;i=d;return C|0}while(1){if((D|0)>=1024){E=0;break}F=9638528+(D<<2)|0;if((c[F>>2]|0)==0){A=62147;break}else{D=D+1|0}}do{if((A|0)==62147){y=gGq(6291456)|0;c[F>>2]=y;if((y|0)==0){E=0;break}gGz(y|0,0,6291456);E=y}}while(0);y=E+2097152|0;do{if((c[3542200]|0)!=0){B=w+108|0;c[B>>2]=0;G=w+100|0;c[G>>2]=0;H=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[H&16383](w,4)|0;if((c[B>>2]|0)==0){break}B=c[G>>2]|0;c[x>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](x,4,0)|0;if((B|0)<1){break}gzL(E,0,4)|0}}while(0);do{if((c[3542200]|0)!=0){B=u+108|0;c[B>>2]=0;G=u+100|0;c[G>>2]=0;H=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[H&16383](u,5)|0;if((c[B>>2]|0)==0){break}B=c[G>>2]|0;c[v>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](v,5,0)|0;if((B|0)<1){break}gzL(y,0,5)|0}}while(0);emf(E,3145728,0);do{if((c[3542200]|0)!=0){B=s+108|0;c[B>>2]=0;G=s+100|0;c[G>>2]=0;H=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[H&16383](s,6)|0;if((c[B>>2]|0)==0){break}B=c[G>>2]|0;c[t>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](t,6,0)|0;if((B|0)<1){break}gzL(E,0,6)|0}}while(0);do{if((c[3542200]|0)!=0){B=q+108|0;c[B>>2]=0;G=q+100|0;c[G>>2]=0;H=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[H&16383](q,7)|0;if((c[B>>2]|0)==0){break}B=c[G>>2]|0;c[r>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](r,7,0)|0;if((B|0)<1){break}gzL(y,0,7)|0}}while(0);emf(E,3145728,2);do{if((c[3542200]|0)!=0){B=o+108|0;c[B>>2]=0;G=o+100|0;c[G>>2]=0;H=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[H&16383](o,8)|0;if((c[B>>2]|0)==0){break}B=c[G>>2]|0;c[p>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](p,8,0)|0;if((B|0)<1){break}gzL(E,0,8)|0}}while(0);do{if((c[3542200]|0)!=0){B=m+108|0;c[B>>2]=0;G=m+100|0;c[G>>2]=0;H=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[H&16383](m,9)|0;if((c[B>>2]|0)==0){break}B=c[G>>2]|0;c[n>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](n,9,0)|0;if((B|0)<1){break}gzL(y,0,9)|0}}while(0);emf(E,3145728,4);do{if((c[3542200]|0)!=0){B=k+108|0;c[B>>2]=0;G=k+100|0;c[G>>2]=0;H=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[H&16383](k,10)|0;if((c[B>>2]|0)==0){break}B=c[G>>2]|0;c[l>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](l,10,0)|0;if((B|0)<1){break}gzL(E,0,10)|0}}while(0);do{if((c[3542200]|0)!=0){B=g+108|0;c[B>>2]=0;G=g+100|0;c[G>>2]=0;H=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[H&16383](g,11)|0;if((c[B>>2]|0)==0){break}B=c[G>>2]|0;c[j>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](j,11,0)|0;if((B|0)<1){break}gzL(y,0,11)|0}}while(0);emf(E,3145728,6);y=0;while(1){if((y|0)>=1024){break}I=9638528+(y<<2)|0;if((c[I>>2]|0)==(E|0)){A=62184;break}else{y=y+1|0}}if((A|0)==62184){gGr(E);c[I>>2]=0}y=(c[3531862]|0)+1048576|0;do{if((c[3542200]|0)!=0){B=e+108|0;c[B>>2]=0;G=e+100|0;c[G>>2]=0;H=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[H&16383](e,12)|0;if((c[B>>2]|0)==0){break}B=c[G>>2]|0;c[f>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](f,12,0)|0;if((B|0)<1){break}gzL(y,0,12)|0}}while(0);fxU(0,425984);if((c[2394]|0)==0){J=c[2112932]|0}else{c[2394]=0;y=c[3532596]|0;c[2112932]=y;B=c[3532592]|0;if((B|0)!=0){gGC(9104152,B|0,280)|0}c[2113054]=c[2113060];J=y}y=c[2411330]|0;B=J|0;G=0;while(1){H=y+G|0;c[B>>2]=H;c[B+131072>>2]=H;H=G+1024|0;if(H>>>0>2097151){break}else{B=B+4|0;G=H}}G=c[2411902]|0;B=J+8192|0;y=2097152;while(1){H=G+(y-2097152)|0;c[B>>2]=H;c[B+65536>>2]=H;c[B+131072>>2]=H;H=y+1024|0;if(H>>>0>2162687){break}else{B=B+4|0;y=H}}y=c[2411368]|0;B=J+53248|0;G=13631488;while(1){H=y+(G-13631488)|0;c[B>>2]=H;c[B+65536>>2]=H;c[B+131072>>2]=H;H=G+1024|0;if(H>>>0>13893631){break}else{B=B+4|0;G=H}}G=c[2411422]|0;B=J+54272|0;y=B;H=13893632;while(1){K=G+(H-13893632)|0;c[y>>2]=K;c[y+131072>>2]=K;K=H+1024|0;if(K>>>0>13959167){break}else{y=y+4|0;H=K}}H=c[2406856]|0;c[J+54784>>2]=H;c[J+120320>>2]=H;c[J+185856>>2]=H;H=c[3527034]|0;c[J+65532>>2]=H;c[J+196604>>2]=H;c[J+45056>>2]=1;c[J+110592>>2]=1;c[J+45060>>2]=1;c[J+110596>>2]=1;c[J+45064>>2]=1;c[J+110600>>2]=1;c[J+45068>>2]=1;c[J+110604>>2]=1;c[J+45072>>2]=1;c[J+110608>>2]=1;c[J+45076>>2]=1;c[J+110612>>2]=1;c[J+45080>>2]=1;c[J+110616>>2]=1;c[J+45084>>2]=1;c[J+110620>>2]=1;c[J+45088>>2]=1;c[J+110624>>2]=1;c[J+45092>>2]=1;c[J+110628>>2]=1;c[J+45096>>2]=1;c[J+110632>>2]=1;c[J+45100>>2]=1;c[J+110636>>2]=1;c[J+45104>>2]=1;c[J+110640>>2]=1;c[J+45108>>2]=1;c[J+110644>>2]=1;c[J+45112>>2]=1;c[J+110648>>2]=1;c[J+45116>>2]=1;c[J+110652>>2]=1;H=B;y=13893632;while(1){c[H+65536>>2]=2;G=y+1024|0;if(G>>>0>13959167){break}else{H=H+4|0;y=G}}c[J+131068>>2]=3;c[J+196688>>2]=3474;c[J+196608>>2]=444;c[J+196728>>2]=718;c[J+196648>>2]=2522;c[J+196692>>2]=286;c[J+196612>>2]=1754;c[J+196732>>2]=3428;c[J+196652>>2]=2034;c[J+196736>>2]=1972;c[J+196656>>2]=1402;c[J+196740>>2]=1920;c[J+196660>>2]=1710;c[J+196856>>2]=202;y=c[3532592]|0;if((y|0)!=0){gGC(y|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;y=c[642608+(c[2436]<<2)>>2]|0;H=c[y+128>>2]|0;if((c[y+52>>2]&4|0)==0){c[2113068]=H;B=c[y+132>>2]|0;c[2113070]=B;c[2443814]=H;c[2440436]=B;L=H;M=B}else{c[2113070]=H;B=c[y+132>>2]|0;c[2113068]=B;c[2440436]=H;c[2443814]=B;L=B;M=H}H=ag(L<<1,M)|0;B=gGq(H)|0;c[2112926]=B;if((B|0)!=0){gGz(B|0,0,H|0)}a[642544]=1;c[2415132]=0;c[2415130]=0;c[2439290]=393216;H=gGq(16584)|0;c[2076600]=H;c[H+16524>>2]=16666666;c[H>>2]=16276;c[H+4>>2]=0;h[H+16560>>3]=1.0;c[H+16576>>2]=1;h[H+16568>>3]=1.0;c[H+16580>>2]=2;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];H=c[3532592]|0;if((H|0)!=0){gGC(9104152,H|0,280)|0}c[2113054]=c[2113060]}RI();H=c[2394]|0;B=c[14130368+(H<<2)>>2]|0;if((B|0)!=0){gGC(B|0,9104152,280)|0}c[8452240+(H<<2)>>2]=c[2113054];c[2394]=-1;if((fa(c[c[642608+(c[2436]<<2)>>2]>>2]|0,361672)|0)!=0){C=0;i=d;return C|0}c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];if(a[1040128]|0){C=0;i=d;return C|0}b[7050196]=28680;C=0;i=d;return C|0}}while(0);c[2426698]=0;C=1;i=d;return C|0}function elq(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4466020+(b*112|0)>>2];c[a+104>>2]=c[4466024+(b*112|0)>>2];c[a+108>>2]=c[4466028+(b*112|0)>>2];d=0;return d|0}function elr(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=4465920+(b*112|0);e=0;return e|0}function els(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>50){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4466704+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function elt(){var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;d=i;i=i+600|0;e=d|0;f=d+112|0;g=d+120|0;j=d+232|0;k=d+240|0;l=d+352|0;m=d+360|0;n=d+472|0;o=d+480|0;p=d+592|0;c[2426698]=0;c[2411330]=0;c[2411324]=1048576;c[3531862]=17825792;c[2405634]=23068672;c[2411902]=23068672;c[3528980]=23134208;if(a[642480]|0){c[2418170]=23134208}c[2411368]=23199744;c[2385744]=23461888;c[2411422]=23724032;c[3527034]=23789568;c[2406856]=23790592;c[2411608]=23790656;c[2414528]=23790656;q=0;while(1){if((q|0)>=1024){break}r=9638528+(q<<2)|0;if((c[r>>2]|0)==0){s=62253;break}else{q=q+1|0}}do{if((s|0)==62253){q=gGq(23921728)|0;c[r>>2]=q;if((q|0)==0){break}c[2426698]=q;gGz(q|0,0,23921728);c[2411330]=q;c[2411324]=q+1048576;c[3531862]=q+17825792;t=q+23068672|0;c[2405634]=t;c[2411902]=t;t=q+23134208|0;c[3528980]=t;if(a[642480]|0){c[2418170]=t}c[2411368]=q+23199744;c[2385744]=q+23461888;c[2411422]=q+23724032;c[3527034]=q+23789568;c[2406856]=q+23790592;t=q+23790656|0;c[2411608]=t;c[2414528]=t;c[2414148]=q+23921728;if((R6(q+1|0,0,2)|0)!=0){u=1;i=d;return u|0}if((R6(c[2411330]|0,1,2)|0)==0){v=0}else{u=1;i=d;return u|0}while(1){if((v|0)>=1024){w=0;break}x=9638528+(v<<2)|0;if((c[x>>2]|0)==0){s=62261;break}else{v=v+1|0}}do{if((s|0)==62261){q=gGq(4194304)|0;c[x>>2]=q;if((q|0)==0){w=0;break}gGz(q|0,0,4194304);w=q}}while(0);do{if((c[3542200]|0)!=0){q=o+108|0;c[q>>2]=0;t=o+100|0;c[t>>2]=0;y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[y&16383](o,2)|0;if((c[q>>2]|0)==0){break}q=c[t>>2]|0;c[p>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](p,2,0)|0;if((q|0)<1){break}gzL(w,0,2)|0}}while(0);emf(w,2097152,0);do{if((c[3542200]|0)!=0){q=m+108|0;c[q>>2]=0;t=m+100|0;c[t>>2]=0;y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[y&16383](m,3)|0;if((c[q>>2]|0)==0){break}q=c[t>>2]|0;c[n>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](n,3,0)|0;if((q|0)<1){break}gzL(w,0,3)|0}}while(0);emf(w,2097152,2);do{if((c[3542200]|0)!=0){q=k+108|0;c[q>>2]=0;t=k+100|0;c[t>>2]=0;y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[y&16383](k,4)|0;if((c[q>>2]|0)==0){break}q=c[t>>2]|0;c[l>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](l,4,0)|0;if((q|0)<1){break}gzL(w,0,4)|0}}while(0);emf(w,2097152,4);do{if((c[3542200]|0)!=0){q=g+108|0;c[q>>2]=0;t=g+100|0;c[t>>2]=0;y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[y&16383](g,5)|0;if((c[q>>2]|0)==0){break}q=c[t>>2]|0;c[j>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](j,5,0)|0;if((q|0)<1){break}gzL(w,0,5)|0}}while(0);emf(w,2097152,6);q=0;while(1){if((q|0)>=1024){break}z=9638528+(q<<2)|0;if((c[z>>2]|0)==(w|0)){s=62282;break}else{q=q+1|0}}if((s|0)==62282){gGr(w);c[z>>2]=0}q=(c[3531862]|0)+1048576|0;do{if((c[3542200]|0)!=0){t=e+108|0;c[t>>2]=0;y=e+100|0;c[y>>2]=0;A=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[A&16383](e,6)|0;if((c[t>>2]|0)==0){break}t=c[y>>2]|0;c[f>>2]=9534384;y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[y&16383](f,6,0)|0;if((t|0)<1){break}gzL(q,0,6)|0}}while(0);fxU(0,425984);if((c[2394]|0)==0){B=c[2112932]|0}else{c[2394]=0;q=c[3532596]|0;c[2112932]=q;t=c[3532592]|0;if((t|0)!=0){gGC(9104152,t|0,280)|0}c[2113054]=c[2113060];B=q}q=c[2411330]|0;t=B|0;y=0;while(1){A=q+y|0;c[t>>2]=A;c[t+131072>>2]=A;A=y+1024|0;if(A>>>0>1048575){break}else{t=t+4|0;y=A}}y=c[2411902]|0;t=B+8192|0;q=2097152;while(1){A=y+(q-2097152)|0;c[t>>2]=A;c[t+65536>>2]=A;c[t+131072>>2]=A;A=q+1024|0;if(A>>>0>2162687){break}else{t=t+4|0;q=A}}q=c[2411368]|0;t=B+32768|0;y=8388608;while(1){A=q+(y-8388608)|0;c[t>>2]=A;c[t+65536>>2]=A;c[t+131072>>2]=A;A=y+1024|0;if(A>>>0>8650751){break}else{t=t+4|0;y=A}}y=c[2411422]|0;t=B+33792|0;q=t;A=8650752;while(1){C=y+(A-8650752)|0;c[q>>2]=C;c[q+131072>>2]=C;C=A+1024|0;if(C>>>0>8716287){break}else{q=q+4|0;A=C}}A=c[2406856]|0;c[B+34304>>2]=A;c[B+99840>>2]=A;c[B+165376>>2]=A;A=c[3527034]|0;c[B+65532>>2]=A;c[B+196604>>2]=A;c[B+36864>>2]=1;c[B+102400>>2]=1;c[B+36868>>2]=1;c[B+102404>>2]=1;c[B+36872>>2]=1;c[B+102408>>2]=1;c[B+36876>>2]=1;c[B+102412>>2]=1;c[B+36880>>2]=1;c[B+102416>>2]=1;c[B+36884>>2]=1;c[B+102420>>2]=1;c[B+36888>>2]=1;c[B+102424>>2]=1;c[B+36892>>2]=1;c[B+102428>>2]=1;c[B+36896>>2]=1;c[B+102432>>2]=1;c[B+36900>>2]=1;c[B+102436>>2]=1;c[B+36904>>2]=1;c[B+102440>>2]=1;c[B+36908>>2]=1;c[B+102444>>2]=1;c[B+36912>>2]=1;c[B+102448>>2]=1;c[B+36916>>2]=1;c[B+102452>>2]=1;c[B+36920>>2]=1;c[B+102456>>2]=1;c[B+36924>>2]=1;c[B+102460>>2]=1;A=t;q=8650752;while(1){c[A+65536>>2]=2;y=q+1024|0;if(y>>>0>8716287){break}else{A=A+4|0;q=y}}c[B+131068>>2]=3;c[B+196688>>2]=3438;c[B+196608>>2]=420;c[B+196728>>2]=2168;c[B+196648>>2]=3152;c[B+196692>>2]=286;c[B+196612>>2]=1754;c[B+196732>>2]=3428;c[B+196652>>2]=2034;c[B+196736>>2]=1972;c[B+196656>>2]=1402;c[B+196740>>2]=1920;c[B+196660>>2]=1710;c[B+196856>>2]=202;q=c[3532592]|0;if((q|0)!=0){gGC(q|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;q=c[642608+(c[2436]<<2)>>2]|0;A=c[q+128>>2]|0;if((c[q+52>>2]&4|0)==0){c[2113068]=A;t=c[q+132>>2]|0;c[2113070]=t;c[2443814]=A;c[2440436]=t;D=A;E=t}else{c[2113070]=A;t=c[q+132>>2]|0;c[2113068]=t;c[2440436]=A;c[2443814]=t;D=t;E=A}A=ag(D<<1,E)|0;t=gGq(A)|0;c[2112926]=t;if((t|0)!=0){gGz(t|0,0,A|0)}a[642544]=0;c[2415132]=16;c[2415130]=256;c[2439290]=262144;A=gGq(16584)|0;c[2076600]=A;c[A+16524>>2]=16666666;c[A>>2]=16276;c[A+4>>2]=0;h[A+16560>>3]=1.0;c[A+16576>>2]=1;h[A+16568>>3]=1.0;c[A+16580>>2]=2;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];A=c[3532592]|0;if((A|0)!=0){gGC(9104152,A|0,280)|0}c[2113054]=c[2113060]}RI();A=c[2394]|0;t=c[14130368+(A<<2)>>2]|0;if((t|0)!=0){gGC(t|0,9104152,280)|0}c[8452240+(A<<2)>>2]=c[2113054];c[2394]=-1;if((fa(c[c[642608+(c[2436]<<2)>>2]>>2]|0,361672)|0)!=0){u=0;i=d;return u|0}c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];if(a[1040128]|0){u=0;i=d;return u|0}b[7050196]=28680;u=0;i=d;return u|0}}while(0);c[2426698]=0;u=1;i=d;return u|0}function elu(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>5){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4487900+(b*112|0)>>2];c[a+104>>2]=c[4487904+(b*112|0)>>2];c[a+108>>2]=c[4487908+(b*112|0)>>2];d=0;return d|0}function elv(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<6&(d|0)==0)){e=1;return e|0}c[a>>2]=4487800+(b*112|0);e=0;return e|0}function elw(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1441616+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function elx(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>40){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4488472+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function ely(){var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;d=i;i=i+480|0;e=d|0;f=d+112|0;g=d+120|0;j=d+232|0;k=d+240|0;l=d+352|0;m=d+360|0;n=d+472|0;c[2426698]=0;c[2411330]=0;c[2411324]=1048576;c[3531862]=17825792;c[2405634]=20971520;c[2411902]=20971520;c[3528980]=21037056;if(a[642480]|0){c[2418170]=21299200}c[2411368]=21364736;c[2385744]=21626880;c[2411422]=21889024;c[3527034]=21954560;c[2406856]=21955584;c[2411608]=21955648;c[2414528]=21955648;o=0;while(1){if((o|0)>=1024){break}p=9638528+(o<<2)|0;if((c[p>>2]|0)==0){q=62356;break}else{o=o+1|0}}do{if((q|0)==62356){o=gGq(22086720)|0;c[p>>2]=o;if((o|0)==0){break}c[2426698]=o;gGz(o|0,0,22086720);c[2411330]=o;c[2411324]=o+1048576;c[3531862]=o+17825792;r=o+20971520|0;c[2405634]=r;c[2411902]=r;c[3528980]=o+21037056;if(a[642480]|0){c[2418170]=o+21299200}c[2411368]=o+21364736;c[2385744]=o+21626880;c[2411422]=o+21889024;c[3527034]=o+21954560;c[2406856]=o+21955584;r=o+21955648|0;c[2411608]=r;c[2414528]=r;c[2414148]=o+22086720;if((R6(o+1|0,0,2)|0)!=0){s=1;i=d;return s|0}if((R6(c[2411330]|0,1,2)|0)==0){t=0}else{s=1;i=d;return s|0}while(1){if((t|0)>=1024){u=0;break}v=9638528+(t<<2)|0;if((c[v>>2]|0)==0){q=62364;break}else{t=t+1|0}}do{if((q|0)==62364){o=gGq(4194304)|0;c[v>>2]=o;if((o|0)==0){u=0;break}gGz(o|0,0,4194304);u=o}}while(0);do{if((c[3542200]|0)!=0){o=m+108|0;c[o>>2]=0;r=m+100|0;c[r>>2]=0;w=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[w&16383](m,2)|0;if((c[o>>2]|0)==0){break}o=c[r>>2]|0;c[n>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](n,2,0)|0;if((o|0)<1){break}gzL(u,0,2)|0}}while(0);emf(u,2097152,0);do{if((c[3542200]|0)!=0){o=k+108|0;c[o>>2]=0;r=k+100|0;c[r>>2]=0;w=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[w&16383](k,3)|0;if((c[o>>2]|0)==0){break}o=c[r>>2]|0;c[l>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](l,3,0)|0;if((o|0)<1){break}gzL(u,0,3)|0}}while(0);emf(u,2097152,2);do{if((c[3542200]|0)!=0){o=g+108|0;c[o>>2]=0;r=g+100|0;c[r>>2]=0;w=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[w&16383](g,4)|0;if((c[o>>2]|0)==0){break}o=c[r>>2]|0;c[j>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](j,4,0)|0;if((o|0)<1){break}gzL(u,0,4)|0}}while(0);emf(u,2097152,4);o=0;while(1){if((o|0)>=1024){break}x=9638528+(o<<2)|0;if((c[x>>2]|0)==(u|0)){q=62381;break}else{o=o+1|0}}if((q|0)==62381){gGr(u);c[x>>2]=0}o=(c[3531862]|0)+1048576|0;do{if((c[3542200]|0)!=0){r=e+108|0;c[r>>2]=0;w=e+100|0;c[w>>2]=0;y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[y&16383](e,5)|0;if((c[r>>2]|0)==0){break}r=c[w>>2]|0;c[f>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](f,5,0)|0;if((r|0)<1){break}gzL(o,0,5)|0}}while(0);fxU(0,425984);if((c[2394]|0)==0){z=c[2112932]|0}else{c[2394]=0;o=c[3532596]|0;c[2112932]=o;r=c[3532592]|0;if((r|0)!=0){gGC(9104152,r|0,280)|0}c[2113054]=c[2113060];z=o}o=c[2411330]|0;r=z|0;w=0;while(1){y=o+w|0;c[r>>2]=y;c[r+131072>>2]=y;y=w+1024|0;if(y>>>0>1048575){break}else{r=r+4|0;w=y}}w=c[2411902]|0;r=z+8192|0;o=2097152;while(1){y=w+(o-2097152)|0;c[r>>2]=y;c[r+65536>>2]=y;c[r+131072>>2]=y;y=o+1024|0;if(y>>>0>2162687){break}else{r=r+4|0;o=y}}o=c[3528980]|0;r=z+8448|0;w=2162688;while(1){y=o+(w-2162688)|0;c[r>>2]=y;c[r+65536>>2]=y;c[r+131072>>2]=y;y=w+1024|0;if(y>>>0>2359295){break}else{r=r+4|0;w=y}}w=z+12288|0;r=3145728;while(1){y=o+(r-2949120)|0;c[w>>2]=y;c[w+65536>>2]=y;c[w+131072>>2]=y;y=r+1024|0;if(y>>>0>3211263){break}else{w=w+4|0;r=y}}r=c[2411368]|0;w=z+45056|0;o=11534336;while(1){y=r+(o-11534336)|0;c[w>>2]=y;c[w+65536>>2]=y;c[w+131072>>2]=y;y=o+1024|0;if(y>>>0>11796479){break}else{w=w+4|0;o=y}}o=c[2411422]|0;w=z+46080|0;r=w;y=11796480;while(1){A=o+(y-11796480)|0;c[r>>2]=A;c[r+131072>>2]=A;A=y+1024|0;if(A>>>0>11862015){break}else{r=r+4|0;y=A}}y=c[2406856]|0;c[z+46592>>2]=y;c[z+112128>>2]=y;c[z+177664>>2]=y;y=c[3527034]|0;c[z+65532>>2]=y;c[z+196604>>2]=y;c[z+40960>>2]=1;c[z+106496>>2]=1;c[z+40964>>2]=1;c[z+106500>>2]=1;c[z+40968>>2]=1;c[z+106504>>2]=1;c[z+40972>>2]=1;c[z+106508>>2]=1;c[z+40976>>2]=1;c[z+106512>>2]=1;c[z+40980>>2]=1;c[z+106516>>2]=1;c[z+40984>>2]=1;c[z+106520>>2]=1;c[z+40988>>2]=1;c[z+106524>>2]=1;c[z+40992>>2]=1;c[z+106528>>2]=1;c[z+40996>>2]=1;c[z+106532>>2]=1;c[z+41e3>>2]=1;c[z+106536>>2]=1;c[z+41004>>2]=1;c[z+106540>>2]=1;c[z+41008>>2]=1;c[z+106544>>2]=1;c[z+41012>>2]=1;c[z+106548>>2]=1;c[z+41016>>2]=1;c[z+106552>>2]=1;c[z+41020>>2]=1;c[z+106556>>2]=1;y=w;r=11796480;while(1){c[y+65536>>2]=2;o=r+1024|0;if(o>>>0>11862015){break}else{y=y+4|0;r=o}}c[z+131068>>2]=3;c[z+196688>>2]=2028;c[z+196608>>2]=3062;c[z+196728>>2]=1414;c[z+196648>>2]=1334;c[z+196692>>2]=286;c[z+196612>>2]=1754;c[z+196732>>2]=3428;c[z+196652>>2]=2034;c[z+196736>>2]=1972;c[z+196656>>2]=1402;c[z+196740>>2]=1920;c[z+196660>>2]=1710;c[z+196856>>2]=202;r=c[3532592]|0;if((r|0)!=0){gGC(r|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;r=c[642608+(c[2436]<<2)>>2]|0;y=c[r+128>>2]|0;if((c[r+52>>2]&4|0)==0){c[2113068]=y;w=c[r+132>>2]|0;c[2113070]=w;c[2443814]=y;c[2440436]=w;B=y;C=w}else{c[2113070]=y;w=c[r+132>>2]|0;c[2113068]=w;c[2440436]=y;c[2443814]=w;B=w;C=y}y=ag(B<<1,C)|0;w=gGq(y)|0;c[2112926]=w;if((w|0)!=0){gGz(w|0,0,y|0)}a[642544]=0;c[2415132]=0;c[2415130]=128;c[2439290]=262144;y=gGq(16584)|0;c[2076600]=y;c[y+16524>>2]=16666666;c[y>>2]=16276;c[y+4>>2]=0;h[y+16560>>3]=1.0;c[y+16576>>2]=1;h[y+16568>>3]=1.0;c[y+16580>>2]=2;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];y=c[3532592]|0;if((y|0)!=0){gGC(9104152,y|0,280)|0}c[2113054]=c[2113060]}RI();y=c[2394]|0;w=c[14130368+(y<<2)>>2]|0;if((w|0)!=0){gGC(w|0,9104152,280)|0}c[8452240+(y<<2)>>2]=c[2113054];c[2394]=-1;if((fa(c[c[642608+(c[2436]<<2)>>2]>>2]|0,361672)|0)!=0){s=0;i=d;return s|0}c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];if(a[1040128]|0){s=0;i=d;return s|0}b[7050196]=28680;s=0;i=d;return s|0}}while(0);c[2426698]=0;s=1;i=d;return s|0}function elz(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2807204+(b*112|0)>>2];c[a+104>>2]=c[2807208+(b*112|0)>>2];c[a+108>>2]=c[2807212+(b*112|0)>>2];d=0;return d|0}function elA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=2807104+(b*112|0);e=0;return e|0}function elB(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>24){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1240688+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function elC(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>49){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3884472+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function elD(){var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;d=i;i=i+1320|0;e=d|0;f=d+112|0;g=d+120|0;j=d+232|0;k=d+240|0;l=d+352|0;m=d+360|0;n=d+472|0;o=d+480|0;p=d+592|0;q=d+600|0;r=d+712|0;s=d+720|0;t=d+832|0;u=d+840|0;v=d+952|0;w=d+960|0;x=d+1072|0;y=d+1080|0;z=d+1192|0;A=d+1200|0;B=d+1312|0;c[2426698]=0;c[2411330]=0;c[2411324]=3145728;c[3531862]=36700160;c[2405634]=39845888;c[2411902]=39845888;c[3528980]=39911424;if(a[642480]|0){c[2418170]=39976960}c[2411368]=40042496;c[2385744]=40304640;c[2411422]=40566784;c[3527034]=40632320;c[2406856]=40633344;c[2411608]=40633408;c[2414528]=40633408;C=0;while(1){if((C|0)>=1024){break}D=9638528+(C<<2)|0;if((c[D>>2]|0)==0){E=62459;break}else{C=C+1|0}}do{if((E|0)==62459){C=gGq(40764480)|0;c[D>>2]=C;if((C|0)==0){break}c[2426698]=C;gGz(C|0,0,40764480);c[2411330]=C;c[2411324]=C+3145728;c[3531862]=C+36700160;F=C+39845888|0;c[2405634]=F;c[2411902]=F;c[3528980]=C+39911424;if(a[642480]|0){c[2418170]=C+39976960}c[2411368]=C+40042496;c[2385744]=C+40304640;c[2411422]=C+40566784;c[3527034]=C+40632320;c[2406856]=C+40633344;F=C+40633408|0;c[2411608]=F;c[2414528]=F;c[2414148]=C+40764480;if((R6(C+1|0,0,2)|0)!=0){G=1;i=d;return G|0}if((R6(c[2411330]|0,1,2)|0)!=0){G=1;i=d;return G|0}if((R6((c[2411330]|0)+1048577|0,2,2)|0)!=0){G=1;i=d;return G|0}if((R6((c[2411330]|0)+1048576|0,3,2)|0)!=0){G=1;i=d;return G|0}C=(c[2411330]|0)+2097152|0;if((c[3542200]|0)==0){G=1;i=d;return G|0}F=A+108|0;c[F>>2]=0;H=A+100|0;c[H>>2]=0;I=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[I&16383](A,4)|0;do{if((c[F>>2]|0)==0){J=0}else{I=c[H>>2]|0;c[B>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](B,4,0)|0;if((I|0)<1){G=1;i=d;return G|0}if((gzL(C,0,4)|0)==0){J=0;break}else{G=1}i=d;return G|0}}while(0);while(1){if((J|0)>=1024){L=0;break}M=9638528+(J<<2)|0;if((c[M>>2]|0)==0){E=62473;break}else{J=J+1|0}}do{if((E|0)==62473){C=gGq(6291456)|0;c[M>>2]=C;if((C|0)==0){L=0;break}gGz(C|0,0,6291456);L=C}}while(0);if((c[3542200]|0)==0){G=1;i=d;return G|0}C=y+108|0;c[C>>2]=0;H=y+100|0;c[H>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](y,5)|0;do{if((c[C>>2]|0)!=0){F=c[H>>2]|0;c[z>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](z,5,0)|0;if((F|0)<1){G=1;i=d;return G|0}if((gzL(L,0,5)|0)==0){break}else{G=1}i=d;return G|0}}while(0);H=L+2097152|0;if((c[3542200]|0)==0){G=1;i=d;return G|0}C=w+108|0;c[C>>2]=0;F=w+100|0;c[F>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](w,6)|0;do{if((c[C>>2]|0)!=0){I=c[F>>2]|0;c[x>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](x,6,0)|0;if((I|0)<1){G=1;i=d;return G|0}if((gzL(H,0,6)|0)==0){break}else{G=1}i=d;return G|0}}while(0);F=L+4194304|0;if((c[3542200]|0)==0){G=1;i=d;return G|0}C=u+108|0;c[C>>2]=0;I=u+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](u,7)|0;do{if((c[C>>2]|0)!=0){K=c[I>>2]|0;c[v>>2]=9534384;N=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[N&16383](v,7,0)|0;if((K|0)<1){G=1;i=d;return G|0}if((gzL(F,0,7)|0)==0){break}else{G=1}i=d;return G|0}}while(0);emf(L,3145728,0);if((c[3542200]|0)==0){G=1;i=d;return G|0}I=s+108|0;c[I>>2]=0;C=s+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](s,8)|0;do{if((c[I>>2]|0)!=0){K=c[C>>2]|0;c[t>>2]=9534384;N=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[N&16383](t,8,0)|0;if((K|0)<1){G=1;i=d;return G|0}if((gzL(L,0,8)|0)==0){break}else{G=1}i=d;return G|0}}while(0);if((c[3542200]|0)==0){G=1;i=d;return G|0}C=q+108|0;c[C>>2]=0;I=q+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](q,9)|0;do{if((c[C>>2]|0)!=0){K=c[I>>2]|0;c[r>>2]=9534384;N=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[N&16383](r,9,0)|0;if((K|0)<1){G=1;i=d;return G|0}if((gzL(H,0,9)|0)==0){break}else{G=1}i=d;return G|0}}while(0);if((c[3542200]|0)==0){G=1;i=d;return G|0}I=o+108|0;c[I>>2]=0;C=o+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](o,10)|0;do{if((c[I>>2]|0)!=0){K=c[C>>2]|0;c[p>>2]=9534384;N=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[N&16383](p,10,0)|0;if((K|0)<1){G=1;i=d;return G|0}if((gzL(F,0,10)|0)==0){break}else{G=1}i=d;return G|0}}while(0);emf(L,3145728,2);if((c[3542200]|0)==0){G=1;i=d;return G|0}C=m+108|0;c[C>>2]=0;I=m+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,11)|0;do{if((c[C>>2]|0)!=0){K=c[I>>2]|0;c[n>>2]=9534384;N=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[N&16383](n,11,0)|0;if((K|0)<1){G=1;i=d;return G|0}if((gzL(L,0,11)|0)==0){break}else{G=1}i=d;return G|0}}while(0);if((c[3542200]|0)==0){G=1;i=d;return G|0}I=k+108|0;c[I>>2]=0;C=k+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,12)|0;do{if((c[I>>2]|0)!=0){K=c[C>>2]|0;c[l>>2]=9534384;N=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[N&16383](l,12,0)|0;if((K|0)<1){G=1;i=d;return G|0}if((gzL(H,0,12)|0)==0){break}else{G=1}i=d;return G|0}}while(0);if((c[3542200]|0)==0){G=1;i=d;return G|0}H=g+108|0;c[H>>2]=0;C=g+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,13)|0;do{if((c[H>>2]|0)!=0){I=c[C>>2]|0;c[j>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](j,13,0)|0;if((I|0)<1){G=1;i=d;return G|0}if((gzL(F,0,13)|0)==0){break}else{G=1}i=d;return G|0}}while(0);emf(L,3145728,4);F=0;while(1){if((F|0)>=1024){break}O=9638528+(F<<2)|0;if((c[O>>2]|0)==(L|0)){E=62514;break}else{F=F+1|0}}if((E|0)==62514){gGr(L);c[O>>2]=0}F=(c[3531862]|0)+1048576|0;do{if((c[3542200]|0)!=0){C=e+108|0;c[C>>2]=0;H=e+100|0;c[H>>2]=0;I=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[I&16383](e,14)|0;if((c[C>>2]|0)==0){break}C=c[H>>2]|0;c[f>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](f,14,0)|0;if((C|0)<1){break}gzL(F,0,14)|0}}while(0);fxU(0,425984);if((c[2394]|0)==0){P=c[2112932]|0}else{c[2394]=0;F=c[3532596]|0;c[2112932]=F;C=c[3532592]|0;if((C|0)!=0){gGC(9104152,C|0,280)|0}c[2113054]=c[2113060];P=F}F=c[2411330]|0;C=P|0;H=0;while(1){I=F+H|0;c[C>>2]=I;c[C+131072>>2]=I;I=H+1024|0;if(I>>>0>2097151){break}else{C=C+4|0;H=I}}H=c[2411902]|0;C=P+8192|0;I=2097152;while(1){K=H+(I-2097152)|0;c[C>>2]=K;c[C+65536>>2]=K;c[C+131072>>2]=K;K=I+1024|0;if(K>>>0>2162687){break}else{C=C+4|0;I=K}}I=P+20480|0;C=5242880;while(1){H=F+(C-3145728)|0;c[I>>2]=H;c[I+131072>>2]=H;H=C+1024|0;if(H>>>0>5767167){break}else{I=I+4|0;C=H}}C=c[2411368]|0;I=P+49152|0;F=12582912;while(1){H=C+(F-12582912)|0;c[I>>2]=H;c[I+65536>>2]=H;c[I+131072>>2]=H;H=F+1024|0;if(H>>>0>12845055){break}else{I=I+4|0;F=H}}F=c[2411422]|0;I=P+50176|0;C=I;H=12845056;while(1){K=F+(H-12845056)|0;c[C>>2]=K;c[C+131072>>2]=K;K=H+1024|0;if(K>>>0>12910591){break}else{C=C+4|0;H=K}}H=c[3528980]|0;C=P+50432|0;F=12910592;while(1){K=H+(F-12910592)|0;c[C>>2]=K;c[C+65536>>2]=K;c[C+131072>>2]=K;K=F+1024|0;if(K>>>0>12976127){break}else{C=C+4|0;F=K}}F=c[2406856]|0;c[P+50688>>2]=F;c[P+116224>>2]=F;c[P+181760>>2]=F;c[P+45056>>2]=1;c[P+110592>>2]=1;c[P+45060>>2]=1;c[P+110596>>2]=1;c[P+45064>>2]=1;c[P+110600>>2]=1;c[P+45068>>2]=1;c[P+110604>>2]=1;c[P+45072>>2]=1;c[P+110608>>2]=1;c[P+45076>>2]=1;c[P+110612>>2]=1;c[P+45080>>2]=1;c[P+110616>>2]=1;c[P+45084>>2]=1;c[P+110620>>2]=1;c[P+45088>>2]=1;c[P+110624>>2]=1;c[P+45092>>2]=1;c[P+110628>>2]=1;c[P+45096>>2]=1;c[P+110632>>2]=1;c[P+45100>>2]=1;c[P+110636>>2]=1;c[P+45104>>2]=1;c[P+110640>>2]=1;c[P+45108>>2]=1;c[P+110644>>2]=1;c[P+45112>>2]=1;c[P+110648>>2]=1;c[P+45116>>2]=1;c[P+110652>>2]=1;F=I;C=12845056;while(1){c[F+65536>>2]=2;H=C+1024|0;if(H>>>0>12910591){break}else{F=F+4|0;C=H}}c[P+196688>>2]=194;c[P+196728>>2]=1446;c[P+196648>>2]=1744;c[P+196692>>2]=286;c[P+196612>>2]=1754;c[P+196732>>2]=3428;c[P+196652>>2]=2034;c[P+196736>>2]=1972;c[P+196656>>2]=1402;c[P+196856>>2]=202;C=c[3532592]|0;if((C|0)!=0){gGC(C|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;C=c[642608+(c[2436]<<2)>>2]|0;F=c[C+128>>2]|0;if((c[C+52>>2]&4|0)==0){c[2113068]=F;I=c[C+132>>2]|0;c[2113070]=I;c[2443814]=F;c[2440436]=I;Q=F;R=I}else{c[2113070]=F;I=c[C+132>>2]|0;c[2113068]=I;c[2440436]=F;c[2443814]=I;Q=I;R=F}F=ag(Q<<1,R)|0;I=gGq(F)|0;c[2112926]=I;if((I|0)!=0){gGz(I|0,0,F|0)}a[642544]=0;c[2415132]=0;c[2415130]=256;c[2439290]=524288;F=gGq(16584)|0;c[2076600]=F;c[F+16524>>2]=16666666;c[F>>2]=16276;c[F+4>>2]=0;h[F+16560>>3]=1.0;c[F+16576>>2]=1;h[F+16568>>3]=1.0;c[F+16580>>2]=2;Tq(689936);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];F=c[3532592]|0;if((F|0)!=0){gGC(9104152,F|0,280)|0}c[2113054]=c[2113060]}RI();F=c[2394]|0;I=c[14130368+(F<<2)>>2]|0;if((I|0)!=0){gGC(I|0,9104152,280)|0}c[8452240+(F<<2)>>2]=c[2113054];c[2394]=-1;if((fa(c[c[642608+(c[2436]<<2)>>2]>>2]|0,361672)|0)!=0){G=0;i=d;return G|0}c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];if(a[1040128]|0){G=0;i=d;return G|0}b[7050196]=28680;G=0;i=d;return G|0}}while(0);c[2426698]=0;G=1;i=d;return G|0}function elE(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2947636+(b*112|0)>>2];c[a+104>>2]=c[2947640+(b*112|0)>>2];c[a+108>>2]=c[2947644+(b*112|0)>>2];d=0;return d|0}function elF(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=2947536+(b*112|0);e=0;return e|0}function elG(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1284616+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function elH(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>48){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4076392+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function elI(){var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;d=i;i=i+600|0;e=d|0;f=d+112|0;g=d+120|0;j=d+232|0;k=d+240|0;l=d+352|0;m=d+360|0;n=d+472|0;o=d+480|0;p=d+592|0;a[642480]=1;c[2426698]=0;c[2411330]=0;c[2411324]=2097152;c[3531862]=35651584;c[2405634]=40894464;c[2411902]=40894464;c[3528980]=4096e4;c[2418170]=41025536;c[2411368]=41091072;c[2385744]=41353216;c[2411422]=41615360;c[3527034]=41680896;c[2406856]=41681920;c[2411608]=41681984;c[2414528]=41681984;q=0;while(1){if((q|0)>=1024){break}r=9638528+(q<<2)|0;if((c[r>>2]|0)==0){s=62622;break}else{q=q+1|0}}do{if((s|0)==62622){q=gGq(41813056)|0;c[r>>2]=q;if((q|0)==0){break}c[2426698]=q;gGz(q|0,0,41813056);c[2411330]=q;c[2411324]=q+2097152;c[3531862]=q+35651584;t=q+40894464|0;c[2405634]=t;c[2411902]=t;c[3528980]=q+4096e4;if(a[642480]|0){c[2418170]=q+41025536}c[2411368]=q+41091072;c[2385744]=q+41353216;c[2411422]=q+41615360;c[3527034]=q+41680896;c[2406856]=q+41681920;t=q+41681984|0;c[2411608]=t;c[2414528]=t;c[2414148]=q+41813056;if((R6(q+1|0,0,2)|0)!=0){u=1;i=d;return u|0}if((R6(c[2411330]|0,1,2)|0)==0){v=0}else{u=1;i=d;return u|0}while(1){if((v|0)>=1024){w=0;break}x=9638528+(v<<2)|0;if((c[x>>2]|0)==0){s=62630;break}else{v=v+1|0}}do{if((s|0)==62630){q=gGq(8388608)|0;c[x>>2]=q;if((q|0)==0){w=0;break}gGz(q|0,0,8388608);w=q}}while(0);if((c[3542200]|0)==0){u=1;i=d;return u|0}q=o+108|0;c[q>>2]=0;t=o+100|0;c[t>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](o,2)|0;do{if((c[q>>2]|0)!=0){y=c[t>>2]|0;c[p>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](p,2,0)|0;if((y|0)<1){u=1;i=d;return u|0}if((gzL(w,0,2)|0)==0){break}else{u=1}i=d;return u|0}}while(0);emf(w,4194304,0);if((c[3542200]|0)==0){u=1;i=d;return u|0}t=m+108|0;c[t>>2]=0;q=m+100|0;c[q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,3)|0;do{if((c[t>>2]|0)!=0){y=c[q>>2]|0;c[n>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](n,3,0)|0;if((y|0)<1){u=1;i=d;return u|0}if((gzL(w,0,3)|0)==0){break}else{u=1}i=d;return u|0}}while(0);emf(w,4194304,2);if((c[3542200]|0)==0){u=1;i=d;return u|0}q=k+108|0;c[q>>2]=0;t=k+100|0;c[t>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,4)|0;do{if((c[q>>2]|0)!=0){y=c[t>>2]|0;c[l>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](l,4,0)|0;if((y|0)<1){u=1;i=d;return u|0}if((gzL(w,0,4)|0)==0){break}else{u=1}i=d;return u|0}}while(0);emf(w,4194304,4);if((c[3542200]|0)==0){u=1;i=d;return u|0}t=g+108|0;c[t>>2]=0;q=g+100|0;c[q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,5)|0;do{if((c[t>>2]|0)!=0){y=c[q>>2]|0;c[j>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](j,5,0)|0;if((y|0)<1){u=1;i=d;return u|0}if((gzL(w,0,5)|0)==0){break}else{u=1}i=d;return u|0}}while(0);emf(w,4194304,6);q=0;while(1){if((q|0)>=1024){break}A=9638528+(q<<2)|0;if((c[A>>2]|0)==(w|0)){s=62651;break}else{q=q+1|0}}if((s|0)==62651){gGr(w);c[A>>2]=0}q=(c[3531862]|0)+1048576|0;do{if((c[3542200]|0)!=0){t=e+108|0;c[t>>2]=0;y=e+100|0;c[y>>2]=0;z=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[z&16383](e,6)|0;if((c[t>>2]|0)==0){break}t=c[y>>2]|0;c[f>>2]=9534384;y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[y&16383](f,6,0)|0;if((t|0)<1){break}gzL(q,0,6)|0}}while(0);fxU(0,425984);if((c[2394]|0)==0){B=c[2112932]|0}else{c[2394]=0;q=c[3532596]|0;c[2112932]=q;t=c[3532592]|0;if((t|0)!=0){gGC(9104152,t|0,280)|0}c[2113054]=c[2113060];B=q}q=c[2411330]|0;t=B|0;y=0;while(1){z=q+y|0;c[t>>2]=z;c[t+131072>>2]=z;z=y+1024|0;if(z>>>0>2097151){break}else{t=t+4|0;y=z}}y=c[2411902]|0;t=B+8192|0;q=2097152;while(1){z=y+(q-2097152)|0;c[t>>2]=z;c[t+65536>>2]=z;c[t+131072>>2]=z;z=q+1024|0;if(z>>>0>2162687){break}else{t=t+4|0;q=z}}q=c[2418170]|0;t=B+12288|0;y=3145728;while(1){z=q+(y-3145728)|0;c[t>>2]=z;c[t+65536>>2]=z;c[t+131072>>2]=z;z=y+1024|0;if(z>>>0>3211263){break}else{t=t+4|0;y=z}}y=c[2411368]|0;t=B+32768|0;q=8388608;while(1){z=y+(q-8388608)|0;c[t>>2]=z;c[t+65536>>2]=z;c[t+131072>>2]=z;z=q+1024|0;if(z>>>0>8650751){break}else{t=t+4|0;q=z}}q=c[2411422]|0;t=B+33792|0;y=t;z=8650752;while(1){C=q+(z-8650752)|0;c[y>>2]=C;c[y+131072>>2]=C;C=z+1024|0;if(C>>>0>8716287){break}else{y=y+4|0;z=C}}z=c[2406856]|0;c[B+34304>>2]=z;c[B+99840>>2]=z;c[B+165376>>2]=z;z=c[3527034]|0;c[B+65532>>2]=z;c[B+196604>>2]=z;z=t;y=8650752;while(1){c[z+65536>>2]=2;q=y+1024|0;if(q>>>0>8716287){break}else{z=z+4|0;y=q}}c[B+36864>>2]=1;c[B+102400>>2]=1;c[B+36868>>2]=1;c[B+102404>>2]=1;c[B+36872>>2]=1;c[B+102408>>2]=1;c[B+36876>>2]=1;c[B+102412>>2]=1;c[B+36880>>2]=1;c[B+102416>>2]=1;c[B+36884>>2]=1;c[B+102420>>2]=1;c[B+36888>>2]=1;c[B+102424>>2]=1;c[B+36892>>2]=1;c[B+102428>>2]=1;c[B+36896>>2]=1;c[B+102432>>2]=1;c[B+36900>>2]=1;c[B+102436>>2]=1;c[B+36904>>2]=1;c[B+102440>>2]=1;c[B+36908>>2]=1;c[B+102444>>2]=1;c[B+36912>>2]=1;c[B+102448>>2]=1;c[B+36916>>2]=1;c[B+102452>>2]=1;c[B+36920>>2]=1;c[B+102456>>2]=1;c[B+36924>>2]=1;c[B+102460>>2]=1;c[B+131068>>2]=3;c[B+196688>>2]=1302;c[B+196728>>2]=696;c[B+196692>>2]=286;c[B+196612>>2]=1754;c[B+196732>>2]=3428;c[B+196652>>2]=2034;c[B+196736>>2]=1972;c[B+196656>>2]=1402;c[B+196740>>2]=1920;c[B+196660>>2]=1710;c[B+196856>>2]=202;y=c[3532592]|0;if((y|0)!=0){gGC(y|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;y=c[642608+(c[2436]<<2)>>2]|0;z=c[y+128>>2]|0;if((c[y+52>>2]&4|0)==0){c[2113068]=z;t=c[y+132>>2]|0;c[2113070]=t;c[2443814]=z;c[2440436]=t;D=z;E=t}else{c[2113070]=z;t=c[y+132>>2]|0;c[2113068]=t;c[2440436]=z;c[2443814]=t;D=t;E=z}z=ag(D<<1,E)|0;t=gGq(z)|0;c[2112926]=t;if((t|0)!=0){gGz(t|0,0,z|0)}a[642544]=0;c[2415132]=64;c[2415130]=64;c[2439290]=524288;z=gGq(16584)|0;c[2076600]=z;c[z+16524>>2]=16666666;c[z>>2]=16276;c[z+4>>2]=0;h[z+16560>>3]=1.0;c[z+16576>>2]=1;h[z+16568>>3]=1.0;c[z+16580>>2]=2;c[2113302]=2;a[801640]=0;z=c[642608+(c[2436]<<2)>>2]|0;t=c[z+128>>2]|0;if((c[z+52>>2]&4|0)==0){c[2440576]=t;y=c[z+132>>2]|0;c[2440574]=y;F=t;G=y}else{c[2440574]=t;y=c[z+132>>2]|0;c[2440576]=y;F=y;G=t}t=(((F|0)/2|0)<<8)-1792|0;y=(((G|0)/2|0)<<8)-2048|0;c[3542196]=t;c[3542192]=y;c[3542197]=t;c[3542193]=y;c[3542198]=t;c[3542194]=y;c[3542199]=t;c[3542195]=y;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];y=c[3532592]|0;if((y|0)!=0){gGC(9104152,y|0,280)|0}c[2113054]=c[2113060]}RI();y=c[2394]|0;t=c[14130368+(y<<2)>>2]|0;if((t|0)!=0){gGC(t|0,9104152,280)|0}c[8452240+(y<<2)>>2]=c[2113054];c[2394]=-1;if((fa(c[c[642608+(c[2436]<<2)>>2]>>2]|0,361672)|0)!=0){u=0;i=d;return u|0}c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];if(a[1040128]|0){u=0;i=d;return u|0}b[7050196]=28680;u=0;i=d;return u|0}}while(0);c[2426698]=0;u=1;i=d;return u|0}function elJ(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;do{if((a[9623976]|0)!=0){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;if((fa(c[c[642608+(c[2436]<<2)>>2]>>2]|0,361672)|0)!=0){break}c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];if(a[1040128]|0){break}b[7050196]=28680}}while(0);gGz(9625632,-1|0,5);d=0;e=-1;f=-1;g=-1;h=-1;i=-1;do{e=((a[9633144+d|0]&1)<<d^e&255)&255;f=((a[9631016+d|0]&1)<<d^f&255)&255;g=((a[9629448+d|0]&1)<<d^g&255)&255;h=((a[9628920+d|0]&1)<<d^h&255)&255;i=((a[9628712+d|0]&1)<<d^i&255)&255;d=d+1|0;}while((d|0)<8);a[9625632]=e;a[9625633]=f;a[9625634]=g;a[9625635]=h;a[9625636]=i;i=c[2408955]|0;h=(c[3542196]|0)+(c[2408954]<<16>>16)|0;c[3542196]=h;g=(c[3542192]|0)+(i<<16>>16)|0;c[3542192]=g;if((h|0)<-2048){c[3542196]=-2048;j=-2048}else{j=h}h=(c[2440576]<<8)-2048|0;if((j|0)>(h|0)){c[3542196]=h;k=h}else{k=j}if((g|0)<-2048){c[3542192]=-2048;l=-2048}else{l=g}g=(c[2440574]<<8)-2048|0;if((l|0)>(g|0)){c[3542192]=g;m=g}else{m=l}l=c[2408957]|0;j=(c[3542197]|0)+(c[2408956]<<16>>16)|0;c[3542197]=j;i=(c[3542193]|0)+(l<<16>>16)|0;c[3542193]=i;if((j|0)<-2048){c[3542197]=-2048;n=-2048}else{n=j}if((n|0)>(h|0)){c[3542197]=h;o=h}else{o=n}if((i|0)<-2048){c[3542193]=-2048;p=-2048}else{p=i}if((p|0)>(g|0)){c[3542193]=g;q=g}else{q=p}a[9755360]=~~((320.0- +((k>>8)+8|0))/320.0*160.0)+36&255;a[9755352]=~~((240.0- +((m>>8)+8|0))/240.0*240.0)+22&255;a[9755344]=~~((320.0- +((o>>8)+8|0))/320.0*160.0)+36&255;a[9755336]=~~((240.0- +((q>>8)+8|0))/240.0*240.0)+22&255;q=c[2392]|0;if((q|0)>=0){gGz(8452240,0,((q|0)>0?(q<<2)+4|0:4)|0)}c[2113054]=0;if((c[2394]|0)==0){r=0;s=8680;t=0}else{c[2394]=0;c[2112932]=c[3532596];q=c[3532592]|0;if((q|0)!=0){gGC(9104152,q|0,280)|0}c[2113054]=c[2113060];r=0;s=8680;t=0}while(1){q=s-r|0;c[2113056]=q;o=RG(q)|0;c[2113054]=(c[2113054]|0)+o;c[2276108]=-1;c[2113056]=-1;q=c[2438050]|0;do{if((q|0)!=0){m=(c[2427058]|0)+o|0;c[2427058]=m;if((m|0)<(q|0)){break}c[2438050]=0;c[2427058]=0;el6(0)}}while(0);q=c[2438051]|0;do{if((q|0)!=0){m=(c[2427059]|0)+o|0;c[2427059]=m;if((m|0)<(q|0)){break}c[2438051]=0;c[2427059]=0;el6(1)}}while(0);q=c[2438052]|0;do{if((q|0)!=0){m=(c[2427060]|0)+o|0;c[2427060]=m;if((m|0)<(q|0)){break}c[2438052]=0;c[2427060]=0;el6(2)}}while(0);q=o+r|0;do{if((t|0)==15){m=c[3527034]|0;if((b[m+148>>1]&4)!=0){u=16;break}k=b[m+132>>1]&7;c[9718296+(k<<2)>>2]=b[m+154>>1]&224|2;c[8452200+(c[2394]<<2)>>2]=k|8192;m=c[2276080]|0;p=k<<8;c[2276080]=p;if((m|0)!=1792&(k|0)==7){RH(7);v=62755;break}if(p>>>0<=(c[2276079]|0)>>>0){v=62755;break}RH(k);v=62755}else{v=62755}}while(0);if((v|0)==62755){v=0;o=t+1|0;if((o|0)<32){u=o}else{break}}r=q;s=s+8680|0;t=u}u=c[3527034]|0;do{if((b[u+148>>1]&1)==0){t=b[u+128>>1]&7;c[9718296+(t<<2)>>2]=b[u+154>>1]&224;c[8452200+(c[2394]<<2)>>2]=t|8192;s=c[2276080]|0;r=t<<8;c[2276080]=r;if((s|0)!=1792&(t|0)==7){RH(7);break}if(r>>>0<=(c[2276079]|0)>>>0){break}RH(t)}}while(0);u=c[2394]|0;t=c[14130368+(u<<2)>>2]|0;if((t|0)!=0){gGC(t|0,9104152,280)|0}c[8452240+(u<<2)>>2]=c[2113054];c[2394]=-1;do{if((c[2112968]|0)!=0){el7();u=(c[642608+(c[2436]<<2)>>2]|0)+56|0;if((c[u>>2]|0)>0){w=0}else{break}do{R7(w,c[14168784+(w<<2)>>2]>>8,c[14168768+(w<<2)>>2]>>8);w=w+1|0;}while((w|0)<(c[u>>2]|0))}}while(0);if((c[2112964]|0)==0){return 0}TV();return 0}function elK(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2951556+(b*112|0)>>2];c[a+104>>2]=c[2951560+(b*112|0)>>2];c[a+108>>2]=c[2951564+(b*112|0)>>2];d=0;return d|0}function elL(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=2951456+(b*112|0);e=0;return e|0}function elM(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2950772+(b*112|0)>>2];c[a+104>>2]=c[2950776+(b*112|0)>>2];c[a+108>>2]=c[2950780+(b*112|0)>>2];d=0;return d|0}function elN(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=2950672+(b*112|0);e=0;return e|0}function elO(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2949988+(b*112|0)>>2];c[a+104>>2]=c[2949992+(b*112|0)>>2];c[a+108>>2]=c[2949996+(b*112|0)>>2];d=0;return d|0}function elP(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=2949888+(b*112|0);e=0;return e|0}function elQ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2949204+(b*112|0)>>2];c[a+104>>2]=c[2949208+(b*112|0)>>2];c[a+108>>2]=c[2949212+(b*112|0)>>2];d=0;return d|0}function elR(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=2949104+(b*112|0);e=0;return e|0}function elS(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2948420+(b*112|0)>>2];c[a+104>>2]=c[2948424+(b*112|0)>>2];c[a+108>>2]=c[2948428+(b*112|0)>>2];d=0;return d|0}function elT(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=2948320+(b*112|0);e=0;return e|0}function elU(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2116068+(b*112|0)>>2];c[a+104>>2]=c[2116072+(b*112|0)>>2];c[a+108>>2]=c[2116076+(b*112|0)>>2];d=0;return d|0}function elV(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=2115968+(b*112|0);e=0;return e|0}function elW(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>48){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3278784+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function elX(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4313164+(b*112|0)>>2];c[a+104>>2]=c[4313168+(b*112|0)>>2];c[a+108>>2]=c[4313172+(b*112|0)>>2];d=0;return d|0}function elY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=4313064+(b*112|0);e=0;return e|0}function elZ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1639608+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function el_(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>41){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4871200+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function el$(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2073492+(b*112|0)>>2];c[a+104>>2]=c[2073496+(b*112|0)>>2];c[a+108>>2]=c[2073500+(b*112|0)>>2];d=0;return d|0}function el0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=2073392+(b*112|0);e=0;return e|0}function el1(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2072708+(b*112|0)>>2];c[a+104>>2]=c[2072712+(b*112|0)>>2];c[a+108>>2]=c[2072716+(b*112|0)>>2];d=0;return d|0}function el2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=2072608+(b*112|0);e=0;return e|0}function el3(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4344052+(b*112|0)>>2];c[a+104>>2]=c[4344056+(b*112|0)>>2];c[a+108>>2]=c[4344060+(b*112|0)>>2];d=0;return d|0}function el4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=4343952+(b*112|0);e=0;return e|0}function el5(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>44){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4915584+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function el6(a){a=a|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0.0;d=a<<5;f=(d+512|0)/2|0;g=c[3527034]|0;h=b[g+(a+71<<1)>>1]|0;i=b[g+154>>1]|0;j=e[g+(f<<1)>>1]|0;do{if((j&4|0)!=0){if(((e[g+148>>1]|0)&256<<a|0)!=0){break}k=h&7;c[9718296+(k<<2)>>2]=a+4+(i&224);c[8452200+(c[2394]<<2)>>2]=k|8192;l=c[2276080]|0;m=k<<8;c[2276080]=m;if((l|0)!=1792&(k|0)==7){RH(7);break}if(m>>>0<=(c[2276079]|0)>>>0){break}RH(k)}}while(0);if((j&128|0)==0){return}j=c[3527034]|0;i=b[j+(f<<1)>>1]|0;f=b[j+(((d+516|0)/2|0)<<1)>>1]|0;h=b[j+(((d+518|0)/2|0)<<1)>>1]|0;d=9752200+(a<<2)|0;c[d>>2]=0;c[9708232+(a<<2)>>2]=0;a=i&65535;i=a>>>4&3;if((i|0)==2){n=h}else if((i|0)==1){n=f}else{return}if((a&49152|0)!=0|n<<16>>16==0){return}f=a>>>10&15;o=16666666.0/(f>>>0>8?256.0:+(1<<f|0))/+(n&65535|0);if(!((a&2|0)==0&o!=0.0)){return}c[d>>2]=~~(16666666.0/o);return}function el7(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;if((a[9753328]|0)!=0){d=c[2411422]|0;f=c[2414528]|0;g=0;do{h=e[d+(g<<1)>>1]|0;i=h>>>2&248;c[f+(g<<2)>>2]=h>>>7<<8&63488|h&31|(i>>>5|i)<<3&2016;g=g+1|0;}while((g|0)<32768);a[9753328]=0}g=c[2112926]|0;gGz(g|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);g=c[2385744]|0;if((b[(c[2406856]|0)+48>>1]&1)!=0){f=g;d=c[2411368]|0;gGC(f|0,d|0,262144)|0;return}d=g+262144|0;f=g+12288|0;while(1){if(f>>>0>=d>>>0){break}g=b[f>>1]|0;i=g&65535;h=e[f+2>>1]|0;j=e[f+4>>1]|0;k=e[f+6>>1]|0;l=(c[2385744]|0)+((k<<2&131068)<<1)|0;switch(i&1792|0){case 1792:{m=90;break};case 1280:{m=110;break};case 1024:{m=108;break};case 0:{m=108;break};case 256:{m=64;break};case 512:{m=30;break};case 1536:{m=38;break};default:{m=18}}if(l>>>0<d>>>0){n=(k&32768|0)==0;k=(i&4096|0)!=0;o=h+32|0;p=l;l=(i&255)+1|0;do{i=e[p>>1]|0;q=e[p+2>>1]|0;r=e[p+4>>1]|0;s=e[p+6>>1]|0;do{if(n){t=r&16;u=r&8;v=(k?h:i)>>>10&3;w=1<<v;x=w-1|0;y=1<<((k?j:q)>>>10&3);z=y-1|0;A=i+h|0;B=(A&511)-(A&512)|0;A=(a[642544]|0?-16:0)+(q+j&511)|0;if((z|0)<0){break}C=(x|0)<0;D=r>>>5<<4;E=(t|0)==0;F=(u|0)==0;G=(r<<16&458752|s)&-(y<<v);v=0;while(1){if(C){H=G}else{y=A+((F?v:z-v|0)<<3)|0;if(E){I=G;J=0;while(1){gB[m&127](I,D,0,u,(J<<3)+B|0,y);K=J+1|0;if((K|0)>(x|0)){break}else{I=I+1|0;J=K}}}else{J=G;I=0;while(1){gB[m&127](J,D,t,u,(x-I<<3)+B|0,y);K=I+1|0;if((K|0)>(x|0)){break}else{J=J+1|0;I=K}}}H=G+w|0}I=v+1|0;if((I|0)>(z|0)){break}else{G=H;v=I}}}else{v=r>>>15;G=q+j&511;z=(q>>>10<<4|15)+G|0;w=c[2415130]|0;x=w-1+(c[2113070]|0)|0;if((G|0)>(x|0)|(z|0)<(w|0)){break}B=c[2415132]|0;u=B-1+(c[2113068]|0)|0;t=(z|0)>(x|0)?x:z;z=64>>>(v>>>0);if((z|0)<=0){break}x=8<<v;D=s+16|0;E=((G|0)<(w|0)?w:G)-16|0;G=o+i+r|0;w=B-16|0;B=r>>>10<<11&63488;F=(v|0)==0;A=0;while(1){C=A+1|0;I=D-(ag(C,x)|0)&511;J=(a[642544]|0?-32:-16)+I|0;if(!((J|0)<(E|0)|(J|0)>(t|0))){I=A<<6&1984|B;y=0;do{K=(G+(ag(y,x)|0)&1023)-16|0;L83524:do{if(!((K|0)<(w|0)|(K|0)>(u|0))){L=c[2385744]|0;M=(I|y)<<1;N=e[L+(M<<1)>>1]|0;O=N<<16&458752|e[L+((M|1)<<1)>>1];M=N&16;L=N&8;P=F?O:O&524284;O=N>>>5<<4;N=(L|0)==0;if((M|0)==0){Q=0;while(1){R=Q<<1^P;S=((N?Q:v-Q|0)<<3)+J|0;T=0;do{gB[m&127](R^T,O,0,L,(T<<3)+K|0,S);T=T+1|0;}while((T|0)<=(v|0));Q=Q+1|0;if((Q|0)>(v|0)){break L83524}}}if(N){Q=0;do{T=Q<<1^P;S=(Q<<3)+J|0;R=0;do{gB[m&127](T^R,O,M,0,(v-R<<3)+K|0,S);R=R+1|0;}while((R|0)<=(v|0));Q=Q+1|0;}while((Q|0)<=(v|0))}else{Q=0;do{N=Q<<1^P;R=(v-Q<<3)+J|0;S=0;do{gB[m&127](N^S,O,M,L,(v-S<<3)+K|0,R);S=S+1|0;}while((S|0)<=(v|0));Q=Q+1|0;}while((Q|0)<=(v|0))}}}while(0);y=y+1|0;}while((y|0)<64)}if((C|0)<(z|0)){A=C}else{break}}}}while(0);l=l-1|0;p=p+8|0;}while((l|0)>0&p>>>0<d>>>0);U=b[f>>1]|0}else{U=g}if(U<<16>>16<0){break}else{f=f+8|0}}R8(c[2414528]|0);f=c[2385744]|0;U=c[2411368]|0;gGC(f|0,U|0,262144)|0;return}function el8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return}function el9(d,e,f,g,h,i){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;j=(d>>>0)%((c[2439290]|0)>>>0)|0;if((j|0)==0){return}d=h-(c[2415132]|0)|0;h=i-(c[2415130]|0)|0;if((d|0)<-7){return}i=c[2113068]|0;if((d|0)>=(i|0)|(h|0)<-7){return}k=c[2113070]|0;if((h|0)>=(k|0)){return}l=c[2112926]|0;m=(c[2411324]|0)+(j<<6)|0;do{if((d|0)>=0){if((d|0)>(i-8|0)|(h|0)<0){break}if((h|0)>(k-8|0)){break}if((g|0)==0){j=l+((ag(i,h)|0)+d<<1)|0;if((f|0)==0){n=m;o=j;p=0;while(1){q=a[n]|0;if(q<<24>>24!=0){b[o>>1]=(q&255|e)&65535}q=a[n+1|0]|0;if(q<<24>>24!=0){b[o+2>>1]=(q&255|e)&65535}q=a[n+2|0]|0;if(q<<24>>24!=0){b[o+4>>1]=(q&255|e)&65535}q=a[n+3|0]|0;if(q<<24>>24!=0){b[o+6>>1]=(q&255|e)&65535}q=a[n+4|0]|0;if(q<<24>>24!=0){b[o+8>>1]=(q&255|e)&65535}q=a[n+5|0]|0;if(q<<24>>24!=0){b[o+10>>1]=(q&255|e)&65535}q=a[n+6|0]|0;if(q<<24>>24!=0){b[o+12>>1]=(q&255|e)&65535}q=a[n+7|0]|0;if(q<<24>>24!=0){b[o+14>>1]=(q&255|e)&65535}q=p+1|0;if((q|0)<8){n=n+8|0;o=o+(i<<1)|0;p=q}else{break}}return}else{p=m;o=j;n=0;while(1){q=a[p]|0;if(q<<24>>24!=0){b[o+14>>1]=(q&255|e)&65535}q=a[p+1|0]|0;if(q<<24>>24!=0){b[o+12>>1]=(q&255|e)&65535}q=a[p+2|0]|0;if(q<<24>>24!=0){b[o+10>>1]=(q&255|e)&65535}q=a[p+3|0]|0;if(q<<24>>24!=0){b[o+8>>1]=(q&255|e)&65535}q=a[p+4|0]|0;if(q<<24>>24!=0){b[o+6>>1]=(q&255|e)&65535}q=a[p+5|0]|0;if(q<<24>>24!=0){b[o+4>>1]=(q&255|e)&65535}q=a[p+6|0]|0;if(q<<24>>24!=0){b[o+2>>1]=(q&255|e)&65535}q=a[p+7|0]|0;if(q<<24>>24!=0){b[o>>1]=(q&255|e)&65535}q=n+1|0;if((q|0)<8){p=p+8|0;o=o+(i<<1)|0;n=q}else{break}}return}}else{n=l+((ag(i,h+7|0)|0)+d<<1)|0;o=-i|0;if((f|0)==0){p=m;j=n;q=0;while(1){r=a[p]|0;if(r<<24>>24!=0){b[j>>1]=(r&255|e)&65535}r=a[p+1|0]|0;if(r<<24>>24!=0){b[j+2>>1]=(r&255|e)&65535}r=a[p+2|0]|0;if(r<<24>>24!=0){b[j+4>>1]=(r&255|e)&65535}r=a[p+3|0]|0;if(r<<24>>24!=0){b[j+6>>1]=(r&255|e)&65535}r=a[p+4|0]|0;if(r<<24>>24!=0){b[j+8>>1]=(r&255|e)&65535}r=a[p+5|0]|0;if(r<<24>>24!=0){b[j+10>>1]=(r&255|e)&65535}r=a[p+6|0]|0;if(r<<24>>24!=0){b[j+12>>1]=(r&255|e)&65535}r=a[p+7|0]|0;if(r<<24>>24!=0){b[j+14>>1]=(r&255|e)&65535}r=q+1|0;if((r|0)<8){p=p+8|0;j=j+(o<<1)|0;q=r}else{break}}return}else{q=m;j=0;p=n;while(1){r=a[q]|0;if(r<<24>>24!=0){b[p+14>>1]=(r&255|e)&65535}r=a[q+1|0]|0;if(r<<24>>24!=0){b[p+12>>1]=(r&255|e)&65535}r=a[q+2|0]|0;if(r<<24>>24!=0){b[p+10>>1]=(r&255|e)&65535}r=a[q+3|0]|0;if(r<<24>>24!=0){b[p+8>>1]=(r&255|e)&65535}r=a[q+4|0]|0;if(r<<24>>24!=0){b[p+6>>1]=(r&255|e)&65535}r=a[q+5|0]|0;if(r<<24>>24!=0){b[p+4>>1]=(r&255|e)&65535}r=a[q+6|0]|0;if(r<<24>>24!=0){b[p+2>>1]=(r&255|e)&65535}r=a[q+7|0]|0;if(r<<24>>24!=0){b[p>>1]=(r&255|e)&65535}r=j+1|0;if((r|0)<8){q=q+8|0;j=r;p=p+(o<<1)|0}else{break}}return}}}}while(0);if((g|0)==0){g=l+((ag(i,h)|0)+d<<1)|0;if((f|0)==0){o=d+7|0;p=d+6|0;j=d+5|0;q=d+4|0;n=d+3|0;r=d+2|0;s=d+1|0;t=(d|0)>-1;u=(o|0)>-1&(o|0)<(i|0);o=(p|0)>-1&(p|0)<(i|0);p=(j|0)>-1&(j|0)<(i|0);j=(q|0)>-1&(q|0)<(i|0);q=(n|0)>-1&(n|0)<(i|0);n=(r|0)>-1&(r|0)<(i|0);r=(s|0)>-1&(s|0)<(i|0);s=0;v=m;w=g;while(1){x=s+h|0;do{if((x|0)>-1&(x|0)<(k|0)){y=a[v]|0;do{if(y<<24>>24!=0){if(!(t&(d|0)<(i|0))){break}b[w>>1]=(y&255|e)&65535}}while(0);y=a[v+1|0]|0;if(!(y<<24>>24==0|r^1)){b[w+2>>1]=(y&255|e)&65535}y=a[v+2|0]|0;if(!(y<<24>>24==0|n^1)){b[w+4>>1]=(y&255|e)&65535}y=a[v+3|0]|0;if(!(y<<24>>24==0|q^1)){b[w+6>>1]=(y&255|e)&65535}y=a[v+4|0]|0;if(!(y<<24>>24==0|j^1)){b[w+8>>1]=(y&255|e)&65535}y=a[v+5|0]|0;if(!(y<<24>>24==0|p^1)){b[w+10>>1]=(y&255|e)&65535}y=a[v+6|0]|0;if(!(y<<24>>24==0|o^1)){b[w+12>>1]=(y&255|e)&65535}y=a[v+7|0]|0;if(y<<24>>24==0|u^1){break}b[w+14>>1]=(y&255|e)&65535}}while(0);x=s+1|0;if((x|0)>=8){break}s=x;v=v+8|0;w=w+(i<<1)|0}return}else{w=(d|0)>-1;v=d+1|0;s=d+2|0;u=d+3|0;o=d+4|0;p=d+5|0;j=d+6|0;q=d+7|0;n=(q|0)>-1;r=(v|0)>-1&(v|0)<(i|0);v=(s|0)>-1&(s|0)<(i|0);s=(u|0)>-1&(u|0)<(i|0);u=(o|0)>-1&(o|0)<(i|0);o=(p|0)>-1&(p|0)<(i|0);p=(j|0)>-1&(j|0)<(i|0);j=0;t=m;x=g;while(1){g=j+h|0;do{if((g|0)>-1&(g|0)<(k|0)){y=a[t]|0;do{if(y<<24>>24!=0){if(!(n&(q|0)<(i|0))){break}b[x+14>>1]=(y&255|e)&65535}}while(0);y=a[t+1|0]|0;if(!(y<<24>>24==0|p^1)){b[x+12>>1]=(y&255|e)&65535}y=a[t+2|0]|0;if(!(y<<24>>24==0|o^1)){b[x+10>>1]=(y&255|e)&65535}y=a[t+3|0]|0;if(!(y<<24>>24==0|u^1)){b[x+8>>1]=(y&255|e)&65535}y=a[t+4|0]|0;if(!(y<<24>>24==0|s^1)){b[x+6>>1]=(y&255|e)&65535}y=a[t+5|0]|0;if(!(y<<24>>24==0|v^1)){b[x+4>>1]=(y&255|e)&65535}y=a[t+6|0]|0;if(!(y<<24>>24==0|r^1)){b[x+2>>1]=(y&255|e)&65535}y=a[t+7|0]|0;if(y<<24>>24==0|w^1){break}b[x>>1]=(y&255|e)&65535}}while(0);g=j+1|0;if((g|0)>=8){break}j=g;t=t+8|0;x=x+(i<<1)|0}return}}else{x=l+((ag(i,h+7|0)|0)+d<<1)|0;if((f|0)==0){f=d+7|0;l=d+6|0;t=d+5|0;j=d+4|0;w=d+3|0;r=d+2|0;v=d+1|0;s=(d|0)>-1;u=(f|0)>-1&(f|0)<(i|0);f=(l|0)>-1&(l|0)<(i|0);l=(t|0)>-1&(t|0)<(i|0);t=(j|0)>-1&(j|0)<(i|0);j=(w|0)>-1&(w|0)<(i|0);w=(r|0)>-1&(r|0)<(i|0);r=(v|0)>-1&(v|0)<(i|0);v=7;o=m;p=x;while(1){q=v+h|0;do{if((q|0)>-1&(q|0)<(k|0)){n=a[o]|0;do{if(n<<24>>24!=0){if(!(s&(d|0)<(i|0))){break}b[p>>1]=(n&255|e)&65535}}while(0);n=a[o+1|0]|0;if(!(n<<24>>24==0|r^1)){b[p+2>>1]=(n&255|e)&65535}n=a[o+2|0]|0;if(!(n<<24>>24==0|w^1)){b[p+4>>1]=(n&255|e)&65535}n=a[o+3|0]|0;if(!(n<<24>>24==0|j^1)){b[p+6>>1]=(n&255|e)&65535}n=a[o+4|0]|0;if(!(n<<24>>24==0|t^1)){b[p+8>>1]=(n&255|e)&65535}n=a[o+5|0]|0;if(!(n<<24>>24==0|l^1)){b[p+10>>1]=(n&255|e)&65535}n=a[o+6|0]|0;if(!(n<<24>>24==0|f^1)){b[p+12>>1]=(n&255|e)&65535}n=a[o+7|0]|0;if(n<<24>>24==0|u^1){break}b[p+14>>1]=(n&255|e)&65535}}while(0);if((v|0)<=0){break}v=v-1|0;o=o+8|0;p=p+(-i<<1)|0}return}else{p=(d|0)>-1;o=d+1|0;v=d+2|0;u=d+3|0;f=d+4|0;l=d+5|0;t=d+6|0;j=d+7|0;d=(j|0)>-1;w=(o|0)>-1&(o|0)<(i|0);o=(v|0)>-1&(v|0)<(i|0);v=(u|0)>-1&(u|0)<(i|0);u=(f|0)>-1&(f|0)<(i|0);f=(l|0)>-1&(l|0)<(i|0);l=(t|0)>-1&(t|0)<(i|0);t=7;r=m;m=x;while(1){x=t+h|0;do{if((x|0)>-1&(x|0)<(k|0)){s=a[r]|0;do{if(s<<24>>24!=0){if(!(d&(j|0)<(i|0))){break}b[m+14>>1]=(s&255|e)&65535}}while(0);s=a[r+1|0]|0;if(!(s<<24>>24==0|l^1)){b[m+12>>1]=(s&255|e)&65535}s=a[r+2|0]|0;if(!(s<<24>>24==0|f^1)){b[m+10>>1]=(s&255|e)&65535}s=a[r+3|0]|0;if(!(s<<24>>24==0|u^1)){b[m+8>>1]=(s&255|e)&65535}s=a[r+4|0]|0;if(!(s<<24>>24==0|v^1)){b[m+6>>1]=(s&255|e)&65535}s=a[r+5|0]|0;if(!(s<<24>>24==0|o^1)){b[m+4>>1]=(s&255|e)&65535}s=a[r+6|0]|0;if(!(s<<24>>24==0|w^1)){b[m+2>>1]=(s&255|e)&65535}s=a[r+7|0]|0;if(s<<24>>24==0|p^1){break}b[m>>1]=(s&255|e)&65535}}while(0);if((t|0)<=0){break}t=t-1|0;r=r+8|0;m=m+(-i<<1)|0}return}}}function ema(d,e,f,g,h,i){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;j=(d>>>0)%((c[2439290]|0)>>>0)|0;if((j|0)==0){return}d=h-(c[2415132]|0)|0;h=i-(c[2415130]|0)|0;if((d|0)<-7){return}i=c[2113068]|0;if((d|0)>=(i|0)|(h|0)<-7){return}k=c[2113070]|0;if((h|0)>=(k|0)){return}l=c[2112926]|0;m=(c[2411324]|0)+(j<<6)|0;do{if((d|0)>=0){if((d|0)>(i-8|0)|(h|0)<0){break}if((h|0)>(k-8|0)){break}if((g|0)==0){j=l+((ag(i,h)|0)+d<<1)|0;if((f|0)==0){n=m;o=j;p=0;while(1){q=a[n]&63;if(q<<24>>24!=0){b[o>>1]=(q&255|e)&65535}q=a[n+1|0]&63;if(q<<24>>24!=0){b[o+2>>1]=(q&255|e)&65535}q=a[n+2|0]&63;if(q<<24>>24!=0){b[o+4>>1]=(q&255|e)&65535}q=a[n+3|0]&63;if(q<<24>>24!=0){b[o+6>>1]=(q&255|e)&65535}q=a[n+4|0]&63;if(q<<24>>24!=0){b[o+8>>1]=(q&255|e)&65535}q=a[n+5|0]&63;if(q<<24>>24!=0){b[o+10>>1]=(q&255|e)&65535}q=a[n+6|0]&63;if(q<<24>>24!=0){b[o+12>>1]=(q&255|e)&65535}q=a[n+7|0]&63;if(q<<24>>24!=0){b[o+14>>1]=(q&255|e)&65535}q=p+1|0;if((q|0)<8){n=n+8|0;o=o+(i<<1)|0;p=q}else{break}}return}else{p=m;o=j;n=0;while(1){q=a[p]&63;if(q<<24>>24!=0){b[o+14>>1]=(q&255|e)&65535}q=a[p+1|0]&63;if(q<<24>>24!=0){b[o+12>>1]=(q&255|e)&65535}q=a[p+2|0]&63;if(q<<24>>24!=0){b[o+10>>1]=(q&255|e)&65535}q=a[p+3|0]&63;if(q<<24>>24!=0){b[o+8>>1]=(q&255|e)&65535}q=a[p+4|0]&63;if(q<<24>>24!=0){b[o+6>>1]=(q&255|e)&65535}q=a[p+5|0]&63;if(q<<24>>24!=0){b[o+4>>1]=(q&255|e)&65535}q=a[p+6|0]&63;if(q<<24>>24!=0){b[o+2>>1]=(q&255|e)&65535}q=a[p+7|0]&63;if(q<<24>>24!=0){b[o>>1]=(q&255|e)&65535}q=n+1|0;if((q|0)<8){p=p+8|0;o=o+(i<<1)|0;n=q}else{break}}return}}else{n=l+((ag(i,h+7|0)|0)+d<<1)|0;o=-i|0;if((f|0)==0){p=m;j=n;q=0;while(1){r=a[p]&63;if(r<<24>>24!=0){b[j>>1]=(r&255|e)&65535}r=a[p+1|0]&63;if(r<<24>>24!=0){b[j+2>>1]=(r&255|e)&65535}r=a[p+2|0]&63;if(r<<24>>24!=0){b[j+4>>1]=(r&255|e)&65535}r=a[p+3|0]&63;if(r<<24>>24!=0){b[j+6>>1]=(r&255|e)&65535}r=a[p+4|0]&63;if(r<<24>>24!=0){b[j+8>>1]=(r&255|e)&65535}r=a[p+5|0]&63;if(r<<24>>24!=0){b[j+10>>1]=(r&255|e)&65535}r=a[p+6|0]&63;if(r<<24>>24!=0){b[j+12>>1]=(r&255|e)&65535}r=a[p+7|0]&63;if(r<<24>>24!=0){b[j+14>>1]=(r&255|e)&65535}r=q+1|0;if((r|0)<8){p=p+8|0;j=j+(o<<1)|0;q=r}else{break}}return}else{q=m;j=0;p=n;while(1){r=a[q]&63;if(r<<24>>24!=0){b[p+14>>1]=(r&255|e)&65535}r=a[q+1|0]&63;if(r<<24>>24!=0){b[p+12>>1]=(r&255|e)&65535}r=a[q+2|0]&63;if(r<<24>>24!=0){b[p+10>>1]=(r&255|e)&65535}r=a[q+3|0]&63;if(r<<24>>24!=0){b[p+8>>1]=(r&255|e)&65535}r=a[q+4|0]&63;if(r<<24>>24!=0){b[p+6>>1]=(r&255|e)&65535}r=a[q+5|0]&63;if(r<<24>>24!=0){b[p+4>>1]=(r&255|e)&65535}r=a[q+6|0]&63;if(r<<24>>24!=0){b[p+2>>1]=(r&255|e)&65535}r=a[q+7|0]&63;if(r<<24>>24!=0){b[p>>1]=(r&255|e)&65535}r=j+1|0;if((r|0)<8){q=q+8|0;j=r;p=p+(o<<1)|0}else{break}}return}}}}while(0);if((g|0)==0){g=l+((ag(i,h)|0)+d<<1)|0;if((f|0)==0){o=0;p=m;j=g;while(1){q=o+h|0;if((q|0)>-1&(q|0)<(k|0)){q=0;n=p;while(1){r=a[n]&63;do{if(r<<24>>24!=0){s=q+d|0;if(!((s|0)>-1&(s|0)<(i|0))){break}b[j+(q<<1)>>1]=(r&255|e)&65535}}while(0);r=q+1|0;if((r|0)<8){q=r;n=n+1|0}else{break}}}n=o+1|0;if((n|0)>=8){break}o=n;p=p+8|0;j=j+(i<<1)|0}return}else{j=0;p=m;o=g;while(1){g=j+h|0;if((g|0)>-1&(g|0)<(k|0)){g=7;n=p;while(1){q=a[n]&63;do{if(q<<24>>24!=0){r=g+d|0;if(!((r|0)>-1&(r|0)<(i|0))){break}b[o+(g<<1)>>1]=(q&255|e)&65535}}while(0);if((g|0)>0){g=g-1|0;n=n+1|0}else{break}}}n=j+1|0;if((n|0)>=8){break}j=n;p=p+8|0;o=o+(i<<1)|0}return}}else{o=l+((ag(i,h+7|0)|0)+d<<1)|0;l=-i|0;if((f|0)==0){f=7;p=m;j=o;while(1){n=f+h|0;if((n|0)>-1&(n|0)<(k|0)){n=0;g=p;while(1){q=a[g]&63;do{if(q<<24>>24!=0){r=n+d|0;if(!((r|0)>-1&(r|0)<(i|0))){break}b[j+(n<<1)>>1]=(q&255|e)&65535}}while(0);q=n+1|0;if((q|0)<8){n=q;g=g+1|0}else{break}}}if((f|0)<=0){break}f=f-1|0;p=p+8|0;j=j+(l<<1)|0}return}else{j=7;p=m;m=o;while(1){o=j+h|0;if((o|0)>-1&(o|0)<(k|0)){o=7;f=p;while(1){g=a[f]&63;do{if(g<<24>>24!=0){n=o+d|0;if(!((n|0)>-1&(n|0)<(i|0))){break}b[m+(o<<1)>>1]=(g&255|e)&65535}}while(0);if((o|0)>0){o=o-1|0;f=f+1|0}else{break}}}if((j|0)<=0){break}j=j-1|0;p=p+8|0;m=m+(l<<1)|0}return}}}function emb(a,e,f,g,h,i){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;j=(a>>>0)%((c[2439290]|0)>>>0)|0;if((j|0)==0){return}a=h-(c[2415132]|0)|0;h=i-(c[2415130]|0)|0;if((a|0)<-7){return}i=c[2113068]|0;if((a|0)>=(i|0)|(h|0)<-7){return}k=c[2113070]|0;if((h|0)>=(k|0)){return}l=c[2112926]|0;m=(c[2411324]|0)+(j<<6)|0;do{if((a|0)>=0){if((a|0)>(i-8|0)|(h|0)<0){break}if((h|0)>(k-8|0)){break}if((g|0)==0){j=l+((ag(i,h)|0)+a<<1)|0;if((f|0)==0){n=m;o=j;p=0;while(1){q=(d[n]|0)>>>4;if(q<<24>>24!=0){b[o>>1]=(q&255|e)&65535}q=(d[n+1|0]|0)>>>4;if(q<<24>>24!=0){b[o+2>>1]=(q&255|e)&65535}q=(d[n+2|0]|0)>>>4;if(q<<24>>24!=0){b[o+4>>1]=(q&255|e)&65535}q=(d[n+3|0]|0)>>>4;if(q<<24>>24!=0){b[o+6>>1]=(q&255|e)&65535}q=(d[n+4|0]|0)>>>4;if(q<<24>>24!=0){b[o+8>>1]=(q&255|e)&65535}q=(d[n+5|0]|0)>>>4;if(q<<24>>24!=0){b[o+10>>1]=(q&255|e)&65535}q=(d[n+6|0]|0)>>>4;if(q<<24>>24!=0){b[o+12>>1]=(q&255|e)&65535}q=(d[n+7|0]|0)>>>4;if(q<<24>>24!=0){b[o+14>>1]=(q&255|e)&65535}q=p+1|0;if((q|0)<8){n=n+8|0;o=o+(i<<1)|0;p=q}else{break}}return}else{p=m;o=j;n=0;while(1){q=(d[p]|0)>>>4;if(q<<24>>24!=0){b[o+14>>1]=(q&255|e)&65535}q=(d[p+1|0]|0)>>>4;if(q<<24>>24!=0){b[o+12>>1]=(q&255|e)&65535}q=(d[p+2|0]|0)>>>4;if(q<<24>>24!=0){b[o+10>>1]=(q&255|e)&65535}q=(d[p+3|0]|0)>>>4;if(q<<24>>24!=0){b[o+8>>1]=(q&255|e)&65535}q=(d[p+4|0]|0)>>>4;if(q<<24>>24!=0){b[o+6>>1]=(q&255|e)&65535}q=(d[p+5|0]|0)>>>4;if(q<<24>>24!=0){b[o+4>>1]=(q&255|e)&65535}q=(d[p+6|0]|0)>>>4;if(q<<24>>24!=0){b[o+2>>1]=(q&255|e)&65535}q=(d[p+7|0]|0)>>>4;if(q<<24>>24!=0){b[o>>1]=(q&255|e)&65535}q=n+1|0;if((q|0)<8){p=p+8|0;o=o+(i<<1)|0;n=q}else{break}}return}}else{n=l+((ag(i,h+7|0)|0)+a<<1)|0;o=-i|0;if((f|0)==0){p=m;j=n;q=0;while(1){r=(d[p]|0)>>>4;if(r<<24>>24!=0){b[j>>1]=(r&255|e)&65535}r=(d[p+1|0]|0)>>>4;if(r<<24>>24!=0){b[j+2>>1]=(r&255|e)&65535}r=(d[p+2|0]|0)>>>4;if(r<<24>>24!=0){b[j+4>>1]=(r&255|e)&65535}r=(d[p+3|0]|0)>>>4;if(r<<24>>24!=0){b[j+6>>1]=(r&255|e)&65535}r=(d[p+4|0]|0)>>>4;if(r<<24>>24!=0){b[j+8>>1]=(r&255|e)&65535}r=(d[p+5|0]|0)>>>4;if(r<<24>>24!=0){b[j+10>>1]=(r&255|e)&65535}r=(d[p+6|0]|0)>>>4;if(r<<24>>24!=0){b[j+12>>1]=(r&255|e)&65535}r=(d[p+7|0]|0)>>>4;if(r<<24>>24!=0){b[j+14>>1]=(r&255|e)&65535}r=q+1|0;if((r|0)<8){p=p+8|0;j=j+(o<<1)|0;q=r}else{break}}return}else{q=m;j=0;p=n;while(1){r=(d[q]|0)>>>4;if(r<<24>>24!=0){b[p+14>>1]=(r&255|e)&65535}r=(d[q+1|0]|0)>>>4;if(r<<24>>24!=0){b[p+12>>1]=(r&255|e)&65535}r=(d[q+2|0]|0)>>>4;if(r<<24>>24!=0){b[p+10>>1]=(r&255|e)&65535}r=(d[q+3|0]|0)>>>4;if(r<<24>>24!=0){b[p+8>>1]=(r&255|e)&65535}r=(d[q+4|0]|0)>>>4;if(r<<24>>24!=0){b[p+6>>1]=(r&255|e)&65535}r=(d[q+5|0]|0)>>>4;if(r<<24>>24!=0){b[p+4>>1]=(r&255|e)&65535}r=(d[q+6|0]|0)>>>4;if(r<<24>>24!=0){b[p+2>>1]=(r&255|e)&65535}r=(d[q+7|0]|0)>>>4;if(r<<24>>24!=0){b[p>>1]=(r&255|e)&65535}r=j+1|0;if((r|0)<8){q=q+8|0;j=r;p=p+(o<<1)|0}else{break}}return}}}}while(0);if((g|0)==0){g=l+((ag(i,h)|0)+a<<1)|0;if((f|0)==0){o=0;p=m;j=g;while(1){q=o+h|0;if((q|0)>-1&(q|0)<(k|0)){q=0;n=p;while(1){r=(d[n]|0)>>>4;do{if(r<<24>>24!=0){s=q+a|0;if(!((s|0)>-1&(s|0)<(i|0))){break}b[j+(q<<1)>>1]=(r&255|e)&65535}}while(0);r=q+1|0;if((r|0)<8){q=r;n=n+1|0}else{break}}}n=o+1|0;if((n|0)>=8){break}o=n;p=p+8|0;j=j+(i<<1)|0}return}else{j=0;p=m;o=g;while(1){g=j+h|0;if((g|0)>-1&(g|0)<(k|0)){g=7;n=p;while(1){q=(d[n]|0)>>>4;do{if(q<<24>>24!=0){r=g+a|0;if(!((r|0)>-1&(r|0)<(i|0))){break}b[o+(g<<1)>>1]=(q&255|e)&65535}}while(0);if((g|0)>0){g=g-1|0;n=n+1|0}else{break}}}n=j+1|0;if((n|0)>=8){break}j=n;p=p+8|0;o=o+(i<<1)|0}return}}else{o=l+((ag(i,h+7|0)|0)+a<<1)|0;l=-i|0;if((f|0)==0){f=7;p=m;j=o;while(1){n=f+h|0;if((n|0)>-1&(n|0)<(k|0)){n=0;g=p;while(1){q=(d[g]|0)>>>4;do{if(q<<24>>24!=0){r=n+a|0;if(!((r|0)>-1&(r|0)<(i|0))){break}b[j+(n<<1)>>1]=(q&255|e)&65535}}while(0);q=n+1|0;if((q|0)<8){n=q;g=g+1|0}else{break}}}if((f|0)<=0){break}f=f-1|0;p=p+8|0;j=j+(l<<1)|0}return}else{j=7;p=m;m=o;while(1){o=j+h|0;if((o|0)>-1&(o|0)<(k|0)){o=7;f=p;while(1){g=(d[f]|0)>>>4;do{if(g<<24>>24!=0){n=o+a|0;if(!((n|0)>-1&(n|0)<(i|0))){break}b[m+(o<<1)>>1]=(g&255|e)&65535}}while(0);if((o|0)>0){o=o-1|0;f=f+1|0}else{break}}}if((j|0)<=0){break}j=j-1|0;p=p+8|0;m=m+(l<<1)|0}return}}}function emc(d,e,f,g,h,i){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;j=(d>>>0)%((c[2439290]|0)>>>0)|0;if((j|0)==0){return}d=h-(c[2415132]|0)|0;h=i-(c[2415130]|0)|0;if((d|0)<-7){return}i=c[2113068]|0;if((d|0)>=(i|0)|(h|0)<-7){return}k=c[2113070]|0;if((h|0)>=(k|0)){return}l=c[2112926]|0;m=(c[2411324]|0)+(j<<6)|0;do{if((d|0)>=0){if((d|0)>(i-8|0)|(h|0)<0){break}if((h|0)>(k-8|0)){break}if((g|0)==0){j=l+((ag(i,h)|0)+d<<1)|0;if((f|0)==0){n=m;o=j;p=0;while(1){q=a[n]&15;if(q<<24>>24!=0){b[o>>1]=(q&255|e)&65535}q=a[n+1|0]&15;if(q<<24>>24!=0){b[o+2>>1]=(q&255|e)&65535}q=a[n+2|0]&15;if(q<<24>>24!=0){b[o+4>>1]=(q&255|e)&65535}q=a[n+3|0]&15;if(q<<24>>24!=0){b[o+6>>1]=(q&255|e)&65535}q=a[n+4|0]&15;if(q<<24>>24!=0){b[o+8>>1]=(q&255|e)&65535}q=a[n+5|0]&15;if(q<<24>>24!=0){b[o+10>>1]=(q&255|e)&65535}q=a[n+6|0]&15;if(q<<24>>24!=0){b[o+12>>1]=(q&255|e)&65535}q=a[n+7|0]&15;if(q<<24>>24!=0){b[o+14>>1]=(q&255|e)&65535}q=p+1|0;if((q|0)<8){n=n+8|0;o=o+(i<<1)|0;p=q}else{break}}return}else{p=m;o=j;n=0;while(1){q=a[p]&15;if(q<<24>>24!=0){b[o+14>>1]=(q&255|e)&65535}q=a[p+1|0]&15;if(q<<24>>24!=0){b[o+12>>1]=(q&255|e)&65535}q=a[p+2|0]&15;if(q<<24>>24!=0){b[o+10>>1]=(q&255|e)&65535}q=a[p+3|0]&15;if(q<<24>>24!=0){b[o+8>>1]=(q&255|e)&65535}q=a[p+4|0]&15;if(q<<24>>24!=0){b[o+6>>1]=(q&255|e)&65535}q=a[p+5|0]&15;if(q<<24>>24!=0){b[o+4>>1]=(q&255|e)&65535}q=a[p+6|0]&15;if(q<<24>>24!=0){b[o+2>>1]=(q&255|e)&65535}q=a[p+7|0]&15;if(q<<24>>24!=0){b[o>>1]=(q&255|e)&65535}q=n+1|0;if((q|0)<8){p=p+8|0;o=o+(i<<1)|0;n=q}else{break}}return}}else{n=l+((ag(i,h+7|0)|0)+d<<1)|0;o=-i|0;if((f|0)==0){p=m;j=n;q=0;while(1){r=a[p]&15;if(r<<24>>24!=0){b[j>>1]=(r&255|e)&65535}r=a[p+1|0]&15;if(r<<24>>24!=0){b[j+2>>1]=(r&255|e)&65535}r=a[p+2|0]&15;if(r<<24>>24!=0){b[j+4>>1]=(r&255|e)&65535}r=a[p+3|0]&15;if(r<<24>>24!=0){b[j+6>>1]=(r&255|e)&65535}r=a[p+4|0]&15;if(r<<24>>24!=0){b[j+8>>1]=(r&255|e)&65535}r=a[p+5|0]&15;if(r<<24>>24!=0){b[j+10>>1]=(r&255|e)&65535}r=a[p+6|0]&15;if(r<<24>>24!=0){b[j+12>>1]=(r&255|e)&65535}r=a[p+7|0]&15;if(r<<24>>24!=0){b[j+14>>1]=(r&255|e)&65535}r=q+1|0;if((r|0)<8){p=p+8|0;j=j+(o<<1)|0;q=r}else{break}}return}else{q=m;j=0;p=n;while(1){r=a[q]&15;if(r<<24>>24!=0){b[p+14>>1]=(r&255|e)&65535}r=a[q+1|0]&15;if(r<<24>>24!=0){b[p+12>>1]=(r&255|e)&65535}r=a[q+2|0]&15;if(r<<24>>24!=0){b[p+10>>1]=(r&255|e)&65535}r=a[q+3|0]&15;if(r<<24>>24!=0){b[p+8>>1]=(r&255|e)&65535}r=a[q+4|0]&15;if(r<<24>>24!=0){b[p+6>>1]=(r&255|e)&65535}r=a[q+5|0]&15;if(r<<24>>24!=0){b[p+4>>1]=(r&255|e)&65535}r=a[q+6|0]&15;if(r<<24>>24!=0){b[p+2>>1]=(r&255|e)&65535}r=a[q+7|0]&15;if(r<<24>>24!=0){b[p>>1]=(r&255|e)&65535}r=j+1|0;if((r|0)<8){q=q+8|0;j=r;p=p+(o<<1)|0}else{break}}return}}}}while(0);if((g|0)==0){g=l+((ag(i,h)|0)+d<<1)|0;if((f|0)==0){o=0;p=m;j=g;while(1){q=o+h|0;if((q|0)>-1&(q|0)<(k|0)){q=0;n=p;while(1){r=a[n]&15;do{if(r<<24>>24!=0){s=q+d|0;if(!((s|0)>-1&(s|0)<(i|0))){break}b[j+(q<<1)>>1]=(r&255|e)&65535}}while(0);r=q+1|0;if((r|0)<8){q=r;n=n+1|0}else{break}}}n=o+1|0;if((n|0)>=8){break}o=n;p=p+8|0;j=j+(i<<1)|0}return}else{j=0;p=m;o=g;while(1){g=j+h|0;if((g|0)>-1&(g|0)<(k|0)){g=7;n=p;while(1){q=a[n]&15;do{if(q<<24>>24!=0){r=g+d|0;if(!((r|0)>-1&(r|0)<(i|0))){break}b[o+(g<<1)>>1]=(q&255|e)&65535}}while(0);if((g|0)>0){g=g-1|0;n=n+1|0}else{break}}}n=j+1|0;if((n|0)>=8){break}j=n;p=p+8|0;o=o+(i<<1)|0}return}}else{o=l+((ag(i,h+7|0)|0)+d<<1)|0;l=-i|0;if((f|0)==0){f=7;p=m;j=o;while(1){n=f+h|0;if((n|0)>-1&(n|0)<(k|0)){n=0;g=p;while(1){q=a[g]&15;do{if(q<<24>>24!=0){r=n+d|0;if(!((r|0)>-1&(r|0)<(i|0))){break}b[j+(n<<1)>>1]=(q&255|e)&65535}}while(0);q=n+1|0;if((q|0)<8){n=q;g=g+1|0}else{break}}}if((f|0)<=0){break}f=f-1|0;p=p+8|0;j=j+(l<<1)|0}return}else{j=7;p=m;m=o;while(1){o=j+h|0;if((o|0)>-1&(o|0)<(k|0)){o=7;f=p;while(1){g=a[f]&15;do{if(g<<24>>24!=0){n=o+d|0;if(!((n|0)>-1&(n|0)<(i|0))){break}b[m+(o<<1)>>1]=(g&255|e)&65535}}while(0);if((o|0)>0){o=o-1|0;f=f+1|0}else{break}}}if((j|0)<=0){break}j=j-1|0;p=p+8|0;m=m+(l<<1)|0}return}}}function emd(d,e,f,g,h,i){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;j=(d>>>0)%((c[2439290]|0)>>>0)|0;if((j|0)==0){return}d=h-(c[2415132]|0)|0;h=i-(c[2415130]|0)|0;if((d|0)<-7){return}i=c[2113068]|0;if((d|0)>=(i|0)|(h|0)<-7){return}k=c[2113070]|0;if((h|0)>=(k|0)){return}l=c[2112926]|0;m=(c[2411324]|0)+(j<<6)|0;do{if((d|0)>=0){if((d|0)>(i-8|0)|(h|0)<0){break}if((h|0)>(k-8|0)){break}if((g|0)==0){j=l+((ag(i,h)|0)+d<<1)|0;if((f|0)==0){n=m;o=j;p=0;while(1){q=a[n]&7;if(q<<24>>24!=0){b[o>>1]=(q&255|e)&65535}q=a[n+1|0]&7;if(q<<24>>24!=0){b[o+2>>1]=(q&255|e)&65535}q=a[n+2|0]&7;if(q<<24>>24!=0){b[o+4>>1]=(q&255|e)&65535}q=a[n+3|0]&7;if(q<<24>>24!=0){b[o+6>>1]=(q&255|e)&65535}q=a[n+4|0]&7;if(q<<24>>24!=0){b[o+8>>1]=(q&255|e)&65535}q=a[n+5|0]&7;if(q<<24>>24!=0){b[o+10>>1]=(q&255|e)&65535}q=a[n+6|0]&7;if(q<<24>>24!=0){b[o+12>>1]=(q&255|e)&65535}q=a[n+7|0]&7;if(q<<24>>24!=0){b[o+14>>1]=(q&255|e)&65535}q=p+1|0;if((q|0)<8){n=n+8|0;o=o+(i<<1)|0;p=q}else{break}}return}else{p=m;o=j;n=0;while(1){q=a[p]&7;if(q<<24>>24!=0){b[o+14>>1]=(q&255|e)&65535}q=a[p+1|0]&7;if(q<<24>>24!=0){b[o+12>>1]=(q&255|e)&65535}q=a[p+2|0]&7;if(q<<24>>24!=0){b[o+10>>1]=(q&255|e)&65535}q=a[p+3|0]&7;if(q<<24>>24!=0){b[o+8>>1]=(q&255|e)&65535}q=a[p+4|0]&7;if(q<<24>>24!=0){b[o+6>>1]=(q&255|e)&65535}q=a[p+5|0]&7;if(q<<24>>24!=0){b[o+4>>1]=(q&255|e)&65535}q=a[p+6|0]&7;if(q<<24>>24!=0){b[o+2>>1]=(q&255|e)&65535}q=a[p+7|0]&7;if(q<<24>>24!=0){b[o>>1]=(q&255|e)&65535}q=n+1|0;if((q|0)<8){p=p+8|0;o=o+(i<<1)|0;n=q}else{break}}return}}else{n=l+((ag(i,h+7|0)|0)+d<<1)|0;o=-i|0;if((f|0)==0){p=m;j=n;q=0;while(1){r=a[p]&7;if(r<<24>>24!=0){b[j>>1]=(r&255|e)&65535}r=a[p+1|0]&7;if(r<<24>>24!=0){b[j+2>>1]=(r&255|e)&65535}r=a[p+2|0]&7;if(r<<24>>24!=0){b[j+4>>1]=(r&255|e)&65535}r=a[p+3|0]&7;if(r<<24>>24!=0){b[j+6>>1]=(r&255|e)&65535}r=a[p+4|0]&7;if(r<<24>>24!=0){b[j+8>>1]=(r&255|e)&65535}r=a[p+5|0]&7;if(r<<24>>24!=0){b[j+10>>1]=(r&255|e)&65535}r=a[p+6|0]&7;if(r<<24>>24!=0){b[j+12>>1]=(r&255|e)&65535}r=a[p+7|0]&7;if(r<<24>>24!=0){b[j+14>>1]=(r&255|e)&65535}r=q+1|0;if((r|0)<8){p=p+8|0;j=j+(o<<1)|0;q=r}else{break}}return}else{q=m;j=0;p=n;while(1){r=a[q]&7;if(r<<24>>24!=0){b[p+14>>1]=(r&255|e)&65535}r=a[q+1|0]&7;if(r<<24>>24!=0){b[p+12>>1]=(r&255|e)&65535}r=a[q+2|0]&7;if(r<<24>>24!=0){b[p+10>>1]=(r&255|e)&65535}r=a[q+3|0]&7;if(r<<24>>24!=0){b[p+8>>1]=(r&255|e)&65535}r=a[q+4|0]&7;if(r<<24>>24!=0){b[p+6>>1]=(r&255|e)&65535}r=a[q+5|0]&7;if(r<<24>>24!=0){b[p+4>>1]=(r&255|e)&65535}r=a[q+6|0]&7;if(r<<24>>24!=0){b[p+2>>1]=(r&255|e)&65535}r=a[q+7|0]&7;if(r<<24>>24!=0){b[p>>1]=(r&255|e)&65535}r=j+1|0;if((r|0)<8){q=q+8|0;j=r;p=p+(o<<1)|0}else{break}}return}}}}while(0);if((g|0)==0){g=l+((ag(i,h)|0)+d<<1)|0;if((f|0)==0){o=0;p=m;j=g;while(1){q=o+h|0;if((q|0)>-1&(q|0)<(k|0)){q=0;n=p;while(1){r=a[n]&7;do{if(r<<24>>24!=0){s=q+d|0;if(!((s|0)>-1&(s|0)<(i|0))){break}b[j+(q<<1)>>1]=(r&255|e)&65535}}while(0);r=q+1|0;if((r|0)<8){q=r;n=n+1|0}else{break}}}n=o+1|0;if((n|0)>=8){break}o=n;p=p+8|0;j=j+(i<<1)|0}return}else{j=0;p=m;o=g;while(1){g=j+h|0;if((g|0)>-1&(g|0)<(k|0)){g=7;n=p;while(1){q=a[n]&7;do{if(q<<24>>24!=0){r=g+d|0;if(!((r|0)>-1&(r|0)<(i|0))){break}b[o+(g<<1)>>1]=(q&255|e)&65535}}while(0);if((g|0)>0){g=g-1|0;n=n+1|0}else{break}}}n=j+1|0;if((n|0)>=8){break}j=n;p=p+8|0;o=o+(i<<1)|0}return}}else{o=l+((ag(i,h+7|0)|0)+d<<1)|0;l=-i|0;if((f|0)==0){f=7;p=m;j=o;while(1){n=f+h|0;if((n|0)>-1&(n|0)<(k|0)){n=0;g=p;while(1){q=a[g]&7;do{if(q<<24>>24!=0){r=n+d|0;if(!((r|0)>-1&(r|0)<(i|0))){break}b[j+(n<<1)>>1]=(q&255|e)&65535}}while(0);q=n+1|0;if((q|0)<8){n=q;g=g+1|0}else{break}}}if((f|0)<=0){break}f=f-1|0;p=p+8|0;j=j+(l<<1)|0}return}else{j=7;p=m;m=o;while(1){o=j+h|0;if((o|0)>-1&(o|0)<(k|0)){o=7;f=p;while(1){g=a[f]&7;do{if(g<<24>>24!=0){n=o+d|0;if(!((n|0)>-1&(n|0)<(i|0))){break}b[m+(o<<1)>>1]=(g&255|e)&65535}}while(0);if((o|0)>0){o=o-1|0;f=f+1|0}else{break}}}if((j|0)<=0){break}j=j-1|0;p=p+8|0;m=m+(l<<1)|0}return}}}function eme(a,e,f,g,h,i){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;j=(a>>>0)%((c[2439290]|0)>>>0)|0;if((j|0)==0){return}a=h-(c[2415132]|0)|0;h=i-(c[2415130]|0)|0;if((a|0)<-7){return}i=c[2113068]|0;if((a|0)>=(i|0)|(h|0)<-7){return}k=c[2113070]|0;if((h|0)>=(k|0)){return}l=c[2112926]|0;m=(c[2411324]|0)+(j<<6)|0;do{if((a|0)>=0){if((a|0)>(i-8|0)|(h|0)<0){break}if((h|0)>(k-8|0)){break}if((g|0)==0){j=l+((ag(i,h)|0)+a<<1)|0;if((f|0)==0){n=m;o=j;p=0;while(1){q=(d[n]|0)>>>4&3;if(q<<24>>24!=0){b[o>>1]=(q&255|e)&65535}q=(d[n+1|0]|0)>>>4&3;if(q<<24>>24!=0){b[o+2>>1]=(q&255|e)&65535}q=(d[n+2|0]|0)>>>4&3;if(q<<24>>24!=0){b[o+4>>1]=(q&255|e)&65535}q=(d[n+3|0]|0)>>>4&3;if(q<<24>>24!=0){b[o+6>>1]=(q&255|e)&65535}q=(d[n+4|0]|0)>>>4&3;if(q<<24>>24!=0){b[o+8>>1]=(q&255|e)&65535}q=(d[n+5|0]|0)>>>4&3;if(q<<24>>24!=0){b[o+10>>1]=(q&255|e)&65535}q=(d[n+6|0]|0)>>>4&3;if(q<<24>>24!=0){b[o+12>>1]=(q&255|e)&65535}q=(d[n+7|0]|0)>>>4&3;if(q<<24>>24!=0){b[o+14>>1]=(q&255|e)&65535}q=p+1|0;if((q|0)<8){n=n+8|0;o=o+(i<<1)|0;p=q}else{break}}return}else{p=m;o=j;n=0;while(1){q=(d[p]|0)>>>4&3;if(q<<24>>24!=0){b[o+14>>1]=(q&255|e)&65535}q=(d[p+1|0]|0)>>>4&3;if(q<<24>>24!=0){b[o+12>>1]=(q&255|e)&65535}q=(d[p+2|0]|0)>>>4&3;if(q<<24>>24!=0){b[o+10>>1]=(q&255|e)&65535}q=(d[p+3|0]|0)>>>4&3;if(q<<24>>24!=0){b[o+8>>1]=(q&255|e)&65535}q=(d[p+4|0]|0)>>>4&3;if(q<<24>>24!=0){b[o+6>>1]=(q&255|e)&65535}q=(d[p+5|0]|0)>>>4&3;if(q<<24>>24!=0){b[o+4>>1]=(q&255|e)&65535}q=(d[p+6|0]|0)>>>4&3;if(q<<24>>24!=0){b[o+2>>1]=(q&255|e)&65535}q=(d[p+7|0]|0)>>>4&3;if(q<<24>>24!=0){b[o>>1]=(q&255|e)&65535}q=n+1|0;if((q|0)<8){p=p+8|0;o=o+(i<<1)|0;n=q}else{break}}return}}else{n=l+((ag(i,h+7|0)|0)+a<<1)|0;o=-i|0;if((f|0)==0){p=m;j=n;q=0;while(1){r=(d[p]|0)>>>4&3;if(r<<24>>24!=0){b[j>>1]=(r&255|e)&65535}r=(d[p+1|0]|0)>>>4&3;if(r<<24>>24!=0){b[j+2>>1]=(r&255|e)&65535}r=(d[p+2|0]|0)>>>4&3;if(r<<24>>24!=0){b[j+4>>1]=(r&255|e)&65535}r=(d[p+3|0]|0)>>>4&3;if(r<<24>>24!=0){b[j+6>>1]=(r&255|e)&65535}r=(d[p+4|0]|0)>>>4&3;if(r<<24>>24!=0){b[j+8>>1]=(r&255|e)&65535}r=(d[p+5|0]|0)>>>4&3;if(r<<24>>24!=0){b[j+10>>1]=(r&255|e)&65535}r=(d[p+6|0]|0)>>>4&3;if(r<<24>>24!=0){b[j+12>>1]=(r&255|e)&65535}r=(d[p+7|0]|0)>>>4&3;if(r<<24>>24!=0){b[j+14>>1]=(r&255|e)&65535}r=q+1|0;if((r|0)<8){p=p+8|0;j=j+(o<<1)|0;q=r}else{break}}return}else{q=m;j=0;p=n;while(1){r=(d[q]|0)>>>4&3;if(r<<24>>24!=0){b[p+14>>1]=(r&255|e)&65535}r=(d[q+1|0]|0)>>>4&3;if(r<<24>>24!=0){b[p+12>>1]=(r&255|e)&65535}r=(d[q+2|0]|0)>>>4&3;if(r<<24>>24!=0){b[p+10>>1]=(r&255|e)&65535}r=(d[q+3|0]|0)>>>4&3;if(r<<24>>24!=0){b[p+8>>1]=(r&255|e)&65535}r=(d[q+4|0]|0)>>>4&3;if(r<<24>>24!=0){b[p+6>>1]=(r&255|e)&65535}r=(d[q+5|0]|0)>>>4&3;if(r<<24>>24!=0){b[p+4>>1]=(r&255|e)&65535}r=(d[q+6|0]|0)>>>4&3;if(r<<24>>24!=0){b[p+2>>1]=(r&255|e)&65535}r=(d[q+7|0]|0)>>>4&3;if(r<<24>>24!=0){b[p>>1]=(r&255|e)&65535}r=j+1|0;if((r|0)<8){q=q+8|0;j=r;p=p+(o<<1)|0}else{break}}return}}}}while(0);if((g|0)==0){g=l+((ag(i,h)|0)+a<<1)|0;if((f|0)==0){o=0;p=m;j=g;while(1){q=o+h|0;if((q|0)>-1&(q|0)<(k|0)){q=0;n=p;while(1){r=(d[n]|0)>>>4&3;do{if(r<<24>>24!=0){s=q+a|0;if(!((s|0)>-1&(s|0)<(i|0))){break}b[j+(q<<1)>>1]=(r&255|e)&65535}}while(0);r=q+1|0;if((r|0)<8){q=r;n=n+1|0}else{break}}}n=o+1|0;if((n|0)>=8){break}o=n;p=p+8|0;j=j+(i<<1)|0}return}else{j=0;p=m;o=g;while(1){g=j+h|0;if((g|0)>-1&(g|0)<(k|0)){g=7;n=p;while(1){q=(d[n]|0)>>>4&3;do{if(q<<24>>24!=0){r=g+a|0;if(!((r|0)>-1&(r|0)<(i|0))){break}b[o+(g<<1)>>1]=(q&255|e)&65535}}while(0);if((g|0)>0){g=g-1|0;n=n+1|0}else{break}}}n=j+1|0;if((n|0)>=8){break}j=n;p=p+8|0;o=o+(i<<1)|0}return}}else{o=l+((ag(i,h+7|0)|0)+a<<1)|0;l=-i|0;if((f|0)==0){f=7;p=m;j=o;while(1){n=f+h|0;if((n|0)>-1&(n|0)<(k|0)){n=0;g=p;while(1){q=(d[g]|0)>>>4&3;do{if(q<<24>>24!=0){r=n+a|0;if(!((r|0)>-1&(r|0)<(i|0))){break}b[j+(n<<1)>>1]=(q&255|e)&65535}}while(0);q=n+1|0;if((q|0)<8){n=q;g=g+1|0}else{break}}}if((f|0)<=0){break}f=f-1|0;p=p+8|0;j=j+(l<<1)|0}return}else{j=7;p=m;m=o;while(1){o=j+h|0;if((o|0)>-1&(o|0)<(k|0)){o=7;f=p;while(1){g=(d[f]|0)>>>4&3;do{if(g<<24>>24!=0){n=o+a|0;if(!((n|0)>-1&(n|0)<(i|0))){break}b[m+(o<<1)>>1]=(g&255|e)&65535}}while(0);if((o|0)>0){o=o-1|0;f=f+1|0}else{break}}}if((j|0)<=0){break}j=j-1|0;p=p+8|0;m=m+(l<<1)|0}return}}}function emf(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;if((e|0)<=0){return}g=f+1|0;h=b;i=c[2411324]|0;j=b+1|0;b=0;while(1){a[i]=(d[i]|0|(d[h]|0)>>>7<<f|(d[j]|0)>>>7<<g)&255;k=i+1|0;a[k]=(((d[h]|0)>>>6&1)<<f|(d[k]|0)|((d[j]|0)>>>6&1)<<g)&255;k=i+2|0;a[k]=(((d[h]|0)>>>5&1)<<f|(d[k]|0)|((d[j]|0)>>>5&1)<<g)&255;k=i+3|0;a[k]=(((d[h]|0)>>>4&1)<<f|(d[k]|0)|((d[j]|0)>>>4&1)<<g)&255;k=i+4|0;a[k]=(((d[h]|0)>>>3&1)<<f|(d[k]|0)|((d[j]|0)>>>3&1)<<g)&255;k=i+5|0;a[k]=(((d[h]|0)>>>2&1)<<f|(d[k]|0)|((d[j]|0)>>>2&1)<<g)&255;k=i+6|0;a[k]=(((d[h]|0)>>>1&1)<<f|(d[k]|0)|((d[j]|0)>>>1&1)<<g)&255;k=i+7|0;a[k]=(d[k]|0|(a[h]&1)<<f|(a[j]&1)<<g)&255;k=b+1|0;if((k|0)<(e|0)){h=h+2|0;i=i+8|0;j=j+2|0;b=k}else{break}}return}function emg(b,c){b=b|0;c=c|0;var d=0;b=(c|0)!=0?-41:-1;a[9553416]=b;c=a[9553408]|0;d=c&b;if(d<<24>>24==-1){a[9706117]=0;return}if(c<<24>>24!=-33){return}a[14125144]=d;a[9706117]=1;return}function emh(a){a=a|0;var b=0,d=0;b=(c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,3579545,0)|0;return a|0}function emi(b){b=b|0;var d=0;switch(b|0){case 45056:{d=~a[9625617];break};case 53261:case 53260:case 53257:case 53248:case 53249:case 53250:case 53251:case 53256:{d=-1;break};case 53252:{d=a[9553880]|0;break};case 53258:{d=(c[2432906]|0)!=0|0;break};case 53254:{d=a[9553881]|0;break};case 45057:{d=~a[9625618];break};case 45059:{d=~a[9625620];break};case 45058:{d=~a[9625619];break};default:{d=0}}return d|0}function emj(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0;switch(d|0){case 53351:case 53350:case 53349:case 53348:case 53347:case 53346:case 53345:case 53344:{a[(c[2385748]|0)+(d-53344)|0]=e;return};case 53256:{a[9553408]=-33;d=c[2439330]|0;f=(d|0)==0;if(!f){g=d;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;g=c[2438118]|0;c[2433530]=g;h=c[3528484]|0;c[2076596]=h;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;a[14125144]=a[9553416]&-33;a[9706117]=1;if(!f){f=d;gGC(f|0,9706056,76)|0}c[2438118]=g;c[3528484]=h;c[2417276]=i;c[1836236]=-1;return};case 53260:{c[2432766]=0;c[2432906]=1;return};case 53248:{a[9579168]=e;return};case 53250:{a[9579169]=e;return};default:{return}}}function emk(b){b=b|0;var d=0;if((b|0)==40964){d=a[9553880]|0}else if((b|0)==57346){d=~a[9625619]}else if((b|0)==57344){d=~a[9625617]}else if((b|0)==57347){d=~a[9625620]}else if((b|0)==57345){d=~a[9625618]}else if((b|0)==40966){d=a[9553881]|0}else if((b|0)==40973|(b|0)==40972|(b|0)==40969|(b|0)==40960|(b|0)==40961|(b|0)==40962|(b|0)==40963|(b|0)==40968){d=-1}else if((b|0)==40970){d=(c[2432906]|0)!=0|0}else{d=0}return d|0}function eml(d,e){d=d|0;e=e|0;var f=0,g=0,h=0;if((d|0)==61474){a[(c[2385748]|0)+4|0]=e;return}else if((d|0)==40960){a[9579168]=e;return}else if((d|0)==61442){a[c[2385748]|0]=e;return}else if((d|0)==61460){a[(c[2385748]|0)+3|0]=e;return}else if((d|0)==61492){a[(c[2385748]|0)+7|0]=e;return}else if((d|0)==61444){a[(c[2385748]|0)+1|0]=e;return}else if((d|0)==61458){a[(c[2385748]|0)+2|0]=e;return}else if((d|0)==40972){c[2432766]=0;c[2432906]=1;return}else if((d|0)==40962){a[9579169]=e;return}else if((d|0)==61490){a[(c[2385748]|0)+6|0]=e;return}else if((d|0)==61476){a[(c[2385748]|0)+5|0]=e;return}else if((d|0)==40968){a[9553408]=-33;d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;h=c[2417276]|0;c[3541536]=h;c[1836236]=0;a[14125144]=a[9553416]&-33;a[9706117]=1;if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=h;c[1836236]=-1;return}else{return}}function emm(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;if((d|0)==32772){a[(c[2385748]|0)+1|0]=e;return}else if((d|0)==53248){a[9579168]=e;return}else if((d|0)==53250){a[9579169]=e;return}else if((d|0)==32804){a[(c[2385748]|0)+5|0]=e;return}else if((d|0)==32820){a[(c[2385748]|0)+7|0]=e;return}else if((d|0)==32818){a[(c[2385748]|0)+6|0]=e;return}else if((d|0)==32786){a[(c[2385748]|0)+2|0]=e;return}else if((d|0)==53256){a[9553408]=-33;f=c[2439330]|0;g=(f|0)==0;if(!g){h=f;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;h=c[2438118]|0;c[2433530]=h;i=c[3528484]|0;c[2076596]=i;j=c[2417276]|0;c[3541536]=j;c[1836236]=0;a[14125144]=a[9553416]&-33;a[9706117]=1;if(!g){g=f;gGC(g|0,9706056,76)|0}c[2438118]=h;c[3528484]=i;c[2417276]=j;c[1836236]=-1;return}else if((d|0)==32802){a[(c[2385748]|0)+4|0]=e;return}else if((d|0)==32788){a[(c[2385748]|0)+3|0]=e;return}else if((d|0)==53260){c[2432766]=0;c[2432906]=1;return}else if((d|0)==32770){a[c[2385748]|0]=e;return}else{return}}function emn(b){b=b|0;var d=0;if((b|0)==16392){d=a[(c[2406864]|0)+8|0]|0}else if((b|0)==16393){d=a[(c[2406864]|0)+9|0]|0}else{d=0}return d|0}function emo(e,f){e=e|0;f=f|0;var g=0,h=0,i=0;if((e&1044480|0)!=12288){return}g=e-12288|0;h=c[2411420]|0;a[h+g|0]=f;if((g&1|0)==0){return}i=d[h+(e-12289)|0]|0;e=f&255;b[(c[2385756]|0)+(g>>>1<<1)>>1]=((i<<4|i&8)<<8&63488|(i&240|i>>>4)<<3&2016|(e<<4|e&8)>>>3&31)&65535;return}function emp(b){b=b|0;var d=0;if((b|0)==32777){d=a[(c[2406864]|0)+9|0]|0}else if((b|0)==32776){d=a[(c[2406864]|0)+8|0]|0}else{d=0}return d|0}function emq(e,f){e=e|0;f=f|0;var g=0,h=0,i=0;if((e&1044480|0)!=28672){return}g=e-28672|0;h=c[2411420]|0;a[h+g|0]=f;if((g&1|0)==0){return}i=d[h+(e-28673)|0]|0;e=f&255;b[(c[2385756]|0)+(g>>>1<<1)>>1]=((i<<4|i&8)<<8&63488|(i&240|i>>>4)<<3&2016|(e<<4|e&8)>>>3&31)&65535;return}function emr(b){b=b|0;var e=0,f=0,g=0,h=0;e=b&65535;if((e|0)==16401){f=a[9579169]|0;return f|0}else if((e|0)==16403){f=a[9625616]|0;return f|0}else if((e|0)==16392){b=c[3540984]|0;g=(d[b+5887|0]|0|128)&(d[b+5886|0]|0);if((a[b+5884|0]&2)==0){h=g&255}else{h=(a[(c[b+5828>>2]|0)+100|0]&1|g)&255}f=h|6;return f|0}else if((e|0)==16402){f=(c[2432766]|0)!=0|0;return f|0}else if((e|0)==24576){f=c[2113156]&255;return f|0}else if((e|0)==16400){f=a[9579168]|0;return f|0}else{f=0;return f|0}return 0}function ems(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;switch(b&65535|0){case 16385:{a[9553416]=-1;a[9553408]=-1;a[9706117]=0;return};case 16409:{a[9553881]=e;return};case 16387:{a[9553408]=-1;if((a[9553416]|0)!=-1){return}a[9706117]=0;return};case 16391:{b=e&255;f=b&1;if((c[3528396]|0)==(f|0)){return}c[3528396]=f;f=c[2411302]|0;g=c[9757320+(c[1836236]<<2)>>2]|0;h=b<<31>>16;i=128;j=128;while(1){c[g+76+(j<<2)>>2]=f+(h+(j<<8));k=i+1&65535;if((k&65535)>255){break}else{i=k;j=k&65535}}j=b<<31>>16;b=128;i=128;while(1){h=f+(j+(i<<8))|0;c[g+76+(i+512<<2)>>2]=h;c[g+76+(i+768<<2)>>2]=h;h=b+1&65535;if((h&65535)>255){break}else{b=h;i=h&65535}}return};case 16384:{c[2432906]=0;c[2432766]=1;return};case 16408:{a[9553880]=e;return};case 16392:{a[(c[3540984]|0)+5885|0]=e;return};case 24576:{Uv(0,e);return};case 16393:{i=c[3540984]|0;b=c[i+5876>>2]|0;if((b|0)!=0){gg[b&4095](c[i+5880>>2]|0,0)}lH(i,d[i+5885|0]|0,e&255);return};default:{return}}}function emt(b,c){b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=b;b=c;c=0;while(1){e=d;f=b;g=0;while(1){h=f+1|0;i=a[h]|0;j=a[f]|0;a[e]=(i&255)>>>7<<2|i&8|(j&255)>>>7|(j&255)>>>3<<1&2;j=a[h]|0;i=a[f]|0;a[e+1|0]=(j&255)>>>6<<2&4|(j&255)>>>2<<3&8|(i&255)>>>6&1|(i&255)>>>2<<1&2;i=a[h]|0;j=a[f]|0;a[e+2|0]=(i&255)>>>1<<3&8|j&2|(i&255)>>>5<<2&4|(j&255)>>>5&1;j=a[h]|0;h=a[f]|0;a[e+3|0]=(j&255)>>>4<<2&4|j<<3&8|(h&255)>>>4&1|h<<1&2;h=f+3|0;j=a[h]|0;i=f+2|0;k=a[i]|0;a[e+4|0]=(j&255)>>>7<<2|j&8|(k&255)>>>7|(k&255)>>>3<<1&2;k=a[h]|0;j=a[i]|0;a[e+5|0]=(k&255)>>>6<<2&4|(k&255)>>>2<<3&8|(j&255)>>>6&1|(j&255)>>>2<<1&2;j=a[h]|0;k=a[i]|0;a[e+6|0]=(j&255)>>>1<<3&8|k&2|(j&255)>>>5<<2&4|(k&255)>>>5&1;k=a[h]|0;h=a[i]|0;a[e+7|0]=(k&255)>>>4<<2&4|k<<3&8|(h&255)>>>4&1|h<<1&2;h=f+65|0;k=a[h]|0;i=f+64|0;j=a[i]|0;a[e+8|0]=(k&255)>>>7<<2|k&8|(j&255)>>>7|(j&255)>>>3<<1&2;j=a[h]|0;k=a[i]|0;a[e+9|0]=(j&255)>>>6<<2&4|(j&255)>>>2<<3&8|(k&255)>>>6&1|(k&255)>>>2<<1&2;k=a[h]|0;j=a[i]|0;a[e+10|0]=(k&255)>>>1<<3&8|j&2|(k&255)>>>5<<2&4|(j&255)>>>5&1;j=a[h]|0;h=a[i]|0;a[e+11|0]=(j&255)>>>4<<2&4|j<<3&8|(h&255)>>>4&1|h<<1&2;h=f+67|0;j=a[h]|0;i=f+66|0;k=a[i]|0;a[e+12|0]=(j&255)>>>7<<2|j&8|(k&255)>>>7|(k&255)>>>3<<1&2;k=a[h]|0;j=a[i]|0;a[e+13|0]=(k&255)>>>6<<2&4|(k&255)>>>2<<3&8|(j&255)>>>6&1|(j&255)>>>2<<1&2;j=a[h]|0;k=a[i]|0;a[e+14|0]=(j&255)>>>1<<3&8|k&2|(j&255)>>>5<<2&4|(k&255)>>>5&1;k=a[h]|0;h=a[i]|0;a[e+15|0]=(k&255)>>>4<<2&4|k<<3&8|(h&255)>>>4&1|h<<1&2;h=g+1|0;if((h|0)<16){e=e+16|0;f=f+4|0;g=h}else{break}}g=c+1|0;if((g|0)<4096){d=d+256|0;b=b+128|0;c=g}else{break}}return}function emu(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5733724+(b*112|0)>>2];c[a+104>>2]=c[5733728+(b*112|0)>>2];c[a+108>>2]=c[5733732+(b*112|0)>>2];d=0;return d|0}function emv(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=5733624+(b*112|0);e=0;return e|0}function emw(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=2401136+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function emx(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>48){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5735080+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function emy(){var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;d=i;i=i+840|0;e=d|0;f=d+112|0;g=d+120|0;j=d+232|0;k=d+240|0;l=d+352|0;m=d+360|0;n=d+472|0;o=d+480|0;p=d+592|0;q=d+600|0;r=d+712|0;s=d+720|0;t=d+832|0;u=c[c[642608+(c[2436]<<2)>>2]>>2]|0;do{if((fa(u|0,239432)|0)==0){c[2405112]=0}else{if((fa(u|0,185776)|0)==0){c[2405112]=0;break}if((fa(u|0,534512)|0)==0){c[2405112]=2;break}if((fa(u|0,119968)|0)==0){c[2405112]=0;break}if((fa(u|0,581568)|0)==0){c[2405112]=0;break}if((fa(u|0,495536)|0)==0){c[2405112]=1;break}if((fa(u|0,471064)|0)==0){c[2405112]=3;break}else{v=1;i=d;return v|0}}}while(0);c[2426696]=0;c[2406824]=0;c[2406822]=393216;c[2411302]=655360;c[2406846]=786432;c[2406844]=917504;c[2406842]=1966080;c[2406840]=3014656;c[3541206]=4063232;c[2405632]=4128768;c[2406868]=4128768;c[2406866]=4157440;c[2406864]=4182016;c[2411344]=4186112;c[2411366]=4188160;c[2418176]=4192256;c[2418182]=4194304;c[2411362]=4196352;c[2411420]=4198400;c[2385748]=4202496;c[2411606]=4202504;c[2385756]=4202504;u=0;while(1){if((u|0)>=1024){break}w=9638528+(u<<2)|0;if((c[w>>2]|0)==0){x=64016;break}else{u=u+1|0}}do{if((x|0)==64016){u=gGq(4206600)|0;c[w>>2]=u;if((u|0)==0){break}c[2426696]=u;gGz(u|0,0,4206600);c[2406824]=u;c[2406822]=u+393216;c[2411302]=u+655360;c[2406846]=u+786432;c[2406844]=u+917504;c[2406842]=u+1966080;c[2406840]=u+3014656;c[3541206]=u+4063232;y=u+4128768|0;c[2405632]=y;c[2406868]=y;c[2406866]=u+4157440;c[2406864]=u+4182016;c[2411344]=u+4186112;c[2411366]=u+4188160;c[2418176]=u+4192256;c[2418182]=u+4194304;c[2411362]=u+4196352;c[2411420]=u+4198400;c[2385748]=u+4202496;y=u+4202504|0;c[2411606]=y;c[2385756]=y;c[2414146]=u+4206600;if((R6(u,0,2)|0)!=0){v=1;i=d;return v|0}if((R6((c[2406824]|0)+1|0,1,2)|0)!=0){v=1;i=d;return v|0}if((R6((c[2406824]|0)+131072|0,2,2)|0)!=0){v=1;i=d;return v|0}if((R6((c[2406824]|0)+131073|0,3,2)|0)!=0){v=1;i=d;return v|0}if((R6(c[2406822]|0,4,2)|0)!=0){v=1;i=d;return v|0}if((R6((c[2406822]|0)+1|0,5,2)|0)!=0){v=1;i=d;return v|0}u=c[2405112]|0;if(!((u|0)==3|(u|0)==1)){u=c[2406824]|0;y=131072;while(1){z=u+y|0;A=(a[604720+(((y|0)/2|0)&15)|0]^~a[z])&255;B=A<<4;a[z]=(A<<1&4|A&49|A>>>5&2|B&64|B&128|A>>>4&8)&255;A=y+2|0;if((A|0)<393216){y=A}else{C=131073;break}}do{y=u+C|0;A=a[604736+(((C|0)/2|0)&15)|0]^~a[y];a[y]=(A&255)>>>3&4|A&-37|A<<3&32;C=C+2|0;}while((C|0)<393216);u=c[2406822]|0;A=0;while(1){y=u+A|0;B=a[604752+(((A|0)/2|0)&15)|0]^~a[y];a[y]=(B&255)>>>1&4|B&50|(B&255)>>>4&8|B<<5&-128|(B&255)>>>6&1|B<<6&64;B=A+2|0;if((B|0)<262144){A=B}else{D=1;break}}do{A=u+D|0;B=a[604768+(((D|0)/2|0)&15)|0]^~a[A];a[A]=(B&255)>>>3&2|B&-19|B<<3&16;D=D+2|0;}while((D|0)<262144)}u=c[2411302]|0;if((c[3542200]|0)==0){v=1;i=d;return v|0}B=s+108|0;c[B>>2]=0;A=s+100|0;c[A>>2]=0;y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[y&16383](s,6)|0;do{if((c[B>>2]|0)!=0){y=c[A>>2]|0;c[t>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](t,6,0)|0;if((y|0)<1){v=1;i=d;return v|0}if((gzL(u,0,6)|0)==0){break}else{v=1}i=d;return v|0}}while(0);u=c[2405112]|0;if((u|0)==3|(u|0)==0){u=c[2411302]|0;A=0;while(1){B=u+A|0;y=a[B]|0;z=A>>>9;E=z&1;F=A>>>8;G=(F&1&z|0)==0?y:y^-128;y=A>>>11;z=y&1;H=A>>>4;I=H&1;J=A>>>1;K=(J&y&I|0)==0?G:G^64;G=(z&J&((F|-2)^1)|0)==0;L=G?K:K^4;M=A>>>13;N=(A>>>6|-2)^1;O=(M&1&H&N|0)==0;H=A>>>2;P=E&H&(y^1)&255;y=(O?L:L^2)^P;L=(I&M|0)==0;if(L){Q=y}else{Q=y<<1&2|y&-4|(y&255)>>>1&1}y=(I&F|0)==0;if(y){R=Q}else{R=(Q&255)>>>2<<3&8|Q&-13|(Q&255)>>>3<<2&4}a[B]=R;B=A>>>12;F=(B&1&(M^1)|0)==0?K:K^32;K=(J&1&N|0)==0?F:F^16;F=(H&1&(B^1)|0)==0?K:K^8;K=G?F:F^4;F=(O?K:K^2)^P;if(L){S=F}else{S=F<<1&2|F&-4|(F&255)>>>1&1}if(y){T=S}else{T=(S&255)>>>2<<3&8|S&-13|(S&255)>>>3<<2&4}if((E&B|0)==0){U=T}else{U=(T&255)>>>4<<5&32|T&-49|(T&255)>>>5<<4&16}if((N&z|0)==0){V=U}else{V=(U&255)>>>7<<6|U&63|(U&255)>>>6<<7}a[u+(A+65536)|0]=V;z=A+1|0;if((z|0)<65536){A=z}else{W=0;break}}}else{W=0}while(1){if((W|0)>=1024){v=1;x=64120;break}X=9638528+(W<<2)|0;if((c[X>>2]|0)==0){break}else{W=W+1|0}}if((x|0)==64120){i=d;return v|0}A=gGq(524288)|0;c[X>>2]=A;if((A|0)==0){v=1;i=d;return v|0}gGz(A|0,0,524288);do{if((c[3542200]|0)!=0){u=q+108|0;c[u>>2]=0;z=q+100|0;c[z>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](q,7)|0;if((c[u>>2]|0)==0){break}u=c[z>>2]|0;c[r>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](r,7,0)|0;if((u|0)<1){break}gzL(A,0,7)|0}}while(0);u=A+32768|0;do{if((c[3542200]|0)!=0){z=o+108|0;c[z>>2]=0;N=o+100|0;c[N>>2]=0;B=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[B&16383](o,8)|0;if((c[z>>2]|0)==0){break}z=c[N>>2]|0;c[p>>2]=9534384;N=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[N&16383](p,8,0)|0;if((z|0)<1){break}gzL(u,0,8)|0}}while(0);u=c[2406846]|0;z=A;N=0;while(1){B=u;E=z;y=0;while(1){F=a[E]|0;L=E+32768|0;P=a[L]|0;a[B]=(F&255)>>>7<<2|F&8|(P&255)>>>7|(P&255)>>>3<<1&2;P=a[E]|0;F=a[L]|0;a[B+1|0]=(P&255)>>>6<<2&4|(P&255)>>>2<<3&8|(F&255)>>>6&1|(F&255)>>>2<<1&2;F=a[E]|0;P=a[L]|0;a[B+2|0]=(F&255)>>>1<<3&8|P&2|(F&255)>>>5<<2&4|(P&255)>>>5&1;P=a[E]|0;F=a[L]|0;a[B+3|0]=(P&255)>>>4<<2&4|P<<3&8|(F&255)>>>4&1|F<<1&2;F=E+1|0;P=a[F]|0;L=E+32769|0;K=a[L]|0;a[B+4|0]=(P&255)>>>7<<2|P&8|(K&255)>>>7|(K&255)>>>3<<1&2;K=a[F]|0;P=a[L]|0;a[B+5|0]=(K&255)>>>6<<2&4|(K&255)>>>2<<3&8|(P&255)>>>6&1|(P&255)>>>2<<1&2;P=a[F]|0;K=a[L]|0;a[B+6|0]=(P&255)>>>1<<3&8|K&2|(P&255)>>>5<<2&4|(K&255)>>>5&1;K=a[F]|0;F=a[L]|0;a[B+7|0]=(K&255)>>>4<<2&4|K<<3&8|(F&255)>>>4&1|F<<1&2;F=y+1|0;if((F|0)<8){B=B+8|0;E=E+2|0;y=F}else{break}}y=N+1|0;if((y|0)<2048){u=u+64|0;z=z+16|0;N=y}else{break}}do{if((c[3542200]|0)!=0){N=m+108|0;c[N>>2]=0;z=m+100|0;c[z>>2]=0;u=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[u&16383](m,9)|0;if((c[N>>2]|0)==0){break}N=c[z>>2]|0;c[n>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](n,9,0)|0;if((N|0)<1){break}gzL(A,0,9)|0}}while(0);emt(c[2406844]|0,A);do{if((c[3542200]|0)!=0){N=k+108|0;c[N>>2]=0;z=k+100|0;c[z>>2]=0;u=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[u&16383](k,10)|0;if((c[N>>2]|0)==0){break}N=c[z>>2]|0;c[l>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](l,10,0)|0;if((N|0)<1){break}gzL(A,0,10)|0}}while(0);emt(c[2406842]|0,A);do{if((c[3542200]|0)!=0){N=g+108|0;c[N>>2]=0;z=g+100|0;c[z>>2]=0;u=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[u&16383](g,11)|0;if((c[N>>2]|0)==0){break}N=c[z>>2]|0;c[j>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](j,11,0)|0;if((N|0)<1){break}gzL(A,0,11)|0}}while(0);emt(c[2406840]|0,A);N=0;while(1){if((N|0)>=1024){break}Y=9638528+(N<<2)|0;if((c[Y>>2]|0)==(A|0)){x=64080;break}else{N=N+1|0}}if((x|0)==64080){gGr(A);c[Y>>2]=0}N=c[3541206]|0;do{if((c[3542200]|0)!=0){z=e+108|0;c[z>>2]=0;u=e+100|0;c[u>>2]=0;y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[y&16383](e,12)|0;if((c[z>>2]|0)==0){break}z=c[u>>2]|0;c[f>>2]=9534384;u=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[u&16383](f,12,0)|0;if((z|0)<1){break}gzL(N,0,12)|0}}while(0);fyz(0,8,0);fyz(1,8,0);c[1836234]=0;N=c[2439374]|0;c[3531864]=N;gf[c[N>>2]&2047](0);N=c[2406868]|0;A=c[3531864]|0;c[A+44>>2]=N;c[A+48>>2]=N;c[A+52>>2]=N;c[A+56>>2]=N;c[A+60>>2]=N;c[A+64>>2]=N;c[A+68>>2]=N;c[A+72>>2]=N;c[A+76>>2]=N;c[A+80>>2]=N;c[A+84>>2]=N;c[A+88>>2]=N;c[A+92>>2]=N;c[A+96>>2]=N;c[A+2092>>2]=N;c[A+2096>>2]=N;c[A+2100>>2]=N;c[A+2104>>2]=N;c[A+2108>>2]=N;c[A+2112>>2]=N;c[A+2116>>2]=N;c[A+2120>>2]=N;c[A+2124>>2]=N;c[A+2128>>2]=N;c[A+2132>>2]=N;c[A+2136>>2]=N;c[A+2140>>2]=N;c[A+2144>>2]=N;N=(c[2411366]|0)-28672|0;c[A+100>>2]=N;c[A+104>>2]=N;c[A+2148>>2]=N;c[A+2152>>2]=N;c[A+2188>>2]=(c[2411362]|0)-49152;N=(c[2406824]|0)-655360|0;z=320;while(1){c[A+44+(z<<2)>>2]=N;u=z+1|0;if((u|0)<512){z=u}else{Z=320;break}}do{c[A+4140+(Z<<2)>>2]=N;c[A+6188+(Z<<2)>>2]=N;Z=Z+1|0;}while((Z|0)<512);N=c[2405112]|0;z=c[2406864]|0;do{if((N|0)==3|(N|0)==1){u=z-40960|0;c[A+124>>2]=u;c[A+128>>2]=u;c[A+2172>>2]=u;c[A+2176>>2]=u;c[A+8236>>2]=804;u=A+8240|0;if((N|0)==3){c[u>>2]=1648;break}else{c[u>>2]=3116;break}}else{u=z-32768|0;c[A+108>>2]=u;c[A+112>>2]=u;c[A+2156>>2]=u;c[A+2160>>2]=u;c[A+8236>>2]=212;c[A+8240>>2]=3178}}while(0);c[1836234]=-1;gu[c[A+4>>2]&16383]();c[1836234]=1;z=c[2439375]|0;c[3531864]=z;gf[c[z>>2]&2047](1);z=(c[2405112]|0)==3;N=c[2406866]|0;u=c[3531864]|0;c[u+44>>2]=N;c[u+48>>2]=N;c[u+52>>2]=N;c[u+56>>2]=N;if(z){c[u+60>>2]=N;c[u+64>>2]=N;c[u+68>>2]=N;c[u+72>>2]=N;c[u+76>>2]=N;c[u+80>>2]=N;c[u+84>>2]=N;c[u+88>>2]=N;c[u+2092>>2]=N;c[u+2096>>2]=N;c[u+2100>>2]=N;c[u+2104>>2]=N;c[u+2108>>2]=N;c[u+2112>>2]=N;c[u+2116>>2]=N;c[u+2120>>2]=N;c[u+2124>>2]=N;c[u+2128>>2]=N;c[u+2132>>2]=N;c[u+2136>>2]=N;z=(c[2418182]|0)-24576|0;c[u+92>>2]=z;c[u+2140>>2]=z;z=(c[2418176]|0)-26624|0;c[u+96>>2]=z;c[u+2144>>2]=z;z=(c[2411420]|0)-28672|0;c[u+100>>2]=z;c[u+104>>2]=z;z=(c[2406864]|0)-32768|0;c[u+108>>2]=z;c[u+112>>2]=z;c[u+2156>>2]=z;c[u+2160>>2]=z;c[u+8236>>2]=2388;c[u+8240>>2]=42}else{c[u+2092>>2]=N;c[u+2096>>2]=N;c[u+2100>>2]=N;c[u+2104>>2]=N;N=(c[2418182]|0)-8192|0;c[u+60>>2]=N;c[u+2108>>2]=N;N=(c[2418176]|0)-10240|0;c[u+64>>2]=N;c[u+2112>>2]=N;N=(c[2411420]|0)-12288|0;c[u+68>>2]=N;c[u+72>>2]=N;N=(c[2406864]|0)-16384|0;c[u+76>>2]=N;c[u+80>>2]=N;c[u+2124>>2]=N;c[u+2128>>2]=N;c[u+8236>>2]=728;c[u+8240>>2]=2292}N=(c[2406822]|0)-786432|0;z=384;while(1){c[u+44+(z<<2)>>2]=N;y=z+1|0;if((y|0)<512){z=y}else{_=384;break}}do{c[u+4140+(_<<2)>>2]=N;c[u+6188+(_<<2)>>2]=N;_=_+1|0;}while((_|0)<512);c[1836234]=-1;gu[c[u+4>>2]&16383]();c[3531864]=0;fwR(0);N=c[2439330]|0;z=(N|0)==0;if(!z){A=N;gGC(9706056,A|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];A=c[3528484]|0;c[2076596]=A;y=c[2417276]|0;c[3541536]=y;c[1836236]=0;E=c[2411302]|0;B=0;F=0;while(1){c[N+76+(F<<2)>>2]=E+(F<<8);K=B+1&65535;if((K&65535)>31){break}else{B=K;F=K&65535}}F=c[2405112]|0;if((F|0)==3|(F|0)==0){F=0;B=0;while(1){u=B<<8;c[N+76+(B+512<<2)>>2]=E+(u+65536);c[N+76+(B+768<<2)>>2]=E+u;u=F+1&65535;if((u&65535)>31){break}else{F=u;B=u&65535}}}else{B=0;F=0;while(1){u=E+(F<<8)|0;c[N+76+(F+512<<2)>>2]=u;c[N+76+(F+768<<2)>>2]=u;u=B+1&65535;if((u&65535)>31){break}else{B=u;F=u&65535}}}F=c[2411344]|0;c[N+204>>2]=F;B=F+256|0;c[N+208>>2]=B;E=F+512|0;c[N+212>>2]=E;u=F+768|0;c[N+216>>2]=u;K=F+1024|0;c[N+220>>2]=K;L=F+1280|0;c[N+224>>2]=L;P=F+1536|0;c[N+228>>2]=P;O=F+1792|0;c[N+232>>2]=O;c[N+1228>>2]=F;c[N+1232>>2]=B;c[N+1236>>2]=E;c[N+1240>>2]=u;c[N+1244>>2]=K;c[N+1248>>2]=L;c[N+1252>>2]=P;c[N+1256>>2]=O;c[N+2252>>2]=F;c[N+3276>>2]=F;c[N+2256>>2]=B;c[N+3280>>2]=B;c[N+2260>>2]=E;c[N+3284>>2]=E;c[N+2264>>2]=u;c[N+3288>>2]=u;c[N+2268>>2]=K;c[N+3292>>2]=K;c[N+2272>>2]=L;c[N+3296>>2]=L;c[N+2276>>2]=P;c[N+3300>>2]=P;c[N+2280>>2]=O;c[N+3304>>2]=O;c[N+4180>>2]=1580;c[N+4184>>2]=2410;if(!z){O=N;gGC(O|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=A;c[2417276]=y;c[1836236]=-1;UL(3579545,2070,3356,0);c[2438224]=3579545;c[2433522]=3416;c[2406672]=1752;c[3528468]=9362;c[2443842]=571;h[745398]=1.0;a[3203264]=1;Ux(0,8e3,1);c[2407030]=256;c[2407068]=3;emP();v=0;i=d;return v|0}}while(0);c[2426696]=0;v=1;i=d;return v|0}function emz(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;Uw(0);b=a[7452584]|0;if(b){d=0;e=b&1;while(1){b=14163936+(d<<2)|0;f=c[b>>2]|0;g=c[2113006]|0;if((g|0)==0){h=64128}else{i=g-1|0;c[2113006]=i;if((i|0)==0){h=64128}}if((h|0)==64128){h=0;c[2383474]=0}if((f|0)==0){j=e}else{gGr(f);j=a[7452584]&1}c[b>>2]=0;b=d+1|0;if((b|0)<(j|0)){d=b;e=j}else{break}}}a[7452584]=0;c[2438224]=0;c[2433522]=0;c[2406672]=0;c[3528468]=0;j=c[2406688]|0;if((j|0)!=0){gGr(j);c[2406688]=0}c[2432972]=0;fyA();fwZ();j=c[2426696]|0;e=0;while(1){if((e|0)>=1024){h=64140;break}k=9638528+(e<<2)|0;if((c[k>>2]|0)==(j|0)){break}else{e=e+1|0}}if((h|0)==64140){c[2426696]=0;return 0}gGr(j);c[k>>2]=0;c[2426696]=0;return 0}function emA(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;if((a[9623968]|0)!=0){emP()}if((a[9753320]|0)!=0){f=c[2411420]|0;g=c[2385756]|0;h=0;do{i=h<<1;j=d[f+i|0]|0;k=d[f+(i|1)|0]|0;b[g+(h<<1)>>1]=((j<<4|j&8)<<8&63488|(j&240|j>>>4)<<3&2016|(k<<4|k&8)>>>3&31)&65535;h=h+1|0;}while((h|0)<2048);a[9753320]=0}a[9625616]=0;a[9625617]=0;a[9625618]=0;h=0;g=0;f=0;k=0;do{g=((a[9551768+h|0]&1)<<h|g&255)&255;f=((a[9633136+h|0]&1)<<h|f&255)&255;k=((a[9631008+h|0]&1)<<h|k&255)&255;h=h+1|0;}while((h|0)<8);a[9625616]=g;a[9625617]=f;a[9625618]=k;c[2409128]=0;c[2409245]=0;c[2409362]=0;c[2409479]=0;c[2409508]=0;c[2409537]=0;c[2409566]=0;c[2409595]=0;k=c[2385548]|0;if((k|0)>0){gGz(9752472,0,((k|0)>1?k<<2:4)|0)}c[2433530]=0;c[1836234]=0;k=c[2439374]|0;c[3531864]=k;gf[c[k>>2]&2047](0);k=0;do{gj[c[(c[3531864]|0)+12>>2]&4095](1388)|0;c[1836234]=-1;gu[c[(c[3531864]|0)+4>>2]&16383]();c[1836234]=1;f=c[2439375]|0;c[3531864]=f;gf[c[f>>2]&2047](1);gj[c[(c[3531864]|0)+12>>2]&4095](1388)|0;c[1836234]=-1;gu[c[(c[3531864]|0)+4>>2]&16383]();k=k+1|0;c[1836234]=0;f=c[2439374]|0;c[3531864]=f;gf[c[f>>2]&2047](0)}while((k|0)<120);gG[c[(c[3531864]|0)+16>>2]&255](0,50,1);c[1836234]=-1;gu[c[(c[3531864]|0)+4>>2]&16383]();c[1836234]=1;k=c[2439375]|0;c[3531864]=k;gf[c[k>>2]&2047](1);gG[c[(c[3531864]|0)+16>>2]&255](0,50,1);c[1836234]=-1;gu[c[(c[3531864]|0)+4>>2]&16383]();c[3531864]=0;k=c[2112968]|0;if((k|0)!=0){emQ();emR(64);emS();emR(128);f=c[2385756]|0;g=c[2411362]|0;h=k;k=c[2406846]|0;j=0;i=0;l=0;while(1){m=(i|0)==32;n=(m&1)+j|0;o=m?0:i;m=o<<3;p=(n<<3)-16|0;do{if(p>>>0<=223){q=e[g+(l<<1)>>1]|0;r=q>>>6&768|q&255;if((r|0)==0){break}s=q>>>4&240;q=h+((p<<8)+m<<1)|0;t=k+(r<<6)|0;r=0;while(1){u=a[t]|0;if(u<<24>>24!=15){b[q>>1]=b[f+((s|u&255|768)<<1)>>1]|0}u=a[t+1|0]|0;if(u<<24>>24!=15){b[q+2>>1]=b[f+((s|u&255|768)<<1)>>1]|0}u=a[t+2|0]|0;if(u<<24>>24!=15){b[q+4>>1]=b[f+((s|u&255|768)<<1)>>1]|0}u=a[t+3|0]|0;if(u<<24>>24!=15){b[q+6>>1]=b[f+((s|u&255|768)<<1)>>1]|0}u=a[t+4|0]|0;if(u<<24>>24!=15){b[q+8>>1]=b[f+((s|u&255|768)<<1)>>1]|0}u=a[t+5|0]|0;if(u<<24>>24!=15){b[q+10>>1]=b[f+((s|u&255|768)<<1)>>1]|0}u=a[t+6|0]|0;if(u<<24>>24!=15){b[q+12>>1]=b[f+((s|u&255|768)<<1)>>1]|0}u=a[t+7|0]|0;if(u<<24>>24!=15){b[q+14>>1]=b[f+((s|u&255|768)<<1)>>1]|0}u=r+1|0;if((u|0)<8){q=q+512|0;t=t+8|0;r=u}else{break}}}}while(0);m=l+1|0;if((m|0)<1024){j=n;i=o+1|0;l=m}else{break}}}l=c[2439330]|0;if((l|0)!=0){i=l;gGC(9706056,i|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;i=c[2438224]|0;l=gGS(-1597636608,28447,i,(i|0)<0|0?-1:0)|0;i=l;UF(59659)|0;l=c[2443826]|0;if((l|0)<1073676288){c[2443826]=l-i}l=c[2443827]|0;if((l|0)<1073676288){c[2443827]=l-i}l=(c[3528508]|0)-i|0;c[3528508]=(l|0)<0?0:l;l=c[2112964]|0;if((l|0)!=0){gg[c[3542112]&4095](l,a[9688]|0?534:0);Uu(0,c[2112964]|0,a[9688]|0?534:0)}l=c[1836236]|0;i=c[9757320+(l<<2)>>2]|0;if((i|0)==0){v=c[2433530]|0;w=9752472+(l<<2)|0;c[w>>2]=v;x=c[2076596]|0;y=14113936+(l<<2)|0;c[y>>2]=x;z=c[3541536]|0;A=9669104+(l<<2)|0;c[A>>2]=z;c[1836236]=-1;return 0}j=i;gGC(j|0,9706056,76)|0;v=c[2433530]|0;w=9752472+(l<<2)|0;c[w>>2]=v;x=c[2076596]|0;y=14113936+(l<<2)|0;c[y>>2]=x;z=c[3541536]|0;A=9669104+(l<<2)|0;c[A>>2]=z;c[1836236]=-1;return 0}function emB(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=i;i=i+168|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;l=e+80|0;m=e+96|0;n=e+112|0;o=e+128|0;p=e+144|0;q=e+160|0;if((d|0)!=0){c[d>>2]=169585}do{if((b&32|0)!=0){gGz(p|0,0,12);r=c[2405632]|0;c[p>>2]=r;c[p+4>>2]=(c[2411606]|0)-r;c[p+12>>2]=162152;r=c[2076592]|0;gj[r&4095](p)|0;if((b&2|0)==0){break}a[9753320]=1}}while(0);if((b&64|0)==0){i=e;return 0}p=c[2385546]|0;if((p|0)>0){r=0;s=p;while(1){p=c[(c[9757496+(r<<2)>>2]|0)+32>>2]|0;if((p|0)==0){t=s}else{gg[p&4095](r,b);t=c[2385546]|0}p=r+1|0;if((p|0)<(t|0)){r=p;s=t}else{break}}}fw$(b);UQ(b,d);Ut(0);do{if((b&2|0)==0){c[q>>2]=c[3528396];gGz(n|0,0,12);c[n>>2]=q;c[n+4>>2]=4;c[n+12>>2]=437480;d=c[2076592]|0;gj[d&4095](n)|0}else{gGz(o|0,0,12);c[o>>2]=q;c[o+4>>2]=4;c[o+12>>2]=437480;d=c[2076592]|0;gj[d&4095](o)|0;d=c[q>>2]|0;t=d&1;if((c[3528396]|0)==(t|0)){break}c[3528396]=t;t=c[2411302]|0;s=c[9757320+(c[1836236]<<2)>>2]|0;r=d<<31>>16;p=128;u=128;while(1){c[s+76+(u<<2)>>2]=t+(r+(u<<8));v=p+1&65535;if((v&65535)>255){break}else{p=v;u=v&65535}}u=d<<31>>16;p=128;r=128;while(1){v=t+(u+(r<<8))|0;c[s+76+(r+512<<2)>>2]=v;c[s+76+(r+768<<2)>>2]=v;v=p+1&65535;if((v&65535)>255){break}else{p=v;r=v&65535}}}}while(0);gGz(m|0,0,12);c[m>>2]=9625616;c[m+4>>2]=8;c[m+12>>2]=215728;gj[c[2076592]&4095](m)|0;gGz(l|0,0,12);c[l>>2]=9579168;c[l+4>>2]=2;c[l+12>>2]=414344;gj[c[2076592]&4095](l)|0;gGz(k|0,0,12);c[k>>2]=9553880;c[k+4>>2]=2;c[k+12>>2]=403384;gj[c[2076592]&4095](k)|0;gGz(j|0,0,12);c[j>>2]=9731624;c[j+4>>2]=4;c[j+12>>2]=392160;gj[c[2076592]&4095](j)|0;gGz(h|0,0,12);c[h>>2]=9731064;c[h+4>>2]=4;c[h+12>>2]=380848;gj[c[2076592]&4095](h)|0;gGz(g|0,0,12);c[g>>2]=9553416;c[g+4>>2]=1;c[g+12>>2]=370680;gj[c[2076592]&4095](g)|0;gGz(f|0,0,12);c[f>>2]=9553408;c[f+4>>2]=1;c[f+12>>2]=361656;gj[c[2076592]&4095](f)|0;i=e;return 0}function emC(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4459860+(b*112|0)>>2];c[a+104>>2]=c[4459864+(b*112|0)>>2];c[a+108>>2]=c[4459868+(b*112|0)>>2];d=0;return d|0}function emD(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=4459760+(b*112|0);e=0;return e|0}function emE(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4455268+(b*112|0)>>2];c[a+104>>2]=c[4455272+(b*112|0)>>2];c[a+108>>2]=c[4455276+(b*112|0)>>2];d=0;return d|0}function emF(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=4455168+(b*112|0);e=0;return e|0}function emG(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4453812+(b*112|0)>>2];c[a+104>>2]=c[4453816+(b*112|0)>>2];c[a+108>>2]=c[4453820+(b*112|0)>>2];d=0;return d|0}function emH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=4453712+(b*112|0);e=0;return e|0}function emI(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4456724+(b*112|0)>>2];c[a+104>>2]=c[4456728+(b*112|0)>>2];c[a+108>>2]=c[4456732+(b*112|0)>>2];d=0;return d|0}function emJ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=4456624+(b*112|0);e=0;return e|0}function emK(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4458180+(b*112|0)>>2];c[a+104>>2]=c[4458184+(b*112|0)>>2];c[a+108>>2]=c[4458188+(b*112|0)>>2];d=0;return d|0}function emL(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=4458080+(b*112|0);e=0;return e|0}function emM(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;if((a[9623968]|0)!=0){emP()}if((a[9753320]|0)!=0){f=c[2411420]|0;g=c[2385756]|0;h=0;do{i=h<<1;j=d[f+i|0]|0;k=d[f+(i|1)|0]|0;b[g+(h<<1)>>1]=((j<<4|j&8)<<8&63488|(j&240|j>>>4)<<3&2016|(k<<4|k&8)>>>3&31)&65535;h=h+1|0;}while((h|0)<2048);a[9753320]=0}a[9625616]=0;a[9625617]=0;a[9625618]=0;h=0;g=0;f=0;k=0;do{g=((a[9551768+h|0]&1)<<h|g&255)&255;f=((a[9633136+h|0]&1)<<h|f&255)&255;k=((a[9631008+h|0]&1)<<h|k&255)&255;h=h+1|0;}while((h|0)<8);a[9625616]=g;a[9625617]=f;a[9625618]=k;c[2409128]=0;c[2409245]=0;c[2409362]=0;c[2409479]=0;c[2409508]=0;c[2409537]=0;c[2409566]=0;c[2409595]=0;k=c[2385548]|0;if((k|0)>0){gGz(9752472,0,((k|0)>1?k<<2:4)|0)}c[2433530]=0;c[1836234]=0;k=c[2439374]|0;c[3531864]=k;gf[c[k>>2]&2047](0);k=0;do{gj[c[(c[3531864]|0)+12>>2]&4095](833)|0;c[1836234]=-1;gu[c[(c[3531864]|0)+4>>2]&16383]();c[1836234]=1;f=c[2439375]|0;c[3531864]=f;gf[c[f>>2]&2047](1);gj[c[(c[3531864]|0)+12>>2]&4095](833)|0;c[1836234]=-1;gu[c[(c[3531864]|0)+4>>2]&16383]();c[3531864]=0;f=c[2439330]|0;if((f|0)!=0){g=f;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;UF(k*298|0)|0;g=c[1836236]|0;f=c[9757320+(g<<2)>>2]|0;if((f|0)!=0){h=f;gGC(h|0,9706056,76)|0}c[9752472+(g<<2)>>2]=c[2433530];c[14113936+(g<<2)>>2]=c[2076596];c[9669104+(g<<2)>>2]=c[3541536];c[1836236]=-1;k=k+1|0;c[1836234]=0;g=c[2439374]|0;c[3531864]=g;gf[c[g>>2]&2047](0)}while((k|0)<200);gG[c[(c[3531864]|0)+16>>2]&255](0,50,1);c[1836234]=-1;gu[c[(c[3531864]|0)+4>>2]&16383]();c[1836234]=1;k=c[2439375]|0;c[3531864]=k;gf[c[k>>2]&2047](1);gG[c[(c[3531864]|0)+16>>2]&255](0,50,1);c[1836234]=-1;gu[c[(c[3531864]|0)+4>>2]&16383]();c[3531864]=0;k=c[2112968]|0;if((k|0)!=0){emQ();emR(64);emS();emR(128);g=c[2385756]|0;h=c[2411362]|0;f=k;k=c[2406846]|0;j=0;i=0;l=0;while(1){m=(j|0)==32;n=m?0:j;o=(m&1)+i|0;m=o<<3;p=(n<<3)-16|0;do{if(p>>>0<=223){q=e[h+(l<<1)>>1]|0;r=q>>>6&768|q&255;if((r|0)==0){break}s=q>>>4&240;q=f+((p<<8)+m<<1)|0;t=k+(r<<6)|0;r=0;while(1){u=a[t]|0;if(u<<24>>24!=15){b[q>>1]=b[g+((s|u&255|768)<<1)>>1]|0}u=a[t+1|0]|0;if(u<<24>>24!=15){b[q+2>>1]=b[g+((s|u&255|768)<<1)>>1]|0}u=a[t+2|0]|0;if(u<<24>>24!=15){b[q+4>>1]=b[g+((s|u&255|768)<<1)>>1]|0}u=a[t+3|0]|0;if(u<<24>>24!=15){b[q+6>>1]=b[g+((s|u&255|768)<<1)>>1]|0}u=a[t+4|0]|0;if(u<<24>>24!=15){b[q+8>>1]=b[g+((s|u&255|768)<<1)>>1]|0}u=a[t+5|0]|0;if(u<<24>>24!=15){b[q+10>>1]=b[g+((s|u&255|768)<<1)>>1]|0}u=a[t+6|0]|0;if(u<<24>>24!=15){b[q+12>>1]=b[g+((s|u&255|768)<<1)>>1]|0}u=a[t+7|0]|0;if(u<<24>>24!=15){b[q+14>>1]=b[g+((s|u&255|768)<<1)>>1]|0}u=r+1|0;if((u|0)<8){q=q+512|0;t=t+8|0;r=u}else{break}}}}while(0);m=l+1|0;if((m|0)<1024){j=n+1|0;i=o;l=m}else{break}}}l=c[2439330]|0;if((l|0)!=0){i=l;gGC(9706056,i|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;i=c[2438224]|0;l=gGS(-1597636608,28447,i,(i|0)<0|0?-1:0)|0;i=l;UF(59659)|0;l=c[2443826]|0;if((l|0)<1073676288){c[2443826]=l-i}l=c[2443827]|0;if((l|0)<1073676288){c[2443827]=l-i}l=(c[3528508]|0)-i|0;c[3528508]=(l|0)<0?0:l;l=c[2112964]|0;if((l|0)!=0){gg[c[3542112]&4095](l,a[9688]|0?534:0);Uu(0,c[2112964]|0,a[9688]|0?534:0)}l=c[1836236]|0;i=c[9757320+(l<<2)>>2]|0;if((i|0)==0){v=c[2433530]|0;w=9752472+(l<<2)|0;c[w>>2]=v;x=c[2076596]|0;y=14113936+(l<<2)|0;c[y>>2]=x;z=c[3541536]|0;A=9669104+(l<<2)|0;c[A>>2]=z;c[1836236]=-1;return 0}j=i;gGC(j|0,9706056,76)|0;v=c[2433530]|0;w=9752472+(l<<2)|0;c[w>>2]=v;x=c[2076596]|0;y=14113936+(l<<2)|0;c[y>>2]=x;z=c[3541536]|0;A=9669104+(l<<2)|0;c[A>>2]=z;c[1836236]=-1;return 0}function emN(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2399780+(b*112|0)>>2];c[a+104>>2]=c[2399784+(b*112|0)>>2];c[a+108>>2]=c[2399788+(b*112|0)>>2];d=0;return d|0}function emO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=2399680+(b*112|0);e=0;return e|0}function emP(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0;c[1836234]=0;d=c[2439374]|0;c[3531864]=d;gf[c[d>>2]&2047](0);gD[c[(c[3531864]|0)+8>>2]&8191]()|0;c[1836234]=-1;gu[c[(c[3531864]|0)+4>>2]&16383]();c[1836234]=1;d=c[2439375]|0;c[3531864]=d;gf[c[d>>2]&2047](1);gD[c[(c[3531864]|0)+8>>2]&8191]()|0;c[1836234]=-1;gu[c[(c[3531864]|0)+4>>2]&16383]();c[3531864]=0;c[3528396]=-1;d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];f=c[3528484]|0;c[2076596]=f;g=c[2417276]|0;c[3541536]=g;c[1836236]=0;c[3528396]=0;i=c[2411302]|0;j=128;k=128;while(1){c[d+76+(k<<2)>>2]=i+(k<<8);l=j+1&65535;if((l&65535)>255){m=128;n=128;break}else{j=l;k=l&65535}}while(1){k=i+(n<<8)|0;c[d+76+(n+512<<2)>>2]=k;c[d+76+(n+768<<2)>>2]=k;k=m+1&65535;if((k&65535)>255){break}else{m=k;n=k&65535}}gGz(9706056,0,76);a[9553416]=-1;a[9553408]=-1;a[9706117]=0;if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=f;c[2417276]=g;c[1836236]=-1;c[2113156]=0;a[9628264]=0;c[2407033]=0;g=c[3541206]|0;c[3541190]=g;c[3541198]=g;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=g+256;c[3541199]=g+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=g+512;c[3541200]=g+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=g+768;c[3541201]=g+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;lw(c[3540984]|0);return}function emQ(){var a=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;a=c[2385756]|0;f=c[2385748]|0;if((c[2405112]|0)==1){g=(d[f+3|0]|0)<<8&256|(d[f+2|0]|0);h=(d[f+1|0]|0)<<8&256|(d[f]|0)}else{i=d[f+3|0]|0;j=d[f+1|0]|0;g=j>>>7|(d[f]|0)<<4&256|j<<1&254;h=i>>>7|(d[f+2|0]|0)<<4&256|i<<1&254}i=-16-g|0;g=c[2418182]|0;f=c[2112968]|0;j=c[2406844]|0;k=0;l=0;m=0;while(1){n=(k|0)==32;o=n?0:k;p=(n&1)+l|0;n=(p<<4)-h|0;q=(n|0)<-16?n+512|0:n;n=(o<<4)+i|0;r=(n|0)<-16?n+512|0:n;n=q+15|0;L85461:do{if(n>>>0<=270){if((r+15|0)>>>0>238){break}s=e[g+(m<<1)>>1]|0;t=s>>>8&240;u=f+((r<<8)+q<<1)|0;v=j+(s<<8&1048320)|0;if(!(q>>>0>240|r>>>0>208)){s=u;w=v;x=0;while(1){b[s>>1]=b[a+((d[w]|0|t)<<1)>>1]|0;b[s+2>>1]=b[a+((d[w+1|0]|0|t)<<1)>>1]|0;b[s+4>>1]=b[a+((d[w+2|0]|0|t)<<1)>>1]|0;b[s+6>>1]=b[a+((d[w+3|0]|0|t)<<1)>>1]|0;b[s+8>>1]=b[a+((d[w+4|0]|0|t)<<1)>>1]|0;b[s+10>>1]=b[a+((d[w+5|0]|0|t)<<1)>>1]|0;b[s+12>>1]=b[a+((d[w+6|0]|0|t)<<1)>>1]|0;b[s+14>>1]=b[a+((d[w+7|0]|0|t)<<1)>>1]|0;b[s+16>>1]=b[a+((d[w+8|0]|0|t)<<1)>>1]|0;b[s+18>>1]=b[a+((d[w+9|0]|0|t)<<1)>>1]|0;b[s+20>>1]=b[a+((d[w+10|0]|0|t)<<1)>>1]|0;b[s+22>>1]=b[a+((d[w+11|0]|0|t)<<1)>>1]|0;b[s+24>>1]=b[a+((d[w+12|0]|0|t)<<1)>>1]|0;b[s+26>>1]=b[a+((d[w+13|0]|0|t)<<1)>>1]|0;b[s+28>>1]=b[a+((d[w+14|0]|0|t)<<1)>>1]|0;b[s+30>>1]=b[a+((d[w+15|0]|0|t)<<1)>>1]|0;y=x+1|0;if((y|0)<16){s=s+512|0;w=w+16|0;x=y}else{break L85461}}}x=q>>>0<256;w=(q+1|0)>>>0<256;s=(q+2|0)>>>0<256;y=(q+3|0)>>>0<256;z=(q+4|0)>>>0<256;A=(q+5|0)>>>0<256;B=(q+6|0)>>>0<256;C=(q+7|0)>>>0<256;D=(q+8|0)>>>0<256;E=(q+9|0)>>>0<256;F=(q+10|0)>>>0<256;G=(q+11|0)>>>0<256;H=(q+12|0)>>>0<256;I=(q+13|0)>>>0<256;J=(q+14|0)>>>0<256;K=n>>>0<256;L=u;M=v;N=0;while(1){do{if((N+r|0)>>>0<224){if(x){b[L>>1]=b[a+((d[M]|0|t)<<1)>>1]|0}if(w){b[L+2>>1]=b[a+((d[M+1|0]|0|t)<<1)>>1]|0}if(s){b[L+4>>1]=b[a+((d[M+2|0]|0|t)<<1)>>1]|0}if(y){b[L+6>>1]=b[a+((d[M+3|0]|0|t)<<1)>>1]|0}if(z){b[L+8>>1]=b[a+((d[M+4|0]|0|t)<<1)>>1]|0}if(A){b[L+10>>1]=b[a+((d[M+5|0]|0|t)<<1)>>1]|0}if(B){b[L+12>>1]=b[a+((d[M+6|0]|0|t)<<1)>>1]|0}if(C){b[L+14>>1]=b[a+((d[M+7|0]|0|t)<<1)>>1]|0}if(D){b[L+16>>1]=b[a+((d[M+8|0]|0|t)<<1)>>1]|0}if(E){b[L+18>>1]=b[a+((d[M+9|0]|0|t)<<1)>>1]|0}if(F){b[L+20>>1]=b[a+((d[M+10|0]|0|t)<<1)>>1]|0}if(G){b[L+22>>1]=b[a+((d[M+11|0]|0|t)<<1)>>1]|0}if(H){b[L+24>>1]=b[a+((d[M+12|0]|0|t)<<1)>>1]|0}if(I){b[L+26>>1]=b[a+((d[M+13|0]|0|t)<<1)>>1]|0}if(J){b[L+28>>1]=b[a+((d[M+14|0]|0|t)<<1)>>1]|0}if(!K){break}b[L+30>>1]=b[a+((d[M+15|0]|0|t)<<1)>>1]|0}}while(0);O=N+1|0;if((O|0)<16){L=L+512|0;M=M+16|0;N=O}else{break}}}}while(0);r=m+1|0;if((r|0)<1024){k=o+1|0;l=p;m=r}else{break}}return}function emR(e){e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;f=c[2385756]|0;g=c[2411366]|0;h=c[2406840]|0;i=c[2112968]|0;j=g+4088|0;do{L85524:do{if((a[j+7|0]|0)==15){k=d[j+5|0]|0;if((k&e|0)==0){break}l=d[j+1|0]|0;m=l&32;n=d[j]|0;o=n-16|0;p=d[j+4|0]|0;q=(k&1|0)==0;k=q?p:p|-256;p=l<<4&240;r=k+15|0;if(r>>>0>270){break}if((n-1|0)>>>0>238){break}n=h+((d[j+3|0]<<8&3840|d[j+2|0])<<8)|0;s=k+(o<<8)|0;t=i+(s<<1)|0;u=(l&64|0)==0;if(!(k>>>0>240|o>>>0>208)){if(u){if((m|0)==0){l=n;v=t;w=0;while(1){x=a[l]|0;if(x<<24>>24!=15){b[v>>1]=b[f+((p|x&255|512)<<1)>>1]|0}x=a[l+1|0]|0;if(x<<24>>24!=15){b[v+2>>1]=b[f+((p|x&255|512)<<1)>>1]|0}x=a[l+2|0]|0;if(x<<24>>24!=15){b[v+4>>1]=b[f+((p|x&255|512)<<1)>>1]|0}x=a[l+3|0]|0;if(x<<24>>24!=15){b[v+6>>1]=b[f+((p|x&255|512)<<1)>>1]|0}x=a[l+4|0]|0;if(x<<24>>24!=15){b[v+8>>1]=b[f+((p|x&255|512)<<1)>>1]|0}x=a[l+5|0]|0;if(x<<24>>24!=15){b[v+10>>1]=b[f+((p|x&255|512)<<1)>>1]|0}x=a[l+6|0]|0;if(x<<24>>24!=15){b[v+12>>1]=b[f+((p|x&255|512)<<1)>>1]|0}x=a[l+7|0]|0;if(x<<24>>24!=15){b[v+14>>1]=b[f+((p|x&255|512)<<1)>>1]|0}x=a[l+8|0]|0;if(x<<24>>24!=15){b[v+16>>1]=b[f+((p|x&255|512)<<1)>>1]|0}x=a[l+9|0]|0;if(x<<24>>24!=15){b[v+18>>1]=b[f+((p|x&255|512)<<1)>>1]|0}x=a[l+10|0]|0;if(x<<24>>24!=15){b[v+20>>1]=b[f+((p|x&255|512)<<1)>>1]|0}x=a[l+11|0]|0;if(x<<24>>24!=15){b[v+22>>1]=b[f+((p|x&255|512)<<1)>>1]|0}x=a[l+12|0]|0;if(x<<24>>24!=15){b[v+24>>1]=b[f+((p|x&255|512)<<1)>>1]|0}x=a[l+13|0]|0;if(x<<24>>24!=15){b[v+26>>1]=b[f+((p|x&255|512)<<1)>>1]|0}x=a[l+14|0]|0;if(x<<24>>24!=15){b[v+28>>1]=b[f+((p|x&255|512)<<1)>>1]|0}x=a[l+15|0]|0;if(x<<24>>24!=15){b[v+30>>1]=b[f+((p|x&255|512)<<1)>>1]|0}x=w+1|0;if((x|0)<16){l=l+16|0;v=v+512|0;w=x}else{break L85524}}}else{w=n;v=t;l=0;while(1){x=a[w+15|0]|0;if(x<<24>>24!=15){b[v>>1]=b[f+((p|x&255|512)<<1)>>1]|0}x=a[w+14|0]|0;if(x<<24>>24!=15){b[v+2>>1]=b[f+((p|x&255|512)<<1)>>1]|0}x=a[w+13|0]|0;if(x<<24>>24!=15){b[v+4>>1]=b[f+((p|x&255|512)<<1)>>1]|0}x=a[w+12|0]|0;if(x<<24>>24!=15){b[v+6>>1]=b[f+((p|x&255|512)<<1)>>1]|0}x=a[w+11|0]|0;if(x<<24>>24!=15){b[v+8>>1]=b[f+((p|x&255|512)<<1)>>1]|0}x=a[w+10|0]|0;if(x<<24>>24!=15){b[v+10>>1]=b[f+((p|x&255|512)<<1)>>1]|0}x=a[w+9|0]|0;if(x<<24>>24!=15){b[v+12>>1]=b[f+((p|x&255|512)<<1)>>1]|0}x=a[w+8|0]|0;if(x<<24>>24!=15){b[v+14>>1]=b[f+((p|x&255|512)<<1)>>1]|0}x=a[w+7|0]|0;if(x<<24>>24!=15){b[v+16>>1]=b[f+((p|x&255|512)<<1)>>1]|0}x=a[w+6|0]|0;if(x<<24>>24!=15){b[v+18>>1]=b[f+((p|x&255|512)<<1)>>1]|0}x=a[w+5|0]|0;if(x<<24>>24!=15){b[v+20>>1]=b[f+((p|x&255|512)<<1)>>1]|0}x=a[w+4|0]|0;if(x<<24>>24!=15){b[v+22>>1]=b[f+((p|x&255|512)<<1)>>1]|0}x=a[w+3|0]|0;if(x<<24>>24!=15){b[v+24>>1]=b[f+((p|x&255|512)<<1)>>1]|0}x=a[w+2|0]|0;if(x<<24>>24!=15){b[v+26>>1]=b[f+((p|x&255|512)<<1)>>1]|0}x=a[w+1|0]|0;if(x<<24>>24!=15){b[v+28>>1]=b[f+((p|x&255|512)<<1)>>1]|0}x=a[w]|0;if(x<<24>>24!=15){b[v+30>>1]=b[f+((p|x&255|512)<<1)>>1]|0}x=l+1|0;if((x|0)<16){w=w+16|0;v=v+512|0;l=x}else{break L85524}}}}else{l=i+(s+3840<<1)|0;if((m|0)==0){v=n;w=l;x=15;while(1){y=a[v]|0;if(y<<24>>24!=15){b[w>>1]=b[f+((p|y&255|512)<<1)>>1]|0}y=a[v+1|0]|0;if(y<<24>>24!=15){b[w+2>>1]=b[f+((p|y&255|512)<<1)>>1]|0}y=a[v+2|0]|0;if(y<<24>>24!=15){b[w+4>>1]=b[f+((p|y&255|512)<<1)>>1]|0}y=a[v+3|0]|0;if(y<<24>>24!=15){b[w+6>>1]=b[f+((p|y&255|512)<<1)>>1]|0}y=a[v+4|0]|0;if(y<<24>>24!=15){b[w+8>>1]=b[f+((p|y&255|512)<<1)>>1]|0}y=a[v+5|0]|0;if(y<<24>>24!=15){b[w+10>>1]=b[f+((p|y&255|512)<<1)>>1]|0}y=a[v+6|0]|0;if(y<<24>>24!=15){b[w+12>>1]=b[f+((p|y&255|512)<<1)>>1]|0}y=a[v+7|0]|0;if(y<<24>>24!=15){b[w+14>>1]=b[f+((p|y&255|512)<<1)>>1]|0}y=a[v+8|0]|0;if(y<<24>>24!=15){b[w+16>>1]=b[f+((p|y&255|512)<<1)>>1]|0}y=a[v+9|0]|0;if(y<<24>>24!=15){b[w+18>>1]=b[f+((p|y&255|512)<<1)>>1]|0}y=a[v+10|0]|0;if(y<<24>>24!=15){b[w+20>>1]=b[f+((p|y&255|512)<<1)>>1]|0}y=a[v+11|0]|0;if(y<<24>>24!=15){b[w+22>>1]=b[f+((p|y&255|512)<<1)>>1]|0}y=a[v+12|0]|0;if(y<<24>>24!=15){b[w+24>>1]=b[f+((p|y&255|512)<<1)>>1]|0}y=a[v+13|0]|0;if(y<<24>>24!=15){b[w+26>>1]=b[f+((p|y&255|512)<<1)>>1]|0}y=a[v+14|0]|0;if(y<<24>>24!=15){b[w+28>>1]=b[f+((p|y&255|512)<<1)>>1]|0}y=a[v+15|0]|0;if(y<<24>>24!=15){b[w+30>>1]=b[f+((p|y&255|512)<<1)>>1]|0}if((x|0)>0){v=v+16|0;w=w-512|0;x=x-1|0}else{break L85524}}}else{x=n;w=l;v=15;while(1){y=a[x+15|0]|0;if(y<<24>>24!=15){b[w>>1]=b[f+((p|y&255|512)<<1)>>1]|0}y=a[x+14|0]|0;if(y<<24>>24!=15){b[w+2>>1]=b[f+((p|y&255|512)<<1)>>1]|0}y=a[x+13|0]|0;if(y<<24>>24!=15){b[w+4>>1]=b[f+((p|y&255|512)<<1)>>1]|0}y=a[x+12|0]|0;if(y<<24>>24!=15){b[w+6>>1]=b[f+((p|y&255|512)<<1)>>1]|0}y=a[x+11|0]|0;if(y<<24>>24!=15){b[w+8>>1]=b[f+((p|y&255|512)<<1)>>1]|0}y=a[x+10|0]|0;if(y<<24>>24!=15){b[w+10>>1]=b[f+((p|y&255|512)<<1)>>1]|0}y=a[x+9|0]|0;if(y<<24>>24!=15){b[w+12>>1]=b[f+((p|y&255|512)<<1)>>1]|0}y=a[x+8|0]|0;if(y<<24>>24!=15){b[w+14>>1]=b[f+((p|y&255|512)<<1)>>1]|0}y=a[x+7|0]|0;if(y<<24>>24!=15){b[w+16>>1]=b[f+((p|y&255|512)<<1)>>1]|0}y=a[x+6|0]|0;if(y<<24>>24!=15){b[w+18>>1]=b[f+((p|y&255|512)<<1)>>1]|0}y=a[x+5|0]|0;if(y<<24>>24!=15){b[w+20>>1]=b[f+((p|y&255|512)<<1)>>1]|0}y=a[x+4|0]|0;if(y<<24>>24!=15){b[w+22>>1]=b[f+((p|y&255|512)<<1)>>1]|0}y=a[x+3|0]|0;if(y<<24>>24!=15){b[w+24>>1]=b[f+((p|y&255|512)<<1)>>1]|0}y=a[x+2|0]|0;if(y<<24>>24!=15){b[w+26>>1]=b[f+((p|y&255|512)<<1)>>1]|0}y=a[x+1|0]|0;if(y<<24>>24!=15){b[w+28>>1]=b[f+((p|y&255|512)<<1)>>1]|0}y=a[x]|0;if(y<<24>>24!=15){b[w+30>>1]=b[f+((p|y&255|512)<<1)>>1]|0}if((v|0)>0){x=x+16|0;w=w-512|0;v=v-1|0}else{break L85524}}}}}if(u){v=(k+1|0)>>>0>255;w=(k+2|0)>>>0>255;x=(k+3|0)>>>0>255;l=(k+4|0)>>>0>255;y=(k+5|0)>>>0>255;z=(k+6|0)>>>0>255;A=(k+7|0)>>>0>255;B=(k+8|0)>>>0>255;C=(k+9|0)>>>0>255;D=(k+10|0)>>>0>255;E=(k+11|0)>>>0>255;F=(k+12|0)>>>0>255;G=(k+13|0)>>>0>255;H=(k+14|0)>>>0>255;I=r>>>0>255;if((m|0)==0){J=n;K=t;L=0;while(1){do{if((L+o|0)>>>0<224){M=a[J]|0;if(M<<24>>24!=15&q){b[K>>1]=b[f+((p|M&255|512)<<1)>>1]|0}M=a[J+1|0]|0;if(!(M<<24>>24==15|v)){b[K+2>>1]=b[f+((p|M&255|512)<<1)>>1]|0}M=a[J+2|0]|0;if(!(M<<24>>24==15|w)){b[K+4>>1]=b[f+((p|M&255|512)<<1)>>1]|0}M=a[J+3|0]|0;if(!(M<<24>>24==15|x)){b[K+6>>1]=b[f+((p|M&255|512)<<1)>>1]|0}M=a[J+4|0]|0;if(!(M<<24>>24==15|l)){b[K+8>>1]=b[f+((p|M&255|512)<<1)>>1]|0}M=a[J+5|0]|0;if(!(M<<24>>24==15|y)){b[K+10>>1]=b[f+((p|M&255|512)<<1)>>1]|0}M=a[J+6|0]|0;if(!(M<<24>>24==15|z)){b[K+12>>1]=b[f+((p|M&255|512)<<1)>>1]|0}M=a[J+7|0]|0;if(!(M<<24>>24==15|A)){b[K+14>>1]=b[f+((p|M&255|512)<<1)>>1]|0}M=a[J+8|0]|0;if(!(M<<24>>24==15|B)){b[K+16>>1]=b[f+((p|M&255|512)<<1)>>1]|0}M=a[J+9|0]|0;if(!(M<<24>>24==15|C)){b[K+18>>1]=b[f+((p|M&255|512)<<1)>>1]|0}M=a[J+10|0]|0;if(!(M<<24>>24==15|D)){b[K+20>>1]=b[f+((p|M&255|512)<<1)>>1]|0}M=a[J+11|0]|0;if(!(M<<24>>24==15|E)){b[K+22>>1]=b[f+((p|M&255|512)<<1)>>1]|0}M=a[J+12|0]|0;if(!(M<<24>>24==15|F)){b[K+24>>1]=b[f+((p|M&255|512)<<1)>>1]|0}M=a[J+13|0]|0;if(!(M<<24>>24==15|G)){b[K+26>>1]=b[f+((p|M&255|512)<<1)>>1]|0}M=a[J+14|0]|0;if(!(M<<24>>24==15|H)){b[K+28>>1]=b[f+((p|M&255|512)<<1)>>1]|0}M=a[J+15|0]|0;if(M<<24>>24==15|I){break}b[K+30>>1]=b[f+((p|M&255|512)<<1)>>1]|0}}while(0);M=L+1|0;if((M|0)<16){J=J+16|0;K=K+512|0;L=M}else{break}}}else{L=n;K=t;J=0;while(1){do{if((J+o|0)>>>0<224){u=a[L+15|0]|0;if(u<<24>>24!=15&q){b[K>>1]=b[f+((p|u&255|512)<<1)>>1]|0}u=a[L+14|0]|0;if(!(u<<24>>24==15|v)){b[K+2>>1]=b[f+((p|u&255|512)<<1)>>1]|0}u=a[L+13|0]|0;if(!(u<<24>>24==15|w)){b[K+4>>1]=b[f+((p|u&255|512)<<1)>>1]|0}u=a[L+12|0]|0;if(!(u<<24>>24==15|x)){b[K+6>>1]=b[f+((p|u&255|512)<<1)>>1]|0}u=a[L+11|0]|0;if(!(u<<24>>24==15|l)){b[K+8>>1]=b[f+((p|u&255|512)<<1)>>1]|0}u=a[L+10|0]|0;if(!(u<<24>>24==15|y)){b[K+10>>1]=b[f+((p|u&255|512)<<1)>>1]|0}u=a[L+9|0]|0;if(!(u<<24>>24==15|z)){b[K+12>>1]=b[f+((p|u&255|512)<<1)>>1]|0}u=a[L+8|0]|0;if(!(u<<24>>24==15|A)){b[K+14>>1]=b[f+((p|u&255|512)<<1)>>1]|0}u=a[L+7|0]|0;if(!(u<<24>>24==15|B)){b[K+16>>1]=b[f+((p|u&255|512)<<1)>>1]|0}u=a[L+6|0]|0;if(!(u<<24>>24==15|C)){b[K+18>>1]=b[f+((p|u&255|512)<<1)>>1]|0}u=a[L+5|0]|0;if(!(u<<24>>24==15|D)){b[K+20>>1]=b[f+((p|u&255|512)<<1)>>1]|0}u=a[L+4|0]|0;if(!(u<<24>>24==15|E)){b[K+22>>1]=b[f+((p|u&255|512)<<1)>>1]|0}u=a[L+3|0]|0;if(!(u<<24>>24==15|F)){b[K+24>>1]=b[f+((p|u&255|512)<<1)>>1]|0}u=a[L+2|0]|0;if(!(u<<24>>24==15|G)){b[K+26>>1]=b[f+((p|u&255|512)<<1)>>1]|0}u=a[L+1|0]|0;if(!(u<<24>>24==15|H)){b[K+28>>1]=b[f+((p|u&255|512)<<1)>>1]|0}u=a[L]|0;if(u<<24>>24==15|I){break}b[K+30>>1]=b[f+((p|u&255|512)<<1)>>1]|0}}while(0);u=J+1|0;if((u|0)<16){L=L+16|0;K=K+512|0;J=u}else{break}}}}else{J=i+(s+3840<<1)|0;K=(k+1|0)>>>0>255;L=(k+2|0)>>>0>255;I=(k+3|0)>>>0>255;H=(k+4|0)>>>0>255;G=(k+5|0)>>>0>255;F=(k+6|0)>>>0>255;E=(k+7|0)>>>0>255;D=(k+8|0)>>>0>255;C=(k+9|0)>>>0>255;B=(k+10|0)>>>0>255;A=(k+11|0)>>>0>255;z=(k+12|0)>>>0>255;y=(k+13|0)>>>0>255;l=(k+14|0)>>>0>255;x=r>>>0>255;if((m|0)==0){w=n;v=J;t=15;while(1){do{if((t+o|0)>>>0<224){u=a[w]|0;if(u<<24>>24!=15&q){b[v>>1]=b[f+((p|u&255|512)<<1)>>1]|0}u=a[w+1|0]|0;if(!(u<<24>>24==15|K)){b[v+2>>1]=b[f+((p|u&255|512)<<1)>>1]|0}u=a[w+2|0]|0;if(!(u<<24>>24==15|L)){b[v+4>>1]=b[f+((p|u&255|512)<<1)>>1]|0}u=a[w+3|0]|0;if(!(u<<24>>24==15|I)){b[v+6>>1]=b[f+((p|u&255|512)<<1)>>1]|0}u=a[w+4|0]|0;if(!(u<<24>>24==15|H)){b[v+8>>1]=b[f+((p|u&255|512)<<1)>>1]|0}u=a[w+5|0]|0;if(!(u<<24>>24==15|G)){b[v+10>>1]=b[f+((p|u&255|512)<<1)>>1]|0}u=a[w+6|0]|0;if(!(u<<24>>24==15|F)){b[v+12>>1]=b[f+((p|u&255|512)<<1)>>1]|0}u=a[w+7|0]|0;if(!(u<<24>>24==15|E)){b[v+14>>1]=b[f+((p|u&255|512)<<1)>>1]|0}u=a[w+8|0]|0;if(!(u<<24>>24==15|D)){b[v+16>>1]=b[f+((p|u&255|512)<<1)>>1]|0}u=a[w+9|0]|0;if(!(u<<24>>24==15|C)){b[v+18>>1]=b[f+((p|u&255|512)<<1)>>1]|0}u=a[w+10|0]|0;if(!(u<<24>>24==15|B)){b[v+20>>1]=b[f+((p|u&255|512)<<1)>>1]|0}u=a[w+11|0]|0;if(!(u<<24>>24==15|A)){b[v+22>>1]=b[f+((p|u&255|512)<<1)>>1]|0}u=a[w+12|0]|0;if(!(u<<24>>24==15|z)){b[v+24>>1]=b[f+((p|u&255|512)<<1)>>1]|0}u=a[w+13|0]|0;if(!(u<<24>>24==15|y)){b[v+26>>1]=b[f+((p|u&255|512)<<1)>>1]|0}u=a[w+14|0]|0;if(!(u<<24>>24==15|l)){b[v+28>>1]=b[f+((p|u&255|512)<<1)>>1]|0}u=a[w+15|0]|0;if(u<<24>>24==15|x){break}b[v+30>>1]=b[f+((p|u&255|512)<<1)>>1]|0}}while(0);if((t|0)>0){w=w+16|0;v=v-512|0;t=t-1|0}else{break}}}else{t=n;v=J;w=15;while(1){do{if((w+o|0)>>>0<224){m=a[t+15|0]|0;if(m<<24>>24!=15&q){b[v>>1]=b[f+((p|m&255|512)<<1)>>1]|0}m=a[t+14|0]|0;if(!(m<<24>>24==15|K)){b[v+2>>1]=b[f+((p|m&255|512)<<1)>>1]|0}m=a[t+13|0]|0;if(!(m<<24>>24==15|L)){b[v+4>>1]=b[f+((p|m&255|512)<<1)>>1]|0}m=a[t+12|0]|0;if(!(m<<24>>24==15|I)){b[v+6>>1]=b[f+((p|m&255|512)<<1)>>1]|0}m=a[t+11|0]|0;if(!(m<<24>>24==15|H)){b[v+8>>1]=b[f+((p|m&255|512)<<1)>>1]|0}m=a[t+10|0]|0;if(!(m<<24>>24==15|G)){b[v+10>>1]=b[f+((p|m&255|512)<<1)>>1]|0}m=a[t+9|0]|0;if(!(m<<24>>24==15|F)){b[v+12>>1]=b[f+((p|m&255|512)<<1)>>1]|0}m=a[t+8|0]|0;if(!(m<<24>>24==15|E)){b[v+14>>1]=b[f+((p|m&255|512)<<1)>>1]|0}m=a[t+7|0]|0;if(!(m<<24>>24==15|D)){b[v+16>>1]=b[f+((p|m&255|512)<<1)>>1]|0}m=a[t+6|0]|0;if(!(m<<24>>24==15|C)){b[v+18>>1]=b[f+((p|m&255|512)<<1)>>1]|0}m=a[t+5|0]|0;if(!(m<<24>>24==15|B)){b[v+20>>1]=b[f+((p|m&255|512)<<1)>>1]|0}m=a[t+4|0]|0;if(!(m<<24>>24==15|A)){b[v+22>>1]=b[f+((p|m&255|512)<<1)>>1]|0}m=a[t+3|0]|0;if(!(m<<24>>24==15|z)){b[v+24>>1]=b[f+((p|m&255|512)<<1)>>1]|0}m=a[t+2|0]|0;if(!(m<<24>>24==15|y)){b[v+26>>1]=b[f+((p|m&255|512)<<1)>>1]|0}m=a[t+1|0]|0;if(!(m<<24>>24==15|l)){b[v+28>>1]=b[f+((p|m&255|512)<<1)>>1]|0}m=a[t]|0;if(m<<24>>24==15|x){break}b[v+30>>1]=b[f+((p|m&255|512)<<1)>>1]|0}}while(0);if((w|0)>0){t=t+16|0;v=v-512|0;w=w-1|0}else{break}}}}}}while(0);j=j-8|0;}while(j>>>0>=g>>>0);return}function emS(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;f=c[2385756]|0;g=c[2385748]|0;if((c[2405112]|0)==1){h=(d[g+7|0]|0)<<8&256|(d[g+6|0]|0);i=(d[g+5|0]|0)<<8&256|(d[g+4|0]|0)}else{j=d[g+7|0]|0;k=d[g+5|0]|0;h=k>>>7|(d[g+4|0]|0)<<4&256|k<<1&254;i=j>>>7|(d[g+6|0]|0)<<4&256|j<<1&254}j=-16-h|0;h=c[2418176]|0;g=c[2112968]|0;k=c[2406842]|0;l=0;m=0;n=0;while(1){o=(l|0)==32;p=o?0:l;q=(o&1)+m|0;o=(q<<4)-i|0;r=(o|0)<-16?o+512|0:o;o=(p<<4)+j|0;s=(o|0)<-16?o+512|0:o;o=r+15|0;L85955:do{if(o>>>0<=270){if((s+15|0)>>>0>238){break}t=e[h+(n<<1)>>1]|0;u=t&4095;if((u|0)==0){break}v=t>>>8&240;t=g+((s<<8)+r<<1)|0;w=k+(u<<8)|0;if(!(r>>>0>240|s>>>0>208)){u=t;x=w;y=0;while(1){z=a[x]|0;if(z<<24>>24!=15){b[u>>1]=b[f+((v|z&255|256)<<1)>>1]|0}z=a[x+1|0]|0;if(z<<24>>24!=15){b[u+2>>1]=b[f+((v|z&255|256)<<1)>>1]|0}z=a[x+2|0]|0;if(z<<24>>24!=15){b[u+4>>1]=b[f+((v|z&255|256)<<1)>>1]|0}z=a[x+3|0]|0;if(z<<24>>24!=15){b[u+6>>1]=b[f+((v|z&255|256)<<1)>>1]|0}z=a[x+4|0]|0;if(z<<24>>24!=15){b[u+8>>1]=b[f+((v|z&255|256)<<1)>>1]|0}z=a[x+5|0]|0;if(z<<24>>24!=15){b[u+10>>1]=b[f+((v|z&255|256)<<1)>>1]|0}z=a[x+6|0]|0;if(z<<24>>24!=15){b[u+12>>1]=b[f+((v|z&255|256)<<1)>>1]|0}z=a[x+7|0]|0;if(z<<24>>24!=15){b[u+14>>1]=b[f+((v|z&255|256)<<1)>>1]|0}z=a[x+8|0]|0;if(z<<24>>24!=15){b[u+16>>1]=b[f+((v|z&255|256)<<1)>>1]|0}z=a[x+9|0]|0;if(z<<24>>24!=15){b[u+18>>1]=b[f+((v|z&255|256)<<1)>>1]|0}z=a[x+10|0]|0;if(z<<24>>24!=15){b[u+20>>1]=b[f+((v|z&255|256)<<1)>>1]|0}z=a[x+11|0]|0;if(z<<24>>24!=15){b[u+22>>1]=b[f+((v|z&255|256)<<1)>>1]|0}z=a[x+12|0]|0;if(z<<24>>24!=15){b[u+24>>1]=b[f+((v|z&255|256)<<1)>>1]|0}z=a[x+13|0]|0;if(z<<24>>24!=15){b[u+26>>1]=b[f+((v|z&255|256)<<1)>>1]|0}z=a[x+14|0]|0;if(z<<24>>24!=15){b[u+28>>1]=b[f+((v|z&255|256)<<1)>>1]|0}z=a[x+15|0]|0;if(z<<24>>24!=15){b[u+30>>1]=b[f+((v|z&255|256)<<1)>>1]|0}z=y+1|0;if((z|0)<16){u=u+512|0;x=x+16|0;y=z}else{break L85955}}}y=(r|0)>-1;x=(r|0)<256;u=(r+1|0)>>>0>255;z=(r+2|0)>>>0>255;A=(r+3|0)>>>0>255;B=(r+4|0)>>>0>255;C=(r+5|0)>>>0>255;D=(r+6|0)>>>0>255;E=(r+7|0)>>>0>255;F=(r+8|0)>>>0>255;G=(r+9|0)>>>0>255;H=(r+10|0)>>>0>255;I=(r+11|0)>>>0>255;J=(r+12|0)>>>0>255;K=(r+13|0)>>>0>255;L=(r+14|0)>>>0>255;M=o>>>0>255;N=t;O=w;P=0;while(1){do{if((P+s|0)>>>0<224){Q=a[O]|0;if(Q<<24>>24!=15&y&x){b[N>>1]=b[f+((v|Q&255|256)<<1)>>1]|0}Q=a[O+1|0]|0;if(!(Q<<24>>24==15|u)){b[N+2>>1]=b[f+((v|Q&255|256)<<1)>>1]|0}Q=a[O+2|0]|0;if(!(Q<<24>>24==15|z)){b[N+4>>1]=b[f+((v|Q&255|256)<<1)>>1]|0}Q=a[O+3|0]|0;if(!(Q<<24>>24==15|A)){b[N+6>>1]=b[f+((v|Q&255|256)<<1)>>1]|0}Q=a[O+4|0]|0;if(!(Q<<24>>24==15|B)){b[N+8>>1]=b[f+((v|Q&255|256)<<1)>>1]|0}Q=a[O+5|0]|0;if(!(Q<<24>>24==15|C)){b[N+10>>1]=b[f+((v|Q&255|256)<<1)>>1]|0}Q=a[O+6|0]|0;if(!(Q<<24>>24==15|D)){b[N+12>>1]=b[f+((v|Q&255|256)<<1)>>1]|0}Q=a[O+7|0]|0;if(!(Q<<24>>24==15|E)){b[N+14>>1]=b[f+((v|Q&255|256)<<1)>>1]|0}Q=a[O+8|0]|0;if(!(Q<<24>>24==15|F)){b[N+16>>1]=b[f+((v|Q&255|256)<<1)>>1]|0}Q=a[O+9|0]|0;if(!(Q<<24>>24==15|G)){b[N+18>>1]=b[f+((v|Q&255|256)<<1)>>1]|0}Q=a[O+10|0]|0;if(!(Q<<24>>24==15|H)){b[N+20>>1]=b[f+((v|Q&255|256)<<1)>>1]|0}Q=a[O+11|0]|0;if(!(Q<<24>>24==15|I)){b[N+22>>1]=b[f+((v|Q&255|256)<<1)>>1]|0}Q=a[O+12|0]|0;if(!(Q<<24>>24==15|J)){b[N+24>>1]=b[f+((v|Q&255|256)<<1)>>1]|0}Q=a[O+13|0]|0;if(!(Q<<24>>24==15|K)){b[N+26>>1]=b[f+((v|Q&255|256)<<1)>>1]|0}Q=a[O+14|0]|0;if(!(Q<<24>>24==15|L)){b[N+28>>1]=b[f+((v|Q&255|256)<<1)>>1]|0}Q=a[O+15|0]|0;if(Q<<24>>24==15|M){break}b[N+30>>1]=b[f+((v|Q&255|256)<<1)>>1]|0}}while(0);Q=P+1|0;if((Q|0)<16){N=N+512|0;O=O+16|0;P=Q}else{break}}}}while(0);s=n+1|0;if((s|0)<1024){l=p+1|0;m=q;n=s}else{break}}return}function emT(b,d){b=b|0;d=d|0;var e=0;if((b&-65536|0)!=983040){return}e=b&65534;b=c[2388254]|0;a[b+e|0]=d;a[b+(e|1)|0]=d;return}function emU(d,e){d=d|0;e=e|0;if((d&-65536|0)==983040){b[(c[2388254]|0)+(d&65534)>>1]=e;return}if((d|0)!=524318){return}a[c[3528248]|0]=e&255;return}function emV(d){d=d|0;var f=0,g=0,h=0,i=0;L86079:do{switch(d|0){case 524291:{f=b[4774892]&255;break};case 524288:{f=(e[4774976]|0)>>>8&255;break};case 524289:{f=b[4774976]&255;break};case 524290:{g=c[2388254]|0;h=c[2276056]|0;if((h|0)==2254){f=b[g+36964>>1]&255|96;break L86079}else if((h|0)==25844){f=b[g+37110>>1]&255;break L86079}else if((h|0)==818){f=b[g+37110>>1]&255;break L86079}else if((h|0)==2218){f=b[g+36964>>1]&255|32;break L86079}else{g=c[3528410]|0;h=g+1|0;c[3528410]=h;i=a[602656+g|0]|0;if((h|0)<=14){f=i;break L86079}c[3528410]=0;f=i;break L86079}break};case 524292:{f=a[9634961]|0;break};case 524293:{f=a[9634960]|0;break};case 524302:case 524303:{f=a[c[2443718]|0]|0;break};case 524802:{f=(e[4774848]|0)>>>8&255;break};case 524803:{f=b[4774848]&255;break};default:{f=0}}}while(0);return f|0}function emW(a){a=a|0;var e=0;switch(a|0){case 524802:{e=b[4774848]|0;break};case 524302:{e=d[c[2443718]|0]|0;break};case 524290:{e=b[4774892]|0;break};case 524292:{e=(d[9634960]|0)<<8|(d[9634961]|0);break};case 524288:{e=b[4774976]|0;break};default:{e=0}}return e|0}function emX(b,d){b=b|0;d=d|0;if((b-524318|0)>>>0>=2){return}a[c[3528248]|0]=d;return}function emY(b,d){b=b|0;d=d|0;if((b|0)!=524318){return}a[c[3528248]|0]=d&255;return}function emZ(d){d=d|0;var f=0;switch(d|0){case 524288:{f=(e[4774976]|0)>>>8&255;break};case 524318:case 524319:{f=a[c[2443718]|0]|0;break};case 524293:{f=a[9634961]|0;break};case 524292:{f=a[9634960]|0;break};case 524289:{f=b[4774976]&255;break};case 524290:{f=(e[4774892]|0)>>>8&255;break};case 524291:{f=b[4774892]&255;break};default:{f=0}}return f|0}function em_(a){a=a|0;var e=0;if((a|0)==524288){e=b[4774976]|0}else if((a|0)==524318){e=d[c[2443718]|0]|0}else if((a|0)==524292){e=(d[9634960]|0)<<8|(d[9634961]|0)}else if((a|0)==524290){e=b[4774892]|0}else{e=0}return e|0}function em$(b,d){b=b|0;d=d|0;if((b|0)==786463|(b|0)==786462){a[c[3528248]|0]=d;a[9706117]=1;return}else if((b|0)==786456|(b|0)==786457){if(d<<24>>24==-1){return}a[c[2388456]|0]=d;return}else{return}}function em0(b,d){b=b|0;d=d|0;if((b|0)==786456){if((d&255)==255){return}a[c[2388456]|0]=d&255;return}else if((b|0)==786462){a[c[3528248]|0]=d&255;a[9706117]=1;return}else{return}}function em1(c){c=c|0;var d=0;switch(c|0){case 786432:{d=(e[4774976]|0)>>>8&255;break};case 786437:{d=b[4774892]&255;break};case 786433:{d=b[4774976]&255;break};case 786436:{d=(e[4774892]|0)>>>8&255;break};case 786438:{d=a[9634960]|0;break};case 786439:{d=a[9634961]|0;break};default:{d=0}}return d|0}function em2(a){a=a|0;var c=0;if((a|0)==786436){c=b[4774892]|0}else if((a|0)==786438){c=(d[9634960]|0)<<8|(d[9634961]|0)}else if((a|0)==786432){c=b[4774976]|0}else{c=0}return c|0}function em3(d){d=d|0;var f=0;switch(d|0){case 1048584:case 1048585:{f=a[9634960]|0;break};case 1048577:{f=b[4774976]&255;break};case 1048590:case 1048591:{f=a[c[2443718]|0]|0;break};case 1048576:{f=(e[4774976]|0)>>>8&255;break};case 1048579:{f=b[4774892]&255;break};case 1048578:{f=(e[4774892]|0)>>>8&255;break};case 1048586:case 1048587:{f=a[9634961]|0;break};default:{f=0}}return f|0}function em4(a){a=a|0;var e=0;switch(a|0){case 1048576:{e=b[4774976]|0;break};case 1048586:{a=d[9634961]|0;e=(a<<8|a)&65535;break};case 1048590:{e=d[c[2443718]|0]|0;break};case 1048578:{e=b[4774892]|0;break};case 1048584:{a=d[9634960]|0;e=(a<<8|a)&65535;break};default:{e=0}}return e|0}function em5(a,b){a=a|0;b=b|0;return}function em6(b,d){b=b|0;d=d|0;if((b|0)==1048600){if((d&255)==255){return}a[c[2388456]|0]=d&255;return}else if((b|0)==1048606){a[c[3528248]|0]=d&255;return}else if((b|0)==1048598){if(d<<16>>16==0&(c[2429282]|0)!=0){gGz(9706056,0,76)}c[2429282]=d&65535;return}else{return}}function em7(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0;if(d>>>0>1048575){f=d&1048575;g=c[2112932]|0;h=c[g+((f>>>10|16384)<<2)>>2]|0;if(h>>>0>9){i=d&1023;a[h+i|0]=e&255;a[h+(i+1)|0]=(e&65535)>>>8&255;return}else{gg[c[g+196728+(h<<2)>>2]&4095](f,e);return}}f=d&-65536;if((f|0)==983040){b[(c[2388254]|0)+(d&65534)>>1]=e;return}else if((f|0)==786432){b[(c[2388254]|0)+(d&65534)>>1]=e;return}else{if((d|0)!=524318){return}a[c[3528248]|0]=e&255;a[9706117]=1;return}}function em8(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;if(b>>>0>1048575){e=b&1048575;f=c[2112932]|0;g=c[f+((e>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(b&1023^1)|0]=d;return}else{gg[c[f+196648+(g<<2)>>2]&4095](e,d);return}}e=b&-65536;if((e|0)==786432){g=b&65534;f=c[2388254]|0;a[f+g|0]=d;a[f+(g|1)|0]=d;return}else if((e|0)==983040){e=b&65534;g=c[2388254]|0;a[g+e|0]=d;a[g+(e|1)|0]=d;return}else{if((b-524318|0)>>>0>=2){return}a[c[3528248]|0]=d;a[9706117]=1;return}}function em9(d){d=d|0;var f=0,g=0,h=0,i=0;L86240:do{if(d>>>0>1048575){f=d&1048575;g=c[2112932]|0;h=c[g+(f>>>10<<2)>>2]|0;if(h>>>0>9){i=a[h+(d&1023^1)|0]|0;break}else{i=gj[c[g+196608+(h<<2)>>2]&4095](f)|0;break}}else{switch(d|0){case 524289:{i=b[4774976]&255;break L86240;break};case 524291:{i=b[4774892]&255;break L86240;break};case 524306:case 524307:{i=1;break L86240;break};case 524288:{i=(e[4774976]|0)>>>8&255;break L86240;break};case 524290:{i=(e[4774892]|0)>>>8&255;break L86240;break};case 524293:{i=a[9634961]|0;break L86240;break};case 524292:{i=a[9634960]|0;break L86240;break};default:{i=0;break L86240}}}}while(0);return i|0}function ena(a){a=a|0;var e=0,f=0,g=0,h=0,i=0;if(a>>>0>1048575){e=a&1048575;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=a&1023;i=(d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0);return i|0}else{i=gj[c[f+196688+(g<<2)>>2]&4095](e)|0;return i|0}}if((a|0)==524288){i=b[4774976]|0;return i|0}else if((a|0)==524306){i=256;return i|0}else if((a|0)==524292){i=(d[9634960]|0)<<8|(d[9634961]|0);return i|0}else if((a|0)==524290){i=b[4774892]|0;return i|0}else{i=0;return i|0}return 0}function enb(b,d){b=b|0;d=d|0;if((b-606208|0)>>>0>1|d<<24>>24==-1){return}a[c[2388456]|0]=d;return}function enc(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;if((b|0)==540704|(b|0)==540706|(b|0)==540708|(b|0)==540710|(b|0)==540712|(b|0)==540714|(b|0)==540716|(b|0)==540718){e=b>>>1;f=d&255;g=b>>>3&1;h=e&3;i=c[9638392+(g<<2)>>2]|0;j=((d&255)<<16|0)%((c[9541248+(g<<2)>>2]|0)-262144|0)|0;k=9771520+(e&7)|0;if((a[k]|0)==f<<24>>24){return}e=a[632360]<<31>>31&255&1<<g;a[k]=f;f=(e|0)!=0;if(f&(h|0)==0){e=i+1024|0;k=i+(j+263168)|0;gGC(e|0,k|0,64512)|0}else{k=i+(h<<16)|0;e=i+(j+262144)|0;gGC(k|0,e|0,65536)|0}if(!f){return}f=h<<8;h=i+f|0;e=i+(j+(f|262144))|0;gGC(h|0,e|0,256)|0;return}else if((b|0)==540688){Uv(1,d&255);return}else if((b|0)==540672){Uv(0,d&255);return}else if((b|0)==606208){if((d&255)==255){return}a[c[2388456]|0]=d&255;return}else{return}}function end(d){d=d|0;var f=0;if((d|0)==524289){f=b[4774976]&255}else if((d|0)==524298|(d|0)==524299){f=a[9634961]|0}else if((d|0)==540672|(d|0)==540673){f=c[2113156]&255}else if((d|0)==524290){f=(e[4774892]|0)>>>8&255}else if((d|0)==524291){f=b[4774892]&255}else if((d|0)==540688|(d|0)==540689){f=c[2113157]&255}else if((d|0)==524296|(d|0)==524297){f=a[9634960]|0}else if((d|0)==524288){f=(e[4774976]|0)>>>8&255}else{f=0}return f|0}function ene(a){a=a|0;var e=0;if((a|0)==524296){e=d[9634960]|0|-256}else if((a|0)==524288){e=b[4774976]|0}else if((a|0)==540672){e=c[2113156]&65535}else if((a|0)==524290){e=b[4774892]|0}else if((a|0)==524298){e=d[9634961]|0|-256}else if((a|0)==540688){e=c[2113157]&65535}else{e=0}return e|0}function enf(d,e){d=d|0;e=e|0;if((d&-65536|0)==983040){b[(c[2388254]|0)+(d&65534)>>1]=e;return}if(!((d|0)==786462|(d|0)==524318)){return}a[9579184]=e&255;a[9579185]=0;c[2384374]=223;a[14125144]=c[2384378]&255&-33;a[9706117]=1;return}function eng(b,d){b=b|0;d=d|0;var e=0,f=0;if((b&-65536|0)==983040){e=b&65534;f=c[2388254]|0;a[f+e|0]=d;a[f+(e|1)|0]=d;return}if(!((b|0)==786463|(b|0)==786462|(b|0)==524319|(b|0)==524318)){return}a[9579184]=d;a[9579185]=0;c[2384374]=223;a[14125144]=c[2384378]&255&-33;a[9706117]=1;return}function enh(a){a=a|0;var c=0;if((a|0)==786442){c=d[9634961]|0|-256}else if((a|0)==524292|(a|0)==786440){c=(d[9634960]|0)<<8|(d[9634961]|0)}else if((a|0)==524290|(a|0)==786434){c=b[4774892]|0}else if((a|0)==524288|(a|0)==786432){c=b[4774976]|0}else{c=0}return c|0}function eni(c){c=c|0;var d=0;if((c|0)==786442|(c|0)==786443){d=a[9634961]|0}else if((c|0)==524288|(c|0)==786432){d=(e[4774976]|0)>>>8&255}else if((c|0)==524293|(c|0)==786441){d=a[9634960]|0}else if((c|0)==524290|(c|0)==786434){d=(e[4774892]|0)>>>8&255}else if((c|0)==524289|(c|0)==786433){d=b[4774976]&255}else if((c|0)==524291|(c|0)==786435){d=b[4774892]&255}else if((c|0)==524292|(c|0)==786440){d=a[9634961]|0}else{d=0}return d|0}function enj(b){b=b|0;var c=0;switch(b|0){case 524288:case 524289:{c=(e[4774976]|0)>>>((b<<3&8^8)>>>0)&255;break};case 524290:case 524291:{c=(e[4774892]|0)>>>((b<<3&8^8)>>>0)&255;break};case 524302:case 524303:{c=a[9771925]|0;break};case 524292:case 524293:{c=a[9634960+(b&1)|0]|0;break};default:{c=0}}return c|0}function enk(a){a=a|0;var c=0;if((a|0)==524302){c=d[9771925]|0}else if((a|0)==524292){c=(d[9634960]|0)<<8|(d[9634961]|0)}else if((a|0)==524290){c=b[4774892]|0}else if((a|0)==524288){c=b[4774976]|0}else{c=0}return c|0}function enl(d,e){d=d|0;e=e|0;if((d&-65536|0)==983040){b[(c[2388254]|0)+(d&65534)>>1]=e;return}if((d|0)!=524318){return}a[9771924]=e&255;return}function enm(b,d){b=b|0;d=d|0;var e=0;if((b&-65536|0)!=983040){return}e=b&65534;b=c[2388254]|0;a[b+e|0]=d;a[b+(e|1)|0]=d;return}function enn(b){b=b|0;var c=0;switch(b|0){case 786442:case 786443:{c=a[9634961]|0;break};case 786432:case 786433:{c=(e[4774976]|0)>>>((b<<3&8^8)>>>0)&255;break};case 786434:case 786435:{c=(e[4774892]|0)>>>((b<<3&8^8)>>>0)&255;break};case 786440:case 786441:{c=a[9634960]|0;break};default:{c=0}}return c|0}function eno(a){a=a|0;var c=0;switch(a|0){case 786432:{c=b[4774976]|0;break};case 786440:{c=d[9634960]|0;break};case 786442:{c=d[9634961]|0;break};case 786446:{c=d[9771925]|0;break};case 786434:{c=b[4774892]|0;break};default:{c=0}}return c|0}function enp(b,d){b=b|0;d=d|0;if((b|0)==786456|(b|0)==786457){if((d&255)==255){return}a[c[2388456]|0]=d&255;return}else if((b|0)==786463|(b|0)==786462){a[9771924]=d&255;return}else{return}}function enq(b,d){b=b|0;d=d|0;if((b|0)==786456|(b|0)==786457){if(d<<24>>24==-1){return}a[c[2388456]|0]=d;return}else if((b|0)==786463|(b|0)==786462){a[9771924]=d;return}else{return}}function enr(b){b=b|0;var c=0;switch(b|0){case 786432:case 786433:{c=(e[4774976]|0)>>>((b<<3&8^8)>>>0)&255;break};case 786434:case 786435:{c=(e[4774892]|0)>>>((b<<3&8^8)>>>0)&255;break};case 786440:case 786441:{c=a[9634960]|0;break};case 786442:case 786443:{c=a[9634961]|0;break};default:{c=0}}return c|0}function ens(a){a=a|0;var c=0;switch(a|0){case 786442:{c=d[9634961]|0;break};case 786446:{c=d[9771925]|0;break};case 786434:{c=b[4774892]|0;break};case 786432:{c=b[4774976]|0;break};case 786440:{c=d[9634960]|0;break};default:{c=0}}return c|0}function ent(d,e){d=d|0;e=e|0;if((d&-65536|0)==720896){b[(c[2388254]|0)+(d&65534)>>1]=e;enu(d>>>1&32767);return}if((d|0)==786462){a[9771924]=e&255;return}else if((d|0)==786456){if((e&255)==255){return}a[c[2388456]|0]=e&255;return}else{return}}function enu(a){a=a|0;var d=0,e=0;d=c[2388254]|0;switch(a|0){case 29447:{if((b[d+58894>>1]|0)!=1660){return}b[d+57352>>1]=12;b[d+57354>>1]=8;return};case 29687:{a=d+59374|0;e=b[a>>1]|0;if((e<<16>>16|0)==(-32722|0)){b[a>>1]=-1;b[d+59360>>1]=20217;b[d+59362>>1]=0;b[d+59364>>1]=-14684;return}else if((e<<16>>16|0)==(-32747|0)){b[a>>1]=-1;b[d+59360>>1]=20217;b[d+59362>>1]=0;b[d+59364>>1]=-24236;return}else{return}break};case 29583:{a=d+59166|0;e=b[a>>1]|0;if((e<<16>>16|0)==(-32712|0)){b[a>>1]=-1;b[d+59152>>1]=20217;b[d+59154>>1]=0;b[d+59156>>1]=-22006;return}else if((e<<16>>16|0)==(-32719|0)){b[a>>1]=-1;b[d+59152>>1]=20217;b[d+59154>>1]=0;b[d+59156>>1]=-29060;return}else{return}break};case 29695:{a=d+59390|0;e=b[a>>1]|0;if((e<<16>>16|0)==(-32730|0)){b[a>>1]=-1;b[d+59376>>1]=20217;b[d+59378>>1]=0;b[d+59380>>1]=-23174;return}else if((e<<16>>16|0)==(-32746|0)){b[a>>1]=-1;b[d+59376>>1]=20217;b[d+59378>>1]=0;b[d+59380>>1]=-23174;return}else{return}break};case 29575:{a=d+59150|0;e=b[a>>1]|0;if((e<<16>>16|0)==(-32768|0)){b[a>>1]=-1;b[d+59136>>1]=20217;b[d+59138>>1]=0;b[d+59140>>1]=-10984;return}else if((e<<16>>16|0)==(-32761|0)){b[a>>1]=-1;b[d+59136>>1]=20217;b[d+59138>>1]=0;b[d+59140>>1]=-25054;return}else{return}break};case 29623:{a=d+59246|0;e=b[a>>1]|0;if((e<<16>>16|0)==(-32739|0)){b[a>>1]=-1;b[d+59232>>1]=20217;b[d+59234>>1]=0;b[d+59236>>1]=-20570;return}else if((e<<16>>16|0)==(-32730|0)){b[a>>1]=-1;b[d+59232>>1]=20217;b[d+59234>>1]=0;b[d+59236>>1]=-23174;return}else{return}break};case 29578:{if((b[d+59156>>1]|0)!=6539){return}b[d+57356>>1]=12;b[d+57358>>1]=10;return};case 29639:{a=d+59278|0;e=b[a>>1]|0;if((e<<16>>16|0)==(-32764|0)){b[a>>1]=-1;b[d+59264>>1]=20217;b[d+59266>>1]=0;b[d+59268>>1]=-22006;return}else if((e<<16>>16|0)==(-32760|0)){b[a>>1]=-1;b[d+59264>>1]=20217;b[d+59266>>1]=0;b[d+59268>>1]=-22006;return}else{return}break};case 29647:{a=d+59294|0;e=b[a>>1]|0;if((e<<16>>16|0)==(-32720|0)){b[a>>1]=-1;b[d+59280>>1]=20217;b[d+59282>>1]=0;b[d+59284>>1]=-10984;return}else if((e<<16>>16|0)==(-32711|0)){b[a>>1]=-1;b[d+59280>>1]=20217;b[d+59282>>1]=0;b[d+59284>>1]=-21432;return}else{return}break};case 29607:{a=d+59214|0;e=b[a>>1]|0;if((e<<16>>16|0)==(-32757|0)){b[a>>1]=-1;b[d+59200>>1]=20217;b[d+59202>>1]=0;b[d+59204>>1]=-17998;return}else if((e<<16>>16|0)==(-32764|0)){b[a>>1]=-1;b[d+59200>>1]=20217;b[d+59202>>1]=0;b[d+59204>>1]=-24478;return}else{return}break};case 28834:{if((b[d+57668>>1]|0)!=-2739){return}b[d+57348>>1]=12;b[d+57350>>1]=2;return};case 29679:{a=d+59358|0;e=b[a>>1]|0;if((e<<16>>16|0)==(-32716|0)){b[a>>1]=-1;b[d+59344>>1]=20217;b[d+59346>>1]=0;b[d+59348>>1]=-24478;return}else if((e<<16>>16|0)==(-32707|0)){b[a>>1]=-1;b[d+59344>>1]=20217;b[d+59346>>1]=0;b[d+59348>>1]=-20570;return}else{return}break};case 28723:{if((b[d+57446>>1]|0)!=-7618){return}b[d+57344>>1]=12;b[d+57346>>1]=0;return};case 29591:{a=d+59182|0;e=b[a>>1]|0;if((e<<16>>16|0)==(-32743|0)){b[a>>1]=-1;b[d+59168>>1]=20217;b[d+59170>>1]=0;b[d+59172>>1]=-21432;return}else if((e<<16>>16|0)==(-32734|0)){b[a>>1]=-1;b[d+59168>>1]=20217;b[d+59170>>1]=0;b[d+59172>>1]=-10920;return}else{return}break};case 29671:{a=d+59342|0;e=b[a>>1]|0;if((e<<16>>16|0)==(-32765|0)){b[a>>1]=-1;b[d+59328>>1]=20217;b[d+59330>>1]=0;b[d+59332>>1]=-26918;return}else if((e<<16>>16|0)==(-32756|0)){b[a>>1]=-1;b[d+59328>>1]=20217;b[d+59330>>1]=0;b[d+59332>>1]=-17588;return}else{return}break};case 30592:{a=d+61184|0;if((b[a>>1]|0)!=24830){return}b[a>>1]=0;b[d+61186>>1]=0;b[d+61188>>1]=20217;b[d+61190>>1]=0;b[d+61192>>1]=-27916;return};case 29631:{a=d+59262|0;e=b[a>>1]|0;if((e<<16>>16|0)==(-32722|0)){b[a>>1]=-1;b[d+59248>>1]=20217;b[d+59250>>1]=0;b[d+59252>>1]=-14684;return}else if((e<<16>>16|0)==(-32745|0)){b[a>>1]=-1;b[d+59248>>1]=20217;b[d+59250>>1]=0;b[d+59252>>1]=-25054;return}else{return}break};case 29663:{a=d+59326|0;e=b[a>>1]|0;if((e<<16>>16|0)==(-32734|0)){b[a>>1]=-1;b[d+59312>>1]=20217;b[d+59314>>1]=0;b[d+59316>>1]=-10920;return}else if((e<<16>>16|0)==(-32741|0)){b[a>>1]=-1;b[d+59312>>1]=20217;b[d+59314>>1]=0;b[d+59316>>1]=-17998;return}else{return}break};case 29599:{a=d+59198|0;e=b[a>>1]|0;if((e<<16>>16|0)==(-32726|0)){b[a>>1]=-1;b[d+59184>>1]=20217;b[d+59186>>1]=0;b[d+59188>>1]=-20208;return}else if((e<<16>>16|0)==(-32749|0)){b[a>>1]=-1;b[d+59184>>1]=20217;b[d+59186>>1]=0;b[d+59188>>1]=-26918;return}else{return}break};case 29615:{a=d+59230|0;e=b[a>>1]|0;if((e<<16>>16|0)==(-32708|0)){b[a>>1]=-1;b[d+59216>>1]=20217;b[d+59218>>1]=0;b[d+59220>>1]=-17588;return}else if((e<<16>>16|0)==(-32715|0)){b[a>>1]=-1;b[d+59216>>1]=20217;b[d+59218>>1]=0;b[d+59220>>1]=-24236;return}else{return}break};case 29655:{a=d+59310|0;e=b[a>>1]|0;if((e<<16>>16|0)==(-32751|0)){b[a>>1]=-1;b[d+59296>>1]=20217;b[d+59298>>1]=0;b[d+59300>>1]=-29060;return}else if((e<<16>>16|0)==(-32726|0)){b[a>>1]=-1;b[d+59296>>1]=20217;b[d+59298>>1]=0;b[d+59300>>1]=-20208;return}else{return}break};default:{return}}}function enw(b,d){b=b|0;d=d|0;if((b&-65536|0)==720896){a[(c[2388254]|0)+(b&65535^1)|0]=d;enu(b>>>1&32767);return}if((b|0)==786463|(b|0)==786462){a[9771924]=d;return}else if((b|0)==786456|(b|0)==786457){if(d<<24>>24==-1){return}a[c[2388456]|0]=d;return}else{return}}function enx(b){b=b|0;var c=0;switch(b|0){case 524296:case 524297:{c=a[9634960]|0;break};case 524302:case 524303:{c=a[9771925]|0;break};case 524298:case 524299:{c=a[9634961]|0;break};case 524288:case 524289:{c=(e[4774976]|0)>>>((b<<3&8^8)>>>0)&255;break};case 524290:case 524291:{c=(e[4774892]|0)>>>((b<<3&8^8)>>>0)&255;break};default:{c=0}}return c|0}function eny(a){a=a|0;var c=0;switch(a|0){case 524296:{a=d[9634960]|0;c=(a<<8|a)&65535;break};case 524288:{c=b[4774976]|0;break};case 524290:{c=b[4774892]|0;break};case 524302:{c=d[9771925]|0;break};case 524298:{a=d[9634961]|0;c=(a<<8|a)&65535;break};default:{c=0}}return c|0}function enz(d,e){d=d|0;e=e|0;if((d&-65536|0)==983040){b[(c[2388254]|0)+(d&65534)>>1]=e;return}if((d|0)==524312){if((e&255)==255){return}a[c[2388456]|0]=e&255;return}else if((d|0)==524318){a[9771924]=e&255;return}else if((d|0)==540672){if((e&255)==255){return}a[c[2388456]|0]=e&255;return}else{return}}function enA(b,d){b=b|0;d=d|0;var e=0,f=0;if((b&-65536|0)==983040){e=b&65534;f=c[2388254]|0;a[f+e|0]=d;a[f+(e|1)|0]=d;return}if((b|0)==540673|(b|0)==540672){if(d<<24>>24==-1){return}a[c[2388456]|0]=d;return}else if((b|0)==524318|(b|0)==524319){a[9771924]=d;return}else if((b|0)==524312|(b|0)==524313){if(d<<24>>24==-1){return}a[c[2388456]|0]=d;return}else{return}}function enB(d,e){d=d|0;e=e|0;switch(d|0){case 524312:{if((e&255)==255){return}a[c[2388456]|0]=e&255;return};case 524316:{b[c[2443470]>>1]=e;return};case 524314:{b[(c[2443470]|0)+2>>1]=e;return};case 524306:{b[(c[2443470]|0)+4>>1]=e;return};case 524304:{b[(c[2443470]|0)+6>>1]=e;return};default:{return}}}function enC(b,d){b=b|0;d=d|0;if((b|0)==524313|(b|0)==524312){if(d<<24>>24==-1){return}a[c[2388456]|0]=d;return}else if((b|0)==524314){a[(c[2443470]|0)+3|0]=d;return}else if((b|0)==524304){a[(c[2443470]|0)+7|0]=d;return}else{return}}function enD(b){b=b|0;var c=0;switch(b|0){case 524290:case 524291:{c=(e[4774892]|0)>>>((b<<3&8^8)>>>0)&255;return c|0};case 524303:case 524302:{c=a[9771925]|0;return c|0};case 524288:case 524289:{c=(e[4774976]|0)>>>((b<<3&8^8)>>>0)&255;return c|0};default:{c=0;return c|0}}return 0}function enE(a){a=a|0;var c=0;if((a|0)==524290){c=b[4774892]|0}else if((a|0)==524302){c=d[9771925]|0}else if((a|0)==524296){c=(d[9634960]|0)<<8|(d[9634961]|0)}else if((a|0)==524288){c=b[4774976]|0}else{c=0}return c|0}function enF(d,e){d=d|0;e=e|0;if((d&-65536|0)==983040){b[(c[2388254]|0)+(d&65534)>>1]=e;enG(d>>>1&32767);return}if((d|0)==524318){a[9771924]=e&255;return}else if((d|0)==524312){if((e&255)==255){return}a[c[2388456]|0]=e&255;return}else{return}}function enG(a){a=a|0;var d=0,e=0;d=c[2388254]|0;switch(a|0){case 28815:{a=d+57630|0;e=b[a>>1]|0;if((e<<16>>16|0)==(-32712|0)){b[a>>1]=-1;b[d+57616>>1]=20217;b[d+57618>>1]=0;b[d+57620>>1]=-26838;return}else if((e<<16>>16|0)==(-32719|0)){b[a>>1]=-1;b[d+57616>>1]=20217;b[d+57618>>1]=0;b[d+57620>>1]=-11784;return}else{return}break};case 28865:{if((b[d+57730>>1]|0)!=-31139){return}b[d+57348>>1]=8;b[d+57350>>1]=2;return};case 28927:{a=d+57854|0;e=b[a>>1]|0;if((e<<16>>16|0)==(-32730|0)){b[a>>1]=-1;b[d+57840>>1]=20217;b[d+57842>>1]=0;b[d+57844>>1]=-29642;return}else if((e<<16>>16|0)==(-32746|0)){b[a>>1]=-1;b[d+57840>>1]=20217;b[d+57842>>1]=0;b[d+57844>>1]=-10720;return}else{return}break};case 28903:{a=d+57806|0;e=b[a>>1]|0;if((e<<16>>16|0)==(-32765|0)){b[a>>1]=-1;b[d+57792>>1]=20217;b[d+57794>>1]=0;b[d+57796>>1]=-32342;return}else if((e<<16>>16|0)==(-32756|0)){b[a>>1]=-1;b[d+57792>>1]=20217;b[d+57794>>1]=0;b[d+57796>>1]=-19042;return}else{return}break};case 29530:{if((b[d+59060>>1]|0)!=31166){return}b[d+57356>>1]=8;b[d+57358>>1]=10;return};case 28716:{if((b[d+57432>>1]|0)!=-14561){return}b[d+57344>>1]=8;b[d+57346>>1]=0;return};case 28919:{a=d+57838|0;e=b[a>>1]|0;if((e<<16>>16|0)==(-32747|0)){b[a>>1]=-1;b[d+57824>>1]=20217;b[d+57826>>1]=0;b[d+57828>>1]=-29428;return}else if((e<<16>>16|0)==(-32722|0)){b[a>>1]=-1;b[d+57824>>1]=20217;b[d+57826>>1]=0;b[d+57828>>1]=-15514;return}else{return}break};case 30592:{a=d+61184|0;if((b[a>>1]|0)!=24830){return}b[a>>1]=0;b[d+61186>>1]=0;b[d+61188>>1]=20217;b[d+61190>>1]=0;b[d+61192>>1]=32194;return};case 28839:{a=d+57678|0;e=b[a>>1]|0;if((e<<16>>16|0)==(-32757|0)){b[a>>1]=-1;b[d+57664>>1]=20217;b[d+57666>>1]=0;b[d+57668>>1]=-19470;return}else if((e<<16>>16|0)==(-32764|0)){b[a>>1]=-1;b[d+57664>>1]=20217;b[d+57666>>1]=0;b[d+57668>>1]=-30316;return}else{return}break};case 28831:{a=d+57662|0;e=b[a>>1]|0;if((e<<16>>16|0)==(-32749|0)){b[a>>1]=-1;b[d+57648>>1]=20217;b[d+57650>>1]=0;b[d+57652>>1]=-32342;return}else if((e<<16>>16|0)==(-32726|0)){b[a>>1]=-1;b[d+57648>>1]=20217;b[d+57650>>1]=0;b[d+57652>>1]=-25242;return}else{return}break};case 28863:{a=d+57726|0;e=b[a>>1]|0;if((e<<16>>16|0)==(-32722|0)){b[a>>1]=-1;b[d+57712>>1]=20217;b[d+57714>>1]=0;b[d+57716>>1]=-15514;return}else if((e<<16>>16|0)==(-32745|0)){b[a>>1]=-1;b[d+57712>>1]=20217;b[d+57714>>1]=0;b[d+57716>>1]=-30966;return}else{return}break};case 29327:{if((b[d+58654>>1]|0)!=3970){return}b[d+57352>>1]=8;b[d+57354>>1]=8;return};case 28807:{a=d+57614|0;e=b[a>>1]|0;if((e<<16>>16|0)==(-32761|0)){b[a>>1]=-1;b[d+57600>>1]=20217;b[d+57602>>1]=0;b[d+57604>>1]=-30966;return}else if((e<<16>>16|0)==(-32768|0)){b[a>>1]=-1;b[d+57600>>1]=20217;b[d+57602>>1]=0;b[d+57604>>1]=-9786;return}else{return}break};case 28879:{a=d+57758|0;e=b[a>>1]|0;if((e<<16>>16|0)==(-32720|0)){b[a>>1]=-1;b[d+57744>>1]=20217;b[d+57746>>1]=0;b[d+57748>>1]=-9786;return}else if((e<<16>>16|0)==(-32711|0)){b[a>>1]=-1;b[d+57744>>1]=20217;b[d+57746>>1]=0;b[d+57748>>1]=-27070;return}else{return}break};case 28823:{a=d+57646|0;e=b[a>>1]|0;if((e<<16>>16|0)==(-32734|0)){b[a>>1]=-1;b[d+57632>>1]=20217;b[d+57634>>1]=0;b[d+57636>>1]=-9722;return}else if((e<<16>>16|0)==(-32743|0)){b[a>>1]=-1;b[d+57632>>1]=20217;b[d+57634>>1]=0;b[d+57636>>1]=-27070;return}else{return}break};case 28895:{a=d+57790|0;e=b[a>>1]|0;if((e<<16>>16|0)==(-32734|0)){b[a>>1]=-1;b[d+57776>>1]=20217;b[d+57778>>1]=0;b[d+57780>>1]=-9722;return}else if((e<<16>>16|0)==(-32741|0)){b[a>>1]=-1;b[d+57776>>1]=20217;b[d+57778>>1]=0;b[d+57780>>1]=-19470;return}else{return}break};case 28911:{a=d+57822|0;e=b[a>>1]|0;if((e<<16>>16|0)==(-32716|0)){b[a>>1]=-1;b[d+57808>>1]=20217;b[d+57810>>1]=0;b[d+57812>>1]=-30316;return}else if((e<<16>>16|0)==(-32707|0)){b[a>>1]=-1;b[d+57808>>1]=20217;b[d+57810>>1]=0;b[d+57812>>1]=-25918;return}else{return}break};case 28855:{a=d+57710|0;e=b[a>>1]|0;if((e<<16>>16|0)==(-32739|0)){b[a>>1]=-1;b[d+57696>>1]=20217;b[d+57698>>1]=0;b[d+57700>>1]=-25918;return}else if((e<<16>>16|0)==(-32730|0)){b[a>>1]=-1;b[d+57696>>1]=20217;b[d+57698>>1]=0;b[d+57700>>1]=-29642;return}else{return}break};case 28847:{a=d+57694|0;e=b[a>>1]|0;if((e<<16>>16|0)==(-32715|0)){b[a>>1]=-1;b[d+57680>>1]=20217;b[d+57682>>1]=0;b[d+57684>>1]=-29428;return}else if((e<<16>>16|0)==(-32708|0)){b[a>>1]=-1;b[d+57680>>1]=20217;b[d+57682>>1]=0;b[d+57684>>1]=-19042;return}else{return}break};case 28887:{a=d+57774|0;e=b[a>>1]|0;if((e<<16>>16|0)==(-32751|0)){b[a>>1]=-1;b[d+57760>>1]=20217;b[d+57762>>1]=0;b[d+57764>>1]=-11784;return}else if((e<<16>>16|0)==(-32726|0)){b[a>>1]=-1;b[d+57760>>1]=20217;b[d+57762>>1]=0;b[d+57764>>1]=-25242;return}else{return}break};case 28871:{a=d+57742|0;e=b[a>>1]|0;if((e<<16>>16|0)==(-32764|0)){b[a>>1]=-1;b[d+57728>>1]=20217;b[d+57730>>1]=0;b[d+57732>>1]=-10720;return}else if((e<<16>>16|0)==(-32760|0)){b[a>>1]=-1;b[d+57728>>1]=20217;b[d+57730>>1]=0;b[d+57732>>1]=-26838;return}else{return}break};default:{return}}}function enH(b,d){b=b|0;d=d|0;var e=0;if((b&-65536|0)==983040){e=b&65535;a[(c[2388254]|0)+(e^1)|0]=d;enG(e>>>1);return}if((b|0)==524319|(b|0)==524318){a[9771924]=d;return}else if((b|0)==524312|(b|0)==524313){if(d<<24>>24==-1){return}a[c[2388456]|0]=d;return}else{return}}function enI(b,d){b=b|0;d=d|0;if((b|0)==1048607|(b|0)==1048606){a[c[3528248]|0]=d;return}else if((b|0)==1048600|(b|0)==1048601){if(d<<24>>24==-1){return}a[c[2388456]|0]=d;return}else{return}}function enJ(b,d){b=b|0;d=d|0;if((b|0)==1048606){a[c[3528248]|0]=d&255;return}else if((b|0)==1048600){if((d&255)==255){return}a[c[2388456]|0]=d&255;return}else{return}}function enK(b){b=b|0;var d=0;switch(b|0){case 1048590:case 1048591:{d=a[c[2443718]|0]|0;break};case 1048578:case 1048579:{d=(e[4774892]|0)>>>((b<<3&8^8)>>>0)&255;break};case 1048584:case 1048585:{d=a[9634960]|0;break};case 1048576:case 1048577:{d=(e[4774976]|0)>>>((b<<3&8^8)>>>0)&255;break};case 1048586:case 1048587:{d=a[9634961]|0;break};default:{d=0}}return d|0}function enL(a){a=a|0;var e=0;switch(a|0){case 1048576:{e=b[4774976]|0;break};case 1048590:{e=d[c[2443718]|0]|0;break};case 1048586:{e=d[9634961]|0;break};case 1048584:{e=d[9634960]|0;break};case 1048578:{e=b[4774892]|0;break};default:{e=0}}return e|0}function enM(b,d){b=b|0;d=d|0;var e=0;switch(b&65535|0){case 62976:{b=c[3529752]|0;e=d&3;if((e|0)==3){return}gGC(b+131072|0,b+((e<<17)+262144)|0,131072)|0;return};case 62464:{Uv(0,d);return};case 63232:{e=c[3529708]|0;b=d&3;if((b|0)==3){return}gGC(e+131072|0,e+((b<<17)+262144)|0,131072)|0;return};case 61440:{a[c[2443718]|0]=d;return};case 62720:{Uv(0,d);return};default:{return}}}function enN(b){b=b|0;var d=0,e=0;d=b&65535;if((d|0)==61440){e=a[c[3528248]|0]|0}else if((d|0)==62720){e=c[2113157]&255}else if((d|0)==62464){e=c[2113156]&255}else{e=0}return e|0}function enO(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=b&255;if((e|0)==1){lS(0,1,d);return}else if((e|0)==0){e=c[3541518]|0;b=e+256|0;a[e+304|0]=d;f=d&255;if((d&255)<16){c[14168912+((c[2383582]|0)*252|0)>>2]=f&15}if((d-45&255)>=3){return}if((f|0)==46){d=e+312|0;g=a[d]|1;a[d]=g;h=g}else if((f|0)==45){g=e+312|0;d=a[g]|2;a[g]=d;h=d}else if((f|0)==47){a[e+312|0]=0;h=0}else if((f|0)==0){a[e+312|0]=2;h=2}else{h=a[e+312|0]|0}e=h&3;h=c[7461744+(e<<2)>>2]|0;lI(b,h,h,c[7461728+(e<<2)>>2]|0);return}else{return}}function enP(b){b=b|0;var d=0,e=0,f=0.0,g=0.0;if((b&254)>>>0>=2){d=0;return d|0}b=c[3541518]|0;e=b+296|0;f=+h[e>>3];do{if(f!=0.0){g=+h[6675];if(f-(g+ +gC[c[2429842]&255]())<=0.0){h[e>>3]=0.0;break}d=a[b+307|0]|-128;return d|0}}while(0);d=a[b+307|0]|0;return d|0}function enQ(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=a&65535;if((d|0)==36864){a=c[3529752]|0;e=a+131072|0;f=a+(((b&255)<<17&393216)+262144)|0;gGC(e|0,f|0,131072)|0;return}else if((d|0)==38912){Uv(0,b);return}else{return}}function enR(b){b=b|0;var d=0,e=0;d=b&65535;if((d|0)==38912){e=c[2113156]&255}else if((d|0)==40960){a[9706117]=0;e=a[c[3528248]|0]|0}else{e=0}return e|0}function enS(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((e|0)==63498){Uv(0,d);return}else if((e|0)==63497){b=c[2113304]|0;a[14168504+b|0]=d;mv(0,b,d&255);return}else if((e|0)==63496){c[2113304]=d&255;return}else{return}}function enT(b){b=b|0;var d=0,e=0;d=b&65535;if((d|0)==63488){a[9706117]=0;e=a[c[3528248]|0]|0}else if((d|0)==63496|(d|0)==63497){e=c[(c[3531464]|0)+4240>>2]&255}else if((d|0)==63498){e=c[2113156]&255}else{e=0}return e|0}function enU(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;e=b&65535;if((e|0)==65528){Uv(1,d);return}else if((e|0)==65530){Uv(0,d);return}else if((e|0)==65522){if((d<<24>>24|0)==(-1|0)){f=c[3529708]|0;g=f+524288|0;gGC(f|0,g|0,262144)|0;return}else if((d<<24>>24|0)==(-2|0)){g=c[3529708]|0;f=g+262144|0;gGC(g|0,f|0,262144)|0;return}else{return}}else{if((b&65535)<=65023){return}a[(c[2386056]|0)+(e&4095)|0]=d;return}}function enV(b){b=b|0;var d=0,e=0;d=b&65535;do{if((d|0)==65520){a[9706117]=0;e=a[c[3528248]|0]|0}else if((d|0)==65528){e=c[2113157]&255}else if((d|0)==65530){e=c[2113156]&255}else{if((b&65535)<=65023){e=0;break}e=a[(c[2386056]|0)+(d&4095)|0]|0}}while(0);return e|0}function enW(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=b&65535;if((e|0)==57345){b=c[2385902]|0;f=c[9757320+(c[1836236]<<2)>>2]|0;g=((d&255)<<14&114688)+32768|0;h=128;i=128;while(1){c[f+76+(i<<2)>>2]=b+(g+(i<<8));j=h+1&65535;if((j&65535)>191){k=128;l=128;break}else{h=j;i=j&65535}}while(1){i=b+(g+(l<<8))|0;c[f+76+(l+512<<2)>>2]=i;c[f+76+(l+768<<2)>>2]=i;i=k+1&65535;if((i&65535)>191){break}else{k=i;l=i&65535}}return}else if((e|0)==61440){a[c[2443718]|0]=d;return}else{return}}function enX(b){b=b|0;var d=0;if(b<<16>>16!=-4096){d=0;return d|0}d=a[c[3528248]|0]|0;return d|0}function enY(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=b&65535;switch(e&255|0){case 1:{lS(0,1,d);return};case 128:{Uv(0,d);return};case 0:{b=c[3541518]|0;f=b+256|0;a[b+304|0]=d;g=d&255;if((d&255)<16){c[14168912+((c[2383582]|0)*252|0)>>2]=g&15}if((d-45&255)>=3){return}if((g|0)==47){a[b+312|0]=0;h=0}else if((g|0)==46){i=b+312|0;j=a[i]|1;a[i]=j;h=j}else if((g|0)==45){j=b+312|0;i=a[j]|2;a[j]=i;h=i}else if((g|0)==0){a[b+312|0]=2;h=2}else{h=a[b+312|0]|0}b=h&3;h=c[7461744+(b<<2)>>2]|0;lI(f,h,h,c[7461728+(b<<2)>>2]|0);return};case 144:case 145:case 146:case 147:case 148:case 149:case 150:case 151:{b=e>>>2&1;h=e&3;f=c[9638392+(b<<2)>>2]|0;g=((d&255)<<16|0)%((c[9541248+(b<<2)>>2]|0)-262144|0)|0;i=9771520+(e&7)|0;if((a[i]|0)==d<<24>>24){return}e=a[632360]<<31>>31&255&1<<b;a[i]=d;i=(e|0)!=0;if(i&(h|0)==0){e=f+1024|0;b=f+(g+263168)|0;gGC(e|0,b|0,64512)|0}else{b=f+(h<<16)|0;e=f+(g+262144)|0;gGC(b|0,e|0,65536)|0}if(!i){return}i=h<<8;gGC(f+i|0,f+(g+(i|262144))|0,256)|0;return};case 136:{Uv(1,d);return};default:{return}}}function enZ(b){b=b|0;var d=0,e=0,f=0.0,g=0.0,i=0;d=b&255;if((d|0)==0|(d|0)==1){b=c[3541518]|0;e=b+296|0;f=+h[e>>3];do{if(f!=0.0){g=+h[6675];if(f-(g+ +gC[c[2429842]&255]())<=0.0){h[e>>3]=0.0;break}i=a[b+307|0]|-128;return i|0}}while(0);i=a[b+307|0]|0;return i|0}else if((d|0)==136){i=c[2113157]&255;return i|0}else if((d|0)==128){i=c[2113156]&255;return i|0}else{i=0;return i|0}return 0}function en_(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2167076+(b*112|0)>>2];c[a+104>>2]=c[2167080+(b*112|0)>>2];c[a+108>>2]=c[2167084+(b*112|0)>>2];d=0;return d|0}function en$(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=2166976+(b*112|0);e=0;return e|0}function en0(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1180776+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function en1(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>37){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3321104+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function en2(){c[3528624]=32767;c[3528622]=65535;return esc(3520)|0}function en3(){var b=0,d=0,e=0,f=0,g=0;fwZ();b=c[3541518]|0;if((b|0)!=0){gGr(b|0);c[3541518]=0}if((c[2385508]|0)>0){c[2113008]=0;c[2076598]=0;c[2383582]=0}c[2438228]=0;c[2433526]=0;c[2406676]=0;c[3528472]=0;b=c[2406680]|0;if((b|0)!=0){gGr(b);c[2406680]=0}c[2385508]=0;c[2432978]=0;a[64240]=0;Uw(0);Uw(1);c[3541206]=0;c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}if((c[2392]|0)>=0){b=0;do{d=14130368+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}d=14130384+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}b=b+1|0;}while((b|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;b=c[2414932]|0;d=0;while(1){if((d|0)>=1024){f=65682;break}g=9638528+(d<<2)|0;if((c[g>>2]|0)==(b|0)){break}else{d=d+1|0}}if((f|0)==65682){c[2414932]=0;c[3528622]=0;c[3528624]=0;a[668912]=0;a[2826944]=0;a[7325688]=0;a[5689032]=0;return 0}gGr(b);c[g>>2]=0;c[2414932]=0;c[3528622]=0;c[3528624]=0;a[668912]=0;a[2826944]=0;a[7325688]=0;a[5689032]=0;return 0}function en4(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((a[9623960]|0)!=0){d=c[2414634]|0;gGz(d|0,0,(c[2411604]|0)-d|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=i;c[1836236]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){i=0;do{lN(i);mB(i);i=i+1|0;}while((i|0)<(c[2385508]|0))}c[2113156]=0;a[9628264]=0;c[2407033]=0;i=c[3541206]|0;gGz(c[2430118]|0,0,16384);c[2407041]=4;gGz(c[2430119]|0,0,16384);c[2407049]=4;gGz(c[2430120]|0,0,16384);c[2407057]=4;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2113157]=0;a[9628420]=0;c[2407072]=0;gGz(c[2430122]|0,0,16384);c[2407080]=4;gGz(c[2430123]|0,0,16384);c[2407088]=4;gGz(c[2430124]|0,0,16384);c[2407096]=4;gGz(c[2430125]|0,0,16384);c[2407104]=4;g=(c[3529708]|0)-(c[3529752]|0)|0;c[3541190]=i;c[3541198]=i;c[3541191]=i+256;c[3541199]=i+65536;c[3541192]=i+512;c[3541200]=i+131072;c[3541193]=i+768;c[3541201]=i+196608;f=i+g|0;c[3541194]=f;c[3541202]=f;c[3541195]=i+(g+256);c[3541203]=i+(g+65536);c[3541196]=i+(g+512);c[3541204]=i+(g+131072);c[3541197]=i+(g+768);c[3541205]=i+(g+196608);c[2429282]=-1;c[3528410]=0}do{if((dW(c[c[642608+(c[2436]<<2)>>2]>>2]|0,238160,8)|0)==0){b[4774976]=-32768;b[4774892]=0;b[4774848]=0;g=0;i=-32768;f=0;e=0;do{i=((a[9633120+g|0]&1)<<g^i&65535)&65535;f=((a[9630992+g|0]&1)<<g^f&65535)&65535;e=((a[9629432+g|0]&1)<<g^e&65535)&65535;g=g+1|0;}while((g|0)<16);b[4774976]=i;b[4774892]=f;b[4774848]=e;if((i&1)==0){j=f}else{g=f^128;b[4774892]=g;j=g}if((i&2)==0){k=j}else{g=j^32;b[4774892]=g;k=g}if((i&8)==0){l=k}else{g=k^1;b[4774892]=g;l=g}if((i&16)==0){break}b[4774892]=l^258}else{g=(c[3528624]^65535)&65535;b[4774976]=g;d=(c[3528622]^65535)&65535;b[4774892]=d;m=0;n=g;g=d;do{n=((a[9633120+m|0]&1)<<m^n&65535)&65535;g=((a[9630992+m|0]&1)<<m^g&65535)&65535;m=m+1|0;}while((m|0)<16);b[4774976]=n;b[4774892]=g}}while(0);l=c[2385548]|0;if((l|0)>0){gGz(9752472,0,((l|0)>1?l<<2:4)|0)}c[2433530]=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];l=c[3532592]|0;if((l|0)!=0){gGC(9104152,l|0,280)|0}c[2113054]=c[2113060]}l=c[2439330]|0;if((l|0)!=0){k=l;gGC(9706056,k|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;k=0;do{c[2113056]=17857;l=RG(17857)|0;c[2113054]=(c[2113054]|0)+l;c[2276108]=-1;c[2113056]=-1;do{if((k|0)==9|(k|0)==4){c[8452200+(c[2394]<<2)>>2]=8193;c[2276080]=256;if((c[2276079]|0)>>>0<256){RH(1)}c[2113056]=0;l=RG(0)|0;c[2113054]=(c[2113054]|0)+l;c[2276108]=-1;c[2113056]=-1;if((k|0)==4){c[8452200+(c[2394]<<2)>>2]=8194;c[2276080]=512;if((c[2276079]|0)>>>0>=512){break}RH(2);break}else if((k|0)==9){c[8452200+(c[2394]<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0>=1024){break}RH(4);break}else{break}}}while(0);Sb(k*5357|0);k=k+1|0;}while((k|0)<10);k=c[2438228]|0;g=gGS(-1531576320,25544,k,(k|0)<0|0?-1:0)|0;k=g;Sb(53571);g=c[2443830]|0;if((g|0)<1073676288){c[2443830]=g-k}g=c[2443831]|0;if((g|0)<1073676288){c[2443831]=g-k}g=(c[3528512]|0)-k|0;c[3528512]=(g|0)<0?0:g;g=c[2112964]|0;if((g|0)!=0){gg[c[3542122]&4095](g,a[9688]|0?534:0);g=c[2112964]|0;k=a[9688]|0?534:0;Uu(0,g,k);Uu(1,g,k)}k=c[1836236]|0;g=c[9757320+(k<<2)>>2]|0;if((g|0)!=0){n=g;gGC(n|0,9706056,76)|0}c[9752472+(k<<2)>>2]=c[2433530];c[14113936+(k<<2)>>2]=c[2076596];c[9669104+(k<<2)>>2]=c[3541536];c[1836236]=-1;k=c[2394]|0;n=c[14130368+(k<<2)>>2]|0;if((n|0)!=0){gGC(n|0,9104152,280)|0}c[8452240+(k<<2)>>2]=c[2113054];c[2394]=-1;if((c[2112968]|0)==0){o=c[3529664]|0;p=c[2388254]|0;q=p+32768|0;gGC(o|0,q|0,4096)|0;return 0}k=c[(c[642608+(c[2436]<<2)>>2]|0)+112>>2]|0;if((k|0)==0){o=c[3529664]|0;p=c[2388254]|0;q=p+32768|0;gGC(o|0,q|0,4096)|0;return 0}gD[k&8191]()|0;o=c[3529664]|0;p=c[2388254]|0;q=p+32768|0;gGC(o|0,q|0,4096)|0;return 0}function en5(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=b[(c[2388254]|0)+40704>>1]|0;f=c[2387164]|0;g=c[3529970]|0;h=0;do{i=e[f+(h<<1)>>1]|0;j=i>>>3;k=i>>>7&30;c[g+(h<<2)>>2]=i>>>1&1|i&61440|j&30|j<<11&2048|((k|i>>>2&1)<<3|k>>>2)<<3&2016;h=h+1|0;}while((h|0)<1024);erv(c[2387982]|0,d&4095,0,0,0);ern(1,256,15,3);ern(1,256,15,2);ern(1,256,15,1);ern(1,256,15,0);if((c[2439222]|0)!=0){d=c[2405794]|0;h=a[2826944]|0?0:248;f=c[2112926]|0;k=c[3530812]|0;i=c[2113068]|0;j=c[2113070]|0;l=0;do{m=((l>>5<<3)+8&248)-8|0;n=((l<<3)+h&255)-8|0;if((m|0)<(i|0)&(n|0)<(j|0)){o=e[d+(l<<1)>>1]|0;Sr(f,o&4095,m,n,o>>>12,4,15,0,k)}l=l+1|0;}while((l|0)<1024)}if(!(a[5689032]|0)){R8(g);return 0}l=c[2112968]|0;k=c[2112926]|0;f=c[2113070]|0;if((f|0)<=1){R8(g);return 0}d=c[2113068]|0;j=d<<1;i=-d|0;h=(f|0)/2|0;o=k;n=k+((ag(d,f-1|0)|0)<<1)|0;f=0;while(1){k=o;gGC(l|0,k|0,j)|0;m=n;gGC(k|0,m|0,j)|0;gGC(m|0,l|0,j)|0;m=f+1|0;if((m|0)<(h|0)){o=o+(d<<1)|0;n=n+(i<<1)|0;f=m}else{break}}R8(g);return 0}function en6(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1378116+(b*112|0)>>2];c[a+104>>2]=c[1378120+(b*112|0)>>2];c[a+108>>2]=c[1378124+(b*112|0)>>2];d=0;return d|0}function en7(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=1378016+(b*112|0);e=0;return e|0}function en8(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2613652+(b*112|0)>>2];c[a+104>>2]=c[2613656+(b*112|0)>>2];c[a+108>>2]=c[2613660+(b*112|0)>>2];d=0;return d|0}function en9(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=2613552+(b*112|0);e=0;return e|0}function eoa(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1232800+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eob(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>44){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3765440+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eoc(){a[2826944]=1;c[3528624]=32767;c[3528622]=65535;return esc(4920)|0}function eod(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=c[2443470]|0;f=b[d+130>>1]|0;g=b[d+194>>1]|0;d=c[2387164]|0;h=c[3529970]|0;i=0;do{j=e[d+(i<<1)>>1]|0;k=j>>>3;l=j>>>7&30;c[h+(i<<2)>>2]=j>>>1&1|j&61440|k&30|k<<11&2048|((l|j>>>2&1)<<3|l>>>2)<<3&2016;i=i+1|0;}while((i|0)<1024);erv(c[2387982]|0,f&4095,g&511,0,0);ern(1,256,15,3);ern(1,256,15,2);ern(1,256,15,1);ern(1,256,15,0);if((c[2439222]|0)!=0){g=c[2405794]|0;f=a[2826944]|0?0:248;i=c[2112926]|0;d=c[3530812]|0;l=c[2113068]|0;j=c[2113070]|0;k=0;do{m=((k>>5<<3)+8&248)-8|0;n=((k<<3)+f&255)-8|0;if((m|0)<(l|0)&(n|0)<(j|0)){o=e[g+(k<<1)>>1]|0;Sr(i,o&4095,m,n,o>>>12,4,15,0,d)}k=k+1|0;}while((k|0)<1024)}if(!(a[5689032]|0)){R8(h);return 0}k=c[2112968]|0;d=c[2112926]|0;i=c[2113070]|0;if((i|0)<=1){R8(h);return 0}g=c[2113068]|0;j=g<<1;l=-g|0;f=(i|0)/2|0;o=d;n=d+((ag(g,i-1|0)|0)<<1)|0;i=0;while(1){d=o;gGC(k|0,d|0,j)|0;m=n;gGC(d|0,m|0,j)|0;gGC(m|0,k|0,j)|0;m=i+1|0;if((m|0)<(f|0)){o=o+(g<<1)|0;n=n+(l<<1)|0;i=m}else{break}}R8(h);return 0}function eoe(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2211972+(b*112|0)>>2];c[a+104>>2]=c[2211976+(b*112|0)>>2];c[a+108>>2]=c[2211980+(b*112|0)>>2];d=0;return d|0}function eof(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=2211872+(b*112|0);e=0;return e|0}function eog(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1187544+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eoh(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>23){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3371840+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eoi(){return erU(1204)|0}function eoj(){var b=0,d=0,e=0,f=0,g=0;fwZ();Uw(0);c[3541206]=0;c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}if((c[2392]|0)>=0){b=0;do{d=14130368+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}d=14130384+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}b=b+1|0;}while((b|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;b=c[2414932]|0;d=0;while(1){if((d|0)>=1024){f=65856;break}g=9638528+(d<<2)|0;if((c[g>>2]|0)==(b|0)){break}else{d=d+1|0}}if((f|0)==65856){c[2414932]=0;c[3528622]=0;c[3528624]=0;a[668912]=0;a[2826944]=0;a[7325688]=0;a[5689032]=0;return 0}gGr(b);c[g>>2]=0;c[2414932]=0;c[3528622]=0;c[3528624]=0;a[668912]=0;a[2826944]=0;a[7325688]=0;a[5689032]=0;return 0}function eok(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((a[9623960]|0)!=0){d=c[2414634]|0;gGz(d|0,0,(c[2411604]|0)-d|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;h=c[2417276]|0;c[3541536]=h;c[1836236]=0;gGz(9706056,0,76);if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=h;c[1836236]=-1;c[2113156]=0;a[9628264]=0;c[2407033]=0;h=c[3541206]|0;c[3541190]=h;c[3541198]=h;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=h+256;c[3541199]=h+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=h+512;c[3541200]=h+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=h+768;c[3541201]=h+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4}h=(c[3528624]^65535)&65535;b[4774976]=h;g=(c[3528622]^65535)&65535;b[4774892]=g;f=0;e=h;h=g;do{e=((a[9633120+f|0]&1)<<f^e&65535)&65535;h=((a[9630992+f|0]&1)<<f^h&65535)&65535;f=f+1|0;}while((f|0)<16);b[4774976]=e;b[4774892]=h;h=c[2385548]|0;if((h|0)>0){gGz(9752472,0,((h|0)>1?h<<2:4)|0)}c[2433530]=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];h=c[3532592]|0;if((h|0)!=0){gGC(9104152,h|0,280)|0}c[2113054]=c[2113060]}h=c[2439330]|0;if((h|0)!=0){e=h;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;e=0;do{c[2113056]=14285;h=RG(14285)|0;c[2113054]=(c[2113054]|0)+h;c[2276108]=-1;c[2113056]=-1;h=(e|0)==9;if((e|0)==9|(e|0)==4){c[8452200+(c[2394]<<2)>>2]=8193;c[2276080]=256;if((c[2276079]|0)>>>0<256){RH(1)}c[2113056]=0;f=RG(0)|0;c[2113054]=(c[2113054]|0)+f;c[2276108]=-1;c[2113056]=-1;do{if((e|0)==4&(c[2430448]|0)!=0){c[8452200+(c[2394]<<2)>>2]=8194;c[2276080]=512;if((c[2276079]|0)>>>0>=512){break}RH(2)}}while(0);if(h){i=65887;break}}if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){f=gfc(7142)|0;j=(c[2433530]|0)+f|0}else{j=(c[2433530]|0)+7142|0}c[2433530]=j;e=e+1|0;}while((e|0)<10);do{if((i|0)==65887){c[8452200+(c[2394]<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0<1024){RH(4)}if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){e=gfc(7142)|0;c[2433530]=(c[2433530]|0)+e;break}else{c[2433530]=(c[2433530]|0)+7142;break}}}while(0);i=c[2112964]|0;if((i|0)!=0){Uu(0,i,a[9688]|0?534:0)}i=c[1836236]|0;e=c[9757320+(i<<2)>>2]|0;if((e|0)!=0){j=e;gGC(j|0,9706056,76)|0}c[9752472+(i<<2)>>2]=c[2433530];c[14113936+(i<<2)>>2]=c[2076596];c[9669104+(i<<2)>>2]=c[3541536];c[1836236]=-1;i=c[2394]|0;j=c[14130368+(i<<2)>>2]|0;if((j|0)!=0){gGC(j|0,9104152,280)|0}c[8452240+(i<<2)>>2]=c[2113054];c[2394]=-1;if((c[2112968]|0)==0){k=c[3529664]|0;l=c[2388254]|0;m=l+32768|0;gGC(k|0,m|0,4096)|0;return 0}i=c[(c[642608+(c[2436]<<2)>>2]|0)+112>>2]|0;if((i|0)==0){k=c[3529664]|0;l=c[2388254]|0;m=l+32768|0;gGC(k|0,m|0,4096)|0;return 0}gD[i&8191]()|0;k=c[3529664]|0;l=c[2388254]|0;m=l+32768|0;gGC(k|0,m|0,4096)|0;return 0}function eol(){var b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[2443470]|0;d=e[b>>1]|0;f=e[b+2>>1]|0;g=e[b+4>>1]|0;h=e[b+6>>1]|0;b=c[2387164]|0;i=c[3529970]|0;j=0;do{k=e[b+(j<<1)>>1]|0;l=k>>>3;m=k>>>7&30;c[i+(j<<2)>>2]=k>>>1&1|k&61440|l&30|l<<11&2048|((m|k>>>2&1)<<3|m>>>2)<<3&2016;j=j+1|0;}while((j|0)<1024);erv(c[2387982]|0,d<<8&3840|f&255,g<<8&256|h&255,0,0);ern(0,256,15,3);ern(0,256,15,2);ern(0,256,15,1);ern(0,256,15,0);if((c[2439222]|0)!=0){h=c[2405794]|0;g=a[2826944]|0?0:248;f=c[2112926]|0;d=c[3530812]|0;j=c[2113068]|0;b=c[2113070]|0;m=0;do{k=((m>>5<<3)+8&248)-8|0;l=((m<<3)+g&255)-8|0;if((k|0)<(j|0)&(l|0)<(b|0)){n=e[h+(m<<1)>>1]|0;Sr(f,n&4095,k,l,n>>>12,4,15,512,d)}m=m+1|0;}while((m|0)<1024)}if(!(a[5689032]|0)){R8(i);return 0}m=c[2112968]|0;d=c[2112926]|0;f=c[2113070]|0;if((f|0)<=1){R8(i);return 0}h=c[2113068]|0;b=h<<1;j=-h|0;g=(f|0)/2|0;n=d;l=d+((ag(h,f-1|0)|0)<<1)|0;f=0;while(1){d=n;gGC(m|0,d|0,b)|0;k=l;gGC(d|0,k|0,b)|0;gGC(k|0,m|0,b)|0;k=f+1|0;if((k|0)<(g|0)){n=n+(h<<1)|0;l=l+(j<<1)|0;f=k}else{break}}R8(i);return 0}function eom(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3173716+(b*112|0)>>2];c[a+104>>2]=c[3173720+(b*112|0)>>2];c[a+108>>2]=c[3173724+(b*112|0)>>2];d=0;return d|0}function eon(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=3173616+(b*112|0);e=0;return e|0}function eoo(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1625252+(b*112|0)>>2];c[a+104>>2]=c[1625256+(b*112|0)>>2];c[a+108>>2]=c[1625260+(b*112|0)>>2];d=0;return d|0}function eop(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=1625152+(b*112|0);e=0;return e|0}function eoq(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2632172+(b*112|0)>>2];c[a+104>>2]=c[2632176+(b*112|0)>>2];c[a+108>>2]=c[2632180+(b*112|0)>>2];d=0;return d|0}function eor(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=2632072+(b*112|0);e=0;return e|0}function eos(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4154640+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eot(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>49){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3776592+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eou(){var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;d=i;i=i+960|0;e=d|0;f=d+112|0;g=d+120|0;j=d+232|0;k=d+240|0;l=d+352|0;m=d+360|0;n=d+472|0;o=d+480|0;p=d+592|0;q=d+600|0;r=d+712|0;s=d+720|0;t=d+832|0;u=d+840|0;v=d+952|0;c[2414932]=0;err();w=c[2414144]|0;x=0;while(1){if((x|0)>=1024){break}y=9638528+(x<<2)|0;if((c[y>>2]|0)==0){z=65977;break}else{x=x+1|0}}do{if((z|0)==65977){x=gGq(w)|0;c[y>>2]=x;if((x|0)==0){break}gGz(x|0,0,w|0);c[2414932]=x;gGz(x|0,0,w|0);err();x=c[2388126]|0;if((c[3542200]|0)==0){A=1;i=d;return A|0}B=u+108|0;c[B>>2]=0;C=u+100|0;c[C>>2]=0;D=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[D&16383](u,0)|0;do{if((c[B>>2]|0)!=0){D=c[C>>2]|0;c[v>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](v,0,0)|0;if((D|0)<1){A=1;i=d;return A|0}if((gzL(x,0,0)|0)==0){break}else{A=1}i=d;return A|0}}while(0);x=c[2385902]|0;if((c[3542200]|0)==0){A=1;i=d;return A|0}C=s+108|0;c[C>>2]=0;B=s+100|0;c[B>>2]=0;D=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[D&16383](s,1)|0;do{if((c[C>>2]|0)!=0){D=c[B>>2]|0;c[t>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](t,1,0)|0;if((D|0)<1){A=1;i=d;return A|0}if((gzL(x,0,1)|0)==0){break}else{A=1}i=d;return A|0}}while(0);x=c[2385902]|0;B=x+65536|0;gGC(B|0,x|0,131072)|0;x=c[3530812]|0;if((c[3542200]|0)==0){A=1;i=d;return A|0}B=q+108|0;c[B>>2]=0;C=q+100|0;c[C>>2]=0;D=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[D&16383](q,2)|0;do{if((c[B>>2]|0)!=0){D=c[C>>2]|0;c[r>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](r,2,0)|0;if((D|0)<1){A=1;i=d;return A|0}if((gzL(x,0,2)|0)==0){break}else{A=1}i=d;return A|0}}while(0);x=c[3530576]|0;if((c[3542200]|0)==0){A=1;i=d;return A|0}C=o+108|0;c[C>>2]=0;B=o+100|0;c[B>>2]=0;D=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[D&16383](o,3)|0;do{if((c[C>>2]|0)!=0){D=c[B>>2]|0;c[p>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](p,3,0)|0;if((D|0)<1){A=1;i=d;return A|0}if((gzL(x,0,3)|0)==0){break}else{A=1}i=d;return A|0}}while(0);x=c[3530416]|0;if((c[3542200]|0)==0){A=1;i=d;return A|0}B=m+108|0;c[B>>2]=0;C=m+100|0;c[C>>2]=0;D=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[D&16383](m,4)|0;do{if((c[B>>2]|0)!=0){D=c[C>>2]|0;c[n>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](n,4,0)|0;if((D|0)<1){A=1;i=d;return A|0}if((gzL(x,0,4)|0)==0){break}else{A=1}i=d;return A|0}}while(0);x=(c[3530416]|0)+2097152|0;if((c[3542200]|0)==0){A=1;i=d;return A|0}C=k+108|0;c[C>>2]=0;B=k+100|0;c[B>>2]=0;D=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[D&16383](k,5)|0;do{if((c[C>>2]|0)!=0){D=c[B>>2]|0;c[l>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](l,5,0)|0;if((D|0)<1){A=1;i=d;return A|0}if((gzL(x,0,5)|0)==0){break}else{A=1}i=d;return A|0}}while(0);x=0;B=c[3530416]|0;while(1){C=a[B]|0;D=B+1|0;a[B]=a[D]|0;a[D]=C;C=x+1|0;if((C|0)<2097152){x=C;B=B+2|0}else{break}}B=(c[3529752]|0)+262144|0;if((c[3542200]|0)==0){A=1;i=d;return A|0}x=g+108|0;c[x>>2]=0;C=g+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,6)|0;do{if((c[x>>2]|0)!=0){D=c[C>>2]|0;c[j>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](j,6,0)|0;if((D|0)<1){A=1;i=d;return A|0}if((gzL(B,0,6)|0)==0){break}else{A=1}i=d;return A|0}}while(0);B=c[3529752]|0;C=B+262144|0;gGC(B|0,C|0,262144)|0;C=(c[3529708]|0)+262144|0;if((c[3542200]|0)==0){A=1;i=d;return A|0}B=e+108|0;c[B>>2]=0;x=e+100|0;c[x>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,7)|0;do{if((c[B>>2]|0)!=0){D=c[x>>2]|0;c[f>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](f,7,0)|0;if((D|0)<1){A=1;i=d;return A|0}if((gzL(C,0,7)|0)==0){break}else{A=1}i=d;return A|0}}while(0);C=c[3529708]|0;x=C+262144|0;gGC(C|0,x|0,262144)|0;erq(131072,2097152,4194304);fxU(0,425984);if((c[2394]|0)==0){F=c[2112932]|0}else{c[2394]=0;x=c[3532596]|0;c[2112932]=x;C=c[3532592]|0;if((C|0)!=0){gGC(9104152,C|0,280)|0}c[2113054]=c[2113060];F=x}x=c[2388126]|0;C=F|0;B=0;while(1){D=x+B|0;c[C>>2]=D;c[C+131072>>2]=D;D=B+1024|0;if(D>>>0>524287){break}else{C=C+4|0;B=D}}B=c[2387164]|0;c[F+4608>>2]=B;c[F+70144>>2]=B;c[F+135680>>2]=B;C=B+1024|0;c[F+4612>>2]=C;c[F+70148>>2]=C;c[F+135684>>2]=C;C=c[2443470]|0;c[F+4864>>2]=C;c[F+70400>>2]=C;c[F+135936>>2]=C;B=C+1024|0;c[F+4868>>2]=B;c[F+70404>>2]=B;c[F+135940>>2]=B;B=c[2387982]|0;c[F+5120>>2]=B;c[F+70656>>2]=B;c[F+136192>>2]=B;C=B+1024|0;c[F+5124>>2]=C;c[F+70660>>2]=C;c[F+136196>>2]=C;C=B+2048|0;c[F+5128>>2]=C;c[F+70664>>2]=C;c[F+136200>>2]=C;C=B+3072|0;c[F+5132>>2]=C;c[F+70668>>2]=C;c[F+136204>>2]=C;C=B+4096|0;c[F+5136>>2]=C;c[F+70672>>2]=C;c[F+136208>>2]=C;C=B+5120|0;c[F+5140>>2]=C;c[F+70676>>2]=C;c[F+136212>>2]=C;C=B+6144|0;c[F+5144>>2]=C;c[F+70680>>2]=C;c[F+136216>>2]=C;C=B+7168|0;c[F+5148>>2]=C;c[F+70684>>2]=C;c[F+136220>>2]=C;C=B+8192|0;c[F+5152>>2]=C;c[F+70688>>2]=C;c[F+136224>>2]=C;C=B+9216|0;c[F+5156>>2]=C;c[F+70692>>2]=C;c[F+136228>>2]=C;C=B+10240|0;c[F+5160>>2]=C;c[F+70696>>2]=C;c[F+136232>>2]=C;C=B+11264|0;c[F+5164>>2]=C;c[F+70700>>2]=C;c[F+136236>>2]=C;C=B+12288|0;c[F+5168>>2]=C;c[F+70704>>2]=C;c[F+136240>>2]=C;C=B+13312|0;c[F+5172>>2]=C;c[F+70708>>2]=C;c[F+136244>>2]=C;C=B+14336|0;c[F+5176>>2]=C;c[F+70712>>2]=C;c[F+136248>>2]=C;C=B+15360|0;c[F+5180>>2]=C;c[F+70716>>2]=C;c[F+136252>>2]=C;C=c[2387978]|0;c[F+5184>>2]=C;c[F+70720>>2]=C;c[F+136256>>2]=C;B=C+1024|0;c[F+5188>>2]=B;c[F+70724>>2]=B;c[F+136260>>2]=B;B=C+2048|0;c[F+5192>>2]=B;c[F+70728>>2]=B;c[F+136264>>2]=B;B=C+3072|0;c[F+5196>>2]=B;c[F+70732>>2]=B;c[F+136268>>2]=B;B=C+4096|0;c[F+5200>>2]=B;c[F+70736>>2]=B;c[F+136272>>2]=B;B=C+5120|0;c[F+5204>>2]=B;c[F+70740>>2]=B;c[F+136276>>2]=B;B=C+6144|0;c[F+5208>>2]=B;c[F+70744>>2]=B;c[F+136280>>2]=B;B=C+7168|0;c[F+5212>>2]=B;c[F+70748>>2]=B;c[F+136284>>2]=B;B=C+8192|0;c[F+5216>>2]=B;c[F+70752>>2]=B;c[F+136288>>2]=B;B=C+9216|0;c[F+5220>>2]=B;c[F+70756>>2]=B;c[F+136292>>2]=B;B=C+10240|0;c[F+5224>>2]=B;c[F+70760>>2]=B;c[F+136296>>2]=B;B=C+11264|0;c[F+5228>>2]=B;c[F+70764>>2]=B;c[F+136300>>2]=B;B=C+12288|0;c[F+5232>>2]=B;c[F+70768>>2]=B;c[F+136304>>2]=B;B=C+13312|0;c[F+5236>>2]=B;c[F+70772>>2]=B;c[F+136308>>2]=B;B=C+14336|0;c[F+5240>>2]=B;c[F+70776>>2]=B;c[F+136312>>2]=B;B=C+15360|0;c[F+5244>>2]=B;c[F+70780>>2]=B;c[F+136316>>2]=B;B=c[2387972]|0;c[F+5248>>2]=B;c[F+70784>>2]=B;c[F+136320>>2]=B;C=B+1024|0;c[F+5252>>2]=C;c[F+70788>>2]=C;c[F+136324>>2]=C;C=B+2048|0;c[F+5256>>2]=C;c[F+70792>>2]=C;c[F+136328>>2]=C;C=B+3072|0;c[F+5260>>2]=C;c[F+70796>>2]=C;c[F+136332>>2]=C;C=B+4096|0;c[F+5264>>2]=C;c[F+70800>>2]=C;c[F+136336>>2]=C;C=B+5120|0;c[F+5268>>2]=C;c[F+70804>>2]=C;c[F+136340>>2]=C;C=B+6144|0;c[F+5272>>2]=C;c[F+70808>>2]=C;c[F+136344>>2]=C;C=B+7168|0;c[F+5276>>2]=C;c[F+70812>>2]=C;c[F+136348>>2]=C;C=B+8192|0;c[F+5280>>2]=C;c[F+70816>>2]=C;c[F+136352>>2]=C;C=B+9216|0;c[F+5284>>2]=C;c[F+70820>>2]=C;c[F+136356>>2]=C;C=B+10240|0;c[F+5288>>2]=C;c[F+70824>>2]=C;c[F+136360>>2]=C;C=B+11264|0;c[F+5292>>2]=C;c[F+70828>>2]=C;c[F+136364>>2]=C;C=B+12288|0;c[F+5296>>2]=C;c[F+70832>>2]=C;c[F+136368>>2]=C;C=B+13312|0;c[F+5300>>2]=C;c[F+70836>>2]=C;c[F+136372>>2]=C;C=B+14336|0;c[F+5304>>2]=C;c[F+70840>>2]=C;c[F+136376>>2]=C;C=B+15360|0;c[F+5308>>2]=C;c[F+70844>>2]=C;c[F+136380>>2]=C;C=c[2387968]|0;c[F+5312>>2]=C;c[F+70848>>2]=C;c[F+136384>>2]=C;B=C+1024|0;c[F+5316>>2]=B;c[F+70852>>2]=B;c[F+136388>>2]=B;B=C+2048|0;c[F+5320>>2]=B;c[F+70856>>2]=B;c[F+136392>>2]=B;B=C+3072|0;c[F+5324>>2]=B;c[F+70860>>2]=B;c[F+136396>>2]=B;B=C+4096|0;c[F+5328>>2]=B;c[F+70864>>2]=B;c[F+136400>>2]=B;B=C+5120|0;c[F+5332>>2]=B;c[F+70868>>2]=B;c[F+136404>>2]=B;B=C+6144|0;c[F+5336>>2]=B;c[F+70872>>2]=B;c[F+136408>>2]=B;B=C+7168|0;c[F+5340>>2]=B;c[F+70876>>2]=B;c[F+136412>>2]=B;B=C+8192|0;c[F+5344>>2]=B;c[F+70880>>2]=B;c[F+136416>>2]=B;B=C+9216|0;c[F+5348>>2]=B;c[F+70884>>2]=B;c[F+136420>>2]=B;B=C+10240|0;c[F+5352>>2]=B;c[F+70888>>2]=B;c[F+136424>>2]=B;B=C+11264|0;c[F+5356>>2]=B;c[F+70892>>2]=B;c[F+136428>>2]=B;B=C+12288|0;c[F+5360>>2]=B;c[F+70896>>2]=B;c[F+136432>>2]=B;B=C+13312|0;c[F+5364>>2]=B;c[F+70900>>2]=B;c[F+136436>>2]=B;B=C+14336|0;c[F+5368>>2]=B;c[F+70904>>2]=B;c[F+136440>>2]=B;B=C+15360|0;c[F+5372>>2]=B;c[F+70908>>2]=B;c[F+136444>>2]=B;B=c[2405794]|0;c[F+5888>>2]=B;c[F+71424>>2]=B;c[F+136960>>2]=B;C=B+1024|0;c[F+5892>>2]=C;c[F+71428>>2]=C;c[F+136964>>2]=C;x=B+2048|0;c[F+5896>>2]=x;c[F+71432>>2]=x;c[F+136968>>2]=x;D=B+3072|0;c[F+5900>>2]=D;c[F+71436>>2]=D;c[F+136972>>2]=D;E=c[2112932]|0;c[E+5904>>2]=B;c[E+71440>>2]=B;c[E+136976>>2]=B;c[E+5908>>2]=C;c[E+71444>>2]=C;c[E+136980>>2]=C;c[E+5912>>2]=x;c[E+71448>>2]=x;c[E+136984>>2]=x;c[E+5916>>2]=D;c[E+71452>>2]=D;c[E+136988>>2]=D;D=c[2388254]|0;x=E+7936|0;C=2031616;while(1){B=D+(C-2031616)|0;c[x>>2]=B;c[x+65536>>2]=B;c[x+131072>>2]=B;B=C+1024|0;if(B>>>0>2097151){break}else{x=x+4|0;C=B}}c[E+196728>>2]=1766;c[E+196648>>2]=2056;c[E+196688>>2]=294;c[E+196608>>2]=858;C=c[2394]|0;x=c[14130368+(C<<2)>>2]|0;if((x|0)!=0){gGC(x|0,9104152,280)|0}c[8452240+(C<<2)>>2]=c[2113054];c[2394]=-1;fwR(0);C=c[2439330]|0;x=(C|0)==0;if(!x){D=C;gGC(9706056,D|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];D=c[3528484]|0;c[2076596]=D;B=c[2417276]|0;c[3541536]=B;c[1836236]=0;G=c[2385902]|0;H=0;I=0;while(1){c[C+76+(I<<2)>>2]=G+(I<<8);J=H+1&65535;if((J&65535)>127){K=0;L=0;break}else{H=J;I=J&65535}}while(1){I=G+(L<<8)|0;c[C+76+(L+512<<2)>>2]=I;c[C+76+(L+768<<2)>>2]=I;I=K+1&65535;if((I&65535)>127){M=128;N=128;break}else{K=I;L=I&65535}}while(1){c[C+76+(N<<2)>>2]=G+(N<<8);I=M+1&65535;if((I&65535)>191){O=128;P=128;break}else{M=I;N=I&65535}}while(1){I=G+(P<<8)|0;c[C+76+(P+512<<2)>>2]=I;c[C+76+(P+768<<2)>>2]=I;I=O+1&65535;if((I&65535)>191){break}else{O=I;P=I&65535}}G=c[2386056]|0;I=192;H=192;while(1){c[C+76+(H<<2)>>2]=G+((H<<8)-49152);E=I+1&65535;if((E&65535)>223){Q=192;R=192;break}else{I=E;H=E&65535}}while(1){c[C+76+(R+256<<2)>>2]=G+((R<<8)-49152);H=Q+1&65535;if((H&65535)>223){S=192;T=192;break}else{Q=H;R=H&65535}}while(1){H=G+((T<<8)-49152)|0;c[C+76+(T+512<<2)>>2]=H;c[C+76+(T+768<<2)>>2]=H;H=S+1&65535;if((H&65535)>223){break}else{S=H;T=H&65535}}c[C+4184>>2]=884;c[C+4180>>2]=2380;c[C+4176>>2]=794;c[C+4172>>2]=498;if(!x){G=C;gGC(G|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=D;c[2417276]=B;c[1836236]=-1;c[2424]=5600;Vr(1,15e5,128,3304,78,0);c[2438228]=4e6;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=511;h[745419]=.9;a[3203368]=1;h[745418]=.9;a[3203360]=1;h[745417]=.9;a[3203352]=1;h[745416]=.9;a[3203344]=1;Ux(0,24242,1);Ux(1,24242,1);c[2407030]=51;c[2407068]=3;c[2407069]=51;c[2407107]=3;G=c[642608+(c[2436]<<2)>>2]|0;H=(fa(c[G>>2]|0,437464)|0)==0;I=c[3529752]|0;E=c[3529708]|0;c[2409598]=I;c[2409599]=E;c[2385312]=2359296;if(H){c[2385313]=1310720;a[632360]=1;H=9771520;c[H>>2]=-1;c[H+4>>2]=-1;a[9771520]=0;H=I+1024|0;J=I+263168|0;gGC(H|0,J|0,64512)|0;J=I+262144|0;gGC(I|0,J|0,256)|0;a[9771524]=0;J=E+1024|0;H=E+263168|0;gGC(J|0,H|0,64512)|0;H=E+262144|0;gGC(E|0,H|0,256)|0}else{c[2385313]=2359296;a[632360]=1;H=9771520;c[H>>2]=-1;c[H+4>>2]=-1;a[9771520]=0;H=I+1024|0;J=I+263168|0;gGC(H|0,J|0,64512)|0;J=I+262144|0;gGC(I|0,J|0,256)|0;a[9771524]=0;J=E+1024|0;I=E+263168|0;gGC(J|0,I|0,64512)|0;I=E+262144|0;gGC(E|0,I|0,256)|0}I=c[G+128>>2]|0;if((c[G+52>>2]&4|0)==0){c[2113068]=I;E=c[G+132>>2]|0;c[2113070]=E;c[2443814]=I;c[2440436]=E;U=I;V=E}else{c[2113070]=I;E=c[G+132>>2]|0;c[2113068]=E;c[2440436]=I;c[2443814]=E;U=E;V=I}I=ag(U<<1,V)|0;E=gGq(I)|0;c[2112926]=E;if((E|0)!=0){gGz(E|0,0,I|0)}I=c[2414634]|0;gGz(I|0,0,(c[2411604]|0)-I|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];I=c[3532592]|0;if((I|0)!=0){gGC(9104152,I|0,280)|0}c[2113054]=c[2113060]}RI();I=c[2394]|0;E=c[14130368+(I<<2)>>2]|0;if((E|0)!=0){gGC(E|0,9104152,280)|0}c[8452240+(I<<2)>>2]=c[2113054];c[2394]=-1;I=c[2439330]|0;E=(I|0)==0;if(!E){G=I;gGC(9706056,G|0,76)|0}G=c[2438118]|0;c[2433530]=G;J=c[3528484]|0;c[2076596]=J;H=c[2417276]|0;c[3541536]=H;c[1836236]=0;gGz(9706056,0,76);if(!E){E=I;gGC(E|0,9706056,76)|0}c[2438118]=G;c[3528484]=J;c[2417276]=H;c[1836236]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){H=0;do{lN(H);mB(H);H=H+1|0;}while((H|0)<(c[2385508]|0))}c[2113156]=0;a[9628264]=0;c[2407033]=0;H=c[3541206]|0;gGz(c[2430118]|0,0,16384);c[2407041]=4;gGz(c[2430119]|0,0,16384);c[2407049]=4;gGz(c[2430120]|0,0,16384);c[2407057]=4;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2113157]=0;a[9628420]=0;c[2407072]=0;gGz(c[2430122]|0,0,16384);c[2407080]=4;gGz(c[2430123]|0,0,16384);c[2407088]=4;gGz(c[2430124]|0,0,16384);c[2407096]=4;gGz(c[2430125]|0,0,16384);c[2407104]=4;B=(c[3529708]|0)-(c[3529752]|0)|0;c[3541190]=H;c[3541198]=H;c[3541191]=H+256;c[3541199]=H+65536;c[3541192]=H+512;c[3541200]=H+131072;c[3541193]=H+768;c[3541201]=H+196608;D=H+B|0;c[3541194]=D;c[3541202]=D;c[3541195]=H+(B+256);c[3541203]=H+(B+65536);c[3541196]=H+(B+512);c[3541204]=H+(B+131072);c[3541197]=H+(B+768);c[3541205]=H+(B+196608);c[2429282]=-1;c[3528410]=0;A=0;i=d;return A|0}}while(0);c[2414932]=0;A=1;i=d;return A|0}function eov(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0;if((a[9623960]|0)!=0){d=c[2414634]|0;gGz(d|0,0,(c[2411604]|0)-d|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=i;c[1836236]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){i=0;do{lN(i);mB(i);i=i+1|0;}while((i|0)<(c[2385508]|0))}c[2113156]=0;a[9628264]=0;c[2407033]=0;i=c[3541206]|0;gGz(c[2430118]|0,0,16384);c[2407041]=4;gGz(c[2430119]|0,0,16384);c[2407049]=4;gGz(c[2430120]|0,0,16384);c[2407057]=4;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2113157]=0;a[9628420]=0;c[2407072]=0;gGz(c[2430122]|0,0,16384);c[2407080]=4;gGz(c[2430123]|0,0,16384);c[2407088]=4;gGz(c[2430124]|0,0,16384);c[2407096]=4;gGz(c[2430125]|0,0,16384);c[2407104]=4;g=(c[3529708]|0)-(c[3529752]|0)|0;c[3541190]=i;c[3541198]=i;c[3541191]=i+256;c[3541199]=i+65536;c[3541192]=i+512;c[3541200]=i+131072;c[3541193]=i+768;c[3541201]=i+196608;f=i+g|0;c[3541194]=f;c[3541202]=f;c[3541195]=i+(g+256);c[3541203]=i+(g+65536);c[3541196]=i+(g+512);c[3541204]=i+(g+131072);c[3541197]=i+(g+768);c[3541205]=i+(g+196608);c[2429282]=-1;c[3528410]=0}g=(c[3528624]^65535)&65535;b[4774976]=g;i=(c[3528622]^65535)&65535;b[4774892]=i;f=0;e=g;g=i;do{e=((a[9633120+f|0]&1)<<f^e&65535)&65535;g=((a[9630992+f|0]&1)<<f^g&65535)&65535;f=f+1|0;}while((f|0)<16);b[4774976]=e;b[4774892]=g;g=c[2385548]|0;if((g|0)>0){gGz(9752472,0,((g|0)>1?g<<2:4)|0)}c[2433530]=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060]}g=c[2439330]|0;if((g|0)!=0){e=g;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;e=0;do{c[2113056]=892;g=RG(892)|0;c[2113054]=(c[2113054]|0)+g;c[2276108]=-1;c[2113056]=-1;do{if((e|0)==199){c[8452200+(c[2394]<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0>=1024){break}RH(4)}else if((e|0)==1|(e|0)==100){c[8452200+(c[2394]<<2)>>2]=8193;c[2276080]=256;if((c[2276079]|0)>>>0>=256){break}RH(1)}}while(0);if((c[2429282]|0)!=0){Sb(e*357|0)}e=e+1|0;}while((e|0)<200);if((c[2429282]|0)!=0){e=c[2438228]|0;g=gGS(-2042101760,34059,e,(e|0)<0|0?-1:0)|0;e=g;Sb(71428);g=c[2443830]|0;if((g|0)<1073676288){c[2443830]=g-e}g=c[2443831]|0;if((g|0)<1073676288){c[2443831]=g-e}g=(c[3528512]|0)-e|0;c[3528512]=(g|0)<0?0:g}g=c[2112964]|0;if((g|0)!=0){gg[c[3542122]&4095](g,a[9688]|0?534:0);g=c[2112964]|0;e=a[9688]|0?534:0;Uu(1,g,e);Uu(0,g,e)}e=c[1836236]|0;g=c[9757320+(e<<2)>>2]|0;if((g|0)!=0){f=g;gGC(f|0,9706056,76)|0}c[9752472+(e<<2)>>2]=c[2433530];c[14113936+(e<<2)>>2]=c[2076596];c[9669104+(e<<2)>>2]=c[3541536];c[1836236]=-1;e=c[2394]|0;f=c[14130368+(e<<2)>>2]|0;if((f|0)!=0){gGC(f|0,9104152,280)|0}c[8452240+(e<<2)>>2]=c[2113054];c[2394]=-1;if((c[2112968]|0)==0){j=c[3529664]|0;k=c[2388254]|0;l=k+32768|0;gGC(j|0,l|0,4096)|0;return 0}e=c[(c[642608+(c[2436]<<2)>>2]|0)+112>>2]|0;if((e|0)==0){j=c[3529664]|0;k=c[2388254]|0;l=k+32768|0;gGC(j|0,l|0,4096)|0;return 0}gD[e&8191]()|0;j=c[3529664]|0;k=c[2388254]|0;l=k+32768|0;gGC(j|0,l|0,4096)|0;return 0}function eow(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a[7325688]=1;d=c[2387164]|0;f=c[3529970]|0;g=0;do{h=e[d+(g<<1)>>1]|0;i=h>>>3;j=h>>>7&30;c[f+(g<<2)>>2]=h>>>1&1|h&61440|i&30|i<<11&2048|((j|h>>>2&1)<<3|j>>>2)<<3&2016;g=g+1|0;}while((g|0)<1024);g=c[2443470]|0;d=e[g>>1]|0;j=d<<8&3840|b[g+2>>1]&255;h=(e[g+4>>1]|0)<<8&256|b[g+6>>1]&255;g=d&48;if((g|0)==0){erv(c[2387982]|0,j+4032&4095,h,0,0)}else if((g|0)==16){erv(c[2387978]|0,j+4032&4095,h,0,0)}else if((g|0)==48){erv(c[2387968]|0,j+4032&4095,h,0,0)}else if((g|0)==32){erv(c[2387972]|0,j+4032&4095,h,0,0)}ern(0,256,31,3);ern(0,256,31,2);ern(0,256,31,1);ern(0,256,31,0);if((c[2439222]|0)!=0){h=c[2405794]|0;j=a[2826944]|0?0:248;g=c[2112926]|0;d=c[3530812]|0;i=c[2113068]|0;k=c[2113070]|0;l=0;do{m=((l>>5<<3)+72&504)-8|0;n=((l<<3)+j&255)-8|0;if((m|0)<(i|0)&(n|0)<(k|0)){o=e[h+(l<<1)>>1]|0;Sr(g,o&4095,m,n,o>>>12,4,15,768,d)}l=l+1|0;}while((l|0)<2048)}if(!(a[5689032]|0)){R8(f);return 0}l=c[2112968]|0;d=c[2112926]|0;g=c[2113070]|0;if((g|0)<=1){R8(f);return 0}h=c[2113068]|0;k=h<<1;i=-h|0;j=(g|0)/2|0;o=d;n=d+((ag(h,g-1|0)|0)<<1)|0;g=0;while(1){d=o;gGC(l|0,d|0,k)|0;m=n;gGC(d|0,m|0,k)|0;gGC(m|0,l|0,k)|0;m=g+1|0;if((m|0)<(j|0)){o=o+(h<<1)|0;n=n+(i<<1)|0;g=m}else{break}}R8(f);return 0}function eox(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2174932+(b*112|0)>>2];c[a+104>>2]=c[2174936+(b*112|0)>>2];c[a+108>>2]=c[2174940+(b*112|0)>>2];d=0;return d|0}function eoy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=2174832+(b*112|0);e=0;return e|0}function eoz(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1182456+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eoA(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>51){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3324536+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eoB(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1381028+(b*112|0)>>2];c[a+104>>2]=c[1381032+(b*112|0)>>2];c[a+108>>2]=c[1381036+(b*112|0)>>2];d=0;return d|0}function eoC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=1380928+(b*112|0);e=0;return e|0}function eoD(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4813428+(b*112|0)>>2];c[a+104>>2]=c[4813432+(b*112|0)>>2];c[a+108>>2]=c[4813436+(b*112|0)>>2];d=0;return d|0}function eoE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=4813328+(b*112|0);e=0;return e|0}function eoF(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2207716+(b*112|0)>>2];c[a+104>>2]=c[2207720+(b*112|0)>>2];c[a+108>>2]=c[2207724+(b*112|0)>>2];d=0;return d|0}function eoG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=2207616+(b*112|0);e=0;return e|0}function eoH(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>26){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3368824+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eoI(){return erW(4222,9106)|0}function eoJ(){var b=0,d=0,e=0,f=0,g=0;fwZ();b=c[3531464]|0;c[b+44344>>2]=0;c[b+44348>>2]=0;if((b|0)!=0){gGr(b);c[3531464]=0}b=c[2406684]|0;if((b|0)!=0){gGr(b);c[2406684]=0}Uw(0);Uw(1);c[3541206]=0;c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}if((c[2392]|0)>=0){b=0;do{d=14130368+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}d=14130384+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}b=b+1|0;}while((b|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;b=c[2414932]|0;d=0;while(1){if((d|0)>=1024){f=66244;break}g=9638528+(d<<2)|0;if((c[g>>2]|0)==(b|0)){break}else{d=d+1|0}}if((f|0)==66244){c[2414932]=0;c[3528622]=0;c[3528624]=0;a[668912]=0;a[2826944]=0;a[7325688]=0;a[5689032]=0;return 0}gGr(b);c[g>>2]=0;c[2414932]=0;c[3528622]=0;c[3528624]=0;a[668912]=0;a[2826944]=0;a[7325688]=0;a[5689032]=0;return 0}function eoK(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((a[9623960]|0)!=0){d=c[2414634]|0;gGz(d|0,0,(c[2411604]|0)-d|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;h=c[2417276]|0;c[3541536]=h;c[1836236]=0;gGz(9706056,0,76);if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=h;c[1836236]=-1;mx(0);c[2113156]=0;a[9628264]=0;c[2407033]=0;h=c[3541206]|0;gGz(c[2430118]|0,0,16384);c[2407041]=4;gGz(c[2430119]|0,0,16384);c[2407049]=4;gGz(c[2430120]|0,0,16384);c[2407057]=4;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2113157]=0;a[9628420]=0;c[2407072]=0;gGz(c[2430122]|0,0,16384);c[2407080]=4;gGz(c[2430123]|0,0,16384);c[2407088]=4;gGz(c[2430124]|0,0,16384);c[2407096]=4;gGz(c[2430125]|0,0,16384);c[2407104]=4;g=(c[3529708]|0)-(c[3529752]|0)|0;c[3541190]=h;c[3541198]=h;c[3541191]=h+256;c[3541199]=h+65536;c[3541192]=h+512;c[3541200]=h+131072;c[3541193]=h+768;c[3541201]=h+196608;f=h+g|0;c[3541194]=f;c[3541202]=f;c[3541195]=h+(g+256);c[3541203]=h+(g+65536);c[3541196]=h+(g+512);c[3541204]=h+(g+131072);c[3541197]=h+(g+768);c[3541205]=h+(g+196608)}g=c[2385548]|0;if((g|0)>0){gGz(9752472,0,((g|0)>1?g<<2:4)|0)}c[2433530]=0;g=(c[3528624]^65535)&65535;b[4774976]=g;h=(c[3528622]^65535)&65535;b[4774892]=h;f=0;e=g;g=h;do{e=((a[9633120+f|0]&1)<<f^e&65535)&65535;g=((a[9630992+f|0]&1)<<f^g&65535)&65535;f=f+1|0;}while((f|0)<16);b[4774976]=e;b[4774892]=g;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060]}g=c[2439330]|0;if((g|0)!=0){e=g;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;e=0;g=0;while(1){c[2113056]=21428;f=RG(21428)|0;c[2113054]=(c[2113054]|0)+f;c[2276108]=-1;c[2113056]=-1;do{if((e|0)==4){c[8452200+(c[2394]<<2)>>2]=8194;c[2276080]=512;if((c[2276079]|0)>>>0>=512){break}RH(2)}else if((e|0)==9){c[8452200+(c[2394]<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0>=1024){break}RH(4)}}while(0);if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){f=gfc(7142)|0;i=(c[2433530]|0)+f|0}else{i=(c[2433530]|0)+7142|0}c[2433530]=i;f=c[2112964]|0;if((f|0)==0){j=g}else{h=a[9688]|0?53:0;d=f+(g<<1<<1)|0;gg[c[3542124]&4095](d,h);Uu(0,d,h);Uu(1,d,h);j=h+g|0}h=e+1|0;if((h|0)<10){e=h;g=j}else{break}}g=c[2112964]|0;do{if((g|0)!=0){e=a[9688]|0?534:0;i=e-j|0;h=g+(j<<1<<1)|0;if((e|0)==(j|0)){break}gg[c[3542124]&4095](h,i);Uu(0,h,i);Uu(1,h,i)}}while(0);j=c[1836236]|0;g=c[9757320+(j<<2)>>2]|0;if((g|0)!=0){i=g;gGC(i|0,9706056,76)|0}c[9752472+(j<<2)>>2]=c[2433530];c[14113936+(j<<2)>>2]=c[2076596];c[9669104+(j<<2)>>2]=c[3541536];c[1836236]=-1;j=c[2394]|0;i=c[14130368+(j<<2)>>2]|0;if((i|0)!=0){gGC(i|0,9104152,280)|0}c[8452240+(j<<2)>>2]=c[2113054];c[2394]=-1;if((c[2112968]|0)==0){k=c[3529664]|0;l=c[2388254]|0;m=l+32768|0;gGC(k|0,m|0,4096)|0;return 0}j=c[(c[642608+(c[2436]<<2)>>2]|0)+112>>2]|0;if((j|0)==0){k=c[3529664]|0;l=c[2388254]|0;m=l+32768|0;gGC(k|0,m|0,4096)|0;return 0}gD[j&8191]()|0;k=c[3529664]|0;l=c[2388254]|0;m=l+32768|0;gGC(k|0,m|0,4096)|0;return 0}function eoL(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=c[2443470]|0;f=e[d+2>>1]|0;g=b[d>>1]|0;h=b[d+6>>1]|0;i=b[d+4>>1]|0;d=c[2387164]|0;j=c[3529970]|0;k=0;do{l=e[d+(k<<1)>>1]|0;m=l>>>3;n=l>>>7&30;c[j+(k<<2)>>2]=l>>>1&1|l&61440|m&30|m<<11&2048|((n|l>>>2&1)<<3|n>>>2)<<3&2016;k=k+1|0;}while((k|0)<1024);erv(c[2387982]|0,f+3840&4095,g&511,0,0);ern(1,256,15,3);ern(1,256,15,2);ern(1,256,15,1);ern(1,256,15,0);if((c[2439222]|0)!=0){g=c[2405794]|0;f=8-(h&65535)|0;h=8-(i&65535)+(a[2826944]|0?248:240)|0;i=c[2112926]|0;k=c[3530812]|0;d=c[2113068]|0;n=c[2113070]|0;l=0;do{m=(f+(l>>5<<3)&255)-8|0;o=(h+(l<<3)&255)-8|0;if((m|0)<(d|0)&(o|0)<(n|0)){p=e[g+(l<<1)>>1]|0;Sr(i,p&4095,m,o,p>>>12,4,15,512,k)}l=l+1|0;}while((l|0)<1024)}if(!(a[5689032]|0)){R8(j);return 0}l=c[2112968]|0;k=c[2112926]|0;i=c[2113070]|0;if((i|0)<=1){R8(j);return 0}g=c[2113068]|0;n=g<<1;d=-g|0;h=(i|0)/2|0;f=k;p=k+((ag(g,i-1|0)|0)<<1)|0;i=0;while(1){k=f;gGC(l|0,k|0,n)|0;o=p;gGC(k|0,o|0,n)|0;gGC(o|0,l|0,n)|0;o=i+1|0;if((o|0)<(h|0)){f=f+(g<<1)|0;p=p+(d<<1)|0;i=o}else{break}}R8(j);return 0}function eoM(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4447428+(b*112|0)>>2];c[a+104>>2]=c[4447432+(b*112|0)>>2];c[a+108>>2]=c[4447436+(b*112|0)>>2];d=0;return d|0}function eoN(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=4447328+(b*112|0);e=0;return e|0}function eoO(){var b=0,d=0,e=0,f=0;b=erW(4222,9106)|0;if((b|0)!=0){return b|0}d=gGq(262144)|0;e=c[2388126]|0;gGC(d|0,e|0,262144)|0;f=0;do{a[e+f|0]=a[d+(f>>>16<<17&131072|f&16531455|f>>>15<<16&65536|f>>>14<<15&32768|f>>>17<<14&16384)|0]|0;f=f+1|0;}while((f|0)<262144);gGr(d);return b|0}function eoP(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2391044+(b*112|0)>>2];c[a+104>>2]=c[2391048+(b*112|0)>>2];c[a+108>>2]=c[2391052+(b*112|0)>>2];d=0;return d|0}function eoQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=2390944+(b*112|0);e=0;return e|0}function eoR(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2390260+(b*112|0)>>2];c[a+104>>2]=c[2390264+(b*112|0)>>2];c[a+108>>2]=c[2390268+(b*112|0)>>2];d=0;return d|0}function eoS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=2390160+(b*112|0);e=0;return e|0}function eoT(){var b=0,d=0,e=0,f=0;b=erW(4222,9106)|0;if((b|0)!=0){return b|0}d=gGq(262144)|0;e=c[2388126]|0;gGC(d|0,e|0,262144)|0;a[e]=a[d]|0;f=1;do{a[e+f|0]=a[d+(f>>>15<<17&131072|f&16613375|f>>>17<<15&32768)|0]|0;f=f+1|0;}while((f|0)<262144);gGr(d);return b|0}function eoU(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=c[2443470]|0;f=b[d+4>>1]|0;g=b[d+6>>1]|0;d=c[2387164]|0;h=c[3529970]|0;i=0;do{j=e[d+(i<<1)>>1]|0;k=j>>>3;l=j>>>7&30;c[h+(i<<2)>>2]=j>>>1&1|j&61440|k&30|k<<11&2048|((l|j>>>2&1)<<3|l>>>2)<<3&2016;i=i+1|0;}while((i|0)<1024);erv(c[2387982]|0,f&255,g&255,0,0);ern(0,256,15,3);ern(0,256,15,2);ern(0,256,15,1);ern(0,256,15,0);if((c[2439222]|0)!=0){g=c[2405794]|0;f=a[2826944]|0?0:248;i=c[2112926]|0;d=c[3530812]|0;l=c[2113068]|0;j=c[2113070]|0;k=0;do{m=((k>>5<<3)+8&248)-8|0;n=((k<<3)+f&255)-8|0;if((m|0)<(l|0)&(n|0)<(j|0)){o=e[g+(k<<1)>>1]|0;Sr(i,o&4095,m,n,o>>>12,4,15,768,d)}k=k+1|0;}while((k|0)<1024)}if(!(a[5689032]|0)){R8(h);return 0}k=c[2112968]|0;d=c[2112926]|0;i=c[2113070]|0;if((i|0)<=1){R8(h);return 0}g=c[2113068]|0;j=g<<1;l=-g|0;f=(i|0)/2|0;o=d;n=d+((ag(g,i-1|0)|0)<<1)|0;i=0;while(1){d=o;gGC(k|0,d|0,j)|0;m=n;gGC(d|0,m|0,j)|0;gGC(m|0,k|0,j)|0;m=i+1|0;if((m|0)<(f|0)){o=o+(g<<1)|0;n=n+(l<<1)|0;i=m}else{break}}R8(h);return 0}function eoV(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2391828+(b*112|0)>>2];c[a+104>>2]=c[2391832+(b*112|0)>>2];c[a+108>>2]=c[2391836+(b*112|0)>>2];d=0;return d|0}function eoW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=2391728+(b*112|0);e=0;return e|0}function eoX(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>26){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3568448+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eoY(){c[3528622]=65535;c[3528624]=65535;return erW(248,9106)|0}function eoZ(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=c[2443470]|0;f=b[d+2>>1]|0;g=e[d>>1]|0;h=b[d+6>>1]|0;i=b[d+4>>1]|0;d=c[2387164]|0;j=c[3529970]|0;k=0;do{l=e[d+(k<<1)>>1]|0;m=l>>>3;n=l>>>7&30;c[j+(k<<2)>>2]=l>>>1&1|l&61440|m&30|m<<11&2048|((n|l>>>2&1)<<3|n>>>2)<<3&2016;k=k+1|0;}while((k|0)<1024);erv(c[2387982]|0,f&4095,g+256&511,0,0);ern(1,256,15,3);ern(1,256,15,2);ern(1,256,15,1);ern(1,256,15,0);if((c[2439222]|0)!=0){g=c[2405794]|0;f=8-(h&65535)|0;h=8-(i&65535)+(a[2826944]|0?248:240)|0;i=c[2112926]|0;k=c[3530812]|0;d=c[2113068]|0;n=c[2113070]|0;l=0;do{m=(f+(l>>5<<3)&255)-8|0;o=(h+(l<<3)&255)-8|0;if((m|0)<(d|0)&(o|0)<(n|0)){p=e[g+(l<<1)>>1]|0;Sr(i,p&4095,m,o,p>>>12,4,15,512,k)}l=l+1|0;}while((l|0)<1024)}if(!(a[5689032]|0)){R8(j);return 0}l=c[2112968]|0;k=c[2112926]|0;i=c[2113070]|0;if((i|0)<=1){R8(j);return 0}g=c[2113068]|0;n=g<<1;d=-g|0;h=(i|0)/2|0;f=k;p=k+((ag(g,i-1|0)|0)<<1)|0;i=0;while(1){k=f;gGC(l|0,k|0,n)|0;o=p;gGC(k|0,o|0,n)|0;gGC(o|0,l|0,n)|0;o=i+1|0;if((o|0)<(h|0)){f=f+(g<<1)|0;p=p+(d<<1)|0;i=o}else{break}}R8(j);return 0}function eo_(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2817396+(b*112|0)>>2];c[a+104>>2]=c[2817400+(b*112|0)>>2];c[a+108>>2]=c[2817404+(b*112|0)>>2];d=0;return d|0}function eo$(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=2817296+(b*112|0);e=0;return e|0}function eo0(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>32){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3890016+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eo1(){a[5689032]=1;return erW(1130,9106)|0}function eo2(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=c[2443470]|0;f=e[d+6>>1]|0;g=b[d+4>>1]|0;d=c[2387164]|0;h=c[3529970]|0;i=0;do{j=e[d+(i<<1)>>1]|0;k=j>>>3;l=j>>>7&30;c[h+(i<<2)>>2]=j>>>1&1|j&61440|k&30|k<<11&2048|((l|j>>>2&1)<<3|l>>>2)<<3&2016;i=i+1|0;}while((i|0)<1024);erv(c[2387982]|0,g&4095,f+256&511,0,0);ern(1,256,15,3);ern(1,256,15,2);ern(1,256,15,1);ern(1,256,15,0);if((c[2439222]|0)!=0){f=c[2405794]|0;g=a[2826944]|0?0:248;i=c[2112926]|0;d=c[3530812]|0;l=c[2113068]|0;j=c[2113070]|0;k=0;do{m=((k>>5<<3)+8&248)-8|0;n=((k<<3)+g&255)-8|0;if((m|0)<(l|0)&(n|0)<(j|0)){o=e[f+(k<<1)>>1]|0;Sr(i,o&4095,m,n,o>>>12,4,15,512,d)}k=k+1|0;}while((k|0)<1024)}if(!(a[5689032]|0)){R8(h);return 0}k=c[2112968]|0;d=c[2112926]|0;i=c[2113070]|0;if((i|0)<=1){R8(h);return 0}f=c[2113068]|0;j=f<<1;l=-f|0;g=(i|0)/2|0;o=d;n=d+((ag(f,i-1|0)|0)<<1)|0;i=0;while(1){d=o;gGC(k|0,d|0,j)|0;m=n;gGC(d|0,m|0,j)|0;gGC(m|0,k|0,j)|0;m=i+1|0;if((m|0)<(g|0)){o=o+(f<<1)|0;n=n+(l<<1)|0;i=m}else{break}}R8(h);return 0}function eo3(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1535700+(b*112|0)>>2];c[a+104>>2]=c[1535704+(b*112|0)>>2];c[a+108>>2]=c[1535708+(b*112|0)>>2];d=0;return d|0}function eo4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=1535600+(b*112|0);e=0;return e|0}function eo5(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>32){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3890016+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eo6(){var b=0,d=0,e=0,f=0;b=erW(1130,9106)|0;if((b|0)!=0){return b|0}d=gGq(524288)|0;e=c[2388126]|0;gGC(d|0,e|0,524288)|0;f=0;do{a[e+f|0]=a[d+(f>>>16<<17&131072|f&16531455|f>>>17<<16&65536|f>>>14<<15&32768|f>>>15<<14&16384)|0]|0;f=f+1|0;}while((f|0)<524288);gGr(d);return b|0}function eo7(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1534804+(b*112|0)>>2];c[a+104>>2]=c[1534808+(b*112|0)>>2];c[a+108>>2]=c[1534812+(b*112|0)>>2];d=0;return d|0}function eo8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=1534704+(b*112|0);e=0;return e|0}function eo9(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1536596+(b*112|0)>>2];c[a+104>>2]=c[1536600+(b*112|0)>>2];c[a+108>>2]=c[1536604+(b*112|0)>>2];d=0;return d|0}function epa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=1536496+(b*112|0);e=0;return e|0}function epb(){var b=0,d=0,e=0,f=0;b=erW(28,9106)|0;if((b|0)!=0){return b|0}d=gGq(524288)|0;e=c[2388126]|0;gGC(d|0,e|0,524288)|0;f=0;do{a[e+f|0]=a[d+(f>>>13<<17&131072|f&16523263|f>>>17<<16&65536|f>>>16<<15&32768|f>>>15<<14&16384|f>>>14<<13&8192)|0]|0;f=f+1|0;}while((f|0)<524288);gGr(d);d=gGq(524288)|0;f=c[2388126]|0;gGC(d|0,f|0,524288)|0;a[f]=a[d]|0;e=1;do{a[f+e|0]=a[d+(e>>>14<<15&32768|e&16728063|e>>>15<<14&16384)|0]|0;e=e+1|0;}while((e|0)<524288);gGr(d);d=gGq(524288)|0;e=c[2388126]|0;gGC(d|0,e|0,524288)|0;a[e]=a[d]|0;f=1;do{a[e+f|0]=a[d+(f>>>15<<16&65536|f&16678911|f>>>16<<15&32768)|0]|0;f=f+1|0;}while((f|0)<524288);gGr(d);d=gGq(524288)|0;f=c[2388126]|0;gGC(d|0,f|0,524288)|0;a[f]=a[d]|0;e=1;do{a[f+e|0]=a[d+(e>>>16<<17&131072|e&16580607|e>>>17<<16&65536)|0]|0;e=e+1|0;}while((e|0)<524288);gGr(d);return b|0}function epc(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1425708+(b*112|0)>>2];c[a+104>>2]=c[1425712+(b*112|0)>>2];c[a+108>>2]=c[1425716+(b*112|0)>>2];d=0;return d|0}function epd(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=1425608+(b*112|0);e=0;return e|0}function epe(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1023508+(b*112|0)>>2];c[a+104>>2]=c[1023512+(b*112|0)>>2];c[a+108>>2]=c[1023516+(b*112|0)>>2];d=0;return d|0}function epf(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=1023408+(b*112|0);e=0;return e|0}function epg(){var b=0,d=0,e=0,f=0;b=erW(1130,9106)|0;if((b|0)!=0){return b|0}d=gGq(524288)|0;e=c[2388126]|0;gGC(d|0,e|0,524288)|0;f=0;do{a[e+f|0]=a[d+(f>>>13<<15&32768|f&16719871|f>>>15<<14&16384|f>>>14<<13&8192)|0]|0;f=f+1|0;}while((f|0)<524288);gGr(d);d=gGq(524288)|0;f=c[2388126]|0;gGC(d|0,f|0,524288)|0;a[f]=a[d]|0;e=1;do{a[f+e|0]=a[d+(e>>>14<<15&32768|e&16728063|e>>>15<<14&16384)|0]|0;e=e+1|0;}while((e|0)<524288);gGr(d);d=gGq(524288)|0;e=c[2388126]|0;gGC(d|0,e|0,524288)|0;a[e]=a[d]|0;f=1;do{a[e+f|0]=a[d+(f>>>16<<17&131072|f&16580607|f>>>17<<16&65536)|0]|0;f=f+1|0;}while((f|0)<524288);gGr(d);return b|0}function eph(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2445396+(b*112|0)>>2];c[a+104>>2]=c[2445400+(b*112|0)>>2];c[a+108>>2]=c[2445404+(b*112|0)>>2];d=0;return d|0}function epi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=2445296+(b*112|0);e=0;return e|0}function epj(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3617304+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function epk(){var b=0,d=0,e=0,f=0;b=erW(458,9106)|0;if((b|0)!=0){return b|0}d=gGq(524288)|0;e=c[2388126]|0;gGC(d|0,e|0,524288)|0;f=0;do{a[e+f|0]=a[d+(f>>>16<<17&131072|f&16531455|f>>>17<<16&65536|f>>>14<<15&32768|f>>>15<<14&16384)|0]|0;f=f+1|0;}while((f|0)<524288);gGr(d);return b|0}function epl(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=c[2443470]|0;f=e[d+2>>1]|0;g=b[d>>1]|0;h=b[d+6>>1]|0;i=b[d+4>>1]|0;d=c[2387164]|0;j=c[3529970]|0;k=0;do{l=e[d+(k<<1)>>1]|0;m=l>>>3;n=l>>>7&30;c[j+(k<<2)>>2]=l>>>1&1|l&61440|m&30|m<<11&2048|((n|l>>>2&1)<<3|n>>>2)<<3&2016;k=k+1|0;}while((k|0)<1024);erv(c[2387982]|0,f+3840&4095,g&511,0,0);ern(1,256,15,3);ern(1,256,15,2);ern(1,256,15,1);ern(1,256,15,0);if((c[2439222]|0)!=0){g=c[2405794]|0;f=8-(h&65535)|0;h=8-(i&65535)+(a[2826944]|0?248:240)|0;i=c[2112926]|0;k=c[3530812]|0;d=c[2113068]|0;n=c[2113070]|0;l=0;do{m=(f+(l>>5<<3)&255)-8|0;o=(h+(l<<3)&255)-8|0;if((m|0)<(d|0)&(o|0)<(n|0)){p=e[g+(l<<1)>>1]|0;Sr(i,p&4095,m,o,p>>>12,4,15,512,k)}l=l+1|0;}while((l|0)<1024)}if(!(a[5689032]|0)){R8(j);return 0}l=c[2112968]|0;k=c[2112926]|0;i=c[2113070]|0;if((i|0)<=1){R8(j);return 0}g=c[2113068]|0;n=g<<1;d=-g|0;h=(i|0)/2|0;f=k;p=k+((ag(g,i-1|0)|0)<<1)|0;i=0;while(1){k=f;gGC(l|0,k|0,n)|0;o=p;gGC(k|0,o|0,n)|0;gGC(o|0,l|0,n)|0;o=i+1|0;if((o|0)<(h|0)){f=f+(g<<1)|0;p=p+(d<<1)|0;i=o}else{break}}R8(j);return 0}function epm(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3042668+(b*112|0)>>2];c[a+104>>2]=c[3042672+(b*112|0)>>2];c[a+108>>2]=c[3042676+(b*112|0)>>2];d=0;return d|0}function epn(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=3042568+(b*112|0);e=0;return e|0}function epo(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>30){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4206928+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function epp(){var b=0,d=0,e=0,f=0;b=erW(1512,9106)|0;if((b|0)!=0){return b|0}d=gGq(262144)|0;e=c[2388126]|0;gGC(d|0,e|0,262144)|0;f=0;do{a[e+f|0]=a[d+(f>>>13<<17&131072|f&16556031|f>>>14<<16&65536|f>>>16<<14&16384|f>>>17<<13&8192)|0]|0;f=f+1|0;}while((f|0)<262144);gGr(d);return b|0}function epq(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4665644+(b*112|0)>>2];c[a+104>>2]=c[4665648+(b*112|0)>>2];c[a+108>>2]=c[4665652+(b*112|0)>>2];d=0;return d|0}function epr(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=4665544+(b*112|0);e=0;return e|0}function eps(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4561276+(b*112|0)>>2];c[a+104>>2]=c[4561280+(b*112|0)>>2];c[a+108>>2]=c[4561284+(b*112|0)>>2];d=0;return d|0}function ept(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=4561176+(b*112|0);e=0;return e|0}function epu(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>29){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5297480+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function epv(){var b=0,d=0,e=0,f=0;b=erW(710,9106)|0;if((b|0)!=0){return b|0}d=gGq(524288)|0;e=c[2388126]|0;gGC(d|0,e|0,524288)|0;f=0;do{a[e+f|0]=a[d+(f>>>13<<17&131072|f&16556031|f>>>14<<16&65536|f>>>16<<14&16384|f>>>17<<13&8192)|0]|0;f=f+1|0;}while((f|0)<524288);gGr(d);return b|0}function epw(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2858364+(b*112|0)>>2];c[a+104>>2]=c[2858368+(b*112|0)>>2];c[a+108>>2]=c[2858372+(b*112|0)>>2];d=0;return d|0}function epx(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=2858264+(b*112|0);e=0;return e|0}function epy(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>42){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3959888+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function epz(){a[5689032]=1;return erW(2146,9708)|0}function epA(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5665724+(b*112|0)>>2];c[a+104>>2]=c[5665728+(b*112|0)>>2];c[a+108>>2]=c[5665732+(b*112|0)>>2];d=0;return d|0}function epB(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=5665624+(b*112|0);e=0;return e|0}function epC(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>35){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6061176+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function epD(){var b=0,d=0,e=0,f=0;a[5689032]=1;b=erW(124,9708)|0;if((b|0)!=0){return b|0}d=gGq(524288)|0;e=c[2388126]|0;gGC(d|0,e|0,524288)|0;f=0;do{a[e+f|0]=a[d+(f>>>13<<16&65536|f&16654335|f>>>14<<15&32768|f>>>15<<14&16384|f>>>16<<13&8192)|0]|0;f=f+1|0;}while((f|0)<524288);gGr(d);return b|0}function epE(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2115060+(b*112|0)>>2];c[a+104>>2]=c[2115064+(b*112|0)>>2];c[a+108>>2]=c[2115068+(b*112|0)>>2];d=0;return d|0}function epF(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=2114960+(b*112|0);e=0;return e|0}function epG(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>32){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3278384+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function epH(){c[3528624]=0;c[3528622]=32896;c[2430448]=1;return erU(3132)|0}function epI(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2351484+(b*112|0)>>2];c[a+104>>2]=c[2351488+(b*112|0)>>2];c[a+108>>2]=c[2351492+(b*112|0)>>2];d=0;return d|0}function epJ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=2351384+(b*112|0);e=0;return e|0}function epK(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>35){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3531880+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function epL(){return erN(724)|0}function epM(){var b=0,d=0,e=0,f=0,g=0;Uw(0);Uw(1);c[3541206]=0;c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}if((c[2392]|0)>=0){b=0;do{d=14130368+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}d=14130384+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}b=b+1|0;}while((b|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;b=c[2414932]|0;d=0;while(1){if((d|0)>=1024){f=66746;break}g=9638528+(d<<2)|0;if((c[g>>2]|0)==(b|0)){break}else{d=d+1|0}}if((f|0)==66746){c[2414932]=0;c[3528622]=0;c[3528624]=0;a[668912]=0;a[2826944]=0;a[7325688]=0;a[5689032]=0;return 0}gGr(b);c[g>>2]=0;c[2414932]=0;c[3528622]=0;c[3528624]=0;a[668912]=0;a[2826944]=0;a[7325688]=0;a[5689032]=0;return 0}function epN(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if((a[9623960]|0)!=0){erQ()}d=(c[3528624]^65535)&65535;b[4774976]=d;e=(c[3528622]^65535)&65535;b[4774892]=e;f=0;g=d;d=e;do{g=((a[9633120+f|0]&1)<<f^g&65535)&65535;d=((a[9630992+f|0]&1)<<f^d&65535)&65535;f=f+1|0;}while((f|0)<16);b[4774976]=g;b[4774892]=d;if((c[2394]|0)==0){h=0}else{c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];h=0}do{c[2113056]=17857;d=RG(17857)|0;c[2113054]=(c[2113054]|0)+d;c[2276108]=-1;c[2113056]=-1;d=(h|0)==9;if((h|0)==9|(h|0)==4){c[8452200+(c[2394]<<2)>>2]=8193;c[2276080]=256;if((c[2276079]|0)>>>0<256){RH(1)}if(d){i=66760;break}}h=h+1|0;}while((h|0)<10);do{if((i|0)==66760){c[2113056]=0;h=RG(0)|0;c[2113054]=(c[2113054]|0)+h;c[2276108]=-1;c[2113056]=-1;c[8452200+(c[2394]<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0>=1024){break}RH(4)}}while(0);i=c[2112964]|0;if((i|0)!=0){h=a[9688]|0;gGz(i|0,0,(h?2136:0)|0);d=h?534:0;Uu(1,i,d);Uu(0,i,d)}d=c[2394]|0;i=c[14130368+(d<<2)>>2]|0;if((i|0)!=0){gGC(i|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;if((c[2112968]|0)==0){j=c[3529664]|0;k=c[2388254]|0;l=k+32768|0;gGC(j|0,l|0,4096)|0;return 0}d=c[(c[642608+(c[2436]<<2)>>2]|0)+112>>2]|0;if((d|0)==0){j=c[3529664]|0;k=c[2388254]|0;l=k+32768|0;gGC(j|0,l|0,4096)|0;return 0}gD[d&8191]()|0;j=c[3529664]|0;k=c[2388254]|0;l=k+32768|0;gGC(j|0,l|0,4096)|0;return 0}function epO(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;a[7325688]=1;b=c[2387164]|0;f=c[3529970]|0;g=0;do{h=e[b+(g<<1)>>1]|0;i=h>>>3;j=h>>>7&30;c[f+(g<<2)>>2]=h>>>1&1|h&61440|i&30|i<<11&2048|((j|h>>>2&1)<<3|j>>>2)<<3&2016;g=g+1|0;}while((g|0)<1024);g=c[2387982]|0;b=a[2826944]|0?8:16;j=c[2388456]|0;h=c[2439220]|0;i=c[2112926]|0;k=c[3530576]|0;l=c[3530812]|0;m=c[2113068]|0;n=c[2113070]|0;o=0;do{p=(o<<3&248)-b|0;q=((o>>5<<3)+72&504)-8|0;if((q|0)<(m|0)&(p|0)<(n|0)){r=e[g+(o<<1)>>1]|0;s=r&2047;t=(r&2048|0)!=0;if(t){u=(d[j]|0)<<11|s}else{u=s}Sj(i,h&u,q,p,r>>>12,4,0,t?k:l)}o=o+1|0;}while((o|0)<2048);ern(0,256,15,3);ern(0,256,15,2);ern(0,256,15,1);ern(0,256,15,0);if(!(a[5689032]|0)){R8(f);return 0}o=c[2112968]|0;if((n|0)<=1){R8(f);return 0}l=m<<1;k=-m|0;u=(n|0)/2|0;h=i;j=i+((ag(m,n-1|0)|0)<<1)|0;n=0;while(1){i=h;gGC(o|0,i|0,l)|0;g=j;gGC(i|0,g|0,l)|0;gGC(g|0,o|0,l)|0;g=n+1|0;if((g|0)<(u|0)){h=h+(m<<1)|0;j=j+(k<<1)|0;n=g}else{break}}R8(f);return 0}function epP(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1419316+(b*112|0)>>2];c[a+104>>2]=c[1419320+(b*112|0)>>2];c[a+108>>2]=c[1419324+(b*112|0)>>2];d=0;return d|0}function epQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=1419216+(b*112|0);e=0;return e|0}function epR(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5937396+(b*112|0)>>2];c[a+104>>2]=c[5937400+(b*112|0)>>2];c[a+108>>2]=c[5937404+(b*112|0)>>2];d=0;return d|0}function epS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=5937296+(b*112|0);e=0;return e|0}function epT(){return erN(1322)|0}function epU(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5941092+(b*112|0)>>2];c[a+104>>2]=c[5941096+(b*112|0)>>2];c[a+108>>2]=c[5941100+(b*112|0)>>2];d=0;return d|0}function epV(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=5940992+(b*112|0);e=0;return e|0}function epW(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>41){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6416216+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function epX(){return erN(4386)|0}function epY(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4806596+(b*112|0)>>2];c[a+104>>2]=c[4806600+(b*112|0)>>2];c[a+108>>2]=c[4806604+(b*112|0)>>2];d=0;return d|0}function epZ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=4806496+(b*112|0);e=0;return e|0}function ep_(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2501492+(b*112|0)>>2];c[a+104>>2]=c[2501496+(b*112|0)>>2];c[a+108>>2]=c[2501500+(b*112|0)>>2];d=0;return d|0}function ep$(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=2501392+(b*112|0);e=0;return e|0}function ep0(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>29){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3660096+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function ep1(){return erN(5098)|0}function ep2(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4526412+(b*112|0)>>2];c[a+104>>2]=c[4526416+(b*112|0)>>2];c[a+108>>2]=c[4526420+(b*112|0)>>2];d=0;return d|0}function ep3(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=4526312+(b*112|0);e=0;return e|0}function ep4(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>32){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5240352+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function ep5(){return ero(4776,1e7,0,1)|0}function ep6(){var b=0,d=0,e=0,f=0,g=0;b=c[3541518]|0;if((b|0)!=0){gGr(b|0);c[3541518]=0}if((c[2385508]|0)>0){c[2113008]=0;c[2076598]=0;c[2383582]=0}c[2438228]=0;c[2433526]=0;c[2406676]=0;c[3528472]=0;b=c[2406680]|0;if((b|0)!=0){gGr(b);c[2406680]=0}c[2385508]=0;c[2432978]=0;a[64240]=0;Uw(0);Uw(1);c[3541206]=0;c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}if((c[2392]|0)>=0){b=0;do{d=14130368+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}d=14130384+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}b=b+1|0;}while((b|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;b=c[2414932]|0;d=0;while(1){if((d|0)>=1024){f=66907;break}g=9638528+(d<<2)|0;if((c[g>>2]|0)==(b|0)){break}else{d=d+1|0}}if((f|0)==66907){c[2414932]=0;c[3528622]=0;c[3528624]=0;a[668912]=0;a[2826944]=0;a[7325688]=0;a[5689032]=0;return 0}gGr(b);c[g>>2]=0;c[2414932]=0;c[3528622]=0;c[3528624]=0;a[668912]=0;a[2826944]=0;a[7325688]=0;a[5689032]=0;return 0}function ep7(){var d=0,e=0,f=0,g=0,i=0,j=0;if((a[9623960]|0)!=0){d=c[2414634]|0;gGz(d|0,0,(c[2411604]|0)-d|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){d=0;do{lN(d);mB(d);d=d+1|0;}while((d|0)<(c[2385508]|0));f=(c[2394]|0)==0}else{f=0}c[2113156]=0;a[9628264]=0;c[2407033]=0;d=c[3541206]|0;gGz(c[2430118]|0,0,16384);c[2407041]=4;gGz(c[2430119]|0,0,16384);c[2407049]=4;gGz(c[2430120]|0,0,16384);c[2407057]=4;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2113157]=0;a[9628420]=0;c[2407072]=0;gGz(c[2430122]|0,0,16384);c[2407080]=4;gGz(c[2430123]|0,0,16384);c[2407088]=4;gGz(c[2430124]|0,0,16384);c[2407096]=4;gGz(c[2430125]|0,0,16384);c[2407104]=4;e=(c[3529708]|0)-(c[3529752]|0)|0;c[3541190]=d;c[3541198]=d;c[3541191]=d+256;c[3541199]=d+65536;c[3541192]=d+512;c[3541200]=d+131072;c[3541193]=d+768;c[3541201]=d+196608;g=d+e|0;c[3541194]=g;c[3541202]=g;c[3541195]=d+(e+256);c[3541203]=d+(e+65536);c[3541196]=d+(e+512);c[3541204]=d+(e+131072);c[3541197]=d+(e+768);c[3541205]=d+(e+196608);if(!f){c[2394]=0;c[2112932]=c[3532596];f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060]}d18();f=c[2394]|0;e=c[14130368+(f<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(f<<2)>>2]=c[2113054];c[2394]=-1}f=(c[3528624]^65535)&65535;b[4774976]=f;e=(c[3528622]^65535)&65535;b[4774892]=e;d=0;g=f;f=e;do{g=((a[9633120+d|0]&1)<<d^g&65535)&65535;f=((a[9630992+d|0]&1)<<d^f&65535)&65535;d=d+1|0;}while((d|0)<16);b[4774976]=g;b[4774892]=f;f=c[2392]|0;if((f|0)>=0){gGz(8452240,0,((f|0)>0?(f<<2)+4|0:4)|0)}c[2113054]=0;f=c[2433556]|0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060]}g=(f>>>0)/11200|0;d=0;while(1){e=d+1|0;Sb(ag(e,g)|0);i=(d|0)==199;do{if((d|0)==199|(d|0)==99){c[8452200+(c[2394]<<2)>>2]=8193;c[2276080]=256;if((c[2276079]|0)>>>0<256){RH(1)}do{if((d|0)==99&(c[2430448]|0)!=0){c[2113056]=0;j=RG(0)|0;c[2113054]=(c[2113054]|0)+j;c[2276108]=-1;c[2113056]=-1;c[8452200+(c[2394]<<2)>>2]=8194;c[2276080]=512;if((c[2276079]|0)>>>0>=512){break}RH(2)}}while(0);if(!i){break}c[2113056]=0;j=RG(0)|0;c[2113054]=(c[2113054]|0)+j;c[2276108]=-1;c[2113056]=-1;c[8452200+(c[2394]<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0>=1024){break}RH(4)}}while(0);if((e|0)<200){d=e}else{break}}d=(f>>>0)/56|0;f=gGU(d,0,2048e6,0)|0;g=c[2438228]|0;i=gGS(f,K,g,(g|0)<0|0?-1:0)|0;g=i;Sb(d);d=c[2443830]|0;if((d|0)<1073676288){c[2443830]=d-g}d=c[2443831]|0;if((d|0)<1073676288){c[2443831]=d-g}d=(c[3528512]|0)-g|0;c[3528512]=(d|0)<0?0:d;d=c[2112964]|0;if((d|0)!=0){gg[c[3542122]&4095](d,a[9688]|0?534:0);d=c[2112964]|0;g=a[9688]|0?534:0;Uu(0,d,g);Uu(1,d,g)}g=c[2394]|0;d=c[14130368+(g<<2)>>2]|0;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[8452240+(g<<2)>>2]=c[2113054];c[2394]=-1;do{if((c[2112968]|0)!=0){g=c[(c[642608+(c[2436]<<2)>>2]|0)+112>>2]|0;if((g|0)==0){break}gD[g&8191]()|0}}while(0);g=(dW(c[c[642608+(c[2436]<<2)>>2]>>2]|0,526360,6)|0)==0;d=c[3529664]|0;i=c[2388254]|0;if(g){g=i+61440|0;gGC(d|0,g|0,4096)|0;return 0}else{g=i+32768|0;gGC(d|0,g|0,4096)|0;return 0}return 0}function ep8(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2539340+(b*112|0)>>2];c[a+104>>2]=c[2539344+(b*112|0)>>2];c[a+108>>2]=c[2539348+(b*112|0)>>2];d=0;return d|0}function ep9(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=2539240+(b*112|0);e=0;return e|0}function eqa(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2540572+(b*112|0)>>2];c[a+104>>2]=c[2540576+(b*112|0)>>2];c[a+108>>2]=c[2540580+(b*112|0)>>2];d=0;return d|0}function eqb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=2540472+(b*112|0);e=0;return e|0}function eqc(){return erG(1278,1)|0}function eqd(){var b=0,d=0,e=0,f=0,g=0;c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}TE();if((c[2392]|0)>=0){b=0;do{d=14130368+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}d=14130384+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}b=b+1|0;}while((b|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;b=c[2414932]|0;d=0;while(1){if((d|0)>=1024){f=66999;break}g=9638528+(d<<2)|0;if((c[g>>2]|0)==(b|0)){break}else{d=d+1|0}}if((f|0)==66999){c[2414932]=0;c[3528622]=0;c[3528624]=0;a[668912]=0;a[2826944]=0;a[7325688]=0;return 0}gGr(b);c[g>>2]=0;c[2414932]=0;c[3528622]=0;c[3528624]=0;a[668912]=0;a[2826944]=0;a[7325688]=0;return 0}function eqe(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;if((a[9623960]|0)!=0){d=c[2414634]|0;gGz(d|0,0,(c[2411604]|0)-d|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;Ty();d=(c[3529708]|0)-(c[3529752]|0)|0;e=c[3541206]|0;c[3541190]=e;c[3541198]=e;c[3541191]=e+256;c[3541199]=e+65536;c[3541192]=e+512;c[3541200]=e+131072;c[3541193]=e+768;c[3541201]=e+196608;f=e+d|0;c[3541194]=f;c[3541202]=f;c[3541195]=e+(d+256);c[3541203]=e+(d+65536);c[3541196]=e+(d+512);c[3541204]=e+(d+131072);c[3541197]=e+(d+768);c[3541205]=e+(d+196608)}d=c[2385548]|0;if((d|0)>0){gGz(9752472,0,((d|0)>1?d<<2:4)|0)}c[2433530]=0;d=(c[3528624]^65535)&65535;b[4774976]=d;e=(c[3528622]^65535)&65535;b[4774892]=e;f=0;g=d;d=e;do{g=((a[9633120+f|0]&1)<<f^g&65535)&65535;d=((a[9630992+f|0]&1)<<f^d&65535)&65535;f=f+1|0;}while((f|0)<16);b[4774976]=g;b[4774892]=d;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}d=c[2439330]|0;if((d|0)!=0){g=d;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;g=0;do{c[2113056]=1785;d=RG(1785)|0;c[2113054]=(c[2113054]|0)+d;c[2276108]=-1;c[2113056]=-1;do{if((g|0)==99|(g|0)==49){c[8452200+(c[2394]<<2)>>2]=8193;c[2276080]=256;if((c[2276079]|0)>>>0<256){RH(1)}if((g|0)==49){c[2113056]=0;d=RG(0)|0;c[2113054]=(c[2113054]|0)+d;c[2276108]=-1;c[2113056]=-1;c[8452200+(c[2394]<<2)>>2]=8194;c[2276080]=512;if((c[2276079]|0)>>>0>=512){break}RH(2);break}else if((g|0)==99){c[2113056]=0;d=RG(0)|0;c[2113054]=(c[2113054]|0)+d;c[2276108]=-1;c[2113056]=-1;c[8452200+(c[2394]<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0>=1024){break}RH(4);break}else{break}}}while(0);UF(g*639|0)|0;g=g+1|0;}while((g|0)<100);g=c[2438224]|0;d=gGS(1851785216,30479,g,(g|0)<0|0?-1:0)|0;g=d;UF(63920)|0;d=c[2443826]|0;if((d|0)<1073676288){c[2443826]=d-g}d=c[2443827]|0;if((d|0)<1073676288){c[2443827]=d-g}d=(c[3528508]|0)-g|0;c[3528508]=(d|0)<0?0:d;d=c[2112964]|0;if((d|0)!=0){g=a[9688]|0?534:0;f=c[2438058]&3;if((f|0)==0){gg[c[3542112]&4095](d,g)}else if((f|0)==1){gg[c[3542124]&4095](d,g)}else if((f|0)==2){gg[c[3542122]&4095](d,g)}if((c[2438058]&4|0)!=0){Uu(1,d,g)}Uu(0,d,g)}g=c[1836236]|0;d=c[9757320+(g<<2)>>2]|0;if((d|0)!=0){f=d;gGC(f|0,9706056,76)|0}c[9752472+(g<<2)>>2]=c[2433530];c[14113936+(g<<2)>>2]=c[2076596];c[9669104+(g<<2)>>2]=c[3541536];c[1836236]=-1;g=c[2394]|0;f=c[14130368+(g<<2)>>2]|0;if((f|0)!=0){gGC(f|0,9104152,280)|0}c[8452240+(g<<2)>>2]=c[2113054];c[2394]=-1;if((c[2112968]|0)==0){h=c[3529664]|0;i=c[2388254]|0;j=i+32768|0;gGC(h|0,j|0,4096)|0;return 0}g=c[(c[642608+(c[2436]<<2)>>2]|0)+112>>2]|0;if((g|0)==0){h=c[3529664]|0;i=c[2388254]|0;j=i+32768|0;gGC(h|0,j|0,4096)|0;return 0}gD[g&8191]()|0;h=c[3529664]|0;i=c[2388254]|0;j=i+32768|0;gGC(h|0,j|0,4096)|0;return 0}function eqf(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1454436+(b*112|0)>>2];c[a+104>>2]=c[1454440+(b*112|0)>>2];c[a+108>>2]=c[1454444+(b*112|0)>>2];d=0;return d|0}function eqg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=1454336+(b*112|0);e=0;return e|0}function eqh(){return erG(5118,1)|0}function eqi(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4368380+(b*112|0)>>2];c[a+104>>2]=c[4368384+(b*112|0)>>2];c[a+108>>2]=c[4368388+(b*112|0)>>2];d=0;return d|0}function eqj(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=4368280+(b*112|0);e=0;return e|0}function eqk(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>32){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4936112+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eql(){return ero(4076,8e6,0,1)|0}function eqm(){var b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[2433556]|0)==1e7){erI(0)}else{erI(1)}b=c[2443470]|0;d=e[b>>1]|0;f=e[b+2>>1]|0;g=e[b+4>>1]|0;h=e[b+6>>1]|0;b=c[2387164]|0;i=c[3529970]|0;j=0;do{k=e[b+(j<<1)>>1]|0;l=k>>>3;m=k>>>7&30;c[i+(j<<2)>>2]=k>>>1&1|k&61440|l&30|l<<11&2048|((m|k>>>2&1)<<3|m>>>2)<<3&2016;j=j+1|0;}while((j|0)<1024);erv(c[2387982]|0,d<<8&3840|f&255,g<<8&256|h&255,0,0);ern(0,256,15,3);ern(0,256,15,2);ern(0,256,15,1);ern(0,256,15,0);if((c[2439222]|0)!=0){h=c[2405794]|0;g=a[2826944]|0?0:248;f=c[2112926]|0;d=c[3530812]|0;j=c[2113068]|0;b=c[2113070]|0;m=0;do{k=((m>>5<<3)+8&248)-8|0;l=((m<<3)+g&255)-8|0;if((k|0)<(j|0)&(l|0)<(b|0)){n=e[h+(m<<1)>>1]|0;Sr(f,n&4095,k,l,n>>>12,4,15,512,d)}m=m+1|0;}while((m|0)<1024)}if(!(a[5689032]|0)){R8(i);return 0}m=c[2112968]|0;d=c[2112926]|0;f=c[2113070]|0;if((f|0)<=1){R8(i);return 0}h=c[2113068]|0;b=h<<1;j=-h|0;g=(f|0)/2|0;n=d;l=d+((ag(h,f-1|0)|0)<<1)|0;f=0;while(1){d=n;gGC(m|0,d|0,b)|0;k=l;gGC(d|0,k|0,b)|0;gGC(k|0,m|0,b)|0;k=f+1|0;if((k|0)<(g|0)){n=n+(h<<1)|0;l=l+(j<<1)|0;f=k}else{break}}R8(i);return 0}function eqn(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2176052+(b*112|0)>>2];c[a+104>>2]=c[2176056+(b*112|0)>>2];c[a+108>>2]=c[2176060+(b*112|0)>>2];d=0;return d|0}function eqo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=2175952+(b*112|0);e=0;return e|0}function eqp(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2173924+(b*112|0)>>2];c[a+104>>2]=c[2173928+(b*112|0)>>2];c[a+108>>2]=c[2173932+(b*112|0)>>2];d=0;return d|0}function eqq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=2173824+(b*112|0);e=0;return e|0}function eqr(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>32){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3324136+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eqs(){return erG(4108,0)|0}function eqt(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3185900+(b*112|0)>>2];c[a+104>>2]=c[3185904+(b*112|0)>>2];c[a+108>>2]=c[3185908+(b*112|0)>>2];d=0;return d|0}function equ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=3185800+(b*112|0);e=0;return e|0}function eqv(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1326984+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eqw(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>43){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4301088+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eqx(){return ero(4004,1e7,0,1)|0}function eqy(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4565532+(b*112|0)>>2];c[a+104>>2]=c[4565536+(b*112|0)>>2];c[a+108>>2]=c[4565540+(b*112|0)>>2];d=0;return d|0}function eqz(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=4565432+(b*112|0);e=0;return e|0}function eqA(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>54){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5298312+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eqB(){return ero(236,1e7,0,0)|0}function eqC(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4682220+(b*112|0)>>2];c[a+104>>2]=c[4682224+(b*112|0)>>2];c[a+108>>2]=c[4682228+(b*112|0)>>2];d=0;return d|0}function eqD(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=4682120+(b*112|0);e=0;return e|0}function eqE(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>30){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5369184+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eqF(){return ero(4252,12e6,0,0)|0}function eqG(){var b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[2387164]|0;d=c[3529970]|0;f=0;do{g=e[b+(f<<1)>>1]|0;h=g>>>3;i=g>>>7&30;c[d+(f<<2)>>2]=g>>>1&1|g&61440|h&30|h<<11&2048|((i|g>>>2&1)<<3|i>>>2)<<3&2016;f=f+1|0;}while((f|0)<1024);a[7325688]=1;f=(e[c[2443470]>>1]|0)>>>8&48;if((f|0)==16|(f|0)==32|(f|0)==48){b=c[2112926]|0;gGz(b|0,0,ag(c[2443814]<<1,c[2440436]|0)|0)}else if((f|0)==0){erm(c[2387982]|0)}ern(0,256,15,3);ern(0,256,15,2);ern(0,256,15,1);ern(0,256,15,0);if((c[2439222]|0)!=0){f=c[2405794]|0;b=a[2826944]|0?0:248;i=c[2112926]|0;g=c[3530812]|0;h=c[2113068]|0;j=c[2113070]|0;k=0;do{l=((k>>5<<3)+72&504)-8|0;m=((k<<3)+b&255)-8|0;if((l|0)<(h|0)&(m|0)<(j|0)){n=e[f+(k<<1)>>1]|0;Sr(i,n&4095,l,m,n>>>12,4,15,512,g)}k=k+1|0;}while((k|0)<2048)}if(!(a[5689032]|0)){R8(d);return 0}k=c[2112968]|0;g=c[2112926]|0;i=c[2113070]|0;if((i|0)<=1){R8(d);return 0}f=c[2113068]|0;j=f<<1;h=-f|0;b=(i|0)/2|0;n=g;m=g+((ag(f,i-1|0)|0)<<1)|0;i=0;while(1){g=n;gGC(k|0,g|0,j)|0;l=m;gGC(g|0,l|0,j)|0;gGC(l|0,k|0,j)|0;l=i+1|0;if((l|0)<(b|0)){n=n+(f<<1)|0;m=m+(h<<1)|0;i=l}else{break}}R8(d);return 0}function eqH(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3069860+(b*112|0)>>2];c[a+104>>2]=c[3069864+(b*112|0)>>2];c[a+108>>2]=c[3069868+(b*112|0)>>2];d=0;return d|0}function eqI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=3069760+(b*112|0);e=0;return e|0}function eqJ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>35){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4238712+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eqK(){return ero(2496,8e6,0,0)|0}function eqL(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1612700+(b*112|0)>>2];c[a+104>>2]=c[1612704+(b*112|0)>>2];c[a+108>>2]=c[1612708+(b*112|0)>>2];d=0;return d|0}function eqM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=1612600+(b*112|0);e=0;return e|0}function eqN(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4333572+(b*112|0)>>2];c[a+104>>2]=c[4333576+(b*112|0)>>2];c[a+108>>2]=c[4333580+(b*112|0)>>2];d=0;return d|0}function eqO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=4333472+(b*112|0);e=0;return e|0}function eqP(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>33){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4898784+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eqQ(){return ero(2152,1e7,0,1)|0}function eqR(){var b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[2443470]|0;d=e[b>>1]|0;f=e[b+2>>1]|0;g=e[b+4>>1]|0;h=e[b+6>>1]|0;b=c[2387164]|0;i=c[3529970]|0;j=0;do{k=e[b+(j<<1)>>1]|0;l=k>>>3;m=k>>>7&30;c[i+(j<<2)>>2]=k>>>1&1|k&61440|l&30|l<<11&2048|((m|k>>>2&1)<<3|m>>>2)<<3&2016;j=j+1|0;}while((j|0)<1024);erv(c[2387982]|0,d<<8&3840|f>>>8,g<<8&256|h>>>8,0,0);ern(0,256,15,3);ern(0,256,15,2);ern(0,256,15,1);ern(0,256,15,0);if((c[2439222]|0)!=0){h=c[2405794]|0;g=a[2826944]|0?0:248;f=c[2112926]|0;d=c[3530812]|0;j=c[2113068]|0;b=c[2113070]|0;m=0;do{k=((m>>5<<3)+8&248)-8|0;l=((m<<3)+g&255)-8|0;if((k|0)<(j|0)&(l|0)<(b|0)){n=e[h+(m<<1)>>1]|0;Sr(f,n&4095,k,l,n>>>12,4,15,512,d)}m=m+1|0;}while((m|0)<1024)}if(!(a[5689032]|0)){R8(i);return 0}m=c[2112968]|0;d=c[2112926]|0;f=c[2113070]|0;if((f|0)<=1){R8(i);return 0}h=c[2113068]|0;b=h<<1;j=-h|0;g=(f|0)/2|0;n=d;l=d+((ag(h,f-1|0)|0)<<1)|0;f=0;while(1){d=n;gGC(m|0,d|0,b)|0;k=l;gGC(d|0,k|0,b)|0;gGC(k|0,m|0,b)|0;k=f+1|0;if((k|0)<(g|0)){n=n+(h<<1)|0;l=l+(j<<1)|0;f=k}else{break}}R8(i);return 0}function eqS(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[997316+(b*112|0)>>2];c[a+104>>2]=c[997320+(b*112|0)>>2];c[a+108>>2]=c[997324+(b*112|0)>>2];d=0;return d|0}function eqT(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=997216+(b*112|0);e=0;return e|0}function eqU(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[823220+(b*112|0)>>2];c[a+104>>2]=c[823224+(b*112|0)>>2];c[a+108>>2]=c[823228+(b*112|0)>>2];d=0;return d|0}function eqV(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=823120+(b*112|0);e=0;return e|0}function eqW(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2101324+(b*112|0)>>2];c[a+104>>2]=c[2101328+(b*112|0)>>2];c[a+108>>2]=c[2101332+(b*112|0)>>2];d=0;return d|0}function eqX(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=2101224+(b*112|0);e=0;return e|0}function eqY(){c[3528624]=64;return ero(2008,1e7,0,1)|0}function eqZ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4677292+(b*112|0)>>2];c[a+104>>2]=c[4677296+(b*112|0)>>2];c[a+108>>2]=c[4677300+(b*112|0)>>2];d=0;return d|0}function eq_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=4677192+(b*112|0);e=0;return e|0}function eq$(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>35){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5368752+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eq0(){return ero(1402,1e7,0,0)|0}function eq1(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5663708+(b*112|0)>>2];c[a+104>>2]=c[5663712+(b*112|0)>>2];c[a+108>>2]=c[5663716+(b*112|0)>>2];d=0;return d|0}function eq2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=5663608+(b*112|0);e=0;return e|0}function eq3(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>40){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6040464+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eq4(){return ero(3216,12e6,0,1)|0}function eq5(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=c[2387164]|0;f=c[3529970]|0;g=0;do{h=e[d+(g<<1)>>1]|0;i=h>>>3;j=h>>>7&30;c[f+(g<<2)>>2]=h>>>1&1|h&61440|i&30|i<<11&2048|((j|h>>>2&1)<<3|j>>>2)<<3&2016;g=g+1|0;}while((g|0)<1024);g=c[2443470]|0;d=(e[g+1024>>1]|0)<<8&3840|b[g+1026>>1]&255;j=(e[g+1028>>1]|0)<<8&256|b[g+1030>>1]&255;erv(c[2387982]|0,(e[g>>1]|0)<<8&3840|b[g+2>>1]&255,(e[g+4>>1]|0)<<8&256|b[g+6>>1]&255,768,0);g=c[2388456]|0;h=a[g]|0;a[g]=1;erv(c[2387978]|0,d,j,512,1);a[g]=h;ern(0,256,15,3);ern(0,256,15,2);ern(0,256,15,1);ern(0,256,15,0);if((c[2439222]|0)!=0){h=c[2405794]|0;g=a[2826944]|0?0:248;j=c[2112926]|0;d=c[3530812]|0;i=c[2113068]|0;k=c[2113070]|0;l=0;do{m=((l>>5<<3)+8&248)-8|0;n=((l<<3)+g&255)-8|0;if((m|0)<(i|0)&(n|0)<(k|0)){o=e[h+(l<<1)>>1]|0;Sr(j,o&4095,m,n,o>>>12,4,15,512,d)}l=l+1|0;}while((l|0)<1024)}if(!(a[5689032]|0)){R8(f);return 0}l=c[2112968]|0;d=c[2112926]|0;j=c[2113070]|0;if((j|0)<=1){R8(f);return 0}h=c[2113068]|0;k=h<<1;i=-h|0;g=(j|0)/2|0;o=d;n=d+((ag(h,j-1|0)|0)<<1)|0;j=0;while(1){d=o;gGC(l|0,d|0,k)|0;m=n;gGC(d|0,m|0,k)|0;gGC(m|0,l|0,k)|0;m=j+1|0;if((m|0)<(g|0)){o=o+(h<<1)|0;n=n+(i<<1)|0;j=m}else{break}}R8(f);return 0}function eq6(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4380028+(b*112|0)>>2];c[a+104>>2]=c[4380032+(b*112|0)>>2];c[a+108>>2]=c[4380036+(b*112|0)>>2];d=0;return d|0}function eq7(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=4379928+(b*112|0);e=0;return e|0}function eq8(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4807604+(b*112|0)>>2];c[a+104>>2]=c[4807608+(b*112|0)>>2];c[a+108>>2]=c[4807612+(b*112|0)>>2];d=0;return d|0}function eq9(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=4807504+(b*112|0);e=0;return e|0}function era(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>35){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5572360+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function erb(){return ero(2052,1e7,1,1)|0}function erc(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=c[2387164]|0;g=c[3529970]|0;h=0;do{i=e[f+(h<<1)>>1]|0;j=i>>>3;k=i>>>7&30;c[g+(h<<2)>>2]=i>>>1&1|i&61440|j&30|j<<11&2048|((k|i>>>2&1)<<3|k>>>2)<<3&2016;h=h+1|0;}while((h|0)<1024);h=c[2443470]|0;f=(e[h+6>>1]|0)>>>8|b[h+4>>1]&256;k=(e[h+2>>1]|0)>>>8|b[h>>1]&3840;h=a[2826944]|0;i=c[2388456]|0;j=(d[i]|0)<<13;l=c[3529500]|0;m=16-f+(h?-8:-16)|0;n=c[2112926]|0;o=(c[3530576]|0)+1048576|0;p=c[2113068]|0;q=0;do{r=((q+16&4080)-k&4095)-16|0;do{if((r|0)<(p|0)){s=q|j;t=e[l+(s<<1)>>1]|0;u=m+(q<<4&240)|0;v=(u&511)-16|0;w=c[2113070]|0;if((v|0)<(w|0)){Sz(n,t&4095,r,v,t>>>12,4,0,o)}t=e[l+((s|4096)<<1)>>1]|0;s=(u+256&511)-16|0;if((s|0)>=(w|0)){break}Sz(n,t&4095,r,s,t>>>12,4,0,o)}}while(0);q=q+1|0;}while((q|0)<4096);q=a[i]|0;a[i]=0;erv(c[2387982]|0,k,f,256,1);a[i]=q;ern(0,512,15,3);ern(0,512,15,2);ern(0,512,15,1);ern(0,512,15,0);if((c[2439222]|0)!=0){q=c[2405794]|0;i=h?0:248;h=c[3530812]|0;f=c[2113070]|0;k=0;do{o=((k>>5<<3)+8&248)-8|0;l=((k<<3)+i&255)-8|0;if((o|0)<(p|0)&(l|0)<(f|0)){m=e[q+(k<<1)>>1]|0;Sr(n,m&4095,o,l,m>>>12,4,15,768,h)}k=k+1|0;}while((k|0)<1024)}if(!(a[5689032]|0)){R8(g);return 0}k=c[2112968]|0;h=c[2113070]|0;if((h|0)<=1){R8(g);return 0}q=p<<1;f=-p|0;i=(h|0)/2|0;m=n;l=n+((ag(p,h-1|0)|0)<<1)|0;h=0;while(1){n=m;gGC(k|0,n|0,q)|0;o=l;gGC(n|0,o|0,q)|0;gGC(o|0,k|0,q)|0;o=h+1|0;if((o|0)<(i|0)){m=m+(p<<1)|0;l=l+(f<<1)|0;h=o}else{break}}R8(g);return 0}function erd(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4424268+(b*112|0)>>2];c[a+104>>2]=c[4424272+(b*112|0)>>2];c[a+108>>2]=c[4424276+(b*112|0)>>2];d=0;return d|0}function ere(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=4424168+(b*112|0);e=0;return e|0}function erf(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4448212+(b*112|0)>>2];c[a+104>>2]=c[4448216+(b*112|0)>>2];c[a+108>>2]=c[4448220+(b*112|0)>>2];d=0;return d|0}function erg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=4448112+(b*112|0);e=0;return e|0}function erh(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>38){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5113832+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function eri(){return ero(3210,14e6,0,0)|0}function erj(){var b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[2387164]|0;d=c[3529970]|0;f=0;do{g=e[b+(f<<1)>>1]|0;h=g>>>3;i=g>>>7&30;c[d+(f<<2)>>2]=g>>>1&1|g&61440|h&30|h<<11&2048|((i|g>>>2&1)<<3|i>>>2)<<3&2016;f=f+1|0;}while((f|0)<1024);a[7325688]=1;f=(e[c[2443470]>>1]|0)>>>8&48;if((f|0)==0){erm(c[2387982]|0)}else if((f|0)==48){erm(c[2387968]|0)}else if((f|0)==32){erm(c[2387972]|0)}else if((f|0)==16){erm(c[2387978]|0)}ern(0,256,31,3);ern(0,256,31,2);ern(0,256,31,1);ern(0,256,31,0);if((c[2439222]|0)!=0){f=c[2405794]|0;b=a[2826944]|0?0:248;i=c[2112926]|0;g=c[3530812]|0;h=c[2113068]|0;j=c[2113070]|0;k=0;do{l=((k>>5<<3)+72&504)-8|0;m=((k<<3)+b&255)-8|0;if((l|0)<(h|0)&(m|0)<(j|0)){n=e[f+(k<<1)>>1]|0;Sr(i,n&4095,l,m,n>>>12,4,15,768,g)}k=k+1|0;}while((k|0)<2048)}if(!(a[5689032]|0)){R8(d);return 0}k=c[2112968]|0;g=c[2112926]|0;i=c[2113070]|0;if((i|0)<=1){R8(d);return 0}f=c[2113068]|0;j=f<<1;h=-f|0;b=(i|0)/2|0;n=g;m=g+((ag(f,i-1|0)|0)<<1)|0;i=0;while(1){g=n;gGC(k|0,g|0,j)|0;l=m;gGC(g|0,l|0,j)|0;gGC(l|0,k|0,j)|0;l=i+1|0;if((l|0)<(b|0)){n=n+(f<<1)|0;m=m+(h<<1)|0;i=l}else{break}}R8(d);return 0}function erk(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4833588+(b*112|0)>>2];c[a+104>>2]=c[4833592+(b*112|0)>>2];c[a+108>>2]=c[4833596+(b*112|0)>>2];d=0;return d|0}function erl(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=4833488+(b*112|0);e=0;return e|0}function erm(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;g=(d[c[2388456]|0]|0)<<12&c[2439220];h=f;f=c[2443470]|0;i=f;j=c[2113070]|0;if((j|0)<=0){return}k=f+512|0;f=c[2113068]|0;l=a[7325688]|0?-64:0;m=c[2112926]|0;n=c[3530576]|0;o=f+16|0;p=16;do{q=(e[k>>1]|0)+p+(e[i+((p|256)<<1)>>1]|0)|0;r=q<<4&240;s=q>>>8<<12&4096|q>>>4&15;q=ag(p-16|0,f)|0;if((f+16|0)>0){t=(e[i>>1]|0)+l+(e[i+(p<<1)>>1]|0)|0;u=0;do{v=t+u|0;w=b[h+((s|v&4080)<<1)>>1]|0;x=(w&65535)>>>12<<4;y=(w&4095|g)<<8|r;w=u-(v&15)|0;v=0;while(1){if((w|0)>-1&(w|0)<(f|0)){b[m+(w+q<<1)>>1]=d[n+(v+y)|0]|0|x}z=v+1|0;if((z|0)>=16){break}w=w+1|0;v=z}u=u+16|0;}while((u|0)<(o|0))}p=p+1|0;}while((p|0)<(j+16|0));return}function ern(d,f,g,h){d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;i=c[3529664]|0;j=(d|0)==0;d=a[7325688]|0?64:0;k=c[2439218]|0;l=c[3528686]|0;m=a[2826944]|0?8:16;n=c[2112926]|0;o=c[3530416]|0;p=0;do{q=e[i+(p<<1)>>1]|0;do{if((q&1|0)!=0){r=(b[i+((p|4)<<1)>>1]&511)+d|0;s=b[i+((p|6)<<1)>>1]&511;t=(e[i+((p|3)<<1)>>1]|0)&k;u=e[i+((p|1)<<1)>>1]|0;v=u&15;w=u>>>4&15;x=j?0:u>>>9&1;y=j?0:u>>>8&1;u=(((e[i+((p|7)<<1)>>1]|0)&g)<<4)+f|0;if((q>>>6&3|0)!=(h|0)){break}z=a[l]|0;if(z<<24>>24==0){A=r;B=16;C=y;D=x;E=s}else{F=z&255;A=368-r|0;B=-16;C=F^y;D=F^x;E=240-s|0}s=(D|0)!=0;if(s){G=ag(B,w)|0}else{G=0}x=(C|0)!=0;F=ag(B,v)|0;y=ag(x?-1:1,B)|0;r=(x?F:0)+A|0;F=w;w=G+E|0;z=t;while(1){t=(w&511)-m|0;L89430:do{if(s){H=v;I=r;J=z;while(1){K=(I+16&511)-16|0;if(x){SN(n,J,K,t,u,0,15,0,o)}else{SL(n,J,K,t,u,0,15,0,o)}K=k&J+1;if((H|0)<=0){L=K;break L89430}H=H-1|0;I=I+y|0;J=K}}else{J=v;I=r;H=z;while(1){K=(I+16&511)-16|0;if(x){SJ(n,H,K,t,u,0,15,0,o)}else{SH(n,H,K,t,u,0,15,0,o)}K=k&H+1;if((J|0)<=0){L=K;break L89430}J=J-1|0;I=I+y|0;H=K}}}while(0);if((F|0)>0){F=F-1|0;w=w+y|0;z=L}else{break}}}}while(0);p=p+8|0;}while((p|0)<2048);return}function ero(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;c[2414932]=0;err();g=c[2414144]|0;i=0;while(1){if((i|0)>=1024){break}j=9638528+(i<<2)|0;if((c[j>>2]|0)==0){k=67536;break}else{i=i+1|0}}do{if((k|0)==67536){i=gGq(g)|0;c[j>>2]=i;if((i|0)==0){break}gGz(i|0,0,g|0);c[2414932]=i;gGz(i|0,0,g|0);err();c[2433556]=d;c[2430448]=f;if((b|0)!=0){gD[b&8191]()|0}c[2424]=5600;Vr(1,15e5,1232,824,100,0);i=c[2433556]|0;c[2438228]=i;c[2433526]=3248;c[2406676]=148;c[3528472]=444;l=gGS(2048e6,0,i,(i|0)<0|0?-1:0)|0;i=gGK(l,K,-1,0)|0;c[2443846]=i;h[745419]=2.0;a[3203368]=1;h[745418]=.5;a[3203360]=1;h[745417]=.5;a[3203352]=1;h[745416]=.5;a[3203344]=1;i=4e6/(((e|0)!=0?132:165)>>>0)|0;Ux(0,i,1);Ux(1,i,1);c[2407030]=51;c[2407068]=3;c[2407069]=51;c[2407107]=3;c[3541154]=c[3529752];c[3541152]=c[3529708];c[3541150]=c[2385902];i=c[642608+(c[2436]<<2)>>2]|0;l=c[i+128>>2]|0;if((c[i+52>>2]&4|0)==0){c[2113068]=l;m=c[i+132>>2]|0;c[2113070]=m;c[2443814]=l;c[2440436]=m;n=l;o=m}else{c[2113070]=l;m=c[i+132>>2]|0;c[2113068]=m;c[2440436]=l;c[2443814]=m;n=m;o=l}l=ag(n<<1,o)|0;m=gGq(l)|0;c[2112926]=m;if((m|0)!=0){gGz(m|0,0,l|0)}l=c[2414634]|0;gGz(l|0,0,(c[2411604]|0)-l|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];l=c[3532592]|0;if((l|0)!=0){gGC(9104152,l|0,280)|0}c[2113054]=c[2113060]}RI();l=c[2394]|0;m=c[14130368+(l<<2)>>2]|0;if((m|0)!=0){gGC(m|0,9104152,280)|0}c[8452240+(l<<2)>>2]=c[2113054];c[2394]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){l=0;do{lN(l);mB(l);l=l+1|0;}while((l|0)<(c[2385508]|0));p=(c[2394]|0)==0}else{p=0}c[2113156]=0;a[9628264]=0;c[2407033]=0;l=c[3541206]|0;gGz(c[2430118]|0,0,16384);c[2407041]=4;gGz(c[2430119]|0,0,16384);c[2407049]=4;gGz(c[2430120]|0,0,16384);c[2407057]=4;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2113157]=0;a[9628420]=0;c[2407072]=0;gGz(c[2430122]|0,0,16384);c[2407080]=4;gGz(c[2430123]|0,0,16384);c[2407088]=4;gGz(c[2430124]|0,0,16384);c[2407096]=4;gGz(c[2430125]|0,0,16384);c[2407104]=4;m=(c[3529708]|0)-(c[3529752]|0)|0;c[3541190]=l;c[3541198]=l;c[3541191]=l+256;c[3541199]=l+65536;c[3541192]=l+512;c[3541200]=l+131072;c[3541193]=l+768;c[3541201]=l+196608;i=l+m|0;c[3541194]=i;c[3541202]=i;c[3541195]=l+(m+256);c[3541203]=l+(m+65536);c[3541196]=l+(m+512);c[3541204]=l+(m+131072);c[3541197]=l+(m+768);c[3541205]=l+(m+196608);if(!p){c[2394]=0;c[2112932]=c[3532596];m=c[3532592]|0;if((m|0)!=0){gGC(9104152,m|0,280)|0}c[2113054]=c[2113060]}d18();m=c[2394]|0;l=c[14130368+(m<<2)>>2]|0;if((l|0)!=0){gGC(l|0,9104152,280)|0}c[8452240+(m<<2)>>2]=c[2113054];c[2394]=-1;q=0;return q|0}}while(0);c[2414932]=0;q=1;return q|0}function erp(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;b=i;i=i+1440|0;d=b|0;e=b+112|0;f=b+120|0;g=b+232|0;h=b+240|0;j=b+352|0;k=b+360|0;l=b+472|0;m=b+480|0;n=b+592|0;o=b+600|0;p=b+712|0;q=b+720|0;r=b+832|0;s=b+840|0;t=b+952|0;u=b+960|0;v=b+1072|0;w=b+1080|0;x=b+1192|0;y=b+1200|0;z=b+1312|0;A=b+1320|0;B=b+1432|0;C=c[2388126]|0;if((c[3542200]|0)==0){D=1;i=b;return D|0}E=A+108|0;c[E>>2]=0;F=A+100|0;c[F>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](A,0)|0;do{if((c[E>>2]|0)!=0){A=c[F>>2]|0;c[B>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](B,0,0)|0;if((A|0)<1){D=1;i=b;return D|0}if((gzL(C,0,0)|0)==0){break}else{D=1}i=b;return D|0}}while(0);C=c[2385902]|0;if((c[3542200]|0)==0){D=1;i=b;return D|0}B=y+108|0;c[B>>2]=0;F=y+100|0;c[F>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](y,1)|0;do{if((c[B>>2]|0)!=0){y=c[F>>2]|0;c[z>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](z,1,0)|0;if((y|0)<1){D=1;i=b;return D|0}if((gzL(C,0,1)|0)==0){break}else{D=1}i=b;return D|0}}while(0);C=c[2385902]|0;gGG(C+65536|0,C|0,131072);C=c[3530812]|0;if((c[3542200]|0)==0){D=1;i=b;return D|0}z=w+108|0;c[z>>2]=0;F=w+100|0;c[F>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](w,2)|0;do{if((c[z>>2]|0)!=0){w=c[F>>2]|0;c[x>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](x,2,0)|0;if((w|0)<1){D=1;i=b;return D|0}if((gzL(C,0,2)|0)==0){break}else{D=1}i=b;return D|0}}while(0);C=c[3530576]|0;if((c[3542200]|0)==0){D=1;i=b;return D|0}x=u+108|0;c[x>>2]=0;F=u+100|0;c[F>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](u,3)|0;do{if((c[x>>2]|0)!=0){u=c[F>>2]|0;c[v>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](v,3,0)|0;if((u|0)<1){D=1;i=b;return D|0}if((gzL(C,0,3)|0)==0){break}else{D=1}i=b;return D|0}}while(0);C=c[3530416]|0;if((c[3542200]|0)==0){D=1;i=b;return D|0}v=s+108|0;c[v>>2]=0;F=s+100|0;c[F>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](s,4)|0;do{if((c[v>>2]|0)!=0){s=c[F>>2]|0;c[t>>2]=9534384;x=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[x&16383](t,4,0)|0;if((s|0)<1){D=1;i=b;return D|0}if((gzL(C,0,4)|0)==0){break}else{D=1}i=b;return D|0}}while(0);C=(c[3530416]|0)+2097152|0;if((c[3542200]|0)==0){D=1;i=b;return D|0}t=q+108|0;c[t>>2]=0;F=q+100|0;c[F>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](q,5)|0;do{if((c[t>>2]|0)!=0){q=c[F>>2]|0;c[r>>2]=9534384;v=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[v&16383](r,5,0)|0;if((q|0)<1){D=1;i=b;return D|0}if((gzL(C,0,5)|0)==0){break}else{D=1}i=b;return D|0}}while(0);C=(c[3530416]|0)+4194304|0;if((c[3542200]|0)==0){D=1;i=b;return D|0}r=o+108|0;c[r>>2]=0;F=o+100|0;c[F>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](o,6)|0;do{if((c[r>>2]|0)!=0){o=c[F>>2]|0;c[p>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](p,6,0)|0;if((o|0)<1){D=1;i=b;return D|0}if((gzL(C,0,6)|0)==0){break}else{D=1}i=b;return D|0}}while(0);C=0;p=c[3530416]|0;while(1){F=a[p]|0;r=p+1|0;a[p]=a[r]|0;a[r]=F;F=C+1|0;if((F|0)<3145728){C=F;p=p+2|0}else{break}}p=(c[3529752]|0)+262144|0;if((c[3542200]|0)==0){D=1;i=b;return D|0}C=m+108|0;c[C>>2]=0;F=m+100|0;c[F>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,7)|0;do{if((c[C>>2]|0)!=0){m=c[F>>2]|0;c[n>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](n,7,0)|0;if((m|0)<1){D=1;i=b;return D|0}if((gzL(p,0,7)|0)==0){break}else{D=1}i=b;return D|0}}while(0);p=c[3529752]|0;n=p+262144|0;gGC(p|0,n|0,131072)|0;if((c[3542200]|0)==0){D=1;i=b;return D|0}p=k+108|0;c[p>>2]=0;F=k+100|0;c[F>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,8)|0;do{if((c[p>>2]|0)!=0){k=c[F>>2]|0;c[l>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](l,8,0)|0;if((k|0)<1){D=1;i=b;return D|0}if((gzL(n,0,8)|0)==0){break}else{D=1}i=b;return D|0}}while(0);n=(c[3529752]|0)+2359296|0;if((c[3542200]|0)==0){D=1;i=b;return D|0}l=h+108|0;c[l>>2]=0;F=h+100|0;c[F>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](h,9)|0;do{if((c[l>>2]|0)!=0){h=c[F>>2]|0;c[j>>2]=9534384;p=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[p&16383](j,9,0)|0;if((h|0)<1){D=1;i=b;return D|0}if((gzL(n,0,9)|0)==0){break}else{D=1}i=b;return D|0}}while(0);n=(c[3529752]|0)+4456448|0;if((c[3542200]|0)==0){D=1;i=b;return D|0}j=f+108|0;c[j>>2]=0;F=f+100|0;c[F>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,10)|0;do{if((c[j>>2]|0)!=0){f=c[F>>2]|0;c[g>>2]=9534384;l=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[l&16383](g,10,0)|0;if((f|0)<1){D=1;i=b;return D|0}if((gzL(n,0,10)|0)==0){break}else{D=1}i=b;return D|0}}while(0);n=(c[3529752]|0)+6553600|0;if((c[3542200]|0)==0){D=1;i=b;return D|0}g=d+108|0;c[g>>2]=0;F=d+100|0;c[F>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](d,11)|0;do{if((c[g>>2]|0)!=0){d=c[F>>2]|0;c[e>>2]=9534384;j=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[j&16383](e,11,0)|0;if((d|0)<1){D=1;i=b;return D|0}if((gzL(n,0,11)|0)==0){break}else{D=1}i=b;return D|0}}while(0);n=c[3529752]|0;e=n+262144|0;gGC(n|0,e|0,131072)|0;erq(131072,2097152,6291456);gGz((c[3530416]|0)+12582912|0,15,4194304);c[2439218]=65535;fxU(0,425984);if((c[2394]|0)==0){H=c[2112932]|0}else{c[2394]=0;e=c[3532596]|0;c[2112932]=e;n=c[3532592]|0;if((n|0)!=0){gGC(9104152,n|0,280)|0}c[2113054]=c[2113060];H=e}e=c[2388126]|0;n=H|0;F=0;while(1){g=e+F|0;c[n>>2]=g;c[n+131072>>2]=g;g=F+1024|0;if(g>>>0>524287){break}else{n=n+4|0;F=g}}F=c[2387164]|0;c[H+4608>>2]=F;c[H+70144>>2]=F;c[H+135680>>2]=F;n=F+1024|0;c[H+4612>>2]=n;c[H+70148>>2]=n;c[H+135684>>2]=n;n=c[2443470]|0;c[H+4864>>2]=n;c[H+70400>>2]=n;c[H+135936>>2]=n;F=n+1024|0;c[H+4868>>2]=F;c[H+70404>>2]=F;c[H+135940>>2]=F;F=c[2387982]|0;c[H+5120>>2]=F;c[H+70656>>2]=F;c[H+136192>>2]=F;n=F+1024|0;c[H+5124>>2]=n;c[H+70660>>2]=n;c[H+136196>>2]=n;n=F+2048|0;c[H+5128>>2]=n;c[H+70664>>2]=n;c[H+136200>>2]=n;n=F+3072|0;c[H+5132>>2]=n;c[H+70668>>2]=n;c[H+136204>>2]=n;n=F+4096|0;c[H+5136>>2]=n;c[H+70672>>2]=n;c[H+136208>>2]=n;n=F+5120|0;c[H+5140>>2]=n;c[H+70676>>2]=n;c[H+136212>>2]=n;n=F+6144|0;c[H+5144>>2]=n;c[H+70680>>2]=n;c[H+136216>>2]=n;n=F+7168|0;c[H+5148>>2]=n;c[H+70684>>2]=n;c[H+136220>>2]=n;n=F+8192|0;c[H+5152>>2]=n;c[H+70688>>2]=n;c[H+136224>>2]=n;n=F+9216|0;c[H+5156>>2]=n;c[H+70692>>2]=n;c[H+136228>>2]=n;n=F+10240|0;c[H+5160>>2]=n;c[H+70696>>2]=n;c[H+136232>>2]=n;n=F+11264|0;c[H+5164>>2]=n;c[H+70700>>2]=n;c[H+136236>>2]=n;n=F+12288|0;c[H+5168>>2]=n;c[H+70704>>2]=n;c[H+136240>>2]=n;n=F+13312|0;c[H+5172>>2]=n;c[H+70708>>2]=n;c[H+136244>>2]=n;n=F+14336|0;c[H+5176>>2]=n;c[H+70712>>2]=n;c[H+136248>>2]=n;n=F+15360|0;c[H+5180>>2]=n;c[H+70716>>2]=n;c[H+136252>>2]=n;n=c[2387978]|0;c[H+5184>>2]=n;c[H+70720>>2]=n;c[H+136256>>2]=n;F=n+1024|0;c[H+5188>>2]=F;c[H+70724>>2]=F;c[H+136260>>2]=F;F=n+2048|0;c[H+5192>>2]=F;c[H+70728>>2]=F;c[H+136264>>2]=F;F=n+3072|0;c[H+5196>>2]=F;c[H+70732>>2]=F;c[H+136268>>2]=F;F=n+4096|0;c[H+5200>>2]=F;c[H+70736>>2]=F;c[H+136272>>2]=F;F=n+5120|0;c[H+5204>>2]=F;c[H+70740>>2]=F;c[H+136276>>2]=F;F=n+6144|0;c[H+5208>>2]=F;c[H+70744>>2]=F;c[H+136280>>2]=F;F=n+7168|0;c[H+5212>>2]=F;c[H+70748>>2]=F;c[H+136284>>2]=F;F=n+8192|0;c[H+5216>>2]=F;c[H+70752>>2]=F;c[H+136288>>2]=F;F=n+9216|0;c[H+5220>>2]=F;c[H+70756>>2]=F;c[H+136292>>2]=F;F=n+10240|0;c[H+5224>>2]=F;c[H+70760>>2]=F;c[H+136296>>2]=F;F=n+11264|0;c[H+5228>>2]=F;c[H+70764>>2]=F;c[H+136300>>2]=F;F=n+12288|0;c[H+5232>>2]=F;c[H+70768>>2]=F;c[H+136304>>2]=F;F=n+13312|0;c[H+5236>>2]=F;c[H+70772>>2]=F;c[H+136308>>2]=F;F=n+14336|0;c[H+5240>>2]=F;c[H+70776>>2]=F;c[H+136312>>2]=F;F=n+15360|0;c[H+5244>>2]=F;c[H+70780>>2]=F;c[H+136316>>2]=F;F=c[2387972]|0;c[H+5248>>2]=F;c[H+70784>>2]=F;c[H+136320>>2]=F;n=F+1024|0;c[H+5252>>2]=n;c[H+70788>>2]=n;c[H+136324>>2]=n;n=F+2048|0;c[H+5256>>2]=n;c[H+70792>>2]=n;c[H+136328>>2]=n;n=F+3072|0;c[H+5260>>2]=n;c[H+70796>>2]=n;c[H+136332>>2]=n;n=F+4096|0;c[H+5264>>2]=n;c[H+70800>>2]=n;c[H+136336>>2]=n;n=F+5120|0;c[H+5268>>2]=n;c[H+70804>>2]=n;c[H+136340>>2]=n;n=F+6144|0;c[H+5272>>2]=n;c[H+70808>>2]=n;c[H+136344>>2]=n;n=F+7168|0;c[H+5276>>2]=n;c[H+70812>>2]=n;c[H+136348>>2]=n;n=F+8192|0;c[H+5280>>2]=n;c[H+70816>>2]=n;c[H+136352>>2]=n;n=F+9216|0;c[H+5284>>2]=n;c[H+70820>>2]=n;c[H+136356>>2]=n;n=F+10240|0;c[H+5288>>2]=n;c[H+70824>>2]=n;c[H+136360>>2]=n;n=F+11264|0;c[H+5292>>2]=n;c[H+70828>>2]=n;c[H+136364>>2]=n;n=F+12288|0;c[H+5296>>2]=n;c[H+70832>>2]=n;c[H+136368>>2]=n;n=F+13312|0;c[H+5300>>2]=n;c[H+70836>>2]=n;c[H+136372>>2]=n;n=F+14336|0;c[H+5304>>2]=n;c[H+70840>>2]=n;c[H+136376>>2]=n;n=F+15360|0;c[H+5308>>2]=n;c[H+70844>>2]=n;c[H+136380>>2]=n;n=c[2387968]|0;c[H+5312>>2]=n;c[H+70848>>2]=n;c[H+136384>>2]=n;F=n+1024|0;c[H+5316>>2]=F;c[H+70852>>2]=F;c[H+136388>>2]=F;F=n+2048|0;c[H+5320>>2]=F;c[H+70856>>2]=F;c[H+136392>>2]=F;F=n+3072|0;c[H+5324>>2]=F;c[H+70860>>2]=F;c[H+136396>>2]=F;F=n+4096|0;c[H+5328>>2]=F;c[H+70864>>2]=F;c[H+136400>>2]=F;F=n+5120|0;c[H+5332>>2]=F;c[H+70868>>2]=F;c[H+136404>>2]=F;F=n+6144|0;c[H+5336>>2]=F;c[H+70872>>2]=F;c[H+136408>>2]=F;F=n+7168|0;c[H+5340>>2]=F;c[H+70876>>2]=F;c[H+136412>>2]=F;F=n+8192|0;c[H+5344>>2]=F;c[H+70880>>2]=F;c[H+136416>>2]=F;F=n+9216|0;c[H+5348>>2]=F;c[H+70884>>2]=F;c[H+136420>>2]=F;F=n+10240|0;c[H+5352>>2]=F;c[H+70888>>2]=F;c[H+136424>>2]=F;F=n+11264|0;c[H+5356>>2]=F;c[H+70892>>2]=F;c[H+136428>>2]=F;F=n+12288|0;c[H+5360>>2]=F;c[H+70896>>2]=F;c[H+136432>>2]=F;F=n+13312|0;c[H+5364>>2]=F;c[H+70900>>2]=F;c[H+136436>>2]=F;F=n+14336|0;c[H+5368>>2]=F;c[H+70904>>2]=F;c[H+136440>>2]=F;F=n+15360|0;c[H+5372>>2]=F;c[H+70908>>2]=F;c[H+136444>>2]=F;F=c[2405794]|0;c[H+5888>>2]=F;c[H+71424>>2]=F;c[H+136960>>2]=F;n=F+1024|0;c[H+5892>>2]=n;c[H+71428>>2]=n;c[H+136964>>2]=n;e=F+2048|0;c[H+5896>>2]=e;c[H+71432>>2]=e;c[H+136968>>2]=e;g=F+3072|0;c[H+5900>>2]=g;c[H+71436>>2]=g;c[H+136972>>2]=g;H=c[2112932]|0;c[H+5904>>2]=F;c[H+71440>>2]=F;c[H+136976>>2]=F;c[H+5908>>2]=n;c[H+71444>>2]=n;c[H+136980>>2]=n;c[H+5912>>2]=e;c[H+71448>>2]=e;c[H+136984>>2]=e;c[H+5916>>2]=g;c[H+71452>>2]=g;c[H+136988>>2]=g;g=c[2388254]|0;e=H+7936|0;n=2031616;while(1){F=g+(n-2031616)|0;c[e>>2]=F;c[e+65536>>2]=F;c[e+131072>>2]=F;F=n+1024|0;if(F>>>0>2097151){break}else{e=e+4|0;n=F}}c[H+196728>>2]=1740;c[H+196648>>2]=180;c[H+196688>>2]=3090;c[H+196608>>2]=2308;H=c[2394]|0;n=c[14130368+(H<<2)>>2]|0;if((n|0)!=0){gGC(n|0,9104152,280)|0}c[8452240+(H<<2)>>2]=c[2113054];c[2394]=-1;D=0;i=b;return D|0}function erq(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=(f|0)>=(e|0)?f:e;h=0;while(1){if((h|0)>=1024){i=67704;break}j=9638528+(h<<2)|0;if((c[j>>2]|0)==0){break}else{h=h+1|0}}if((i|0)==67704){return}h=gGq(g)|0;c[j>>2]=h;if((h|0)==0){return}gGz(h|0,0,g|0);g=c[3530812]|0;gGC(h|0,g|0,b)|0;j=b<<1;b=(j|0)/64|0;if((j|0)>63){j=0;do{k=j<<6;gGz(g+k|0,0,64);l=j<<8;m=0;do{n=1<<3-m;o=(c[703416+(m<<2)>>2]|0)+l|0;p=0;do{q=o+(c[611840+(p<<2)>>2]|0)|0;r=(p<<3)+k|0;s=0;do{t=q+(c[600104+(s<<2)>>2]|0)|0;if(((d[h+((t|0)/8|0)|0]|0)&128>>>((t&7)>>>0)|0)!=0){t=g+(r+s)|0;a[t]=(d[t]|0|n)&255}s=s+1|0;}while((s|0)<8);p=p+1|0;}while((p|0)<8);m=m+1|0;}while((m|0)<4);j=j+1|0;}while((j|0)<(b|0))}j=c[3530576]|0;gGC(h|0,j|0,e)|0;g=e<<1;e=(g|0)/256|0;if((g|0)>255){g=0;do{m=g<<8;gGz(j+m|0,0,256);k=g<<10;l=0;do{p=1<<3-l;n=(c[703416+(l<<2)>>2]|0)+k|0;o=0;do{s=n+(c[611840+(o<<2)>>2]|0)|0;r=(o<<4)+m|0;q=0;do{t=s+(c[600104+(q<<2)>>2]|0)|0;if(((d[h+((t|0)/8|0)|0]|0)&128>>>((t&7)>>>0)|0)!=0){t=j+(r+q)|0;a[t]=(d[t]|0|p)&255}q=q+1|0;}while((q|0)<16);o=o+1|0;}while((o|0)<16);l=l+1|0;}while((l|0)<4);g=g+1|0;}while((g|0)<(e|0))}g=c[3530416]|0;gGC(h|0,g|0,f)|0;j=f<<1;f=(j|0)/256|0;if((j|0)>255){j=0;do{l=j<<8;gGz(g+l|0,0,256);m=j<<10;k=0;do{o=1<<3-k;p=(c[703416+(k<<2)>>2]|0)+m|0;n=0;do{q=p+(c[611840+(n<<2)>>2]|0)|0;r=(n<<4)+l|0;s=0;do{t=q+(c[600104+(s<<2)>>2]|0)|0;if(((d[h+((t|0)/8|0)|0]|0)&128>>>((t&7)>>>0)|0)!=0){t=g+(r+s)|0;a[t]=(d[t]|0|o)&255}s=s+1|0;}while((s|0)<16);n=n+1|0;}while((n|0)<16);k=k+1|0;}while((k|0)<4);j=j+1|0;}while((j|0)<(f|0))}c[2439222]=b-1;c[2439220]=e-1;c[2439218]=f-1;f=0;while(1){if((f|0)>=1024){i=67703;break}u=9638528+(f<<2)|0;if((c[u>>2]|0)==(h|0)){break}else{f=f+1|0}}if((i|0)==67703){return}gGr(h);c[u>>2]=0;return}function err(){var a=0,b=0,d=0,e=0,f=0;a=c[2414932]|0;c[2388126]=a;c[2385902]=a+524288;c[3530812]=a+720896;c[3530576]=a+983040;c[3530416]=a+9371648;b=c[c[642608+(c[2436]<<2)>>2]>>2]|0;if((fa(b|0,514968)|0)==0){d=67709}else{if((fa(b|0,507840)|0)==0){d=67709}else{e=a+17760256|0}}if((d|0)==67709){e=a+26148864|0}c[3529500]=e;a=e+131072|0;c[3541206]=a;c[3529752]=a;c[3529708]=e+3276800;if((fa(b|0,514968)|0)==0){d=67712}else{if((fa(b|0,507840)|0)==0){d=67712}else{f=e+6422528|0}}if((d|0)==67712){f=e+12713984|0}c[3529970]=f;e=f+4096|0;c[2414634]=e;c[2387164]=e;c[2388254]=f+6144;c[2387982]=f+71680;c[2387978]=f+88064;c[2387972]=f+104448;c[2387968]=f+120832;c[2405794]=f+137216;c[2443470]=f+141312;c[2386564]=f+145408;c[3529664]=f+149504;c[2386056]=f+153600;c[3528248]=f+161792;c[2443718]=f+161793;c[3528686]=f+161794;c[2388456]=f+161795;e=f+161796|0;c[2411604]=e;c[2414144]=e;return}function ers(f,g){f=f|0;g=g|0;var j=0,k=0.0,l=0.0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0;f=i;if((g|0)==0){i=f;return}g=c[3541518]|0;j=g+296|0;k=+h[j>>3];do{if(k!=0.0){l=+h[6675];if(k-(l+ +gC[c[2429842]&255]())>0.0){m=a[g+307|0]|-128;break}else{h[j>>3]=0.0;n=67719;break}}else{n=67719}}while(0);if((n|0)==67719){m=a[g+307|0]|0}if((m&1)==0){i=f;return}a[9771945]=(c[8452624+(c[2442984]<<2)>>2]&15|c[8452624+(c[2442985]<<2)>>2]<<4)&255;m=a[9771924]|0;g=c[2442982]|0;do{if((g|0)<15){if(m<<24>>24!=(a[614048+g|0]|0)){break}c[2442982]=g+1;a[9771925]=a[602656+g|0]|0}else{a[9771925]=m}}while(0);L89728:do{if((a[9771944]|0)==m<<24>>24){o=0}else{g=c[2442980]|0;j=((d[g+61425|0]<<8|d[g+61424|0])&65535)+((m&255)<<1)|0;p=d[g+(j+1)|0]<<8|d[g+j|0];a[9771944]=m;j=p&65535;if((j&65280|0)==0){d19(j);o=0;break}q=a[g+j|0]|0;if(q<<24>>24==-1){o=0;break}else{r=p;s=g;t=q}while(1){q=t&255;g=r+1&65535;p=d[s+(g+1)|0]<<8|d[s+g|0];g=r+3&65535;if(t<<24>>24==-17){o=0;break L89728}do{if((t&255)<6){b[9771980+(q*104|0)>>1]=p;c[9772020+(q*104|0)>>2]=0;j=9771949+(q*104|0)|0;a[j]=a[j]|1;u=s}else{j=q-6|0;if((j|0)<3){b[9772580+(j*56|0)>>1]=p;c[9772616+(j*56|0)>>2]=0;v=9772572+(j*56|0)|0;a[v]=a[v]|4;u=c[2442980]|0;break}else{v=q-9|0;b[9772742+(v*48|0)>>1]=p;c[9772780+(v*48|0)>>2]=0;j=9772740+(v*48|0)|0;a[j]=a[j]|1;u=s;break}}}while(0);p=a[u+(g&65535)|0]|0;if(p<<24>>24==-1){o=0;break}else{r=g;s=u;t=p}}}}while(0);while(1){t=9772026+(o*104|0)|0;u=b[t>>1]|0;if(u<<16>>16==0){w=0}else{s=u-1&65535;b[t>>1]=s;w=s}s=9772028+(o*104|0)|0;u=b[s>>1]|0;if(u<<16>>16!=0){b[s>>1]=u-1&65535}u=9772036+(o*104|0)|0;r=b[u>>1]|0;if(r<<16>>16!=0){b[u>>1]=r-1&65535}r=9771949+(o*104|0)|0;m=a[r]|0;if((m&1)==0){if(m<<24>>24<0&w<<16>>16==0){n=67745}else{x=m;n=67788}}else{a[r]=-128;b[t>>1]=0;n=67745}do{if((n|0)==67745){n=0;m=9771980+(o*104|0)|0;p=9771950+(o*104|0)|0;q=(o|0)<3;j=((o|0)%3|0)&255;v=9771949+((o-3|0)*104|0)|0;y=9771978+(o*104|0)|0;z=9771979+(o*104|0)|0;A=9771984+(o*104|0)|0;B=9771982+(o*104|0)|0;D=9772020+(o*104|0)|0;E=9772024+(o*104|0)|0;F=9772034+(o*104|0)|0;G=9772038+(o*104|0)|0;H=9772040+(o*104|0)|0;I=9771951+(o*104|0)|0;J=9771952+(o*104|0)|0;K=9771953+(o*104|0)|0;L=9771954+(o*104|0)|0;M=9772044+(o*104|0)|0;N=9772045+(o*104|0)|0;O=9772046+(o*104|0)|0;P=9772047+(o*104|0)|0;Q=9771959+(o*104|0)|0;R=9771960+(o*104|0)|0;S=9771961+(o*104|0)|0;L89759:while(1){T=b[m>>1]|0;U=T+1&65535;b[m>>1]=U;V=c[2442980]|0;W=a[V+(T&65535)|0]|0;X=W&255;Y=W<<24>>24==-17;if(!Y){if((X&240|0)!=240){Z=U;_=V;break}}L89764:do{switch(X|0){case 251:{b[m>>1]=T+2&65535;a[E]=a[V+(U&65535)|0]|0;break};case 252:{a[r]=a[r]|10;break};case 253:{a[r]=a[r]&-3;break};case 254:{b[m>>1]=T+2&65535;W=a[V+(U&65535)|0]|0;a[F]=W;if(W<<24>>24==0){a[r]=a[r]&-17;break L89764}else{$=c[2442980]|0;aa=((W&255)<<1)-2+((d[$+61413|0]<<8|d[$+61412|0])&65535)|0;W=d[$+(aa+1)|0]<<8|d[$+aa|0];b[G>>1]=W;aa=W&65535;b[u>>1]=d[$+(aa+1)|0]<<8|d[$+aa|0];b[H>>1]=W+2&65535;a[r]=a[r]|16;break L89764}break};case 240:{a[r]=a[r]|64;b[m>>1]=T+2&65535;a[p]=a[V+(U&65535)|0]|0;if(!q){if((a[v]|0)<0){break L89764}}a[(c[3541518]|0)+((c[2442983]|0)*19024|0)+304|0]=40;lS(c[2442983]|0,1,j);break};case 250:{W=(c[D>>2]|0)-1|0;c[D>>2]=W;b[m>>1]=b[9771986+(o*104|0)+(W<<1)>>1]|0;break};case 255:{n=67771;break L89759;break};case 249:{W=c[D>>2]|0;c[D>>2]=W+1;b[9771986+(o*104|0)+(W<<1)>>1]=T+3&65535;W=e[m>>1]|0;aa=c[2442980]|0;b[m>>1]=d[aa+(W+1)|0]<<8|d[aa+W|0];break};case 244:{a[r]=a[r]|64;b[m>>1]=T+2&65535;a[y]=a[V+(U&65535)|0]|0;break};case 245:{b[m>>1]=T+2&65535;a[z]=a[V+(U&65535)|0]|0;break};case 246:{W=U&65535;b[m>>1]=d[V+(W+1)|0]<<8|d[V+W|0];break};case 247:{W=T+2&65535;b[m>>1]=W;a[A]=a[V+(U&65535)|0]|0;b[B>>1]=W;break};case 248:{W=(a[A]|0)-1&255;a[A]=W;if(W<<24>>24==0){break L89764}b[m>>1]=b[B>>1]|0;break};case 242:{a[r]=a[r]|64;W=T+2&65535;b[m>>1]=W;a[M]=a[V+(U&65535)|0]|0;aa=T+3&65535;b[m>>1]=aa;a[N]=a[V+(W&65535)|0]|0;W=T+4&65535;b[m>>1]=W;a[O]=a[V+(aa&65535)|0]|0;b[m>>1]=T+5&65535;a[P]=a[V+(W&65535)|0]|0;break};case 243:{a[r]=a[r]|64;W=T+2&65535;b[m>>1]=W;a[Q]=a[V+(U&65535)|0]|0;aa=T+3&65535;b[m>>1]=aa;a[R]=a[V+(W&65535)|0]|0;W=c[2442980]|0;$=T+4&65535;b[m>>1]=$;a[S]=a[W+(aa&65535)|0]|0;aa=11;W=$;while(1){$=c[2442980]|0;b[m>>1]=W+1&65535;a[9771951+(o*104|0)+aa|0]=a[$+(W&65535)|0]|0;$=aa+1|0;if(($|0)>=24){break L89764}aa=$;W=b[m>>1]|0}break};case 241:{a[r]=a[r]|64;W=T+2&65535;b[m>>1]=W;a[I]=a[V+(U&65535)|0]|0;aa=T+3&65535;b[m>>1]=aa;a[J]=a[V+(W&65535)|0]|0;W=T+4&65535;b[m>>1]=W;a[K]=a[(c[2442980]|0)+(aa&65535)|0]|0;b[m>>1]=T+5&65535;a[L]=a[(c[2442980]|0)+(W&65535)|0]|0;break};default:{bw(529168,(ab=i,i=i+16|0,c[ab>>2]=o,c[ab+8>>2]=X,ab)|0)|0;i=ab}}}while(0);if(Y){continue}if((X&240|0)!=240){n=67775;break}}if((n|0)==67775){n=0;Z=b[m>>1]|0;_=c[2442980]|0}else if((n|0)==67771){n=0;a[r]=64;L=o*104|0;K=L+9771955|0;C=2139062143;a[K]=C&255;C=C>>8;a[K+1|0]=C&255;C=C>>8;a[K+2|0]=C&255;C=C>>8;a[K+3|0]=C&255;K=L+9771971|0;C=252645135;a[K]=C&255;C=C>>8;a[K+1|0]=C&255;C=C>>8;a[K+2|0]=C&255;C=C>>8;a[K+3|0]=C&255;break}K=Z-1&65535;b[m>>1]=K;L=_+(K&65535)|0;do{if((a[L]|0)>-1){b[m>>1]=Z;J=a[L]|0;a[9771948+(o*104|0)|0]=J;I=J&15;if((I|0)==12){a[r]=a[r]|4;ac=Z;ad=_;break}else{S=((d[_+61415|0]<<8|d[_+61414|0])&65535)+(I<<1)|0;I=d[_+(S+1)|0]<<8|d[_+S|0];S=(a[E]<<4)+J&255&-16;a[r]=a[r]&-5;b[9772042+(o*104|0)>>1]=I|(S&255)<<7;a[9772048+(o*104|0)|0]=1;ac=Z;ad=c[2442980]|0;break}}else{ac=K;ad=_}}while(0);K=ad+(ac&65535)|0;if((a[K]|0)<0){b[m>>1]=ac+1&65535;E=(a[K]&127)<<1;K=((d[ad+61417|0]<<8|d[ad+61416|0])&65535)+E|0;L=d[ad+(K+1)|0]<<8|d[ad+K|0];b[9772030+(o*104|0)>>1]=L;if((a[z]|0)==0){ae=d[ad+61419|0]<<8|d[ad+61418|0]}else{ae=d[ad+61421|0]<<8|d[ad+61420|0]}K=(ae&65535)+E|0;E=d[ad+(K+1)|0]<<8|d[ad+K|0];b[9772032+(o*104|0)>>1]=E;af=E;ag=L}else{af=b[9772032+(o*104|0)>>1]|0;ag=b[9772030+(o*104|0)>>1]|0}b[t>>1]=ag;b[s>>1]=af;L=a[r]|0;E=L&255;if((E&4|0)!=0|(E&10|0)==2){x=L;n=67788;break}E=L&-105|96;a[r]=E;x=E;n=67788}}while(0);L89812:do{if((n|0)==67788){n=0;s=x&48;do{if((s<<24>>24|0)==48){t=b[9772038+(o*104|0)>>1]|0;E=t&65535;L=c[2442980]|0;b[u>>1]=d[L+(E+1)|0]<<8|d[L+E|0];b[9772040+(o*104|0)>>1]=t+2&65535;n=67790}else if((s<<24>>24|0)==16){t=9772048+(o*104|0)|0;if((a[t]|0)!=0){ah=t;break}if((b[u>>1]|0)!=0){break L89812}a[9771955+(o*104|0)|0]=a[9772044+(o*104|0)|0]|0;a[9771956+(o*104|0)|0]=a[9772045+(o*104|0)|0]|0;a[9771957+(o*104|0)|0]=a[9772046+(o*104|0)|0]|0;a[9771958+(o*104|0)|0]=a[9772047+(o*104|0)|0]|0;t=9772040+(o*104|0)|0;E=b[t>>1]|0;L=E+2&65535;b[t>>1]=L;K=a[(c[2442980]|0)+(E+1&65535)|0]|0;S=K&255;if((S&128|0)==0){ai=K&255}else{ai=(S|65280)&65535}b[9771976+(o*104|0)>>1]=(b[9772042+(o*104|0)>>1]|0)+(ai<<2)&65535;S=E+3&65535;b[t>>1]=S;E=c[2442980]|0;b[u>>1]=d[E+(L&65535)|0]|0;L=a[E+(S&65535)|0]|0;if((L<<24>>24|0)==(-120|0)){a[r]=x&-17;break L89812}else if((L<<24>>24|0)==(-128|0)){b[t>>1]=(b[9772038+(o*104|0)>>1]|0)+2&65535;break L89812}else{break L89812}}else{n=67790}}while(0);if((n|0)==67790){n=0;ah=9772048+(o*104|0)|0}a[ah]=0;a[9771955+(o*104|0)|0]=a[9772044+(o*104|0)|0]|0;a[9771956+(o*104|0)|0]=a[9772045+(o*104|0)|0]|0;a[9771957+(o*104|0)|0]=a[9772046+(o*104|0)|0]|0;a[9771958+(o*104|0)|0]=a[9772047+(o*104|0)|0]|0;b[9771976+(o*104|0)>>1]=b[9772042+(o*104|0)>>1]|0}}while(0);r=o+1|0;if((r|0)<6){o=r}else{aj=0;break}}while(1){o=aj+3|0;ah=9771949+(aj*104|0)|0;x=a[ah]|0;if((x&64)!=0){a[ah]=x&-65;x=0;do{ai=c[2442983]|0;af=(c[600408+(x<<2)>>2]|0)+aj|0;ag=af&255;ad=c[3541518]|0;ae=ad+(ai*19024|0)+256|0;a[ad+(ai*19024|0)+304|0]=ag;ac=af&255;if((ag&255)<16){c[14168912+(((c[2383582]|0)+ai|0)*252|0)>>2]=af&15}if((ag-45&255)<3){if((ac|0)==0){a[ad+(ai*19024|0)+312|0]=2;ak=2}else if((ac|0)==45){ag=ad+(ai*19024|0)+312|0;af=a[ag]|2;a[ag]=af;ak=af}else if((ac|0)==46){af=ad+(ai*19024|0)+312|0;ag=a[af]|1;a[af]=ag;ak=ag}else if((ac|0)==47){a[ad+(ai*19024|0)+312|0]=0;ak=0}else{ak=a[ad+(ai*19024|0)+312|0]|0}ai=ak&3;ad=c[7461744+(ai<<2)>>2]|0;lI(ae,ad,ad,c[7461728+(ai<<2)>>2]|0)}lS(c[2442983]|0,1,a[9771951+(aj*104|0)+x|0]|0);x=x+1|0;}while((x|0)<24)}x=9771949+(o*104|0)|0;ai=a[x]|0;do{if((ai&64)==0){n=67827}else{a[x]=ai&-65;ad=a[ah]|0;if(ad<<24>>24<0){al=ad;break}else{am=0}while(1){ad=c[2442983]|0;ae=(c[600408+(am<<2)>>2]|0)+aj|0;ac=ae&255;ag=c[3541518]|0;af=ag+(ad*19024|0)+256|0;a[ag+(ad*19024|0)+304|0]=ac;_=ae&255;if((ac&255)<16){c[14168912+(((c[2383582]|0)+ad|0)*252|0)>>2]=ae&15}if((ac-45&255)<3){if((_|0)==0){a[ag+(ad*19024|0)+312|0]=2;an=2}else if((_|0)==45){ac=ag+(ad*19024|0)+312|0;ae=a[ac]|2;a[ac]=ae;an=ae}else if((_|0)==46){ae=ag+(ad*19024|0)+312|0;ac=a[ae]|1;a[ae]=ac;an=ac}else if((_|0)==47){a[ag+(ad*19024|0)+312|0]=0;an=0}else{an=a[ag+(ad*19024|0)+312|0]|0}ad=an&3;ag=c[7461744+(ad<<2)>>2]|0;lI(af,ag,ag,c[7461728+(ad<<2)>>2]|0)}lS(c[2442983]|0,1,a[9771951+(o*104|0)+am|0]|0);ad=am+1|0;if((ad|0)<24){am=ad}else{n=67827;break}}}}while(0);if((n|0)==67827){n=0;al=a[ah]|0}ai=al<<24>>24<0;ad=c[2442983]|0;ag=aj+176|0;af=ag&255;_=c[3541518]|0;ac=_+(ad*19024|0)+256|0;a[_+(ad*19024|0)+304|0]=af;if((af&255)<16){c[14168912+(((c[2383582]|0)+ad|0)*252|0)>>2]=ag&15}if((af-45&255)<3){if((aj|0)==(-176|0)){a[_+(ad*19024|0)+312|0]=2;ao=2}else if((aj|0)==(-131|0)){af=_+(ad*19024|0)+312|0;ag=a[af]|2;a[af]=ag;ao=ag}else if((aj|0)==(-130|0)){ag=_+(ad*19024|0)+312|0;af=a[ag]|1;a[ag]=af;ao=af}else if((aj|0)==(-129|0)){a[_+(ad*19024|0)+312|0]=0;ao=0}else{ao=a[_+(ad*19024|0)+312|0]|0}ad=ao&3;_=c[7461744+(ad<<2)>>2]|0;lI(ac,_,_,c[7461728+(ad<<2)>>2]|0)}ad=c[2442983]|0;if(ai){lS(ad,1,a[9771978+(aj*104|0)|0]|0);ai=c[2442983]|0;_=aj+164|0;ac=_&255;af=c[3541518]|0;ag=af+(ai*19024|0)+256|0;a[af+(ai*19024|0)+304|0]=ac;if((ac&255)<16){c[14168912+(((c[2383582]|0)+ai|0)*252|0)>>2]=_&15}if((ac-45&255)<3){if((aj|0)==(-164|0)){a[af+(ai*19024|0)+312|0]=2;ap=2}else if((aj|0)==(-119|0)){ac=af+(ai*19024|0)+312|0;_=a[ac]|2;a[ac]=_;ap=_}else if((aj|0)==(-118|0)){_=af+(ai*19024|0)+312|0;ac=a[_]|1;a[_]=ac;ap=ac}else if((aj|0)==(-117|0)){a[af+(ai*19024|0)+312|0]=0;ap=0}else{ap=a[af+(ai*19024|0)+312|0]|0}ai=ap&3;af=c[7461744+(ai<<2)>>2]|0;lI(ag,af,af,c[7461728+(ai<<2)>>2]|0)}ai=9771976+(aj*104|0)|0;lS(c[2442983]|0,1,(e[ai>>1]|0)>>>8&255);af=c[2442983]|0;ag=aj+160|0;ac=ag&255;_=c[3541518]|0;ae=_+(af*19024|0)+256|0;a[_+(af*19024|0)+304|0]=ac;if((ac&255)<16){c[14168912+(((c[2383582]|0)+af|0)*252|0)>>2]=ag&15}if((ac-45&255)<3){if((aj|0)==(-160|0)){a[_+(af*19024|0)+312|0]=2;aq=2}else if((aj|0)==(-115|0)){ac=_+(af*19024|0)+312|0;ag=a[ac]|2;a[ac]=ag;aq=ag}else if((aj|0)==(-114|0)){ag=_+(af*19024|0)+312|0;ac=a[ag]|1;a[ag]=ac;aq=ac}else if((aj|0)==(-113|0)){a[_+(af*19024|0)+312|0]=0;aq=0}else{aq=a[_+(af*19024|0)+312|0]|0}af=aq&3;_=c[7461744+(af<<2)>>2]|0;lI(ae,_,_,c[7461728+(af<<2)>>2]|0)}lS(c[2442983]|0,1,b[ai>>1]&255)}else{lS(ad,1,a[9771978+(o*104|0)|0]|0);ad=c[2442983]|0;ai=aj+164|0;af=ai&255;_=c[3541518]|0;ae=_+(ad*19024|0)+256|0;a[_+(ad*19024|0)+304|0]=af;if((af&255)<16){c[14168912+(((c[2383582]|0)+ad|0)*252|0)>>2]=ai&15}if((af-45&255)<3){if((aj|0)==(-164|0)){a[_+(ad*19024|0)+312|0]=2;ar=2}else if((aj|0)==(-119|0)){af=_+(ad*19024|0)+312|0;ai=a[af]|2;a[af]=ai;ar=ai}else if((aj|0)==(-118|0)){ai=_+(ad*19024|0)+312|0;af=a[ai]|1;a[ai]=af;ar=af}else if((aj|0)==(-117|0)){a[_+(ad*19024|0)+312|0]=0;ar=0}else{ar=a[_+(ad*19024|0)+312|0]|0}ad=ar&3;_=c[7461744+(ad<<2)>>2]|0;lI(ae,_,_,c[7461728+(ad<<2)>>2]|0)}ad=9771976+(o*104|0)|0;lS(c[2442983]|0,1,(e[ad>>1]|0)>>>8&255);_=c[2442983]|0;ae=aj+160|0;af=ae&255;ai=c[3541518]|0;ac=ai+(_*19024|0)+256|0;a[ai+(_*19024|0)+304|0]=af;if((af&255)<16){c[14168912+(((c[2383582]|0)+_|0)*252|0)>>2]=ae&15}if((af-45&255)<3){if((aj|0)==(-160|0)){a[ai+(_*19024|0)+312|0]=2;as=2}else if((aj|0)==(-115|0)){af=ai+(_*19024|0)+312|0;ae=a[af]|2;a[af]=ae;as=ae}else if((aj|0)==(-114|0)){ae=ai+(_*19024|0)+312|0;af=a[ae]|1;a[ae]=af;as=af}else if((aj|0)==(-113|0)){a[ai+(_*19024|0)+312|0]=0;as=0}else{as=a[ai+(_*19024|0)+312|0]|0}_=as&3;ai=c[7461744+(_<<2)>>2]|0;lI(ac,ai,ai,c[7461728+(_<<2)>>2]|0)}lS(c[2442983]|0,1,b[ad>>1]&255)}ad=a[ah]|0;if((ad&32)!=0){a[ah]=ad&-33;a[(c[3541518]|0)+((c[2442983]|0)*19024|0)+304|0]=40;lS(c[2442983]|0,1,(d[9771950+(aj*104|0)|0]|aj)&255)}ad=a[x]|0;do{if((ad&32)!=0){a[x]=ad&-33;if((a[ah]|0)<0){break}a[(c[3541518]|0)+((c[2442983]|0)*19024|0)+304|0]=40;lS(c[2442983]|0,1,(d[9771950+(o*104|0)|0]|aj)&255)}}while(0);o=aj+1|0;if((o|0)<3){aj=o}else{at=0;break}}while(1){aj=9772574+(at*56|0)|0;as=b[aj>>1]|0;if(as<<16>>16==0){au=0}else{ar=as-1&65535;b[aj>>1]=ar;au=ar}ar=9772578+(at*56|0)|0;as=a[ar]|0;if(as<<24>>24!=0){a[ar]=as-1&255}as=9772572+(at*56|0)|0;aq=a[as]|0;if((aq&4)==0){av=aq;aw=au}else{ap=aq&-6|1;a[as]=ap;if((aq&32)==0){ax=ap}else{a[as]=ap&-101;ap=c[2442983]|0;aq=c[3541518]|0;a[aq+(ap*19024|0)+304|0]=7;ao=c[2383582]|0;c[14168912+((ao+ap|0)*252|0)>>2]=7;ap=c[2442983]|0;do{if((d[aq+(ap*19024|0)+304|0]|0)<16){al=ao+ap|0;am=c[14168912+(al*252|0)>>2]|0;if((am|0)>15){ay=0;az=ap;break}do{if((am|0)==14){an=c[14168896+(al*252|0)>>2]|0;if((an|0)==0){break}a[14168930+(al*252|0)|0]=gj[an&4095](0)|0}else if((am|0)==15){an=c[14168900+(al*252|0)>>2]|0;if((an|0)==0){break}a[14168931+(al*252|0)|0]=gj[an&4095](0)|0}}while(0);ay=d[14168916+(al*252|0)+am|0]|0;az=c[2442983]|0}else{ay=0;az=ap}}while(0);lS(az,1,(ay|1<<at)&(8<<at^255)&255);ax=a[as]|0}b[aj>>1]=0;a[ar]=0;a[9772625+(at*56|0)|0]=0;av=ax;aw=0}L89970:do{if((av&1)!=0){do{if(aw<<16>>16==0){ap=9772580+(at*56|0)|0;ao=b[ap>>1]|0;aq=ao+1&65535;b[ap>>1]=aq;an=c[2442980]|0;ak=a[an+(ao&65535)|0]|0;o=ak&255;L89974:do{if((o&240|0)==240){ah=1<<at;ad=8<<at^255;x=9772623+(at*56|0)|0;_=9772622+(at*56|0)|0;ai=9772620+(at*56|0)|0;ac=9772616+(at*56|0)|0;af=9772625+(at*56|0)|0;ae=ao;ag=aq;Z=an;w=o;L89976:while(1){L89978:do{switch(w|0){case 240:{a[as]=a[as]|32;aA=ag;break};case 241:{a[as]=a[as]&-97;r=c[2442983]|0;u=c[3541518]|0;a[u+(r*19024|0)+304|0]=7;s=c[2383582]|0;c[14168912+((s+r|0)*252|0)>>2]=7;r=c[2442983]|0;do{if((d[u+(r*19024|0)+304|0]|0)<16){z=s+r|0;m=c[14168912+(z*252|0)>>2]|0;if((m|0)>15){aB=0;aC=r;break}do{if((m|0)==14){t=c[14168896+(z*252|0)>>2]|0;if((t|0)==0){break}a[14168930+(z*252|0)|0]=gj[t&4095](0)|0}else if((m|0)==15){t=c[14168900+(z*252|0)>>2]|0;if((t|0)==0){break}a[14168931+(z*252|0)|0]=gj[t&4095](0)|0}}while(0);aB=d[14168916+(z*252|0)+m|0]|0;aC=c[2442983]|0}else{aB=0;aC=r}}while(0);lS(aC,1,(aB|ah)&ad&255);aA=b[ap>>1]|0;break};case 242:case 243:case 244:case 245:{r=ag+1&65535;b[ap>>1]=r;a[x]=a[Z+(ag&65535)|0]|0;aA=r;break};case 246:{r=ag&65535;s=d[Z+(r+1)|0]<<8|d[Z+r|0];b[ap>>1]=s;aA=s;break};case 247:{s=ae+2&65535;b[ap>>1]=s;a[_]=a[Z+(ag&65535)|0]|0;b[ai>>1]=s;aA=s;break};case 248:{s=(a[_]|0)-1&255;a[_]=s;if(s<<24>>24==0){aA=ag;break L89978}s=b[ai>>1]|0;b[ap>>1]=s;aA=s;break};case 249:{s=c[ac>>2]|0;c[ac>>2]=s+1;b[9772582+(at*56|0)+(s<<1)>>1]=ae+3&65535;s=e[ap>>1]|0;r=c[2442980]|0;u=d[r+(s+1)|0]<<8|d[r+s|0];b[ap>>1]=u;aA=u;break};case 250:{u=(c[ac>>2]|0)-1|0;c[ac>>2]=u;s=b[9772582+(at*56|0)+(u<<1)>>1]|0;b[ap>>1]=s;aA=s;break};case 251:case 252:case 253:case 254:{s=ag+1&65535;b[ap>>1]=s;a[af]=a[Z+(ag&65535)|0]|0;aA=s;break};case 255:{break L89976;break};default:{aA=ag}}}while(0);s=aA+1&65535;b[ap>>1]=s;u=c[2442980]|0;r=a[u+(aA&65535)|0]|0;t=r&255;if((t&240|0)==240){ae=aA;ag=s;Z=u;w=t}else{aD=r;aE=s;break L89974}}a[as]=0;a[x]=0;w=c[2442983]|0;Z=at+8|0;ag=Z&255;ae=c[3541518]|0;af=ae+(w*19024|0)+256|0;a[ae+(w*19024|0)+304|0]=ag;if((ag&255)<16){c[14168912+(((c[2383582]|0)+w|0)*252|0)>>2]=Z}if((ag-45&255)<3){if((at|0)==(-8|0)){a[ae+(w*19024|0)+312|0]=2;aF=2}else if((at|0)==37){ag=ae+(w*19024|0)+312|0;Z=a[ag]|2;a[ag]=Z;aF=Z}else if((at|0)==38){Z=ae+(w*19024|0)+312|0;ag=a[Z]|1;a[Z]=ag;aF=ag}else if((at|0)==39){a[ae+(w*19024|0)+312|0]=0;aF=0}else{aF=a[ae+(w*19024|0)+312|0]|0}w=aF&3;ae=c[7461744+(w<<2)>>2]|0;lI(af,ae,ae,c[7461728+(w<<2)>>2]|0)}lS(c[2442983]|0,1,0);break L89970}else{aD=ak;aE=aq}}while(0);aq=9772626+(at*56|0)|0;a[aq]=aD;ak=c[2442980]|0;o=ak+(aE&65535)|0;if((a[o]|0)<0){an=(d[ak+61417|0]<<8|d[ak+61416|0])&65535;b[ap>>1]=aE+1&65535;ao=(d[o]<<1&254)+an|0;an=d[ak+(ao+1)|0]<<8|d[ak+ao|0];b[9772576+(at*56|0)>>1]=an;aG=an}else{aG=b[9772576+(at*56|0)>>1]|0}b[aj>>1]=aG;a[ar]=0;an=a[as]|0;ao=an|8;a[as]=ao;if(aD<<24>>24==12){a[as]=an|10;break}an=ao&-3;a[as]=an;ao=an&255;if((ao&32|0)!=0){if((ao&64|0)==0){a[as]=an|64;an=c[2442983]|0;ao=c[3541518]|0;a[ao+(an*19024|0)+304|0]=7;ak=c[2383582]|0;c[14168912+((ak+an|0)*252|0)>>2]=7;an=c[2442983]|0;do{if((d[ao+(an*19024|0)+304|0]|0)<16){o=ak+an|0;X=c[14168912+(o*252|0)>>2]|0;if((X|0)>15){aH=0;aI=an;break}do{if((X|0)==14){Y=c[14168896+(o*252|0)>>2]|0;if((Y|0)==0){break}a[14168930+(o*252|0)|0]=gj[Y&4095](0)|0}else if((X|0)==15){Y=c[14168900+(o*252|0)>>2]|0;if((Y|0)==0){break}a[14168931+(o*252|0)|0]=gj[Y&4095](0)|0}}while(0);aH=d[14168916+(o*252|0)+X|0]|0;aI=c[2442983]|0}else{aH=0;aI=an}}while(0);lS(aI,1,(aH&(1<<at^255)|8<<at)&255)}an=c[2442983]|0;a[(c[3541518]|0)+(an*19024|0)+304|0]=6;c[14168912+(((c[2383582]|0)+an|0)*252|0)>>2]=6;lS(c[2442983]|0,1,a[aq]|0);a[9772627+(at*56|0)|0]=a[aq]|0;break}an=c[2442980]|0;ak=((d[an+61427|0]<<8|d[an+61426|0])&65535)+((aD&255)<<1&30)|0;ao=((d[an+(ak+1)|0]<<8|d[an+ak|0])&65535)>>>(((a[9772625+(at*56|0)|0]|0)+((aD&255)>>>4)&255)>>>0);ak=c[2442983]|0;an=at<<1;ap=an|1;x=ap&255;Y=c[3541518]|0;w=Y+(ak*19024|0)+256|0;a[Y+(ak*19024|0)+304|0]=x;if((x&255)<16){c[14168912+(((c[2383582]|0)+ak|0)*252|0)>>2]=ap}if((x-45&255)<3){if((ap|0)==45){x=Y+(ak*19024|0)+312|0;ae=a[x]|2;a[x]=ae;aJ=ae}else if((ap|0)==47){a[Y+(ak*19024|0)+312|0]=0;aJ=0}else{aJ=a[Y+(ak*19024|0)+312|0]|0}ak=aJ&3;Y=c[7461744+(ak<<2)>>2]|0;lI(w,Y,Y,c[7461728+(ak<<2)>>2]|0)}ak=ao>>>8&15;lS(c[2442983]|0,1,ak);Y=c[2442983]|0;w=an&255;ap=c[3541518]|0;ae=ap+(Y*19024|0)+256|0;a[ap+(Y*19024|0)+304|0]=w;if((w&255)<16){c[14168912+(((c[2383582]|0)+Y|0)*252|0)>>2]=an}if((w-45&255)<3){if((an|0)==0){a[ap+(Y*19024|0)+312|0]=2;aK=2}else if((an|0)==46){an=ap+(Y*19024|0)+312|0;w=a[an]|1;a[an]=w;aK=w}else{aK=a[ap+(Y*19024|0)+312|0]|0}Y=aK&3;ap=c[7461744+(Y<<2)>>2]|0;lI(ae,ap,ap,c[7461728+(Y<<2)>>2]|0)}lS(c[2442983]|0,1,ao&255);a[9772627+(at*56|0)|0]=ak}}while(0);if((a[ar]|0)!=0){break}am=c[2442980]|0;al=((d[am+61423|0]<<8|d[am+61422|0])&65535)+(d[9772623+(at*56|0)|0]<<1)|0;ak=d[am+(al+1)|0]<<8|d[am+al|0];al=a[as]|0;if((al&8)==0){aL=al;aM=a[9772624+(at*56|0)|0]|0}else{am=al&-9;a[as]=am;a[9772624+(at*56|0)|0]=0;aL=am;aM=0}am=ak&65535;ak=9772624+(at*56|0)|0;al=aM+1&255;a[ak]=al;ao=a[(c[2442980]|0)+((aM&255)+am)|0]|0;a[ak]=aM+2&255;a[ar]=a[(c[2442980]|0)+((al&255)+am)|0]|0;am=(aL&2)==0;al=c[2442983]|0;ak=at+8|0;Y=ak&255;ap=c[3541518]|0;ae=ap+(al*19024|0)+256|0;a[ap+(al*19024|0)+304|0]=Y;if((Y&255)<16){c[14168912+(((c[2383582]|0)+al|0)*252|0)>>2]=ak}if((Y-45&255)<3){if((at|0)==(-8|0)){a[ap+(al*19024|0)+312|0]=2;aN=2}else if((at|0)==37){Y=ap+(al*19024|0)+312|0;ak=a[Y]|2;a[Y]=ak;aN=ak}else if((at|0)==38){ak=ap+(al*19024|0)+312|0;Y=a[ak]|1;a[ak]=Y;aN=Y}else if((at|0)==39){a[ap+(al*19024|0)+312|0]=0;aN=0}else{aN=a[ap+(al*19024|0)+312|0]|0}al=aN&3;ap=c[7461744+(al<<2)>>2]|0;lI(ae,ap,ap,c[7461728+(al<<2)>>2]|0)}lS(c[2442983]|0,1,am?ao&15:0)}}while(0);ar=at+1|0;if((ar|0)<3){at=ar}else{aO=0;break}}do{at=9772784+(aO*48|0)|0;aN=b[at>>1]|0;if(aN<<16>>16==0){aP=0}else{aL=aN-1&65535;b[at>>1]=aL;aP=aL}aL=9772740+(aO*48|0)|0;aN=a[aL]|0;if((aN&1)==0){if(aN<<24>>24<0&aP<<16>>16==0){n=67993}}else{a[aL]=-128;b[at>>1]=0;n=67993}do{if((n|0)==67993){n=0;aN=9772742+(aO*48|0)|0;aM=9772746+(aO*48|0)|0;aK=9772744+(aO*48|0)|0;aJ=9772780+(aO*48|0)|0;L90090:while(1){aD=b[aN>>1]|0;aH=aD+1&65535;b[aN>>1]=aH;aI=c[2442980]|0;aG=a[aI+(aD&65535)|0]|0;aE=aG&255;aF=aG<<24>>24==-17;if(!aF){if((aE&240|0)!=240){aQ=aH;aR=aI;break}}L90095:do{switch(aE|0){case 239:{b[aN>>1]=aD+2&65535;d19(d[aI+(aH&65535)|0]|0);break};case 246:{aG=aH&65535;b[aN>>1]=d[aI+(aG+1)|0]<<8|d[aI+aG|0];break};case 247:{aG=aD+2&65535;b[aN>>1]=aG;a[aM]=a[aI+(aH&65535)|0]|0;b[aK>>1]=aG;break};case 248:{aG=(a[aM]|0)-1&255;a[aM]=aG;if(aG<<24>>24==0){break L90095}b[aN>>1]=b[aK>>1]|0;break};case 249:{aG=c[aJ>>2]|0;c[aJ>>2]=aG+1;b[9772748+(aO*48|0)+(aG<<1)>>1]=aD+3&65535;aG=e[aN>>1]|0;aA=c[2442980]|0;b[aN>>1]=d[aA+(aG+1)|0]<<8|d[aA+aG|0];break};case 250:{aG=(c[aJ>>2]|0)-1|0;c[aJ>>2]=aG;b[aN>>1]=b[9772748+(aO*48|0)+(aG<<1)>>1]|0;break};case 255:{n=68004;break L90090;break};case 252:case 253:{break};default:{bw(279072,(ab=i,i=i+16|0,c[ab>>2]=aO,c[ab+8>>2]=aE,ab)|0)|0;i=ab}}}while(0);if(aF){continue}if((aE&240|0)!=240){n=68008;break}}if((n|0)==68004){n=0;a[aL]=0;break}else if((n|0)==68008){n=0;aQ=b[aN>>1]|0;aR=c[2442980]|0}aJ=aQ-1&65535;b[aN>>1]=aJ;do{if((a[aR+(aJ&65535)|0]|0)>-1){b[aN>>1]=aQ;if((a[aR+(aQ&65535)|0]|0)<0){aS=aQ;n=68012;break}aT=b[9772786+(aO*48|0)>>1]|0}else{aS=aJ;n=68012}}while(0);if((n|0)==68012){n=0;aJ=(d[aR+61417|0]<<8|d[aR+61416|0])&65535;b[aN>>1]=aS+1&65535;aK=(d[aR+(aS&65535)|0]<<1&254)+aJ|0;aJ=d[aR+(aK+1)|0]<<8|d[aR+aK|0];b[9772786+(aO*48|0)>>1]=aJ;aT=aJ}b[at>>1]=aT}}while(0);aO=aO+1|0;}while((aO|0)<8);a[(c[3541518]|0)+304|0]=39;lS(0,1,21);i=f;return}function ert(a){a=a|0;var b=0;b=ag((c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0,a)|0;return(b>>>0)/((c[2433556]|0)>>>0)|0|0}function eru(){return+(+((c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0)/+((c[2433556]|0)>>>0>>>0))}function erv(b,f,g,h,i){b=b|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;j=b;b=16-f|0;f=(a[2826944]|0?-8:-16)+(16-g)|0;g=a[668912]|0;k=c[2439220]|0;l=c[2112926]|0;m=c[3530576]|0;n=c[2388456]|0;o=c[2113068]|0;p=c[2113070]|0;if((i|0)==0){i=0;do{q=i<<4;r=i>>8;s=(q+b&4095)-16|0;t=((r<<4)+f&511)-16|0;do{if((s|0)<(o|0)&(t|0)<(p|0)){u=e[j+((r&15|i&-4096|q&4080)<<1)>>1]|0;if(g){Sz(l,k&u,s,t,0,8,h,m);break}else{Sz(l,((d[n]|0)<<12|u&4095)&k,s,t,u>>>12,4,h,m);break}}}while(0);i=i+1|0;}while((i|0)<8192);return}else{i=0;do{t=i<<4;s=i>>8;q=(t+b&4095)-16|0;r=((s<<4)+f&511)-16|0;do{if((q|0)<(o|0)&(r|0)<(p|0)){u=e[j+((s&15|i&-4096|t&4080)<<1)>>1]|0;if(g){Sz(l,k&u,q,r,0,8,h,m);break}else{SH(l,((d[n]|0)<<12|u&4095)&k,q,r,u>>>12,4,15,h,m);break}}}while(0);i=i+1|0;}while((i|0)<8192);return}}function erw(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;a=i;i=i+840|0;b=a|0;d=a+112|0;e=a+120|0;f=a+232|0;g=a+240|0;h=a+352|0;j=a+360|0;k=a+472|0;l=a+480|0;m=a+592|0;n=a+600|0;o=a+712|0;p=a+720|0;q=a+832|0;if((R6((c[2388126]|0)+1|0,0,2)|0)!=0){r=1;i=a;return r|0}if((R6(c[2388126]|0,1,2)|0)!=0){r=1;i=a;return r|0}s=c[2385902]|0;if((c[3542200]|0)==0){r=1;i=a;return r|0}t=p+108|0;c[t>>2]=0;u=p+100|0;c[u>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,2)|0;do{if((c[t>>2]|0)!=0){p=c[u>>2]|0;c[q>>2]=9534384;v=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[v&16383](q,2,0)|0;if((p|0)<1){r=1;i=a;return r|0}if((gzL(s,0,2)|0)==0){break}else{r=1}i=a;return r|0}}while(0);s=c[3530812]|0;if((c[3542200]|0)==0){r=1;i=a;return r|0}q=n+108|0;c[q>>2]=0;u=n+100|0;c[u>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,3)|0;do{if((c[q>>2]|0)!=0){n=c[u>>2]|0;c[o>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](o,3,0)|0;if((n|0)<1){r=1;i=a;return r|0}if((gzL(s,0,3)|0)==0){break}else{r=1}i=a;return r|0}}while(0);s=c[3530576]|0;if((c[3542200]|0)==0){r=1;i=a;return r|0}o=l+108|0;c[o>>2]=0;u=l+100|0;c[u>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,4)|0;do{if((c[o>>2]|0)!=0){l=c[u>>2]|0;c[m>>2]=9534384;q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[q&16383](m,4,0)|0;if((l|0)<1){r=1;i=a;return r|0}if((gzL(s,0,4)|0)==0){break}else{r=1}i=a;return r|0}}while(0);s=c[3530416]|0;if((c[3542200]|0)==0){r=1;i=a;return r|0}m=j+108|0;c[m>>2]=0;u=j+100|0;c[u>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,5)|0;do{if((c[m>>2]|0)!=0){j=c[u>>2]|0;c[k>>2]=9534384;o=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[o&16383](k,5,0)|0;if((j|0)<1){r=1;i=a;return r|0}if((gzL(s,0,5)|0)==0){break}else{r=1}i=a;return r|0}}while(0);s=(c[3530576]|0)+524288|0;if((c[3542200]|0)==0){r=1;i=a;return r|0}k=g+108|0;c[k>>2]=0;u=g+100|0;c[u>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,6)|0;do{if((c[k>>2]|0)!=0){g=c[u>>2]|0;c[h>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](h,6,0)|0;if((g|0)<1){r=1;i=a;return r|0}if((gzL(s,0,6)|0)==0){break}else{r=1}i=a;return r|0}}while(0);if((R6((c[3529500]|0)+1|0,7,2)|0)!=0){r=1;i=a;return r|0}if((R6(c[3529500]|0,8,2)|0)!=0){r=1;i=a;return r|0}s=(c[3529752]|0)+131072|0;if((c[3542200]|0)==0){r=1;i=a;return r|0}h=e+108|0;c[h>>2]=0;u=e+100|0;c[u>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,9)|0;do{if((c[h>>2]|0)!=0){e=c[u>>2]|0;c[f>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](f,9,0)|0;if((e|0)<1){r=1;i=a;return r|0}if((gzL(s,0,9)|0)==0){break}else{r=1}i=a;return r|0}}while(0);s=c[3529752]|0;f=s+131072|0;gGC(s|0,f|0,131072)|0;f=(c[3529708]|0)+131072|0;if((c[3542200]|0)==0){r=1;i=a;return r|0}s=b+108|0;c[s>>2]=0;u=b+100|0;c[u>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](b,10)|0;do{if((c[s>>2]|0)!=0){b=c[u>>2]|0;c[d>>2]=9534384;h=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[h&16383](d,10,0)|0;if((b|0)<1){r=1;i=a;return r|0}if((gzL(f,0,10)|0)==0){break}else{r=1}i=a;return r|0}}while(0);f=c[3529708]|0;d=f+131072|0;gGC(f|0,d|0,131072)|0;erq(65536,1048576,524288);fxU(0,425984);if((c[2394]|0)==0){w=c[2112932]|0}else{c[2394]=0;d=c[3532596]|0;c[2112932]=d;f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];w=d}d=c[2388126]|0;f=w|0;u=0;while(1){s=d+u|0;c[f>>2]=s;c[f+131072>>2]=s;s=u+1024|0;if(s>>>0>262143){break}else{f=f+4|0;u=s}}u=c[2387164]|0;c[w+2176>>2]=u;c[w+67712>>2]=u;c[w+133248>>2]=u;f=u+1024|0;c[w+2180>>2]=f;c[w+67716>>2]=f;c[w+133252>>2]=f;f=c[2443470]|0;c[w+2240>>2]=f;c[w+67776>>2]=f;c[w+133312>>2]=f;f=c[2387982]|0;c[w+2304>>2]=f;c[w+67840>>2]=f;c[w+133376>>2]=f;u=f+1024|0;c[w+2308>>2]=u;c[w+67844>>2]=u;c[w+133380>>2]=u;u=f+2048|0;c[w+2312>>2]=u;c[w+67848>>2]=u;c[w+133384>>2]=u;u=f+3072|0;c[w+2316>>2]=u;c[w+67852>>2]=u;c[w+133388>>2]=u;u=f+4096|0;c[w+2320>>2]=u;c[w+67856>>2]=u;c[w+133392>>2]=u;u=f+5120|0;c[w+2324>>2]=u;c[w+67860>>2]=u;c[w+133396>>2]=u;u=f+6144|0;c[w+2328>>2]=u;c[w+67864>>2]=u;c[w+133400>>2]=u;u=f+7168|0;c[w+2332>>2]=u;c[w+67868>>2]=u;c[w+133404>>2]=u;u=f+8192|0;c[w+2336>>2]=u;c[w+67872>>2]=u;c[w+133408>>2]=u;u=f+9216|0;c[w+2340>>2]=u;c[w+67876>>2]=u;c[w+133412>>2]=u;u=f+10240|0;c[w+2344>>2]=u;c[w+67880>>2]=u;c[w+133416>>2]=u;u=f+11264|0;c[w+2348>>2]=u;c[w+67884>>2]=u;c[w+133420>>2]=u;u=f+12288|0;c[w+2352>>2]=u;c[w+67888>>2]=u;c[w+133424>>2]=u;u=f+13312|0;c[w+2356>>2]=u;c[w+67892>>2]=u;c[w+133428>>2]=u;u=f+14336|0;c[w+2360>>2]=u;c[w+67896>>2]=u;c[w+133432>>2]=u;u=f+15360|0;c[w+2364>>2]=u;c[w+67900>>2]=u;c[w+133436>>2]=u;u=c[2405794]|0;c[w+2496>>2]=u;c[w+68032>>2]=u;c[w+133568>>2]=u;f=u+1024|0;c[w+2500>>2]=f;c[w+68036>>2]=f;c[w+133572>>2]=f;f=c[2388254]|0;u=w+3840|0;d=983040;while(1){s=f+(d-983040)|0;c[u>>2]=s;c[u+65536>>2]=s;c[u+131072>>2]=s;s=d+1024|0;if(s>>>0>1048575){break}else{u=u+4|0;d=s}}c[w+196728>>2]=1128;c[w+196648>>2]=986;c[w+196688>>2]=396;c[w+196608>>2]=1322;w=c[3532592]|0;if((w|0)!=0){gGC(w|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;r=0;i=a;return r|0}function erx(){var a=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;a=i;i=i+1080|0;d=a|0;e=a+112|0;f=a+120|0;g=a+232|0;h=a+240|0;j=a+352|0;k=a+360|0;l=a+472|0;m=a+480|0;n=a+592|0;o=a+600|0;p=a+712|0;q=a+720|0;r=a+832|0;s=a+840|0;t=a+952|0;u=a+960|0;v=a+1072|0;if((R6((c[2388126]|0)+1|0,0,2)|0)!=0){w=1;i=a;return w|0}if((R6(c[2388126]|0,1,2)|0)!=0){w=1;i=a;return w|0}x=c[2385902]|0;if((c[3542200]|0)==0){w=1;i=a;return w|0}y=u+108|0;c[y>>2]=0;z=u+100|0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](u,2)|0;do{if((c[y>>2]|0)!=0){u=c[z>>2]|0;c[v>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](v,2,0)|0;if((u|0)<1){w=1;i=a;return w|0}if((gzL(x,0,2)|0)==0){break}else{w=1}i=a;return w|0}}while(0);x=c[3530812]|0;if((c[3542200]|0)==0){w=1;i=a;return w|0}v=s+108|0;c[v>>2]=0;z=s+100|0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](s,3)|0;do{if((c[v>>2]|0)!=0){s=c[z>>2]|0;c[t>>2]=9534384;y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[y&16383](t,3,0)|0;if((s|0)<1){w=1;i=a;return w|0}if((gzL(x,0,3)|0)==0){break}else{w=1}i=a;return w|0}}while(0);x=c[3530576]|0;if((c[3542200]|0)==0){w=1;i=a;return w|0}t=q+108|0;c[t>>2]=0;z=q+100|0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](q,4)|0;do{if((c[t>>2]|0)!=0){q=c[z>>2]|0;c[r>>2]=9534384;v=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[v&16383](r,4,0)|0;if((q|0)<1){w=1;i=a;return w|0}if((gzL(x,0,4)|0)==0){break}else{w=1}i=a;return w|0}}while(0);x=c[3530416]|0;if((c[3542200]|0)==0){w=1;i=a;return w|0}r=o+108|0;c[r>>2]=0;z=o+100|0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](o,5)|0;do{if((c[r>>2]|0)!=0){o=c[z>>2]|0;c[p>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](p,5,0)|0;if((o|0)<1){w=1;i=a;return w|0}if((gzL(x,0,5)|0)==0){break}else{w=1}i=a;return w|0}}while(0);x=(c[3530416]|0)+524288|0;if((c[3542200]|0)==0){w=1;i=a;return w|0}p=m+108|0;c[p>>2]=0;z=m+100|0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,6)|0;do{if((c[p>>2]|0)!=0){m=c[z>>2]|0;c[n>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](n,6,0)|0;if((m|0)<1){w=1;i=a;return w|0}if((gzL(x,0,6)|0)==0){break}else{w=1}i=a;return w|0}}while(0);x=(c[3530416]|0)+1048576|0;if((c[3542200]|0)==0){w=1;i=a;return w|0}n=k+108|0;c[n>>2]=0;z=k+100|0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,7)|0;do{if((c[n>>2]|0)!=0){k=c[z>>2]|0;c[l>>2]=9534384;p=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[p&16383](l,7,0)|0;if((k|0)<1){w=1;i=a;return w|0}if((gzL(x,0,7)|0)==0){break}else{w=1}i=a;return w|0}}while(0);x=(c[3530576]|0)+524288|0;if((c[3542200]|0)==0){w=1;i=a;return w|0}l=h+108|0;c[l>>2]=0;z=h+100|0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](h,8)|0;do{if((c[l>>2]|0)!=0){h=c[z>>2]|0;c[j>>2]=9534384;n=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[n&16383](j,8,0)|0;if((h|0)<1){w=1;i=a;return w|0}if((gzL(x,0,8)|0)==0){break}else{w=1}i=a;return w|0}}while(0);x=(c[3529752]|0)+131072|0;if((c[3542200]|0)==0){w=1;i=a;return w|0}j=f+108|0;c[j>>2]=0;z=f+100|0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,9)|0;do{if((c[j>>2]|0)!=0){f=c[z>>2]|0;c[g>>2]=9534384;l=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[l&16383](g,9,0)|0;if((f|0)<1){w=1;i=a;return w|0}if((gzL(x,0,9)|0)==0){break}else{w=1}i=a;return w|0}}while(0);x=c[3529752]|0;g=x+131072|0;gGC(x|0,g|0,131072)|0;g=(c[3529708]|0)+131072|0;if((c[3542200]|0)==0){w=1;i=a;return w|0}x=d+108|0;c[x>>2]=0;z=d+100|0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](d,10)|0;do{if((c[x>>2]|0)!=0){d=c[z>>2]|0;c[e>>2]=9534384;j=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[j&16383](e,10,0)|0;if((d|0)<1){w=1;i=a;return w|0}if((gzL(g,0,10)|0)==0){break}else{w=1}i=a;return w|0}}while(0);g=c[3529708]|0;e=g+131072|0;gGC(g|0,e|0,131072)|0;erq(65536,1048576,2097152);e=c[2388126]|0;b[e+1950>>1]=20081;b[e+1952>>1]=20081;b[e+1954>>1]=20081;b[e+2272>>1]=20081;b[e+2274>>1]=20081;b[e+2408>>1]=20081;b[e+2410>>1]=20081;fxU(0,425984);if((c[2394]|0)==0){B=c[2112932]|0}else{c[2394]=0;e=c[3532596]|0;c[2112932]=e;g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060];B=e}e=c[2388126]|0;g=B|0;z=0;while(1){x=e+z|0;c[g>>2]=x;c[g+131072>>2]=x;x=z+1024|0;if(x>>>0>262143){break}else{g=g+4|0;z=x}}z=c[2443470]|0;c[B+2112>>2]=z;c[B+67648>>2]=z;c[B+133184>>2]=z;g=z+1024|0;c[B+2176>>2]=g;c[B+67712>>2]=g;c[B+133248>>2]=g;g=c[2387164]|0;c[B+2240>>2]=g;c[B+67776>>2]=g;c[B+133312>>2]=g;z=g+1024|0;c[B+2244>>2]=z;c[B+67780>>2]=z;c[B+133316>>2]=z;z=c[2387982]|0;c[B+2304>>2]=z;c[B+67840>>2]=z;c[B+133376>>2]=z;g=z+1024|0;c[B+2308>>2]=g;c[B+67844>>2]=g;c[B+133380>>2]=g;g=z+2048|0;c[B+2312>>2]=g;c[B+67848>>2]=g;c[B+133384>>2]=g;g=z+3072|0;c[B+2316>>2]=g;c[B+67852>>2]=g;c[B+133388>>2]=g;g=z+4096|0;c[B+2320>>2]=g;c[B+67856>>2]=g;c[B+133392>>2]=g;g=z+5120|0;c[B+2324>>2]=g;c[B+67860>>2]=g;c[B+133396>>2]=g;g=z+6144|0;c[B+2328>>2]=g;c[B+67864>>2]=g;c[B+133400>>2]=g;g=z+7168|0;c[B+2332>>2]=g;c[B+67868>>2]=g;c[B+133404>>2]=g;g=z+8192|0;c[B+2336>>2]=g;c[B+67872>>2]=g;c[B+133408>>2]=g;g=z+9216|0;c[B+2340>>2]=g;c[B+67876>>2]=g;c[B+133412>>2]=g;g=z+10240|0;c[B+2344>>2]=g;c[B+67880>>2]=g;c[B+133416>>2]=g;g=z+11264|0;c[B+2348>>2]=g;c[B+67884>>2]=g;c[B+133420>>2]=g;g=z+12288|0;c[B+2352>>2]=g;c[B+67888>>2]=g;c[B+133424>>2]=g;g=z+13312|0;c[B+2356>>2]=g;c[B+67892>>2]=g;c[B+133428>>2]=g;g=z+14336|0;c[B+2360>>2]=g;c[B+67896>>2]=g;c[B+133432>>2]=g;g=z+15360|0;c[B+2364>>2]=g;c[B+67900>>2]=g;c[B+133436>>2]=g;g=c[2387978]|0;c[B+2368>>2]=g;c[B+67904>>2]=g;c[B+133440>>2]=g;z=g+1024|0;c[B+2372>>2]=z;c[B+67908>>2]=z;c[B+133444>>2]=z;z=g+2048|0;c[B+2376>>2]=z;c[B+67912>>2]=z;c[B+133448>>2]=z;z=g+3072|0;c[B+2380>>2]=z;c[B+67916>>2]=z;c[B+133452>>2]=z;z=g+4096|0;c[B+2384>>2]=z;c[B+67920>>2]=z;c[B+133456>>2]=z;z=g+5120|0;c[B+2388>>2]=z;c[B+67924>>2]=z;c[B+133460>>2]=z;z=g+6144|0;c[B+2392>>2]=z;c[B+67928>>2]=z;c[B+133464>>2]=z;z=g+7168|0;c[B+2396>>2]=z;c[B+67932>>2]=z;c[B+133468>>2]=z;z=g+8192|0;c[B+2400>>2]=z;c[B+67936>>2]=z;c[B+133472>>2]=z;z=g+9216|0;c[B+2404>>2]=z;c[B+67940>>2]=z;c[B+133476>>2]=z;z=g+10240|0;c[B+2408>>2]=z;c[B+67944>>2]=z;c[B+133480>>2]=z;z=g+11264|0;c[B+2412>>2]=z;c[B+67948>>2]=z;c[B+133484>>2]=z;z=g+12288|0;c[B+2416>>2]=z;c[B+67952>>2]=z;c[B+133488>>2]=z;z=g+13312|0;c[B+2420>>2]=z;c[B+67956>>2]=z;c[B+133492>>2]=z;z=g+14336|0;c[B+2424>>2]=z;c[B+67960>>2]=z;c[B+133496>>2]=z;z=g+15360|0;c[B+2428>>2]=z;c[B+67964>>2]=z;c[B+133500>>2]=z;z=c[2405794]|0;c[B+2496>>2]=z;c[B+68032>>2]=z;c[B+133568>>2]=z;g=z+1024|0;c[B+2500>>2]=g;c[B+68036>>2]=g;c[B+133572>>2]=g;g=c[2388254]|0;z=B+3840|0;e=983040;while(1){x=g+(e-983040)|0;c[z>>2]=x;c[z+65536>>2]=x;c[z+131072>>2]=x;x=e+1024|0;if(x>>>0>1048575){break}else{z=z+4|0;e=x}}c[B+196728>>2]=1128;c[B+196648>>2]=986;c[B+196688>>2]=396;c[B+196608>>2]=1322;B=c[3532592]|0;if((B|0)!=0){gGC(B|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;w=0;i=a;return w|0}function ery(){var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=i;i=i+720|0;e=d|0;f=d+112|0;g=d+120|0;h=d+232|0;j=d+240|0;k=d+352|0;l=d+360|0;m=d+472|0;n=d+480|0;o=d+592|0;p=d+600|0;q=d+712|0;if((R6((c[2388126]|0)+1|0,0,2)|0)!=0){r=1;i=d;return r|0}if((R6(c[2388126]|0,1,2)|0)!=0){r=1;i=d;return r|0}s=c[2385902]|0;if((c[3542200]|0)==0){r=1;i=d;return r|0}t=p+108|0;c[t>>2]=0;u=p+100|0;c[u>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,2)|0;do{if((c[t>>2]|0)!=0){p=c[u>>2]|0;c[q>>2]=9534384;v=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[v&16383](q,2,0)|0;if((p|0)<1){r=1;i=d;return r|0}if((gzL(s,0,2)|0)==0){break}else{r=1}i=d;return r|0}}while(0);s=c[3530812]|0;if((c[3542200]|0)==0){r=1;i=d;return r|0}q=n+108|0;c[q>>2]=0;u=n+100|0;c[u>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,3)|0;do{if((c[q>>2]|0)!=0){n=c[u>>2]|0;c[o>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](o,3,0)|0;if((n|0)<1){r=1;i=d;return r|0}if((gzL(s,0,3)|0)==0){break}else{r=1}i=d;return r|0}}while(0);s=c[3530576]|0;if((c[3542200]|0)==0){r=1;i=d;return r|0}o=l+108|0;c[o>>2]=0;u=l+100|0;c[u>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,4)|0;do{if((c[o>>2]|0)!=0){l=c[u>>2]|0;c[m>>2]=9534384;q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[q&16383](m,4,0)|0;if((l|0)<1){r=1;i=d;return r|0}if((gzL(s,0,4)|0)==0){break}else{r=1}i=d;return r|0}}while(0);s=c[3530416]|0;if((c[3542200]|0)==0){r=1;i=d;return r|0}m=j+108|0;c[m>>2]=0;u=j+100|0;c[u>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,5)|0;do{if((c[m>>2]|0)!=0){j=c[u>>2]|0;c[k>>2]=9534384;o=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[o&16383](k,5,0)|0;if((j|0)<1){r=1;i=d;return r|0}if((gzL(s,0,5)|0)==0){break}else{r=1}i=d;return r|0}}while(0);s=0;k=c[3530416]|0;while(1){u=a[k]|0;m=k+1|0;a[k]=a[m]|0;a[m]=u;u=s+1|0;if((u|0)<524288){s=u;k=k+2|0}else{break}}k=(c[3529752]|0)+131072|0;if((c[3542200]|0)==0){r=1;i=d;return r|0}s=g+108|0;c[s>>2]=0;u=g+100|0;c[u>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,6)|0;do{if((c[s>>2]|0)!=0){g=c[u>>2]|0;c[h>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](h,6,0)|0;if((g|0)<1){r=1;i=d;return r|0}if((gzL(k,0,6)|0)==0){break}else{r=1}i=d;return r|0}}while(0);k=c[3529752]|0;h=k+131072|0;gGC(k|0,h|0,131072)|0;h=(c[3529708]|0)+131072|0;if((c[3542200]|0)==0){r=1;i=d;return r|0}k=e+108|0;c[k>>2]=0;u=e+100|0;c[u>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,7)|0;do{if((c[k>>2]|0)!=0){e=c[u>>2]|0;c[f>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](f,7,0)|0;if((e|0)<1){r=1;i=d;return r|0}if((gzL(h,0,7)|0)==0){break}else{r=1}i=d;return r|0}}while(0);h=c[3529708]|0;f=h+131072|0;gGC(h|0,f|0,131072)|0;erq(131072,1048576,1048576);f=c[2388126]|0;b[f+1162>>1]=20081;b[f+1194>>1]=20081;fxU(0,425984);if((c[2394]|0)==0){w=c[2112932]|0}else{c[2394]=0;f=c[3532596]|0;c[2112932]=f;h=c[3532592]|0;if((h|0)!=0){gGC(9104152,h|0,280)|0}c[2113054]=c[2113060];w=f}f=c[2388126]|0;h=w|0;u=0;while(1){k=f+u|0;c[h>>2]=k;c[h+131072>>2]=k;k=u+1024|0;if(k>>>0>262143){break}else{h=h+4|0;u=k}}u=c[2387164]|0;c[w+2176>>2]=u;c[w+67712>>2]=u;c[w+133248>>2]=u;h=u+1024|0;c[w+2180>>2]=h;c[w+67716>>2]=h;c[w+133252>>2]=h;c[w+67776>>2]=c[2443470];h=c[2387982]|0;c[w+2304>>2]=h;c[w+67840>>2]=h;c[w+133376>>2]=h;u=h+1024|0;c[w+2308>>2]=u;c[w+67844>>2]=u;c[w+133380>>2]=u;u=h+2048|0;c[w+2312>>2]=u;c[w+67848>>2]=u;c[w+133384>>2]=u;u=h+3072|0;c[w+2316>>2]=u;c[w+67852>>2]=u;c[w+133388>>2]=u;u=h+4096|0;c[w+2320>>2]=u;c[w+67856>>2]=u;c[w+133392>>2]=u;u=h+5120|0;c[w+2324>>2]=u;c[w+67860>>2]=u;c[w+133396>>2]=u;u=h+6144|0;c[w+2328>>2]=u;c[w+67864>>2]=u;c[w+133400>>2]=u;u=h+7168|0;c[w+2332>>2]=u;c[w+67868>>2]=u;c[w+133404>>2]=u;u=h+8192|0;c[w+2336>>2]=u;c[w+67872>>2]=u;c[w+133408>>2]=u;u=h+9216|0;c[w+2340>>2]=u;c[w+67876>>2]=u;c[w+133412>>2]=u;u=h+10240|0;c[w+2344>>2]=u;c[w+67880>>2]=u;c[w+133416>>2]=u;u=h+11264|0;c[w+2348>>2]=u;c[w+67884>>2]=u;c[w+133420>>2]=u;u=h+12288|0;c[w+2352>>2]=u;c[w+67888>>2]=u;c[w+133424>>2]=u;u=h+13312|0;c[w+2356>>2]=u;c[w+67892>>2]=u;c[w+133428>>2]=u;u=h+14336|0;c[w+2360>>2]=u;c[w+67896>>2]=u;c[w+133432>>2]=u;u=h+15360|0;c[w+2364>>2]=u;c[w+67900>>2]=u;c[w+133436>>2]=u;u=c[2405794]|0;c[w+2496>>2]=u;c[w+68032>>2]=u;c[w+133568>>2]=u;h=u+1024|0;c[w+2500>>2]=h;c[w+68036>>2]=h;c[w+133572>>2]=h;h=c[2388254]|0;u=w+3840|0;f=983040;while(1){k=h+(f-983040)|0;c[u>>2]=k;c[u+131072>>2]=k;k=f+1024|0;if(k>>>0>1048575){break}else{u=u+4|0;f=k}}c[w+196728>>2]=2368;c[w+196648>>2]=2398;c[w+196688>>2]=1746;c[w+196608>>2]=1880;w=c[3532592]|0;if((w|0)!=0){gGC(w|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;r=0;i=d;return r|0}function erz(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;a=i;i=i+360|0;b=a|0;d=a+112|0;e=a+120|0;f=a+232|0;g=a+240|0;h=a+352|0;if((R6((c[2388126]|0)+1|0,0,2)|0)!=0){j=1;i=a;return j|0}if((R6(c[2388126]|0,1,2)|0)!=0){j=1;i=a;return j|0}k=c[3530812]|0;if((c[3542200]|0)==0){j=1;i=a;return j|0}l=g+108|0;c[l>>2]=0;m=g+100|0;c[m>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,3)|0;do{if((c[l>>2]|0)!=0){g=c[m>>2]|0;c[h>>2]=9534384;n=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[n&16383](h,3,0)|0;if((g|0)<1){j=1;i=a;return j|0}if((gzL(k,0,3)|0)==0){break}else{j=1}i=a;return j|0}}while(0);k=c[3530576]|0;if((c[3542200]|0)==0){j=1;i=a;return j|0}h=e+108|0;c[h>>2]=0;m=e+100|0;c[m>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,4)|0;do{if((c[h>>2]|0)!=0){e=c[m>>2]|0;c[f>>2]=9534384;l=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[l&16383](f,4,0)|0;if((e|0)<1){j=1;i=a;return j|0}if((gzL(k,0,4)|0)==0){break}else{j=1}i=a;return j|0}}while(0);k=(c[3530576]|0)+262144|0;if((c[3542200]|0)==0){j=1;i=a;return j|0}f=b+108|0;c[f>>2]=0;m=b+100|0;c[m>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](b,5)|0;do{if((c[f>>2]|0)!=0){b=c[m>>2]|0;c[d>>2]=9534384;h=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[h&16383](d,5,0)|0;if((b|0)<1){j=1;i=a;return j|0}if((gzL(k,0,5)|0)==0){break}else{j=1}i=a;return j|0}}while(0);if((R6(c[3530416]|0,6,2)|0)!=0){j=1;i=a;return j|0}if((R6((c[3530416]|0)+1|0,7,2)|0)!=0){j=1;i=a;return j|0}if((R6((c[3530416]|0)+524288|0,8,2)|0)!=0){j=1;i=a;return j|0}if((R6((c[3530416]|0)+524289|0,9,2)|0)!=0){j=1;i=a;return j|0}if((R6((c[3530416]|0)+1048576|0,10,2)|0)!=0){j=1;i=a;return j|0}if((R6((c[3530416]|0)+1048577|0,11,2)|0)!=0){j=1;i=a;return j|0}if((R6((c[3530416]|0)+1310720|0,12,2)|0)!=0){j=1;i=a;return j|0}if((R6((c[3530416]|0)+1310721|0,13,2)|0)!=0){j=1;i=a;return j|0}erq(65536,524288,2097152);fxU(0,425984);if((c[2394]|0)==0){o=c[2112932]|0}else{c[2394]=0;k=c[3532596]|0;c[2112932]=k;d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];o=k}k=c[2388126]|0;d=o|0;m=0;while(1){f=k+m|0;c[d>>2]=f;c[d+131072>>2]=f;f=m+1024|0;if(f>>>0>262143){break}else{d=d+4|0;m=f}}m=c[2387164]|0;c[o+2176>>2]=m;c[o+67712>>2]=m;c[o+133248>>2]=m;d=m+1024|0;c[o+2180>>2]=d;c[o+67716>>2]=d;c[o+133252>>2]=d;d=c[2387982]|0;c[o+2304>>2]=d;c[o+67840>>2]=d;c[o+133376>>2]=d;m=d+1024|0;c[o+2308>>2]=m;c[o+67844>>2]=m;c[o+133380>>2]=m;m=d+2048|0;c[o+2312>>2]=m;c[o+67848>>2]=m;c[o+133384>>2]=m;m=d+3072|0;c[o+2316>>2]=m;c[o+67852>>2]=m;c[o+133388>>2]=m;m=d+4096|0;c[o+2320>>2]=m;c[o+67856>>2]=m;c[o+133392>>2]=m;m=d+5120|0;c[o+2324>>2]=m;c[o+67860>>2]=m;c[o+133396>>2]=m;m=d+6144|0;c[o+2328>>2]=m;c[o+67864>>2]=m;c[o+133400>>2]=m;m=d+7168|0;c[o+2332>>2]=m;c[o+67868>>2]=m;c[o+133404>>2]=m;m=d+8192|0;c[o+2336>>2]=m;c[o+67872>>2]=m;c[o+133408>>2]=m;m=d+9216|0;c[o+2340>>2]=m;c[o+67876>>2]=m;c[o+133412>>2]=m;m=d+10240|0;c[o+2344>>2]=m;c[o+67880>>2]=m;c[o+133416>>2]=m;m=d+11264|0;c[o+2348>>2]=m;c[o+67884>>2]=m;c[o+133420>>2]=m;m=d+12288|0;c[o+2352>>2]=m;c[o+67888>>2]=m;c[o+133424>>2]=m;m=d+13312|0;c[o+2356>>2]=m;c[o+67892>>2]=m;c[o+133428>>2]=m;m=d+14336|0;c[o+2360>>2]=m;c[o+67896>>2]=m;c[o+133432>>2]=m;m=d+15360|0;c[o+2364>>2]=m;c[o+67900>>2]=m;c[o+133436>>2]=m;m=c[2405794]|0;c[o+2512>>2]=m;c[o+68048>>2]=m;c[o+133584>>2]=m;d=m+1024|0;c[o+2516>>2]=d;c[o+68052>>2]=d;c[o+133588>>2]=d;d=c[2388254]|0;m=o+3840|0;k=983040;while(1){f=d+(k-983040)|0;c[m>>2]=f;c[m+65536>>2]=f;c[m+131072>>2]=f;f=k+1024|0;if(f>>>0>1048575){break}else{m=m+4|0;k=f}}c[o+196728>>2]=2100;c[o+196648>>2]=2930;c[o+196688>>2]=396;c[o+196608>>2]=1322;o=c[3532592]|0;if((o|0)!=0){gGC(o|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;j=0;i=a;return j|0}function erA(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;a=i;i=i+600|0;b=a|0;d=a+112|0;e=a+120|0;f=a+232|0;g=a+240|0;h=a+352|0;j=a+360|0;k=a+472|0;l=a+480|0;m=a+592|0;if((R6((c[2388126]|0)+1|0,0,2)|0)!=0){n=1;i=a;return n|0}if((R6(c[2388126]|0,1,2)|0)!=0){n=1;i=a;return n|0}o=c[2385902]|0;if((c[3542200]|0)==0){n=1;i=a;return n|0}p=l+108|0;c[p>>2]=0;q=l+100|0;c[q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,2)|0;do{if((c[p>>2]|0)!=0){l=c[q>>2]|0;c[m>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](m,2,0)|0;if((l|0)<1){n=1;i=a;return n|0}if((gzL(o,0,2)|0)==0){break}else{n=1}i=a;return n|0}}while(0);o=c[3530812]|0;if((c[3542200]|0)==0){n=1;i=a;return n|0}m=j+108|0;c[m>>2]=0;q=j+100|0;c[q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,3)|0;do{if((c[m>>2]|0)!=0){j=c[q>>2]|0;c[k>>2]=9534384;p=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[p&16383](k,3,0)|0;if((j|0)<1){n=1;i=a;return n|0}if((gzL(o,0,3)|0)==0){break}else{n=1}i=a;return n|0}}while(0);o=c[3530576]|0;if((c[3542200]|0)==0){n=1;i=a;return n|0}k=g+108|0;c[k>>2]=0;q=g+100|0;c[q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,4)|0;do{if((c[k>>2]|0)!=0){g=c[q>>2]|0;c[h>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](h,4,0)|0;if((g|0)<1){n=1;i=a;return n|0}if((gzL(o,0,4)|0)==0){break}else{n=1}i=a;return n|0}}while(0);if((R6(c[3530416]|0,5,2)|0)!=0){n=1;i=a;return n|0}if((R6((c[3530416]|0)+1|0,6,2)|0)!=0){n=1;i=a;return n|0}if((R6((c[3530416]|0)+1048576|0,7,2)|0)!=0){n=1;i=a;return n|0}if((R6((c[3530416]|0)+1048577|0,8,2)|0)!=0){n=1;i=a;return n|0}o=(c[3529752]|0)+131072|0;if((c[3542200]|0)==0){n=1;i=a;return n|0}h=e+108|0;c[h>>2]=0;q=e+100|0;c[q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,9)|0;do{if((c[h>>2]|0)!=0){e=c[q>>2]|0;c[f>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](f,9,0)|0;if((e|0)<1){n=1;i=a;return n|0}if((gzL(o,0,9)|0)==0){break}else{n=1}i=a;return n|0}}while(0);o=c[3529752]|0;f=o+131072|0;gGC(o|0,f|0,131072)|0;f=(c[3529708]|0)+131072|0;if((c[3542200]|0)==0){n=1;i=a;return n|0}o=b+108|0;c[o>>2]=0;q=b+100|0;c[q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](b,10)|0;do{if((c[o>>2]|0)!=0){b=c[q>>2]|0;c[d>>2]=9534384;h=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[h&16383](d,10,0)|0;if((b|0)<1){n=1;i=a;return n|0}if((gzL(f,0,10)|0)==0){break}else{n=1}i=a;return n|0}}while(0);f=c[3529708]|0;d=f+131072|0;gGC(f|0,d|0,131072)|0;erq(65536,524288,2097152);fxU(0,425984);if((c[2394]|0)==0){s=c[2112932]|0}else{c[2394]=0;d=c[3532596]|0;c[2112932]=d;f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];s=d}d=c[2388126]|0;f=s|0;q=0;while(1){o=d+q|0;c[f>>2]=o;c[f+131072>>2]=o;o=q+1024|0;if(o>>>0>262143){break}else{f=f+4|0;q=o}}q=c[2387164]|0;c[s+2176>>2]=q;c[s+67712>>2]=q;c[s+133248>>2]=q;f=q+1024|0;c[s+2180>>2]=f;c[s+67716>>2]=f;c[s+133252>>2]=f;f=c[2443470]|0;c[s+2240>>2]=f;c[s+67776>>2]=f;c[s+133312>>2]=f;f=c[2387982]|0;c[s+2304>>2]=f;c[s+67840>>2]=f;c[s+133376>>2]=f;q=f+1024|0;c[s+2308>>2]=q;c[s+67844>>2]=q;c[s+133380>>2]=q;q=f+2048|0;c[s+2312>>2]=q;c[s+67848>>2]=q;c[s+133384>>2]=q;q=f+3072|0;c[s+2316>>2]=q;c[s+67852>>2]=q;c[s+133388>>2]=q;q=f+4096|0;c[s+2320>>2]=q;c[s+67856>>2]=q;c[s+133392>>2]=q;q=f+5120|0;c[s+2324>>2]=q;c[s+67860>>2]=q;c[s+133396>>2]=q;q=f+6144|0;c[s+2328>>2]=q;c[s+67864>>2]=q;c[s+133400>>2]=q;q=f+7168|0;c[s+2332>>2]=q;c[s+67868>>2]=q;c[s+133404>>2]=q;q=f+8192|0;c[s+2336>>2]=q;c[s+67872>>2]=q;c[s+133408>>2]=q;q=f+9216|0;c[s+2340>>2]=q;c[s+67876>>2]=q;c[s+133412>>2]=q;q=f+10240|0;c[s+2344>>2]=q;c[s+67880>>2]=q;c[s+133416>>2]=q;q=f+11264|0;c[s+2348>>2]=q;c[s+67884>>2]=q;c[s+133420>>2]=q;q=f+12288|0;c[s+2352>>2]=q;c[s+67888>>2]=q;c[s+133424>>2]=q;q=f+13312|0;c[s+2356>>2]=q;c[s+67892>>2]=q;c[s+133428>>2]=q;q=f+14336|0;c[s+2360>>2]=q;c[s+67896>>2]=q;c[s+133432>>2]=q;q=f+15360|0;c[s+2364>>2]=q;c[s+67900>>2]=q;c[s+133436>>2]=q;q=c[2405794]|0;c[s+2512>>2]=q;c[s+68048>>2]=q;c[s+133584>>2]=q;f=q+1024|0;c[s+2516>>2]=f;c[s+68052>>2]=f;c[s+133588>>2]=f;f=c[2388254]|0;q=s+3840|0;d=983040;while(1){o=f+(d-983040)|0;c[q>>2]=o;c[q+65536>>2]=o;c[q+131072>>2]=o;o=d+1024|0;if(o>>>0>1048575){break}else{q=q+4|0;d=o}}c[s+196728>>2]=1128;c[s+196648>>2]=986;c[s+196688>>2]=396;c[s+196608>>2]=1322;s=c[3532592]|0;if((s|0)!=0){gGC(s|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;n=0;i=a;return n|0}function erB(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;b=i;i=i+720|0;d=b|0;e=b+112|0;f=b+120|0;g=b+232|0;h=b+240|0;j=b+352|0;k=b+360|0;l=b+472|0;m=b+480|0;n=b+592|0;o=b+600|0;p=b+712|0;if((R6((c[2388126]|0)+1|0,0,2)|0)!=0){q=1;i=b;return q|0}if((R6(c[2388126]|0,1,2)|0)!=0){q=1;i=b;return q|0}r=c[2385902]|0;if((c[3542200]|0)==0){q=1;i=b;return q|0}s=o+108|0;c[s>>2]=0;t=o+100|0;c[t>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](o,2)|0;do{if((c[s>>2]|0)!=0){o=c[t>>2]|0;c[p>>2]=9534384;u=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[u&16383](p,2,0)|0;if((o|0)<1){q=1;i=b;return q|0}if((gzL(r,0,2)|0)==0){break}else{q=1}i=b;return q|0}}while(0);r=c[3530812]|0;if((c[3542200]|0)==0){q=1;i=b;return q|0}p=m+108|0;c[p>>2]=0;t=m+100|0;c[t>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,3)|0;do{if((c[p>>2]|0)!=0){m=c[t>>2]|0;c[n>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](n,3,0)|0;if((m|0)<1){q=1;i=b;return q|0}if((gzL(r,0,3)|0)==0){break}else{q=1}i=b;return q|0}}while(0);r=c[3530576]|0;if((c[3542200]|0)==0){q=1;i=b;return q|0}n=k+108|0;c[n>>2]=0;t=k+100|0;c[t>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,4)|0;do{if((c[n>>2]|0)!=0){k=c[t>>2]|0;c[l>>2]=9534384;p=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[p&16383](l,4,0)|0;if((k|0)<1){q=1;i=b;return q|0}if((gzL(r,0,4)|0)==0){break}else{q=1}i=b;return q|0}}while(0);r=c[3530416]|0;if((c[3542200]|0)==0){q=1;i=b;return q|0}l=h+108|0;c[l>>2]=0;t=h+100|0;c[t>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](h,5)|0;do{if((c[l>>2]|0)!=0){h=c[t>>2]|0;c[j>>2]=9534384;n=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[n&16383](j,5,0)|0;if((h|0)<1){q=1;i=b;return q|0}if((gzL(r,0,5)|0)==0){break}else{q=1}i=b;return q|0}}while(0);r=0;j=c[3530416]|0;while(1){t=a[j]|0;l=j+1|0;a[j]=a[l]|0;a[l]=t;t=r+1|0;if((t|0)<524288){r=t;j=j+2|0}else{break}}j=(c[3529752]|0)+131072|0;if((c[3542200]|0)==0){q=1;i=b;return q|0}r=f+108|0;c[r>>2]=0;t=f+100|0;c[t>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,6)|0;do{if((c[r>>2]|0)!=0){f=c[t>>2]|0;c[g>>2]=9534384;l=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[l&16383](g,6,0)|0;if((f|0)<1){q=1;i=b;return q|0}if((gzL(j,0,6)|0)==0){break}else{q=1}i=b;return q|0}}while(0);j=c[3529752]|0;g=j+131072|0;gGC(j|0,g|0,131072)|0;g=(c[3529708]|0)+131072|0;if((c[3542200]|0)==0){q=1;i=b;return q|0}j=d+108|0;c[j>>2]=0;t=d+100|0;c[t>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](d,7)|0;do{if((c[j>>2]|0)!=0){d=c[t>>2]|0;c[e>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](e,7,0)|0;if((d|0)<1){q=1;i=b;return q|0}if((gzL(g,0,7)|0)==0){break}else{q=1}i=b;return q|0}}while(0);g=c[3529708]|0;e=g+131072|0;gGC(g|0,e|0,131072)|0;erq(131072,1048576,1048576);fxU(0,425984);if((c[2394]|0)==0){v=c[2112932]|0}else{c[2394]=0;e=c[3532596]|0;c[2112932]=e;g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060];v=e}e=c[2388126]|0;g=v|0;t=0;while(1){j=e+t|0;c[g>>2]=j;c[g+131072>>2]=j;j=t+1024|0;if(j>>>0>524287){break}else{g=g+4|0;t=j}}t=c[2387164]|0;c[v+2176>>2]=t;c[v+67712>>2]=t;c[v+133248>>2]=t;g=t+1024|0;c[v+2180>>2]=g;c[v+67716>>2]=g;c[v+133252>>2]=g;c[v+67776>>2]=c[2443470];g=c[2387982]|0;c[v+2304>>2]=g;c[v+67840>>2]=g;c[v+133376>>2]=g;t=g+1024|0;c[v+2308>>2]=t;c[v+67844>>2]=t;c[v+133380>>2]=t;t=g+2048|0;c[v+2312>>2]=t;c[v+67848>>2]=t;c[v+133384>>2]=t;t=g+3072|0;c[v+2316>>2]=t;c[v+67852>>2]=t;c[v+133388>>2]=t;t=g+4096|0;c[v+2320>>2]=t;c[v+67856>>2]=t;c[v+133392>>2]=t;t=g+5120|0;c[v+2324>>2]=t;c[v+67860>>2]=t;c[v+133396>>2]=t;t=g+6144|0;c[v+2328>>2]=t;c[v+67864>>2]=t;c[v+133400>>2]=t;t=g+7168|0;c[v+2332>>2]=t;c[v+67868>>2]=t;c[v+133404>>2]=t;t=g+8192|0;c[v+2336>>2]=t;c[v+67872>>2]=t;c[v+133408>>2]=t;t=g+9216|0;c[v+2340>>2]=t;c[v+67876>>2]=t;c[v+133412>>2]=t;t=g+10240|0;c[v+2344>>2]=t;c[v+67880>>2]=t;c[v+133416>>2]=t;t=g+11264|0;c[v+2348>>2]=t;c[v+67884>>2]=t;c[v+133420>>2]=t;t=g+12288|0;c[v+2352>>2]=t;c[v+67888>>2]=t;c[v+133424>>2]=t;t=g+13312|0;c[v+2356>>2]=t;c[v+67892>>2]=t;c[v+133428>>2]=t;t=g+14336|0;c[v+2360>>2]=t;c[v+67896>>2]=t;c[v+133432>>2]=t;t=g+15360|0;c[v+2364>>2]=t;c[v+67900>>2]=t;c[v+133436>>2]=t;t=c[2405794]|0;c[v+2496>>2]=t;c[v+68032>>2]=t;c[v+133568>>2]=t;g=t+1024|0;c[v+2500>>2]=g;c[v+68036>>2]=g;c[v+133572>>2]=g;g=c[2388254]|0;t=v+3840|0;e=983040;while(1){j=g+(e-983040)|0;c[t>>2]=j;c[t+131072>>2]=j;j=e+1024|0;if(j>>>0>1048575){break}else{t=t+4|0;e=j}}c[v+196728>>2]=1128;c[v+196648>>2]=986;c[v+196688>>2]=396;c[v+196608>>2]=1322;v=c[3532592]|0;if((v|0)!=0){gGC(v|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;q=0;i=b;return q|0}function erC(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;b=i;i=i+720|0;d=b|0;e=b+112|0;f=b+120|0;g=b+232|0;h=b+240|0;j=b+352|0;k=b+360|0;l=b+472|0;m=b+480|0;n=b+592|0;o=b+600|0;p=b+712|0;if((R6((c[2388126]|0)+1|0,0,2)|0)!=0){q=1;i=b;return q|0}if((R6(c[2388126]|0,1,2)|0)!=0){q=1;i=b;return q|0}r=c[2385902]|0;if((c[3542200]|0)==0){q=1;i=b;return q|0}s=o+108|0;c[s>>2]=0;t=o+100|0;c[t>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](o,2)|0;do{if((c[s>>2]|0)!=0){o=c[t>>2]|0;c[p>>2]=9534384;u=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[u&16383](p,2,0)|0;if((o|0)<1){q=1;i=b;return q|0}if((gzL(r,0,2)|0)==0){break}else{q=1}i=b;return q|0}}while(0);r=c[3530812]|0;if((c[3542200]|0)==0){q=1;i=b;return q|0}p=m+108|0;c[p>>2]=0;t=m+100|0;c[t>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,3)|0;do{if((c[p>>2]|0)!=0){m=c[t>>2]|0;c[n>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](n,3,0)|0;if((m|0)<1){q=1;i=b;return q|0}if((gzL(r,0,3)|0)==0){break}else{q=1}i=b;return q|0}}while(0);r=c[3530576]|0;if((c[3542200]|0)==0){q=1;i=b;return q|0}n=k+108|0;c[n>>2]=0;t=k+100|0;c[t>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,4)|0;do{if((c[n>>2]|0)!=0){k=c[t>>2]|0;c[l>>2]=9534384;p=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[p&16383](l,4,0)|0;if((k|0)<1){q=1;i=b;return q|0}if((gzL(r,0,4)|0)==0){break}else{q=1}i=b;return q|0}}while(0);r=c[3530416]|0;if((c[3542200]|0)==0){q=1;i=b;return q|0}l=h+108|0;c[l>>2]=0;t=h+100|0;c[t>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](h,5)|0;do{if((c[l>>2]|0)!=0){h=c[t>>2]|0;c[j>>2]=9534384;n=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[n&16383](j,5,0)|0;if((h|0)<1){q=1;i=b;return q|0}if((gzL(r,0,5)|0)==0){break}else{q=1}i=b;return q|0}}while(0);r=0;j=c[3530416]|0;while(1){t=a[j]|0;l=j+1|0;a[j]=a[l]|0;a[l]=t;t=r+1|0;if((t|0)<1048576){r=t;j=j+2|0}else{break}}j=(c[3529752]|0)+131072|0;if((c[3542200]|0)==0){q=1;i=b;return q|0}r=f+108|0;c[r>>2]=0;t=f+100|0;c[t>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,5)|0;do{if((c[r>>2]|0)!=0){f=c[t>>2]|0;c[g>>2]=9534384;l=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[l&16383](g,5,0)|0;if((f|0)<1){q=1;i=b;return q|0}if((gzL(j,0,5)|0)==0){break}else{q=1}i=b;return q|0}}while(0);j=c[3529752]|0;g=j+131072|0;gGC(j|0,g|0,131072)|0;g=(c[3529708]|0)+131072|0;if((c[3542200]|0)==0){q=1;i=b;return q|0}j=d+108|0;c[j>>2]=0;t=d+100|0;c[t>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](d,6)|0;do{if((c[j>>2]|0)!=0){d=c[t>>2]|0;c[e>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](e,6,0)|0;if((d|0)<1){q=1;i=b;return q|0}if((gzL(g,0,6)|0)==0){break}else{q=1}i=b;return q|0}}while(0);g=c[3529708]|0;e=g+131072|0;gGC(g|0,e|0,131072)|0;erD(1048576,2097152);erq(131072,1048576,2097152);fxU(0,425984);if((c[2394]|0)==0){v=c[2112932]|0}else{c[2394]=0;e=c[3532596]|0;c[2112932]=e;g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060];v=e}e=c[2388126]|0;g=v|0;t=0;while(1){j=e+t|0;c[g>>2]=j;c[g+131072>>2]=j;j=t+1024|0;if(j>>>0>524287){break}else{g=g+4|0;t=j}}t=c[2387164]|0;c[v+2176>>2]=t;c[v+67712>>2]=t;c[v+133248>>2]=t;g=t+1024|0;c[v+2180>>2]=g;c[v+67716>>2]=g;c[v+133252>>2]=g;g=c[2443470]|0;c[v+67776>>2]=g;c[v+67780>>2]=g+1024;g=c[2387982]|0;c[v+2304>>2]=g;c[v+67840>>2]=g;c[v+133376>>2]=g;t=g+1024|0;c[v+2308>>2]=t;c[v+67844>>2]=t;c[v+133380>>2]=t;t=g+2048|0;c[v+2312>>2]=t;c[v+67848>>2]=t;c[v+133384>>2]=t;t=g+3072|0;c[v+2316>>2]=t;c[v+67852>>2]=t;c[v+133388>>2]=t;t=g+4096|0;c[v+2320>>2]=t;c[v+67856>>2]=t;c[v+133392>>2]=t;t=g+5120|0;c[v+2324>>2]=t;c[v+67860>>2]=t;c[v+133396>>2]=t;t=g+6144|0;c[v+2328>>2]=t;c[v+67864>>2]=t;c[v+133400>>2]=t;t=g+7168|0;c[v+2332>>2]=t;c[v+67868>>2]=t;c[v+133404>>2]=t;t=g+8192|0;c[v+2336>>2]=t;c[v+67872>>2]=t;c[v+133408>>2]=t;t=g+9216|0;c[v+2340>>2]=t;c[v+67876>>2]=t;c[v+133412>>2]=t;t=g+10240|0;c[v+2344>>2]=t;c[v+67880>>2]=t;c[v+133416>>2]=t;t=g+11264|0;c[v+2348>>2]=t;c[v+67884>>2]=t;c[v+133420>>2]=t;t=g+12288|0;c[v+2352>>2]=t;c[v+67888>>2]=t;c[v+133424>>2]=t;t=g+13312|0;c[v+2356>>2]=t;c[v+67892>>2]=t;c[v+133428>>2]=t;t=g+14336|0;c[v+2360>>2]=t;c[v+67896>>2]=t;c[v+133432>>2]=t;t=g+15360|0;c[v+2364>>2]=t;c[v+67900>>2]=t;c[v+133436>>2]=t;t=c[2405794]|0;c[v+2496>>2]=t;c[v+68032>>2]=t;c[v+133568>>2]=t;g=t+1024|0;c[v+2500>>2]=g;c[v+68036>>2]=g;c[v+133572>>2]=g;e=t+2048|0;c[v+2504>>2]=e;c[v+68040>>2]=e;c[v+133576>>2]=e;j=t+3072|0;c[v+2508>>2]=j;c[v+68044>>2]=j;c[v+133580>>2]=j;c[v+2512>>2]=t;c[v+68048>>2]=t;c[v+133584>>2]=t;c[v+2516>>2]=g;c[v+68052>>2]=g;c[v+133588>>2]=g;c[v+2520>>2]=e;c[v+68056>>2]=e;c[v+133592>>2]=e;c[v+2524>>2]=j;c[v+68060>>2]=j;c[v+133596>>2]=j;j=c[2388254]|0;e=v+3840|0;g=983040;while(1){t=j+(g-983040)|0;c[e>>2]=t;c[e+65536>>2]=t;c[e+131072>>2]=t;t=g+1024|0;if(t>>>0>1048575){break}else{e=e+4|0;g=t}}c[v+196728>>2]=1128;c[v+196648>>2]=986;c[v+196688>>2]=396;c[v+196608>>2]=1322;v=c[3532592]|0;if((v|0)!=0){gGC(v|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;q=0;i=b;return q|0}function erD(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((b|0)>0){f=c[3530576]|0;g=0;do{h=f+g|0;i=g>>>2&1|g>>>10&2|g>>>16&4;j=d[h]|0;a[h]=(j>>>((d[614537+(i<<3)|0]|0)>>>0)<<6&64|j>>>((d[614536+(i<<3)|0]|0)>>>0)<<7&128|j>>>((d[614538+(i<<3)|0]|0)>>>0)<<5&32|j>>>((d[614539+(i<<3)|0]|0)>>>0)<<4&16|j>>>((d[614540+(i<<3)|0]|0)>>>0)<<3&8|j>>>((d[614541+(i<<3)|0]|0)>>>0)<<2&4|j>>>((d[614542+(i<<3)|0]|0)>>>0)<<1&2|j>>>((d[614543+(i<<3)|0]|0)>>>0)&1)&255;g=g+1|0;}while((g|0)<(b|0))}if((e|0)<=0){return}b=c[3530416]|0;g=0;do{f=b+(g|1)|0;i=b+g|0;j=g>>>4&1|g>>>16&2|g>>>18&4;h=((d[f]|0)<<8|(d[i]|0))&65535;k=0;l=0;do{m=(h>>>((d[614408+(j<<4)+l|0]|0)>>>0)&1)<<15-l|k&65535;k=m&65535;l=l+1|0;}while((l|0)<16);a[f]=(k&65535)>>>8&255;a[i]=m&255;g=g+2|0;}while((g|0)<(e|0));return}function erE(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;b=i;i=i+840|0;d=b|0;e=b+112|0;f=b+120|0;g=b+232|0;h=b+240|0;j=b+352|0;k=b+360|0;l=b+472|0;m=b+480|0;n=b+592|0;o=b+600|0;p=b+712|0;q=b+720|0;r=b+832|0;s=c[2388126]|0;if((c[3542200]|0)==0){t=1;i=b;return t|0}u=q+108|0;c[u>>2]=0;v=q+100|0;c[v>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](q,0)|0;do{if((c[u>>2]|0)!=0){q=c[v>>2]|0;c[r>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](r,0,0)|0;if((q|0)<1){t=1;i=b;return t|0}if((gzL(s,0,0)|0)==0){break}else{t=1}i=b;return t|0}}while(0);s=c[2385902]|0;if((c[3542200]|0)==0){t=1;i=b;return t|0}r=o+108|0;c[r>>2]=0;v=o+100|0;c[v>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](o,1)|0;do{if((c[r>>2]|0)!=0){o=c[v>>2]|0;c[p>>2]=9534384;u=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[u&16383](p,1,0)|0;if((o|0)<1){t=1;i=b;return t|0}if((gzL(s,0,1)|0)==0){break}else{t=1}i=b;return t|0}}while(0);s=c[3530812]|0;if((c[3542200]|0)==0){t=1;i=b;return t|0}p=m+108|0;c[p>>2]=0;v=m+100|0;c[v>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,2)|0;do{if((c[p>>2]|0)!=0){m=c[v>>2]|0;c[n>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](n,2,0)|0;if((m|0)<1){t=1;i=b;return t|0}if((gzL(s,0,2)|0)==0){break}else{t=1}i=b;return t|0}}while(0);s=c[3530576]|0;if((c[3542200]|0)==0){t=1;i=b;return t|0}n=k+108|0;c[n>>2]=0;v=k+100|0;c[v>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,3)|0;do{if((c[n>>2]|0)!=0){k=c[v>>2]|0;c[l>>2]=9534384;p=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[p&16383](l,3,0)|0;if((k|0)<1){t=1;i=b;return t|0}if((gzL(s,0,3)|0)==0){break}else{t=1}i=b;return t|0}}while(0);s=c[3530416]|0;if((c[3542200]|0)==0){t=1;i=b;return t|0}l=h+108|0;c[l>>2]=0;v=h+100|0;c[v>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](h,4)|0;do{if((c[l>>2]|0)!=0){h=c[v>>2]|0;c[j>>2]=9534384;n=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[n&16383](j,4,0)|0;if((h|0)<1){t=1;i=b;return t|0}if((gzL(s,0,4)|0)==0){break}else{t=1}i=b;return t|0}}while(0);s=0;j=c[3530416]|0;while(1){v=a[j]|0;l=j+1|0;a[j]=a[l]|0;a[l]=v;v=s+1|0;if((v|0)<1048576){s=v;j=j+2|0}else{break}}j=(c[3529752]|0)+131072|0;if((c[3542200]|0)==0){t=1;i=b;return t|0}s=f+108|0;c[s>>2]=0;v=f+100|0;c[v>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,5)|0;do{if((c[s>>2]|0)!=0){f=c[v>>2]|0;c[g>>2]=9534384;l=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[l&16383](g,5,0)|0;if((f|0)<1){t=1;i=b;return t|0}if((gzL(j,0,5)|0)==0){break}else{t=1}i=b;return t|0}}while(0);j=c[3529752]|0;g=j+131072|0;gGC(j|0,g|0,131072)|0;g=(c[3529708]|0)+131072|0;if((c[3542200]|0)==0){t=1;i=b;return t|0}j=d+108|0;c[j>>2]=0;v=d+100|0;c[v>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](d,6)|0;do{if((c[j>>2]|0)!=0){d=c[v>>2]|0;c[e>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](e,6,0)|0;if((d|0)<1){t=1;i=b;return t|0}if((gzL(g,0,6)|0)==0){break}else{t=1}i=b;return t|0}}while(0);g=c[3529708]|0;e=g+131072|0;gGC(g|0,e|0,131072)|0;erD(2097152,2097152);erq(131072,2097152,2097152);fxU(0,425984);if((c[2394]|0)==0){x=c[2112932]|0}else{c[2394]=0;e=c[3532596]|0;c[2112932]=e;g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060];x=e}e=c[2388126]|0;g=x|0;v=0;while(1){j=e+v|0;c[g>>2]=j;c[g+131072>>2]=j;j=v+1024|0;if(j>>>0>524287){break}else{g=g+4|0;v=j}}v=c[2387164]|0;c[x+2176>>2]=v;c[x+67712>>2]=v;c[x+133248>>2]=v;g=v+1024|0;c[x+2180>>2]=g;c[x+67716>>2]=g;c[x+133252>>2]=g;c[x+67776>>2]=c[2443470];g=c[2387982]|0;c[x+2304>>2]=g;c[x+67840>>2]=g;c[x+133376>>2]=g;v=g+1024|0;c[x+2308>>2]=v;c[x+67844>>2]=v;c[x+133380>>2]=v;v=g+2048|0;c[x+2312>>2]=v;c[x+67848>>2]=v;c[x+133384>>2]=v;v=g+3072|0;c[x+2316>>2]=v;c[x+67852>>2]=v;c[x+133388>>2]=v;v=g+4096|0;c[x+2320>>2]=v;c[x+67856>>2]=v;c[x+133392>>2]=v;v=g+5120|0;c[x+2324>>2]=v;c[x+67860>>2]=v;c[x+133396>>2]=v;v=g+6144|0;c[x+2328>>2]=v;c[x+67864>>2]=v;c[x+133400>>2]=v;v=g+7168|0;c[x+2332>>2]=v;c[x+67868>>2]=v;c[x+133404>>2]=v;v=g+8192|0;c[x+2336>>2]=v;c[x+67872>>2]=v;c[x+133408>>2]=v;v=g+9216|0;c[x+2340>>2]=v;c[x+67876>>2]=v;c[x+133412>>2]=v;v=g+10240|0;c[x+2344>>2]=v;c[x+67880>>2]=v;c[x+133416>>2]=v;v=g+11264|0;c[x+2348>>2]=v;c[x+67884>>2]=v;c[x+133420>>2]=v;v=g+12288|0;c[x+2352>>2]=v;c[x+67888>>2]=v;c[x+133424>>2]=v;v=g+13312|0;c[x+2356>>2]=v;c[x+67892>>2]=v;c[x+133428>>2]=v;v=g+14336|0;c[x+2360>>2]=v;c[x+67896>>2]=v;c[x+133432>>2]=v;v=g+15360|0;c[x+2364>>2]=v;c[x+67900>>2]=v;c[x+133436>>2]=v;v=c[2405794]|0;c[x+2496>>2]=v;c[x+68032>>2]=v;c[x+133568>>2]=v;g=v+1024|0;c[x+2500>>2]=g;c[x+68036>>2]=g;c[x+133572>>2]=g;g=c[2388254]|0;v=x+3840|0;e=983040;while(1){j=g+(e-983040)|0;c[v>>2]=j;c[v+131072>>2]=j;j=e+1024|0;if(j>>>0>1048575){break}else{v=v+4|0;e=j}}c[x+196728>>2]=1128;c[x+196648>>2]=986;c[x+196688>>2]=396;c[x+196608>>2]=1322;x=c[3532592]|0;if((x|0)!=0){gGC(x|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;t=0;i=b;return t|0}function erF(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;a=i;i=i+840|0;b=a|0;d=a+112|0;e=a+120|0;f=a+232|0;g=a+240|0;h=a+352|0;j=a+360|0;k=a+472|0;l=a+480|0;m=a+592|0;n=a+600|0;o=a+712|0;p=a+720|0;q=a+832|0;if((R6((c[2388126]|0)+1|0,0,2)|0)!=0){r=1;i=a;return r|0}if((R6(c[2388126]|0,1,2)|0)!=0){r=1;i=a;return r|0}s=c[2385902]|0;if((c[3542200]|0)==0){r=1;i=a;return r|0}t=p+108|0;c[t>>2]=0;u=p+100|0;c[u>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,2)|0;do{if((c[t>>2]|0)!=0){p=c[u>>2]|0;c[q>>2]=9534384;v=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[v&16383](q,2,0)|0;if((p|0)<1){r=1;i=a;return r|0}if((gzL(s,0,2)|0)==0){break}else{r=1}i=a;return r|0}}while(0);s=c[3530812]|0;if((c[3542200]|0)==0){r=1;i=a;return r|0}q=n+108|0;c[q>>2]=0;u=n+100|0;c[u>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,3)|0;do{if((c[q>>2]|0)!=0){n=c[u>>2]|0;c[o>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](o,3,0)|0;if((n|0)<1){r=1;i=a;return r|0}if((gzL(s,0,3)|0)==0){break}else{r=1}i=a;return r|0}}while(0);s=c[3530576]|0;if((c[3542200]|0)==0){r=1;i=a;return r|0}o=l+108|0;c[o>>2]=0;u=l+100|0;c[u>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,4)|0;do{if((c[o>>2]|0)!=0){l=c[u>>2]|0;c[m>>2]=9534384;q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[q&16383](m,4,0)|0;if((l|0)<1){r=1;i=a;return r|0}if((gzL(s,0,4)|0)==0){break}else{r=1}i=a;return r|0}}while(0);s=c[3530416]|0;if((c[3542200]|0)==0){r=1;i=a;return r|0}m=j+108|0;c[m>>2]=0;u=j+100|0;c[u>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,5)|0;do{if((c[m>>2]|0)!=0){j=c[u>>2]|0;c[k>>2]=9534384;o=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[o&16383](k,5,0)|0;if((j|0)<1){r=1;i=a;return r|0}if((gzL(s,0,5)|0)==0){break}else{r=1}i=a;return r|0}}while(0);s=(c[3530416]|0)+1048576|0;if((c[3542200]|0)==0){r=1;i=a;return r|0}k=g+108|0;c[k>>2]=0;u=g+100|0;c[u>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,6)|0;do{if((c[k>>2]|0)!=0){g=c[u>>2]|0;c[h>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](h,6,0)|0;if((g|0)<1){r=1;i=a;return r|0}if((gzL(s,0,6)|0)==0){break}else{r=1}i=a;return r|0}}while(0);s=(c[3529752]|0)+131072|0;if((c[3542200]|0)==0){r=1;i=a;return r|0}h=e+108|0;c[h>>2]=0;u=e+100|0;c[u>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,7)|0;do{if((c[h>>2]|0)!=0){e=c[u>>2]|0;c[f>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](f,7,0)|0;if((e|0)<1){r=1;i=a;return r|0}if((gzL(s,0,7)|0)==0){break}else{r=1}i=a;return r|0}}while(0);s=c[3529752]|0;f=s+131072|0;gGC(s|0,f|0,131072)|0;f=(c[3529708]|0)+131072|0;if((c[3542200]|0)==0){r=1;i=a;return r|0}s=b+108|0;c[s>>2]=0;u=b+100|0;c[u>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](b,8)|0;do{if((c[s>>2]|0)!=0){b=c[u>>2]|0;c[d>>2]=9534384;h=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[h&16383](d,8,0)|0;if((b|0)<1){r=1;i=a;return r|0}if((gzL(f,0,8)|0)==0){break}else{r=1}i=a;return r|0}}while(0);f=c[3529708]|0;d=f+131072|0;gGC(f|0,d|0,131072)|0;erq(65536,1048576,2097152);fxU(0,425984);if((c[2394]|0)==0){w=c[2112932]|0}else{c[2394]=0;d=c[3532596]|0;c[2112932]=d;f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];w=d}d=c[2388126]|0;f=w|0;u=0;while(1){s=d+u|0;c[f>>2]=s;c[f+131072>>2]=s;s=u+1024|0;if(s>>>0>262143){break}else{f=f+4|0;u=s}}u=c[2388254]|0;f=w+2048|0;d=524288;while(1){s=u+(d-524288)|0;c[f>>2]=s;c[f+65536>>2]=s;c[f+131072>>2]=s;s=d+1024|0;if(s>>>0>589823){break}else{f=f+4|0;d=s}}d=c[2387164]|0;c[w+3136>>2]=d;c[w+68672>>2]=d;c[w+134208>>2]=d;f=d+1024|0;c[w+3140>>2]=f;c[w+68676>>2]=f;c[w+134212>>2]=f;c[w+68736>>2]=c[2443470];f=c[2387982]|0;c[w+3264>>2]=f;c[w+68800>>2]=f;c[w+134336>>2]=f;d=f+1024|0;c[w+3268>>2]=d;c[w+68804>>2]=d;c[w+134340>>2]=d;d=f+2048|0;c[w+3272>>2]=d;c[w+68808>>2]=d;c[w+134344>>2]=d;d=f+3072|0;c[w+3276>>2]=d;c[w+68812>>2]=d;c[w+134348>>2]=d;d=f+4096|0;c[w+3280>>2]=d;c[w+68816>>2]=d;c[w+134352>>2]=d;d=f+5120|0;c[w+3284>>2]=d;c[w+68820>>2]=d;c[w+134356>>2]=d;d=f+6144|0;c[w+3288>>2]=d;c[w+68824>>2]=d;c[w+134360>>2]=d;d=f+7168|0;c[w+3292>>2]=d;c[w+68828>>2]=d;c[w+134364>>2]=d;d=f+8192|0;c[w+3296>>2]=d;c[w+68832>>2]=d;c[w+134368>>2]=d;d=f+9216|0;c[w+3300>>2]=d;c[w+68836>>2]=d;c[w+134372>>2]=d;d=f+10240|0;c[w+3304>>2]=d;c[w+68840>>2]=d;c[w+134376>>2]=d;d=f+11264|0;c[w+3308>>2]=d;c[w+68844>>2]=d;c[w+134380>>2]=d;d=f+12288|0;c[w+3312>>2]=d;c[w+68848>>2]=d;c[w+134384>>2]=d;d=f+13312|0;c[w+3316>>2]=d;c[w+68852>>2]=d;c[w+134388>>2]=d;d=f+14336|0;c[w+3320>>2]=d;c[w+68856>>2]=d;c[w+134392>>2]=d;d=f+15360|0;c[w+3324>>2]=d;c[w+68860>>2]=d;c[w+134396>>2]=d;d=c[2405794]|0;c[w+3392>>2]=d;c[w+68928>>2]=d;c[w+134464>>2]=d;f=d+1024|0;c[w+3396>>2]=f;c[w+68932>>2]=f;c[w+134468>>2]=f;c[w+196728>>2]=704;c[w+196648>>2]=730;c[w+196688>>2]=2170;c[w+196608>>2]=2014;w=c[3532592]|0;if((w|0)!=0){gGC(w|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;r=0;i=a;return r|0}function erG(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;c[2414932]=0;err();d=c[2414144]|0;e=0;while(1){if((e|0)>=1024){break}f=9638528+(e<<2)|0;if((c[f>>2]|0)==0){g=71;break}else{e=e+1|0}}do{if((g|0)==71){e=gGq(d)|0;c[f>>2]=e;if((e|0)==0){break}gGz(e|0,0,d|0);c[2414932]=e;gGz(e|0,0,d|0);err();do{if((a|0)!=0){if((gD[a&8191]()|0)==0){break}else{h=1}return h|0}}while(0);fxU(0,425984);if((c[2394]|0)==0){i=c[2112932]|0}else{c[2394]=0;e=c[3532596]|0;c[2112932]=e;j=c[3532592]|0;if((j|0)!=0){gGC(9104152,j|0,280)|0}c[2113054]=c[2113060];i=e}e=c[2388126]|0;j=i|0;k=0;while(1){l=e+k|0;c[j>>2]=l;c[j+131072>>2]=l;l=k+1024|0;if(l>>>0>262143){break}else{j=j+4|0;k=l}}if((b|0)==0){k=c[2388254]|0;j=i+2816|0;e=720896;while(1){l=k+(e-720896)|0;c[j>>2]=l;c[j+65536>>2]=l;c[j+131072>>2]=l;l=e+1024|0;if(l>>>0>786431){break}else{j=j+4|0;e=l}}c[i+68672>>2]=c[2443470];e=c[2387164]|0;c[i+3200>>2]=e;c[i+68736>>2]=e;c[i+134272>>2]=e;j=e+1024|0;c[i+3204>>2]=j;c[i+68740>>2]=j;c[i+134276>>2]=j;j=c[2387982]|0;c[i+3264>>2]=j;c[i+68800>>2]=j;c[i+134336>>2]=j;e=j+1024|0;c[i+3268>>2]=e;c[i+68804>>2]=e;c[i+134340>>2]=e;e=j+2048|0;c[i+3272>>2]=e;c[i+68808>>2]=e;c[i+134344>>2]=e;e=j+3072|0;c[i+3276>>2]=e;c[i+68812>>2]=e;c[i+134348>>2]=e;e=j+4096|0;c[i+3280>>2]=e;c[i+68816>>2]=e;c[i+134352>>2]=e;e=j+5120|0;c[i+3284>>2]=e;c[i+68820>>2]=e;c[i+134356>>2]=e;e=j+6144|0;c[i+3288>>2]=e;c[i+68824>>2]=e;c[i+134360>>2]=e;e=j+7168|0;c[i+3292>>2]=e;c[i+68828>>2]=e;c[i+134364>>2]=e;e=j+8192|0;c[i+3296>>2]=e;c[i+68832>>2]=e;c[i+134368>>2]=e;e=j+9216|0;c[i+3300>>2]=e;c[i+68836>>2]=e;c[i+134372>>2]=e;e=j+10240|0;c[i+3304>>2]=e;c[i+68840>>2]=e;c[i+134376>>2]=e;e=j+11264|0;c[i+3308>>2]=e;c[i+68844>>2]=e;c[i+134380>>2]=e;e=j+12288|0;c[i+3312>>2]=e;c[i+68848>>2]=e;c[i+134384>>2]=e;e=j+13312|0;c[i+3316>>2]=e;c[i+68852>>2]=e;c[i+134388>>2]=e;e=j+14336|0;c[i+3320>>2]=e;c[i+68856>>2]=e;c[i+134392>>2]=e;e=j+15360|0;c[i+3324>>2]=e;c[i+68860>>2]=e;c[i+134396>>2]=e;e=c[2405794]|0;c[i+3328>>2]=e;c[i+68864>>2]=e;c[i+134400>>2]=e;j=e+1024|0;c[i+3332>>2]=j;c[i+68868>>2]=j;c[i+134404>>2]=j}else{j=c[2387164]|0;c[i+2176>>2]=j;c[i+67712>>2]=j;c[i+133248>>2]=j;e=j+1024|0;c[i+2180>>2]=e;c[i+67716>>2]=e;c[i+133252>>2]=e;c[i+67776>>2]=c[2443470];e=c[2387982]|0;c[i+2304>>2]=e;c[i+67840>>2]=e;c[i+133376>>2]=e;j=e+1024|0;c[i+2308>>2]=j;c[i+67844>>2]=j;c[i+133380>>2]=j;j=e+2048|0;c[i+2312>>2]=j;c[i+67848>>2]=j;c[i+133384>>2]=j;j=e+3072|0;c[i+2316>>2]=j;c[i+67852>>2]=j;c[i+133388>>2]=j;j=e+4096|0;c[i+2320>>2]=j;c[i+67856>>2]=j;c[i+133392>>2]=j;j=e+5120|0;c[i+2324>>2]=j;c[i+67860>>2]=j;c[i+133396>>2]=j;j=e+6144|0;c[i+2328>>2]=j;c[i+67864>>2]=j;c[i+133400>>2]=j;j=e+7168|0;c[i+2332>>2]=j;c[i+67868>>2]=j;c[i+133404>>2]=j;j=e+8192|0;c[i+2336>>2]=j;c[i+67872>>2]=j;c[i+133408>>2]=j;j=e+9216|0;c[i+2340>>2]=j;c[i+67876>>2]=j;c[i+133412>>2]=j;j=e+10240|0;c[i+2344>>2]=j;c[i+67880>>2]=j;c[i+133416>>2]=j;j=e+11264|0;c[i+2348>>2]=j;c[i+67884>>2]=j;c[i+133420>>2]=j;j=e+12288|0;c[i+2352>>2]=j;c[i+67888>>2]=j;c[i+133424>>2]=j;j=e+13312|0;c[i+2356>>2]=j;c[i+67892>>2]=j;c[i+133428>>2]=j;j=e+14336|0;c[i+2360>>2]=j;c[i+67896>>2]=j;c[i+133432>>2]=j;j=e+15360|0;c[i+2364>>2]=j;c[i+67900>>2]=j;c[i+133436>>2]=j;j=c[2405794]|0;c[i+2496>>2]=j;c[i+68032>>2]=j;c[i+133568>>2]=j;e=j+1024|0;c[i+2500>>2]=e;c[i+68036>>2]=e;c[i+133572>>2]=e;e=c[2388254]|0;j=i+3840|0;k=983040;while(1){l=e+(k-983040)|0;c[j>>2]=l;c[j+131072>>2]=l;l=k+1024|0;if(l>>>0>1048575){break}else{j=j+4|0;k=l}}}c[i+196728>>2]=2638;c[i+196648>>2]=126;c[i+196688>>2]=732;c[i+196608>>2]=2392;k=c[3532592]|0;if((k|0)!=0){gGC(k|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;c[2424]=5600;c[3532600]=c[2385902];c[3532602]=c[2386056];Tz(0,0,1e4);k=c[642608+(c[2436]<<2)>>2]|0;j=c[k+128>>2]|0;if((c[k+52>>2]&4|0)==0){c[2113068]=j;e=c[k+132>>2]|0;c[2113070]=e;c[2443814]=j;c[2440436]=e;m=j;n=e}else{c[2113070]=j;e=c[k+132>>2]|0;c[2113068]=e;c[2440436]=j;c[2443814]=e;m=e;n=j}j=ag(m<<1,n)|0;e=gGq(j)|0;c[2112926]=e;if((e|0)!=0){gGz(e|0,0,j|0)}j=c[2414634]|0;gGz(j|0,0,(c[2411604]|0)-j|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];j=c[3532592]|0;if((j|0)!=0){gGC(9104152,j|0,280)|0}c[2113054]=c[2113060]}RI();j=c[2394]|0;e=c[14130368+(j<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(j<<2)>>2]=c[2113054];c[2394]=-1;Ty();j=(c[3529708]|0)-(c[3529752]|0)|0;e=c[3541206]|0;c[3541190]=e;c[3541198]=e;c[3541191]=e+256;c[3541199]=e+65536;c[3541192]=e+512;c[3541200]=e+131072;c[3541193]=e+768;c[3541201]=e+196608;k=e+j|0;c[3541194]=k;c[3541202]=k;c[3541195]=e+(j+256);c[3541203]=e+(j+65536);c[3541196]=e+(j+512);c[3541204]=e+(j+131072);c[3541197]=e+(j+768);c[3541205]=e+(j+196608);h=0;return h|0}}while(0);c[2414932]=0;h=1;return h|0}function erH(){var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=i;i=i+600|0;f=e|0;g=e+112|0;h=e+120|0;j=e+232|0;k=e+240|0;l=e+352|0;m=e+360|0;n=e+472|0;o=e+480|0;p=e+592|0;if((R6((c[2388126]|0)+1|0,0,2)|0)!=0){q=1;i=e;return q|0}if((R6(c[2388126]|0,1,2)|0)!=0){q=1;i=e;return q|0}r=c[2385902]|0;if((c[3542200]|0)==0){q=1;i=e;return q|0}s=o+108|0;c[s>>2]=0;t=o+100|0;c[t>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](o,2)|0;do{if((c[s>>2]|0)!=0){o=c[t>>2]|0;c[p>>2]=9534384;u=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[u&16383](p,2,0)|0;if((o|0)<1){q=1;i=e;return q|0}if((gzL(r,0,2)|0)==0){break}else{q=1}i=e;return q|0}}while(0);r=c[2385902]|0;p=r+65536|0;t=r+32768|0;gGC(p|0,t|0,32768)|0;t=r+98304|0;gGC(t|0,r|0,32768)|0;r=c[3530812]|0;if((c[3542200]|0)==0){q=1;i=e;return q|0}t=m+108|0;c[t>>2]=0;p=m+100|0;c[p>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,3)|0;do{if((c[t>>2]|0)!=0){m=c[p>>2]|0;c[n>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](n,3,0)|0;if((m|0)<1){q=1;i=e;return q|0}if((gzL(r,0,3)|0)==0){break}else{q=1}i=e;return q|0}}while(0);r=c[3530576]|0;if((c[3542200]|0)==0){q=1;i=e;return q|0}n=k+108|0;c[n>>2]=0;p=k+100|0;c[p>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,4)|0;do{if((c[n>>2]|0)!=0){k=c[p>>2]|0;c[l>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](l,4,0)|0;if((k|0)<1){q=1;i=e;return q|0}if((gzL(r,0,4)|0)==0){break}else{q=1}i=e;return q|0}}while(0);r=(c[3530576]|0)+524288|0;if((c[3542200]|0)==0){q=1;i=e;return q|0}l=h+108|0;c[l>>2]=0;p=h+100|0;c[p>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](h,5)|0;do{if((c[l>>2]|0)!=0){h=c[p>>2]|0;c[j>>2]=9534384;n=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[n&16383](j,5,0)|0;if((h|0)<1){q=1;i=e;return q|0}if((gzL(r,0,5)|0)==0){break}else{q=1}i=e;return q|0}}while(0);if((R6(c[3530416]|0,6,2)|0)!=0){q=1;i=e;return q|0}if((R6((c[3530416]|0)+1|0,7,2)|0)!=0){q=1;i=e;return q|0}r=c[3529752]|0;if((c[3542200]|0)==0){q=1;i=e;return q|0}j=f+108|0;c[j>>2]=0;p=f+100|0;c[p>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,8)|0;do{if((c[j>>2]|0)!=0){f=c[p>>2]|0;c[g>>2]=9534384;l=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[l&16383](g,8,0)|0;if((f|0)<1){q=1;i=e;return q|0}if((gzL(r,0,8)|0)==0){break}else{q=1}i=e;return q|0}}while(0);r=c[2388126]|0;g=0;do{p=r+(g|1)|0;j=r+g|0;f=((d[p]|0)<<8|(d[j]|0))&65535;l=0;h=0;do{v=(f>>>((d[602400+h|0]|0)>>>0)&1)<<15-h|l&65535;l=v&65535;h=h+1|0;}while((h|0)<16);a[p]=(l&65535)>>>8&255;a[j]=v&255;g=g+2|0;}while((g|0)<262144);g=c[3530576]|0;v=c[3530416]|0;r=0;do{h=g+r|0;f=a[h]|0;a[h]=(f&255)>>>3<<4&16|f&-25|(f&255)>>>4<<3&8;f=v+r|0;h=a[f]|0;a[f]=(h&255)>>>3<<4&16|h&-25|(h&255)>>>4<<3&8;r=r+1|0;}while((r|0)<1048576);erq(131072,1048576,1048576);b[(c[2388126]|0)+776>>1]=20081;q=0;i=e;return q|0}function erI(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=c[2388254]|0;g=a[9537176]|0;h=f+36864|0;do{if((g&1)==0){i=g;j=h}else{if((b[h>>1]&512)==0){i=g;j=h;break}k=f+61184|0;b[k>>1]=(b[k>>1]|0)-1&65535;k=g&2;a[9537176]=k;i=k;j=h}}while(0);do{if((i&2)!=0){if((b[j>>1]&256)==0){break}h=f+61184|0;b[h>>1]=(b[h>>1]|0)-1&65535;a[9537176]=i&1}}while(0);i=a[9634961]|0;h=(i&255)>>>3;g=i&7;L228:do{if(d<<24>>24==0){switch(g|0){case 0:{b[j>>1]=b[j>>1]|16384;break};case 1:{a[9537160]=4;a[9537200]=1;break};case 2:{a[9537160]=3;a[9537200]=1;break};case 6:{a[9537160]=1;a[9537200]=2;break};case 7:{a[9537160]=1;a[9537200]=1;break};case 5:{a[9537160]=1;a[9537200]=3;break};case 3:{a[9537160]=2;a[9537200]=1;break};case 4:{a[9537160]=1;a[9537200]=4;break};default:{}}switch(h&7|0){case 7:{a[9537152]=1;a[9537192]=1;break L228;break};case 6:{a[9537152]=1;a[9537192]=2;break L228;break};case 5:{a[9537152]=1;a[9537192]=3;break L228;break};case 4:{a[9537152]=1;a[9537192]=4;break L228;break};case 3:{a[9537152]=2;a[9537192]=1;break L228;break};case 2:{a[9537152]=3;a[9537192]=1;break L228;break};case 1:{a[9537152]=4;a[9537192]=1;break L228;break};case 0:{b[j>>1]=b[j>>1]|16384;break L228;break};default:{break L228}}}else{switch(g|0){case 3:{a[9537160]=1;a[9537200]=2;break};case 4:{a[9537160]=4;a[9537200]=1;break};case 5:{a[9537160]=3;a[9537200]=1;break};case 6:{a[9537160]=2;a[9537200]=1;break};case 7:{a[9537160]=1;a[9537200]=1;break};case 0:{b[j>>1]=b[j>>1]|16384;break};case 1:{a[9537160]=1;a[9537200]=4;break};case 2:{a[9537160]=1;a[9537200]=3;break};default:{}}switch(h&7|0){case 7:{a[9537152]=1;a[9537192]=1;break L228;break};case 6:{a[9537152]=2;a[9537192]=1;break L228;break};case 5:{a[9537152]=3;a[9537192]=1;break L228;break};case 4:{a[9537152]=4;a[9537192]=1;break L228;break};case 3:{a[9537152]=1;a[9537192]=2;break L228;break};case 2:{a[9537152]=1;a[9537192]=3;break L228;break};case 1:{a[9537152]=1;a[9537192]=4;break L228;break};case 0:{b[j>>1]=b[j>>1]|16384;break L228;break};default:{break L228}}}}while(0);h=~b[4774976];b[4768592]=h;g=a[9537168]|0;if((h&1)==0){l=g&-2}else{do{if((g&1)==0){d=a[9537160]|0;i=a[9537200]|0;k=i&255;if(d<<24>>24==1){m=f+61184|0;b[m>>1]=(e[m>>1]|0)+k&65535;break}m=f+61186|0;n=(e[m>>1]|0)+k|0;b[m>>1]=n&65535;if((d&255|0)!=(n&65535|0)){break}n=f+61184|0;b[n>>1]=(b[n>>1]|0)+(i&255)&65535;b[m>>1]=0}}while(0);l=g|1}a[9537168]=l;if((h&2)==0){o=l&-3}else{do{if((l&2)==0){g=a[9537152]|0;m=a[9537192]|0;i=m&255;if(g<<24>>24==1){n=f+61184|0;b[n>>1]=(e[n>>1]|0)+i&65535;break}n=f+61186|0;d=(e[n>>1]|0)+i|0;b[n>>1]=d&65535;if((g&255|0)!=(d&65535|0)){break}d=f+61184|0;b[d>>1]=(b[d>>1]|0)+(m&255)&65535;b[n>>1]=0}}while(0);o=l|2}a[9537168]=o;if((h&4)==0){p=o&-5}else{if((o&4)==0){l=f+61184|0;b[l>>1]=(b[l>>1]|0)+1&65535}p=o|4}a[9537168]=p;if((b[f+61184>>1]|0)==0){return}f=b[j>>1]|0;j=f&65535;if((j&32768|0)==0){return}if((h&8)==0){q=p&-9}else{do{if((p&8)==0){if((j&512|0)!=0){break}a[9537176]=1}}while(0);q=p|8}a[9537168]=q;if((h&16)==0){a[9537168]=q&-17;return}do{if((q&16)==0){if((f&256)!=0){break}a[9537176]=f<<16>>16==-32768?3:2}}while(0);a[9537168]=q|16;return}function erJ(){var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=i;i=i+720|0;e=d|0;f=d+112|0;g=d+120|0;h=d+232|0;j=d+240|0;k=d+352|0;l=d+360|0;m=d+472|0;n=d+480|0;o=d+592|0;p=d+600|0;q=d+712|0;if((R6((c[2388126]|0)+1|0,0,2)|0)!=0){r=1;i=d;return r|0}if((R6(c[2388126]|0,1,2)|0)!=0){r=1;i=d;return r|0}s=c[2385902]|0;if((c[3542200]|0)==0){r=1;i=d;return r|0}t=p+108|0;c[t>>2]=0;u=p+100|0;c[u>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,2)|0;do{if((c[t>>2]|0)!=0){p=c[u>>2]|0;c[q>>2]=9534384;v=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[v&16383](q,2,0)|0;if((p|0)<1){r=1;i=d;return r|0}if((gzL(s,0,2)|0)==0){break}else{r=1}i=d;return r|0}}while(0);s=c[3530812]|0;if((c[3542200]|0)==0){r=1;i=d;return r|0}q=n+108|0;c[q>>2]=0;u=n+100|0;c[u>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,3)|0;do{if((c[q>>2]|0)!=0){n=c[u>>2]|0;c[o>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](o,3,0)|0;if((n|0)<1){r=1;i=d;return r|0}if((gzL(s,0,3)|0)==0){break}else{r=1}i=d;return r|0}}while(0);s=c[3530576]|0;if((c[3542200]|0)==0){r=1;i=d;return r|0}o=l+108|0;c[o>>2]=0;u=l+100|0;c[u>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,4)|0;do{if((c[o>>2]|0)!=0){l=c[u>>2]|0;c[m>>2]=9534384;q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[q&16383](m,4,0)|0;if((l|0)<1){r=1;i=d;return r|0}if((gzL(s,0,4)|0)==0){break}else{r=1}i=d;return r|0}}while(0);s=c[3530416]|0;if((c[3542200]|0)==0){r=1;i=d;return r|0}m=j+108|0;c[m>>2]=0;u=j+100|0;c[u>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,5)|0;do{if((c[m>>2]|0)!=0){j=c[u>>2]|0;c[k>>2]=9534384;o=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[o&16383](k,5,0)|0;if((j|0)<1){r=1;i=d;return r|0}if((gzL(s,0,5)|0)==0){break}else{r=1}i=d;return r|0}}while(0);s=0;k=c[3530416]|0;while(1){u=a[k]|0;m=k+1|0;a[k]=a[m]|0;a[m]=u;u=s+1|0;if((u|0)<524288){s=u;k=k+2|0}else{break}}k=(c[3529752]|0)+131072|0;if((c[3542200]|0)==0){r=1;i=d;return r|0}s=g+108|0;c[s>>2]=0;u=g+100|0;c[u>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,6)|0;do{if((c[s>>2]|0)!=0){g=c[u>>2]|0;c[h>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](h,6,0)|0;if((g|0)<1){r=1;i=d;return r|0}if((gzL(k,0,6)|0)==0){break}else{r=1}i=d;return r|0}}while(0);k=c[3529752]|0;h=k+131072|0;gGC(k|0,h|0,131072)|0;h=(c[3529708]|0)+131072|0;if((c[3542200]|0)==0){r=1;i=d;return r|0}k=e+108|0;c[k>>2]=0;u=e+100|0;c[u>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,7)|0;do{if((c[k>>2]|0)!=0){e=c[u>>2]|0;c[f>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](f,7,0)|0;if((e|0)<1){r=1;i=d;return r|0}if((gzL(h,0,7)|0)==0){break}else{r=1}i=d;return r|0}}while(0);h=c[3529708]|0;f=h+131072|0;gGC(h|0,f|0,131072)|0;erq(131072,1048576,1048576);f=c[2388126]|0;b[f+1162>>1]=20081;b[f+1194>>1]=20081;fxU(0,425984);if((c[2394]|0)==0){w=c[2112932]|0}else{c[2394]=0;f=c[3532596]|0;c[2112932]=f;h=c[3532592]|0;if((h|0)!=0){gGC(9104152,h|0,280)|0}c[2113054]=c[2113060];w=f}f=c[2388126]|0;h=w|0;u=0;while(1){k=f+u|0;c[h>>2]=k;c[h+131072>>2]=k;k=u+1024|0;if(k>>>0>262143){break}else{h=h+4|0;u=k}}u=c[2388254]|0;h=w+2816|0;f=720896;while(1){k=u+(f-720896)|0;c[h>>2]=k;c[h+131072>>2]=k;k=f+1024|0;if(k>>>0>786431){break}else{h=h+4|0;f=k}}f=c[2443470]|0;c[w+3136>>2]=f;c[w+68672>>2]=f;c[w+134208>>2]=f;f=c[2387164]|0;c[w+3200>>2]=f;c[w+68736>>2]=f;c[w+134272>>2]=f;h=f+1024|0;c[w+3204>>2]=h;c[w+68740>>2]=h;c[w+134276>>2]=h;h=c[2387982]|0;c[w+3264>>2]=h;c[w+68800>>2]=h;c[w+134336>>2]=h;f=h+1024|0;c[w+3268>>2]=f;c[w+68804>>2]=f;c[w+134340>>2]=f;f=h+2048|0;c[w+3272>>2]=f;c[w+68808>>2]=f;c[w+134344>>2]=f;f=h+3072|0;c[w+3276>>2]=f;c[w+68812>>2]=f;c[w+134348>>2]=f;f=h+4096|0;c[w+3280>>2]=f;c[w+68816>>2]=f;c[w+134352>>2]=f;f=h+5120|0;c[w+3284>>2]=f;c[w+68820>>2]=f;c[w+134356>>2]=f;f=h+6144|0;c[w+3288>>2]=f;c[w+68824>>2]=f;c[w+134360>>2]=f;f=h+7168|0;c[w+3292>>2]=f;c[w+68828>>2]=f;c[w+134364>>2]=f;f=h+8192|0;c[w+3296>>2]=f;c[w+68832>>2]=f;c[w+134368>>2]=f;f=h+9216|0;c[w+3300>>2]=f;c[w+68836>>2]=f;c[w+134372>>2]=f;f=h+10240|0;c[w+3304>>2]=f;c[w+68840>>2]=f;c[w+134376>>2]=f;f=h+11264|0;c[w+3308>>2]=f;c[w+68844>>2]=f;c[w+134380>>2]=f;f=h+12288|0;c[w+3312>>2]=f;c[w+68848>>2]=f;c[w+134384>>2]=f;f=h+13312|0;c[w+3316>>2]=f;c[w+68852>>2]=f;c[w+134388>>2]=f;f=h+14336|0;c[w+3320>>2]=f;c[w+68856>>2]=f;c[w+134392>>2]=f;f=h+15360|0;c[w+3324>>2]=f;c[w+68860>>2]=f;c[w+134396>>2]=f;f=c[2405794]|0;c[w+3328>>2]=f;c[w+68864>>2]=f;c[w+134400>>2]=f;h=f+1024|0;c[w+3332>>2]=h;c[w+68868>>2]=h;c[w+134404>>2]=h;c[w+196728>>2]=2470;c[w+196648>>2]=710;c[w+196688>>2]=750;c[w+196608>>2]=250;w=c[3532592]|0;if((w|0)!=0){gGC(w|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;r=0;i=d;return r|0}function erK(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;a=i;i=i+840|0;b=a|0;d=a+112|0;e=a+120|0;f=a+232|0;g=a+240|0;h=a+352|0;j=a+360|0;k=a+472|0;l=a+480|0;m=a+592|0;n=a+600|0;o=a+712|0;p=a+720|0;q=a+832|0;if((R6((c[2388126]|0)+1|0,0,2)|0)!=0){r=1;i=a;return r|0}if((R6(c[2388126]|0,1,2)|0)!=0){r=1;i=a;return r|0}s=c[2385902]|0;if((c[3542200]|0)==0){r=1;i=a;return r|0}t=p+108|0;c[t>>2]=0;u=p+100|0;c[u>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,2)|0;do{if((c[t>>2]|0)!=0){p=c[u>>2]|0;c[q>>2]=9534384;v=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[v&16383](q,2,0)|0;if((p|0)<1){r=1;i=a;return r|0}if((gzL(s,0,2)|0)==0){break}else{r=1}i=a;return r|0}}while(0);s=c[2385902]|0;q=s+65536|0;u=s+32768|0;gGC(q|0,u|0,32768)|0;q=s+98304|0;gGC(q|0,u|0,32768)|0;u=c[3530812]|0;if((c[3542200]|0)==0){r=1;i=a;return r|0}q=n+108|0;c[q>>2]=0;s=n+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,3)|0;do{if((c[q>>2]|0)!=0){n=c[s>>2]|0;c[o>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](o,3,0)|0;if((n|0)<1){r=1;i=a;return r|0}if((gzL(u,0,3)|0)==0){break}else{r=1}i=a;return r|0}}while(0);u=c[3530576]|0;if((c[3542200]|0)==0){r=1;i=a;return r|0}o=l+108|0;c[o>>2]=0;s=l+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,4)|0;do{if((c[o>>2]|0)!=0){l=c[s>>2]|0;c[m>>2]=9534384;q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[q&16383](m,4,0)|0;if((l|0)<1){r=1;i=a;return r|0}if((gzL(u,0,4)|0)==0){break}else{r=1}i=a;return r|0}}while(0);u=(c[3530576]|0)+131072|0;if((c[3542200]|0)==0){r=1;i=a;return r|0}m=j+108|0;c[m>>2]=0;s=j+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,5)|0;do{if((c[m>>2]|0)!=0){j=c[s>>2]|0;c[k>>2]=9534384;o=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[o&16383](k,5,0)|0;if((j|0)<1){r=1;i=a;return r|0}if((gzL(u,0,5)|0)==0){break}else{r=1}i=a;return r|0}}while(0);u=(c[3530576]|0)+262144|0;if((c[3542200]|0)==0){r=1;i=a;return r|0}k=g+108|0;c[k>>2]=0;s=g+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,6)|0;do{if((c[k>>2]|0)!=0){g=c[s>>2]|0;c[h>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](h,6,0)|0;if((g|0)<1){r=1;i=a;return r|0}if((gzL(u,0,6)|0)==0){break}else{r=1}i=a;return r|0}}while(0);u=(c[3530576]|0)+393216|0;if((c[3542200]|0)==0){r=1;i=a;return r|0}h=e+108|0;c[h>>2]=0;s=e+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,7)|0;do{if((c[h>>2]|0)!=0){e=c[s>>2]|0;c[f>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](f,7,0)|0;if((e|0)<1){r=1;i=a;return r|0}if((gzL(u,0,7)|0)==0){break}else{r=1}i=a;return r|0}}while(0);if((R6(c[3530416]|0,8,2)|0)!=0){r=1;i=a;return r|0}if((R6((c[3530416]|0)+1|0,9,2)|0)!=0){r=1;i=a;return r|0}if((R6((c[3530416]|0)+262144|0,10,2)|0)!=0){r=1;i=a;return r|0}if((R6((c[3530416]|0)+262145|0,11,2)|0)!=0){r=1;i=a;return r|0}if((R6((c[3530416]|0)+524288|0,12,2)|0)!=0){r=1;i=a;return r|0}if((R6((c[3530416]|0)+524289|0,13,2)|0)!=0){r=1;i=a;return r|0}if((R6((c[3530416]|0)+786432|0,14,2)|0)!=0){r=1;i=a;return r|0}if((R6((c[3530416]|0)+786433|0,15,2)|0)!=0){r=1;i=a;return r|0}u=c[3529752]|0;if((c[3542200]|0)==0){r=1;i=a;return r|0}f=b+108|0;c[f>>2]=0;s=b+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](b,16)|0;do{if((c[f>>2]|0)!=0){b=c[s>>2]|0;c[d>>2]=9534384;h=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[h&16383](d,16,0)|0;if((b|0)<1){r=1;i=a;return r|0}if((gzL(u,0,16)|0)==0){break}else{r=1}i=a;return r|0}}while(0);erq(131072,524288,1048576);r=0;i=a;return r|0}function erL(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;a=i;i=i+480|0;b=a|0;d=a+112|0;e=a+120|0;f=a+232|0;g=a+240|0;h=a+352|0;j=a+360|0;k=a+472|0;if((R6((c[2388126]|0)+1|0,0,2)|0)!=0){l=1;i=a;return l|0}if((R6(c[2388126]|0,1,2)|0)!=0){l=1;i=a;return l|0}m=c[2385902]|0;if((c[3542200]|0)==0){l=1;i=a;return l|0}n=j+108|0;c[n>>2]=0;o=j+100|0;c[o>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,2)|0;do{if((c[n>>2]|0)!=0){j=c[o>>2]|0;c[k>>2]=9534384;p=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[p&16383](k,2,0)|0;if((j|0)<1){l=1;i=a;return l|0}if((gzL(m,0,2)|0)==0){break}else{l=1}i=a;return l|0}}while(0);m=c[2385902]|0;k=m+65536|0;o=m+32768|0;gGC(k|0,o|0,32768)|0;o=m+98304|0;gGC(o|0,m|0,32768)|0;m=c[3530812]|0;if((c[3542200]|0)==0){l=1;i=a;return l|0}o=g+108|0;c[o>>2]=0;k=g+100|0;c[k>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,3)|0;do{if((c[o>>2]|0)!=0){g=c[k>>2]|0;c[h>>2]=9534384;n=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[n&16383](h,3,0)|0;if((g|0)<1){l=1;i=a;return l|0}if((gzL(m,0,3)|0)==0){break}else{l=1}i=a;return l|0}}while(0);m=c[3530576]|0;if((c[3542200]|0)==0){l=1;i=a;return l|0}h=e+108|0;c[h>>2]=0;k=e+100|0;c[k>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,4)|0;do{if((c[h>>2]|0)!=0){e=c[k>>2]|0;c[f>>2]=9534384;o=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[o&16383](f,4,0)|0;if((e|0)<1){l=1;i=a;return l|0}if((gzL(m,0,4)|0)==0){break}else{l=1}i=a;return l|0}}while(0);if((R6(c[3530416]|0,5,2)|0)!=0){l=1;i=a;return l|0}if((R6((c[3530416]|0)+1|0,6,2)|0)!=0){l=1;i=a;return l|0}m=c[3529752]|0;if((c[3542200]|0)==0){l=1;i=a;return l|0}f=b+108|0;c[f>>2]=0;k=b+100|0;c[k>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](b,7)|0;do{if((c[f>>2]|0)!=0){b=c[k>>2]|0;c[d>>2]=9534384;h=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[h&16383](d,7,0)|0;if((b|0)<1){l=1;i=a;return l|0}if((gzL(m,0,7)|0)==0){break}else{l=1}i=a;return l|0}}while(0);erq(131072,524288,1048576);l=0;i=a;return l|0}function erM(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;a=i;i=i+600|0;b=a|0;d=a+112|0;e=a+120|0;f=a+232|0;g=a+240|0;h=a+352|0;j=a+360|0;k=a+472|0;l=a+480|0;m=a+592|0;if((R6((c[2388126]|0)+1|0,0,2)|0)!=0){n=1;i=a;return n|0}if((R6(c[2388126]|0,1,2)|0)!=0){n=1;i=a;return n|0}o=c[2385902]|0;if((c[3542200]|0)==0){n=1;i=a;return n|0}p=l+108|0;c[p>>2]=0;q=l+100|0;c[q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,2)|0;do{if((c[p>>2]|0)!=0){l=c[q>>2]|0;c[m>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](m,2,0)|0;if((l|0)<1){n=1;i=a;return n|0}if((gzL(o,0,2)|0)==0){break}else{n=1}i=a;return n|0}}while(0);o=c[3530812]|0;if((c[3542200]|0)==0){n=1;i=a;return n|0}m=j+108|0;c[m>>2]=0;q=j+100|0;c[q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,3)|0;do{if((c[m>>2]|0)!=0){j=c[q>>2]|0;c[k>>2]=9534384;p=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[p&16383](k,3,0)|0;if((j|0)<1){n=1;i=a;return n|0}if((gzL(o,0,3)|0)==0){break}else{n=1}i=a;return n|0}}while(0);o=c[3530576]|0;if((c[3542200]|0)==0){n=1;i=a;return n|0}k=g+108|0;c[k>>2]=0;q=g+100|0;c[q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,4)|0;do{if((c[k>>2]|0)!=0){g=c[q>>2]|0;c[h>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](h,4,0)|0;if((g|0)<1){n=1;i=a;return n|0}if((gzL(o,0,4)|0)==0){break}else{n=1}i=a;return n|0}}while(0);if((R6(c[3530416]|0,5,2)|0)!=0){n=1;i=a;return n|0}if((R6((c[3530416]|0)+1|0,6,2)|0)!=0){n=1;i=a;return n|0}o=(c[3529752]|0)+131072|0;if((c[3542200]|0)==0){n=1;i=a;return n|0}h=e+108|0;c[h>>2]=0;q=e+100|0;c[q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,7)|0;do{if((c[h>>2]|0)!=0){e=c[q>>2]|0;c[f>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](f,7,0)|0;if((e|0)<1){n=1;i=a;return n|0}if((gzL(o,0,7)|0)==0){break}else{n=1}i=a;return n|0}}while(0);o=c[3529752]|0;f=o+131072|0;gGC(o|0,f|0,131072)|0;f=(c[3529708]|0)+131072|0;if((c[3542200]|0)==0){n=1;i=a;return n|0}o=b+108|0;c[o>>2]=0;q=b+100|0;c[q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](b,8)|0;do{if((c[o>>2]|0)!=0){b=c[q>>2]|0;c[d>>2]=9534384;h=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[h&16383](d,8,0)|0;if((b|0)<1){n=1;i=a;return n|0}if((gzL(f,0,8)|0)==0){break}else{n=1}i=a;return n|0}}while(0);f=c[3529708]|0;d=f+131072|0;gGC(f|0,d|0,131072)|0;erq(131072,524288,1048576);fxU(0,425984);if((c[2394]|0)==0){s=c[2112932]|0}else{c[2394]=0;d=c[3532596]|0;c[2112932]=d;f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];s=d}d=c[2388126]|0;f=s|0;q=0;while(1){o=d+q|0;c[f>>2]=o;c[f+131072>>2]=o;o=q+1024|0;if(o>>>0>262143){break}else{f=f+4|0;q=o}}q=c[2387164]|0;c[s+2176>>2]=q;c[s+67712>>2]=q;c[s+133248>>2]=q;f=q+1024|0;c[s+2180>>2]=f;c[s+67716>>2]=f;c[s+133252>>2]=f;c[s+67776>>2]=c[2443470];f=c[2387982]|0;c[s+2304>>2]=f;c[s+67840>>2]=f;c[s+133376>>2]=f;q=f+1024|0;c[s+2308>>2]=q;c[s+67844>>2]=q;c[s+133380>>2]=q;q=f+2048|0;c[s+2312>>2]=q;c[s+67848>>2]=q;c[s+133384>>2]=q;q=f+3072|0;c[s+2316>>2]=q;c[s+67852>>2]=q;c[s+133388>>2]=q;q=f+4096|0;c[s+2320>>2]=q;c[s+67856>>2]=q;c[s+133392>>2]=q;q=f+5120|0;c[s+2324>>2]=q;c[s+67860>>2]=q;c[s+133396>>2]=q;q=f+6144|0;c[s+2328>>2]=q;c[s+67864>>2]=q;c[s+133400>>2]=q;q=f+7168|0;c[s+2332>>2]=q;c[s+67868>>2]=q;c[s+133404>>2]=q;q=f+8192|0;c[s+2336>>2]=q;c[s+67872>>2]=q;c[s+133408>>2]=q;q=f+9216|0;c[s+2340>>2]=q;c[s+67876>>2]=q;c[s+133412>>2]=q;q=f+10240|0;c[s+2344>>2]=q;c[s+67880>>2]=q;c[s+133416>>2]=q;q=f+11264|0;c[s+2348>>2]=q;c[s+67884>>2]=q;c[s+133420>>2]=q;q=f+12288|0;c[s+2352>>2]=q;c[s+67888>>2]=q;c[s+133424>>2]=q;q=f+13312|0;c[s+2356>>2]=q;c[s+67892>>2]=q;c[s+133428>>2]=q;q=f+14336|0;c[s+2360>>2]=q;c[s+67896>>2]=q;c[s+133432>>2]=q;q=f+15360|0;c[s+2364>>2]=q;c[s+67900>>2]=q;c[s+133436>>2]=q;q=c[2405794]|0;c[s+2496>>2]=q;c[s+68032>>2]=q;c[s+133568>>2]=q;f=q+1024|0;c[s+2500>>2]=f;c[s+68036>>2]=f;c[s+133572>>2]=f;f=c[2388254]|0;q=s+3840|0;d=983040;while(1){o=f+(d-983040)|0;c[q>>2]=o;c[q+131072>>2]=o;o=d+1024|0;if(o>>>0>1048575){break}else{q=q+4|0;d=o}}c[s+196728>>2]=2898;c[s+196648>>2]=1072;c[s+196688>>2]=1908;c[s+196608>>2]=2762;s=c[3532592]|0;if((s|0)!=0){gGC(s|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;n=0;i=a;return n|0}function erN(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;c[2414932]=0;err();d=c[2414144]|0;e=0;while(1){if((e|0)>=1024){break}f=9638528+(e<<2)|0;if((c[f>>2]|0)==0){g=474;break}else{e=e+1|0}}do{if((g|0)==474){e=gGq(d)|0;c[f>>2]=e;if((e|0)==0){break}gGz(e|0,0,d|0);c[2414932]=e;gGz(e|0,0,d|0);err();do{if((b|0)!=0){if((gD[b&8191]()|0)==0){break}else{h=1}return h|0}}while(0);fxU(0,425984);if((c[2394]|0)==0){i=c[2112932]|0}else{c[2394]=0;e=c[3532596]|0;c[2112932]=e;j=c[3532592]|0;if((j|0)!=0){gGC(9104152,j|0,280)|0}c[2113054]=c[2113060];i=e}e=c[2388126]|0;j=i|0;k=0;while(1){l=e+k|0;c[j>>2]=l;c[j+131072>>2]=l;l=k+1024|0;if(l>>>0>524287){break}else{j=j+4|0;k=l}}k=c[2387164]|0;c[i+2176>>2]=k;c[i+67712>>2]=k;c[i+133248>>2]=k;j=k+1024|0;c[i+2180>>2]=j;c[i+67716>>2]=j;c[i+133252>>2]=j;j=c[2387982]|0;c[i+2496>>2]=j;c[i+68032>>2]=j;c[i+133568>>2]=j;k=j+1024|0;c[i+2500>>2]=k;c[i+68036>>2]=k;c[i+133572>>2]=k;e=j+2048|0;c[i+2504>>2]=e;c[i+68040>>2]=e;c[i+133576>>2]=e;l=j+3072|0;c[i+2508>>2]=l;c[i+68044>>2]=l;c[i+133580>>2]=l;c[i+2512>>2]=j;c[i+68048>>2]=j;c[i+133584>>2]=j;c[i+2516>>2]=k;c[i+68052>>2]=k;c[i+133588>>2]=k;c[i+2520>>2]=e;c[i+68056>>2]=e;c[i+133592>>2]=e;c[i+2524>>2]=l;c[i+68060>>2]=l;c[i+133596>>2]=l;l=c[2388254]|0;e=i+3840|0;k=983040;while(1){j=l+(k-983040)|0;c[e>>2]=j;c[e+65536>>2]=j;c[e+131072>>2]=j;j=k+1024|0;if(j>>>0>1048575){break}else{e=e+4|0;k=j}}c[i+196728>>2]=742;c[i+196648>>2]=2460;c[i+196688>>2]=1442;c[i+196608>>2]=1226;k=c[3532592]|0;if((k|0)!=0){gGC(k|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;c[2424]=5600;Ux(0,24242,1);Ux(1,24242,1);c[2407030]=51;c[2407068]=3;c[2407069]=51;c[2407107]=3;k=c[3529752]|0;e=c[3529708]|0;c[2409598]=k;c[2409599]=e;c[2385312]=1310720;c[2385313]=1310720;a[632360]=1;l=9771520;c[l>>2]=-1;c[l+4>>2]=-1;a[9771520]=0;l=k+1024|0;j=k+263168|0;gGC(l|0,j|0,64512)|0;j=k+262144|0;gGC(k|0,j|0,256)|0;a[9771524]=0;j=e+1024|0;k=e+263168|0;gGC(j|0,k|0,64512)|0;k=e+262144|0;gGC(e|0,k|0,256)|0;k=c[642608+(c[2436]<<2)>>2]|0;e=c[k+128>>2]|0;if((c[k+52>>2]&4|0)==0){c[2113068]=e;j=c[k+132>>2]|0;c[2113070]=j;c[2443814]=e;c[2440436]=j;m=e;n=j}else{c[2113070]=e;j=c[k+132>>2]|0;c[2113068]=j;c[2440436]=e;c[2443814]=j;m=j;n=e}e=ag(m<<1,n)|0;j=gGq(e)|0;c[2112926]=j;if((j|0)!=0){gGz(j|0,0,e|0)}erQ();h=0;return h|0}}while(0);c[2414932]=0;h=1;return h|0}function erO(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=i;i=i+600|0;d=b|0;e=b+112|0;f=b+120|0;g=b+232|0;h=b+240|0;j=b+352|0;k=b+360|0;l=b+472|0;m=b+480|0;n=b+592|0;if((R6((c[2388126]|0)+1|0,0,2)|0)!=0){o=1;i=b;return o|0}if((R6(c[2388126]|0,1,2)|0)!=0){o=1;i=b;return o|0}p=c[3530812]|0;if((c[3542200]|0)==0){o=1;i=b;return o|0}q=m+108|0;c[q>>2]=0;r=m+100|0;c[r>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,2)|0;do{if((c[q>>2]|0)!=0){m=c[r>>2]|0;c[n>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](n,2,0)|0;if((m|0)<1){o=1;i=b;return o|0}if((gzL(p,0,2)|0)==0){break}else{o=1}i=b;return o|0}}while(0);p=c[3530576]|0;if((c[3542200]|0)==0){o=1;i=b;return o|0}n=k+108|0;c[n>>2]=0;r=k+100|0;c[r>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,3)|0;do{if((c[n>>2]|0)!=0){k=c[r>>2]|0;c[l>>2]=9534384;q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[q&16383](l,3,0)|0;if((k|0)<1){o=1;i=b;return o|0}if((gzL(p,0,3)|0)==0){break}else{o=1}i=b;return o|0}}while(0);p=c[3530416]|0;if((c[3542200]|0)==0){o=1;i=b;return o|0}l=h+108|0;c[l>>2]=0;r=h+100|0;c[r>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](h,4)|0;do{if((c[l>>2]|0)!=0){h=c[r>>2]|0;c[j>>2]=9534384;n=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[n&16383](j,4,0)|0;if((h|0)<1){o=1;i=b;return o|0}if((gzL(p,0,4)|0)==0){break}else{o=1}i=b;return o|0}}while(0);p=0;j=c[3530416]|0;while(1){r=a[j]|0;l=j+1|0;a[j]=a[l]|0;a[l]=r;r=p+1|0;if((r|0)<1048576){p=r;j=j+2|0}else{break}}j=(c[3529752]|0)+262144|0;if((c[3542200]|0)==0){o=1;i=b;return o|0}p=f+108|0;c[p>>2]=0;r=f+100|0;c[r>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,5)|0;do{if((c[p>>2]|0)!=0){f=c[r>>2]|0;c[g>>2]=9534384;l=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[l&16383](g,5,0)|0;if((f|0)<1){o=1;i=b;return o|0}if((gzL(j,0,5)|0)==0){break}else{o=1}i=b;return o|0}}while(0);j=(c[3529708]|0)+262144|0;if((c[3542200]|0)==0){o=1;i=b;return o|0}g=d+108|0;c[g>>2]=0;r=d+100|0;c[r>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](d,6)|0;do{if((c[g>>2]|0)!=0){d=c[r>>2]|0;c[e>>2]=9534384;p=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[p&16383](e,6,0)|0;if((d|0)<1){o=1;i=b;return o|0}if((gzL(j,0,6)|0)==0){break}else{o=1}i=b;return o|0}}while(0);erD(2097152,2097152);erP(2097152,2097152);o=0;i=b;return o|0}function erP(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=(e|0)>=(b|0)?e:b;g=0;while(1){if((g|0)>=1024){h=584;break}i=9638528+(g<<2)|0;if((c[i>>2]|0)==0){break}else{g=g+1|0}}if((h|0)==584){return}g=gGq(f)|0;c[i>>2]=g;if((g|0)==0){return}gGz(g|0,0,f|0);f=c[3530812]|0;gGC(g|0,f|0,65536)|0;i=0;do{j=i<<6;gGz(f+j|0,0,64);k=i<<8;l=0;do{m=1<<3-l;n=(c[703416+(l<<2)>>2]|0)+k|0;o=0;do{p=n+(c[611840+(o<<2)>>2]|0)|0;q=(o<<3)+j|0;r=0;do{s=p+(c[600104+(r<<2)>>2]|0)|0;if(((d[g+((s|0)/8|0)|0]|0)&128>>>((s&7)>>>0)|0)!=0){s=f+(q+r)|0;a[s]=(d[s]|0|m)&255}r=r+1|0;}while((r|0)<8);o=o+1|0;}while((o|0)<8);l=l+1|0;}while((l|0)<4);i=i+1|0;}while((i|0)<2048);i=c[3530576]|0;gGC(g|0,i|0,b)|0;f=b<<1;b=(f|0)/64|0;if((f|0)>63){f=0;do{l=f<<6;gGz(i+l|0,0,64);j=f<<8;k=0;do{o=1<<3-k;m=(c[703416+(k<<2)>>2]|0)+j|0;n=0;do{r=m+(c[611840+(n<<2)>>2]|0)|0;q=(n<<3)+l|0;p=0;do{s=r+(c[600104+(p<<2)>>2]|0)|0;if(((d[g+((s|0)/8|0)|0]|0)&128>>>((s&7)>>>0)|0)!=0){s=i+(q+p)|0;a[s]=(d[s]|0|o)&255}p=p+1|0;}while((p|0)<8);n=n+1|0;}while((n|0)<8);k=k+1|0;}while((k|0)<4);f=f+1|0;}while((f|0)<(b|0))}f=c[3530416]|0;gGC(g|0,f|0,e)|0;i=e<<1;e=(i|0)/256|0;if((i|0)>255){i=0;do{k=i<<8;gGz(f+k|0,0,256);l=i<<10;j=0;do{n=1<<3-j;o=(c[703416+(j<<2)>>2]|0)+l|0;m=0;do{p=o+(c[611840+(m<<2)>>2]|0)|0;q=(m<<4)+k|0;r=0;do{s=p+(c[600104+(r<<2)>>2]|0)|0;if(((d[g+((s|0)/8|0)|0]|0)&128>>>((s&7)>>>0)|0)!=0){s=f+(q+r)|0;a[s]=(d[s]|0|n)&255}r=r+1|0;}while((r|0)<16);m=m+1|0;}while((m|0)<16);j=j+1|0;}while((j|0)<4);i=i+1|0;}while((i|0)<(e|0))}c[2439222]=2047;c[2439220]=b-1;c[2439218]=e-1;e=0;while(1){if((e|0)>=1024){h=582;break}t=9638528+(e<<2)|0;if((c[t>>2]|0)==(g|0)){break}else{e=e+1|0}}if((h|0)==582){return}gGr(g);c[t>>2]=0;return}function erQ(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=c[2414634]|0;gGz(b|0,0,(c[2411604]|0)-b|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];b=c[3532592]|0;if((b|0)!=0){gGC(9104152,b|0,280)|0}c[2113054]=c[2113060]}RI();b=c[2394]|0;d=c[14130368+(b<<2)>>2]|0;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[8452240+(b<<2)>>2]=c[2113054];c[2394]=-1;c[2113156]=0;a[9628264]=0;c[2407033]=0;b=c[3541206]|0;c[3541190]=b;c[3541198]=b;gGz(c[2430118]|0,0,16384);c[2407041]=4;d=b+256|0;c[3541191]=d;e=b+65536|0;c[3541199]=e;gGz(c[2430119]|0,0,16384);c[2407049]=4;f=b+512|0;c[3541192]=f;g=b+131072|0;c[3541200]=g;gGz(c[2430120]|0,0,16384);c[2407057]=4;h=b+768|0;c[3541193]=h;i=b+196608|0;c[3541201]=i;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2113157]=0;a[9628420]=0;c[2407072]=0;j=b+1048576|0;c[3541194]=j;c[3541202]=j;gGz(c[2430122]|0,0,16384);c[2407080]=4;c[3541195]=b+1048832;c[3541203]=b+1114112;gGz(c[2430123]|0,0,16384);c[2407088]=4;c[3541196]=b+1049088;c[3541204]=b+1179648;gGz(c[2430124]|0,0,16384);c[2407096]=4;c[3541197]=b+1049344;c[3541205]=b+1245184;gGz(c[2430125]|0,0,16384);c[2407104]=4;j=9771520;c[j>>2]=-1;c[j+4>>2]=-1;j=c[2409598]|0;k=a[632360]<<31>>31;a[9771520]=0;if((k&1)==0){l=j+262144|0;gGC(j|0,l|0,65536)|0}else{l=j+1024|0;m=j+263168|0;gGC(l|0,m|0,64512)|0;m=j+262144|0;gGC(j|0,m|0,256)|0}m=c[2409599]|0;a[9771524]=0;if((k&2)==0){k=m+262144|0;gGC(m|0,k|0,65536)|0}else{k=m+1024|0;j=m+263168|0;gGC(k|0,j|0,64512)|0;j=m+262144|0;gGC(m|0,j|0,256)|0}j=(c[3529708]|0)-(c[3529752]|0)|0;c[3541190]=b;c[3541198]=b;c[3541191]=d;c[3541199]=e;c[3541192]=f;c[3541200]=g;c[3541193]=h;c[3541201]=i;i=b+j|0;c[3541194]=i;c[3541202]=i;c[3541195]=b+(j+256);c[3541203]=b+(j+65536);c[3541196]=b+(j+512);c[3541204]=b+(j+131072);c[3541197]=b+(j+768);c[3541205]=b+(j+196608);return}function erR(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=i;i=i+600|0;d=b|0;e=b+112|0;f=b+120|0;g=b+232|0;h=b+240|0;j=b+352|0;k=b+360|0;l=b+472|0;m=b+480|0;n=b+592|0;if((R6((c[2388126]|0)+1|0,0,2)|0)!=0){o=1;i=b;return o|0}if((R6(c[2388126]|0,1,2)|0)!=0){o=1;i=b;return o|0}p=c[3530812]|0;if((c[3542200]|0)==0){o=1;i=b;return o|0}q=m+108|0;c[q>>2]=0;r=m+100|0;c[r>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,2)|0;do{if((c[q>>2]|0)!=0){m=c[r>>2]|0;c[n>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](n,2,0)|0;if((m|0)<1){o=1;i=b;return o|0}if((gzL(p,0,2)|0)==0){break}else{o=1}i=b;return o|0}}while(0);p=c[3530576]|0;if((c[3542200]|0)==0){o=1;i=b;return o|0}n=k+108|0;c[n>>2]=0;r=k+100|0;c[r>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,3)|0;do{if((c[n>>2]|0)!=0){k=c[r>>2]|0;c[l>>2]=9534384;q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[q&16383](l,3,0)|0;if((k|0)<1){o=1;i=b;return o|0}if((gzL(p,0,3)|0)==0){break}else{o=1}i=b;return o|0}}while(0);p=c[3530416]|0;if((c[3542200]|0)==0){o=1;i=b;return o|0}l=h+108|0;c[l>>2]=0;r=h+100|0;c[r>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](h,4)|0;do{if((c[l>>2]|0)!=0){h=c[r>>2]|0;c[j>>2]=9534384;n=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[n&16383](j,4,0)|0;if((h|0)<1){o=1;i=b;return o|0}if((gzL(p,0,4)|0)==0){break}else{o=1}i=b;return o|0}}while(0);p=0;j=c[3530416]|0;while(1){r=a[j]|0;l=j+1|0;a[j]=a[l]|0;a[l]=r;r=p+1|0;if((r|0)<524288){p=r;j=j+2|0}else{break}}j=(c[3529752]|0)+262144|0;if((c[3542200]|0)==0){o=1;i=b;return o|0}p=f+108|0;c[p>>2]=0;r=f+100|0;c[r>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,5)|0;do{if((c[p>>2]|0)!=0){f=c[r>>2]|0;c[g>>2]=9534384;l=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[l&16383](g,5,0)|0;if((f|0)<1){o=1;i=b;return o|0}if((gzL(j,0,5)|0)==0){break}else{o=1}i=b;return o|0}}while(0);j=(c[3529708]|0)+262144|0;if((c[3542200]|0)==0){o=1;i=b;return o|0}g=d+108|0;c[g>>2]=0;r=d+100|0;c[r>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](d,6)|0;do{if((c[g>>2]|0)!=0){d=c[r>>2]|0;c[e>>2]=9534384;p=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[p&16383](e,6,0)|0;if((d|0)<1){o=1;i=b;return o|0}if((gzL(j,0,6)|0)==0){break}else{o=1}i=b;return o|0}}while(0);erD(1048576,1048576);erP(1048576,1048576);o=0;i=b;return o|0}function erS(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;a=i;i=i+600|0;b=a|0;d=a+112|0;e=a+120|0;f=a+232|0;g=a+240|0;h=a+352|0;j=a+360|0;k=a+472|0;l=a+480|0;m=a+592|0;if((R6((c[2388126]|0)+1|0,0,2)|0)!=0){n=1;i=a;return n|0}if((R6(c[2388126]|0,1,2)|0)!=0){n=1;i=a;return n|0}o=c[3530812]|0;if((c[3542200]|0)==0){n=1;i=a;return n|0}p=l+108|0;c[p>>2]=0;q=l+100|0;c[q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,2)|0;do{if((c[p>>2]|0)!=0){l=c[q>>2]|0;c[m>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](m,2,0)|0;if((l|0)<1){n=1;i=a;return n|0}if((gzL(o,0,2)|0)==0){break}else{n=1}i=a;return n|0}}while(0);o=c[3530576]|0;if((c[3542200]|0)==0){n=1;i=a;return n|0}m=j+108|0;c[m>>2]=0;q=j+100|0;c[q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,3)|0;do{if((c[m>>2]|0)!=0){j=c[q>>2]|0;c[k>>2]=9534384;p=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[p&16383](k,3,0)|0;if((j|0)<1){n=1;i=a;return n|0}if((gzL(o,0,3)|0)==0){break}else{n=1}i=a;return n|0}}while(0);o=(c[3530576]|0)+1048576|0;if((c[3542200]|0)==0){n=1;i=a;return n|0}k=g+108|0;c[k>>2]=0;q=g+100|0;c[q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,4)|0;do{if((c[k>>2]|0)!=0){g=c[q>>2]|0;c[h>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](h,4,0)|0;if((g|0)<1){n=1;i=a;return n|0}if((gzL(o,0,4)|0)==0){break}else{n=1}i=a;return n|0}}while(0);if((R6((c[3530416]|0)+1|0,5,2)|0)!=0){n=1;i=a;return n|0}if((R6(c[3530416]|0,6,2)|0)!=0){n=1;i=a;return n|0}o=(c[3529752]|0)+262144|0;if((c[3542200]|0)==0){n=1;i=a;return n|0}h=e+108|0;c[h>>2]=0;q=e+100|0;c[q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,7)|0;do{if((c[h>>2]|0)!=0){e=c[q>>2]|0;c[f>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](f,7,0)|0;if((e|0)<1){n=1;i=a;return n|0}if((gzL(o,0,7)|0)==0){break}else{n=1}i=a;return n|0}}while(0);o=(c[3529708]|0)+262144|0;if((c[3542200]|0)==0){n=1;i=a;return n|0}f=b+108|0;c[f>>2]=0;q=b+100|0;c[q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](b,8)|0;do{if((c[f>>2]|0)!=0){b=c[q>>2]|0;c[d>>2]=9534384;h=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[h&16383](d,8,0)|0;if((b|0)<1){n=1;i=a;return n|0}if((gzL(o,0,8)|0)==0){break}else{n=1}i=a;return n|0}}while(0);erD(2097152,2097152);erP(2097152,2097152);n=0;i=a;return n|0}function erT(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=i;i=i+600|0;d=b|0;e=b+112|0;f=b+120|0;g=b+232|0;h=b+240|0;j=b+352|0;k=b+360|0;l=b+472|0;m=b+480|0;n=b+592|0;if((R6((c[2388126]|0)+1|0,0,2)|0)!=0){o=1;i=b;return o|0}if((R6(c[2388126]|0,1,2)|0)!=0){o=1;i=b;return o|0}p=c[3530812]|0;if((c[3542200]|0)==0){o=1;i=b;return o|0}q=m+108|0;c[q>>2]=0;r=m+100|0;c[r>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,2)|0;do{if((c[q>>2]|0)!=0){m=c[r>>2]|0;c[n>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](n,2,0)|0;if((m|0)<1){o=1;i=b;return o|0}if((gzL(p,0,2)|0)==0){break}else{o=1}i=b;return o|0}}while(0);p=c[3530576]|0;if((c[3542200]|0)==0){o=1;i=b;return o|0}n=k+108|0;c[n>>2]=0;r=k+100|0;c[r>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,3)|0;do{if((c[n>>2]|0)!=0){k=c[r>>2]|0;c[l>>2]=9534384;q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[q&16383](l,3,0)|0;if((k|0)<1){o=1;i=b;return o|0}if((gzL(p,0,3)|0)==0){break}else{o=1}i=b;return o|0}}while(0);p=c[3530416]|0;if((c[3542200]|0)==0){o=1;i=b;return o|0}l=h+108|0;c[l>>2]=0;r=h+100|0;c[r>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](h,4)|0;do{if((c[l>>2]|0)!=0){h=c[r>>2]|0;c[j>>2]=9534384;n=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[n&16383](j,4,0)|0;if((h|0)<1){o=1;i=b;return o|0}if((gzL(p,0,4)|0)==0){break}else{o=1}i=b;return o|0}}while(0);p=0;j=c[3530416]|0;while(1){r=a[j]|0;l=j+1|0;a[j]=a[l]|0;a[l]=r;r=p+1|0;if((r|0)<1048576){p=r;j=j+2|0}else{break}}j=(c[3529752]|0)+262144|0;if((c[3542200]|0)==0){o=1;i=b;return o|0}p=f+108|0;c[p>>2]=0;r=f+100|0;c[r>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,5)|0;do{if((c[p>>2]|0)!=0){f=c[r>>2]|0;c[g>>2]=9534384;l=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[l&16383](g,5,0)|0;if((f|0)<1){o=1;i=b;return o|0}if((gzL(j,0,5)|0)==0){break}else{o=1}i=b;return o|0}}while(0);j=(c[3529708]|0)+262144|0;if((c[3542200]|0)==0){o=1;i=b;return o|0}g=d+108|0;c[g>>2]=0;r=d+100|0;c[r>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](d,6)|0;do{if((c[g>>2]|0)!=0){d=c[r>>2]|0;c[e>>2]=9534384;p=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[p&16383](e,6,0)|0;if((d|0)<1){o=1;i=b;return o|0}if((gzL(j,0,6)|0)==0){break}else{o=1}i=b;return o|0}}while(0);erD(2097152,2097152);erP(2097152,2097152);o=0;i=b;return o|0}function erU(d){d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;c[2414932]=0;err();e=c[2414144]|0;f=0;while(1){if((f|0)>=1024){break}g=9638528+(f<<2)|0;if((c[g>>2]|0)==0){h=736;break}else{f=f+1|0}}do{if((h|0)==736){f=gGq(e)|0;c[g>>2]=f;if((f|0)==0){break}gGz(f|0,0,e|0);c[2414932]=f;gGz(f|0,0,e|0);err();do{if((d|0)!=0){if((gD[d&8191]()|0)==0){break}else{i=1}return i|0}}while(0);fwR(0);f=c[2439330]|0;j=(f|0)==0;if(!j){k=f;gGC(9706056,k|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];k=c[3528484]|0;c[2076596]=k;l=c[2417276]|0;c[3541536]=l;c[1836236]=0;m=c[2385902]|0;n=0;o=0;while(1){c[f+76+(o<<2)>>2]=m+(o<<8);p=n+1&65535;if((p&65535)>127){q=0;r=0;break}else{n=p;o=p&65535}}while(1){o=m+(r<<8)|0;c[f+76+(r+512<<2)>>2]=o;c[f+76+(r+768<<2)>>2]=o;o=q+1&65535;if((o&65535)>127){break}else{q=o;r=o&65535}}m=c[2386056]|0;c[f+588>>2]=m;o=m+256|0;c[f+592>>2]=o;n=m+512|0;c[f+596>>2]=n;p=m+768|0;c[f+600>>2]=p;s=m+1024|0;c[f+604>>2]=s;t=m+1280|0;c[f+608>>2]=t;u=m+1536|0;c[f+612>>2]=u;v=m+1792|0;c[f+616>>2]=v;c[f+1612>>2]=m;c[f+1616>>2]=o;c[f+1620>>2]=n;c[f+1624>>2]=p;c[f+1628>>2]=s;c[f+1632>>2]=t;c[f+1636>>2]=u;c[f+1640>>2]=v;c[f+2636>>2]=m;c[f+3660>>2]=m;c[f+2640>>2]=o;c[f+3664>>2]=o;c[f+2644>>2]=n;c[f+3668>>2]=n;c[f+2648>>2]=p;c[f+3672>>2]=p;c[f+2652>>2]=s;c[f+3676>>2]=s;c[f+2656>>2]=t;c[f+3680>>2]=t;c[f+2660>>2]=u;c[f+3684>>2]=u;c[f+2664>>2]=v;c[f+3688>>2]=v;c[f+4184>>2]=1530;c[f+4180>>2]=2494;if(!j){v=f;gGC(v|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=k;c[2417276]=l;c[1836236]=-1;c[2424]=5600;Ux(0,6060,0);c[2407030]=256;c[2407068]=3;v=c[642608+(c[2436]<<2)>>2]|0;u=c[v+128>>2]|0;if((c[v+52>>2]&4|0)==0){c[2113068]=u;t=c[v+132>>2]|0;c[2113070]=t;c[2443814]=u;c[2440436]=t;w=u;x=t}else{c[2113070]=u;t=c[v+132>>2]|0;c[2113068]=t;c[2440436]=u;c[2443814]=t;w=t;x=u}u=ag(w<<1,x)|0;t=gGq(u)|0;c[2112926]=t;if((t|0)!=0){gGz(t|0,0,u|0)}u=c[2414634]|0;gGz(u|0,0,(c[2411604]|0)-u|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];u=c[3532592]|0;if((u|0)!=0){gGC(9104152,u|0,280)|0}c[2113054]=c[2113060]}RI();u=c[2394]|0;t=c[14130368+(u<<2)>>2]|0;if((t|0)!=0){gGC(t|0,9104152,280)|0}c[8452240+(u<<2)>>2]=c[2113054];c[2394]=-1;u=c[2439330]|0;t=(u|0)==0;if(!t){v=u;gGC(9706056,v|0,76)|0}v=c[2438118]|0;c[2433530]=v;s=c[3528484]|0;c[2076596]=s;p=c[2417276]|0;c[3541536]=p;c[1836236]=0;gGz(9706056,0,76);if(!t){t=u;gGC(t|0,9706056,76)|0}c[2438118]=v;c[3528484]=s;c[2417276]=p;c[1836236]=-1;c[2113156]=0;a[9628264]=0;c[2407033]=0;p=c[3541206]|0;c[3541190]=p;c[3541198]=p;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=p+256;c[3541199]=p+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=p+512;c[3541200]=p+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=p+768;c[3541201]=p+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;i=0;return i|0}}while(0);c[2414932]=0;i=1;return i|0}function erV(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;a=i;i=i+600|0;b=a|0;d=a+112|0;e=a+120|0;f=a+232|0;g=a+240|0;h=a+352|0;j=a+360|0;k=a+472|0;l=a+480|0;m=a+592|0;if((R6((c[2388126]|0)+1|0,0,2)|0)!=0){n=1;i=a;return n|0}if((R6(c[2388126]|0,1,2)|0)!=0){n=1;i=a;return n|0}o=c[2385902]|0;if((c[3542200]|0)==0){n=1;i=a;return n|0}p=l+108|0;c[p>>2]=0;q=l+100|0;c[q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,2)|0;do{if((c[p>>2]|0)!=0){l=c[q>>2]|0;c[m>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](m,2,0)|0;if((l|0)<1){n=1;i=a;return n|0}if((gzL(o,0,2)|0)==0){break}else{n=1}i=a;return n|0}}while(0);o=c[3530812]|0;if((c[3542200]|0)==0){n=1;i=a;return n|0}m=j+108|0;c[m>>2]=0;q=j+100|0;c[q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,3)|0;do{if((c[m>>2]|0)!=0){j=c[q>>2]|0;c[k>>2]=9534384;p=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[p&16383](k,3,0)|0;if((j|0)<1){n=1;i=a;return n|0}if((gzL(o,0,3)|0)==0){break}else{n=1}i=a;return n|0}}while(0);o=c[3530576]|0;if((c[3542200]|0)==0){n=1;i=a;return n|0}k=g+108|0;c[k>>2]=0;q=g+100|0;c[q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,4)|0;do{if((c[k>>2]|0)!=0){g=c[q>>2]|0;c[h>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](h,4,0)|0;if((g|0)<1){n=1;i=a;return n|0}if((gzL(o,0,4)|0)==0){break}else{n=1}i=a;return n|0}}while(0);if((R6(c[3530416]|0,5,2)|0)!=0){n=1;i=a;return n|0}if((R6((c[3530416]|0)+1|0,6,2)|0)!=0){n=1;i=a;return n|0}o=c[3529752]|0;if((c[3542200]|0)==0){n=1;i=a;return n|0}h=e+108|0;c[h>>2]=0;q=e+100|0;c[q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,7)|0;do{if((c[h>>2]|0)!=0){e=c[q>>2]|0;c[f>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](f,7,0)|0;if((e|0)<1){n=1;i=a;return n|0}if((gzL(o,0,7)|0)==0){break}else{n=1}i=a;return n|0}}while(0);o=c[3529752]|0;f=o+262144|0;gGC(f|0,o|0,131072)|0;f=o+393216|0;gGC(f|0,o|0,131072)|0;f=o+524288|0;if((c[3542200]|0)==0){n=1;i=a;return n|0}o=b+108|0;c[o>>2]=0;q=b+100|0;c[q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](b,8)|0;do{if((c[o>>2]|0)!=0){b=c[q>>2]|0;c[d>>2]=9534384;h=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[h&16383](d,8,0)|0;if((b|0)<1){n=1;i=a;return n|0}if((gzL(f,0,8)|0)==0){break}else{n=1}i=a;return n|0}}while(0);erq(131072,524288,1048576);fxU(0,425984);if((c[2394]|0)==0){s=c[2112932]|0}else{c[2394]=0;f=c[3532596]|0;c[2112932]=f;d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];s=f}f=c[2388126]|0;d=s|0;q=0;while(1){o=f+q|0;c[d>>2]=o;c[d+131072>>2]=o;o=q+1024|0;if(o>>>0>262143){break}else{d=d+4|0;q=o}}q=c[2387164]|0;c[s+2176>>2]=q;c[s+67712>>2]=q;c[s+133248>>2]=q;d=q+1024|0;c[s+2180>>2]=d;c[s+67716>>2]=d;c[s+133252>>2]=d;c[s+67776>>2]=c[2443470];d=c[2387982]|0;c[s+2304>>2]=d;c[s+67840>>2]=d;c[s+133376>>2]=d;q=d+1024|0;c[s+2308>>2]=q;c[s+67844>>2]=q;c[s+133380>>2]=q;q=d+2048|0;c[s+2312>>2]=q;c[s+67848>>2]=q;c[s+133384>>2]=q;q=d+3072|0;c[s+2316>>2]=q;c[s+67852>>2]=q;c[s+133388>>2]=q;q=d+4096|0;c[s+2320>>2]=q;c[s+67856>>2]=q;c[s+133392>>2]=q;q=d+5120|0;c[s+2324>>2]=q;c[s+67860>>2]=q;c[s+133396>>2]=q;q=d+6144|0;c[s+2328>>2]=q;c[s+67864>>2]=q;c[s+133400>>2]=q;q=d+7168|0;c[s+2332>>2]=q;c[s+67868>>2]=q;c[s+133404>>2]=q;q=d+8192|0;c[s+2336>>2]=q;c[s+67872>>2]=q;c[s+133408>>2]=q;q=d+9216|0;c[s+2340>>2]=q;c[s+67876>>2]=q;c[s+133412>>2]=q;q=d+10240|0;c[s+2344>>2]=q;c[s+67880>>2]=q;c[s+133416>>2]=q;q=d+11264|0;c[s+2348>>2]=q;c[s+67884>>2]=q;c[s+133420>>2]=q;q=d+12288|0;c[s+2352>>2]=q;c[s+67888>>2]=q;c[s+133424>>2]=q;q=d+13312|0;c[s+2356>>2]=q;c[s+67892>>2]=q;c[s+133428>>2]=q;q=d+14336|0;c[s+2360>>2]=q;c[s+67896>>2]=q;c[s+133432>>2]=q;q=d+15360|0;c[s+2364>>2]=q;c[s+67900>>2]=q;c[s+133436>>2]=q;q=c[2405794]|0;c[s+2496>>2]=q;c[s+68032>>2]=q;c[s+133568>>2]=q;d=q+1024|0;c[s+2500>>2]=d;c[s+68036>>2]=d;c[s+133572>>2]=d;d=c[2388254]|0;q=s+3840|0;f=983040;while(1){o=d+(f-983040)|0;c[q>>2]=o;c[q+131072>>2]=o;o=f+1024|0;if(o>>>0>1048575){break}else{q=q+4|0;f=o}}c[s+196728>>2]=160;c[s+196648>>2]=2950;c[s+196688>>2]=2956;c[s+196608>>2]=3162;s=c[3532592]|0;if((s|0)!=0){gGC(s|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;n=0;i=a;return n|0}function erW(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;c[2414932]=0;err();e=c[2414144]|0;f=0;while(1){if((f|0)>=1024){break}g=9638528+(f<<2)|0;if((c[g>>2]|0)==0){i=827;break}else{f=f+1|0}}do{if((i|0)==827){f=gGq(e)|0;c[g>>2]=f;if((f|0)==0){break}gGz(f|0,0,e|0);c[2414932]=f;gGz(f|0,0,e|0);err();do{if((b|0)!=0){if((gD[b&8191]()|0)==0){break}else{j=1}return j|0}}while(0);fxU(0,425984);if((c[2394]|0)==0){k=c[2112932]|0}else{c[2394]=0;f=c[3532596]|0;c[2112932]=f;l=c[3532592]|0;if((l|0)!=0){gGC(9104152,l|0,280)|0}c[2113054]=c[2113060];k=f}f=c[2388126]|0;l=k|0;m=0;while(1){n=f+m|0;c[l>>2]=n;c[l+131072>>2]=n;n=m+1024|0;if(n>>>0>524287){break}else{l=l+4|0;m=n}}m=c[2387164]|0;c[k+2176>>2]=m;c[k+67712>>2]=m;c[k+133248>>2]=m;l=m+1024|0;c[k+2180>>2]=l;c[k+67716>>2]=l;c[k+133252>>2]=l;l=c[2387982]|0;c[k+2304>>2]=l;c[k+67840>>2]=l;c[k+133376>>2]=l;m=l+1024|0;c[k+2308>>2]=m;c[k+67844>>2]=m;c[k+133380>>2]=m;m=l+2048|0;c[k+2312>>2]=m;c[k+67848>>2]=m;c[k+133384>>2]=m;m=l+3072|0;c[k+2316>>2]=m;c[k+67852>>2]=m;c[k+133388>>2]=m;m=l+4096|0;c[k+2320>>2]=m;c[k+67856>>2]=m;c[k+133392>>2]=m;m=l+5120|0;c[k+2324>>2]=m;c[k+67860>>2]=m;c[k+133396>>2]=m;m=l+6144|0;c[k+2328>>2]=m;c[k+67864>>2]=m;c[k+133400>>2]=m;m=l+7168|0;c[k+2332>>2]=m;c[k+67868>>2]=m;c[k+133404>>2]=m;m=l+8192|0;c[k+2336>>2]=m;c[k+67872>>2]=m;c[k+133408>>2]=m;m=l+9216|0;c[k+2340>>2]=m;c[k+67876>>2]=m;c[k+133412>>2]=m;m=l+10240|0;c[k+2344>>2]=m;c[k+67880>>2]=m;c[k+133416>>2]=m;m=l+11264|0;c[k+2348>>2]=m;c[k+67884>>2]=m;c[k+133420>>2]=m;m=l+12288|0;c[k+2352>>2]=m;c[k+67888>>2]=m;c[k+133424>>2]=m;m=l+13312|0;c[k+2356>>2]=m;c[k+67892>>2]=m;c[k+133428>>2]=m;m=l+14336|0;c[k+2360>>2]=m;c[k+67896>>2]=m;c[k+133432>>2]=m;m=l+15360|0;c[k+2364>>2]=m;c[k+67900>>2]=m;c[k+133436>>2]=m;m=c[2405794]|0;c[k+2496>>2]=m;c[k+68032>>2]=m;c[k+133568>>2]=m;l=m+1024|0;c[k+2500>>2]=l;c[k+68036>>2]=l;c[k+133572>>2]=l;l=c[2443470]|0;c[k+2112>>2]=l;c[k+67648>>2]=l;c[k+133184>>2]=l;c[k+2240>>2]=l;c[k+67776>>2]=l;c[k+133312>>2]=l;l=c[2388254]|0;m=k+3072|0;f=786432;while(1){n=l+(f-786432)|0;c[m>>2]=n;c[m+131072>>2]=n;n=f+1024|0;if(n>>>0>851967){break}else{m=m+4|0;f=n}}f=k+3840|0;m=983040;while(1){n=l+(m-983040)|0;c[f>>2]=n;c[f+131072>>2]=n;n=m+1024|0;if(n>>>0>1048575){break}else{f=f+4|0;m=n}}c[k+196728>>2]=160;c[k+196648>>2]=2950;c[k+196688>>2]=2956;c[k+196608>>2]=3162;m=c[3532592]|0;if((m|0)!=0){gGC(m|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;if((d|0)!=0){gu[d&16383]()}c[2424]=5600;m=a[9680]|0;f=m?32e3:0;if(m){if(a[9624]|0){m=f*3|0;l=62500;while(1){if((l|0)>(m|0)){l=l>>1}else{o=1222;p=l;break}}}else{o=2462;p=f}c[2429380]=p;c[3542124]=o;mw(4e6,p);l=gGq(262144)|0;c[2406684]=l;gGz(l|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(4e6,11025)}c[(c[3531464]|0)+44344>>2]=362;h[745421]=.3;c[2436794]=1;h[745420]=.3;c[2436792]=2;Ux(0,7575,1);Ux(1,7575,1);c[2407030]=154;c[2407068]=3;c[2407069]=154;c[2407107]=3;l=c[642608+(c[2436]<<2)>>2]|0;m=c[l+128>>2]|0;if((c[l+52>>2]&4|0)==0){c[2113068]=m;n=c[l+132>>2]|0;c[2113070]=n;c[2443814]=m;c[2440436]=n;q=m;r=n}else{c[2113070]=m;n=c[l+132>>2]|0;c[2113068]=n;c[2440436]=m;c[2443814]=n;q=n;r=m}m=ag(q<<1,r)|0;n=gGq(m)|0;c[2112926]=n;if((n|0)!=0){gGz(n|0,0,m|0)}m=c[2414634]|0;gGz(m|0,0,(c[2411604]|0)-m|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];m=c[3532592]|0;if((m|0)!=0){gGC(9104152,m|0,280)|0}c[2113054]=c[2113060]}RI();m=c[2394]|0;n=c[14130368+(m<<2)>>2]|0;if((n|0)!=0){gGC(n|0,9104152,280)|0}c[8452240+(m<<2)>>2]=c[2113054];c[2394]=-1;m=c[2439330]|0;n=(m|0)==0;if(!n){l=m;gGC(9706056,l|0,76)|0}l=c[2438118]|0;c[2433530]=l;s=c[3528484]|0;c[2076596]=s;t=c[2417276]|0;c[3541536]=t;c[1836236]=0;gGz(9706056,0,76);if(!n){n=m;gGC(n|0,9706056,76)|0}c[2438118]=l;c[3528484]=s;c[2417276]=t;c[1836236]=-1;mx(0);c[2113156]=0;a[9628264]=0;c[2407033]=0;t=c[3541206]|0;gGz(c[2430118]|0,0,16384);c[2407041]=4;gGz(c[2430119]|0,0,16384);c[2407049]=4;gGz(c[2430120]|0,0,16384);c[2407057]=4;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2113157]=0;a[9628420]=0;c[2407072]=0;gGz(c[2430122]|0,0,16384);c[2407080]=4;gGz(c[2430123]|0,0,16384);c[2407088]=4;gGz(c[2430124]|0,0,16384);c[2407096]=4;gGz(c[2430125]|0,0,16384);c[2407104]=4;s=(c[3529708]|0)-(c[3529752]|0)|0;c[3541190]=t;c[3541198]=t;c[3541191]=t+256;c[3541199]=t+65536;c[3541192]=t+512;c[3541200]=t+131072;c[3541193]=t+768;c[3541201]=t+196608;l=t+s|0;c[3541194]=l;c[3541202]=l;c[3541195]=t+(s+256);c[3541203]=t+(s+65536);c[3541196]=t+(s+512);c[3541204]=t+(s+131072);c[3541197]=t+(s+768);c[3541205]=t+(s+196608);j=0;return j|0}}while(0);c[2414932]=0;j=1;return j|0}function erX(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;a=i;i=i+840|0;b=a|0;d=a+112|0;e=a+120|0;f=a+232|0;g=a+240|0;h=a+352|0;j=a+360|0;k=a+472|0;l=a+480|0;m=a+592|0;n=a+600|0;o=a+712|0;p=a+720|0;q=a+832|0;if((R6((c[2388126]|0)+1|0,0,2)|0)!=0){r=1;i=a;return r|0}if((R6(c[2388126]|0,1,2)|0)!=0){r=1;i=a;return r|0}s=c[2385902]|0;if((c[3542200]|0)==0){r=1;i=a;return r|0}t=p+108|0;c[t>>2]=0;u=p+100|0;c[u>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,2)|0;do{if((c[t>>2]|0)!=0){p=c[u>>2]|0;c[q>>2]=9534384;v=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[v&16383](q,2,0)|0;if((p|0)<1){r=1;i=a;return r|0}if((gzL(s,0,2)|0)==0){break}else{r=1}i=a;return r|0}}while(0);s=c[3530812]|0;if((c[3542200]|0)==0){r=1;i=a;return r|0}q=n+108|0;c[q>>2]=0;u=n+100|0;c[u>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,3)|0;do{if((c[q>>2]|0)!=0){n=c[u>>2]|0;c[o>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](o,3,0)|0;if((n|0)<1){r=1;i=a;return r|0}if((gzL(s,0,3)|0)==0){break}else{r=1}i=a;return r|0}}while(0);s=c[3530576]|0;if((c[3542200]|0)==0){r=1;i=a;return r|0}o=l+108|0;c[o>>2]=0;u=l+100|0;c[u>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,4)|0;do{if((c[o>>2]|0)!=0){l=c[u>>2]|0;c[m>>2]=9534384;q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[q&16383](m,4,0)|0;if((l|0)<1){r=1;i=a;return r|0}if((gzL(s,0,4)|0)==0){break}else{r=1}i=a;return r|0}}while(0);s=(c[3530576]|0)+2097152|0;if((c[3542200]|0)==0){r=1;i=a;return r|0}m=j+108|0;c[m>>2]=0;u=j+100|0;c[u>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,5)|0;do{if((c[m>>2]|0)!=0){j=c[u>>2]|0;c[k>>2]=9534384;o=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[o&16383](k,5,0)|0;if((j|0)<1){r=1;i=a;return r|0}if((gzL(s,0,5)|0)==0){break}else{r=1}i=a;return r|0}}while(0);s=c[3530416]|0;if((c[3542200]|0)==0){r=1;i=a;return r|0}k=g+108|0;c[k>>2]=0;u=g+100|0;c[u>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,6)|0;do{if((c[k>>2]|0)!=0){g=c[u>>2]|0;c[h>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](h,6,0)|0;if((g|0)<1){r=1;i=a;return r|0}if((gzL(s,0,6)|0)==0){break}else{r=1}i=a;return r|0}}while(0);s=c[3529752]|0;if((c[3542200]|0)==0){r=1;i=a;return r|0}h=e+108|0;c[h>>2]=0;u=e+100|0;c[u>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,7)|0;do{if((c[h>>2]|0)!=0){e=c[u>>2]|0;c[f>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](f,7,0)|0;if((e|0)<1){r=1;i=a;return r|0}if((gzL(s,0,7)|0)==0){break}else{r=1}i=a;return r|0}}while(0);s=(c[3529708]|0)+262144|0;if((c[3542200]|0)==0){r=1;i=a;return r|0}f=b+108|0;c[f>>2]=0;u=b+100|0;c[u>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](b,8)|0;do{if((c[f>>2]|0)!=0){b=c[u>>2]|0;c[d>>2]=9534384;h=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[h&16383](d,8,0)|0;if((b|0)<1){r=1;i=a;return r|0}if((gzL(s,0,8)|0)==0){break}else{r=1}i=a;return r|0}}while(0);erZ(131072,4194304,2097152);r=0;i=a;return r|0}function erY(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;fwR(0);a=c[2439330]|0;if((a|0)!=0){d=a;gGC(9706056,d|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];d=c[3528484]|0;c[2076596]=d;e=c[2417276]|0;c[3541536]=e;c[1836236]=0;f=c[2385902]|0;g=0;h=0;while(1){c[a+76+(h<<2)>>2]=f+(h<<8);i=g+1&65535;if((i&65535)>239){j=0;k=0;break}else{g=i;h=i&65535}}while(1){h=f+(k<<8)|0;c[a+76+(k+512<<2)>>2]=h;c[a+76+(k+768<<2)>>2]=h;h=j+1&65535;if((h&65535)>239){break}else{j=h;k=h&65535}}k=c[2386056]|0;c[a+1036>>2]=k;j=k+256|0;c[a+1040>>2]=j;f=k+512|0;c[a+1044>>2]=f;h=k+768|0;c[a+1048>>2]=h;g=k+1024|0;c[a+1052>>2]=g;i=k+1280|0;c[a+1056>>2]=i;l=k+1536|0;c[a+1060>>2]=l;m=k+1792|0;c[a+1064>>2]=m;n=k+2048|0;c[a+1068>>2]=n;o=k+2304|0;c[a+1072>>2]=o;p=k+2560|0;c[a+1076>>2]=p;q=k+2816|0;c[a+1080>>2]=q;r=k+3072|0;c[a+1084>>2]=r;s=k+3328|0;c[a+1088>>2]=s;t=k+3584|0;c[a+1092>>2]=t;c[a+2060>>2]=k;c[a+2064>>2]=j;c[a+2068>>2]=f;c[a+2072>>2]=h;c[a+2076>>2]=g;c[a+2080>>2]=i;c[a+2084>>2]=l;c[a+2088>>2]=m;c[a+2092>>2]=n;c[a+2096>>2]=o;c[a+2100>>2]=p;c[a+2104>>2]=q;c[a+2108>>2]=r;c[a+2112>>2]=s;c[a+2116>>2]=t;t=240;s=240;while(1){r=k+((s<<8)-61440)|0;c[a+76+(s+512<<2)>>2]=r;c[a+76+(s+768<<2)>>2]=r;r=t+1&65535;if((r&65535)>254){break}else{t=r;s=r&65535}}c[a+4184>>2]=2156;c[a+4180>>2]=1834;s=a;gGC(s|0,9706056,76)|0;c[2438118]=c[2433530];c[3528484]=d;c[2417276]=e;c[1836236]=-1;return}function erZ(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;g=i;i=i+32|0;h=g|0;c[h>>2]=0;c[h+4>>2]=1;c[h+8>>2]=2;c[h+12>>2]=3;j=e<<2;c[h+16>>2]=j;c[h+20>>2]=j|1;c[h+24>>2]=j|2;c[h+28>>2]=j|3;j=(f|0)>=(e|0)?f:e;k=0;while(1){if((k|0)>=1024){l=978;break}m=9638528+(k<<2)|0;if((c[m>>2]|0)==0){break}else{k=k+1|0}}if((l|0)==978){i=g;return}k=gGq(j)|0;c[m>>2]=k;if((k|0)==0){i=g;return}gGz(k|0,0,j|0);j=c[3530812]|0;gGC(k|0,j|0,b)|0;m=b<<1;b=(m|0)/64|0;if((m|0)>63){m=0;do{n=m<<6;gGz(j+n|0,0,64);o=m<<8;p=0;do{q=1<<3-p;r=(c[h+(p<<2)>>2]|0)+o|0;s=0;do{t=r+(c[611840+(s<<2)>>2]|0)|0;u=(s<<3)+n|0;v=0;do{w=t+(c[600104+(v<<2)>>2]|0)|0;if(((d[k+((w|0)/8|0)|0]|0)&128>>>((w&7)>>>0)|0)!=0){w=j+(u+v)|0;a[w]=(d[w]|0|q)&255}v=v+1|0;}while((v|0)<8);s=s+1|0;}while((s|0)<8);p=p+1|0;}while((p|0)<4);m=m+1|0;}while((m|0)<(b|0))}m=c[3530576]|0;gGC(k|0,m|0,e)|0;j=(e|0)/256|0;if((e|0)>255){e=0;do{p=e<<8;gGz(m+p|0,0,256);n=e<<10;o=0;do{s=1<<7-o;q=(c[h+(o<<2)>>2]|0)+n|0;r=0;do{v=q+(c[611840+(r<<2)>>2]|0)|0;u=(r<<4)+p|0;t=0;do{w=v+(c[600104+(t<<2)>>2]|0)|0;if(((d[k+((w|0)/8|0)|0]|0)&128>>>((w&7)>>>0)|0)!=0){w=m+(u+t)|0;a[w]=(d[w]|0|s)&255}t=t+1|0;}while((t|0)<16);r=r+1|0;}while((r|0)<16);o=o+1|0;}while((o|0)<8);e=e+1|0;}while((e|0)<(j|0))}e=c[3530416]|0;gGC(k|0,e|0,f)|0;m=f<<1;f=(m|0)/256|0;if((m|0)>255){m=0;do{o=m<<8;gGz(e+o|0,0,256);p=m<<10;n=0;do{r=1<<3-n;s=(c[h+(n<<2)>>2]|0)+p|0;q=0;do{t=s+(c[611840+(q<<2)>>2]|0)|0;u=(q<<4)+o|0;v=0;do{w=t+(c[600104+(v<<2)>>2]|0)|0;if(((d[k+((w|0)/8|0)|0]|0)&128>>>((w&7)>>>0)|0)!=0){w=e+(u+v)|0;a[w]=(d[w]|0|r)&255}v=v+1|0;}while((v|0)<16);q=q+1|0;}while((q|0)<16);n=n+1|0;}while((n|0)<4);m=m+1|0;}while((m|0)<(f|0))}c[2439222]=b-1;c[2439220]=j-1;c[2439218]=f-1;a[668912]=1;f=0;while(1){if((f|0)>=1024){l=975;break}x=9638528+(f<<2)|0;if((c[x>>2]|0)==(k|0)){break}else{f=f+1|0}}if((l|0)==975){i=g;return}gGr(k);c[x>>2]=0;i=g;return}function er_(b){b=b|0;a[9706117]=(b|0)!=0|0;return}function er$(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;a=i;i=i+720|0;b=a|0;d=a+112|0;e=a+120|0;f=a+232|0;g=a+240|0;h=a+352|0;j=a+360|0;k=a+472|0;l=a+480|0;m=a+592|0;n=a+600|0;o=a+712|0;if((R6(c[2388126]|0,0,2)|0)!=0){p=1;i=a;return p|0}if((R6((c[2388126]|0)+1|0,1,2)|0)!=0){p=1;i=a;return p|0}q=c[2385902]|0;if((c[3542200]|0)==0){p=1;i=a;return p|0}r=n+108|0;c[r>>2]=0;s=n+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,2)|0;do{if((c[r>>2]|0)!=0){n=c[s>>2]|0;c[o>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](o,2,0)|0;if((n|0)<1){p=1;i=a;return p|0}if((gzL(q,0,2)|0)==0){break}else{p=1}i=a;return p|0}}while(0);gGz(c[3530812]|0,-1|0,32);q=c[3530576]|0;if((c[3542200]|0)==0){p=1;i=a;return p|0}o=l+108|0;c[o>>2]=0;s=l+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,3)|0;do{if((c[o>>2]|0)!=0){l=c[s>>2]|0;c[m>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](m,3,0)|0;if((l|0)<1){p=1;i=a;return p|0}if((gzL(q,0,3)|0)==0){break}else{p=1}i=a;return p|0}}while(0);q=(c[3530576]|0)+2097152|0;if((c[3542200]|0)==0){p=1;i=a;return p|0}m=j+108|0;c[m>>2]=0;s=j+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,4)|0;do{if((c[m>>2]|0)!=0){j=c[s>>2]|0;c[k>>2]=9534384;o=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[o&16383](k,4,0)|0;if((j|0)<1){p=1;i=a;return p|0}if((gzL(q,0,4)|0)==0){break}else{p=1}i=a;return p|0}}while(0);q=c[3530416]|0;if((c[3542200]|0)==0){p=1;i=a;return p|0}k=g+108|0;c[k>>2]=0;s=g+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,5)|0;do{if((c[k>>2]|0)!=0){g=c[s>>2]|0;c[h>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](h,5,0)|0;if((g|0)<1){p=1;i=a;return p|0}if((gzL(q,0,5)|0)==0){break}else{p=1}i=a;return p|0}}while(0);q=c[3529752]|0;if((c[3542200]|0)==0){p=1;i=a;return p|0}h=e+108|0;c[h>>2]=0;s=e+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,6)|0;do{if((c[h>>2]|0)!=0){e=c[s>>2]|0;c[f>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](f,6,0)|0;if((e|0)<1){p=1;i=a;return p|0}if((gzL(q,0,6)|0)==0){break}else{p=1}i=a;return p|0}}while(0);q=(c[3529708]|0)+262144|0;if((c[3542200]|0)==0){p=1;i=a;return p|0}f=b+108|0;c[f>>2]=0;s=b+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](b,7)|0;do{if((c[f>>2]|0)!=0){b=c[s>>2]|0;c[d>>2]=9534384;h=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[h&16383](d,7,0)|0;if((b|0)<1){p=1;i=a;return p|0}if((gzL(q,0,7)|0)==0){break}else{p=1}i=a;return p|0}}while(0);erZ(32,4194304,2097152);p=0;i=a;return p|0}function er0(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;a=i;i=i+480|0;b=a|0;d=a+112|0;e=a+120|0;f=a+232|0;g=a+240|0;h=a+352|0;j=a+360|0;k=a+472|0;if((R6((c[2388126]|0)+1|0,0,2)|0)!=0){l=1;i=a;return l|0}if((R6(c[2388126]|0,1,2)|0)!=0){l=1;i=a;return l|0}m=c[2385902]|0;if((c[3542200]|0)==0){l=1;i=a;return l|0}n=j+108|0;c[n>>2]=0;o=j+100|0;c[o>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,2)|0;do{if((c[n>>2]|0)!=0){j=c[o>>2]|0;c[k>>2]=9534384;p=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[p&16383](k,2,0)|0;if((j|0)<1){l=1;i=a;return l|0}if((gzL(m,0,2)|0)==0){break}else{l=1}i=a;return l|0}}while(0);gGz(c[3530812]|0,-1|0,32);m=c[3530576]|0;if((c[3542200]|0)==0){l=1;i=a;return l|0}k=g+108|0;c[k>>2]=0;o=g+100|0;c[o>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,3)|0;do{if((c[k>>2]|0)!=0){g=c[o>>2]|0;c[h>>2]=9534384;n=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[n&16383](h,3,0)|0;if((g|0)<1){l=1;i=a;return l|0}if((gzL(m,0,3)|0)==0){break}else{l=1}i=a;return l|0}}while(0);m=(c[3530576]|0)+524288|0;if((c[3542200]|0)==0){l=1;i=a;return l|0}h=e+108|0;c[h>>2]=0;o=e+100|0;c[o>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,4)|0;do{if((c[h>>2]|0)!=0){e=c[o>>2]|0;c[f>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](f,4,0)|0;if((e|0)<1){l=1;i=a;return l|0}if((gzL(m,0,4)|0)==0){break}else{l=1}i=a;return l|0}}while(0);if((R6(c[3530416]|0,5,2)|0)!=0){l=1;i=a;return l|0}if((R6((c[3530416]|0)+1|0,6,2)|0)!=0){l=1;i=a;return l|0}m=c[3529752]|0;if((c[3542200]|0)==0){l=1;i=a;return l|0}f=b+108|0;c[f>>2]=0;o=b+100|0;c[o>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](b,7)|0;do{if((c[f>>2]|0)!=0){b=c[o>>2]|0;c[d>>2]=9534384;h=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[h&16383](d,7,0)|0;if((b|0)<1){l=1;i=a;return l|0}if((gzL(m,0,7)|0)==0){break}else{l=1}i=a;return l|0}}while(0);erZ(32,1048576,524288);l=0;i=a;return l|0}function er1(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;fwR(0);a=c[2439330]|0;d=(a|0)==0;if(!d){e=a;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];e=c[3528484]|0;c[2076596]=e;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;g=c[2385902]|0;h=0;i=0;while(1){c[a+76+(i<<2)>>2]=g+(i<<8);j=h+1&65535;if((j&65535)>239){k=0;l=0;break}else{h=j;i=j&65535}}while(1){i=g+(l<<8)|0;c[a+76+(l+512<<2)>>2]=i;c[a+76+(l+768<<2)>>2]=i;i=k+1&65535;if((i&65535)>239){break}else{k=i;l=i&65535}}l=c[2386056]|0;c[a+1036>>2]=l;k=l+256|0;c[a+1040>>2]=k;g=l+512|0;c[a+1044>>2]=g;i=l+768|0;c[a+1048>>2]=i;h=l+1024|0;c[a+1052>>2]=h;j=l+1280|0;c[a+1056>>2]=j;m=l+1536|0;c[a+1060>>2]=m;n=l+1792|0;c[a+1064>>2]=n;c[a+2060>>2]=l;c[a+2064>>2]=k;c[a+2068>>2]=g;c[a+2072>>2]=i;c[a+2076>>2]=h;c[a+2080>>2]=j;c[a+2084>>2]=m;c[a+2088>>2]=n;c[a+3084>>2]=l;c[a+4108>>2]=l;c[a+3088>>2]=k;c[a+4112>>2]=k;c[a+3092>>2]=g;c[a+4116>>2]=g;c[a+3096>>2]=i;c[a+4120>>2]=i;c[a+3100>>2]=h;c[a+4124>>2]=h;c[a+3104>>2]=j;c[a+4128>>2]=j;c[a+3108>>2]=m;c[a+4132>>2]=m;c[a+3112>>2]=n;c[a+4136>>2]=n;c[a+4184>>2]=3326;c[a+4180>>2]=1832;if(d){o=c[2433530]|0;c[2438118]=o;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}d=a;gGC(d|0,9706056,76)|0;o=c[2433530]|0;c[2438118]=o;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}function er2(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;a=i;i=i+1080|0;b=a|0;d=a+112|0;e=a+120|0;f=a+232|0;g=a+240|0;h=a+352|0;j=a+360|0;k=a+472|0;l=a+480|0;m=a+592|0;n=a+600|0;o=a+712|0;p=a+720|0;q=a+832|0;r=a+840|0;s=a+952|0;t=a+960|0;u=a+1072|0;if((R6((c[2388126]|0)+1|0,0,2)|0)!=0){v=1;i=a;return v|0}if((R6(c[2388126]|0,1,2)|0)!=0){v=1;i=a;return v|0}w=c[2385902]|0;if((c[3542200]|0)==0){v=1;i=a;return v|0}x=t+108|0;c[x>>2]=0;y=t+100|0;c[y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,2)|0;do{if((c[x>>2]|0)!=0){t=c[y>>2]|0;c[u>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](u,2,0)|0;if((t|0)<1){v=1;i=a;return v|0}if((gzL(w,0,2)|0)==0){break}else{v=1}i=a;return v|0}}while(0);w=c[3530812]|0;if((c[3542200]|0)==0){v=1;i=a;return v|0}u=r+108|0;c[u>>2]=0;y=r+100|0;c[y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,3)|0;do{if((c[u>>2]|0)!=0){r=c[y>>2]|0;c[s>>2]=9534384;x=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[x&16383](s,3,0)|0;if((r|0)<1){v=1;i=a;return v|0}if((gzL(w,0,3)|0)==0){break}else{v=1}i=a;return v|0}}while(0);w=c[3530576]|0;if((c[3542200]|0)==0){v=1;i=a;return v|0}s=p+108|0;c[s>>2]=0;y=p+100|0;c[y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,4)|0;do{if((c[s>>2]|0)!=0){p=c[y>>2]|0;c[q>>2]=9534384;u=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[u&16383](q,4,0)|0;if((p|0)<1){v=1;i=a;return v|0}if((gzL(w,0,4)|0)==0){break}else{v=1}i=a;return v|0}}while(0);w=(c[3530576]|0)+524288|0;if((c[3542200]|0)==0){v=1;i=a;return v|0}q=n+108|0;c[q>>2]=0;y=n+100|0;c[y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,5)|0;do{if((c[q>>2]|0)!=0){n=c[y>>2]|0;c[o>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](o,5,0)|0;if((n|0)<1){v=1;i=a;return v|0}if((gzL(w,0,5)|0)==0){break}else{v=1}i=a;return v|0}}while(0);w=(c[3530576]|0)+1048576|0;if((c[3542200]|0)==0){v=1;i=a;return v|0}o=l+108|0;c[o>>2]=0;y=l+100|0;c[y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,6)|0;do{if((c[o>>2]|0)!=0){l=c[y>>2]|0;c[m>>2]=9534384;q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[q&16383](m,6,0)|0;if((l|0)<1){v=1;i=a;return v|0}if((gzL(w,0,6)|0)==0){break}else{v=1}i=a;return v|0}}while(0);w=(c[3530576]|0)+2097152|0;if((c[3542200]|0)==0){v=1;i=a;return v|0}m=j+108|0;c[m>>2]=0;y=j+100|0;c[y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,7)|0;do{if((c[m>>2]|0)!=0){j=c[y>>2]|0;c[k>>2]=9534384;o=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[o&16383](k,7,0)|0;if((j|0)<1){v=1;i=a;return v|0}if((gzL(w,0,7)|0)==0){break}else{v=1}i=a;return v|0}}while(0);w=(c[3530576]|0)+2621440|0;if((c[3542200]|0)==0){v=1;i=a;return v|0}k=g+108|0;c[k>>2]=0;y=g+100|0;c[y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,8)|0;do{if((c[k>>2]|0)!=0){g=c[y>>2]|0;c[h>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](h,8,0)|0;if((g|0)<1){v=1;i=a;return v|0}if((gzL(w,0,8)|0)==0){break}else{v=1}i=a;return v|0}}while(0);w=(c[3530576]|0)+3145728|0;if((c[3542200]|0)==0){v=1;i=a;return v|0}h=e+108|0;c[h>>2]=0;y=e+100|0;c[y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,9)|0;do{if((c[h>>2]|0)!=0){e=c[y>>2]|0;c[f>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](f,9,0)|0;if((e|0)<1){v=1;i=a;return v|0}if((gzL(w,0,9)|0)==0){break}else{v=1}i=a;return v|0}}while(0);if((R6(c[3530416]|0,10,2)|0)!=0){v=1;i=a;return v|0}if((R6((c[3530416]|0)+1|0,11,2)|0)!=0){v=1;i=a;return v|0}w=c[3529752]|0;if((c[3542200]|0)==0){v=1;i=a;return v|0}f=b+108|0;c[f>>2]=0;y=b+100|0;c[y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](b,12)|0;do{if((c[f>>2]|0)!=0){b=c[y>>2]|0;c[d>>2]=9534384;h=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[h&16383](d,12,0)|0;if((b|0)<1){v=1;i=a;return v|0}if((gzL(w,0,12)|0)==0){break}else{v=1}i=a;return v|0}}while(0);erZ(65536,4194304,524288);v=0;i=a;return v|0}function er3(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;a=i;i=i+600|0;b=a|0;d=a+112|0;e=a+120|0;f=a+232|0;g=a+240|0;h=a+352|0;j=a+360|0;k=a+472|0;l=a+480|0;m=a+592|0;if((R6((c[2388126]|0)+1|0,0,2)|0)!=0){n=1;i=a;return n|0}if((R6(c[2388126]|0,1,2)|0)!=0){n=1;i=a;return n|0}o=c[2385902]|0;if((c[3542200]|0)==0){n=1;i=a;return n|0}p=l+108|0;c[p>>2]=0;q=l+100|0;c[q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,2)|0;do{if((c[p>>2]|0)!=0){l=c[q>>2]|0;c[m>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](m,2,0)|0;if((l|0)<1){n=1;i=a;return n|0}if((gzL(o,0,2)|0)==0){break}else{n=1}i=a;return n|0}}while(0);o=c[3530812]|0;if((c[3542200]|0)==0){n=1;i=a;return n|0}m=j+108|0;c[m>>2]=0;q=j+100|0;c[q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,3)|0;do{if((c[m>>2]|0)!=0){j=c[q>>2]|0;c[k>>2]=9534384;p=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[p&16383](k,3,0)|0;if((j|0)<1){n=1;i=a;return n|0}if((gzL(o,0,3)|0)==0){break}else{n=1}i=a;return n|0}}while(0);o=c[3530576]|0;if((c[3542200]|0)==0){n=1;i=a;return n|0}k=g+108|0;c[k>>2]=0;q=g+100|0;c[q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,4)|0;do{if((c[k>>2]|0)!=0){g=c[q>>2]|0;c[h>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](h,4,0)|0;if((g|0)<1){n=1;i=a;return n|0}if((gzL(o,0,4)|0)==0){break}else{n=1}i=a;return n|0}}while(0);o=(c[3530576]|0)+2097152|0;if((c[3542200]|0)==0){n=1;i=a;return n|0}h=e+108|0;c[h>>2]=0;q=e+100|0;c[q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,5)|0;do{if((c[h>>2]|0)!=0){e=c[q>>2]|0;c[f>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](f,5,0)|0;if((e|0)<1){n=1;i=a;return n|0}if((gzL(o,0,5)|0)==0){break}else{n=1}i=a;return n|0}}while(0);gGz(c[3530416]|0,-1|0,128);o=c[3529752]|0;if((c[3542200]|0)==0){n=1;i=a;return n|0}f=b+108|0;c[f>>2]=0;q=b+100|0;c[q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](b,6)|0;do{if((c[f>>2]|0)!=0){b=c[q>>2]|0;c[d>>2]=9534384;h=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[h&16383](d,6,0)|0;if((b|0)<1){n=1;i=a;return n|0}if((gzL(o,0,6)|0)==0){break}else{n=1}i=a;return n|0}}while(0);erZ(65536,4194304,128);n=0;i=a;return n|0}function er4(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;a=i;i=i+720|0;b=a|0;d=a+112|0;e=a+120|0;f=a+232|0;g=a+240|0;h=a+352|0;j=a+360|0;k=a+472|0;l=a+480|0;m=a+592|0;n=a+600|0;o=a+712|0;if((R6((c[2388126]|0)+1|0,0,2)|0)!=0){p=1;i=a;return p|0}if((R6(c[2388126]|0,1,2)|0)!=0){p=1;i=a;return p|0}q=c[2385902]|0;if((c[3542200]|0)==0){p=1;i=a;return p|0}r=n+108|0;c[r>>2]=0;s=n+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,2)|0;do{if((c[r>>2]|0)!=0){n=c[s>>2]|0;c[o>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](o,2,0)|0;if((n|0)<1){p=1;i=a;return p|0}if((gzL(q,0,2)|0)==0){break}else{p=1}i=a;return p|0}}while(0);q=c[3530812]|0;if((c[3542200]|0)==0){p=1;i=a;return p|0}o=l+108|0;c[o>>2]=0;s=l+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,3)|0;do{if((c[o>>2]|0)!=0){l=c[s>>2]|0;c[m>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](m,3,0)|0;if((l|0)<1){p=1;i=a;return p|0}if((gzL(q,0,3)|0)==0){break}else{p=1}i=a;return p|0}}while(0);q=c[3530576]|0;if((c[3542200]|0)==0){p=1;i=a;return p|0}m=j+108|0;c[m>>2]=0;s=j+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,4)|0;do{if((c[m>>2]|0)!=0){j=c[s>>2]|0;c[k>>2]=9534384;o=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[o&16383](k,4,0)|0;if((j|0)<1){p=1;i=a;return p|0}if((gzL(q,0,4)|0)==0){break}else{p=1}i=a;return p|0}}while(0);q=(c[3530576]|0)+2097152|0;if((c[3542200]|0)==0){p=1;i=a;return p|0}k=g+108|0;c[k>>2]=0;s=g+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,5)|0;do{if((c[k>>2]|0)!=0){g=c[s>>2]|0;c[h>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](h,5,0)|0;if((g|0)<1){p=1;i=a;return p|0}if((gzL(q,0,5)|0)==0){break}else{p=1}i=a;return p|0}}while(0);q=c[3530416]|0;if((c[3542200]|0)==0){p=1;i=a;return p|0}h=e+108|0;c[h>>2]=0;s=e+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,6)|0;do{if((c[h>>2]|0)!=0){e=c[s>>2]|0;c[f>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](f,6,0)|0;if((e|0)<1){p=1;i=a;return p|0}if((gzL(q,0,6)|0)==0){break}else{p=1}i=a;return p|0}}while(0);q=c[3529752]|0;if((c[3542200]|0)==0){p=1;i=a;return p|0}f=b+108|0;c[f>>2]=0;s=b+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](b,7)|0;do{if((c[f>>2]|0)!=0){b=c[s>>2]|0;c[d>>2]=9534384;h=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[h&16383](d,7,0)|0;if((b|0)<1){p=1;i=a;return p|0}if((gzL(q,0,7)|0)==0){break}else{p=1}i=a;return p|0}}while(0);erZ(65536,4194304,2097152);p=0;i=a;return p|0}function er5(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;a=i;i=i+840|0;b=a|0;d=a+112|0;e=a+120|0;f=a+232|0;g=a+240|0;h=a+352|0;j=a+360|0;k=a+472|0;l=a+480|0;m=a+592|0;n=a+600|0;o=a+712|0;p=a+720|0;q=a+832|0;if((R6((c[2388126]|0)+1|0,0,2)|0)!=0){r=1;i=a;return r|0}if((R6(c[2388126]|0,1,2)|0)!=0){r=1;i=a;return r|0}s=c[2385902]|0;if((c[3542200]|0)==0){r=1;i=a;return r|0}t=p+108|0;c[t>>2]=0;u=p+100|0;c[u>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,2)|0;do{if((c[t>>2]|0)!=0){p=c[u>>2]|0;c[q>>2]=9534384;v=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[v&16383](q,2,0)|0;if((p|0)<1){r=1;i=a;return r|0}if((gzL(s,0,2)|0)==0){break}else{r=1}i=a;return r|0}}while(0);s=c[3530812]|0;if((c[3542200]|0)==0){r=1;i=a;return r|0}q=n+108|0;c[q>>2]=0;u=n+100|0;c[u>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,3)|0;do{if((c[q>>2]|0)!=0){n=c[u>>2]|0;c[o>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](o,3,0)|0;if((n|0)<1){r=1;i=a;return r|0}if((gzL(s,0,3)|0)==0){break}else{r=1}i=a;return r|0}}while(0);s=c[3530576]|0;if((c[3542200]|0)==0){r=1;i=a;return r|0}o=l+108|0;c[o>>2]=0;u=l+100|0;c[u>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,4)|0;do{if((c[o>>2]|0)!=0){l=c[u>>2]|0;c[m>>2]=9534384;q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[q&16383](m,4,0)|0;if((l|0)<1){r=1;i=a;return r|0}if((gzL(s,0,4)|0)==0){break}else{r=1}i=a;return r|0}}while(0);s=(c[3530576]|0)+524288|0;if((c[3542200]|0)==0){r=1;i=a;return r|0}m=j+108|0;c[m>>2]=0;u=j+100|0;c[u>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,5)|0;do{if((c[m>>2]|0)!=0){j=c[u>>2]|0;c[k>>2]=9534384;o=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[o&16383](k,5,0)|0;if((j|0)<1){r=1;i=a;return r|0}if((gzL(s,0,5)|0)==0){break}else{r=1}i=a;return r|0}}while(0);s=(c[3530576]|0)+1048576|0;if((c[3542200]|0)==0){r=1;i=a;return r|0}k=g+108|0;c[k>>2]=0;u=g+100|0;c[u>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,6)|0;do{if((c[k>>2]|0)!=0){g=c[u>>2]|0;c[h>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](h,6,0)|0;if((g|0)<1){r=1;i=a;return r|0}if((gzL(s,0,6)|0)==0){break}else{r=1}i=a;return r|0}}while(0);s=(c[3530576]|0)+1572864|0;if((c[3542200]|0)==0){r=1;i=a;return r|0}h=e+108|0;c[h>>2]=0;u=e+100|0;c[u>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,7)|0;do{if((c[h>>2]|0)!=0){e=c[u>>2]|0;c[f>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](f,7,0)|0;if((e|0)<1){r=1;i=a;return r|0}if((gzL(s,0,7)|0)==0){break}else{r=1}i=a;return r|0}}while(0);if((R6((c[3530416]|0)+1|0,8,2)|0)!=0){r=1;i=a;return r|0}if((R6(c[3530416]|0,9,2)|0)!=0){r=1;i=a;return r|0}if((R6((c[3530416]|0)+1048577|0,10,2)|0)!=0){r=1;i=a;return r|0}if((R6((c[3530416]|0)+1048576|0,11,2)|0)!=0){r=1;i=a;return r|0}s=c[3529752]|0;if((c[3542200]|0)==0){r=1;i=a;return r|0}f=b+108|0;c[f>>2]=0;u=b+100|0;c[u>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](b,12)|0;do{if((c[f>>2]|0)!=0){b=c[u>>2]|0;c[d>>2]=9534384;h=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[h&16383](d,12,0)|0;if((b|0)<1){r=1;i=a;return r|0}if((gzL(s,0,12)|0)==0){break}else{r=1}i=a;return r|0}}while(0);erZ(65536,4194304,2097152);r=0;i=a;return r|0}function er6(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=i;i=i+600|0;d=b|0;e=b+112|0;f=b+120|0;g=b+232|0;h=b+240|0;j=b+352|0;k=b+360|0;l=b+472|0;m=b+480|0;n=b+592|0;if((R6((c[2388126]|0)+1|0,0,2)|0)!=0){o=1;i=b;return o|0}if((R6(c[2388126]|0,1,2)|0)!=0){o=1;i=b;return o|0}p=c[2385902]|0;if((c[3542200]|0)==0){o=1;i=b;return o|0}q=m+108|0;c[q>>2]=0;r=m+100|0;c[r>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,2)|0;do{if((c[q>>2]|0)!=0){m=c[r>>2]|0;c[n>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](n,2,0)|0;if((m|0)<1){o=1;i=b;return o|0}if((gzL(p,0,2)|0)==0){break}else{o=1}i=b;return o|0}}while(0);gGz(c[3530812]|0,-1|0,32);p=c[3530576]|0;if((c[3542200]|0)==0){o=1;i=b;return o|0}n=k+108|0;c[n>>2]=0;r=k+100|0;c[r>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,3)|0;do{if((c[n>>2]|0)!=0){k=c[r>>2]|0;c[l>>2]=9534384;q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[q&16383](l,3,0)|0;if((k|0)<1){o=1;i=b;return o|0}if((gzL(p,0,3)|0)==0){break}else{o=1}i=b;return o|0}}while(0);p=c[3530416]|0;if((c[3542200]|0)==0){o=1;i=b;return o|0}l=h+108|0;c[l>>2]=0;r=h+100|0;c[r>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](h,4)|0;do{if((c[l>>2]|0)!=0){h=c[r>>2]|0;c[j>>2]=9534384;n=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[n&16383](j,4,0)|0;if((h|0)<1){o=1;i=b;return o|0}if((gzL(p,0,4)|0)==0){break}else{o=1}i=b;return o|0}}while(0);p=(c[3530416]|0)+524288|0;if((c[3542200]|0)==0){o=1;i=b;return o|0}j=f+108|0;c[j>>2]=0;r=f+100|0;c[r>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,5)|0;do{if((c[j>>2]|0)!=0){f=c[r>>2]|0;c[g>>2]=9534384;l=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[l&16383](g,5,0)|0;if((f|0)<1){o=1;i=b;return o|0}if((gzL(p,0,5)|0)==0){break}else{o=1}i=b;return o|0}}while(0);p=c[3529752]|0;if((c[3542200]|0)==0){o=1;i=b;return o|0}g=d+108|0;c[g>>2]=0;r=d+100|0;c[r>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](d,6)|0;do{if((c[g>>2]|0)!=0){d=c[r>>2]|0;c[e>>2]=9534384;j=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[j&16383](e,6,0)|0;if((d|0)<1){o=1;i=b;return o|0}if((gzL(p,0,6)|0)==0){break}else{o=1}i=b;return o|0}}while(0);erq(32,524288,1048576);p=0;e=c[3530576]|0;while(1){r=a[e]|0;g=e+1|0;a[e]=a[g]|0;a[g]=r;r=p+1|0;if((r|0)<524288){p=r;e=e+2|0}else{break}}e=0;p=c[3530416]|0;while(1){r=a[p]|0;g=p+1|0;a[p]=a[g]|0;a[g]=r;r=e+1|0;if((r|0)<1048576){e=r;p=p+2|0}else{o=0;break}}i=b;return o|0}function er7(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;a=i;i=i+360|0;b=a|0;d=a+112|0;e=a+120|0;f=a+232|0;g=a+240|0;h=a+352|0;if((R6((c[2388126]|0)+1|0,0,2)|0)!=0){j=1;i=a;return j|0}if((R6(c[2388126]|0,1,2)|0)!=0){j=1;i=a;return j|0}k=c[2385902]|0;if((c[3542200]|0)==0){j=1;i=a;return j|0}l=g+108|0;c[l>>2]=0;m=g+100|0;c[m>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,2)|0;do{if((c[l>>2]|0)!=0){g=c[m>>2]|0;c[h>>2]=9534384;n=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[n&16383](h,2,0)|0;if((g|0)<1){j=1;i=a;return j|0}if((gzL(k,0,2)|0)==0){break}else{j=1}i=a;return j|0}}while(0);gGz(c[3530812]|0,-1|0,32);k=c[3530576]|0;if((c[3542200]|0)==0){j=1;i=a;return j|0}h=e+108|0;c[h>>2]=0;m=e+100|0;c[m>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,3)|0;do{if((c[h>>2]|0)!=0){e=c[m>>2]|0;c[f>>2]=9534384;l=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[l&16383](f,3,0)|0;if((e|0)<1){j=1;i=a;return j|0}if((gzL(k,0,3)|0)==0){break}else{j=1}i=a;return j|0}}while(0);if((R6(c[3530416]|0,4,2)|0)!=0){j=1;i=a;return j|0}if((R6((c[3530416]|0)+1|0,5,2)|0)!=0){j=1;i=a;return j|0}k=c[3529752]|0;if((c[3542200]|0)==0){j=1;i=a;return j|0}f=b+108|0;c[f>>2]=0;m=b+100|0;c[m>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](b,6)|0;do{if((c[f>>2]|0)!=0){b=c[m>>2]|0;c[d>>2]=9534384;h=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[h&16383](d,6,0)|0;if((b|0)<1){j=1;i=a;return j|0}if((gzL(k,0,6)|0)==0){break}else{j=1}i=a;return j|0}}while(0);erq(32,524288,1048576);j=0;i=a;return j|0}function er8(b,c){b=b|0;c=c|0;a[9706117]=(c|0)!=0|0;return}function er9(a){a=a|0;return(ag((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0,a)|0)/4e6|0|0}function esa(){return+(+((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)/4.0e6)}function esb(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;b=i;i=i+720|0;d=b|0;e=b+112|0;f=b+120|0;g=b+232|0;h=b+240|0;j=b+352|0;k=b+360|0;l=b+472|0;m=b+480|0;n=b+592|0;o=b+600|0;p=b+712|0;if((R6(c[2388126]|0,0,2)|0)!=0){q=1;i=b;return q|0}if((R6((c[2388126]|0)+1|0,1,2)|0)!=0){q=1;i=b;return q|0}r=c[2385902]|0;if((c[3542200]|0)==0){q=1;i=b;return q|0}s=o+108|0;c[s>>2]=0;t=o+100|0;c[t>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](o,2)|0;do{if((c[s>>2]|0)!=0){o=c[t>>2]|0;c[p>>2]=9534384;u=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[u&16383](p,2,0)|0;if((o|0)<1){q=1;i=b;return q|0}if((gzL(r,0,2)|0)==0){break}else{q=1}i=b;return q|0}}while(0);r=c[3530812]|0;if((c[3542200]|0)==0){q=1;i=b;return q|0}p=m+108|0;c[p>>2]=0;t=m+100|0;c[t>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,3)|0;do{if((c[p>>2]|0)!=0){m=c[t>>2]|0;c[n>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](n,3,0)|0;if((m|0)<1){q=1;i=b;return q|0}if((gzL(r,0,3)|0)==0){break}else{q=1}i=b;return q|0}}while(0);r=c[3530576]|0;if((c[3542200]|0)==0){q=1;i=b;return q|0}n=k+108|0;c[n>>2]=0;t=k+100|0;c[t>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,4)|0;do{if((c[n>>2]|0)!=0){k=c[t>>2]|0;c[l>>2]=9534384;p=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[p&16383](l,4,0)|0;if((k|0)<1){q=1;i=b;return q|0}if((gzL(r,0,4)|0)==0){break}else{q=1}i=b;return q|0}}while(0);r=(c[3530576]|0)+524288|0;if((c[3542200]|0)==0){q=1;i=b;return q|0}l=h+108|0;c[l>>2]=0;t=h+100|0;c[t>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](h,5)|0;do{if((c[l>>2]|0)!=0){h=c[t>>2]|0;c[j>>2]=9534384;n=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[n&16383](j,5,0)|0;if((h|0)<1){q=1;i=b;return q|0}if((gzL(r,0,5)|0)==0){break}else{q=1}i=b;return q|0}}while(0);if((R6((c[3530416]|0)+1|0,6,2)|0)!=0){q=1;i=b;return q|0}if((R6(c[3530416]|0,7,2)|0)!=0){q=1;i=b;return q|0}r=c[3529752]|0;if((c[3542200]|0)==0){q=1;i=b;return q|0}j=f+108|0;c[j>>2]=0;t=f+100|0;c[t>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,8)|0;do{if((c[j>>2]|0)!=0){f=c[t>>2]|0;c[g>>2]=9534384;l=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[l&16383](g,8,0)|0;if((f|0)<1){q=1;i=b;return q|0}if((gzL(r,0,8)|0)==0){break}else{q=1}i=b;return q|0}}while(0);r=(c[3529752]|0)+262144|0;if((c[3542200]|0)==0){q=1;i=b;return q|0}g=d+108|0;c[g>>2]=0;t=d+100|0;c[t>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](d,9)|0;do{if((c[g>>2]|0)!=0){d=c[t>>2]|0;c[e>>2]=9534384;j=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[j&16383](e,9,0)|0;if((d|0)<1){q=1;i=b;return q|0}if((gzL(r,0,9)|0)==0){break}else{q=1}i=b;return q|0}}while(0);r=c[3530576]|0;e=c[3530416]|0;t=0;do{g=r+t|0;d=a[g]|0;a[g]=(d&255)>>>3<<4&16|d&-25|(d&255)>>>4<<3&8;d=e+t|0;g=a[d]|0;a[d]=(g&255)>>>3<<4&16|g&-25|(g&255)>>>4<<3&8;t=t+1|0;}while((t|0)<1048576);erq(131072,1048576,1048576);fxU(0,425984);if((c[2394]|0)==0){v=c[2112932]|0}else{c[2394]=0;t=c[3532596]|0;c[2112932]=t;e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060];v=t}t=c[2388126]|0;e=v|0;r=0;while(1){g=t+r|0;c[e>>2]=g;c[e+131072>>2]=g;g=r+1024|0;if(g>>>0>262143){break}else{e=e+4|0;r=g}}r=c[2388254]|0;e=v+2816|0;t=720896;while(1){g=r+(t-720896)|0;c[e>>2]=g;c[e+65536>>2]=g;c[e+131072>>2]=g;g=t+1024|0;if(g>>>0>786431){break}else{e=e+4|0;t=g}}t=c[2443470]|0;c[v+3136>>2]=t;c[v+68672>>2]=t;c[v+134208>>2]=t;t=c[2387164]|0;c[v+3200>>2]=t;c[v+68736>>2]=t;c[v+134272>>2]=t;e=t+1024|0;c[v+3204>>2]=e;c[v+68740>>2]=e;c[v+134276>>2]=e;e=c[2387982]|0;c[v+3264>>2]=e;c[v+68800>>2]=e;c[v+134336>>2]=e;t=e+1024|0;c[v+3268>>2]=t;c[v+68804>>2]=t;c[v+134340>>2]=t;t=e+2048|0;c[v+3272>>2]=t;c[v+68808>>2]=t;c[v+134344>>2]=t;t=e+3072|0;c[v+3276>>2]=t;c[v+68812>>2]=t;c[v+134348>>2]=t;t=e+4096|0;c[v+3280>>2]=t;c[v+68816>>2]=t;c[v+134352>>2]=t;t=e+5120|0;c[v+3284>>2]=t;c[v+68820>>2]=t;c[v+134356>>2]=t;t=e+6144|0;c[v+3288>>2]=t;c[v+68824>>2]=t;c[v+134360>>2]=t;t=e+7168|0;c[v+3292>>2]=t;c[v+68828>>2]=t;c[v+134364>>2]=t;t=e+8192|0;c[v+3296>>2]=t;c[v+68832>>2]=t;c[v+134368>>2]=t;t=e+9216|0;c[v+3300>>2]=t;c[v+68836>>2]=t;c[v+134372>>2]=t;t=e+10240|0;c[v+3304>>2]=t;c[v+68840>>2]=t;c[v+134376>>2]=t;t=e+11264|0;c[v+3308>>2]=t;c[v+68844>>2]=t;c[v+134380>>2]=t;t=e+12288|0;c[v+3312>>2]=t;c[v+68848>>2]=t;c[v+134384>>2]=t;t=e+13312|0;c[v+3316>>2]=t;c[v+68852>>2]=t;c[v+134388>>2]=t;t=e+14336|0;c[v+3320>>2]=t;c[v+68856>>2]=t;c[v+134392>>2]=t;t=e+15360|0;c[v+3324>>2]=t;c[v+68860>>2]=t;c[v+134396>>2]=t;t=c[2405794]|0;c[v+3328>>2]=t;c[v+68864>>2]=t;c[v+134400>>2]=t;e=t+1024|0;c[v+3332>>2]=e;c[v+68868>>2]=e;c[v+134404>>2]=e;c[v+3336>>2]=t;c[v+68872>>2]=t;c[v+134408>>2]=t;c[v+3340>>2]=e;c[v+68876>>2]=e;c[v+134412>>2]=e;c[v+3344>>2]=t;c[v+68880>>2]=t;c[v+134416>>2]=t;c[v+3348>>2]=e;c[v+68884>>2]=e;c[v+134420>>2]=e;c[v+3352>>2]=t;c[v+68888>>2]=t;c[v+134424>>2]=t;c[v+3356>>2]=e;c[v+68892>>2]=e;c[v+134428>>2]=e;c[v+196728>>2]=210;c[v+196648>>2]=1814;c[v+196688>>2]=3388;c[v+196608>>2]=3258;v=c[3532592]|0;if((v|0)!=0){gGC(v|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;q=0;i=b;return q|0}function esc(d){d=d|0;var e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;c[2414932]=0;err();e=c[2414144]|0;f=0;while(1){if((f|0)>=1024){break}g=9638528+(f<<2)|0;if((c[g>>2]|0)==0){i=1456;break}else{f=f+1|0}}do{if((i|0)==1456){f=gGq(e)|0;c[g>>2]=f;if((f|0)==0){break}gGz(f|0,0,e|0);c[2414932]=f;gGz(f|0,0,e|0);err();do{if((d|0)!=0){if((gD[d&8191]()|0)==0){break}else{j=1}return j|0}}while(0);fwR(0);f=c[2439330]|0;k=(f|0)==0;if(!k){l=f;gGC(9706056,l|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];l=c[3528484]|0;c[2076596]=l;m=c[2417276]|0;c[3541536]=m;c[1836236]=0;n=c[2385902]|0;o=0;p=0;while(1){c[f+76+(p<<2)>>2]=n+(p<<8);q=o+1&65535;if((q&65535)>191){r=0;s=0;break}else{o=q;p=q&65535}}while(1){p=n+(s<<8)|0;c[f+76+(s+512<<2)>>2]=p;c[f+76+(s+768<<2)>>2]=p;p=r+1&65535;if((p&65535)>191){break}else{r=p;s=p&65535}}n=c[2386056]|0;c[f+844>>2]=n;p=n+256|0;c[f+848>>2]=p;o=n+512|0;c[f+852>>2]=o;q=n+768|0;c[f+856>>2]=q;t=n+1024|0;c[f+860>>2]=t;u=n+1280|0;c[f+864>>2]=u;v=n+1536|0;c[f+868>>2]=v;w=n+1792|0;c[f+872>>2]=w;c[f+1868>>2]=n;c[f+1872>>2]=p;c[f+1876>>2]=o;c[f+1880>>2]=q;c[f+1884>>2]=t;c[f+1888>>2]=u;c[f+1892>>2]=v;c[f+1896>>2]=w;c[f+2892>>2]=n;c[f+3916>>2]=n;c[f+2896>>2]=p;c[f+3920>>2]=p;c[f+2900>>2]=o;c[f+3924>>2]=o;c[f+2904>>2]=q;c[f+3928>>2]=q;c[f+2908>>2]=t;c[f+3932>>2]=t;c[f+2912>>2]=u;c[f+3936>>2]=u;c[f+2916>>2]=v;c[f+3940>>2]=v;c[f+2920>>2]=w;c[f+3944>>2]=w;c[f+4184>>2]=2820;c[f+4180>>2]=1096;c[f+4176>>2]=460;c[f+4172>>2]=2398;if(!k){w=f;gGC(w|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=l;c[2417276]=m;c[1836236]=-1;c[2424]=5600;Vr(1,15e5,128,1324,68,0);c[2438228]=3e6;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=681;h[745419]=2.0;a[3203368]=1;h[745418]=.5;a[3203360]=1;h[745417]=.5;a[3203352]=1;h[745416]=.5;a[3203344]=1;Ux(0,24242,1);Ux(1,24242,1);c[2407030]=51;c[2407068]=3;c[2407069]=51;c[2407107]=3;w=c[642608+(c[2436]<<2)>>2]|0;v=c[w+128>>2]|0;if((c[w+52>>2]&4|0)==0){c[2113068]=v;u=c[w+132>>2]|0;c[2113070]=u;c[2443814]=v;c[2440436]=u;x=v;y=u}else{c[2113070]=v;u=c[w+132>>2]|0;c[2113068]=u;c[2440436]=v;c[2443814]=u;x=u;y=v}v=ag(x<<1,y)|0;u=gGq(v)|0;c[2112926]=u;if((u|0)!=0){gGz(u|0,0,v|0)}v=c[2414634]|0;gGz(v|0,0,(c[2411604]|0)-v|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];v=c[3532592]|0;if((v|0)!=0){gGC(9104152,v|0,280)|0}c[2113054]=c[2113060]}RI();v=c[2394]|0;u=c[14130368+(v<<2)>>2]|0;if((u|0)!=0){gGC(u|0,9104152,280)|0}c[8452240+(v<<2)>>2]=c[2113054];c[2394]=-1;v=c[2439330]|0;u=(v|0)==0;if(!u){w=v;gGC(9706056,w|0,76)|0}w=c[2438118]|0;c[2433530]=w;t=c[3528484]|0;c[2076596]=t;q=c[2417276]|0;c[3541536]=q;c[1836236]=0;gGz(9706056,0,76);if(!u){u=v;gGC(u|0,9706056,76)|0}c[2438118]=w;c[3528484]=t;c[2417276]=q;c[1836236]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){q=0;do{lN(q);mB(q);q=q+1|0;}while((q|0)<(c[2385508]|0))}c[2113156]=0;a[9628264]=0;c[2407033]=0;q=c[3541206]|0;gGz(c[2430118]|0,0,16384);c[2407041]=4;gGz(c[2430119]|0,0,16384);c[2407049]=4;gGz(c[2430120]|0,0,16384);c[2407057]=4;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2113157]=0;a[9628420]=0;c[2407072]=0;gGz(c[2430122]|0,0,16384);c[2407080]=4;gGz(c[2430123]|0,0,16384);c[2407088]=4;gGz(c[2430124]|0,0,16384);c[2407096]=4;gGz(c[2430125]|0,0,16384);c[2407104]=4;m=(c[3529708]|0)-(c[3529752]|0)|0;c[3541190]=q;c[3541198]=q;c[3541191]=q+256;c[3541199]=q+65536;c[3541192]=q+512;c[3541200]=q+131072;c[3541193]=q+768;c[3541201]=q+196608;l=q+m|0;c[3541194]=l;c[3541202]=l;c[3541195]=q+(m+256);c[3541203]=q+(m+65536);c[3541196]=q+(m+512);c[3541204]=q+(m+131072);c[3541197]=q+(m+768);c[3541205]=q+(m+196608);c[2429282]=-1;c[3528410]=0;j=0;return j|0}}while(0);c[2414932]=0;j=1;return j|0}function esd(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;a=i;i=i+720|0;b=a|0;d=a+112|0;e=a+120|0;f=a+232|0;g=a+240|0;h=a+352|0;j=a+360|0;k=a+472|0;l=a+480|0;m=a+592|0;n=a+600|0;o=a+712|0;if((R6(c[2388126]|0,0,2)|0)!=0){p=1;i=a;return p|0}if((R6((c[2388126]|0)+1|0,1,2)|0)!=0){p=1;i=a;return p|0}q=c[2385902]|0;if((c[3542200]|0)==0){p=1;i=a;return p|0}r=n+108|0;c[r>>2]=0;s=n+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,2)|0;do{if((c[r>>2]|0)!=0){n=c[s>>2]|0;c[o>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](o,2,0)|0;if((n|0)<1){p=1;i=a;return p|0}if((gzL(q,0,2)|0)==0){break}else{p=1}i=a;return p|0}}while(0);q=c[3530812]|0;if((c[3542200]|0)==0){p=1;i=a;return p|0}o=l+108|0;c[o>>2]=0;s=l+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,3)|0;do{if((c[o>>2]|0)!=0){l=c[s>>2]|0;c[m>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](m,3,0)|0;if((l|0)<1){p=1;i=a;return p|0}if((gzL(q,0,3)|0)==0){break}else{p=1}i=a;return p|0}}while(0);q=c[3530576]|0;if((c[3542200]|0)==0){p=1;i=a;return p|0}m=j+108|0;c[m>>2]=0;s=j+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,4)|0;do{if((c[m>>2]|0)!=0){j=c[s>>2]|0;c[k>>2]=9534384;o=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[o&16383](k,4,0)|0;if((j|0)<1){p=1;i=a;return p|0}if((gzL(q,0,4)|0)==0){break}else{p=1}i=a;return p|0}}while(0);q=(c[3530576]|0)+262144|0;if((c[3542200]|0)==0){p=1;i=a;return p|0}k=g+108|0;c[k>>2]=0;s=g+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,5)|0;do{if((c[k>>2]|0)!=0){g=c[s>>2]|0;c[h>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](h,5,0)|0;if((g|0)<1){p=1;i=a;return p|0}if((gzL(q,0,5)|0)==0){break}else{p=1}i=a;return p|0}}while(0);if((R6(c[3530416]|0,6,2)|0)!=0){p=1;i=a;return p|0}if((R6((c[3530416]|0)+1|0,7,2)|0)!=0){p=1;i=a;return p|0}if((R6((c[3530416]|0)+262144|0,8,2)|0)!=0){p=1;i=a;return p|0}if((R6((c[3530416]|0)+262145|0,9,2)|0)!=0){p=1;i=a;return p|0}q=c[3529752]|0;if((c[3542200]|0)==0){p=1;i=a;return p|0}h=e+108|0;c[h>>2]=0;s=e+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,10)|0;do{if((c[h>>2]|0)!=0){e=c[s>>2]|0;c[f>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](f,10,0)|0;if((e|0)<1){p=1;i=a;return p|0}if((gzL(q,0,10)|0)==0){break}else{p=1}i=a;return p|0}}while(0);q=(c[3529752]|0)+393216|0;if((c[3542200]|0)==0){p=1;i=a;return p|0}f=b+108|0;c[f>>2]=0;s=b+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](b,11)|0;do{if((c[f>>2]|0)!=0){b=c[s>>2]|0;c[d>>2]=9534384;h=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[h&16383](d,11,0)|0;if((b|0)<1){p=1;i=a;return p|0}if((gzL(q,0,11)|0)==0){break}else{p=1}i=a;return p|0}}while(0);q=c[3529752]|0;d=q+262144|0;s=q+131072|0;gGC(d|0,s|0,131072)|0;erq(65536,524288,524288);fxU(0,425984);if((c[2394]|0)==0){u=c[2112932]|0}else{c[2394]=0;s=c[3532596]|0;c[2112932]=s;d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];u=s}s=c[2388126]|0;d=u|0;q=0;while(1){f=s+q|0;c[d>>2]=f;c[d+131072>>2]=f;f=q+1024|0;if(f>>>0>262143){break}else{d=d+4|0;q=f}}q=c[2387164]|0;c[u+2176>>2]=q;c[u+67712>>2]=q;c[u+133248>>2]=q;q=c[2387982]|0;c[u+2304>>2]=q;c[u+67840>>2]=q;c[u+133376>>2]=q;d=q+1024|0;c[u+2308>>2]=d;c[u+67844>>2]=d;c[u+133380>>2]=d;d=q+2048|0;c[u+2312>>2]=d;c[u+67848>>2]=d;c[u+133384>>2]=d;d=q+3072|0;c[u+2316>>2]=d;c[u+67852>>2]=d;c[u+133388>>2]=d;d=q+4096|0;c[u+2320>>2]=d;c[u+67856>>2]=d;c[u+133392>>2]=d;d=q+5120|0;c[u+2324>>2]=d;c[u+67860>>2]=d;c[u+133396>>2]=d;d=q+6144|0;c[u+2328>>2]=d;c[u+67864>>2]=d;c[u+133400>>2]=d;d=q+7168|0;c[u+2332>>2]=d;c[u+67868>>2]=d;c[u+133404>>2]=d;d=q+8192|0;c[u+2336>>2]=d;c[u+67872>>2]=d;c[u+133408>>2]=d;d=q+9216|0;c[u+2340>>2]=d;c[u+67876>>2]=d;c[u+133412>>2]=d;d=q+10240|0;c[u+2344>>2]=d;c[u+67880>>2]=d;c[u+133416>>2]=d;d=q+11264|0;c[u+2348>>2]=d;c[u+67884>>2]=d;c[u+133420>>2]=d;d=q+12288|0;c[u+2352>>2]=d;c[u+67888>>2]=d;c[u+133424>>2]=d;d=q+13312|0;c[u+2356>>2]=d;c[u+67892>>2]=d;c[u+133428>>2]=d;d=q+14336|0;c[u+2360>>2]=d;c[u+67896>>2]=d;c[u+133432>>2]=d;d=q+15360|0;c[u+2364>>2]=d;c[u+67900>>2]=d;c[u+133436>>2]=d;d=c[2443470]|0;c[u+2496>>2]=d;c[u+68032>>2]=d;c[u+133568>>2]=d;q=d+1024|0;c[u+2500>>2]=q;c[u+68036>>2]=q;c[u+133572>>2]=q;q=d+2048|0;c[u+2504>>2]=q;c[u+68040>>2]=q;c[u+133576>>2]=q;q=d+3072|0;c[u+2508>>2]=q;c[u+68044>>2]=q;c[u+133580>>2]=q;q=c[2405794]|0;c[u+2512>>2]=q;c[u+68048>>2]=q;c[u+133584>>2]=q;d=q+1024|0;c[u+2516>>2]=d;c[u+68052>>2]=d;c[u+133588>>2]=d;d=c[2388254]|0;q=u+3840|0;s=983040;while(1){f=d+(s-983040)|0;c[q>>2]=f;c[q+65536>>2]=f;c[q+131072>>2]=f;f=s+1024|0;if(f>>>0>1048575){break}else{q=q+4|0;s=f}}c[u+196728>>2]=576;c[u+196648>>2]=838;c[u+196688>>2]=126;c[u+196608>>2]=3126;u=c[3532592]|0;if((u|0)!=0){gGC(u|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;p=0;i=a;return p|0}function ese(a){a=a|0;return(ag((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0,a)|0)/3e6|0|0}function esf(){return+(+((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)/3.0e6)}function esg(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;a=i;i=i+600|0;b=a|0;d=a+112|0;e=a+120|0;f=a+232|0;g=a+240|0;h=a+352|0;j=a+360|0;k=a+472|0;l=a+480|0;m=a+592|0;if((R6((c[2388126]|0)+1|0,0,2)|0)!=0){n=1;i=a;return n|0}if((R6(c[2388126]|0,1,2)|0)!=0){n=1;i=a;return n|0}o=c[2385902]|0;if((c[3542200]|0)==0){n=1;i=a;return n|0}p=l+108|0;c[p>>2]=0;q=l+100|0;c[q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,2)|0;do{if((c[p>>2]|0)!=0){l=c[q>>2]|0;c[m>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](m,2,0)|0;if((l|0)<1){n=1;i=a;return n|0}if((gzL(o,0,2)|0)==0){break}else{n=1}i=a;return n|0}}while(0);o=c[3530812]|0;if((c[3542200]|0)==0){n=1;i=a;return n|0}m=j+108|0;c[m>>2]=0;q=j+100|0;c[q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,3)|0;do{if((c[m>>2]|0)!=0){j=c[q>>2]|0;c[k>>2]=9534384;p=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[p&16383](k,3,0)|0;if((j|0)<1){n=1;i=a;return n|0}if((gzL(o,0,3)|0)==0){break}else{n=1}i=a;return n|0}}while(0);o=c[3530576]|0;if((c[3542200]|0)==0){n=1;i=a;return n|0}k=g+108|0;c[k>>2]=0;q=g+100|0;c[q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,4)|0;do{if((c[k>>2]|0)!=0){g=c[q>>2]|0;c[h>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](h,4,0)|0;if((g|0)<1){n=1;i=a;return n|0}if((gzL(o,0,4)|0)==0){break}else{n=1}i=a;return n|0}}while(0);if((R6(c[3530416]|0,5,2)|0)!=0){n=1;i=a;return n|0}if((R6((c[3530416]|0)+1|0,6,2)|0)!=0){n=1;i=a;return n|0}o=c[3529752]|0;if((c[3542200]|0)==0){n=1;i=a;return n|0}h=e+108|0;c[h>>2]=0;q=e+100|0;c[q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,7)|0;do{if((c[h>>2]|0)!=0){e=c[q>>2]|0;c[f>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](f,7,0)|0;if((e|0)<1){n=1;i=a;return n|0}if((gzL(o,0,7)|0)==0){break}else{n=1}i=a;return n|0}}while(0);o=c[3529752]|0;gGG(o+262144|0,o+131072|0,393216);o=c[3529708]|0;if((c[3542200]|0)==0){n=1;i=a;return n|0}f=b+108|0;c[f>>2]=0;q=b+100|0;c[q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](b,8)|0;do{if((c[f>>2]|0)!=0){b=c[q>>2]|0;c[d>>2]=9534384;h=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[h&16383](d,8,0)|0;if((b|0)<1){n=1;i=a;return n|0}if((gzL(o,0,8)|0)==0){break}else{n=1}i=a;return n|0}}while(0);o=c[3529708]|0;gGG(o+262144|0,o+131072|0,393216);erq(65536,524288,1048576);fxU(0,425984);if((c[2394]|0)==0){s=c[2112932]|0}else{c[2394]=0;o=c[3532596]|0;c[2112932]=o;d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];s=o}o=c[2388126]|0;d=s|0;q=0;while(1){f=o+q|0;c[d>>2]=f;c[d+131072>>2]=f;f=q+1024|0;if(f>>>0>262143){break}else{d=d+4|0;q=f}}q=c[2387164]|0;c[s+2176>>2]=q;c[s+67712>>2]=q;c[s+133248>>2]=q;q=c[2387982]|0;c[s+2304>>2]=q;c[s+67840>>2]=q;c[s+133376>>2]=q;d=q+1024|0;c[s+2308>>2]=d;c[s+67844>>2]=d;c[s+133380>>2]=d;d=q+2048|0;c[s+2312>>2]=d;c[s+67848>>2]=d;c[s+133384>>2]=d;d=q+3072|0;c[s+2316>>2]=d;c[s+67852>>2]=d;c[s+133388>>2]=d;d=q+4096|0;c[s+2320>>2]=d;c[s+67856>>2]=d;c[s+133392>>2]=d;d=q+5120|0;c[s+2324>>2]=d;c[s+67860>>2]=d;c[s+133396>>2]=d;d=q+6144|0;c[s+2328>>2]=d;c[s+67864>>2]=d;c[s+133400>>2]=d;d=q+7168|0;c[s+2332>>2]=d;c[s+67868>>2]=d;c[s+133404>>2]=d;d=q+8192|0;c[s+2336>>2]=d;c[s+67872>>2]=d;c[s+133408>>2]=d;d=q+9216|0;c[s+2340>>2]=d;c[s+67876>>2]=d;c[s+133412>>2]=d;d=q+10240|0;c[s+2344>>2]=d;c[s+67880>>2]=d;c[s+133416>>2]=d;d=q+11264|0;c[s+2348>>2]=d;c[s+67884>>2]=d;c[s+133420>>2]=d;d=q+12288|0;c[s+2352>>2]=d;c[s+67888>>2]=d;c[s+133424>>2]=d;d=q+13312|0;c[s+2356>>2]=d;c[s+67892>>2]=d;c[s+133428>>2]=d;d=q+14336|0;c[s+2360>>2]=d;c[s+67896>>2]=d;c[s+133432>>2]=d;d=q+15360|0;c[s+2364>>2]=d;c[s+67900>>2]=d;c[s+133436>>2]=d;d=c[2443470]|0;c[s+2496>>2]=d;c[s+68032>>2]=d;c[s+133568>>2]=d;q=d+1024|0;c[s+2500>>2]=q;c[s+68036>>2]=q;c[s+133572>>2]=q;q=c[2405794]|0;c[s+2512>>2]=q;c[s+68048>>2]=q;c[s+133584>>2]=q;d=q+1024|0;c[s+2516>>2]=d;c[s+68052>>2]=d;c[s+133588>>2]=d;d=c[2388254]|0;q=s+3840|0;o=983040;while(1){f=d+(o-983040)|0;c[q>>2]=f;c[q+131072>>2]=f;f=o+1024|0;if(f>>>0>1048575){break}else{q=q+4|0;o=f}}c[s+196728>>2]=1382;c[s+196648>>2]=824;c[s+196688>>2]=1736;c[s+196608>>2]=2402;s=c[3532592]|0;if((s|0)!=0){gGC(s|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;n=0;i=a;return n|0}function esh(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;if((d&16760832|0)==9437184){f=c[2387162]|0;a[f+(d&16383)|0]=e;g=d&16382;h=b[f+g>>1]|0;f=h&255;i=(h&65535)>>>8;j=(h&65535)>>>4;h=(i&15|i<<4&255)&255;i=(j&15|j<<4&255)&255;j=(f&15|f<<4)&255;f=g>>>1;c[(c[2406924]|0)+(f<<2)>>2]=i<<8|j|h<<16;c[(c[3529968]|0)+(f<<2)>>2]=i<<3&2016|j>>>3|h<<8&63488;return}if((d-8388864|0)>>>0<32){a[(c[3529384]|0)+(d&31)|0]=e;return}switch(d|0){case 8389001:case 8389e3:{a[9731856]=1;return};case 8388993:{a[9718600]=e;c[2226884]=(c[2226884]|0)-(c[2276108]|0);c[2276108]=0;return};case 8388656:case 8388657:{a[c[2442890]|0]=(e&255)>>>2&3^3;return};default:{return}}}function esi(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;if((d&16760832|0)==9437184){f=d&16382;b[(c[2387162]|0)+f>>1]=e;g=e&255;h=(e&65535)>>>8;i=(e&65535)>>>4;j=(h&15|h<<4&255)&255;h=(i&15|i<<4&255)&255;i=(g&15|g<<4)&255;g=f>>>1;c[(c[2406924]|0)+(g<<2)>>2]=h<<8|i|j<<16;c[(c[3529968]|0)+(g<<2)>>2]=h<<3&2016|i>>>3|j<<8&63488;return}if((d-8388864|0)>>>0<32){b[(c[3529384]|0)+(d&30)>>1]=e;return}switch(d|0){case 8389e3:case 8389001:{a[9731856]=1;return};case 8388992:case 8388993:{a[9718600]=e&255;c[2443968]=(gd4((((c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0)/3|0)-(c[2443968]|0)|0)|0)+(c[2443968]|0);return};case 8388948:{b[c[2432792]>>1]=e;return};default:{return}}}function esj(b){b=b|0;var c=0;switch(b|0){case 8388636:{c=a[9634953]|0;break};case 8388632:case 8388633:{c=(e[4817277]|0)>>>((b<<3&8^8)>>>0)&255;break};case 8388634:{c=a[9634952]|0;break};case 8388982:case 8388983:{c=(e[4817278]|0)>>>((b<<3&8^8)>>>0)&255;break};case 8388608:case 8388609:{c=(e[4817276]|0)>>>((b<<3&8^8)>>>0)&255;break};case 8388635:case 8388637:{c=-1;break};default:{c=0}}return c|0}function esk(a){a=a|0;var c=0;switch(a|0){case 8388608:{c=b[4817276]|0;break};case 8388636:{c=(d[9634953]|0)<<8|255;break};case 8388634:{c=(d[9634952]|0)<<8|255;break};case 8388982:{c=b[4817278]|0;break};case 8388632:{c=b[4817277]|0;break};default:{c=0}}return c|0}function esl(b){b=b|0;var d=0,e=0;d=b&65535;do{if((d|0)==2){if((a[9731856]|0)==0){e=0;break}a[9731856]=0;e=64}else if((d|0)==1){b=a[9718608]&31;if((b|0)==22){e=c[2113156]&15;break}else if((b|0)==18){e=c[2113157]&15;break}else if((b|0)==11|(b|0)==15){e=a[9718600]|0;break}else{e=0;break}}else if((d|0)==0){e=a[9752344]|0}else{e=0}}while(0);return e|0}function esm(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=b&255;if((f|0)==0){a[9752344]=e;return}else if((f|0)==2){b=e&255;a[9718608]=e;g=d[9752344]|0;h=g>>>2&3|b>>>5&4;if((h|0)!=(d[9721984]|0|0)){i=h&255;a[9721984]=i;j=c[3541206]|0;k=(c[3529750]|0)+(((i<<24>>24!=0)<<31>>31)+h<<18&786432)|0;gGC(j|0,k|0,262144)|0}k=g&3|b>>>3&4;if((k|0)!=(d[9721976]|0|0)){a[9721976]=k&255;g=(c[3541206]|0)+1048576|0;j=(c[3529706]|0)+(k<<18)|0;gGC(g|0,j|0,262144)|0}j=b&31;if((j|0)==21){Uv(0,a[9718616]|0);return}else if((j|0)==17){Uv(1,a[9718616]|0);return}else{return}}else if((f|0)==1){a[9718616]=e;return}else{return}}function esn(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4731660+(b*112|0)>>2];c[a+104>>2]=c[4731664+(b*112|0)>>2];c[a+108>>2]=c[4731668+(b*112|0)>>2];d=0;return d|0}function eso(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=4731560+(b*112|0);e=0;return e|0}function esp(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>28){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6924848+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function esq(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>48){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7434360+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function esr(){var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;e=i;i=i+240|0;f=e|0;g=e+112|0;h=e+120|0;j=e+232|0;c[2414930]=0;c[2388124]=0;c[2387052]=1048576;c[3541206]=1049600;c[3529750]=2360320;c[3529706]=3408896;c[3530810]=5506048;c[3530574]=22283264;c[3530414]=26477568;c[3530324]=30671872;c[3529968]=34866176;c[2414632]=34898944;c[2388252]=34898944;c[2387162]=34964480;c[2386430]=34980864;c[2406562]=34982912;c[2387308]=34999296;c[2406484]=35015680;c[2443486]=35032064;c[3529384]=35048448;c[2432792]=35048480;c[2442890]=35048482;c[2406924]=35048483;c[2411602]=35081251;k=0;while(1){if((k|0)>=1024){break}l=9638528+(k<<2)|0;if((c[l>>2]|0)==0){m=1716;break}else{k=k+1|0}}do{if((m|0)==1716){k=gGq(35081251)|0;c[l>>2]=k;if((k|0)==0){break}c[2414930]=k;gGz(k|0,0,35081251);c[2388124]=k;c[2387052]=k+1048576;c[3541206]=k+1049600;c[3529750]=k+2360320;c[3529706]=k+3408896;c[3530810]=k+5506048;c[3530574]=k+22283264;c[3530414]=k+26477568;c[3530324]=k+30671872;c[3529968]=k+34866176;n=k+34898944|0;c[2414632]=n;c[2388252]=n;c[2387162]=k+34964480;c[2386430]=k+34980864;c[2406562]=k+34982912;c[2387308]=k+34999296;c[2406484]=k+35015680;c[2443486]=k+35032064;c[3529384]=k+35048448;c[2432792]=k+35048480;c[2442890]=k+35048482;c[2406924]=k+35048483;n=k+35081251|0;c[2411602]=n;c[2414142]=n;n=0;while(1){if((n|0)>=1024){o=1;m=1818;break}p=9638528+(n<<2)|0;if((c[p>>2]|0)==0){break}else{n=n+1|0}}if((m|0)==1818){i=e;return o|0}n=gGq(4194304)|0;c[p>>2]=n;if((n|0)==0){o=1;i=e;return o|0}gGz(n|0,0,4194304);if((R6((c[2388124]|0)+1|0,0,2)|0)!=0){o=1;i=e;return o|0}if((R6(c[2388124]|0,1,2)|0)!=0){o=1;i=e;return o|0}if((R6(n,2,2)|0)!=0){o=1;i=e;return o|0}k=n+1|0;if((R6(k,3,2)|0)!=0){o=1;i=e;return o|0}q=c[3530810]|0;gGC(q|0,n|0,1048576)|0;r=q+4194304|0;s=n+1048576|0;gGC(r|0,s|0,1048576)|0;s=q+1048576|0;r=n+2097152|0;gGC(s|0,r|0,1048576)|0;r=q+5242880|0;q=n+3145728|0;gGC(r|0,q|0,1048576)|0;if((R6(n,4,2)|0)!=0){o=1;i=e;return o|0}if((R6(k,5,2)|0)!=0){o=1;i=e;return o|0}k=c[3530810]|0;q=k+2097152|0;gGC(q|0,n|0,524288)|0;q=k+6291456|0;k=n+524288|0;gGC(q|0,k|0,524288)|0;if((R6((c[3530574]|0)+1|0,6,2)|0)!=0){o=1;i=e;return o|0}if((R6(c[3530574]|0,7,2)|0)!=0){o=1;i=e;return o|0}k=c[3529750]|0;if((c[3542200]|0)==0){o=1;i=e;return o|0}q=h+108|0;c[q>>2]=0;r=h+100|0;c[r>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](h,9)|0;do{if((c[q>>2]|0)!=0){s=c[r>>2]|0;c[j>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](j,9,0)|0;if((s|0)<1){o=1;i=e;return o|0}if((gzL(k,0,9)|0)==0){break}else{o=1}i=e;return o|0}}while(0);k=c[3529706]|0;if((c[3542200]|0)==0){o=1;i=e;return o|0}r=f+108|0;c[r>>2]=0;q=f+100|0;c[q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,10)|0;do{if((c[r>>2]|0)==0){u=0}else{s=c[q>>2]|0;c[g>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](g,10,0)|0;if((s|0)<1){o=1;i=e;return o|0}if((gzL(k,0,10)|0)==0){u=0;break}else{o=1}i=e;return o|0}}while(0);while(1){if((u|0)>=1024){break}v=9638528+(u<<2)|0;if((c[v>>2]|0)==(n|0)){m=1740;break}else{u=u+1|0}}if((m|0)==1740){gGr(n);c[v>>2]=0}if((fvF(c[2387052]|0,8,2939)|0)==0){w=0}else{o=1;i=e;return o|0}while(1){if((w|0)>=1024){break}x=9638528+(w<<2)|0;if((c[x>>2]|0)==0){m=1744;break}else{w=w+1|0}}L2429:do{if((m|0)==1744){n=gGq(8388608)|0;c[x>>2]=n;if((n|0)==0){break}gGz(n|0,0,8388608);k=c[3530810]|0;gGC(n|0,k|0,8388608)|0;q=0;do{r=q<<8;gGz(k+r|0,0,256);s=q<<9;t=0;do{y=1<<3-t;z=(c[613152+(t<<2)>>2]|0)+s|0;A=0;do{B=z+(c[611840+(A<<2)>>2]|0)|0;C=(A<<4)+r|0;D=0;do{E=B+(c[609648+(D<<2)>>2]|0)|0;if(((d[n+((E|0)/8|0)|0]|0)&128>>>((E&7)>>>0)|0)!=0){E=k+(C+D)|0;a[E]=(d[E]|0|y)&255}D=D+1|0;}while((D|0)<16);A=A+1|0;}while((A|0)<16);t=t+1|0;}while((t|0)<4);q=q+1|0;}while((q|0)<65536);q=c[3530574]|0;gGC(n|0,q|0,2097152)|0;k=0;do{t=k<<6;gGz(q+t|0,0,64);r=k<<8;s=0;do{A=1<<3-s;y=(c[613152+(s<<2)>>2]|0)+r|0;z=0;do{D=y+(c[611840+(z<<2)>>2]|0)|0;C=(z<<3)+t|0;B=0;do{E=D+(c[610608+(B+8<<2)>>2]|0)|0;if(((d[n+((E|0)/8|0)|0]|0)&128>>>((E&7)>>>0)|0)!=0){E=q+(C+B)|0;a[E]=(d[E]|0|A)&255}B=B+1|0;}while((B|0)<8);z=z+1|0;}while((z|0)<8);s=s+1|0;}while((s|0)<4);k=k+1|0;}while((k|0)<65536);k=c[3530414]|0;q=0;do{s=q<<8;gGz(k+s|0,0,256);t=q<<9;r=0;do{z=1<<3-r;A=(c[613152+(r<<2)>>2]|0)+t|0;y=0;do{B=A+(c[611840+(y<<2)>>2]|0)|0;C=(y<<4)+s|0;D=0;do{E=B+(c[610608+(D<<2)>>2]|0)|0;if(((d[n+((E|0)/8|0)|0]|0)&128>>>((E&7)>>>0)|0)!=0){E=k+(C+D)|0;a[E]=(d[E]|0|z)&255}D=D+1|0;}while((D|0)<16);y=y+1|0;}while((y|0)<16);r=r+1|0;}while((r|0)<4);q=q+1|0;}while((q|0)<16384);q=c[3530324]|0;k=0;while(1){r=k<<10;gGz(q+r|0,0,1024);s=k<<11;t=0;do{y=1<<3-t;z=(c[613152+(t<<2)>>2]|0)+s|0;A=0;do{D=z+(c[608624+(A<<2)>>2]|0)|0;C=(A<<5)+r|0;B=0;do{E=D+(c[610608+(B<<2)>>2]|0)|0;if(((d[n+((E|0)/8|0)|0]|0)&128>>>((E&7)>>>0)|0)!=0){E=q+(C+B)|0;a[E]=(d[E]|0|y)&255}B=B+1|0;}while((B|0)<32);A=A+1|0;}while((A|0)<32);t=t+1|0;}while((t|0)<4);t=k+1|0;if((t|0)<4096){k=t}else{F=0;break}}while(1){if((F|0)>=1024){break L2429}G=9638528+(F<<2)|0;if((c[G>>2]|0)==(n|0)){break}else{F=F+1|0}}gGr(n);c[G>>2]=0}}while(0);fxU(0,425984);if((c[2394]|0)==0){H=c[2112932]|0}else{c[2394]=0;k=c[3532596]|0;c[2112932]=k;q=c[3532592]|0;if((q|0)!=0){gGC(9104152,q|0,280)|0}c[2113054]=c[2113060];H=k}k=c[2388124]|0;q=H|0;t=0;while(1){r=k+t|0;c[q>>2]=r;c[q+131072>>2]=r;r=t+1024|0;if(r>>>0>1048575){break}else{q=q+4|0;t=r}}t=c[2387162]|0;c[H+36864>>2]=t;c[H+167936>>2]=t;q=t+1024|0;c[H+36868>>2]=q;c[H+167940>>2]=q;q=t+2048|0;c[H+36872>>2]=q;c[H+167944>>2]=q;q=t+3072|0;c[H+36876>>2]=q;c[H+167948>>2]=q;q=t+4096|0;c[H+36880>>2]=q;c[H+167952>>2]=q;q=t+5120|0;c[H+36884>>2]=q;c[H+167956>>2]=q;q=t+6144|0;c[H+36888>>2]=q;c[H+167960>>2]=q;q=t+7168|0;c[H+36892>>2]=q;c[H+167964>>2]=q;q=t+8192|0;c[H+36896>>2]=q;c[H+167968>>2]=q;q=t+9216|0;c[H+36900>>2]=q;c[H+167972>>2]=q;q=t+10240|0;c[H+36904>>2]=q;c[H+167976>>2]=q;q=t+11264|0;c[H+36908>>2]=q;c[H+167980>>2]=q;q=t+12288|0;c[H+36912>>2]=q;c[H+167984>>2]=q;q=t+13312|0;c[H+36916>>2]=q;c[H+167988>>2]=q;q=t+14336|0;c[H+36920>>2]=q;c[H+167992>>2]=q;q=t+15360|0;c[H+36924>>2]=q;c[H+167996>>2]=q;q=c[2387308]|0;c[H+36928>>2]=q;c[H+102464>>2]=q;c[H+168e3>>2]=q;t=q+1024|0;c[H+36932>>2]=t;c[H+102468>>2]=t;c[H+168004>>2]=t;t=q+2048|0;c[H+36936>>2]=t;c[H+102472>>2]=t;c[H+168008>>2]=t;t=q+3072|0;c[H+36940>>2]=t;c[H+102476>>2]=t;c[H+168012>>2]=t;t=q+4096|0;c[H+36944>>2]=t;c[H+102480>>2]=t;c[H+168016>>2]=t;t=q+5120|0;c[H+36948>>2]=t;c[H+102484>>2]=t;c[H+168020>>2]=t;t=q+6144|0;c[H+36952>>2]=t;c[H+102488>>2]=t;c[H+168024>>2]=t;t=q+7168|0;c[H+36956>>2]=t;c[H+102492>>2]=t;c[H+168028>>2]=t;t=q+8192|0;c[H+36960>>2]=t;c[H+102496>>2]=t;c[H+168032>>2]=t;t=q+9216|0;c[H+36964>>2]=t;c[H+102500>>2]=t;c[H+168036>>2]=t;t=q+10240|0;c[H+36968>>2]=t;c[H+102504>>2]=t;c[H+168040>>2]=t;t=q+11264|0;c[H+36972>>2]=t;c[H+102508>>2]=t;c[H+168044>>2]=t;t=q+12288|0;c[H+36976>>2]=t;c[H+102512>>2]=t;c[H+168048>>2]=t;t=q+13312|0;c[H+36980>>2]=t;c[H+102516>>2]=t;c[H+168052>>2]=t;t=q+14336|0;c[H+36984>>2]=t;c[H+102520>>2]=t;c[H+168056>>2]=t;t=q+15360|0;c[H+36988>>2]=t;c[H+102524>>2]=t;c[H+168060>>2]=t;t=c[2406562]|0;c[H+36992>>2]=t;c[H+102528>>2]=t;c[H+168064>>2]=t;q=t+1024|0;c[H+36996>>2]=q;c[H+102532>>2]=q;c[H+168068>>2]=q;q=t+2048|0;c[H+37e3>>2]=q;c[H+102536>>2]=q;c[H+168072>>2]=q;q=t+3072|0;c[H+37004>>2]=q;c[H+102540>>2]=q;c[H+168076>>2]=q;q=t+4096|0;c[H+37008>>2]=q;c[H+102544>>2]=q;c[H+168080>>2]=q;q=t+5120|0;c[H+37012>>2]=q;c[H+102548>>2]=q;c[H+168084>>2]=q;q=t+6144|0;c[H+37016>>2]=q;c[H+102552>>2]=q;c[H+168088>>2]=q;q=t+7168|0;c[H+37020>>2]=q;c[H+102556>>2]=q;c[H+168092>>2]=q;q=t+8192|0;c[H+37024>>2]=q;c[H+102560>>2]=q;c[H+168096>>2]=q;q=t+9216|0;c[H+37028>>2]=q;c[H+102564>>2]=q;c[H+168100>>2]=q;q=t+10240|0;c[H+37032>>2]=q;c[H+102568>>2]=q;c[H+168104>>2]=q;q=t+11264|0;c[H+37036>>2]=q;c[H+102572>>2]=q;c[H+168108>>2]=q;q=t+12288|0;c[H+37040>>2]=q;c[H+102576>>2]=q;c[H+168112>>2]=q;q=t+13312|0;c[H+37044>>2]=q;c[H+102580>>2]=q;c[H+168116>>2]=q;q=t+14336|0;c[H+37048>>2]=q;c[H+102584>>2]=q;c[H+168120>>2]=q;q=t+15360|0;c[H+37052>>2]=q;c[H+102588>>2]=q;c[H+168124>>2]=q;q=c[2406484]|0;c[H+37056>>2]=q;c[H+102592>>2]=q;c[H+168128>>2]=q;t=q+1024|0;c[H+37060>>2]=t;c[H+102596>>2]=t;c[H+168132>>2]=t;t=q+2048|0;c[H+37064>>2]=t;c[H+102600>>2]=t;c[H+168136>>2]=t;t=q+3072|0;c[H+37068>>2]=t;c[H+102604>>2]=t;c[H+168140>>2]=t;t=q+4096|0;c[H+37072>>2]=t;c[H+102608>>2]=t;c[H+168144>>2]=t;t=q+5120|0;c[H+37076>>2]=t;c[H+102612>>2]=t;c[H+168148>>2]=t;t=q+6144|0;c[H+37080>>2]=t;c[H+102616>>2]=t;c[H+168152>>2]=t;t=q+7168|0;c[H+37084>>2]=t;c[H+102620>>2]=t;c[H+168156>>2]=t;t=q+8192|0;c[H+37088>>2]=t;c[H+102624>>2]=t;c[H+168160>>2]=t;t=q+9216|0;c[H+37092>>2]=t;c[H+102628>>2]=t;c[H+168164>>2]=t;t=q+10240|0;c[H+37096>>2]=t;c[H+102632>>2]=t;c[H+168168>>2]=t;t=q+11264|0;c[H+37100>>2]=t;c[H+102636>>2]=t;c[H+168172>>2]=t;t=q+12288|0;c[H+37104>>2]=t;c[H+102640>>2]=t;c[H+168176>>2]=t;t=q+13312|0;c[H+37108>>2]=t;c[H+102644>>2]=t;c[H+168180>>2]=t;t=q+14336|0;c[H+37112>>2]=t;c[H+102648>>2]=t;c[H+168184>>2]=t;t=q+15360|0;c[H+37116>>2]=t;c[H+102652>>2]=t;c[H+168188>>2]=t;t=c[2443486]|0;c[H+37376>>2]=t;c[H+102912>>2]=t;c[H+168448>>2]=t;q=t+1024|0;c[H+37380>>2]=q;c[H+102916>>2]=q;c[H+168452>>2]=q;q=t+2048|0;c[H+37384>>2]=q;c[H+102920>>2]=q;c[H+168456>>2]=q;q=t+3072|0;c[H+37388>>2]=q;c[H+102924>>2]=q;c[H+168460>>2]=q;q=t+4096|0;c[H+37392>>2]=q;c[H+102928>>2]=q;c[H+168464>>2]=q;q=t+5120|0;c[H+37396>>2]=q;c[H+102932>>2]=q;c[H+168468>>2]=q;q=t+6144|0;c[H+37400>>2]=q;c[H+102936>>2]=q;c[H+168472>>2]=q;q=t+7168|0;c[H+37404>>2]=q;c[H+102940>>2]=q;c[H+168476>>2]=q;q=t+8192|0;c[H+37408>>2]=q;c[H+102944>>2]=q;c[H+168480>>2]=q;q=t+9216|0;c[H+37412>>2]=q;c[H+102948>>2]=q;c[H+168484>>2]=q;q=t+10240|0;c[H+37416>>2]=q;c[H+102952>>2]=q;c[H+168488>>2]=q;q=t+11264|0;c[H+37420>>2]=q;c[H+102956>>2]=q;c[H+168492>>2]=q;q=t+12288|0;c[H+37424>>2]=q;c[H+102960>>2]=q;c[H+168496>>2]=q;q=t+13312|0;c[H+37428>>2]=q;c[H+102964>>2]=q;c[H+168500>>2]=q;q=t+14336|0;c[H+37432>>2]=q;c[H+102968>>2]=q;c[H+168504>>2]=q;q=t+15360|0;c[H+37436>>2]=q;c[H+102972>>2]=q;c[H+168508>>2]=q;q=c[2386430]|0;t=c[2112932]|0;c[t+37632>>2]=q;c[t+103168>>2]=q;c[t+168704>>2]=q;k=q+1024|0;c[t+37636>>2]=k;c[t+103172>>2]=k;c[t+168708>>2]=k;k=c[2388252]|0;q=t+65280|0;r=16711680;while(1){s=k+(r-16711680)|0;c[q>>2]=s;c[q+65536>>2]=s;c[q+131072>>2]=s;s=r+1024|0;if(s>>>0>16777215){break}else{q=q+4|0;r=s}}c[t+196648>>2]=2988;c[t+196728>>2]=2964;c[t+196608>>2]=1146;c[t+196688>>2]=3486;r=c[2394]|0;q=c[14130368+(r<<2)>>2]|0;if((q|0)!=0){gGC(q|0,9104152,280)|0}c[8452240+(r<<2)>>2]=c[2113054];c[2394]=-1;r=c[2387052]|0;c[2396]=93269;c[2394714]=93269;a[14113648]=31;c[2427090]=511;b[4859088]=511;b[4859091]=b[4887388]|0;a[9718188]=-1;a[9718189]=-1;a[9718190]=-1;a[9718181]=63;a[9718206]=-1;a[9718208]=a[9718208]|-32;a[9718209]=a[9718209]&15;b[4859098]=0;c[3526934]=0;a[9638440]=0;c[2444184]=0;a[9718207]=a[9718207]&7|24;c[355e3]=1023;a[1428184]=1;c[2440230]=r;r=0;while(1){if((r|0)>=1024){I=0;break}J=9638528+(r<<2)|0;if((c[J>>2]|0)==0){m=1802;break}else{r=r+1|0}}do{if((m|0)==1802){r=gGq(32)|0;c[J>>2]=r;if((r|0)==0){I=0;break}gGz(r|0,0,32);I=r}}while(0);c[2440232]=I;c[2112948]=3024;c[2112946]=2720;Ux(0,7575,0);Ux(1,7575,0);c[2407030]=128;c[2407068]=3;c[2407069]=128;c[2407107]=3;r=c[642608+(c[2436]<<2)>>2]|0;t=c[r+128>>2]|0;if((c[r+52>>2]&4|0)==0){c[2113068]=t;q=c[r+132>>2]|0;c[2113070]=q;c[2443814]=t;c[2440436]=q;K=t;L=q}else{c[2113070]=t;q=c[r+132>>2]|0;c[2113068]=q;c[2440436]=t;c[2443814]=q;K=q;L=t}t=ag(K<<1,L)|0;q=gGq(t)|0;c[2112926]=q;if((q|0)!=0){gGz(q|0,0,t|0)}a[9623944]=0;t=c[2414632]|0;gGz(t|0,0,(c[2411602]|0)-t|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];t=c[3532592]|0;if((t|0)!=0){gGC(9104152,t|0,280)|0}c[2113054]=c[2113060]}RI();t=c[2394]|0;q=c[14130368+(t<<2)>>2]|0;if((q|0)!=0){gGC(q|0,9104152,280)|0}c[8452240+(t<<2)>>2]=c[2113054];c[2394]=-1;gd6(c[2396]|0);t=c[3541206]|0;q=c[3529750]|0;gGC(t|0,q|0,262144)|0;q=t+1048576|0;r=c[3529706]|0;gGC(q|0,r|0,262144)|0;c[2113156]=0;a[9628264]=0;c[2407033]=0;c[3541190]=t;c[3541198]=t;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=t+256;c[3541199]=t+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=t+512;c[3541200]=t+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=t+768;c[3541201]=t+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2113157]=0;a[9628420]=0;c[2407072]=0;c[3541194]=q;c[3541202]=q;gGz(c[2430122]|0,0,16384);c[2407080]=4;c[3541195]=t+1048832;c[3541203]=t+1114112;gGz(c[2430123]|0,0,16384);c[2407088]=4;c[3541196]=t+1049088;c[3541204]=t+1179648;gGz(c[2430124]|0,0,16384);c[2407096]=4;c[3541197]=t+1049344;c[3541205]=t+1245184;gGz(c[2430125]|0,0,16384);c[2407104]=4;o=0;i=e;return o|0}}while(0);c[2414930]=0;o=1;i=e;return o|0}function ess(){var a=0,b=0,d=0,e=0,f=0,g=0;c[2113070]=0;c[2113068]=0;a=c[2112926]|0;if((a|0)!=0){gGr(a);c[2112926]=0}if((c[2392]|0)>=0){a=0;do{b=14130368+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}b=14130384+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}a=a+1|0;}while((a|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;c[2440230]=0;c[2396]=-1;a=c[2440232]|0;b=0;while(1){if((b|0)>=1024){break}e=9638528+(b<<2)|0;if((c[e>>2]|0)==(a|0)){f=1847;break}else{b=b+1|0}}if((f|0)==1847){gGr(a);c[e>>2]=0}c[2440232]=0;Uw(0);Uw(1);e=c[2414930]|0;a=0;while(1){if((a|0)>=1024){f=1854;break}g=9638528+(a<<2)|0;if((c[g>>2]|0)==(e|0)){break}else{a=a+1|0}}if((f|0)==1854){c[2414930]=0;return 0}gGr(e);c[g>>2]=0;c[2414930]=0;return 0}function est(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((a[9623944]|0)!=0){a[9623944]=0;e=c[2414632]|0;gGz(e|0,0,(c[2411602]|0)-e|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060]}RI();e=c[2394]|0;f=c[14130368+(e<<2)>>2]|0;if((f|0)!=0){gGC(f|0,9104152,280)|0}c[8452240+(e<<2)>>2]=c[2113054];c[2394]=-1;gd6(c[2396]|0);e=c[3541206]|0;f=c[3529750]|0;gGC(e|0,f|0,262144)|0;f=e+1048576|0;g=c[3529706]|0;gGC(f|0,g|0,262144)|0;c[2113156]=0;a[9628264]=0;c[2407033]=0;c[3541190]=e;c[3541198]=e;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=e+256;c[3541199]=e+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=e+512;c[3541200]=e+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=e+768;c[3541201]=e+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2113157]=0;a[9628420]=0;c[2407072]=0;c[3541194]=f;c[3541202]=f;gGz(c[2430122]|0,0,16384);c[2407080]=4;c[3541195]=e+1048832;c[3541203]=e+1114112;gGz(c[2430123]|0,0,16384);c[2407088]=4;c[3541196]=e+1049088;c[3541204]=e+1179648;gGz(c[2430124]|0,0,16384);c[2407096]=4;c[3541197]=e+1049344;c[3541205]=e+1245184;gGz(c[2430125]|0,0,16384);c[2407104]=4}e=c[2392]|0;if((e|0)>=0){gGz(8452240,0,((e|0)>0?(e<<2)+4|0:4)|0)}c[2113054]=0;gGz(9634552,-1|0,6);e=0;f=-1;g=-1;h=-1;do{f=((a[9633088+e|0]&1)<<e^f&65535)&65535;g=((a[9630960+e|0]&1)<<e^g&65535)&65535;h=((a[9629416+e|0]&1)<<e^h&65535)&65535;e=e+1|0;}while((e|0)<16);b[4817276]=f;b[4817277]=g;b[4817278]=h;b[4817277]=d[c[2442890]|0]|g;c[2444014]=0;c[2443968]=0;if((c[2394]|0)==0){i=0;j=0;k=0}else{c[2394]=0;c[2112932]=c[3532596];g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060];i=0;j=0;k=0}while(1){g=10-i|0;h=(2e5-k|0)/(g|0)|0;c[2113056]=h;f=RG(h)|0;c[2113054]=(c[2113054]|0)+f;c[2276108]=-1;c[2113056]=-1;c[2444014]=(c[2444014]|0)+f;f=gd4((66666-(c[2443968]|0)|0)/(g|0)|0)|0;c[2443968]=(c[2443968]|0)+f;f=c[2112964]|0;if((f|0)==0){l=j}else{g=a[9688]|0?53:0;h=f+(j<<1<<1)|0;Uu(0,h,g);Uu(1,h,g);l=g+j|0}g=i+1|0;if((g|0)>=10){break}i=g;j=l;k=c[2444014]|0}k=c[2394]|0;c[8452200+(k<<2)>>2]=8194;c[2276080]=512;if((c[2276079]|0)>>>0<512){RH(2);m=c[2394]|0}else{m=k}k=c[14130368+(m<<2)>>2]|0;if((k|0)!=0){gGC(k|0,9104152,280)|0}c[8452240+(m<<2)>>2]=c[2113054];c[2394]=-1;m=c[2112964]|0;do{if((m|0)!=0){k=a[9688]|0?534:0;j=k-l|0;i=m+(l<<1<<1)|0;if((k|0)==(l|0)){break}Uu(0,i,j);Uu(1,i,j)}}while(0);if((c[2112968]|0)==0){return 0}esu()|0;return 0}function esu(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;if((a[9547328]|0)!=0){d=c[2406924]|0;f=c[3529968]|0;g=0;do{h=c[d+(g<<2)>>2]|0;c[f+(g<<2)>>2]=h>>8<<3&2016|h>>>3&31|h>>16<<8&63488;g=g+1|0;}while((g|0)<8192)}g=c[2113068]|0;f=c[2113070]|0;d=ag(f,g)|0;if((d|0)>0){h=c[2112926]|0;i=0;do{b[h+(i<<1)>>1]=15;i=i+1|0;}while((i|0)<(d|0))}switch(e[c[2432792]>>1]|0){case 9152:{esy();esw();esx();break};case 9297:case 11674:case 9280:case 9306:{esw();esx();esy();break};case 14554:case 8538:case 8512:{esw();esy();esx();break};case 11648:{esx();esy();esw();break};default:{}}d=c[2386430]|0;i=d+2048|0;h=c[2112926]|0;j=c[3530810]|0;k=d;while(1){d=e[k+4>>1]|0;l=(e[k>>1]|0)-64|0;m=(e[k+2>>1]|0)-16|0;n=e[k+6>>1]|0;o=n>>>8&15;p=n>>>12;q=n&31;if((n&65280|0)==65280){r=1919;break}s=(n&32|0)!=0;if(s){t=-16;u=(o<<4)+l|0}else{t=16;u=l}l=(n&64|0)!=0;if(l){v=-16;w=(p<<4)+m|0}else{v=16;w=m}m=0;do{n=(ag(m,v)|0)+w|0;x=(m<<4)+d|0;if((n|0)>-16){y=0;do{z=(ag(y,t)|0)+u|0;A=x+y|0;do{if((z|0)>-16&(n|0)<(f|0)&(z|0)<(g|0)){if(l){if(s){SN(h,A,z,n,q,4,15,0,j);break}else{SL(h,A,z,n,q,4,15,0,j);break}}else{if(s){SJ(h,A,z,n,q,4,15,0,j);break}else{SH(h,A,z,n,q,4,15,0,j);break}}}}while(0);y=y+1|0;}while((y|0)<=(o|0))}m=m+1|0;}while((m|0)<=(p|0));p=k+8|0;if(p>>>0<i>>>0){k=p}else{r=1918;break}}if((r|0)==1918){B=c[3529968]|0;R8(B);return 0}else if((r|0)==1919){B=c[3529968]|0;R8(B);return 0}return 0}function esv(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;f=i;i=i+416|0;g=f|0;h=f+16|0;j=f+32|0;k=f+48|0;l=f+64|0;m=f+80|0;n=f+96|0;o=f+112|0;p=f+128|0;q=f+144|0;r=f+160|0;s=f+176|0;t=f+192|0;u=f+208|0;v=f+224|0;w=f+240|0;x=f+256|0;y=f+272|0;z=f+288|0;A=f+304|0;B=f+320|0;C=f+336|0;D=f+352|0;E=f+368|0;F=f+384|0;G=f+400|0;if((e|0)!=0){c[e>>2]=169623}e=(b&32|0)==0;if(!e){gGz(G|0,0,12);H=c[2414632]|0;c[G>>2]=H;c[G+4>>2]=(c[2411602]|0)-H;c[G+12>>2]=162152;H=c[2076592]|0;gj[H&4095](G)|0}if((b&64|0)==0){i=f;return 0}b=y|0;gGz(x|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){G=y+9|0;y=w;H=w|0;I=w+4|0;J=w+12|0;K=x|0;L=x+4|0;M=x+12|0;N=0;do{gGC(b|0,614896,11)|0;a[G]=N+48&255;O=8452256+(N<<2)|0;gGz(y|0,0,12);c[H>>2]=O;c[I>>2]=4;c[J>>2]=164976;gj[c[2076592]&4095](w)|0;if((c[O>>2]|0)!=0){c[K>>2]=c[14130368+(N<<2)>>2];c[L>>2]=c[8452184+(N<<2)>>2];c[M>>2]=b;O=c[2076592]|0;gj[O&4095](x)|0}N=N+1|0;}while((N|0)<=(c[2392]|0))}gGz(t|0,0,12);c[t>>2]=9718176;c[t+4>>2]=2;c[t+12>>2]=162200;gj[c[2076592]&4095](t)|0;gGz(s|0,0,12);c[s>>2]=9718178;c[s+4>>2]=2;c[s+12>>2]=500560;gj[c[2076592]&4095](s)|0;gGz(r|0,0,12);c[r>>2]=9718180;c[r+4>>2]=1;c[r+12>>2]=384968;gj[c[2076592]&4095](r)|0;gGz(q|0,0,12);c[q>>2]=9718181;c[q+4>>2]=1;c[q+12>>2]=3e5;gj[c[2076592]&4095](q)|0;gGz(p|0,0,12);c[p>>2]=9718182;c[p+4>>2]=2;c[p+12>>2]=228584;gj[c[2076592]&4095](p)|0;gGz(o|0,0,12);c[o>>2]=9718184;c[o+4>>2]=1;c[o+12>>2]=178248;gj[c[2076592]&4095](o)|0;gGz(n|0,0,12);c[n>>2]=9718186;c[n+4>>2]=2;c[n+12>>2]=143456;gj[c[2076592]&4095](n)|0;gGz(m|0,0,12);c[m>>2]=9718188;c[m+4>>2]=1;c[m+12>>2]=115200;gj[c[2076592]&4095](m)|0;gGz(l|0,0,12);c[l>>2]=9718190;c[l+4>>2]=1;c[l+12>>2]=90216;gj[c[2076592]&4095](l)|0;gGz(k|0,0,12);c[k>>2]=9718192;c[k+4>>2]=2;c[k+12>>2]=70296;gj[c[2076592]&4095](k)|0;gGz(j|0,0,12);c[j>>2]=9718194;c[j+4>>2]=2;c[j+12>>2]=578304;gj[c[2076592]&4095](j)|0;gGz(h|0,0,12);c[h>>2]=9718196;c[h+4>>2]=2;c[h+12>>2]=561968;gj[c[2076592]&4095](h)|0;gGz(g|0,0,12);c[g>>2]=9718200;c[g+4>>2]=4;c[g+12>>2]=545816;gj[c[2076592]&4095](g)|0;if(!e){c[u>>2]=9718204;c[u+4>>2]=8;c[u+8>>2]=0;c[u+12>>2]=532136;e=c[2076592]|0;gj[e&4095](u)|0;c[v>>2]=c[2440232];c[v+4>>2]=a[1428184]|0?32:128;c[v+8>>2]=0;c[v+12>>2]=532136;u=c[2076592]|0;gj[u&4095](v)|0}Ut(0);Ut(1);gGz(F|0,0,12);c[F>>2]=9752344;c[F+4>>2]=1;c[F+12>>2]=149368;gj[c[2076592]&4095](F)|0;gGz(E|0,0,12);c[E>>2]=9718608;c[E+4>>2]=1;c[E+12>>2]=119688;gj[c[2076592]&4095](E)|0;gGz(D|0,0,12);c[D>>2]=9718600;c[D+4>>2]=1;c[D+12>>2]=94832;gj[c[2076592]&4095](D)|0;gGz(C|0,0,12);c[C>>2]=9731856;c[C+4>>2]=1;c[C+12>>2]=74184;gj[c[2076592]&4095](C)|0;gGz(B|0,0,12);c[B>>2]=9721984;c[B+4>>2]=1;c[B+12>>2]=581416;gj[c[2076592]&4095](B)|0;gGz(A|0,0,12);c[A>>2]=9721976;c[A+4>>2]=1;c[A+12>>2]=564440;gj[c[2076592]&4095](A)|0;gGz(z|0,0,12);c[z>>2]=9718616;c[z+4>>2]=1;c[z+12>>2]=548616;gj[c[2076592]&4095](z)|0;z=c[3541206]|0;A=(c[3529750]|0)+((d[9721984]|0)<<18&786432)|0;gGC(z|0,A|0,262144)|0;A=z+1048576|0;z=(c[3529706]|0)+((d[9721976]|0)<<18&1835008)|0;gGC(A|0,z|0,262144)|0;i=f;return 0}function esw(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;a=c[2406484]|0;d=c[3529384]|0;f=-16-(b[d+14>>1]&511)|0;g=-64-((e[d+12>>1]|0)+494&511)|0;d=c[2112926]|0;h=c[3530574]|0;i=0;do{j=i>>6;k=(j<<5|i&31)+(i<<6&2048)<<1;l=b[a+(k<<1)>>1]&4095;do{if((l|0)!=32){m=e[a+((k|1)<<1)>>1]|0;n=m&31;o=(i<<3&504)+f|0;p=(o|0)<-7?o+512|0:o;o=(j<<3)+g|0;q=(o|0)<-7?o+512|0:o;if(!((q|0)<(c[2113068]|0)&(p|0)<(c[2113070]|0))){break}o=(m&32|0)!=0;if((m&64|0)==0){if(o){St(d,l,q,p,n,4,15,512,h);break}else{Sr(d,l,q,p,n,4,15,512,h);break}}else{if(o){Sx(d,l,q,p,n,4,15,512,h);break}else{Sv(d,l,q,p,n,4,15,512,h);break}}}}while(0);i=i+1|0;}while((i|0)<4096);return}function esx(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;f=c[2387308]|0;g=c[3529384]|0;h=(e[g+16>>1]|0)+1008|0;i=(c[2443486]|0)+((d[g+19|0]|0)<<8&12288)|0;j=-16-(b[g+18>>1]&1023)|0;g=c[3530414]|0;k=c[2113070]|0;l=c[2113068]|0;m=c[2112926]|0;n=0;do{o=n>>6<<4;p=(o|n&15)+(n<<6&3072)<<1;q=(b[f+(p<<1)>>1]&32767)-8192|0;L2700:do{if((q|0)!=2048){r=n<<4&1008;s=b[f+((p|1)<<1)>>1]|0;t=s&65535;u=o-64|0;v=q<<8;w=((t&64|0)!=0?240:0)|((t&32|0)!=0?15:0);t=s<<4&496;s=0;x=0;while(1){y=s+r|0;z=u-(h+(e[i+(y<<1)>>1]|0)&1023)|0;A=y+j|0;y=(A|0)<-15?A+1024|0:A;if((y|0)>=(k|0)){break L2700}A=ag(l,y)|0;B=x;C=0;while(1){D=z+C|0;E=(D|0)<-15?D+1024|0:D;do{if((E|y|0)>=0&(E|0)<(l|0)){D=a[g+((B^w)+v)|0]|0;if(D<<24>>24==15){break}b[m+(A+E<<1)>>1]=t|D&255|1024}}while(0);E=C+1|0;if((E|0)<16){B=B+1|0;C=E}else{break}}C=s+1|0;if((C|0)>=16){break L2700}s=C;x=x+16|0}}}while(0);n=n+1|0;}while((n|0)<4096);return}function esy(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;a=c[2406562]|0;d=c[3529384]|0;f=-16-(b[d+22>>1]&2047)|0;g=-64-((e[d+20>>1]|0)+2030&2047)|0;d=c[2112926]|0;h=c[3530324]|0;i=c[2113068]|0;j=c[2113070]|0;k=0;do{l=k<<5&2016;m=k>>6;n=(l>>>8<<9)+(m<<3|k&7)<<1;o=(b[a+(n<<1)>>1]&8191)+2048|0;p=e[a+((n|1)<<1)>>1]|0;n=p&63;q=l+f|0;l=(q|0)<-31?q+2048|0:q;q=(m<<5)+g|0;m=(q|0)<-31?q+2048|0:q;do{if((m|0)<(i|0)&(l|0)<(j|0)){q=(p&32|0)!=0;if((p&64|0)==0){if(q){SZ(d,o,m,l,n,4,15,1536,h);break}else{SX(d,o,m,l,n,4,15,1536,h);break}}else{if(q){S1(d,o,m,l,n,4,15,1536,h);break}else{S$(d,o,m,l,n,4,15,1536,h);break}}}}while(0);k=k+1|0;}while((k|0)<4096);return}function esz(d){d=d|0;var e=0,f=0;e=d-2113536|0;if(e>>>0<1536){f=b[(c[2439608]|0)+(e>>>1<<1)>>1]&255;return f|0}e=d-2115072|0;if(e>>>0<14848){f=b[(c[2388044]|0)+32768+(e>>>1<<1)>>1]&255;return f|0}if((d|0)==7340047){f=c[2113156]&255;return f|0}else if((d|0)==7340041){if(a[6346600]|0){d=c[2386344]^8;c[2386344]=d;f=d&255;return f|0}else{d=(a[9760128]|0)<0?4:0;f=(d|(cT()|0)&8)&255;return f|0}}else{f=0;return f|0}return 0}function esA(a,d){a=a|0;d=d|0;var e=0;if((a-1048576|0)>>>0<16384){return}e=a-2097152|0;if(e>>>0<1536){b[(c[2439608]|0)+(e>>>1<<1)>>1]=d&255;return}e=a-2098688|0;if(e>>>0<14848){b[(c[2388044]|0)+16384+(e>>>1<<1)>>1]=d&255;return}if((a|0)!=7340045){return}a=d&15;c[3530246]=a;d=(c[3541206]|0)+196608|0;e=(c[2433464]|0)+(a<<16)|0;gGC(d|0,e|0,65536)|0;return}function esB(a){a=a|0;var e=0,f=0;e=a-2113536|0;if(e>>>0<1536){f=b[(c[2439608]|0)+(e>>>1<<1)>>1]|0;return f|0}e=a-2115072|0;if(e>>>0<14848){f=b[(c[2388044]|0)+32768+(e>>>1<<1)>>1]|0;return f|0}if((a|0)==7340032){f=(d[9657929]|0)<<8|(d[9657928]|0);return f|0}else if((a|0)==7340034){f=(d[9625609]|0)<<8|(d[9625608]|0);return f|0}else{f=0;return f|0}return 0}function esC(a,d){a=a|0;d=d|0;var e=0;if((a-1081344|0)>>>0<16384){return}e=a-2097152|0;if(e>>>0<1536){b[(c[2439608]|0)+(e>>>1<<1)>>1]=d;return}e=a-2113536|0;if(e>>>0<1536){b[(c[2439608]|0)+(e>>>1<<1)>>1]=d;return}e=a-2115072|0;if(e>>>0<14848){b[(c[2388044]|0)+32768+(e>>>1<<1)>>1]=d;return}if((a|0)==1097732|(a|0)==1097734){b[(c[3529816]|0)+((a-1097732|0)>>>1<<1)>>1]=d;return}else if((a|0)==1097728|(a|0)==1097730){b[(c[3529812]|0)+((a-1097728|0)>>>1<<1)>>1]=d;return}else if((a|0)==7340046){Uv(0,d&255);return}else{return}}function esD(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7402708+(b*112|0)>>2];c[a+104>>2]=c[7402712+(b*112|0)>>2];c[a+108>>2]=c[7402716+(b*112|0)>>2];d=0;return d|0}function esE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=7402608+(b*112|0);e=0;return e|0}function esF(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6924544+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function esG(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>41){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7433856+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function esH(){a[6939744]=1;return esN()|0}function esI(){var b=0,d=0,e=0,f=0,g=0;if((c[2392]|0)>=0){b=0;do{d=14130368+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}d=14130384+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}b=b+1|0;}while((b|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;Uw(0);c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}b=c[2426692]|0;d=0;while(1){if((d|0)>=1024){f=2075;break}g=9638528+(d<<2)|0;if((c[g>>2]|0)==(b|0)){break}else{d=d+1|0}}if((f|0)==2075){c[2426692]=0;a[6939744]=0;a[6346600]=0;a[9760128]=0;c[3530246]=0;c[2386344]=0;return 0}gGr(b);c[g>>2]=0;c[2426692]=0;a[6939744]=0;a[6346600]=0;a[9760128]=0;c[3530246]=0;c[2386344]=0;return 0}function esJ(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if((a[9623936]|0)!=0){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;c[2113156]=0;a[9628264]=0;c[2407033]=0;d=c[3541206]|0;c[3541190]=d;c[3541198]=d;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=d+256;c[3541199]=d+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=d+512;c[3541200]=d+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=d+768;e=d+196608|0;c[3541201]=e;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[3530246]=0;d=c[2433464]|0;gGC(e|0,d|0,65536)|0;a[9760128]=0;c[2386344]=0}a[9625609]=-1;a[9625608]=-1;d=0;e=-1;f=-1;do{e=(e&255)-((a[9759160+d|0]&1)<<d)&255;f=(f&255)-((a[9758968+d|0]&1)<<d)&255;d=d+1|0;}while((d|0)<8);a[9625608]=e;a[9625609]=f;f=c[2392]|0;if((f|0)>=0){gGz(8452240,0,((f|0)>0?(f<<2)+4|0:4)|0)}c[2113054]=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060]}c[2113056]=166666;f=RG(166666)|0;c[2113054]=(c[2113054]|0)+f;c[2276108]=-1;c[2113056]=-1;f=c[2394]|0;c[8452200+(f<<2)>>2]=8193;c[2276080]=256;if((c[2276079]|0)>>>0<256){RH(1);g=c[2394]|0}else{g=f}f=c[14130368+(g<<2)>>2]|0;if((f|0)!=0){gGC(f|0,9104152,280)|0}c[8452240+(g<<2)>>2]=c[2113054];c[2394]=-1;g=c[2112964]|0;if((g|0)!=0){Uu(0,g,a[9688]|0?534:0)}if((c[2112968]|0)==0){return 0}g=c[2112926]|0;gGz(g|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);g=c[3529966]|0;f=0;e=c[2439608]|0;d=g;while(1){h=b[e>>1]|0;i=(h&65535)>>>4;j=h&255;k=(h&65535)>>>8;c[d>>2]=((k<<4&255|k&8)&255)>>>3|((j<<4|j&12)&255)<<3&2016|((i<<4&255|i&8)&255)<<8&63488;i=f+1|0;if((i|0)<768){f=i;e=e+2|0;d=d+4|0}else{break}}esS(0);esS(1);esT(0);esU(0);esT(1);esU(1);R8(g);return 0}function esK(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;e=i;i=i+144|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;l=e+80|0;m=e+96|0;n=e+112|0;o=e+128|0;if((d|0)!=0){c[d>>2]=169751}if((b&32|0)!=0){gGz(o|0,0,12);d=c[2405628]|0;c[o>>2]=d;c[o+4>>2]=(c[2411598]|0)-d;c[o+12>>2]=162152;d=c[2076592]|0;gj[d&4095](o)|0}if((b&64|0)==0){i=e;return 0}o=h|0;gGz(g|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){d=h+9|0;h=f;p=f|0;q=f+4|0;r=f+12|0;s=g|0;t=g+4|0;u=g+12|0;v=0;do{gGC(o|0,614896,11)|0;a[d]=v+48&255;w=8452256+(v<<2)|0;gGz(h|0,0,12);c[p>>2]=w;c[q>>2]=4;c[r>>2]=164976;gj[c[2076592]&4095](f)|0;if((c[w>>2]|0)!=0){c[s>>2]=c[14130368+(v<<2)>>2];c[t>>2]=c[8452184+(v<<2)>>2];c[u>>2]=o;w=c[2076592]|0;gj[w&4095](g)|0}v=v+1|0;}while((v|0)<=(c[2392]|0))}Ut(0);gGz(n|0,0,12);c[n>>2]=9625608;c[n+4>>2]=2;c[n+12>>2]=215728;gj[c[2076592]&4095](n)|0;gGz(m|0,0,12);c[m>>2]=9657928;c[m+4>>2]=2;c[m+12>>2]=483352;gj[c[2076592]&4095](m)|0;gGz(l|0,0,12);c[l>>2]=9760128;c[l+4>>2]=1;c[l+12>>2]=268952;gj[c[2076592]&4095](l)|0;gGz(k|0,0,12);c[k>>2]=14120984;c[k+4>>2]=4;c[k+12>>2]=491248;gj[c[2076592]&4095](k)|0;gGz(j|0,0,12);c[j>>2]=9545376;c[j+4>>2]=4;c[j+12>>2]=252600;gj[c[2076592]&4095](j)|0;if((b&2|0)==0){i=e;return 0}b=c[3530246]&255;c[3530246]=b;j=(c[3541206]|0)+196608|0;k=(c[2433464]|0)+(b<<16)|0;gGC(j|0,k|0,65536)|0;i=e;return 0}function esL(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7223028+(b*112|0)>>2];c[a+104>>2]=c[7223032+(b*112|0)>>2];c[a+108>>2]=c[7223036+(b*112|0)>>2];d=0;return d|0}function esM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=7222928+(b*112|0);e=0;return e|0}function esN(){var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;e=i;i=i+720|0;f=e|0;g=e+112|0;h=e+120|0;j=e+232|0;k=e+240|0;l=e+352|0;m=e+360|0;n=e+472|0;o=e+480|0;p=e+592|0;q=e+600|0;r=e+712|0;c[2426692]=0;c[2388024]=0;c[3541206]=1048576;c[2433464]=1310720;c[2405628]=2359296;c[2388044]=2359296;c[2405792]=2416640;c[2405790]=2424832;c[2443408]=2433024;c[2439608]=2441216;c[3529816]=2442752;c[3529812]=2442756;c[2411598]=2442760;c[3529568]=2442760;c[3529966]=6637064;s=0;while(1){if((s|0)>=1024){break}t=9638528+(s<<2)|0;if((c[t>>2]|0)==0){u=2136;break}else{s=s+1|0}}do{if((u|0)==2136){s=gGq(6640136)|0;c[t>>2]=s;if((s|0)==0){break}c[2426692]=s;gGz(s|0,0,6640136);c[2388024]=s;c[3541206]=s+1048576;c[2433464]=s+1310720;v=s+2359296|0;c[2405628]=v;c[2388044]=v;c[2405792]=s+2416640;c[2405790]=s+2424832;c[2443408]=s+2433024;c[2439608]=s+2441216;c[3529816]=s+2442752;c[3529812]=s+2442756;v=s+2442760|0;c[2411598]=v;c[3529568]=v;c[3529966]=s+6637064;c[2414138]=s+6640136;s=0;while(1){if((s|0)>=1024){w=0;break}x=9638528+(s<<2)|0;if((c[x>>2]|0)==0){u=2141;break}else{s=s+1|0}}do{if((u|0)==2141){s=gGq(2097152)|0;c[x>>2]=s;if((s|0)==0){w=0;break}gGz(s|0,0,2097152);w=s}}while(0);c[3529518]=w;if((R6((c[2388024]|0)+1|0,0,2)|0)!=0){y=1;i=e;return y|0}if((R6(c[2388024]|0,1,2)|0)!=0){y=1;i=e;return y|0}s=c[3529518]|0;gGz(s|0,0,2097152);if((c[3542200]|0)==0){y=1;i=e;return y|0}v=q+108|0;c[v>>2]=0;z=q+100|0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](q,2)|0;do{if((c[v>>2]|0)!=0){A=c[z>>2]|0;c[r>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](r,2,0)|0;if((A|0)<1){y=1;i=e;return y|0}if((gzL(s,0,2)|0)==0){break}else{y=1}i=e;return y|0}}while(0);s=(c[3529518]|0)+524288|0;if((c[3542200]|0)==0){y=1;i=e;return y|0}z=o+108|0;c[z>>2]=0;v=o+100|0;c[v>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](o,3)|0;do{if((c[z>>2]|0)!=0){A=c[v>>2]|0;c[p>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](p,3,0)|0;if((A|0)<1){y=1;i=e;return y|0}if((gzL(s,0,3)|0)==0){break}else{y=1}i=e;return y|0}}while(0);s=(c[3529518]|0)+1048576|0;if((c[3542200]|0)==0){y=1;i=e;return y|0}v=m+108|0;c[v>>2]=0;z=m+100|0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,4)|0;do{if((c[v>>2]|0)!=0){A=c[z>>2]|0;c[n>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](n,4,0)|0;if((A|0)<1){y=1;i=e;return y|0}if((gzL(s,0,4)|0)==0){break}else{y=1}i=e;return y|0}}while(0);s=(c[3529518]|0)+1572864|0;if((c[3542200]|0)==0){y=1;i=e;return y|0}z=k+108|0;c[z>>2]=0;v=k+100|0;c[v>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,5)|0;do{if((c[z>>2]|0)!=0){A=c[v>>2]|0;c[l>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](l,5,0)|0;if((A|0)<1){y=1;i=e;return y|0}if((gzL(s,0,5)|0)==0){break}else{y=1}i=e;return y|0}}while(0);s=c[3529518]|0;v=c[3529568]|0;z=0;do{A=z<<8;gGz(v+A|0,0,256);B=0;do{C=1<<3-B;D=(c[601464+(B<<2)>>2]|0)+A|0;E=0;do{F=D+(c[609008+(E<<2)>>2]|0)|0;G=(E<<4)+A|0;H=0;do{I=F+(c[597864+(H<<2)>>2]|0)|0;if(((d[s+((I|0)/8|0)|0]|0)&128>>>((I&7)>>>0)|0)!=0){I=v+(G+H)|0;a[I]=(d[I]|0|C)&255}H=H+1|0;}while((H|0)<16);E=E+1|0;}while((E|0)<16);B=B+1|0;}while((B|0)<4);z=z+1|0;}while((z|0)<16384);z=c[2433464]|0;if((c[3542200]|0)==0){y=1;i=e;return y|0}v=h+108|0;c[v>>2]=0;s=h+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](h,6)|0;do{if((c[v>>2]|0)!=0){B=c[s>>2]|0;c[j>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](j,6,0)|0;if((B|0)<1){y=1;i=e;return y|0}if((gzL(z,0,6)|0)==0){break}else{y=1}i=e;return y|0}}while(0);do{if(!(a[6346600]|0)){z=(c[2433464]|0)+524288|0;if((c[3542200]|0)==0){y=1;i=e;return y|0}s=f+108|0;c[s>>2]=0;v=f+100|0;c[v>>2]=0;B=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[B&16383](f,7)|0;if((c[s>>2]|0)==0){break}s=c[v>>2]|0;c[g>>2]=9534384;v=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[v&16383](g,7,0)|0;if((s|0)<1){y=1;i=e;return y|0}if((gzL(z,0,7)|0)==0){break}else{y=1}i=e;return y|0}}while(0);z=c[3541206]|0;s=c[2433464]|0;gGC(z|0,s|0,262144)|0;s=c[3529518]|0;z=0;while(1){if((z|0)>=1024){break}J=9638528+(z<<2)|0;if((c[J>>2]|0)==(s|0)){u=2183;break}else{z=z+1|0}}if((u|0)==2183){gGr(s);c[J>>2]=0}c[3529518]=0;if(a[6939744]|0){z=c[2388024]|0;v=0;do{B=z+(v<<1)|0;A=b[B>>1]|0;b[B>>1]=A<<1&1028|A&-1543|(A&65535)>>>1&514;v=v+1|0;}while((v|0)<524288)}fxU(0,425984);if((c[2394]|0)==0){K=c[2112932]|0}else{c[2394]=0;v=c[3532596]|0;c[2112932]=v;z=c[3532592]|0;if((z|0)!=0){gGC(9104152,z|0,280)|0}c[2113054]=c[2113060];K=v}v=c[2388024]|0;z=K|0;s=0;while(1){A=v+s|0;c[z>>2]=A;c[z+131072>>2]=A;A=s+1024|0;if(A>>>0>1048575){break}else{z=z+4|0;s=A}}s=c[2405790]|0;c[K+4160>>2]=s;c[K+69696>>2]=s;c[K+135232>>2]=s;z=s+1024|0;c[K+4164>>2]=z;c[K+69700>>2]=z;c[K+135236>>2]=z;z=s+2048|0;c[K+4168>>2]=z;c[K+69704>>2]=z;c[K+135240>>2]=z;z=s+3072|0;c[K+4172>>2]=z;c[K+69708>>2]=z;c[K+135244>>2]=z;z=s+4096|0;c[K+4176>>2]=z;c[K+69712>>2]=z;c[K+135248>>2]=z;z=s+5120|0;c[K+4180>>2]=z;c[K+69716>>2]=z;c[K+135252>>2]=z;z=s+6144|0;c[K+4184>>2]=z;c[K+69720>>2]=z;c[K+135256>>2]=z;z=s+7168|0;c[K+4188>>2]=z;c[K+69724>>2]=z;c[K+135260>>2]=z;z=c[2405792]|0;c[K+4192>>2]=z;c[K+69728>>2]=z;c[K+135264>>2]=z;s=z+1024|0;c[K+4196>>2]=s;c[K+69732>>2]=s;c[K+135268>>2]=s;s=z+2048|0;c[K+4200>>2]=s;c[K+69736>>2]=s;c[K+135272>>2]=s;s=z+3072|0;c[K+4204>>2]=s;c[K+69740>>2]=s;c[K+135276>>2]=s;s=z+4096|0;c[K+4208>>2]=s;c[K+69744>>2]=s;c[K+135280>>2]=s;s=z+5120|0;c[K+4212>>2]=s;c[K+69748>>2]=s;c[K+135284>>2]=s;s=z+6144|0;c[K+4216>>2]=s;c[K+69752>>2]=s;c[K+135288>>2]=s;s=z+7168|0;c[K+4220>>2]=s;c[K+69756>>2]=s;c[K+135292>>2]=s;s=c[2388044]|0;z=s+49152|0;c[K+17408>>2]=z;c[K+82944>>2]=z;c[K+148480>>2]=z;z=s+50176|0;c[K+17412>>2]=z;c[K+82948>>2]=z;c[K+148484>>2]=z;z=s+51200|0;c[K+17416>>2]=z;c[K+82952>>2]=z;c[K+148488>>2]=z;z=s+52224|0;c[K+17420>>2]=z;c[K+82956>>2]=z;c[K+148492>>2]=z;z=s+53248|0;c[K+17424>>2]=z;c[K+82960>>2]=z;c[K+148496>>2]=z;z=s+54272|0;c[K+17428>>2]=z;c[K+82964>>2]=z;c[K+148500>>2]=z;z=s+55296|0;c[K+17432>>2]=z;c[K+82968>>2]=z;c[K+148504>>2]=z;z=s+56320|0;c[K+17436>>2]=z;c[K+82972>>2]=z;c[K+148508>>2]=z;z=c[2443408]|0;c[K+17472>>2]=z;c[K+83008>>2]=z;c[K+148544>>2]=z;v=z+1024|0;c[K+17476>>2]=v;c[K+83012>>2]=v;c[K+148548>>2]=v;v=z+2048|0;c[K+17480>>2]=v;c[K+83016>>2]=v;c[K+148552>>2]=v;v=z+3072|0;c[K+17484>>2]=v;c[K+83020>>2]=v;c[K+148556>>2]=v;v=z+4096|0;c[K+17488>>2]=v;c[K+83024>>2]=v;c[K+148560>>2]=v;v=z+5120|0;c[K+17492>>2]=v;c[K+83028>>2]=v;c[K+148564>>2]=v;v=z+6144|0;c[K+17496>>2]=v;c[K+83032>>2]=v;c[K+148568>>2]=v;v=z+7168|0;c[K+17500>>2]=v;c[K+83036>>2]=v;c[K+148572>>2]=v;c[K+65216>>2]=s;c[K+130752>>2]=s;c[K+196288>>2]=s;v=s+1024|0;c[K+65220>>2]=v;c[K+130756>>2]=v;c[K+196292>>2]=v;v=s+2048|0;c[K+65224>>2]=v;c[K+130760>>2]=v;c[K+196296>>2]=v;v=s+3072|0;c[K+65228>>2]=v;c[K+130764>>2]=v;c[K+196300>>2]=v;v=s+4096|0;c[K+65232>>2]=v;c[K+130768>>2]=v;c[K+196304>>2]=v;v=s+5120|0;c[K+65236>>2]=v;c[K+130772>>2]=v;c[K+196308>>2]=v;v=s+6144|0;c[K+65240>>2]=v;c[K+130776>>2]=v;c[K+196312>>2]=v;v=s+7168|0;c[K+65244>>2]=v;c[K+130780>>2]=v;c[K+196316>>2]=v;v=s+8192|0;c[K+65248>>2]=v;c[K+130784>>2]=v;c[K+196320>>2]=v;v=s+9216|0;c[K+65252>>2]=v;c[K+130788>>2]=v;c[K+196324>>2]=v;v=s+10240|0;c[K+65256>>2]=v;c[K+130792>>2]=v;c[K+196328>>2]=v;v=s+11264|0;c[K+65260>>2]=v;c[K+130796>>2]=v;c[K+196332>>2]=v;v=s+12288|0;c[K+65264>>2]=v;c[K+130800>>2]=v;c[K+196336>>2]=v;v=s+13312|0;c[K+65268>>2]=v;c[K+130804>>2]=v;c[K+196340>>2]=v;v=s+14336|0;c[K+65272>>2]=v;c[K+130808>>2]=v;c[K+196344>>2]=v;v=s+15360|0;c[K+65276>>2]=v;c[K+130812>>2]=v;c[K+196348>>2]=v;c[K+196688>>2]=2490;c[K+196728>>2]=1046;c[K+196608>>2]=642;c[K+196648>>2]=2088;v=c[3532592]|0;if((v|0)!=0){gGC(v|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;Ux(0,8e3,0);c[2407030]=256;c[2407068]=3;v=c[642608+(c[2436]<<2)>>2]|0;s=c[v+128>>2]|0;if((c[v+52>>2]&4|0)==0){c[2113068]=s;z=c[v+132>>2]|0;c[2113070]=z;c[2443814]=s;c[2440436]=z;L=s;M=z}else{c[2113070]=s;z=c[v+132>>2]|0;c[2113068]=z;c[2440436]=s;c[2443814]=z;L=z;M=s}s=ag(L<<1,M)|0;z=gGq(s)|0;c[2112926]=z;if((z|0)!=0){gGz(z|0,0,s|0)}if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];s=c[3532592]|0;if((s|0)!=0){gGC(9104152,s|0,280)|0}c[2113054]=c[2113060]}RI();s=c[2394]|0;z=c[14130368+(s<<2)>>2]|0;if((z|0)!=0){gGC(z|0,9104152,280)|0}c[8452240+(s<<2)>>2]=c[2113054];c[2394]=-1;c[2113156]=0;a[9628264]=0;c[2407033]=0;s=c[3541206]|0;c[3541190]=s;c[3541198]=s;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=s+256;c[3541199]=s+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=s+512;c[3541200]=s+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=s+768;z=s+196608|0;c[3541201]=z;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[3530246]=0;s=c[2433464]|0;gGC(z|0,s|0,65536)|0;a[9760128]=0;c[2386344]=0;y=0;i=e;return y|0}}while(0);c[2426692]=0;y=1;i=e;return y|0}function esO(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3252324+(b*112|0)>>2];c[a+104>>2]=c[3252328+(b*112|0)>>2];c[a+108>>2]=c[3252332+(b*112|0)>>2];d=0;return d|0}function esP(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=3252224+(b*112|0);e=0;return e|0}function esQ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>30){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3253008+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function esR(){a[6346600]=1;return esN()|0}function esS(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;f=c[2405792]|0;g=c[3529816]|0;h=g;i=g+2|0;g=a[6346600]|0;j=c[2112926]|0;k=c[3529568]|0;l=0;m=0;while(1){n=m<<4;o=l;p=0;while(1){q=o<<1;r=e[f+(q<<1)>>1]|0;s=e[f+((q|1)<<1)>>1]|0;q=s&31;t=s>>>6;u=t&1;v=t&2;L3098:do{if((s>>>5&1|0)==(d|0)){t=(p<<4)-(b[i>>1]&1023)|0;w=n-(b[h>>1]&511)|0;x=(t|0)<-16?t+1024|0:t;t=(w|0)<-16?w+512|0:w;w=g?t-16|0:t;do{if((x-17|0)>>>0<351&(w|0)>16){if((w|0)>=((c[2113070]|0)-16|0)){break}t=(v|0)!=0;if((u|0)==0){if(t){SK(j,r,x,w,q,4,0,0,k);break L3098}else{SG(j,r,x,w,q,4,0,0,k);break L3098}}else{if(t){SM(j,r,x,w,q,4,0,0,k);break L3098}else{SI(j,r,x,w,q,4,0,0,k);break L3098}}}}while(0);t=(v|0)!=0;if((u|0)==0){if(t){SL(j,r,x,w,q,4,0,0,k);break}else{SH(j,r,x,w,q,4,0,0,k);break}}else{if(t){SN(j,r,x,w,q,4,0,0,k);break}else{SJ(j,r,x,w,q,4,0,0,k);break}}}}while(0);q=p+1|0;if((q|0)<64){o=o+1|0;p=q}else{break}}p=m+1|0;if((p|0)<32){l=l+64|0;m=p}else{break}}return}function esT(b){b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=c[2405790]|0;f=c[3529812]|0;g=f;h=f+2|0;f=a[6346600]|0;i=c[2112926]|0;j=c[3529568]|0;k=0;l=0;while(1){m=l<<4;n=k;o=0;while(1){p=n<<1;q=e[d+(p<<1)>>1]|0;r=e[d+((p|1)<<1)>>1]|0;p=r&31;s=r>>>6;t=s&1;u=s&2;L3130:do{if((r>>>5&1|0)==(b|0)){s=(o<<4)-((e[h>>1]|0)+5&1023)|0;v=m-((e[g>>1]|0)+1&511)|0;w=(s|0)<-16?s+1024|0:s;s=(v|0)<-16?v+512|0:v;v=f?s-16|0:s;do{if((w-17|0)>>>0<351&(v|0)>16){if((v|0)>=((c[2113070]|0)-16|0)){break}s=(u|0)!=0;if((t|0)==0){if(s){SK(i,q,w,v,p,4,0,0,j);break L3130}else{SG(i,q,w,v,p,4,0,0,j);break L3130}}else{if(s){SM(i,q,w,v,p,4,0,0,j);break L3130}else{SI(i,q,w,v,p,4,0,0,j);break L3130}}}}while(0);s=(u|0)!=0;if((t|0)==0){if(s){SL(i,q,w,v,p,4,0,0,j);break}else{SH(i,q,w,v,p,4,0,0,j);break}}else{if(s){SN(i,q,w,v,p,4,0,0,j);break}else{SJ(i,q,w,v,p,4,0,0,j);break}}}}while(0);p=o+1|0;if((p|0)<64){n=n+1|0;o=p}else{break}}o=l+1|0;if((o|0)<32){k=k+64|0;l=o}else{break}}return}function esU(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=c[2443408]|0;g=f;h=f+8184|0;i=f+6|0;while(1){if(i>>>0>=h>>>0){break}if((b[i>>1]|0)<0){break}else{i=i+8|0}}h=i-8|0;if(h>>>0<g>>>0){return}f=a[6346600]|0?224:240;j=c[2112926]|0;k=c[3529568]|0;l=i;i=h;while(1){h=e[i>>1]|0;m=e[l-6>>1]|0;n=e[l-4>>1]|0;o=e[l-2>>1]|0;p=n&16384;q=n&32768;L3167:do{if((n>>>3&1^1|0)==(d|0)){r=n&15|32;if((o&16384|0)!=0){break}s=o&511;t=s-16|0;u=f+((h&256)-(h&255))|0;do{if((s-33|0)>>>0<351&(u|0)>16){if((u|0)>=((c[2113070]|0)-16|0)){break}v=(q|0)!=0;if((p|0)==0){if(v){SK(j,m,t,u,r,4,0,0,k);break L3167}else{SG(j,m,t,u,r,4,0,0,k);break L3167}}else{if(v){SM(j,m,t,u,r,4,0,0,k);break L3167}else{SI(j,m,t,u,r,4,0,0,k);break L3167}}}}while(0);s=(q|0)!=0;if((p|0)==0){if(s){SL(j,m,t,u,r,4,0,0,k);break}else{SH(j,m,t,u,r,4,0,0,k);break}}else{if(s){SN(j,m,t,u,r,4,0,0,k);break}else{SJ(j,m,t,u,r,4,0,0,k);break}}}}while(0);m=i-8|0;if(m>>>0<g>>>0){break}else{l=i;i=m}}return}function esV(f,g){f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;if((f|0)==15728640){b[4876600]=g&-32768;return}else if((f|0)==3342336|(f|0)==3407872|(f|0)==3473408|(f|0)==3538944){h=c[2406734]|0;b[h+((f-3342336|0)>>>16<<1)>>1]=g;if((b[h>>1]|0)!=-1){return}if((b[h+2>>1]|0)!=-1){return}if((b[h+4>>1]|0)!=-1){return}if((b[h+6>>1]|0)!=-1){return}g=h;h=g|0;C=0;b[h>>1]=C&65535;b[h+2>>1]=C>>16;h=g+4|0;C=0;b[h>>1]=C&65535;b[h+2>>1]=C>>16;h=c[2387358]|0;g=b[h+18>>1]|0;i=(g&65535)>>>1;j=(e[h+16>>1]|0)>>>8;if((j|0)==3){b[h+((i&65535)<<1)>>1]=d[9634945]<<8|d[9634944];return}else if((j|0)==4){k=e[h+20>>1]<<3&504;l=c[2387354]|0;m=d[l+(k|65541)|0]<<8|d[l+(k|65540)|0];n=m&65535;if(m<<16>>16==0){return}o=(d[l+(k|65539)|0]<<8|d[l+(k|65538)|0])&65535|65536;k=g&65535;a[h+k|0]=a[l+o|0]|0;if((m&65535)>1){p=1}else{return}do{a[h+(p+k)|0]=a[l+(p+o)|0]|0;p=p+1|0;}while((p|0)<(n|0));return}else if((j|0)==2){n=h+(i&65535)|0;p=c[2406296]|0;gGC(n|0,p|0,128)|0;return}else if((j|0)==66){j=c[2406296]|0;p=h+(i&65535)|0;gGC(j|0,p|0,128)|0;return}else{return}}else if((f|0)==16252928){c[2388358]=0;return}else{return}}function esW(a,b){a=a|0;b=b|0;return}function esX(a){a=a|0;return 0}function esY(a){a=a|0;var b=0;if((a|0)==15728646){b=(e[4775187]|0)>>>8&255}else if((a|0)==15728642){b=(e[4775185]|0)>>>8&255}else if((a|0)==15728644){b=(e[4775186]|0)>>>8&255}else if((a|0)==15728640){b=(e[4775184]|0)>>>8&255}else{b=0}return b|0}function esZ(a,b){a=a|0;b=b|0;if((a|0)==10485760){c[2388358]=0;return}else if((a|0)==8388610){Ui(b&255);return}else if((a|0)==8388608){c[2113012]=b&255;return}else{return}}function es_(a,b){a=a|0;b=b|0;if((a|0)==8388609){c[2113012]=b&255;return}else if((a|0)==8388611){Ui(b);return}else{return}}function es$(a){a=a|0;return 0}function es0(a){a=a|0;return 0}function es1(a,d){a=a|0;d=d|0;var e=0,f=0;b[(c[3527298]|0)+(a&16382)>>1]=d;if((a|0)!=4210686){return}a=c[2394]|0;d=c[14130368+(a<<2)>>2]|0;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[8452240+(a<<2)>>2]=c[2113054];c[2394]=1;c[2112932]=c[3532597];a=c[3532593]|0;if((a|0)!=0){gGC(9104152,a|0,280)|0}c[2113054]=c[2113061];c[2113051]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0<1024){RH(4);d=c[2394]|0;e=d;f=c[14130368+(d<<2)>>2]|0}else{e=1;f=a}if((f|0)!=0){gGC(f|0,9104152,280)|0}c[8452240+(e<<2)>>2]=c[2113054];c[2394]=0;c[2112932]=c[3532596];e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060];return}function es2(b,d){b=b|0;d=d|0;a[(c[3527298]|0)+(b&16383^1)|0]=d;return}function es3(a,d){a=a|0;d=d|0;var e=0,f=0;b[(c[3527298]|0)+(a&16382)>>1]=d;if((a|0)!=4194304){return}a=c[2394]|0;d=c[14130368+(a<<2)>>2]|0;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[8452240+(a<<2)>>2]=c[2113054];c[2394]=0;c[2112932]=c[3532596];a=c[3532592]|0;if((a|0)!=0){gGC(9104152,a|0,280)|0}c[2113054]=c[2113060];c[2113050]=8195;c[2276080]=768;if((c[2276079]|0)>>>0<768){RH(3);d=c[2394]|0;e=d;f=c[14130368+(d<<2)>>2]|0}else{e=0;f=a}if((f|0)!=0){gGC(f|0,9104152,280)|0}c[8452240+(e<<2)>>2]=c[2113054];c[2394]=1;c[2112932]=c[3532597];e=c[3532593]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113061];return}function es4(b,d){b=b|0;d=d|0;a[(c[3527298]|0)+(b&16383^1)|0]=d;return}function es5(a,d){a=a|0;d=d|0;var f=0;f=c[2387160]|0;b[f+(a&65534)>>1]=d;d=a&65535;a=e[f+d>>1]|0;c[(c[3529964]|0)+(d>>>1<<2)>>2]=a>>>5<<11&63488|a&31|(a>>>10<<3|a>>>12&4)<<3&2016;return}function es6(b,d){b=b|0;d=d|0;var f=0;f=c[2387160]|0;a[f+(b&65535^1)|0]=d;d=b&65534;b=e[f+d>>1]|0;c[(c[3529964]|0)+(d>>>1<<2)>>2]=b>>>5<<11&63488|b&31|(b>>>10<<3|b>>>12&4)<<3&2016;return}function es7(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6560508+(b*112|0)>>2];c[a+104>>2]=c[6560512+(b*112|0)>>2];c[a+108>>2]=c[6560516+(b*112|0)>>2];d=0;return d|0}function es8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<22&(d|0)==0)){e=1;return e|0}c[a>>2]=6560408+(b*112|0);e=0;return e|0}function es9(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>24){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5340840+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eta(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>25){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6872976+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function etb(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0;e=i;i=i+1800|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;B=e+1200|0;C=e+1312|0;D=e+1320|0;E=e+1432|0;F=e+1440|0;G=e+1552|0;H=e+1560|0;I=e+1672|0;J=e+1680|0;K=e+1792|0;c[2414928]=0;c[3531120]=0;c[3531108]=2097152;c[2387354]=4194304;c[3530808]=4325376;c[3530572]=6422528;c[3530412]=39976960;c[3527244]=56754176;c[3531292]=56762368;c[2406296]=73539584;c[3529964]=73539712;c[2414630]=73670788;c[3531162]=73670788;c[3531138]=73736324;c[2387358]=73801860;c[3527298]=73867396;c[3529654]=73883780;c[3529608]=73900164;c[3529634]=73901188;c[3529606]=73917572;c[2387160]=73918596;c[3529420]=73984132;c[3529456]=73988228;c[3529822]=73992324;c[3529824]=73996420;c[3529382]=74000516;c[2406734]=74001540;c[2411596]=74001548;L=0;while(1){if((L|0)>=1024){break}M=9638528+(L<<2)|0;if((c[M>>2]|0)==0){N=2440;break}else{L=L+1|0}}do{if((N|0)==2440){L=gGq(74001548)|0;c[M>>2]=L;if((L|0)==0){break}c[2414928]=L;gGz(L|0,0,74001548);c[3531120]=L;c[3531108]=L+2097152;c[2387354]=L+4194304;c[3530808]=L+4325376;c[3530572]=L+6422528;c[3530412]=L+39976960;c[3527244]=L+56754176;c[3531292]=L+56762368;c[2406296]=L+73539584;c[3529964]=L+73539712;O=L+73670788|0;c[2414630]=O;c[3531162]=O;c[3531138]=L+73736324;c[2387358]=L+73801860;c[3527298]=L+73867396;c[3529654]=L+73883780;c[3529608]=L+73900164;c[3529634]=L+73901188;c[3529606]=L+73917572;c[2387160]=L+73918596;c[3529420]=L+73984132;c[3529456]=L+73988228;c[3529822]=L+73992324;c[3529824]=L+73996420;c[3529382]=L+74000516;c[2406734]=L+74001540;O=L+74001548|0;c[2411596]=O;c[2414136]=O;if((R6(L,0,2)|0)!=0){P=1;i=e;return P|0}if((R6((c[3531120]|0)+1|0,1,2)|0)!=0){P=1;i=e;return P|0}if((R6((c[3531120]|0)+1048576|0,2,2)|0)!=0){P=1;i=e;return P|0}if((R6((c[3531120]|0)+1048577|0,3,2)|0)!=0){P=1;i=e;return P|0}if((R6(c[3531108]|0,4,2)|0)!=0){P=1;i=e;return P|0}if((R6((c[3531108]|0)+1|0,5,2)|0)!=0){P=1;i=e;return P|0}L=c[2387354]|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}O=J+108|0;c[O>>2]=0;Q=J+100|0;c[Q>>2]=0;R=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[R&16383](J,6)|0;do{if((c[O>>2]|0)!=0){R=c[Q>>2]|0;c[K>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](K,6,0)|0;if((R|0)<1){P=1;i=e;return P|0}if((gzL(L,0,6)|0)==0){break}else{P=1}i=e;return P|0}}while(0);L=0;Q=c[2387354]|0;while(1){O=a[Q]|0;R=Q+1|0;a[Q]=a[R]|0;a[R]=O;O=L+1|0;if((O|0)<65536){L=O;Q=Q+2|0}else{break}}Q=c[3530808]|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}L=H+108|0;c[L>>2]=0;O=H+100|0;c[O>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](H,7)|0;do{if((c[L>>2]|0)!=0){R=c[O>>2]|0;c[I>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](I,7,0)|0;if((R|0)<1){P=1;i=e;return P|0}if((gzL(Q,0,7)|0)==0){break}else{P=1}i=e;return P|0}}while(0);Q=c[3530572]|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}O=F+108|0;c[O>>2]=0;L=F+100|0;c[L>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](F,8)|0;do{if((c[O>>2]|0)!=0){R=c[L>>2]|0;c[G>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](G,8,0)|0;if((R|0)<1){P=1;i=e;return P|0}if((gzL(Q,0,8)|0)==0){break}else{P=1}i=e;return P|0}}while(0);Q=(c[3530572]|0)+4194304|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}L=D+108|0;c[L>>2]=0;O=D+100|0;c[O>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](D,9)|0;do{if((c[L>>2]|0)!=0){R=c[O>>2]|0;c[E>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](E,9,0)|0;if((R|0)<1){P=1;i=e;return P|0}if((gzL(Q,0,9)|0)==0){break}else{P=1}i=e;return P|0}}while(0);Q=(c[3530572]|0)+8388608|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}O=B+108|0;c[O>>2]=0;L=B+100|0;c[L>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](B,10)|0;do{if((c[O>>2]|0)!=0){R=c[L>>2]|0;c[C>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](C,10,0)|0;if((R|0)<1){P=1;i=e;return P|0}if((gzL(Q,0,10)|0)==0){break}else{P=1}i=e;return P|0}}while(0);Q=(c[3530572]|0)+12582912|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}L=z+108|0;c[L>>2]=0;O=z+100|0;c[O>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,11)|0;do{if((c[L>>2]|0)!=0){R=c[O>>2]|0;c[A>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](A,11,0)|0;if((R|0)<1){P=1;i=e;return P|0}if((gzL(Q,0,11)|0)==0){break}else{P=1}i=e;return P|0}}while(0);Q=(c[3530572]|0)+16777216|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}O=x+108|0;c[O>>2]=0;L=x+100|0;c[L>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,12)|0;do{if((c[O>>2]|0)!=0){R=c[L>>2]|0;c[y>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](y,12,0)|0;if((R|0)<1){P=1;i=e;return P|0}if((gzL(Q,0,12)|0)==0){break}else{P=1}i=e;return P|0}}while(0);Q=(c[3530572]|0)+18874368|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}L=v+108|0;c[L>>2]=0;O=v+100|0;c[O>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,13)|0;do{if((c[L>>2]|0)!=0){R=c[O>>2]|0;c[w>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](w,13,0)|0;if((R|0)<1){P=1;i=e;return P|0}if((gzL(Q,0,13)|0)==0){break}else{P=1}i=e;return P|0}}while(0);Q=(c[3530572]|0)+20971520|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}O=t+108|0;c[O>>2]=0;L=t+100|0;c[L>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,14)|0;do{if((c[O>>2]|0)!=0){R=c[L>>2]|0;c[u>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](u,14,0)|0;if((R|0)<1){P=1;i=e;return P|0}if((gzL(Q,0,14)|0)==0){break}else{P=1}i=e;return P|0}}while(0);if((R6((c[3530572]|0)+23068672|0,15,2)|0)!=0){P=1;i=e;return P|0}if((R6((c[3530572]|0)+23068673|0,16,2)|0)!=0){P=1;i=e;return P|0}Q=c[3530412]|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}L=r+108|0;c[L>>2]=0;O=r+100|0;c[O>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,17)|0;do{if((c[L>>2]|0)!=0){R=c[O>>2]|0;c[s>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](s,17,0)|0;if((R|0)<1){P=1;i=e;return P|0}if((gzL(Q,0,17)|0)==0){break}else{P=1}i=e;return P|0}}while(0);Q=(c[3530412]|0)+2097152|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}O=p+108|0;c[O>>2]=0;L=p+100|0;c[L>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,18)|0;do{if((c[O>>2]|0)!=0){R=c[L>>2]|0;c[q>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](q,18,0)|0;if((R|0)<1){P=1;i=e;return P|0}if((gzL(Q,0,18)|0)==0){break}else{P=1}i=e;return P|0}}while(0);Q=c[3531292]|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}L=n+108|0;c[L>>2]=0;O=n+100|0;c[O>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,19)|0;do{if((c[L>>2]|0)!=0){R=c[O>>2]|0;c[o>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](o,19,0)|0;if((R|0)<1){P=1;i=e;return P|0}if((gzL(Q,0,19)|0)==0){break}else{P=1}i=e;return P|0}}while(0);Q=(c[3531292]|0)+1048576|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}O=l+108|0;c[O>>2]=0;L=l+100|0;c[L>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,19)|0;do{if((c[O>>2]|0)!=0){R=c[L>>2]|0;c[m>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](m,19,0)|0;if((R|0)<1){P=1;i=e;return P|0}if((gzL(Q,0,19)|0)==0){break}else{P=1}i=e;return P|0}}while(0);Q=(c[3531292]|0)+2097152|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}L=j+108|0;c[L>>2]=0;O=j+100|0;c[O>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,20)|0;do{if((c[L>>2]|0)!=0){R=c[O>>2]|0;c[k>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](k,20,0)|0;if((R|0)<1){P=1;i=e;return P|0}if((gzL(Q,0,20)|0)==0){break}else{P=1}i=e;return P|0}}while(0);Q=(c[3531292]|0)+4194304|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}O=f+108|0;c[O>>2]=0;L=f+100|0;c[L>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,21)|0;do{if((c[O>>2]|0)==0){T=0}else{R=c[L>>2]|0;c[g>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](g,21,0)|0;if((R|0)<1){P=1;i=e;return P|0}if((gzL(Q,0,21)|0)==0){T=0;break}else{P=1}i=e;return P|0}}while(0);while(1){if((T|0)>=1024){break}U=9638528+(T<<2)|0;if((c[U>>2]|0)==0){N=2514;break}else{T=T+1|0}}L3517:do{if((N|0)==2514){Q=gGq(1048576)|0;c[U>>2]=Q;if((Q|0)==0){break}gGz(Q|0,0,1048576);L=c[3530808]|0;gGC(Q|0,L|0,1048576)|0;O=0;while(1){R=O<<8;gGz(L+R|0,0,256);S=O<<10;V=0;do{W=1<<3-V;X=(c[703416+(V<<2)>>2]|0)+S|0;Y=0;do{Z=X+(c[3946808+(Y<<2)>>2]|0)|0;_=(Y<<4)+R|0;$=0;do{aa=Z+(c[612576+($<<2)>>2]|0)|0;if((d[Q+((aa|0)/8|0)|0]&128>>>((aa&7)>>>0)|0)!=0){aa=L+(_+$)|0;a[aa]=(d[aa]|W)&255}$=$+1|0;}while(($|0)<16);Y=Y+1|0;}while((Y|0)<16);V=V+1|0;}while((V|0)<4);V=O+1|0;if((V|0)<8192){O=V}else{ab=0;break}}while(1){if((ab|0)>=1024){break L3517}ac=9638528+(ab<<2)|0;if((c[ac>>2]|0)==(Q|0)){break}else{ab=ab+1|0}}gGr(Q);c[ac>>2]=0}}while(0);O=c[2387354]|0;L=0;do{V=O+L|0;a[V]=(a[601112+(L&255^1)|0]|0)+(a[V]|0)&255;L=L+1|0;}while((L|0)<131072);L=c[3527244]|0;gGz(L|0,0,8192);O=c[3530808]|0;V=0;do{R=L+((V|0)/256|0)|0;a[R]=1;S=0;while(1){if((S|0)>=256){break}if((a[O+(S+V)|0]|0)==0){S=S+1|0}else{N=2534;break}}if((N|0)==2534){N=0;a[R]=0}V=V+256|0;}while((V|0)<2097152);fxU(0,425984);if((c[2394]|0)==0){ad=c[2112932]|0}else{c[2394]=0;V=c[3532596]|0;c[2112932]=V;O=c[3532592]|0;if((O|0)!=0){gGC(9104152,O|0,280)|0}c[2113054]=c[2113060];ad=V}V=c[3531120]|0;O=ad|0;L=0;while(1){S=V+L|0;c[O>>2]=S;c[O+131072>>2]=S;S=L+1024|0;if(S>>>0>2097151){break}else{O=O+4|0;L=S}}L=c[3531162]|0;O=ad+8192|0;V=2097152;while(1){S=L+(V-2097152)|0;c[O>>2]=S;c[O+65536>>2]=S;c[O+131072>>2]=S;S=V+1024|0;if(S>>>0>2162687){break}else{O=O+4|0;V=S}}V=c[2387358]|0;O=ad+12288|0;L=3145728;while(1){S=V+(L-3145728)|0;c[O>>2]=S;c[O+65536>>2]=S;c[O+131072>>2]=S;S=L+1024|0;if(S>>>0>3211263){break}else{O=O+4|0;L=S}}L=c[3527298]|0;c[ad+16384>>2]=L;c[ad+81920>>2]=L;c[ad+147456>>2]=L;O=L+1024|0;c[ad+16388>>2]=O;c[ad+81924>>2]=O;c[ad+147460>>2]=O;O=L+2048|0;c[ad+16392>>2]=O;c[ad+81928>>2]=O;c[ad+147464>>2]=O;O=L+3072|0;c[ad+16396>>2]=O;c[ad+81932>>2]=O;c[ad+147468>>2]=O;O=L+4096|0;c[ad+16400>>2]=O;c[ad+81936>>2]=O;c[ad+147472>>2]=O;O=L+5120|0;c[ad+16404>>2]=O;c[ad+81940>>2]=O;c[ad+147476>>2]=O;O=L+6144|0;c[ad+16408>>2]=O;c[ad+81944>>2]=O;c[ad+147480>>2]=O;O=L+7168|0;c[ad+16412>>2]=O;c[ad+81948>>2]=O;c[ad+147484>>2]=O;O=L+8192|0;c[ad+16416>>2]=O;c[ad+81952>>2]=O;c[ad+147488>>2]=O;O=L+9216|0;c[ad+16420>>2]=O;c[ad+81956>>2]=O;c[ad+147492>>2]=O;O=L+10240|0;c[ad+16424>>2]=O;c[ad+81960>>2]=O;c[ad+147496>>2]=O;O=L+11264|0;c[ad+16428>>2]=O;c[ad+81964>>2]=O;c[ad+147500>>2]=O;O=L+12288|0;c[ad+16432>>2]=O;c[ad+81968>>2]=O;c[ad+147504>>2]=O;O=L+13312|0;c[ad+16436>>2]=O;c[ad+81972>>2]=O;c[ad+147508>>2]=O;O=L+14336|0;c[ad+16440>>2]=O;c[ad+81976>>2]=O;c[ad+147512>>2]=O;O=L+15360|0;c[ad+16444>>2]=O;L=ad+81980|0;c[L>>2]=O;c[ad+147516>>2]=O;O=c[3529654]|0;c[ad+20480>>2]=O;c[ad+86016>>2]=O;c[ad+151552>>2]=O;V=O+1024|0;c[ad+20484>>2]=V;c[ad+86020>>2]=V;c[ad+151556>>2]=V;V=O+2048|0;c[ad+20488>>2]=V;c[ad+86024>>2]=V;c[ad+151560>>2]=V;V=O+3072|0;c[ad+20492>>2]=V;c[ad+86028>>2]=V;c[ad+151564>>2]=V;V=O+4096|0;c[ad+20496>>2]=V;c[ad+86032>>2]=V;c[ad+151568>>2]=V;V=O+5120|0;c[ad+20500>>2]=V;c[ad+86036>>2]=V;c[ad+151572>>2]=V;V=O+6144|0;c[ad+20504>>2]=V;c[ad+86040>>2]=V;c[ad+151576>>2]=V;V=O+7168|0;c[ad+20508>>2]=V;c[ad+86044>>2]=V;c[ad+151580>>2]=V;V=O+8192|0;c[ad+20512>>2]=V;c[ad+86048>>2]=V;c[ad+151584>>2]=V;V=O+9216|0;c[ad+20516>>2]=V;c[ad+86052>>2]=V;c[ad+151588>>2]=V;V=O+10240|0;c[ad+20520>>2]=V;c[ad+86056>>2]=V;c[ad+151592>>2]=V;V=O+11264|0;c[ad+20524>>2]=V;c[ad+86060>>2]=V;c[ad+151596>>2]=V;V=O+12288|0;c[ad+20528>>2]=V;c[ad+86064>>2]=V;c[ad+151600>>2]=V;V=O+13312|0;c[ad+20532>>2]=V;c[ad+86068>>2]=V;c[ad+151604>>2]=V;V=O+14336|0;c[ad+20536>>2]=V;c[ad+86072>>2]=V;c[ad+151608>>2]=V;V=O+15360|0;c[ad+20540>>2]=V;c[ad+86076>>2]=V;c[ad+151612>>2]=V;V=c[3529608]|0;c[ad+24576>>2]=V;c[ad+90112>>2]=V;c[ad+155648>>2]=V;V=c[2387160]|0;O=ad+28672|0;S=O;Q=7340032;while(1){Y=V+(Q-7340032)|0;c[S>>2]=Y;c[S+65536>>2]=Y;c[S+131072>>2]=Y;Y=Q+1024|0;if(Y>>>0>7405567){break}else{S=S+4|0;Q=Y}}c[ad+196728>>2]=656;c[ad+196648>>2]=1830;c[ad+196688>>2]=3022;c[ad+196608>>2]=1960;c[L>>2]=1;c[ad+196732>>2]=1760;c[ad+196652>>2]=1136;Q=O;S=7340032;while(1){c[Q+65536>>2]=2;V=S+1024|0;if(V>>>0>7405567){break}else{Q=Q+4|0;S=V}}c[ad+196736>>2]=1418;c[ad+196656>>2]=3034;S=c[3532592]|0;if((S|0)!=0){gGC(S|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fxU(1,425984);if((c[2394]|0)==1){ae=c[2112932]|0}else{c[2394]=1;S=c[3532597]|0;c[2112932]=S;Q=c[3532593]|0;if((Q|0)!=0){gGC(9104152,Q|0,280)|0}c[2113054]=c[2113061];ae=S}S=c[3531108]|0;Q=ae|0;O=0;while(1){L=S+O|0;c[Q>>2]=L;c[Q+131072>>2]=L;L=O+1024|0;if(L>>>0>1048575){break}else{Q=Q+4|0;O=L}}O=c[3531138]|0;Q=ae+4096|0;S=1048576;while(1){L=O+(S-1048576)|0;c[Q>>2]=L;c[Q+65536>>2]=L;c[Q+131072>>2]=L;L=S+1024|0;if(L>>>0>1114111){break}else{Q=Q+4|0;S=L}}S=c[3527298]|0;c[ae+16384>>2]=S;c[ae+147456>>2]=S;Q=S+1024|0;c[ae+16388>>2]=Q;c[ae+81924>>2]=Q;c[ae+147460>>2]=Q;Q=S+2048|0;c[ae+16392>>2]=Q;c[ae+81928>>2]=Q;c[ae+147464>>2]=Q;Q=S+3072|0;c[ae+16396>>2]=Q;c[ae+81932>>2]=Q;c[ae+147468>>2]=Q;Q=S+4096|0;c[ae+16400>>2]=Q;c[ae+81936>>2]=Q;c[ae+147472>>2]=Q;Q=S+5120|0;c[ae+16404>>2]=Q;c[ae+81940>>2]=Q;c[ae+147476>>2]=Q;Q=S+6144|0;c[ae+16408>>2]=Q;c[ae+81944>>2]=Q;c[ae+147480>>2]=Q;Q=S+7168|0;c[ae+16412>>2]=Q;c[ae+81948>>2]=Q;c[ae+147484>>2]=Q;Q=S+8192|0;c[ae+16416>>2]=Q;c[ae+81952>>2]=Q;c[ae+147488>>2]=Q;Q=S+9216|0;c[ae+16420>>2]=Q;c[ae+81956>>2]=Q;c[ae+147492>>2]=Q;Q=S+10240|0;c[ae+16424>>2]=Q;c[ae+81960>>2]=Q;c[ae+147496>>2]=Q;Q=S+11264|0;c[ae+16428>>2]=Q;c[ae+81964>>2]=Q;c[ae+147500>>2]=Q;Q=S+12288|0;c[ae+16432>>2]=Q;c[ae+81968>>2]=Q;c[ae+147504>>2]=Q;Q=S+13312|0;c[ae+16436>>2]=Q;c[ae+81972>>2]=Q;c[ae+147508>>2]=Q;Q=S+14336|0;c[ae+16440>>2]=Q;c[ae+81976>>2]=Q;c[ae+147512>>2]=Q;Q=S+15360|0;c[ae+16444>>2]=Q;c[ae+81980>>2]=Q;c[ae+147516>>2]=Q;Q=c[3529420]|0;c[ae+20480>>2]=Q;c[ae+86016>>2]=Q;c[ae+151552>>2]=Q;S=Q+1024|0;c[ae+20484>>2]=S;c[ae+86020>>2]=S;c[ae+151556>>2]=S;S=Q+2048|0;c[ae+20488>>2]=S;c[ae+86024>>2]=S;c[ae+151560>>2]=S;S=Q+3072|0;c[ae+20492>>2]=S;c[ae+86028>>2]=S;c[ae+151564>>2]=S;S=c[3529456]|0;c[ae+20496>>2]=S;c[ae+86032>>2]=S;c[ae+151568>>2]=S;Q=S+1024|0;c[ae+20500>>2]=Q;c[ae+86036>>2]=Q;c[ae+151572>>2]=Q;Q=S+2048|0;c[ae+20504>>2]=Q;c[ae+86040>>2]=Q;c[ae+151576>>2]=Q;Q=S+3072|0;c[ae+20508>>2]=Q;c[ae+86044>>2]=Q;c[ae+151580>>2]=Q;Q=c[3529822]|0;c[ae+20512>>2]=Q;c[ae+86048>>2]=Q;c[ae+151584>>2]=Q;S=Q+1024|0;c[ae+20516>>2]=S;c[ae+86052>>2]=S;c[ae+151588>>2]=S;S=Q+2048|0;c[ae+20520>>2]=S;c[ae+86056>>2]=S;c[ae+151592>>2]=S;S=Q+3072|0;c[ae+20524>>2]=S;c[ae+86060>>2]=S;c[ae+151596>>2]=S;S=c[3529824]|0;c[ae+20528>>2]=S;c[ae+86064>>2]=S;c[ae+151600>>2]=S;Q=S+1024|0;c[ae+20532>>2]=Q;c[ae+86068>>2]=Q;c[ae+151604>>2]=Q;Q=S+2048|0;c[ae+20536>>2]=Q;c[ae+86072>>2]=Q;c[ae+151608>>2]=Q;Q=S+3072|0;c[ae+20540>>2]=Q;c[ae+86076>>2]=Q;c[ae+151612>>2]=Q;Q=c[3529382]|0;c[ae+24576>>2]=Q;c[ae+90112>>2]=Q;c[ae+155648>>2]=Q;Q=c[3529634]|0;c[ae+28672>>2]=Q;c[ae+94208>>2]=Q;c[ae+159744>>2]=Q;S=Q+1024|0;c[ae+28676>>2]=S;c[ae+94212>>2]=S;c[ae+159748>>2]=S;S=Q+2048|0;c[ae+28680>>2]=S;c[ae+94216>>2]=S;c[ae+159752>>2]=S;S=Q+3072|0;c[ae+28684>>2]=S;c[ae+94220>>2]=S;c[ae+159756>>2]=S;S=Q+4096|0;c[ae+28688>>2]=S;c[ae+94224>>2]=S;c[ae+159760>>2]=S;S=Q+5120|0;c[ae+28692>>2]=S;c[ae+94228>>2]=S;c[ae+159764>>2]=S;S=Q+6144|0;c[ae+28696>>2]=S;c[ae+94232>>2]=S;c[ae+159768>>2]=S;S=Q+7168|0;c[ae+28700>>2]=S;c[ae+94236>>2]=S;c[ae+159772>>2]=S;S=Q+8192|0;c[ae+28704>>2]=S;c[ae+94240>>2]=S;c[ae+159776>>2]=S;S=Q+9216|0;c[ae+28708>>2]=S;c[ae+94244>>2]=S;c[ae+159780>>2]=S;S=Q+10240|0;c[ae+28712>>2]=S;c[ae+94248>>2]=S;c[ae+159784>>2]=S;S=Q+11264|0;c[ae+28716>>2]=S;c[ae+94252>>2]=S;c[ae+159788>>2]=S;S=Q+12288|0;c[ae+28720>>2]=S;c[ae+94256>>2]=S;c[ae+159792>>2]=S;S=Q+13312|0;c[ae+28724>>2]=S;c[ae+94260>>2]=S;c[ae+159796>>2]=S;S=Q+14336|0;c[ae+28728>>2]=S;c[ae+94264>>2]=S;c[ae+159800>>2]=S;S=Q+15360|0;c[ae+28732>>2]=S;c[ae+94268>>2]=S;c[ae+159804>>2]=S;S=c[3529606]|0;c[ae+30720>>2]=S;c[ae+96256>>2]=S;c[ae+161792>>2]=S;c[ae+196728>>2]=306;c[ae+196648>>2]=1226;c[ae+196688>>2]=778;c[ae+196608>>2]=590;c[ae+81920>>2]=1;c[ae+196732>>2]=2758;c[ae+196652>>2]=3344;S=c[3532593]|0;if((S|0)!=0){gGC(S|0,9104152,280)|0}c[2113061]=c[2113054];c[2394]=-1;Uf(16e6,0);h[607287]=1.0;c[2433116]=1;h[607286]=1.0;c[2433114]=2;S=c[642608+(c[2436]<<2)>>2]|0;Q=c[S+128>>2]|0;if((c[S+52>>2]&4|0)==0){c[2113068]=Q;O=c[S+132>>2]|0;c[2113070]=O;c[2443814]=Q;c[2440436]=O;af=Q;ah=O}else{c[2113070]=Q;O=c[S+132>>2]|0;c[2113068]=O;c[2440436]=Q;c[2443814]=O;af=O;ah=Q}Q=ag(af<<1,ah)|0;O=gGq(Q)|0;c[2112926]=O;if((O|0)!=0){gGz(O|0,0,Q|0)}Q=c[2414630]|0;gGz(Q|0,0,(c[2411596]|0)-Q|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];Q=c[3532592]|0;if((Q|0)!=0){gGC(9104152,Q|0,280)|0}c[2113054]=c[2113060]}RI();Q=c[2394]|0;O=c[14130368+(Q<<2)>>2]|0;if((O|0)!=0){gGC(O|0,9104152,280)|0}c[8452240+(Q<<2)>>2]=c[2113054];c[2394]=1;c[2112932]=c[3532597];Q=c[3532593]|0;if((Q|0)!=0){gGC(9104152,Q|0,280)|0}c[2113054]=c[2113061];RI();Q=c[2394]|0;O=c[14130368+(Q<<2)>>2]|0;if((O|0)!=0){gGC(O|0,9104152,280)|0}c[8452240+(Q<<2)>>2]=c[2113054];c[2394]=-1;gGz(14125184,0,668);c[2433532]=0;c[2430402]=0;c[2113010]=0;a[9753304]=0;c[2433552]=0;gGz(c[2430036]|0,0,16384);c[3531316]=4;gGz(c[2430037]|0,0,16384);c[3531337]=4;gGz(c[2430038]|0,0,16384);c[3531358]=4;gGz(c[2430039]|0,0,16384);c[3531379]=4;gGz(c[2430040]|0,0,16384);c[3531400]=4;gGz(c[2430041]|0,0,16384);c[3531421]=4;gGz(c[2430042]|0,0,16384);c[3531442]=4;gGz(c[2430043]|0,0,16384);c[3531463]=4;b[4876600]=0;c[2388358]=0;P=0;i=e;return P|0}}while(0);c[2414928]=0;P=1;i=e;return P|0}function etc(){var a=0,b=0,d=0,e=0,f=0;c[2113070]=0;c[2113068]=0;a=c[2112926]|0;if((a|0)!=0){gGr(a);c[2112926]=0}if((c[2392]|0)>=0){a=0;do{b=14130368+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}b=14130384+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}a=a+1|0;}while((a|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;a=c[2406694]|0;if((a|0)!=0){gGr(a);c[2406694]=0}c[3531294]=0;c[3531292]=0;a=c[2414928]|0;b=0;while(1){if((b|0)>=1024){e=2651;break}f=9638528+(b<<2)|0;if((c[f>>2]|0)==(a|0)){break}else{b=b+1|0}}if((e|0)==2651){c[2414928]=0;return 0}gGr(a);c[f>>2]=0;c[2414928]=0;return 0}function etd(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=(c[2388358]|0)+1|0;c[2388358]=d;if((d|0)>179){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=1;c[2112932]=c[3532597];d=c[3532593]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113061];RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;gGz(14125184,0,668);c[2433532]=0;c[2430402]=0;c[2113010]=0;a[9753304]=0;c[2433552]=0;gGz(c[2430036]|0,0,16384);c[3531316]=4;gGz(c[2430037]|0,0,16384);c[3531337]=4;gGz(c[2430038]|0,0,16384);c[3531358]=4;gGz(c[2430039]|0,0,16384);c[3531379]=4;gGz(c[2430040]|0,0,16384);c[3531400]=4;gGz(c[2430041]|0,0,16384);c[3531421]=4;gGz(c[2430042]|0,0,16384);c[3531442]=4;gGz(c[2430043]|0,0,16384);c[3531463]=4;b[4876600]=0;c[2388358]=0}if((a[9623928]|0)!=0){d=c[2414630]|0;gGz(d|0,0,(c[2411596]|0)-d|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=1;c[2112932]=c[3532597];d=c[3532593]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113061];RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;gGz(14125184,0,668);c[2433532]=0;c[2430402]=0;c[2113010]=0;a[9753304]=0;c[2433552]=0;gGz(c[2430036]|0,0,16384);c[3531316]=4;gGz(c[2430037]|0,0,16384);c[3531337]=4;gGz(c[2430038]|0,0,16384);c[3531358]=4;gGz(c[2430039]|0,0,16384);c[3531379]=4;gGz(c[2430040]|0,0,16384);c[3531400]=4;gGz(c[2430041]|0,0,16384);c[3531421]=4;gGz(c[2430042]|0,0,16384);c[3531442]=4;gGz(c[2430043]|0,0,16384);c[3531463]=4;b[4876600]=0;c[2388358]=0}d=c[2392]|0;if((d|0)>=0){gGz(8452240,0,((d|0)>0?(d<<2)+4|0:4)|0)}c[2113054]=0;d=9550368;c[d>>2]=-1;c[d+4>>2]=-1;d=0;e=-1;f=-1;g=-1;h=-1;do{e=((a[9633072+d|0]&1)<<d^e&65535)&65535;f=((a[9630944+d|0]&1)<<d^f&65535)&65535;g=((a[9629400+d|0]&1)<<d^g&65535)&65535;h=((a[9628904+d|0]&1)<<d^h&65535)&65535;d=d+1|0;}while((d|0)<16);b[4775184]=e;b[4775185]=f;b[4775186]=g;b[4775187]=h;h=0;g=(c[2394]|0)==0;L3684:while(1){if(!g){c[2394]=0;c[2112932]=c[3532596];f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060]}c[2113056]=520;f=RG(520)|0;c[2113054]=(c[2113054]|0)+f;c[2276108]=-1;c[2113056]=-1;f=(h|0)==11;do{if(f){c[8452200+(c[2394]<<2)>>2]=8194;c[2276080]=512;if((c[2276079]|0)>>>0>=512){i=0;break}RH(2);i=0}else{if((h|0)!=240){i=0;break}c[8452200+(c[2394]<<2)>>2]=8193;c[2276080]=256;if((c[2276079]|0)>>>0>=256){i=1;break}RH(1);i=1}}while(0);e=c[2113054]|0;d=c[2113056]|0;j=c[2276108]|0;k=c[2394]|0;l=c[14130368+(k<<2)>>2]|0;if((l|0)!=0){gGC(l|0,9104152,280)|0}c[8452240+(k<<2)>>2]=e;c[2394]=1;c[2112932]=c[3532597];k=c[3532593]|0;if((k|0)!=0){gGC(9104152,k|0,280)|0}k=c[2113061]|0;c[2113054]=k;l=d+e-j-k-d+j|0;c[2113056]=l;j=RG(l)|0;c[2113054]=(c[2113054]|0)+j;c[2276108]=-1;c[2113056]=-1;do{if((b[4876600]|0)!=0){do{if(f){c[8452200+(c[2394]<<2)>>2]=8195;c[2276080]=768;if((c[2276079]|0)>>>0>=768){break}RH(3)}}while(0);if(i){c[8452200+(c[2394]<<2)>>2]=8193;c[2276080]=256;if((c[2276079]|0)>>>0>=256){break}RH(1);break}if((h|0)!=249){break}j=c[2394]|0;c[8452200+(j<<2)>>2]=8194;c[2276080]=512;if((c[2276079]|0)>>>0<512){RH(2);m=c[2394]|0}else{m=j}j=c[14130368+(m<<2)>>2]|0;if((j|0)!=0){gGC(j|0,9104152,280)|0}c[8452240+(m<<2)>>2]=c[2113054];c[2394]=-1;h=250;g=0;continue L3684}}while(0);f=c[2394]|0;j=c[14130368+(f<<2)>>2]|0;if((j|0)!=0){gGC(j|0,9104152,280)|0}c[8452240+(f<<2)>>2]=c[2113054];c[2394]=-1;f=h+1|0;if((f|0)<512){h=f;g=0}else{break}}g=c[2112964]|0;if((g|0)!=0){Ug(g,a[9688]|0?534:0)}if((c[2112968]|0)==0){return 0}ete()|0;return 0}function ete(){var d=0,f=0,g=0,h=0,i=0;if((a[9547320]|0)!=0){d=c[2387160]|0;f=c[3529964]|0;g=0;do{h=e[d+g>>1]|0;c[f+(g>>>1<<2)>>2]=h>>>5<<11&63488|h&31|(h>>>10<<3|h>>>12&4)<<3&2016;g=g+2|0;}while((g|0)<65536);a[9547320]=0}g=ag(c[2113070]|0,c[2113068]|0)|0;f=c[2112926]|0;if((g|0)>0){d=0;while(1){b[f+(d<<1)>>1]=-32768;h=d+1|0;if((h|0)<(g|0)){d=h}else{i=f;break}}}else{i=f}f=c[3529456]|0;d=c[3529824]|0;etj(f,d,0,0);g=c[3529420]|0;h=c[3529822]|0;etj(g,h,1,0);etj(f,d,0,1);etj(g,h,1,1);etj(f,d,0,2);etj(g,h,1,2);etj(f,d,0,3);etj(g,h,1,3);etj(f,d,0,4);etj(g,h,1,4);etj(f,d,0,5);etj(g,h,1,5);etj(f,d,0,6);etj(g,h,1,6);etj(f,d,0,7);etj(g,h,1,7);Tl(i,c[3529634]|0,c[3530412]|0,16777216,c[3529606]|0);Tl(c[2112926]|0,c[3529654]|0,c[3530572]|0,33554432,c[3529608]|0);R8(c[3529964]|0);return 0}function etf(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=i;i=i+80|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;if((d|0)!=0){c[d>>2]=169624}if((b&32|0)!=0){gGz(k|0,0,12);d=c[2414630]|0;c[k>>2]=d;c[k+4>>2]=(c[2411596]|0)-d;c[k+12>>2]=162152;d=c[2076592]|0;gj[d&4095](k)|0}if((b&64|0)!=0){d=h|0;gGz(g|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){l=h+9|0;h=f;m=f|0;n=f+4|0;o=f+12|0;p=g|0;q=g+4|0;r=g+12|0;s=0;do{gGC(d|0,614896,11)|0;a[l]=s+48&255;t=8452256+(s<<2)|0;gGz(h|0,0,12);c[m>>2]=t;c[n>>2]=4;c[o>>2]=164976;gj[c[2076592]&4095](f)|0;if((c[t>>2]|0)!=0){c[p>>2]=c[14130368+(s<<2)>>2];c[q>>2]=c[8452184+(s<<2)>>2];c[r>>2]=d;t=c[2076592]|0;gj[t&4095](g)|0}s=s+1|0;}while((s|0)<=(c[2392]|0))}Ue();gGz(j|0,0,12);c[j>>2]=9753200;c[j+4>>2]=2;c[j+12>>2]=370560;s=c[2076592]|0;gj[s&4095](j)|0}if((b&8|0)!=0){gGz(k|0,0,12);c[k>>2]=c[2406296];c[k+4>>2]=128;c[k+12>>2]=361568;j=c[2076592]|0;gj[j&4095](k)|0}if((b&2|0)==0){i=e;return 0}a[9547320]=1;i=e;return 0}function etg(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5860140+(b*112|0)>>2];c[a+104>>2]=c[5860144+(b*112|0)>>2];c[a+108>>2]=c[5860148+(b*112|0)>>2];d=0;return d|0}function eth(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<22&(d|0)==0)){e=1;return e|0}c[a>>2]=5860040+(b*112|0);e=0;return e|0}function eti(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=25){if((a|0)==0){d=0;return d|0}e=a;f=6872976+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}f=b-26|0;if(f>>>0>2){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;a=6270816+(f*12|0)|0;c[b>>2]=c[a>>2];c[b+4>>2]=c[a+4>>2];c[b+8>>2]=c[a+8>>2];d=0;return d|0}function etj(d,f,g,h){d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;i=d;d=f;f=c[3529382]|0;j=f;k=e[f+8>>1]|0;f=(g|0)!=0;if(((f?16:4096)&~k|0)==0){return}l=g<<1;m=(k&512|0)!=0;n=g<<7;g=(e[j+(2-l<<1)>>1]|0)+(m?-22016-n|0:n+1600|0)|0;n=(k&256|0)!=0;o=((e[j+(3-l<<1)>>1]|0)>>>6)+(n?252:11)|0;l=o&511;if((k&(f?8:2048)|0)!=0){f=c[2113070]|0;if((f|0)<=0){return}k=c[2113068]|0;j=c[3527244]|0;p=c[3530808]|0;q=0;r=c[2112926]|0;while(1){s=q+o|0;t=s&511;u=(e[d+(t<<1)>>1]|0)+g|0;v=u>>>20;if((k+16|0)>0){w=t>>>4<<5;t=s<<4&240;s=u>>>16&15;u=0;do{x=((u>>>4)+v&31|w)<<1;y=b[i+(x<<1)>>1]|0;z=y&65535;A=b[i+((x|1)<<1)>>1]&8191;x=y<<2&1008;y=(z&2|0)!=0?15:0;B=(z&1|0)!=0?240:0;do{if((a[j+A|0]|0)==0){if((z>>>8&7|0)!=(h|0)){break}C=B^t|A<<8;D=u-s|0;E=0;do{F=E+D|0;do{if((F|0)>-1&(F|0)<(k|0)){G=a[p+((E^y)+C)|0]|0;if(G<<24>>24==0){break}b[r+(F<<1)>>1]=(G&255)+x&65535}}while(0);E=E+1|0;}while((E|0)<16)}}while(0);u=u+16|0;}while((u|0)<(k+16|0))}u=q+1|0;if((u|0)<(f|0)){q=u;r=r+(k<<1)|0}else{break}}return}k=g>>>6&511;g=c[3527244]|0;r=c[2112926]|0;q=c[3530808]|0;f=c[2113068]|0;p=c[2113070]|0;j=0;do{d=(((j|0)/32|0)<<4)-l|0;o=(d|0)<-15?d+512|0:d;d=(j<<4&496)-k|0;u=(d|0)<-15?d+512|0:d;L3828:do{if((u|0)<(f|0)&(o|0)<(p|0)){d=j<<1;s=e[i+(d<<1)>>1]|0;t=b[i+((d|1)<<1)>>1]&8191;d=s>>>2&63;w=s&2;v=s&1;if((a[g+t|0]|0)!=0){break}if(n){H=v^1;I=224-o|0}else{H=v;I=o}if(m){J=w^2;K=304-u|0}else{J=w;K=u}if((s>>>8&7|0)!=(h|0)){break}do{if((K|I|0)>-1){if((K|0)>(f-16|0)){break}if((I|0)>(p-16|0)){break}s=(J|0)!=0;if((H|0)==0){if(s){SI(r,t,K,I,d,4,0,0,q);break L3828}else{SG(r,t,K,I,d,4,0,0,q);break L3828}}else{if(s){SM(r,t,K,I,d,4,0,0,q);break L3828}else{SK(r,t,K,I,d,4,0,0,q);break L3828}}}}while(0);s=(J|0)!=0;if((H|0)==0){if(s){SJ(r,t,K,I,d,4,0,0,q);break}else{SH(r,t,K,I,d,4,0,0,q);break}}else{if(s){SN(r,t,K,I,d,4,0,0,q);break}else{SL(r,t,K,I,d,4,0,0,q);break}}}}while(0);j=j+1|0;}while((j|0)<1024);return}function etk(a,b){a=a|0;b=b|0;return}function etl(d,e){d=d|0;e=e|0;var f=0;f=d&16777184;if((f|0)==9175040){if((d|0)==9175068){b[c[2443494]>>1]=e&255}b[(c[3529380]|0)+(d&30)>>1]=e;return}else if((f|0)==9453536){f=((((c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0)*3|0|0)/10|0)-(c[2433530]|0)-(c[2426530]|0)+(c[2076596]|0)|0;if((f|0)>0){Sb(f)}a[(c[3527296]|0)+(d>>>1&15)|0]=e&255;return}else{if((d|0)==10485760){b[c[2388454]>>1]=e;return}else if((d|0)==9306112){a[c[2394698]|0]=e&15;return}else{return}}}function etm(b,d){b=b|0;d=d|0;var e=0;if((b&16777184|0)!=9453536){return}e=((((c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0)*3|0|0)/10|0)-(c[2433530]|0)-(c[2426530]|0)+(c[2076596]|0)|0;if((e|0)>0){Sb(e)}a[(c[3527296]|0)+(b>>>1&15)|0]=d;return}function etn(a){a=a|0;return 0}function eto(a){a=a|0;var d=0;if((a|0)==8388608){d=b[4775180]|0}else if((a|0)==8978432){d=b[4775183]|0}else if((a|0)==9175070){d=b[(c[3529380]|0)+30>>1]|0}else if((a|0)==8912896){d=b[4775182]|0}else if((a|0)==8454144){d=b[4775181]|0}else{d=0}return d|0}function etp(b){b=b|0;var d=0,e=0;if((b&16777184|0)!=9453536){d=0;return d|0}e=((((c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0)*3|0|0)/10|0)-(c[2433530]|0)-(c[2426530]|0)+(c[2076596]|0)|0;if((e|0)>0){Sb(e)}d=a[(c[3527296]|0)+(b>>>1&15)|0]|0;return d|0}function etq(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((e&65520|0)!=32752){return}a[(c[3527296]|0)+(e&15)|0]=d;return}function etr(b){b=b|0;var d=0,e=0;d=b&65535;if((d&65520|0)!=32752){e=0;return e|0}e=a[(c[3527296]|0)+(d&15)|0]|0;return e|0}function ets(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=b&65535;switch(e&255|0){case 0:{a[c[2443932]|0]=d;b=c[2385900]|0;f=c[9757320+(c[1836236]<<2)>>2]|0;g=((d&255)<<15&491520)-32768|0;h=128;i=128;while(1){c[f+76+(i<<2)>>2]=b+(g+(i<<8));j=h+1&65535;if((j&65535)>255){k=128;l=128;break}else{h=j;i=j&65535}}while(1){i=b+(g+(l<<8))|0;c[f+76+(l+512<<2)>>2]=i;c[f+76+(l+768<<2)>>2]=i;i=k+1&65535;if((i&65535)>255){break}else{k=i;l=i&65535}}return};case 65:case 67:case 69:{l=e>>>1&3;if((l|0)==2){Vy(gj[c[2426988]&4095](a[9680]|0?32e3:0)|0);mp(d);return}else if((l|0)==0){Vy(gj[c[2426988]&4095](a[9680]|0?32e3:0)|0);mo(d);return}else{return}break};case 64:case 66:case 68:{l=e>>>1&3;if((l|0)==2){a[14127338]=d;return}else if((l|0)==0){a[14127336]=d;return}else if((l|0)==1){a[14127337]=d;return}else{return}break};default:{return}}}function ett(b){b=b|0;var d=0;if((b&255)!=64){d=0;return d|0}Vy(gj[c[2426988]&4095](a[9680]|0?32e3:0)|0);d=((c[3531833]|0)==1?-128:0)|a[14127331];return d|0}function etu(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3134660+(b*112|0)>>2];c[a+104>>2]=c[3134664+(b*112|0)>>2];c[a+108>>2]=c[3134668+(b*112|0)>>2];d=0;return d|0}function etv(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=3134560+(b*112|0);e=0;return e|0}function etw(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1314240+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function etx(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>54){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4261320+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function ety(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0;e=i;i=i+2520|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;B=e+1200|0;C=e+1312|0;D=e+1320|0;E=e+1432|0;F=e+1440|0;G=e+1552|0;H=e+1560|0;I=e+1672|0;J=e+1680|0;K=e+1792|0;L=e+1800|0;M=e+1912|0;N=e+1920|0;O=e+2032|0;P=e+2040|0;Q=e+2152|0;R=e+2160|0;S=e+2272|0;T=e+2280|0;U=e+2392|0;V=e+2400|0;W=e+2512|0;c[2414926]=0;c[2388122]=0;c[2385900]=2097152;c[2443384]=2621440;c[2443380]=2654208;c[2443376]=2686976;c[3530806]=2752512;c[3530570]=69861376;c[3530410]=78249984;c[3530322]=86638592;c[2386624]=90832896;c[3529962]=95027200;c[2443480]=95059968;c[2443494]=95064064;c[2414628]=95064066;c[3529380]=95064066;c[3527296]=95065090;c[2386054]=95065106;c[2388250]=95069202;c[2387158]=95200274;c[2387852]=95216658;c[2387850]=95224850;c[2387976]=95355922;c[2387970]=95364114;c[2386428]=95372306;c[3529684]=95380498;c[3529676]=95388690;c[2394698]=95396882;c[2388454]=95396883;c[2440190]=95396885;c[2443932]=95396889;c[2411594]=95396890;X=0;while(1){if((X|0)>=1024){break}Y=9638528+(X<<2)|0;if((c[Y>>2]|0)==0){Z=2918;break}else{X=X+1|0}}do{if((Z|0)==2918){X=gGq(95396890)|0;c[Y>>2]=X;if((X|0)==0){break}c[2414926]=X;gGz(X|0,0,95396890);c[2388122]=X;c[2385900]=X+2097152;c[2443384]=X+2621440;c[2443380]=X+2654208;c[2443376]=X+2686976;c[3530806]=X+2752512;c[3530570]=X+69861376;c[3530410]=X+78249984;c[3530322]=X+86638592;c[2386624]=X+90832896;c[3529962]=X+95027200;c[2443480]=X+95059968;c[2443494]=X+95064064;_=X+95064066|0;c[2414628]=_;c[3529380]=_;c[3527296]=X+95065090;c[2386054]=X+95065106;c[2388250]=X+95069202;c[2387158]=X+95200274;c[2387852]=X+95216658;c[2387850]=X+95224850;c[2387976]=X+95355922;c[2387970]=X+95364114;c[2386428]=X+95372306;c[3529684]=X+95380498;c[3529676]=X+95388690;c[2394698]=X+95396882;c[2388454]=X+95396883;c[2440190]=X+95396885;c[2443932]=X+95396889;_=X+95396890|0;c[2411594]=_;c[2414134]=_;if((R6(X+1|0,0,4)|0)!=0){$=1;i=e;return $|0}if((R6(c[2388122]|0,1,4)|0)!=0){$=1;i=e;return $|0}if((R6((c[2388122]|0)+3|0,2,4)|0)!=0){$=1;i=e;return $|0}if((R6((c[2388122]|0)+2|0,3,4)|0)!=0){$=1;i=e;return $|0}X=c[2385900]|0;if((c[3542200]|0)==0){$=1;i=e;return $|0}_=V+108|0;c[_>>2]=0;aa=V+100|0;c[aa>>2]=0;ab=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ab&16383](V,4)|0;do{if((c[_>>2]|0)!=0){ab=c[aa>>2]|0;c[W>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](W,4,0)|0;if((ab|0)<1){$=1;i=e;return $|0}if((gzL(X,0,4)|0)==0){break}else{$=1}i=e;return $|0}}while(0);X=c[2386624]|0;if((c[3542200]|0)==0){$=1;i=e;return $|0}aa=T+108|0;c[aa>>2]=0;_=T+100|0;c[_>>2]=0;ab=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ab&16383](T,5)|0;do{if((c[aa>>2]|0)!=0){ab=c[_>>2]|0;c[U>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](U,5,0)|0;if((ab|0)<1){$=1;i=e;return $|0}if((gzL(X,0,5)|0)==0){break}else{$=1}i=e;return $|0}}while(0);X=c[3530570]|0;if((c[3542200]|0)==0){$=1;i=e;return $|0}_=R+108|0;c[_>>2]=0;aa=R+100|0;c[aa>>2]=0;ab=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ab&16383](R,6)|0;do{if((c[_>>2]|0)!=0){ab=c[aa>>2]|0;c[S>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](S,6,0)|0;if((ab|0)<1){$=1;i=e;return $|0}if((gzL(X,0,6)|0)==0){break}else{$=1}i=e;return $|0}}while(0);X=(c[3530570]|0)+4194304|0;if((c[3542200]|0)==0){$=1;i=e;return $|0}aa=P+108|0;c[aa>>2]=0;_=P+100|0;c[_>>2]=0;ab=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ab&16383](P,7)|0;do{if((c[aa>>2]|0)!=0){ab=c[_>>2]|0;c[Q>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](Q,7,0)|0;if((ab|0)<1){$=1;i=e;return $|0}if((gzL(X,0,7)|0)==0){break}else{$=1}i=e;return $|0}}while(0);X=c[3530410]|0;if((c[3542200]|0)==0){$=1;i=e;return $|0}_=N+108|0;c[_>>2]=0;aa=N+100|0;c[aa>>2]=0;ab=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ab&16383](N,8)|0;do{if((c[_>>2]|0)!=0){ab=c[aa>>2]|0;c[O>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](O,8,0)|0;if((ab|0)<1){$=1;i=e;return $|0}if((gzL(X,0,8)|0)==0){break}else{$=1}i=e;return $|0}}while(0);X=(c[3530410]|0)+4194304|0;if((c[3542200]|0)==0){$=1;i=e;return $|0}aa=L+108|0;c[aa>>2]=0;_=L+100|0;c[_>>2]=0;ab=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ab&16383](L,9)|0;do{if((c[aa>>2]|0)!=0){ab=c[_>>2]|0;c[M>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](M,9,0)|0;if((ab|0)<1){$=1;i=e;return $|0}if((gzL(X,0,9)|0)==0){break}else{$=1}i=e;return $|0}}while(0);X=c[3530322]|0;if((c[3542200]|0)==0){$=1;i=e;return $|0}_=J+108|0;c[_>>2]=0;aa=J+100|0;c[aa>>2]=0;ab=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ab&16383](J,10)|0;do{if((c[_>>2]|0)!=0){ab=c[aa>>2]|0;c[K>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](K,10,0)|0;if((ab|0)<1){$=1;i=e;return $|0}if((gzL(X,0,10)|0)==0){break}else{$=1}i=e;return $|0}}while(0);X=c[642608+(c[2436]<<2)>>2]|0;aa=(fa(c[X>>2]|0,232816)|0)==0;_=c[3530806]|0;do{if(aa){ab=_+4194304|0;if((c[3542200]|0)==0){$=1;i=e;return $|0}ac=H+108|0;c[ac>>2]=0;ad=H+100|0;c[ad>>2]=0;ae=c[X+76>>2]|0;gA[ae&16383](H,11)|0;do{if((c[ac>>2]|0)!=0){ae=c[ad>>2]|0;c[I>>2]=9534384;af=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[af&16383](I,11,0)|0;if((ae|0)<1){$=1;i=e;return $|0}if((gzL(ab,0,11)|0)==0){break}else{$=1}i=e;return $|0}}while(0);ab=(c[3530806]|0)+8388608|0;if((c[3542200]|0)==0){$=1;i=e;return $|0}ad=F+108|0;c[ad>>2]=0;ac=F+100|0;c[ac>>2]=0;ae=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ae&16383](F,12)|0;do{if((c[ad>>2]|0)!=0){ae=c[ac>>2]|0;c[G>>2]=9534384;af=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[af&16383](G,12,0)|0;if((ae|0)<1){$=1;i=e;return $|0}if((gzL(ab,0,12)|0)==0){break}else{$=1}i=e;return $|0}}while(0);ab=(c[3530806]|0)+12582912|0;if((c[3542200]|0)==0){$=1;i=e;return $|0}ac=D+108|0;c[ac>>2]=0;ad=D+100|0;c[ad>>2]=0;ae=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ae&16383](D,13)|0;do{if((c[ac>>2]|0)!=0){ae=c[ad>>2]|0;c[E>>2]=9534384;af=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[af&16383](E,13,0)|0;if((ae|0)<1){$=1;i=e;return $|0}if((gzL(ab,0,13)|0)==0){break}else{$=1}i=e;return $|0}}while(0);ab=(c[3530806]|0)+16777216|0;if((c[3542200]|0)==0){$=1;i=e;return $|0}ad=B+108|0;c[ad>>2]=0;ac=B+100|0;c[ac>>2]=0;ae=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ae&16383](B,14)|0;do{if((c[ad>>2]|0)!=0){ae=c[ac>>2]|0;c[C>>2]=9534384;af=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[af&16383](C,14,0)|0;if((ae|0)<1){$=1;i=e;return $|0}if((gzL(ab,0,14)|0)==0){break}else{$=1}i=e;return $|0}}while(0);ab=(c[3530806]|0)+20971520|0;if((c[3542200]|0)==0){$=1;i=e;return $|0}ac=z+108|0;c[ac>>2]=0;ad=z+100|0;c[ad>>2]=0;ae=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ae&16383](z,15)|0;do{if((c[ac>>2]|0)!=0){ae=c[ad>>2]|0;c[A>>2]=9534384;af=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[af&16383](A,15,0)|0;if((ae|0)<1){$=1;i=e;return $|0}if((gzL(ab,0,15)|0)==0){break}else{$=1}i=e;return $|0}}while(0);ab=(c[3530806]|0)+25165824|0;if((c[3542200]|0)==0){$=1;i=e;return $|0}ad=x+108|0;c[ad>>2]=0;ac=x+100|0;c[ac>>2]=0;ae=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ae&16383](x,16)|0;if((c[ad>>2]|0)==0){break}ad=c[ac>>2]|0;c[y>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](y,16,0)|0;if((ad|0)<1){$=1;i=e;return $|0}if((gzL(ab,0,16)|0)==0){break}else{$=1}i=e;return $|0}else{if((c[3542200]|0)==0){$=1;i=e;return $|0}ab=v+108|0;c[ab>>2]=0;ad=v+100|0;c[ad>>2]=0;ac=c[X+76>>2]|0;gA[ac&16383](v,11)|0;do{if((c[ab>>2]|0)!=0){ac=c[ad>>2]|0;c[w>>2]=9534384;ae=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ae&16383](w,11,0)|0;if((ac|0)<1){$=1;i=e;return $|0}if((gzL(_,0,11)|0)==0){break}else{$=1}i=e;return $|0}}while(0);ad=(c[3530806]|0)+4194304|0;if((c[3542200]|0)==0){$=1;i=e;return $|0}ab=t+108|0;c[ab>>2]=0;ac=t+100|0;c[ac>>2]=0;ae=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ae&16383](t,12)|0;do{if((c[ab>>2]|0)!=0){ae=c[ac>>2]|0;c[u>>2]=9534384;af=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[af&16383](u,12,0)|0;if((ae|0)<1){$=1;i=e;return $|0}if((gzL(ad,0,12)|0)==0){break}else{$=1}i=e;return $|0}}while(0);ad=(c[3530806]|0)+8388608|0;if((c[3542200]|0)==0){$=1;i=e;return $|0}ac=r+108|0;c[ac>>2]=0;ab=r+100|0;c[ab>>2]=0;ae=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ae&16383](r,13)|0;do{if((c[ac>>2]|0)!=0){ae=c[ab>>2]|0;c[s>>2]=9534384;af=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[af&16383](s,13,0)|0;if((ae|0)<1){$=1;i=e;return $|0}if((gzL(ad,0,13)|0)==0){break}else{$=1}i=e;return $|0}}while(0);ad=(c[3530806]|0)+12582912|0;if((c[3542200]|0)==0){$=1;i=e;return $|0}ab=p+108|0;c[ab>>2]=0;ac=p+100|0;c[ac>>2]=0;ae=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ae&16383](p,14)|0;do{if((c[ab>>2]|0)!=0){ae=c[ac>>2]|0;c[q>>2]=9534384;af=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[af&16383](q,14,0)|0;if((ae|0)<1){$=1;i=e;return $|0}if((gzL(ad,0,14)|0)==0){break}else{$=1}i=e;return $|0}}while(0);ad=(c[3530806]|0)+16777216|0;if((c[3542200]|0)==0){$=1;i=e;return $|0}ac=n+108|0;c[ac>>2]=0;ab=n+100|0;c[ab>>2]=0;ae=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ae&16383](n,15)|0;do{if((c[ac>>2]|0)!=0){ae=c[ab>>2]|0;c[o>>2]=9534384;af=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[af&16383](o,15,0)|0;if((ae|0)<1){$=1;i=e;return $|0}if((gzL(ad,0,15)|0)==0){break}else{$=1}i=e;return $|0}}while(0);ad=(c[3530806]|0)+20971520|0;if((c[3542200]|0)==0){$=1;i=e;return $|0}ab=l+108|0;c[ab>>2]=0;ac=l+100|0;c[ac>>2]=0;ae=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ae&16383](l,16)|0;do{if((c[ab>>2]|0)!=0){ae=c[ac>>2]|0;c[m>>2]=9534384;af=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[af&16383](m,16,0)|0;if((ae|0)<1){$=1;i=e;return $|0}if((gzL(ad,0,16)|0)==0){break}else{$=1}i=e;return $|0}}while(0);ad=(c[3530806]|0)+25165824|0;if((c[3542200]|0)==0){$=1;i=e;return $|0}ac=j+108|0;c[ac>>2]=0;ab=j+100|0;c[ab>>2]=0;ae=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ae&16383](j,17)|0;do{if((c[ac>>2]|0)!=0){ae=c[ab>>2]|0;c[k>>2]=9534384;af=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[af&16383](k,17,0)|0;if((ae|0)<1){$=1;i=e;return $|0}if((gzL(ad,0,17)|0)==0){break}else{$=1}i=e;return $|0}}while(0);ad=(c[3530806]|0)+29360128|0;if((c[3542200]|0)==0){$=1;i=e;return $|0}ab=f+108|0;c[ab>>2]=0;ac=f+100|0;c[ac>>2]=0;ae=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ae&16383](f,18)|0;if((c[ab>>2]|0)==0){break}ab=c[ac>>2]|0;c[g>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](g,18,0)|0;if((ab|0)<1){$=1;i=e;return $|0}if((gzL(ad,0,18)|0)==0){break}else{$=1}i=e;return $|0}}while(0);_=c[3530806]|0;X=_+33554432|0;aa=c[3530570]|0;gGC(X|0,aa|0,8388608)|0;ad=0;do{ab=ad<<8;gGz(aa+ab|0,0,256);ac=ad<<10;ae=0;do{af=1<<7-ae;ah=(c[613120+(ae<<2)>>2]|0)+ac|0;ai=0;do{aj=ah+(c[611904+(ai<<2)>>2]|0)|0;ak=(ai<<4)+ab|0;al=0;do{am=aj+(c[610544+(al<<2)>>2]|0)|0;if(((d[_+(((am|0)/8|0)+33554432)|0]|0)&128>>>((am&7)>>>0)|0)!=0){am=aa+(ak+al)|0;a[am]=(d[am]|0|af)&255}al=al+1|0;}while((al|0)<16);ai=ai+1|0;}while((ai|0)<16);ae=ae+1|0;}while((ae|0)<8);ad=ad+1|0;}while((ad|0)<32768);ad=c[3530410]|0;gGC(X|0,ad|0,8388608)|0;ae=0;do{ab=ae<<8;gGz(ad+ab|0,0,256);ac=ae<<10;ai=0;do{af=1<<7-ai;ah=(c[613120+(ai<<2)>>2]|0)+ac|0;al=0;do{ak=ah+(c[611904+(al<<2)>>2]|0)|0;aj=(al<<4)+ab|0;am=0;do{an=ak+(c[610544+(am<<2)>>2]|0)|0;if(((d[_+(((an|0)/8|0)+33554432)|0]|0)&128>>>((an&7)>>>0)|0)!=0){an=ad+(aj+am)|0;a[an]=(d[an]|0|af)&255}am=am+1|0;}while((am|0)<16);al=al+1|0;}while((al|0)<16);ai=ai+1|0;}while((ai|0)<8);ae=ae+1|0;}while((ae|0)<32768);ae=c[3530322]|0;gGC(X|0,ae|0,2097152)|0;ai=0;while(1){ab=ai<<6;gGz(ae+ab|0,0,64);ac=ai<<8;al=0;do{af=1<<3-al;ah=(c[613120+(al<<2)>>2]|0)+ac|0;am=0;do{aj=ah+(c[1183816+(am<<2)>>2]|0)|0;ak=(am<<3)+ab|0;an=0;do{ao=aj+(c[610544+(an<<2)>>2]|0)|0;if(((d[_+(((ao|0)/8|0)+33554432)|0]|0)&128>>>((ao&7)>>>0)|0)!=0){ao=ae+(ak+an)|0;a[ao]=(d[ao]|0|af)&255}an=an+1|0;}while((an|0)<8);am=am+1|0;}while((am|0)<8);al=al+1|0;}while((al|0)<4);al=ai+1|0;if((al|0)<65536){ai=al}else{ap=0;aq=_;break}}while(1){ai=a[aq]|0;X=aq+1|0;a[aq]=a[X]|0;a[X]=ai;ai=ap+1|0;if((ai|0)<33554432){ap=ai;aq=aq+2|0}else{ar=33554304;break}}do{ai=ar|127;X=a[_+ai|0]|0;al=ai<<1;a[_+al|0]=(X&255)>>>4;a[_+(al|1)|0]=X&15;X=127;do{X=X-1|0;al=X+ar|0;ai=a[_+al|0]|0;ab=al<<1;a[_+ab|0]=(ai&255)>>>4;a[_+(ab|1)|0]=ai&15;}while((X|0)>0);ar=ar-128|0;}while((ar|0)>-1);_=c[2443384]|0;X=0;while(1){ai=0;ab=0;al=0;do{ac=a[aa+(al+X)|0]|0;ai=ac&255^255|ai;ab=(ac<<24>>24!=-1)+ab|0;al=al+1|0;}while((al|0)<256);a[_]=(ab|0)==256|((ai|0)!=0?0:2);al=X+256|0;if((al|0)<8388608){_=_+1|0;X=al}else{break}}X=c[2443380]|0;_=0;while(1){aa=0;al=0;ac=0;do{am=a[ad+(ac+_)|0]|0;aa=am&255^255|aa;al=(am<<24>>24!=-1)+al|0;ac=ac+1|0;}while((ac|0)<256);a[X]=(al|0)==256|((aa|0)!=0?0:2);ac=_+256|0;if((ac|0)<8388608){X=X+1|0;_=ac}else{break}}_=c[2443376]|0;X=0;while(1){ad=0;ac=0;ai=0;do{ab=a[ae+(ai+X)|0]|0;ad=ab&255^15|ad;ac=(ab<<24>>24!=15)+ac|0;ai=ai+1|0;}while((ai|0)<64);a[_]=(ac|0)==64|((ad|0)!=0?0:2);ai=X+64|0;if((ai|0)<4194304){_=_+1|0;X=ai}else{break}}fxU(0,110018592);if((c[2394]|0)==0){as=c[2112932]|0}else{c[2394]=0;X=c[3532596]|0;c[2112932]=X;_=c[3532592]|0;if((_|0)!=0){gGC(9104152,_|0,280)|0}c[2113054]=c[2113060];as=X}X=c[2388122]|0;_=as|0;ae=0;while(1){ai=X+ae|0;c[_>>2]=ai;c[_+131072>>2]=ai;ai=ae+1024|0;if(ai>>>0>2097151){break}else{_=_+4|0;ae=ai}}ae=c[2388250]|0;_=as+16384|0;X=4194304;while(1){ai=ae+(X-4194304)|0;c[_>>2]=ai;c[_+65536>>2]=ai;c[_+131072>>2]=ai;ai=X+1024|0;if(ai>>>0>4259839){break}else{_=_+4|0;X=ai}}X=as+16640|0;_=4259840;while(1){ai=ae+(_-4259840)|0;c[X>>2]=ai;c[X+65536>>2]=ai;c[X+131072>>2]=ai;ai=_+1024|0;if(ai>>>0>4325375){break}else{X=X+4|0;_=ai}}_=c[2387976]|0;c[as+20480>>2]=_;c[as+86016>>2]=_;c[as+151552>>2]=_;X=_+1024|0;c[as+20484>>2]=X;c[as+86020>>2]=X;c[as+151556>>2]=X;X=_+2048|0;c[as+20488>>2]=X;c[as+86024>>2]=X;c[as+151560>>2]=X;X=_+3072|0;c[as+20492>>2]=X;c[as+86028>>2]=X;c[as+151564>>2]=X;X=_+4096|0;c[as+20496>>2]=X;c[as+86032>>2]=X;c[as+151568>>2]=X;X=_+5120|0;c[as+20500>>2]=X;c[as+86036>>2]=X;c[as+151572>>2]=X;X=_+6144|0;c[as+20504>>2]=X;c[as+86040>>2]=X;c[as+151576>>2]=X;X=_+7168|0;c[as+20508>>2]=X;c[as+86044>>2]=X;c[as+151580>>2]=X;X=c[2387970]|0;c[as+20512>>2]=X;c[as+86048>>2]=X;c[as+151584>>2]=X;_=X+1024|0;c[as+20516>>2]=_;c[as+86052>>2]=_;c[as+151588>>2]=_;_=X+2048|0;c[as+20520>>2]=_;c[as+86056>>2]=_;c[as+151592>>2]=_;_=X+3072|0;c[as+20524>>2]=_;c[as+86060>>2]=_;c[as+151596>>2]=_;_=X+4096|0;c[as+20528>>2]=_;c[as+86064>>2]=_;c[as+151600>>2]=_;_=X+5120|0;c[as+20532>>2]=_;c[as+86068>>2]=_;c[as+151604>>2]=_;_=X+6144|0;c[as+20536>>2]=_;c[as+86072>>2]=_;c[as+151608>>2]=_;_=X+7168|0;c[as+20540>>2]=_;c[as+86076>>2]=_;c[as+151612>>2]=_;_=c[2387852]|0;c[as+20544>>2]=_;c[as+86080>>2]=_;c[as+151616>>2]=_;X=_+1024|0;c[as+20548>>2]=X;c[as+86084>>2]=X;c[as+151620>>2]=X;X=_+2048|0;c[as+20552>>2]=X;c[as+86088>>2]=X;c[as+151624>>2]=X;X=_+3072|0;c[as+20556>>2]=X;c[as+86092>>2]=X;c[as+151628>>2]=X;X=_+4096|0;c[as+20560>>2]=X;c[as+86096>>2]=X;c[as+151632>>2]=X;X=_+5120|0;c[as+20564>>2]=X;c[as+86100>>2]=X;c[as+151636>>2]=X;X=_+6144|0;c[as+20568>>2]=X;c[as+86104>>2]=X;c[as+151640>>2]=X;X=_+7168|0;c[as+20572>>2]=X;c[as+86108>>2]=X;c[as+151644>>2]=X;X=c[2387850]|0;c[as+20576>>2]=X;c[as+86112>>2]=X;c[as+151648>>2]=X;_=X+1024|0;c[as+20580>>2]=_;c[as+86116>>2]=_;c[as+151652>>2]=_;_=X+2048|0;c[as+20584>>2]=_;c[as+86120>>2]=_;c[as+151656>>2]=_;_=X+3072|0;c[as+20588>>2]=_;c[as+86124>>2]=_;c[as+151660>>2]=_;_=X+4096|0;c[as+20592>>2]=_;c[as+86128>>2]=_;c[as+151664>>2]=_;_=X+5120|0;c[as+20596>>2]=_;c[as+86132>>2]=_;c[as+151668>>2]=_;_=X+6144|0;c[as+20600>>2]=_;c[as+86136>>2]=_;c[as+151672>>2]=_;_=X+7168|0;c[as+20604>>2]=_;c[as+86140>>2]=_;c[as+151676>>2]=_;_=as+20608|0;ae=5275648;while(1){ai=X+(ae-5267456)|0;c[_>>2]=ai;c[_+65536>>2]=ai;c[_+131072>>2]=ai;ai=ae+1024|0;if(ai>>>0>5341183){break}else{_=_+4|0;ae=ai}}ae=c[2386428]|0;c[as+24576>>2]=ae;c[as+90112>>2]=ae;c[as+155648>>2]=ae;_=ae+1024|0;c[as+24580>>2]=_;c[as+90116>>2]=_;c[as+155652>>2]=_;_=ae+2048|0;c[as+24584>>2]=_;c[as+90120>>2]=_;c[as+155656>>2]=_;_=ae+3072|0;c[as+24588>>2]=_;c[as+90124>>2]=_;c[as+155660>>2]=_;_=ae+4096|0;c[as+24592>>2]=_;c[as+90128>>2]=_;c[as+155664>>2]=_;_=ae+5120|0;c[as+24596>>2]=_;c[as+90132>>2]=_;c[as+155668>>2]=_;_=ae+6144|0;c[as+24600>>2]=_;c[as+90136>>2]=_;c[as+155672>>2]=_;_=ae+7168|0;c[as+24604>>2]=_;c[as+90140>>2]=_;c[as+155676>>2]=_;_=c[2387158]|0;c[as+28672>>2]=_;c[as+94208>>2]=_;c[as+159744>>2]=_;ae=_+1024|0;c[as+28676>>2]=ae;c[as+94212>>2]=ae;c[as+159748>>2]=ae;ae=_+2048|0;c[as+28680>>2]=ae;c[as+94216>>2]=ae;c[as+159752>>2]=ae;ae=_+3072|0;c[as+28684>>2]=ae;c[as+94220>>2]=ae;c[as+159756>>2]=ae;ae=_+4096|0;c[as+28688>>2]=ae;c[as+94224>>2]=ae;c[as+159760>>2]=ae;ae=_+5120|0;c[as+28692>>2]=ae;c[as+94228>>2]=ae;c[as+159764>>2]=ae;ae=_+6144|0;c[as+28696>>2]=ae;c[as+94232>>2]=ae;c[as+159768>>2]=ae;ae=_+7168|0;c[as+28700>>2]=ae;c[as+94236>>2]=ae;c[as+159772>>2]=ae;ae=_+8192|0;c[as+28704>>2]=ae;c[as+94240>>2]=ae;c[as+159776>>2]=ae;ae=_+9216|0;c[as+28708>>2]=ae;c[as+94244>>2]=ae;c[as+159780>>2]=ae;ae=_+10240|0;c[as+28712>>2]=ae;c[as+94248>>2]=ae;c[as+159784>>2]=ae;ae=_+11264|0;c[as+28716>>2]=ae;c[as+94252>>2]=ae;c[as+159788>>2]=ae;ae=_+12288|0;c[as+28720>>2]=ae;c[as+94256>>2]=ae;c[as+159792>>2]=ae;ae=_+13312|0;c[as+28724>>2]=ae;c[as+94260>>2]=ae;c[as+159796>>2]=ae;ae=_+14336|0;c[as+28728>>2]=ae;c[as+94264>>2]=ae;c[as+159800>>2]=ae;ae=_+15360|0;c[as+28732>>2]=ae;c[as+94268>>2]=ae;c[as+159804>>2]=ae;c[as+196808>>2]=1350;c[as+196728>>2]=3038;c[as+196648>>2]=2652;c[as+196768>>2]=238;c[as+196688>>2]=2320;c[as+196608>>2]=2140;ae=c[3532592]|0;if((ae|0)!=0){gGC(ae|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);ae=c[2439330]|0;_=(ae|0)==0;if(!_){X=ae;gGC(9706056,X|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];X=c[3528484]|0;c[2076596]=X;ai=c[2417276]|0;c[3541536]=ai;c[1836236]=0;aa=c[2385900]|0;al=0;ab=0;while(1){c[ae+76+(ab<<2)>>2]=aa+(ab<<8);am=al+1&65535;if((am&65535)>95){at=0;au=0;break}else{al=am;ab=am&65535}}while(1){ab=aa+(au<<8)|0;c[ae+76+(au+512<<2)>>2]=ab;c[ae+76+(au+768<<2)>>2]=ab;ab=at+1&65535;if((ab&65535)>95){break}else{at=ab;au=ab&65535}}ab=c[2386054]|0;c[ae+460>>2]=ab;c[ae+464>>2]=ab+256;c[ae+468>>2]=ab+512;c[ae+472>>2]=ab+768;c[ae+476>>2]=ab+1024;c[ae+480>>2]=ab+1280;c[ae+484>>2]=ab+1536;c[ae+488>>2]=ab+1792;c[ae+492>>2]=ab+2048;c[ae+496>>2]=ab+2304;c[ae+500>>2]=ab+2560;c[ae+504>>2]=ab+2816;c[ae+508>>2]=ab+3072;c[ae+512>>2]=ab+3328;c[ae+516>>2]=ab+3584;c[ae+520>>2]=ab+3840;al=96;am=96;while(1){c[ae+76+(am+256<<2)>>2]=ab+((am<<8)-24576);af=al+1&65535;if((af&65535)>111){av=96;aw=96;break}else{al=af;am=af&65535}}while(1){am=ab+((aw<<8)-24576)|0;c[ae+76+(aw+512<<2)>>2]=am;c[ae+76+(aw+768<<2)>>2]=am;am=av+1&65535;if((am&65535)>111){ax=128;ay=128;break}else{av=am;aw=am&65535}}while(1){c[ae+76+(ay<<2)>>2]=aa+(ay<<8);ab=ax+1&65535;if((ab&65535)>255){az=128;aA=128;break}else{ax=ab;ay=ab&65535}}while(1){ab=aa+(aA<<8)|0;c[ae+76+(aA+512<<2)>>2]=ab;c[ae+76+(aA+768<<2)>>2]=ab;ab=az+1&65535;if((ab&65535)>255){break}else{az=ab;aA=ab&65535}}c[ae+4184>>2]=2002;c[ae+4180>>2]=2620;c[ae+4176>>2]=3104;c[ae+4172>>2]=2336;if(!_){aa=ae;gGC(aa|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=X;c[2417276]=ai;c[1836236]=-1;Vz(c[2386624]|0,200,2510);h[607289]=.5;c[2433120]=1;h[607288]=.5;c[2433118]=2;c[2438228]=6e6;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=340;aa=c[642608+(c[2436]<<2)>>2]|0;ab=c[aa+128>>2]|0;if((c[aa+52>>2]&4|0)==0){c[2113068]=ab;am=c[aa+132>>2]|0;c[2113070]=am;c[2443814]=ab;c[2440436]=am;aB=ab;aC=am}else{c[2113070]=ab;am=c[aa+132>>2]|0;c[2113068]=am;c[2440436]=ab;c[2443814]=am;aB=am;aC=ab}ab=ag(aB<<1,aC)|0;am=gGq(ab)|0;c[2112926]=am;if((am|0)!=0){gGz(am|0,0,ab|0)}a[9623920]=0;ab=c[2414628]|0;gGz(ab|0,0,(c[2411594]|0)-ab|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];ab=c[3532592]|0;if((ab|0)!=0){gGC(9104152,ab|0,280)|0}c[2113054]=c[2113060]}RI();ab=c[2394]|0;am=c[14130368+(ab<<2)>>2]|0;if((am|0)!=0){gGC(am|0,9104152,280)|0}c[8452240+(ab<<2)>>2]=c[2113054];c[2394]=-1;ab=c[2439330]|0;am=(ab|0)==0;if(!am){aa=ab;gGC(9706056,aa|0,76)|0}aa=c[2438118]|0;c[2433530]=aa;al=c[3528484]|0;c[2076596]=al;af=c[2417276]|0;c[3541536]=af;c[1836236]=0;gGz(9706056,0,76);if(!am){am=ab;gGC(am|0,9706056,76)|0}c[2438118]=aa;c[3528484]=al;c[2417276]=af;c[1836236]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;$=0;i=e;return $|0}}while(0);c[2414926]=0;$=1;i=e;return $|0}function etz(){var a=0,b=0,d=0,e=0,f=0;c[2113070]=0;c[2113068]=0;a=c[2112926]|0;if((a|0)!=0){gGr(a);c[2112926]=0}c[2438228]=0;c[2433526]=0;c[2406676]=0;c[3528472]=0;a=c[2406678]|0;if((a|0)!=0){gGr(a);c[2406678]=0}if((c[2392]|0)>=0){a=0;do{b=14130368+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}b=14130384+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}a=a+1|0;}while((a|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;fwZ();a=c[2414926]|0;b=0;while(1){if((b|0)>=1024){e=3184;break}f=9638528+(b<<2)|0;if((c[f>>2]|0)==(a|0)){break}else{b=b+1|0}}if((e|0)==3184){c[2414926]=0;return 0}gGr(a);c[f>>2]=0;c[2414926]=0;return 0}function etA(){var f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;if((a[9623920]|0)!=0){a[9623920]=0;f=c[2414628]|0;gGz(f|0,0,(c[2411594]|0)-f|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060]}RI();f=c[2394]|0;g=c[14130368+(f<<2)>>2]|0;if((g|0)!=0){gGC(g|0,9104152,280)|0}c[8452240+(f<<2)>>2]=c[2113054];c[2394]=-1;f=c[2439330]|0;g=(f|0)==0;if(!g){i=f;gGC(9706056,i|0,76)|0}i=c[2438118]|0;c[2433530]=i;j=c[3528484]|0;c[2076596]=j;k=c[2417276]|0;c[3541536]=k;c[1836236]=0;gGz(9706056,0,76);if(!g){g=f;gGC(g|0,9706056,76)|0}c[2438118]=i;c[3528484]=j;c[2417276]=k;c[1836236]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0}c[2387590]=-1;k=0;j=-1;i=-1;do{j=((a[9633056+k|0]&1)<<k^j&65535)&65535;i=((a[9630928+k|0]&1)<<k^i&65535)&65535;k=k+1|0;}while((k|0)<16);b[4775180]=j;b[4775181]=i;b[4775182]=d[9634936]|-256;b[4775183]=d[9634938]<<8|d[9634937];i=c[2392]|0;if((i|0)>=0){gGz(8452240,0,((i|0)>0?(i<<2)+4|0:4)|0)}c[2113054]=0;i=c[2385548]|0;if((i|0)>0){gGz(9752472,0,((i|0)>1?i<<2:4)|0)}c[2433530]=0;i=c[3529380]|0;j=i;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];k=c[3532592]|0;if((k|0)!=0){gGC(9104152,k|0,280)|0}c[2113054]=c[2113060]}k=c[2439330]|0;if((k|0)!=0){g=k;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;g=i+4|0;k=i+8|0;f=i+12|0;i=0;l=0;while(1){m=l+1|0;n=(m*1344|0)-i|0;c[2113056]=n;o=RG(n)|0;c[2113054]=(c[2113054]|0)+o;c[2276108]=-1;c[2113056]=-1;n=o+i|0;o=c[2443494]|0;if((l|0)==(e[o>>1]|0)){c[8452200+(c[2394]<<2)>>2]=8197;c[2276080]=1280;if((c[2276079]|0)>>>0<1280){RH(5);p=c[2443494]|0}else{p=o}b[p>>1]=4096}do{if((l|0)==239){c[8452200+(c[2394]<<2)>>2]=8195;c[2276080]=768;if((c[2276079]|0)>>>0>=768){break}RH(3)}else if((l|0)==247){c[8452200+(c[2394]<<2)>>2]=8193;c[2276080]=256;if((c[2276079]|0)>>>0>=256){break}RH(1)}}while(0);o=c[2443480]|0;c[o+(l<<2)>>2]=c[j>>2];c[o+(l+256<<2)>>2]=c[g>>2];c[o+(l+512<<2)>>2]=c[k>>2];c[o+(l+768<<2)>>2]=c[f>>2];if((m|0)<248){i=n;l=m}else{break}}l=c[2438228]|0;i=gGS(-1220542464,47683,l,(l|0)<0|0?-1:0)|0;l=i;Sb(1e5);i=c[2443830]|0;if((i|0)<1073676288){c[2443830]=i-l}i=c[2443831]|0;if((i|0)<1073676288){c[2443831]=i-l}i=(c[3528512]|0)-l|0;c[3528512]=(i|0)<0?0:i;Vy(a[9688]|0?534:0);i=c[1836236]|0;l=c[9757320+(i<<2)>>2]|0;if((l|0)!=0){f=l;gGC(f|0,9706056,76)|0}c[9752472+(i<<2)>>2]=c[2433530];c[14113936+(i<<2)>>2]=c[2076596];c[9669104+(i<<2)>>2]=c[3541536];c[1836236]=-1;i=c[2394]|0;f=c[14130368+(i<<2)>>2]|0;if((f|0)!=0){gGC(f|0,9104152,280)|0}c[8452240+(i<<2)>>2]=c[2113054];c[2394]=-1;if((c[2112968]|0)==0){q=c[3529676]|0;r=c[3529684]|0;gGC(q|0,r|0,8192)|0;s=c[2386428]|0;gGC(r|0,s|0,8192)|0;t=c[2440190]|0;u=b[t>>1]|0;v=t+2|0;b[v>>1]=u;w=c[2388454]|0;x=b[w>>1]|0;b[t>>1]=x;return 0}etB()|0;q=c[3529676]|0;r=c[3529684]|0;gGC(q|0,r|0,8192)|0;s=c[2386428]|0;gGC(r|0,s|0,8192)|0;t=c[2440190]|0;u=b[t>>1]|0;v=t+2|0;b[v>>1]=u;w=c[2388454]|0;x=b[w>>1]|0;b[t>>1]=x;return 0}function etB(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;if((a[9547312]|0)!=0){e=c[2387158]|0;f=c[3529962]|0;g=0;do{h=b[e+(g<<1)>>1]|0;c[f+(g<<2)>>2]=((h&65535)>>>10<<3&248)<<8|((h&255)<<3&255)>>>3|(((h&65535)>>>5<<3&255|(h&65535)>>>7&4)&255)<<3&2016;g=g+1|0;}while((g|0)<4096)}g=d[c[2394698]|0]|0;f=c[591584+(g*12|0)>>2]|0;e=c[591588+(g*12|0)>>2]|0;h=c[591592+(g*12|0)>>2]|0;g=c[(c[3529380]|0)+28>>2]&64;i=c[2113070]|0;j=ag(i,c[2113068]|0)|0;if((j|0)>0){k=c[2112926]|0;l=0;do{b[k+(l<<1)>>1]=8191;l=l+1|0;}while((l|0)<(j|0))}c[2439232]=0;c[2439234]=0;c[2439236]=0;if((i|0)<=0){etF(3);etG(h,g);etF(2);etG(e,g);etF(1);etG(f,g);etF(0);m=c[3529962]|0;R8(m);return 0}j=c[2443480]|0;l=c[j>>2]|0;k=c[j+1024>>2]|0;n=c[j+2048>>2]|0;o=c[j+3072>>2]|0;p=0;q=0;r=0;s=0;t=l;while(1){if((l|0)==(t|0)){u=q}else{v=q|1;c[2439236]=v;u=v}if((k|0)==(c[j+(p+256<<2)>>2]|0)){w=r}else{v=r|1;c[2439234]=v;w=v}if((n|0)==(c[j+(p+512<<2)>>2]|0)){x=s}else{v=s|1;c[2439232]=v;x=v}if((o|0)==(c[j+(p+768<<2)>>2]|0)){y=u;z=w}else{v=u|1;c[2439236]=v;A=w|1;c[2439234]=A;y=v;z=A}A=p+1|0;if((A|0)>=(i|0)){break}p=A;q=y;r=z;s=x;t=c[j+(A<<2)>>2]|0}etF(3);etG(h,g);etF(2);etG(e,g);etF(1);etG(f,g);etF(0);m=c[3529962]|0;R8(m);return 0}function etC(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;g=i;i=i+128|0;h=g|0;j=g+16|0;k=g+32|0;l=g+48|0;m=g+64|0;n=g+80|0;o=g+96|0;p=g+112|0;q=(f|0)==0;if(!q){c[f>>2]=169732}if((e&32|0)!=0){gGz(p|0,0,12);r=c[2414628]|0;c[p>>2]=r;c[p+4>>2]=(c[2411594]|0)-r;c[p+12>>2]=162152;r=c[2076592]|0;gj[r&4095](p)|0}if((e&64|0)!=0){p=o|0;gGz(n|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){r=o+9|0;o=m;s=m|0;t=m+4|0;u=m+12|0;v=n|0;w=n+4|0;x=n+12|0;y=0;do{gGC(p|0,614896,11)|0;a[r]=y+48&255;z=8452256+(y<<2)|0;gGz(o|0,0,12);c[s>>2]=z;c[t>>2]=4;c[u>>2]=164976;gj[c[2076592]&4095](m)|0;if((c[z>>2]|0)!=0){c[v>>2]=c[14130368+(y<<2)>>2];c[w>>2]=c[8452184+(y<<2)>>2];c[x>>2]=p;z=c[2076592]|0;gj[z&4095](n)|0}y=y+1|0;}while((y|0)<=(c[2392]|0))}fw$(e);do{if(!q){if((c[f>>2]|0)>=169249){break}c[f>>2]=169249}}while(0);gGz(l|0,0,12);c[l>>2]=9775320;c[l+4>>2]=8;c[l+12>>2]=111920;f=c[2076592]|0;gj[f&4095](l)|0;gGz(k|0,0,12);c[k>>2]=9775288;c[k+4>>2]=8;c[k+12>>2]=478936;l=c[2076592]|0;gj[l&4095](k)|0;gGz(j|0,0,12);c[j>>2]=53400;c[j+4>>2]=8;c[j+12>>2]=398448;k=c[2076592]|0;gj[k&4095](j)|0;gGz(h|0,0,12);c[h>>2]=14114048;c[h+4>>2]=4;c[h+12>>2]=287368;j=c[2076592]|0;gj[j&4095](h)|0}if((e&2|0)==0){i=g;return 0}e=c[2439330]|0;h=(e|0)==0;if(!h){j=e;gGC(9706056,j|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];j=c[3528484]|0;c[2076596]=j;k=c[2417276]|0;c[3541536]=k;c[1836236]=0;l=c[2385900]|0;f=((d[c[2443932]|0]|0)<<15&491520)-32768|0;q=128;y=128;while(1){c[e+76+(y<<2)>>2]=l+(f+(y<<8));n=q+1&65535;if((n&65535)>255){A=128;B=128;break}else{q=n;y=n&65535}}while(1){y=l+(f+(B<<8))|0;c[e+76+(B+512<<2)>>2]=y;c[e+76+(B+768<<2)>>2]=y;y=A+1&65535;if((y&65535)>255){break}else{A=y;B=y&65535}}if(!h){h=e;gGC(h|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=j;c[2417276]=k;c[1836236]=-1;i=g;return 0}function etD(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3132532+(b*112|0)>>2];c[a+104>>2]=c[3132536+(b*112|0)>>2];c[a+108>>2]=c[3132540+(b*112|0)>>2];d=0;return d|0}function etE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=3132432+(b*112|0);e=0;return e|0}function etF(a){a=a|0;var b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;b=c[3529676]|0;d=(c[2440190]|0)+2|0;f=c[2112926]|0;g=c[3530806]|0;h=0;do{i=e[b+(h<<1)>>1]|0;j=e[b+((h|1)<<1)>>1]|0;k=e[b+((h|2)<<1)>>1]|0;l=e[b+((h|3)<<1)>>1]|0;m=k>>>6;do{if((m&3|0)==(a|0)){if((i&1024|0)!=0){break}n=i&2048;o=j&2048;p=k>>>10;q=128-(p&60)|0;r=128-(m&60)|0;s=(i&511)-(i&512)|0;t=(j&511)-(j&512)|0;u=(n|0)!=0;v=i>>>12<<4;w=u?v:0;x=u?-16:v+16|0;v=(n>>>6^32)-16|0;y=(o|0)!=0;z=j>>>12<<4;A=y?z:0;B=y?-16:z+16|0;z=(o>>>6^32)-16|0;if((A|0)==(B|0)){break}C=(w|0)==(x|0);D=((p|m)&60|0)==0;p=k&63;E=k<<4&1008|2048;F=(q<<9)+4096|0;G=(r<<9)+4096|0;H=(e[d>>1]|0)>>>((l>>>12&12)>>>0)<<14&245760|l&16383;I=A;while(1){if(C){J=H}else{A=I+t|0;K=((ag(I,r)|0)/128|0)+t|0;L=(A|0)<0;M=H;N=w;while(1){L4528:do{if(D){O=N+s|0;do{if((O|0)>-1){if((O|0)>=((c[2113068]|0)-15|0)|L){break}if((A|0)>=((c[2113070]|0)-15|0)){break}P=M+1|0;if(y){if(u){SM(f,M,O,A,p,4,15,2048,g);Q=P;break L4528}else{SK(f,M,O,A,p,4,15,2048,g);Q=P;break L4528}}else{if(u){SI(f,M,O,A,p,4,15,2048,g);Q=P;break L4528}else{SG(f,M,O,A,p,4,15,2048,g);Q=P;break L4528}}}}while(0);P=M+1|0;if(y){if(u){SN(f,M,O,A,p,4,15,2048,g);Q=P;break}else{SL(f,M,O,A,p,4,15,2048,g);Q=P;break}}else{if(u){SJ(f,M,O,A,p,4,15,2048,g);Q=P;break}else{SH(f,M,O,A,p,4,15,2048,g);Q=P;break}}}else{S2(f,g,M,E,15,((ag(N,q)|0)/128|0)+s|0,K,n,o,F,G);Q=M+1|0}}while(0);P=v+N|0;if((P|0)==(x|0)){J=Q;break}else{M=Q;N=P}}}N=z+I|0;if((N|0)==(B|0)){break}else{H=J;I=N}}}}while(0);h=h+4|0;}while((h|0)<4096);return}function etG(a,b){a=a|0;b=b|0;var d=0,e=0;if((a|0)==2){d=(c[2439232]|0)!=0;if((b|0)==0){b=c[2387852]|0;if(d){etJ(b);return}else{etK(b);return}}else{b=c[2387850]|0;if(d){etJ(b);return}else{etK(b);return}}}else if((a|0)==1){b=c[2387970]|0;d=c[3530410]|0;e=c[2443380]|0;if((c[2439234]|0)==0){etI(b,d,e,1024,1);return}else{etH(b,d,e,1024,1);return}}else if((a|0)==0){a=c[2387976]|0;e=c[3530570]|0;d=c[2443384]|0;if((c[2439236]|0)==0){etI(a,e,d,0,0);return}else{etH(a,e,d,0,0);return}}else{return}}function etH(f,g,h,i,j){f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;k=f;f=c[2113070]|0;if((f|0)<=0){return}l=j<<8;j=c[2113068]|0;m=c[2443480]|0;n=j+16|0;o=0;p=c[2112926]|0;while(1){q=c[m+(o+768<<2)>>2]|0;r=c[m+(o+l<<2)>>2]|0;s=o+13+q+r|0;t=(q>>>16)+10+(r>>>16)|0;r=s<<4;q=t&15;if((j+16|0)>0){u=s<<3&3968;s=0;do{v=(s+t|0)>>>3&126|u;w=b[k+(v<<1)>>1]&32767;x=a[h+w|0]|0;L4597:do{if(x<<24>>24!=2){y=e[k+((v|1)<<1)>>1]|0;z=-(y>>>6&1)&15;A=y<<4&768|i;B=(r^-(y>>>7&1))&240|w<<8;y=s-q|0;C=(y|0)>-1;if(x<<24>>24!=0){do{if(C){if((y|0)>=(j-15|0)){D=y;E=0;break}F=B|z;b[p+(y<<1)>>1]=(d[g+F|0]|0|A)&65535;b[p+(y+1<<1)>>1]=(d[g+(F^1)|0]|0|A)&65535;b[p+(y+2<<1)>>1]=(d[g+(F^2)|0]|0|A)&65535;b[p+(y+3<<1)>>1]=(d[g+(F^3)|0]|0|A)&65535;b[p+(y+4<<1)>>1]=(d[g+(F^4)|0]|0|A)&65535;b[p+(y+5<<1)>>1]=(d[g+(F^5)|0]|0|A)&65535;b[p+(y+6<<1)>>1]=(d[g+(F^6)|0]|0|A)&65535;b[p+(y+7<<1)>>1]=(d[g+(F^7)|0]|0|A)&65535;b[p+(y+8<<1)>>1]=(d[g+(F^8)|0]|0|A)&65535;b[p+(y+9<<1)>>1]=(d[g+(F^9)|0]|0|A)&65535;b[p+(y+10<<1)>>1]=(d[g+(F^10)|0]|0|A)&65535;b[p+(y+11<<1)>>1]=(d[g+(F^11)|0]|0|A)&65535;b[p+(y+12<<1)>>1]=(d[g+(F^12)|0]|0|A)&65535;b[p+(y+13<<1)>>1]=(d[g+(F^13)|0]|0|A)&65535;b[p+(y+14<<1)>>1]=(d[g+(F^14)|0]|0|A)&65535;b[p+(y+15<<1)>>1]=(d[g+(F^15)|0]|0|A)&65535;break L4597}else{D=y;E=0}}while(0);while(1){if((D|0)>-1&(D|0)<(j|0)){b[p+(D<<1)>>1]=(d[g+((E^z)+B)|0]|0|A)&65535}F=E+1|0;if((F|0)>=16){break L4597}D=D+1|0;E=F}}do{if(C){if((y|0)<(j-15|0)){G=y;H=0}else{I=y;J=0;break}while(1){F=a[g+((H^z)+B)|0]|0;if(F<<24>>24!=-1){b[p+(G<<1)>>1]=(F&255|A)&65535}F=H+1|0;if((F|0)<16){G=G+1|0;H=F}else{break L4597}}}else{I=y;J=0}}while(0);while(1){y=a[g+((J^z)+B)|0]|0;if(!((I|0)>=(j|0)|(I|0)<0|y<<24>>24==-1)){b[p+(I<<1)>>1]=(y&255|A)&65535}y=J+1|0;if((y|0)>=16){break L4597}I=I+1|0;J=y}}}while(0);s=s+16|0;}while((s|0)<(n|0))}s=o+1|0;if((s|0)>=(f|0)){break}o=s;p=p+(j<<1)|0}return}function etI(d,f,g,h,i){d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;j=c[2443480]|0;k=c[j+3072>>2]|0;l=c[j+(i<<8<<2)>>2]|0;i=k+13+l&511;j=(k>>>16)+10+(l>>>16)&1023;l=d;d=c[2112926]|0;k=0;do{m=(k<<4&1008)-j|0;n=(m|0)<-15?m+1024|0:m;m=(k>>6<<4)-i|0;o=(m|0)<-15?m+512|0:m;m=k<<1;p=b[l+(m<<1)>>1]&32767;q=a[g+p|0]|0;L4631:do{if(q<<24>>24!=2){r=e[l+((m|1)<<1)>>1]|0;s=r>>>4&3;t=r>>>6&1;u=r>>>7&1;r=c[2113068]|0;do{if((n|0)>-1){if(!((n|0)<(r-15|0)&(o|0)>-1)){break}if((o|0)>=((c[2113070]|0)-15|0)){break}v=(u|0)!=0;w=(t|0)!=0;if(q<<24>>24==0){if(v){if(w){SM(d,p,n,o,s,8,255,h,f);break L4631}else{SK(d,p,n,o,s,8,255,h,f);break L4631}}else{if(w){SI(d,p,n,o,s,8,255,h,f);break L4631}else{SG(d,p,n,o,s,8,255,h,f);break L4631}}}else{if(v){if(w){SE(d,p,n,o,s,8,h,f);break L4631}else{SC(d,p,n,o,s,8,h,f);break L4631}}else{if(w){SA(d,p,n,o,s,8,h,f);break L4631}else{Sy(d,p,n,o,s,8,h,f);break L4631}}}}}while(0);if(!((n|0)<(r|0)&(o|0)<(r|0))){break}w=(u|0)!=0;v=(t|0)!=0;if(q<<24>>24==0){if(w){if(v){SN(d,p,n,o,s,8,255,h,f);break}else{SL(d,p,n,o,s,8,255,h,f);break}}else{if(v){SJ(d,p,n,o,s,8,255,h,f);break}else{SH(d,p,n,o,s,8,255,h,f);break}}}else{if(w){if(v){SF(d,p,n,o,s,8,h,f);break}else{SD(d,p,n,o,s,8,h,f);break}}else{if(v){SB(d,p,n,o,s,8,h,f);break}else{Sz(d,p,n,o,s,8,h,f);break}}}}}while(0);k=k+1|0;}while((k|0)<2048);return}function etJ(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;g=f;f=c[2113070]|0;if((f|0)<=0){return}h=c[2113068]|0;i=c[2443480]|0;j=c[2443376]|0;k=h+8|0;l=c[3530322]|0;m=0;n=c[2112926]|0;while(1){o=c[i+(m+512<<2)>>2]|0;p=o+m|0;q=o>>>16;o=p<<3;r=q&7;if((h+8|0)>0){s=p<<4&3968;p=0;do{t=(p+q|0)>>>2&126|s;u=e[g+(t<<1)>>1]|0;v=a[j+u|0]|0;L4693:do{if(v<<24>>24!=2){w=e[g+((t|1)<<1)>>1]|0;x=-(w>>>6&1)&7;y=w<<4&1008|3072;z=(o^-(w>>>7&1))&56|u<<6;w=p-r|0;A=(w|0)>-1;if(v<<24>>24!=0){do{if(A){if((w|0)>=(h-7|0)){B=w;C=0;break}D=z|x;b[n+(w<<1)>>1]=(d[l+D|0]|0|y)&65535;b[n+(w+1<<1)>>1]=(d[l+(D^1)|0]|0|y)&65535;b[n+(w+2<<1)>>1]=(d[l+(D^2)|0]|0|y)&65535;b[n+(w+3<<1)>>1]=(d[l+(D^3)|0]|0|y)&65535;b[n+(w+4<<1)>>1]=(d[l+(D^4)|0]|0|y)&65535;b[n+(w+5<<1)>>1]=(d[l+(D^5)|0]|0|y)&65535;b[n+(w+6<<1)>>1]=(d[l+(D^6)|0]|0|y)&65535;b[n+(w+7<<1)>>1]=(d[l+(D^7)|0]|0|y)&65535;break L4693}else{B=w;C=0}}while(0);while(1){if((B|0)>-1&(B|0)<(h|0)){b[n+(B<<1)>>1]=(d[l+((C^x)+z)|0]|0|y)&65535}D=C+1|0;if((D|0)>=8){break L4693}B=B+1|0;C=D}}do{if(A){if((w|0)>=(h-7|0)){E=w;F=0;break}D=z|x;G=a[l+D|0]|0;if(G<<24>>24!=15){b[n+(w<<1)>>1]=(G&255|y)&65535}G=a[l+(D^1)|0]|0;if(G<<24>>24!=15){b[n+(w+1<<1)>>1]=(G&255|y)&65535}G=a[l+(D^2)|0]|0;if(G<<24>>24!=15){b[n+(w+2<<1)>>1]=(G&255|y)&65535}G=a[l+(D^3)|0]|0;if(G<<24>>24!=15){b[n+(w+3<<1)>>1]=(G&255|y)&65535}G=a[l+(D^4)|0]|0;if(G<<24>>24!=15){b[n+(w+4<<1)>>1]=(G&255|y)&65535}G=a[l+(D^5)|0]|0;if(G<<24>>24!=15){b[n+(w+5<<1)>>1]=(G&255|y)&65535}G=a[l+(D^6)|0]|0;if(G<<24>>24!=15){b[n+(w+6<<1)>>1]=(G&255|y)&65535}G=a[l+(D^7)|0]|0;if(G<<24>>24==15){break L4693}b[n+(w+7<<1)>>1]=(G&255|y)&65535;break L4693}else{E=w;F=0}}while(0);while(1){w=a[l+((F^x)+z)|0]|0;if(!((E|0)>=(h|0)|(E|0)<0|w<<24>>24==15)){b[n+(E<<1)>>1]=(w&255|y)&65535}w=F+1|0;if((w|0)>=8){break L4693}E=E+1|0;F=w}}}while(0);p=p+8|0;}while((p|0)<(k|0))}p=m+1|0;if((p|0)>=(f|0)){break}m=p;n=n+(h<<1)|0}return}function etK(b){b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;d=b;b=c[(c[2443480]|0)+2048>>2]|0;f=b&255;g=b>>>16&511;b=c[2443376]|0;h=c[2112926]|0;i=c[3530322]|0;j=c[2113068]|0;k=0;do{l=(k<<3&504)-g|0;m=(l|0)<-7?l+512|0:l;l=(k>>6<<3)-f|0;n=(l|0)<-7?l+256|0:l;L4745:do{if((m|0)<(j|0)){l=c[2113070]|0;if((n|0)>=(l|0)){break}o=k<<1;p=e[d+(o<<1)>>1]|0;q=a[b+p|0]|0;if(q<<24>>24==2){break}r=e[d+((o|1)<<1)>>1]|0;o=r&63;s=r>>>6&1;t=r>>>7&1;do{if((m|0)>-1){if(!((m|0)<(j-15|0)&(n|0)>-1)){break}if((n|0)>=(l-15|0)){break}r=(t|0)!=0;u=(s|0)!=0;if(q<<24>>24==0){if(r){if(u){Sw(h,p,m,n,o,4,15,3072,i);break L4745}else{Su(h,p,m,n,o,4,15,3072,i);break L4745}}else{if(u){Ss(h,p,m,n,o,4,15,3072,i);break L4745}else{Sq(h,p,m,n,o,4,15,3072,i);break L4745}}}else{if(r){if(u){So(h,p,m,n,o,4,3072,i);break L4745}else{Sm(h,p,m,n,o,4,3072,i);break L4745}}else{if(u){Sk(h,p,m,n,o,4,3072,i);break L4745}else{Si(h,p,m,n,o,4,3072,i);break L4745}}}}}while(0);l=(t|0)!=0;u=(s|0)!=0;if(q<<24>>24==0){if(l){if(u){Sx(h,p,m,n,o,4,15,3072,i);break}else{Sv(h,p,m,n,o,4,15,3072,i);break}}else{if(u){St(h,p,m,n,o,4,15,3072,i);break}else{Sr(h,p,m,n,o,4,15,3072,i);break}}}else{if(l){if(u){Sp(h,p,m,n,o,4,3072,i);break}else{Sn(h,p,m,n,o,4,3072,i);break}}else{if(u){Sl(h,p,m,n,o,4,3072,i);break}else{Sj(h,p,m,n,o,4,3072,i);break}}}}}while(0);k=k+1|0;}while((k|0)<2048);return}function etL(b,c){b=b|0;c=c|0;a[9706117]=(c|0)!=0|0;return}function etM(a){a=a|0;var b=0,d=0;b=(c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,6e6,0)|0;return a|0}function etN(b){b=b|0;var d=0;if((b|0)==12861441){d=a[9550352]|0}else if((b|0)==12861443){d=a[9550353]|0}else if((b|0)==12845059){d=a[c[2442906]|0]|0}else if((b|0)==12861451){d=a[9634928]|0}else if((b|0)==12861445){d=a[9550354]|0}else if((b|0)==12845057){d=c[2113156]&255}else{d=0}return d|0}function etO(b,e){b=b|0;e=e|0;var f=0;switch(b|0){case 12845064:{a[(c[3540984]|0)+5885|0]=e;return};case 12845059:{a[c[2442906]|0]=e;return};case 12845063:{b=e&1;a[c[2406700]|0]=b;c[3541206]=(c[2386622]|0)+(b<<24>>24!=0?262144:0);return};case 12845056:{if((c[2415174]|0)==2){return}a[c[3528246]|0]=e;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12;return};case 12845066:{b=c[3540984]|0;f=c[b+5876>>2]|0;if((f|0)!=0){gg[f&4095](c[b+5880>>2]|0,0)}lH(b,d[b+5885|0]|0,e&255);return};case 12845057:{if((c[2415174]|0)!=2){return}Uv(0,e);return};default:{return}}}function etP(b,e){b=b|0;e=e|0;var f=0,g=0;f=b&255;if((f|0)==5){Uv(0,e);return}else if((f|0)==3){b=c[3540984]|0;g=c[b+5876>>2]|0;if((g|0)!=0){gg[g&4095](c[b+5880>>2]|0,0)}lH(b,d[b+5885|0]|0,e&255);return}else if((f|0)==7){b=e&64;a[c[2406700]|0]=b;c[3541206]=(c[2386622]|0)+(b<<24>>24!=0?262144:0);return}else if((f|0)==2){a[(c[3540984]|0)+5885|0]=e;return}else{return}}function etQ(b){b=b|0;var d=0,e=0;d=b&255;if((d|0)==1){e=a[c[3528246]|0]|0}else if((d|0)==5){e=c[2113156]&255}else{e=0}return e|0}function etR(b,c){b=b|0;c=c|0;a[9706117]=(c|0)!=0|0;return}function etS(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2637100+(b*112|0)>>2];c[a+104>>2]=c[2637104+(b*112|0)>>2];c[a+108>>2]=c[2637108+(b*112|0)>>2];d=0;return d|0}function etT(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=2637e3+(b*112|0);e=0;return e|0}function etU(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6924208+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function etV(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3789368+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function etW(){a[4814456]=1;a[4814448]=1;a[7072520]=1;a[4717648]=1;a[4717640]=1;a[7054640]=1;c[2436760]=13;a[3099368]=0;c[2433678]=9;a[2862968]=0;return et8()|0}function etX(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}b=a[7452584]|0;if(b){d=0;e=b&1;while(1){b=14163936+(d<<2)|0;f=c[b>>2]|0;g=c[2113006]|0;if((g|0)==0){h=3576}else{i=g-1|0;c[2113006]=i;if((i|0)==0){h=3576}}if((h|0)==3576){h=0;c[2383474]=0}if((f|0)==0){j=e}else{gGr(f);j=a[7452584]&1}c[b>>2]=0;b=d+1|0;if((b|0)<(j|0)){d=b;e=j}else{break}}}a[7452584]=0;c[2438224]=0;c[2433522]=0;c[2406672]=0;c[3528468]=0;j=c[2406688]|0;if((j|0)!=0){gGr(j);c[2406688]=0}c[2432972]=0;Uw(0);if((c[2392]|0)>=0){j=0;do{e=14130368+(j<<2)|0;d=c[e>>2]|0;if((d|0)!=0){gGr(d);c[e>>2]=0}e=14130384+(j<<2)|0;d=c[e>>2]|0;if((d|0)!=0){gGr(d);c[e>>2]=0}j=j+1|0;}while((j|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;fwZ();j=c[2414924]|0;e=0;while(1){if((e|0)>=1024){h=3594;break}k=9638528+(e<<2)|0;if((c[k>>2]|0)==(j|0)){break}else{e=e+1|0}}if((h|0)==3594){c[2414924]=0;c[3541206]=0;c[2415174]=0;return 0}gGr(j);c[k>>2]=0;c[2414924]=0;c[3541206]=0;c[2415174]=0;return 0}function etY(){var d=0,e=0,f=0,g=0,i=0,j=0;if((a[9623912]|0)!=0){a[9623912]=0;d=c[2414626]|0;gGz(d|0,0,(c[2411592]|0)-d|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=i;c[1836236]=-1;c[2113156]=0;a[9628264]=0;c[2407033]=0;i=c[3541206]|0;c[3541190]=i;c[3541198]=i;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=i+256;c[3541199]=i+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=i+512;c[3541200]=i+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=i+768;c[3541201]=i+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;lw(c[3540984]|0);a[c[2406700]|0]=0;c[3541206]=c[2386622]}gGz(9550352,-1|0,3);i=0;g=-1;f=-1;e=-1;do{g=((a[9633040+i|0]&1)<<i^g&255)&255;f=((a[9630912+i|0]&1)<<i^f&255)&255;e=((a[9629384+i|0]&1)<<i^e&255)&255;i=i+1|0;}while((i|0)<8);a[9550352]=g;a[9550353]=f;a[9550354]=e;e=c[2392]|0;if((e|0)>=0){gGz(8452240,0,((e|0)>0?(e<<2)+4|0:4)|0)}c[2113054]=0;e=c[2385548]|0;if((e|0)>0){gGz(9752472,0,((e|0)>1?e<<2:4)|0)}c[2433530]=0;c[2444071]=0;c[2444070]=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060]}e=c[2439330]|0;if((e|0)!=0){f=e;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;c[2113056]=20833;f=RG(20833)|0;c[2113054]=(c[2113054]|0)+f;c[2276108]=-1;c[2113056]=-1;c[2444070]=f;if((c[2415174]|0)!=2){UF(0)|0}c[2113056]=20833;f=RG(20833)|0;c[2113054]=(c[2113054]|0)+f;c[2276108]=-1;c[2113056]=-1;c[2444070]=f;if((c[2415174]|0)!=2){UF(10416)|0}c[2113056]=20833;f=RG(20833)|0;c[2113054]=(c[2113054]|0)+f;c[2276108]=-1;c[2113056]=-1;c[2444070]=f;if((c[2415174]|0)!=2){UF(20832)|0}c[2113056]=20833;f=RG(20833)|0;c[2113054]=(c[2113054]|0)+f;c[2276108]=-1;c[2113056]=-1;c[2444070]=f;if((c[2415174]|0)!=2){UF(31248)|0}c[2113056]=20833;f=RG(20833)|0;c[2113054]=(c[2113054]|0)+f;c[2276108]=-1;c[2113056]=-1;c[2444070]=f;if((c[2415174]|0)!=2){UF(41664)|0}c[2113056]=20833;f=RG(20833)|0;c[2113054]=(c[2113054]|0)+f;c[2276108]=-1;c[2113056]=-1;c[2444070]=f;if((c[2415174]|0)!=2){UF(52080)|0}c[2113056]=20833;f=RG(20833)|0;c[2113054]=(c[2113054]|0)+f;c[2276108]=-1;c[2113056]=-1;c[2444070]=f;if((c[2415174]|0)!=2){UF(62496)|0}c[2113056]=20833;f=RG(20833)|0;c[2113054]=(c[2113054]|0)+f;c[2276108]=-1;c[2113056]=-1;c[2444070]=f;if((c[2415174]|0)!=2){UF(72912)|0}c[2113056]=20833;f=RG(20833)|0;c[2113054]=(c[2113054]|0)+f;c[2276108]=-1;c[2113056]=-1;c[2444070]=f;if((c[2415174]|0)!=2){UF(83328)|0}c[2113056]=20833;f=RG(20833)|0;c[2113054]=(c[2113054]|0)+f;c[2276108]=-1;c[2113056]=-1;c[2444070]=f;if((c[2415174]|0)!=2){UF(93744)|0}c[8452200+(c[2394]<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0<1024){RH(4)}f=c[2112964]|0;if((f|0)!=0){if((c[2415174]|0)==2){j=f}else{f=c[2438224]|0;e=gGS(942407680,49670,f,(f|0)<0|0?-1:0)|0;f=e;UF(104166)|0;e=c[2443826]|0;if((e|0)<1073676288){c[2443826]=e-f}e=c[2443827]|0;if((e|0)<1073676288){c[2443827]=e-f}e=(c[3528508]|0)-f|0;c[3528508]=(e|0)<0?0:e;j=c[2112964]|0}gg[c[3542112]&4095](j,a[9688]|0?534:0);Uu(0,c[2112964]|0,a[9688]|0?534:0)}j=c[1836236]|0;e=c[9757320+(j<<2)>>2]|0;if((e|0)!=0){f=e;gGC(f|0,9706056,76)|0}c[9752472+(j<<2)>>2]=c[2433530];c[14113936+(j<<2)>>2]=c[2076596];c[9669104+(j<<2)>>2]=c[3541536];c[1836236]=-1;j=c[2394]|0;f=c[14130368+(j<<2)>>2]|0;if((f|0)!=0){gGC(f|0,9104152,280)|0}c[8452240+(j<<2)>>2]=c[2113054];c[2394]=-1;if((c[2112968]|0)==0){return 0}etZ()|0;return 0}function etZ(){var d=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=i;i=i+16|0;f=d|0;if((a[9547304]|0)!=0){g=c[2387156]|0;h=c[3529960]|0;j=0;do{k=e[g+j>>1]|0;l=k>>>3&30;c[h+(((j|0)/2|0)<<2)>>2]=k>>>7&30|k>>>14&1|(k<<1&30|k>>>12&1)<<11|((l|k>>>13&1)<<3|l>>>2)<<3&2016;j=j+2|0;}while((j|0)<4096)}if((a[c[2442906]|0]&32)==0){i=d;return 0}j=c[2386328]|0;h=(e[j+((a[4814456]|0?82:0)<<1)>>1]|0)-(c[2436760]|0)&511;g=(e[j+((a[4814448]|0?84:0)<<1)>>1]|0)-(a[3099368]|0?128:0)&255;l=e[j+((a[7072520]|0?86:0)<<1)>>1]|0;k=f+12|0;c[k>>2]=l>>>12;m=f+8|0;c[m>>2]=l>>>8&15;n=f+4|0;c[n>>2]=l>>>4&15;o=f|0;c[o>>2]=l&15;eub(o,h+192|0,g,0);euc(1);g=(e[j+((a[4717648]|0?81:0)<<1)>>1]|0)-(c[2433678]|0)&511;h=(e[j+((a[4717640]|0?83:0)<<1)>>1]|0)-(a[2862968]|0?128:0)&255;l=e[j+((a[7054640]|0?85:0)<<1)>>1]|0;c[k>>2]=l>>>12;c[m>>2]=l>>>8&15;c[n>>2]=l>>>4&15;c[o>>2]=l&15;eub(o,g+192|0,h,1);euc(2);h=c[3527234]|0;g=c[2112926]|0;o=c[3530804]|0;l=0;do{n=(l<<3&504)-192|0;m=l>>6<<3;k=e[j+(b[h+(l<<1)>>1]<<1)>>1]|0;f=k&61951;p=k>>>9&7;L5026:do{if((n|0)>=0){k=c[2113070]|0;if((m|0)>=(k|0)){break}q=c[2113068]|0;if((n|0)>=(q|0)|(f|0)==0){break}do{if((n|0)>-1){if(!((n|0)<(q-7|0)&(m|0)>-1)){break}if((m|0)>=(k-7|0)){break}Sq(g,f,n,m,p,3,0,0,o);break L5026}}while(0);Sr(g,f,n,m,p,3,0,0,o)}}while(0);l=l+1|0;}while((l|0)<2048);euc(3);R8(c[3529960]|0);i=d;return 0}function et_(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=i;i=i+96|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;l=e+80|0;if((d|0)!=0){c[d>>2]=169624}if((b&96|0)==0){i=e;return 0}gGz(l|0,0,12);m=c[2414626]|0;c[l>>2]=m;c[l+4>>2]=(c[2411592]|0)-m;c[l+12>>2]=162152;gj[c[2076592]&4095](l)|0;l=h|0;do{if((b&64|0)!=0){gGz(g|0,0,16);c[2394]=-1;if((c[2392]|0)<0){break}m=h+9|0;n=f;o=f|0;p=f+4|0;q=f+12|0;r=g|0;s=g+4|0;t=g+12|0;u=0;do{gGC(l|0,614896,11)|0;a[m]=u+48&255;v=8452256+(u<<2)|0;gGz(n|0,0,12);c[o>>2]=v;c[p>>2]=4;c[q>>2]=164976;gj[c[2076592]&4095](f)|0;if((c[v>>2]|0)!=0){c[r>>2]=c[14130368+(u<<2)>>2];c[s>>2]=c[8452184+(u<<2)>>2];c[t>>2]=l;v=c[2076592]|0;gj[v&4095](g)|0}u=u+1|0;}while((u|0)<=(c[2392]|0))}}while(0);fw$(b);gGz(k|0,0,12);c[k>>2]=9776280;c[k+4>>2]=4;c[k+12>>2]=330672;gj[c[2076592]&4095](k)|0;gGz(j|0,0,12);c[j>>2]=9776284;c[j+4>>2]=4;c[j+12>>2]=321856;gj[c[2076592]&4095](j)|0;UQ(b,d);Ut(0);c[3541206]=(c[2386622]|0)+((a[c[2406700]|0]|0)!=0?262144:0);i=e;return 0}function et$(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4768228+(b*112|0)>>2];c[a+104>>2]=c[4768232+(b*112|0)>>2];c[a+108>>2]=c[4768236+(b*112|0)>>2];d=0;return d|0}function et0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=4768128+(b*112|0);e=0;return e|0}function et1(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4629964+(b*112|0)>>2];c[a+104>>2]=c[4629968+(b*112|0)>>2];c[a+108>>2]=c[4629972+(b*112|0)>>2];d=0;return d|0}function et2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=4629864+(b*112|0);e=0;return e|0}function et3(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5333808+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function et4(){c[2415174]=1;a[4814456]=1;a[4814448]=1;a[7072520]=1;a[4717648]=1;a[4717640]=1;a[7054640]=1;c[2436760]=269;a[3099368]=1;c[2433678]=265;a[2862968]=1;return et8()|0}function et5(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2638108+(b*112|0)>>2];c[a+104>>2]=c[2638112+(b*112|0)>>2];c[a+108>>2]=c[2638116+(b*112|0)>>2];d=0;return d|0}function et6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=2638008+(b*112|0);e=0;return e|0}function et7(){c[2415174]=2;a[4814456]=1;a[4814448]=1;a[7072520]=1;a[4717648]=1;a[4717640]=1;a[7054640]=1;c[2436760]=13;a[3099368]=0;c[2433678]=9;a[2862968]=0;return et8()|0}function et8(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0;e=i;i=i+1800|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;B=e+1200|0;C=e+1312|0;D=e+1320|0;E=e+1432|0;F=e+1440|0;G=e+1552|0;H=e+1560|0;I=e+1672|0;J=e+1680|0;K=e+1792|0;c[2414924]=0;c[2388120]=0;c[2385898]=1048576;c[3530804]=1114112;c[3530568]=5308416;c[3541206]=9502720;c[2386622]=9502720;c[3529960]=10551296;c[3527234]=10559488;c[2439658]=10563584;c[2414626]=10579968;c[2386426]=10579968;c[2386328]=10582016;c[2388248]=10586112;c[2387156]=10651648;c[2386202]=10655744;c[2386052]=10721280;c[2442906]=10723328;c[3528246]=10723329;c[2406700]=10723330;c[2411592]=10723331;L=0;while(1){if((L|0)>=1024){break}M=9638528+(L<<2)|0;if((c[M>>2]|0)==0){N=3737;break}else{L=L+1|0}}do{if((N|0)==3737){L=gGq(10723331)|0;c[M>>2]=L;if((L|0)==0){break}c[2414924]=L;gGz(L|0,0,10723331);c[2388120]=L;c[2385898]=L+1048576;c[3530804]=L+1114112;c[3530568]=L+5308416;O=L+9502720|0;c[3541206]=O;c[2386622]=O;c[3529960]=L+10551296;c[3527234]=L+10559488;c[2439658]=L+10563584;O=L+10579968|0;c[2414626]=O;c[2386426]=O;c[2386328]=L+10582016;c[2388248]=L+10586112;c[2387156]=L+10651648;c[2386202]=L+10655744;c[2386052]=L+10721280;c[2442906]=L+10723328;c[3528246]=L+10723329;c[2406700]=L+10723330;O=L+10723331|0;c[2411592]=O;c[2414132]=O;if((R6(L+1|0,0,2)|0)!=0){P=1;i=e;return P|0}if((R6(c[2388120]|0,1,2)|0)!=0){P=1;i=e;return P|0}L=c[2415174]|0;do{if((L|0)==0){O=c[2385898]|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}Q=J+108|0;c[Q>>2]=0;R=J+100|0;c[R>>2]=0;S=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[S&16383](J,2)|0;do{if((c[Q>>2]|0)!=0){S=c[R>>2]|0;c[K>>2]=9534384;T=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[T&16383](K,2,0)|0;if((S|0)<1){P=1;i=e;return P|0}if((gzL(O,0,2)|0)==0){break}else{P=1}i=e;return P|0}}while(0);O=c[3530804]|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}R=H+108|0;c[R>>2]=0;Q=H+100|0;c[Q>>2]=0;S=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[S&16383](H,3)|0;do{if((c[R>>2]|0)!=0){S=c[Q>>2]|0;c[I>>2]=9534384;T=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[T&16383](I,3,0)|0;if((S|0)<1){P=1;i=e;return P|0}if((gzL(O,0,3)|0)==0){break}else{P=1}i=e;return P|0}}while(0);O=(c[3530804]|0)+524288|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}Q=F+108|0;c[Q>>2]=0;R=F+100|0;c[R>>2]=0;S=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[S&16383](F,4)|0;do{if((c[Q>>2]|0)!=0){S=c[R>>2]|0;c[G>>2]=9534384;T=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[T&16383](G,4,0)|0;if((S|0)<1){P=1;i=e;return P|0}if((gzL(O,0,4)|0)==0){break}else{P=1}i=e;return P|0}}while(0);O=(c[3530804]|0)+1048576|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}R=D+108|0;c[R>>2]=0;Q=D+100|0;c[Q>>2]=0;S=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[S&16383](D,5)|0;do{if((c[R>>2]|0)!=0){S=c[Q>>2]|0;c[E>>2]=9534384;T=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[T&16383](E,5,0)|0;if((S|0)<1){P=1;i=e;return P|0}if((gzL(O,0,5)|0)==0){break}else{P=1}i=e;return P|0}}while(0);if((R6(c[3530568]|0,6,2)|0)!=0){P=1;i=e;return P|0}if((R6((c[3530568]|0)+1|0,7,2)|0)!=0){P=1;i=e;return P|0}O=c[2386622]|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}Q=B+108|0;c[Q>>2]=0;R=B+100|0;c[R>>2]=0;S=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[S&16383](B,8)|0;if((c[Q>>2]|0)==0){U=0;break}Q=c[R>>2]|0;c[C>>2]=9534384;R=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[R&16383](C,8,0)|0;if((Q|0)<1){P=1;i=e;return P|0}if((gzL(O,0,8)|0)==0){U=0;break}else{P=1}i=e;return P|0}else if((L|0)==1){O=c[2385898]|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}Q=z+108|0;c[Q>>2]=0;R=z+100|0;c[R>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,2)|0;do{if((c[Q>>2]|0)!=0){S=c[R>>2]|0;c[A>>2]=9534384;T=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[T&16383](A,2,0)|0;if((S|0)<1){P=1;i=e;return P|0}if((gzL(O,0,2)|0)==0){break}else{P=1}i=e;return P|0}}while(0);O=c[3530804]|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}R=x+108|0;c[R>>2]=0;Q=x+100|0;c[Q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,3)|0;do{if((c[R>>2]|0)!=0){S=c[Q>>2]|0;c[y>>2]=9534384;T=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[T&16383](y,3,0)|0;if((S|0)<1){P=1;i=e;return P|0}if((gzL(O,0,3)|0)==0){break}else{P=1}i=e;return P|0}}while(0);O=(c[3530804]|0)+524288|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}Q=v+108|0;c[Q>>2]=0;R=v+100|0;c[R>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,4)|0;do{if((c[Q>>2]|0)!=0){S=c[R>>2]|0;c[w>>2]=9534384;T=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[T&16383](w,4,0)|0;if((S|0)<1){P=1;i=e;return P|0}if((gzL(O,0,4)|0)==0){break}else{P=1}i=e;return P|0}}while(0);O=(c[3530804]|0)+1048576|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}R=t+108|0;c[R>>2]=0;Q=t+100|0;c[Q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,5)|0;do{if((c[R>>2]|0)!=0){S=c[Q>>2]|0;c[u>>2]=9534384;T=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[T&16383](u,5,0)|0;if((S|0)<1){P=1;i=e;return P|0}if((gzL(O,0,5)|0)==0){break}else{P=1}i=e;return P|0}}while(0);if((R6(c[3530568]|0,6,2)|0)!=0){P=1;i=e;return P|0}if((R6((c[3530568]|0)+1|0,7,2)|0)!=0){P=1;i=e;return P|0}if((R6((c[3530568]|0)+1048576|0,8,2)|0)!=0){P=1;i=e;return P|0}if((R6((c[3530568]|0)+1048577|0,9,2)|0)!=0){P=1;i=e;return P|0}if((R6((c[3530568]|0)+2097152|0,10,2)|0)!=0){P=1;i=e;return P|0}if((R6((c[3530568]|0)+2097153|0,11,2)|0)!=0){P=1;i=e;return P|0}O=c[2386622]|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}Q=r+108|0;c[Q>>2]=0;R=r+100|0;c[R>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,12)|0;if((c[Q>>2]|0)==0){U=0;break}Q=c[R>>2]|0;c[s>>2]=9534384;gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](s,12,0)|0;if((Q|0)<1){P=1;i=e;return P|0}if((gzL(O,0,12)|0)==0){U=0;break}else{P=1}i=e;return P|0}else if((L|0)==2){O=c[3530804]|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}Q=p+108|0;c[Q>>2]=0;R=p+100|0;c[R>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,2)|0;do{if((c[Q>>2]|0)!=0){S=c[R>>2]|0;c[q>>2]=9534384;T=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[T&16383](q,2,0)|0;if((S|0)<1){P=1;i=e;return P|0}if((gzL(O,0,2)|0)==0){break}else{P=1}i=e;return P|0}}while(0);O=(c[3530804]|0)+524288|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}R=n+108|0;c[R>>2]=0;Q=n+100|0;c[Q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,3)|0;do{if((c[R>>2]|0)!=0){S=c[Q>>2]|0;c[o>>2]=9534384;T=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[T&16383](o,3,0)|0;if((S|0)<1){P=1;i=e;return P|0}if((gzL(O,0,3)|0)==0){break}else{P=1}i=e;return P|0}}while(0);O=(c[3530804]|0)+1048576|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}Q=l+108|0;c[Q>>2]=0;R=l+100|0;c[R>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,4)|0;do{if((c[Q>>2]|0)!=0){S=c[R>>2]|0;c[m>>2]=9534384;T=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[T&16383](m,4,0)|0;if((S|0)<1){P=1;i=e;return P|0}if((gzL(O,0,4)|0)==0){break}else{P=1}i=e;return P|0}}while(0);O=c[3530568]|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}R=j+108|0;c[R>>2]=0;Q=j+100|0;c[Q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,5)|0;do{if((c[R>>2]|0)!=0){S=c[Q>>2]|0;c[k>>2]=9534384;T=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[T&16383](k,5,0)|0;if((S|0)<1){P=1;i=e;return P|0}if((gzL(O,0,5)|0)==0){break}else{P=1}i=e;return P|0}}while(0);O=0;Q=c[3530568]|0;while(1){R=a[Q]|0;S=Q+1|0;a[Q]=a[S]|0;a[S]=R;R=O+1|0;if((R|0)<2097152){O=R;Q=Q+2|0}else{break}}Q=c[2386622]|0;if((c[3542200]|0)==0){P=1;i=e;return P|0}O=f+108|0;c[O>>2]=0;R=f+100|0;c[R>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,6)|0;if((c[O>>2]|0)==0){U=0;break}O=c[R>>2]|0;c[g>>2]=9534384;gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](g,6,0)|0;if((O|0)<1){P=1;i=e;return P|0}if((gzL(Q,0,6)|0)==0){U=0;break}else{P=1}i=e;return P|0}else{U=0}}while(0);while(1){if((U|0)>=1024){break}V=9638528+(U<<2)|0;if((c[V>>2]|0)==0){N=3814;break}else{U=U+1|0}}L5295:do{if((N|0)==3814){L=gGq(1572864)|0;c[V>>2]=L;if((L|0)==0){break}gGz(L|0,0,1572864);Q=c[3530804]|0;gGC(L|0,Q|0,1572864)|0;O=0;while(1){R=O<<6;gGz(Q+R|0,0,64);S=R+8388608|0;T=0;do{W=S+(c[1238464+(T<<2)>>2]|0)|0;X=(T<<3)+R|0;Y=0;do{Z=W+(c[614800+(Y<<2)>>2]|0)|0;if(((d[L+((Z|0)/8|0)|0]|0)&128>>>((Z&7)>>>0)|0)!=0){Z=Q+(X+Y)|0;a[Z]=a[Z]|4}Y=Y+1|0;}while((Y|0)<8);T=T+1|0;}while((T|0)<8);T=R+4194304|0;S=0;while(1){Y=T+(c[1238464+(S<<2)>>2]|0)|0;X=(S<<3)+R|0;W=0;do{Z=Y+(c[614800+(W<<2)>>2]|0)|0;if(((d[L+((Z|0)/8|0)|0]|0)&128>>>((Z&7)>>>0)|0)!=0){Z=Q+(X+W)|0;a[Z]=a[Z]|2}W=W+1|0;}while((W|0)<8);W=S+1|0;if((W|0)<8){S=W}else{_=0;break}}do{S=R+(c[1238464+(_<<2)>>2]|0)|0;T=(_<<3)+R|0;W=0;do{X=S+(c[614800+(W<<2)>>2]|0)|0;if(((d[L+((X|0)/8|0)|0]|0)&128>>>((X&7)>>>0)|0)!=0){X=Q+(T+W)|0;a[X]=a[X]|1}W=W+1|0;}while((W|0)<8);_=_+1|0;}while((_|0)<8);R=O+1|0;if((R|0)<65536){O=R}else{$=0;break}}while(1){if(($|0)>=1024){break L5295}aa=9638528+($<<2)|0;if((c[aa>>2]|0)==(L|0)){break}else{$=$+1|0}}gGr(L);c[aa>>2]=0}}while(0);O=c[2439658]|0;Q=0;do{R=Q>>7;b[O+(Q<<1)>>1]=(Q<<5&2048|Q&63|R<<6&1984|R<<7&4096)&65535;Q=Q+1|0;}while((Q|0)<8192);Q=c[3527234]|0;O=0;do{R=O>>6;b[Q+(O<<1)>>1]=(R<<6&1984|O&63|R<<7&4096)&65535;O=O+1|0;}while((O|0)<2048);fxU(0,425984);if((c[2394]|0)==0){ab=c[2112932]|0}else{c[2394]=0;O=c[3532596]|0;c[2112932]=O;Q=c[3532592]|0;if((Q|0)!=0){gGC(9104152,Q|0,280)|0}c[2113054]=c[2113060];ab=O}O=c[2388120]|0;Q=ab|0;R=0;while(1){W=O+R|0;c[Q>>2]=W;c[Q+131072>>2]=W;W=R+1024|0;if(W>>>0>1048575){break}else{Q=Q+4|0;R=W}}R=c[2386202]|0;Q=ab+16384|0;O=4194304;while(1){W=R+(O-4194304)|0;c[Q>>2]=W;c[Q+65536>>2]=W;c[Q+131072>>2]=W;W=O+1024|0;if(W>>>0>4259839){break}else{Q=Q+4|0;O=W}}O=c[2386328]|0;c[ab+16640>>2]=O;c[ab+82176>>2]=O;c[ab+147712>>2]=O;Q=O+1024|0;c[ab+16644>>2]=Q;c[ab+82180>>2]=Q;c[ab+147716>>2]=Q;Q=O+2048|0;c[ab+16648>>2]=Q;c[ab+82184>>2]=Q;c[ab+147720>>2]=Q;Q=O+3072|0;c[ab+16652>>2]=Q;c[ab+82188>>2]=Q;c[ab+147724>>2]=Q;Q=c[2386426]|0;c[ab+82944>>2]=Q;c[ab+82948>>2]=Q+1024;Q=c[2387156]|0;c[ab+33792>>2]=Q;c[ab+99328>>2]=Q;c[ab+164864>>2]=Q;O=Q+1024|0;c[ab+33796>>2]=O;c[ab+99332>>2]=O;c[ab+164868>>2]=O;O=Q+2048|0;c[ab+33800>>2]=O;c[ab+99336>>2]=O;c[ab+164872>>2]=O;O=Q+3072|0;c[ab+33804>>2]=O;c[ab+99340>>2]=O;c[ab+164876>>2]=O;O=c[2388248]|0;Q=ab+65280|0;R=16711680;while(1){W=O+(R-16711680)|0;c[Q>>2]=W;c[Q+65536>>2]=W;c[Q+131072>>2]=W;W=R+1024|0;if(W>>>0>16777215){break}else{Q=Q+4|0;R=W}}c[ab+196648>>2]=244;c[ab+196608>>2]=1342;R=c[3532592]|0;if((R|0)!=0){gGC(R|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);R=c[2439330]|0;Q=(R|0)==0;if(!Q){O=R;gGC(9706056,O|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];O=c[3528484]|0;c[2076596]=O;W=c[2417276]|0;c[3541536]=W;c[1836236]=0;T=c[2385898]|0;S=0;X=0;while(1){c[R+76+(X<<2)>>2]=T+(X<<8);Y=S+1&65535;if((Y&65535)>247){ac=0;ad=0;break}else{S=Y;X=Y&65535}}while(1){X=T+(ad<<8)|0;c[R+76+(ad+512<<2)>>2]=X;c[R+76+(ad+768<<2)>>2]=X;X=ac+1&65535;if((X&65535)>247){break}else{ac=X;ad=X&65535}}T=c[2386052]|0;c[R+1068>>2]=T;X=T+256|0;c[R+1072>>2]=X;S=T+512|0;c[R+1076>>2]=S;Y=T+768|0;c[R+1080>>2]=Y;Z=T+1024|0;c[R+1084>>2]=Z;ae=T+1280|0;c[R+1088>>2]=ae;af=T+1536|0;c[R+1092>>2]=af;ah=T+1792|0;c[R+1096>>2]=ah;c[R+2092>>2]=T;c[R+2096>>2]=X;c[R+2100>>2]=S;c[R+2104>>2]=Y;c[R+2108>>2]=Z;c[R+2112>>2]=ae;c[R+2116>>2]=af;c[R+2120>>2]=ah;c[R+3116>>2]=T;c[R+4140>>2]=T;c[R+3120>>2]=X;c[R+4144>>2]=X;c[R+3124>>2]=S;c[R+4148>>2]=S;c[R+3128>>2]=Y;c[R+4152>>2]=Y;c[R+3132>>2]=Z;c[R+4156>>2]=Z;c[R+3136>>2]=ae;c[R+4160>>2]=ae;c[R+3140>>2]=af;c[R+4164>>2]=af;c[R+3144>>2]=ah;c[R+4168>>2]=ah;c[R+4176>>2]=2856;c[R+4172>>2]=3192;if(!Q){ah=R;gGC(ah|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=O;c[2417276]=W;c[1836236]=-1;if((c[2415174]|0)==2){UL(3125e3,0,1164,0);ai=162;aj=444;ak=148;al=4710;am=125e5}else{UL(3125e3,1924,3054,0);ai=326;aj=9362;ak=1752;al=3416;am=625e4}c[2438224]=am;c[2433522]=al;c[2406672]=ak;c[3528468]=aj;c[2443842]=ai;h[745398]=.6;a[3203264]=1;Ux(0,8e3,1);c[2407030]=256;c[2407068]=3;ah=c[642608+(c[2436]<<2)>>2]|0;af=c[ah+128>>2]|0;if((c[ah+52>>2]&4|0)==0){c[2113068]=af;ae=c[ah+132>>2]|0;c[2113070]=ae;c[2443814]=af;c[2440436]=ae;an=af;ao=ae}else{c[2113070]=af;ae=c[ah+132>>2]|0;c[2113068]=ae;c[2440436]=af;c[2443814]=ae;an=ae;ao=af}af=ag(an<<1,ao)|0;ae=gGq(af)|0;c[2112926]=ae;if((ae|0)!=0){gGz(ae|0,0,af|0)}a[9623912]=0;af=c[2414626]|0;gGz(af|0,0,(c[2411592]|0)-af|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];af=c[3532592]|0;if((af|0)!=0){gGC(9104152,af|0,280)|0}c[2113054]=c[2113060]}RI();af=c[2394]|0;ae=c[14130368+(af<<2)>>2]|0;if((ae|0)!=0){gGC(ae|0,9104152,280)|0}c[8452240+(af<<2)>>2]=c[2113054];c[2394]=-1;af=c[2439330]|0;ae=(af|0)==0;if(!ae){ah=af;gGC(9706056,ah|0,76)|0}ah=c[2438118]|0;c[2433530]=ah;Z=c[3528484]|0;c[2076596]=Z;Y=c[2417276]|0;c[3541536]=Y;c[1836236]=0;gGz(9706056,0,76);if(!ae){ae=af;gGC(ae|0,9706056,76)|0}c[2438118]=ah;c[3528484]=Z;c[2417276]=Y;c[1836236]=-1;c[2113156]=0;a[9628264]=0;c[2407033]=0;Y=c[3541206]|0;c[3541190]=Y;c[3541198]=Y;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=Y+256;c[3541199]=Y+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=Y+512;c[3541200]=Y+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=Y+768;c[3541201]=Y+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;lw(c[3540984]|0);a[c[2406700]|0]=0;c[3541206]=c[2386622];P=0;i=e;return P|0}}while(0);c[2414924]=0;P=1;i=e;return P|0}function et9(a){a=a|0;return(ag((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0,a)|0)/625e4|0|0}function eua(a){a=a|0;return(ag((c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0,a)|0)/125e5|0|0}function eub(a,d,f,g){a=a|0;d=d|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=c[2386202]|0;i=c[2439658]|0;j=c[3530804]|0;k=c[2112926]|0;if((g|0)==0){g=c[2113068]|0;l=0;do{m=(l<<3&1016)-d|0;n=(l>>7<<3)-f|0;o=b[i+(l<<1)>>1]|0;p=e[h+((c[a+(o>>11<<2)>>2]<<11|o&2047)<<1)>>1]|0;o=p>>>6&127;L5416:do{if((m|0)<(g|0)){q=c[2113070]|0;if((n|0)>=(q|0)|(n|0)<-7|(m|0)<-7){break}do{if((m|0)>-1){if(!((m|0)<(g-7|0)&(n|0)>-1)){break}if((n|0)>=(q-7|0)){break}Si(k,p,m,n,o,3,0,j);break L5416}}while(0);Sj(k,p,m,n,o,3,0,j)}}while(0);l=l+1|0;}while((l|0)<8192);return}else{l=0;do{g=(l<<3&1016)-d|0;o=(l>>7<<3)-f|0;n=b[i+(l<<1)>>1]|0;m=b[h+((c[a+(n>>11<<2)>>2]<<11|n&2047)<<1)>>1]|0;n=m&65535;L5402:do{if(m<<16>>16!=0){p=n>>>6&127;q=c[2113068]|0;if((g|0)>=(q|0)){break}r=c[2113070]|0;if((o|0)>=(r|0)|(o|0)<-7|(g|0)<-7){break}do{if((g|0)>-1){if(!((g|0)<(q-7|0)&(o|0)>-1)){break}if((o|0)>=(r-7|0)){break}Sq(k,n,g,o,p,3,0,0,j);break L5402}}while(0);Sr(k,n,g,o,p,3,0,0,j)}}while(0);l=l+1|0;}while((l|0)<8192);return}}function euc(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;f=c[2386426]|0;g=c[2113070]|0;h=g-1|0;i=c[3530568]|0;j=c[2112926]|0;k=c[2113068]|0;l=0;do{m=e[f+((l|4)<<1)>>1]|0;do{if((m>>>6&3|0)==(d|0)){n=b[f+((l|1)<<1)>>1]&511;o=n+127|0;p=e[f+(l<<1)>>1]|0;q=p&255;if((q|0)>=(g|0)){break}r=p>>>8;p=(r|0)<(g|0)?r:h;r=e[f+((l|2)<<1)>>1]|0;s=r&256;t=(s|0)==0;u=(s>>>8|-192)+(o>>>0>511?n-385|0:o)|0;o=m<<4&1008|1024;n=q+1|0;if((n|0)>(p|0)){break}q=r<<1&254;r=i+((e[f+((l|3)<<1)>>1]|0|m<<8&2031616)<<1)|0;s=n;while(1){n=r+q|0;v=ag(k,s)|0;w=0;x=0;y=0;L5435:while(1){z=r+(x+q)|0;A=a[z]|0;B=A&255;if(t){C=B&240;do{if((C|0)==0){D=A;E=3985}else if((C|0)==240){if((w|0)==0){F=y;G=1;H=A}else{break L5435}}else{I=y+u|0;if(!((I|0)>-1&(I|0)<(k|0))){D=A;E=3985;break}b[j+(I+v<<1)>>1]=(B>>>4|o)&65535;D=a[z]|0;E=3985}}while(0);if((E|0)==3985){E=0;F=y+1|0;G=w;H=D}C=H&15;do{if((C|0)==15){if((G|0)==0){J=F;K=1}else{break L5435}}else if((C|0)==0){E=3990}else{I=F+u|0;if(!((I|0)>-1&(I|0)<(k|0))){E=3990;break}b[j+(I+v<<1)>>1]=(C|o)&65535;E=3990}}while(0);if((E|0)==3990){E=0;J=F+1|0;K=G}L=J;M=x+1|0;N=K}else{C=B&15;do{if((C|0)==15){if((w|0)==0){O=y;P=1;Q=A}else{break L5435}}else if((C|0)==0){R=A;E=3974}else{I=y+u|0;if(!((I|0)>-1&(I|0)<(k|0))){R=A;E=3974;break}b[j+(I+v<<1)>>1]=(C|o)&65535;R=a[z]|0;E=3974}}while(0);if((E|0)==3974){E=0;O=y+1|0;P=w;Q=R}z=Q&255;C=z&240;do{if((C|0)==0){E=3979}else if((C|0)==240){if((P|0)==0){S=O;T=1}else{break L5435}}else{A=O+u|0;if(!((A|0)>-1&(A|0)<(k|0))){E=3979;break}b[j+(A+v<<1)>>1]=(z>>>4|o)&65535;E=3979}}while(0);if((E|0)==3979){E=0;S=O+1|0;T=P}L=S;M=x-1|0;N=T}if((M|0)<512){w=N;x=M;y=L}else{break}}y=s+1|0;if((y|0)>(p|0)){break}else{r=n;s=y}}}}while(0);l=l+8|0;}while((l|0)<1024);return}function eud(b){b=b|0;var c=0;switch(b|0){case 1900580:{c=a[9625597]&63^63;break};case 1900577:{c=~a[9625592];break};case 1900579:{c=~a[9625594];break};case 1900583:{c=~a[9625598];break};case 1900576:{c=a[9625593]&63^63;break};case 1900581:{c=~a[9625596];break};case 1900582:{c=~((a[670544]&1)<<2|a[9625599]);break};case 1900578:{c=a[9625595]&63^63;break};case 1900557:{c=a[7024792]|0;break};default:{c=0}}return c|0}function eue(b){b=b|0;var c=0;if((b|0)==1900578){c=((d[9625595]|0)<<8&16128|(d[9625594]|0))^16383;return c|0}else if((b|0)==1900582){c=~(((a[670544]&1)<<2|(d[9625599]|0))<<8|(d[9625598]|0));return c|0}else if((b|0)==1900580){c=((d[9625597]|0)<<8&16128|(d[9625596]|0))^16383;return c|0}else if((b|0)==1900576){c=((d[9625593]|0)<<8&16128|(d[9625592]|0))^16383;return c|0}else{c=0;return c|0}return 0}function euf(d,f){d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((d|0)==1900557){a[7024792]=f;g=f&255;h=c[2411418]|0;i=c[2385754]|0;j=0;do{k=e[h+(j<<1)>>1]|0;l=k<<3&248;m=k>>>2&248;n=k>>>7&248;k=ag(l>>>5|l,g)|0;l=(ag(m>>>5|m,g)|0)>>>8;b[i+(j<<1)>>1]=((ag(n>>>5|n,g)|0)>>>11|k&63488|l<<3&2016)&65535;j=j+1|0;}while((j|0)<16384);return}else if((d|0)==1900556){a[9775448]=f;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12;return}else{return}}function eug(a,c){a=a|0;c=c|0;if((a|0)==1835010){b[7057664]=c&511;return}else if((a|0)==1835014){b[7057648]=c&511;return}else if((a|0)==1835008){b[7057668]=c&511;return}else if((a|0)==1835012){b[7057656]=c&511;return}else{return}}function euh(a,e){a=a|0;e=e|0;var f=0,g=0,h=0,i=0;f=a>>>1&16383;b[(c[2411418]|0)+(f<<1)>>1]=e;a=e&65535;e=a<<3&248;g=a>>>2&248;h=a>>>7&248;a=d[7024792]|0;i=ag(e>>>5|e,a)|0;e=(ag(g>>>5|g,a)|0)>>>8;g=((ag(h>>>5|h,a)|0)>>>11|i&63488|e<<3&2016)&65535;b[(c[2385754]|0)+(f<<1)>>1]=g;return}function eui(b){b=b|0;var d=0,e=0;d=b&65535;if((d|0)==57344){e=a[9775448]|0}else if((d|0)==55296){e=c[2113156]&255}else if((d|0)==51201){e=c[(c[3531464]|0)+4240>>2]&255}else{e=0}return e|0}function euj(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((e|0)==51201){b=c[2113304]|0;a[14168504+b|0]=d;mv(0,b,d&255);return}else if((e|0)==55296){Uv(0,d);return}else if((e|0)==51200){c[2113304]=d&255;return}else{return}}function euk(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2293148+(b*112|0)>>2];c[a+104>>2]=c[2293152+(b*112|0)>>2];c[a+108>>2]=c[2293156+(b*112|0)>>2];d=0;return d|0}function eul(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=2293048+(b*112|0);e=0;return e|0}function eum(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>28){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1010784+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function eun(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>36){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=2294728+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function euo(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0;e=i;i=i+1320|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;B=e+1200|0;C=e+1312|0;c[2426690]=0;c[2411328]=0;c[2411300]=1048576;c[2405560]=1114112;c[2405558]=1376256;c[2405556]=18153472;c[3541206]=22347776;c[2405626]=22872064;c[2406904]=22872064;c[2406902]=22880256;c[2418174]=22888448;c[2411364]=22896640;c[2411418]=22904832;c[2411900]=22937600;c[2411342]=23003136;c[2411590]=23009280;c[2385754]=23009280;c[2411376]=23042048;D=0;while(1){if((D|0)>=1024){break}E=9638528+(D<<2)|0;if((c[E>>2]|0)==0){F=4082;break}else{D=D+1|0}}do{if((F|0)==4082){D=gGq(23123968)|0;c[E>>2]=D;if((D|0)==0){break}c[2426690]=D;gGz(D|0,0,23123968);c[2411328]=D;c[2411300]=D+1048576;c[2405560]=D+1114112;c[2405558]=D+1376256;c[2405556]=D+18153472;c[3541206]=D+22347776;G=D+22872064|0;c[2405626]=G;c[2406904]=G;c[2406902]=D+22880256;c[2418174]=D+22888448;c[2411364]=D+22896640;c[2411418]=D+22904832;c[2411900]=D+22937600;c[2411342]=D+23003136;G=D+23009280|0;c[2411590]=G;c[2385754]=G;c[2411376]=D+23042048;c[2414130]=D+23123968;if((R6(D,0,2)|0)!=0){H=1;i=e;return H|0}if((R6((c[2411328]|0)+1|0,1,2)|0)!=0){H=1;i=e;return H|0}if((R6((c[2411328]|0)+524288|0,2,2)|0)!=0){H=1;i=e;return H|0}if((R6((c[2411328]|0)+524289|0,3,2)|0)!=0){H=1;i=e;return H|0}D=c[2411300]|0;if((c[3542200]|0)==0){H=1;i=e;return H|0}G=B+108|0;c[G>>2]=0;I=B+100|0;c[I>>2]=0;J=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[J&16383](B,4)|0;do{if((c[G>>2]|0)==0){K=0}else{J=c[I>>2]|0;c[C>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](C,4,0)|0;if((J|0)<1){H=1;i=e;return H|0}if((gzL(D,0,4)|0)==0){K=0;break}else{H=1}i=e;return H|0}}while(0);while(1){if((K|0)>=1024){M=0;break}N=9638528+(K<<2)|0;if((c[N>>2]|0)==0){F=4094;break}else{K=K+1|0}}L5594:do{if((F|0)==4094){D=gGq(131072)|0;c[N>>2]=D;if((D|0)==0){M=0;break}gGz(D|0,0,131072);do{if((c[3542200]|0)!=0){I=z+108|0;c[I>>2]=0;G=z+100|0;c[G>>2]=0;J=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[J&16383](z,5)|0;if((c[I>>2]|0)==0){break}I=c[G>>2]|0;c[A>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](A,5,0)|0;if((I|0)<1){break}gzL(D,0,5)|0}}while(0);I=D;G=c[2405560]|0;J=0;while(1){L=I;O=G;P=0;while(1){Q=a[L]|0;a[O]=(Q&255)>>>2<<1&2|Q&1|(Q&255)>>>4<<2&4|(Q&255)>>>6<<3&8;Q=a[L]|0;a[O+1|0]=(Q&255)>>>7<<3|(Q&255)>>>1&1|(Q&255)>>>3<<1&2|(Q&255)>>>5<<2&4;Q=L+8|0;R=a[Q]|0;a[O+2|0]=(R&255)>>>2<<1&2|R&1|(R&255)>>>4<<2&4|(R&255)>>>6<<3&8;R=a[Q]|0;a[O+3|0]=(R&255)>>>7<<3|(R&255)>>>1&1|(R&255)>>>3<<1&2|(R&255)>>>5<<2&4;R=L+16|0;Q=a[R]|0;a[O+4|0]=(Q&255)>>>2<<1&2|Q&1|(Q&255)>>>4<<2&4|(Q&255)>>>6<<3&8;Q=a[R]|0;a[O+5|0]=(Q&255)>>>7<<3|(Q&255)>>>1&1|(Q&255)>>>3<<1&2|(Q&255)>>>5<<2&4;Q=L+24|0;R=a[Q]|0;a[O+6|0]=(R&255)>>>2<<1&2|R&1|(R&255)>>>4<<2&4|(R&255)>>>6<<3&8;R=a[Q]|0;a[O+7|0]=(R&255)>>>7<<3|(R&255)>>>1&1|(R&255)>>>3<<1&2|(R&255)>>>5<<2&4;R=P+1|0;if((R|0)<8){L=L+1|0;O=O+8|0;P=R}else{break}}P=J+1|0;if((P|0)<4096){I=I+32|0;G=G+64|0;J=P}else{S=0;break}}while(1){if((S|0)>=1024){M=0;break L5594}T=9638528+(S<<2)|0;if((c[T>>2]|0)==(D|0)){break}else{S=S+1|0}}gGr(D);c[T>>2]=0;M=0}}while(0);while(1){if((M|0)>=1024){U=0;break}V=9638528+(M<<2)|0;if((c[V>>2]|0)==0){F=4108;break}else{M=M+1|0}}L5614:do{if((F|0)==4108){J=gGq(10485760)|0;c[V>>2]=J;if((J|0)==0){U=0;break}gGz(J|0,0,10485760);do{if((c[3542200]|0)!=0){G=x+108|0;c[G>>2]=0;I=x+100|0;c[I>>2]=0;P=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[P&16383](x,6)|0;if((c[G>>2]|0)==0){break}G=c[I>>2]|0;c[y>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](y,6,0)|0;if((G|0)<1){break}gzL(J,0,6)|0}}while(0);D=J+2097152|0;do{if((c[3542200]|0)!=0){G=v+108|0;c[G>>2]=0;I=v+100|0;c[I>>2]=0;P=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[P&16383](v,7)|0;if((c[G>>2]|0)==0){break}G=c[I>>2]|0;c[w>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](w,7,0)|0;if((G|0)<1){break}gzL(D,0,7)|0}}while(0);G=J+4194304|0;do{if((c[3542200]|0)!=0){I=t+108|0;c[I>>2]=0;P=t+100|0;c[P>>2]=0;O=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[O&16383](t,8)|0;if((c[I>>2]|0)==0){break}I=c[P>>2]|0;c[u>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](u,8,0)|0;if((I|0)<1){break}gzL(G,0,8)|0}}while(0);I=J+6291456|0;do{if((c[3542200]|0)!=0){P=r+108|0;c[P>>2]=0;O=r+100|0;c[O>>2]=0;L=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[L&16383](r,9)|0;if((c[P>>2]|0)==0){break}P=c[O>>2]|0;c[s>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](s,9,0)|0;if((P|0)<1){break}gzL(I,0,9)|0}}while(0);P=J+8388608|0;do{if((c[3542200]|0)!=0){O=p+108|0;c[O>>2]=0;L=p+100|0;c[L>>2]=0;R=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[R&16383](p,10)|0;if((c[O>>2]|0)==0){break}O=c[L>>2]|0;c[q>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](q,10,0)|0;if((O|0)<1){break}gzL(P,0,10)|0}}while(0);O=J;L=D;R=G;Q=I;W=P;X=c[2405558]|0;Y=0;while(1){Z=O;_=L;$=R;aa=Q;ab=W;ac=X;ad=0;while(1){ae=Z+16|0;af=_+16|0;ag=$+16|0;ah=aa+16|0;ai=ab+16|0;aj=0;do{ak=7-aj|0;a[ac+ak|0]=((d[_]|0)>>>(aj>>>0)<<1&2|(d[Z]|0)>>>(aj>>>0)&1|(d[$]|0)>>>(aj>>>0)<<2&4|(d[aa]|0)>>>(aj>>>0)<<3&8|(d[ab]|0)>>>(aj>>>0)<<4&16)&255;a[ac+(ak+8)|0]=((d[af]|0)>>>(aj>>>0)<<1&2|(d[ae]|0)>>>(aj>>>0)&1|(d[ag]|0)>>>(aj>>>0)<<2&4|(d[ah]|0)>>>(aj>>>0)<<3&8|(d[ai]|0)>>>(aj>>>0)<<4&16)&255;aj=aj+1|0;}while((aj|0)<8);aj=ad+1|0;if((aj|0)<16){Z=Z+1|0;_=_+1|0;$=$+1|0;aa=aa+1|0;ab=ab+1|0;ac=ac+16|0;ad=aj}else{break}}ad=Y+1|0;if((ad|0)<65536){O=O+32|0;L=L+32|0;R=R+32|0;Q=Q+32|0;W=W+32|0;X=X+256|0;Y=ad}else{al=0;break}}while(1){if((al|0)>=1024){U=0;break L5614}am=9638528+(al<<2)|0;if((c[am>>2]|0)==(J|0)){break}else{al=al+1|0}}gGr(J);c[am>>2]=0;U=0}}while(0);while(1){if((U|0)>=1024){break}an=9638528+(U<<2)|0;if((c[an>>2]|0)==0){F=4140;break}else{U=U+1|0}}L5657:do{if((F|0)==4140){Y=gGq(3145728)|0;c[an>>2]=Y;if((Y|0)==0){break}gGz(Y|0,0,3145728);do{if((c[3542200]|0)!=0){X=n+108|0;c[X>>2]=0;W=n+100|0;c[W>>2]=0;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Q&16383](n,11)|0;if((c[X>>2]|0)==0){break}X=c[W>>2]|0;c[o>>2]=9534384;W=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[W&16383](o,11,0)|0;if((X|0)<1){break}gzL(Y,0,11)|0}}while(0);J=Y+1048576|0;do{if((c[3542200]|0)!=0){X=l+108|0;c[X>>2]=0;W=l+100|0;c[W>>2]=0;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Q&16383](l,12)|0;if((c[X>>2]|0)==0){break}X=c[W>>2]|0;c[m>>2]=9534384;W=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[W&16383](m,12,0)|0;if((X|0)<1){break}gzL(J,0,12)|0}}while(0);X=Y+2097152|0;do{if((c[3542200]|0)!=0){W=j+108|0;c[W>>2]=0;Q=j+100|0;c[Q>>2]=0;R=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[R&16383](j,13)|0;if((c[W>>2]|0)==0){break}W=c[Q>>2]|0;c[k>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](k,13,0)|0;if((W|0)<1){break}gzL(X,0,13)|0}}while(0);W=Y;Q=J;R=X;L=c[2405556]|0;O=0;while(1){P=W;I=Q;G=R;D=L;ad=0;while(1){ac=G+1|0;ab=I+1|0;aa=P+1|0;$=G+32|0;_=G+33|0;Z=I+32|0;aj=I+33|0;ai=P+32|0;ah=P+33|0;ag=0;do{ae=7-ag|0;a[D+ae|0]=((d[ac]|0)>>>(ag>>>0)<<1&2|(d[G]|0)>>>(ag>>>0)&1|(d[I]|0)>>>(ag>>>0)<<2&4|(d[ab]|0)>>>(ag>>>0)<<3&8|(d[P]|0)>>>(ag>>>0)<<4&16|(d[aa]|0)>>>(ag>>>0)<<5&32)&255;a[D+(ae+8)|0]=((d[_]|0)>>>(ag>>>0)<<1&2|(d[$]|0)>>>(ag>>>0)&1|(d[Z]|0)>>>(ag>>>0)<<2&4|(d[aj]|0)>>>(ag>>>0)<<3&8|(d[ai]|0)>>>(ag>>>0)<<4&16|(d[ah]|0)>>>(ag>>>0)<<5&32)&255;ag=ag+1|0;}while((ag|0)<8);ag=ad+1|0;if((ag|0)<16){P=P+2|0;I=I+2|0;G=G+2|0;D=D+16|0;ad=ag}else{break}}ad=O+1|0;if((ad|0)<16384){W=W+64|0;Q=Q+64|0;R=R+64|0;L=L+256|0;O=ad}else{ao=0;break}}while(1){if((ao|0)>=1024){break L5657}ap=9638528+(ao<<2)|0;if((c[ap>>2]|0)==(Y|0)){break}else{ao=ao+1|0}}gGr(Y);c[ap>>2]=0}}while(0);O=c[3541206]|0;do{if((c[3542200]|0)!=0){L=f+108|0;c[L>>2]=0;R=f+100|0;c[R>>2]=0;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Q&16383](f,14)|0;if((c[L>>2]|0)==0){break}L=c[R>>2]|0;c[g>>2]=9534384;R=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[R&16383](g,14,0)|0;if((L|0)<1){break}gzL(O,0,14)|0}}while(0);fxU(0,425984);if((c[2394]|0)==0){aq=c[2112932]|0}else{c[2394]=0;O=c[3532596]|0;c[2112932]=O;L=c[3532592]|0;if((L|0)!=0){gGC(9104152,L|0,280)|0}c[2113054]=c[2113060];aq=O}O=c[2411328]|0;L=aq|0;R=0;while(1){Q=O+R|0;c[L>>2]=Q;c[L+131072>>2]=Q;Q=R+1024|0;if(Q>>>0>1048575){break}else{L=L+4|0;R=Q}}R=c[2406904]|0;L=R;c[aq+4096>>2]=L;c[aq+69632>>2]=L;c[aq+135168>>2]=L;L=R+1024|0;c[aq+4100>>2]=L;c[aq+69636>>2]=L;c[aq+135172>>2]=L;L=R+2048|0;c[aq+4104>>2]=L;c[aq+69640>>2]=L;c[aq+135176>>2]=L;L=R+3072|0;c[aq+4108>>2]=L;c[aq+69644>>2]=L;c[aq+135180>>2]=L;L=R+4096|0;c[aq+4112>>2]=L;c[aq+69648>>2]=L;c[aq+135184>>2]=L;L=R+5120|0;c[aq+4116>>2]=L;c[aq+69652>>2]=L;c[aq+135188>>2]=L;L=R+6144|0;c[aq+4120>>2]=L;c[aq+69656>>2]=L;c[aq+135192>>2]=L;L=R+7168|0;c[aq+4124>>2]=L;c[aq+69660>>2]=L;c[aq+135196>>2]=L;L=c[2406902]|0;R=L;c[aq+4128>>2]=R;c[aq+69664>>2]=R;c[aq+135200>>2]=R;R=L+1024|0;c[aq+4132>>2]=R;c[aq+69668>>2]=R;c[aq+135204>>2]=R;R=L+2048|0;c[aq+4136>>2]=R;c[aq+69672>>2]=R;c[aq+135208>>2]=R;R=L+3072|0;c[aq+4140>>2]=R;c[aq+69676>>2]=R;c[aq+135212>>2]=R;R=L+4096|0;c[aq+4144>>2]=R;c[aq+69680>>2]=R;c[aq+135216>>2]=R;R=L+5120|0;c[aq+4148>>2]=R;c[aq+69684>>2]=R;c[aq+135220>>2]=R;R=L+6144|0;c[aq+4152>>2]=R;c[aq+69688>>2]=R;c[aq+135224>>2]=R;R=L+7168|0;c[aq+4156>>2]=R;c[aq+69692>>2]=R;c[aq+135228>>2]=R;R=c[2418174]|0;L=R;c[aq+5120>>2]=L;c[aq+70656>>2]=L;c[aq+136192>>2]=L;L=R+1024|0;c[aq+5124>>2]=L;c[aq+70660>>2]=L;c[aq+136196>>2]=L;L=R+2048|0;c[aq+5128>>2]=L;c[aq+70664>>2]=L;c[aq+136200>>2]=L;L=R+3072|0;c[aq+5132>>2]=L;c[aq+70668>>2]=L;c[aq+136204>>2]=L;L=R+4096|0;c[aq+5136>>2]=L;c[aq+70672>>2]=L;c[aq+136208>>2]=L;L=R+5120|0;c[aq+5140>>2]=L;c[aq+70676>>2]=L;c[aq+136212>>2]=L;L=R+6144|0;c[aq+5144>>2]=L;c[aq+70680>>2]=L;c[aq+136216>>2]=L;L=R+7168|0;c[aq+5148>>2]=L;c[aq+70684>>2]=L;c[aq+136220>>2]=L;L=c[2411364]|0;R=L;c[aq+5152>>2]=R;c[aq+70688>>2]=R;c[aq+136224>>2]=R;R=L+1024|0;c[aq+5156>>2]=R;c[aq+70692>>2]=R;c[aq+136228>>2]=R;R=L+2048|0;c[aq+5160>>2]=R;c[aq+70696>>2]=R;c[aq+136232>>2]=R;R=L+3072|0;c[aq+5164>>2]=R;c[aq+70700>>2]=R;c[aq+136236>>2]=R;R=L+4096|0;c[aq+5168>>2]=R;c[aq+70704>>2]=R;c[aq+136240>>2]=R;R=L+5120|0;c[aq+5172>>2]=R;c[aq+70708>>2]=R;c[aq+136244>>2]=R;R=L+6144|0;c[aq+5176>>2]=R;c[aq+70712>>2]=R;c[aq+136248>>2]=R;R=L+7168|0;c[aq+5180>>2]=R;c[aq+70716>>2]=R;c[aq+136252>>2]=R;R=c[2411418]|0;L=aq+6144|0;O=1572864;while(1){Q=R+(O-1572864)|0;c[L>>2]=Q;c[L+131072>>2]=Q;Q=O+1024|0;if(Q>>>0>1605631){break}else{L=L+4|0;O=Q}}O=c[2411900]|0;L=aq+7936|0;R=2031616;while(1){Q=O+(R-2031616)|0;c[L>>2]=Q;c[L+65536>>2]=Q;c[L+131072>>2]=Q;Q=R+1024|0;if(Q>>>0>2097151){break}else{L=L+4|0;R=Q}}c[aq+71680>>2]=1;c[aq+71684>>2]=1;c[aq+71688>>2]=1;c[aq+71692>>2]=1;c[aq+71696>>2]=1;c[aq+71700>>2]=1;c[aq+71704>>2]=1;c[aq+71708>>2]=1;c[aq+71712>>2]=1;c[aq+71716>>2]=1;c[aq+71720>>2]=1;c[aq+71724>>2]=1;c[aq+71728>>2]=1;c[aq+71732>>2]=1;c[aq+71736>>2]=1;c[aq+71740>>2]=1;c[aq+71744>>2]=1;c[aq+71748>>2]=1;c[aq+71752>>2]=1;c[aq+71756>>2]=1;c[aq+71760>>2]=1;c[aq+71764>>2]=1;c[aq+71768>>2]=1;c[aq+71772>>2]=1;c[aq+71776>>2]=1;c[aq+71780>>2]=1;c[aq+71784>>2]=1;c[aq+71788>>2]=1;c[aq+71792>>2]=1;c[aq+71796>>2]=1;c[aq+71800>>2]=1;c[aq+71804>>2]=1;c[aq+196688>>2]=1174;c[aq+196608>>2]=552;c[aq+196728>>2]=382;c[aq+196648>>2]=380;c[aq+196732>>2]=1368;R=c[3532592]|0;if((R|0)!=0){gGC(R|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);R=c[2439330]|0;L=(R|0)==0;if(!L){O=R;gGC(9706056,O|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];O=c[3528484]|0;c[2076596]=O;Q=c[2417276]|0;c[3541536]=Q;c[1836236]=0;c[R+4180>>2]=2840;c[R+4184>>2]=952;W=c[2411300]|0;X=0;J=0;while(1){c[R+76+(J<<2)>>2]=W+(J<<8);ad=X+1&65535;if((ad&65535)>191){ar=0;as=0;break}else{X=ad;J=ad&65535}}while(1){J=W+(as<<8)|0;c[R+76+(as+512<<2)>>2]=J;c[R+76+(as+768<<2)>>2]=J;J=ar+1&65535;if((J&65535)>191){break}else{ar=J;as=J&65535}}W=c[2411342]|0;c[R+844>>2]=W;J=W+256|0;c[R+848>>2]=J;X=W+512|0;c[R+852>>2]=X;ad=W+768|0;c[R+856>>2]=ad;D=W+1024|0;c[R+860>>2]=D;G=W+1280|0;c[R+864>>2]=G;I=W+1536|0;c[R+868>>2]=I;P=W+1792|0;c[R+872>>2]=P;c[R+1868>>2]=W;c[R+1872>>2]=J;c[R+1876>>2]=X;c[R+1880>>2]=ad;c[R+1884>>2]=D;c[R+1888>>2]=G;c[R+1892>>2]=I;c[R+1896>>2]=P;c[R+2892>>2]=W;c[R+3916>>2]=W;c[R+2896>>2]=J;c[R+3920>>2]=J;c[R+2900>>2]=X;c[R+3924>>2]=X;c[R+2904>>2]=ad;c[R+3928>>2]=ad;c[R+2908>>2]=D;c[R+3932>>2]=D;c[R+2912>>2]=G;c[R+3936>>2]=G;c[R+2916>>2]=I;c[R+3940>>2]=I;c[R+2920>>2]=P;c[R+3944>>2]=P;c[R+1036>>2]=W+2048;c[R+1040>>2]=W+2304;c[R+1044>>2]=W+2560;c[R+1048>>2]=W+2816;c[R+1052>>2]=W+3072;c[R+1056>>2]=W+3328;c[R+1060>>2]=W+3584;c[R+1064>>2]=W+3840;c[R+1068>>2]=W+4096;c[R+1072>>2]=W+4352;c[R+1076>>2]=W+4608;c[R+1080>>2]=W+4864;c[R+1084>>2]=W+5120;c[R+1088>>2]=W+5376;c[R+1092>>2]=W+5632;c[R+1096>>2]=W+5888;P=240;I=240;while(1){c[R+76+(I+256<<2)>>2]=W+((I<<8)-59392);G=P+1&65535;if((G&65535)>255){at=240;au=240;break}else{P=G;I=G&65535}}while(1){I=W+((au<<8)-59392)|0;c[R+76+(au+512<<2)>>2]=I;c[R+76+(au+768<<2)>>2]=I;I=at+1&65535;if((I&65535)>255){break}else{at=I;au=I&65535}}if(!L){W=R;gGC(W|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=O;c[2417276]=Q;c[1836236]=-1;W=a[9680]|0;I=W?32e3:0;if(W){if(a[9624]|0){W=I*3|0;P=55930;while(1){if((P|0)>(W|0)){P=P>>1}else{av=1222;aw=P;break}}}else{av=2462;aw=I}c[2429380]=aw;c[3542124]=av;mw(3579545,aw);P=gGq(262144)|0;c[2406684]=P;gGz(P|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(3579545,11025)}c[(c[3531464]|0)+44344>>2]=408;h[745421]=.5;c[2436794]=1;h[745420]=.5;c[2436792]=2;Ux(0,12e3,1);c[2407030]=128;c[2407068]=3;c[3528492]=357954500/(c[2424]|0)|0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];P=c[3532592]|0;if((P|0)!=0){gGC(9104152,P|0,280)|0}c[2113054]=c[2113060]}c[2113050]=0;c[2276080]=0;RI();P=c[2394]|0;W=c[14130368+(P<<2)>>2]|0;if((W|0)!=0){gGC(W|0,9104152,280)|0}c[8452240+(P<<2)>>2]=c[2113054];c[2394]=-1;P=c[2439330]|0;W=(P|0)==0;if(!W){Q=P;gGC(9706056,Q|0,76)|0}Q=c[2438118]|0;c[2433530]=Q;O=c[3528484]|0;c[2076596]=O;R=c[2417276]|0;c[3541536]=R;c[1836236]=0;gGz(9706056,0,76);if(!W){W=P;gGC(W|0,9706056,76)|0}c[2438118]=Q;c[3528484]=O;c[2417276]=R;c[1836236]=-1;c[2113156]=0;a[9628264]=0;c[2407033]=0;R=c[3541206]|0;c[3541190]=R;c[3541198]=R;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=R+256;c[3541199]=R+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=R+512;c[3541200]=R+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=R+768;c[3541201]=R+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;mx(0);H=0;i=e;return H|0}}while(0);c[2426690]=0;H=1;i=e;return H|0}function eup(){var a=0,b=0,d=0,e=0,f=0;Uw(0);a=c[3531464]|0;c[a+44344>>2]=0;c[a+44348>>2]=0;if((a|0)!=0){gGr(a);c[3531464]=0}a=c[2406684]|0;if((a|0)!=0){gGr(a);c[2406684]=0}if((c[2392]|0)>=0){a=0;do{b=14130368+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}b=14130384+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}a=a+1|0;}while((a|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;fwZ();a=c[2426690]|0;b=0;while(1){if((b|0)>=1024){e=4231;break}f=9638528+(b<<2)|0;if((c[f>>2]|0)==(a|0)){break}else{b=b+1|0}}if((e|0)==4231){c[2426690]=0;return 0}gGr(a);c[f>>2]=0;c[2426690]=0;return 0}
function dCf(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;a=i;i=i+720|0;b=a|0;d=a+112|0;e=a+120|0;f=a+232|0;g=a+240|0;h=a+352|0;j=a+360|0;k=a+472|0;l=a+480|0;m=a+592|0;n=a+600|0;o=a+712|0;p=dCh()|0;q=c[3530642]|0;if((c[3542200]|0)==0){r=1;i=a;return r|0}s=n+108|0;c[s>>2]=0;t=n+100|0;c[t>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,6)|0;do{if((c[s>>2]|0)!=0){n=c[t>>2]|0;c[o>>2]=9534384;u=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[u&16383](o,6,0)|0;if((n|0)<1){r=1;i=a;return r|0}if((gzL(q,0,6)|0)==0){break}else{r=1}i=a;return r|0}}while(0);q=(c[3530642]|0)+4096|0;if((c[3542200]|0)==0){r=1;i=a;return r|0}o=l+108|0;c[o>>2]=0;t=l+100|0;c[t>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,7)|0;do{if((c[o>>2]|0)!=0){l=c[t>>2]|0;c[m>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](m,7,0)|0;if((l|0)<1){r=1;i=a;return r|0}if((gzL(q,0,7)|0)==0){break}else{r=1}i=a;return r|0}}while(0);q=(c[3530642]|0)+8192|0;if((c[3542200]|0)==0){r=1;i=a;return r|0}m=j+108|0;c[m>>2]=0;t=j+100|0;c[t>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,8)|0;do{if((c[m>>2]|0)!=0){j=c[t>>2]|0;c[k>>2]=9534384;o=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[o&16383](k,8,0)|0;if((j|0)<1){r=1;i=a;return r|0}if((gzL(q,0,8)|0)==0){break}else{r=1}i=a;return r|0}}while(0);q=(c[3530642]|0)+12288|0;if((c[3542200]|0)==0){r=1;i=a;return r|0}k=g+108|0;c[k>>2]=0;t=g+100|0;c[t>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,9)|0;do{if((c[k>>2]|0)!=0){g=c[t>>2]|0;c[h>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](h,9,0)|0;if((g|0)<1){r=1;i=a;return r|0}if((gzL(q,0,9)|0)==0){break}else{r=1}i=a;return r|0}}while(0);q=(c[2385950]|0)+36864|0;if((c[3542200]|0)==0){r=1;i=a;return r|0}h=e+108|0;c[h>>2]=0;t=e+100|0;c[t>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,13)|0;do{if((c[h>>2]|0)!=0){e=c[t>>2]|0;c[f>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](f,13,0)|0;if((e|0)<1){r=1;i=a;return r|0}if((gzL(q,0,13)|0)==0){break}else{r=1}i=a;return r|0}}while(0);q=(c[2385950]|0)+53248|0;if((c[3542200]|0)==0){r=1;i=a;return r|0}f=b+108|0;c[f>>2]=0;t=b+100|0;c[t>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](b,14)|0;if((c[f>>2]|0)==0){r=p;i=a;return r|0}f=c[t>>2]|0;c[d>>2]=9534384;gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](d,14,0)|0;if((f|0)<1){r=1;i=a;return r|0}f=(gzL(q,0,14)|0)==0;r=f?p:1;i=a;return r|0}function dCg(){var a=0,b=0,e=0,f=0,g=0;a=c[3531022]|0;b=c[3530070]|0;e=0;do{f=d[a+e|0]|0;g=d[a+(e+256)|0]|0;c[b+(e<<2)>>2]=(-(f>>>7)&143^255)-(-(f>>>5&1)&31)-(-(f>>>4&1)&14)-(-(f>>>6&1)&67)<<8&63488|(-(f&1)&14^255)-(-(f>>>1&1)&31)-(-(f>>>2&1)&67)-(-(f>>>3&1)&143)<<3&2016|((-(g&1)&14^255)-(-(g>>>1&1)&31)-(-(g>>>2&1)&67)-(-(g>>>3&1)&143)|0)>>>3&31;e=e+1|0;}while((e|0)<256);return}function dCh(){var a=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;a=i;i=i+1560|0;d=a|0;e=a+112|0;f=a+120|0;g=a+232|0;h=a+240|0;j=a+352|0;k=a+360|0;l=a+472|0;m=a+480|0;n=a+592|0;o=a+600|0;p=a+712|0;q=a+720|0;r=a+832|0;s=a+840|0;t=a+952|0;u=a+960|0;v=a+1072|0;w=a+1080|0;x=a+1192|0;y=a+1200|0;z=a+1312|0;A=a+1320|0;B=a+1432|0;C=a+1440|0;D=a+1552|0;E=0;while(1){if((E|0)>=1024){F=0;break}G=9638528+(E<<2)|0;if((c[G>>2]|0)==0){H=4977;break}else{E=E+1|0}}do{if((H|0)==4977){E=gGq(8192)|0;c[G>>2]=E;if((E|0)==0){F=0;break}gGz(E|0,0,8192);F=E}}while(0);if((c[3542200]|0)==0){I=1;i=a;return I|0}G=C+108|0;c[G>>2]=0;E=C+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](C,0)|0;do{if((c[G>>2]|0)!=0){C=c[E>>2]|0;c[D>>2]=9534384;J=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[J&16383](D,0,0)|0;if((C|0)<1){I=1;i=a;return I|0}if((gzL(F,0,0)|0)==0){break}else{I=1}i=a;return I|0}}while(0);D=c[2385950]|0;gGC(D|0,F|0,4096)|0;E=D+12288|0;D=F+4096|0;gGC(E|0,D|0,4096)|0;if((c[3542200]|0)==0){I=1;i=a;return I|0}E=A+108|0;c[E>>2]=0;G=A+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](A,1)|0;do{if((c[E>>2]|0)!=0){A=c[G>>2]|0;c[B>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](B,1,0)|0;if((A|0)<1){I=1;i=a;return I|0}if((gzL(F,0,1)|0)==0){break}else{I=1}i=a;return I|0}}while(0);B=c[2385950]|0;G=B+8192|0;gGC(G|0,F|0,2048)|0;G=B+18432|0;E=F+2048|0;gGC(G|0,E|0,2048)|0;G=B+4096|0;gGC(G|0,D|0,2048)|0;G=B+22528|0;B=F+6144|0;gGC(G|0,B|0,2048)|0;if((c[3542200]|0)==0){I=1;i=a;return I|0}G=y+108|0;c[G>>2]=0;A=y+100|0;c[A>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](y,2)|0;do{if((c[G>>2]|0)!=0){y=c[A>>2]|0;c[z>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](z,2,0)|0;if((y|0)<1){I=1;i=a;return I|0}if((gzL(F,0,2)|0)==0){break}else{I=1}i=a;return I|0}}while(0);z=c[2385950]|0;A=z+16384|0;gGC(A|0,F|0,2048)|0;A=z+10240|0;gGC(A|0,E|0,2048)|0;E=z+20480|0;gGC(E|0,D|0,2048)|0;D=z+6144|0;gGC(D|0,B|0,2048)|0;B=0;while(1){if((B|0)>=1024){break}K=9638528+(B<<2)|0;if((c[K>>2]|0)==(F|0)){H=4994;break}else{B=B+1|0}}if((H|0)==4994){gGr(F);c[K>>2]=0}K=c[3529764]|0;if((c[3542200]|0)==0){I=1;i=a;return I|0}F=w+108|0;c[F>>2]=0;H=w+100|0;c[H>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](w,3)|0;do{if((c[F>>2]|0)!=0){w=c[H>>2]|0;c[x>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](x,3,0)|0;if((w|0)<1){I=1;i=a;return I|0}if((gzL(K,0,3)|0)==0){break}else{I=1}i=a;return I|0}}while(0);K=c[3530878]|0;if((c[3542200]|0)==0){I=1;i=a;return I|0}x=u+108|0;c[x>>2]=0;H=u+100|0;c[H>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](u,4)|0;do{if((c[x>>2]|0)!=0){u=c[H>>2]|0;c[v>>2]=9534384;F=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[F&16383](v,4,0)|0;if((u|0)<1){I=1;i=a;return I|0}if((gzL(K,0,4)|0)==0){break}else{I=1}i=a;return I|0}}while(0);K=(c[3530878]|0)+4096|0;if((c[3542200]|0)==0){I=1;i=a;return I|0}v=s+108|0;c[v>>2]=0;H=s+100|0;c[H>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](s,5)|0;do{if((c[v>>2]|0)!=0){s=c[H>>2]|0;c[t>>2]=9534384;x=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[x&16383](t,5,0)|0;if((s|0)<1){I=1;i=a;return I|0}if((gzL(K,0,5)|0)==0){break}else{I=1}i=a;return I|0}}while(0);K=c[3530642]|0;if((c[3542200]|0)==0){I=1;i=a;return I|0}t=q+108|0;c[t>>2]=0;H=q+100|0;c[H>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](q,6)|0;do{if((c[t>>2]|0)!=0){q=c[H>>2]|0;c[r>>2]=9534384;v=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[v&16383](r,6,0)|0;if((q|0)<1){I=1;i=a;return I|0}if((gzL(K,0,6)|0)==0){break}else{I=1}i=a;return I|0}}while(0);K=(c[3530642]|0)+4096|0;if((c[3542200]|0)==0){I=1;i=a;return I|0}r=o+108|0;c[r>>2]=0;H=o+100|0;c[H>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](o,7)|0;do{if((c[r>>2]|0)!=0){o=c[H>>2]|0;c[p>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](p,7,0)|0;if((o|0)<1){I=1;i=a;return I|0}if((gzL(K,0,7)|0)==0){break}else{I=1}i=a;return I|0}}while(0);K=(c[3530642]|0)+8192|0;if((c[3542200]|0)==0){I=1;i=a;return I|0}p=m+108|0;c[p>>2]=0;H=m+100|0;c[H>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,8)|0;do{if((c[p>>2]|0)!=0){m=c[H>>2]|0;c[n>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](n,8,0)|0;if((m|0)<1){I=1;i=a;return I|0}if((gzL(K,0,8)|0)==0){break}else{I=1}i=a;return I|0}}while(0);K=(c[3530642]|0)+12288|0;if((c[3542200]|0)==0){I=1;i=a;return I|0}n=k+108|0;c[n>>2]=0;H=k+100|0;c[H>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,9)|0;do{if((c[n>>2]|0)!=0){k=c[H>>2]|0;c[l>>2]=9534384;p=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[p&16383](l,9,0)|0;if((k|0)<1){I=1;i=a;return I|0}if((gzL(K,0,9)|0)==0){break}else{I=1}i=a;return I|0}}while(0);K=c[3531022]|0;if((c[3542200]|0)==0){I=1;i=a;return I|0}l=h+108|0;c[l>>2]=0;H=h+100|0;c[H>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](h,10)|0;do{if((c[l>>2]|0)!=0){h=c[H>>2]|0;c[j>>2]=9534384;n=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[n&16383](j,10,0)|0;if((h|0)<1){I=1;i=a;return I|0}if((gzL(K,0,10)|0)==0){break}else{I=1}i=a;return I|0}}while(0);K=(c[3531022]|0)+256|0;if((c[3542200]|0)==0){I=1;i=a;return I|0}j=f+108|0;c[j>>2]=0;H=f+100|0;c[H>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,11)|0;do{if((c[j>>2]|0)!=0){f=c[H>>2]|0;c[g>>2]=9534384;l=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[l&16383](g,11,0)|0;if((f|0)<1){I=1;i=a;return I|0}if((gzL(K,0,11)|0)==0){break}else{I=1}i=a;return I|0}}while(0);K=(c[3531022]|0)+512|0;if((c[3542200]|0)==0){I=1;i=a;return I|0}g=d+108|0;c[g>>2]=0;H=d+100|0;c[H>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](d,12)|0;do{if((c[g>>2]|0)!=0){d=c[H>>2]|0;c[e>>2]=9534384;j=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[j&16383](e,12,0)|0;if((d|0)<1){I=1;i=a;return I|0}if((gzL(K,0,12)|0)==0){break}else{I=1}i=a;return I|0}}while(0);K=c[2439330]|0;e=(K|0)==0;if(!e){H=K;gGC(9706056,H|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];H=c[3528484]|0;c[2076596]=H;g=c[2417276]|0;c[3541536]=g;c[1836236]=0;c[K+4184>>2]=1214;if(!e){e=K;gGC(e|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=H;c[2417276]=g;c[1836236]=-1;I=0;i=a;return I|0}function dCi(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;a=i;i=i+1800|0;b=a|0;d=a+112|0;e=a+120|0;f=a+232|0;g=a+240|0;h=a+352|0;j=a+360|0;k=a+472|0;l=a+480|0;m=a+592|0;n=a+600|0;o=a+712|0;p=a+720|0;q=a+832|0;r=a+840|0;s=a+952|0;t=a+960|0;u=a+1072|0;v=a+1080|0;w=a+1192|0;x=a+1200|0;y=a+1312|0;z=a+1320|0;A=a+1432|0;B=a+1440|0;C=a+1552|0;D=a+1560|0;E=a+1672|0;F=a+1680|0;G=a+1792|0;H=c[2385950]|0;if((c[3542200]|0)==0){I=1;i=a;return I|0}J=F+108|0;c[J>>2]=0;K=F+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](F,0)|0;do{if((c[J>>2]|0)!=0){F=c[K>>2]|0;c[G>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](G,0,0)|0;if((F|0)<1){I=1;i=a;return I|0}if((gzL(H,0,0)|0)==0){break}else{I=1}i=a;return I|0}}while(0);H=(c[2385950]|0)+8192|0;if((c[3542200]|0)==0){I=1;i=a;return I|0}G=D+108|0;c[G>>2]=0;K=D+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](D,1)|0;do{if((c[G>>2]|0)!=0){D=c[K>>2]|0;c[E>>2]=9534384;J=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[J&16383](E,1,0)|0;if((D|0)<1){I=1;i=a;return I|0}if((gzL(H,0,1)|0)==0){break}else{I=1}i=a;return I|0}}while(0);H=(c[2385950]|0)+16384|0;if((c[3542200]|0)==0){I=1;i=a;return I|0}E=B+108|0;c[E>>2]=0;K=B+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](B,2)|0;do{if((c[E>>2]|0)!=0){B=c[K>>2]|0;c[C>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](C,2,0)|0;if((B|0)<1){I=1;i=a;return I|0}if((gzL(H,0,2)|0)==0){break}else{I=1}i=a;return I|0}}while(0);H=(c[2385950]|0)+32768|0;if((c[3542200]|0)==0){I=1;i=a;return I|0}C=z+108|0;c[C>>2]=0;K=z+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,3)|0;do{if((c[C>>2]|0)!=0){z=c[K>>2]|0;c[A>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](A,3,0)|0;if((z|0)<1){I=1;i=a;return I|0}if((gzL(H,0,3)|0)==0){break}else{I=1}i=a;return I|0}}while(0);H=c[3529764]|0;if((c[3542200]|0)==0){I=1;i=a;return I|0}A=x+108|0;c[A>>2]=0;K=x+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,4)|0;do{if((c[A>>2]|0)!=0){x=c[K>>2]|0;c[y>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](y,4,0)|0;if((x|0)<1){I=1;i=a;return I|0}if((gzL(H,0,4)|0)==0){break}else{I=1}i=a;return I|0}}while(0);H=c[3529718]|0;if((c[3542200]|0)==0){I=1;i=a;return I|0}y=v+108|0;c[y>>2]=0;K=v+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,5)|0;do{if((c[y>>2]|0)!=0){v=c[K>>2]|0;c[w>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](w,5,0)|0;if((v|0)<1){I=1;i=a;return I|0}if((gzL(H,0,5)|0)==0){break}else{I=1}i=a;return I|0}}while(0);H=c[3530642]|0;if((c[3542200]|0)==0){I=1;i=a;return I|0}w=t+108|0;c[w>>2]=0;K=t+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,6)|0;do{if((c[w>>2]|0)!=0){t=c[K>>2]|0;c[u>>2]=9534384;y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[y&16383](u,6,0)|0;if((t|0)<1){I=1;i=a;return I|0}if((gzL(H,0,6)|0)==0){break}else{I=1}i=a;return I|0}}while(0);H=(c[3530642]|0)+4096|0;if((c[3542200]|0)==0){I=1;i=a;return I|0}u=r+108|0;c[u>>2]=0;K=r+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,7)|0;do{if((c[u>>2]|0)!=0){r=c[K>>2]|0;c[s>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](s,7,0)|0;if((r|0)<1){I=1;i=a;return I|0}if((gzL(H,0,7)|0)==0){break}else{I=1}i=a;return I|0}}while(0);H=c[3530878]|0;s=c[3530642]|0;K=s+2048|0;gGC(H|0,K|0,2048)|0;K=H+2048|0;gGC(K|0,s|0,2048)|0;K=H+4096|0;u=s+6144|0;gGC(K|0,u|0,2048)|0;u=H+6144|0;H=s+4096|0;gGC(u|0,H|0,2048)|0;if((c[3542200]|0)==0){I=1;i=a;return I|0}H=p+108|0;c[H>>2]=0;u=p+100|0;c[u>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,8)|0;do{if((c[H>>2]|0)!=0){p=c[u>>2]|0;c[q>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](q,8,0)|0;if((p|0)<1){I=1;i=a;return I|0}if((gzL(s,0,8)|0)==0){break}else{I=1}i=a;return I|0}}while(0);s=(c[3530642]|0)+4096|0;if((c[3542200]|0)==0){I=1;i=a;return I|0}q=n+108|0;c[q>>2]=0;u=n+100|0;c[u>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,9)|0;do{if((c[q>>2]|0)!=0){n=c[u>>2]|0;c[o>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](o,9,0)|0;if((n|0)<1){I=1;i=a;return I|0}if((gzL(s,0,9)|0)==0){break}else{I=1}i=a;return I|0}}while(0);s=(c[3530642]|0)+8192|0;if((c[3542200]|0)==0){I=1;i=a;return I|0}o=l+108|0;c[o>>2]=0;u=l+100|0;c[u>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,10)|0;do{if((c[o>>2]|0)!=0){l=c[u>>2]|0;c[m>>2]=9534384;q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[q&16383](m,10,0)|0;if((l|0)<1){I=1;i=a;return I|0}if((gzL(s,0,10)|0)==0){break}else{I=1}i=a;return I|0}}while(0);s=(c[3530642]|0)+12288|0;if((c[3542200]|0)==0){I=1;i=a;return I|0}m=j+108|0;c[m>>2]=0;u=j+100|0;c[u>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,11)|0;do{if((c[m>>2]|0)!=0){j=c[u>>2]|0;c[k>>2]=9534384;o=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[o&16383](k,11,0)|0;if((j|0)<1){I=1;i=a;return I|0}if((gzL(s,0,11)|0)==0){break}else{I=1}i=a;return I|0}}while(0);s=c[3531022]|0;if((c[3542200]|0)==0){I=1;i=a;return I|0}k=g+108|0;c[k>>2]=0;u=g+100|0;c[u>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,12)|0;do{if((c[k>>2]|0)!=0){g=c[u>>2]|0;c[h>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](h,12,0)|0;if((g|0)<1){I=1;i=a;return I|0}if((gzL(s,0,12)|0)==0){break}else{I=1}i=a;return I|0}}while(0);s=(c[3531022]|0)+256|0;if((c[3542200]|0)==0){I=1;i=a;return I|0}h=e+108|0;c[h>>2]=0;u=e+100|0;c[u>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,13)|0;do{if((c[h>>2]|0)!=0){e=c[u>>2]|0;c[f>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](f,13,0)|0;if((e|0)<1){I=1;i=a;return I|0}if((gzL(s,0,13)|0)==0){break}else{I=1}i=a;return I|0}}while(0);s=(c[3531022]|0)+512|0;if((c[3542200]|0)==0){I=1;i=a;return I|0}f=b+108|0;c[f>>2]=0;u=b+100|0;c[u>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](b,14)|0;if((c[f>>2]|0)==0){I=0;i=a;return I|0}f=c[u>>2]|0;c[d>>2]=9534384;gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](d,14,0)|0;if((f|0)<1){I=1;i=a;return I|0}I=(gzL(s,0,14)|0)!=0|0;i=a;return I|0}function dCj(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;h=(d[c[2443706]|0]|0)<<9;i=(g|0)!=0;g=h+512|0;j=i?1:2;k=i?2:1;l=i?232:231;m=i?64:128;i=c[2386490]|0;n=c[2440368]|0;o=c[2112926]|0;p=c[3530642]|0;q=h;do{h=a[i+q|0]|0;do{if(h<<24>>24!=0){r=d[i+(q|3)|0]|0;s=r-8|0;t=d[i+(q|j)|0]|0;u=((d[i+(q|k)|0]|0)&b)+((t&e)<<f)|0;v=l-(h&255)|0;w=(d[n]|0)<<4|t&15;x=((d[i+(q|1)|0]|0)&m|0)!=0;y=(t&128|0)!=0;do{if(x){if(y){SN(o,u,s,v,w,2,0,0,p);break}else{SL(o,u,s,v,w,2,0,0,p);break}}else{if(y){SJ(o,u,s,v,w,2,0,0,p);break}else{SH(o,u,s,v,w,2,0,0,p);break}}}while(0);if((s|0)>=0){break}t=r+248|0;if(x){if(y){SN(o,u,t,v,w,2,0,0,p);break}else{SL(o,u,t,v,w,2,0,0,p);break}}else{if(y){SJ(o,u,t,v,w,2,0,0,p);break}else{SH(o,u,t,v,w,2,0,0,p);break}}}}while(0);q=q+4|0;}while((q|0)<(g|0));return}function dCk(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;b=i;i=i+120|0;d=b|0;e=b+112|0;f=dCh()|0;g=(c[2385950]|0)+45056|0;if((c[3542200]|0)==0){h=1;i=b;return h|0}j=d+108|0;c[j>>2]=0;k=d+100|0;c[k>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](d,13)|0;do{if((c[j>>2]|0)!=0){d=c[k>>2]|0;c[e>>2]=9534384;l=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[l&16383](e,13,0)|0;if((d|0)<1){h=1;i=b;return h|0}if((gzL(g,0,13)|0)==0){break}else{h=1}i=b;return h|0}}while(0);g=c[3531022]|0;e=0;while(1){k=g+e|0;a[k]=~a[k];k=e+1|0;if((k|0)<768){e=k}else{h=f;break}}i=b;return h|0}function dCl(){var b=0,d=0,e=0,f=0;b=dCh()|0;d=c[3531022]|0;e=0;do{f=d+e|0;a[f]=~a[f];e=e+1|0;}while((e|0)<512);return b|0}function dCm(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;b=i;i=i+1440|0;d=b|0;e=b+112|0;f=b+120|0;g=b+232|0;h=b+240|0;j=b+352|0;k=b+360|0;l=b+472|0;m=b+480|0;n=b+592|0;o=b+600|0;p=b+712|0;q=b+720|0;r=b+832|0;s=b+840|0;t=b+952|0;u=b+960|0;v=b+1072|0;w=b+1080|0;x=b+1192|0;y=b+1200|0;z=b+1312|0;A=b+1320|0;B=b+1432|0;C=c[2385950]|0;if((c[3542200]|0)==0){D=1;i=b;return D|0}E=A+108|0;c[E>>2]=0;F=A+100|0;c[F>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](A,4)|0;do{if((c[E>>2]|0)!=0){A=c[F>>2]|0;c[B>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](B,4,0)|0;if((A|0)<1){D=1;i=b;return D|0}if((gzL(C,0,4)|0)==0){break}else{D=1}i=b;return D|0}}while(0);C=c[3529764]|0;if((c[3542200]|0)==0){D=1;i=b;return D|0}B=y+108|0;c[B>>2]=0;F=y+100|0;c[F>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](y,5)|0;do{if((c[B>>2]|0)!=0){y=c[F>>2]|0;c[z>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](z,5,0)|0;if((y|0)<1){D=1;i=b;return D|0}if((gzL(C,0,5)|0)==0){break}else{D=1}i=b;return D|0}}while(0);C=c[3529764]|0;z=C+2048|0;gGC(z|0,C|0,2048)|0;z=C+4096|0;if((c[3542200]|0)==0){D=1;i=b;return D|0}C=w+108|0;c[C>>2]=0;F=w+100|0;c[F>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](w,6)|0;do{if((c[C>>2]|0)!=0){w=c[F>>2]|0;c[x>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](x,6,0)|0;if((w|0)<1){D=1;i=b;return D|0}if((gzL(z,0,6)|0)==0){break}else{D=1}i=b;return D|0}}while(0);z=c[3530878]|0;if((c[3542200]|0)==0){D=1;i=b;return D|0}x=u+108|0;c[x>>2]=0;F=u+100|0;c[F>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](u,7)|0;do{if((c[x>>2]|0)!=0){u=c[F>>2]|0;c[v>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](v,7,0)|0;if((u|0)<1){D=1;i=b;return D|0}if((gzL(z,0,7)|0)==0){break}else{D=1}i=b;return D|0}}while(0);z=(c[3530878]|0)+4096|0;if((c[3542200]|0)==0){D=1;i=b;return D|0}v=s+108|0;c[v>>2]=0;F=s+100|0;c[F>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](s,8)|0;do{if((c[v>>2]|0)!=0){s=c[F>>2]|0;c[t>>2]=9534384;x=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[x&16383](t,8,0)|0;if((s|0)<1){D=1;i=b;return D|0}if((gzL(z,0,8)|0)==0){break}else{D=1}i=b;return D|0}}while(0);z=c[3530642]|0;if((c[3542200]|0)==0){D=1;i=b;return D|0}t=q+108|0;c[t>>2]=0;F=q+100|0;c[F>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](q,9)|0;do{if((c[t>>2]|0)!=0){q=c[F>>2]|0;c[r>>2]=9534384;v=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[v&16383](r,9,0)|0;if((q|0)<1){D=1;i=b;return D|0}if((gzL(z,0,9)|0)==0){break}else{D=1}i=b;return D|0}}while(0);z=(c[3530642]|0)+4096|0;if((c[3542200]|0)==0){D=1;i=b;return D|0}r=o+108|0;c[r>>2]=0;F=o+100|0;c[F>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](o,10)|0;do{if((c[r>>2]|0)!=0){o=c[F>>2]|0;c[p>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](p,10,0)|0;if((o|0)<1){D=1;i=b;return D|0}if((gzL(z,0,10)|0)==0){break}else{D=1}i=b;return D|0}}while(0);z=(c[3530642]|0)+8192|0;if((c[3542200]|0)==0){D=1;i=b;return D|0}p=m+108|0;c[p>>2]=0;F=m+100|0;c[F>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,11)|0;do{if((c[p>>2]|0)!=0){m=c[F>>2]|0;c[n>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](n,11,0)|0;if((m|0)<1){D=1;i=b;return D|0}if((gzL(z,0,11)|0)==0){break}else{D=1}i=b;return D|0}}while(0);z=(c[3530642]|0)+12288|0;if((c[3542200]|0)==0){D=1;i=b;return D|0}n=k+108|0;c[n>>2]=0;F=k+100|0;c[F>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,12)|0;do{if((c[n>>2]|0)!=0){k=c[F>>2]|0;c[l>>2]=9534384;p=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[p&16383](l,12,0)|0;if((k|0)<1){D=1;i=b;return D|0}if((gzL(z,0,12)|0)==0){break}else{D=1}i=b;return D|0}}while(0);z=c[3531022]|0;if((c[3542200]|0)==0){D=1;i=b;return D|0}l=h+108|0;c[l>>2]=0;F=h+100|0;c[F>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](h,13)|0;do{if((c[l>>2]|0)!=0){h=c[F>>2]|0;c[j>>2]=9534384;n=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[n&16383](j,13,0)|0;if((h|0)<1){D=1;i=b;return D|0}if((gzL(z,0,13)|0)==0){break}else{D=1}i=b;return D|0}}while(0);z=(c[3531022]|0)+256|0;if((c[3542200]|0)==0){D=1;i=b;return D|0}j=f+108|0;c[j>>2]=0;F=f+100|0;c[F>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,14)|0;do{if((c[j>>2]|0)!=0){f=c[F>>2]|0;c[g>>2]=9534384;l=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[l&16383](g,14,0)|0;if((f|0)<1){D=1;i=b;return D|0}if((gzL(z,0,14)|0)==0){break}else{D=1}i=b;return D|0}}while(0);z=(c[3531022]|0)+512|0;if((c[3542200]|0)==0){D=1;i=b;return D|0}g=d+108|0;c[g>>2]=0;F=d+100|0;c[F>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](d,15)|0;do{if((c[g>>2]|0)==0){H=0}else{d=c[F>>2]|0;c[e>>2]=9534384;j=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[j&16383](e,15,0)|0;if((d|0)<1){D=1;i=b;return D|0}if((gzL(z,0,15)|0)==0){H=0;break}else{D=1}i=b;return D|0}}while(0);while(1){if((H|0)>=1024){I=0;break}J=9638528+(H<<2)|0;if((c[J>>2]|0)==0){K=5271;break}else{H=H+1|0}}do{if((K|0)==5271){H=gGq(65536)|0;c[J>>2]=H;if((H|0)==0){I=0;break}gGz(H|0,0,65536);I=H}}while(0);J=c[2385950]|0;H=0;do{z=a[J+H|0]|0;a[I+((H>>>10<<6&64|H>>>13&1|H>>>15<<7&128|H>>>11<<5&32|H>>>9<<4&16|H>>8<<3&8|H>>>14<<2&4|H>>>12<<1&2)<<8|H&255)|0]=(z&255)>>>1<<7|z&32|(z&255)>>>7<<4|z<<2&4|(z&255)>>>2&1|(z&255)>>>4<<6&64|(z&255)>>>6<<3&8|(z&255)>>>3<<1&2;H=H+1|0;}while((H|0)<65536);gGC(J|0,I|0,65536)|0;J=0;while(1){if((J|0)>=1024){D=0;K=5283;break}L=9638528+(J<<2)|0;if((c[L>>2]|0)==(I|0)){break}else{J=J+1|0}}if((K|0)==5283){i=b;return D|0}gGr(I);c[L>>2]=0;D=0;i=b;return D|0}function dCn(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;a=i;i=i+1800|0;b=a|0;d=a+112|0;e=a+120|0;f=a+232|0;g=a+240|0;h=a+352|0;j=a+360|0;k=a+472|0;l=a+480|0;m=a+592|0;n=a+600|0;o=a+712|0;p=a+720|0;q=a+832|0;r=a+840|0;s=a+952|0;t=a+960|0;u=a+1072|0;v=a+1080|0;w=a+1192|0;x=a+1200|0;y=a+1312|0;z=a+1320|0;A=a+1432|0;B=a+1440|0;C=a+1552|0;D=a+1560|0;E=a+1672|0;F=a+1680|0;G=a+1792|0;H=c[2385950]|0;if((c[3542200]|0)==0){I=1;i=a;return I|0}J=F+108|0;c[J>>2]=0;K=F+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](F,0)|0;do{if((c[J>>2]|0)!=0){F=c[K>>2]|0;c[G>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](G,0,0)|0;if((F|0)<1){I=1;i=a;return I|0}if((gzL(H,0,0)|0)==0){break}else{I=1}i=a;return I|0}}while(0);H=(c[2385950]|0)+4096|0;if((c[3542200]|0)==0){I=1;i=a;return I|0}G=D+108|0;c[G>>2]=0;K=D+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](D,1)|0;do{if((c[G>>2]|0)!=0){D=c[K>>2]|0;c[E>>2]=9534384;J=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[J&16383](E,1,0)|0;if((D|0)<1){I=1;i=a;return I|0}if((gzL(H,0,1)|0)==0){break}else{I=1}i=a;return I|0}}while(0);H=(c[2385950]|0)+8192|0;if((c[3542200]|0)==0){I=1;i=a;return I|0}E=B+108|0;c[E>>2]=0;K=B+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](B,2)|0;do{if((c[E>>2]|0)!=0){B=c[K>>2]|0;c[C>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](C,2,0)|0;if((B|0)<1){I=1;i=a;return I|0}if((gzL(H,0,2)|0)==0){break}else{I=1}i=a;return I|0}}while(0);H=(c[2385950]|0)+12288|0;if((c[3542200]|0)==0){I=1;i=a;return I|0}C=z+108|0;c[C>>2]=0;K=z+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,3)|0;do{if((c[C>>2]|0)!=0){z=c[K>>2]|0;c[A>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](A,3,0)|0;if((z|0)<1){I=1;i=a;return I|0}if((gzL(H,0,3)|0)==0){break}else{I=1}i=a;return I|0}}while(0);H=c[3529764]|0;if((c[3542200]|0)==0){I=1;i=a;return I|0}A=x+108|0;c[A>>2]=0;K=x+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,4)|0;do{if((c[A>>2]|0)!=0){x=c[K>>2]|0;c[y>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](y,4,0)|0;if((x|0)<1){I=1;i=a;return I|0}if((gzL(H,0,4)|0)==0){break}else{I=1}i=a;return I|0}}while(0);H=c[3529764]|0;y=H+2048|0;gGC(y|0,H|0,2048)|0;y=H+4096|0;if((c[3542200]|0)==0){I=1;i=a;return I|0}H=v+108|0;c[H>>2]=0;K=v+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,5)|0;do{if((c[H>>2]|0)!=0){v=c[K>>2]|0;c[w>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](w,5,0)|0;if((v|0)<1){I=1;i=a;return I|0}if((gzL(y,0,5)|0)==0){break}else{I=1}i=a;return I|0}}while(0);y=c[3530878]|0;if((c[3542200]|0)==0){I=1;i=a;return I|0}w=t+108|0;c[w>>2]=0;K=t+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,6)|0;do{if((c[w>>2]|0)!=0){t=c[K>>2]|0;c[u>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](u,6,0)|0;if((t|0)<1){I=1;i=a;return I|0}if((gzL(y,0,6)|0)==0){break}else{I=1}i=a;return I|0}}while(0);y=(c[3530878]|0)+4096|0;if((c[3542200]|0)==0){I=1;i=a;return I|0}u=r+108|0;c[u>>2]=0;K=r+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,7)|0;do{if((c[u>>2]|0)!=0){r=c[K>>2]|0;c[s>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](s,7,0)|0;if((r|0)<1){I=1;i=a;return I|0}if((gzL(y,0,7)|0)==0){break}else{I=1}i=a;return I|0}}while(0);y=c[3530642]|0;if((c[3542200]|0)==0){I=1;i=a;return I|0}s=p+108|0;c[s>>2]=0;K=p+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,8)|0;do{if((c[s>>2]|0)!=0){p=c[K>>2]|0;c[q>>2]=9534384;u=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[u&16383](q,8,0)|0;if((p|0)<1){I=1;i=a;return I|0}if((gzL(y,0,8)|0)==0){break}else{I=1}i=a;return I|0}}while(0);y=(c[3530642]|0)+4096|0;if((c[3542200]|0)==0){I=1;i=a;return I|0}q=n+108|0;c[q>>2]=0;K=n+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,9)|0;do{if((c[q>>2]|0)!=0){n=c[K>>2]|0;c[o>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](o,9,0)|0;if((n|0)<1){I=1;i=a;return I|0}if((gzL(y,0,9)|0)==0){break}else{I=1}i=a;return I|0}}while(0);y=(c[3530642]|0)+8192|0;if((c[3542200]|0)==0){I=1;i=a;return I|0}o=l+108|0;c[o>>2]=0;K=l+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,10)|0;do{if((c[o>>2]|0)!=0){l=c[K>>2]|0;c[m>>2]=9534384;q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[q&16383](m,10,0)|0;if((l|0)<1){I=1;i=a;return I|0}if((gzL(y,0,10)|0)==0){break}else{I=1}i=a;return I|0}}while(0);y=(c[3530642]|0)+12288|0;if((c[3542200]|0)==0){I=1;i=a;return I|0}m=j+108|0;c[m>>2]=0;K=j+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,11)|0;do{if((c[m>>2]|0)!=0){j=c[K>>2]|0;c[k>>2]=9534384;o=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[o&16383](k,11,0)|0;if((j|0)<1){I=1;i=a;return I|0}if((gzL(y,0,11)|0)==0){break}else{I=1}i=a;return I|0}}while(0);y=c[3531022]|0;if((c[3542200]|0)==0){I=1;i=a;return I|0}k=g+108|0;c[k>>2]=0;K=g+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,12)|0;do{if((c[k>>2]|0)!=0){g=c[K>>2]|0;c[h>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](h,12,0)|0;if((g|0)<1){I=1;i=a;return I|0}if((gzL(y,0,12)|0)==0){break}else{I=1}i=a;return I|0}}while(0);y=(c[3531022]|0)+256|0;if((c[3542200]|0)==0){I=1;i=a;return I|0}h=e+108|0;c[h>>2]=0;K=e+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,13)|0;do{if((c[h>>2]|0)!=0){e=c[K>>2]|0;c[f>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](f,13,0)|0;if((e|0)<1){I=1;i=a;return I|0}if((gzL(y,0,13)|0)==0){break}else{I=1}i=a;return I|0}}while(0);y=(c[3531022]|0)+512|0;if((c[3542200]|0)==0){I=1;i=a;return I|0}f=b+108|0;c[f>>2]=0;K=b+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](b,14)|0;if((c[f>>2]|0)==0){I=0;i=a;return I|0}f=c[K>>2]|0;c[d>>2]=9534384;gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](d,14,0)|0;if((f|0)<1){I=1;i=a;return I|0}I=(gzL(y,0,14)|0)!=0|0;i=a;return I|0}function dCo(){return(dCp()|0)!=0|0}function dCp(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;a=i;i=i+1800|0;b=a|0;d=a+112|0;e=a+120|0;f=a+232|0;g=a+240|0;h=a+352|0;j=a+360|0;k=a+472|0;l=a+480|0;m=a+592|0;n=a+600|0;o=a+712|0;p=a+720|0;q=a+832|0;r=a+840|0;s=a+952|0;t=a+960|0;u=a+1072|0;v=a+1080|0;w=a+1192|0;x=a+1200|0;y=a+1312|0;z=a+1320|0;A=a+1432|0;B=a+1440|0;C=a+1552|0;D=a+1560|0;E=a+1672|0;F=a+1680|0;G=a+1792|0;H=c[2385950]|0;if((c[3542200]|0)==0){I=1;i=a;return I|0}J=F+108|0;c[J>>2]=0;K=F+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](F,0)|0;do{if((c[J>>2]|0)!=0){F=c[K>>2]|0;c[G>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](G,0,0)|0;if((F|0)<1){I=1;i=a;return I|0}if((gzL(H,0,0)|0)==0){break}else{I=1}i=a;return I|0}}while(0);H=(c[2385950]|0)+4096|0;if((c[3542200]|0)==0){I=1;i=a;return I|0}G=D+108|0;c[G>>2]=0;K=D+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](D,1)|0;do{if((c[G>>2]|0)!=0){D=c[K>>2]|0;c[E>>2]=9534384;J=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[J&16383](E,1,0)|0;if((D|0)<1){I=1;i=a;return I|0}if((gzL(H,0,1)|0)==0){break}else{I=1}i=a;return I|0}}while(0);H=(c[2385950]|0)+8192|0;if((c[3542200]|0)==0){I=1;i=a;return I|0}E=B+108|0;c[E>>2]=0;K=B+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](B,2)|0;do{if((c[E>>2]|0)!=0){B=c[K>>2]|0;c[C>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](C,2,0)|0;if((B|0)<1){I=1;i=a;return I|0}if((gzL(H,0,2)|0)==0){break}else{I=1}i=a;return I|0}}while(0);H=(c[2385950]|0)+12288|0;if((c[3542200]|0)==0){I=1;i=a;return I|0}C=z+108|0;c[C>>2]=0;K=z+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,3)|0;do{if((c[C>>2]|0)!=0){z=c[K>>2]|0;c[A>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](A,3,0)|0;if((z|0)<1){I=1;i=a;return I|0}if((gzL(H,0,3)|0)==0){break}else{I=1}i=a;return I|0}}while(0);H=c[3529764]|0;if((c[3542200]|0)==0){I=1;i=a;return I|0}A=x+108|0;c[A>>2]=0;K=x+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,4)|0;do{if((c[A>>2]|0)!=0){x=c[K>>2]|0;c[y>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](y,4,0)|0;if((x|0)<1){I=1;i=a;return I|0}if((gzL(H,0,4)|0)==0){break}else{I=1}i=a;return I|0}}while(0);H=c[3529764]|0;y=H+2048|0;gGC(y|0,H|0,2048)|0;H=c[3530878]|0;if((c[3542200]|0)==0){I=1;i=a;return I|0}y=v+108|0;c[y>>2]=0;K=v+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,5)|0;do{if((c[y>>2]|0)!=0){v=c[K>>2]|0;c[w>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](w,5,0)|0;if((v|0)<1){I=1;i=a;return I|0}if((gzL(H,0,5)|0)==0){break}else{I=1}i=a;return I|0}}while(0);H=(c[3530878]|0)+4096|0;if((c[3542200]|0)==0){I=1;i=a;return I|0}w=t+108|0;c[w>>2]=0;K=t+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,6)|0;do{if((c[w>>2]|0)!=0){t=c[K>>2]|0;c[u>>2]=9534384;y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[y&16383](u,6,0)|0;if((t|0)<1){I=1;i=a;return I|0}if((gzL(H,0,6)|0)==0){break}else{I=1}i=a;return I|0}}while(0);H=c[3530642]|0;if((c[3542200]|0)==0){I=1;i=a;return I|0}u=r+108|0;c[u>>2]=0;K=r+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,7)|0;do{if((c[u>>2]|0)!=0){r=c[K>>2]|0;c[s>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](s,7,0)|0;if((r|0)<1){I=1;i=a;return I|0}if((gzL(H,0,7)|0)==0){break}else{I=1}i=a;return I|0}}while(0);H=(c[3530642]|0)+4096|0;if((c[3542200]|0)==0){I=1;i=a;return I|0}s=p+108|0;c[s>>2]=0;K=p+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,8)|0;do{if((c[s>>2]|0)!=0){p=c[K>>2]|0;c[q>>2]=9534384;u=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[u&16383](q,8,0)|0;if((p|0)<1){I=1;i=a;return I|0}if((gzL(H,0,8)|0)==0){break}else{I=1}i=a;return I|0}}while(0);H=(c[3530642]|0)+8192|0;if((c[3542200]|0)==0){I=1;i=a;return I|0}q=n+108|0;c[q>>2]=0;K=n+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,9)|0;do{if((c[q>>2]|0)!=0){n=c[K>>2]|0;c[o>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](o,9,0)|0;if((n|0)<1){I=1;i=a;return I|0}if((gzL(H,0,9)|0)==0){break}else{I=1}i=a;return I|0}}while(0);H=(c[3530642]|0)+12288|0;if((c[3542200]|0)==0){I=1;i=a;return I|0}o=l+108|0;c[o>>2]=0;K=l+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,10)|0;do{if((c[o>>2]|0)!=0){l=c[K>>2]|0;c[m>>2]=9534384;q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[q&16383](m,10,0)|0;if((l|0)<1){I=1;i=a;return I|0}if((gzL(H,0,10)|0)==0){break}else{I=1}i=a;return I|0}}while(0);H=c[3531022]|0;if((c[3542200]|0)==0){I=1;i=a;return I|0}m=j+108|0;c[m>>2]=0;K=j+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,11)|0;do{if((c[m>>2]|0)!=0){j=c[K>>2]|0;c[k>>2]=9534384;o=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[o&16383](k,11,0)|0;if((j|0)<1){I=1;i=a;return I|0}if((gzL(H,0,11)|0)==0){break}else{I=1}i=a;return I|0}}while(0);H=(c[3531022]|0)+256|0;if((c[3542200]|0)==0){I=1;i=a;return I|0}k=g+108|0;c[k>>2]=0;K=g+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,12)|0;do{if((c[k>>2]|0)!=0){g=c[K>>2]|0;c[h>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](h,12,0)|0;if((g|0)<1){I=1;i=a;return I|0}if((gzL(H,0,12)|0)==0){break}else{I=1}i=a;return I|0}}while(0);H=(c[3531022]|0)+512|0;if((c[3542200]|0)==0){I=1;i=a;return I|0}h=e+108|0;c[h>>2]=0;K=e+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,13)|0;do{if((c[h>>2]|0)!=0){e=c[K>>2]|0;c[f>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](f,13,0)|0;if((e|0)<1){I=1;i=a;return I|0}if((gzL(H,0,13)|0)==0){break}else{I=1}i=a;return I|0}}while(0);H=c[3530452]|0;if((c[3542200]|0)==0){I=1;i=a;return I|0}f=b+108|0;c[f>>2]=0;K=b+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](b,14)|0;if((c[f>>2]|0)==0){I=0;i=a;return I|0}f=c[K>>2]|0;c[d>>2]=9534384;gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](d,14,0)|0;if((f|0)<1){I=1;i=a;return I|0}I=(gzL(H,0,14)|0)!=0|0;i=a;return I|0}function dCq(b){b=b|0;var c=0;switch(b&65535|0){case 58882:{c=a[9771818]|0;break};case 58884:{c=a[14115760]|0;break};case 58880:{c=a[9771816]|0;break};case 58881:{c=a[9771817]|0;break};case 58885:{c=a[14115761]|0;break};default:{c=0}}return c|0}function dCr(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=d&65535;if((f|0)==59392){c[2430826]=e&255;d=c[1836236]|0;g=c[9757320+(d<<2)>>2]|0;if((g|0)!=0){h=g;gGC(h|0,9706056,76)|0}c[9752472+(d<<2)>>2]=c[2433530];c[14113936+(d<<2)>>2]=c[2076596];c[9669104+(d<<2)>>2]=c[3541536];c[1836236]=-1;d=c[2439331]|0;if((d|0)!=0){h=d;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;h=(c[2433530]|0)+12|0;c[2433530]=h;d=c[1836236]|0;g=c[9757320+(d<<2)>>2]|0;if((g|0)!=0){i=g;gGC(i|0,9706056,76)|0}c[9752472+(d<<2)>>2]=h;c[14113936+(d<<2)>>2]=c[2076596];c[9669104+(d<<2)>>2]=c[3541536];c[1836236]=-1;d=c[2439330]|0;if((d|0)!=0){h=d;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;return}else if((f|0)==58880){c[2438440]=e&255;return}else if((f|0)==58884){c[2430836]=e&1;return}else{return}}function dCs(a){a=a|0;var b=0;if(a<<16>>16!=-32768){b=0;return b|0}b=c[2430826]&255;return b|0}function dCt(b,d){b=b|0;d=d|0;var e=0;switch(b&255|0){case 33:{b=d&255;e=c[3542291]|0;if((e|0)>15){return}do{if((e|0)<14){if((e|0)!=13){if((a[14169168+e|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(1,e,b);return};case 17:{b=d&255;e=c[3542228]|0;if((e|0)>15){return}do{if((e|0)<14){if((e|0)!=13){if((a[14168916+e|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(0,e,b);return};case 49:{b=d&255;e=c[3542354]|0;if((e|0)>15){return}do{if((e|0)<14){if((e|0)!=13){if((a[14169420+e|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(2,e,b);return};case 32:{c[3542291]=d&15;return};case 48:{c[3542354]=d&15;return};case 16:{c[3542228]=d&15;return};default:{return}}}function dCu(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0.0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0;e=i;i=i+1440|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;B=e+1200|0;C=e+1312|0;D=e+1320|0;E=e+1432|0;c[2426766]=0;c[2438428]=0;c[2438426]=65536;c[2405686]=81920;c[2438432]=81920;c[2438430]=86016;c[2433336]=88064;c[2437008]=89088;c[2430070]=90112;c[2430838]=91136;c[2433334]=92160;c[2430828]=92288;c[2411746]=92800;c[2438444]=92800;c[2438442]=223872;c[2438436]=354944;c[2385376]=486016;F=a[9688]|0?9612:0;c[2438438]=F+486016;G=F+488064|0;c[2414288]=G;F=G;G=0;while(1){if((G|0)>=1024){break}H=9638528+(G<<2)|0;if((c[H>>2]|0)==0){I=5600;break}else{G=G+1|0}}do{if((I|0)==5600){G=gGq(F)|0;c[H>>2]=G;if((G|0)==0){break}gGz(G|0,0,F|0);c[2426766]=G;gGz(G|0,0,F|0);c[2438428]=G;c[2438426]=G+65536;J=G+81920|0;c[2405686]=J;c[2438432]=J;c[2438430]=G+86016;c[2433336]=G+88064;c[2437008]=G+89088;c[2430070]=G+90112;c[2430838]=G+91136;c[2433334]=G+92160;c[2430828]=G+92288;J=G+92800|0;c[2411746]=J;c[2438444]=J;c[2438442]=G+223872;c[2438436]=G+354944;c[2385376]=G+486016;J=a[9688]|0?9612:0;c[2438438]=G+(J+486016);c[2414288]=G+(J+488064);J=0;while(1){if((J|0)>=1024){K=0;break}L=9638528+(J<<2)|0;if((c[L>>2]|0)==0){I=5605;break}else{J=J+1|0}}do{if((I|0)==5605){J=gGq(65536)|0;c[L>>2]=J;if((J|0)==0){K=0;break}gGz(J|0,0,65536);K=J}}while(0);c[2438434]=K;J=c[2438428]|0;if((c[3542200]|0)==0){M=1;i=e;return M|0}G=D+108|0;c[G>>2]=0;N=D+100|0;c[N>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](D,0)|0;do{if((c[G>>2]|0)!=0){O=c[N>>2]|0;c[E>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](E,0,0)|0;if((O|0)<1){M=1;i=e;return M|0}if((gzL(J,0,0)|0)==0){break}else{M=1}i=e;return M|0}}while(0);J=c[2438434]|0;if((c[3542200]|0)==0){M=1;i=e;return M|0}N=B+108|0;c[N>>2]=0;G=B+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](B,1)|0;do{if((c[N>>2]|0)!=0){O=c[G>>2]|0;c[C>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](C,1,0)|0;if((O|0)<1){M=1;i=e;return M|0}if((gzL(J,0,1)|0)==0){break}else{M=1}i=e;return M|0}}while(0);J=c[2438428]|0;G=J+16384|0;N=c[2438434]|0;O=N+16384|0;gGC(G|0,O|0,16384)|0;O=J+32768|0;gGC(O|0,N|0,16384)|0;gGz(N|0,0,65536);if((c[3542200]|0)==0){M=1;i=e;return M|0}O=z+108|0;c[O>>2]=0;J=z+100|0;c[J>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,2)|0;do{if((c[O>>2]|0)!=0){G=c[J>>2]|0;c[A>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](A,2,0)|0;if((G|0)<1){M=1;i=e;return M|0}if((gzL(N,0,2)|0)==0){break}else{M=1}i=e;return M|0}}while(0);N=(c[2438428]|0)+61440|0;J=c[2438434]|0;gGC(N|0,J|0,4096)|0;J=c[2438426]|0;if((c[3542200]|0)==0){M=1;i=e;return M|0}N=x+108|0;c[N>>2]=0;O=x+100|0;c[O>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,3)|0;do{if((c[N>>2]|0)!=0){G=c[O>>2]|0;c[y>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](y,3,0)|0;if((G|0)<1){M=1;i=e;return M|0}if((gzL(J,0,3)|0)==0){break}else{M=1}i=e;return M|0}}while(0);J=c[2438434]|0;gGz(J|0,0,65536);if((c[3542200]|0)==0){M=1;i=e;return M|0}O=v+108|0;c[O>>2]=0;N=v+100|0;c[N>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,6)|0;do{if((c[O>>2]|0)!=0){G=c[N>>2]|0;c[w>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](w,6,0)|0;if((G|0)<1){M=1;i=e;return M|0}if((gzL(J,0,6)|0)==0){break}else{M=1}i=e;return M|0}}while(0);J=(c[2438434]|0)+32768|0;if((c[3542200]|0)==0){M=1;i=e;return M|0}N=t+108|0;c[N>>2]=0;O=t+100|0;c[O>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,7)|0;do{if((c[N>>2]|0)!=0){G=c[O>>2]|0;c[u>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](u,7,0)|0;if((G|0)<1){M=1;i=e;return M|0}if((gzL(J,0,7)|0)==0){break}else{M=1}i=e;return M|0}}while(0);J=c[2438434]|0;O=c[2438444]|0;N=0;do{G=N<<6;gGz(O+G|0,0,64);P=N<<8;Q=0;do{R=1<<3-Q;S=(c[703416+(Q<<2)>>2]|0)+P|0;T=0;do{U=S+(c[1183816+(T<<2)>>2]|0)|0;V=(T<<3)+G|0;W=0;do{X=U+(c[1934976+(W<<2)>>2]|0)|0;if(((d[J+((X|0)/8|0)|0]|0)&128>>>((X&7)>>>0)|0)!=0){X=O+(V+W)|0;a[X]=(d[X]|0|R)&255}W=W+1|0;}while((W|0)<8);T=T+1|0;}while((T|0)<8);Q=Q+1|0;}while((Q|0)<4);N=N+1|0;}while((N|0)<2048);gGz(J|0,0,65536);if((c[3542200]|0)==0){M=1;i=e;return M|0}N=r+108|0;c[N>>2]=0;O=r+100|0;c[O>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,4)|0;do{if((c[N>>2]|0)!=0){Q=c[O>>2]|0;c[s>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](s,4,0)|0;if((Q|0)<1){M=1;i=e;return M|0}if((gzL(J,0,4)|0)==0){break}else{M=1}i=e;return M|0}}while(0);J=(c[2438434]|0)+32768|0;if((c[3542200]|0)==0){M=1;i=e;return M|0}O=p+108|0;c[O>>2]=0;N=p+100|0;c[N>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,5)|0;do{if((c[O>>2]|0)!=0){Q=c[N>>2]|0;c[q>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](q,5,0)|0;if((Q|0)<1){M=1;i=e;return M|0}if((gzL(J,0,5)|0)==0){break}else{M=1}i=e;return M|0}}while(0);J=c[2438434]|0;N=c[2438442]|0;O=0;do{Q=O<<6;gGz(N+Q|0,0,64);G=O<<8;P=0;do{T=1<<3-P;R=(c[703416+(P<<2)>>2]|0)+G|0;S=0;do{W=R+(c[1183816+(S<<2)>>2]|0)|0;V=(S<<3)+Q|0;U=0;do{X=W+(c[1934976+(U<<2)>>2]|0)|0;if(((d[J+((X|0)/8|0)|0]|0)&128>>>((X&7)>>>0)|0)!=0){X=N+(V+U)|0;a[X]=(d[X]|0|T)&255}U=U+1|0;}while((U|0)<8);S=S+1|0;}while((S|0)<8);P=P+1|0;}while((P|0)<4);O=O+1|0;}while((O|0)<2048);gGz(J|0,0,65536);if((c[3542200]|0)==0){M=1;i=e;return M|0}O=n+108|0;c[O>>2]=0;N=n+100|0;c[N>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,8)|0;do{if((c[O>>2]|0)!=0){P=c[N>>2]|0;c[o>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](o,8,0)|0;if((P|0)<1){M=1;i=e;return M|0}if((gzL(J,0,8)|0)==0){break}else{M=1}i=e;return M|0}}while(0);J=(c[2438434]|0)+16384|0;if((c[3542200]|0)==0){M=1;i=e;return M|0}N=l+108|0;c[N>>2]=0;O=l+100|0;c[O>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,9)|0;do{if((c[N>>2]|0)!=0){P=c[O>>2]|0;c[m>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](m,9,0)|0;if((P|0)<1){M=1;i=e;return M|0}if((gzL(J,0,9)|0)==0){break}else{M=1}i=e;return M|0}}while(0);J=(c[2438434]|0)+32768|0;if((c[3542200]|0)==0){M=1;i=e;return M|0}O=j+108|0;c[O>>2]=0;N=j+100|0;c[N>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,10)|0;do{if((c[O>>2]|0)!=0){P=c[N>>2]|0;c[k>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](k,10,0)|0;if((P|0)<1){M=1;i=e;return M|0}if((gzL(J,0,10)|0)==0){break}else{M=1}i=e;return M|0}}while(0);J=(c[2438434]|0)+49152|0;if((c[3542200]|0)==0){M=1;i=e;return M|0}N=f+108|0;c[N>>2]=0;O=f+100|0;c[O>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,11)|0;do{if((c[N>>2]|0)!=0){P=c[O>>2]|0;c[g>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](g,11,0)|0;if((P|0)<1){M=1;i=e;return M|0}if((gzL(J,0,11)|0)==0){break}else{M=1}i=e;return M|0}}while(0);J=c[2438434]|0;O=c[2438436]|0;N=0;do{P=N<<8;gGz(O+P|0,0,256);Q=0;do{G=1<<3-Q;S=(c[961488+(Q<<2)>>2]|0)+P|0;T=0;do{R=S+(c[611776+(T<<2)>>2]|0)|0;U=(T<<4)+P|0;V=0;do{W=R+(c[601400+(V<<2)>>2]|0)|0;if(((d[J+((W|0)/8|0)|0]|0)&128>>>((W&7)>>>0)|0)!=0){W=O+(U+V)|0;a[W]=(d[W]|0|G)&255}V=V+1|0;}while((V|0)<16);T=T+1|0;}while((T|0)<16);Q=Q+1|0;}while((Q|0)<4);N=N+1|0;}while((N|0)<512);fwR(0);N=c[2439330]|0;if((N|0)!=0){O=N;gGC(9706056,O|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];O=c[3528484]|0;c[2076596]=O;J=c[2417276]|0;c[3541536]=J;c[1836236]=0;c[N+4180>>2]=2578;c[N+4184>>2]=2364;Q=c[2438428]|0;P=0;T=0;while(1){c[N+76+(T<<2)>>2]=Q+(T<<8);G=P+1&65535;if((G&65535)>191){Y=0;Z=0;break}else{P=G;T=G&65535}}while(1){T=Q+(Z<<8)|0;c[N+76+(Z+512<<2)>>2]=T;c[N+76+(Z+768<<2)>>2]=T;T=Y+1&65535;if((T&65535)>191){break}else{Y=T;Z=T&65535}}T=c[2438432]|0;c[N+844>>2]=T;c[N+848>>2]=T+256;c[N+852>>2]=T+512;c[N+856>>2]=T+768;c[N+860>>2]=T+1024;c[N+864>>2]=T+1280;c[N+868>>2]=T+1536;c[N+872>>2]=T+1792;c[N+876>>2]=T+2048;c[N+880>>2]=T+2304;c[N+884>>2]=T+2560;c[N+888>>2]=T+2816;c[N+892>>2]=T+3072;c[N+896>>2]=T+3328;c[N+900>>2]=T+3584;c[N+904>>2]=T+3840;P=192;G=192;while(1){c[N+76+(G+256<<2)>>2]=T+((G<<8)-49152);S=P+1&65535;if((S&65535)>207){_=192;$=192;break}else{P=S;G=S&65535}}while(1){G=T+(($<<8)-49152)|0;c[N+76+($+512<<2)>>2]=G;c[N+76+($+768<<2)>>2]=G;G=_+1&65535;if((G&65535)>207){break}else{_=G;$=G&65535}}T=c[2433336]|0;c[N+908>>2]=T;G=T+256|0;c[N+912>>2]=G;P=T+512|0;c[N+916>>2]=P;S=T+768|0;c[N+920>>2]=S;c[N+1932>>2]=T;c[N+1936>>2]=G;c[N+1940>>2]=P;c[N+1944>>2]=S;c[N+2956>>2]=T;c[N+3980>>2]=T;c[N+2960>>2]=G;c[N+3984>>2]=G;c[N+2964>>2]=P;c[N+3988>>2]=P;c[N+2968>>2]=S;c[N+3992>>2]=S;S=c[2437008]|0;c[N+924>>2]=S;P=S+256|0;c[N+928>>2]=P;G=S+512|0;c[N+932>>2]=G;T=S+768|0;c[N+936>>2]=T;c[N+1948>>2]=S;c[N+1952>>2]=P;c[N+1956>>2]=G;c[N+1960>>2]=T;c[N+2972>>2]=S;c[N+3996>>2]=S;c[N+2976>>2]=P;c[N+4e3>>2]=P;c[N+2980>>2]=G;c[N+4004>>2]=G;c[N+2984>>2]=T;c[N+4008>>2]=T;T=c[2430070]|0;c[N+940>>2]=T;G=T+256|0;c[N+944>>2]=G;P=T+512|0;c[N+948>>2]=P;S=T+768|0;c[N+952>>2]=S;c[N+1964>>2]=T;c[N+1968>>2]=G;c[N+1972>>2]=P;c[N+1976>>2]=S;c[N+2988>>2]=T;c[N+4012>>2]=T;c[N+2992>>2]=G;c[N+4016>>2]=G;c[N+2996>>2]=P;c[N+4020>>2]=P;c[N+3e3>>2]=S;c[N+4024>>2]=S;S=c[2430838]|0;c[N+956>>2]=S;P=S+256|0;c[N+960>>2]=P;G=S+512|0;c[N+964>>2]=G;T=S+768|0;c[N+968>>2]=T;c[N+1980>>2]=S;c[N+1984>>2]=P;c[N+1988>>2]=G;c[N+1992>>2]=T;c[N+3004>>2]=S;c[N+4028>>2]=S;c[N+3008>>2]=P;c[N+4032>>2]=P;c[N+3012>>2]=G;c[N+4036>>2]=G;c[N+3016>>2]=T;c[N+4040>>2]=T;T=c[2433334]|0;c[N+972>>2]=T;c[N+1996>>2]=T;c[N+3020>>2]=T;c[N+4044>>2]=T;T=c[2430828]|0;c[N+988>>2]=T;G=T+256|0;c[N+992>>2]=G;c[N+2012>>2]=T;c[N+2016>>2]=G;c[N+3036>>2]=T;c[N+4060>>2]=T;c[N+3040>>2]=G;c[N+4064>>2]=G;c[N+1036>>2]=Q+61440;c[N+1040>>2]=Q+61696;c[N+1044>>2]=Q+61952;c[N+1048>>2]=Q+62208;c[N+1052>>2]=Q+62464;c[N+1056>>2]=Q+62720;c[N+1060>>2]=Q+62976;c[N+1064>>2]=Q+63232;c[N+1068>>2]=Q+63488;c[N+1072>>2]=Q+63744;c[N+1076>>2]=Q+64e3;c[N+1080>>2]=Q+64256;c[N+1084>>2]=Q+64512;c[N+1088>>2]=Q+64768;c[N+1092>>2]=Q+65024;c[N+1096>>2]=Q+65280;G=240;T=240;while(1){P=Q+(T<<8)|0;c[N+76+(T+512<<2)>>2]=P;c[N+76+(T+768<<2)>>2]=P;P=G+1&65535;if((P&65535)>255){break}else{G=P;T=P&65535}}T=N;gGC(T|0,9706056,76)|0;c[2438118]=c[2433530];c[3528484]=O;c[2417276]=J;c[1836236]=-1;fwR(1);T=c[2439331]|0;G=(T|0)==0;if(!G){Q=T;gGC(9706056,Q|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];Q=c[3528485]|0;c[2076596]=Q;P=c[2417277]|0;c[3541536]=P;c[1836236]=1;c[T+4180>>2]=1400;c[T+4176>>2]=1198;S=c[2438426]|0;V=0;U=0;while(1){c[T+76+(U<<2)>>2]=S+(U<<8);R=V+1&65535;if((R&65535)>63){aa=0;ab=0;break}else{V=R;U=R&65535}}while(1){U=S+(ab<<8)|0;c[T+76+(ab+512<<2)>>2]=U;c[T+76+(ab+768<<2)>>2]=U;U=aa+1&65535;if((U&65535)>63){break}else{aa=U;ab=U&65535}}S=c[2438430]|0;c[T+332>>2]=S;U=S+256|0;c[T+336>>2]=U;V=S+512|0;c[T+340>>2]=V;J=S+768|0;c[T+344>>2]=J;O=S+1024|0;c[T+348>>2]=O;N=S+1280|0;c[T+352>>2]=N;R=S+1536|0;c[T+356>>2]=R;W=S+1792|0;c[T+360>>2]=W;c[T+1356>>2]=S;c[T+1360>>2]=U;c[T+1364>>2]=V;c[T+1368>>2]=J;c[T+1372>>2]=O;c[T+1376>>2]=N;c[T+1380>>2]=R;c[T+1384>>2]=W;c[T+2380>>2]=S;c[T+3404>>2]=S;c[T+2384>>2]=U;c[T+3408>>2]=U;c[T+2388>>2]=V;c[T+3412>>2]=V;c[T+2392>>2]=J;c[T+3416>>2]=J;c[T+2396>>2]=O;c[T+3420>>2]=O;c[T+2400>>2]=N;c[T+3424>>2]=N;c[T+2404>>2]=R;c[T+3428>>2]=R;c[T+2408>>2]=W;c[T+3432>>2]=W;if(!G){W=T;gGC(W|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=Q;c[2417277]=P;c[1836236]=-1;W=c[2438434]|0;R=0;while(1){if((R|0)>=1024){break}ac=9638528+(R<<2)|0;if((c[ac>>2]|0)==(W|0)){I=5705;break}else{R=R+1|0}}if((I|0)==5705){gGr(W);c[ac>>2]=0}c[2438434]=0;R=c[2385376]|0;c[2439064]=R;P=a[9688]|0?534:0;c[2439065]=R+(P<<1);c[2439066]=R+(P<<1<<1);c[2439067]=R+((P*3|0)<<1);c[2439068]=R+(P<<2<<1);c[2439069]=R+((P*5|0)<<1);c[2439070]=R+((P*6|0)<<1);c[2439071]=R+((P*7|0)<<1);c[2439072]=R+(P<<3<<1);P=a[9680]|0?32e3:0;c[3542220]=11200;R=c[2113008]|0;if((R|0)==0){gGz(14168888,0,252);c[3542223]=P;gGz(14168896,0,16);c[3542234]=~~((+(P|0)*32768.0*8.0+75.0e4)/15.0e5);Q=31;ad=32767.0;while(1){c[14169012+(Q<<2)>>2]=~~(ad+.5);T=Q-1|0;if((T|0)>0){Q=T;ad=ad/1.188502227}else{break}}c[3542253]=0;h[1771269]=1.0;h[1771270]=1.0;h[1771271]=1.0;c[3542574]=3;c[3542575]=3;c[3542576]=3;mB(0);Q=(c[2113008]|0)+1|0;c[2113008]=Q;ae=Q;af=a[9680]|0?32e3:0}else{ae=R;af=P}c[3542220]=11200;if((ae|0)==1){gGz(14169140,0,252);c[3542286]=af;gGz(14169148,0,16);c[3542297]=~~((+(af|0)*32768.0*8.0+75.0e4)/15.0e5);Q=31;ad=32767.0;while(1){c[14169264+(Q<<2)>>2]=~~(ad+.5);W=Q-1|0;if((W|0)>0){Q=W;ad=ad/1.188502227}else{break}}c[3542316]=0;h[1771272]=1.0;h[1771273]=1.0;h[1771274]=1.0;c[3542577]=3;c[3542578]=3;c[3542579]=3;mB(1);Q=(c[2113008]|0)+1|0;c[2113008]=Q;ah=Q;ai=a[9680]|0?32e3:0}else{ah=ae;ai=af}c[3542220]=11200;if((ah|0)==2){gGz(14169392,0,252);c[3542349]=ai;gGz(14169400,0,16);c[3542360]=~~((+(ai|0)*32768.0*8.0+75.0e4)/15.0e5);Q=31;ad=32767.0;while(1){c[14169516+(Q<<2)>>2]=~~(ad+.5);P=Q-1|0;if((P|0)>0){Q=P;ad=ad/1.188502227}else{break}}c[3542379]=0;h[1771275]=1.0;h[1771276]=1.0;h[1771277]=1.0;c[3542580]=3;c[3542581]=3;c[3542582]=3;mB(2);c[2113008]=(c[2113008]|0)+1}h[1771269]=.12;c[3542574]=3;h[1771270]=.12;c[3542575]=3;h[1771271]=.12;c[3542576]=3;h[1771272]=.12;c[3542577]=3;h[1771273]=.12;c[3542578]=3;h[1771274]=.12;c[3542579]=3;h[1771275]=.12;c[3542580]=3;h[1771276]=.12;c[3542581]=3;h[1771277]=.12;c[3542582]=3;Q=c[642608+(c[2436]<<2)>>2]|0;P=c[Q+128>>2]|0;if((c[Q+52>>2]&4|0)==0){c[2113068]=P;R=c[Q+132>>2]|0;c[2113070]=R;c[2443814]=P;c[2440436]=R;aj=P;ak=R}else{c[2113070]=P;R=c[Q+132>>2]|0;c[2113068]=R;c[2440436]=P;c[2443814]=R;aj=R;ak=P}P=ag(aj<<1,ak)|0;R=gGq(P)|0;c[2112926]=R;if((R|0)!=0){gGz(R|0,0,P|0)}c[2438440]=0;c[2430836]=0;c[2430826]=0;P=c[2439330]|0;R=(P|0)==0;if(!R){Q=P;gGC(9706056,Q|0,76)|0}Q=c[2438118]|0;c[2433530]=Q;W=c[3528484]|0;c[2076596]=W;T=c[2417276]|0;c[3541536]=T;c[1836236]=0;gGz(9706056,0,76);if(!R){R=P;gGC(R|0,9706056,76)|0}c[2438118]=Q;c[3528484]=W;c[2417276]=T;c[1836236]=-1;T=c[2439331]|0;W=(T|0)==0;if(!W){Q=T;gGC(9706056,Q|0,76)|0}Q=c[2438119]|0;c[2433530]=Q;R=c[3528485]|0;c[2076596]=R;P=c[2417277]|0;c[3541536]=P;c[1836236]=1;gGz(9706056,0,76);if(!W){W=T;gGC(W|0,9706056,76)|0}c[2438119]=Q;c[3528485]=R;c[2417277]=P;c[1836236]=-1;mB(0);mB(1);mB(2);M=0;i=e;return M|0}}while(0);c[2426766]=0;M=1;i=e;return M|0}function dCv(){var a=0,b=0,d=0,e=0;fwZ();c[2113008]=0;c[2076598]=0;c[2383582]=0;c[2113070]=0;c[2113068]=0;a=c[2112926]|0;if((a|0)!=0){gGr(a);c[2112926]=0}a=c[2426766]|0;b=0;while(1){if((b|0)>=1024){d=5778;break}e=9638528+(b<<2)|0;if((c[e>>2]|0)==(a|0)){break}else{b=b+1|0}}if((d|0)==5778){c[2426766]=0;return 0}gGr(a);c[e>>2]=0;c[2426766]=0;return 0}function dCw(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;if((a[9771808]|0)!=0){c[2438440]=0;c[2430836]=0;c[2430826]=0;e=c[2439330]|0;f=(e|0)==0;if(!f){g=e;gGC(9706056,g|0,76)|0}g=c[2438118]|0;c[2433530]=g;h=c[3528484]|0;c[2076596]=h;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);if(!f){f=e;gGC(f|0,9706056,76)|0}c[2438118]=g;c[3528484]=h;c[2417276]=i;c[1836236]=-1;i=c[2439331]|0;h=(i|0)==0;if(!h){g=i;gGC(9706056,g|0,76)|0}g=c[2438119]|0;c[2433530]=g;f=c[3528485]|0;c[2076596]=f;e=c[2417277]|0;c[3541536]=e;c[1836236]=1;gGz(9706056,0,76);if(!h){h=i;gGC(h|0,9706056,76)|0}c[2438119]=g;c[3528485]=f;c[2417277]=e;c[1836236]=-1;mB(0);mB(1);mB(2)}a[9771818]=0;a[9771817]=0;a[9771816]=0;e=0;f=0;g=0;h=0;do{f=((a[9723336+e|0]&1)<<e|f&255)&255;g=((a[9723328+e|0]&1)<<e|g&255)&255;h=((a[9723320+e|0]&1)<<e|h&255)&255;e=e+1|0;}while((e|0)<8);a[9771816]=f;a[9771817]=g;a[9771818]=h;if((f&3)==3){h=f&-4;a[9771816]=h;j=h}else{j=f}if((j&12)==12){a[9771816]=j&-13}if((g&3)==3){j=g&-4;a[9771817]=j;k=j}else{k=g}if((k&12)==12){a[9771817]=k&-13}a[6518272]=1;a[6518088]=1;c[2443980]=0;c[2444028]=0;k=0;g=0;L7794:while(1){j=g;while(1){if((j|0)>=2){break L7794}f=c[2439330]|0;if((f|0)!=0){h=f;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;h=c[2438118]|0;c[2433530]=h;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;l=j+1|0;e=(ag(a[6518272]|0?66666:0,l)|0)/2|0;i=c[2444028]|0;m=e-i|0;do{if((m|0)<1){n=0;o=i;p=h}else{if((a[f+4188|0]|0)==0){e=gfc(m)|0;q=(c[2433530]|0)+e|0;c[2433530]=q;n=e;o=c[2444028]|0;p=q;break}else{q=h+m|0;c[2433530]=q;n=m;o=i;p=q;break}}}while(0);c[2444028]=o+n;if((j|0)==1&(c[2438440]|0)!=0){if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;i=(c[2433530]|0)+12|0;c[2433530]=i;r=i}else{r=p}i=c[1836236]|0;m=c[9757320+(i<<2)>>2]|0;if((m|0)!=0){h=m;gGC(h|0,9706056,76)|0}c[9752472+(i<<2)>>2]=r;c[14113936+(i<<2)>>2]=c[2076596];c[9669104+(i<<2)>>2]=c[3541536];c[1836236]=-1;i=c[2439331]|0;if((i|0)!=0){h=i;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;h=c[2438119]|0;c[2433530]=h;c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;m=(ag(a[6518088]|0?51200:0,l)|0)/2|0;f=c[2443980]|0;q=m-f|0;do{if((q|0)<1){s=0;t=f}else{if((a[i+4188|0]|0)==0){m=gfc(q)|0;c[2433530]=(c[2433530]|0)+m;s=m;t=c[2443980]|0;break}else{c[2433530]=h+q;s=q;t=f;break}}}while(0);c[2443980]=t+s;a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0;f=c[1836236]|0;q=c[9757320+(f<<2)>>2]|0;if((q|0)!=0){h=q;gGC(h|0,9706056,76)|0}c[9752472+(f<<2)>>2]=c[2433530];c[14113936+(f<<2)>>2]=c[2076596];c[9669104+(f<<2)>>2]=c[3541536];c[1836236]=-1;u=c[2112964]|0;if((u|0)==0){j=l}else{break}}j=a[9688]|0?267:0;mF(9756256,u+(k<<1<<1)|0,j,0);k=j+k|0;g=l}l=c[2112964]|0;do{if((l|0)!=0){g=a[9688]|0?534:0;if((g|0)==(k|0)){break}mF(9756256,l+(k<<1<<1)|0,g-k|0,0)}}while(0);if((c[2112968]|0)==0){return 0}k=c[2112926]|0;gGz(k|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);l=c[2430828]|0;g=c[2438438]|0;u=0;do{s=(d[l+(u|1)|0]<<8|d[l+(u&-2)|0])&65535;t=s>>>4&15;r=s>>>8;c[g+(((u|0)/2|0)<<2)>>2]=(r<<4|r&8)>>>3&31|(s<<4|s&8)<<8&63488|(t<<4|t)<<3&2016;u=u+1|0;}while((u|0)<512);u=c[2430070]|0;l=c[2430838]|0;t=c[2438444]|0;s=0;do{r=(s|0)%32|0;p=(s|0)/32|0;n=d[u+s|0]|0;o=d[l+s|0]|n<<8&1792;j=n>>>4&7;f=n&8;if((c[2430836]|0)==0){v=f;w=n&128;x=r;y=p}else{v=f>>>3^1;w=n>>>7^1;x=31-r|0;y=31-p|0}p=x<<3;r=(y<<3)-16|0;n=(v|0)==0;f=(w|0)!=0;do{if(p>>>0<247&r>>>0<215){if(n){if(f){Ss(k,o,p,r,j,4,0,128,t);break}else{Sq(k,o,p,r,j,4,0,128,t);break}}else{if(f){Sw(k,o,p,r,j,4,0,128,t);break}else{Su(k,o,p,r,j,4,0,128,t);break}}}else{if(n){if(f){St(k,o,p,r,j,4,0,128,t);break}else{Sr(k,o,p,r,j,4,0,128,t);break}}else{if(f){Sx(k,o,p,r,j,4,0,128,t);break}else{Sv(k,o,p,r,j,4,0,128,t);break}}}}while(0);s=s+1|0;}while((s|0)<1024);s=c[2437008]|0;t=c[2433336]|0;w=c[2438442]|0;v=1023;while(1){y=(v|0)%32|0;x=(v|0)/32|0;l=d[t+v|0]|0;u=l<<8&1792|d[s+v|0];j=l>>>4&7;l=(c[2430836]|0)==0;if(l){z=y;A=x}else{z=31-y|0;A=31-x|0}x=z<<3;y=(A<<3)-16|0;do{if(x>>>0<247&y>>>0<215){if(l){Sq(k,u,x,y,j,4,0,0,w);break}else{Sw(k,u,x,y,j,4,0,0,w);break}}else{if(l){Sr(k,u,x,y,j,4,0,0,w);break}else{Sx(k,u,x,y,j,4,0,0,w);break}}}while(0);if((v|0)>0){v=v-1|0}else{break}}v=c[2433334]|0;w=c[2438436]|0;A=124;do{z=d[v+(A|3)|0]|0;s=241-(d[v+(A|2)|0]|0)|0;t=d[v+(A|1)|0]|0;j=t<<4&256|d[v+A|0];y=t>>>1&7;x=t&64;if((c[2430836]&1|0)==0){B=t&128;C=x;D=z;E=s}else{B=t>>>7^1;C=x>>>6^1;D=240-z|0;E=240-s|0}s=E-16|0;z=(B|0)==0;x=(C|0)!=0;do{if(D>>>0<239&s>>>0<207){if(z){if(x){SI(k,j,D,s,y,4,0,0,w);break}else{SG(k,j,D,s,y,4,0,0,w);break}}else{if(x){SM(k,j,D,s,y,4,0,0,w);break}else{SK(k,j,D,s,y,4,0,0,w);break}}}else{if(z){if(x){SJ(k,j,D,s,y,4,0,0,w);break}else{SH(k,j,D,s,y,4,0,0,w);break}}else{if(x){SN(k,j,D,s,y,4,0,0,w);break}else{SL(k,j,D,s,y,4,0,0,w);break}}}}while(0);A=A-4|0;}while((A|0)>-1);R8(g);return 0}function dCx(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4976268+(b*112|0)>>2];c[a+104>>2]=c[4976272+(b*112|0)>>2];c[a+108>>2]=c[4976276+(b*112|0)>>2];d=0;return d|0}function dCy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=4976168+(b*112|0);e=0;return e|0}function dCz(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1690112+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dCA(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>44){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4977512+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dCB(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;d=i;i=i+96|0;e=d|0;f=d+16|0;g=d+32|0;h=d+48|0;j=d+64|0;k=d+80|0;if((b|0)!=0){c[b>>2]=10565}if((a&32|0)!=0){gGz(k|0,0,12);b=c[2405686]|0;c[k>>2]=b;c[k+4>>2]=(c[2411746]|0)-b;c[k+12>>2]=162152;b=c[2076592]|0;gj[b&4095](k)|0}if((a&64|0)==0){i=d;return 0}fw$(a);gGz(j|0,0,12);c[j>>2]=9753760;c[j+4>>2]=4;c[j+12>>2]=76968;gj[c[2076592]&4095](j)|0;gGz(h|0,0,12);c[h>>2]=9723344;c[h+4>>2]=4;c[h+12>>2]=584056;gj[c[2076592]&4095](h)|0;gGz(g|0,0,12);c[g>>2]=9723304;c[g+4>>2]=4;c[g+12>>2]=567352;gj[c[2076592]&4095](g)|0;gGz(f|0,0,12);c[f>>2]=9771816;c[f+4>>2]=3;c[f+12>>2]=551208;gj[c[2076592]&4095](f)|0;gGz(e|0,0,12);c[e>>2]=14115760;c[e+4>>2]=2;c[e+12>>2]=536792;gj[c[2076592]&4095](e)|0;i=d;return 0}function dCC(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3416012+(b*112|0)>>2];c[a+104>>2]=c[3416016+(b*112|0)>>2];c[a+108>>2]=c[3416020+(b*112|0)>>2];d=0;return d|0}function dCD(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=3415912+(b*112|0);e=0;return e|0}function dCE(b,d){b=b|0;d=d|0;var e=0;e=b&61440;if((e|0)==45056){TR(0,d&255);return}else if((e|0)==40960){a[c[3528732]|0]=d&1;return}else if((e|0)==49152){TR(1,d&255);return}else{return}}function dCF(b){b=b|0;var c=0,d=0;c=b&65535;do{if((c|0)==36865){if(!(a[668648]|0)){d=(a[672592]|0?-64:0)^a[9550673];break}if((a[9635328]&32)==0){d=(a[672592]|0?-64:0)^a[9550672]&127;break}else{d=(a[672592]|0?-64:0)^a[9550673];break}}else if((c|0)==57344){d=a[9550674]|0}else if((c|0)==36866){d=a[9635328]|0}else if((c|0)==32773){d=62}else if((c|0)==36867){d=a[9635329]|0}else if((c|0)==36864){d=a[9550672]|0}else{d=0}}while(0);return d|0}function dCG(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((e|0)==32775){a[(c[3528306]|0)+1|0]=d;return}else if((e|0)==32774){a[c[3528306]|0]=d;return}else{return}}function dCH(b,d){b=b|0;d=d|0;if(b<<16>>16!=-6144){return}a[c[3528732]|0]=d&-128;a[c[2385614]|0]=d&112;a[c[3525096]|0]=d&8;a[c[2385230]|0]=(d&7)-1&255;return}function dCI(b){b=b|0;var d=0,e=0;d=b&65535;if((d|0)==40960){e=a[(c[3528306]|0)+1|0]|0}else if((d|0)==32768){e=a[c[3528306]|0]|0}else{e=0}return e|0}function dCJ(a,b){a=a|0;b=b|0;switch(a&255|0){case 16:{TR(2,b&255);return};case 0:{TR(0,b&255);return};case 8:{TR(1,b&255);return};case 24:{TR(3,b&255);return};case 32:{TR(4,b&255);return};default:{return}}}function dCK(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4578412+(b*112|0)>>2];c[a+104>>2]=c[4578416+(b*112|0)>>2];c[a+108>>2]=c[4578420+(b*112|0)>>2];d=0;return d|0}function dCL(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=4578312+(b*112|0);e=0;return e|0}function dCM(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1850928+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dCN(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>46){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5313232+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dCO(){return dDk(0)|0}function dCP(){var b=0,d=0,e=0,f=0;c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}fwZ();TT();b=c[2415012]|0;d=0;while(1){if((d|0)>=1024){e=6016;break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==(b|0)){break}else{d=d+1|0}}if((e|0)==6016){c[2415012]=0;a[668648]=0;return 0}gGr(b);c[f>>2]=0;c[2415012]=0;a[668648]=0;return 0}function dCQ(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((a[9624520]|0)!=0){a[9624520]=0;d=c[2414718]|0;gGz(d|0,0,(c[2411744]|0)-d|0);d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;h=c[2417276]|0;c[3541536]=h;c[1836236]=0;gGz(9706056,0,76);if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=h;c[1836236]=-1;h=c[2439331]|0;g=(h|0)==0;if(!g){f=h;gGC(9706056,f|0,76)|0}f=c[2438119]|0;c[2433530]=f;e=c[3528485]|0;c[2076596]=e;d=c[2417277]|0;c[3541536]=d;c[1836236]=1;gGz(9706056,0,76);if(!g){g=h;gGC(g|0,9706056,76)|0}c[2438119]=f;c[3528485]=e;c[2417277]=d;c[1836236]=-1;c[2440192]=0;c[2443698]=0;a[672592]=0}d=a[9550675]|0;c[2387668]=-1;e=0;f=-1;g=-1;h=-1;i=-1;do{f=((a[9633936+e|0]&1)<<e^f&255)&255;g=((a[9631736+e|0]&1)<<e^g&255)&255;h=((a[9629712+e|0]&1)<<e^h&255)&255;j=(a[9629e3+e|0]&1)<<e^i&255;i=j&255;e=e+1|0;}while((e|0)<8);e=d&255^255;a[9550672]=f;a[9550674]=h;a[9550675]=i;i=(e&2|0)==(j&2^2|0);a[9550673]=g&127;g=c[2439330]|0;if((g|0)!=0){h=g;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;h=c[2438118]|0;c[2433530]=h;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;if((e&1|0)!=(j&1^1|0)){j=(a[9629e3]|0)!=0;if(!((a[9706115]|0)!=0|j^1)){a[9706116]=1}a[9706115]=j&1}if(!i){a[9706117]=(a[9629001]|0)!=0|0}a[672592]=1;i=0;j=h;while(1){if((i|0)==31){k=6043;break}else if((i|0)==5){a[672592]=0;if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){h=gfc(2083)|0;l=(c[2433530]|0)+h|0}else{l=j+2083|0}c[2433530]=l;i=6;j=l;continue}else{if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){h=gfc(2083)|0;m=(c[2433530]|0)+h|0}else{m=j+2083|0}c[2433530]=m;h=i+1|0;if((h|0)<32){i=h;j=m;continue}else{n=m;break}}}do{if((k|0)==6043){a[672592]=1;if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){m=gfc(2083)|0;i=(c[2433530]|0)+m|0;c[2433530]=i;n=i;break}else{i=j+2083|0;c[2433530]=i;n=i;break}}}while(0);j=c[1836236]|0;k=c[9757320+(j<<2)>>2]|0;if((k|0)!=0){i=k;gGC(i|0,9706056,76)|0}c[9752472+(j<<2)>>2]=n;c[14113936+(j<<2)>>2]=c[2076596];c[9669104+(j<<2)>>2]=c[3541536];c[1836236]=-1;j=c[2112964]|0;n=a[9688]|0?534:0;TQ(0,j,n);TQ(1,j,n);if((c[2112968]|0)==0){return 0}if((a[9547648]|0)==0){o=c[3530068]|0}else{n=c[2406954]|0;j=c[3530068]|0;i=0;do{k=c[n+(i<<2)>>2]|0;c[j+(i<<2)>>2]=k>>8<<3&2016|k>>>3&31|k>>16<<8&63488;i=i+1|0;}while((i|0)<96);a[9547648]=0;o=j}j=c[2112926]|0;gGz(j|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);dDg();dDh();R8(o);return 0}function dCR(){var b=0,d=0,e=0,f=0,g=0;if((a[9547648]|0)==0){b=c[3530068]|0}else{d=c[2406954]|0;e=c[3530068]|0;f=0;do{g=c[d+(f<<2)>>2]|0;c[e+(f<<2)>>2]=g>>8<<3&2016|g>>>3&31|g>>16<<8&63488;f=f+1|0;}while((f|0)<96);a[9547648]=0;b=e}e=c[2112926]|0;gGz(e|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);dDg();dDh();R8(b);return 0}function dCS(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=i;i=i+48|0;e=d|0;f=d+16|0;g=d+32|0;if((b|0)!=0){c[b>>2]=169734}if((a&96|0)==0){i=d;return 0}gGz(g|0,0,12);h=c[2414718]|0;c[g>>2]=h;c[g+4>>2]=(c[2411744]|0)-h;c[g+12>>2]=162152;gj[c[2076592]&4095](g)|0;fw$(a);TU(a,b);gGz(f|0,0,12);c[f>>2]=9760768;c[f+4>>2]=4;c[f+12>>2]=587688;gj[c[2076592]&4095](f)|0;gGz(e|0,0,12);c[e>>2]=9774792;c[e+4>>2]=4;c[e+12>>2]=585872;gj[c[2076592]&4095](e)|0;i=d;return 0}function dCT(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2658604+(b*112|0)>>2];c[a+104>>2]=c[2658608+(b*112|0)>>2];c[a+108>>2]=c[2658612+(b*112|0)>>2];d=0;return d|0}function dCU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=2658504+(b*112|0);e=0;return e|0}function dCV(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2660060+(b*112|0)>>2];c[a+104>>2]=c[2660064+(b*112|0)>>2];c[a+108>>2]=c[2660068+(b*112|0)>>2];d=0;return d|0}function dCW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=2659960+(b*112|0);e=0;return e|0}function dCX(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2258660+(b*112|0)>>2];c[a+104>>2]=c[2258664+(b*112|0)>>2];c[a+108>>2]=c[2258668+(b*112|0)>>2];d=0;return d|0}function dCY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=2258560+(b*112|0);e=0;return e|0}function dCZ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>41){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3423688+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dC_(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3031972+(b*112|0)>>2];c[a+104>>2]=c[3031976+(b*112|0)>>2];c[a+108>>2]=c[3031980+(b*112|0)>>2];d=0;return d|0}function dC$(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=3031872+(b*112|0);e=0;return e|0}function dC0(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>44){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4183840+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dC1(){return dDk(1)|0}function dC2(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4734236+(b*112|0)>>2];c[a+104>>2]=c[4734240+(b*112|0)>>2];c[a+108>>2]=c[4734244+(b*112|0)>>2];d=0;return d|0}function dC3(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=4734136+(b*112|0);e=0;return e|0}function dC4(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>46){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5452528+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dC5(){return dDk(2)|0}function dC6(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2928036+(b*112|0)>>2];c[a+104>>2]=c[2928040+(b*112|0)>>2];c[a+108>>2]=c[2928044+(b*112|0)>>2];d=0;return d|0}function dC7(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=2927936+(b*112|0);e=0;return e|0}function dC8(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4382828+(b*112|0)>>2];c[a+104>>2]=c[4382832+(b*112|0)>>2];c[a+108>>2]=c[4382836+(b*112|0)>>2];d=0;return d|0}function dC9(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=4382728+(b*112|0);e=0;return e|0}function dDa(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1686272+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dDb(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>44){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4968280+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dDc(){var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0;d=i;i=i+1560|0;e=d|0;f=d+112|0;g=d+120|0;j=d+232|0;k=d+240|0;l=d+352|0;m=d+360|0;n=d+472|0;o=d+480|0;p=d+592|0;q=d+600|0;r=d+712|0;s=d+720|0;t=d+832|0;u=d+840|0;v=d+952|0;w=d+960|0;x=d+1072|0;y=d+1080|0;z=d+1192|0;A=d+1200|0;B=d+1312|0;C=d+1320|0;D=d+1432|0;E=d+1440|0;F=d+1552|0;c[2415012]=0;c[3529250]=0;c[3529206]=65536;c[3529354]=65536;c[3530876]=131072;c[3530640]=163840;c[3530450]=196608;c[3530344]=229376;c[3531020]=262144;c[2406954]=262208;c[3530068]=262728;c[2414718]=263248;c[3529338]=263248;c[3529296]=267344;c[2387880]=268368;c[2386236]=269392;c[2386488]=270416;c[3530278]=271440;c[3528732]=271696;c[3528306]=271697;c[2385614]=271699;c[3525096]=271700;c[2385230]=271701;c[2411744]=271702;G=0;while(1){if((G|0)>=1024){break}H=9638528+(G<<2)|0;if((c[H>>2]|0)==0){I=6199;break}else{G=G+1|0}}do{if((I|0)==6199){G=gGq(271702)|0;c[H>>2]=G;if((G|0)==0){break}c[2415012]=G;gGz(G|0,0,271702);c[3529250]=G;J=G+65536|0;c[3529206]=J;c[3529354]=J;c[3530876]=G+131072;c[3530640]=G+163840;c[3530450]=G+196608;c[3530344]=G+229376;c[3531020]=G+262144;c[2406954]=G+262208;c[3530068]=G+262728;J=G+263248|0;c[2414718]=J;c[3529338]=J;c[3529296]=G+267344;c[2387880]=G+268368;c[2386236]=G+269392;c[2386488]=G+270416;c[3530278]=G+271440;c[3528732]=G+271696;c[3528306]=G+271697;c[2385614]=G+271699;c[3525096]=G+271700;c[2385230]=G+271701;J=G+271702|0;c[2411744]=J;c[2414286]=J;if((c[3542200]|0)==0){K=1;i=d;return K|0}J=E+108|0;c[J>>2]=0;L=E+100|0;c[L>>2]=0;M=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[M&16383](E,0)|0;do{if((c[J>>2]|0)!=0){M=c[L>>2]|0;c[F>>2]=9534384;N=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[N&16383](F,0,0)|0;if((M|0)<1){K=1;i=d;return K|0}if((gzL(G,0,0)|0)==0){break}else{K=1}i=d;return K|0}}while(0);G=(c[3529250]|0)+8192|0;if((c[3542200]|0)==0){K=1;i=d;return K|0}L=C+108|0;c[L>>2]=0;J=C+100|0;c[J>>2]=0;M=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[M&16383](C,1)|0;do{if((c[L>>2]|0)!=0){M=c[J>>2]|0;c[D>>2]=9534384;N=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[N&16383](D,1,0)|0;if((M|0)<1){K=1;i=d;return K|0}if((gzL(G,0,1)|0)==0){break}else{K=1}i=d;return K|0}}while(0);G=(c[3529250]|0)+16384|0;if((c[3542200]|0)==0){K=1;i=d;return K|0}J=A+108|0;c[J>>2]=0;L=A+100|0;c[L>>2]=0;M=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[M&16383](A,2)|0;do{if((c[J>>2]|0)!=0){M=c[L>>2]|0;c[B>>2]=9534384;N=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[N&16383](B,2,0)|0;if((M|0)<1){K=1;i=d;return K|0}if((gzL(G,0,2)|0)==0){break}else{K=1}i=d;return K|0}}while(0);G=c[3529206]|0;if((c[3542200]|0)==0){K=1;i=d;return K|0}L=y+108|0;c[L>>2]=0;J=y+100|0;c[J>>2]=0;M=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[M&16383](y,3)|0;do{if((c[L>>2]|0)!=0){M=c[J>>2]|0;c[z>>2]=9534384;N=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[N&16383](z,3,0)|0;if((M|0)<1){K=1;i=d;return K|0}if((gzL(G,0,3)|0)==0){break}else{K=1}i=d;return K|0}}while(0);G=(c[3529206]|0)+8192|0;if((c[3542200]|0)==0){K=1;i=d;return K|0}J=w+108|0;c[J>>2]=0;L=w+100|0;c[L>>2]=0;M=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[M&16383](w,4)|0;do{if((c[J>>2]|0)!=0){M=c[L>>2]|0;c[x>>2]=9534384;N=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[N&16383](x,4,0)|0;if((M|0)<1){K=1;i=d;return K|0}if((gzL(G,0,4)|0)==0){break}else{K=1}i=d;return K|0}}while(0);G=(c[3529206]|0)+16384|0;if((c[3542200]|0)==0){K=1;i=d;return K|0}L=u+108|0;c[L>>2]=0;J=u+100|0;c[J>>2]=0;M=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[M&16383](u,5)|0;do{if((c[L>>2]|0)!=0){M=c[J>>2]|0;c[v>>2]=9534384;N=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[N&16383](v,5,0)|0;if((M|0)<1){K=1;i=d;return K|0}if((gzL(G,0,5)|0)==0){break}else{K=1}i=d;return K|0}}while(0);G=c[3530876]|0;if((c[3542200]|0)==0){K=1;i=d;return K|0}J=s+108|0;c[J>>2]=0;L=s+100|0;c[L>>2]=0;M=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[M&16383](s,6)|0;do{if((c[J>>2]|0)!=0){M=c[L>>2]|0;c[t>>2]=9534384;N=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[N&16383](t,6,0)|0;if((M|0)<1){K=1;i=d;return K|0}if((gzL(G,0,6)|0)==0){break}else{K=1}i=d;return K|0}}while(0);G=(c[3530876]|0)+4096|0;if((c[3542200]|0)==0){K=1;i=d;return K|0}L=q+108|0;c[L>>2]=0;J=q+100|0;c[J>>2]=0;M=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[M&16383](q,7)|0;do{if((c[L>>2]|0)!=0){M=c[J>>2]|0;c[r>>2]=9534384;N=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[N&16383](r,7,0)|0;if((M|0)<1){K=1;i=d;return K|0}if((gzL(G,0,7)|0)==0){break}else{K=1}i=d;return K|0}}while(0);G=c[3530640]|0;if((c[3542200]|0)==0){K=1;i=d;return K|0}J=o+108|0;c[J>>2]=0;L=o+100|0;c[L>>2]=0;M=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[M&16383](o,8)|0;do{if((c[J>>2]|0)!=0){M=c[L>>2]|0;c[p>>2]=9534384;N=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[N&16383](p,8,0)|0;if((M|0)<1){K=1;i=d;return K|0}if((gzL(G,0,8)|0)==0){break}else{K=1}i=d;return K|0}}while(0);G=(c[3530640]|0)+4096|0;if((c[3542200]|0)==0){K=1;i=d;return K|0}L=m+108|0;c[L>>2]=0;J=m+100|0;c[J>>2]=0;M=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[M&16383](m,9)|0;do{if((c[L>>2]|0)!=0){M=c[J>>2]|0;c[n>>2]=9534384;N=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[N&16383](n,9,0)|0;if((M|0)<1){K=1;i=d;return K|0}if((gzL(G,0,9)|0)==0){break}else{K=1}i=d;return K|0}}while(0);G=c[3530344]|0;if((c[3542200]|0)==0){K=1;i=d;return K|0}J=k+108|0;c[J>>2]=0;L=k+100|0;c[L>>2]=0;M=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[M&16383](k,10)|0;do{if((c[J>>2]|0)!=0){M=c[L>>2]|0;c[l>>2]=9534384;N=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[N&16383](l,10,0)|0;if((M|0)<1){K=1;i=d;return K|0}if((gzL(G,0,10)|0)==0){break}else{K=1}i=d;return K|0}}while(0);G=c[3531020]|0;if((c[3542200]|0)==0){K=1;i=d;return K|0}L=g+108|0;c[L>>2]=0;J=g+100|0;c[J>>2]=0;M=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[M&16383](g,11)|0;do{if((c[L>>2]|0)!=0){M=c[J>>2]|0;c[j>>2]=9534384;N=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[N&16383](j,11,0)|0;if((M|0)<1){K=1;i=d;return K|0}if((gzL(G,0,11)|0)==0){break}else{K=1}i=d;return K|0}}while(0);G=(c[3531020]|0)+32|0;if((c[3542200]|0)==0){K=1;i=d;return K|0}J=e+108|0;c[J>>2]=0;L=e+100|0;c[L>>2]=0;M=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[M&16383](e,12)|0;do{if((c[J>>2]|0)!=0){M=c[L>>2]|0;c[f>>2]=9534384;N=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[N&16383](f,12,0)|0;if((M|0)<1){K=1;i=d;return K|0}if((gzL(G,0,12)|0)==0){break}else{K=1}i=d;return K|0}}while(0);dDj(3,0,5,4,7,6);G=c[2406954]|0;L=0;do{c[G+(L+96<<2)>>2]=(-(L>>>3&1)&71)+(-(L>>>4&1)&151)|-(L&1)<<16&4653056|(-(L>>>1&1)&71)+(-(L>>>2&1)&151)<<8;L=L+1|0;}while((L|0)<32);dDi();fwR(0);L=c[2439330]|0;G=(L|0)==0;if(!G){J=L;gGC(9706056,J|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];J=c[3528484]|0;c[2076596]=J;M=c[2417276]|0;c[3541536]=M;c[1836236]=0;N=c[3529250]|0;O=0;P=0;while(1){c[L+76+(P<<2)>>2]=N+(P<<8);Q=O+1&65535;if((Q&65535)>95){R=0;S=0;break}else{O=Q;P=Q&65535}}while(1){P=N+(S<<8)|0;c[L+76+(S+512<<2)>>2]=P;c[L+76+(S+768<<2)>>2]=P;P=R+1&65535;if((P&65535)>95){break}else{R=P;S=P&65535}}N=c[3529338]|0;c[L+460>>2]=N;c[L+464>>2]=N+256;c[L+468>>2]=N+512;c[L+472>>2]=N+768;c[L+476>>2]=N+1024;c[L+480>>2]=N+1280;c[L+484>>2]=N+1536;c[L+488>>2]=N+1792;c[L+492>>2]=N+2048;c[L+496>>2]=N+2304;c[L+500>>2]=N+2560;c[L+504>>2]=N+2816;c[L+508>>2]=N+3072;c[L+512>>2]=N+3328;c[L+516>>2]=N+3584;c[L+520>>2]=N+3840;P=96;O=96;while(1){c[L+76+(O+256<<2)>>2]=N+((O<<8)-24576);Q=P+1&65535;if((Q&65535)>111){T=96;U=96;break}else{P=Q;O=Q&65535}}while(1){O=N+((U<<8)-24576)|0;c[L+76+(U+512<<2)>>2]=O;c[L+76+(U+768<<2)>>2]=O;O=T+1&65535;if((O&65535)>111){break}else{T=O;U=O&65535}}N=c[2386488]|0;c[L+524>>2]=N;O=N+256|0;c[L+528>>2]=O;P=N+512|0;c[L+532>>2]=P;Q=N+768|0;c[L+536>>2]=Q;c[L+1548>>2]=N;c[L+1552>>2]=O;c[L+1556>>2]=P;c[L+1560>>2]=Q;c[L+2572>>2]=N;c[L+3596>>2]=N;c[L+2576>>2]=O;c[L+3600>>2]=O;c[L+2580>>2]=P;c[L+3604>>2]=P;c[L+2584>>2]=Q;c[L+3608>>2]=Q;Q=c[2386236]|0;c[L+908>>2]=Q;P=Q+256|0;c[L+912>>2]=P;O=Q+512|0;c[L+916>>2]=O;N=Q+768|0;c[L+920>>2]=N;c[L+1932>>2]=Q;c[L+1936>>2]=P;c[L+1940>>2]=O;c[L+1944>>2]=N;c[L+2956>>2]=Q;c[L+3980>>2]=Q;c[L+2960>>2]=P;c[L+3984>>2]=P;c[L+2964>>2]=O;c[L+3988>>2]=O;c[L+2968>>2]=N;c[L+3992>>2]=N;N=c[2387880]|0;c[L+924>>2]=N;O=N+256|0;c[L+928>>2]=O;P=N+512|0;c[L+932>>2]=P;Q=N+768|0;c[L+936>>2]=Q;c[L+1948>>2]=N;c[L+1952>>2]=O;c[L+1956>>2]=P;c[L+1960>>2]=Q;c[L+2972>>2]=N;c[L+3996>>2]=N;c[L+2976>>2]=O;c[L+4e3>>2]=O;c[L+2980>>2]=P;c[L+4004>>2]=P;c[L+2984>>2]=Q;c[L+4008>>2]=Q;c[L+4184>>2]=202;c[L+4180>>2]=2886;if(!G){Q=L;gGC(Q|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=J;c[2417276]=M;c[1836236]=-1;fwR(1);Q=c[2439331]|0;P=(Q|0)==0;if(!P){O=Q;gGC(9706056,O|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];O=c[3528485]|0;c[2076596]=O;N=c[2417277]|0;c[3541536]=N;c[1836236]=1;V=c[3529206]|0;W=0;X=0;while(1){c[Q+76+(X<<2)>>2]=V+(X<<8);Y=W+1&65535;if((Y&65535)>95){Z=0;_=0;break}else{W=Y;X=Y&65535}}while(1){X=V+(_<<8)|0;c[Q+76+(_+512<<2)>>2]=X;c[Q+76+(_+768<<2)>>2]=X;X=Z+1&65535;if((X&65535)>95){break}else{Z=X;_=X&65535}}V=c[3529296]|0;c[Q+460>>2]=V;X=V+256|0;c[Q+464>>2]=X;W=V+512|0;c[Q+468>>2]=W;M=V+768|0;c[Q+472>>2]=M;c[Q+1484>>2]=V;c[Q+1488>>2]=X;c[Q+1492>>2]=W;c[Q+1496>>2]=M;c[Q+2508>>2]=V;c[Q+3532>>2]=V;c[Q+2512>>2]=X;c[Q+3536>>2]=X;c[Q+2516>>2]=W;c[Q+3540>>2]=W;c[Q+2520>>2]=M;c[Q+3544>>2]=M;M=c[3530278]|0;c[Q+972>>2]=M;c[Q+1996>>2]=M;c[Q+3020>>2]=M;c[Q+4044>>2]=M;c[Q+4184>>2]=1806;c[Q+4180>>2]=2120;c[Q+4176>>2]=2760;if(!P){M=Q;gGC(M|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=O;c[2417277]=N;c[1836236]=-1;TS(0,4e6,16384,3,1,0);TS(1,4e6,16384,3,1,1);TS(2,4e6,16384,3,1,1);TS(3,4e6,16384,3,1,1);TS(4,4e6,16384,3,1,1);M=c[2420348]|0;h[M+192>>3]=1.0;c[M+200>>2]=3;M=c[2420346]|0;h[M+192>>3]=1.0;c[M+200>>2]=3;M=c[2420344]|0;h[M+192>>3]=1.0;c[M+200>>2]=3;M=c[2420342]|0;h[M+192>>3]=1.0;c[M+200>>2]=3;M=c[2420340]|0;h[M+192>>3]=1.0;c[M+200>>2]=3;M=c[642608+(c[2436]<<2)>>2]|0;W=c[M+128>>2]|0;if((c[M+52>>2]&4|0)==0){c[2113068]=W;X=c[M+132>>2]|0;c[2113070]=X;c[2443814]=W;c[2440436]=X;$=W;aa=X}else{c[2113070]=W;X=c[M+132>>2]|0;c[2113068]=X;c[2440436]=W;c[2443814]=X;$=X;aa=W}W=ag($<<1,aa)|0;X=gGq(W)|0;c[2112926]=X;if((X|0)!=0){gGz(X|0,0,W|0)}a[9624520]=0;W=c[2414718]|0;gGz(W|0,0,(c[2411744]|0)-W|0);W=c[2439330]|0;X=(W|0)==0;if(!X){M=W;gGC(9706056,M|0,76)|0}M=c[2438118]|0;c[2433530]=M;V=c[3528484]|0;c[2076596]=V;J=c[2417276]|0;c[3541536]=J;c[1836236]=0;gGz(9706056,0,76);if(!X){X=W;gGC(X|0,9706056,76)|0}c[2438118]=M;c[3528484]=V;c[2417276]=J;c[1836236]=-1;J=c[2439331]|0;V=(J|0)==0;if(!V){M=J;gGC(9706056,M|0,76)|0}M=c[2438119]|0;c[2433530]=M;X=c[3528485]|0;c[2076596]=X;W=c[2417277]|0;c[3541536]=W;c[1836236]=1;gGz(9706056,0,76);if(!V){V=J;gGC(V|0,9706056,76)|0}c[2438119]=M;c[3528485]=X;c[2417277]=W;c[1836236]=-1;c[2440192]=0;c[2443698]=0;a[672592]=0;K=0;i=d;return K|0}}while(0);c[2415012]=0;K=1;i=d;return K|0}function dDd(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((a[9624520]|0)!=0){a[9624520]=0;d=c[2414718]|0;gGz(d|0,0,(c[2411744]|0)-d|0);d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;h=c[2417276]|0;c[3541536]=h;c[1836236]=0;gGz(9706056,0,76);if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=h;c[1836236]=-1;h=c[2439331]|0;g=(h|0)==0;if(!g){f=h;gGC(9706056,f|0,76)|0}f=c[2438119]|0;c[2433530]=f;e=c[3528485]|0;c[2076596]=e;d=c[2417277]|0;c[3541536]=d;c[1836236]=1;gGz(9706056,0,76);if(!g){g=h;gGC(g|0,9706056,76)|0}c[2438119]=f;c[3528485]=e;c[2417277]=d;c[1836236]=-1;c[2440192]=0;c[2443698]=0;a[672592]=0}b[4775336]=-1;d=0;e=-1;f=-1;do{e=((a[9633936+d|0]&1)<<d^e&255)&255;f=((a[9631736+d|0]&1)<<d^f&255)&255;d=d+1|0;}while((d|0)<8);a[9550672]=e;a[9550673]=f;f=0;do{e=c[2439330]|0;if((e|0)!=0){d=e;gGC(9706056,d|0,76)|0}b[4853030]=c[2426515]&65535;d=c[2438118]|0;c[2433530]=d;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;if((a[e+4188|0]|0)==0){e=gfc(666)|0;i=(c[2433530]|0)+e|0}else{i=d+666|0}c[2433530]=i;if((f|0)==99){j=6347;break}d=c[1836236]|0;e=c[9757320+(d<<2)>>2]|0;if((e|0)!=0){g=e;gGC(g|0,9706056,76)|0}c[9752472+(d<<2)>>2]=i;c[14113936+(d<<2)>>2]=c[2076596];c[9669104+(d<<2)>>2]=c[3541536];c[1836236]=-1;d=c[2439331]|0;if((d|0)!=0){g=d;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;g=c[2438119]|0;c[2433530]=g;c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;if((a[d+4188|0]|0)==0){e=gfc(666)|0;h=c[1836236]|0;k=(c[2433530]|0)+e|0;l=h;m=c[9757320+(h<<2)>>2]|0}else{k=g+666|0;l=1;m=d}c[2433530]=k;if((m|0)!=0){d=m;gGC(d|0,9706056,76)|0}c[9752472+(l<<2)>>2]=k;c[14113936+(l<<2)>>2]=c[2076596];c[9669104+(l<<2)>>2]=c[3541536];c[1836236]=-1;f=f+1|0;}while((f|0)<100);if((j|0)==6347){a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0;j=c[1836236]|0;f=c[9757320+(j<<2)>>2]|0;if((f|0)!=0){l=f;gGC(l|0,9706056,76)|0}c[9752472+(j<<2)>>2]=c[2433530];c[14113936+(j<<2)>>2]=c[2076596];c[9669104+(j<<2)>>2]=c[3541536];c[1836236]=-1;j=c[2439331]|0;if((j|0)!=0){l=j;gGC(9706056,l|0,76)|0}b[4853030]=c[2426515]&65535;l=c[2438119]|0;c[2433530]=l;c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;if((a[j+4188|0]|0)==0){j=gfc(666)|0;n=(c[2433530]|0)+j|0}else{n=l+666|0}c[2433530]=n;a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0;n=c[1836236]|0;l=c[9757320+(n<<2)>>2]|0;if((l|0)!=0){j=l;gGC(j|0,9706056,76)|0}c[9752472+(n<<2)>>2]=c[2433530];c[14113936+(n<<2)>>2]=c[2076596];c[9669104+(n<<2)>>2]=c[3541536];c[1836236]=-1}n=c[2112964]|0;j=a[9688]|0?534:0;TQ(0,n,j);TQ(1,n,j);TQ(2,n,j);TQ(3,n,j);TQ(4,n,j);if((c[2112968]|0)==0){return 0}dDe()|0;return 0}function dDe(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((a[9547648]|0)==0){b=c[3530068]|0}else{e=c[2406954]|0;f=c[3530068]|0;g=0;do{h=c[e+(g<<2)>>2]|0;c[f+(g<<2)>>2]=h>>8<<3&2016|h>>>3&31|h>>16<<8&63488;g=g+1|0;}while((g|0)<128);a[9547648]=0;b=f}f=d[c[2385614]|0]|0;c[b+516>>2]=((f&32|0)!=0?224:0)|((f&16|0)!=0?31:0);f=c[2112926]|0;gGz(f|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);g=c[3528732]|0;if((a[g]|0)==0){dDf(0,216)}else{dDf(39,255)}do{if((a[c[3525096]|0]|0)!=0){e=c[2384304]&1;c[2384304]=e^1;if((e|0)==0){c[2443698]=130161;break}else{c[2440192]=(c[2440192]|0)+65527+(d[c[2385230]|0]<<1)&65535;c[2443698]=0;break}}}while(0);e=c[3530344]|0;h=128;do{i=h<<3&248;j=i-8|0;k=h>>5<<3;l=k-32|0;do{if((a[g]|0)==0){if((h&512|0)==0){Sr(f,h,j,l,0,1,0,128,e);break}else{Sv(f,h&511^480,j,l,0,1,0,128,e);break}}else{m=248-i|0;n=228-k|0;if((h&512|0)==0){Sx(f,h,m,n,0,1,0,128,e);break}else{St(f,h&511^480,m,n,0,1,0,128,e);break}}}while(0);h=h+1|0;}while((h|0)<896);dDg();dDh();R8(b);return 0}function dDf(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;if((a[c[3525096]|0]|0)==0){return}f=c[2113068]|0;g=c[2113070]|0;h=c[2112926]|0;i=c[2443698]|0;j=0;while(1){k=(c[2440192]|0)+j|0;l=(k&255)-8|0;m=(k>>>8&255)-32|0;n=i>>>16&1;o=i>>>5&1^1;p=o^n;do{if((l|0)>-1){if(!((l|0)<(f|0)&(m|0)>-1&(m|0)<(g|0))){break}if((k&16|0)==0){break}if((n|0)!=(o|0)|(i&255|0)!=255|(l|0)<(d|0)|(l|0)>(e|0)){break}b[h+((ag(f,m)|0)+l<<1)>>1]=(i>>>9&31|96)&65535}}while(0);l=j+1|0;if((l|0)>=65536){break}i=p|i<<1&131070;j=l}return}function dDg(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[2386236]|0;e=c[2387880]|0;f=c[3528732]|0;g=c[2112926]|0;h=c[3530876]|0;i=128;do{j=i>>5;k=(i<<3&248)-8-(d[b+(j<<5&96|i>>7)|0]|0)|0;l=(k|0)<-7?k+256|0:k;k=d[e+i|0]|0;m=k<<5&256|d[b+i|0];n=k&7;if((a[f]|0)==0){Sr(g,m,l,(j<<3)-32|0,n,2,0,0,h)}else{Sx(g,m,240-l|0,(196-j<<3)-32|0,n,2,0,0,h)}i=i+1|0;}while((i|0)<896);return}function dDh(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;b=c[2386488]|0;e=c[2112926]|0;f=c[3530450]|0;g=c[3530640]|0;h=896;do{i=0;while(1){if((i|0)>=64){j=6417;break}if((a[b+(i+h)|0]|0)==0){j=6416;break}else{i=i+4|0}}if((j|0)==6416){j=0;if((i|0)>0){j=6417}}if((j|0)==6417){j=0;k=(h|0)/4|0;l=i;do{l=l-4|0;m=l+h|0;n=d[b+m|0]|0;do{if((n&128|0)!=0){o=n>>>6&1;p=d[b+(m|2)|0]|0;q=((p&16)<<(4>>>(o>>>0)))+((d[b+(m|1)|0]|0)>>>2)|0;r=(p&15)+8|0;p=(d[b+(m|3)|0]|0)-8|0;s=(n&15)+k|0;t=s-32|0;u=(n&16|0)!=0;v=(n&32|0)!=0;if((o|0)==0){if(u){if(v){Sx(e,q,p,t,r,2,0,0,f);break}else{Sv(e,q,p,t,r,2,0,0,f);break}}else{if(v){St(e,q,p,t,r,2,0,0,f);break}else{Sr(e,q,p,t,r,2,0,0,f);break}}}else{t=s-40|0;if(u){if(v){SN(e,q,p,t,r,2,0,0,g);break}else{SL(e,q,p,t,r,2,0,0,g);break}}else{if(v){SJ(e,q,p,t,r,2,0,0,g);break}else{SH(e,q,p,t,r,2,0,0,g);break}}}}}while(0);}while((l|0)>0)}h=h-64|0;}while((h|0)>127);return}function dDi(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=0;while(1){if((b|0)>=1024){e=6493;break}f=9638528+(b<<2)|0;if((c[f>>2]|0)==0){break}else{b=b+1|0}}if((e|0)==6493){return}b=gGq(8192)|0;c[f>>2]=b;if((b|0)==0){return}gGz(b|0,0,8192);f=c[3530876]|0;gGC(b|0,f|0,8192)|0;g=0;do{h=g<<6;gGz(f+h|0,0,64);i=0;do{j=h+(c[1238464+(i<<2)>>2]|0)|0;k=(i<<3)+h|0;l=0;do{m=j+(c[610352+(l<<2)>>2]|0)|0;if(((d[b+((m|0)/8|0)|0]|0)&128>>>((m&7)>>>0)|0)!=0){m=f+(k+l)|0;a[m]=a[m]|2}l=l+1|0;}while((l|0)<8);i=i+1|0;}while((i|0)<8);i=h+32768|0;l=0;do{k=i+(c[1238464+(l<<2)>>2]|0)|0;j=(l<<3)+h|0;m=0;do{n=k+(c[610352+(m<<2)>>2]|0)|0;if(((d[b+((n|0)/8|0)|0]|0)&128>>>((n&7)>>>0)|0)!=0){n=f+(j+m)|0;a[n]=a[n]|1}m=m+1|0;}while((m|0)<8);l=l+1|0;}while((l|0)<8);g=g+1|0;}while((g|0)<512);g=c[3530640]|0;gGC(b|0,g|0,8192)|0;f=0;do{l=f<<8;gGz(g+l|0,0,256);h=f<<9;i=h|1;m=0;while(1){j=i+(c[608816+(m<<2)>>2]|0)|0;k=(m<<4)+l|0;n=0;do{o=j+(c[610192+(n<<2)>>2]|0)|0;if(((d[b+((o|0)/8|0)|0]|0)&128>>>((o&7)>>>0)|0)!=0){o=g+(k+n)|0;a[o]=a[o]|2}n=n+1|0;}while((n|0)<16);n=m+1|0;if((n|0)<16){m=n}else{p=0;break}}do{m=h+(c[608816+(p<<2)>>2]|0)|0;i=(p<<4)+l|0;n=0;do{k=m+(c[610192+(n<<2)>>2]|0)|0;if(((d[b+((k|0)/8|0)|0]|0)&128>>>((k&7)>>>0)|0)!=0){k=g+(i+n)|0;a[k]=a[k]|1}n=n+1|0;}while((n|0)<16);p=p+1|0;}while((p|0)<16);f=f+1|0;}while((f|0)<128);f=c[3530450]|0;p=0;do{g=p<<6;gGz(f+g|0,0,64);l=p<<7;h=l|1;n=0;while(1){i=h+(c[608816+(n+8<<2)>>2]|0)|0;m=(n<<3)+g|0;k=0;do{j=i+(c[610192+(k<<2)>>2]|0)|0;if(((d[b+((j|0)/8|0)|0]|0)&128>>>((j&7)>>>0)|0)!=0){j=f+(m+k)|0;a[j]=a[j]|2}k=k+1|0;}while((k|0)<8);k=n+1|0;if((k|0)<8){n=k}else{q=0;break}}do{n=l+(c[608816+(q+8<<2)>>2]|0)|0;h=(q<<3)+g|0;k=0;do{m=n+(c[610192+(k<<2)>>2]|0)|0;if(((d[b+((m|0)/8|0)|0]|0)&128>>>((m&7)>>>0)|0)!=0){m=f+(h+k)|0;a[m]=a[m]|1}k=k+1|0;}while((k|0)<8);q=q+1|0;}while((q|0)<8);p=p+1|0;}while((p|0)<512);p=c[3530344]|0;gGC(b|0,p|0,4096)|0;q=0;while(1){f=q<<6;gGz(p+f|0,0,64);g=0;do{l=f+(c[1238464+(g<<2)>>2]|0)|0;k=(g<<3)+f|0;h=0;do{n=l+(c[610352+(h<<2)>>2]|0)|0;if(((d[b+((n|0)/8|0)|0]|0)&128>>>((n&7)>>>0)|0)!=0){n=p+(k+h)|0;a[n]=a[n]|1}h=h+1|0;}while((h|0)<8);g=g+1|0;}while((g|0)<8);g=q+1|0;if((g|0)<512){q=g}else{r=0;break}}while(1){if((r|0)>=1024){e=6494;break}s=9638528+(r<<2)|0;if((c[s>>2]|0)==(b|0)){break}else{r=r+1|0}}if((e|0)==6494){return}gGr(b);c[s>>2]=0;return}function dDj(b,e,f,g,h,i){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0;j=c[3531020]|0;k=c[3530068]|0;l=0;do{m=~(d[j+l|0]|0);c[k+(l<<2)>>2]=-(m>>>(h>>>0)&1)&82|-(m>>>(i>>>0)&1)&173|(-(m>>>(f>>>0)&1)&82|-(m>>>(g>>>0)&1)&173)<<8|(-(m>>>(b>>>0)&1)&82|-(m>>>(e>>>0)&1)&173)<<16;l=l+1|0;}while((l|0)<32);l=c[2406954]|0;e=0;do{c[l+(e<<2)>>2]=c[k+((e<<3&24|e>>>2&7)<<2)>>2];b=e+32|0;g=j+b|0;f=d[g]|0;c[l+(b<<2)>>2]=c[k+((f>>>3&1|f<<3&8|f>>>1<<2&4|f>>>2<<1&2)<<2)>>2];f=d[g]|0;c[l+(e+64<<2)>>2]=c[k+((f>>>5<<2&4|f>>>7|f>>>4<<3&8|f>>>6<<1&2)<<2)>>2];e=e+1|0;}while((e|0)<32);a[9547648]=1;return}function dDk(e){e=e|0;var f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0;f=i;i=i+4080|0;g=f|0;j=f+112|0;k=f+120|0;l=f+232|0;m=f+240|0;n=f+352|0;o=f+360|0;p=f+472|0;q=f+480|0;r=f+592|0;s=f+600|0;t=f+712|0;u=f+720|0;v=f+832|0;w=f+840|0;x=f+952|0;y=f+960|0;z=f+1072|0;A=f+1080|0;B=f+1192|0;C=f+1200|0;D=f+1312|0;E=f+1320|0;F=f+1432|0;G=f+1440|0;H=f+1552|0;I=f+1560|0;J=f+1672|0;K=f+1680|0;L=f+1792|0;M=f+1800|0;N=f+1912|0;O=f+1920|0;P=f+2032|0;Q=f+2040|0;R=f+2152|0;S=f+2160|0;T=f+2272|0;U=f+2280|0;V=f+2392|0;W=f+2400|0;X=f+2512|0;Y=f+2520|0;Z=f+2632|0;_=f+2640|0;$=f+2752|0;aa=f+2760|0;ab=f+2872|0;ac=f+2880|0;ad=f+2992|0;ae=f+3e3|0;af=f+3112|0;ah=f+3120|0;ai=f+3232|0;aj=f+3240|0;ak=f+3352|0;al=f+3360|0;am=f+3472|0;an=f+3480|0;ao=f+3592|0;ap=f+3600|0;aq=f+3712|0;ar=f+3720|0;as=f+3832|0;at=f+3840|0;au=f+3952|0;av=f+3960|0;aw=f+4072|0;c[2415012]=0;c[3529250]=0;c[3529206]=65536;c[3529354]=65536;c[3530876]=131072;c[3530640]=163840;c[3530450]=196608;c[3530344]=229376;c[3531020]=262144;c[2406954]=262208;c[3530068]=262728;c[2414718]=263248;c[3529338]=263248;c[3529296]=267344;c[2387880]=268368;c[2386236]=269392;c[2386488]=270416;c[3530278]=271440;c[3528732]=271696;c[3528306]=271697;c[2385614]=271699;c[3525096]=271700;c[2385230]=271701;c[2411744]=271702;ax=0;while(1){if((ax|0)>=1024){break}ay=9638528+(ax<<2)|0;if((c[ay>>2]|0)==0){az=6505;break}else{ax=ax+1|0}}do{if((az|0)==6505){ax=gGq(271702)|0;c[ay>>2]=ax;if((ax|0)==0){break}c[2415012]=ax;gGz(ax|0,0,271702);c[3529250]=ax;aA=ax+65536|0;c[3529206]=aA;c[3529354]=aA;c[3530876]=ax+131072;c[3530640]=ax+163840;c[3530450]=ax+196608;c[3530344]=ax+229376;c[3531020]=ax+262144;c[2406954]=ax+262208;c[3530068]=ax+262728;aA=ax+263248|0;c[2414718]=aA;c[3529338]=aA;c[3529296]=ax+267344;c[2387880]=ax+268368;c[2386236]=ax+269392;c[2386488]=ax+270416;c[3530278]=ax+271440;c[3528732]=ax+271696;c[3528306]=ax+271697;c[2385614]=ax+271699;c[3525096]=ax+271700;c[2385230]=ax+271701;aA=ax+271702|0;c[2411744]=aA;c[2414286]=aA;do{if((e|0)==0){if((c[3542200]|0)==0){aB=1;i=f;return aB|0}aA=av+108|0;c[aA>>2]=0;aC=av+100|0;c[aC>>2]=0;aD=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aD&16383](av,0)|0;do{if((c[aA>>2]|0)!=0){aD=c[aC>>2]|0;c[aw>>2]=9534384;aE=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aE&16383](aw,0,0)|0;if((aD|0)<1){aB=1;i=f;return aB|0}if((gzL(ax,0,0)|0)==0){break}else{aB=1}i=f;return aB|0}}while(0);aC=(c[3529250]|0)+4096|0;if((c[3542200]|0)==0){aB=1;i=f;return aB|0}aA=at+108|0;c[aA>>2]=0;aD=at+100|0;c[aD>>2]=0;aE=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aE&16383](at,1)|0;do{if((c[aA>>2]|0)!=0){aE=c[aD>>2]|0;c[au>>2]=9534384;aF=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aF&16383](au,1,0)|0;if((aE|0)<1){aB=1;i=f;return aB|0}if((gzL(aC,0,1)|0)==0){break}else{aB=1}i=f;return aB|0}}while(0);aC=(c[3529250]|0)+8192|0;if((c[3542200]|0)==0){aB=1;i=f;return aB|0}aD=ar+108|0;c[aD>>2]=0;aA=ar+100|0;c[aA>>2]=0;aE=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aE&16383](ar,2)|0;do{if((c[aD>>2]|0)!=0){aE=c[aA>>2]|0;c[as>>2]=9534384;aF=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aF&16383](as,2,0)|0;if((aE|0)<1){aB=1;i=f;return aB|0}if((gzL(aC,0,2)|0)==0){break}else{aB=1}i=f;return aB|0}}while(0);aC=(c[3529250]|0)+12288|0;if((c[3542200]|0)==0){aB=1;i=f;return aB|0}aA=ap+108|0;c[aA>>2]=0;aD=ap+100|0;c[aD>>2]=0;aE=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aE&16383](ap,3)|0;do{if((c[aA>>2]|0)!=0){aE=c[aD>>2]|0;c[aq>>2]=9534384;aF=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aF&16383](aq,3,0)|0;if((aE|0)<1){aB=1;i=f;return aB|0}if((gzL(aC,0,3)|0)==0){break}else{aB=1}i=f;return aB|0}}while(0);aC=(c[3529250]|0)+16384|0;if((c[3542200]|0)==0){aB=1;i=f;return aB|0}aD=an+108|0;c[aD>>2]=0;aA=an+100|0;c[aA>>2]=0;aE=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aE&16383](an,4)|0;do{if((c[aD>>2]|0)!=0){aE=c[aA>>2]|0;c[ao>>2]=9534384;aF=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aF&16383](ao,4,0)|0;if((aE|0)<1){aB=1;i=f;return aB|0}if((gzL(aC,0,4)|0)==0){break}else{aB=1}i=f;return aB|0}}while(0);aC=(c[3529250]|0)+20480|0;if((c[3542200]|0)==0){aB=1;i=f;return aB|0}aA=al+108|0;c[aA>>2]=0;aD=al+100|0;c[aD>>2]=0;aE=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aE&16383](al,5)|0;do{if((c[aA>>2]|0)!=0){aE=c[aD>>2]|0;c[am>>2]=9534384;aF=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aF&16383](am,5,0)|0;if((aE|0)<1){aB=1;i=f;return aB|0}if((gzL(aC,0,5)|0)==0){break}else{aB=1}i=f;return aB|0}}while(0);aC=c[3529354]|0;aD=c[3529250]|0;gGC(aC|0,aD|0,65536)|0;aD=c[3530876]|0;if((c[3542200]|0)==0){aB=1;i=f;return aB|0}aC=aj+108|0;c[aC>>2]=0;aA=aj+100|0;c[aA>>2]=0;aE=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aE&16383](aj,6)|0;do{if((c[aC>>2]|0)!=0){aE=c[aA>>2]|0;c[ak>>2]=9534384;aF=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aF&16383](ak,6,0)|0;if((aE|0)<1){aB=1;i=f;return aB|0}if((gzL(aD,0,6)|0)==0){break}else{aB=1}i=f;return aB|0}}while(0);aD=(c[3530876]|0)+4096|0;if((c[3542200]|0)==0){aB=1;i=f;return aB|0}aA=ah+108|0;c[aA>>2]=0;aC=ah+100|0;c[aC>>2]=0;aE=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aE&16383](ah,7)|0;do{if((c[aA>>2]|0)!=0){aE=c[aC>>2]|0;c[ai>>2]=9534384;aF=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aF&16383](ai,7,0)|0;if((aE|0)<1){aB=1;i=f;return aB|0}if((gzL(aD,0,7)|0)==0){break}else{aB=1}i=f;return aB|0}}while(0);aD=c[3530640]|0;if((c[3542200]|0)==0){aB=1;i=f;return aB|0}aC=ae+108|0;c[aC>>2]=0;aA=ae+100|0;c[aA>>2]=0;aE=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aE&16383](ae,8)|0;do{if((c[aC>>2]|0)!=0){aE=c[aA>>2]|0;c[af>>2]=9534384;aF=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aF&16383](af,8,0)|0;if((aE|0)<1){aB=1;i=f;return aB|0}if((gzL(aD,0,8)|0)==0){break}else{aB=1}i=f;return aB|0}}while(0);aD=(c[3530640]|0)+4096|0;if((c[3542200]|0)==0){aB=1;i=f;return aB|0}aA=ac+108|0;c[aA>>2]=0;aC=ac+100|0;c[aC>>2]=0;aE=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aE&16383](ac,9)|0;do{if((c[aA>>2]|0)!=0){aE=c[aC>>2]|0;c[ad>>2]=9534384;aF=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aF&16383](ad,9,0)|0;if((aE|0)<1){aB=1;i=f;return aB|0}if((gzL(aD,0,9)|0)==0){break}else{aB=1}i=f;return aB|0}}while(0);aD=c[3531020]|0;if((c[3542200]|0)==0){aB=1;i=f;return aB|0}aC=aa+108|0;c[aC>>2]=0;aA=aa+100|0;c[aA>>2]=0;aE=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aE&16383](aa,10)|0;do{if((c[aC>>2]|0)!=0){aE=c[aA>>2]|0;c[ab>>2]=9534384;aF=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aF&16383](ab,10,0)|0;if((aE|0)<1){aB=1;i=f;return aB|0}if((gzL(aD,0,10)|0)==0){break}else{aB=1}i=f;return aB|0}}while(0);aD=(c[3531020]|0)+32|0;if((c[3542200]|0)==0){aB=1;i=f;return aB|0}aA=_+108|0;c[aA>>2]=0;aC=_+100|0;c[aC>>2]=0;aE=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aE&16383](_,11)|0;do{if((c[aA>>2]|0)!=0){aE=c[aC>>2]|0;c[$>>2]=9534384;aF=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aF&16383]($,11,0)|0;if((aE|0)<1){aB=1;i=f;return aB|0}if((gzL(aD,0,11)|0)==0){break}else{aB=1}i=f;return aB|0}}while(0);a[668648]=1}else if((e|0)==1){if((c[3542200]|0)==0){aB=1;i=f;return aB|0}aD=Y+108|0;c[aD>>2]=0;aC=Y+100|0;c[aC>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](Y,0)|0;do{if((c[aD>>2]|0)!=0){aA=c[aC>>2]|0;c[Z>>2]=9534384;aE=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aE&16383](Z,0,0)|0;if((aA|0)<1){aB=1;i=f;return aB|0}if((gzL(ax,0,0)|0)==0){break}else{aB=1}i=f;return aB|0}}while(0);aC=(c[3529250]|0)+4096|0;if((c[3542200]|0)==0){aB=1;i=f;return aB|0}aD=W+108|0;c[aD>>2]=0;aA=W+100|0;c[aA>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](W,1)|0;do{if((c[aD>>2]|0)!=0){aE=c[aA>>2]|0;c[X>>2]=9534384;aF=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aF&16383](X,1,0)|0;if((aE|0)<1){aB=1;i=f;return aB|0}if((gzL(aC,0,1)|0)==0){break}else{aB=1}i=f;return aB|0}}while(0);aC=(c[3529250]|0)+8192|0;if((c[3542200]|0)==0){aB=1;i=f;return aB|0}aA=U+108|0;c[aA>>2]=0;aD=U+100|0;c[aD>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](U,2)|0;do{if((c[aA>>2]|0)!=0){aE=c[aD>>2]|0;c[V>>2]=9534384;aF=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aF&16383](V,2,0)|0;if((aE|0)<1){aB=1;i=f;return aB|0}if((gzL(aC,0,2)|0)==0){break}else{aB=1}i=f;return aB|0}}while(0);aC=(c[3529250]|0)+12288|0;if((c[3542200]|0)==0){aB=1;i=f;return aB|0}aD=S+108|0;c[aD>>2]=0;aA=S+100|0;c[aA>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](S,3)|0;do{if((c[aD>>2]|0)!=0){aE=c[aA>>2]|0;c[T>>2]=9534384;aF=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aF&16383](T,3,0)|0;if((aE|0)<1){aB=1;i=f;return aB|0}if((gzL(aC,0,3)|0)==0){break}else{aB=1}i=f;return aB|0}}while(0);aC=(c[3529250]|0)+16384|0;if((c[3542200]|0)==0){aB=1;i=f;return aB|0}aA=Q+108|0;c[aA>>2]=0;aD=Q+100|0;c[aD>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](Q,4)|0;do{if((c[aA>>2]|0)!=0){aE=c[aD>>2]|0;c[R>>2]=9534384;aF=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aF&16383](R,4,0)|0;if((aE|0)<1){aB=1;i=f;return aB|0}if((gzL(aC,0,4)|0)==0){break}else{aB=1}i=f;return aB|0}}while(0);aC=(c[3529250]|0)+20480|0;if((c[3542200]|0)==0){aB=1;i=f;return aB|0}aD=O+108|0;c[aD>>2]=0;aA=O+100|0;c[aA>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](O,5)|0;do{if((c[aD>>2]|0)!=0){aE=c[aA>>2]|0;c[P>>2]=9534384;aF=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aF&16383](P,5,0)|0;if((aE|0)<1){aB=1;i=f;return aB|0}if((gzL(aC,0,5)|0)==0){break}else{aB=1}i=f;return aB|0}}while(0);aC=c[3529354]|0;aA=c[3529250]|0;gGC(aC|0,aA|0,65536)|0;aA=c[3530876]|0;if((c[3542200]|0)==0){aB=1;i=f;return aB|0}aC=M+108|0;c[aC>>2]=0;aD=M+100|0;c[aD>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](M,6)|0;do{if((c[aC>>2]|0)!=0){aE=c[aD>>2]|0;c[N>>2]=9534384;aF=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aF&16383](N,6,0)|0;if((aE|0)<1){aB=1;i=f;return aB|0}if((gzL(aA,0,6)|0)==0){break}else{aB=1}i=f;return aB|0}}while(0);aA=(c[3530876]|0)+4096|0;if((c[3542200]|0)==0){aB=1;i=f;return aB|0}aD=K+108|0;c[aD>>2]=0;aC=K+100|0;c[aC>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](K,7)|0;do{if((c[aD>>2]|0)!=0){aE=c[aC>>2]|0;c[L>>2]=9534384;aF=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aF&16383](L,7,0)|0;if((aE|0)<1){aB=1;i=f;return aB|0}if((gzL(aA,0,7)|0)==0){break}else{aB=1}i=f;return aB|0}}while(0);aA=c[3530640]|0;if((c[3542200]|0)==0){aB=1;i=f;return aB|0}aC=I+108|0;c[aC>>2]=0;aD=I+100|0;c[aD>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](I,8)|0;do{if((c[aC>>2]|0)!=0){aE=c[aD>>2]|0;c[J>>2]=9534384;aF=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aF&16383](J,8,0)|0;if((aE|0)<1){aB=1;i=f;return aB|0}if((gzL(aA,0,8)|0)==0){break}else{aB=1}i=f;return aB|0}}while(0);aA=c[3531020]|0;if((c[3542200]|0)==0){aB=1;i=f;return aB|0}aD=G+108|0;c[aD>>2]=0;aC=G+100|0;c[aC>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](G,9)|0;do{if((c[aD>>2]|0)!=0){aE=c[aC>>2]|0;c[H>>2]=9534384;aF=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aF&16383](H,9,0)|0;if((aE|0)<1){aB=1;i=f;return aB|0}if((gzL(aA,0,9)|0)==0){break}else{aB=1}i=f;return aB|0}}while(0);aA=(c[3531020]|0)+32|0;if((c[3542200]|0)==0){aB=1;i=f;return aB|0}aC=E+108|0;c[aC>>2]=0;aD=E+100|0;c[aD>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](E,10)|0;if((c[aC>>2]|0)==0){break}aC=c[aD>>2]|0;c[F>>2]=9534384;gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](F,10,0)|0;if((aC|0)<1){aB=1;i=f;return aB|0}if((gzL(aA,0,10)|0)==0){break}else{aB=1}i=f;return aB|0}else if((e|0)==2){if((c[3542200]|0)==0){aB=1;i=f;return aB|0}aA=C+108|0;c[aA>>2]=0;aC=C+100|0;c[aC>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](C,0)|0;do{if((c[aA>>2]|0)!=0){aD=c[aC>>2]|0;c[D>>2]=9534384;aE=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aE&16383](D,0,0)|0;if((aD|0)<1){aB=1;i=f;return aB|0}if((gzL(ax,0,0)|0)==0){break}else{aB=1}i=f;return aB|0}}while(0);aC=(c[3529250]|0)+8192|0;if((c[3542200]|0)==0){aB=1;i=f;return aB|0}aA=A+108|0;c[aA>>2]=0;aD=A+100|0;c[aD>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](A,1)|0;do{if((c[aA>>2]|0)!=0){aE=c[aD>>2]|0;c[B>>2]=9534384;aF=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aF&16383](B,1,0)|0;if((aE|0)<1){aB=1;i=f;return aB|0}if((gzL(aC,0,1)|0)==0){break}else{aB=1}i=f;return aB|0}}while(0);aC=(c[3529250]|0)+16384|0;if((c[3542200]|0)==0){aB=1;i=f;return aB|0}aD=y+108|0;c[aD>>2]=0;aA=y+100|0;c[aA>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](y,2)|0;do{if((c[aD>>2]|0)!=0){aE=c[aA>>2]|0;c[z>>2]=9534384;aF=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aF&16383](z,2,0)|0;if((aE|0)<1){aB=1;i=f;return aB|0}if((gzL(aC,0,2)|0)==0){break}else{aB=1}i=f;return aB|0}}while(0);aC=c[3530876]|0;if((c[3542200]|0)==0){aB=1;i=f;return aB|0}aA=w+108|0;c[aA>>2]=0;aD=w+100|0;c[aD>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](w,3)|0;do{if((c[aA>>2]|0)!=0){aE=c[aD>>2]|0;c[x>>2]=9534384;aF=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aF&16383](x,3,0)|0;if((aE|0)<1){aB=1;i=f;return aB|0}if((gzL(aC,0,3)|0)==0){break}else{aB=1}i=f;return aB|0}}while(0);aC=(c[3530876]|0)+4096|0;if((c[3542200]|0)==0){aB=1;i=f;return aB|0}aD=u+108|0;c[aD>>2]=0;aA=u+100|0;c[aA>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](u,4)|0;do{if((c[aD>>2]|0)!=0){aE=c[aA>>2]|0;c[v>>2]=9534384;aF=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aF&16383](v,4,0)|0;if((aE|0)<1){aB=1;i=f;return aB|0}if((gzL(aC,0,4)|0)==0){break}else{aB=1}i=f;return aB|0}}while(0);aC=c[3530640]|0;if((c[3542200]|0)==0){aB=1;i=f;return aB|0}aA=s+108|0;c[aA>>2]=0;aD=s+100|0;c[aD>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](s,5)|0;do{if((c[aA>>2]|0)!=0){aE=c[aD>>2]|0;c[t>>2]=9534384;aF=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aF&16383](t,5,0)|0;if((aE|0)<1){aB=1;i=f;return aB|0}if((gzL(aC,0,5)|0)==0){break}else{aB=1}i=f;return aB|0}}while(0);aC=(c[3530640]|0)+4096|0;if((c[3542200]|0)==0){aB=1;i=f;return aB|0}aD=q+108|0;c[aD>>2]=0;aA=q+100|0;c[aA>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](q,6)|0;do{if((c[aD>>2]|0)!=0){aE=c[aA>>2]|0;c[r>>2]=9534384;aF=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aF&16383](r,6,0)|0;if((aE|0)<1){aB=1;i=f;return aB|0}if((gzL(aC,0,6)|0)==0){break}else{aB=1}i=f;return aB|0}}while(0);aC=c[3531020]|0;if((c[3542200]|0)==0){aB=1;i=f;return aB|0}aA=o+108|0;c[aA>>2]=0;aD=o+100|0;c[aD>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](o,9)|0;do{if((c[aA>>2]|0)!=0){aE=c[aD>>2]|0;c[p>>2]=9534384;aF=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aF&16383](p,9,0)|0;if((aE|0)<1){aB=1;i=f;return aB|0}if((gzL(aC,0,9)|0)==0){break}else{aB=1}i=f;return aB|0}}while(0);aC=(c[3531020]|0)+32|0;if((c[3542200]|0)==0){aB=1;i=f;return aB|0}aD=m+108|0;c[aD>>2]=0;aA=m+100|0;c[aA>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,10)|0;do{if((c[aD>>2]|0)!=0){aE=c[aA>>2]|0;c[n>>2]=9534384;aF=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aF&16383](n,10,0)|0;if((aE|0)<1){aB=1;i=f;return aB|0}if((gzL(aC,0,10)|0)==0){break}else{aB=1}i=f;return aB|0}}while(0);aC=c[3529338]|0;if((c[3542200]|0)==0){break}aA=k+108|0;c[aA>>2]=0;aD=k+100|0;c[aD>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,7)|0;if((c[aA>>2]|0)!=0){aA=c[aD>>2]|0;c[l>>2]=9534384;aD=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aD&16383](l,7,0)|0;if((aA|0)<1){break}if((gzL(aC,0,7)|0)!=0){break}}aA=aC+256|0;if((c[3542200]|0)==0){break}aD=g+108|0;c[aD>>2]=0;aE=g+100|0;c[aE>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,8)|0;if((c[aD>>2]|0)==0){aG=0}else{aD=c[aE>>2]|0;c[j>>2]=9534384;aE=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aE&16383](j,8,0)|0;if((aD|0)<1){break}if((gzL(aA,0,8)|0)==0){aG=0}else{break}}do{aA=aC+aG|0;a[aA]=a[aA]<<4|a[aC+(aG+256)|0];aG=aG+1|0;}while((aG|0)<256);aA=c[3529250]|0;aD=c[3529354]|0;aE=0;do{a[aD+aE|0]=a[aC+(d[aA+aE|0]|0)|0]|0;aE=aE+1|0;}while((aE|0)<65536)}}while(0);dDj(0,5,2,6,4,7);dDi();fwR(0);ax=c[2439330]|0;aE=(ax|0)==0;if(!aE){aA=ax;gGC(9706056,aA|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];aA=c[3528484]|0;c[2076596]=aA;aC=c[2417276]|0;c[3541536]=aC;c[1836236]=0;aD=c[3529250]|0;aF=0;aH=0;while(1){c[ax+76+(aH<<2)>>2]=aD+(aH<<8);aI=aF+1&65535;if((aI&65535)>95){break}else{aF=aI;aH=aI&65535}}aH=c[3529354]|0;aF=0;aI=0;while(1){aJ=aI<<8;c[ax+76+(aI+512<<2)>>2]=aH+aJ;c[ax+76+(aI+768<<2)>>2]=aD+aJ;aJ=aF+1&65535;if((aJ&65535)>95){break}else{aF=aJ;aI=aJ&65535}}aI=c[3529338]|0;c[ax+460>>2]=aI;c[ax+464>>2]=aI+256;c[ax+468>>2]=aI+512;c[ax+472>>2]=aI+768;c[ax+476>>2]=aI+1024;c[ax+480>>2]=aI+1280;c[ax+484>>2]=aI+1536;c[ax+488>>2]=aI+1792;c[ax+492>>2]=aI+2048;c[ax+496>>2]=aI+2304;c[ax+500>>2]=aI+2560;c[ax+504>>2]=aI+2816;c[ax+508>>2]=aI+3072;c[ax+512>>2]=aI+3328;c[ax+516>>2]=aI+3584;c[ax+520>>2]=aI+3840;aF=96;aD=96;while(1){c[ax+76+(aD+256<<2)>>2]=aI+((aD<<8)-24576);aH=aF+1&65535;if((aH&65535)>111){aK=96;aL=96;break}else{aF=aH;aD=aH&65535}}while(1){aD=aI+((aL<<8)-24576)|0;c[ax+76+(aL+512<<2)>>2]=aD;c[ax+76+(aL+768<<2)>>2]=aD;aD=aK+1&65535;if((aD&65535)>111){break}else{aK=aD;aL=aD&65535}}aI=c[2386488]|0;c[ax+524>>2]=aI;aD=aI+256|0;c[ax+528>>2]=aD;aF=aI+512|0;c[ax+532>>2]=aF;aH=aI+768|0;c[ax+536>>2]=aH;c[ax+1548>>2]=aI;c[ax+1552>>2]=aD;c[ax+1556>>2]=aF;c[ax+1560>>2]=aH;c[ax+2572>>2]=aI;c[ax+3596>>2]=aI;c[ax+2576>>2]=aD;c[ax+3600>>2]=aD;c[ax+2580>>2]=aF;c[ax+3604>>2]=aF;c[ax+2584>>2]=aH;c[ax+3608>>2]=aH;aH=c[2386236]|0;c[ax+908>>2]=aH;aF=aH+256|0;c[ax+912>>2]=aF;aD=aH+512|0;c[ax+916>>2]=aD;aI=aH+768|0;c[ax+920>>2]=aI;c[ax+1932>>2]=aH;c[ax+1936>>2]=aF;c[ax+1940>>2]=aD;c[ax+1944>>2]=aI;c[ax+2956>>2]=aH;c[ax+3980>>2]=aH;c[ax+2960>>2]=aF;c[ax+3984>>2]=aF;c[ax+2964>>2]=aD;c[ax+3988>>2]=aD;c[ax+2968>>2]=aI;c[ax+3992>>2]=aI;aI=c[2387880]|0;c[ax+924>>2]=aI;aD=aI+256|0;c[ax+928>>2]=aD;aF=aI+512|0;c[ax+932>>2]=aF;aH=aI+768|0;c[ax+936>>2]=aH;c[ax+1948>>2]=aI;c[ax+1952>>2]=aD;c[ax+1956>>2]=aF;c[ax+1960>>2]=aH;c[ax+2972>>2]=aI;c[ax+3996>>2]=aI;c[ax+2976>>2]=aD;c[ax+4e3>>2]=aD;c[ax+2980>>2]=aF;c[ax+4004>>2]=aF;c[ax+2984>>2]=aH;c[ax+4008>>2]=aH;c[ax+4184>>2]=336;c[ax+4180>>2]=2886;if(!aE){aH=ax;gGC(aH|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=aA;c[2417276]=aC;c[1836236]=-1;fwR(1);TS(0,4e6,16384,3,1,0);TS(1,4e6,16384,3,1,1);aH=c[2420348]|0;h[aH+192>>3]=1.0;c[aH+200>>2]=3;aH=c[2420346]|0;h[aH+192>>3]=1.0;c[aH+200>>2]=3;aH=c[642608+(c[2436]<<2)>>2]|0;aF=c[aH+128>>2]|0;if((c[aH+52>>2]&4|0)==0){c[2113068]=aF;aD=c[aH+132>>2]|0;c[2113070]=aD;c[2443814]=aF;c[2440436]=aD;aM=aF;aN=aD}else{c[2113070]=aF;aD=c[aH+132>>2]|0;c[2113068]=aD;c[2440436]=aF;c[2443814]=aD;aM=aD;aN=aF}aF=ag(aM<<1,aN)|0;aD=gGq(aF)|0;c[2112926]=aD;if((aD|0)!=0){gGz(aD|0,0,aF|0)}a[9624520]=0;aF=c[2414718]|0;gGz(aF|0,0,(c[2411744]|0)-aF|0);aF=c[2439330]|0;aD=(aF|0)==0;if(!aD){aH=aF;gGC(9706056,aH|0,76)|0}aH=c[2438118]|0;c[2433530]=aH;aI=c[3528484]|0;c[2076596]=aI;aJ=c[2417276]|0;c[3541536]=aJ;c[1836236]=0;gGz(9706056,0,76);if(!aD){aD=aF;gGC(aD|0,9706056,76)|0}c[2438118]=aH;c[3528484]=aI;c[2417276]=aJ;c[1836236]=-1;aJ=c[2439331]|0;aI=(aJ|0)==0;if(!aI){aH=aJ;gGC(9706056,aH|0,76)|0}aH=c[2438119]|0;c[2433530]=aH;aD=c[3528485]|0;c[2076596]=aD;aF=c[2417277]|0;c[3541536]=aF;c[1836236]=1;gGz(9706056,0,76);if(!aI){aI=aJ;gGC(aI|0,9706056,76)|0}c[2438119]=aH;c[3528485]=aD;c[2417277]=aF;c[1836236]=-1;c[2440192]=0;c[2443698]=0;a[672592]=0;aB=0;i=f;return aB|0}}while(0);c[2415012]=0;aB=1;i=f;return aB|0}function dDl(a,b){a=a|0;b=b|0;var d=0,e=0;d=((a&-4096)<<16>>16==-4096?a&-2048:a)&65535;if((d|0)==61440){c[2388524]=b&255;return}else if((d|0)==63488){c[2388520]=((c[3528730]|0)!=0?255:0)^b&255;return}else if((d|0)==38912){c[3528730]=b&1;return}else if((d|0)==38914){e=b&255}else if((d|0)==38913){d=b&255;TR(0,d);e=d}else{return}TR(1,e);return}function dDm(b){b=b|0;var d=0;switch(b&65535|0){case 40961:{d=a[9631729]<<1^~a[9631728]^a[9631730]<<2^a[9631731]<<3^a[9631732]<<4^a[9631733]<<5^a[9631734]<<6^a[9631735]<<7;return d|0};case 38915:{d=a[(c[2426610]|0)+(e[4853040]|0)|0]|0;return d|0};case 40963:{d=a[9635321]|0;return d|0};case 40962:{d=a[9635320]|0;return d|0};case 40960:{d=a[9633929]<<1^~a[9633928]^a[9633930]<<2^a[9633931]<<3^a[9633932]<<4^a[9633933]<<5^a[9633934]<<6^a[9633935]<<7;return d|0};default:{d=0;return d|0}}return 0}function dDn(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7028036+(b*112|0)>>2];c[a+104>>2]=c[7028040+(b*112|0)>>2];c[a+108>>2]=c[7028044+(b*112|0)>>2];d=0;return d|0}function dDo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=7027936+(b*112|0);e=0;return e|0}function dDp(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6931808+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dDq(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>47){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7441008+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dDr(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0.0,I=0.0,J=0.0,K=0.0,L=0.0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0;e=i;i=i+664|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=0;while(1){if((s|0)>=1024){break}t=9638528+(s<<2)|0;if((c[t>>2]|0)==0){u=6827;break}else{s=s+1|0}}do{if((u|0)==6827){s=gGq(165248)|0;c[t>>2]=s;if((s|0)==0){break}gGz(s|0,0,165248);c[2426764]=s;c[2426610]=s;c[2424854]=s+65536;c[2424830]=s+98304;c[2424812]=s+131072;c[2424782]=s+163840;c[2406952]=s+163968;v=p+108|0;w=p+100|0;x=n+108|0;y=n+100|0;z=0;A=s;while(1){s=A+(z<<13)|0;if((c[3542200]|0)==0){B=1;u=6935;break}c[v>>2]=0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,z)|0;if((c[v>>2]|0)!=0){C=c[w>>2]|0;c[q>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](q,z,0)|0;if((C|0)<1){B=1;u=6937;break}if((gzL(s,0,z)|0)!=0){B=1;u=6942;break}}s=(c[2424782]|0)+(z<<5)|0;C=z+10|0;if((c[3542200]|0)==0){B=1;u=6931;break}c[x>>2]=0;c[y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,C)|0;if((c[x>>2]|0)!=0){D=c[y>>2]|0;c[o>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](o,C,0)|0;if((D|0)<1){B=1;u=6936;break}if((gzL(s,0,C)|0)!=0){B=1;u=6941;break}}C=z+1|0;if((C|0)>=4){u=6830;break}z=C;A=c[2426610]|0}if((u|0)==6935){i=e;return B|0}else if((u|0)==6936){i=e;return B|0}else if((u|0)==6937){i=e;return B|0}else if((u|0)==6830){A=l+108|0;z=l+100|0;y=j+108|0;x=j+100|0;w=f+108|0;v=f+100|0;C=0;while(1){s=C<<12;D=(c[2424854]|0)+s|0;E=C+4|0;if((c[3542200]|0)==0){B=1;u=6928;break}c[A>>2]=0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,E)|0;if((c[A>>2]|0)!=0){F=c[z>>2]|0;c[m>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](m,E,0)|0;if((F|0)<1){B=1;u=6933;break}if((gzL(D,0,E)|0)!=0){B=1;u=6934;break}}E=(c[2424830]|0)+s|0;D=C+6|0;if((c[3542200]|0)==0){B=1;u=6930;break}c[y>>2]=0;c[x>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,D)|0;if((c[y>>2]|0)!=0){F=c[x>>2]|0;c[k>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](k,D,0)|0;if((F|0)<1){B=1;u=6927;break}if((gzL(E,0,D)|0)!=0){B=1;u=6938;break}}D=(c[2424812]|0)+s|0;s=C+8|0;if((c[3542200]|0)==0){B=1;u=6932;break}c[w>>2]=0;c[v>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,s)|0;if((c[w>>2]|0)!=0){E=c[v>>2]|0;c[g>>2]=9534384;F=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[F&16383](g,s,0)|0;if((E|0)<1){B=1;u=6939;break}if((gzL(D,0,s)|0)!=0){B=1;u=6940;break}}s=C+1|0;if((s|0)<2){C=s}else{u=6854;break}}if((u|0)==6934){i=e;return B|0}else if((u|0)==6938){i=e;return B|0}else if((u|0)==6928){i=e;return B|0}else if((u|0)==6927){i=e;return B|0}else if((u|0)==6854){C=15;while(1){H=(C&1|0)==0?0.0:.006666666828095913;if((C&2|0)==0){I=H}else{I=H+.008333333333333333}if((C&4|0)==0){J=I}else{J=I+.01}if((C&8|0)==0){K=J}else{K=J+.013333333333333334}if(K!=0.0){L=(200.0/(1.0/K+200.0)+-.20000000298023224)*255.0}else{L=0.0}c[r+(C<<2)>>2]=~~(L/.684615);if((C|0)>0){C=C-1|0}else{break}}C=c[2424782]|0;v=c[2406952]|0;w=0;while(1){x=d[C+(w&3|w>>>3&28|32)|0]|0;y=d[C+(w&31)|0]|0;c[v+(w<<2)>>2]=c[r+((x>>>2&3|y&12)<<2)>>2]<<8|c[r+((y<<2&12|x&3)<<2)>>2]<<16|c[r+((y>>>4<<2&12|x>>>4&3)<<2)>>2];x=w+1|0;if((x|0)<256){w=x}else{M=0;break}}while(1){c[v+(M+256<<2)>>2]=c[v+(((d[C+(M&31|64)|0]|0)>>>((M>>>3&4)>>>0)&15)<<2)>>2];w=M+1|0;if((w|0)<64){M=w}else{N=0;break}}while(1){if((N|0)>=1024){break}O=9638528+(N<<2)|0;if((c[O>>2]|0)==0){u=6869;break}else{N=N+1|0}}L9221:do{if((u|0)==6869){C=gGq(8192)|0;c[O>>2]=C;if((C|0)==0){break}gGz(C|0,0,8192);v=c[2424854]|0;gGC(C|0,v|0,8192)|0;w=0;do{x=w<<6;gGz(v+x|0,0,64);y=0;do{z=x+(c[1238464+(y<<2)>>2]|0)|0;A=(y<<3)+x|0;s=0;do{D=z+(c[610352+(s<<2)>>2]|0)|0;if(((d[C+((D|0)/8|0)|0]|0)&128>>>((D&7)>>>0)|0)!=0){D=v+(A+s)|0;a[D]=a[D]|2}s=s+1|0;}while((s|0)<8);y=y+1|0;}while((y|0)<8);y=x+32768|0;s=0;do{A=y+(c[1238464+(s<<2)>>2]|0)|0;z=(s<<3)+x|0;D=0;do{E=A+(c[610352+(D<<2)>>2]|0)|0;if(((d[C+((E|0)/8|0)|0]|0)&128>>>((E&7)>>>0)|0)!=0){E=v+(z+D)|0;a[E]=a[E]|1}D=D+1|0;}while((D|0)<8);s=s+1|0;}while((s|0)<8);w=w+1|0;}while((w|0)<512);w=c[2424830]|0;gGC(C|0,w|0,8192)|0;v=0;do{s=v<<6;gGz(w+s|0,0,64);x=0;do{y=s+(c[1238464+(x<<2)>>2]|0)|0;D=(x<<3)+s|0;z=0;do{A=y+(c[610352+(z<<2)>>2]|0)|0;if(((d[C+((A|0)/8|0)|0]|0)&128>>>((A&7)>>>0)|0)!=0){A=w+(D+z)|0;a[A]=a[A]|2}z=z+1|0;}while((z|0)<8);x=x+1|0;}while((x|0)<8);x=s+32768|0;z=0;do{D=x+(c[1238464+(z<<2)>>2]|0)|0;y=(z<<3)+s|0;A=0;do{E=D+(c[610352+(A<<2)>>2]|0)|0;if(((d[C+((E|0)/8|0)|0]|0)&128>>>((E&7)>>>0)|0)!=0){E=w+(y+A)|0;a[E]=a[E]|1}A=A+1|0;}while((A|0)<8);z=z+1|0;}while((z|0)<8);v=v+1|0;}while((v|0)<512);v=c[2424812]|0;gGC(C|0,v|0,8192)|0;w=0;while(1){z=w<<8;gGz(v+z|0,0,256);s=w<<9;x=s|4;A=0;while(1){y=x+(c[611840+(A<<2)>>2]|0)|0;D=(A<<4)+z|0;E=0;do{F=y+(c[602176+(E<<2)>>2]|0)|0;if(((d[C+((F|0)/8|0)|0]|0)&128>>>((F&7)>>>0)|0)!=0){F=v+(D+E)|0;a[F]=a[F]|2}E=E+1|0;}while((E|0)<16);E=A+1|0;if((E|0)<16){A=E}else{P=0;break}}do{A=s+(c[611840+(P<<2)>>2]|0)|0;x=(P<<4)+z|0;E=0;do{D=A+(c[602176+(E<<2)>>2]|0)|0;if(((d[C+((D|0)/8|0)|0]|0)&128>>>((D&7)>>>0)|0)!=0){D=v+(x+E)|0;a[D]=a[D]|1}E=E+1|0;}while((E|0)<16);P=P+1|0;}while((P|0)<16);z=w+1|0;if((z|0)<128){w=z}else{Q=0;break}}while(1){if((Q|0)>=1024){break L9221}R=9638528+(Q<<2)|0;if((c[R>>2]|0)==(C|0)){break}else{Q=Q+1|0}}gGr(C);c[R>>2]=0}}while(0);fwR(0);w=c[2439330]|0;if((w|0)!=0){v=w;gGC(9706056,v|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];v=c[3528484]|0;c[2076596]=v;z=c[2417276]|0;c[3541536]=z;c[1836236]=0;c[w+4180>>2]=2954;c[w+4184>>2]=46;s=c[2426610]|0;E=0;x=0;while(1){c[w+76+(x<<2)>>2]=s+(x<<8);A=E+1&65535;if((A&65535)>127){S=0;T=0;break}else{E=A;x=A&65535}}while(1){x=s+(T<<8)|0;c[w+76+(T+512<<2)>>2]=x;c[w+76+(T+768<<2)>>2]=x;x=S+1&65535;if((x&65535)>127){break}else{S=x;T=x&65535}}x=s+32768|0;c[w+588>>2]=x;E=s+33024|0;c[w+592>>2]=E;A=s+33280|0;c[w+596>>2]=A;D=s+33536|0;c[w+600>>2]=D;y=s+33792|0;c[w+604>>2]=y;F=s+34048|0;c[w+608>>2]=F;G=s+34304|0;c[w+612>>2]=G;U=s+34560|0;c[w+616>>2]=U;V=s+34816|0;c[w+620>>2]=V;W=s+35072|0;c[w+624>>2]=W;X=s+35328|0;c[w+628>>2]=X;Y=s+35584|0;c[w+632>>2]=Y;Z=s+35840|0;c[w+636>>2]=Z;_=s+36096|0;c[w+640>>2]=_;$=s+36352|0;c[w+644>>2]=$;aa=s+36608|0;c[w+648>>2]=aa;c[w+1612>>2]=x;c[w+1616>>2]=E;c[w+1620>>2]=A;c[w+1624>>2]=D;c[w+1628>>2]=y;c[w+1632>>2]=F;c[w+1636>>2]=G;c[w+1640>>2]=U;c[w+1644>>2]=V;c[w+1648>>2]=W;c[w+1652>>2]=X;c[w+1656>>2]=Y;c[w+1660>>2]=Z;c[w+1664>>2]=_;c[w+1668>>2]=$;c[w+1672>>2]=aa;c[w+1676>>2]=s+36864;aa=s+57344|0;c[w+972>>2]=aa;$=s+57600|0;c[w+976>>2]=$;_=s+57856|0;c[w+980>>2]=_;Z=s+58112|0;c[w+984>>2]=Z;Y=s+58368|0;c[w+988>>2]=Y;X=s+58624|0;c[w+992>>2]=X;W=s+58880|0;c[w+996>>2]=W;V=s+59136|0;c[w+1e3>>2]=V;U=s+59392|0;c[w+1004>>2]=U;G=s+59648|0;c[w+1008>>2]=G;F=s+59904|0;c[w+1012>>2]=F;y=s+60160|0;c[w+1016>>2]=y;D=s+60416|0;c[w+1020>>2]=D;A=s+60672|0;c[w+1024>>2]=A;E=s+60928|0;c[w+1028>>2]=E;x=s+61184|0;c[w+1032>>2]=x;c[w+1996>>2]=aa;c[w+2e3>>2]=$;c[w+2004>>2]=_;c[w+2008>>2]=Z;c[w+2012>>2]=Y;c[w+2016>>2]=X;c[w+2020>>2]=W;c[w+2024>>2]=V;c[w+2028>>2]=U;c[w+2032>>2]=G;c[w+2036>>2]=F;c[w+2040>>2]=y;c[w+2044>>2]=D;c[w+2048>>2]=A;c[w+2052>>2]=E;c[w+2056>>2]=x;x=224;E=224;while(1){A=s+(E<<8)|0;c[w+76+(E+512<<2)>>2]=A;c[w+76+(E+768<<2)>>2]=A;A=x+1&65535;if((A&65535)>239){break}else{x=A;E=A&65535}}E=w;gGC(E|0,9706056,76)|0;c[2438118]=c[2433530];c[3528484]=v;c[2417276]=z;c[1836236]=-1;c[2424]=6116;TS(0,4e6,16384,3,1,0);TS(1,4e6,16384,3,1,1);E=c[2420348]|0;h[E+192>>3]=.5;c[E+200>>2]=3;E=c[2420346]|0;h[E+192>>3]=.5;c[E+200>>2]=3;a[9624512]=0;gGz((c[2426610]|0)+32768|0,0,32768);c[3528730]=0;c[2388520]=0;c[2388524]=0;E=c[2439330]|0;x=(E|0)==0;if(!x){s=E;gGC(9706056,s|0,76)|0}s=c[2438118]|0;c[2433530]=s;A=c[3528484]|0;c[2076596]=A;D=c[2417276]|0;c[3541536]=D;c[1836236]=0;gGz(9706056,0,76);if(!x){x=E;gGC(x|0,9706056,76)|0}c[2438118]=s;c[3528484]=A;c[2417276]=D;c[1836236]=-1;B=0;i=e;return B|0}else if((u|0)==6932){i=e;return B|0}else if((u|0)==6933){i=e;return B|0}else if((u|0)==6930){i=e;return B|0}else if((u|0)==6939){i=e;return B|0}else if((u|0)==6940){i=e;return B|0}}else if((u|0)==6931){i=e;return B|0}else if((u|0)==6941){i=e;return B|0}else if((u|0)==6942){i=e;return B|0}}}while(0);c[2426764]=0;B=1;i=e;return B|0}function dDs(){var a=0,b=0,d=0,e=0;fwZ();TT();a=c[2426764]|0;b=0;while(1){if((b|0)>=1024){break}d=9638528+(b<<2)|0;if((c[d>>2]|0)==(a|0)){e=6947;break}else{b=b+1|0}}if((e|0)==6947){gGr(a);c[d>>2]=0}c[2424782]=0;c[2424812]=0;c[2424830]=0;c[2424854]=0;c[2426610]=0;c[2426764]=0;c[2406952]=0;c[2388520]=0;c[2388524]=0;c[3528730]=0;return 0}function dDt(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;if((a[9624512]|0)==0){d=c[2439330]|0}else{a[9624512]=0;gGz((c[2426610]|0)+32768|0,0,32768);c[3528730]=0;c[2388520]=0;c[2388524]=0;e=c[2439330]|0;f=(e|0)==0;if(!f){g=e;gGC(9706056,g|0,76)|0}g=c[2438118]|0;c[2433530]=g;h=c[3528484]|0;c[2076596]=h;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);if(!f){f=e;gGC(f|0,9706056,76)|0}c[2438118]=g;c[3528484]=h;c[2417276]=i;c[1836236]=-1;d=e}if((d|0)!=0){e=d;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;e=c[2438118]|0;c[2433530]=e;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;if((a[d+4188|0]|0)==0){d=gfc(66666)|0;j=(c[2433530]|0)+d|0}else{j=e+66666|0}c[2433530]=j;a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0;j=c[1836236]|0;e=c[9757320+(j<<2)>>2]|0;if((e|0)!=0){d=e;gGC(d|0,9706056,76)|0}c[9752472+(j<<2)>>2]=c[2433530];c[14113936+(j<<2)>>2]=c[2076596];c[9669104+(j<<2)>>2]=c[3541536];c[1836236]=-1;if((c[2112968]|0)!=0){dDu()|0}j=c[2112964]|0;if((j|0)==0){return 0}d=a[9688]|0?534:0;TQ(0,j,d);TQ(1,j,d);return 0}function dDu(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;e=c[2112968]|0;f=c[2113308]|0;gGz(e|0,0,f*45840|0|0);g=c[2426610]|0;dDI(g+32768|0,c[2424830]|0,c[2388524]|0,c[2388520]|0);dDI(g+34816|0,c[2424854]|0,0,0);h=c[2424812]|0;i=c[2406952]|0;j=(f|0)>3;k=(f|0)==2;l=252;do{m=a[g+(l+36865)|0]|0;if(m<<24>>24!=0){n=d[g+(l+36867)|0]|0;o=d[g+(l+36866)|0]|0;p=o<<2&60|256;q=o&16;r=h+((d[g+(l+36864)|0]|0)<<8&32512)|0;s=n-8|0;t=223-(m&255)|0;if((o&32|0)==0){o=t+16|0;m=(q|0)==0;u=n+7|0;v=n+8|0;w=-7-n|0;x=8-n|0;y=((w|0)>(x|0)?w:x)+n|0;x=n-7|0;w=((x|0)>(v|0)?x:v)-n|0;x=r;z=t;while(1){A=(z|0)>191;B=z*240|0;if(m){C=x;D=s;while(1){do{if(!((D|z|0)<0|A|(D|0)>239)){E=a[C]|0;if(E<<24>>24==0){break}F=c[i+((E&255|p)<<2)>>2]|0;E=ag(f,D+B|0)|0;G=e+E|0;H=F>>16<<8&63488|F>>8<<3&2016;I=H|F>>>3&31;if(j){c[G>>2]=I;break}if(k){b[G>>1]=I&65535;break}else{a[G]=I&255;a[e+(E+1)|0]=H>>>8&255;a[e+(E+2)|0]=0;break}}}while(0);E=D+1|0;if((E|0)<(v|0)){C=C+1|0;D=E}else{J=w;break}}}else{D=x;C=u;while(1){do{if(!((C|z|0)<0|A|(C|0)>239)){E=a[D]|0;if(E<<24>>24==0){break}H=c[i+((E&255|p)<<2)>>2]|0;E=ag(f,C+B|0)|0;I=e+E|0;G=H>>16<<8&63488|H>>8<<3&2016;F=G|H>>>3&31;if(j){c[I>>2]=F;break}if(k){b[I>>1]=F&65535;break}else{a[I]=F&255;a[e+(E+1)|0]=G>>>8&255;a[e+(E+2)|0]=0;break}}}while(0);E=C-1|0;if((E|0)<(s|0)){J=y;break}else{D=D+1|0;C=E}}}C=z+1|0;if((C|0)<(o|0)){x=x+(J+8)|0;z=C}else{break}}}else{z=(q|0)==0;x=n+7|0;o=n+8|0;y=-7-n|0;u=8-n|0;w=((y|0)>(u|0)?y:u)+n|0;u=n-7|0;y=((u|0)>(o|0)?u:o)-n|0;u=t+15|0;v=r;while(1){m=(u|0)>191;C=u*240|0;if(z){D=v;B=s;while(1){do{if(!((B|u|0)<0|m|(B|0)>239)){A=a[D]|0;if(A<<24>>24==0){break}E=c[i+((A&255|p)<<2)>>2]|0;A=ag(f,B+C|0)|0;G=e+A|0;F=E>>16<<8&63488|E>>8<<3&2016;I=F|E>>>3&31;if(j){c[G>>2]=I;break}if(k){b[G>>1]=I&65535;break}else{a[G]=I&255;a[e+(A+1)|0]=F>>>8&255;a[e+(A+2)|0]=0;break}}}while(0);A=B+1|0;if((A|0)<(o|0)){D=D+1|0;B=A}else{K=y;break}}}else{B=x;D=v;while(1){do{if(!((B|u|0)<0|m|(B|0)>239)){A=a[D]|0;if(A<<24>>24==0){break}F=c[i+((A&255|p)<<2)>>2]|0;A=ag(f,B+C|0)|0;I=e+A|0;G=F>>16<<8&63488|F>>8<<3&2016;E=G|F>>>3&31;if(j){c[I>>2]=E;break}if(k){b[I>>1]=E&65535;break}else{a[I]=E&255;a[e+(A+1)|0]=G>>>8&255;a[e+(A+2)|0]=0;break}}}while(0);A=B-1|0;if((A|0)<(s|0)){K=w;break}else{B=A;D=D+1|0}}}D=u-1|0;if((D|0)<(t|0)){break}else{u=D;v=v+(K+8)|0}}}}l=l-4|0;}while((l|0)>-1);return 0}function dDv(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=i;i=i+64|0;e=d|0;f=d+16|0;g=d+32|0;h=d+48|0;if((b|0)!=0){c[b>>2]=169249}if((a&96|0)==0){i=d;return 0}gGz(h|0,0,12);c[h>>2]=(c[2426610]|0)+32768;c[h+4>>2]=32768;c[h+12>>2]=162152;gj[c[2076592]&4095](h)|0;fw$(a);gGz(g|0,0,12);c[g>>2]=14114920;c[g+4>>2]=4;c[g+12>>2]=142288;gj[c[2076592]&4095](g)|0;gGz(f|0,0,12);c[f>>2]=9554096;c[f+4>>2]=4;c[f+12>>2]=149352;gj[c[2076592]&4095](f)|0;gGz(e|0,0,12);c[e>>2]=9554080;c[e+4>>2]=4;c[e+12>>2]=416408;gj[c[2076592]&4095](e)|0;i=d;return 0}function dDw(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6522428+(b*112|0)>>2];c[a+104>>2]=c[6522432+(b*112|0)>>2];c[a+108>>2]=c[6522436+(b*112|0)>>2];d=0;return d|0}function dDx(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=6522328+(b*112|0);e=0;return e|0}function dDy(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4538212+(b*112|0)>>2];c[a+104>>2]=c[4538216+(b*112|0)>>2];c[a+108>>2]=c[4538220+(b*112|0)>>2];d=0;return d|0}function dDz(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=4538112+(b*112|0);e=0;return e|0}function dDA(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7024900+(b*112|0)>>2];c[a+104>>2]=c[7024904+(b*112|0)>>2];c[a+108>>2]=c[7024908+(b*112|0)>>2];d=0;return d|0}function dDB(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=7024800+(b*112|0);e=0;return e|0}function dDC(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7026468+(b*112|0)>>2];c[a+104>>2]=c[7026472+(b*112|0)>>2];c[a+108>>2]=c[7026476+(b*112|0)>>2];d=0;return d|0}function dDD(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=7026368+(b*112|0);e=0;return e|0}function dDE(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6520860+(b*112|0)>>2];c[a+104>>2]=c[6520864+(b*112|0)>>2];c[a+108>>2]=c[6520868+(b*112|0)>>2];d=0;return d|0}function dDF(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=6520760+(b*112|0);e=0;return e|0}function dDG(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2066076+(b*112|0)>>2];c[a+104>>2]=c[2066080+(b*112|0)>>2];c[a+108>>2]=c[2066084+(b*112|0)>>2];d=0;return d|0}function dDH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=2065976+(b*112|0);e=0;return e|0}function dDI(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;i=c[2406952]|0;j=c[2112968]|0;k=c[2113308]|0;l=(k|0)>3;m=(k|0)==2;n=0;o=-g&255;while(1){p=o&255;q=p-7|0;r=d[e+n|0]|0;s=r<<2&252;t=(n<<3)-g&255;u=(n>>>2&248)-h&255;v=t-8|0;w=u-24|0;x=(r&64|0)==0;y=8-p+((q|0)>(p|0)?q:p)|0;p=f+((r<<1&256|(d[e+(n+1024)|0]|0))<<6)|0;r=u-32|0;while(1){u=r*240|0;q=((192-r|0)*240|0)+240|0;L9510:do{if((r|0)<=191){if(x){z=p;A=v}else{B=p;C=v;while(1){do{if(!((C|r|0)<0|(C|0)>239)){D=c[i+((d[B]|0|s)<<2)>>2]|0;E=ag(k,(c[3528730]|0)==0?C+u|0:q-C|0)|0;F=j+E|0;G=D>>16<<8&63488|D>>8<<3&2016;H=G|D>>>3&31;if(l){c[F>>2]=H;break}if(m){b[F>>1]=H&65535;break}else{a[F]=H&255;a[j+(E+1)|0]=G>>>8&255;a[j+(E+2)|0]=0;break}}}while(0);E=C+1|0;if((E|0)<(t|0)){B=B+1|0;C=E}else{break L9510}}}while(1){do{if(!((A|r|0)<0|(A|0)>239)){C=a[z]|0;B=c[i+((C&255|s)<<2)>>2]|0;if(C<<24>>24==0){break}C=ag(k,(c[3528730]|0)==0?A+u|0:q-A|0)|0;E=j+C|0;G=B>>16<<8&63488|B>>8<<3&2016;H=G|B>>>3&31;if(l){c[E>>2]=H;break}if(m){b[E>>1]=H&65535;break}else{a[E]=H&255;a[j+(C+1)|0]=G>>>8&255;a[j+(C+2)|0]=0;break}}}while(0);C=A+1|0;if((C|0)<(t|0)){z=z+1|0;A=C}else{break}}}}while(0);q=r+1|0;if((q|0)<(w|0)){p=p+y|0;r=q}else{break}}r=n+1|0;if((r|0)<1024){n=r;o=o+8&255}else{break}}return}function dDJ(b,d){b=b|0;d=d|0;var e=0,f=0;e=b&65535;f=e&61440;if(!((f|0)==53248|(f|0)==28672)){return}f=e<<1&2046;e=c[2386234]|0;a[e+f|0]=d;a[e+(f|1)|0]=(b&65535)>>>10&3;return}function dDK(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=b&255;if((f|0)==32|(f|0)==35){a[c[3528304]|0]=e;return}else if((f|0)==48|(f|0)==51){f=c[2440206]|0;b=d[f]|0;g=c[2385302]|0;do{if((b&g|0)==(g|0)){if((g&(e&255)|0)!=0){h=f;break}i=a[c[3528304]|0]|0;j=i&255;if((b&1|0)!=0){c[3542228]=j&15;h=f;break}k=c[3542228]|0;if((k|0)>15){h=f;break}do{if((k|0)<14){if((k|0)!=13){if((a[14168916+k|0]|0)==i<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(0,k,j);h=c[2440206]|0}else{h=f}}while(0);a[h]=e;return}else{return}}function dDL(b){b=b|0;var c=0,d=0;c=b&255;if((c|0)==2){d=a[9549848]|0}else if((c|0)==0){d=a[9635312]|0}else if((c|0)==1){d=a[9550032]|0}else{d=0}return d|0}function dDM(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>5){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4722252+(b*112|0)>>2];c[a+104>>2]=c[4722256+(b*112|0)>>2];c[a+108>>2]=c[4722260+(b*112|0)>>2];d=0;return d|0}function dDN(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<6&(d|0)==0)){e=1;return e|0}c[a>>2]=4722152+(b*112|0);e=0;return e|0}function dDO(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1939424+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dDP(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>23){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5426424+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dDQ(){return dD_(0,4)|0}function dDR(){var a=0,b=0,d=0,e=0;c[2113070]=0;c[2113068]=0;a=c[2112926]|0;if((a|0)!=0){gGr(a);c[2112926]=0}fwZ();c[2113008]=0;c[2076598]=0;c[2383582]=0;a=c[2415010]|0;b=0;while(1){if((b|0)>=1024){d=7176;break}e=9638528+(b<<2)|0;if((c[e>>2]|0)==(a|0)){break}else{b=b+1|0}}if((d|0)==7176){c[2415010]=0;return 0}gGr(a);c[e>>2]=0;c[2415010]=0;return 0}function dDS(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if((a[9624504]|0)!=0){d=c[2414716]|0;gGz(d|0,0,(c[2411742]|0)-d|0);d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;h=c[2417276]|0;c[3541536]=h;c[1836236]=0;gGz(9706056,0,76);if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=h;c[1836236]=-1;mB(0)}h=a[9635313]|0;a[9550032]=h;a[9549848]=-1;g=0;f=h;h=-1;do{f=((a[9633920+g|0]&1)<<g^f&255)&255;h=((a[9631720+g|0]&1)<<g^h&255)&255;g=g+1|0;}while((g|0)<8);a[9550032]=f;a[9549848]=h;h=c[2439330]|0;if((h|0)!=0){f=h;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;f=c[2438118]|0;c[2433530]=f;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;if((a[h+4188|0]|0)==0){h=gfc(16666)|0;i=(c[2433530]|0)+h|0}else{i=f+16666|0}c[2433530]=i;a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0;if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){i=gfc(16666)|0;j=(c[2433530]|0)+i|0}else{j=(c[2433530]|0)+16666|0}c[2433530]=j;a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0;if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){j=gfc(16666)|0;k=(c[2433530]|0)+j|0}else{k=(c[2433530]|0)+16666|0}c[2433530]=k;a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0;if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){k=gfc(16666)|0;l=(c[2433530]|0)+k|0}else{l=(c[2433530]|0)+16666|0}c[2433530]=l;a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0;l=c[1836236]|0;k=c[9757320+(l<<2)>>2]|0;if((k|0)!=0){j=k;gGC(j|0,9706056,76)|0}c[9752472+(l<<2)>>2]=c[2433530];c[14113936+(l<<2)>>2]=c[2076596];c[9669104+(l<<2)>>2]=c[3541536];c[1836236]=-1;l=c[2112964]|0;if((l|0)!=0){mF(9756240,l,a[9688]|0?534:0,0)}if((c[2112968]|0)==0){return 0}dDT()|0;return 0}function dDT(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((a[9547640]|0)!=0){e=c[3530066]|0;f=0;do{c[e+(f<<2)>>2]=-(f>>>1&1)<<3&2016|-(f&1)<<8&63488|(-(f>>>2&1)|0)>>>3&31;f=f+1|0;}while((f|0)<8);a[9547640]=0}f=c[2113068]|0;e=c[2386234]|0;g=c[2112926]|0;h=c[2387826]|0;i=64;do{j=i<<1;k=h+((d[e+(j|1)|0]<<8|d[e+j|0])<<6)|0;j=g+((ag(f,(i>>5<<3)-16|0)|0)+(i<<3&248)<<1)|0;l=0;m=k;while(1){b[j>>1]=d[m]|0;b[j+2>>1]=d[m+1|0]|0;b[j+4>>1]=d[m+2|0]|0;b[j+6>>1]=d[m+3|0]|0;b[j+8>>1]=d[m+4|0]|0;b[j+10>>1]=d[m+5|0]|0;b[j+12>>1]=d[m+6|0]|0;b[j+14>>1]=d[m+7|0]|0;k=l+1|0;n=m+8|0;if((k|0)<8){j=j+(f<<1)|0;l=k;m=n}else{break}}i=i+1|0;}while((i|0)<960);c[2112928]=n;R8(c[3530066]|0);return 0}function dDU(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;d=i;i=i+48|0;e=d|0;f=d+32|0;g=(b|0)==0;if(!g){c[b>>2]=169730}do{if((a&96|0)!=0){gGz(f|0,0,12);h=c[2414716]|0;c[f>>2]=h;c[f+4>>2]=(c[2411742]|0)-h;c[f+12>>2]=162152;h=c[2076592]|0;gj[h&4095](f)|0;fw$(a);h=d+16|0;if((a&64|0)==0){break}do{if(!g){if((c[b>>2]|0)>=169110){break}c[b>>2]=169110}}while(0);if((c[2113008]|0)<=0){break}j=e|0;k=e+4|0;l=e+8|0;m=e+12|0;n=0;do{cC(h|0,531144,(o=i,i=i+8|0,c[o>>2]=n,o)|0)|0;i=o;c[j>>2]=14168888+(n*252|0);c[k>>2]=252;c[l>>2]=0;c[m>>2]=h;gj[c[2076592]&4095](e)|0;n=n+1|0;}while((n|0)<(c[2113008]|0))}}while(0);if((a&8|0)==0){i=d;return 0}c[f>>2]=c[2406300];c[f+4>>2]=4096;c[f+8>>2]=0;c[f+12>>2]=254016;gj[c[2076592]&4095](f)|0;i=d;return 0}function dDV(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>4){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4335700+(b*112|0)>>2];c[a+104>>2]=c[4335704+(b*112|0)>>2];c[a+108>>2]=c[4335708+(b*112|0)>>2];d=0;return d|0}function dDW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<5&(d|0)==0)){e=1;return e|0}c[a>>2]=4335600+(b*112|0);e=0;return e|0}function dDX(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1650952+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dDY(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>28){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4906576+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dDZ(){return dD_(1,2)|0}function dD_(e,f){e=e|0;f=f|0;var g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0.0,Z=0,_=0,$=0;g=i;i=i+600|0;j=g|0;k=g+112|0;l=g+120|0;m=g+232|0;n=g+240|0;o=g+352|0;p=g+360|0;q=g+472|0;r=g+480|0;s=g+592|0;c[2415010]=0;c[2385948]=0;c[2387826]=49152;c[3530066]=114720;c[2406300]=114752;c[2414716]=118848;c[2386102]=118848;c[2386234]=122944;c[3528304]=124992;c[2440206]=124993;c[2411742]=124994;c[2439060]=124994;t=a[9688]|0?1068:0;u=t|124994;c[2439061]=u;v=u+t|0;c[2439062]=v;u=v+t|0;c[2414284]=u;t=u;u=0;while(1){if((u|0)>=1024){break}w=9638528+(u<<2)|0;if((c[w>>2]|0)==0){x=7262;break}else{u=u+1|0}}do{if((x|0)==7262){u=gGq(t)|0;c[w>>2]=u;if((u|0)==0){break}gGz(u|0,0,t|0);c[2415010]=u;gGz(u|0,0,t|0);c[2385948]=u;c[2387826]=u+49152;c[2406950]=u+114688;c[3530066]=u+114720;c[2406300]=u+114752;v=u+118848|0;c[2414716]=v;c[2386102]=v;c[2386234]=u+122944;c[3528304]=u+124992;c[2440206]=u+124993;v=u+124994|0;c[2411742]=v;c[2439060]=v;v=a[9688]|0?1068:0;y=v|124994;c[2439061]=u+y;z=y+v|0;c[2439062]=u+z;c[2414284]=u+(z+v);do{if((c[3542200]|0)!=0){v=r+108|0;c[v>>2]=0;z=r+100|0;c[z>>2]=0;y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[y&16383](r,0)|0;if((c[v>>2]|0)==0){break}v=c[z>>2]|0;c[s>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](s,0,0)|0;if((v|0)<1){break}gzL(u,0,0)|0}}while(0);u=(c[2385948]|0)+32768|0;do{if((c[3542200]|0)!=0){v=p+108|0;c[v>>2]=0;z=p+100|0;c[z>>2]=0;y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[y&16383](p,1)|0;if((c[v>>2]|0)==0){break}v=c[z>>2]|0;c[q>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](q,1,0)|0;if((v|0)<1){break}gzL(u,0,1)|0}}while(0);u=c[2387826]|0;do{if((c[3542200]|0)!=0){v=n+108|0;c[v>>2]=0;z=n+100|0;c[z>>2]=0;y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[y&16383](n,2)|0;if((c[v>>2]|0)==0){break}v=c[z>>2]|0;c[o>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](o,2,0)|0;if((v|0)<1){break}gzL(u,0,2)|0}}while(0);u=(c[2387826]|0)+8192|0;do{if((c[3542200]|0)!=0){v=l+108|0;c[v>>2]=0;z=l+100|0;c[z>>2]=0;y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[y&16383](l,3)|0;if((c[v>>2]|0)==0){break}v=c[z>>2]|0;c[m>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](m,3,0)|0;if((v|0)<1){break}gzL(u,0,3)|0}}while(0);u=(c[2387826]|0)+16384|0;do{if((c[3542200]|0)!=0){v=j+108|0;c[v>>2]=0;z=j+100|0;c[z>>2]=0;y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[y&16383](j,4)|0;if((c[v>>2]|0)==0){break}v=c[z>>2]|0;c[k>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](k,4,0)|0;if((v|0)<1){break}gzL(u,0,4)|0}}while(0);u=(e|0)==0;if(!u){v=c[2385948]|0;z=32768;do{y=v+z|0;A=a[y]|0;a[y]=(A&255)>>>1&1|A&-4|A<<1&2;z=z+1|0;}while((z|0)<40960)}z=c[3530066]|0;v=0;while(1){c[z+(v<<2)>>2]=-(v>>>1&1)<<3&2016|-(v&1)<<8&63488|(-(v>>>2&1)|0)>>>3&31;A=v+1|0;if((A|0)<8){v=A}else{B=0;break}}while(1){if((B|0)>=1024){break}C=9638528+(B<<2)|0;if((c[C>>2]|0)==0){x=7291;break}else{B=B+1|0}}L9758:do{if((x|0)==7291){v=gGq(24576)|0;c[C>>2]=v;if((v|0)==0){break}gGz(v|0,0,24576);z=c[2387826]|0;gGC(v|0,z|0,24576)|0;A=0;while(1){y=A<<6;gGz(z+y|0,0,64);D=y+65536|0;E=0;do{F=D+(c[1238464+(E<<2)>>2]|0)|0;G=(E<<3)+y|0;H=0;do{I=F+(c[614800+(H<<2)>>2]|0)|0;if(((d[v+((I|0)/8|0)|0]|0)&128>>>((I&7)>>>0)|0)!=0){I=z+(G+H)|0;a[I]=a[I]|4}H=H+1|0;}while((H|0)<8);E=E+1|0;}while((E|0)<8);E=y+131072|0;D=0;while(1){H=E+(c[1238464+(D<<2)>>2]|0)|0;G=(D<<3)+y|0;F=0;do{I=H+(c[614800+(F<<2)>>2]|0)|0;if(((d[v+((I|0)/8|0)|0]|0)&128>>>((I&7)>>>0)|0)!=0){I=z+(G+F)|0;a[I]=a[I]|2}F=F+1|0;}while((F|0)<8);F=D+1|0;if((F|0)<8){D=F}else{J=0;break}}do{D=y+(c[1238464+(J<<2)>>2]|0)|0;E=(J<<3)+y|0;F=0;do{G=D+(c[614800+(F<<2)>>2]|0)|0;if(((d[v+((G|0)/8|0)|0]|0)&128>>>((G&7)>>>0)|0)!=0){G=z+(E+F)|0;a[G]=a[G]|1}F=F+1|0;}while((F|0)<8);J=J+1|0;}while((J|0)<8);y=A+1|0;if((y|0)<1024){A=y}else{K=0;break}}while(1){if((K|0)>=1024){break L9758}L=9638528+(K<<2)|0;if((c[L>>2]|0)==(v|0)){break}else{K=K+1|0}}gGr(v);c[L>>2]=0}}while(0);fwR(0);A=c[2439330]|0;z=(A|0)==0;if(!z){y=A;gGC(9706056,y|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];y=c[3528484]|0;c[2076596]=y;F=c[2417276]|0;c[3541536]=F;c[1836236]=0;E=c[2385948]|0;if(u){D=0;G=0;while(1){c[A+76+(G<<2)>>2]=E+(G<<8);H=D+1&65535;if((H&65535)>191){M=0;N=0;break}else{D=H;G=H&65535}}while(1){G=E+(N<<8)|0;c[A+76+(N+512<<2)>>2]=G;c[A+76+(N+768<<2)>>2]=G;G=M+1&65535;if((G&65535)>191){break}else{M=G;N=G&65535}}G=c[2386102]|0;c[A+844>>2]=G;c[A+848>>2]=G+256;c[A+852>>2]=G+512;c[A+856>>2]=G+768;c[A+860>>2]=G+1024;c[A+864>>2]=G+1280;c[A+868>>2]=G+1536;c[A+872>>2]=G+1792;c[A+876>>2]=G+2048;c[A+880>>2]=G+2304;c[A+884>>2]=G+2560;c[A+888>>2]=G+2816;c[A+892>>2]=G+3072;c[A+896>>2]=G+3328;c[A+900>>2]=G+3584;c[A+904>>2]=G+3840;D=192;u=192;while(1){c[A+76+(u+256<<2)>>2]=G+((u<<8)-49152);H=D+1&65535;if((H&65535)>207){O=192;P=192;break}else{D=H;u=H&65535}}while(1){u=G+((P<<8)-49152)|0;c[A+76+(P+512<<2)>>2]=u;c[A+76+(P+768<<2)>>2]=u;u=O+1&65535;if((u&65535)>207){break}else{O=u;P=u&65535}}}else{G=0;u=0;while(1){c[A+76+(u<<2)>>2]=E+(u<<8);D=G+1&65535;if((D&65535)>31){Q=0;R=0;break}else{G=D;u=D&65535}}while(1){u=E+(R<<8)|0;c[A+76+(R+512<<2)>>2]=u;c[A+76+(R+768<<2)>>2]=u;u=Q+1&65535;if((u&65535)>31){break}else{Q=u;R=u&65535}}u=c[2406300]|0;c[A+460>>2]=u;c[A+464>>2]=u+256;c[A+468>>2]=u+512;c[A+472>>2]=u+768;c[A+476>>2]=u+1024;c[A+480>>2]=u+1280;c[A+484>>2]=u+1536;c[A+488>>2]=u+1792;c[A+492>>2]=u+2048;c[A+496>>2]=u+2304;c[A+500>>2]=u+2560;c[A+504>>2]=u+2816;c[A+508>>2]=u+3072;c[A+512>>2]=u+3328;c[A+516>>2]=u+3584;c[A+520>>2]=u+3840;G=96;D=96;while(1){c[A+76+(D+256<<2)>>2]=u+((D<<8)-24576);H=G+1&65535;if((H&65535)>111){S=96;T=96;break}else{G=H;D=H&65535}}while(1){D=u+((T<<8)-24576)|0;c[A+76+(T+512<<2)>>2]=D;c[A+76+(T+768<<2)>>2]=D;D=S+1&65535;if((D&65535)>111){U=128;V=128;break}else{S=D;T=D&65535}}while(1){c[A+76+(V<<2)>>2]=E+(V<<8);u=U+1&65535;if((u&65535)>159){W=128;X=128;break}else{U=u;V=u&65535}}while(1){u=E+(X<<8)|0;c[A+76+(X+512<<2)>>2]=u;c[A+76+(X+768<<2)>>2]=u;u=W+1&65535;if((u&65535)>159){break}else{W=u;X=u&65535}}}c[A+4176>>2]=2012;c[A+4172>>2]=2698;c[A+4184>>2]=2200;if(!z){E=A;gGC(E|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=y;c[2417276]=F;c[1836236]=-1;E=a[9680]|0?32e3:0;c[3542220]=11200;if((c[2113008]|0)==0){gGz(14168888,0,252);c[3542223]=E;gGz(14168896,0,16);c[3542234]=~~((+(E|0)*32768.0*8.0+1.0e6)/2.0e6);E=31;Y=32767.0;while(1){c[14169012+(E<<2)>>2]=~~(Y+.5);u=E-1|0;if((u|0)>0){E=u;Y=Y/1.188502227}else{break}}c[3542253]=0;h[1771269]=1.0;h[1771270]=1.0;h[1771271]=1.0;c[3542574]=3;c[3542575]=3;c[3542576]=3;mB(0);c[2113008]=(c[2113008]|0)+1}h[1771269]=.3;c[3542574]=3;h[1771270]=.3;c[3542575]=3;h[1771271]=.3;c[3542576]=3;c[2385302]=f;E=c[642608+(c[2436]<<2)>>2]|0;F=c[E+128>>2]|0;if((c[E+52>>2]&4|0)==0){c[2113068]=F;y=c[E+132>>2]|0;c[2113070]=y;c[2443814]=F;c[2440436]=y;Z=F;_=y}else{c[2113070]=F;y=c[E+132>>2]|0;c[2113068]=y;c[2440436]=F;c[2443814]=y;Z=y;_=F}F=ag(Z<<1,_)|0;y=gGq(F)|0;c[2112926]=y;if((y|0)!=0){gGz(y|0,0,F|0)}F=c[2414716]|0;gGz(F|0,0,(c[2411742]|0)-F|0);F=c[2439330]|0;y=(F|0)==0;if(!y){E=F;gGC(9706056,E|0,76)|0}E=c[2438118]|0;c[2433530]=E;A=c[3528484]|0;c[2076596]=A;z=c[2417276]|0;c[3541536]=z;c[1836236]=0;gGz(9706056,0,76);if(!y){y=F;gGC(y|0,9706056,76)|0}c[2438118]=E;c[3528484]=A;c[2417276]=z;c[1836236]=-1;mB(0);$=0;i=g;return $|0}}while(0);c[2415010]=0;$=1;i=g;return $|0}function dD$(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4496652+(b*112|0)>>2];c[a+104>>2]=c[4496656+(b*112|0)>>2];c[a+108>>2]=c[4496660+(b*112|0)>>2];d=0;return d|0}function dD0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=4496552+(b*112|0);e=0;return e|0}function dD1(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1790088+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dD2(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>46){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5176744+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dD3(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0;e=i;i=i+2280|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;B=e+1200|0;C=e+1312|0;D=e+1320|0;E=e+1432|0;F=e+1440|0;G=e+1552|0;H=e+1560|0;I=e+1672|0;J=e+1680|0;K=e+1792|0;L=e+1800|0;M=e+1912|0;N=e+1920|0;O=e+2032|0;P=e+2040|0;Q=e+2152|0;R=e+2160|0;S=e+2272|0;c[2415008]=0;c[3530264]=0;c[2387356]=131072;c[3530874]=196608;c[3530638]=229376;c[3530448]=262144;c[3531018]=393216;c[3530064]=398336;c[2443768]=447488;c[3529662]=512e3;c[2414714]=515072;c[3541148]=515072;c[3529476]=516096;c[3529442]=520192;c[2386486]=524288;c[2387360]=530432;c[3530270]=532480;c[3528728]=532608;c[2409002]=532609;c[2432932]=532613;c[2442898]=532614;c[2440366]=532615;c[2411740]=532616;T=0;while(1){if((T|0)>=1024){break}U=9638528+(T<<2)|0;if((c[U>>2]|0)==0){V=7377;break}else{T=T+1|0}}do{if((V|0)==7377){T=gGq(532616)|0;c[U>>2]=T;if((T|0)==0){break}c[2415008]=T;gGz(T|0,0,532616);c[3530264]=T;c[2387356]=T+131072;c[3530874]=T+196608;c[3530638]=T+229376;c[3530448]=T+262144;c[3531018]=T+393216;c[3530064]=T+398336;c[2443768]=T+447488;c[3529662]=T+512e3;W=T+515072|0;c[2414714]=W;c[3541148]=W;c[3529476]=T+516096;c[3529442]=T+520192;c[2386486]=T+524288;c[2387360]=T+530432;c[3530270]=T+532480;c[3528728]=T+532608;c[2409002]=T+532609;c[2432932]=T+532613;c[2442898]=T+532614;c[2440366]=T+532615;W=T+532616|0;c[2411740]=W;c[2414282]=W;W=T+32768|0;if((c[3542200]|0)==0){X=1;i=e;return X|0}T=R+108|0;c[T>>2]=0;Y=R+100|0;c[Y>>2]=0;Z=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Z&16383](R,0)|0;do{if((c[T>>2]|0)!=0){Z=c[Y>>2]|0;c[S>>2]=9534384;_=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[_&16383](S,0,0)|0;if((Z|0)<1){X=1;i=e;return X|0}if((gzL(W,0,0)|0)==0){break}else{X=1}i=e;return X|0}}while(0);W=(c[3530264]|0)+49152|0;if((c[3542200]|0)==0){X=1;i=e;return X|0}Y=P+108|0;c[Y>>2]=0;T=P+100|0;c[T>>2]=0;Z=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Z&16383](P,1)|0;do{if((c[Y>>2]|0)!=0){Z=c[T>>2]|0;c[Q>>2]=9534384;_=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[_&16383](Q,1,0)|0;if((Z|0)<1){X=1;i=e;return X|0}if((gzL(W,0,1)|0)==0){break}else{X=1}i=e;return X|0}}while(0);W=(c[3530264]|0)+65536|0;if((c[3542200]|0)==0){X=1;i=e;return X|0}T=N+108|0;c[T>>2]=0;Y=N+100|0;c[Y>>2]=0;Z=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Z&16383](N,2)|0;do{if((c[T>>2]|0)!=0){Z=c[Y>>2]|0;c[O>>2]=9534384;_=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[_&16383](O,2,0)|0;if((Z|0)<1){X=1;i=e;return X|0}if((gzL(W,0,2)|0)==0){break}else{X=1}i=e;return X|0}}while(0);W=(c[3530264]|0)+81920|0;if((c[3542200]|0)==0){X=1;i=e;return X|0}Y=L+108|0;c[Y>>2]=0;T=L+100|0;c[T>>2]=0;Z=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Z&16383](L,3)|0;do{if((c[Y>>2]|0)!=0){Z=c[T>>2]|0;c[M>>2]=9534384;_=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[_&16383](M,3,0)|0;if((Z|0)<1){X=1;i=e;return X|0}if((gzL(W,0,3)|0)==0){break}else{X=1}i=e;return X|0}}while(0);W=(c[3530264]|0)+98304|0;if((c[3542200]|0)==0){X=1;i=e;return X|0}T=J+108|0;c[T>>2]=0;Y=J+100|0;c[Y>>2]=0;Z=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Z&16383](J,4)|0;do{if((c[T>>2]|0)!=0){Z=c[Y>>2]|0;c[K>>2]=9534384;_=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[_&16383](K,4,0)|0;if((Z|0)<1){X=1;i=e;return X|0}if((gzL(W,0,4)|0)==0){break}else{X=1}i=e;return X|0}}while(0);W=(c[3530264]|0)+114688|0;if((c[3542200]|0)==0){X=1;i=e;return X|0}Y=H+108|0;c[Y>>2]=0;T=H+100|0;c[T>>2]=0;Z=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Z&16383](H,5)|0;do{if((c[Y>>2]|0)!=0){Z=c[T>>2]|0;c[I>>2]=9534384;_=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[_&16383](I,5,0)|0;if((Z|0)<1){X=1;i=e;return X|0}if((gzL(W,0,5)|0)==0){break}else{X=1}i=e;return X|0}}while(0);W=(c[2387356]|0)+32768|0;if((c[3542200]|0)==0){X=1;i=e;return X|0}T=F+108|0;c[T>>2]=0;Y=F+100|0;c[Y>>2]=0;Z=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Z&16383](F,6)|0;do{if((c[T>>2]|0)!=0){Z=c[Y>>2]|0;c[G>>2]=9534384;_=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[_&16383](G,6,0)|0;if((Z|0)<1){X=1;i=e;return X|0}if((gzL(W,0,6)|0)==0){break}else{X=1}i=e;return X|0}}while(0);W=(c[2387356]|0)+61440|0;if((c[3542200]|0)==0){X=1;i=e;return X|0}Y=D+108|0;c[Y>>2]=0;T=D+100|0;c[T>>2]=0;Z=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Z&16383](D,7)|0;do{if((c[Y>>2]|0)!=0){Z=c[T>>2]|0;c[E>>2]=9534384;_=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[_&16383](E,7,0)|0;if((Z|0)<1){X=1;i=e;return X|0}if((gzL(W,0,7)|0)==0){break}else{X=1}i=e;return X|0}}while(0);W=c[3530874]|0;if((c[3542200]|0)==0){X=1;i=e;return X|0}T=B+108|0;c[T>>2]=0;Y=B+100|0;c[Y>>2]=0;Z=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Z&16383](B,8)|0;do{if((c[T>>2]|0)!=0){Z=c[Y>>2]|0;c[C>>2]=9534384;_=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[_&16383](C,8,0)|0;if((Z|0)<1){X=1;i=e;return X|0}if((gzL(W,0,8)|0)==0){break}else{X=1}i=e;return X|0}}while(0);W=c[3530638]|0;if((c[3542200]|0)==0){X=1;i=e;return X|0}Y=z+108|0;c[Y>>2]=0;T=z+100|0;c[T>>2]=0;Z=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Z&16383](z,9)|0;do{if((c[Y>>2]|0)!=0){Z=c[T>>2]|0;c[A>>2]=9534384;_=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[_&16383](A,9,0)|0;if((Z|0)<1){X=1;i=e;return X|0}if((gzL(W,0,9)|0)==0){break}else{X=1}i=e;return X|0}}while(0);W=c[3530448]|0;if((c[3542200]|0)==0){X=1;i=e;return X|0}T=x+108|0;c[T>>2]=0;Y=x+100|0;c[Y>>2]=0;Z=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Z&16383](x,10)|0;do{if((c[T>>2]|0)!=0){Z=c[Y>>2]|0;c[y>>2]=9534384;_=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[_&16383](y,10,0)|0;if((Z|0)<1){X=1;i=e;return X|0}if((gzL(W,0,10)|0)==0){break}else{X=1}i=e;return X|0}}while(0);W=(c[3530448]|0)+16384|0;if((c[3542200]|0)==0){X=1;i=e;return X|0}Y=v+108|0;c[Y>>2]=0;T=v+100|0;c[T>>2]=0;Z=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Z&16383](v,11)|0;do{if((c[Y>>2]|0)!=0){Z=c[T>>2]|0;c[w>>2]=9534384;_=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[_&16383](w,11,0)|0;if((Z|0)<1){X=1;i=e;return X|0}if((gzL(W,0,11)|0)==0){break}else{X=1}i=e;return X|0}}while(0);W=(c[3530448]|0)+32768|0;if((c[3542200]|0)==0){X=1;i=e;return X|0}T=t+108|0;c[T>>2]=0;Y=t+100|0;c[Y>>2]=0;Z=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Z&16383](t,12)|0;do{if((c[T>>2]|0)!=0){Z=c[Y>>2]|0;c[u>>2]=9534384;_=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[_&16383](u,12,0)|0;if((Z|0)<1){X=1;i=e;return X|0}if((gzL(W,0,12)|0)==0){break}else{X=1}i=e;return X|0}}while(0);W=(c[3530448]|0)+49152|0;if((c[3542200]|0)==0){X=1;i=e;return X|0}Y=r+108|0;c[Y>>2]=0;T=r+100|0;c[T>>2]=0;Z=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Z&16383](r,13)|0;do{if((c[Y>>2]|0)!=0){Z=c[T>>2]|0;c[s>>2]=9534384;_=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[_&16383](s,13,0)|0;if((Z|0)<1){X=1;i=e;return X|0}if((gzL(W,0,13)|0)==0){break}else{X=1}i=e;return X|0}}while(0);W=c[3531018]|0;if((c[3542200]|0)==0){X=1;i=e;return X|0}T=p+108|0;c[T>>2]=0;Y=p+100|0;c[Y>>2]=0;Z=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Z&16383](p,14)|0;do{if((c[T>>2]|0)!=0){Z=c[Y>>2]|0;c[q>>2]=9534384;_=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[_&16383](q,14,0)|0;if((Z|0)<1){X=1;i=e;return X|0}if((gzL(W,0,14)|0)==0){break}else{X=1}i=e;return X|0}}while(0);W=(c[3531018]|0)+1024|0;if((c[3542200]|0)==0){X=1;i=e;return X|0}Y=n+108|0;c[Y>>2]=0;T=n+100|0;c[T>>2]=0;Z=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Z&16383](n,15)|0;do{if((c[Y>>2]|0)!=0){Z=c[T>>2]|0;c[o>>2]=9534384;_=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[_&16383](o,15,0)|0;if((Z|0)<1){X=1;i=e;return X|0}if((gzL(W,0,15)|0)==0){break}else{X=1}i=e;return X|0}}while(0);W=(c[3531018]|0)+2048|0;if((c[3542200]|0)==0){X=1;i=e;return X|0}T=l+108|0;c[T>>2]=0;Y=l+100|0;c[Y>>2]=0;Z=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Z&16383](l,16)|0;do{if((c[T>>2]|0)!=0){Z=c[Y>>2]|0;c[m>>2]=9534384;_=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[_&16383](m,16,0)|0;if((Z|0)<1){X=1;i=e;return X|0}if((gzL(W,0,16)|0)==0){break}else{X=1}i=e;return X|0}}while(0);W=(c[3531018]|0)+3072|0;if((c[3542200]|0)==0){X=1;i=e;return X|0}Y=j+108|0;c[Y>>2]=0;T=j+100|0;c[T>>2]=0;Z=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Z&16383](j,17)|0;do{if((c[Y>>2]|0)!=0){Z=c[T>>2]|0;c[k>>2]=9534384;_=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[_&16383](k,17,0)|0;if((Z|0)<1){X=1;i=e;return X|0}if((gzL(W,0,17)|0)==0){break}else{X=1}i=e;return X|0}}while(0);W=(c[3531018]|0)+4096|0;if((c[3542200]|0)==0){X=1;i=e;return X|0}T=f+108|0;c[T>>2]=0;Y=f+100|0;c[Y>>2]=0;Z=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Z&16383](f,18)|0;do{if((c[T>>2]|0)!=0){Z=c[Y>>2]|0;c[g>>2]=9534384;_=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[_&16383](g,18,0)|0;if((Z|0)<1){X=1;i=e;return X|0}if((gzL(W,0,18)|0)==0){break}else{X=1}i=e;return X|0}}while(0);W=c[3529662]|0;gGz(W|0,0,3072);Y=c[3531018]|0;T=0;do{Z=a[Y+(T+4096)|0]|0;if(Z<<24>>24<0){a[W+T|0]=1}if((Z&127)==127){a[W+(T+1024)|0]=1}if((Z&255)<240|Z<<24>>24==-1){a[W+(T+2048)|0]=1}T=T+1|0;}while((T|0)<1024);dEg();T=0;while(1){if((T|0)>=1024){break}$=9638528+(T<<2)|0;if((c[$>>2]|0)==0){V=7466;break}else{T=T+1|0}}L10087:do{if((V|0)==7466){T=gGq(65536)|0;c[$>>2]=T;if((T|0)==0){break}gGz(T|0,0,65536);W=c[3530874]|0;gGC(T|0,W|0,8192)|0;Y=0;do{Z=Y<<6;gGz(W+Z|0,0,64);_=Y<<7;aa=0;do{ab=_+(c[611712+(aa<<2)>>2]|0)|0;ac=(aa<<3)+Z|0;ad=0;do{ae=ab+(c[610928+(ad<<2)>>2]|0)|0;if(((d[T+((ae|0)/8|0)|0]|0)&128>>>((ae&7)>>>0)|0)!=0){ae=W+(ac+ad)|0;a[ae]=a[ae]|2}ad=ad+1|0;}while((ad|0)<8);aa=aa+1|0;}while((aa|0)<8);aa=_|4;ad=0;do{ac=aa+(c[611712+(ad<<2)>>2]|0)|0;ab=(ad<<3)+Z|0;ae=0;do{af=ac+(c[610928+(ae<<2)>>2]|0)|0;if(((d[T+((af|0)/8|0)|0]|0)&128>>>((af&7)>>>0)|0)!=0){af=W+(ab+ae)|0;a[af]=a[af]|1}ae=ae+1|0;}while((ae|0)<8);ad=ad+1|0;}while((ad|0)<8);Y=Y+1|0;}while((Y|0)<512);Y=c[3530638]|0;gGC(T|0,Y|0,8192)|0;W=0;do{ad=W<<6;gGz(Y+ad|0,0,64);Z=W<<7;aa=0;do{_=Z+(c[611712+(aa<<2)>>2]|0)|0;ae=(aa<<3)+ad|0;ab=0;do{ac=_+(c[610928+(ab<<2)>>2]|0)|0;if(((d[T+((ac|0)/8|0)|0]|0)&128>>>((ac&7)>>>0)|0)!=0){ac=Y+(ae+ab)|0;a[ac]=a[ac]|2}ab=ab+1|0;}while((ab|0)<8);aa=aa+1|0;}while((aa|0)<8);aa=Z|4;ab=0;do{ae=aa+(c[611712+(ab<<2)>>2]|0)|0;_=(ab<<3)+ad|0;ac=0;do{af=ae+(c[610928+(ac<<2)>>2]|0)|0;if(((d[T+((af|0)/8|0)|0]|0)&128>>>((af&7)>>>0)|0)!=0){af=Y+(_+ac)|0;a[af]=a[af]|1}ac=ac+1|0;}while((ac|0)<8);ab=ab+1|0;}while((ab|0)<8);W=W+1|0;}while((W|0)<512);W=c[3530448]|0;gGC(T|0,W|0,65536)|0;Y=0;while(1){ab=Y<<8;gGz(W+ab|0,0,256);ad=Y<<9;aa=0;do{Z=1<<3-aa;ac=(c[613104+(aa<<2)>>2]|0)+ad|0;_=0;do{ae=ac+(c[611712+(_<<2)>>2]|0)|0;af=(_<<4)+ab|0;ah=0;do{ai=ae+(c[609488+(ah<<2)>>2]|0)|0;if(((d[T+((ai|0)/8|0)|0]|0)&128>>>((ai&7)>>>0)|0)!=0){ai=W+(af+ah)|0;a[ai]=(d[ai]|0|Z)&255}ah=ah+1|0;}while((ah|0)<16);_=_+1|0;}while((_|0)<16);aa=aa+1|0;}while((aa|0)<4);aa=Y+1|0;if((aa|0)<512){Y=aa}else{aj=0;break}}while(1){if((aj|0)>=1024){break L10087}ak=9638528+(aj<<2)|0;if((c[ak>>2]|0)==(T|0)){break}else{aj=aj+1|0}}gGr(T);c[ak>>2]=0}}while(0);c[3528554]=-1;c[2113160]=1;Y=gGq(3148)|0;W=Y;c[2433592]=W;if((Y|0)!=0){gGz(Y|0,0,3148);c[Y+3120>>2]=3128;c[Y+3124>>2]=1840;c[Y+3128>>2]=136;c[Y+3132>>2]=1902;c[2432840]=0;aa=0;do{c[W+48+(aa<<2)>>2]=0;aa=aa+1|0;}while((aa|0)<768);c[2113158]=0;c[2415198]=0;aa=c[2427044]|0;c[9681616+(aa<<3)>>2]=809272;c[9681620+(aa<<3)>>2]=0;c[2427044]=aa+1}c[3528554]=0;f43(Y);aa=c[3528554]|0;W=9731360+(aa<<2)|0;ab=c[W>>2]|0;c[2113158]=ab;ad=c[3529476]|0;_=c[2433592]|0;Z=0;ac=0;while(1){ah=ad+(ac<<8)|0;c[_+(aa*3148|0)+48+(ac<<2)>>2]=ah;c[_+(aa*3148|0)+48+(ac+256<<2)>>2]=ah;c[_+(aa*3148|0)+48+(ac+512<<2)>>2]=ah;ah=Z+1&65535;if((ah&65535)>15){break}else{Z=ah;ac=ah&65535}}ac=c[3529442]|0;Z=16;ad=16;while(1){Y=ac+((ad<<8)-4096)|0;c[_+(aa*3148|0)+48+(ad<<2)>>2]=Y;c[_+(aa*3148|0)+48+(ad+256<<2)>>2]=Y;c[_+(aa*3148|0)+48+(ad+512<<2)>>2]=Y;Y=Z+1&65535;if((Y&65535)>31){break}else{Z=Y;ad=Y&65535}}ad=c[2386486]|0;Z=32;ac=32;while(1){Y=ad+((ac<<8)-8192)|0;c[_+(aa*3148|0)+48+(ac<<2)>>2]=Y;c[_+(aa*3148|0)+48+(ac+256<<2)>>2]=Y;c[_+(aa*3148|0)+48+(ac+512<<2)>>2]=Y;Y=Z+1&65535;if((Y&65535)>55){break}else{Z=Y;ac=Y&65535}}ac=c[3530264]|0;Z=128;ad=128;while(1){Y=ac+(ad<<8)|0;c[_+(aa*3148|0)+48+(ad<<2)>>2]=Y;c[_+(aa*3148|0)+48+(ad+512<<2)>>2]=Y;Y=Z+1&65535;if((Y&65535)>255){break}else{Z=Y;ad=Y&65535}}c[_+(aa*3148|0)+3124>>2]=1746;c[_+(aa*3148|0)+3120>>2]=2456;ad=_+(aa*3148|0)|0;if((ad|0)!=0){Z=ad;gGC(Z|0,9660752,48)|0}c[W>>2]=ab;c[3528554]=-1;fwj(2);Z=c[2387356]|0;ad=c[2437644]|0;ac=128;Y=128;while(1){ah=Z+(Y<<8)|0;c[ad+72+(Y<<2)>>2]=ah;c[ad+72+(Y+512<<2)>>2]=ah;ah=ac+1&65535;if((ah&65535)>191){break}else{ac=ah;Y=ah&65535}}Y=c[2387360]|0;c[ad+840>>2]=Y;c[ad+1864>>2]=Y;c[ad+2888>>2]=Y;ac=Y+256|0;c[ad+844>>2]=ac;c[ad+1868>>2]=ac;c[ad+2892>>2]=ac;ac=Y+512|0;c[ad+848>>2]=ac;c[ad+1872>>2]=ac;c[ad+2896>>2]=ac;ac=Y+768|0;c[ad+852>>2]=ac;c[ad+1876>>2]=ac;c[ad+2900>>2]=ac;ac=Y+1024|0;c[ad+856>>2]=ac;c[ad+1880>>2]=ac;c[ad+2904>>2]=ac;ac=Y+1280|0;c[ad+860>>2]=ac;c[ad+1884>>2]=ac;c[ad+2908>>2]=ac;ac=Y+1536|0;c[ad+864>>2]=ac;c[ad+1888>>2]=ac;c[ad+2912>>2]=ac;ac=Y+1792|0;c[ad+868>>2]=ac;c[ad+1892>>2]=ac;c[ad+2916>>2]=ac;ac=240;Y=240;while(1){ab=Z+(Y<<8)|0;c[ad+72+(Y<<2)>>2]=ab;c[ad+72+(Y+512<<2)>>2]=ab;ab=ac+1&65535;if((ab&65535)>255){break}else{ac=ab;Y=ab&65535}}c[ad+3164>>2]=2926;c[ad+3160>>2]=374;c[ad+3148>>2]=1754;c[ad+3144>>2]=1326;U_(24e3,8);Y=c[2420424]|0;h[Y+424>>3]=.5;c[Y+440>>2]=3;h[Y+432>>3]=.5;c[Y+444>>2]=3;a[632536]=1;a[632544]=1;c[2394816]=2;a[5804e3]=1;c[2433642]=204;c[2432922]=52;Y=c[642608+(c[2436]<<2)>>2]|0;ac=Y+52|0;c[2438060]=(c[ac>>2]|0)>>>1&1;gGz(14114352,0,32);R4(0);Z=c[Y+128>>2]|0;if((c[ac>>2]&4|0)==0){c[2113068]=Z;ac=c[Y+132>>2]|0;c[2113070]=ac;c[2443814]=Z;c[2440436]=ac;al=Z;am=ac}else{c[2113070]=Z;ac=c[Y+132>>2]|0;c[2113068]=ac;c[2440436]=Z;c[2443814]=ac;al=ac;am=Z}Z=ag(al<<1,am)|0;ac=gGq(Z)|0;c[2112926]=ac;if((ac|0)!=0){gGz(ac|0,0,Z|0)}Z=c[2414714]|0;gGz(Z|0,0,(c[2411740]|0)-Z|0);c[3528554]=0;f43(c[2433592]|0);Z=c[3528554]|0;c[2113158]=c[9731360+(Z<<2)>>2];a[9660796]=0;a[9660797]=0;a[9660786]=0;a[9660787]=0;c[2415191]=0;a[9660784]=a[9660784]|80;ac=c[2433592]|0;Y=c[ac+(Z*3148|0)+1068>>2]|0;do{if((Y|0)==0){ab=c[ac+(Z*3148|0)+3120>>2]|0;if((ab|0)==0){an=0;ao=0;ap=Z;aq=ac;break}W=gj[ab&4095](-2)|0;ab=c[3528554]|0;aa=c[2433592]|0;_=c[aa+(ab*3148|0)+1068>>2]|0;ah=(W&255)<<8;if((_|0)!=0){ar=_;as=ah;at=ab;au=aa;V=7523;break}_=c[aa+(ab*3148|0)+3120>>2]|0;if((_|0)==0){an=0;ao=ah;ap=ab;aq=aa;break}aa=gj[_&4095](-1)|0;an=aa;ao=ah;ap=c[3528554]|0;aq=c[2433592]|0}else{ar=Y;as=(d[Y+254|0]|0)<<8;at=Z;au=ac;V=7523}}while(0);if((V|0)==7523){an=a[ar+255|0]|0;ao=as;ap=at;aq=au}ac=an&255|ao;c[2415188]=ac;b[4830376]=ac&65535;ac=aq+(ap*3148|0)|0;if((ac|0)!=0){Z=ac;gGC(Z|0,9660752,48)|0}c[9731360+(ap<<2)>>2]=c[2113158];c[3528554]=-1;a[9660900]=a[9660900]|16;Z=c[2437644]|0;ac=c[Z+1092>>2]|0;do{if((ac|0)==0){Y=c[Z+3144>>2]|0;if((Y|0)==0){av=0;aw=0;break}ad=gj[Y&4095](-2)|0;Y=c[2437644]|0;ah=c[Y+1092>>2]|0;aa=(ad&255)<<8;if((ah|0)!=0){ax=ah;ay=aa;V=7532;break}ah=c[Y+3144>>2]|0;if((ah|0)==0){av=0;aw=aa;break}av=gj[ah&4095](-1)|0;aw=aa}else{ax=ac;ay=(d[ac+254|0]|0)<<8;V=7532}}while(0);if((V|0)==7532){av=a[ax+255|0]|0;aw=ay}ac=av&255|aw;c[2415221]=ac;b[4830442]=ac&65535;a[9660920]=0;a[9660921]=0;a[9660928]=0;a[9660930]=0;a[9660931]=0;c[2415234]=0;gGz(9660901,0,5);c[2415235]=65535;c[2415237]=65535;a[9660932]=a[9660932]|64;gGz(14114352,0,32);R4(0);c[2388376]=0;c[2385562]=0;X=0;i=e;return X|0}}while(0);c[2415008]=0;X=1;i=e;return X|0}function dD4(){var b=0,d=0,e=0,f=0;c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}c[2113160]=0;b=c[2433592]|0;if((b|0)!=0){gGr(b);c[2433592]=0}b=c[2437644]|0;if((b|0)!=0){gGr(b);c[2437644]=0}gGz(14114352,0,32);R4(0);a[632536]=0;c[2433642]=0;c[2432922]=0;a[632544]=0;c[2394816]=0;a[5804e3]=0;c[2394812]=0;c[2394808]=0;c[2438060]=0;c[2440444]=0;c[1839550]=-1;b=c[2420424]|0;if((b|0)!=0){gGr(b);c[2420424]=0}b=c[2433528]|0;if((b|0)!=0){gGr(b);c[2433528]=0}c[3541148]=0;b=c[2415008]|0;d=0;while(1){if((d|0)>=1024){e=7624;break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==(b|0)){break}else{d=d+1|0}}if((e|0)==7624){c[2415008]=0;return 0}gGr(b);c[f>>2]=0;c[2415008]=0;return 0}function dD5(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;e=(c[2388376]|0)+1|0;c[2388376]=e;if((e|0)>180){c[3528554]=0;f43(c[2433592]|0);e=c[3528554]|0;c[2113158]=c[9731360+(e<<2)>>2];a[9660796]=0;a[9660797]=0;a[9660786]=0;a[9660787]=0;c[2415191]=0;a[9660784]=a[9660784]|80;f=c[2433592]|0;g=c[f+(e*3148|0)+1068>>2]|0;do{if((g|0)==0){h=c[f+(e*3148|0)+3120>>2]|0;if((h|0)==0){i=0;j=0;k=e;l=f;break}m=gj[h&4095](-2)|0;h=c[3528554]|0;n=c[2433592]|0;o=c[n+(h*3148|0)+1068>>2]|0;p=(m&255)<<8;if((o|0)!=0){q=o;r=p;s=h;t=n;u=7630;break}o=c[n+(h*3148|0)+3120>>2]|0;if((o|0)==0){i=0;j=p;k=h;l=n;break}n=gj[o&4095](-1)|0;i=n;j=p;k=c[3528554]|0;l=c[2433592]|0}else{q=g;r=d[g+254|0]<<8;s=e;t=f;u=7630}}while(0);if((u|0)==7630){i=a[q+255|0]|0;j=r;k=s;l=t}t=i&255|j;c[2415188]=t;b[4830376]=t&65535;t=l+(k*3148|0)|0;if((t|0)!=0){l=t;gGC(l|0,9660752,48)|0}c[9731360+(k<<2)>>2]=c[2113158];c[3528554]=-1;a[9660900]=a[9660900]|16;k=c[2437644]|0;l=c[k+1092>>2]|0;do{if((l|0)==0){t=c[k+3144>>2]|0;if((t|0)==0){v=0;w=0;break}j=gj[t&4095](-2)|0;t=c[2437644]|0;i=c[t+1092>>2]|0;s=(j&255)<<8;if((i|0)!=0){x=i;y=s;u=7639;break}i=c[t+3144>>2]|0;if((i|0)==0){v=0;w=s;break}v=gj[i&4095](-1)|0;w=s}else{x=l;y=d[l+254|0]<<8;u=7639}}while(0);if((u|0)==7639){v=a[x+255|0]|0;w=y}y=v&255|w;c[2415221]=y;b[4830442]=y&65535;a[9660920]=0;a[9660921]=0;a[9660928]=0;a[9660930]=0;a[9660931]=0;c[2415234]=0;gGz(9660901,0,5);c[2415235]=65535;c[2415237]=65535;a[9660932]=a[9660932]|64;gGz(14114352,0,32);R4(0);c[2388376]=0;c[2385562]=0}if((a[9624496]|0)!=0){y=c[2414714]|0;gGz(y|0,0,(c[2411740]|0)-y|0);c[3528554]=0;f43(c[2433592]|0);y=c[3528554]|0;c[2113158]=c[9731360+(y<<2)>>2];a[9660796]=0;a[9660797]=0;a[9660786]=0;a[9660787]=0;c[2415191]=0;a[9660784]=a[9660784]|80;w=c[2433592]|0;v=c[w+(y*3148|0)+1068>>2]|0;do{if((v|0)==0){x=c[w+(y*3148|0)+3120>>2]|0;if((x|0)==0){z=0;A=0;B=y;C=w;break}l=gj[x&4095](-2)|0;x=c[3528554]|0;k=c[2433592]|0;s=c[k+(x*3148|0)+1068>>2]|0;i=(l&255)<<8;if((s|0)!=0){D=s;E=i;F=x;G=k;u=7648;break}s=c[k+(x*3148|0)+3120>>2]|0;if((s|0)==0){z=0;A=i;B=x;C=k;break}k=gj[s&4095](-1)|0;z=k;A=i;B=c[3528554]|0;C=c[2433592]|0}else{D=v;E=d[v+254|0]<<8;F=y;G=w;u=7648}}while(0);if((u|0)==7648){z=a[D+255|0]|0;A=E;B=F;C=G}G=z&255|A;c[2415188]=G;b[4830376]=G&65535;G=C+(B*3148|0)|0;if((G|0)!=0){C=G;gGC(C|0,9660752,48)|0}c[9731360+(B<<2)>>2]=c[2113158];c[3528554]=-1;a[9660900]=a[9660900]|16;B=c[2437644]|0;C=c[B+1092>>2]|0;do{if((C|0)==0){G=c[B+3144>>2]|0;if((G|0)==0){H=0;I=0;break}A=gj[G&4095](-2)|0;G=c[2437644]|0;z=c[G+1092>>2]|0;F=(A&255)<<8;if((z|0)!=0){J=z;K=F;u=7657;break}z=c[G+3144>>2]|0;if((z|0)==0){H=0;I=F;break}H=gj[z&4095](-1)|0;I=F}else{J=C;K=d[C+254|0]<<8;u=7657}}while(0);if((u|0)==7657){H=a[J+255|0]|0;I=K}K=H&255|I;c[2415221]=K;b[4830442]=K&65535;a[9660920]=0;a[9660921]=0;a[9660928]=0;a[9660930]=0;a[9660931]=0;c[2415234]=0;gGz(9660901,0,5);c[2415235]=65535;c[2415237]=65535;a[9660932]=a[9660932]|64;gGz(14114352,0,32);R4(0);c[2388376]=0;c[2385562]=0}b[4775332]=-1;K=0;I=-1;H=-1;do{I=((a[9633912+K|0]&1)<<K^I&255)&255;H=((a[9631712+K|0]&1)<<K^H&255)&255;K=K+1|0;}while((K|0)<8);a[9550665]=H;a[9550664]=a[9635304]&-128|I&127;I=a[9688]|0;H=I?534:0;c[3528554]=0;f43(c[2433592]|0);K=c[3528554]|0;c[2113158]=c[9731360+(K<<2)>>2];if(I){I=H-1|0;J=0;u=0;while(1){C=f45(47)|0;c[2113158]=(c[2113158]|0)+C;C=(J|0)==(I|0);do{if(C){if((a[c[2432932]|0]|0)==0){break}f44(0)}}while(0);do{if((c[2385562]|0)==0){B=f4D(47)|0;c[2113162]=(c[2113162]|0)+B;if(!C){break}if((a[(c[2432932]|0)+1|0]|0)==0){break}f01()}}while(0);C=c[2112964]|0;if((C|0)==0){L=u}else{B=a[9688]|0;F=B&1;if(B){UX(C+(u<<1<<1)|0,F)}L=F+u|0}F=J+1|0;if((F|0)<(H|0)){J=F;u=L}else{break}}M=L;N=c[3528554]|0}else{M=0;N=K}K=(c[2433592]|0)+(N*3148|0)|0;if((K|0)!=0){L=K;gGC(L|0,9660752,48)|0}c[9731360+(N<<2)>>2]=c[2113158];c[3528554]=-1;N=c[2112964]|0;do{if((N|0)!=0){L=a[9688]|0?534:0;if((L|0)==(M|0)){break}UX(N+(M<<1<<1)|0,L-M|0)}}while(0);if((c[2112968]|0)==0){return 0}dD6()|0;return 0}function dD6(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;if((a[9547632]|0)!=0){dEg();a[9547632]=0}gGz(c[2443768]|0,0,64512);dEh(0);b=(e[(c[2409002]|0)+2>>1]|0)+27&511;f=c[3529442]|0;g=c[3528728]|0;h=c[2112926]|0;i=c[3530638]|0;j=c[2113068]|0;k=128;do{l=((k|0)/64|0)<<3;m=(k<<3&504)-b|0;n=(m|0)<-7?m+512|0:m;do{if((n|0)<(j|0)){m=k<<1;o=d[f+(m|1)|0]|0;p=o<<8;q=p|d[f+m|0];m=q&511;r=q>>>1&224|o>>>1&31;o=p&32768;q=p&16384;if((a[g]|0)==0){s=q;t=o;u=n;v=l}else{s=q^16384;t=o^32768;u=280-n|0;v=216-l|0}o=(s|0)!=0;q=v-16|0;if((t|0)==0){if(o){Sl(h,m,u,q,r,2,1024,i);break}else{Sj(h,m,u,q,r,2,1024,i);break}}else{if(o){Sp(h,m,u,q,r,2,1024,i);break}else{Sn(h,m,u,q,r,2,1024,i);break}}}}while(0);k=k+1|0;}while((k|0)<1920);dEi(0);dEh(1);dEi(1);dEh(2);R8((c[3530064]|0)+(((d[c[2440366]|0]|0)*3072|0)<<2)|0);R5();return 0}function dD7(a,b){a=a|0;b=b|0;return 1}function dD8(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2477252+(b*112|0)>>2];c[a+104>>2]=c[2477256+(b*112|0)>>2];c[a+108>>2]=c[2477260+(b*112|0)>>2];d=0;return d|0}function dD9(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=2477152+(b*112|0);e=0;return e|0}function dEa(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1446644+(b*112|0)>>2];c[a+104>>2]=c[1446648+(b*112|0)>>2];c[a+108>>2]=c[1446652+(b*112|0)>>2];d=0;return d|0}function dEb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=1446544+(b*112|0);e=0;return e|0}function dEc(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1033572+(b*112|0)>>2];c[a+104>>2]=c[1033576+(b*112|0)>>2];c[a+108>>2]=c[1033580+(b*112|0)>>2];d=0;return d|0}function dEd(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=1033472+(b*112|0);e=0;return e|0}function dEe(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2475124+(b*112|0)>>2];c[a+104>>2]=c[2475128+(b*112|0)>>2];c[a+108>>2]=c[2475132+(b*112|0)>>2];d=0;return d|0}function dEf(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=2475024+(b*112|0);e=0;return e|0}function dEg(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=0;while(1){if((a|0)>=1024){b=0;break}e=9638528+(a<<2)|0;if((c[e>>2]|0)==0){f=7755;break}else{a=a+1|0}}do{if((f|0)==7755){a=gGq(4096)|0;c[e>>2]=a;if((a|0)==0){b=0;break}gGz(a|0,0,4096);b=a}}while(0);e=b;a=c[3531018]|0;g=0;do{h=d[a+g|0]|0;i=d[a+(g+1024)|0]|0;c[e+(g<<2)>>2]=(-(h>>>1&1)&31)+(-(h&1)&14)+(-(h>>>2&1)&67)+(-(h>>>3&1)&143)<<8&63488|(-(h>>>5&1)&31)+(-(h>>>7)&143)+(-(h>>>4&1)&14)+(-(h>>>6&1)&67)<<3&2016|((-(i>>>1&1)&31)+(-(i&1)&14)+(-(i>>>2&1)&67)+(-(i>>>3&1)&143)|0)>>>3&31;g=g+1|0;}while((g|0)<1024);g=c[3530064]|0;i=0;while(1){h=i<<8;j=i*3072|0;k=j+1024|0;l=j+2048|0;m=0;do{c[g+(m+j<<2)>>2]=c[e+((d[a+(m+2048)|0]|0|h)<<2)>>2];c[g+(k+m<<2)>>2]=c[e+((d[a+(m+3072)|0]|0|h)<<2)>>2];c[g+(l+m<<2)>>2]=c[e+((d[a+(m+4096)|0]|0|h)<<2)>>2];m=m+1|0;}while((m|0)<1024);m=i+1|0;if((m|0)<4){i=m}else{n=0;break}}while(1){if((n|0)>=1024){f=7767;break}o=9638528+(n<<2)|0;if((c[o>>2]|0)==(b|0)){break}else{n=n+1|0}}if((f|0)==7767){return}gGr(b);c[o>>2]=0;return}function dEh(e){e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;f=e<<10;g=(e|0)==0|0;e=c[2386486]|0;h=c[3528728]|0;i=c[2113068]|0;j=c[2113070]|0;k=c[3530448]|0;l=c[3529662]|0;m=c[2112926]|0;n=c[2443768]|0;o=0;do{p=d[e+(o+6016)|0]|0;q=p&1;r=p>>>1&1;s=p>>>2&1;t=p>>>3&1;u=((t<<1|s)^511)&(p<<1&256|d[e+(o+1920)|0]);if((a[h]|0)==0){v=r;w=q}else{v=r^1;w=q^1}q=(d[e+(o+6017)|0]<<8&256|d[e+(o+3969)|0])-71|0;r=(265-(t<<4)-(d[e+(o+3968)|0]|0)&255)-48|0;p=v&-t;x=w&-s;y=((v|0)!=0?240:0)|((w|0)!=0?15:0);z=d[e+(o+1921)|0]<<4&1008;A=0;do{B=r+(A<<4)|0;C=((A^p)<<1)+u|0;if((B|0)>=-15){D=(j|0)<=(B|0);E=0;do{F=q+(E<<4)|0;L10426:do{if(!(D|(i|0)<=(F|0)|(F|0)<-15)){G=C+(E^x)<<8;H=B;I=0;while(1){if((H|0)>-1&(H|0)<(j|0)){J=I<<4;K=ag(i,H)|0;L=0;M=F;while(1){do{if((M|0)>=0&(M|0)<(i|0)){N=(d[k+((L+J^y)+G)|0]|0)+z|0;if((a[l+(N+f)|0]|0)!=0){break}O=K+M|0;b[m+(O<<1)>>1]=N+2048&65535;a[n+O|0]=g}}while(0);O=L+1|0;if((O|0)<16){L=O;M=M+1|0}else{break}}}M=I+1|0;if((M|0)>=16){break L10426}H=H+1|0;I=M}}}while(0);E=E+1|0;}while((E|0)<=(s|0))}A=A+1|0;}while((A|0)<=(t|0));o=o+2|0;}while((o|0)<128);return}function dEi(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;g=c[3531018]|0;h=(e[c[2409002]>>1]|0)+24&511;i=c[2113068]|0;j=c[3529476]|0;k=c[3528728]|0;l=c[3530874]|0;m=c[2113070]|0;n=c[2443768]|0;o=c[2112926]|0;p=128;do{q=((p|0)/64|0)<<3;r=(p<<3&504)-((q-40|0)>>>0<192?h:0)|0;s=(r|0)<-7?r+512|0:r;L10447:do{if((s|0)<(i|0)){r=p<<1;t=d[j+(r|1)|0]|0;u=t<<8;v=u|d[j+r|0];r=u&32768;w=u&16384;if((a[k]|0)==0){x=s;y=q;z=w;A=r}else{x=280-s|0;y=216-q|0;z=w^16384;A=r^32768}if((t>>>5&1|0)!=(f|0)){break}r=(v>>>1&240|t>>>1&15)<<2;t=v<<6&32704;v=((z|0)!=0?7:0)|((A|0)!=0?56:0);w=y-16|0;u=0;while(1){if((w|0)>-1&(w|0)<(m|0)){B=u<<3;C=ag(i,w)|0;D=x;E=0;while(1){do{if((D|0)>=0&(D|0)<(i|0)){F=(d[l+((E+B^v)+t)|0]|0)+r|0;if((a[g+(F+2048)|0]&127)==127){break}G=C+D|0;if((a[n+G|0]|0)!=0){break}b[o+(G<<1)>>1]=F&65535}}while(0);F=E+1|0;if((F|0)<8){D=D+1|0;E=F}else{break}}}E=u+1|0;if((E|0)>=8){break L10447}w=w+1|0;u=E}}}while(0);p=p+1|0;}while((p|0)<1920);return}function dEj(e,f){e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=e&65535;if((g&64512|0)==26624){UZ(g&1023,f&255);return}e=g&61440;if((e|0)==32768){h=g&2048;if((h|0)!=0){a[9660900]=a[9660900]|16;i=c[2437644]|0;j=c[i+1092>>2]|0;do{if((j|0)==0){k=c[i+3144>>2]|0;if((k|0)==0){l=0;m=0;break}n=gj[k&4095](-2)|0;k=c[2437644]|0;o=c[k+1092>>2]|0;p=(n&255)<<8;if((o|0)!=0){q=o;r=p;s=7816;break}o=c[k+3144>>2]|0;if((o|0)==0){l=0;m=p;break}l=gj[o&4095](-1)|0;m=p}else{q=j;r=(d[j+254|0]|0)<<8;s=7816}}while(0);if((s|0)==7816){l=a[q+255|0]|0;m=r}r=l&255|m;c[2415221]=r;b[4830442]=r&65535;a[9660920]=0;a[9660921]=0;a[9660928]=0;a[9660930]=0;a[9660931]=0;c[2415234]=0;gGz(9660901,0,5);c[2415235]=65535;c[2415237]=65535;a[9660932]=a[9660932]|64}c[2385562]=h;return}else if((e|0)==36864){h=g>>>11&1^1;a[c[3528728]|0]=h&255;R4(h);return}else if((e|0)==28672){e=g&2048;a[c[2432932]|0]=(e>>>11^1)&255;if((e|0)==0){return}a[9660786]=0;return}else{switch(g|0){case 14848:{b[(c[2409002]|0)+2>>1]=f&255;return};case 14336:{b[c[2409002]>>1]=f&255;return};case 14337:{b[c[2409002]>>1]=f&255|256;return};case 15360:{a[c[2440366]|0]=(f&255)>>>3&3;g=c[3530264]|0;e=c[3528554]|0;h=c[2433592]|0;r=((f&255)<<13&57344|65536)-16384|0;m=64;l=64;while(1){q=g+(r+(l<<8))|0;c[h+(e*3148|0)+48+(l<<2)>>2]=q;c[h+(e*3148|0)+48+(l+512<<2)>>2]=q;q=m+1&65535;if((q&65535)>95){break}else{m=q;l=q&65535}}return};case 14849:{b[(c[2409002]|0)+2>>1]=f&255|256;return};default:{return}}}}function dEk(b){b=b|0;var d=0,e=0;d=b&65535;if((d&64512|0)==26624){e=a[(c[2438116]|0)+(d&1023)|0]|0;return e|0}if((d&63488|0)!=30720){e=0;return e|0}c[2388376]=0;e=0;return e|0}function dEl(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;e=b&65535;if((e|0)==257){b=d&255;f=a[632536]|0;g=f?2:0;if(!f){return}f=(c[2438060]|0)==(c[1839550]|0);c[14114352+((f?0:g-1|0)<<2)>>2]=b>>>3&1;c[14114352+((f?1:g-2|0)<<2)>>2]=b>>>4&1;return}else if((e|0)==256){a[c[2442898]|0]=d&1;return}else{return}}function dEm(b){b=b|0;var c=0,d=0;c=b&65535;if((c|0)==257){d=-1}else if((c|0)==256){d=a[9550665]|0}else{d=0}return d|0}function dEn(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((e&65504|0)==0){f4S(b,d);return}if((e&65408|0)==128){a[(c[3530270]|0)+(e&127)|0]=d;return}if((e&64512|0)==4096){UZ(e&1023,d&255);return}if((e&57344|0)==8192){c[2388376]=0;return}if((e&49152|0)!=16384){return}d=e>>>13&1;a[(c[2432932]|0)+1|0]=(d^1)&255;if((d|0)==0|(a[9660903]|0)==0){return}a[9660903]=0;return}function dEo(b){b=b|0;var e=0,f=0;e=b&65535;do{if((e&65504|0)==0){f=f4R(b)|0}else{if((e&65408|0)==128){f=a[(c[3530270]|0)+(e&127)|0]|0;break}if((e&64512|0)==4096){f=a[(c[2438116]|0)+(e&1023)|0]|0;break}if((e|0)==53251){f=a[9550664]<<4|15;break}else if((e|0)==53249){f=a[9635306]&15|a[9635305]<<4;break}else if((e|0)==53250){f=a[9550664]|15;break}else if((e|0)==53248){f=(d[9635306]|0)>>>4|a[9635305]&-16;break}else{f=0;break}}}while(0);return f|0}function dEp(b,d){b=b|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((b&-2048|0)==16744448){f=b&2047;g=c[2387228]|0;a[g+(f^1)|0]=d;h=f>>>1;f=e[g+(h<<1)>>1]|0;g=(f>>>12)*17|0;i=(f>>>8&15)*17|0;j=(f>>>4&15)*17|0;if((f&8|0)==0){k=(f&15)+7|0;f=((ag(g,k)|0)>>>0)/14|0;l=((ag(i,k)|0)>>>0)/14|0;m=f;n=((ag(j,k)|0)>>>0)/14|0;o=l}else{m=g;n=j;o=i}c[(c[2406948]|0)+(h<<2)>>2]=n|o<<8|m<<16;c[(c[3530062]|0)+(h<<2)>>2]=n>>>3&31|o<<3&2016|m<<8&63488;return}else{if((b-16662528|0)>>>0>=2){return}b=d&255;c[3528726]=b&1;c[2385620]=b&16;c[2385722]=b&32;return}}function dEq(f,g){f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((f&-2048|0)==16744448){h=f&2047;i=c[2387228]|0;b[i+h>>1]=g;j=h>>>1;h=e[i+(j<<1)>>1]|0;i=(h>>>12)*17|0;k=(h>>>8&15)*17|0;l=(h>>>4&15)*17|0;if((h&8|0)==0){m=(h&15)+7|0;h=((ag(i,m)|0)>>>0)/14|0;n=((ag(k,m)|0)>>>0)/14|0;o=h;p=((ag(l,m)|0)>>>0)/14|0;q=n}else{o=i;p=l;q=k}c[(c[2406948]|0)+(j<<2)>>2]=p|q<<8|o<<16;c[(c[3530062]|0)+(j<<2)>>2]=p>>>3&31|q<<3&2016|o<<8&63488;return}switch(f|0){case 16678932:{c[3526966]=g&511;return};case 16678934:{c[3526958]=g&511;return};case 16678928:{c[3525092]=g&1023;return};case 16678938:{f=c[3531152]|0;b[f+16378>>1]=(a[9550024]&255)>>>4^15;b[f+16380>>1]=(d[9549720]|0)^255;b[f+16382>>1]=(d[9549840]|0)^255;return};case 16678930:{c[3525084]=g&1023;return};default:{return}}}function dEr(b){b=b|0;var c=0;if((b|0)==16662528){c=a[9550024]|0}else if((b|0)==16662529){c=-1}else if((b|0)==16662531){c=a[9635297]|0}else if((b|0)==16662530){c=a[9635296]|0}else{c=0}return c|0}function dEs(a){a=a|0;var b=0;if((a|0)==16662530){b=(d[9635297]|0)<<8|(d[9635296]|0)}else if((a|0)==16662528){b=(d[9550024]|0)<<8|255}else{b=0}return b|0}function dEt(b){b=b|0;var d=0,e=0;d=b&65535;if((d|0)==32769){e=c[(c[3531464]|0)+4240>>2]&255;return e|0}else if((d|0)==40960){e=a[c[3528302]|0]|0;return e|0}else{e=0;return e|0}return 0}function dEu(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((e|0)==32769){b=c[2113304]|0;a[14168504+b|0]=d;mv(0,b,d&255);return}else if((e|0)==32768){c[2113304]=d&255;return}else{return}}function dEv(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>25){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4809172+(b*112|0)>>2];c[a+104>>2]=c[4809176+(b*112|0)>>2];c[a+108>>2]=c[4809180+(b*112|0)>>2];d=0;return d|0}function dEw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<26&(d|0)==0)){e=1;return e|0}c[a>>2]=4809072+(b*112|0);e=0;return e|0}function dEx(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6931504+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dEy(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>46){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7440440+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dEz(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;e=i;i=i+720|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;c[2426762]=0;c[2388178]=0;c[2385946]=262144;c[3530872]=294912;c[3530636]=425984;c[3530446]=557056;c[3530342]=1081344;c[3530062]=1605632;c[2414712]=1609728;c[3531174]=1609728;c[3531152]=1626112;c[2387228]=1642496;c[3529508]=1644544;c[3529474]=1648640;c[3529440]=1665024;c[2386576]=1681408;c[2386100]=1682688;c[2406948]=1684736;c[2411738]=1688832;t=0;while(1){if((t|0)>=1024){break}u=9638528+(t<<2)|0;if((c[u>>2]|0)==0){v=7974;break}else{t=t+1|0}}do{if((v|0)==7974){t=gGq(1688832)|0;c[u>>2]=t;if((t|0)==0){break}c[2426762]=t;gGz(t|0,0,1688832);c[2388178]=t;c[2385946]=t+262144;c[3530872]=t+294912;c[3530636]=t+425984;c[3530446]=t+557056;c[3530342]=t+1081344;c[3530062]=t+1605632;w=t+1609728|0;c[2414712]=w;c[3531174]=w;c[3531152]=t+1626112;c[2387228]=t+1642496;c[3529508]=t+1644544;c[3529474]=t+1648640;c[3529440]=t+1665024;c[2386576]=t+1681408;c[2386100]=t+1682688;c[2406948]=t+1684736;w=t+1688832|0;c[2411738]=w;c[2414280]=w;if((R6(t+1|0,0,2)|0)!=0){x=1;i=e;return x|0}if((R6(c[2388178]|0,1,2)|0)!=0){x=1;i=e;return x|0}if((R6((c[2388178]|0)+131073|0,2,2)|0)!=0){x=1;i=e;return x|0}if((R6((c[2388178]|0)+131072|0,3,2)|0)!=0){x=1;i=e;return x|0}t=c[2385946]|0;if((c[3542200]|0)==0){x=1;i=e;return x|0}w=r+108|0;c[w>>2]=0;y=r+100|0;c[y>>2]=0;z=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[z&16383](r,4)|0;do{if((c[w>>2]|0)!=0){z=c[y>>2]|0;c[s>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](s,4,0)|0;if((z|0)<1){x=1;i=e;return x|0}if((gzL(t,0,4)|0)==0){break}else{x=1}i=e;return x|0}}while(0);t=c[3530872]|0;if((c[3542200]|0)==0){x=1;i=e;return x|0}y=p+108|0;c[y>>2]=0;w=p+100|0;c[w>>2]=0;z=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[z&16383](p,5)|0;do{if((c[y>>2]|0)!=0){z=c[w>>2]|0;c[q>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](q,5,0)|0;if((z|0)<1){x=1;i=e;return x|0}if((gzL(t,0,5)|0)==0){break}else{x=1}i=e;return x|0}}while(0);t=c[3530636]|0;if((c[3542200]|0)==0){x=1;i=e;return x|0}w=n+108|0;c[w>>2]=0;y=n+100|0;c[y>>2]=0;z=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[z&16383](n,6)|0;do{if((c[w>>2]|0)!=0){z=c[y>>2]|0;c[o>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](o,6,0)|0;if((z|0)<1){x=1;i=e;return x|0}if((gzL(t,0,6)|0)==0){break}else{x=1}i=e;return x|0}}while(0);t=(c[3530636]|0)+32768|0;if((c[3542200]|0)==0){x=1;i=e;return x|0}y=l+108|0;c[y>>2]=0;w=l+100|0;c[w>>2]=0;z=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[z&16383](l,7)|0;do{if((c[y>>2]|0)!=0){z=c[w>>2]|0;c[m>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](m,7,0)|0;if((z|0)<1){x=1;i=e;return x|0}if((gzL(t,0,7)|0)==0){break}else{x=1}i=e;return x|0}}while(0);t=j+108|0;w=j+100|0;y=f+108|0;z=f+100|0;A=0;while(1){B=A<<15;C=(c[3530446]|0)+B|0;D=A+8|0;if((c[3542200]|0)==0){x=1;v=8098;break}c[t>>2]=0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,D)|0;if((c[t>>2]|0)!=0){E=c[w>>2]|0;c[k>>2]=9534384;F=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[F&16383](k,D,0)|0;if((E|0)<1){x=1;v=8101;break}if((gzL(C,0,D)|0)!=0){x=1;v=8096;break}}D=(c[3530342]|0)+B|0;B=A+16|0;if((c[3542200]|0)==0){x=1;v=8115;break}c[y>>2]=0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,B)|0;if((c[y>>2]|0)!=0){C=c[z>>2]|0;c[g>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](g,B,0)|0;if((C|0)<1){x=1;v=8118;break}if((gzL(D,0,B)|0)!=0){x=1;v=8117;break}}B=A+1|0;if((B|0)<8){A=B}else{G=0;v=8006;break}}if((v|0)==8006){while(1){v=0;if((G|0)>=1024){x=1;v=8099;break}H=9638528+(G<<2)|0;if((c[H>>2]|0)==0){break}else{G=G+1|0;v=8006}}if((v|0)==8099){i=e;return x|0}A=gGq(262144)|0;c[H>>2]=A;if((A|0)==0){x=1;i=e;return x|0}gGz(A|0,0,262144);z=c[3530872]|0;gGC(A|0,z|0,32768)|0;y=0;do{w=y<<6;gGz(z+w|0,0,64);t=y<<7;B=t|4;D=0;while(1){C=B+(c[608544+(D<<2)>>2]|0)|0;E=(D<<3)+w|0;F=0;do{I=C+(c[609552+(F<<2)>>2]|0)|0;if(((d[A+((I|0)/8|0)|0]|0)&128>>>((I&7)>>>0)|0)!=0){I=z+(E+F)|0;a[I]=a[I]|2}F=F+1|0;}while((F|0)<8);F=D+1|0;if((F|0)<8){D=F}else{J=0;break}}do{D=t+(c[608544+(J<<2)>>2]|0)|0;B=(J<<3)+w|0;F=0;do{E=D+(c[609552+(F<<2)>>2]|0)|0;if(((d[A+((E|0)/8|0)|0]|0)&128>>>((E&7)>>>0)|0)!=0){E=z+(B+F)|0;a[E]=a[E]|1}F=F+1|0;}while((F|0)<8);J=J+1|0;}while((J|0)<8);y=y+1|0;}while((y|0)<1024);y=c[3530636]|0;gGC(A|0,y|0,65536)|0;z=0;do{w=z<<6;gGz(y+w|0,0,64);t=z<<7;F=0;do{B=1<<3-F;D=(c[613264+(F<<2)>>2]|0)+t|0;E=0;do{C=D+(c[608544+(E<<2)>>2]|0)|0;I=(E<<3)+w|0;K=0;do{L=C+(c[609552+(K<<2)>>2]|0)|0;if(((d[A+((L|0)/8|0)|0]|0)&128>>>((L&7)>>>0)|0)!=0){L=y+(I+K)|0;a[L]=(d[L]|0|B)&255}K=K+1|0;}while((K|0)<8);E=E+1|0;}while((E|0)<8);F=F+1|0;}while((F|0)<4);z=z+1|0;}while((z|0)<2048);z=c[3530446]|0;gGC(A|0,z|0,262144)|0;y=0;do{F=y<<8;gGz(z+F|0,0,256);w=y<<9;t=0;do{E=1<<3-t;B=(c[961472+(t<<2)>>2]|0)+w|0;D=0;do{K=B+(c[608544+(D<<2)>>2]|0)|0;I=(D<<4)+F|0;C=0;do{L=K+(c[609552+(C<<2)>>2]|0)|0;if(((d[A+((L|0)/8|0)|0]|0)&128>>>((L&7)>>>0)|0)!=0){L=z+(I+C)|0;a[L]=(d[L]|0|E)&255}C=C+1|0;}while((C|0)<16);D=D+1|0;}while((D|0)<16);t=t+1|0;}while((t|0)<4);y=y+1|0;}while((y|0)<2048);y=c[3530342]|0;gGC(A|0,y|0,262144)|0;z=0;while(1){t=z<<8;gGz(y+t|0,0,256);F=0;do{w=1<<3-F;D=(c[613280+(F<<2)>>2]|0)+t|0;E=0;do{B=D+(c[609008+(E<<2)>>2]|0)|0;C=(E<<4)+t|0;I=0;do{K=B+(c[597864+(I<<2)>>2]|0)|0;if(((d[A+((K|0)/8|0)|0]|0)&128>>>((K&7)>>>0)|0)!=0){K=y+(C+I)|0;a[K]=(d[K]|0|w)&255}I=I+1|0;}while((I|0)<16);E=E+1|0;}while((E|0)<16);F=F+1|0;}while((F|0)<4);F=z+1|0;if((F|0)<2048){z=F}else{M=0;break}}while(1){if((M|0)>=1024){break}N=9638528+(M<<2)|0;if((c[N>>2]|0)==(A|0)){v=8048;break}else{M=M+1|0}}if((v|0)==8048){gGr(A);c[N>>2]=0}fxU(0,425984);if((c[2394]|0)==0){O=c[2112932]|0}else{c[2394]=0;z=c[3532596]|0;c[2112932]=z;y=c[3532592]|0;if((y|0)!=0){gGC(9104152,y|0,280)|0}c[2113054]=c[2113060];O=z}z=c[2388178]|0;y=O|0;F=0;while(1){t=z+F|0;c[y>>2]=t;c[y+131072>>2]=t;t=F+1024|0;if(t>>>0>262143){break}else{y=y+4|0;F=t}}F=c[3531174]|0;c[O+65024>>2]=F;c[O+130560>>2]=F;c[O+196096>>2]=F;y=F+1024|0;c[O+65028>>2]=y;c[O+130564>>2]=y;c[O+196100>>2]=y;y=F+2048|0;c[O+65032>>2]=y;c[O+130568>>2]=y;c[O+196104>>2]=y;y=F+3072|0;c[O+65036>>2]=y;c[O+130572>>2]=y;c[O+196108>>2]=y;y=F+4096|0;c[O+65040>>2]=y;c[O+130576>>2]=y;c[O+196112>>2]=y;y=F+5120|0;c[O+65044>>2]=y;c[O+130580>>2]=y;c[O+196116>>2]=y;y=F+6144|0;c[O+65048>>2]=y;c[O+130584>>2]=y;c[O+196120>>2]=y;y=F+7168|0;c[O+65052>>2]=y;c[O+130588>>2]=y;c[O+196124>>2]=y;y=F+8192|0;c[O+65056>>2]=y;c[O+130592>>2]=y;c[O+196128>>2]=y;y=F+9216|0;c[O+65060>>2]=y;c[O+130596>>2]=y;c[O+196132>>2]=y;y=F+10240|0;c[O+65064>>2]=y;c[O+130600>>2]=y;c[O+196136>>2]=y;y=F+11264|0;c[O+65068>>2]=y;c[O+130604>>2]=y;c[O+196140>>2]=y;y=F+12288|0;c[O+65072>>2]=y;c[O+130608>>2]=y;c[O+196144>>2]=y;y=F+13312|0;c[O+65076>>2]=y;c[O+130612>>2]=y;c[O+196148>>2]=y;y=F+14336|0;c[O+65080>>2]=y;c[O+130616>>2]=y;c[O+196152>>2]=y;y=F+15360|0;c[O+65084>>2]=y;c[O+130620>>2]=y;c[O+196156>>2]=y;y=c[3529508]|0;c[O+65216>>2]=y;c[O+130752>>2]=y;c[O+196288>>2]=y;F=y+1024|0;c[O+65220>>2]=F;c[O+130756>>2]=F;c[O+196292>>2]=F;F=y+2048|0;c[O+65224>>2]=F;c[O+130760>>2]=F;c[O+196296>>2]=F;F=y+3072|0;c[O+65228>>2]=F;c[O+130764>>2]=F;c[O+196300>>2]=F;F=c[3529474]|0;c[O+65280>>2]=F;c[O+130816>>2]=F;c[O+196352>>2]=F;y=F+1024|0;c[O+65284>>2]=y;c[O+130820>>2]=y;c[O+196356>>2]=y;y=F+2048|0;c[O+65288>>2]=y;c[O+130824>>2]=y;c[O+196360>>2]=y;y=F+3072|0;c[O+65292>>2]=y;c[O+130828>>2]=y;c[O+196364>>2]=y;y=F+4096|0;c[O+65296>>2]=y;c[O+130832>>2]=y;c[O+196368>>2]=y;y=F+5120|0;c[O+65300>>2]=y;c[O+130836>>2]=y;c[O+196372>>2]=y;y=F+6144|0;c[O+65304>>2]=y;c[O+130840>>2]=y;c[O+196376>>2]=y;y=F+7168|0;c[O+65308>>2]=y;c[O+130844>>2]=y;c[O+196380>>2]=y;y=F+8192|0;c[O+65312>>2]=y;c[O+130848>>2]=y;c[O+196384>>2]=y;y=F+9216|0;c[O+65316>>2]=y;c[O+130852>>2]=y;c[O+196388>>2]=y;y=F+10240|0;c[O+65320>>2]=y;c[O+130856>>2]=y;c[O+196392>>2]=y;y=F+11264|0;c[O+65324>>2]=y;c[O+130860>>2]=y;c[O+196396>>2]=y;y=F+12288|0;c[O+65328>>2]=y;c[O+130864>>2]=y;c[O+196400>>2]=y;y=F+13312|0;c[O+65332>>2]=y;c[O+130868>>2]=y;c[O+196404>>2]=y;y=F+14336|0;c[O+65336>>2]=y;c[O+130872>>2]=y;c[O+196408>>2]=y;y=F+15360|0;c[O+65340>>2]=y;c[O+130876>>2]=y;c[O+196412>>2]=y;y=c[3529440]|0;c[O+65344>>2]=y;c[O+130880>>2]=y;c[O+196416>>2]=y;F=y+1024|0;c[O+65348>>2]=F;c[O+130884>>2]=F;c[O+196420>>2]=F;F=y+2048|0;c[O+65352>>2]=F;c[O+130888>>2]=F;c[O+196424>>2]=F;F=y+3072|0;c[O+65356>>2]=F;c[O+130892>>2]=F;c[O+196428>>2]=F;F=y+4096|0;c[O+65360>>2]=F;c[O+130896>>2]=F;c[O+196432>>2]=F;F=y+5120|0;c[O+65364>>2]=F;c[O+130900>>2]=F;c[O+196436>>2]=F;F=y+6144|0;c[O+65368>>2]=F;c[O+130904>>2]=F;c[O+196440>>2]=F;F=y+7168|0;c[O+65372>>2]=F;c[O+130908>>2]=F;c[O+196444>>2]=F;F=y+8192|0;c[O+65376>>2]=F;c[O+130912>>2]=F;c[O+196448>>2]=F;F=y+9216|0;c[O+65380>>2]=F;c[O+130916>>2]=F;c[O+196452>>2]=F;F=y+10240|0;c[O+65384>>2]=F;c[O+130920>>2]=F;c[O+196456>>2]=F;F=y+11264|0;c[O+65388>>2]=F;c[O+130924>>2]=F;c[O+196460>>2]=F;F=y+12288|0;c[O+65392>>2]=F;c[O+130928>>2]=F;c[O+196464>>2]=F;F=y+13312|0;c[O+65396>>2]=F;c[O+130932>>2]=F;c[O+196468>>2]=F;F=y+14336|0;c[O+65400>>2]=F;c[O+130936>>2]=F;c[O+196472>>2]=F;F=y+15360|0;c[O+65404>>2]=F;c[O+130940>>2]=F;c[O+196476>>2]=F;F=c[2387228]|0;c[O+65408>>2]=F;c[O+196480>>2]=F;y=F+1024|0;c[O+65412>>2]=y;c[O+196484>>2]=y;y=c[3531152]|0;c[O+65472>>2]=y;c[O+131008>>2]=y;c[O+196544>>2]=y;F=y+1024|0;c[O+65476>>2]=F;c[O+131012>>2]=F;c[O+196548>>2]=F;F=y+2048|0;c[O+65480>>2]=F;c[O+131016>>2]=F;c[O+196552>>2]=F;F=y+3072|0;c[O+65484>>2]=F;c[O+131020>>2]=F;c[O+196556>>2]=F;F=y+4096|0;c[O+65488>>2]=F;c[O+131024>>2]=F;c[O+196560>>2]=F;F=y+5120|0;c[O+65492>>2]=F;c[O+131028>>2]=F;c[O+196564>>2]=F;F=y+6144|0;c[O+65496>>2]=F;c[O+131032>>2]=F;c[O+196568>>2]=F;F=y+7168|0;c[O+65500>>2]=F;c[O+131036>>2]=F;c[O+196572>>2]=F;F=y+8192|0;c[O+65504>>2]=F;c[O+131040>>2]=F;c[O+196576>>2]=F;F=y+9216|0;c[O+65508>>2]=F;c[O+131044>>2]=F;c[O+196580>>2]=F;F=y+10240|0;c[O+65512>>2]=F;c[O+131048>>2]=F;c[O+196584>>2]=F;F=y+11264|0;c[O+65516>>2]=F;c[O+131052>>2]=F;c[O+196588>>2]=F;F=y+12288|0;c[O+65520>>2]=F;c[O+131056>>2]=F;c[O+196592>>2]=F;F=y+13312|0;c[O+65524>>2]=F;c[O+131060>>2]=F;c[O+196596>>2]=F;F=y+14336|0;c[O+65528>>2]=F;c[O+131064>>2]=F;c[O+196600>>2]=F;F=y+15360|0;c[O+65532>>2]=F;c[O+131068>>2]=F;c[O+196604>>2]=F;c[O+196608>>2]=2708;c[O+196688>>2]=2868;c[O+196648>>2]=2384;c[O+196728>>2]=2836;F=c[3532592]|0;if((F|0)!=0){gGC(F|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);F=c[2439330]|0;y=(F|0)==0;if(!y){z=F;gGC(9706056,z|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];z=c[3528484]|0;c[2076596]=z;A=c[2417276]|0;c[3541536]=A;c[1836236]=0;t=c[2385946]|0;E=0;w=0;while(1){c[F+76+(w<<2)>>2]=t+(w<<8);D=E+1&65535;if((D&65535)>127){P=0;Q=0;break}else{E=D;w=D&65535}}while(1){w=t+(Q<<8)|0;c[F+76+(Q+512<<2)>>2]=w;c[F+76+(Q+768<<2)>>2]=w;w=P+1&65535;if((w&65535)>127){break}else{P=w;Q=w&65535}}t=c[2386100]|0;c[F+844>>2]=t;w=t+256|0;c[F+848>>2]=w;E=t+512|0;c[F+852>>2]=E;D=t+768|0;c[F+856>>2]=D;I=t+1024|0;c[F+860>>2]=I;C=t+1280|0;c[F+864>>2]=C;B=t+1536|0;c[F+868>>2]=B;K=t+1792|0;c[F+872>>2]=K;c[F+1868>>2]=t;c[F+1872>>2]=w;c[F+1876>>2]=E;c[F+1880>>2]=D;c[F+1884>>2]=I;c[F+1888>>2]=C;c[F+1892>>2]=B;c[F+1896>>2]=K;c[F+2892>>2]=t;c[F+3916>>2]=t;c[F+2896>>2]=w;c[F+3920>>2]=w;c[F+2900>>2]=E;c[F+3924>>2]=E;c[F+2904>>2]=D;c[F+3928>>2]=D;c[F+2908>>2]=I;c[F+3932>>2]=I;c[F+2912>>2]=C;c[F+3936>>2]=C;c[F+2916>>2]=B;c[F+3940>>2]=B;c[F+2920>>2]=K;c[F+3944>>2]=K;c[F+4184>>2]=1850;c[F+4180>>2]=688;if(!y){K=F;gGC(K|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=z;c[2417276]=A;c[1836236]=-1;K=a[9680]|0;B=K?32e3:0;if(K){if(a[9624]|0){K=B*3|0;C=55930;while(1){if((C|0)>(K|0)){C=C>>1}else{R=1222;S=C;break}}}else{R=2462;S=B}c[2429380]=S;c[3542124]=R;mw(3579545,S);C=gGq(262144)|0;c[2406684]=C;gGz(C|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(3579545,11025)}h[745421]=.6;c[2436794]=3;h[745420]=.6;c[2436792]=3;C=c[642608+(c[2436]<<2)>>2]|0;K=c[C+128>>2]|0;if((c[C+52>>2]&4|0)==0){c[2113068]=K;A=c[C+132>>2]|0;c[2113070]=A;c[2443814]=K;c[2440436]=A;T=K;U=A}else{c[2113070]=K;A=c[C+132>>2]|0;c[2113068]=A;c[2440436]=K;c[2443814]=A;T=A;U=K}K=ag(T<<1,U)|0;A=gGq(K)|0;c[2112926]=A;if((A|0)!=0){gGz(A|0,0,K|0)}a[9624488]=0;K=c[2414712]|0;gGz(K|0,0,(c[2411738]|0)-K|0);c[3525092]=0;c[3525084]=0;c[3526966]=0;c[3526958]=0;c[3528302]=(c[3531152]|0)+16376;c[3528726]=0;c[2385620]=0;c[2385722]=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];K=c[3532592]|0;if((K|0)!=0){gGC(9104152,K|0,280)|0}c[2113054]=c[2113060]}RI();K=c[2394]|0;A=c[14130368+(K<<2)>>2]|0;if((A|0)!=0){gGC(A|0,9104152,280)|0}c[8452240+(K<<2)>>2]=c[2113054];c[2394]=-1;K=c[2439330]|0;A=(K|0)==0;if(!A){C=K;gGC(9706056,C|0,76)|0}C=c[2438118]|0;c[2433530]=C;z=c[3528484]|0;c[2076596]=z;F=c[2417276]|0;c[3541536]=F;c[1836236]=0;gGz(9706056,0,76);if(!A){A=K;gGC(A|0,9706056,76)|0}c[2438118]=C;c[3528484]=z;c[2417276]=F;c[1836236]=-1;mx(0);x=0;i=e;return x|0}else if((v|0)==8096){i=e;return x|0}else if((v|0)==8115){i=e;return x|0}else if((v|0)==8117){i=e;return x|0}else if((v|0)==8118){i=e;return x|0}else if((v|0)==8098){i=e;return x|0}else if((v|0)==8101){i=e;return x|0}}}while(0);c[2426762]=0;x=1;i=e;return x|0}function dEA(){var a=0,b=0,d=0,e=0,f=0;a=c[3531464]|0;c[a+44344>>2]=0;c[a+44348>>2]=0;if((a|0)!=0){gGr(a);c[3531464]=0}a=c[2406684]|0;if((a|0)!=0){gGr(a);c[2406684]=0}if((c[2392]|0)>=0){a=0;do{b=14130368+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}b=14130384+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}a=a+1|0;}while((a|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;fwZ();a=c[2426762]|0;b=0;while(1){if((b|0)>=1024){break}e=9638528+(b<<2)|0;if((c[e>>2]|0)==(a|0)){f=8133;break}else{b=b+1|0}}if((f|0)==8133){gGr(a);c[e>>2]=0}c[2426762]=0;c[2113070]=0;c[2113068]=0;e=c[2112926]|0;if((e|0)==0){return 0}gGr(e);c[2112926]=0;return 0}function dEB(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((a[9624488]|0)!=0){a[9624488]=0;e=c[2414712]|0;gGz(e|0,0,(c[2411738]|0)-e|0);c[3525092]=0;c[3525084]=0;c[3526966]=0;c[3526958]=0;c[3528302]=(c[3531152]|0)+16376;c[3528726]=0;c[2385620]=0;c[2385722]=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060]}RI();e=c[2394]|0;f=c[14130368+(e<<2)>>2]|0;if((f|0)!=0){gGC(f|0,9104152,280)|0}c[8452240+(e<<2)>>2]=c[2113054];c[2394]=-1;e=c[2439330]|0;f=(e|0)==0;if(!f){g=e;gGC(9706056,g|0,76)|0}g=c[2438118]|0;c[2433530]=g;h=c[3528484]|0;c[2076596]=h;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);if(!f){f=e;gGC(f|0,9706056,76)|0}c[2438118]=g;c[3528484]=h;c[2417276]=i;c[1836236]=-1;mx(0)}a[9549720]=-1;a[9549840]=-1;a[9550024]=-1;i=0;h=-1;g=-1;f=-1;do{h=(d[9633904+i|0]<<i^h&255)&255;g=(d[9631704+i|0]<<i^g&255)&255;f=(d[9629704+i|0]<<i^f&255)&255;i=i+1|0;}while((i|0)<8);a[9550024]=h;a[9549840]=g;a[9549720]=f;f=c[2385548]|0;if((f|0)>0){gGz(9752472,0,((f|0)>1?f<<2:4)|0)}c[2433530]=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060]}f=c[2439330]|0;if((f|0)!=0){g=f;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;g=0;f=2e5;h=59659;i=0;while(1){e=8-g|0;j=(f|0)/(e|0)|0;c[2113056]=j;k=RG(j)|0;c[2113054]=(c[2113054]|0)+k;c[2276108]=-1;c[2113056]=-1;j=f-k|0;do{if((g|0)!=7){c[8452200+(c[2394]<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0>=1024){break}RH(4)}}while(0);k=(h|0)/(e|0)|0;do{if((k|0)<1){l=0}else{if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){m=gfc(k)|0;c[2433530]=(c[2433530]|0)+m;l=m;break}else{c[2433530]=(c[2433530]|0)+k;l=k;break}}}while(0);k=h-l|0;if((g&1|0)!=0){if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12}e=c[2112964]|0;if((e|0)==0){n=i}else{m=a[9688]|0?66:0;gg[c[3542124]&4095](e+(i<<1<<1)|0,m);n=m+i|0}m=g+1|0;if((m|0)<8){g=m;f=j;h=k;i=n}else{break}}c[8452200+(c[2394]<<2)>>2]=8194;c[2276080]=512;if((c[2276079]|0)>>>0<512){RH(2)}i=c[2112964]|0;if((i|0)!=0){gg[c[3542124]&4095](i+(n<<1<<1)|0,(a[9688]|0?534:0)-n|0)}n=c[1836236]|0;i=c[9757320+(n<<2)>>2]|0;if((i|0)!=0){h=i;gGC(h|0,9706056,76)|0}c[9752472+(n<<2)>>2]=c[2433530];c[14113936+(n<<2)>>2]=c[2076596];c[9669104+(n<<2)>>2]=c[3541536];c[1836236]=-1;n=c[2394]|0;h=c[14130368+(n<<2)>>2]|0;if((h|0)!=0){gGC(h|0,9104152,280)|0}c[8452240+(n<<2)>>2]=c[2113054];c[2394]=-1;if((c[2112968]|0)==0){o=c[2386576]|0;p=c[3531174]|0;q=p+2048|0;gGC(o|0,q|0,1280)|0;return 0}dEC()|0;o=c[2386576]|0;p=c[3531174]|0;q=p+2048|0;gGC(o|0,q|0,1280)|0;return 0}function dEC(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;if((a[9547624]|0)!=0){d=c[2406948]|0;f=c[3530062]|0;g=0;do{h=c[d+(g<<2)>>2]|0;c[f+(g<<2)>>2]=h>>8<<3&2016|h>>>3&31|h>>16<<8&63488;g=g+1|0;}while((g|0)<1024)}g=c[2112926]|0;f=c[2113070]|0;d=c[2113068]|0;gGz(g|0,0,ag(f<<1,d)|0);if((c[2385620]|0)!=0){dEK(2)}if((c[2385722]|0)!=0){h=c[3529440]|0;i=c[3530636]|0;j=0;do{k=(j<<3&504)-(c[3526966]|0)|0;l=(j>>6<<3)-(c[3526958]|0)|0;m=(k|0)<-7?k+512|0:k;k=(l|0)<-7?l+512|0:l;do{if((k-9|0)>>>0<=230){if((m+7|0)>>>0>262){break}l=k-16|0;n=j<<1;o=e[h+((n|1)<<1)>>1]|0;p=b[h+(n<<1)>>1]&255|o<<8&1792;n=o>>>3&3;q=(o&128|0)!=0;if((o&64|0)==0){if(q){St(g,p,m,l,n,4,15,0,i);break}else{Sr(g,p,m,l,n,4,15,0,i);break}}else{if(q){Sx(g,p,m,l,n,4,15,0,i);break}else{Sv(g,p,m,l,n,4,15,0,i);break}}}}while(0);j=j+1|0;}while((j|0)<4096)}if((c[2385620]|0)!=0){dEK(0)}j=c[2386576]|0;i=c[3530342]|0;h=636;do{m=b[j+(h<<1)>>1]&2047;do{if((m|0)!=2047){k=e[j+((h|1)<<1)>>1]|0;n=k>>>2&15;l=b[j+((h|3)<<1)>>1]|0;p=l<<16>>16;q=b[j+((h|2)<<1)>>1]|0;o=q<<16>>16;r=q<<16>>16>496?o-512|0:o;if((l+15&65535)>270){break}if((r-1|0)>>>0>238){break}l=r-16|0;if((k&2|0)==0){SH(g,m,p,l,n,4,15,512,i);break}else{SJ(g,m,p,l,n,4,15,512,i);break}}}while(0);h=h-4|0;}while((h|0)>-1);if((c[2385620]|0)!=0){dEK(1)}h=c[3529508]|0;i=c[3530872]|0;j=0;do{m=(j>>>2&248)-16|0;if(m>>>0<=223){n=e[h+(j+1024<<1)>>1]|0;Sq(g,b[h+(j<<1)>>1]&255|n<<2&768,j<<3&248,m,n&63,2,3,768,i)}j=j+1|0;}while((j|0)<1024);if((c[3528726]|0)==0){s=c[3530062]|0;R8(s);return 0}j=(ag(f,d)|0)-1|0;d=j>>1;if((d|0)>0){t=0}else{s=c[3530062]|0;R8(s);return 0}do{f=g+(t<<1)|0;i=b[f>>1]|0;h=g+(j-t<<1)|0;b[f>>1]=b[h>>1]|0;b[h>>1]=i;t=t+1|0;}while((t|0)<(d|0));s=c[3530062]|0;R8(s);return 0}function dED(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;f=i;i=i+208|0;g=f|0;h=f+16|0;j=f+32|0;k=f+48|0;l=f+64|0;m=f+80|0;n=f+96|0;o=f+112|0;p=f+128|0;q=f+144|0;r=f+160|0;s=f+176|0;t=f+192|0;if((e|0)!=0){c[e>>2]=169602}if((b&96|0)!=0){gGz(t|0,0,12);e=c[2414712]|0;c[t>>2]=e;c[t+4>>2]=(c[2411738]|0)-e;c[t+12>>2]=196728;e=c[2076592]|0;gj[e&4095](t)|0}if((b&64|0)==0){i=f;return 0}t=l|0;gGz(k|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){e=l+9|0;l=j;u=j|0;v=j+4|0;w=j+12|0;x=k|0;y=k+4|0;z=k+12|0;A=0;do{gGC(t|0,614896,11)|0;a[e]=A+48&255;B=8452256+(A<<2)|0;gGz(l|0,0,12);c[u>>2]=B;c[v>>2]=4;c[w>>2]=164976;gj[c[2076592]&4095](j)|0;if((c[B>>2]|0)!=0){c[x>>2]=c[14130368+(A<<2)>>2];c[y>>2]=c[8452184+(A<<2)>>2];c[z>>2]=t;B=c[2076592]|0;gj[B&4095](k)|0}A=A+1|0;}while((A|0)<=(c[2392]|0))}fw$(b);gGz(h|0,0,12);c[h>>2]=8453216;c[h+4>>2]=4;c[h+12>>2]=107480;gj[c[2076592]&4095](h)|0;gGz(g|0,0,12);c[g>>2]=14168504;c[g+4>>2]=256;c[g+12>>2]=476464;gj[c[2076592]&4095](g)|0;if((b&2|0)!=0){b=0;do{mv(0,b,d[14168504+b|0]|0);b=b+1|0;}while((b|0)<256)}gGz(s|0,0,12);c[s>>2]=14100368;c[s+4>>2]=4;c[s+12>>2]=558672;gj[c[2076592]&4095](s)|0;gGz(r|0,0,12);c[r>>2]=14100336;c[r+4>>2]=4;c[r+12>>2]=557256;gj[c[2076592]&4095](r)|0;gGz(q|0,0,12);c[q>>2]=14107864;c[q+4>>2]=4;c[q+12>>2]=555984;gj[c[2076592]&4095](q)|0;gGz(p|0,0,12);c[p>>2]=14107832;c[p+4>>2]=4;c[p+12>>2]=554432;gj[c[2076592]&4095](p)|0;gGz(o|0,0,12);c[o>>2]=9542480;c[o+4>>2]=4;c[o+12>>2]=497256;gj[c[2076592]&4095](o)|0;gGz(n|0,0,12);c[n>>2]=9542888;c[n+4>>2]=4;c[n+12>>2]=485408;gj[c[2076592]&4095](n)|0;gGz(m|0,0,12);c[m>>2]=14114904;c[m+4>>2]=4;c[m+12>>2]=142288;gj[c[2076592]&4095](m)|0;i=f;return 0}function dEE(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>25){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3084868+(b*112|0)>>2];c[a+104>>2]=c[3084872+(b*112|0)>>2];c[a+108>>2]=c[3084876+(b*112|0)>>2];d=0;return d|0}function dEF(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<26&(d|0)==0)){e=1;return e|0}c[a>>2]=3084768+(b*112|0);e=0;return e|0}function dEG(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>25){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3081956+(b*112|0)>>2];c[a+104>>2]=c[3081960+(b*112|0)>>2];c[a+108>>2]=c[3081964+(b*112|0)>>2];d=0;return d|0}function dEH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<26&(d|0)==0)){e=1;return e|0}c[a>>2]=3081856+(b*112|0);e=0;return e|0}function dEI(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>25){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2132412+(b*112|0)>>2];c[a+104>>2]=c[2132416+(b*112|0)>>2];c[a+108>>2]=c[2132420+(b*112|0)>>2];d=0;return d|0}function dEJ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<26&(d|0)==0)){e=1;return e|0}c[a>>2]=2132312+(b*112|0);e=0;return e|0}function dEK(a){a=a|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=c[3529474]|0;f=c[2112926]|0;g=c[3530446]|0;h=0;do{i=(h<<4&1008)-(c[3525092]|0)|0;j=(h>>6<<4)-(c[3525084]|0)|0;k=(i|0)<-15?i+1024|0:i;i=(j|0)<-15?j+1024|0:j;do{if((k+15|0)>>>0<=270){if((i-1|0)>>>0>238){break}j=i-16|0;l=h<<1;m=e[d+((l|1)<<1)>>1]|0;n=b[d+(l<<1)>>1]&255|m<<8&1792;l=m>>>3&3;o=(m&192|0)==192;if(((o?2:m>>>5&1)|0)!=(a|0)){break}p=(m&128|0)!=0&(o^1);if(o|(m&64|0)==0){if(p){SJ(f,n,k,j,l,4,15,256,g);break}else{SH(f,n,k,j,l,4,15,256,g);break}}else{if(p){SN(f,n,k,j,l,4,15,256,g);break}else{SL(f,n,k,j,l,4,15,256,g);break}}}}while(0);h=h+1|0;}while((h|0)<4096);return}function dEL(b){b=b|0;var d=0,e=0;if((b+26592&65535)<96){d=a[(c[2406604]|0)+((b&65535)-38944)|0]|0;return d|0}switch(b<<16>>16){case-20476:{d=a[14168824]|0;return d|0};case-20478:{b=(a[14166160]|0)!=0|0;e=(a[14166161]|0)==0?b:b|4;b=(a[14166152]|0)==0?e:e|2;d=(a[14166153]|0)==0?b:b|8;return d|0};case-20479:{b=(a[14166157]|0)!=0|0;e=(a[14166156]|0)==0?b:b|2;b=(a[14166154]|0)==0?e:e|4;e=(a[14166155]|0)==0?b:b|8;d=(a[14166158]|0)==0?e:e|16;return d|0};case-20475:{d=a[14168825]|0;return d|0};case-20480:{e=(a[14166165]|0)!=0|0;b=(a[14166164]|0)==0?e:e|2;e=(a[14166162]|0)==0?b:b|4;b=(a[14166163]|0)==0?e:e|8;d=(a[14166166]|0)==0?b:b|16;return d|0};default:{d=0;return d|0}}return 0}function dEM(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((b+26592&65535)<96){a[(c[2406604]|0)+(e-38944)|0]=d;return}if((b<<16>>16|0)==(-18432|0)){c[2415254]=d&255;return}else if((b<<16>>16|0)==(-20480|0)){c[3526944]=d&255}a[(c[2420352]|0)+e|0]=d;return}function dEN(a){a=a|0;var b=0;if((a<<16>>16|0)==(-256|0)){b=127}else if((a<<16>>16|0)==24576){a=c[2415254]|0;c[2415254]=0;b=a&255}else{b=0}return b|0}function dEO(b,d){b=b|0;d=d|0;var e=0;switch(b&255|0){case 0:{c[3542228]=d&15;return};case 1:{b=d&255;e=c[3542228]|0;if((e|0)>15){return}do{if((e|0)<14){if((e|0)!=13){if((a[14168916+e|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(0,e,b);return};case 128:{c[3542354]=d&15;return};case 17:{b=d&255;e=c[3542291]|0;if((e|0)>15){return}do{if((e|0)<14){if((e|0)!=13){if((a[14169168+e|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(1,e,b);return};case 129:{b=d&255;e=c[3542354]|0;if((e|0)>15){return}do{if((e|0)<14){if((e|0)!=13){if((a[14169420+e|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(2,e,b);return};case 16:{c[3542291]=d&15;return};default:{return}}}function dEP(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4218996+(b*112|0)>>2];c[a+104>>2]=c[4219e3+(b*112|0)>>2];c[a+108>>2]=c[4219004+(b*112|0)>>2];d=0;return d|0}function dEQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=4218896+(b*112|0);e=0;return e|0}function dER(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6931232+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dES(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>44){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=638040+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dET(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0.0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0;e=i;i=i+2160|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;B=e+1200|0;C=e+1312|0;D=e+1320|0;E=e+1432|0;F=e+1440|0;G=e+1552|0;H=e+1560|0;I=e+1672|0;J=e+1680|0;K=e+1792|0;L=e+1800|0;M=e+1912|0;N=e+1920|0;O=e+2032|0;P=e+2040|0;Q=e+2152|0;c[2426760]=0;c[2420350]=0;c[2420356]=65536;c[2420354]=126976;c[2411226]=135168;c[2405684]=143360;c[2420352]=143360;c[2411228]=208896;c[2406606]=212992;c[2406602]=213248;c[2406608]=214272;c[2406604]=215296;c[2411736]=215392;c[2420360]=215392;c[2406630]=248160;c[2415128]=313696;c[2385374]=379232;R=a[9688]|0?9612:0;c[2388330]=R+379232;S=R+379744|0;c[2414278]=S;R=S;S=0;while(1){if((S|0)>=1024){break}T=9638528+(S<<2)|0;if((c[T>>2]|0)==0){U=8386;break}else{S=S+1|0}}do{if((U|0)==8386){S=gGq(R)|0;c[T>>2]=S;if((S|0)==0){break}gGz(S|0,0,R|0);c[2426760]=S;gGz(S|0,0,R|0);c[2420350]=S;c[2420356]=S+65536;c[2420354]=S+126976;c[2411226]=S+135168;V=S+143360|0;c[2405684]=V;c[2420352]=V;c[2411228]=S+208896;c[2406606]=S+212992;c[2406602]=S+213248;c[2406608]=S+214272;c[2406604]=S+215296;V=S+215392|0;c[2411736]=V;c[2420360]=V;c[2406630]=S+248160;c[2415128]=S+313696;c[2385374]=S+379232;V=a[9688]|0?9612:0;c[2388330]=S+(V+379232);c[2414278]=S+(V+379744);V=a[6416720]|0;do{if((c[3542200]|0)!=0){W=P+108|0;c[W>>2]=0;X=P+100|0;c[X>>2]=0;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Y&16383](P,0)|0;if((c[W>>2]|0)==0){break}W=c[X>>2]|0;c[Q>>2]=9534384;X=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[X&16383](Q,0,0)|0;if((W|0)<1){break}gzL(S,0,0)|0}}while(0);S=c[2420350]|0;do{if(V){W=S+16384|0;do{if((c[3542200]|0)!=0){X=F+108|0;c[X>>2]=0;Y=F+100|0;c[Y>>2]=0;Z=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Z&16383](F,1)|0;if((c[X>>2]|0)==0){break}X=c[Y>>2]|0;c[G>>2]=9534384;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Y&16383](G,1,0)|0;if((X|0)<1){break}gzL(W,0,1)|0}}while(0);W=(c[2420350]|0)+32768|0;if((c[3542200]|0)==0){_=3;break}X=D+108|0;c[X>>2]=0;Y=D+100|0;c[Y>>2]=0;Z=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Z&16383](D,2)|0;if((c[X>>2]|0)==0){_=3;break}X=c[Y>>2]|0;c[E>>2]=9534384;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Y&16383](E,2,0)|0;if((X|0)<1){_=3;break}gzL(W,0,2)|0;_=3}else{W=S+8192|0;do{if((c[3542200]|0)!=0){X=N+108|0;c[X>>2]=0;Y=N+100|0;c[Y>>2]=0;Z=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Z&16383](N,1)|0;if((c[X>>2]|0)==0){break}X=c[Y>>2]|0;c[O>>2]=9534384;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Y&16383](O,1,0)|0;if((X|0)<1){break}gzL(W,0,1)|0}}while(0);W=(c[2420350]|0)+16384|0;do{if((c[3542200]|0)!=0){X=L+108|0;c[X>>2]=0;Y=L+100|0;c[Y>>2]=0;Z=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Z&16383](L,2)|0;if((c[X>>2]|0)==0){break}X=c[Y>>2]|0;c[M>>2]=9534384;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Y&16383](M,2,0)|0;if((X|0)<1){break}gzL(W,0,2)|0}}while(0);W=(c[2420350]|0)+24576|0;do{if((c[3542200]|0)!=0){X=J+108|0;c[X>>2]=0;Y=J+100|0;c[Y>>2]=0;Z=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Z&16383](J,3)|0;if((c[X>>2]|0)==0){break}X=c[Y>>2]|0;c[K>>2]=9534384;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Y&16383](K,3,0)|0;if((X|0)<1){break}gzL(W,0,3)|0}}while(0);W=(c[2420350]|0)+32768|0;if((c[3542200]|0)==0){_=5;break}X=H+108|0;c[X>>2]=0;Y=H+100|0;c[Y>>2]=0;Z=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Z&16383](H,4)|0;if((c[X>>2]|0)==0){_=5;break}X=c[Y>>2]|0;c[I>>2]=9534384;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Y&16383](I,4,0)|0;if((X|0)<1){_=5;break}gzL(W,0,4)|0;_=5}}while(0);S=c[2420356]|0;do{if((c[3542200]|0)!=0){V=B+108|0;c[V>>2]=0;W=B+100|0;c[W>>2]=0;X=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[X&16383](B,_)|0;if((c[V>>2]|0)==0){break}V=c[W>>2]|0;c[C>>2]=9534384;W=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[W&16383](C,_,0)|0;if((V|0)<1){break}gzL(S,0,_)|0}}while(0);S=(c[2420356]|0)+4096|0;V=_+1|0;do{if((c[3542200]|0)!=0){W=z+108|0;c[W>>2]=0;X=z+100|0;c[X>>2]=0;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Y&16383](z,V)|0;if((c[W>>2]|0)==0){break}W=c[X>>2]|0;c[A>>2]=9534384;X=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[X&16383](A,V,0)|0;if((W|0)<1){break}gzL(S,0,V)|0}}while(0);V=(c[2420356]|0)+8192|0;S=_+2|0;do{if((c[3542200]|0)!=0){W=x+108|0;c[W>>2]=0;X=x+100|0;c[X>>2]=0;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Y&16383](x,S)|0;if((c[W>>2]|0)==0){break}W=c[X>>2]|0;c[y>>2]=9534384;X=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[X&16383](y,S,0)|0;if((W|0)<1){break}gzL(V,0,S)|0}}while(0);S=(c[2420356]|0)+12288|0;V=_+3|0;do{if((c[3542200]|0)!=0){W=v+108|0;c[W>>2]=0;X=v+100|0;c[X>>2]=0;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Y&16383](v,V)|0;if((c[W>>2]|0)==0){break}W=c[X>>2]|0;c[w>>2]=9534384;X=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[X&16383](w,V,0)|0;if((W|0)<1){break}gzL(S,0,V)|0}}while(0);V=(c[2420356]|0)+20480|0;S=_+4|0;do{if((c[3542200]|0)!=0){W=t+108|0;c[W>>2]=0;X=t+100|0;c[X>>2]=0;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Y&16383](t,S)|0;if((c[W>>2]|0)==0){break}W=c[X>>2]|0;c[u>>2]=9534384;X=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[X&16383](u,S,0)|0;if((W|0)<1){break}gzL(V,0,S)|0}}while(0);S=(c[2420356]|0)+28672|0;V=_+5|0;do{if((c[3542200]|0)!=0){W=r+108|0;c[W>>2]=0;X=r+100|0;c[X>>2]=0;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Y&16383](r,V)|0;if((c[W>>2]|0)==0){break}W=c[X>>2]|0;c[s>>2]=9534384;X=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[X&16383](s,V,0)|0;if((W|0)<1){break}gzL(S,0,V)|0}}while(0);V=(c[2420356]|0)+36864|0;S=_+6|0;do{if((c[3542200]|0)!=0){W=p+108|0;c[W>>2]=0;X=p+100|0;c[X>>2]=0;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Y&16383](p,S)|0;if((c[W>>2]|0)==0){break}W=c[X>>2]|0;c[q>>2]=9534384;X=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[X&16383](q,S,0)|0;if((W|0)<1){break}gzL(V,0,S)|0}}while(0);S=(c[2420356]|0)+45056|0;V=_+7|0;do{if((c[3542200]|0)!=0){W=n+108|0;c[W>>2]=0;X=n+100|0;c[X>>2]=0;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Y&16383](n,V)|0;if((c[W>>2]|0)==0){break}W=c[X>>2]|0;c[o>>2]=9534384;X=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[X&16383](o,V,0)|0;if((W|0)<1){break}gzL(S,0,V)|0}}while(0);V=(c[2420356]|0)+53248|0;S=_|8;do{if((c[3542200]|0)!=0){W=l+108|0;c[W>>2]=0;X=l+100|0;c[X>>2]=0;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Y&16383](l,S)|0;if((c[W>>2]|0)==0){break}W=c[X>>2]|0;c[m>>2]=9534384;X=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[X&16383](m,S,0)|0;if((W|0)<1){break}gzL(V,0,S)|0}}while(0);S=c[2420354]|0;V=_+9|0;do{if((c[3542200]|0)!=0){W=j+108|0;c[W>>2]=0;X=j+100|0;c[X>>2]=0;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Y&16383](j,V)|0;if((c[W>>2]|0)==0){break}W=c[X>>2]|0;c[k>>2]=9534384;X=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[X&16383](k,V,0)|0;if((W|0)<1){break}gzL(S,0,V)|0}}while(0);V=c[2411226]|0;S=_+10|0;do{if((c[3542200]|0)!=0){W=f+108|0;c[W>>2]=0;X=f+100|0;c[X>>2]=0;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Y&16383](f,S)|0;if((c[W>>2]|0)==0){break}W=c[X>>2]|0;c[g>>2]=9534384;X=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[X&16383](g,S,0)|0;if((W|0)<1){break}gzL(V,0,S)|0}}while(0);fwR(0);S=c[2439330]|0;V=(S|0)==0;if(!V){W=S;gGC(9706056,W|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];W=c[3528484]|0;c[2076596]=W;X=c[2417276]|0;c[3541536]=X;c[1836236]=0;Y=c[2420350]|0;Z=0;$=0;while(1){c[S+76+($<<2)>>2]=Y+($<<8);aa=Z+1&65535;if((aa&65535)>127){ab=0;ac=0;break}else{Z=aa;$=aa&65535}}while(1){$=Y+(ac<<8)|0;c[S+76+(ac+512<<2)>>2]=$;c[S+76+(ac+768<<2)>>2]=$;$=ab+1&65535;if(($&65535)>127){ad=192;ae=192;break}else{ab=$;ac=$&65535}}while(1){c[S+76+(ae<<2)>>2]=Y+((ae<<8)-16384);$=ad+1&65535;if(($&65535)>223){af=192;ah=192;break}else{ad=$;ae=$&65535}}while(1){$=Y+((ah<<8)-16384)|0;c[S+76+(ah+512<<2)>>2]=$;c[S+76+(ah+768<<2)>>2]=$;$=af+1&65535;if(($&65535)>223){break}else{af=$;ah=$&65535}}Y=c[2420352]|0;$=Y+32768|0;c[S+588>>2]=$;Z=Y+33024|0;c[S+592>>2]=Z;aa=Y+33280|0;c[S+596>>2]=aa;ai=Y+33536|0;c[S+600>>2]=ai;aj=Y+33792|0;c[S+604>>2]=aj;ak=Y+34048|0;c[S+608>>2]=ak;al=Y+34304|0;c[S+612>>2]=al;am=Y+34560|0;c[S+616>>2]=am;an=Y+34816|0;c[S+620>>2]=an;ao=Y+35072|0;c[S+624>>2]=ao;ap=Y+35328|0;c[S+628>>2]=ap;aq=Y+35584|0;c[S+632>>2]=aq;ar=Y+35840|0;c[S+636>>2]=ar;as=Y+36096|0;c[S+640>>2]=as;at=Y+36352|0;c[S+644>>2]=at;au=Y+36608|0;c[S+648>>2]=au;c[S+1612>>2]=$;c[S+1616>>2]=Z;c[S+1620>>2]=aa;c[S+1624>>2]=ai;c[S+1628>>2]=aj;c[S+1632>>2]=ak;c[S+1636>>2]=al;c[S+1640>>2]=am;c[S+1644>>2]=an;c[S+1648>>2]=ao;c[S+1652>>2]=ap;c[S+1656>>2]=aq;c[S+1660>>2]=ar;c[S+1664>>2]=as;c[S+1668>>2]=at;c[S+1672>>2]=au;au=c[2406602]|0;c[S+652>>2]=au;at=au+256|0;c[S+656>>2]=at;as=au+512|0;c[S+660>>2]=as;ar=au+768|0;c[S+664>>2]=ar;c[S+1676>>2]=au;c[S+1680>>2]=at;c[S+1684>>2]=as;c[S+1688>>2]=ar;ar=c[2406608]|0;c[S+668>>2]=ar;as=ar+256|0;c[S+672>>2]=as;at=ar+512|0;c[S+676>>2]=at;au=ar+768|0;c[S+680>>2]=au;c[S+1692>>2]=ar;c[S+1696>>2]=as;c[S+1700>>2]=at;c[S+1704>>2]=au;au=c[2406606]|0;c[S+700>>2]=au;c[S+1724>>2]=au;au=Y+40448|0;c[S+708>>2]=au;c[S+1732>>2]=au;c[S+4180>>2]=2646;c[S+4184>>2]=1166;if(!V){au=S;gGC(au|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=W;c[2417276]=X;c[1836236]=-1;fwR(1);au=c[2439331]|0;Y=(au|0)==0;if(!Y){at=au;gGC(9706056,at|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];at=c[3528485]|0;c[2076596]=at;as=c[2417277]|0;c[3541536]=as;c[1836236]=1;ar=c[2411226]|0;aq=0;ap=0;while(1){c[au+76+(ap<<2)>>2]=ar+(ap<<8);ao=aq+1&65535;if((ao&65535)>31){av=0;aw=0;break}else{aq=ao;ap=ao&65535}}while(1){ap=ar+(aw<<8)|0;c[au+76+(aw+512<<2)>>2]=ap;c[au+76+(aw+768<<2)>>2]=ap;ap=av+1&65535;if((ap&65535)>31){break}else{av=ap;aw=ap&65535}}ar=c[2411228]|0;c[au+332>>2]=ar;ap=ar+256|0;c[au+336>>2]=ap;aq=ar+512|0;c[au+340>>2]=aq;X=ar+768|0;c[au+344>>2]=X;c[au+1356>>2]=ar;c[au+1360>>2]=ap;c[au+1364>>2]=aq;c[au+1368>>2]=X;c[au+2380>>2]=ar;c[au+3404>>2]=ar;c[au+2384>>2]=ap;c[au+3408>>2]=ap;c[au+2388>>2]=aq;c[au+3412>>2]=aq;c[au+2392>>2]=X;c[au+3416>>2]=X;c[au+1096>>2]=ar;c[au+2120>>2]=ar;c[au+3144>>2]=ar;c[au+4168>>2]=ar;c[au+4180>>2]=1958;c[au+4176>>2]=1020;if(!Y){ar=au;gGC(ar|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=at;c[2417277]=as;c[1836236]=-1;ar=c[2385374]|0;c[2439050]=ar;X=a[9688]|0?534:0;c[2439051]=ar+(X<<1);c[2439052]=ar+(X<<1<<1);c[2439053]=ar+((X*3|0)<<1);c[2439054]=ar+(X<<2<<1);c[2439055]=ar+((X*5|0)<<1);c[2439056]=ar+((X*6|0)<<1);c[2439057]=ar+((X*7|0)<<1);c[2439058]=ar+(X<<3<<1);X=a[9680]|0?32e3:0;c[3542220]=11200;ar=c[2113008]|0;if((ar|0)==0){gGz(14168888,0,252);c[3542223]=X;gGz(14168896,0,16);c[3542234]=~~((+(X|0)*32768.0*8.0+75.0e4)/15.0e5);aq=31;ax=32767.0;while(1){c[14169012+(aq<<2)>>2]=~~(ax+.5);ap=aq-1|0;if((ap|0)>0){aq=ap;ax=ax/1.188502227}else{break}}c[3542253]=0;h[1771269]=1.0;h[1771270]=1.0;h[1771271]=1.0;c[3542574]=3;c[3542575]=3;c[3542576]=3;mB(0);aq=(c[2113008]|0)+1|0;c[2113008]=aq;ay=aq;az=a[9680]|0?32e3:0}else{ay=ar;az=X}c[3542220]=11200;if((ay|0)==1){gGz(14169140,0,252);c[3542286]=az;gGz(14169148,0,16);c[3542297]=~~((+(az|0)*32768.0*8.0+75.0e4)/15.0e5);aq=31;ax=32767.0;while(1){c[14169264+(aq<<2)>>2]=~~(ax+.5);as=aq-1|0;if((as|0)>0){aq=as;ax=ax/1.188502227}else{break}}c[3542316]=0;h[1771272]=1.0;h[1771273]=1.0;h[1771274]=1.0;c[3542577]=3;c[3542578]=3;c[3542579]=3;mB(1);aq=(c[2113008]|0)+1|0;c[2113008]=aq;aA=aq;aB=a[9680]|0?32e3:0}else{aA=ay;aB=az}c[3542220]=11200;if((aA|0)==2){gGz(14169392,0,252);c[3542349]=aB;gGz(14169400,0,16);c[3542360]=~~((+(aB|0)*32768.0*8.0+75.0e4)/15.0e5);aq=31;ax=32767.0;while(1){c[14169516+(aq<<2)>>2]=~~(ax+.5);X=aq-1|0;if((X|0)>0){aq=X;ax=ax/1.188502227}else{break}}c[3542379]=0;h[1771275]=1.0;h[1771276]=1.0;h[1771277]=1.0;c[3542580]=3;c[3542581]=3;c[3542582]=3;mB(2);c[2113008]=(c[2113008]|0)+1}h[1771269]=.13;c[3542574]=3;h[1771270]=.13;c[3542575]=3;h[1771271]=.13;c[3542576]=3;h[1771272]=.13;c[3542577]=3;h[1771273]=.13;c[3542578]=3;h[1771274]=.13;c[3542579]=3;h[1771275]=.13;c[3542580]=3;h[1771276]=.13;c[3542581]=3;h[1771277]=.13;c[3542582]=3;c[3526944]=0;c[2415254]=0;aq=c[2439330]|0;X=(aq|0)==0;if(!X){ar=aq;gGC(9706056,ar|0,76)|0}ar=c[2438118]|0;c[2433530]=ar;as=c[3528484]|0;c[2076596]=as;at=c[2417276]|0;c[3541536]=at;c[1836236]=0;gGz(9706056,0,76);if(!X){X=aq;gGC(X|0,9706056,76)|0}c[2438118]=ar;c[3528484]=as;c[2417276]=at;c[1836236]=-1;at=c[2439331]|0;as=(at|0)==0;if(!as){ar=at;gGC(9706056,ar|0,76)|0}ar=c[2438119]|0;c[2433530]=ar;X=c[3528485]|0;c[2076596]=X;aq=c[2417277]|0;c[3541536]=aq;c[1836236]=1;gGz(9706056,0,76);if(!as){as=at;gGC(as|0,9706056,76)|0}c[2438119]=ar;c[3528485]=X;c[2417277]=aq;c[1836236]=-1;mB(0);mB(1);mB(2);aq=c[2420360]|0;X=c[2420356]|0;ar=0;do{as=ar<<3;at=as+4096|0;au=as+8192|0;Y=ar<<6|7;ap=0;do{W=Y-ap|0;S=0;V=d[X+(ap+as)|0]|0;ao=d[X+(at+ap)|0]|0;an=d[X+(au+ap)|0]|0;while(1){am=V<<2&4;al=(ao&1|0)==0?am:am|2;if((an&1|0)==0){aC=al&255}else{aC=(al|1)&255}a[aq+(W+(7-S<<3))|0]=aC;al=S+1|0;if((al|0)<8){S=al;V=V>>1;ao=ao>>1;an=an>>1}else{break}}ap=ap+1|0;}while((ap|0)<8);ar=ar+1|0;}while((ar|0)<512);ar=c[2406630]|0;aq=0;do{ap=aq<<3;au=ap+28672|0;at=ap+20480|0;as=ap+12288|0;ap=aq<<6|7;Y=0;do{an=ap-Y|0;ao=0;V=d[X+(au+Y)|0]|0;S=d[X+(at+Y)|0]|0;W=d[X+(as+Y)|0]|0;while(1){al=V<<2&4;am=(S&1|0)==0?al:al|2;if((W&1|0)==0){aD=am&255}else{aD=(am|1)&255}a[ar+(an+(7-ao<<3))|0]=aD;am=ao+1|0;if((am|0)<8){ao=am;V=V>>1;S=S>>1;W=W>>1}else{break}}Y=Y+1|0;}while((Y|0)<8);aq=aq+1|0;}while((aq|0)<1024);aq=c[2415128]|0;ar=0;do{Y=ar<<3;as=Y+36864|0;at=Y+45056|0;au=Y+53248|0;Y=ar<<6|7;ap=0;do{W=Y-ap|0;S=0;V=d[X+(as+ap)|0]|0;ao=d[X+(at+ap)|0]|0;an=d[X+(au+ap)|0]|0;while(1){am=V<<2&4;al=(ao&1|0)==0?am:am|2;if((an&1|0)==0){aE=al&255}else{aE=(al|1)&255}a[aq+(W+(7-S<<3))|0]=aE;al=S+1|0;if((al|0)<8){S=al;V=V>>1;ao=ao>>1;an=an>>1}else{break}}ap=ap+1|0;}while((ap|0)<8);ar=ar+1|0;}while((ar|0)<1024);ar=c[642608+(c[2436]<<2)>>2]|0;aq=c[ar+128>>2]|0;if((c[ar+52>>2]&4|0)==0){c[2113068]=aq;X=c[ar+132>>2]|0;c[2113070]=X;c[2443814]=aq;c[2440436]=X;aF=aq;aG=X}else{c[2113070]=aq;X=c[ar+132>>2]|0;c[2113068]=X;c[2440436]=aq;c[2443814]=X;aF=X;aG=aq}aq=ag(aF<<1,aG)|0;X=gGq(aq)|0;c[2112926]=X;if((X|0)!=0){gGz(X|0,0,aq|0)}c[3526944]=0;c[2415254]=0;aq=c[2439330]|0;X=(aq|0)==0;if(!X){ar=aq;gGC(9706056,ar|0,76)|0}ar=c[2438118]|0;c[2433530]=ar;ap=c[3528484]|0;c[2076596]=ap;au=c[2417276]|0;c[3541536]=au;c[1836236]=0;gGz(9706056,0,76);if(!X){X=aq;gGC(X|0,9706056,76)|0}c[2438118]=ar;c[3528484]=ap;c[2417276]=au;c[1836236]=-1;au=c[2439331]|0;ap=(au|0)==0;if(!ap){ar=au;gGC(9706056,ar|0,76)|0}ar=c[2438119]|0;c[2433530]=ar;X=c[3528485]|0;c[2076596]=X;aq=c[2417277]|0;c[3541536]=aq;c[1836236]=1;gGz(9706056,0,76);if(!ap){ap=au;gGC(ap|0,9706056,76)|0}c[2438119]=ar;c[3528485]=X;c[2417277]=aq;c[1836236]=-1;mB(0);mB(1);mB(2);aH=0;i=e;return aH|0}}while(0);c[2426760]=0;aH=1;i=e;return aH|0}function dEU(){var b=0,d=0,e=0,f=0;fwZ();c[2113008]=0;c[2076598]=0;c[2383582]=0;c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}b=c[2426760]|0;d=0;while(1){if((d|0)>=1024){e=8545;break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==(b|0)){break}else{d=d+1|0}}if((e|0)==8545){c[2426760]=0;a[6416720]=0;return 0}gGr(b);c[f>>2]=0;c[2426760]=0;a[6416720]=0;return 0}function dEV(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;if((a[9624480]|0)!=0){c[3526944]=0;c[2415254]=0;e=c[2439330]|0;f=(e|0)==0;if(!f){g=e;gGC(9706056,g|0,76)|0}g=c[2438118]|0;c[2433530]=g;h=c[3528484]|0;c[2076596]=h;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);if(!f){f=e;gGC(f|0,9706056,76)|0}c[2438118]=g;c[3528484]=h;c[2417276]=i;c[1836236]=-1;i=c[2439331]|0;h=(i|0)==0;if(!h){g=i;gGC(9706056,g|0,76)|0}g=c[2438119]|0;c[2433530]=g;f=c[3528485]|0;c[2076596]=f;e=c[2417277]|0;c[3541536]=e;c[1836236]=1;gGz(9706056,0,76);if(!h){h=i;gGC(h|0,9706056,76)|0}c[2438119]=g;c[3528485]=f;c[2417277]=e;c[1836236]=-1;mB(0);mB(1);mB(2)}a[6518264]=1;a[6518080]=1;c[2443978]=0;c[2444026]=0;e=0;f=0;L11455:while(1){g=f;while(1){if((g|0)>=10){break L11455}h=c[2439330]|0;if((h|0)!=0){i=h;gGC(9706056,i|0,76)|0}b[4853030]=c[2426515]&65535;i=c[2438118]|0;c[2433530]=i;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;j=g+1|0;k=(ag(a[6518264]|0?66666:0,j)|0)/10|0;l=c[2444026]|0;m=k-l|0;do{if((m|0)<1){n=0;o=l;p=i}else{if((a[h+4188|0]|0)==0){k=gfc(m)|0;q=(c[2433530]|0)+k|0;c[2433530]=q;n=k;o=c[2444026]|0;p=q;break}else{q=i+m|0;c[2433530]=q;n=m;o=l;p=q;break}}}while(0);c[2444026]=o+n;if((g|0)==1&(c[3526944]|0)!=0){if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;l=(c[2433530]|0)+12|0;c[2433530]=l;r=l}else{r=p}l=c[1836236]|0;m=c[9757320+(l<<2)>>2]|0;if((m|0)!=0){i=m;gGC(i|0,9706056,76)|0}c[9752472+(l<<2)>>2]=r;c[14113936+(l<<2)>>2]=c[2076596];c[9669104+(l<<2)>>2]=c[3541536];c[1836236]=-1;l=c[2439331]|0;if((l|0)!=0){i=l;gGC(9706056,i|0,76)|0}b[4853030]=c[2426515]&65535;i=c[2438119]|0;c[2433530]=i;c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;m=(ag(a[6518080]|0?5e4:0,j)|0)/10|0;h=c[2443978]|0;q=m-h|0;do{if((q|0)<1){s=0;t=h;u=1;v=l;w=i}else{if((a[l+4188|0]|0)==0){m=gfc(q)|0;k=(c[2433530]|0)+m|0;c[2433530]=k;x=c[1836236]|0;s=m;t=c[2443978]|0;u=x;v=c[9757320+(x<<2)>>2]|0;w=k;break}else{k=i+q|0;c[2433530]=k;s=q;t=h;u=1;v=l;w=k;break}}}while(0);c[2443978]=t+s;if((v|0)!=0){l=v;gGC(l|0,9706056,76)|0}c[9752472+(u<<2)>>2]=w;c[14113936+(u<<2)>>2]=c[2076596];c[9669104+(u<<2)>>2]=c[3541536];c[1836236]=-1;y=c[2112964]|0;if((y|0)==0){g=j}else{break}}g=a[9688]|0?534:0;mF(9756200,y+(e<<1<<1)|0,g-e|0,0);e=g;f=j}j=c[2112964]|0;do{if((j|0)!=0){f=a[9688]|0?534:0;if((f|0)==(e|0)){break}mF(9756200,j+(e<<1<<1)|0,f-e|0,0)}}while(0);e=c[2439331]|0;if((e|0)!=0){j=e;gGC(9706056,j|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;j=(c[2433530]|0)+12|0;c[2433530]=j;e=c[1836236]|0;f=c[9757320+(e<<2)>>2]|0;if((f|0)!=0){y=f;gGC(y|0,9706056,76)|0}c[9752472+(e<<2)>>2]=j;c[14113936+(e<<2)>>2]=c[2076596];c[9669104+(e<<2)>>2]=c[3541536];c[1836236]=-1;if((c[2112968]|0)==0){return 0}e=c[2112926]|0;gGz(e|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);j=c[2406606]|0;y=c[2388330]|0;f=0;do{u=(d[j+(f|1)|0]<<8|d[j+(f&-2)|0])&65535;w=u>>>4&15;v=u>>>8;c[y+(((f|0)/2|0)<<2)>>2]=(v<<4|v&8)>>>3&31|(u<<4|u&8)<<8&63488|(w<<4|w)<<3&2016;f=f+1|0;}while((f|0)<256);f=(c[2420352]|0)+40448|0;j=c[2420354]|0;w=c[2415128]|0;u=0;do{v=d[f]|0;s=(v<<9&3584)+u|0;if((v&16|0)==0){z=0}else{z=d[j+s|0]<<2}v=a[j+(s+256)|0]&15;s=15-((u|0)/16|0)<<4;t=s-16|0;r=((u|0)%16|0)<<4;p=s-8|0;if(t>>>0<215&r>>>0<246){Sq(e,z,p,r,v,3,0,0,w);s=r|8;Sq(e,z|1,p,s,v,3,0,0,w);Sq(e,z|2,t,r,v,3,0,0,w);Sq(e,z|3,t,s,v,3,0,0,w)}else{Sr(e,z,p,r,v,3,0,0,w);s=r|8;Sr(e,z|1,p,s,v,3,0,0,w);Sr(e,z|2,t,r,v,3,0,0,w);Sr(e,z|3,t,s,v,3,0,0,w)}u=u+1|0;}while((u|0)<256);u=c[2406602]|0;w=c[2406608]|0;z=c[2420360]|0;j=0;do{f=d[w+j|0]|0;v=f<<4&256|d[u+j|0];s=f&15;f=(31-((j|0)/32|0)<<3)-16|0;t=((j|0)%32|0)<<3;if(f>>>0<215&t>>>0<246){Sq(e,v,f,t,s,3,0,0,z)}else{Sr(e,v,f,t,s,3,0,0,z)}j=j+1|0;}while((j|0)<1024);j=c[2406604]|0;z=c[2406630]|0;u=92;do{w=a[j+(u|3)|0]|0;s=w&255;t=d[j+(u|2)|0]|0;f=d[j+(u|1)|0]|0;v=d[j+u|0]|0;r=f&15;p=t-16|0;do{if((v&128|0)==0){n=v<<2&508;o=(f&64|0)==0;g=(f&128|0)!=0;if(p>>>0<215&(w&255)<246){if(o){if(g){l=t-8|0;Ss(e,n|2,l,s,r,3,0,0,z);h=s+8|0;Ss(e,n|3,l,h,r,3,0,0,z);Ss(e,n,p,s,r,3,0,0,z);Ss(e,n|1,p,h,r,3,0,0,z);break}else{h=t-8|0;Sq(e,n,h,s,r,3,0,0,z);l=s+8|0;Sq(e,n|1,h,l,r,3,0,0,z);Sq(e,n|2,p,s,r,3,0,0,z);Sq(e,n|3,p,l,r,3,0,0,z);break}}else{if(g){l=t-8|0;Sw(e,n|3,l,s,r,3,0,0,z);h=s+8|0;Sw(e,n|2,l,h,r,3,0,0,z);Sw(e,n|1,p,s,r,3,0,0,z);Sw(e,n,p,h,r,3,0,0,z);break}else{h=t-8|0;Su(e,n|1,h,s,r,3,0,0,z);l=s+8|0;Su(e,n,h,l,r,3,0,0,z);Su(e,n|3,p,s,r,3,0,0,z);Su(e,n|2,p,l,r,3,0,0,z);break}}}else{if(o){if(g){o=t-8|0;St(e,n|2,o,s,r,3,0,0,z);l=s+8|0;St(e,n|3,o,l,r,3,0,0,z);St(e,n,p,s,r,3,0,0,z);St(e,n|1,p,l,r,3,0,0,z);break}else{l=t-8|0;Sr(e,n,l,s,r,3,0,0,z);o=s+8|0;Sr(e,n|1,l,o,r,3,0,0,z);Sr(e,n|2,p,s,r,3,0,0,z);Sr(e,n|3,p,o,r,3,0,0,z);break}}else{if(g){g=t-8|0;Sx(e,n|3,g,s,r,4,0,0,z);o=s+8|0;Sx(e,n|2,g,o,r,4,0,0,z);Sx(e,n|1,p,s,r,4,0,0,z);Sx(e,n,p,o,r,4,0,0,z);break}else{Sv(e,n|1,p,s,r,4,0,0,z);o=s+8|0;Sv(e,n,p,o,r,4,0,0,z);g=t-8|0;Sv(e,n|3,g,s,r,4,0,0,z);Sv(e,n|2,g,o,r,4,0,0,z);break}}}}else{o=v<<4&496;g=t-17|0;n=(f&192|0)==0;if(g>>>0<215&(w&255)<246){if(!n){break}l=t-9|0;h=t+7|0;Sq(e,o|512,h,s,r,3,0,0,z);q=s+8|0;Sq(e,o|513,h,q,r,3,0,0,z);i=t-1|0;Sq(e,o|514,i,s,r,3,0,0,z);Sq(e,o|515,i,q,r,3,0,0,z);k=s+16|0;Sq(e,o|516,h,k,r,3,0,0,z);x=s+24|0;Sq(e,o|517,h,x,r,3,0,0,z);Sq(e,o|518,i,k,r,3,0,0,z);Sq(e,o|519,i,x,r,3,0,0,z);Sq(e,o|520,l,s,r,3,0,0,z);Sq(e,o|521,l,q,r,3,0,0,z);Sq(e,o|522,g,s,r,3,0,0,z);Sq(e,o|523,g,q,r,3,0,0,z);Sq(e,o|524,l,k,r,3,0,0,z);Sq(e,o|525,l,x,r,3,0,0,z);Sq(e,o|526,g,k,r,3,0,0,z);Sq(e,o|527,g,x,r,3,0,0,z);break}else{if(!n){break}n=t-9|0;x=t+7|0;Sr(e,o|512,x,s,r,3,0,0,z);k=s+8|0;Sr(e,o|513,x,k,r,3,0,0,z);l=t-1|0;Sr(e,o|514,l,s,r,3,0,0,z);Sr(e,o|515,l,k,r,3,0,0,z);q=s+16|0;Sr(e,o|516,x,q,r,3,0,0,z);i=s+24|0;Sr(e,o|517,x,i,r,3,0,0,z);Sr(e,o|518,l,q,r,3,0,0,z);Sr(e,o|519,l,i,r,3,0,0,z);Sr(e,o|520,n,s,r,3,0,0,z);Sr(e,o|521,n,k,r,3,0,0,z);Sr(e,o|522,g,s,r,3,0,0,z);Sr(e,o|523,g,k,r,3,0,0,z);Sr(e,o|524,n,q,r,3,0,0,z);Sr(e,o|525,n,i,r,3,0,0,z);Sr(e,o|526,g,q,r,3,0,0,z);Sr(e,o|527,g,i,r,3,0,0,z);break}}}while(0);u=u-4|0;}while((u|0)>-1);R8(y);return 0}function dEW(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;d=i;i=i+96|0;e=d|0;f=d+16|0;g=d+32|0;h=d+48|0;j=d+64|0;k=d+80|0;if((b|0)!=0){c[b>>2]=169249}if((a&96|0)==0){i=d;return 0}gGz(k|0,0,12);b=c[2405684]|0;c[k>>2]=b;c[k+4>>2]=(c[2411736]|0)-b;c[k+12>>2]=162152;gj[c[2076592]&4095](k)|0;fw$(a);gGz(j|0,0,12);c[j>>2]=14107776;c[j+4>>2]=4;c[j+12>>2]=567192;gj[c[2076592]&4095](j)|0;gGz(h|0,0,12);c[h>>2]=9661016;c[h+4>>2]=4;c[h+12>>2]=102088;gj[c[2076592]&4095](h)|0;gGz(g|0,0,12);c[g>>2]=14166160;c[g+4>>2]=7;c[g+12>>2]=536672;gj[c[2076592]&4095](g)|0;gGz(f|0,0,12);c[f>>2]=14166152;c[f+4>>2]=7;c[f+12>>2]=523272;gj[c[2076592]&4095](f)|0;gGz(e|0,0,12);c[e>>2]=14168824;c[e+4>>2]=2;c[e+12>>2]=509640;gj[c[2076592]&4095](e)|0;i=d;return 0}function dEX(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4220788+(b*112|0)>>2];c[a+104>>2]=c[4220792+(b*112|0)>>2];c[a+108>>2]=c[4220796+(b*112|0)>>2];d=0;return d|0}function dEY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=4220688+(b*112|0);e=0;return e|0}function dEZ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2000900+(b*112|0)>>2];c[a+104>>2]=c[2000904+(b*112|0)>>2];c[a+108>>2]=c[2000908+(b*112|0)>>2];d=0;return d|0}function dE_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=2000800+(b*112|0);e=0;return e|0}function dE$(){a[6416720]=1;return dET()|0}function dE0(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((f&-256|0)!=527872){if((f|0)==1703936){g=(e[4775328]|0)>>>8&255;return g|0}else if((f|0)==1703937){g=b[4775328]&255;return g|0}else if((f|0)==1835008){g=(e[4775329]|0)>>>8&255;return g|0}else{g=0;return g|0}}h=f&254;f=c[2112932]|0;i=c[f+6156>>2]|0;if(i>>>0>9){j=(d[i+(h|513)|0]|0)<<8|(d[i+(h|512)|0]|0)}else{j=gj[c[f+196688+(i<<2)>>2]&4095](h|1576448)|0}i=j&65535;if((h|0)==82){c[2406762]=0;if((b[4775330]&3)==0){c[2385566]=0}f=i&65280;k=(f|34)&65535;l=c[2112932]|0;m=c[l+71692>>2]|0;if(m>>>0>9){a[m+594|0]=34;a[m+595|0]=(k&65535)>>>8&255}else{gg[c[l+196728+(m<<2)>>2]&4095](1576530,k)}k=e[4775330]|0;m=(c[2385566]|0)!=0;if(!((k&1|0)==0|m)){l=f&65535;n=c[2112932]|0;o=c[n+71692>>2]|0;if(o>>>0>9){a[o+580|0]=0;a[o+581|0]=(l&65535)>>>8&255}else{gg[c[n+196728+(o<<2)>>2]&4095](1576516,l)}c[2385566]=1;l=(d[9635288]|0)>>>3&1^1;o=(c[2385634]|0)+1|0;c[2385634]=o;if((o|0)==(d[614112+(l<<1)|0]|0|0)){c[2406762]=d[614113+(l<<1)|0]|0;c[2385634]=0;g=0;return g|0}else{c[2406762]=0;g=0;return g|0}}if((k&2|0)==0|m){g=0;return g|0}m=f&65535;f=c[2112932]|0;k=c[f+71692>>2]|0;if(k>>>0>9){a[k+580|0]=0;a[k+581|0]=(m&65535)>>>8&255}else{gg[c[f+196728+(k<<2)>>2]&4095](1576516,m)}c[2385566]=1;m=(d[9635288]|0)>>>3&1^1;k=(c[2385632]|0)+1|0;c[2385632]=k;if((k|0)==(d[614104+(m<<1)|0]|0|0)){c[2406762]=d[614105+(m<<1)|0]|0;c[2385632]=0;g=0;return g|0}else{c[2406762]=0;g=0;return g|0}}else if((h|0)==0){m=a[9635288]|0;k=c[2112932]|0;f=c[k+71692>>2]|0;if(f>>>0>9){a[f+512|0]=m;a[f+513|0]=(j&65535)>>>8&255;g=0;return g|0}else{gg[c[k+196728+(f<<2)>>2]&4095](1576448,m&255|j&-256);g=0;return g|0}}else if((h|0)==68){h=c[2406762]|0;j=(h|i&65280)&65535;i=c[2112932]|0;m=c[i+71692>>2]|0;if(m>>>0>9){a[m+580|0]=h&255;a[m+581|0]=(j&65535)>>>8&255;g=0;return g|0}else{gg[c[i+196728+(m<<2)>>2]&4095](1576516,j);g=0;return g|0}}else{g=0;return g|0}return 0}function dE1(b,d){b=b|0;d=d|0;if((b|0)!=1703937){return}a[c[3528300]|0]=d;return}function dE2(b){b=b|0;var d=0,e=0;if((b&255)!=1){d=0;return d|0}b=c[3542228]|0;if((b|0)>15){d=0;return d|0}do{if((b|0)==15){e=c[3542225]|0;if((e|0)==0){break}a[14168931]=gj[e&4095](0)|0}else if((b|0)==14){e=c[3542224]|0;if((e|0)==0){break}a[14168930]=gj[e&4095](0)|0}}while(0);d=a[14168916+b|0]|0;return d|0}function dE3(b,d){b=b|0;d=d|0;var e=0,f=0;e=b&65535;b=e&255;if((b|0)==0|(b|0)==1){f=d&255;if((e&1|0)==0){c[3542228]=f&15;return}e=c[3542228]|0;if((e|0)>15){return}do{if((e|0)<14){if((e|0)!=13){if((a[14168916+e|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(0,e,f);return}else if((b|0)==2){a[c[3528300]|0]=0;return}else{return}}function dE4(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2579268+(b*112|0)>>2];c[a+104>>2]=c[2579272+(b*112|0)>>2];c[a+108>>2]=c[2579276+(b*112|0)>>2];d=0;return d|0}function dE5(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=2579168+(b*112|0);e=0;return e|0}function dE6(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6930928+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dE7(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7440208+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dE8(){var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0.0,J=0,K=0;d=i;i=i+360|0;e=d|0;f=d+112|0;g=d+120|0;j=d+232|0;k=d+240|0;l=d+352|0;c[2415006]=0;c[2388176]=0;c[2385944]=262144;c[3531016]=294912;c[3530060]=294944;c[2414710]=295008;c[2388296]=295008;c[2386098]=303200;c[2386232]=305248;c[3528300]=338016;c[2411734]=338017;c[2439046]=338017;m=a[9688]|0?1068:0;n=m+338017|0;c[2439047]=n;o=n+m|0;c[2439048]=o;n=o+m|0;c[2414276]=n;m=n;n=0;while(1){if((n|0)>=1024){break}p=9638528+(n<<2)|0;if((c[p>>2]|0)==0){q=8776;break}else{n=n+1|0}}do{if((q|0)==8776){n=gGq(m)|0;c[p>>2]=n;if((n|0)==0){break}gGz(n|0,0,m|0);c[2415006]=n;gGz(n|0,0,m|0);c[2388176]=n;c[2385944]=n+262144;c[3531016]=n+294912;c[3530060]=n+294944;o=n+295008|0;c[2414710]=o;c[2388296]=o;c[2386098]=n+303200;c[2386232]=n+305248;c[3528300]=n+338016;o=n+338017|0;c[2411734]=o;c[2439046]=o;o=a[9688]|0?1068:0;r=o+338017|0;c[2439047]=n+r;s=r+o|0;c[2439048]=n+s;c[2414276]=n+(s+o);o=0;while(1){if((o|0)>=1024){t=0;break}u=9638528+(o<<2)|0;if((c[u>>2]|0)==0){q=8781;break}else{o=o+1|0}}do{if((q|0)==8781){o=gGq(65536)|0;c[u>>2]=o;if((o|0)==0){t=0;break}gGz(o|0,0,65536);t=o}}while(0);o=t+1|0;if((R6(o,0,2)|0)!=0){v=1;i=d;return v|0}if((R6(t,1,2)|0)!=0){v=1;i=d;return v|0}s=c[2388176]|0;gGC(s|0,t|0,32768)|0;n=s+131072|0;s=t+32768|0;gGC(n|0,s|0,32768)|0;if((R6(o,2,2)|0)!=0){v=1;i=d;return v|0}if((R6(t,3,2)|0)!=0){v=1;i=d;return v|0}n=c[2388176]|0;r=n+32768|0;gGC(r|0,t|0,32768)|0;r=n+163840|0;gGC(r|0,s|0,32768)|0;if((R6(o,4,2)|0)!=0){v=1;i=d;return v|0}if((R6(t,5,2)|0)!=0){v=1;i=d;return v|0}r=c[2388176]|0;n=r+65536|0;gGC(n|0,t|0,32768)|0;n=r+196608|0;gGC(n|0,s|0,32768)|0;if((R6(o,6,2)|0)!=0){v=1;i=d;return v|0}if((R6(t,7,2)|0)!=0){v=1;i=d;return v|0}o=c[2388176]|0;n=o+98304|0;gGC(n|0,t|0,32768)|0;n=o+229376|0;gGC(n|0,s|0,32768)|0;s=0;while(1){if((s|0)>=1024){break}w=9638528+(s<<2)|0;if((c[w>>2]|0)==(t|0)){q=8794;break}else{s=s+1|0}}if((q|0)==8794){gGr(t);c[w>>2]=0}s=c[2385944]|0;if((c[3542200]|0)==0){v=1;i=d;return v|0}n=k+108|0;c[n>>2]=0;o=k+100|0;c[o>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,8)|0;do{if((c[n>>2]|0)!=0){r=c[o>>2]|0;c[l>>2]=9534384;x=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[x&16383](l,8,0)|0;if((r|0)<1){v=1;i=d;return v|0}if((gzL(s,0,8)|0)==0){break}else{v=1}i=d;return v|0}}while(0);s=(c[2385944]|0)+16384|0;if((c[3542200]|0)==0){v=1;i=d;return v|0}o=g+108|0;c[o>>2]=0;n=g+100|0;c[n>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,9)|0;do{if((c[o>>2]|0)!=0){r=c[n>>2]|0;c[j>>2]=9534384;x=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[x&16383](j,9,0)|0;if((r|0)<1){v=1;i=d;return v|0}if((gzL(s,0,9)|0)==0){break}else{v=1}i=d;return v|0}}while(0);s=c[3531016]|0;if((c[3542200]|0)==0){v=1;i=d;return v|0}n=e+108|0;c[n>>2]=0;o=e+100|0;c[o>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,10)|0;do{if((c[n>>2]|0)!=0){r=c[o>>2]|0;c[f>>2]=9534384;x=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[x&16383](f,10,0)|0;if((r|0)<1){v=1;i=d;return v|0}if((gzL(s,0,10)|0)==0){break}else{v=1}i=d;return v|0}}while(0);dFd();fxU(0,425984);if((c[2394]|0)==0){y=c[2112932]|0}else{c[2394]=0;s=c[3532596]|0;c[2112932]=s;o=c[3532592]|0;if((o|0)!=0){gGC(9104152,o|0,280)|0}c[2113054]=c[2113060];y=s}s=c[2388176]|0;o=y|0;n=0;while(1){r=s+n|0;c[o>>2]=r;c[o+131072>>2]=r;r=n+1024|0;if(r>>>0>262143){break}else{o=o+4|0;n=r}}n=c[2386232]|0;o=y+4096|0;s=1048576;while(1){r=n+(s-1048576)|0;c[o>>2]=r;c[o+65536>>2]=r;c[o+131072>>2]=r;r=s+1024|0;if(r>>>0>1081343){break}else{o=o+4|0;s=r}}s=c[2388296]|0;c[y+6144>>2]=s;c[y+71680>>2]=s;c[y+137216>>2]=s;o=s+1024|0;c[y+6148>>2]=o;c[y+71684>>2]=o;c[y+137220>>2]=o;o=s+2048|0;c[y+6152>>2]=o;c[y+71688>>2]=o;c[y+137224>>2]=o;o=s+3072|0;c[y+6156>>2]=o;c[y+71692>>2]=o;c[y+137228>>2]=o;o=s+4096|0;c[y+6160>>2]=o;c[y+71696>>2]=o;c[y+137232>>2]=o;o=s+5120|0;c[y+6164>>2]=o;c[y+71700>>2]=o;c[y+137236>>2]=o;o=s+6144|0;c[y+6168>>2]=o;c[y+71704>>2]=o;c[y+137240>>2]=o;o=s+7168|0;c[y+6172>>2]=o;c[y+71708>>2]=o;c[y+137244>>2]=o;c[y+196648>>2]=864;c[y+196608>>2]=2260;o=c[3532592]|0;if((o|0)!=0){gGC(o|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);o=c[2439330]|0;s=(o|0)==0;if(!s){n=o;gGC(9706056,n|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];n=c[3528484]|0;c[2076596]=n;r=c[2417276]|0;c[3541536]=r;c[1836236]=0;x=c[2385944]|0;z=0;A=0;while(1){c[o+76+(A<<2)>>2]=x+(A<<8);B=z+1&65535;if((B&65535)>127){C=0;D=0;break}else{z=B;A=B&65535}}while(1){A=x+(D<<8)|0;c[o+76+(D+512<<2)>>2]=A;c[o+76+(D+768<<2)>>2]=A;A=C+1&65535;if((A&65535)>127){break}else{C=A;D=A&65535}}x=c[2386098]|0;c[o+588>>2]=x;A=x+256|0;c[o+592>>2]=A;z=x+512|0;c[o+596>>2]=z;B=x+768|0;c[o+600>>2]=B;E=x+1024|0;c[o+604>>2]=E;F=x+1280|0;c[o+608>>2]=F;G=x+1536|0;c[o+612>>2]=G;H=x+1792|0;c[o+616>>2]=H;c[o+1612>>2]=x;c[o+1616>>2]=A;c[o+1620>>2]=z;c[o+1624>>2]=B;c[o+1628>>2]=E;c[o+1632>>2]=F;c[o+1636>>2]=G;c[o+1640>>2]=H;c[o+2636>>2]=x;c[o+3660>>2]=x;c[o+2640>>2]=A;c[o+3664>>2]=A;c[o+2644>>2]=z;c[o+3668>>2]=z;c[o+2648>>2]=B;c[o+3672>>2]=B;c[o+2652>>2]=E;c[o+3676>>2]=E;c[o+2656>>2]=F;c[o+3680>>2]=F;c[o+2660>>2]=G;c[o+3684>>2]=G;c[o+2664>>2]=H;c[o+3688>>2]=H;c[o+4176>>2]=1872;c[o+4172>>2]=456;if(!s){H=o;gGC(H|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=n;c[2417276]=r;c[1836236]=-1;H=a[9680]|0?32e3:0;c[3542220]=11200;if((c[2113008]|0)==0){gGz(14168888,0,252);c[3542223]=H;c[3542224]=440;c[3542225]=0;c[3542226]=0;c[3542227]=0;c[3542234]=~~((+(H|0)*32768.0*8.0+1.0e6)/2.0e6);H=31;I=32767.0;while(1){c[14169012+(H<<2)>>2]=~~(I+.5);G=H-1|0;if((G|0)>0){H=G;I=I/1.188502227}else{break}}c[3542253]=0;h[1771269]=1.0;h[1771270]=1.0;h[1771271]=1.0;c[3542574]=3;c[3542575]=3;c[3542576]=3;mB(0);c[2113008]=(c[2113008]|0)+1}h[1771269]=.75;c[3542574]=3;h[1771270]=.75;c[3542575]=3;h[1771271]=.75;c[3542576]=3;H=c[642608+(c[2436]<<2)>>2]|0;r=c[H+128>>2]|0;if((c[H+52>>2]&4|0)==0){c[2113068]=r;n=c[H+132>>2]|0;c[2113070]=n;c[2443814]=r;c[2440436]=n;J=r;K=n}else{c[2113070]=r;n=c[H+132>>2]|0;c[2113068]=n;c[2440436]=r;c[2443814]=n;J=n;K=r}r=ag(J<<1,K)|0;n=gGq(r)|0;c[2112926]=n;if((n|0)!=0){gGz(n|0,0,r|0)}r=c[2414710]|0;gGz(r|0,0,(c[2411734]|0)-r|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];r=c[3532592]|0;if((r|0)!=0){gGC(9104152,r|0,280)|0}c[2113054]=c[2113060]}RI();r=c[2394]|0;n=c[14130368+(r<<2)>>2]|0;if((n|0)!=0){gGC(n|0,9104152,280)|0}c[8452240+(r<<2)>>2]=c[2113054];c[2394]=-1;r=c[2439330]|0;n=(r|0)==0;if(!n){H=r;gGC(9706056,H|0,76)|0}H=c[2438118]|0;c[2433530]=H;o=c[3528484]|0;c[2076596]=o;s=c[2417276]|0;c[3541536]=s;c[1836236]=0;gGz(9706056,0,76);if(!n){n=r;gGC(n|0,9706056,76)|0}c[2438118]=H;c[3528484]=o;c[2417276]=s;c[1836236]=-1;mB(0);c[2406762]=0;c[2385566]=0;c[2385634]=0;c[2385632]=0;v=0;i=d;return v|0}}while(0);c[2415006]=0;v=1;i=d;return v|0}function dE9(){var a=0,b=0,d=0,e=0,f=0;c[2113070]=0;c[2113068]=0;a=c[2112926]|0;if((a|0)!=0){gGr(a);c[2112926]=0}if((c[2392]|0)>=0){a=0;do{b=14130368+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}b=14130384+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}a=a+1|0;}while((a|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;fwZ();c[2113008]=0;c[2076598]=0;c[2383582]=0;a=c[2415006]|0;b=0;while(1){if((b|0)>=1024){e=8879;break}f=9638528+(b<<2)|0;if((c[f>>2]|0)==(a|0)){break}else{b=b+1|0}}if((e|0)==8879){c[2415006]=0;return 0}gGr(a);c[f>>2]=0;c[2415006]=0;return 0}function dFa(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if((a[9624472]|0)!=0){d=c[2414710]|0;gGz(d|0,0,(c[2411734]|0)-d|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;h=c[2417276]|0;c[3541536]=h;c[1836236]=0;gGz(9706056,0,76);if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=h;c[1836236]=-1;mB(0);c[2406762]=0;c[2385566]=0;c[2385634]=0;c[2385632]=0}gGz(9550656,0,6);h=0;g=0;f=0;e=0;do{g=((a[9633888+h|0]&1)<<h^g&65535)&65535;f=((a[9631688+h|0]&1)<<h^f&65535)&65535;e=((a[9629688+h|0]&1)<<h^e&65535)&65535;h=h+1|0;}while((h|0)<16);b[4775328]=g;b[4775329]=f;b[4775330]=e;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060]}e=c[2439330]|0;if((e|0)!=0){f=e;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;f=0;e=0;g=0;while(1){h=g+1|0;d=((h*15e4|0|0)/160|0)-e|0;c[2113056]=d;i=RG(d)|0;c[2113054]=(c[2113054]|0)+i;c[2276108]=-1;c[2113056]=-1;d=i+e|0;do{if((g|0)==159){c[8452200+(c[2394]<<2)>>2]=8193;c[2276080]=256;if((c[2276079]|0)>>>0>=256){break}RH(1)}else if((g|0)==0){c[8452200+(c[2394]<<2)>>2]=8194;c[2276080]=512;if((c[2276079]|0)>>>0>=512){break}RH(2)}}while(0);i=((h*66666|0|0)/160|0)-f|0;do{if((i|0)<1){j=0}else{if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){k=gfc(i)|0;c[2433530]=(c[2433530]|0)+k;j=k;break}else{c[2433530]=(c[2433530]|0)+i;j=i;break}}}while(0);a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0;if((h|0)<160){f=j+f|0;e=d;g=h}else{break}}g=c[1836236]|0;e=c[9757320+(g<<2)>>2]|0;if((e|0)!=0){f=e;gGC(f|0,9706056,76)|0}c[9752472+(g<<2)>>2]=c[2433530];c[14113936+(g<<2)>>2]=c[2076596];c[9669104+(g<<2)>>2]=c[3541536];c[1836236]=-1;g=c[2394]|0;f=c[14130368+(g<<2)>>2]|0;if((f|0)!=0){gGC(f|0,9104152,280)|0}c[8452240+(g<<2)>>2]=c[2113054];c[2394]=-1;g=c[2112964]|0;if((g|0)!=0){mF(9756184,g,a[9688]|0?534:0,0)}if((c[2112968]|0)==0){return 0}dFb()|0;return 0}function dFb(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((a[9547616]|0)!=0){dFd();a[9547616]=0}d=c[2386232]|0;e=c[2112926]|0;f=0;do{g=f>>>6&252;h=f&255;do{if((h-16|0)>>>0<=223){if((g-12|0)>>>0>228){break}i=b[d+(f<<1)>>1]|0;j=g-3724+(h*232|0)|0;k=(i&65535)>>>3;l=(i&65535)>>>6;m=(i&65535)>>>9;b[e+((j|3)<<1)>>1]=k&2|i&1|l&4|m&8;b[e+((j|2)<<1)>>1]=(i&65535)>>>4&2|(i&65535)>>>1&1|(i&65535)>>>7&4|(i&65535)>>>10&8;b[e+((j|1)<<1)>>1]=(i&65535)>>>5&2|(i&65535)>>>2&1|(i&65535)>>>8&4|(i&65535)>>>11&8;b[e+(j<<1)>>1]=l&2|k&1|m&4|(i&65535)>>>12&8}}while(0);f=f+1|0;}while((f|0)<16384);R8(c[3530060]|0);return 0}function dFc(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;e=i;i=i+160|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;l=e+80|0;m=e+96|0;n=e+112|0;o=e+128|0;p=e+144|0;q=(d|0)==0;if(!q){c[d>>2]=169249}if((b&96|0)==0){i=e;return 0}gGz(p|0,0,12);r=c[2414710]|0;c[p>>2]=r;c[p+4>>2]=(c[2411734]|0)-r;c[p+12>>2]=162152;gj[c[2076592]&4095](p)|0;p=k|0;r=(b&64|0)==0;do{if(!r){gGz(j|0,0,16);c[2394]=-1;if((c[2392]|0)<0){break}s=k+9|0;t=h;u=h|0;v=h+4|0;w=h+12|0;x=j|0;y=j+4|0;z=j+12|0;A=0;do{gGC(p|0,614896,11)|0;a[s]=A+48&255;B=8452256+(A<<2)|0;gGz(t|0,0,12);c[u>>2]=B;c[v>>2]=4;c[w>>2]=164976;gj[c[2076592]&4095](h)|0;if((c[B>>2]|0)!=0){c[x>>2]=c[14130368+(A<<2)>>2];c[y>>2]=c[8452184+(A<<2)>>2];c[z>>2]=p;B=c[2076592]|0;gj[B&4095](j)|0}A=A+1|0;}while((A|0)<=(c[2392]|0))}}while(0);fw$(b);b=g|0;do{if(!r){do{if(!q){if((c[d>>2]|0)>=169110){break}c[d>>2]=169110}}while(0);if((c[2113008]|0)<=0){break}g=f|0;j=f+4|0;p=f+8|0;h=f+12|0;k=0;do{cC(b|0,531144,(A=i,i=i+8|0,c[A>>2]=k,A)|0)|0;i=A;c[g>>2]=14168888+(k*252|0);c[j>>2]=252;c[p>>2]=0;c[h>>2]=b;gj[c[2076592]&4095](f)|0;k=k+1|0;}while((k|0)<(c[2113008]|0))}}while(0);gGz(o|0,0,12);c[o>>2]=9542264;c[o+4>>2]=4;c[o+12>>2]=480080;gj[c[2076592]&4095](o)|0;gGz(n|0,0,12);c[n>>2]=9542536;c[n+4>>2]=4;c[n+12>>2]=98752;gj[c[2076592]&4095](n)|0;gGz(m|0,0,12);c[m>>2]=9542528;c[m+4>>2]=4;c[m+12>>2]=76752;gj[c[2076592]&4095](m)|0;gGz(l|0,0,12);c[l>>2]=9627048;c[l+4>>2]=4;c[l+12>>2]=583920;gj[c[2076592]&4095](l)|0;i=e;return 0}function dFd(){var a=0,b=0,e=0,f=0;a=c[3531016]|0;b=c[3530060]|0;e=0;do{f=d[a+e|0]|0;c[b+(e<<2)>>2]=((((-(f>>>3&1)&4169)+(-(f>>>4&1)&7304)+(-(f>>>5&1)&14025)|0)>>>0)/100|0)<<3&2016|((((-(f>>>1&1)&7304)+(-(f&1)&4169)+(-(f>>>2&1)&14025)|0)>>>0)/100|0)<<8&63488|((((-(f>>>6&1)&8322)+(-(f>>>7)&15980)|0)>>>0)/100|0)>>>3&31;e=e+1|0;}while((e|0)<16);return}function dFe(b){b=b|0;return a[c[3528300]|0]|0}function dFf(b){b=b|0;var d=0;d=b-229376|0;b=((Tk((d|0)/2|0)|0)<<13|d&8191)^1;return a[(c[2430522]|0)+b|0]|0}function dFg(a,b){a=a|0;b=b|0;return}function dFh(a){a=a|0;var b=0;b=((gj[c[(c[2112932]|0)+196612>>2]&4095](a)|0)&255)<<8;return(gj[c[(c[2112932]|0)+196612>>2]&4095](a+1|0)|0)&255|b|0}function dFi(a,b){a=a|0;b=b|0;Tk((a-229376|0)/2|0)|0;return}function dFj(d){d=d|0;var e=0,f=0,g=0;e=d-8396800|0;if(e>>>0<4096){f=b[(c[2387858]|0)+(e>>>1<<1)>>1]&255;return f|0}if((d|0)==8400905){e=(a[638016]|0?64:0)|a[9625812];g=a[986992]|0?e^32:e;f=a[986976]|0?g^16:g;return f|0}else if((d|0)==8400911){a[986976]=0;c[8452200+(c[2394]<<2)>>2]=0;c[2276080]=0;f=a[9758128]|0;return f|0}else{f=0;return f|0}return 0}function dFk(d,e){d=d|0;e=e|0;var f=0;f=d-8396800|0;if(!(f>>>0<4096&a[2886608])){return}d=c[2387858]|0;a[2886608]=0;b[d+(f>>>1<<1)>>1]=e&255;return}function dFl(b){b=b|0;var e=0,f=0;switch(b|0){case 8400896:{e=~(d[9625808]|0);return e|0};case 8400904:{b=(a[638016]|0?64:0)|a[9625812];f=a[986992]|0?b^32:b;e=(a[986976]|0?f^16:f)&255|-256;return e|0};case 8400900:{e=~(d[9625810]|0);return e|0};case 8400910:{a[986976]=0;c[8452200+(c[2394]<<2)>>2]=0;c[2276080]=0;e=d[9758128]|0|-256;return e|0};case 8400902:{e=~(d[9625811]|0);return e|0};case 8400898:{e=~(d[9625809]|0);return e|0};default:{e=0;return e|0}}return 0}function dFm(d,e){d=d|0;e=e|0;var f=0,g=0;if((d|0)==9633792){b[7059604]=e&511;return}else if((d|0)==8401232){a[2886608]=1;return}else if((d|0)==8401184|(d|0)==8401198){f=b[4866888]|0;b[4866888]=e;if(((f^e)&1)==0){return}if((e&1)!=0){a[4039504]=0;return}c[3528556]=0;f=c[2433594]|0;c[2443776]=f;L12031:do{if((f|0)!=0){g=f|0;gGC(9660952,g|0,52)|0;switch(a[9660952]|0){case 3:{c[2309668]=639984;break L12031;break};case 5:{c[2309668]=7354992;break L12031;break};case 1:{c[2309668]=634096;break L12031;break};case 2:{c[2309668]=638960;break L12031;break};case 4:{c[2309668]=7356016;break L12031;break};case 0:{c[2309668]=638960;break L12031;break};default:{break L12031}}}}while(0);c[2113164]=c[2432850];gu[c[f+56>>2]&16383]();f=c[2443776]|0;if((f|0)!=0){g=f|0;gGC(g|0,9660952,52)|0}c[9731400+(c[3528556]<<2)>>2]=c[2113164];c[2443776]=0;c[3528556]=-1;a[4039504]=1;return}else if((d|0)==8401264){a[9759808]=e&255;a[986992]=1;c[3528556]=0;e=c[2433594]|0;c[2443776]=e;L12046:do{if((e|0)!=0){d=e|0;gGC(9660952,d|0,52)|0;switch(a[9660952]|0){case 0:{c[2309668]=638960;break L12046;break};case 3:{c[2309668]=639984;break L12046;break};case 5:{c[2309668]=7354992;break L12046;break};case 1:{c[2309668]=634096;break L12046;break};case 2:{c[2309668]=638960;break L12046;break};case 4:{c[2309668]=7356016;break L12046;break};default:{break L12046}}}}while(0);c[2113164]=c[2432850];d=gj[c[e+52>>2]&4095](100)|0;c[2113164]=(c[2113164]|0)+d;c[2443976]=(c[2443976]|0)+d;gg[c[(c[2443776]|0)+64>>2]&4095](32,1);gj[c[(c[2443776]|0)+52>>2]&4095](0)|0;gg[c[(c[2443776]|0)+64>>2]&4095](32,0);gj[c[(c[2443776]|0)+52>>2]&4095](0)|0;d=gj[c[(c[2443776]|0)+52>>2]&4095](100)|0;e=(c[2113164]|0)+d|0;c[2113164]=e;c[2443976]=(c[2443976]|0)+d;d=c[2443776]|0;if((d|0)!=0){g=d|0;gGC(g|0,9660952,52)|0}c[9731400+(c[3528556]<<2)>>2]=e;c[2443776]=0;c[3528556]=-1;return}else{return}}function dFn(b){b=b|0;var d=0;switch(b&65535|0){case 4144:case 4145:{b=a[986992]|0?-80:48;d=(a[986976]|0?b|64:b)&(a[9625812]<<1&16|-64);return d|0};case 4112:{a[986992]=0;d=a[9759808]|0;return d|0};case 4128:{d=~a[9625813];return d|0};case 6161:{d=c[(c[3531464]|0)+4240>>2]&255;return d|0};default:{d=0;return d|0}}return 0}function dFo(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;switch(b&65535|0){case 6160:{c[2113304]=d&255;return};case 6192:{gg[c[(c[2443776]|0)+64>>2]&4095](0,0);return};case 4096:case 4097:case 4098:case 4099:case 4100:case 4101:case 4102:case 4103:case 4104:case 4105:case 4106:case 4107:case 4108:case 4109:case 4110:case 4111:{a[9758128]=d;a[986976]=1;b=c[2394]|0;if((b|0)!=-1){c[8452200+(b<<2)>>2]=4102;c[2276080]=1536;if((c[2276079]|0)>>>0>=1536){return}RH(6);return}c[2394]=0;c[2112932]=c[3532596];b=c[3532592]|0;if((b|0)!=0){gGC(9104152,b|0,280)|0}c[2113054]=c[2113060];c[2113050]=4102;c[2276080]=1536;if((c[2276079]|0)>>>0<1536){RH(6);e=c[2394]|0;f=e;g=c[14130368+(e<<2)>>2]|0}else{f=0;g=b}if((g|0)!=0){gGC(g|0,9104152,280)|0}c[8452240+(f<<2)>>2]=c[2113054];c[2394]=-1;return};case 6161:{f=c[2113304]|0;a[14168504+f|0]=d;mv(0,f,d&255);return};default:{return}}}function dFp(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3920260+(b*112|0)>>2];c[a+104>>2]=c[3920264+(b*112|0)>>2];c[a+108>>2]=c[3920268+(b*112|0)>>2];d=0;return d|0}function dFq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=3920160+(b*112|0);e=0;return e|0}function dFr(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>29){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1256880+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dFs(){var b=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0;b=i;i=i+1320|0;e=b|0;f=b+112|0;g=b+120|0;j=b+232|0;k=b+240|0;l=b+352|0;m=b+360|0;n=b+472|0;o=b+480|0;p=b+592|0;q=b+600|0;r=b+712|0;s=b+720|0;t=b+832|0;u=b+840|0;v=b+952|0;w=b+960|0;x=b+1072|0;y=b+1080|0;z=b+1192|0;A=b+1200|0;B=b+1312|0;c[2426758]=0;c[3541542]=0;c[3527422]=524288;c[2405682]=589824;c[2388052]=589824;c[3527430]=602112;c[2387858]=606208;c[2437760]=610304;c[2438784]=618496;c[3527480]=626688;c[2443512]=630656;c[2439620]=630784;c[2411732]=632832;c[2406526]=632832;c[2429526]=698368;c[3530058]=1484800;C=0;while(1){if((C|0)>=1024){break}D=9638528+(C<<2)|0;if((c[D>>2]|0)==0){E=9079;break}else{C=C+1|0}}do{if((E|0)==9079){C=gGq(1488896)|0;c[D>>2]=C;if((C|0)==0){break}c[2426758]=C;gGz(C|0,0,1488896);c[3541542]=C;c[3527422]=C+524288;F=C+589824|0;c[2405682]=F;c[2388052]=F;c[3527430]=C+602112;c[2387858]=C+606208;c[2437760]=C+610304;c[2438784]=C+618496;c[3527480]=C+626688;c[2443512]=C+630656;c[2439620]=C+630784;F=C+632832|0;c[2411732]=F;c[2406526]=F;c[2429526]=C+698368;c[3530058]=C+1484800;c[2414274]=C+1488896;C=0;while(1){if((C|0)>=1024){G=0;break}H=9638528+(C<<2)|0;if((c[H>>2]|0)==0){E=9084;break}else{C=C+1|0}}do{if((E|0)==9084){C=gGq(393216)|0;c[H>>2]=C;if((C|0)==0){G=0;break}gGz(C|0,0,393216);G=C}}while(0);c[3529528]=G;if((R6((c[3541542]|0)+1|0,0,2)|0)!=0){I=1;i=b;return I|0}if((R6(c[3541542]|0,1,2)|0)!=0){I=1;i=b;return I|0}if((R6((c[3541542]|0)+229377|0,2,2)|0)!=0){I=1;i=b;return I|0}if((R6((c[3541542]|0)+229376|0,3,2)|0)!=0){I=1;i=b;return I|0}if((R6((c[3541542]|0)+262145|0,4,2)|0)!=0){I=1;i=b;return I|0}if((R6((c[3541542]|0)+262144|0,5,2)|0)!=0){I=1;i=b;return I|0}C=c[3541542]|0;F=C;J=C+32768|0;K=32768;while(1){L=K-1|0;M=a[F]|0;a[F]=a[J]|0;a[J]=M;if((L|0)==0){break}else{F=F+1|0;J=J+1|0;K=L}}K=C+262144|0;J=C+294912|0;F=32768;while(1){L=F-1|0;M=a[K]|0;a[K]=a[J]|0;a[J]=M;if((L|0)==0){break}else{K=K+1|0;J=J+1|0;F=L}}F=C+327680|0;J=C+360448|0;K=32768;while(1){L=K-1|0;M=a[F]|0;a[F]=a[J]|0;a[J]=M;if((L|0)==0){break}else{F=F+1|0;J=J+1|0;K=L}}K=C+393216|0;J=C+425984|0;F=32768;while(1){L=F-1|0;M=a[K]|0;a[K]=a[J]|0;a[J]=M;if((L|0)==0){break}else{K=K+1|0;J=J+1|0;F=L}}F=C+458752|0;J=C+491520|0;K=32768;while(1){L=K-1|0;M=a[F]|0;a[F]=a[J]|0;a[J]=M;if((L|0)==0){break}else{F=F+1|0;J=J+1|0;K=L}}K=c[3527422]|0;if((c[3542200]|0)==0){I=1;i=b;return I|0}J=A+108|0;c[J>>2]=0;F=A+100|0;c[F>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](A,6)|0;do{if((c[J>>2]|0)!=0){C=c[F>>2]|0;c[B>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](B,6,0)|0;if((C|0)<1){I=1;i=b;return I|0}if((gzL(K,0,6)|0)==0){break}else{I=1}i=b;return I|0}}while(0);K=(c[3527422]|0)+16384|0;if((c[3542200]|0)==0){I=1;i=b;return I|0}F=y+108|0;c[F>>2]=0;J=y+100|0;c[J>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](y,7)|0;do{if((c[F>>2]|0)!=0){C=c[J>>2]|0;c[z>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](z,7,0)|0;if((C|0)<1){I=1;i=b;return I|0}if((gzL(K,0,7)|0)==0){break}else{I=1}i=b;return I|0}}while(0);K=c[3529528]|0;if((c[3542200]|0)==0){I=1;i=b;return I|0}J=w+108|0;c[J>>2]=0;F=w+100|0;c[F>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](w,8)|0;do{if((c[J>>2]|0)!=0){C=c[F>>2]|0;c[x>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](x,8,0)|0;if((C|0)<1){I=1;i=b;return I|0}if((gzL(K,0,8)|0)==0){break}else{I=1}i=b;return I|0}}while(0);K=c[3529528]|0;F=c[2406526]|0;J=0;do{C=J<<6;gGz(F+C|0,0,64);L=J<<7;M=0;do{N=L+(c[6669224+(M<<2)>>2]|0)|0;O=(M<<3)+C|0;P=0;do{Q=N+(c[612480+(P<<2)>>2]|0)|0;if((d[K+((Q|0)/8|0)|0]&128>>>((Q&7)>>>0)|0)!=0){Q=F+(O+P)|0;a[Q]=a[Q]|2}P=P+1|0;}while((P|0)<8);M=M+1|0;}while((M|0)<8);M=L|4;P=0;do{O=M+(c[6669224+(P<<2)>>2]|0)|0;N=(P<<3)+C|0;Q=0;do{R=O+(c[612480+(Q<<2)>>2]|0)|0;if((d[K+((R|0)/8|0)|0]&128>>>((R&7)>>>0)|0)!=0){R=F+(N+Q)|0;a[R]=a[R]|1}Q=Q+1|0;}while((Q|0)<8);P=P+1|0;}while((P|0)<8);J=J+1|0;}while((J|0)<1024);gGz(K|0,0,393216);if((c[3542200]|0)==0){I=1;i=b;return I|0}J=u+108|0;c[J>>2]=0;F=u+100|0;c[F>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](u,9)|0;do{if((c[J>>2]|0)!=0){P=c[F>>2]|0;c[v>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](v,9,0)|0;if((P|0)<1){I=1;i=b;return I|0}if((gzL(K,0,9)|0)==0){break}else{I=1}i=b;return I|0}}while(0);K=(c[3529528]|0)+32768|0;if((c[3542200]|0)==0){I=1;i=b;return I|0}F=s+108|0;c[F>>2]=0;J=s+100|0;c[J>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](s,10)|0;do{if((c[F>>2]|0)!=0){P=c[J>>2]|0;c[t>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](t,10,0)|0;if((P|0)<1){I=1;i=b;return I|0}if((gzL(K,0,10)|0)==0){break}else{I=1}i=b;return I|0}}while(0);K=(c[3529528]|0)+98304|0;if((c[3542200]|0)==0){I=1;i=b;return I|0}J=q+108|0;c[J>>2]=0;F=q+100|0;c[F>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](q,11)|0;do{if((c[J>>2]|0)!=0){P=c[F>>2]|0;c[r>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](r,11,0)|0;if((P|0)<1){I=1;i=b;return I|0}if((gzL(K,0,11)|0)==0){break}else{I=1}i=b;return I|0}}while(0);K=(c[3529528]|0)+131072|0;if((c[3542200]|0)==0){I=1;i=b;return I|0}F=o+108|0;c[F>>2]=0;J=o+100|0;c[J>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](o,12)|0;do{if((c[F>>2]|0)!=0){P=c[J>>2]|0;c[p>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](p,12,0)|0;if((P|0)<1){I=1;i=b;return I|0}if((gzL(K,0,12)|0)==0){break}else{I=1}i=b;return I|0}}while(0);K=(c[3529528]|0)+196608|0;if((c[3542200]|0)==0){I=1;i=b;return I|0}J=m+108|0;c[J>>2]=0;F=m+100|0;c[F>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,13)|0;do{if((c[J>>2]|0)!=0){P=c[F>>2]|0;c[n>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](n,13,0)|0;if((P|0)<1){I=1;i=b;return I|0}if((gzL(K,0,13)|0)==0){break}else{I=1}i=b;return I|0}}while(0);K=(c[3529528]|0)+229376|0;if((c[3542200]|0)==0){I=1;i=b;return I|0}F=k+108|0;c[F>>2]=0;J=k+100|0;c[J>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,14)|0;do{if((c[F>>2]|0)!=0){P=c[J>>2]|0;c[l>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](l,14,0)|0;if((P|0)<1){I=1;i=b;return I|0}if((gzL(K,0,14)|0)==0){break}else{I=1}i=b;return I|0}}while(0);K=(c[3529528]|0)+294912|0;if((c[3542200]|0)==0){I=1;i=b;return I|0}J=g+108|0;c[J>>2]=0;F=g+100|0;c[F>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,15)|0;do{if((c[J>>2]|0)!=0){P=c[F>>2]|0;c[j>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](j,15,0)|0;if((P|0)<1){I=1;i=b;return I|0}if((gzL(K,0,15)|0)==0){break}else{I=1}i=b;return I|0}}while(0);K=(c[3529528]|0)+327680|0;if((c[3542200]|0)==0){I=1;i=b;return I|0}F=e+108|0;c[F>>2]=0;J=e+100|0;c[J>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,16)|0;do{if((c[F>>2]|0)!=0){P=c[J>>2]|0;c[f>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](f,16,0)|0;if((P|0)<1){I=1;i=b;return I|0}if((gzL(K,0,16)|0)==0){break}else{I=1}i=b;return I|0}}while(0);K=c[3529528]|0;J=0;do{F=K+J|0;a[F]=~a[F];J=J+1|0;}while(J>>>0<393216);J=c[2429526]|0;F=0;while(1){P=F<<6;gGz(J+P|0,0,64);C=0;do{M=1<<3-C;L=(c[5298976+(C<<2)>>2]|0)+P|0;Q=0;do{N=L+(c[1238464+(Q<<2)>>2]|0)|0;O=(Q<<3)+P|0;R=0;do{S=N+(c[614800+(R<<2)>>2]|0)|0;if((d[K+((S|0)/8|0)|0]&128>>>((S&7)>>>0)|0)!=0){S=J+(O+R)|0;a[S]=(d[S]|M)&255}R=R+1|0;}while((R|0)<8);Q=Q+1|0;}while((Q|0)<8);C=C+1|0;}while((C|0)<4);C=F+1|0;if((C|0)<12288){F=C}else{T=0;break}}while(1){if((T|0)>=1024){break}U=9638528+(T<<2)|0;if((c[U>>2]|0)==(K|0)){E=9168;break}else{T=T+1|0}}if((E|0)==9168){gGr(K);c[U>>2]=0}c[3529528]=0;fxU(0,426e3);if((c[2394]|0)==0){V=c[2112932]|0}else{c[2394]=0;F=c[3532596]|0;c[2112932]=F;J=c[3532592]|0;if((J|0)!=0){gGC(9104152,J|0,280)|0}c[2113054]=c[2113060];V=F}F=c[3541542]|0;J=V|0;C=0;while(1){P=F+C|0;c[J>>2]=P;c[J+131072>>2]=P;P=C+1024|0;if(P>>>0>524287){break}else{J=J+4|0;C=P}}C=c[2437760]|0;c[V+36864>>2]=C;c[V+102400>>2]=C;c[V+167936>>2]=C;J=C+1024|0;c[V+36868>>2]=J;c[V+102404>>2]=J;c[V+167940>>2]=J;J=C+2048|0;c[V+36872>>2]=J;c[V+102408>>2]=J;c[V+167944>>2]=J;J=C+3072|0;c[V+36876>>2]=J;c[V+102412>>2]=J;c[V+167948>>2]=J;J=C+4096|0;c[V+36880>>2]=J;c[V+102416>>2]=J;c[V+167952>>2]=J;J=C+5120|0;c[V+36884>>2]=J;c[V+102420>>2]=J;c[V+167956>>2]=J;J=C+6144|0;c[V+36888>>2]=J;c[V+102424>>2]=J;c[V+167960>>2]=J;J=C+7168|0;c[V+36892>>2]=J;c[V+102428>>2]=J;c[V+167964>>2]=J;J=c[2438784]|0;c[V+36896>>2]=J;c[V+102432>>2]=J;c[V+167968>>2]=J;C=J+1024|0;c[V+36900>>2]=C;c[V+102436>>2]=C;c[V+167972>>2]=C;C=J+2048|0;c[V+36904>>2]=C;c[V+102440>>2]=C;c[V+167976>>2]=C;C=J+3072|0;c[V+36908>>2]=C;c[V+102444>>2]=C;c[V+167980>>2]=C;C=J+4096|0;c[V+36912>>2]=C;c[V+102448>>2]=C;c[V+167984>>2]=C;C=J+5120|0;c[V+36916>>2]=C;c[V+102452>>2]=C;c[V+167988>>2]=C;C=J+6144|0;c[V+36920>>2]=C;c[V+102456>>2]=C;c[V+167992>>2]=C;C=J+7168|0;c[V+36924>>2]=C;c[V+102460>>2]=C;c[V+167996>>2]=C;C=c[2388052]|0;J=C+8192|0;c[V+36928>>2]=J;c[V+102464>>2]=J;c[V+168e3>>2]=J;J=C+9216|0;c[V+36932>>2]=J;c[V+102468>>2]=J;c[V+168004>>2]=J;J=C+10240|0;c[V+36936>>2]=J;c[V+102472>>2]=J;c[V+168008>>2]=J;J=C+11264|0;c[V+36940>>2]=J;c[V+102476>>2]=J;c[V+168012>>2]=J;J=c[3527480]|0;c[V+36944>>2]=J;c[V+102480>>2]=J;c[V+168016>>2]=J;C=J+1024|0;c[V+36948>>2]=C;c[V+102484>>2]=C;c[V+168020>>2]=C;C=J+2048|0;c[V+36952>>2]=C;c[V+102488>>2]=C;c[V+168024>>2]=C;C=(c[2443512]|0)-896|0;c[V+36956>>2]=C;c[V+102492>>2]=C;c[V+168028>>2]=C;C=c[2439620]|0;c[V+37120>>2]=C;c[V+102656>>2]=C;c[V+168192>>2]=C;J=C+1024|0;c[V+37124>>2]=J;c[V+102660>>2]=J;c[V+168196>>2]=J;c[V+196608>>2]=2642;c[V+196648>>2]=1444;c[V+196688>>2]=1064;c[V+196728>>2]=2014;J=c[3532592]|0;if((J|0)!=0){gGC(J|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fvI();c[3528556]=0;J=c[2433594]|0;c[2443776]=J;L12334:do{if((J|0)!=0){C=J|0;gGC(9660952,C|0,52)|0;switch(a[9660952]|0){case 0:{c[2309668]=638960;break L12334;break};case 5:{c[2309668]=7354992;break L12334;break};case 2:{c[2309668]=638960;break L12334;break};case 1:{c[2309668]=634096;break L12334;break};case 3:{c[2309668]=639984;break L12334;break};case 4:{c[2309668]=7356016;break L12334;break};default:{break L12334}}}}while(0);C=c[2432850]|0;c[2113164]=C;F=c[3527430]|0;K=0;P=0;while(1){Q=F+(P<<8)|0;c[J+68+(P<<2)>>2]=Q;c[J+68+(P+256<<2)>>2]=Q;c[J+68+(P+512<<2)>>2]=Q;Q=K+1&65535;if((Q&65535)>15){break}else{K=Q;P=Q&65535}}P=c[3527422]|0;K=64;F=64;while(1){Q=P+((F<<8)-16384)|0;c[J+68+(F<<2)>>2]=Q;c[J+68+(F+512<<2)>>2]=Q;Q=K+1&65535;if((Q&65535)>255){break}else{K=Q;F=Q&65535}}c[J+3148>>2]=2670;c[J+3152>>2]=1786;F=J|0;gGC(F|0,9660952,52)|0;c[2432850]=C;c[2443776]=0;c[3528556]=-1;a[9717208]=104;c[2430522]=0;gGC(9553936,6996144,144)|0;a[9660536]=0;a[9771528]=3;a[14115672]=(c[2392]|0)!=-1|0;if((c[2394]|0)==0){W=c[2112932]|0}else{c[2394]=0;F=c[3532596]|0;c[2112932]=F;K=c[3532592]|0;if((K|0)!=0){gGC(9104152,K|0,280)|0}c[2113054]=c[2113060];W=F}F=W+896|0;K=229376;while(1){c[F>>2]=1;c[F+65536>>2]=1;c[F+131072>>2]=1;P=K+1024|0;if(P>>>0>262143){break}else{F=F+4|0;K=P}}c[W+196612>>2]=2434;c[W+196692>>2]=2766;c[W+196652>>2]=2568;c[W+196732>>2]=2790;K=c[3532592]|0;if((K|0)!=0){gGC(K|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;K=0;while(1){if((K|0)>=1024){X=0;break}Y=9638528+(K<<2)|0;if((c[Y>>2]|0)==0){E=9202;break}else{K=K+1|0}}do{if((E|0)==9202){K=gGq(32768)|0;c[Y>>2]=K;if((K|0)==0){X=0;break}gGz(K|0,0,32768);X=K}}while(0);c[2430522]=X;K=(c[3541542]|0)+229376|0;gGC(X|0,K|0,32768)|0;gGz(c[2387858]|0,-1|0,4096);K=a[9680]|0;F=K?32e3:0;if(K){if(a[9624]|0){K=F*3|0;C=55930;while(1){if((C|0)>(K|0)){C=C>>1}else{Z=1222;_=C;break}}}else{Z=2462;_=F}c[2429380]=_;c[3542124]=Z;mw(3579545,_);C=gGq(262144)|0;c[2406684]=C;gGz(C|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(3579545,11025)}h[745421]=.48;c[2436794]=2;h[745420]=.48;c[2436792]=1;C=c[642608+(c[2436]<<2)>>2]|0;K=c[C+128>>2]|0;if((c[C+52>>2]&4|0)==0){c[2113068]=K;J=c[C+132>>2]|0;c[2113070]=J;c[2443814]=K;c[2440436]=J;$=K;aa=J}else{c[2113070]=K;J=c[C+132>>2]|0;c[2113068]=J;c[2440436]=K;c[2443814]=J;$=J;aa=K}K=ag($<<1,aa)|0;J=gGq(K)|0;c[2112926]=J;if((J|0)!=0){gGz(J|0,0,K|0)}c[2409630]=591552;K=(c[147888]|0)*600|0;J=0;while(1){if((J|0)>=1024){E=9219;break}ab=9638528+(J<<2)|0;if((c[ab>>2]|0)==0){E=9218;break}else{J=J+1|0}}do{if((E|0)==9218){J=gGq(K)|0;c[ab>>2]=J;if((J|0)==0){E=9219;break}gGz(J|0,0,K|0);F=J;c[3525360]=F;c[2433680]=F;c[2432968]=0}}while(0);if((E|0)==9219){c[3525360]=0}a[7303760]=0;dGi();I=0;i=b;return I|0}}while(0);c[2426758]=0;I=1;i=b;return I|0}function dFt(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;if((c[2392]|0)>=0){d=0;do{e=14130368+(d<<2)|0;f=c[e>>2]|0;if((f|0)!=0){gGr(f);c[e>>2]=0}e=14130384+(d<<2)|0;f=c[e>>2]|0;if((f|0)!=0){gGr(f);c[e>>2]=0}d=d+1|0;}while((d|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;fvR();d=c[3531464]|0;c[d+44344>>2]=0;c[d+44348>>2]=0;if((d|0)!=0){gGr(d);c[3531464]=0}d=c[2406684]|0;if((d|0)!=0){gGr(d);c[2406684]=0}c[2113070]=0;c[2113068]=0;d=c[2112926]|0;if((d|0)!=0){gGr(d);c[2112926]=0}d=c[3525360]|0;e=0;while(1){if((e|0)>=1024){break}g=9638528+(e<<2)|0;if((c[g>>2]|0)==(d|0)){h=9285;break}else{e=e+1|0}}if((h|0)==9285){gGr(d);c[g>>2]=0}c[3525360]=0;g=c[2430522]|0;d=0;while(1){if((d|0)>=1024){break}i=9638528+(d<<2)|0;if((c[i>>2]|0)==(g|0)){h=9289;break}else{d=d+1|0}}if((h|0)==9289){gGr(g);c[i>>2]=0}c[2430522]=0;i=c[2426758]|0;g=0;while(1){if((g|0)>=1024){h=9295;break}j=9638528+(g<<2)|0;if((c[j>>2]|0)==(i|0)){break}else{g=g+1|0}}if((h|0)==9295){c[2426758]=0;a[638016]=0;b[4866888]=0;a[4039504]=0;a[7303760]=0;return 0}gGr(i);c[j>>2]=0;c[2426758]=0;a[638016]=0;b[4866888]=0;a[4039504]=0;a[7303760]=0;return 0}function dFu(){var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0;f=i;i=i+1032|0;g=f|0;h=f+1024|0;if((a[9624464]|0)!=0){dGi()}a[9625813]=0;c[2406452]=0;a[9625812]=8;if((a[9758715]|0)==0){j=0;k=0;l=0;m=0;n=0;o=0}else{a[9625812]=0;j=0;k=0;l=0;m=0;n=0;o=0}do{k=((a[9759208+j|0]&1)<<j|k&255)&255;l=((a[9759016+j|0]&1)<<j|l&255)&255;m=((a[9758832+j|0]&1)<<j|m&255)&255;n=((a[9758752+j|0]&1)<<j|n&255)&255;o=((a[9758680+j|0]&1)<<j|o&255)&255;j=j+1|0;}while((j|0)<8);a[9625808]=k;a[9625809]=l;a[9625810]=m;a[9625811]=n;a[9625813]=o;if((k&48)==48){o=k&-49;a[9625808]=o;p=o}else{p=k}if((p&-64)<<24>>24==-64){a[9625808]=p&63}if((l&48)==48){p=l&-49;a[9625809]=p;q=p}else{q=l}if((q&-64)<<24>>24==-64){a[9625809]=q&63}if((m&48)==48){q=m&-49;a[9625810]=q;r=q}else{r=m}if((r&-64)<<24>>24==-64){a[9625810]=r&63}if((n&48)==48){r=n&-49;a[9625811]=r;s=r}else{s=n}if((s&-64)<<24>>24==-64){a[9625811]=s&63}a[6518256]=1;a[6518072]=1;c[2443976]=0;c[2444024]=0;s=c[2392]|0;if((s|0)>=0){gGz(8452240,0,((s|0)>0?(s<<2)+4|0:4)|0)}c[2113054]=0;s=b[(c[3527480]|0)+3950>>1]|0;n=s&3;a[14109024]=n;b[7059588]=(s&65535)>>>7;do{if(a[7303760]|0){if(n<<24>>24!=3){break}a[14109024]=0}else{if((n&255)<=1){break}a[14109024]=n-2&255}}while(0);n=g|0;s=h|0;r=h+2|0;m=h+4|0;q=h+6|0;l=0;p=0;k=0;L12479:while(1){o=p;j=k;while(1){if((j|0)>=262){break L12479}if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];t=c[3532592]|0;if((t|0)!=0){gGC(9104152,t|0,280)|0}c[2113054]=c[2113060]}u=j+1|0;t=(ag(a[6518256]|0?119318:0,u)|0)/262|0;v=t-(c[2444024]|0)|0;c[2113056]=v;t=RG(v)|0;c[2113054]=(c[2113054]|0)+t;c[2276108]=-1;c[2113056]=-1;c[2444024]=(c[2444024]|0)+t;do{if((j|0)==250){a[638016]=1}else if((j|0)==11){a[638016]=0}else if((j|0)==261){c[8452200+(c[2394]<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0>=1024){break}RH(4)}}while(0);t=c[2394]|0;v=c[14130368+(t<<2)>>2]|0;if((v|0)!=0){gGC(v|0,9104152,280)|0}c[8452240+(t<<2)>>2]=c[2113054];c[2394]=-1;do{if((j|0)==(o|0)){t=b[7059588]|0;v=(((t<<16>>16)+j|0)/8|0)<<1&126;w=c[2443512]|0;x=d[w+(v|1)|0]<<8&768|d[w+v|0];v=c[2438784]|0;w=c[2409630]|0;y=c[w+4>>2]|0;z=c[w+8>>2]|0;A=c[w+12>>2]|0;do{if((j|0)<1){B=c[3525360]|0;c[2433680]=B;c[2432968]=0;C=B;D=0;E=0}else{B=c[2432968]|0;F=c[2433680]|0;if((B|0)==0){C=F;D=0;E=0;break}G=(e[B>>1]|0)==(j|0);C=G?B:F;D=G&1^1;E=B}}while(0);gGz(n|0,0,1024);B=g+x|0;L12506:do{if((a[B]|0)==0){G=j&65535;F=z+1|0;H=z<<1;I=H|1;J=z*3|0;K=J+1|0;L=h+(A<<1)|0;M=c[3525360]|0;N=w+16|0;O=w+20|0;P=w+24|0;Q=D;R=C;S=E;T=x;U=B;while(1){V=ag(T,y)|0;if((R-M>>1|0)>=((c[w>>2]|0)*150|0|0)){W=Q;X=R;break L12506}b[R>>1]=G;Y=d[v+(V+1)|0]<<8|d[v+V|0];b[R+2>>1]=Y;b[s>>1]=Y;Y=d[v+(F+V)|0]<<8|d[v+(V+z)|0];b[R+4>>1]=Y;b[r>>1]=Y;Y=d[v+(V+I)|0]<<8|d[v+(V+H)|0];b[R+6>>1]=Y;b[m>>1]=Y;Y=d[v+(K+V)|0]<<8|d[v+(V+J)|0];V=R+10|0;b[R+8>>1]=Y;b[q>>1]=Y;L12511:do{if((b[L>>1]|0)==-1){Z=S;_=R;$=Q}else{if((Q|0)==0){Z=S;_=V;$=0;break}aa=S+4|0;do{if((b[S+2>>1]|0)==(b[s>>1]|0)){ab=S+6|0;if((b[aa>>1]|0)!=(b[r>>1]|0)){ac=ab;break}ad=S+8|0;if((b[ab>>1]|0)!=(b[m>>1]|0)){ac=ad;break}ab=S+10|0;if((b[ad>>1]|0)==Y<<16>>16){Z=ab;_=V;$=Q;break L12511}else{ac=ab}}else{ac=aa}}while(0);Z=ac;_=V;$=0}}while(0);a[U]=1;V=c[N>>2]|0;if((V|0)>-1){ae=(e[h+(V<<1)>>1]|0)>>>((c[O>>2]|0)>>>0)&c[P>>2]}else{ae=c[P>>2]&T+1}V=g+ae|0;if((a[V]|0)==0){Q=$;R=_;S=Z;T=ae;U=V}else{W=$;X=_;break}}}else{W=D;X=C}}while(0);if((W|0)==0){c[2433680]=X;c[2432968]=C}if((j|0)==0){af=8-(t&7)|0;break}else{af=j+8|0;break}}else{af=o}}while(0);if(!(a[4039504]|0)){c[3528556]=0;v=c[2433594]|0;c[2443776]=v;L12534:do{if((v|0)!=0){z=v|0;gGC(9660952,z|0,52)|0;switch(a[9660952]|0){case 0:{c[2309668]=638960;break L12534;break};case 1:{c[2309668]=634096;break L12534;break};case 3:{c[2309668]=639984;break L12534;break};case 4:{c[2309668]=7356016;break L12534;break};case 5:{c[2309668]=7354992;break L12534;break};case 2:{c[2309668]=638960;break L12534;break};default:{break L12534}}}}while(0);c[2113164]=c[2432850];z=(ag(a[6518072]|0?29829:0,u)|0)/262|0;w=gj[c[v+52>>2]&4095](z-(c[2443976]|0)|0)|0;c[2113164]=(c[2113164]|0)+w;c[2443976]=(c[2443976]|0)+w;if((j|0)==256|(j|0)==192|(j|0)==128|(j|0)==64){gg[c[(c[2443776]|0)+64>>2]&4095](0,1)}w=c[2443776]|0;if((w|0)!=0){z=w|0;gGC(z|0,9660952,52)|0}c[9731400+(c[3528556]<<2)>>2]=c[2113164];c[2443776]=0;c[3528556]=-1}ah=c[2112964]|0;if((ah|0)==0){o=af;j=u}else{break}}j=a[9688]|0?2:0;gg[c[3542124]&4095](ah+(l<<1<<1)|0,j);l=j+l|0;p=af;k=u}u=c[2112964]|0;do{if((u|0)!=0){k=a[9688]|0?534:0;if((k|0)==(l|0)){break}gg[c[3542124]&4095](u+(l<<1<<1)|0,k-l|0)}}while(0);if((c[2112968]|0)==0){i=f;return 0}l=c[2112926]|0;gGz(l|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);u=c[3530058]|0;k=0;af=c[2439620]|0;p=u;while(1){ah=e[af>>1]|0;C=d[591736+(ah>>>12)|0]|0;X=ag(C,ah&15)|0;W=(ag(ah&3840,C)|0)&63488;c[p>>2]=X>>>3&31|W|(ag(ah>>>4<<3&120,C)|0)&2016;C=k+1|0;if((C|0)<1024){k=C;af=af+2|0;p=p+4|0}else{break}}dGj(0);dGj(1);p=c[3525360]|0;af=b[7059604]|0;k=c[2433680]|0;if(p>>>0<k>>>0){C=(c[2113070]|0)-1|0;ah=(e[(c[3527480]|0)+3950>>1]|0)>>>7;W=(c[2409630]|0)+28|0;X=c[2429526]|0;D=C;_=p;while(1){p=b[_>>1]|0;$=p&65535;ae=_;while(1){if(ae>>>0>=k>>>0){ai=D;break}aj=b[ae>>1]|0;if(aj<<16>>16==p<<16>>16){ae=ae+10|0}else{ak=9391;break}}if((ak|0)==9391){ak=0;ai=aj&65535}p=(ae|0)==(k|0)?C:ai;if((c[W>>2]|0)==0){al=5;am=ae;an=_}else{al=-5;am=_-10|0;an=ae-10|0}if((an|0)!=(am|0)){Z=$-8|0;g=an;do{h=e[g+4>>1]|0;ac=h&15|16;m=(h>>>7)-af|0;h=e[g+6>>1]|0;r=(h&7)+1|0;s=h>>>3&7;q=s+1|0;E=-((h>>>7)+ah+(r<<3)|0)|0;if((h&64|0)==0){ao=m;ap=8}else{ao=(s<<3)+m|0;ap=-8}m=ao&511;s=E&511;h=m>>>0>335?ao|-512:m;m=s>>>0>239?E|-512:s;s=0;E=b[g+2>>1]&32767;while(1){if((m|0)>(Z|0)){if((m|0)>(p|0)){break}else{aq=h;ar=0;as=E}while(1){if((aq+7|0)>>>0<=342){Sr(l,as^2048,aq,m,ac,4,0,0,X)}n=ar+1|0;if((n|0)<(q|0)){aq=aq+ap|0;ar=n;as=as+1|0}else{break}}}t=s+1|0;if((t|0)<(r|0)){m=m+8|0;s=t;E=E+q|0}else{break}}g=g+(al<<1)|0;}while((g|0)!=(am|0))}if(ae>>>0<k>>>0){D=p;_=ae}else{break}}}_=c[3527480]|0;D=c[2406526]|0;k=0;am=0;while(1){al=am<<3;as=k;ar=0;while(1){ap=e[_+(as<<1)>>1]|0;aq=ap&1023;X=ap>>>10&15|ap>>>9&32;ao=ar<<3;if((ap&32768|0)==0){Sr(l,aq,ao,al,X,2,0,0,D)}else{Sj(l,aq,ao,al,X,2,0,D)}X=ar+1|0;if((X|0)<64){as=as+1|0;ar=X}else{break}}ar=am+1|0;if((ar|0)<32){k=k+64|0;am=ar}else{break}}R8(u);i=f;return 0}function dFv(a,b){a=a|0;b=b|0;var d=0,e=0;d=i;i=i+16|0;e=d|0;if((b|0)!=0){c[b>>2]=169479}if((a&32|0)==0){i=d;return 0}gGz(e|0,0,12);a=c[2405682]|0;c[e>>2]=a;c[e+4>>2]=(c[2411732]|0)-a;c[e+12>>2]=162152;gj[c[2076592]&4095](e)|0;i=d;return 0}function dFw(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1897532+(b*112|0)>>2];c[a+104>>2]=c[1897536+(b*112|0)>>2];c[a+108>>2]=c[1897540+(b*112|0)>>2];d=0;return d|0}function dFx(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=1897432+(b*112|0);e=0;return e|0}function dFy(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1899772+(b*112|0)>>2];c[a+104>>2]=c[1899776+(b*112|0)>>2];c[a+108>>2]=c[1899780+(b*112|0)>>2];d=0;return d|0}function dFz(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=1899672+(b*112|0);e=0;return e|0}function dFA(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1902012+(b*112|0)>>2];c[a+104>>2]=c[1902016+(b*112|0)>>2];c[a+108>>2]=c[1902020+(b*112|0)>>2];d=0;return d|0}function dFB(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=1901912+(b*112|0);e=0;return e|0}function dFC(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[966828+(b*112|0)>>2];c[a+104>>2]=c[966832+(b*112|0)>>2];c[a+108>>2]=c[966836+(b*112|0)>>2];d=0;return d|0}function dFD(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=966728+(b*112|0);e=0;return e|0}function dFE(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1243540+(b*112|0)>>2];c[a+104>>2]=c[1243544+(b*112|0)>>2];c[a+108>>2]=c[1243548+(b*112|0)>>2];d=0;return d|0}function dFF(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=1243440+(b*112|0);e=0;return e|0}function dFG(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[969068+(b*112|0)>>2];c[a+104>>2]=c[969072+(b*112|0)>>2];c[a+108>>2]=c[969076+(b*112|0)>>2];d=0;return d|0}function dFH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=968968+(b*112|0);e=0;return e|0}function dFI(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1245780+(b*112|0)>>2];c[a+104>>2]=c[1245784+(b*112|0)>>2];c[a+108>>2]=c[1245788+(b*112|0)>>2];d=0;return d|0}function dFJ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=1245680+(b*112|0);e=0;return e|0}function dFK(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[971308+(b*112|0)>>2];c[a+104>>2]=c[971312+(b*112|0)>>2];c[a+108>>2]=c[971316+(b*112|0)>>2];d=0;return d|0}function dFL(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=971208+(b*112|0);e=0;return e|0}function dFM(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1248020+(b*112|0)>>2];c[a+104>>2]=c[1248024+(b*112|0)>>2];c[a+108>>2]=c[1248028+(b*112|0)>>2];d=0;return d|0}function dFN(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=1247920+(b*112|0);e=0;return e|0}function dFO(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1250260+(b*112|0)>>2];c[a+104>>2]=c[1250264+(b*112|0)>>2];c[a+108>>2]=c[1250268+(b*112|0)>>2];d=0;return d|0}function dFP(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=1250160+(b*112|0);e=0;return e|0}function dFQ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[973548+(b*112|0)>>2];c[a+104>>2]=c[973552+(b*112|0)>>2];c[a+108>>2]=c[973556+(b*112|0)>>2];d=0;return d|0}function dFR(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=973448+(b*112|0);e=0;return e|0}function dFS(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1252500+(b*112|0)>>2];c[a+104>>2]=c[1252504+(b*112|0)>>2];c[a+108>>2]=c[1252508+(b*112|0)>>2];d=0;return d|0}function dFT(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=1252400+(b*112|0);e=0;return e|0}function dFU(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1254740+(b*112|0)>>2];c[a+104>>2]=c[1254744+(b*112|0)>>2];c[a+108>>2]=c[1254748+(b*112|0)>>2];d=0;return d|0}function dFV(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=1254640+(b*112|0);e=0;return e|0}function dFW(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1257460+(b*112|0)>>2];c[a+104>>2]=c[1257464+(b*112|0)>>2];c[a+108>>2]=c[1257468+(b*112|0)>>2];d=0;return d|0}function dFX(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=1257360+(b*112|0);e=0;return e|0}function dFY(){var b=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0;b=i;i=i+1320|0;e=b|0;f=b+112|0;g=b+120|0;j=b+232|0;k=b+240|0;l=b+352|0;m=b+360|0;n=b+472|0;o=b+480|0;p=b+592|0;q=b+600|0;r=b+712|0;s=b+720|0;t=b+832|0;u=b+840|0;v=b+952|0;w=b+960|0;x=b+1072|0;y=b+1080|0;z=b+1192|0;A=b+1200|0;B=b+1312|0;c[2426758]=0;c[3541542]=0;c[3527422]=524288;c[2405682]=589824;c[2388052]=589824;c[3527430]=602112;c[2387858]=606208;c[2437760]=610304;c[2438784]=618496;c[3527480]=626688;c[2443512]=630656;c[2439620]=630784;c[2411732]=632832;c[2406526]=632832;c[2429526]=698368;c[3530058]=1484800;C=0;while(1){if((C|0)>=1024){break}D=9638528+(C<<2)|0;if((c[D>>2]|0)==0){E=9595;break}else{C=C+1|0}}do{if((E|0)==9595){C=gGq(1488896)|0;c[D>>2]=C;if((C|0)==0){break}c[2426758]=C;gGz(C|0,0,1488896);c[3541542]=C;c[3527422]=C+524288;F=C+589824|0;c[2405682]=F;c[2388052]=F;c[3527430]=C+602112;c[2387858]=C+606208;c[2437760]=C+610304;c[2438784]=C+618496;c[3527480]=C+626688;c[2443512]=C+630656;c[2439620]=C+630784;F=C+632832|0;c[2411732]=F;c[2406526]=F;c[2429526]=C+698368;c[3530058]=C+1484800;c[2414274]=C+1488896;C=0;while(1){if((C|0)>=1024){G=0;break}H=9638528+(C<<2)|0;if((c[H>>2]|0)==0){E=9600;break}else{C=C+1|0}}do{if((E|0)==9600){C=gGq(393216)|0;c[H>>2]=C;if((C|0)==0){G=0;break}gGz(C|0,0,393216);G=C}}while(0);c[3529528]=G;if((R6((c[3541542]|0)+1|0,0,2)|0)!=0){I=1;i=b;return I|0}if((R6(c[3541542]|0,1,2)|0)!=0){I=1;i=b;return I|0}if((R6((c[3541542]|0)+229377|0,2,2)|0)!=0){I=1;i=b;return I|0}if((R6((c[3541542]|0)+229376|0,3,2)|0)!=0){I=1;i=b;return I|0}if((R6((c[3541542]|0)+262145|0,4,2)|0)!=0){I=1;i=b;return I|0}if((R6((c[3541542]|0)+262144|0,5,2)|0)!=0){I=1;i=b;return I|0}C=c[3541542]|0;F=C;J=C+32768|0;K=32768;while(1){L=K-1|0;M=a[F]|0;a[F]=a[J]|0;a[J]=M;if((L|0)==0){break}else{F=F+1|0;J=J+1|0;K=L}}K=C+262144|0;J=C+294912|0;F=32768;while(1){L=F-1|0;M=a[K]|0;a[K]=a[J]|0;a[J]=M;if((L|0)==0){break}else{K=K+1|0;J=J+1|0;F=L}}F=C+327680|0;J=C+360448|0;K=32768;while(1){L=K-1|0;M=a[F]|0;a[F]=a[J]|0;a[J]=M;if((L|0)==0){break}else{F=F+1|0;J=J+1|0;K=L}}K=C+393216|0;J=C+425984|0;F=32768;while(1){L=F-1|0;M=a[K]|0;a[K]=a[J]|0;a[J]=M;if((L|0)==0){break}else{K=K+1|0;J=J+1|0;F=L}}F=C+458752|0;J=C+491520|0;K=32768;while(1){L=K-1|0;M=a[F]|0;a[F]=a[J]|0;a[J]=M;if((L|0)==0){break}else{F=F+1|0;J=J+1|0;K=L}}K=c[3527422]|0;if((c[3542200]|0)==0){I=1;i=b;return I|0}J=A+108|0;c[J>>2]=0;F=A+100|0;c[F>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](A,6)|0;do{if((c[J>>2]|0)!=0){C=c[F>>2]|0;c[B>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](B,6,0)|0;if((C|0)<1){I=1;i=b;return I|0}if((gzL(K,0,6)|0)==0){break}else{I=1}i=b;return I|0}}while(0);K=(c[3527422]|0)+16384|0;if((c[3542200]|0)==0){I=1;i=b;return I|0}F=y+108|0;c[F>>2]=0;J=y+100|0;c[J>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](y,7)|0;do{if((c[F>>2]|0)!=0){C=c[J>>2]|0;c[z>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](z,7,0)|0;if((C|0)<1){I=1;i=b;return I|0}if((gzL(K,0,7)|0)==0){break}else{I=1}i=b;return I|0}}while(0);K=c[3529528]|0;if((c[3542200]|0)==0){I=1;i=b;return I|0}J=w+108|0;c[J>>2]=0;F=w+100|0;c[F>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](w,8)|0;do{if((c[J>>2]|0)!=0){C=c[F>>2]|0;c[x>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](x,8,0)|0;if((C|0)<1){I=1;i=b;return I|0}if((gzL(K,0,8)|0)==0){break}else{I=1}i=b;return I|0}}while(0);K=c[3529528]|0;F=c[2406526]|0;J=0;do{C=J<<6;gGz(F+C|0,0,64);L=J<<7;M=0;do{N=L+(c[6669224+(M<<2)>>2]|0)|0;O=(M<<3)+C|0;P=0;do{Q=N+(c[612480+(P<<2)>>2]|0)|0;if((d[K+((Q|0)/8|0)|0]&128>>>((Q&7)>>>0)|0)!=0){Q=F+(O+P)|0;a[Q]=a[Q]|2}P=P+1|0;}while((P|0)<8);M=M+1|0;}while((M|0)<8);M=L|4;P=0;do{O=M+(c[6669224+(P<<2)>>2]|0)|0;N=(P<<3)+C|0;Q=0;do{R=O+(c[612480+(Q<<2)>>2]|0)|0;if((d[K+((R|0)/8|0)|0]&128>>>((R&7)>>>0)|0)!=0){R=F+(N+Q)|0;a[R]=a[R]|1}Q=Q+1|0;}while((Q|0)<8);P=P+1|0;}while((P|0)<8);J=J+1|0;}while((J|0)<1024);gGz(K|0,0,393216);if((c[3542200]|0)==0){I=1;i=b;return I|0}J=u+108|0;c[J>>2]=0;F=u+100|0;c[F>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](u,9)|0;do{if((c[J>>2]|0)!=0){P=c[F>>2]|0;c[v>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](v,9,0)|0;if((P|0)<1){I=1;i=b;return I|0}if((gzL(K,0,9)|0)==0){break}else{I=1}i=b;return I|0}}while(0);K=(c[3529528]|0)+32768|0;if((c[3542200]|0)==0){I=1;i=b;return I|0}F=s+108|0;c[F>>2]=0;J=s+100|0;c[J>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](s,10)|0;do{if((c[F>>2]|0)!=0){P=c[J>>2]|0;c[t>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](t,10,0)|0;if((P|0)<1){I=1;i=b;return I|0}if((gzL(K,0,10)|0)==0){break}else{I=1}i=b;return I|0}}while(0);K=(c[3529528]|0)+98304|0;if((c[3542200]|0)==0){I=1;i=b;return I|0}J=q+108|0;c[J>>2]=0;F=q+100|0;c[F>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](q,11)|0;do{if((c[J>>2]|0)!=0){P=c[F>>2]|0;c[r>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](r,11,0)|0;if((P|0)<1){I=1;i=b;return I|0}if((gzL(K,0,11)|0)==0){break}else{I=1}i=b;return I|0}}while(0);K=(c[3529528]|0)+131072|0;if((c[3542200]|0)==0){I=1;i=b;return I|0}F=o+108|0;c[F>>2]=0;J=o+100|0;c[J>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](o,12)|0;do{if((c[F>>2]|0)!=0){P=c[J>>2]|0;c[p>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](p,12,0)|0;if((P|0)<1){I=1;i=b;return I|0}if((gzL(K,0,12)|0)==0){break}else{I=1}i=b;return I|0}}while(0);K=(c[3529528]|0)+196608|0;if((c[3542200]|0)==0){I=1;i=b;return I|0}J=m+108|0;c[J>>2]=0;F=m+100|0;c[F>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,13)|0;do{if((c[J>>2]|0)!=0){P=c[F>>2]|0;c[n>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](n,13,0)|0;if((P|0)<1){I=1;i=b;return I|0}if((gzL(K,0,13)|0)==0){break}else{I=1}i=b;return I|0}}while(0);K=(c[3529528]|0)+229376|0;if((c[3542200]|0)==0){I=1;i=b;return I|0}F=k+108|0;c[F>>2]=0;J=k+100|0;c[J>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,14)|0;do{if((c[F>>2]|0)!=0){P=c[J>>2]|0;c[l>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](l,14,0)|0;if((P|0)<1){I=1;i=b;return I|0}if((gzL(K,0,14)|0)==0){break}else{I=1}i=b;return I|0}}while(0);K=(c[3529528]|0)+294912|0;if((c[3542200]|0)==0){I=1;i=b;return I|0}J=g+108|0;c[J>>2]=0;F=g+100|0;c[F>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,15)|0;do{if((c[J>>2]|0)!=0){P=c[F>>2]|0;c[j>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](j,15,0)|0;if((P|0)<1){I=1;i=b;return I|0}if((gzL(K,0,15)|0)==0){break}else{I=1}i=b;return I|0}}while(0);K=(c[3529528]|0)+327680|0;if((c[3542200]|0)==0){I=1;i=b;return I|0}F=e+108|0;c[F>>2]=0;J=e+100|0;c[J>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,16)|0;do{if((c[F>>2]|0)!=0){P=c[J>>2]|0;c[f>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](f,16,0)|0;if((P|0)<1){I=1;i=b;return I|0}if((gzL(K,0,16)|0)==0){break}else{I=1}i=b;return I|0}}while(0);K=c[3529528]|0;J=0;do{F=K+J|0;a[F]=~a[F];J=J+1|0;}while(J>>>0<393216);J=c[2429526]|0;F=0;while(1){P=F<<6;gGz(J+P|0,0,64);C=0;do{M=1<<3-C;L=(c[5298976+(C<<2)>>2]|0)+P|0;Q=0;do{N=L+(c[1238464+(Q<<2)>>2]|0)|0;O=(Q<<3)+P|0;R=0;do{S=N+(c[614800+(R<<2)>>2]|0)|0;if((d[K+((S|0)/8|0)|0]&128>>>((S&7)>>>0)|0)!=0){S=J+(O+R)|0;a[S]=(d[S]|M)&255}R=R+1|0;}while((R|0)<8);Q=Q+1|0;}while((Q|0)<8);C=C+1|0;}while((C|0)<4);C=F+1|0;if((C|0)<12288){F=C}else{T=0;break}}while(1){if((T|0)>=1024){break}U=9638528+(T<<2)|0;if((c[U>>2]|0)==(K|0)){E=9684;break}else{T=T+1|0}}if((E|0)==9684){gGr(K);c[U>>2]=0}c[3529528]=0;fxU(0,426e3);if((c[2394]|0)==0){V=c[2112932]|0}else{c[2394]=0;F=c[3532596]|0;c[2112932]=F;J=c[3532592]|0;if((J|0)!=0){gGC(9104152,J|0,280)|0}c[2113054]=c[2113060];V=F}F=c[3541542]|0;J=V|0;C=0;while(1){P=F+C|0;c[J>>2]=P;c[J+131072>>2]=P;P=C+1024|0;if(P>>>0>524287){break}else{J=J+4|0;C=P}}C=c[2437760]|0;c[V+36864>>2]=C;c[V+102400>>2]=C;c[V+167936>>2]=C;J=C+1024|0;c[V+36868>>2]=J;c[V+102404>>2]=J;c[V+167940>>2]=J;J=C+2048|0;c[V+36872>>2]=J;c[V+102408>>2]=J;c[V+167944>>2]=J;J=C+3072|0;c[V+36876>>2]=J;c[V+102412>>2]=J;c[V+167948>>2]=J;J=C+4096|0;c[V+36880>>2]=J;c[V+102416>>2]=J;c[V+167952>>2]=J;J=C+5120|0;c[V+36884>>2]=J;c[V+102420>>2]=J;c[V+167956>>2]=J;J=C+6144|0;c[V+36888>>2]=J;c[V+102424>>2]=J;c[V+167960>>2]=J;J=C+7168|0;c[V+36892>>2]=J;c[V+102428>>2]=J;c[V+167964>>2]=J;J=c[2438784]|0;c[V+36896>>2]=J;c[V+102432>>2]=J;c[V+167968>>2]=J;C=J+1024|0;c[V+36900>>2]=C;c[V+102436>>2]=C;c[V+167972>>2]=C;C=J+2048|0;c[V+36904>>2]=C;c[V+102440>>2]=C;c[V+167976>>2]=C;C=J+3072|0;c[V+36908>>2]=C;c[V+102444>>2]=C;c[V+167980>>2]=C;C=J+4096|0;c[V+36912>>2]=C;c[V+102448>>2]=C;c[V+167984>>2]=C;C=J+5120|0;c[V+36916>>2]=C;c[V+102452>>2]=C;c[V+167988>>2]=C;C=J+6144|0;c[V+36920>>2]=C;c[V+102456>>2]=C;c[V+167992>>2]=C;C=J+7168|0;c[V+36924>>2]=C;c[V+102460>>2]=C;c[V+167996>>2]=C;C=c[2388052]|0;J=C+8192|0;c[V+36928>>2]=J;c[V+102464>>2]=J;c[V+168e3>>2]=J;J=C+9216|0;c[V+36932>>2]=J;c[V+102468>>2]=J;c[V+168004>>2]=J;J=C+10240|0;c[V+36936>>2]=J;c[V+102472>>2]=J;c[V+168008>>2]=J;J=C+11264|0;c[V+36940>>2]=J;c[V+102476>>2]=J;c[V+168012>>2]=J;J=c[3527480]|0;c[V+36944>>2]=J;c[V+102480>>2]=J;c[V+168016>>2]=J;C=J+1024|0;c[V+36948>>2]=C;c[V+102484>>2]=C;c[V+168020>>2]=C;C=J+2048|0;c[V+36952>>2]=C;c[V+102488>>2]=C;c[V+168024>>2]=C;C=(c[2443512]|0)-896|0;c[V+36956>>2]=C;c[V+102492>>2]=C;c[V+168028>>2]=C;C=c[2439620]|0;c[V+37120>>2]=C;c[V+102656>>2]=C;c[V+168192>>2]=C;J=C+1024|0;c[V+37124>>2]=J;c[V+102660>>2]=J;c[V+168196>>2]=J;c[V+196608>>2]=2642;c[V+196648>>2]=1444;c[V+196688>>2]=1064;c[V+196728>>2]=2014;J=c[3532592]|0;if((J|0)!=0){gGC(J|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fvI();c[3528556]=0;J=c[2433594]|0;c[2443776]=J;L13011:do{if((J|0)!=0){C=J|0;gGC(9660952,C|0,52)|0;switch(a[9660952]|0){case 0:{c[2309668]=638960;break L13011;break};case 4:{c[2309668]=7356016;break L13011;break};case 5:{c[2309668]=7354992;break L13011;break};case 1:{c[2309668]=634096;break L13011;break};case 3:{c[2309668]=639984;break L13011;break};case 2:{c[2309668]=638960;break L13011;break};default:{break L13011}}}}while(0);C=c[2432850]|0;c[2113164]=C;F=c[3527430]|0;K=0;P=0;while(1){Q=F+(P<<8)|0;c[J+68+(P<<2)>>2]=Q;c[J+68+(P+256<<2)>>2]=Q;c[J+68+(P+512<<2)>>2]=Q;Q=K+1&65535;if((Q&65535)>15){break}else{K=Q;P=Q&65535}}P=c[3527422]|0;K=64;F=64;while(1){Q=P+((F<<8)-16384)|0;c[J+68+(F<<2)>>2]=Q;c[J+68+(F+512<<2)>>2]=Q;Q=K+1&65535;if((Q&65535)>255){break}else{K=Q;F=Q&65535}}c[J+3148>>2]=2670;c[J+3152>>2]=1786;F=J|0;gGC(F|0,9660952,52)|0;c[2432850]=C;c[2443776]=0;c[3528556]=-1;a[9717208]=107;c[2430522]=0;gGC(9553936,6995856,144)|0;a[9660536]=0;a[9771528]=3;a[14115672]=(c[2392]|0)!=-1|0;if((c[2394]|0)==0){W=c[2112932]|0}else{c[2394]=0;F=c[3532596]|0;c[2112932]=F;K=c[3532592]|0;if((K|0)!=0){gGC(9104152,K|0,280)|0}c[2113054]=c[2113060];W=F}F=W+896|0;K=229376;while(1){c[F>>2]=1;c[F+65536>>2]=1;c[F+131072>>2]=1;P=K+1024|0;if(P>>>0>262143){break}else{F=F+4|0;K=P}}c[W+196612>>2]=2434;c[W+196692>>2]=2766;c[W+196652>>2]=2568;c[W+196732>>2]=2790;K=c[3532592]|0;if((K|0)!=0){gGC(K|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;K=0;while(1){if((K|0)>=1024){X=0;break}Y=9638528+(K<<2)|0;if((c[Y>>2]|0)==0){E=9718;break}else{K=K+1|0}}do{if((E|0)==9718){K=gGq(32768)|0;c[Y>>2]=K;if((K|0)==0){X=0;break}gGz(K|0,0,32768);X=K}}while(0);c[2430522]=X;K=(c[3541542]|0)+229376|0;gGC(X|0,K|0,32768)|0;gGz(c[2387858]|0,-1|0,4096);K=a[9680]|0;F=K?32e3:0;if(K){if(a[9624]|0){K=F*3|0;C=55930;while(1){if((C|0)>(K|0)){C=C>>1}else{Z=1222;_=C;break}}}else{Z=2462;_=F}c[2429380]=_;c[3542124]=Z;mw(3579545,_);C=gGq(262144)|0;c[2406684]=C;gGz(C|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(3579545,11025)}h[745421]=.48;c[2436794]=2;h[745420]=.48;c[2436792]=1;C=c[642608+(c[2436]<<2)>>2]|0;K=c[C+128>>2]|0;if((c[C+52>>2]&4|0)==0){c[2113068]=K;J=c[C+132>>2]|0;c[2113070]=J;c[2443814]=K;c[2440436]=J;$=K;aa=J}else{c[2113070]=K;J=c[C+132>>2]|0;c[2113068]=J;c[2440436]=K;c[2443814]=J;$=J;aa=K}K=ag($<<1,aa)|0;J=gGq(K)|0;c[2112926]=J;if((J|0)!=0){gGz(J|0,0,K|0)}c[2409630]=614328;K=(c[153582]|0)*600|0;J=0;while(1){if((J|0)>=1024){E=9735;break}ab=9638528+(J<<2)|0;if((c[ab>>2]|0)==0){E=9734;break}else{J=J+1|0}}do{if((E|0)==9734){J=gGq(K)|0;c[ab>>2]=J;if((J|0)==0){E=9735;break}gGz(J|0,0,K|0);F=J;c[3525360]=F;c[2433680]=F;c[2432968]=0}}while(0);if((E|0)==9735){c[3525360]=0}a[7303760]=0;dGi();I=0;i=b;return I|0}}while(0);c[2426758]=0;I=1;i=b;return I|0}function dFZ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[975788+(b*112|0)>>2];c[a+104>>2]=c[975792+(b*112|0)>>2];c[a+108>>2]=c[975796+(b*112|0)>>2];d=0;return d|0}function dF_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=975688+(b*112|0);e=0;return e|0}function dF$(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[978028+(b*112|0)>>2];c[a+104>>2]=c[978032+(b*112|0)>>2];c[a+108>>2]=c[978036+(b*112|0)>>2];d=0;return d|0}function dF0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=977928+(b*112|0);e=0;return e|0}function dF1(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[809780+(b*112|0)>>2];c[a+104>>2]=c[809784+(b*112|0)>>2];c[a+108>>2]=c[809788+(b*112|0)>>2];d=0;return d|0}function dF2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=809680+(b*112|0);e=0;return e|0}function dF3(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[812020+(b*112|0)>>2];c[a+104>>2]=c[812024+(b*112|0)>>2];c[a+108>>2]=c[812028+(b*112|0)>>2];d=0;return d|0}function dF4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=811920+(b*112|0);e=0;return e|0}function dF5(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[814260+(b*112|0)>>2];c[a+104>>2]=c[814264+(b*112|0)>>2];c[a+108>>2]=c[814268+(b*112|0)>>2];d=0;return d|0}function dF6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=814160+(b*112|0);e=0;return e|0}function dF7(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>25){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6296380+(b*112|0)>>2];c[a+104>>2]=c[6296384+(b*112|0)>>2];c[a+108>>2]=c[6296388+(b*112|0)>>2];d=0;return d|0}function dF8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<26&(d|0)==0)){e=1;return e|0}c[a>>2]=6296280+(b*112|0);e=0;return e|0}function dF9(){var b=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0;b=i;i=i+2280|0;e=b|0;f=b+112|0;g=b+120|0;j=b+232|0;k=b+240|0;l=b+352|0;m=b+360|0;n=b+472|0;o=b+480|0;p=b+592|0;q=b+600|0;r=b+712|0;s=b+720|0;t=b+832|0;u=b+840|0;v=b+952|0;w=b+960|0;x=b+1072|0;y=b+1080|0;z=b+1192|0;A=b+1200|0;B=b+1312|0;C=b+1320|0;D=b+1432|0;E=b+1440|0;F=b+1552|0;G=b+1560|0;H=b+1672|0;I=b+1680|0;J=b+1792|0;K=b+1800|0;L=b+1912|0;M=b+1920|0;N=b+2032|0;O=b+2040|0;P=b+2152|0;Q=b+2160|0;R=b+2272|0;c[2426758]=0;c[3541542]=0;c[3527422]=524288;c[2405682]=589824;c[2388052]=589824;c[3527430]=602112;c[2387858]=606208;c[2437760]=610304;c[2438784]=618496;c[3527480]=626688;c[2443512]=630656;c[2439620]=630784;c[2411732]=632832;c[2406526]=632832;c[2429526]=698368;c[3530058]=1484800;S=0;while(1){if((S|0)>=1024){break}T=9638528+(S<<2)|0;if((c[T>>2]|0)==0){U=9861;break}else{S=S+1|0}}do{if((U|0)==9861){S=gGq(1488896)|0;c[T>>2]=S;if((S|0)==0){break}c[2426758]=S;gGz(S|0,0,1488896);c[3541542]=S;c[3527422]=S+524288;V=S+589824|0;c[2405682]=V;c[2388052]=V;c[3527430]=S+602112;c[2387858]=S+606208;c[2437760]=S+610304;c[2438784]=S+618496;c[3527480]=S+626688;c[2443512]=S+630656;c[2439620]=S+630784;V=S+632832|0;c[2411732]=V;c[2406526]=V;c[2429526]=S+698368;c[3530058]=S+1484800;c[2414274]=S+1488896;S=0;while(1){if((S|0)>=1024){W=0;break}X=9638528+(S<<2)|0;if((c[X>>2]|0)==0){U=9866;break}else{S=S+1|0}}do{if((U|0)==9866){S=gGq(393216)|0;c[X>>2]=S;if((S|0)==0){W=0;break}gGz(S|0,0,393216);W=S}}while(0);c[3529528]=W;if((R6((c[3541542]|0)+1|0,0,2)|0)!=0){Y=1;i=b;return Y|0}if((R6(c[3541542]|0,1,2)|0)!=0){Y=1;i=b;return Y|0}if((R6((c[3541542]|0)+229377|0,2,2)|0)!=0){Y=1;i=b;return Y|0}if((R6((c[3541542]|0)+229376|0,3,2)|0)!=0){Y=1;i=b;return Y|0}if((R6((c[3541542]|0)+262145|0,4,2)|0)!=0){Y=1;i=b;return Y|0}if((R6((c[3541542]|0)+262144|0,5,2)|0)!=0){Y=1;i=b;return Y|0}if((R6((c[3541542]|0)+327681|0,6,2)|0)!=0){Y=1;i=b;return Y|0}if((R6((c[3541542]|0)+327680|0,7,2)|0)!=0){Y=1;i=b;return Y|0}S=c[3541542]|0;V=S;Z=S+32768|0;_=32768;while(1){$=_-1|0;aa=a[V]|0;a[V]=a[Z]|0;a[Z]=aa;if(($|0)==0){break}else{V=V+1|0;Z=Z+1|0;_=$}}_=S+262144|0;Z=S+294912|0;V=32768;while(1){$=V-1|0;aa=a[_]|0;a[_]=a[Z]|0;a[Z]=aa;if(($|0)==0){break}else{_=_+1|0;Z=Z+1|0;V=$}}V=S+327680|0;Z=S+360448|0;_=32768;while(1){$=_-1|0;aa=a[V]|0;a[V]=a[Z]|0;a[Z]=aa;if(($|0)==0){break}else{V=V+1|0;Z=Z+1|0;_=$}}_=S+393216|0;Z=S+425984|0;V=32768;while(1){$=V-1|0;aa=a[_]|0;a[_]=a[Z]|0;a[Z]=aa;if(($|0)==0){break}else{_=_+1|0;Z=Z+1|0;V=$}}V=S+458752|0;Z=S+491520|0;_=32768;while(1){$=_-1|0;aa=a[V]|0;a[V]=a[Z]|0;a[Z]=aa;if(($|0)==0){break}else{V=V+1|0;Z=Z+1|0;_=$}}_=c[3527422]|0;if((c[3542200]|0)==0){Y=1;i=b;return Y|0}Z=Q+108|0;c[Z>>2]=0;V=Q+100|0;c[V>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](Q,8)|0;do{if((c[Z>>2]|0)!=0){S=c[V>>2]|0;c[R>>2]=9534384;$=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[$&16383](R,8,0)|0;if((S|0)<1){Y=1;i=b;return Y|0}if((gzL(_,0,8)|0)==0){break}else{Y=1}i=b;return Y|0}}while(0);_=(c[3527422]|0)+16384|0;if((c[3542200]|0)==0){Y=1;i=b;return Y|0}V=O+108|0;c[V>>2]=0;Z=O+100|0;c[Z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](O,9)|0;do{if((c[V>>2]|0)!=0){S=c[Z>>2]|0;c[P>>2]=9534384;$=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[$&16383](P,9,0)|0;if((S|0)<1){Y=1;i=b;return Y|0}if((gzL(_,0,9)|0)==0){break}else{Y=1}i=b;return Y|0}}while(0);_=c[3529528]|0;if((c[3542200]|0)==0){Y=1;i=b;return Y|0}Z=M+108|0;c[Z>>2]=0;V=M+100|0;c[V>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](M,10)|0;do{if((c[Z>>2]|0)!=0){S=c[V>>2]|0;c[N>>2]=9534384;$=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[$&16383](N,10,0)|0;if((S|0)<1){Y=1;i=b;return Y|0}if((gzL(_,0,10)|0)==0){break}else{Y=1}i=b;return Y|0}}while(0);_=c[3529528]|0;V=c[2406526]|0;Z=0;do{S=Z<<6;gGz(V+S|0,0,64);$=Z<<7;aa=0;do{ab=$+(c[6669224+(aa<<2)>>2]|0)|0;ac=(aa<<3)+S|0;ad=0;do{ae=ab+(c[612480+(ad<<2)>>2]|0)|0;if((d[_+((ae|0)/8|0)|0]&128>>>((ae&7)>>>0)|0)!=0){ae=V+(ac+ad)|0;a[ae]=a[ae]|2}ad=ad+1|0;}while((ad|0)<8);aa=aa+1|0;}while((aa|0)<8);aa=$|4;ad=0;do{ac=aa+(c[6669224+(ad<<2)>>2]|0)|0;ab=(ad<<3)+S|0;ae=0;do{af=ac+(c[612480+(ae<<2)>>2]|0)|0;if((d[_+((af|0)/8|0)|0]&128>>>((af&7)>>>0)|0)!=0){af=V+(ab+ae)|0;a[af]=a[af]|1}ae=ae+1|0;}while((ae|0)<8);ad=ad+1|0;}while((ad|0)<8);Z=Z+1|0;}while((Z|0)<1024);gGz(_|0,0,393216);if((c[3542200]|0)==0){Y=1;i=b;return Y|0}Z=K+108|0;c[Z>>2]=0;V=K+100|0;c[V>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](K,11)|0;do{if((c[Z>>2]|0)!=0){ad=c[V>>2]|0;c[L>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](L,11,0)|0;if((ad|0)<1){Y=1;i=b;return Y|0}if((gzL(_,0,11)|0)==0){break}else{Y=1}i=b;return Y|0}}while(0);_=(c[3529528]|0)+32768|0;if((c[3542200]|0)==0){Y=1;i=b;return Y|0}V=I+108|0;c[V>>2]=0;Z=I+100|0;c[Z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](I,12)|0;do{if((c[V>>2]|0)!=0){ad=c[Z>>2]|0;c[J>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](J,12,0)|0;if((ad|0)<1){Y=1;i=b;return Y|0}if((gzL(_,0,12)|0)==0){break}else{Y=1}i=b;return Y|0}}while(0);_=(c[3529528]|0)+65536|0;if((c[3542200]|0)==0){Y=1;i=b;return Y|0}Z=G+108|0;c[Z>>2]=0;V=G+100|0;c[V>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](G,13)|0;do{if((c[Z>>2]|0)!=0){ad=c[V>>2]|0;c[H>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](H,13,0)|0;if((ad|0)<1){Y=1;i=b;return Y|0}if((gzL(_,0,13)|0)==0){break}else{Y=1}i=b;return Y|0}}while(0);_=(c[3529528]|0)+81920|0;if((c[3542200]|0)==0){Y=1;i=b;return Y|0}V=E+108|0;c[V>>2]=0;Z=E+100|0;c[Z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](E,13)|0;do{if((c[V>>2]|0)!=0){ad=c[Z>>2]|0;c[F>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](F,13,0)|0;if((ad|0)<1){Y=1;i=b;return Y|0}if((gzL(_,0,13)|0)==0){break}else{Y=1}i=b;return Y|0}}while(0);_=(c[3529528]|0)+98304|0;if((c[3542200]|0)==0){Y=1;i=b;return Y|0}Z=C+108|0;c[Z>>2]=0;V=C+100|0;c[V>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](C,14)|0;do{if((c[Z>>2]|0)!=0){ad=c[V>>2]|0;c[D>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](D,14,0)|0;if((ad|0)<1){Y=1;i=b;return Y|0}if((gzL(_,0,14)|0)==0){break}else{Y=1}i=b;return Y|0}}while(0);_=(c[3529528]|0)+131072|0;if((c[3542200]|0)==0){Y=1;i=b;return Y|0}V=A+108|0;c[V>>2]=0;Z=A+100|0;c[Z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](A,15)|0;do{if((c[V>>2]|0)!=0){ad=c[Z>>2]|0;c[B>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](B,15,0)|0;if((ad|0)<1){Y=1;i=b;return Y|0}if((gzL(_,0,15)|0)==0){break}else{Y=1}i=b;return Y|0}}while(0);_=(c[3529528]|0)+163840|0;if((c[3542200]|0)==0){Y=1;i=b;return Y|0}Z=y+108|0;c[Z>>2]=0;V=y+100|0;c[V>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](y,16)|0;do{if((c[Z>>2]|0)!=0){ad=c[V>>2]|0;c[z>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](z,16,0)|0;if((ad|0)<1){Y=1;i=b;return Y|0}if((gzL(_,0,16)|0)==0){break}else{Y=1}i=b;return Y|0}}while(0);_=(c[3529528]|0)+180224|0;if((c[3542200]|0)==0){Y=1;i=b;return Y|0}V=w+108|0;c[V>>2]=0;Z=w+100|0;c[Z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](w,16)|0;do{if((c[V>>2]|0)!=0){ad=c[Z>>2]|0;c[x>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](x,16,0)|0;if((ad|0)<1){Y=1;i=b;return Y|0}if((gzL(_,0,16)|0)==0){break}else{Y=1}i=b;return Y|0}}while(0);_=(c[3529528]|0)+196608|0;if((c[3542200]|0)==0){Y=1;i=b;return Y|0}Z=u+108|0;c[Z>>2]=0;V=u+100|0;c[V>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](u,17)|0;do{if((c[Z>>2]|0)!=0){ad=c[V>>2]|0;c[v>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](v,17,0)|0;if((ad|0)<1){Y=1;i=b;return Y|0}if((gzL(_,0,17)|0)==0){break}else{Y=1}i=b;return Y|0}}while(0);_=(c[3529528]|0)+229376|0;if((c[3542200]|0)==0){Y=1;i=b;return Y|0}V=s+108|0;c[V>>2]=0;Z=s+100|0;c[Z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](s,18)|0;do{if((c[V>>2]|0)!=0){ad=c[Z>>2]|0;c[t>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](t,18,0)|0;if((ad|0)<1){Y=1;i=b;return Y|0}if((gzL(_,0,18)|0)==0){break}else{Y=1}i=b;return Y|0}}while(0);_=(c[3529528]|0)+262144|0;if((c[3542200]|0)==0){Y=1;i=b;return Y|0}Z=q+108|0;c[Z>>2]=0;V=q+100|0;c[V>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](q,19)|0;do{if((c[Z>>2]|0)!=0){ad=c[V>>2]|0;c[r>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](r,19,0)|0;if((ad|0)<1){Y=1;i=b;return Y|0}if((gzL(_,0,19)|0)==0){break}else{Y=1}i=b;return Y|0}}while(0);_=(c[3529528]|0)+278528|0;if((c[3542200]|0)==0){Y=1;i=b;return Y|0}V=o+108|0;c[V>>2]=0;Z=o+100|0;c[Z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](o,19)|0;do{if((c[V>>2]|0)!=0){ad=c[Z>>2]|0;c[p>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](p,19,0)|0;if((ad|0)<1){Y=1;i=b;return Y|0}if((gzL(_,0,19)|0)==0){break}else{Y=1}i=b;return Y|0}}while(0);_=(c[3529528]|0)+294912|0;if((c[3542200]|0)==0){Y=1;i=b;return Y|0}Z=m+108|0;c[Z>>2]=0;V=m+100|0;c[V>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,20)|0;do{if((c[Z>>2]|0)!=0){ad=c[V>>2]|0;c[n>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](n,20,0)|0;if((ad|0)<1){Y=1;i=b;return Y|0}if((gzL(_,0,20)|0)==0){break}else{Y=1}i=b;return Y|0}}while(0);_=(c[3529528]|0)+327680|0;if((c[3542200]|0)==0){Y=1;i=b;return Y|0}V=k+108|0;c[V>>2]=0;Z=k+100|0;c[Z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,21)|0;do{if((c[V>>2]|0)!=0){ad=c[Z>>2]|0;c[l>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](l,21,0)|0;if((ad|0)<1){Y=1;i=b;return Y|0}if((gzL(_,0,21)|0)==0){break}else{Y=1}i=b;return Y|0}}while(0);_=(c[3529528]|0)+360448|0;if((c[3542200]|0)==0){Y=1;i=b;return Y|0}Z=g+108|0;c[Z>>2]=0;V=g+100|0;c[V>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,22)|0;do{if((c[Z>>2]|0)!=0){ad=c[V>>2]|0;c[j>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](j,22,0)|0;if((ad|0)<1){Y=1;i=b;return Y|0}if((gzL(_,0,22)|0)==0){break}else{Y=1}i=b;return Y|0}}while(0);_=(c[3529528]|0)+376832|0;if((c[3542200]|0)==0){Y=1;i=b;return Y|0}V=e+108|0;c[V>>2]=0;Z=e+100|0;c[Z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,22)|0;do{if((c[V>>2]|0)!=0){ad=c[Z>>2]|0;c[f>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](f,22,0)|0;if((ad|0)<1){Y=1;i=b;return Y|0}if((gzL(_,0,22)|0)==0){break}else{Y=1}i=b;return Y|0}}while(0);_=c[3529528]|0;Z=0;do{V=_+Z|0;a[V]=~a[V];Z=Z+1|0;}while(Z>>>0<393216);Z=c[2429526]|0;V=0;while(1){ad=V<<6;gGz(Z+ad|0,0,64);S=0;do{aa=1<<3-S;$=(c[5298976+(S<<2)>>2]|0)+ad|0;ae=0;do{ab=$+(c[1238464+(ae<<2)>>2]|0)|0;ac=(ae<<3)+ad|0;af=0;do{ah=ab+(c[614800+(af<<2)>>2]|0)|0;if((d[_+((ah|0)/8|0)|0]&128>>>((ah&7)>>>0)|0)!=0){ah=Z+(ac+af)|0;a[ah]=(d[ah]|aa)&255}af=af+1|0;}while((af|0)<8);ae=ae+1|0;}while((ae|0)<8);S=S+1|0;}while((S|0)<4);S=V+1|0;if((S|0)<12288){V=S}else{ai=0;break}}while(1){if((ai|0)>=1024){break}aj=9638528+(ai<<2)|0;if((c[aj>>2]|0)==(_|0)){U=9984;break}else{ai=ai+1|0}}if((U|0)==9984){gGr(_);c[aj>>2]=0}c[3529528]=0;fxU(0,426e3);if((c[2394]|0)==0){ak=c[2112932]|0}else{c[2394]=0;V=c[3532596]|0;c[2112932]=V;Z=c[3532592]|0;if((Z|0)!=0){gGC(9104152,Z|0,280)|0}c[2113054]=c[2113060];ak=V}V=c[3541542]|0;Z=ak|0;S=0;while(1){ad=V+S|0;c[Z>>2]=ad;c[Z+131072>>2]=ad;ad=S+1024|0;if(ad>>>0>524287){break}else{Z=Z+4|0;S=ad}}S=c[2437760]|0;c[ak+36864>>2]=S;c[ak+102400>>2]=S;c[ak+167936>>2]=S;Z=S+1024|0;c[ak+36868>>2]=Z;c[ak+102404>>2]=Z;c[ak+167940>>2]=Z;Z=S+2048|0;c[ak+36872>>2]=Z;c[ak+102408>>2]=Z;c[ak+167944>>2]=Z;Z=S+3072|0;c[ak+36876>>2]=Z;c[ak+102412>>2]=Z;c[ak+167948>>2]=Z;Z=S+4096|0;c[ak+36880>>2]=Z;c[ak+102416>>2]=Z;c[ak+167952>>2]=Z;Z=S+5120|0;c[ak+36884>>2]=Z;c[ak+102420>>2]=Z;c[ak+167956>>2]=Z;Z=S+6144|0;c[ak+36888>>2]=Z;c[ak+102424>>2]=Z;c[ak+167960>>2]=Z;Z=S+7168|0;c[ak+36892>>2]=Z;c[ak+102428>>2]=Z;c[ak+167964>>2]=Z;Z=c[2438784]|0;c[ak+36896>>2]=Z;c[ak+102432>>2]=Z;c[ak+167968>>2]=Z;S=Z+1024|0;c[ak+36900>>2]=S;c[ak+102436>>2]=S;c[ak+167972>>2]=S;S=Z+2048|0;c[ak+36904>>2]=S;c[ak+102440>>2]=S;c[ak+167976>>2]=S;S=Z+3072|0;c[ak+36908>>2]=S;c[ak+102444>>2]=S;c[ak+167980>>2]=S;S=Z+4096|0;c[ak+36912>>2]=S;c[ak+102448>>2]=S;c[ak+167984>>2]=S;S=Z+5120|0;c[ak+36916>>2]=S;c[ak+102452>>2]=S;c[ak+167988>>2]=S;S=Z+6144|0;c[ak+36920>>2]=S;c[ak+102456>>2]=S;c[ak+167992>>2]=S;S=Z+7168|0;c[ak+36924>>2]=S;c[ak+102460>>2]=S;c[ak+167996>>2]=S;S=c[2388052]|0;Z=S+8192|0;c[ak+36928>>2]=Z;c[ak+102464>>2]=Z;c[ak+168e3>>2]=Z;Z=S+9216|0;c[ak+36932>>2]=Z;c[ak+102468>>2]=Z;c[ak+168004>>2]=Z;Z=S+10240|0;c[ak+36936>>2]=Z;c[ak+102472>>2]=Z;c[ak+168008>>2]=Z;Z=S+11264|0;c[ak+36940>>2]=Z;c[ak+102476>>2]=Z;c[ak+168012>>2]=Z;Z=c[3527480]|0;c[ak+36944>>2]=Z;c[ak+102480>>2]=Z;c[ak+168016>>2]=Z;S=Z+1024|0;c[ak+36948>>2]=S;c[ak+102484>>2]=S;c[ak+168020>>2]=S;S=Z+2048|0;c[ak+36952>>2]=S;c[ak+102488>>2]=S;c[ak+168024>>2]=S;S=(c[2443512]|0)-896|0;c[ak+36956>>2]=S;c[ak+102492>>2]=S;c[ak+168028>>2]=S;S=c[2439620]|0;c[ak+37120>>2]=S;c[ak+102656>>2]=S;c[ak+168192>>2]=S;Z=S+1024|0;c[ak+37124>>2]=Z;c[ak+102660>>2]=Z;c[ak+168196>>2]=Z;c[ak+196608>>2]=2642;c[ak+196648>>2]=1444;c[ak+196688>>2]=1064;c[ak+196728>>2]=2014;Z=c[3532592]|0;if((Z|0)!=0){gGC(Z|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fvI();c[3528556]=0;Z=c[2433594]|0;c[2443776]=Z;L13453:do{if((Z|0)!=0){S=Z|0;gGC(9660952,S|0,52)|0;switch(a[9660952]|0){case 0:{c[2309668]=638960;break L13453;break};case 3:{c[2309668]=639984;break L13453;break};case 4:{c[2309668]=7356016;break L13453;break};case 5:{c[2309668]=7354992;break L13453;break};case 1:{c[2309668]=634096;break L13453;break};case 2:{c[2309668]=638960;break L13453;break};default:{break L13453}}}}while(0);S=c[2432850]|0;c[2113164]=S;V=c[3527430]|0;_=0;ad=0;while(1){ae=V+(ad<<8)|0;c[Z+68+(ad<<2)>>2]=ae;c[Z+68+(ad+256<<2)>>2]=ae;c[Z+68+(ad+512<<2)>>2]=ae;ae=_+1&65535;if((ae&65535)>15){break}else{_=ae;ad=ae&65535}}ad=c[3527422]|0;_=64;V=64;while(1){ae=ad+((V<<8)-16384)|0;c[Z+68+(V<<2)>>2]=ae;c[Z+68+(V+512<<2)>>2]=ae;ae=_+1&65535;if((ae&65535)>255){break}else{_=ae;V=ae&65535}}c[Z+3148>>2]=2670;c[Z+3152>>2]=1786;V=Z|0;gGC(V|0,9660952,52)|0;c[2432850]=S;c[2443776]=0;c[3528556]=-1;a[9717208]=106;c[2430522]=0;gGC(9553936,6996e3,144)|0;a[9660536]=0;a[9771528]=3;a[14115672]=(c[2392]|0)!=-1|0;if((c[2394]|0)==0){al=c[2112932]|0}else{c[2394]=0;V=c[3532596]|0;c[2112932]=V;_=c[3532592]|0;if((_|0)!=0){gGC(9104152,_|0,280)|0}c[2113054]=c[2113060];al=V}V=al+896|0;_=229376;while(1){c[V>>2]=1;c[V+65536>>2]=1;c[V+131072>>2]=1;ad=_+1024|0;if(ad>>>0>262143){break}else{V=V+4|0;_=ad}}c[al+196612>>2]=2434;c[al+196692>>2]=2766;c[al+196652>>2]=2568;c[al+196732>>2]=2790;_=c[3532592]|0;if((_|0)!=0){gGC(_|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;_=0;while(1){if((_|0)>=1024){am=0;break}an=9638528+(_<<2)|0;if((c[an>>2]|0)==0){U=10018;break}else{_=_+1|0}}do{if((U|0)==10018){_=gGq(32768)|0;c[an>>2]=_;if((_|0)==0){am=0;break}gGz(_|0,0,32768);am=_}}while(0);c[2430522]=am;_=(c[3541542]|0)+229376|0;gGC(am|0,_|0,32768)|0;gGz(c[2387858]|0,-1|0,4096);_=a[9680]|0;V=_?32e3:0;if(_){if(a[9624]|0){_=V*3|0;S=55930;while(1){if((S|0)>(_|0)){S=S>>1}else{ao=1222;ap=S;break}}}else{ao=2462;ap=V}c[2429380]=ap;c[3542124]=ao;mw(3579545,ap);S=gGq(262144)|0;c[2406684]=S;gGz(S|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(3579545,11025)}h[745421]=.48;c[2436794]=2;h[745420]=.48;c[2436792]=1;S=c[642608+(c[2436]<<2)>>2]|0;_=c[S+128>>2]|0;if((c[S+52>>2]&4|0)==0){c[2113068]=_;Z=c[S+132>>2]|0;c[2113070]=Z;c[2443814]=_;c[2440436]=Z;aq=_;ar=Z}else{c[2113070]=_;Z=c[S+132>>2]|0;c[2113068]=Z;c[2440436]=_;c[2443814]=Z;aq=Z;ar=_}_=ag(aq<<1,ar)|0;Z=gGq(_)|0;c[2112926]=Z;if((Z|0)!=0){gGz(Z|0,0,_|0)}c[2409630]=614648;_=(c[153662]|0)*600|0;Z=0;while(1){if((Z|0)>=1024){U=10035;break}as=9638528+(Z<<2)|0;if((c[as>>2]|0)==0){U=10034;break}else{Z=Z+1|0}}do{if((U|0)==10034){Z=gGq(_)|0;c[as>>2]=Z;if((Z|0)==0){U=10035;break}gGz(Z|0,0,_|0);V=Z;c[3525360]=V;c[2433680]=V;c[2432968]=0}}while(0);if((U|0)==10035){c[3525360]=0}a[7303760]=1;dGi();Y=0;i=b;return Y|0}}while(0);c[2426758]=0;Y=1;i=b;return Y|0}function dGa(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>25){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5388460+(b*112|0)>>2];c[a+104>>2]=c[5388464+(b*112|0)>>2];c[a+108>>2]=c[5388468+(b*112|0)>>2];d=0;return d|0}function dGb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<26&(d|0)==0)){e=1;return e|0}c[a>>2]=5388360+(b*112|0);e=0;return e|0}function dGc(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>25){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3922500+(b*112|0)>>2];c[a+104>>2]=c[3922504+(b*112|0)>>2];c[a+108>>2]=c[3922508+(b*112|0)>>2];d=0;return d|0}function dGd(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<26&(d|0)==0)){e=1;return e|0}c[a>>2]=3922400+(b*112|0);e=0;return e|0}function dGe(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>25){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1907164+(b*112|0)>>2];c[a+104>>2]=c[1907168+(b*112|0)>>2];c[a+108>>2]=c[1907172+(b*112|0)>>2];d=0;return d|0}function dGf(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<26&(d|0)==0)){e=1;return e|0}c[a>>2]=1907064+(b*112|0);e=0;return e|0}function dGg(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>25){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1904252+(b*112|0)>>2];c[a+104>>2]=c[1904256+(b*112|0)>>2];c[a+108>>2]=c[1904260+(b*112|0)>>2];d=0;return d|0}function dGh(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<26&(d|0)==0)){e=1;return e|0}c[a>>2]=1904152+(b*112|0);e=0;return e|0}function dGi(){var d=0,e=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;c[3528556]=0;d=c[2433594]|0;c[2443776]=d;L13579:do{if((d|0)!=0){e=d|0;gGC(9660952,e|0,52)|0;switch(a[9660952]|0){case 3:{c[2309668]=639984;break L13579;break};case 5:{c[2309668]=7354992;break L13579;break};case 4:{c[2309668]=7356016;break L13579;break};case 2:{c[2309668]=638960;break L13579;break};case 0:{c[2309668]=638960;break L13579;break};case 1:{c[2309668]=634096;break L13579;break};default:{break L13579}}}}while(0);c[2113164]=c[2432850];gu[c[d+56>>2]&16383]();d=c[2443776]|0;if((d|0)!=0){e=d|0;gGC(e|0,9660952,52)|0}c[9731400+(c[3528556]<<2)>>2]=c[2113164];c[2443776]=0;c[3528556]=-1;mx(0);if((a[9717208]|0)==0){a[2886608]=0;a[638016]=1;b[4866888]=0;a[4039504]=0;a[986992]=0;a[986976]=0;a[9759808]=0;a[9758128]=0;return}a[9660536]=0;a[9771528]=c[2388484]&255;a[2886608]=0;a[638016]=1;b[4866888]=0;a[4039504]=0;a[986992]=0;a[986976]=0;a[9759808]=0;a[9758128]=0;return}function dGj(a){a=a|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=c[2437760]|0;g=d[14109024]<<12;h=b[7059604]|0;i=b[7059588]|0;j=c[2112926]|0;k=c[2429526]|0;l=0;do{m=(l<<3)-i|0;n=(m|0)<-8?m+512|0:m;m=0;do{o=e[f+((m<<6)+l<<1)>>1]|0;p=(g|o&4095)^2048;do{if(p>>>0<12288){q=(m<<3)-h|0;if((o>>>15|0)!=(a|0)){break}Sj(j,p,(q|0)<-8?q+512|0:q,n,o>>>12|40,4,0,k)}}while(0);m=m+1|0;}while((m|0)<64);l=l+1|0;}while((l|0)<64);return}function dGk(b,d){b=b|0;d=d|0;var e=0,f=0;e=b&65535;if((e&63488|0)!=55296){return}b=c[2387226]|0;a[b+(e&2047)|0]=d;d=e&1023;e=a[b+d|0]|0;f=a[b+(d|1024)|0]|0;b=(e&255)>>>4;c[(c[3530056]|0)+(d<<2)>>2]=((f&8|f<<4)&255)>>>3|((e&12|e<<4)&255)<<3&2016|((b<<4|b)&255)<<8&63488;return}function dGl(a){a=a|0;return 0}function dGm(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;switch(d&255|0){case 12:{d=~e;a[c[2443444]|0]=d&2;a[c[3527476]|0]=d&4;return};case 10:{d=c[3529786]|0;b[d>>1]=b[d>>1]&-256|e&255;return};case 14:{a[c[2437752]|0]=e<<24>>24!=0|0;return};case 9:{d=c[3529790]|0;b[d>>1]=b[d>>1]&255|(e&255)<<8;return};case 13:{d=e&3;a[c[3529484]|0]=d&255;f=c[2406578]|0;g=c[9757320+(c[1836236]<<2)>>2]|0;h=d<<12|-49152;c[g+844>>2]=f+(h+49152);c[g+848>>2]=f+(h+49408);c[g+852>>2]=f+(h+49664);c[g+856>>2]=f+(h+49920);c[g+860>>2]=f+(h+50176);c[g+864>>2]=f+(h+50432);c[g+868>>2]=f+(h+50688);c[g+872>>2]=f+(h+50944);c[g+876>>2]=f+(h+51200);c[g+880>>2]=f+(h+51456);c[g+884>>2]=f+(h+51712);c[g+888>>2]=f+(h+51968);c[g+892>>2]=f+(h+52224);c[g+896>>2]=f+(h+52480);c[g+900>>2]=f+(h+52736);c[g+904>>2]=f+(h+52992);d=192;i=192;while(1){c[g+76+(i+256<<2)>>2]=f+(h+(i<<8));j=d+1&65535;if((j&65535)>207){k=192;l=192;break}else{d=j;i=j&65535}}while(1){i=f+(h+(l<<8))|0;c[g+76+(l+512<<2)>>2]=i;c[g+76+(l+768<<2)>>2]=i;i=k+1&65535;if((i&65535)>207){break}else{k=i;l=i&65535}}return};case 3:{if((a[9635282]&1)==0){return}a[c[2442896]|0]=e<<6^-64;return};case 11:{l=c[3529786]|0;b[l>>1]=b[l>>1]&255|(e&255)<<8;return};case 6:{c[2388374]=0;return};case 8:{l=c[3529790]|0;b[l>>1]=b[l>>1]&-256|e&255;return};case 1:{l=e&15;a[c[3529832]|0]=l&255;k=c[3529248]|0;g=c[9757320+(c[1836236]<<2)>>2]|0;h=(l<<14)+32768|0;l=128;f=128;while(1){c[g+76+(f<<2)>>2]=k+(h+(f<<8));i=l+1&65535;if((i&65535)>191){m=128;n=128;break}else{l=i;f=i&65535}}while(1){f=k+(h+(n<<8))|0;c[g+76+(n+512<<2)>>2]=f;c[g+76+(n+768<<2)>>2]=f;f=m+1&65535;if((f&65535)>191){break}else{m=f;n=f&65535}}return};case 4:{if((e&32)!=0){n=c[1836236]|0;m=c[9757320+(n<<2)>>2]|0;if((m|0)!=0){g=m;gGC(g|0,9706056,76)|0}c[9752472+(n<<2)>>2]=c[2433530];c[14113936+(n<<2)>>2]=c[2076596];c[9669104+(n<<2)>>2]=c[3541536];c[1836236]=-1;n=c[2439331]|0;g=(n|0)==0;if(!g){m=n;gGC(9706056,m|0,76)|0}m=c[2438119]|0;c[2433530]=m;h=c[3528485]|0;c[2076596]=h;k=c[2417277]|0;c[3541536]=k;c[1836236]=1;gGz(9706056,0,76);if(!g){g=n;gGC(g|0,9706056,76)|0}c[2438119]=m;c[3528485]=h;c[2417277]=k;c[1836236]=-1;k=c[2439330]|0;if((k|0)!=0){h=k;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0}a[c[3528724]|0]=e&64;a[c[3527458]|0]=e&-128^-128;return};case 0:{a[c[3528298]|0]=e;return};default:{return}}}function dGn(b){b=b|0;var c=0,d=0;c=b&65535;switch(c&255|0){case 3:case 4:{d=a[9635280+(c&1^1)|0]|0;break};case 0:case 1:case 2:{d=a[9550648+(c&3)|0]|0;break};case 5:{d=1;break};case 7:{d=(e[4853038]|0)>>>8&255;break};default:{d=0}}return d|0}function dGo(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=b&65535;if((e|0)==57345){lS(0,1,d);return}else if((e|0)==57347){lS(1,1,d);return}else if((e|0)==57344){b=c[3541518]|0;f=b+256|0;a[b+304|0]=d;g=d&255;if((d&255)<16){c[14168912+((c[2383582]|0)*252|0)>>2]=g&15}if((d-45&255)>=3){return}if((g|0)==46){h=b+312|0;i=a[h]|1;a[h]=i;j=i}else if((g|0)==0){a[b+312|0]=2;j=2}else if((g|0)==47){a[b+312|0]=0;j=0}else if((g|0)==45){g=b+312|0;i=a[g]|2;a[g]=i;j=i}else{j=a[b+312|0]|0}b=j&3;j=c[7461744+(b<<2)>>2]|0;lI(f,j,j,c[7461728+(b<<2)>>2]|0);return}else if((e|0)==57346){e=c[3541518]|0;b=e+19280|0;a[e+19328|0]=d;j=d&255;if((d&255)<16){c[14168912+(((c[2383582]|0)+1|0)*252|0)>>2]=j&15}if((d-45&255)>=3){return}if((j|0)==46){d=e+19336|0;f=a[d]|1;a[d]=f;k=f}else if((j|0)==0){a[e+19336|0]=2;k=2}else if((j|0)==45){f=e+19336|0;d=a[f]|2;a[f]=d;k=d}else if((j|0)==47){a[e+19336|0]=0;k=0}else{k=a[e+19336|0]|0}e=k&3;k=c[7461744+(e<<2)>>2]|0;lI(b,k,k,c[7461728+(e<<2)>>2]|0);return}else{return}}function dGp(b){b=b|0;var e=0,f=0,g=0,i=0,j=0.0,k=0.0;e=b&65535;if((e|0)==57347){if((d[(c[3541518]|0)+19328|0]|0)>=16){f=0;return f|0}b=(c[2383582]|0)+1|0;g=c[14168912+(b*252|0)>>2]|0;if((g|0)>15){f=0;return f|0}do{if((g|0)==15){i=c[14168900+(b*252|0)>>2]|0;if((i|0)==0){break}a[14168931+(b*252|0)|0]=gj[i&4095](0)|0}else if((g|0)==14){i=c[14168896+(b*252|0)>>2]|0;if((i|0)==0){break}a[14168930+(b*252|0)|0]=gj[i&4095](0)|0}}while(0);f=a[14168916+(b*252|0)+g|0]|0;return f|0}else if((e|0)==57344){g=c[3541518]|0;b=g+296|0;j=+h[b>>3];do{if(j!=0.0){k=+h[6675];if(j-(k+ +gC[c[2429842]&255]())<=0.0){h[b>>3]=0.0;break}f=a[g+307|0]|-128;return f|0}}while(0);f=a[g+307|0]|0;return f|0}else if((e|0)==57345){if((d[(c[3541518]|0)+304|0]|0)>=16){f=0;return f|0}g=c[2383582]|0;b=c[14168912+(g*252|0)>>2]|0;if((b|0)>15){f=0;return f|0}do{if((b|0)==15){i=c[14168900+(g*252|0)>>2]|0;if((i|0)==0){break}a[14168931+(g*252|0)|0]=gj[i&4095](0)|0}else if((b|0)==14){i=c[14168896+(g*252|0)>>2]|0;if((i|0)==0){break}a[14168930+(g*252|0)|0]=gj[i&4095](0)|0}}while(0);f=a[14168916+(g*252|0)+b|0]|0;return f|0}else if((e|0)==57346){b=c[3541518]|0;g=b+19320|0;j=+h[g>>3];do{if(j!=0.0){k=+h[6675];if(j-(k+ +gC[c[2429842]&255]())<=0.0){h[g>>3]=0.0;break}f=a[b+19331|0]|-128;return f|0}}while(0);f=a[b+19331|0]|0;return f|0}else if((e|0)==51200){f=a[c[3528298]|0]|0;return f|0}else{f=0;return f|0}return 0}function dGq(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3067620+(b*112|0)>>2];c[a+104>>2]=c[3067624+(b*112|0)>>2];c[a+108>>2]=c[3067628+(b*112|0)>>2];d=0;return d|0}function dGr(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=3067520+(b*112|0);e=0;return e|0}function dGs(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6930592+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dGt(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>52){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7439568+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dGu(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;e=i;i=i+600|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;c[2415004]=0;c[3529248]=0;c[3529204]=327680;c[3530870]=360448;c[3530634]=491520;c[3530444]=1015808;c[3530056]=1540096;c[2414708]=1544192;c[3529336]=1544192;c[3529294]=1551872;c[2387226]=1553920;c[2405802]=1555968;c[2406578]=1558016;c[2386484]=1574400;c[2386574]=1579008;c[2437752]=1583616;c[3527476]=1583617;c[3527458]=1583618;c[2443444]=1583619;c[3529484]=1583620;c[3529832]=1583621;c[3529790]=1583622;c[3529786]=1583624;c[3528298]=1583626;c[3528724]=1583627;c[2442896]=1583628;c[2411730]=1583629;r=0;while(1){if((r|0)>=1024){break}s=9638528+(r<<2)|0;if((c[s>>2]|0)==0){t=10345;break}else{r=r+1|0}}do{if((t|0)==10345){r=gGq(1583629)|0;c[s>>2]=r;if((r|0)==0){break}c[2415004]=r;gGz(r|0,0,1583629);c[3529248]=r;c[3529204]=r+327680;c[3530870]=r+360448;c[3530634]=r+491520;c[3530444]=r+1015808;c[3530056]=r+1540096;u=r+1544192|0;c[2414708]=u;c[3529336]=u;c[3529294]=r+1551872;c[2387226]=r+1553920;c[2405802]=r+1555968;c[2406578]=r+1558016;c[2386484]=r+1574400;c[2386574]=r+1579008;c[2437752]=r+1583616;c[3527476]=r+1583617;c[3527458]=r+1583618;c[2443444]=r+1583619;c[3529484]=r+1583620;c[3529832]=r+1583621;c[3529790]=r+1583622;c[3529786]=r+1583624;c[3528298]=r+1583626;c[3528724]=r+1583627;c[2442896]=r+1583628;u=r+1583629|0;c[2411730]=u;c[2414272]=u;u=p+108|0;v=p+100|0;w=0;x=r;while(1){r=x+(w<<16)|0;if((c[3542200]|0)==0){y=1;t=10459;break}c[u>>2]=0;c[v>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,w)|0;if((c[u>>2]|0)!=0){z=c[v>>2]|0;c[q>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](q,w,0)|0;if((z|0)<1){y=1;t=10458;break}if((gzL(r,0,w)|0)!=0){y=1;t=10456;break}}r=w+1|0;if((r|0)>=5){t=10354;break}w=r;x=c[3529248]|0}if((t|0)==10456){i=e;return y|0}else if((t|0)==10354){x=c[3529204]|0;if((c[3542200]|0)==0){y=1;i=e;return y|0}w=n+108|0;c[w>>2]=0;v=n+100|0;c[v>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,5)|0;do{if((c[w>>2]|0)!=0){u=c[v>>2]|0;c[o>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](o,5,0)|0;if((u|0)<1){y=1;i=e;return y|0}if((gzL(x,0,5)|0)==0){break}else{y=1}i=e;return y|0}}while(0);x=c[3530870]|0;if((c[3542200]|0)==0){y=1;i=e;return y|0}v=l+108|0;c[v>>2]=0;w=l+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,6)|0;do{if((c[v>>2]|0)!=0){u=c[w>>2]|0;c[m>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](m,6,0)|0;if((u|0)<1){y=1;i=e;return y|0}if((gzL(x,0,6)|0)==0){break}else{y=1}i=e;return y|0}}while(0);x=j+108|0;w=j+100|0;v=f+108|0;u=f+100|0;r=0;while(1){z=r<<16;A=(c[3530634]|0)+z|0;B=r+7|0;if((c[3542200]|0)==0){y=1;t=10461;break}c[x>>2]=0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,B)|0;if((c[x>>2]|0)!=0){C=c[w>>2]|0;c[k>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](k,B,0)|0;if((C|0)<1){y=1;t=10460;break}if((gzL(A,0,B)|0)!=0){y=1;t=10462;break}}B=(c[3530444]|0)+z|0;z=r+11|0;if((c[3542200]|0)==0){y=1;t=10452;break}c[v>>2]=0;c[u>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,z)|0;if((c[v>>2]|0)!=0){A=c[u>>2]|0;c[g>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](g,z,0)|0;if((A|0)<1){y=1;t=10453;break}if((gzL(B,0,z)|0)!=0){y=1;t=10467;break}}z=r+1|0;if((z|0)<4){r=z}else{E=0;t=10372;break}}if((t|0)==10452){i=e;return y|0}else if((t|0)==10467){i=e;return y|0}else if((t|0)==10453){i=e;return y|0}else if((t|0)==10460){i=e;return y|0}else if((t|0)==10461){i=e;return y|0}else if((t|0)==10462){i=e;return y|0}else if((t|0)==10372){while(1){t=0;if((E|0)>=1024){break}F=9638528+(E<<2)|0;if((c[F>>2]|0)==0){t=10374;break}else{E=E+1|0;t=10372}}L13850:do{if((t|0)==10374){r=gGq(262144)|0;c[F>>2]=r;if((r|0)==0){break}gGz(r|0,0,262144);u=c[3530870]|0;gGC(r|0,u|0,32768)|0;v=0;do{w=v<<6;gGz(u+w|0,0,64);x=v<<7;z=x|4;B=0;while(1){A=z+(c[608544+(B<<2)>>2]|0)|0;C=(B<<3)+w|0;D=0;do{G=A+(c[609552+(D<<2)>>2]|0)|0;if(((d[r+((G|0)/8|0)|0]|0)&128>>>((G&7)>>>0)|0)!=0){G=u+(C+D)|0;a[G]=a[G]|2}D=D+1|0;}while((D|0)<8);D=B+1|0;if((D|0)<8){B=D}else{H=0;break}}do{B=x+(c[608544+(H<<2)>>2]|0)|0;z=(H<<3)+w|0;D=0;do{C=B+(c[609552+(D<<2)>>2]|0)|0;if(((d[r+((C|0)/8|0)|0]|0)&128>>>((C&7)>>>0)|0)!=0){C=u+(z+D)|0;a[C]=a[C]|1}D=D+1|0;}while((D|0)<8);H=H+1|0;}while((H|0)<8);v=v+1|0;}while((v|0)<2048);v=c[3530634]|0;gGC(r|0,v|0,262144)|0;u=0;do{w=u<<8;gGz(v+w|0,0,256);x=u<<9;D=0;do{z=1<<3-D;B=(c[961472+(D<<2)>>2]|0)+x|0;C=0;do{A=B+(c[608544+(C<<2)>>2]|0)|0;G=(C<<4)+w|0;I=0;do{J=A+(c[609552+(I<<2)>>2]|0)|0;if(((d[r+((J|0)/8|0)|0]|0)&128>>>((J&7)>>>0)|0)!=0){J=v+(G+I)|0;a[J]=(d[J]|0|z)&255}I=I+1|0;}while((I|0)<16);C=C+1|0;}while((C|0)<16);D=D+1|0;}while((D|0)<4);u=u+1|0;}while((u|0)<2048);u=c[3530444]|0;gGC(r|0,u|0,262144)|0;v=0;while(1){D=v<<8;gGz(u+D|0,0,256);w=v<<9;x=0;do{C=1<<3-x;z=(c[961472+(x<<2)>>2]|0)+w|0;B=0;do{I=z+(c[608544+(B<<2)>>2]|0)|0;G=(B<<4)+D|0;A=0;do{J=I+(c[609552+(A<<2)>>2]|0)|0;if(((d[r+((J|0)/8|0)|0]|0)&128>>>((J&7)>>>0)|0)!=0){J=u+(G+A)|0;a[J]=(d[J]|0|C)&255}A=A+1|0;}while((A|0)<16);B=B+1|0;}while((B|0)<16);x=x+1|0;}while((x|0)<4);x=v+1|0;if((x|0)<2048){v=x}else{K=0;break}}while(1){if((K|0)>=1024){break L13850}L=9638528+(K<<2)|0;if((c[L>>2]|0)==(r|0)){break}else{K=K+1|0}}gGr(r);c[L>>2]=0}}while(0);fwR(0);v=c[2439330]|0;u=(v|0)==0;if(!u){x=v;gGC(9706056,x|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];x=c[3528484]|0;c[2076596]=x;D=c[2417276]|0;c[3541536]=D;c[1836236]=0;w=c[3529248]|0;B=0;C=0;while(1){c[v+76+(C<<2)>>2]=w+(C<<8);z=B+1&65535;if((z&65535)>127){M=0;N=0;break}else{B=z;C=z&65535}}while(1){C=w+(N<<8)|0;c[v+76+(N+512<<2)>>2]=C;c[v+76+(N+768<<2)>>2]=C;C=M+1&65535;if((C&65535)>127){break}else{M=C;N=C&65535}}w=c[2405802]|0;c[v+908>>2]=w;C=w+256|0;c[v+912>>2]=C;B=w+512|0;c[v+916>>2]=B;z=w+768|0;c[v+920>>2]=z;A=w+1024|0;c[v+924>>2]=A;G=w+1280|0;c[v+928>>2]=G;I=w+1536|0;c[v+932>>2]=I;J=w+1792|0;c[v+936>>2]=J;c[v+1932>>2]=w;c[v+1936>>2]=C;c[v+1940>>2]=B;c[v+1944>>2]=z;c[v+1948>>2]=A;c[v+1952>>2]=G;c[v+1956>>2]=I;c[v+1960>>2]=J;c[v+2956>>2]=w;c[v+3980>>2]=w;c[v+2960>>2]=C;c[v+3984>>2]=C;c[v+2964>>2]=B;c[v+3988>>2]=B;c[v+2968>>2]=z;c[v+3992>>2]=z;c[v+2972>>2]=A;c[v+3996>>2]=A;c[v+2976>>2]=G;c[v+4e3>>2]=G;c[v+2980>>2]=I;c[v+4004>>2]=I;c[v+2984>>2]=J;c[v+4008>>2]=J;J=c[2387226]|0;c[v+940>>2]=J;I=J+256|0;c[v+944>>2]=I;G=J+512|0;c[v+948>>2]=G;A=J+768|0;c[v+952>>2]=A;z=J+1024|0;c[v+956>>2]=z;B=J+1280|0;c[v+960>>2]=B;C=J+1536|0;c[v+964>>2]=C;w=J+1792|0;c[v+968>>2]=w;c[v+2988>>2]=J;c[v+4012>>2]=J;c[v+2992>>2]=I;c[v+4016>>2]=I;c[v+2996>>2]=G;c[v+4020>>2]=G;c[v+3e3>>2]=A;c[v+4024>>2]=A;c[v+3004>>2]=z;c[v+4028>>2]=z;c[v+3008>>2]=B;c[v+4032>>2]=B;c[v+3012>>2]=C;c[v+4036>>2]=C;c[v+3016>>2]=w;c[v+4040>>2]=w;w=c[3529336]|0;C=224;B=224;while(1){c[v+76+(B<<2)>>2]=w+((B<<8)-57344);z=C+1&65535;if((z&65535)>253){O=224;P=224;break}else{C=z;B=z&65535}}while(1){c[v+76+(P+256<<2)>>2]=w+((P<<8)-57344);B=O+1&65535;if((B&65535)>253){Q=224;R=224;break}else{O=B;P=B&65535}}while(1){B=w+((R<<8)-57344)|0;c[v+76+(R+512<<2)>>2]=B;c[v+76+(R+768<<2)>>2]=B;B=Q+1&65535;if((B&65535)>253){break}else{Q=B;R=B&65535}}w=c[2386484]|0;c[v+1092>>2]=w;B=w+256|0;c[v+1096>>2]=B;c[v+2116>>2]=w;c[v+2120>>2]=B;c[v+3140>>2]=w;c[v+4164>>2]=w;c[v+3144>>2]=B;c[v+4168>>2]=B;c[v+4184>>2]=860;c[v+4180>>2]=1368;c[v+4172>>2]=2828;c[v+4176>>2]=680;if(!u){B=v;gGC(B|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=x;c[2417276]=D;c[1836236]=-1;fwR(1);B=c[2439331]|0;w=(B|0)==0;if(!w){C=B;gGC(9706056,C|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];C=c[3528485]|0;c[2076596]=C;z=c[2417277]|0;c[3541536]=z;c[1836236]=1;A=c[3529204]|0;G=0;I=0;while(1){c[B+76+(I<<2)>>2]=A+(I<<8);J=G+1&65535;if((J&65535)>127){S=0;T=0;break}else{G=J;I=J&65535}}while(1){I=A+(T<<8)|0;c[B+76+(T+512<<2)>>2]=I;c[B+76+(T+768<<2)>>2]=I;I=S+1&65535;if((I&65535)>127){break}else{S=I;T=I&65535}}A=c[3529294]|0;c[B+844>>2]=A;I=A+256|0;c[B+848>>2]=I;G=A+512|0;c[B+852>>2]=G;D=A+768|0;c[B+856>>2]=D;x=A+1024|0;c[B+860>>2]=x;v=A+1280|0;c[B+864>>2]=v;u=A+1536|0;c[B+868>>2]=u;J=A+1792|0;c[B+872>>2]=J;c[B+1868>>2]=A;c[B+1872>>2]=I;c[B+1876>>2]=G;c[B+1880>>2]=D;c[B+1884>>2]=x;c[B+1888>>2]=v;c[B+1892>>2]=u;c[B+1896>>2]=J;c[B+2892>>2]=A;c[B+3916>>2]=A;c[B+2896>>2]=I;c[B+3920>>2]=I;c[B+2900>>2]=G;c[B+3924>>2]=G;c[B+2904>>2]=D;c[B+3928>>2]=D;c[B+2908>>2]=x;c[B+3932>>2]=x;c[B+2912>>2]=v;c[B+3936>>2]=v;c[B+2916>>2]=u;c[B+3940>>2]=u;c[B+2920>>2]=J;c[B+3944>>2]=J;c[B+4184>>2]=2908;c[B+4180>>2]=902;if(!w){J=B;gGC(J|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=C;c[2417277]=z;c[1836236]=-1;J=c[642608+(c[2436]<<2)>>2]|0;u=c[J+128>>2]|0;if((c[J+52>>2]&4|0)==0){c[2113068]=u;v=c[J+132>>2]|0;c[2113070]=v;c[2443814]=u;c[2440436]=v;U=u;V=v}else{c[2113070]=u;v=c[J+132>>2]|0;c[2113068]=v;c[2440436]=u;c[2443814]=v;U=v;V=u}u=ag(U<<1,V)|0;v=gGq(u)|0;c[2112926]=v;if((v|0)!=0){gGz(v|0,0,u|0)}Vr(2,3579545,750,1600,14,0);c[2438228]=3579545;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=571;h[745419]=.15;a[3203368]=1;h[745418]=.15;a[3203360]=1;h[745417]=.15;a[3203352]=1;h[745416]=.15;a[3203344]=1;h[745415]=.15;a[3203336]=1;h[745414]=.15;a[3203328]=1;h[745413]=.15;a[3203320]=1;h[745412]=.15;a[3203312]=1;u=c[2414708]|0;gGz(u|0,0,(c[2411730]|0)-u|0);u=c[2439330]|0;v=(u|0)==0;if(!v){J=u;gGC(9706056,J|0,76)|0}c[2433530]=c[2438118];J=c[3528484]|0;c[2076596]=J;x=c[2417276]|0;c[3541536]=x;c[1836236]=0;gGz(9706056,0,76);a[c[3529832]|0]=1;D=c[3529248]|0;G=128;I=128;while(1){c[u+76+(I<<2)>>2]=D+((I<<8)+49152);A=G+1&65535;if((A&65535)>191){W=128;X=128;break}else{G=A;I=A&65535}}while(1){I=D+((X<<8)+49152)|0;c[u+76+(X+512<<2)>>2]=I;c[u+76+(X+768<<2)>>2]=I;I=W+1&65535;if((I&65535)>191){break}else{W=I;X=I&65535}}a[c[3529484]|0]=1;D=c[2406578]|0;c[u+844>>2]=D+4096;c[u+848>>2]=D+4352;c[u+852>>2]=D+4608;c[u+856>>2]=D+4864;c[u+860>>2]=D+5120;c[u+864>>2]=D+5376;c[u+868>>2]=D+5632;c[u+872>>2]=D+5888;c[u+876>>2]=D+6144;c[u+880>>2]=D+6400;c[u+884>>2]=D+6656;c[u+888>>2]=D+6912;c[u+892>>2]=D+7168;c[u+896>>2]=D+7424;c[u+900>>2]=D+7680;c[u+904>>2]=D+7936;I=192;G=192;while(1){c[u+76+(G+256<<2)>>2]=D+((G<<8)-45056);z=I+1&65535;if((z&65535)>207){Y=192;Z=192;break}else{I=z;G=z&65535}}while(1){G=D+((Z<<8)-45056)|0;c[u+76+(Z+512<<2)>>2]=G;c[u+76+(Z+768<<2)>>2]=G;G=Y+1&65535;if((G&65535)>207){break}else{Y=G;Z=G&65535}}if(!v){D=u;gGC(D|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=J;c[2417276]=x;c[1836236]=-1;D=c[2439331]|0;G=(D|0)==0;if(!G){I=D;gGC(9706056,I|0,76)|0}I=c[2438119]|0;c[2433530]=I;z=c[3528485]|0;c[2076596]=z;C=c[2417277]|0;c[3541536]=C;c[1836236]=1;gGz(9706056,0,76);if(!G){G=D;gGC(G|0,9706056,76)|0}c[2438119]=I;c[3528485]=z;c[2417277]=C;c[1836236]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){C=0;do{lN(C);mB(C);C=C+1|0;}while((C|0)<(c[2385508]|0))}c[2388374]=0;y=0;i=e;return y|0}}else if((t|0)==10458){i=e;return y|0}else if((t|0)==10459){i=e;return y|0}}}while(0);c[2415004]=0;y=1;i=e;return y|0}function dGv(){var b=0,d=0,e=0,f=0;b=c[3541518]|0;if((b|0)!=0){gGr(b|0);c[3541518]=0}if((c[2385508]|0)>0){c[2113008]=0;c[2076598]=0;c[2383582]=0}c[2438228]=0;c[2433526]=0;c[2406676]=0;c[3528472]=0;b=c[2406680]|0;if((b|0)!=0){gGr(b);c[2406680]=0}c[2385508]=0;c[2432978]=0;a[64240]=0;fwZ();c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}b=c[2415004]|0;d=0;while(1){if((d|0)>=1024){e=10482;break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==(b|0)){break}else{d=d+1|0}}if((e|0)==10482){c[2415004]=0;return 0}gGr(b);c[f>>2]=0;c[2415004]=0;return 0}function dGw(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;do{if((a[9624456]|0)==0){d=c[2388374]|0;if((d|0)<=179){e=d;break}d=c[2439330]|0;f=(d|0)==0;if(!f){g=d;gGC(9706056,g|0,76)|0}c[2433530]=c[2438118];g=c[3528484]|0;c[2076596]=g;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);a[c[3529832]|0]=1;j=c[3529248]|0;k=128;l=128;while(1){c[d+76+(l<<2)>>2]=j+((l<<8)+49152);m=k+1&65535;if((m&65535)>191){n=128;o=128;break}else{k=m;l=m&65535}}while(1){l=j+((o<<8)+49152)|0;c[d+76+(o+512<<2)>>2]=l;c[d+76+(o+768<<2)>>2]=l;l=n+1&65535;if((l&65535)>191){break}else{n=l;o=l&65535}}a[c[3529484]|0]=1;j=c[2406578]|0;c[d+844>>2]=j+4096;c[d+848>>2]=j+4352;c[d+852>>2]=j+4608;c[d+856>>2]=j+4864;c[d+860>>2]=j+5120;c[d+864>>2]=j+5376;c[d+868>>2]=j+5632;c[d+872>>2]=j+5888;c[d+876>>2]=j+6144;c[d+880>>2]=j+6400;c[d+884>>2]=j+6656;c[d+888>>2]=j+6912;c[d+892>>2]=j+7168;c[d+896>>2]=j+7424;c[d+900>>2]=j+7680;c[d+904>>2]=j+7936;l=192;k=192;while(1){c[d+76+(k+256<<2)>>2]=j+((k<<8)-45056);m=l+1&65535;if((m&65535)>207){p=192;q=192;break}else{l=m;k=m&65535}}while(1){k=j+((q<<8)-45056)|0;c[d+76+(q+512<<2)>>2]=k;c[d+76+(q+768<<2)>>2]=k;k=p+1&65535;if((k&65535)>207){break}else{p=k;q=k&65535}}if(!f){j=d;gGC(j|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=g;c[2417276]=i;c[1836236]=-1;j=c[2439331]|0;k=(j|0)==0;if(!k){l=j;gGC(9706056,l|0,76)|0}l=c[2438119]|0;c[2433530]=l;m=c[3528485]|0;c[2076596]=m;r=c[2417277]|0;c[3541536]=r;c[1836236]=1;gGz(9706056,0,76);if(!k){k=j;gGC(k|0,9706056,76)|0}c[2438119]=l;c[3528485]=m;c[2417277]=r;c[1836236]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){r=0;do{lN(r);mB(r);r=r+1|0;}while((r|0)<(c[2385508]|0))}c[2388374]=0;e=0}else{r=c[2414708]|0;gGz(r|0,0,(c[2411730]|0)-r|0);r=c[2439330]|0;i=(r|0)==0;if(!i){g=r;gGC(9706056,g|0,76)|0}c[2433530]=c[2438118];g=c[3528484]|0;c[2076596]=g;d=c[2417276]|0;c[3541536]=d;c[1836236]=0;gGz(9706056,0,76);a[c[3529832]|0]=1;f=c[3529248]|0;m=128;l=128;while(1){c[r+76+(l<<2)>>2]=f+((l<<8)+49152);k=m+1&65535;if((k&65535)>191){s=128;t=128;break}else{m=k;l=k&65535}}while(1){l=f+((t<<8)+49152)|0;c[r+76+(t+512<<2)>>2]=l;c[r+76+(t+768<<2)>>2]=l;l=s+1&65535;if((l&65535)>191){break}else{s=l;t=l&65535}}a[c[3529484]|0]=1;f=c[2406578]|0;c[r+844>>2]=f+4096;c[r+848>>2]=f+4352;c[r+852>>2]=f+4608;c[r+856>>2]=f+4864;c[r+860>>2]=f+5120;c[r+864>>2]=f+5376;c[r+868>>2]=f+5632;c[r+872>>2]=f+5888;c[r+876>>2]=f+6144;c[r+880>>2]=f+6400;c[r+884>>2]=f+6656;c[r+888>>2]=f+6912;c[r+892>>2]=f+7168;c[r+896>>2]=f+7424;c[r+900>>2]=f+7680;c[r+904>>2]=f+7936;l=192;m=192;while(1){c[r+76+(m+256<<2)>>2]=f+((m<<8)-45056);k=l+1&65535;if((k&65535)>207){u=192;v=192;break}else{l=k;m=k&65535}}while(1){m=f+((v<<8)-45056)|0;c[r+76+(v+512<<2)>>2]=m;c[r+76+(v+768<<2)>>2]=m;m=u+1&65535;if((m&65535)>207){break}else{u=m;v=m&65535}}if(!i){f=r;gGC(f|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=g;c[2417276]=d;c[1836236]=-1;f=c[2439331]|0;m=(f|0)==0;if(!m){l=f;gGC(9706056,l|0,76)|0}l=c[2438119]|0;c[2433530]=l;k=c[3528485]|0;c[2076596]=k;j=c[2417277]|0;c[3541536]=j;c[1836236]=1;gGz(9706056,0,76);if(!m){m=f;gGC(m|0,9706056,76)|0}c[2438119]=l;c[3528485]=k;c[2417277]=j;c[1836236]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){j=0;do{lN(j);mB(j);j=j+1|0;}while((j|0)<(c[2385508]|0))}c[2388374]=0;e=0}}while(0);c[2388374]=e+1;a[9550650]=-1;a[9550649]=-1;a[9550648]=-1;e=0;v=-1;u=-1;t=-1;do{v=((a[9633880+e|0]&1)<<e^v&255)&255;u=((a[9631680+e|0]&1)<<e^u&255)&255;t=((a[9629680+e|0]&1)<<e^t&255)&255;e=e+1|0;}while((e|0)<8);a[9550649]=u;a[9550650]=t;a[9550648]=a[c[2442896]|0]|v;v=c[2385548]|0;if((v|0)>0){gGz(9752472,0,((v|0)>1?v<<2:4)|0)}c[2433530]=0;a[6518248]=1;a[6518064]=1;v=0;t=0;while(1){u=c[2439330]|0;if((u|0)!=0){e=u;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;e=c[2438118]|0;c[2433530]=e;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;s=t+1|0;q=((ag(a[6518248]|0?1e5:0,s)|0)/100|0)-v|0;do{if((q|0)<1){w=0;x=e}else{if((a[u+4188|0]|0)==0){p=gfc(q)|0;o=(c[2433530]|0)+p|0;c[2433530]=o;w=p;x=o;break}else{o=e+q|0;c[2433530]=o;w=q;x=o;break}}}while(0);q=w+v|0;if((t|0)==99){a[9706117]=0}else if((t|0)==98){a[9706117]=1}e=c[1836236]|0;u=c[9757320+(e<<2)>>2]|0;if((u|0)!=0){o=u;gGC(o|0,9706056,76)|0}c[9752472+(e<<2)>>2]=x;c[14113936+(e<<2)>>2]=c[2076596];c[9669104+(e<<2)>>2]=c[3541536];c[1836236]=-1;e=c[2439331]|0;if((e|0)!=0){o=e;gGC(9706056,o|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;Sb(ag(a[6518064]|0?596:0,t)|0);o=c[1836236]|0;e=c[9757320+(o<<2)>>2]|0;if((e|0)!=0){u=e;gGC(u|0,9706056,76)|0}c[9752472+(o<<2)>>2]=c[2433530];c[14113936+(o<<2)>>2]=c[2076596];c[9669104+(o<<2)>>2]=c[3541536];c[1836236]=-1;if((s|0)<100){v=q;t=s}else{break}}t=c[2439331]|0;if((t|0)!=0){v=t;gGC(9706056,v|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;v=a[6518064]|0?59659:0;t=gGU(v,0,2048e6,0)|0;x=c[2438228]|0;w=gGS(t,K,x,(x|0)<0|0?-1:0)|0;x=w;Sb(v);v=c[2443830]|0;if((v|0)<1073676288){c[2443830]=v-x}v=c[2443831]|0;if((v|0)<1073676288){c[2443831]=v-x}v=(c[3528512]|0)-x|0;c[3528512]=(v|0)<0?0:v;v=c[2112964]|0;if((v|0)!=0){gg[c[3542122]&4095](v,a[9688]|0?534:0)}v=c[1836236]|0;x=c[9757320+(v<<2)>>2]|0;if((x|0)!=0){w=x;gGC(w|0,9706056,76)|0}c[9752472+(v<<2)>>2]=c[2433530];c[14113936+(v<<2)>>2]=c[2076596];c[9669104+(v<<2)>>2]=c[3541536];c[1836236]=-1;if((c[2112968]|0)==0){y=c[2386574]|0;z=c[2386484]|0;gGC(y|0,z|0,4608)|0;return 0}dGx()|0;y=c[2386574]|0;z=c[2386484]|0;gGC(y|0,z|0,4608)|0;return 0}function dGx(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;if((a[9547608]|0)!=0){f=c[2387226]|0;g=c[3530056]|0;h=0;do{i=a[f+h|0]|0;j=a[f+(h|1024)|0]|0;k=(i&255)>>>4;c[g+(h<<2)>>2]=((j&8|j<<4)&255)>>>3|((i&12|i<<4)&255)<<3&2016|((k<<4|k)&255)<<8&63488;h=h+1|0;}while((h|0)<1024)}h=c[2113068]|0;g=c[2113070]|0;f=ag(g,h)|0;if((f|0)>0){k=c[2112926]|0;i=0;do{b[k+(i<<1)>>1]=1023;i=i+1|0;}while((i|0)<(f|0))}if((a[c[3527476]|0]|0)!=0){f=a[c[2437752]|0]|0;i=f&255;k=e[c[3529790]>>1]&(512<<i|1023);j=(e[c[3529786]>>1]|0)+16&2047>>>(i>>>0);l=1024<<i;m=2048>>>(i>>>0);i=c[2406578]|0;n=c[3528724]|0;o=c[2112926]|0;p=c[3530634]|0;if(f<<24>>24==0){f=0;do{q=f>>6;r=q<<4;s=f<<4;t=(s&768|f&15|r&240|q<<7&14336)<<1;q=(s&1008)-k|0;s=r-j|0;r=((q|0)<-15?l:0)+q|0;q=((s|0)<-15?m:0)+s|0;do{if((r|0)<(h|0)&(q|0)<(g|0)){s=d[i+(t|1)|0]|0;u=s>>>3&15;v=s<<8&1792|d[i+t|0];w=s&128;if((a[n]|0)==0){if((w|0)==0){SH(o,v,r,q,u,4,0,0,p);break}else{SJ(o,v,r,q,u,4,0,0,p);break}}else{s=240-r|0;x=208-q|0;if((w|0)==0){SN(o,v,s,x,u,4,0,0,p);break}else{SL(o,v,s,x,u,4,0,0,p);break}}}}while(0);f=f+1|0;}while((f|0)<8192)}else{f=0;do{q=f>>7;r=q<<4;t=f<<4;u=(t&1792|f&15|r&240|q<<7&6144)<<1;q=(t&2032)-k|0;t=r-j|0;r=((q|0)<-15?l:0)+q|0;q=((t|0)<-15?m:0)+t|0;do{if((r|0)<(h|0)&(q|0)<(g|0)){t=d[i+(u|1)|0]|0;x=t>>>3&15;s=t<<8&1792|d[i+u|0];v=t&128;if((a[n]|0)==0){if((v|0)==0){SH(o,s,r,q,x,4,0,0,p);break}else{SJ(o,s,r,q,x,4,0,0,p);break}}else{t=240-r|0;w=208-q|0;if((v|0)==0){SN(o,s,t,w,x,4,0,0,p);break}else{SL(o,s,t,w,x,4,0,0,p);break}}}}while(0);f=f+1|0;}while((f|0)<8192)}}if((a[c[2443444]|0]|0)!=0){f=c[2386574]|0;p=c[3528724]|0;o=c[2112926]|0;n=c[3530444]|0;i=4604;do{g=d[f+(i|1)|0]|0;h=(d[f+(i|3)|0]|0)-(g<<4&256)|0;m=d[f+(i|2)|0]|0;l=d[f+i|0]|g<<3&1792;j=g&7;k=g&8;g=(a[p]|0)==0;if(g){y=k;z=h;A=m}else{y=k>>>3^1;z=240-h|0;A=240-m|0}m=A-16|0;do{if((A-1|0)>>>0<=254){if((z+15|0)>>>0>270){break}h=(y|0)!=0;if(g){if(h){SJ(o,l,z,m,j,4,15,512,n);break}else{SH(o,l,z,m,j,4,15,512,n);break}}else{if(h){SN(o,l,z,m,j,4,15,512,n);break}else{SL(o,l,z,m,j,4,15,512,n);break}}}}while(0);i=i-4|0;}while((i|0)>-1)}if((a[c[3527458]|0]|0)==0){B=c[3530056]|0;R8(B);return 0}i=c[2405802]|0;n=c[3528724]|0;z=c[2112926]|0;o=c[3530870]|0;y=64;do{A=d[i+(y|1024)|0]|0;p=A<<3&1792|d[i+y|0];f=y<<3&248;j=y>>5<<3;if((a[n]|0)==0){Sq(z,p,f,j-16|0,A&31,2,3,768,o)}else{Sw(z,p,248-f|0,232-j|0,A&31,2,3,768,o)}y=y+1|0;}while((y|0)<960);B=c[3530056]|0;R8(B);return 0}function dGy(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=i;i=i+16|0;g=f|0;if((e|0)!=0){c[e>>2]=169624}if((d&32|0)!=0){gGz(g|0,0,12);h=c[2414708]|0;c[g>>2]=h;c[g+4>>2]=(c[2411730]|0)-h;c[g+12>>2]=162152;h=c[2076592]|0;gj[h&4095](g)|0}if((d&64|0)!=0){fw$(d);Vx(d,e)}e=c[2439330]|0;d=(e|0)==0;if(!d){g=e;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];g=c[3528484]|0;c[2076596]=g;h=c[2417276]|0;c[3541536]=h;c[1836236]=0;j=c[3529832]|0;k=a[j]&15;a[j]=k&255;j=c[3529248]|0;l=(k<<14)+32768|0;k=128;m=128;while(1){c[e+76+(m<<2)>>2]=j+(l+(m<<8));n=k+1&65535;if((n&65535)>191){o=128;p=128;break}else{k=n;m=n&65535}}while(1){m=j+(l+(p<<8))|0;c[e+76+(p+512<<2)>>2]=m;c[e+76+(p+768<<2)>>2]=m;m=o+1&65535;if((m&65535)>191){break}else{o=m;p=m&65535}}p=c[3529484]|0;o=a[p]&3;a[p]=o&255;p=c[2406578]|0;l=o<<12|-49152;c[e+844>>2]=p+(l+49152);c[e+848>>2]=p+(l+49408);c[e+852>>2]=p+(l+49664);c[e+856>>2]=p+(l+49920);c[e+860>>2]=p+(l+50176);c[e+864>>2]=p+(l+50432);c[e+868>>2]=p+(l+50688);c[e+872>>2]=p+(l+50944);c[e+876>>2]=p+(l+51200);c[e+880>>2]=p+(l+51456);c[e+884>>2]=p+(l+51712);c[e+888>>2]=p+(l+51968);c[e+892>>2]=p+(l+52224);c[e+896>>2]=p+(l+52480);c[e+900>>2]=p+(l+52736);c[e+904>>2]=p+(l+52992);o=192;j=192;while(1){c[e+76+(j+256<<2)>>2]=p+(l+(j<<8));m=o+1&65535;if((m&65535)>207){q=192;r=192;break}else{o=m;j=m&65535}}while(1){j=p+(l+(r<<8))|0;c[e+76+(r+512<<2)>>2]=j;c[e+76+(r+768<<2)>>2]=j;j=q+1&65535;if((j&65535)>207){break}else{q=j;r=j&65535}}if(d){s=c[2433530]|0;c[2438118]=s;c[3528484]=g;c[2417276]=h;c[1836236]=-1;i=f;return 0}d=e;gGC(d|0,9706056,76)|0;s=c[2433530]|0;c[2438118]=s;c[3528484]=g;c[2417276]=h;c[1836236]=-1;i=f;return 0}function dGz(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1610460+(b*112|0)>>2];c[a+104>>2]=c[1610464+(b*112|0)>>2];c[a+108>>2]=c[1610468+(b*112|0)>>2];d=0;return d|0}function dGA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=1610360+(b*112|0);e=0;return e|0}function dGB(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1167788+(b*112|0)>>2];c[a+104>>2]=c[1167792+(b*112|0)>>2];c[a+108>>2]=c[1167796+(b*112|0)>>2];d=0;return d|0}function dGC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=1167688+(b*112|0);e=0;return e|0}function dGD(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1165660+(b*112|0)>>2];c[a+104>>2]=c[1165664+(b*112|0)>>2];c[a+108>>2]=c[1165668+(b*112|0)>>2];d=0;return d|0}function dGE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=1165560+(b*112|0);e=0;return e|0}function dGF(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3070980+(b*112|0)>>2];c[a+104>>2]=c[3070984+(b*112|0)>>2];c[a+108>>2]=c[3070988+(b*112|0)>>2];d=0;return d|0}function dGG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=3070880+(b*112|0);e=0;return e|0}function dGH(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1613820+(b*112|0)>>2];c[a+104>>2]=c[1613824+(b*112|0)>>2];c[a+108>>2]=c[1613828+(b*112|0)>>2];d=0;return d|0}function dGI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=1613720+(b*112|0);e=0;return e|0}function dGJ(b,c){b=b|0;c=c|0;a[9706117]=c&1;return}function dGK(a){a=a|0;var b=0,d=0;b=(c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,3579545,0)|0;return a|0}function dGL(){return+(+((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)/3579545.0)}function dGM(f){f=f|0;var g=0,h=0,i=0,j=0;L14272:do{switch(c[2444210]|0){case 11:{if((f<<16>>16|0)==20673){g=(c[2436774]|0)+1|0;c[2436774]=g;h=g>>>10&1;break L14272}else if((f<<16>>16|0)==20672){h=(cT()|0)&255;break L14272}else{i=10718;break L14272}break};case 10:{g=f&65535;if((g&65520|0)==24544){h=(d[(c[2429840]|0)+(g>>>2&3)|0]|0)>>>4;break L14272}if(f<<16>>16==24575){h=a[9635275]|0;break L14272}if((g&32768|0)==0){i=10718;break L14272}h=a[(c[2407130]|0)+(c[2394738]<<15|g&32767)|0]|0;break};case 3:{g=f&65472;if((g|0)==20672){j=e[4853030]|0;if((j|0)==1093|(j|0)==1038){h=32;break L14272}if((j|0)==15078|(j|0)==15074|(j|0)==4446|(j|0)==4443){h=0;break L14272}j=f&63;if((j|0)==9){h=48;break L14272}else if((j|0)==12){h=0;break L14272}else if((j|0)==0){h=31;break L14272}else{h=32;break L14272}}else if((g|0)==20608){g=a[9635274]|0;j=e[4853030]|0;if((j|0)==9097|(j|0)==9095|(j|0)==6515|(j|0)==6510){h=g|64;break L14272}j=f&63;if((j|0)==1|(j|0)==4){h=g|64;break L14272}else if((j|0)==5){h=g|-64;break L14272}else{h=g&63;break L14272}}else{i=10718;break L14272}break};case 12:{if(f<<16>>16!=20608){i=10718;break L14272}h=a[9550641]|0;break};case 2:{if((f&-4096)<<16>>16!=12288){i=10718;break L14272}g=f&4095;if((g|0)==263){h=64;break L14272}else if((g|0)==1){if((b[4853030]|0)!=11159){h=-1;break L14272}j=a[9718696]|0;a[9718696]=j-1&255;h=70>>>((j&255)>>>0)<<7&255;break L14272}else if((g|0)==4){a[9718696]=7;h=0;break L14272}else{h=0;break L14272}break};default:{i=10718}}}while(0);do{if((i|0)==10718){g=f&65535;j=g&65472;if((j|0)==20480){h=a[9550640]|0;break}else if((j|0)==20608){h=a[9635274]|0;break}else if((j|0)==20672){h=a[9635275]|0;break}else if((j|0)==20544){h=a[9550641]|0;break}else{h=(g&64512|0)==18432?-65:0;break}}}while(0);return h|0}function dGN(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;L14321:do{switch(c[2444210]|0){case 5:{if(b<<16>>16!=20481){e=b;break L14321}f=(d&1)!=0?44373:0;g=c[3531014]|0;h=c[2406946]|0;i=0;do{if((a[g+(i+256)|0]|0)==0){c[h+(i<<2)>>2]=f}i=i+1|0;}while((i|0)<256);return};case 11:{i=b&65535;if(b<<16>>16==20674){a[9706117]=0;c[2438258]=d&255;return}f=i&65520;if((f|0)==20544){UY(i&15,d);return}else if((f|0)==20560){a[(c[3529614]|0)+(i&15)|0]=d;return}else if((f|0)==20576){UY(i&15|16,d);return}else{if(b<<16>>16!=20480){e=b;break L14321}c[2388372]=0;return}break};case 14:{i=(b&-32)<<16>>16==20608?b-64&65535:b;f=(i&-16)<<16>>16==20640?i-64&65535:i;if((f<<16>>16|0)==20480){return}else if((f<<16>>16|0)==20481){c[2438258]=d&1;e=20481;break L14321}else{e=f;break L14321}break};case 10:{f=b&65535;if((f&65532|0)==24544){a[(c[2429840]|0)+(f&3)|0]=d;return}if(b<<16>>16!=24560){e=b;break L14321}c[2394738]=d&255;return};case 9:{if(b<<16>>16!=24576){e=b;break L14321}c[2394738]=d&255;return};default:{e=b}}}while(0);b=e&65535;if((b&65504|0)==20544){UY(b&31,d);return}if((b&65520|0)==20576){a[(c[3529614]|0)+(b&15)|0]=d;return}if((b|0)==20480){c[2438258]=d&1;return}else if((b|0)==20483){a[c[3528722]|0]=d&1;return}else if((b|0)==20672){c[2388372]=0;return}else{return}}function dGO(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[2444210]|0;if((d|0)==9){e=a[(c[2407130]|0)+((c[2394738]<<16|b&65535)^65535)|0]|0;return e|0}f=b&255;if((d|0)==12){if((f<<16>>16|0)==2){e=a[9635274]|0;return e|0}else if((f<<16>>16|0)==1){e=a[9635275]|0;return e|0}else{e=0;return e|0}}else if((d|0)==15){g=a[9717168]|0;do{if((b&1)==0){h=g+1&15;a[9717168]=h;i=h}else{h=g-1&255;a[9717168]=h;if(h<<24>>24>=0){i=h;break}a[9717168]=15;e=0;return e|0}}while(0);if((i-8&255)>=4){e=0;return e|0}g=i&3;c[2394738]=g;i=c[2385942]|0;b=g<<14|65536;g=c[9757320+(c[1836236]<<2)>>2]|0;h=0;j=0;while(1){c[g+76+(j<<2)>>2]=i+((j<<8)+b);k=h+1&65535;if((k&65535)>63){break}else{h=k;j=k&65535}}j=(c[2394738]<<14)+65536|0;h=0;b=0;while(1){k=i+(j+(b<<8))|0;c[g+76+(b+512<<2)>>2]=k;c[g+76+(b+768<<2)>>2]=k;k=h+1&65535;if((k&65535)>63){e=0;break}else{h=k;b=k&65535}}return e|0}else if((d|0)==8){if(f<<16>>16!=0){e=0;return e|0}f=a[9734320]|0;a[9734320]=f+1&255;e=f;return e|0}else{e=0;return e|0}return 0}function dGP(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;e=b&255;switch(c[2444210]|0){case 12:{if((e&65535)>=2){return}f=d&255;if((b&1)!=0){c[3542228]=f&15;return}g=c[3542228]|0;if((g|0)>15){return}do{if((g|0)<14){if((g|0)!=13){if((a[14168916+g|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(0,g,f);return};case 4:{if(e<<16>>16!=0){return}c[2438256]=d<<24>>24==-6?120:d&255;return};case 5:{if((e-1&65535)>=2){return}TR((e&65535)-1|0,d&255);return};case 7:{if((e-6&65535)>=2){return}f=d&255;if((b&1)!=0){c[3542228]=f&15;return}b=c[3542228]|0;if((b|0)>15){return}do{if((b|0)<14){if((b|0)!=13){if((a[14168916+b|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(0,b,f);return};case 6:{if(e<<16>>16!=0){return}f=d<<24>>24==-65?60:d;c[2438256]=f<<24>>24==-58?64:f&255;return};default:{if(e<<16>>16!=0){return}c[2438256]=d&255;a[14125144]=d;a[9706117]=0;return}}}function dGQ(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=b&65535;do{if((b&65535)<16384){if((b&65535)<=55){e=0;f=0;break}if((b&65535)<=943){e=0;f=(b&65535)<64|0;break}if((b&65535)<=5631){e=0;f=(b&65535)<952|0;break}if((b&65535)<=8479){e=0;f=(b&65535)<5640|0;break}if((b&65535)<=16367){e=0;f=(b&65535)<8488|0;break}e=0;f=(b&65535)<16376|0}else{if(b<<16>>16<0&(b&65535)<49152){g=(b&65535)<32776|0;if((b&65535)<=38895){e=0;f=g;break}e=(b&65535)<38904|0;f=g;break}if((d&64512|0)==18432){h=-65;return h|0}g=((d&65280|0)==20480?b&-64:b)&65535;if((g|0)==20544){h=a[9550641]|0;return h|0}else if((g|0)==20480){h=a[9550640]|0;return h|0}else if((g|0)==20672){h=a[9635275]|0;return h|0}else if((g|0)==20608){h=a[9635274]|0;return h|0}else{h=0;return h|0}}}while(0);if((e|f|0)!=0){c[2394738]=0}if((b-16376&65535)<8){c[2394738]=1;i=65536}else{i=c[2394738]<<16}h=a[(c[2385942]|0)+(i|d)|0]|0;return h|0}function dGR(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=b&65535;do{if((b&65535)>55){if((b&65535)<=943){f=0;g=(b&65535)<64|0;break}if((b&65535)<=5631){f=0;g=(b&65535)<952|0;break}if((b&65535)<=8479){f=0;g=(b&65535)<5640|0;break}if((b&65535)<=16367){f=0;g=(b&65535)<8488|0;break}if(b<<16>>16>=0){f=0;g=(b&65535)<16376|0;break}h=(b&65535)<32776|0;if((b&65535)<=38895){f=0;g=h;break}f=(b&65535)<38904|0;g=h}else{f=0;g=0}}while(0);if((f|g|0)!=0){c[2394738]=0}if((b-16376&65535)<8){c[2394738]=1}if((e&65504|0)==20544){UY(e&31,d);return}if((e&65520|0)==20576){a[(c[3529614]|0)+(e&15)|0]=d;return}if((e|0)==20483){a[c[3528722]|0]=d&1;return}else if((e|0)==20480){c[2438258]=d&1;return}else if((e|0)==20672){c[2388372]=0;return}else{return}}function dGS(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((e&65504|0)==36864){UY(e&31,d);return}if((e&65520|0)==36896){a[(c[3529614]|0)+(e&15)|0]=d;return}switch(e|0){case 36935:{e=d&1;a[9620488]=e;a[14112808]=e;return};case 36928:{c[2438258]=d&1;return};case 36930:{a[9775016]=d;return};case 36931:{a[c[3528722]|0]=d&1;return};case 36976:{c[2388372]=0;return};case 36934:{a[9753272]=d;return};default:{return}}}function dGT(b){b=b|0;var c=0,d=0;c=b&65472;if((c|0)==36864){d=a[9635275]|0}else if((c|0)==37056){d=a[9550640]|0}else if((c|0)==36992){d=a[9550641]|0}else if((c|0)==36928){d=a[9635274]|0}else{d=0}return d|0}function dGU(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4472556+(b*112|0)>>2];c[a+104>>2]=c[4472560+(b*112|0)>>2];c[a+108>>2]=c[4472564+(b*112|0)>>2];d=0;return d|0}function dGV(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=4472456+(b*112|0);e=0;return e|0}function dGW(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6930304+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dGX(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>29){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7439208+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dGY(){return dK0(4924,0,0)|0}function dGZ(){var b=0,d=0,e=0,f=0;c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}fwZ();c[2113008]=0;c[2076598]=0;c[2383582]=0;TT();b=c[2420424]|0;if((b|0)!=0){gGr(b);c[2420424]=0}b=c[2433528]|0;if((b|0)!=0){gGr(b);c[2433528]=0}c[2444210]=0;a[673120]=0;c[2394738]=-1;b=c[2415002]|0;d=0;while(1){if((d|0)>=1024){e=10966;break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==(b|0)){break}else{d=d+1|0}}if((e|0)==10966){c[2415002]=0;return 0}gGr(b);c[f>>2]=0;c[2415002]=0;return 0}function dG_(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=(c[2388372]|0)+1|0;c[2388372]=d;if(d>>>0>15){dK4(0)}if((a[9624448]|0)!=0){dK4(1)}b[4775320]=0;d=0;e=0;f=0;do{e=((a[9633872+d|0]&1)<<d^e&255)&255;f=((a[9631672+d|0]&1)<<d^f&255)&255;d=d+1|0;}while((d|0)<8);a[9550640]=e;a[9550641]=f;d=c[2444210]|0;do{if((d|0)!=13&(a[673120]^1)){if((e&6)==6){g=e&-7;a[9550640]=g;h=g}else{h=e}if((h&9)==9){g=h&-10;a[9550640]=g;i=g}else{i=h}if((f&6)==6){g=f&-7;a[9550641]=g;j=g}else{j=f}if((j&9)!=9){k=i;l=j;break}g=j&-10;a[9550641]=g;k=i;l=g}else{k=e;l=f}}while(0);f=a[9635272]^k;a[9550640]=f;k=a[9635273]^l;a[9550641]=k;if((d|0)==13){a[9550640]=f;a[9550641]=k}k=c[2439330]|0;if((k|0)!=0){f=k;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;f=a[9688]|0?534:0;k=f-1|0;d=0;l=0;e=0;L14642:while(1){i=l;j=e;while(1){if((j|0)>=(f|0)){break L14642}m=j+1|0;h=((m*51200|0|0)/534|0)-i|0;do{if((h|0)<1){n=0}else{if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){g=gfc(h)|0;c[2433530]=(c[2433530]|0)+g;n=g;break}else{c[2433530]=(c[2433530]|0)+h;n=h;break}}}while(0);o=n+i|0;h=c[2444210]|0;do{if((h|0)==9){g=a[9688]|0?26:0;p=0;do{if((j|0)==((ag(p,g)|0)-1|0)){a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0}p=p+1|0;}while((p|0)<20)}else{p=(j|0)==(k|0);if(!((h|0)==7|(h|0)==5)){if(!(p&(c[2438258]|0)!=0)){break}a[14125144]=c[2438256]&255;a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0;break}if(!p){break}if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12}}while(0);q=c[2112964]|0;if((q|0)==0){i=o;j=m}else{break}}j=a[9688]|0;i=j&1;h=q+(d<<1<<1)|0;do{if(j){p=c[2444210]|0;if((p|0)==5){TQ(0,h,i);TQ(1,h,i);break}else if((p|0)==12|(p|0)==7){mF(9756168,h,i,0);break}else{UX(h,i);break}}}while(0);d=i+d|0;l=o;e=m}m=c[2112964]|0;do{if((m|0)!=0){e=a[9688]|0?534:0;o=e-d|0;l=m+(d<<1<<1)|0;if((e|0)==(d|0)){break}e=c[2444210]|0;if((e|0)==5){TQ(0,l,o);TQ(1,l,o);break}else if((e|0)==12|(e|0)==7){mF(9756168,l,o,0);break}else{UX(l,o);break}}}while(0);d=c[1836236]|0;m=c[9757320+(d<<2)>>2]|0;if((m|0)!=0){o=m;gGC(o|0,9706056,76)|0}c[9752472+(d<<2)>>2]=c[2433530];c[14113936+(d<<2)>>2]=c[2076596];c[9669104+(d<<2)>>2]=c[3541536];c[1836236]=-1;if((c[2112968]|0)==0){return 0}dG$()|0;return 0}function dG$(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;if((a[9547600]|0)!=0){dK3();a[9547600]=0}e=c[2386230]|0;f=c[2387878]|0;g=c[3528722]|0;h=c[2112926]|0;i=c[2387824]|0;j=0;do{k=(j|0)%36|0;l=(j|0)/36|0;m=l+2|0;n=k-2|0;if((n&32|0)==0){o=(m<<5)+n|0}else{o=(n<<5&992)+m|0}m=d[e+o|0]|d[9620488]<<8;n=d[9753272]<<5|a[f+o|0]&31|d[9775016]<<6;p=k<<3;if((a[g]|0)==0){Sj(h,m,p,l<<3,n,2,0,i)}else{Sp(h,m,280-p|0,216-(l<<3)|0,n,2,0,i)}j=j+1|0;}while((j|0)<1008);j=c[2386482]|0;o=d[14112808]<<6;f=d[9753272]<<5;e=d[9775016]<<6;n=c[3529614]|0;l=c[2439514]|0;p=c[2113070]|0;m=c[2113068]|0;k=14;do{q=d[j+k|0]|0;r=k|1;s=d[n+r|0]|0;t=d[n+k|0]|0;u=q&1;v=q&2;if((a[g]|0)==0){w=v;x=u;y=t-31|0;z=272-s|0}else{w=v>>>1^1;x=u^1;y=232-t|0;z=s+8|0}s=(f|a[j+r|0]&31|e)<<2;r=(w|0)==0?0:240;t=(x|0)==0?r:r|15;r=((o|q>>>2)<<8)+32768|0;q=y;u=0;while(1){if((q|0)>-1&(q|0)<(p|0)){v=u<<4;A=ag(m,q)|0;B=z;C=0;while(1){do{if((B|0)>=0&(B|0)<(m|0)){D=d[i+(r+(C+v^t))|0]|s;if((a[l+D|0]|0)==0){break}b[h+(A+B<<1)>>1]=D&65535}}while(0);D=C+1|0;if((D|0)<16){B=B+1|0;C=D}else{break}}}C=u+1|0;if((C|0)>=16){break}q=q+1|0;u=C}k=k-2|0;}while((k|0)>-1);R8(c[2406946]|0);return 0}function dG0(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;e=i;i=i+240|0;f=e|0;g=e+16|0;h=e+48|0;j=e+64|0;k=e+80|0;l=e+96|0;m=e+112|0;n=e+128|0;o=e+144|0;p=e+160|0;q=e+176|0;r=e+192|0;s=e+208|0;t=e+224|0;u=(d|0)==0;if(!u){c[d>>2]=169619}if((b&96|0)!=0){gGz(t|0,0,12);v=c[2414706]|0;c[t>>2]=v;c[t+4>>2]=(c[2411728]|0)-v;c[t+12>>2]=162152;v=c[2076592]|0;gj[v&4095](t)|0;fw$(b);t=e+32|0;v=(b&64|0)==0;if(!v){if(!u){c[d>>2]=169735}gGC(t|0,117464,15)|0;c[g>>2]=c[2433528];c[g+4>>2]=64;c[g+8>>2]=0;c[g+12>>2]=t;w=c[2076592]|0;gj[w&4095](g)|0}do{if(!v){do{if(!u){if((c[d>>2]|0)>=169110){break}c[d>>2]=169110}}while(0);if((c[2113008]|0)<=0){break}g=f|0;w=f+4|0;x=f+8|0;y=f+12|0;z=0;do{cC(t|0,531144,(A=i,i=i+8|0,c[A>>2]=z,A)|0)|0;i=A;c[g>>2]=14168888+(z*252|0);c[w>>2]=252;c[x>>2]=0;c[y>>2]=t;gj[c[2076592]&4095](f)|0;z=z+1|0;}while((z|0)<(c[2113008]|0))}}while(0);TU(b,d);gGz(s|0,0,12);c[s>>2]=9578952;c[s+4>>2]=4;c[s+12>>2]=215136;d=c[2076592]|0;gj[d&4095](s)|0;gGz(r|0,0,12);c[r>>2]=9753024;c[r+4>>2]=4;c[r+12>>2]=214792;s=c[2076592]|0;gj[s&4095](r)|0;gGz(q|0,0,12);c[q>>2]=9753032;c[q+4>>2]=4;c[q+12>>2]=214600;r=c[2076592]|0;gj[r&4095](q)|0;gGz(p|0,0,12);c[p>>2]=9753272;c[p+4>>2]=1;c[p+12>>2]=214296;q=c[2076592]|0;gj[q&4095](p)|0;gGz(o|0,0,12);c[o>>2]=9775016;c[o+4>>2]=1;c[o+12>>2]=213944;p=c[2076592]|0;gj[p&4095](o)|0;gGz(n|0,0,12);c[n>>2]=14112808;c[n+4>>2]=1;c[n+12>>2]=213528;o=c[2076592]|0;gj[o&4095](n)|0;gGz(m|0,0,12);c[m>>2]=9620488;c[m+4>>2]=1;c[m+12>>2]=213192;n=c[2076592]|0;gj[n&4095](m)|0;gGz(l|0,0,12);c[l>>2]=9747096;c[l+4>>2]=4;c[l+12>>2]=212672;m=c[2076592]|0;gj[m&4095](l)|0;gGz(k|0,0,12);c[k>>2]=9717168;c[k+4>>2]=1;c[k+12>>2]=212352;l=c[2076592]|0;gj[l&4095](k)|0;gGz(j|0,0,12);c[j>>2]=9734320;c[j+4>>2]=1;c[j+12>>2]=211968;k=c[2076592]|0;gj[k&4095](j)|0;gGz(h|0,0,12);c[h>>2]=9718696;c[h+4>>2]=1;c[h+12>>2]=211808;j=c[2076592]|0;gj[j&4095](h)|0}if((b&2|0)==0){i=e;return 0}b=c[2444210]|0;if((b|0)==8){B=11068}else if((b|0)!=15){i=e;return 0}do{if((B|0)==11068){h=a[9635275]&1;c[2394738]=h;j=c[2385942]|0;k=h<<15;h=c[9757320+(c[1836236]<<2)>>2]|0;l=0;m=0;while(1){c[h+76+(m<<2)>>2]=j+((m<<8)+k);n=l+1&65535;if((n&65535)>63){break}else{l=n;m=n&65535}}m=c[2394738]<<15;l=0;k=0;while(1){n=j+((k<<8)+m)|0;c[h+76+(k+512<<2)>>2]=n;c[h+76+(k+768<<2)>>2]=n;n=l+1&65535;if((n&65535)>63){break}else{l=n;k=n&65535}}k=(c[2394738]<<15|16384)-32768|0;l=128;m=128;while(1){c[h+76+(m<<2)>>2]=j+(k+(m<<8));n=l+1&65535;if((n&65535)>191){break}else{l=n;m=n&65535}}m=(c[2394738]<<15|16384)-32768|0;l=128;k=128;while(1){n=j+(m+(k<<8))|0;c[h+76+(k+512<<2)>>2]=n;c[h+76+(k+768<<2)>>2]=n;n=l+1&65535;if((n&65535)>191){break}else{l=n;k=n&65535}}if((b|0)==15){break}i=e;return 0}}while(0);b=c[2394738]&3;c[2394738]=b;B=c[2385942]|0;k=b<<14|65536;b=c[9757320+(c[1836236]<<2)>>2]|0;l=0;h=0;while(1){c[b+76+(h<<2)>>2]=B+((h<<8)+k);m=l+1&65535;if((m&65535)>63){break}else{l=m;h=m&65535}}h=(c[2394738]<<14)+65536|0;l=0;k=0;while(1){m=B+(h+(k<<8))|0;c[b+76+(k+512<<2)>>2]=m;c[b+76+(k+768<<2)>>2]=m;m=l+1&65535;if((m&65535)>63){break}else{l=m;k=m&65535}}i=e;return 0}function dG1(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2427748+(b*112|0)>>2];c[a+104>>2]=c[2427752+(b*112|0)>>2];c[a+108>>2]=c[2427756+(b*112|0)>>2];d=0;return d|0}function dG2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=2427648+(b*112|0);e=0;return e|0}function dG3(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2426628+(b*112|0)>>2];c[a+104>>2]=c[2426632+(b*112|0)>>2];c[a+108>>2]=c[2426636+(b*112|0)>>2];d=0;return d|0}function dG4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=2426528+(b*112|0);e=0;return e|0}function dG5(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2425284+(b*112|0)>>2];c[a+104>>2]=c[2425288+(b*112|0)>>2];c[a+108>>2]=c[2425292+(b*112|0)>>2];d=0;return d|0}function dG6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=2425184+(b*112|0);e=0;return e|0}function dG7(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4471436+(b*112|0)>>2];c[a+104>>2]=c[4471440+(b*112|0)>>2];c[a+108>>2]=c[4471444+(b*112|0)>>2];d=0;return d|0}function dG8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=4471336+(b*112|0);e=0;return e|0}function dG9(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5746636+(b*112|0)>>2];c[a+104>>2]=c[5746640+(b*112|0)>>2];c[a+108>>2]=c[5746644+(b*112|0)>>2];d=0;return d|0}function dHa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=5746536+(b*112|0);e=0;return e|0}function dHb(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4495532+(b*112|0)>>2];c[a+104>>2]=c[4495536+(b*112|0)>>2];c[a+108>>2]=c[4495540+(b*112|0)>>2];d=0;return d|0}function dHc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=4495432+(b*112|0);e=0;return e|0}function dHd(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5873932+(b*112|0)>>2];c[a+104>>2]=c[5873936+(b*112|0)>>2];c[a+108>>2]=c[5873940+(b*112|0)>>2];d=0;return d|0}function dHe(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=5873832+(b*112|0);e=0;return e|0}function dHf(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4675948+(b*112|0)>>2];c[a+104>>2]=c[4675952+(b*112|0)>>2];c[a+108>>2]=c[4675956+(b*112|0)>>2];d=0;return d|0}function dHg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=4675848+(b*112|0);e=0;return e|0}function dHh(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4674156+(b*112|0)>>2];c[a+104>>2]=c[4674160+(b*112|0)>>2];c[a+108>>2]=c[4674164+(b*112|0)>>2];d=0;return d|0}function dHi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=4674056+(b*112|0);e=0;return e|0}function dHj(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1435012+(b*112|0)>>2];c[a+104>>2]=c[1435016+(b*112|0)>>2];c[a+108>>2]=c[1435020+(b*112|0)>>2];d=0;return d|0}function dHk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=1434912+(b*112|0);e=0;return e|0}function dHl(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4492620+(b*112|0)>>2];c[a+104>>2]=c[4492624+(b*112|0)>>2];c[a+108>>2]=c[4492628+(b*112|0)>>2];d=0;return d|0}function dHm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=4492520+(b*112|0);e=0;return e|0}function dHn(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>29){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5176384+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dHo(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2999044+(b*112|0)>>2];c[a+104>>2]=c[2999048+(b*112|0)>>2];c[a+108>>2]=c[2999052+(b*112|0)>>2];d=0;return d|0}function dHp(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=2998944+(b*112|0);e=0;return e|0}function dHq(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5745516+(b*112|0)>>2];c[a+104>>2]=c[5745520+(b*112|0)>>2];c[a+108>>2]=c[5745524+(b*112|0)>>2];d=0;return d|0}function dHr(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=5745416+(b*112|0);e=0;return e|0}function dHs(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2506980+(b*112|0)>>2];c[a+104>>2]=c[2506984+(b*112|0)>>2];c[a+108>>2]=c[2506988+(b*112|0)>>2];d=0;return d|0}function dHt(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=2506880+(b*112|0);e=0;return e|0}function dHu(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2479380+(b*112|0)>>2];c[a+104>>2]=c[2479384+(b*112|0)>>2];c[a+108>>2]=c[2479388+(b*112|0)>>2];d=0;return d|0}function dHv(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=2479280+(b*112|0);e=0;return e|0}function dHw(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5844684+(b*112|0)>>2];c[a+104>>2]=c[5844688+(b*112|0)>>2];c[a+108>>2]=c[5844692+(b*112|0)>>2];d=0;return d|0}function dHx(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=5844584+(b*112|0);e=0;return e|0}function dHy(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4790452+(b*112|0)>>2];c[a+104>>2]=c[4790456+(b*112|0)>>2];c[a+108>>2]=c[4790460+(b*112|0)>>2];d=0;return d|0}function dHz(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=4790352+(b*112|0);e=0;return e|0}function dHA(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2983588+(b*112|0)>>2];c[a+104>>2]=c[2983592+(b*112|0)>>2];c[a+108>>2]=c[2983596+(b*112|0)>>2];d=0;return d|0}function dHB(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=2983488+(b*112|0);e=0;return e|0}function dHC(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>5){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2474452+(b*112|0)>>2];c[a+104>>2]=c[2474456+(b*112|0)>>2];c[a+108>>2]=c[2474460+(b*112|0)>>2];d=0;return d|0}function dHD(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<6&(d|0)==0)){e=1;return e|0}c[a>>2]=2474352+(b*112|0);e=0;return e|0}function dHE(){return dK0(4924,6518,0)|0}function dHF(){var b=0,e=0,f=0,g=0,h=0;b=c[2385942]|0;e=0;do{f=b+e|0;g=c[601864+((e>>>1&2|e&1|e>>>3&4|e>>>4&8|e>>>5&16)<<2)>>2]^e>>>11&1;h=d[f]|0;a[f]=((h>>>((d[601993+(g*9|0)|0]|0)>>>0)<<6&64|h>>>((d[601992+(g*9|0)|0]|0)>>>0)<<7&128|h>>>((d[601994+(g*9|0)|0]|0)>>>0)<<5&32|h>>>((d[601995+(g*9|0)|0]|0)>>>0)<<4&16|h>>>((d[601996+(g*9|0)|0]|0)>>>0)<<3&8|h>>>((d[601997+(g*9|0)|0]|0)>>>0)<<2&4|h>>>((d[601998+(g*9|0)|0]|0)>>>0)<<1&2|h>>>((d[601999+(g*9|0)|0]|0)>>>0)&1)^(d[602e3+(g*9|0)|0]|0))&255;e=e+1|0;}while((e|0)<16384);return}function dHG(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4494412+(b*112|0)>>2];c[a+104>>2]=c[4494416+(b*112|0)>>2];c[a+108>>2]=c[4494420+(b*112|0)>>2];d=0;return d|0}function dHH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=4494312+(b*112|0);e=0;return e|0}function dHI(){return dK0(4924,1700,0)|0}function dHJ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4513172+(b*112|0)>>2];c[a+104>>2]=c[4513176+(b*112|0)>>2];c[a+108>>2]=c[4513180+(b*112|0)>>2];d=0;return d|0}function dHK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=4513072+(b*112|0);e=0;return e|0}function dHL(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2508100+(b*112|0)>>2];c[a+104>>2]=c[2508104+(b*112|0)>>2];c[a+108>>2]=c[2508108+(b*112|0)>>2];d=0;return d|0}function dHM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=2508e3+(b*112|0);e=0;return e|0}function dHN(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2558604+(b*112|0)>>2];c[a+104>>2]=c[2558608+(b*112|0)>>2];c[a+108>>2]=c[2558612+(b*112|0)>>2];d=0;return d|0}function dHO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=2558504+(b*112|0);e=0;return e|0}function dHP(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>26){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=2559960+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dHQ(){return dK0(10552,7684,1)|0}function dHR(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2554348+(b*112|0)>>2];c[a+104>>2]=c[2554352+(b*112|0)>>2];c[a+108>>2]=c[2554356+(b*112|0)>>2];d=0;return d|0}function dHS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=2554248+(b*112|0);e=0;return e|0}function dHT(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2557148+(b*112|0)>>2];c[a+104>>2]=c[2557152+(b*112|0)>>2];c[a+108>>2]=c[2557156+(b*112|0)>>2];d=0;return d|0}function dHU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=2557048+(b*112|0);e=0;return e|0}function dHV(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2563524+(b*112|0)>>2];c[a+104>>2]=c[2563528+(b*112|0)>>2];c[a+108>>2]=c[2563532+(b*112|0)>>2];d=0;return d|0}function dHW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=2563424+(b*112|0);e=0;return e|0}function dHX(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2560388+(b*112|0)>>2];c[a+104>>2]=c[2560392+(b*112|0)>>2];c[a+108>>2]=c[2560396+(b*112|0)>>2];d=0;return d|0}function dHY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=2560288+(b*112|0);e=0;return e|0}function dHZ(){return dK0(10552,0,0)|0}function dH_(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2555804+(b*112|0)>>2];c[a+104>>2]=c[2555808+(b*112|0)>>2];c[a+108>>2]=c[2555812+(b*112|0)>>2];d=0;return d|0}function dH$(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=2555704+(b*112|0);e=0;return e|0}function dH0(){return dK0(10552,11604,0)|0}function dH1(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5747756+(b*112|0)>>2];c[a+104>>2]=c[5747760+(b*112|0)>>2];c[a+108>>2]=c[5747764+(b*112|0)>>2];d=0;return d|0}function dH2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=5747656+(b*112|0);e=0;return e|0}function dH3(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2553004+(b*112|0)>>2];c[a+104>>2]=c[2553008+(b*112|0)>>2];c[a+108>>2]=c[2553012+(b*112|0)>>2];d=0;return d|0}function dH4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=2552904+(b*112|0);e=0;return e|0}function dH5(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>5){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1040244+(b*112|0)>>2];c[a+104>>2]=c[1040248+(b*112|0)>>2];c[a+108>>2]=c[1040252+(b*112|0)>>2];d=0;return d|0}function dH6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<6&(d|0)==0)){e=1;return e|0}c[a>>2]=1040144+(b*112|0);e=0;return e|0}function dH7(){return dK0(10552,6518,0)|0}function dH8(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>5){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4533356+(b*112|0)>>2];c[a+104>>2]=c[4533360+(b*112|0)>>2];c[a+108>>2]=c[4533364+(b*112|0)>>2];d=0;return d|0}function dH9(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<6&(d|0)==0)){e=1;return e|0}c[a>>2]=4533256+(b*112|0);e=0;return e|0}function dIa(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1457024+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dIb(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>30){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4533928+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dIc(){return dK0(5534,5406,8)|0}function dId(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>5){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2565764+(b*112|0)>>2];c[a+104>>2]=c[2565768+(b*112|0)>>2];c[a+108>>2]=c[2565772+(b*112|0)>>2];d=0;return d|0}function dIe(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<6&(d|0)==0)){e=1;return e|0}c[a>>2]=2565664+(b*112|0);e=0;return e|0}function dIf(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6595868+(b*112|0)>>2];c[a+104>>2]=c[6595872+(b*112|0)>>2];c[a+108>>2]=c[6595876+(b*112|0)>>2];d=0;return d|0}function dIg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=6595768+(b*112|0);e=0;return e|0}function dIh(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=2618368+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dIi(){return dK0(4924,12098,0)|0}function dIj(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4766212+(b*112|0)>>2];c[a+104>>2]=c[4766216+(b*112|0)>>2];c[a+108>>2]=c[4766220+(b*112|0)>>2];d=0;return d|0}function dIk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=4766112+(b*112|0);e=0;return e|0}function dIl(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2993556+(b*112|0)>>2];c[a+104>>2]=c[2993560+(b*112|0)>>2];c[a+108>>2]=c[2993564+(b*112|0)>>2];d=0;return d|0}function dIm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=2993456+(b*112|0);e=0;return e|0}function dIn(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2992212+(b*112|0)>>2];c[a+104>>2]=c[2992216+(b*112|0)>>2];c[a+108>>2]=c[2992220+(b*112|0)>>2];d=0;return d|0}function dIo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=2992112+(b*112|0);e=0;return e|0}function dIp(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5929444+(b*112|0)>>2];c[a+104>>2]=c[5929448+(b*112|0)>>2];c[a+108>>2]=c[5929452+(b*112|0)>>2];d=0;return d|0}function dIq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=5929344+(b*112|0);e=0;return e|0}function dIr(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5927652+(b*112|0)>>2];c[a+104>>2]=c[5927656+(b*112|0)>>2];c[a+108>>2]=c[5927660+(b*112|0)>>2];d=0;return d|0}function dIs(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=5927552+(b*112|0);e=0;return e|0}function dIt(){return dK0(4924,4660,0)|0}function dIu(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>5){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5926980+(b*112|0)>>2];c[a+104>>2]=c[5926984+(b*112|0)>>2];c[a+108>>2]=c[5926988+(b*112|0)>>2];d=0;return d|0}function dIv(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<6&(d|0)==0)){e=1;return e|0}c[a>>2]=5926880+(b*112|0);e=0;return e|0}function dIw(){return dK0(4924,7246,0)|0}function dIx(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2472660+(b*112|0)>>2];c[a+104>>2]=c[2472664+(b*112|0)>>2];c[a+108>>2]=c[2472668+(b*112|0)>>2];d=0;return d|0}function dIy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=2472560+(b*112|0);e=0;return e|0}function dIz(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5788264+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dIA(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5925588+(b*112|0)>>2];c[a+104>>2]=c[5925592+(b*112|0)>>2];c[a+108>>2]=c[5925596+(b*112|0)>>2];d=0;return d|0}function dIB(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=5925488+(b*112|0);e=0;return e|0}function dIC(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>40){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5926384+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dID(){return dK0(4924,0,12)|0}function dIE(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2617348+(b*112|0)>>2];c[a+104>>2]=c[2617352+(b*112|0)>>2];c[a+108>>2]=c[2617356+(b*112|0)>>2];d=0;return d|0}function dIF(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=2617248+(b*112|0);e=0;return e|0}function dIG(){return dK0(4924,12098,3)|0}function dIH(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2616228+(b*112|0)>>2];c[a+104>>2]=c[2616232+(b*112|0)>>2];c[a+108>>2]=c[2616236+(b*112|0)>>2];d=0;return d|0}function dII(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=2616128+(b*112|0);e=0;return e|0}function dIJ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5787020+(b*112|0)>>2];c[a+104>>2]=c[5787024+(b*112|0)>>2];c[a+108>>2]=c[5787028+(b*112|0)>>2];d=0;return d|0}function dIK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=5786920+(b*112|0);e=0;return e|0}function dIL(){return dK0(4924,10404,0)|0}function dIM(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2673036+(b*112|0)>>2];c[a+104>>2]=c[2673040+(b*112|0)>>2];c[a+108>>2]=c[2673044+(b*112|0)>>2];d=0;return d|0}function dIN(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=2672936+(b*112|0);e=0;return e|0}function dIO(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1087088+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dIP(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=2674056+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dIQ(){return dK0(4924,3176,3)|0}function dIR(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7057100+(b*112|0)>>2];c[a+104>>2]=c[7057104+(b*112|0)>>2];c[a+108>>2]=c[7057108+(b*112|0)>>2];d=0;return d|0}function dIS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=7057e3+(b*112|0);e=0;return e|0}function dIT(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5902160+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dIU(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7058120+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dIV(){return dK0(4924,4660,0)|0}function dIW(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6582084+(b*112|0)>>2];c[a+104>>2]=c[6582088+(b*112|0)>>2];c[a+108>>2]=c[6582092+(b*112|0)>>2];d=0;return d|0}function dIX(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=6581984+(b*112|0);e=0;return e|0}function dIY(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6580292+(b*112|0)>>2];c[a+104>>2]=c[6580296+(b*112|0)>>2];c[a+108>>2]=c[6580300+(b*112|0)>>2];d=0;return d|0}function dIZ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=6580192+(b*112|0);e=0;return e|0}function dI_(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2872036+(b*112|0)>>2];c[a+104>>2]=c[2872040+(b*112|0)>>2];c[a+108>>2]=c[2872044+(b*112|0)>>2];d=0;return d|0}function dI$(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=2871936+(b*112|0);e=0;return e|0}function dI0(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6519484+(b*112|0)>>2];c[a+104>>2]=c[6519488+(b*112|0)>>2];c[a+108>>2]=c[6519492+(b*112|0)>>2];d=0;return d|0}function dI1(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=6519384+(b*112|0);e=0;return e|0}function dI2(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6520504+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dI3(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4695636+(b*112|0)>>2];c[a+104>>2]=c[4695640+(b*112|0)>>2];c[a+108>>2]=c[4695644+(b*112|0)>>2];d=0;return d|0}function dI4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=4695536+(b*112|0);e=0;return e|0}function dI5(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6583204+(b*112|0)>>2];c[a+104>>2]=c[6583208+(b*112|0)>>2];c[a+108>>2]=c[6583212+(b*112|0)>>2];d=0;return d|0}function dI6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=6583104+(b*112|0);e=0;return e|0}function dI7(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4481292+(b*112|0)>>2];c[a+104>>2]=c[4481296+(b*112|0)>>2];c[a+108>>2]=c[4481300+(b*112|0)>>2];d=0;return d|0}function dI8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=4481192+(b*112|0);e=0;return e|0}function dI9(){return dK0(4924,4660,4)|0}function dJa(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2454804+(b*112|0)>>2];c[a+104>>2]=c[2454808+(b*112|0)>>2];c[a+108>>2]=c[2454812+(b*112|0)>>2];d=0;return d|0}function dJb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=2454704+(b*112|0);e=0;return e|0}function dJc(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2456596+(b*112|0)>>2];c[a+104>>2]=c[2456600+(b*112|0)>>2];c[a+108>>2]=c[2456604+(b*112|0)>>2];d=0;return d|0}function dJd(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=2456496+(b*112|0);e=0;return e|0}function dJe(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5958044+(b*112|0)>>2];c[a+104>>2]=c[5958048+(b*112|0)>>2];c[a+108>>2]=c[5958052+(b*112|0)>>2];d=0;return d|0}function dJf(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=5957944+(b*112|0);e=0;return e|0}function dJg(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2731004+(b*112|0)>>2];c[a+104>>2]=c[2731008+(b*112|0)>>2];c[a+108>>2]=c[2731012+(b*112|0)>>2];d=0;return d|0}function dJh(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=2730904+(b*112|0);e=0;return e|0}function dJi(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1091240+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dJj(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=2732024+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dJk(){return dK0(4924,718,0)|0}function dJl(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1520508+(b*112|0)>>2];c[a+104>>2]=c[1520512+(b*112|0)>>2];c[a+108>>2]=c[1520516+(b*112|0)>>2];d=0;return d|0}function dJm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=1520408+(b*112|0);e=0;return e|0}function dJn(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=2730672+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dJo(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3033316+(b*112|0)>>2];c[a+104>>2]=c[3033320+(b*112|0)>>2];c[a+108>>2]=c[3033324+(b*112|0)>>2];d=0;return d|0}function dJp(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=3033216+(b*112|0);e=0;return e|0}function dJq(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1115168+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dJr(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3034784+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dJs(){return dK0(11076,0,2)|0}function dJt(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2076404+(b*112|0)>>2];c[a+104>>2]=c[2076408+(b*112|0)>>2];c[a+108>>2]=c[2076412+(b*112|0)>>2];d=0;return d|0}function dJu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=2076304+(b*112|0);e=0;return e|0}function dJv(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1336512+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dJw(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>23){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4313848+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dJx(){return dK0(5534,2394,0)|0}function dJy(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2075172+(b*112|0)>>2];c[a+104>>2]=c[2075176+(b*112|0)>>2];c[a+108>>2]=c[2075180+(b*112|0)>>2];d=0;return d|0}function dJz(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=2075072+(b*112|0);e=0;return e|0}function dJA(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5798188+(b*112|0)>>2];c[a+104>>2]=c[5798192+(b*112|0)>>2];c[a+108>>2]=c[5798196+(b*112|0)>>2];d=0;return d|0}function dJB(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=5798088+(b*112|0);e=0;return e|0}function dJC(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=2639576+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dJD(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5799432+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dJE(){return dK0(5534,0,0)|0}function dJF(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4477148+(b*112|0)>>2];c[a+104>>2]=c[4477152+(b*112|0)>>2];c[a+108>>2]=c[4477156+(b*112|0)>>2];d=0;return d|0}function dJG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=4477048+(b*112|0);e=0;return e|0}function dJH(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1436704+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dJI(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>36){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4478616+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dJJ(){return dK0(5534,3830,0)|0}function dJK(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2446852+(b*112|0)>>2];c[a+104>>2]=c[2446856+(b*112|0)>>2];c[a+108>>2]=c[2446860+(b*112|0)>>2];d=0;return d|0}function dJL(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=2446752+(b*112|0);e=0;return e|0}function dJM(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2163884+(b*112|0)>>2];c[a+104>>2]=c[2163888+(b*112|0)>>2];c[a+108>>2]=c[2163892+(b*112|0)>>2];d=0;return d|0}function dJN(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=2163784+(b*112|0);e=0;return e|0}function dJO(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=999432+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dJP(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=2164680+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dJQ(){return dK0(4924,11784,15)|0}function dJR(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2229780+(b*112|0)>>2];c[a+104>>2]=c[2229784+(b*112|0)>>2];c[a+108>>2]=c[2229788+(b*112|0)>>2];d=0;return d|0}function dJS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=2229680+(b*112|0);e=0;return e|0}function dJT(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2230676+(b*112|0)>>2];c[a+104>>2]=c[2230680+(b*112|0)>>2];c[a+108>>2]=c[2230684+(b*112|0)>>2];d=0;return d|0}function dJU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=2230576+(b*112|0);e=0;return e|0}function dJV(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5944564+(b*112|0)>>2];c[a+104>>2]=c[5944568+(b*112|0)>>2];c[a+108>>2]=c[5944572+(b*112|0)>>2];d=0;return d|0}function dJW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=5944464+(b*112|0);e=0;return e|0}function dJX(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5634628+(b*112|0)>>2];c[a+104>>2]=c[5634632+(b*112|0)>>2];c[a+108>>2]=c[5634636+(b*112|0)>>2];d=0;return d|0}function dJY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=5634528+(b*112|0);e=0;return e|0}function dJZ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=2100936+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dJ_(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>23){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5635536+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dJ$(){return dK0(5830,3880,5)|0}function dJ0(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4331556+(b*112|0)>>2];c[a+104>>2]=c[4331560+(b*112|0)>>2];c[a+108>>2]=c[4331564+(b*112|0)>>2];d=0;return d|0}function dJ1(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=4331456+(b*112|0);e=0;return e|0}function dJ2(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1350384+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dJ3(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4332564+(b*112|0)>>2];c[a+104>>2]=c[4332568+(b*112|0)>>2];c[a+108>>2]=c[4332572+(b*112|0)>>2];d=0;return d|0}function dJ4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=4332464+(b*112|0);e=0;return e|0}function dJ5(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5750900+(b*112|0)>>2];c[a+104>>2]=c[5750904+(b*112|0)>>2];c[a+108>>2]=c[5750908+(b*112|0)>>2];d=0;return d|0}function dJ6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=5750800+(b*112|0);e=0;return e|0}function dJ7(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>26){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5752592+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dJ8(){return dK0(4924,4660,6)|0}function dJ9(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4509796+(b*112|0)>>2];c[a+104>>2]=c[4509800+(b*112|0)>>2];c[a+108>>2]=c[4509804+(b*112|0)>>2];d=0;return d|0}function dKa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=4509696+(b*112|0);e=0;return e|0}function dKb(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2920764+(b*112|0)>>2];c[a+104>>2]=c[2920768+(b*112|0)>>2];c[a+108>>2]=c[2920772+(b*112|0)>>2];d=0;return d|0}function dKc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=2920664+(b*112|0);e=0;return e|0}function dKd(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1105328+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dKe(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>24){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=2921896+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dKf(){return dK0(5830,0,7)|0}function dKg(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3037540+(b*112|0)>>2];c[a+104>>2]=c[3037544+(b*112|0)>>2];c[a+108>>2]=c[3037548+(b*112|0)>>2];d=0;return d|0}function dKh(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=3037440+(b*112|0);e=0;return e|0}function dKi(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1115456+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dKj(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>25){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3038224+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dKk(){a[673120]=1;return dK0(4924,1270,15)|0}function dKl(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5956980+(b*112|0)>>2];c[a+104>>2]=c[5956984+(b*112|0)>>2];c[a+108>>2]=c[5956988+(b*112|0)>>2];d=0;return d|0}function dKm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=5956880+(b*112|0);e=0;return e|0}function dKn(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3187032+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dKo(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5957664+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dKp(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3090020+(b*112|0)>>2];c[a+104>>2]=c[3090024+(b*112|0)>>2];c[a+108>>2]=c[3090028+(b*112|0)>>2];d=0;return d|0}function dKq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=3089920+(b*112|0);e=0;return e|0}function dKr(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1169816+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dKs(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>23){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3092048+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dKt(){return dK0(9236,0,9)|0}function dKu(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2371996+(b*112|0)>>2];c[a+104>>2]=c[2372e3+(b*112|0)>>2];c[a+108>>2]=c[2372004+(b*112|0)>>2];d=0;return d|0}function dKv(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=2371896+(b*112|0);e=0;return e|0}function dKw(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1023120+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dKx(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>46){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=2374472+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dKy(){return dK0(6098,8856,10)|0}function dKz(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4848036+(b*112|0)>>2];c[a+104>>2]=c[4848040+(b*112|0)>>2];c[a+108>>2]=c[4848044+(b*112|0)>>2];d=0;return d|0}function dKA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=4847936+(b*112|0);e=0;return e|0}function dKB(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1620928+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dKC(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>27){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4849616+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dKD(){return dK0(7094,2932,11)|0}function dKE(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3169684+(b*112|0)>>2];c[a+104>>2]=c[3169688+(b*112|0)>>2];c[a+108>>2]=c[3169692+(b*112|0)>>2];d=0;return d|0}function dKF(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=3169584+(b*112|0);e=0;return e|0}function dKG(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5942100+(b*112|0)>>2];c[a+104>>2]=c[5942104+(b*112|0)>>2];c[a+108>>2]=c[5942108+(b*112|0)>>2];d=0;return d|0}function dKH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=5942e3+(b*112|0);e=0;return e|0}function dKI(){return dK0(4924,0,14)|0}function dKJ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6505372+(b*112|0)>>2];c[a+104>>2]=c[6505376+(b*112|0)>>2];c[a+108>>2]=c[6505380+(b*112|0)>>2];d=0;return d|0}function dKK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=6505272+(b*112|0);e=0;return e|0}function dKL(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5148176+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dKM(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>61){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6817552+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dKN(){return dK0(966,12740,16)|0}function dKO(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5743948+(b*112|0)>>2];c[a+104>>2]=c[5743952+(b*112|0)>>2];c[a+108>>2]=c[5743956+(b*112|0)>>2];d=0;return d|0}function dKP(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=5743848+(b*112|0);e=0;return e|0}function dKQ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4486332+(b*112|0)>>2];c[a+104>>2]=c[4486336+(b*112|0)>>2];c[a+108>>2]=c[4486340+(b*112|0)>>2];d=0;return d|0}function dKR(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=4486232+(b*112|0);e=0;return e|0}function dKS(){return dK0(966,12454,16)|0}function dKT(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4484764+(b*112|0)>>2];c[a+104>>2]=c[4484768+(b*112|0)>>2];c[a+108>>2]=c[4484772+(b*112|0)>>2];d=0;return d|0}function dKU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=4484664+(b*112|0);e=0;return e|0}function dKV(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5742380+(b*112|0)>>2];c[a+104>>2]=c[5742384+(b*112|0)>>2];c[a+108>>2]=c[5742388+(b*112|0)>>2];d=0;return d|0}function dKW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=5742280+(b*112|0);e=0;return e|0}function dKX(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5741036+(b*112|0)>>2];c[a+104>>2]=c[5741040+(b*112|0)>>2];c[a+108>>2]=c[5741044+(b*112|0)>>2];d=0;return d|0}function dKY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=5740936+(b*112|0);e=0;return e|0}function dKZ(){return dK0(966,7206,16)|0}function dK_(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6503804+(b*112|0)>>2];c[a+104>>2]=c[6503808+(b*112|0)>>2];c[a+108>>2]=c[6503812+(b*112|0)>>2];d=0;return d|0}function dK$(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=6503704+(b*112|0);e=0;return e|0}function dK0(e,f,g){e=e|0;f=f|0;g=g|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0.0,ah=0,ai=0;j=i;i=i+720|0;k=j|0;l=j+112|0;m=j+120|0;n=j+232|0;o=j+240|0;p=j+352|0;q=j+360|0;r=j+472|0;s=j+480|0;t=j+592|0;u=j+600|0;v=j+608|0;c[2444210]=g;c[2415002]=0;c[2385942]=0;c[2407130]=131072;w=(g|0)==9?524288:131072;x=(g|0)==10?w+262144|0:w;c[2387824]=x;c[3531014]=x+65536;c[3541148]=x+66816;c[2439514]=x+67328;c[2406946]=x+67840;w=x+69888|0;c[2414706]=w;c[2386096]=w;c[2386482]=x+((g|0)==11?71664:71920);c[3529614]=x+73984;c[2387878]=x+74e3;c[2386230]=x+75024;c[2429840]=x+76048;c[3528722]=x+76052;g=x+76053|0;c[2411728]=g;c[2439042]=g;g=a[9688]|0?1068:0;w=g+76053|0;c[2439043]=x+w;y=w+g|0;c[2439044]=x+y;w=x+(y+g)|0;c[2414270]=w;g=w;w=0;while(1){if((w|0)>=1024){break}z=9638528+(w<<2)|0;if((c[z>>2]|0)==0){A=12494;break}else{w=w+1|0}}do{if((A|0)==12494){w=gGq(g)|0;c[z>>2]=w;if((w|0)==0){break}gGz(w|0,0,g|0);c[2415002]=w;gGz(w|0,0,g|0);c[2385942]=w;y=w+131072|0;c[2407130]=y;x=c[2444210]|0;B=(x|0)==9?w+524288|0:y;w=(x|0)==10?B+262144|0:B;c[2387824]=w;B=w+65536|0;c[3531014]=B;C=w+66816|0;c[3541148]=C;c[2439514]=w+67328;c[2406946]=w+67840;D=w+69888|0;c[2414706]=D;c[2386096]=D;c[2386482]=w+((x|0)==11?71664:71920);c[3529614]=w+73984;c[2387878]=w+74e3;c[2386230]=w+75024;c[2429840]=w+76048;c[3528722]=w+76052;x=w+76053|0;c[2411728]=x;c[2439042]=x;x=a[9688]|0?1068:0;D=x+76053|0;c[2439043]=w+D;E=D+x|0;c[2439044]=w+E;c[2414270]=w+(E+x);L16324:do{if((gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](u,0,0)|0)==0){x=v+108|0;E=v+100|0;D=s+108|0;F=s+100|0;G=q+108|0;H=q+100|0;I=o+108|0;J=o+100|0;K=m+108|0;L=m+100|0;M=k+108|0;N=k+100|0;O=0;P=w;Q=B;R=C;S=y;T=0;L16326:while(1){gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,T)|0;switch(c[x>>2]&7|0){case 4:{if((c[3542200]|0)==0){U=1;A=12586;break L16326}c[K>>2]=0;c[L>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,T)|0;if((c[K>>2]|0)!=0){V=c[L>>2]|0;c[n>>2]=9534384;W=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[W&16383](n,T,0)|0;if((V|0)<1){U=1;A=12587;break L16326}if((gzL(R,0,T)|0)!=0){U=1;A=12588;break L16326}}X=S;Y=R+256|0;Z=Q;_=P;$=O;break};case 2:{if((c[3542200]|0)==0){U=1;A=12591;break L16326}c[G>>2]=0;c[H>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](q,T)|0;if((c[G>>2]|0)!=0){V=c[H>>2]|0;c[r>>2]=9534384;W=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[W&16383](r,T,0)|0;if((V|0)<1){U=1;A=12596;break L16326}if((gzL(P,0,T)|0)!=0){U=1;A=12597;break L16326}}X=S;Y=R;Z=Q;_=P+(c[E>>2]|0)|0;$=O;break};case 1:{V=(c[2385942]|0)+O|0;if((c[3542200]|0)==0){U=1;A=12592;break L16326}c[D>>2]=0;c[F>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](s,T)|0;if((c[D>>2]|0)!=0){W=c[F>>2]|0;c[t>>2]=9534384;aa=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aa&16383](t,T,0)|0;if((W|0)<1){U=1;A=12589;break L16326}if((gzL(V,0,T)|0)!=0){U=1;A=12590;break L16326}}V=c[2444210]|0;if((V|0)==1){ab=O+4096|0}else{ab=(c[E>>2]|0)+O|0}X=S;Y=R;Z=Q;_=P;$=(ab|0)==16384&(V|0)!=16?32768:ab;break};case 7:{if((c[3542200]|0)==0){U=1;A=12593;break L16326}c[M>>2]=0;c[N>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,T)|0;if((c[M>>2]|0)!=0){V=c[N>>2]|0;c[l>>2]=9534384;W=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[W&16383](l,T,0)|0;if((V|0)<1){U=1;A=12594;break L16326}if((gzL(S,0,T)|0)!=0){U=1;A=12595;break L16326}}X=S+(c[E>>2]|0)|0;Y=R;Z=Q;_=P;$=O;break};case 3:{if((c[3542200]|0)==0){U=1;A=12598;break L16326}c[I>>2]=0;c[J>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](o,T)|0;if((c[I>>2]|0)!=0){V=c[J>>2]|0;c[p>>2]=9534384;W=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[W&16383](p,T,0)|0;if((V|0)<1){U=1;A=12599;break L16326}if((gzL(Q,0,T)|0)!=0){U=1;A=12600;break L16326}}X=S;Y=R;Z=Q+256|0;_=P;$=O;break};default:{X=S;Y=R;Z=Q;_=P;$=O}}V=T+1|0;if((gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](u,V,0)|0)==0){O=$;P=_;Q=Z;R=Y;S=X;T=V}else{break L16324}}if((A|0)==12586){i=j;return U|0}else if((A|0)==12587){i=j;return U|0}else if((A|0)==12588){i=j;return U|0}else if((A|0)==12589){i=j;return U|0}else if((A|0)==12590){i=j;return U|0}else if((A|0)==12591){i=j;return U|0}else if((A|0)==12592){i=j;return U|0}else if((A|0)==12593){i=j;return U|0}else if((A|0)==12594){i=j;return U|0}else if((A|0)==12595){i=j;return U|0}else if((A|0)==12596){i=j;return U|0}else if((A|0)==12597){i=j;return U|0}else if((A|0)==12598){i=j;return U|0}else if((A|0)==12599){i=j;return U|0}else if((A|0)==12600){i=j;return U|0}}}while(0);if((f|0)!=0){gu[f&16383]()}y=(c[2444210]|0)==16?8192:4096;C=y<<1;B=0;while(1){if((B|0)>=1024){ac=0;break}ad=9638528+(B<<2)|0;if((c[ad>>2]|0)==0){A=12533;break}else{B=B+1|0}}do{if((A|0)==12533){B=gGq(C)|0;c[ad>>2]=B;if((B|0)==0){ac=0;break}gGz(B|0,0,C|0);w=c[2387824]|0;gGC(B|0,w|0,C)|0;T=y>>>4;S=0;do{R=S<<6;gGz(w+R|0,0,64);Q=S<<7;P=0;do{O=Q+(c[611712+(P<<2)>>2]|0)|0;J=(P<<3)+R|0;I=0;do{E=O+(c[610928+(I<<2)>>2]|0)|0;if(((d[B+((E|0)/8|0)|0]|0)&128>>>((E&7)>>>0)|0)!=0){E=w+(J+I)|0;a[E]=a[E]|2}I=I+1|0;}while((I|0)<8);P=P+1|0;}while((P|0)<8);P=Q|4;I=0;do{J=P+(c[611712+(I<<2)>>2]|0)|0;O=(I<<3)+R|0;E=0;do{N=J+(c[610928+(E<<2)>>2]|0)|0;if(((d[B+((N|0)/8|0)|0]|0)&128>>>((N&7)>>>0)|0)!=0){N=w+(O+E)|0;a[N]=a[N]|1}E=E+1|0;}while((E|0)<8);I=I+1|0;}while((I|0)<8);S=S+1|0;}while((S|0)<(T|0));T=y>>>6;S=0;while(1){I=(S<<8)+32768|0;gGz(w+I|0,0,256);R=S<<9;P=0;do{Q=R+(c[611712+(P<<2)>>2]|0)|0;E=I+(P<<4)|0;O=0;do{J=Q+(c[61e4+(O<<2)>>2]|0)|0;if(((d[B+(((J|0)/8|0)+y)|0]|0)&128>>>((J&7)>>>0)|0)!=0){J=w+(E+O)|0;a[J]=a[J]|2}O=O+1|0;}while((O|0)<16);P=P+1|0;}while((P|0)<16);P=R|4;O=0;do{E=P+(c[611712+(O<<2)>>2]|0)|0;Q=I+(O<<4)|0;J=0;do{N=E+(c[61e4+(J<<2)>>2]|0)|0;if(((d[B+(((N|0)/8|0)+y)|0]|0)&128>>>((N&7)>>>0)|0)!=0){N=w+(Q+J)|0;a[N]=a[N]|1}J=J+1|0;}while((J|0)<16);O=O+1|0;}while((O|0)<16);O=S+1|0;if((O|0)<(T|0)){S=O}else{ac=B;break}}}}while(0);y=0;while(1){if((y|0)>=1024){break}ae=9638528+(y<<2)|0;if((c[ae>>2]|0)==(ac|0)){A=12553;break}else{y=y+1|0}}if((A|0)==12553){gGr(ac);c[ae>>2]=0}dK3();y=c[3531014]|0;C=c[2439514]|0;B=0;do{a[C+B|0]=(a[y+(B|256)|0]&15)!=0|0;B=B+1|0;}while((B|0)<256);fwR(0);B=c[2439330]|0;if((B|0)!=0){y=B;gGC(9706056,y|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;gu[e&16383]();y=c[1836236]|0;B=c[9757320+(y<<2)>>2]|0;if((B|0)!=0){C=B;gGC(C|0,9706056,76)|0}c[9752472+(y<<2)>>2]=c[2433530];c[14113936+(y<<2)>>2]=c[2076596];c[9669104+(y<<2)>>2]=c[3541536];c[1836236]=-1;y=a[9680]|0?32e3:0;c[3542220]=11200;if((c[2113008]|0)==0){gGz(14168888,0,252);c[3542223]=y;gGz(14168896,0,16);c[3542234]=~~((+(y|0)*32768.0*8.0+894875.0)/1789750.0);y=31;af=32767.0;while(1){c[14169012+(y<<2)>>2]=~~(af+.5);C=y-1|0;if((C|0)>0){y=C;af=af/1.188502227}else{break}}c[3542253]=0;h[1771269]=1.0;h[1771270]=1.0;h[1771271]=1.0;c[3542574]=3;c[3542575]=3;c[3542576]=3;mB(0);c[2113008]=(c[2113008]|0)+1}h[1771269]=.75;c[3542574]=3;h[1771270]=.75;c[3542575]=3;h[1771271]=.75;c[3542576]=3;if((c[2444210]|0)==7){h[1771269]=.5;c[3542574]=3}h[1771270]=.5;c[3542575]=3;h[1771271]=.5;c[3542576]=3;TS(0,1789750,32768,6,0,0);TS(1,1789750,32768,6,0,1);y=c[2420348]|0;h[y+192>>3]=.75;c[y+200>>2]=3;y=c[2420346]|0;h[y+192>>3]=.75;c[y+200>>2]=3;U_(96e3,3);y=c[2420424]|0;h[y+424>>3]=1.0;c[y+440>>2]=3;h[y+432>>3]=1.0;c[y+444>>2]=3;y=c[642608+(c[2436]<<2)>>2]|0;C=c[y+128>>2]|0;if((c[y+52>>2]&4|0)==0){c[2113068]=C;B=c[y+132>>2]|0;c[2113070]=B;c[2443814]=C;c[2440436]=B;ah=C;ai=B}else{c[2113070]=C;B=c[y+132>>2]|0;c[2113068]=B;c[2440436]=C;c[2443814]=B;ah=B;ai=C}C=ag(ah<<1,ai)|0;B=gGq(C)|0;c[2112926]=B;if((B|0)!=0){gGz(B|0,0,C|0)}dK4(1);U=0;i=j;return U|0}}while(0);c[2415002]=0;U=1;i=j;return U|0}function dK1(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a=c[2385942]|0;b=c[9757320+(c[1836236]<<2)>>2]|0;d=0;e=0;while(1){c[b+76+(e<<2)>>2]=a+(e<<8);f=d+1&65535;if((f&65535)>127){g=0;h=0;break}else{d=f;e=f&65535}}while(1){e=h<<8;c[b+76+(h+512<<2)>>2]=a+(e+32768);c[b+76+(h+768<<2)>>2]=a+e;e=g+1&65535;if((e&65535)>127){break}else{g=e;h=e&65535}}h=c[2386230]|0;c[b+588>>2]=h;g=h+256|0;c[b+592>>2]=g;a=h+512|0;c[b+596>>2]=a;e=h+768|0;c[b+600>>2]=e;c[b+1612>>2]=h;c[b+1616>>2]=g;c[b+1620>>2]=a;c[b+1624>>2]=e;c[b+2636>>2]=h;c[b+3660>>2]=h;c[b+2640>>2]=g;c[b+3664>>2]=g;c[b+2644>>2]=a;c[b+3668>>2]=a;c[b+2648>>2]=e;c[b+3672>>2]=e;e=c[2387878]|0;c[b+604>>2]=e;a=e+256|0;c[b+608>>2]=a;g=e+512|0;c[b+612>>2]=g;h=e+768|0;c[b+616>>2]=h;c[b+1628>>2]=e;c[b+1632>>2]=a;c[b+1636>>2]=g;c[b+1640>>2]=h;c[b+2652>>2]=e;c[b+3676>>2]=e;c[b+2656>>2]=a;c[b+3680>>2]=a;c[b+2660>>2]=g;c[b+3684>>2]=g;c[b+2664>>2]=h;c[b+3688>>2]=h;h=c[2386096]|0;c[b+620>>2]=h;g=h+256|0;c[b+624>>2]=g;a=h+512|0;c[b+628>>2]=a;e=h+768|0;c[b+632>>2]=e;d=h+1024|0;c[b+636>>2]=d;f=h+1280|0;c[b+640>>2]=f;i=h+1536|0;c[b+644>>2]=i;j=h+1792|0;c[b+648>>2]=j;c[b+1644>>2]=h;c[b+1648>>2]=g;c[b+1652>>2]=a;c[b+1656>>2]=e;c[b+1660>>2]=d;c[b+1664>>2]=f;c[b+1668>>2]=i;c[b+1672>>2]=j;c[b+2668>>2]=h;c[b+3692>>2]=h;c[b+2672>>2]=g;c[b+3696>>2]=g;c[b+2676>>2]=a;c[b+3700>>2]=a;c[b+2680>>2]=e;c[b+3704>>2]=e;c[b+2684>>2]=d;c[b+3708>>2]=d;c[b+2688>>2]=f;c[b+3712>>2]=f;c[b+2692>>2]=i;c[b+3716>>2]=i;c[b+2696>>2]=j;c[b+3720>>2]=j;c[b+4184>>2]=1004;c[b+4180>>2]=1266;return}function dK2(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[2385942]|0;d=0;while(1){e=b+d|0;f=a[e]|0;g=f&255;h=g>>>3<<1&2|g>>>1&1|g>>>5<<2&4;i=(g&128|0)==0?h:h^7;a[e]=a[614184+((d&1)<<3)+i|0]^f;a[b+(d+32768)|0]=a[614120+((d>>>8<<1&2|d>>>4&1|d>>>12<<2&4)<<3)+i|0]^f;f=d+1|0;if((f|0)<32768){d=f}else{j=0;break}}while(1){if((j|0)>=1024){k=0;break}l=9638528+(j<<2)|0;if((c[l>>2]|0)==0){m=12610;break}else{j=j+1|0}}do{if((m|0)==12610){j=gGq(8192)|0;c[l>>2]=j;if((j|0)==0){k=0;break}gGz(j|0,0,8192);k=j}}while(0);l=c[2387824]|0;j=l+8192|0;gGC(k|0,j|0,4096)|0;j=k+4096|0;d=l+4096|0;gGC(j|0,d|0,4096)|0;gGC(d|0,k|0,8192)|0;d=0;while(1){if((d|0)>=1024){m=12617;break}n=9638528+(d<<2)|0;if((c[n>>2]|0)==(k|0)){break}else{d=d+1|0}}if((m|0)==12617){return}gGr(k);c[n>>2]=0;return}function dK3(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;i=i+128|0;d=b|0;e=c[3531014]|0;f=0;do{g=a[e+f|0]|0;c[d+(f<<2)>>2]=(((-((g&255)>>>3&1)&33)+(-((g&255)>>>4&1)&71)&255)+(-((g&255)>>>5&1)&255&-105)&255)<<3&2016|((-((g&255)>>>6&1)&80|g<<24>>24>>7&-88)&255)>>>3|(((-((g&255)>>>1&1)&71)+(-(g&1)&33)&255)+(-((g&255)>>>2&1)&255&-105)&255)<<8&63488;f=f+1|0;}while((f|0)<32);f=c[2406946]|0;g=0;do{h=g+256|0;j=a[e+h|0]&15;c[f+(g<<2)>>2]=c[d+(j<<2)>>2];c[f+(h<<2)>>2]=c[d+((j|16)<<2)>>2];g=g+1|0;}while((g|0)<256);a[9547600]=1;i=b;return}function dK4(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((b|0)!=0){b=c[2414706]|0;gGz(b|0,0,(c[2411728]|0)-b|0)}c[2388372]=0;c[2394738]=0;b=c[2439330]|0;d=(b|0)==0;if(!d){e=b;gGC(9706056,e|0,76)|0}c[2433530]=c[2438118];e=c[3528484]|0;c[2076596]=e;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;gGz(9706056,0,76);g=c[2444210]|0;if((g|0)==15){h=a[673120]&1|10;a[9717168]=h;i=h&3;c[2394738]=i;h=c[2385942]|0;j=i<<14|65536;i=0;k=0;while(1){c[b+76+(k<<2)>>2]=h+((k<<8)+j);l=i+1&65535;if((l&65535)>63){break}else{i=l;k=l&65535}}k=(c[2394738]<<14)+65536|0;i=0;j=0;while(1){l=h+(k+(j<<8))|0;c[b+76+(j+512<<2)>>2]=l;c[b+76+(j+768<<2)>>2]=l;l=i+1&65535;if((l&65535)>63){break}else{i=l;j=l&65535}}}else if((g|0)==8){g=a[9635275]&1;c[2394738]=g;j=c[2385942]|0;i=g<<15;g=0;k=0;while(1){c[b+76+(k<<2)>>2]=j+((k<<8)+i);h=g+1&65535;if((h&65535)>63){break}else{g=h;k=h&65535}}k=c[2394738]<<15;g=0;i=0;while(1){h=j+((i<<8)+k)|0;c[b+76+(i+512<<2)>>2]=h;c[b+76+(i+768<<2)>>2]=h;h=g+1&65535;if((h&65535)>63){break}else{g=h;i=h&65535}}i=(c[2394738]<<15|16384)-32768|0;g=128;k=128;while(1){c[b+76+(k<<2)>>2]=j+(i+(k<<8));h=g+1&65535;if((h&65535)>191){break}else{g=h;k=h&65535}}k=(c[2394738]<<15|16384)-32768|0;g=128;i=128;while(1){h=j+(k+(i<<8))|0;c[b+76+(i+512<<2)>>2]=h;c[b+76+(i+768<<2)>>2]=h;h=g+1&65535;if((h&65535)>191){break}else{g=h;i=h&65535}}}if(d){m=c[2433530]|0;c[2438118]=m;c[3528484]=e;c[2417276]=f;c[1836236]=-1;mB(0);a[9734320]=0;a[9718696]=0;c[2436774]=0;c[2438256]=0;c[2438258]=0;a[9753272]=0;a[9775016]=0;a[14112808]=0;a[9620488]=0;return}d=b;gGC(d|0,9706056,76)|0;m=c[2433530]|0;c[2438118]=m;c[3528484]=e;c[2417276]=f;c[1836236]=-1;mB(0);a[9734320]=0;a[9718696]=0;c[2436774]=0;c[2438256]=0;c[2438258]=0;a[9753272]=0;a[9775016]=0;a[14112808]=0;a[9620488]=0;return}function dK5(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[2385942]|0;b=a+32768|0;gGC(b|0,a|0,32768)|0;a=0;while(1){if((a|0)>=1024){d=0;break}e=9638528+(a<<2)|0;if((c[e>>2]|0)==0){f=12649;break}else{a=a+1|0}}do{if((f|0)==12649){a=gGq(8192)|0;c[e>>2]=a;if((a|0)==0){d=0;break}gGz(a|0,0,8192);d=a}}while(0);e=c[2387824]|0;a=e+8192|0;gGC(d|0,a|0,4096)|0;a=d+4096|0;b=e+4096|0;gGC(a|0,b|0,4096)|0;gGC(b|0,d|0,8192)|0;b=0;while(1){if((b|0)>=1024){f=12656;break}g=9638528+(b<<2)|0;if((c[g>>2]|0)==(d|0)){break}else{b=b+1|0}}if((f|0)==12656){return}gGr(d);c[g>>2]=0;return}function dK6(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=c[2385942]|0;e=0;while(1){f=b+e|0;g=d[f]|0;h=g>>>5<<1&2|g>>>3&1;i=(g&128|0)==0;j=i?0:168;k=i?h:h^3;h=g&87;g=(e>>>4<<1&2|e&1|e>>>8<<2&4|e>>>12<<3&8)<<1;i=a[614200+(g<<2)+k|0]|0;l=b+(e+32768)|0;a[l]=(j^i&255|h)&255;m=a[614200+((g|1)<<2)+k|0]|0;a[f]=(j^m&255|h)&255;if(i<<24>>24==-1){a[l]=-18}if(m<<24>>24==-1){a[f]=-18}f=e+1|0;if((f|0)<32768){e=f}else{n=0;break}}while(1){if((n|0)>=1024){o=0;break}p=9638528+(n<<2)|0;if((c[p>>2]|0)==0){q=12666;break}else{n=n+1|0}}do{if((q|0)==12666){n=gGq(8192)|0;c[p>>2]=n;if((n|0)==0){o=0;break}gGz(n|0,0,8192);o=n}}while(0);p=c[2387824]|0;n=p+8192|0;gGC(o|0,n|0,4096)|0;n=o+4096|0;e=p+4096|0;gGC(n|0,e|0,4096)|0;gGC(e|0,o|0,8192)|0;e=0;while(1){if((e|0)>=1024){q=12673;break}r=9638528+(e<<2)|0;if((c[r>>2]|0)==(o|0)){break}else{e=e+1|0}}if((q|0)==12673){return}gGr(o);c[r>>2]=0;return}function dK7(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;a=c[2385942]|0;b=c[9757320+(c[1836236]<<2)>>2]|0;d=c[2386230]|0;e=c[2387878]|0;f=c[2386096]|0;g=0;do{h=g>>>8;i=h&128;j=i&65535;k=g>>8;l=k|63;if((j|0)<=(l|0)){m=i;n=j;while(1){c[b+76+(n<<2)>>2]=a+(n-h<<8);o=m+1&65535;p=o&65535;if((p|0)>(l|0)){q=i;r=j;break}else{m=o;n=p}}do{n=a+(r-h<<8)|0;c[b+76+(r+512<<2)>>2]=n;c[b+76+(r+768<<2)>>2]=n;q=q+1&65535;r=q&65535;}while((r|0)<=(l|0))}l=h|64;n=l&192;m=n&65535;j=k|67;if((m|0)<=(j|0)){i=n;p=m;while(1){c[b+76+(p<<2)>>2]=d+(p-l<<8);o=i+1&65535;s=o&65535;if((s|0)>(j|0)){t=n;u=m;break}else{i=o;p=s}}while(1){c[b+76+(u+256<<2)>>2]=d+(u-l<<8);p=t+1&65535;i=p&65535;if((i|0)>(j|0)){v=n;w=m;break}else{t=p;u=i}}do{m=d+(w-l<<8)|0;c[b+76+(w+512<<2)>>2]=m;c[b+76+(w+768<<2)>>2]=m;v=v+1&65535;w=v&65535;}while((w|0)<=(j|0))}j=h|68;l=j&196;m=l&65535;n=k|71;if((m|0)<=(n|0)){i=l;p=m;while(1){c[b+76+(p<<2)>>2]=e+(p-j<<8);s=i+1&65535;o=s&65535;if((o|0)>(n|0)){x=l;y=m;break}else{i=s;p=o}}while(1){c[b+76+(y+256<<2)>>2]=e+(y-j<<8);p=x+1&65535;i=p&65535;if((i|0)>(n|0)){z=l;A=m;break}else{x=p;y=i}}do{m=e+(A-j<<8)|0;c[b+76+(A+512<<2)>>2]=m;c[b+76+(A+768<<2)>>2]=m;z=z+1&65535;A=z&65535;}while((A|0)<=(n|0))}n=h|76;j=n&204;m=j&65535;l=k|79;if((m|0)<=(l|0)){i=j;p=m;while(1){c[b+76+(p<<2)>>2]=f+((p-n<<8)+1024);o=i+1&65535;s=o&65535;if((s|0)>(l|0)){B=j;C=m;break}else{i=o;p=s}}while(1){c[b+76+(C+256<<2)>>2]=f+((C-n<<8)+1024);p=B+1&65535;i=p&65535;if((i|0)>(l|0)){D=j;E=m;break}else{B=p;C=i}}do{m=f+((E-n<<8)+1024)|0;c[b+76+(E+512<<2)>>2]=m;c[b+76+(E+768<<2)>>2]=m;D=D+1&65535;E=D&65535;}while((E|0)<=(l|0))}l=h|96;n=l&224;m=n&65535;j=k|99;if((m|0)<=(j|0)){i=n;p=m;while(1){c[b+76+(p<<2)>>2]=d+(p-l<<8);s=i+1&65535;o=s&65535;if((o|0)>(j|0)){F=n;G=m;break}else{i=s;p=o}}while(1){c[b+76+(G+256<<2)>>2]=d+(G-l<<8);p=F+1&65535;i=p&65535;if((i|0)>(j|0)){H=n;I=m;break}else{F=p;G=i}}do{m=d+(I-l<<8)|0;c[b+76+(I+512<<2)>>2]=m;c[b+76+(I+768<<2)>>2]=m;H=H+1&65535;I=H&65535;}while((I|0)<=(j|0))}j=h|100;l=j&228;m=l&65535;n=k|103;if((m|0)<=(n|0)){i=l;p=m;while(1){c[b+76+(p<<2)>>2]=e+(p-j<<8);o=i+1&65535;s=o&65535;if((s|0)>(n|0)){J=l;K=m;break}else{i=o;p=s}}while(1){c[b+76+(K+256<<2)>>2]=e+(K-j<<8);p=J+1&65535;i=p&65535;if((i|0)>(n|0)){L=l;M=m;break}else{J=p;K=i}}do{m=e+(M-j<<8)|0;c[b+76+(M+512<<2)>>2]=m;c[b+76+(M+768<<2)>>2]=m;L=L+1&65535;M=L&65535;}while((M|0)<=(n|0))}n=h|108;j=n&236;m=j&65535;l=k|111;if((m|0)<=(l|0)){i=j;p=m;while(1){c[b+76+(p<<2)>>2]=f+((p-n<<8)+1024);s=i+1&65535;o=s&65535;if((o|0)>(l|0)){N=j;O=m;break}else{i=s;p=o}}while(1){c[b+76+(O+256<<2)>>2]=f+((O-n<<8)+1024);p=N+1&65535;i=p&65535;if((i|0)>(l|0)){P=j;Q=m;break}else{N=p;O=i}}do{m=f+((Q-n<<8)+1024)|0;c[b+76+(Q+512<<2)>>2]=m;c[b+76+(Q+768<<2)>>2]=m;P=P+1&65535;Q=P&65535;}while((Q|0)<=(l|0))}g=g+32768|0;}while((g|0)<32769);c[b+4184>>2]=2142;c[b+4180>>2]=1696;c[b+4176>>2]=2250;c[b+4172>>2]=80;return}function dK8(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;dK7();a=c[2385942]|0;b=c[9757320+(c[1836236]<<2)>>2]|0;c[b+588>>2]=a+32768;c[b+592>>2]=a+33024;c[b+596>>2]=a+33280;c[b+600>>2]=a+33536;c[b+604>>2]=a+33792;c[b+608>>2]=a+34048;c[b+612>>2]=a+34304;c[b+616>>2]=a+34560;c[b+620>>2]=a+34816;c[b+624>>2]=a+35072;c[b+628>>2]=a+35328;c[b+632>>2]=a+35584;c[b+636>>2]=a+35840;c[b+640>>2]=a+36096;c[b+644>>2]=a+36352;c[b+648>>2]=a+36608;d=128;e=128;while(1){f=a+(e<<8)|0;c[b+76+(e+512<<2)>>2]=f;c[b+76+(e+768<<2)>>2]=f;f=d+1&65535;if((f&65535)>143){break}else{d=f;e=f&65535}}e=c[2386096]|0;c[b+652>>2]=e;d=e+256|0;c[b+656>>2]=d;f=e+512|0;c[b+660>>2]=f;g=e+768|0;c[b+664>>2]=g;c[b+1676>>2]=e;c[b+1680>>2]=d;c[b+1684>>2]=f;c[b+1688>>2]=g;c[b+2700>>2]=e;c[b+3724>>2]=e;c[b+2704>>2]=d;c[b+3728>>2]=d;c[b+2708>>2]=f;c[b+3732>>2]=f;c[b+2712>>2]=g;c[b+3736>>2]=g;c[b+668>>2]=e;c[b+672>>2]=d;c[b+676>>2]=f;c[b+680>>2]=g;c[b+1692>>2]=e;c[b+1696>>2]=d;c[b+1700>>2]=f;c[b+1704>>2]=g;c[b+2716>>2]=e;c[b+3740>>2]=e;c[b+2720>>2]=d;c[b+3744>>2]=d;c[b+2724>>2]=f;c[b+3748>>2]=f;c[b+2728>>2]=g;c[b+3752>>2]=g;c[b+684>>2]=e;c[b+688>>2]=d;c[b+692>>2]=f;c[b+696>>2]=g;c[b+1708>>2]=e;c[b+1712>>2]=d;c[b+1716>>2]=f;c[b+1720>>2]=g;c[b+2732>>2]=e;c[b+3756>>2]=e;c[b+2736>>2]=d;c[b+3760>>2]=d;c[b+2740>>2]=f;c[b+3764>>2]=f;c[b+2744>>2]=g;c[b+3768>>2]=g;c[b+700>>2]=e;c[b+704>>2]=d;c[b+708>>2]=f;c[b+712>>2]=g;c[b+1724>>2]=e;c[b+1728>>2]=d;c[b+1732>>2]=f;c[b+1736>>2]=g;c[b+2748>>2]=e;c[b+3772>>2]=e;c[b+2752>>2]=d;c[b+3776>>2]=d;c[b+2756>>2]=f;c[b+3780>>2]=f;c[b+2760>>2]=g;c[b+3784>>2]=g;g=a+40960|0;c[b+716>>2]=g;f=a+41216|0;c[b+720>>2]=f;d=a+41472|0;c[b+724>>2]=d;e=a+41728|0;c[b+728>>2]=e;h=a+41984|0;c[b+732>>2]=h;i=a+42240|0;c[b+736>>2]=i;j=a+42496|0;c[b+740>>2]=j;k=a+42752|0;c[b+744>>2]=k;c[b+2764>>2]=g;c[b+3788>>2]=g;c[b+2768>>2]=f;c[b+3792>>2]=f;c[b+2772>>2]=d;c[b+3796>>2]=d;c[b+2776>>2]=e;c[b+3800>>2]=e;c[b+2780>>2]=h;c[b+3804>>2]=h;c[b+2784>>2]=i;c[b+3808>>2]=i;c[b+2788>>2]=j;c[b+3812>>2]=j;c[b+2792>>2]=k;c[b+3816>>2]=k;c[b+748>>2]=g;c[b+752>>2]=f;c[b+756>>2]=d;c[b+760>>2]=e;c[b+764>>2]=h;c[b+768>>2]=i;c[b+772>>2]=j;c[b+776>>2]=k;c[b+2796>>2]=g;c[b+3820>>2]=g;c[b+2800>>2]=f;c[b+3824>>2]=f;c[b+2804>>2]=d;c[b+3828>>2]=d;c[b+2808>>2]=e;c[b+3832>>2]=e;c[b+2812>>2]=h;c[b+3836>>2]=h;c[b+2816>>2]=i;c[b+3840>>2]=i;c[b+2820>>2]=j;c[b+3844>>2]=j;c[b+2824>>2]=k;c[b+3848>>2]=k;c[b+780>>2]=g;c[b+784>>2]=f;c[b+788>>2]=d;c[b+792>>2]=e;c[b+796>>2]=h;c[b+800>>2]=i;c[b+804>>2]=j;c[b+808>>2]=k;c[b+2828>>2]=g;c[b+3852>>2]=g;c[b+2832>>2]=f;c[b+3856>>2]=f;c[b+2836>>2]=d;c[b+3860>>2]=d;c[b+2840>>2]=e;c[b+3864>>2]=e;c[b+2844>>2]=h;c[b+3868>>2]=h;c[b+2848>>2]=i;c[b+3872>>2]=i;c[b+2852>>2]=j;c[b+3876>>2]=j;c[b+2856>>2]=k;c[b+3880>>2]=k;c[b+812>>2]=g;c[b+816>>2]=f;c[b+820>>2]=d;c[b+824>>2]=e;c[b+828>>2]=h;c[b+832>>2]=i;c[b+836>>2]=j;c[b+840>>2]=k;c[b+2860>>2]=g;c[b+3884>>2]=g;c[b+2864>>2]=f;c[b+3888>>2]=f;c[b+2868>>2]=d;c[b+3892>>2]=d;c[b+2872>>2]=e;c[b+3896>>2]=e;c[b+2876>>2]=h;c[b+3900>>2]=h;c[b+2880>>2]=i;c[b+3904>>2]=i;c[b+2884>>2]=j;c[b+3908>>2]=j;c[b+2888>>2]=k;c[b+3912>>2]=k;return}function dK9(){var a=0,b=0,d=0;a=c[2385942]|0;b=a+40960|0;d=a+36864|0;gGC(b|0,d|0,2048)|0;gGz(d|0,0,2048);return}function dLa(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a=c[2385942]|0;b=c[9757320+(c[1836236]<<2)>>2]|0;d=0;e=0;while(1){c[b+76+(e<<2)>>2]=a+(e<<8);f=d+1&65535;if((f&65535)>63){g=0;h=0;break}else{d=f;e=f&65535}}while(1){e=a+(h<<8)|0;c[b+76+(h+512<<2)>>2]=e;c[b+76+(h+768<<2)>>2]=e;e=g+1&65535;if((e&65535)>63){break}else{g=e;h=e&65535}}h=c[2386230]|0;c[b+332>>2]=h;g=h+256|0;c[b+336>>2]=g;e=h+512|0;c[b+340>>2]=e;d=h+768|0;c[b+344>>2]=d;c[b+1356>>2]=h;c[b+1360>>2]=g;c[b+1364>>2]=e;c[b+1368>>2]=d;c[b+2380>>2]=h;c[b+3404>>2]=h;c[b+2384>>2]=g;c[b+3408>>2]=g;c[b+2388>>2]=e;c[b+3412>>2]=e;c[b+2392>>2]=d;c[b+3416>>2]=d;d=c[2387878]|0;c[b+348>>2]=d;e=d+256|0;c[b+352>>2]=e;g=d+512|0;c[b+356>>2]=g;h=d+768|0;c[b+360>>2]=h;c[b+1372>>2]=d;c[b+1376>>2]=e;c[b+1380>>2]=g;c[b+1384>>2]=h;c[b+2396>>2]=d;c[b+3420>>2]=d;c[b+2400>>2]=e;c[b+3424>>2]=e;c[b+2404>>2]=g;c[b+3428>>2]=g;c[b+2408>>2]=h;c[b+3432>>2]=h;h=c[2386096]|0;g=h+1024|0;c[b+380>>2]=g;e=h+1280|0;c[b+384>>2]=e;d=h+1536|0;c[b+388>>2]=d;f=h+1792|0;c[b+392>>2]=f;c[b+1404>>2]=g;c[b+1408>>2]=e;c[b+1412>>2]=d;c[b+1416>>2]=f;c[b+2428>>2]=g;c[b+3452>>2]=g;c[b+2432>>2]=e;c[b+3456>>2]=e;c[b+2436>>2]=d;c[b+3460>>2]=d;c[b+2440>>2]=f;c[b+3464>>2]=f;f=96;d=96;while(1){c[b+76+(d<<2)>>2]=a+((d<<8)+8192);e=f+1&65535;if((e&65535)>127){i=96;j=96;break}else{f=e;d=e&65535}}while(1){d=a+((j<<8)+8192)|0;c[b+76+(j+512<<2)>>2]=d;c[b+76+(j+768<<2)>>2]=d;d=i+1&65535;if((d&65535)>127){break}else{i=d;j=d&65535}}c[b+4184>>2]=2142;c[b+4180>>2]=1696;c[b+4176>>2]=2250;c[b+4172>>2]=80;return}function dLb(){var b=0;b=c[2385942]|0;a[b+40958|0]=-89;a[b+40942|0]=109;return}function dLc(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a=c[2385942]|0;b=c[9757320+(c[1836236]<<2)>>2]|0;d=0;e=0;while(1){c[b+76+(e<<2)>>2]=a+(e<<8);f=d+1&65535;if((f&65535)>63){g=0;h=0;break}else{d=f;e=f&65535}}while(1){e=a+(h<<8)|0;c[b+76+(h+512<<2)>>2]=e;c[b+76+(h+768<<2)>>2]=e;e=g+1&65535;if((e&65535)>63){break}else{g=e;h=e&65535}}h=c[2386230]|0;c[b+332>>2]=h;g=h+256|0;c[b+336>>2]=g;e=h+512|0;c[b+340>>2]=e;d=h+768|0;c[b+344>>2]=d;c[b+1356>>2]=h;c[b+1360>>2]=g;c[b+1364>>2]=e;c[b+1368>>2]=d;c[b+2380>>2]=h;c[b+3404>>2]=h;c[b+2384>>2]=g;c[b+3408>>2]=g;c[b+2388>>2]=e;c[b+3412>>2]=e;c[b+2392>>2]=d;c[b+3416>>2]=d;d=c[2387878]|0;c[b+348>>2]=d;e=d+256|0;c[b+352>>2]=e;g=d+512|0;c[b+356>>2]=g;h=d+768|0;c[b+360>>2]=h;c[b+1372>>2]=d;c[b+1376>>2]=e;c[b+1380>>2]=g;c[b+1384>>2]=h;c[b+2396>>2]=d;c[b+3420>>2]=d;c[b+2400>>2]=e;c[b+3424>>2]=e;c[b+2404>>2]=g;c[b+3428>>2]=g;c[b+2408>>2]=h;c[b+3432>>2]=h;h=c[2386096]|0;g=h+1024|0;c[b+380>>2]=g;e=h+1280|0;c[b+384>>2]=e;d=h+1536|0;c[b+388>>2]=d;f=h+1792|0;c[b+392>>2]=f;c[b+1404>>2]=g;c[b+1408>>2]=e;c[b+1412>>2]=d;c[b+1416>>2]=f;c[b+2428>>2]=g;c[b+3452>>2]=g;c[b+2432>>2]=e;c[b+3456>>2]=e;c[b+2436>>2]=d;c[b+3460>>2]=d;c[b+2440>>2]=f;c[b+3464>>2]=f;f=128;d=128;while(1){c[b+76+(d<<2)>>2]=a+(d<<8);e=f+1&65535;if((e&65535)>159){i=128;j=128;break}else{f=e;d=e&65535}}while(1){d=a+(j<<8)|0;c[b+76+(j+512<<2)>>2]=d;c[b+76+(j+768<<2)>>2]=d;d=i+1&65535;if((d&65535)>159){break}else{i=d;j=d&65535}}c[b+4184>>2]=2142;c[b+4180>>2]=1696;c[b+4176>>2]=2250;c[b+4172>>2]=80;return}function dLd(){var b=0,e=0,f=0,g=0;b=c[2385942]|0;e=0;do{f=d[b+e|0]|0;g=f^181;a[b+(e+65536)|0]=(g>>>7<<5|g&64|g<<2&4|g>>>5&1|g>>>1<<7&128|g>>>3<<4&16|g>>>4<<3&8|g>>>2<<1&2)&255;g=f^167;a[b+(e+81920)|0]=(g<<2&4|g&192|g>>>5&1|g>>>1<<5&32|g>>>3<<4&16|g>>>4<<3&8|g>>>2<<1&2)&255;g=f^252;a[b+(e+98304)|0]=(g>>>7<<5|g<<6&64|g>>>5&1|g>>>1<<7&128|g>>>6<<4&16|g>>>4<<3&8|g>>>3<<2&4|g>>>2<<1&2)&255;g=f^238;a[b+(e+114688)|0]=(g<<6&64|g&128|g>>>5&1|g>>>1<<5&32|g>>>6<<4&16|g>>>4<<3&8|g>>>3<<2&4|g>>>2<<1&2)&255;e=e+1|0;}while((e|0)<16384);return}function dLe(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;dLf();a=c[2385942]|0;b=c[9757320+(c[1836236]<<2)>>2]|0;d=0;e=0;while(1){c[b+76+(e<<2)>>2]=a+(e<<8);f=d+1&65535;if((f&65535)>63){g=0;h=0;break}else{d=f;e=f&65535}}while(1){e=a+(h<<8)|0;c[b+76+(h+512<<2)>>2]=e;c[b+76+(h+768<<2)>>2]=e;e=g+1&65535;if((e&65535)>63){i=128;j=128;break}else{g=e;h=e&65535}}while(1){c[b+76+(j<<2)>>2]=a+(j<<8);h=i+1&65535;if((h&65535)>191){k=128;l=128;break}else{i=h;j=h&65535}}while(1){j=a+(l<<8)|0;c[b+76+(l+512<<2)>>2]=j;c[b+76+(l+768<<2)>>2]=j;j=k+1&65535;if((j&65535)>191){break}else{k=j;l=j&65535}}return}function dLf(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;a=c[2385942]|0;b=c[9757320+(c[1836236]<<2)>>2]|0;d=c[2386230]|0;e=c[2387878]|0;f=c[2386096]|0;g=0;do{h=g>>>8;i=h&128;j=i&65535;k=g>>8|47;if((j|0)<=(k|0)){l=i;m=j;while(1){c[b+76+(m<<2)>>2]=a+(m-h<<8);n=l+1&65535;o=n&65535;if((o|0)>(k|0)){p=i;q=j;break}else{l=n;m=o}}do{m=a+(q-h<<8)|0;c[b+76+(q+512<<2)>>2]=m;c[b+76+(q+768<<2)>>2]=m;p=p+1&65535;q=p&65535;}while((q|0)<=(k|0))}k=g|16384;h=g|17407;m=g|17408;l=g|18431;j=g|18432;i=g|19455;o=g|19456;n=g|20479;r=0;do{s=(r+k|0)>>>8;t=s&224;u=t&65535;v=r+h>>8;if((u|0)<=(v|0)){w=t;x=u;while(1){c[b+76+(x<<2)>>2]=d+(x-s<<8);y=w+1&65535;z=y&65535;if((z|0)>(v|0)){A=t;B=u;break}else{w=y;x=z}}while(1){c[b+76+(B+256<<2)>>2]=d+(B-s<<8);x=A+1&65535;w=x&65535;if((w|0)>(v|0)){C=t;D=u;break}else{A=x;B=w}}do{u=d+(D-s<<8)|0;c[b+76+(D+512<<2)>>2]=u;c[b+76+(D+768<<2)>>2]=u;C=C+1&65535;D=C&65535;}while((D|0)<=(v|0))}v=(r+m|0)>>>8;s=v&228;u=s&65535;t=r+l>>8;if((u|0)<=(t|0)){w=s;x=u;while(1){c[b+76+(x<<2)>>2]=e+(x-v<<8);z=w+1&65535;y=z&65535;if((y|0)>(t|0)){E=s;F=u;break}else{w=z;x=y}}while(1){c[b+76+(F+256<<2)>>2]=e+(F-v<<8);x=E+1&65535;w=x&65535;if((w|0)>(t|0)){G=s;H=u;break}else{E=x;F=w}}do{u=e+(H-v<<8)|0;c[b+76+(H+512<<2)>>2]=u;c[b+76+(H+768<<2)>>2]=u;G=G+1&65535;H=G&65535;}while((H|0)<=(t|0))}t=(r+j|0)>>>8;v=t&232;u=v&65535;s=r+i>>8;if((u|0)<=(s|0)){w=v;x=u;while(1){c[b+76+(x<<2)>>2]=f+(x-t<<8);y=w+1&65535;z=y&65535;if((z|0)>(s|0)){I=v;J=u;break}else{w=y;x=z}}while(1){c[b+76+(J+256<<2)>>2]=f+(J-t<<8);x=I+1&65535;w=x&65535;if((w|0)>(s|0)){K=v;L=u;break}else{I=x;J=w}}do{u=f+(L-t<<8)|0;c[b+76+(L+512<<2)>>2]=u;c[b+76+(L+768<<2)>>2]=u;K=K+1&65535;L=K&65535;}while((L|0)<=(s|0))}s=(r+o|0)>>>8;t=s&236;u=t&65535;v=r+n>>8;if((u|0)<=(v|0)){w=t;x=u;while(1){c[b+76+(x<<2)>>2]=f+((x-s<<8)+1024);z=w+1&65535;y=z&65535;if((y|0)>(v|0)){M=t;N=u;break}else{w=z;x=y}}while(1){c[b+76+(N+256<<2)>>2]=f+((N-s<<8)+1024);x=M+1&65535;w=x&65535;if((w|0)>(v|0)){O=t;P=u;break}else{M=x;N=w}}do{u=f+((P-s<<8)+1024)|0;c[b+76+(P+512<<2)>>2]=u;c[b+76+(P+768<<2)>>2]=u;O=O+1&65535;P=O&65535;}while((P|0)<=(v|0))}r=r+8192|0;}while((r|0)<8193);g=g+32768|0;}while((g|0)<32769);c[b+4184>>2]=2142;c[b+4180>>2]=1696;c[b+4176>>2]=2250;c[b+4172>>2]=80;return}function dLg(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;b=i;i=i+8|0;d=b|0;e=c[2385942]|0;f=0;do{g=e+f|0;h=a[g]|0;a[g]=(h&255)>>>3<<5&32|h&-41|(h&255)>>>5<<3&8;f=f+1|0;}while((f|0)<16384);f=d;e=c[2387824]|0;h=0;do{g=0;do{j=a[e+(g&2|h|g>>>2&1|g<<2&4)|0]|0;a[f+g|0]=(j&255)>>>4<<6&64|j&-81|(j&255)>>>6<<4&16;g=g+1|0;}while((g|0)<8);g=e+h|0;j=c[d+4>>2]|0;k=g|0;C=c[d>>2]|0;a[k]=C&255;C=C>>8;a[k+1|0]=C&255;C=C>>8;a[k+2|0]=C&255;C=C>>8;a[k+3|0]=C&255;k=g+4|0;C=j;a[k]=C&255;C=C>>8;a[k+1|0]=C&255;C=C>>8;a[k+2|0]=C&255;C=C>>8;a[k+3|0]=C&255;h=h+8|0;}while((h|0)<8192);i=b;return}function dLh(){var a=0,b=0,d=0;a=c[2385942]|0;b=a+36864|0;d=a+32768|0;gGC(b|0,d|0,4096)|0;b=a+40960|0;gGC(b|0,d|0,4096)|0;b=a+45056|0;gGC(b|0,d|0,4096)|0;return}function dLi(){var b=0,e=0,f=0,g=0;b=c[2385942]|0;e=0;do{f=d[b+e|0]|0;g=f^252;a[b+(e+65536)|0]=(g<<5&32|g>>>7<<6|g>>>5&1|g>>>3<<7&128|g>>>6<<4&16|g>>>4<<3&8|g>>>1<<2&4|g>>>2<<1&2)&255;g=f^246;a[b+(e+81920)|0]=(g<<5&32|g>>>7<<6|g>>>5&1|g>>>1<<7&128|g>>>3<<4&16|g>>>4<<3&8|g>>>6<<2&4|g>>>2<<1&2)&255;g=f^125;a[b+(e+98304)|0]=(g>>>7<<3|g<<6&64|g>>>5&1|g>>>3<<7&128|g>>>4<<5&32|g>>>6<<4&16|g>>>1<<2&4|g>>>2<<1&2)&255;g=f^119;a[b+(e+114688)|0]=(g>>>7<<3|g<<6&64|g>>>5&1|g>>>1<<7&128|g>>>4<<5&32|g>>>3<<4&16|g>>>6<<2&4|g>>>2<<1&2)&255;e=e+1|0;}while((e|0)<16384);return}function dLj(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0;dK7();a=c[2385942]|0;b=c[9757320+(c[1836236]<<2)>>2]|0;d=128;e=128;while(1){c[b+76+(e<<2)>>2]=a+(e<<8);f=d+1&65535;if((f&65535)>191){g=128;h=128;break}else{d=f;e=f&65535}}while(1){e=a+(h<<8)|0;c[b+76+(h+512<<2)>>2]=e;c[b+76+(h+768<<2)>>2]=e;e=g+1&65535;if((e&65535)>191){break}else{g=e;h=e&65535}}return}function dLk(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=c[2387824]|0;d=0;while(1){e=b+(d|8)|0;f=a[e]|0;g=b+d|0;a[e]=a[g]|0;a[g]=f;f=b+(d|9)|0;g=a[f]|0;e=b+(d|1)|0;a[f]=a[e]|0;a[e]=g;g=b+(d|10)|0;e=a[g]|0;f=b+(d|2)|0;a[g]=a[f]|0;a[f]=e;e=b+(d|11)|0;f=a[e]|0;g=b+(d|3)|0;a[e]=a[g]|0;a[g]=f;f=b+(d|12)|0;g=a[f]|0;e=b+(d|4)|0;a[f]=a[e]|0;a[e]=g;g=b+(d|13)|0;e=a[g]|0;f=b+(d|5)|0;a[g]=a[f]|0;a[f]=e;e=b+(d|14)|0;f=a[e]|0;g=b+(d|6)|0;a[e]=a[g]|0;a[g]=f;f=b+(d|15)|0;g=a[f]|0;e=b+(d|7)|0;a[f]=a[e]|0;a[e]=g;g=d+16|0;if((g|0)<4096){d=g}else{h=4096;break}}do{d=0;do{g=d+h|0;e=b+(g+24)|0;f=a[e]|0;i=b+(g+16)|0;a[e]=a[i]|0;e=b+(g+8)|0;a[i]=a[e]|0;i=b+g|0;a[e]=a[i]|0;a[i]=f;d=d+1|0;}while((d|0)<8);h=h+32|0;}while((h|0)<8192);return}function dLl(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;b=i;i=i+8|0;d=b|0;e=c[2385942]|0;f=e+45056|0;g=e+32768|0;gGC(f|0,g|0,4096)|0;f=e+4096|0;gGC(g|0,f|0,12288)|0;gGz(f|0,0,12288);f=d;g=c[2387824]|0;e=0;do{h=0;do{j=a[g+(h&2|e|h>>>2&1|h<<2&4)|0]|0;a[f+h|0]=(j&255)>>>4<<6&64|j&-81|(j&255)>>>6<<4&16;h=h+1|0;}while((h|0)<8);h=g+e|0;j=c[d+4>>2]|0;k=h|0;C=c[d>>2]|0;a[k]=C&255;C=C>>8;a[k+1|0]=C&255;C=C>>8;a[k+2|0]=C&255;C=C>>8;a[k+3|0]=C&255;k=h+4|0;C=j;a[k]=C&255;C=C>>8;a[k+1|0]=C&255;C=C>>8;a[k+2|0]=C&255;C=C>>8;a[k+3|0]=C&255;e=e+8|0;}while((e|0)<8192);i=b;return}function dLm(){var b=0,e=0,f=0,g=0,h=0;b=c[2385942]|0;e=0;do{f=b+e|0;g=c[600192+((e>>>1&2|e&1|e>>>3&4|e>>>4&8|e>>>5&16)<<2)>>2]^e>>>11&1;h=d[f]|0;a[f]=((h>>>((d[600321+(g*9|0)|0]|0)>>>0)<<6&64|h>>>((d[600320+(g*9|0)|0]|0)>>>0)<<7&128|h>>>((d[600322+(g*9|0)|0]|0)>>>0)<<5&32|h>>>((d[600323+(g*9|0)|0]|0)>>>0)<<4&16|h>>>((d[600324+(g*9|0)|0]|0)>>>0)<<3&8|h>>>((d[600325+(g*9|0)|0]|0)>>>0)<<2&4|h>>>((d[600326+(g*9|0)|0]|0)>>>0)<<1&2|h>>>((d[600327+(g*9|0)|0]|0)>>>0)&1)^(d[600328+(g*9|0)|0]|0))&255;e=e+1|0;}while((e|0)<16384);return}function dLn(){var b=0;b=c[2385942]|0;a[b+563|0]=0;a[b+564|0]=0;a[b+565|0]=0;a[b+572|0]=0;a[b+574|0]=0;a[b+587|0]=0;a[b+588|0]=0;a[b+589|0]=0;a[b+1100|0]=-55;a[b+4443|0]=-55;a[b+6889|0]=24;a[b+7335|0]=-89;a[b+7336|0]=-55;a[b+9100|0]=-55;a[b+15081|0]=62;a[b+15083|0]=-2;a[b+15084|0]=63;a[b+15086|0]=-55;a[b+1117|0]=-58;a[b+1118|0]=18;a[b+5249|0]=40;a[b+5266|0]=32;a[b+5285|0]=-56;return}function dLo(){var b=0;b=c[2385942]|0;a[b+15074|0]=62;a[b+15075|0]=0;a[b+15076|0]=0;return}function dLp(){var b=0;b=c[2385942]|0;a[b+548|0]=0;a[b+549|0]=0;a[b+550|0]=0;a[b+557|0]=0;a[b+559|0]=0;a[b+572|0]=0;a[b+573|0]=0;a[b+574|0]=0;a[b+1045|0]=-55;a[b+1064|0]=-58;a[b+1065|0]=18;a[b+4446|0]=-55;a[b+5249|0]=40;a[b+5266|0]=32;a[b+5285|0]=-56;a[b+6520|0]=24;a[b+7327|0]=-89;a[b+7328|0]=-55;a[b+9102|0]=-55;a[b+15077|0]=62;a[b+15079|0]=-2;a[b+15080|0]=63;a[b+15081|0]=-55;return}function dLq(){var a=0,b=0,d=0,e=0,f=0,g=0;a=0;while(1){if((a|0)>=1024){b=0;break}d=9638528+(a<<2)|0;if((c[d>>2]|0)==0){e=12792;break}else{a=a+1|0}}do{if((e|0)==12792){a=gGq(16384)|0;c[d>>2]=a;if((a|0)==0){b=0;break}gGz(a|0,0,16384);b=a}}while(0);d=c[2387824]|0;gGC(b|0,d|0,16384)|0;a=d+4096|0;f=b+2048|0;gGC(a|0,f|0,2048)|0;f=d+2048|0;a=b+4096|0;gGC(f|0,a|0,2048)|0;a=d+12288|0;f=b+10240|0;gGC(a|0,f|0,2048)|0;f=d+10240|0;d=b+12288|0;gGC(f|0,d|0,2048)|0;d=c[2385942]|0;f=d+32768|0;gGC(d|0,f|0,16384)|0;a=d+49152|0;gGC(f|0,a|0,16384)|0;gGz(a|0,0,16384);a=0;while(1){if((a|0)>=1024){e=12799;break}g=9638528+(a<<2)|0;if((c[g>>2]|0)==(b|0)){break}else{a=a+1|0}}if((e|0)==12799){return}gGr(b);c[g>>2]=0;return}function dLr(){var a=0,b=0,d=0,e=0,f=0,g=0;a=0;while(1){if((a|0)>=1024){b=0;break}d=9638528+(a<<2)|0;if((c[d>>2]|0)==0){e=12804;break}else{a=a+1|0}}do{if((e|0)==12804){a=gGq(4096)|0;c[d>>2]=a;if((a|0)==0){b=0;break}gGz(a|0,0,4096);b=a}}while(0);d=c[2387824]|0;a=d+2048|0;gGC(b|0,a|0,4096)|0;f=d+4096|0;gGC(f|0,a|0,2048)|0;f=b+2048|0;gGC(a|0,f|0,2048)|0;f=0;while(1){if((f|0)>=1024){e=12812;break}g=9638528+(f<<2)|0;if((c[g>>2]|0)==(b|0)){break}else{f=f+1|0}}if((e|0)==12812){return}gGr(b);c[g>>2]=0;return}function dLs(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;a=c[2386230]|0;b=c[9757320+(c[1836236]<<2)>>2]|0;d=c[2387878]|0;e=c[2386096]|0;f=0;do{g=f>>>8;h=g|64;i=h&192;j=i&65535;k=f>>8;l=k|67;if((j|0)<=(l|0)){m=i;n=j;while(1){c[b+76+(n<<2)>>2]=a+(n-h<<8);o=m+1&65535;p=o&65535;if((p|0)>(l|0)){q=i;r=j;break}else{m=o;n=p}}while(1){c[b+76+(r+256<<2)>>2]=a+(r-h<<8);n=q+1&65535;m=n&65535;if((m|0)>(l|0)){s=i;t=j;break}else{q=n;r=m}}do{j=a+(t-h<<8)|0;c[b+76+(t+512<<2)>>2]=j;c[b+76+(t+768<<2)>>2]=j;s=s+1&65535;t=s&65535;}while((t|0)<=(l|0))}l=g|68;h=l&196;j=h&65535;i=k|71;if((j|0)<=(i|0)){m=h;n=j;while(1){c[b+76+(n<<2)>>2]=d+(n-l<<8);p=m+1&65535;o=p&65535;if((o|0)>(i|0)){u=h;v=j;break}else{m=p;n=o}}while(1){c[b+76+(v+256<<2)>>2]=d+(v-l<<8);n=u+1&65535;m=n&65535;if((m|0)>(i|0)){w=h;x=j;break}else{u=n;v=m}}do{j=d+(x-l<<8)|0;c[b+76+(x+512<<2)>>2]=j;c[b+76+(x+768<<2)>>2]=j;w=w+1&65535;x=w&65535;}while((x|0)<=(i|0))}i=g|76;l=i&204;j=l&65535;h=k|79;if((j|0)<=(h|0)){m=l;n=j;while(1){c[b+76+(n<<2)>>2]=e+((n-i<<8)+1024);o=m+1&65535;p=o&65535;if((p|0)>(h|0)){y=l;z=j;break}else{m=o;n=p}}while(1){c[b+76+(z+256<<2)>>2]=e+((z-i<<8)+1024);n=y+1&65535;m=n&65535;if((m|0)>(h|0)){A=l;B=j;break}else{y=n;z=m}}do{j=e+((B-i<<8)+1024)|0;c[b+76+(B+512<<2)>>2]=j;c[b+76+(B+768<<2)>>2]=j;A=A+1&65535;B=A&65535;}while((B|0)<=(h|0))}h=g|96;i=h&224;j=i&65535;l=k|99;if((j|0)<=(l|0)){m=i;n=j;while(1){c[b+76+(n<<2)>>2]=a+(n-h<<8);p=m+1&65535;o=p&65535;if((o|0)>(l|0)){C=i;D=j;break}else{m=p;n=o}}while(1){c[b+76+(D+256<<2)>>2]=a+(D-h<<8);n=C+1&65535;m=n&65535;if((m|0)>(l|0)){E=i;F=j;break}else{C=n;D=m}}do{j=a+(F-h<<8)|0;c[b+76+(F+512<<2)>>2]=j;c[b+76+(F+768<<2)>>2]=j;E=E+1&65535;F=E&65535;}while((F|0)<=(l|0))}l=g|100;h=l&228;j=h&65535;i=k|103;if((j|0)<=(i|0)){m=h;n=j;while(1){c[b+76+(n<<2)>>2]=d+(n-l<<8);o=m+1&65535;p=o&65535;if((p|0)>(i|0)){G=h;H=j;break}else{m=o;n=p}}while(1){c[b+76+(H+256<<2)>>2]=d+(H-l<<8);n=G+1&65535;m=n&65535;if((m|0)>(i|0)){I=h;J=j;break}else{G=n;H=m}}do{j=d+(J-l<<8)|0;c[b+76+(J+512<<2)>>2]=j;c[b+76+(J+768<<2)>>2]=j;I=I+1&65535;J=I&65535;}while((J|0)<=(i|0))}i=g|108;l=i&236;j=l&65535;h=k|111;if((j|0)<=(h|0)){m=l;n=j;while(1){c[b+76+(n<<2)>>2]=e+((n-i<<8)+1024);p=m+1&65535;o=p&65535;if((o|0)>(h|0)){K=l;L=j;break}else{m=p;n=o}}while(1){c[b+76+(L+256<<2)>>2]=e+((L-i<<8)+1024);n=K+1&65535;m=n&65535;if((m|0)>(h|0)){M=l;N=j;break}else{K=n;L=m}}do{j=e+((N-i<<8)+1024)|0;c[b+76+(N+512<<2)>>2]=j;c[b+76+(N+768<<2)>>2]=j;M=M+1&65535;N=M&65535;}while((N|0)<=(h|0))}f=f+32768|0;}while((f|0)<32769);c[b+4184>>2]=572;c[b+4180>>2]=1108;c[b+4176>>2]=2250;return}function dLt(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0;a=c[2385942]|0;b=a+32768|0;d=a+16384|0;gGC(b|0,d|0,16384)|0;gGz(d|0,0,16384);d=0;while(1){if((d|0)>=1024){e=0;break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==0){g=12843;break}else{d=d+1|0}}do{if((g|0)==12843){d=gGq(8192)|0;c[f>>2]=d;if((d|0)==0){e=0;break}gGz(d|0,0,8192);e=d}}while(0);f=c[2387824]|0;gGC(e|0,f|0,8192)|0;d=f+4096|0;b=e+2048|0;gGC(d|0,b|0,2048)|0;b=f+2048|0;d=e+4096|0;gGC(b|0,d|0,2048)|0;d=f+6144|0;f=e+6144|0;gGC(d|0,f|0,2048)|0;f=0;while(1){if((f|0)>=1024){g=12851;break}h=9638528+(f<<2)|0;if((c[h>>2]|0)==(e|0)){break}else{f=f+1|0}}if((g|0)==12851){return}gGr(e);c[h>>2]=0;return}function dLu(){var b=0,d=0,e=0,f=0,g=0;b=c[2385942]|0;d=4096;do{if((d&8|0)==0){e=b+(d|1)|0;f=a[e]|0;g=b+(d|2)|0;a[e]=a[g]|0;a[g]=f}d=d+4|0;}while((d|0)<8192);return}function dLv(){var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2385942]|0;f=b+45056|0;g=b+40960|0;gGC(f|0,g|0,4096)|0;g=b+65536|0;gGC(g|0,b|0,12288)|0;g=0;while(1){f=a[b+((g>>>3<<10&1024|g&63495|g>>>7<<9&512|g>>>9<<8&256|g>>>10<<7&128|g>>>8<<6&64|g>>>6<<5&32|g>>>5<<4&16|g>>>4<<3&8)+45056)|0]|0;a[b+(g+77824)|0]=f&32|f<<7|(f&255)>>>7<<4|(f&255)>>>1&1|(f&255)>>>4<<6&64|(f&255)>>>6<<3&8|(f&255)>>>3<<2&4|(f&255)>>>2<<1&2;f=g+1|0;if((f|0)<4096){g=f}else{h=0;break}}do{g=h>>>8&1;f=h>>>7<<9&512;i=h>>>5&1;j=h>>>9&1;k=h>>>10&1;l=h>>>6<<5&32;m=h>>>3&1;n=h>>>4<<3&8;o=h&63495;p=a[b+((g<<10|o|f|i<<8|j<<7|k<<6|l|m<<4|n)+32768)|0]|0;a[b+(h+98304)|0]=p&32|p<<7|(p&255)>>>7<<4|(p&255)>>>1&1|(p&255)>>>4<<6&64|(p&255)>>>6<<3&8|(p&255)>>>3<<2&4|(p&255)>>>2<<1&2;p=m<<10|o|f|j<<8|k<<7|g<<6|l|i<<4|n;n=a[b+(p+38912)|0]|0;a[b+(h+100352)|0]=n&32|n<<7|(n&255)>>>7<<4|(n&255)>>>1&1|(n&255)>>>4<<6&64|(n&255)>>>6<<3&8|(n&255)>>>3<<2&4|(n&255)>>>2<<1&2;n=a[b+(p+36864)|0]|0;a[b+(h+102400)|0]=n&32|n<<7|(n&255)>>>7<<4|(n&255)>>>1&1|(n&255)>>>4<<6&64|(n&255)>>>6<<3&8|(n&255)>>>3<<2&4|(n&255)>>>2<<1&2;a[b+(h+104448)|0]=a[b+(h+6144)|0]|0;h=h+1|0;}while((h|0)<2048);h=b+106496|0;n=b+8192|0;gGC(h|0,n|0,8192)|0;n=0;do{h=b+(e[605632+((n|1)<<1)>>1]|0|65536)|0;p=b+(e[605632+(n<<1)>>1]|0|65536)|0;i=h|0;l=h+4|0;h=d[l]|d[l+1|0]<<8|d[l+2|0]<<16|d[l+3|0]<<24|0;l=p|0;C=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;a[l]=C&255;C=C>>8;a[l+1|0]=C&255;C=C>>8;a[l+2|0]=C&255;C=C>>8;a[l+3|0]=C&255;l=p+4|0;C=h;a[l]=C&255;C=C>>8;a[l+1|0]=C&255;C=C>>8;a[l+2|0]=C&255;C=C>>8;a[l+3|0]=C&255;n=n+2|0;}while((n|0)<80);n=b+32768|0;gGC(n|0,b|0,16384)|0;return}function dLw(d,f){d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;if((d-1572864|0)>>>0>=262144){if((d|0)!=1048597){return}a[c[3528296]|0]=f;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12;return}g=d&262143^1;d=c[3529472]|0;a[d+g|0]=f;f=g>>>1&255;h=g>>>9&255;if((h-8|0)>>>0>239){return}g=d;d=h<<8|f;i=c[2386346]|0;j=(f<<1|-2560)+(h*320|0)|0;h=e[g+(d<<1)>>1]|0;f=b[g+((d|65536)<<1)>>1]|0;d=h>>>8;if((d|0)==0){k=(f&65535)>>>8|256}else{k=d&65535}b[i+(j<<1)>>1]=k;k=h&255;if((k|0)==0){b[i+((j|1)<<1)>>1]=f&255|256;return}else{b[i+((j|1)<<1)>>1]=k&65535;return}}function dLx(d,f){d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;g=d-2621952|0;if(g>>>0<1024){h=c[2387224]|0;b[h+g>>1]=f;g=d&1022;i=e[h+g>>1]|0;c[(c[3530054]|0)+(g>>>1<<2)>>2]=(-(i>>>1&1)&31)+(-(i&1)&14)+(-(i>>>2&1)&67)+(-(i>>>3&1)&143)<<8&63488|(-(i>>>4&1)&14)+(-(i>>>5&1)&31)+(-(i>>>6&1)&67)+(-(i>>>7&1)&143)<<3&2016|((-(i>>>8&1)&14)+(-(i>>>9&1)&31)+(-(i>>>10&1)&67)+(-(i>>>11&1)&143)|0)>>>3&31;return}if((d-1572864|0)>>>0>=262144){if((d|0)==1048596){a[c[3528296]|0]=f&255;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12;return}else if((d|0)==2621442){b[(c[2387224]|0)+1024>>1]=f;i=f&65535;c[(c[3530054]|0)+2048>>2]=(-(i>>>1&1)&31)+(-(i&1)&14)+(-(i>>>2&1)&67)+(-(i>>>3&1)&143)<<8&63488|(-(i>>>4&1)&14)+(-(i>>>5&1)&31)+(-(i>>>6&1)&67)+(-(i>>>7&1)&143)<<3&2016|((-(i>>>8&1)&14)+(-(i>>>9&1)&31)+(-(i>>>10&1)&67)+(-(i>>>11&1)&143)|0)>>>3&31;return}else{return}}i=d&262142;g=c[3529472]|0;b[g+i>>1]=f;f=i>>>1&255;i=d>>>9&255;if((i-8|0)>>>0>239){return}d=g;g=i<<8|f;h=c[2386346]|0;j=(f<<1|-2560)+(i*320|0)|0;i=e[d+(g<<1)>>1]|0;f=b[d+((g|65536)<<1)>>1]|0;g=i>>>8;if((g|0)==0){k=(f&65535)>>>8|256}else{k=g&65535}b[h+(j<<1)>>1]=k;k=i&255;if((k|0)==0){b[h+((j|1)<<1)>>1]=f&255|256;return}else{b[h+((j|1)<<1)>>1]=k&65535;return}}function dLy(b){b=b|0;var c=0;switch(b^1|0){case 1048580:{c=a[9550634]&14;break};case 1048578:{c=a[9550633]|0;break};case 1048576:{c=a[9550632]|0;break};case 1048582:{c=a[9635264]|0;break};case 1048584:{c=a[9550636]&-64|a[9635265]&63;break};default:{c=0}}return c|0}function dLz(b){b=b|0;var c=0;switch(b|0){case 1048582:{c=d[9635264]|0;break};case 1048584:{c=a[9550636]&192|a[9635265]&63;break};case 1048576:{c=d[9550632]|0;break};case 1048580:{c=a[9550634]&14;break};case 1048578:{c=d[9550633]|0;break};default:{c=0}}return c|0}function dLA(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((e|0)==38912){Uv(0,d);return}else if((e|0)==34817){b=c[2113304]|0;a[14168504+b|0]=d;mv(0,b,d&255);return}else if((e|0)==34816){c[2113304]=d&255;return}else{return}}function dLB(b){b=b|0;var d=0,e=0;d=b&65535;if((d|0)==38912){e=c[2113156]&255}else if((d|0)==40960){e=a[c[3528296]|0]|0}else if((d|0)==34817){e=c[(c[3531464]|0)+4240>>2]&255}else{e=0}return e|0}function dLC(b){b=b|0;a[9706117]=(b|0)!=0|0;return}function dLD(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>4){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3066500+(b*112|0)>>2];c[a+104>>2]=c[3066504+(b*112|0)>>2];c[a+108>>2]=c[3066508+(b*112|0)>>2];d=0;return d|0}function dLE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<5&(d|0)==0)){e=1;return e|0}c[a>>2]=3066400+(b*112|0);e=0;return e|0}function dLF(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>23){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1310176+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dLG(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4234528+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dLH(){var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;d=i;i=i+240|0;e=d|0;f=d+112|0;g=d+120|0;j=d+232|0;c[2424]=5800;c[2415e3]=0;c[2388174]=0;c[2385940]=262144;c[3541206]=294912;c[2386664]=294912;c[3530054]=557056;c[2414704]=559108;c[3531172]=559108;c[3531150]=608260;c[3531136]=657412;c[3529472]=755716;c[3529438]=1017860;c[2387224]=1050628;c[2386094]=1052676;c[3528296]=1054724;c[2386346]=1054725;c[2411726]=1208325;k=0;while(1){if((k|0)>=1024){break}l=9638528+(k<<2)|0;if((c[l>>2]|0)==0){m=12962;break}else{k=k+1|0}}do{if((m|0)==12962){k=gGq(1208325)|0;c[l>>2]=k;if((k|0)==0){break}c[2415e3]=k;gGz(k|0,0,1208325);c[2388174]=k;c[2385940]=k+262144;n=k+294912|0;c[3541206]=n;c[2386664]=n;c[3530054]=k+557056;n=k+559108|0;c[2414704]=n;c[3531172]=n;c[3531150]=k+608260;c[3531136]=k+657412;c[3529472]=k+755716;c[3529438]=k+1017860;c[2387224]=k+1050628;c[2386094]=k+1052676;c[3528296]=k+1054724;c[2386346]=k+1054725;n=k+1208325|0;c[2411726]=n;c[2414268]=n;if((R6(k+1|0,0,2)|0)!=0){o=1;i=d;return o|0}if((R6(c[2388174]|0,1,2)|0)!=0){o=1;i=d;return o|0}k=c[2385940]|0;if((c[3542200]|0)==0){o=1;i=d;return o|0}n=g+108|0;c[n>>2]=0;p=g+100|0;c[p>>2]=0;q=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[q&16383](g,2)|0;do{if((c[n>>2]|0)!=0){q=c[p>>2]|0;c[j>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](j,2,0)|0;if((q|0)<1){o=1;i=d;return o|0}if((gzL(k,0,2)|0)==0){break}else{o=1}i=d;return o|0}}while(0);k=c[2386664]|0;if((c[3542200]|0)==0){o=1;i=d;return o|0}p=e+108|0;c[p>>2]=0;n=e+100|0;c[n>>2]=0;q=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[q&16383](e,3)|0;do{if((c[p>>2]|0)!=0){q=c[n>>2]|0;c[f>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](f,3,0)|0;if((q|0)<1){o=1;i=d;return o|0}if((gzL(k,0,3)|0)==0){break}else{o=1}i=d;return o|0}}while(0);fxU(0,425984);if((c[2394]|0)==0){s=c[2112932]|0}else{c[2394]=0;k=c[3532596]|0;c[2112932]=k;n=c[3532592]|0;if((n|0)!=0){gGC(9104152,n|0,280)|0}c[2113054]=c[2113060];s=k}k=c[2388174]|0;n=s|0;p=0;while(1){q=k+p|0;c[n>>2]=q;c[n+131072>>2]=q;q=p+1024|0;if(q>>>0>262143){break}else{n=n+4|0;p=q}}p=c[3529472]|0;n=s+6144|0;k=1572864;while(1){q=p+(k-1572864)|0;c[n>>2]=q;c[n+131072>>2]=q;q=k+1024|0;if(q>>>0>1835007){break}else{n=n+4|0;k=q}}k=c[3531172]|0;n=s+7488|0;p=1916928;while(1){q=k+(p-1916928)|0;c[n>>2]=q;c[n+65536>>2]=q;c[n+131072>>2]=q;q=p+1024|0;if(q>>>0>1966079){break}else{n=n+4|0;p=q}}p=c[3531150]|0;n=s+8e3|0;k=2048e3;while(1){q=p+(k-2048e3)|0;c[n>>2]=q;c[n+65536>>2]=q;c[n+131072>>2]=q;q=k+1024|0;if(q>>>0>2097151){break}else{n=n+4|0;k=q}}k=c[3529438]|0;n=s+8192|0;p=2097152;while(1){q=k+(p-2097152)|0;c[n>>2]=q;c[n+65536>>2]=q;c[n+131072>>2]=q;q=p+1024|0;if(q>>>0>2129919){break}else{n=n+4|0;p=q}}p=c[3531136]|0;n=s+8320|0;k=2129920;while(1){q=p+(k-2129920)|0;c[n>>2]=q;c[n+65536>>2]=q;c[n+131072>>2]=q;q=k+1024|0;if(q>>>0>2228223){break}else{n=n+4|0;k=q}}k=c[2387224]|0;n=k-512|0;c[s+10240>>2]=n;c[s+141312>>2]=n;n=k+512|0;c[s+10244>>2]=n;c[s+141316>>2]=n;c[s+196648>>2]=630;c[s+196728>>2]=2018;c[s+196608>>2]=1784;c[s+196688>>2]=1452;n=c[3532592]|0;if((n|0)!=0){gGC(n|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);n=c[2439330]|0;k=(n|0)==0;if(!k){p=n;gGC(9706056,p|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];p=c[3528484]|0;c[2076596]=p;q=c[2417276]|0;c[3541536]=q;c[1836236]=0;r=c[2385940]|0;t=0;u=0;while(1){c[n+76+(u<<2)>>2]=r+(u<<8);v=t+1&65535;if((v&65535)>127){w=0;x=0;break}else{t=v;u=v&65535}}while(1){u=r+(x<<8)|0;c[n+76+(x+512<<2)>>2]=u;c[n+76+(x+768<<2)>>2]=u;u=w+1&65535;if((u&65535)>127){break}else{w=u;x=u&65535}}r=c[2386094]|0;c[n+588>>2]=r;u=r+256|0;c[n+592>>2]=u;t=r+512|0;c[n+596>>2]=t;v=r+768|0;c[n+600>>2]=v;y=r+1024|0;c[n+604>>2]=y;z=r+1280|0;c[n+608>>2]=z;A=r+1536|0;c[n+612>>2]=A;B=r+1792|0;c[n+616>>2]=B;c[n+1612>>2]=r;c[n+1616>>2]=u;c[n+1620>>2]=t;c[n+1624>>2]=v;c[n+1628>>2]=y;c[n+1632>>2]=z;c[n+1636>>2]=A;c[n+1640>>2]=B;c[n+2636>>2]=r;c[n+3660>>2]=r;c[n+2640>>2]=u;c[n+3664>>2]=u;c[n+2644>>2]=t;c[n+3668>>2]=t;c[n+2648>>2]=v;c[n+3672>>2]=v;c[n+2652>>2]=y;c[n+3676>>2]=y;c[n+2656>>2]=z;c[n+3680>>2]=z;c[n+2660>>2]=A;c[n+3684>>2]=A;c[n+2664>>2]=B;c[n+3688>>2]=B;c[n+4184>>2]=2570;c[n+4180>>2]=980;if(!k){B=n;gGC(B|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=p;c[2417276]=q;c[1836236]=-1;Ux(0,8e3,1);c[2407030]=128;c[2407068]=3;B=a[9680]|0;A=B?32e3:0;if(B){if(a[9624]|0){B=A*3|0;z=55930;while(1){if((z|0)>(B|0)){z=z>>1}else{C=1222;D=z;break}}}else{C=2462;D=A}c[2429380]=D;c[3542124]=C;mw(3579545,D);z=gGq(262144)|0;c[2406684]=z;gGz(z|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(3579545,11025)}c[(c[3531464]|0)+44344>>2]=1574;h[745421]=.6;c[2436794]=1;h[745420]=.6;c[2436792]=2;z=c[642608+(c[2436]<<2)>>2]|0;B=c[z+128>>2]|0;if((c[z+52>>2]&4|0)==0){c[2113068]=B;q=c[z+132>>2]|0;c[2113070]=q;c[2443814]=B;c[2440436]=q;E=B;F=q}else{c[2113070]=B;q=c[z+132>>2]|0;c[2113068]=q;c[2440436]=B;c[2443814]=q;E=q;F=B}B=ag(E<<1,F)|0;q=gGq(B)|0;c[2112926]=q;if((q|0)!=0){gGz(q|0,0,B|0)}a[9624440]=0;B=c[2414704]|0;gGz(B|0,0,(c[2411726]|0)-B|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];B=c[3532592]|0;if((B|0)!=0){gGC(9104152,B|0,280)|0}c[2113054]=c[2113060]}RI();B=c[2394]|0;q=c[14130368+(B<<2)>>2]|0;if((q|0)!=0){gGC(q|0,9104152,280)|0}c[8452240+(B<<2)>>2]=c[2113054];c[2394]=-1;B=c[2439330]|0;q=(B|0)==0;if(!q){z=B;gGC(9706056,z|0,76)|0}z=c[2438118]|0;c[2433530]=z;p=c[3528484]|0;c[2076596]=p;n=c[2417276]|0;c[3541536]=n;c[1836236]=0;gGz(9706056,0,76);if(!q){q=B;gGC(q|0,9706056,76)|0}c[2438118]=z;c[3528484]=p;c[2417276]=n;c[1836236]=-1;c[2113156]=0;a[9628264]=0;c[2407033]=0;n=c[3541206]|0;c[3541190]=n;c[3541198]=n;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=n+256;c[3541199]=n+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=n+512;c[3541200]=n+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=n+768;c[3541201]=n+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;mx(0);o=0;i=d;return o|0}}while(0);c[2415e3]=0;o=1;i=d;return o|0}function dLI(){var a=0,b=0,d=0,e=0,f=0;c[2113070]=0;c[2113068]=0;a=c[2112926]|0;if((a|0)!=0){gGr(a);c[2112926]=0}Uw(0);a=c[3531464]|0;c[a+44344>>2]=0;c[a+44348>>2]=0;if((a|0)!=0){gGr(a);c[3531464]=0}a=c[2406684]|0;if((a|0)!=0){gGr(a);c[2406684]=0}if((c[2392]|0)>=0){a=0;do{b=14130368+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}b=14130384+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}a=a+1|0;}while((a|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;fwZ();a=c[2415e3]|0;b=0;while(1){if((b|0)>=1024){e=13051;break}f=9638528+(b<<2)|0;if((c[f>>2]|0)==(a|0)){break}else{b=b+1|0}}if((e|0)==13051){c[2415e3]=0;c[3541206]=0;return 0}gGr(a);c[f>>2]=0;c[2415e3]=0;c[3541206]=0;return 0}function dLJ(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;if((a[9624440]|0)!=0){a[9624440]=0;d=c[2414704]|0;gGz(d|0,0,(c[2411726]|0)-d|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;h=c[2417276]|0;c[3541536]=h;c[1836236]=0;gGz(9706056,0,76);if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=h;c[1836236]=-1;c[2113156]=0;a[9628264]=0;c[2407033]=0;h=c[3541206]|0;c[3541190]=h;c[3541198]=h;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=h+256;c[3541199]=h+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=h+512;c[3541200]=h+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=h+768;c[3541201]=h+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;mx(0)}gGz(9550632,-1|0,5);h=0;g=-1;f=-1;e=-1;d=-1;do{g=((a[9633856+h|0]&1)<<h^g&255)&255;f=((a[9631656+h|0]&1)<<h^f&255)&255;e=((a[9629664+h|0]&1)<<h^e&255)&255;d=((a[9628768+h|0]&1)<<h^d&255)&255;h=h+1|0;}while((h|0)<8);a[9550632]=g;a[9550633]=f;a[9550634]=e;a[9550636]=d;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}d=c[2439330]|0;if((d|0)!=0){e=d;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;e=0;d=0;while(1){c[2113056]=17241;f=RG(17241)|0;c[2113054]=(c[2113054]|0)+f;c[2276108]=-1;c[2113056]=-1;if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){f=gfc(6171)|0;i=(c[2433530]|0)+f|0}else{i=(c[2433530]|0)+6171|0}c[2433530]=i;f=a[9688]|0?53:0;g=c[2112964]|0;if((g|0)==0){j=e}else{h=g+(e<<1<<1)|0;gg[c[3542124]&4095](h,f);Uu(0,h,f);j=f+e|0}if((d|0)!=4){f=d+1|0;if((f|0)<10){e=j;d=f;continue}else{break}}c[8452200+(c[2394]<<2)>>2]=8198;c[2276080]=1536;if((c[2276079]|0)>>>0>=1536){e=j;d=5;continue}RH(6);e=j;d=5}d=c[2112964]|0;do{if((d|0)!=0){e=d+(j<<1<<1)|0;i=a[9688]|0?534:0;f=i-j|0;if((i|0)==(j|0)){break}gg[c[3542124]&4095](e,f);Uu(0,e,f)}}while(0);c[8452200+(c[2394]<<2)>>2]=8197;c[2276080]=1280;if((c[2276079]|0)>>>0<1280){RH(5)}j=c[1836236]|0;d=c[9757320+(j<<2)>>2]|0;if((d|0)!=0){f=d;gGC(f|0,9706056,76)|0}c[9752472+(j<<2)>>2]=c[2433530];c[14113936+(j<<2)>>2]=c[2076596];c[9669104+(j<<2)>>2]=c[3541536];c[1836236]=-1;j=c[2394]|0;f=c[14130368+(j<<2)>>2]|0;if((f|0)!=0){gGC(f|0,9104152,280)|0}c[8452240+(j<<2)>>2]=c[2113054];c[2394]=-1;if((c[2112968]|0)==0){return 0}dLK()|0;return 0}function dLK(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((a[9547592]|0)!=0){d=c[2387224]|0;f=c[3530054]|0;g=0;do{h=e[d+g>>1]|0;c[f+(((g|0)/2|0)<<2)>>2]=(-(h>>>1&1)&31)+(-(h&1)&14)+(-(h>>>2&1)&67)+(-(h>>>3&1)&143)<<8&63488|(-(h>>>4&1)&14)+(-(h>>>5&1)&31)+(-(h>>>6&1)&67)+(-(h>>>7&1)&143)<<3&2016|((-(h>>>8&1)&14)+(-(h>>>9&1)&31)+(-(h>>>10&1)&67)+(-(h>>>11&1)&143)|0)>>>3&31;g=g+2|0;}while((g|0)<1026)}g=c[2112926]|0;f=g;d=c[2386346]|0;gGC(f|0,d|0,153600)|0;d=c[3529438]|0;f=0;do{h=(f<<6)+512|0;i=f*320|0;j=0;do{k=b[d+(h+(j>>3)<<1)>>1]|0;l=k&65535;do{if(k<<16>>16!=0){m=j+i|0;if((l&128|0)!=0){b[g+(m<<1)>>1]=512}if((l&64|0)!=0){b[g+((m|1)<<1)>>1]=512}if((l&32|0)!=0){b[g+((m|2)<<1)>>1]=512}if((l&16|0)!=0){b[g+((m|3)<<1)>>1]=512}if((l&8|0)!=0){b[g+((m|4)<<1)>>1]=512}if((l&4|0)!=0){b[g+((m|5)<<1)>>1]=512}if((l&2|0)!=0){b[g+((m|6)<<1)>>1]=512}if((l&1|0)==0){break}b[g+((m|7)<<1)>>1]=512}}while(0);j=j+8|0;}while((j|0)<320);f=f+1|0;}while((f|0)<240);R8(c[3530054]|0);return 0}function dLL(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+96|0;g=f|0;h=f+16|0;j=f+32|0;k=f+48|0;l=f+64|0;m=f+80|0;if((e|0)!=0){c[e>>2]=169624}if((b&32|0)!=0){gGz(m|0,0,12);e=c[2414704]|0;c[m>>2]=e;c[m+4>>2]=(c[2411726]|0)-e;c[m+12>>2]=162152;e=c[2076592]|0;gj[e&4095](m)|0}if((b&64|0)==0){i=f;return 0}m=l|0;gGz(k|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){e=l+9|0;l=j;n=j|0;o=j+4|0;p=j+12|0;q=k|0;r=k+4|0;s=k+12|0;t=0;do{gGC(m|0,614896,11)|0;a[e]=t+48&255;u=8452256+(t<<2)|0;gGz(l|0,0,12);c[n>>2]=u;c[o>>2]=4;c[p>>2]=164976;gj[c[2076592]&4095](j)|0;if((c[u>>2]|0)!=0){c[q>>2]=c[14130368+(t<<2)>>2];c[r>>2]=c[8452184+(t<<2)>>2];c[s>>2]=m;u=c[2076592]|0;gj[u&4095](k)|0}t=t+1|0;}while((t|0)<=(c[2392]|0))}fw$(b);gGz(h|0,0,12);c[h>>2]=8453216;c[h+4>>2]=4;c[h+12>>2]=107480;gj[c[2076592]&4095](h)|0;gGz(g|0,0,12);c[g>>2]=14168504;c[g+4>>2]=256;c[g+12>>2]=476464;gj[c[2076592]&4095](g)|0;if((b&2|0)!=0){b=0;do{mv(0,b,d[14168504+b|0]|0);b=b+1|0;}while((b|0)<256)}Ut(0);i=f;return 0}function dLM(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>4){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3073780+(b*112|0)>>2];c[a+104>>2]=c[3073784+(b*112|0)>>2];c[a+108>>2]=c[3073788+(b*112|0)>>2];d=0;return d|0}function dLN(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<5&(d|0)==0)){e=1;return e|0}c[a>>2]=3073680+(b*112|0);e=0;return e|0}function dLO(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>4){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3073220+(b*112|0)>>2];c[a+104>>2]=c[3073224+(b*112|0)>>2];c[a+108>>2]=c[3073228+(b*112|0)>>2];d=0;return d|0}function dLP(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<5&(d|0)==0)){e=1;return e|0}c[a>>2]=3073120+(b*112|0);e=0;return e|0}function dLQ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>23){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1310976+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dLR(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>4){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5956420+(b*112|0)>>2];c[a+104>>2]=c[5956424+(b*112|0)>>2];c[a+108>>2]=c[5956428+(b*112|0)>>2];d=0;return d|0}function dLS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<5&(d|0)==0)){e=1;return e|0}c[a>>2]=5956320+(b*112|0);e=0;return e|0}function dLT(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6444768+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dLU(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>4){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4852068+(b*112|0)>>2];c[a+104>>2]=c[4852072+(b*112|0)>>2];c[a+108>>2]=c[4852076+(b*112|0)>>2];d=0;return d|0}function dLV(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<5&(d|0)==0)){e=1;return e|0}c[a>>2]=4851968+(b*112|0);e=0;return e|0}function dLW(a){a=a|0;var b=0,e=0;switch(a|0){case 917520:{b=(d[9757681]|0)^255;return b|0};case 917568:{b=255-((d[9757680]|0)^c[2438862])&65535;return b|0};case 917570:{b=d[14108168]|0;return b|0};case 917572:{a=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;if((a|0)>140711){e=128}else{e=(a|0)<20592?128:0}b=e+(d[14108169]|0)&65535;return b|0};case 917536:{b=(d[9757682]|0)^255;return b|0};default:{b=0;return b|0}}return 0}function dLX(d,e){d=d|0;e=e|0;switch(d|0){case 983120:{b[7057844]=e;return};case 983088:{b[7057843]=e;return};case 983072:{b[7057842]=e;return};case 983040:{b[7057840]=e;return};case 983056:{b[7057841]=e;return};case 983122:{b[7057845]=e;return};case 983152:{c[3528936]=e&255;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12;return};case 983110:{c[2438862]=e<<16>>16!=0?255:0;return};case 983136:{b[7057846]=e;return};default:{return}}}function dLY(b){b=b|0;var e=0,f=0,g=0;if((b&255)!=0){e=0;return e|0}b=c[3540984]|0;f=(d[b+5887|0]|0|128)&(d[b+5886|0]|0);if((a[b+5884|0]&2)==0){g=f&255}else{g=(a[(c[b+5828>>2]|0)+100|0]&1|f)&255}e=g|6;return e|0}function dLZ(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=b&255;if((f|0)==64){b=c[2418506]|0;a[b+8|0]=e;c[2424874]=b;g=b+10|0;h=a[g]|0;a[g]=0;g=c[2424874]|0;i=g+16|0;do{if((a[i]|h)<<24>>24==0){if((a[g+10|0]|0)==0){j=b;break}if((a[g+9|0]|0)==0){j=b;break}a[i]=2;if(!(a[635136]|0)){j=b;break}k=a[(c[2424874]|0)+11|0]|0;Vk();l=c[2424874]|0;m=a[l+11|0]|0;if(k<<24>>24==m<<24>>24){j=b;break}k=c[l+12>>2]|0;if((k|0)==0){j=b;break}gf[k&2047](m&255);j=c[2418506]|0}else{j=b}}while(0);c[2424874]=j;b=j+10|0;j=a[b]|0;a[b]=1;b=c[2424874]|0;i=b+16|0;if((a[i]|j)<<24>>24!=0){return}if((a[b+10|0]|0)==0){return}if((a[b+9|0]|0)==0){return}a[i]=2;if(!(a[635136]|0)){return}i=a[(c[2424874]|0)+11|0]|0;Vk();b=c[2424874]|0;j=a[b+11|0]|0;if(i<<24>>24==j<<24>>24){return}i=c[b+12>>2]|0;if((i|0)==0){return}gf[i&2047](j&255);return}else if((f|0)==128){j=c[2418506]|0;c[2424874]=j;i=j+9|0;j=a[i]|0;a[i]=e<<24>>24!=0|0;if(j<<24>>24==0){return}if((a[(c[2424874]|0)+9|0]|0)!=0){return}Vl();return}else if((f|0)==0){a[(c[3540984]|0)+5885|0]=e;return}else if((f|0)==32){f=c[3540984]|0;j=c[f+5876>>2]|0;if((j|0)!=0){gg[j&4095](c[f+5880>>2]|0,0)}lH(f,d[f+5885|0]|0,e&255);return}else{return}}function dL_(a){a=a|0;var b=0;if(a<<16>>16!=-2048){b=0;return b|0}b=c[3528936]&255;return b|0}function dL$(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;e=i;i=i+960|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;c[2426756]=0;c[3527038]=0;c[2438586]=262144;c[2430078]=327680;c[2429494]=393216;c[2405680]=524288;c[3527040]=524288;c[2433346]=540672;c[2430856]=542720;c[2430852]=544768;c[2430080]=561152;c[2438588]=563200;c[2411724]=565248;c[2430854]=565248;c[2437022]=630784;c[2430090]=1941504;c[2430088]=2465792;c[2437024]=2990080;x=0;while(1){if((x|0)>=1024){break}y=9638528+(x<<2)|0;if((c[y>>2]|0)==0){z=13288;break}else{x=x+1|0}}do{if((z|0)==13288){x=gGq(2998272)|0;c[y>>2]=x;if((x|0)==0){break}c[2426756]=x;gGz(x|0,0,2998272);c[3527038]=x;c[2438586]=x+262144;c[2430078]=x+327680;c[2429494]=x+393216;A=x+524288|0;c[2405680]=A;c[3527040]=A;c[2433346]=x+540672;c[2430856]=x+542720;c[2430852]=x+544768;c[2430080]=x+561152;c[2438588]=x+563200;A=x+565248|0;c[2411724]=A;c[2430854]=A;c[2437022]=x+630784;c[2430090]=x+1941504;c[2430088]=x+2465792;c[2437024]=x+2990080;c[2414266]=x+2998272;x=0;while(1){if((x|0)>=1024){B=0;break}C=9638528+(x<<2)|0;if((c[C>>2]|0)==0){z=13293;break}else{x=x+1|0}}do{if((z|0)==13293){x=gGq(655360)|0;c[C>>2]=x;if((x|0)==0){B=0;break}gGz(x|0,0,655360);B=x}}while(0);c[2437020]=B;if((R6((c[3527038]|0)+1|0,0,2)|0)!=0){D=1;i=e;return D|0}if((R6(c[3527038]|0,1,2)|0)!=0){D=1;i=e;return D|0}x=c[2437020]|0;gGz(x|0,0,655360);if((c[3542200]|0)==0){D=1;i=e;return D|0}A=v+108|0;c[A>>2]=0;E=v+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,2)|0;do{if((c[A>>2]|0)!=0){F=c[E>>2]|0;c[w>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](w,2,0)|0;if((F|0)<1){D=1;i=e;return D|0}if((gzL(x,0,2)|0)==0){break}else{D=1}i=e;return D|0}}while(0);x=c[2437020]|0;E=c[2430854]|0;A=0;do{F=A<<6;gGz(E+F|0,0,64);G=A<<8;H=0;do{I=1<<3-H;J=(c[703416+(H<<2)>>2]|0)+G|0;K=0;do{L=J+(c[1183816+(K<<2)>>2]|0)|0;M=(K<<3)+F|0;N=0;do{O=L+(c[1934976+(N<<2)>>2]|0)|0;if(((d[x+((O|0)/8|0)|0]|0)&128>>>((O&7)>>>0)|0)!=0){O=E+(M+N)|0;a[O]=(d[O]|0|I)&255}N=N+1|0;}while((N|0)<8);K=K+1|0;}while((K|0)<8);H=H+1|0;}while((H|0)<4);A=A+1|0;}while((A|0)<1024);gGz(x|0,0,655360);if((c[3542200]|0)==0){D=1;i=e;return D|0}A=t+108|0;c[A>>2]=0;E=t+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,3)|0;do{if((c[A>>2]|0)!=0){H=c[E>>2]|0;c[u>>2]=9534384;F=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[F&16383](u,3,0)|0;if((H|0)<1){D=1;i=e;return D|0}if((gzL(x,0,3)|0)==0){break}else{D=1}i=e;return D|0}}while(0);x=c[2437020]|0;E=c[2430088]|0;A=0;do{H=A<<8;gGz(E+H|0,0,256);F=A<<10;G=0;do{K=1<<3-G;I=(c[703416+(G<<2)>>2]|0)+F|0;J=0;do{N=I+(c[611840+(J<<2)>>2]|0)|0;M=(J<<4)+H|0;L=0;do{O=N+(c[600104+(L<<2)>>2]|0)|0;if(((d[x+((O|0)/8|0)|0]|0)&128>>>((O&7)>>>0)|0)!=0){O=E+(M+L)|0;a[O]=(d[O]|0|K)&255}L=L+1|0;}while((L|0)<16);J=J+1|0;}while((J|0)<16);G=G+1|0;}while((G|0)<4);A=A+1|0;}while((A|0)<2048);gGz(x|0,0,655360);if((c[3542200]|0)==0){D=1;i=e;return D|0}A=r+108|0;c[A>>2]=0;E=r+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,4)|0;do{if((c[A>>2]|0)!=0){G=c[E>>2]|0;c[s>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](s,4,0)|0;if((G|0)<1){D=1;i=e;return D|0}if((gzL(x,0,4)|0)==0){break}else{D=1}i=e;return D|0}}while(0);x=c[2437020]|0;E=c[2430090]|0;A=0;do{G=A<<8;gGz(E+G|0,0,256);H=A<<10;F=0;do{J=1<<3-F;K=(c[703416+(F<<2)>>2]|0)+H|0;I=0;do{L=K+(c[611840+(I<<2)>>2]|0)|0;M=(I<<4)+G|0;N=0;do{O=L+(c[600104+(N<<2)>>2]|0)|0;if(((d[x+((O|0)/8|0)|0]|0)&128>>>((O&7)>>>0)|0)!=0){O=E+(M+N)|0;a[O]=(d[O]|0|J)&255}N=N+1|0;}while((N|0)<16);I=I+1|0;}while((I|0)<16);F=F+1|0;}while((F|0)<4);A=A+1|0;}while((A|0)<2048);gGz(x|0,0,655360);if((c[3542200]|0)==0){D=1;i=e;return D|0}A=p+108|0;c[A>>2]=0;E=p+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,5)|0;do{if((c[A>>2]|0)!=0){F=c[E>>2]|0;c[q>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](q,5,0)|0;if((F|0)<1){D=1;i=e;return D|0}if((gzL(x,0,5)|0)==0){break}else{D=1}i=e;return D|0}}while(0);x=(c[2437020]|0)+524288|0;if((c[3542200]|0)==0){D=1;i=e;return D|0}E=n+108|0;c[E>>2]=0;A=n+100|0;c[A>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,6)|0;do{if((c[E>>2]|0)!=0){F=c[A>>2]|0;c[o>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](o,6,0)|0;if((F|0)<1){D=1;i=e;return D|0}if((gzL(x,0,6)|0)==0){break}else{D=1}i=e;return D|0}}while(0);x=c[2437020]|0;A=c[2437022]|0;E=0;while(1){F=E<<8;gGz(A+F|0,0,256);G=E<<10;H=0;do{I=1<<3-H;J=(c[703416+(H<<2)>>2]|0)+G|0;K=0;do{N=J+(c[611840+(K<<2)>>2]|0)|0;M=(K<<4)+F|0;L=0;do{O=N+(c[600104+(L<<2)>>2]|0)|0;if(((d[x+((O|0)/8|0)|0]|0)&128>>>((O&7)>>>0)|0)!=0){O=A+(M+L)|0;a[O]=(d[O]|0|I)&255}L=L+1|0;}while((L|0)<16);K=K+1|0;}while((K|0)<16);H=H+1|0;}while((H|0)<4);H=E+1|0;if((H|0)<5120){E=H}else{P=0;break}}while(1){if((P|0)>=1024){break}Q=9638528+(P<<2)|0;if((c[Q>>2]|0)==(x|0)){z=13359;break}else{P=P+1|0}}if((z|0)==13359){gGr(x);c[Q>>2]=0}c[2437020]=0;E=c[2430078]|0;if((c[3542200]|0)==0){D=1;i=e;return D|0}A=l+108|0;c[A>>2]=0;H=l+100|0;c[H>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,7)|0;do{if((c[A>>2]|0)!=0){F=c[H>>2]|0;c[m>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](m,7,0)|0;if((F|0)<1){D=1;i=e;return D|0}if((gzL(E,0,7)|0)==0){break}else{D=1}i=e;return D|0}}while(0);E=c[2438586]|0;if((c[3542200]|0)==0){D=1;i=e;return D|0}H=j+108|0;c[H>>2]=0;A=j+100|0;c[A>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,8)|0;do{if((c[H>>2]|0)!=0){x=c[A>>2]|0;c[k>>2]=9534384;F=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[F&16383](k,8,0)|0;if((x|0)<1){D=1;i=e;return D|0}if((gzL(E,0,8)|0)==0){break}else{D=1}i=e;return D|0}}while(0);E=c[2429494]|0;if((c[3542200]|0)==0){D=1;i=e;return D|0}A=f+108|0;c[A>>2]=0;H=f+100|0;c[H>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,9)|0;do{if((c[A>>2]|0)!=0){x=c[H>>2]|0;c[g>>2]=9534384;F=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[F&16383](g,9,0)|0;if((x|0)<1){D=1;i=e;return D|0}if((gzL(E,0,9)|0)==0){break}else{D=1}i=e;return D|0}}while(0);fxU(0,425984);if((c[2394]|0)==0){R=c[2112932]|0}else{c[2394]=0;E=c[3532596]|0;c[2112932]=E;H=c[3532592]|0;if((H|0)!=0){gGC(9104152,H|0,280)|0}c[2113054]=c[2113060];R=E}E=c[3527038]|0;H=R|0;A=0;while(1){x=E+A|0;c[H>>2]=x;c[H+131072>>2]=x;x=A+1024|0;if(x>>>0>262143){break}else{H=H+4|0;A=x}}A=c[3527040]|0;c[R+1792>>2]=A;c[R+67328>>2]=A;c[R+132864>>2]=A;H=A+1024|0;c[R+1796>>2]=H;c[R+67332>>2]=H;c[R+132868>>2]=H;H=A+2048|0;c[R+1800>>2]=H;c[R+67336>>2]=H;c[R+132872>>2]=H;H=A+3072|0;c[R+1804>>2]=H;c[R+67340>>2]=H;c[R+132876>>2]=H;H=A+4096|0;c[R+1808>>2]=H;c[R+67344>>2]=H;c[R+132880>>2]=H;H=A+5120|0;c[R+1812>>2]=H;c[R+67348>>2]=H;c[R+132884>>2]=H;H=A+6144|0;c[R+1816>>2]=H;c[R+67352>>2]=H;c[R+132888>>2]=H;H=A+7168|0;c[R+1820>>2]=H;c[R+67356>>2]=H;c[R+132892>>2]=H;H=A+8192|0;c[R+1824>>2]=H;c[R+67360>>2]=H;c[R+132896>>2]=H;H=A+9216|0;c[R+1828>>2]=H;c[R+67364>>2]=H;c[R+132900>>2]=H;H=A+10240|0;c[R+1832>>2]=H;c[R+67368>>2]=H;c[R+132904>>2]=H;H=A+11264|0;c[R+1836>>2]=H;c[R+67372>>2]=H;c[R+132908>>2]=H;H=A+12288|0;c[R+1840>>2]=H;c[R+67376>>2]=H;c[R+132912>>2]=H;H=A+13312|0;c[R+1844>>2]=H;c[R+67380>>2]=H;c[R+132916>>2]=H;H=A+14336|0;c[R+1848>>2]=H;c[R+67384>>2]=H;c[R+132920>>2]=H;H=A+15360|0;c[R+1852>>2]=H;c[R+67388>>2]=H;c[R+132924>>2]=H;H=c[2433346]|0;c[R+2304>>2]=H;c[R+67840>>2]=H;c[R+133376>>2]=H;A=H+1024|0;c[R+2308>>2]=A;c[R+67844>>2]=A;c[R+133380>>2]=A;A=c[2430856]|0;c[R+2560>>2]=A;c[R+68096>>2]=A;c[R+133632>>2]=A;H=A+1024|0;c[R+2564>>2]=H;c[R+68100>>2]=H;c[R+133636>>2]=H;H=c[2430852]|0;c[R+2816>>2]=H;c[R+68352>>2]=H;c[R+133888>>2]=H;A=H+1024|0;c[R+2820>>2]=A;c[R+68356>>2]=A;c[R+133892>>2]=A;A=H+2048|0;c[R+2824>>2]=A;c[R+68360>>2]=A;c[R+133896>>2]=A;A=H+3072|0;c[R+2828>>2]=A;c[R+68364>>2]=A;c[R+133900>>2]=A;A=H+4096|0;c[R+2832>>2]=A;c[R+68368>>2]=A;c[R+133904>>2]=A;A=H+5120|0;c[R+2836>>2]=A;c[R+68372>>2]=A;c[R+133908>>2]=A;A=H+6144|0;c[R+2840>>2]=A;c[R+68376>>2]=A;c[R+133912>>2]=A;A=H+7168|0;c[R+2844>>2]=A;c[R+68380>>2]=A;c[R+133916>>2]=A;A=H+8192|0;c[R+2848>>2]=A;c[R+68384>>2]=A;c[R+133920>>2]=A;A=H+9216|0;c[R+2852>>2]=A;c[R+68388>>2]=A;c[R+133924>>2]=A;A=H+10240|0;c[R+2856>>2]=A;c[R+68392>>2]=A;c[R+133928>>2]=A;A=H+11264|0;c[R+2860>>2]=A;c[R+68396>>2]=A;c[R+133932>>2]=A;A=H+12288|0;c[R+2864>>2]=A;c[R+68400>>2]=A;c[R+133936>>2]=A;A=H+13312|0;c[R+2868>>2]=A;c[R+68404>>2]=A;c[R+133940>>2]=A;A=H+14336|0;c[R+2872>>2]=A;c[R+68408>>2]=A;c[R+133944>>2]=A;A=H+15360|0;c[R+2876>>2]=A;c[R+68412>>2]=A;c[R+133948>>2]=A;A=c[2430080]|0;c[R+3328>>2]=A;c[R+68864>>2]=A;c[R+134400>>2]=A;H=A+1024|0;c[R+3332>>2]=H;c[R+68868>>2]=H;c[R+134404>>2]=H;c[R+196688>>2]=6;c[R+196728>>2]=3242;H=c[3532592]|0;if((H|0)!=0){gGC(H|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);H=c[2439330]|0;A=(H|0)==0;if(!A){E=H;gGC(9706056,E|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];E=c[3528484]|0;c[2076596]=E;x=c[2417276]|0;c[3541536]=x;c[1836236]=0;F=c[2438586]|0;G=0;K=0;while(1){c[H+76+(K<<2)>>2]=F+(K<<8);I=G+1&65535;if((I&65535)>239){S=0;T=0;break}else{G=I;K=I&65535}}while(1){K=F+(T<<8)|0;c[H+76+(T+512<<2)>>2]=K;c[H+76+(T+768<<2)>>2]=K;K=S+1&65535;if((K&65535)>239){break}else{S=K;T=K&65535}}F=c[2438588]|0;c[H+1036>>2]=F;K=F+256|0;c[H+1040>>2]=K;G=F+512|0;c[H+1044>>2]=G;I=F+768|0;c[H+1048>>2]=I;J=F+1024|0;c[H+1052>>2]=J;L=F+1280|0;c[H+1056>>2]=L;M=F+1536|0;c[H+1060>>2]=M;N=F+1792|0;c[H+1064>>2]=N;c[H+2060>>2]=F;c[H+2064>>2]=K;c[H+2068>>2]=G;c[H+2072>>2]=I;c[H+2076>>2]=J;c[H+2080>>2]=L;c[H+2084>>2]=M;c[H+2088>>2]=N;c[H+3084>>2]=F;c[H+4108>>2]=F;c[H+3088>>2]=K;c[H+4112>>2]=K;c[H+3092>>2]=G;c[H+4116>>2]=G;c[H+3096>>2]=I;c[H+4120>>2]=I;c[H+3100>>2]=J;c[H+4124>>2]=J;c[H+3104>>2]=L;c[H+4128>>2]=L;c[H+3108>>2]=M;c[H+4132>>2]=M;c[H+3112>>2]=N;c[H+4136>>2]=N;c[H+4180>>2]=886;c[H+4172>>2]=634;c[H+4176>>2]=2918;if(!A){N=H;gGC(N|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=E;c[2417276]=x;c[1836236]=-1;UL(4e6,206,2796,0);c[2438224]=4e6;c[2433522]=3416;c[2406672]=1752;c[3528468]=9362;c[2443842]=511;h[745398]=1.0;a[3203264]=1;N=c[2429494]|0;M=gGq(80)|0;L=M;c[2418506]=L;c[2424874]=L;gGz(M|0,0,80);a[635136]=0;c[M+4>>2]=~~(16.0e4/(a[9680]|0?32.0e3:0.0)*4194304.0);a[M+16|0]=0;if((N|0)==0){a[635136]=1}else{c[M+52>>2]=N}a[M+9|0]=1;a[(c[2424874]|0)+10|0]=1;N=c[2424874]|0;h[N+64>>3]=1.0;c[N+72>>2]=3;Vl();c[2424874]=L;h[M+64>>3]=.9;c[M+72>>2]=3;M=c[642608+(c[2436]<<2)>>2]|0;L=c[M+128>>2]|0;if((c[M+52>>2]&4|0)==0){c[2113068]=L;N=c[M+132>>2]|0;c[2113070]=N;c[2443814]=L;c[2440436]=N;U=L;V=N}else{c[2113070]=L;N=c[M+132>>2]|0;c[2113068]=N;c[2440436]=L;c[2443814]=N;U=N;V=L}L=ag(U<<1,V)|0;N=gGq(L)|0;c[2112926]=N;if((N|0)!=0){gGz(N|0,0,L|0)}c[2438862]=0;c[3528936]=0;gGz(14115680,0,14);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];L=c[3532592]|0;if((L|0)!=0){gGC(9104152,L|0,280)|0}c[2113054]=c[2113060]}RI();L=c[2394]|0;N=c[14130368+(L<<2)>>2]|0;if((N|0)!=0){gGC(N|0,9104152,280)|0}c[8452240+(L<<2)>>2]=c[2113054];c[2394]=-1;L=c[2439330]|0;N=(L|0)==0;if(!N){M=L;gGC(9706056,M|0,76)|0}M=c[2438118]|0;c[2433530]=M;J=c[3528484]|0;c[2076596]=J;I=c[2417276]|0;c[3541536]=I;c[1836236]=0;gGz(9706056,0,76);if(!N){N=L;gGC(N|0,9706056,76)|0}c[2438118]=M;c[3528484]=J;c[2417276]=I;c[1836236]=-1;c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;lw(c[3540984]|0);Vl();D=0;i=e;return D|0}}while(0);c[2426756]=0;D=1;i=e;return D|0}function dL0(b,c){b=b|0;c=c|0;a[9706117]=(c|0)!=0|0;return}function dL1(a){a=a|0;var b=0,d=0;b=(c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,4e6,0)|0;return a|0}function dL2(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=a[7452584]|0;if(b){d=0;e=b&1;while(1){b=14163936+(d<<2)|0;f=c[b>>2]|0;g=c[2113006]|0;if((g|0)==0){h=13442}else{i=g-1|0;c[2113006]=i;if((i|0)==0){h=13442}}if((h|0)==13442){h=0;c[2383474]=0}if((f|0)==0){j=e}else{gGr(f);j=a[7452584]&1}c[b>>2]=0;b=d+1|0;if((b|0)<(j|0)){d=b;e=j}else{break}}}a[7452584]=0;c[2438224]=0;c[2433522]=0;c[2406672]=0;c[3528468]=0;j=c[2406688]|0;if((j|0)!=0){gGr(j);c[2406688]=0}c[2432972]=0;j=c[2418506]|0;if((j|0)!=0){gGr(j);c[2418506]=0}j=c[2418507]|0;if((j|0)!=0){gGr(j);c[2418507]=0}a[635136]=0;if((c[2392]|0)>=0){j=0;do{e=14130368+(j<<2)|0;d=c[e>>2]|0;if((d|0)!=0){gGr(d);c[e>>2]=0}e=14130384+(j<<2)|0;d=c[e>>2]|0;if((d|0)!=0){gGr(d);c[e>>2]=0}j=j+1|0;}while((j|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;fwZ();c[2113070]=0;c[2113068]=0;j=c[2112926]|0;if((j|0)!=0){gGr(j);c[2112926]=0}j=c[2426756]|0;e=0;while(1){if((e|0)>=1024){h=13466;break}k=9638528+(e<<2)|0;if((c[k>>2]|0)==(j|0)){break}else{e=e+1|0}}if((h|0)==13466){c[2426756]=0;return 0}gGr(j);c[k>>2]=0;c[2426756]=0;return 0}function dL3(){var f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;if((a[9757672]|0)!=0){c[2438862]=0;c[3528936]=0;gGz(14115680,0,14);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060]}RI();f=c[2394]|0;g=c[14130368+(f<<2)>>2]|0;if((g|0)!=0){gGC(g|0,9104152,280)|0}c[8452240+(f<<2)>>2]=c[2113054];c[2394]=-1;f=c[2439330]|0;g=(f|0)==0;if(!g){i=f;gGC(9706056,i|0,76)|0}i=c[2438118]|0;c[2433530]=i;j=c[3528484]|0;c[2076596]=j;k=c[2417276]|0;c[3541536]=k;c[1836236]=0;gGz(9706056,0,76);if(!g){g=f;gGC(g|0,9706056,76)|0}c[2438118]=i;c[3528484]=j;c[2417276]=k;c[1836236]=-1;c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;lw(c[3540984]|0);Vl()}a[9757682]=0;a[9757681]=0;a[9757680]=0;k=0;j=0;i=0;g=0;do{j=((a[9720344+k|0]&1)<<k|j&255)&255;i=((a[9720336+k|0]&1)<<k|i&255)&255;g=((a[9720328+k|0]&1)<<k|g&255)&255;k=k+1|0;}while((k|0)<8);a[9757680]=j;a[9757681]=i;a[9757682]=g;if((j&3)==3){g=j&-4;a[9757680]=g;l=g}else{l=j}if((l&12)==12){a[9757680]=l&-13}if((i&3)==3){l=i&-4;a[9757681]=l;m=l}else{m=i}if((m&12)==12){a[9757681]=m&-13}a[6518056]=1;c[2444099]=0;c[2444098]=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];m=c[3532592]|0;if((m|0)!=0){gGC(9104152,m|0,280)|0}c[2113054]=c[2113060]}m=c[2439330]|0;if((m|0)!=0){i=m;gGC(9706056,i|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;i=c[2392]|0;if((i|0)>=0){gGz(8452240,0,((i|0)>0?(i<<2)+4|0:4)|0)}c[2113054]=0;i=c[2385548]|0;if((i|0)>0){gGz(9752472,0,((i|0)>1?i<<2:4)|0)}c[2433530]=0;c[2113056]=15e4;i=RG(15e4)|0;c[2113054]=(c[2113054]|0)+i;c[2276108]=-1;c[2113056]=-1;c[2444098]=(c[2444098]|0)+i;c[8452200+(c[2394]<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0<1024){RH(4)}i=a[6518056]|0?66666:0;m=gGU(i,0,2048e6,0)|0;l=c[2438224]|0;j=gGS(m,K,l,(l|0)<0|0?-1:0)|0;l=j;UF(i)|0;i=c[2443826]|0;if((i|0)<1073676288){c[2443826]=i-l}i=c[2443827]|0;if((i|0)<1073676288){c[2443827]=i-l}i=(c[3528508]|0)-l|0;c[3528508]=(i|0)<0?0:i;i=c[2112964]|0;if((i|0)!=0){gg[c[3542112]&4095](i,a[9688]|0?534:0);Vj(0,c[2112964]|0,a[9688]|0?534:0)}i=c[1836236]|0;l=c[9757320+(i<<2)>>2]|0;if((l|0)!=0){j=l;gGC(j|0,9706056,76)|0}c[9752472+(i<<2)>>2]=c[2433530];c[14113936+(i<<2)>>2]=c[2076596];c[9669104+(i<<2)>>2]=c[3541536];c[1836236]=-1;i=c[2394]|0;j=c[14130368+(i<<2)>>2]|0;if((j|0)!=0){gGC(j|0,9104152,280)|0}c[8452240+(i<<2)>>2]=c[2113054];c[2394]=-1;if((c[2112968]|0)==0){return 0}i=c[2437024]|0;j=0;l=c[2430080]|0;m=i;while(1){g=e[l>>1]|0;k=g>>>12;f=g>>>8;n=g>>>4&15;c[m>>2]=(k<<4|k)<<8&63488|(f<<4|f&12)<<3&2016|(n<<4|n)>>>3;n=j+1|0;if((n|0)<2048){j=n;l=l+2|0;m=m+4|0}else{break}}m=e[7057843]|0;l=m&15;j=e[7057842]|0;n=c[2430078]|0;f=c[2112926]|0;k=c[2430088]|0;g=0;o=m>>>4<<5&32736;while(1){m=(g<<4)-l|0;if((m-16|0)>>>0<224){p=0;q=o;while(1){r=q<<1;s=d[n+r|0]|0;t=s<<8;u=s>>>4;s=(p<<4)-j&511;v=s-16|0;w=(t&2048|0)==0;x=t&1792|d[n+(r|1)|0];do{if((s-32|0)>>>0<192){if(w){Sy(f,x,m,v,u,4,768,k);break}else{SA(f,x,m,v,u,4,768,k);break}}else{if(w){Sz(f,x,m,v,u,4,768,k);break}else{SB(f,x,m,v,u,4,768,k);break}}}while(0);u=q+1|0;v=(u|0)==32768?0:u;u=p+1|0;if((u|0)<32){p=u;q=v}else{y=v;break}}}else{q=0;p=o;while(1){v=p<<1;u=d[n+v|0]|0;x=u<<8;w=u>>>4;u=((q<<4)-j&511)-16|0;s=x&1792|d[n+(v|1)|0];if((x&2048|0)==0){Sz(f,s,m,u,w,4,768,k)}else{SB(f,s,m,u,w,4,768,k)}w=p+1|0;u=(w|0)==32768?0:w;w=q+1|0;if((w|0)<32){q=w;p=u}else{y=u;break}}}p=g+1|0;if((p|0)<17){g=p;o=y}else{break}}y=e[7057841]|0;o=y&15;g=e[7057840]|0;k=c[2430852]|0;n=c[2430090]|0;j=0;l=y>>>4<<5&8160;while(1){y=(j<<4)-o|0;if((y-16|0)>>>0<224){p=0;q=l;while(1){m=q<<1;u=d[k+(m|1)|0]|0;w=u<<8;s=u>>>4;u=(p<<4)-g&511;x=u-16|0;v=(w&2048|0)==0;r=w&1792|d[k+m|0];do{if((u-32|0)>>>0<192){if(v){SG(f,r,y,x,s,4,15,512,n);break}else{SK(f,r,y,x,s,4,15,512,n);break}}else{if(v){SH(f,r,y,x,s,4,15,512,n);break}else{SL(f,r,y,x,s,4,15,512,n);break}}}while(0);s=q+1|0;x=(s|0)==8192?0:s;s=p+1|0;if((s|0)<32){p=s;q=x}else{z=x;break}}}else{q=0;p=l;while(1){x=p<<1;s=d[k+(x|1)|0]|0;r=s<<8;v=s>>>4;s=((q<<4)-g&511)-16|0;u=r&1792|d[k+x|0];if((r&2048|0)==0){SH(f,u,y,s,v,4,15,512,n)}else{SL(f,u,y,s,v,4,15,512,n)}v=p+1|0;s=(v|0)==8192?0:v;v=q+1|0;if((v|0)<32){q=v;p=s}else{z=s;break}}}p=j+1|0;if((p|0)<17){j=p;l=z}else{break}}z=c[2430856]|0;l=c[2437022]|0;j=0;do{n=d[z+(j|1)|0]<<8|d[z+j|0];L17786:do{if(n>>>0<=254){k=n-16|0;g=d[z+(j|3)|0]<<8;o=d[z+(j|2)|0]|0;if((g&512|0)==0){A=g|o}else{A=-(o^255)|0}if((A|0)>256){break}o=d[z+(j|5)|0]<<8;g=(d[z+(j|7)|0]|0)>>>4;p=o&32768;q=o&16384;y=o&7936|d[z+(j|4)|0];o=y>>>0>5119?5119:y;do{if((A-16|0)>>>0<224){if((n-32|0)>>>0>=192){break}y=(q|0)!=0;if((p|0)==0){if(y){SI(f,o,A,k,g,4,15,256,l);break L17786}else{SG(f,o,A,k,g,4,15,256,l);break L17786}}else{if(y){SM(f,o,A,k,g,4,15,256,l);break L17786}else{SK(f,o,A,k,g,4,15,256,l);break L17786}}}}while(0);y=(q|0)!=0;if((p|0)==0){if(y){SJ(f,o,A,k,g,4,15,256,l);break}else{SH(f,o,A,k,g,4,15,256,l);break}}else{if(y){SN(f,o,A,k,g,4,15,256,l);break}else{SL(f,o,A,k,g,4,15,256,l);break}}}}while(0);j=j+8|0;}while((j|0)<2048);j=c[2433346]|0;l=c[2430854]|0;A=0;z=0;n=0;while(1){y=(z|0)==32;s=(y&1)+A|0;v=y?0:z;y=d[j+(n|1)|0]|0;u=y<<8|d[j+n|0];r=y>>>4;y=v<<3;x=s<<3;m=x-16|0;do{if((y-8|0)>>>0<240){if((x-24|0)>>>0>=208){B=13570;break}Sq(f,u&4095,y,m,r,4,15,0,l)}else{B=13570}}while(0);if((B|0)==13570){B=0;Sr(f,u&4095,y,m,r,4,15,0,l)}x=n+2|0;if((x|0)<2048){A=s;z=v+1|0;n=x}else{break}}R8(i);return 0}function dL4(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3615556+(b*112|0)>>2];c[a+104>>2]=c[3615560+(b*112|0)>>2];c[a+108>>2]=c[3615564+(b*112|0)>>2];d=0;return d|0}function dL5(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=3615456+(b*112|0);e=0;return e|0}function dL6(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>23){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1215120+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dL7(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>38){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3616576+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dL8(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;e=i;i=i+176|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;l=e+80|0;m=e+96|0;n=e+112|0;o=e+128|0;p=e+144|0;q=e+160|0;r=(d|0)==0;if(!r){c[d>>2]=169249}if((b&32|0)!=0){gGz(q|0,0,12);s=c[2405680]|0;c[q>>2]=s;c[q+4>>2]=(c[2411724]|0)-s;c[q+12>>2]=162152;s=c[2076592]|0;gj[s&4095](q)|0}if((b&64|0)==0){i=e;return 0}q=k|0;gGz(j|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){s=k+9|0;k=h;t=h|0;u=h+4|0;v=h+12|0;w=j|0;x=j+4|0;y=j+12|0;z=0;do{gGC(q|0,614896,11)|0;a[s]=z+48&255;A=8452256+(z<<2)|0;gGz(k|0,0,12);c[t>>2]=A;c[u>>2]=4;c[v>>2]=164976;gj[c[2076592]&4095](h)|0;if((c[A>>2]|0)!=0){c[w>>2]=c[14130368+(z<<2)>>2];c[x>>2]=c[8452184+(z<<2)>>2];c[y>>2]=q;A=c[2076592]|0;gj[A&4095](j)|0}z=z+1|0;}while((z|0)<=(c[2392]|0))}fw$(b);UQ(b,d);b=g|0;if(!r){c[d>>2]=169600}c[2424874]=c[2418506];cC(b|0,100600,(d=i,i=i+8|0,c[d>>2]=0,d)|0)|0;i=d;c[f>>2]=9699496;c[f+4>>2]=80;c[f+8>>2]=0;c[f+12>>2]=b;gj[c[2076592]&4095](f)|0;gGz(p|0,0,12);c[p>>2]=9757680;c[p+4>>2]=3;c[p+12>>2]=509360;gj[c[2076592]&4095](p)|0;gGz(o|0,0,12);c[o>>2]=14108168;c[o+4>>2]=2;c[o+12>>2]=497080;gj[c[2076592]&4095](o)|0;gGz(n|0,0,12);c[n>>2]=9755448;c[n+4>>2]=4;c[n+12>>2]=485184;gj[c[2076592]&4095](n)|0;gGz(m|0,0,12);c[m>>2]=14115680;c[m+4>>2]=14;c[m+12>>2]=472232;gj[c[2076592]&4095](m)|0;gGz(l|0,0,12);c[l>>2]=9776392;c[l+4>>2]=8;c[l+12>>2]=212472;gj[c[2076592]&4095](l)|0;i=e;return 0}function dL9(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3613316+(b*112|0)>>2];c[a+104>>2]=c[3613320+(b*112|0)>>2];c[a+108>>2]=c[3613324+(b*112|0)>>2];d=0;return d|0}function dMa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=3613216+(b*112|0);e=0;return e|0}function dMb(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3614436+(b*112|0)>>2];c[a+104>>2]=c[3614440+(b*112|0)>>2];c[a+108>>2]=c[3614444+(b*112|0)>>2];d=0;return d|0}function dMc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=3614336+(b*112|0);e=0;return e|0}function dMd(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3918084+(b*112|0)>>2];c[a+104>>2]=c[3918088+(b*112|0)>>2];c[a+108>>2]=c[3918092+(b*112|0)>>2];d=0;return d|0}function dMe(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=3917984+(b*112|0);e=0;return e|0}function dMf(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;if(b<<16>>16<0&(b&65535)<49152){f=e&255;g=(f&1|0)==0?0:85;h=(f&16|0)==0?g:g|170;g=(f&2|0)==0?h:h|21760;h=(f&32|0)==0?g:g|43520;g=(f&4|0)==0?h:h|5570560;h=(f&64|0)==0?g:g|11141120;g=(f&8|0)==0?h:h|1426063360;h=d[(c[2439506]|0)+8|0]|0;i=(h&8|0)==0?0:808464432;j=(h&4|0)==0?i:i|-1061109568;i=(h&2|0)==0?j:j|50529027;j=(h&1|0)==0?i:i|202116108;i=(c[3527232]|0)+((b&16383)<<2)|0;c[i>>2]=c[i>>2]&~j|j&((f&128|0)==0?g:g|-1442840576);return}g=(b&-5120)<<16>>16==-6144?b&-1009:b;b=((g&-5120)<<16>>16==-5120?g&-256:g)&65535;switch(b|0){case 59397:{g=c[2439506]|0;a[g+5|0]=e;f=a[g+4|0]|0;j=a[g+8|0]|0;i=e&255;h=f&255;k=((j&255)>>>1&1|j&5)&255;l=(k&4|0)==0?0:-1061109568;m=(k&1|0)==0?l:l|202116108;l=~m;k=(j<<1&2|j&10)&255;j=(k&8|0)==0?0:808464432;n=(k&2|0)==0?j:j|50529027;j=~n;k=(f&255)+1&65535;f=c[2387822]|0;o=c[3527232]|0;p=0;q=(d[g+3|0]|0)<<8|(d[g+2|0]|0);r=(d[g+1|0]|0)<<8|(d[g]|0);while(1){g=q&65535;s=0;t=r;while(1){u=t&8191;v=d[f+u|0]|0;w=(v&1|0)==0?0:85;x=(v&16|0)==0?w:w|170;w=(v&2|0)==0?x:x|21760;x=(v&32|0)==0?w:w|43520;w=(v&4|0)==0?x:x|5570560;x=(v&64|0)==0?w:w|11141120;w=(v&8|0)==0?x:x|1426063360;x=o+((s+g&16383)<<2)|0;y=((v&128|0)==0?w:w|-2013265920)&m|c[x>>2]&l;c[x>>2]=y;w=d[f+(u|8192)|0]|0;u=(w&1|0)==0?0:85;v=(w&16|0)==0?u:u|170;u=(w&2|0)==0?v:v|21760;v=(w&32|0)==0?u:u|43520;u=(w&4|0)==0?v:v|5570560;v=(w&64|0)==0?u:u|11141120;u=(w&8|0)==0?v:v|1426063360;c[x>>2]=((w&128|0)==0?u:u|570425344)&n|y&j;y=s+1|0;if((y|0)>(h|0)){break}else{s=y;t=t+1&65535}}t=p+1|0;if((t|0)>(i|0)){break}else{p=t;q=q+256&65535;r=k+r&65535}}return};case 59400:{a[(c[2439506]|0)+8|0]=e;r=c[2387822]|0;k=c[9757320+(c[1836236]<<2)>>2]|0;q=(e&5)!=0?-49152:-40960;p=192;i=192;while(1){c[k+76+(i<<2)>>2]=r+(q+(i<<8));h=p+1&65535;if((h&65535)>223){break}else{p=h;i=h&65535}}return};case 59398:case 59399:{a[(c[2439506]|0)+(b&15)|0]=e;return};case 59401:case 59402:{a[(c[2439506]|0)+(b&15)|0]=e;return};case 60416:{a[14113176]=e;return};case 59392:case 59393:case 59394:case 59395:case 59396:{a[(c[2439506]|0)+(b&15)|0]=e;return};default:{return}}}function dMg(b){b=b|0;var c=0,d=0;c=(b&-5120)<<16>>16==-7168?b&-1024:b;switch(((c&-5120)<<16>>16==-5120?c&-256:c)&65535|0){case 60672:{c=(a[9633850]|0)!=0|0;b=(a[9633851]|0)==0?c:c|2;c=(a[9633852]|0)==0?b:b|4;b=(a[9633853]|0)==0?c:c|8;d=(a[9633854]|0)==0?b:b|16;return d|0};case 61184:{b=(a[9753008]|0)+1&255;a[9753008]=b;d=b&15;return d|0};case 60928:{b=(a[9631650]|0)!=0|0;c=(a[9631651]|0)==0?b:b|2;b=(a[9631652]|0)==0?c:c|4;c=(a[9631653]|0)==0?b:b|8;d=(a[9631654]|0)==0?c:c|16;return d|0};case 58368:{d=a[9635257]|0;return d|0};case 60416:{c=(a[9633855]|0)!=0|a[9635256];b=(a[9633849]|0)==0?c:c|2;c=(a[9631649]|0)==0?b:b|4;b=(a[9633848]|0)==0?c:c|8;d=(a[9631648]|0)==0?b:b|16;return d|0};default:{d=0;return d|0}}return 0}function dMh(b){b=b|0;return((b&-4096)<<16>>16==24576?a[14113176]|0:0)|0}function dMi(b,d){b=b|0;d=d|0;var e=0,f=0;e=b&61440;if((e|0)==28672){b=d&255;f=c[3542228]|0;if((f|0)>15){return}do{if((f|0)<14){if((f|0)!=13){if((a[14168916+f|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(0,f,b);return}else if((e|0)==32768){c[3542228]=d&15;return}else{return}}function dMj(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;if((a[9624432]|0)!=0){a[9624432]=0;d=c[2414832]|0;gGz(d|0,0,(c[2411722]|0)-d|0);d=c[2439330]|0;if((d|0)!=0){e=d;gGC(9706056,e|0,76)|0}c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;gGz(9706056,0,76);a[9706116]=1;a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;e=(c[2433530]|0)+12|0;c[2433530]=e;d=c[1836236]|0;f=c[9757320+(d<<2)>>2]|0;if((f|0)!=0){g=f;gGC(g|0,9706056,76)|0}c[9752472+(d<<2)>>2]=e;c[14113936+(d<<2)>>2]=c[2076596];c[9669104+(d<<2)>>2]=c[3541536];c[1836236]=-1;d=c[2439331]|0;e=(d|0)==0;if(!e){g=d;gGC(9706056,g|0,76)|0}g=c[2438119]|0;c[2433530]=g;f=c[3528485]|0;c[2076596]=f;h=c[2417277]|0;c[3541536]=h;c[1836236]=1;gGz(9706056,0,76);if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438119]=g;c[3528485]=f;c[2417277]=h;c[1836236]=-1;mB(0);a[14113176]=0;a[9753008]=0}h=c[2385548]|0;if((h|0)>0){gGz(9752472,0,((h|0)>1?h<<2:4)|0)}c[2433530]=0;h=0;f=0;g=0;e=0;L17991:while(1){d=f;i=g;j=e;while(1){if((d|0)>=10){break L17991}k=c[2439330]|0;if((k|0)!=0){l=k;gGC(9706056,l|0,76)|0}b[4853030]=c[2426515]&65535;l=c[2438118]|0;c[2433530]=l;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;m=d+1|0;n=((m*41666|0|0)/10|0)-i|0;do{if((n|0)<1){o=0}else{if((a[k+4188|0]|0)==0){p=gfc(n)|0;c[2433530]=(c[2433530]|0)+p;o=p;break}else{c[2433530]=l+n;o=n;break}}}while(0);q=o+i|0;if((d|0)==9){a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0;r=1}else{r=0}n=c[1836236]|0;l=c[9757320+(n<<2)>>2]|0;if((l|0)!=0){k=l;gGC(k|0,9706056,76)|0}c[9752472+(n<<2)>>2]=c[2433530];c[14113936+(n<<2)>>2]=c[2076596];c[9669104+(n<<2)>>2]=c[3541536];c[1836236]=-1;n=c[2439331]|0;if((n|0)!=0){k=n;gGC(9706056,k|0,76)|0}b[4853030]=c[2426515]&65535;k=c[2438119]|0;c[2433530]=k;c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;l=((m*20833|0|0)/10|0)-j|0;do{if((l|0)<1){s=0}else{if((a[n+4188|0]|0)==0){p=gfc(l)|0;c[2433530]=(c[2433530]|0)+p;s=p;break}else{c[2433530]=k+l;s=l;break}}}while(0);t=s+j|0;if(r){a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0}l=c[1836236]|0;k=c[9757320+(l<<2)>>2]|0;if((k|0)!=0){n=k;gGC(n|0,9706056,76)|0}c[9752472+(l<<2)>>2]=c[2433530];c[14113936+(l<<2)>>2]=c[2076596];c[9669104+(l<<2)>>2]=c[3541536];c[1836236]=-1;u=c[2112964]|0;if((u|0)==0){d=m;i=q;j=t}else{break}}j=a[9688]|0?53:0;mF(9756152,u+(h<<1<<1)|0,j,0);h=j+h|0;f=m;g=q;e=t}t=c[2112964]|0;do{if((t|0)!=0){e=a[9688]|0?534:0;if((e|0)==(h|0)){break}mF(9756152,t+(h<<1<<1)|0,e-h|0,0)}}while(0);if((c[2112968]|0)==0){return 0}dMk()|0;return 0}function dMk(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;d=c[2439506]|0;e=a[d+6|0]|0;f=a[d+7|0]|0;g=a[d+10|0]|0;h=(g&255)>>>3&5;i=g&7;j=a[d+9|0]|0;d=j&255;k=d<<26>>31;l=d<<27>>31;d=j&8;m=j&4;n=~j;j=n&2;o=n&1;if((a[9547584]|0)!=0){n=c[2406944]|0;p=c[3530052]|0;q=0;do{r=c[n+(q<<2)>>2]|0;c[p+(q<<2)>>2]=r>>>8<<3&2016|r>>>3&31|r>>>16<<8&63488;q=q+1|0;}while((q|0)<8)}q=c[2113070]|0;if((q|0)<=0){s=c[3530052]|0;R8(s);return 0}p=f&255;f=e&255;e=d<<24>>24==0;d=j<<24>>24!=0;j=m<<24>>24!=0;m=o<<24>>24!=0;o=c[2113068]|0;n=c[2112926]|0;r=c[3527232]|0;t=0;do{u=ag(t,o)|0;L18047:do{if((o|0)>0){v=(t^k)+f&255;w=(t^l)&255;if(e){x=0;while(1){y=(x|0)/2|0;z=(y^k)+p|0;A=y^l;y=(c[r+((A>>>2<<8&16128|w)<<2)>>2]|0)>>>((A<<3&24|4)>>>0);A=y&255;do{if(j){B=m|(c[r+((z>>>2<<8&16128|v)<<2)>>2]&15<<(z<<3&24)|0)==0;b[n+(x+u<<1)>>1]=B?y&7:0;if(!B){C=0;break}C=((A&8)==0?g:7)&A&7}else{b[n+(x+u<<1)>>1]=0;C=0}}while(0);b[n+((x|1)+u<<1)>>1]=C;x=x+2|0;if((x|0)>=(o|0)){break L18047}}}else{D=0}do{x=(D|0)/2|0;A=(x^k)+p|0;y=x^l;x=(c[r+((A>>>2<<8&16128|v)<<2)>>2]|0)>>>((A<<3&24)>>>0)&255;A=x&15;z=(c[r+((y>>>2<<8&16128|w)<<2)>>2]|0)>>>((y<<3&24|4)>>>0)&255;y=z&15;B=d|y<<24>>24==0;E=B?A:0;if(j){F=E|(m|A<<24>>24==0?y:0)}else{F=E}b[n+(D+u<<1)>>1]=F&7;if(B){B=(x&8)==0?h&x:A;G=B;H=B}else{G=0;H=A}do{if(j){if(!(m|H<<24>>24==0)){I=G;break}I=G|((z&8)==0?i&z:y)}else{I=G}}while(0);b[n+((D|1)+u<<1)>>1]=I&7;D=D+2|0;}while((D|0)<(o|0))}}while(0);t=t+1|0;}while((t|0)<(q|0));s=c[3530052]|0;R8(s);return 0}function dMl(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2852764+(b*112|0)>>2];c[a+104>>2]=c[2852768+(b*112|0)>>2];c[a+108>>2]=c[2852772+(b*112|0)>>2];d=0;return d|0}function dMm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=2852664+(b*112|0);e=0;return e|0}function dMn(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6930016+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dMo(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>38){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7438736+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dMp(){var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0.0,K=0,L=0;d=i;i=i+720|0;e=d|0;f=d+112|0;g=d+120|0;j=d+232|0;k=d+240|0;l=d+352|0;m=d+360|0;n=d+472|0;o=d+480|0;p=d+592|0;q=d+600|0;r=d+712|0;c[2426754]=0;c[3529246]=65536;c[3529202]=90112;c[2387822]=94208;c[2406944]=110592;c[3530052]=110624;c[2414832]=110656;c[3529334]=110656;c[3529292]=111680;c[3527232]=112704;c[2439506]=178240;c[2411722]=178256;s=(a[9688]|0?181460:178256)|0;c[2414264]=s;t=s;s=0;while(1){if((s|0)>=1024){break}u=9638528+(s<<2)|0;if((c[u>>2]|0)==0){v=13801;break}else{s=s+1|0}}do{if((v|0)==13801){s=gGq(t)|0;c[u>>2]=s;if((s|0)==0){break}gGz(s|0,0,t|0);c[2426754]=s;gGz(s|0,0,t|0);w=s+65536|0;c[3529246]=w;c[3529202]=s+90112;c[2387822]=s+94208;c[2406944]=s+110592;c[3530052]=s+110624;x=s+110656|0;c[2414832]=x;c[3529334]=x;c[3529292]=s+111680;c[3527232]=s+112704;c[2439506]=s+178240;x=s+178256|0;c[2411722]=x;y=x;c[2385372]=y;x=a[9688]|0?534:0;c[2414264]=s+((x*6|0)+178256);c[2439038]=y;c[2439039]=y+(x<<1);c[2439040]=y+(x<<1<<1);L18107:do{if((dW(522984,c[c[642608+(c[2436]<<2)>>2]>>2]|0,7)|0)==0){x=q+108|0;y=q+100|0;s=0;z=w;while(1){A=z+(s<<12)|0;if((c[3542200]|0)==0){B=1;v=13875;break}c[x>>2]=0;c[y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](q,s)|0;if((c[x>>2]|0)!=0){C=c[y>>2]|0;c[r>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](r,s,0)|0;if((C|0)<1){B=1;v=13883;break}if((gzL(A,0,s)|0)!=0){B=1;v=13866;break}}A=s+1|0;if((A|0)>=6){v=13812;break}s=A;z=c[3529246]|0}if((v|0)==13866){i=d;return B|0}else if((v|0)==13875){i=d;return B|0}else if((v|0)==13812){z=c[3529202]|0;if((c[3542200]|0)==0){B=1;i=d;return B|0}s=o+108|0;c[s>>2]=0;y=o+100|0;c[y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](o,6)|0;do{if((c[s>>2]|0)!=0){x=c[y>>2]|0;c[p>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](p,6,0)|0;if((x|0)<1){B=1;i=d;return B|0}if((gzL(z,0,6)|0)==0){break}else{B=1}i=d;return B|0}}while(0);z=m+108|0;y=m+100|0;s=0;while(1){x=(c[2387822]|0)+(s<<12)|0;A=s+7|0;if((c[3542200]|0)==0){B=1;v=13865;break}c[z>>2]=0;c[y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,A)|0;if((c[z>>2]|0)!=0){C=c[y>>2]|0;c[n>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](n,A,0)|0;if((C|0)<1){B=1;v=13873;break}if((gzL(x,0,A)|0)!=0){B=1;v=13879;break}}s=s+1|0;if((s|0)>=4){break L18107}}if((v|0)==13865){i=d;return B|0}else if((v|0)==13873){i=d;return B|0}else if((v|0)==13879){i=d;return B|0}}else if((v|0)==13883){i=d;return B|0}}else{s=k+108|0;y=k+100|0;z=g+108|0;A=g+100|0;x=0;C=w;while(1){D=x<<12;E=C+D|0;if((c[3542200]|0)==0){B=1;v=13869;break}c[s>>2]=0;c[y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,x)|0;if((c[s>>2]|0)!=0){F=c[y>>2]|0;c[l>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](l,x,0)|0;if((F|0)<1){B=1;v=13882;break}if((gzL(E,0,x)|0)!=0){B=1;v=13870;break}}E=(c[2387822]|0)+D|0;D=x+5|0;if((c[3542200]|0)==0){B=1;v=13880;break}c[z>>2]=0;c[A>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,D)|0;if((c[z>>2]|0)!=0){F=c[A>>2]|0;c[j>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](j,D,0)|0;if((F|0)<1){B=1;v=13885;break}if((gzL(E,0,D)|0)!=0){B=1;v=13868;break}}D=x+1|0;if((D|0)>=4){v=13832;break}x=D;C=c[3529246]|0}if((v|0)==13868){i=d;return B|0}else if((v|0)==13869){i=d;return B|0}else if((v|0)==13870){i=d;return B|0}else if((v|0)==13880){i=d;return B|0}else if((v|0)==13882){i=d;return B|0}else if((v|0)==13885){i=d;return B|0}else if((v|0)==13832){C=c[3529202]|0;if((c[3542200]|0)==0){B=1;i=d;return B|0}x=e+108|0;c[x>>2]=0;A=e+100|0;c[A>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,4)|0;if((c[x>>2]|0)==0){break}x=c[A>>2]|0;c[f>>2]=9534384;gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](f,4,0)|0;if((x|0)<1){B=1;i=d;return B|0}if((gzL(C,0,4)|0)==0){break}else{B=1}i=d;return B|0}}}while(0);w=c[2406944]|0;c[w>>2]=0;c[w+4>>2]=255;c[w+8>>2]=65280;c[w+12>>2]=65535;c[w+16>>2]=16711680;c[w+20>>2]=16711935;c[w+24>>2]=16776960;c[w+28>>2]=16777215;fwR(0);w=c[2439330]|0;if((w|0)!=0){C=w;gGC(9706056,C|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];C=c[3528484]|0;c[2076596]=C;x=c[2417276]|0;c[3541536]=x;c[1836236]=0;A=c[3529246]|0;z=0;y=0;while(1){c[w+76+(y<<2)>>2]=A+(y<<8);s=z+1&65535;if((s&65535)>95){H=0;I=0;break}else{z=s;y=s&65535}}while(1){y=A+(I<<8)|0;c[w+76+(I+512<<2)>>2]=y;c[w+76+(I+768<<2)>>2]=y;y=H+1&65535;if((y&65535)>95){break}else{H=y;I=y&65535}}A=c[2387822]|0;y=192;z=192;while(1){c[w+76+(z<<2)>>2]=A+((z<<8)-49152);s=y+1&65535;if((s&65535)>223){break}else{y=s;z=s&65535}}z=c[3529334]|0;c[w+972>>2]=z;y=z+256|0;c[w+976>>2]=y;A=z+512|0;c[w+980>>2]=A;s=z+768|0;c[w+984>>2]=s;c[w+1996>>2]=z;c[w+2e3>>2]=y;c[w+2004>>2]=A;c[w+2008>>2]=s;c[w+3020>>2]=z;c[w+4044>>2]=z;c[w+3024>>2]=y;c[w+4048>>2]=y;c[w+3028>>2]=A;c[w+4052>>2]=A;c[w+3032>>2]=s;c[w+4056>>2]=s;c[w+4184>>2]=1552;c[w+4180>>2]=2844;s=w;gGC(s|0,9706056,76)|0;c[2438118]=c[2433530];c[3528484]=C;c[2417276]=x;c[1836236]=-1;fwR(1);s=c[2439331]|0;if((s|0)!=0){A=s;gGC(9706056,A|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];A=c[3528485]|0;c[2076596]=A;y=c[2417277]|0;c[3541536]=y;c[1836236]=1;z=c[3529202]|0;c[s+76>>2]=z;c[s+80>>2]=z+256;c[s+84>>2]=z+512;c[s+88>>2]=z+768;c[s+92>>2]=z+1024;c[s+96>>2]=z+1280;c[s+100>>2]=z+1536;c[s+104>>2]=z+1792;c[s+108>>2]=z+2048;c[s+112>>2]=z+2304;c[s+116>>2]=z+2560;c[s+120>>2]=z+2816;c[s+124>>2]=z+3072;c[s+128>>2]=z+3328;c[s+132>>2]=z+3584;c[s+136>>2]=z+3840;D=0;E=0;while(1){F=z+(E<<8)|0;c[s+76+(E+512<<2)>>2]=F;c[s+76+(E+768<<2)>>2]=F;F=D+1&65535;if((F&65535)>15){break}else{D=F;E=F&65535}}E=c[3529292]|0;c[s+332>>2]=E;D=E+256|0;c[s+336>>2]=D;z=E+512|0;c[s+340>>2]=z;x=E+768|0;c[s+344>>2]=x;c[s+1356>>2]=E;c[s+1360>>2]=D;c[s+1364>>2]=z;c[s+1368>>2]=x;c[s+2380>>2]=E;c[s+3404>>2]=E;c[s+2384>>2]=D;c[s+3408>>2]=D;c[s+2388>>2]=z;c[s+3412>>2]=z;c[s+2392>>2]=x;c[s+3416>>2]=x;c[s+4184>>2]=290;c[s+4180>>2]=1864;c[s+4172>>2]=1864;c[s+4176>>2]=290;x=s;gGC(x|0,9706056,76)|0;c[2438119]=c[2433530];c[3528485]=A;c[2417277]=y;c[1836236]=-1;x=a[9680]|0?32e3:0;c[3542220]=11200;if((c[2113008]|0)==0){gGz(14168888,0,252);c[3542223]=x;gGz(14168896,0,16);c[3542234]=~~((+(x|0)*32768.0*8.0+625.0e3)/125.0e4);x=31;J=32767.0;while(1){c[14169012+(x<<2)>>2]=~~(J+.5);z=x-1|0;if((z|0)>0){x=z;J=J/1.188502227}else{break}}c[3542253]=0;h[1771269]=1.0;h[1771270]=1.0;h[1771271]=1.0;c[3542574]=3;c[3542575]=3;c[3542576]=3;mB(0);c[2113008]=(c[2113008]|0)+1}h[1771269]=.5;c[3542574]=3;h[1771270]=.5;c[3542575]=3;h[1771271]=.5;c[3542576]=3;a[9624432]=0;x=c[2414832]|0;gGz(x|0,0,(c[2411722]|0)-x|0);x=c[2439330]|0;if((x|0)!=0){y=x;gGC(9706056,y|0,76)|0}c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;gGz(9706056,0,76);a[9706116]=1;a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;y=(c[2433530]|0)+12|0;c[2433530]=y;x=c[1836236]|0;A=c[9757320+(x<<2)>>2]|0;if((A|0)!=0){s=A;gGC(s|0,9706056,76)|0}c[9752472+(x<<2)>>2]=y;c[14113936+(x<<2)>>2]=c[2076596];c[9669104+(x<<2)>>2]=c[3541536];c[1836236]=-1;x=c[2439331]|0;y=(x|0)==0;if(!y){s=x;gGC(9706056,s|0,76)|0}s=c[2438119]|0;c[2433530]=s;A=c[3528485]|0;c[2076596]=A;z=c[2417277]|0;c[3541536]=z;c[1836236]=1;gGz(9706056,0,76);if(!y){y=x;gGC(y|0,9706056,76)|0}c[2438119]=s;c[3528485]=A;c[2417277]=z;c[1836236]=-1;mB(0);a[14113176]=0;a[9753008]=0;z=c[642608+(c[2436]<<2)>>2]|0;A=c[z+128>>2]|0;if((c[z+52>>2]&4|0)==0){c[2113068]=A;s=c[z+132>>2]|0;c[2113070]=s;c[2443814]=A;c[2440436]=s;K=A;L=s}else{c[2113070]=A;s=c[z+132>>2]|0;c[2113068]=s;c[2440436]=A;c[2443814]=s;K=s;L=A}A=ag(K<<1,L)|0;s=gGq(A)|0;c[2112926]=s;if((s|0)==0){B=0;i=d;return B|0}gGz(s|0,0,A|0);B=0;i=d;return B|0}}while(0);c[2426754]=0;B=1;i=d;return B|0}function dMq(){var a=0,b=0,d=0,e=0;a=c[2426754]|0;b=0;while(1){if((b|0)>=1024){break}d=9638528+(b<<2)|0;if((c[d>>2]|0)==(a|0)){e=13889;break}else{b=b+1|0}}if((e|0)==13889){gGr(a);c[d>>2]=0}c[2426754]=0;c[2113070]=0;c[2113068]=0;d=c[2112926]|0;if((d|0)!=0){gGr(d);c[2112926]=0}fwZ();c[2113008]=0;c[2076598]=0;c[2383582]=0;return 0}function dMr(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2723156+(b*112|0)>>2];c[a+104>>2]=c[2723160+(b*112|0)>>2];c[a+108>>2]=c[2723164+(b*112|0)>>2];d=0;return d|0}function dMs(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=2723056+(b*112|0);e=0;return e|0}function dMt(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2725844+(b*112|0)>>2];c[a+104>>2]=c[2725848+(b*112|0)>>2];c[a+108>>2]=c[2725852+(b*112|0)>>2];d=0;return d|0}function dMu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=2725744+(b*112|0);e=0;return e|0}function dMv(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2724612+(b*112|0)>>2];c[a+104>>2]=c[2724616+(b*112|0)>>2];c[a+108>>2]=c[2724620+(b*112|0)>>2];d=0;return d|0}function dMw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=2724512+(b*112|0);e=0;return e|0}function dMx(a,b){a=a|0;b=b|0;return}function dMy(d,e){d=d|0;e=e|0;switch(d|0){case 1572870:{b[(c[2409e3]|0)+2>>1]=e&511;return};case 1572866:{c[8452200+(c[2394]<<2)>>2]=0;c[2276080]=0;return};case 1572874:{a[c[3528720]|0]=e&1;return};case 1572872:{a[c[3528292]|0]=e&255;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12;return};case 1572864:{c[8452200+(c[2394]<<2)>>2]=0;c[2276080]=0;return};case 1572868:{b[c[2409e3]>>1]=e&511;return};default:{return}}}function dMz(d){d=d|0;var f=0;switch(d|0){case 1572868:{f=(e[4775312]|0)>>>8&255;break};case 1572873:{f=(b[4775314]&254|c[2408982])&255;break};case 1572870:{f=(e[4775313]|0)>>>8&255;break};case 1572867:{f=a[9635249]|0;break};case 1572869:{f=b[4775312]&255;break};case 1572872:{f=(e[4775314]|0)>>>8&255;break};case 1572871:{f=b[4775313]&255;break};default:{f=0}}return f|0}function dMA(a){a=a|0;var e=0;switch(a|0){case 1572872:{e=(b[4775314]&65534|c[2408982])&65535;break};case 1572870:{e=b[4775313]|0;break};case 1572864:{e=d[9635248]|0|-256;break};case 1572868:{e=b[4775312]|0;break};case 1572866:{e=d[9635249]|0|-256;break};default:{e=0}}return e|0}function dMB(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((e|0)==34816){c[2113304]=d&255;return}else if((e|0)==34817){b=c[2113304]|0;a[14168504+b|0]=d;mv(0,b,d&255);return}else if((e|0)==38912){Uv(0,d);return}else{return}}function dMC(b){b=b|0;var d=0,e=0;d=b&65535;if((d|0)==38912){e=c[2113156]&255}else if((d|0)==40960){e=a[c[3528292]|0]|0}else if((d|0)==34816|(d|0)==34817){e=c[(c[3531464]|0)+4240>>2]&255}else{e=0}return e|0}function dMD(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2071140+(b*112|0)>>2];c[a+104>>2]=c[2071144+(b*112|0)>>2];c[a+108>>2]=c[2071148+(b*112|0)>>2];d=0;return d|0}function dME(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=2071040+(b*112|0);e=0;return e|0}function dMF(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1172928+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dMG(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>41){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3228264+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dMH(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0;e=i;i=i+7080|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;B=e+1200|0;C=e+1312|0;D=e+1320|0;E=e+1432|0;F=e+1440|0;G=e+1552|0;H=e+1560|0;I=e+1672|0;J=e+1680|0;K=e+1792|0;L=e+1800|0;M=e+1912|0;N=e+1920|0;O=e+2032|0;P=e+2040|0;Q=e+2152|0;R=e+2160|0;S=e+2272|0;T=e+2280|0;U=e+2392|0;V=e+2400|0;W=e+2512|0;X=e+2520|0;Y=e+2632|0;Z=e+2640|0;_=e+2752|0;$=e+2760|0;aa=e+2872|0;ab=e+2880|0;ac=e+2992|0;ad=e+3e3|0;ae=e+3112|0;af=e+3120|0;ah=e+3232|0;ai=e+3240|0;aj=e+3352|0;ak=e+3360|0;al=e+3472|0;am=e+3480|0;an=e+3592|0;ao=e+3600|0;ap=e+3712|0;aq=e+3720|0;ar=e+3832|0;as=e+3840|0;at=e+3952|0;au=e+3960|0;av=e+4072|0;aw=e+4080|0;ax=e+4192|0;ay=e+4200|0;az=e+4312|0;aA=e+4320|0;aB=e+4432|0;aC=e+4440|0;aD=e+4552|0;aE=e+4560|0;aF=e+4672|0;aG=e+4680|0;aH=e+4792|0;aI=e+4800|0;aJ=e+4912|0;aK=e+4920|0;aL=e+5032|0;aM=e+5040|0;aN=e+5152|0;aO=e+5160|0;aP=e+5272|0;aQ=e+5280|0;aR=e+5392|0;aS=e+5400|0;aT=e+5512|0;aU=e+5520|0;aV=e+5632|0;aW=e+5640|0;aX=e+5752|0;aY=e+5760|0;aZ=e+5872|0;a_=e+5880|0;a$=e+5992|0;a0=e+6e3|0;a1=e+6112|0;a2=e+6120|0;a3=e+6232|0;a4=e+6240|0;a5=e+6352|0;a6=e+6360|0;a7=e+6472|0;a8=e+6480|0;a9=e+6592|0;ba=e+6600|0;bb=e+6712|0;bc=e+6720|0;bd=e+6832|0;be=e+6840|0;bf=e+6952|0;bg=e+6960|0;bh=e+7072|0;c[2414998]=0;c[2388172]=0;c[2385938]=262144;c[3530868]=327680;c[3530632]=589824;c[3530442]=4784128;c[3541206]=5832704;c[2386662]=5832704;c[3530050]=6094848;c[2414702]=6096384;c[2388294]=6096384;c[2386092]=6112768;c[2386480]=6114816;c[2387222]=6115840;c[2406496]=6119936;c[2406576]=6124032;c[3528292]=6128128;c[3528720]=6128129;c[2409e3]=6128130;c[2411720]=6128134;bi=0;while(1){if((bi|0)>=1024){break}bj=9638528+(bi<<2)|0;if((c[bj>>2]|0)==0){bk=14006;break}else{bi=bi+1|0}}do{if((bk|0)==14006){bi=gGq(6128134)|0;c[bj>>2]=bi;if((bi|0)==0){break}c[2414998]=bi;gGz(bi|0,0,6128134);c[2388172]=bi;c[2385938]=bi+262144;c[3530868]=bi+327680;c[3530632]=bi+589824;c[3530442]=bi+4784128;bl=bi+5832704|0;c[3541206]=bl;c[2386662]=bl;c[3530050]=bi+6094848;bl=bi+6096384|0;c[2414702]=bl;c[2388294]=bl;c[2386092]=bi+6112768;c[2386480]=bi+6114816;c[2387222]=bi+6115840;c[2406496]=bi+6119936;c[2406576]=bi+6124032;c[3528292]=bi+6128128;c[3528720]=bi+6128129;c[2409e3]=bi+6128130;bl=bi+6128134|0;c[2411720]=bl;c[2414262]=bl;bl=(fa(c[c[642608+(c[2436]<<2)>>2]>>2]|0,566632)|0)==0;bm=(R6(bi+1|0,0,2)|0)!=0;do{if(bl){if(bm){bn=1;i=e;return bn|0}if((R6((c[2388172]|0)+131073|0,1,2)|0)!=0){bn=1;i=e;return bn|0}if((R6(c[2388172]|0,2,2)|0)!=0){bn=1;i=e;return bn|0}if((R6((c[2388172]|0)+131072|0,3,2)|0)!=0){bn=1;i=e;return bn|0}bi=c[2385938]|0;if((c[3542200]|0)==0){bn=1;i=e;return bn|0}bo=bg+108|0;c[bo>>2]=0;bp=bg+100|0;c[bp>>2]=0;bq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[bq&16383](bg,4)|0;do{if((c[bo>>2]|0)!=0){bq=c[bp>>2]|0;c[bh>>2]=9534384;br=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[br&16383](bh,4,0)|0;if((bq|0)<1){bn=1;i=e;return bn|0}if((gzL(bi,0,4)|0)==0){break}else{bn=1}i=e;return bn|0}}while(0);bi=c[2386662]|0;if((c[3542200]|0)==0){bn=1;i=e;return bn|0}bp=be+108|0;c[bp>>2]=0;bo=be+100|0;c[bo>>2]=0;bq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[bq&16383](be,5)|0;do{if((c[bp>>2]|0)!=0){bq=c[bo>>2]|0;c[bf>>2]=9534384;br=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[br&16383](bf,5,0)|0;if((bq|0)<1){bn=1;i=e;return bn|0}if((gzL(bi,0,5)|0)==0){break}else{bn=1}i=e;return bn|0}}while(0);bi=(c[2386662]|0)+65536|0;if((c[3542200]|0)==0){bn=1;i=e;return bn|0}bo=bc+108|0;c[bo>>2]=0;bp=bc+100|0;c[bp>>2]=0;bq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[bq&16383](bc,6)|0;do{if((c[bo>>2]|0)!=0){bq=c[bp>>2]|0;c[bd>>2]=9534384;br=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[br&16383](bd,6,0)|0;if((bq|0)<1){bn=1;i=e;return bn|0}if((gzL(bi,0,6)|0)==0){break}else{bn=1}i=e;return bn|0}}while(0);bi=(c[2386662]|0)+131072|0;if((c[3542200]|0)==0){bn=1;i=e;return bn|0}bp=ba+108|0;c[bp>>2]=0;bo=ba+100|0;c[bo>>2]=0;bq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[bq&16383](ba,7)|0;do{if((c[bp>>2]|0)!=0){bq=c[bo>>2]|0;c[bb>>2]=9534384;br=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[br&16383](bb,7,0)|0;if((bq|0)<1){bn=1;i=e;return bn|0}if((gzL(bi,0,7)|0)==0){break}else{bn=1}i=e;return bn|0}}while(0);bi=(c[2386662]|0)+196608|0;if((c[3542200]|0)==0){bn=1;i=e;return bn|0}bo=a8+108|0;c[bo>>2]=0;bp=a8+100|0;c[bp>>2]=0;bq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[bq&16383](a8,8)|0;do{if((c[bo>>2]|0)!=0){bq=c[bp>>2]|0;c[a9>>2]=9534384;br=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[br&16383](a9,8,0)|0;if((bq|0)<1){bn=1;i=e;return bn|0}if((gzL(bi,0,8)|0)==0){break}else{bn=1}i=e;return bn|0}}while(0);bi=c[3530868]|0;if((c[3542200]|0)==0){bn=1;i=e;return bn|0}bp=a6+108|0;c[bp>>2]=0;bo=a6+100|0;c[bo>>2]=0;bq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[bq&16383](a6,9)|0;do{if((c[bp>>2]|0)!=0){bq=c[bo>>2]|0;c[a7>>2]=9534384;br=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[br&16383](a7,9,0)|0;if((bq|0)<1){bn=1;i=e;return bn|0}if((gzL(bi,0,9)|0)==0){break}else{bn=1}i=e;return bn|0}}while(0);bi=(c[3530868]|0)+65536|0;if((c[3542200]|0)==0){bn=1;i=e;return bn|0}bo=a4+108|0;c[bo>>2]=0;bp=a4+100|0;c[bp>>2]=0;bq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[bq&16383](a4,10)|0;do{if((c[bo>>2]|0)!=0){bq=c[bp>>2]|0;c[a5>>2]=9534384;br=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[br&16383](a5,10,0)|0;if((bq|0)<1){bn=1;i=e;return bn|0}if((gzL(bi,0,10)|0)==0){break}else{bn=1}i=e;return bn|0}}while(0);bi=c[3530632]|0;if((c[3542200]|0)==0){bn=1;i=e;return bn|0}bp=a2+108|0;c[bp>>2]=0;bo=a2+100|0;c[bo>>2]=0;bq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[bq&16383](a2,11)|0;do{if((c[bp>>2]|0)!=0){bq=c[bo>>2]|0;c[a3>>2]=9534384;br=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[br&16383](a3,11,0)|0;if((bq|0)<1){bn=1;i=e;return bn|0}if((gzL(bi,0,11)|0)==0){break}else{bn=1}i=e;return bn|0}}while(0);bi=(c[3530632]|0)+65536|0;if((c[3542200]|0)==0){bn=1;i=e;return bn|0}bo=a0+108|0;c[bo>>2]=0;bp=a0+100|0;c[bp>>2]=0;bq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[bq&16383](a0,12)|0;do{if((c[bo>>2]|0)!=0){bq=c[bp>>2]|0;c[a1>>2]=9534384;br=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[br&16383](a1,12,0)|0;if((bq|0)<1){bn=1;i=e;return bn|0}if((gzL(bi,0,12)|0)==0){break}else{bn=1}i=e;return bn|0}}while(0);bi=(c[3530632]|0)+131072|0;if((c[3542200]|0)==0){bn=1;i=e;return bn|0}bp=a_+108|0;c[bp>>2]=0;bo=a_+100|0;c[bo>>2]=0;bq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[bq&16383](a_,13)|0;do{if((c[bp>>2]|0)!=0){bq=c[bo>>2]|0;c[a$>>2]=9534384;br=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[br&16383](a$,13,0)|0;if((bq|0)<1){bn=1;i=e;return bn|0}if((gzL(bi,0,13)|0)==0){break}else{bn=1}i=e;return bn|0}}while(0);bi=(c[3530632]|0)+196608|0;if((c[3542200]|0)==0){bn=1;i=e;return bn|0}bo=aY+108|0;c[bo>>2]=0;bp=aY+100|0;c[bp>>2]=0;bq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[bq&16383](aY,14)|0;do{if((c[bo>>2]|0)!=0){bq=c[bp>>2]|0;c[aZ>>2]=9534384;br=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[br&16383](aZ,14,0)|0;if((bq|0)<1){bn=1;i=e;return bn|0}if((gzL(bi,0,14)|0)==0){break}else{bn=1}i=e;return bn|0}}while(0);bi=(c[3530632]|0)+262144|0;if((c[3542200]|0)==0){bn=1;i=e;return bn|0}bp=aW+108|0;c[bp>>2]=0;bo=aW+100|0;c[bo>>2]=0;bq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[bq&16383](aW,15)|0;do{if((c[bp>>2]|0)!=0){bq=c[bo>>2]|0;c[aX>>2]=9534384;br=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[br&16383](aX,15,0)|0;if((bq|0)<1){bn=1;i=e;return bn|0}if((gzL(bi,0,15)|0)==0){break}else{bn=1}i=e;return bn|0}}while(0);bi=(c[3530632]|0)+327680|0;if((c[3542200]|0)==0){bn=1;i=e;return bn|0}bo=aU+108|0;c[bo>>2]=0;bp=aU+100|0;c[bp>>2]=0;bq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[bq&16383](aU,16)|0;do{if((c[bo>>2]|0)!=0){bq=c[bp>>2]|0;c[aV>>2]=9534384;br=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[br&16383](aV,16,0)|0;if((bq|0)<1){bn=1;i=e;return bn|0}if((gzL(bi,0,16)|0)==0){break}else{bn=1}i=e;return bn|0}}while(0);bi=(c[3530632]|0)+393216|0;if((c[3542200]|0)==0){bn=1;i=e;return bn|0}bp=aS+108|0;c[bp>>2]=0;bo=aS+100|0;c[bo>>2]=0;bq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[bq&16383](aS,17)|0;do{if((c[bp>>2]|0)!=0){bq=c[bo>>2]|0;c[aT>>2]=9534384;br=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[br&16383](aT,17,0)|0;if((bq|0)<1){bn=1;i=e;return bn|0}if((gzL(bi,0,17)|0)==0){break}else{bn=1}i=e;return bn|0}}while(0);bi=(c[3530632]|0)+458752|0;if((c[3542200]|0)==0){bn=1;i=e;return bn|0}bo=aQ+108|0;c[bo>>2]=0;bp=aQ+100|0;c[bp>>2]=0;bq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[bq&16383](aQ,18)|0;do{if((c[bo>>2]|0)!=0){bq=c[bp>>2]|0;c[aR>>2]=9534384;br=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[br&16383](aR,18,0)|0;if((bq|0)<1){bn=1;i=e;return bn|0}if((gzL(bi,0,18)|0)==0){break}else{bn=1}i=e;return bn|0}}while(0);bi=(c[3530632]|0)+524288|0;if((c[3542200]|0)==0){bn=1;i=e;return bn|0}bp=aO+108|0;c[bp>>2]=0;bo=aO+100|0;c[bo>>2]=0;bq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[bq&16383](aO,19)|0;do{if((c[bp>>2]|0)!=0){bq=c[bo>>2]|0;c[aP>>2]=9534384;br=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[br&16383](aP,19,0)|0;if((bq|0)<1){bn=1;i=e;return bn|0}if((gzL(bi,0,19)|0)==0){break}else{bn=1}i=e;return bn|0}}while(0);bi=(c[3530632]|0)+589824|0;if((c[3542200]|0)==0){bn=1;i=e;return bn|0}bo=aM+108|0;c[bo>>2]=0;bp=aM+100|0;c[bp>>2]=0;bq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[bq&16383](aM,20)|0;do{if((c[bo>>2]|0)!=0){bq=c[bp>>2]|0;c[aN>>2]=9534384;br=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[br&16383](aN,20,0)|0;if((bq|0)<1){bn=1;i=e;return bn|0}if((gzL(bi,0,20)|0)==0){break}else{bn=1}i=e;return bn|0}}while(0);bi=(c[3530632]|0)+655360|0;if((c[3542200]|0)==0){bn=1;i=e;return bn|0}bp=aK+108|0;c[bp>>2]=0;bo=aK+100|0;c[bo>>2]=0;bq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[bq&16383](aK,21)|0;do{if((c[bp>>2]|0)!=0){bq=c[bo>>2]|0;c[aL>>2]=9534384;br=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[br&16383](aL,21,0)|0;if((bq|0)<1){bn=1;i=e;return bn|0}if((gzL(bi,0,21)|0)==0){break}else{bn=1}i=e;return bn|0}}while(0);bi=(c[3530632]|0)+720896|0;if((c[3542200]|0)==0){bn=1;i=e;return bn|0}bo=aI+108|0;c[bo>>2]=0;bp=aI+100|0;c[bp>>2]=0;bq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[bq&16383](aI,22)|0;do{if((c[bo>>2]|0)!=0){bq=c[bp>>2]|0;c[aJ>>2]=9534384;br=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[br&16383](aJ,22,0)|0;if((bq|0)<1){bn=1;i=e;return bn|0}if((gzL(bi,0,22)|0)==0){break}else{bn=1}i=e;return bn|0}}while(0);bi=(c[3530632]|0)+786432|0;if((c[3542200]|0)==0){bn=1;i=e;return bn|0}bp=aG+108|0;c[bp>>2]=0;bo=aG+100|0;c[bo>>2]=0;bq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[bq&16383](aG,23)|0;do{if((c[bp>>2]|0)!=0){bq=c[bo>>2]|0;c[aH>>2]=9534384;br=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[br&16383](aH,23,0)|0;if((bq|0)<1){bn=1;i=e;return bn|0}if((gzL(bi,0,23)|0)==0){break}else{bn=1}i=e;return bn|0}}while(0);bi=(c[3530632]|0)+851968|0;if((c[3542200]|0)==0){bn=1;i=e;return bn|0}bo=aE+108|0;c[bo>>2]=0;bp=aE+100|0;c[bp>>2]=0;bq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[bq&16383](aE,24)|0;do{if((c[bo>>2]|0)!=0){bq=c[bp>>2]|0;c[aF>>2]=9534384;br=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[br&16383](aF,24,0)|0;if((bq|0)<1){bn=1;i=e;return bn|0}if((gzL(bi,0,24)|0)==0){break}else{bn=1}i=e;return bn|0}}while(0);bi=(c[3530632]|0)+917504|0;if((c[3542200]|0)==0){bn=1;i=e;return bn|0}bp=aC+108|0;c[bp>>2]=0;bo=aC+100|0;c[bo>>2]=0;bq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[bq&16383](aC,25)|0;do{if((c[bp>>2]|0)!=0){bq=c[bo>>2]|0;c[aD>>2]=9534384;br=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[br&16383](aD,25,0)|0;if((bq|0)<1){bn=1;i=e;return bn|0}if((gzL(bi,0,25)|0)==0){break}else{bn=1}i=e;return bn|0}}while(0);bi=(c[3530632]|0)+983040|0;if((c[3542200]|0)==0){bn=1;i=e;return bn|0}bo=aA+108|0;c[bo>>2]=0;bp=aA+100|0;c[bp>>2]=0;bq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[bq&16383](aA,26)|0;do{if((c[bo>>2]|0)!=0){bq=c[bp>>2]|0;c[aB>>2]=9534384;br=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[br&16383](aB,26,0)|0;if((bq|0)<1){bn=1;i=e;return bn|0}if((gzL(bi,0,26)|0)==0){break}else{bn=1}i=e;return bn|0}}while(0);bi=(c[3530632]|0)+1048576|0;if((c[3542200]|0)==0){bn=1;i=e;return bn|0}bp=ay+108|0;c[bp>>2]=0;bo=ay+100|0;c[bo>>2]=0;bq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[bq&16383](ay,27)|0;do{if((c[bp>>2]|0)!=0){bq=c[bo>>2]|0;c[az>>2]=9534384;br=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[br&16383](az,27,0)|0;if((bq|0)<1){bn=1;i=e;return bn|0}if((gzL(bi,0,27)|0)==0){break}else{bn=1}i=e;return bn|0}}while(0);bi=(c[3530632]|0)+1114112|0;if((c[3542200]|0)==0){bn=1;i=e;return bn|0}bo=aw+108|0;c[bo>>2]=0;bp=aw+100|0;c[bp>>2]=0;bq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[bq&16383](aw,28)|0;do{if((c[bo>>2]|0)!=0){bq=c[bp>>2]|0;c[ax>>2]=9534384;br=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[br&16383](ax,28,0)|0;if((bq|0)<1){bn=1;i=e;return bn|0}if((gzL(bi,0,28)|0)==0){break}else{bn=1}i=e;return bn|0}}while(0);bi=(c[3530632]|0)+1179648|0;if((c[3542200]|0)==0){bn=1;i=e;return bn|0}bp=au+108|0;c[bp>>2]=0;bo=au+100|0;c[bo>>2]=0;bq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[bq&16383](au,29)|0;do{if((c[bp>>2]|0)!=0){bq=c[bo>>2]|0;c[av>>2]=9534384;br=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[br&16383](av,29,0)|0;if((bq|0)<1){bn=1;i=e;return bn|0}if((gzL(bi,0,29)|0)==0){break}else{bn=1}i=e;return bn|0}}while(0);bi=(c[3530632]|0)+1245184|0;if((c[3542200]|0)==0){bn=1;i=e;return bn|0}bo=as+108|0;c[bo>>2]=0;bp=as+100|0;c[bp>>2]=0;bq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[bq&16383](as,30)|0;do{if((c[bo>>2]|0)!=0){bq=c[bp>>2]|0;c[at>>2]=9534384;br=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[br&16383](at,30,0)|0;if((bq|0)<1){bn=1;i=e;return bn|0}if((gzL(bi,0,30)|0)==0){break}else{bn=1}i=e;return bn|0}}while(0);bi=(c[3530632]|0)+1310720|0;if((c[3542200]|0)==0){bn=1;i=e;return bn|0}bp=aq+108|0;c[bp>>2]=0;bo=aq+100|0;c[bo>>2]=0;bq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[bq&16383](aq,31)|0;do{if((c[bp>>2]|0)!=0){bq=c[bo>>2]|0;c[ar>>2]=9534384;br=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[br&16383](ar,31,0)|0;if((bq|0)<1){bn=1;i=e;return bn|0}if((gzL(bi,0,31)|0)==0){break}else{bn=1}i=e;return bn|0}}while(0);bi=(c[3530632]|0)+1376256|0;if((c[3542200]|0)==0){bn=1;i=e;return bn|0}bo=ao+108|0;c[bo>>2]=0;bp=ao+100|0;c[bp>>2]=0;bq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[bq&16383](ao,32)|0;do{if((c[bo>>2]|0)!=0){bq=c[bp>>2]|0;c[ap>>2]=9534384;br=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[br&16383](ap,32,0)|0;if((bq|0)<1){bn=1;i=e;return bn|0}if((gzL(bi,0,32)|0)==0){break}else{bn=1}i=e;return bn|0}}while(0);bi=(c[3530632]|0)+1441792|0;if((c[3542200]|0)==0){bn=1;i=e;return bn|0}bp=am+108|0;c[bp>>2]=0;bo=am+100|0;c[bo>>2]=0;bq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[bq&16383](am,33)|0;do{if((c[bp>>2]|0)!=0){bq=c[bo>>2]|0;c[an>>2]=9534384;br=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[br&16383](an,33,0)|0;if((bq|0)<1){bn=1;i=e;return bn|0}if((gzL(bi,0,33)|0)==0){break}else{bn=1}i=e;return bn|0}}while(0);bi=(c[3530632]|0)+1507328|0;if((c[3542200]|0)==0){bn=1;i=e;return bn|0}bo=ak+108|0;c[bo>>2]=0;bp=ak+100|0;c[bp>>2]=0;bq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[bq&16383](ak,34)|0;do{if((c[bo>>2]|0)!=0){bq=c[bp>>2]|0;c[al>>2]=9534384;br=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[br&16383](al,34,0)|0;if((bq|0)<1){bn=1;i=e;return bn|0}if((gzL(bi,0,34)|0)==0){break}else{bn=1}i=e;return bn|0}}while(0);bi=(c[3530632]|0)+1572864|0;if((c[3542200]|0)==0){bn=1;i=e;return bn|0}bp=ai+108|0;c[bp>>2]=0;bo=ai+100|0;c[bo>>2]=0;bq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[bq&16383](ai,35)|0;do{if((c[bp>>2]|0)!=0){bq=c[bo>>2]|0;c[aj>>2]=9534384;br=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[br&16383](aj,35,0)|0;if((bq|0)<1){bn=1;i=e;return bn|0}if((gzL(bi,0,35)|0)==0){break}else{bn=1}i=e;return bn|0}}while(0);bi=(c[3530632]|0)+1638400|0;if((c[3542200]|0)==0){bn=1;i=e;return bn|0}bo=af+108|0;c[bo>>2]=0;bp=af+100|0;c[bp>>2]=0;bq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[bq&16383](af,36)|0;do{if((c[bo>>2]|0)!=0){bq=c[bp>>2]|0;c[ah>>2]=9534384;br=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[br&16383](ah,36,0)|0;if((bq|0)<1){bn=1;i=e;return bn|0}if((gzL(bi,0,36)|0)==0){break}else{bn=1}i=e;return bn|0}}while(0);bi=(c[3530632]|0)+1703936|0;if((c[3542200]|0)==0){bn=1;i=e;return bn|0}bp=ad+108|0;c[bp>>2]=0;bo=ad+100|0;c[bo>>2]=0;bq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[bq&16383](ad,37)|0;do{if((c[bp>>2]|0)!=0){bq=c[bo>>2]|0;c[ae>>2]=9534384;br=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[br&16383](ae,37,0)|0;if((bq|0)<1){bn=1;i=e;return bn|0}if((gzL(bi,0,37)|0)==0){break}else{bn=1}i=e;return bn|0}}while(0);bi=(c[3530632]|0)+1769472|0;if((c[3542200]|0)==0){bn=1;i=e;return bn|0}bo=ab+108|0;c[bo>>2]=0;bp=ab+100|0;c[bp>>2]=0;bq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[bq&16383](ab,38)|0;do{if((c[bo>>2]|0)!=0){bq=c[bp>>2]|0;c[ac>>2]=9534384;br=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[br&16383](ac,38,0)|0;if((bq|0)<1){bn=1;i=e;return bn|0}if((gzL(bi,0,38)|0)==0){break}else{bn=1}i=e;return bn|0}}while(0);bi=(c[3530632]|0)+1835008|0;if((c[3542200]|0)==0){bn=1;i=e;return bn|0}bp=$+108|0;c[bp>>2]=0;bo=$+100|0;c[bo>>2]=0;bq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[bq&16383]($,39)|0;do{if((c[bp>>2]|0)!=0){bq=c[bo>>2]|0;c[aa>>2]=9534384;br=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[br&16383](aa,39,0)|0;if((bq|0)<1){bn=1;i=e;return bn|0}if((gzL(bi,0,39)|0)==0){break}else{bn=1}i=e;return bn|0}}while(0);bi=(c[3530632]|0)+1900544|0;if((c[3542200]|0)==0){bn=1;i=e;return bn|0}bo=Z+108|0;c[bo>>2]=0;bp=Z+100|0;c[bp>>2]=0;bq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[bq&16383](Z,40)|0;do{if((c[bo>>2]|0)!=0){bq=c[bp>>2]|0;c[_>>2]=9534384;br=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[br&16383](_,40,0)|0;if((bq|0)<1){bn=1;i=e;return bn|0}if((gzL(bi,0,40)|0)==0){break}else{bn=1}i=e;return bn|0}}while(0);bi=(c[3530632]|0)+1966080|0;if((c[3542200]|0)==0){bn=1;i=e;return bn|0}bp=X+108|0;c[bp>>2]=0;bo=X+100|0;c[bo>>2]=0;bq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[bq&16383](X,41)|0;do{if((c[bp>>2]|0)!=0){bq=c[bo>>2]|0;c[Y>>2]=9534384;br=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[br&16383](Y,41,0)|0;if((bq|0)<1){bn=1;i=e;return bn|0}if((gzL(bi,0,41)|0)==0){break}else{bn=1}i=e;return bn|0}}while(0);bi=(c[3530632]|0)+2031616|0;if((c[3542200]|0)==0){bn=1;i=e;return bn|0}bo=V+108|0;c[bo>>2]=0;bp=V+100|0;c[bp>>2]=0;bq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[bq&16383](V,42)|0;do{if((c[bo>>2]|0)!=0){bq=c[bp>>2]|0;c[W>>2]=9534384;br=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[br&16383](W,42,0)|0;if((bq|0)<1){bn=1;i=e;return bn|0}if((gzL(bi,0,42)|0)==0){break}else{bn=1}i=e;return bn|0}}while(0);bi=c[3530442]|0;if((c[3542200]|0)==0){bn=1;i=e;return bn|0}bp=T+108|0;c[bp>>2]=0;bo=T+100|0;c[bo>>2]=0;bq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[bq&16383](T,43)|0;do{if((c[bp>>2]|0)!=0){bq=c[bo>>2]|0;c[U>>2]=9534384;br=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[br&16383](U,43,0)|0;if((bq|0)<1){bn=1;i=e;return bn|0}if((gzL(bi,0,43)|0)==0){break}else{bn=1}i=e;return bn|0}}while(0);bi=(c[3530442]|0)+65536|0;if((c[3542200]|0)==0){bn=1;i=e;return bn|0}bo=R+108|0;c[bo>>2]=0;bp=R+100|0;c[bp>>2]=0;bq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[bq&16383](R,44)|0;do{if((c[bo>>2]|0)!=0){bq=c[bp>>2]|0;c[S>>2]=9534384;br=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[br&16383](S,44,0)|0;if((bq|0)<1){bn=1;i=e;return bn|0}if((gzL(bi,0,44)|0)==0){break}else{bn=1}i=e;return bn|0}}while(0);bi=(c[3530442]|0)+131072|0;if((c[3542200]|0)==0){bn=1;i=e;return bn|0}bp=P+108|0;c[bp>>2]=0;bo=P+100|0;c[bo>>2]=0;bq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[bq&16383](P,45)|0;do{if((c[bp>>2]|0)!=0){bq=c[bo>>2]|0;c[Q>>2]=9534384;br=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[br&16383](Q,45,0)|0;if((bq|0)<1){bn=1;i=e;return bn|0}if((gzL(bi,0,45)|0)==0){break}else{bn=1}i=e;return bn|0}}while(0);bi=(c[3530442]|0)+196608|0;if((c[3542200]|0)==0){bn=1;i=e;return bn|0}bo=N+108|0;c[bo>>2]=0;bp=N+100|0;c[bp>>2]=0;bq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[bq&16383](N,46)|0;do{if((c[bo>>2]|0)!=0){bq=c[bp>>2]|0;c[O>>2]=9534384;br=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[br&16383](O,46,0)|0;if((bq|0)<1){bn=1;i=e;return bn|0}if((gzL(bi,0,46)|0)==0){break}else{bn=1}i=e;return bn|0}}while(0);bi=(c[3530442]|0)+262144|0;if((c[3542200]|0)==0){bn=1;i=e;return bn|0}bp=L+108|0;c[bp>>2]=0;bo=L+100|0;c[bo>>2]=0;bq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[bq&16383](L,47)|0;do{if((c[bp>>2]|0)!=0){bq=c[bo>>2]|0;c[M>>2]=9534384;br=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[br&16383](M,47,0)|0;if((bq|0)<1){bn=1;i=e;return bn|0}if((gzL(bi,0,47)|0)==0){break}else{bn=1}i=e;return bn|0}}while(0);bi=(c[3530442]|0)+327680|0;if((c[3542200]|0)==0){bn=1;i=e;return bn|0}bo=J+108|0;c[bo>>2]=0;bp=J+100|0;c[bp>>2]=0;bq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[bq&16383](J,48)|0;do{if((c[bo>>2]|0)!=0){bq=c[bp>>2]|0;c[K>>2]=9534384;br=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[br&16383](K,48,0)|0;if((bq|0)<1){bn=1;i=e;return bn|0}if((gzL(bi,0,48)|0)==0){break}else{bn=1}i=e;return bn|0}}while(0);bi=(c[3530442]|0)+393216|0;if((c[3542200]|0)==0){bn=1;i=e;return bn|0}bp=H+108|0;c[bp>>2]=0;bo=H+100|0;c[bo>>2]=0;bq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[bq&16383](H,49)|0;do{if((c[bp>>2]|0)!=0){bq=c[bo>>2]|0;c[I>>2]=9534384;br=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[br&16383](I,49,0)|0;if((bq|0)<1){bn=1;i=e;return bn|0}if((gzL(bi,0,49)|0)==0){break}else{bn=1}i=e;return bn|0}}while(0);bi=(c[3530442]|0)+458752|0;if((c[3542200]|0)==0){bn=1;i=e;return bn|0}bo=F+108|0;c[bo>>2]=0;bp=F+100|0;c[bp>>2]=0;bq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[bq&16383](F,50)|0;if((c[bo>>2]|0)==0){bs=0;break}bo=c[bp>>2]|0;c[G>>2]=9534384;bp=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[bp&16383](G,50,0)|0;if((bo|0)<1){bn=1;i=e;return bn|0}if((gzL(bi,0,50)|0)==0){bs=0;break}else{bn=1}i=e;return bn|0}else{if(bm){bn=1;i=e;return bn|0}if((R6(c[2388172]|0,1,2)|0)!=0){bn=1;i=e;return bn|0}bi=c[2385938]|0;if((c[3542200]|0)==0){bn=1;i=e;return bn|0}bo=D+108|0;c[bo>>2]=0;bp=D+100|0;c[bp>>2]=0;bq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[bq&16383](D,2)|0;do{if((c[bo>>2]|0)!=0){bq=c[bp>>2]|0;c[E>>2]=9534384;br=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[br&16383](E,2,0)|0;if((bq|0)<1){bn=1;i=e;return bn|0}if((gzL(bi,0,2)|0)==0){break}else{bn=1}i=e;return bn|0}}while(0);bi=c[2386662]|0;if((c[3542200]|0)==0){bn=1;i=e;return bn|0}bp=B+108|0;c[bp>>2]=0;bo=B+100|0;c[bo>>2]=0;bq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[bq&16383](B,3)|0;do{if((c[bp>>2]|0)!=0){bq=c[bo>>2]|0;c[C>>2]=9534384;br=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[br&16383](C,3,0)|0;if((bq|0)<1){bn=1;i=e;return bn|0}if((gzL(bi,0,3)|0)==0){break}else{bn=1}i=e;return bn|0}}while(0);bi=(c[2386662]|0)+131072|0;if((c[3542200]|0)==0){bn=1;i=e;return bn|0}bo=z+108|0;c[bo>>2]=0;bp=z+100|0;c[bp>>2]=0;bq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[bq&16383](z,4)|0;do{if((c[bo>>2]|0)!=0){bq=c[bp>>2]|0;c[A>>2]=9534384;br=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[br&16383](A,4,0)|0;if((bq|0)<1){bn=1;i=e;return bn|0}if((gzL(bi,0,4)|0)==0){break}else{bn=1}i=e;return bn|0}}while(0);bi=c[3530868]|0;if((c[3542200]|0)==0){bn=1;i=e;return bn|0}bp=x+108|0;c[bp>>2]=0;bo=x+100|0;c[bo>>2]=0;bq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[bq&16383](x,5)|0;do{if((c[bp>>2]|0)!=0){bq=c[bo>>2]|0;c[y>>2]=9534384;br=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[br&16383](y,5,0)|0;if((bq|0)<1){bn=1;i=e;return bn|0}if((gzL(bi,0,5)|0)==0){break}else{bn=1}i=e;return bn|0}}while(0);bi=c[3530632]|0;if((c[3542200]|0)==0){bn=1;i=e;return bn|0}bo=v+108|0;c[bo>>2]=0;bp=v+100|0;c[bp>>2]=0;bq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[bq&16383](v,6)|0;do{if((c[bo>>2]|0)!=0){bq=c[bp>>2]|0;c[w>>2]=9534384;br=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[br&16383](w,6,0)|0;if((bq|0)<1){bn=1;i=e;return bn|0}if((gzL(bi,0,6)|0)==0){break}else{bn=1}i=e;return bn|0}}while(0);bi=(c[3530632]|0)+524288|0;if((c[3542200]|0)==0){bn=1;i=e;return bn|0}bp=t+108|0;c[bp>>2]=0;bo=t+100|0;c[bo>>2]=0;bq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[bq&16383](t,7)|0;do{if((c[bp>>2]|0)!=0){bq=c[bo>>2]|0;c[u>>2]=9534384;br=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[br&16383](u,7,0)|0;if((bq|0)<1){bn=1;i=e;return bn|0}if((gzL(bi,0,7)|0)==0){break}else{bn=1}i=e;return bn|0}}while(0);bi=(c[3530632]|0)+786432|0;if((c[3542200]|0)==0){bn=1;i=e;return bn|0}bo=r+108|0;c[bo>>2]=0;bp=r+100|0;c[bp>>2]=0;bq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[bq&16383](r,8)|0;do{if((c[bo>>2]|0)!=0){bq=c[bp>>2]|0;c[s>>2]=9534384;br=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[br&16383](s,8,0)|0;if((bq|0)<1){bn=1;i=e;return bn|0}if((gzL(bi,0,8)|0)==0){break}else{bn=1}i=e;return bn|0}}while(0);bi=(c[3530632]|0)+1048576|0;if((c[3542200]|0)==0){bn=1;i=e;return bn|0}bp=p+108|0;c[bp>>2]=0;bo=p+100|0;c[bo>>2]=0;bq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[bq&16383](p,9)|0;do{if((c[bp>>2]|0)!=0){bq=c[bo>>2]|0;c[q>>2]=9534384;br=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[br&16383](q,9,0)|0;if((bq|0)<1){bn=1;i=e;return bn|0}if((gzL(bi,0,9)|0)==0){break}else{bn=1}i=e;return bn|0}}while(0);bi=(c[3530632]|0)+1572864|0;if((c[3542200]|0)==0){bn=1;i=e;return bn|0}bo=n+108|0;c[bo>>2]=0;bp=n+100|0;c[bp>>2]=0;bq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[bq&16383](n,10)|0;do{if((c[bo>>2]|0)!=0){bq=c[bp>>2]|0;c[o>>2]=9534384;br=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[br&16383](o,10,0)|0;if((bq|0)<1){bn=1;i=e;return bn|0}if((gzL(bi,0,10)|0)==0){break}else{bn=1}i=e;return bn|0}}while(0);bi=(c[3530632]|0)+1835008|0;if((c[3542200]|0)==0){bn=1;i=e;return bn|0}bp=l+108|0;c[bp>>2]=0;bo=l+100|0;c[bo>>2]=0;bq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[bq&16383](l,11)|0;do{if((c[bp>>2]|0)!=0){bq=c[bo>>2]|0;c[m>>2]=9534384;br=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[br&16383](m,11,0)|0;if((bq|0)<1){bn=1;i=e;return bn|0}if((gzL(bi,0,11)|0)==0){break}else{bn=1}i=e;return bn|0}}while(0);bi=c[3530442]|0;if((c[3542200]|0)==0){bn=1;i=e;return bn|0}bo=j+108|0;c[bo>>2]=0;bp=j+100|0;c[bp>>2]=0;bq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[bq&16383](j,12)|0;do{if((c[bo>>2]|0)!=0){bq=c[bp>>2]|0;c[k>>2]=9534384;br=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[br&16383](k,12,0)|0;if((bq|0)<1){bn=1;i=e;return bn|0}if((gzL(bi,0,12)|0)==0){break}else{bn=1}i=e;return bn|0}}while(0);bi=(c[3530442]|0)+262144|0;if((c[3542200]|0)==0){bn=1;i=e;return bn|0}bp=f+108|0;c[bp>>2]=0;bo=f+100|0;c[bo>>2]=0;bq=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[bq&16383](f,13)|0;if((c[bp>>2]|0)==0){bs=0;break}bp=c[bo>>2]|0;c[g>>2]=9534384;bo=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[bo&16383](g,13,0)|0;if((bp|0)<1){bn=1;i=e;return bn|0}if((gzL(bi,0,13)|0)==0){bs=0;break}else{bn=1}i=e;return bn|0}}while(0);while(1){if((bs|0)>=1024){break}bt=9638528+(bs<<2)|0;if((c[bt>>2]|0)==0){bk=14253;break}else{bs=bs+1|0}}L18966:do{if((bk|0)==14253){bm=gGq(2097152)|0;c[bt>>2]=bm;if((bm|0)==0){break}gGz(bm|0,0,2097152);bl=c[3530868]|0;gGC(bm|0,bl|0,131072)|0;bi=0;do{bp=bi<<6;gGz(bl+bp|0,0,64);bo=bi<<8;bq=0;do{br=1<<3-bq;bu=(c[1983672+(bq<<2)>>2]|0)+bo|0;bv=0;do{bw=bu+(c[609008+(bv<<2)>>2]|0)|0;bx=(bv<<3)+bp|0;by=0;do{bz=bw+(c[6964280+(by<<2)>>2]|0)|0;if(((d[bm+((bz|0)/8|0)|0]|0)&128>>>((bz&7)>>>0)|0)!=0){bz=bl+(bx+by)|0;a[bz]=(d[bz]|0|br)&255}by=by+1|0;}while((by|0)<8);bv=bv+1|0;}while((bv|0)<8);bq=bq+1|0;}while((bq|0)<4);bi=bi+1|0;}while((bi|0)<4096);bi=c[3530632]|0;gGC(bm|0,bi|0,2097152)|0;bl=0;do{bq=bl<<8;gGz(bi+bq|0,0,256);bp=bl<<9;bo=0;do{bv=1<<3-bo;br=(c[611344+(bo<<2)>>2]|0)+bp|0;bu=0;do{by=br+(c[609008+(bu<<2)>>2]|0)|0;bx=(bu<<4)+bq|0;bw=0;do{bz=by+(c[610128+(bw<<2)>>2]|0)|0;if(((d[bm+((bz|0)/8|0)|0]|0)&128>>>((bz&7)>>>0)|0)!=0){bz=bi+(bx+bw)|0;a[bz]=(d[bz]|0|bv)&255}bw=bw+1|0;}while((bw|0)<16);bu=bu+1|0;}while((bu|0)<16);bo=bo+1|0;}while((bo|0)<4);bl=bl+1|0;}while((bl|0)<16384);bl=c[3530442]|0;gGC(bm|0,bl|0,524288)|0;bi=0;while(1){bo=bi<<8;gGz(bl+bo|0,0,256);bq=bi<<9;bp=0;do{bu=1<<3-bp;bv=(c[611168+(bp<<2)>>2]|0)+bq|0;br=0;do{bw=bv+(c[609008+(br<<2)>>2]|0)|0;bx=(br<<4)+bo|0;by=0;do{bz=bw+(c[610128+(by<<2)>>2]|0)|0;if(((d[bm+((bz|0)/8|0)|0]|0)&128>>>((bz&7)>>>0)|0)!=0){bz=bl+(bx+by)|0;a[bz]=(d[bz]|0|bu)&255}by=by+1|0;}while((by|0)<16);br=br+1|0;}while((br|0)<16);bp=bp+1|0;}while((bp|0)<4);bp=bi+1|0;if((bp|0)<4096){bi=bp}else{bA=0;break}}while(1){if((bA|0)>=1024){break L18966}bB=9638528+(bA<<2)|0;if((c[bB>>2]|0)==(bm|0)){break}else{bA=bA+1|0}}gGr(bm);c[bB>>2]=0}}while(0);fxU(0,425984);if((c[2394]|0)==0){bC=c[2112932]|0}else{c[2394]=0;bi=c[3532596]|0;c[2112932]=bi;bl=c[3532592]|0;if((bl|0)!=0){gGC(9104152,bl|0,280)|0}c[2113054]=c[2113060];bC=bi}bi=c[2388172]|0;bl=bC|0;bp=0;while(1){bo=bi+bp|0;c[bl>>2]=bo;c[bl+131072>>2]=bo;bo=bp+1024|0;if(bo>>>0>262143){break}else{bl=bl+4|0;bp=bo}}bp=c[2406496]|0;c[bC+2048>>2]=bp;c[bC+67584>>2]=bp;c[bC+133120>>2]=bp;bl=bp+1024|0;c[bC+2052>>2]=bl;c[bC+67588>>2]=bl;c[bC+133124>>2]=bl;bl=bp+2048|0;c[bC+2056>>2]=bl;c[bC+67592>>2]=bl;c[bC+133128>>2]=bl;bl=bp+3072|0;c[bC+2060>>2]=bl;c[bC+67596>>2]=bl;c[bC+133132>>2]=bl;bl=c[2406576]|0;c[bC+3072>>2]=bl;c[bC+68608>>2]=bl;c[bC+134144>>2]=bl;bp=bl+1024|0;c[bC+3076>>2]=bp;c[bC+68612>>2]=bp;c[bC+134148>>2]=bp;bp=bl+2048|0;c[bC+3080>>2]=bp;c[bC+68616>>2]=bp;c[bC+134152>>2]=bp;bp=bl+3072|0;c[bC+3084>>2]=bp;c[bC+68620>>2]=bp;c[bC+134156>>2]=bp;bp=c[2386480]|0;c[bC+4096>>2]=bp;c[bC+69632>>2]=bp;c[bC+135168>>2]=bp;bp=c[2387222]|0;c[bC+5120>>2]=bp;c[bC+70656>>2]=bp;c[bC+136192>>2]=bp;bl=bp+1024|0;c[bC+5124>>2]=bl;c[bC+70660>>2]=bl;c[bC+136196>>2]=bl;bl=bp+2048|0;c[bC+5128>>2]=bl;c[bC+70664>>2]=bl;c[bC+136200>>2]=bl;bl=bp+3072|0;c[bC+5132>>2]=bl;c[bC+70668>>2]=bl;c[bC+136204>>2]=bl;bl=c[2388294]|0;c[bC+7168>>2]=bl;c[bC+72704>>2]=bl;c[bC+138240>>2]=bl;bp=bl+1024|0;c[bC+7172>>2]=bp;c[bC+72708>>2]=bp;c[bC+138244>>2]=bp;bp=bl+2048|0;c[bC+7176>>2]=bp;c[bC+72712>>2]=bp;c[bC+138248>>2]=bp;bp=bl+3072|0;c[bC+7180>>2]=bp;c[bC+72716>>2]=bp;c[bC+138252>>2]=bp;bp=bl+4096|0;c[bC+7184>>2]=bp;c[bC+72720>>2]=bp;c[bC+138256>>2]=bp;bp=bl+5120|0;c[bC+7188>>2]=bp;c[bC+72724>>2]=bp;c[bC+138260>>2]=bp;bp=bl+6144|0;c[bC+7192>>2]=bp;c[bC+72728>>2]=bp;c[bC+138264>>2]=bp;bp=bl+7168|0;c[bC+7196>>2]=bp;c[bC+72732>>2]=bp;c[bC+138268>>2]=bp;bp=bl+8192|0;c[bC+7200>>2]=bp;c[bC+72736>>2]=bp;c[bC+138272>>2]=bp;bp=bl+9216|0;c[bC+7204>>2]=bp;c[bC+72740>>2]=bp;c[bC+138276>>2]=bp;bp=bl+10240|0;c[bC+7208>>2]=bp;c[bC+72744>>2]=bp;c[bC+138280>>2]=bp;bp=bl+11264|0;c[bC+7212>>2]=bp;c[bC+72748>>2]=bp;c[bC+138284>>2]=bp;bp=bl+12288|0;c[bC+7216>>2]=bp;c[bC+72752>>2]=bp;c[bC+138288>>2]=bp;bp=bl+13312|0;c[bC+7220>>2]=bp;c[bC+72756>>2]=bp;c[bC+138292>>2]=bp;bp=bl+14336|0;c[bC+7224>>2]=bp;c[bC+72760>>2]=bp;c[bC+138296>>2]=bp;bp=bl+15360|0;c[bC+7228>>2]=bp;c[bC+72764>>2]=bp;c[bC+138300>>2]=bp;c[bC+196688>>2]=2532;c[bC+196608>>2]=2;c[bC+196728>>2]=3308;c[bC+196648>>2]=2556;bp=c[3532592]|0;if((bp|0)!=0){gGC(bp|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);bp=c[2439330]|0;bl=(bp|0)==0;if(!bl){bi=bp;gGC(9706056,bi|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];bi=c[3528484]|0;c[2076596]=bi;bo=c[2417276]|0;c[3541536]=bo;c[1836236]=0;bq=c[2385938]|0;br=0;bu=0;while(1){c[bp+76+(bu<<2)>>2]=bq+(bu<<8);bv=br+1&65535;if((bv&65535)>127){bD=0;bE=0;break}else{br=bv;bu=bv&65535}}while(1){bu=bq+(bE<<8)|0;c[bp+76+(bE+512<<2)>>2]=bu;c[bp+76+(bE+768<<2)>>2]=bu;bu=bD+1&65535;if((bu&65535)>127){break}else{bD=bu;bE=bu&65535}}bq=c[2386092]|0;c[bp+588>>2]=bq;bu=bq+256|0;c[bp+592>>2]=bu;br=bq+512|0;c[bp+596>>2]=br;bv=bq+768|0;c[bp+600>>2]=bv;by=bq+1024|0;c[bp+604>>2]=by;bx=bq+1280|0;c[bp+608>>2]=bx;bw=bq+1536|0;c[bp+612>>2]=bw;bz=bq+1792|0;c[bp+616>>2]=bz;c[bp+1612>>2]=bq;c[bp+1616>>2]=bu;c[bp+1620>>2]=br;c[bp+1624>>2]=bv;c[bp+1628>>2]=by;c[bp+1632>>2]=bx;c[bp+1636>>2]=bw;c[bp+1640>>2]=bz;c[bp+2636>>2]=bq;c[bp+3660>>2]=bq;c[bp+2640>>2]=bu;c[bp+3664>>2]=bu;c[bp+2644>>2]=br;c[bp+3668>>2]=br;c[bp+2648>>2]=bv;c[bp+3672>>2]=bv;c[bp+2652>>2]=by;c[bp+3676>>2]=by;c[bp+2656>>2]=bx;c[bp+3680>>2]=bx;c[bp+2660>>2]=bw;c[bp+3684>>2]=bw;c[bp+2664>>2]=bz;c[bp+3688>>2]=bz;c[bp+4184>>2]=1896;c[bp+4180>>2]=2244;if(!bl){bz=bp;gGC(bz|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=bi;c[2417276]=bo;c[1836236]=-1;bz=a[9680]|0;bw=bz?32e3:0;if(bz){if(a[9624]|0){bz=bw*3|0;bx=55930;while(1){if((bx|0)>(bz|0)){bx=bx>>1}else{bF=1222;bG=bx;break}}}else{bF=2462;bG=bw}c[2429380]=bG;c[3542124]=bF;mw(3579545,bG);bx=gGq(262144)|0;c[2406684]=bx;gGz(bx|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(3579545,11025)}c[(c[3531464]|0)+44344>>2]=936;h[745421]=.45;c[2436794]=1;h[745420]=.45;c[2436792]=2;Ux(0,8e3,1);c[2407030]=120;c[2407068]=3;bx=c[2414702]|0;gGz(bx|0,0,(c[2411720]|0)-bx|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];bx=c[3532592]|0;if((bx|0)!=0){gGC(9104152,bx|0,280)|0}c[2113054]=c[2113060]}RI();bx=c[2394]|0;bz=c[14130368+(bx<<2)>>2]|0;if((bz|0)!=0){gGC(bz|0,9104152,280)|0}c[8452240+(bx<<2)>>2]=c[2113054];c[2394]=-1;bx=c[2439330]|0;bz=(bx|0)==0;if(!bz){bo=bx;gGC(9706056,bo|0,76)|0}bo=c[2438118]|0;c[2433530]=bo;bi=c[3528484]|0;c[2076596]=bi;bp=c[2417276]|0;c[3541536]=bp;c[1836236]=0;gGz(9706056,0,76);if(!bz){bz=bx;gGC(bz|0,9706056,76)|0}c[2438118]=bo;c[3528484]=bi;c[2417276]=bp;c[1836236]=-1;mx(0);c[2113156]=0;a[9628264]=0;c[2407033]=0;bp=c[3541206]|0;c[3541190]=bp;c[3541198]=bp;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=bp+256;c[3541199]=bp+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=bp+512;c[3541200]=bp+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=bp+768;c[3541201]=bp+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2408982]=1;bp=c[642608+(c[2436]<<2)>>2]|0;bi=c[bp+128>>2]|0;if((c[bp+52>>2]&4|0)==0){c[2113068]=bi;bo=c[bp+132>>2]|0;c[2113070]=bo;c[2443814]=bi;c[2440436]=bo;bH=bi;bI=bo}else{c[2113070]=bi;bo=c[bp+132>>2]|0;c[2113068]=bo;c[2440436]=bi;c[2443814]=bo;bH=bo;bI=bi}bi=ag(bH<<1,bI)|0;bo=gGq(bi)|0;c[2112926]=bo;if((bo|0)==0){bn=0;i=e;return bn|0}gGz(bo|0,0,bi|0);bn=0;i=e;return bn|0}}while(0);c[2414998]=0;bn=1;i=e;return bn|0}function dMI(){var a=0,b=0,d=0,e=0,f=0;c[2113070]=0;c[2113068]=0;a=c[2112926]|0;if((a|0)!=0){gGr(a);c[2112926]=0}if((c[2392]|0)>=0){a=0;do{b=14130368+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}b=14130384+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}a=a+1|0;}while((a|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;fwZ();Uw(0);a=c[3531464]|0;c[a+44344>>2]=0;c[a+44348>>2]=0;if((a|0)!=0){gGr(a);c[3531464]=0}a=c[2406684]|0;if((a|0)!=0){gGr(a);c[2406684]=0}a=c[2414998]|0;b=0;while(1){if((b|0)>=1024){e=14529;break}f=9638528+(b<<2)|0;if((c[f>>2]|0)==(a|0)){break}else{b=b+1|0}}if((e|0)==14529){c[2414998]=0;return 0}gGr(a);c[f>>2]=0;c[2414998]=0;return 0}function dMJ(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if((a[9624424]|0)!=0){e=c[2414702]|0;gGz(e|0,0,(c[2411720]|0)-e|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060]}RI();e=c[2394]|0;f=c[14130368+(e<<2)>>2]|0;if((f|0)!=0){gGC(f|0,9104152,280)|0}c[8452240+(e<<2)>>2]=c[2113054];c[2394]=-1;e=c[2439330]|0;f=(e|0)==0;if(!f){g=e;gGC(9706056,g|0,76)|0}g=c[2438118]|0;c[2433530]=g;h=c[3528484]|0;c[2076596]=h;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);if(!f){f=e;gGC(f|0,9706056,76)|0}c[2438118]=g;c[3528484]=h;c[2417276]=i;c[1836236]=-1;mx(0);c[2113156]=0;a[9628264]=0;c[2407033]=0;i=c[3541206]|0;c[3541190]=i;c[3541198]=i;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=i+256;c[3541199]=i+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=i+512;c[3541200]=i+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=i+768;c[3541201]=i+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2408982]=1}gGz(9550624,-1|0,6);i=0;h=-1;g=-1;f=-1;do{h=(d[9633832+i|0]<<i^h&65535)&65535;g=(d[9631632+i|0]<<i^g&65535)&65535;f=(d[9629648+i|0]<<i^f&65535)&65535;i=i+1|0;}while((i|0)<16);b[4775312]=h;b[4775313]=g;b[4775314]=f;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060]}f=c[2439330]|0;if((f|0)!=0){g=f;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;g=0;f=0;while(1){c[2113056]=651;h=RG(651)|0;c[2113054]=(c[2113054]|0)+h;c[2276108]=-1;c[2113056]=-1;h=g-8|0;do{if(h>>>0<241){if((g|0)==8){c[2408982]=0;j=14556}else if((g|0)==247){c[2408982]=1;break}else{if((h&15|0)==0){j=14556}}do{if((j|0)==14556){j=0;c[8452200+(c[2394]<<2)>>2]=4101;c[2276080]=1280;if((c[2276079]|0)>>>0>=1280){break}RH(5)}}while(0);if((h|0)!=240){break}c[8452200+(c[2394]<<2)>>2]=4102;c[2276080]=1536;if((c[2276079]|0)>>>0>=1536){break}RH(6)}}while(0);if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){h=gfc(233)|0;k=(c[2433530]|0)+h|0}else{k=(c[2433530]|0)+233|0}c[2433530]=k;h=c[2112964]|0;if((h|0)==0){l=f}else{i=a[9688]|0?2:0;e=h+(f<<1<<1)|0;gg[c[3542124]&4095](e,i);Uu(0,e,i);l=i+f|0}i=g+1|0;if((i|0)<256){g=i;f=l}else{break}}f=c[2112964]|0;do{if((f|0)!=0){g=a[9688]|0?534:0;k=g-l|0;j=f+(l<<1<<1)|0;if((g|0)==(l|0)){break}gg[c[3542124]&4095](j,k);Uu(0,j,k)}}while(0);l=c[1836236]|0;f=c[9757320+(l<<2)>>2]|0;if((f|0)!=0){k=f;gGC(k|0,9706056,76)|0}c[9752472+(l<<2)>>2]=c[2433530];c[14113936+(l<<2)>>2]=c[2076596];c[9669104+(l<<2)>>2]=c[3541536];c[1836236]=-1;l=c[2394]|0;k=c[14130368+(l<<2)>>2]|0;if((k|0)!=0){gGC(k|0,9104152,280)|0}c[8452240+(l<<2)>>2]=c[2113054];c[2394]=-1;if((c[2112968]|0)==0){return 0}dMK()|0;return 0}function dMK(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;d=c[2387222]|0;f=c[3530050]|0;g=0;do{h=b[d+(g<<1)>>1]|0;i=h&255;j=(h&65535)>>>8;k=(h&65535)>>>4;c[f+(g<<2)>>2]=((j&8|j<<4&255)&255)>>>3|((i&8|i<<4)&255)<<8&63488|((k&12|k<<4&255)&255)<<3&2016;g=g+1|0;}while((g|0)<384);g=c[2406576]|0;d=c[2409e3]|0;k=d+2|0;i=c[3528720]|0;j=c[2112926]|0;h=c[3530442]|0;l=c[2113068]|0;m=c[2113070]|0;n=0;do{o=n>>5;p=n<<4;q=o<<4;r=(p&496)-(e[d>>1]|0)|0;s=(r|0)<-15?r+512|0:r;r=q-(e[k>>1]|0)|0;t=(r|0)<-15?r+512|0:r;do{if((s|0)<(l|0)&(t|0)<(m|0)){r=(p&256|n&15|q&240|o<<5&512)<<1;u=e[g+(r<<1)>>1]|0;v=b[g+((r|1)<<1)>>1]&255|u<<8&3840;r=u>>>4&7;w=u&128;if((a[i]|0)==0){if((w|0)==0){Sz(j,v,s,t,r,4,256,h);break}else{SB(j,v,s,t,r,4,256,h);break}}else{u=240-t-16|0;x=240-s|0;if((w|0)==0){SF(j,v,x,u,r,4,256,h);break}else{SD(j,v,x,u,r,4,256,h);break}}}}while(0);n=n+1|0;}while((n|0)<1024);n=c[2386480]|0;h=n+1022|0;g=c[3530632]|0;m=n;do{n=e[m+2>>1]|0;L19192:do{if((n&1|0)!=0){l=e[m+4>>1]|0;k=l>>>7&1;d=l>>>6&1;s=n>>>1;t=s&1;o=((n&240)+128|0)>>>4;q=256-(b[m>>1]&255|n<<6&256)&511;p=256-(b[m+8>>1]&255|n<<5&256)&511;r=t+1|0;u=(b[m+6>>1]&255|l<<8&16128)&((s|-2)^1);s=a[i]|0;if(s<<24>>24==0){y=d;z=k;A=p-16|0;B=q}else{y=d^1;z=k^1;A=256-p|0;B=256-q|0}q=B-16|0;p=t<<4;t=(z|0)==0;if((y|0)==0){k=0;d=s;while(1){l=(k<<4)-(d<<24>>24==0?p:0)+q|0;x=k+u|0;if(t){SH(j,x,A,l,o,4,0,0,g)}else{SJ(j,x,A,l,o,4,0,0,g)}l=k+1|0;if((l|0)>=(r|0)){break L19192}k=l;d=a[i]|0}}else{if(t){d=0;k=s;while(1){SL(j,d+u|0,A,(k<<24>>24==0?0:p)+q-(d<<4)|0,o,4,0,0,g);l=d+1|0;if((l|0)>=(r|0)){break L19192}d=l;k=a[i]|0}}else{k=0;d=s;while(1){SN(j,k+u|0,A,(d<<24>>24==0?0:p)+q-(k<<4)|0,o,4,0,0,g);t=k+1|0;if((t|0)>=(r|0)){break L19192}k=t;d=a[i]|0}}}}}while(0);m=m+10|0;}while(m>>>0<h>>>0);h=c[2406496]|0;m=c[3530868]|0;g=0;do{A=g<<3&248;y=g>>5<<3;z=g<<1;B=e[h+(z<<1)>>1]|0;n=b[h+((z|1)<<1)>>1]&255|B<<8&3840;z=B>>>4&15;if((a[i]|0)==0){Sr(j,n,A,y,z,4,0,0,m)}else{Sx(j,n,A^248,(y^248)-16|0,z,4,0,0,m)}g=g+1|0;}while((g|0)<1024);R8(f);return 0}function dML(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=i;i=i+112|0;g=f|0;h=f+16|0;j=f+32|0;k=f+48|0;l=f+64|0;m=f+80|0;n=f+96|0;if((e|0)!=0){c[e>>2]=169734}if((b&32|0)!=0){gGz(n|0,0,12);e=c[2414702]|0;c[n>>2]=e;c[n+4>>2]=(c[2411720]|0)-e;c[n+12>>2]=162152;e=c[2076592]|0;gj[e&4095](n)|0}if((b&64|0)==0){i=f;return 0}n=l|0;gGz(k|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){e=l+9|0;l=j;o=j|0;p=j+4|0;q=j+12|0;r=k|0;s=k+4|0;t=k+12|0;u=0;do{gGC(n|0,614896,11)|0;a[e]=u+48&255;v=8452256+(u<<2)|0;gGz(l|0,0,12);c[o>>2]=v;c[p>>2]=4;c[q>>2]=164976;gj[c[2076592]&4095](j)|0;if((c[v>>2]|0)!=0){c[r>>2]=c[14130368+(u<<2)>>2];c[s>>2]=c[8452184+(u<<2)>>2];c[t>>2]=n;v=c[2076592]|0;gj[v&4095](k)|0}u=u+1|0;}while((u|0)<=(c[2392]|0))}fw$(b);gGz(h|0,0,12);c[h>>2]=8453216;c[h+4>>2]=4;c[h+12>>2]=107480;gj[c[2076592]&4095](h)|0;gGz(g|0,0,12);c[g>>2]=14168504;c[g+4>>2]=256;c[g+12>>2]=476464;gj[c[2076592]&4095](g)|0;if((b&2|0)!=0){b=0;do{mv(0,b,d[14168504+b|0]|0);b=b+1|0;}while((b|0)<256)}Ut(0);gGz(m|0,0,12);c[m>>2]=9635928;c[m+4>>2]=4;c[m+12>>2]=509304;gj[c[2076592]&4095](m)|0;i=f;return 0}function dMM(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1327764+(b*112|0)>>2];c[a+104>>2]=c[1327768+(b*112|0)>>2];c[a+108>>2]=c[1327772+(b*112|0)>>2];d=0;return d|0}function dMN(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=1327664+(b*112|0);e=0;return e|0}function dMO(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[992276+(b*112|0)>>2];c[a+104>>2]=c[992280+(b*112|0)>>2];c[a+108>>2]=c[992284+(b*112|0)>>2];d=0;return d|0}function dMP(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=992176+(b*112|0);e=0;return e|0}function dMQ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1329332+(b*112|0)>>2];c[a+104>>2]=c[1329336+(b*112|0)>>2];c[a+108>>2]=c[1329340+(b*112|0)>>2];d=0;return d|0}function dMR(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=1329232+(b*112|0);e=0;return e|0}function dMS(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>50){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1330900+(b*112|0)>>2];c[a+104>>2]=c[1330904+(b*112|0)>>2];c[a+108>>2]=c[1330908+(b*112|0)>>2];d=0;return d|0}function dMT(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<51&(d|0)==0)){e=1;return e|0}c[a>>2]=1330800+(b*112|0);e=0;return e|0}function dMU(b){b=b|0;a[9706117]=(b|0)!=0|0;return}function dMV(b,d){b=b|0;d=d|0;var e=0,f=0;e=b&65535;b=e&64512;if((b|0)==6144){a[(c[2386228]|0)+(e>>>5&31|e<<5&992)|0]=d;return}else if((b|0)==7168){a[(c[2387876]|0)+(e>>>5&31|e<<5&992)|0]=d;return}else{switch(e|0){case 8196:case 8197:case 8198:case 8199:{b=e>>>1&1;f=d&255;if((e&1|0)==0){c[14168912+(b*252|0)>>2]=f&15;return}e=c[14168912+(b*252|0)>>2]|0;if((e|0)>15){return}do{if((e|0)<14){if((e|0)!=13){if((a[14168916+(b*252|0)+e|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(b,e,f);return};case 8193:{gg[c[(c[2443776]|0)+64>>2]&4095](0,0);return};case 8192:{a[c[3528718]|0]=d&1;return};default:{return}}}}function dMW(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6586788+(b*112|0)>>2];c[a+104>>2]=c[6586792+(b*112|0)>>2];c[a+108>>2]=c[6586796+(b*112|0)>>2];d=0;return d|0}function dMX(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=6586688+(b*112|0);e=0;return e|0}function dMY(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6929744+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dMZ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>25){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7438424+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dM_(){return dNb(2684,2454)|0}function dM$(){var a=0,b=0,d=0,e=0,f=0;c[2113070]=0;c[2113068]=0;a=c[2112926]|0;if((a|0)!=0){gGr(a);c[2112926]=0}fvR();c[2113008]=0;c[2076598]=0;c[2383582]=0;a=c[2414996]|0;b=0;while(1){if((b|0)>=1024){break}d=9638528+(b<<2)|0;if((c[d>>2]|0)==(a|0)){e=14733;break}else{b=b+1|0}}if((e|0)==14733){gGr(a);c[d>>2]=0}c[2414996]=0;d=c[2385370]|0;a=0;while(1){if((a|0)>=1024){e=14739;break}f=9638528+(a<<2)|0;if((c[f>>2]|0)==(d|0)){break}else{a=a+1|0}}if((e|0)==14739){c[2385370]=0;return 0}gGr(d);c[f>>2]=0;c[2385370]=0;return 0}function dM0(){var d=0,e=0,f=0,g=0,h=0,i=0;if((c[2385370]|0)==0&(c[2112964]|0)!=0){d=a[9688]|0?6408:0;e=0;while(1){if((e|0)>=1024){f=0;break}g=9638528+(e<<2)|0;if((c[g>>2]|0)==0){h=14745;break}else{e=e+1|0}}do{if((h|0)==14745){e=gGq(d)|0;c[g>>2]=e;if((e|0)==0){f=0;break}gGz(e|0,0,d|0);f=e}}while(0);c[2385370]=f;c[2439032]=f;d=a[9688]|0?534:0;c[2439033]=f+(d<<1);c[2439034]=f+(d<<1<<1);c[2439035]=f+((d*3|0)<<1);c[2439036]=f+(d<<2<<1);c[2439037]=f+((d*5|0)<<1)}if((a[9624416]|0)!=0){d=c[2414700]|0;gGz(d|0,0,(c[2411718]|0)-d|0);c[3528556]=0;d=c[2433594]|0;c[2443776]=d;L19386:do{if((d|0)!=0){f=d|0;gGC(9660952,f|0,52)|0;switch(a[9660952]|0){case 0:{c[2309668]=638960;break L19386;break};case 3:{c[2309668]=639984;break L19386;break};case 4:{c[2309668]=7356016;break L19386;break};case 1:{c[2309668]=634096;break L19386;break};case 5:{c[2309668]=7354992;break L19386;break};case 2:{c[2309668]=638960;break L19386;break};default:{break L19386}}}}while(0);c[2113164]=c[2432850];gu[c[d+56>>2]&16383]();d=c[2443776]|0;if((d|0)!=0){f=d|0;gGC(f|0,9660952,52)|0}c[9731400+(c[3528556]<<2)>>2]=c[2113164];c[2443776]=0;c[3528556]=-1;mB(0);mB(1)}b[4775308]=-1;f=0;d=-1;g=-1;do{d=((a[9633824+f|0]&1)<<f^d&255)&255;g=((a[9631624+f|0]&1)<<f^g&255)&255;f=f+1|0;}while((f|0)<8);a[9550616]=d;a[9550617]=g;c[3528556]=0;g=c[2433594]|0;c[2443776]=g;L19403:do{if((g|0)!=0){d=g|0;gGC(9660952,d|0,52)|0;switch(a[9660952]|0){case 2:{c[2309668]=638960;break L19403;break};case 0:{c[2309668]=638960;break L19403;break};case 3:{c[2309668]=639984;break L19403;break};case 1:{c[2309668]=634096;break L19403;break};case 4:{c[2309668]=7356016;break L19403;break};case 5:{c[2309668]=7354992;break L19403;break};default:{break L19403}}}}while(0);c[2113164]=c[2432850];a[672584]=0;d=0;f=g;while(1){g=gj[c[f+52>>2]&4095](822)|0;c[2113164]=(c[2113164]|0)+g;g=d&1;if((g|0)==0){gg[c[(c[2443776]|0)+64>>2]&4095](0,0)}else if((g|0)==1){gg[c[(c[2443776]|0)+64>>2]&4095](0,1)}if((d|0)==28){a[672584]=1;i=29}else{g=d+1|0;if((g|0)<32){i=g}else{break}}d=i;f=c[2443776]|0}f=c[2443776]|0;if((f|0)!=0){i=f|0;gGC(i|0,9660952,52)|0}c[9731400+(c[3528556]<<2)>>2]=c[2113164];c[2443776]=0;c[3528556]=-1;i=c[2112964]|0;if((i|0)!=0){mF(9756128,i,a[9688]|0?534:0,0)}if((c[2112968]|0)==0){return 0}dM1()|0;return 0}function dM1(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;if((a[9547576]|0)!=0){b=c[3531012]|0;e=c[3530048]|0;f=0;do{g=d[b+f|0]|0;c[e+(f<<2)>>2]=(-(g>>>3&1)&33)+(-(g>>>4&1)&71)+(-(g>>>5&1)&151)<<3&2016|((-(g>>>6&1)&71)+(-(g>>>7)&151)|0)>>>3&31|(-(g>>>1&1)&71)+(-(g&1)&33)+(-(g>>>2&1)&151)<<8&63488;f=f+1|0;}while((f|0)<8);a[9547576]=0}f=c[2386228]|0;e=c[2387876]|0;b=c[3528718]|0;g=c[2112926]|0;h=c[3530866]|0;i=0;do{j=i>>>2&248;k=i<<3&248;l=(d[e+i|0]<<8&768|d[f+i|0])&65535;if((a[b]|0)==0){Sj(g,l,(j^248)-8|0,k-8|0,0,3,0,h)}else{Sp(g,l,j-8|0,(k^248)-8|0,0,3,0,h)}i=i+1|0;}while((i|0)<1024);i=c[3530630]|0;h=0;e=1;while(1){k=d[f+h|0]|0;do{if((k&1|0)!=0){j=d[f+(h|96)|0]|0;l=d[f+(h|64)|0]|0;m=k&4;n=k&2;o=d[f+(h|32)|0]|0;if((a[b]|0)==0){p=n;q=m;r=240-l|0;s=240-j|0}else{p=n>>>1^1;q=m>>>2^1;r=l;s=j}j=(q|0)!=0;l=s-8|0;m=r-8|0;if((p|0)==0){if(j){SJ(g,o,l,m,0,3,0,0,i);break}else{SH(g,o,l,m,0,3,0,0,i);break}}else{if(j){SN(g,o,l,m,0,3,0,0,i);break}else{SL(g,o,l,m,0,3,0,0,i);break}}}}while(0);if((e|0)>=8){break}h=h+128|0;e=e+1|0}R8(c[3530048]|0);return 0}function dM2(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;e=i;i=i+128|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;l=e+80|0;m=e+96|0;n=e+112|0;o=(d|0)==0;if(!o){c[d>>2]=169249}if((b&96|0)==0){i=e;return 0}gGz(n|0,0,12);p=c[2414700]|0;c[n>>2]=p;c[n+4>>2]=(c[2411718]|0)-p;c[n+12>>2]=162152;gj[c[2076592]&4095](n)|0;n=m|0;p=(b&64|0)==0;if((c[2113166]|0)>0&(p^1)){b=m+7|0;m=l|0;q=l+4|0;r=l+12|0;s=k;t=k|0;u=k+4|0;v=k+12|0;w=j;x=j|0;y=j+4|0;z=j+12|0;A=h;B=h|0;C=h+4|0;D=h+12|0;E=0;do{F=c[9734376+(E<<2)>>2]|0;G=F+36|0;H=c[G>>2]|0;gGC(n|0,614768,9)|0;a[b]=E+48&255;c[m>>2]=F;c[q>>2]=52;c[r>>2]=n;gj[c[2076592]&4095](l)|0;gGz(s|0,0,12);c[t>>2]=F+3172;c[u>>2]=4;c[v>>2]=165288;gj[c[2076592]&4095](k)|0;gGz(w|0,0,12);c[x>>2]=F+3176;c[y>>2]=4;c[z>>2]=501592;gj[c[2076592]&4095](j)|0;gGz(A|0,0,12);c[B>>2]=F+3180;c[C>>2]=4;c[D>>2]=386080;gj[c[2076592]&4095](h)|0;c[G>>2]=H;E=E+1|0;}while((E|0)<(c[2113166]|0))}E=g|0;if(p){i=e;return 0}do{if(!o){if((c[d>>2]|0)>=169110){break}c[d>>2]=169110}}while(0);if((c[2113008]|0)<=0){i=e;return 0}d=f|0;o=f+4|0;p=f+8|0;g=f+12|0;h=0;do{cC(E|0,531144,(D=i,i=i+8|0,c[D>>2]=h,D)|0)|0;i=D;c[d>>2]=14168888+(h*252|0);c[o>>2]=252;c[p>>2]=0;c[g>>2]=E;gj[c[2076592]&4095](f)|0;h=h+1|0;}while((h|0)<(c[2113008]|0));i=e;return 0}function dM3(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5687676+(b*112|0)>>2];c[a+104>>2]=c[5687680+(b*112|0)>>2];c[a+108>>2]=c[5687684+(b*112|0)>>2];d=0;return d|0}function dM4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=5687576+(b*112|0);e=0;return e|0}function dM5(){return dNb(7244,1152)|0}function dM6(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7058476+(b*112|0)>>2];c[a+104>>2]=c[7058480+(b*112|0)>>2];c[a+108>>2]=c[7058484+(b*112|0)>>2];d=0;return d|0}function dM7(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=7058376+(b*112|0);e=0;return e|0}function dM8(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2375140+(b*112|0)>>2];c[a+104>>2]=c[2375144+(b*112|0)>>2];c[a+108>>2]=c[2375148+(b*112|0)>>2];d=0;return d|0}function dM9(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=2375040+(b*112|0);e=0;return e|0}function dNa(){return dNb(7244,2720)|0}function dNb(b,e){b=b|0;e=e|0;var f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0.0,A=0,B=0,C=0,D=0;c[2414996]=0;c[3531196]=0;c[3530866]=65536;c[3530630]=131072;c[3531012]=196608;c[3530048]=196640;c[2414700]=196672;c[3531206]=196672;c[2386228]=198720;c[2387876]=199744;c[3528718]=200768;c[2411718]=200769;f=0;while(1){if((f|0)>=1024){break}g=9638528+(f<<2)|0;if((c[g>>2]|0)==0){i=14869;break}else{f=f+1|0}}do{if((i|0)==14869){f=gGq(200769)|0;c[g>>2]=f;if((f|0)==0){break}c[2414996]=f;gGz(f|0,0,200769);c[3531196]=f;c[3530866]=f+65536;c[3530630]=f+131072;c[3531012]=f+196608;c[3530048]=f+196640;j=f+196672|0;c[2414700]=j;c[3531206]=j;c[2386228]=f+198720;c[2387876]=f+199744;c[3528718]=f+200768;j=f+200769|0;c[2411718]=j;c[2414260]=j;if((e|0)!=0){if((gD[e&8191]()|0)==0){k=0}else{l=1;return l|0}while(1){if((k|0)>=1024){break}m=9638528+(k<<2)|0;if((c[m>>2]|0)==0){i=14875;break}else{k=k+1|0}}L19547:do{if((i|0)==14875){j=gGq(24576)|0;c[m>>2]=j;if((j|0)==0){break}gGz(j|0,0,24576);f=c[3530866]|0;gGC(j|0,f|0,24576)|0;n=0;do{o=n<<6;gGz(f+o|0,0,64);p=o+131072|0;q=0;do{r=p+(c[609008+(q<<2)>>2]|0)|0;s=(q<<3)+o|0;t=0;do{u=r+(c[612640+(t+8<<2)>>2]|0)|0;if((d[j+((u|0)/8|0)|0]&128>>>((u&7)>>>0)|0)!=0){u=f+(s+t)|0;a[u]=a[u]|4}t=t+1|0;}while((t|0)<8);q=q+1|0;}while((q|0)<8);q=o+65536|0;p=0;while(1){t=q+(c[609008+(p<<2)>>2]|0)|0;s=(p<<3)+o|0;r=0;do{u=t+(c[612640+(r+8<<2)>>2]|0)|0;if((d[j+((u|0)/8|0)|0]&128>>>((u&7)>>>0)|0)!=0){u=f+(s+r)|0;a[u]=a[u]|2}r=r+1|0;}while((r|0)<8);r=p+1|0;if((r|0)<8){p=r}else{v=0;break}}do{p=o+(c[609008+(v<<2)>>2]|0)|0;q=(v<<3)+o|0;r=0;do{s=p+(c[612640+(r+8<<2)>>2]|0)|0;if((d[j+((s|0)/8|0)|0]&128>>>((s&7)>>>0)|0)!=0){s=f+(q+r)|0;a[s]=a[s]|1}r=r+1|0;}while((r|0)<8);v=v+1|0;}while((v|0)<8);n=n+1|0;}while((n|0)<1024);n=c[3530630]|0;f=0;while(1){o=f<<8;gGz(n+o|0,0,256);r=o+131072|0;q=0;do{p=r+(c[609008+(q<<2)>>2]|0)|0;s=(q<<4)+o|0;t=0;do{u=p+(c[612640+(t<<2)>>2]|0)|0;if((d[j+((u|0)/8|0)|0]&128>>>((u&7)>>>0)|0)!=0){u=n+(s+t)|0;a[u]=a[u]|4}t=t+1|0;}while((t|0)<16);q=q+1|0;}while((q|0)<16);q=o+65536|0;r=0;while(1){t=q+(c[609008+(r<<2)>>2]|0)|0;s=(r<<4)+o|0;p=0;do{u=t+(c[612640+(p<<2)>>2]|0)|0;if((d[j+((u|0)/8|0)|0]&128>>>((u&7)>>>0)|0)!=0){u=n+(s+p)|0;a[u]=a[u]|2}p=p+1|0;}while((p|0)<16);p=r+1|0;if((p|0)<16){r=p}else{w=0;break}}do{r=o+(c[609008+(w<<2)>>2]|0)|0;q=(w<<4)+o|0;p=0;do{s=r+(c[612640+(p<<2)>>2]|0)|0;if((d[j+((s|0)/8|0)|0]&128>>>((s&7)>>>0)|0)!=0){s=n+(q+p)|0;a[s]=a[s]|1}p=p+1|0;}while((p|0)<16);w=w+1|0;}while((w|0)<16);o=f+1|0;if((o|0)<256){f=o}else{x=0;break}}while(1){if((x|0)>=1024){break L19547}y=9638528+(x<<2)|0;if((c[y>>2]|0)==(j|0)){break}else{x=x+1|0}}gGr(j);c[y>>2]=0}}while(0);f=c[3531012]|0;n=c[3530048]|0;o=0;do{p=d[f+o|0]|0;c[n+(o<<2)>>2]=(-(p>>>3&1)&33)+(-(p>>>4&1)&71)+(-(p>>>5&1)&151)<<3&2016|((-(p>>>6&1)&71)+(-(p>>>7)&151)|0)>>>3&31|(-(p>>>1&1)&71)+(-(p&1)&33)+(-(p>>>2&1)&151)<<8&63488;o=o+1|0;}while((o|0)<8)}if((b|0)!=0){gu[b&16383]()}c[2424]=5700;o=a[9680]|0?32e3:0;c[3542220]=11200;n=c[2113008]|0;if((n|0)==0){gGz(14168888,0,252);c[3542223]=o;gGz(14168896,0,16);c[3542234]=~~((+(o|0)*32768.0*8.0+75.0e4)/15.0e5);f=31;z=32767.0;while(1){c[14169012+(f<<2)>>2]=~~(z+.5);p=f-1|0;if((p|0)>0){f=p;z=z/1.188502227}else{break}}c[3542253]=0;h[1771269]=1.0;h[1771270]=1.0;h[1771271]=1.0;c[3542574]=3;c[3542575]=3;c[3542576]=3;mB(0);f=(c[2113008]|0)+1|0;c[2113008]=f;A=f;B=a[9680]|0?32e3:0}else{A=n;B=o}c[3542220]=11200;if((A|0)==1){gGz(14169140,0,252);c[3542286]=B;gGz(14169148,0,16);c[3542297]=~~((+(B|0)*32768.0*8.0+75.0e4)/15.0e5);f=31;z=32767.0;while(1){c[14169264+(f<<2)>>2]=~~(z+.5);p=f-1|0;if((p|0)>0){f=p;z=z/1.188502227}else{break}}c[3542316]=0;h[1771272]=1.0;h[1771273]=1.0;h[1771274]=1.0;c[3542577]=3;c[3542578]=3;c[3542579]=3;mB(1);c[2113008]=(c[2113008]|0)+1}h[1771269]=.23;c[3542574]=3;h[1771270]=.23;c[3542575]=3;h[1771271]=.23;c[3542576]=3;h[1771272]=.23;c[3542577]=3;h[1771273]=.23;c[3542578]=3;h[1771274]=.23;c[3542579]=3;f=c[642608+(c[2436]<<2)>>2]|0;o=c[f+128>>2]|0;if((c[f+52>>2]&4|0)==0){c[2113068]=o;n=c[f+132>>2]|0;c[2113070]=n;c[2443814]=o;c[2440436]=n;C=o;D=n}else{c[2113070]=o;n=c[f+132>>2]|0;c[2113068]=n;c[2440436]=o;c[2443814]=n;C=n;D=o}o=ag(C<<1,D)|0;n=gGq(o)|0;c[2112926]=n;if((n|0)!=0){gGz(n|0,0,o|0)}o=c[2414700]|0;gGz(o|0,0,(c[2411718]|0)-o|0);c[3528556]=0;o=c[2433594]|0;c[2443776]=o;L19637:do{if((o|0)!=0){n=o|0;gGC(9660952,n|0,52)|0;switch(a[9660952]|0){case 5:{c[2309668]=7354992;break L19637;break};case 2:{c[2309668]=638960;break L19637;break};case 4:{c[2309668]=7356016;break L19637;break};case 1:{c[2309668]=634096;break L19637;break};case 3:{c[2309668]=639984;break L19637;break};case 0:{c[2309668]=638960;break L19637;break};default:{break L19637}}}}while(0);c[2113164]=c[2432850];gu[c[o+56>>2]&16383]();n=c[2443776]|0;if((n|0)!=0){f=n|0;gGC(f|0,9660952,52)|0}c[9731400+(c[3528556]<<2)>>2]=c[2113164];c[2443776]=0;c[3528556]=-1;mB(0);mB(1);l=0;return l|0}}while(0);c[2414996]=0;l=1;return l|0}function dNc(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;fvI();c[3528556]=0;b=c[2433594]|0;c[2443776]=b;d=(b|0)==0;L19654:do{if(!d){e=b|0;gGC(9660952,e|0,52)|0;switch(a[9660952]|0){case 3:{c[2309668]=639984;break L19654;break};case 4:{c[2309668]=7356016;break L19654;break};case 1:{c[2309668]=634096;break L19654;break};case 5:{c[2309668]=7354992;break L19654;break};case 2:{c[2309668]=638960;break L19654;break};case 0:{c[2309668]=638960;break L19654;break};default:{break L19654}}}}while(0);e=c[2432850]|0;c[2113164]=e;f=c[3531206]|0;c[b+68>>2]=f;c[b+1092>>2]=f;c[b+2116>>2]=f;g=f+256|0;c[b+72>>2]=g;c[b+1096>>2]=g;c[b+2120>>2]=g;g=f+512|0;c[b+76>>2]=g;c[b+1100>>2]=g;c[b+2124>>2]=g;g=f+768|0;c[b+80>>2]=g;c[b+1104>>2]=g;c[b+2128>>2]=g;g=f+1024|0;c[b+84>>2]=g;c[b+1108>>2]=g;c[b+2132>>2]=g;g=f+1280|0;c[b+88>>2]=g;c[b+1112>>2]=g;c[b+2136>>2]=g;g=f+1536|0;c[b+92>>2]=g;c[b+1116>>2]=g;c[b+2140>>2]=g;g=f+1792|0;c[b+96>>2]=g;c[b+1120>>2]=g;c[b+2144>>2]=g;g=c[2386228]|0;c[b+132>>2]=g;c[b+1156>>2]=g;c[b+2180>>2]=g;f=g+256|0;c[b+136>>2]=f;c[b+1160>>2]=f;c[b+2184>>2]=f;f=g+512|0;c[b+140>>2]=f;c[b+1164>>2]=f;c[b+2188>>2]=f;f=g+768|0;c[b+144>>2]=f;c[b+1168>>2]=f;c[b+2192>>2]=f;f=c[2387876]|0;c[b+148>>2]=f;c[b+1172>>2]=f;c[b+2196>>2]=f;g=f+256|0;c[b+152>>2]=g;c[b+1176>>2]=g;c[b+2200>>2]=g;g=f+512|0;c[b+156>>2]=g;c[b+1180>>2]=g;c[b+2204>>2]=g;g=f+768|0;c[b+160>>2]=g;c[b+1184>>2]=g;c[b+2208>>2]=g;g=c[3531196]|0;f=48;h=48;while(1){i=g+(h<<8)|0;c[b+68+(h<<2)>>2]=i;c[b+68+(h+512<<2)>>2]=i;i=f+1&65535;if((i&65535)>127){j=240;k=240;break}else{f=i;h=i&65535}}while(1){h=g+((k<<8)-32768)|0;c[b+68+(k<<2)>>2]=h;c[b+68+(k+512<<2)>>2]=h;h=j+1&65535;if((h&65535)>255){break}else{j=h;k=h&65535}}c[b+3160>>2]=2342;c[b+3156>>2]=200;c[b+3168>>2]=200;c[b+3152>>2]=2342;c[b+3164>>2]=200;c[b+3148>>2]=200;if(d){c[2432850]=e;c[2443776]=0;c[3528556]=-1;return}d=b|0;gGC(d|0,9660952,52)|0;c[2432850]=e;c[2443776]=0;c[3528556]=-1;return}function dNd(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=i;i=i+840|0;d=b|0;e=b+112|0;f=b+120|0;g=b+232|0;h=b+240|0;j=b+352|0;k=b+360|0;l=b+472|0;m=b+480|0;n=b+592|0;o=b+600|0;p=b+712|0;q=b+720|0;r=b+832|0;s=(c[3531196]|0)+16384|0;if((c[3542200]|0)==0){t=1;i=b;return t|0}u=q+108|0;c[u>>2]=0;v=q+100|0;c[v>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](q,0)|0;do{if((c[u>>2]|0)!=0){q=c[v>>2]|0;c[r>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](r,0,0)|0;if((q|0)<1){t=1;i=b;return t|0}if((gzL(s,0,0)|0)==0){break}else{t=1}i=b;return t|0}}while(0);s=(c[3531196]|0)+24576|0;if((c[3542200]|0)==0){t=1;i=b;return t|0}r=o+108|0;c[r>>2]=0;v=o+100|0;c[v>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](o,1)|0;do{if((c[r>>2]|0)!=0){o=c[v>>2]|0;c[p>>2]=9534384;u=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[u&16383](p,1,0)|0;if((o|0)<1){t=1;i=b;return t|0}if((gzL(s,0,1)|0)==0){break}else{t=1}i=b;return t|0}}while(0);s=(c[3531196]|0)+32768|0;if((c[3542200]|0)==0){t=1;i=b;return t|0}p=m+108|0;c[p>>2]=0;v=m+100|0;c[v>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,2)|0;do{if((c[p>>2]|0)!=0){m=c[v>>2]|0;c[n>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](n,2,0)|0;if((m|0)<1){t=1;i=b;return t|0}if((gzL(s,0,2)|0)==0){break}else{t=1}i=b;return t|0}}while(0);s=c[3531196]|0;n=s+12288|0;v=s+20480|0;gGC(n|0,v|0,4096)|0;n=s+28672|0;gGC(v|0,n|0,4096)|0;v=s+57344|0;p=s+32768|0;gGC(v|0,p|0,8192)|0;p=s+36864|0;gGC(n|0,p|0,4096)|0;p=c[3530866]|0;if((c[3542200]|0)==0){t=1;i=b;return t|0}n=k+108|0;c[n>>2]=0;s=k+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,3)|0;do{if((c[n>>2]|0)!=0){k=c[s>>2]|0;c[l>>2]=9534384;v=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[v&16383](l,3,0)|0;if((k|0)<1){t=1;i=b;return t|0}if((gzL(p,0,3)|0)==0){break}else{t=1}i=b;return t|0}}while(0);p=(c[3530866]|0)+8192|0;if((c[3542200]|0)==0){t=1;i=b;return t|0}l=h+108|0;c[l>>2]=0;s=h+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](h,4)|0;do{if((c[l>>2]|0)!=0){h=c[s>>2]|0;c[j>>2]=9534384;n=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[n&16383](j,4,0)|0;if((h|0)<1){t=1;i=b;return t|0}if((gzL(p,0,4)|0)==0){break}else{t=1}i=b;return t|0}}while(0);p=(c[3530866]|0)+16384|0;if((c[3542200]|0)==0){t=1;i=b;return t|0}j=f+108|0;c[j>>2]=0;s=f+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,5)|0;do{if((c[j>>2]|0)!=0){f=c[s>>2]|0;c[g>>2]=9534384;l=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[l&16383](g,5,0)|0;if((f|0)<1){t=1;i=b;return t|0}if((gzL(p,0,5)|0)==0){break}else{t=1}i=b;return t|0}}while(0);p=c[3531012]|0;if((c[3542200]|0)==0){t=1;i=b;return t|0}g=d+108|0;c[g>>2]=0;s=d+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](d,6)|0;do{if((c[g>>2]|0)!=0){d=c[s>>2]|0;c[e>>2]=9534384;j=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[j&16383](e,6,0)|0;if((d|0)<1){t=1;i=b;return t|0}if((gzL(p,0,6)|0)==0){break}else{t=1}i=b;return t|0}}while(0);p=c[3530866]|0;e=8192;while(1){s=p+e|0;g=a[s]|0;a[s]=(g&255)>>>2<<7|g<<6&64|(g&255)>>>7<<1|(g&255)>>>5&1|(g&255)>>>3<<5&32|(g&255)>>>6<<4&16|(g&255)>>>1<<3&8|(g&255)>>>4<<2&4;g=e+1|0;if((g|0)<24576){e=g}else{t=0;break}}i=b;return t|0}function dNe(b){b=b|0;var d=0,e=0;d=b&65535;do{if((d&63488|0)==6144){e=a[(c[2386228]|0)+(d>>>5&31|d<<5&992)|0]|0}else{if((d|0)==8193){e=a[9635241]|0;break}else if((d|0)==8194){e=a[9550616]|0;break}else if((d|0)==8195){e=a[9550617]|0;break}else if((d|0)==8192){e=(a[672584]|0?-128:0)|a[9635240];break}else{e=0;break}}}while(0);return e|0}function dNf(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;a=i;i=i+1440|0;b=a|0;d=a+112|0;e=a+120|0;f=a+232|0;g=a+240|0;h=a+352|0;j=a+360|0;k=a+472|0;l=a+480|0;m=a+592|0;n=a+600|0;o=a+712|0;p=a+720|0;q=a+832|0;r=a+840|0;s=a+952|0;t=a+960|0;u=a+1072|0;v=a+1080|0;w=a+1192|0;x=a+1200|0;y=a+1312|0;z=a+1320|0;A=a+1432|0;B=(c[3531196]|0)+12288|0;if((c[3542200]|0)==0){C=1;i=a;return C|0}D=z+108|0;c[D>>2]=0;E=z+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,0)|0;do{if((c[D>>2]|0)!=0){z=c[E>>2]|0;c[A>>2]=9534384;F=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[F&16383](A,0,0)|0;if((z|0)<1){C=1;i=a;return C|0}if((gzL(B,0,0)|0)==0){break}else{C=1}i=a;return C|0}}while(0);B=(c[3531196]|0)+16384|0;if((c[3542200]|0)==0){C=1;i=a;return C|0}A=x+108|0;c[A>>2]=0;E=x+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,1)|0;do{if((c[A>>2]|0)!=0){x=c[E>>2]|0;c[y>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](y,1,0)|0;if((x|0)<1){C=1;i=a;return C|0}if((gzL(B,0,1)|0)==0){break}else{C=1}i=a;return C|0}}while(0);B=(c[3531196]|0)+20480|0;if((c[3542200]|0)==0){C=1;i=a;return C|0}y=v+108|0;c[y>>2]=0;E=v+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,2)|0;do{if((c[y>>2]|0)!=0){v=c[E>>2]|0;c[w>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](w,2,0)|0;if((v|0)<1){C=1;i=a;return C|0}if((gzL(B,0,2)|0)==0){break}else{C=1}i=a;return C|0}}while(0);B=(c[3531196]|0)+24576|0;if((c[3542200]|0)==0){C=1;i=a;return C|0}w=t+108|0;c[w>>2]=0;E=t+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,3)|0;do{if((c[w>>2]|0)!=0){t=c[E>>2]|0;c[u>>2]=9534384;y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[y&16383](u,3,0)|0;if((t|0)<1){C=1;i=a;return C|0}if((gzL(B,0,3)|0)==0){break}else{C=1}i=a;return C|0}}while(0);B=(c[3531196]|0)+28672|0;if((c[3542200]|0)==0){C=1;i=a;return C|0}u=r+108|0;c[u>>2]=0;E=r+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,4)|0;do{if((c[u>>2]|0)!=0){r=c[E>>2]|0;c[s>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](s,4,0)|0;if((r|0)<1){C=1;i=a;return C|0}if((gzL(B,0,4)|0)==0){break}else{C=1}i=a;return C|0}}while(0);B=c[3530866]|0;if((c[3542200]|0)==0){C=1;i=a;return C|0}s=p+108|0;c[s>>2]=0;E=p+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,5)|0;do{if((c[s>>2]|0)!=0){p=c[E>>2]|0;c[q>>2]=9534384;u=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[u&16383](q,5,0)|0;if((p|0)<1){C=1;i=a;return C|0}if((gzL(B,0,5)|0)==0){break}else{C=1}i=a;return C|0}}while(0);B=(c[3530866]|0)+4096|0;if((c[3542200]|0)==0){C=1;i=a;return C|0}q=n+108|0;c[q>>2]=0;E=n+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,6)|0;do{if((c[q>>2]|0)!=0){n=c[E>>2]|0;c[o>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](o,6,0)|0;if((n|0)<1){C=1;i=a;return C|0}if((gzL(B,0,6)|0)==0){break}else{C=1}i=a;return C|0}}while(0);B=(c[3530866]|0)+8192|0;if((c[3542200]|0)==0){C=1;i=a;return C|0}o=l+108|0;c[o>>2]=0;E=l+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,7)|0;do{if((c[o>>2]|0)!=0){l=c[E>>2]|0;c[m>>2]=9534384;q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[q&16383](m,7,0)|0;if((l|0)<1){C=1;i=a;return C|0}if((gzL(B,0,7)|0)==0){break}else{C=1}i=a;return C|0}}while(0);B=(c[3530866]|0)+12288|0;if((c[3542200]|0)==0){C=1;i=a;return C|0}m=j+108|0;c[m>>2]=0;E=j+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,8)|0;do{if((c[m>>2]|0)!=0){j=c[E>>2]|0;c[k>>2]=9534384;o=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[o&16383](k,8,0)|0;if((j|0)<1){C=1;i=a;return C|0}if((gzL(B,0,8)|0)==0){break}else{C=1}i=a;return C|0}}while(0);B=(c[3530866]|0)+16384|0;if((c[3542200]|0)==0){C=1;i=a;return C|0}k=g+108|0;c[k>>2]=0;E=g+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,9)|0;do{if((c[k>>2]|0)!=0){g=c[E>>2]|0;c[h>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](h,9,0)|0;if((g|0)<1){C=1;i=a;return C|0}if((gzL(B,0,9)|0)==0){break}else{C=1}i=a;return C|0}}while(0);B=(c[3530866]|0)+20480|0;if((c[3542200]|0)==0){C=1;i=a;return C|0}h=e+108|0;c[h>>2]=0;E=e+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,10)|0;do{if((c[h>>2]|0)!=0){e=c[E>>2]|0;c[f>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](f,10,0)|0;if((e|0)<1){C=1;i=a;return C|0}if((gzL(B,0,10)|0)==0){break}else{C=1}i=a;return C|0}}while(0);B=c[3531012]|0;if((c[3542200]|0)==0){C=1;i=a;return C|0}f=b+108|0;c[f>>2]=0;E=b+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](b,11)|0;if((c[f>>2]|0)==0){C=0;i=a;return C|0}f=c[E>>2]|0;c[d>>2]=9534384;gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](d,11,0)|0;if((f|0)<1){C=1;i=a;return C|0}C=(gzL(B,0,11)|0)!=0|0;i=a;return C|0}function dNg(){var b=0,d=0,e=0,f=0,g=0,h=0;fvI();c[3528556]=0;b=c[2433594]|0;c[2443776]=b;L19879:do{if((b|0)!=0){d=b|0;gGC(9660952,d|0,52)|0;switch(a[9660952]|0){case 4:{c[2309668]=7356016;break L19879;break};case 3:{c[2309668]=639984;break L19879;break};case 5:{c[2309668]=7354992;break L19879;break};case 1:{c[2309668]=634096;break L19879;break};case 2:{c[2309668]=638960;break L19879;break};case 0:{c[2309668]=638960;break L19879;break};default:{break L19879}}}}while(0);d=c[2432850]|0;c[2113164]=d;e=c[3531206]|0;c[b+68>>2]=e;c[b+1092>>2]=e;c[b+2116>>2]=e;f=e+256|0;c[b+72>>2]=f;c[b+1096>>2]=f;c[b+2120>>2]=f;f=e+512|0;c[b+76>>2]=f;c[b+1100>>2]=f;c[b+2124>>2]=f;f=e+768|0;c[b+80>>2]=f;c[b+1104>>2]=f;c[b+2128>>2]=f;f=e+1024|0;c[b+84>>2]=f;c[b+1108>>2]=f;c[b+2132>>2]=f;f=e+1280|0;c[b+88>>2]=f;c[b+1112>>2]=f;c[b+2136>>2]=f;f=e+1536|0;c[b+92>>2]=f;c[b+1116>>2]=f;c[b+2140>>2]=f;f=e+1792|0;c[b+96>>2]=f;c[b+1120>>2]=f;c[b+2144>>2]=f;f=c[2386228]|0;c[b+196>>2]=f;c[b+1220>>2]=f;c[b+2244>>2]=f;e=f+256|0;c[b+200>>2]=e;c[b+1224>>2]=e;c[b+2248>>2]=e;e=f+512|0;c[b+204>>2]=e;c[b+1228>>2]=e;c[b+2252>>2]=e;e=f+768|0;c[b+208>>2]=e;c[b+1232>>2]=e;c[b+2256>>2]=e;e=c[2387876]|0;c[b+212>>2]=e;c[b+1236>>2]=e;c[b+2260>>2]=e;f=e+256|0;c[b+216>>2]=f;c[b+1240>>2]=f;c[b+2264>>2]=f;f=e+512|0;c[b+220>>2]=f;c[b+1244>>2]=f;c[b+2268>>2]=f;f=e+768|0;c[b+224>>2]=f;c[b+1248>>2]=f;c[b+2272>>2]=f;f=c[3531196]|0;e=160;g=160;while(1){h=f+(g<<8)|0;c[b+68+(g<<2)>>2]=h;c[b+68+(g+512<<2)>>2]=h;h=e+1&65535;if((h&65535)>255){break}else{e=h;g=h&65535}}c[b+3160>>2]=2546;c[b+3156>>2]=410;c[b+3168>>2]=410;c[b+3152>>2]=2546;c[b+3164>>2]=410;c[b+3148>>2]=410;g=b|0;gGC(g|0,9660952,52)|0;c[2432850]=d;c[2443776]=0;c[3528556]=-1;return}function dNh(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;b=i;i=i+840|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;l=b+360|0;m=b+472|0;n=b+480|0;o=b+592|0;p=b+600|0;q=b+712|0;r=b+720|0;s=b+832|0;t=(c[3531196]|0)+40960|0;if((c[3542200]|0)==0){u=1;i=b;return u|0}v=r+108|0;c[v>>2]=0;w=r+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,0)|0;do{if((c[v>>2]|0)!=0){r=c[w>>2]|0;c[s>>2]=9534384;x=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[x&16383](s,0,0)|0;if((r|0)<1){u=1;i=b;return u|0}if((gzL(t,0,0)|0)==0){break}else{u=1}i=b;return u|0}}while(0);t=(c[3531196]|0)+49152|0;if((c[3542200]|0)==0){u=1;i=b;return u|0}s=p+108|0;c[s>>2]=0;w=p+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,1)|0;do{if((c[s>>2]|0)!=0){p=c[w>>2]|0;c[q>>2]=9534384;v=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[v&16383](q,1,0)|0;if((p|0)<1){u=1;i=b;return u|0}if((gzL(t,0,1)|0)==0){break}else{u=1}i=b;return u|0}}while(0);t=(c[3531196]|0)+57344|0;if((c[3542200]|0)==0){u=1;i=b;return u|0}q=n+108|0;c[q>>2]=0;w=n+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,2)|0;do{if((c[q>>2]|0)!=0){n=c[w>>2]|0;c[o>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](o,2,0)|0;if((n|0)<1){u=1;i=b;return u|0}if((gzL(t,0,2)|0)==0){break}else{u=1}i=b;return u|0}}while(0);t=c[3530866]|0;if((c[3542200]|0)==0){u=1;i=b;return u|0}o=l+108|0;c[o>>2]=0;w=l+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,3)|0;do{if((c[o>>2]|0)!=0){l=c[w>>2]|0;c[m>>2]=9534384;q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[q&16383](m,3,0)|0;if((l|0)<1){u=1;i=b;return u|0}if((gzL(t,0,3)|0)==0){break}else{u=1}i=b;return u|0}}while(0);t=(c[3530866]|0)+8192|0;if((c[3542200]|0)==0){u=1;i=b;return u|0}m=j+108|0;c[m>>2]=0;w=j+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,4)|0;do{if((c[m>>2]|0)!=0){j=c[w>>2]|0;c[k>>2]=9534384;o=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[o&16383](k,4,0)|0;if((j|0)<1){u=1;i=b;return u|0}if((gzL(t,0,4)|0)==0){break}else{u=1}i=b;return u|0}}while(0);t=(c[3530866]|0)+16384|0;if((c[3542200]|0)==0){u=1;i=b;return u|0}k=g+108|0;c[k>>2]=0;w=g+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,5)|0;do{if((c[k>>2]|0)!=0){g=c[w>>2]|0;c[h>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](h,5,0)|0;if((g|0)<1){u=1;i=b;return u|0}if((gzL(t,0,5)|0)==0){break}else{u=1}i=b;return u|0}}while(0);t=c[3531012]|0;if((c[3542200]|0)==0){u=1;i=b;return u|0}h=e+108|0;c[h>>2]=0;w=e+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,6)|0;do{if((c[h>>2]|0)!=0){e=c[w>>2]|0;c[f>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](f,6,0)|0;if((e|0)<1){u=1;i=b;return u|0}if((gzL(t,0,6)|0)==0){break}else{u=1}i=b;return u|0}}while(0);t=c[3531012]|0;f=t+8|0;w=t;t=f|0;h=f+4|0;f=d[h]|d[h+1|0]<<8|d[h+2|0]<<16|d[h+3|0]<<24|0;h=w|0;C=d[t]|d[t+1|0]<<8|d[t+2|0]<<16|d[t+3|0]<<24|0;a[h]=C&255;C=C>>8;a[h+1|0]=C&255;C=C>>8;a[h+2|0]=C&255;C=C>>8;a[h+3|0]=C&255;h=w+4|0;C=f;a[h]=C&255;C=C>>8;a[h+1|0]=C&255;C=C>>8;a[h+2|0]=C&255;C=C>>8;a[h+3|0]=C&255;u=0;i=b;return u|0}function dNi(b,d){b=b|0;d=d|0;var e=0,f=0;e=b&65535;if((e&64512|0)==10240){a[(c[2386228]|0)+(e>>>5&31|e<<5&992)|0]=d;return}switch(e|0){case 16385:{a[c[3528718]|0]=d&1;return};case 16384:{gg[c[(c[2443776]|0)+64>>2]&4095](0,0);return};case 16388:case 16389:case 16390:case 16391:{b=e>>>1&1;f=d&255;if((e&1|0)==0){c[14168912+(b*252|0)>>2]=f&15;return}e=c[14168912+(b*252|0)>>2]|0;if((e|0)>15){return}do{if((e|0)<14){if((e|0)!=13){if((a[14168916+(b*252|0)+e|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(b,e,f);return};default:{return}}}function dNj(b){b=b|0;var d=0,e=0;d=b&65535;do{if((d&64512|0)==10240){e=a[(c[2386228]|0)+(d>>>5&31|d<<5&992)|0]|0}else{if((d|0)==16384){e=(a[672584]|0?-128:0)|a[9635240];break}else if((d|0)==16386){e=a[9550616]|0;break}else if((d|0)==16385){e=a[9635241]|0;break}else if((d|0)==16387){e=a[9550617]|0;break}else{e=0;break}}}while(0);return e|0}function dNk(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((e|0)==57357){a[(c[2408998]|0)+1|0]=d;return}else if((e|0)==57358){a[14114864]=d&1;return}else if((e|0)==57356){a[c[2408998]|0]=d;return}else{return}}function dNl(b){b=b|0;var c=0;switch(b&65535|0){case 57345:{c=a[9635232]|0;break};case 57344:{c=a[9635233]|0;break};case 57349:{c=a[9635234]&16|a[9550610]&-17;break};case 57347:{c=a[9550609]|0;break};case 57346:{c=a[9550608]|0;break};default:{c=0}}return c|0}function dNm(a,b){a=a|0;b=b|0;var c=0;c=a&65535;if((c|0)==49153){TR(1,b&255);return}else if((c|0)==49152){TR(0,b&255);return}else{return}}function dNn(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4559484+(b*112|0)>>2];c[a+104>>2]=c[4559488+(b*112|0)>>2];c[a+108>>2]=c[4559492+(b*112|0)>>2];d=0;return d|0}function dNo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=4559384+(b*112|0);e=0;return e|0}function dNp(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1837888+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dNq(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>45){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5294504+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dNr(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0;e=i;i=i+1920|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;B=e+1200|0;C=e+1312|0;D=e+1320|0;E=e+1432|0;F=e+1440|0;G=e+1552|0;H=e+1560|0;I=e+1672|0;J=e+1680|0;K=e+1792|0;L=e+1800|0;M=e+1912|0;c[2414994]=0;c[3529244]=0;c[3529200]=24576;c[3530864]=49152;c[3530628]=114688;c[3531010]=180224;c[2406942]=182016;c[3530046]=186112;c[2414698]=190208;c[3529332]=190208;c[2386226]=192256;c[2386478]=194304;c[3527308]=196352;c[2408998]=198400;c[2411716]=198402;N=0;while(1){if((N|0)>=1024){break}O=9638528+(N<<2)|0;if((c[O>>2]|0)==0){P=15256;break}else{N=N+1|0}}do{if((P|0)==15256){N=gGq(198402)|0;c[O>>2]=N;if((N|0)==0){break}c[2414994]=N;gGz(N|0,0,198402);c[3529244]=N;c[3529200]=N+24576;c[3530864]=N+49152;c[3530628]=N+114688;c[3531010]=N+180224;c[2406942]=N+182016;c[3530046]=N+186112;Q=N+190208|0;c[2414698]=Q;c[3529332]=Q;c[2386226]=N+192256;c[2386478]=N+194304;c[3527308]=N+196352;c[2408998]=N+198400;Q=N+198402|0;c[2411716]=Q;c[2414258]=Q;if((c[3542200]|0)==0){R=1;i=e;return R|0}Q=L+108|0;c[Q>>2]=0;S=L+100|0;c[S>>2]=0;T=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[T&16383](L,0)|0;do{if((c[Q>>2]|0)!=0){T=c[S>>2]|0;c[M>>2]=9534384;U=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[U&16383](M,0,0)|0;if((T|0)<1){R=1;i=e;return R|0}if((gzL(N,0,0)|0)==0){break}else{R=1}i=e;return R|0}}while(0);N=(c[3529244]|0)+8192|0;if((c[3542200]|0)==0){R=1;i=e;return R|0}S=J+108|0;c[S>>2]=0;Q=J+100|0;c[Q>>2]=0;T=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[T&16383](J,1)|0;do{if((c[S>>2]|0)!=0){T=c[Q>>2]|0;c[K>>2]=9534384;U=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[U&16383](K,1,0)|0;if((T|0)<1){R=1;i=e;return R|0}if((gzL(N,0,1)|0)==0){break}else{R=1}i=e;return R|0}}while(0);N=(c[3529244]|0)+16384|0;if((c[3542200]|0)==0){R=1;i=e;return R|0}Q=H+108|0;c[Q>>2]=0;S=H+100|0;c[S>>2]=0;T=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[T&16383](H,2)|0;do{if((c[Q>>2]|0)!=0){T=c[S>>2]|0;c[I>>2]=9534384;U=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[U&16383](I,2,0)|0;if((T|0)<1){R=1;i=e;return R|0}if((gzL(N,0,2)|0)==0){break}else{R=1}i=e;return R|0}}while(0);N=c[3529200]|0;if((c[3542200]|0)==0){R=1;i=e;return R|0}S=F+108|0;c[S>>2]=0;Q=F+100|0;c[Q>>2]=0;T=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[T&16383](F,3)|0;do{if((c[S>>2]|0)!=0){T=c[Q>>2]|0;c[G>>2]=9534384;U=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[U&16383](G,3,0)|0;if((T|0)<1){R=1;i=e;return R|0}if((gzL(N,0,3)|0)==0){break}else{R=1}i=e;return R|0}}while(0);N=(c[3529200]|0)+16384|0;if((c[3542200]|0)==0){R=1;i=e;return R|0}Q=D+108|0;c[Q>>2]=0;S=D+100|0;c[S>>2]=0;T=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[T&16383](D,4)|0;do{if((c[Q>>2]|0)!=0){T=c[S>>2]|0;c[E>>2]=9534384;U=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[U&16383](E,4,0)|0;if((T|0)<1){R=1;i=e;return R|0}if((gzL(N,0,4)|0)==0){break}else{R=1}i=e;return R|0}}while(0);N=c[3530864]|0;if((c[3542200]|0)==0){R=1;i=e;return R|0}S=B+108|0;c[S>>2]=0;Q=B+100|0;c[Q>>2]=0;T=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[T&16383](B,7)|0;do{if((c[S>>2]|0)!=0){T=c[Q>>2]|0;c[C>>2]=9534384;U=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[U&16383](C,7,0)|0;if((T|0)<1){R=1;i=e;return R|0}if((gzL(N,0,7)|0)==0){break}else{R=1}i=e;return R|0}}while(0);N=(c[3530864]|0)+8192|0;if((c[3542200]|0)==0){R=1;i=e;return R|0}Q=z+108|0;c[Q>>2]=0;S=z+100|0;c[S>>2]=0;T=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[T&16383](z,6)|0;do{if((c[Q>>2]|0)!=0){T=c[S>>2]|0;c[A>>2]=9534384;U=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[U&16383](A,6,0)|0;if((T|0)<1){R=1;i=e;return R|0}if((gzL(N,0,6)|0)==0){break}else{R=1}i=e;return R|0}}while(0);N=(c[3530864]|0)+16384|0;if((c[3542200]|0)==0){R=1;i=e;return R|0}S=x+108|0;c[S>>2]=0;Q=x+100|0;c[Q>>2]=0;T=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[T&16383](x,5)|0;do{if((c[S>>2]|0)!=0){T=c[Q>>2]|0;c[y>>2]=9534384;U=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[U&16383](y,5,0)|0;if((T|0)<1){R=1;i=e;return R|0}if((gzL(N,0,5)|0)==0){break}else{R=1}i=e;return R|0}}while(0);N=c[3530628]|0;if((c[3542200]|0)==0){R=1;i=e;return R|0}Q=v+108|0;c[Q>>2]=0;S=v+100|0;c[S>>2]=0;T=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[T&16383](v,8)|0;do{if((c[Q>>2]|0)!=0){T=c[S>>2]|0;c[w>>2]=9534384;U=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[U&16383](w,8,0)|0;if((T|0)<1){R=1;i=e;return R|0}if((gzL(N,0,8)|0)==0){break}else{R=1}i=e;return R|0}}while(0);N=(c[3530628]|0)+8192|0;if((c[3542200]|0)==0){R=1;i=e;return R|0}S=t+108|0;c[S>>2]=0;Q=t+100|0;c[Q>>2]=0;T=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[T&16383](t,9)|0;do{if((c[S>>2]|0)!=0){T=c[Q>>2]|0;c[u>>2]=9534384;U=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[U&16383](u,9,0)|0;if((T|0)<1){R=1;i=e;return R|0}if((gzL(N,0,9)|0)==0){break}else{R=1}i=e;return R|0}}while(0);N=(c[3530628]|0)+16384|0;if((c[3542200]|0)==0){R=1;i=e;return R|0}Q=r+108|0;c[Q>>2]=0;S=r+100|0;c[S>>2]=0;T=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[T&16383](r,10)|0;do{if((c[Q>>2]|0)!=0){T=c[S>>2]|0;c[s>>2]=9534384;U=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[U&16383](s,10,0)|0;if((T|0)<1){R=1;i=e;return R|0}if((gzL(N,0,10)|0)==0){break}else{R=1}i=e;return R|0}}while(0);N=c[3531010]|0;if((c[3542200]|0)==0){R=1;i=e;return R|0}S=p+108|0;c[S>>2]=0;Q=p+100|0;c[Q>>2]=0;T=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[T&16383](p,11)|0;do{if((c[S>>2]|0)!=0){T=c[Q>>2]|0;c[q>>2]=9534384;U=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[U&16383](q,11,0)|0;if((T|0)<1){R=1;i=e;return R|0}if((gzL(N,0,11)|0)==0){break}else{R=1}i=e;return R|0}}while(0);N=(c[3531010]|0)+256|0;if((c[3542200]|0)==0){R=1;i=e;return R|0}Q=n+108|0;c[Q>>2]=0;S=n+100|0;c[S>>2]=0;T=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[T&16383](n,12)|0;do{if((c[Q>>2]|0)!=0){T=c[S>>2]|0;c[o>>2]=9534384;U=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[U&16383](o,12,0)|0;if((T|0)<1){R=1;i=e;return R|0}if((gzL(N,0,12)|0)==0){break}else{R=1}i=e;return R|0}}while(0);N=(c[3531010]|0)+512|0;if((c[3542200]|0)==0){R=1;i=e;return R|0}S=l+108|0;c[S>>2]=0;Q=l+100|0;c[Q>>2]=0;T=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[T&16383](l,13)|0;do{if((c[S>>2]|0)!=0){T=c[Q>>2]|0;c[m>>2]=9534384;U=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[U&16383](m,13,0)|0;if((T|0)<1){R=1;i=e;return R|0}if((gzL(N,0,13)|0)==0){break}else{R=1}i=e;return R|0}}while(0);N=(c[3531010]|0)+768|0;if((c[3542200]|0)==0){R=1;i=e;return R|0}Q=j+108|0;c[Q>>2]=0;S=j+100|0;c[S>>2]=0;T=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[T&16383](j,14)|0;do{if((c[Q>>2]|0)!=0){T=c[S>>2]|0;c[k>>2]=9534384;U=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[U&16383](k,14,0)|0;if((T|0)<1){R=1;i=e;return R|0}if((gzL(N,0,14)|0)==0){break}else{R=1}i=e;return R|0}}while(0);N=(c[3531010]|0)+1280|0;if((c[3542200]|0)==0){R=1;i=e;return R|0}S=f+108|0;c[S>>2]=0;Q=f+100|0;c[Q>>2]=0;T=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[T&16383](f,15)|0;do{if((c[S>>2]|0)==0){V=0}else{T=c[Q>>2]|0;c[g>>2]=9534384;U=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[U&16383](g,15,0)|0;if((T|0)<1){R=1;i=e;return R|0}if((gzL(N,0,15)|0)==0){V=0;break}else{R=1}i=e;return R|0}}while(0);while(1){if((V|0)>=1024){break}W=9638528+(V<<2)|0;if((c[W>>2]|0)==0){P=15324;break}else{V=V+1|0}}L20222:do{if((P|0)==15324){N=gGq(24576)|0;c[W>>2]=N;if((N|0)==0){break}gGz(N|0,0,24576);Q=c[3530864]|0;gGC(N|0,Q|0,24576)|0;S=0;do{T=S<<8;gGz(Q+T|0,0,256);U=0;do{X=T+(c[609008+(U<<2)>>2]|0)|0;Y=(U<<4)+T|0;Z=0;do{_=X+(c[610384+(Z<<2)>>2]|0)|0;if(((d[N+((_|0)/8|0)|0]|0)&128>>>((_&7)>>>0)|0)!=0){_=Q+(Y+Z)|0;a[_]=a[_]|4}Z=Z+1|0;}while((Z|0)<16);U=U+1|0;}while((U|0)<16);U=T+65536|0;Z=0;do{Y=U+(c[609008+(Z<<2)>>2]|0)|0;X=(Z<<4)+T|0;_=0;do{$=Y+(c[610384+(_<<2)>>2]|0)|0;if(((d[N+(($|0)/8|0)|0]|0)&128>>>(($&7)>>>0)|0)!=0){$=Q+(X+_)|0;a[$]=a[$]|2}_=_+1|0;}while((_|0)<16);Z=Z+1|0;}while((Z|0)<16);Z=T+131072|0;U=0;do{_=Z+(c[609008+(U<<2)>>2]|0)|0;X=(U<<4)+T|0;Y=0;do{$=_+(c[610384+(Y<<2)>>2]|0)|0;if(((d[N+(($|0)/8|0)|0]|0)&128>>>(($&7)>>>0)|0)!=0){$=Q+(X+Y)|0;a[$]=a[$]|1}Y=Y+1|0;}while((Y|0)<16);U=U+1|0;}while((U|0)<16);S=S+1|0;}while((S|0)<256);S=c[3530628]|0;gGC(N|0,S|0,24576)|0;Q=0;while(1){U=Q<<6;gGz(S+U|0,0,64);T=0;do{Z=U+(c[609008+(T<<2)>>2]|0)|0;Y=(T<<3)+U|0;X=0;do{_=Z+(c[610384+(X<<2)>>2]|0)|0;if(((d[N+((_|0)/8|0)|0]|0)&128>>>((_&7)>>>0)|0)!=0){_=S+(Y+X)|0;a[_]=a[_]|4}X=X+1|0;}while((X|0)<8);T=T+1|0;}while((T|0)<8);T=U+65536|0;X=0;do{Y=T+(c[609008+(X<<2)>>2]|0)|0;Z=(X<<3)+U|0;_=0;do{$=Y+(c[610384+(_<<2)>>2]|0)|0;if(((d[N+(($|0)/8|0)|0]|0)&128>>>(($&7)>>>0)|0)!=0){$=S+(Z+_)|0;a[$]=a[$]|2}_=_+1|0;}while((_|0)<8);X=X+1|0;}while((X|0)<8);X=U+131072|0;T=0;do{_=X+(c[609008+(T<<2)>>2]|0)|0;Z=(T<<3)+U|0;Y=0;do{$=_+(c[610384+(Y<<2)>>2]|0)|0;if(((d[N+(($|0)/8|0)|0]|0)&128>>>(($&7)>>>0)|0)!=0){$=S+(Z+Y)|0;a[$]=a[$]|1}Y=Y+1|0;}while((Y|0)<8);T=T+1|0;}while((T|0)<8);T=Q+1|0;if((T|0)<1024){Q=T}else{aa=0;break}}while(1){if((aa|0)>=1024){break L20222}ab=9638528+(aa<<2)|0;if((c[ab>>2]|0)==(N|0)){break}else{aa=aa+1|0}}gGr(N);c[ab>>2]=0}}while(0);Q=c[3531010]|0;S=c[3530046]|0;T=0;do{U=a[Q+T|0]&15;X=a[Q+(T+256)|0]&15;Y=a[Q+(T+512)|0]&15;c[S+(T<<2)>>2]=U<<20|U<<16|X<<12|X<<8|Y|Y<<4;T=T+1|0;}while((T|0)<256);T=c[2406942]|0;Y=0;do{c[T+(Y<<2)>>2]=c[S+((d[Q+(Y+768)|0]|0)<<2)>>2];Y=Y+1|0;}while((Y|0)<1024);a[9547568]=1;fwR(0);Y=c[2439330]|0;Q=(Y|0)==0;if(!Q){S=Y;gGC(9706056,S|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];S=c[3528484]|0;c[2076596]=S;T=c[2417276]|0;c[3541536]=T;c[1836236]=0;X=c[3529244]|0;U=0;Z=0;while(1){c[Y+76+(Z<<2)>>2]=X+(Z<<8);_=U+1&65535;if((_&65535)>95){ac=0;ad=0;break}else{U=_;Z=_&65535}}while(1){Z=X+(ad<<8)|0;c[Y+76+(ad+512<<2)>>2]=Z;c[Y+76+(ad+768<<2)>>2]=Z;Z=ac+1&65535;if((Z&65535)>95){break}else{ac=Z;ad=Z&65535}}X=c[3529332]|0;c[Y+844>>2]=X;Z=X+256|0;c[Y+848>>2]=Z;U=X+512|0;c[Y+852>>2]=U;_=X+768|0;c[Y+856>>2]=_;$=X+1024|0;c[Y+860>>2]=$;ae=X+1280|0;c[Y+864>>2]=ae;af=X+1536|0;c[Y+868>>2]=af;ah=X+1792|0;c[Y+872>>2]=ah;c[Y+1868>>2]=X;c[Y+1872>>2]=Z;c[Y+1876>>2]=U;c[Y+1880>>2]=_;c[Y+1884>>2]=$;c[Y+1888>>2]=ae;c[Y+1892>>2]=af;c[Y+1896>>2]=ah;c[Y+2892>>2]=X;c[Y+3916>>2]=X;c[Y+2896>>2]=Z;c[Y+3920>>2]=Z;c[Y+2900>>2]=U;c[Y+3924>>2]=U;c[Y+2904>>2]=_;c[Y+3928>>2]=_;c[Y+2908>>2]=$;c[Y+3932>>2]=$;c[Y+2912>>2]=ae;c[Y+3936>>2]=ae;c[Y+2916>>2]=af;c[Y+3940>>2]=af;c[Y+2920>>2]=ah;c[Y+3944>>2]=ah;ah=c[2386478]|0;c[Y+876>>2]=ah;af=ah+256|0;c[Y+880>>2]=af;ae=ah+512|0;c[Y+884>>2]=ae;$=ah+768|0;c[Y+888>>2]=$;_=ah+1024|0;c[Y+892>>2]=_;U=ah+1280|0;c[Y+896>>2]=U;Z=ah+1536|0;c[Y+900>>2]=Z;X=ah+1792|0;c[Y+904>>2]=X;c[Y+1900>>2]=ah;c[Y+1904>>2]=af;c[Y+1908>>2]=ae;c[Y+1912>>2]=$;c[Y+1916>>2]=_;c[Y+1920>>2]=U;c[Y+1924>>2]=Z;c[Y+1928>>2]=X;c[Y+2924>>2]=ah;c[Y+3948>>2]=ah;c[Y+2928>>2]=af;c[Y+3952>>2]=af;c[Y+2932>>2]=ae;c[Y+3956>>2]=ae;c[Y+2936>>2]=$;c[Y+3960>>2]=$;c[Y+2940>>2]=_;c[Y+3964>>2]=_;c[Y+2944>>2]=U;c[Y+3968>>2]=U;c[Y+2948>>2]=Z;c[Y+3972>>2]=Z;c[Y+2952>>2]=X;c[Y+3976>>2]=X;X=c[2386226]|0;c[Y+908>>2]=X;Z=X+256|0;c[Y+912>>2]=Z;U=X+512|0;c[Y+916>>2]=U;_=X+768|0;c[Y+920>>2]=_;$=X+1024|0;c[Y+924>>2]=$;ae=X+1280|0;c[Y+928>>2]=ae;af=X+1536|0;c[Y+932>>2]=af;ah=X+1792|0;c[Y+936>>2]=ah;c[Y+1932>>2]=X;c[Y+1936>>2]=Z;c[Y+1940>>2]=U;c[Y+1944>>2]=_;c[Y+1948>>2]=$;c[Y+1952>>2]=ae;c[Y+1956>>2]=af;c[Y+1960>>2]=ah;c[Y+2956>>2]=X;c[Y+3980>>2]=X;c[Y+2960>>2]=Z;c[Y+3984>>2]=Z;c[Y+2964>>2]=U;c[Y+3988>>2]=U;c[Y+2968>>2]=_;c[Y+3992>>2]=_;c[Y+2972>>2]=$;c[Y+3996>>2]=$;c[Y+2976>>2]=ae;c[Y+4e3>>2]=ae;c[Y+2980>>2]=af;c[Y+4004>>2]=af;c[Y+2984>>2]=ah;c[Y+4008>>2]=ah;ah=c[3527308]|0;c[Y+940>>2]=ah;af=ah+256|0;c[Y+944>>2]=af;ae=ah+512|0;c[Y+948>>2]=ae;$=ah+768|0;c[Y+952>>2]=$;_=ah+1024|0;c[Y+956>>2]=_;U=ah+1280|0;c[Y+960>>2]=U;Z=ah+1536|0;c[Y+964>>2]=Z;X=ah+1792|0;c[Y+968>>2]=X;c[Y+1964>>2]=ah;c[Y+1968>>2]=af;c[Y+1972>>2]=ae;c[Y+1976>>2]=$;c[Y+1980>>2]=_;c[Y+1984>>2]=U;c[Y+1988>>2]=Z;c[Y+1992>>2]=X;c[Y+2988>>2]=ah;c[Y+4012>>2]=ah;c[Y+2992>>2]=af;c[Y+4016>>2]=af;c[Y+2996>>2]=ae;c[Y+4020>>2]=ae;c[Y+3e3>>2]=$;c[Y+4024>>2]=$;c[Y+3004>>2]=_;c[Y+4028>>2]=_;c[Y+3008>>2]=U;c[Y+4032>>2]=U;c[Y+3012>>2]=Z;c[Y+4036>>2]=Z;c[Y+3016>>2]=X;c[Y+4040>>2]=X;c[Y+4184>>2]=2334;c[Y+4180>>2]=292;if(!Q){X=Y;gGC(X|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=S;c[2417276]=T;c[1836236]=-1;fwR(1);X=c[2439331]|0;Z=(X|0)==0;if(!Z){U=X;gGC(9706056,U|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];U=c[3528485]|0;c[2076596]=U;_=c[2417277]|0;c[3541536]=_;c[1836236]=1;$=c[3529200]|0;ae=0;af=0;while(1){c[X+76+(af<<2)>>2]=$+(af<<8);ah=ae+1&65535;if((ah&65535)>95){ai=0;aj=0;break}else{ae=ah;af=ah&65535}}while(1){af=$+(aj<<8)|0;c[X+76+(aj+512<<2)>>2]=af;c[X+76+(aj+768<<2)>>2]=af;af=ai+1&65535;if((af&65535)>95){break}else{ai=af;aj=af&65535}}$=c[3527308]|0;c[X+588>>2]=$;af=$+256|0;c[X+592>>2]=af;ae=$+512|0;c[X+596>>2]=ae;T=$+768|0;c[X+600>>2]=T;S=$+1024|0;c[X+604>>2]=S;Y=$+1280|0;c[X+608>>2]=Y;Q=$+1536|0;c[X+612>>2]=Q;ah=$+1792|0;c[X+616>>2]=ah;c[X+1612>>2]=$;c[X+1616>>2]=af;c[X+1620>>2]=ae;c[X+1624>>2]=T;c[X+1628>>2]=S;c[X+1632>>2]=Y;c[X+1636>>2]=Q;c[X+1640>>2]=ah;c[X+2636>>2]=$;c[X+3660>>2]=$;c[X+2640>>2]=af;c[X+3664>>2]=af;c[X+2644>>2]=ae;c[X+3668>>2]=ae;c[X+2648>>2]=T;c[X+3672>>2]=T;c[X+2652>>2]=S;c[X+3676>>2]=S;c[X+2656>>2]=Y;c[X+3680>>2]=Y;c[X+2660>>2]=Q;c[X+3684>>2]=Q;c[X+2664>>2]=ah;c[X+3688>>2]=ah;c[X+4184>>2]=74;if(!Z){ah=X;gGC(ah|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=U;c[2417277]=_;c[1836236]=-1;TS(0,4e6,32768,6,0,0);TS(1,4e6,32768,6,0,1);ah=c[2420348]|0;h[ah+192>>3]=.75;c[ah+200>>2]=3;ah=c[2420346]|0;h[ah+192>>3]=.75;c[ah+200>>2]=3;ah=c[642608+(c[2436]<<2)>>2]|0;Q=c[ah+128>>2]|0;if((c[ah+52>>2]&4|0)==0){c[2113068]=Q;Y=c[ah+132>>2]|0;c[2113070]=Y;c[2443814]=Q;c[2440436]=Y;ak=Q;al=Y}else{c[2113070]=Q;Y=c[ah+132>>2]|0;c[2113068]=Y;c[2440436]=Q;c[2443814]=Y;ak=Y;al=Q}Q=ag(ak<<1,al)|0;Y=gGq(Q)|0;c[2112926]=Y;if((Y|0)!=0){gGz(Y|0,0,Q|0)}Q=c[2414698]|0;gGz(Q|0,0,(c[2411716]|0)-Q|0);Q=c[2439330]|0;Y=(Q|0)==0;if(!Y){ah=Q;gGC(9706056,ah|0,76)|0}ah=c[2438118]|0;c[2433530]=ah;S=c[3528484]|0;c[2076596]=S;T=c[2417276]|0;c[3541536]=T;c[1836236]=0;gGz(9706056,0,76);if(!Y){Y=Q;gGC(Y|0,9706056,76)|0}c[2438118]=ah;c[3528484]=S;c[2417276]=T;c[1836236]=-1;T=c[2439331]|0;S=(T|0)==0;if(!S){ah=T;gGC(9706056,ah|0,76)|0}ah=c[2438119]|0;c[2433530]=ah;Y=c[3528485]|0;c[2076596]=Y;Q=c[2417277]|0;c[3541536]=Q;c[1836236]=1;gGz(9706056,0,76);if(!S){S=T;gGC(S|0,9706056,76)|0}c[2438119]=ah;c[3528485]=Y;c[2417277]=Q;c[1836236]=-1;a[14114864]=0;R=0;i=e;return R|0}}while(0);c[2414994]=0;R=1;i=e;return R|0}function dNs(){var a=0,b=0,d=0,e=0;c[2113070]=0;c[2113068]=0;a=c[2112926]|0;if((a|0)!=0){gGr(a);c[2112926]=0}fwZ();TT();a=c[2414994]|0;b=0;while(1){if((b|0)>=1024){d=15459;break}e=9638528+(b<<2)|0;if((c[e>>2]|0)==(a|0)){break}else{b=b+1|0}}if((d|0)==15459){c[2414994]=0;return 0}gGr(a);c[e>>2]=0;c[2414994]=0;return 0}function dNt(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((a[9624408]|0)!=0){d=c[2414698]|0;gGz(d|0,0,(c[2411716]|0)-d|0);d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;h=c[2417276]|0;c[3541536]=h;c[1836236]=0;gGz(9706056,0,76);if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=h;c[1836236]=-1;h=c[2439331]|0;g=(h|0)==0;if(!g){f=h;gGC(9706056,f|0,76)|0}f=c[2438119]|0;c[2433530]=f;e=c[3528485]|0;c[2076596]=e;d=c[2417277]|0;c[3541536]=d;c[1836236]=1;gGz(9706056,0,76);if(!g){g=h;gGC(g|0,9706056,76)|0}c[2438119]=f;c[3528485]=e;c[2417277]=d;c[1836236]=-1;a[14114864]=0}d=c[2385548]|0;if((d|0)>0){gGz(9752472,0,((d|0)>1?d<<2:4)|0)}c[2433530]=0;gGz(9550608,0,3);d=0;e=0;f=0;g=0;do{e=((a[9633816+d|0]&1)<<d^e&255)&255;f=((a[9631616+d|0]&1)<<d^f&255)&255;g=((a[9629640+d|0]&1)<<d^g&255)&255;d=d+1|0;}while((d|0)<8);a[9550608]=e;a[9550609]=f;a[9550610]=g;g=0;do{f=c[2439330]|0;if((f|0)!=0){e=f;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;e=c[2438118]|0;c[2433530]=e;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;if((a[f+4188|0]|0)==0){f=gfc(6666)|0;i=(c[2433530]|0)+f|0}else{i=e+6666|0}c[2433530]=i;if((g|0)==9){j=15481;break}e=c[1836236]|0;f=c[9757320+(e<<2)>>2]|0;if((f|0)!=0){d=f;gGC(d|0,9706056,76)|0}c[9752472+(e<<2)>>2]=i;c[14113936+(e<<2)>>2]=c[2076596];c[9669104+(e<<2)>>2]=c[3541536];c[1836236]=-1;e=c[2439331]|0;if((e|0)!=0){d=e;gGC(9706056,d|0,76)|0}b[4853030]=c[2426515]&65535;d=c[2438119]|0;c[2433530]=d;c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;if((a[e+4188|0]|0)==0){f=gfc(6666)|0;h=c[1836236]|0;k=(c[2433530]|0)+f|0;l=h;m=c[9757320+(h<<2)>>2]|0}else{k=d+6666|0;l=1;m=e}c[2433530]=k;if((m|0)!=0){e=m;gGC(e|0,9706056,76)|0}c[9752472+(l<<2)>>2]=k;c[14113936+(l<<2)>>2]=c[2076596];c[9669104+(l<<2)>>2]=c[3541536];c[1836236]=-1;g=g+1|0;}while((g|0)<10);if((j|0)==15481){a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0;j=c[1836236]|0;g=c[9757320+(j<<2)>>2]|0;if((g|0)!=0){l=g;gGC(l|0,9706056,76)|0}c[9752472+(j<<2)>>2]=c[2433530];c[14113936+(j<<2)>>2]=c[2076596];c[9669104+(j<<2)>>2]=c[3541536];c[1836236]=-1;j=c[2439331]|0;if((j|0)!=0){l=j;gGC(9706056,l|0,76)|0}b[4853030]=c[2426515]&65535;l=c[2438119]|0;c[2433530]=l;c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;if((a[j+4188|0]|0)==0){j=gfc(6666)|0;n=(c[2433530]|0)+j|0}else{n=l+6666|0}c[2433530]=n;a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0;n=c[1836236]|0;l=c[9757320+(n<<2)>>2]|0;if((l|0)!=0){j=l;gGC(j|0,9706056,76)|0}c[9752472+(n<<2)>>2]=c[2433530];c[14113936+(n<<2)>>2]=c[2076596];c[9669104+(n<<2)>>2]=c[3541536];c[1836236]=-1}n=c[2112964]|0;if((n|0)!=0){j=a[9688]|0?534:0;TQ(0,n,j);TQ(1,n,j)}if((c[2112968]|0)==0){return 0}dNu()|0;return 0}function dNu(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;if((a[9547568]|0)!=0){e=c[2406942]|0;f=c[3530046]|0;g=0;do{h=c[e+(g<<2)>>2]|0;c[f+(g<<2)>>2]=h>>>8&2016|h&31|h>>16<<8&63488;g=g+1|0;}while((g|0)<1024);a[9547568]=0}g=c[2408998]|0;f=g+1|0;e=c[2386226]|0;h=c[2112926]|0;i=c[3530628]|0;j=0;do{k=j>>5<<3;l=j<<3&248;if((l-32|0)>>>0<96){m=k-(d[g]|0)|0}else{m=k}if(l>>>0>127){n=m-(d[f]|0)|0}else{n=m}k=(n|0)<-7?n+256|0:n;o=j<<1;p=d[e+o|0]|0;q=p<<3&768|d[e+(o|1)|0];o=p>>>2&32|p&31;if((a[14114864]|0)==0){Sj(h,q,k-8|0,l-16|0,o,3,512,i)}else{Sp(h,q,240-k|0,232-l|0,o,3,512,i)}j=j+1|0;}while((j|0)<1024);j=c[2386478]|0;i=(a[14114864]|0)==0;e=c[3530864]|0;n=c[3531010]|0;m=i?0:255;f=c[2113070]|0;g=c[2113068]|0;o=96;do{l=d[j+o|0]|0;k=d[j+(o|3)|0]|0;if(i){r=k+254|0;s=240-l|0}else{r=240-k|0;s=l}l=r&255;k=d[j+(o|2)|0]<<3&504;q=(l>>>0>248?r|-256:l)-8|0;l=d[j+(o|1)|0]<<8;p=s-16|0;t=0;while(1){if((p|0)>-1&(p|0)<(f|0)){u=t<<4;v=ag(g,p)|0;w=q;x=0;while(1){do{if((w|0)>=0&(w|0)<(g|0)){y=d[e+((x+u^m)+l)|0]|k;if((a[n+(y+768)|0]|0)==0){break}b[h+(v+w<<1)>>1]=y&65535}}while(0);y=x+1|0;if((y|0)<16){w=w+1|0;x=y}else{break}}}x=t+1|0;if((x|0)>=16){break}p=p+1|0;t=x}o=o+4|0;}while((o|0)<256);R8(c[3530046]|0);return 0}function dNv(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=i;i=i+32|0;e=d|0;f=d+16|0;if((b|0)!=0){c[b>>2]=169735}if((a&96|0)==0){i=d;return 0}gGz(f|0,0,12);b=c[2414698]|0;c[f>>2]=b;c[f+4>>2]=(c[2411716]|0)-b;c[f+12>>2]=162152;gj[c[2076592]&4095](f)|0;fw$(a);gGz(e|0,0,12);c[e>>2]=14114864;c[e+4>>2]=1;c[e+12>>2]=142288;gj[c[2076592]&4095](e)|0;i=d;return 0}function dNw(b){b=b|0;var d=0,e=0;d=b&65535;if((b+16384&65535)<2048){e=a[(c[2439618]|0)+(d-49152+((a[9730904]|0)!=0?2048:0))|0]|0;return e|0}if((b+12288&65535)>=4096){e=0;return e|0}b=d-53248|0;if((a[9773432]|0)==0){e=a[(c[3527218]|0)+b|0]|0;return e|0}else{e=a[(c[2443418]|0)+b|0]|0;return e|0}return 0}function dNx(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((b+16384&65535)<2048){a[(c[2439618]|0)+(e-49152+((a[9730904]|0)!=0?2048:0))|0]=d;return}if((b+12288&65535)>=4096){return}b=e-53248|0;if((a[9773432]|0)==0){a[(c[3527218]|0)+b|0]=d;return}else{a[(c[2443418]|0)+b|0]=d;return}}function dNy(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0;switch(b&255|0){case 0:{f=~a[9625792];return f|0};case 2:{b=d[9774160]|0;if((b|0)==1){g=15590}else if((b|0)!=2){f=~a[9625794];return f|0}do{if((g|0)==15590){b=c[2429764]|0;if((b&128|0)!=0){f=~a[9625799];return f|0}if((b&64|0)!=0){f=~a[9625800];return f|0}if((b&32|0)!=0){f=~a[9625801];return f|0}if((b&16|0)!=0){f=~a[9625802];return f|0}if((b&8|0)==0){break}f=~a[9625803];return f|0}}while(0);if((a[9751072]|0)==0){b=a[9625794]&247^247;if(!(a[606600]|0)){f=b&255;return f|0}f=(b|8)&255;return f|0}b=(e[4813024]|0)-(c[2408943]|0)|0;h=b&255;do{if((b&128|0)==0){if((h|0)==0){i=0;break}if(a[606600]|0){i=h;break}a[606600]=1;i=0}else{if(!(a[606600]|0)){i=-b&255;break}a[606600]=0;i=0}}while(0);f=i>>>0>63?-4:i<<2&255;return f|0};case 1:{i=d[9774160]|0;if((i|0)==1){g=15568}else if((i|0)!=2){f=~a[9625793];return f|0}do{if((g|0)==15568){i=c[2429764]|0;if((i&128|0)!=0){f=~a[9625793];return f|0}if((i&64|0)!=0){f=~a[9625794];return f|0}if((i&32|0)!=0){f=~a[9625796];return f|0}if((i&16|0)!=0){f=~a[9625797];return f|0}if((i&8|0)==0){break}f=~a[9625798];return f|0}}while(0);if((a[9751072]|0)==0){g=a[9625793]&247^247;if(!(a[606608]|0)){f=g&255;return f|0}f=(g|8)&255;return f|0}g=(e[4813028]|0)-(c[2408942]|0)|0;i=g&255;do{if((g&128|0)==0){if((i|0)==0){j=0;break}if(a[606608]|0){j=i;break}a[606608]=1;j=0}else{if(!(a[606608]|0)){j=-g&255;break}a[606608]=0;j=0}}while(0);f=j>>>0>63?-4:j<<2&255;return f|0};case 3:{f=a[9657984]|0;return f|0};case 4:{f=a[9657985]|0;return f|0};case 5:{do{if(a[6939736]|0){if((c[2406632]|0)!=0){k=(c[2432962]|0)>>>((c[(c[2420380]|0)+4>>2]|0)>>>0)<<7&128;break}j=c[2443744]|0;if((j|0)<=0){k=128;break}c[2443744]=j-1;k=0}else{k=128}}while(0);j=((a[9751048]|0)==0?8:1)|k;f=(((a[5450472]|0?j^8:j)|a[9625795]&118)^118)&255;return f|0};default:{f=-1;return f|0}}return 0}function dNz(e,f){e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;switch(e&255|0){case 16:{if(!(a[6939736]|0)){return}Tr(f<<24>>24==0|0);return};case 8:{if(!(a[6939736]|0)){return}e=f<<24>>24==0;c[3528406]=e&1;if(!e){return}c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];return};case 5:{Uv(0,f);return};case 0:{a[9759712]=f&4;e=f&16;do{if((d[14121024]|0)!=(e|0)){g=e&255;a[14121024]=g;h=c[3541206]|0;i=c[3527282]|0;if(g<<24>>24==0){gGC(h|0,i|0,262144)|0;break}else{g=i+262144|0;gGC(h|0,g|0,262144)|0;break}}}while(0);a[9730904]=f&32;return};case 3:{e=c[3540990]|0;g=c[e+1868>>2]|0;if((g|0)!=0){gg[g&4095](c[e+1872>>2]|0,0)}ms(e,d[e+5972|0]|0,f&255);return};case 24:{if(!(a[6939736]|0)){return}c[2415256]=f&255;return};case 7:{a[9773432]=f;return};case 2:{e=f&15;a[14119320]=e;g=c[2385838]|0;h=(e&255)<<14;e=c[9757320+(c[1836236]<<2)>>2]|0;i=h+32768|0;j=128;k=128;while(1){c[e+76+(k<<2)>>2]=g+(i+(k<<8));l=j+1&65535;if((l&65535)>191){break}else{j=l;k=l&65535}}if(!(a[6939736]|0)){k=128;j=128;while(1){l=g+(i+(j<<8))|0;c[e+76+(j+512<<2)>>2]=l;c[e+76+(j+768<<2)>>2]=l;l=k+1&65535;if((l&65535)>191){break}else{k=l;j=l&65535}}return}j=c[3529358]|0;k=128;i=128;while(1){l=(i<<8)+h+32768|0;c[e+76+(i+512<<2)>>2]=j+l;c[e+76+(i+768<<2)>>2]=g+l;l=k+1&65535;if((l&65535)>191){break}else{k=l;i=l&65535}}return};case 1:{i=d[9774160]|0;if((i|0)==1){c[2429764]=f&255;return}else if((i|0)==2){if((f<<24>>24|0)==(-128|0)){a[9751072]=0;return}else if((f<<24>>24|0)==8){c[2408942]=b[4813028]|0;c[2408943]=b[4813024]|0;return}else{a[9751072]=1;return}}else{return}break};case 4:{a[(c[3540990]|0)+5972|0]=f;return};default:{return}}}function dNA(b){b=b|0;var c=0;switch(b&255|0){case 0:{c=~a[9625792];break};case 3:{c=a[9657984]|0;break};case 1:{c=-2-(a[9625793]|0)&255;break};case 5:{c=~a[9625795];break};case 2:{c=-2-(a[9625794]|0)&255;break};default:{c=-1}}return c|0}function dNB(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=d&255;if((f|0)==0){a[9759712]=e&4;a[9730904]=e&32;return}else if((f|0)==2){d=e&15;a[14119320]=d;g=c[2385838]|0;h=(d&255)<<14;d=c[9757320+(c[1836236]<<2)>>2]|0;i=h+32768|0;j=128;k=128;while(1){c[d+76+(k<<2)>>2]=g+(i+(k<<8));l=j+1&65535;if((l&65535)>191){break}else{j=l;k=l&65535}}k=c[3529358]|0;j=128;i=128;while(1){l=(i<<8)+h+32768|0;c[d+76+(i+512<<2)>>2]=k+l;c[d+76+(i+768<<2)>>2]=g+l;l=j+1&65535;if((l&65535)>191){break}else{j=l;i=l&65535}}return}else if((f|0)==7){a[9773432]=e&1;return}else if((f|0)==3){a[9758184]=e;e=c[1836236]|0;f=c[9757320+(e<<2)>>2]|0;if((f|0)!=0){i=f;gGC(i|0,9706056,76)|0}c[9752472+(e<<2)>>2]=c[2433530];c[14113936+(e<<2)>>2]=c[2076596];c[9669104+(e<<2)>>2]=c[3541536];c[1836236]=-1;e=c[2439331]|0;i=(e|0)==0;if(!i){f=e;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;f=c[2438119]|0;c[2433530]=f;j=c[3528485]|0;c[2076596]=j;g=c[2417277]|0;c[3541536]=g;c[1836236]=1;a[9706117]=1;if(!i){i=e;gGC(i|0,9706056,76)|0}c[2438119]=f;c[3528485]=j;c[2417277]=g;c[1836236]=-1;g=c[2439330]|0;if((g|0)!=0){j=g;gGC(9706056,j|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;return}else{return}}function dNC(b){b=b|0;var d=0,e=0;d=b&65535;if((d|0)==38912){e=c[2113156]&255}else if((d|0)==40960){a[9706117]=0;e=a[9758184]|0}else{e=0}return e|0}function dND(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((e|0)==38912){Uv(0,d);return}else if((e|0)==36864){e=d&3;a[14121024]=e;d=c[3541206]|0;b=(c[3527282]|0)+((e&255)<<18)|0;gGC(d|0,b|0,262144)|0;return}else{return}}function dNE(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5279036+(b*112|0)>>2];c[a+104>>2]=c[5279040+(b*112|0)>>2];c[a+108>>2]=c[5279044+(b*112|0)>>2];d=0;return d|0}function dNF(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=5278936+(b*112|0);e=0;return e|0}function dNG(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>45){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1829336+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dNH(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>44){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5279944+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dNI(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0;e=i;i=i+1080|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;c[2426752]=0;c[2385838]=0;c[3541206]=327680;c[3527282]=589824;c[2405678]=1114112;c[2385856]=1114112;c[2439618]=1118208;c[3531098]=1120256;c[3527218]=1122304;c[2443418]=1126400;c[2411714]=1130496;c[2406524]=1130496;c[3529578]=5324800;c[3530044]=5849088;z=0;while(1){if((z|0)>=1024){break}A=9638528+(z<<2)|0;if((c[A>>2]|0)==0){B=15764;break}else{z=z+1|0}}do{if((B|0)==15764){z=gGq(5853184)|0;c[A>>2]=z;if((z|0)==0){break}c[2426752]=z;gGz(z|0,0,5853184);c[2385838]=z;c[3541206]=z+327680;c[3527282]=z+589824;C=z+1114112|0;c[2405678]=C;c[2385856]=C;c[2439618]=z+1118208;c[3531098]=z+1120256;c[3527218]=z+1122304;c[2443418]=z+1126400;C=z+1130496|0;c[2411714]=C;c[2406524]=C;c[3529578]=z+5324800;c[3530044]=z+5849088;c[2414256]=z+5853184;z=0;while(1){if((z|0)>=1024){D=0;break}E=9638528+(z<<2)|0;if((c[E>>2]|0)==0){B=15769;break}else{z=z+1|0}}do{if((B|0)==15769){z=gGq(2097152)|0;c[E>>2]=z;if((z|0)==0){D=0;break}gGz(z|0,0,2097152);D=z}}while(0);c[3529526]=D;z=c[2385838]|0;if((c[3542200]|0)==0){F=1;i=e;return F|0}C=x+108|0;c[C>>2]=0;G=x+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,0)|0;do{if((c[C>>2]|0)!=0){H=c[G>>2]|0;c[y>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](y,0,0)|0;if((H|0)<1){F=1;i=e;return F|0}if((gzL(z,0,0)|0)==0){break}else{F=1}i=e;return F|0}}while(0);z=(c[2385838]|0)+65536|0;if((c[3542200]|0)==0){F=1;i=e;return F|0}G=v+108|0;c[G>>2]=0;C=v+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,1)|0;do{if((c[G>>2]|0)!=0){H=c[C>>2]|0;c[w>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](w,1,0)|0;if((H|0)<1){F=1;i=e;return F|0}if((gzL(z,0,1)|0)==0){break}else{F=1}i=e;return F|0}}while(0);z=c[3529526]|0;gGz(z|0,-1|0,2097152);if((c[3542200]|0)==0){F=1;i=e;return F|0}C=t+108|0;c[C>>2]=0;G=t+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,2)|0;do{if((c[C>>2]|0)!=0){H=c[G>>2]|0;c[u>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](u,2,0)|0;if((H|0)<1){F=1;i=e;return F|0}if((gzL(z,0,2)|0)==0){break}else{F=1}i=e;return F|0}}while(0);z=(c[3529526]|0)+524288|0;if((c[3542200]|0)==0){F=1;i=e;return F|0}G=r+108|0;c[G>>2]=0;C=r+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,3)|0;do{if((c[G>>2]|0)!=0){H=c[C>>2]|0;c[s>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](s,3,0)|0;if((H|0)<1){F=1;i=e;return F|0}if((gzL(z,0,3)|0)==0){break}else{F=1}i=e;return F|0}}while(0);z=(c[3529526]|0)+1048576|0;if((c[3542200]|0)==0){F=1;i=e;return F|0}C=p+108|0;c[C>>2]=0;G=p+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,4)|0;do{if((c[C>>2]|0)!=0){H=c[G>>2]|0;c[q>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](q,4,0)|0;if((H|0)<1){F=1;i=e;return F|0}if((gzL(z,0,4)|0)==0){break}else{F=1}i=e;return F|0}}while(0);z=(c[3529526]|0)+1572864|0;if((c[3542200]|0)==0){F=1;i=e;return F|0}G=n+108|0;c[G>>2]=0;C=n+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,5)|0;do{if((c[G>>2]|0)!=0){H=c[C>>2]|0;c[o>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](o,5,0)|0;if((H|0)<1){F=1;i=e;return F|0}if((gzL(z,0,5)|0)==0){break}else{F=1}i=e;return F|0}}while(0);z=c[3529526]|0;C=c[2406524]|0;G=0;do{H=G<<6;gGz(C+H|0,0,64);I=G<<8;J=0;do{K=1<<3-J;L=(c[687256+(J<<2)>>2]|0)+I|0;M=0;do{N=L+(c[1183816+(M<<2)>>2]|0)|0;O=(M<<3)+H|0;P=0;do{Q=N+(c[809240+(P<<2)>>2]|0)|0;if(((d[z+((Q|0)/8|0)|0]|0)&128>>>((Q&7)>>>0)|0)!=0){Q=C+(O+P)|0;a[Q]=(d[Q]|0|K)&255}P=P+1|0;}while((P|0)<8);M=M+1|0;}while((M|0)<8);J=J+1|0;}while((J|0)<4);G=G+1|0;}while((G|0)<65536);gGz(z|0,-1|0,2097152);if((c[3542200]|0)==0){F=1;i=e;return F|0}G=l+108|0;c[G>>2]=0;C=l+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,6)|0;do{if((c[G>>2]|0)!=0){J=c[C>>2]|0;c[m>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](m,6,0)|0;if((J|0)<1){F=1;i=e;return F|0}if((gzL(z,0,6)|0)==0){break}else{F=1}i=e;return F|0}}while(0);z=(c[3529526]|0)+131072|0;if((c[3542200]|0)==0){F=1;i=e;return F|0}C=j+108|0;c[C>>2]=0;G=j+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,7)|0;do{if((c[C>>2]|0)!=0){J=c[G>>2]|0;c[k>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](k,7,0)|0;if((J|0)<1){F=1;i=e;return F|0}if((gzL(z,0,7)|0)==0){break}else{F=1}i=e;return F|0}}while(0);z=c[3529526]|0;G=c[3529578]|0;C=0;while(1){J=C<<8;gGz(G+J|0,0,256);H=C<<9;I=0;do{M=1<<3-I;K=(c[961472+(I<<2)>>2]|0)+H|0;L=0;do{P=K+(c[608544+(L<<2)>>2]|0)|0;O=(L<<4)+J|0;N=0;do{Q=P+(c[609552+(N<<2)>>2]|0)|0;if(((d[z+((Q|0)/8|0)|0]|0)&128>>>((Q&7)>>>0)|0)!=0){Q=G+(O+N)|0;a[Q]=(d[Q]|0|M)&255}N=N+1|0;}while((N|0)<16);L=L+1|0;}while((L|0)<16);I=I+1|0;}while((I|0)<4);I=C+1|0;if((I|0)<2048){C=I}else{R=0;break}}while(1){if((R|0)>=1024){break}S=9638528+(R<<2)|0;if((c[S>>2]|0)==(z|0)){B=15825;break}else{R=R+1|0}}if((B|0)==15825){gGr(z);c[S>>2]=0}c[3529526]=0;C=c[3527282]|0;if((c[3542200]|0)==0){F=1;i=e;return F|0}G=f+108|0;c[G>>2]=0;I=f+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,8)|0;do{if((c[G>>2]|0)!=0){J=c[I>>2]|0;c[g>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](g,8,0)|0;if((J|0)<1){F=1;i=e;return F|0}if((gzL(C,0,8)|0)==0){break}else{F=1}i=e;return F|0}}while(0);fwR(0);C=c[2439330]|0;I=(C|0)==0;if(!I){G=C;gGC(9706056,G|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];G=c[3528484]|0;c[2076596]=G;z=c[2417276]|0;c[3541536]=z;c[1836236]=0;c[C+4172>>2]=1424;c[C+4176>>2]=2902;J=c[2385838]|0;H=0;L=0;while(1){c[C+76+(L<<2)>>2]=J+(L<<8);M=H+1&65535;if((M&65535)>127){T=0;U=0;break}else{H=M;L=M&65535}}while(1){L=J+(U<<8)|0;c[C+76+(U+512<<2)>>2]=L;c[C+76+(U+768<<2)>>2]=L;L=T+1&65535;if((L&65535)>127){V=128;W=128;break}else{T=L;U=L&65535}}while(1){c[C+76+(W<<2)>>2]=J+((W<<8)+32768);L=V+1&65535;if((L&65535)>191){X=128;Y=128;break}else{V=L;W=L&65535}}while(1){L=J+((Y<<8)+32768)|0;c[C+76+(Y+512<<2)>>2]=L;c[C+76+(Y+768<<2)>>2]=L;L=X+1&65535;if((L&65535)>191){break}else{X=L;Y=L&65535}}J=c[2439618]|0;c[C+844>>2]=J;L=J+256|0;c[C+848>>2]=L;H=J+512|0;c[C+852>>2]=H;M=J+768|0;c[C+856>>2]=M;K=J+1024|0;c[C+860>>2]=K;N=J+1280|0;c[C+864>>2]=N;O=J+1536|0;c[C+868>>2]=O;P=J+1792|0;c[C+872>>2]=P;c[C+1868>>2]=J;c[C+1872>>2]=L;c[C+1876>>2]=H;c[C+1880>>2]=M;c[C+1884>>2]=K;c[C+1888>>2]=N;c[C+1892>>2]=O;c[C+1896>>2]=P;c[C+2892>>2]=J;c[C+3916>>2]=J;c[C+2896>>2]=L;c[C+3920>>2]=L;c[C+2900>>2]=H;c[C+3924>>2]=H;c[C+2904>>2]=M;c[C+3928>>2]=M;c[C+2908>>2]=K;c[C+3932>>2]=K;c[C+2912>>2]=N;c[C+3936>>2]=N;c[C+2916>>2]=O;c[C+3940>>2]=O;c[C+2920>>2]=P;c[C+3944>>2]=P;P=c[3531098]|0;c[C+876>>2]=P;O=P+256|0;c[C+880>>2]=O;N=P+512|0;c[C+884>>2]=N;K=P+768|0;c[C+888>>2]=K;M=P+1024|0;c[C+892>>2]=M;H=P+1280|0;c[C+896>>2]=H;L=P+1536|0;c[C+900>>2]=L;J=P+1792|0;c[C+904>>2]=J;c[C+1900>>2]=P;c[C+1904>>2]=O;c[C+1908>>2]=N;c[C+1912>>2]=K;c[C+1916>>2]=M;c[C+1920>>2]=H;c[C+1924>>2]=L;c[C+1928>>2]=J;c[C+2924>>2]=P;c[C+3948>>2]=P;c[C+2928>>2]=O;c[C+3952>>2]=O;c[C+2932>>2]=N;c[C+3956>>2]=N;c[C+2936>>2]=K;c[C+3960>>2]=K;c[C+2940>>2]=M;c[C+3964>>2]=M;c[C+2944>>2]=H;c[C+3968>>2]=H;c[C+2948>>2]=L;c[C+3972>>2]=L;c[C+2952>>2]=J;c[C+3976>>2]=J;J=c[3527218]|0;c[C+908>>2]=J;c[C+912>>2]=J+256;c[C+916>>2]=J+512;c[C+920>>2]=J+768;c[C+924>>2]=J+1024;c[C+928>>2]=J+1280;c[C+932>>2]=J+1536;c[C+936>>2]=J+1792;c[C+940>>2]=J+2048;c[C+944>>2]=J+2304;c[C+948>>2]=J+2560;c[C+952>>2]=J+2816;c[C+956>>2]=J+3072;c[C+960>>2]=J+3328;c[C+964>>2]=J+3584;c[C+968>>2]=J+3840;L=208;H=208;while(1){c[C+76+(H+256<<2)>>2]=J+((H<<8)-53248);M=L+1&65535;if((M&65535)>223){Z=208;_=208;break}else{L=M;H=M&65535}}while(1){H=J+((_<<8)-53248)|0;c[C+76+(_+512<<2)>>2]=H;c[C+76+(_+768<<2)>>2]=H;H=Z+1&65535;if((H&65535)>223){break}else{Z=H;_=H&65535}}J=c[2385856]|0;c[C+972>>2]=J;c[C+976>>2]=J+256;c[C+980>>2]=J+512;c[C+984>>2]=J+768;c[C+988>>2]=J+1024;c[C+992>>2]=J+1280;c[C+996>>2]=J+1536;c[C+1e3>>2]=J+1792;c[C+1004>>2]=J+2048;c[C+1008>>2]=J+2304;c[C+1012>>2]=J+2560;c[C+1016>>2]=J+2816;c[C+1020>>2]=J+3072;c[C+1024>>2]=J+3328;c[C+1028>>2]=J+3584;c[C+1032>>2]=J+3840;H=224;L=224;while(1){c[C+76+(L+256<<2)>>2]=J+((L<<8)-57344);M=H+1&65535;if((M&65535)>239){$=224;aa=224;break}else{H=M;L=M&65535}}while(1){L=J+((aa<<8)-57344)|0;c[C+76+(aa+512<<2)>>2]=L;c[C+76+(aa+768<<2)>>2]=L;L=$+1&65535;if((L&65535)>239){break}else{$=L;aa=L&65535}}J=c[2443418]|0;c[C+1036>>2]=J;c[C+1040>>2]=J+256;c[C+1044>>2]=J+512;c[C+1048>>2]=J+768;c[C+1052>>2]=J+1024;c[C+1056>>2]=J+1280;c[C+1060>>2]=J+1536;c[C+1064>>2]=J+1792;c[C+1068>>2]=J+2048;c[C+1072>>2]=J+2304;c[C+1076>>2]=J+2560;c[C+1080>>2]=J+2816;c[C+1084>>2]=J+3072;c[C+1088>>2]=J+3328;c[C+1092>>2]=J+3584;c[C+1096>>2]=J+3840;L=240;H=240;while(1){c[C+76+(H+256<<2)>>2]=J+((H<<8)-61440);M=L+1&65535;if((M&65535)>255){ab=240;ac=240;break}else{L=M;H=M&65535}}while(1){H=J+((ac<<8)-61440)|0;c[C+76+(ac+512<<2)>>2]=H;c[C+76+(ac+768<<2)>>2]=H;H=ab+1&65535;if((H&65535)>255){break}else{ab=H;ac=H&65535}}if(!I){J=C;gGC(J|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=G;c[2417276]=z;c[1836236]=-1;if(a[9680]|0){mq(4e6,32e3);J=gGq(262144)|0;c[2406690]=J;gGz(J|0,0,262144);c[2439246]=0;h[745411]=1.0;h[745410]=1.0;a[3203304]=1;a[3203296]=1}else{mq(4e6,11025)}h[745411]=1.0;a[3203304]=1;h[745410]=1.0;a[3203296]=1;Ux(0,7500,1);c[2407030]=128;c[2407068]=3;J=c[3541206]|0;H=c[3527282]|0;gGC(J|0,H|0,262144)|0;H=c[642608+(c[2436]<<2)>>2]|0;J=c[H+128>>2]|0;if((c[H+52>>2]&4|0)==0){c[2113068]=J;L=c[H+132>>2]|0;c[2113070]=L;c[2443814]=J;c[2440436]=L;ad=J;ae=L}else{c[2113070]=J;L=c[H+132>>2]|0;c[2113068]=L;c[2440436]=J;c[2443814]=L;ad=L;ae=J}J=ag(ad<<1,ae)|0;L=gGq(J)|0;c[2112926]=L;if((L|0)!=0){gGz(L|0,0,J|0)}c[3527252]=65535;c[2439652]=1024;a[6939736]=0;a[9774160]=1;dO1();F=0;i=e;return F|0}}while(0);c[2426752]=0;F=1;i=e;return F|0}function dNJ(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;i=i+128|0;d=b|0;e=a[7460880]|0;if(e){f=0;g=e&1;while(1){e=14163960+(f<<2)|0;h=c[e>>2]|0;if((h|0)==0){j=g}else{k=c[2113004]|0;if((k|0)==0){l=15892}else{m=k-1|0;c[2113004]=m;if((m|0)==0){l=15892}}if((l|0)==15892){l=0;c[2383470]=0}gGr(h);j=a[7460880]&1}c[e>>2]=0;e=f+1|0;if((e|0)<(j|0)){f=e;g=j}else{break}}}a[7460880]=0;j=c[2406690]|0;if((j|0)!=0){gGr(j);c[2406690]=0}fwZ();Uw(0);do{if(a[6939736]|0){j=d|0;g=c[c[642608+(c[2436]<<2)>>2]>>2]|0;be(j|0,128,179600,(f=i,i=i+24|0,c[f>>2]=9374064,c[f+8>>2]=47,c[f+16>>2]=g,f)|0)|0;i=f;a[1040128]=0;f=c[2420380]|0;g=c[f>>2]|0;e=c[f+4>>2]|0;f=fw(j|0,389440)|0;if((f|0)==0){break}j=e>>3<<g&1023;cj(14100392,j|0,1,f|0)|0;aY(f|0)|0}}while(0);c[2113070]=0;c[2113068]=0;d=c[2112926]|0;if((d|0)!=0){gGr(d);c[2112926]=0}d=c[2426752]|0;f=0;while(1){if((f|0)>=1024){l=15908;break}n=9638528+(f<<2)|0;if((c[n>>2]|0)==(d|0)){break}else{f=f+1|0}}if((l|0)==15908){c[2426752]=0;a[14119320]=0;a[9730904]=0;a[14121024]=0;a[9759712]=0;a[9773432]=0;a[9774160]=0;c[2429764]=0;c[3527252]=0;a[9751048]=0;a[5450472]=0;a[6939736]=0;c[2439652]=0;a[6923456]=0;a[4039512]=0;a[9751072]=0;a[9758184]=0;i=b;return 0}gGr(d);c[n>>2]=0;c[2426752]=0;a[14119320]=0;a[9730904]=0;a[14121024]=0;a[9759712]=0;a[9773432]=0;a[9774160]=0;c[2429764]=0;c[3527252]=0;a[9751048]=0;a[5450472]=0;a[6939736]=0;c[2439652]=0;a[6923456]=0;a[4039512]=0;a[9751072]=0;a[9758184]=0;i=b;return 0}function dNK(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;if((a[9624400]|0)!=0){dO1()}dO3();c[2440542]=133333;c[2444096]=0;a[9751048]=0;d=c[2385548]|0;if((d|0)>0){gGz(9752472,0,((d|0)>1?d<<2:4)|0)}c[2433530]=0;d=0;e=0;L20953:while(1){f=e;while(1){if((f|0)>=10){break L20953}g=c[2439330]|0;if((g|0)!=0){h=g;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;h=c[2438118]|0;c[2433530]=h;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;i=f+1|0;j=(ag(c[2440542]|0,i)|0)/10|0;k=c[2444096]|0;l=j-k|0;do{if((l|0)<1){m=0;n=k;o=h}else{if((a[g+4188|0]|0)==0){j=gfc(l)|0;p=(c[2433530]|0)+j|0;c[2433530]=p;m=j;n=c[2444096]|0;o=p;break}else{p=h+l|0;c[2433530]=p;m=l;n=k;o=p;break}}}while(0);k=n+m|0;c[2444096]=k;if((f|0)==7){a[9751048]=1;q=o}else if((f|0)==4){a[9706117]=1;if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){l=gfc(500)|0;r=l;s=(c[2433530]|0)+l|0;t=c[2444096]|0}else{r=500;s=o+500|0;t=k}c[2433530]=s;c[2444096]=t+r;a[9706117]=0;q=s}else if((f|0)==9){a[9706117]=1;if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){l=gfc(500)|0;u=l;v=(c[2433530]|0)+l|0;w=c[2444096]|0}else{u=500;v=o+500|0;w=k}c[2433530]=v;c[2444096]=w+u;a[9706117]=0;q=v}else{q=o}k=c[1836236]|0;l=c[9757320+(k<<2)>>2]|0;if((l|0)!=0){h=l;gGC(h|0,9706056,76)|0}c[9752472+(k<<2)>>2]=q;c[14113936+(k<<2)>>2]=c[2076596];c[9669104+(k<<2)>>2]=c[3541536];c[1836236]=-1;x=c[2112964]|0;if((x|0)==0){f=i}else{break}}f=a[9688]|0?53:0;k=x+(d<<1<<1)|0;Uy(k,f);Uu(0,k,f);d=f+d|0;e=i}i=c[2112964]|0;do{if((i|0)!=0){e=a[9688]|0?534:0;x=e-d|0;q=i+(d<<1<<1)|0;if((e|0)==(d|0)){break}Uy(q,x);Uu(0,q,x)}}while(0);if((c[2112968]|0)==0){return 0}dO4();return 0}function dNL(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;g=i;i=i+240|0;h=g|0;j=g+16|0;k=g+32|0;l=g+48|0;m=g+64|0;n=g+80|0;o=g+96|0;p=g+112|0;q=g+128|0;r=g+144|0;s=g+160|0;t=g+176|0;u=g+192|0;v=g+208|0;w=g+224|0;if((f|0)!=0){c[f>>2]=169735}if((e&32|0)!=0){gGz(w|0,0,12);x=c[2405678]|0;c[w>>2]=x;c[w+4>>2]=(c[2411714]|0)-x;c[w+12>>2]=162152;x=c[2076592]|0;gj[x&4095](w)|0}if((e&8|0)!=0&a[6923456]){gGz(w|0,0,12);c[w>>2]=(c[2385856]|0)+(a[4039512]|0?8064:0);c[w+4>>2]=128;c[w+12>>2]=544120;x=c[2076592]|0;gj[x&4095](w)|0}if((e&64|0)!=0){fw$(e);mt(e);Ut(0);if(a[6939736]|0){Ts(e,f)}gGz(v|0,0,12);c[v>>2]=9776384;c[v+4>>2]=4;c[v+12>>2]=330672;f=c[2076592]|0;gj[f&4095](v)|0;gGz(u|0,0,12);c[u>>2]=9776388;c[u+4>>2]=4;c[u+12>>2]=321856;v=c[2076592]|0;gj[v&4095](u)|0;gGz(t|0,0,12);c[t>>2]=14119320;c[t+4>>2]=1;c[t+12>>2]=511192;u=c[2076592]|0;gj[u&4095](t)|0;gGz(s|0,0,12);c[s>>2]=9730904;c[s+4>>2]=1;c[s+12>>2]=66936;t=c[2076592]|0;gj[t&4095](s)|0;gGz(r|0,0,12);c[r>>2]=14121024;c[r+4>>2]=1;c[r+12>>2]=491248;s=c[2076592]|0;gj[s&4095](r)|0;gGz(q|0,0,12);c[q>>2]=9759712;c[q+4>>2]=1;c[q+12>>2]=503888;r=c[2076592]|0;gj[r&4095](q)|0;gGz(p|0,0,12);c[p>>2]=9773432;c[p+4>>2]=1;c[p+12>>2]=587648;q=c[2076592]|0;gj[q&4095](p)|0;gGz(o|0,0,12);c[o>>2]=9751048;c[o+4>>2]=1;c[o+12>>2]=434648;p=c[2076592]|0;gj[p&4095](o)|0;gGz(n|0,0,12);c[n>>2]=9751072;c[n+4>>2]=1;c[n+12>>2]=433760;o=c[2076592]|0;gj[o&4095](n)|0;gGz(m|0,0,12);c[m>>2]=9635768;c[m+4>>2]=4;c[m+12>>2]=432888;n=c[2076592]|0;gj[n&4095](m)|0;gGz(l|0,0,12);c[l>>2]=9635772;c[l+4>>2]=4;c[l+12>>2]=432136;m=c[2076592]|0;gj[m&4095](l)|0;gGz(k|0,0,12);c[k>>2]=9626056;c[k+4>>2]=2;c[k+12>>2]=431200;l=c[2076592]|0;gj[l&4095](k)|0;gGz(j|0,0,12);c[j>>2]=9626048;c[j+4>>2]=2;c[j+12>>2]=430112;k=c[2076592]|0;gj[k&4095](j)|0;gGz(h|0,0,12);c[h>>2]=9719056;c[h+4>>2]=4;c[h+12>>2]=429176;j=c[2076592]|0;gj[j&4095](h)|0}if((e&2|0)==0){i=g;return 0}e=c[2439330]|0;h=(e|0)==0;if(!h){j=e;gGC(9706056,j|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];j=c[3528484]|0;c[2076596]=j;k=c[2417276]|0;c[3541536]=k;c[1836236]=0;l=c[2385838]|0;m=d[14119320]<<14;n=m+32768|0;o=128;p=128;while(1){c[e+76+(p<<2)>>2]=l+(n+(p<<8));q=o+1&65535;if((q&65535)>191){break}else{o=q;p=q&65535}}if(a[6939736]|0){p=c[3529358]|0;o=128;q=128;while(1){r=(q<<8)+m+32768|0;c[e+76+(q+512<<2)>>2]=p+r;c[e+76+(q+768<<2)>>2]=l+r;r=o+1&65535;if((r&65535)>191){break}else{o=r;q=r&65535}}}else{q=128;o=128;while(1){p=l+(n+(o<<8))|0;c[e+76+(o+512<<2)>>2]=p;c[e+76+(o+768<<2)>>2]=p;p=q+1&65535;if((p&65535)>191){break}else{q=p;o=p&65535}}}if(!h){h=e;gGC(h|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=j;c[2417276]=k;c[1836236]=-1;if((a[14121024]|0)==0){i=g;return 0}k=c[3541206]|0;j=(c[3527282]|0)+262144|0;gGC(k|0,j|0,262144)|0;i=g;return 0}function dNM(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[962652+(b*112|0)>>2];c[a+104>>2]=c[962656+(b*112|0)>>2];c[a+108>>2]=c[962660+(b*112|0)>>2];d=0;return d|0}function dNN(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=962552+(b*112|0);e=0;return e|0}function dNO(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3741236+(b*112|0)>>2];c[a+104>>2]=c[3741240+(b*112|0)>>2];c[a+108>>2]=c[3741244+(b*112|0)>>2];d=0;return d|0}function dNP(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=3741136+(b*112|0);e=0;return e|0}function dNQ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>44){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1837168+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dNR(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;b=i;i=i+1200|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;l=b+360|0;m=b+472|0;n=b+480|0;o=b+592|0;p=b+600|0;q=b+712|0;r=b+720|0;s=b+832|0;t=b+840|0;u=b+952|0;v=b+960|0;w=b+1072|0;x=b+1080|0;y=b+1192|0;c[2426752]=0;c[2385838]=0;c[3529358]=327680;c[3541206]=655360;c[3527282]=917504;c[2405678]=1441792;c[2385856]=1441792;c[2439618]=1449984;c[3531098]=1454080;c[3527218]=1456128;c[2443418]=1460224;c[2411714]=1464320;c[2406524]=1464320;c[3529578]=5658624;c[3530044]=6182912;z=0;while(1){if((z|0)>=1024){break}A=9638528+(z<<2)|0;if((c[A>>2]|0)==0){B=16005;break}else{z=z+1|0}}do{if((B|0)==16005){z=gGq(6191104)|0;c[A>>2]=z;if((z|0)==0){break}c[2426752]=z;gGz(z|0,0,6191104);c[2385838]=z;c[3529358]=z+327680;c[3541206]=z+655360;c[3527282]=z+917504;C=z+1441792|0;c[2405678]=C;c[2385856]=C;c[2439618]=z+1449984;c[3531098]=z+1454080;c[3527218]=z+1456128;c[2443418]=z+1460224;C=z+1464320|0;c[2411714]=C;c[2406524]=C;c[3529578]=z+5658624;c[3530044]=z+6182912;c[2414256]=z+6191104;z=0;while(1){if((z|0)>=1024){D=0;break}E=9638528+(z<<2)|0;if((c[E>>2]|0)==0){B=16010;break}else{z=z+1|0}}do{if((B|0)==16010){z=gGq(2097152)|0;c[E>>2]=z;if((z|0)==0){D=0;break}gGz(z|0,0,2097152);D=z}}while(0);c[3529526]=D;z=c[2385838]|0;if((c[3542200]|0)==0){F=1;i=b;return F|0}C=x+108|0;c[C>>2]=0;G=x+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,0)|0;do{if((c[C>>2]|0)!=0){H=c[G>>2]|0;c[y>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](y,0,0)|0;if((H|0)<1){F=1;i=b;return F|0}if((gzL(z,0,0)|0)==0){break}else{F=1}i=b;return F|0}}while(0);z=(c[2385838]|0)+65536|0;if((c[3542200]|0)==0){F=1;i=b;return F|0}G=v+108|0;c[G>>2]=0;C=v+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,1)|0;do{if((c[G>>2]|0)!=0){H=c[C>>2]|0;c[w>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](w,1,0)|0;if((H|0)<1){F=1;i=b;return F|0}if((gzL(z,0,1)|0)==0){break}else{F=1}i=b;return F|0}}while(0);z=(c[2385838]|0)+196608|0;if((c[3542200]|0)==0){F=1;i=b;return F|0}C=t+108|0;c[C>>2]=0;G=t+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,2)|0;do{if((c[C>>2]|0)!=0){H=c[G>>2]|0;c[u>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](u,2,0)|0;if((H|0)<1){F=1;i=b;return F|0}if((gzL(z,0,2)|0)==0){break}else{F=1}i=b;return F|0}}while(0);z=c[3529526]|0;gGz(z|0,-1|0,2097152);if((c[3542200]|0)==0){F=1;i=b;return F|0}G=r+108|0;c[G>>2]=0;C=r+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,3)|0;do{if((c[G>>2]|0)!=0){H=c[C>>2]|0;c[s>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](s,3,0)|0;if((H|0)<1){F=1;i=b;return F|0}if((gzL(z,0,3)|0)==0){break}else{F=1}i=b;return F|0}}while(0);z=(c[3529526]|0)+524288|0;if((c[3542200]|0)==0){F=1;i=b;return F|0}C=p+108|0;c[C>>2]=0;G=p+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,4)|0;do{if((c[C>>2]|0)!=0){H=c[G>>2]|0;c[q>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](q,4,0)|0;if((H|0)<1){F=1;i=b;return F|0}if((gzL(z,0,4)|0)==0){break}else{F=1}i=b;return F|0}}while(0);z=(c[3529526]|0)+1048576|0;if((c[3542200]|0)==0){F=1;i=b;return F|0}G=n+108|0;c[G>>2]=0;C=n+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,5)|0;do{if((c[G>>2]|0)!=0){H=c[C>>2]|0;c[o>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](o,5,0)|0;if((H|0)<1){F=1;i=b;return F|0}if((gzL(z,0,5)|0)==0){break}else{F=1}i=b;return F|0}}while(0);z=(c[3529526]|0)+1572864|0;if((c[3542200]|0)==0){F=1;i=b;return F|0}C=l+108|0;c[C>>2]=0;G=l+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,6)|0;do{if((c[C>>2]|0)!=0){H=c[G>>2]|0;c[m>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](m,6,0)|0;if((H|0)<1){F=1;i=b;return F|0}if((gzL(z,0,6)|0)==0){break}else{F=1}i=b;return F|0}}while(0);z=c[3529526]|0;G=c[2406524]|0;C=0;do{H=C<<6;gGz(G+H|0,0,64);I=C<<8;J=0;do{K=1<<3-J;L=(c[687256+(J<<2)>>2]|0)+I|0;M=0;do{N=L+(c[1183816+(M<<2)>>2]|0)|0;O=(M<<3)+H|0;P=0;do{Q=N+(c[809240+(P<<2)>>2]|0)|0;if(((d[z+((Q|0)/8|0)|0]|0)&128>>>((Q&7)>>>0)|0)!=0){Q=G+(O+P)|0;a[Q]=(d[Q]|0|K)&255}P=P+1|0;}while((P|0)<8);M=M+1|0;}while((M|0)<8);J=J+1|0;}while((J|0)<4);C=C+1|0;}while((C|0)<65536);gGz(z|0,-1|0,2097152);if((c[3542200]|0)==0){F=1;i=b;return F|0}C=j+108|0;c[C>>2]=0;G=j+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,7)|0;do{if((c[C>>2]|0)!=0){J=c[G>>2]|0;c[k>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](k,7,0)|0;if((J|0)<1){F=1;i=b;return F|0}if((gzL(z,0,7)|0)==0){break}else{F=1}i=b;return F|0}}while(0);z=(c[3529526]|0)+131072|0;if((c[3542200]|0)==0){F=1;i=b;return F|0}G=g+108|0;c[G>>2]=0;C=g+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,8)|0;do{if((c[G>>2]|0)!=0){J=c[C>>2]|0;c[h>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](h,8,0)|0;if((J|0)<1){F=1;i=b;return F|0}if((gzL(z,0,8)|0)==0){break}else{F=1}i=b;return F|0}}while(0);z=c[3529526]|0;C=c[3529578]|0;G=0;while(1){J=G<<8;gGz(C+J|0,0,256);H=G<<9;I=0;do{M=1<<3-I;K=(c[961472+(I<<2)>>2]|0)+H|0;L=0;do{P=K+(c[608544+(L<<2)>>2]|0)|0;O=(L<<4)+J|0;N=0;do{Q=P+(c[609552+(N<<2)>>2]|0)|0;if(((d[z+((Q|0)/8|0)|0]|0)&128>>>((Q&7)>>>0)|0)!=0){Q=C+(O+N)|0;a[Q]=(d[Q]|0|M)&255}N=N+1|0;}while((N|0)<16);L=L+1|0;}while((L|0)<16);I=I+1|0;}while((I|0)<4);I=G+1|0;if((I|0)<2048){G=I}else{R=0;break}}while(1){if((R|0)>=1024){break}S=9638528+(R<<2)|0;if((c[S>>2]|0)==(z|0)){B=16070;break}else{R=R+1|0}}if((B|0)==16070){gGr(z);c[S>>2]=0}c[3529526]=0;G=c[3527282]|0;if((c[3542200]|0)==0){F=1;i=b;return F|0}C=e+108|0;c[C>>2]=0;I=e+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,9)|0;do{if((c[C>>2]|0)!=0){J=c[I>>2]|0;c[f>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](f,9,0)|0;if((J|0)<1){F=1;i=b;return F|0}if((gzL(G,0,9)|0)==0){break}else{F=1}i=b;return F|0}}while(0);G=c[2385838]|0;I=c[3529358]|0;W4(G,I,G,0,32768,1985229328,19088743,43605,165);C=0;do{z=(C<<14)+65536|0;J=G+z|0;W4(J,I+z|0,J,32768,16384,1985229328,19088743,43605,165);C=C+1|0;}while((C|0)<16);dO2();a[9774160]=1;a[5450472]=1;dO1();F=0;i=b;return F|0}}while(0);c[2426752]=0;F=1;i=b;return F|0}function dNS(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3620004+(b*112|0)>>2];c[a+104>>2]=c[3620008+(b*112|0)>>2];c[a+108>>2]=c[3620012+(b*112|0)>>2];d=0;return d|0}function dNT(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=3619904+(b*112|0);e=0;return e|0}function dNU(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1217216+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dNV(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;b=i;i=i+720|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;l=b+360|0;m=b+472|0;n=b+480|0;o=b+592|0;p=b+600|0;q=b+712|0;c[2426752]=0;c[2385838]=0;c[3529358]=327680;c[3541206]=655360;c[3527282]=917504;c[2405678]=1441792;c[2385856]=1441792;c[2439618]=1449984;c[3531098]=1454080;c[3527218]=1456128;c[2443418]=1460224;c[2411714]=1464320;c[2406524]=1464320;c[3529578]=5658624;c[3530044]=6182912;r=0;while(1){if((r|0)>=1024){break}s=9638528+(r<<2)|0;if((c[s>>2]|0)==0){t=16133;break}else{r=r+1|0}}do{if((t|0)==16133){r=gGq(6191104)|0;c[s>>2]=r;if((r|0)==0){break}c[2426752]=r;gGz(r|0,0,6191104);c[2385838]=r;c[3529358]=r+327680;c[3541206]=r+655360;c[3527282]=r+917504;u=r+1441792|0;c[2405678]=u;c[2385856]=u;c[2439618]=r+1449984;c[3531098]=r+1454080;c[3527218]=r+1456128;c[2443418]=r+1460224;u=r+1464320|0;c[2411714]=u;c[2406524]=u;c[3529578]=r+5658624;c[3530044]=r+6182912;c[2414256]=r+6191104;r=0;while(1){if((r|0)>=1024){v=0;break}w=9638528+(r<<2)|0;if((c[w>>2]|0)==0){t=16138;break}else{r=r+1|0}}do{if((t|0)==16138){r=gGq(2097152)|0;c[w>>2]=r;if((r|0)==0){v=0;break}gGz(r|0,0,2097152);v=r}}while(0);c[3529526]=v;r=c[2385838]|0;if((c[3542200]|0)==0){x=1;i=b;return x|0}u=p+108|0;c[u>>2]=0;y=p+100|0;c[y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,0)|0;do{if((c[u>>2]|0)!=0){z=c[y>>2]|0;c[q>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](q,0,0)|0;if((z|0)<1){x=1;i=b;return x|0}if((gzL(r,0,0)|0)==0){break}else{x=1}i=b;return x|0}}while(0);r=(c[2385838]|0)+65536|0;if((c[3542200]|0)==0){x=1;i=b;return x|0}y=n+108|0;c[y>>2]=0;u=n+100|0;c[u>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,1)|0;do{if((c[y>>2]|0)!=0){z=c[u>>2]|0;c[o>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](o,1,0)|0;if((z|0)<1){x=1;i=b;return x|0}if((gzL(r,0,1)|0)==0){break}else{x=1}i=b;return x|0}}while(0);r=c[3529526]|0;gGz(r|0,-1|0,2097152);if((R6(r,2,2)|0)!=0){x=1;i=b;return x|0}if((R6((c[3529526]|0)+1|0,3,2)|0)!=0){x=1;i=b;return x|0}if((R6((c[3529526]|0)+1048576|0,4,2)|0)!=0){x=1;i=b;return x|0}if((R6((c[3529526]|0)+1048577|0,5,2)|0)!=0){x=1;i=b;return x|0}r=c[3529526]|0;u=c[2406524]|0;y=0;do{z=y<<6;gGz(u+z|0,0,64);A=y<<8;B=0;do{C=1<<3-B;D=(c[687256+(B<<2)>>2]|0)+A|0;E=0;do{F=D+(c[1183816+(E<<2)>>2]|0)|0;G=(E<<3)+z|0;H=0;do{I=F+(c[809240+(H<<2)>>2]|0)|0;if(((d[r+((I|0)/8|0)|0]|0)&128>>>((I&7)>>>0)|0)!=0){I=u+(G+H)|0;a[I]=(d[I]|0|C)&255}H=H+1|0;}while((H|0)<8);E=E+1|0;}while((E|0)<8);B=B+1|0;}while((B|0)<4);y=y+1|0;}while((y|0)<65536);gGz(r|0,-1|0,2097152);if((c[3542200]|0)==0){x=1;i=b;return x|0}y=l+108|0;c[y>>2]=0;u=l+100|0;c[u>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,6)|0;do{if((c[y>>2]|0)!=0){B=c[u>>2]|0;c[m>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](m,6,0)|0;if((B|0)<1){x=1;i=b;return x|0}if((gzL(r,0,6)|0)==0){break}else{x=1}i=b;return x|0}}while(0);r=(c[3529526]|0)+131072|0;if((c[3542200]|0)==0){x=1;i=b;return x|0}u=j+108|0;c[u>>2]=0;y=j+100|0;c[y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,7)|0;do{if((c[u>>2]|0)!=0){B=c[y>>2]|0;c[k>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](k,7,0)|0;if((B|0)<1){x=1;i=b;return x|0}if((gzL(r,0,7)|0)==0){break}else{x=1}i=b;return x|0}}while(0);r=c[3529526]|0;y=c[3529578]|0;u=0;while(1){B=u<<8;gGz(y+B|0,0,256);z=u<<9;A=0;do{E=1<<3-A;C=(c[961472+(A<<2)>>2]|0)+z|0;D=0;do{H=C+(c[608544+(D<<2)>>2]|0)|0;G=(D<<4)+B|0;F=0;do{I=H+(c[609552+(F<<2)>>2]|0)|0;if(((d[r+((I|0)/8|0)|0]|0)&128>>>((I&7)>>>0)|0)!=0){I=y+(G+F)|0;a[I]=(d[I]|0|E)&255}F=F+1|0;}while((F|0)<16);D=D+1|0;}while((D|0)<16);A=A+1|0;}while((A|0)<4);A=u+1|0;if((A|0)<2048){u=A}else{J=0;break}}while(1){if((J|0)>=1024){break}K=9638528+(J<<2)|0;if((c[K>>2]|0)==(r|0)){t=16182;break}else{J=J+1|0}}if((t|0)==16182){gGr(r);c[K>>2]=0}c[3529526]=0;u=c[3527282]|0;if((c[3542200]|0)==0){x=1;i=b;return x|0}y=g+108|0;c[y>>2]=0;A=g+100|0;c[A>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,8)|0;do{if((c[y>>2]|0)!=0){B=c[A>>2]|0;c[h>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](h,8,0)|0;if((B|0)<1){x=1;i=b;return x|0}if((gzL(u,0,8)|0)==0){break}else{x=1}i=b;return x|0}}while(0);u=(c[3527282]|0)+131072|0;if((c[3542200]|0)==0){x=1;i=b;return x|0}A=e+108|0;c[A>>2]=0;y=e+100|0;c[y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,9)|0;do{if((c[A>>2]|0)!=0){r=c[y>>2]|0;c[f>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](f,9,0)|0;if((r|0)<1){x=1;i=b;return x|0}if((gzL(u,0,9)|0)==0){break}else{x=1}i=b;return x|0}}while(0);u=c[2385838]|0;y=c[3529358]|0;W4(u,y,u,0,32768,1985229328,19088743,43605,165);A=0;do{r=(A<<14)+65536|0;B=u+r|0;W4(B,y+r|0,B,32768,16384,1985229328,19088743,43605,165);A=A+1|0;}while((A|0)<16);dO2();a[9774160]=1;dO1();x=0;i=b;return x|0}}while(0);c[2426752]=0;x=1;i=b;return x|0}function dNW(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1783372+(b*112|0)>>2];c[a+104>>2]=c[1783376+(b*112|0)>>2];c[a+108>>2]=c[1783380+(b*112|0)>>2];d=0;return d|0}function dNX(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=1783272+(b*112|0);e=0;return e|0}function dNY(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1216196+(b*112|0)>>2];c[a+104>>2]=c[1216200+(b*112|0)>>2];c[a+108>>2]=c[1216204+(b*112|0)>>2];d=0;return d|0}function dNZ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=1216096+(b*112|0);e=0;return e|0}function dN_(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5453196+(b*112|0)>>2];c[a+104>>2]=c[5453200+(b*112|0)>>2];c[a+108>>2]=c[5453204+(b*112|0)>>2];d=0;return d|0}function dN$(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=5453096+(b*112|0);e=0;return e|0}function dN0(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6179720+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dN1(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;b=i;i=i+1200|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;l=b+360|0;m=b+472|0;n=b+480|0;o=b+592|0;p=b+600|0;q=b+712|0;r=b+720|0;s=b+832|0;t=b+840|0;u=b+952|0;v=b+960|0;w=b+1072|0;x=b+1080|0;y=b+1192|0;c[2426752]=0;c[2385838]=0;c[3529358]=327680;c[3527282]=655360;c[2405678]=786432;c[2385856]=786432;c[2439618]=794624;c[3531098]=798720;c[3527218]=800768;c[2443418]=804864;c[2411714]=808960;c[2406524]=808960;c[3529578]=2906112;c[3530044]=3430400;z=0;while(1){if((z|0)>=1024){break}A=9638528+(z<<2)|0;if((c[A>>2]|0)==0){B=16265;break}else{z=z+1|0}}do{if((B|0)==16265){z=gGq(3438592)|0;c[A>>2]=z;if((z|0)==0){break}c[2426752]=z;gGz(z|0,0,3438592);c[2385838]=z;c[3529358]=z+327680;c[3527282]=z+655360;C=z+786432|0;c[2405678]=C;c[2385856]=C;c[2439618]=z+794624;c[3531098]=z+798720;c[3527218]=z+800768;c[2443418]=z+804864;C=z+808960|0;c[2411714]=C;c[2406524]=C;c[3529578]=z+2906112;c[3530044]=z+3430400;c[2414256]=z+3438592;z=0;while(1){if((z|0)>=1024){D=0;break}E=9638528+(z<<2)|0;if((c[E>>2]|0)==0){B=16270;break}else{z=z+1|0}}do{if((B|0)==16270){z=gGq(1048576)|0;c[E>>2]=z;if((z|0)==0){D=0;break}gGz(z|0,0,1048576);D=z}}while(0);c[3529526]=D;z=c[2385838]|0;if((c[3542200]|0)==0){F=1;i=b;return F|0}C=x+108|0;c[C>>2]=0;G=x+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,0)|0;do{if((c[C>>2]|0)!=0){H=c[G>>2]|0;c[y>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](y,0,0)|0;if((H|0)<1){F=1;i=b;return F|0}if((gzL(z,0,0)|0)==0){break}else{F=1}i=b;return F|0}}while(0);z=(c[2385838]|0)+65536|0;if((c[3542200]|0)==0){F=1;i=b;return F|0}G=v+108|0;c[G>>2]=0;C=v+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,1)|0;do{if((c[G>>2]|0)!=0){H=c[C>>2]|0;c[w>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](w,1,0)|0;if((H|0)<1){F=1;i=b;return F|0}if((gzL(z,0,1)|0)==0){break}else{F=1}i=b;return F|0}}while(0);z=(c[2385838]|0)+196608|0;if((c[3542200]|0)==0){F=1;i=b;return F|0}C=t+108|0;c[C>>2]=0;G=t+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,2)|0;do{if((c[C>>2]|0)!=0){H=c[G>>2]|0;c[u>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](u,2,0)|0;if((H|0)<1){F=1;i=b;return F|0}if((gzL(z,0,2)|0)==0){break}else{F=1}i=b;return F|0}}while(0);z=c[3529526]|0;gGz(z|0,-1|0,1048576);if((c[3542200]|0)==0){F=1;i=b;return F|0}G=r+108|0;c[G>>2]=0;C=r+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,3)|0;do{if((c[G>>2]|0)!=0){H=c[C>>2]|0;c[s>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](s,3,0)|0;if((H|0)<1){F=1;i=b;return F|0}if((gzL(z,0,3)|0)==0){break}else{F=1}i=b;return F|0}}while(0);z=(c[3529526]|0)+131072|0;if((c[3542200]|0)==0){F=1;i=b;return F|0}C=p+108|0;c[C>>2]=0;G=p+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,4)|0;do{if((c[C>>2]|0)!=0){H=c[G>>2]|0;c[q>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](q,4,0)|0;if((H|0)<1){F=1;i=b;return F|0}if((gzL(z,0,4)|0)==0){break}else{F=1}i=b;return F|0}}while(0);z=(c[3529526]|0)+524288|0;if((c[3542200]|0)==0){F=1;i=b;return F|0}G=n+108|0;c[G>>2]=0;C=n+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,5)|0;do{if((c[G>>2]|0)!=0){H=c[C>>2]|0;c[o>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](o,5,0)|0;if((H|0)<1){F=1;i=b;return F|0}if((gzL(z,0,5)|0)==0){break}else{F=1}i=b;return F|0}}while(0);z=(c[3529526]|0)+655360|0;if((c[3542200]|0)==0){F=1;i=b;return F|0}C=l+108|0;c[C>>2]=0;G=l+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,6)|0;do{if((c[C>>2]|0)!=0){H=c[G>>2]|0;c[m>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](m,6,0)|0;if((H|0)<1){F=1;i=b;return F|0}if((gzL(z,0,6)|0)==0){break}else{F=1}i=b;return F|0}}while(0);z=c[3529526]|0;G=c[2406524]|0;C=0;do{H=C<<6;gGz(G+H|0,0,64);I=C<<7;J=0;do{K=1<<3-J;L=(c[611600+(J<<2)>>2]|0)+I|0;M=0;do{N=L+(c[6669224+(M<<2)>>2]|0)|0;O=(M<<3)+H|0;P=0;do{Q=N+(c[612480+(P<<2)>>2]|0)|0;if(((d[z+((Q|0)/8|0)|0]|0)&128>>>((Q&7)>>>0)|0)!=0){Q=G+(O+P)|0;a[Q]=(d[Q]|0|K)&255}P=P+1|0;}while((P|0)<8);M=M+1|0;}while((M|0)<8);J=J+1|0;}while((J|0)<4);C=C+1|0;}while((C|0)<32768);gGz(z|0,-1|0,1048576);if((c[3542200]|0)==0){F=1;i=b;return F|0}C=j+108|0;c[C>>2]=0;G=j+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,7)|0;do{if((c[C>>2]|0)!=0){J=c[G>>2]|0;c[k>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](k,7,0)|0;if((J|0)<1){F=1;i=b;return F|0}if((gzL(z,0,7)|0)==0){break}else{F=1}i=b;return F|0}}while(0);z=(c[3529526]|0)+131072|0;if((c[3542200]|0)==0){F=1;i=b;return F|0}G=g+108|0;c[G>>2]=0;C=g+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,8)|0;do{if((c[G>>2]|0)!=0){J=c[C>>2]|0;c[h>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](h,8,0)|0;if((J|0)<1){F=1;i=b;return F|0}if((gzL(z,0,8)|0)==0){break}else{F=1}i=b;return F|0}}while(0);z=c[3529526]|0;C=c[3529578]|0;G=0;while(1){J=G<<8;gGz(C+J|0,0,256);H=G<<9;I=0;do{M=1<<3-I;K=(c[961472+(I<<2)>>2]|0)+H|0;L=0;do{P=K+(c[608544+(L<<2)>>2]|0)|0;O=(L<<4)+J|0;N=0;do{Q=P+(c[609552+(N<<2)>>2]|0)|0;if(((d[z+((Q|0)/8|0)|0]|0)&128>>>((Q&7)>>>0)|0)!=0){Q=C+(O+N)|0;a[Q]=(d[Q]|0|M)&255}N=N+1|0;}while((N|0)<16);L=L+1|0;}while((L|0)<16);I=I+1|0;}while((I|0)<4);I=G+1|0;if((I|0)<2048){G=I}else{R=0;break}}while(1){if((R|0)>=1024){break}S=9638528+(R<<2)|0;if((c[S>>2]|0)==(z|0)){B=16330;break}else{R=R+1|0}}if((B|0)==16330){gGr(z);c[S>>2]=0}c[3529526]=0;G=c[3527282]|0;if((c[3542200]|0)==0){F=1;i=b;return F|0}C=e+108|0;c[C>>2]=0;I=e+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,9)|0;do{if((c[C>>2]|0)!=0){J=c[I>>2]|0;c[f>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](f,9,0)|0;if((J|0)<1){F=1;i=b;return F|0}if((gzL(G,0,9)|0)==0){break}else{F=1}i=b;return F|0}}while(0);G=c[2385838]|0;I=c[3529358]|0;W4(G,I,G,0,32768,1985229328,19088743,43605,165);C=0;do{z=(C<<14)+65536|0;J=G+z|0;W4(J,I+z|0,J,32768,16384,1985229328,19088743,43605,165);C=C+1|0;}while((C|0)<16);dO0();dO1();F=0;i=b;return F|0}}while(0);c[2426752]=0;F=1;i=b;return F|0}function dN2(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7161388+(b*112|0)>>2];c[a+104>>2]=c[7161392+(b*112|0)>>2];c[a+108>>2]=c[7161396+(b*112|0)>>2];d=0;return d|0}function dN3(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=7161288+(b*112|0);e=0;return e|0}function dN4(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;b=i;i=i+1080|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;l=b+360|0;m=b+472|0;n=b+480|0;o=b+592|0;p=b+600|0;q=b+712|0;r=b+720|0;s=b+832|0;t=b+840|0;u=b+952|0;v=b+960|0;w=b+1072|0;c[2426752]=0;c[2385838]=0;c[3529358]=327680;c[3527282]=655360;c[2405678]=786432;c[2385856]=786432;c[2439618]=794624;c[3531098]=798720;c[3527218]=800768;c[2443418]=804864;c[2411714]=808960;c[2406524]=808960;c[3529578]=2906112;c[3530044]=3430400;x=0;while(1){if((x|0)>=1024){break}y=9638528+(x<<2)|0;if((c[y>>2]|0)==0){z=16386;break}else{x=x+1|0}}do{if((z|0)==16386){x=gGq(3438592)|0;c[y>>2]=x;if((x|0)==0){break}c[2426752]=x;gGz(x|0,0,3438592);c[2385838]=x;c[3529358]=x+327680;c[3527282]=x+655360;A=x+786432|0;c[2405678]=A;c[2385856]=A;c[2439618]=x+794624;c[3531098]=x+798720;c[3527218]=x+800768;c[2443418]=x+804864;A=x+808960|0;c[2411714]=A;c[2406524]=A;c[3529578]=x+2906112;c[3530044]=x+3430400;c[2414256]=x+3438592;x=0;while(1){if((x|0)>=1024){B=0;break}C=9638528+(x<<2)|0;if((c[C>>2]|0)==0){z=16391;break}else{x=x+1|0}}do{if((z|0)==16391){x=gGq(1048576)|0;c[C>>2]=x;if((x|0)==0){B=0;break}gGz(x|0,0,1048576);B=x}}while(0);c[3529526]=B;x=c[2385838]|0;if((c[3542200]|0)==0){D=1;i=b;return D|0}A=v+108|0;c[A>>2]=0;E=v+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,0)|0;do{if((c[A>>2]|0)!=0){F=c[E>>2]|0;c[w>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](w,0,0)|0;if((F|0)<1){D=1;i=b;return D|0}if((gzL(x,0,0)|0)==0){break}else{D=1}i=b;return D|0}}while(0);x=(c[2385838]|0)+65536|0;if((c[3542200]|0)==0){D=1;i=b;return D|0}E=t+108|0;c[E>>2]=0;A=t+100|0;c[A>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,1)|0;do{if((c[E>>2]|0)!=0){F=c[A>>2]|0;c[u>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](u,1,0)|0;if((F|0)<1){D=1;i=b;return D|0}if((gzL(x,0,1)|0)==0){break}else{D=1}i=b;return D|0}}while(0);x=c[3529526]|0;gGz(x|0,-1|0,1048576);if((c[3542200]|0)==0){D=1;i=b;return D|0}A=r+108|0;c[A>>2]=0;E=r+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,2)|0;do{if((c[A>>2]|0)!=0){F=c[E>>2]|0;c[s>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](s,2,0)|0;if((F|0)<1){D=1;i=b;return D|0}if((gzL(x,0,2)|0)==0){break}else{D=1}i=b;return D|0}}while(0);x=(c[3529526]|0)+131072|0;if((c[3542200]|0)==0){D=1;i=b;return D|0}E=p+108|0;c[E>>2]=0;A=p+100|0;c[A>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,3)|0;do{if((c[E>>2]|0)!=0){F=c[A>>2]|0;c[q>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](q,3,0)|0;if((F|0)<1){D=1;i=b;return D|0}if((gzL(x,0,3)|0)==0){break}else{D=1}i=b;return D|0}}while(0);x=(c[3529526]|0)+524288|0;if((c[3542200]|0)==0){D=1;i=b;return D|0}A=n+108|0;c[A>>2]=0;E=n+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,4)|0;do{if((c[A>>2]|0)!=0){F=c[E>>2]|0;c[o>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](o,4,0)|0;if((F|0)<1){D=1;i=b;return D|0}if((gzL(x,0,4)|0)==0){break}else{D=1}i=b;return D|0}}while(0);x=(c[3529526]|0)+655360|0;if((c[3542200]|0)==0){D=1;i=b;return D|0}E=l+108|0;c[E>>2]=0;A=l+100|0;c[A>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,5)|0;do{if((c[E>>2]|0)!=0){F=c[A>>2]|0;c[m>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](m,5,0)|0;if((F|0)<1){D=1;i=b;return D|0}if((gzL(x,0,5)|0)==0){break}else{D=1}i=b;return D|0}}while(0);x=c[3529526]|0;A=c[2406524]|0;E=0;do{F=E<<6;gGz(A+F|0,0,64);G=E<<7;H=0;do{I=1<<3-H;J=(c[611600+(H<<2)>>2]|0)+G|0;K=0;do{L=J+(c[6669224+(K<<2)>>2]|0)|0;M=(K<<3)+F|0;N=0;do{O=L+(c[612480+(N<<2)>>2]|0)|0;if(((d[x+((O|0)/8|0)|0]|0)&128>>>((O&7)>>>0)|0)!=0){O=A+(M+N)|0;a[O]=(d[O]|0|I)&255}N=N+1|0;}while((N|0)<8);K=K+1|0;}while((K|0)<8);H=H+1|0;}while((H|0)<4);E=E+1|0;}while((E|0)<32768);gGz(x|0,-1|0,1048576);if((c[3542200]|0)==0){D=1;i=b;return D|0}E=j+108|0;c[E>>2]=0;A=j+100|0;c[A>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,6)|0;do{if((c[E>>2]|0)!=0){H=c[A>>2]|0;c[k>>2]=9534384;F=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[F&16383](k,6,0)|0;if((H|0)<1){D=1;i=b;return D|0}if((gzL(x,0,6)|0)==0){break}else{D=1}i=b;return D|0}}while(0);x=(c[3529526]|0)+131072|0;if((c[3542200]|0)==0){D=1;i=b;return D|0}A=g+108|0;c[A>>2]=0;E=g+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,7)|0;do{if((c[A>>2]|0)!=0){H=c[E>>2]|0;c[h>>2]=9534384;F=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[F&16383](h,7,0)|0;if((H|0)<1){D=1;i=b;return D|0}if((gzL(x,0,7)|0)==0){break}else{D=1}i=b;return D|0}}while(0);x=c[3529526]|0;E=c[3529578]|0;A=0;while(1){H=A<<8;gGz(E+H|0,0,256);F=A<<9;G=0;do{K=1<<3-G;I=(c[961472+(G<<2)>>2]|0)+F|0;J=0;do{N=I+(c[608544+(J<<2)>>2]|0)|0;M=(J<<4)+H|0;L=0;do{O=N+(c[609552+(L<<2)>>2]|0)|0;if(((d[x+((O|0)/8|0)|0]|0)&128>>>((O&7)>>>0)|0)!=0){O=E+(M+L)|0;a[O]=(d[O]|0|K)&255}L=L+1|0;}while((L|0)<16);J=J+1|0;}while((J|0)<16);G=G+1|0;}while((G|0)<4);G=A+1|0;if((G|0)<2048){A=G}else{P=0;break}}while(1){if((P|0)>=1024){break}Q=9638528+(P<<2)|0;if((c[Q>>2]|0)==(x|0)){z=16447;break}else{P=P+1|0}}if((z|0)==16447){gGr(x);c[Q>>2]=0}c[3529526]=0;A=c[3527282]|0;if((c[3542200]|0)==0){D=1;i=b;return D|0}E=e+108|0;c[E>>2]=0;G=e+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,8)|0;do{if((c[E>>2]|0)!=0){H=c[G>>2]|0;c[f>>2]=9534384;F=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[F&16383](f,8,0)|0;if((H|0)<1){D=1;i=b;return D|0}if((gzL(A,0,8)|0)==0){break}else{D=1}i=b;return D|0}}while(0);A=c[2385838]|0;G=c[3529358]|0;W4(A,G,A,0,32768,19088743,1985229328,25928,36);E=0;do{x=(E<<14)+65536|0;H=A+x|0;W4(H,G+x|0,H,32768,16384,19088743,1985229328,25928,36);E=E+1|0;}while((E|0)<16);dO0();dO1();D=0;i=b;return D|0}}while(0);c[2426752]=0;D=1;i=b;return D|0}function dN5(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6968892+(b*112|0)>>2];c[a+104>>2]=c[6968896+(b*112|0)>>2];c[a+108>>2]=c[6968900+(b*112|0)>>2];d=0;return d|0}function dN6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=6968792+(b*112|0);e=0;return e|0}function dN7(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3617636+(b*112|0)>>2];c[a+104>>2]=c[3617640+(b*112|0)>>2];c[a+108>>2]=c[3617644+(b*112|0)>>2];d=0;return d|0}function dN8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=3617536+(b*112|0);e=0;return e|0}function dN9(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6818396+(b*112|0)>>2];c[a+104>>2]=c[6818400+(b*112|0)>>2];c[a+108>>2]=c[6818404+(b*112|0)>>2];d=0;return d|0}function dOa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=6818296+(b*112|0);e=0;return e|0}function dOb(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;b=i;i=i+1200|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;l=b+360|0;m=b+472|0;n=b+480|0;o=b+592|0;p=b+600|0;q=b+712|0;r=b+720|0;s=b+832|0;t=b+840|0;u=b+952|0;v=b+960|0;w=b+1072|0;x=b+1080|0;y=b+1192|0;c[2426752]=0;c[2385838]=0;c[3529358]=327680;c[3527282]=655360;c[2405678]=786432;c[2385856]=786432;c[2439618]=794624;c[3531098]=798720;c[3527218]=800768;c[2443418]=804864;c[2411714]=808960;c[2406524]=808960;c[3529578]=2906112;c[3530044]=3430400;z=0;while(1){if((z|0)>=1024){break}A=9638528+(z<<2)|0;if((c[A>>2]|0)==0){B=16524;break}else{z=z+1|0}}do{if((B|0)==16524){z=gGq(3438592)|0;c[A>>2]=z;if((z|0)==0){break}c[2426752]=z;gGz(z|0,0,3438592);c[2385838]=z;c[3529358]=z+327680;c[3527282]=z+655360;C=z+786432|0;c[2405678]=C;c[2385856]=C;c[2439618]=z+794624;c[3531098]=z+798720;c[3527218]=z+800768;c[2443418]=z+804864;C=z+808960|0;c[2411714]=C;c[2406524]=C;c[3529578]=z+2906112;c[3530044]=z+3430400;c[2414256]=z+3438592;z=0;while(1){if((z|0)>=1024){D=0;break}E=9638528+(z<<2)|0;if((c[E>>2]|0)==0){B=16529;break}else{z=z+1|0}}do{if((B|0)==16529){z=gGq(1048576)|0;c[E>>2]=z;if((z|0)==0){D=0;break}gGz(z|0,0,1048576);D=z}}while(0);c[3529526]=D;z=c[3529358]|0;if((c[3542200]|0)==0){F=1;i=b;return F|0}C=x+108|0;c[C>>2]=0;G=x+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,0)|0;do{if((c[C>>2]|0)!=0){H=c[G>>2]|0;c[y>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](y,0,0)|0;if((H|0)<1){F=1;i=b;return F|0}if((gzL(z,0,0)|0)==0){break}else{F=1}i=b;return F|0}}while(0);z=(c[3529358]|0)+65536|0;if((c[3542200]|0)==0){F=1;i=b;return F|0}G=v+108|0;c[G>>2]=0;C=v+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,1)|0;do{if((c[G>>2]|0)!=0){H=c[C>>2]|0;c[w>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](w,1,0)|0;if((H|0)<1){F=1;i=b;return F|0}if((gzL(z,0,1)|0)==0){break}else{F=1}i=b;return F|0}}while(0);z=(c[2385838]|0)+65536|0;if((c[3542200]|0)==0){F=1;i=b;return F|0}C=t+108|0;c[C>>2]=0;G=t+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,2)|0;do{if((c[C>>2]|0)!=0){H=c[G>>2]|0;c[u>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](u,2,0)|0;if((H|0)<1){F=1;i=b;return F|0}if((gzL(z,0,2)|0)==0){break}else{F=1}i=b;return F|0}}while(0);z=c[2385838]|0;G=(c[3529358]|0)+32768|0;gGC(z|0,G|0,32768)|0;gGz(G|0,0,32768);G=c[3529526]|0;gGz(G|0,-1|0,1048576);if((c[3542200]|0)==0){F=1;i=b;return F|0}z=r+108|0;c[z>>2]=0;C=r+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,3)|0;do{if((c[z>>2]|0)!=0){H=c[C>>2]|0;c[s>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](s,3,0)|0;if((H|0)<1){F=1;i=b;return F|0}if((gzL(G,0,3)|0)==0){break}else{F=1}i=b;return F|0}}while(0);G=(c[3529526]|0)+131072|0;if((c[3542200]|0)==0){F=1;i=b;return F|0}C=p+108|0;c[C>>2]=0;z=p+100|0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,4)|0;do{if((c[C>>2]|0)!=0){H=c[z>>2]|0;c[q>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](q,4,0)|0;if((H|0)<1){F=1;i=b;return F|0}if((gzL(G,0,4)|0)==0){break}else{F=1}i=b;return F|0}}while(0);G=(c[3529526]|0)+524288|0;if((c[3542200]|0)==0){F=1;i=b;return F|0}z=n+108|0;c[z>>2]=0;C=n+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,5)|0;do{if((c[z>>2]|0)!=0){H=c[C>>2]|0;c[o>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](o,5,0)|0;if((H|0)<1){F=1;i=b;return F|0}if((gzL(G,0,5)|0)==0){break}else{F=1}i=b;return F|0}}while(0);G=(c[3529526]|0)+655360|0;if((c[3542200]|0)==0){F=1;i=b;return F|0}C=l+108|0;c[C>>2]=0;z=l+100|0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,6)|0;do{if((c[C>>2]|0)!=0){H=c[z>>2]|0;c[m>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](m,6,0)|0;if((H|0)<1){F=1;i=b;return F|0}if((gzL(G,0,6)|0)==0){break}else{F=1}i=b;return F|0}}while(0);G=c[3529526]|0;z=c[2406524]|0;C=0;do{H=C<<6;gGz(z+H|0,0,64);I=C<<7;J=0;do{K=1<<3-J;L=(c[611600+(J<<2)>>2]|0)+I|0;M=0;do{N=L+(c[6669224+(M<<2)>>2]|0)|0;O=(M<<3)+H|0;P=0;do{Q=N+(c[612480+(P<<2)>>2]|0)|0;if(((d[G+((Q|0)/8|0)|0]|0)&128>>>((Q&7)>>>0)|0)!=0){Q=z+(O+P)|0;a[Q]=(d[Q]|0|K)&255}P=P+1|0;}while((P|0)<8);M=M+1|0;}while((M|0)<8);J=J+1|0;}while((J|0)<4);C=C+1|0;}while((C|0)<32768);gGz(G|0,-1|0,1048576);if((c[3542200]|0)==0){F=1;i=b;return F|0}C=j+108|0;c[C>>2]=0;z=j+100|0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,7)|0;do{if((c[C>>2]|0)!=0){J=c[z>>2]|0;c[k>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](k,7,0)|0;if((J|0)<1){F=1;i=b;return F|0}if((gzL(G,0,7)|0)==0){break}else{F=1}i=b;return F|0}}while(0);G=(c[3529526]|0)+131072|0;if((c[3542200]|0)==0){F=1;i=b;return F|0}z=g+108|0;c[z>>2]=0;C=g+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,8)|0;do{if((c[z>>2]|0)!=0){J=c[C>>2]|0;c[h>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](h,8,0)|0;if((J|0)<1){F=1;i=b;return F|0}if((gzL(G,0,8)|0)==0){break}else{F=1}i=b;return F|0}}while(0);G=c[3529526]|0;C=c[3529578]|0;z=0;while(1){J=z<<8;gGz(C+J|0,0,256);H=z<<9;I=0;do{M=1<<3-I;K=(c[961472+(I<<2)>>2]|0)+H|0;L=0;do{P=K+(c[608544+(L<<2)>>2]|0)|0;O=(L<<4)+J|0;N=0;do{Q=P+(c[609552+(N<<2)>>2]|0)|0;if(((d[G+((Q|0)/8|0)|0]|0)&128>>>((Q&7)>>>0)|0)!=0){Q=C+(O+N)|0;a[Q]=(d[Q]|0|M)&255}N=N+1|0;}while((N|0)<16);L=L+1|0;}while((L|0)<16);I=I+1|0;}while((I|0)<4);I=z+1|0;if((I|0)<2048){z=I}else{R=0;break}}while(1){if((R|0)>=1024){break}S=9638528+(R<<2)|0;if((c[S>>2]|0)==(G|0)){B=16589;break}else{R=R+1|0}}if((B|0)==16589){gGr(G);c[S>>2]=0}c[3529526]=0;z=c[3527282]|0;if((c[3542200]|0)==0){F=1;i=b;return F|0}C=e+108|0;c[C>>2]=0;I=e+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,9)|0;do{if((c[C>>2]|0)!=0){J=c[I>>2]|0;c[f>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](f,9,0)|0;if((J|0)<1){F=1;i=b;return F|0}if((gzL(z,0,9)|0)==0){break}else{F=1}i=b;return F|0}}while(0);dO0();dO1();F=0;i=b;return F|0}}while(0);c[2426752]=0;F=1;i=b;return F|0}function dOc(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3633132+(b*112|0)>>2];c[a+104>>2]=c[3633136+(b*112|0)>>2];c[a+108>>2]=c[3633140+(b*112|0)>>2];d=0;return d|0}function dOd(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=3633032+(b*112|0);e=0;return e|0}function dOe(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;b=i;i=i+1440|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;l=b+360|0;m=b+472|0;n=b+480|0;o=b+592|0;p=b+600|0;q=b+712|0;r=b+720|0;s=b+832|0;t=b+840|0;u=b+952|0;v=b+960|0;w=b+1072|0;x=b+1080|0;y=b+1192|0;z=b+1200|0;A=b+1312|0;B=b+1320|0;C=b+1432|0;c[2426752]=0;c[2385838]=0;c[3529358]=327680;c[3527282]=655360;c[2405678]=786432;c[2385856]=786432;c[2439618]=794624;c[3531098]=798720;c[3527218]=800768;c[2443418]=804864;c[2411714]=808960;c[2406524]=808960;c[3529578]=2906112;c[3530044]=3430400;D=0;while(1){if((D|0)>=1024){break}E=9638528+(D<<2)|0;if((c[E>>2]|0)==0){F=16643;break}else{D=D+1|0}}do{if((F|0)==16643){D=gGq(3438592)|0;c[E>>2]=D;if((D|0)==0){break}c[2426752]=D;gGz(D|0,0,3438592);c[2385838]=D;c[3529358]=D+327680;c[3527282]=D+655360;G=D+786432|0;c[2405678]=G;c[2385856]=G;c[2439618]=D+794624;c[3531098]=D+798720;c[3527218]=D+800768;c[2443418]=D+804864;G=D+808960|0;c[2411714]=G;c[2406524]=G;c[3529578]=D+2906112;c[3530044]=D+3430400;c[2414256]=D+3438592;D=0;while(1){if((D|0)>=1024){H=0;break}I=9638528+(D<<2)|0;if((c[I>>2]|0)==0){F=16648;break}else{D=D+1|0}}do{if((F|0)==16648){D=gGq(1048576)|0;c[I>>2]=D;if((D|0)==0){H=0;break}gGz(D|0,0,1048576);H=D}}while(0);c[3529526]=H;D=c[3529358]|0;if((c[3542200]|0)==0){J=1;i=b;return J|0}G=B+108|0;c[G>>2]=0;K=B+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](B,0)|0;do{if((c[G>>2]|0)!=0){L=c[K>>2]|0;c[C>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](C,0,0)|0;if((L|0)<1){J=1;i=b;return J|0}if((gzL(D,0,0)|0)==0){break}else{J=1}i=b;return J|0}}while(0);D=(c[3529358]|0)+65536|0;if((c[3542200]|0)==0){J=1;i=b;return J|0}K=z+108|0;c[K>>2]=0;G=z+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,1)|0;do{if((c[K>>2]|0)!=0){L=c[G>>2]|0;c[A>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](A,1,0)|0;if((L|0)<1){J=1;i=b;return J|0}if((gzL(D,0,1)|0)==0){break}else{J=1}i=b;return J|0}}while(0);D=(c[2385838]|0)+65536|0;if((c[3542200]|0)==0){J=1;i=b;return J|0}G=x+108|0;c[G>>2]=0;K=x+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,2)|0;do{if((c[G>>2]|0)!=0){L=c[K>>2]|0;c[y>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](y,2,0)|0;if((L|0)<1){J=1;i=b;return J|0}if((gzL(D,0,2)|0)==0){break}else{J=1}i=b;return J|0}}while(0);D=c[2385838]|0;K=(c[3529358]|0)+32768|0;gGC(D|0,K|0,32768)|0;gGz(K|0,0,32768);K=c[3529526]|0;gGz(K|0,-1|0,1048576);if((c[3542200]|0)==0){J=1;i=b;return J|0}D=v+108|0;c[D>>2]=0;G=v+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,3)|0;do{if((c[D>>2]|0)!=0){L=c[G>>2]|0;c[w>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](w,3,0)|0;if((L|0)<1){J=1;i=b;return J|0}if((gzL(K,0,3)|0)==0){break}else{J=1}i=b;return J|0}}while(0);K=(c[3529526]|0)+131072|0;if((c[3542200]|0)==0){J=1;i=b;return J|0}G=t+108|0;c[G>>2]=0;D=t+100|0;c[D>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,4)|0;do{if((c[G>>2]|0)!=0){L=c[D>>2]|0;c[u>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](u,4,0)|0;if((L|0)<1){J=1;i=b;return J|0}if((gzL(K,0,4)|0)==0){break}else{J=1}i=b;return J|0}}while(0);K=(c[3529526]|0)+524288|0;if((c[3542200]|0)==0){J=1;i=b;return J|0}D=r+108|0;c[D>>2]=0;G=r+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,5)|0;do{if((c[D>>2]|0)!=0){L=c[G>>2]|0;c[s>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](s,5,0)|0;if((L|0)<1){J=1;i=b;return J|0}if((gzL(K,0,5)|0)==0){break}else{J=1}i=b;return J|0}}while(0);K=(c[3529526]|0)+655360|0;if((c[3542200]|0)==0){J=1;i=b;return J|0}G=p+108|0;c[G>>2]=0;D=p+100|0;c[D>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,6)|0;do{if((c[G>>2]|0)!=0){L=c[D>>2]|0;c[q>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](q,6,0)|0;if((L|0)<1){J=1;i=b;return J|0}if((gzL(K,0,6)|0)==0){break}else{J=1}i=b;return J|0}}while(0);K=c[3529526]|0;D=c[2406524]|0;G=0;do{L=G<<6;gGz(D+L|0,0,64);M=G<<7;N=0;do{O=1<<3-N;P=(c[611600+(N<<2)>>2]|0)+M|0;Q=0;do{R=P+(c[6669224+(Q<<2)>>2]|0)|0;S=(Q<<3)+L|0;T=0;do{U=R+(c[612480+(T<<2)>>2]|0)|0;if(((d[K+((U|0)/8|0)|0]|0)&128>>>((U&7)>>>0)|0)!=0){U=D+(S+T)|0;a[U]=(d[U]|0|O)&255}T=T+1|0;}while((T|0)<8);Q=Q+1|0;}while((Q|0)<8);N=N+1|0;}while((N|0)<4);G=G+1|0;}while((G|0)<32768);gGz(K|0,-1|0,1048576);if((c[3542200]|0)==0){J=1;i=b;return J|0}G=n+108|0;c[G>>2]=0;D=n+100|0;c[D>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,7)|0;do{if((c[G>>2]|0)!=0){N=c[D>>2]|0;c[o>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](o,7,0)|0;if((N|0)<1){J=1;i=b;return J|0}if((gzL(K,0,7)|0)==0){break}else{J=1}i=b;return J|0}}while(0);K=(c[3529526]|0)+65536|0;if((c[3542200]|0)==0){J=1;i=b;return J|0}D=l+108|0;c[D>>2]=0;G=l+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,8)|0;do{if((c[D>>2]|0)!=0){N=c[G>>2]|0;c[m>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](m,8,0)|0;if((N|0)<1){J=1;i=b;return J|0}if((gzL(K,0,8)|0)==0){break}else{J=1}i=b;return J|0}}while(0);K=(c[3529526]|0)+131072|0;if((c[3542200]|0)==0){J=1;i=b;return J|0}G=j+108|0;c[G>>2]=0;D=j+100|0;c[D>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,9)|0;do{if((c[G>>2]|0)!=0){N=c[D>>2]|0;c[k>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](k,9,0)|0;if((N|0)<1){J=1;i=b;return J|0}if((gzL(K,0,9)|0)==0){break}else{J=1}i=b;return J|0}}while(0);K=(c[3529526]|0)+196608|0;if((c[3542200]|0)==0){J=1;i=b;return J|0}D=g+108|0;c[D>>2]=0;G=g+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,10)|0;do{if((c[D>>2]|0)!=0){N=c[G>>2]|0;c[h>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](h,10,0)|0;if((N|0)<1){J=1;i=b;return J|0}if((gzL(K,0,10)|0)==0){break}else{J=1}i=b;return J|0}}while(0);K=c[3529526]|0;G=c[3529578]|0;D=0;while(1){N=D<<8;gGz(G+N|0,0,256);L=D<<9;M=0;do{Q=1<<3-M;O=(c[961472+(M<<2)>>2]|0)+L|0;P=0;do{T=O+(c[608544+(P<<2)>>2]|0)|0;S=(P<<4)+N|0;R=0;do{U=T+(c[609552+(R<<2)>>2]|0)|0;if(((d[K+((U|0)/8|0)|0]|0)&128>>>((U&7)>>>0)|0)!=0){U=G+(S+R)|0;a[U]=(d[U]|0|Q)&255}R=R+1|0;}while((R|0)<16);P=P+1|0;}while((P|0)<16);M=M+1|0;}while((M|0)<4);M=D+1|0;if((M|0)<2048){D=M}else{V=0;break}}while(1){if((V|0)>=1024){break}W=9638528+(V<<2)|0;if((c[W>>2]|0)==(K|0)){F=16716;break}else{V=V+1|0}}if((F|0)==16716){gGr(K);c[W>>2]=0}c[3529526]=0;D=c[3527282]|0;if((c[3542200]|0)==0){J=1;i=b;return J|0}G=e+108|0;c[G>>2]=0;M=e+100|0;c[M>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,11)|0;do{if((c[G>>2]|0)!=0){N=c[M>>2]|0;c[f>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](f,11,0)|0;if((N|0)<1){J=1;i=b;return J|0}if((gzL(D,0,11)|0)==0){break}else{J=1}i=b;return J|0}}while(0);dO0();dO1();J=0;i=b;return J|0}}while(0);c[2426752]=0;J=1;i=b;return J|0}function dOf(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6178812+(b*112|0)>>2];c[a+104>>2]=c[6178816+(b*112|0)>>2];c[a+108>>2]=c[6178820+(b*112|0)>>2];d=0;return d|0}function dOg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=6178712+(b*112|0);e=0;return e|0}function dOh(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;b=i;i=i+1080|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;l=b+360|0;m=b+472|0;n=b+480|0;o=b+592|0;p=b+600|0;q=b+712|0;r=b+720|0;s=b+832|0;t=b+840|0;u=b+952|0;v=b+960|0;w=b+1072|0;c[2426752]=0;c[2385838]=0;c[3529358]=327680;c[3527282]=655360;c[2405678]=786432;c[2385856]=786432;c[2439618]=794624;c[3531098]=798720;c[3527218]=800768;c[2443418]=804864;c[2411714]=808960;c[2406524]=808960;c[3529578]=2906112;c[3530044]=3430400;x=0;while(1){if((x|0)>=1024){break}y=9638528+(x<<2)|0;if((c[y>>2]|0)==0){z=16776;break}else{x=x+1|0}}do{if((z|0)==16776){x=gGq(3438592)|0;c[y>>2]=x;if((x|0)==0){break}c[2426752]=x;gGz(x|0,0,3438592);c[2385838]=x;c[3529358]=x+327680;c[3527282]=x+655360;A=x+786432|0;c[2405678]=A;c[2385856]=A;c[2439618]=x+794624;c[3531098]=x+798720;c[3527218]=x+800768;c[2443418]=x+804864;A=x+808960|0;c[2411714]=A;c[2406524]=A;c[3529578]=x+2906112;c[3530044]=x+3430400;c[2414256]=x+3438592;x=0;while(1){if((x|0)>=1024){B=0;break}C=9638528+(x<<2)|0;if((c[C>>2]|0)==0){z=16781;break}else{x=x+1|0}}do{if((z|0)==16781){x=gGq(1048576)|0;c[C>>2]=x;if((x|0)==0){B=0;break}gGz(x|0,0,1048576);B=x}}while(0);c[3529526]=B;x=c[3529358]|0;if((c[3542200]|0)==0){D=1;i=b;return D|0}A=v+108|0;c[A>>2]=0;E=v+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,0)|0;do{if((c[A>>2]|0)!=0){F=c[E>>2]|0;c[w>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](w,0,0)|0;if((F|0)<1){D=1;i=b;return D|0}if((gzL(x,0,0)|0)==0){break}else{D=1}i=b;return D|0}}while(0);x=(c[3529358]|0)+65536|0;if((c[3542200]|0)==0){D=1;i=b;return D|0}E=t+108|0;c[E>>2]=0;A=t+100|0;c[A>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,1)|0;do{if((c[E>>2]|0)!=0){F=c[A>>2]|0;c[u>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](u,1,0)|0;if((F|0)<1){D=1;i=b;return D|0}if((gzL(x,0,1)|0)==0){break}else{D=1}i=b;return D|0}}while(0);x=c[2385838]|0;A=c[3529358]|0;E=A+32768|0;gGC(x|0,E|0,32768)|0;F=x+65536|0;x=A+196608|0;gGC(F|0,x|0,131072)|0;gGz(E|0,0,32768);E=c[3529526]|0;gGz(E|0,-1|0,1048576);if((c[3542200]|0)==0){D=1;i=b;return D|0}x=r+108|0;c[x>>2]=0;F=r+100|0;c[F>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,2)|0;do{if((c[x>>2]|0)!=0){A=c[F>>2]|0;c[s>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](s,2,0)|0;if((A|0)<1){D=1;i=b;return D|0}if((gzL(E,0,2)|0)==0){break}else{D=1}i=b;return D|0}}while(0);E=(c[3529526]|0)+131072|0;if((c[3542200]|0)==0){D=1;i=b;return D|0}F=p+108|0;c[F>>2]=0;x=p+100|0;c[x>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,3)|0;do{if((c[F>>2]|0)!=0){A=c[x>>2]|0;c[q>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](q,3,0)|0;if((A|0)<1){D=1;i=b;return D|0}if((gzL(E,0,3)|0)==0){break}else{D=1}i=b;return D|0}}while(0);E=(c[3529526]|0)+524288|0;if((c[3542200]|0)==0){D=1;i=b;return D|0}x=n+108|0;c[x>>2]=0;F=n+100|0;c[F>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,4)|0;do{if((c[x>>2]|0)!=0){A=c[F>>2]|0;c[o>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](o,4,0)|0;if((A|0)<1){D=1;i=b;return D|0}if((gzL(E,0,4)|0)==0){break}else{D=1}i=b;return D|0}}while(0);E=(c[3529526]|0)+655360|0;if((c[3542200]|0)==0){D=1;i=b;return D|0}F=l+108|0;c[F>>2]=0;x=l+100|0;c[x>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,5)|0;do{if((c[F>>2]|0)!=0){A=c[x>>2]|0;c[m>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](m,5,0)|0;if((A|0)<1){D=1;i=b;return D|0}if((gzL(E,0,5)|0)==0){break}else{D=1}i=b;return D|0}}while(0);E=c[3529526]|0;x=c[2406524]|0;F=0;do{A=F<<6;gGz(x+A|0,0,64);G=F<<7;H=0;do{I=1<<3-H;J=(c[611600+(H<<2)>>2]|0)+G|0;K=0;do{L=J+(c[6669224+(K<<2)>>2]|0)|0;M=(K<<3)+A|0;N=0;do{O=L+(c[612480+(N<<2)>>2]|0)|0;if(((d[E+((O|0)/8|0)|0]|0)&128>>>((O&7)>>>0)|0)!=0){O=x+(M+N)|0;a[O]=(d[O]|0|I)&255}N=N+1|0;}while((N|0)<8);K=K+1|0;}while((K|0)<8);H=H+1|0;}while((H|0)<4);F=F+1|0;}while((F|0)<32768);gGz(E|0,-1|0,1048576);if((c[3542200]|0)==0){D=1;i=b;return D|0}F=j+108|0;c[F>>2]=0;x=j+100|0;c[x>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,6)|0;do{if((c[F>>2]|0)!=0){H=c[x>>2]|0;c[k>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](k,6,0)|0;if((H|0)<1){D=1;i=b;return D|0}if((gzL(E,0,6)|0)==0){break}else{D=1}i=b;return D|0}}while(0);E=(c[3529526]|0)+131072|0;if((c[3542200]|0)==0){D=1;i=b;return D|0}x=g+108|0;c[x>>2]=0;F=g+100|0;c[F>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,7)|0;do{if((c[x>>2]|0)!=0){H=c[F>>2]|0;c[h>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](h,7,0)|0;if((H|0)<1){D=1;i=b;return D|0}if((gzL(E,0,7)|0)==0){break}else{D=1}i=b;return D|0}}while(0);E=c[3529526]|0;F=c[3529578]|0;x=0;while(1){H=x<<8;gGz(F+H|0,0,256);A=x<<9;G=0;do{K=1<<3-G;I=(c[961472+(G<<2)>>2]|0)+A|0;J=0;do{N=I+(c[608544+(J<<2)>>2]|0)|0;M=(J<<4)+H|0;L=0;do{O=N+(c[609552+(L<<2)>>2]|0)|0;if(((d[E+((O|0)/8|0)|0]|0)&128>>>((O&7)>>>0)|0)!=0){O=F+(M+L)|0;a[O]=(d[O]|0|K)&255}L=L+1|0;}while((L|0)<16);J=J+1|0;}while((J|0)<16);G=G+1|0;}while((G|0)<4);G=x+1|0;if((G|0)<2048){x=G}else{P=0;break}}while(1){if((P|0)>=1024){break}Q=9638528+(P<<2)|0;if((c[Q>>2]|0)==(E|0)){z=16837;break}else{P=P+1|0}}if((z|0)==16837){gGr(E);c[Q>>2]=0}c[3529526]=0;x=c[3527282]|0;if((c[3542200]|0)==0){D=1;i=b;return D|0}F=e+108|0;c[F>>2]=0;G=e+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,8)|0;do{if((c[F>>2]|0)!=0){H=c[G>>2]|0;c[f>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](f,8,0)|0;if((H|0)<1){D=1;i=b;return D|0}if((gzL(x,0,8)|0)==0){break}else{D=1}i=b;return D|0}}while(0);dO0();dO1();D=0;i=b;return D|0}}while(0);c[2426752]=0;D=1;i=b;return D|0}function dOi(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6385580+(b*112|0)>>2];c[a+104>>2]=c[6385584+(b*112|0)>>2];c[a+108>>2]=c[6385588+(b*112|0)>>2];d=0;return d|0}function dOj(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=6385480+(b*112|0);e=0;return e|0}function dOk(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3593704+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dOl(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;b=i;i=i+1680|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;l=b+360|0;m=b+472|0;n=b+480|0;o=b+592|0;p=b+600|0;q=b+712|0;r=b+720|0;s=b+832|0;t=b+840|0;u=b+952|0;v=b+960|0;w=b+1072|0;x=b+1080|0;y=b+1192|0;z=b+1200|0;A=b+1312|0;B=b+1320|0;C=b+1432|0;D=b+1440|0;E=b+1552|0;F=b+1560|0;G=b+1672|0;c[2426752]=0;c[2385838]=0;c[3529358]=327680;c[3527282]=655360;c[2405678]=786432;c[2385856]=786432;c[2439618]=794624;c[3531098]=798720;c[3527218]=800768;c[2443418]=804864;c[2411714]=808960;c[2406524]=808960;c[3529578]=2906112;c[3530044]=3430400;H=0;while(1){if((H|0)>=1024){break}I=9638528+(H<<2)|0;if((c[I>>2]|0)==0){J=16895;break}else{H=H+1|0}}do{if((J|0)==16895){H=gGq(3438592)|0;c[I>>2]=H;if((H|0)==0){break}c[2426752]=H;gGz(H|0,0,3438592);c[2385838]=H;c[3529358]=H+327680;c[3527282]=H+655360;K=H+786432|0;c[2405678]=K;c[2385856]=K;c[2439618]=H+794624;c[3531098]=H+798720;c[3527218]=H+800768;c[2443418]=H+804864;K=H+808960|0;c[2411714]=K;c[2406524]=K;c[3529578]=H+2906112;c[3530044]=H+3430400;c[2414256]=H+3438592;H=0;while(1){if((H|0)>=1024){L=0;break}M=9638528+(H<<2)|0;if((c[M>>2]|0)==0){J=16900;break}else{H=H+1|0}}do{if((J|0)==16900){H=gGq(1048576)|0;c[M>>2]=H;if((H|0)==0){L=0;break}gGz(H|0,0,1048576);L=H}}while(0);c[3529526]=L;H=c[2385838]|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}K=F+108|0;c[K>>2]=0;O=F+100|0;c[O>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](F,0)|0;do{if((c[K>>2]|0)!=0){P=c[O>>2]|0;c[G>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](G,0,0)|0;if((P|0)<1){N=1;i=b;return N|0}if((gzL(H,0,0)|0)==0){break}else{N=1}i=b;return N|0}}while(0);H=(c[2385838]|0)+65536|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}O=D+108|0;c[O>>2]=0;K=D+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](D,1)|0;do{if((c[O>>2]|0)!=0){P=c[K>>2]|0;c[E>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](E,1,0)|0;if((P|0)<1){N=1;i=b;return N|0}if((gzL(H,0,1)|0)==0){break}else{N=1}i=b;return N|0}}while(0);H=(c[2385838]|0)+196608|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}K=B+108|0;c[K>>2]=0;O=B+100|0;c[O>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](B,2)|0;do{if((c[K>>2]|0)!=0){P=c[O>>2]|0;c[C>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](C,2,0)|0;if((P|0)<1){N=1;i=b;return N|0}if((gzL(H,0,2)|0)==0){break}else{N=1}i=b;return N|0}}while(0);H=c[3529526]|0;gGz(H|0,-1|0,1048576);if((c[3542200]|0)==0){N=1;i=b;return N|0}O=z+108|0;c[O>>2]=0;K=z+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,3)|0;do{if((c[O>>2]|0)!=0){P=c[K>>2]|0;c[A>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](A,3,0)|0;if((P|0)<1){N=1;i=b;return N|0}if((gzL(H,0,3)|0)==0){break}else{N=1}i=b;return N|0}}while(0);H=(c[3529526]|0)+131072|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}K=x+108|0;c[K>>2]=0;O=x+100|0;c[O>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,4)|0;do{if((c[K>>2]|0)!=0){P=c[O>>2]|0;c[y>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](y,4,0)|0;if((P|0)<1){N=1;i=b;return N|0}if((gzL(H,0,4)|0)==0){break}else{N=1}i=b;return N|0}}while(0);H=(c[3529526]|0)+262144|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}O=v+108|0;c[O>>2]=0;K=v+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,5)|0;do{if((c[O>>2]|0)!=0){P=c[K>>2]|0;c[w>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](w,5,0)|0;if((P|0)<1){N=1;i=b;return N|0}if((gzL(H,0,5)|0)==0){break}else{N=1}i=b;return N|0}}while(0);H=(c[3529526]|0)+393216|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}K=t+108|0;c[K>>2]=0;O=t+100|0;c[O>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,6)|0;do{if((c[K>>2]|0)!=0){P=c[O>>2]|0;c[u>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](u,6,0)|0;if((P|0)<1){N=1;i=b;return N|0}if((gzL(H,0,6)|0)==0){break}else{N=1}i=b;return N|0}}while(0);H=(c[3529526]|0)+524288|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}O=r+108|0;c[O>>2]=0;K=r+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,7)|0;do{if((c[O>>2]|0)!=0){P=c[K>>2]|0;c[s>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](s,7,0)|0;if((P|0)<1){N=1;i=b;return N|0}if((gzL(H,0,7)|0)==0){break}else{N=1}i=b;return N|0}}while(0);H=(c[3529526]|0)+655360|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}K=p+108|0;c[K>>2]=0;O=p+100|0;c[O>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,8)|0;do{if((c[K>>2]|0)!=0){P=c[O>>2]|0;c[q>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](q,8,0)|0;if((P|0)<1){N=1;i=b;return N|0}if((gzL(H,0,8)|0)==0){break}else{N=1}i=b;return N|0}}while(0);H=(c[3529526]|0)+786432|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}O=n+108|0;c[O>>2]=0;K=n+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,9)|0;do{if((c[O>>2]|0)!=0){P=c[K>>2]|0;c[o>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](o,9,0)|0;if((P|0)<1){N=1;i=b;return N|0}if((gzL(H,0,9)|0)==0){break}else{N=1}i=b;return N|0}}while(0);H=(c[3529526]|0)+917504|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}K=l+108|0;c[K>>2]=0;O=l+100|0;c[O>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,10)|0;do{if((c[K>>2]|0)!=0){P=c[O>>2]|0;c[m>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](m,10,0)|0;if((P|0)<1){N=1;i=b;return N|0}if((gzL(H,0,10)|0)==0){break}else{N=1}i=b;return N|0}}while(0);H=c[3529526]|0;O=c[2406524]|0;K=0;do{P=K<<6;gGz(O+P|0,0,64);Q=K<<7;R=0;do{S=1<<3-R;T=(c[611600+(R<<2)>>2]|0)+Q|0;U=0;do{V=T+(c[6669224+(U<<2)>>2]|0)|0;W=(U<<3)+P|0;X=0;do{Y=V+(c[612480+(X<<2)>>2]|0)|0;if(((d[H+((Y|0)/8|0)|0]|0)&128>>>((Y&7)>>>0)|0)!=0){Y=O+(W+X)|0;a[Y]=(d[Y]|0|S)&255}X=X+1|0;}while((X|0)<8);U=U+1|0;}while((U|0)<8);R=R+1|0;}while((R|0)<4);K=K+1|0;}while((K|0)<32768);gGz(H|0,-1|0,1048576);if((c[3542200]|0)==0){N=1;i=b;return N|0}K=j+108|0;c[K>>2]=0;O=j+100|0;c[O>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,11)|0;do{if((c[K>>2]|0)!=0){R=c[O>>2]|0;c[k>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](k,11,0)|0;if((R|0)<1){N=1;i=b;return N|0}if((gzL(H,0,11)|0)==0){break}else{N=1}i=b;return N|0}}while(0);H=(c[3529526]|0)+131072|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}O=g+108|0;c[O>>2]=0;K=g+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,12)|0;do{if((c[O>>2]|0)!=0){R=c[K>>2]|0;c[h>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](h,12,0)|0;if((R|0)<1){N=1;i=b;return N|0}if((gzL(H,0,12)|0)==0){break}else{N=1}i=b;return N|0}}while(0);H=c[3529526]|0;K=c[3529578]|0;O=0;while(1){R=O<<8;gGz(K+R|0,0,256);P=O<<9;Q=0;do{U=1<<3-Q;S=(c[961472+(Q<<2)>>2]|0)+P|0;T=0;do{X=S+(c[608544+(T<<2)>>2]|0)|0;W=(T<<4)+R|0;V=0;do{Y=X+(c[609552+(V<<2)>>2]|0)|0;if(((d[H+((Y|0)/8|0)|0]|0)&128>>>((Y&7)>>>0)|0)!=0){Y=K+(W+V)|0;a[Y]=(d[Y]|0|U)&255}V=V+1|0;}while((V|0)<16);T=T+1|0;}while((T|0)<16);Q=Q+1|0;}while((Q|0)<4);Q=O+1|0;if((Q|0)<2048){O=Q}else{Z=0;break}}while(1){if((Z|0)>=1024){break}_=9638528+(Z<<2)|0;if((c[_>>2]|0)==(H|0)){J=16976;break}else{Z=Z+1|0}}if((J|0)==16976){gGr(H);c[_>>2]=0}c[3529526]=0;O=c[3527282]|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}K=e+108|0;c[K>>2]=0;Q=e+100|0;c[Q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,13)|0;do{if((c[K>>2]|0)!=0){R=c[Q>>2]|0;c[f>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](f,13,0)|0;if((R|0)<1){N=1;i=b;return N|0}if((gzL(O,0,13)|0)==0){break}else{N=1}i=b;return N|0}}while(0);O=c[2385838]|0;Q=c[3529358]|0;W4(O,Q,O,0,32768,68494903,1079075443,22353,67);K=0;do{H=(K<<14)+65536|0;R=O+H|0;W4(R,Q+H|0,R,32768,16384,68494903,1079075443,22353,67);K=K+1|0;}while((K|0)<16);dO0();dO1();N=0;i=b;return N|0}}while(0);c[2426752]=0;N=1;i=b;return N|0}function dOm(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6277164+(b*112|0)>>2];c[a+104>>2]=c[6277168+(b*112|0)>>2];c[a+108>>2]=c[6277172+(b*112|0)>>2];d=0;return d|0}function dOn(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=6277064+(b*112|0);e=0;return e|0}function dOo(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;b=i;i=i+1680|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;l=b+360|0;m=b+472|0;n=b+480|0;o=b+592|0;p=b+600|0;q=b+712|0;r=b+720|0;s=b+832|0;t=b+840|0;u=b+952|0;v=b+960|0;w=b+1072|0;x=b+1080|0;y=b+1192|0;z=b+1200|0;A=b+1312|0;B=b+1320|0;C=b+1432|0;D=b+1440|0;E=b+1552|0;F=b+1560|0;G=b+1672|0;c[2426752]=0;c[2385838]=0;c[3529358]=327680;c[3527282]=655360;c[2405678]=786432;c[2385856]=786432;c[2439618]=794624;c[3531098]=798720;c[3527218]=800768;c[2443418]=804864;c[2411714]=808960;c[2406524]=808960;c[3529578]=2906112;c[3530044]=3430400;H=0;while(1){if((H|0)>=1024){break}I=9638528+(H<<2)|0;if((c[I>>2]|0)==0){J=17044;break}else{H=H+1|0}}do{if((J|0)==17044){H=gGq(3438592)|0;c[I>>2]=H;if((H|0)==0){break}c[2426752]=H;gGz(H|0,0,3438592);c[2385838]=H;c[3529358]=H+327680;c[3527282]=H+655360;K=H+786432|0;c[2405678]=K;c[2385856]=K;c[2439618]=H+794624;c[3531098]=H+798720;c[3527218]=H+800768;c[2443418]=H+804864;K=H+808960|0;c[2411714]=K;c[2406524]=K;c[3529578]=H+2906112;c[3530044]=H+3430400;c[2414256]=H+3438592;H=0;while(1){if((H|0)>=1024){L=0;break}M=9638528+(H<<2)|0;if((c[M>>2]|0)==0){J=17049;break}else{H=H+1|0}}do{if((J|0)==17049){H=gGq(1048576)|0;c[M>>2]=H;if((H|0)==0){L=0;break}gGz(H|0,0,1048576);L=H}}while(0);c[3529526]=L;H=c[2385838]|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}K=F+108|0;c[K>>2]=0;O=F+100|0;c[O>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](F,0)|0;do{if((c[K>>2]|0)!=0){P=c[O>>2]|0;c[G>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](G,0,0)|0;if((P|0)<1){N=1;i=b;return N|0}if((gzL(H,0,0)|0)==0){break}else{N=1}i=b;return N|0}}while(0);H=(c[2385838]|0)+65536|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}O=D+108|0;c[O>>2]=0;K=D+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](D,1)|0;do{if((c[O>>2]|0)!=0){P=c[K>>2]|0;c[E>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](E,1,0)|0;if((P|0)<1){N=1;i=b;return N|0}if((gzL(H,0,1)|0)==0){break}else{N=1}i=b;return N|0}}while(0);H=(c[2385838]|0)+196608|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}K=B+108|0;c[K>>2]=0;O=B+100|0;c[O>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](B,2)|0;do{if((c[K>>2]|0)!=0){P=c[O>>2]|0;c[C>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](C,2,0)|0;if((P|0)<1){N=1;i=b;return N|0}if((gzL(H,0,2)|0)==0){break}else{N=1}i=b;return N|0}}while(0);H=c[3529526]|0;gGz(H|0,-1|0,1048576);if((c[3542200]|0)==0){N=1;i=b;return N|0}O=z+108|0;c[O>>2]=0;K=z+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,3)|0;do{if((c[O>>2]|0)!=0){P=c[K>>2]|0;c[A>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](A,3,0)|0;if((P|0)<1){N=1;i=b;return N|0}if((gzL(H,0,3)|0)==0){break}else{N=1}i=b;return N|0}}while(0);H=(c[3529526]|0)+131072|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}K=x+108|0;c[K>>2]=0;O=x+100|0;c[O>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,4)|0;do{if((c[K>>2]|0)!=0){P=c[O>>2]|0;c[y>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](y,4,0)|0;if((P|0)<1){N=1;i=b;return N|0}if((gzL(H,0,4)|0)==0){break}else{N=1}i=b;return N|0}}while(0);H=(c[3529526]|0)+262144|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}O=v+108|0;c[O>>2]=0;K=v+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,5)|0;do{if((c[O>>2]|0)!=0){P=c[K>>2]|0;c[w>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](w,5,0)|0;if((P|0)<1){N=1;i=b;return N|0}if((gzL(H,0,5)|0)==0){break}else{N=1}i=b;return N|0}}while(0);H=(c[3529526]|0)+393216|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}K=t+108|0;c[K>>2]=0;O=t+100|0;c[O>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,6)|0;do{if((c[K>>2]|0)!=0){P=c[O>>2]|0;c[u>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](u,6,0)|0;if((P|0)<1){N=1;i=b;return N|0}if((gzL(H,0,6)|0)==0){break}else{N=1}i=b;return N|0}}while(0);H=(c[3529526]|0)+524288|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}O=r+108|0;c[O>>2]=0;K=r+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,7)|0;do{if((c[O>>2]|0)!=0){P=c[K>>2]|0;c[s>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](s,7,0)|0;if((P|0)<1){N=1;i=b;return N|0}if((gzL(H,0,7)|0)==0){break}else{N=1}i=b;return N|0}}while(0);H=(c[3529526]|0)+655360|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}K=p+108|0;c[K>>2]=0;O=p+100|0;c[O>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,8)|0;do{if((c[K>>2]|0)!=0){P=c[O>>2]|0;c[q>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](q,8,0)|0;if((P|0)<1){N=1;i=b;return N|0}if((gzL(H,0,8)|0)==0){break}else{N=1}i=b;return N|0}}while(0);H=(c[3529526]|0)+786432|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}O=n+108|0;c[O>>2]=0;K=n+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,9)|0;do{if((c[O>>2]|0)!=0){P=c[K>>2]|0;c[o>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](o,9,0)|0;if((P|0)<1){N=1;i=b;return N|0}if((gzL(H,0,9)|0)==0){break}else{N=1}i=b;return N|0}}while(0);H=(c[3529526]|0)+917504|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}K=l+108|0;c[K>>2]=0;O=l+100|0;c[O>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,10)|0;do{if((c[K>>2]|0)!=0){P=c[O>>2]|0;c[m>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](m,10,0)|0;if((P|0)<1){N=1;i=b;return N|0}if((gzL(H,0,10)|0)==0){break}else{N=1}i=b;return N|0}}while(0);H=c[3529526]|0;O=c[2406524]|0;K=0;do{P=K<<6;gGz(O+P|0,0,64);Q=K<<7;R=0;do{S=1<<3-R;T=(c[611600+(R<<2)>>2]|0)+Q|0;U=0;do{V=T+(c[6669224+(U<<2)>>2]|0)|0;W=(U<<3)+P|0;X=0;do{Y=V+(c[612480+(X<<2)>>2]|0)|0;if(((d[H+((Y|0)/8|0)|0]|0)&128>>>((Y&7)>>>0)|0)!=0){Y=O+(W+X)|0;a[Y]=(d[Y]|0|S)&255}X=X+1|0;}while((X|0)<8);U=U+1|0;}while((U|0)<8);R=R+1|0;}while((R|0)<4);K=K+1|0;}while((K|0)<32768);gGz(H|0,-1|0,1048576);if((c[3542200]|0)==0){N=1;i=b;return N|0}K=j+108|0;c[K>>2]=0;O=j+100|0;c[O>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,11)|0;do{if((c[K>>2]|0)!=0){R=c[O>>2]|0;c[k>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](k,11,0)|0;if((R|0)<1){N=1;i=b;return N|0}if((gzL(H,0,11)|0)==0){break}else{N=1}i=b;return N|0}}while(0);H=(c[3529526]|0)+131072|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}O=g+108|0;c[O>>2]=0;K=g+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,12)|0;do{if((c[O>>2]|0)!=0){R=c[K>>2]|0;c[h>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](h,12,0)|0;if((R|0)<1){N=1;i=b;return N|0}if((gzL(H,0,12)|0)==0){break}else{N=1}i=b;return N|0}}while(0);H=c[3529526]|0;K=c[3529578]|0;O=0;while(1){R=O<<8;gGz(K+R|0,0,256);P=O<<9;Q=0;do{U=1<<3-Q;S=(c[961472+(Q<<2)>>2]|0)+P|0;T=0;do{X=S+(c[608544+(T<<2)>>2]|0)|0;W=(T<<4)+R|0;V=0;do{Y=X+(c[609552+(V<<2)>>2]|0)|0;if(((d[H+((Y|0)/8|0)|0]|0)&128>>>((Y&7)>>>0)|0)!=0){Y=K+(W+V)|0;a[Y]=(d[Y]|0|U)&255}V=V+1|0;}while((V|0)<16);T=T+1|0;}while((T|0)<16);Q=Q+1|0;}while((Q|0)<4);Q=O+1|0;if((Q|0)<2048){O=Q}else{Z=0;break}}while(1){if((Z|0)>=1024){break}_=9638528+(Z<<2)|0;if((c[_>>2]|0)==(H|0)){J=17125;break}else{Z=Z+1|0}}if((J|0)==17125){gGr(H);c[_>>2]=0}c[3529526]=0;O=c[3527282]|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}K=e+108|0;c[K>>2]=0;Q=e+100|0;c[Q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,13)|0;do{if((c[K>>2]|0)!=0){R=c[Q>>2]|0;c[f>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](f,13,0)|0;if((R|0)<1){N=1;i=b;return N|0}if((gzL(O,0,13)|0)==0){break}else{N=1}i=b;return N|0}}while(0);O=c[2385838]|0;Q=c[3529358]|0;W4(O,Q,O,0,32768,1164378403,1164378403,22353,67);K=0;do{H=(K<<14)+65536|0;R=O+H|0;W4(R,Q+H|0,R,32768,16384,1164378403,1164378403,22353,67);K=K+1|0;}while((K|0)<16);dO0();dO1();N=0;i=b;return N|0}}while(0);c[2426752]=0;N=1;i=b;return N|0}function dOp(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6689724+(b*112|0)>>2];c[a+104>>2]=c[6689728+(b*112|0)>>2];c[a+108>>2]=c[6689732+(b*112|0)>>2];d=0;return d|0}function dOq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=6689624+(b*112|0);e=0;return e|0}function dOr(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;b=i;i=i+1320|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;l=b+360|0;m=b+472|0;n=b+480|0;o=b+592|0;p=b+600|0;q=b+712|0;r=b+720|0;s=b+832|0;t=b+840|0;u=b+952|0;v=b+960|0;w=b+1072|0;x=b+1080|0;y=b+1192|0;z=b+1200|0;A=b+1312|0;c[2426752]=0;c[2385838]=0;c[3529358]=327680;c[3527282]=655360;c[2405678]=786432;c[2385856]=786432;c[2439618]=794624;c[3531098]=798720;c[3527218]=800768;c[2443418]=804864;c[2411714]=808960;c[2406524]=808960;c[3529578]=2906112;c[3530044]=3430400;B=0;while(1){if((B|0)>=1024){break}C=9638528+(B<<2)|0;if((c[C>>2]|0)==0){D=17193;break}else{B=B+1|0}}do{if((D|0)==17193){B=gGq(3438592)|0;c[C>>2]=B;if((B|0)==0){break}c[2426752]=B;gGz(B|0,0,3438592);c[2385838]=B;c[3529358]=B+327680;c[3527282]=B+655360;E=B+786432|0;c[2405678]=E;c[2385856]=E;c[2439618]=B+794624;c[3531098]=B+798720;c[3527218]=B+800768;c[2443418]=B+804864;E=B+808960|0;c[2411714]=E;c[2406524]=E;c[3529578]=B+2906112;c[3530044]=B+3430400;c[2414256]=B+3438592;B=0;while(1){if((B|0)>=1024){F=0;break}G=9638528+(B<<2)|0;if((c[G>>2]|0)==0){D=17198;break}else{B=B+1|0}}do{if((D|0)==17198){B=gGq(1048576)|0;c[G>>2]=B;if((B|0)==0){F=0;break}gGz(B|0,0,1048576);F=B}}while(0);c[3529526]=F;B=c[2385838]|0;if((c[3542200]|0)==0){H=1;i=b;return H|0}E=z+108|0;c[E>>2]=0;I=z+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,0)|0;do{if((c[E>>2]|0)!=0){J=c[I>>2]|0;c[A>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](A,0,0)|0;if((J|0)<1){H=1;i=b;return H|0}if((gzL(B,0,0)|0)==0){break}else{H=1}i=b;return H|0}}while(0);B=(c[2385838]|0)+65536|0;if((c[3542200]|0)==0){H=1;i=b;return H|0}I=x+108|0;c[I>>2]=0;E=x+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,1)|0;do{if((c[I>>2]|0)!=0){J=c[E>>2]|0;c[y>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](y,1,0)|0;if((J|0)<1){H=1;i=b;return H|0}if((gzL(B,0,1)|0)==0){break}else{H=1}i=b;return H|0}}while(0);B=(c[2385838]|0)+196608|0;if((c[3542200]|0)==0){H=1;i=b;return H|0}E=v+108|0;c[E>>2]=0;I=v+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,2)|0;do{if((c[E>>2]|0)!=0){J=c[I>>2]|0;c[w>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](w,2,0)|0;if((J|0)<1){H=1;i=b;return H|0}if((gzL(B,0,2)|0)==0){break}else{H=1}i=b;return H|0}}while(0);B=c[3529526]|0;gGz(B|0,-1|0,1048576);if((c[3542200]|0)==0){H=1;i=b;return H|0}I=t+108|0;c[I>>2]=0;E=t+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,3)|0;do{if((c[I>>2]|0)!=0){J=c[E>>2]|0;c[u>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](u,3,0)|0;if((J|0)<1){H=1;i=b;return H|0}if((gzL(B,0,3)|0)==0){break}else{H=1}i=b;return H|0}}while(0);B=(c[3529526]|0)+131072|0;if((c[3542200]|0)==0){H=1;i=b;return H|0}E=r+108|0;c[E>>2]=0;I=r+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,4)|0;do{if((c[E>>2]|0)!=0){J=c[I>>2]|0;c[s>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](s,4,0)|0;if((J|0)<1){H=1;i=b;return H|0}if((gzL(B,0,4)|0)==0){break}else{H=1}i=b;return H|0}}while(0);B=(c[3529526]|0)+524288|0;if((c[3542200]|0)==0){H=1;i=b;return H|0}I=p+108|0;c[I>>2]=0;E=p+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,5)|0;do{if((c[I>>2]|0)!=0){J=c[E>>2]|0;c[q>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](q,5,0)|0;if((J|0)<1){H=1;i=b;return H|0}if((gzL(B,0,5)|0)==0){break}else{H=1}i=b;return H|0}}while(0);B=(c[3529526]|0)+655360|0;if((c[3542200]|0)==0){H=1;i=b;return H|0}E=n+108|0;c[E>>2]=0;I=n+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,6)|0;do{if((c[E>>2]|0)!=0){J=c[I>>2]|0;c[o>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](o,6,0)|0;if((J|0)<1){H=1;i=b;return H|0}if((gzL(B,0,6)|0)==0){break}else{H=1}i=b;return H|0}}while(0);B=c[3529526]|0;I=c[2406524]|0;E=0;do{J=E<<6;gGz(I+J|0,0,64);K=E<<7;L=0;do{M=1<<3-L;N=(c[611600+(L<<2)>>2]|0)+K|0;O=0;do{P=N+(c[6669224+(O<<2)>>2]|0)|0;Q=(O<<3)+J|0;R=0;do{S=P+(c[612480+(R<<2)>>2]|0)|0;if(((d[B+((S|0)/8|0)|0]|0)&128>>>((S&7)>>>0)|0)!=0){S=I+(Q+R)|0;a[S]=(d[S]|0|M)&255}R=R+1|0;}while((R|0)<8);O=O+1|0;}while((O|0)<8);L=L+1|0;}while((L|0)<4);E=E+1|0;}while((E|0)<32768);gGz(B|0,-1|0,1048576);if((c[3542200]|0)==0){H=1;i=b;return H|0}E=l+108|0;c[E>>2]=0;I=l+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,7)|0;do{if((c[E>>2]|0)!=0){L=c[I>>2]|0;c[m>>2]=9534384;J=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[J&16383](m,7,0)|0;if((L|0)<1){H=1;i=b;return H|0}if((gzL(B,0,7)|0)==0){break}else{H=1}i=b;return H|0}}while(0);B=(c[3529526]|0)+131072|0;if((c[3542200]|0)==0){H=1;i=b;return H|0}I=j+108|0;c[I>>2]=0;E=j+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,8)|0;do{if((c[I>>2]|0)!=0){L=c[E>>2]|0;c[k>>2]=9534384;J=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[J&16383](k,8,0)|0;if((L|0)<1){H=1;i=b;return H|0}if((gzL(B,0,8)|0)==0){break}else{H=1}i=b;return H|0}}while(0);B=c[3529526]|0;E=c[3529578]|0;I=0;do{L=I<<8;gGz(E+L|0,0,256);J=I<<9;K=0;do{O=1<<3-K;M=(c[961472+(K<<2)>>2]|0)+J|0;N=0;do{R=M+(c[608544+(N<<2)>>2]|0)|0;Q=(N<<4)+L|0;P=0;do{S=R+(c[609552+(P<<2)>>2]|0)|0;if(((d[B+((S|0)/8|0)|0]|0)&128>>>((S&7)>>>0)|0)!=0){S=E+(Q+P)|0;a[S]=(d[S]|0|O)&255}P=P+1|0;}while((P|0)<16);N=N+1|0;}while((N|0)<16);K=K+1|0;}while((K|0)<4);I=I+1|0;}while((I|0)<2048);I=c[3527282]|0;if((c[3542200]|0)==0){H=1;i=b;return H|0}E=g+108|0;c[E>>2]=0;B=g+100|0;c[B>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,9)|0;do{if((c[E>>2]|0)!=0){K=c[B>>2]|0;c[h>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](h,9,0)|0;if((K|0)<1){H=1;i=b;return H|0}if((gzL(I,0,9)|0)==0){break}else{H=1}i=b;return H|0}}while(0);I=c[3529526]|0;if((c[3542200]|0)==0){H=1;i=b;return H|0}B=e+108|0;c[B>>2]=0;E=e+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,10)|0;do{if((c[B>>2]|0)!=0){K=c[E>>2]|0;c[f>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](f,10,0)|0;if((K|0)<1){H=1;i=b;return H|0}if((gzL(I,0,10)|0)==0){break}else{H=1}i=b;return H|0}}while(0);I=c[2385838]|0;E=c[3529358]|0;W4(I,E,I,0,32768,1164378403,1164378403,22610,67);B=0;do{K=(B<<14)+65536|0;L=I+K|0;W4(L,E+K|0,L,32768,16384,1164378403,1164378403,22610,67);B=B+1|0;}while((B|0)<16);dO0();B=c[3529526]|0;if(a[1040128]|0){T=0}else{gGC(14100392,B|0,128)|0;T=0}while(1){if((T|0)>=1024){break}U=9638528+(T<<2)|0;if((c[U>>2]|0)==(B|0)){D=17270;break}else{T=T+1|0}}if((D|0)==17270){gGr(B);c[U>>2]=0}c[3529526]=0;a[6923456]=1;a[4039512]=0;dO1();H=0;i=b;return H|0}}while(0);c[2426752]=0;H=1;i=b;return H|0}function dOs(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6061708+(b*112|0)>>2];c[a+104>>2]=c[6061712+(b*112|0)>>2];c[a+108>>2]=c[6061716+(b*112|0)>>2];d=0;return d|0}function dOt(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=6061608+(b*112|0);e=0;return e|0}function dOu(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;b=i;i=i+1320|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;l=b+360|0;m=b+472|0;n=b+480|0;o=b+592|0;p=b+600|0;q=b+712|0;r=b+720|0;s=b+832|0;t=b+840|0;u=b+952|0;v=b+960|0;w=b+1072|0;x=b+1080|0;y=b+1192|0;z=b+1200|0;A=b+1312|0;c[2426752]=0;c[2385838]=0;c[3529358]=327680;c[3527282]=655360;c[2405678]=786432;c[2385856]=786432;c[2439618]=794624;c[3531098]=798720;c[3527218]=800768;c[2443418]=804864;c[2411714]=808960;c[2406524]=808960;c[3529578]=2906112;c[3530044]=3430400;B=0;while(1){if((B|0)>=1024){break}C=9638528+(B<<2)|0;if((c[C>>2]|0)==0){D=17323;break}else{B=B+1|0}}do{if((D|0)==17323){B=gGq(3438592)|0;c[C>>2]=B;if((B|0)==0){break}c[2426752]=B;gGz(B|0,0,3438592);c[2385838]=B;c[3529358]=B+327680;c[3527282]=B+655360;E=B+786432|0;c[2405678]=E;c[2385856]=E;c[2439618]=B+794624;c[3531098]=B+798720;c[3527218]=B+800768;c[2443418]=B+804864;E=B+808960|0;c[2411714]=E;c[2406524]=E;c[3529578]=B+2906112;c[3530044]=B+3430400;c[2414256]=B+3438592;B=0;while(1){if((B|0)>=1024){F=0;break}G=9638528+(B<<2)|0;if((c[G>>2]|0)==0){D=17328;break}else{B=B+1|0}}do{if((D|0)==17328){B=gGq(1048576)|0;c[G>>2]=B;if((B|0)==0){F=0;break}gGz(B|0,0,1048576);F=B}}while(0);c[3529526]=F;B=c[2385838]|0;if((c[3542200]|0)==0){H=1;i=b;return H|0}E=z+108|0;c[E>>2]=0;I=z+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,0)|0;do{if((c[E>>2]|0)!=0){J=c[I>>2]|0;c[A>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](A,0,0)|0;if((J|0)<1){H=1;i=b;return H|0}if((gzL(B,0,0)|0)==0){break}else{H=1}i=b;return H|0}}while(0);B=(c[2385838]|0)+65536|0;if((c[3542200]|0)==0){H=1;i=b;return H|0}I=x+108|0;c[I>>2]=0;E=x+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,1)|0;do{if((c[I>>2]|0)!=0){J=c[E>>2]|0;c[y>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](y,1,0)|0;if((J|0)<1){H=1;i=b;return H|0}if((gzL(B,0,1)|0)==0){break}else{H=1}i=b;return H|0}}while(0);B=(c[2385838]|0)+196608|0;if((c[3542200]|0)==0){H=1;i=b;return H|0}E=v+108|0;c[E>>2]=0;I=v+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,2)|0;do{if((c[E>>2]|0)!=0){J=c[I>>2]|0;c[w>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](w,2,0)|0;if((J|0)<1){H=1;i=b;return H|0}if((gzL(B,0,2)|0)==0){break}else{H=1}i=b;return H|0}}while(0);B=c[3529526]|0;gGz(B|0,-1|0,1048576);if((c[3542200]|0)==0){H=1;i=b;return H|0}I=t+108|0;c[I>>2]=0;E=t+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,3)|0;do{if((c[I>>2]|0)!=0){J=c[E>>2]|0;c[u>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](u,3,0)|0;if((J|0)<1){H=1;i=b;return H|0}if((gzL(B,0,3)|0)==0){break}else{H=1}i=b;return H|0}}while(0);B=(c[3529526]|0)+131072|0;if((c[3542200]|0)==0){H=1;i=b;return H|0}E=r+108|0;c[E>>2]=0;I=r+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,4)|0;do{if((c[E>>2]|0)!=0){J=c[I>>2]|0;c[s>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](s,4,0)|0;if((J|0)<1){H=1;i=b;return H|0}if((gzL(B,0,4)|0)==0){break}else{H=1}i=b;return H|0}}while(0);B=(c[3529526]|0)+524288|0;if((c[3542200]|0)==0){H=1;i=b;return H|0}I=p+108|0;c[I>>2]=0;E=p+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,5)|0;do{if((c[I>>2]|0)!=0){J=c[E>>2]|0;c[q>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](q,5,0)|0;if((J|0)<1){H=1;i=b;return H|0}if((gzL(B,0,5)|0)==0){break}else{H=1}i=b;return H|0}}while(0);B=(c[3529526]|0)+655360|0;if((c[3542200]|0)==0){H=1;i=b;return H|0}E=n+108|0;c[E>>2]=0;I=n+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,6)|0;do{if((c[E>>2]|0)!=0){J=c[I>>2]|0;c[o>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](o,6,0)|0;if((J|0)<1){H=1;i=b;return H|0}if((gzL(B,0,6)|0)==0){break}else{H=1}i=b;return H|0}}while(0);B=c[3529526]|0;I=c[2406524]|0;E=0;do{J=E<<6;gGz(I+J|0,0,64);K=E<<7;L=0;do{M=1<<3-L;N=(c[611600+(L<<2)>>2]|0)+K|0;O=0;do{P=N+(c[6669224+(O<<2)>>2]|0)|0;Q=(O<<3)+J|0;R=0;do{S=P+(c[612480+(R<<2)>>2]|0)|0;if(((d[B+((S|0)/8|0)|0]|0)&128>>>((S&7)>>>0)|0)!=0){S=I+(Q+R)|0;a[S]=(d[S]|0|M)&255}R=R+1|0;}while((R|0)<8);O=O+1|0;}while((O|0)<8);L=L+1|0;}while((L|0)<4);E=E+1|0;}while((E|0)<32768);gGz(B|0,-1|0,1048576);if((c[3542200]|0)==0){H=1;i=b;return H|0}E=l+108|0;c[E>>2]=0;I=l+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,7)|0;do{if((c[E>>2]|0)!=0){L=c[I>>2]|0;c[m>>2]=9534384;J=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[J&16383](m,7,0)|0;if((L|0)<1){H=1;i=b;return H|0}if((gzL(B,0,7)|0)==0){break}else{H=1}i=b;return H|0}}while(0);B=(c[3529526]|0)+131072|0;if((c[3542200]|0)==0){H=1;i=b;return H|0}I=j+108|0;c[I>>2]=0;E=j+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,8)|0;do{if((c[I>>2]|0)!=0){L=c[E>>2]|0;c[k>>2]=9534384;J=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[J&16383](k,8,0)|0;if((L|0)<1){H=1;i=b;return H|0}if((gzL(B,0,8)|0)==0){break}else{H=1}i=b;return H|0}}while(0);B=c[3529526]|0;E=c[3529578]|0;I=0;do{L=I<<8;gGz(E+L|0,0,256);J=I<<9;K=0;do{O=1<<3-K;M=(c[961472+(K<<2)>>2]|0)+J|0;N=0;do{R=M+(c[608544+(N<<2)>>2]|0)|0;Q=(N<<4)+L|0;P=0;do{S=R+(c[609552+(P<<2)>>2]|0)|0;if(((d[B+((S|0)/8|0)|0]|0)&128>>>((S&7)>>>0)|0)!=0){S=E+(Q+P)|0;a[S]=(d[S]|0|O)&255}P=P+1|0;}while((P|0)<16);N=N+1|0;}while((N|0)<16);K=K+1|0;}while((K|0)<4);I=I+1|0;}while((I|0)<2048);I=c[3527282]|0;if((c[3542200]|0)==0){H=1;i=b;return H|0}E=g+108|0;c[E>>2]=0;B=g+100|0;c[B>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,9)|0;do{if((c[E>>2]|0)!=0){K=c[B>>2]|0;c[h>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](h,9,0)|0;if((K|0)<1){H=1;i=b;return H|0}if((gzL(I,0,9)|0)==0){break}else{H=1}i=b;return H|0}}while(0);I=c[3529526]|0;if((c[3542200]|0)==0){H=1;i=b;return H|0}B=e+108|0;c[B>>2]=0;E=e+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,10)|0;do{if((c[B>>2]|0)!=0){K=c[E>>2]|0;c[f>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](f,10,0)|0;if((K|0)<1){H=1;i=b;return H|0}if((gzL(I,0,10)|0)==0){break}else{H=1}i=b;return H|0}}while(0);I=c[2385838]|0;E=c[3529358]|0;W4(I,E,I,0,32768,1158821488,1728127813,21930,90);B=0;do{K=(B<<14)+65536|0;L=I+K|0;W4(L,E+K|0,L,32768,16384,1158821488,1728127813,21930,90);B=B+1|0;}while((B|0)<16);dO0();B=c[3529526]|0;if(a[1040128]|0){T=0}else{gGC(14100392,B|0,128)|0;T=0}while(1){if((T|0)>=1024){break}U=9638528+(T<<2)|0;if((c[U>>2]|0)==(B|0)){D=17400;break}else{T=T+1|0}}if((D|0)==17400){gGr(B);c[U>>2]=0}c[3529526]=0;a[6923456]=1;a[4039512]=0;dO1();H=0;i=b;return H|0}}while(0);c[2426752]=0;H=1;i=b;return H|0}function dOv(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6141340+(b*112|0)>>2];c[a+104>>2]=c[6141344+(b*112|0)>>2];c[a+108>>2]=c[6141348+(b*112|0)>>2];d=0;return d|0}function dOw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=6141240+(b*112|0);e=0;return e|0}function dOx(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;b=i;i=i+1320|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;l=b+360|0;m=b+472|0;n=b+480|0;o=b+592|0;p=b+600|0;q=b+712|0;r=b+720|0;s=b+832|0;t=b+840|0;u=b+952|0;v=b+960|0;w=b+1072|0;x=b+1080|0;y=b+1192|0;z=b+1200|0;A=b+1312|0;c[2426752]=0;c[2385838]=0;c[3529358]=327680;c[3527282]=655360;c[2405678]=786432;c[2385856]=786432;c[2439618]=794624;c[3531098]=798720;c[3527218]=800768;c[2443418]=804864;c[2411714]=808960;c[2406524]=808960;c[3529578]=2906112;c[3530044]=3430400;B=0;while(1){if((B|0)>=1024){break}C=9638528+(B<<2)|0;if((c[C>>2]|0)==0){D=17453;break}else{B=B+1|0}}do{if((D|0)==17453){B=gGq(3438592)|0;c[C>>2]=B;if((B|0)==0){break}c[2426752]=B;gGz(B|0,0,3438592);c[2385838]=B;c[3529358]=B+327680;c[3527282]=B+655360;E=B+786432|0;c[2405678]=E;c[2385856]=E;c[2439618]=B+794624;c[3531098]=B+798720;c[3527218]=B+800768;c[2443418]=B+804864;E=B+808960|0;c[2411714]=E;c[2406524]=E;c[3529578]=B+2906112;c[3530044]=B+3430400;c[2414256]=B+3438592;B=0;while(1){if((B|0)>=1024){F=0;break}G=9638528+(B<<2)|0;if((c[G>>2]|0)==0){D=17458;break}else{B=B+1|0}}do{if((D|0)==17458){B=gGq(1048576)|0;c[G>>2]=B;if((B|0)==0){F=0;break}gGz(B|0,0,1048576);F=B}}while(0);c[3529526]=F;B=c[2385838]|0;if((c[3542200]|0)==0){H=1;i=b;return H|0}E=z+108|0;c[E>>2]=0;I=z+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,0)|0;do{if((c[E>>2]|0)!=0){J=c[I>>2]|0;c[A>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](A,0,0)|0;if((J|0)<1){H=1;i=b;return H|0}if((gzL(B,0,0)|0)==0){break}else{H=1}i=b;return H|0}}while(0);B=(c[2385838]|0)+65536|0;if((c[3542200]|0)==0){H=1;i=b;return H|0}I=x+108|0;c[I>>2]=0;E=x+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,1)|0;do{if((c[I>>2]|0)!=0){J=c[E>>2]|0;c[y>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](y,1,0)|0;if((J|0)<1){H=1;i=b;return H|0}if((gzL(B,0,1)|0)==0){break}else{H=1}i=b;return H|0}}while(0);B=(c[2385838]|0)+196608|0;if((c[3542200]|0)==0){H=1;i=b;return H|0}E=v+108|0;c[E>>2]=0;I=v+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,2)|0;do{if((c[E>>2]|0)!=0){J=c[I>>2]|0;c[w>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](w,2,0)|0;if((J|0)<1){H=1;i=b;return H|0}if((gzL(B,0,2)|0)==0){break}else{H=1}i=b;return H|0}}while(0);B=c[3529526]|0;gGz(B|0,-1|0,1048576);if((c[3542200]|0)==0){H=1;i=b;return H|0}I=t+108|0;c[I>>2]=0;E=t+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,3)|0;do{if((c[I>>2]|0)!=0){J=c[E>>2]|0;c[u>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](u,3,0)|0;if((J|0)<1){H=1;i=b;return H|0}if((gzL(B,0,3)|0)==0){break}else{H=1}i=b;return H|0}}while(0);B=(c[3529526]|0)+131072|0;if((c[3542200]|0)==0){H=1;i=b;return H|0}E=r+108|0;c[E>>2]=0;I=r+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,4)|0;do{if((c[E>>2]|0)!=0){J=c[I>>2]|0;c[s>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](s,4,0)|0;if((J|0)<1){H=1;i=b;return H|0}if((gzL(B,0,4)|0)==0){break}else{H=1}i=b;return H|0}}while(0);B=(c[3529526]|0)+524288|0;if((c[3542200]|0)==0){H=1;i=b;return H|0}I=p+108|0;c[I>>2]=0;E=p+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,5)|0;do{if((c[I>>2]|0)!=0){J=c[E>>2]|0;c[q>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](q,5,0)|0;if((J|0)<1){H=1;i=b;return H|0}if((gzL(B,0,5)|0)==0){break}else{H=1}i=b;return H|0}}while(0);B=(c[3529526]|0)+655360|0;if((c[3542200]|0)==0){H=1;i=b;return H|0}E=n+108|0;c[E>>2]=0;I=n+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,6)|0;do{if((c[E>>2]|0)!=0){J=c[I>>2]|0;c[o>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](o,6,0)|0;if((J|0)<1){H=1;i=b;return H|0}if((gzL(B,0,6)|0)==0){break}else{H=1}i=b;return H|0}}while(0);B=c[3529526]|0;I=c[2406524]|0;E=0;do{J=E<<6;gGz(I+J|0,0,64);K=E<<7;L=0;do{M=1<<3-L;N=(c[611600+(L<<2)>>2]|0)+K|0;O=0;do{P=N+(c[6669224+(O<<2)>>2]|0)|0;Q=(O<<3)+J|0;R=0;do{S=P+(c[612480+(R<<2)>>2]|0)|0;if(((d[B+((S|0)/8|0)|0]|0)&128>>>((S&7)>>>0)|0)!=0){S=I+(Q+R)|0;a[S]=(d[S]|0|M)&255}R=R+1|0;}while((R|0)<8);O=O+1|0;}while((O|0)<8);L=L+1|0;}while((L|0)<4);E=E+1|0;}while((E|0)<32768);gGz(B|0,-1|0,1048576);if((c[3542200]|0)==0){H=1;i=b;return H|0}E=l+108|0;c[E>>2]=0;I=l+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,7)|0;do{if((c[E>>2]|0)!=0){L=c[I>>2]|0;c[m>>2]=9534384;J=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[J&16383](m,7,0)|0;if((L|0)<1){H=1;i=b;return H|0}if((gzL(B,0,7)|0)==0){break}else{H=1}i=b;return H|0}}while(0);B=(c[3529526]|0)+131072|0;if((c[3542200]|0)==0){H=1;i=b;return H|0}I=j+108|0;c[I>>2]=0;E=j+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,8)|0;do{if((c[I>>2]|0)!=0){L=c[E>>2]|0;c[k>>2]=9534384;J=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[J&16383](k,8,0)|0;if((L|0)<1){H=1;i=b;return H|0}if((gzL(B,0,8)|0)==0){break}else{H=1}i=b;return H|0}}while(0);B=c[3529526]|0;E=c[3529578]|0;I=0;do{L=I<<8;gGz(E+L|0,0,256);J=I<<9;K=0;do{O=1<<3-K;M=(c[961472+(K<<2)>>2]|0)+J|0;N=0;do{R=M+(c[608544+(N<<2)>>2]|0)|0;Q=(N<<4)+L|0;P=0;do{S=R+(c[609552+(P<<2)>>2]|0)|0;if(((d[B+((S|0)/8|0)|0]|0)&128>>>((S&7)>>>0)|0)!=0){S=E+(Q+P)|0;a[S]=(d[S]|0|O)&255}P=P+1|0;}while((P|0)<16);N=N+1|0;}while((N|0)<16);K=K+1|0;}while((K|0)<4);I=I+1|0;}while((I|0)<2048);I=c[3527282]|0;if((c[3542200]|0)==0){H=1;i=b;return H|0}E=g+108|0;c[E>>2]=0;B=g+100|0;c[B>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,9)|0;do{if((c[E>>2]|0)!=0){K=c[B>>2]|0;c[h>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](h,9,0)|0;if((K|0)<1){H=1;i=b;return H|0}if((gzL(I,0,9)|0)==0){break}else{H=1}i=b;return H|0}}while(0);I=c[3529526]|0;if((c[3542200]|0)==0){H=1;i=b;return H|0}B=e+108|0;c[B>>2]=0;E=e+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,10)|0;do{if((c[B>>2]|0)!=0){K=c[E>>2]|0;c[f>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](f,10,0)|0;if((K|0)<1){H=1;i=b;return H|0}if((gzL(I,0,10)|0)==0){break}else{H=1}i=b;return H|0}}while(0);I=c[2385838]|0;E=c[3529358]|0;W4(I,E,I,0,32768,1164378403,1164378403,8496,18);B=0;do{K=(B<<14)+65536|0;L=I+K|0;W4(L,E+K|0,L,32768,16384,1164378403,1164378403,8496,18);B=B+1|0;}while((B|0)<16);dO0();B=c[3529526]|0;if(a[1040128]|0){T=0}else{gGC(14100392,B|0,128)|0;T=0}while(1){if((T|0)>=1024){break}U=9638528+(T<<2)|0;if((c[U>>2]|0)==(B|0)){D=17530;break}else{T=T+1|0}}if((D|0)==17530){gGr(B);c[U>>2]=0}c[3529526]=0;a[6923456]=1;a[4039512]=0;dO1();H=0;i=b;return H|0}}while(0);c[2426752]=0;H=1;i=b;return H|0}function dOy(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3680156+(b*112|0)>>2];c[a+104>>2]=c[3680160+(b*112|0)>>2];c[a+108>>2]=c[3680164+(b*112|0)>>2];d=0;return d|0}function dOz(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=3680056+(b*112|0);e=0;return e|0}function dOA(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1226488+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dOB(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3681064+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dOC(){var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0;e=i;i=i+1080|0;f=e|0;g=e+112|0;h=e+120|0;j=e+232|0;k=e+240|0;l=e+352|0;m=e+360|0;n=e+472|0;o=e+480|0;p=e+592|0;q=e+600|0;r=e+712|0;s=e+720|0;t=e+832|0;u=e+840|0;v=e+952|0;w=e+960|0;x=e+1072|0;c[2426752]=0;c[2385838]=0;c[3529358]=327680;c[3529108]=655360;c[3541206]=688128;c[3527282]=950272;c[2405678]=1998848;c[2385856]=1998848;c[3529140]=2007040;c[2439618]=2009088;c[3531098]=2013184;c[3527218]=2015232;c[2443418]=2019328;c[2411714]=2023424;c[2406524]=2023424;c[3529578]=3072e3;c[3530044]=3596288;y=0;while(1){if((y|0)>=1024){break}z=9638528+(y<<2)|0;if((c[z>>2]|0)==0){A=17597;break}else{y=y+1|0}}do{if((A|0)==17597){y=gGq(3604480)|0;c[z>>2]=y;if((y|0)==0){break}c[2426752]=y;gGz(y|0,0,3604480);c[2385838]=y;c[3529358]=y+327680;c[3529108]=y+655360;c[3541206]=y+688128;c[3527282]=y+950272;B=y+1998848|0;c[2405678]=B;c[2385856]=B;c[3529140]=y+2007040;c[2439618]=y+2009088;c[3531098]=y+2013184;c[3527218]=y+2015232;c[2443418]=y+2019328;B=y+2023424|0;c[2411714]=B;c[2406524]=B;c[3529578]=y+3072e3;c[3530044]=y+3596288;c[2414256]=y+3604480;y=0;while(1){if((y|0)>=1024){C=0;break}D=9638528+(y<<2)|0;if((c[D>>2]|0)==0){A=17602;break}else{y=y+1|0}}do{if((A|0)==17602){y=gGq(524288)|0;c[D>>2]=y;if((y|0)==0){C=0;break}gGz(y|0,0,524288);C=y}}while(0);c[3529526]=C;y=c[2385838]|0;if((c[3542200]|0)==0){E=1;i=e;return E|0}B=w+108|0;c[B>>2]=0;F=w+100|0;c[F>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](w,0)|0;do{if((c[B>>2]|0)!=0){G=c[F>>2]|0;c[x>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](x,0,0)|0;if((G|0)<1){E=1;i=e;return E|0}if((gzL(y,0,0)|0)==0){break}else{E=1}i=e;return E|0}}while(0);y=c[3529108]|0;if((c[3542200]|0)==0){E=1;i=e;return E|0}F=u+108|0;c[F>>2]=0;B=u+100|0;c[B>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](u,1)|0;do{if((c[F>>2]|0)!=0){G=c[B>>2]|0;c[v>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](v,1,0)|0;if((G|0)<1){E=1;i=e;return E|0}if((gzL(y,0,1)|0)==0){break}else{E=1}i=e;return E|0}}while(0);y=c[3529526]|0;gGz(y|0,0,524288);if((c[3542200]|0)==0){E=1;i=e;return E|0}B=s+108|0;c[B>>2]=0;F=s+100|0;c[F>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](s,2)|0;do{if((c[B>>2]|0)!=0){G=c[F>>2]|0;c[t>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](t,2,0)|0;if((G|0)<1){E=1;i=e;return E|0}if((gzL(y,0,2)|0)==0){break}else{E=1}i=e;return E|0}}while(0);y=(c[3529526]|0)+131072|0;if((c[3542200]|0)==0){E=1;i=e;return E|0}F=q+108|0;c[F>>2]=0;B=q+100|0;c[B>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](q,3)|0;do{if((c[F>>2]|0)!=0){G=c[B>>2]|0;c[r>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](r,3,0)|0;if((G|0)<1){E=1;i=e;return E|0}if((gzL(y,0,3)|0)==0){break}else{E=1}i=e;return E|0}}while(0);y=(c[3529526]|0)+262144|0;if((c[3542200]|0)==0){E=1;i=e;return E|0}B=o+108|0;c[B>>2]=0;F=o+100|0;c[F>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](o,4)|0;do{if((c[B>>2]|0)!=0){G=c[F>>2]|0;c[p>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](p,4,0)|0;if((G|0)<1){E=1;i=e;return E|0}if((gzL(y,0,4)|0)==0){break}else{E=1}i=e;return E|0}}while(0);y=(c[3529526]|0)+393216|0;if((c[3542200]|0)==0){E=1;i=e;return E|0}F=m+108|0;c[F>>2]=0;B=m+100|0;c[B>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,5)|0;do{if((c[F>>2]|0)!=0){G=c[B>>2]|0;c[n>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](n,5,0)|0;if((G|0)<1){E=1;i=e;return E|0}if((gzL(y,0,5)|0)==0){break}else{E=1}i=e;return E|0}}while(0);y=c[3529526]|0;B=0;do{F=y+B|0;a[F]=~a[F];B=B+1|0;}while((B|0)<524288);B=c[2406524]|0;F=0;do{G=F<<6;gGz(B+G|0,0,64);H=0;do{I=1<<3-H;J=(c[611536+(H<<2)>>2]|0)+G|0;K=0;do{L=J+(c[1238464+(K<<2)>>2]|0)|0;M=(K<<3)+G|0;N=0;do{O=L+(c[610352+(N<<2)>>2]|0)|0;if(((d[y+((O|0)/8|0)|0]|0)&128>>>((O&7)>>>0)|0)!=0){O=B+(M+N)|0;a[O]=(d[O]|0|I)&255}N=N+1|0;}while((N|0)<8);K=K+1|0;}while((K|0)<8);H=H+1|0;}while((H|0)<4);F=F+1|0;}while((F|0)<16384);gGz(y|0,0,524288);if((c[3542200]|0)==0){E=1;i=e;return E|0}F=k+108|0;c[F>>2]=0;B=k+100|0;c[B>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,6)|0;do{if((c[F>>2]|0)!=0){H=c[B>>2]|0;c[l>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](l,6,0)|0;if((H|0)<1){E=1;i=e;return E|0}if((gzL(y,0,6)|0)==0){break}else{E=1}i=e;return E|0}}while(0);y=(c[3529526]|0)+131072|0;if((c[3542200]|0)==0){E=1;i=e;return E|0}B=h+108|0;c[B>>2]=0;F=h+100|0;c[F>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](h,7)|0;do{if((c[B>>2]|0)!=0){H=c[F>>2]|0;c[j>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](j,7,0)|0;if((H|0)<1){E=1;i=e;return E|0}if((gzL(y,0,7)|0)==0){break}else{E=1}i=e;return E|0}}while(0);y=c[3529526]|0;F=0;do{B=y+F|0;a[B]=~a[B];F=F+1|0;}while((F|0)<262144);F=c[3529578]|0;B=0;do{H=B<<8;gGz(F+H|0,0,256);G=B<<9;K=0;do{I=1<<3-K;J=(c[611296+(K<<2)>>2]|0)+G|0;N=0;do{M=J+(c[608544+(N<<2)>>2]|0)|0;L=(N<<4)+H|0;O=0;do{P=M+(c[609552+(O<<2)>>2]|0)|0;if(((d[y+((P|0)/8|0)|0]|0)&128>>>((P&7)>>>0)|0)!=0){P=F+(L+O)|0;a[P]=(d[P]|0|I)&255}O=O+1|0;}while((O|0)<16);N=N+1|0;}while((N|0)<16);K=K+1|0;}while((K|0)<4);B=B+1|0;}while((B|0)<2048);if((c[3542200]|0)==0){E=1;i=e;return E|0}B=f+108|0;c[B>>2]=0;F=f+100|0;c[F>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,8)|0;do{if((c[B>>2]|0)!=0){K=c[F>>2]|0;c[g>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](g,8,0)|0;if((K|0)<1){E=1;i=e;return E|0}if((gzL(y,0,8)|0)==0){break}else{E=1}i=e;return E|0}}while(0);y=c[3527282]|0;F=c[3529526]|0;gGC(y|0,F|0,131072)|0;B=y+131072|0;gGC(B|0,F|0,131072)|0;B=y+262144|0;gGC(B|0,F|0,131072)|0;B=y+393216|0;K=F+131072|0;gGC(B|0,K|0,131072)|0;K=y+524288|0;gGC(K|0,F|0,131072)|0;K=y+655360|0;B=F+262144|0;gGC(K|0,B|0,131072)|0;B=y+786432|0;gGC(B|0,F|0,131072)|0;B=y+917504|0;y=F+393216|0;gGC(B|0,y|0,131072)|0;y=c[2385838]|0;gGC(F|0,y|0,524288)|0;B=c[3529358]|0;K=0;while(1){H=c[608288+(K<<2)>>2]|0;if((H|0)!=-1){G=((K|0)/2|0)<<14;N=y+G|0;I=F+(H<<14)|0;gGC(N|0,I|0,16384)|0;I=B+G|0;G=F+(c[608288+((K|1)<<2)>>2]<<14)|0;gGC(I|0,G|0,16384)|0}G=K+2|0;if((G|0)<40){K=G}else{Q=0;break}}while(1){if((Q|0)>=1024){break}R=9638528+(Q<<2)|0;if((c[R>>2]|0)==(F|0)){A=17670;break}else{Q=Q+1|0}}if((A|0)==17670){gGr(F);c[R>>2]=0}c[3529526]=0;fwR(0);K=c[2439330]|0;B=(K|0)==0;if(!B){y=K;gGC(9706056,y|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];y=c[3528484]|0;c[2076596]=y;G=c[2417276]|0;c[3541536]=G;c[1836236]=0;c[K+4180>>2]=2926;c[K+4184>>2]=1666;c[K+4172>>2]=62;c[K+4176>>2]=446;I=c[2385838]|0;N=0;H=0;while(1){c[K+76+(H<<2)>>2]=I+(H<<8);J=N+1&65535;if((J&65535)>127){break}else{N=J;H=J&65535}}H=c[3529358]|0;N=0;F=0;while(1){J=F<<8;c[K+76+(F+512<<2)>>2]=H+J;c[K+76+(F+768<<2)>>2]=I+J;J=N+1&65535;if((J&65535)>127){S=128;T=128;break}else{N=J;F=J&65535}}while(1){c[K+76+(T<<2)>>2]=I+((T<<8)+32768);F=S+1&65535;if((F&65535)>191){U=128;V=128;break}else{S=F;T=F&65535}}while(1){F=(V<<8)+32768|0;c[K+76+(V+512<<2)>>2]=H+F;c[K+76+(V+768<<2)>>2]=I+F;F=U+1&65535;if((F&65535)>191){break}else{U=F;V=F&65535}}I=c[3531098]|0;c[K+876>>2]=I;H=I+256|0;c[K+880>>2]=H;F=I+512|0;c[K+884>>2]=F;N=I+768|0;c[K+888>>2]=N;J=I+1024|0;c[K+892>>2]=J;O=I+1280|0;c[K+896>>2]=O;L=I+1536|0;c[K+900>>2]=L;M=I+1792|0;c[K+904>>2]=M;c[K+1900>>2]=I;c[K+1904>>2]=H;c[K+1908>>2]=F;c[K+1912>>2]=N;c[K+1916>>2]=J;c[K+1920>>2]=O;c[K+1924>>2]=L;c[K+1928>>2]=M;c[K+2924>>2]=I;c[K+3948>>2]=I;c[K+2928>>2]=H;c[K+3952>>2]=H;c[K+2932>>2]=F;c[K+3956>>2]=F;c[K+2936>>2]=N;c[K+3960>>2]=N;c[K+2940>>2]=J;c[K+3964>>2]=J;c[K+2944>>2]=O;c[K+3968>>2]=O;c[K+2948>>2]=L;c[K+3972>>2]=L;c[K+2952>>2]=M;c[K+3976>>2]=M;M=c[2385856]|0;L=224;O=224;while(1){c[K+76+(O<<2)>>2]=M+((O<<8)-57344);J=L+1&65535;if((J&65535)>255){W=224;X=224;break}else{L=J;O=J&65535}}while(1){c[K+76+(X+256<<2)>>2]=M+((X<<8)-57344);O=W+1&65535;if((O&65535)>255){Y=224;Z=224;break}else{W=O;X=O&65535}}while(1){O=M+((Z<<8)-57344)|0;c[K+76+(Z+512<<2)>>2]=O;c[K+76+(Z+768<<2)>>2]=O;O=Y+1&65535;if((O&65535)>255){break}else{Y=O;Z=O&65535}}if(!B){M=K;gGC(M|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=y;c[2417276]=G;c[1836236]=-1;fwR(1);M=c[2439331]|0;O=(M|0)==0;if(!O){L=M;gGC(9706056,L|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];L=c[3528485]|0;c[2076596]=L;J=c[2417277]|0;c[3541536]=J;c[1836236]=1;c[M+4180>>2]=314;c[M+4184>>2]=3302;N=c[3529108]|0;F=0;H=0;while(1){c[M+76+(H<<2)>>2]=N+(H<<8);I=F+1&65535;if((I&65535)>127){_=0;$=0;break}else{F=I;H=I&65535}}while(1){H=N+($<<8)|0;c[M+76+($+512<<2)>>2]=H;c[M+76+($+768<<2)>>2]=H;H=_+1&65535;if((H&65535)>127){break}else{_=H;$=H&65535}}N=c[3529140]|0;c[M+588>>2]=N;H=N+256|0;c[M+592>>2]=H;F=N+512|0;c[M+596>>2]=F;G=N+768|0;c[M+600>>2]=G;y=N+1024|0;c[M+604>>2]=y;K=N+1280|0;c[M+608>>2]=K;B=N+1536|0;c[M+612>>2]=B;I=N+1792|0;c[M+616>>2]=I;c[M+1612>>2]=N;c[M+1616>>2]=H;c[M+1620>>2]=F;c[M+1624>>2]=G;c[M+1628>>2]=y;c[M+1632>>2]=K;c[M+1636>>2]=B;c[M+1640>>2]=I;c[M+2636>>2]=N;c[M+3660>>2]=N;c[M+2640>>2]=H;c[M+3664>>2]=H;c[M+2644>>2]=F;c[M+3668>>2]=F;c[M+2648>>2]=G;c[M+3672>>2]=G;c[M+2652>>2]=y;c[M+3676>>2]=y;c[M+2656>>2]=K;c[M+3680>>2]=K;c[M+2660>>2]=B;c[M+3684>>2]=B;c[M+2664>>2]=I;c[M+3688>>2]=I;if(!O){I=M;gGC(I|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=L;c[2417277]=J;c[1836236]=-1;Ux(0,7500,0);c[2407030]=128;c[2407068]=3;I=c[3541206]|0;B=c[3527282]|0;gGC(I|0,B|0,262144)|0;a[6939736]=0;B=c[642608+(c[2436]<<2)>>2]|0;I=c[B+128>>2]|0;if((c[B+52>>2]&4|0)==0){c[2113068]=I;K=c[B+132>>2]|0;c[2113070]=K;c[2443814]=I;c[2440436]=K;aa=I;ab=K}else{c[2113070]=I;K=c[B+132>>2]|0;c[2113068]=K;c[2440436]=I;c[2443814]=K;aa=K;ab=I}I=ag(aa<<1,ab)|0;K=gGq(I)|0;c[2112926]=K;if((K|0)!=0){gGz(K|0,0,I|0)}c[3527252]=16383;c[2439652]=2048;I=c[2439330]|0;if((I|0)!=0){K=I;gGC(9706056,K|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];K=c[3528484]|0;c[2076596]=K;B=c[2417276]|0;c[3541536]=B;c[1836236]=0;a[14119320]=0;y=c[2385838]|0;G=128;F=128;while(1){c[I+76+(F<<2)>>2]=y+((F<<8)+32768);H=G+1&65535;if((H&65535)>191){break}else{G=H;F=H&65535}}F=c[3529358]|0;G=128;J=128;while(1){L=(J<<8)+32768|0;c[I+76+(J+512<<2)>>2]=F+L;c[I+76+(J+768<<2)>>2]=y+L;L=G+1&65535;if((L&65535)>191){break}else{G=L;J=L&65535}}gGz(9706056,0,76);J=I;gGC(J|0,9706056,76)|0;c[2438118]=c[2433530];c[3528484]=K;c[2417276]=B;c[1836236]=-1;J=c[2439331]|0;G=(J|0)==0;if(!G){y=J;gGC(9706056,y|0,76)|0}y=c[2438119]|0;c[2433530]=y;F=c[3528485]|0;c[2076596]=F;L=c[2417277]|0;c[3541536]=L;c[1836236]=1;gGz(9706056,0,76);if(!G){G=J;gGC(G|0,9706056,76)|0}c[2438119]=y;c[3528485]=F;c[2417277]=L;c[1836236]=-1;c[2113156]=0;a[9628264]=0;c[2407033]=0;L=c[3541206]|0;c[3541190]=L;c[3541198]=L;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=L+256;c[3541199]=L+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=L+512;c[3541200]=L+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=L+768;c[3541201]=L+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;a[9730904]=0;a[9773432]=0;a[9758184]=0;E=0;i=e;return E|0}}while(0);c[2426752]=0;E=1;i=e;return E|0}function dOD(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;i=i+128|0;fwZ();Uw(0);do{if(a[6939736]|0){d=b|0;e=c[c[642608+(c[2436]<<2)>>2]>>2]|0;be(d|0,128,179600,(f=i,i=i+24|0,c[f>>2]=9374064,c[f+8>>2]=47,c[f+16>>2]=e,f)|0)|0;i=f;a[1040128]=0;f=c[2420380]|0;e=c[f>>2]|0;g=c[f+4>>2]|0;f=fw(d|0,389440)|0;if((f|0)==0){break}d=g>>3<<e&1023;cj(14100392,d|0,1,f|0)|0;aY(f|0)|0}}while(0);c[2113070]=0;c[2113068]=0;f=c[2112926]|0;if((f|0)!=0){gGr(f);c[2112926]=0}f=c[2426752]|0;d=0;while(1){if((d|0)>=1024){break}h=9638528+(d<<2)|0;if((c[h>>2]|0)==(f|0)){j=17746;break}else{d=d+1|0}}if((j|0)==17746){gGr(f);c[h>>2]=0}c[2426752]=0;a[14119320]=0;a[9730904]=0;a[14121024]=0;a[9759712]=0;a[9773432]=0;a[9774160]=0;c[2429764]=0;c[3527252]=0;a[9751048]=0;a[5450472]=0;a[6939736]=0;c[2439652]=0;a[6923456]=0;a[4039512]=0;a[9751072]=0;a[9758184]=0;i=b;return 0}function dOE(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;if((a[9624400]|0)!=0){d=c[2439330]|0;if((d|0)!=0){e=d;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];e=c[3528484]|0;c[2076596]=e;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;a[14119320]=0;g=c[2385838]|0;h=128;i=128;while(1){c[d+76+(i<<2)>>2]=g+((i<<8)+32768);j=h+1&65535;if((j&65535)>191){break}else{h=j;i=j&65535}}i=c[3529358]|0;h=128;j=128;while(1){k=(j<<8)+32768|0;c[d+76+(j+512<<2)>>2]=i+k;c[d+76+(j+768<<2)>>2]=g+k;k=h+1&65535;if((k&65535)>191){break}else{h=k;j=k&65535}}gGz(9706056,0,76);j=d;gGC(j|0,9706056,76)|0;c[2438118]=c[2433530];c[3528484]=e;c[2417276]=f;c[1836236]=-1;f=c[2439331]|0;e=(f|0)==0;if(!e){j=f;gGC(9706056,j|0,76)|0}j=c[2438119]|0;c[2433530]=j;d=c[3528485]|0;c[2076596]=d;h=c[2417277]|0;c[3541536]=h;c[1836236]=1;gGz(9706056,0,76);if(!e){e=f;gGC(e|0,9706056,76)|0}c[2438119]=j;c[3528485]=d;c[2417277]=h;c[1836236]=-1;c[2113156]=0;a[9628264]=0;c[2407033]=0;h=c[3541206]|0;c[3541190]=h;c[3541198]=h;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=h+256;c[3541199]=h+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=h+512;c[3541200]=h+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=h+768;c[3541201]=h+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;a[9730904]=0;a[9773432]=0;a[9758184]=0}dO3();c[2440542]=4e5;a[6518048]=1;c[2444097]=0;c[2444096]=0;h=c[2385548]|0;if((h|0)>0){gGz(9752472,0,((h|0)>1?h<<2:4)|0)}c[2433530]=0;h=0;d=0;L23502:while(1){j=d;while(1){if((j|0)>=10){break L23502}e=c[2439330]|0;if((e|0)!=0){f=e;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;f=c[2438118]|0;c[2433530]=f;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;l=j+1|0;g=(ag(c[2440542]|0,l)|0)/10|0;i=c[2444096]|0;k=g-i|0;do{if((k|0)<1){m=0;n=i;o=f}else{if((a[e+4188|0]|0)==0){g=gfc(k)|0;p=(c[2433530]|0)+g|0;c[2433530]=p;m=g;n=c[2444096]|0;o=p;break}else{p=f+k|0;c[2433530]=p;m=k;n=i;o=p;break}}}while(0);i=n+m|0;c[2444096]=i;if((j|0)==9){a[9706117]=1;if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){k=gfc(500)|0;q=k;r=(c[2433530]|0)+k|0;s=c[2444096]|0}else{q=500;r=o+500|0;s=i}c[2433530]=r;c[2444096]=s+q;a[9706117]=0;t=r}else{t=o}i=c[1836236]|0;k=c[9757320+(i<<2)>>2]|0;if((k|0)!=0){f=k;gGC(f|0,9706056,76)|0}c[9752472+(i<<2)>>2]=t;c[14113936+(i<<2)>>2]=c[2076596];c[9669104+(i<<2)>>2]=c[3541536];c[1836236]=-1;i=c[2439331]|0;if((i|0)!=0){f=i;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;f=c[2438119]|0;c[2433530]=f;c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;k=(ag(a[6518048]|0?1e5:0,l)|0)/10|0;e=c[2444097]|0;p=k-e|0;do{if((p|0)<1){u=0;v=e;w=1;x=i;y=f}else{if((a[i+4188|0]|0)==0){k=gfc(p)|0;g=(c[2433530]|0)+k|0;c[2433530]=g;z=c[1836236]|0;u=k;v=c[2444097]|0;w=z;x=c[9757320+(z<<2)>>2]|0;y=g;break}else{g=f+p|0;c[2433530]=g;u=p;v=e;w=1;x=i;y=g;break}}}while(0);c[2444097]=v+u;if((x|0)!=0){i=x;gGC(i|0,9706056,76)|0}c[9752472+(w<<2)>>2]=y;c[14113936+(w<<2)>>2]=c[2076596];c[9669104+(w<<2)>>2]=c[3541536];c[1836236]=-1;A=c[2112964]|0;if((A|0)==0){j=l}else{break}}j=a[9688]|0?53:0;Uu(0,A+(h<<1<<1)|0,j);h=j+h|0;d=l}l=c[2112964]|0;do{if((l|0)!=0){d=a[9688]|0?534:0;if((d|0)==(h|0)){break}Uu(0,l+(h<<1<<1)|0,d-h|0)}}while(0);if((c[2112968]|0)==0){return 0}dO4();return 0}function dOF(a,e){a=a|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+144|0;g=f|0;h=f+16|0;j=f+32|0;k=f+48|0;l=f+64|0;m=f+80|0;n=f+96|0;o=f+112|0;p=f+128|0;if((e|0)!=0){c[e>>2]=169735}if((a&32|0)!=0){gGz(p|0,0,12);e=c[2405678]|0;c[p>>2]=e;c[p+4>>2]=(c[2411714]|0)-e;c[p+12>>2]=162152;e=c[2076592]|0;gj[e&4095](p)|0}if((a&64|0)!=0){fw$(a);Ut(0);gGz(o|0,0,12);c[o>>2]=9776384;c[o+4>>2]=4;c[o+12>>2]=330672;p=c[2076592]|0;gj[p&4095](o)|0;gGz(n|0,0,12);c[n>>2]=9776388;c[n+4>>2]=4;c[n+12>>2]=321856;o=c[2076592]|0;gj[o&4095](n)|0;gGz(m|0,0,12);c[m>>2]=14119320;c[m+4>>2]=1;c[m+12>>2]=511192;n=c[2076592]|0;gj[n&4095](m)|0;gGz(l|0,0,12);c[l>>2]=9730904;c[l+4>>2]=1;c[l+12>>2]=66936;m=c[2076592]|0;gj[m&4095](l)|0;gGz(k|0,0,12);c[k>>2]=14121024;c[k+4>>2]=1;c[k+12>>2]=491248;l=c[2076592]|0;gj[l&4095](k)|0;gGz(j|0,0,12);c[j>>2]=9759712;c[j+4>>2]=1;c[j+12>>2]=503888;k=c[2076592]|0;gj[k&4095](j)|0;gGz(h|0,0,12);c[h>>2]=9773432;c[h+4>>2]=1;c[h+12>>2]=587648;j=c[2076592]|0;gj[j&4095](h)|0;gGz(g|0,0,12);c[g>>2]=9758184;c[g+4>>2]=1;c[g+12>>2]=497064;h=c[2076592]|0;gj[h&4095](g)|0}if((a&2|0)==0){i=f;return 0}a=c[2439330]|0;if((a|0)!=0){g=a;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];g=c[3528484]|0;c[2076596]=g;h=c[2417276]|0;c[3541536]=h;c[1836236]=0;j=c[2385838]|0;k=(d[14119320]|0)<<14;l=k+32768|0;m=128;n=128;while(1){c[a+76+(n<<2)>>2]=j+(l+(n<<8));o=m+1&65535;if((o&65535)>191){break}else{m=o;n=o&65535}}n=c[3529358]|0;m=128;l=128;while(1){o=(l<<8)+k+32768|0;c[a+76+(l+512<<2)>>2]=n+o;c[a+76+(l+768<<2)>>2]=j+o;o=m+1&65535;if((o&65535)>191){break}else{m=o;l=o&65535}}l=a;gGC(l|0,9706056,76)|0;c[2438118]=c[2433530];c[3528484]=g;c[2417276]=h;c[1836236]=-1;h=c[3541206]|0;g=(c[3527282]|0)+((d[14121024]|0)<<18)|0;gGC(h|0,g|0,262144)|0;i=f;return 0}function dOG(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5293596+(b*112|0)>>2];c[a+104>>2]=c[5293600+(b*112|0)>>2];c[a+108>>2]=c[5293604+(b*112|0)>>2];d=0;return d|0}function dOH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=5293496+(b*112|0);e=0;return e|0}function dOI(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;b=i;i=i+1080|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;l=b+360|0;m=b+472|0;n=b+480|0;o=b+592|0;p=b+600|0;q=b+712|0;r=b+720|0;s=b+832|0;t=b+840|0;u=b+952|0;v=b+960|0;w=b+1072|0;c[2426752]=0;c[2385838]=0;c[3529358]=327680;c[3541206]=655360;c[3527282]=917504;c[2405678]=1441792;c[2385856]=1441792;c[2439618]=1449984;c[3531098]=1454080;c[3527218]=1456128;c[2443418]=1460224;c[2411714]=1464320;c[2406524]=1464320;c[3529578]=5658624;c[3530044]=6182912;x=0;while(1){if((x|0)>=1024){break}y=9638528+(x<<2)|0;if((c[y>>2]|0)==0){z=17828;break}else{x=x+1|0}}do{if((z|0)==17828){x=gGq(6191104)|0;c[y>>2]=x;if((x|0)==0){break}c[2426752]=x;gGz(x|0,0,6191104);c[2385838]=x;c[3529358]=x+327680;c[3541206]=x+655360;c[3527282]=x+917504;A=x+1441792|0;c[2405678]=A;c[2385856]=A;c[2439618]=x+1449984;c[3531098]=x+1454080;c[3527218]=x+1456128;c[2443418]=x+1460224;A=x+1464320|0;c[2411714]=A;c[2406524]=A;c[3529578]=x+5658624;c[3530044]=x+6182912;c[2414256]=x+6191104;x=0;while(1){if((x|0)>=1024){B=0;break}C=9638528+(x<<2)|0;if((c[C>>2]|0)==0){z=17833;break}else{x=x+1|0}}do{if((z|0)==17833){x=gGq(2097152)|0;c[C>>2]=x;if((x|0)==0){B=0;break}gGz(x|0,0,2097152);B=x}}while(0);c[3529526]=B;x=c[2385838]|0;if((c[3542200]|0)==0){D=1;i=b;return D|0}A=v+108|0;c[A>>2]=0;E=v+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,0)|0;do{if((c[A>>2]|0)!=0){F=c[E>>2]|0;c[w>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](w,0,0)|0;if((F|0)<1){D=1;i=b;return D|0}if((gzL(x,0,0)|0)==0){break}else{D=1}i=b;return D|0}}while(0);x=(c[2385838]|0)+65536|0;if((c[3542200]|0)==0){D=1;i=b;return D|0}E=t+108|0;c[E>>2]=0;A=t+100|0;c[A>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,1)|0;do{if((c[E>>2]|0)!=0){F=c[A>>2]|0;c[u>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](u,1,0)|0;if((F|0)<1){D=1;i=b;return D|0}if((gzL(x,0,1)|0)==0){break}else{D=1}i=b;return D|0}}while(0);x=c[3529526]|0;gGz(x|0,-1|0,2097152);if((c[3542200]|0)==0){D=1;i=b;return D|0}A=r+108|0;c[A>>2]=0;E=r+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,2)|0;do{if((c[A>>2]|0)!=0){F=c[E>>2]|0;c[s>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](s,2,0)|0;if((F|0)<1){D=1;i=b;return D|0}if((gzL(x,0,2)|0)==0){break}else{D=1}i=b;return D|0}}while(0);x=(c[3529526]|0)+524288|0;if((c[3542200]|0)==0){D=1;i=b;return D|0}E=p+108|0;c[E>>2]=0;A=p+100|0;c[A>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,3)|0;do{if((c[E>>2]|0)!=0){F=c[A>>2]|0;c[q>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](q,3,0)|0;if((F|0)<1){D=1;i=b;return D|0}if((gzL(x,0,3)|0)==0){break}else{D=1}i=b;return D|0}}while(0);x=(c[3529526]|0)+1048576|0;if((c[3542200]|0)==0){D=1;i=b;return D|0}A=n+108|0;c[A>>2]=0;E=n+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,4)|0;do{if((c[A>>2]|0)!=0){F=c[E>>2]|0;c[o>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](o,4,0)|0;if((F|0)<1){D=1;i=b;return D|0}if((gzL(x,0,4)|0)==0){break}else{D=1}i=b;return D|0}}while(0);x=(c[3529526]|0)+1572864|0;if((c[3542200]|0)==0){D=1;i=b;return D|0}E=l+108|0;c[E>>2]=0;A=l+100|0;c[A>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,5)|0;do{if((c[E>>2]|0)!=0){F=c[A>>2]|0;c[m>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](m,5,0)|0;if((F|0)<1){D=1;i=b;return D|0}if((gzL(x,0,5)|0)==0){break}else{D=1}i=b;return D|0}}while(0);x=c[3529526]|0;A=c[2406524]|0;E=0;do{F=E<<6;gGz(A+F|0,0,64);G=E<<8;H=0;do{I=1<<3-H;J=(c[687256+(H<<2)>>2]|0)+G|0;K=0;do{L=J+(c[1183816+(K<<2)>>2]|0)|0;M=(K<<3)+F|0;N=0;do{O=L+(c[809240+(N<<2)>>2]|0)|0;if(((d[x+((O|0)/8|0)|0]|0)&128>>>((O&7)>>>0)|0)!=0){O=A+(M+N)|0;a[O]=(d[O]|0|I)&255}N=N+1|0;}while((N|0)<8);K=K+1|0;}while((K|0)<8);H=H+1|0;}while((H|0)<4);E=E+1|0;}while((E|0)<65536);gGz(x|0,-1|0,2097152);if((c[3542200]|0)==0){D=1;i=b;return D|0}E=j+108|0;c[E>>2]=0;A=j+100|0;c[A>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,6)|0;do{if((c[E>>2]|0)!=0){H=c[A>>2]|0;c[k>>2]=9534384;F=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[F&16383](k,6,0)|0;if((H|0)<1){D=1;i=b;return D|0}if((gzL(x,0,6)|0)==0){break}else{D=1}i=b;return D|0}}while(0);x=(c[3529526]|0)+131072|0;if((c[3542200]|0)==0){D=1;i=b;return D|0}A=g+108|0;c[A>>2]=0;E=g+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,7)|0;do{if((c[A>>2]|0)!=0){H=c[E>>2]|0;c[h>>2]=9534384;F=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[F&16383](h,7,0)|0;if((H|0)<1){D=1;i=b;return D|0}if((gzL(x,0,7)|0)==0){break}else{D=1}i=b;return D|0}}while(0);x=c[3529526]|0;E=c[3529578]|0;A=0;while(1){H=A<<8;gGz(E+H|0,0,256);F=A<<9;G=0;do{K=1<<3-G;I=(c[961472+(G<<2)>>2]|0)+F|0;J=0;do{N=I+(c[608544+(J<<2)>>2]|0)|0;M=(J<<4)+H|0;L=0;do{O=N+(c[609552+(L<<2)>>2]|0)|0;if(((d[x+((O|0)/8|0)|0]|0)&128>>>((O&7)>>>0)|0)!=0){O=E+(M+L)|0;a[O]=(d[O]|0|K)&255}L=L+1|0;}while((L|0)<16);J=J+1|0;}while((J|0)<16);G=G+1|0;}while((G|0)<4);G=A+1|0;if((G|0)<2048){A=G}else{P=0;break}}while(1){if((P|0)>=1024){break}Q=9638528+(P<<2)|0;if((c[Q>>2]|0)==(x|0)){z=17889;break}else{P=P+1|0}}if((z|0)==17889){gGr(x);c[Q>>2]=0}c[3529526]=0;A=c[3527282]|0;if((c[3542200]|0)==0){D=1;i=b;return D|0}E=e+108|0;c[E>>2]=0;G=e+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,8)|0;do{if((c[E>>2]|0)!=0){H=c[G>>2]|0;c[f>>2]=9534384;F=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[F&16383](f,8,0)|0;if((H|0)<1){D=1;i=b;return D|0}if((gzL(A,0,8)|0)==0){break}else{D=1}i=b;return D|0}}while(0);A=c[2385838]|0;G=c[3529358]|0;W4(A,G,A,0,32768,1412567158,1412567158,18516,79);E=0;do{x=(E<<14)+65536|0;H=A+x|0;W4(H,G+x|0,H,32768,16384,1412567158,1412567158,18516,79);E=E+1|0;}while((E|0)<16);dO2();a[9774160]=1;dO1();D=0;i=b;return D|0}}while(0);c[2426752]=0;D=1;i=b;return D|0}function dOJ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6162108+(b*112|0)>>2];c[a+104>>2]=c[6162112+(b*112|0)>>2];c[a+108>>2]=c[6162116+(b*112|0)>>2];d=0;return d|0}function dOK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=6162008+(b*112|0);e=0;return e|0}function dOL(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;b=i;i=i+1680|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;l=b+360|0;m=b+472|0;n=b+480|0;o=b+592|0;p=b+600|0;q=b+712|0;r=b+720|0;s=b+832|0;t=b+840|0;u=b+952|0;v=b+960|0;w=b+1072|0;x=b+1080|0;y=b+1192|0;z=b+1200|0;A=b+1312|0;B=b+1320|0;C=b+1432|0;D=b+1440|0;E=b+1552|0;F=b+1560|0;G=b+1672|0;c[2426752]=0;c[2385838]=0;c[3529358]=327680;c[3527282]=655360;c[2405678]=786432;c[2385856]=786432;c[2439618]=794624;c[3531098]=798720;c[3527218]=800768;c[2443418]=804864;c[2411714]=808960;c[2406524]=808960;c[3529578]=2906112;c[3530044]=3430400;H=0;while(1){if((H|0)>=1024){break}I=9638528+(H<<2)|0;if((c[I>>2]|0)==0){J=17942;break}else{H=H+1|0}}do{if((J|0)==17942){H=gGq(3438592)|0;c[I>>2]=H;if((H|0)==0){break}c[2426752]=H;gGz(H|0,0,3438592);c[2385838]=H;c[3529358]=H+327680;c[3527282]=H+655360;K=H+786432|0;c[2405678]=K;c[2385856]=K;c[2439618]=H+794624;c[3531098]=H+798720;c[3527218]=H+800768;c[2443418]=H+804864;K=H+808960|0;c[2411714]=K;c[2406524]=K;c[3529578]=H+2906112;c[3530044]=H+3430400;c[2414256]=H+3438592;H=0;while(1){if((H|0)>=1024){L=0;break}M=9638528+(H<<2)|0;if((c[M>>2]|0)==0){J=17947;break}else{H=H+1|0}}do{if((J|0)==17947){H=gGq(1048576)|0;c[M>>2]=H;if((H|0)==0){L=0;break}gGz(H|0,0,1048576);L=H}}while(0);c[3529526]=L;H=c[2385838]|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}K=F+108|0;c[K>>2]=0;O=F+100|0;c[O>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](F,0)|0;do{if((c[K>>2]|0)!=0){P=c[O>>2]|0;c[G>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](G,0,0)|0;if((P|0)<1){N=1;i=b;return N|0}if((gzL(H,0,0)|0)==0){break}else{N=1}i=b;return N|0}}while(0);H=(c[2385838]|0)+65536|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}O=D+108|0;c[O>>2]=0;K=D+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](D,1)|0;do{if((c[O>>2]|0)!=0){P=c[K>>2]|0;c[E>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](E,1,0)|0;if((P|0)<1){N=1;i=b;return N|0}if((gzL(H,0,1)|0)==0){break}else{N=1}i=b;return N|0}}while(0);H=(c[2385838]|0)+196608|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}K=B+108|0;c[K>>2]=0;O=B+100|0;c[O>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](B,2)|0;do{if((c[K>>2]|0)!=0){P=c[O>>2]|0;c[C>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](C,2,0)|0;if((P|0)<1){N=1;i=b;return N|0}if((gzL(H,0,2)|0)==0){break}else{N=1}i=b;return N|0}}while(0);H=c[3529526]|0;gGz(H|0,-1|0,1048576);if((c[3542200]|0)==0){N=1;i=b;return N|0}O=z+108|0;c[O>>2]=0;K=z+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,3)|0;do{if((c[O>>2]|0)!=0){P=c[K>>2]|0;c[A>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](A,3,0)|0;if((P|0)<1){N=1;i=b;return N|0}if((gzL(H,0,3)|0)==0){break}else{N=1}i=b;return N|0}}while(0);H=(c[3529526]|0)+131072|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}K=x+108|0;c[K>>2]=0;O=x+100|0;c[O>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,4)|0;do{if((c[K>>2]|0)!=0){P=c[O>>2]|0;c[y>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](y,4,0)|0;if((P|0)<1){N=1;i=b;return N|0}if((gzL(H,0,4)|0)==0){break}else{N=1}i=b;return N|0}}while(0);H=(c[3529526]|0)+262144|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}O=v+108|0;c[O>>2]=0;K=v+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,5)|0;do{if((c[O>>2]|0)!=0){P=c[K>>2]|0;c[w>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](w,5,0)|0;if((P|0)<1){N=1;i=b;return N|0}if((gzL(H,0,5)|0)==0){break}else{N=1}i=b;return N|0}}while(0);H=(c[3529526]|0)+393216|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}K=t+108|0;c[K>>2]=0;O=t+100|0;c[O>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,6)|0;do{if((c[K>>2]|0)!=0){P=c[O>>2]|0;c[u>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](u,6,0)|0;if((P|0)<1){N=1;i=b;return N|0}if((gzL(H,0,6)|0)==0){break}else{N=1}i=b;return N|0}}while(0);H=(c[3529526]|0)+524288|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}O=r+108|0;c[O>>2]=0;K=r+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,7)|0;do{if((c[O>>2]|0)!=0){P=c[K>>2]|0;c[s>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](s,7,0)|0;if((P|0)<1){N=1;i=b;return N|0}if((gzL(H,0,7)|0)==0){break}else{N=1}i=b;return N|0}}while(0);H=(c[3529526]|0)+655360|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}K=p+108|0;c[K>>2]=0;O=p+100|0;c[O>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,8)|0;do{if((c[K>>2]|0)!=0){P=c[O>>2]|0;c[q>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](q,8,0)|0;if((P|0)<1){N=1;i=b;return N|0}if((gzL(H,0,8)|0)==0){break}else{N=1}i=b;return N|0}}while(0);H=(c[3529526]|0)+786432|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}O=n+108|0;c[O>>2]=0;K=n+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,9)|0;do{if((c[O>>2]|0)!=0){P=c[K>>2]|0;c[o>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](o,9,0)|0;if((P|0)<1){N=1;i=b;return N|0}if((gzL(H,0,9)|0)==0){break}else{N=1}i=b;return N|0}}while(0);H=(c[3529526]|0)+917504|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}K=l+108|0;c[K>>2]=0;O=l+100|0;c[O>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,10)|0;do{if((c[K>>2]|0)!=0){P=c[O>>2]|0;c[m>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](m,10,0)|0;if((P|0)<1){N=1;i=b;return N|0}if((gzL(H,0,10)|0)==0){break}else{N=1}i=b;return N|0}}while(0);H=c[3529526]|0;O=c[2406524]|0;K=0;do{P=K<<6;gGz(O+P|0,0,64);Q=K<<7;R=0;do{S=1<<3-R;T=(c[611600+(R<<2)>>2]|0)+Q|0;U=0;do{V=T+(c[6669224+(U<<2)>>2]|0)|0;W=(U<<3)+P|0;X=0;do{Y=V+(c[612480+(X<<2)>>2]|0)|0;if(((d[H+((Y|0)/8|0)|0]|0)&128>>>((Y&7)>>>0)|0)!=0){Y=O+(W+X)|0;a[Y]=(d[Y]|0|S)&255}X=X+1|0;}while((X|0)<8);U=U+1|0;}while((U|0)<8);R=R+1|0;}while((R|0)<4);K=K+1|0;}while((K|0)<32768);gGz(H|0,-1|0,1048576);if((c[3542200]|0)==0){N=1;i=b;return N|0}K=j+108|0;c[K>>2]=0;O=j+100|0;c[O>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,11)|0;do{if((c[K>>2]|0)!=0){R=c[O>>2]|0;c[k>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](k,11,0)|0;if((R|0)<1){N=1;i=b;return N|0}if((gzL(H,0,11)|0)==0){break}else{N=1}i=b;return N|0}}while(0);H=(c[3529526]|0)+131072|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}O=g+108|0;c[O>>2]=0;K=g+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,12)|0;do{if((c[O>>2]|0)!=0){R=c[K>>2]|0;c[h>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](h,12,0)|0;if((R|0)<1){N=1;i=b;return N|0}if((gzL(H,0,12)|0)==0){break}else{N=1}i=b;return N|0}}while(0);H=c[3529526]|0;K=c[3529578]|0;O=0;while(1){R=O<<8;gGz(K+R|0,0,256);P=O<<9;Q=0;do{U=1<<3-Q;S=(c[961472+(Q<<2)>>2]|0)+P|0;T=0;do{X=S+(c[608544+(T<<2)>>2]|0)|0;W=(T<<4)+R|0;V=0;do{Y=X+(c[609552+(V<<2)>>2]|0)|0;if(((d[H+((Y|0)/8|0)|0]|0)&128>>>((Y&7)>>>0)|0)!=0){Y=K+(W+V)|0;a[Y]=(d[Y]|0|U)&255}V=V+1|0;}while((V|0)<16);T=T+1|0;}while((T|0)<16);Q=Q+1|0;}while((Q|0)<4);Q=O+1|0;if((Q|0)<2048){O=Q}else{Z=0;break}}while(1){if((Z|0)>=1024){break}_=9638528+(Z<<2)|0;if((c[_>>2]|0)==(H|0)){J=18023;break}else{Z=Z+1|0}}if((J|0)==18023){gGr(H);c[_>>2]=0}c[3529526]=0;O=c[3527282]|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}K=e+108|0;c[K>>2]=0;Q=e+100|0;c[Q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,13)|0;do{if((c[K>>2]|0)!=0){R=c[Q>>2]|0;c[f>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](f,13,0)|0;if((R|0)<1){N=1;i=b;return N|0}if((gzL(O,0,13)|0)==0){break}else{N=1}i=b;return N|0}}while(0);O=c[2385838]|0;Q=c[3529358]|0;W4(O,Q,O,0,32768,305419888,305419888,4369,17);K=0;do{H=(K<<14)+65536|0;R=O+H|0;W4(R,Q+H|0,R,32768,16384,305419888,305419888,4369,17);K=K+1|0;}while((K|0)<16);dO0();dO1();N=0;i=b;return N|0}}while(0);c[2426752]=0;N=1;i=b;return N|0}function dOM(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3594028+(b*112|0)>>2];c[a+104>>2]=c[3594032+(b*112|0)>>2];c[a+108>>2]=c[3594036+(b*112|0)>>2];d=0;return d|0}function dON(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=3593928+(b*112|0);e=0;return e|0}function dOO(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;b=i;i=i+1680|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;l=b+360|0;m=b+472|0;n=b+480|0;o=b+592|0;p=b+600|0;q=b+712|0;r=b+720|0;s=b+832|0;t=b+840|0;u=b+952|0;v=b+960|0;w=b+1072|0;x=b+1080|0;y=b+1192|0;z=b+1200|0;A=b+1312|0;B=b+1320|0;C=b+1432|0;D=b+1440|0;E=b+1552|0;F=b+1560|0;G=b+1672|0;c[2426752]=0;c[2385838]=0;c[3529358]=327680;c[3527282]=655360;c[2405678]=786432;c[2385856]=786432;c[2439618]=794624;c[3531098]=798720;c[3527218]=800768;c[2443418]=804864;c[2411714]=808960;c[2406524]=808960;c[3529578]=2906112;c[3530044]=3430400;H=0;while(1){if((H|0)>=1024){break}I=9638528+(H<<2)|0;if((c[I>>2]|0)==0){J=18091;break}else{H=H+1|0}}do{if((J|0)==18091){H=gGq(3438592)|0;c[I>>2]=H;if((H|0)==0){break}c[2426752]=H;gGz(H|0,0,3438592);c[2385838]=H;c[3529358]=H+327680;c[3527282]=H+655360;K=H+786432|0;c[2405678]=K;c[2385856]=K;c[2439618]=H+794624;c[3531098]=H+798720;c[3527218]=H+800768;c[2443418]=H+804864;K=H+808960|0;c[2411714]=K;c[2406524]=K;c[3529578]=H+2906112;c[3530044]=H+3430400;c[2414256]=H+3438592;H=0;while(1){if((H|0)>=1024){L=0;break}M=9638528+(H<<2)|0;if((c[M>>2]|0)==0){J=18096;break}else{H=H+1|0}}do{if((J|0)==18096){H=gGq(1048576)|0;c[M>>2]=H;if((H|0)==0){L=0;break}gGz(H|0,0,1048576);L=H}}while(0);c[3529526]=L;H=c[2385838]|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}K=F+108|0;c[K>>2]=0;O=F+100|0;c[O>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](F,0)|0;do{if((c[K>>2]|0)!=0){P=c[O>>2]|0;c[G>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](G,0,0)|0;if((P|0)<1){N=1;i=b;return N|0}if((gzL(H,0,0)|0)==0){break}else{N=1}i=b;return N|0}}while(0);H=(c[2385838]|0)+65536|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}O=D+108|0;c[O>>2]=0;K=D+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](D,1)|0;do{if((c[O>>2]|0)!=0){P=c[K>>2]|0;c[E>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](E,1,0)|0;if((P|0)<1){N=1;i=b;return N|0}if((gzL(H,0,1)|0)==0){break}else{N=1}i=b;return N|0}}while(0);H=(c[2385838]|0)+196608|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}K=B+108|0;c[K>>2]=0;O=B+100|0;c[O>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](B,2)|0;do{if((c[K>>2]|0)!=0){P=c[O>>2]|0;c[C>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](C,2,0)|0;if((P|0)<1){N=1;i=b;return N|0}if((gzL(H,0,2)|0)==0){break}else{N=1}i=b;return N|0}}while(0);H=c[3529526]|0;gGz(H|0,-1|0,1048576);if((c[3542200]|0)==0){N=1;i=b;return N|0}O=z+108|0;c[O>>2]=0;K=z+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,3)|0;do{if((c[O>>2]|0)!=0){P=c[K>>2]|0;c[A>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](A,3,0)|0;if((P|0)<1){N=1;i=b;return N|0}if((gzL(H,0,3)|0)==0){break}else{N=1}i=b;return N|0}}while(0);H=(c[3529526]|0)+131072|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}K=x+108|0;c[K>>2]=0;O=x+100|0;c[O>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,4)|0;do{if((c[K>>2]|0)!=0){P=c[O>>2]|0;c[y>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](y,4,0)|0;if((P|0)<1){N=1;i=b;return N|0}if((gzL(H,0,4)|0)==0){break}else{N=1}i=b;return N|0}}while(0);H=(c[3529526]|0)+262144|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}O=v+108|0;c[O>>2]=0;K=v+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,5)|0;do{if((c[O>>2]|0)!=0){P=c[K>>2]|0;c[w>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](w,5,0)|0;if((P|0)<1){N=1;i=b;return N|0}if((gzL(H,0,5)|0)==0){break}else{N=1}i=b;return N|0}}while(0);H=(c[3529526]|0)+393216|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}K=t+108|0;c[K>>2]=0;O=t+100|0;c[O>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,6)|0;do{if((c[K>>2]|0)!=0){P=c[O>>2]|0;c[u>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](u,6,0)|0;if((P|0)<1){N=1;i=b;return N|0}if((gzL(H,0,6)|0)==0){break}else{N=1}i=b;return N|0}}while(0);H=(c[3529526]|0)+524288|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}O=r+108|0;c[O>>2]=0;K=r+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,7)|0;do{if((c[O>>2]|0)!=0){P=c[K>>2]|0;c[s>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](s,7,0)|0;if((P|0)<1){N=1;i=b;return N|0}if((gzL(H,0,7)|0)==0){break}else{N=1}i=b;return N|0}}while(0);H=(c[3529526]|0)+655360|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}K=p+108|0;c[K>>2]=0;O=p+100|0;c[O>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,8)|0;do{if((c[K>>2]|0)!=0){P=c[O>>2]|0;c[q>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](q,8,0)|0;if((P|0)<1){N=1;i=b;return N|0}if((gzL(H,0,8)|0)==0){break}else{N=1}i=b;return N|0}}while(0);H=(c[3529526]|0)+786432|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}O=n+108|0;c[O>>2]=0;K=n+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,9)|0;do{if((c[O>>2]|0)!=0){P=c[K>>2]|0;c[o>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](o,9,0)|0;if((P|0)<1){N=1;i=b;return N|0}if((gzL(H,0,9)|0)==0){break}else{N=1}i=b;return N|0}}while(0);H=(c[3529526]|0)+917504|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}K=l+108|0;c[K>>2]=0;O=l+100|0;c[O>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,10)|0;do{if((c[K>>2]|0)!=0){P=c[O>>2]|0;c[m>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](m,10,0)|0;if((P|0)<1){N=1;i=b;return N|0}if((gzL(H,0,10)|0)==0){break}else{N=1}i=b;return N|0}}while(0);H=c[3529526]|0;O=c[2406524]|0;K=0;do{P=K<<6;gGz(O+P|0,0,64);Q=K<<7;R=0;do{S=1<<3-R;T=(c[611600+(R<<2)>>2]|0)+Q|0;U=0;do{V=T+(c[6669224+(U<<2)>>2]|0)|0;W=(U<<3)+P|0;X=0;do{Y=V+(c[612480+(X<<2)>>2]|0)|0;if(((d[H+((Y|0)/8|0)|0]|0)&128>>>((Y&7)>>>0)|0)!=0){Y=O+(W+X)|0;a[Y]=(d[Y]|0|S)&255}X=X+1|0;}while((X|0)<8);U=U+1|0;}while((U|0)<8);R=R+1|0;}while((R|0)<4);K=K+1|0;}while((K|0)<32768);gGz(H|0,-1|0,1048576);if((c[3542200]|0)==0){N=1;i=b;return N|0}K=j+108|0;c[K>>2]=0;O=j+100|0;c[O>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,11)|0;do{if((c[K>>2]|0)!=0){R=c[O>>2]|0;c[k>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](k,11,0)|0;if((R|0)<1){N=1;i=b;return N|0}if((gzL(H,0,11)|0)==0){break}else{N=1}i=b;return N|0}}while(0);H=(c[3529526]|0)+131072|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}O=g+108|0;c[O>>2]=0;K=g+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,12)|0;do{if((c[O>>2]|0)!=0){R=c[K>>2]|0;c[h>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](h,12,0)|0;if((R|0)<1){N=1;i=b;return N|0}if((gzL(H,0,12)|0)==0){break}else{N=1}i=b;return N|0}}while(0);H=c[3529526]|0;K=c[3529578]|0;O=0;while(1){R=O<<8;gGz(K+R|0,0,256);P=O<<9;Q=0;do{U=1<<3-Q;S=(c[961472+(Q<<2)>>2]|0)+P|0;T=0;do{X=S+(c[608544+(T<<2)>>2]|0)|0;W=(T<<4)+R|0;V=0;do{Y=X+(c[609552+(V<<2)>>2]|0)|0;if(((d[H+((Y|0)/8|0)|0]|0)&128>>>((Y&7)>>>0)|0)!=0){Y=K+(W+V)|0;a[Y]=(d[Y]|0|U)&255}V=V+1|0;}while((V|0)<16);T=T+1|0;}while((T|0)<16);Q=Q+1|0;}while((Q|0)<4);Q=O+1|0;if((Q|0)<2048){O=Q}else{Z=0;break}}while(1){if((Z|0)>=1024){break}_=9638528+(Z<<2)|0;if((c[_>>2]|0)==(H|0)){J=18172;break}else{Z=Z+1|0}}if((J|0)==18172){gGr(H);c[_>>2]=0}c[3529526]=0;O=c[3527282]|0;if((c[3542200]|0)==0){N=1;i=b;return N|0}K=e+108|0;c[K>>2]=0;Q=e+100|0;c[Q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,13)|0;do{if((c[K>>2]|0)!=0){R=c[Q>>2]|0;c[f>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](f,13,0)|0;if((R|0)<1){N=1;i=b;return N|0}if((gzL(O,0,13)|0)==0){break}else{N=1}i=b;return N|0}}while(0);O=c[2385838]|0;Q=c[3529358]|0;W4(O,Q,O,0,32768,591750913,591750913,6184,24);K=0;do{H=(K<<14)+65536|0;R=O+H|0;W4(R,Q+H|0,R,32768,16384,591750913,591750913,6184,24);K=K+1|0;}while((K|0)<16);dO0();dO1();N=0;i=b;return N|0}}while(0);c[2426752]=0;N=1;i=b;return N|0}function dOP(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6967772+(b*112|0)>>2];c[a+104>>2]=c[6967776+(b*112|0)>>2];c[a+108>>2]=c[6967780+(b*112|0)>>2];d=0;return d|0}function dOQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=6967672+(b*112|0);e=0;return e|0}function dOR(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5568880+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dOS(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;b=i;i=i+1200|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;l=b+360|0;m=b+472|0;n=b+480|0;o=b+592|0;p=b+600|0;q=b+712|0;r=b+720|0;s=b+832|0;t=b+840|0;u=b+952|0;v=b+960|0;w=b+1072|0;x=b+1080|0;y=b+1192|0;c[2426752]=0;c[2385838]=0;c[3529358]=327680;c[3527282]=655360;c[2405678]=786432;c[2385856]=786432;c[2439618]=794624;c[3531098]=798720;c[3527218]=800768;c[2443418]=804864;c[2411714]=808960;c[2406524]=808960;c[3529578]=2906112;c[3530044]=3430400;z=0;while(1){if((z|0)>=1024){break}A=9638528+(z<<2)|0;if((c[A>>2]|0)==0){B=18247;break}else{z=z+1|0}}do{if((B|0)==18247){z=gGq(3438592)|0;c[A>>2]=z;if((z|0)==0){break}c[2426752]=z;gGz(z|0,0,3438592);c[2385838]=z;c[3529358]=z+327680;c[3527282]=z+655360;C=z+786432|0;c[2405678]=C;c[2385856]=C;c[2439618]=z+794624;c[3531098]=z+798720;c[3527218]=z+800768;c[2443418]=z+804864;C=z+808960|0;c[2411714]=C;c[2406524]=C;c[3529578]=z+2906112;c[3530044]=z+3430400;c[2414256]=z+3438592;z=0;while(1){if((z|0)>=1024){D=0;break}E=9638528+(z<<2)|0;if((c[E>>2]|0)==0){B=18252;break}else{z=z+1|0}}do{if((B|0)==18252){z=gGq(1048576)|0;c[E>>2]=z;if((z|0)==0){D=0;break}gGz(z|0,0,1048576);D=z}}while(0);c[3529526]=D;z=c[2385838]|0;if((c[3542200]|0)==0){F=1;i=b;return F|0}C=x+108|0;c[C>>2]=0;G=x+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,0)|0;do{if((c[C>>2]|0)!=0){H=c[G>>2]|0;c[y>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](y,0,0)|0;if((H|0)<1){F=1;i=b;return F|0}if((gzL(z,0,0)|0)==0){break}else{F=1}i=b;return F|0}}while(0);z=(c[2385838]|0)+65536|0;if((c[3542200]|0)==0){F=1;i=b;return F|0}G=v+108|0;c[G>>2]=0;C=v+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,1)|0;do{if((c[G>>2]|0)!=0){H=c[C>>2]|0;c[w>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](w,1,0)|0;if((H|0)<1){F=1;i=b;return F|0}if((gzL(z,0,1)|0)==0){break}else{F=1}i=b;return F|0}}while(0);z=(c[2385838]|0)+196608|0;if((c[3542200]|0)==0){F=1;i=b;return F|0}C=t+108|0;c[C>>2]=0;G=t+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,2)|0;do{if((c[C>>2]|0)!=0){H=c[G>>2]|0;c[u>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](u,2,0)|0;if((H|0)<1){F=1;i=b;return F|0}if((gzL(z,0,2)|0)==0){break}else{F=1}i=b;return F|0}}while(0);z=c[3529526]|0;gGz(z|0,-1|0,1048576);if((c[3542200]|0)==0){F=1;i=b;return F|0}G=r+108|0;c[G>>2]=0;C=r+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,3)|0;do{if((c[G>>2]|0)!=0){H=c[C>>2]|0;c[s>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](s,3,0)|0;if((H|0)<1){F=1;i=b;return F|0}if((gzL(z,0,3)|0)==0){break}else{F=1}i=b;return F|0}}while(0);z=(c[3529526]|0)+131072|0;if((c[3542200]|0)==0){F=1;i=b;return F|0}C=p+108|0;c[C>>2]=0;G=p+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,4)|0;do{if((c[C>>2]|0)!=0){H=c[G>>2]|0;c[q>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](q,4,0)|0;if((H|0)<1){F=1;i=b;return F|0}if((gzL(z,0,4)|0)==0){break}else{F=1}i=b;return F|0}}while(0);z=(c[3529526]|0)+524288|0;if((c[3542200]|0)==0){F=1;i=b;return F|0}G=n+108|0;c[G>>2]=0;C=n+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,5)|0;do{if((c[G>>2]|0)!=0){H=c[C>>2]|0;c[o>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](o,5,0)|0;if((H|0)<1){F=1;i=b;return F|0}if((gzL(z,0,5)|0)==0){break}else{F=1}i=b;return F|0}}while(0);z=(c[3529526]|0)+655360|0;if((c[3542200]|0)==0){F=1;i=b;return F|0}C=l+108|0;c[C>>2]=0;G=l+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,6)|0;do{if((c[C>>2]|0)!=0){H=c[G>>2]|0;c[m>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](m,6,0)|0;if((H|0)<1){F=1;i=b;return F|0}if((gzL(z,0,6)|0)==0){break}else{F=1}i=b;return F|0}}while(0);z=c[3529526]|0;G=c[2406524]|0;C=0;do{H=C<<6;gGz(G+H|0,0,64);I=C<<7;J=0;do{K=1<<3-J;L=(c[611600+(J<<2)>>2]|0)+I|0;M=0;do{N=L+(c[6669224+(M<<2)>>2]|0)|0;O=(M<<3)+H|0;P=0;do{Q=N+(c[612480+(P<<2)>>2]|0)|0;if(((d[z+((Q|0)/8|0)|0]|0)&128>>>((Q&7)>>>0)|0)!=0){Q=G+(O+P)|0;a[Q]=(d[Q]|0|K)&255}P=P+1|0;}while((P|0)<8);M=M+1|0;}while((M|0)<8);J=J+1|0;}while((J|0)<4);C=C+1|0;}while((C|0)<32768);gGz(z|0,-1|0,1048576);if((c[3542200]|0)==0){F=1;i=b;return F|0}C=j+108|0;c[C>>2]=0;G=j+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,7)|0;do{if((c[C>>2]|0)!=0){J=c[G>>2]|0;c[k>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](k,7,0)|0;if((J|0)<1){F=1;i=b;return F|0}if((gzL(z,0,7)|0)==0){break}else{F=1}i=b;return F|0}}while(0);z=(c[3529526]|0)+131072|0;if((c[3542200]|0)==0){F=1;i=b;return F|0}G=g+108|0;c[G>>2]=0;C=g+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,8)|0;do{if((c[G>>2]|0)!=0){J=c[C>>2]|0;c[h>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](h,8,0)|0;if((J|0)<1){F=1;i=b;return F|0}if((gzL(z,0,8)|0)==0){break}else{F=1}i=b;return F|0}}while(0);z=c[3529526]|0;C=c[3529578]|0;G=0;while(1){J=G<<8;gGz(C+J|0,0,256);H=G<<9;I=0;do{M=1<<3-I;K=(c[961472+(I<<2)>>2]|0)+H|0;L=0;do{P=K+(c[608544+(L<<2)>>2]|0)|0;O=(L<<4)+J|0;N=0;do{Q=P+(c[609552+(N<<2)>>2]|0)|0;if(((d[z+((Q|0)/8|0)|0]|0)&128>>>((Q&7)>>>0)|0)!=0){Q=C+(O+N)|0;a[Q]=(d[Q]|0|M)&255}N=N+1|0;}while((N|0)<16);L=L+1|0;}while((L|0)<16);I=I+1|0;}while((I|0)<4);I=G+1|0;if((I|0)<2048){G=I}else{R=0;break}}while(1){if((R|0)>=1024){break}S=9638528+(R<<2)|0;if((c[S>>2]|0)==(z|0)){B=18312;break}else{R=R+1|0}}if((B|0)==18312){gGr(z);c[S>>2]=0}c[3529526]=0;G=c[3527282]|0;if((c[3542200]|0)==0){F=1;i=b;return F|0}C=e+108|0;c[C>>2]=0;I=e+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,9)|0;do{if((c[C>>2]|0)!=0){J=c[I>>2]|0;c[f>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](f,9,0)|0;if((J|0)<1){F=1;i=b;return F|0}if((gzL(G,0,9)|0)==0){break}else{F=1}i=b;return F|0}}while(0);G=c[2385838]|0;I=c[3529358]|0;W4(G,I,G,0,32768,38146903,1679848753,2,1);C=0;do{z=(C<<14)+65536|0;J=G+z|0;W4(J,I+z|0,J,32768,16384,38146903,1679848753,2,1);C=C+1|0;}while((C|0)<16);dO0();a[9774160]=2;a[6923456]=1;a[4039512]=1;dO1();F=0;i=b;return F|0}}while(0);c[2426752]=0;F=1;i=b;return F|0}function dOT(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6415196+(b*112|0)>>2];c[a+104>>2]=c[6415200+(b*112|0)>>2];c[a+108>>2]=c[6415204+(b*112|0)>>2];d=0;return d|0}function dOU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=6415096+(b*112|0);e=0;return e|0}function dOV(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4234884+(b*112|0)>>2];c[a+104>>2]=c[4234888+(b*112|0)>>2];c[a+108>>2]=c[4234892+(b*112|0)>>2];d=0;return d|0}function dOW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=4234784+(b*112|0);e=0;return e|0}function dOX(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1310560+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dOY(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;b=i;i=i+1200|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;l=b+360|0;m=b+472|0;n=b+480|0;o=b+592|0;p=b+600|0;q=b+712|0;r=b+720|0;s=b+832|0;t=b+840|0;u=b+952|0;v=b+960|0;w=b+1072|0;x=b+1080|0;y=b+1192|0;c[2426752]=0;c[2385838]=0;c[3529358]=327680;c[3527282]=655360;c[2405678]=786432;c[2385856]=786432;c[2439618]=794624;c[3531098]=798720;c[3527218]=800768;c[2443418]=804864;c[2411714]=808960;c[2406524]=808960;c[3529578]=2906112;c[3530044]=3430400;z=0;while(1){if((z|0)>=1024){break}A=9638528+(z<<2)|0;if((c[A>>2]|0)==0){B=18387;break}else{z=z+1|0}}do{if((B|0)==18387){z=gGq(3438592)|0;c[A>>2]=z;if((z|0)==0){break}c[2426752]=z;gGz(z|0,0,3438592);c[2385838]=z;c[3529358]=z+327680;c[3527282]=z+655360;C=z+786432|0;c[2405678]=C;c[2385856]=C;c[2439618]=z+794624;c[3531098]=z+798720;c[3527218]=z+800768;c[2443418]=z+804864;C=z+808960|0;c[2411714]=C;c[2406524]=C;c[3529578]=z+2906112;c[3530044]=z+3430400;c[2414256]=z+3438592;z=0;while(1){if((z|0)>=1024){D=0;break}E=9638528+(z<<2)|0;if((c[E>>2]|0)==0){B=18392;break}else{z=z+1|0}}do{if((B|0)==18392){z=gGq(1048576)|0;c[E>>2]=z;if((z|0)==0){D=0;break}gGz(z|0,0,1048576);D=z}}while(0);c[3529526]=D;z=c[2385838]|0;if((c[3542200]|0)==0){F=1;i=b;return F|0}C=x+108|0;c[C>>2]=0;G=x+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,0)|0;do{if((c[C>>2]|0)!=0){H=c[G>>2]|0;c[y>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](y,0,0)|0;if((H|0)<1){F=1;i=b;return F|0}if((gzL(z,0,0)|0)==0){break}else{F=1}i=b;return F|0}}while(0);z=(c[2385838]|0)+65536|0;if((c[3542200]|0)==0){F=1;i=b;return F|0}G=v+108|0;c[G>>2]=0;C=v+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,1)|0;do{if((c[G>>2]|0)!=0){H=c[C>>2]|0;c[w>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](w,1,0)|0;if((H|0)<1){F=1;i=b;return F|0}if((gzL(z,0,1)|0)==0){break}else{F=1}i=b;return F|0}}while(0);z=(c[2385838]|0)+196608|0;if((c[3542200]|0)==0){F=1;i=b;return F|0}C=t+108|0;c[C>>2]=0;G=t+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,2)|0;do{if((c[C>>2]|0)!=0){H=c[G>>2]|0;c[u>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](u,2,0)|0;if((H|0)<1){F=1;i=b;return F|0}if((gzL(z,0,2)|0)==0){break}else{F=1}i=b;return F|0}}while(0);z=c[3529526]|0;gGz(z|0,-1|0,1048576);if((c[3542200]|0)==0){F=1;i=b;return F|0}G=r+108|0;c[G>>2]=0;C=r+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,3)|0;do{if((c[G>>2]|0)!=0){H=c[C>>2]|0;c[s>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](s,3,0)|0;if((H|0)<1){F=1;i=b;return F|0}if((gzL(z,0,3)|0)==0){break}else{F=1}i=b;return F|0}}while(0);z=(c[3529526]|0)+131072|0;if((c[3542200]|0)==0){F=1;i=b;return F|0}C=p+108|0;c[C>>2]=0;G=p+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,4)|0;do{if((c[C>>2]|0)!=0){H=c[G>>2]|0;c[q>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](q,4,0)|0;if((H|0)<1){F=1;i=b;return F|0}if((gzL(z,0,4)|0)==0){break}else{F=1}i=b;return F|0}}while(0);z=(c[3529526]|0)+524288|0;if((c[3542200]|0)==0){F=1;i=b;return F|0}G=n+108|0;c[G>>2]=0;C=n+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,5)|0;do{if((c[G>>2]|0)!=0){H=c[C>>2]|0;c[o>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](o,5,0)|0;if((H|0)<1){F=1;i=b;return F|0}if((gzL(z,0,5)|0)==0){break}else{F=1}i=b;return F|0}}while(0);z=(c[3529526]|0)+655360|0;if((c[3542200]|0)==0){F=1;i=b;return F|0}C=l+108|0;c[C>>2]=0;G=l+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,6)|0;do{if((c[C>>2]|0)!=0){H=c[G>>2]|0;c[m>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](m,6,0)|0;if((H|0)<1){F=1;i=b;return F|0}if((gzL(z,0,6)|0)==0){break}else{F=1}i=b;return F|0}}while(0);z=c[3529526]|0;G=c[2406524]|0;C=0;do{H=C<<6;gGz(G+H|0,0,64);I=C<<7;J=0;do{K=1<<3-J;L=(c[611600+(J<<2)>>2]|0)+I|0;M=0;do{N=L+(c[6669224+(M<<2)>>2]|0)|0;O=(M<<3)+H|0;P=0;do{Q=N+(c[612480+(P<<2)>>2]|0)|0;if(((d[z+((Q|0)/8|0)|0]|0)&128>>>((Q&7)>>>0)|0)!=0){Q=G+(O+P)|0;a[Q]=(d[Q]|0|K)&255}P=P+1|0;}while((P|0)<8);M=M+1|0;}while((M|0)<8);J=J+1|0;}while((J|0)<4);C=C+1|0;}while((C|0)<32768);gGz(z|0,-1|0,1048576);if((c[3542200]|0)==0){F=1;i=b;return F|0}C=j+108|0;c[C>>2]=0;G=j+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,7)|0;do{if((c[C>>2]|0)!=0){J=c[G>>2]|0;c[k>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](k,7,0)|0;if((J|0)<1){F=1;i=b;return F|0}if((gzL(z,0,7)|0)==0){break}else{F=1}i=b;return F|0}}while(0);z=(c[3529526]|0)+131072|0;if((c[3542200]|0)==0){F=1;i=b;return F|0}G=g+108|0;c[G>>2]=0;C=g+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,8)|0;do{if((c[G>>2]|0)!=0){J=c[C>>2]|0;c[h>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](h,8,0)|0;if((J|0)<1){F=1;i=b;return F|0}if((gzL(z,0,8)|0)==0){break}else{F=1}i=b;return F|0}}while(0);z=c[3529526]|0;C=c[3529578]|0;G=0;while(1){J=G<<8;gGz(C+J|0,0,256);H=G<<9;I=0;do{M=1<<3-I;K=(c[961472+(I<<2)>>2]|0)+H|0;L=0;do{P=K+(c[608544+(L<<2)>>2]|0)|0;O=(L<<4)+J|0;N=0;do{Q=P+(c[609552+(N<<2)>>2]|0)|0;if(((d[z+((Q|0)/8|0)|0]|0)&128>>>((Q&7)>>>0)|0)!=0){Q=C+(O+N)|0;a[Q]=(d[Q]|0|M)&255}N=N+1|0;}while((N|0)<16);L=L+1|0;}while((L|0)<16);I=I+1|0;}while((I|0)<4);I=G+1|0;if((I|0)<2048){G=I}else{R=0;break}}while(1){if((R|0)>=1024){break}S=9638528+(R<<2)|0;if((c[S>>2]|0)==(z|0)){B=18452;break}else{R=R+1|0}}if((B|0)==18452){gGr(z);c[S>>2]=0}c[3529526]=0;G=c[3527282]|0;if((c[3542200]|0)==0){F=1;i=b;return F|0}C=e+108|0;c[C>>2]=0;I=e+100|0;c[I>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,9)|0;do{if((c[C>>2]|0)!=0){J=c[I>>2]|0;c[f>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](f,9,0)|0;if((J|0)<1){F=1;i=b;return F|0}if((gzL(G,0,9)|0)==0){break}else{F=1}i=b;return F|0}}while(0);G=c[2385838]|0;I=c[3529358]|0;W4(G,I,G,0,32768,38146903,1679848753,2,1);C=0;do{z=(C<<14)+65536|0;J=G+z|0;W4(J,I+z|0,J,32768,16384,38146903,1679848753,2,1);C=C+1|0;}while((C|0)<16);dO0();dO1();F=0;i=b;return F|0}}while(0);c[2426752]=0;F=1;i=b;return F|0}function dOZ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5567636+(b*112|0)>>2];c[a+104>>2]=c[5567640+(b*112|0)>>2];c[a+108>>2]=c[5567644+(b*112|0)>>2];d=0;return d|0}function dO_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=5567536+(b*112|0);e=0;return e|0}function dO$(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;b=i;i=i+1440|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;l=b+360|0;m=b+472|0;n=b+480|0;o=b+592|0;p=b+600|0;q=b+712|0;r=b+720|0;s=b+832|0;t=b+840|0;u=b+952|0;v=b+960|0;w=b+1072|0;x=b+1080|0;y=b+1192|0;z=b+1200|0;A=b+1312|0;B=b+1320|0;C=b+1432|0;c[2426752]=0;c[2385838]=0;c[3529358]=327680;c[3527282]=655360;c[2405678]=786432;c[2385856]=786432;c[2439618]=794624;c[3531098]=798720;c[3527218]=800768;c[2443418]=804864;c[2411714]=808960;c[2406524]=808960;c[3529578]=2906112;c[3530044]=3430400;D=0;while(1){if((D|0)>=1024){break}E=9638528+(D<<2)|0;if((c[E>>2]|0)==0){F=18508;break}else{D=D+1|0}}do{if((F|0)==18508){D=gGq(3438592)|0;c[E>>2]=D;if((D|0)==0){break}c[2426752]=D;gGz(D|0,0,3438592);c[2385838]=D;c[3529358]=D+327680;c[3527282]=D+655360;G=D+786432|0;c[2405678]=G;c[2385856]=G;c[2439618]=D+794624;c[3531098]=D+798720;c[3527218]=D+800768;c[2443418]=D+804864;G=D+808960|0;c[2411714]=G;c[2406524]=G;c[3529578]=D+2906112;c[3530044]=D+3430400;c[2414256]=D+3438592;D=0;while(1){if((D|0)>=1024){H=0;break}I=9638528+(D<<2)|0;if((c[I>>2]|0)==0){F=18513;break}else{D=D+1|0}}do{if((F|0)==18513){D=gGq(1048576)|0;c[I>>2]=D;if((D|0)==0){H=0;break}gGz(D|0,0,1048576);H=D}}while(0);c[3529526]=H;D=c[3529358]|0;if((c[3542200]|0)==0){J=1;i=b;return J|0}G=B+108|0;c[G>>2]=0;K=B+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](B,0)|0;do{if((c[G>>2]|0)!=0){L=c[K>>2]|0;c[C>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](C,0,0)|0;if((L|0)<1){J=1;i=b;return J|0}if((gzL(D,0,0)|0)==0){break}else{J=1}i=b;return J|0}}while(0);D=(c[3529358]|0)+65536|0;if((c[3542200]|0)==0){J=1;i=b;return J|0}K=z+108|0;c[K>>2]=0;G=z+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,1)|0;do{if((c[K>>2]|0)!=0){L=c[G>>2]|0;c[A>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](A,1,0)|0;if((L|0)<1){J=1;i=b;return J|0}if((gzL(D,0,1)|0)==0){break}else{J=1}i=b;return J|0}}while(0);D=(c[2385838]|0)+196608|0;if((c[3542200]|0)==0){J=1;i=b;return J|0}G=x+108|0;c[G>>2]=0;K=x+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,2)|0;do{if((c[G>>2]|0)!=0){L=c[K>>2]|0;c[y>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](y,2,0)|0;if((L|0)<1){J=1;i=b;return J|0}if((gzL(D,0,2)|0)==0){break}else{J=1}i=b;return J|0}}while(0);D=c[2385838]|0;K=c[3529358]|0;G=K+32768|0;gGC(D|0,G|0,32768)|0;gGz(G|0,0,32768);G=D+65536|0;D=K+196608|0;gGC(G|0,D|0,131072)|0;gGz(D|0,0,131072);D=c[3529526]|0;gGz(D|0,-1|0,1048576);if((c[3542200]|0)==0){J=1;i=b;return J|0}G=v+108|0;c[G>>2]=0;K=v+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,3)|0;do{if((c[G>>2]|0)!=0){L=c[K>>2]|0;c[w>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](w,3,0)|0;if((L|0)<1){J=1;i=b;return J|0}if((gzL(D,0,3)|0)==0){break}else{J=1}i=b;return J|0}}while(0);D=(c[3529526]|0)+131072|0;if((c[3542200]|0)==0){J=1;i=b;return J|0}K=t+108|0;c[K>>2]=0;G=t+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,4)|0;do{if((c[K>>2]|0)!=0){L=c[G>>2]|0;c[u>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](u,4,0)|0;if((L|0)<1){J=1;i=b;return J|0}if((gzL(D,0,4)|0)==0){break}else{J=1}i=b;return J|0}}while(0);D=(c[3529526]|0)+524288|0;if((c[3542200]|0)==0){J=1;i=b;return J|0}G=r+108|0;c[G>>2]=0;K=r+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,5)|0;do{if((c[G>>2]|0)!=0){L=c[K>>2]|0;c[s>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](s,5,0)|0;if((L|0)<1){J=1;i=b;return J|0}if((gzL(D,0,5)|0)==0){break}else{J=1}i=b;return J|0}}while(0);D=(c[3529526]|0)+655360|0;if((c[3542200]|0)==0){J=1;i=b;return J|0}K=p+108|0;c[K>>2]=0;G=p+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,6)|0;do{if((c[K>>2]|0)!=0){L=c[G>>2]|0;c[q>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](q,6,0)|0;if((L|0)<1){J=1;i=b;return J|0}if((gzL(D,0,6)|0)==0){break}else{J=1}i=b;return J|0}}while(0);D=c[3529526]|0;G=c[2406524]|0;K=0;do{L=K<<6;gGz(G+L|0,0,64);M=K<<7;N=0;do{O=1<<3-N;P=(c[611600+(N<<2)>>2]|0)+M|0;Q=0;do{R=P+(c[6669224+(Q<<2)>>2]|0)|0;S=(Q<<3)+L|0;T=0;do{U=R+(c[612480+(T<<2)>>2]|0)|0;if(((d[D+((U|0)/8|0)|0]|0)&128>>>((U&7)>>>0)|0)!=0){U=G+(S+T)|0;a[U]=(d[U]|0|O)&255}T=T+1|0;}while((T|0)<8);Q=Q+1|0;}while((Q|0)<8);N=N+1|0;}while((N|0)<4);K=K+1|0;}while((K|0)<32768);gGz(D|0,-1|0,1048576);if((c[3542200]|0)==0){J=1;i=b;return J|0}K=n+108|0;c[K>>2]=0;G=n+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,7)|0;do{if((c[K>>2]|0)!=0){N=c[G>>2]|0;c[o>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](o,7,0)|0;if((N|0)<1){J=1;i=b;return J|0}if((gzL(D,0,7)|0)==0){break}else{J=1}i=b;return J|0}}while(0);D=(c[3529526]|0)+65536|0;if((c[3542200]|0)==0){J=1;i=b;return J|0}G=l+108|0;c[G>>2]=0;K=l+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,8)|0;do{if((c[G>>2]|0)!=0){N=c[K>>2]|0;c[m>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](m,8,0)|0;if((N|0)<1){J=1;i=b;return J|0}if((gzL(D,0,8)|0)==0){break}else{J=1}i=b;return J|0}}while(0);D=(c[3529526]|0)+131072|0;if((c[3542200]|0)==0){J=1;i=b;return J|0}K=j+108|0;c[K>>2]=0;G=j+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,9)|0;do{if((c[K>>2]|0)!=0){N=c[G>>2]|0;c[k>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](k,9,0)|0;if((N|0)<1){J=1;i=b;return J|0}if((gzL(D,0,9)|0)==0){break}else{J=1}i=b;return J|0}}while(0);D=(c[3529526]|0)+196608|0;if((c[3542200]|0)==0){J=1;i=b;return J|0}G=g+108|0;c[G>>2]=0;K=g+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,10)|0;do{if((c[G>>2]|0)!=0){N=c[K>>2]|0;c[h>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](h,10,0)|0;if((N|0)<1){J=1;i=b;return J|0}if((gzL(D,0,10)|0)==0){break}else{J=1}i=b;return J|0}}while(0);D=c[3529526]|0;K=c[3529578]|0;G=0;while(1){N=G<<8;gGz(K+N|0,0,256);L=G<<9;M=0;do{Q=1<<3-M;O=(c[961472+(M<<2)>>2]|0)+L|0;P=0;do{T=O+(c[608544+(P<<2)>>2]|0)|0;S=(P<<4)+N|0;R=0;do{U=T+(c[609552+(R<<2)>>2]|0)|0;if(((d[D+((U|0)/8|0)|0]|0)&128>>>((U&7)>>>0)|0)!=0){U=K+(S+R)|0;a[U]=(d[U]|0|Q)&255}R=R+1|0;}while((R|0)<16);P=P+1|0;}while((P|0)<16);M=M+1|0;}while((M|0)<4);M=G+1|0;if((M|0)<2048){G=M}else{V=0;break}}while(1){if((V|0)>=1024){break}W=9638528+(V<<2)|0;if((c[W>>2]|0)==(D|0)){F=18581;break}else{V=V+1|0}}if((F|0)==18581){gGr(D);c[W>>2]=0}c[3529526]=0;G=c[3527282]|0;if((c[3542200]|0)==0){J=1;i=b;return J|0}K=e+108|0;c[K>>2]=0;M=e+100|0;c[M>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,11)|0;do{if((c[K>>2]|0)!=0){N=c[M>>2]|0;c[f>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](f,11,0)|0;if((N|0)<1){J=1;i=b;return J|0}if((gzL(G,0,11)|0)==0){break}else{J=1}i=b;return J|0}}while(0);dO0();a[9774160]=2;a[6923456]=1;a[4039512]=1;dO1();J=0;i=b;return J|0}}while(0);c[2426752]=0;J=1;i=b;return J|0}function dO0(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;fwR(0);d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];f=c[3528484]|0;c[2076596]=f;g=c[2417276]|0;c[3541536]=g;c[1836236]=0;c[d+4180>>2]=2926;c[d+4184>>2]=1666;c[d+4172>>2]=1424;c[d+4176>>2]=2902;i=c[2385838]|0;j=0;k=0;while(1){c[d+76+(k<<2)>>2]=i+(k<<8);l=j+1&65535;if((l&65535)>127){break}else{j=l;k=l&65535}}k=c[3529358]|0;j=0;l=0;while(1){m=l<<8;c[d+76+(l+512<<2)>>2]=k+m;c[d+76+(l+768<<2)>>2]=i+m;m=j+1&65535;if((m&65535)>127){n=128;o=128;break}else{j=m;l=m&65535}}while(1){c[d+76+(o<<2)>>2]=i+((o<<8)+32768);l=n+1&65535;if((l&65535)>191){p=128;q=128;break}else{n=l;o=l&65535}}while(1){o=(q<<8)+32768|0;c[d+76+(q+512<<2)>>2]=k+o;c[d+76+(q+768<<2)>>2]=i+o;o=p+1&65535;if((o&65535)>191){break}else{p=o;q=o&65535}}q=c[3531098]|0;c[d+876>>2]=q;p=q+256|0;c[d+880>>2]=p;i=q+512|0;c[d+884>>2]=i;k=q+768|0;c[d+888>>2]=k;o=q+1024|0;c[d+892>>2]=o;n=q+1280|0;c[d+896>>2]=n;l=q+1536|0;c[d+900>>2]=l;j=q+1792|0;c[d+904>>2]=j;c[d+1900>>2]=q;c[d+1904>>2]=p;c[d+1908>>2]=i;c[d+1912>>2]=k;c[d+1916>>2]=o;c[d+1920>>2]=n;c[d+1924>>2]=l;c[d+1928>>2]=j;c[d+2924>>2]=q;c[d+3948>>2]=q;c[d+2928>>2]=p;c[d+3952>>2]=p;c[d+2932>>2]=i;c[d+3956>>2]=i;c[d+2936>>2]=k;c[d+3960>>2]=k;c[d+2940>>2]=o;c[d+3964>>2]=o;c[d+2944>>2]=n;c[d+3968>>2]=n;c[d+2948>>2]=l;c[d+3972>>2]=l;c[d+2952>>2]=j;c[d+3976>>2]=j;j=c[2385856]|0;l=224;n=224;while(1){c[d+76+(n<<2)>>2]=j+((n<<8)-57344);o=l+1&65535;if((o&65535)>255){r=224;s=224;break}else{l=o;n=o&65535}}while(1){c[d+76+(s+256<<2)>>2]=j+((s<<8)-57344);n=r+1&65535;if((n&65535)>255){t=224;u=224;break}else{r=n;s=n&65535}}while(1){s=j+((u<<8)-57344)|0;c[d+76+(u+512<<2)>>2]=s;c[d+76+(u+768<<2)>>2]=s;s=t+1&65535;if((s&65535)>255){break}else{t=s;u=s&65535}}if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=f;c[2417276]=g;c[1836236]=-1;if(a[9680]|0){mq(4e6,32e3);g=gGq(262144)|0;c[2406690]=g;gGz(g|0,0,262144);c[2439246]=0;h[745411]=1.0;h[745410]=1.0;a[3203304]=1;a[3203296]=1}else{mq(4e6,11025)}h[745411]=1.0;a[3203304]=1;h[745410]=1.0;a[3203296]=1;Ux(0,7575,1);c[2407030]=77;c[2407068]=3;c[3541206]=c[3527282];Tq(965704);a[6939736]=1;g=c[642608+(c[2436]<<2)>>2]|0;f=c[g+128>>2]|0;if((c[g+52>>2]&4|0)==0){c[2113068]=f;e=c[g+132>>2]|0;c[2113070]=e;c[2443814]=f;c[2440436]=e;v=f;w=e}else{c[2113070]=f;e=c[g+132>>2]|0;c[2113068]=e;c[2440436]=f;c[2443814]=e;v=e;w=f}f=ag(v<<1,w)|0;w=gGq(f)|0;c[2112926]=w;if((w|0)==0){c[3527252]=32767;c[2439652]=2048;return}gGz(w|0,0,f|0);c[3527252]=32767;c[2439652]=2048;return}function dO1(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];f=c[3528484]|0;c[2076596]=f;g=c[2417276]|0;c[3541536]=g;c[1836236]=0;a[14119320]=0;h=c[2385838]|0;i=128;j=128;while(1){c[d+76+(j<<2)>>2]=h+((j<<8)+32768);k=i+1&65535;if((k&65535)>191){break}else{i=k;j=k&65535}}j=a[6939736]|0;if(j){i=c[3529358]|0;k=128;l=128;while(1){m=(l<<8)+32768|0;c[d+76+(l+512<<2)>>2]=i+m;c[d+76+(l+768<<2)>>2]=h+m;m=k+1&65535;if((m&65535)>191){break}else{k=m;l=m&65535}}}else{l=128;k=128;while(1){i=h+((k<<8)+32768)|0;c[d+76+(k+512<<2)>>2]=i;c[d+76+(k+768<<2)>>2]=i;i=l+1&65535;if((i&65535)>191){break}else{l=i;k=i&65535}}}gGz(9706056,0,76);if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=f;c[2417276]=g;c[1836236]=-1;mr(c[3540990]|0);c[2113156]=0;a[9628264]=0;c[2407033]=0;g=c[3541206]|0;c[3541190]=g;c[3541198]=g;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=g+256;c[3541199]=g+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=g+512;c[3541200]=g+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=g+768;c[3541201]=g+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;if(!j){a[9730904]=0;a[9773432]=0;a[9751072]=0;return}c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];a[9730904]=0;a[9773432]=0;a[9751072]=0;return}function dO2(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;fwR(0);d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];f=c[3528484]|0;c[2076596]=f;g=c[2417276]|0;c[3541536]=g;c[1836236]=0;c[d+4180>>2]=2926;c[d+4184>>2]=1666;c[d+4172>>2]=1424;c[d+4176>>2]=2902;i=c[2385838]|0;j=0;k=0;while(1){c[d+76+(k<<2)>>2]=i+(k<<8);l=j+1&65535;if((l&65535)>127){break}else{j=l;k=l&65535}}k=c[3529358]|0;j=0;l=0;while(1){m=l<<8;c[d+76+(l+512<<2)>>2]=k+m;c[d+76+(l+768<<2)>>2]=i+m;m=j+1&65535;if((m&65535)>127){n=128;o=128;break}else{j=m;l=m&65535}}while(1){c[d+76+(o<<2)>>2]=i+((o<<8)+32768);l=n+1&65535;if((l&65535)>191){p=128;q=128;break}else{n=l;o=l&65535}}while(1){o=(q<<8)+32768|0;c[d+76+(q+512<<2)>>2]=k+o;c[d+76+(q+768<<2)>>2]=i+o;o=p+1&65535;if((o&65535)>191){break}else{p=o;q=o&65535}}q=c[3531098]|0;c[d+876>>2]=q;p=q+256|0;c[d+880>>2]=p;i=q+512|0;c[d+884>>2]=i;k=q+768|0;c[d+888>>2]=k;o=q+1024|0;c[d+892>>2]=o;n=q+1280|0;c[d+896>>2]=n;l=q+1536|0;c[d+900>>2]=l;j=q+1792|0;c[d+904>>2]=j;c[d+1900>>2]=q;c[d+1904>>2]=p;c[d+1908>>2]=i;c[d+1912>>2]=k;c[d+1916>>2]=o;c[d+1920>>2]=n;c[d+1924>>2]=l;c[d+1928>>2]=j;c[d+2924>>2]=q;c[d+3948>>2]=q;c[d+2928>>2]=p;c[d+3952>>2]=p;c[d+2932>>2]=i;c[d+3956>>2]=i;c[d+2936>>2]=k;c[d+3960>>2]=k;c[d+2940>>2]=o;c[d+3964>>2]=o;c[d+2944>>2]=n;c[d+3968>>2]=n;c[d+2948>>2]=l;c[d+3972>>2]=l;c[d+2952>>2]=j;c[d+3976>>2]=j;j=c[2385856]|0;l=224;n=224;while(1){c[d+76+(n<<2)>>2]=j+((n<<8)-57344);o=l+1&65535;if((o&65535)>255){r=224;s=224;break}else{l=o;n=o&65535}}while(1){c[d+76+(s+256<<2)>>2]=j+((s<<8)-57344);n=r+1&65535;if((n&65535)>255){t=224;u=224;break}else{r=n;s=n&65535}}while(1){s=j+((u<<8)-57344)|0;c[d+76+(u+512<<2)>>2]=s;c[d+76+(u+768<<2)>>2]=s;s=t+1&65535;if((s&65535)>255){break}else{t=s;u=s&65535}}if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=f;c[2417276]=g;c[1836236]=-1;if(a[9680]|0){mq(4e6,32e3);g=gGq(262144)|0;c[2406690]=g;gGz(g|0,0,262144);c[2439246]=0;h[745411]=1.0;h[745410]=1.0;a[3203304]=1;a[3203296]=1}else{mq(4e6,11025)}h[745411]=1.0;a[3203304]=1;h[745410]=1.0;a[3203296]=1;Ux(0,7500,1);c[2407030]=77;c[2407068]=3;g=c[3541206]|0;f=c[3527282]|0;gGC(g|0,f|0,262144)|0;Tq(965704);a[6939736]=1;f=c[642608+(c[2436]<<2)>>2]|0;g=c[f+128>>2]|0;if((c[f+52>>2]&4|0)==0){c[2113068]=g;e=c[f+132>>2]|0;c[2113070]=e;c[2443814]=g;c[2440436]=e;v=g;w=e}else{c[2113070]=g;e=c[f+132>>2]|0;c[2113068]=e;c[2440436]=g;c[2443814]=e;v=e;w=g}g=ag(v<<1,w)|0;w=gGq(g)|0;c[2112926]=w;if((w|0)==0){c[3527252]=65535;c[2439652]=2048;return}gGz(w|0,0,g|0);c[3527252]=65535;c[2439652]=2048;return}function dO3(){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;gGz(9625792,0,12);c=0;d=0;e=0;f=0;g=0;h=0;i=0;j=0;k=0;l=0;m=0;n=0;o=0;do{d=((a[9759200+c|0]&1)<<c|d&255)&255;e=((a[9759008+c|0]&1)<<c|e&255)&255;f=((a[9758824+c|0]&1)<<c|f&255)&255;g=((a[9758744+c|0]&1)<<c|g&255)&255;h=((a[9758704+c|0]&1)<<c|h&255)&255;i=((a[9758672+c|0]&1)<<c|i&255)&255;j=((a[9758664+c|0]&1)<<c|j&255)&255;k=((a[9758656+c|0]&1)<<c|k&255)&255;l=((a[9758648+c|0]&1)<<c|l&255)&255;m=((a[9758640+c|0]&1)<<c|m&255)&255;n=((a[9755160+c|0]&1)<<c|n&255)&255;o=((a[9755152+c|0]&1)<<c|o&255)&255;c=c+1|0;}while((c|0)<8);a[9625792]=d;a[9625793]=e;a[9625794]=f;a[9625795]=g;a[9625796]=h;a[9625797]=i;a[9625798]=j;a[9625799]=k;a[9625800]=l;a[9625801]=m;a[9625802]=n;a[9625803]=o;o=a[9774160]|0;if((o<<24>>24|0)==2){n=b[4813028]|0;if((a[9755152]|0)==0){p=n}else{m=n-4&65535;b[4813028]=m;p=m}if((a[9755153]|0)==0){q=p}else{m=p+4&65535;b[4813028]=m;q=m}do{if(q<<16>>16>255){b[4813028]=0}else{if(q<<16>>16>=0){break}b[4813028]=252}}while(0);q=b[4813024]|0;if((a[9755154]|0)==0){r=q}else{m=q-4&65535;b[4813024]=m;r=m}if((a[9755155]|0)==0){s=r}else{m=r+4&65535;b[4813024]=m;s=m}if(s<<16>>16>255){b[4813024]=0;return}if(s<<16>>16>=0){return}b[4813024]=252;return}else if((o<<24>>24|0)==1){return}else{if((e&48)==48){o=e&-49;a[9625793]=o;t=o}else{t=e}if((t&-64)<<24>>24==-64){a[9625793]=t&63}if((f&48)==48){t=f&-49;a[9625794]=t;u=t}else{u=f}if((u&-64)<<24>>24!=-64){return}a[9625794]=u&63;return}}function dO4(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;b=c[2112926]|0;gGz(b|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);e=c[2439652]|0;f=e<<1;if((f|0)>0){g=c[2439618]|0;h=c[3530044]|0;i=0;do{j=a[g+i|0]|0;k=a[g+(i|1)|0]|0;l=(((k&255)<<8|j&255)&65535)>>>4;c[h+(i>>1<<2)>>2]=((k<<4|k&8)&255)<<8&63488|((j<<4|j&8)&255)>>>3|((l<<4&255|l&12)&255)<<3&2016;i=i+2|0;}while((i|0)<(f|0))}f=c[3531098]|0;i=c[3527218]|0;h=(e|0)==2048?127:63;e=c[3527252]|0;g=c[2406524]|0;l=0;j=0;while(1){k=l<<3;m=k-8|0;n=(m|0)>8;o=248-k-8|0;L24842:do{if((o|0)>8){k=0;p=j;while(1){q=d[f+p|0]|0;r=p<<1;s=d[i+(r|1)|0]<<8|d[i+r|0];r=h&q;t=q&128;u=k<<3;L24845:do{if((a[9759712]|0)==0){v=u-64|0;w=e&s;do{if((v|0)>8){if(!((v|0)<((c[2113068]|0)-8|0)&n)){break}if((m|0)>=((c[2113070]|0)-8|0)){break}if((t|0)==0){Sq(b,w,v,m,r,4,15,0,g);break L24845}else{Ss(b,w,v,m,r,4,15,0,g);break L24845}}}while(0);if((t|0)==0){Sr(b,w,v,m,r,4,15,0,g);break}else{St(b,w,v,m,r,4,15,0,g);break}}else{x=q>>>7;y=504-u-64|0;z=e&s;do{if((y|0)>8){if((y|0)>=((c[2113068]|0)-8|0)){break}if((o|0)>=((c[2113070]|0)-8|0)){break}if((x|0)==1){Su(b,z,y,o,r,4,15,0,g);break L24845}else{Sw(b,z,y,o,r,4,15,0,g);break L24845}}}while(0);if((x|0)==1){Sv(b,z,y,o,r,4,15,0,g);break}else{Sx(b,z,y,o,r,4,15,0,g);break}}}while(0);r=k+1|0;if((r|0)>=64){break L24842}k=r;p=p+1|0}}else{p=0;k=j;while(1){r=d[f+k|0]|0;s=k<<1;u=d[i+(s|1)|0]<<8|d[i+s|0];s=h&r;q=r&128;r=p<<3;L24874:do{if((a[9759712]|0)==0){t=r-64|0;v=e&u;do{if((t|0)>8){if(!((t|0)<((c[2113068]|0)-8|0)&n)){break}if((m|0)>=((c[2113070]|0)-8|0)){break}if((q|0)==0){Sq(b,v,t,m,s,4,15,0,g);break L24874}else{Ss(b,v,t,m,s,4,15,0,g);break L24874}}}while(0);if((q|0)==0){Sr(b,v,t,m,s,4,15,0,g);break}else{St(b,v,t,m,s,4,15,0,g);break}}else{y=504-r-64|0;z=e&u;if((q|0)==0){Sx(b,z,y,o,s,4,15,0,g);break}else{Sv(b,z,y,o,s,4,15,0,g);break}}}while(0);s=p+1|0;if((s|0)>=64){break L24842}p=s;k=k+1|0}}}while(0);o=l+1|0;if((o|0)<32){l=o;j=j+64|0}else{break}}j=c[2443418]|0;l=c[3529578]|0;g=4032;do{e=d[j+(g|1)|0]|0;h=e&15;i=e<<4&256|d[j+(g|3)|0];f=(d[j+(g|2)|0]|0)+8&255;o=e<<3&1792|d[j+g|0];L24897:do{if((a[9759712]|0)==0){e=i-64|0;m=f-16|0;do{if((e|0)>16){if(!((e|0)<((c[2113068]|0)-16|0)&(m|0)>16)){break}if((m|0)>=((c[2113070]|0)-16|0)){break}SG(b,o,e,m,h,4,15,0,l);break L24897}}while(0);SH(b,o,e,m,h,4,15,0,l)}else{n=496-i-64|0;k=248-f-8|0;do{if((n|0)>16){if(!((n|0)<((c[2113068]|0)-16|0)&(k|0)>16)){break}if((k|0)>=((c[2113070]|0)-16|0)){break}SM(b,o,n,k,h,4,15,0,l);break L24897}}while(0);SN(b,o,n,k,h,4,15,0,l)}}while(0);g=g-32|0;}while((g|0)>-1);R8(c[3530044]|0);return}function dO5(b){b=b|0;var d=0,e=0,f=0;d=b&65535;if((d|0)==40961){b=c[3542228]|0;if((b|0)>15){e=0;return e|0}do{if((b|0)==15){f=c[3542225]|0;if((f|0)==0){break}a[14168931]=gj[f&4095](0)|0}else if((b|0)==14){f=c[3542224]|0;if((f|0)==0){break}a[14168930]=gj[f&4095](0)|0}}while(0);e=a[14168916+b|0]|0;return e|0}else if((d|0)==40963){d=c[3542291]|0;if((d|0)>15){e=0;return e|0}do{if((d|0)==14){b=c[3542287]|0;if((b|0)==0){break}a[14169182]=gj[b&4095](0)|0}else if((d|0)==15){b=c[3542288]|0;if((b|0)==0){break}a[14169183]=gj[b&4095](0)|0}}while(0);e=a[14169168+d|0]|0;return e|0}else{e=0;return e|0}return 0}function dO6(b,d){b=b|0;d=d|0;var e=0,f=0;e=b&65535;if((e|0)==40963){b=d&255;f=c[3542291]|0;if((f|0)>15){return}do{if((f|0)<14){if((f|0)!=13){if((a[14169168+f|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(1,f,b);return}else if((e|0)==40961){b=d&255;f=c[3542228]|0;if((f|0)>15){return}do{if((f|0)<14){if((f|0)!=13){if((a[14168916+f|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(0,f,b);return}else if((e|0)==40962){c[3542291]=d&15;return}else if((e|0)==40960){c[3542228]=d&15;return}else{return}}function dO7(a,b){a=a|0;b=b|0;if((a&255)!=0){return}c[3528714]=b&1;return}function dO8(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4479164+(b*112|0)>>2];c[a+104>>2]=c[4479168+(b*112|0)>>2];c[a+108>>2]=c[4479172+(b*112|0)>>2];d=0;return d|0}function dO9(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=4479064+(b*112|0);e=0;return e|0}function dPa(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6929552+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dPb(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7438144+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dPc(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0.0,ae=0,af=0;e=i;i=i+960|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=0;while(1){if((x|0)>=1024){break}y=9638528+(x<<2)|0;if((c[y>>2]|0)==0){z=18859;break}else{x=x+1|0}}do{if((z|0)==18859){x=gGq(329728)|0;c[y>>2]=x;if((x|0)==0){break}gGz(x|0,0,329728);c[2426750]=x;x=a[9688]|0?6408:0;A=0;while(1){if((A|0)>=1024){break}B=9638528+(A<<2)|0;if((c[B>>2]|0)==0){z=18864;break}else{A=A+1|0}}do{if((z|0)==18864){A=gGq(x)|0;c[B>>2]=A;if((A|0)==0){break}gGz(A|0,0,x|0);c[2385368]=A;A=c[2426750]|0;c[2426608]=A;c[2424852]=A+65536;c[2424828]=A+196608;c[2406940]=A+262144;A=0;while(1){if((A|0)>=1024){C=1;z=18980;break}D=9638528+(A<<2)|0;if((c[D>>2]|0)==0){break}else{A=A+1|0}}if((z|0)==18980){i=e;return C|0}A=gGq(65536)|0;c[D>>2]=A;if((A|0)==0){C=1;i=e;return C|0}gGz(A|0,0,65536);E=c[2426608]|0;if((c[3542200]|0)==0){C=1;i=e;return C|0}F=v+108|0;c[F>>2]=0;G=v+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,0)|0;do{if((c[F>>2]|0)!=0){H=c[G>>2]|0;c[w>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](w,0,0)|0;if((H|0)<1){C=1;i=e;return C|0}if((gzL(E,0,0)|0)==0){break}else{C=1}i=e;return C|0}}while(0);E=(c[2426608]|0)+16384|0;if((c[3542200]|0)==0){C=1;i=e;return C|0}G=t+108|0;c[G>>2]=0;F=t+100|0;c[F>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,1)|0;do{if((c[G>>2]|0)!=0){H=c[F>>2]|0;c[u>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](u,1,0)|0;if((H|0)<1){C=1;i=e;return C|0}if((gzL(E,0,1)|0)==0){break}else{C=1}i=e;return C|0}}while(0);E=(c[2426608]|0)+57344|0;if((c[3542200]|0)==0){C=1;i=e;return C|0}F=r+108|0;c[F>>2]=0;G=r+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,2)|0;do{if((c[F>>2]|0)!=0){H=c[G>>2]|0;c[s>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](s,2,0)|0;if((H|0)<1){C=1;i=e;return C|0}if((gzL(E,0,2)|0)==0){break}else{C=1}i=e;return C|0}}while(0);E=c[2424852]|0;if((c[3542200]|0)==0){C=1;i=e;return C|0}G=p+108|0;c[G>>2]=0;F=p+100|0;c[F>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,3)|0;do{if((c[G>>2]|0)!=0){H=c[F>>2]|0;c[q>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](q,3,0)|0;if((H|0)<1){C=1;i=e;return C|0}if((gzL(E,0,3)|0)==0){break}else{C=1}i=e;return C|0}}while(0);E=(c[2424852]|0)+16384|0;if((c[3542200]|0)==0){C=1;i=e;return C|0}F=n+108|0;c[F>>2]=0;G=n+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,4)|0;do{if((c[F>>2]|0)!=0){H=c[G>>2]|0;c[o>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](o,4,0)|0;if((H|0)<1){C=1;i=e;return C|0}if((gzL(E,0,4)|0)==0){break}else{C=1}i=e;return C|0}}while(0);E=(c[2424852]|0)+32768|0;if((c[3542200]|0)==0){C=1;i=e;return C|0}G=l+108|0;c[G>>2]=0;F=l+100|0;c[F>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,5)|0;do{if((c[G>>2]|0)!=0){H=c[F>>2]|0;c[m>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](m,5,0)|0;if((H|0)<1){C=1;i=e;return C|0}if((gzL(E,0,5)|0)==0){break}else{C=1}i=e;return C|0}}while(0);E=(c[2424852]|0)+49152|0;if((c[3542200]|0)==0){C=1;i=e;return C|0}F=j+108|0;c[F>>2]=0;G=j+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,6)|0;do{if((c[F>>2]|0)!=0){H=c[G>>2]|0;c[k>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](k,6,0)|0;if((H|0)<1){C=1;i=e;return C|0}if((gzL(E,0,6)|0)==0){break}else{C=1}i=e;return C|0}}while(0);E=c[2424852]|0;gGC(A|0,E|0,8192)|0;G=A+32768|0;F=E+8192|0;gGC(G|0,F|0,8192)|0;F=A+8192|0;G=E+16384|0;gGC(F|0,G|0,8192)|0;G=A+40960|0;F=E+24576|0;gGC(G|0,F|0,8192)|0;F=A+16384|0;G=E+32768|0;gGC(F|0,G|0,8192)|0;G=A+49152|0;F=E+40960|0;gGC(G|0,F|0,8192)|0;F=A+24576|0;G=E+49152|0;gGC(F|0,G|0,8192)|0;G=A+57344|0;F=E+57344|0;gGC(G|0,F|0,8192)|0;F=0;do{G=F<<6;gGz(E+G|0,0,64);H=F<<7;I=0;do{J=1<<3-I;K=(c[703416+(I<<2)>>2]|0)+H|0;L=0;do{M=K+(c[597800+(L<<2)>>2]|0)|0;N=(L<<3)+G|0;O=0;do{P=M+(c[597736+(O<<2)>>2]|0)|0;if(((d[A+((P|0)/8|0)|0]|0)&128>>>((P&7)>>>0)|0)!=0){P=E+(N+O)|0;a[P]=(d[P]|0|J)&255}O=O+1|0;}while((O|0)<8);L=L+1|0;}while((L|0)<8);I=I+1|0;}while((I|0)<4);F=F+1|0;}while((F|0)<2048);F=c[2424828]|0;E=0;do{I=E<<8;gGz(F+I|0,0,256);G=E<<9;H=0;do{L=1<<3-H;J=(c[703416+(H<<2)>>2]|0)+G|0;K=0;do{O=J+(c[597800+(K<<2)>>2]|0)|0;N=(K<<4)+I|0;M=0;do{P=O+(c[597736+(M<<2)>>2]|0)|0;if(((d[A+((P|0)/8|0)|0]|0)&128>>>((P&7)>>>0)|0)!=0){P=F+(N+M)|0;a[P]=(d[P]|0|L)&255}M=M+1|0;}while((M|0)<16);K=K+1|0;}while((K|0)<16);H=H+1|0;}while((H|0)<4);E=E+1|0;}while((E|0)<512);if((c[3542200]|0)==0){C=1;i=e;return C|0}E=f+108|0;c[E>>2]=0;F=f+100|0;c[F>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,7)|0;do{if((c[E>>2]|0)!=0){H=c[F>>2]|0;c[g>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](g,7,0)|0;if((H|0)<1){C=1;i=e;return C|0}if((gzL(A,0,7)|0)==0){break}else{C=1}i=e;return C|0}}while(0);F=c[2406940]|0;E=0;while(1){H=E&15;I=E>>>4;if((H|0)==1){Q=I&31}else{Q=I&16|H}H=d[A+Q|0]|0;I=H&3;c[F+(E<<2)>>2]=(H>>>2&12|I)*4352|0|(ag(H&15,1114112)|0)|((H>>>4&12|I)*17|0);I=E+1|0;if((I|0)<512){E=I}else{R=0;break}}while(1){if((R|0)>=1024){break}S=9638528+(R<<2)|0;if((c[S>>2]|0)==(A|0)){z=18929;break}else{R=R+1|0}}if((z|0)==18929){gGr(A);c[S>>2]=0}fwR(0);E=c[2439330]|0;F=(E|0)==0;if(!F){I=E;gGC(9706056,I|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];I=c[3528484]|0;c[2076596]=I;H=c[2417276]|0;c[3541536]=H;c[1836236]=0;c[E+4176>>2]=1074;c[E+4180>>2]=2624;c[E+4184>>2]=2716;G=c[2426608]|0;K=0;L=0;while(1){c[E+76+(L<<2)>>2]=G+(L<<8);J=K+1&65535;if((J&65535)>127){T=0;U=0;break}else{K=J;L=J&65535}}while(1){L=G+(U<<8)|0;c[E+76+(U+512<<2)>>2]=L;c[E+76+(U+768<<2)>>2]=L;L=T+1&65535;if((L&65535)>127){break}else{T=L;U=L&65535}}L=G+32768|0;c[E+588>>2]=L;K=G+33024|0;c[E+592>>2]=K;A=G+33280|0;c[E+596>>2]=A;J=G+33536|0;c[E+600>>2]=J;M=G+33792|0;c[E+604>>2]=M;N=G+34048|0;c[E+608>>2]=N;O=G+34304|0;c[E+612>>2]=O;P=G+34560|0;c[E+616>>2]=P;V=G+34816|0;c[E+620>>2]=V;W=G+35072|0;c[E+624>>2]=W;X=G+35328|0;c[E+628>>2]=X;Y=G+35584|0;c[E+632>>2]=Y;Z=G+35840|0;c[E+636>>2]=Z;_=G+36096|0;c[E+640>>2]=_;$=G+36352|0;c[E+644>>2]=$;aa=G+36608|0;c[E+648>>2]=aa;c[E+1612>>2]=L;c[E+1616>>2]=K;c[E+1620>>2]=A;c[E+1624>>2]=J;c[E+1628>>2]=M;c[E+1632>>2]=N;c[E+1636>>2]=O;c[E+1640>>2]=P;c[E+1644>>2]=V;c[E+1648>>2]=W;c[E+1652>>2]=X;c[E+1656>>2]=Y;c[E+1660>>2]=Z;c[E+1664>>2]=_;c[E+1668>>2]=$;c[E+1672>>2]=aa;aa=G+49152|0;c[E+844>>2]=aa;$=G+49408|0;c[E+848>>2]=$;_=G+49664|0;c[E+852>>2]=_;Z=G+49920|0;c[E+856>>2]=Z;Y=G+50176|0;c[E+860>>2]=Y;X=G+50432|0;c[E+864>>2]=X;W=G+50688|0;c[E+868>>2]=W;V=G+50944|0;c[E+872>>2]=V;c[E+1868>>2]=aa;c[E+1872>>2]=$;c[E+1876>>2]=_;c[E+1880>>2]=Z;c[E+1884>>2]=Y;c[E+1888>>2]=X;c[E+1892>>2]=W;c[E+1896>>2]=V;c[E+2892>>2]=aa;c[E+3916>>2]=aa;c[E+2896>>2]=$;c[E+3920>>2]=$;c[E+2900>>2]=_;c[E+3924>>2]=_;c[E+2904>>2]=Z;c[E+3928>>2]=Z;c[E+2908>>2]=Y;c[E+3932>>2]=Y;c[E+2912>>2]=X;c[E+3936>>2]=X;c[E+2916>>2]=W;c[E+3940>>2]=W;c[E+2920>>2]=V;c[E+3944>>2]=V;V=224;W=224;while(1){c[E+76+(W<<2)>>2]=G+(W<<8);X=V+1&65535;if((X&65535)>255){ab=224;ac=224;break}else{V=X;W=X&65535}}while(1){W=G+(ac<<8)|0;c[E+76+(ac+512<<2)>>2]=W;c[E+76+(ac+768<<2)>>2]=W;W=ab+1&65535;if((W&65535)>255){break}else{ab=W;ac=W&65535}}if(!F){G=E;gGC(G|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=I;c[2417276]=H;c[1836236]=-1;G=c[2385368]|0;c[2439026]=G;W=a[9688]|0?534:0;c[2439027]=G+(W<<1);c[2439028]=G+(W<<1<<1);c[2439029]=G+((W*3|0)<<1);c[2439030]=G+(W<<2<<1);c[2439031]=G+((W*5|0)<<1);W=a[9680]|0?32e3:0;c[3542220]=11200;G=c[2113008]|0;if((G|0)==0){gGz(14168888,0,252);c[3542223]=W;c[3542224]=2040;c[3542225]=710;c[3542226]=0;c[3542227]=0;c[3542234]=~~((+(W|0)*32768.0*8.0+75.0e4)/15.0e5);V=31;ad=32767.0;while(1){c[14169012+(V<<2)>>2]=~~(ad+.5);X=V-1|0;if((X|0)>0){V=X;ad=ad/1.188502227}else{break}}c[3542253]=0;h[1771269]=1.0;h[1771270]=1.0;h[1771271]=1.0;c[3542574]=3;c[3542575]=3;c[3542576]=3;mB(0);V=(c[2113008]|0)+1|0;c[2113008]=V;ae=V;af=a[9680]|0?32e3:0}else{ae=G;af=W}c[3542220]=11200;if((ae|0)==1){gGz(14169140,0,252);c[3542286]=af;c[3542287]=3260;c[3542288]=2460;c[3542289]=0;c[3542290]=0;c[3542297]=~~((+(af|0)*32768.0*8.0+75.0e4)/15.0e5);V=31;ad=32767.0;while(1){c[14169264+(V<<2)>>2]=~~(ad+.5);H=V-1|0;if((H|0)>0){V=H;ad=ad/1.188502227}else{break}}c[3542316]=0;h[1771272]=1.0;h[1771273]=1.0;h[1771274]=1.0;c[3542577]=3;c[3542578]=3;c[3542579]=3;mB(1);c[2113008]=(c[2113008]|0)+1}h[1771269]=.25;c[3542574]=3;h[1771270]=.25;c[3542575]=3;h[1771271]=.25;c[3542576]=3;h[1771272]=.25;c[3542577]=3;h[1771273]=.25;c[3542578]=3;h[1771274]=.25;c[3542579]=3;a[9624392]=0;V=c[2426608]|0;gGz(V+32768|0,0,4096);gGz(V+49152|0,0,2048);c[3528714]=0;V=c[2439330]|0;W=(V|0)==0;if(!W){G=V;gGC(9706056,G|0,76)|0}G=c[2438118]|0;c[2433530]=G;H=c[3528484]|0;c[2076596]=H;I=c[2417276]|0;c[3541536]=I;c[1836236]=0;gGz(9706056,0,76);if(!W){W=V;gGC(W|0,9706056,76)|0}c[2438118]=G;c[3528484]=H;c[2417276]=I;c[1836236]=-1;mB(0);mB(1);C=0;i=e;return C|0}}while(0);c[2385368]=0;C=1;i=e;return C|0}}while(0);c[2426750]=0;C=1;i=e;return C|0}function dPd(){var a=0,b=0,d=0,e=0,f=0;fwZ();c[2113008]=0;c[2076598]=0;c[2383582]=0;a=c[2385368]|0;b=0;while(1){if((b|0)>=1024){break}d=9638528+(b<<2)|0;if((c[d>>2]|0)==(a|0)){e=18986;break}else{b=b+1|0}}if((e|0)==18986){gGr(a);c[d>>2]=0}c[2385368]=0;d=c[2426750]|0;a=0;while(1){if((a|0)>=1024){break}f=9638528+(a<<2)|0;if((c[f>>2]|0)==(d|0)){e=18990;break}else{a=a+1|0}}if((e|0)==18990){gGr(d);c[f>>2]=0}c[2426750]=0;c[2424828]=0;c[2424852]=0;c[2426608]=0;c[2406940]=0;c[3528714]=0;c[2408980]=0;return 0}function dPe(){var d=0,e=0,f=0,g=0,h=0,i=0;if((a[9624392]|0)!=0){a[9624392]=0;d=c[2426608]|0;gGz(d+32768|0,0,4096);gGz(d+49152|0,0,2048);c[3528714]=0;d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;h=c[2417276]|0;c[3541536]=h;c[1836236]=0;gGz(9706056,0,76);if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=h;c[1836236]=-1;mB(0);mB(1)}c[2408980]=0;h=c[2439330]|0;if((h|0)!=0){g=h;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;g=c[2438118]|0;c[2433530]=g;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;if((a[h+4188|0]|0)==0){h=gfc(5e4)|0;i=(c[2433530]|0)+h|0}else{i=g+5e4|0}c[2433530]=i;a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0;i=c[1836236]|0;g=c[9757320+(i<<2)>>2]|0;if((g|0)!=0){h=g;gGC(h|0,9706056,76)|0}c[9752472+(i<<2)>>2]=c[2433530];c[14113936+(i<<2)>>2]=c[2076596];c[9669104+(i<<2)>>2]=c[3541536];c[1836236]=-1;i=c[2112964]|0;if((i|0)!=0){mF(9756104,i,a[9688]|0?534:0,0)}if((c[2112968]|0)==0){return 0}dPf()|0;return 0}function dPf(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;dPj(0);e=c[2426608]|0;f=c[2424828]|0;g=c[2406940]|0;h=c[2112968]|0;i=c[2113308]|0;j=(i|0)>3;k=(i|0)==2;l=0;do{m=d[e+(l+32769)|0]|0;n=a[e+(l+32770)|0]|0;if((n-16&255)<=207){o=n&255;n=o-32|0;p=d[e+(l+32768)|0]|0;q=p&1;r=d[e+(l+32771)|0]|0;s=r&240;t=f+((r<<6&448|p>>>2)<<8)|0;if((p&2|0)==0){p=o-16|0;r=(q|0)==0;u=m+15|0;v=m+16|0;w=-m|0;x=-15-m|0;y=m+1|0;z=(v>>>0>y>>>0?v:y)-m|0;y=v+((x|0)<(w|0)?w:x)|0;x=t;w=n;while(1){A=w>>>0>191;B=w<<8;C=191-w<<8;if(r){D=x;E=m;while(1){do{if(!A){F=a[D]|0;if(F<<24>>24==0){break}G=c[g+((F&255|s)<<2)>>2]|0;F=E&255;if((c[3528714]|0)==0){H=F|B}else{H=(F|C)^255}F=ag(i,H)|0;I=h+F|0;J=G>>16<<8&63488|G>>8<<3&2016;K=J|G>>>3&31;if(j){c[I>>2]=K;break}if(k){b[I>>1]=K&65535;break}else{a[I]=K&255;a[h+(F+1)|0]=J>>>8&255;a[h+(F+2)|0]=0;break}}}while(0);F=E+1|0;if((F|0)<(v|0)){D=D+1|0;E=F}else{L=z;break}}}else{E=x;D=u;while(1){do{if(!A){F=a[E]|0;if(F<<24>>24==0){break}J=c[g+((F&255|s)<<2)>>2]|0;F=D&255;if((c[3528714]|0)==0){M=F|B}else{M=(F|C)^255}F=ag(i,M)|0;K=h+F|0;I=J>>16<<8&63488|J>>8<<3&2016;G=I|J>>>3&31;if(j){c[K>>2]=G;break}if(k){b[K>>1]=G&65535;break}else{a[K]=G&255;a[h+(F+1)|0]=I>>>8&255;a[h+(F+2)|0]=0;break}}}while(0);F=D-1|0;if((F|0)<(m|0)){L=y;break}else{E=E+1|0;D=F}}}D=w+1|0;if((D|0)<(p|0)){x=x+L|0;w=D}else{break}}}else{w=(q|0)==0;x=m+15|0;p=m+16|0;y=-m|0;u=-15-m|0;z=m+1|0;v=(p>>>0>z>>>0?p:z)-m|0;z=p+((u|0)<(y|0)?y:u)|0;u=t;y=o-17|0;while(1){r=y>>>0>191;D=y<<8;E=191-y<<8;if(w){C=u;B=m;while(1){do{if(!r){A=a[C]|0;if(A<<24>>24==0){break}F=c[g+((A&255|s)<<2)>>2]|0;A=B&255;if((c[3528714]|0)==0){N=A|D}else{N=(A|E)^255}A=ag(i,N)|0;I=h+A|0;G=F>>16<<8&63488|F>>8<<3&2016;K=G|F>>>3&31;if(j){c[I>>2]=K;break}if(k){b[I>>1]=K&65535;break}else{a[I]=K&255;a[h+(A+1)|0]=G>>>8&255;a[h+(A+2)|0]=0;break}}}while(0);A=B+1|0;if((A|0)<(p|0)){C=C+1|0;B=A}else{O=v;break}}}else{B=u;C=x;while(1){do{if(!r){A=a[B]|0;if(A<<24>>24==0){break}G=c[g+((A&255|s)<<2)>>2]|0;A=C&255;if((c[3528714]|0)==0){P=A|D}else{P=(A|E)^255}A=ag(i,P)|0;K=h+A|0;I=G>>16<<8&63488|G>>8<<3&2016;F=I|G>>>3&31;if(j){c[K>>2]=F;break}if(k){b[K>>1]=F&65535;break}else{a[K]=F&255;a[h+(A+1)|0]=I>>>8&255;a[h+(A+2)|0]=0;break}}}while(0);A=C-1|0;if((A|0)<(m|0)){O=z;break}else{B=B+1|0;C=A}}}C=y-1|0;if((C|0)<(n|0)){break}else{u=u+O|0;y=C}}}}l=l+32|0;}while((l|0)<2048);dPj(1);return 0}function dPg(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;d=i;i=i+64|0;e=d|0;f=d+32|0;g=d+48|0;h=(b|0)==0;if(!h){c[b>>2]=169249}if((a&96|0)==0){i=d;return 0}gGz(g|0,0,12);j=g|0;c[j>>2]=(c[2426608]|0)+32768;k=g+4|0;c[k>>2]=4096;l=g+12|0;c[l>>2]=151792;gj[c[2076592]&4095](g)|0;c[j>>2]=(c[2426608]|0)+49152;c[k>>2]=2048;c[l>>2]=397736;gj[c[2076592]&4095](g)|0;fw$(a);g=d+16|0;do{if((a&64|0)!=0){do{if(!h){if((c[b>>2]|0)>=169110){break}c[b>>2]=169110}}while(0);if((c[2113008]|0)<=0){break}l=e|0;k=e+4|0;j=e+8|0;m=e+12|0;n=0;do{cC(g|0,531144,(o=i,i=i+8|0,c[o>>2]=n,o)|0)|0;i=o;c[l>>2]=14168888+(n*252|0);c[k>>2]=252;c[j>>2]=0;c[m>>2]=g;gj[c[2076592]&4095](e)|0;n=n+1|0;}while((n|0)<(c[2113008]|0))}}while(0);gGz(f|0,0,12);c[f>>2]=14114856;c[f+4>>2]=4;c[f+12>>2]=142288;gj[c[2076592]&4095](f)|0;i=d;return 0}function dPh(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2453236+(b*112|0)>>2];c[a+104>>2]=c[2453240+(b*112|0)>>2];c[a+108>>2]=c[2453244+(b*112|0)>>2];d=0;return d|0}function dPi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=2453136+(b*112|0);e=0;return e|0}function dPj(e){e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;f=(e|0)==0;e=c[2426608]|0;g=c[2424852]|0;h=c[2406940]|0;i=c[2112968]|0;j=c[2113308]|0;k=(j|0)>3;l=(j|0)==2;m=959;n=-8;while(1){o=n&255;p=o+8|0;q=o|1;r=(p>>>0>q>>>0?p:q)-o|0;o=a[e+(m+35840)|0]|0;do{if((o&8)!=0|f){q=m<<3&248;p=m>>>2&248;s=p-32|0;if(s>>>0>191){break}t=o&255;u=p-24|0;p=q+8|0;v=t&240|256;w=g+((d[e+(m+34816)|0]|0|t<<8&1792)<<6)|0;t=s;while(1){s=t<<8;x=191-t<<8;if(f){y=w;z=q;while(1){A=c[h+((d[y]|0|v)<<2)>>2]|0;B=z&255;if((c[3528714]|0)==0){C=B|s}else{C=(B|x)^255}B=ag(j,C)|0;D=i+B|0;E=A>>16<<8&63488|A>>8<<3&2016;F=E|A>>>3&31;do{if(k){c[D>>2]=F}else{if(l){b[D>>1]=F&65535;break}else{a[D]=F&255;a[i+(B+1)|0]=E>>>8&255;a[i+(B+2)|0]=0;break}}}while(0);B=z+1|0;if((B|0)<(p|0)){y=y+1|0;z=B}else{break}}}else{z=w;y=q;while(1){B=a[z]|0;do{if(B<<24>>24!=0){E=c[h+((B&255|v)<<2)>>2]|0;F=y&255;if((c[3528714]|0)==0){G=F|s}else{G=(F|x)^255}F=ag(j,G)|0;D=i+F|0;A=E>>16<<8&63488|E>>8<<3&2016;H=A|E>>>3&31;if(k){c[D>>2]=H;break}if(l){b[D>>1]=H&65535;break}else{a[D]=H&255;a[i+(F+1)|0]=A>>>8&255;a[i+(F+2)|0]=0;break}}}while(0);B=y+1|0;if((B|0)<(p|0)){z=z+1|0;y=B}else{break}}}y=t+1|0;if((y|0)<(u|0)){w=w+r|0;t=y}else{break}}}}while(0);r=m-1|0;if((r|0)<=63){break}m=r;n=n-8&255}return}function dPk(a){a=a|0;a=c[2408980]^128;c[2408980]=a;return((d[9633808]|0)^(a|127)^(d[9633809]|0)<<1^(d[9633810]|0)<<2^(d[9633811]|0)<<3^(d[9633812]|0)<<4^(d[9633813]|0)<<5^(d[9633814]|0)<<6^(d[9633815]|0)<<7)&255|0}function dPl(b){b=b|0;return a[9631609]<<1^~a[9631608]^a[9631610]<<2^a[9631611]<<3^a[9631612]<<4^a[9631613]<<5^a[9631614]<<6^a[9631615]<<7|0}function dPm(a){a=a|0;return-1|0}function dPn(b){b=b|0;return a[9635224]|0}function dPo(d,e){d=d|0;e=e|0;switch(d|0){case 446470:{b[(c[2386724]|0)+4>>1]=e&1023;return};case 446468:{b[(c[2386724]|0)+2>>1]=e&511;return};case 446464:{a[c[3529398]|0]=(e&65535)>>>8&255;a[c[3528712]|0]=(e&65535)>>>12&1;return};case 446466:{b[c[2386724]>>1]=e&1023;return};case 446474:{a[c[3528290]|0]=(e&255)<<1|1;return};case 446472:{b[(c[2386724]|0)+6>>1]=e&511;return};default:{return}}}function dPp(d,e){d=d|0;e=e|0;var f=0,g=0,h=0;f=c[2443738]|0;g=(f|0)==6;do{if(g){if((d&16777152|0)!=262144){break}b[(c[2387338]|0)+((d>>>1&31)<<1)>>1]=e;return}}while(0);switch(d|0){case 507908:{b[(c[2386724]|0)+2>>1]=e&511;return};case 507914:{a[c[3528290]|0]=(e&255)<<1|1;return};case 507904:{L25409:do{switch(f|0){case 6:case 5:case 3:case 0:{d=e&16640;if(!((d|0)==16384&(f|0)!=6|(d|0)==0&g)){break L25409}d=c[2405800]|0;h=16;do{b[d+(h<<1)>>1]=32;h=h+1|0;}while((h|0)<4096);break};case 2:{if((e&128)!=0){break L25409}gGz(c[2405800]|0,-1|0,8192);break};default:{}}}while(0);a[c[3529398]|0]=(e&65535)>>>8&255;a[c[3528712]|0]=(e&65535)>>>12&1;return};case 507918:{if(!((f|0)==5|(f|0)==3|(f|0)==0)){return}b[c[2387338]>>1]=e;return};case 507906:{b[c[2386724]>>1]=e&1023;return};default:{return}}}function dPq(a,d){a=a|0;d=d|0;var e=0;if((c[2443738]|0)!=0){return}if((a|0)==507910){e=c[2387338]|0;b[e+22>>1]=d&255;b[e+62>>1]=1;return}else if((a|0)==786432){b[(c[2387338]|0)+62>>1]=0;return}else if((a|0)==507912){a=c[2387338]|0;e=d&255;if((b[a+62>>1]|0)==0){b[a+26>>1]=e;return}else{b[a+28>>1]=(e&65535)>>>4;b[a+24>>1]=e;return}}else{return}}function dPr(a){a=a|0;var c=0;if((a|0)==491526){c=b[4775303]|0}else if((a|0)==491522){c=b[4775301]|0}else if((a|0)==491524){c=b[4775302]|0}else if((a|0)==491520){c=b[4775300]|0}else{c=0}return c|0}function dPs(e,f){e=e|0;f=f|0;var g=0,i=0;g=e&255;if((g|0)==3){US(1,gD[c[2385651]&8191]()|0);b[4771288]=~~(+(b[9753784+((f&255)<<1)>>1]|0)*+h[1192823])&65535;return}else if((g|0)==0){a[(c[3540984]|0)+5885|0]=f;return}else if((g|0)==1){e=c[3540984]|0;i=c[e+5876>>2]|0;if((i|0)!=0){gg[i&4095](c[e+5880>>2]|0,0)}lH(e,d[e+5885|0]|0,f&255);return}else if((g|0)==2){US(0,gD[c[2385643]&8191]()|0);b[4771272]=~~(+(b[9753784+((f&255)<<1)>>1]|0)*+h[1192819])&65535;return}else{return}}function dPt(b){b=b|0;var d=0,e=0;d=b&255;if((d|0)==4){a[c[3528290]|0]=0;e=0}else if((d|0)==6){e=a[c[3528290]|0]|0}else{e=0}return e|0}function dPu(a,b){a=a|0;b=b|0;return}function dPv(a){a=a|0;return 0}function dPw(b,d){b=b|0;d=d|0;if((b-16384&65535)>=8192){return}a[(c[2405800]|0)+((b&65535^1)-16384)|0]=d;return}function dPx(b){b=b|0;var d=0;if((b-16384&65535)>=8192){d=0;return d|0}d=a[(c[2405800]|0)+((b&65535^1)-16384)|0]|0;return d|0}function dPy(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5952276+(b*112|0)>>2];c[a+104>>2]=c[5952280+(b*112|0)>>2];c[a+108>>2]=c[5952284+(b*112|0)>>2];d=0;return d|0}function dPz(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=5952176+(b*112|0);e=0;return e|0}function dPA(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4274696+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dPB(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>46){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6433496+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dPC(){var b=0;c[2443738]=1;a[6995848]=1;c[2406744]=1;b=dQb(4698,2064,63488)|0;h[1192819]=.5;c[2385642]=3;h[1192823]=.5;c[2385650]=3;return b|0}function dPD(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}UT();b=a[7452584]|0;if(b){d=0;e=b&1;while(1){b=14163936+(d<<2)|0;f=c[b>>2]|0;g=c[2113006]|0;if((g|0)==0){h=19247}else{i=g-1|0;c[2113006]=i;if((i|0)==0){h=19247}}if((h|0)==19247){h=0;c[2383474]=0}if((f|0)==0){j=e}else{gGr(f);j=a[7452584]&1}c[b>>2]=0;b=d+1|0;if((b|0)<(j|0)){d=b;e=j}else{break}}}a[7452584]=0;c[2438224]=0;c[2433522]=0;c[2406672]=0;c[3528468]=0;j=c[2406688]|0;if((j|0)!=0){gGr(j);c[2406688]=0}c[2432972]=0;if((c[2392]|0)>=0){j=0;do{e=14130368+(j<<2)|0;d=c[e>>2]|0;if((d|0)!=0){gGr(d);c[e>>2]=0}e=14130384+(j<<2)|0;d=c[e>>2]|0;if((d|0)!=0){gGr(d);c[e>>2]=0}j=j+1|0;}while((j|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;fwZ();j=c[2414992]|0;e=0;while(1){if((e|0)>=1024){h=19265;break}k=9638528+(e<<2)|0;if((c[k>>2]|0)==(j|0)){break}else{e=e+1|0}}if((h|0)==19265){c[2414992]=0;a[641808]=0;return 0}gGr(j);c[k>>2]=0;c[2414992]=0;a[641808]=0;return 0}function dPE(){var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;e=i;i=i+40|0;f=e|0;if((a[9624376]|0)!=0){dQg()}g=c[2392]|0;if((g|0)>=0){gGz(8452240,0,((g|0)>0?(g<<2)+4|0:4)|0)}c[2113054]=0;g=c[2385548]|0;if((g|0)>0){gGz(9752472,0,((g|0)>1?g<<2:4)|0)}c[2433530]=0;c[2387650]=-1;g=0;h=-1;j=-1;do{h=((a[9633776+g|0]&1)<<g^h&65535)&65535;j=((a[9631576+g|0]&1)<<g^j&65535)&65535;g=g+1|0;}while((g|0)<16);b[4775300]=h;b[4775301]=j;g=d[9635216]|-256;b[4775302]=g;k=d[9635217]|-256;b[4775303]=k;if((c[2443738]|0)==1){l=c[3531134]|0;b[l>>1]=h;b[l+2>>1]=j;b[l+4>>1]=g;b[l+6>>1]=k}c[f>>2]=10;c[f+4>>2]=20;c[f+8>>2]=30;c[f+12>>2]=40;c[f+16>>2]=50;c[f+20>>2]=60;c[f+24>>2]=70;c[f+28>>2]=80;c[f+32>>2]=90;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];k=c[3532592]|0;if((k|0)!=0){gGC(9104152,k|0,280)|0}c[2113054]=c[2113060]}k=c[2439330]|0;if((k|0)==0){m=0;n=0;o=0}else{l=k;gGC(9706056,l|0,76)|0;m=0;n=0;o=0}L25570:while(1){b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;l=m;k=n;while(1){if((l|0)>=100){break L25570}p=l+1|0;g=((p*133333|0|0)/100|0)-k|0;c[2113056]=g;j=RG(g)|0;c[2113054]=(c[2113054]|0)+j;c[2276108]=-1;c[2113056]=-1;UF(l*666|0)|0;g=0;do{if((l|0)==(c[f+(g<<2)>>2]|0)){a[9706117]=1;if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){h=gfc(3e3)|0;q=(c[2433530]|0)+h|0}else{q=(c[2433530]|0)+3e3|0}c[2433530]=q;a[9706117]=0}g=g+1|0;}while((g|0)<9);r=j+k|0;if(a[641808]|0){break}else{l=p;k=r}}k=c[1836236]|0;l=c[9757320+(k<<2)>>2]|0;if((l|0)!=0){g=l;gGC(g|0,9706056,76)|0}c[9752472+(k<<2)>>2]=c[2433530];c[14113936+(k<<2)>>2]=c[2076596];c[9669104+(k<<2)>>2]=c[3541536];c[1836236]=-1;k=c[2439331]|0;if((k|0)!=0){g=k;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;g=c[2438119]|0;c[2433530]=g;c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;l=((p*66666|0|0)/100|0)-o|0;do{if((l|0)<1){s=0;t=1;u=k;v=g}else{if((a[k+4188|0]|0)==0){h=gfc(l)|0;w=(c[2433530]|0)+h|0;c[2433530]=w;x=c[1836236]|0;s=h;t=x;u=c[9757320+(x<<2)>>2]|0;v=w;break}else{w=g+l|0;c[2433530]=w;s=l;t=1;u=k;v=w;break}}}while(0);k=s+o|0;if((u|0)!=0){l=u;gGC(l|0,9706056,76)|0}c[9752472+(t<<2)>>2]=v;c[14113936+(t<<2)>>2]=c[2076596];c[9669104+(t<<2)>>2]=c[3541536];c[1836236]=-1;l=c[2439330]|0;if((l|0)==0){m=p;n=r;o=k;continue}g=l;gGC(9706056,g|0,76)|0;m=p;n=r;o=k}o=c[2438224]|0;r=gGS(-747372544,31788,o,(o|0)<0|0?-1:0)|0;o=r;UF(66666)|0;r=c[2443826]|0;if((r|0)<1073676288){c[2443826]=r-o}r=c[2443827]|0;if((r|0)<1073676288){c[2443827]=r-o}r=(c[3528508]|0)-o|0;c[3528508]=(r|0)<0?0:r;r=c[2112964]|0;if((r|0)!=0){gg[c[3542112]&4095](r,a[9688]|0?534:0);UR(c[2112964]|0,a[9688]|0?534:0)}r=c[2406744]|0;c[8452200+(c[2394]<<2)>>2]=r|8192;o=c[2276080]|0;n=r<<8;c[2276080]=n;do{if((o|0)!=1792&(n|0)==1792){RH(7)}else{if(n>>>0<=(c[2276079]|0)>>>0){break}RH(r&16777215)}}while(0);r=c[1836236]|0;n=c[9757320+(r<<2)>>2]|0;if((n|0)!=0){o=n;gGC(o|0,9706056,76)|0}c[9752472+(r<<2)>>2]=c[2433530];c[14113936+(r<<2)>>2]=c[2076596];c[9669104+(r<<2)>>2]=c[3541536];c[1836236]=-1;r=c[2394]|0;o=c[14130368+(r<<2)>>2]|0;if((o|0)!=0){gGC(o|0,9104152,280)|0}c[8452240+(r<<2)>>2]=c[2113054];c[2394]=-1;if((c[2112968]|0)==0){i=e;return 0}dPF()|0;i=e;return 0}function dPF(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((a[9547560]|0)!=0){d=c[2387220]|0;f=c[3530042]|0;g=0;do{h=b[d+(g<<1)>>1]|0;i=h&255;c[f+(g<<2)>>2]=((i&-16|(i&255)>>>4)&255)<<3&2016|((i&8|i<<4)&255)>>>3|(((h&65535)>>>4&255&-16|(h&65535)>>>8&8)&255)<<8&63488;g=g+1|0;}while((g|0)<2048)}g=ag(c[2113070]|0,c[2113068]|0)|0;if((g|0)>0){f=c[2112926]|0;d=0;do{b[f+(d<<1)>>1]=255;d=d+1|0;}while((d|0)<(g|0))}g=c[2443738]|0;if((g|0)==5|(g|0)==0){j=(b[c[2387338]>>1]&15)!=15|0}else{j=1}if((g|0)!=1){if((g|0)==6|(g|0)==0){k=c[2387338]|0}else{k=c[2405800]|0}g=c[2386724]|0;b[g+4>>1]=b[k+28>>1]<<8&768|b[k+26>>1]&255;b[g+6>>1]=b[k+24>>1]<<8&256|b[k+22>>1]&255}k=c[3529398]|0;if((a[k]&8)!=0){g=c[2386724]|0;dQm(c[2406574]|0,c[3530440]|0,e[g>>1]|0,e[g+2>>1]|0,1536,1023)}g=c[2387338]|0;do{if((b[g>>1]&48)==48){if((a[k]&1)==0){break}dQn(j)}}while(0);if((a[k]&2)!=0){dQo(2)}do{if((b[g>>1]&48)==32){if((a[k]&1)==0){break}dQn(j)}}while(0);if((a[k]&4)!=0){d=c[2386724]|0;dQm(c[2406494]|0,c[3530626]|0,e[d+4>>1]|0,e[d+6>>1]|0,1024,2047)}do{if((b[g>>1]&48)==16){if((a[k]&1)==0){break}dQn(j)}}while(0);if((a[k]&2)!=0){dQo(1)}do{if((b[g>>1]&48)==0){if((a[k]&1)==0){break}dQn(j)}}while(0);if((a[k]&2)==0){l=c[3530042]|0;R8(l);m=c[2386572]|0;n=c[2386476]|0;gGC(m|0,n|0,4096)|0;return 0}dQo(0);l=c[3530042]|0;R8(l);m=c[2386572]|0;n=c[2386476]|0;gGC(m|0,n|0,4096)|0;return 0}function dPG(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=i;i=i+80|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;l=(d|0)==0;if(!l){c[d>>2]=169730}if((b&32|0)!=0){gGz(k|0,0,12);m=c[2414696]|0;c[k>>2]=m;c[k+4>>2]=(c[2411710]|0)-m;c[k+12>>2]=162152;m=c[2076592]|0;gj[m&4095](k)|0}if((b&64|0)==0){i=e;return 0}k=j|0;gGz(h|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){m=j+9|0;j=g;n=g|0;o=g+4|0;p=g+12|0;q=h|0;r=h+4|0;s=h+12|0;t=0;do{gGC(k|0,614896,11)|0;a[m]=t+48&255;u=8452256+(t<<2)|0;gGz(j|0,0,12);c[n>>2]=u;c[o>>2]=4;c[p>>2]=164976;gj[c[2076592]&4095](g)|0;if((c[u>>2]|0)!=0){c[q>>2]=c[14130368+(t<<2)>>2];c[r>>2]=c[8452184+(t<<2)>>2];c[s>>2]=k;u=c[2076592]|0;gj[u&4095](h)|0}t=t+1|0;}while((t|0)<=(c[2392]|0))}fw$(b);UQ(b,d);if(!l){c[d>>2]=169753}if((c[2405758]|0)<=0){i=e;return 0}d=f;l=f|0;b=f+4|0;t=f+12|0;h=0;do{gGz(d|0,0,12);c[l>>2]=9542544+(h<<5);c[b>>2]=2;c[t>>2]=119040;gj[c[2076592]&4095](f)|0;h=h+1|0;}while((h|0)<(c[2405758]|0));i=e;return 0}function dPH(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4829284+(b*112|0)>>2];c[a+104>>2]=c[4829288+(b*112|0)>>2];c[a+108>>2]=c[4829292+(b*112|0)>>2];d=0;return d|0}function dPI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=4829184+(b*112|0);e=0;return e|0}function dPJ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3025924+(b*112|0)>>2];c[a+104>>2]=c[3025928+(b*112|0)>>2];c[a+108>>2]=c[3025932+(b*112|0)>>2];d=0;return d|0}function dPK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=3025824+(b*112|0);e=0;return e|0}function dPL(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>24){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1293992+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dPM(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>39){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4177264+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dPN(){c[2443738]=4;a[6995848]=0;c[2406744]=2;return dQb(2126,6976,49152)|0}function dPO(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3023908+(b*112|0)>>2];c[a+104>>2]=c[3023912+(b*112|0)>>2];c[a+108>>2]=c[3023916+(b*112|0)>>2];d=0;return d|0}function dPP(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=3023808+(b*112|0);e=0;return e|0}function dPQ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5804108+(b*112|0)>>2];c[a+104>>2]=c[5804112+(b*112|0)>>2];c[a+108>>2]=c[5804116+(b*112|0)>>2];d=0;return d|0}function dPR(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=5804008+(b*112|0);e=0;return e|0}function dPS(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>38){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6267808+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dPT(){c[2443738]=2;a[6995848]=1;c[2406744]=1;return dQb(2464,6976,63488)|0}function dPU(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5802644+(b*112|0)>>2];c[a+104>>2]=c[5802648+(b*112|0)>>2];c[a+108>>2]=c[5802652+(b*112|0)>>2];d=0;return d|0}function dPV(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=5802544+(b*112|0);e=0;return e|0}function dPW(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>40){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6251840+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dPX(){var d=0,e=0;c[2443738]=3;a[6995848]=0;c[2406744]=2;d=dQb(1086,6976,49152)|0;if((d|0)!=0){return d|0}e=c[2388170]|0;b[e+470>>1]=1;b[e+1160>>1]=20081;return d|0}function dPY(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4577068+(b*112|0)>>2];c[a+104>>2]=c[4577072+(b*112|0)>>2];c[a+108>>2]=c[4577076+(b*112|0)>>2];d=0;return d|0}function dPZ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=4576968+(b*112|0);e=0;return e|0}function dP_(){var d=0;c[2443738]=6;a[6995848]=0;c[2406744]=2;d=dQb(3192,6976,49152)|0;if((d|0)!=0){return d|0}b[(c[2388170]|0)+470>>1]=1;return d|0}function dP$(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5655964+(b*112|0)>>2];c[a+104>>2]=c[5655968+(b*112|0)>>2];c[a+108>>2]=c[5655972+(b*112|0)>>2];d=0;return d|0}function dP0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=5655864+(b*112|0);e=0;return e|0}function dP1(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>38){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6037936+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dP2(){var b=0;c[2443738]=0;a[6995848]=1;c[2406744]=1;b=dQb(4698,6976,63488)|0;h[1192819]=.8;c[2385642]=3;h[1192823]=.8;c[2385650]=3;return b|0}function dP3(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4363788+(b*112|0)>>2];c[a+104>>2]=c[4363792+(b*112|0)>>2];c[a+108>>2]=c[4363796+(b*112|0)>>2];d=0;return d|0}function dP4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=4363688+(b*112|0);e=0;return e|0}function dP5(){var b=0;c[2443738]=5;a[6995848]=1;c[2406744]=1;b=dQb(4698,6976,63488)|0;h[1192819]=.8;c[2385642]=3;h[1192823]=.8;c[2385650]=3;return b|0}function dP6(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2171252+(b*112|0)>>2];c[a+104>>2]=c[2171256+(b*112|0)>>2];c[a+108>>2]=c[2171260+(b*112|0)>>2];d=0;return d|0}function dP7(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=2171152+(b*112|0);e=0;return e|0}function dP8(){var b=0;c[2443738]=5;a[6995848]=1;c[2406744]=1;a[641808]=1;b=dQb(3470,6976,63488)|0;h[1192819]=.8;c[2385642]=3;h[1192823]=.8;c[2385650]=3;return b|0}function dP9(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4365580+(b*112|0)>>2];c[a+104>>2]=c[4365584+(b*112|0)>>2];c[a+108>>2]=c[4365588+(b*112|0)>>2];d=0;return d|0}function dQa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=4365480+(b*112|0);e=0;return e|0}function dQb(e,f,g){e=e|0;f=f|0;g=g|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;c[2414992]=0;c[2385936]=0;c[2388170]=65536;c[3530862]=458752;c[3530626]=524288;c[3530440]=1048576;c[3530340]=1572864;i=a[641808]|0;if(i){c[3529172]=2097152;j=2113536}else{j=2097152}c[3530042]=j;k=j+8192|0;c[2414696]=k;c[2386476]=k;c[2386572]=j+12288;c[2406574]=j+16384;c[2406494]=j+20480;c[2405800]=j+24576;c[2387220]=j+32768;c[3531170]=j+36864;c[3531148]=j+57344;c[3531134]=j+61440;c[3528712]=j+65536;c[3528290]=j+65537;c[3529398]=j+65538;c[2386724]=j+65539;c[2387338]=j+65547;c[2386090]=j+65611;k=j+81995|0;if(i){c[3529270]=k;l=j+84043|0}else{l=k}c[2411710]=l;c[2414252]=l;k=l;l=0;while(1){if((l|0)>=1024){break}m=9638528+(l<<2)|0;if((c[m>>2]|0)==0){n=19556;break}else{l=l+1|0}}do{if((n|0)==19556){l=gGq(k)|0;c[m>>2]=l;if((l|0)==0){break}gGz(l|0,0,k|0);c[2414992]=l;gGz(l|0,0,k|0);c[2385936]=l;c[2388170]=l+65536;c[3530862]=l+458752;c[3530626]=l+524288;c[3530440]=l+1048576;c[3530340]=l+1572864;j=l+2097152|0;i=a[641808]|0;if(i){c[3529172]=j;o=l+2113536|0}else{o=j}c[3530042]=o;j=o+8192|0;c[2414696]=j;c[2386476]=j;c[2386572]=o+12288;c[2406574]=o+16384;c[2406494]=o+20480;c[2405800]=o+24576;c[2387220]=o+32768;c[3531170]=o+36864;c[3531148]=o+57344;c[3531134]=o+61440;c[3528712]=o+65536;c[3528290]=o+65537;c[3529398]=o+65538;c[2386724]=o+65539;c[2387338]=o+65547;c[2386090]=o+65611;j=o+81995|0;if(i){c[3529270]=j;p=o+84043|0}else{p=j}c[2411710]=p;c[2414252]=p;do{if((e|0)==0){q=0}else{if((gD[e&8191]()|0)==0){q=0;break}else{r=1}return r|0}}while(0);while(1){if((q|0)>=1024){break}s=9638528+(q<<2)|0;if((c[s>>2]|0)==0){n=19566;break}else{q=q+1|0}}L25916:do{if((n|0)==19566){j=gGq(262144)|0;c[s>>2]=j;if((j|0)==0){break}gGz(j|0,0,262144);i=c[3530862]|0;gGC(j|0,i|0,32768)|0;l=0;do{t=l<<6;gGz(i+t|0,0,64);u=l<<8;v=0;do{w=1<<3-v;x=(c[703416+(v<<2)>>2]|0)+u|0;y=0;do{z=x+(c[611840+(y<<2)>>2]|0)|0;A=(y<<3)+t|0;B=0;do{C=z+(c[612512+(B<<2)>>2]|0)|0;if(((d[j+((C|0)/8|0)|0]|0)&128>>>((C&7)>>>0)|0)!=0){C=i+(A+B)|0;a[C]=(d[C]|0|w)&255}B=B+1|0;}while((B|0)<8);y=y+1|0;}while((y|0)<8);v=v+1|0;}while((v|0)<4);l=l+1|0;}while((l|0)<1024);l=c[3530626]|0;gGC(j|0,l|0,262144)|0;i=0;do{v=i<<8;gGz(l+v|0,0,256);t=i<<10;u=0;do{y=1<<3-u;w=(c[703416+(u<<2)>>2]|0)+t|0;x=0;do{B=w+(c[611904+(x<<2)>>2]|0)|0;A=(x<<4)+v|0;z=0;do{C=B+(c[612512+(z<<2)>>2]|0)|0;if(((d[j+((C|0)/8|0)|0]|0)&128>>>((C&7)>>>0)|0)!=0){C=l+(A+z)|0;a[C]=(d[C]|0|y)&255}z=z+1|0;}while((z|0)<16);x=x+1|0;}while((x|0)<16);u=u+1|0;}while((u|0)<4);i=i+1|0;}while((i|0)<2048);i=c[3530440]|0;gGC(j|0,i|0,131072)|0;l=0;do{u=l<<8;gGz(i+u|0,0,256);v=l<<10;t=0;do{x=1<<3-t;y=(c[703416+(t<<2)>>2]|0)+v|0;w=0;do{z=y+(c[611904+(w<<2)>>2]|0)|0;A=(w<<4)+u|0;B=0;do{C=z+(c[612512+(B<<2)>>2]|0)|0;if(((d[j+((C|0)/8|0)|0]|0)&128>>>((C&7)>>>0)|0)!=0){C=i+(A+B)|0;a[C]=(d[C]|0|x)&255}B=B+1|0;}while((B|0)<16);w=w+1|0;}while((w|0)<16);t=t+1|0;}while((t|0)<4);l=l+1|0;}while((l|0)<1024);l=c[3530340]|0;gGC(j|0,l|0,262144)|0;i=0;while(1){t=i<<8;gGz(l+t|0,0,256);u=i<<9;v=0;do{w=1<<3-v;x=(c[703416+(v<<2)>>2]|0)+u|0;y=0;do{B=x+(c[611840+(y<<2)>>2]|0)|0;A=(y<<4)+t|0;z=0;do{C=B+(c[610064+(z<<2)>>2]|0)|0;if(((d[j+((C|0)/8|0)|0]|0)&128>>>((C&7)>>>0)|0)!=0){C=l+(A+z)|0;a[C]=(d[C]|0|w)&255}z=z+1|0;}while((z|0)<16);y=y+1|0;}while((y|0)<16);v=v+1|0;}while((v|0)<4);v=i+1|0;if((v|0)<2048){i=v}else{D=0;break}}while(1){if((D|0)>=1024){break L25916}E=9638528+(D<<2)|0;if((c[E>>2]|0)==(j|0)){break}else{D=D+1|0}}gGr(j);c[E>>2]=0}}while(0);fxU(0,425984);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];i=c[3532592]|0;if((i|0)!=0){gGC(9104152,i|0,280)|0}c[2113054]=c[2113060]}if((f|0)==0){F=0}else{gu[f&16383]();F=c[2394]|0}i=c[14130368+(F<<2)>>2]|0;if((i|0)!=0){gGC(i|0,9104152,280)|0}c[8452240+(F<<2)>>2]=c[2113054];c[2394]=-1;fwR(0);i=c[2439330]|0;l=(i|0)==0;if(!l){v=i;gGC(9706056,v|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];v=c[3528484]|0;c[2076596]=v;t=c[2417276]|0;c[3541536]=t;c[1836236]=0;u=c[2385936]|0;y=g-1>>8;if((y|0)>=0){w=0;x=0;while(1){c[i+76+(x<<2)>>2]=u+(x<<8);z=w+1&65535;A=z&65535;if((A|0)>(y|0)){G=0;H=0;break}else{w=z;x=A}}do{x=u+(H<<8)|0;c[i+76+(H+512<<2)>>2]=x;c[i+76+(H+768<<2)>>2]=x;G=G+1&65535;H=G&65535;}while((H|0)<=(y|0))}y=c[2386090]|0;u=g>>>8;x=u&255;w=x&65535;A=u&255;u=x;z=w;while(1){c[i+76+(z<<2)>>2]=y+(z-A<<8);B=u+1&65535;if((B&65535)>255){I=x;J=w;break}else{u=B;z=B&65535}}while(1){c[i+76+(J+256<<2)>>2]=y+(J-A<<8);z=I+1&65535;if((z&65535)>255){K=x;L=w;break}else{I=z;J=z&65535}}while(1){w=y+(L-A<<8)|0;c[i+76+(L+512<<2)>>2]=w;c[i+76+(L+768<<2)>>2]=w;w=K+1&65535;if((w&65535)>255){break}else{K=w;L=w&65535}}c[i+4176>>2]=2304;c[i+4172>>2]=1290;if(!l){A=i;gGC(A|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=v;c[2417276]=t;c[1836236]=-1;if(a[641808]|0){fwR(1);A=c[2439331]|0;y=(A|0)==0;if(!y){w=A;gGC(9706056,w|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];w=c[3528485]|0;c[2076596]=w;x=c[2417277]|0;c[3541536]=x;c[1836236]=1;z=c[3529172]|0;u=0;B=0;while(1){c[A+76+(B<<2)>>2]=z+(B<<8);C=u+1&65535;if((C&65535)>63){M=0;N=0;break}else{u=C;B=C&65535}}while(1){B=z+(N<<8)|0;c[A+76+(N+512<<2)>>2]=B;c[A+76+(N+768<<2)>>2]=B;B=M+1&65535;if((B&65535)>63){break}else{M=B;N=B&65535}}z=c[2386090]|0;c[A+588>>2]=z;B=z+256|0;c[A+592>>2]=B;u=z+512|0;c[A+596>>2]=u;t=z+768|0;c[A+600>>2]=t;v=z+1024|0;c[A+604>>2]=v;i=z+1280|0;c[A+608>>2]=i;l=z+1536|0;c[A+612>>2]=l;C=z+1792|0;c[A+616>>2]=C;c[A+1612>>2]=z;c[A+1616>>2]=B;c[A+1620>>2]=u;c[A+1624>>2]=t;c[A+1628>>2]=v;c[A+1632>>2]=i;c[A+1636>>2]=l;c[A+1640>>2]=C;c[A+2636>>2]=z;c[A+3660>>2]=z;c[A+2640>>2]=B;c[A+3664>>2]=B;c[A+2644>>2]=u;c[A+3668>>2]=u;c[A+2648>>2]=t;c[A+3672>>2]=t;c[A+2652>>2]=v;c[A+3676>>2]=v;c[A+2656>>2]=i;c[A+3680>>2]=i;c[A+2660>>2]=l;c[A+3684>>2]=l;c[A+2664>>2]=C;c[A+3688>>2]=C;c[A+4184>>2]=1154;c[A+4180>>2]=1852;c[A+4176>>2]=1624;c[A+4172>>2]=510;if(!y){C=A;gGC(C|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=w;c[2417277]=x;c[1836236]=-1}UL(4e6,0,132,0);c[2438224]=4e6;c[2433522]=3416;c[2406672]=1752;c[3528468]=9362;c[2443842]=511;h[745398]=.5;a[3203264]=1;c[2405758]=1;gGz(9542544,0,32);c[2385641]=1;h[1192819]=1.0;c[2385642]=3;c[2385643]=2060;C=0;do{l=C*257|0;b[9732544+(C<<1)>>1]=((l|0)/2|0)&65535;b[9753784+(C<<1)>>1]=l+32768&65535;C=C+1|0;}while((C|0)<256);c[3528842]=1;c[2405758]=2;gGz(9542576,0,32);c[2385649]=1;h[1192823]=1.0;c[2385650]=3;c[2385651]=2060;C=0;do{x=C*257|0;b[9732544+(C<<1)>>1]=((x|0)/2|0)&65535;b[9753784+(C<<1)>>1]=x+32768&65535;C=C+1|0;}while((C|0)<256);c[3528842]=1;h[1192819]=.4;c[2385642]=3;h[1192823]=.4;c[2385650]=3;C=c[642608+(c[2436]<<2)>>2]|0;x=c[C+128>>2]|0;if((c[C+52>>2]&4|0)==0){c[2113068]=x;w=c[C+132>>2]|0;c[2113070]=w;c[2443814]=x;c[2440436]=w;O=x;P=w}else{c[2113070]=x;w=c[C+132>>2]|0;c[2113068]=w;c[2440436]=x;c[2443814]=w;O=w;P=x}x=ag(O<<1,P)|0;w=gGq(x)|0;c[2112926]=w;if((w|0)!=0){gGz(w|0,0,x|0)}x=(c[2113068]|0)==320;c[2406614]=x?96:112;c[2406610]=x?8:16;dQg();r=0;return r|0}}while(0);c[2414992]=0;r=1;return r|0}function dQc(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;a=i;i=i+1080|0;b=a|0;d=a+112|0;e=a+120|0;f=a+232|0;g=a+240|0;h=a+352|0;j=a+360|0;k=a+472|0;l=a+480|0;m=a+592|0;n=a+600|0;o=a+712|0;p=a+720|0;q=a+832|0;r=a+840|0;s=a+952|0;t=a+960|0;u=a+1072|0;if((R6((c[2388170]|0)+1|0,0,2)|0)!=0){v=1;i=a;return v|0}if((R6(c[2388170]|0,1,2)|0)!=0){v=1;i=a;return v|0}if((R6((c[2388170]|0)+131073|0,2,2)|0)!=0){v=1;i=a;return v|0}if((R6((c[2388170]|0)+131072|0,3,2)|0)!=0){v=1;i=a;return v|0}if((R6((c[2388170]|0)+262145|0,4,2)|0)!=0){v=1;i=a;return v|0}if((R6((c[2388170]|0)+262144|0,5,2)|0)!=0){v=1;i=a;return v|0}w=c[2385936]|0;if((c[3542200]|0)==0){v=1;i=a;return v|0}x=t+108|0;c[x>>2]=0;y=t+100|0;c[y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,6)|0;do{if((c[x>>2]|0)!=0){t=c[y>>2]|0;c[u>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](u,6,0)|0;if((t|0)<1){v=1;i=a;return v|0}if((gzL(w,0,6)|0)==0){break}else{v=1}i=a;return v|0}}while(0);w=c[3529172]|0;if((c[3542200]|0)==0){v=1;i=a;return v|0}u=r+108|0;c[u>>2]=0;y=r+100|0;c[y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,7)|0;do{if((c[u>>2]|0)!=0){r=c[y>>2]|0;c[s>>2]=9534384;x=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[x&16383](s,7,0)|0;if((r|0)<1){v=1;i=a;return v|0}if((gzL(w,0,7)|0)==0){break}else{v=1}i=a;return v|0}}while(0);w=c[3530862]|0;if((c[3542200]|0)==0){v=1;i=a;return v|0}s=p+108|0;c[s>>2]=0;y=p+100|0;c[y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,8)|0;do{if((c[s>>2]|0)!=0){p=c[y>>2]|0;c[q>>2]=9534384;u=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[u&16383](q,8,0)|0;if((p|0)<1){v=1;i=a;return v|0}if((gzL(w,0,8)|0)==0){break}else{v=1}i=a;return v|0}}while(0);w=c[3530626]|0;if((c[3542200]|0)==0){v=1;i=a;return v|0}q=n+108|0;c[q>>2]=0;y=n+100|0;c[y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,9)|0;do{if((c[q>>2]|0)!=0){n=c[y>>2]|0;c[o>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](o,9,0)|0;if((n|0)<1){v=1;i=a;return v|0}if((gzL(w,0,9)|0)==0){break}else{v=1}i=a;return v|0}}while(0);w=(c[3530626]|0)+65536|0;if((c[3542200]|0)==0){v=1;i=a;return v|0}o=l+108|0;c[o>>2]=0;y=l+100|0;c[y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,10)|0;do{if((c[o>>2]|0)!=0){l=c[y>>2]|0;c[m>>2]=9534384;q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[q&16383](m,10,0)|0;if((l|0)<1){v=1;i=a;return v|0}if((gzL(w,0,10)|0)==0){break}else{v=1}i=a;return v|0}}while(0);w=c[3530440]|0;if((c[3542200]|0)==0){v=1;i=a;return v|0}m=j+108|0;c[m>>2]=0;y=j+100|0;c[y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,11)|0;do{if((c[m>>2]|0)!=0){j=c[y>>2]|0;c[k>>2]=9534384;o=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[o&16383](k,11,0)|0;if((j|0)<1){v=1;i=a;return v|0}if((gzL(w,0,11)|0)==0){break}else{v=1}i=a;return v|0}}while(0);w=(c[3530440]|0)+65536|0;if((c[3542200]|0)==0){v=1;i=a;return v|0}k=g+108|0;c[k>>2]=0;y=g+100|0;c[y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,12)|0;do{if((c[k>>2]|0)!=0){g=c[y>>2]|0;c[h>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](h,12,0)|0;if((g|0)<1){v=1;i=a;return v|0}if((gzL(w,0,12)|0)==0){break}else{v=1}i=a;return v|0}}while(0);w=c[3530340]|0;if((c[3542200]|0)==0){v=1;i=a;return v|0}h=e+108|0;c[h>>2]=0;y=e+100|0;c[y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,13)|0;do{if((c[h>>2]|0)!=0){e=c[y>>2]|0;c[f>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](f,13,0)|0;if((e|0)<1){v=1;i=a;return v|0}if((gzL(w,0,13)|0)==0){break}else{v=1}i=a;return v|0}}while(0);w=(c[3530340]|0)+131072|0;if((c[3542200]|0)==0){v=1;i=a;return v|0}f=b+108|0;c[f>>2]=0;y=b+100|0;c[y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](b,14)|0;if((c[f>>2]|0)==0){v=0;i=a;return v|0}f=c[y>>2]|0;c[d>>2]=9534384;gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](d,14,0)|0;if((f|0)<1){v=1;i=a;return v|0}v=(gzL(w,0,14)|0)!=0|0;i=a;return v|0}function dQd(){var a=0,b=0,d=0,e=0,f=0;a=c[2388170]|0;b=c[2112932]|0;d=b|0;e=0;while(1){f=a+e|0;c[d>>2]=f;c[d+131072>>2]=f;f=e+1024|0;if(f>>>0>393215){break}else{d=d+4|0;e=f}}e=c[2386476]|0;c[b+1536>>2]=e;c[b+67072>>2]=e;c[b+132608>>2]=e;d=e+1024|0;c[b+1540>>2]=d;c[b+67076>>2]=d;c[b+132612>>2]=d;d=e+2048|0;c[b+1544>>2]=d;c[b+67080>>2]=d;c[b+132616>>2]=d;d=e+3072|0;c[b+1548>>2]=d;c[b+67084>>2]=d;c[b+132620>>2]=d;d=c[3531170]|0;c[b+1552>>2]=d;c[b+67088>>2]=d;c[b+132624>>2]=d;e=d+1024|0;c[b+1556>>2]=e;c[b+67092>>2]=e;c[b+132628>>2]=e;e=d+2048|0;c[b+1560>>2]=e;c[b+67096>>2]=e;c[b+132632>>2]=e;e=d+3072|0;c[b+1564>>2]=e;c[b+67100>>2]=e;c[b+132636>>2]=e;e=d+4096|0;c[b+1568>>2]=e;c[b+67104>>2]=e;c[b+132640>>2]=e;e=d+5120|0;c[b+1572>>2]=e;c[b+67108>>2]=e;c[b+132644>>2]=e;e=d+6144|0;c[b+1576>>2]=e;c[b+67112>>2]=e;c[b+132648>>2]=e;e=d+7168|0;c[b+1580>>2]=e;c[b+67116>>2]=e;c[b+132652>>2]=e;e=d+8192|0;c[b+1584>>2]=e;c[b+67120>>2]=e;c[b+132656>>2]=e;e=d+9216|0;c[b+1588>>2]=e;c[b+67124>>2]=e;c[b+132660>>2]=e;e=d+10240|0;c[b+1592>>2]=e;c[b+67128>>2]=e;c[b+132664>>2]=e;e=d+11264|0;c[b+1596>>2]=e;c[b+67132>>2]=e;c[b+132668>>2]=e;e=c[2387220]|0;c[b+1600>>2]=e;c[b+67136>>2]=e;c[b+132672>>2]=e;d=e+1024|0;c[b+1604>>2]=d;c[b+67140>>2]=d;c[b+132676>>2]=d;d=e+2048|0;c[b+1608>>2]=d;c[b+67144>>2]=d;c[b+132680>>2]=d;d=e+3072|0;c[b+1612>>2]=d;c[b+67148>>2]=d;c[b+132684>>2]=d;d=c[2405800]|0;c[b+1664>>2]=d;c[b+67200>>2]=d;c[b+132736>>2]=d;e=d+1024|0;c[b+1668>>2]=e;c[b+67204>>2]=e;c[b+132740>>2]=e;e=d+2048|0;c[b+1672>>2]=e;c[b+67208>>2]=e;c[b+132744>>2]=e;e=d+3072|0;c[b+1676>>2]=e;c[b+67212>>2]=e;c[b+132748>>2]=e;e=d+4096|0;c[b+1680>>2]=e;c[b+67216>>2]=e;c[b+132752>>2]=e;e=d+5120|0;c[b+1684>>2]=e;c[b+67220>>2]=e;c[b+132756>>2]=e;e=d+6144|0;c[b+1688>>2]=e;c[b+67224>>2]=e;c[b+132760>>2]=e;e=d+7168|0;c[b+1692>>2]=e;c[b+67228>>2]=e;c[b+132764>>2]=e;e=c[3531148]|0;c[b+1696>>2]=e;c[b+67232>>2]=e;c[b+132768>>2]=e;d=e+1024|0;c[b+1700>>2]=d;c[b+67236>>2]=d;c[b+132772>>2]=d;d=e+2048|0;c[b+1704>>2]=d;c[b+67240>>2]=d;c[b+132776>>2]=d;d=c[3531134]|0;c[b+1728>>2]=d;c[b+67264>>2]=d;c[b+132800>>2]=d;e=d+1024|0;c[b+1732>>2]=e;c[b+67268>>2]=e;c[b+132804>>2]=e;e=d+2048|0;c[b+1736>>2]=e;c[b+67272>>2]=e;c[b+132808>>2]=e;e=c[2406494]|0;c[b+1792>>2]=e;c[b+67328>>2]=e;c[b+132864>>2]=e;d=e+1024|0;c[b+1796>>2]=d;c[b+67332>>2]=d;c[b+132868>>2]=d;d=e+2048|0;c[b+1800>>2]=d;c[b+67336>>2]=d;c[b+132872>>2]=d;d=e+3072|0;c[b+1804>>2]=d;c[b+67340>>2]=d;c[b+132876>>2]=d;d=c[2406574]|0;c[b+1856>>2]=d;c[b+67392>>2]=d;c[b+132928>>2]=d;e=d+1024|0;c[b+1860>>2]=e;c[b+67396>>2]=e;c[b+132932>>2]=e;e=d+2048|0;c[b+1864>>2]=e;c[b+67400>>2]=e;c[b+132936>>2]=e;e=d+3072|0;c[b+1868>>2]=e;c[b+67404>>2]=e;c[b+132940>>2]=e;c[b+196728>>2]=844;c[b+196648>>2]=600;c[b+196688>>2]=846;return}function dQe(a){a=a|0;var b=0,d=0;b=(c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,4e6,0)|0;return a|0}function dQf(){return~~((a[9688]|0?534.0:0.0)*(+((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)/(4.0e6/(+(c[2424]|0)/100.0))))|0}function dQg(){var d=0,e=0,f=0,g=0,i=0,j=0;a[9624376]=0;d=c[2414696]|0;gGz(d|0,0,(c[2411710]|0)-d|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=i;c[1836236]=-1;if(a[641808]|0){i=c[2439331]|0;g=(i|0)==0;if(!g){f=i;gGC(9706056,f|0,76)|0}f=c[2438119]|0;c[2433530]=f;e=c[3528485]|0;c[2076596]=e;d=c[2417277]|0;c[3541536]=d;c[1836236]=1;gGz(9706056,0,76);if(!g){g=i;gGC(g|0,9706056,76)|0}c[2438119]=f;c[3528485]=e;c[2417277]=d;c[1836236]=-1}c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;lw(c[3540984]|0);d=c[2405758]|0;if((d|0)>0){j=0}else{return}do{c[9542560+(j<<5)>>2]=0;b[9542544+(j<<5)>>1]=0;j=j+1|0;}while((j|0)<(d|0));return}function dQh(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;a=i;i=i+960|0;b=a|0;d=a+112|0;e=a+120|0;f=a+232|0;g=a+240|0;h=a+352|0;j=a+360|0;k=a+472|0;l=a+480|0;m=a+592|0;n=a+600|0;o=a+712|0;p=a+720|0;q=a+832|0;r=a+840|0;s=a+952|0;if((R6((c[2388170]|0)+1|0,0,2)|0)!=0){t=1;i=a;return t|0}if((R6(c[2388170]|0,1,2)|0)!=0){t=1;i=a;return t|0}if((R6((c[2388170]|0)+131073|0,2,2)|0)!=0){t=1;i=a;return t|0}if((R6((c[2388170]|0)+131072|0,3,2)|0)!=0){t=1;i=a;return t|0}if((R6((c[2388170]|0)+262145|0,4,2)|0)!=0){t=1;i=a;return t|0}if((R6((c[2388170]|0)+262144|0,5,2)|0)!=0){t=1;i=a;return t|0}u=c[2385936]|0;if((c[3542200]|0)==0){t=1;i=a;return t|0}v=r+108|0;c[v>>2]=0;w=r+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,6)|0;do{if((c[v>>2]|0)!=0){r=c[w>>2]|0;c[s>>2]=9534384;x=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[x&16383](s,6,0)|0;if((r|0)<1){t=1;i=a;return t|0}if((gzL(u,0,6)|0)==0){break}else{t=1}i=a;return t|0}}while(0);u=c[3530862]|0;if((c[3542200]|0)==0){t=1;i=a;return t|0}s=p+108|0;c[s>>2]=0;w=p+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,7)|0;do{if((c[s>>2]|0)!=0){p=c[w>>2]|0;c[q>>2]=9534384;v=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[v&16383](q,7,0)|0;if((p|0)<1){t=1;i=a;return t|0}if((gzL(u,0,7)|0)==0){break}else{t=1}i=a;return t|0}}while(0);u=c[3530626]|0;if((c[3542200]|0)==0){t=1;i=a;return t|0}q=n+108|0;c[q>>2]=0;w=n+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,8)|0;do{if((c[q>>2]|0)!=0){n=c[w>>2]|0;c[o>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](o,8,0)|0;if((n|0)<1){t=1;i=a;return t|0}if((gzL(u,0,8)|0)==0){break}else{t=1}i=a;return t|0}}while(0);u=(c[3530626]|0)+65536|0;if((c[3542200]|0)==0){t=1;i=a;return t|0}o=l+108|0;c[o>>2]=0;w=l+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,9)|0;do{if((c[o>>2]|0)!=0){l=c[w>>2]|0;c[m>>2]=9534384;q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[q&16383](m,9,0)|0;if((l|0)<1){t=1;i=a;return t|0}if((gzL(u,0,9)|0)==0){break}else{t=1}i=a;return t|0}}while(0);u=c[3530440]|0;if((c[3542200]|0)==0){t=1;i=a;return t|0}m=j+108|0;c[m>>2]=0;w=j+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,10)|0;do{if((c[m>>2]|0)!=0){j=c[w>>2]|0;c[k>>2]=9534384;o=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[o&16383](k,10,0)|0;if((j|0)<1){t=1;i=a;return t|0}if((gzL(u,0,10)|0)==0){break}else{t=1}i=a;return t|0}}while(0);u=(c[3530440]|0)+65536|0;if((c[3542200]|0)==0){t=1;i=a;return t|0}k=g+108|0;c[k>>2]=0;w=g+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,11)|0;do{if((c[k>>2]|0)!=0){g=c[w>>2]|0;c[h>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](h,11,0)|0;if((g|0)<1){t=1;i=a;return t|0}if((gzL(u,0,11)|0)==0){break}else{t=1}i=a;return t|0}}while(0);u=c[3530340]|0;if((c[3542200]|0)==0){t=1;i=a;return t|0}h=e+108|0;c[h>>2]=0;w=e+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,12)|0;do{if((c[h>>2]|0)!=0){e=c[w>>2]|0;c[f>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](f,12,0)|0;if((e|0)<1){t=1;i=a;return t|0}if((gzL(u,0,12)|0)==0){break}else{t=1}i=a;return t|0}}while(0);u=(c[3530340]|0)+131072|0;if((c[3542200]|0)==0){t=1;i=a;return t|0}f=b+108|0;c[f>>2]=0;w=b+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](b,13)|0;if((c[f>>2]|0)==0){t=0;i=a;return t|0}f=c[w>>2]|0;c[d>>2]=9534384;gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](d,13,0)|0;if((f|0)<1){t=1;i=a;return t|0}t=(gzL(u,0,13)|0)!=0|0;i=a;return t|0}function dQi(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;a=i;i=i+960|0;b=a|0;d=a+112|0;e=a+120|0;f=a+232|0;g=a+240|0;h=a+352|0;j=a+360|0;k=a+472|0;l=a+480|0;m=a+592|0;n=a+600|0;o=a+712|0;p=a+720|0;q=a+832|0;r=a+840|0;s=a+952|0;if((R6((c[2388170]|0)+1|0,0,2)|0)!=0){t=1;i=a;return t|0}if((R6(c[2388170]|0,1,2)|0)!=0){t=1;i=a;return t|0}if((R6((c[2388170]|0)+131073|0,2,2)|0)!=0){t=1;i=a;return t|0}if((R6((c[2388170]|0)+131072|0,3,2)|0)!=0){t=1;i=a;return t|0}u=c[2385936]|0;if((c[3542200]|0)==0){t=1;i=a;return t|0}v=r+108|0;c[v>>2]=0;w=r+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,4)|0;do{if((c[v>>2]|0)!=0){r=c[w>>2]|0;c[s>>2]=9534384;x=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[x&16383](s,4,0)|0;if((r|0)<1){t=1;i=a;return t|0}if((gzL(u,0,4)|0)==0){break}else{t=1}i=a;return t|0}}while(0);u=(c[2385936]|0)+16384|0;if((c[3542200]|0)==0){t=1;i=a;return t|0}s=p+108|0;c[s>>2]=0;w=p+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,11)|0;do{if((c[s>>2]|0)!=0){p=c[w>>2]|0;c[q>>2]=9534384;v=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[v&16383](q,11,0)|0;if((p|0)<1){t=1;i=a;return t|0}if((gzL(u,0,11)|0)==0){break}else{t=1}i=a;return t|0}}while(0);u=c[3530862]|0;if((c[3542200]|0)==0){t=1;i=a;return t|0}q=n+108|0;c[q>>2]=0;w=n+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,5)|0;do{if((c[q>>2]|0)!=0){n=c[w>>2]|0;c[o>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](o,5,0)|0;if((n|0)<1){t=1;i=a;return t|0}if((gzL(u,0,5)|0)==0){break}else{t=1}i=a;return t|0}}while(0);u=c[3530626]|0;if((c[3542200]|0)==0){t=1;i=a;return t|0}o=l+108|0;c[o>>2]=0;w=l+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,6)|0;do{if((c[o>>2]|0)!=0){l=c[w>>2]|0;c[m>>2]=9534384;q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[q&16383](m,6,0)|0;if((l|0)<1){t=1;i=a;return t|0}if((gzL(u,0,6)|0)==0){break}else{t=1}i=a;return t|0}}while(0);u=(c[3530626]|0)+98304|0;if((c[3542200]|0)==0){t=1;i=a;return t|0}m=j+108|0;c[m>>2]=0;w=j+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,7)|0;do{if((c[m>>2]|0)!=0){j=c[w>>2]|0;c[k>>2]=9534384;o=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[o&16383](k,7,0)|0;if((j|0)<1){t=1;i=a;return t|0}if((gzL(u,0,7)|0)==0){break}else{t=1}i=a;return t|0}}while(0);u=c[3530440]|0;if((c[3542200]|0)==0){t=1;i=a;return t|0}k=g+108|0;c[k>>2]=0;w=g+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,8)|0;do{if((c[k>>2]|0)!=0){g=c[w>>2]|0;c[h>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](h,8,0)|0;if((g|0)<1){t=1;i=a;return t|0}if((gzL(u,0,8)|0)==0){break}else{t=1}i=a;return t|0}}while(0);u=c[3530340]|0;if((c[3542200]|0)==0){t=1;i=a;return t|0}h=e+108|0;c[h>>2]=0;w=e+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,9)|0;do{if((c[h>>2]|0)!=0){e=c[w>>2]|0;c[f>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](f,9,0)|0;if((e|0)<1){t=1;i=a;return t|0}if((gzL(u,0,9)|0)==0){break}else{t=1}i=a;return t|0}}while(0);u=(c[3530340]|0)+131072|0;if((c[3542200]|0)==0){t=1;i=a;return t|0}f=b+108|0;c[f>>2]=0;w=b+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](b,10)|0;if((c[f>>2]|0)==0){t=0;i=a;return t|0}f=c[w>>2]|0;c[d>>2]=9534384;gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](d,10,0)|0;if((f|0)<1){t=1;i=a;return t|0}t=(gzL(u,0,10)|0)!=0|0;i=a;return t|0}function dQj(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;a=i;i=i+960|0;b=a|0;d=a+112|0;e=a+120|0;f=a+232|0;g=a+240|0;h=a+352|0;j=a+360|0;k=a+472|0;l=a+480|0;m=a+592|0;n=a+600|0;o=a+712|0;p=a+720|0;q=a+832|0;r=a+840|0;s=a+952|0;if((R6((c[2388170]|0)+1|0,0,2)|0)!=0){t=1;i=a;return t|0}if((R6(c[2388170]|0,1,2)|0)!=0){t=1;i=a;return t|0}if((R6((c[2388170]|0)+131073|0,2,2)|0)!=0){t=1;i=a;return t|0}if((R6((c[2388170]|0)+131072|0,3,2)|0)!=0){t=1;i=a;return t|0}u=c[2385936]|0;if((c[3542200]|0)==0){t=1;i=a;return t|0}v=r+108|0;c[v>>2]=0;w=r+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,4)|0;do{if((c[v>>2]|0)!=0){r=c[w>>2]|0;c[s>>2]=9534384;x=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[x&16383](s,4,0)|0;if((r|0)<1){t=1;i=a;return t|0}if((gzL(u,0,4)|0)==0){break}else{t=1}i=a;return t|0}}while(0);u=(c[2385936]|0)+16384|0;if((c[3542200]|0)==0){t=1;i=a;return t|0}s=p+108|0;c[s>>2]=0;w=p+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,12)|0;do{if((c[s>>2]|0)!=0){p=c[w>>2]|0;c[q>>2]=9534384;v=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[v&16383](q,12,0)|0;if((p|0)<1){t=1;i=a;return t|0}if((gzL(u,0,12)|0)==0){break}else{t=1}i=a;return t|0}}while(0);u=c[3530862]|0;if((c[3542200]|0)==0){t=1;i=a;return t|0}q=n+108|0;c[q>>2]=0;w=n+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,5)|0;do{if((c[q>>2]|0)!=0){n=c[w>>2]|0;c[o>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](o,5,0)|0;if((n|0)<1){t=1;i=a;return t|0}if((gzL(u,0,5)|0)==0){break}else{t=1}i=a;return t|0}}while(0);u=c[3530626]|0;if((c[3542200]|0)==0){t=1;i=a;return t|0}o=l+108|0;c[o>>2]=0;w=l+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,6)|0;do{if((c[o>>2]|0)!=0){l=c[w>>2]|0;c[m>>2]=9534384;q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[q&16383](m,6,0)|0;if((l|0)<1){t=1;i=a;return t|0}if((gzL(u,0,6)|0)==0){break}else{t=1}i=a;return t|0}}while(0);u=(c[3530626]|0)+98304|0;if((c[3542200]|0)==0){t=1;i=a;return t|0}m=j+108|0;c[m>>2]=0;w=j+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,7)|0;do{if((c[m>>2]|0)!=0){j=c[w>>2]|0;c[k>>2]=9534384;o=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[o&16383](k,7,0)|0;if((j|0)<1){t=1;i=a;return t|0}if((gzL(u,0,7)|0)==0){break}else{t=1}i=a;return t|0}}while(0);u=c[3530440]|0;if((c[3542200]|0)==0){t=1;i=a;return t|0}k=g+108|0;c[k>>2]=0;w=g+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,8)|0;do{if((c[k>>2]|0)!=0){g=c[w>>2]|0;c[h>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](h,8,0)|0;if((g|0)<1){t=1;i=a;return t|0}if((gzL(u,0,8)|0)==0){break}else{t=1}i=a;return t|0}}while(0);u=c[3530340]|0;if((c[3542200]|0)==0){t=1;i=a;return t|0}h=e+108|0;c[h>>2]=0;w=e+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,9)|0;do{if((c[h>>2]|0)!=0){e=c[w>>2]|0;c[f>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](f,9,0)|0;if((e|0)<1){t=1;i=a;return t|0}if((gzL(u,0,9)|0)==0){break}else{t=1}i=a;return t|0}}while(0);u=(c[3530340]|0)+131072|0;if((c[3542200]|0)==0){t=1;i=a;return t|0}f=b+108|0;c[f>>2]=0;w=b+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](b,10)|0;if((c[f>>2]|0)==0){t=0;i=a;return t|0}f=c[w>>2]|0;c[d>>2]=9534384;gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](d,10,0)|0;if((f|0)<1){t=1;i=a;return t|0}t=(gzL(u,0,10)|0)!=0|0;i=a;return t|0}function dQk(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;a=i;i=i+840|0;b=a|0;d=a+112|0;e=a+120|0;f=a+232|0;g=a+240|0;h=a+352|0;j=a+360|0;k=a+472|0;l=a+480|0;m=a+592|0;n=a+600|0;o=a+712|0;p=a+720|0;q=a+832|0;if((R6((c[2388170]|0)+1|0,0,2)|0)!=0){r=1;i=a;return r|0}if((R6(c[2388170]|0,1,2)|0)!=0){r=1;i=a;return r|0}if((R6((c[2388170]|0)+131073|0,2,2)|0)!=0){r=1;i=a;return r|0}if((R6((c[2388170]|0)+131072|0,3,2)|0)!=0){r=1;i=a;return r|0}if((R6((c[2388170]|0)+262145|0,4,2)|0)!=0){r=1;i=a;return r|0}if((R6((c[2388170]|0)+262144|0,5,2)|0)!=0){r=1;i=a;return r|0}s=c[2385936]|0;if((c[3542200]|0)==0){r=1;i=a;return r|0}t=p+108|0;c[t>>2]=0;u=p+100|0;c[u>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,6)|0;do{if((c[t>>2]|0)!=0){p=c[u>>2]|0;c[q>>2]=9534384;v=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[v&16383](q,6,0)|0;if((p|0)<1){r=1;i=a;return r|0}if((gzL(s,0,6)|0)==0){break}else{r=1}i=a;return r|0}}while(0);s=c[3530862]|0;if((c[3542200]|0)==0){r=1;i=a;return r|0}q=n+108|0;c[q>>2]=0;u=n+100|0;c[u>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,7)|0;do{if((c[q>>2]|0)!=0){n=c[u>>2]|0;c[o>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](o,7,0)|0;if((n|0)<1){r=1;i=a;return r|0}if((gzL(s,0,7)|0)==0){break}else{r=1}i=a;return r|0}}while(0);s=c[3530626]|0;if((c[3542200]|0)==0){r=1;i=a;return r|0}o=l+108|0;c[o>>2]=0;u=l+100|0;c[u>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,8)|0;do{if((c[o>>2]|0)!=0){l=c[u>>2]|0;c[m>>2]=9534384;q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[q&16383](m,8,0)|0;if((l|0)<1){r=1;i=a;return r|0}if((gzL(s,0,8)|0)==0){break}else{r=1}i=a;return r|0}}while(0);s=(c[3530626]|0)+131072|0;if((c[3542200]|0)==0){r=1;i=a;return r|0}m=j+108|0;c[m>>2]=0;u=j+100|0;c[u>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,9)|0;do{if((c[m>>2]|0)!=0){j=c[u>>2]|0;c[k>>2]=9534384;o=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[o&16383](k,9,0)|0;if((j|0)<1){r=1;i=a;return r|0}if((gzL(s,0,9)|0)==0){break}else{r=1}i=a;return r|0}}while(0);s=c[3530440]|0;if((c[3542200]|0)==0){r=1;i=a;return r|0}k=g+108|0;c[k>>2]=0;u=g+100|0;c[u>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,10)|0;do{if((c[k>>2]|0)!=0){g=c[u>>2]|0;c[h>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](h,10,0)|0;if((g|0)<1){r=1;i=a;return r|0}if((gzL(s,0,10)|0)==0){break}else{r=1}i=a;return r|0}}while(0);s=c[3530340]|0;if((c[3542200]|0)==0){r=1;i=a;return r|0}h=e+108|0;c[h>>2]=0;u=e+100|0;c[u>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,11)|0;do{if((c[h>>2]|0)!=0){e=c[u>>2]|0;c[f>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](f,11,0)|0;if((e|0)<1){r=1;i=a;return r|0}if((gzL(s,0,11)|0)==0){break}else{r=1}i=a;return r|0}}while(0);s=(c[3530340]|0)+131072|0;if((c[3542200]|0)==0){r=1;i=a;return r|0}f=b+108|0;c[f>>2]=0;u=b+100|0;c[u>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](b,12)|0;if((c[f>>2]|0)==0){r=0;i=a;return r|0}f=c[u>>2]|0;c[d>>2]=9534384;gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](d,12,0)|0;if((f|0)<1){r=1;i=a;return r|0}r=(gzL(s,0,12)|0)!=0|0;i=a;return r|0}function dQl(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;a=i;i=i+1320|0;b=a|0;d=a+112|0;e=a+120|0;f=a+232|0;g=a+240|0;h=a+352|0;j=a+360|0;k=a+472|0;l=a+480|0;m=a+592|0;n=a+600|0;o=a+712|0;p=a+720|0;q=a+832|0;r=a+840|0;s=a+952|0;t=a+960|0;u=a+1072|0;v=a+1080|0;w=a+1192|0;x=a+1200|0;y=a+1312|0;if((R6((c[2388170]|0)+1|0,0,2)|0)!=0){z=1;i=a;return z|0}if((R6(c[2388170]|0,1,2)|0)!=0){z=1;i=a;return z|0}if((R6((c[2388170]|0)+131073|0,2,2)|0)!=0){z=1;i=a;return z|0}if((R6((c[2388170]|0)+131072|0,3,2)|0)!=0){z=1;i=a;return z|0}if((R6((c[2388170]|0)+262145|0,4,2)|0)!=0){z=1;i=a;return z|0}if((R6((c[2388170]|0)+262144|0,5,2)|0)!=0){z=1;i=a;return z|0}A=c[2385936]|0;if((c[3542200]|0)==0){z=1;i=a;return z|0}B=x+108|0;c[B>>2]=0;C=x+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,6)|0;do{if((c[B>>2]|0)!=0){x=c[C>>2]|0;c[y>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](y,6,0)|0;if((x|0)<1){z=1;i=a;return z|0}if((gzL(A,0,6)|0)==0){break}else{z=1}i=a;return z|0}}while(0);A=(c[2385936]|0)+16384|0;if((c[3542200]|0)==0){z=1;i=a;return z|0}y=v+108|0;c[y>>2]=0;C=v+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,7)|0;do{if((c[y>>2]|0)!=0){v=c[C>>2]|0;c[w>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](w,7,0)|0;if((v|0)<1){z=1;i=a;return z|0}if((gzL(A,0,7)|0)==0){break}else{z=1}i=a;return z|0}}while(0);A=c[3530862]|0;if((c[3542200]|0)==0){z=1;i=a;return z|0}w=t+108|0;c[w>>2]=0;C=t+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,8)|0;do{if((c[w>>2]|0)!=0){t=c[C>>2]|0;c[u>>2]=9534384;y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[y&16383](u,8,0)|0;if((t|0)<1){z=1;i=a;return z|0}if((gzL(A,0,8)|0)==0){break}else{z=1}i=a;return z|0}}while(0);A=c[3530626]|0;if((c[3542200]|0)==0){z=1;i=a;return z|0}u=r+108|0;c[u>>2]=0;C=r+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,9)|0;do{if((c[u>>2]|0)!=0){r=c[C>>2]|0;c[s>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](s,9,0)|0;if((r|0)<1){z=1;i=a;return z|0}if((gzL(A,0,9)|0)==0){break}else{z=1}i=a;return z|0}}while(0);A=(c[3530626]|0)+65536|0;if((c[3542200]|0)==0){z=1;i=a;return z|0}s=p+108|0;c[s>>2]=0;C=p+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,10)|0;do{if((c[s>>2]|0)!=0){p=c[C>>2]|0;c[q>>2]=9534384;u=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[u&16383](q,10,0)|0;if((p|0)<1){z=1;i=a;return z|0}if((gzL(A,0,10)|0)==0){break}else{z=1}i=a;return z|0}}while(0);A=c[3530440]|0;if((c[3542200]|0)==0){z=1;i=a;return z|0}q=n+108|0;c[q>>2]=0;C=n+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,11)|0;do{if((c[q>>2]|0)!=0){n=c[C>>2]|0;c[o>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](o,11,0)|0;if((n|0)<1){z=1;i=a;return z|0}if((gzL(A,0,11)|0)==0){break}else{z=1}i=a;return z|0}}while(0);A=(c[3530440]|0)+65536|0;if((c[3542200]|0)==0){z=1;i=a;return z|0}o=l+108|0;c[o>>2]=0;C=l+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,12)|0;do{if((c[o>>2]|0)!=0){l=c[C>>2]|0;c[m>>2]=9534384;q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[q&16383](m,12,0)|0;if((l|0)<1){z=1;i=a;return z|0}if((gzL(A,0,12)|0)==0){break}else{z=1}i=a;return z|0}}while(0);A=c[3530340]|0;if((c[3542200]|0)==0){z=1;i=a;return z|0}m=j+108|0;c[m>>2]=0;C=j+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,13)|0;do{if((c[m>>2]|0)!=0){j=c[C>>2]|0;c[k>>2]=9534384;o=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[o&16383](k,13,0)|0;if((j|0)<1){z=1;i=a;return z|0}if((gzL(A,0,13)|0)==0){break}else{z=1}i=a;return z|0}}while(0);A=(c[3530340]|0)+65536|0;if((c[3542200]|0)==0){z=1;i=a;return z|0}k=g+108|0;c[k>>2]=0;C=g+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,14)|0;do{if((c[k>>2]|0)!=0){g=c[C>>2]|0;c[h>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](h,14,0)|0;if((g|0)<1){z=1;i=a;return z|0}if((gzL(A,0,14)|0)==0){break}else{z=1}i=a;return z|0}}while(0);A=(c[3530340]|0)+131072|0;if((c[3542200]|0)==0){z=1;i=a;return z|0}h=e+108|0;c[h>>2]=0;C=e+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,15)|0;do{if((c[h>>2]|0)!=0){e=c[C>>2]|0;c[f>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](f,15,0)|0;if((e|0)<1){z=1;i=a;return z|0}if((gzL(A,0,15)|0)==0){break}else{z=1}i=a;return z|0}}while(0);A=(c[3530340]|0)+196608|0;if((c[3542200]|0)==0){z=1;i=a;return z|0}f=b+108|0;c[f>>2]=0;C=b+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](b,16)|0;if((c[f>>2]|0)==0){z=0;i=a;return z|0}f=c[C>>2]|0;c[d>>2]=9534384;gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](d,16,0)|0;if((f|0)<1){z=1;i=a;return z|0}z=(gzL(A,0,16)|0)!=0|0;i=a;return z|0}function dQm(b,d,f,g,h,i){b=b|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;j=b;b=c[2406610]|0;k=c[2406614]|0;l=c[3528712]|0;m=c[2112926]|0;n=c[2113070]|0;o=0;do{p=(o<<4&496)-g-b|0;q=(o>>5<<4)-f-k|0;r=(p|0)<-15?p+512|0:p;p=(q|0)<-15?q+1024|0:q;do{if((r|0)<(n|0)){q=c[2113068]|0;if((p|0)>=(q|0)){break}s=e[j+(o<<1)>>1]|0;t=s&i;u=s>>>11;if((a[l]|0)==0){SH(m,t,p,r,u,4,15,h,d);break}else{SN(m,t,-16-p+q|0,n-16-r|0,u,4,15,h,d);break}}}while(0);o=o+1|0;}while((o|0)<2048);return}function dQn(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;f=c[2405800]|0;g=c[2443738]|0;h=c[2406614]|0;i=c[2406610]|0;j=(g|0)==1;k=c[3528712]|0;l=c[2112926]|0;m=c[3530862]|0;if((d|0)==0){d=0;do{n=d&63;o=d>>6;if((g|0)==6|(g|0)==3){p=d<<5&992|o|n>>>5<<11;q=1024}else if((g|0)==1){p=n<<5|o;q=2048}else{p=(o<<5|d&31|n>>>5<<11)^992;q=1024}r=(n<<3)-h|0;n=(o<<3)-i|0;o=j?r:r+128|0;do{if(!((o|0)<-7|(n|0)<-7)){r=c[2113068]|0;if((o|0)>=(r|0)){break}s=c[2113070]|0;if((n|0)>=(s|0)){break}t=e[f+(p+q<<1)>>1]|0;u=t&255;v=b[f+(p<<1)>>1]&255|t<<8&768;if((a[k]|0)==0){Sj(l,v,o,n,u>>>4,4,0,m);break}else{Sp(l,v,-8-o+r|0,-8-n+s|0,u>>>4,4,0,m);break}}}while(0);d=d+1|0;}while((d|0)<2048);return}else{d=0;do{p=d&63;q=d>>6;if((g|0)==6|(g|0)==3){w=d<<5&992|q|p>>>5<<11;x=1024}else if((g|0)==1){w=p<<5|q;x=2048}else{w=(q<<5|d&31|p>>>5<<11)^992;x=1024}n=(p<<3)-h|0;p=(q<<3)-i|0;q=j?n:n+128|0;do{if(!((q|0)<-7|(p|0)<-7)){n=c[2113068]|0;if((q|0)>=(n|0)){break}o=c[2113070]|0;if((p|0)>=(o|0)){break}u=e[f+(w+x<<1)>>1]|0;s=u&255;r=b[f+(w<<1)>>1]&255|u<<8&768;if((a[k]|0)==0){Sr(l,r,q,p,s>>>4,4,15,0,m);break}else{Sx(l,r,-8-q+n|0,-8-p+o|0,s>>>4,4,15,0,m);break}}}while(0);d=d+1|0;}while((d|0)<2048);return}}function dQo(b){b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;d=c[2386572]|0;f=c[2443738]|0;if((f|0)==5|(f|0)==0){g=512}else{g=2048}f=a[6995848]|0?368:240;h=c[3528712]|0;i=c[2406610]|0;j=c[2406614]|0;k=c[2112926]|0;l=c[3530340]|0;m=0;do{n=e[d+(m<<1)>>1]|0;do{if((n>>>12&3|0)==(b|0)){o=e[d+((m|1)<<1)>>1]|0;p=o&8192;q=o&4096;r=(e[d+((m|2)<<1)>>1]|0)>>>8&31;s=e[d+((m|3)<<1)>>1]|0;t=f-(n&511)|0;u=o&4095;if((a[h]|0)==0){v=t;w=s;x=q;y=p}else{v=241-t|0;w=496-s|0;x=q>>>12^1;y=p>>>13^1}p=v-i|0;q=w-j|0;if(!((p|0)>-16&(q|0)>-16&(q|0)<(c[2113068]|0)&(p|0)<(c[2113070]|0))){break}s=(y|0)!=0;if((x|0)==0){if(s){SJ(k,u,q,p,r,4,15,512,l);break}else{SH(k,u,q,p,r,4,15,512,l);break}}else{if(s){SN(k,u,q,p,r,4,15,512,l);break}else{SL(k,u,q,p,r,4,15,512,l);break}}}}while(0);m=m+4|0;}while((m|0)<(g|0));return}function dQp(){var a=0,b=0,d=0,e=0,f=0;a=c[2388170]|0;b=c[2112932]|0;d=b|0;e=0;while(1){f=a+e|0;c[d>>2]=f;c[d+131072>>2]=f;f=e+1024|0;if(f>>>0>393215){break}else{d=d+4|0;e=f}}e=c[2386476]|0;c[b+1536>>2]=e;c[b+67072>>2]=e;c[b+132608>>2]=e;d=e+1024|0;c[b+1540>>2]=d;c[b+67076>>2]=d;c[b+132612>>2]=d;d=e+2048|0;c[b+1544>>2]=d;c[b+67080>>2]=d;c[b+132616>>2]=d;d=e+3072|0;c[b+1548>>2]=d;c[b+67084>>2]=d;c[b+132620>>2]=d;d=c[3531170]|0;e=b+1552|0;a=397312;while(1){f=d+(a-397312)|0;c[e>>2]=f;c[e+65536>>2]=f;c[e+131072>>2]=f;f=a+1024|0;if(f>>>0>417791){break}else{e=e+4|0;a=f}}a=c[2406574]|0;c[b+1632>>2]=a;c[b+67168>>2]=a;c[b+132704>>2]=a;e=a+1024|0;c[b+1636>>2]=e;c[b+67172>>2]=e;c[b+132708>>2]=e;e=a+2048|0;c[b+1640>>2]=e;c[b+67176>>2]=e;c[b+132712>>2]=e;e=a+3072|0;c[b+1644>>2]=e;c[b+67180>>2]=e;c[b+132716>>2]=e;e=c[2406494]|0;c[b+1648>>2]=e;c[b+67184>>2]=e;c[b+132720>>2]=e;a=e+1024|0;c[b+1652>>2]=a;c[b+67188>>2]=a;c[b+132724>>2]=a;a=e+2048|0;c[b+1656>>2]=a;c[b+67192>>2]=a;c[b+132728>>2]=a;a=e+3072|0;c[b+1660>>2]=a;c[b+67196>>2]=a;c[b+132732>>2]=a;a=c[2405800]|0;c[b+1664>>2]=a;c[b+67200>>2]=a;c[b+132736>>2]=a;e=a+1024|0;c[b+1668>>2]=e;c[b+67204>>2]=e;c[b+132740>>2]=e;e=a+2048|0;c[b+1672>>2]=e;c[b+67208>>2]=e;c[b+132744>>2]=e;e=a+3072|0;c[b+1676>>2]=e;c[b+67212>>2]=e;c[b+132748>>2]=e;e=a+4096|0;c[b+1680>>2]=e;c[b+67216>>2]=e;c[b+132752>>2]=e;e=a+5120|0;c[b+1684>>2]=e;c[b+67220>>2]=e;c[b+132756>>2]=e;e=a+6144|0;c[b+1688>>2]=e;c[b+67224>>2]=e;c[b+132760>>2]=e;e=a+7168|0;c[b+1692>>2]=e;c[b+67228>>2]=e;c[b+132764>>2]=e;e=c[2387220]|0;c[b+1696>>2]=e;c[b+67232>>2]=e;c[b+132768>>2]=e;a=e+1024|0;c[b+1700>>2]=a;c[b+67236>>2]=a;c[b+132772>>2]=a;a=e+2048|0;c[b+1704>>2]=a;c[b+67240>>2]=a;c[b+132776>>2]=a;a=e+3072|0;c[b+1708>>2]=a;c[b+67244>>2]=a;c[b+132780>>2]=a;a=c[3531148]|0;c[b+1712>>2]=a;c[b+67248>>2]=a;c[b+132784>>2]=a;e=a+1024|0;c[b+1716>>2]=e;c[b+67252>>2]=e;c[b+132788>>2]=e;e=a+2048|0;c[b+1720>>2]=e;c[b+67256>>2]=e;c[b+132792>>2]=e;e=a+3072|0;c[b+1724>>2]=e;c[b+67260>>2]=e;c[b+132796>>2]=e;e=c[3531134]|0;c[b+1728>>2]=e;c[b+67264>>2]=e;c[b+132800>>2]=e;a=e+1024|0;c[b+1732>>2]=a;c[b+67268>>2]=a;c[b+132804>>2]=a;c[b+196728>>2]=1886;return}function dQq(e){e=e|0;var f=0,g=0,h=0,i=0;f=e&65535;if((f|0)==20480){if((c[2385628]|0)!=1){e=(a[9633754]|0)!=0|0;g=(a[9633755]|0)==0?e:e|2;e=(a[9633756]|0)==0?g:g|4;g=(a[9633757]|0)==0?e:e|8;e=(a[9633758]|0)==0?g:g|16;g=(a[9633759]|0)==0?e:e|64;return((a[9633752]|0)==0?g:g|-128)|0}h=~(a[9633752]<<7);return h|0}else if((f|0)==22528){if((c[2385628]|0)!=1){g=(a[9631569]|0)!=0|0;e=(a[9631570]|0)==0?g:g|2;g=(a[9631571]|0)==0?e:e|4;e=(a[9631572]|0)==0?g:g|8;g=(a[9631573]|0)==0?e:e|16;e=(a[9631568]|0)==0?g:g|64;h=(a[9633753]|0)==0?e:e|-128;return h|0}e=d[9717384]|0;if((e|0)==2){i=a[9633761]<<1|a[9633760]|a[9633762]<<2|a[9633763]<<3|a[9633764]<<4|a[9633754]<<5}else if((e|0)==1){i=a[9633756]<<1|a[9633755]|a[9633757]<<2|a[9633758]<<3|a[9633759]<<4|a[9633753]<<5}else if((e|0)==4){i=a[9633766]<<1|a[9633765]|a[9633767]<<2|a[9633768]<<3|a[9633769]<<4}else if((e|0)==8){i=a[9633771]<<1|a[9633770]|a[9633772]<<2|a[9633773]<<3}else{i=0}h=~i;return h|0}else if((f|0)==18432){h=a[9699480]|0;return h|0}else if((f|0)==24576){i=(c[2440204]|0)+1|0;c[2440204]=i;e=(i|0)>768;h=((e?-8:-4)|((i|0)>512?0:2)|e&1)^1;return h|0}else if((f|0)==25600){h=(b[4853030]|0)==47?-5:0;return h|0}else{h=0;return h|0}return 0}function dQr(d,e){d=d|0;e=e|0;var f=0;f=d&65535;if((d-16384&65535)<1024){a[(c[2424760]|0)+f|0]=e;return}if((f|0)==18432){a[9541312]=e&31;return}else if((f|0)==22528){a[9717384]=e;c[2440204]=0;return}else if((f|0)==20480){a[9541304]=e&31;a[14114840]=(e&255)>>>5&1;return}else if((f|0)==10240){US(0,gD[c[2385643]&8191]()|0);b[4771272]=~~(+(b[9732544+((e&255)<<1)>>1]|0)*+h[1192819])&65535;return}else if((f|0)==26880){c[3542228]=e&15;return}else if((f|0)==26624){f=e&255;d=c[3542228]|0;if((d|0)>15){return}do{if((d|0)<14){if((d|0)!=13){if((a[14168916+d|0]|0)==e<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(0,d,f);return}else{return}}function dQs(b,d){b=b|0;d=d|0;var e=0,f=0;e=b&511;if((e|0)==0){b=d&255;f=c[3542228]|0;if((f|0)>15){return}do{if((f|0)<14){if((f|0)!=13){if((a[14168916+f|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(0,f,b);return}else if((e|0)==256){c[3542228]=d&15;return}else{return}}function dQt(a,b){a=a|0;b=b|0;return}function dQu(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4443708+(b*112|0)>>2];c[a+104>>2]=c[4443712+(b*112|0)>>2];c[a+108>>2]=c[4443716+(b*112|0)>>2];d=0;return d|0}function dQv(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=4443608+(b*112|0);e=0;return e|0}function dQw(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6929296+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dQx(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7437936+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dQy(){var b=0,d=0;c[2385628]=0;b=dQ$()|0;if((b|0)!=0){return b|0}d=c[2424760]|0;a[d+233|0]=58;a[d+1876|0]=-61;a[d+1877|0]=99;a[d+1878|0]=7;return b|0}function dQz(){var a=0,b=0,d=0,e=0,f=0;UT();fwZ();c[2113008]=0;c[2076598]=0;c[2383582]=0;a=c[2426746]|0;b=0;while(1){if((b|0)>=1024){break}d=9638528+(b<<2)|0;if((c[d>>2]|0)==(a|0)){e=20260;break}else{b=b+1|0}}if((e|0)==20260){gGr(a);c[d>>2]=0}c[2426746]=0;d=c[2385366]|0;a=0;while(1){if((a|0)>=1024){break}f=9638528+(a<<2)|0;if((c[f>>2]|0)==(d|0)){e=20264;break}else{a=a+1|0}}if((e|0)==20264){gGr(d);c[f>>2]=0}c[2385628]=0;c[2385366]=0;c[2426746]=0;c[2424780]=0;c[2424746]=0;c[2424760]=0;c[2439024]=0;c[2439023]=0;c[2439022]=0;return 0}function dQA(){var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;d=i;i=i+192|0;e=d|0;if((a[9624368]|0)==0){f=0}else{a[9717384]=0;a[9541304]=0;a[9541312]=0;a[14114840]=0;c[2440204]=0;a[9624368]=0;gGz((c[2424760]|0)+16384|0,0,49152);gGz((c[2424746]|0)+32768|0,0,16384);g=c[2439330]|0;h=(g|0)==0;if(!h){j=g;gGC(9706056,j|0,76)|0}j=c[2438118]|0;c[2433530]=j;k=c[3528484]|0;c[2076596]=k;l=c[2417276]|0;c[3541536]=l;c[1836236]=0;gGz(9706056,0,76);if(!h){h=g;gGC(h|0,9706056,76)|0}c[2438118]=j;c[3528484]=k;c[2417276]=l;c[1836236]=-1;l=c[2439331]|0;k=(l|0)==0;if(!k){j=l;gGC(9706056,j|0,76)|0}j=c[2438119]|0;c[2433530]=j;h=c[3528485]|0;c[2076596]=h;g=c[2417277]|0;c[3541536]=g;c[1836236]=1;gGz(9706056,0,76);if(!k){k=l;gGC(k|0,9706056,76)|0}c[2438119]=j;c[3528485]=h;c[2417277]=g;c[1836236]=-1;mB(0);f=0}while(1){g=f+1|0;c[e+(f<<2)>>2]=(g*100|0|0)/49|0;if((g|0)<48){f=g}else{break}}f=c[2385548]|0;if((f|0)>0){gGz(9752472,0,((f|0)>1?f<<2:4)|0)}c[2433530]=0;f=0;g=0;h=0;j=0;L26905:while(1){k=g;l=h;m=j;while(1){if((k|0)>=100){break L26905}n=c[2439330]|0;if((n|0)!=0){o=n;gGC(9706056,o|0,76)|0}b[4853030]=c[2426515]&65535;o=c[2438118]|0;c[2433530]=o;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;p=k+1|0;q=(p*41666|0|0)/100|0;r=q-l|0;do{if((r|0)<1){s=0}else{if((a[n+4188|0]|0)==0){t=gfc(r)|0;c[2433530]=(c[2433530]|0)+t;s=t;break}else{c[2433530]=o+r;s=r;break}}}while(0);u=s+l|0;if((p|0)==100){a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0}r=c[1836236]|0;o=c[9757320+(r<<2)>>2]|0;if((o|0)!=0){n=o;gGC(n|0,9706056,76)|0}c[9752472+(r<<2)>>2]=c[2433530];c[14113936+(r<<2)>>2]=c[2076596];c[9669104+(r<<2)>>2]=c[3541536];c[1836236]=-1;r=c[2439331]|0;if((r|0)!=0){n=r;gGC(9706056,n|0,76)|0}b[4853030]=c[2426515]&65535;n=c[2438119]|0;c[2433530]=n;c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;o=q-m|0;do{if((o|0)<1){v=0}else{if((a[r+4188|0]|0)==0){t=gfc(o)|0;c[2433530]=(c[2433530]|0)+t;v=t;break}else{c[2433530]=n+o;v=o;break}}}while(0);w=v+m|0;if((c[2385628]|0)==3){o=0;do{if((k|0)==(c[e+(o<<2)>>2]|0)){a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0}o=o+1|0;}while((o|0)<48)}o=c[1836236]|0;n=c[9757320+(o<<2)>>2]|0;if((n|0)!=0){r=n;gGC(r|0,9706056,76)|0}c[9752472+(o<<2)>>2]=c[2433530];c[14113936+(o<<2)>>2]=c[2076596];c[9669104+(o<<2)>>2]=c[3541536];c[1836236]=-1;x=c[2112964]|0;if((x|0)==0){k=p;l=u;m=w}else{break}}m=a[9688]|0?5:0;mF(9756088,x+(f<<1<<1)|0,m,0);f=m+f|0;g=p;h=u;j=w}w=c[2112964]|0;if((w|0)!=0){j=a[9688]|0?534:0;if((j|0)==(f|0)){y=f}else{mF(9756088,w+(f<<1<<1)|0,j-f|0,0);y=j}UR(w,y)}if((c[2112968]|0)==0){i=d;return 0}dQB()|0;i=d;return 0}function dQB(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;e=c[2424780]|0;f=c[2424760]|0;g=c[2424746]|0;h=c[2385628]|0;i=(h|0)==0;j=c[2112968]|0;k=c[2113308]|0;l=(k|0)>3;m=(k|0)==2;n=(h|0)==1;h=0;do{o=h+32768|0;p=h>>>6&255;q=h<<2&255;r=a[f+o|0]|0;s=a[g+o|0]|0;o=1;while(1){t=d[9541312]|0;do{if(i){u=r&255;v=a[e+(u>>>3&2|u&1|t<<2|t<<6&128)|0]|0;u=d[9541304]|0;w=v&255;x=s&255;y=(a[e+((x>>>3&2|x&1|u<<2|(w<<6|w<<7|u<<6)&128)+256)|0]|v)&255;z=20321}else{v=r&255;u=s&255;w=(a[e+((u>>>3&2|u&1|(v<<3|v<<7)&128|d[9541304]<<2)+256)|0]|a[e+(v>>>3&2|v&1|t<<2)|0])&255;if(!n){y=w;z=20321;break}v=(w&4|0)==0?0:16711680;u=(w&2|0)==0?v:v|65280;A=(w&1|0)==0?u:u|255}}while(0);if((z|0)==20321){z=0;t=(y&1|0)==0?0:16711680;u=(y&2|0)==0?t:t|65280;A=(y&4|0)==0?u:u|255}u=(q&255)<<8|p;do{if((a[14114840]|0)==0){t=ag(k,u^65280)|0;w=j+t|0;v=A>>>16<<8&63488|A>>>8<<3&2016;x=v|A>>>3&31;if(l){c[w>>2]=x;break}if(m){b[w>>1]=x&65535;break}else{a[w]=x&255;a[j+(t+1)|0]=v>>>8&255;a[j+(t+2)|0]=0;break}}else{t=ag(k,u^255)|0;v=j+t|0;x=A>>>16<<8&63488|A>>>8<<3&2016;w=x|A>>>3&31;if(l){c[v>>2]=w;break}if(m){b[v>>1]=w&65535;break}else{a[v]=w&255;a[j+(t+1)|0]=x>>>8&255;a[j+(t+2)|0]=0;break}}}while(0);if((o|0)>=4){break}q=q+1&255;r=(r&255)>>>1;s=(s&255)>>>1;o=o+1|0}h=h+1|0;}while((h|0)<16384);return 0}function dQC(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=i;i=i+128|0;e=d|0;f=d+32|0;g=d+48|0;h=d+64|0;j=d+80|0;k=d+96|0;l=d+112|0;m=(b|0)==0;if(!m){c[b>>2]=169249}if((a&96|0)==0){i=d;return 0}n=l;gGz(n|0,0,12);o=l|0;c[o>>2]=(c[2424760]|0)+16384;p=l+4|0;c[p>>2]=1024;q=l+12|0;c[q>>2]=288280;gj[c[2076592]&4095](l)|0;gGz(n|0,0,12);c[o>>2]=(c[2424760]|0)+32768;c[p>>2]=16384;c[q>>2]=69720;gj[c[2076592]&4095](l)|0;gGz(n|0,0,12);c[o>>2]=(c[2424746]|0)+32768;c[p>>2]=16384;c[q>>2]=68472;gj[c[2076592]&4095](l)|0;fw$(a);l=d+16|0;do{if((a&64|0)!=0){do{if(!m){if((c[b>>2]|0)>=169110){break}c[b>>2]=169110}}while(0);if((c[2113008]|0)<=0){break}q=e|0;p=e+4|0;o=e+8|0;n=e+12|0;r=0;do{cC(l|0,531144,(s=i,i=i+8|0,c[s>>2]=r,s)|0)|0;i=s;c[q>>2]=14168888+(r*252|0);c[p>>2]=252;c[o>>2]=0;c[n>>2]=l;gj[c[2076592]&4095](e)|0;r=r+1|0;}while((r|0)<(c[2113008]|0))}}while(0);gGz(k|0,0,12);c[k>>2]=14114840;c[k+4>>2]=1;c[k+12>>2]=142288;gj[c[2076592]&4095](k)|0;gGz(j|0,0,12);c[j>>2]=9541312;c[j+4>>2]=1;c[j+12>>2]=65664;gj[c[2076592]&4095](j)|0;gGz(h|0,0,12);c[h>>2]=9541304;c[h+4>>2]=1;c[h+12>>2]=589136;gj[c[2076592]&4095](h)|0;gGz(g|0,0,12);c[g>>2]=9717384;c[g+4>>2]=1;c[g+12>>2]=587624;gj[c[2076592]&4095](g)|0;gGz(f|0,0,12);c[f>>2]=9760816;c[f+4>>2]=4;c[f+12>>2]=585840;gj[c[2076592]&4095](f)|0;i=d;return 0}function dQD(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2369868+(b*112|0)>>2];c[a+104>>2]=c[2369872+(b*112|0)>>2];c[a+108>>2]=c[2369876+(b*112|0)>>2];d=0;return d|0}function dQE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=2369768+(b*112|0);e=0;return e|0}function dQF(){var b=0,d=0;c[2385628]=0;b=dQ$()|0;if((b|0)!=0){return b|0}d=c[2424760]|0;a[d+233|0]=58;a[d+261|0]=0;a[d+262|0]=0;a[d+263|0]=0;a[d+1841|0]=0;a[d+1842|0]=0;a[d+1843|0]=0;a[d+1863|0]=-61;a[d+1864|0]=86;a[d+1865|0]=7;return b|0}function dQG(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2368524+(b*112|0)>>2];c[a+104>>2]=c[2368528+(b*112|0)>>2];c[a+108>>2]=c[2368532+(b*112|0)>>2];d=0;return d|0}function dQH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=2368424+(b*112|0);e=0;return e|0}function dQI(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5716132+(b*112|0)>>2];c[a+104>>2]=c[5716136+(b*112|0)>>2];c[a+108>>2]=c[5716140+(b*112|0)>>2];d=0;return d|0}function dQJ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=5716032+(b*112|0);e=0;return e|0}function dQK(){c[2385628]=0;return dQ$()|0}function dQL(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2244948+(b*112|0)>>2];c[a+104>>2]=c[2244952+(b*112|0)>>2];c[a+108>>2]=c[2244956+(b*112|0)>>2];d=0;return d|0}function dQM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=2244848+(b*112|0);e=0;return e|0}function dQN(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=2245968+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dQO(){c[2385628]=2;return dQ$()|0}function dQP(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2202276+(b*112|0)>>2];c[a+104>>2]=c[2202280+(b*112|0)>>2];c[a+108>>2]=c[2202284+(b*112|0)>>2];d=0;return d|0}function dQQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=2202176+(b*112|0);e=0;return e|0}function dQR(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>23){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=2203296+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dQS(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2203684+(b*112|0)>>2];c[a+104>>2]=c[2203688+(b*112|0)>>2];c[a+108>>2]=c[2203692+(b*112|0)>>2];d=0;return d|0}function dQT(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=2203584+(b*112|0);e=0;return e|0}function dQU(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2250268+(b*112|0)>>2];c[a+104>>2]=c[2250272+(b*112|0)>>2];c[a+108>>2]=c[2250276+(b*112|0)>>2];d=0;return d|0}function dQV(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=2250168+(b*112|0);e=0;return e|0}function dQW(){var a=0,b=0,d=0,e=0;c[2385628]=3;a=dQ$()|0;b=c[2424746]|0;d=b+4096|0;e=b+2048|0;gGC(d|0,e|0,4096)|0;return a|0}function dQX(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2120964+(b*112|0)>>2];c[a+104>>2]=c[2120968+(b*112|0)>>2];c[a+108>>2]=c[2120972+(b*112|0)>>2];d=0;return d|0}function dQY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=2120864+(b*112|0);e=0;return e|0}function dQZ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1508056+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dQ_(){c[2385628]=1;return dQ$()|0}function dQ$(){var d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0.0;d=i;i=i+480|0;e=d|0;f=d+112|0;g=d+120|0;j=d+232|0;k=d+240|0;l=d+352|0;m=d+360|0;n=d+368|0;o=0;while(1){if((o|0)>=1024){break}p=9638528+(o<<2)|0;if((c[p>>2]|0)==0){q=20480;break}else{o=o+1|0}}do{if((q|0)==20480){o=gGq(131584)|0;c[p>>2]=o;if((o|0)==0){break}gGz(o|0,0,131584);c[2426746]=o;o=a[9688]|0?3204:0;r=0;while(1){if((r|0)>=1024){break}s=9638528+(r<<2)|0;if((c[s>>2]|0)==0){q=20485;break}else{r=r+1|0}}do{if((q|0)==20485){r=gGq(o)|0;c[s>>2]=r;if((r|0)==0){break}gGz(r|0,0,o|0);c[2385366]=r;r=c[2426746]|0;c[2424760]=r;t=r+65536|0;c[2424746]=t;u=r+131072|0;c[2424780]=u;L27155:do{if((gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](m,0,0)|0)==0){v=n+108|0;w=n+100|0;x=k+108|0;y=k+100|0;z=g+108|0;A=g+100|0;B=e+108|0;C=e+100|0;D=r;E=t;F=u;G=0;while(1){gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,G)|0;H=c[v>>2]&7;if((H|0)==3){if((c[3542200]|0)==0){I=1;q=20544;break}c[B>>2]=0;c[C>>2]=0;J=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[J&16383](e,G)|0;if((c[B>>2]|0)!=0){J=c[C>>2]|0;c[f>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](f,G,0)|0;if((J|0)<1){I=1;q=20550;break}if((gzL(F,0,G)|0)!=0){I=1;q=20542;break}}L=F+(c[w>>2]|0)|0;M=E;N=D}else if((H|0)==2){if((c[3542200]|0)==0){I=1;q=20546;break}c[z>>2]=0;c[A>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,G)|0;if((c[z>>2]|0)!=0){J=c[A>>2]|0;c[j>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](j,G,0)|0;if((J|0)<1){I=1;q=20549;break}if((gzL(E,0,G)|0)!=0){I=1;q=20547;break}}L=F;M=E+(c[w>>2]|0)|0;N=D}else if((H|0)==1){if((c[3542200]|0)==0){I=1;q=20548;break}c[x>>2]=0;c[y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,G)|0;if((c[x>>2]|0)!=0){H=c[y>>2]|0;c[l>>2]=9534384;J=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[J&16383](l,G,0)|0;if((H|0)<1){I=1;q=20553;break}if((gzL(D,0,G)|0)!=0){I=1;q=20552;break}}L=F;M=E;N=D+(c[w>>2]|0)|0}else{L=F;M=E;N=D}H=G+1|0;if((gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](m,H,0)|0)==0){D=N;E=M;F=L;G=H}else{break L27155}}if((q|0)==20542){i=d;return I|0}else if((q|0)==20544){i=d;return I|0}else if((q|0)==20546){i=d;return I|0}else if((q|0)==20547){i=d;return I|0}else if((q|0)==20548){i=d;return I|0}else if((q|0)==20549){i=d;return I|0}else if((q|0)==20550){i=d;return I|0}else if((q|0)==20552){i=d;return I|0}else if((q|0)==20553){i=d;return I|0}}}while(0);fwR(0);u=c[2439330]|0;t=(u|0)==0;if(!t){r=u;gGC(9706056,r|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];r=c[3528484]|0;c[2076596]=r;G=c[2417276]|0;c[3541536]=G;c[1836236]=0;c[u+4176>>2]=2786;c[u+4180>>2]=180;c[u+4184>>2]=3466;F=c[2424760]|0;E=0;D=0;while(1){c[u+76+(D<<2)>>2]=F+(D<<8);w=E+1&65535;if((w&65535)>63){O=0;P=0;break}else{E=w;D=w&65535}}while(1){D=F+(P<<8)|0;c[u+76+(P+512<<2)>>2]=D;c[u+76+(P+768<<2)>>2]=D;D=O+1&65535;if((D&65535)>63){break}else{O=D;P=D&65535}}c[u+332>>2]=F+16384;c[u+336>>2]=F+16640;c[u+340>>2]=F+16896;c[u+344>>2]=F+17152;D=128;E=128;while(1){c[u+76+(E<<2)>>2]=F+(E<<8);w=D+1&65535;if((w&65535)>191){Q=128;R=128;break}else{D=w;E=w&65535}}while(1){c[u+76+(R+256<<2)>>2]=F+(R<<8);E=Q+1&65535;if((E&65535)>191){break}else{Q=E;R=E&65535}}if(!t){F=u;gGC(F|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=r;c[2417276]=G;c[1836236]=-1;fwR(1);F=c[2439331]|0;E=(F|0)==0;if(!E){D=F;gGC(9706056,D|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];D=c[3528485]|0;c[2076596]=D;w=c[2417277]|0;c[3541536]=w;c[1836236]=1;c[F+4184>>2]=3466;y=c[2424746]|0;x=0;A=0;while(1){c[F+76+(A<<2)>>2]=y+(A<<8);z=x+1&65535;if((z&65535)>31){S=0;T=0;break}else{x=z;A=z&65535}}while(1){A=y+(T<<8)|0;c[F+76+(T+512<<2)>>2]=A;c[F+76+(T+768<<2)>>2]=A;A=S+1&65535;if((A&65535)>31){break}else{S=A;T=A&65535}}A=c[2424760]|0;c[F+332>>2]=A+16384;c[F+336>>2]=A+16640;c[F+340>>2]=A+16896;c[F+344>>2]=A+17152;A=128;x=128;while(1){c[F+76+(x<<2)>>2]=y+(x<<8);G=A+1&65535;if((G&65535)>191){U=128;V=128;break}else{A=G;x=G&65535}}while(1){c[F+76+(V+256<<2)>>2]=y+(V<<8);x=U+1&65535;if((x&65535)>191){break}else{U=x;V=x&65535}}if(!E){y=F;gGC(y|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=D;c[2417277]=w;c[1836236]=-1;y=c[2385366]|0;c[2439022]=y;x=a[9688]|0?534:0;c[2439023]=y+(x<<1);c[2439024]=y+(x<<1<<1);x=a[9680]|0?32e3:0;c[3542220]=11200;if((c[2113008]|0)==0){gGz(14168888,0,252);c[3542223]=x;c[3542224]=0;c[3542225]=0;c[3542226]=426;c[3542227]=0;c[3542234]=~~((+(x|0)*32768.0*8.0+625.0e3)/125.0e4);x=31;W=32767.0;while(1){c[14169012+(x<<2)>>2]=~~(W+.5);y=x-1|0;if((y|0)>0){x=y;W=W/1.188502227}else{break}}c[3542253]=0;h[1771269]=1.0;h[1771270]=1.0;h[1771271]=1.0;c[3542574]=3;c[3542575]=3;c[3542576]=3;mB(0);c[2113008]=(c[2113008]|0)+1}h[1771269]=.5;c[3542574]=3;h[1771270]=.5;c[3542575]=3;h[1771271]=.5;c[3542576]=3;c[2405758]=1;gGz(9542544,0,32);c[2385641]=1;h[1192819]=1.0;c[2385642]=3;c[2385643]=1024;x=0;do{w=x*257|0;b[9732544+(x<<1)>>1]=((w|0)/2|0)&65535;b[9753784+(x<<1)>>1]=w+32768&65535;x=x+1|0;}while((x|0)<256);c[3528842]=1;h[1192819]=.5;c[2385642]=3;a[9717384]=0;a[9541304]=0;a[9541312]=0;a[14114840]=0;c[2440204]=0;a[9624368]=0;gGz((c[2424760]|0)+16384|0,0,49152);gGz((c[2424746]|0)+32768|0,0,16384);x=c[2439330]|0;w=(x|0)==0;if(!w){D=x;gGC(9706056,D|0,76)|0}D=c[2438118]|0;c[2433530]=D;F=c[3528484]|0;c[2076596]=F;E=c[2417276]|0;c[3541536]=E;c[1836236]=0;gGz(9706056,0,76);if(!w){w=x;gGC(w|0,9706056,76)|0}c[2438118]=D;c[3528484]=F;c[2417276]=E;c[1836236]=-1;E=c[2439331]|0;F=(E|0)==0;if(!F){D=E;gGC(9706056,D|0,76)|0}D=c[2438119]|0;c[2433530]=D;w=c[3528485]|0;c[2076596]=w;x=c[2417277]|0;c[3541536]=x;c[1836236]=1;gGz(9706056,0,76);if(!F){F=E;gGC(F|0,9706056,76)|0}c[2438119]=D;c[3528485]=w;c[2417277]=x;c[1836236]=-1;mB(0);I=0;i=d;return I|0}}while(0);c[2385366]=0;I=1;i=d;return I|0}}while(0);c[2426746]=0;I=1;i=d;return I|0}function dQ0(){return~~((a[9688]|0?534.0:0.0)*(+((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)/(25.0e5/(+(c[2424]|0)/100.0))))|0}function dQ1(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((e-57352|0)>>>0>=8){return}a[(c[3529396]|0)+(e&7)|0]=d;return}function dQ2(b){b=b|0;var e=0,f=0;e=b&65535;if((e|0)==61441){f=a[9635210]|0}else if((e|0)==57345){f=a[9635208]|0}else if((e|0)==57346){f=(d[9635209]|0|c[2408978])&255}else if((e|0)==57344){f=a[9550016]|0}else{f=0}return f|0}function dQ3(a,b){a=a|0;b=b|0;var c=0;c=a&65535;if((c|0)==49152|(c|0)==49153){lS(1,c&1,b);return}else if((c|0)==40960|(c|0)==40961){lS(0,c&1,b);return}else{return}}function dQ4(b){b=b|0;var d=0,e=0,f=0.0,g=0.0,i=0;d=b&65535;if((d|0)==40961){b=c[3541518]|0;e=b+296|0;f=+h[e>>3];do{if(f!=0.0){g=+h[6675];if(f-(g+ +gC[c[2429842]&255]())<=0.0){h[e>>3]=0.0;break}i=a[b+307|0]|-128;return i|0}}while(0);i=a[b+307|0]|0;return i|0}else if((d|0)==45056){i=a[c[3528288]|0]|0;return i|0}else{i=0;return i|0}return 0}function dQ5(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5670204+(b*112|0)>>2];c[a+104>>2]=c[5670208+(b*112|0)>>2];c[a+108>>2]=c[5670212+(b*112|0)>>2];d=0;return d|0}function dQ6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=5670104+(b*112|0);e=0;return e|0}function dQ7(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3440408+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dQ8(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>32){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6080616+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dQ9(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0;e=i;i=i+1560|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;B=e+1200|0;C=e+1312|0;D=e+1320|0;E=e+1432|0;F=e+1440|0;G=e+1552|0;c[2414990]=0;c[3529242]=0;c[3529198]=65536;c[3530860]=131072;c[3530624]=524288;c[3531008]=557056;c[3530040]=557824;c[2406938]=559872;c[2414694]=561920;c[3529330]=561920;c[3529290]=566016;c[2386474]=568064;c[3529396]=572160;c[2387988]=572160;c[3528288]=572161;c[2406588]=572168;c[2411708]=572172;H=0;while(1){if((H|0)>=1024){break}I=9638528+(H<<2)|0;if((c[I>>2]|0)==0){J=20614;break}else{H=H+1|0}}do{if((J|0)==20614){H=gGq(572172)|0;c[I>>2]=H;if((H|0)==0){break}c[2414990]=H;gGz(H|0,0,572172);c[3529242]=H;c[3529198]=H+65536;c[3530860]=H+131072;c[3530624]=H+524288;c[3531008]=H+557056;c[3530040]=H+557824;c[2406938]=H+559872;K=H+561920|0;c[2414694]=K;c[3529330]=K;c[3529290]=H+566016;c[2386474]=H+568064;K=H+572160|0;c[3529396]=K;c[2387988]=K;c[3528288]=H+572161;c[2406588]=H+572168;K=H+572172|0;c[2411708]=K;c[2414250]=K;if((c[3542200]|0)==0){L=1;i=e;return L|0}K=F+108|0;c[K>>2]=0;M=F+100|0;c[M>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](F,0)|0;do{if((c[K>>2]|0)!=0){N=c[M>>2]|0;c[G>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](G,0,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(H,0,0)|0)==0){break}else{L=1}i=e;return L|0}}while(0);H=(c[3529242]|0)+32768|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}M=D+108|0;c[M>>2]=0;K=D+100|0;c[K>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](D,1)|0;do{if((c[M>>2]|0)!=0){N=c[K>>2]|0;c[E>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](E,1,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(H,0,1)|0)==0){break}else{L=1}i=e;return L|0}}while(0);H=c[3529198]|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}K=B+108|0;c[K>>2]=0;M=B+100|0;c[M>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](B,2)|0;do{if((c[K>>2]|0)!=0){N=c[M>>2]|0;c[C>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](C,2,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(H,0,2)|0)==0){break}else{L=1}i=e;return L|0}}while(0);H=c[3530860]|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}M=z+108|0;c[M>>2]=0;K=z+100|0;c[K>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](z,3)|0;do{if((c[M>>2]|0)!=0){N=c[K>>2]|0;c[A>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](A,3,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(H,0,3)|0)==0){break}else{L=1}i=e;return L|0}}while(0);H=(c[3530860]|0)+65536|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}K=x+108|0;c[K>>2]=0;M=x+100|0;c[M>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](x,4)|0;do{if((c[K>>2]|0)!=0){N=c[M>>2]|0;c[y>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](y,4,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(H,0,4)|0)==0){break}else{L=1}i=e;return L|0}}while(0);H=(c[3530860]|0)+131072|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}M=v+108|0;c[M>>2]=0;K=v+100|0;c[K>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](v,5)|0;do{if((c[M>>2]|0)!=0){N=c[K>>2]|0;c[w>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](w,5,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(H,0,5)|0)==0){break}else{L=1}i=e;return L|0}}while(0);H=(c[3530860]|0)+196608|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}K=t+108|0;c[K>>2]=0;M=t+100|0;c[M>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](t,6)|0;do{if((c[K>>2]|0)!=0){N=c[M>>2]|0;c[u>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](u,6,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(H,0,6)|0)==0){break}else{L=1}i=e;return L|0}}while(0);H=(c[3530860]|0)+262144|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}M=r+108|0;c[M>>2]=0;K=r+100|0;c[K>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](r,7)|0;do{if((c[M>>2]|0)!=0){N=c[K>>2]|0;c[s>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](s,7,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(H,0,7)|0)==0){break}else{L=1}i=e;return L|0}}while(0);H=(c[3530860]|0)+327680|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}K=p+108|0;c[K>>2]=0;M=p+100|0;c[M>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](p,8)|0;do{if((c[K>>2]|0)!=0){N=c[M>>2]|0;c[q>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](q,8,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(H,0,8)|0)==0){break}else{L=1}i=e;return L|0}}while(0);H=c[3530624]|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}M=n+108|0;c[M>>2]=0;K=n+100|0;c[K>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](n,9)|0;do{if((c[M>>2]|0)!=0){N=c[K>>2]|0;c[o>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](o,9,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(H,0,9)|0)==0){break}else{L=1}i=e;return L|0}}while(0);H=c[3531008]|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}K=l+108|0;c[K>>2]=0;M=l+100|0;c[M>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](l,10)|0;do{if((c[K>>2]|0)!=0){N=c[M>>2]|0;c[m>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](m,10,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(H,0,10)|0)==0){break}else{L=1}i=e;return L|0}}while(0);H=(c[3531008]|0)+256|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}M=j+108|0;c[M>>2]=0;K=j+100|0;c[K>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](j,11)|0;do{if((c[M>>2]|0)!=0){N=c[K>>2]|0;c[k>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](k,11,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(H,0,11)|0)==0){break}else{L=1}i=e;return L|0}}while(0);H=(c[3531008]|0)+512|0;if((c[3542200]|0)==0){L=1;i=e;return L|0}K=f+108|0;c[K>>2]=0;M=f+100|0;c[M>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](f,12)|0;do{if((c[K>>2]|0)!=0){N=c[M>>2]|0;c[g>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](g,12,0)|0;if((N|0)<1){L=1;i=e;return L|0}if((gzL(H,0,12)|0)==0){break}else{L=1}i=e;return L|0}}while(0);H=c[3531008]|0;M=c[2406938]|0;K=0;while(1){N=d[H+K|0]|0;O=d[H+(K+256)|0]|0;P=d[H+(K+512)|0]|0;c[M+(K<<2)>>2]=(-(O>>>1&1)&31)+(-(O&1)&14)+(-(O>>>2&1)&67)+(-(O>>>3&1)&143)<<8|(-(N>>>1&1)&31)+(-(N&1)&14)+(-(N>>>2&1)&67)+(-(N>>>3&1)&143)<<16|(-(P>>>1&1)&31)+(-(P&1)&14)+(-(P>>>2&1)&67)+(-(P>>>3&1)&143);P=K+1|0;if((P|0)<256){K=P}else{Q=0;break}}while(1){c[M+((Q|256)<<2)>>2]=Q<<8|Q|Q<<16;K=Q+1|0;if((K|0)<256){Q=K}else{R=0;break}}while(1){if((R|0)>=1024){S=0;break}T=9638528+(R<<2)|0;if((c[T>>2]|0)==0){J=20673;break}else{R=R+1|0}}do{if((J|0)==20673){M=gGq(393216)|0;c[T>>2]=M;if((M|0)==0){S=0;break}gGz(M|0,0,393216);S=M}}while(0);M=c[3530860]|0;K=0;do{a[S+K|0]=a[M+(K>>>3<<5&224|K&-249|K>>>6<<3&24)|0]|0;K=K+1|0;}while((K|0)<393216);gGC(M|0,S|0,393216)|0;K=0;while(1){if((K|0)>=1024){break}U=9638528+(K<<2)|0;if((c[U>>2]|0)==(S|0)){J=20680;break}else{K=K+1|0}}if((J|0)==20680){gGr(S);c[U>>2]=0}fwR(0);K=c[2439330]|0;M=(K|0)==0;if(!M){H=K;gGC(9706056,H|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];H=c[3528484]|0;c[2076596]=H;P=c[2417276]|0;c[3541536]=P;c[1836236]=0;N=c[3529242]|0;O=0;V=0;while(1){c[K+76+(V<<2)>>2]=N+(V<<8);W=O+1&65535;if((W&65535)>191){X=0;Y=0;break}else{O=W;V=W&65535}}while(1){c[K+76+(Y+256<<2)>>2]=N+(Y<<8);V=X+1&65535;if((V&65535)>191){Z=0;_=0;break}else{X=V;Y=V&65535}}while(1){V=N+(_<<8)|0;c[K+76+(_+512<<2)>>2]=V;c[K+76+(_+768<<2)>>2]=V;V=Z+1&65535;if((V&65535)>191){break}else{Z=V;_=V&65535}}N=c[3529330]|0;c[K+844>>2]=N;c[K+848>>2]=N+256;c[K+852>>2]=N+512;c[K+856>>2]=N+768;c[K+860>>2]=N+1024;c[K+864>>2]=N+1280;c[K+868>>2]=N+1536;c[K+872>>2]=N+1792;c[K+876>>2]=N+2048;c[K+880>>2]=N+2304;c[K+884>>2]=N+2560;c[K+888>>2]=N+2816;c[K+892>>2]=N+3072;c[K+896>>2]=N+3328;c[K+900>>2]=N+3584;c[K+904>>2]=N+3840;V=192;O=192;while(1){c[K+76+(O+256<<2)>>2]=N+((O<<8)-49152);W=V+1&65535;if((W&65535)>207){$=192;aa=192;break}else{V=W;O=W&65535}}while(1){O=N+((aa<<8)-49152)|0;c[K+76+(aa+512<<2)>>2]=O;c[K+76+(aa+768<<2)>>2]=O;O=$+1&65535;if((O&65535)>207){break}else{$=O;aa=O&65535}}N=c[2386474]|0;c[K+908>>2]=N;c[K+912>>2]=N+256;c[K+916>>2]=N+512;c[K+920>>2]=N+768;c[K+924>>2]=N+1024;c[K+928>>2]=N+1280;c[K+932>>2]=N+1536;c[K+936>>2]=N+1792;c[K+940>>2]=N+2048;c[K+944>>2]=N+2304;c[K+948>>2]=N+2560;c[K+952>>2]=N+2816;c[K+956>>2]=N+3072;c[K+960>>2]=N+3328;c[K+964>>2]=N+3584;c[K+968>>2]=N+3840;O=208;V=208;while(1){c[K+76+(V+256<<2)>>2]=N+((V<<8)-53248);W=O+1&65535;if((W&65535)>223){ab=208;ac=208;break}else{O=W;V=W&65535}}while(1){V=N+((ac<<8)-53248)|0;c[K+76+(ac+512<<2)>>2]=V;c[K+76+(ac+768<<2)>>2]=V;V=ab+1&65535;if((V&65535)>223){break}else{ab=V;ac=V&65535}}c[K+4184>>2]=476;c[K+4180>>2]=2350;if(!M){N=K;gGC(N|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=H;c[2417276]=P;c[1836236]=-1;fwR(1);N=c[2439331]|0;V=(N|0)==0;if(!V){O=N;gGC(9706056,O|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];O=c[3528485]|0;c[2076596]=O;W=c[2417277]|0;c[3541536]=W;c[1836236]=1;ad=c[3529198]|0;ae=0;af=0;while(1){c[N+76+(af<<2)>>2]=ad+(af<<8);ah=ae+1&65535;if((ah&65535)>127){ai=0;aj=0;break}else{ae=ah;af=ah&65535}}while(1){af=ad+(aj<<8)|0;c[N+76+(aj+512<<2)>>2]=af;c[N+76+(aj+768<<2)>>2]=af;af=ai+1&65535;if((af&65535)>127){break}else{ai=af;aj=af&65535}}ad=c[3529290]|0;c[N+588>>2]=ad;af=ad+256|0;c[N+592>>2]=af;ae=ad+512|0;c[N+596>>2]=ae;P=ad+768|0;c[N+600>>2]=P;H=ad+1024|0;c[N+604>>2]=H;K=ad+1280|0;c[N+608>>2]=K;M=ad+1536|0;c[N+612>>2]=M;ah=ad+1792|0;c[N+616>>2]=ah;c[N+1612>>2]=ad;c[N+1616>>2]=af;c[N+1620>>2]=ae;c[N+1624>>2]=P;c[N+1628>>2]=H;c[N+1632>>2]=K;c[N+1636>>2]=M;c[N+1640>>2]=ah;c[N+2636>>2]=ad;c[N+3660>>2]=ad;c[N+2640>>2]=af;c[N+3664>>2]=af;c[N+2644>>2]=ae;c[N+3668>>2]=ae;c[N+2648>>2]=P;c[N+3672>>2]=P;c[N+2652>>2]=H;c[N+3676>>2]=H;c[N+2656>>2]=K;c[N+3680>>2]=K;c[N+2660>>2]=M;c[N+3684>>2]=M;c[N+2664>>2]=ah;c[N+3688>>2]=ah;c[N+4184>>2]=58;c[N+4180>>2]=1972;if(!V){ah=N;gGC(ah|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=O;c[2417277]=W;c[1836236]=-1;Vr(2,1748e3,0,658,50,0);c[2438228]=1748e3;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=1170;h[745419]=.8;a[3203368]=1;h[745418]=.8;a[3203360]=1;h[745417]=.8;a[3203352]=1;h[745416]=.8;a[3203344]=1;h[745415]=.8;a[3203336]=1;h[745414]=.8;a[3203328]=1;h[745413]=.8;a[3203320]=1;h[745412]=.8;a[3203312]=1;ah=c[642608+(c[2436]<<2)>>2]|0;M=c[ah+128>>2]|0;if((c[ah+52>>2]&4|0)==0){c[2113068]=M;K=c[ah+132>>2]|0;c[2113070]=K;c[2443814]=M;c[2440436]=K;ak=M;al=K}else{c[2113070]=M;K=c[ah+132>>2]|0;c[2113068]=K;c[2440436]=M;c[2443814]=K;ak=K;al=M}M=ag(ak<<1,al)|0;K=gGq(M)|0;c[2112926]=K;if((K|0)!=0){gGz(K|0,0,M|0)}M=c[2414694]|0;gGz(M|0,0,(c[2411708]|0)-M|0);M=c[2439330]|0;K=(M|0)==0;if(!K){ah=M;gGC(9706056,ah|0,76)|0}ah=c[2438118]|0;c[2433530]=ah;H=c[3528484]|0;c[2076596]=H;P=c[2417276]|0;c[3541536]=P;c[1836236]=0;gGz(9706056,0,76);if(!K){K=M;gGC(K|0,9706056,76)|0}c[2438118]=ah;c[3528484]=H;c[2417276]=P;c[1836236]=-1;P=c[2439331]|0;H=(P|0)==0;if(!H){ah=P;gGC(9706056,ah|0,76)|0}ah=c[2438119]|0;c[2433530]=ah;K=c[3528485]|0;c[2076596]=K;M=c[2417277]|0;c[3541536]=M;c[1836236]=1;gGz(9706056,0,76);if(!H){H=P;gGC(H|0,9706056,76)|0}c[2438119]=ah;c[3528485]=K;c[2417277]=M;c[1836236]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){am=0}else{L=0;i=e;return L|0}while(1){lN(am);mB(am);M=am+1|0;if((M|0)<(c[2385508]|0)){am=M}else{L=0;break}}i=e;return L|0}}while(0);c[2414990]=0;L=1;i=e;return L|0}function dRa(){var b=0,d=0,e=0,f=0;b=c[3541518]|0;if((b|0)!=0){gGr(b|0);c[3541518]=0}if((c[2385508]|0)>0){c[2113008]=0;c[2076598]=0;c[2383582]=0}c[2438228]=0;c[2433526]=0;c[2406676]=0;c[3528472]=0;b=c[2406680]|0;if((b|0)!=0){gGr(b);c[2406680]=0}c[2385508]=0;c[2432978]=0;a[64240]=0;c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}fwZ();b=c[2414990]|0;d=0;while(1){if((d|0)>=1024){e=20774;break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==(b|0)){break}else{d=d+1|0}}if((e|0)==20774){c[2414990]=0;return 0}gGr(b);c[f>>2]=0;c[2414990]=0;return 0}function dRb(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0;do{if((a[9624360]|0)!=0){d=c[2414694]|0;gGz(d|0,0,(c[2411708]|0)-d|0);d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=i;c[1836236]=-1;i=c[2439331]|0;g=(i|0)==0;if(!g){f=i;gGC(9706056,f|0,76)|0}f=c[2438119]|0;c[2433530]=f;e=c[3528485]|0;c[2076596]=e;d=c[2417277]|0;c[3541536]=d;c[1836236]=1;gGz(9706056,0,76);if(!g){g=i;gGC(g|0,9706056,76)|0}c[2438119]=f;c[3528485]=e;c[2417277]=d;c[1836236]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){j=0}else{break}do{lN(j);mB(j);j=j+1|0;}while((j|0)<(c[2385508]|0))}}while(0);a[9550016]=(a[9633744]|-2)^1^a[9633745]<<1&2^a[9633746]<<2&4^a[9633747]<<3&8^a[9633748]<<4&16^a[9633749]<<5&32^a[9633750]<<6&64^a[9633751]<<7;j=c[2385548]|0;if((j|0)>0){gGz(9752472,0,((j|0)>1?j<<2:4)|0)}c[2433530]=0;c[2408978]=0;j=0;do{if((j|0)==248|(j|0)==8){c[2408978]=c[2408978]^1}d=c[2439330]|0;if((d|0)!=0){e=d;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;e=c[2438118]|0;c[2433530]=e;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;if((a[d+4188|0]|0)==0){d=gfc(260)|0;k=(c[2433530]|0)+d|0}else{k=e+260|0}c[2433530]=k;if((j|0)==255&(a[9631560]|0)!=0){if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;e=(c[2433530]|0)+12|0;c[2433530]=e;l=e}else{l=k}e=c[1836236]|0;d=c[9757320+(e<<2)>>2]|0;if((d|0)!=0){f=d;gGC(f|0,9706056,76)|0}c[9752472+(e<<2)>>2]=l;c[14113936+(e<<2)>>2]=c[2076596];c[9669104+(e<<2)>>2]=c[3541536];c[1836236]=-1;e=c[2439331]|0;if((e|0)!=0){f=e;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;Sb(j*113|0);f=c[1836236]|0;e=c[9757320+(f<<2)>>2]|0;if((e|0)!=0){d=e;gGC(d|0,9706056,76)|0}c[9752472+(f<<2)>>2]=c[2433530];c[14113936+(f<<2)>>2]=c[2076596];c[9669104+(f<<2)>>2]=c[3541536];c[1836236]=-1;j=j+1|0;}while((j|0)<256);j=c[2439331]|0;if((j|0)!=0){l=j;gGC(9706056,l|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;l=c[2438228]|0;j=gGS(-1301676032,13891,l,(l|0)<0|0?-1:0)|0;l=j;Sb(29133);j=c[2443830]|0;if((j|0)<1073676288){c[2443830]=j-l}j=c[2443831]|0;if((j|0)<1073676288){c[2443831]=j-l}j=(c[3528512]|0)-l|0;c[3528512]=(j|0)<0?0:j;j=c[2112964]|0;if((j|0)!=0){gg[c[3542122]&4095](j,a[9688]|0?534:0)}j=c[1836236]|0;l=c[9757320+(j<<2)>>2]|0;if((l|0)!=0){k=l;gGC(k|0,9706056,76)|0}c[9752472+(j<<2)>>2]=c[2433530];c[14113936+(j<<2)>>2]=c[2076596];c[9669104+(j<<2)>>2]=c[3541536];c[1836236]=-1;if((c[2112968]|0)==0){return 0}dRc()|0;return 0}function dRc(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;if((a[9547552]|0)!=0){e=c[2406938]|0;f=c[3530040]|0;g=0;do{h=c[e+(g<<2)>>2]|0;c[f+(g<<2)>>2]=h>>8<<3&2016|h>>>3&31|h>>16<<8&63488;g=g+1|0;}while((g|0)<512)}g=c[2113068]|0;f=c[2113070]|0;e=ag(f,g)|0;h=c[2112926]|0;if((e|0)>0){i=0;while(1){b[h+(i<<1)>>1]=255;j=i+1|0;if((j|0)<(e|0)){i=j}else{k=h;break}}}else{k=h}h=c[2406588]|0;i=(c[h>>2]|0)>>>4&1023;e=c[2387988]|0;j=c[3530624]|0;l=0;do{m=d[e]|0;n=(m<<9&24576)+(l<<1)|0;o=d[j+n|0]|0;p=(l<<6&512)+i+(d[j+(n|1)|0]<<1|l&1)|0;n=l>>4<<3|l&7;if((m&1|0)==0){q=p;r=n}else{q=1024-(p&1023)|0;r=256-(n&255)|0}n=(o&128|0)!=0?0:3;p=(o&127|256)&65535;o=0;do{m=((o&1)+q&511)-96|0;s=((o>>>1&1)+r&255)-16|0;do{if((s|m|0)>=0){if(!((m|0)<(g|0)&(s|0)<(f|0))){break}b[k+((ag(g,s)|0)+m<<1)>>1]=p}}while(0);o=o+1|0;}while((o|0)<=(n|0));l=l+1|0;}while((l|0)<4096);l=(a[e]|0)<0?3:4;r=c[2386474]|0;q=c[3530860]|0;j=0;do{i=d[r+j|0]|0;n=d[r+(j|2)|0]|0;o=d[r+(j|3)|0]<<8;p=n&2;m=n&4;s=n&1|d[r+(j|1)|0]<<1;t=(o|n)>>>4;u=(t&2032)+((o&32768)>>>(l>>>0))|0;o=n&136;if((o|0)==136){v=4;w=0}else if((o|0)==8){v=2;w=n>>>2&8|n>>>3&2}else{v=1;w=t&15}if((a[e]&1)==0){x=m;y=p;z=s-96|0;A=i-16|0}else{t=8-(v<<3)|0;x=m>>>2^1;y=p>>>1^1;z=87-s+t+g|0;A=7-i+t+f|0}t=(y|0)!=0;i=v-1|0;s=t?-1:v;p=t?-1:1;m=t?i:0;n=(x|0)!=0;o=n?-1:v;B=n?-1:1;C=n?i:0;if((C|0)!=(o|0)){i=(m|0)==(s|0);D=v&2;E=C;C=u+w|0;while(1){u=(E<<3)+A|0;if(i){F=C}else{if(n){if(t){G=m;H=C;while(1){I=H+1|0;Sx(k,H,(G<<3)+z|0,u,0,8,255,0,q);J=G+p|0;if((J|0)==(s|0)){F=I;break}else{G=J;H=I}}}else{H=m;G=C;while(1){I=G+1|0;Sv(k,G,(H<<3)+z|0,u,0,8,255,0,q);J=H+p|0;if((J|0)==(s|0)){F=I;break}else{H=J;G=I}}}}else{if(t){G=m;H=C;while(1){I=H+1|0;St(k,H,(G<<3)+z|0,u,0,8,255,0,q);J=G+p|0;if((J|0)==(s|0)){F=I;break}else{G=J;H=I}}}else{H=m;G=C;while(1){I=G+1|0;Sr(k,G,(H<<3)+z|0,u,0,8,255,0,q);J=H+p|0;if((J|0)==(s|0)){F=I;break}else{H=J;G=I}}}}}G=E+B|0;if((G|0)==(o|0)){break}else{E=G;C=F+D|0}}}j=j+4|0;}while((j|0)<1024);R8(c[3530040]|0);c[h>>2]=((d[e]|0)>>>1&7)+(c[h>>2]|0);return 0}function dRd(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=i;i=i+16|0;e=d|0;if((b|0)!=0){c[b>>2]=169730}if((a&96|0)==0){i=d;return 0}f=c[2414694]|0;c[e>>2]=f;c[e+4>>2]=(c[2411708]|0)-f;c[e+12>>2]=196728;gj[c[2076592]&4095](e)|0;fw$(a);Vx(a,b);i=d;return 0}function dRe(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2878084+(b*112|0)>>2];c[a+104>>2]=c[2878088+(b*112|0)>>2];c[a+108>>2]=c[2878092+(b*112|0)>>2];d=0;return d|0}function dRf(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=2877984+(b*112|0);e=0;return e|0}function dRg(a){a=a|0;var b=0,d=0;b=(c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,1748e3,0)|0;return a|0}function dRh(){return+(+((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)/1748.0e3)}function dRi(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>3){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2913372+(b*112|0)>>2];c[a+104>>2]=c[2913376+(b*112|0)>>2];c[a+108>>2]=c[2913380+(b*112|0)>>2];d=0;return d|0}function dRj(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<4&(d|0)==0)){e=1;return e|0}c[a>>2]=2913272+(b*112|0);e=0;return e|0}function dRk(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1276736+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dRl(a,b){a=a|0;b=b|0;var d=0;if((b|0)!=0){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;c[b>>2]=c[1010314];c[b+4>>2]=c[1010315];c[b+8>>2]=c[1010316];d=0;return d|0}function dRm(){return dRB(0,0)|0}function dRn(){var a=0,b=0,d=0,e=0;c[2113070]=0;c[2113068]=0;a=c[2112926]|0;if((a|0)!=0){gGr(a);c[2112926]=0}gGz(8443768,0,6208);gGz(9718136,0,38);gGz(9669136,0,152);TT();a=c[2414988]|0;b=0;while(1){if((b|0)>=1024){d=20911;break}e=9638528+(b<<2)|0;if((c[e>>2]|0)==(a|0)){break}else{b=b+1|0}}if((d|0)==20911){c[2414988]=0;return 0}gGr(a);c[e>>2]=0;c[2414988]=0;return 0}function dRo(){var d=0,e=0,f=0,g=0;do{if((a[9624352]|0)==0){d=c[2388370]|0;if((d|0)<=179){e=d;break}c[2110940]=8443768;gGC(9718136,9669136,38)|0;c[3528404]=-1;dRH(0);gGz(9718136,0,38);a[9718144]=10;a[9718145]=0;gGC(9669136,9718136,38)|0;c[2444]=-1;c[2388370]=0;e=0}else{d=c[2414692]|0;gGz(d|0,0,(c[2411706]|0)-d|0);c[2110940]=8443768;gGC(9718136,9669136,38)|0;c[3528404]=-1;dRH(0);gGz(9718136,0,38);a[9718144]=10;a[9718145]=0;gGC(9669136,9718136,38)|0;c[2444]=-1;c[2388370]=0;e=0}}while(0);c[2388370]=e+1;b[4775296]=-1;e=0;d=-1;f=-1;do{d=((a[9633736+e|0]&1)<<e^d&255)&255;f=((a[9631552+e|0]&1)<<e^f&255)&255;e=e+1|0;}while((e|0)<8);a[9550592]=d;a[9550593]=f;c[2110940]=8443768;c[2444]=0;gGC(9718136,9669136,38)|0;a[672576]=0;f=0;do{if((f|0)==31){g=20921;break}geH(800)|0;f=f+1|0;}while((f|0)<32);if((g|0)==20921){a[672576]=1;geG(3);geH(800)|0;a[9718172]=0}g=9669136+((c[2444]|0)*38|0)|0;gGC(g|0,9718136,38)|0;c[2444]=-1;g=c[2112964]|0;if((g|0)!=0){TQ(0,g,a[9688]|0?534:0)}if((c[2112968]|0)==0){return 0}dRp()|0;return 0}function dRp(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;if((a[9547544]|0)!=0){dRC();a[9547544]=0}e=c[2386736]|0;f=c[2386224]|0;g=c[2387874]|0;h=c[3528708]|0;i=c[2112926]|0;j=c[3530858]|0;k=c[2113070]|0;l=0;do{m=l&31;n=m<<3;o=(l>>5<<3)-16-(d[e+m|0]|0)|0;p=(o|0)<-7?o+256|0:o;do{if((p|0)<(k|0)){o=d[e+(m|160)|0]<<8&768|d[f+l|0];q=a[g+m|0]&31;if((a[h]|0)==0){Sj(i,o,n,p,q,2,0,j);break}else{Sp(i,o,248-n|0,216-p|0,q,2,0,j);break}}}while(0);l=l+1|0;}while((l|0)<1024);l=c[3529658]|0;j=c[3529612]|0;h=c[3529640]|0;g=c[3530622]|0;f=c[3531006]|0;e=c[2113068]|0;p=14;do{n=d[l+p|0]|0;m=p|1;q=d[j+m|0]^255;o=d[l+m|0]<<2&124;m=(n&2|0)==0?0:240;r=(n&1|0)==0?m:m|15;m=(d[h+p|0]<<6&192|n>>>2)<<8;n=(d[j+p|0]|0)+((p|0)<5?-30:-31)|0;s=0;while(1){if((n|0)>-1&(n|0)<(k|0)){t=s<<4;u=ag(e,n)|0;v=q;w=0;while(1){do{if((v|0)>=0&(v|0)<(e|0)){x=d[g+((w+t^r)+m)|0]|o;if((a[f+(x+32)|0]|0)==0){break}b[i+(u+v<<1)>>1]=x&65535}}while(0);x=w+1|0;if((x|0)<16){v=v+1|0;w=x}else{break}}}w=s+1|0;if((w|0)>=16){break}n=n+1|0;s=w}p=p-2|0;}while((p|0)>-1);R8(c[3530038]|0);return 0}function dRq(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=i;i=i+64|0;e=d|0;f=d+16|0;g=d+32|0;h=d+48|0;if((b|0)!=0){c[b>>2]=169737}if((a&96|0)!=0){gGz(h|0,0,12);b=c[2414692]|0;c[h>>2]=b;c[h+4>>2]=(c[2411706]|0)-b;c[h+12>>2]=162152;b=c[2076592]|0;gj[b&4095](h)|0;if((a&64|0)!=0){gGz(e|0,0,12);c[e>>2]=9669136;c[e+4>>2]=152;c[e+12>>2]=162152;h=c[2076592]|0;gj[h&4095](e)|0}gGz(g|0,0,12);c[g>>2]=9553480;c[g+4>>2]=4;c[g+12>>2]=102144;e=c[2076592]|0;gj[e&4095](g)|0;gGz(f|0,0,12);c[f>>2]=14113616;c[f+4>>2]=4;c[f+12>>2]=181472;g=c[2076592]|0;gj[g&4095](f)|0}if((a&2|0)==0){i=d;return 0}c[2110940]=8443768;gGC(9718136,9669136,38)|0;a=c[3528404]|0;c[3528404]=-1;dRH(a);gGC(9669136,9718136,38)|0;c[2444]=-1;i=d;return 0}function dRr(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>3){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6610068+(b*112|0)>>2];c[a+104>>2]=c[6610072+(b*112|0)>>2];c[a+108>>2]=c[6610076+(b*112|0)>>2];d=0;return d|0}function dRs(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<4&(d|0)==0)){e=1;return e|0}c[a>>2]=6609968+(b*112|0);e=0;return e|0}function dRt(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4855232+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dRu(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>3){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6610416+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dRv(){return dRB(0,6)|0}function dRw(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>4){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6500764+(b*112|0)>>2];c[a+104>>2]=c[6500768+(b*112|0)>>2];c[a+108>>2]=c[6500772+(b*112|0)>>2];d=0;return d|0}function dRx(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<5&(d|0)==0)){e=1;return e|0}c[a>>2]=6500664+(b*112|0);e=0;return e|0}function dRy(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5142632+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dRz(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>3){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6815264+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dRA(){return dRB(1,4)|0}function dRB(b,e){b=b|0;e=e|0;var f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;f=i;i=i+600|0;g=f|0;j=f+112|0;k=f+120|0;l=f+232|0;m=f+240|0;n=f+352|0;o=f+360|0;p=f+472|0;q=f+480|0;r=f+592|0;c[2414988]=0;c[2387046]=0;c[3530858]=32768;c[3530622]=98304;c[3531006]=163840;c[3530038]=164128;c[2414692]=164640;c[2387048]=164640;c[2386224]=165664;c[2386736]=166688;c[2387874]=166944;c[3529612]=166976;c[3529640]=166832;c[3529658]=165648;c[3528708]=166992;c[2411706]=166993;s=0;while(1){if((s|0)>=1024){break}t=9638528+(s<<2)|0;if((c[t>>2]|0)==0){u=21018;break}else{s=s+1|0}}do{if((u|0)==21018){s=gGq(166993)|0;c[t>>2]=s;if((s|0)==0){break}c[2414988]=s;gGz(s|0,0,166993);c[2387046]=s;c[3530858]=s+32768;c[3530622]=s+98304;c[3531006]=s+163840;c[3530038]=s+164128;v=s+164640|0;c[2414692]=v;c[2387048]=v;c[2386224]=s+165664;c[2386736]=s+166688;c[2387874]=s+166944;c[3529612]=s+166976;c[3529640]=s+166832;c[3529658]=s+165648;c[3528708]=s+166992;v=s+166993|0;c[2411706]=v;c[2414248]=v;if((c[3542200]|0)==0){w=1;i=f;return w|0}v=q+108|0;c[v>>2]=0;x=q+100|0;c[x>>2]=0;y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[y&16383](q,0)|0;do{if((c[v>>2]|0)!=0){y=c[x>>2]|0;c[r>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](r,0,0)|0;if((y|0)<1){w=1;i=f;return w|0}if((gzL(s,0,0)|0)==0){break}else{w=1}i=f;return w|0}}while(0);s=c[2387046]|0;x=s+16384|0;gGC(x|0,s|0,16384)|0;do{if((b|0)!=0){if((c[3542200]|0)==0){w=1;i=f;return w|0}s=o+108|0;c[s>>2]=0;v=o+100|0;c[v>>2]=0;y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[y&16383](o,1)|0;if((c[s>>2]|0)==0){break}s=c[v>>2]|0;c[p>>2]=9534384;v=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[v&16383](p,1,0)|0;if((s|0)<1){w=1;i=f;return w|0}if((gzL(x,0,1)|0)==0){break}else{w=1}i=f;return w|0}}while(0);x=1<<e&254^254;s=c[2387046]|0;v=0;do{y=s+v|0;z=d[y]|0;a[y]=(z>>>(e>>>0)&1|z&x|(z&1)<<e)&255;v=v+1|0;}while((v|0)<32768);v=c[3530622]|0;x=b+1|0;if((c[3542200]|0)==0){w=1;i=f;return w|0}s=m+108|0;c[s>>2]=0;z=m+100|0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,x)|0;do{if((c[s>>2]|0)!=0){y=c[z>>2]|0;c[n>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](n,x,0)|0;if((y|0)<1){w=1;i=f;return w|0}if((gzL(v,0,x)|0)==0){break}else{w=1}i=f;return w|0}}while(0);x=c[3530622]|0;v=c[3530858]|0;z=0;do{a[v+(z<<1&8192|z&4095|z>>>1&4096)|0]=a[x+z|0]|0;z=z+1|0;}while((z|0)<16384);z=c[3531006]|0;x=b+2|0;if((c[3542200]|0)==0){w=1;i=f;return w|0}v=k+108|0;c[v>>2]=0;s=k+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,x)|0;do{if((c[v>>2]|0)!=0){y=c[s>>2]|0;c[l>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](l,x,0)|0;if((y|0)<1){w=1;i=f;return w|0}if((gzL(z,0,x)|0)==0){break}else{w=1}i=f;return w|0}}while(0);x=(c[3531006]|0)+32|0;z=b+3|0;if((c[3542200]|0)==0){w=1;i=f;return w|0}s=g+108|0;c[s>>2]=0;v=g+100|0;c[v>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,z)|0;do{if((c[s>>2]|0)!=0){y=c[v>>2]|0;c[j>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](j,z,0)|0;if((y|0)<1){w=1;i=f;return w|0}if((gzL(x,0,z)|0)==0){break}else{w=1}i=f;return w|0}}while(0);dRC();z=0;while(1){if((z|0)>=1024){break}B=9638528+(z<<2)|0;if((c[B>>2]|0)==0){u=21048;break}else{z=z+1|0}}L27927:do{if((u|0)==21048){z=gGq(16384)|0;c[B>>2]=z;if((z|0)==0){break}gGz(z|0,0,16384);x=c[3530858]|0;gGC(z|0,x|0,16384)|0;v=0;do{s=v<<6;gGz(x+s|0,0,64);y=v<<7;A=0;do{C=y+(c[611712+(A<<2)>>2]|0)|0;D=(A<<3)+s|0;E=0;do{F=C+(c[610928+(E<<2)>>2]|0)|0;if(((d[z+((F|0)/8|0)|0]|0)&128>>>((F&7)>>>0)|0)!=0){F=x+(D+E)|0;a[F]=a[F]|2}E=E+1|0;}while((E|0)<8);A=A+1|0;}while((A|0)<8);A=y|4;E=0;do{D=A+(c[611712+(E<<2)>>2]|0)|0;C=(E<<3)+s|0;F=0;do{G=D+(c[610928+(F<<2)>>2]|0)|0;if(((d[z+((G|0)/8|0)|0]|0)&128>>>((G&7)>>>0)|0)!=0){G=x+(C+F)|0;a[G]=a[G]|1}F=F+1|0;}while((F|0)<8);E=E+1|0;}while((E|0)<8);v=v+1|0;}while((v|0)<1024);v=c[3530622]|0;x=0;while(1){E=x<<8;gGz(v+E|0,0,256);s=x<<9;A=0;do{y=s+(c[611712+(A<<2)>>2]|0)|0;F=(A<<4)+E|0;C=0;do{D=y+(c[61e4+(C<<2)>>2]|0)|0;if(((d[z+((D|0)/8|0)|0]|0)&128>>>((D&7)>>>0)|0)!=0){D=v+(F+C)|0;a[D]=a[D]|2}C=C+1|0;}while((C|0)<16);A=A+1|0;}while((A|0)<16);A=s|4;C=0;do{F=A+(c[611712+(C<<2)>>2]|0)|0;y=(C<<4)+E|0;D=0;do{G=F+(c[61e4+(D<<2)>>2]|0)|0;if(((d[z+((G|0)/8|0)|0]|0)&128>>>((G&7)>>>0)|0)!=0){G=v+(y+D)|0;a[G]=a[G]|1}D=D+1|0;}while((D|0)<16);C=C+1|0;}while((C|0)<16);C=x+1|0;if((C|0)<256){x=C}else{H=0;break}}while(1){if((H|0)>=1024){break L27927}I=9638528+(H<<2)|0;if((c[I>>2]|0)==(z|0)){break}else{H=H+1|0}}gGr(z);c[I>>2]=0}}while(0);gGz(8443768,0,1552);gGz(9669136,0,38);x=c[2427044]|0;c[9681616+(x<<3)>>2]=728712;c[9681620+(x<<3)>>2]=0;c[2427044]=x+1;c[2110940]=8443768;c[2444]=0;gGC(9718136,9669136,38)|0;x=c[2386736]|0;v=c[2386224]|0;C=c[2387048]|0;E=0;do{A=E|5120;s=(A|0)/256|0;D=((E|5375|0)/256|0)+1|0;if((s|0)<(D|0)){y=s;do{s=x+((y<<8)-A)|0;c[8443784+(y<<2)>>2]=s;c[8444296+(y<<2)>>2]=s;c[8444808+(y<<2)>>2]=s;y=y+1|0;}while((y|0)<(D|0))}D=E|6144;y=(D|0)/256|0;A=((E|7167|0)/256|0)+1|0;if((y|0)<(A|0)){z=y;do{y=v+((z<<8)-D)|0;c[8443784+(z<<2)>>2]=y;c[8444296+(z<<2)>>2]=y;c[8444808+(z<<2)>>2]=y;z=z+1|0;}while((z|0)<(A|0))}A=E|7168;z=(A|0)/256|0;D=((E|8191|0)/256|0)+1|0;if((z|0)<(D|0)){y=z;do{z=C+((y<<8)-A)|0;c[8443784+(y<<2)>>2]=z;c[8444296+(y<<2)>>2]=z;c[8444808+(y<<2)>>2]=z;y=y+1|0;}while((y|0)<(D|0))}E=E+8192|0;}while((E|0)<57345);c[2110943]=2180;c[2110942]=2432;c[2110945]=2048;c[2110944]=3286;gGC(9669136,9718136,38)|0;c[2444]=-1;TS(0,307200,32768,6,0,0);E=c[2420348]|0;h[E+192>>3]=.75;c[E+200>>2]=3;E=c[642608+(c[2436]<<2)>>2]|0;C=c[E+128>>2]|0;if((c[E+52>>2]&4|0)==0){c[2113068]=C;v=c[E+132>>2]|0;c[2113070]=v;c[2443814]=C;c[2440436]=v;J=C;K=v}else{c[2113070]=C;v=c[E+132>>2]|0;c[2113068]=v;c[2440436]=C;c[2443814]=v;J=v;K=C}C=ag(J<<1,K)|0;v=gGq(C)|0;c[2112926]=v;if((v|0)!=0){gGz(v|0,0,C|0)}C=c[2414692]|0;gGz(C|0,0,(c[2411706]|0)-C|0);c[2110940]=8443768;gGC(9718136,9669136,38)|0;c[3528404]=-1;dRH(0);gGz(9718136,0,38);a[9718144]=10;a[9718145]=0;gGC(9669136,9718136,38)|0;c[2444]=-1;c[2388370]=0;w=0;i=f;return w|0}}while(0);c[2414988]=0;w=1;i=f;return w|0}function dRC(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0;b=i;i=i+128|0;e=b|0;f=c[3531006]|0;g=0;do{h=d[f+g|0]|0;c[e+(g<<2)>>2]=(-(h>>>3&1)&33)+(-(h>>>4&1)&71)+(-(h>>>5&1)&151)<<3&2016|(-(h>>>6&1)&80|-(h>>>7)&168)>>>3&31|(-(h>>>1&1)&71)+(-(h&1)&33)+(-(h>>>2&1)&151)<<8&63488;g=g+1|0;}while((g|0)<32);g=f+32|0;h=a[g]&15;a[g]=h;g=c[3530038]|0;c[g>>2]=c[e+((h&255)<<2)>>2];h=1;do{j=f+(h+32)|0;k=a[j]&15;a[j]=k;c[g+(h<<2)>>2]=c[e+((k&255)<<2)>>2];h=h+1|0;}while((h|0)<128);i=b;return}function dRD(b,d){b=b|0;d=d|0;var e=0;e=b&65535;b=e&8191;if((b|0)==5379){a[c[3528708]|0]=d&1;return}else if((b|0)==5383){return}else if((b|0)==5575){dRH(d&255);return}else if((b|0)==5568){c[2388370]=0;return}else{if((e&7168|0)==4096){a[(c[2387874]|0)+(e&31)|0]=d;return}if((e&8176|0)!=5472){return}a[(c[3529612]|0)+(e&15)|0]=d;return}}function dRE(b){b=b|0;var c=0,d=0;c=b&8191;if((c|0)==5504){d=a[9635200]|0}else if((c|0)==5440){d=a[9550593]|0}else if((c|0)==5376){d=a[9550592]|0}else{d=0}return d|0}function dRF(a,b){a=a|0;b=b|0;if((a&511)!=257){return}TR(0,b&255);return}function dRG(b){b=b|0;var c=0,d=0;c=b&511;do{if((c|0)==1){b=(e[4859070]|0)+(e[4859069]|0)|0;if((b|0)==48|(b|0)==52|(b|0)==657|(b|0)==1126){d=1;break}d=0}else if((c|0)==258){d=a[672576]|0?0:-128}else{d=0}}while(0);return d|0}function dRH(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=a&1;a=b<<14;if((c[3528404]|0)==(b|0)){return}d=a|8192;e=c[2387046]|0;f=c[2110940]|0;g=0;do{h=e+((g<<8)+a)|0;c[f+16+(g<<2)>>2]=h;c[f+1040+(g<<2)>>2]=h;g=g+1|0;}while((g|0)<16);g=a|4096;h=a|12288;i=g-8192|0;j=32;do{k=e+(i+(j<<8))|0;c[f+16+(j<<2)>>2]=k;c[f+1040+(j<<2)>>2]=k;j=j+1|0;}while((j|0)<48);j=d-16384|0;i=64;do{k=e+(j+(i<<8))|0;c[f+16+(i<<2)>>2]=k;c[f+1040+(i<<2)>>2]=k;i=i+1|0;}while((i|0)<80);i=h-24576|0;j=96;do{k=e+(i+(j<<8))|0;c[f+16+(j<<2)>>2]=k;c[f+1040+(j<<2)>>2]=k;j=j+1|0;}while((j|0)<112);j=a|-32768;a=128;do{i=e+(j+(a<<8))|0;c[f+16+(a<<2)>>2]=i;c[f+1040+(a<<2)>>2]=i;a=a+1|0;}while((a|0)<144);a=g-40960|0;g=160;do{j=e+(a+(g<<8))|0;c[f+16+(g<<2)>>2]=j;c[f+1040+(g<<2)>>2]=j;g=g+1|0;}while((g|0)<176);g=d-49152|0;d=192;do{a=e+(g+(d<<8))|0;c[f+16+(d<<2)>>2]=a;c[f+1040+(d<<2)>>2]=a;d=d+1|0;}while((d|0)<208);d=h-57344|0;h=224;do{g=e+(d+(h<<8))|0;c[f+16+(h<<2)>>2]=g;c[f+1040+(h<<2)>>2]=g;h=h+1|0;}while((h|0)<240);c[3528404]=b;return}function dRI(d,f){d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((d|0)==16662530){if(!(a[638656]|0)){a[c[3528286]|0]=f;return}g=c[2276056]|0;h=c[2388292]|0;if((g|0)==24898){i=b[h+16374>>1]|0;j=i&65535;do{if((i&65535)<15){k=(e[716016+(j<<1)>>1]|0)-(e[h+16372>>1]|0)|0;if((k|0)<=255){l=255;break}l=b[715504+((k<<4)+(j&255)<<1)>>1]|0}else{l=255}}while(0);b[h+16370>>1]=l;return}else if((g|0)==20850|(g|0)==20810|(g|0)==20770|(g|0)==10240){a[c[3528286]|0]=b[h+16380>>1]&255;return}else if((g|0)==9300){l=e[h+16368>>1]|0;b[h+16358>>1]=b[801320+(l<<1)>>1]|0;b[h+16360>>1]=b[801320+(l+1<<1)>>1]|0;b[h+16362>>1]=b[801320+(l+2<<1)>>1]|0;b[h+16364>>1]=b[801320+(l+3<<1)>>1]|0;return}else if((g|0)==97144){g=b[h+16368>>1]|0;do{if((g&65535)>3){m=128}else{if((g&65535)>2){m=96;break}if((g<<16>>16|0)==1){m=32;break}else if((g<<16>>16|0)==2){m=64;break}else{m=0;break}}}while(0);g=(e[h+16366>>1]|0)+m|0;if((g|0)<128){b[h+16358>>1]=b[716048+(g<<1)>>1]|0;b[h+16360>>1]=b[716048+(g+1<<1)>>1]|0;b[h+16362>>1]=b[716048+(g+2<<1)>>1]|0;b[h+16364>>1]=b[716048+(g+3<<1)>>1]|0;return}else{b[h+16358>>1]=255;b[h+16360>>1]=255;b[h+16362>>1]=255;b[h+16364>>1]=255;return}}else{return}}else if((d|0)==16662528){a[c[3528706]|0]=f&2;a[c[3528814]|0]=(f&255)>>>2&1;a[c[2442894]|0]=f<<1&96^96;return}else{return}}function dRJ(a,d){a=a|0;d=d|0;var e=0,f=0,g=0,h=0;e=a-16744960|0;if(e>>>0<1152){b[(c[2387218]|0)+(a-16744448)>>1]=d;f=d&255;g=(d&65535)>>>8;h=(d&65535)>>>4;c[(c[3530036]|0)+(((e|0)/2|0)<<2)>>2]=((h&12|h<<4&255)&255)<<3&2016|((f&8|f<<4)&255)>>>3|((g&8|g<<4&255)&255)<<8&63488;return}if(!((a|0)==16678912|(a|0)==16678914)){return}b[(c[2443474]|0)+(a&2)>>1]=d;return}function dRK(b){b=b|0;var c=0;switch(b|0){case 16662530:case 16662531:{c=(e[4774916]|0)>>>((b<<3&8^8)>>>0)&255;return c|0};case 16662532:case 16662533:{c=a[9657976+(b&1^1)|0]|0;return c|0};case 16662528:case 16662529:{c=(e[4775004]|0)>>>((b<<3&8^8)>>>0)&255;return c|0};default:{c=0;return c|0}}return 0}function dRL(a){a=a|0;var c=0;if((a|0)==16662532){c=(d[9657977]|0)<<8|(d[9657976]|0)}else if((a|0)==16662530){c=b[4774916]|0}else if((a|0)==16662528){c=b[4775004]|0}else{c=0}return c|0}function dRM(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=b&65535;if((e|0)==32769){lS(0,1,d);return}else if((e|0)==40961){lS(1,1,d);return}else if((e|0)==40960){b=c[3541518]|0;f=b+19280|0;a[b+19328|0]=d;g=d&255;if((d&255)<16){c[14168912+(((c[2383582]|0)+1|0)*252|0)>>2]=g&15}if((d-45&255)>=3){return}if((g|0)==45){h=b+19336|0;i=a[h]|2;a[h]=i;j=i}else if((g|0)==47){a[b+19336|0]=0;j=0}else if((g|0)==0){a[b+19336|0]=2;j=2}else if((g|0)==46){g=b+19336|0;i=a[g]|1;a[g]=i;j=i}else{j=a[b+19336|0]|0}b=j&3;j=c[7461744+(b<<2)>>2]|0;lI(f,j,j,c[7461728+(b<<2)>>2]|0);return}else if((e|0)==32768){e=c[3541518]|0;b=e+256|0;a[e+304|0]=d;j=d&255;if((d&255)<16){c[14168912+((c[2383582]|0)*252|0)>>2]=j&15}if((d-45&255)>=3){return}if((j|0)==0){a[e+312|0]=2;k=2}else if((j|0)==47){a[e+312|0]=0;k=0}else if((j|0)==46){d=e+312|0;f=a[d]|1;a[d]=f;k=f}else if((j|0)==45){j=e+312|0;f=a[j]|2;a[j]=f;k=f}else{k=a[e+312|0]|0}e=k&3;k=c[7461744+(e<<2)>>2]|0;lI(b,k,k,c[7461728+(e<<2)>>2]|0);return}else{return}}function dRN(b,d){b=b|0;d=d|0;if((b&255)!=127){return}a[c[2443724]|0]=d;return}function dRO(b){b=b|0;var d=0,e=0,f=0.0,g=0.0,i=0;d=b&65535;if((d|0)==40960){b=c[3541518]|0;e=b+19320|0;f=+h[e>>3];do{if(f!=0.0){g=+h[6675];if(f-(g+ +gC[c[2429842]&255]())<=0.0){h[e>>3]=0.0;break}i=a[b+19331|0]|-128;return i|0}}while(0);i=a[b+19331|0]|0;return i|0}else if((d|0)==57344){i=a[c[3528286]|0]|0;return i|0}else if((d|0)==32768){d=c[3541518]|0;b=d+296|0;f=+h[b>>3];do{if(f!=0.0){g=+h[6675];if(f-(g+ +gC[c[2429842]&255]())<=0.0){h[b>>3]=0.0;break}i=a[d+307|0]|-128;return i|0}}while(0);i=a[d+307|0]|0;return i|0}else{i=0;return i|0}return 0}function dRP(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if((a&255)!=1){return}if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];a=c[3532592]|0;if((a|0)!=0){gGC(9104152,a|0,280)|0}c[2113054]=c[2113060]}a=b&255;c[2415540]=a>>>7;c[2415126]=9662152;if((c[2415542]|0)==4){d=a&15}else{d=a<<1&14}c[2415538]=d;c[2415126]=9662152;d=(c[2415541]|0)!=0;a=c[2415539]|0;if(d|(a|0)==1){e=a}else{c[2415539]=1;e=1}c[2415126]=9662152;if(d|(e|0)==0){f=0}else{c[2415539]=0;UC(0);f=c[2394]|0}e=c[14130368+(f<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(f<<2)>>2]=c[2113054];c[2394]=-1;return}function dRQ(b){b=b|0;var d=0;if((b&255)!=0){d=0;return d|0}d=a[c[2443724]|0]|0;return d|0}function dRR(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2144764+(b*112|0)>>2];c[a+104>>2]=c[2144768+(b*112|0)>>2];c[a+108>>2]=c[2144772+(b*112|0)>>2];d=0;return d|0}function dRS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=2144664+(b*112|0);e=0;return e|0}function dRT(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1179016+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dRU(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>46){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3310032+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dRV(){return dSc(4932)|0}function dRW(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=c[3541518]|0;if((b|0)!=0){gGr(b|0);c[3541518]=0}if((c[2385508]|0)>0){c[2113008]=0;c[2076598]=0;c[2383582]=0}c[2438228]=0;c[2433526]=0;c[2406676]=0;c[3528472]=0;b=c[2406680]|0;if((b|0)!=0){gGr(b);c[2406680]=0}c[2385508]=0;c[2432978]=0;a[64240]=0;do{if(a[638584]|0){c[2415126]=9662152;b=c[2408988]|0;if((b|0)!=0){gGz(9662152,0,3224);d=b;b=0;while(1){if((b|0)>=1024){break}e=9638528+(b<<2)|0;if((c[e>>2]|0)==(d|0)){f=21336;break}else{b=b+1|0}}if((f|0)==21336){gGr(d);c[e>>2]=0}c[2408988]=0}c[2415126]=9665376;b=c[2408989]|0;if((b|0)==0){break}gGz(9665376,0,3224);g=b;b=0;while(1){if((b|0)>=1024){break}h=9638528+(b<<2)|0;if((c[h>>2]|0)==(g|0)){f=21342;break}else{b=b+1|0}}if((f|0)==21342){gGr(g);c[h>>2]=0}c[2408989]=0}}while(0);c[2113070]=0;c[2113068]=0;h=c[2112926]|0;if((h|0)!=0){gGr(h);c[2112926]=0}if((c[2392]|0)>=0){h=0;do{e=14130368+(h<<2)|0;b=c[e>>2]|0;if((b|0)!=0){gGr(b);c[e>>2]=0}e=14130384+(h<<2)|0;b=c[e>>2]|0;if((b|0)!=0){gGr(b);c[e>>2]=0}h=h+1|0;}while((h|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;fwZ();h=c[2414986]|0;e=0;while(1){if((e|0)>=1024){f=21357;break}i=9638528+(e<<2)|0;if((c[i>>2]|0)==(h|0)){break}else{e=e+1|0}}if((f|0)==21357){c[2414986]=0;a[638656]=0;a[638584]=0;return 0}gGr(h);c[i>>2]=0;c[2414986]=0;a[638656]=0;a[638584]=0;return 0}function dRX(){var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;e=i;i=i+272|0;f=e|0;if((a[9624344]|0)!=0){dSi()}b[4775004]=-1;b[4774916]=-1;g=0;h=-1;j=-1;do{h=((a[9633720+g|0]&1)<<g^h&65535)&65535;j=((a[9631536+g|0]&1)<<g^j&65535)&65535;g=g+1|0;}while((g|0)<16);b[4775004]=h;b[4774916]=d[c[2442894]|0]<<8|j;j=c[2392]|0;if((j|0)>=0){gGz(8452240,0,((j|0)>0?(j<<2)+4|0:4)|0)}c[2113054]=0;j=c[2385548]|0;if((j|0)>0){gGz(9752472,0,((j|0)>1?j<<2:4)|0)}c[2433530]=0;if(a[638584]|0){c[2415126]=9662152;j=c[2415557]|0;h=j&3;if((h|0)==3){k=133}else{k=(1e7/(1e7/((c[2415554]|0)/(c[600992+((j>>>3&1)<<4)+(h<<2)>>2]|0)|0|0)|0|0)|0|0)/((c[2424]|0)/100|0|0)|0}h=0;while(1){j=h+1|0;c[f+(h<<2)>>2]=(ag(j,k)|0)/68|0;if((j|0)<67){h=j}else{l=k;break}}}else{l=10}k=l-1|0;h=0;j=0;g=0;L28325:while(1){m=h;n=j;while(1){if((m|0)>=(l|0)){break L28325}if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];o=c[3532592]|0;if((o|0)!=0){gGC(9104152,o|0,280)|0}c[2113054]=c[2113060]}p=m+1|0;o=((p*166666|0|0)/(l|0)|0)-n|0;c[2113056]=o;q=RG(o)|0;c[2113054]=(c[2113054]|0)+q;c[2276108]=-1;c[2113056]=-1;r=q+n|0;do{if((m|0)==(k|0)){c[8452200+(c[2394]<<2)>>2]=8194;c[2276080]=512;if((c[2276079]|0)>>>0>=512){break}RH(2)}}while(0);if(a[638584]|0){UD()}q=c[2394]|0;o=c[14130368+(q<<2)>>2]|0;if((o|0)!=0){gGC(o|0,9104152,280)|0}c[8452240+(q<<2)>>2]=c[2113054];c[2394]=-1;q=c[2439330]|0;if((q|0)!=0){o=q;gGC(9706056,o|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;Sb(ag(59659/(l|0)|0,m)|0);o=c[1836236]|0;q=c[9757320+(o<<2)>>2]|0;if((q|0)!=0){s=q;gGC(s|0,9706056,76)|0}c[9752472+(o<<2)>>2]=c[2433530];c[14113936+(o<<2)>>2]=c[2076596];c[9669104+(o<<2)>>2]=c[3541536];c[1836236]=-1;if(a[638584]|0){break}else{m=p;n=r}}n=c[2439331]|0;if((n|0)!=0){o=n;gGC(9706056,o|0,76)|0}b[4853030]=c[2426515]&65535;o=c[2438119]|0;c[2433530]=o;c[2076596]=c[3528485];c[3541536]=c[2417277];c[1836236]=1;s=((p*59659|0|0)/(l|0)|0)-g|0;do{if((s|0)<1){t=0;u=o}else{if((a[n+4188|0]|0)==0){q=gfc(s)|0;v=(c[2433530]|0)+q|0;c[2433530]=v;t=q;u=v;break}else{v=o+s|0;c[2433530]=v;t=s;u=v;break}}}while(0);s=t+g|0;o=0;n=u;while(1){if((m|0)==(c[f+(o<<2)>>2]|0)){a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0;if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){v=gfc(1e3)|0;w=v;x=(c[2433530]|0)+v|0}else{w=1e3;x=(c[2433530]|0)+1e3|0}c[2433530]=x;y=w+s|0;z=x}else{y=s;z=n}v=o+1|0;if((v|0)<67){s=y;o=v;n=z}else{break}}n=c[1836236]|0;o=c[9757320+(n<<2)>>2]|0;if((o|0)!=0){s=o;gGC(s|0,9706056,76)|0}c[9752472+(n<<2)>>2]=z;c[14113936+(n<<2)>>2]=c[2076596];c[9669104+(n<<2)>>2]=c[3541536];c[1836236]=-1;h=p;j=r;g=y}y=c[2439330]|0;if((y|0)!=0){g=y;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;g=c[2438228]|0;y=gGS(-1597636608,28447,g,(g|0)<0|0?-1:0)|0;g=y;Sb(59659);y=c[2443830]|0;if((y|0)<1073676288){c[2443830]=y-g}y=c[2443831]|0;if((y|0)<1073676288){c[2443831]=y-g}y=(c[3528512]|0)-g|0;c[3528512]=(y|0)<0?0:y;y=c[2112964]|0;do{if((y|0)!=0){gg[c[3542122]&4095](y,a[9688]|0?534:0);if(!(a[638584]|0)){break}if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060]}Uz(0,c[2112964]|0,a[9688]|0?534:0);g=c[2394]|0;r=c[14130368+(g<<2)>>2]|0;if((r|0)!=0){gGC(r|0,9104152,280)|0}c[8452240+(g<<2)>>2]=c[2113054];c[2394]=-1}}while(0);y=c[1836236]|0;g=c[9757320+(y<<2)>>2]|0;if((g|0)!=0){r=g;gGC(r|0,9706056,76)|0}c[9752472+(y<<2)>>2]=c[2433530];c[14113936+(y<<2)>>2]=c[2076596];c[9669104+(y<<2)>>2]=c[3541536];c[1836236]=-1;if((c[2112968]|0)==0){A=c[2386570]|0;B=c[2386472]|0;gGC(A|0,B|0,1280)|0;i=e;return 0}dRY()|0;A=c[2386570]|0;B=c[2386472]|0;gGC(A|0,B|0,1280)|0;i=e;return 0}function dRY(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;if((a[9547536]|0)!=0){d=c[2387218]|0;f=c[3530036]|0;g=0;do{h=b[d+(g+512)>>1]|0;i=h&255;j=(h&65535)>>>8;k=(h&65535)>>>4;c[f+(((g|0)/2|0)<<2)>>2]=((k&12|k<<4&255)&255)<<3&2016|((i&8|i<<4)&255)>>>3|((j&8|j<<4&255)&255)<<8&63488;g=g+2|0;}while((g|0)<1152)}g=c[2112926]|0;gGz(g|0,0,ag(c[2113068]<<1,c[2113070]|0)|0);dSm(0);f=c[2386570]|0;d=c[3528706]|0;j=c[3530438]|0;i=636;do{k=b[f+(i<<1)>>1]|0;h=k&65535;do{if(k<<16>>16!=4095){l=e[f+((i|1)<<1)>>1]|0;m=e[f+((i|2)<<1)>>1]|0;n=m&511;o=e[f+((i|3)<<1)>>1]|0;p=o&511;q=l&2;r=l&1;s=l>>>2&15;l=p>>>0>256?o|-512:p;p=n>>>0>256?m|-512:n;if((a[d]|0)==0){t=r;u=q;v=l;w=p}else{t=r^1;u=q>>>1^1;v=240-l|0;w=240-p|0}p=240-w-16|0;l=(u|0)!=0;if((t|0)==0){if(l){SJ(g,h,v,p,s,4,15,256,j);break}else{SH(g,h,v,p,s,4,15,256,j);break}}else{if(l){SN(g,h,v,p,s,4,15,256,j);break}else{SL(g,h,v,p,s,4,15,256,j);break}}}}while(0);i=i-4|0;}while((i|0)>-1);dSm(1);i=c[2386222]|0;j=c[3530856]|0;v=64;do{t=v<<3&248;u=v>>5<<3;w=e[i+(v<<1)>>1]|0;f=w>>>8;h=f<<2&768|w&255|f<<5&1024;do{if((h|0)!=1024){w=f&15;k=f&16;if((a[d]|0)==0){if((k|0)==0){Sr(g,h,t,u-16|0,w,2,3,512,j);break}else{St(g,h,t-16|0,u,w,2,3,512,j);break}}else{s=t^248;p=(u^248)-16|0;if((k|0)==0){Sx(g,h,s,p,w,2,3,512,j);break}else{Sv(g,h,s,p,w,2,3,512,j);break}}}}while(0);v=v+1|0;}while((v|0)<960);R8(c[3530036]|0);return 0}function dRZ(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=i;i=i+64|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;if((d|0)!=0){c[d>>2]=169624}if((b&32|0)!=0){gGz(j|0,0,12);k=c[2414690]|0;c[j>>2]=k;c[j+4>>2]=(c[2411704]|0)-k;c[j+12>>2]=162152;k=c[2076592]|0;gj[k&4095](j)|0}if((b&64|0)==0){i=e;return 0}j=h|0;gGz(g|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){k=h+9|0;h=f;l=f|0;m=f+4|0;n=f+12|0;o=g|0;p=g+4|0;q=g+12|0;r=0;do{gGC(j|0,614896,11)|0;a[k]=r+48&255;s=8452256+(r<<2)|0;gGz(h|0,0,12);c[l>>2]=s;c[m>>2]=4;c[n>>2]=164976;gj[c[2076592]&4095](f)|0;if((c[s>>2]|0)!=0){c[o>>2]=c[14130368+(r<<2)>>2];c[p>>2]=c[8452184+(r<<2)>>2];c[q>>2]=j;s=c[2076592]|0;gj[s&4095](g)|0}r=r+1|0;}while((r|0)<=(c[2392]|0))}fw$(b);Vx(b,d);i=e;return 0}function dR_(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2130284+(b*112|0)>>2];c[a+104>>2]=c[2130288+(b*112|0)>>2];c[a+108>>2]=c[2130292+(b*112|0)>>2];d=0;return d|0}function dR$(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=2130184+(b*112|0);e=0;return e|0}function dR0(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>47){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3298016+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dR1(){a[638584]=1;return dSc(4932)|0}function dR2(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2142412+(b*112|0)>>2];c[a+104>>2]=c[2142416+(b*112|0)>>2];c[a+108>>2]=c[2142420+(b*112|0)>>2];d=0;return d|0}function dR3(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<21&(d|0)==0)){e=1;return e|0}c[a>>2]=2142312+(b*112|0);e=0;return e|0}function dR4(){return dSc(4066)|0}function dR5(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4717772+(b*112|0)>>2];c[a+104>>2]=c[4717776+(b*112|0)>>2];c[a+108>>2]=c[4717780+(b*112|0)>>2];d=0;return d|0}function dR6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=4717672+(b*112|0);e=0;return e|0}function dR7(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>47){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5421536+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dR8(){a[638656]=1;return dSc(2142)|0}function dR9(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2870020+(b*112|0)>>2];c[a+104>>2]=c[2870024+(b*112|0)>>2];c[a+108>>2]=c[2870028+(b*112|0)>>2];d=0;return d|0}function dSa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=2869920+(b*112|0);e=0;return e|0}function dSb(){return dSc(3308)|0}function dSc(e){e=e|0;var f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;c[2414986]=0;c[2388168]=0;c[2385934]=262144;c[2386660]=294912;c[3530856]=360448;c[3530620]=491520;c[3530438]=2588672;c[3530338]=3637248;c[3530036]=3670016;c[2443390]=3672320;c[2414690]=3672336;c[2388292]=3672336;c[2387218]=3688720;c[2386222]=3690768;c[2386472]=3692816;c[2386570]=3697936;c[2386088]=3699216;c[2443474]=3701264;c[3528286]=3701268;c[2443724]=3701269;c[3528706]=3701270;c[3528814]=3701271;c[2442894]=3701272;c[2411704]=3701273;f=0;while(1){if((f|0)>=1024){break}g=9638528+(f<<2)|0;if((c[g>>2]|0)==0){i=21538;break}else{f=f+1|0}}do{if((i|0)==21538){f=gGq(3701273)|0;c[g>>2]=f;if((f|0)==0){break}c[2414986]=f;gGz(f|0,0,3701273);c[2388168]=f;c[2385934]=f+262144;c[2386660]=f+294912;c[3530856]=f+360448;c[3530620]=f+491520;c[3530438]=f+2588672;c[3530338]=f+3637248;c[3530036]=f+3670016;c[2443390]=f+3672320;j=f+3672336|0;c[2414690]=j;c[2388292]=j;c[2387218]=f+3688720;c[2386222]=f+3690768;c[2386472]=f+3692816;c[2386570]=f+3697936;c[2386088]=f+3699216;c[2443474]=f+3701264;c[3528286]=f+3701268;c[2443724]=f+3701269;c[3528706]=f+3701270;c[3528814]=f+3701271;c[2442894]=f+3701272;j=f+3701273|0;c[2411704]=j;c[2414246]=j;if((gD[e&8191]()|0)==0){k=0}else{l=1;return l|0}while(1){if((k|0)>=1024){break}m=9638528+(k<<2)|0;if((c[m>>2]|0)==0){i=21543;break}else{k=k+1|0}}L28547:do{if((i|0)==21543){j=gGq(1048576)|0;c[m>>2]=j;if((j|0)==0){break}gGz(j|0,0,1048576);f=c[3530856]|0;gGC(j|0,f|0,32768)|0;n=0;do{o=n<<6;gGz(f+o|0,0,64);p=n<<7;q=p|4;r=0;while(1){s=q+(c[609168+(r<<2)>>2]|0)|0;t=(r<<3)+o|0;u=0;do{v=s+(c[610736+(u<<2)>>2]|0)|0;if(((d[j+((v|0)/8|0)|0]|0)&128>>>((v&7)>>>0)|0)!=0){v=f+(t+u)|0;a[v]=a[v]|2}u=u+1|0;}while((u|0)<8);u=r+1|0;if((u|0)<8){r=u}else{w=0;break}}do{r=p+(c[609168+(w<<2)>>2]|0)|0;q=(w<<3)+o|0;u=0;do{t=r+(c[610736+(u<<2)>>2]|0)|0;if(((d[j+((t|0)/8|0)|0]|0)&128>>>((t&7)>>>0)|0)!=0){t=f+(q+u)|0;a[t]=a[t]|1}u=u+1|0;}while((u|0)<8);w=w+1|0;}while((w|0)<8);n=n+1|0;}while((n|0)<2048);n=c[3530620]|0;gGC(j|0,n|0,1048576)|0;f=0;do{o=f<<10;gGz(n+o|0,0,1024);p=f<<11;u=0;do{q=1<<3-u;r=(c[611600+(u<<2)>>2]|0)+p|0;t=0;do{s=r+(c[609168+(t<<2)>>2]|0)|0;v=(t<<5)+o|0;x=0;do{y=s+(c[610736+(x<<2)>>2]|0)|0;if(((d[j+((y|0)/8|0)|0]|0)&128>>>((y&7)>>>0)|0)!=0){y=n+(v+x)|0;a[y]=(d[y]|0|q)&255}x=x+1|0;}while((x|0)<32);t=t+1|0;}while((t|0)<32);u=u+1|0;}while((u|0)<4);f=f+1|0;}while((f|0)<2048);f=c[3530438]|0;gGC(j|0,f|0,524288)|0;n=0;do{u=n<<8;gGz(f+u|0,0,256);o=0;do{p=1<<3-o;t=(c[704200+(o<<2)>>2]|0)+u|0;q=0;do{r=t+(c[609008+(q<<2)>>2]|0)|0;x=(q<<4)+u|0;v=0;do{s=r+(c[597864+(v<<2)>>2]|0)|0;if(((d[j+((s|0)/8|0)|0]|0)&128>>>((s&7)>>>0)|0)!=0){s=f+(x+v)|0;a[s]=(d[s]|0|p)&255}v=v+1|0;}while((v|0)<16);q=q+1|0;}while((q|0)<16);o=o+1|0;}while((o|0)<4);n=n+1|0;}while((n|0)<4096);n=c[2443390]|0;gGz(n|0,0,9);gGz(n+9|0,1,7);n=0;while(1){if((n|0)>=1024){break L28547}z=9638528+(n<<2)|0;if((c[z>>2]|0)==(j|0)){break}else{n=n+1|0}}gGr(j);c[z>>2]=0}}while(0);fxU(0,425984);if((c[2394]|0)==0){A=c[2112932]|0}else{c[2394]=0;n=c[3532596]|0;c[2112932]=n;f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];A=n}n=c[2388168]|0;f=A|0;o=0;while(1){u=n+o|0;c[f>>2]=u;c[f+131072>>2]=u;u=o+1024|0;if(u>>>0>262143){break}else{f=f+4|0;o=u}}o=c[2386472]|0;c[A+65032>>2]=o;c[A+130568>>2]=o;c[A+196104>>2]=o;f=o+1024|0;c[A+65036>>2]=f;c[A+130572>>2]=f;c[A+196108>>2]=f;f=o+2048|0;c[A+65040>>2]=f;c[A+130576>>2]=f;c[A+196112>>2]=f;f=o+3072|0;c[A+65044>>2]=f;c[A+130580>>2]=f;c[A+196116>>2]=f;f=o+4096|0;c[A+65048>>2]=f;c[A+130584>>2]=f;c[A+196120>>2]=f;f=c[2386222]|0;c[A+65216>>2]=f;c[A+130752>>2]=f;c[A+196288>>2]=f;o=f+1024|0;c[A+65220>>2]=o;c[A+130756>>2]=o;c[A+196292>>2]=o;o=c[2387218]|0;c[A+65408>>2]=o;c[A+196480>>2]=o;f=o+1024|0;c[A+65412>>2]=f;c[A+196484>>2]=f;f=c[2388292]|0;c[A+65472>>2]=f;c[A+131008>>2]=f;c[A+196544>>2]=f;o=f+1024|0;c[A+65476>>2]=o;c[A+131012>>2]=o;c[A+196548>>2]=o;o=f+2048|0;c[A+65480>>2]=o;c[A+131016>>2]=o;c[A+196552>>2]=o;o=f+3072|0;c[A+65484>>2]=o;c[A+131020>>2]=o;c[A+196556>>2]=o;o=f+4096|0;c[A+65488>>2]=o;c[A+131024>>2]=o;c[A+196560>>2]=o;o=f+5120|0;c[A+65492>>2]=o;c[A+131028>>2]=o;c[A+196564>>2]=o;o=f+6144|0;c[A+65496>>2]=o;c[A+131032>>2]=o;c[A+196568>>2]=o;o=f+7168|0;c[A+65500>>2]=o;c[A+131036>>2]=o;c[A+196572>>2]=o;o=f+8192|0;c[A+65504>>2]=o;c[A+131040>>2]=o;c[A+196576>>2]=o;o=f+9216|0;c[A+65508>>2]=o;c[A+131044>>2]=o;c[A+196580>>2]=o;o=f+10240|0;c[A+65512>>2]=o;c[A+131048>>2]=o;c[A+196584>>2]=o;o=f+11264|0;c[A+65516>>2]=o;c[A+131052>>2]=o;c[A+196588>>2]=o;o=f+12288|0;c[A+65520>>2]=o;c[A+131056>>2]=o;c[A+196592>>2]=o;o=f+13312|0;c[A+65524>>2]=o;c[A+131060>>2]=o;c[A+196596>>2]=o;o=f+14336|0;c[A+65528>>2]=o;c[A+131064>>2]=o;c[A+196600>>2]=o;o=f+15360|0;c[A+65532>>2]=o;c[A+131068>>2]=o;c[A+196604>>2]=o;c[A+196648>>2]=3210;c[A+196728>>2]=2944;c[A+196608>>2]=1158;c[A+196688>>2]=124;o=c[3532592]|0;if((o|0)!=0){gGC(o|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);o=c[2439330]|0;f=(o|0)==0;if(!f){n=o;gGC(9706056,n|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];n=c[3528484]|0;c[2076596]=n;u=c[2417276]|0;c[3541536]=u;c[1836236]=0;q=c[2385934]|0;p=0;t=0;while(1){c[o+76+(t<<2)>>2]=q+(t<<8);v=p+1&65535;if((v&65535)>127){B=0;C=0;break}else{p=v;t=v&65535}}while(1){t=q+(C<<8)|0;c[o+76+(C+512<<2)>>2]=t;c[o+76+(C+768<<2)>>2]=t;t=B+1&65535;if((t&65535)>127){break}else{B=t;C=t&65535}}q=c[2386088]|0;c[o+844>>2]=q;t=q+256|0;c[o+848>>2]=t;p=q+512|0;c[o+852>>2]=p;v=q+768|0;c[o+856>>2]=v;x=q+1024|0;c[o+860>>2]=x;r=q+1280|0;c[o+864>>2]=r;s=q+1536|0;c[o+868>>2]=s;y=q+1792|0;c[o+872>>2]=y;c[o+1868>>2]=q;c[o+1872>>2]=t;c[o+1876>>2]=p;c[o+1880>>2]=v;c[o+1884>>2]=x;c[o+1888>>2]=r;c[o+1892>>2]=s;c[o+1896>>2]=y;c[o+2892>>2]=q;c[o+3916>>2]=q;c[o+2896>>2]=t;c[o+3920>>2]=t;c[o+2900>>2]=p;c[o+3924>>2]=p;c[o+2904>>2]=v;c[o+3928>>2]=v;c[o+2908>>2]=x;c[o+3932>>2]=x;c[o+2912>>2]=r;c[o+3936>>2]=r;c[o+2916>>2]=s;c[o+3940>>2]=s;c[o+2920>>2]=y;c[o+3944>>2]=y;c[o+4184>>2]=608;c[o+4180>>2]=3178;c[o+4176>>2]=2932;if(!f){y=o;gGC(y|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=n;c[2417276]=u;c[1836236]=-1;if(a[638584]|0){fwR(1);y=c[2439331]|0;s=(y|0)==0;if(!s){r=y;gGC(9706056,r|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438119];r=c[3528485]|0;c[2076596]=r;x=c[2417277]|0;c[3541536]=x;c[1836236]=1;v=c[2386660]|0;p=0;t=0;while(1){c[y+76+(t<<2)>>2]=v+(t<<8);q=p+1&65535;if((q&65535)>255){D=0;E=0;break}else{p=q;t=q&65535}}while(1){t=v+(E<<8)|0;c[y+76+(E+512<<2)>>2]=t;c[y+76+(E+768<<2)>>2]=t;t=D+1&65535;if((t&65535)>255){break}else{D=t;E=t&65535}}c[y+4176>>2]=90;c[y+4172>>2]=1278;if(!s){v=y;gGC(v|0,9706056,76)|0}c[2438119]=c[2433530];c[3528485]=r;c[2417277]=x;c[1836236]=-1}Vr(2,3579545,786,3562,130,0);c[2438228]=3579545;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=571;h[745419]=.25;a[3203368]=1;h[745418]=.25;a[3203360]=1;h[745417]=.25;a[3203352]=1;h[745416]=.25;a[3203344]=1;h[745415]=.25;a[3203336]=1;h[745414]=.25;a[3203328]=1;h[745413]=.25;a[3203320]=1;h[745412]=.25;a[3203312]=1;if(a[638584]|0){UB(0,1910,384e3,0,7);c[2415126]=9662152;h[1207773]=1.0;c[2415548]=3}v=c[642608+(c[2436]<<2)>>2]|0;t=c[v+128>>2]|0;if((c[v+52>>2]&4|0)==0){c[2113068]=t;p=c[v+132>>2]|0;c[2113070]=p;c[2443814]=t;c[2440436]=p;F=t;G=p}else{c[2113070]=t;p=c[v+132>>2]|0;c[2113068]=p;c[2440436]=t;c[2443814]=p;F=p;G=t}t=ag(F<<1,G)|0;p=gGq(t)|0;c[2112926]=p;if((p|0)!=0){gGz(p|0,0,t|0)}dSi();l=0;return l|0}}while(0);c[2414986]=0;l=1;return l|0}function dSd(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;a=i;i=i+720|0;b=a|0;d=a+112|0;e=a+120|0;f=a+232|0;g=a+240|0;h=a+352|0;j=a+360|0;k=a+472|0;l=a+480|0;m=a+592|0;n=a+600|0;o=a+712|0;if((R6((c[2388168]|0)+1|0,0,2)|0)!=0){p=1;i=a;return p|0}if((R6(c[2388168]|0,1,2)|0)!=0){p=1;i=a;return p|0}if((R6((c[2388168]|0)+131073|0,2,2)|0)!=0){p=1;i=a;return p|0}if((R6((c[2388168]|0)+131072|0,3,2)|0)!=0){p=1;i=a;return p|0}q=c[2385934]|0;if((c[3542200]|0)==0){p=1;i=a;return p|0}r=n+108|0;c[r>>2]=0;s=n+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,4)|0;do{if((c[r>>2]|0)!=0){n=c[s>>2]|0;c[o>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](o,4,0)|0;if((n|0)<1){p=1;i=a;return p|0}if((gzL(q,0,4)|0)==0){break}else{p=1}i=a;return p|0}}while(0);q=c[3530856]|0;if((c[3542200]|0)==0){p=1;i=a;return p|0}o=l+108|0;c[o>>2]=0;s=l+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,5)|0;do{if((c[o>>2]|0)!=0){l=c[s>>2]|0;c[m>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](m,5,0)|0;if((l|0)<1){p=1;i=a;return p|0}if((gzL(q,0,5)|0)==0){break}else{p=1}i=a;return p|0}}while(0);q=j+108|0;m=j+100|0;s=g+108|0;o=g+100|0;l=0;while(1){r=l<<16;n=(c[3530620]|0)+r|0;t=l+6|0;if((c[3542200]|0)==0){p=1;u=21661;break}c[q>>2]=0;c[m>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,t)|0;if((c[q>>2]|0)!=0){v=c[m>>2]|0;c[k>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](k,t,0)|0;if((v|0)<1){p=1;u=21662;break}if((gzL(n,0,t)|0)!=0){p=1;u=21663;break}}t=(c[3530620]|0)+(r+524288)|0;r=l+9|0;if((c[3542200]|0)==0){p=1;u=21664;break}c[s>>2]=0;c[o>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,r)|0;if((c[s>>2]|0)!=0){n=c[o>>2]|0;c[h>>2]=9534384;v=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[v&16383](h,r,0)|0;if((n|0)<1){p=1;u=21665;break}if((gzL(t,0,r)|0)!=0){p=1;u=21666;break}}r=l+1|0;if((r|0)<3){l=r}else{u=21631;break}}if((u|0)==21664){i=a;return p|0}else if((u|0)==21665){i=a;return p|0}else if((u|0)==21661){i=a;return p|0}else if((u|0)==21662){i=a;return p|0}else if((u|0)==21663){i=a;return p|0}else if((u|0)==21666){i=a;return p|0}else if((u|0)==21631){l=e+108|0;h=e+100|0;o=0;while(1){s=(c[3530438]|0)+(o<<17)|0;g=o+12|0;if((c[3542200]|0)==0){p=1;u=21667;break}c[l>>2]=0;c[h>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,g)|0;if((c[l>>2]|0)!=0){k=c[h>>2]|0;c[f>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](f,g,0)|0;if((k|0)<1){p=1;u=21668;break}if((gzL(s,0,g)|0)!=0){p=1;u=21669;break}}g=o+1|0;if((g|0)<4){o=g}else{u=21646;break}}if((u|0)==21669){i=a;return p|0}else if((u|0)==21668){i=a;return p|0}else if((u|0)==21667){i=a;return p|0}else if((u|0)==21646){u=c[3530338]|0;if((c[3542200]|0)==0){p=1;i=a;return p|0}o=b+108|0;c[o>>2]=0;f=b+100|0;c[f>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](b,16)|0;if((c[o>>2]|0)==0){p=0;i=a;return p|0}o=c[f>>2]|0;c[d>>2]=9534384;gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](d,16,0)|0;if((o|0)<1){p=1;i=a;return p|0}p=(gzL(u,0,16)|0)!=0|0;i=a;return p|0}}return 0}function dSe(b,c){b=b|0;c=c|0;a[9706117]=c&1;return}function dSf(a){a=a|0;var b=0,d=0;b=(c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,3579545,0)|0;return a|0}function dSg(){return+(+((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)/3579545.0)}function dSh(a){a=a|0;var b=0.0;b=+(a|0)*+((c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0)/1.0e7;+V(b)>=1.0?b>0.0?(al(+U(b/4294967296.0),4294967295.0)|0)>>>0:~~+af((b- +(~~b>>>0))/4294967296.0)>>>0:0;return~~b>>>0|0}function dSi(){var b=0,d=0,e=0,f=0,g=0;a[9624344]=0;b=c[2414690]|0;gGz(b|0,0,(c[2411704]|0)-b|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];b=c[3532592]|0;if((b|0)!=0){gGC(9104152,b|0,280)|0}c[2113054]=c[2113060]}RI();b=c[2394]|0;d=c[14130368+(b<<2)>>2]|0;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[8452240+(b<<2)>>2]=c[2113054];c[2394]=-1;b=c[2439330]|0;d=(b|0)==0;if(!d){e=b;gGC(9706056,e|0,76)|0}e=c[2438118]|0;c[2433530]=e;f=c[3528484]|0;c[2076596]=f;g=c[2417276]|0;c[3541536]=g;c[1836236]=0;gGz(9706056,0,76);if(!d){d=b;gGC(d|0,9706056,76)|0}c[2438118]=e;c[3528484]=f;c[2417276]=g;c[1836236]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){g=0;do{lN(g);mB(g);g=g+1|0;}while((g|0)<(c[2385508]|0))}if(a[638584]|0){g=c[2439331]|0;f=(g|0)==0;if(!f){e=g;gGC(9706056,e|0,76)|0}e=c[2438119]|0;c[2433530]=e;d=c[3528485]|0;c[2076596]=d;b=c[2417277]|0;c[3541536]=b;c[1836236]=1;gGz(9706056,0,76);if(!f){f=g;gGC(f|0,9706056,76)|0}c[2438119]=e;c[3528485]=d;c[2417277]=b;c[1836236]=-1;UA()}b=c[2112964]|0;if((b|0)==0){return}gGz(b|0,0,(a[9688]|0?534:0)|0);return}function dSj(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;a=i;i=i+720|0;b=a|0;d=a+112|0;e=a+120|0;f=a+232|0;g=a+240|0;h=a+352|0;j=a+360|0;k=a+472|0;l=a+480|0;m=a+592|0;n=a+600|0;o=a+712|0;if((R6((c[2388168]|0)+1|0,0,2)|0)!=0){p=1;i=a;return p|0}if((R6(c[2388168]|0,1,2)|0)!=0){p=1;i=a;return p|0}q=c[2385934]|0;if((c[3542200]|0)==0){p=1;i=a;return p|0}r=n+108|0;c[r>>2]=0;s=n+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,2)|0;do{if((c[r>>2]|0)!=0){n=c[s>>2]|0;c[o>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](o,2,0)|0;if((n|0)<1){p=1;i=a;return p|0}if((gzL(q,0,2)|0)==0){break}else{p=1}i=a;return p|0}}while(0);q=c[3530856]|0;if((c[3542200]|0)==0){p=1;i=a;return p|0}o=l+108|0;c[o>>2]=0;s=l+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,3)|0;do{if((c[o>>2]|0)!=0){l=c[s>>2]|0;c[m>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](m,3,0)|0;if((l|0)<1){p=1;i=a;return p|0}if((gzL(q,0,3)|0)==0){break}else{p=1}i=a;return p|0}}while(0);q=j+108|0;m=j+100|0;s=g+108|0;o=g+100|0;l=0;while(1){r=l<<16;n=(c[3530620]|0)+r|0;t=l+4|0;if((c[3542200]|0)==0){p=1;u=21747;break}c[q>>2]=0;c[m>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,t)|0;if((c[q>>2]|0)!=0){v=c[m>>2]|0;c[k>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](k,t,0)|0;if((v|0)<1){p=1;u=21741;break}if((gzL(n,0,t)|0)!=0){p=1;u=21734;break}}t=(c[3530620]|0)+(r+524288)|0;r=l+7|0;if((c[3542200]|0)==0){p=1;u=21739;break}c[s>>2]=0;c[o>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,r)|0;if((c[s>>2]|0)!=0){n=c[o>>2]|0;c[h>>2]=9534384;v=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[v&16383](h,r,0)|0;if((n|0)<1){p=1;u=21751;break}if((gzL(t,0,r)|0)!=0){p=1;u=21749;break}}r=l+1|0;if((r|0)<3){l=r}else{u=21712;break}}if((u|0)==21741){i=a;return p|0}else if((u|0)==21749){i=a;return p|0}else if((u|0)==21751){i=a;return p|0}else if((u|0)==21747){i=a;return p|0}else if((u|0)==21734){i=a;return p|0}else if((u|0)==21739){i=a;return p|0}else if((u|0)==21712){l=e+108|0;h=e+100|0;o=0;while(1){s=(c[3530438]|0)+(o<<17)|0;g=o+10|0;if((c[3542200]|0)==0){p=1;u=21740;break}c[l>>2]=0;c[h>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,g)|0;if((c[l>>2]|0)!=0){k=c[h>>2]|0;c[f>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](f,g,0)|0;if((k|0)<1){p=1;u=21744;break}if((gzL(s,0,g)|0)!=0){p=1;u=21750;break}}g=o+1|0;if((g|0)<4){o=g}else{u=21727;break}}if((u|0)==21750){i=a;return p|0}else if((u|0)==21727){o=c[3530338]|0;if((c[3542200]|0)==0){p=1;i=a;return p|0}f=b+108|0;c[f>>2]=0;h=b+100|0;c[h>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](b,14)|0;if((c[f>>2]|0)==0){p=0;i=a;return p|0}f=c[h>>2]|0;c[d>>2]=9534384;gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](d,14,0)|0;if((f|0)<1){p=1;i=a;return p|0}p=(gzL(o,0,14)|0)!=0|0;i=a;return p|0}else if((u|0)==21740){i=a;return p|0}else if((u|0)==21744){i=a;return p|0}}return 0}function dSk(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;a=i;i=i+720|0;b=a|0;d=a+112|0;e=a+120|0;f=a+232|0;g=a+240|0;h=a+352|0;j=a+360|0;k=a+472|0;l=a+480|0;m=a+592|0;n=a+600|0;o=a+712|0;if((R6((c[2388168]|0)+1|0,0,2)|0)!=0){p=1;i=a;return p|0}if((R6(c[2388168]|0,1,2)|0)!=0){p=1;i=a;return p|0}if((R6((c[2388168]|0)+131073|0,2,2)|0)!=0){p=1;i=a;return p|0}if((R6((c[2388168]|0)+131072|0,3,2)|0)!=0){p=1;i=a;return p|0}q=c[2385934]|0;if((c[3542200]|0)==0){p=1;i=a;return p|0}r=n+108|0;c[r>>2]=0;s=n+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,4)|0;do{if((c[r>>2]|0)!=0){n=c[s>>2]|0;c[o>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](o,4,0)|0;if((n|0)<1){p=1;i=a;return p|0}if((gzL(q,0,4)|0)==0){break}else{p=1}i=a;return p|0}}while(0);q=c[3530856]|0;if((c[3542200]|0)==0){p=1;i=a;return p|0}o=l+108|0;c[o>>2]=0;s=l+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,5)|0;do{if((c[o>>2]|0)!=0){l=c[s>>2]|0;c[m>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](m,5,0)|0;if((l|0)<1){p=1;i=a;return p|0}if((gzL(q,0,5)|0)==0){break}else{p=1}i=a;return p|0}}while(0);q=j+108|0;m=j+100|0;s=0;o=c[3530620]|0;while(1){l=o+(s<<17)|0;r=s+6|0;if((c[3542200]|0)==0){p=1;u=21796;break}c[q>>2]=0;c[m>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,r)|0;if((c[q>>2]|0)!=0){n=c[m>>2]|0;c[k>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](k,r,0)|0;if((n|0)<1){p=1;u=21798;break}if((gzL(l,0,r)|0)!=0){p=1;u=21805;break}}r=s+1|0;v=c[3530620]|0;if((r|0)<8){s=r;o=v}else{u=21771;break}}if((u|0)==21798){i=a;return p|0}else if((u|0)==21771){o=v+983040|0;if((c[3542200]|0)==0){p=1;i=a;return p|0}v=g+108|0;c[v>>2]=0;s=g+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,14)|0;do{if((c[v>>2]|0)!=0){g=c[s>>2]|0;c[h>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](h,14,0)|0;if((g|0)<1){p=1;i=a;return p|0}if((gzL(o,0,14)|0)==0){break}else{p=1}i=a;return p|0}}while(0);o=e+108|0;h=e+100|0;s=0;while(1){v=(c[3530438]|0)+(s<<17)|0;g=s+15|0;if((c[3542200]|0)==0){p=1;u=21793;break}c[o>>2]=0;c[h>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,g)|0;if((c[o>>2]|0)!=0){k=c[h>>2]|0;c[f>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](f,g,0)|0;if((k|0)<1){p=1;u=21794;break}if((gzL(v,0,g)|0)!=0){p=1;u=21799;break}}g=s+1|0;if((g|0)<4){s=g}else{u=21781;break}}if((u|0)==21799){i=a;return p|0}else if((u|0)==21793){i=a;return p|0}else if((u|0)==21794){i=a;return p|0}else if((u|0)==21781){s=c[3530338]|0;if((c[3542200]|0)==0){p=1;i=a;return p|0}f=b+108|0;c[f>>2]=0;h=b+100|0;c[h>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](b,19)|0;if((c[f>>2]|0)==0){p=0;i=a;return p|0}f=c[h>>2]|0;c[d>>2]=9534384;gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](d,19,0)|0;if((f|0)<1){p=1;i=a;return p|0}p=(gzL(s,0,19)|0)!=0|0;i=a;return p|0}}else if((u|0)==21796){i=a;return p|0}else if((u|0)==21805){i=a;return p|0}return 0}function dSl(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;b=i;i=i+720|0;d=b|0;e=b+112|0;f=b+120|0;g=b+232|0;h=b+240|0;j=b+352|0;k=b+360|0;l=b+472|0;m=b+480|0;n=b+592|0;o=b+600|0;p=b+712|0;if((R6((c[2388168]|0)+1|0,0,2)|0)!=0){q=1;i=b;return q|0}if((R6(c[2388168]|0,1,2)|0)!=0){q=1;i=b;return q|0}r=c[2385934]|0;if((c[3542200]|0)==0){q=1;i=b;return q|0}s=o+108|0;c[s>>2]=0;t=o+100|0;c[t>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](o,2)|0;do{if((c[s>>2]|0)!=0){o=c[t>>2]|0;c[p>>2]=9534384;u=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[u&16383](p,2,0)|0;if((o|0)<1){q=1;i=b;return q|0}if((gzL(r,0,2)|0)==0){break}else{q=1}i=b;return q|0}}while(0);r=c[3530856]|0;if((c[3542200]|0)==0){q=1;i=b;return q|0}p=m+108|0;c[p>>2]=0;t=m+100|0;c[t>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,3)|0;do{if((c[p>>2]|0)!=0){m=c[t>>2]|0;c[n>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](n,3,0)|0;if((m|0)<1){q=1;i=b;return q|0}if((gzL(r,0,3)|0)==0){break}else{q=1}i=b;return q|0}}while(0);r=k+108|0;n=k+100|0;t=0;while(1){p=(c[3530620]|0)+(t<<17)|0;m=t+4|0;if((c[3542200]|0)==0){q=1;v=21842;break}c[r>>2]=0;c[n>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,m)|0;if((c[r>>2]|0)!=0){s=c[n>>2]|0;c[l>>2]=9534384;o=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[o&16383](l,m,0)|0;if((s|0)<1){q=1;v=21860;break}if((gzL(p,0,m)|0)!=0){q=1;v=21853;break}}m=t+1|0;if((m|0)<8){t=m}else{v=21820;break}}if((v|0)==21820){t=h+108|0;l=h+100|0;n=0;while(1){r=(c[3530438]|0)+(n<<17)|0;k=n+12|0;if((c[3542200]|0)==0){q=1;v=21852;break}c[t>>2]=0;c[l>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](h,k)|0;if((c[t>>2]|0)!=0){m=c[l>>2]|0;c[j>>2]=9534384;p=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[p&16383](j,k,0)|0;if((m|0)<1){q=1;v=21857;break}if((gzL(r,0,k)|0)!=0){q=1;v=21862;break}}k=n+1|0;if((k|0)<4){n=k}else{v=21831;break}}if((v|0)==21852){i=b;return q|0}else if((v|0)==21831){n=c[3530338]|0;if((c[3542200]|0)==0){q=1;i=b;return q|0}j=f+108|0;c[j>>2]=0;l=f+100|0;c[l>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,16)|0;do{if((c[j>>2]|0)!=0){f=c[l>>2]|0;c[g>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](g,16,0)|0;if((f|0)<1){q=1;i=b;return q|0}if((gzL(n,0,16)|0)==0){break}else{q=1}i=b;return q|0}}while(0);if(!(a[638584]|0)){q=0;i=b;return q|0}n=c[2386660]|0;if((c[3542200]|0)==0){q=1;i=b;return q|0}g=d+108|0;c[g>>2]=0;l=d+100|0;c[l>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](d,18)|0;do{if((c[g>>2]|0)!=0){d=c[l>>2]|0;c[e>>2]=9534384;j=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[j&16383](e,18,0)|0;if((d|0)<1){q=1;i=b;return q|0}if((gzL(n,0,18)|0)==0){break}else{q=1}i=b;return q|0}}while(0);q=0;i=b;return q|0}else if((v|0)==21857){i=b;return q|0}else if((v|0)==21862){i=b;return q|0}}else if((v|0)==21853){i=b;return q|0}else if((v|0)==21842){i=b;return q|0}else if((v|0)==21860){i=b;return q|0}return 0}function dSm(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;g=c[2443474]|0;h=e[g>>1]|0;i=-256-(e[g+2>>1]|0)|0;g=h>>>5&127;j=i>>>5&127^127;k=(f|0)!=0;f=h&31;h=i&31;i=c[3530338]|0;l=c[3528814]|0;m=c[3528706]|0;n=c[3530620]|0;o=c[2112926]|0;p=c[2443390]|0;q=0;do{r=j-q|0;s=r<<4&112;t=r>>>3<<11;r=(q<<5)-h|0;u=224-r|0;v=0;do{w=v+g|0;x=(w<<1&14|s|w>>>3<<7)+t|0;w=d[i+(x|1)|0]|0;if(k){if((w&16|0)!=0){y=21868}}else{y=21868}L28996:do{if((y|0)==21868){y=0;z=d[i+x|0]|w<<2&768|d[l]<<10;A=w&15;B=w&32;C=(v<<5)-f|0;if((a[m]|0)==0){D=0;E=B;F=C;G=r}else{D=1;E=B^32;F=224-C|0;G=u}if(!k){C=(E|0)!=0;B=G-16|0;if((D|0)==0){if(C){SR(o,z,F,B,A,4,0,n);break}else{SP(o,z,F,B,A,4,0,n);break}}else{if(C){SV(o,z,F,B,A,4,0,n);break}else{ST(o,z,F,B,A,4,0,n);break}}}B=G-16|0;C=A<<4;A=n+(-D&992|z<<10)|0;z=(D|0)!=0?-32:32;H=c[2113070]|0;if((H|0)<=(B|0)){break}I=c[2113068]|0;if((E|0)==0){J=A;K=B;L=0;while(1){if((K|0)>-1){M=ag(I,K)|0;N=0;do{O=N+F|0;do{if((O|0)>-1&(O|0)<(I|0)){P=d[J+N|0]|0;if((a[p+P|0]|0)==0){break}b[o+(O+M<<1)>>1]=(P|C)&65535}}while(0);N=N+1|0;}while((N|0)<32)}N=L+1|0;M=K+1|0;if((N|0)<32&(M|0)<(H|0)){J=J+z|0;K=M;L=N}else{break L28996}}}else{Q=A;R=B;S=0}while(1){L29028:do{if((R|0)>-1){L=ag(I,R)|0;K=31;while(1){J=K+F|0;do{if((J|0)>-1&(J|0)<(I|0)){N=d[Q+(K^31)|0]|0;if((a[p+N|0]|0)==0){break}b[o+(J+L<<1)>>1]=(N|C)&65535}}while(0);if((K|0)<=0){break L29028}K=K-1|0}}}while(0);K=S+1|0;L=R+1|0;if((K|0)<32&(L|0)<(H|0)){Q=Q+z|0;R=L;S=K}else{break}}}}while(0);v=v+1|0;}while((v|0)<9);q=q+1|0;}while((q|0)<9);return}function dSn(b,d){b=b|0;d=d|0;var e=0,f=0;e=b&65535;switch(e|0){case 51203:case 51204:{b=d&255;if((e&1|0)!=0){c[3542291]=b&15;return}f=c[3542291]|0;if((f|0)>15){return}do{if((f|0)<14){if((f|0)!=13){if((a[14169168+f|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(1,f,b);return};case 51201:case 51202:{b=d&255;if((e&1|0)!=0){c[3542228]=b&15;return}e=c[3542228]|0;if((e|0)>15){return}do{if((e|0)<14){if((e|0)!=13){if((a[14168916+e|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(0,e,b);return};case 51200:{c[3528704]=(d&255)>>>7;return};default:{return}}}function dSo(b){b=b|0;var c=0;switch(b&65535|0){case 49154:{c=a[9629632]^a[9635192]^a[9629633]<<1^a[9629634]<<2^a[9629635]<<3^a[9629636]<<4^a[9629637]<<5^a[9629638]<<6^a[9629639]<<7;return c|0};case 49155:{c=a[9635193]|0;return c|0};case 49156:{c=a[9635194]|0;return c|0};case 49152:{c=a[9633713]<<1^~a[9633712]^a[9633714]<<2^a[9633715]<<3^a[9633716]<<4^a[9633717]<<5^a[9633718]<<6^a[9633719]<<7;return c|0};case 49153:{c=a[9631529]<<1^~a[9631528]^a[9631530]<<2^a[9631531]<<3^a[9631532]<<4^a[9631533]<<5^a[9631534]<<6^a[9631535]<<7;return c|0};default:{c=0;return c|0}}return 0}function dSp(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2765284+(b*112|0)>>2];c[a+104>>2]=c[2765288+(b*112|0)>>2];c[a+108>>2]=c[2765292+(b*112|0)>>2];d=0;return d|0}function dSq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=2765184+(b*112|0);e=0;return e|0}function dSr(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6929008+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dSs(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>49){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7437336+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dSt(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0.0,Z=0,_=0,$=0,aa=0;e=i;i=i+728|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;c[2426744]=0;c[2426606]=0;c[2424850]=65536;c[2424826]=98304;c[2424778]=131072;c[2406936]=131840;c[3530034]=133376;s=(a[9688]|0?141320:134912)|0;c[2414244]=s;t=s;s=0;while(1){if((s|0)>=1024){break}u=9638528+(s<<2)|0;if((c[u>>2]|0)==0){v=21967;break}else{s=s+1|0}}do{if((v|0)==21967){s=gGq(t)|0;c[u>>2]=s;if((s|0)==0){break}gGz(s|0,0,t|0);c[2426744]=s;gGz(s|0,0,t|0);c[2426606]=s;c[2424850]=s+65536;c[2424826]=s+98304;c[2424778]=s+131072;c[2406936]=s+131840;c[3530034]=s+133376;w=s+134912|0;c[2385364]=w;x=a[9688]|0?534:0;c[2414244]=s+((x*12|0)+134912);c[2439016]=w;c[2439017]=w+(x<<1);c[2439018]=w+(x<<1<<1);c[2439019]=w+((x*3|0)<<1);c[2439020]=w+(x<<2<<1);c[2439021]=w+((x*5|0)<<1);x=p+108|0;w=p+100|0;y=0;z=s;while(1){s=z+(y<<13)|0;if((c[3542200]|0)==0){A=1;v=22062;break}c[x>>2]=0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,y)|0;if((c[x>>2]|0)!=0){B=c[w>>2]|0;c[q>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](q,y,0)|0;if((B|0)<1){A=1;v=22078;break}if((gzL(s,0,y)|0)!=0){A=1;v=22065;break}}s=y+1|0;if((s|0)>=4){v=21976;break}y=s;z=c[2426606]|0}if((v|0)==21976){z=c[2424850]|0;if((c[3542200]|0)==0){A=1;i=e;return A|0}y=n+108|0;c[y>>2]=0;w=n+100|0;c[w>>2]=0;x=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[x&16383](n,4)|0;do{if((c[y>>2]|0)!=0){x=c[w>>2]|0;c[o>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](o,4,0)|0;if((x|0)<1){A=1;i=e;return A|0}if((gzL(z,0,4)|0)==0){break}else{A=1}i=e;return A|0}}while(0);z=c[2424826]|0;if((c[3542200]|0)==0){A=1;i=e;return A|0}w=l+108|0;c[w>>2]=0;y=l+100|0;c[y>>2]=0;x=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[x&16383](l,5)|0;do{if((c[w>>2]|0)!=0){x=c[y>>2]|0;c[m>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](m,5,0)|0;if((x|0)<1){A=1;i=e;return A|0}if((gzL(z,0,5)|0)==0){break}else{A=1}i=e;return A|0}}while(0);z=(c[2424826]|0)+8192|0;if((c[3542200]|0)==0){A=1;i=e;return A|0}y=j+108|0;c[y>>2]=0;w=j+100|0;c[w>>2]=0;x=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[x&16383](j,6)|0;do{if((c[y>>2]|0)!=0){x=c[w>>2]|0;c[k>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](k,6,0)|0;if((x|0)<1){A=1;i=e;return A|0}if((gzL(z,0,6)|0)==0){break}else{A=1}i=e;return A|0}}while(0);z=f+108|0;w=f+100|0;y=c[2424778]|0;if((c[3542200]|0)==0){A=1;i=e;return A|0}c[z>>2]=0;c[w>>2]=0;x=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[x&16383](f,7)|0;do{if((c[z>>2]|0)!=0){x=c[w>>2]|0;c[g>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](g,7,0)|0;if((x|0)<1){A=1;i=e;return A|0}if((gzL(y,0,7)|0)==0){break}else{A=1}i=e;return A|0}}while(0);y=(c[2424778]|0)+256|0;if((c[3542200]|0)==0){A=1;i=e;return A|0}c[z>>2]=0;c[w>>2]=0;x=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[x&16383](f,8)|0;do{if((c[z>>2]|0)!=0){x=c[w>>2]|0;c[g>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](g,8,0)|0;if((x|0)<1){A=1;i=e;return A|0}if((gzL(y,0,8)|0)==0){break}else{A=1}i=e;return A|0}}while(0);y=(c[2424778]|0)+512|0;if((c[3542200]|0)==0){A=1;i=e;return A|0}c[z>>2]=0;c[w>>2]=0;x=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[x&16383](f,9)|0;do{if((c[z>>2]|0)==0){D=0}else{x=c[w>>2]|0;c[g>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](g,9,0)|0;if((x|0)<1){A=1;i=e;return A|0}if((gzL(y,0,9)|0)==0){D=0;break}else{A=1}i=e;return A|0}}while(0);while(1){if((D|0)>=1024){A=1;v=22072;break}E=9638528+(D<<2)|0;if((c[E>>2]|0)==0){break}else{D=D+1|0}}if((v|0)==22072){i=e;return A|0}y=gGq(16384)|0;c[E>>2]=y;if((y|0)==0){A=1;i=e;return A|0}gGz(y|0,0,16384);w=c[2424850]|0;gGC(y|0,w|0,8192)|0;z=0;do{x=z<<6;gGz(w+x|0,0,64);s=z<<7;B=s|4;C=0;while(1){F=B+(c[608544+(C<<2)>>2]|0)|0;G=(C<<3)+x|0;H=0;do{I=F+(c[609552+(H<<2)>>2]|0)|0;if(((d[y+((I|0)/8|0)|0]|0)&128>>>((I&7)>>>0)|0)!=0){I=w+(G+H)|0;a[I]=a[I]|2}H=H+1|0;}while((H|0)<8);H=C+1|0;if((H|0)<8){C=H}else{J=0;break}}do{C=s+(c[608544+(J<<2)>>2]|0)|0;B=(J<<3)+x|0;H=0;do{G=C+(c[609552+(H<<2)>>2]|0)|0;if(((d[y+((G|0)/8|0)|0]|0)&128>>>((G&7)>>>0)|0)!=0){G=w+(B+H)|0;a[G]=a[G]|1}H=H+1|0;}while((H|0)<8);J=J+1|0;}while((J|0)<8);z=z+1|0;}while((z|0)<512);z=c[2424826]|0;gGC(y|0,z|0,16384)|0;w=0;while(1){x=w<<8;gGz(z+x|0,0,256);s=w<<9;H=0;do{B=1<<3-H;C=(c[611072+(H<<2)>>2]|0)+s|0;G=0;do{F=C+(c[608544+(G<<2)>>2]|0)|0;I=(G<<4)+x|0;K=0;do{L=F+(c[609552+(K<<2)>>2]|0)|0;if(((d[y+((L|0)/8|0)|0]|0)&128>>>((L&7)>>>0)|0)!=0){L=z+(I+K)|0;a[L]=(d[L]|0|B)&255}K=K+1|0;}while((K|0)<16);G=G+1|0;}while((G|0)<16);H=H+1|0;}while((H|0)<4);H=w+1|0;if((H|0)<128){w=H}else{M=0;break}}while(1){if((M|0)>=1024){break}N=9638528+(M<<2)|0;if((c[N>>2]|0)==(y|0)){v=22015;break}else{M=M+1|0}}if((v|0)==22015){gGr(y);c[N>>2]=0}w=c[2424778]|0;z=0;do{H=d[w+z|0]|0;c[r+(z<<2)>>2]=(-(H>>>3&1)&33)+(-(H>>>4&1)&71)+(-(H>>>5&1)&151)<<8|(-(H>>>6&1)&71)+(-(H>>>7)&151)|(-(H>>>1&1)&71)+(-(H&1)&33)+(-(H>>>2&1)&151)<<16;z=z+1|0;}while((z|0)<32);z=w+256|0;c[2424778]=z;y=c[2406936]|0;c[y>>2]=c[r+((a[z]&15)<<2)>>2];z=1;while(1){c[y+(z<<2)>>2]=c[r+((a[w+(z+256)|0]&15)<<2)>>2];H=z+1|0;if((H|0)<128){z=H}else{O=128;break}}do{c[y+(O<<2)>>2]=c[r+((a[w+(O+384)|0]&15|16)<<2)>>2];O=O+1|0;}while((O|0)<384);fwR(0);w=c[2439330]|0;if((w|0)!=0){y=w;gGC(9706056,y|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];y=c[3528484]|0;c[2076596]=y;z=c[2417276]|0;c[3541536]=z;c[1836236]=0;H=c[2426606]|0;x=0;s=0;while(1){c[w+76+(s<<2)>>2]=H+(s<<8);G=x+1&65535;if((G&65535)>127){P=0;Q=0;break}else{x=G;s=G&65535}}while(1){s=H+(Q<<8)|0;c[w+76+(Q+512<<2)>>2]=s;c[w+76+(Q+768<<2)>>2]=s;s=P+1&65535;if((s&65535)>127){break}else{P=s;Q=s&65535}}s=H+53248|0;c[w+908>>2]=s;x=H+53504|0;c[w+912>>2]=x;G=H+53760|0;c[w+916>>2]=G;B=H+54016|0;c[w+920>>2]=B;C=H+54272|0;c[w+924>>2]=C;K=H+54528|0;c[w+928>>2]=K;I=H+54784|0;c[w+932>>2]=I;F=H+55040|0;c[w+936>>2]=F;c[w+1932>>2]=s;c[w+1936>>2]=x;c[w+1940>>2]=G;c[w+1944>>2]=B;c[w+1948>>2]=C;c[w+1952>>2]=K;c[w+1956>>2]=I;c[w+1960>>2]=F;c[w+1964>>2]=H+55296;c[w+1968>>2]=H+55552;F=H+57344|0;c[w+972>>2]=F;I=H+57600|0;c[w+976>>2]=I;K=H+57856|0;c[w+980>>2]=K;C=H+58112|0;c[w+984>>2]=C;B=H+58368|0;c[w+988>>2]=B;G=H+58624|0;c[w+992>>2]=G;x=H+58880|0;c[w+996>>2]=x;s=H+59136|0;c[w+1e3>>2]=s;L=H+59392|0;c[w+1004>>2]=L;R=H+59648|0;c[w+1008>>2]=R;S=H+59904|0;c[w+1012>>2]=S;T=H+60160|0;c[w+1016>>2]=T;U=H+60416|0;c[w+1020>>2]=U;V=H+60672|0;c[w+1024>>2]=V;W=H+60928|0;c[w+1028>>2]=W;X=H+61184|0;c[w+1032>>2]=X;c[w+1996>>2]=F;c[w+2e3>>2]=I;c[w+2004>>2]=K;c[w+2008>>2]=C;c[w+2012>>2]=B;c[w+2016>>2]=G;c[w+2020>>2]=x;c[w+2024>>2]=s;c[w+2028>>2]=L;c[w+2032>>2]=R;c[w+2036>>2]=S;c[w+2040>>2]=T;c[w+2044>>2]=U;c[w+2048>>2]=V;c[w+2052>>2]=W;c[w+2056>>2]=X;X=224;W=224;while(1){V=H+(W<<8)|0;c[w+76+(W+512<<2)>>2]=V;c[w+76+(W+768<<2)>>2]=V;V=X+1&65535;if((V&65535)>239){break}else{X=V;W=V&65535}}c[w+4184>>2]=366;c[w+4180>>2]=3274;W=w;gGC(W|0,9706056,76)|0;c[2438118]=c[2433530];c[3528484]=y;c[2417276]=z;c[1836236]=-1;W=a[9680]|0?32e3:0;c[3542220]=11200;X=c[2113008]|0;if((X|0)==0){gGz(14168888,0,252);c[3542223]=W;gGz(14168896,0,16);c[3542234]=~~((+(W|0)*32768.0*8.0+75.0e4)/15.0e5);H=31;Y=32767.0;while(1){c[14169012+(H<<2)>>2]=~~(Y+.5);V=H-1|0;if((V|0)>0){H=V;Y=Y/1.188502227}else{break}}c[3542253]=0;h[1771269]=1.0;h[1771270]=1.0;h[1771271]=1.0;c[3542574]=3;c[3542575]=3;c[3542576]=3;mB(0);H=(c[2113008]|0)+1|0;c[2113008]=H;Z=H;_=a[9680]|0?32e3:0}else{Z=X;_=W}c[3542220]=11200;if((Z|0)==1){gGz(14169140,0,252);c[3542286]=_;gGz(14169148,0,16);c[3542297]=~~((+(_|0)*32768.0*8.0+75.0e4)/15.0e5);H=31;Y=32767.0;while(1){c[14169264+(H<<2)>>2]=~~(Y+.5);z=H-1|0;if((z|0)>0){H=z;Y=Y/1.188502227}else{break}}c[3542316]=0;h[1771272]=1.0;h[1771273]=1.0;h[1771274]=1.0;c[3542577]=3;c[3542578]=3;c[3542579]=3;mB(1);c[2113008]=(c[2113008]|0)+1}h[1771269]=.25;c[3542574]=3;h[1771270]=.25;c[3542575]=3;h[1771271]=.25;c[3542576]=3;h[1771272]=.25;c[3542577]=3;h[1771273]=.25;c[3542578]=3;h[1771274]=.25;c[3542579]=3;gGz((c[2426606]|0)+53248|0,0,8192);mB(0);mB(1);H=c[2439330]|0;W=(H|0)==0;if(!W){X=H;gGC(9706056,X|0,76)|0}X=c[2438118]|0;c[2433530]=X;z=c[3528484]|0;c[2076596]=z;y=c[2417276]|0;c[3541536]=y;c[1836236]=0;gGz(9706056,0,76);if(!W){W=H;gGC(W|0,9706056,76)|0}c[2438118]=X;c[3528484]=z;c[2417276]=y;c[1836236]=-1;c[3528704]=0;y=c[642608+(c[2436]<<2)>>2]|0;z=c[y+128>>2]|0;if((c[y+52>>2]&4|0)==0){c[2113068]=z;X=c[y+132>>2]|0;c[2113070]=X;c[2443814]=z;c[2440436]=X;$=z;aa=X}else{c[2113070]=z;X=c[y+132>>2]|0;c[2113068]=X;c[2440436]=z;c[2443814]=X;$=X;aa=z}z=ag($<<1,aa)|0;X=gGq(z)|0;c[2112926]=X;if((X|0)==0){A=0;i=e;return A|0}gGz(X|0,0,z|0);A=0;i=e;return A|0}else if((v|0)==22062){i=e;return A|0}else if((v|0)==22065){i=e;return A|0}else if((v|0)==22078){i=e;return A|0}}}while(0);c[2426744]=0;A=1;i=e;return A|0}function dSu(){var b=0,d=0,e=0,f=0;fwZ();c[2113008]=0;c[2076598]=0;c[2383582]=0;c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}b=c[2426744]|0;d=0;while(1){if((d|0)>=1024){break}e=9638528+(d<<2)|0;if((c[e>>2]|0)==(b|0)){f=22090;break}else{d=d+1|0}}if((f|0)==22090){gGr(b);c[e>>2]=0}c[2424778]=0;c[2424826]=0;c[2424850]=0;c[2426606]=0;c[2426744]=0;c[2406936]=0;c[3530034]=0;gGz(9756064,0,24);c[3528704]=0;a[9547528]=0;return 0}function dSv(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if((a[9624336]|0)==0){d=c[2439330]|0}else{gGz((c[2426606]|0)+53248|0,0,8192);mB(0);mB(1);e=c[2439330]|0;f=(e|0)==0;if(!f){g=e;gGC(9706056,g|0,76)|0}g=c[2438118]|0;c[2433530]=g;h=c[3528484]|0;c[2076596]=h;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);if(!f){f=e;gGC(f|0,9706056,76)|0}c[2438118]=g;c[3528484]=h;c[2417276]=i;c[1836236]=-1;c[3528704]=0;d=e}if((d|0)!=0){e=d;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;e=c[2438118]|0;c[2433530]=e;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;if((a[d+4188|0]|0)==0){d=gfc(33333)|0;j=(c[2433530]|0)+d|0}else{j=e+33333|0}c[2433530]=j;a[14125144]=-41;a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0;if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){j=gfc(33334)|0;k=(c[2433530]|0)+j|0}else{k=(c[2433530]|0)+33334|0}c[2433530]=k;a[14125144]=-49;a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0;k=c[1836236]|0;j=c[9757320+(k<<2)>>2]|0;if((j|0)!=0){e=j;gGC(e|0,9706056,76)|0}c[9752472+(k<<2)>>2]=c[2433530];c[14113936+(k<<2)>>2]=c[2076596];c[9669104+(k<<2)>>2]=c[3541536];c[1836236]=-1;k=c[2112964]|0;if((k|0)!=0){mF(9756064,k,a[9688]|0?534:0,0)}if((c[2112968]|0)==0){return 0}dSw()|0;return 0}function dSw(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if((a[9547528]|0)!=0){b=c[2406936]|0;e=c[3530034]|0;f=0;do{g=c[b+(f<<2)>>2]|0;c[e+(f<<2)>>2]=g>>8<<3&2016|g>>>3&31|g>>16<<8&63488;f=f+1|0;}while((f|0)<256)}f=c[2426606]|0;e=c[2112926]|0;b=c[2424850]|0;g=64;do{h=g<<3&248;i=g>>>2&248;j=d[f+(g+54272)|0]|0;k=j<<1&256|d[f+(g+53248)|0];l=j&31;if((c[3528704]|0)==0){Sj(e,k,h,i-16|0,l,2,0,b)}else{Sp(e,k,h^248,232-i|0,l,2,0,b)}g=g+1|0;}while((g|0)<960);g=c[2424826]|0;b=368;do{l=a[f+(b+55424)|0]&127;i=d[f+(b+55428)|0]|0;h=i&15;k=d[f+(b+55436)|0]|0;j=d[f+(b+55432)|0]|0;m=i&16;n=i&32;if((c[3528704]|0)==0){o=n;p=m;q=j;r=k}else{o=n>>>5^1;p=m>>>4^1;q=240-j|0;r=240-k|0}k=q-16|0;j=(p|0)!=0;do{if((o|0)==0){if(j){SJ(e,l,r,k,h,4,15,128,g);if((r|0)<=240){break}SJ(e,l,r-256|0,k,h,4,15,128,g);break}else{SH(e,l,r,k,h,4,15,128,g);if((r|0)<=240){break}SH(e,l,r-256|0,k,h,4,15,128,g);break}}else{if(j){SN(e,l,r,k,h,4,15,128,g);if((r|0)<=240){break}SN(e,l,r-256|0,k,h,4,15,128,g);break}else{SL(e,l,r,k,h,4,15,128,g);if((r|0)<=240){break}SL(e,l,r-256|0,k,h,4,15,128,g);break}}}while(0);b=b-16|0;}while((b|0)>-1);R8(c[3530034]|0);return 0}function dSx(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;d=i;i=i+64|0;e=d|0;f=d+32|0;g=d+48|0;h=(b|0)==0;if(!h){c[b>>2]=169586}if((a&32|0)!=0){gGz(g|0,0,12);c[g>>2]=(c[2426606]|0)+53248;c[g+4>>2]=8192;c[g+12>>2]=162152;j=c[2076592]|0;gj[j&4095](g)|0}if((a&64|0)==0){i=d;return 0}fw$(a);a=d+16|0;do{if(!h){if((c[b>>2]|0)>=169110){break}c[b>>2]=169110}}while(0);if((c[2113008]|0)>0){b=e|0;h=e+4|0;g=e+8|0;j=e+12|0;k=0;do{cC(a|0,531144,(l=i,i=i+8|0,c[l>>2]=k,l)|0)|0;i=l;c[b>>2]=14168888+(k*252|0);c[h>>2]=252;c[g>>2]=0;c[j>>2]=a;gj[c[2076592]&4095](e)|0;k=k+1|0;}while((k|0)<(c[2113008]|0))}gGz(f|0,0,12);c[f>>2]=14114816;c[f+4>>2]=4;c[f+12>>2]=142288;gj[c[2076592]&4095](f)|0;i=d;return 0}function dSy(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;e=b&65535;if(b<<16>>16<0&(b&65535)<33792){a[(c[2408974]|0)+(e&1023)|0]=c[2385218]&255;a[(c[2426604]|0)+e|0]=d;return}do{if((e|0)==35841|(e|0)==35840){f=d&255;if((e&1|0)!=0){c[3542228]=f&15;break}g=c[3542228]|0;if((g|0)>15){break}do{if((g|0)<14){if((g|0)!=13){if((a[14168916+g|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(0,g,f)}else if((e|0)==33792){c[2385218]=d&255}else if((e|0)==36288){c[3528702]=d&1}}while(0);if((b&65535)>=1024){return}a[(c[2426604]|0)+e|0]=d;return}function dSz(b){b=b|0;var d=0,e=0;d=b&65535;if((d|0)==36096){e=a[9635184]&3;return e|0}else if((d|0)==36288){e=a[9631518]<<1|a[9631519]|a[9631515]<<2|a[9631520]<<3|a[9631517]<<4|a[9631516]<<5;return e|0}else if((d|0)==36160){e=a[9633697]<<1|a[9633696]|a[9633698]<<2|a[9633699]<<3|a[9633700]<<4|a[9633701]<<5|a[9633702]<<6|a[9633703]<<7;return e|0}else if((d|0)==36224){e=a[9631512]<<1|a[9633704]|a[9631513]<<2|a[9631514]<<3|a[9635184]&16|a[9631522]<<5|a[9633706]<<6|a[9633705]<<7;return e|0}else{if((b-2048&65535)>=256){if((b&65535)>=1024){e=0;return e|0}e=a[(c[2426604]|0)+d|0]|0;return e|0}d=b&255;if((d|0)==38){e=(c[2415240]|0)==21463?6:-58;return e|0}else if((d|0)==174){e=50;return e|0}else if((d|0)==134){e=-111;return e|0}else if((d|0)==8){e=-80;return e|0}else{e=0;return e|0}}return 0}function dSA(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7029604+(b*112|0)>>2];c[a+104>>2]=c[7029608+(b*112|0)>>2];c[a+108>>2]=c[7029612+(b*112|0)>>2];d=0;return d|0}function dSB(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=7029504+(b*112|0);e=0;return e|0}function dSC(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6928640+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dSD(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7437216+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dSE(){var b=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0.0,R=0,S=0,T=0;b=i;i=i+1080|0;e=b|0;f=b+112|0;g=b+120|0;j=b+232|0;k=b+240|0;l=b+352|0;m=b+360|0;n=b+472|0;o=b+480|0;p=b+592|0;q=b+600|0;r=b+712|0;s=b+720|0;t=b+832|0;u=b+840|0;v=b+952|0;w=b+960|0;x=b+1072|0;y=0;while(1){if((y|0)>=1024){break}z=9638528+(y<<2)|0;if((c[z>>2]|0)==0){A=22228;break}else{y=y+1|0}}do{if((A|0)==22228){y=gGq(132224)|0;c[z>>2]=y;if((y|0)==0){break}gGz(y|0,0,132224);c[2426742]=y;y=a[9688]|0?3204:0;B=0;while(1){if((B|0)>=1024){break}C=9638528+(B<<2)|0;if((c[C>>2]|0)==0){A=22233;break}else{B=B+1|0}}do{if((A|0)==22233){B=gGq(y)|0;c[C>>2]=B;if((B|0)==0){break}gGz(B|0,0,y|0);c[2385362]=B;B=c[2426742]|0;gGz(B|0,0,132128);c[2426604]=B;c[2426828]=B+65536;c[2408974]=B+131072;c[2406934]=B+132096;D=B+20480|0;do{if((c[3542200]|0)!=0){B=w+108|0;c[B>>2]=0;E=w+100|0;c[E>>2]=0;F=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[F&16383](w,0)|0;if((c[B>>2]|0)==0){break}B=c[E>>2]|0;c[x>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](x,0,0)|0;if((B|0)<1){break}gzL(D,0,0)|0}}while(0);D=(c[2426604]|0)+24576|0;do{if((c[3542200]|0)!=0){B=u+108|0;c[B>>2]=0;E=u+100|0;c[E>>2]=0;F=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[F&16383](u,1)|0;if((c[B>>2]|0)==0){break}B=c[E>>2]|0;c[v>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](v,1,0)|0;if((B|0)<1){break}gzL(D,0,1)|0}}while(0);D=(c[2426604]|0)+28672|0;do{if((c[3542200]|0)!=0){B=s+108|0;c[B>>2]=0;E=s+100|0;c[E>>2]=0;F=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[F&16383](s,2)|0;if((c[B>>2]|0)==0){break}B=c[E>>2]|0;c[t>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](t,2,0)|0;if((B|0)<1){break}gzL(D,0,2)|0}}while(0);D=c[2426828]|0;do{if((c[3542200]|0)!=0){B=q+108|0;c[B>>2]=0;E=q+100|0;c[E>>2]=0;F=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[F&16383](q,3)|0;if((c[B>>2]|0)==0){break}B=c[E>>2]|0;c[r>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](r,3,0)|0;if((B|0)<1){break}gzL(D,0,3)|0}}while(0);D=(c[2426828]|0)+4096|0;do{if((c[3542200]|0)!=0){B=o+108|0;c[B>>2]=0;E=o+100|0;c[E>>2]=0;F=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[F&16383](o,4)|0;if((c[B>>2]|0)==0){break}B=c[E>>2]|0;c[p>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](p,4,0)|0;if((B|0)<1){break}gzL(D,0,4)|0}}while(0);D=(c[2426828]|0)+8192|0;do{if((c[3542200]|0)!=0){B=m+108|0;c[B>>2]=0;E=m+100|0;c[E>>2]=0;F=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[F&16383](m,5)|0;if((c[B>>2]|0)==0){break}B=c[E>>2]|0;c[n>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](n,5,0)|0;if((B|0)<1){break}gzL(D,0,5)|0}}while(0);D=(c[2426828]|0)+12288|0;do{if((c[3542200]|0)!=0){B=k+108|0;c[B>>2]=0;E=k+100|0;c[E>>2]=0;F=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[F&16383](k,6)|0;if((c[B>>2]|0)==0){break}B=c[E>>2]|0;c[l>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](l,6,0)|0;if((B|0)<1){break}gzL(D,0,6)|0}}while(0);D=(c[2426828]|0)+16384|0;do{if((c[3542200]|0)!=0){B=g+108|0;c[B>>2]=0;E=g+100|0;c[E>>2]=0;F=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[F&16383](g,7)|0;if((c[B>>2]|0)==0){break}B=c[E>>2]|0;c[j>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](j,7,0)|0;if((B|0)<1){break}gzL(D,0,7)|0}}while(0);D=(c[2426828]|0)+20480|0;do{if((c[3542200]|0)==0){G=0}else{B=e+108|0;c[B>>2]=0;E=e+100|0;c[E>>2]=0;F=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[F&16383](e,8)|0;if((c[B>>2]|0)==0){G=0;break}B=c[E>>2]|0;c[f>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](f,8,0)|0;if((B|0)<1){G=0;break}gzL(D,0,8)|0;G=0}}while(0);while(1){if((G|0)>=1024){break}H=9638528+(G<<2)|0;if((c[H>>2]|0)==0){A=22273;break}else{G=G+1|0}}L29529:do{if((A|0)==22273){D=gGq(24576)|0;c[H>>2]=D;if((D|0)==0){break}gGz(D|0,0,24576);B=c[2426828]|0;gGC(D|0,B|0,24576)|0;E=0;while(1){F=E>>3;I=E&7;a[B+(E^7)|0]=((d[D+(F+4096)|0]|0)>>>(I>>>0)<<1&2|(d[D+F|0]|0)>>>(I>>>0)<<2&4|(d[D+(F+8192)|0]|0)>>>(I>>>0)&1)&255;a[B+(E^32775)|0]=((d[D+(F+16384)|0]|0)>>>(I>>>0)<<1&2|(d[D+(F+12288)|0]|0)>>>(I>>>0)<<2&4|(d[D+(F+20480)|0]|0)>>>(I>>>0)&1)&255;I=E+1|0;if((I|0)<32768){E=I}else{J=0;break}}while(1){if((J|0)>=1024){break L29529}K=9638528+(J<<2)|0;if((c[K>>2]|0)==(D|0)){break}else{J=J+1|0}}gGr(D);c[K>>2]=0}}while(0);E=c[2406934]|0;B=0;do{I=E+(B<<2)|0;c[I>>2]=((B&1|0)!=0?16711680:0)|c[I>>2]|((B&4|0)!=0?65280:0)|((B&2|0)!=0?255:0);B=B+1|0;}while((B|0)<8);fvI();c[3528556]=0;B=c[2433594]|0;c[2443776]=B;E=(B|0)==0;L29542:do{if(!E){I=B|0;gGC(9660952,I|0,52)|0;switch(a[9660952]|0){case 0:{c[2309668]=638960;break L29542;break};case 5:{c[2309668]=7354992;break L29542;break};case 2:{c[2309668]=638960;break L29542;break};case 1:{c[2309668]=634096;break L29542;break};case 3:{c[2309668]=639984;break L29542;break};case 4:{c[2309668]=7356016;break L29542;break};default:{break L29542}}}}while(0);I=c[2432850]|0;c[2113164]=I;F=c[2426604]|0;c[B+68>>2]=F;c[B+1092>>2]=F;c[B+2116>>2]=F;L=F+256|0;c[B+72>>2]=L;c[B+1096>>2]=L;c[B+2120>>2]=L;L=F+512|0;c[B+76>>2]=L;c[B+1100>>2]=L;c[B+2124>>2]=L;L=F+768|0;c[B+80>>2]=L;c[B+1104>>2]=L;c[B+2128>>2]=L;L=80;M=80;while(1){N=F+(M<<8)|0;c[B+68+(M<<2)>>2]=N;c[B+68+(M+512<<2)>>2]=N;N=L+1&65535;if((N&65535)>127){O=208;P=208;break}else{L=N;M=N&65535}}while(1){M=F+((P<<8)-32768)|0;c[B+68+(P<<2)>>2]=M;c[B+68+(P+512<<2)>>2]=M;M=O+1&65535;if((M&65535)>255){break}else{O=M;P=M&65535}}c[B+3148>>2]=2848;c[B+3152>>2]=3100;c[B+3156>>2]=2848;c[B+3160>>2]=3100;c[B+3164>>2]=2848;c[B+3168>>2]=2848;if(!E){M=B|0;gGC(M|0,9660952,52)|0}c[2432850]=I;c[2443776]=0;c[3528556]=-1;M=c[2385362]|0;c[2439012]=M;L=a[9688]|0?534:0;c[2439013]=M+(L<<1);c[2439014]=M+(L<<1<<1);L=a[9680]|0?32e3:0;c[3542220]=11200;if((c[2113008]|0)==0){gGz(14168888,0,252);c[3542223]=L;gGz(14168896,0,16);c[3542234]=~~((+(L|0)*32768.0*8.0+1.0e6)/2.0e6);L=31;Q=32767.0;while(1){c[14169012+(L<<2)>>2]=~~(Q+.5);M=L-1|0;if((M|0)>0){L=M;Q=Q/1.188502227}else{break}}c[3542253]=0;h[1771269]=1.0;h[1771270]=1.0;h[1771271]=1.0;c[3542574]=3;c[3542575]=3;c[3542576]=3;mB(0);c[2113008]=(c[2113008]|0)+1;R=c[2426604]|0;S=c[2433594]|0}else{R=F;S=B}h[1771269]=1.0;c[3542574]=3;h[1771270]=1.0;c[3542575]=3;h[1771271]=1.0;c[3542576]=3;a[9624328]=0;gGz(R|0,0,1024);gGz(R+32768|0,0,1024);gGz(c[2408974]|0,0,1024);c[2385218]=0;c[3528702]=0;c[3528556]=0;c[2443776]=S;L29566:do{if((S|0)!=0){L=S|0;gGC(9660952,L|0,52)|0;switch(a[9660952]|0){case 3:{c[2309668]=639984;break L29566;break};case 4:{c[2309668]=7356016;break L29566;break};case 5:{c[2309668]=7354992;break L29566;break};case 0:{c[2309668]=638960;break L29566;break};case 1:{c[2309668]=634096;break L29566;break};case 2:{c[2309668]=638960;break L29566;break};default:{break L29566}}}}while(0);c[2113164]=c[2432850];gu[c[S+56>>2]&16383]();B=c[2443776]|0;if((B|0)!=0){F=B|0;gGC(F|0,9660952,52)|0}c[9731400+(c[3528556]<<2)>>2]=c[2113164];c[2443776]=0;c[3528556]=-1;mB(0);T=0;i=b;return T|0}}while(0);c[2385362]=0;T=1;i=b;return T|0}}while(0);c[2426742]=0;T=1;i=b;return T|0}function dSF(){var a=0,b=0,d=0,e=0,f=0;fvR();c[2113008]=0;c[2076598]=0;c[2383582]=0;a=c[2426742]|0;b=0;while(1){if((b|0)>=1024){break}d=9638528+(b<<2)|0;if((c[d>>2]|0)==(a|0)){e=22316;break}else{b=b+1|0}}if((e|0)==22316){gGr(a);c[d>>2]=0}c[2426742]=0;d=c[2385362]|0;a=0;while(1){if((a|0)>=1024){e=22322;break}f=9638528+(a<<2)|0;if((c[f>>2]|0)==(d|0)){break}else{a=a+1|0}}if((e|0)==22322){c[2385362]=0;return 0}gGr(d);c[f>>2]=0;c[2385362]=0;return 0}function dSG(){var b=0,d=0;if((a[9624328]|0)!=0){a[9624328]=0;b=c[2426604]|0;gGz(b|0,0,1024);gGz(b+32768|0,0,1024);gGz(c[2408974]|0,0,1024);c[2385218]=0;c[3528702]=0;c[3528556]=0;b=c[2433594]|0;c[2443776]=b;L29601:do{if((b|0)!=0){d=b|0;gGC(9660952,d|0,52)|0;switch(a[9660952]|0){case 5:{c[2309668]=7354992;break L29601;break};case 0:{c[2309668]=638960;break L29601;break};case 3:{c[2309668]=639984;break L29601;break};case 1:{c[2309668]=634096;break L29601;break};case 2:{c[2309668]=638960;break L29601;break};case 4:{c[2309668]=7356016;break L29601;break};default:{break L29601}}}}while(0);c[2113164]=c[2432850];gu[c[b+56>>2]&16383]();b=c[2443776]|0;if((b|0)!=0){d=b|0;gGC(d|0,9660952,52)|0}c[9731400+(c[3528556]<<2)>>2]=c[2113164];c[2443776]=0;c[3528556]=-1;mB(0)}c[3528556]=0;d=c[2433594]|0;c[2443776]=d;L29615:do{if((d|0)!=0){b=d|0;gGC(9660952,b|0,52)|0;switch(a[9660952]|0){case 2:{c[2309668]=638960;break L29615;break};case 4:{c[2309668]=7356016;break L29615;break};case 1:{c[2309668]=634096;break L29615;break};case 3:{c[2309668]=639984;break L29615;break};case 0:{c[2309668]=638960;break L29615;break};case 5:{c[2309668]=7354992;break L29615;break};default:{break L29615}}}}while(0);c[2113164]=c[2432850];b=gj[c[d+52>>2]&4095](66666)|0;c[2113164]=(c[2113164]|0)+b;gg[c[(c[2443776]|0)+64>>2]&4095](0,1);gj[c[(c[2443776]|0)+52>>2]&4095](0)|0;gg[c[(c[2443776]|0)+64>>2]&4095](0,0);gj[c[(c[2443776]|0)+52>>2]&4095](0)|0;b=c[2443776]|0;if((b|0)!=0){d=b|0;gGC(d|0,9660952,52)|0}c[9731400+(c[3528556]<<2)>>2]=c[2113164];c[2443776]=0;c[3528556]=-1;d=c[2112964]|0;if((d|0)!=0){mF(9756048,d,a[9688]|0?534:0,0)}if((c[2112968]|0)==0){return 0}dSH()|0;return 0}function dSH(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;e=c[2408974]|0;f=c[2426604]|0;g=c[2426828]|0;h=c[2406934]|0;i=c[2112968]|0;j=c[2113308]|0;k=(j|0)>3;l=(j|0)==2;m=0;do{n=(((m|0)/40|0|0)%25|0)<<3;o=((m|0)%40|0)<<3;p=n+8|0;q=o+8|0;r=o|1;s=((q|0)>(r|0)?q:r)-o|0;r=g+((d[f+(m+32768)|0]|0)<<6|(d[e+m|0]|0)<<14&49152)|0;t=n;while(1){n=t*320|0;u=((199-t|0)*320|0)+319|0;v=r;w=o;while(1){x=c[h+((d[v]|0)<<2)>>2]|0;y=ag(j,(c[3528702]|0)==0?w+n|0:u-w|0)|0;z=i+y|0;A=x>>16<<8&63488|x>>8<<3&2016;B=A|x>>>3&31;do{if(k){c[z>>2]=B}else{if(l){b[z>>1]=B&65535;break}else{a[z]=B&255;a[i+(y+1)|0]=A>>>8&255;a[i+(y+2)|0]=0;break}}}while(0);y=w+1|0;if((y|0)<(q|0)){v=v+1|0;w=y}else{break}}w=t+1|0;if((w|0)<(p|0)){r=r+s|0;t=w}else{break}}m=m+1|0;}while((m|0)<1024);return 0}function dSI(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;e=i;i=i+160|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;l=e+80|0;m=e+96|0;n=e+112|0;o=e+128|0;p=e+144|0;q=(d|0)==0;if(!q){c[d>>2]=169249}if((b&96|0)==0){i=e;return 0}gGz(p|0,0,12);r=p|0;c[r>>2]=c[2426604];s=p+4|0;c[s>>2]=1024;t=p+12|0;c[t>>2]=397736;gj[c[2076592]&4095](p)|0;c[r>>2]=(c[2426604]|0)+32768;c[s>>2]=1024;c[t>>2]=151792;gj[c[2076592]&4095](p)|0;c[r>>2]=c[2408974];c[s>>2]=1024;c[t>>2]=122496;gj[c[2076592]&4095](p)|0;p=m|0;t=(b&64|0)==0;if((c[2113166]|0)>0&(t^1)){b=m+7|0;m=l|0;s=l+4|0;r=l+12|0;u=k;v=k|0;w=k+4|0;x=k+12|0;y=j;z=j|0;A=j+4|0;B=j+12|0;C=h;D=h|0;E=h+4|0;F=h+12|0;G=0;do{H=c[9734376+(G<<2)>>2]|0;I=H+36|0;J=c[I>>2]|0;gGC(p|0,614768,9)|0;a[b]=G+48&255;c[m>>2]=H;c[s>>2]=52;c[r>>2]=p;gj[c[2076592]&4095](l)|0;gGz(u|0,0,12);c[v>>2]=H+3172;c[w>>2]=4;c[x>>2]=165288;gj[c[2076592]&4095](k)|0;gGz(y|0,0,12);c[z>>2]=H+3176;c[A>>2]=4;c[B>>2]=501592;gj[c[2076592]&4095](j)|0;gGz(C|0,0,12);c[D>>2]=H+3180;c[E>>2]=4;c[F>>2]=386080;gj[c[2076592]&4095](h)|0;c[I>>2]=J;G=G+1|0;}while((G|0)<(c[2113166]|0))}G=g|0;do{if(!t){do{if(!q){if((c[d>>2]|0)>=169110){break}c[d>>2]=169110}}while(0);if((c[2113008]|0)<=0){break}g=f|0;h=f+4|0;F=f+8|0;E=f+12|0;D=0;do{cC(G|0,531144,(C=i,i=i+8|0,c[C>>2]=D,C)|0)|0;i=C;c[g>>2]=14168888+(D*252|0);c[h>>2]=252;c[F>>2]=0;c[E>>2]=G;gj[c[2076592]&4095](f)|0;D=D+1|0;}while((D|0)<(c[2113008]|0))}}while(0);gGz(o|0,0,12);c[o>>2]=9540872;c[o+4>>2]=4;c[o+12>>2]=245488;gj[c[2076592]&4095](o)|0;gGz(n|0,0,12);c[n>>2]=14114808;c[n+4>>2]=4;c[n+12>>2]=142288;gj[c[2076592]&4095](n)|0;i=e;return 0}function dSJ(b){b=b|0;var d=0,e=0;d=b&65535;if((d|0)==63489){e=a[9550585]|0}else if((d|0)==63488){c[2388368]=0;e=a[9635176]&-32|a[9550584]}else if((d|0)==63490){e=a[9550586]|0}else{e=0}return e|0}function dSK(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((e|0)==59397){a[c[2405104]|0]=d&1;return}else if((e|0)==59392){a[c[3528700]|0]=d&1;return}else if((e|0)==63488){c[2388368]=0;return}else if((e|0)==57344){a[c[2408996]|0]=d;return}else{return}}function dSL(b){b=b|0;var d=0,e=0;if((b&255)!=2){d=0;return d|0}b=c[3542228]|0;if((b|0)>15){d=0;return d|0}do{if((b|0)==14){e=c[3542224]|0;if((e|0)==0){break}a[14168930]=gj[e&4095](0)|0}else if((b|0)==15){e=c[3542225]|0;if((e|0)==0){break}a[14168931]=gj[e&4095](0)|0}}while(0);d=a[14168916+b|0]|0;return d|0}function dSM(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((e&254)>>>0>=2){return}b=d&255;if((e&1|0)==0){c[3542228]=b&15;return}e=c[3542228]|0;if((e|0)>15){return}do{if((e|0)<14){if((e|0)!=13){if((a[14168916+e|0]|0)==d<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(0,e,b);return}function dSN(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2849900+(b*112|0)>>2];c[a+104>>2]=c[2849904+(b*112|0)>>2];c[a+108>>2]=c[2849908+(b*112|0)>>2];d=0;return d|0}function dSO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=2849800+(b*112|0);e=0;return e|0}function dSP(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6928368+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dSQ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>25){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=2850584+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dSR(){return dS4(0)|0}function dSS(){var a=0,b=0,d=0,e=0;c[2113070]=0;c[2113068]=0;a=c[2112926]|0;if((a|0)!=0){gGr(a);c[2112926]=0}fwZ();c[2113008]=0;c[2076598]=0;c[2383582]=0;a=c[2414984]|0;b=0;while(1){if((b|0)>=1024){d=22459;break}e=9638528+(b<<2)|0;if((c[e>>2]|0)==(a|0)){break}else{b=b+1|0}}if((d|0)==22459){c[2414984]=0;return 0}gGr(a);c[e>>2]=0;c[2414984]=0;return 0}function dST(){var d=0,e=0,f=0,g=0,h=0,i=0;do{if((a[9624312]|0)==0){d=(c[2388368]|0)+1|0;c[2388368]=d;if((d|0)<=179){break}d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;h=c[2417276]|0;c[3541536]=h;c[1836236]=0;gGz(9706056,0,76);if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=h;c[1836236]=-1;c[2388368]=0}else{h=c[2414688]|0;gGz(h|0,0,(c[2411700]|0)-h|0);h=c[2439330]|0;g=(h|0)==0;if(!g){f=h;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;e=c[3528484]|0;c[2076596]=e;d=c[2417276]|0;c[3541536]=d;c[1836236]=0;gGz(9706056,0,76);if(!g){g=h;gGC(g|0,9706056,76)|0}c[2438118]=f;c[3528484]=e;c[2417276]=d;c[1836236]=-1;c[2388368]=1}}while(0);gGz(9550584,0,3);d=0;e=0;f=0;g=0;do{e=((a[9633672+d|0]&1)<<d^e&255)&255;f=((a[9631488+d|0]&1)<<d^f&255)&255;g=((a[9629624+d|0]&1)<<d^g&255)&255;d=d+1|0;}while((d|0)<8);a[9550584]=e;a[9550585]=f;a[9550586]=g;g=c[2439330]|0;if((g|0)!=0){f=g;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;f=c[2438118]|0;c[2433530]=f;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;if((a[g+4188|0]|0)==0){g=gfc(51200)|0;i=(c[2433530]|0)+g|0}else{i=f+51200|0}c[2433530]=i;a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0;i=c[1836236]|0;f=c[9757320+(i<<2)>>2]|0;if((f|0)!=0){g=f;gGC(g|0,9706056,76)|0}c[9752472+(i<<2)>>2]=c[2433530];c[14113936+(i<<2)>>2]=c[2076596];c[9669104+(i<<2)>>2]=c[3541536];c[1836236]=-1;i=c[2112964]|0;if((i|0)!=0){mF(9756032,i,a[9688]|0?534:0,0)}if((c[2112968]|0)==0){return 0}dSU()|0;return 0}function dSU(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;if((a[9547520]|0)!=0){e=c[3531004]|0;f=c[3530032]|0;g=0;do{h=d[e+g|0]|0;c[f+(g<<2)>>2]=(-(h>>>3&1)&33)+(-(h>>>4&1)&71)+(-(h>>>5&1)&151)<<8|(-(h>>>6&1)&71)+(-(h>>>7)&151)|(-(h>>>1&1)&71)+(-(h&1)&33)+(-(h>>>2&1)&151)<<16;g=g+1|0;}while((g|0)<32);a[9547520]=0}g=c[2408996]|0;f=c[2387872]|0;e=c[2386220]|0;h=c[2405104]|0;i=c[2112926]|0;j=c[3530854]|0;k=0;do{l=k&31;m=(k|0)/32|0;n=(l<<3)-(d[g]|0)|0;o=m<<8|l;l=d[f+o|0]|0;Sj(i,d[e+o|0]|l<<1&256|d[h]<<9,((n|0)<-7?n+256|0:n)-12|0,m<<3,l&3,2,0,j);k=k+1|0;}while((k|0)<1024);k=c[2113068]|0;g=c[3530618]|0;l=c[2113070]|0;m=15;while(1){n=m+7680|0;o=d[e+n|0]|0;p=224-(d[f+n|0]|0)|0;n=m+7696|0;q=(d[e+n|0]|0)-12|0;r=d[f+n|0]<<2&12|16;n=g+((o<<5&64|o>>>2|d[h]<<7)<<8)|0;L29815:do{if((o&1|0)==0){s=i+((ag(k,p)|0)+q<<1)|0;t=0;u=n;while(1){v=t+p|0;if((v|0)>=(l|0)|(v|0)<0){w=u}else{v=0;while(1){x=v+q|0;do{if((x|0)>-1&(x|0)<(k|0)){y=a[u+v|0]|0;if(y<<24>>24==0){break}b[s+(v<<1)>>1]=(y&255|r)&65535}}while(0);x=v+1|0;if((x|0)<8){v=x}else{w=u;break}}}v=t+1|0;x=w+8|0;if((v|0)>=32){z=x;break L29815}s=s+(k<<1)|0;t=v;u=x}}else{u=i+((ag(k,p+31|0)|0)+q<<1)|0;t=31;s=n;while(1){x=t+p|0;if((x|0)>=(l|0)|(x|0)<0){A=s}else{x=0;while(1){v=x+q|0;do{if((v|0)>-1&(v|0)<(k|0)){y=a[s+x|0]|0;if(y<<24>>24==0){break}b[u+(x<<1)>>1]=(y&255|r)&65535}}while(0);v=x+1|0;if((v|0)<8){x=v}else{A=s;break}}}x=A+8|0;if((t|0)<=0){z=x;break L29815}u=u+(-k<<1)|0;t=t-1|0;s=x}}}while(0);if((m|0)<=0){break}m=m-1|0}c[2112928]=z;z=c[3528700]|0;m=f+7952|0;k=e+7967|0;A=e+7952|0;l=f+7953|0;f=e+7966|0;w=e+7953|0;g=31;while(1){r=g<<3;q=(a[z]|0)!=0;p=q?248-r|0:r;r=d[h]<<9|d[e+(g+7168)|0];n=a[m]&3;o=d[q?k:A]|0;if(q){Sx(i,r,236-o|0,p^248,n,2,0,0,j)}else{Sr(i,r,o-12|0,p,n,2,0,0,j)}n=d[h]<<9|d[e+(g+7424)|0];o=a[l]&3;r=d[q?f:w]|0;if(q){Sx(i,n,236-r|0,p^248,o,2,0,0,j)}else{Sr(i,n,r-12|0,p,o,2,0,0,j)}if((g|0)<=0){break}g=g-1|0}R8(c[3530032]|0);return 0}function dSV(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;d=i;i=i+48|0;e=d|0;f=d+32|0;g=(b|0)==0;if(!g){c[b>>2]=169249}if((a&96|0)==0){i=d;return 0}gGz(f|0,0,12);h=c[2414688]|0;c[f>>2]=h;c[f+4>>2]=(c[2411700]|0)-h;c[f+12>>2]=162152;gj[c[2076592]&4095](f)|0;fw$(a);f=d+16|0;if((a&64|0)==0){i=d;return 0}do{if(!g){if((c[b>>2]|0)>=169110){break}c[b>>2]=169110}}while(0);if((c[2113008]|0)<=0){i=d;return 0}b=e|0;g=e+4|0;a=e+8|0;h=e+12|0;j=0;do{cC(f|0,531144,(k=i,i=i+8|0,c[k>>2]=j,k)|0)|0;i=k;c[b>>2]=14168888+(j*252|0);c[g>>2]=252;c[a>>2]=0;c[h>>2]=f;gj[c[2076592]&4095](e)|0;j=j+1|0;}while((j|0)<(c[2113008]|0));i=d;return 0}function dSW(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2850996+(b*112|0)>>2];c[a+104>>2]=c[2851e3+(b*112|0)>>2];c[a+108>>2]=c[2851004+(b*112|0)>>2];d=0;return d|0}function dSX(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=2850896+(b*112|0);e=0;return e|0}function dSY(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>25){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=2851680+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dSZ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>5){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2269356+(b*112|0)>>2];c[a+104>>2]=c[2269360+(b*112|0)>>2];c[a+108>>2]=c[2269364+(b*112|0)>>2];d=0;return d|0}function dS_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<6&(d|0)==0)){e=1;return e|0}c[a>>2]=2269256+(b*112|0);e=0;return e|0}function dS$(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>25){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=2269928+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dS0(){return dS4(1)|0}function dS1(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>5){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2270340+(b*112|0)>>2];c[a+104>>2]=c[2270344+(b*112|0)>>2];c[a+108>>2]=c[2270348+(b*112|0)>>2];d=0;return d|0}function dS2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<6&(d|0)==0)){e=1;return e|0}c[a>>2]=2270240+(b*112|0);e=0;return e|0}function dS3(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>25){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=2270912+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dS4(e){e=e|0;var f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0.0,am=0,an=0;f=i;i=i+1440|0;g=f|0;j=f+112|0;k=f+120|0;l=f+232|0;m=f+240|0;n=f+352|0;o=f+360|0;p=f+472|0;q=f+480|0;r=f+592|0;s=f+600|0;t=f+712|0;u=f+720|0;v=f+832|0;w=f+840|0;x=f+952|0;y=f+960|0;z=f+1072|0;A=f+1080|0;B=f+1192|0;C=f+1200|0;D=f+1312|0;E=f+1320|0;F=f+1432|0;c[2414984]=0;c[2385932]=0;c[3530854]=20480;c[3530618]=86016;c[3531004]=151552;c[3530032]=151584;c[2414688]=151712;c[2386086]=151712;c[2386220]=153760;c[2387872]=161952;c[3528700]=170144;c[2405104]=170145;c[2408996]=170146;c[2411700]=170147;c[2439008]=170147;G=a[9688]|0?1068:0;H=G+170147|0;c[2439009]=H;I=H+G|0;c[2439010]=I;H=I+G|0;c[2414242]=H;G=H;H=0;while(1){if((H|0)>=1024){break}J=9638528+(H<<2)|0;if((c[J>>2]|0)==0){K=22600;break}else{H=H+1|0}}do{if((K|0)==22600){H=gGq(G)|0;c[J>>2]=H;if((H|0)==0){break}gGz(H|0,0,G|0);c[2414984]=H;gGz(H|0,0,G|0);c[2385932]=H;c[3530854]=H+20480;c[3530618]=H+86016;c[3531004]=H+151552;c[3530032]=H+151584;I=H+151712|0;c[2414688]=I;c[2386086]=I;c[2386220]=H+153760;c[2387872]=H+161952;c[3528700]=H+170144;c[2405104]=H+170145;c[2408996]=H+170146;I=H+170147|0;c[2411700]=I;c[2439008]=I;I=a[9688]|0?1068:0;L=I+170147|0;c[2439009]=H+L;M=L+I|0;c[2439010]=H+M;c[2414242]=H+(M+I);I=(e|0)==0;do{if((c[3542200]|0)==0){N=1}else{M=E+108|0;c[M>>2]=0;L=E+100|0;c[L>>2]=0;O=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[O&16383](E,0)|0;if((c[M>>2]|0)==0){N=0;break}M=c[L>>2]|0;c[F>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](F,0,0)|0;if((M|0)<1){N=1;break}N=(gzL(H,0,0)|0)!=0}}while(0);do{if(I){if(N){P=1;i=f;return P|0}H=(c[2385932]|0)+4096|0;if((c[3542200]|0)==0){P=1;i=f;return P|0}M=s+108|0;c[M>>2]=0;L=s+100|0;c[L>>2]=0;O=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[O&16383](s,1)|0;do{if((c[M>>2]|0)!=0){O=c[L>>2]|0;c[t>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](t,1,0)|0;if((O|0)<1){P=1;i=f;return P|0}if((gzL(H,0,1)|0)==0){break}else{P=1}i=f;return P|0}}while(0);H=(c[2385932]|0)+8192|0;if((c[3542200]|0)==0){P=1;i=f;return P|0}L=q+108|0;c[L>>2]=0;M=q+100|0;c[M>>2]=0;O=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[O&16383](q,2)|0;do{if((c[L>>2]|0)!=0){O=c[M>>2]|0;c[r>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](r,2,0)|0;if((O|0)<1){P=1;i=f;return P|0}if((gzL(H,0,2)|0)==0){break}else{P=1}i=f;return P|0}}while(0);H=(c[2385932]|0)+12288|0;if((c[3542200]|0)==0){P=1;i=f;return P|0}M=o+108|0;c[M>>2]=0;L=o+100|0;c[L>>2]=0;O=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[O&16383](o,3)|0;do{if((c[M>>2]|0)!=0){O=c[L>>2]|0;c[p>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](p,3,0)|0;if((O|0)<1){P=1;i=f;return P|0}if((gzL(H,0,3)|0)==0){break}else{P=1}i=f;return P|0}}while(0);H=c[3530854]|0;if((c[3542200]|0)==0){P=1;i=f;return P|0}L=m+108|0;c[L>>2]=0;M=m+100|0;c[M>>2]=0;O=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[O&16383](m,4)|0;do{if((c[L>>2]|0)!=0){O=c[M>>2]|0;c[n>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](n,4,0)|0;if((O|0)<1){P=1;i=f;return P|0}if((gzL(H,0,4)|0)==0){break}else{P=1}i=f;return P|0}}while(0);H=(c[3530854]|0)+8192|0;if((c[3542200]|0)==0){P=1;i=f;return P|0}M=k+108|0;c[M>>2]=0;L=k+100|0;c[L>>2]=0;O=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[O&16383](k,5)|0;do{if((c[M>>2]|0)!=0){O=c[L>>2]|0;c[l>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](l,5,0)|0;if((O|0)<1){P=1;i=f;return P|0}if((gzL(H,0,5)|0)==0){break}else{P=1}i=f;return P|0}}while(0);H=c[3531004]|0;if((c[3542200]|0)==0){P=1;i=f;return P|0}L=g+108|0;c[L>>2]=0;M=g+100|0;c[M>>2]=0;O=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[O&16383](g,6)|0;if((c[L>>2]|0)==0){break}L=c[M>>2]|0;c[j>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](j,6,0)|0;if((L|0)<1){P=1;i=f;return P|0}if((gzL(H,0,6)|0)==0){break}else{P=1}i=f;return P|0}else{if(N){P=1;i=f;return P|0}H=(c[2385932]|0)+8192|0;if((c[3542200]|0)==0){P=1;i=f;return P|0}L=C+108|0;c[L>>2]=0;M=C+100|0;c[M>>2]=0;O=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[O&16383](C,1)|0;do{if((c[L>>2]|0)!=0){O=c[M>>2]|0;c[D>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](D,1,0)|0;if((O|0)<1){P=1;i=f;return P|0}if((gzL(H,0,1)|0)==0){break}else{P=1}i=f;return P|0}}while(0);H=(c[2385932]|0)+16384|0;if((c[3542200]|0)==0){P=1;i=f;return P|0}M=A+108|0;c[M>>2]=0;L=A+100|0;c[L>>2]=0;O=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[O&16383](A,2)|0;do{if((c[M>>2]|0)!=0){O=c[L>>2]|0;c[B>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](B,2,0)|0;if((O|0)<1){P=1;i=f;return P|0}if((gzL(H,0,2)|0)==0){break}else{P=1}i=f;return P|0}}while(0);H=c[3530854]|0;if((c[3542200]|0)==0){P=1;i=f;return P|0}L=y+108|0;c[L>>2]=0;M=y+100|0;c[M>>2]=0;O=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[O&16383](y,3)|0;do{if((c[L>>2]|0)!=0){O=c[M>>2]|0;c[z>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](z,3,0)|0;if((O|0)<1){P=1;i=f;return P|0}if((gzL(H,0,3)|0)==0){break}else{P=1}i=f;return P|0}}while(0);H=(c[3530854]|0)+8192|0;if((c[3542200]|0)==0){P=1;i=f;return P|0}M=w+108|0;c[M>>2]=0;L=w+100|0;c[L>>2]=0;O=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[O&16383](w,4)|0;do{if((c[M>>2]|0)!=0){O=c[L>>2]|0;c[x>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](x,4,0)|0;if((O|0)<1){P=1;i=f;return P|0}if((gzL(H,0,4)|0)==0){break}else{P=1}i=f;return P|0}}while(0);H=c[3531004]|0;if((c[3542200]|0)==0){P=1;i=f;return P|0}L=u+108|0;c[L>>2]=0;M=u+100|0;c[M>>2]=0;O=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[O&16383](u,5)|0;if((c[L>>2]|0)==0){break}L=c[M>>2]|0;c[v>>2]=9534384;M=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[M&16383](v,5,0)|0;if((L|0)<1){P=1;i=f;return P|0}if((gzL(H,0,5)|0)==0){break}else{P=1}i=f;return P|0}}while(0);I=c[3531004]|0;H=c[3530032]|0;L=0;while(1){M=d[I+L|0]|0;c[H+(L<<2)>>2]=(-(M>>>3&1)&33)+(-(M>>>4&1)&71)+(-(M>>>5&1)&151)<<8|(-(M>>>6&1)&71)+(-(M>>>7)&151)|(-(M>>>1&1)&71)+(-(M&1)&33)+(-(M>>>2&1)&151)<<16;M=L+1|0;if((M|0)<32){L=M}else{R=0;break}}while(1){if((R|0)>=1024){break}S=9638528+(R<<2)|0;if((c[S>>2]|0)==0){K=22657;break}else{R=R+1|0}}L30072:do{if((K|0)==22657){L=gGq(16384)|0;c[S>>2]=L;if((L|0)==0){break}gGz(L|0,0,16384);H=c[3530854]|0;gGC(L|0,H|0,16384)|0;I=0;do{M=I<<6;gGz(H+M|0,0,64);O=I<<7;Q=0;do{T=O+(c[611968+(Q<<2)>>2]|0)|0;U=(Q<<3)+M|0;V=0;do{W=T+(c[612768+(V<<2)>>2]|0)|0;if(((d[L+((W|0)/8|0)|0]|0)&128>>>((W&7)>>>0)|0)!=0){W=H+(U+V)|0;a[W]=a[W]|2}V=V+1|0;}while((V|0)<8);Q=Q+1|0;}while((Q|0)<8);Q=O|4;V=0;do{U=Q+(c[611968+(V<<2)>>2]|0)|0;T=(V<<3)+M|0;W=0;do{X=U+(c[612768+(W<<2)>>2]|0)|0;if(((d[L+((X|0)/8|0)|0]|0)&128>>>((X&7)>>>0)|0)!=0){X=H+(T+W)|0;a[X]=a[X]|1}W=W+1|0;}while((W|0)<8);V=V+1|0;}while((V|0)<8);I=I+1|0;}while((I|0)<1024);I=c[3530618]|0;H=0;while(1){V=H<<8;gGz(I+V|0,0,256);M=H<<9;Q=0;do{O=M+(c[611968+(Q<<2)>>2]|0)|0;W=(Q<<3)+V|0;T=0;do{U=O+(c[612768+(T<<2)>>2]|0)|0;if(((d[L+((U|0)/8|0)|0]|0)&128>>>((U&7)>>>0)|0)!=0){U=I+(W+T)|0;a[U]=a[U]|2}T=T+1|0;}while((T|0)<8);Q=Q+1|0;}while((Q|0)<32);Q=M|4;T=0;do{W=Q+(c[611968+(T<<2)>>2]|0)|0;O=(T<<3)+V|0;U=0;do{X=W+(c[612768+(U<<2)>>2]|0)|0;if(((d[L+((X|0)/8|0)|0]|0)&128>>>((X&7)>>>0)|0)!=0){X=I+(O+U)|0;a[X]=a[X]|1}U=U+1|0;}while((U|0)<8);T=T+1|0;}while((T|0)<32);T=H+1|0;if((T|0)<256){H=T}else{Y=0;break}}while(1){if((Y|0)>=1024){break L30072}Z=9638528+(Y<<2)|0;if((c[Z>>2]|0)==(L|0)){break}else{Y=Y+1|0}}gGr(L);c[Z>>2]=0}}while(0);fwR(0);H=c[2439330]|0;I=(H|0)==0;if(!I){T=H;gGC(9706056,T|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];T=c[3528484]|0;c[2076596]=T;V=c[2417276]|0;c[3541536]=V;c[1836236]=0;Q=c[2385932]|0;M=0;U=0;while(1){c[H+76+(U<<2)>>2]=Q+(U<<8);O=M+1&65535;if((O&65535)>79){_=0;$=0;break}else{M=O;U=O&65535}}while(1){U=Q+($<<8)|0;c[H+76+($+512<<2)>>2]=U;c[H+76+($+768<<2)>>2]=U;U=_+1&65535;if((U&65535)>79){break}else{_=U;$=U&65535}}Q=c[2386086]|0;c[H+588>>2]=Q;U=Q+256|0;c[H+592>>2]=U;M=Q+512|0;c[H+596>>2]=M;O=Q+768|0;c[H+600>>2]=O;W=Q+1024|0;c[H+604>>2]=W;X=Q+1280|0;c[H+608>>2]=X;aa=Q+1536|0;c[H+612>>2]=aa;ab=Q+1792|0;c[H+616>>2]=ab;c[H+1612>>2]=Q;c[H+1616>>2]=U;c[H+1620>>2]=M;c[H+1624>>2]=O;c[H+1628>>2]=W;c[H+1632>>2]=X;c[H+1636>>2]=aa;c[H+1640>>2]=ab;c[H+2636>>2]=Q;c[H+3660>>2]=Q;c[H+2640>>2]=U;c[H+3664>>2]=U;c[H+2644>>2]=M;c[H+3668>>2]=M;c[H+2648>>2]=O;c[H+3672>>2]=O;c[H+2652>>2]=W;c[H+3676>>2]=W;c[H+2656>>2]=X;c[H+3680>>2]=X;c[H+2660>>2]=aa;c[H+3684>>2]=aa;c[H+2664>>2]=ab;c[H+3688>>2]=ab;ab=c[2386220]|0;aa=160;X=160;while(1){c[H+76+(X<<2)>>2]=ab+((X<<8)-40960);W=aa+1&65535;if((W&65535)>191){ac=160;ad=160;break}else{aa=W;X=W&65535}}while(1){c[H+76+(ad+256<<2)>>2]=ab+((ad<<8)-40960);X=ac+1&65535;if((X&65535)>191){ae=160;af=160;break}else{ac=X;ad=X&65535}}while(1){X=ab+((af<<8)-40960)|0;c[H+76+(af+512<<2)>>2]=X;c[H+76+(af+768<<2)>>2]=X;X=ae+1&65535;if((X&65535)>191){break}else{ae=X;af=X&65535}}ab=c[2387872]|0;X=192;aa=192;while(1){c[H+76+(aa<<2)>>2]=ab+((aa<<8)-49152);W=X+1&65535;if((W&65535)>223){ah=192;ai=192;break}else{X=W;aa=W&65535}}while(1){c[H+76+(ai+256<<2)>>2]=ab+((ai<<8)-49152);aa=ah+1&65535;if((aa&65535)>223){aj=192;ak=192;break}else{ah=aa;ai=aa&65535}}while(1){aa=ab+((ak<<8)-49152)|0;c[H+76+(ak+512<<2)>>2]=aa;c[H+76+(ak+768<<2)>>2]=aa;aa=aj+1&65535;if((aa&65535)>223){break}else{aj=aa;ak=aa&65535}}c[H+4184>>2]=120;c[H+4180>>2]=1694;c[H+4176>>2]=60;c[H+4172>>2]=1182;if(!I){ab=H;gGC(ab|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=T;c[2417276]=V;c[1836236]=-1;ab=a[9680]|0?32e3:0;c[3542220]=11200;if((c[2113008]|0)==0){gGz(14168888,0,252);c[3542223]=ab;c[3542224]=2566;c[3542225]=0;c[3542226]=0;c[3542227]=0;c[3542234]=~~((+(ab|0)*32768.0*8.0+75.0e4)/15.0e5);ab=31;al=32767.0;while(1){c[14169012+(ab<<2)>>2]=~~(al+.5);aa=ab-1|0;if((aa|0)>0){ab=aa;al=al/1.188502227}else{break}}c[3542253]=0;h[1771269]=1.0;h[1771270]=1.0;h[1771271]=1.0;c[3542574]=3;c[3542575]=3;c[3542576]=3;mB(0);c[2113008]=(c[2113008]|0)+1}h[1771269]=.5;c[3542574]=3;h[1771270]=.5;c[3542575]=3;h[1771271]=.5;c[3542576]=3;ab=c[642608+(c[2436]<<2)>>2]|0;V=c[ab+128>>2]|0;if((c[ab+52>>2]&4|0)==0){c[2113068]=V;T=c[ab+132>>2]|0;c[2113070]=T;c[2443814]=V;c[2440436]=T;am=V;an=T}else{c[2113070]=V;T=c[ab+132>>2]|0;c[2113068]=T;c[2440436]=V;c[2443814]=T;am=T;an=V}V=ag(am<<1,an)|0;T=gGq(V)|0;c[2112926]=T;if((T|0)!=0){gGz(T|0,0,V|0)}V=c[2414688]|0;gGz(V|0,0,(c[2411700]|0)-V|0);V=c[2439330]|0;T=(V|0)==0;if(!T){ab=V;gGC(9706056,ab|0,76)|0}ab=c[2438118]|0;c[2433530]=ab;H=c[3528484]|0;c[2076596]=H;I=c[2417276]|0;c[3541536]=I;c[1836236]=0;gGz(9706056,0,76);if(!T){T=V;gGC(T|0,9706056,76)|0}c[2438118]=ab;c[3528484]=H;c[2417276]=I;c[1836236]=-1;c[2388368]=0;P=0;i=f;return P|0}}while(0);c[2414984]=0;P=1;i=f;return P|0}function dS5(b){b=b|0;return a[9635177]|0}function dS6(a){a=a|0;var b=0,d=0;if(((a&-939524100)-50331648|0)>>>0<14336){b=c[(c[2386470]|0)+(a&16380)>>2]|0;return b|0}d=a&-939532288;if((d|0)==50348032){b=c[(c[2387216]|0)+(a&8188)>>2]|0;return b|0}else if((d|0)==50356224){d=(e[c[2385216]>>1]|0)<<13&67100672|a&8188;if((d|0)>=((c[2394756]<<8)+256|0)){b=0;return b|0}b=c[(c[2387820]|0)+d>>2]|0;return b|0}else{b=0;return b|0}return 0}function dS7(a,b){a=a|0;b=b|0;var d=0;d=a&-939524100;if((d-50331648|0)>>>0<14336){c[(c[2386470]|0)+(a&16380)>>2]=b;return}if((a&-939532288|0)==50348032){c[(c[2387216]|0)+(a&8188)>>2]=b;return}a=d-50348004|0;if(a>>>0>=12){return}c[(c[3529394]|0)+a>>2]=b;return}function dS8(e){e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=e&-939524098^2;if((f-50331648|0)>>>0<14336){g=b[(c[2386470]|0)+(f&16382)>>1]|0;return g|0}if((f&-939532288|0)==50348032){g=b[(c[2387216]|0)+(f&8190)>>1]|0;return g|0}if((f|0)==50348002){e=d[9635169]|0;do{if((c[2406632]|0)==0){h=c[2443744]|0;if((h|0)<=0){i=16;break}c[2443744]=h-1;i=0}else{i=(c[2432962]|0)>>>((c[(c[2420380]|0)+4>>2]|0)>>>0)<<4&16}}while(0);g=(i|e)&65535;return g|0}else if((f|0)==92274690){if(!(a[666048]|0)){g=(c[2387644]|0)>>>16&65535;return g|0}e=a[(c[2405092]|0)+2|0]|0;if((e&1)==0){j=255}else{j=d[9628553]|0}if((e&2)==0){k=j}else{k=(d[9628554]|0)&j}if((e&4)==0){l=k}else{l=(d[9628555]|0)&k}if((e&8)==0){m=l}else{m=(d[9628556]|0)&l}g=(m<<8|255)&65535;return g|0}else if((f|0)==92274688){if(a[666048]|0){g=d[9628552]|0|-256;return g|0}else{g=c[2387644]&65535;return g|0}}else if((f|0)==92274692){if(a[666048]|0){g=d[9628552]|0|-256;return g|0}else{g=c[2387642]&65535;return g|0}}else if((f|0)==92274694){if(!(a[666048]|0)){g=(c[2387642]|0)>>>16&65535;return g|0}f=a[(c[2405092]|0)+2|0]|0;if((f&1)==0){n=255}else{n=d[9628557]|0}if((f&2)==0){o=n}else{o=(d[9628558]|0)&n}if((f&4)==0){p=o}else{p=(d[9628559]|0)&o}if((f&8)==0){q=p}else{q=(d[9628560]|0)&p}g=(q<<8|255)&65535;return g|0}else{g=0;return g|0}return 0}function dS9(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=b&-939524097;if((e-50331648|0)>>>0<14336){f=a[(c[2386470]|0)+(b&16383^3)|0]|0;return f|0}if((b&-939532288|0)==50348032){f=a[(c[2387216]|0)+(b&8191^3)|0]|0;return f|0}if((e|0)==92274692|(e|0)==92274693|(e|0)==92274694|(e|0)==92274695){if(a[666048]|0){g=a[(c[2405092]|0)+2|0]|0;if((g&1)==0){h=255}else{h=d[9628557]|0}if((g&2)==0){i=h}else{i=(d[9628558]|0)&h}if((g&4)==0){j=i}else{j=(d[9628559]|0)&i}if((g&8)==0){k=j}else{k=(d[9628560]|0)&j}l=k<<24|(d[9628552]|0)|16776960}else{l=c[2387642]|0}f=l>>>((b<<3&24^24)>>>0)&255;return f|0}else if((e|0)==92274688|(e|0)==92274689|(e|0)==92274690|(e|0)==92274691){if(a[666048]|0){l=a[(c[2405092]|0)+2|0]|0;if((l&1)==0){m=255}else{m=d[9628553]|0}if((l&2)==0){n=m}else{n=(d[9628554]|0)&m}if((l&4)==0){o=n}else{o=(d[9628555]|0)&n}if((l&8)==0){p=o}else{p=(d[9628556]|0)&o}q=p<<24|(d[9628552]|0)|16776960}else{q=c[2387644]|0}f=q>>>((b<<3&24^24)>>>0)&255;return f|0}else if((e|0)==50348001){b=d[9635169]|0;do{if((c[2406632]|0)==0){q=c[2443744]|0;if((q|0)<=0){r=16;break}c[2443744]=q-1;r=0}else{r=(c[2432962]|0)>>>((c[(c[2420380]|0)+4>>2]|0)>>>0)<<4&16}}while(0);f=(r|b)&255;return f|0}else if((e|0)==83886080){Vy(gj[c[2426988]&4095](a[9680]|0?32e3:0)|0);f=((c[3531833]|0)==1?-128:0)|a[14127331];return f|0}else if((e|0)==83886085){e=c[2443742]|0;c[2443742]=e+1;f=a[(c[2386658]|0)+(e&4194303)|0]|0;return f|0}else{f=0;return f|0}return 0}function dTa(a,d){a=a|0;d=d|0;var e=0,f=0;e=a&-939524098;a=e^2;if((a-50331648|0)>>>0<14336){b[(c[2386470]|0)+(a&16382)>>1]=d;return}if((a&-939532288|0)==50348032){b[(c[2387216]|0)+(a&8190)>>1]=d;return}f=a-50348004|0;if(f>>>0<12){b[(c[3529394]|0)+f>>1]=d;return}if((e|0)!=50348e3){return}e=d&65535;c[2415256]=e&32;d=e>>>7&1;c[3528406]=d^1;if((d|0)==0){c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2]}Tr(e>>>6&1);return}function dTb(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=b&-939524097;if((f-50331648|0)>>>0<14336){a[(c[2386470]|0)+(b&16383^3)|0]=e;return}if((b&-939532288|0)==50348032){a[(c[2387216]|0)+(b&8191^3)|0]=e;return}if((f-50348004|0)>>>0<12){a[(c[3529394]|0)+((f^3)-50348004)|0]=e;return}do{if((f|0)==83886080|(f|0)==83886082|(f|0)==83886084|(f|0)==83886086){g=b>>>1&3;if((g|0)==0){a[14127336]=e;return}else if((g|0)==2){a[14127338]=e;return}else if((g|0)==1){a[14127337]=e;return}else{return}}else if((f|0)==83886081|(f|0)==83886083|(f|0)==83886085|(f|0)==83886087){g=b>>>1&3;if((g|0)==0){Vy(gj[c[2426988]&4095](a[9680]|0?32e3:0)|0);mo(e);return}else if((g|0)==2){Vy(gj[c[2426988]&4095](a[9680]|0?32e3:0)|0);mp(e);return}else{return}}else if((f|0)==50348027){a[(c[2443580]|0)+1|0]=(e<<24>>24<0?127:e)^127;return}else if((f|0)==50348020|(f|0)==50348021|(f|0)==50348022|(f|0)==50348023){a[(c[2387216]|0)+(b&3^8195)|0]=e;return}else if((f|0)==50348019){a[c[2443580]|0]=(e<<24>>24<0?127:e)^127;return}else if((f|0)==50348028|(f|0)==50348029|(f|0)==50348030|(f|0)==50348031){a[(c[2387216]|0)+(b&3^8199)|0]=e;return}else if((f|0)==92274696){if(!(a[666048]|0)){break}g=d[c[2405092]|0]|0;h=g&119;if((c[2432794]|0)==(h|0)){break}i=g>>>4<<20&7340032;c[2432794]=h;h=c[2386658]|0;j=h+2097152|0;k=c[3527286]|0;l=k+(g<<20&7340032)|0;gGC(j|0,l|0,1048576)|0;l=h+3145728|0;h=k+i|0;gGC(l|0,h|0,1048576)|0}else if(!((f|0)==92274699|(f|0)==92274697|(f|0)==92274698)){return}}while(0);a[(c[2405092]|0)+(b&3)|0]=e;return}function dTc(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=a&1048572;do{if((b|0)==(c[251648]|0)){a=c[2424904]|0;d=c[a+100>>2]|0;if((d|0)==0){e=c[a+4>>2]|0}else{e=d}d=e&-939524097;if((d|0)==(c[2440198]|0)){f=a+2400|0;g=a+2404|0;c[g>>2]=(c[g>>2]|0)+(c[f>>2]|0);c[f>>2]=0;c[a+2396>>2]=0;break}if((d|0)!=(c[2440196]|0)){break}d=a+2400|0;f=a+2404|0;c[f>>2]=(c[f>>2]|0)+(c[d>>2]|0);c[d>>2]=0;c[a+2396>>2]=0}}while(0);return c[(c[2386718]|0)+b>>2]|0}function dTd(a){a=a|0;return b[(c[2386718]|0)+(a&1048574^2)>>1]|0}function dTe(b){b=b|0;return a[(c[2386718]|0)+(b&1048575^3)|0]|0}function dTf(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4664188+(b*112|0)>>2];c[a+104>>2]=c[4664192+(b*112|0)>>2];c[a+108>>2]=c[4664196+(b*112|0)>>2];d=0;return d|0}function dTg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=4664088+(b*112|0);e=0;return e|0}function dTh(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>45){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1870816+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dTi(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5350656+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dTj(){a[666048]=1;return dTM(168,33554432)|0}function dTk(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;i=i+128|0;c[2113070]=0;c[2113068]=0;d=c[2112926]|0;if((d|0)!=0){gGr(d);c[2112926]=0}d=c[2411230]|0;if((d|0)!=0){gGr(d);c[2411230]=0}c[2406668]=0;c[2438228]=0;c[2433526]=0;c[2406676]=0;c[3528472]=0;d=c[2406678]|0;if((d|0)!=0){gGr(d);c[2406678]=0}d=b|0;e=c[c[642608+(c[2436]<<2)>>2]>>2]|0;be(d|0,128,179600,(f=i,i=i+24|0,c[f>>2]=9374064,c[f+8>>2]=47,c[f+16>>2]=e,f)|0)|0;i=f;a[1040128]=0;f=c[2420380]|0;e=c[f>>2]|0;g=c[f+4>>2]|0;f=fw(d|0,389440)|0;if((f|0)!=0){d=g>>3<<e&1023;cj(14100392,d|0,1,f|0)|0;aY(f|0)|0}f=c[2414982]|0;d=0;while(1){if((d|0)>=1024){h=22982;break}j=9638528+(d<<2)|0;if((c[j>>2]|0)==(f|0)){break}else{d=d+1|0}}if((h|0)==22982){c[2414982]=0;a[666048]=0;i=b;return 0}gGr(f);c[j>>2]=0;c[2414982]=0;a[666048]=0;i=b;return 0}function dTl(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((a[9624304]|0)!=0){dTQ()}c[(c[2424904]|0)+2404>>2]=0;if(a[666048]|0){gGz(9628552,-1|0,10);b=a[9635168]|-97;a[9628552]=b;e=0;f=b;b=-1;g=-1;h=-1;i=-1;j=-1;k=-1;l=-1;m=-1;do{f=((a[9628632+e|0]&1)<<e^f&255)&255;b=((a[9628624+e|0]&1)<<e^b&255)&255;g=((a[9628616+e|0]&1)<<e^g&255)&255;h=((a[9628608+e|0]&1)<<e^h&255)&255;i=((a[9628600+e|0]&1)<<e^i&255)&255;j=((a[9628592+e|0]&1)<<e^j&255)&255;k=((a[9628584+e|0]&1)<<e^k&255)&255;l=((a[9628576+e|0]&1)<<e^l&255)&255;m=((a[9628568+e|0]&1)<<e^m&255)&255;e=e+1|0;}while((e|0)<8);a[9628552]=f;a[9628553]=b;a[9628554]=g;a[9628555]=h;a[9628556]=i;a[9628557]=j;a[9628558]=k;a[9628559]=l;a[9628560]=m}else{m=d[9635168]|-97;c[2387644]=m;c[2387642]=-1;l=0;k=m;m=-1;do{k=(a[9633640+l|0]&1)<<l^k;m=(a[9631456+l|0]&1)<<l^m;l=l+1|0;}while((l|0)<32);c[2387644]=k;c[2387642]=m}m=c[2438228]|0;k=gGS(103809024,227581,m,(m|0)<0|0?-1:0)|0;m=k;Sb(477272);k=c[2443830]|0;if((k|0)<1073676288){c[2443830]=k-m}k=c[2443831]|0;if((k|0)<1073676288){c[2443831]=k-m}k=(c[3528512]|0)-m|0;c[3528512]=(k|0)<0?0:k;ge$(4);geZ(0)|0;k=c[2424904]|0;m=k+264|0;if((a[m]|0)!=0){a[m]=0;m=k+124|0;c[m>>2]=c[m>>2]&-17}Vy(a[9688]|0?534:0);if((c[2112968]|0)==0){return 0}dTm()|0;return 0}function dTm(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=c[2387216]|0;e=c[3530030]|0;f=c[2443580]|0;g=a[f]|0;h=g&255;i=d;if(g<<24>>24==127){g=0;do{j=c[i+(g<<2)>>2]|0;c[e+(g<<2)>>2]=j>>>16<<3&2016|j>>>11&31|j>>>24<<8&63488;g=g+1|0;}while((g|0)<2048)}else{g=0;do{j=c[i+(g<<2)>>2]|0;k=(((ag(j>>>24,h)|0)>>>0)/127|0)<<8&63488;l=(((ag(j>>>16&255,h)|0)>>>0)/127|0)<<3&2016|k;c[e+(g<<2)>>2]=l|(((ag(j>>>8&255,h)|0)>>>0)/127|0)>>>3&31;g=g+1|0;}while((g|0)<2048)}g=a[f+1|0]|0;f=g&255;if(g<<24>>24==127){g=0;do{h=c[i+(g<<2)>>2]|0;c[e+(g+2048<<2)>>2]=h>>>16<<3&2016|h>>>11&31|h>>>24<<8&63488;g=g+1|0;}while((g|0)<2048)}else{g=0;do{h=c[i+(g<<2)>>2]|0;j=(((ag(h>>>24,f)|0)>>>0)/127|0)<<8&63488;l=(((ag(h>>>16&255,f)|0)>>>0)/127|0)<<3&2016|j;c[e+(g+2048<<2)>>2]=l|(((ag(h>>>8&255,f)|0)>>>0)/127|0)>>>3&31;g=g+1|0;}while((g|0)<2048)}g=c[d+8192>>2]|0;c[e+16384>>2]=g>>>16<<3&2016|g>>>11&31|g>>>24<<8&63488;g=c[d+8196>>2]|0;c[e+16388>>2]=g>>>16<<3&2016|g>>>11&31|g>>>24<<8&63488;g=c[2112926]|0;gGz(g|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);d=c[2113070]|0;f=(d|0)>0;i=c[2385350]|0;if(f){h=0;while(1){l=h*640|0;j=h*320|0;k=0;do{b[g+(k+l<<1)>>1]=4096;b[i+(k+j<<1)>>1]=4097;k=k+1|0;}while((k|0)<320);k=h+1|0;if((k|0)<(d|0)){h=k}else{m=i;break}}}else{m=i}c[2113068]=640;dTV(g,0);c[2113068]=320;dTV(m,8192);c[2113068]=640;if(f){n=0}else{R8(e);return 0}do{f=g+((n*640|0)+320<<1)|0;i=m+((n*320|0)<<1)|0;gGC(f|0,i|0,640)|0;n=n+1|0;}while((n|0)<(d|0));R8(e);return 0}function dTn(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+96|0;g=f|0;h=f+16|0;j=f+32|0;k=f+48|0;l=f+64|0;m=f+80|0;n=(e|0)==0;if(!n){c[e>>2]=169735}if((b&32|0)!=0){o=c[2414686]|0;c[m>>2]=o;c[m+4>>2]=(c[2411698]|0)-o;c[m+8>>2]=0;c[m+12>>2]=196728;o=c[2076592]|0;gj[o&4095](m)|0}if((b&64|0)!=0){ge4(b);do{if(!n){if((c[e>>2]|0)>=169249){break}c[e>>2]=169249}}while(0);gGz(k|0,0,12);c[k>>2]=9775320;c[k+4>>2]=8;c[k+12>>2]=111920;e=c[2076592]|0;gj[e&4095](k)|0;gGz(j|0,0,12);c[j>>2]=9775288;c[j+4>>2]=8;c[j+12>>2]=478936;k=c[2076592]|0;gj[k&4095](j)|0;gGz(h|0,0,12);c[h>>2]=53400;c[h+4>>2]=8;c[h+12>>2]=398448;j=c[2076592]|0;gj[j&4095](h)|0;gGz(g|0,0,12);c[g>>2]=14114048;c[g+4>>2]=4;c[g+12>>2]=287368;h=c[2076592]|0;gj[h&4095](g)|0;gGz(l|0,0,12);c[l>>2]=9774968;c[l+4>>2]=4;c[l+12>>2]=68456;g=c[2076592]|0;gj[g&4095](l)|0}if((b&2|0)==0){i=f;return 0}if(!(a[666048]|0)){i=f;return 0}b=d[c[2405092]|0]|0;l=b&119;if((c[2432794]|0)==(l|0)){i=f;return 0}g=b>>>4<<20&7340032;c[2432794]=l;l=c[2386658]|0;h=l+2097152|0;j=c[3527286]|0;k=j+(b<<20&7340032)|0;gGC(h|0,k|0,1048576)|0;k=l+3145728|0;l=j+g|0;gGC(k|0,l|0,1048576)|0;i=f;return 0}function dTo(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2766628+(b*112|0)>>2];c[a+104>>2]=c[2766632+(b*112|0)>>2];c[a+108>>2]=c[2766636+(b*112|0)>>2];d=0;return d|0}function dTp(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=2766528+(b*112|0);e=0;return e|0}function dTq(){a[666048]=1;return dTM(1916,50331648)|0}function dTr(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2758452+(b*112|0)>>2];c[a+104>>2]=c[2758456+(b*112|0)>>2];c[a+108>>2]=c[2758460+(b*112|0)>>2];d=0;return d|0}function dTs(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<21&(d|0)==0)){e=1;return e|0}c[a>>2]=2758352+(b*112|0);e=0;return e|0}function dTt(){a[666048]=1;return dTM(4490,67108864)|0}function dTu(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2760804+(b*112|0)>>2];c[a+104>>2]=c[2760808+(b*112|0)>>2];c[a+108>>2]=c[2760812+(b*112|0)>>2];d=0;return d|0}function dTv(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<21&(d|0)==0)){e=1;return e|0}c[a>>2]=2760704+(b*112|0);e=0;return e|0}function dTw(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2756100+(b*112|0)>>2];c[a+104>>2]=c[2756104+(b*112|0)>>2];c[a+108>>2]=c[2756108+(b*112|0)>>2];d=0;return d|0}function dTx(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<21&(d|0)==0)){e=1;return e|0}c[a>>2]=2756e3+(b*112|0);e=0;return e|0}function dTy(){a[666048]=1;return dTM(180,67108864)|0}function dTz(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2638892+(b*112|0)>>2];c[a+104>>2]=c[2638896+(b*112|0)>>2];c[a+108>>2]=c[2638900+(b*112|0)>>2];d=0;return d|0}function dTA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=2638792+(b*112|0);e=0;return e|0}function dTB(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>40){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1234048+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dTC(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3796368+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dTD(){c[251648]=32;c[2440198]=6974;c[2440196]=6976;return dTM(276,33554432)|0}function dTE(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1510316+(b*112|0)>>2];c[a+104>>2]=c[1510320+(b*112|0)>>2];c[a+108>>2]=c[1510324+(b*112|0)>>2];d=0;return d|0}function dTF(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=1510216+(b*112|0);e=0;return e|0}function dTG(){c[251648]=32;c[2440198]=6986;c[2440196]=6988;return dTM(276,33554432)|0}function dTH(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2764276+(b*112|0)>>2];c[a+104>>2]=c[2764280+(b*112|0)>>2];c[a+108>>2]=c[2764284+(b*112|0)>>2];d=0;return d|0}function dTI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=2764176+(b*112|0);e=0;return e|0}function dTJ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>27){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1239616+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dTK(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3862736+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dTL(){c[251648]=28;c[2440198]=10734;c[2440196]=10736;return dTM(3184,25165824)|0}function dTM(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;c[2414982]=0;c[2386714]=0;c[2387820]=3145728;e=d+3145728|0;c[2386658]=e;f=d+7340032|0;g=f|0;if(a[666048]|0){c[3527286]=g;i=d+15728640|0}else{i=g}c[2414686]=i;c[3529394]=i;c[2386718]=i+12;c[2386470]=i+1048588;c[2387216]=i+1062924;c[2443580]=i+1071124;c[2405092]=i+1071126;g=i+1071130|0;c[2411698]=g;c[2385350]=g;c[3530030]=i+1234970;g=i+1251362|0;c[2385216]=i+8;c[2414238]=g;i=g;g=0;while(1){if((g|0)>=1024){break}j=9638528+(g<<2)|0;if((c[j>>2]|0)==0){k=23159;break}else{g=g+1|0}}do{if((k|0)==23159){g=gGq(i)|0;c[j>>2]=g;if((g|0)==0){break}gGz(g|0,0,i|0);c[2414982]=g;gGz(g|0,0,i|0);c[2386714]=g;c[2387820]=g+3145728;c[2386658]=g+e;l=g+f|0;if(a[666048]|0){c[3527286]=l;m=g+(d+15728640)|0}else{m=l}c[2414686]=m;c[3529394]=m;c[2386718]=m+12;c[2386470]=m+1048588;c[2387216]=m+1062924;c[2443580]=m+1071124;c[2405092]=m+1071126;l=m+1071130|0;c[2411698]=l;c[2385350]=l;c[3530030]=m+1234970;c[2385216]=m+8;c[2414238]=m+1251362;do{if((b|0)==0){n=g}else{if((gD[b&8191]()|0)==0){n=c[2386714]|0;break}else{o=1;return o|0}}}while(0);g=0;while(1){l=n+(g|1)|0;p=a[l]|0;q=n+(g|2)|0;a[l]=a[q]|0;a[q]=p;p=g+4|0;if((p|0)<1048576){g=p}else{r=0;s=n;break}}while(1){g=a[s]|0;p=s+1|0;a[s]=a[p]|0;a[p]=g;g=r+1|0;if((g|0)<1572864){r=g;s=s+2|0}else{t=0;break}}do{g=n+t|0;p=a[g]|0;q=n+(t|3)|0;a[g]=a[q]|0;a[q]=p;p=n+(t|1)|0;q=a[p]|0;g=n+(t|2)|0;a[p]=a[g]|0;a[g]=q;t=t+4|0;}while((t|0)<3145728);q=c[2387820]|0;if((d|0)>0){g=0;do{p=q+(g|1)|0;l=a[p]|0;u=q+(g|2)|0;a[p]=a[u]|0;a[u]=l;g=g+4|0;}while((g|0)<(d|0))}if(a[666048]|0){g=c[2386658]|0;q=c[3527286]|0;gGC(g|0,q|0,2097152)|0}geV();q=c[2411230]|0;c[2406668]=q;c[2424904]=q;g=c[2386714]|0;l=q+2412|0;u=0;p=0;while(1){v=g+p|0;c[l>>2]=v;c[l+524288>>2]=v;c[l+8192>>2]=v;c[l+16384>>2]=v;c[l+24576>>2]=v;c[l+32768>>2]=v;c[l+40960>>2]=v;c[l+49152>>2]=v;c[l+57344>>2]=v;c[l+532480>>2]=v;c[l+540672>>2]=v;c[l+548864>>2]=v;c[l+557056>>2]=v;c[l+565248>>2]=v;c[l+573440>>2]=v;c[l+581632>>2]=v;v=gGK(p,u,65536,0)|0;w=K;x=0;if(w>>>0>x>>>0|w>>>0==x>>>0&v>>>0>1048575>>>0){break}else{l=l+4|0;u=w;p=v}}p=q+4460|0;u=0;l=33554432;while(1){v=g+(l-32505856)|0;c[p>>2]=v;c[p+524288>>2]=v;c[p+8192>>2]=v;c[p+16384>>2]=v;c[p+24576>>2]=v;c[p+32768>>2]=v;c[p+40960>>2]=v;c[p+49152>>2]=v;c[p+57344>>2]=v;c[p+532480>>2]=v;c[p+540672>>2]=v;c[p+548864>>2]=v;c[p+557056>>2]=v;c[p+565248>>2]=v;c[p+573440>>2]=v;c[p+581632>>2]=v;v=gGK(l,u,65536,0)|0;w=K;x=0;if(w>>>0>x>>>0|w>>>0==x>>>0&v>>>0>35651583>>>0){break}else{p=p+4|0;u=w;l=v}}l=c[2386718]|0;u=q+8556|0;p=0;g=100663296;while(1){v=l+(g-100663296)|0;c[u>>2]=v;c[u+262144>>2]=v;c[u+524288>>2]=v;c[u+8192>>2]=v;c[u+16384>>2]=v;c[u+24576>>2]=v;c[u+32768>>2]=v;c[u+40960>>2]=v;c[u+49152>>2]=v;c[u+57344>>2]=v;c[u+270336>>2]=v;c[u+278528>>2]=v;c[u+286720>>2]=v;c[u+294912>>2]=v;c[u+303104>>2]=v;c[u+311296>>2]=v;c[u+319488>>2]=v;c[u+532480>>2]=v;c[u+540672>>2]=v;c[u+548864>>2]=v;c[u+557056>>2]=v;c[u+565248>>2]=v;c[u+573440>>2]=v;c[u+581632>>2]=v;v=gGK(g,p,65536,0)|0;w=K;x=0;if(w>>>0>x>>>0|w>>>0==x>>>0&v>>>0>101711871>>>0){break}else{u=u+4|0;p=w;g=v}}c[q+788844>>2]=3080;c[q+788908>>2]=1308;c[q+788972>>2]=1510;c[q+788876>>2]=848;c[q+788940>>2]=3146;c[q+789004>>2]=2178;g=c[251648]|0;p=g|100663296;u=g|100728831;g=p>>>0<134217728;l=p&-65536;v=u;w=0;if(l>>>0<=u>>>0){u=q+2412+(p>>>16<<2)|0;p=0;x=l;while(1){c[u>>2]=1;c[u+524288>>2]=1;if(g){c[u+8192>>2]=1;c[u+16384>>2]=1;c[u+24576>>2]=1;c[u+32768>>2]=1;c[u+40960>>2]=1;c[u+49152>>2]=1;c[u+57344>>2]=1;c[u+532480>>2]=1;c[u+540672>>2]=1;c[u+548864>>2]=1;c[u+557056>>2]=1;c[u+565248>>2]=1;c[u+573440>>2]=1;c[u+581632>>2]=1}l=gGK(x,p,65536,0)|0;y=K;if(y>>>0>w>>>0|y>>>0==w>>>0&l>>>0>v>>>0){break}else{u=u+4|0;p=y;x=l}}}c[q+788848>>2]=3528;c[q+788912>>2]=242;c[q+788976>>2]=470;Vz(c[2386658]|0,2862,2752);h[607289]=1.0;c[2433120]=3;h[607288]=1.0;c[2433118]=3;c[2438228]=28636350;c[2433526]=3716;c[2406676]=1604;c[3528472]=6968;c[2443846]=70;Tq(689496);c[2394756]=d-1>>8;x=c[642608+(c[2436]<<2)>>2]|0;p=c[x+128>>2]|0;if((c[x+52>>2]&4|0)==0){c[2113068]=p;u=c[x+132>>2]|0;c[2113070]=u;c[2443814]=p;c[2440436]=u;z=p;A=u}else{c[2113070]=p;u=c[x+132>>2]|0;c[2113068]=u;c[2440436]=p;c[2443814]=u;z=u;A=p}p=ag(z<<1,A)|0;u=gGq(p)|0;c[2112926]=u;if((u|0)!=0){gGz(u|0,0,p|0)}dTQ();o=0;return o|0}}while(0);c[2414982]=0;o=1;return o|0}function dTN(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0;a=i;i=i+120|0;b=a|0;d=a+112|0;if((R6((c[2386714]|0)+1|0,0,2)|0)!=0){e=1;i=a;return e|0}if((R6(c[2386714]|0,1,2)|0)!=0){e=1;i=a;return e|0}if((R6(c[2387820]|0,2,2)|0)!=0){e=1;i=a;return e|0}if((R6((c[2387820]|0)+1|0,3,2)|0)!=0){e=1;i=a;return e|0}if((R6((c[2387820]|0)+8388608|0,4,2)|0)!=0){e=1;i=a;return e|0}if((R6((c[2387820]|0)+8388609|0,5,2)|0)!=0){e=1;i=a;return e|0}if((R6((c[2387820]|0)+16777216|0,6,2)|0)!=0){e=1;i=a;return e|0}if((R6((c[2387820]|0)+16777217|0,7,2)|0)!=0){e=1;i=a;return e|0}f=c[2386658]|0;if((c[3542200]|0)==0){e=1;i=a;return e|0}g=b+108|0;c[g>>2]=0;h=b+100|0;c[h>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](b,8)|0;if((c[g>>2]|0)==0){e=0;i=a;return e|0}g=c[h>>2]|0;c[d>>2]=9534384;gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](d,8,0)|0;if((g|0)<1){e=1;i=a;return e|0}e=(gzL(f,0,8)|0)!=0|0;i=a;return e|0}function dTO(b,d){b=b|0;d=d|0;if((d|0)!=0){ge$(12);return}d=c[2424904]|0;b=d+272|0;if((a[b]|0)==0){return}a[b]=0;b=d+124|0;c[b>>2]=c[b>>2]&-4097;return}function dTP(a){a=a|0;var b=0,d=0;b=c[(c[2424904]|0)+2404>>2]|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,28636350,0)|0;return a|0}function dTQ(){var b=0,d=0,e=0,f=0,g=0,i=0,j=0,k=0;b=c[2406668]|0;d=c[b+2412>>2]|0;if(d>>>0>7){e=c[d>>2]|0;f=b;g=d}else{i=gj[c[b+788972+(d<<2)>>2]&4095](0)|0;d=c[2406668]|0;e=i;f=d;g=c[d+2412>>2]|0}if(g>>>0>7){j=c[g+4>>2]|0;k=f}else{d=gj[c[f+788972+(g<<2)>>2]&4095](4)|0;j=d;k=c[2406668]|0}d=c[2424904]|0;gGz(d|0,0,2408);g=d+4|0;c[d+92>>2]=j;c[d+12>>2]=240;j=e&-939524097;c[g>>2]=j;e=c[k+2412+((j>>>16|131072)<<2)>>2]|0;j=k+789036|0;c[j>>2]=e;c[j>>2]=e+(-(c[g>>2]&-65536)|0);c[d+2348>>2]=-1;d=c[2414686]|0;gGz(d|0,0,(c[2411698]|0)-d|0);c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];if(!(a[1040128]|0)){d=c[2386718]|0;gGC(14100392,d|0,256)|0}c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;c[2443742]=0;d=c[2405092]|0;g=d;C=-1;a[g]=C&255;C=C>>8;a[g+1|0]=C&255;C=C>>8;a[g+2|0]=C&255;C=C>>8;a[g+3|0]=C&255;a[d+2|0]=50;if(!(a[666048]|0)){return}c[2432794]=119;d=c[2386658]|0;g=d+2097152|0;e=(c[3527286]|0)+7340032|0;gGC(g|0,e|0,1048576)|0;g=d+3145728|0;gGC(g|0,e|0,1048576)|0;return}function dTR(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0;a=i;i=i+120|0;b=a|0;d=a+112|0;if((R6((c[2386714]|0)+1|0,0,2)|0)!=0){e=1;i=a;return e|0}if((R6(c[2386714]|0,1,2)|0)!=0){e=1;i=a;return e|0}f=c[2387820]|0;if((c[3542200]|0)==0){e=1;i=a;return e|0}g=b+108|0;c[g>>2]=0;h=b+100|0;c[h>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](b,6)|0;do{if((c[g>>2]|0)!=0){b=c[h>>2]|0;c[d>>2]=9534384;j=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[j&16383](d,6,0)|0;if((b|0)<1){e=1;i=a;return e|0}if((gzL(f,0,6)|0)==0){break}else{e=1}i=a;return e|0}}while(0);f=c[2386658]|0;d=c[2387820]|0;gGC(f|0,d|0,4194304)|0;if((R6(d,2,2)|0)!=0){e=1;i=a;return e|0}if((R6((c[2387820]|0)+1|0,3,2)|0)!=0){e=1;i=a;return e|0}if((R6((c[2387820]|0)+16777216|0,4,2)|0)!=0){e=1;i=a;return e|0}e=(R6((c[2387820]|0)+16777217|0,5,2)|0)!=0|0;i=a;return e|0}function dTS(){var a=0,b=0,d=0,e=0;if((dTT()|0)!=0){a=1;return a|0}b=c[2387820]|0;d=b+4194304|0;gGC(d|0,b|0,4194304)|0;d=b+12582912|0;e=b+8388608|0;gGC(d|0,e|0,4194304)|0;e=b+20971520|0;d=b+16777216|0;gGC(e|0,d|0,4194304)|0;d=b+29360128|0;e=b+25165824|0;gGC(d|0,e|0,4194304)|0;e=b+37748736|0;d=b+33554432|0;gGC(e|0,d|0,4194304)|0;d=b+46137344|0;e=b+41943040|0;gGC(d|0,e|0,4194304)|0;e=b+54525952|0;d=b+50331648|0;gGC(e|0,d|0,4194304)|0;d=b+62914560|0;e=b+58720256|0;gGC(d|0,e|0,4194304)|0;a=0;return a|0}function dTT(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;a=i;i=i+360|0;b=a|0;d=a+112|0;e=a+120|0;f=a+232|0;g=a+240|0;h=a+352|0;if((R6(c[2386714]|0,0,2)|0)!=0){j=1;i=a;return j|0}if((R6((c[2386714]|0)+1|0,1,2)|0)!=0){j=1;i=a;return j|0}k=(c[2386714]|0)+1048576|0;if((c[3542200]|0)==0){j=1;i=a;return j|0}l=g+108|0;c[l>>2]=0;m=g+100|0;c[m>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,2)|0;do{if((c[l>>2]|0)!=0){g=c[m>>2]|0;c[h>>2]=9534384;n=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[n&16383](h,2,0)|0;if((g|0)<1){j=1;i=a;return j|0}if((gzL(k,0,2)|0)==0){break}else{j=1}i=a;return j|0}}while(0);if((R6(c[2387820]|0,3,2)|0)!=0){j=1;i=a;return j|0}if((R6((c[2387820]|0)+1|0,4,2)|0)!=0){j=1;i=a;return j|0}if((R6((c[2387820]|0)+8388608|0,5,2)|0)!=0){j=1;i=a;return j|0}if((R6((c[2387820]|0)+8388609|0,6,2)|0)!=0){j=1;i=a;return j|0}if((R6((c[2387820]|0)+16777216|0,7,2)|0)!=0){j=1;i=a;return j|0}if((R6((c[2387820]|0)+16777217|0,8,2)|0)!=0){j=1;i=a;return j|0}if((R6((c[2387820]|0)+25165824|0,9,2)|0)!=0){j=1;i=a;return j|0}if((R6((c[2387820]|0)+25165825|0,10,2)|0)!=0){j=1;i=a;return j|0}if((R6((c[2387820]|0)+33554432|0,11,2)|0)!=0){j=1;i=a;return j|0}if((R6((c[2387820]|0)+33554433|0,12,2)|0)!=0){j=1;i=a;return j|0}if((R6((c[2387820]|0)+41943040|0,13,2)|0)!=0){j=1;i=a;return j|0}if((R6((c[2387820]|0)+41943041|0,14,2)|0)!=0){j=1;i=a;return j|0}if((R6((c[2387820]|0)+50331648|0,15,2)|0)!=0){j=1;i=a;return j|0}if((R6((c[2387820]|0)+50331649|0,16,2)|0)!=0){j=1;i=a;return j|0}if((R6((c[2387820]|0)+58720256|0,17,2)|0)!=0){j=1;i=a;return j|0}if((R6((c[2387820]|0)+58720257|0,18,2)|0)!=0){j=1;i=a;return j|0}k=c[3527286]|0;if((c[3542200]|0)==0){j=1;i=a;return j|0}h=e+108|0;c[h>>2]=0;m=e+100|0;c[m>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,19)|0;do{if((c[h>>2]|0)!=0){e=c[m>>2]|0;c[f>>2]=9534384;l=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[l&16383](f,19,0)|0;if((e|0)<1){j=1;i=a;return j|0}if((gzL(k,0,19)|0)==0){break}else{j=1}i=a;return j|0}}while(0);k=(c[3527286]|0)+4194304|0;if((c[3542200]|0)==0){j=1;i=a;return j|0}f=b+108|0;c[f>>2]=0;m=b+100|0;c[m>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](b,20)|0;if((c[f>>2]|0)==0){j=0;i=a;return j|0}f=c[m>>2]|0;c[d>>2]=9534384;gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](d,20,0)|0;if((f|0)<1){j=1;i=a;return j|0}j=(gzL(k,0,20)|0)!=0|0;i=a;return j|0}function dTU(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;a=i;i=i+360|0;b=a|0;d=a+112|0;e=a+120|0;f=a+232|0;g=a+240|0;h=a+352|0;if((R6((c[2386714]|0)+1|0,0,2)|0)!=0){j=1;i=a;return j|0}if((R6(c[2386714]|0,1,2)|0)!=0){j=1;i=a;return j|0}k=(c[2386714]|0)+1048576|0;if((c[3542200]|0)==0){j=1;i=a;return j|0}l=g+108|0;c[l>>2]=0;m=g+100|0;c[m>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,2)|0;do{if((c[l>>2]|0)!=0){g=c[m>>2]|0;c[h>>2]=9534384;n=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[n&16383](h,2,0)|0;if((g|0)<1){j=1;i=a;return j|0}if((gzL(k,0,2)|0)==0){break}else{j=1}i=a;return j|0}}while(0);if((R6(c[2387820]|0,3,2)|0)!=0){j=1;i=a;return j|0}if((R6((c[2387820]|0)+1|0,4,2)|0)!=0){j=1;i=a;return j|0}if((R6((c[2387820]|0)+8388608|0,5,2)|0)!=0){j=1;i=a;return j|0}if((R6((c[2387820]|0)+8388609|0,6,2)|0)!=0){j=1;i=a;return j|0}if((R6((c[2387820]|0)+16777216|0,7,2)|0)!=0){j=1;i=a;return j|0}if((R6((c[2387820]|0)+16777217|0,8,2)|0)!=0){j=1;i=a;return j|0}if((R6((c[2387820]|0)+25165824|0,9,2)|0)!=0){j=1;i=a;return j|0}if((R6((c[2387820]|0)+25165825|0,10,2)|0)!=0){j=1;i=a;return j|0}if((R6((c[2387820]|0)+33554432|0,11,2)|0)!=0){j=1;i=a;return j|0}if((R6((c[2387820]|0)+33554433|0,12,2)|0)!=0){j=1;i=a;return j|0}if((R6((c[2387820]|0)+41943040|0,13,2)|0)!=0){j=1;i=a;return j|0}if((R6((c[2387820]|0)+41943041|0,14,2)|0)!=0){j=1;i=a;return j|0}k=c[3527286]|0;if((c[3542200]|0)==0){j=1;i=a;return j|0}h=e+108|0;c[h>>2]=0;m=e+100|0;c[m>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,15)|0;do{if((c[h>>2]|0)!=0){e=c[m>>2]|0;c[f>>2]=9534384;l=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[l&16383](f,15,0)|0;if((e|0)<1){j=1;i=a;return j|0}if((gzL(k,0,15)|0)==0){break}else{j=1}i=a;return j|0}}while(0);k=(c[3527286]|0)+4194304|0;if((c[3542200]|0)==0){j=1;i=a;return j|0}f=b+108|0;c[f>>2]=0;m=b+100|0;c[m>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](b,16)|0;if((c[f>>2]|0)==0){j=0;i=a;return j|0}f=c[m>>2]|0;c[d>>2]=9534384;gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](d,16,0)|0;if((f|0)<1){j=1;i=a;return j|0}j=(gzL(k,0,16)|0)!=0|0;i=a;return j|0}function dTV(a,d){a=a|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;e=c[2386470]|0;f=e;g=e+11268|0;e=c[(c[3529394]|0)+4>>2]|0;h=d&65535;i=(d|0)!=0;d=i|(e&1073741824|0)==0;j=(e&4194304|0)==0|i^1;e=c[2394756]|0;k=c[2387820]|0;l=0;while(1){if((l&65535)>=1534){m=23398;break}n=b[g+((l&65535^1)<<1)>>1]|0;o=n&65535;if(!((o&32768|0)!=0|(o&8192|0)!=(h|0))){p=n<<1&2046;n=c[f+(p<<2)>>2]|0;q=n>>>16;r=n>>>28;s=r+1|0;t=n>>>12&15;u=t+1|0;v=c[f+((p|1)<<2)>>2]|0;p=v&524287;w=v>>>24&63;x=v&1073741824;y=(q&512|0)==0?q&1023:q|-1024;q=(n&512|0)==0?n&1023:n|-1024;n=i?w|64:w;if(d){if(j){z=v&-2147483648;A=x;B=q;C=y}else{m=23382}}else{m=23382}if((m|0)==23382){m=0;z=v>>>31^1;A=x>>>30^1;B=320-q-(u<<4)|0;C=(c[2113070]|0)-(y+(s<<4))|0}y=(A|0)!=0;q=y?-1:1;x=y?-1:u;u=y?t:0;t=(z|0)!=0;v=t?-1:1;w=t?-1:s;s=0;D=t?r:0;while(1){r=(D<<4)+C|0;E=(r|0)>-16;F=c[2113070]|0;if(t){G=s;H=u;while(1){I=(H<<4)+B|0;J=G+p|0;do{if(!((e|0)<(J|0)|E&(I+15|0)>>>0<335&(r|0)<(F|0)^1)){if(y){SN(a,J,I,r,n,5,0,0,k);break}else{SL(a,J,I,r,n,5,0,0,k);break}}}while(0);I=H+q|0;J=G+1|0;if((I|0)==(x|0)){K=J;break}else{G=J;H=I}}}else{H=s;G=u;while(1){I=(G<<4)+B|0;J=H+p|0;do{if(!((e|0)<(J|0)|E&(I+15|0)>>>0<335&(r|0)<(F|0)^1)){if(y){SJ(a,J,I,r,n,5,0,0,k);break}else{SH(a,J,I,r,n,5,0,0,k);break}}}while(0);I=G+q|0;J=H+1|0;if((I|0)==(x|0)){K=J;break}else{H=J;G=I}}}G=D+v|0;if((G|0)==(w|0)){break}else{s=K;D=G}}}if((o&16384|0)==0){l=l+1&65535}else{m=23399;break}}if((m|0)==23398){return}else if((m|0)==23399){return}}function dTW(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;a=i;i=i+360|0;b=a|0;d=a+112|0;e=a+120|0;f=a+232|0;g=a+240|0;h=a+352|0;if((R6((c[2386714]|0)+1|0,0,2)|0)!=0){j=1;i=a;return j|0}if((R6(c[2386714]|0,1,2)|0)!=0){j=1;i=a;return j|0}k=(c[2386714]|0)+1048576|0;if((c[3542200]|0)==0){j=1;i=a;return j|0}l=g+108|0;c[l>>2]=0;m=g+100|0;c[m>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,2)|0;do{if((c[l>>2]|0)!=0){g=c[m>>2]|0;c[h>>2]=9534384;n=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[n&16383](h,2,0)|0;if((g|0)<1){j=1;i=a;return j|0}if((gzL(k,0,2)|0)==0){break}else{j=1}i=a;return j|0}}while(0);if((R6(c[2387820]|0,3,2)|0)!=0){j=1;i=a;return j|0}if((R6((c[2387820]|0)+1|0,4,2)|0)!=0){j=1;i=a;return j|0}if((R6((c[2387820]|0)+8388608|0,5,2)|0)!=0){j=1;i=a;return j|0}if((R6((c[2387820]|0)+8388609|0,6,2)|0)!=0){j=1;i=a;return j|0}if((R6((c[2387820]|0)+16777216|0,7,2)|0)!=0){j=1;i=a;return j|0}if((R6((c[2387820]|0)+16777217|0,8,2)|0)!=0){j=1;i=a;return j|0}if((R6((c[2387820]|0)+25165824|0,9,2)|0)!=0){j=1;i=a;return j|0}if((R6((c[2387820]|0)+25165825|0,10,2)|0)!=0){j=1;i=a;return j|0}k=c[3527286]|0;if((c[3542200]|0)==0){j=1;i=a;return j|0}h=e+108|0;c[h>>2]=0;m=e+100|0;c[m>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,11)|0;do{if((c[h>>2]|0)!=0){e=c[m>>2]|0;c[f>>2]=9534384;l=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[l&16383](f,11,0)|0;if((e|0)<1){j=1;i=a;return j|0}if((gzL(k,0,11)|0)==0){break}else{j=1}i=a;return j|0}}while(0);k=(c[3527286]|0)+4194304|0;if((c[3542200]|0)==0){j=1;i=a;return j|0}f=b+108|0;c[f>>2]=0;m=b+100|0;c[m>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](b,12)|0;if((c[f>>2]|0)==0){j=0;i=a;return j|0}f=c[m>>2]|0;c[d>>2]=9534384;gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](d,12,0)|0;if((f|0)<1){j=1;i=a;return j|0}j=(gzL(k,0,12)|0)!=0|0;i=a;return j|0}function dTX(a,b){a=a|0;b=b|0;return}function dTY(a,d){a=a|0;d=d|0;var e=0;e=a&-939524097^2;if((e&-939524608|0)!=50659328){return}b[(c[3529098]|0)+(e&510)>>1]=d;return}function dTZ(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=b&-939524097;if((b&-939524608|0)==50659328){a[(c[3529098]|0)+(b&511^3)|0]=d;return}if((b&-939524128|0)==50724832){f=e^3;g=c[3529392]|0;a[g+(f&31)|0]=d;a[(c[3529098]|0)+(f&65535)|0]=d;if((f&28|0)!=16){return}f=c[g+16>>2]<<17&66977792;if((f|0)==(c[2427062]|0)){return}c[2427062]=f;g=c[2432950]|0;h=f-g|0;f=c[2432948]|0;i=(h|0)>-1&(h|0)<(f|0)?h:f-g|0;g=c[2112938]|0;f=c[2406668]|0;h=g+i|0;c[f+5508>>2]=h;c[f+529796>>2]=h;c[f+13700>>2]=h;c[f+21892>>2]=h;c[f+30084>>2]=h;c[f+38276>>2]=h;c[f+46468>>2]=h;c[f+54660>>2]=h;c[f+62852>>2]=h;c[f+537988>>2]=h;c[f+546180>>2]=h;c[f+554372>>2]=h;c[f+562564>>2]=h;c[f+570756>>2]=h;c[f+578948>>2]=h;c[f+587140>>2]=h;j=g+(i+65536)|0;c[f+5512>>2]=j;c[f+529800>>2]=j;c[f+13704>>2]=j;c[f+21896>>2]=j;c[f+30088>>2]=j;c[f+38280>>2]=j;c[f+46472>>2]=j;c[f+54664>>2]=j;c[f+62856>>2]=j;c[f+537992>>2]=j;c[f+546184>>2]=j;c[f+554376>>2]=j;c[f+562568>>2]=j;c[f+570760>>2]=j;c[f+578952>>2]=j;c[f+587144>>2]=j;c[f+6532>>2]=h;c[f+530820>>2]=h;c[f+14724>>2]=h;c[f+22916>>2]=h;c[f+31108>>2]=h;c[f+39300>>2]=h;c[f+47492>>2]=h;c[f+55684>>2]=h;c[f+63876>>2]=h;c[f+539012>>2]=h;c[f+547204>>2]=h;c[f+555396>>2]=h;c[f+563588>>2]=h;c[f+571780>>2]=h;c[f+579972>>2]=h;c[f+588164>>2]=h;c[f+6536>>2]=j;c[f+530824>>2]=j;c[f+14728>>2]=j;c[f+22920>>2]=j;c[f+31112>>2]=j;c[f+39304>>2]=j;c[f+47496>>2]=j;c[f+55688>>2]=j;c[f+63880>>2]=j;c[f+539016>>2]=j;c[f+547208>>2]=j;c[f+555400>>2]=j;c[f+563592>>2]=j;c[f+571784>>2]=j;c[f+579976>>2]=j;c[f+588168>>2]=j;return}if((e|0)==50724829){if((d&255)>63){return}j=c[2424904]|0;f=j+264|0;if((a[f]|0)==0){return}a[f]=0;f=j+124|0;c[f>>2]=c[f>>2]&-17;return}else if((e|0)==83886080|(e|0)==83886082|(e|0)==83886084){f=b>>>1&3;if((f|0)==1){a[14127337]=d;return}else if((f|0)==0){a[14127336]=d;return}else if((f|0)==2){a[14127338]=d;return}else{return}}else if((e|0)==92274692){f=d&255;c[2415256]=f&32;j=f>>>7;c[3528406]=j^1;if((j|0)!=1){c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2]}Tr(f>>>6&1);return}else if((e|0)==83886081|(e|0)==83886083|(e|0)==83886085){e=b>>>1&3;if((e|0)==0){Vy(gj[c[2426988]&4095](a[9680]|0?32e3:0)|0);mo(d);return}else if((e|0)==2){Vy(gj[c[2426988]&4095](a[9680]|0?32e3:0)|0);mp(d);return}else{return}}else{return}}function dT_(b){b=b|0;var e=0,f=0,g=0,h=0,i=0;e=b&-939524097;if((e|0)==83886085){f=c[2443740]|0;c[2443740]=f+1;g=a[(c[2386656]|0)+(f&4194303)|0]|0;return g|0}else if((e|0)==83886080){Vy(gj[c[2426988]&4095](a[9680]|0?32e3:0)|0);g=((c[3531833]|0)==1?-128:0)|a[14127331];return g|0}else if((e|0)==92274692){f=d[9635161]|0;do{if((c[2406632]|0)==0){h=c[2443744]|0;if((h|0)<=0){i=16;break}c[2443744]=h-1;i=0}else{i=(c[2432962]|0)>>>((c[(c[2420380]|0)+4>>2]|0)>>>0)<<4&16}}while(0);g=(i|f)&255;return g|0}else if((e|0)==92274688|(e|0)==92274689|(e|0)==92274690|(e|0)==92274691){g=(c[2387640]|0)>>>((b<<3&24^24)>>>0)&255;return g|0}else{g=0;return g|0}return 0}function dT$(a,d){a=a|0;d=d|0;var e=0;e=a&-939524097^2;if((e&-939524608|0)!=67436544){return}b[(c[3529098]|0)+(e&510)>>1]=d;return}function dT0(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=b&-939524097;if((b&-939524608|0)==67436544){a[(c[3529098]|0)+(b&511^3)|0]=d;return}if((b&-939524128|0)==67502048){f=e^3;g=c[3529392]|0;a[g+(f&31)|0]=d;a[(c[3529098]|0)+(f&65535)|0]=d;if((f&28|0)!=16){return}f=c[g+16>>2]<<17&66977792;if((f|0)==(c[2427062]|0)){return}c[2427062]=f;g=c[2432950]|0;h=f-g|0;f=c[2432948]|0;i=(h|0)>-1&(h|0)<(f|0)?h:f-g|0;g=c[2112938]|0;f=c[2406668]|0;h=g+i|0;c[f+5508>>2]=h;c[f+529796>>2]=h;c[f+13700>>2]=h;c[f+21892>>2]=h;c[f+30084>>2]=h;c[f+38276>>2]=h;c[f+46468>>2]=h;c[f+54660>>2]=h;c[f+62852>>2]=h;c[f+537988>>2]=h;c[f+546180>>2]=h;c[f+554372>>2]=h;c[f+562564>>2]=h;c[f+570756>>2]=h;c[f+578948>>2]=h;c[f+587140>>2]=h;j=g+(i+65536)|0;c[f+5512>>2]=j;c[f+529800>>2]=j;c[f+13704>>2]=j;c[f+21896>>2]=j;c[f+30088>>2]=j;c[f+38280>>2]=j;c[f+46472>>2]=j;c[f+54664>>2]=j;c[f+62856>>2]=j;c[f+537992>>2]=j;c[f+546184>>2]=j;c[f+554376>>2]=j;c[f+562568>>2]=j;c[f+570760>>2]=j;c[f+578952>>2]=j;c[f+587144>>2]=j;c[f+6532>>2]=h;c[f+530820>>2]=h;c[f+14724>>2]=h;c[f+22916>>2]=h;c[f+31108>>2]=h;c[f+39300>>2]=h;c[f+47492>>2]=h;c[f+55684>>2]=h;c[f+63876>>2]=h;c[f+539012>>2]=h;c[f+547204>>2]=h;c[f+555396>>2]=h;c[f+563588>>2]=h;c[f+571780>>2]=h;c[f+579972>>2]=h;c[f+588164>>2]=h;c[f+6536>>2]=j;c[f+530824>>2]=j;c[f+14728>>2]=j;c[f+22920>>2]=j;c[f+31112>>2]=j;c[f+39304>>2]=j;c[f+47496>>2]=j;c[f+55688>>2]=j;c[f+63880>>2]=j;c[f+539016>>2]=j;c[f+547208>>2]=j;c[f+555400>>2]=j;c[f+563592>>2]=j;c[f+571784>>2]=j;c[f+579976>>2]=j;c[f+588168>>2]=j;return}if((e|0)==51380224|(e|0)==51380226|(e|0)==51380228|(e|0)==51380230){j=b>>>1&3;if((j|0)==0){a[14127336]=d;return}else if((j|0)==1){a[14127337]=d;return}else if((j|0)==2){a[14127338]=d;return}else{return}}else if((e|0)==50331652){j=d&255;c[2415256]=j&32;f=j>>>7;c[3528406]=f^1;if((f|0)!=1){c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2]}Tr(j>>>6&1);return}else if((e|0)==51380225|(e|0)==51380227|(e|0)==51380229|(e|0)==51380231){j=b>>>1&3;if((j|0)==0){Vy(gj[c[2426988]&4095](a[9680]|0?32e3:0)|0);mo(d);return}else if((j|0)==2){Vy(gj[c[2426988]&4095](a[9680]|0?32e3:0)|0);mp(d);return}else{return}}else if((e|0)==67502045){if((d&255)>63){return}d=c[2424904]|0;e=d+264|0;if((a[e]|0)==0){return}a[e]=0;e=d+124|0;c[e>>2]=c[e>>2]&-17;return}else{return}}function dT1(b){b=b|0;var e=0,f=0,g=0,h=0;e=b&-939524097;if((e|0)==51380229){f=c[2443740]|0;c[2443740]=f+1;g=a[(c[2386656]|0)+(f&4194303)|0]|0;return g|0}else if((e|0)==51380224){Vy(gj[c[2426988]&4095](a[9680]|0?32e3:0)|0);g=((c[3531833]|0)==1?-128:0)|a[14127331];return g|0}else if((e|0)==50331648|(e|0)==50331649|(e|0)==50331650|(e|0)==50331651){g=(c[2387640]|0)>>>((b<<3&24^24)>>>0)&255;return g|0}else if((e|0)==50331652){e=d[9635161]|0;do{if((c[2406632]|0)==0){b=c[2443744]|0;if((b|0)<=0){h=16;break}c[2443744]=b-1;h=0}else{h=(c[2432962]|0)>>>((c[(c[2420380]|0)+4>>2]|0)>>>0)<<4&16}}while(0);g=(h|e)&255;return g|0}else{g=0;return g|0}return 0}function dT2(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=a&1048575;do{if((b|0)==(c[251646]|0)){a=c[2424904]|0;d=c[a+100>>2]|0;if((d|0)==0){e=c[a+4>>2]|0}else{e=d}d=e&-939524097;if((d|0)==(c[2440200]|0)){f=a+2400|0;g=a+2404|0;c[g>>2]=(c[g>>2]|0)+(c[f>>2]|0);c[f>>2]=0;c[a+2396>>2]=0;break}if((d|0)==(c[2440201]|0)){f=a+2400|0;g=a+2404|0;c[g>>2]=(c[g>>2]|0)+(c[f>>2]|0);c[f>>2]=0;c[a+2396>>2]=0;break}if((d|0)==(c[2440202]|0)){f=a+2400|0;g=a+2404|0;c[g>>2]=(c[g>>2]|0)+(c[f>>2]|0);c[f>>2]=0;c[a+2396>>2]=0;break}if((d|0)!=(c[2440203]|0)){break}d=a+2400|0;f=a+2404|0;c[f>>2]=(c[f>>2]|0)+(c[d>>2]|0);c[d>>2]=0;c[a+2396>>2]=0}}while(0);return c[(c[2386716]|0)+b>>2]|0}function dT3(a){a=a|0;return b[(c[2386716]|0)+(a&1048575^2)>>1]|0}function dT4(b){b=b|0;return a[(c[2386716]|0)+(b&1048575^3)|0]|0}function dT5(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2254300+(b*112|0)>>2];c[a+104>>2]=c[2254304+(b*112|0)>>2];c[a+108>>2]=c[2254308+(b*112|0)>>2];d=0;return d|0}function dT6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=2254200+(b*112|0);e=0;return e|0}function dT7(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=691704+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dT8(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3418464+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dT9(){c[251646]=12;c[2440200]=110508;c[2440201]=110198;return dUR(3078,0,58720256,33554432)|0}function dUa(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;b=i;i=i+128|0;d=b|0;e=c[3529100]|0;f=0;while(1){if((f|0)>=1024){break}g=9638528+(f<<2)|0;if((c[g>>2]|0)==(e|0)){h=23602;break}else{f=f+1|0}}if((h|0)==23602){gGr(e);c[g>>2]=0}c[3529100]=0;g=c[2387044]|0;e=0;while(1){if((e|0)>=1024){break}j=9638528+(e<<2)|0;if((c[j>>2]|0)==(g|0)){h=23606;break}else{e=e+1|0}}if((h|0)==23606){gGr(g);c[j>>2]=0}c[2387044]=0;j=c[2438736]|0;g=0;while(1){if((g|0)>=1024){break}k=9638528+(g<<2)|0;if((c[k>>2]|0)==(j|0)){h=23610;break}else{g=g+1|0}}if((h|0)==23610){gGr(j);c[k>>2]=0}c[2438736]=0;c[3529496]=0;k=c[3527248]|0;j=0;while(1){if((j|0)>=1024){break}l=9638528+(j<<2)|0;if((c[l>>2]|0)==(k|0)){h=23614;break}else{j=j+1|0}}if((h|0)==23614){gGr(k);c[l>>2]=0}c[3527248]=0;c[1629464]=-1;c[2112938]=0;c[2112940]=0;c[2112944]=0;c[2112936]=0;c[2112942]=0;c[2112934]=0;c[2112966]=0;c[2113070]=0;c[2113068]=0;l=c[2411230]|0;if((l|0)!=0){gGr(l);c[2411230]=0}c[2406668]=0;c[2438228]=0;c[2433526]=0;c[2406676]=0;c[3528472]=0;l=c[2406678]|0;if((l|0)!=0){gGr(l);c[2406678]=0}l=d|0;d=c[c[642608+(c[2436]<<2)>>2]>>2]|0;be(l|0,128,179600,(k=i,i=i+24|0,c[k>>2]=9374064,c[k+8>>2]=47,c[k+16>>2]=d,k)|0)|0;i=k;a[1040128]=0;k=c[2420380]|0;d=c[k>>2]|0;j=c[k+4>>2]|0;k=fw(l|0,389440)|0;if((k|0)!=0){l=j>>3<<d&1023;cj(14100392,l|0,1,k|0)|0;aY(k|0)|0}k=c[2414980]|0;l=0;while(1){if((l|0)>=1024){h=23627;break}m=9638528+(l<<2)|0;if((c[m>>2]|0)==(k|0)){break}else{l=l+1|0}}if((h|0)==23627){c[2414980]=0;c[251646]=-1;gGz(9760800,0,16);i=b;return 0}gGr(k);c[m>>2]=0;c[2414980]=0;c[251646]=-1;gGz(9760800,0,16);i=b;return 0}function dUb(){var b=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((a[9624296]|0)==0){b=c[2424904]|0}else{e=c[2406668]|0;f=c[e+2412>>2]|0;if(f>>>0>7){g=c[f>>2]|0;i=e;j=f}else{k=gj[c[e+788972+(f<<2)>>2]&4095](0)|0;f=c[2406668]|0;g=k;i=f;j=c[f+2412>>2]|0}if(j>>>0>7){l=c[j+4>>2]|0;m=i}else{f=gj[c[i+788972+(j<<2)>>2]&4095](4)|0;l=f;m=c[2406668]|0}f=c[2424904]|0;gGz(f|0,0,2408);j=f+4|0;c[f+92>>2]=l;c[f+12>>2]=240;l=g&-939524097;c[j>>2]=l;g=c[m+2412+((l>>>16|131072)<<2)>>2]|0;l=m+789036|0;c[l>>2]=g;c[l>>2]=g+(-(c[j>>2]&-65536)|0);c[f+2348>>2]=-1;j=c[2414684]|0;gGz(j|0,0,(c[2411696]|0)-j|0);if(!(a[1040128]|0)){j=c[2387856]|0;gGC(14100392,j|0,256)|0}c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;c[2443740]=0;c[2427062]=-1;b=f}c[b+2404>>2]=0;b=d[9635160]|-97;c[2387640]=b;f=0;j=b;do{j=(a[9633608+f|0]&1)<<f^j;f=f+1|0;}while((f|0)<32);c[2387640]=j;j=c[2438228]|0;f=gGS(103809024,227581,j,(j|0)<0|0?-1:0)|0;j=f;Sb(477272);f=c[2443830]|0;if((f|0)<1073676288){c[2443830]=f-j}f=c[2443831]|0;if((f|0)<1073676288){c[2443831]=f-j}f=(c[3528512]|0)-j|0;c[3528512]=(f|0)<0?0:f;ge$(4);if((c[2112964]|0)!=0){Vy(a[9688]|0?534:0)}if((c[2112968]|0)==0){n=c[2386568]|0;o=c[2386468]|0;gGC(n|0,o|0,16384)|0;return 0}dWm()|0;n=c[2386568]|0;o=c[2386468]|0;gGC(n|0,o|0,16384)|0;return 0}function dUc(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;d=i;i=i+96|0;e=d|0;f=d+16|0;g=d+32|0;h=d+48|0;j=d+64|0;k=d+80|0;l=(b|0)==0;if(!l){c[b>>2]=169735}if((a&32|0)!=0){m=c[2414684]|0;c[k>>2]=m;c[k+4>>2]=(c[2411696]|0)-m;c[k+8>>2]=0;c[k+12>>2]=196728;m=c[2076592]|0;gj[m&4095](k)|0}if((a&64|0)!=0){ge4(a);do{if(!l){if((c[b>>2]|0)>=169249){break}c[b>>2]=169249}}while(0);gGz(h|0,0,12);c[h>>2]=9775320;c[h+4>>2]=8;c[h+12>>2]=111920;b=c[2076592]|0;gj[b&4095](h)|0;gGz(g|0,0,12);c[g>>2]=9775288;c[g+4>>2]=8;c[g+12>>2]=478936;h=c[2076592]|0;gj[h&4095](g)|0;gGz(f|0,0,12);c[f>>2]=53400;c[f+4>>2]=8;c[f+12>>2]=398448;g=c[2076592]|0;gj[g&4095](f)|0;gGz(e|0,0,12);c[e>>2]=14114048;c[e+4>>2]=4;c[e+12>>2]=287368;f=c[2076592]|0;gj[f&4095](e)|0;gGz(j|0,0,12);c[j>>2]=9774960;c[j+4>>2]=4;c[j+12>>2]=68456;e=c[2076592]|0;gj[e&4095](j)|0}if((a&2|0)==0){i=d;return 0}a=c[(c[3529392]|0)+16>>2]<<17&66977792;c[2427062]=a;j=c[2432950]|0;e=a-j|0;a=c[2432948]|0;f=(e|0)>-1&(e|0)<(a|0)?e:a-j|0;j=c[2112938]|0;a=c[2406668]|0;e=j+f|0;c[a+5508>>2]=e;c[a+529796>>2]=e;c[a+13700>>2]=e;c[a+21892>>2]=e;c[a+30084>>2]=e;c[a+38276>>2]=e;c[a+46468>>2]=e;c[a+54660>>2]=e;c[a+62852>>2]=e;c[a+537988>>2]=e;c[a+546180>>2]=e;c[a+554372>>2]=e;c[a+562564>>2]=e;c[a+570756>>2]=e;c[a+578948>>2]=e;c[a+587140>>2]=e;g=j+(f+65536)|0;c[a+5512>>2]=g;c[a+529800>>2]=g;c[a+13704>>2]=g;c[a+21896>>2]=g;c[a+30088>>2]=g;c[a+38280>>2]=g;c[a+46472>>2]=g;c[a+54664>>2]=g;c[a+62856>>2]=g;c[a+537992>>2]=g;c[a+546184>>2]=g;c[a+554376>>2]=g;c[a+562568>>2]=g;c[a+570760>>2]=g;c[a+578952>>2]=g;c[a+587144>>2]=g;c[a+6532>>2]=e;c[a+530820>>2]=e;c[a+14724>>2]=e;c[a+22916>>2]=e;c[a+31108>>2]=e;c[a+39300>>2]=e;c[a+47492>>2]=e;c[a+55684>>2]=e;c[a+63876>>2]=e;c[a+539012>>2]=e;c[a+547204>>2]=e;c[a+555396>>2]=e;c[a+563588>>2]=e;c[a+571780>>2]=e;c[a+579972>>2]=e;c[a+588164>>2]=e;c[a+6536>>2]=g;c[a+530824>>2]=g;c[a+14728>>2]=g;c[a+22920>>2]=g;c[a+31112>>2]=g;c[a+39304>>2]=g;c[a+47496>>2]=g;c[a+55688>>2]=g;c[a+63880>>2]=g;c[a+539016>>2]=g;c[a+547208>>2]=g;c[a+555400>>2]=g;c[a+563592>>2]=g;c[a+571784>>2]=g;c[a+579976>>2]=g;c[a+588168>>2]=g;i=d;return 0}function dUd(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4438108+(b*112|0)>>2];c[a+104>>2]=c[4438112+(b*112|0)>>2];c[a+108>>2]=c[4438116+(b*112|0)>>2];d=0;return d|0}function dUe(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=4438008+(b*112|0);e=0;return e|0}function dUf(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=692056+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dUg(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5094552+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dUh(){c[251646]=12;c[2440200]=101317738;c[2440201]=101318356;c[2440202]=101319026;return dUR(1706,0,33554432,0)|0}function dUi(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5922676+(b*112|0)>>2];c[a+104>>2]=c[5922680+(b*112|0)>>2];c[a+108>>2]=c[5922684+(b*112|0)>>2];d=0;return d|0}function dUj(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=5922576+(b*112|0);e=0;return e|0}function dUk(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>23){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=691320+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dUl(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6383104+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dUm(){c[251646]=12;c[2440200]=292380;c[2440201]=293240;return dUR(4604,0,54525952,0)|0}function dUn(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4425836+(b*112|0)>>2];c[a+104>>2]=c[4425840+(b*112|0)>>2];c[a+108>>2]=c[4425844+(b*112|0)>>2];d=0;return d|0}function dUo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=4425736+(b*112|0);e=0;return e|0}function dUp(){c[251646]=12;c[2440200]=101322990;c[2440201]=101324378;c[2440202]=101323650;return dUR(2022,0,41943040,0)|0}function dUq(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2329436+(b*112|0)>>2];c[a+104>>2]=c[2329440+(b*112|0)>>2];c[a+108>>2]=c[2329444+(b*112|0)>>2];d=0;return d|0}function dUr(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=2329336+(b*112|0);e=0;return e|0}function dUs(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2811460+(b*112|0)>>2];c[a+104>>2]=c[2811464+(b*112|0)>>2];c[a+108>>2]=c[2811468+(b*112|0)>>2];d=0;return d|0}function dUt(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=2811360+(b*112|0);e=0;return e|0}function dUu(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3885072+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dUv(){c[251646]=262156;c[2440200]=100830182;c[2440201]=100829556;c[2440202]=100830820;return dUR(4802,1,58720256,0)|0}function dUw(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2352284+(b*112|0)>>2];c[a+104>>2]=c[2352288+(b*112|0)>>2];c[a+108>>2]=c[2352292+(b*112|0)>>2];d=0;return d|0}function dUx(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=2352184+(b*112|0);e=0;return e|0}function dUy(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3532312+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dUz(){c[251646]=393228;c[2440200]=100840548;c[2440201]=100841852;c[2440202]=100841186;c[2440203]=100842526;return dUR(4460,1,58720256,0)|0}function dUA(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>23){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2922324+(b*112|0)>>2];c[a+104>>2]=c[2922328+(b*112|0)>>2];c[a+108>>2]=c[2922332+(b*112|0)>>2];d=0;return d|0}function dUB(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<24&(d|0)==0)){e=1;return e|0}c[a>>2]=2922224+(b*112|0);e=0;return e|0}function dUC(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4049136+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dUD(){c[251646]=393228;c[2440200]=100824128;c[2440201]=100824806;c[2440202]=100826228;c[2440203]=100825512;return dUR(4568,1,46137344,4194304)|0}function dUE(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2825700+(b*112|0)>>2];c[a+104>>2]=c[2825704+(b*112|0)>>2];c[a+108>>2]=c[2825708+(b*112|0)>>2];d=0;return d|0}function dUF(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=2825600+(b*112|0);e=0;return e|0}function dUG(){c[251646]=393228;c[2440200]=100846312;c[2440201]=100846984;c[2440202]=100848368;c[2440203]=100847682;return dUR(2174,1,41943040,25165824)|0}function dUH(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2570004+(b*112|0)>>2];c[a+104>>2]=c[2570008+(b*112|0)>>2];c[a+108>>2]=c[2570012+(b*112|0)>>2];d=0;return d|0}function dUI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=2569904+(b*112|0);e=0;return e|0}function dUJ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7116496+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dUK(){c[251646]=393228;c[2440200]=100867844;c[2440201]=100868428;return dUR(478,1,20971520,4194304)|0}function dUL(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6992588+(b*112|0)>>2];c[a+104>>2]=c[6992592+(b*112|0)>>2];c[a+108>>2]=c[6992596+(b*112|0)>>2];d=0;return d|0}function dUM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=6992488+(b*112|0);e=0;return e|0}function dUN(){c[251646]=393228;c[2440200]=100829530;c[2440201]=100830380;c[2440202]=100831858;c[2440203]=100830962;return dUR(4162,1,46137344,12582912)|0}function dUO(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6477260+(b*112|0)>>2];c[a+104>>2]=c[6477264+(b*112|0)>>2];c[a+108>>2]=c[6477268+(b*112|0)>>2];d=0;return d|0}function dUP(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=6477160+(b*112|0);e=0;return e|0}function dUQ(){c[251646]=393228;c[2440200]=100839002;c[2440201]=100839852;c[2440202]=100841330;c[2440203]=100840434;return dUR(4162,1,46137344,12582912)|0}function dUR(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0;c[2414980]=0;i=f-g|0;c[2386712]=0;c[2112938]=2097152;j=i+2228224|0;c[2386656]=j;k=i+6422528|0;c[2387856]=k;l=i+6422784|0;m=l|0;c[2414684]=m;c[3529098]=m;n=i+6488320|0;o=n|0;c[2387214]=o;p=i+6553856|0;c[2386468]=p;q=i+6619392|0;r=q|0;c[3529392]=r;s=i+6619904|0;c[2386716]=s;t=i+7668480|0;u=t|0;c[2386568]=u;v=i+7684864|0;w=v|0;c[2411696]=w;c[2112966]=w;w=i+7705344|0;x=w|0;y=i+6570240|0;z=y|0;c[2406572]=z;c[2112942]=o;c[2112940]=u;c[2112944]=z;c[2112936]=r;c[2112934]=m;c[2414236]=x;m=x;x=0;while(1){if((x|0)>=1024){break}A=9638528+(x<<2)|0;if((c[A>>2]|0)==0){B=23867;break}else{x=x+1|0}}do{if((B|0)==23867){x=gGq(m)|0;c[A>>2]=x;if((x|0)==0){break}gGz(x|0,0,m|0);c[2414980]=x;gGz(x|0,0,m|0);c[2386712]=x;c[2112938]=x+2097152;c[2386656]=x+j;c[2387856]=x+k;r=x+l|0;c[2414684]=r;c[3529098]=r;z=x+n|0;c[2387214]=z;c[2386468]=x+p;u=x+q|0;c[3529392]=u;c[2386716]=x+s;o=x+t|0;c[2386568]=o;C=x+v|0;c[2411696]=C;c[2112966]=C;C=x+y|0;c[2406572]=C;c[2112942]=z;c[2112940]=o;c[2112944]=C;c[2112936]=u;c[2112934]=r;c[2414236]=x+w;do{if((b|0)==0){D=x}else{if((gD[b&8191]()|0)==0){D=c[2386712]|0;break}else{E=1;return E|0}}}while(0);x=0;while(1){r=D+(x|1)|0;u=a[r]|0;C=D+(x|2)|0;a[r]=a[C]|0;a[C]=u;u=x+4|0;if((u|0)<1048576){x=u}else{F=0;G=D;break}}while(1){x=a[G]|0;u=G+1|0;a[G]=a[u]|0;a[u]=x;x=F+1|0;if((x|0)<1048576){F=x;G=G+2|0}else{H=0;break}}do{x=D+H|0;u=a[x]|0;C=D+(H|3)|0;a[x]=a[C]|0;a[C]=u;u=D+(H|1)|0;C=a[u]|0;x=D+(H|2)|0;a[u]=a[x]|0;a[x]=C;H=H+4|0;}while((H|0)<2097152);C=c[2112938]|0;if((i|0)>0){x=0;do{u=C+(x|1)|0;r=a[u]|0;o=C+(x|2)|0;a[u]=a[o]|0;a[o]=r;x=x+4|0;}while((x|0)<(i|0))}do{if((fa(c[c[642608+(c[2436]<<2)>>2]>>2]|0,400936)|0)==0){x=i>>1;if((x|0)>0){I=0;J=C}else{break}while(1){r=a[J]|0;o=J+1|0;a[J]=a[o]|0;a[o]=r;r=I+1|0;if((r|0)<(x|0)){I=r;J=J+2|0}else{break}}}}while(0);c[2432950]=g;c[2432948]=f;geV();C=c[2411230]|0;c[2406668]=C;c[2424904]=C;x=c[2386712]|0;r=C+2412|0;o=0;u=0;while(1){z=x+u|0;c[r>>2]=z;c[r+524288>>2]=z;c[r+8192>>2]=z;c[r+16384>>2]=z;c[r+24576>>2]=z;c[r+32768>>2]=z;c[r+40960>>2]=z;c[r+49152>>2]=z;c[r+57344>>2]=z;c[r+532480>>2]=z;c[r+540672>>2]=z;c[r+548864>>2]=z;c[r+557056>>2]=z;c[r+565248>>2]=z;c[r+573440>>2]=z;c[r+581632>>2]=z;z=gGK(u,o,65536,0)|0;L=K;M=0;if(L>>>0>M>>>0|L>>>0==M>>>0&z>>>0>1048575>>>0){break}else{r=r+4|0;o=L;u=z}}if((e|0)==0){u=C+4460|0;o=0;r=33554432;while(1){z=x+(r-32505856)|0;c[u>>2]=z;c[u+524288>>2]=z;c[u+8192>>2]=z;c[u+16384>>2]=z;c[u+24576>>2]=z;c[u+32768>>2]=z;c[u+40960>>2]=z;c[u+49152>>2]=z;c[u+57344>>2]=z;c[u+532480>>2]=z;c[u+540672>>2]=z;c[u+548864>>2]=z;c[u+557056>>2]=z;c[u+565248>>2]=z;c[u+573440>>2]=z;c[u+581632>>2]=z;z=gGK(r,o,65536,0)|0;L=K;M=0;if(L>>>0>M>>>0|L>>>0==M>>>0&z>>>0>34603007>>>0){break}else{u=u+4|0;o=L;r=z}}r=c[2386468]|0;c[C+5484>>2]=r;c[C+267628>>2]=r;c[C+529772>>2]=r;c[C+13676>>2]=r;c[C+21868>>2]=r;c[C+30060>>2]=r;c[C+38252>>2]=r;c[C+46444>>2]=r;c[C+54636>>2]=r;c[C+62828>>2]=r;c[C+275820>>2]=r;c[C+284012>>2]=r;c[C+292204>>2]=r;c[C+300396>>2]=r;c[C+308588>>2]=r;c[C+316780>>2]=r;c[C+324972>>2]=r;c[C+537964>>2]=r;c[C+546156>>2]=r;c[C+554348>>2]=r;c[C+562540>>2]=r;c[C+570732>>2]=r;c[C+578924>>2]=r;c[C+587116>>2]=r;r=c[2387214]|0;c[C+5500>>2]=r;c[C+267644>>2]=r;c[C+529788>>2]=r;c[C+13692>>2]=r;c[C+21884>>2]=r;c[C+30076>>2]=r;c[C+38268>>2]=r;c[C+46460>>2]=r;c[C+54652>>2]=r;c[C+62844>>2]=r;c[C+275836>>2]=r;c[C+284028>>2]=r;c[C+292220>>2]=r;c[C+300412>>2]=r;c[C+308604>>2]=r;c[C+316796>>2]=r;c[C+324988>>2]=r;c[C+537980>>2]=r;c[C+546172>>2]=r;c[C+554364>>2]=r;c[C+562556>>2]=r;c[C+570748>>2]=r;c[C+578940>>2]=r;c[C+587132>>2]=r;r=c[3529098]|0;c[C+5504>>2]=r;c[C+529792>>2]=r;c[C+13696>>2]=r;c[C+21888>>2]=r;c[C+30080>>2]=r;c[C+38272>>2]=r;c[C+46464>>2]=r;c[C+54656>>2]=r;c[C+62848>>2]=r;c[C+537984>>2]=r;c[C+546176>>2]=r;c[C+554368>>2]=r;c[C+562560>>2]=r;c[C+570752>>2]=r;c[C+578944>>2]=r;c[C+587136>>2]=r;r=c[2386716]|0;o=C+8556|0;u=0;z=100663296;while(1){L=r+(z-100663296)|0;c[o>>2]=L;c[o+262144>>2]=L;c[o+524288>>2]=L;c[o+8192>>2]=L;c[o+16384>>2]=L;c[o+24576>>2]=L;c[o+32768>>2]=L;c[o+40960>>2]=L;c[o+49152>>2]=L;c[o+57344>>2]=L;c[o+270336>>2]=L;c[o+278528>>2]=L;c[o+286720>>2]=L;c[o+294912>>2]=L;c[o+303104>>2]=L;c[o+311296>>2]=L;c[o+319488>>2]=L;c[o+532480>>2]=L;c[o+540672>>2]=L;c[o+548864>>2]=L;c[o+557056>>2]=L;c[o+565248>>2]=L;c[o+573440>>2]=L;c[o+581632>>2]=L;L=gGK(z,u,65536,0)|0;M=K;N=0;if(M>>>0>N>>>0|M>>>0==N>>>0&L>>>0>101711871>>>0){break}else{o=o+4|0;u=M;z=L}}c[C+788844>>2]=3464;c[C+788876>>2]=2808;c[C+788940>>2]=3098;c[C+789004>>2]=1492}else{z=c[2386468]|0;c[C+6508>>2]=z;c[C+268652>>2]=z;c[C+530796>>2]=z;c[C+14700>>2]=z;c[C+22892>>2]=z;c[C+31084>>2]=z;c[C+39276>>2]=z;c[C+47468>>2]=z;c[C+55660>>2]=z;c[C+63852>>2]=z;c[C+276844>>2]=z;c[C+285036>>2]=z;c[C+293228>>2]=z;c[C+301420>>2]=z;c[C+309612>>2]=z;c[C+317804>>2]=z;c[C+325996>>2]=z;c[C+538988>>2]=z;c[C+547180>>2]=z;c[C+555372>>2]=z;c[C+563564>>2]=z;c[C+571756>>2]=z;c[C+579948>>2]=z;c[C+588140>>2]=z;z=c[2387214]|0;c[C+6524>>2]=z;c[C+268668>>2]=z;c[C+530812>>2]=z;c[C+14716>>2]=z;c[C+22908>>2]=z;c[C+31100>>2]=z;c[C+39292>>2]=z;c[C+47484>>2]=z;c[C+55676>>2]=z;c[C+63868>>2]=z;c[C+276860>>2]=z;c[C+285052>>2]=z;c[C+293244>>2]=z;c[C+301436>>2]=z;c[C+309628>>2]=z;c[C+317820>>2]=z;c[C+326012>>2]=z;c[C+539004>>2]=z;c[C+547196>>2]=z;c[C+555388>>2]=z;c[C+563580>>2]=z;c[C+571772>>2]=z;c[C+579964>>2]=z;c[C+588156>>2]=z;z=c[3529098]|0;c[C+6528>>2]=z;c[C+530816>>2]=z;c[C+14720>>2]=z;c[C+22912>>2]=z;c[C+31104>>2]=z;c[C+39296>>2]=z;c[C+47488>>2]=z;c[C+55680>>2]=z;c[C+63872>>2]=z;c[C+539008>>2]=z;c[C+547200>>2]=z;c[C+555392>>2]=z;c[C+563584>>2]=z;c[C+571776>>2]=z;c[C+579968>>2]=z;c[C+588160>>2]=z;z=C+7532|0;u=0;o=83886080;while(1){r=x+(o-82837504)|0;c[z>>2]=r;c[z+524288>>2]=r;c[z+8192>>2]=r;c[z+16384>>2]=r;c[z+24576>>2]=r;c[z+32768>>2]=r;c[z+40960>>2]=r;c[z+49152>>2]=r;c[z+57344>>2]=r;c[z+532480>>2]=r;c[z+540672>>2]=r;c[z+548864>>2]=r;c[z+557056>>2]=r;c[z+565248>>2]=r;c[z+573440>>2]=r;c[z+581632>>2]=r;r=gGK(o,u,65536,0)|0;L=K;M=0;if(L>>>0>M>>>0|L>>>0==M>>>0&r>>>0>84410367>>>0){break}else{z=z+4|0;u=L;o=r}}o=c[2386716]|0;u=C+8556|0;z=0;x=100663296;while(1){r=o+(x-100663296)|0;c[u>>2]=r;c[u+262144>>2]=r;c[u+524288>>2]=r;c[u+8192>>2]=r;c[u+16384>>2]=r;c[u+24576>>2]=r;c[u+32768>>2]=r;c[u+40960>>2]=r;c[u+49152>>2]=r;c[u+57344>>2]=r;c[u+270336>>2]=r;c[u+278528>>2]=r;c[u+286720>>2]=r;c[u+294912>>2]=r;c[u+303104>>2]=r;c[u+311296>>2]=r;c[u+319488>>2]=r;c[u+532480>>2]=r;c[u+540672>>2]=r;c[u+548864>>2]=r;c[u+557056>>2]=r;c[u+565248>>2]=r;c[u+573440>>2]=r;c[u+581632>>2]=r;r=gGK(x,z,65536,0)|0;L=K;M=0;if(L>>>0>M>>>0|L>>>0==M>>>0&r>>>0>101711871>>>0){break}else{u=u+4|0;z=L;x=r}}c[C+788844>>2]=610;c[C+788876>>2]=264;c[C+788940>>2]=2276;c[C+789004>>2]=1492}x=c[251646]|0;z=x|100663296;u=x|100728831;x=z>>>0<134217728;o=z&-65536;r=u;L=0;if(o>>>0<=u>>>0){u=C+2412+(z>>>16<<2)|0;z=0;M=o;while(1){c[u>>2]=1;c[u+524288>>2]=1;if(x){c[u+8192>>2]=1;c[u+16384>>2]=1;c[u+24576>>2]=1;c[u+32768>>2]=1;c[u+40960>>2]=1;c[u+49152>>2]=1;c[u+57344>>2]=1;c[u+532480>>2]=1;c[u+540672>>2]=1;c[u+548864>>2]=1;c[u+557056>>2]=1;c[u+565248>>2]=1;c[u+573440>>2]=1;c[u+581632>>2]=1}o=gGK(M,z,65536,0)|0;N=K;if(N>>>0>L>>>0|N>>>0==L>>>0&o>>>0>r>>>0){break}else{u=u+4|0;z=N;M=o}}}c[C+788848>>2]=3592;c[C+788912>>2]=3492;c[C+788976>>2]=1150;Vz(c[2386656]|0,1216,3070);h[607289]=1.0;c[2433120]=3;h[607288]=1.0;c[2433118]=3;c[2438228]=28636350;c[2433526]=3716;c[2406676]=1604;c[3528472]=6968;c[2443846]=70;Tq(689456);M=0;while(1){if((M|0)>=1024){O=0;break}P=9638528+(M<<2)|0;if((c[P>>2]|0)==0){B=23902;break}else{M=M+1|0}}do{if((B|0)==23902){M=gGq(65536)|0;c[P>>2]=M;if((M|0)==0){O=0;break}gGz(M|0,0,65536);O=M}}while(0);c[3529100]=O;M=0;while(1){if((M|0)>=1024){Q=0;break}R=9638528+(M<<2)|0;if((c[R>>2]|0)==0){B=23907;break}else{M=M+1|0}}do{if((B|0)==23907){M=gGq(153600)|0;c[R>>2]=M;if((M|0)==0){Q=0;break}gGz(M|0,0,153600);Q=M}}while(0);c[2387044]=Q;M=0;while(1){if((M|0)>=1024){S=0;break}T=9638528+(M<<2)|0;if((c[T>>2]|0)==0){B=23912;break}else{M=M+1|0}}do{if((B|0)==23912){M=gGq(307200)|0;c[T>>2]=M;if((M|0)==0){S=0;break}gGz(M|0,0,307200);S=M}}while(0);c[2438736]=S;M=c[642608+(c[2436]<<2)>>2]|0;C=c[M+128>>2]|0;if((c[M+52>>2]&4|0)==0){c[2113068]=C;c[2113070]=c[M+132>>2]}else{c[2113070]=C;c[2113068]=c[M+132>>2]}c[2439212]=i;c[2439216]=(g|0)/128|0;c[2439214]=(g|0)/256|0;c[2438158]=((i|0)/128|0)-1;c[2438156]=((i|0)/256|0)-1;M=0;while(1){if((M|0)>=1024){U=0;break}V=9638528+(M<<2)|0;if((c[V>>2]|0)==0){B=23920;break}else{M=M+1|0}}do{if((B|0)==23920){M=gGq(98304)|0;c[V>>2]=M;if((M|0)==0){U=0;break}gGz(M|0,0,98304);U=M}}while(0);c[3527248]=U;gGz(U|0,-1|0,98304);M=c[2439212]|0;do{if((M|0)>0){C=c[2112938]|0;z=0;do{u=0;while(1){if((u|0)>=128){break}if((a[C+(u+z)|0]|0)==0){u=u+1|0}else{B=23928;break}}if((B|0)==23928){B=0;u=U+(z>>10)|0;a[u]=d[u]&(1<<(z>>>7&7)^255)&255}z=z+128|0;}while((z|0)<(M|0));if((M|0)>0){W=0}else{break}do{z=0;while(1){if((z|0)>=256){break}if((a[C+(z+W)|0]|0)==0){z=z+1|0}else{B=23933;break}}if((B|0)==23933){B=0;z=U+((W>>11)+65536)|0;a[z]=d[z]&(1<<(W>>>8&7)^255)&255}W=W+256|0;}while((W|0)<(M|0))}}while(0);gGz(14115392,-1|0,192);M=0;do{a[14115392+(M|192)|0]=(((63-M|0)*255|0|0)/63|0)&255;M=M+1|0;}while((M|0)<64);M=c[2406668]|0;C=c[M+2412>>2]|0;if(C>>>0>7){X=c[C>>2]|0;Y=M;Z=C}else{z=gj[c[M+788972+(C<<2)>>2]&4095](0)|0;C=c[2406668]|0;X=z;Y=C;Z=c[C+2412>>2]|0}if(Z>>>0>7){_=c[Z+4>>2]|0;$=Y}else{C=gj[c[Y+788972+(Z<<2)>>2]&4095](4)|0;_=C;$=c[2406668]|0}C=c[2424904]|0;gGz(C|0,0,2408);z=C+4|0;c[C+92>>2]=_;c[C+12>>2]=240;M=X&-939524097;c[z>>2]=M;u=c[$+2412+((M>>>16|131072)<<2)>>2]|0;M=$+789036|0;c[M>>2]=u;c[M>>2]=u+(-(c[z>>2]&-65536)|0);c[C+2348>>2]=-1;C=c[2414684]|0;gGz(C|0,0,(c[2411696]|0)-C|0);if(!(a[1040128]|0)){C=c[2387856]|0;gGC(14100392,C|0,256)|0}c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;c[2443740]=0;c[2427062]=-1;E=0;return E|0}}while(0);c[2414980]=0;E=1;return E|0}function dUS(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;a=i;i=i+240|0;b=a|0;d=a+112|0;e=a+120|0;f=a+232|0;if((R6((c[2386712]|0)+1|0,0,2)|0)!=0){g=1;i=a;return g|0}if((R6(c[2386712]|0,1,2)|0)!=0){g=1;i=a;return g|0}if((R6(c[2112938]|0,2,2)|0)!=0){g=1;i=a;return g|0}if((R6((c[2112938]|0)+1|0,3,2)|0)!=0){g=1;i=a;return g|0}if((R6((c[2112938]|0)+4194304|0,4,2)|0)!=0){g=1;i=a;return g|0}if((R6((c[2112938]|0)+4194305|0,5,2)|0)!=0){g=1;i=a;return g|0}if((R6((c[2112938]|0)+8388608|0,6,2)|0)!=0){g=1;i=a;return g|0}if((R6((c[2112938]|0)+8388609|0,7,2)|0)!=0){g=1;i=a;return g|0}if((R6((c[2112938]|0)+12582912|0,8,2)|0)!=0){g=1;i=a;return g|0}if((R6((c[2112938]|0)+12582913|0,9,2)|0)!=0){g=1;i=a;return g|0}if((R6((c[2112938]|0)+16777216|0,10,2)|0)!=0){g=1;i=a;return g|0}if((R6((c[2112938]|0)+16777217|0,11,2)|0)!=0){g=1;i=a;return g|0}if((R6((c[2112938]|0)+20971520|0,12,2)|0)!=0){g=1;i=a;return g|0}if((R6((c[2112938]|0)+20971521|0,13,2)|0)!=0){g=1;i=a;return g|0}if((R6((c[2112938]|0)+25165824|0,14,2)|0)!=0){g=1;i=a;return g|0}if((R6((c[2112938]|0)+25165825|0,15,2)|0)!=0){g=1;i=a;return g|0}if((R6((c[2112938]|0)+29360128|0,16,2)|0)!=0){g=1;i=a;return g|0}if((R6((c[2112938]|0)+29360129|0,17,2)|0)!=0){g=1;i=a;return g|0}h=c[2386656]|0;if((c[3542200]|0)==0){g=1;i=a;return g|0}j=e+108|0;c[j>>2]=0;k=e+100|0;c[k>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,18)|0;do{if((c[j>>2]|0)!=0){e=c[k>>2]|0;c[f>>2]=9534384;l=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[l&16383](f,18,0)|0;if((e|0)<1){g=1;i=a;return g|0}if((gzL(h,0,18)|0)==0){break}else{g=1}i=a;return g|0}}while(0);h=c[2387856]|0;if((c[3542200]|0)==0){g=1;i=a;return g|0}f=b+108|0;c[f>>2]=0;k=b+100|0;c[k>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](b,19)|0;if((c[f>>2]|0)==0){g=0;i=a;return g|0}f=c[k>>2]|0;c[d>>2]=9534384;gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](d,19,0)|0;if((f|0)<1){g=1;i=a;return g|0}g=(gzL(h,0,19)|0)!=0|0;i=a;return g|0}function dUT(b,d){b=b|0;d=d|0;if((d|0)!=0){ge$(12);return}d=c[2424904]|0;b=d+272|0;if((a[b]|0)==0){return}a[b]=0;b=d+124|0;c[b>>2]=c[b>>2]&-4097;return}function dUU(a){a=a|0;var b=0,d=0;b=c[(c[2424904]|0)+2404>>2]|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,28636350,0)|0;return a|0}function dUV(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0;a=i;i=i+120|0;b=a|0;d=a+112|0;if((R6((c[2386712]|0)+1|0,0,2)|0)!=0){e=1;i=a;return e|0}if((R6(c[2386712]|0,1,2)|0)!=0){e=1;i=a;return e|0}if((R6(c[2112938]|0,2,2)|0)!=0){e=1;i=a;return e|0}if((R6((c[2112938]|0)+1|0,3,2)|0)!=0){e=1;i=a;return e|0}if((R6((c[2112938]|0)+4194304|0,4,2)|0)!=0){e=1;i=a;return e|0}if((R6((c[2112938]|0)+4194305|0,5,2)|0)!=0){e=1;i=a;return e|0}if((R6((c[2112938]|0)+8388608|0,6,2)|0)!=0){e=1;i=a;return e|0}if((R6((c[2112938]|0)+8388609|0,7,2)|0)!=0){e=1;i=a;return e|0}if((R6((c[2112938]|0)+12582912|0,8,2)|0)!=0){e=1;i=a;return e|0}if((R6((c[2112938]|0)+12582913|0,9,2)|0)!=0){e=1;i=a;return e|0}f=c[2386656]|0;if((c[3542200]|0)==0){e=1;i=a;return e|0}g=b+108|0;c[g>>2]=0;h=b+100|0;c[h>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](b,10)|0;do{if((c[g>>2]|0)!=0){b=c[h>>2]|0;c[d>>2]=9534384;j=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[j&16383](d,10,0)|0;if((b|0)<1){e=1;i=a;return e|0}if((gzL(f,0,10)|0)==0){break}else{e=1}i=a;return e|0}}while(0);f=c[2387856]|0;gGC(f|0,2569888,16)|0;d=f+240|0;gGC(d|0,2569888,16)|0;e=0;i=a;return e|0}function dUW(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0;a=i;i=i+120|0;b=a|0;d=a+112|0;if((R6((c[2386712]|0)+1|0,0,2)|0)!=0){e=1;i=a;return e|0}if((R6(c[2386712]|0,1,2)|0)!=0){e=1;i=a;return e|0}if((R6(c[2112938]|0,2,2)|0)!=0){e=1;i=a;return e|0}if((R6((c[2112938]|0)+1|0,3,2)|0)!=0){e=1;i=a;return e|0}if((R6((c[2112938]|0)+4194304|0,4,2)|0)!=0){e=1;i=a;return e|0}if((R6((c[2112938]|0)+4194305|0,5,2)|0)!=0){e=1;i=a;return e|0}if((R6((c[2112938]|0)+8388608|0,6,2)|0)!=0){e=1;i=a;return e|0}if((R6((c[2112938]|0)+8388609|0,7,2)|0)!=0){e=1;i=a;return e|0}if((R6((c[2112938]|0)+12582912|0,8,2)|0)!=0){e=1;i=a;return e|0}if((R6((c[2112938]|0)+12582913|0,9,2)|0)!=0){e=1;i=a;return e|0}f=c[2386656]|0;if((c[3542200]|0)==0){e=1;i=a;return e|0}g=b+108|0;c[g>>2]=0;h=b+100|0;c[h>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](b,10)|0;do{if((c[g>>2]|0)!=0){b=c[h>>2]|0;c[d>>2]=9534384;j=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[j&16383](d,10,0)|0;if((b|0)<1){e=1;i=a;return e|0}if((gzL(f,0,10)|0)==0){break}else{e=1}i=a;return e|0}}while(0);f=c[2387856]|0;gGC(f|0,4717656,16)|0;d=f+240|0;gGC(d|0,2825584,16)|0;e=0;i=a;return e|0}function dUX(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0;a=i;i=i+120|0;b=a|0;d=a+112|0;do{if((R6((c[2386712]|0)+1|0,0,2)|0)==0){if((R6(c[2386712]|0,1,2)|0)!=0){e=1;break}if((R6(c[2112938]|0,2,2)|0)!=0){e=1;break}if((R6((c[2112938]|0)+1|0,3,2)|0)!=0){e=1;break}if((R6((c[2112938]|0)+4194304|0,4,2)|0)!=0){e=1;break}if((R6((c[2112938]|0)+4194305|0,5,2)|0)!=0){e=1;break}if((R6((c[2112938]|0)+8388608|0,6,2)|0)!=0){e=1;break}if((R6((c[2112938]|0)+8388609|0,7,2)|0)!=0){e=1;break}if((R6((c[2112938]|0)+12582912|0,8,2)|0)!=0){e=1;break}if((R6((c[2112938]|0)+12582913|0,9,2)|0)!=0){e=1;break}if((R6((c[2112938]|0)+16777216|0,10,2)|0)!=0){e=1;break}if((R6((c[2112938]|0)+16777217|0,11,2)|0)!=0){e=1;break}if((R6((c[2112938]|0)+20971520|0,12,2)|0)!=0){e=1;break}if((R6((c[2112938]|0)+20971521|0,13,2)|0)!=0){e=1;break}if((R6((c[2112938]|0)+25165824|0,14,2)|0)!=0){e=1;break}if((R6((c[2112938]|0)+25165825|0,15,2)|0)!=0){e=1;break}if((R6((c[2112938]|0)+29360128|0,16,2)|0)!=0){e=1;break}if((R6((c[2112938]|0)+29360129|0,17,2)|0)!=0){e=1;break}if((R6((c[2112938]|0)+33554432|0,18,2)|0)!=0){e=1;break}if((R6((c[2112938]|0)+33554433|0,19,2)|0)!=0){e=1;break}if((R6((c[2112938]|0)+37748736|0,20,2)|0)!=0){e=1;break}if((R6((c[2112938]|0)+37748737|0,21,2)|0)!=0){e=1;break}f=c[2386656]|0;if((c[3542200]|0)==0){e=1;break}g=b+108|0;c[g>>2]=0;h=b+100|0;c[h>>2]=0;j=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[j&16383](b,22)|0;if((c[g>>2]|0)!=0){g=c[h>>2]|0;c[d>>2]=9534384;h=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[h&16383](d,22,0)|0;if((g|0)<1){e=1;break}if((gzL(f,0,22)|0)!=0){e=1;break}}f=c[2387856]|0;gGC(f|0,4717656,16)|0;g=f+240|0;gGC(g|0,2922208,16)|0;e=0}else{e=1}}while(0);i=a;return e|0}function dUY(){var a=0,b=0,d=0;a=dUZ()|0;b=c[2387856]|0;gGC(b|0,4717656,16)|0;d=b+240|0;gGC(d|0,2352168,16)|0;return a|0}function dUZ(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;a=i;i=i+240|0;b=a|0;d=a+112|0;e=a+120|0;f=a+232|0;if((R6((c[2386712]|0)+1|0,0,2)|0)!=0){g=1;i=a;return g|0}if((R6(c[2386712]|0,1,2)|0)!=0){g=1;i=a;return g|0}h=(c[2386712]|0)+1048576|0;if((c[3542200]|0)==0){g=1;i=a;return g|0}j=e+108|0;c[j>>2]=0;k=e+100|0;c[k>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,2)|0;do{if((c[j>>2]|0)!=0){e=c[k>>2]|0;c[f>>2]=9534384;l=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[l&16383](f,2,0)|0;if((e|0)<1){g=1;i=a;return g|0}if((gzL(h,0,2)|0)==0){break}else{g=1}i=a;return g|0}}while(0);if((R6(c[2112938]|0,3,2)|0)!=0){g=1;i=a;return g|0}if((R6((c[2112938]|0)+1|0,4,2)|0)!=0){g=1;i=a;return g|0}if((R6((c[2112938]|0)+16777216|0,5,2)|0)!=0){g=1;i=a;return g|0}if((R6((c[2112938]|0)+16777217|0,6,2)|0)!=0){g=1;i=a;return g|0}if((R6((c[2112938]|0)+33554432|0,7,2)|0)!=0){g=1;i=a;return g|0}if((R6((c[2112938]|0)+33554433|0,8,2)|0)!=0){g=1;i=a;return g|0}if((R6((c[2112938]|0)+50331648|0,9,2)|0)!=0){g=1;i=a;return g|0}if((R6((c[2112938]|0)+50331649|0,10,2)|0)!=0){g=1;i=a;return g|0}h=c[2386656]|0;if((c[3542200]|0)==0){g=1;i=a;return g|0}f=b+108|0;c[f>>2]=0;k=b+100|0;c[k>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](b,11)|0;do{if((c[f>>2]|0)!=0){b=c[k>>2]|0;c[d>>2]=9534384;j=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[j&16383](d,11,0)|0;if((b|0)<1){g=1;i=a;return g|0}if((gzL(h,0,11)|0)==0){break}else{g=1}i=a;return g|0}}while(0);h=c[2387856]|0;gGC(h|0,4717656,16)|0;g=0;i=a;return g|0}function dU_(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0;a=i;i=i+120|0;b=a|0;d=a+112|0;do{if((R6((c[2386712]|0)+1|0,0,2)|0)==0){if((R6(c[2386712]|0,1,2)|0)!=0){e=1;break}if((R6(c[2112938]|0,2,2)|0)!=0){e=1;break}if((R6((c[2112938]|0)+1|0,3,2)|0)!=0){e=1;break}if((R6((c[2112938]|0)+8388608|0,4,2)|0)!=0){e=1;break}if((R6((c[2112938]|0)+8388609|0,5,2)|0)!=0){e=1;break}if((R6((c[2112938]|0)+16777216|0,6,2)|0)!=0){e=1;break}if((R6((c[2112938]|0)+16777217|0,7,2)|0)!=0){e=1;break}if((R6((c[2112938]|0)+25165824|0,8,2)|0)!=0){e=1;break}if((R6((c[2112938]|0)+25165825|0,9,2)|0)!=0){e=1;break}if((R6((c[2112938]|0)+33554432|0,10,2)|0)!=0){e=1;break}if((R6((c[2112938]|0)+33554433|0,11,2)|0)!=0){e=1;break}f=c[2386656]|0;if((c[3542200]|0)==0){e=1;break}g=b+108|0;c[g>>2]=0;h=b+100|0;c[h>>2]=0;j=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[j&16383](b,12)|0;if((c[g>>2]|0)!=0){g=c[h>>2]|0;c[d>>2]=9534384;h=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[h&16383](d,12,0)|0;if((g|0)<1){e=1;break}if((gzL(f,0,12)|0)!=0){e=1;break}}f=c[2387856]|0;gGC(f|0,4717656,16)|0;e=0}else{e=1}}while(0);i=a;return e|0}function dU$(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;a=i;i=i+240|0;b=a|0;d=a+112|0;e=a+120|0;f=a+232|0;if((R6((c[2386712]|0)+1|0,0,2)|0)!=0){g=1;i=a;return g|0}if((R6(c[2386712]|0,1,2)|0)!=0){g=1;i=a;return g|0}h=(c[2386712]|0)+1048576|0;if((c[3542200]|0)==0){g=1;i=a;return g|0}j=e+108|0;c[j>>2]=0;k=e+100|0;c[k>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,2)|0;do{if((c[j>>2]|0)!=0){e=c[k>>2]|0;c[f>>2]=9534384;l=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[l&16383](f,2,0)|0;if((e|0)<1){g=1;i=a;return g|0}if((gzL(h,0,2)|0)==0){break}else{g=1}i=a;return g|0}}while(0);if((R6(c[2112938]|0,3,2)|0)!=0){g=1;i=a;return g|0}if((R6((c[2112938]|0)+1|0,4,2)|0)!=0){g=1;i=a;return g|0}if((R6((c[2112938]|0)+8388608|0,5,2)|0)!=0){g=1;i=a;return g|0}if((R6((c[2112938]|0)+8388609|0,6,2)|0)!=0){g=1;i=a;return g|0}if((R6((c[2112938]|0)+16777216|0,7,2)|0)!=0){g=1;i=a;return g|0}if((R6((c[2112938]|0)+16777217|0,8,2)|0)!=0){g=1;i=a;return g|0}if((R6((c[2112938]|0)+25165824|0,9,2)|0)!=0){g=1;i=a;return g|0}if((R6((c[2112938]|0)+25165825|0,10,2)|0)!=0){g=1;i=a;return g|0}if((R6((c[2112938]|0)+33554432|0,11,2)|0)!=0){g=1;i=a;return g|0}if((R6((c[2112938]|0)+33554433|0,12,2)|0)!=0){g=1;i=a;return g|0}if((R6((c[2112938]|0)+41943040|0,13,2)|0)!=0){g=1;i=a;return g|0}if((R6((c[2112938]|0)+41943041|0,14,2)|0)!=0){g=1;i=a;return g|0}if((R6((c[2112938]|0)+50331648|0,15,2)|0)!=0){g=1;i=a;return g|0}if((R6((c[2112938]|0)+50331649|0,16,2)|0)!=0){g=1;i=a;return g|0}h=c[2386656]|0;if((c[3542200]|0)==0){g=1;i=a;return g|0}f=b+108|0;c[f>>2]=0;k=b+100|0;c[k>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](b,17)|0;do{if((c[f>>2]|0)!=0){b=c[k>>2]|0;c[d>>2]=9534384;j=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[j&16383](d,17,0)|0;if((b|0)<1){g=1;i=a;return g|0}if((gzL(h,0,17)|0)==0){break}else{g=1}i=a;return g|0}}while(0);h=c[2387856]|0;gGC(h|0,5922560,16)|0;g=0;i=a;return g|0}function dU0(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0;a=i;i=i+120|0;b=a|0;d=a+112|0;do{if((R6((c[2386712]|0)+1|0,0,2)|0)==0){if((R6(c[2386712]|0,1,2)|0)!=0){e=1;break}if((R6(c[2112938]|0,2,2)|0)!=0){e=1;break}if((R6((c[2112938]|0)+1|0,3,2)|0)!=0){e=1;break}if((R6((c[2112938]|0)+8388608|0,4,2)|0)!=0){e=1;break}if((R6((c[2112938]|0)+8388609|0,5,2)|0)!=0){e=1;break}if((R6((c[2112938]|0)+16777216|0,6,2)|0)!=0){e=1;break}if((R6((c[2112938]|0)+16777217|0,7,2)|0)!=0){e=1;break}if((R6((c[2112938]|0)+25165824|0,8,2)|0)!=0){e=1;break}if((R6((c[2112938]|0)+25165825|0,9,2)|0)!=0){e=1;break}f=c[2386656]|0;if((c[3542200]|0)==0){e=1;break}g=b+108|0;c[g>>2]=0;h=b+100|0;c[h>>2]=0;j=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[j&16383](b,10)|0;if((c[g>>2]|0)!=0){g=c[h>>2]|0;c[d>>2]=9534384;h=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[h&16383](d,10,0)|0;if((g|0)<1){e=1;break}if((gzL(f,0,10)|0)!=0){e=1;break}}f=c[2387856]|0;gGC(f|0,4717656,16)|0;e=0}else{e=1}}while(0);i=a;return e|0}function dU1(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0;a=i;i=i+120|0;b=a|0;d=a+112|0;if((R6((c[2386712]|0)+1|0,0,2)|0)!=0){e=1;i=a;return e|0}if((R6(c[2386712]|0,1,2)|0)!=0){e=1;i=a;return e|0}if((R6(c[2112938]|0,2,2)|0)!=0){e=1;i=a;return e|0}if((R6((c[2112938]|0)+1|0,3,2)|0)!=0){e=1;i=a;return e|0}if((R6((c[2112938]|0)+8388608|0,4,2)|0)!=0){e=1;i=a;return e|0}if((R6((c[2112938]|0)+8388609|0,5,2)|0)!=0){e=1;i=a;return e|0}if((R6((c[2112938]|0)+16777216|0,6,2)|0)!=0){e=1;i=a;return e|0}if((R6((c[2112938]|0)+16777217|0,7,2)|0)!=0){e=1;i=a;return e|0}f=c[2386656]|0;if((c[3542200]|0)==0){e=1;i=a;return e|0}g=b+108|0;c[g>>2]=0;h=b+100|0;c[h>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](b,8)|0;if((c[g>>2]|0)==0){e=0;i=a;return e|0}g=c[h>>2]|0;c[d>>2]=9534384;gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](d,8,0)|0;if((g|0)<1){e=1;i=a;return e|0}e=(gzL(f,0,8)|0)!=0|0;i=a;return e|0}function dU2(b){b=b|0;var d=0,e=0,f=0.0,g=0.0,i=0,j=0;d=b&255;if((d|0)==8){e=c[2443866]&255;return e|0}else if((d|0)==2){e=a[(c[3541514]|0)+20904|0]|0;return e|0}else if((d|0)==0){d=c[3541514]|0;b=d+552|0;f=+h[b>>3];do{if(f!=0.0){g=+h[6675];if(f-(g+ +gC[c[2429842]&255]())>0.0){i=a[d+563|0]|-128;break}else{h[b>>3]=0.0;j=24250;break}}else{j=24250}}while(0);if((j|0)==24250){i=a[d+563|0]|0}e=i&-125;return e|0}else{e=0;return e|0}return 0}function dU3(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=a&65535;switch(d&255|0){case 4:{a=b&3;if((a|0)==(c[2438146]|0)){return}e=c[2442962]|0;f=c[9757320+(c[1836236]<<2)>>2]|0;g=(a<<15)-32768|0;h=128;i=128;while(1){c[f+76+(i<<2)>>2]=e+(g+(i<<8));j=h+1&65535;if((j&65535)>255){k=128;l=128;break}else{h=j;i=j&65535}}while(1){i=e+(g+(l<<8))|0;c[f+76+(l+512<<2)>>2]=i;c[f+76+(l+768<<2)>>2]=i;i=k+1&65535;if((i&65535)>255){break}else{k=i;l=i&65535}}c[2438146]=a;return};case 12:{c[2438144]=1;return};case 0:case 1:case 2:case 3:{l7(d&3,b);return};default:{return}}}function dU4(b){b=b|0;var d=0,e=0,f=0.0,g=0.0,i=0,j=0;d=b&255;if((d|0)==8){e=c[2443866]&255;return e|0}else if((d|0)==6){e=a[(c[3541514]|0)+20904|0]|0;return e|0}else if((d|0)==4){d=c[3541514]|0;b=d+552|0;f=+h[b>>3];do{if(f!=0.0){g=+h[6675];if(f-(g+ +gC[c[2429842]&255]())>0.0){i=a[d+563|0]|-128;break}else{h[b>>3]=0.0;j=24278;break}}else{j=24278}}while(0);if((j|0)==24278){i=a[d+563|0]|0}e=i&-125;return e|0}else{e=0;return e|0}return 0}function dU5(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=a&65535;switch(d&255|0){case 0:{a=(b&255)>>>4&3;if((a|0)==(c[2438146]|0)){return}e=c[2442962]|0;f=c[9757320+(c[1836236]<<2)>>2]|0;g=(a<<15|512)-33280|0;h=130;i=130;while(1){c[f+76+(i<<2)>>2]=e+(g+(i<<8));j=h+1&65535;if((j&65535)>255){k=130;l=130;break}else{h=j;i=j&65535}}while(1){i=e+(g+(l<<8))|0;c[f+76+(l+512<<2)>>2]=i;c[f+76+(l+768<<2)>>2]=i;i=k+1&65535;if((i&65535)>255){break}else{k=i;l=i&65535}}c[2438146]=a;return};case 12:{c[2438144]=1;return};case 4:case 5:case 6:case 7:{l7(d&3,b);return};default:{return}}}function dU6(b){b=b|0;var d=0,e=0;d=b&255;if((d|0)==8){Vy(gj[c[2426988]&4095](a[9680]|0?32e3:0)|0);e=((c[3531833]|0)==1?-128:0)|a[14127331];return e|0}else if((d|0)==16){e=c[2443866]&255;return e|0}else{e=0;return e|0}return 0}function dU7(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=b&65535;switch(e&255|0){case 0:{b=(d&255)>>>4&3;if((b|0)==(c[2438146]|0)){return}f=c[2442962]|0;g=c[9757320+(c[1836236]<<2)>>2]|0;h=(b<<15|512)-33280|0;i=130;j=130;while(1){c[g+76+(j<<2)>>2]=f+(h+(j<<8));k=i+1&65535;if((k&65535)>255){l=130;m=130;break}else{i=k;j=k&65535}}while(1){j=f+(h+(m<<8))|0;c[g+76+(m+512<<2)>>2]=j;c[g+76+(m+768<<2)>>2]=j;j=l+1&65535;if((j&65535)>255){break}else{l=j;m=j&65535}}c[2438146]=b;return};case 8:case 10:case 12:{b=e>>>1&3;if((b|0)==2){a[14127338]=d;return}else if((b|0)==1){a[14127337]=d;return}else if((b|0)==0){a[14127336]=d;return}else{return}break};case 24:{c[2438144]=1;return};case 9:case 11:case 13:{b=e>>>1&3;if((b|0)==2){Vy(gj[c[2426988]&4095](a[9680]|0?32e3:0)|0);mp(d);return}else if((b|0)==0){Vy(gj[c[2426988]&4095](a[9680]|0?32e3:0)|0);mo(d);return}else{return}break};default:{return}}}function dU8(d){d=d|0;var f=0,g=0,h=0,i=0;if((d|0)==12582919){f=~(b[4812887]&255);return f|0}else if((d|0)==12582917){f=~(b[4812886]&255);return f|0}else if((d|0)==12582913){f=~(b[4812884]&255);return f|0}else if((d|0)==12582916){f=((e[4812886]|0)>>>8^255)&255;return f|0}else if((d|0)==12582920){f=((e[4812885]|0)>>>8^255)&255;return f|0}else if((d|0)==13107209){g=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;h=a[6518032]|0;i=gGU(g,(g|0)<0|0?-1:0,h?67456:0,h?0:0)|0;h=c[2440536]|0;g=gGS(i,K,h,(h|0)<0|0?-1:0)|0;h=g;if((h|0)>((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)){Sb(h)}h=e[4812885]|0;if((c[2438144]|0)==0){f=(h^255)&255;return f|0}else{f=(h&127^127)&255;return f|0}}else if((d|0)==12582923){f=~(b[4813580]&255);return f|0}else if((d|0)==12582918){f=((e[4812887]|0)>>>8^255)&255;return f|0}else if((d|0)==12582912){f=((e[4812884]|0)>>>8^255)&255;return f|0}else{f=0;return f|0}return 0}function dU9(d){d=d|0;var e=0,f=0,g=0;switch(d|0){case 12582918:{e=~b[4812887];return e|0};case 12582922:{e=~b[4813580];return e|0};case 12582912:{e=~b[4812884];return e|0};case 12582916:{e=~b[4812886];return e|0};case 12582920:{d=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;f=a[6518032]|0;g=gGU(d,(d|0)<0|0?-1:0,f?67456:0,f?0:0)|0;f=c[2440536]|0;d=gGS(g,K,f,(f|0)<0|0?-1:0)|0;if((d|0)>((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)){Sb(d)}d=b[4812885]|0;if((c[2438144]|0)==0){e=~d;return e|0}else{e=d&-129^-129;return e|0}break};default:{e=0;return e|0}}return 0}function dVa(d){d=d|0;var f=0,g=0,h=0;switch(d|0){case 12582916:{f=((e[4812886]|0)>>>8^255)&255;return f|0};case 12582914:{f=((e[4812885]|0)>>>8^255)&255;return f|0};case 12582915:{d=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;g=a[6518032]|0;h=gGU(d,(d|0)<0|0?-1:0,g?67456:0,g?0:0)|0;g=c[2440536]|0;d=gGS(h,K,g,(g|0)<0|0?-1:0)|0;if((d|0)>((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)){Sb(d)}d=e[4812885]|0;if((c[2438144]|0)==0){f=(d^255)&255;return f|0}else{f=(d&127^127)&255;return f|0}break};case 12582912:{f=((e[4812884]|0)>>>8^255)&255;return f|0};case 12582917:{f=~(b[4812886]&255);return f|0};case 12582918:{f=((e[4812887]|0)>>>8^255)&255;return f|0};case 12582913:{f=~(b[4812884]&255);return f|0};case 12582919:{f=~((b[4813580]&255)<<7|b[4812887]&255);return f|0};default:{f=0;return f|0}}return 0}function dVb(d){d=d|0;var e=0,f=0,g=0,h=0;if((d|0)==12582912){e=~b[4812884];return e|0}else if((d|0)==12582916){e=~b[4812886];return e|0}else if((d|0)==12582914){f=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;g=a[6518032]|0;h=gGU(f,(f|0)<0|0?-1:0,g?67456:0,g?0:0)|0;g=c[2440536]|0;f=gGS(h,K,g,(g|0)<0|0?-1:0)|0;g=f;if((g|0)>((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)){Sb(g)}g=b[4812885]|0;if((c[2438144]|0)==0){e=~g;return e|0}else{e=g&-129^-129;return e|0}}else if((d|0)==12582918){e=~(b[4813580]<<7|b[4812887]);return e|0}else{e=0;return e|0}return 0}function dVc(b,d){b=b|0;d=d|0;var e=0,f=0;if((b|0)!=12582929){return}b=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;e=a[6518032]|0;f=gGU(b,(b|0)<0|0?-1:0,e?67456:0,e?0:0)|0;e=c[2440536]|0;b=gGS(f,K,e,(e|0)<0|0?-1:0)|0;e=b;if((e|0)>((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)){Sb(e)}c[2443866]=d<<24>>24;c[2438144]=0;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12;return}function dVd(b,d){b=b|0;d=d|0;var e=0,f=0;if((b|0)!=12582930){return}b=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;e=a[6518032]|0;f=gGU(b,(b|0)<0|0?-1:0,e?67456:0,e?0:0)|0;e=c[2440536]|0;b=gGS(f,K,e,(e|0)<0|0?-1:0)|0;e=b;if((e|0)>((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)){Sb(e)}c[2443866]=(d&255)<<24>>24;c[2438144]=0;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12;return}function dVe(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;switch(f|0){case 12582913:{g=~(b[4812884]&255);return g|0};case 12582914:{g=((e[4812885]|0)>>>8^255)&255;return g|0};case 12582918:{f=a[9719352]|0;h=f&255;if((a[9721008]&16)==0){i=(h&1|0)==0?a[9731136]|0:-1;j=f|1}else{i=(h&4|0)==0?a[9731144]|0:-1;j=f|4}a[9719352]=j;g=i;return g|0};case 12582919:{i=b[4812887]&15^15;j=a[9719352]|0;f=j&255;if((a[9721008]&16)==0){if((f&1|0)==0){k=(d[9731136]|0)<<8}else{k=-256}l=k;m=j|1}else{if((f&4|0)==0){n=(d[9731144]|0)<<8}else{n=-256}l=n;m=j|4}a[9719352]=m;g=(a[9733992]&240|l)&255|i;return g|0};case 12582917:{g=~(b[4812886]&255);return g|0};case 12582920:{g=a[9719352]|8;return g|0};case 12582916:{g=((e[4812886]|0)>>>8^255)&255;return g|0};case 12582912:{g=((e[4812884]|0)>>>8^255)&255;return g|0};case 12582915:{i=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;l=a[6518032]|0;m=gGU(i,(i|0)<0|0?-1:0,l?67456:0,l?0:0)|0;l=c[2440536]|0;i=gGS(m,K,l,(l|0)<0|0?-1:0)|0;if((i|0)>((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)){Sb(i)}i=e[4812885]|0;if((c[2438144]|0)==0){g=(i&251^251)&255;return g|0}else{g=(i&123^123)&255;return g|0}break};default:{g=0;return g|0}}return 0}function dVf(e){e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;switch(e|0){case 12582914:{e=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;f=a[6518032]|0;g=gGU(e,(e|0)<0|0?-1:0,f?67456:0,f?0:0)|0;f=c[2440536]|0;e=gGS(g,K,f,(f|0)<0|0?-1:0)|0;if((e|0)>((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)){Sb(e)}e=b[4812885]|0;if((c[2438144]|0)==0){h=e&-5^-5;return h|0}else{h=e&-133^-133;return h|0}break};case 12582918:{e=b[4812887]&15^15;f=a[9719352]|0;g=f&255;if((a[9721008]&16)==0){if((g&1|0)==0){i=(d[9731136]|0)<<8}else{i=-256}j=i;k=f|1}else{if((g&4|0)==0){l=(d[9731144]|0)<<8}else{l=-256}j=l;k=f|4}a[9719352]=k;h=j|e|a[9733992]&240;return h|0};case 12582916:{h=~b[4812886];return h|0};case 12582912:{h=~b[4812884];return h|0};case 12582920:{h=(d[9719352]|0)<<8|2048;return h|0};default:{h=0;return h|0}}return 0}function dVg(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0;switch(b|0){case 12582929:{f=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;g=a[6518032]|0;h=gGU(f,(f|0)<0|0?-1:0,g?67456:0,g?0:0)|0;g=c[2440536]|0;f=gGS(h,K,g,(g|0)<0|0?-1:0)|0;if((f|0)>((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)){Sb(f)}c[2443866]=e<<24>>24;c[2438144]=0;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12;return};case 12582916:case 12582917:case 12582918:case 12582919:case 12582920:case 12582921:case 12582922:case 12582923:{switch(b&15|0){case 9:{a[9718344]=e;return};case 6:{a[9721e3]=e;return};case 7:{b=e&255;c[2438585]=b>>>6<<13;c[2438584]=b>>>4<<13&24576;a[9733992]=e;return};case 11:{switch(((a[9718344]|0)!=0?256:0)|e&255|0){case 19:{a[9719352]=1;a[9731144]=a[(c[2433494]|0)+(d[9733984]|0)|0]|0;return};case 275:{b=a[9721e3]|0;a[9752264]=b;f=a[9719352]&-2;a[9719352]=f;if(b<<24>>24==1){a[9731136]=85;i=f}else{g=f|2;a[9719352]=g;i=g}a[9719352]=i&-5;a[9731144]=b;return};case 284:{a[9719352]=5;a[9733984]=a[9721e3]|0;return};case 16:case 272:{a[9719352]=a[9719352]|4;return};default:{return}}break};case 8:{a[9721008]=e;return};default:{return}}break};default:{return}}}function dVh(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;switch(b|0){case 12582928:{f=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;g=a[6518032]|0;h=gGU(f,(f|0)<0|0?-1:0,g?67456:0,g?0:0)|0;g=c[2440536]|0;f=gGS(h,K,g,(g|0)<0|0?-1:0)|0;if((f|0)>((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)){Sb(f)}c[2443866]=(e&255)<<24>>24;c[2438144]=0;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12;return};case 12582916:case 12582917:case 12582918:case 12582919:case 12582920:case 12582921:case 12582922:case 12582923:{f=b&15;b=(e&65535)>>>8;g=b&255;L32412:do{switch(f|0){case 7:{h=b&65535;c[2438585]=h>>>6<<13;c[2438584]=h>>>4<<13&24576;a[9733992]=g;i=e&255;j=24546;break};case 11:{switch(((a[9718344]|0)!=0?256:0)|b&65535|0){case 275:{h=a[9721e3]|0;a[9752264]=h;k=a[9719352]&-2;a[9719352]=k;if(h<<24>>24==1){a[9731136]=85;l=k}else{m=k|2;a[9719352]=m;l=m}a[9719352]=l&-5;a[9731144]=h;j=24543;break L32412;break};case 19:{a[9719352]=1;a[9731144]=a[(c[2433494]|0)+(d[9733984]|0)|0]|0;return};case 16:case 272:{a[9719352]=a[9719352]|4;return};case 284:{a[9719352]=5;a[9733984]=a[9721e3]|0;return};default:{return}}break};case 6:{a[9721e3]=g;n=e&255;j=24545;break};case 8:{a[9721008]=g;o=e&255;j=24547;break};case 9:{a[9718344]=g;return};default:{j=24543}}}while(0);L32432:do{if((j|0)==24543){g=e&255;switch(f|0){case 5:{a[9721e3]=g;return};case 6:{n=g;j=24545;break L32432;break};case 7:{i=g;j=24546;break L32432;break};case 8:{o=g;j=24547;break L32432;break};case 10:{switch(((a[9718344]|0)!=0?256:0)|e&255|0){case 16:case 272:{a[9719352]=a[9719352]|4;return};case 275:{g=a[9721e3]|0;a[9752264]=g;l=a[9719352]&-2;a[9719352]=l;if(g<<24>>24==1){a[9731136]=85;p=l}else{b=l|2;a[9719352]=b;p=b}a[9719352]=p&-5;a[9731144]=g;return};case 284:{a[9719352]=5;a[9733984]=a[9721e3]|0;return};case 19:{a[9719352]=1;a[9731144]=a[(c[2433494]|0)+(d[9733984]|0)|0]|0;return};default:{return}}break};default:{return}}}}while(0);if((j|0)==24545){p=n&255;c[2438585]=p>>>6<<13;c[2438584]=p>>>4<<13&24576;a[9733992]=n;return}else if((j|0)==24546){a[9721008]=i;return}else if((j|0)==24547){a[9718344]=o;return}break};default:{return}}}function dVi(b,d){b=b|0;d=d|0;var f=0,g=0;f=b&8191^1;b=c[3532666]|0;a[b+f|0]=d;g=(c[2439416]|0)+(f<<1)|0;if((a[g]|0)==d<<24>>24){return}a[g]=d;d=e[b+(f&8190)>>1]|0;b=d>>>2&248;c[(c[3532664]|0)+(f>>>1<<2)>>2]=d>>>7<<8&63488|d&31|(b>>>5|b)<<3&2016;return}function dVj(a,d){a=a|0;d=d|0;var e=0;e=a>>>1&4095;b[(c[3532666]|0)+(e<<1)>>1]=d;a=(c[2439416]|0)+(e<<1)|0;if((b[a>>1]|0)==d<<16>>16){return}b[a>>1]=d;a=d&65535;d=a>>>2&248;c[(c[3532664]|0)+(e<<2)>>2]=a>>>7<<8&63488|a&31|(d>>>5|d)<<3&2016;return}function dVk(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2336716+(b*112|0)>>2];c[a+104>>2]=c[2336720+(b*112|0)>>2];c[a+108>>2]=c[2336724+(b*112|0)>>2];d=0;return d|0}function dVl(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=2336616+(b*112|0);e=0;return e|0}function dVm(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>23){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1534320+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dVn(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=63){if((a|0)==0){d=0;return d|0}e=a;f=2337512+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}f=b-64|0;if(f>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;a=692496+(f*12|0)|0;c[b>>2]=c[a>>2];c[b+4>>2]=c[a+4>>2];c[b+8>>2]=c[a+8>>2];d=0;return d|0}function dVo(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0;e=i;i=i+4680|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;z=e+1080|0;A=e+1192|0;B=e+1200|0;C=e+1312|0;D=e+1320|0;E=e+1432|0;F=e+1440|0;G=e+1552|0;H=e+1560|0;I=e+1672|0;J=e+1680|0;K=e+1792|0;L=e+1800|0;M=e+1912|0;N=e+1920|0;O=e+2032|0;P=e+2040|0;Q=e+2152|0;R=e+2160|0;S=e+2272|0;T=e+2280|0;U=e+2392|0;V=e+2400|0;W=e+2512|0;X=e+2520|0;Y=e+2632|0;Z=e+2640|0;_=e+2752|0;$=e+2760|0;aa=e+2872|0;ab=e+2880|0;ac=e+2992|0;ad=e+3e3|0;ae=e+3112|0;af=e+3120|0;ag=e+3232|0;ah=e+3240|0;ai=e+3352|0;aj=e+3360|0;ak=e+3472|0;al=e+3480|0;am=e+3592|0;an=e+3600|0;ao=e+3712|0;ap=e+3720|0;aq=e+3832|0;ar=e+3840|0;as=e+3952|0;at=e+3960|0;au=e+4072|0;av=e+4080|0;aw=e+4192|0;ax=e+4200|0;ay=e+4312|0;az=e+4320|0;aA=e+4432|0;aB=e+4440|0;aC=e+4552|0;aD=e+4560|0;aE=e+4672|0;c[2424]=5929;aF=c[642608+(c[2436]<<2)>>2]|0;aG=c[aF>>2]|0;if((fa(aG|0,288264)|0)==0){aH=24622}else{if((fa(aG|0,190080)|0)==0){aH=24622}else{aI=aG}}if((aH|0)==24622){c[3532668]=0;c[3531230]=1100;c[2430842]=4194304;c[2429716]=4194304;c[2429308]=0;c[2429306]=1048576;a[64272]=0;aI=c[aF>>2]|0}do{if((fa(aI|0,97520)|0)==0){aH=24628}else{if((fa(aI|0,550432)|0)==0){aH=24628;break}if((fa(aI|0,508976)|0)==0){aH=24628;break}if((fa(aI|0,484896)|0)==0){aH=24628;break}if((fa(aI|0,450040)|0)==0){aH=24628}else{aJ=aI}}}while(0);do{if((aH|0)==24628){c[3532668]=1;c[3531230]=1810;if((fa(aI|0,97520)|0)==0){c[3531230]=1006}if((fa(aI|0,550432)|0)==0){c[3531230]=2020}if((fa(aI|0,508976)|0)==0){c[3531230]=154}if((fa(aI|0,450040)|0)==0){c[3531230]=1090}c[2430842]=4194304;aG=(fa(aI|0,484896)|0)==0;c[2429716]=aG?12582912:16777216;c[2429308]=524288;c[2429306]=1048576;aG=c[aF>>2]|0;if((fa(aG|0,450040)|0)==0){a[64272]=0;aJ=aG;break}else{a[64272]=1;aJ=aG;break}}}while(0);do{if((fa(aJ|0,438584)|0)==0){aH=24643}else{if((fa(aJ|0,393320)|0)==0){aH=24643;break}if((fa(aJ|0,371608)|0)==0){aH=24643;break}if((fa(aJ|0,355472)|0)==0){aH=24643}else{aK=aJ}}}while(0);if((aH|0)==24643){c[3532668]=2;c[3531230]=1810;if((fa(aJ|0,393320)|0)==0){a[9718344]=0;a[9721e3]=-1;a[9731144]=-1;a[9731136]=-1;a[9719352]=5;a[9721008]=-1;a[9733984]=0;a[9752264]=0;c[2433494]=6485648;a[9733992]=0}if((fa(aJ|0,438584)|0)==0){aH=24647}else{if((fa(aJ|0,371608)|0)==0){aH=24647}}if((aH|0)==24647){a[9718344]=0;a[9721e3]=-1;a[9731144]=-1;a[9731136]=-1;a[9719352]=5;a[9721008]=-1;a[9733984]=0;a[9752264]=0;c[2433494]=7006520;a[9733992]=0}if((fa(aJ|0,355472)|0)==0){a[9718344]=0;a[9721e3]=-1;a[9731144]=-1;a[9731136]=-1;a[9719352]=5;a[9721008]=-1;a[9733984]=0;a[9752264]=0;c[2433494]=6485904;a[9733992]=0}c[2430842]=4194304;c[2429716]=16777216;c[2429308]=0;c[2429306]=2097152;a[64272]=0;aK=c[aF>>2]|0}do{if((fa(aK|0,339296)|0)==0){aH=24654}else{if((fa(aK|0,313648)|0)==0){aH=24654;break}aL=c[2429716]|0;aM=c[2430842]|0;aN=c[2429308]|0;aO=c[2429306]|0;aP=(c[3532668]|0)==0?133120:131584}}while(0);if((aH|0)==24654){c[3532668]=3;c[3531230]=1810;a[9718344]=0;a[9721e3]=-1;a[9731144]=-1;a[9731136]=-1;a[9719352]=5;a[9721008]=-1;a[9733984]=0;a[9752264]=0;c[2433494]=7006520;a[9733992]=0;c[2430842]=8388608;c[2429716]=12582912;c[2429308]=0;c[2429306]=4194304;a[64272]=0;aL=12582912;aM=8388608;aN=0;aO=4194304;aP=131584}c[2426738]=0;c[2442966]=0;c[2442962]=1048576;c[3532656]=1179648;c[3532660]=aL+1179648;aK=aL+1441792|0;c[3532650]=aK;aL=aK+aM|0;c[2430846]=aL;aM=aL+aN|0;c[2430844]=aM;aN=aM+aO|0;aO=aN|0;c[2405672]=aO;c[2442968]=aO;c[2442964]=aN+131072;aO=aN+aP|0;c[3532652]=aO;c[3532653]=aO+8192;c[3532654]=aO+16384;c[3532658]=aO+32768;c[3532666]=aO+40960;aP=aO+49152|0;c[2411694]=aP;c[2414234]=aP;aO=aP;aP=0;while(1){if((aP|0)>=1024){break}aQ=9638528+(aP<<2)|0;if((c[aQ>>2]|0)==0){aH=24658;break}else{aP=aP+1|0}}do{if((aH|0)==24658){aP=gGq(aO)|0;c[aQ>>2]=aP;if((aP|0)==0){break}gGz(aP|0,0,aO|0);c[2426738]=aP;gGz(aP|0,0,aO|0);c[2442966]=aP;c[2442962]=aP+1048576;c[3532656]=aP+1179648;aN=c[2429716]|0;c[3532660]=aP+(aN+1179648);aM=aN+1441792|0;c[3532650]=aP+aM;aN=aM+(c[2430842]|0)|0;c[2430846]=aP+aN;aM=aN+(c[2429308]|0)|0;c[2430844]=aP+aM;aN=aM+(c[2429306]|0)|0;aM=aP+aN|0;c[2405672]=aM;c[2442968]=aM;aM=c[3532668]|0;c[2442964]=aP+(aN+131072);aL=((aM|0)==0?133120:131584)+aN|0;c[3532652]=aP+aL;c[3532653]=aP+(aL+8192);c[3532654]=aP+(aL+16384);c[3532658]=aP+(aL+32768);c[3532666]=aP+(aL+40960);aN=aP+(aL+49152)|0;c[2411694]=aN;c[2414234]=aN;do{if((aM|0)==0){aN=0;while(1){if((aN|0)>=1024){aR=1;aH=25073;break}aS=9638528+(aN<<2)|0;if((c[aS>>2]|0)==0){break}else{aN=aN+1|0}}if((aH|0)==25073){i=e;return aR|0}aN=gGq(524288)|0;c[aS>>2]=aN;if((aN|0)==0){aR=1;i=e;return aR|0}gGz(aN|0,0,524288);do{if((c[3542200]|0)!=0){aL=az+108|0;c[aL>>2]=0;aP=az+100|0;c[aP>>2]=0;aK=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aK&16383](az,0)|0;if((c[aL>>2]|0)==0){break}aL=c[aP>>2]|0;c[aA>>2]=9534384;aP=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aP&16383](aA,0,0)|0;if((aL|0)<1){break}gzL(aN,0,0)|0}}while(0);aL=aN+262144|0;do{if((c[3542200]|0)!=0){aP=ax+108|0;c[aP>>2]=0;aK=ax+100|0;c[aK>>2]=0;aF=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aF&16383](ax,1)|0;if((c[aP>>2]|0)==0){break}aP=c[aK>>2]|0;c[ay>>2]=9534384;aK=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aK&16383](ay,1,0)|0;if((aP|0)<1){break}gzL(aL,0,1)|0}}while(0);aL=aN;aP=c[2442966]|0;aK=0;while(1){aF=aK<<1;b[aP+(aF<<1)>>1]=b[aL+(aK<<1)>>1]|0;b[aP+((aF|1)<<1)>>1]=b[aL+(aK+131072<<1)>>1]|0;aF=aK+1|0;if((aF|0)<131072){aK=aF}else{aT=0;break}}while(1){if((aT|0)>=1024){break}aU=9638528+(aT<<2)|0;if((c[aU>>2]|0)==(aN|0)){aH=24676;break}else{aT=aT+1|0}}if((aH|0)==24676){gGr(aN);c[aU>>2]=0}aK=c[3532656]|0;do{if((c[3542200]|0)!=0){aL=av+108|0;c[aL>>2]=0;aP=av+100|0;c[aP>>2]=0;aF=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aF&16383](av,2)|0;if((c[aL>>2]|0)==0){break}aL=c[aP>>2]|0;c[aw>>2]=9534384;aP=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aP&16383](aw,2,0)|0;if((aL|0)<1){break}gzL(aK,0,2)|0}}while(0);aK=c[3532656]|0;aN=aK;aL=2097152;aP=2097150;while(1){aF=d[aK+aP|0]|0;aJ=aL-1|0;aI=d[aK+aJ|0]|0;b[aN+(aP<<1)>>1]=(aI<<8&3840|aI>>>4)&65535;b[aN+(aJ<<1)>>1]=(aF<<8&3840|aF>>>4)&65535;aF=aP-2|0;if((aF|0)>-1){aL=aP;aP=aF}else{break}}aP=c[3532660]|0;do{if((c[3542200]|0)!=0){aL=at+108|0;c[aL>>2]=0;aN=at+100|0;c[aN>>2]=0;aK=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aK&16383](at,3)|0;if((c[aL>>2]|0)==0){break}aL=c[aN>>2]|0;c[au>>2]=9534384;aN=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aN&16383](au,3,0)|0;if((aL|0)<1){break}gzL(aP,0,3)|0}}while(0);aP=c[3532650]|0;do{if((c[3542200]|0)!=0){aL=ar+108|0;c[aL>>2]=0;aN=ar+100|0;c[aN>>2]=0;aK=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aK&16383](ar,4)|0;if((c[aL>>2]|0)==0){break}aL=c[aN>>2]|0;c[as>>2]=9534384;aN=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aN&16383](as,4,0)|0;if((aL|0)<1){break}gzL(aP,0,4)|0}}while(0);aP=(c[3532650]|0)+1048576|0;do{if((c[3542200]|0)!=0){aL=ap+108|0;c[aL>>2]=0;aN=ap+100|0;c[aN>>2]=0;aK=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aK&16383](ap,5)|0;if((c[aL>>2]|0)==0){break}aL=c[aN>>2]|0;c[aq>>2]=9534384;aN=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aN&16383](aq,5,0)|0;if((aL|0)<1){break}gzL(aP,0,5)|0}}while(0);aP=c[3532650]|0;aL=aP;aN=2097152;aK=2097150;while(1){aF=d[aP+aK|0]|0;aJ=aN-1|0;aI=d[aP+aJ|0]|0;b[aL+(aK<<1)>>1]=(aI<<8&3840|aI>>>4)&65535;b[aL+(aJ<<1)>>1]=(aF<<8&3840|aF>>>4)&65535;aF=aK-2|0;if((aF|0)>-1){aN=aK;aK=aF}else{break}}aK=c[2442962]|0;do{if((c[3542200]|0)!=0){aN=an+108|0;c[aN>>2]=0;aL=an+100|0;c[aL>>2]=0;aP=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aP&16383](an,6)|0;if((c[aN>>2]|0)==0){break}aN=c[aL>>2]|0;c[ao>>2]=9534384;aL=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aL&16383](ao,6,0)|0;if((aN|0)<1){break}gzL(aK,0,6)|0}}while(0);aK=c[2430844]|0;do{if((c[3542200]|0)!=0){aN=al+108|0;c[aN>>2]=0;aL=al+100|0;c[aL>>2]=0;aP=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aP&16383](al,7)|0;if((c[aN>>2]|0)==0){break}aN=c[aL>>2]|0;c[am>>2]=9534384;aL=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aL&16383](am,7,0)|0;if((aN|0)<1){break}gzL(aK,0,7)|0}}while(0);aK=c[2430844]|0;aN=0;do{aL=aK+aN|0;aP=a[aL]|0;a[aL]=aP<<1&-128|aP&63|(aP&255)>>>1&64;aN=aN+1|0;}while((aN|0)<1048576)}else if((aM|0)==1){aN=0;while(1){if((aN|0)>=1024){aR=1;aH=25075;break}aV=9638528+(aN<<2)|0;if((c[aV>>2]|0)==0){break}else{aN=aN+1|0}}if((aH|0)==25075){i=e;return aR|0}aN=gGq(1048576)|0;c[aV>>2]=aN;if((aN|0)==0){aR=1;i=e;return aR|0}gGz(aN|0,0,1048576);do{if((c[3542200]|0)!=0){aK=aj+108|0;c[aK>>2]=0;aP=aj+100|0;c[aP>>2]=0;aL=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aL&16383](aj,0)|0;if((c[aK>>2]|0)==0){break}aK=c[aP>>2]|0;c[ak>>2]=9534384;aP=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aP&16383](ak,0,0)|0;if((aK|0)<1){break}gzL(aN,0,0)|0}}while(0);aK=aN+524288|0;do{if((c[3542200]|0)!=0){aP=ah+108|0;c[aP>>2]=0;aL=ah+100|0;c[aL>>2]=0;aF=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aF&16383](ah,1)|0;if((c[aP>>2]|0)==0){break}aP=c[aL>>2]|0;c[ai>>2]=9534384;aL=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aL&16383](ai,1,0)|0;if((aP|0)<1){break}gzL(aK,0,1)|0}}while(0);aK=aN;aP=c[2442966]|0;aL=0;while(1){aF=aL<<1;b[aP+(aF<<1)>>1]=b[aK+(aL<<1)>>1]|0;b[aP+((aF|1)<<1)>>1]=b[aK+(aL+262144<<1)>>1]|0;aF=aL+1|0;if((aF|0)<262144){aL=aF}else{aW=0;break}}while(1){if((aW|0)>=1024){break}aX=9638528+(aW<<2)|0;if((c[aX>>2]|0)==(aN|0)){aH=24722;break}else{aW=aW+1|0}}if((aH|0)==24722){gGr(aN);c[aX>>2]=0}aL=c[3532656]|0;do{if((c[3542200]|0)!=0){aK=af+108|0;c[aK>>2]=0;aP=af+100|0;c[aP>>2]=0;aF=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aF&16383](af,2)|0;if((c[aK>>2]|0)==0){break}aK=c[aP>>2]|0;c[ag>>2]=9534384;aP=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aP&16383](ag,2,0)|0;if((aK|0)<1){break}gzL(aL,0,2)|0}}while(0);aL=(c[3532656]|0)+2097152|0;do{if((c[3542200]|0)!=0){aN=ad+108|0;c[aN>>2]=0;aK=ad+100|0;c[aK>>2]=0;aP=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aP&16383](ad,3)|0;if((c[aN>>2]|0)==0){break}aN=c[aK>>2]|0;c[ae>>2]=9534384;aK=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aK&16383](ae,3,0)|0;if((aN|0)<1){break}gzL(aL,0,3)|0}}while(0);aL=(c[3532656]|0)+4194304|0;do{if((c[3542200]|0)!=0){aN=ab+108|0;c[aN>>2]=0;aK=ab+100|0;c[aK>>2]=0;aP=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aP&16383](ab,4)|0;if((c[aN>>2]|0)==0){break}aN=c[aK>>2]|0;c[ac>>2]=9534384;aK=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aK&16383](ac,4,0)|0;if((aN|0)<1){break}gzL(aL,0,4)|0}}while(0);aL=c[2429716]|0;if((aL|0)>12582912){aN=(c[3532656]|0)+6291456|0;do{if((c[3542200]|0)!=0){aK=$+108|0;c[aK>>2]=0;aP=$+100|0;c[aP>>2]=0;aF=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aF&16383]($,5)|0;if((c[aK>>2]|0)==0){break}aK=c[aP>>2]|0;c[aa>>2]=9534384;aP=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aP&16383](aa,5,0)|0;if((aK|0)<1){break}gzL(aN,0,5)|0}}while(0);aY=c[2429716]|0}else{aY=aL}aN=c[3532656]|0;aK=aY>>1;aP=aK-2|0;if((aP|0)>-1){aF=aN;aJ=aK;aK=aP;while(1){aP=d[aN+aK|0]|0;aI=aJ-1|0;aG=d[aN+aI|0]|0;b[aF+(aK<<1)>>1]=(aG<<8&3840|aG>>>4)&65535;b[aF+(aI<<1)>>1]=(aP<<8&3840|aP>>>4)&65535;aP=aK-2|0;if((aP|0)>-1){aJ=aK;aK=aP}else{break}}}aK=c[3532660]|0;do{if((c[3542200]|0)!=0){aJ=Z+108|0;c[aJ>>2]=0;aF=Z+100|0;c[aF>>2]=0;aN=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aN&16383](Z,6)|0;if((c[aJ>>2]|0)==0){break}aJ=c[aF>>2]|0;c[_>>2]=9534384;aF=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aF&16383](_,6,0)|0;if((aJ|0)<1){break}gzL(aK,0,6)|0}}while(0);aK=c[3532650]|0;do{if((c[3542200]|0)!=0){aJ=X+108|0;c[aJ>>2]=0;aF=X+100|0;c[aF>>2]=0;aN=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aN&16383](X,7)|0;if((c[aJ>>2]|0)==0){break}aJ=c[aF>>2]|0;c[Y>>2]=9534384;aF=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aF&16383](Y,7,0)|0;if((aJ|0)<1){break}gzL(aK,0,7)|0}}while(0);aK=c[3532650]|0;aJ=aK;aF=2097152;aN=2097150;while(1){aL=d[aK+aN|0]|0;aP=aF-1|0;aI=d[aK+aP|0]|0;b[aJ+(aN<<1)>>1]=(aI<<8&3840|aI>>>4)&65535;b[aJ+(aP<<1)>>1]=(aL<<8&3840|aL>>>4)&65535;aL=aN-2|0;if((aL|0)>-1){aF=aN;aN=aL}else{break}}aN=c[2442962]|0;do{if((c[3542200]|0)!=0){aF=V+108|0;c[aF>>2]=0;aJ=V+100|0;c[aJ>>2]=0;aK=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aK&16383](V,8)|0;if((c[aF>>2]|0)==0){break}aF=c[aJ>>2]|0;c[W>>2]=9534384;aJ=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aJ&16383](W,8,0)|0;if((aF|0)<1){break}gzL(aN,0,8)|0}}while(0);aN=c[2430846]|0;do{if((c[3542200]|0)!=0){aF=T+108|0;c[aF>>2]=0;aJ=T+100|0;c[aJ>>2]=0;aK=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aK&16383](T,9)|0;if((c[aF>>2]|0)==0){break}aF=c[aJ>>2]|0;c[U>>2]=9534384;aJ=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aJ&16383](U,9,0)|0;if((aF|0)<1){break}gzL(aN,0,9)|0}}while(0);aN=c[2430844]|0;if((c[3542200]|0)==0){break}aF=R+108|0;c[aF>>2]=0;aJ=R+100|0;c[aJ>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](R,10)|0;if((c[aF>>2]|0)==0){break}aF=c[aJ>>2]|0;c[S>>2]=9534384;gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](S,10,0)|0;if((aF|0)<1){break}gzL(aN,0,10)|0}else if((aM|0)==2){aN=0;while(1){if((aN|0)>=1024){aR=1;aH=25077;break}aZ=9638528+(aN<<2)|0;if((c[aZ>>2]|0)==0){break}else{aN=aN+1|0}}if((aH|0)==25077){i=e;return aR|0}aN=gGq(1048576)|0;c[aZ>>2]=aN;if((aN|0)==0){aR=1;i=e;return aR|0}gGz(aN|0,0,1048576);do{if((c[3542200]|0)!=0){aF=P+108|0;c[aF>>2]=0;aJ=P+100|0;c[aJ>>2]=0;aK=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aK&16383](P,0)|0;if((c[aF>>2]|0)==0){break}aF=c[aJ>>2]|0;c[Q>>2]=9534384;aJ=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aJ&16383](Q,0,0)|0;if((aF|0)<1){break}gzL(aN,0,0)|0}}while(0);aF=aN+524288|0;do{if((c[3542200]|0)!=0){aJ=N+108|0;c[aJ>>2]=0;aK=N+100|0;c[aK>>2]=0;aL=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aL&16383](N,1)|0;if((c[aJ>>2]|0)==0){break}aJ=c[aK>>2]|0;c[O>>2]=9534384;aK=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aK&16383](O,1,0)|0;if((aJ|0)<1){break}gzL(aF,0,1)|0}}while(0);aF=aN;aJ=c[2442966]|0;aK=0;while(1){aL=aK<<1;b[aJ+(aL<<1)>>1]=b[aF+(aK<<1)>>1]|0;b[aJ+((aL|1)<<1)>>1]=b[aF+(aK+262144<<1)>>1]|0;aL=aK+1|0;if((aL|0)<262144){aK=aL}else{a_=0;break}}while(1){if((a_|0)>=1024){break}a$=9638528+(a_<<2)|0;if((c[a$>>2]|0)==(aN|0)){aH=24781;break}else{a_=a_+1|0}}if((aH|0)==24781){gGr(aN);c[a$>>2]=0}aK=c[3532656]|0;do{if((c[3542200]|0)!=0){aF=L+108|0;c[aF>>2]=0;aJ=L+100|0;c[aJ>>2]=0;aL=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aL&16383](L,2)|0;if((c[aF>>2]|0)==0){break}aF=c[aJ>>2]|0;c[M>>2]=9534384;aJ=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aJ&16383](M,2,0)|0;if((aF|0)<1){break}gzL(aK,0,2)|0}}while(0);aK=(c[3532656]|0)+2097152|0;do{if((c[3542200]|0)!=0){aN=J+108|0;c[aN>>2]=0;aF=J+100|0;c[aF>>2]=0;aJ=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aJ&16383](J,3)|0;if((c[aN>>2]|0)==0){break}aN=c[aF>>2]|0;c[K>>2]=9534384;aF=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aF&16383](K,3,0)|0;if((aN|0)<1){break}gzL(aK,0,3)|0}}while(0);aK=(c[3532656]|0)+4194304|0;do{if((c[3542200]|0)!=0){aN=H+108|0;c[aN>>2]=0;aF=H+100|0;c[aF>>2]=0;aJ=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aJ&16383](H,4)|0;if((c[aN>>2]|0)==0){break}aN=c[aF>>2]|0;c[I>>2]=9534384;aF=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aF&16383](I,4,0)|0;if((aN|0)<1){break}gzL(aK,0,4)|0}}while(0);aK=(c[3532656]|0)+6291456|0;do{if((c[3542200]|0)!=0){aN=F+108|0;c[aN>>2]=0;aF=F+100|0;c[aF>>2]=0;aJ=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aJ&16383](F,5)|0;if((c[aN>>2]|0)==0){break}aN=c[aF>>2]|0;c[G>>2]=9534384;aF=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aF&16383](G,5,0)|0;if((aN|0)<1){break}gzL(aK,0,5)|0}}while(0);aK=c[3532656]|0;aN=aK;aF=8388608;aJ=8388606;while(1){aL=d[aK+aJ|0]|0;aP=aF-1|0;aI=d[aK+aP|0]|0;b[aN+(aJ<<1)>>1]=(aI<<8&3840|aI>>>4)&65535;b[aN+(aP<<1)>>1]=(aL<<8&3840|aL>>>4)&65535;aL=aJ-2|0;if((aL|0)>-1){aF=aJ;aJ=aL}else{break}}aJ=c[3532660]|0;do{if((c[3542200]|0)!=0){aF=D+108|0;c[aF>>2]=0;aN=D+100|0;c[aN>>2]=0;aK=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aK&16383](D,6)|0;if((c[aF>>2]|0)==0){break}aF=c[aN>>2]|0;c[E>>2]=9534384;aN=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aN&16383](E,6,0)|0;if((aF|0)<1){break}gzL(aJ,0,6)|0}}while(0);aJ=c[3532650]|0;do{if((c[3542200]|0)!=0){aF=B+108|0;c[aF>>2]=0;aN=B+100|0;c[aN>>2]=0;aK=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aK&16383](B,7)|0;if((c[aF>>2]|0)==0){break}aF=c[aN>>2]|0;c[C>>2]=9534384;aN=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aN&16383](C,7,0)|0;if((aF|0)<1){break}gzL(aJ,0,7)|0}}while(0);aJ=c[3532650]|0;aF=aJ;aN=2097152;aK=2097150;while(1){aL=d[aJ+aK|0]|0;aP=aN-1|0;aI=d[aJ+aP|0]|0;b[aF+(aK<<1)>>1]=(aI<<8&3840|aI>>>4)&65535;b[aF+(aP<<1)>>1]=(aL<<8&3840|aL>>>4)&65535;aL=aK-2|0;if((aL|0)>-1){aN=aK;aK=aL}else{break}}aK=c[2442962]|0;do{if((c[3542200]|0)!=0){aN=z+108|0;c[aN>>2]=0;aF=z+100|0;c[aF>>2]=0;aJ=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aJ&16383](z,8)|0;if((c[aN>>2]|0)==0){break}aN=c[aF>>2]|0;c[A>>2]=9534384;aF=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aF&16383](A,8,0)|0;if((aN|0)<1){break}gzL(aK,0,8)|0}}while(0);aK=c[2430844]|0;if((c[3542200]|0)==0){break}aN=x+108|0;c[aN>>2]=0;aF=x+100|0;c[aF>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,9)|0;if((c[aN>>2]|0)==0){break}aN=c[aF>>2]|0;c[y>>2]=9534384;gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](y,9,0)|0;if((aN|0)<1){break}gzL(aK,0,9)|0}else if((aM|0)==3){aK=0;while(1){if((aK|0)>=1024){aR=1;aH=25079;break}a0=9638528+(aK<<2)|0;if((c[a0>>2]|0)==0){break}else{aK=aK+1|0}}if((aH|0)==25079){i=e;return aR|0}aK=gGq(1048576)|0;c[a0>>2]=aK;if((aK|0)==0){aR=1;i=e;return aR|0}gGz(aK|0,0,1048576);do{if((c[3542200]|0)!=0){aN=v+108|0;c[aN>>2]=0;aF=v+100|0;c[aF>>2]=0;aJ=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aJ&16383](v,0)|0;if((c[aN>>2]|0)==0){break}aN=c[aF>>2]|0;c[w>>2]=9534384;aF=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aF&16383](w,0,0)|0;if((aN|0)<1){break}gzL(aK,0,0)|0}}while(0);aN=aK+524288|0;do{if((c[3542200]|0)!=0){aF=t+108|0;c[aF>>2]=0;aJ=t+100|0;c[aJ>>2]=0;aL=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aL&16383](t,1)|0;if((c[aF>>2]|0)==0){break}aF=c[aJ>>2]|0;c[u>>2]=9534384;aJ=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aJ&16383](u,1,0)|0;if((aF|0)<1){break}gzL(aN,0,1)|0}}while(0);aN=aK;aF=c[2442966]|0;aJ=0;while(1){aL=aJ<<1;b[aF+(aL<<1)>>1]=b[aN+(aJ<<1)>>1]|0;b[aF+((aL|1)<<1)>>1]=b[aN+(aJ+262144<<1)>>1]|0;aL=aJ+1|0;if((aL|0)<262144){aJ=aL}else{a1=0;break}}while(1){if((a1|0)>=1024){break}a2=9638528+(a1<<2)|0;if((c[a2>>2]|0)==(aK|0)){aH=24833;break}else{a1=a1+1|0}}if((aH|0)==24833){gGr(aK);c[a2>>2]=0}aJ=c[3532656]|0;do{if((c[3542200]|0)!=0){aN=r+108|0;c[aN>>2]=0;aF=r+100|0;c[aF>>2]=0;aL=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aL&16383](r,2)|0;if((c[aN>>2]|0)==0){break}aN=c[aF>>2]|0;c[s>>2]=9534384;aF=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aF&16383](s,2,0)|0;if((aN|0)<1){break}gzL(aJ,0,2)|0}}while(0);aJ=(c[3532656]|0)+2097152|0;do{if((c[3542200]|0)!=0){aK=p+108|0;c[aK>>2]=0;aN=p+100|0;c[aN>>2]=0;aF=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aF&16383](p,3)|0;if((c[aK>>2]|0)==0){break}aK=c[aN>>2]|0;c[q>>2]=9534384;aN=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aN&16383](q,3,0)|0;if((aK|0)<1){break}gzL(aJ,0,3)|0}}while(0);aJ=(c[3532656]|0)+4194304|0;do{if((c[3542200]|0)!=0){aK=n+108|0;c[aK>>2]=0;aN=n+100|0;c[aN>>2]=0;aF=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aF&16383](n,4)|0;if((c[aK>>2]|0)==0){break}aK=c[aN>>2]|0;c[o>>2]=9534384;aN=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aN&16383](o,4,0)|0;if((aK|0)<1){break}gzL(aJ,0,4)|0}}while(0);aJ=c[3532656]|0;aK=aJ;aN=6291456;do{aN=aN-1|0;aF=d[aJ+aN|0]|0;b[aK+(aN<<1)>>1]=(aF<<8&3840|aF>>>4)&65535;}while((aN|0)>0);aN=c[3532660]|0;do{if((c[3542200]|0)!=0){aK=l+108|0;c[aK>>2]=0;aJ=l+100|0;c[aJ>>2]=0;aF=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aF&16383](l,5)|0;if((c[aK>>2]|0)==0){break}aK=c[aJ>>2]|0;c[m>>2]=9534384;aJ=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aJ&16383](m,5,0)|0;if((aK|0)<1){break}gzL(aN,0,5)|0}}while(0);aN=c[3532650]|0;do{if((c[3542200]|0)!=0){aK=j+108|0;c[aK>>2]=0;aJ=j+100|0;c[aJ>>2]=0;aF=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aF&16383](j,6)|0;if((c[aK>>2]|0)==0){break}aK=c[aJ>>2]|0;c[k>>2]=9534384;aJ=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aJ&16383](k,6,0)|0;if((aK|0)<1){break}gzL(aN,0,6)|0}}while(0);aN=c[3532650]|0;aK=aN;aJ=4194304;do{aJ=aJ-1|0;aF=d[aN+aJ|0]|0;b[aK+(aJ<<1)>>1]=(aF<<8&3840|aF>>>4)&65535;}while((aJ|0)>0);aJ=c[2442962]|0;do{if((c[3542200]|0)!=0){aK=f+108|0;c[aK>>2]=0;aN=f+100|0;c[aN>>2]=0;aF=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aF&16383](f,7)|0;if((c[aK>>2]|0)==0){break}aK=c[aN>>2]|0;c[g>>2]=9534384;aN=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aN&16383](g,7,0)|0;if((aK|0)<1){break}gzL(aJ,0,7)|0}}while(0);aJ=c[2430844]|0;do{if((c[3542200]|0)!=0){aK=aB+108|0;c[aK>>2]=0;aN=aB+100|0;c[aN>>2]=0;aF=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aF&16383](aB,8)|0;if((c[aK>>2]|0)==0){break}aK=c[aN>>2]|0;c[aC>>2]=9534384;aN=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aN&16383](aC,8,0)|0;if((aK|0)<1){break}gzL(aJ,0,8)|0}}while(0);aJ=(c[2430844]|0)+2097152|0;if((c[3542200]|0)==0){break}aK=aD+108|0;c[aK>>2]=0;aN=aD+100|0;c[aN>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](aD,9)|0;if((c[aK>>2]|0)==0){break}aK=c[aN>>2]|0;c[aE>>2]=9534384;gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](aE,9,0)|0;if((aK|0)<1){break}gzL(aJ,0,9)|0}}while(0);fxU(0,110018592);if((c[2394]|0)==0){a3=c[2112932]|0}else{c[2394]=0;aM=c[3532596]|0;c[2112932]=aM;aJ=c[3532592]|0;if((aJ|0)!=0){gGC(9104152,aJ|0,280)|0}c[2113054]=c[2113060];a3=aM}aM=c[2442966]|0;aJ=a3|0;aK=0;while(1){aN=aM+aK|0;c[aJ>>2]=aN;c[aJ+131072>>2]=aN;aN=aK+1024|0;if(aN>>>0>1048575){break}else{aJ=aJ+4|0;aK=aN}}aK=c[3532658]|0;c[a3+16384>>2]=aK;c[a3+81920>>2]=aK;c[a3+147456>>2]=aK;aJ=aK+1024|0;c[a3+16388>>2]=aJ;c[a3+81924>>2]=aJ;c[a3+147460>>2]=aJ;aJ=aK+2048|0;c[a3+16392>>2]=aJ;c[a3+81928>>2]=aJ;c[a3+147464>>2]=aJ;aJ=aK+3072|0;c[a3+16396>>2]=aJ;c[a3+81932>>2]=aJ;c[a3+147468>>2]=aJ;aJ=aK+4096|0;c[a3+16400>>2]=aJ;c[a3+81936>>2]=aJ;c[a3+147472>>2]=aJ;aJ=aK+5120|0;c[a3+16404>>2]=aJ;c[a3+81940>>2]=aJ;c[a3+147476>>2]=aJ;aJ=aK+6144|0;c[a3+16408>>2]=aJ;c[a3+81944>>2]=aJ;c[a3+147480>>2]=aJ;aJ=aK+7168|0;c[a3+16412>>2]=aJ;c[a3+81948>>2]=aJ;c[a3+147484>>2]=aJ;aJ=c[3532652]|0;c[a3+32768>>2]=aJ;c[a3+98304>>2]=aJ;c[a3+163840>>2]=aJ;aK=aJ+1024|0;c[a3+32772>>2]=aK;c[a3+98308>>2]=aK;c[a3+163844>>2]=aK;aK=aJ+2048|0;c[a3+32776>>2]=aK;c[a3+98312>>2]=aK;c[a3+163848>>2]=aK;aK=aJ+3072|0;c[a3+32780>>2]=aK;c[a3+98316>>2]=aK;c[a3+163852>>2]=aK;aK=aJ+4096|0;c[a3+32784>>2]=aK;c[a3+98320>>2]=aK;c[a3+163856>>2]=aK;aK=aJ+5120|0;c[a3+32788>>2]=aK;c[a3+98324>>2]=aK;c[a3+163860>>2]=aK;aK=aJ+6144|0;c[a3+32792>>2]=aK;c[a3+98328>>2]=aK;c[a3+163864>>2]=aK;aK=aJ+7168|0;c[a3+32796>>2]=aK;c[a3+98332>>2]=aK;c[a3+163868>>2]=aK;aK=c[3532653]|0;c[a3+32800>>2]=aK;c[a3+98336>>2]=aK;c[a3+163872>>2]=aK;aJ=aK+1024|0;c[a3+32804>>2]=aJ;c[a3+98340>>2]=aJ;c[a3+163876>>2]=aJ;aJ=aK+2048|0;c[a3+32808>>2]=aJ;c[a3+98344>>2]=aJ;c[a3+163880>>2]=aJ;aJ=aK+3072|0;c[a3+32812>>2]=aJ;c[a3+98348>>2]=aJ;c[a3+163884>>2]=aJ;aJ=aK+4096|0;c[a3+32816>>2]=aJ;c[a3+98352>>2]=aJ;c[a3+163888>>2]=aJ;aJ=aK+5120|0;c[a3+32820>>2]=aJ;c[a3+98356>>2]=aJ;c[a3+163892>>2]=aJ;aJ=aK+6144|0;c[a3+32824>>2]=aJ;c[a3+98360>>2]=aJ;c[a3+163896>>2]=aJ;aJ=aK+7168|0;c[a3+32828>>2]=aJ;c[a3+98364>>2]=aJ;c[a3+163900>>2]=aJ;aJ=c[3532654]|0;c[a3+32832>>2]=aJ;c[a3+98368>>2]=aJ;c[a3+163904>>2]=aJ;aK=aJ+1024|0;c[a3+32836>>2]=aK;c[a3+98372>>2]=aK;c[a3+163908>>2]=aK;aK=aJ+2048|0;c[a3+32840>>2]=aK;c[a3+98376>>2]=aK;c[a3+163912>>2]=aK;aK=aJ+3072|0;c[a3+32844>>2]=aK;c[a3+98380>>2]=aK;c[a3+163916>>2]=aK;aK=aJ+4096|0;c[a3+32848>>2]=aK;c[a3+98384>>2]=aK;c[a3+163920>>2]=aK;aK=aJ+5120|0;c[a3+32852>>2]=aK;c[a3+98388>>2]=aK;c[a3+163924>>2]=aK;aK=aJ+6144|0;c[a3+32856>>2]=aK;c[a3+98392>>2]=aK;c[a3+163928>>2]=aK;aK=aJ+7168|0;c[a3+32860>>2]=aK;c[a3+98396>>2]=aK;c[a3+163932>>2]=aK;aK=aJ+8192|0;c[a3+32864>>2]=aK;c[a3+98400>>2]=aK;c[a3+163936>>2]=aK;aK=aJ+9216|0;c[a3+32868>>2]=aK;c[a3+98404>>2]=aK;c[a3+163940>>2]=aK;aK=aJ+10240|0;c[a3+32872>>2]=aK;c[a3+98408>>2]=aK;c[a3+163944>>2]=aK;aK=aJ+11264|0;c[a3+32876>>2]=aK;c[a3+98412>>2]=aK;c[a3+163948>>2]=aK;aK=aJ+12288|0;c[a3+32880>>2]=aK;c[a3+98416>>2]=aK;c[a3+163952>>2]=aK;aK=aJ+13312|0;c[a3+32884>>2]=aK;c[a3+98420>>2]=aK;c[a3+163956>>2]=aK;aK=aJ+14336|0;c[a3+32888>>2]=aK;c[a3+98424>>2]=aK;c[a3+163960>>2]=aK;aK=aJ+15360|0;c[a3+32892>>2]=aK;c[a3+98428>>2]=aK;c[a3+163964>>2]=aK;aK=c[2442968]|0;aJ=a3+65024|0;aM=16646144;while(1){aN=aK+(aM-16646144)|0;c[aJ>>2]=aN;c[aJ+65536>>2]=aN;c[aJ+131072>>2]=aN;aN=aM+1024|0;if(aN>>>0>16777215){break}else{aJ=aJ+4|0;aM=aN}}aM=c[3532666]|0;c[a3+24576>>2]=aM;c[a3+155648>>2]=aM;aJ=aM+1024|0;c[a3+24580>>2]=aJ;c[a3+155652>>2]=aJ;aJ=aM+2048|0;c[a3+24584>>2]=aJ;c[a3+155656>>2]=aJ;aJ=aM+3072|0;c[a3+24588>>2]=aJ;c[a3+155660>>2]=aJ;aJ=aM+4096|0;c[a3+24592>>2]=aJ;c[a3+155664>>2]=aJ;aJ=aM+5120|0;c[a3+24596>>2]=aJ;c[a3+155668>>2]=aJ;aJ=aM+6144|0;c[a3+24600>>2]=aJ;c[a3+155672>>2]=aJ;aJ=aM+7168|0;c[a3+24604>>2]=aJ;c[a3+155676>>2]=aJ;c[a3+90112>>2]=1;c[a3+90116>>2]=1;c[a3+90120>>2]=1;c[a3+90124>>2]=1;c[a3+90128>>2]=1;c[a3+90132>>2]=1;c[a3+90136>>2]=1;c[a3+90140>>2]=1;aJ=c[3532668]|0;if((aJ|0)==0){c[a3+196688>>2]=3336;c[a3+196608>>2]=878;c[a3+196728>>2]=2650;c[a3+196648>>2]=918}else if((aJ|0)==1){c[a3+196688>>2]=2268;c[a3+196608>>2]=232;c[a3+196728>>2]=2650;c[a3+196648>>2]=918}else if((aJ|0)==2|(aJ|0)==3){c[a3+196688>>2]=2182;c[a3+196608>>2]=700;c[a3+196728>>2]=1244;c[a3+196648>>2]=2530}c[a3+196732>>2]=3362;c[a3+196652>>2]=566;aJ=c[3532592]|0;if((aJ|0)!=0){gGC(aJ|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);aJ=c[2439330]|0;aM=(aJ|0)==0;if(!aM){aK=aJ;gGC(9706056,aK|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];aK=c[3528484]|0;c[2076596]=aK;aN=c[2417276]|0;c[3541536]=aN;c[1836236]=0;aF=c[3532668]|0;if((aF|0)==0){aL=c[2442962]|0;aP=0;aI=0;while(1){c[aJ+76+(aI<<2)>>2]=aL+(aI<<8);aG=aP+1&65535;if((aG&65535)>119){a4=0;a5=0;break}else{aP=aG;aI=aG&65535}}while(1){aI=aL+(a5<<8)|0;c[aJ+76+(a5+512<<2)>>2]=aI;c[aJ+76+(a5+768<<2)>>2]=aI;aI=a4+1&65535;if((aI&65535)>119){break}else{a4=aI;a5=aI&65535}}aL=c[2442964]|0;c[aJ+556>>2]=aL;aI=aL+256|0;c[aJ+560>>2]=aI;aP=aL+512|0;c[aJ+564>>2]=aP;aG=aL+768|0;c[aJ+568>>2]=aG;a6=aL+1024|0;c[aJ+572>>2]=a6;a7=aL+1280|0;c[aJ+576>>2]=a7;a8=aL+1536|0;c[aJ+580>>2]=a8;a9=aL+1792|0;c[aJ+584>>2]=a9;c[aJ+1580>>2]=aL;c[aJ+1584>>2]=aI;c[aJ+1588>>2]=aP;c[aJ+1592>>2]=aG;c[aJ+1596>>2]=a6;c[aJ+1600>>2]=a7;c[aJ+1604>>2]=a8;c[aJ+1608>>2]=a9;c[aJ+2604>>2]=aL;c[aJ+3628>>2]=aL;c[aJ+2608>>2]=aI;c[aJ+3632>>2]=aI;c[aJ+2612>>2]=aP;c[aJ+3636>>2]=aP;c[aJ+2616>>2]=aG;c[aJ+3640>>2]=aG;c[aJ+2620>>2]=a6;c[aJ+3644>>2]=a6;c[aJ+2624>>2]=a7;c[aJ+3648>>2]=a7;c[aJ+2628>>2]=a8;c[aJ+3652>>2]=a8;c[aJ+2632>>2]=a9;c[aJ+3656>>2]=a9;c[aJ+4172>>2]=142;c[aJ+4176>>2]=1664}else if((aF|0)==1){a9=c[2442962]|0;a8=0;a7=0;while(1){c[aJ+76+(a7<<2)>>2]=a9+(a7<<8);a6=a8+1&65535;if((a6&65535)>127){ba=0;bb=0;break}else{a8=a6;a7=a6&65535}}while(1){a7=a9+(bb<<8)|0;c[aJ+76+(bb+512<<2)>>2]=a7;c[aJ+76+(bb+768<<2)>>2]=a7;a7=ba+1&65535;if((a7&65535)>127){break}else{ba=a7;bb=a7&65535}}a9=c[2442964]|0;c[aJ+588>>2]=a9;a7=a9+256|0;c[aJ+592>>2]=a7;c[aJ+1612>>2]=a9;c[aJ+1616>>2]=a7;c[aJ+2636>>2]=a9;c[aJ+3660>>2]=a9;c[aJ+2640>>2]=a7;c[aJ+3664>>2]=a7;c[aJ+4172>>2]=696;c[aJ+4176>>2]=962}else if((aF|0)==2|(aF|0)==3){a7=c[2442962]|0;a9=0;a8=0;while(1){c[aJ+76+(a8<<2)>>2]=a7+(a8<<8);a6=a9+1&65535;if((a6&65535)>127){bc=0;bd=0;break}else{a9=a6;a8=a6&65535}}while(1){a8=a7+(bd<<8)|0;c[aJ+76+(bd+512<<2)>>2]=a8;c[aJ+76+(bd+768<<2)>>2]=a8;a8=bc+1&65535;if((a8&65535)>127){break}else{bc=a8;bd=a8&65535}}a7=c[2442964]|0;c[aJ+588>>2]=a7;a8=a7+256|0;c[aJ+592>>2]=a8;c[aJ+1612>>2]=a7;c[aJ+1616>>2]=a8;c[aJ+2636>>2]=a7;c[aJ+3660>>2]=a7;c[aJ+2640>>2]=a8;c[aJ+3664>>2]=a8;c[aJ+4172>>2]=3020;c[aJ+4176>>2]=2464}if(!aM){a8=aJ;gGC(a8|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=aK;c[2417276]=aN;c[1836236]=-1;a8=0;while(1){if((a8|0)>=1024){be=0;break}bf=9638528+(a8<<2)|0;if((c[bf>>2]|0)==0){aH=24905;break}else{a8=a8+1|0}}do{if((aH|0)==24905){a8=gGq(16384)|0;c[bf>>2]=a8;if((a8|0)==0){be=0;break}gGz(a8|0,0,16384);be=a8}}while(0);c[3532664]=be;gGz(be|0,0,16384);a8=0;while(1){if((a8|0)>=1024){bg=0;break}bh=9638528+(a8<<2)|0;if((c[bh>>2]|0)==0){aH=24910;break}else{a8=a8+1|0}}do{if((aH|0)==24910){a8=gGq(8192)|0;c[bh>>2]=a8;if((a8|0)==0){bg=0;break}gGz(a8|0,0,8192);bg=a8}}while(0);c[2439416]=bg;gGz(bg|0,0,8192);c[2112966]=c[3532664];a8=(c[2430842]|0)>>>8;aN=1;while(1){if((aN|0)<(a8|0)){aN=aN<<1}else{break}}aK=aN-1|0;c[2438582]=aK;aJ=c[2433344]|0;if((aJ|0)==0){bi=aK}else{aM=0;while(1){if((aM|0)>=1024){bj=aK;break}bk=9638528+(aM<<2)|0;if((c[bk>>2]|0)==(aJ|0)){aH=24917;break}else{aM=aM+1|0}}if((aH|0)==24917){gGr(aJ);c[bk>>2]=0;bj=c[2438582]|0}c[2433344]=0;bi=bj}aM=bi+1|0;aK=0;while(1){if((aK|0)>=1024){aH=24923;break}bl=9638528+(aK<<2)|0;if((c[bl>>2]|0)==0){aH=24922;break}else{aK=aK+1|0}}do{if((aH|0)==24922){aK=gGq(aM)|0;c[bl>>2]=aK;if((aK|0)==0){aH=24923;break}gGz(aK|0,0,aM|0);c[2433344]=aK;if((a8|0)!=0){aJ=c[3532650]|0;aN=0;while(1){a7=aN+1|0;a9=a7<<8;aF=1;a6=1;aG=aN<<8;while(1){aP=a[aJ+aG|0]|0;aI=aP<<24>>24==0;bm=aI&aF;if(!(aI|a6)){aH=24929;break}aI=aP<<24>>24==-1;if(!(aI|bm)){aH=24931;break}bn=aI&a6;aI=aG+1|0;if((aI|0)<(a9|0)){aF=bm;a6=bn;aG=aI}else{aH=24933;break}}do{if((aH|0)==24929){aH=0;a[aK+aN|0]=-1}else if((aH|0)==24931){aH=0;a[aK+aN|0]=-1}else if((aH|0)==24933){aH=0;aG=aK+aN|0;a[aG]=-1;if(bm){a[aG]=0;if(!bn){break}}else{if(!bn){break}}a[aG]=15}}while(0);if((a7|0)<(a8|0)){aN=a7}else{break}}}aN=c[2438582]|0;if((a8|0)<=(aN|0)){aJ=a8;do{a[aK+aJ|0]=-1;aJ=aJ+1|0;}while((aJ|0)<=(aN|0))}c[2438584]=0;c[2438585]=8192}}while(0);if((aH|0)==24923){c[2433344]=0}a8=c[2429716]|0;aM=(a8|0)/256|0;aN=c[2440428]|0;if((aN|0)==0){bo=0}else{aJ=aN|0;aN=0;while(1){if((aN|0)>=1024){break}bp=9638528+(aN<<2)|0;if((c[bp>>2]|0)==(aJ|0)){aH=24944;break}else{aN=aN+1|0}}if((aH|0)==24944){gGr(aJ);c[bp>>2]=0}c[2440428]=0;bo=0}while(1){if((bo|0)>=1024){aH=24950;break}bq=9638528+(bo<<2)|0;if((c[bq>>2]|0)==0){aH=24948;break}else{bo=bo+1|0}}L32969:do{if((aH|0)==24948){aJ=gGq(65536)|0;c[bq>>2]=aJ;if((aJ|0)==0){aH=24950;break}gGz(aJ|0,0,65536);c[2440428]=aJ;gGz(9761824,-1|0,32);c[2439224]=65536;c[2439225]=65536;c[2439226]=65536;c[2439227]=65536;c[2439228]=65536;c[2439229]=65536;c[2439230]=65536;c[2439231]=65536;aJ=c[2394716]|0;if((aJ|0)==0){br=0}else{aN=aJ;aJ=0;while(1){if((aJ|0)>=1024){break}bs=9638528+(aJ<<2)|0;if((c[bs>>2]|0)==(aN|0)){aH=24974;break}else{aJ=aJ+1|0}}if((aH|0)==24974){gGr(aN);c[bs>>2]=0}c[2394716]=0;br=0}while(1){if((br|0)>=1024){break}bt=9638528+(br<<2)|0;if((c[bt>>2]|0)==0){aH=24978;break}else{br=br+1|0}}do{if((aH|0)==24978){aN=gGq(143360)|0;c[bt>>2]=aN;if((aN|0)==0){break}c[2394716]=aN;gGz(aN|0,0,143360);c[2394730]=0;aN=1;while(1){if((aN|0)<(a8|0)){aN=aN<<1}else{break}}a7=aN-1|0;c[2429854]=a7;aJ=c[2430072]|0;if((aJ|0)==0){bu=a7}else{aK=0;while(1){if((aK|0)>=1024){bv=a7;break}bw=9638528+(aK<<2)|0;if((c[bw>>2]|0)==(aJ|0)){aH=25005;break}else{aK=aK+1|0}}if((aH|0)==25005){gGr(aJ);c[bw>>2]=0;bv=c[2429854]|0}c[2430072]=0;bu=bv}aK=bu+1|0;a7=0;while(1){if((a7|0)>=1024){break}bx=9638528+(a7<<2)|0;if((c[bx>>2]|0)==0){aH=25010;break}else{a7=a7+1|0}}do{if((aH|0)==25010){a7=gGq(aK)|0;c[bx>>2]=a7;if((a7|0)==0){break}gGz(a7|0,0,aK|0);c[2430072]=a7;if((a8|0)>255){aJ=c[3532656]|0;aN=0;while(1){aG=aN+1|0;a6=aG<<8;aF=1;a9=1;aI=aN<<8;while(1){aP=a[aJ+aI|0]|0;aL=aP<<24>>24==0;by=aL&aF;if(!(aL|a9)){aH=25017;break}aL=aP<<24>>24==-1;if(!(aL|by)){aH=25019;break}bz=aL&a9;aL=aI+1|0;if((aL|0)<(a6|0)){aF=by;a9=bz;aI=aL}else{aH=25021;break}}do{if((aH|0)==25017){aH=0;a[a7+aN|0]=-1}else if((aH|0)==25019){aH=0;a[a7+aN|0]=-1}else if((aH|0)==25021){aH=0;aI=a7+aN|0;a[aI]=-1;if(by){a[aI]=0;if(!bz){break}}else{if(!bz){break}}a[aI]=15}}while(0);if((aG|0)<(aM|0)){aN=aG}else{break}}}aN=c[2429854]|0;if((aM|0)>(aN|0)){bA=0}else{aJ=aM;while(1){a[a7+aJ|0]=-1;aI=aJ+1|0;if((aI|0)>(aN|0)){bA=0;break}else{aJ=aI}}}while(1){if((bA|0)>=1024){bB=0;break}bC=9638528+(bA<<2)|0;if((c[bC>>2]|0)==0){aH=25029;break}else{bA=bA+1|0}}do{if((aH|0)==25029){aJ=gGq(1088)|0;c[bC>>2]=aJ;if((aJ|0)==0){bB=0;break}gGz(aJ|0,0,1088);bB=aJ}}while(0);c[2433342]=bB;aJ=0;while(1){if((aJ|0)>=1024){bD=bB;aH=25036;break}bE=9638528+(aJ<<2)|0;if((c[bE>>2]|0)==0){aH=25034;break}else{aJ=aJ+1|0}}do{if((aH|0)==25034){aJ=gGq(1088)|0;c[bE>>2]=aJ;if((aJ|0)==0){bD=c[2433342]|0;aH=25036;break}gGz(aJ|0,0,1088);aN=aJ;c[2433340]=aN;a7=c[2433342]|0;aI=a7;if((a7|0)==0){bF=aI;bG=aN;break}gGz(aI|0,0,1088);gGz(aJ|0,0,1088);aJ=8;while(1){aI=aJ<<4;a9=1048576/(aJ|0)|0;aF=0;a6=0;while(1){c[a7+(aF+aI<<2)>>2]=a6+32768>>16;aL=aF+1|0;if((aL|0)>=(aJ|0)){bH=1;break}aF=aL;a6=a6+a9|0}do{a9=bH+aI|0;a6=a9-1|0;c[aN+(a6<<2)>>2]=(c[a7+(a9<<2)>>2]|0)-(c[a7+(a6<<2)>>2]|0)<<4;bH=bH+1|0;}while((bH|0)<(aJ|0));c[aN+(aJ-1+aI<<2)>>2]=c[aN+(aI<<2)>>2];a6=aJ+1|0;if((a6|0)<16){aJ=a6}else{bI=0;break}}do{aJ=bI+256|0;c[a7+(aJ<<2)>>2]=bI;c[aN+(aJ<<2)>>2]=16;bI=bI+1|0;}while((bI|0)<16);c[2409622]=0;break L32969}}while(0);if((aH|0)==25036){c[2433340]=0;bF=bD;bG=0}aN=0;while(1){if((aN|0)>=1024){bJ=bG;break}bK=9638528+(aN<<2)|0;if((c[bK>>2]|0)==(bF|0)){aH=25041;break}else{aN=aN+1|0}}if((aH|0)==25041){gGr(bF);c[bK>>2]=0;bJ=c[2433340]|0}c[2433342]=0;aN=bJ;a7=0;while(1){if((a7|0)>=1024){break}bL=9638528+(a7<<2)|0;if((c[bL>>2]|0)==(aN|0)){aH=25045;break}else{a7=a7+1|0}}if((aH|0)==25045){gGr(aN);c[bL>>2]=0}c[2433340]=0;a7=c[2430072]|0;aJ=0;while(1){if((aJ|0)>=1024){break}bM=9638528+(aJ<<2)|0;if((c[bM>>2]|0)==(a7|0)){aH=25049;break}else{aJ=aJ+1|0}}if((aH|0)==25049){gGr(a7);c[bM>>2]=0}c[2430072]=0;aJ=c[2440428]|0;aN=0;while(1){if((aN|0)>=1024){break}bN=9638528+(aN<<2)|0;if((c[bN>>2]|0)==(aJ|0)){aH=25053;break}else{aN=aN+1|0}}if((aH|0)==25053){gGr(aJ);c[bN>>2]=0}c[2440428]=0;aN=c[2394716]|0;a7=0;while(1){if((a7|0)>=1024){break}bO=9638528+(a7<<2)|0;if((c[bO>>2]|0)==(aN|0)){aH=25057;break}else{a7=a7+1|0}}if((aH|0)==25057){gGr(aN);c[bO>>2]=0}c[2394716]=0;break L32969}}while(0);c[2430072]=0;break L32969}}while(0);c[2394716]=0;aK=c[2433342]|0;a7=0;while(1){if((a7|0)>=1024){break}bP=9638528+(a7<<2)|0;if((c[bP>>2]|0)==(aK|0)){aH=24982;break}else{a7=a7+1|0}}if((aH|0)==24982){gGr(aK);c[bP>>2]=0}c[2433342]=0;a7=c[2433340]|0;aJ=0;while(1){if((aJ|0)>=1024){break}bQ=9638528+(aJ<<2)|0;if((c[bQ>>2]|0)==(a7|0)){aH=24986;break}else{aJ=aJ+1|0}}if((aH|0)==24986){gGr(a7);c[bQ>>2]=0}c[2433340]=0;aJ=c[2430072]|0;aK=0;while(1){if((aK|0)>=1024){break}bR=9638528+(aK<<2)|0;if((c[bR>>2]|0)==(aJ|0)){aH=24990;break}else{aK=aK+1|0}}if((aH|0)==24990){gGr(aJ);c[bR>>2]=0}c[2430072]=0;aK=c[2440428]|0;a7=0;while(1){if((a7|0)>=1024){break}bS=9638528+(a7<<2)|0;if((c[bS>>2]|0)==(aK|0)){aH=24994;break}else{a7=a7+1|0}}if((aH|0)==24994){gGr(aK);c[bS>>2]=0}c[2440428]=0;a7=c[2394716]|0;aJ=0;while(1){if((aJ|0)>=1024){break}bT=9638528+(aJ<<2)|0;if((c[bT>>2]|0)==(a7|0)){aH=24998;break}else{aJ=aJ+1|0}}if((aH|0)==24998){gGr(a7);c[bT>>2]=0}c[2394716]=0}}while(0);if((aH|0)==24950){c[2440428]=0;aM=c[2433342]|0;a8=0;while(1){if((a8|0)>=1024){break}bU=9638528+(a8<<2)|0;if((c[bU>>2]|0)==(aM|0)){aH=24953;break}else{a8=a8+1|0}}if((aH|0)==24953){gGr(aM);c[bU>>2]=0}c[2433342]=0;a8=c[2433340]|0;aJ=0;while(1){if((aJ|0)>=1024){break}bV=9638528+(aJ<<2)|0;if((c[bV>>2]|0)==(a8|0)){aH=24957;break}else{aJ=aJ+1|0}}if((aH|0)==24957){gGr(a8);c[bV>>2]=0}c[2433340]=0;aJ=c[2430072]|0;aM=0;while(1){if((aM|0)>=1024){break}bW=9638528+(aM<<2)|0;if((c[bW>>2]|0)==(aJ|0)){aH=24961;break}else{aM=aM+1|0}}if((aH|0)==24961){gGr(aJ);c[bW>>2]=0}c[2430072]=0;aM=c[2440428]|0;a8=0;while(1){if((a8|0)>=1024){break}bX=9638528+(a8<<2)|0;if((c[bX>>2]|0)==(aM|0)){aH=24965;break}else{a8=a8+1|0}}if((aH|0)==24965){gGr(aM);c[bX>>2]=0}c[2440428]=0;a8=c[2394716]|0;aJ=0;while(1){if((aJ|0)>=1024){break}bY=9638528+(aJ<<2)|0;if((c[bY>>2]|0)==(a8|0)){aH=24969;break}else{aJ=aJ+1|0}}if((aH|0)==24969){gGr(a8);c[bY>>2]=0}c[2394716]=0}aJ=c[3532668]|0;if((aJ|0)==0|(aJ|0)==1){TW(c[2430844]|0,9717224,c[2430846]|0,9717232,3384,854,48);c[2438228]=4e6;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=511;h[745406]=1.0;c[2436786]=1;h[745405]=1.0;c[2436784]=2;h[745404]=1.2;a[3203280]=1}else if((aJ|0)==2|(aJ|0)==3){Vz(c[2430844]|0,3384,854);h[607289]=1.0;c[2433120]=1;h[607288]=1.0;c[2433118]=2;c[2438228]=4e6;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=511}c[2427028]=-1;dV$();aR=0;i=e;return aR|0}}while(0);c[2426738]=0;aR=1;i=e;return aR|0}function dVp(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[3532668]|0;do{if((b|0)==0|(b|0)==1){d=c[3541514]|0;if((d|0)!=0){gGr(d|0);c[3541514]=0}c[2113008]=0;c[2076598]=0;c[2383582]=0;c[2438228]=0;c[2433526]=0;c[2406676]=0;c[3528472]=0;d=c[2406698]|0;if((d|0)!=0){gGr(d);c[2406698]=0}d=c[2385412]|0;if((d|0)!=0){gGr(d);c[2385412]=0}a[64232]=0}else if((b|0)==2|(b|0)==3){c[2438228]=0;c[2433526]=0;c[2406676]=0;c[3528472]=0;d=c[2406678]|0;if((d|0)==0){break}gGr(d);c[2406678]=0}}while(0);b=c[2433342]|0;d=0;while(1){if((d|0)>=1024){break}e=9638528+(d<<2)|0;if((c[e>>2]|0)==(b|0)){f=25095;break}else{d=d+1|0}}if((f|0)==25095){gGr(b);c[e>>2]=0}c[2433342]=0;e=c[2433340]|0;b=0;while(1){if((b|0)>=1024){break}g=9638528+(b<<2)|0;if((c[g>>2]|0)==(e|0)){f=25099;break}else{b=b+1|0}}if((f|0)==25099){gGr(e);c[g>>2]=0}c[2433340]=0;g=c[2430072]|0;e=0;while(1){if((e|0)>=1024){break}h=9638528+(e<<2)|0;if((c[h>>2]|0)==(g|0)){f=25103;break}else{e=e+1|0}}if((f|0)==25103){gGr(g);c[h>>2]=0}c[2430072]=0;h=c[2440428]|0;g=0;while(1){if((g|0)>=1024){break}i=9638528+(g<<2)|0;if((c[i>>2]|0)==(h|0)){f=25107;break}else{g=g+1|0}}if((f|0)==25107){gGr(h);c[i>>2]=0}c[2440428]=0;i=c[2394716]|0;h=0;while(1){if((h|0)>=1024){break}j=9638528+(h<<2)|0;if((c[j>>2]|0)==(i|0)){f=25111;break}else{h=h+1|0}}if((f|0)==25111){gGr(i);c[j>>2]=0}c[2394716]=0;j=c[2433344]|0;i=0;while(1){if((i|0)>=1024){break}k=9638528+(i<<2)|0;if((c[k>>2]|0)==(j|0)){f=25115;break}else{i=i+1|0}}if((f|0)==25115){gGr(j);c[k>>2]=0}c[2433344]=0;k=c[3532664]|0;j=0;while(1){if((j|0)>=1024){break}l=9638528+(j<<2)|0;if((c[l>>2]|0)==(k|0)){f=25119;break}else{j=j+1|0}}if((f|0)==25119){gGr(k);c[l>>2]=0}c[3532664]=0;l=c[2439416]|0;k=0;while(1){if((k|0)>=1024){break}m=9638528+(k<<2)|0;if((c[m>>2]|0)==(l|0)){f=25123;break}else{k=k+1|0}}if((f|0)==25123){gGr(l);c[m>>2]=0}c[2439416]=0;if((c[2392]|0)>=0){m=0;do{l=14130368+(m<<2)|0;k=c[l>>2]|0;if((k|0)!=0){gGr(k);c[l>>2]=0}l=14130384+(m<<2)|0;k=c[l>>2]|0;if((k|0)!=0){gGr(k);c[l>>2]=0}m=m+1|0;}while((m|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;fwZ();m=c[2426738]|0;l=0;while(1){if((l|0)>=1024){f=25135;break}n=9638528+(l<<2)|0;if((c[n>>2]|0)==(m|0)){break}else{l=l+1|0}}if((f|0)==25135){c[2426738]=0;return 0}gGr(m);c[n>>2]=0;c[2426738]=0;return 0}function dVq(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;if((a[9624288]|0)!=0){dV$()}b[4812884]=0;b[4812885]=0;d=0;f=0;g=0;do{h=d+8|0;f=((a[9633600+d|0]&1)<<h|f&65535|(a[9631448+d|0]&1)<<d)&65535;g=((a[9634576+d|0]&1)<<d|g&65535|(a[9634568+d|0]&1)<<h)&65535;d=d+1|0;}while((d|0)<8);b[4812884]=f;b[4812885]=g;g=c[2392]|0;if((g|0)>=0){gGz(8452240,0,((g|0)>0?(g<<2)+4|0:4)|0)}c[2113054]=0;g=c[2385548]|0;if((g|0)>0){gGz(9752472,0,((g|0)>1?g<<2:4)|0)}c[2433530]=0;if((c[2394]|0)==0){i=0}else{c[2394]=0;c[2112932]=c[3532596];g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}g=c[2113060]|0;c[2113054]=g;i=g}g=c[2438]|0;if((c[2427028]|0)!=(g|0)){f=gGU(g,(g|0)<0|0?-1:0,16e6,0)|0;d=K;h=gGS(f,d,15180,0)|0;c[2440536]=h;a[6518032]=1;h=gGS(f,d,4e6,0)|0;c[2113058]=h;c[2427028]=g}g=c[2440536]|0;h=(g*448|0|0)/527|0;b[4813580]=1;d=c[2439330]|0;if((d|0)!=0){f=d;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;f=c[2438118]|0;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;d=c[2444092]|0;c[2113054]=i+d;c[2433530]=f+(c[2444093]|0);f=1;i=d;d=g;g=0;while(1){j=(ag(d,f)|0)/16|0;if(g|(j|0)<(h|0)){k=i}else{do{if((i|0)<(h|0)){c[2438192]=h-i;l=(gj[c[3531230]&4095](0)|0)==0;m=c[2438192]|0;if(l){c[2113056]=m;l=RG(m)|0;c[2113054]=(c[2113054]|0)+l;c[2276108]=-1;c[2113056]=-1;c[2444092]=(c[2444092]|0)+l;break}else{c[2113054]=(c[2113054]|0)+m;c[2444092]=(c[2444092]|0)+m;break}}}while(0);if((c[2112968]|0)!=0){if((a[14130648]|0)!=0){m=c[3532666]|0;l=c[2439416]|0;n=c[3532664]|0;o=0;do{p=b[m+(o<<1)>>1]|0;b[l+(o<<1)>>1]=p;q=p&65535;p=q>>>2&248;c[n+(o<<2)>>2]=q>>>7<<8&63488|q&31|(p>>>5|p)<<3&2016;o=o+1|0;}while((o|0)<4096);a[14130648]=0}dV9()}o=c[2409622]^1;c[2409622]=o;n=(c[2440428]|0)+(o<<10<<5)|0;c[2443762]=n;l=o<<2;o=9756896+(l<<2)|0;c[2440466]=o;m=9761824+(l<<2)|0;c[2443894]=m;c[o>>2]=65536;o=l|1;c[9756896+(o<<2)>>2]=65536;p=l|2;c[9756896+(p<<2)>>2]=65536;q=l|3;c[9756896+(q<<2)>>2]=65536;c[m>>2]=-1;c[9761824+(o<<2)>>2]=-1;c[9761824+(p<<2)>>2]=-1;c[9761824+(q<<2)>>2]=-1;q=c[3532658]|0;L33280:do{if((b[q+8190>>1]&1)==0){p=b[q+6144>>1]|0;if(p<<16>>16==-1){break}o=q;m=0;r=3072;s=n;t=p;while(1){do{if((t&65535)>767){u=m;v=s}else{p=(t&65535)<<2;w=o+(p<<1)|0;x=o+((p|1)<<1)|0;y=e[x>>1]|0;z=y&511;A=e[w>>1]|0;B=A&511;C=(y>>>9&7)+1|0;D=(A>>>9&7)+1|0;if(z>>>0>319){E=y|-512;if(((C<<4)+E|0)<0){u=m;v=s;break}else{F=E}}else{F=z}if(B>>>0>223){z=A|-512;if(((D<<4)+z|0)<0){u=m;v=s;break}else{G=z}}else{G=B}B=b[o+((p|2)<<1)>>1]|0;z=B&65535;A=z>>>6&3^3;E=l|A;y=9761824+(E<<2)|0;if((c[y>>2]|0)==-1){c[9756896+(E<<2)>>2]=m}c[y>>2]=m;a[s+1|0]=1<<A&255;c[s+20>>2]=(e[x>>1]|0)>>>12;c[s+24>>2]=(e[w>>1]|0)>>>12;c[s+12>>2]=C;c[s+16>>2]=D;c[s+4>>2]=F;c[s+8>>2]=G;a[s|0]=(B&65535)>>>14&255;b[s+2>>1]=(B&65535)>>>4&496;c[s+28>>2]=e[o+((p|3)<<1)>>1]|z<<16&65536;u=m+1|0;v=s+32|0}}while(0);z=r+1|0;if((z|0)>=4095){break L33280}p=b[o+(z<<1)>>1]|0;if(p<<16>>16==-1){break}else{m=u;r=z;s=v;t=p}}}}while(0);c[8452200+(c[2394]<<2)>>2]=8193;c[2276080]=256;if((c[2276079]|0)>>>0<256){RH(1)}b[4813580]=0;k=c[2444092]|0}c[2438192]=j-k;l=(gj[c[3531230]&4095](0)|0)==0;n=c[2438192]|0;if(l){c[2113056]=n;l=RG(n)|0;c[2113054]=(c[2113054]|0)+l;c[2276108]=-1;c[2113056]=-1;H=(c[2444092]|0)+l|0}else{c[2113054]=(c[2113054]|0)+n;H=(c[2444092]|0)+n|0}c[2444092]=H;n=f+1|0;if((n|0)>=17){break}f=n;i=H;d=c[2440536]|0;g=(b[4813580]|0)==0}g=c[3532668]|0;do{if((g|0)==0|(g|0)==1){d=a[6518032]|0?67456:0;H=gGU(d,0,2048e6,0)|0;i=c[2438228]|0;f=gGS(H,K,i,(i|0)<0|0?-1:0)|0;i=f;Sb(d);d=c[2443830]|0;if((d|0)<1073676288){c[2443830]=d-i}d=c[2443831]|0;if((d|0)<1073676288){c[2443831]=d-i}d=(c[3528512]|0)-i|0;c[3528512]=(d|0)<0?0:d;d=c[2112964]|0;if((d|0)==0){break}gg[c[3542118]&4095](d,a[9688]|0?534:0)}else if((g|0)==2|(g|0)==3){d=a[6518032]|0?67456:0;i=gGU(d,0,2048e6,0)|0;f=c[2438228]|0;H=gGS(i,K,f,(f|0)<0|0?-1:0)|0;f=H;Sb(d);d=c[2443830]|0;if((d|0)<1073676288){c[2443830]=d-f}d=c[2443831]|0;if((d|0)<1073676288){c[2443831]=d-f}d=(c[3528512]|0)-f|0;c[3528512]=(d|0)<0?0:d;if((c[2112964]|0)==0){break}Vy(a[9688]|0?534:0)}else{c[2433530]=(a[6518032]|0?67456:0)-(c[2426530]|0)+(c[2076596]|0)}}while(0);g=c[2113054]|0;c[2444092]=(c[2113056]|0)+g-(c[2276108]|0)-(c[2440536]|0);d=c[2433530]|0;f=c[2076596]|0;c[2444093]=(c[2426530]|0)+d-f+(a[6518032]|0?-67456:0);H=c[1836236]|0;i=c[9757320+(H<<2)>>2]|0;if((i|0)!=0){k=i;gGC(k|0,9706056,76)|0}c[9752472+(H<<2)>>2]=d;c[14113936+(H<<2)>>2]=f;c[9669104+(H<<2)>>2]=c[3541536];c[1836236]=-1;H=c[2394]|0;f=c[14130368+(H<<2)>>2]|0;if((f|0)==0){I=8452240+(H<<2)|0;c[I>>2]=g;c[2394]=-1;return 0}gGC(f|0,9104152,280)|0;I=8452240+(H<<2)|0;c[I>>2]=g;c[2394]=-1;return 0}function dVr(){var d=0,e=0,f=0,g=0,h=0,i=0;if((a[14130648]|0)==0){dV9();return 0}d=c[3532666]|0;e=c[2439416]|0;f=c[3532664]|0;g=0;do{h=b[d+(g<<1)>>1]|0;b[e+(g<<1)>>1]=h;i=h&65535;h=i>>>2&248;c[f+(g<<2)>>2]=i>>>7<<8&63488|i&31|(h>>>5|h)<<3&2016;g=g+1|0;}while((g|0)<4096);a[14130648]=0;dV9();return 0}function dVs(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;g=i;i=i+288|0;h=g|0;j=g+16|0;k=g+32|0;l=g+48|0;m=g+64|0;n=g+80|0;o=g+96|0;p=g+112|0;q=g+128|0;r=g+144|0;s=g+160|0;t=g+176|0;u=g+192|0;v=g+208|0;w=g+224|0;x=g+240|0;y=g+256|0;z=g+272|0;A=(f|0)==0;if(!A){c[f>>2]=169249}if((e&4|0)!=0){B=z|0;c[B>>2]=c[2442966];C=z+4|0;c[C>>2]=1048576;D=z+8|0;c[D>>2]=0;E=z+12|0;c[E>>2]=496208;F=c[2076592]|0;gj[F&4095](z)|0;c[B>>2]=c[2442962];c[C>>2]=131072;c[D>>2]=0;c[E>>2]=501160;E=c[2076592]|0;gj[E&4095](z)|0}if((e&32|0)!=0){E=z|0;c[E>>2]=c[2442968];D=z+4|0;c[D>>2]=131072;C=z+8|0;c[C>>2]=0;B=z+12|0;c[B>>2]=484192;F=c[2076592]|0;gj[F&4095](z)|0;c[E>>2]=c[2442964];c[D>>2]=(c[3532668]|0)==0?2048:512;c[C>>2]=0;c[B>>2]=498600;F=c[2076592]|0;gj[F&4095](z)|0;c[E>>2]=c[3532652];c[D>>2]=8192;c[C>>2]=0;c[B>>2]=497240;F=c[2076592]|0;gj[F&4095](z)|0;c[E>>2]=c[3532653];c[D>>2]=8192;c[C>>2]=0;c[B>>2]=495616;F=c[2076592]|0;gj[F&4095](z)|0;c[E>>2]=c[3532654];c[D>>2]=16384;c[C>>2]=0;c[B>>2]=494144;F=c[2076592]|0;gj[F&4095](z)|0;c[E>>2]=c[3532658];c[D>>2]=8192;c[C>>2]=0;c[B>>2]=492944;F=c[2076592]|0;gj[F&4095](z)|0;c[E>>2]=c[3532666];c[D>>2]=8192;c[C>>2]=0;c[B>>2]=426800;B=c[2076592]|0;gj[B&4095](z)|0}if((e&64|0)==0){i=g;return 0}z=k|0;gGz(j|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){B=k+9|0;k=h;C=h|0;D=h+4|0;E=h+12|0;F=j|0;G=j+4|0;H=j+12|0;I=0;do{gGC(z|0,614896,11)|0;a[B]=I+48&255;J=8452256+(I<<2)|0;gGz(k|0,0,12);c[C>>2]=J;c[D>>2]=4;c[E>>2]=164976;gj[c[2076592]&4095](h)|0;if((c[J>>2]|0)!=0){c[F>>2]=c[14130368+(I<<2)>>2];c[G>>2]=c[8452184+(I<<2)>>2];c[H>>2]=z;J=c[2076592]|0;gj[J&4095](j)|0}I=I+1|0;}while((I|0)<=(c[2392]|0))}fw$(e);gGz(y|0,0,12);c[y>>2]=9776368;c[y+4>>2]=8;c[y+12>>2]=212472;gj[c[2076592]&4095](y)|0;gGz(x|0,0,12);c[x>>2]=9627160;c[x+4>>2]=2;c[x+12>>2]=490464;gj[c[2076592]&4095](x)|0;T0(e,f);gGz(w|0,0,12);c[w>>2]=9775464;c[w+4>>2]=4;c[w+12>>2]=495376;gj[c[2076592]&4095](w)|0;gGz(v|0,0,12);c[v>>2]=9752576;c[v+4>>2]=4;c[v+12>>2]=488448;gj[c[2076592]&4095](v)|0;gGz(u|0,0,12);c[u>>2]=9752584;c[u+4>>2]=4;c[u+12>>2]=487072;gj[c[2076592]&4095](u)|0;if(!A){c[f>>2]=133528}gGz(t|0,0,12);c[t>>2]=9718344;c[t+4>>2]=1;c[t+12>>2]=485384;gj[c[2076592]&4095](t)|0;gGz(s|0,0,12);c[s>>2]=9731144;c[s+4>>2]=1;c[s+12>>2]=483824;gj[c[2076592]&4095](s)|0;gGz(r|0,0,12);c[r>>2]=9731136;c[r+4>>2]=1;c[r+12>>2]=482072;gj[c[2076592]&4095](r)|0;gGz(q|0,0,12);c[q>>2]=9721e3;c[q+4>>2]=1;c[q+12>>2]=480336;gj[c[2076592]&4095](q)|0;gGz(p|0,0,12);c[p>>2]=9733984;c[p+4>>2]=1;c[p+12>>2]=479304;gj[c[2076592]&4095](p)|0;gGz(o|0,0,12);c[o>>2]=9719352;c[o+4>>2]=1;c[o+12>>2]=478496;gj[c[2076592]&4095](o)|0;gGz(n|0,0,12);c[n>>2]=9752264;c[n+4>>2]=1;c[n+12>>2]=477552;gj[c[2076592]&4095](n)|0;gGz(m|0,0,12);c[m>>2]=9721008;c[m+4>>2]=1;c[m+12>>2]=476416;gj[c[2076592]&4095](m)|0;gGz(l|0,0,12);c[l>>2]=9733992;c[l+4>>2]=1;c[l+12>>2]=475280;gj[c[2076592]&4095](l)|0;if((e&2|0)==0){i=g;return 0}e=d[9733992]|0;c[2438585]=e>>>6<<13;c[2438584]=e>>>4<<13&24576;e=c[2438146]|0;c[2438146]=-1;l=c[3532668]|0;if((l|0)==0){m=c[2439330]|0;n=(m|0)==0;if(!n){o=m;gGC(9706056,o|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];o=c[3528484]|0;c[2076596]=o;p=c[2417276]|0;c[3541536]=p;c[1836236]=0;q=e&3;r=c[2442962]|0;s=(q<<15)-32768|0;t=128;f=128;while(1){c[m+76+(f<<2)>>2]=r+(s+(f<<8));A=t+1&65535;if((A&65535)>255){K=128;L=128;break}else{t=A;f=A&65535}}while(1){f=r+(s+(L<<8))|0;c[m+76+(L+512<<2)>>2]=f;c[m+76+(L+768<<2)>>2]=f;f=K+1&65535;if((f&65535)>255){break}else{K=f;L=f&65535}}c[2438146]=q;if(!n){n=m;gGC(n|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=o;c[2417276]=p;c[1836236]=-1}else if((l|0)==1|(l|0)==2|(l|0)==3){l=c[2439330]|0;p=(l|0)==0;if(!p){o=l;gGC(9706056,o|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];o=c[3528484]|0;c[2076596]=o;n=c[2417276]|0;c[3541536]=n;c[1836236]=0;m=e&3;e=c[2442962]|0;q=(m<<15|512)-33280|0;L=130;K=130;while(1){c[l+76+(K<<2)>>2]=e+(q+(K<<8));s=L+1&65535;if((s&65535)>255){M=130;N=130;break}else{L=s;K=s&65535}}while(1){K=e+(q+(N<<8))|0;c[l+76+(N+512<<2)>>2]=K;c[l+76+(N+768<<2)>>2]=K;K=M+1&65535;if((K&65535)>255){break}else{M=K;N=K&65535}}c[2438146]=m;if(!p){p=l;gGC(p|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=o;c[2417276]=n;c[1836236]=-1}a[14130648]=1;i=g;return 0}function dVt(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4389212+(b*112|0)>>2];c[a+104>>2]=c[4389216+(b*112|0)>>2];c[a+108>>2]=c[4389220+(b*112|0)>>2];d=0;return d|0}function dVu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=4389112+(b*112|0);e=0;return e|0}function dVv(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=63){if((a|0)==0){d=0;return d|0}e=a;f=2337512+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}if((b|0)!=64){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;c[b>>2]=c[915114];c[b+4>>2]=c[915115];c[b+8>>2]=c[915116];d=0;return d|0}function dVw(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4683452+(b*112|0)>>2];c[a+104>>2]=c[4683456+(b*112|0)>>2];c[a+108>>2]=c[4683460+(b*112|0)>>2];d=0;return d|0}function dVx(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=4683352+(b*112|0);e=0;return e|0}function dVy(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=63){if((a|0)==0){d=0;return d|0}e=a;f=4684808+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}f=b-64|0;if(f>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;a=715344+(f*12|0)|0;c[b>>2]=c[a>>2];c[b+4>>2]=c[a+4>>2];c[b+8>>2]=c[a+8>>2];d=0;return d|0}function dVz(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2810228+(b*112|0)>>2];c[a+104>>2]=c[2810232+(b*112|0)>>2];c[a+108>>2]=c[2810236+(b*112|0)>>2];d=0;return d|0}function dVA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=2810128+(b*112|0);e=0;return e|0}function dVB(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=63){if((a|0)==0){d=0;return d|0}e=a;f=4684808+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}if((b|0)!=64){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;c[b>>2]=c[915114];c[b+4>>2]=c[915115];c[b+8>>2]=c[915116];d=0;return d|0}function dVC(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2808996+(b*112|0)>>2];c[a+104>>2]=c[2809e3+(b*112|0)>>2];c[a+108>>2]=c[2809004+(b*112|0)>>2];d=0;return d|0}function dVD(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=2808896+(b*112|0);e=0;return e|0}function dVE(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3044124+(b*112|0)>>2];c[a+104>>2]=c[3044128+(b*112|0)>>2];c[a+108>>2]=c[3044132+(b*112|0)>>2];d=0;return d|0}function dVF(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=3044024+(b*112|0);e=0;return e|0}function dVG(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>30){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1115744+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dVH(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>72){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3045480+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dVI(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4436876+(b*112|0)>>2];c[a+104>>2]=c[4436880+(b*112|0)>>2];c[a+108>>2]=c[4436884+(b*112|0)>>2];d=0;return d|0}function dVJ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=4436776+(b*112|0);e=0;return e|0}function dVK(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=47){if((a|0)==0){d=0;return d|0}e=a;f=6487392+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}if((b|0)!=48){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;c[b>>2]=c[915114];c[b+4>>2]=c[915115];c[b+8>>2]=c[915116];d=0;return d|0}function dVL(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6486260+(b*112|0)>>2];c[a+104>>2]=c[6486264+(b*112|0)>>2];c[a+108>>2]=c[6486268+(b*112|0)>>2];d=0;return d|0}function dVM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=6486160+(b*112|0);e=0;return e|0}function dVN(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=47){if((a|0)==0){d=0;return d|0}e=a;f=6487392+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}f=b-48|0;if(f>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;a=715344+(f*12|0)|0;c[b>>2]=c[a>>2];c[b+4>>2]=c[a+4>>2];c[b+8>>2]=c[a+8>>2];d=0;return d|0}function dVO(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5693396+(b*112|0)>>2];c[a+104>>2]=c[5693400+(b*112|0)>>2];c[a+108>>2]=c[5693404+(b*112|0)>>2];d=0;return d|0}function dVP(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=5693296+(b*112|0);e=0;return e|0}function dVQ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5692164+(b*112|0)>>2];c[a+104>>2]=c[5692168+(b*112|0)>>2];c[a+108>>2]=c[5692172+(b*112|0)>>2];d=0;return d|0}function dVR(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=5692064+(b*112|0);e=0;return e|0}function dVS(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5694628+(b*112|0)>>2];c[a+104>>2]=c[5694632+(b*112|0)>>2];c[a+108>>2]=c[5694636+(b*112|0)>>2];d=0;return d|0}function dVT(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=5694528+(b*112|0);e=0;return e|0}function dVU(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=47){if((a|0)==0){d=0;return d|0}e=a;f=6487392+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}f=b-48|0;if(f>>>0>3){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;a=728768+(f*12|0)|0;c[b>>2]=c[a>>2];c[b+4>>2]=c[a+4>>2];c[b+8>>2]=c[a+8>>2];d=0;return d|0}function dVV(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5657756+(b*112|0)>>2];c[a+104>>2]=c[5657760+(b*112|0)>>2];c[a+108>>2]=c[5657764+(b*112|0)>>2];d=0;return d|0}function dVW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=5657656+(b*112|0);e=0;return e|0}function dVX(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=61){if((a|0)==0){d=0;return d|0}e=a;f=5658888+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}f=b-62|0;if(f>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;a=728288+(f*12|0)|0;c[b>>2]=c[a>>2];c[b+4>>2]=c[a+4>>2];c[b+8>>2]=c[a+8>>2];d=0;return d|0}function dVY(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4367148+(b*112|0)>>2];c[a+104>>2]=c[4367152+(b*112|0)>>2];c[a+108>>2]=c[4367156+(b*112|0)>>2];d=0;return d|0}function dVZ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=4367048+(b*112|0);e=0;return e|0}function dV_(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if(b>>>0<=61){if((a|0)==0){d=0;return d|0}e=a;f=5658888+(b*12|0)|0;c[e>>2]=c[f>>2];c[e+4>>2]=c[f+4>>2];c[e+8>>2]=c[f+8>>2];d=0;return d|0}f=b-62|0;if(f>>>0>3){d=1;return d|0}if((a|0)==0){d=0;return d|0}b=a;a=704736+(f*12|0)|0;c[b>>2]=c[a>>2];c[b+4>>2]=c[a+4>>2];c[b+8>>2]=c[a+8>>2];d=0;return d|0}function dV$(){var a=0,d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];a=c[3532592]|0;if((a|0)!=0){gGC(9104152,a|0,280)|0}c[2113054]=c[2113060]}RI();a=c[2394]|0;d=c[14130368+(a<<2)>>2]|0;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[8452240+(a<<2)>>2]=c[2113054];c[2394]=-1;a=c[2439330]|0;d=(a|0)==0;if(!d){e=a;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];e=c[3528484]|0;c[2076596]=e;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;c[2438146]=-1;g=c[3532668]|0;if((g|0)==0){i=c[2442962]|0;j=128;k=128;while(1){c[a+76+(k<<2)>>2]=i+((k<<8)-32768);l=j+1&65535;if((l&65535)>255){m=128;n=128;break}else{j=l;k=l&65535}}while(1){k=i+((n<<8)-32768)|0;c[a+76+(n+512<<2)>>2]=k;c[a+76+(n+768<<2)>>2]=k;k=m+1&65535;if((k&65535)>255){break}else{m=k;n=k&65535}}c[2438146]=0}else if((g|0)==1|(g|0)==2|(g|0)==3){n=c[2442962]|0;m=130;i=130;while(1){c[a+76+(i<<2)>>2]=n+((i<<8)-32768);k=m+1&65535;if((k&65535)>255){o=130;p=130;break}else{m=k;i=k&65535}}while(1){i=n+((p<<8)-32768)|0;c[a+76+(p+512<<2)>>2]=i;c[a+76+(p+768<<2)>>2]=i;i=o+1&65535;if((i&65535)>255){break}else{o=i;p=i&65535}}c[2438146]=0}gGz(9706056,0,76);if(!d){d=a;gGC(d|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=e;c[2417276]=f;c[1836236]=-1;if((g|0)==2|(g|0)==3){c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;c[2443866]=0;c[2438144]=1;c[2444093]=0;c[2444092]=0;return}else if((g|0)==0|(g|0)==1){c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;l6(0);c[2443866]=0;c[2438144]=1;c[2444093]=0;c[2444092]=0;return}else{c[2443866]=0;c[2438144]=1;c[2444093]=0;c[2444092]=0;return}}function dV0(a){a=a|0;return 0}function dV1(a){a=a|0;return 0}function dV2(a){a=a|0;return 0}function dV3(a){a=a|0;return 0}function dV4(a){a=a|0;return 0}function dV5(a){a=a|0;return 0}function dV6(b,c){b=b|0;c=c|0;a[9706117]=(c|0)!=0|0;return}function dV7(a){a=a|0;var b=0,d=0;b=(c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,4e6,0)|0;return a|0}function dV8(){return+(+((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)/4.0e6)}function dV9(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0;f=c[3532654]|0;g=b[f+1042>>1]|0;c[2430848]=g;c[2430076]=b[f+1030>>1]|0;c[2430074]=b[f+1026>>1]|0;h=b[f+1046>>1]|0;c[2430849]=h;c[2430077]=b[f+1038>>1]|0;c[2430075]=b[f+1034>>1]|0;if((c[3532668]|0)==1){c[2438584]=g<<3&8192;c[2438585]=h<<3&8192}do{if(a[64272]|0){i=25545}else{if((g&1|0)==0){j=0;k=1;l=g;break}if((h&2|0)==0){j=0;k=1;l=g}else{i=25545}}}while(0);do{if((i|0)==25545){h=c[642608+(c[2436]<<2)>>2]|0;if((c[h+52>>2]&4|0)==0){f=c[h+132>>2]|0;m=ag(c[2113308]|0,c[h+128>>2]|0)|0;if((f|0)<=0){j=0;k=1;l=g;break}n=c[2113300]|0;o=c[2112968]|0;p=0;while(1){gGz(o|0,0,m|0);q=p+1|0;if((q|0)<(f|0)){o=o+n|0;p=q}else{j=0;k=1;l=g;break}}}else{p=c[h+128>>2]|0;n=ag(c[2113308]|0,c[h+132>>2]|0)|0;if((p|0)<=0){j=0;k=1;l=g;break}o=c[2113300]|0;f=c[2112968]|0;m=0;while(1){gGz(f|0,0,n|0);q=m+1|0;if((q|0)<(p|0)){f=f+o|0;m=q}else{j=0;k=1;l=g;break}}}}}while(0);while(1){g=k-1|0;i=9723392+(g<<2)|0;m=(k|0)==3;if((l&1|0)==0|m){if((j|0)==0){c[2415164]=-1;c[3528498]=-1;c[2384522]=9999;c[2384520]=9999;c[2384524]=-1;c[2384526]=-1;o=c[2409622]^1;c[2443762]=(c[2440428]|0)+(o<<10<<5);f=o<<2;c[2440466]=9756896+(f<<2);c[2443894]=9761824+(f<<2)}do{if((k|0)<3){f=k+1|0;if((f|0)>=4){r=65536;break}o=c[2440466]|0;p=65536;n=f;while(1){f=c[o+(n<<2)>>2]|0;h=(p|0)>(f|0)?f:p;f=n+1|0;if((f|0)<4){p=h;n=f}else{r=h;break}}}else{r=65536}}while(0);n=e[(c[3532658]|0)+8190>>1]<<4&64;p=(n|0)!=0?0:15;do{if((j|0)<=(k|0)){o=c[2440466]|0;h=c[2443894]|0;f=0;q=-1;s=65536;t=j;do{u=c[o+(t<<2)>>2]|0;s=(s|0)>(u|0)?u:s;u=c[h+(t<<2)>>2]|0;q=(q|0)<(u|0)?u:q;f=f|1<<t;t=t+1|0;}while((t|0)<=(k|0));t=f&255;if((t|0)==0){break}if((s|0)<=(q|0)){h=n;o=0;u=(c[2443762]|0)+(s<<5)|0;v=s;while(1){L33775:do{if((d[u+1|0]&t|0)==0){w=o;x=h}else{y=u+4|0;z=c[y>>2]|0;c[2385468]=z;A=c[u+8>>2]|0;c[2385456]=A;c[2440386]=(c[3532664]|0)+(b[u+2>>1]<<2);B=c[u+12>>2]|0;c[2409616]=B;C=c[u+16>>2]|0;c[2409612]=C;D=a[u|0]|0;E=D<<3|h&64;F=c[u+28>>2]|0;if((D|0)==1){G=B<<1;H=-1;I=F+~B|0}else if((D|0)==2){G=-B<<1;H=1;I=(ag(C+1|0,B)|0)+F|0}else if((D|0)==3){G=0;H=-1;I=(ag(C,B)|0)-1+F|0}else{G=0;H=1;I=F}F=c[u+20>>2]|0;D=c[u+24>>2]|0;if((D|F|0)==0){J=c[2384526]|0;do{if((c[3528498]|0)>(v|0)&(z|0)<(J|0)){if(!(((B<<4)+z|0)>=(c[2384520]|0)&(A|0)<(c[2384524]|0))){K=E;break}K=((C<<4)+A|0)<(c[2384522]|0)?E:E|2}else{K=E}}while(0);do{if((r|0)<(v|0)){L=K|4;if((z|0)<(c[2384520]|0)){c[2384520]=z}if((B+z|0)>(J|0)){c[2384526]=(B<<4)+z}if((A|0)<(c[2384522]|0)){c[2384522]=A}if((C+A|0)<=(c[2384524]|0)){M=L;break}c[2384524]=(C<<4)+A;M=L}else{M=K}}while(0);if((M&6|0)==0){N=o}else{J=(c[2394716]|0)+((A*320|0)+z<<1)|0;c[2415164]=(c[2394730]|0)+v;N=J}if((C|0)<=0){w=N;x=M;break}J=c[2113300]|0;L=ag(c[2113308]|0,z)|0;O=(ag(J,A)|0)+L|0;L=6811456+(M+1<<2)|0;P=6811456+(M<<2)|0;Q=(c[2112968]|0)+O|0;O=N;R=I;S=1;T=B;U=A;V=J;J=C;W=z;while(1){c[2385468]=W;c[2415150]=Q;c[2409606]=O;X=R+G|0;if((T|0)>0){Y=X;Z=1;_=W;while(1){$=e[(c[3532660]|0)+(Y<<1)>>1]|0;do{if((a[(c[2430072]|0)+$|0]|0)!=(p|0)){c[2385338]=(c[3532656]|0)+(c[2429854]&$<<8);aa=c[2385456]|0;if(!(aa>>>0>208|(_|0)<0|(_|0)>304)){gu[c[P>>2]&16383]();break}if(!((aa+15|0)>>>0<239&(_|0)>-16&(_|0)<320)){break}gu[c[L>>2]&16383]()}}while(0);$=(c[2385468]|0)+16|0;c[2385468]=$;ab=Y+H|0;c[2415150]=(c[2415150]|0)+(c[2113308]<<4);c[2409606]=(c[2409606]|0)+32;ac=c[2409616]|0;if((Z|0)>=(ac|0)){break}Y=ab;Z=Z+1|0;_=$}ad=ab;ae=ac;af=c[2385456]|0;ah=c[2113300]|0;ai=c[2409612]|0}else{ad=X;ae=T;af=U;ah=V;ai=J}_=af+16|0;c[2385456]=_;Z=O+10240|0;if((S|0)>=(ai|0)){w=Z;x=M;break L33775}Q=Q+(ah<<4)|0;O=Z;R=ad;S=S+1|0;T=ae;U=_;V=ah;J=ai;W=c[y>>2]|0}}y=((ag(F,B)|0)+3>>2)+z|0;c[2385468]=y;W=((ag(D,C)|0)+3>>2)+A|0;c[2385456]=W;J=32-F|0;V=32-D|0;U=c[2384526]|0;do{if((c[3528498]|0)>(v|0)&(y|0)<(U|0)){T=((ag(J,B)|0)/2|0)+y|0;if(!((T|0)>=(c[2384520]|0)&(W|0)<(c[2384524]|0))){aj=E;break}T=((ag(J,C)|0)/2|0)+W|0;aj=(T|0)<(c[2384522]|0)?E:E|2}else{aj=E}}while(0);do{if((r|0)<(v|0)){E=aj|4;if((y|0)<(c[2384520]|0)){c[2384520]=y}if((y+B|0)>(U|0)){c[2384526]=((ag(J,B)|0)/2|0)+y}if((W|0)<(c[2384522]|0)){c[2384522]=W}if((W+C|0)<=(c[2384524]|0)){ak=E;break}c[2384524]=((ag(V,C)|0)/2|0)+W;ak=E}else{ak=aj}}while(0);if((ak&6|0)==0){al=o}else{U=(c[2394716]|0)+((W*320|0)+y<<1)|0;c[2415164]=(c[2394730]|0)+v;al=U}if((C|0)<=0){w=al;x=ak;break}U=c[2113300]|0;E=ag(c[2113308]|0,y)|0;D=(ag(U,W)|0)+E|0;E=6811456+(ak+33<<2)|0;F=6811456+(ak+32<<2)|0;A=(c[2112968]|0)+D|0;D=al;z=I;T=0;S=B;R=W;O=U;U=C;while(1){c[2385468]=y;c[2415150]=A;c[2409606]=D;Q=z+G|0;L=T+1|0;P=(ag(L,V)|0)/2|0;_=P-((ag(T,V)|0)/2|0)|0;c[3528502]=_;c[3528422]=(c[2433340]|0)+(_<<4<<2);if((S|0)>0){P=Q;Z=0;Y=y;while(1){$=Z+1|0;aa=(ag($,J)|0)/2|0;am=aa-((ag(Z,J)|0)/2|0)|0;c[3528504]=am;aa=e[(c[3532660]|0)+(P<<1)>>1]|0;L33848:do{if((a[(c[2430072]|0)+aa|0]|0)!=(p|0)){c[3528424]=(c[2433342]|0)+(am<<4<<2);c[2385338]=(c[3532656]|0)+(aa<<8&c[2429854]);an=c[2385456]|0;ao=c[3528502]|0;do{if((an|0)>=0){if((an|0)>(224-ao|0)|(Y|0)<0){break}if((Y|0)>(320-am|0)){break}gu[c[F>>2]&16383]();break L33848}}while(0);if(!((an|0)>(-ao|0)&(an|0)<224)){break}if(!((Y|0)>(-am|0)&(Y|0)<320)){break}gu[c[E>>2]&16383]()}}while(0);am=c[3528504]|0;aa=(c[2385468]|0)+am|0;c[2385468]=aa;ap=P+H|0;aq=ag(c[2113308]|0,am)|0;c[2415150]=(c[2415150]|0)+aq;c[2409606]=(c[2409606]|0)+(am<<1);ar=c[2409616]|0;if(($|0)<(ar|0)){P=ap;Z=$;Y=aa}else{break}}as=ap;at=ar;au=c[3528502]|0;av=c[2385456]|0;aw=c[2113300]|0;ax=c[2409612]|0}else{as=Q;at=S;au=_;av=R;aw=O;ax=U}Y=au+av|0;c[2385456]=Y;Z=D+((au*320|0)<<1)|0;if((L|0)>=(ax|0)){w=Z;x=ak;break L33775}A=A+(ag(au,aw)|0)|0;D=Z;z=as;T=L;S=at;R=Y;O=aw;U=ax}}}while(0);U=v+1|0;if((U|0)>(q|0)){break}else{h=x;o=w;u=u+32|0;v=U}}}v=c[3528498]|0;if((q|0)>(v|0)){c[3528498]=q;ay=q}else{ay=v}if(!(m&(c[2415164]|0)>-1)){break}v=(c[2394730]|0)+ay|0;c[2394730]=v;if((v|0)<=64512){break}gGz(c[2394716]|0,0,143360);c[2394730]=0}}while(0);az=k+1|0}else{az=j}do{if((g|0)<2){m=c[i>>2]|0;if((m&1|0)!=0){break}if((c[9723392+(k<<2)>>2]&2|0)!=0){break}if((4<<g&255|0)==0){break}p=c[14130608+(g<<2)>>2]|0;n=c[3532664]|0;v=(g|0)!=0;u=v?3072:2048;o=c[9754336+(g<<2)>>2]|0;h=c[598280+((m>>>6&3)<<2)>>2]|0;c[2440376]=(c[3532654]|0)+(g<<9);c[2440438]=(h<<4)-1;do{if(a[64272]|v){if((m&2|0)!=0){aA=99;aB=8;break}t=m&8;aA=(t|0)==0?15:0;aB=t>>>1^4}else{aA=99;aB=8}}while(0);m=9720304+(g<<2)|0;v=c[m>>2]|0;q=c[9720296+(g<<2)>>2]|0;t=ag((q>>4)+1|0,h)|0;s=16-(q&15)-16|0;c[2385458]=s;if((s|0)>=224){break}q=h-1|0;f=7384520+((aB|1)<<2)|0;U=7384520+(aB<<2)|0;O=7384520+((aB|3)<<2)|0;R=7384520+((aB|2)<<2)|0;S=s;s=(v>>4)+1|0;T=16-(v&15)|0;v=-h|0;while(1){L33882:do{if((S|0)<-15){aC=T;aD=s}else{z=v+t&4095;D=S>>>0>208;A=c[i>>2]|0;if((A&768|0)==0){aE=T;aF=s}else{do{if((A&512|0)==0){E=c[2440376]|0;F=32767;J=-32768;y=0;do{V=b[E+((y+S&255)<<1)>>1]|0;J=(V|0)>(J|0)?V:J;F=(V|0)<(F|0)?V:F;y=y+1|0;}while((y|0)<16);if((F|0)==(J|0)){aG=J;break}y=c[m>>2]|0;E=16-(y&15)|0;L=(y>>4)+1|0;y=(J>>4)+21|0;_=F-16>>4;Q=E+(_<<4)|0;c[2385470]=Q;if((_|0)>=(y|0)){aC=E;aD=L;break L33882}if(D){V=_;C=Q;while(1){W=e[p+((V+L&q)+z<<1)>>1]|0;B=(W&8191)+o|0;if((a[(c[2433344]|0)+B|0]|0)==(aA|0)){aH=C}else{Y=c[2112968]|0;c[2415152]=Y+(ag(c[2113300]|0,c[2385458]|0)|0);c[2385340]=(c[3532650]|0)+(B<<8);c[2440388]=n+((W>>>13<<4|u)<<2);gu[c[O>>2]&16383]();aH=c[2385470]|0}W=V+1|0;B=aH+16|0;c[2385470]=B;if((W|0)<(y|0)){V=W;C=B}else{aC=E;aD=L;break L33882}}}else{C=_;V=Q;while(1){F=e[p+((C+L&q)+z<<1)>>1]|0;J=(F&8191)+o|0;if((a[(c[2433344]|0)+J|0]|0)==(aA|0)){aI=V}else{B=c[2112968]|0;c[2415152]=B+(ag(c[2113300]|0,c[2385458]|0)|0);c[2385340]=(c[3532650]|0)+(J<<8);c[2440388]=n+((F>>>13<<4|u)<<2);gu[c[R>>2]&16383]();aI=c[2385470]|0}F=C+1|0;J=aI+16|0;c[2385470]=J;if((F|0)<(y|0)){C=F;V=J}else{aC=E;aD=L;break L33882}}}}else{aG=b[(c[2440376]|0)+((S>>>4&15)<<1)>>1]|0}}while(0);A=(c[m>>2]|0)+aG|0;aE=16-(A&15)|0;aF=(A>>4)+1|0}A=aE-16|0;c[2385470]=A;if((A|0)>=320){aC=aE;aD=aF;break}if(D){L=A;E=-1;while(1){do{if((L|0)<-15){aJ=L}else{V=e[p+((E+aF&q)+z<<1)>>1]|0;C=(V&8191)+o|0;if((a[(c[2433344]|0)+C|0]|0)==(aA|0)){aJ=L;break}y=c[2112968]|0;Q=ag(c[2113300]|0,c[2385458]|0)|0;c[2415152]=y+((ag(c[2113308]|0,L)|0)+Q);c[2385340]=(c[3532650]|0)+(C<<8);c[2440388]=n+((V>>>13<<4|u)<<2);gu[c[f>>2]&16383]();aJ=c[2385470]|0}}while(0);V=aJ+16|0;c[2385470]=V;if((V|0)<320){L=V;E=E+1|0}else{aC=aE;aD=aF;break L33882}}}else{aK=A;aL=-1}while(1){do{if((aK|0)>=-15){E=e[p+((aL+aF&q)+z<<1)>>1]|0;L=(E&8191)+o|0;if((a[(c[2433344]|0)+L|0]|0)==(aA|0)){break}D=c[2112968]|0;V=ag(c[2113300]|0,c[2385458]|0)|0;c[2415152]=D+((ag(c[2113308]|0,aK)|0)+V);c[2385340]=(c[3532650]|0)+(L<<8);c[2440388]=n+((E>>>13<<4|u)<<2);if(aK>>>0>304){gu[c[f>>2]&16383]();break}else{gu[c[U>>2]&16383]();break}}}while(0);E=(c[2385470]|0)+16|0;c[2385470]=E;if((E|0)<320){aK=E;aL=aL+1|0}else{aC=aE;aD=aF;break}}}}while(0);z=(c[2385458]|0)+16|0;c[2385458]=z;if((z|0)<224){S=z;s=aD;T=aC;v=v+h|0}else{break}}}}while(0);i=k+1|0;if((i|0)>=4){break}g=c[9723392+(k<<2)>>2]|0;j=az;k=i;l=g}return}function dWa(){var d=0,e=0,f=0,g=0,h=0,i=0;d=c[2440388]|0;e=c[2415152]|0;f=0;g=c[2385340]|0;while(1){h=a[g]|0;if(h<<24>>24!=0){b[e>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+1|0]|0;if(h<<24>>24!=0){b[e+2>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+2|0]|0;if(h<<24>>24!=0){b[e+4>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+3|0]|0;if(h<<24>>24!=0){b[e+6>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+4|0]|0;if(h<<24>>24!=0){b[e+8>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+5|0]|0;if(h<<24>>24!=0){b[e+10>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+6|0]|0;if(h<<24>>24!=0){b[e+12>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+7|0]|0;if(h<<24>>24!=0){b[e+14>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+8|0]|0;if(h<<24>>24!=0){b[e+16>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+9|0]|0;if(h<<24>>24!=0){b[e+18>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+10|0]|0;if(h<<24>>24!=0){b[e+20>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+11|0]|0;if(h<<24>>24!=0){b[e+22>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+12|0]|0;if(h<<24>>24!=0){b[e+24>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+13|0]|0;if(h<<24>>24!=0){b[e+26>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+14|0]|0;if(h<<24>>24!=0){b[e+28>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+15|0]|0;if(h<<24>>24!=0){b[e+30>>1]=c[d+((h&255)<<2)>>2]&65535}h=f+1|0;i=g+16|0;if((h|0)<16){e=e+640|0;f=h;g=i}else{break}}c[2385340]=i;return}function dWb(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[2385458]|0;e=c[2385470]|0;f=e>>>0<320;g=c[2440388]|0;h=c[2415152]|0;i=0;L33981:while(1){j=d+i|0;do{if((j|0)>=0){if((j|0)>223){k=25764;break L33981}do{if(f){l=a[c[2385340]|0]|0;if(l<<24>>24==0){break}b[h>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+1|0)>>>0<320){l=a[(c[2385340]|0)+1|0]|0;if(l<<24>>24==0){break}b[h+2>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+2|0)>>>0<320){l=a[(c[2385340]|0)+2|0]|0;if(l<<24>>24==0){break}b[h+4>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+3|0)>>>0<320){l=a[(c[2385340]|0)+3|0]|0;if(l<<24>>24==0){break}b[h+6>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+4|0)>>>0<320){l=a[(c[2385340]|0)+4|0]|0;if(l<<24>>24==0){break}b[h+8>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+5|0)>>>0<320){l=a[(c[2385340]|0)+5|0]|0;if(l<<24>>24==0){break}b[h+10>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+6|0)>>>0<320){l=a[(c[2385340]|0)+6|0]|0;if(l<<24>>24==0){break}b[h+12>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+7|0)>>>0<320){l=a[(c[2385340]|0)+7|0]|0;if(l<<24>>24==0){break}b[h+14>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+8|0)>>>0<320){l=a[(c[2385340]|0)+8|0]|0;if(l<<24>>24==0){break}b[h+16>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+9|0)>>>0<320){l=a[(c[2385340]|0)+9|0]|0;if(l<<24>>24==0){break}b[h+18>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+10|0)>>>0<320){l=a[(c[2385340]|0)+10|0]|0;if(l<<24>>24==0){break}b[h+20>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+11|0)>>>0<320){l=a[(c[2385340]|0)+11|0]|0;if(l<<24>>24==0){break}b[h+22>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+12|0)>>>0<320){l=a[(c[2385340]|0)+12|0]|0;if(l<<24>>24==0){break}b[h+24>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+13|0)>>>0<320){l=a[(c[2385340]|0)+13|0]|0;if(l<<24>>24==0){break}b[h+26>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+14|0)>>>0<320){l=a[(c[2385340]|0)+14|0]|0;if(l<<24>>24==0){break}b[h+28>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);if((e+15|0)>>>0>=320){break}l=a[(c[2385340]|0)+15|0]|0;if(l<<24>>24==0){break}b[h+30>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);j=i+1|0;c[2385340]=(c[2385340]|0)+16;if((j|0)>=16){k=25765;break}h=h+640|0;i=j}if((k|0)==25764){return}else if((k|0)==25765){return}}function dWc(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=c[2385470]|0;e=c[2385458]|0;f=c[2440376]|0;g=c[2440438]|0;h=~g;i=c[2440388]|0;j=c[2415152]|0;k=0;l=c[2385340]|0;while(1){m=d-(b[f+((e+k&255)<<1)>>1]|0)&g;n=(m|0)>319?m+h|0:m;do{if((n|0)>=-15){do{if(n>>>0<320){m=a[l]|0;if(m<<24>>24==0){break}b[j+(n<<1)>>1]=c[i+((m&255)<<2)>>2]&65535}}while(0);m=n+1|0;do{if(m>>>0<320){o=a[l+1|0]|0;if(o<<24>>24==0){break}b[j+(m<<1)>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);m=n+2|0;do{if(m>>>0<320){o=a[l+2|0]|0;if(o<<24>>24==0){break}b[j+(m<<1)>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);m=n+3|0;do{if(m>>>0<320){o=a[l+3|0]|0;if(o<<24>>24==0){break}b[j+(m<<1)>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);m=n+4|0;do{if(m>>>0<320){o=a[l+4|0]|0;if(o<<24>>24==0){break}b[j+(m<<1)>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);m=n+5|0;do{if(m>>>0<320){o=a[l+5|0]|0;if(o<<24>>24==0){break}b[j+(m<<1)>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);m=n+6|0;do{if(m>>>0<320){o=a[l+6|0]|0;if(o<<24>>24==0){break}b[j+(m<<1)>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);m=n+7|0;do{if(m>>>0<320){o=a[l+7|0]|0;if(o<<24>>24==0){break}b[j+(m<<1)>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);m=n+8|0;do{if(m>>>0<320){o=a[l+8|0]|0;if(o<<24>>24==0){break}b[j+(m<<1)>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);m=n+9|0;do{if(m>>>0<320){o=a[l+9|0]|0;if(o<<24>>24==0){break}b[j+(m<<1)>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);m=n+10|0;do{if(m>>>0<320){o=a[l+10|0]|0;if(o<<24>>24==0){break}b[j+(m<<1)>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);m=n+11|0;do{if(m>>>0<320){o=a[l+11|0]|0;if(o<<24>>24==0){break}b[j+(m<<1)>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);m=n+12|0;do{if(m>>>0<320){o=a[l+12|0]|0;if(o<<24>>24==0){break}b[j+(m<<1)>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);m=n+13|0;do{if(m>>>0<320){o=a[l+13|0]|0;if(o<<24>>24==0){break}b[j+(m<<1)>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);m=n+14|0;do{if(m>>>0<320){o=a[l+14|0]|0;if(o<<24>>24==0){break}b[j+(m<<1)>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);m=n+15|0;if(m>>>0>=320){break}o=a[l+15|0]|0;if(o<<24>>24==0){break}b[j+(m<<1)>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);n=k+1|0;p=l+16|0;if((n|0)>=16){break}j=j+640|0;k=n;l=p}c[2385340]=p;return}function dWd(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=c[2385458]|0;e=c[2385470]|0;f=c[2440376]|0;g=c[2440438]|0;h=~g;i=c[2440388]|0;j=c[2415152]|0;k=0;L34124:while(1){l=d+k|0;do{if((l|0)>=0){if((l|0)>223){m=25874;break L34124}n=e-(b[f+((l&255)<<1)>>1]|0)&g;o=(n|0)>319?n+h|0:n;if((o|0)<-15){break}do{if(o>>>0<320){n=a[c[2385340]|0]|0;if(n<<24>>24==0){break}b[j+(o<<1)>>1]=c[i+((n&255)<<2)>>2]&65535}}while(0);n=o+1|0;do{if(n>>>0<320){p=a[(c[2385340]|0)+1|0]|0;if(p<<24>>24==0){break}b[j+(n<<1)>>1]=c[i+((p&255)<<2)>>2]&65535}}while(0);n=o+2|0;do{if(n>>>0<320){p=a[(c[2385340]|0)+2|0]|0;if(p<<24>>24==0){break}b[j+(n<<1)>>1]=c[i+((p&255)<<2)>>2]&65535}}while(0);n=o+3|0;do{if(n>>>0<320){p=a[(c[2385340]|0)+3|0]|0;if(p<<24>>24==0){break}b[j+(n<<1)>>1]=c[i+((p&255)<<2)>>2]&65535}}while(0);n=o+4|0;do{if(n>>>0<320){p=a[(c[2385340]|0)+4|0]|0;if(p<<24>>24==0){break}b[j+(n<<1)>>1]=c[i+((p&255)<<2)>>2]&65535}}while(0);n=o+5|0;do{if(n>>>0<320){p=a[(c[2385340]|0)+5|0]|0;if(p<<24>>24==0){break}b[j+(n<<1)>>1]=c[i+((p&255)<<2)>>2]&65535}}while(0);n=o+6|0;do{if(n>>>0<320){p=a[(c[2385340]|0)+6|0]|0;if(p<<24>>24==0){break}b[j+(n<<1)>>1]=c[i+((p&255)<<2)>>2]&65535}}while(0);n=o+7|0;do{if(n>>>0<320){p=a[(c[2385340]|0)+7|0]|0;if(p<<24>>24==0){break}b[j+(n<<1)>>1]=c[i+((p&255)<<2)>>2]&65535}}while(0);n=o+8|0;do{if(n>>>0<320){p=a[(c[2385340]|0)+8|0]|0;if(p<<24>>24==0){break}b[j+(n<<1)>>1]=c[i+((p&255)<<2)>>2]&65535}}while(0);n=o+9|0;do{if(n>>>0<320){p=a[(c[2385340]|0)+9|0]|0;if(p<<24>>24==0){break}b[j+(n<<1)>>1]=c[i+((p&255)<<2)>>2]&65535}}while(0);n=o+10|0;do{if(n>>>0<320){p=a[(c[2385340]|0)+10|0]|0;if(p<<24>>24==0){break}b[j+(n<<1)>>1]=c[i+((p&255)<<2)>>2]&65535}}while(0);n=o+11|0;do{if(n>>>0<320){p=a[(c[2385340]|0)+11|0]|0;if(p<<24>>24==0){break}b[j+(n<<1)>>1]=c[i+((p&255)<<2)>>2]&65535}}while(0);n=o+12|0;do{if(n>>>0<320){p=a[(c[2385340]|0)+12|0]|0;if(p<<24>>24==0){break}b[j+(n<<1)>>1]=c[i+((p&255)<<2)>>2]&65535}}while(0);n=o+13|0;do{if(n>>>0<320){p=a[(c[2385340]|0)+13|0]|0;if(p<<24>>24==0){break}b[j+(n<<1)>>1]=c[i+((p&255)<<2)>>2]&65535}}while(0);n=o+14|0;do{if(n>>>0<320){p=a[(c[2385340]|0)+14|0]|0;if(p<<24>>24==0){break}b[j+(n<<1)>>1]=c[i+((p&255)<<2)>>2]&65535}}while(0);n=o+15|0;if(n>>>0>=320){break}p=a[(c[2385340]|0)+15|0]|0;if(p<<24>>24==0){break}b[j+(n<<1)>>1]=c[i+((p&255)<<2)>>2]&65535}}while(0);l=k+1|0;c[2385340]=(c[2385340]|0)+16;if((l|0)>=16){m=25875;break}j=j+640|0;k=l}if((m|0)==25874){return}else if((m|0)==25875){return}}function dWe(){var d=0,e=0,f=0,g=0,h=0,i=0;d=c[2440388]|0;e=c[2415152]|0;f=0;g=c[2385340]|0;while(1){h=a[g]|0;if(h<<24>>24!=15){b[e>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+1|0]|0;if(h<<24>>24!=15){b[e+2>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+2|0]|0;if(h<<24>>24!=15){b[e+4>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+3|0]|0;if(h<<24>>24!=15){b[e+6>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+4|0]|0;if(h<<24>>24!=15){b[e+8>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+5|0]|0;if(h<<24>>24!=15){b[e+10>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+6|0]|0;if(h<<24>>24!=15){b[e+12>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+7|0]|0;if(h<<24>>24!=15){b[e+14>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+8|0]|0;if(h<<24>>24!=15){b[e+16>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+9|0]|0;if(h<<24>>24!=15){b[e+18>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+10|0]|0;if(h<<24>>24!=15){b[e+20>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+11|0]|0;if(h<<24>>24!=15){b[e+22>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+12|0]|0;if(h<<24>>24!=15){b[e+24>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+13|0]|0;if(h<<24>>24!=15){b[e+26>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+14|0]|0;if(h<<24>>24!=15){b[e+28>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+15|0]|0;if(h<<24>>24!=15){b[e+30>>1]=c[d+((h&255)<<2)>>2]&65535}h=f+1|0;i=g+16|0;if((h|0)<16){e=e+640|0;f=h;g=i}else{break}}c[2385340]=i;return}function dWf(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[2385458]|0;e=c[2385470]|0;f=e>>>0<320;g=c[2440388]|0;h=c[2415152]|0;i=0;L34250:while(1){j=d+i|0;do{if((j|0)>=0){if((j|0)>223){k=25966;break L34250}do{if(f){l=a[c[2385340]|0]|0;if(l<<24>>24==15){break}b[h>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+1|0)>>>0<320){l=a[(c[2385340]|0)+1|0]|0;if(l<<24>>24==15){break}b[h+2>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+2|0)>>>0<320){l=a[(c[2385340]|0)+2|0]|0;if(l<<24>>24==15){break}b[h+4>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+3|0)>>>0<320){l=a[(c[2385340]|0)+3|0]|0;if(l<<24>>24==15){break}b[h+6>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+4|0)>>>0<320){l=a[(c[2385340]|0)+4|0]|0;if(l<<24>>24==15){break}b[h+8>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+5|0)>>>0<320){l=a[(c[2385340]|0)+5|0]|0;if(l<<24>>24==15){break}b[h+10>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+6|0)>>>0<320){l=a[(c[2385340]|0)+6|0]|0;if(l<<24>>24==15){break}b[h+12>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+7|0)>>>0<320){l=a[(c[2385340]|0)+7|0]|0;if(l<<24>>24==15){break}b[h+14>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+8|0)>>>0<320){l=a[(c[2385340]|0)+8|0]|0;if(l<<24>>24==15){break}b[h+16>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+9|0)>>>0<320){l=a[(c[2385340]|0)+9|0]|0;if(l<<24>>24==15){break}b[h+18>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+10|0)>>>0<320){l=a[(c[2385340]|0)+10|0]|0;if(l<<24>>24==15){break}b[h+20>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+11|0)>>>0<320){l=a[(c[2385340]|0)+11|0]|0;if(l<<24>>24==15){break}b[h+22>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+12|0)>>>0<320){l=a[(c[2385340]|0)+12|0]|0;if(l<<24>>24==15){break}b[h+24>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+13|0)>>>0<320){l=a[(c[2385340]|0)+13|0]|0;if(l<<24>>24==15){break}b[h+26>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+14|0)>>>0<320){l=a[(c[2385340]|0)+14|0]|0;if(l<<24>>24==15){break}b[h+28>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);if((e+15|0)>>>0>=320){break}l=a[(c[2385340]|0)+15|0]|0;if(l<<24>>24==15){break}b[h+30>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);j=i+1|0;c[2385340]=(c[2385340]|0)+16;if((j|0)>=16){k=25965;break}h=h+640|0;i=j}if((k|0)==25965){return}else if((k|0)==25966){return}}function dWg(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=c[2385470]|0;e=c[2385458]|0;f=c[2440376]|0;g=c[2440438]|0;h=~g;i=c[2440388]|0;j=c[2415152]|0;k=0;l=c[2385340]|0;while(1){m=d-(b[f+((e+k&255)<<1)>>1]|0)&g;n=(m|0)>319?m+h|0:m;do{if((n|0)>=-15){do{if(n>>>0<320){m=a[l]|0;if(m<<24>>24==15){break}b[j+(n<<1)>>1]=c[i+((m&255)<<2)>>2]&65535}}while(0);m=n+1|0;do{if(m>>>0<320){o=a[l+1|0]|0;if(o<<24>>24==15){break}b[j+(m<<1)>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);m=n+2|0;do{if(m>>>0<320){o=a[l+2|0]|0;if(o<<24>>24==15){break}b[j+(m<<1)>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);m=n+3|0;do{if(m>>>0<320){o=a[l+3|0]|0;if(o<<24>>24==15){break}b[j+(m<<1)>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);m=n+4|0;do{if(m>>>0<320){o=a[l+4|0]|0;if(o<<24>>24==15){break}b[j+(m<<1)>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);m=n+5|0;do{if(m>>>0<320){o=a[l+5|0]|0;if(o<<24>>24==15){break}b[j+(m<<1)>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);m=n+6|0;do{if(m>>>0<320){o=a[l+6|0]|0;if(o<<24>>24==15){break}b[j+(m<<1)>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);m=n+7|0;do{if(m>>>0<320){o=a[l+7|0]|0;if(o<<24>>24==15){break}b[j+(m<<1)>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);m=n+8|0;do{if(m>>>0<320){o=a[l+8|0]|0;if(o<<24>>24==15){break}b[j+(m<<1)>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);m=n+9|0;do{if(m>>>0<320){o=a[l+9|0]|0;if(o<<24>>24==15){break}b[j+(m<<1)>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);m=n+10|0;do{if(m>>>0<320){o=a[l+10|0]|0;if(o<<24>>24==15){break}b[j+(m<<1)>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);m=n+11|0;do{if(m>>>0<320){o=a[l+11|0]|0;if(o<<24>>24==15){break}b[j+(m<<1)>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);m=n+12|0;do{if(m>>>0<320){o=a[l+12|0]|0;if(o<<24>>24==15){break}b[j+(m<<1)>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);m=n+13|0;do{if(m>>>0<320){o=a[l+13|0]|0;if(o<<24>>24==15){break}b[j+(m<<1)>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);m=n+14|0;do{if(m>>>0<320){o=a[l+14|0]|0;if(o<<24>>24==15){break}b[j+(m<<1)>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);m=n+15|0;if(m>>>0>=320){break}o=a[l+15|0]|0;if(o<<24>>24==15){break}b[j+(m<<1)>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);n=k+1|0;p=l+16|0;if((n|0)>=16){break}j=j+640|0;k=n;l=p}c[2385340]=p;return}function dWh(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=c[2385458]|0;e=c[2385470]|0;f=c[2440376]|0;g=c[2440438]|0;h=~g;i=c[2440388]|0;j=c[2415152]|0;k=0;L34393:while(1){l=d+k|0;do{if((l|0)>=0){if((l|0)>223){m=26076;break L34393}n=e-(b[f+((l&255)<<1)>>1]|0)&g;o=(n|0)>319?n+h|0:n;if((o|0)<-15){break}do{if(o>>>0<320){n=a[c[2385340]|0]|0;if(n<<24>>24==15){break}b[j+(o<<1)>>1]=c[i+((n&255)<<2)>>2]&65535}}while(0);n=o+1|0;do{if(n>>>0<320){p=a[(c[2385340]|0)+1|0]|0;if(p<<24>>24==15){break}b[j+(n<<1)>>1]=c[i+((p&255)<<2)>>2]&65535}}while(0);n=o+2|0;do{if(n>>>0<320){p=a[(c[2385340]|0)+2|0]|0;if(p<<24>>24==15){break}b[j+(n<<1)>>1]=c[i+((p&255)<<2)>>2]&65535}}while(0);n=o+3|0;do{if(n>>>0<320){p=a[(c[2385340]|0)+3|0]|0;if(p<<24>>24==15){break}b[j+(n<<1)>>1]=c[i+((p&255)<<2)>>2]&65535}}while(0);n=o+4|0;do{if(n>>>0<320){p=a[(c[2385340]|0)+4|0]|0;if(p<<24>>24==15){break}b[j+(n<<1)>>1]=c[i+((p&255)<<2)>>2]&65535}}while(0);n=o+5|0;do{if(n>>>0<320){p=a[(c[2385340]|0)+5|0]|0;if(p<<24>>24==15){break}b[j+(n<<1)>>1]=c[i+((p&255)<<2)>>2]&65535}}while(0);n=o+6|0;do{if(n>>>0<320){p=a[(c[2385340]|0)+6|0]|0;if(p<<24>>24==15){break}b[j+(n<<1)>>1]=c[i+((p&255)<<2)>>2]&65535}}while(0);n=o+7|0;do{if(n>>>0<320){p=a[(c[2385340]|0)+7|0]|0;if(p<<24>>24==15){break}b[j+(n<<1)>>1]=c[i+((p&255)<<2)>>2]&65535}}while(0);n=o+8|0;do{if(n>>>0<320){p=a[(c[2385340]|0)+8|0]|0;if(p<<24>>24==15){break}b[j+(n<<1)>>1]=c[i+((p&255)<<2)>>2]&65535}}while(0);n=o+9|0;do{if(n>>>0<320){p=a[(c[2385340]|0)+9|0]|0;if(p<<24>>24==15){break}b[j+(n<<1)>>1]=c[i+((p&255)<<2)>>2]&65535}}while(0);n=o+10|0;do{if(n>>>0<320){p=a[(c[2385340]|0)+10|0]|0;if(p<<24>>24==15){break}b[j+(n<<1)>>1]=c[i+((p&255)<<2)>>2]&65535}}while(0);n=o+11|0;do{if(n>>>0<320){p=a[(c[2385340]|0)+11|0]|0;if(p<<24>>24==15){break}b[j+(n<<1)>>1]=c[i+((p&255)<<2)>>2]&65535}}while(0);n=o+12|0;do{if(n>>>0<320){p=a[(c[2385340]|0)+12|0]|0;if(p<<24>>24==15){break}b[j+(n<<1)>>1]=c[i+((p&255)<<2)>>2]&65535}}while(0);n=o+13|0;do{if(n>>>0<320){p=a[(c[2385340]|0)+13|0]|0;if(p<<24>>24==15){break}b[j+(n<<1)>>1]=c[i+((p&255)<<2)>>2]&65535}}while(0);n=o+14|0;do{if(n>>>0<320){p=a[(c[2385340]|0)+14|0]|0;if(p<<24>>24==15){break}b[j+(n<<1)>>1]=c[i+((p&255)<<2)>>2]&65535}}while(0);n=o+15|0;if(n>>>0>=320){break}p=a[(c[2385340]|0)+15|0]|0;if(p<<24>>24==15){break}b[j+(n<<1)>>1]=c[i+((p&255)<<2)>>2]&65535}}while(0);l=k+1|0;c[2385340]=(c[2385340]|0)+16;if((l|0)>=16){m=26075;break}j=j+640|0;k=l}if((m|0)==26075){return}else if((m|0)==26076){return}}function dWi(){var a=0,e=0,f=0,g=0,h=0,i=0;a=c[2440388]|0;e=c[2415152]|0;f=0;g=c[2385340]|0;while(1){b[e>>1]=c[a+((d[g]|0)<<2)>>2]&65535;b[e+2>>1]=c[a+((d[g+1|0]|0)<<2)>>2]&65535;b[e+4>>1]=c[a+((d[g+2|0]|0)<<2)>>2]&65535;b[e+6>>1]=c[a+((d[g+3|0]|0)<<2)>>2]&65535;b[e+8>>1]=c[a+((d[g+4|0]|0)<<2)>>2]&65535;b[e+10>>1]=c[a+((d[g+5|0]|0)<<2)>>2]&65535;b[e+12>>1]=c[a+((d[g+6|0]|0)<<2)>>2]&65535;b[e+14>>1]=c[a+((d[g+7|0]|0)<<2)>>2]&65535;b[e+16>>1]=c[a+((d[g+8|0]|0)<<2)>>2]&65535;b[e+18>>1]=c[a+((d[g+9|0]|0)<<2)>>2]&65535;b[e+20>>1]=c[a+((d[g+10|0]|0)<<2)>>2]&65535;b[e+22>>1]=c[a+((d[g+11|0]|0)<<2)>>2]&65535;b[e+24>>1]=c[a+((d[g+12|0]|0)<<2)>>2]&65535;b[e+26>>1]=c[a+((d[g+13|0]|0)<<2)>>2]&65535;b[e+28>>1]=c[a+((d[g+14|0]|0)<<2)>>2]&65535;b[e+30>>1]=c[a+((d[g+15|0]|0)<<2)>>2]&65535;h=f+1|0;i=g+16|0;if((h|0)<16){e=e+640|0;f=h;g=i}else{break}}c[2385340]=i;return}function dWj(){var a=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[2385458]|0;e=c[2385470]|0;f=e>>>0<320;g=c[2440388]|0;h=c[2415152]|0;i=0;L34471:while(1){j=a+i|0;do{if((j|0)>=0){if((j|0)>223){k=26118;break L34471}if(f){b[h>>1]=c[g+((d[c[2385340]|0]|0)<<2)>>2]&65535}if((e+1|0)>>>0<320){b[h+2>>1]=c[g+((d[(c[2385340]|0)+1|0]|0)<<2)>>2]&65535}if((e+2|0)>>>0<320){b[h+4>>1]=c[g+((d[(c[2385340]|0)+2|0]|0)<<2)>>2]&65535}if((e+3|0)>>>0<320){b[h+6>>1]=c[g+((d[(c[2385340]|0)+3|0]|0)<<2)>>2]&65535}if((e+4|0)>>>0<320){b[h+8>>1]=c[g+((d[(c[2385340]|0)+4|0]|0)<<2)>>2]&65535}if((e+5|0)>>>0<320){b[h+10>>1]=c[g+((d[(c[2385340]|0)+5|0]|0)<<2)>>2]&65535}if((e+6|0)>>>0<320){b[h+12>>1]=c[g+((d[(c[2385340]|0)+6|0]|0)<<2)>>2]&65535}if((e+7|0)>>>0<320){b[h+14>>1]=c[g+((d[(c[2385340]|0)+7|0]|0)<<2)>>2]&65535}if((e+8|0)>>>0<320){b[h+16>>1]=c[g+((d[(c[2385340]|0)+8|0]|0)<<2)>>2]&65535}if((e+9|0)>>>0<320){b[h+18>>1]=c[g+((d[(c[2385340]|0)+9|0]|0)<<2)>>2]&65535}if((e+10|0)>>>0<320){b[h+20>>1]=c[g+((d[(c[2385340]|0)+10|0]|0)<<2)>>2]&65535}if((e+11|0)>>>0<320){b[h+22>>1]=c[g+((d[(c[2385340]|0)+11|0]|0)<<2)>>2]&65535}if((e+12|0)>>>0<320){b[h+24>>1]=c[g+((d[(c[2385340]|0)+12|0]|0)<<2)>>2]&65535}if((e+13|0)>>>0<320){b[h+26>>1]=c[g+((d[(c[2385340]|0)+13|0]|0)<<2)>>2]&65535}if((e+14|0)>>>0<320){b[h+28>>1]=c[g+((d[(c[2385340]|0)+14|0]|0)<<2)>>2]&65535}if((e+15|0)>>>0>=320){break}b[h+30>>1]=c[g+((d[(c[2385340]|0)+15|0]|0)<<2)>>2]&65535}}while(0);j=i+1|0;c[2385340]=(c[2385340]|0)+16;if((j|0)>=16){k=26119;break}h=h+640|0;i=j}if((k|0)==26118){return}else if((k|0)==26119){return}}function dWk(){var a=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=c[2385470]|0;e=c[2385458]|0;f=c[2440376]|0;g=c[2440438]|0;h=~g;i=c[2440388]|0;j=c[2415152]|0;k=0;l=c[2385340]|0;while(1){m=a-(b[f+((e+k&255)<<1)>>1]|0)&g;n=(m|0)>319?m+h|0:m;do{if((n|0)>=-15){if(n>>>0<320){b[j+(n<<1)>>1]=c[i+(d[l]<<2)>>2]&65535}m=n+1|0;if(m>>>0<320){b[j+(m<<1)>>1]=c[i+(d[l+1|0]<<2)>>2]&65535}m=n+2|0;if(m>>>0<320){b[j+(m<<1)>>1]=c[i+(d[l+2|0]<<2)>>2]&65535}m=n+3|0;if(m>>>0<320){b[j+(m<<1)>>1]=c[i+(d[l+3|0]<<2)>>2]&65535}m=n+4|0;if(m>>>0<320){b[j+(m<<1)>>1]=c[i+(d[l+4|0]<<2)>>2]&65535}m=n+5|0;if(m>>>0<320){b[j+(m<<1)>>1]=c[i+(d[l+5|0]<<2)>>2]&65535}m=n+6|0;if(m>>>0<320){b[j+(m<<1)>>1]=c[i+(d[l+6|0]<<2)>>2]&65535}m=n+7|0;if(m>>>0<320){b[j+(m<<1)>>1]=c[i+(d[l+7|0]<<2)>>2]&65535}m=n+8|0;if(m>>>0<320){b[j+(m<<1)>>1]=c[i+(d[l+8|0]<<2)>>2]&65535}m=n+9|0;if(m>>>0<320){b[j+(m<<1)>>1]=c[i+(d[l+9|0]<<2)>>2]&65535}m=n+10|0;if(m>>>0<320){b[j+(m<<1)>>1]=c[i+(d[l+10|0]<<2)>>2]&65535}m=n+11|0;if(m>>>0<320){b[j+(m<<1)>>1]=c[i+(d[l+11|0]<<2)>>2]&65535}m=n+12|0;if(m>>>0<320){b[j+(m<<1)>>1]=c[i+(d[l+12|0]<<2)>>2]&65535}m=n+13|0;if(m>>>0<320){b[j+(m<<1)>>1]=c[i+(d[l+13|0]<<2)>>2]&65535}m=n+14|0;if(m>>>0<320){b[j+(m<<1)>>1]=c[i+(d[l+14|0]<<2)>>2]&65535}m=n+15|0;if(m>>>0>=320){break}b[j+(m<<1)>>1]=c[i+(d[l+15|0]<<2)>>2]&65535}}while(0);n=k+1|0;o=l+16|0;if((n|0)>=16){break}j=j+640|0;k=n;l=o}c[2385340]=o;return}function dWl(){var a=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=c[2385458]|0;e=c[2385470]|0;f=c[2440376]|0;g=c[2440438]|0;h=~g;i=c[2440388]|0;j=c[2415152]|0;k=0;L34582:while(1){l=a+k|0;do{if((l|0)>=0){if((l|0)>223){m=26196;break L34582}n=e-(b[f+((l&255)<<1)>>1]|0)&g;o=(n|0)>319?n+h|0:n;if((o|0)<-15){break}if(o>>>0<320){b[j+(o<<1)>>1]=c[i+(d[c[2385340]|0]<<2)>>2]&65535}n=o+1|0;if(n>>>0<320){b[j+(n<<1)>>1]=c[i+(d[(c[2385340]|0)+1|0]<<2)>>2]&65535}n=o+2|0;if(n>>>0<320){b[j+(n<<1)>>1]=c[i+(d[(c[2385340]|0)+2|0]<<2)>>2]&65535}n=o+3|0;if(n>>>0<320){b[j+(n<<1)>>1]=c[i+(d[(c[2385340]|0)+3|0]<<2)>>2]&65535}n=o+4|0;if(n>>>0<320){b[j+(n<<1)>>1]=c[i+(d[(c[2385340]|0)+4|0]<<2)>>2]&65535}n=o+5|0;if(n>>>0<320){b[j+(n<<1)>>1]=c[i+(d[(c[2385340]|0)+5|0]<<2)>>2]&65535}n=o+6|0;if(n>>>0<320){b[j+(n<<1)>>1]=c[i+(d[(c[2385340]|0)+6|0]<<2)>>2]&65535}n=o+7|0;if(n>>>0<320){b[j+(n<<1)>>1]=c[i+(d[(c[2385340]|0)+7|0]<<2)>>2]&65535}n=o+8|0;if(n>>>0<320){b[j+(n<<1)>>1]=c[i+(d[(c[2385340]|0)+8|0]<<2)>>2]&65535}n=o+9|0;if(n>>>0<320){b[j+(n<<1)>>1]=c[i+(d[(c[2385340]|0)+9|0]<<2)>>2]&65535}n=o+10|0;if(n>>>0<320){b[j+(n<<1)>>1]=c[i+(d[(c[2385340]|0)+10|0]<<2)>>2]&65535}n=o+11|0;if(n>>>0<320){b[j+(n<<1)>>1]=c[i+(d[(c[2385340]|0)+11|0]<<2)>>2]&65535}n=o+12|0;if(n>>>0<320){b[j+(n<<1)>>1]=c[i+(d[(c[2385340]|0)+12|0]<<2)>>2]&65535}n=o+13|0;if(n>>>0<320){b[j+(n<<1)>>1]=c[i+(d[(c[2385340]|0)+13|0]<<2)>>2]&65535}n=o+14|0;if(n>>>0<320){b[j+(n<<1)>>1]=c[i+(d[(c[2385340]|0)+14|0]<<2)>>2]&65535}n=o+15|0;if(n>>>0>=320){break}b[j+(n<<1)>>1]=c[i+(d[(c[2385340]|0)+15|0]<<2)>>2]&65535}}while(0);l=k+1|0;c[2385340]=(c[2385340]|0)+16;if((l|0)>=16){m=26197;break}j=j+640|0;k=l}if((m|0)==26196){return}else if((m|0)==26197){return}}function dWm(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0;f=c[2112942]|0;g=c[2112966]|0;h=0;do{c[g+(h<<2)>>2]=(c[f+(h<<2)>>2]|0)>>>8;h=h+1|0;}while((h|0)<5120);h=c[2113308]|0;if((h|0)==4){i=c[2112968]|0}else{i=c[2438736]|0}c[3529496]=i;f=c[2113068]|0;j=c[2113070]|0;gGz(i|0,0,ag(f<<2,j)|0);k=c[2387044]|0;gGz(k|0,0,ag(f<<1,j)|0);l=c[2112936]|0;m=c[2112944]|0;n=(j|0)>0;if(n){o=(f|0)>1;p=i;q=0;while(1){r=m+(q<<2)|0;s=c[r>>2]|0;do{if((s&255|0)!=0&(f|0)>0){c[p>>2]=s>>>8;if(o){t=1}else{break}do{c[p+(t<<2)>>2]=(c[r>>2]|0)>>>8;t=t+1|0;}while((t|0)<(f|0))}}while(0);r=q+1|0;if((r|0)<(j|0)){p=p+(f<<2)|0;q=r}else{break}}}q=l+8|0;p=c[2112940]|0;t=p+14336|0;o=c[2112934]|0;r=c[3529100]|0;s=c[2438156]|0;u=0;v=i;while(1){w=l;x=0;while(1){y=x&65535;if((x&65535)>=1024){z=0;break}A=e[t+((y^1)<<1)>>1]|0;B=A<<2&4092;C=c[p+((B|1)<<2)>>2]|0;L34662:do{if((c[q>>2]<<(C>>>12<<2&12)>>>28|0)==(u|0)){D=c[p+(B<<2)>>2]|0;E=D>>>16;F=C>>>24&15;G=F+1|0;H=C>>>8&15;I=H+1|0;J=C>>>31;K=C>>>15&1;L=c[p+((B|2)<<2)>>2]|0;M=L&524287;N=L>>>23&1;O=L>>>24;P=(E&512|0)==0?E&1023:E|-1024;E=(D&512|0)==0?D&1023:D|-1024;D=d[w+(L>>>20&7^3)|0]|0;if((D&128|0)==0){Q=d[14115392+(D|192)|0]|0}else{Q=-1}D=b[o+((C>>>16&255^1)<<1)>>1]|0;if(D<<16>>16==0){break}R=b[o+((C&255^1)<<1)>>1]|0;if(R<<16>>16==0){break}S=R&65535;T=D&65535;if(R<<16>>16==1024&D<<16>>16==1024){D=(K|0)==0;R=(K<<1^2)-1|0;U=D?I:-1;V=D?0:H;H=(J|0)==0;D=H?1:-1;W=H?G:-1;X=H?0:F;F=0;while(1){H=(X<<4)+P|0;Y=V;Z=F;while(1){_=Z+1|0;dWo(N,Z+M|0,O,(Y<<4)+E|0,H,K,J,Q,y);$=R+Y|0;if(($|0)==(U|0)){break}else{Y=$;Z=_}}Z=X+D|0;if((Z|0)==(W|0)){break L34662}else{X=Z;F=_}}}do{if((N|0)==0){F=M-(c[2439216]|0)|0;X=(F|0)<0|(F|0)>(c[2438158]|0)?0:F;if((c[1629464]|0)==(X|0)){break}c[1629464]=X;F=I<<7;W=(c[2112938]|0)+(X<<7)|0;X=0;while(1){D=X<<12;U=W;R=0;while(1){V=U;Z=r+((R<<4)+D)|0;Y=0;while(1){H=a[V]|0;a[Z]=(H&255)>>>4;a[Z+1|0]=H&15;H=a[V+1|0]|0;a[Z+2|0]=(H&255)>>>4;a[Z+3|0]=H&15;H=a[V+2|0]|0;a[Z+4|0]=(H&255)>>>4;a[Z+5|0]=H&15;H=a[V+3|0]|0;a[Z+6|0]=(H&255)>>>4;a[Z+7|0]=H&15;H=a[V+4|0]|0;a[Z+8|0]=(H&255)>>>4;a[Z+9|0]=H&15;H=a[V+5|0]|0;a[Z+10|0]=(H&255)>>>4;a[Z+11|0]=H&15;H=a[V+6|0]|0;a[Z+12|0]=(H&255)>>>4;a[Z+13|0]=H&15;H=a[V+7|0]|0;a[Z+14|0]=(H&255)>>>4;a[Z+15|0]=H&15;H=Y+1|0;if((H|0)<16){V=V+8|0;Z=Z+256|0;Y=H}else{break}}Y=R+1|0;if((Y|0)>=(I|0)){break}U=U+128|0;R=Y}R=X+1|0;if((R|0)<(G|0)){W=W+F|0;X=R}else{break}}}else{X=(L&262143)-(c[2439214]|0)|0;F=(X|0)<0|(X|0)>(s|0)?0:X;if((c[1629464]|0)==(F|0)){break}c[1629464]=F;X=I<<6;W=(c[2112938]|0)+(F<<8)|0;F=0;while(1){R=F<<12;U=W;D=0;while(1){Y=U;Z=r+((D<<4)+R)|0;V=0;while(1){c[Z>>2]=c[Y>>2];c[Z+4>>2]=c[Y+4>>2];c[Z+8>>2]=c[Y+8>>2];c[Z+12>>2]=c[Y+12>>2];H=V+1|0;if((H|0)<16){Y=Y+16|0;Z=Z+256|0;V=H}else{break}}V=D+1|0;if((V|0)>=(I|0)){break}U=U+256|0;D=V}D=F+1|0;if((D|0)<(G|0)){W=W+(X<<2)|0;F=D}else{break}}}}while(0);L=O<<4;M=((G<<24|0)/(T|0)|0)+512>>10;N=((I<<24|0)/(S|0)|0)+512>>10;if((N|0)==0|(M|0)==0){break}F=N+E|0;X=M+P|0;if((K|0)==0){aa=0;ab=S}else{aa=ag(N-1|0,S)|0;ab=-S|0}if((J|0)==0){ac=0;ad=T}else{ac=ag(M-1|0,T)|0;ad=-T|0}if((E|0)<0){ae=0;af=aa-(ag(ab,E)|0)|0}else{ae=E;af=aa}if((P|0)<0){ah=0;ai=ac-(ag(ad,P)|0)|0}else{ah=P;ai=ac}M=(F|0)>(f|0)?f:F;F=(X|0)>(j|0)?j:X;if((M|0)<=(ae|0)){break}if((Q|0)==255){X=(ah|0)<(F|0);if(x<<16>>16==0){if(X){aj=ah;ak=ai}else{break}while(1){N=ak>>10<<8;W=ag(aj,f)|0;D=af;U=ae;while(1){R=a[r+((D>>10)+N)|0]|0;if(R<<24>>24!=0){c[v+(U+W<<2)>>2]=c[g+((R&255)+L<<2)>>2]}R=U+1|0;if((R|0)<(M|0)){D=D+ab|0;U=R}else{break}}U=aj+1|0;if((U|0)>=(F|0)){break L34662}aj=U;ak=ak+ad|0}}if(X){al=ah;am=ai}else{break}while(1){P=am>>10<<8;E=ag(al,f)|0;T=af;J=ae;while(1){S=J+E|0;K=k+(S<<1)|0;do{if((e[K>>1]|0)<=(x&65535)){I=a[r+((T>>10)+P)|0]|0;if(I<<24>>24==0){break}c[v+(S<<2)>>2]=c[g+((I&255)+L<<2)>>2];b[K>>1]=x}}while(0);K=J+1|0;if((K|0)<(M|0)){T=T+ab|0;J=K}else{break}}J=al+1|0;if((J|0)>=(F|0)){break L34662}al=J;am=am+ad|0}}X=x<<16>>16!=0;J=(ah|0)<(F|0);if((Q|0)>-1){if(!X){if(!J){break}T=(Q|0)==0;P=256-Q|0;E=ai;K=ah;while(1){S=E>>10<<8;I=ag(K,f)|0;G=af;O=ae;while(1){U=a[r+((G>>10)+S)|0]|0;if(U<<24>>24!=0){D=v+(O+I<<2)|0;W=c[D>>2]|0;N=c[g+((U&255)+L<<2)>>2]|0;if(T){an=W}else{U=ag(N&16711935,Q)|0;R=U+(ag(W&16711935,P)|0)&-16711936;U=ag(N&65280,Q)|0;an=(R|U+(ag(W&65280,P)|0)&16711680)>>>8}c[D>>2]=an}D=O+1|0;if((D|0)<(M|0)){G=G+ab|0;O=D}else{break}}O=K+1|0;if((O|0)>=(F|0)){break L34662}E=E+ad|0;K=O}}if(!J){break}K=(Q|0)==0;E=256-Q|0;P=ai;T=ah;while(1){O=P>>10<<8;G=ag(T,f)|0;I=af;S=ae;while(1){D=S+G|0;W=k+(D<<1)|0;do{if((e[W>>1]|0)<=(x&65535)){U=a[r+((I>>10)+O)|0]|0;if(U<<24>>24==0){break}R=v+(D<<2)|0;N=c[R>>2]|0;V=c[g+((U&255)+L<<2)>>2]|0;if(K){ao=N}else{U=ag(V&16711935,Q)|0;Z=U+(ag(N&16711935,E)|0)&-16711936;U=ag(V&65280,Q)|0;ao=(Z|U+(ag(N&65280,E)|0)&16711680)>>>8}c[R>>2]=ao;b[W>>1]=x}}while(0);W=S+1|0;if((W|0)<(M|0)){I=I+ab|0;S=W}else{break}}S=T+1|0;if((S|0)>=(F|0)){break L34662}P=P+ad|0;T=S}}if(!X){if(J){ap=ai;aq=ah}else{break}while(1){T=ap>>10<<8;P=ag(aq,f)|0;E=af;K=ae;while(1){S=a[r+((E>>10)+T)|0]|0;I=S&255;do{if(S<<24>>24!=0){O=a[14115392+I|0]|0;if(O<<24>>24==-1){c[v+(K+P<<2)>>2]=c[g+(I+L<<2)>>2];break}G=O&255;W=v+(K+P<<2)|0;D=c[W>>2]|0;R=c[g+(I+L<<2)>>2]|0;if(O<<24>>24==0){ar=D}else{O=256-G|0;N=ag(R&16711935,G)|0;U=N+(ag(D&16711935,O)|0)&-16711936;N=ag(R&65280,G)|0;ar=(U|N+(ag(D&65280,O)|0)&16711680)>>>8}c[W>>2]=ar}}while(0);I=K+1|0;if((I|0)<(M|0)){E=E+ab|0;K=I}else{break}}K=aq+1|0;if((K|0)>=(F|0)){break L34662}ap=ap+ad|0;aq=K}}if(J){as=ai;at=ah}else{break}while(1){X=as>>10<<8;K=ag(at,f)|0;E=af;P=ae;while(1){T=P+K|0;I=k+(T<<1)|0;do{if((e[I>>1]|0)<=(x&65535)){S=a[r+((E>>10)+X)|0]|0;W=S&255;if(S<<24>>24==0){break}S=a[14115392+W|0]|0;if(S<<24>>24==-1){c[v+(T<<2)>>2]=c[g+(W+L<<2)>>2]}else{O=S&255;D=v+(T<<2)|0;N=c[D>>2]|0;U=c[g+(W+L<<2)>>2]|0;if(S<<24>>24==0){au=N}else{S=256-O|0;W=ag(U&16711935,O)|0;G=W+(ag(N&16711935,S)|0)&-16711936;W=ag(U&65280,O)|0;au=(G|W+(ag(N&65280,S)|0)&16711680)>>>8}c[D>>2]=au}b[I>>1]=x}}while(0);I=P+1|0;if((I|0)<(M|0)){E=E+ab|0;P=I}else{break}}P=at+1|0;if((P|0)>=(F|0)){break L34662}as=as+ad|0;at=P}}}while(0);if((A&16384|0)==0){x=x+1&65535}else{z=0;break}}do{L34811:do{if((c[l+28>>2]&32768>>>(z<<2>>>0)|0)!=0){x=c[l+24>>2]<<(z<<3)>>>24;w=x&127;switch(w|0){case 10:{y=c[m+(z+1532<<2)>>2]|0;if((y>>>24|0)!=(u|0)){break L34811}C=c[m+(z+1276<<2)>>2]|0;dWn(z,y&255,y>>>8&191,C&511,C>>>16&1023);break L34811;break};case 11:{C=c[m+(z+2044<<2)>>2]|0;if((C>>>24|0)!=(u|0)){break L34811}y=c[m+(z+1788<<2)>>2]|0;dWn(z,C&255,C>>>8&191,y&511,y>>>16&1023);break L34811;break};case 12:case 13:{if(((c[m+((w<<9|256)-4096<<2)>>2]|0)>>>24|0)!=(u|0)){break L34811}y=x<<9&65024;C=c[m+((y|256)-4096<<2)>>2]|0;B=c[m+(y-4096<<2)>>2]|0;dWn(z,C&255,C>>>8&191,B&511,B>>>16&1023);B=c[m+((y|264)-4096<<2)>>2]|0;C=c[m+(y-4088<<2)>>2]|0;dWn(z,B&255,B>>>8&191,C&511,C>>>16&1023);break L34811;break};case 14:case 16:case 17:case 18:case 19:case 20:case 21:case 22:case 23:case 24:case 25:case 26:case 27:case 28:case 29:case 30:case 31:{if(((c[m+((w<<9|256)-4096<<2)>>2]|0)>>>24|0)!=(u|0)){break L34811}w=x<<9&65024;x=c[m+((w|256)-4096<<2)>>2]|0;dWn(z,x&255,x>>>8&191,c[m+(w-4096<<2)>>2]&511,0);break L34811;break};default:{break L34811}}}}while(0);z=z+1|0;}while((z|0)<3);if((c[q>>2]&15|0)==(u|0)^1|n^1){av=v}else{A=(f|0)>0;w=(f|0)>1;x=i;C=0;while(1){B=m+(C+256<<2)|0;y=c[B>>2]|0;L34828:do{if((y&128|0)==0){if((y&127|0)!=0&A){aw=0;ax=y}else{break}while(1){F=x+(aw<<2)|0;M=c[F>>2]|0;L=ax>>>8;J=ax<<1&254;if((J|0)==0){ay=M}else{P=256-J|0;E=ag(L&16711935,J)|0;X=(ag(P,M&16711935)|0)+E&-16711936;E=ag(L&65280,J)|0;ay=(X|(ag(P,M&65280)|0)+E&16711680)>>>8}c[F>>2]=ay;F=aw+1|0;if((F|0)>=(f|0)){break L34828}aw=F;ax=c[B>>2]|0}}else{if(!A){break}c[x>>2]=y>>>8;if(w){az=1}else{break}do{c[x+(az<<2)>>2]=(c[B>>2]|0)>>>8;az=az+1|0;}while((az|0)<(f|0))}}while(0);B=C+1|0;if((B|0)<(j|0)){x=x+(f<<2)|0;C=B}else{av=i;break}}}C=u+1|0;if(C>>>0<8){u=C;v=av}else{break}}if((h|0)>=4){return 0}av=ag(j,f)|0;if((av|0)<=0){return 0}f=c[2112968]|0;j=0;do{v=c[i+(j<<2)>>2]|0;u=ag(j,h)|0;az=f+u|0;ax=v>>16<<8&63488|v>>8<<3&2016;aw=ax|v>>>3&31;do{if((h|0)>3){c[az>>2]=aw}else{if((h|0)==2){b[az>>1]=aw&65535;break}else{a[az]=aw&255;a[f+(u+1)|0]=ax>>>8&255;a[f+(u+2)|0]=0;break}}}while(0);j=j+1|0;}while((j|0)<(av|0));return 0}function dWn(a,b,e,f,g){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if((b-12|0)>>>0>19){return}if((e&128|0)==0){h=d[14115392+(e|192)|0]|0}else{h=-1}e=c[(c[2112936]|0)+28>>2]<<(a<<2);a=e&16384;i=(e>>>8&16)+16|0;e=i<<4;j=i<<5;if((j|0)<=0){return}i=e-1|0;k=((b<<11|0)/4|0)-4096|0;b=c[2112944]|0;l=c[2113068]|0;m=c[2113070]|0;n=0;do{o=(n<<4)+f|0;p=o&511;q=(n>>5<<4)+g&i;r=(p|0)<(l|0)?p:o|-512;o=q-((q|0)<(m|0)?0:e)|0;if(!((r|0)<-15|(o|0)<-15)){q=c[b+(k+n<<2)>>2]|0;dWo(a,q&524287,q>>>24,r,o,0,0,h,0)}n=n+1|0;}while((n|0)<(j|0));return}function dWo(f,g,h,i,j,k,l,m,n){f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0;o=h<<4;h=c[2112966]|0;if((f|0)!=0){f=c[2439214]|0;p=(g&262143)-f|0;if((p|0)<0|(p|0)>(c[2438158]|0)){return}if(((d[(c[3527248]|0)+((p>>3)+65536)|0]|0)&1<<(g-f&7)|0)!=0){return}f=p<<8;p=(l|0)==0;q=p?16:-16;r=(c[2112938]|0)+(p?f:f|240)|0;do{if((i|0)>-1){f=c[2113068]|0;if(!((f-15|0)>(i|0)&(j|0)>-1)){break}if(((c[2113070]|0)-15|0)<=(j|0)){break}p=(k|0)!=0;s=(m|0)==255;if((n|0)<=0){if(p){if(s){t=c[3529496]|0;u=r;v=t+((ag(f,j)|0)<<2)|0;t=0;while(1){w=15;x=i;while(1){y=a[u+w|0]|0;if(y<<24>>24!=0){c[v+(x<<2)>>2]=c[h+((y&255)+o<<2)>>2]}if((w|0)>0){w=w-1|0;x=x+1|0}else{break}}x=t+1|0;if((x|0)<16){u=u+q|0;v=v+(f<<2)|0;t=x}else{break}}return}t=c[3529496]|0;v=t+((ag(f,j)|0)<<2)|0;if((m|0)>-1){t=(m|0)==0;u=256-m|0;x=r;w=v;y=0;while(1){z=15;A=i;while(1){B=a[x+z|0]|0;if(B<<24>>24!=0){C=w+(A<<2)|0;D=c[C>>2]|0;E=c[h+((B&255)+o<<2)>>2]|0;if(t){F=D}else{B=ag(E&16711935,m)|0;G=B+(ag(D&16711935,u)|0)&-16711936;B=ag(E&65280,m)|0;F=(G|B+(ag(D&65280,u)|0)&16711680)>>>8}c[C>>2]=F}if((z|0)>0){z=z-1|0;A=A+1|0}else{break}}A=y+1|0;if((A|0)<16){x=x+q|0;w=w+(f<<2)|0;y=A}else{break}}return}else{H=r;I=v;J=0}while(1){y=15;w=i;while(1){x=a[H+y|0]|0;u=x&255;do{if(x<<24>>24!=0){t=a[14115392+u|0]|0;if(t<<24>>24==-1){c[I+(w<<2)>>2]=c[h+(u+o<<2)>>2];break}A=t&255;z=I+(w<<2)|0;C=c[z>>2]|0;D=c[h+(u+o<<2)>>2]|0;if(t<<24>>24==0){K=C}else{t=256-A|0;B=ag(D&16711935,A)|0;G=B+(ag(C&16711935,t)|0)&-16711936;B=ag(D&65280,A)|0;K=(G|B+(ag(C&65280,t)|0)&16711680)>>>8}c[z>>2]=K}}while(0);if((y|0)>0){y=y-1|0;w=w+1|0}else{break}}w=J+1|0;if((w|0)<16){H=H+q|0;I=I+(f<<2)|0;J=w}else{break}}return}else{if(s){v=c[3529496]|0;w=r;y=v+((ag(f,j)|0)<<2)|0;v=0;while(1){u=0;x=i;while(1){z=a[w+u|0]|0;if(z<<24>>24!=0){c[y+(x<<2)>>2]=c[h+((z&255)+o<<2)>>2]}z=u+1|0;if((z|0)<16){u=z;x=x+1|0}else{break}}x=v+1|0;if((x|0)<16){w=w+q|0;y=y+(f<<2)|0;v=x}else{break}}return}v=c[3529496]|0;y=v+((ag(f,j)|0)<<2)|0;if((m|0)>-1){v=(m|0)==0;w=256-m|0;x=r;u=y;z=0;while(1){t=0;C=i;while(1){B=a[x+t|0]|0;if(B<<24>>24!=0){G=u+(C<<2)|0;A=c[G>>2]|0;D=c[h+((B&255)+o<<2)>>2]|0;if(v){L=A}else{B=ag(D&16711935,m)|0;E=B+(ag(A&16711935,w)|0)&-16711936;B=ag(D&65280,m)|0;L=(E|B+(ag(A&65280,w)|0)&16711680)>>>8}c[G>>2]=L}G=t+1|0;if((G|0)<16){t=G;C=C+1|0}else{break}}C=z+1|0;if((C|0)<16){x=x+q|0;u=u+(f<<2)|0;z=C}else{break}}return}else{M=r;N=y;O=0}while(1){z=0;u=i;while(1){x=a[M+z|0]|0;w=x&255;do{if(x<<24>>24!=0){v=a[14115392+w|0]|0;if(v<<24>>24==-1){c[N+(u<<2)>>2]=c[h+(w+o<<2)>>2];break}C=v&255;t=N+(u<<2)|0;G=c[t>>2]|0;A=c[h+(w+o<<2)>>2]|0;if(v<<24>>24==0){P=G}else{v=256-C|0;B=ag(A&16711935,C)|0;E=B+(ag(G&16711935,v)|0)&-16711936;B=ag(A&65280,C)|0;P=(E|B+(ag(G&65280,v)|0)&16711680)>>>8}c[t>>2]=P}}while(0);w=z+1|0;if((w|0)<16){z=w;u=u+1|0}else{break}}u=O+1|0;if((u|0)<16){M=M+q|0;N=N+(f<<2)|0;O=u}else{break}}return}}if(p){if(s){y=c[3529496]|0;u=ag(f,j)|0;z=n&65535;w=r;x=y+(u<<2)|0;y=(c[2387044]|0)+(u<<1)|0;u=0;while(1){t=15;v=i;while(1){G=y+(v<<1)|0;do{if((e[G>>1]|0|0)<=(n|0)){B=a[w+t|0]|0;if(B<<24>>24==0){break}c[x+(v<<2)>>2]=c[h+((B&255)+o<<2)>>2];b[G>>1]=z}}while(0);if((t|0)>0){t=t-1|0;v=v+1|0}else{break}}v=u+1|0;if((v|0)<16){w=w+q|0;x=x+(f<<2)|0;y=y+(f<<1)|0;u=v}else{break}}return}u=c[3529496]|0;y=ag(f,j)|0;x=u+(y<<2)|0;u=(c[2387044]|0)+(y<<1)|0;if((m|0)>-1){y=(m|0)==0;w=n&65535;z=256-m|0;p=r;v=x;t=u;G=0;while(1){B=15;E=i;while(1){C=t+(E<<1)|0;do{if((e[C>>1]|0|0)<=(n|0)){A=a[p+B|0]|0;if(A<<24>>24==0){break}D=v+(E<<2)|0;Q=c[D>>2]|0;R=c[h+((A&255)+o<<2)>>2]|0;if(y){S=Q}else{A=ag(R&16711935,m)|0;T=A+(ag(Q&16711935,z)|0)&-16711936;A=ag(R&65280,m)|0;S=(T|A+(ag(Q&65280,z)|0)&16711680)>>>8}c[D>>2]=S;b[C>>1]=w}}while(0);if((B|0)>0){B=B-1|0;E=E+1|0}else{break}}E=G+1|0;if((E|0)<16){p=p+q|0;v=v+(f<<2)|0;t=t+(f<<1)|0;G=E}else{break}}return}G=n&65535;t=r;v=x;p=u;w=0;while(1){z=15;y=i;while(1){E=p+(y<<1)|0;do{if((e[E>>1]|0|0)<=(n|0)){B=a[t+z|0]|0;C=B&255;if(B<<24>>24==0){break}B=a[14115392+C|0]|0;if(B<<24>>24==-1){c[v+(y<<2)>>2]=c[h+(C+o<<2)>>2]}else{D=B&255;Q=v+(y<<2)|0;A=c[Q>>2]|0;T=c[h+(C+o<<2)>>2]|0;if(B<<24>>24==0){U=A}else{B=256-D|0;C=ag(T&16711935,D)|0;R=C+(ag(A&16711935,B)|0)&-16711936;C=ag(T&65280,D)|0;U=(R|C+(ag(A&65280,B)|0)&16711680)>>>8}c[Q>>2]=U}b[E>>1]=G}}while(0);if((z|0)>0){z=z-1|0;y=y+1|0}else{break}}y=w+1|0;if((y|0)<16){t=t+q|0;v=v+(f<<2)|0;p=p+(f<<1)|0;w=y}else{break}}return}else{if(s){w=c[3529496]|0;p=ag(f,j)|0;v=n&65535;t=r;G=w+(p<<2)|0;w=(c[2387044]|0)+(p<<1)|0;p=0;while(1){u=0;x=i;while(1){y=w+(x<<1)|0;do{if((e[y>>1]|0|0)<=(n|0)){z=a[t+u|0]|0;if(z<<24>>24==0){break}c[G+(x<<2)>>2]=c[h+((z&255)+o<<2)>>2];b[y>>1]=v}}while(0);y=u+1|0;if((y|0)<16){u=y;x=x+1|0}else{break}}x=p+1|0;if((x|0)<16){t=t+q|0;G=G+(f<<2)|0;w=w+(f<<1)|0;p=x}else{break}}return}p=c[3529496]|0;w=ag(f,j)|0;G=p+(w<<2)|0;p=(c[2387044]|0)+(w<<1)|0;if((m|0)>-1){w=(m|0)==0;t=n&65535;v=256-m|0;s=r;x=G;u=p;y=0;while(1){z=0;E=i;while(1){Q=u+(E<<1)|0;do{if((e[Q>>1]|0|0)<=(n|0)){B=a[s+z|0]|0;if(B<<24>>24==0){break}A=x+(E<<2)|0;C=c[A>>2]|0;R=c[h+((B&255)+o<<2)>>2]|0;if(w){V=C}else{B=ag(R&16711935,m)|0;D=B+(ag(C&16711935,v)|0)&-16711936;B=ag(R&65280,m)|0;V=(D|B+(ag(C&65280,v)|0)&16711680)>>>8}c[A>>2]=V;b[Q>>1]=t}}while(0);Q=z+1|0;if((Q|0)<16){z=Q;E=E+1|0}else{break}}E=y+1|0;if((E|0)<16){s=s+q|0;x=x+(f<<2)|0;u=u+(f<<1)|0;y=E}else{break}}return}y=n&65535;u=r;x=G;s=p;t=0;while(1){v=0;w=i;while(1){E=s+(w<<1)|0;do{if((e[E>>1]|0|0)<=(n|0)){z=a[u+v|0]|0;Q=z&255;if(z<<24>>24==0){break}z=a[14115392+Q|0]|0;if(z<<24>>24==-1){c[x+(w<<2)>>2]=c[h+(Q+o<<2)>>2]}else{A=z&255;C=x+(w<<2)|0;B=c[C>>2]|0;D=c[h+(Q+o<<2)>>2]|0;if(z<<24>>24==0){W=B}else{z=256-A|0;Q=ag(D&16711935,A)|0;R=Q+(ag(B&16711935,z)|0)&-16711936;Q=ag(D&65280,A)|0;W=(R|Q+(ag(B&65280,z)|0)&16711680)>>>8}c[C>>2]=W}b[E>>1]=y}}while(0);E=v+1|0;if((E|0)<16){v=E;w=w+1|0}else{break}}w=t+1|0;if((w|0)<16){u=u+q|0;x=x+(f<<2)|0;s=s+(f<<1)|0;t=w}else{break}}return}}}while(0);W=(k|0)!=0;V=(m|0)==255;if((n|0)<=0){if(W){if(V){U=c[2113070]|0;S=c[3529496]|0;O=c[2113068]|0;N=r;M=1;P=j;while(1){L35080:do{if((P|0)>-1&(P|0)<(U|0)){L=ag(O,P)|0;J=15;I=i;while(1){do{if((I|0)>-1&(I|0)<(O|0)){H=a[N+J|0]|0;if(H<<24>>24==0){break}c[S+(I+L<<2)>>2]=c[h+((H&255)+o<<2)>>2]}}while(0);if((J|0)<=0){break L35080}J=J-1|0;I=I+1|0}}}while(0);if((M|0)>=16){break}N=N+q|0;M=M+1|0;P=P+1|0}return}if((m|0)>-1){P=(m|0)==0;M=256-m|0;N=c[2113070]|0;S=c[3529496]|0;O=c[2113068]|0;U=r;I=1;J=j;while(1){L35097:do{if((J|0)>-1&(J|0)<(N|0)){L=ag(O,J)|0;H=15;K=i;while(1){do{if((K|0)>-1&(K|0)<(O|0)){F=a[U+H|0]|0;if(F<<24>>24==0){break}t=S+(K+L<<2)|0;f=c[t>>2]|0;s=c[h+((F&255)+o<<2)>>2]|0;if(P){X=f}else{F=ag(s&16711935,m)|0;x=F+(ag(f&16711935,M)|0)&-16711936;F=ag(s&65280,m)|0;X=(x|F+(ag(f&65280,M)|0)&16711680)>>>8}c[t>>2]=X}}while(0);if((H|0)<=0){break L35097}H=H-1|0;K=K+1|0}}}while(0);if((I|0)>=16){break}U=U+q|0;I=I+1|0;J=J+1|0}return}J=c[2113070]|0;I=c[3529496]|0;U=c[2113068]|0;X=r;M=1;P=j;while(1){L35115:do{if((P|0)>-1&(P|0)<(J|0)){S=ag(U,P)|0;O=15;N=i;while(1){do{if((N|0)>-1&(N|0)<(U|0)){K=a[X+O|0]|0;H=K&255;if(K<<24>>24==0){break}K=a[14115392+H|0]|0;if(K<<24>>24==-1){c[I+(N+S<<2)>>2]=c[h+(H+o<<2)>>2];break}L=K&255;t=I+(N+S<<2)|0;f=c[t>>2]|0;F=c[h+(H+o<<2)>>2]|0;if(K<<24>>24==0){Y=f}else{K=256-L|0;H=ag(F&16711935,L)|0;x=H+(ag(f&16711935,K)|0)&-16711936;H=ag(F&65280,L)|0;Y=(x|H+(ag(f&65280,K)|0)&16711680)>>>8}c[t>>2]=Y}}while(0);if((O|0)<=0){break L35115}O=O-1|0;N=N+1|0}}}while(0);if((M|0)>=16){break}X=X+q|0;M=M+1|0;P=P+1|0}return}else{if(V){P=c[2113070]|0;M=c[3529496]|0;X=c[2113068]|0;Y=r;I=1;U=j;while(1){L35138:do{if((U|0)>-1&(U|0)<(P|0)){J=ag(X,U)|0;N=0;O=i;while(1){do{if((O|0)>-1&(O|0)<(X|0)){S=a[Y+N|0]|0;if(S<<24>>24==0){break}c[M+(O+J<<2)>>2]=c[h+((S&255)+o<<2)>>2]}}while(0);S=N+1|0;if((S|0)>=16){break L35138}N=S;O=O+1|0}}}while(0);if((I|0)>=16){break}Y=Y+q|0;I=I+1|0;U=U+1|0}return}if((m|0)>-1){U=(m|0)==0;I=256-m|0;Y=c[2113070]|0;M=c[3529496]|0;X=c[2113068]|0;P=r;O=1;N=j;while(1){L35155:do{if((N|0)>-1&(N|0)<(Y|0)){J=ag(X,N)|0;S=0;t=i;while(1){do{if((t|0)>-1&(t|0)<(X|0)){K=a[P+S|0]|0;if(K<<24>>24==0){break}f=M+(t+J<<2)|0;H=c[f>>2]|0;x=c[h+((K&255)+o<<2)>>2]|0;if(U){Z=H}else{K=ag(x&16711935,m)|0;L=K+(ag(H&16711935,I)|0)&-16711936;K=ag(x&65280,m)|0;Z=(L|K+(ag(H&65280,I)|0)&16711680)>>>8}c[f>>2]=Z}}while(0);f=S+1|0;if((f|0)>=16){break L35155}S=f;t=t+1|0}}}while(0);if((O|0)>=16){break}P=P+q|0;O=O+1|0;N=N+1|0}return}N=c[2113070]|0;O=c[3529496]|0;P=c[2113068]|0;Z=r;I=j;U=1;while(1){L35173:do{if((I|0)>-1&(I|0)<(N|0)){M=ag(P,I)|0;X=i;Y=0;while(1){do{if((X|0)>-1&(X|0)<(P|0)){t=a[Z+Y|0]|0;S=t&255;if(t<<24>>24==0){break}t=a[14115392+S|0]|0;if(t<<24>>24==-1){c[O+(X+M<<2)>>2]=c[h+(S+o<<2)>>2];break}J=t&255;f=O+(X+M<<2)|0;H=c[f>>2]|0;K=c[h+(S+o<<2)>>2]|0;if(t<<24>>24==0){_=H}else{t=256-J|0;S=ag(K&16711935,J)|0;L=S+(ag(H&16711935,t)|0)&-16711936;S=ag(K&65280,J)|0;_=(L|S+(ag(H&65280,t)|0)&16711680)>>>8}c[f>>2]=_}}while(0);f=Y+1|0;if((f|0)>=16){break L35173}X=X+1|0;Y=f}}}while(0);if((U|0)>=16){break}Z=Z+q|0;I=I+1|0;U=U+1|0}return}}if(W){if(V){W=n&65535;U=c[2113070]|0;I=c[3529496]|0;Z=c[2113068]|0;_=c[2387044]|0;O=r;P=1;N=j;while(1){L35198:do{if((N|0)>-1&(N|0)<(U|0)){Y=ag(Z,N)|0;X=15;M=i;while(1){do{if((M|0)>-1&(M|0)<(Z|0)){f=M+Y|0;t=_+(f<<1)|0;if((e[t>>1]|0|0)>(n|0)){break}H=a[O+X|0]|0;if(H<<24>>24==0){break}c[I+(f<<2)>>2]=c[h+((H&255)+o<<2)>>2];b[t>>1]=W}}while(0);if((X|0)<=0){break L35198}X=X-1|0;M=M+1|0}}}while(0);if((P|0)>=16){break}O=O+q|0;P=P+1|0;N=N+1|0}return}if((m|0)>-1){N=(m|0)==0;P=n&65535;O=256-m|0;W=c[2113070]|0;I=c[3529496]|0;_=c[2113068]|0;Z=c[2387044]|0;U=r;M=1;X=j;while(1){L35216:do{if((X|0)>-1&(X|0)<(W|0)){Y=ag(_,X)|0;t=15;H=i;while(1){do{if((H|0)>-1&(H|0)<(_|0)){f=H+Y|0;S=Z+(f<<1)|0;if((e[S>>1]|0|0)>(n|0)){break}L=a[U+t|0]|0;if(L<<24>>24==0){break}J=I+(f<<2)|0;f=c[J>>2]|0;K=c[h+((L&255)+o<<2)>>2]|0;if(N){$=f}else{L=ag(K&16711935,m)|0;x=L+(ag(f&16711935,O)|0)&-16711936;L=ag(K&65280,m)|0;$=(x|L+(ag(f&65280,O)|0)&16711680)>>>8}c[J>>2]=$;b[S>>1]=P}}while(0);if((t|0)<=0){break L35216}t=t-1|0;H=H+1|0}}}while(0);if((M|0)>=16){break}U=U+q|0;M=M+1|0;X=X+1|0}return}X=n&65535;M=c[2113070]|0;U=c[3529496]|0;P=c[2113068]|0;$=c[2387044]|0;O=r;N=1;I=j;while(1){L35235:do{if((I|0)>-1&(I|0)<(M|0)){Z=ag(P,I)|0;_=15;W=i;while(1){do{if((W|0)>-1&(W|0)<(P|0)){H=W+Z|0;t=$+(H<<1)|0;if((e[t>>1]|0|0)>(n|0)){break}Y=a[O+_|0]|0;S=Y&255;if(Y<<24>>24==0){break}Y=a[14115392+S|0]|0;if(Y<<24>>24==-1){c[U+(H<<2)>>2]=c[h+(S+o<<2)>>2]}else{J=Y&255;f=U+(H<<2)|0;H=c[f>>2]|0;L=c[h+(S+o<<2)>>2]|0;if(Y<<24>>24==0){aa=H}else{Y=256-J|0;S=ag(L&16711935,J)|0;x=S+(ag(H&16711935,Y)|0)&-16711936;S=ag(L&65280,J)|0;aa=(x|S+(ag(H&65280,Y)|0)&16711680)>>>8}c[f>>2]=aa}b[t>>1]=X}}while(0);if((_|0)<=0){break L35235}_=_-1|0;W=W+1|0}}}while(0);if((N|0)>=16){break}O=O+q|0;N=N+1|0;I=I+1|0}return}else{if(V){V=n&65535;I=c[2113070]|0;N=c[3529496]|0;O=c[2113068]|0;X=c[2387044]|0;aa=r;U=1;$=j;while(1){L35260:do{if(($|0)>-1&($|0)<(I|0)){P=ag(O,$)|0;M=0;W=i;while(1){do{if((W|0)>-1&(W|0)<(O|0)){_=W+P|0;Z=X+(_<<1)|0;if((e[Z>>1]|0|0)>(n|0)){break}t=a[aa+M|0]|0;if(t<<24>>24==0){break}c[N+(_<<2)>>2]=c[h+((t&255)+o<<2)>>2];b[Z>>1]=V}}while(0);Z=M+1|0;if((Z|0)>=16){break L35260}M=Z;W=W+1|0}}}while(0);if((U|0)>=16){break}aa=aa+q|0;U=U+1|0;$=$+1|0}return}if((m|0)>-1){$=(m|0)==0;U=n&65535;aa=256-m|0;V=c[2113070]|0;N=c[3529496]|0;X=c[2113068]|0;O=c[2387044]|0;I=r;W=1;M=j;while(1){L35278:do{if((M|0)>-1&(M|0)<(V|0)){P=ag(X,M)|0;Z=0;t=i;while(1){do{if((t|0)>-1&(t|0)<(X|0)){_=t+P|0;f=O+(_<<1)|0;if((e[f>>1]|0|0)>(n|0)){break}Y=a[I+Z|0]|0;if(Y<<24>>24==0){break}H=N+(_<<2)|0;_=c[H>>2]|0;S=c[h+((Y&255)+o<<2)>>2]|0;if($){ab=_}else{Y=ag(S&16711935,m)|0;x=Y+(ag(_&16711935,aa)|0)&-16711936;Y=ag(S&65280,m)|0;ab=(x|Y+(ag(_&65280,aa)|0)&16711680)>>>8}c[H>>2]=ab;b[f>>1]=U}}while(0);f=Z+1|0;if((f|0)>=16){break L35278}Z=f;t=t+1|0}}}while(0);if((W|0)>=16){break}I=I+q|0;W=W+1|0;M=M+1|0}return}M=n&65535;W=c[2113070]|0;I=c[3529496]|0;U=c[2113068]|0;ab=c[2387044]|0;aa=r;r=1;$=j;while(1){L35297:do{if(($|0)>-1&($|0)<(W|0)){N=ag(U,$)|0;O=0;X=i;while(1){do{if((X|0)>-1&(X|0)<(U|0)){V=X+N|0;t=ab+(V<<1)|0;if((e[t>>1]|0|0)>(n|0)){break}Z=a[aa+O|0]|0;P=Z&255;if(Z<<24>>24==0){break}Z=a[14115392+P|0]|0;if(Z<<24>>24==-1){c[I+(V<<2)>>2]=c[h+(P+o<<2)>>2]}else{f=Z&255;H=I+(V<<2)|0;V=c[H>>2]|0;_=c[h+(P+o<<2)>>2]|0;if(Z<<24>>24==0){ac=V}else{Z=256-f|0;P=ag(_&16711935,f)|0;Y=P+(ag(V&16711935,Z)|0)&-16711936;P=ag(_&65280,f)|0;ac=(Y|P+(ag(V&65280,Z)|0)&16711680)>>>8}c[H>>2]=ac}b[t>>1]=M}}while(0);t=O+1|0;if((t|0)>=16){break L35297}O=t;X=X+1|0}}}while(0);if((r|0)>=16){break}aa=aa+q|0;r=r+1|0;$=$+1|0}return}}$=c[2439216]|0;r=(g&524287)-$|0;if((r|0)<0|(r|0)>(c[2438158]|0)){return}if(((d[(c[3527248]|0)+(r>>3)|0]|0)&1<<(g-$&7)|0)!=0){return}$=r<<7;r=(l|0)==0;l=r?8:-8;g=(c[2112938]|0)+(r?$:$|120)|0;do{if((i|0)>-1){$=c[2113068]|0;if(!(($-15|0)>(i|0)&(j|0)>-1)){break}if(((c[2113070]|0)-15|0)<(j|0)){break}r=(k|0)!=0;q=(m|0)==255;if((n|0)<=0){if(r){if(q){aa=c[3529496]|0;M=0;ac=aa+((ag($,j)|0)<<2)|0;aa=g;while(1){I=15;ab=i;while(1){U=d[aa+(I>>1)|0]|0;W=(I&1|0)==0?U>>>4:U&15;if((W|0)!=0){c[ac+(ab<<2)>>2]=c[h+((W|o)<<2)>>2]}if((I|0)>0){I=I-1|0;ab=ab+1|0}else{break}}ab=M+1|0;if((ab|0)<16){M=ab;ac=ac+($<<2)|0;aa=aa+l|0}else{break}}return}aa=c[3529496]|0;ac=aa+((ag($,j)|0)<<2)|0;if((m|0)>-1){aa=(m|0)==0;M=256-m|0;ab=0;I=ac;W=g;while(1){U=15;X=i;while(1){O=d[W+(U>>1)|0]|0;N=(U&1|0)==0?O>>>4:O&15;if((N|0)!=0){O=I+(X<<2)|0;t=c[O>>2]|0;H=c[h+((N|o)<<2)>>2]|0;if(aa){ad=t}else{N=ag(H&16711935,m)|0;Z=N+(ag(t&16711935,M)|0)&-16711936;N=ag(H&65280,m)|0;ad=(Z|N+(ag(t&65280,M)|0)&16711680)>>>8}c[O>>2]=ad}if((U|0)>0){U=U-1|0;X=X+1|0}else{break}}X=ab+1|0;if((X|0)<16){ab=X;I=I+($<<2)|0;W=W+l|0}else{break}}return}else{ae=0;af=ac;ah=g}while(1){W=15;I=i;while(1){ab=d[ah+(W>>1)|0]|0;M=(W&1|0)==0?ab>>>4:ab&15;do{if((M|0)!=0){ab=a[14115392+M|0]|0;if(ab<<24>>24==-1){c[af+(I<<2)>>2]=c[h+((M|o)<<2)>>2];break}aa=ab&255;X=af+(I<<2)|0;U=c[X>>2]|0;O=c[h+((M|o)<<2)>>2]|0;if(ab<<24>>24==0){ai=U}else{ab=256-aa|0;t=ag(O&16711935,aa)|0;N=t+(ag(U&16711935,ab)|0)&-16711936;t=ag(O&65280,aa)|0;ai=(N|t+(ag(U&65280,ab)|0)&16711680)>>>8}c[X>>2]=ai}}while(0);if((W|0)>0){W=W-1|0;I=I+1|0}else{break}}I=ae+1|0;if((I|0)<16){ae=I;af=af+($<<2)|0;ah=ah+l|0}else{break}}return}else{if(q){ac=c[3529496]|0;I=0;W=ac+((ag($,j)|0)<<2)|0;ac=g;while(1){M=0;X=i;while(1){ab=d[ac+(M>>1)|0]|0;U=(M&1|0)==0?ab>>>4:ab&15;if((U|0)!=0){c[W+(X<<2)>>2]=c[h+((U|o)<<2)>>2]}U=M+1|0;if((U|0)<16){M=U;X=X+1|0}else{break}}X=I+1|0;if((X|0)<16){I=X;W=W+($<<2)|0;ac=ac+l|0}else{break}}return}ac=c[3529496]|0;W=ac+((ag($,j)|0)<<2)|0;if((m|0)>-1){ac=(m|0)==0;I=256-m|0;X=0;M=W;U=g;while(1){ab=0;t=i;while(1){N=d[U+(ab>>1)|0]|0;aa=(ab&1|0)==0?N>>>4:N&15;if((aa|0)!=0){N=M+(t<<2)|0;O=c[N>>2]|0;Z=c[h+((aa|o)<<2)>>2]|0;if(ac){aj=O}else{aa=ag(Z&16711935,m)|0;H=aa+(ag(O&16711935,I)|0)&-16711936;aa=ag(Z&65280,m)|0;aj=(H|aa+(ag(O&65280,I)|0)&16711680)>>>8}c[N>>2]=aj}N=ab+1|0;if((N|0)<16){ab=N;t=t+1|0}else{break}}t=X+1|0;if((t|0)<16){X=t;M=M+($<<2)|0;U=U+l|0}else{break}}return}else{ak=0;al=W;am=g}while(1){U=0;M=i;while(1){X=d[am+(U>>1)|0]|0;I=(U&1|0)==0?X>>>4:X&15;do{if((I|0)!=0){X=a[14115392+I|0]|0;if(X<<24>>24==-1){c[al+(M<<2)>>2]=c[h+((I|o)<<2)>>2];break}ac=X&255;t=al+(M<<2)|0;ab=c[t>>2]|0;N=c[h+((I|o)<<2)>>2]|0;if(X<<24>>24==0){an=ab}else{X=256-ac|0;O=ag(N&16711935,ac)|0;aa=O+(ag(ab&16711935,X)|0)&-16711936;O=ag(N&65280,ac)|0;an=(aa|O+(ag(ab&65280,X)|0)&16711680)>>>8}c[t>>2]=an}}while(0);I=U+1|0;if((I|0)<16){U=I;M=M+1|0}else{break}}M=ak+1|0;if((M|0)<16){ak=M;al=al+($<<2)|0;am=am+l|0}else{break}}return}}if(r){if(q){W=c[3529496]|0;M=ag($,j)|0;U=n&65535;I=0;t=(c[2387044]|0)+(M<<1)|0;X=W+(M<<2)|0;M=g;while(1){W=15;ab=i;while(1){O=t+(ab<<1)|0;do{if((e[O>>1]|0|0)<=(n|0)){aa=d[M+(W>>1)|0]|0;ac=(W&1|0)==0?aa>>>4:aa&15;if((ac|0)==0){break}c[X+(ab<<2)>>2]=c[h+((ac|o)<<2)>>2];b[O>>1]=U}}while(0);if((W|0)>0){W=W-1|0;ab=ab+1|0}else{break}}ab=I+1|0;if((ab|0)<16){I=ab;t=t+($<<1)|0;X=X+($<<2)|0;M=M+l|0}else{break}}return}M=c[3529496]|0;X=ag($,j)|0;t=M+(X<<2)|0;M=(c[2387044]|0)+(X<<1)|0;if((m|0)>-1){X=(m|0)==0;I=n&65535;U=256-m|0;r=0;ab=M;W=t;O=g;while(1){ac=15;aa=i;while(1){N=ab+(aa<<1)|0;do{if((e[N>>1]|0|0)<=(n|0)){H=d[O+(ac>>1)|0]|0;Z=(ac&1|0)==0?H>>>4:H&15;if((Z|0)==0){break}H=W+(aa<<2)|0;V=c[H>>2]|0;P=c[h+((Z|o)<<2)>>2]|0;if(X){ao=V}else{Z=ag(P&16711935,m)|0;Y=Z+(ag(V&16711935,U)|0)&-16711936;Z=ag(P&65280,m)|0;ao=(Y|Z+(ag(V&65280,U)|0)&16711680)>>>8}c[H>>2]=ao;b[N>>1]=I}}while(0);if((ac|0)>0){ac=ac-1|0;aa=aa+1|0}else{break}}aa=r+1|0;if((aa|0)<16){r=aa;ab=ab+($<<1)|0;W=W+($<<2)|0;O=O+l|0}else{break}}return}O=n&65535;W=0;ab=M;r=t;I=g;while(1){U=15;X=i;while(1){aa=ab+(X<<1)|0;do{if((e[aa>>1]|0|0)<=(n|0)){ac=d[I+(U>>1)|0]|0;N=(U&1|0)==0?ac>>>4:ac&15;if((N|0)==0){break}ac=a[14115392+N|0]|0;if(ac<<24>>24==-1){c[r+(X<<2)>>2]=c[h+((N|o)<<2)>>2]}else{H=ac&255;V=r+(X<<2)|0;Z=c[V>>2]|0;Y=c[h+((N|o)<<2)>>2]|0;if(ac<<24>>24==0){ap=Z}else{ac=256-H|0;N=ag(Y&16711935,H)|0;P=N+(ag(Z&16711935,ac)|0)&-16711936;N=ag(Y&65280,H)|0;ap=(P|N+(ag(Z&65280,ac)|0)&16711680)>>>8}c[V>>2]=ap}b[aa>>1]=O}}while(0);if((U|0)>0){U=U-1|0;X=X+1|0}else{break}}X=W+1|0;if((X|0)<16){W=X;ab=ab+($<<1)|0;r=r+($<<2)|0;I=I+l|0}else{break}}return}else{if(q){I=c[3529496]|0;r=ag($,j)|0;ab=n&65535;W=0;O=(c[2387044]|0)+(r<<1)|0;t=I+(r<<2)|0;r=g;while(1){I=0;M=i;while(1){X=O+(M<<1)|0;do{if((e[X>>1]|0|0)<=(n|0)){U=d[r+(I>>1)|0]|0;aa=(I&1|0)==0?U>>>4:U&15;if((aa|0)==0){break}c[t+(M<<2)>>2]=c[h+((aa|o)<<2)>>2];b[X>>1]=ab}}while(0);X=I+1|0;if((X|0)<16){I=X;M=M+1|0}else{break}}M=W+1|0;if((M|0)<16){W=M;O=O+($<<1)|0;t=t+($<<2)|0;r=r+l|0}else{break}}return}r=c[3529496]|0;t=ag($,j)|0;O=r+(t<<2)|0;r=(c[2387044]|0)+(t<<1)|0;if((m|0)>-1){t=(m|0)==0;W=n&65535;ab=256-m|0;q=0;M=r;I=O;X=g;while(1){aa=0;U=i;while(1){V=M+(U<<1)|0;do{if((e[V>>1]|0|0)<=(n|0)){ac=d[X+(aa>>1)|0]|0;Z=(aa&1|0)==0?ac>>>4:ac&15;if((Z|0)==0){break}ac=I+(U<<2)|0;N=c[ac>>2]|0;P=c[h+((Z|o)<<2)>>2]|0;if(t){aq=N}else{Z=ag(P&16711935,m)|0;H=Z+(ag(N&16711935,ab)|0)&-16711936;Z=ag(P&65280,m)|0;aq=(H|Z+(ag(N&65280,ab)|0)&16711680)>>>8}c[ac>>2]=aq;b[V>>1]=W}}while(0);V=aa+1|0;if((V|0)<16){aa=V;U=U+1|0}else{break}}U=q+1|0;if((U|0)<16){q=U;M=M+($<<1)|0;I=I+($<<2)|0;X=X+l|0}else{break}}return}X=n&65535;I=0;M=r;q=O;W=g;while(1){ab=0;t=i;while(1){U=M+(t<<1)|0;do{if((e[U>>1]|0|0)<=(n|0)){aa=d[W+(ab>>1)|0]|0;V=(ab&1|0)==0?aa>>>4:aa&15;if((V|0)==0){break}aa=a[14115392+V|0]|0;if(aa<<24>>24==-1){c[q+(t<<2)>>2]=c[h+((V|o)<<2)>>2]}else{ac=aa&255;N=q+(t<<2)|0;Z=c[N>>2]|0;H=c[h+((V|o)<<2)>>2]|0;if(aa<<24>>24==0){ar=Z}else{aa=256-ac|0;V=ag(H&16711935,ac)|0;P=V+(ag(Z&16711935,aa)|0)&-16711936;V=ag(H&65280,ac)|0;ar=(P|V+(ag(Z&65280,aa)|0)&16711680)>>>8}c[N>>2]=ar}b[U>>1]=X}}while(0);U=ab+1|0;if((U|0)<16){ab=U;t=t+1|0}else{break}}t=I+1|0;if((t|0)<16){I=t;M=M+($<<1)|0;q=q+($<<2)|0;W=W+l|0}else{break}}return}}}while(0);ar=(k|0)!=0;k=(m|0)==255;if((n|0)<=0){if(ar){if(k){aq=c[2113070]|0;ap=c[3529496]|0;ao=c[2113068]|0;am=1;al=g;ak=j;while(1){L35520:do{if((ak|0)>-1&(ak|0)<(aq|0)){an=ag(ao,ak)|0;aj=15;ah=i;while(1){do{if((ah|0)>-1&(ah|0)<(ao|0)){af=d[al+(aj>>1)|0]|0;ae=(aj&1|0)==0?af>>>4:af&15;if((ae|0)==0){break}c[ap+(ah+an<<2)>>2]=c[h+((ae|o)<<2)>>2]}}while(0);if((aj|0)<=0){break L35520}aj=aj-1|0;ah=ah+1|0}}}while(0);if((am|0)>=16){break}am=am+1|0;al=al+l|0;ak=ak+1|0}return}if((m|0)>-1){ak=(m|0)==0;al=256-m|0;am=c[2113070]|0;ap=c[3529496]|0;ao=c[2113068]|0;aq=1;ah=g;aj=j;while(1){L35537:do{if((aj|0)>-1&(aj|0)<(am|0)){an=ag(ao,aj)|0;if(ak){break}else{as=15;at=i}while(1){do{if((at|0)>-1&(at|0)<(ao|0)){ae=d[ah+(as>>1)|0]|0;af=(as&1|0)==0?ae>>>4:ae&15;if((af|0)==0){break}ae=ap+(at+an<<2)|0;ai=c[ae>>2]|0;ad=c[h+((af|o)<<2)>>2]|0;af=ag(ad&16711935,m)|0;W=af+(ag(ai&16711935,al)|0)&-16711936;af=ag(ad&65280,m)|0;c[ae>>2]=(W|af+(ag(ai&65280,al)|0)&16711680)>>>8}}while(0);if((as|0)<=0){break L35537}as=as-1|0;at=at+1|0}}}while(0);if((aq|0)>=16){break}aq=aq+1|0;ah=ah+l|0;aj=aj+1|0}return}aj=c[2113070]|0;ah=c[3529496]|0;aq=c[2113068]|0;at=1;as=g;al=j;while(1){L35552:do{if((al|0)>-1&(al|0)<(aj|0)){ap=ag(aq,al)|0;ao=15;ak=i;while(1){do{if((ak|0)>-1&(ak|0)<(aq|0)){am=d[as+(ao>>1)|0]|0;an=(ao&1|0)==0?am>>>4:am&15;if((an|0)==0){break}am=a[14115392+an|0]|0;if(am<<24>>24==-1){c[ah+(ak+ap<<2)>>2]=c[h+((an|o)<<2)>>2];break}ai=am&255;af=ah+(ak+ap<<2)|0;W=c[af>>2]|0;ae=c[h+((an|o)<<2)>>2]|0;if(am<<24>>24==0){au=W}else{am=256-ai|0;an=ag(ae&16711935,ai)|0;ad=an+(ag(W&16711935,am)|0)&-16711936;an=ag(ae&65280,ai)|0;au=(ad|an+(ag(W&65280,am)|0)&16711680)>>>8}c[af>>2]=au}}while(0);if((ao|0)<=0){break L35552}ao=ao-1|0;ak=ak+1|0}}}while(0);if((at|0)>=16){break}at=at+1|0;as=as+l|0;al=al+1|0}return}if(k){al=c[2113070]|0;as=c[3529496]|0;at=c[2113068]|0;au=1;ah=g;aq=j;while(1){L35575:do{if((aq|0)>-1&(aq|0)<(al|0)){aj=ag(at,aq)|0;ak=0;ao=i;while(1){do{if((ao|0)>-1&(ao|0)<(at|0)){ap=d[ah+(ak>>1)|0]|0;af=(ak&1|0)==0?ap>>>4:ap&15;if((af|0)==0){break}c[as+(ao+aj<<2)>>2]=c[h+((af|o)<<2)>>2]}}while(0);af=ak+1|0;if((af|0)>=16){break L35575}ak=af;ao=ao+1|0}}}while(0);if((au|0)>=16){break}au=au+1|0;ah=ah+l|0;aq=aq+1|0}return}if((m|0)>-1){aq=(m|0)==0;ah=256-m|0;au=c[2113070]|0;as=c[3529496]|0;at=c[2113068]|0;al=1;ao=g;ak=j;while(1){L35592:do{if((ak|0)>-1&(ak|0)<(au|0)){aj=ag(at,ak)|0;af=0;ap=i;while(1){do{if((ap|0)>-1&(ap|0)<(at|0)){am=d[ao+(af>>1)|0]|0;W=(af&1|0)==0?am>>>4:am&15;if((W|0)==0){break}am=as+(ap+aj<<2)|0;an=c[am>>2]|0;ad=c[h+((W|o)<<2)>>2]|0;if(aq){av=an}else{W=ag(ad&16711935,m)|0;ai=W+(ag(an&16711935,ah)|0)&-16711936;W=ag(ad&65280,m)|0;av=(ai|W+(ag(an&65280,ah)|0)&16711680)>>>8}c[am>>2]=av}}while(0);am=af+1|0;if((am|0)>=16){break L35592}af=am;ap=ap+1|0}}}while(0);if((al|0)>=16){break}al=al+1|0;ao=ao+l|0;ak=ak+1|0}return}ak=c[2113070]|0;ao=c[3529496]|0;al=c[2113068]|0;av=1;ah=g;aq=j;while(1){L35610:do{if((aq|0)>-1&(aq|0)<(ak|0)){as=ag(al,aq)|0;at=0;au=i;while(1){do{if((au|0)>-1&(au|0)<(al|0)){ap=d[ah+(at>>1)|0]|0;af=(at&1|0)==0?ap>>>4:ap&15;if((af|0)==0){break}ap=a[14115392+af|0]|0;if(ap<<24>>24==-1){c[ao+(au+as<<2)>>2]=c[h+((af|o)<<2)>>2];break}aj=ap&255;am=ao+(au+as<<2)|0;an=c[am>>2]|0;W=c[h+((af|o)<<2)>>2]|0;if(ap<<24>>24==0){aw=an}else{ap=256-aj|0;af=ag(W&16711935,aj)|0;ai=af+(ag(an&16711935,ap)|0)&-16711936;af=ag(W&65280,aj)|0;aw=(ai|af+(ag(an&65280,ap)|0)&16711680)>>>8}c[am>>2]=aw}}while(0);am=at+1|0;if((am|0)>=16){break L35610}at=am;au=au+1|0}}}while(0);if((av|0)>=16){break}av=av+1|0;ah=ah+l|0;aq=aq+1|0}return}if(ar){if(k){ar=n&65535;aq=c[2113070]|0;ah=c[3529496]|0;av=c[2113068]|0;aw=c[2387044]|0;ao=1;al=g;ak=j;while(1){L35635:do{if((ak|0)>-1&(ak|0)<(aq|0)){au=ag(av,ak)|0;at=15;as=i;while(1){do{if((as|0)>-1&(as|0)<(av|0)){am=as+au|0;ap=aw+(am<<1)|0;if((e[ap>>1]|0|0)>(n|0)){break}an=d[al+(at>>1)|0]|0;af=(at&1|0)==0?an>>>4:an&15;if((af|0)==0){break}c[ah+(am<<2)>>2]=c[h+((af|o)<<2)>>2];b[ap>>1]=ar}}while(0);if((at|0)<=0){break L35635}at=at-1|0;as=as+1|0}}}while(0);if((ao|0)>=16){break}ao=ao+1|0;al=al+l|0;ak=ak+1|0}return}if((m|0)<=-1){ak=n&65535;al=c[2113070]|0;ao=c[3529496]|0;ar=c[2113068]|0;ah=c[2387044]|0;aw=1;av=g;aq=j;while(1){L35653:do{if((aq|0)>-1&(aq|0)<(al|0)){as=ag(ar,aq)|0;at=15;au=i;while(1){do{if((au|0)>-1&(au|0)<(ar|0)){ap=au+as|0;af=ah+(ap<<1)|0;if((e[af>>1]|0|0)>(n|0)){break}am=d[av+(at>>1)|0]|0;an=(at&1|0)==0?am>>>4:am&15;if((an|0)==0){break}am=a[14115392+an|0]|0;if(am<<24>>24==-1){c[ao+(ap<<2)>>2]=c[h+((an|o)<<2)>>2]}else{ai=am&255;aj=ao+(ap<<2)|0;ap=c[aj>>2]|0;W=c[h+((an|o)<<2)>>2]|0;if(am<<24>>24==0){ax=ap}else{am=256-ai|0;an=ag(W&16711935,ai)|0;ad=an+(ag(ap&16711935,am)|0)&-16711936;an=ag(W&65280,ai)|0;ax=(ad|an+(ag(ap&65280,am)|0)&16711680)>>>8}c[aj>>2]=ax}b[af>>1]=ak}}while(0);if((at|0)<=0){break L35653}at=at-1|0;au=au+1|0}}}while(0);if((aw|0)>=16){break}aw=aw+1|0;av=av+l|0;aq=aq+1|0}return}aq=(m|0)==0;av=n&65535;aw=256-m|0;ak=c[2113070]|0;ax=c[3529496]|0;ao=c[2113068]|0;ah=c[2387044]|0;ar=1;al=g;au=j;while(1){L35676:do{if((au|0)>-1&(au|0)<(ak|0)){at=ag(ao,au)|0;if(aq){as=15;af=i;while(1){do{if((af|0)>-1&(af|0)<(ao|0)){aj=ah+(af+at<<1)|0;if((e[aj>>1]|0|0)>(n|0)){break}am=d[al+(as>>1)|0]|0;if((((as&1|0)==0?am>>>4:am&15)|0)==0){break}b[aj>>1]=av}}while(0);if((as|0)<=0){break L35676}as=as-1|0;af=af+1|0}}else{af=15;as=i;while(1){do{if((as|0)>-1&(as|0)<(ao|0)){aj=as+at|0;am=ah+(aj<<1)|0;if((e[am>>1]|0|0)>(n|0)){break}ap=d[al+(af>>1)|0]|0;an=(af&1|0)==0?ap>>>4:ap&15;if((an|0)==0){break}ap=ax+(aj<<2)|0;aj=c[ap>>2]|0;ad=c[h+((an|o)<<2)>>2]|0;an=ag(ad&16711935,m)|0;ai=an+(ag(aj&16711935,aw)|0)&-16711936;an=ag(ad&65280,m)|0;c[ap>>2]=(ai|an+(ag(aj&65280,aw)|0)&16711680)>>>8;b[am>>1]=av}}while(0);if((af|0)<=0){break L35676}af=af-1|0;as=as+1|0}}}}while(0);if((ar|0)>=16){break}ar=ar+1|0;al=al+l|0;au=au+1|0}return}else{if(k){k=n&65535;au=c[2113070]|0;al=c[3529496]|0;ar=c[2113068]|0;av=c[2387044]|0;aw=1;ax=g;ah=j;while(1){L35703:do{if((ah|0)>-1&(ah|0)<(au|0)){ao=ag(ar,ah)|0;aq=0;ak=i;while(1){do{if((ak|0)>-1&(ak|0)<(ar|0)){as=ak+ao|0;af=av+(as<<1)|0;if((e[af>>1]|0|0)>(n|0)){break}at=d[ax+(aq>>1)|0]|0;am=(aq&1|0)==0?at>>>4:at&15;if((am|0)==0){break}c[al+(as<<2)>>2]=c[h+((am|o)<<2)>>2];b[af>>1]=k}}while(0);af=aq+1|0;if((af|0)>=16){break L35703}aq=af;ak=ak+1|0}}}while(0);if((aw|0)>=16){break}aw=aw+1|0;ax=ax+l|0;ah=ah+1|0}return}if((m|0)<=-1){ah=n&65535;ax=c[2113070]|0;aw=c[3529496]|0;k=c[2113068]|0;al=c[2387044]|0;av=1;ar=g;au=j;while(1){L35721:do{if((au|0)>-1&(au|0)<(ax|0)){ak=ag(k,au)|0;aq=0;ao=i;while(1){do{if((ao|0)>-1&(ao|0)<(k|0)){af=ao+ak|0;am=al+(af<<1)|0;if((e[am>>1]|0|0)>(n|0)){break}as=d[ar+(aq>>1)|0]|0;at=(aq&1|0)==0?as>>>4:as&15;if((at|0)==0){break}as=a[14115392+at|0]|0;if(as<<24>>24==-1){c[aw+(af<<2)>>2]=c[h+((at|o)<<2)>>2]}else{aj=as&255;an=aw+(af<<2)|0;af=c[an>>2]|0;ai=c[h+((at|o)<<2)>>2]|0;if(as<<24>>24==0){ay=af}else{as=256-aj|0;at=ag(ai&16711935,aj)|0;ap=at+(ag(af&16711935,as)|0)&-16711936;at=ag(ai&65280,aj)|0;ay=(ap|at+(ag(af&65280,as)|0)&16711680)>>>8}c[an>>2]=ay}b[am>>1]=ah}}while(0);am=aq+1|0;if((am|0)>=16){break L35721}aq=am;ao=ao+1|0}}}while(0);if((av|0)>=16){break}av=av+1|0;ar=ar+l|0;au=au+1|0}return}au=(m|0)==0;ar=n&65535;av=256-m|0;ah=c[2113070]|0;ay=c[3529496]|0;aw=c[2113068]|0;al=c[2387044]|0;k=1;ax=g;g=j;while(1){L35744:do{if((g|0)>-1&(g|0)<(ah|0)){j=ag(aw,g)|0;if(au){ao=0;aq=i;while(1){do{if((aq|0)>-1&(aq|0)<(aw|0)){ak=al+(aq+j<<1)|0;if((e[ak>>1]|0|0)>(n|0)){break}am=d[ax+(ao>>1)|0]|0;if((((ao&1|0)==0?am>>>4:am&15)|0)==0){break}b[ak>>1]=ar}}while(0);ak=ao+1|0;if((ak|0)>=16){break L35744}ao=ak;aq=aq+1|0}}else{aq=0;ao=i;while(1){do{if((ao|0)>-1&(ao|0)<(aw|0)){ak=ao+j|0;am=al+(ak<<1)|0;if((e[am>>1]|0|0)>(n|0)){break}an=d[ax+(aq>>1)|0]|0;as=(aq&1|0)==0?an>>>4:an&15;if((as|0)==0){break}an=ay+(ak<<2)|0;ak=c[an>>2]|0;af=c[h+((as|o)<<2)>>2]|0;as=ag(af&16711935,m)|0;at=as+(ag(ak&16711935,av)|0)&-16711936;as=ag(af&65280,m)|0;c[an>>2]=(at|as+(ag(ak&65280,av)|0)&16711680)>>>8;b[am>>1]=ar}}while(0);am=aq+1|0;if((am|0)>=16){break L35744}aq=am;ao=ao+1|0}}}}while(0);if((k|0)>=16){break}k=k+1|0;ax=ax+l|0;g=g+1|0}return}}function dWp(){var d=0,e=0,f=0,g=0,h=0,i=0;d=c[2440386]|0;e=c[2415150]|0;f=0;g=c[2385338]|0;while(1){h=a[g]|0;if(h<<24>>24!=15){b[e>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+1|0]|0;if(h<<24>>24!=15){b[e+2>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+2|0]|0;if(h<<24>>24!=15){b[e+4>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+3|0]|0;if(h<<24>>24!=15){b[e+6>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+4|0]|0;if(h<<24>>24!=15){b[e+8>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+5|0]|0;if(h<<24>>24!=15){b[e+10>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+6|0]|0;if(h<<24>>24!=15){b[e+12>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+7|0]|0;if(h<<24>>24!=15){b[e+14>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+8|0]|0;if(h<<24>>24!=15){b[e+16>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+9|0]|0;if(h<<24>>24!=15){b[e+18>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+10|0]|0;if(h<<24>>24!=15){b[e+20>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+11|0]|0;if(h<<24>>24!=15){b[e+22>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+12|0]|0;if(h<<24>>24!=15){b[e+24>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+13|0]|0;if(h<<24>>24!=15){b[e+26>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+14|0]|0;if(h<<24>>24!=15){b[e+28>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+15|0]|0;if(h<<24>>24!=15){b[e+30>>1]=c[d+((h&255)<<2)>>2]&65535}h=f+1|0;i=g+16|0;if((h|0)<16){e=e+640|0;f=h;g=i}else{break}}c[2385338]=i;return}function dWq(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[2385456]|0;e=c[2385468]|0;f=e>>>0<320;g=c[2440386]|0;h=c[2415150]|0;i=0;L35819:while(1){j=d+i|0;do{if((j|0)>=0){if((j|0)>223){k=27075;break L35819}do{if(f){l=a[c[2385338]|0]|0;if(l<<24>>24==15){break}b[h>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+1|0)>>>0<320){l=a[(c[2385338]|0)+1|0]|0;if(l<<24>>24==15){break}b[h+2>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+2|0)>>>0<320){l=a[(c[2385338]|0)+2|0]|0;if(l<<24>>24==15){break}b[h+4>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+3|0)>>>0<320){l=a[(c[2385338]|0)+3|0]|0;if(l<<24>>24==15){break}b[h+6>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+4|0)>>>0<320){l=a[(c[2385338]|0)+4|0]|0;if(l<<24>>24==15){break}b[h+8>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+5|0)>>>0<320){l=a[(c[2385338]|0)+5|0]|0;if(l<<24>>24==15){break}b[h+10>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+6|0)>>>0<320){l=a[(c[2385338]|0)+6|0]|0;if(l<<24>>24==15){break}b[h+12>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+7|0)>>>0<320){l=a[(c[2385338]|0)+7|0]|0;if(l<<24>>24==15){break}b[h+14>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+8|0)>>>0<320){l=a[(c[2385338]|0)+8|0]|0;if(l<<24>>24==15){break}b[h+16>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+9|0)>>>0<320){l=a[(c[2385338]|0)+9|0]|0;if(l<<24>>24==15){break}b[h+18>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+10|0)>>>0<320){l=a[(c[2385338]|0)+10|0]|0;if(l<<24>>24==15){break}b[h+20>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+11|0)>>>0<320){l=a[(c[2385338]|0)+11|0]|0;if(l<<24>>24==15){break}b[h+22>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+12|0)>>>0<320){l=a[(c[2385338]|0)+12|0]|0;if(l<<24>>24==15){break}b[h+24>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+13|0)>>>0<320){l=a[(c[2385338]|0)+13|0]|0;if(l<<24>>24==15){break}b[h+26>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+14|0)>>>0<320){l=a[(c[2385338]|0)+14|0]|0;if(l<<24>>24==15){break}b[h+28>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);if((e+15|0)>>>0>=320){break}l=a[(c[2385338]|0)+15|0]|0;if(l<<24>>24==15){break}b[h+30>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);j=i+1|0;c[2385338]=(c[2385338]|0)+16;if((j|0)>=16){k=27076;break}h=h+640|0;i=j}if((k|0)==27075){return}else if((k|0)==27076){return}}function dWr(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;d=c[2415164]|0;f=c[2440386]|0;g=c[2415150]|0;h=c[2409606]|0;i=0;j=c[2385338]|0;while(1){k=a[j]|0;l=k&255;do{if(k<<24>>24==15){m=j}else{if((e[h>>1]|0|0)>(d|0)){m=j;break}b[g>>1]=c[f+(l<<2)>>2]&65535;m=j}}while(0);l=a[m+1|0]|0;k=l&255;do{if(l<<24>>24==15){n=m}else{if((e[h+2>>1]|0|0)>(d|0)){n=m;break}b[g+2>>1]=c[f+(k<<2)>>2]&65535;n=j}}while(0);k=a[n+2|0]|0;l=k&255;do{if(k<<24>>24==15){o=n}else{if((e[h+4>>1]|0|0)>(d|0)){o=n;break}b[g+4>>1]=c[f+(l<<2)>>2]&65535;o=j}}while(0);l=a[o+3|0]|0;k=l&255;do{if(l<<24>>24==15){p=o}else{if((e[h+6>>1]|0|0)>(d|0)){p=o;break}b[g+6>>1]=c[f+(k<<2)>>2]&65535;p=j}}while(0);k=a[p+4|0]|0;l=k&255;do{if(k<<24>>24==15){q=p}else{if((e[h+8>>1]|0|0)>(d|0)){q=p;break}b[g+8>>1]=c[f+(l<<2)>>2]&65535;q=j}}while(0);l=a[q+5|0]|0;k=l&255;do{if(l<<24>>24==15){r=q}else{if((e[h+10>>1]|0|0)>(d|0)){r=q;break}b[g+10>>1]=c[f+(k<<2)>>2]&65535;r=j}}while(0);k=a[r+6|0]|0;l=k&255;do{if(k<<24>>24==15){s=r}else{if((e[h+12>>1]|0|0)>(d|0)){s=r;break}b[g+12>>1]=c[f+(l<<2)>>2]&65535;s=j}}while(0);l=a[s+7|0]|0;k=l&255;do{if(l<<24>>24==15){t=s}else{if((e[h+14>>1]|0|0)>(d|0)){t=s;break}b[g+14>>1]=c[f+(k<<2)>>2]&65535;t=j}}while(0);k=a[t+8|0]|0;l=k&255;do{if(k<<24>>24==15){u=t}else{if((e[h+16>>1]|0|0)>(d|0)){u=t;break}b[g+16>>1]=c[f+(l<<2)>>2]&65535;u=j}}while(0);l=a[u+9|0]|0;k=l&255;do{if(l<<24>>24==15){v=u}else{if((e[h+18>>1]|0|0)>(d|0)){v=u;break}b[g+18>>1]=c[f+(k<<2)>>2]&65535;v=j}}while(0);k=a[v+10|0]|0;l=k&255;do{if(k<<24>>24==15){w=v}else{if((e[h+20>>1]|0|0)>(d|0)){w=v;break}b[g+20>>1]=c[f+(l<<2)>>2]&65535;w=j}}while(0);l=a[w+11|0]|0;k=l&255;do{if(l<<24>>24==15){x=w}else{if((e[h+22>>1]|0|0)>(d|0)){x=w;break}b[g+22>>1]=c[f+(k<<2)>>2]&65535;x=j}}while(0);k=a[x+12|0]|0;l=k&255;do{if(k<<24>>24==15){y=x}else{if((e[h+24>>1]|0|0)>(d|0)){y=x;break}b[g+24>>1]=c[f+(l<<2)>>2]&65535;y=j}}while(0);l=a[y+13|0]|0;k=l&255;do{if(l<<24>>24==15){z=y}else{if((e[h+26>>1]|0|0)>(d|0)){z=y;break}b[g+26>>1]=c[f+(k<<2)>>2]&65535;z=j}}while(0);k=a[z+14|0]|0;l=k&255;do{if(k<<24>>24==15){A=z}else{if((e[h+28>>1]|0|0)>(d|0)){A=z;break}b[g+28>>1]=c[f+(l<<2)>>2]&65535;A=j}}while(0);l=a[A+15|0]|0;k=l&255;do{if(l<<24>>24==15){B=A}else{if((e[h+30>>1]|0|0)>(d|0)){B=A;break}b[g+30>>1]=c[f+(k<<2)>>2]&65535;B=j}}while(0);k=i+1|0;C=B+16|0;if((k|0)<16){g=g+640|0;h=h+640|0;i=k;j=C}else{break}}c[2385338]=C;return}function dWs(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=c[2385456]|0;f=c[2385468]|0;g=f>>>0<320;h=c[2415164]|0;i=c[2440386]|0;j=c[2415150]|0;k=c[2409606]|0;l=0;L35960:while(1){m=d+l|0;do{if((m|0)>=0){if((m|0)>223){n=27198;break L35960}do{if(g){o=a[c[2385338]|0]|0;if(o<<24>>24==15){break}if((e[k>>1]|0|0)>(h|0)){break}b[j>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);do{if((f+1|0)>>>0<320){o=a[(c[2385338]|0)+1|0]|0;if(o<<24>>24==15){break}if((e[k+2>>1]|0|0)>(h|0)){break}b[j+2>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);do{if((f+2|0)>>>0<320){o=a[(c[2385338]|0)+2|0]|0;if(o<<24>>24==15){break}if((e[k+4>>1]|0|0)>(h|0)){break}b[j+4>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);do{if((f+3|0)>>>0<320){o=a[(c[2385338]|0)+3|0]|0;if(o<<24>>24==15){break}if((e[k+6>>1]|0|0)>(h|0)){break}b[j+6>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);do{if((f+4|0)>>>0<320){o=a[(c[2385338]|0)+4|0]|0;if(o<<24>>24==15){break}if((e[k+8>>1]|0|0)>(h|0)){break}b[j+8>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);do{if((f+5|0)>>>0<320){o=a[(c[2385338]|0)+5|0]|0;if(o<<24>>24==15){break}if((e[k+10>>1]|0|0)>(h|0)){break}b[j+10>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);do{if((f+6|0)>>>0<320){o=a[(c[2385338]|0)+6|0]|0;if(o<<24>>24==15){break}if((e[k+12>>1]|0|0)>(h|0)){break}b[j+12>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);do{if((f+7|0)>>>0<320){o=a[(c[2385338]|0)+7|0]|0;if(o<<24>>24==15){break}if((e[k+14>>1]|0|0)>(h|0)){break}b[j+14>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);do{if((f+8|0)>>>0<320){o=a[(c[2385338]|0)+8|0]|0;if(o<<24>>24==15){break}if((e[k+16>>1]|0|0)>(h|0)){break}b[j+16>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);do{if((f+9|0)>>>0<320){o=a[(c[2385338]|0)+9|0]|0;if(o<<24>>24==15){break}if((e[k+18>>1]|0|0)>(h|0)){break}b[j+18>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);do{if((f+10|0)>>>0<320){o=a[(c[2385338]|0)+10|0]|0;if(o<<24>>24==15){break}if((e[k+20>>1]|0|0)>(h|0)){break}b[j+20>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);do{if((f+11|0)>>>0<320){o=a[(c[2385338]|0)+11|0]|0;if(o<<24>>24==15){break}if((e[k+22>>1]|0|0)>(h|0)){break}b[j+22>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);do{if((f+12|0)>>>0<320){o=a[(c[2385338]|0)+12|0]|0;if(o<<24>>24==15){break}if((e[k+24>>1]|0|0)>(h|0)){break}b[j+24>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);do{if((f+13|0)>>>0<320){o=a[(c[2385338]|0)+13|0]|0;if(o<<24>>24==15){break}if((e[k+26>>1]|0|0)>(h|0)){break}b[j+26>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);do{if((f+14|0)>>>0<320){o=a[(c[2385338]|0)+14|0]|0;if(o<<24>>24==15){break}if((e[k+28>>1]|0|0)>(h|0)){break}b[j+28>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);if((f+15|0)>>>0>=320){break}o=a[(c[2385338]|0)+15|0]|0;if(o<<24>>24==15){break}if((e[k+30>>1]|0|0)>(h|0)){break}b[j+30>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);m=l+1|0;c[2385338]=(c[2385338]|0)+16;if((m|0)>=16){n=27199;break}j=j+640|0;k=k+640|0;l=m}if((n|0)==27198){return}else if((n|0)==27199){return}}function dWt(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=c[2415164]&65535;f=c[2440386]|0;g=c[2415150]|0;h=c[2409606]|0;i=0;j=c[2385338]|0;while(1){if((a[j]|0)!=15){b[h>>1]=e;b[g>>1]=c[f+(d[j]<<2)>>2]&65535}if((a[j+1|0]|0)!=15){b[h+2>>1]=e;b[g+2>>1]=c[f+(d[j+1|0]<<2)>>2]&65535}if((a[j+2|0]|0)!=15){b[h+4>>1]=e;b[g+4>>1]=c[f+(d[j+2|0]<<2)>>2]&65535}if((a[j+3|0]|0)!=15){b[h+6>>1]=e;b[g+6>>1]=c[f+(d[j+3|0]<<2)>>2]&65535}if((a[j+4|0]|0)!=15){b[h+8>>1]=e;b[g+8>>1]=c[f+(d[j+4|0]<<2)>>2]&65535}if((a[j+5|0]|0)!=15){b[h+10>>1]=e;b[g+10>>1]=c[f+(d[j+5|0]<<2)>>2]&65535}if((a[j+6|0]|0)!=15){b[h+12>>1]=e;b[g+12>>1]=c[f+(d[j+6|0]<<2)>>2]&65535}if((a[j+7|0]|0)!=15){b[h+14>>1]=e;b[g+14>>1]=c[f+(d[j+7|0]<<2)>>2]&65535}if((a[j+8|0]|0)!=15){b[h+16>>1]=e;b[g+16>>1]=c[f+(d[j+8|0]<<2)>>2]&65535}if((a[j+9|0]|0)!=15){b[h+18>>1]=e;b[g+18>>1]=c[f+(d[j+9|0]<<2)>>2]&65535}if((a[j+10|0]|0)!=15){b[h+20>>1]=e;b[g+20>>1]=c[f+(d[j+10|0]<<2)>>2]&65535}if((a[j+11|0]|0)!=15){b[h+22>>1]=e;b[g+22>>1]=c[f+(d[j+11|0]<<2)>>2]&65535}if((a[j+12|0]|0)!=15){b[h+24>>1]=e;b[g+24>>1]=c[f+(d[j+12|0]<<2)>>2]&65535}if((a[j+13|0]|0)!=15){b[h+26>>1]=e;b[g+26>>1]=c[f+(d[j+13|0]<<2)>>2]&65535}if((a[j+14|0]|0)!=15){b[h+28>>1]=e;b[g+28>>1]=c[f+(d[j+14|0]<<2)>>2]&65535}if((a[j+15|0]|0)!=15){b[h+30>>1]=e;b[g+30>>1]=c[f+(d[j+15|0]<<2)>>2]&65535}k=i+1|0;l=j+16|0;if((k|0)<16){g=g+640|0;h=h+640|0;i=k;j=l}else{break}}c[2385338]=l;return}function dWu(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=c[2385456]|0;f=c[2385468]|0;g=f>>>0<320;h=c[2415164]&65535;i=c[2440386]|0;j=c[2415150]|0;k=c[2409606]|0;l=0;L36101:while(1){m=e+l|0;do{if((m|0)>=0){if((m|0)>223){n=27289;break L36101}do{if(g){o=c[2385338]|0;if((a[o]|0)==15){break}b[k>>1]=h;b[j>>1]=c[i+(d[o]<<2)>>2]&65535}}while(0);do{if((f+1|0)>>>0<320){o=(c[2385338]|0)+1|0;if((a[o]|0)==15){break}b[k+2>>1]=h;b[j+2>>1]=c[i+(d[o]<<2)>>2]&65535}}while(0);do{if((f+2|0)>>>0<320){o=(c[2385338]|0)+2|0;if((a[o]|0)==15){break}b[k+4>>1]=h;b[j+4>>1]=c[i+(d[o]<<2)>>2]&65535}}while(0);do{if((f+3|0)>>>0<320){o=(c[2385338]|0)+3|0;if((a[o]|0)==15){break}b[k+6>>1]=h;b[j+6>>1]=c[i+(d[o]<<2)>>2]&65535}}while(0);do{if((f+4|0)>>>0<320){o=(c[2385338]|0)+4|0;if((a[o]|0)==15){break}b[k+8>>1]=h;b[j+8>>1]=c[i+(d[o]<<2)>>2]&65535}}while(0);do{if((f+5|0)>>>0<320){o=(c[2385338]|0)+5|0;if((a[o]|0)==15){break}b[k+10>>1]=h;b[j+10>>1]=c[i+(d[o]<<2)>>2]&65535}}while(0);do{if((f+6|0)>>>0<320){o=(c[2385338]|0)+6|0;if((a[o]|0)==15){break}b[k+12>>1]=h;b[j+12>>1]=c[i+(d[o]<<2)>>2]&65535}}while(0);do{if((f+7|0)>>>0<320){o=(c[2385338]|0)+7|0;if((a[o]|0)==15){break}b[k+14>>1]=h;b[j+14>>1]=c[i+(d[o]<<2)>>2]&65535}}while(0);do{if((f+8|0)>>>0<320){o=(c[2385338]|0)+8|0;if((a[o]|0)==15){break}b[k+16>>1]=h;b[j+16>>1]=c[i+(d[o]<<2)>>2]&65535}}while(0);do{if((f+9|0)>>>0<320){o=(c[2385338]|0)+9|0;if((a[o]|0)==15){break}b[k+18>>1]=h;b[j+18>>1]=c[i+(d[o]<<2)>>2]&65535}}while(0);do{if((f+10|0)>>>0<320){o=(c[2385338]|0)+10|0;if((a[o]|0)==15){break}b[k+20>>1]=h;b[j+20>>1]=c[i+(d[o]<<2)>>2]&65535}}while(0);do{if((f+11|0)>>>0<320){o=(c[2385338]|0)+11|0;if((a[o]|0)==15){break}b[k+22>>1]=h;b[j+22>>1]=c[i+(d[o]<<2)>>2]&65535}}while(0);do{if((f+12|0)>>>0<320){o=(c[2385338]|0)+12|0;if((a[o]|0)==15){break}b[k+24>>1]=h;b[j+24>>1]=c[i+(d[o]<<2)>>2]&65535}}while(0);do{if((f+13|0)>>>0<320){o=(c[2385338]|0)+13|0;if((a[o]|0)==15){break}b[k+26>>1]=h;b[j+26>>1]=c[i+(d[o]<<2)>>2]&65535}}while(0);do{if((f+14|0)>>>0<320){o=(c[2385338]|0)+14|0;if((a[o]|0)==15){break}b[k+28>>1]=h;b[j+28>>1]=c[i+(d[o]<<2)>>2]&65535}}while(0);if((f+15|0)>>>0>=320){break}o=(c[2385338]|0)+15|0;if((a[o]|0)==15){break}b[k+30>>1]=h;b[j+30>>1]=c[i+(d[o]<<2)>>2]&65535}}while(0);m=l+1|0;c[2385338]=(c[2385338]|0)+16;if((m|0)>=16){n=27290;break}j=j+640|0;k=k+640|0;l=m}if((n|0)==27289){return}else if((n|0)==27290){return}}function dWv(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;f=c[2415164]|0;g=f&65535;h=c[2440386]|0;i=c[2415150]|0;j=c[2409606]|0;k=0;l=c[2385338]|0;while(1){do{if((a[l]|0)==15){m=l}else{if((e[j>>1]|0)>(f|0)){m=l;break}b[j>>1]=g;b[i>>1]=c[h+(d[l]<<2)>>2]&65535;m=l}}while(0);do{if((a[m+1|0]|0)==15){n=m}else{o=j+2|0;if((e[o>>1]|0)>(f|0)){n=m;break}b[o>>1]=g;b[i+2>>1]=c[h+(d[l+1|0]<<2)>>2]&65535;n=l}}while(0);do{if((a[n+2|0]|0)==15){p=n}else{o=j+4|0;if((e[o>>1]|0)>(f|0)){p=n;break}b[o>>1]=g;b[i+4>>1]=c[h+(d[l+2|0]<<2)>>2]&65535;p=l}}while(0);do{if((a[p+3|0]|0)==15){q=p}else{o=j+6|0;if((e[o>>1]|0)>(f|0)){q=p;break}b[o>>1]=g;b[i+6>>1]=c[h+(d[l+3|0]<<2)>>2]&65535;q=l}}while(0);do{if((a[q+4|0]|0)==15){r=q}else{o=j+8|0;if((e[o>>1]|0)>(f|0)){r=q;break}b[o>>1]=g;b[i+8>>1]=c[h+(d[l+4|0]<<2)>>2]&65535;r=l}}while(0);do{if((a[r+5|0]|0)==15){s=r}else{o=j+10|0;if((e[o>>1]|0)>(f|0)){s=r;break}b[o>>1]=g;b[i+10>>1]=c[h+(d[l+5|0]<<2)>>2]&65535;s=l}}while(0);do{if((a[s+6|0]|0)==15){t=s}else{o=j+12|0;if((e[o>>1]|0)>(f|0)){t=s;break}b[o>>1]=g;b[i+12>>1]=c[h+(d[l+6|0]<<2)>>2]&65535;t=l}}while(0);do{if((a[t+7|0]|0)==15){u=t}else{o=j+14|0;if((e[o>>1]|0)>(f|0)){u=t;break}b[o>>1]=g;b[i+14>>1]=c[h+(d[l+7|0]<<2)>>2]&65535;u=l}}while(0);do{if((a[u+8|0]|0)==15){v=u}else{o=j+16|0;if((e[o>>1]|0)>(f|0)){v=u;break}b[o>>1]=g;b[i+16>>1]=c[h+(d[l+8|0]<<2)>>2]&65535;v=l}}while(0);do{if((a[v+9|0]|0)==15){w=v}else{o=j+18|0;if((e[o>>1]|0)>(f|0)){w=v;break}b[o>>1]=g;b[i+18>>1]=c[h+(d[l+9|0]<<2)>>2]&65535;w=l}}while(0);do{if((a[w+10|0]|0)==15){x=w}else{o=j+20|0;if((e[o>>1]|0)>(f|0)){x=w;break}b[o>>1]=g;b[i+20>>1]=c[h+(d[l+10|0]<<2)>>2]&65535;x=l}}while(0);do{if((a[x+11|0]|0)==15){y=x}else{o=j+22|0;if((e[o>>1]|0)>(f|0)){y=x;break}b[o>>1]=g;b[i+22>>1]=c[h+(d[l+11|0]<<2)>>2]&65535;y=l}}while(0);do{if((a[y+12|0]|0)==15){z=y}else{o=j+24|0;if((e[o>>1]|0)>(f|0)){z=y;break}b[o>>1]=g;b[i+24>>1]=c[h+(d[l+12|0]<<2)>>2]&65535;z=l}}while(0);do{if((a[z+13|0]|0)==15){A=z}else{o=j+26|0;if((e[o>>1]|0)>(f|0)){A=z;break}b[o>>1]=g;b[i+26>>1]=c[h+(d[l+13|0]<<2)>>2]&65535;A=l}}while(0);do{if((a[A+14|0]|0)==15){B=A}else{o=j+28|0;if((e[o>>1]|0)>(f|0)){B=A;break}b[o>>1]=g;b[i+28>>1]=c[h+(d[l+14|0]<<2)>>2]&65535;B=l}}while(0);do{if((a[B+15|0]|0)==15){C=B}else{o=j+30|0;if((e[o>>1]|0)>(f|0)){C=B;break}b[o>>1]=g;b[i+30>>1]=c[h+(d[l+15|0]<<2)>>2]&65535;C=l}}while(0);o=k+1|0;D=C+16|0;if((o|0)<16){i=i+640|0;j=j+640|0;k=o;l=D}else{break}}c[2385338]=D;return}function dWw(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=c[2385456]|0;g=c[2385468]|0;h=g>>>0<320;i=c[2415164]|0;j=i&65535;k=c[2440386]|0;l=c[2415150]|0;m=c[2409606]|0;n=0;L36242:while(1){o=f+n|0;do{if((o|0)>=0){if((o|0)>223){p=27413;break L36242}do{if(h){q=c[2385338]|0;if((a[q]|0)==15){break}if((e[m>>1]|0)>(i|0)){break}b[m>>1]=j;b[l>>1]=c[k+(d[q]<<2)>>2]&65535}}while(0);do{if((g+1|0)>>>0<320){q=(c[2385338]|0)+1|0;if((a[q]|0)==15){break}r=m+2|0;if((e[r>>1]|0)>(i|0)){break}b[r>>1]=j;b[l+2>>1]=c[k+(d[q]<<2)>>2]&65535}}while(0);do{if((g+2|0)>>>0<320){q=(c[2385338]|0)+2|0;if((a[q]|0)==15){break}r=m+4|0;if((e[r>>1]|0)>(i|0)){break}b[r>>1]=j;b[l+4>>1]=c[k+(d[q]<<2)>>2]&65535}}while(0);do{if((g+3|0)>>>0<320){q=(c[2385338]|0)+3|0;if((a[q]|0)==15){break}r=m+6|0;if((e[r>>1]|0)>(i|0)){break}b[r>>1]=j;b[l+6>>1]=c[k+(d[q]<<2)>>2]&65535}}while(0);do{if((g+4|0)>>>0<320){q=(c[2385338]|0)+4|0;if((a[q]|0)==15){break}r=m+8|0;if((e[r>>1]|0)>(i|0)){break}b[r>>1]=j;b[l+8>>1]=c[k+(d[q]<<2)>>2]&65535}}while(0);do{if((g+5|0)>>>0<320){q=(c[2385338]|0)+5|0;if((a[q]|0)==15){break}r=m+10|0;if((e[r>>1]|0)>(i|0)){break}b[r>>1]=j;b[l+10>>1]=c[k+(d[q]<<2)>>2]&65535}}while(0);do{if((g+6|0)>>>0<320){q=(c[2385338]|0)+6|0;if((a[q]|0)==15){break}r=m+12|0;if((e[r>>1]|0)>(i|0)){break}b[r>>1]=j;b[l+12>>1]=c[k+(d[q]<<2)>>2]&65535}}while(0);do{if((g+7|0)>>>0<320){q=(c[2385338]|0)+7|0;if((a[q]|0)==15){break}r=m+14|0;if((e[r>>1]|0)>(i|0)){break}b[r>>1]=j;b[l+14>>1]=c[k+(d[q]<<2)>>2]&65535}}while(0);do{if((g+8|0)>>>0<320){q=(c[2385338]|0)+8|0;if((a[q]|0)==15){break}r=m+16|0;if((e[r>>1]|0)>(i|0)){break}b[r>>1]=j;b[l+16>>1]=c[k+(d[q]<<2)>>2]&65535}}while(0);do{if((g+9|0)>>>0<320){q=(c[2385338]|0)+9|0;if((a[q]|0)==15){break}r=m+18|0;if((e[r>>1]|0)>(i|0)){break}b[r>>1]=j;b[l+18>>1]=c[k+(d[q]<<2)>>2]&65535}}while(0);do{if((g+10|0)>>>0<320){q=(c[2385338]|0)+10|0;if((a[q]|0)==15){break}r=m+20|0;if((e[r>>1]|0)>(i|0)){break}b[r>>1]=j;b[l+20>>1]=c[k+(d[q]<<2)>>2]&65535}}while(0);do{if((g+11|0)>>>0<320){q=(c[2385338]|0)+11|0;if((a[q]|0)==15){break}r=m+22|0;if((e[r>>1]|0)>(i|0)){break}b[r>>1]=j;b[l+22>>1]=c[k+(d[q]<<2)>>2]&65535}}while(0);do{if((g+12|0)>>>0<320){q=(c[2385338]|0)+12|0;if((a[q]|0)==15){break}r=m+24|0;if((e[r>>1]|0)>(i|0)){break}b[r>>1]=j;b[l+24>>1]=c[k+(d[q]<<2)>>2]&65535}}while(0);do{if((g+13|0)>>>0<320){q=(c[2385338]|0)+13|0;if((a[q]|0)==15){break}r=m+26|0;if((e[r>>1]|0)>(i|0)){break}b[r>>1]=j;b[l+26>>1]=c[k+(d[q]<<2)>>2]&65535}}while(0);do{if((g+14|0)>>>0<320){q=(c[2385338]|0)+14|0;if((a[q]|0)==15){break}r=m+28|0;if((e[r>>1]|0)>(i|0)){break}b[r>>1]=j;b[l+28>>1]=c[k+(d[q]<<2)>>2]&65535}}while(0);if((g+15|0)>>>0>=320){break}q=(c[2385338]|0)+15|0;if((a[q]|0)==15){break}r=m+30|0;if((e[r>>1]|0)>(i|0)){break}b[r>>1]=j;b[l+30>>1]=c[k+(d[q]<<2)>>2]&65535}}while(0);o=n+1|0;c[2385338]=(c[2385338]|0)+16;if((o|0)>=16){p=27412;break}l=l+640|0;m=m+640|0;n=o}if((p|0)==27412){return}else if((p|0)==27413){return}}function dWx(){var d=0,e=0,f=0,g=0,h=0,i=0;d=c[2440386]|0;e=c[2415150]|0;f=0;g=c[2385338]|0;while(1){h=a[g+15|0]|0;if(h<<24>>24!=15){b[e>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+14|0]|0;if(h<<24>>24!=15){b[e+2>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+13|0]|0;if(h<<24>>24!=15){b[e+4>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+12|0]|0;if(h<<24>>24!=15){b[e+6>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+11|0]|0;if(h<<24>>24!=15){b[e+8>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+10|0]|0;if(h<<24>>24!=15){b[e+10>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+9|0]|0;if(h<<24>>24!=15){b[e+12>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+8|0]|0;if(h<<24>>24!=15){b[e+14>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+7|0]|0;if(h<<24>>24!=15){b[e+16>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+6|0]|0;if(h<<24>>24!=15){b[e+18>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+5|0]|0;if(h<<24>>24!=15){b[e+20>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+4|0]|0;if(h<<24>>24!=15){b[e+22>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+3|0]|0;if(h<<24>>24!=15){b[e+24>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+2|0]|0;if(h<<24>>24!=15){b[e+26>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+1|0]|0;if(h<<24>>24!=15){b[e+28>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g]|0;if(h<<24>>24!=15){b[e+30>>1]=c[d+((h&255)<<2)>>2]&65535}h=f+1|0;i=g+16|0;if((h|0)<16){e=e+640|0;f=h;g=i}else{break}}c[2385338]=i;return}function dWy(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[2385456]|0;e=c[2385468]|0;f=e>>>0<320;g=c[2440386]|0;h=c[2415150]|0;i=0;L36383:while(1){j=d+i|0;do{if((j|0)>=0){if((j|0)>223){k=27503;break L36383}do{if(f){l=a[(c[2385338]|0)+15|0]|0;if(l<<24>>24==15){break}b[h>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+1|0)>>>0<320){l=a[(c[2385338]|0)+14|0]|0;if(l<<24>>24==15){break}b[h+2>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+2|0)>>>0<320){l=a[(c[2385338]|0)+13|0]|0;if(l<<24>>24==15){break}b[h+4>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+3|0)>>>0<320){l=a[(c[2385338]|0)+12|0]|0;if(l<<24>>24==15){break}b[h+6>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+4|0)>>>0<320){l=a[(c[2385338]|0)+11|0]|0;if(l<<24>>24==15){break}b[h+8>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+5|0)>>>0<320){l=a[(c[2385338]|0)+10|0]|0;if(l<<24>>24==15){break}b[h+10>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+6|0)>>>0<320){l=a[(c[2385338]|0)+9|0]|0;if(l<<24>>24==15){break}b[h+12>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+7|0)>>>0<320){l=a[(c[2385338]|0)+8|0]|0;if(l<<24>>24==15){break}b[h+14>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+8|0)>>>0<320){l=a[(c[2385338]|0)+7|0]|0;if(l<<24>>24==15){break}b[h+16>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+9|0)>>>0<320){l=a[(c[2385338]|0)+6|0]|0;if(l<<24>>24==15){break}b[h+18>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+10|0)>>>0<320){l=a[(c[2385338]|0)+5|0]|0;if(l<<24>>24==15){break}b[h+20>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+11|0)>>>0<320){l=a[(c[2385338]|0)+4|0]|0;if(l<<24>>24==15){break}b[h+22>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+12|0)>>>0<320){l=a[(c[2385338]|0)+3|0]|0;if(l<<24>>24==15){break}b[h+24>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+13|0)>>>0<320){l=a[(c[2385338]|0)+2|0]|0;if(l<<24>>24==15){break}b[h+26>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+14|0)>>>0<320){l=a[(c[2385338]|0)+1|0]|0;if(l<<24>>24==15){break}b[h+28>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);if((e+15|0)>>>0>=320){break}l=a[c[2385338]|0]|0;if(l<<24>>24==15){break}b[h+30>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);j=i+1|0;c[2385338]=(c[2385338]|0)+16;if((j|0)>=16){k=27504;break}h=h+640|0;i=j}if((k|0)==27503){return}else if((k|0)==27504){return}}function dWz(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;d=c[2415164]|0;f=c[2440386]|0;g=c[2415150]|0;h=c[2409606]|0;i=0;j=c[2385338]|0;while(1){k=a[j+15|0]|0;l=k&255;do{if(k<<24>>24==15){m=j}else{if((e[h>>1]|0|0)>(d|0)){m=j;break}b[g>>1]=c[f+(l<<2)>>2]&65535;m=j}}while(0);l=a[m+14|0]|0;k=l&255;do{if(l<<24>>24==15){n=m}else{if((e[h+2>>1]|0|0)>(d|0)){n=m;break}b[g+2>>1]=c[f+(k<<2)>>2]&65535;n=j}}while(0);k=a[n+13|0]|0;l=k&255;do{if(k<<24>>24==15){o=n}else{if((e[h+4>>1]|0|0)>(d|0)){o=n;break}b[g+4>>1]=c[f+(l<<2)>>2]&65535;o=j}}while(0);l=a[o+12|0]|0;k=l&255;do{if(l<<24>>24==15){p=o}else{if((e[h+6>>1]|0|0)>(d|0)){p=o;break}b[g+6>>1]=c[f+(k<<2)>>2]&65535;p=j}}while(0);k=a[p+11|0]|0;l=k&255;do{if(k<<24>>24==15){q=p}else{if((e[h+8>>1]|0|0)>(d|0)){q=p;break}b[g+8>>1]=c[f+(l<<2)>>2]&65535;q=j}}while(0);l=a[q+10|0]|0;k=l&255;do{if(l<<24>>24==15){r=q}else{if((e[h+10>>1]|0|0)>(d|0)){r=q;break}b[g+10>>1]=c[f+(k<<2)>>2]&65535;r=j}}while(0);k=a[r+9|0]|0;l=k&255;do{if(k<<24>>24==15){s=r}else{if((e[h+12>>1]|0|0)>(d|0)){s=r;break}b[g+12>>1]=c[f+(l<<2)>>2]&65535;s=j}}while(0);l=a[s+8|0]|0;k=l&255;do{if(l<<24>>24==15){t=s}else{if((e[h+14>>1]|0|0)>(d|0)){t=s;break}b[g+14>>1]=c[f+(k<<2)>>2]&65535;t=j}}while(0);k=a[t+7|0]|0;l=k&255;do{if(k<<24>>24==15){u=t}else{if((e[h+16>>1]|0|0)>(d|0)){u=t;break}b[g+16>>1]=c[f+(l<<2)>>2]&65535;u=j}}while(0);l=a[u+6|0]|0;k=l&255;do{if(l<<24>>24==15){v=u}else{if((e[h+18>>1]|0|0)>(d|0)){v=u;break}b[g+18>>1]=c[f+(k<<2)>>2]&65535;v=j}}while(0);k=a[v+5|0]|0;l=k&255;do{if(k<<24>>24==15){w=v}else{if((e[h+20>>1]|0|0)>(d|0)){w=v;break}b[g+20>>1]=c[f+(l<<2)>>2]&65535;w=j}}while(0);l=a[w+4|0]|0;k=l&255;do{if(l<<24>>24==15){x=w}else{if((e[h+22>>1]|0|0)>(d|0)){x=w;break}b[g+22>>1]=c[f+(k<<2)>>2]&65535;x=j}}while(0);k=a[x+3|0]|0;l=k&255;do{if(k<<24>>24==15){y=x}else{if((e[h+24>>1]|0|0)>(d|0)){y=x;break}b[g+24>>1]=c[f+(l<<2)>>2]&65535;y=j}}while(0);l=a[y+2|0]|0;k=l&255;do{if(l<<24>>24==15){z=y}else{if((e[h+26>>1]|0|0)>(d|0)){z=y;break}b[g+26>>1]=c[f+(k<<2)>>2]&65535;z=j}}while(0);k=a[z+1|0]|0;l=k&255;do{if(k<<24>>24==15){A=z}else{if((e[h+28>>1]|0|0)>(d|0)){A=z;break}b[g+28>>1]=c[f+(l<<2)>>2]&65535;A=j}}while(0);l=a[A]|0;k=l&255;do{if(l<<24>>24==15){B=A}else{if((e[h+30>>1]|0|0)>(d|0)){B=A;break}b[g+30>>1]=c[f+(k<<2)>>2]&65535;B=j}}while(0);k=i+1|0;C=B+16|0;if((k|0)<16){g=g+640|0;h=h+640|0;i=k;j=C}else{break}}c[2385338]=C;return}function dWA(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=c[2385456]|0;f=c[2385468]|0;g=f>>>0<320;h=c[2415164]|0;i=c[2440386]|0;j=c[2415150]|0;k=c[2409606]|0;l=0;L36524:while(1){m=d+l|0;do{if((m|0)>=0){if((m|0)>223){n=27626;break L36524}do{if(g){o=a[(c[2385338]|0)+15|0]|0;if(o<<24>>24==15){break}if((e[k>>1]|0|0)>(h|0)){break}b[j>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);do{if((f+1|0)>>>0<320){o=a[(c[2385338]|0)+14|0]|0;if(o<<24>>24==15){break}if((e[k+2>>1]|0|0)>(h|0)){break}b[j+2>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);do{if((f+2|0)>>>0<320){o=a[(c[2385338]|0)+13|0]|0;if(o<<24>>24==15){break}if((e[k+4>>1]|0|0)>(h|0)){break}b[j+4>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);do{if((f+3|0)>>>0<320){o=a[(c[2385338]|0)+12|0]|0;if(o<<24>>24==15){break}if((e[k+6>>1]|0|0)>(h|0)){break}b[j+6>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);do{if((f+4|0)>>>0<320){o=a[(c[2385338]|0)+11|0]|0;if(o<<24>>24==15){break}if((e[k+8>>1]|0|0)>(h|0)){break}b[j+8>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);do{if((f+5|0)>>>0<320){o=a[(c[2385338]|0)+10|0]|0;if(o<<24>>24==15){break}if((e[k+10>>1]|0|0)>(h|0)){break}b[j+10>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);do{if((f+6|0)>>>0<320){o=a[(c[2385338]|0)+9|0]|0;if(o<<24>>24==15){break}if((e[k+12>>1]|0|0)>(h|0)){break}b[j+12>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);do{if((f+7|0)>>>0<320){o=a[(c[2385338]|0)+8|0]|0;if(o<<24>>24==15){break}if((e[k+14>>1]|0|0)>(h|0)){break}b[j+14>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);do{if((f+8|0)>>>0<320){o=a[(c[2385338]|0)+7|0]|0;if(o<<24>>24==15){break}if((e[k+16>>1]|0|0)>(h|0)){break}b[j+16>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);do{if((f+9|0)>>>0<320){o=a[(c[2385338]|0)+6|0]|0;if(o<<24>>24==15){break}if((e[k+18>>1]|0|0)>(h|0)){break}b[j+18>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);do{if((f+10|0)>>>0<320){o=a[(c[2385338]|0)+5|0]|0;if(o<<24>>24==15){break}if((e[k+20>>1]|0|0)>(h|0)){break}b[j+20>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);do{if((f+11|0)>>>0<320){o=a[(c[2385338]|0)+4|0]|0;if(o<<24>>24==15){break}if((e[k+22>>1]|0|0)>(h|0)){break}b[j+22>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);do{if((f+12|0)>>>0<320){o=a[(c[2385338]|0)+3|0]|0;if(o<<24>>24==15){break}if((e[k+24>>1]|0|0)>(h|0)){break}b[j+24>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);do{if((f+13|0)>>>0<320){o=a[(c[2385338]|0)+2|0]|0;if(o<<24>>24==15){break}if((e[k+26>>1]|0|0)>(h|0)){break}b[j+26>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);do{if((f+14|0)>>>0<320){o=a[(c[2385338]|0)+1|0]|0;if(o<<24>>24==15){break}if((e[k+28>>1]|0|0)>(h|0)){break}b[j+28>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);if((f+15|0)>>>0>=320){break}o=a[c[2385338]|0]|0;if(o<<24>>24==15){break}if((e[k+30>>1]|0|0)>(h|0)){break}b[j+30>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);m=l+1|0;c[2385338]=(c[2385338]|0)+16;if((m|0)>=16){n=27627;break}j=j+640|0;k=k+640|0;l=m}if((n|0)==27626){return}else if((n|0)==27627){return}}function dWB(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=c[2415164]&65535;f=c[2440386]|0;g=c[2415150]|0;h=c[2409606]|0;i=0;j=c[2385338]|0;while(1){if((a[j+15|0]|0)!=15){b[h>>1]=e;b[g>>1]=c[f+(d[j+15|0]<<2)>>2]&65535}if((a[j+14|0]|0)!=15){b[h+2>>1]=e;b[g+2>>1]=c[f+(d[j+14|0]<<2)>>2]&65535}if((a[j+13|0]|0)!=15){b[h+4>>1]=e;b[g+4>>1]=c[f+(d[j+13|0]<<2)>>2]&65535}if((a[j+12|0]|0)!=15){b[h+6>>1]=e;b[g+6>>1]=c[f+(d[j+12|0]<<2)>>2]&65535}if((a[j+11|0]|0)!=15){b[h+8>>1]=e;b[g+8>>1]=c[f+(d[j+11|0]<<2)>>2]&65535}if((a[j+10|0]|0)!=15){b[h+10>>1]=e;b[g+10>>1]=c[f+(d[j+10|0]<<2)>>2]&65535}if((a[j+9|0]|0)!=15){b[h+12>>1]=e;b[g+12>>1]=c[f+(d[j+9|0]<<2)>>2]&65535}if((a[j+8|0]|0)!=15){b[h+14>>1]=e;b[g+14>>1]=c[f+(d[j+8|0]<<2)>>2]&65535}if((a[j+7|0]|0)!=15){b[h+16>>1]=e;b[g+16>>1]=c[f+(d[j+7|0]<<2)>>2]&65535}if((a[j+6|0]|0)!=15){b[h+18>>1]=e;b[g+18>>1]=c[f+(d[j+6|0]<<2)>>2]&65535}if((a[j+5|0]|0)!=15){b[h+20>>1]=e;b[g+20>>1]=c[f+(d[j+5|0]<<2)>>2]&65535}if((a[j+4|0]|0)!=15){b[h+22>>1]=e;b[g+22>>1]=c[f+(d[j+4|0]<<2)>>2]&65535}if((a[j+3|0]|0)!=15){b[h+24>>1]=e;b[g+24>>1]=c[f+(d[j+3|0]<<2)>>2]&65535}if((a[j+2|0]|0)!=15){b[h+26>>1]=e;b[g+26>>1]=c[f+(d[j+2|0]<<2)>>2]&65535}if((a[j+1|0]|0)!=15){b[h+28>>1]=e;b[g+28>>1]=c[f+(d[j+1|0]<<2)>>2]&65535}if((a[j]|0)!=15){b[h+30>>1]=e;b[g+30>>1]=c[f+(d[j]<<2)>>2]&65535}k=i+1|0;l=j+16|0;if((k|0)<16){g=g+640|0;h=h+640|0;i=k;j=l}else{break}}c[2385338]=l;return}function dWC(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=c[2385456]|0;f=c[2385468]|0;g=f>>>0<320;h=c[2415164]&65535;i=c[2440386]|0;j=c[2415150]|0;k=c[2409606]|0;l=0;L36665:while(1){m=e+l|0;do{if((m|0)>=0){if((m|0)>223){n=27717;break L36665}do{if(g){o=(c[2385338]|0)+15|0;if((a[o]|0)==15){break}b[k>>1]=h;b[j>>1]=c[i+(d[o]<<2)>>2]&65535}}while(0);do{if((f+1|0)>>>0<320){o=(c[2385338]|0)+14|0;if((a[o]|0)==15){break}b[k+2>>1]=h;b[j+2>>1]=c[i+(d[o]<<2)>>2]&65535}}while(0);do{if((f+2|0)>>>0<320){o=(c[2385338]|0)+13|0;if((a[o]|0)==15){break}b[k+4>>1]=h;b[j+4>>1]=c[i+(d[o]<<2)>>2]&65535}}while(0);do{if((f+3|0)>>>0<320){o=(c[2385338]|0)+12|0;if((a[o]|0)==15){break}b[k+6>>1]=h;b[j+6>>1]=c[i+(d[o]<<2)>>2]&65535}}while(0);do{if((f+4|0)>>>0<320){o=(c[2385338]|0)+11|0;if((a[o]|0)==15){break}b[k+8>>1]=h;b[j+8>>1]=c[i+(d[o]<<2)>>2]&65535}}while(0);do{if((f+5|0)>>>0<320){o=(c[2385338]|0)+10|0;if((a[o]|0)==15){break}b[k+10>>1]=h;b[j+10>>1]=c[i+(d[o]<<2)>>2]&65535}}while(0);do{if((f+6|0)>>>0<320){o=(c[2385338]|0)+9|0;if((a[o]|0)==15){break}b[k+12>>1]=h;b[j+12>>1]=c[i+(d[o]<<2)>>2]&65535}}while(0);do{if((f+7|0)>>>0<320){o=(c[2385338]|0)+8|0;if((a[o]|0)==15){break}b[k+14>>1]=h;b[j+14>>1]=c[i+(d[o]<<2)>>2]&65535}}while(0);do{if((f+8|0)>>>0<320){o=(c[2385338]|0)+7|0;if((a[o]|0)==15){break}b[k+16>>1]=h;b[j+16>>1]=c[i+(d[o]<<2)>>2]&65535}}while(0);do{if((f+9|0)>>>0<320){o=(c[2385338]|0)+6|0;if((a[o]|0)==15){break}b[k+18>>1]=h;b[j+18>>1]=c[i+(d[o]<<2)>>2]&65535}}while(0);do{if((f+10|0)>>>0<320){o=(c[2385338]|0)+5|0;if((a[o]|0)==15){break}b[k+20>>1]=h;b[j+20>>1]=c[i+(d[o]<<2)>>2]&65535}}while(0);do{if((f+11|0)>>>0<320){o=(c[2385338]|0)+4|0;if((a[o]|0)==15){break}b[k+22>>1]=h;b[j+22>>1]=c[i+(d[o]<<2)>>2]&65535}}while(0);do{if((f+12|0)>>>0<320){o=(c[2385338]|0)+3|0;if((a[o]|0)==15){break}b[k+24>>1]=h;b[j+24>>1]=c[i+(d[o]<<2)>>2]&65535}}while(0);do{if((f+13|0)>>>0<320){o=(c[2385338]|0)+2|0;if((a[o]|0)==15){break}b[k+26>>1]=h;b[j+26>>1]=c[i+(d[o]<<2)>>2]&65535}}while(0);do{if((f+14|0)>>>0<320){o=(c[2385338]|0)+1|0;if((a[o]|0)==15){break}b[k+28>>1]=h;b[j+28>>1]=c[i+(d[o]<<2)>>2]&65535}}while(0);if((f+15|0)>>>0>=320){break}o=c[2385338]|0;if((a[o]|0)==15){break}b[k+30>>1]=h;b[j+30>>1]=c[i+(d[o]<<2)>>2]&65535}}while(0);m=l+1|0;c[2385338]=(c[2385338]|0)+16;if((m|0)>=16){n=27718;break}j=j+640|0;k=k+640|0;l=m}if((n|0)==27717){return}else if((n|0)==27718){return}}function dWD(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;f=c[2415164]|0;g=f&65535;h=c[2440386]|0;i=c[2415150]|0;j=c[2409606]|0;k=0;l=c[2385338]|0;while(1){do{if((a[l+15|0]|0)==15){m=l}else{if((e[j>>1]|0)>(f|0)){m=l;break}b[j>>1]=g;b[i>>1]=c[h+(d[l+15|0]<<2)>>2]&65535;m=l}}while(0);do{if((a[m+14|0]|0)==15){n=m}else{o=j+2|0;if((e[o>>1]|0)>(f|0)){n=m;break}b[o>>1]=g;b[i+2>>1]=c[h+(d[l+14|0]<<2)>>2]&65535;n=l}}while(0);do{if((a[n+13|0]|0)==15){p=n}else{o=j+4|0;if((e[o>>1]|0)>(f|0)){p=n;break}b[o>>1]=g;b[i+4>>1]=c[h+(d[l+13|0]<<2)>>2]&65535;p=l}}while(0);do{if((a[p+12|0]|0)==15){q=p}else{o=j+6|0;if((e[o>>1]|0)>(f|0)){q=p;break}b[o>>1]=g;b[i+6>>1]=c[h+(d[l+12|0]<<2)>>2]&65535;q=l}}while(0);do{if((a[q+11|0]|0)==15){r=q}else{o=j+8|0;if((e[o>>1]|0)>(f|0)){r=q;break}b[o>>1]=g;b[i+8>>1]=c[h+(d[l+11|0]<<2)>>2]&65535;r=l}}while(0);do{if((a[r+10|0]|0)==15){s=r}else{o=j+10|0;if((e[o>>1]|0)>(f|0)){s=r;break}b[o>>1]=g;b[i+10>>1]=c[h+(d[l+10|0]<<2)>>2]&65535;s=l}}while(0);do{if((a[s+9|0]|0)==15){t=s}else{o=j+12|0;if((e[o>>1]|0)>(f|0)){t=s;break}b[o>>1]=g;b[i+12>>1]=c[h+(d[l+9|0]<<2)>>2]&65535;t=l}}while(0);do{if((a[t+8|0]|0)==15){u=t}else{o=j+14|0;if((e[o>>1]|0)>(f|0)){u=t;break}b[o>>1]=g;b[i+14>>1]=c[h+(d[l+8|0]<<2)>>2]&65535;u=l}}while(0);do{if((a[u+7|0]|0)==15){v=u}else{o=j+16|0;if((e[o>>1]|0)>(f|0)){v=u;break}b[o>>1]=g;b[i+16>>1]=c[h+(d[l+7|0]<<2)>>2]&65535;v=l}}while(0);do{if((a[v+6|0]|0)==15){w=v}else{o=j+18|0;if((e[o>>1]|0)>(f|0)){w=v;break}b[o>>1]=g;b[i+18>>1]=c[h+(d[l+6|0]<<2)>>2]&65535;w=l}}while(0);do{if((a[w+5|0]|0)==15){x=w}else{o=j+20|0;if((e[o>>1]|0)>(f|0)){x=w;break}b[o>>1]=g;b[i+20>>1]=c[h+(d[l+5|0]<<2)>>2]&65535;x=l}}while(0);do{if((a[x+4|0]|0)==15){y=x}else{o=j+22|0;if((e[o>>1]|0)>(f|0)){y=x;break}b[o>>1]=g;b[i+22>>1]=c[h+(d[l+4|0]<<2)>>2]&65535;y=l}}while(0);do{if((a[y+3|0]|0)==15){z=y}else{o=j+24|0;if((e[o>>1]|0)>(f|0)){z=y;break}b[o>>1]=g;b[i+24>>1]=c[h+(d[l+3|0]<<2)>>2]&65535;z=l}}while(0);do{if((a[z+2|0]|0)==15){A=z}else{o=j+26|0;if((e[o>>1]|0)>(f|0)){A=z;break}b[o>>1]=g;b[i+26>>1]=c[h+(d[l+2|0]<<2)>>2]&65535;A=l}}while(0);do{if((a[A+1|0]|0)==15){B=A}else{o=j+28|0;if((e[o>>1]|0)>(f|0)){B=A;break}b[o>>1]=g;b[i+28>>1]=c[h+(d[l+1|0]<<2)>>2]&65535;B=l}}while(0);do{if((a[B]|0)==15){C=B}else{o=j+30|0;if((e[o>>1]|0)>(f|0)){C=B;break}b[o>>1]=g;b[i+30>>1]=c[h+(d[l]<<2)>>2]&65535;C=l}}while(0);o=k+1|0;D=C+16|0;if((o|0)<16){i=i+640|0;j=j+640|0;k=o;l=D}else{break}}c[2385338]=D;return}function dWE(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=c[2385456]|0;g=c[2385468]|0;h=g>>>0<320;i=c[2415164]|0;j=i&65535;k=c[2440386]|0;l=c[2415150]|0;m=c[2409606]|0;n=0;L36806:while(1){o=f+n|0;do{if((o|0)>=0){if((o|0)>223){p=27840;break L36806}do{if(h){q=(c[2385338]|0)+15|0;if((a[q]|0)==15){break}if((e[m>>1]|0)>(i|0)){break}b[m>>1]=j;b[l>>1]=c[k+(d[q]<<2)>>2]&65535}}while(0);do{if((g+1|0)>>>0<320){q=(c[2385338]|0)+14|0;if((a[q]|0)==15){break}r=m+2|0;if((e[r>>1]|0)>(i|0)){break}b[r>>1]=j;b[l+2>>1]=c[k+(d[q]<<2)>>2]&65535}}while(0);do{if((g+2|0)>>>0<320){q=(c[2385338]|0)+13|0;if((a[q]|0)==15){break}r=m+4|0;if((e[r>>1]|0)>(i|0)){break}b[r>>1]=j;b[l+4>>1]=c[k+(d[q]<<2)>>2]&65535}}while(0);do{if((g+3|0)>>>0<320){q=(c[2385338]|0)+12|0;if((a[q]|0)==15){break}r=m+6|0;if((e[r>>1]|0)>(i|0)){break}b[r>>1]=j;b[l+6>>1]=c[k+(d[q]<<2)>>2]&65535}}while(0);do{if((g+4|0)>>>0<320){q=(c[2385338]|0)+11|0;if((a[q]|0)==15){break}r=m+8|0;if((e[r>>1]|0)>(i|0)){break}b[r>>1]=j;b[l+8>>1]=c[k+(d[q]<<2)>>2]&65535}}while(0);do{if((g+5|0)>>>0<320){q=(c[2385338]|0)+10|0;if((a[q]|0)==15){break}r=m+10|0;if((e[r>>1]|0)>(i|0)){break}b[r>>1]=j;b[l+10>>1]=c[k+(d[q]<<2)>>2]&65535}}while(0);do{if((g+6|0)>>>0<320){q=(c[2385338]|0)+9|0;if((a[q]|0)==15){break}r=m+12|0;if((e[r>>1]|0)>(i|0)){break}b[r>>1]=j;b[l+12>>1]=c[k+(d[q]<<2)>>2]&65535}}while(0);do{if((g+7|0)>>>0<320){q=(c[2385338]|0)+8|0;if((a[q]|0)==15){break}r=m+14|0;if((e[r>>1]|0)>(i|0)){break}b[r>>1]=j;b[l+14>>1]=c[k+(d[q]<<2)>>2]&65535}}while(0);do{if((g+8|0)>>>0<320){q=(c[2385338]|0)+7|0;if((a[q]|0)==15){break}r=m+16|0;if((e[r>>1]|0)>(i|0)){break}b[r>>1]=j;b[l+16>>1]=c[k+(d[q]<<2)>>2]&65535}}while(0);do{if((g+9|0)>>>0<320){q=(c[2385338]|0)+6|0;if((a[q]|0)==15){break}r=m+18|0;if((e[r>>1]|0)>(i|0)){break}b[r>>1]=j;b[l+18>>1]=c[k+(d[q]<<2)>>2]&65535}}while(0);do{if((g+10|0)>>>0<320){q=(c[2385338]|0)+5|0;if((a[q]|0)==15){break}r=m+20|0;if((e[r>>1]|0)>(i|0)){break}b[r>>1]=j;b[l+20>>1]=c[k+(d[q]<<2)>>2]&65535}}while(0);do{if((g+11|0)>>>0<320){q=(c[2385338]|0)+4|0;if((a[q]|0)==15){break}r=m+22|0;if((e[r>>1]|0)>(i|0)){break}b[r>>1]=j;b[l+22>>1]=c[k+(d[q]<<2)>>2]&65535}}while(0);do{if((g+12|0)>>>0<320){q=(c[2385338]|0)+3|0;if((a[q]|0)==15){break}r=m+24|0;if((e[r>>1]|0)>(i|0)){break}b[r>>1]=j;b[l+24>>1]=c[k+(d[q]<<2)>>2]&65535}}while(0);do{if((g+13|0)>>>0<320){q=(c[2385338]|0)+2|0;if((a[q]|0)==15){break}r=m+26|0;if((e[r>>1]|0)>(i|0)){break}b[r>>1]=j;b[l+26>>1]=c[k+(d[q]<<2)>>2]&65535}}while(0);do{if((g+14|0)>>>0<320){q=(c[2385338]|0)+1|0;if((a[q]|0)==15){break}r=m+28|0;if((e[r>>1]|0)>(i|0)){break}b[r>>1]=j;b[l+28>>1]=c[k+(d[q]<<2)>>2]&65535}}while(0);if((g+15|0)>>>0>=320){break}q=c[2385338]|0;if((a[q]|0)==15){break}r=m+30|0;if((e[r>>1]|0)>(i|0)){break}b[r>>1]=j;b[l+30>>1]=c[k+(d[q]<<2)>>2]&65535}}while(0);o=n+1|0;c[2385338]=(c[2385338]|0)+16;if((o|0)>=16){p=27841;break}l=l+640|0;m=m+640|0;n=o}if((p|0)==27840){return}else if((p|0)==27841){return}}function dWF(){var d=0,e=0,f=0,g=0,h=0,i=0;d=c[2440386]|0;e=(c[2415150]|0)+9600|0;f=15;g=c[2385338]|0;while(1){h=a[g]|0;if(h<<24>>24!=15){b[e>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+1|0]|0;if(h<<24>>24!=15){b[e+2>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+2|0]|0;if(h<<24>>24!=15){b[e+4>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+3|0]|0;if(h<<24>>24!=15){b[e+6>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+4|0]|0;if(h<<24>>24!=15){b[e+8>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+5|0]|0;if(h<<24>>24!=15){b[e+10>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+6|0]|0;if(h<<24>>24!=15){b[e+12>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+7|0]|0;if(h<<24>>24!=15){b[e+14>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+8|0]|0;if(h<<24>>24!=15){b[e+16>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+9|0]|0;if(h<<24>>24!=15){b[e+18>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+10|0]|0;if(h<<24>>24!=15){b[e+20>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+11|0]|0;if(h<<24>>24!=15){b[e+22>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+12|0]|0;if(h<<24>>24!=15){b[e+24>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+13|0]|0;if(h<<24>>24!=15){b[e+26>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+14|0]|0;if(h<<24>>24!=15){b[e+28>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+15|0]|0;if(h<<24>>24!=15){b[e+30>>1]=c[d+((h&255)<<2)>>2]&65535}i=g+16|0;if((f|0)>0){e=e-640|0;f=f-1|0;g=i}else{break}}c[2385338]=i;return}function dWG(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=c[2385456]|0;e=d+15|0;if((e|0)<0){return}f=c[2385468]|0;g=f>>>0<320;h=c[2440386]|0;i=15;j=(c[2415150]|0)+9600|0;k=e;e=c[2385338]|0;while(1){do{if((k|0)<=223){do{if(g){l=a[e]|0;if(l<<24>>24==15){break}b[j>>1]=c[h+((l&255)<<2)>>2]&65535}}while(0);do{if((f+1|0)>>>0<320){l=a[e+1|0]|0;if(l<<24>>24==15){break}b[j+2>>1]=c[h+((l&255)<<2)>>2]&65535}}while(0);do{if((f+2|0)>>>0<320){l=a[e+2|0]|0;if(l<<24>>24==15){break}b[j+4>>1]=c[h+((l&255)<<2)>>2]&65535}}while(0);do{if((f+3|0)>>>0<320){l=a[e+3|0]|0;if(l<<24>>24==15){break}b[j+6>>1]=c[h+((l&255)<<2)>>2]&65535}}while(0);do{if((f+4|0)>>>0<320){l=a[e+4|0]|0;if(l<<24>>24==15){break}b[j+8>>1]=c[h+((l&255)<<2)>>2]&65535}}while(0);do{if((f+5|0)>>>0<320){l=a[e+5|0]|0;if(l<<24>>24==15){break}b[j+10>>1]=c[h+((l&255)<<2)>>2]&65535}}while(0);do{if((f+6|0)>>>0<320){l=a[e+6|0]|0;if(l<<24>>24==15){break}b[j+12>>1]=c[h+((l&255)<<2)>>2]&65535}}while(0);do{if((f+7|0)>>>0<320){l=a[e+7|0]|0;if(l<<24>>24==15){break}b[j+14>>1]=c[h+((l&255)<<2)>>2]&65535}}while(0);do{if((f+8|0)>>>0<320){l=a[e+8|0]|0;if(l<<24>>24==15){break}b[j+16>>1]=c[h+((l&255)<<2)>>2]&65535}}while(0);do{if((f+9|0)>>>0<320){l=a[e+9|0]|0;if(l<<24>>24==15){break}b[j+18>>1]=c[h+((l&255)<<2)>>2]&65535}}while(0);do{if((f+10|0)>>>0<320){l=a[e+10|0]|0;if(l<<24>>24==15){break}b[j+20>>1]=c[h+((l&255)<<2)>>2]&65535}}while(0);do{if((f+11|0)>>>0<320){l=a[e+11|0]|0;if(l<<24>>24==15){break}b[j+22>>1]=c[h+((l&255)<<2)>>2]&65535}}while(0);do{if((f+12|0)>>>0<320){l=a[e+12|0]|0;if(l<<24>>24==15){break}b[j+24>>1]=c[h+((l&255)<<2)>>2]&65535}}while(0);do{if((f+13|0)>>>0<320){l=a[e+13|0]|0;if(l<<24>>24==15){break}b[j+26>>1]=c[h+((l&255)<<2)>>2]&65535}}while(0);do{if((f+14|0)>>>0<320){l=a[e+14|0]|0;if(l<<24>>24==15){break}b[j+28>>1]=c[h+((l&255)<<2)>>2]&65535}}while(0);if((f+15|0)>>>0>=320){break}l=a[e+15|0]|0;if(l<<24>>24==15){break}b[j+30>>1]=c[h+((l&255)<<2)>>2]&65535}}while(0);m=e+16|0;if((i|0)<=0){break}l=i-1|0;n=d+l|0;if((n|0)<0){break}else{i=l;j=j-640|0;k=n;e=m}}c[2385338]=m;return}function dWH(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;d=c[2415164]|0;f=c[2440386]|0;g=(c[2415150]|0)+9600|0;h=(c[2409606]|0)+9600|0;i=15;j=c[2385338]|0;while(1){k=a[j]|0;l=k&255;do{if(k<<24>>24==15){m=j}else{if((e[h>>1]|0|0)>(d|0)){m=j;break}b[g>>1]=c[f+(l<<2)>>2]&65535;m=j}}while(0);l=a[m+1|0]|0;k=l&255;do{if(l<<24>>24==15){n=m}else{if((e[h+2>>1]|0|0)>(d|0)){n=m;break}b[g+2>>1]=c[f+(k<<2)>>2]&65535;n=j}}while(0);k=a[n+2|0]|0;l=k&255;do{if(k<<24>>24==15){o=n}else{if((e[h+4>>1]|0|0)>(d|0)){o=n;break}b[g+4>>1]=c[f+(l<<2)>>2]&65535;o=j}}while(0);l=a[o+3|0]|0;k=l&255;do{if(l<<24>>24==15){p=o}else{if((e[h+6>>1]|0|0)>(d|0)){p=o;break}b[g+6>>1]=c[f+(k<<2)>>2]&65535;p=j}}while(0);k=a[p+4|0]|0;l=k&255;do{if(k<<24>>24==15){q=p}else{if((e[h+8>>1]|0|0)>(d|0)){q=p;break}b[g+8>>1]=c[f+(l<<2)>>2]&65535;q=j}}while(0);l=a[q+5|0]|0;k=l&255;do{if(l<<24>>24==15){r=q}else{if((e[h+10>>1]|0|0)>(d|0)){r=q;break}b[g+10>>1]=c[f+(k<<2)>>2]&65535;r=j}}while(0);k=a[r+6|0]|0;l=k&255;do{if(k<<24>>24==15){s=r}else{if((e[h+12>>1]|0|0)>(d|0)){s=r;break}b[g+12>>1]=c[f+(l<<2)>>2]&65535;s=j}}while(0);l=a[s+7|0]|0;k=l&255;do{if(l<<24>>24==15){t=s}else{if((e[h+14>>1]|0|0)>(d|0)){t=s;break}b[g+14>>1]=c[f+(k<<2)>>2]&65535;t=j}}while(0);k=a[t+8|0]|0;l=k&255;do{if(k<<24>>24==15){u=t}else{if((e[h+16>>1]|0|0)>(d|0)){u=t;break}b[g+16>>1]=c[f+(l<<2)>>2]&65535;u=j}}while(0);l=a[u+9|0]|0;k=l&255;do{if(l<<24>>24==15){v=u}else{if((e[h+18>>1]|0|0)>(d|0)){v=u;break}b[g+18>>1]=c[f+(k<<2)>>2]&65535;v=j}}while(0);k=a[v+10|0]|0;l=k&255;do{if(k<<24>>24==15){w=v}else{if((e[h+20>>1]|0|0)>(d|0)){w=v;break}b[g+20>>1]=c[f+(l<<2)>>2]&65535;w=j}}while(0);l=a[w+11|0]|0;k=l&255;do{if(l<<24>>24==15){x=w}else{if((e[h+22>>1]|0|0)>(d|0)){x=w;break}b[g+22>>1]=c[f+(k<<2)>>2]&65535;x=j}}while(0);k=a[x+12|0]|0;l=k&255;do{if(k<<24>>24==15){y=x}else{if((e[h+24>>1]|0|0)>(d|0)){y=x;break}b[g+24>>1]=c[f+(l<<2)>>2]&65535;y=j}}while(0);l=a[y+13|0]|0;k=l&255;do{if(l<<24>>24==15){z=y}else{if((e[h+26>>1]|0|0)>(d|0)){z=y;break}b[g+26>>1]=c[f+(k<<2)>>2]&65535;z=j}}while(0);k=a[z+14|0]|0;l=k&255;do{if(k<<24>>24==15){A=z}else{if((e[h+28>>1]|0|0)>(d|0)){A=z;break}b[g+28>>1]=c[f+(l<<2)>>2]&65535;A=j}}while(0);l=a[A+15|0]|0;k=l&255;do{if(l<<24>>24==15){B=A}else{if((e[h+30>>1]|0|0)>(d|0)){B=A;break}b[g+30>>1]=c[f+(k<<2)>>2]&65535;B=j}}while(0);C=B+16|0;if((i|0)>0){g=g-640|0;h=h-640|0;i=i-1|0;j=C}else{break}}c[2385338]=C;return}function dWI(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=c[2385456]|0;f=d+15|0;if((f|0)<0){return}g=c[2385468]|0;h=g>>>0<320;i=c[2415164]|0;j=c[2440386]|0;k=15;l=(c[2409606]|0)+9600|0;m=(c[2415150]|0)+9600|0;n=f;f=c[2385338]|0;while(1){do{if((n|0)<=223){do{if(h){o=a[f]|0;if(o<<24>>24==15){break}if((e[l>>1]|0|0)>(i|0)){break}b[m>>1]=c[j+((o&255)<<2)>>2]&65535}}while(0);do{if((g+1|0)>>>0<320){o=a[f+1|0]|0;if(o<<24>>24==15){break}if((e[l+2>>1]|0|0)>(i|0)){break}b[m+2>>1]=c[j+((o&255)<<2)>>2]&65535}}while(0);do{if((g+2|0)>>>0<320){o=a[f+2|0]|0;if(o<<24>>24==15){break}if((e[l+4>>1]|0|0)>(i|0)){break}b[m+4>>1]=c[j+((o&255)<<2)>>2]&65535}}while(0);do{if((g+3|0)>>>0<320){o=a[f+3|0]|0;if(o<<24>>24==15){break}if((e[l+6>>1]|0|0)>(i|0)){break}b[m+6>>1]=c[j+((o&255)<<2)>>2]&65535}}while(0);do{if((g+4|0)>>>0<320){o=a[f+4|0]|0;if(o<<24>>24==15){break}if((e[l+8>>1]|0|0)>(i|0)){break}b[m+8>>1]=c[j+((o&255)<<2)>>2]&65535}}while(0);do{if((g+5|0)>>>0<320){o=a[f+5|0]|0;if(o<<24>>24==15){break}if((e[l+10>>1]|0|0)>(i|0)){break}b[m+10>>1]=c[j+((o&255)<<2)>>2]&65535}}while(0);do{if((g+6|0)>>>0<320){o=a[f+6|0]|0;if(o<<24>>24==15){break}if((e[l+12>>1]|0|0)>(i|0)){break}b[m+12>>1]=c[j+((o&255)<<2)>>2]&65535}}while(0);do{if((g+7|0)>>>0<320){o=a[f+7|0]|0;if(o<<24>>24==15){break}if((e[l+14>>1]|0|0)>(i|0)){break}b[m+14>>1]=c[j+((o&255)<<2)>>2]&65535}}while(0);do{if((g+8|0)>>>0<320){o=a[f+8|0]|0;if(o<<24>>24==15){break}if((e[l+16>>1]|0|0)>(i|0)){break}b[m+16>>1]=c[j+((o&255)<<2)>>2]&65535}}while(0);do{if((g+9|0)>>>0<320){o=a[f+9|0]|0;if(o<<24>>24==15){break}if((e[l+18>>1]|0|0)>(i|0)){break}b[m+18>>1]=c[j+((o&255)<<2)>>2]&65535}}while(0);do{if((g+10|0)>>>0<320){o=a[f+10|0]|0;if(o<<24>>24==15){break}if((e[l+20>>1]|0|0)>(i|0)){break}b[m+20>>1]=c[j+((o&255)<<2)>>2]&65535}}while(0);do{if((g+11|0)>>>0<320){o=a[f+11|0]|0;if(o<<24>>24==15){break}if((e[l+22>>1]|0|0)>(i|0)){break}b[m+22>>1]=c[j+((o&255)<<2)>>2]&65535}}while(0);do{if((g+12|0)>>>0<320){o=a[f+12|0]|0;if(o<<24>>24==15){break}if((e[l+24>>1]|0|0)>(i|0)){break}b[m+24>>1]=c[j+((o&255)<<2)>>2]&65535}}while(0);do{if((g+13|0)>>>0<320){o=a[f+13|0]|0;if(o<<24>>24==15){break}if((e[l+26>>1]|0|0)>(i|0)){break}b[m+26>>1]=c[j+((o&255)<<2)>>2]&65535}}while(0);do{if((g+14|0)>>>0<320){o=a[f+14|0]|0;if(o<<24>>24==15){break}if((e[l+28>>1]|0|0)>(i|0)){break}b[m+28>>1]=c[j+((o&255)<<2)>>2]&65535}}while(0);if((g+15|0)>>>0>=320){break}o=a[f+15|0]|0;if(o<<24>>24==15){break}if((e[l+30>>1]|0|0)>(i|0)){break}b[m+30>>1]=c[j+((o&255)<<2)>>2]&65535}}while(0);p=f+16|0;if((k|0)<=0){break}o=k-1|0;q=d+o|0;if((q|0)<0){break}else{k=o;l=l-640|0;m=m-640|0;n=q;f=p}}c[2385338]=p;return}function dWJ(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=c[2415164]&65535;f=c[2440386]|0;g=(c[2415150]|0)+9600|0;h=(c[2409606]|0)+9600|0;i=15;j=c[2385338]|0;while(1){if((a[j]|0)!=15){b[h>>1]=e;b[g>>1]=c[f+(d[j]<<2)>>2]&65535}if((a[j+1|0]|0)!=15){b[h+2>>1]=e;b[g+2>>1]=c[f+(d[j+1|0]<<2)>>2]&65535}if((a[j+2|0]|0)!=15){b[h+4>>1]=e;b[g+4>>1]=c[f+(d[j+2|0]<<2)>>2]&65535}if((a[j+3|0]|0)!=15){b[h+6>>1]=e;b[g+6>>1]=c[f+(d[j+3|0]<<2)>>2]&65535}if((a[j+4|0]|0)!=15){b[h+8>>1]=e;b[g+8>>1]=c[f+(d[j+4|0]<<2)>>2]&65535}if((a[j+5|0]|0)!=15){b[h+10>>1]=e;b[g+10>>1]=c[f+(d[j+5|0]<<2)>>2]&65535}if((a[j+6|0]|0)!=15){b[h+12>>1]=e;b[g+12>>1]=c[f+(d[j+6|0]<<2)>>2]&65535}if((a[j+7|0]|0)!=15){b[h+14>>1]=e;b[g+14>>1]=c[f+(d[j+7|0]<<2)>>2]&65535}if((a[j+8|0]|0)!=15){b[h+16>>1]=e;b[g+16>>1]=c[f+(d[j+8|0]<<2)>>2]&65535}if((a[j+9|0]|0)!=15){b[h+18>>1]=e;b[g+18>>1]=c[f+(d[j+9|0]<<2)>>2]&65535}if((a[j+10|0]|0)!=15){b[h+20>>1]=e;b[g+20>>1]=c[f+(d[j+10|0]<<2)>>2]&65535}if((a[j+11|0]|0)!=15){b[h+22>>1]=e;b[g+22>>1]=c[f+(d[j+11|0]<<2)>>2]&65535}if((a[j+12|0]|0)!=15){b[h+24>>1]=e;b[g+24>>1]=c[f+(d[j+12|0]<<2)>>2]&65535}if((a[j+13|0]|0)!=15){b[h+26>>1]=e;b[g+26>>1]=c[f+(d[j+13|0]<<2)>>2]&65535}if((a[j+14|0]|0)!=15){b[h+28>>1]=e;b[g+28>>1]=c[f+(d[j+14|0]<<2)>>2]&65535}if((a[j+15|0]|0)!=15){b[h+30>>1]=e;b[g+30>>1]=c[f+(d[j+15|0]<<2)>>2]&65535}k=j+16|0;if((i|0)>0){g=g-640|0;h=h-640|0;i=i-1|0;j=k}else{break}}c[2385338]=k;return}function dWK(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=c[2385456]|0;f=e+15|0;if((f|0)<0){return}g=c[2385468]|0;h=g>>>0<320;i=c[2415164]&65535;j=c[2440386]|0;k=15;l=(c[2409606]|0)+9600|0;m=(c[2415150]|0)+9600|0;n=f;f=c[2385338]|0;while(1){do{if((n|0)<=223){do{if(h){if((a[f]|0)==15){break}b[l>>1]=i;b[m>>1]=c[j+(d[f]<<2)>>2]&65535}}while(0);do{if((g+1|0)>>>0<320){o=f+1|0;if((a[o]|0)==15){break}b[l+2>>1]=i;b[m+2>>1]=c[j+(d[o]<<2)>>2]&65535}}while(0);do{if((g+2|0)>>>0<320){o=f+2|0;if((a[o]|0)==15){break}b[l+4>>1]=i;b[m+4>>1]=c[j+(d[o]<<2)>>2]&65535}}while(0);do{if((g+3|0)>>>0<320){o=f+3|0;if((a[o]|0)==15){break}b[l+6>>1]=i;b[m+6>>1]=c[j+(d[o]<<2)>>2]&65535}}while(0);do{if((g+4|0)>>>0<320){o=f+4|0;if((a[o]|0)==15){break}b[l+8>>1]=i;b[m+8>>1]=c[j+(d[o]<<2)>>2]&65535}}while(0);do{if((g+5|0)>>>0<320){o=f+5|0;if((a[o]|0)==15){break}b[l+10>>1]=i;b[m+10>>1]=c[j+(d[o]<<2)>>2]&65535}}while(0);do{if((g+6|0)>>>0<320){o=f+6|0;if((a[o]|0)==15){break}b[l+12>>1]=i;b[m+12>>1]=c[j+(d[o]<<2)>>2]&65535}}while(0);do{if((g+7|0)>>>0<320){o=f+7|0;if((a[o]|0)==15){break}b[l+14>>1]=i;b[m+14>>1]=c[j+(d[o]<<2)>>2]&65535}}while(0);do{if((g+8|0)>>>0<320){o=f+8|0;if((a[o]|0)==15){break}b[l+16>>1]=i;b[m+16>>1]=c[j+(d[o]<<2)>>2]&65535}}while(0);do{if((g+9|0)>>>0<320){o=f+9|0;if((a[o]|0)==15){break}b[l+18>>1]=i;b[m+18>>1]=c[j+(d[o]<<2)>>2]&65535}}while(0);do{if((g+10|0)>>>0<320){o=f+10|0;if((a[o]|0)==15){break}b[l+20>>1]=i;b[m+20>>1]=c[j+(d[o]<<2)>>2]&65535}}while(0);do{if((g+11|0)>>>0<320){o=f+11|0;if((a[o]|0)==15){break}b[l+22>>1]=i;b[m+22>>1]=c[j+(d[o]<<2)>>2]&65535}}while(0);do{if((g+12|0)>>>0<320){o=f+12|0;if((a[o]|0)==15){break}b[l+24>>1]=i;b[m+24>>1]=c[j+(d[o]<<2)>>2]&65535}}while(0);do{if((g+13|0)>>>0<320){o=f+13|0;if((a[o]|0)==15){break}b[l+26>>1]=i;b[m+26>>1]=c[j+(d[o]<<2)>>2]&65535}}while(0);do{if((g+14|0)>>>0<320){o=f+14|0;if((a[o]|0)==15){break}b[l+28>>1]=i;b[m+28>>1]=c[j+(d[o]<<2)>>2]&65535}}while(0);if((g+15|0)>>>0>=320){break}o=f+15|0;if((a[o]|0)==15){break}b[l+30>>1]=i;b[m+30>>1]=c[j+(d[o]<<2)>>2]&65535}}while(0);p=f+16|0;if((k|0)<=0){break}o=k-1|0;q=e+o|0;if((q|0)<0){break}else{k=o;l=l-640|0;m=m-640|0;n=q;f=p}}c[2385338]=p;return}function dWL(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;f=c[2415164]|0;g=f&65535;h=c[2440386]|0;i=(c[2415150]|0)+9600|0;j=(c[2409606]|0)+9600|0;k=15;l=c[2385338]|0;while(1){do{if((a[l]|0)==15){m=l}else{if((e[j>>1]|0)>(f|0)){m=l;break}b[j>>1]=g;b[i>>1]=c[h+(d[l]<<2)>>2]&65535;m=l}}while(0);do{if((a[m+1|0]|0)==15){n=m}else{o=j+2|0;if((e[o>>1]|0)>(f|0)){n=m;break}b[o>>1]=g;b[i+2>>1]=c[h+(d[l+1|0]<<2)>>2]&65535;n=l}}while(0);do{if((a[n+2|0]|0)==15){p=n}else{o=j+4|0;if((e[o>>1]|0)>(f|0)){p=n;break}b[o>>1]=g;b[i+4>>1]=c[h+(d[l+2|0]<<2)>>2]&65535;p=l}}while(0);do{if((a[p+3|0]|0)==15){q=p}else{o=j+6|0;if((e[o>>1]|0)>(f|0)){q=p;break}b[o>>1]=g;b[i+6>>1]=c[h+(d[l+3|0]<<2)>>2]&65535;q=l}}while(0);do{if((a[q+4|0]|0)==15){r=q}else{o=j+8|0;if((e[o>>1]|0)>(f|0)){r=q;break}b[o>>1]=g;b[i+8>>1]=c[h+(d[l+4|0]<<2)>>2]&65535;r=l}}while(0);do{if((a[r+5|0]|0)==15){s=r}else{o=j+10|0;if((e[o>>1]|0)>(f|0)){s=r;break}b[o>>1]=g;b[i+10>>1]=c[h+(d[l+5|0]<<2)>>2]&65535;s=l}}while(0);do{if((a[s+6|0]|0)==15){t=s}else{o=j+12|0;if((e[o>>1]|0)>(f|0)){t=s;break}b[o>>1]=g;b[i+12>>1]=c[h+(d[l+6|0]<<2)>>2]&65535;t=l}}while(0);do{if((a[t+7|0]|0)==15){u=t}else{o=j+14|0;if((e[o>>1]|0)>(f|0)){u=t;break}b[o>>1]=g;b[i+14>>1]=c[h+(d[l+7|0]<<2)>>2]&65535;u=l}}while(0);do{if((a[u+8|0]|0)==15){v=u}else{o=j+16|0;if((e[o>>1]|0)>(f|0)){v=u;break}b[o>>1]=g;b[i+16>>1]=c[h+(d[l+8|0]<<2)>>2]&65535;v=l}}while(0);do{if((a[v+9|0]|0)==15){w=v}else{o=j+18|0;if((e[o>>1]|0)>(f|0)){w=v;break}b[o>>1]=g;b[i+18>>1]=c[h+(d[l+9|0]<<2)>>2]&65535;w=l}}while(0);do{if((a[w+10|0]|0)==15){x=w}else{o=j+20|0;if((e[o>>1]|0)>(f|0)){x=w;break}b[o>>1]=g;b[i+20>>1]=c[h+(d[l+10|0]<<2)>>2]&65535;x=l}}while(0);do{if((a[x+11|0]|0)==15){y=x}else{o=j+22|0;if((e[o>>1]|0)>(f|0)){y=x;break}b[o>>1]=g;b[i+22>>1]=c[h+(d[l+11|0]<<2)>>2]&65535;y=l}}while(0);do{if((a[y+12|0]|0)==15){z=y}else{o=j+24|0;if((e[o>>1]|0)>(f|0)){z=y;break}b[o>>1]=g;b[i+24>>1]=c[h+(d[l+12|0]<<2)>>2]&65535;z=l}}while(0);do{if((a[z+13|0]|0)==15){A=z}else{o=j+26|0;if((e[o>>1]|0)>(f|0)){A=z;break}b[o>>1]=g;b[i+26>>1]=c[h+(d[l+13|0]<<2)>>2]&65535;A=l}}while(0);do{if((a[A+14|0]|0)==15){B=A}else{o=j+28|0;if((e[o>>1]|0)>(f|0)){B=A;break}b[o>>1]=g;b[i+28>>1]=c[h+(d[l+14|0]<<2)>>2]&65535;B=l}}while(0);do{if((a[B+15|0]|0)==15){C=B}else{o=j+30|0;if((e[o>>1]|0)>(f|0)){C=B;break}b[o>>1]=g;b[i+30>>1]=c[h+(d[l+15|0]<<2)>>2]&65535;C=l}}while(0);D=C+16|0;if((k|0)>0){i=i-640|0;j=j-640|0;k=k-1|0;l=D}else{break}}c[2385338]=D;return}function dWM(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=c[2385456]|0;g=f+15|0;if((g|0)<0){return}h=c[2385468]|0;i=h>>>0<320;j=c[2415164]|0;k=j&65535;l=c[2440386]|0;m=15;n=(c[2409606]|0)+9600|0;o=(c[2415150]|0)+9600|0;p=g;g=c[2385338]|0;while(1){do{if((p|0)<=223){do{if(i){if((a[g]|0)==15){break}if((e[n>>1]|0)>(j|0)){break}b[n>>1]=k;b[o>>1]=c[l+(d[g]<<2)>>2]&65535}}while(0);do{if((h+1|0)>>>0<320){q=g+1|0;if((a[q]|0)==15){break}r=n+2|0;if((e[r>>1]|0)>(j|0)){break}b[r>>1]=k;b[o+2>>1]=c[l+(d[q]<<2)>>2]&65535}}while(0);do{if((h+2|0)>>>0<320){q=g+2|0;if((a[q]|0)==15){break}r=n+4|0;if((e[r>>1]|0)>(j|0)){break}b[r>>1]=k;b[o+4>>1]=c[l+(d[q]<<2)>>2]&65535}}while(0);do{if((h+3|0)>>>0<320){q=g+3|0;if((a[q]|0)==15){break}r=n+6|0;if((e[r>>1]|0)>(j|0)){break}b[r>>1]=k;b[o+6>>1]=c[l+(d[q]<<2)>>2]&65535}}while(0);do{if((h+4|0)>>>0<320){q=g+4|0;if((a[q]|0)==15){break}r=n+8|0;if((e[r>>1]|0)>(j|0)){break}b[r>>1]=k;b[o+8>>1]=c[l+(d[q]<<2)>>2]&65535}}while(0);do{if((h+5|0)>>>0<320){q=g+5|0;if((a[q]|0)==15){break}r=n+10|0;if((e[r>>1]|0)>(j|0)){break}b[r>>1]=k;b[o+10>>1]=c[l+(d[q]<<2)>>2]&65535}}while(0);do{if((h+6|0)>>>0<320){q=g+6|0;if((a[q]|0)==15){break}r=n+12|0;if((e[r>>1]|0)>(j|0)){break}b[r>>1]=k;b[o+12>>1]=c[l+(d[q]<<2)>>2]&65535}}while(0);do{if((h+7|0)>>>0<320){q=g+7|0;if((a[q]|0)==15){break}r=n+14|0;if((e[r>>1]|0)>(j|0)){break}b[r>>1]=k;b[o+14>>1]=c[l+(d[q]<<2)>>2]&65535}}while(0);do{if((h+8|0)>>>0<320){q=g+8|0;if((a[q]|0)==15){break}r=n+16|0;if((e[r>>1]|0)>(j|0)){break}b[r>>1]=k;b[o+16>>1]=c[l+(d[q]<<2)>>2]&65535}}while(0);do{if((h+9|0)>>>0<320){q=g+9|0;if((a[q]|0)==15){break}r=n+18|0;if((e[r>>1]|0)>(j|0)){break}b[r>>1]=k;b[o+18>>1]=c[l+(d[q]<<2)>>2]&65535}}while(0);do{if((h+10|0)>>>0<320){q=g+10|0;if((a[q]|0)==15){break}r=n+20|0;if((e[r>>1]|0)>(j|0)){break}b[r>>1]=k;b[o+20>>1]=c[l+(d[q]<<2)>>2]&65535}}while(0);do{if((h+11|0)>>>0<320){q=g+11|0;if((a[q]|0)==15){break}r=n+22|0;if((e[r>>1]|0)>(j|0)){break}b[r>>1]=k;b[o+22>>1]=c[l+(d[q]<<2)>>2]&65535}}while(0);do{if((h+12|0)>>>0<320){q=g+12|0;if((a[q]|0)==15){break}r=n+24|0;if((e[r>>1]|0)>(j|0)){break}b[r>>1]=k;b[o+24>>1]=c[l+(d[q]<<2)>>2]&65535}}while(0);do{if((h+13|0)>>>0<320){q=g+13|0;if((a[q]|0)==15){break}r=n+26|0;if((e[r>>1]|0)>(j|0)){break}b[r>>1]=k;b[o+26>>1]=c[l+(d[q]<<2)>>2]&65535}}while(0);do{if((h+14|0)>>>0<320){q=g+14|0;if((a[q]|0)==15){break}r=n+28|0;if((e[r>>1]|0)>(j|0)){break}b[r>>1]=k;b[o+28>>1]=c[l+(d[q]<<2)>>2]&65535}}while(0);if((h+15|0)>>>0>=320){break}q=g+15|0;if((a[q]|0)==15){break}r=n+30|0;if((e[r>>1]|0)>(j|0)){break}b[r>>1]=k;b[o+30>>1]=c[l+(d[q]<<2)>>2]&65535}}while(0);s=g+16|0;if((m|0)<=0){break}q=m-1|0;r=f+q|0;if((r|0)<0){break}else{m=q;n=n-640|0;o=o-640|0;p=r;g=s}}c[2385338]=s;return}function dWN(){var d=0,e=0,f=0,g=0,h=0,i=0;d=c[2440386]|0;e=(c[2415150]|0)+9600|0;f=15;g=c[2385338]|0;while(1){h=a[g+15|0]|0;if(h<<24>>24!=15){b[e>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+14|0]|0;if(h<<24>>24!=15){b[e+2>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+13|0]|0;if(h<<24>>24!=15){b[e+4>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+12|0]|0;if(h<<24>>24!=15){b[e+6>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+11|0]|0;if(h<<24>>24!=15){b[e+8>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+10|0]|0;if(h<<24>>24!=15){b[e+10>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+9|0]|0;if(h<<24>>24!=15){b[e+12>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+8|0]|0;if(h<<24>>24!=15){b[e+14>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+7|0]|0;if(h<<24>>24!=15){b[e+16>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+6|0]|0;if(h<<24>>24!=15){b[e+18>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+5|0]|0;if(h<<24>>24!=15){b[e+20>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+4|0]|0;if(h<<24>>24!=15){b[e+22>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+3|0]|0;if(h<<24>>24!=15){b[e+24>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+2|0]|0;if(h<<24>>24!=15){b[e+26>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+1|0]|0;if(h<<24>>24!=15){b[e+28>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g]|0;if(h<<24>>24!=15){b[e+30>>1]=c[d+((h&255)<<2)>>2]&65535}i=g+16|0;if((f|0)>0){e=e-640|0;f=f-1|0;g=i}else{break}}c[2385338]=i;return}function dWO(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=c[2385456]|0;e=d+15|0;if((e|0)<0){return}f=c[2385468]|0;g=f>>>0<320;h=c[2440386]|0;i=15;j=(c[2415150]|0)+9600|0;k=e;e=c[2385338]|0;while(1){do{if((k|0)<=223){do{if(g){l=a[e+15|0]|0;if(l<<24>>24==15){break}b[j>>1]=c[h+((l&255)<<2)>>2]&65535}}while(0);do{if((f+1|0)>>>0<320){l=a[e+14|0]|0;if(l<<24>>24==15){break}b[j+2>>1]=c[h+((l&255)<<2)>>2]&65535}}while(0);do{if((f+2|0)>>>0<320){l=a[e+13|0]|0;if(l<<24>>24==15){break}b[j+4>>1]=c[h+((l&255)<<2)>>2]&65535}}while(0);do{if((f+3|0)>>>0<320){l=a[e+12|0]|0;if(l<<24>>24==15){break}b[j+6>>1]=c[h+((l&255)<<2)>>2]&65535}}while(0);do{if((f+4|0)>>>0<320){l=a[e+11|0]|0;if(l<<24>>24==15){break}b[j+8>>1]=c[h+((l&255)<<2)>>2]&65535}}while(0);do{if((f+5|0)>>>0<320){l=a[e+10|0]|0;if(l<<24>>24==15){break}b[j+10>>1]=c[h+((l&255)<<2)>>2]&65535}}while(0);do{if((f+6|0)>>>0<320){l=a[e+9|0]|0;if(l<<24>>24==15){break}b[j+12>>1]=c[h+((l&255)<<2)>>2]&65535}}while(0);do{if((f+7|0)>>>0<320){l=a[e+8|0]|0;if(l<<24>>24==15){break}b[j+14>>1]=c[h+((l&255)<<2)>>2]&65535}}while(0);do{if((f+8|0)>>>0<320){l=a[e+7|0]|0;if(l<<24>>24==15){break}b[j+16>>1]=c[h+((l&255)<<2)>>2]&65535}}while(0);do{if((f+9|0)>>>0<320){l=a[e+6|0]|0;if(l<<24>>24==15){break}b[j+18>>1]=c[h+((l&255)<<2)>>2]&65535}}while(0);do{if((f+10|0)>>>0<320){l=a[e+5|0]|0;if(l<<24>>24==15){break}b[j+20>>1]=c[h+((l&255)<<2)>>2]&65535}}while(0);do{if((f+11|0)>>>0<320){l=a[e+4|0]|0;if(l<<24>>24==15){break}b[j+22>>1]=c[h+((l&255)<<2)>>2]&65535}}while(0);do{if((f+12|0)>>>0<320){l=a[e+3|0]|0;if(l<<24>>24==15){break}b[j+24>>1]=c[h+((l&255)<<2)>>2]&65535}}while(0);do{if((f+13|0)>>>0<320){l=a[e+2|0]|0;if(l<<24>>24==15){break}b[j+26>>1]=c[h+((l&255)<<2)>>2]&65535}}while(0);do{if((f+14|0)>>>0<320){l=a[e+1|0]|0;if(l<<24>>24==15){break}b[j+28>>1]=c[h+((l&255)<<2)>>2]&65535}}while(0);if((f+15|0)>>>0>=320){break}l=a[e]|0;if(l<<24>>24==15){break}b[j+30>>1]=c[h+((l&255)<<2)>>2]&65535}}while(0);m=e+16|0;if((i|0)<=0){break}l=i-1|0;n=d+l|0;if((n|0)<0){break}else{i=l;j=j-640|0;k=n;e=m}}c[2385338]=m;return}function dWP(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;d=c[2415164]|0;f=c[2440386]|0;g=(c[2415150]|0)+9600|0;h=(c[2409606]|0)+9600|0;i=15;j=c[2385338]|0;while(1){k=a[j+15|0]|0;l=k&255;do{if(k<<24>>24==15){m=j}else{if((e[h>>1]|0|0)>(d|0)){m=j;break}b[g>>1]=c[f+(l<<2)>>2]&65535;m=j}}while(0);l=a[m+14|0]|0;k=l&255;do{if(l<<24>>24==15){n=m}else{if((e[h+2>>1]|0|0)>(d|0)){n=m;break}b[g+2>>1]=c[f+(k<<2)>>2]&65535;n=j}}while(0);k=a[n+13|0]|0;l=k&255;do{if(k<<24>>24==15){o=n}else{if((e[h+4>>1]|0|0)>(d|0)){o=n;break}b[g+4>>1]=c[f+(l<<2)>>2]&65535;o=j}}while(0);l=a[o+12|0]|0;k=l&255;do{if(l<<24>>24==15){p=o}else{if((e[h+6>>1]|0|0)>(d|0)){p=o;break}b[g+6>>1]=c[f+(k<<2)>>2]&65535;p=j}}while(0);k=a[p+11|0]|0;l=k&255;do{if(k<<24>>24==15){q=p}else{if((e[h+8>>1]|0|0)>(d|0)){q=p;break}b[g+8>>1]=c[f+(l<<2)>>2]&65535;q=j}}while(0);l=a[q+10|0]|0;k=l&255;do{if(l<<24>>24==15){r=q}else{if((e[h+10>>1]|0|0)>(d|0)){r=q;break}b[g+10>>1]=c[f+(k<<2)>>2]&65535;r=j}}while(0);k=a[r+9|0]|0;l=k&255;do{if(k<<24>>24==15){s=r}else{if((e[h+12>>1]|0|0)>(d|0)){s=r;break}b[g+12>>1]=c[f+(l<<2)>>2]&65535;s=j}}while(0);l=a[s+8|0]|0;k=l&255;do{if(l<<24>>24==15){t=s}else{if((e[h+14>>1]|0|0)>(d|0)){t=s;break}b[g+14>>1]=c[f+(k<<2)>>2]&65535;t=j}}while(0);k=a[t+7|0]|0;l=k&255;do{if(k<<24>>24==15){u=t}else{if((e[h+16>>1]|0|0)>(d|0)){u=t;break}b[g+16>>1]=c[f+(l<<2)>>2]&65535;u=j}}while(0);l=a[u+6|0]|0;k=l&255;do{if(l<<24>>24==15){v=u}else{if((e[h+18>>1]|0|0)>(d|0)){v=u;break}b[g+18>>1]=c[f+(k<<2)>>2]&65535;v=j}}while(0);k=a[v+5|0]|0;l=k&255;do{if(k<<24>>24==15){w=v}else{if((e[h+20>>1]|0|0)>(d|0)){w=v;break}b[g+20>>1]=c[f+(l<<2)>>2]&65535;w=j}}while(0);l=a[w+4|0]|0;k=l&255;do{if(l<<24>>24==15){x=w}else{if((e[h+22>>1]|0|0)>(d|0)){x=w;break}b[g+22>>1]=c[f+(k<<2)>>2]&65535;x=j}}while(0);k=a[x+3|0]|0;l=k&255;do{if(k<<24>>24==15){y=x}else{if((e[h+24>>1]|0|0)>(d|0)){y=x;break}b[g+24>>1]=c[f+(l<<2)>>2]&65535;y=j}}while(0);l=a[y+2|0]|0;k=l&255;do{if(l<<24>>24==15){z=y}else{if((e[h+26>>1]|0|0)>(d|0)){z=y;break}b[g+26>>1]=c[f+(k<<2)>>2]&65535;z=j}}while(0);k=a[z+1|0]|0;l=k&255;do{if(k<<24>>24==15){A=z}else{if((e[h+28>>1]|0|0)>(d|0)){A=z;break}b[g+28>>1]=c[f+(l<<2)>>2]&65535;A=j}}while(0);l=a[A]|0;k=l&255;do{if(l<<24>>24==15){B=A}else{if((e[h+30>>1]|0|0)>(d|0)){B=A;break}b[g+30>>1]=c[f+(k<<2)>>2]&65535;B=j}}while(0);C=B+16|0;if((i|0)>0){g=g-640|0;h=h-640|0;i=i-1|0;j=C}else{break}}c[2385338]=C;return}function dWQ(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=c[2385456]|0;f=d+15|0;if((f|0)<0){return}g=c[2385468]|0;h=g>>>0<320;i=c[2415164]|0;j=c[2440386]|0;k=15;l=(c[2409606]|0)+9600|0;m=(c[2415150]|0)+9600|0;n=f;f=c[2385338]|0;while(1){do{if((n|0)<=223){do{if(h){o=a[f+15|0]|0;if(o<<24>>24==15){break}if((e[l>>1]|0|0)>(i|0)){break}b[m>>1]=c[j+((o&255)<<2)>>2]&65535}}while(0);do{if((g+1|0)>>>0<320){o=a[f+14|0]|0;if(o<<24>>24==15){break}if((e[l+2>>1]|0|0)>(i|0)){break}b[m+2>>1]=c[j+((o&255)<<2)>>2]&65535}}while(0);do{if((g+2|0)>>>0<320){o=a[f+13|0]|0;if(o<<24>>24==15){break}if((e[l+4>>1]|0|0)>(i|0)){break}b[m+4>>1]=c[j+((o&255)<<2)>>2]&65535}}while(0);do{if((g+3|0)>>>0<320){o=a[f+12|0]|0;if(o<<24>>24==15){break}if((e[l+6>>1]|0|0)>(i|0)){break}b[m+6>>1]=c[j+((o&255)<<2)>>2]&65535}}while(0);do{if((g+4|0)>>>0<320){o=a[f+11|0]|0;if(o<<24>>24==15){break}if((e[l+8>>1]|0|0)>(i|0)){break}b[m+8>>1]=c[j+((o&255)<<2)>>2]&65535}}while(0);do{if((g+5|0)>>>0<320){o=a[f+10|0]|0;if(o<<24>>24==15){break}if((e[l+10>>1]|0|0)>(i|0)){break}b[m+10>>1]=c[j+((o&255)<<2)>>2]&65535}}while(0);do{if((g+6|0)>>>0<320){o=a[f+9|0]|0;if(o<<24>>24==15){break}if((e[l+12>>1]|0|0)>(i|0)){break}b[m+12>>1]=c[j+((o&255)<<2)>>2]&65535}}while(0);do{if((g+7|0)>>>0<320){o=a[f+8|0]|0;if(o<<24>>24==15){break}if((e[l+14>>1]|0|0)>(i|0)){break}b[m+14>>1]=c[j+((o&255)<<2)>>2]&65535}}while(0);do{if((g+8|0)>>>0<320){o=a[f+7|0]|0;if(o<<24>>24==15){break}if((e[l+16>>1]|0|0)>(i|0)){break}b[m+16>>1]=c[j+((o&255)<<2)>>2]&65535}}while(0);do{if((g+9|0)>>>0<320){o=a[f+6|0]|0;if(o<<24>>24==15){break}if((e[l+18>>1]|0|0)>(i|0)){break}b[m+18>>1]=c[j+((o&255)<<2)>>2]&65535}}while(0);do{if((g+10|0)>>>0<320){o=a[f+5|0]|0;if(o<<24>>24==15){break}if((e[l+20>>1]|0|0)>(i|0)){break}b[m+20>>1]=c[j+((o&255)<<2)>>2]&65535}}while(0);do{if((g+11|0)>>>0<320){o=a[f+4|0]|0;if(o<<24>>24==15){break}if((e[l+22>>1]|0|0)>(i|0)){break}b[m+22>>1]=c[j+((o&255)<<2)>>2]&65535}}while(0);do{if((g+12|0)>>>0<320){o=a[f+3|0]|0;if(o<<24>>24==15){break}if((e[l+24>>1]|0|0)>(i|0)){break}b[m+24>>1]=c[j+((o&255)<<2)>>2]&65535}}while(0);do{if((g+13|0)>>>0<320){o=a[f+2|0]|0;if(o<<24>>24==15){break}if((e[l+26>>1]|0|0)>(i|0)){break}b[m+26>>1]=c[j+((o&255)<<2)>>2]&65535}}while(0);do{if((g+14|0)>>>0<320){o=a[f+1|0]|0;if(o<<24>>24==15){break}if((e[l+28>>1]|0|0)>(i|0)){break}b[m+28>>1]=c[j+((o&255)<<2)>>2]&65535}}while(0);if((g+15|0)>>>0>=320){break}o=a[f]|0;if(o<<24>>24==15){break}if((e[l+30>>1]|0|0)>(i|0)){break}b[m+30>>1]=c[j+((o&255)<<2)>>2]&65535}}while(0);p=f+16|0;if((k|0)<=0){break}o=k-1|0;q=d+o|0;if((q|0)<0){break}else{k=o;l=l-640|0;m=m-640|0;n=q;f=p}}c[2385338]=p;return}function dWR(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=c[2415164]&65535;f=c[2440386]|0;g=(c[2415150]|0)+9600|0;h=(c[2409606]|0)+9600|0;i=15;j=c[2385338]|0;while(1){if((a[j+15|0]|0)!=15){b[h>>1]=e;b[g>>1]=c[f+(d[j+15|0]<<2)>>2]&65535}if((a[j+14|0]|0)!=15){b[h+2>>1]=e;b[g+2>>1]=c[f+(d[j+14|0]<<2)>>2]&65535}if((a[j+13|0]|0)!=15){b[h+4>>1]=e;b[g+4>>1]=c[f+(d[j+13|0]<<2)>>2]&65535}if((a[j+12|0]|0)!=15){b[h+6>>1]=e;b[g+6>>1]=c[f+(d[j+12|0]<<2)>>2]&65535}if((a[j+11|0]|0)!=15){b[h+8>>1]=e;b[g+8>>1]=c[f+(d[j+11|0]<<2)>>2]&65535}if((a[j+10|0]|0)!=15){b[h+10>>1]=e;b[g+10>>1]=c[f+(d[j+10|0]<<2)>>2]&65535}if((a[j+9|0]|0)!=15){b[h+12>>1]=e;b[g+12>>1]=c[f+(d[j+9|0]<<2)>>2]&65535}if((a[j+8|0]|0)!=15){b[h+14>>1]=e;b[g+14>>1]=c[f+(d[j+8|0]<<2)>>2]&65535}if((a[j+7|0]|0)!=15){b[h+16>>1]=e;b[g+16>>1]=c[f+(d[j+7|0]<<2)>>2]&65535}if((a[j+6|0]|0)!=15){b[h+18>>1]=e;b[g+18>>1]=c[f+(d[j+6|0]<<2)>>2]&65535}if((a[j+5|0]|0)!=15){b[h+20>>1]=e;b[g+20>>1]=c[f+(d[j+5|0]<<2)>>2]&65535}if((a[j+4|0]|0)!=15){b[h+22>>1]=e;b[g+22>>1]=c[f+(d[j+4|0]<<2)>>2]&65535}if((a[j+3|0]|0)!=15){b[h+24>>1]=e;b[g+24>>1]=c[f+(d[j+3|0]<<2)>>2]&65535}if((a[j+2|0]|0)!=15){b[h+26>>1]=e;b[g+26>>1]=c[f+(d[j+2|0]<<2)>>2]&65535}if((a[j+1|0]|0)!=15){b[h+28>>1]=e;b[g+28>>1]=c[f+(d[j+1|0]<<2)>>2]&65535}if((a[j]|0)!=15){b[h+30>>1]=e;b[g+30>>1]=c[f+(d[j]<<2)>>2]&65535}k=j+16|0;if((i|0)>0){g=g-640|0;h=h-640|0;i=i-1|0;j=k}else{break}}c[2385338]=k;return}function dWS(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=c[2385456]|0;f=e+15|0;if((f|0)<0){return}g=c[2385468]|0;h=g>>>0<320;i=c[2415164]&65535;j=c[2440386]|0;k=15;l=(c[2409606]|0)+9600|0;m=(c[2415150]|0)+9600|0;n=f;f=c[2385338]|0;while(1){do{if((n|0)<=223){do{if(h){o=f+15|0;if((a[o]|0)==15){break}b[l>>1]=i;b[m>>1]=c[j+(d[o]<<2)>>2]&65535}}while(0);do{if((g+1|0)>>>0<320){o=f+14|0;if((a[o]|0)==15){break}b[l+2>>1]=i;b[m+2>>1]=c[j+(d[o]<<2)>>2]&65535}}while(0);do{if((g+2|0)>>>0<320){o=f+13|0;if((a[o]|0)==15){break}b[l+4>>1]=i;b[m+4>>1]=c[j+(d[o]<<2)>>2]&65535}}while(0);do{if((g+3|0)>>>0<320){o=f+12|0;if((a[o]|0)==15){break}b[l+6>>1]=i;b[m+6>>1]=c[j+(d[o]<<2)>>2]&65535}}while(0);do{if((g+4|0)>>>0<320){o=f+11|0;if((a[o]|0)==15){break}b[l+8>>1]=i;b[m+8>>1]=c[j+(d[o]<<2)>>2]&65535}}while(0);do{if((g+5|0)>>>0<320){o=f+10|0;if((a[o]|0)==15){break}b[l+10>>1]=i;b[m+10>>1]=c[j+(d[o]<<2)>>2]&65535}}while(0);do{if((g+6|0)>>>0<320){o=f+9|0;if((a[o]|0)==15){break}b[l+12>>1]=i;b[m+12>>1]=c[j+(d[o]<<2)>>2]&65535}}while(0);do{if((g+7|0)>>>0<320){o=f+8|0;if((a[o]|0)==15){break}b[l+14>>1]=i;b[m+14>>1]=c[j+(d[o]<<2)>>2]&65535}}while(0);do{if((g+8|0)>>>0<320){o=f+7|0;if((a[o]|0)==15){break}b[l+16>>1]=i;b[m+16>>1]=c[j+(d[o]<<2)>>2]&65535}}while(0);do{if((g+9|0)>>>0<320){o=f+6|0;if((a[o]|0)==15){break}b[l+18>>1]=i;b[m+18>>1]=c[j+(d[o]<<2)>>2]&65535}}while(0);do{if((g+10|0)>>>0<320){o=f+5|0;if((a[o]|0)==15){break}b[l+20>>1]=i;b[m+20>>1]=c[j+(d[o]<<2)>>2]&65535}}while(0);do{if((g+11|0)>>>0<320){o=f+4|0;if((a[o]|0)==15){break}b[l+22>>1]=i;b[m+22>>1]=c[j+(d[o]<<2)>>2]&65535}}while(0);do{if((g+12|0)>>>0<320){o=f+3|0;if((a[o]|0)==15){break}b[l+24>>1]=i;b[m+24>>1]=c[j+(d[o]<<2)>>2]&65535}}while(0);do{if((g+13|0)>>>0<320){o=f+2|0;if((a[o]|0)==15){break}b[l+26>>1]=i;b[m+26>>1]=c[j+(d[o]<<2)>>2]&65535}}while(0);do{if((g+14|0)>>>0<320){o=f+1|0;if((a[o]|0)==15){break}b[l+28>>1]=i;b[m+28>>1]=c[j+(d[o]<<2)>>2]&65535}}while(0);if((g+15|0)>>>0>=320){break}if((a[f]|0)==15){break}b[l+30>>1]=i;b[m+30>>1]=c[j+(d[f]<<2)>>2]&65535}}while(0);p=f+16|0;if((k|0)<=0){break}o=k-1|0;q=e+o|0;if((q|0)<0){break}else{k=o;l=l-640|0;m=m-640|0;n=q;f=p}}c[2385338]=p;return}function dWT(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;f=c[2415164]|0;g=f&65535;h=c[2440386]|0;i=(c[2415150]|0)+9600|0;j=(c[2409606]|0)+9600|0;k=15;l=c[2385338]|0;while(1){do{if((a[l+15|0]|0)==15){m=l}else{if((e[j>>1]|0)>(f|0)){m=l;break}b[j>>1]=g;b[i>>1]=c[h+(d[l+15|0]<<2)>>2]&65535;m=l}}while(0);do{if((a[m+14|0]|0)==15){n=m}else{o=j+2|0;if((e[o>>1]|0)>(f|0)){n=m;break}b[o>>1]=g;b[i+2>>1]=c[h+(d[l+14|0]<<2)>>2]&65535;n=l}}while(0);do{if((a[n+13|0]|0)==15){p=n}else{o=j+4|0;if((e[o>>1]|0)>(f|0)){p=n;break}b[o>>1]=g;b[i+4>>1]=c[h+(d[l+13|0]<<2)>>2]&65535;p=l}}while(0);do{if((a[p+12|0]|0)==15){q=p}else{o=j+6|0;if((e[o>>1]|0)>(f|0)){q=p;break}b[o>>1]=g;b[i+6>>1]=c[h+(d[l+12|0]<<2)>>2]&65535;q=l}}while(0);do{if((a[q+11|0]|0)==15){r=q}else{o=j+8|0;if((e[o>>1]|0)>(f|0)){r=q;break}b[o>>1]=g;b[i+8>>1]=c[h+(d[l+11|0]<<2)>>2]&65535;r=l}}while(0);do{if((a[r+10|0]|0)==15){s=r}else{o=j+10|0;if((e[o>>1]|0)>(f|0)){s=r;break}b[o>>1]=g;b[i+10>>1]=c[h+(d[l+10|0]<<2)>>2]&65535;s=l}}while(0);do{if((a[s+9|0]|0)==15){t=s}else{o=j+12|0;if((e[o>>1]|0)>(f|0)){t=s;break}b[o>>1]=g;b[i+12>>1]=c[h+(d[l+9|0]<<2)>>2]&65535;t=l}}while(0);do{if((a[t+8|0]|0)==15){u=t}else{o=j+14|0;if((e[o>>1]|0)>(f|0)){u=t;break}b[o>>1]=g;b[i+14>>1]=c[h+(d[l+8|0]<<2)>>2]&65535;u=l}}while(0);do{if((a[u+7|0]|0)==15){v=u}else{o=j+16|0;if((e[o>>1]|0)>(f|0)){v=u;break}b[o>>1]=g;b[i+16>>1]=c[h+(d[l+7|0]<<2)>>2]&65535;v=l}}while(0);do{if((a[v+6|0]|0)==15){w=v}else{o=j+18|0;if((e[o>>1]|0)>(f|0)){w=v;break}b[o>>1]=g;b[i+18>>1]=c[h+(d[l+6|0]<<2)>>2]&65535;w=l}}while(0);do{if((a[w+5|0]|0)==15){x=w}else{o=j+20|0;if((e[o>>1]|0)>(f|0)){x=w;break}b[o>>1]=g;b[i+20>>1]=c[h+(d[l+5|0]<<2)>>2]&65535;x=l}}while(0);do{if((a[x+4|0]|0)==15){y=x}else{o=j+22|0;if((e[o>>1]|0)>(f|0)){y=x;break}b[o>>1]=g;b[i+22>>1]=c[h+(d[l+4|0]<<2)>>2]&65535;y=l}}while(0);do{if((a[y+3|0]|0)==15){z=y}else{o=j+24|0;if((e[o>>1]|0)>(f|0)){z=y;break}b[o>>1]=g;b[i+24>>1]=c[h+(d[l+3|0]<<2)>>2]&65535;z=l}}while(0);do{if((a[z+2|0]|0)==15){A=z}else{o=j+26|0;if((e[o>>1]|0)>(f|0)){A=z;break}b[o>>1]=g;b[i+26>>1]=c[h+(d[l+2|0]<<2)>>2]&65535;A=l}}while(0);do{if((a[A+1|0]|0)==15){B=A}else{o=j+28|0;if((e[o>>1]|0)>(f|0)){B=A;break}b[o>>1]=g;b[i+28>>1]=c[h+(d[l+1|0]<<2)>>2]&65535;B=l}}while(0);do{if((a[B]|0)==15){C=B}else{o=j+30|0;if((e[o>>1]|0)>(f|0)){C=B;break}b[o>>1]=g;b[i+30>>1]=c[h+(d[l]<<2)>>2]&65535;C=l}}while(0);D=C+16|0;if((k|0)>0){i=i-640|0;j=j-640|0;k=k-1|0;l=D}else{break}}c[2385338]=D;return}function dWU(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=c[2385456]|0;g=f+15|0;if((g|0)<0){return}h=c[2385468]|0;i=h>>>0<320;j=c[2415164]|0;k=j&65535;l=c[2440386]|0;m=15;n=(c[2409606]|0)+9600|0;o=(c[2415150]|0)+9600|0;p=g;g=c[2385338]|0;while(1){do{if((p|0)<=223){do{if(i){q=g+15|0;if((a[q]|0)==15){break}if((e[n>>1]|0)>(j|0)){break}b[n>>1]=k;b[o>>1]=c[l+(d[q]<<2)>>2]&65535}}while(0);do{if((h+1|0)>>>0<320){q=g+14|0;if((a[q]|0)==15){break}r=n+2|0;if((e[r>>1]|0)>(j|0)){break}b[r>>1]=k;b[o+2>>1]=c[l+(d[q]<<2)>>2]&65535}}while(0);do{if((h+2|0)>>>0<320){q=g+13|0;if((a[q]|0)==15){break}r=n+4|0;if((e[r>>1]|0)>(j|0)){break}b[r>>1]=k;b[o+4>>1]=c[l+(d[q]<<2)>>2]&65535}}while(0);do{if((h+3|0)>>>0<320){q=g+12|0;if((a[q]|0)==15){break}r=n+6|0;if((e[r>>1]|0)>(j|0)){break}b[r>>1]=k;b[o+6>>1]=c[l+(d[q]<<2)>>2]&65535}}while(0);do{if((h+4|0)>>>0<320){q=g+11|0;if((a[q]|0)==15){break}r=n+8|0;if((e[r>>1]|0)>(j|0)){break}b[r>>1]=k;b[o+8>>1]=c[l+(d[q]<<2)>>2]&65535}}while(0);do{if((h+5|0)>>>0<320){q=g+10|0;if((a[q]|0)==15){break}r=n+10|0;if((e[r>>1]|0)>(j|0)){break}b[r>>1]=k;b[o+10>>1]=c[l+(d[q]<<2)>>2]&65535}}while(0);do{if((h+6|0)>>>0<320){q=g+9|0;if((a[q]|0)==15){break}r=n+12|0;if((e[r>>1]|0)>(j|0)){break}b[r>>1]=k;b[o+12>>1]=c[l+(d[q]<<2)>>2]&65535}}while(0);do{if((h+7|0)>>>0<320){q=g+8|0;if((a[q]|0)==15){break}r=n+14|0;if((e[r>>1]|0)>(j|0)){break}b[r>>1]=k;b[o+14>>1]=c[l+(d[q]<<2)>>2]&65535}}while(0);do{if((h+8|0)>>>0<320){q=g+7|0;if((a[q]|0)==15){break}r=n+16|0;if((e[r>>1]|0)>(j|0)){break}b[r>>1]=k;b[o+16>>1]=c[l+(d[q]<<2)>>2]&65535}}while(0);do{if((h+9|0)>>>0<320){q=g+6|0;if((a[q]|0)==15){break}r=n+18|0;if((e[r>>1]|0)>(j|0)){break}b[r>>1]=k;b[o+18>>1]=c[l+(d[q]<<2)>>2]&65535}}while(0);do{if((h+10|0)>>>0<320){q=g+5|0;if((a[q]|0)==15){break}r=n+20|0;if((e[r>>1]|0)>(j|0)){break}b[r>>1]=k;b[o+20>>1]=c[l+(d[q]<<2)>>2]&65535}}while(0);do{if((h+11|0)>>>0<320){q=g+4|0;if((a[q]|0)==15){break}r=n+22|0;if((e[r>>1]|0)>(j|0)){break}b[r>>1]=k;b[o+22>>1]=c[l+(d[q]<<2)>>2]&65535}}while(0);do{if((h+12|0)>>>0<320){q=g+3|0;if((a[q]|0)==15){break}r=n+24|0;if((e[r>>1]|0)>(j|0)){break}b[r>>1]=k;b[o+24>>1]=c[l+(d[q]<<2)>>2]&65535}}while(0);do{if((h+13|0)>>>0<320){q=g+2|0;if((a[q]|0)==15){break}r=n+26|0;if((e[r>>1]|0)>(j|0)){break}b[r>>1]=k;b[o+26>>1]=c[l+(d[q]<<2)>>2]&65535}}while(0);do{if((h+14|0)>>>0<320){q=g+1|0;if((a[q]|0)==15){break}r=n+28|0;if((e[r>>1]|0)>(j|0)){break}b[r>>1]=k;b[o+28>>1]=c[l+(d[q]<<2)>>2]&65535}}while(0);if((h+15|0)>>>0>=320){break}if((a[g]|0)==15){break}q=n+30|0;if((e[q>>1]|0)>(j|0)){break}b[q>>1]=k;b[o+30>>1]=c[l+(d[g]<<2)>>2]&65535}}while(0);s=g+16|0;if((m|0)<=0){break}q=m-1|0;r=f+q|0;if((r|0)<0){break}else{m=q;n=n-640|0;o=o-640|0;p=r;g=s}}c[2385338]=s;return}function dWV(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=c[3528502]|0;if((d|0)<=0){return}e=c[3528424]|0;f=c[3528504]|0;g=(f|0)<9;h=c[3528422]|0;i=e+32|0;j=e+36|0;k=e+40|0;l=e+44|0;m=e+48|0;n=e+52|0;o=e+56|0;p=e+60|0;q=c[2440386]|0;r=c[2415150]|0;s=0;t=c[2385338]|0;while(1){u=a[t+(c[e>>2]|0)|0]|0;if(u<<24>>24!=15){b[r>>1]=c[q+((u&255)<<2)>>2]&65535}u=a[t+(c[e+4>>2]|0)|0]|0;if(u<<24>>24!=15){b[r+2>>1]=c[q+((u&255)<<2)>>2]&65535}u=a[t+(c[e+8>>2]|0)|0]|0;if(u<<24>>24!=15){b[r+4>>1]=c[q+((u&255)<<2)>>2]&65535}u=a[t+(c[e+12>>2]|0)|0]|0;if(u<<24>>24!=15){b[r+6>>1]=c[q+((u&255)<<2)>>2]&65535}u=a[t+(c[e+16>>2]|0)|0]|0;if(u<<24>>24!=15){b[r+8>>1]=c[q+((u&255)<<2)>>2]&65535}u=a[t+(c[e+20>>2]|0)|0]|0;if(u<<24>>24!=15){b[r+10>>1]=c[q+((u&255)<<2)>>2]&65535}u=a[t+(c[e+24>>2]|0)|0]|0;if(u<<24>>24!=15){b[r+12>>1]=c[q+((u&255)<<2)>>2]&65535}u=a[t+(c[e+28>>2]|0)|0]|0;if(u<<24>>24!=15){b[r+14>>1]=c[q+((u&255)<<2)>>2]&65535}do{if(!g){u=a[t+(c[i>>2]|0)|0]|0;if(u<<24>>24!=15){b[r+16>>1]=c[q+((u&255)<<2)>>2]&65535}if((f|0)<10){break}u=a[t+(c[j>>2]|0)|0]|0;if(u<<24>>24!=15){b[r+18>>1]=c[q+((u&255)<<2)>>2]&65535}if((f|0)<11){break}u=a[t+(c[k>>2]|0)|0]|0;if(u<<24>>24!=15){b[r+20>>1]=c[q+((u&255)<<2)>>2]&65535}if((f|0)<12){break}u=a[t+(c[l>>2]|0)|0]|0;if(u<<24>>24!=15){b[r+22>>1]=c[q+((u&255)<<2)>>2]&65535}if((f|0)<13){break}u=a[t+(c[m>>2]|0)|0]|0;if(u<<24>>24!=15){b[r+24>>1]=c[q+((u&255)<<2)>>2]&65535}if((f|0)<14){break}u=a[t+(c[n>>2]|0)|0]|0;if(u<<24>>24!=15){b[r+26>>1]=c[q+((u&255)<<2)>>2]&65535}if((f|0)<15){break}u=a[t+(c[o>>2]|0)|0]|0;if(u<<24>>24!=15){b[r+28>>1]=c[q+((u&255)<<2)>>2]&65535}if((f|0)<16){break}u=a[t+(c[p>>2]|0)|0]|0;if(u<<24>>24==15){break}b[r+30>>1]=c[q+((u&255)<<2)>>2]&65535}}while(0);v=t+(c[h+(s<<2)>>2]|0)|0;u=s+1|0;if((u|0)>=(d|0)){break}r=r+640|0;s=u;t=v}c[2385338]=v;return}function dWW(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;d=c[3528502]|0;if((d|0)<=0){return}e=c[2385456]|0;f=c[3528422]|0;g=c[2385468]|0;h=g>>>0<320;i=c[3528424]|0;j=c[2440386]|0;k=i+4|0;l=i+8|0;m=i+12|0;n=i+16|0;o=i+20|0;p=i+24|0;q=i+28|0;r=c[3528504]|0;s=(r|0)<9;t=(g+8|0)>>>0<320;u=i+32|0;v=(g+9|0)>>>0<320;w=i+36|0;x=(g+10|0)>>>0<320;y=i+40|0;z=(g+11|0)>>>0<320;A=i+44|0;B=(g+12|0)>>>0<320;C=i+48|0;D=(g+13|0)>>>0<320;E=i+52|0;F=(g+14|0)>>>0<320;G=i+56|0;H=(g+15|0)>>>0<320;I=i+60|0;J=c[2415150]|0;K=0;L38099:while(1){L=e+K|0;do{if((L|0)>=0){if((L|0)>223){M=28818;break L38099}do{if(h){N=a[(c[2385338]|0)+(c[i>>2]|0)|0]|0;if(N<<24>>24==15){break}b[J>>1]=c[j+((N&255)<<2)>>2]&65535}}while(0);do{if((g+1|0)>>>0<320){N=a[(c[2385338]|0)+(c[k>>2]|0)|0]|0;if(N<<24>>24==15){break}b[J+2>>1]=c[j+((N&255)<<2)>>2]&65535}}while(0);do{if((g+2|0)>>>0<320){N=a[(c[2385338]|0)+(c[l>>2]|0)|0]|0;if(N<<24>>24==15){break}b[J+4>>1]=c[j+((N&255)<<2)>>2]&65535}}while(0);do{if((g+3|0)>>>0<320){N=a[(c[2385338]|0)+(c[m>>2]|0)|0]|0;if(N<<24>>24==15){break}b[J+6>>1]=c[j+((N&255)<<2)>>2]&65535}}while(0);do{if((g+4|0)>>>0<320){N=a[(c[2385338]|0)+(c[n>>2]|0)|0]|0;if(N<<24>>24==15){break}b[J+8>>1]=c[j+((N&255)<<2)>>2]&65535}}while(0);do{if((g+5|0)>>>0<320){N=a[(c[2385338]|0)+(c[o>>2]|0)|0]|0;if(N<<24>>24==15){break}b[J+10>>1]=c[j+((N&255)<<2)>>2]&65535}}while(0);do{if((g+6|0)>>>0<320){N=a[(c[2385338]|0)+(c[p>>2]|0)|0]|0;if(N<<24>>24==15){break}b[J+12>>1]=c[j+((N&255)<<2)>>2]&65535}}while(0);do{if((g+7|0)>>>0<320){N=a[(c[2385338]|0)+(c[q>>2]|0)|0]|0;if(N<<24>>24==15){break}b[J+14>>1]=c[j+((N&255)<<2)>>2]&65535}}while(0);if(s){break}do{if(t){N=a[(c[2385338]|0)+(c[u>>2]|0)|0]|0;if(N<<24>>24==15){break}b[J+16>>1]=c[j+((N&255)<<2)>>2]&65535}}while(0);if((r|0)<10){break}do{if(v){N=a[(c[2385338]|0)+(c[w>>2]|0)|0]|0;if(N<<24>>24==15){break}b[J+18>>1]=c[j+((N&255)<<2)>>2]&65535}}while(0);if((r|0)<11){break}do{if(x){N=a[(c[2385338]|0)+(c[y>>2]|0)|0]|0;if(N<<24>>24==15){break}b[J+20>>1]=c[j+((N&255)<<2)>>2]&65535}}while(0);if((r|0)<12){break}do{if(z){N=a[(c[2385338]|0)+(c[A>>2]|0)|0]|0;if(N<<24>>24==15){break}b[J+22>>1]=c[j+((N&255)<<2)>>2]&65535}}while(0);if((r|0)<13){break}do{if(B){N=a[(c[2385338]|0)+(c[C>>2]|0)|0]|0;if(N<<24>>24==15){break}b[J+24>>1]=c[j+((N&255)<<2)>>2]&65535}}while(0);if((r|0)<14){break}do{if(D){N=a[(c[2385338]|0)+(c[E>>2]|0)|0]|0;if(N<<24>>24==15){break}b[J+26>>1]=c[j+((N&255)<<2)>>2]&65535}}while(0);if((r|0)<15){break}do{if(F){N=a[(c[2385338]|0)+(c[G>>2]|0)|0]|0;if(N<<24>>24==15){break}b[J+28>>1]=c[j+((N&255)<<2)>>2]&65535}}while(0);if((r|0)<16|H^1){break}N=a[(c[2385338]|0)+(c[I>>2]|0)|0]|0;if(N<<24>>24==15){break}b[J+30>>1]=c[j+((N&255)<<2)>>2]&65535}}while(0);c[2385338]=(c[2385338]|0)+(c[f+(K<<2)>>2]|0);L=K+1|0;if((L|0)>=(d|0)){M=28816;break}J=J+640|0;K=L}if((M|0)==28816){return}else if((M|0)==28818){return}}function dWX(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;d=c[3528502]|0;if((d|0)<=0){return}f=c[3528424]|0;g=c[3528504]|0;h=(g|0)<9;i=c[3528422]|0;j=f+32|0;k=f+36|0;l=f+40|0;m=f+44|0;n=f+48|0;o=f+52|0;p=f+56|0;q=f+60|0;r=c[2415164]|0;s=c[2440386]|0;t=c[2415150]|0;u=c[2409606]|0;v=0;w=c[2385338]|0;while(1){x=a[w+(c[f>>2]|0)|0]|0;y=x&255;do{if(x<<24>>24==15){z=w}else{if((e[u>>1]|0|0)>(r|0)){z=w;break}b[t>>1]=c[s+(y<<2)>>2]&65535;z=w}}while(0);y=a[z+(c[f+4>>2]|0)|0]|0;x=y&255;do{if(y<<24>>24==15){A=z}else{if((e[u+2>>1]|0|0)>(r|0)){A=z;break}b[t+2>>1]=c[s+(x<<2)>>2]&65535;A=w}}while(0);x=a[A+(c[f+8>>2]|0)|0]|0;y=x&255;do{if(x<<24>>24==15){B=A}else{if((e[u+4>>1]|0|0)>(r|0)){B=A;break}b[t+4>>1]=c[s+(y<<2)>>2]&65535;B=w}}while(0);y=a[B+(c[f+12>>2]|0)|0]|0;x=y&255;do{if(y<<24>>24==15){C=B}else{if((e[u+6>>1]|0|0)>(r|0)){C=B;break}b[t+6>>1]=c[s+(x<<2)>>2]&65535;C=w}}while(0);x=a[C+(c[f+16>>2]|0)|0]|0;y=x&255;do{if(x<<24>>24==15){D=C}else{if((e[u+8>>1]|0|0)>(r|0)){D=C;break}b[t+8>>1]=c[s+(y<<2)>>2]&65535;D=w}}while(0);y=a[D+(c[f+20>>2]|0)|0]|0;x=y&255;do{if(y<<24>>24==15){E=D}else{if((e[u+10>>1]|0|0)>(r|0)){E=D;break}b[t+10>>1]=c[s+(x<<2)>>2]&65535;E=w}}while(0);x=a[E+(c[f+24>>2]|0)|0]|0;y=x&255;do{if(x<<24>>24==15){F=E}else{if((e[u+12>>1]|0|0)>(r|0)){F=E;break}b[t+12>>1]=c[s+(y<<2)>>2]&65535;F=w}}while(0);y=a[F+(c[f+28>>2]|0)|0]|0;x=y&255;do{if(y<<24>>24!=15){if((e[u+14>>1]|0|0)>(r|0)){break}b[t+14>>1]=c[s+(x<<2)>>2]&65535}}while(0);do{if(!h){x=a[w+(c[j>>2]|0)|0]|0;y=x&255;do{if(x<<24>>24!=15){if((e[u+16>>1]|0|0)>(r|0)){break}b[t+16>>1]=c[s+(y<<2)>>2]&65535}}while(0);if((g|0)<10){break}y=a[w+(c[k>>2]|0)|0]|0;x=y&255;do{if(y<<24>>24!=15){if((e[u+18>>1]|0|0)>(r|0)){break}b[t+18>>1]=c[s+(x<<2)>>2]&65535}}while(0);if((g|0)<11){break}x=a[w+(c[l>>2]|0)|0]|0;y=x&255;do{if(x<<24>>24!=15){if((e[u+20>>1]|0|0)>(r|0)){break}b[t+20>>1]=c[s+(y<<2)>>2]&65535}}while(0);if((g|0)<12){break}y=a[w+(c[m>>2]|0)|0]|0;x=y&255;do{if(y<<24>>24!=15){if((e[u+22>>1]|0|0)>(r|0)){break}b[t+22>>1]=c[s+(x<<2)>>2]&65535}}while(0);if((g|0)<13){break}x=a[w+(c[n>>2]|0)|0]|0;y=x&255;do{if(x<<24>>24!=15){if((e[u+24>>1]|0|0)>(r|0)){break}b[t+24>>1]=c[s+(y<<2)>>2]&65535}}while(0);if((g|0)<14){break}y=a[w+(c[o>>2]|0)|0]|0;x=y&255;do{if(y<<24>>24!=15){if((e[u+26>>1]|0|0)>(r|0)){break}b[t+26>>1]=c[s+(x<<2)>>2]&65535}}while(0);if((g|0)<15){break}x=a[w+(c[p>>2]|0)|0]|0;y=x&255;do{if(x<<24>>24!=15){if((e[u+28>>1]|0|0)>(r|0)){break}b[t+28>>1]=c[s+(y<<2)>>2]&65535}}while(0);if((g|0)<16){break}y=a[w+(c[q>>2]|0)|0]|0;if(y<<24>>24==15){break}if((e[u+30>>1]|0|0)>(r|0)){break}b[t+30>>1]=c[s+((y&255)<<2)>>2]&65535}}while(0);G=w+(c[i+(v<<2)>>2]|0)|0;y=v+1|0;if((y|0)>=(d|0)){break}t=t+640|0;u=u+640|0;v=y;w=G}c[2385338]=G;return}function dWY(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;d=c[3528502]|0;if((d|0)<=0){return}f=c[2385456]|0;g=c[3528422]|0;h=c[2385468]|0;i=h>>>0<320;j=c[3528424]|0;k=c[2415164]|0;l=c[2440386]|0;m=j+4|0;n=j+8|0;o=j+12|0;p=j+16|0;q=j+20|0;r=j+24|0;s=j+28|0;t=c[3528504]|0;u=(t|0)<9;v=(h+8|0)>>>0<320;w=j+32|0;x=(h+9|0)>>>0<320;y=j+36|0;z=(h+10|0)>>>0<320;A=j+40|0;B=(h+11|0)>>>0<320;C=j+44|0;D=(h+12|0)>>>0<320;E=j+48|0;F=(h+13|0)>>>0<320;G=j+52|0;H=(h+14|0)>>>0<320;I=j+56|0;J=(h+15|0)>>>0<320;K=j+60|0;L=c[2415150]|0;M=c[2409606]|0;N=0;L38263:while(1){O=f+N|0;do{if((O|0)>=0){if((O|0)>223){P=28963;break L38263}do{if(i){Q=a[(c[2385338]|0)+(c[j>>2]|0)|0]|0;if(Q<<24>>24==15){break}if((e[M>>1]|0|0)>(k|0)){break}b[L>>1]=c[l+((Q&255)<<2)>>2]&65535}}while(0);do{if((h+1|0)>>>0<320){Q=a[(c[2385338]|0)+(c[m>>2]|0)|0]|0;if(Q<<24>>24==15){break}if((e[M+2>>1]|0|0)>(k|0)){break}b[L+2>>1]=c[l+((Q&255)<<2)>>2]&65535}}while(0);do{if((h+2|0)>>>0<320){Q=a[(c[2385338]|0)+(c[n>>2]|0)|0]|0;if(Q<<24>>24==15){break}if((e[M+4>>1]|0|0)>(k|0)){break}b[L+4>>1]=c[l+((Q&255)<<2)>>2]&65535}}while(0);do{if((h+3|0)>>>0<320){Q=a[(c[2385338]|0)+(c[o>>2]|0)|0]|0;if(Q<<24>>24==15){break}if((e[M+6>>1]|0|0)>(k|0)){break}b[L+6>>1]=c[l+((Q&255)<<2)>>2]&65535}}while(0);do{if((h+4|0)>>>0<320){Q=a[(c[2385338]|0)+(c[p>>2]|0)|0]|0;if(Q<<24>>24==15){break}if((e[M+8>>1]|0|0)>(k|0)){break}b[L+8>>1]=c[l+((Q&255)<<2)>>2]&65535}}while(0);do{if((h+5|0)>>>0<320){Q=a[(c[2385338]|0)+(c[q>>2]|0)|0]|0;if(Q<<24>>24==15){break}if((e[M+10>>1]|0|0)>(k|0)){break}b[L+10>>1]=c[l+((Q&255)<<2)>>2]&65535}}while(0);do{if((h+6|0)>>>0<320){Q=a[(c[2385338]|0)+(c[r>>2]|0)|0]|0;if(Q<<24>>24==15){break}if((e[M+12>>1]|0|0)>(k|0)){break}b[L+12>>1]=c[l+((Q&255)<<2)>>2]&65535}}while(0);do{if((h+7|0)>>>0<320){Q=a[(c[2385338]|0)+(c[s>>2]|0)|0]|0;if(Q<<24>>24==15){break}if((e[M+14>>1]|0|0)>(k|0)){break}b[L+14>>1]=c[l+((Q&255)<<2)>>2]&65535}}while(0);if(u){break}do{if(v){Q=a[(c[2385338]|0)+(c[w>>2]|0)|0]|0;if(Q<<24>>24==15){break}if((e[M+16>>1]|0|0)>(k|0)){break}b[L+16>>1]=c[l+((Q&255)<<2)>>2]&65535}}while(0);if((t|0)<10){break}do{if(x){Q=a[(c[2385338]|0)+(c[y>>2]|0)|0]|0;if(Q<<24>>24==15){break}if((e[M+18>>1]|0|0)>(k|0)){break}b[L+18>>1]=c[l+((Q&255)<<2)>>2]&65535}}while(0);if((t|0)<11){break}do{if(z){Q=a[(c[2385338]|0)+(c[A>>2]|0)|0]|0;if(Q<<24>>24==15){break}if((e[M+20>>1]|0|0)>(k|0)){break}b[L+20>>1]=c[l+((Q&255)<<2)>>2]&65535}}while(0);if((t|0)<12){break}do{if(B){Q=a[(c[2385338]|0)+(c[C>>2]|0)|0]|0;if(Q<<24>>24==15){break}if((e[M+22>>1]|0|0)>(k|0)){break}b[L+22>>1]=c[l+((Q&255)<<2)>>2]&65535}}while(0);if((t|0)<13){break}do{if(D){Q=a[(c[2385338]|0)+(c[E>>2]|0)|0]|0;if(Q<<24>>24==15){break}if((e[M+24>>1]|0|0)>(k|0)){break}b[L+24>>1]=c[l+((Q&255)<<2)>>2]&65535}}while(0);if((t|0)<14){break}do{if(F){Q=a[(c[2385338]|0)+(c[G>>2]|0)|0]|0;if(Q<<24>>24==15){break}if((e[M+26>>1]|0|0)>(k|0)){break}b[L+26>>1]=c[l+((Q&255)<<2)>>2]&65535}}while(0);if((t|0)<15){break}do{if(H){Q=a[(c[2385338]|0)+(c[I>>2]|0)|0]|0;if(Q<<24>>24==15){break}if((e[M+28>>1]|0|0)>(k|0)){break}b[L+28>>1]=c[l+((Q&255)<<2)>>2]&65535}}while(0);if((t|0)<16|J^1){break}Q=a[(c[2385338]|0)+(c[K>>2]|0)|0]|0;if(Q<<24>>24==15){break}if((e[M+30>>1]|0|0)>(k|0)){break}b[L+30>>1]=c[l+((Q&255)<<2)>>2]&65535}}while(0);c[2385338]=(c[2385338]|0)+(c[g+(N<<2)>>2]|0);O=N+1|0;if((O|0)>=(d|0)){P=28962;break}L=L+640|0;M=M+640|0;N=O}if((P|0)==28962){return}else if((P|0)==28963){return}}function dWZ(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;e=c[3528502]|0;if((e|0)<=0){return}f=c[3528424]|0;g=c[3528504]|0;h=(g|0)<9;i=c[3528422]|0;j=f+32|0;k=f+36|0;l=f+40|0;m=f+44|0;n=f+48|0;o=f+52|0;p=f+56|0;q=f+60|0;r=c[2415164]&65535;s=c[2440386]|0;t=f+28|0;u=f+24|0;v=f+20|0;w=f+16|0;x=f+12|0;y=f+8|0;z=f+4|0;A=c[2415150]|0;B=c[2409606]|0;C=0;D=c[2385338]|0;while(1){if((a[D+(c[f>>2]|0)|0]|0)!=15){b[B>>1]=r;b[A>>1]=c[s+(d[D+(c[f>>2]|0)|0]<<2)>>2]&65535}if((a[D+(c[z>>2]|0)|0]|0)!=15){b[B+2>>1]=r;b[A+2>>1]=c[s+(d[D+(c[z>>2]|0)|0]<<2)>>2]&65535}if((a[D+(c[y>>2]|0)|0]|0)!=15){b[B+4>>1]=r;b[A+4>>1]=c[s+(d[D+(c[y>>2]|0)|0]<<2)>>2]&65535}if((a[D+(c[x>>2]|0)|0]|0)!=15){b[B+6>>1]=r;b[A+6>>1]=c[s+(d[D+(c[x>>2]|0)|0]<<2)>>2]&65535}if((a[D+(c[w>>2]|0)|0]|0)!=15){b[B+8>>1]=r;b[A+8>>1]=c[s+(d[D+(c[w>>2]|0)|0]<<2)>>2]&65535}if((a[D+(c[v>>2]|0)|0]|0)!=15){b[B+10>>1]=r;b[A+10>>1]=c[s+(d[D+(c[v>>2]|0)|0]<<2)>>2]&65535}if((a[D+(c[u>>2]|0)|0]|0)!=15){b[B+12>>1]=r;b[A+12>>1]=c[s+(d[D+(c[u>>2]|0)|0]<<2)>>2]&65535}if((a[D+(c[t>>2]|0)|0]|0)!=15){b[B+14>>1]=r;b[A+14>>1]=c[s+(d[D+(c[t>>2]|0)|0]<<2)>>2]&65535}do{if(!h){if((a[D+(c[j>>2]|0)|0]|0)!=15){b[B+16>>1]=r;b[A+16>>1]=c[s+(d[D+(c[j>>2]|0)|0]<<2)>>2]&65535}if((g|0)<10){break}if((a[D+(c[k>>2]|0)|0]|0)!=15){b[B+18>>1]=r;b[A+18>>1]=c[s+(d[D+(c[k>>2]|0)|0]<<2)>>2]&65535}if((g|0)<11){break}if((a[D+(c[l>>2]|0)|0]|0)!=15){b[B+20>>1]=r;b[A+20>>1]=c[s+(d[D+(c[l>>2]|0)|0]<<2)>>2]&65535}if((g|0)<12){break}if((a[D+(c[m>>2]|0)|0]|0)!=15){b[B+22>>1]=r;b[A+22>>1]=c[s+(d[D+(c[m>>2]|0)|0]<<2)>>2]&65535}if((g|0)<13){break}if((a[D+(c[n>>2]|0)|0]|0)!=15){b[B+24>>1]=r;b[A+24>>1]=c[s+(d[D+(c[n>>2]|0)|0]<<2)>>2]&65535}if((g|0)<14){break}if((a[D+(c[o>>2]|0)|0]|0)!=15){b[B+26>>1]=r;b[A+26>>1]=c[s+(d[D+(c[o>>2]|0)|0]<<2)>>2]&65535}if((g|0)<15){break}if((a[D+(c[p>>2]|0)|0]|0)!=15){b[B+28>>1]=r;b[A+28>>1]=c[s+(d[D+(c[p>>2]|0)|0]<<2)>>2]&65535}if((g|0)<16){break}if((a[D+(c[q>>2]|0)|0]|0)==15){break}b[B+30>>1]=r;b[A+30>>1]=c[s+(d[D+(c[q>>2]|0)|0]<<2)>>2]&65535}}while(0);E=D+(c[i+(C<<2)>>2]|0)|0;F=C+1|0;if((F|0)>=(e|0)){break}A=A+640|0;B=B+640|0;C=F;D=E}c[2385338]=E;return}function dW_(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;e=c[3528502]|0;if((e|0)<=0){return}f=c[2385456]|0;g=c[3528422]|0;h=c[2385468]|0;i=h>>>0<320;j=c[3528424]|0;k=c[2415164]&65535;l=c[2440386]|0;m=j+4|0;n=j+8|0;o=j+12|0;p=j+16|0;q=j+20|0;r=j+24|0;s=j+28|0;t=c[3528504]|0;u=(t|0)<9;v=(h+8|0)>>>0<320;w=j+32|0;x=(h+9|0)>>>0<320;y=j+36|0;z=(h+10|0)>>>0<320;A=j+40|0;B=(h+11|0)>>>0<320;C=j+44|0;D=(h+12|0)>>>0<320;E=j+48|0;F=(h+13|0)>>>0<320;G=j+52|0;H=(h+14|0)>>>0<320;I=j+56|0;J=(h+15|0)>>>0<320;K=j+60|0;L=c[2415150]|0;M=c[2409606]|0;N=0;L38427:while(1){O=f+N|0;do{if((O|0)>=0){if((O|0)>223){P=29075;break L38427}do{if(i){Q=c[2385338]|0;if((a[Q+(c[j>>2]|0)|0]|0)==15){break}b[M>>1]=k;b[L>>1]=c[l+(d[Q+(c[j>>2]|0)|0]<<2)>>2]&65535}}while(0);do{if((h+1|0)>>>0<320){Q=c[2385338]|0;if((a[Q+(c[m>>2]|0)|0]|0)==15){break}b[M+2>>1]=k;b[L+2>>1]=c[l+(d[Q+(c[m>>2]|0)|0]<<2)>>2]&65535}}while(0);do{if((h+2|0)>>>0<320){Q=c[2385338]|0;if((a[Q+(c[n>>2]|0)|0]|0)==15){break}b[M+4>>1]=k;b[L+4>>1]=c[l+(d[Q+(c[n>>2]|0)|0]<<2)>>2]&65535}}while(0);do{if((h+3|0)>>>0<320){Q=c[2385338]|0;if((a[Q+(c[o>>2]|0)|0]|0)==15){break}b[M+6>>1]=k;b[L+6>>1]=c[l+(d[Q+(c[o>>2]|0)|0]<<2)>>2]&65535}}while(0);do{if((h+4|0)>>>0<320){Q=c[2385338]|0;if((a[Q+(c[p>>2]|0)|0]|0)==15){break}b[M+8>>1]=k;b[L+8>>1]=c[l+(d[Q+(c[p>>2]|0)|0]<<2)>>2]&65535}}while(0);do{if((h+5|0)>>>0<320){Q=c[2385338]|0;if((a[Q+(c[q>>2]|0)|0]|0)==15){break}b[M+10>>1]=k;b[L+10>>1]=c[l+(d[Q+(c[q>>2]|0)|0]<<2)>>2]&65535}}while(0);do{if((h+6|0)>>>0<320){Q=c[2385338]|0;if((a[Q+(c[r>>2]|0)|0]|0)==15){break}b[M+12>>1]=k;b[L+12>>1]=c[l+(d[Q+(c[r>>2]|0)|0]<<2)>>2]&65535}}while(0);do{if((h+7|0)>>>0<320){Q=c[2385338]|0;if((a[Q+(c[s>>2]|0)|0]|0)==15){break}b[M+14>>1]=k;b[L+14>>1]=c[l+(d[Q+(c[s>>2]|0)|0]<<2)>>2]&65535}}while(0);if(u){break}do{if(v){Q=c[2385338]|0;if((a[Q+(c[w>>2]|0)|0]|0)==15){break}b[M+16>>1]=k;b[L+16>>1]=c[l+(d[Q+(c[w>>2]|0)|0]<<2)>>2]&65535}}while(0);if((t|0)<10){break}do{if(x){Q=c[2385338]|0;if((a[Q+(c[y>>2]|0)|0]|0)==15){break}b[M+18>>1]=k;b[L+18>>1]=c[l+(d[Q+(c[y>>2]|0)|0]<<2)>>2]&65535}}while(0);if((t|0)<11){break}do{if(z){Q=c[2385338]|0;if((a[Q+(c[A>>2]|0)|0]|0)==15){break}b[M+20>>1]=k;b[L+20>>1]=c[l+(d[Q+(c[A>>2]|0)|0]<<2)>>2]&65535}}while(0);if((t|0)<12){break}do{if(B){Q=c[2385338]|0;if((a[Q+(c[C>>2]|0)|0]|0)==15){break}b[M+22>>1]=k;b[L+22>>1]=c[l+(d[Q+(c[C>>2]|0)|0]<<2)>>2]&65535}}while(0);if((t|0)<13){break}do{if(D){Q=c[2385338]|0;if((a[Q+(c[E>>2]|0)|0]|0)==15){break}b[M+24>>1]=k;b[L+24>>1]=c[l+(d[Q+(c[E>>2]|0)|0]<<2)>>2]&65535}}while(0);if((t|0)<14){break}do{if(F){Q=c[2385338]|0;if((a[Q+(c[G>>2]|0)|0]|0)==15){break}b[M+26>>1]=k;b[L+26>>1]=c[l+(d[Q+(c[G>>2]|0)|0]<<2)>>2]&65535}}while(0);if((t|0)<15){break}do{if(H){Q=c[2385338]|0;if((a[Q+(c[I>>2]|0)|0]|0)==15){break}b[M+28>>1]=k;b[L+28>>1]=c[l+(d[Q+(c[I>>2]|0)|0]<<2)>>2]&65535}}while(0);if((t|0)<16|J^1){break}Q=c[2385338]|0;if((a[Q+(c[K>>2]|0)|0]|0)==15){break}b[M+30>>1]=k;b[L+30>>1]=c[l+(d[Q+(c[K>>2]|0)|0]<<2)>>2]&65535}}while(0);c[2385338]=(c[2385338]|0)+(c[g+(N<<2)>>2]|0);O=N+1|0;if((O|0)>=(e|0)){P=29076;break}L=L+640|0;M=M+640|0;N=O}if((P|0)==29075){return}else if((P|0)==29076){return}}function dW$(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;f=c[3528502]|0;if((f|0)<=0){return}g=c[3528424]|0;h=c[3528504]|0;i=(h|0)<9;j=c[3528422]|0;k=g+32|0;l=g+36|0;m=g+40|0;n=g+44|0;o=g+48|0;p=g+52|0;q=g+56|0;r=g+60|0;s=c[2415164]|0;t=s&65535;u=c[2440386]|0;v=g+28|0;w=g+24|0;x=g+20|0;y=g+16|0;z=g+12|0;A=g+8|0;B=g+4|0;C=c[2415150]|0;D=c[2409606]|0;E=0;F=c[2385338]|0;while(1){do{if((a[F+(c[g>>2]|0)|0]|0)==15){G=F}else{if((e[D>>1]|0)>(s|0)){G=F;break}b[D>>1]=t;b[C>>1]=c[u+(d[F+(c[g>>2]|0)|0]<<2)>>2]&65535;G=F}}while(0);do{if((a[G+(c[B>>2]|0)|0]|0)==15){H=G}else{I=D+2|0;if((e[I>>1]|0)>(s|0)){H=G;break}b[I>>1]=t;b[C+2>>1]=c[u+(d[F+(c[B>>2]|0)|0]<<2)>>2]&65535;H=F}}while(0);do{if((a[H+(c[A>>2]|0)|0]|0)==15){J=H}else{I=D+4|0;if((e[I>>1]|0)>(s|0)){J=H;break}b[I>>1]=t;b[C+4>>1]=c[u+(d[F+(c[A>>2]|0)|0]<<2)>>2]&65535;J=F}}while(0);do{if((a[J+(c[z>>2]|0)|0]|0)==15){K=J}else{I=D+6|0;if((e[I>>1]|0)>(s|0)){K=J;break}b[I>>1]=t;b[C+6>>1]=c[u+(d[F+(c[z>>2]|0)|0]<<2)>>2]&65535;K=F}}while(0);do{if((a[K+(c[y>>2]|0)|0]|0)==15){L=K}else{I=D+8|0;if((e[I>>1]|0)>(s|0)){L=K;break}b[I>>1]=t;b[C+8>>1]=c[u+(d[F+(c[y>>2]|0)|0]<<2)>>2]&65535;L=F}}while(0);do{if((a[L+(c[x>>2]|0)|0]|0)==15){M=L}else{I=D+10|0;if((e[I>>1]|0)>(s|0)){M=L;break}b[I>>1]=t;b[C+10>>1]=c[u+(d[F+(c[x>>2]|0)|0]<<2)>>2]&65535;M=F}}while(0);do{if((a[M+(c[w>>2]|0)|0]|0)==15){N=M}else{I=D+12|0;if((e[I>>1]|0)>(s|0)){N=M;break}b[I>>1]=t;b[C+12>>1]=c[u+(d[F+(c[w>>2]|0)|0]<<2)>>2]&65535;N=F}}while(0);do{if((a[N+(c[v>>2]|0)|0]|0)!=15){I=D+14|0;if((e[I>>1]|0)>(s|0)){break}b[I>>1]=t;b[C+14>>1]=c[u+(d[F+(c[v>>2]|0)|0]<<2)>>2]&65535}}while(0);do{if(!i){do{if((a[F+(c[k>>2]|0)|0]|0)!=15){I=D+16|0;if((e[I>>1]|0)>(s|0)){break}b[I>>1]=t;b[C+16>>1]=c[u+(d[F+(c[k>>2]|0)|0]<<2)>>2]&65535}}while(0);if((h|0)<10){break}do{if((a[F+(c[l>>2]|0)|0]|0)!=15){I=D+18|0;if((e[I>>1]|0)>(s|0)){break}b[I>>1]=t;b[C+18>>1]=c[u+(d[F+(c[l>>2]|0)|0]<<2)>>2]&65535}}while(0);if((h|0)<11){break}do{if((a[F+(c[m>>2]|0)|0]|0)!=15){I=D+20|0;if((e[I>>1]|0)>(s|0)){break}b[I>>1]=t;b[C+20>>1]=c[u+(d[F+(c[m>>2]|0)|0]<<2)>>2]&65535}}while(0);if((h|0)<12){break}do{if((a[F+(c[n>>2]|0)|0]|0)!=15){I=D+22|0;if((e[I>>1]|0)>(s|0)){break}b[I>>1]=t;b[C+22>>1]=c[u+(d[F+(c[n>>2]|0)|0]<<2)>>2]&65535}}while(0);if((h|0)<13){break}do{if((a[F+(c[o>>2]|0)|0]|0)!=15){I=D+24|0;if((e[I>>1]|0)>(s|0)){break}b[I>>1]=t;b[C+24>>1]=c[u+(d[F+(c[o>>2]|0)|0]<<2)>>2]&65535}}while(0);if((h|0)<14){break}do{if((a[F+(c[p>>2]|0)|0]|0)!=15){I=D+26|0;if((e[I>>1]|0)>(s|0)){break}b[I>>1]=t;b[C+26>>1]=c[u+(d[F+(c[p>>2]|0)|0]<<2)>>2]&65535}}while(0);if((h|0)<15){break}do{if((a[F+(c[q>>2]|0)|0]|0)!=15){I=D+28|0;if((e[I>>1]|0)>(s|0)){break}b[I>>1]=t;b[C+28>>1]=c[u+(d[F+(c[q>>2]|0)|0]<<2)>>2]&65535}}while(0);if((h|0)<16){break}if((a[F+(c[r>>2]|0)|0]|0)==15){break}I=D+30|0;if((e[I>>1]|0)>(s|0)){break}b[I>>1]=t;b[C+30>>1]=c[u+(d[F+(c[r>>2]|0)|0]<<2)>>2]&65535}}while(0);O=F+(c[j+(E<<2)>>2]|0)|0;I=E+1|0;if((I|0)>=(f|0)){break}C=C+640|0;D=D+640|0;E=I;F=O}c[2385338]=O;return}function dW0(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;f=c[3528502]|0;if((f|0)<=0){return}g=c[2385456]|0;h=c[3528422]|0;i=c[2385468]|0;j=i>>>0<320;k=c[3528424]|0;l=c[2415164]|0;m=l&65535;n=c[2440386]|0;o=k+4|0;p=k+8|0;q=k+12|0;r=k+16|0;s=k+20|0;t=k+24|0;u=k+28|0;v=c[3528504]|0;w=(v|0)<9;x=(i+8|0)>>>0<320;y=k+32|0;z=(i+9|0)>>>0<320;A=k+36|0;B=(i+10|0)>>>0<320;C=k+40|0;D=(i+11|0)>>>0<320;E=k+44|0;F=(i+12|0)>>>0<320;G=k+48|0;H=(i+13|0)>>>0<320;I=k+52|0;J=(i+14|0)>>>0<320;K=k+56|0;L=(i+15|0)>>>0<320;M=k+60|0;N=c[2415150]|0;O=c[2409606]|0;P=0;L38591:while(1){Q=g+P|0;do{if((Q|0)>=0){if((Q|0)>223){R=29221;break L38591}do{if(j){S=c[2385338]|0;if((a[S+(c[k>>2]|0)|0]|0)==15){break}if((e[O>>1]|0)>(l|0)){break}b[O>>1]=m;b[N>>1]=c[n+(d[S+(c[k>>2]|0)|0]<<2)>>2]&65535}}while(0);do{if((i+1|0)>>>0<320){S=c[2385338]|0;if((a[S+(c[o>>2]|0)|0]|0)==15){break}T=O+2|0;if((e[T>>1]|0)>(l|0)){break}b[T>>1]=m;b[N+2>>1]=c[n+(d[S+(c[o>>2]|0)|0]<<2)>>2]&65535}}while(0);do{if((i+2|0)>>>0<320){S=c[2385338]|0;if((a[S+(c[p>>2]|0)|0]|0)==15){break}T=O+4|0;if((e[T>>1]|0)>(l|0)){break}b[T>>1]=m;b[N+4>>1]=c[n+(d[S+(c[p>>2]|0)|0]<<2)>>2]&65535}}while(0);do{if((i+3|0)>>>0<320){S=c[2385338]|0;if((a[S+(c[q>>2]|0)|0]|0)==15){break}T=O+6|0;if((e[T>>1]|0)>(l|0)){break}b[T>>1]=m;b[N+6>>1]=c[n+(d[S+(c[q>>2]|0)|0]<<2)>>2]&65535}}while(0);do{if((i+4|0)>>>0<320){S=c[2385338]|0;if((a[S+(c[r>>2]|0)|0]|0)==15){break}T=O+8|0;if((e[T>>1]|0)>(l|0)){break}b[T>>1]=m;b[N+8>>1]=c[n+(d[S+(c[r>>2]|0)|0]<<2)>>2]&65535}}while(0);do{if((i+5|0)>>>0<320){S=c[2385338]|0;if((a[S+(c[s>>2]|0)|0]|0)==15){break}T=O+10|0;if((e[T>>1]|0)>(l|0)){break}b[T>>1]=m;b[N+10>>1]=c[n+(d[S+(c[s>>2]|0)|0]<<2)>>2]&65535}}while(0);do{if((i+6|0)>>>0<320){S=c[2385338]|0;if((a[S+(c[t>>2]|0)|0]|0)==15){break}T=O+12|0;if((e[T>>1]|0)>(l|0)){break}b[T>>1]=m;b[N+12>>1]=c[n+(d[S+(c[t>>2]|0)|0]<<2)>>2]&65535}}while(0);do{if((i+7|0)>>>0<320){S=c[2385338]|0;if((a[S+(c[u>>2]|0)|0]|0)==15){break}T=O+14|0;if((e[T>>1]|0)>(l|0)){break}b[T>>1]=m;b[N+14>>1]=c[n+(d[S+(c[u>>2]|0)|0]<<2)>>2]&65535}}while(0);if(w){break}do{if(x){S=c[2385338]|0;if((a[S+(c[y>>2]|0)|0]|0)==15){break}T=O+16|0;if((e[T>>1]|0)>(l|0)){break}b[T>>1]=m;b[N+16>>1]=c[n+(d[S+(c[y>>2]|0)|0]<<2)>>2]&65535}}while(0);if((v|0)<10){break}do{if(z){S=c[2385338]|0;if((a[S+(c[A>>2]|0)|0]|0)==15){break}T=O+18|0;if((e[T>>1]|0)>(l|0)){break}b[T>>1]=m;b[N+18>>1]=c[n+(d[S+(c[A>>2]|0)|0]<<2)>>2]&65535}}while(0);if((v|0)<11){break}do{if(B){S=c[2385338]|0;if((a[S+(c[C>>2]|0)|0]|0)==15){break}T=O+20|0;if((e[T>>1]|0)>(l|0)){break}b[T>>1]=m;b[N+20>>1]=c[n+(d[S+(c[C>>2]|0)|0]<<2)>>2]&65535}}while(0);if((v|0)<12){break}do{if(D){S=c[2385338]|0;if((a[S+(c[E>>2]|0)|0]|0)==15){break}T=O+22|0;if((e[T>>1]|0)>(l|0)){break}b[T>>1]=m;b[N+22>>1]=c[n+(d[S+(c[E>>2]|0)|0]<<2)>>2]&65535}}while(0);if((v|0)<13){break}do{if(F){S=c[2385338]|0;if((a[S+(c[G>>2]|0)|0]|0)==15){break}T=O+24|0;if((e[T>>1]|0)>(l|0)){break}b[T>>1]=m;b[N+24>>1]=c[n+(d[S+(c[G>>2]|0)|0]<<2)>>2]&65535}}while(0);if((v|0)<14){break}do{if(H){S=c[2385338]|0;if((a[S+(c[I>>2]|0)|0]|0)==15){break}T=O+26|0;if((e[T>>1]|0)>(l|0)){break}b[T>>1]=m;b[N+26>>1]=c[n+(d[S+(c[I>>2]|0)|0]<<2)>>2]&65535}}while(0);if((v|0)<15){break}do{if(J){S=c[2385338]|0;if((a[S+(c[K>>2]|0)|0]|0)==15){break}T=O+28|0;if((e[T>>1]|0)>(l|0)){break}b[T>>1]=m;b[N+28>>1]=c[n+(d[S+(c[K>>2]|0)|0]<<2)>>2]&65535}}while(0);if((v|0)<16|L^1){break}S=c[2385338]|0;if((a[S+(c[M>>2]|0)|0]|0)==15){break}T=O+30|0;if((e[T>>1]|0)>(l|0)){break}b[T>>1]=m;b[N+30>>1]=c[n+(d[S+(c[M>>2]|0)|0]<<2)>>2]&65535}}while(0);c[2385338]=(c[2385338]|0)+(c[h+(P<<2)>>2]|0);Q=P+1|0;if((Q|0)>=(f|0)){R=29220;break}N=N+640|0;O=O+640|0;P=Q}if((R|0)==29220){return}else if((R|0)==29221){return}}function dW1(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=c[3528502]|0;if((d|0)<=0){return}e=c[3528424]|0;f=c[3528504]|0;g=(f|0)<9;h=c[3528422]|0;i=e+32|0;j=e+36|0;k=e+40|0;l=e+44|0;m=e+48|0;n=e+52|0;o=e+56|0;p=e+60|0;q=c[2440386]|0;r=c[2415150]|0;s=0;t=c[2385338]|0;while(1){u=a[t+(15-(c[e>>2]|0))|0]|0;if(u<<24>>24!=15){b[r>>1]=c[q+((u&255)<<2)>>2]&65535}u=a[t+(15-(c[e+4>>2]|0))|0]|0;if(u<<24>>24!=15){b[r+2>>1]=c[q+((u&255)<<2)>>2]&65535}u=a[t+(15-(c[e+8>>2]|0))|0]|0;if(u<<24>>24!=15){b[r+4>>1]=c[q+((u&255)<<2)>>2]&65535}u=a[t+(15-(c[e+12>>2]|0))|0]|0;if(u<<24>>24!=15){b[r+6>>1]=c[q+((u&255)<<2)>>2]&65535}u=a[t+(15-(c[e+16>>2]|0))|0]|0;if(u<<24>>24!=15){b[r+8>>1]=c[q+((u&255)<<2)>>2]&65535}u=a[t+(15-(c[e+20>>2]|0))|0]|0;if(u<<24>>24!=15){b[r+10>>1]=c[q+((u&255)<<2)>>2]&65535}u=a[t+(15-(c[e+24>>2]|0))|0]|0;if(u<<24>>24!=15){b[r+12>>1]=c[q+((u&255)<<2)>>2]&65535}u=a[t+(15-(c[e+28>>2]|0))|0]|0;if(u<<24>>24!=15){b[r+14>>1]=c[q+((u&255)<<2)>>2]&65535}do{if(!g){u=a[t+(15-(c[i>>2]|0))|0]|0;if(u<<24>>24!=15){b[r+16>>1]=c[q+((u&255)<<2)>>2]&65535}if((f|0)<10){break}u=a[t+(15-(c[j>>2]|0))|0]|0;if(u<<24>>24!=15){b[r+18>>1]=c[q+((u&255)<<2)>>2]&65535}if((f|0)<11){break}u=a[t+(15-(c[k>>2]|0))|0]|0;if(u<<24>>24!=15){b[r+20>>1]=c[q+((u&255)<<2)>>2]&65535}if((f|0)<12){break}u=a[t+(15-(c[l>>2]|0))|0]|0;if(u<<24>>24!=15){b[r+22>>1]=c[q+((u&255)<<2)>>2]&65535}if((f|0)<13){break}u=a[t+(15-(c[m>>2]|0))|0]|0;if(u<<24>>24!=15){b[r+24>>1]=c[q+((u&255)<<2)>>2]&65535}if((f|0)<14){break}u=a[t+(15-(c[n>>2]|0))|0]|0;if(u<<24>>24!=15){b[r+26>>1]=c[q+((u&255)<<2)>>2]&65535}if((f|0)<15){break}u=a[t+(15-(c[o>>2]|0))|0]|0;if(u<<24>>24!=15){b[r+28>>1]=c[q+((u&255)<<2)>>2]&65535}if((f|0)<16){break}u=a[t+(15-(c[p>>2]|0))|0]|0;if(u<<24>>24==15){break}b[r+30>>1]=c[q+((u&255)<<2)>>2]&65535}}while(0);v=t+(c[h+(s<<2)>>2]|0)|0;u=s+1|0;if((u|0)>=(d|0)){break}r=r+640|0;s=u;t=v}c[2385338]=v;return}function dW2(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;d=c[3528502]|0;if((d|0)<=0){return}e=c[2385456]|0;f=c[3528422]|0;g=c[2385468]|0;h=g>>>0<320;i=c[3528424]|0;j=c[2440386]|0;k=i+4|0;l=i+8|0;m=i+12|0;n=i+16|0;o=i+20|0;p=i+24|0;q=i+28|0;r=c[3528504]|0;s=(r|0)<9;t=(g+8|0)>>>0<320;u=i+32|0;v=(g+9|0)>>>0<320;w=i+36|0;x=(g+10|0)>>>0<320;y=i+40|0;z=(g+11|0)>>>0<320;A=i+44|0;B=(g+12|0)>>>0<320;C=i+48|0;D=(g+13|0)>>>0<320;E=i+52|0;F=(g+14|0)>>>0<320;G=i+56|0;H=(g+15|0)>>>0<320;I=i+60|0;J=c[2415150]|0;K=0;L38755:while(1){L=e+K|0;do{if((L|0)>=0){if((L|0)>223){M=29332;break L38755}do{if(h){N=a[(c[2385338]|0)+(15-(c[i>>2]|0))|0]|0;if(N<<24>>24==15){break}b[J>>1]=c[j+((N&255)<<2)>>2]&65535}}while(0);do{if((g+1|0)>>>0<320){N=a[(c[2385338]|0)+(15-(c[k>>2]|0))|0]|0;if(N<<24>>24==15){break}b[J+2>>1]=c[j+((N&255)<<2)>>2]&65535}}while(0);do{if((g+2|0)>>>0<320){N=a[(c[2385338]|0)+(15-(c[l>>2]|0))|0]|0;if(N<<24>>24==15){break}b[J+4>>1]=c[j+((N&255)<<2)>>2]&65535}}while(0);do{if((g+3|0)>>>0<320){N=a[(c[2385338]|0)+(15-(c[m>>2]|0))|0]|0;if(N<<24>>24==15){break}b[J+6>>1]=c[j+((N&255)<<2)>>2]&65535}}while(0);do{if((g+4|0)>>>0<320){N=a[(c[2385338]|0)+(15-(c[n>>2]|0))|0]|0;if(N<<24>>24==15){break}b[J+8>>1]=c[j+((N&255)<<2)>>2]&65535}}while(0);do{if((g+5|0)>>>0<320){N=a[(c[2385338]|0)+(15-(c[o>>2]|0))|0]|0;if(N<<24>>24==15){break}b[J+10>>1]=c[j+((N&255)<<2)>>2]&65535}}while(0);do{if((g+6|0)>>>0<320){N=a[(c[2385338]|0)+(15-(c[p>>2]|0))|0]|0;if(N<<24>>24==15){break}b[J+12>>1]=c[j+((N&255)<<2)>>2]&65535}}while(0);do{if((g+7|0)>>>0<320){N=a[(c[2385338]|0)+(15-(c[q>>2]|0))|0]|0;if(N<<24>>24==15){break}b[J+14>>1]=c[j+((N&255)<<2)>>2]&65535}}while(0);if(s){break}do{if(t){N=a[(c[2385338]|0)+(15-(c[u>>2]|0))|0]|0;if(N<<24>>24==15){break}b[J+16>>1]=c[j+((N&255)<<2)>>2]&65535}}while(0);if((r|0)<10){break}do{if(v){N=a[(c[2385338]|0)+(15-(c[w>>2]|0))|0]|0;if(N<<24>>24==15){break}b[J+18>>1]=c[j+((N&255)<<2)>>2]&65535}}while(0);if((r|0)<11){break}do{if(x){N=a[(c[2385338]|0)+(15-(c[y>>2]|0))|0]|0;if(N<<24>>24==15){break}b[J+20>>1]=c[j+((N&255)<<2)>>2]&65535}}while(0);if((r|0)<12){break}do{if(z){N=a[(c[2385338]|0)+(15-(c[A>>2]|0))|0]|0;if(N<<24>>24==15){break}b[J+22>>1]=c[j+((N&255)<<2)>>2]&65535}}while(0);if((r|0)<13){break}do{if(B){N=a[(c[2385338]|0)+(15-(c[C>>2]|0))|0]|0;if(N<<24>>24==15){break}b[J+24>>1]=c[j+((N&255)<<2)>>2]&65535}}while(0);if((r|0)<14){break}do{if(D){N=a[(c[2385338]|0)+(15-(c[E>>2]|0))|0]|0;if(N<<24>>24==15){break}b[J+26>>1]=c[j+((N&255)<<2)>>2]&65535}}while(0);if((r|0)<15){break}do{if(F){N=a[(c[2385338]|0)+(15-(c[G>>2]|0))|0]|0;if(N<<24>>24==15){break}b[J+28>>1]=c[j+((N&255)<<2)>>2]&65535}}while(0);if((r|0)<16|H^1){break}N=a[(c[2385338]|0)+(15-(c[I>>2]|0))|0]|0;if(N<<24>>24==15){break}b[J+30>>1]=c[j+((N&255)<<2)>>2]&65535}}while(0);c[2385338]=(c[2385338]|0)+(c[f+(K<<2)>>2]|0);L=K+1|0;if((L|0)>=(d|0)){M=29334;break}J=J+640|0;K=L}if((M|0)==29332){return}else if((M|0)==29334){return}}function dW3(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;d=c[3528502]|0;if((d|0)<=0){return}f=c[3528424]|0;g=c[3528504]|0;h=(g|0)<9;i=c[3528422]|0;j=f+32|0;k=f+36|0;l=f+40|0;m=f+44|0;n=f+48|0;o=f+52|0;p=f+56|0;q=f+60|0;r=c[2415164]|0;s=c[2440386]|0;t=c[2415150]|0;u=c[2409606]|0;v=0;w=c[2385338]|0;while(1){x=a[w+(15-(c[f>>2]|0))|0]|0;y=x&255;do{if(x<<24>>24==15){z=w}else{if((e[u>>1]|0|0)>(r|0)){z=w;break}b[t>>1]=c[s+(y<<2)>>2]&65535;z=w}}while(0);y=a[z+(15-(c[f+4>>2]|0))|0]|0;x=y&255;do{if(y<<24>>24==15){A=z}else{if((e[u+2>>1]|0|0)>(r|0)){A=z;break}b[t+2>>1]=c[s+(x<<2)>>2]&65535;A=w}}while(0);x=a[A+(15-(c[f+8>>2]|0))|0]|0;y=x&255;do{if(x<<24>>24==15){B=A}else{if((e[u+4>>1]|0|0)>(r|0)){B=A;break}b[t+4>>1]=c[s+(y<<2)>>2]&65535;B=w}}while(0);y=a[B+(15-(c[f+12>>2]|0))|0]|0;x=y&255;do{if(y<<24>>24==15){C=B}else{if((e[u+6>>1]|0|0)>(r|0)){C=B;break}b[t+6>>1]=c[s+(x<<2)>>2]&65535;C=w}}while(0);x=a[C+(15-(c[f+16>>2]|0))|0]|0;y=x&255;do{if(x<<24>>24==15){D=C}else{if((e[u+8>>1]|0|0)>(r|0)){D=C;break}b[t+8>>1]=c[s+(y<<2)>>2]&65535;D=w}}while(0);y=a[D+(15-(c[f+20>>2]|0))|0]|0;x=y&255;do{if(y<<24>>24==15){E=D}else{if((e[u+10>>1]|0|0)>(r|0)){E=D;break}b[t+10>>1]=c[s+(x<<2)>>2]&65535;E=w}}while(0);x=a[E+(15-(c[f+24>>2]|0))|0]|0;y=x&255;do{if(x<<24>>24==15){F=E}else{if((e[u+12>>1]|0|0)>(r|0)){F=E;break}b[t+12>>1]=c[s+(y<<2)>>2]&65535;F=w}}while(0);y=a[F+(15-(c[f+28>>2]|0))|0]|0;x=y&255;do{if(y<<24>>24!=15){if((e[u+14>>1]|0|0)>(r|0)){break}b[t+14>>1]=c[s+(x<<2)>>2]&65535}}while(0);do{if(!h){x=a[w+(15-(c[j>>2]|0))|0]|0;y=x&255;do{if(x<<24>>24!=15){if((e[u+16>>1]|0|0)>(r|0)){break}b[t+16>>1]=c[s+(y<<2)>>2]&65535}}while(0);if((g|0)<10){break}y=a[w+(15-(c[k>>2]|0))|0]|0;x=y&255;do{if(y<<24>>24!=15){if((e[u+18>>1]|0|0)>(r|0)){break}b[t+18>>1]=c[s+(x<<2)>>2]&65535}}while(0);if((g|0)<11){break}x=a[w+(15-(c[l>>2]|0))|0]|0;y=x&255;do{if(x<<24>>24!=15){if((e[u+20>>1]|0|0)>(r|0)){break}b[t+20>>1]=c[s+(y<<2)>>2]&65535}}while(0);if((g|0)<12){break}y=a[w+(15-(c[m>>2]|0))|0]|0;x=y&255;do{if(y<<24>>24!=15){if((e[u+22>>1]|0|0)>(r|0)){break}b[t+22>>1]=c[s+(x<<2)>>2]&65535}}while(0);if((g|0)<13){break}x=a[w+(15-(c[n>>2]|0))|0]|0;y=x&255;do{if(x<<24>>24!=15){if((e[u+24>>1]|0|0)>(r|0)){break}b[t+24>>1]=c[s+(y<<2)>>2]&65535}}while(0);if((g|0)<14){break}y=a[w+(15-(c[o>>2]|0))|0]|0;x=y&255;do{if(y<<24>>24!=15){if((e[u+26>>1]|0|0)>(r|0)){break}b[t+26>>1]=c[s+(x<<2)>>2]&65535}}while(0);if((g|0)<15){break}x=a[w+(15-(c[p>>2]|0))|0]|0;y=x&255;do{if(x<<24>>24!=15){if((e[u+28>>1]|0|0)>(r|0)){break}b[t+28>>1]=c[s+(y<<2)>>2]&65535}}while(0);if((g|0)<16){break}y=a[w+(15-(c[q>>2]|0))|0]|0;if(y<<24>>24==15){break}if((e[u+30>>1]|0|0)>(r|0)){break}b[t+30>>1]=c[s+((y&255)<<2)>>2]&65535}}while(0);G=w+(c[i+(v<<2)>>2]|0)|0;y=v+1|0;if((y|0)>=(d|0)){break}t=t+640|0;u=u+640|0;v=y;w=G}c[2385338]=G;return}function dW4(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;d=c[3528502]|0;if((d|0)<=0){return}f=c[2385456]|0;g=c[3528422]|0;h=c[2385468]|0;i=h>>>0<320;j=c[3528424]|0;k=c[2415164]|0;l=c[2440386]|0;m=j+4|0;n=j+8|0;o=j+12|0;p=j+16|0;q=j+20|0;r=j+24|0;s=j+28|0;t=c[3528504]|0;u=(t|0)<9;v=(h+8|0)>>>0<320;w=j+32|0;x=(h+9|0)>>>0<320;y=j+36|0;z=(h+10|0)>>>0<320;A=j+40|0;B=(h+11|0)>>>0<320;C=j+44|0;D=(h+12|0)>>>0<320;E=j+48|0;F=(h+13|0)>>>0<320;G=j+52|0;H=(h+14|0)>>>0<320;I=j+56|0;J=(h+15|0)>>>0<320;K=j+60|0;L=c[2415150]|0;M=c[2409606]|0;N=0;L38919:while(1){O=f+N|0;do{if((O|0)>=0){if((O|0)>223){P=29478;break L38919}do{if(i){Q=a[(c[2385338]|0)+(15-(c[j>>2]|0))|0]|0;if(Q<<24>>24==15){break}if((e[M>>1]|0|0)>(k|0)){break}b[L>>1]=c[l+((Q&255)<<2)>>2]&65535}}while(0);do{if((h+1|0)>>>0<320){Q=a[(c[2385338]|0)+(15-(c[m>>2]|0))|0]|0;if(Q<<24>>24==15){break}if((e[M+2>>1]|0|0)>(k|0)){break}b[L+2>>1]=c[l+((Q&255)<<2)>>2]&65535}}while(0);do{if((h+2|0)>>>0<320){Q=a[(c[2385338]|0)+(15-(c[n>>2]|0))|0]|0;if(Q<<24>>24==15){break}if((e[M+4>>1]|0|0)>(k|0)){break}b[L+4>>1]=c[l+((Q&255)<<2)>>2]&65535}}while(0);do{if((h+3|0)>>>0<320){Q=a[(c[2385338]|0)+(15-(c[o>>2]|0))|0]|0;if(Q<<24>>24==15){break}if((e[M+6>>1]|0|0)>(k|0)){break}b[L+6>>1]=c[l+((Q&255)<<2)>>2]&65535}}while(0);do{if((h+4|0)>>>0<320){Q=a[(c[2385338]|0)+(15-(c[p>>2]|0))|0]|0;if(Q<<24>>24==15){break}if((e[M+8>>1]|0|0)>(k|0)){break}b[L+8>>1]=c[l+((Q&255)<<2)>>2]&65535}}while(0);do{if((h+5|0)>>>0<320){Q=a[(c[2385338]|0)+(15-(c[q>>2]|0))|0]|0;if(Q<<24>>24==15){break}if((e[M+10>>1]|0|0)>(k|0)){break}b[L+10>>1]=c[l+((Q&255)<<2)>>2]&65535}}while(0);do{if((h+6|0)>>>0<320){Q=a[(c[2385338]|0)+(15-(c[r>>2]|0))|0]|0;if(Q<<24>>24==15){break}if((e[M+12>>1]|0|0)>(k|0)){break}b[L+12>>1]=c[l+((Q&255)<<2)>>2]&65535}}while(0);do{if((h+7|0)>>>0<320){Q=a[(c[2385338]|0)+(15-(c[s>>2]|0))|0]|0;if(Q<<24>>24==15){break}if((e[M+14>>1]|0|0)>(k|0)){break}b[L+14>>1]=c[l+((Q&255)<<2)>>2]&65535}}while(0);if(u){break}do{if(v){Q=a[(c[2385338]|0)+(15-(c[w>>2]|0))|0]|0;if(Q<<24>>24==15){break}if((e[M+16>>1]|0|0)>(k|0)){break}b[L+16>>1]=c[l+((Q&255)<<2)>>2]&65535}}while(0);if((t|0)<10){break}do{if(x){Q=a[(c[2385338]|0)+(15-(c[y>>2]|0))|0]|0;if(Q<<24>>24==15){break}if((e[M+18>>1]|0|0)>(k|0)){break}b[L+18>>1]=c[l+((Q&255)<<2)>>2]&65535}}while(0);if((t|0)<11){break}do{if(z){Q=a[(c[2385338]|0)+(15-(c[A>>2]|0))|0]|0;if(Q<<24>>24==15){break}if((e[M+20>>1]|0|0)>(k|0)){break}b[L+20>>1]=c[l+((Q&255)<<2)>>2]&65535}}while(0);if((t|0)<12){break}do{if(B){Q=a[(c[2385338]|0)+(15-(c[C>>2]|0))|0]|0;if(Q<<24>>24==15){break}if((e[M+22>>1]|0|0)>(k|0)){break}b[L+22>>1]=c[l+((Q&255)<<2)>>2]&65535}}while(0);if((t|0)<13){break}do{if(D){Q=a[(c[2385338]|0)+(15-(c[E>>2]|0))|0]|0;if(Q<<24>>24==15){break}if((e[M+24>>1]|0|0)>(k|0)){break}b[L+24>>1]=c[l+((Q&255)<<2)>>2]&65535}}while(0);if((t|0)<14){break}do{if(F){Q=a[(c[2385338]|0)+(15-(c[G>>2]|0))|0]|0;if(Q<<24>>24==15){break}if((e[M+26>>1]|0|0)>(k|0)){break}b[L+26>>1]=c[l+((Q&255)<<2)>>2]&65535}}while(0);if((t|0)<15){break}do{if(H){Q=a[(c[2385338]|0)+(15-(c[I>>2]|0))|0]|0;if(Q<<24>>24==15){break}if((e[M+28>>1]|0|0)>(k|0)){break}b[L+28>>1]=c[l+((Q&255)<<2)>>2]&65535}}while(0);if((t|0)<16|J^1){break}Q=a[(c[2385338]|0)+(15-(c[K>>2]|0))|0]|0;if(Q<<24>>24==15){break}if((e[M+30>>1]|0|0)>(k|0)){break}b[L+30>>1]=c[l+((Q&255)<<2)>>2]&65535}}while(0);c[2385338]=(c[2385338]|0)+(c[g+(N<<2)>>2]|0);O=N+1|0;if((O|0)>=(d|0)){P=29477;break}L=L+640|0;M=M+640|0;N=O}if((P|0)==29477){return}else if((P|0)==29478){return}}function dW5(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;e=c[3528502]|0;if((e|0)<=0){return}f=c[3528424]|0;g=c[3528504]|0;h=(g|0)<9;i=c[3528422]|0;j=f+32|0;k=f+36|0;l=f+40|0;m=f+44|0;n=f+48|0;o=f+52|0;p=f+56|0;q=f+60|0;r=c[2415164]&65535;s=c[2440386]|0;t=f+28|0;u=f+24|0;v=f+20|0;w=f+16|0;x=f+12|0;y=f+8|0;z=f+4|0;A=c[2415150]|0;B=c[2409606]|0;C=0;D=c[2385338]|0;while(1){if((a[D+(15-(c[f>>2]|0))|0]|0)!=15){b[B>>1]=r;b[A>>1]=c[s+(d[D+(15-(c[f>>2]|0))|0]<<2)>>2]&65535}if((a[D+(15-(c[z>>2]|0))|0]|0)!=15){b[B+2>>1]=r;b[A+2>>1]=c[s+(d[D+(15-(c[z>>2]|0))|0]<<2)>>2]&65535}if((a[D+(15-(c[y>>2]|0))|0]|0)!=15){b[B+4>>1]=r;b[A+4>>1]=c[s+(d[D+(15-(c[y>>2]|0))|0]<<2)>>2]&65535}if((a[D+(15-(c[x>>2]|0))|0]|0)!=15){b[B+6>>1]=r;b[A+6>>1]=c[s+(d[D+(15-(c[x>>2]|0))|0]<<2)>>2]&65535}if((a[D+(15-(c[w>>2]|0))|0]|0)!=15){b[B+8>>1]=r;b[A+8>>1]=c[s+(d[D+(15-(c[w>>2]|0))|0]<<2)>>2]&65535}if((a[D+(15-(c[v>>2]|0))|0]|0)!=15){b[B+10>>1]=r;b[A+10>>1]=c[s+(d[D+(15-(c[v>>2]|0))|0]<<2)>>2]&65535}if((a[D+(15-(c[u>>2]|0))|0]|0)!=15){b[B+12>>1]=r;b[A+12>>1]=c[s+(d[D+(15-(c[u>>2]|0))|0]<<2)>>2]&65535}if((a[D+(15-(c[t>>2]|0))|0]|0)!=15){b[B+14>>1]=r;b[A+14>>1]=c[s+(d[D+(15-(c[t>>2]|0))|0]<<2)>>2]&65535}do{if(!h){if((a[D+(15-(c[j>>2]|0))|0]|0)!=15){b[B+16>>1]=r;b[A+16>>1]=c[s+(d[D+(15-(c[j>>2]|0))|0]<<2)>>2]&65535}if((g|0)<10){break}if((a[D+(15-(c[k>>2]|0))|0]|0)!=15){b[B+18>>1]=r;b[A+18>>1]=c[s+(d[D+(15-(c[k>>2]|0))|0]<<2)>>2]&65535}if((g|0)<11){break}if((a[D+(15-(c[l>>2]|0))|0]|0)!=15){b[B+20>>1]=r;b[A+20>>1]=c[s+(d[D+(15-(c[l>>2]|0))|0]<<2)>>2]&65535}if((g|0)<12){break}if((a[D+(15-(c[m>>2]|0))|0]|0)!=15){b[B+22>>1]=r;b[A+22>>1]=c[s+(d[D+(15-(c[m>>2]|0))|0]<<2)>>2]&65535}if((g|0)<13){break}if((a[D+(15-(c[n>>2]|0))|0]|0)!=15){b[B+24>>1]=r;b[A+24>>1]=c[s+(d[D+(15-(c[n>>2]|0))|0]<<2)>>2]&65535}if((g|0)<14){break}if((a[D+(15-(c[o>>2]|0))|0]|0)!=15){b[B+26>>1]=r;b[A+26>>1]=c[s+(d[D+(15-(c[o>>2]|0))|0]<<2)>>2]&65535}if((g|0)<15){break}if((a[D+(15-(c[p>>2]|0))|0]|0)!=15){b[B+28>>1]=r;b[A+28>>1]=c[s+(d[D+(15-(c[p>>2]|0))|0]<<2)>>2]&65535}if((g|0)<16){break}if((a[D+(15-(c[q>>2]|0))|0]|0)==15){break}b[B+30>>1]=r;b[A+30>>1]=c[s+(d[D+(15-(c[q>>2]|0))|0]<<2)>>2]&65535}}while(0);E=D+(c[i+(C<<2)>>2]|0)|0;F=C+1|0;if((F|0)>=(e|0)){break}A=A+640|0;B=B+640|0;C=F;D=E}c[2385338]=E;return}function dW6(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;e=c[3528502]|0;if((e|0)<=0){return}f=c[2385456]|0;g=c[3528422]|0;h=c[2385468]|0;i=h>>>0<320;j=c[3528424]|0;k=c[2415164]&65535;l=c[2440386]|0;m=j+4|0;n=j+8|0;o=j+12|0;p=j+16|0;q=j+20|0;r=j+24|0;s=j+28|0;t=c[3528504]|0;u=(t|0)<9;v=(h+8|0)>>>0<320;w=j+32|0;x=(h+9|0)>>>0<320;y=j+36|0;z=(h+10|0)>>>0<320;A=j+40|0;B=(h+11|0)>>>0<320;C=j+44|0;D=(h+12|0)>>>0<320;E=j+48|0;F=(h+13|0)>>>0<320;G=j+52|0;H=(h+14|0)>>>0<320;I=j+56|0;J=(h+15|0)>>>0<320;K=j+60|0;L=c[2415150]|0;M=c[2409606]|0;N=0;L39083:while(1){O=f+N|0;do{if((O|0)>=0){if((O|0)>223){P=29591;break L39083}do{if(i){Q=c[2385338]|0;if((a[Q+(15-(c[j>>2]|0))|0]|0)==15){break}b[M>>1]=k;b[L>>1]=c[l+(d[Q+(15-(c[j>>2]|0))|0]<<2)>>2]&65535}}while(0);do{if((h+1|0)>>>0<320){Q=c[2385338]|0;if((a[Q+(15-(c[m>>2]|0))|0]|0)==15){break}b[M+2>>1]=k;b[L+2>>1]=c[l+(d[Q+(15-(c[m>>2]|0))|0]<<2)>>2]&65535}}while(0);do{if((h+2|0)>>>0<320){Q=c[2385338]|0;if((a[Q+(15-(c[n>>2]|0))|0]|0)==15){break}b[M+4>>1]=k;b[L+4>>1]=c[l+(d[Q+(15-(c[n>>2]|0))|0]<<2)>>2]&65535}}while(0);do{if((h+3|0)>>>0<320){Q=c[2385338]|0;if((a[Q+(15-(c[o>>2]|0))|0]|0)==15){break}b[M+6>>1]=k;b[L+6>>1]=c[l+(d[Q+(15-(c[o>>2]|0))|0]<<2)>>2]&65535}}while(0);do{if((h+4|0)>>>0<320){Q=c[2385338]|0;if((a[Q+(15-(c[p>>2]|0))|0]|0)==15){break}b[M+8>>1]=k;b[L+8>>1]=c[l+(d[Q+(15-(c[p>>2]|0))|0]<<2)>>2]&65535}}while(0);do{if((h+5|0)>>>0<320){Q=c[2385338]|0;if((a[Q+(15-(c[q>>2]|0))|0]|0)==15){break}b[M+10>>1]=k;b[L+10>>1]=c[l+(d[Q+(15-(c[q>>2]|0))|0]<<2)>>2]&65535}}while(0);do{if((h+6|0)>>>0<320){Q=c[2385338]|0;if((a[Q+(15-(c[r>>2]|0))|0]|0)==15){break}b[M+12>>1]=k;b[L+12>>1]=c[l+(d[Q+(15-(c[r>>2]|0))|0]<<2)>>2]&65535}}while(0);do{if((h+7|0)>>>0<320){Q=c[2385338]|0;if((a[Q+(15-(c[s>>2]|0))|0]|0)==15){break}b[M+14>>1]=k;b[L+14>>1]=c[l+(d[Q+(15-(c[s>>2]|0))|0]<<2)>>2]&65535}}while(0);if(u){break}do{if(v){Q=c[2385338]|0;if((a[Q+(15-(c[w>>2]|0))|0]|0)==15){break}b[M+16>>1]=k;b[L+16>>1]=c[l+(d[Q+(15-(c[w>>2]|0))|0]<<2)>>2]&65535}}while(0);if((t|0)<10){break}do{if(x){Q=c[2385338]|0;if((a[Q+(15-(c[y>>2]|0))|0]|0)==15){break}b[M+18>>1]=k;b[L+18>>1]=c[l+(d[Q+(15-(c[y>>2]|0))|0]<<2)>>2]&65535}}while(0);if((t|0)<11){break}do{if(z){Q=c[2385338]|0;if((a[Q+(15-(c[A>>2]|0))|0]|0)==15){break}b[M+20>>1]=k;b[L+20>>1]=c[l+(d[Q+(15-(c[A>>2]|0))|0]<<2)>>2]&65535}}while(0);if((t|0)<12){break}do{if(B){Q=c[2385338]|0;if((a[Q+(15-(c[C>>2]|0))|0]|0)==15){break}b[M+22>>1]=k;b[L+22>>1]=c[l+(d[Q+(15-(c[C>>2]|0))|0]<<2)>>2]&65535}}while(0);if((t|0)<13){break}do{if(D){Q=c[2385338]|0;if((a[Q+(15-(c[E>>2]|0))|0]|0)==15){break}b[M+24>>1]=k;b[L+24>>1]=c[l+(d[Q+(15-(c[E>>2]|0))|0]<<2)>>2]&65535}}while(0);if((t|0)<14){break}do{if(F){Q=c[2385338]|0;if((a[Q+(15-(c[G>>2]|0))|0]|0)==15){break}b[M+26>>1]=k;b[L+26>>1]=c[l+(d[Q+(15-(c[G>>2]|0))|0]<<2)>>2]&65535}}while(0);if((t|0)<15){break}do{if(H){Q=c[2385338]|0;if((a[Q+(15-(c[I>>2]|0))|0]|0)==15){break}b[M+28>>1]=k;b[L+28>>1]=c[l+(d[Q+(15-(c[I>>2]|0))|0]<<2)>>2]&65535}}while(0);if((t|0)<16|J^1){break}Q=c[2385338]|0;if((a[Q+(15-(c[K>>2]|0))|0]|0)==15){break}b[M+30>>1]=k;b[L+30>>1]=c[l+(d[Q+(15-(c[K>>2]|0))|0]<<2)>>2]&65535}}while(0);c[2385338]=(c[2385338]|0)+(c[g+(N<<2)>>2]|0);O=N+1|0;if((O|0)>=(e|0)){P=29590;break}L=L+640|0;M=M+640|0;N=O}if((P|0)==29590){return}else if((P|0)==29591){return}}function dW7(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;f=c[3528502]|0;if((f|0)<=0){return}g=c[3528424]|0;h=c[3528504]|0;i=(h|0)<9;j=c[3528422]|0;k=g+32|0;l=g+36|0;m=g+40|0;n=g+44|0;o=g+48|0;p=g+52|0;q=g+56|0;r=g+60|0;s=c[2415164]|0;t=s&65535;u=c[2440386]|0;v=g+28|0;w=g+24|0;x=g+20|0;y=g+16|0;z=g+12|0;A=g+8|0;B=g+4|0;C=c[2415150]|0;D=c[2409606]|0;E=0;F=c[2385338]|0;while(1){do{if((a[F+(15-(c[g>>2]|0))|0]|0)==15){G=F}else{if((e[D>>1]|0)>(s|0)){G=F;break}b[D>>1]=t;b[C>>1]=c[u+(d[F+(15-(c[g>>2]|0))|0]<<2)>>2]&65535;G=F}}while(0);do{if((a[G+(15-(c[B>>2]|0))|0]|0)==15){H=G}else{I=D+2|0;if((e[I>>1]|0)>(s|0)){H=G;break}b[I>>1]=t;b[C+2>>1]=c[u+(d[F+(15-(c[B>>2]|0))|0]<<2)>>2]&65535;H=F}}while(0);do{if((a[H+(15-(c[A>>2]|0))|0]|0)==15){J=H}else{I=D+4|0;if((e[I>>1]|0)>(s|0)){J=H;break}b[I>>1]=t;b[C+4>>1]=c[u+(d[F+(15-(c[A>>2]|0))|0]<<2)>>2]&65535;J=F}}while(0);do{if((a[J+(15-(c[z>>2]|0))|0]|0)==15){K=J}else{I=D+6|0;if((e[I>>1]|0)>(s|0)){K=J;break}b[I>>1]=t;b[C+6>>1]=c[u+(d[F+(15-(c[z>>2]|0))|0]<<2)>>2]&65535;K=F}}while(0);do{if((a[K+(15-(c[y>>2]|0))|0]|0)==15){L=K}else{I=D+8|0;if((e[I>>1]|0)>(s|0)){L=K;break}b[I>>1]=t;b[C+8>>1]=c[u+(d[F+(15-(c[y>>2]|0))|0]<<2)>>2]&65535;L=F}}while(0);do{if((a[L+(15-(c[x>>2]|0))|0]|0)==15){M=L}else{I=D+10|0;if((e[I>>1]|0)>(s|0)){M=L;break}b[I>>1]=t;b[C+10>>1]=c[u+(d[F+(15-(c[x>>2]|0))|0]<<2)>>2]&65535;M=F}}while(0);do{if((a[M+(15-(c[w>>2]|0))|0]|0)==15){N=M}else{I=D+12|0;if((e[I>>1]|0)>(s|0)){N=M;break}b[I>>1]=t;b[C+12>>1]=c[u+(d[F+(15-(c[w>>2]|0))|0]<<2)>>2]&65535;N=F}}while(0);do{if((a[N+(15-(c[v>>2]|0))|0]|0)!=15){I=D+14|0;if((e[I>>1]|0)>(s|0)){break}b[I>>1]=t;b[C+14>>1]=c[u+(d[F+(15-(c[v>>2]|0))|0]<<2)>>2]&65535}}while(0);do{if(!i){do{if((a[F+(15-(c[k>>2]|0))|0]|0)!=15){I=D+16|0;if((e[I>>1]|0)>(s|0)){break}b[I>>1]=t;b[C+16>>1]=c[u+(d[F+(15-(c[k>>2]|0))|0]<<2)>>2]&65535}}while(0);if((h|0)<10){break}do{if((a[F+(15-(c[l>>2]|0))|0]|0)!=15){I=D+18|0;if((e[I>>1]|0)>(s|0)){break}b[I>>1]=t;b[C+18>>1]=c[u+(d[F+(15-(c[l>>2]|0))|0]<<2)>>2]&65535}}while(0);if((h|0)<11){break}do{if((a[F+(15-(c[m>>2]|0))|0]|0)!=15){I=D+20|0;if((e[I>>1]|0)>(s|0)){break}b[I>>1]=t;b[C+20>>1]=c[u+(d[F+(15-(c[m>>2]|0))|0]<<2)>>2]&65535}}while(0);if((h|0)<12){break}do{if((a[F+(15-(c[n>>2]|0))|0]|0)!=15){I=D+22|0;if((e[I>>1]|0)>(s|0)){break}b[I>>1]=t;b[C+22>>1]=c[u+(d[F+(15-(c[n>>2]|0))|0]<<2)>>2]&65535}}while(0);if((h|0)<13){break}do{if((a[F+(15-(c[o>>2]|0))|0]|0)!=15){I=D+24|0;if((e[I>>1]|0)>(s|0)){break}b[I>>1]=t;b[C+24>>1]=c[u+(d[F+(15-(c[o>>2]|0))|0]<<2)>>2]&65535}}while(0);if((h|0)<14){break}do{if((a[F+(15-(c[p>>2]|0))|0]|0)!=15){I=D+26|0;if((e[I>>1]|0)>(s|0)){break}b[I>>1]=t;b[C+26>>1]=c[u+(d[F+(15-(c[p>>2]|0))|0]<<2)>>2]&65535}}while(0);if((h|0)<15){break}do{if((a[F+(15-(c[q>>2]|0))|0]|0)!=15){I=D+28|0;if((e[I>>1]|0)>(s|0)){break}b[I>>1]=t;b[C+28>>1]=c[u+(d[F+(15-(c[q>>2]|0))|0]<<2)>>2]&65535}}while(0);if((h|0)<16){break}if((a[F+(15-(c[r>>2]|0))|0]|0)==15){break}I=D+30|0;if((e[I>>1]|0)>(s|0)){break}b[I>>1]=t;b[C+30>>1]=c[u+(d[F+(15-(c[r>>2]|0))|0]<<2)>>2]&65535}}while(0);O=F+(c[j+(E<<2)>>2]|0)|0;I=E+1|0;if((I|0)>=(f|0)){break}C=C+640|0;D=D+640|0;E=I;F=O}c[2385338]=O;return}function dW8(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;f=c[3528502]|0;if((f|0)<=0){return}g=c[2385456]|0;h=c[3528422]|0;i=c[2385468]|0;j=i>>>0<320;k=c[3528424]|0;l=c[2415164]|0;m=l&65535;n=c[2440386]|0;o=k+4|0;p=k+8|0;q=k+12|0;r=k+16|0;s=k+20|0;t=k+24|0;u=k+28|0;v=c[3528504]|0;w=(v|0)<9;x=(i+8|0)>>>0<320;y=k+32|0;z=(i+9|0)>>>0<320;A=k+36|0;B=(i+10|0)>>>0<320;C=k+40|0;D=(i+11|0)>>>0<320;E=k+44|0;F=(i+12|0)>>>0<320;G=k+48|0;H=(i+13|0)>>>0<320;I=k+52|0;J=(i+14|0)>>>0<320;K=k+56|0;L=(i+15|0)>>>0<320;M=k+60|0;N=c[2415150]|0;O=c[2409606]|0;P=0;L39247:while(1){Q=g+P|0;do{if((Q|0)>=0){if((Q|0)>223){R=29735;break L39247}do{if(j){S=c[2385338]|0;if((a[S+(15-(c[k>>2]|0))|0]|0)==15){break}if((e[O>>1]|0)>(l|0)){break}b[O>>1]=m;b[N>>1]=c[n+(d[S+(15-(c[k>>2]|0))|0]<<2)>>2]&65535}}while(0);do{if((i+1|0)>>>0<320){S=c[2385338]|0;if((a[S+(15-(c[o>>2]|0))|0]|0)==15){break}T=O+2|0;if((e[T>>1]|0)>(l|0)){break}b[T>>1]=m;b[N+2>>1]=c[n+(d[S+(15-(c[o>>2]|0))|0]<<2)>>2]&65535}}while(0);do{if((i+2|0)>>>0<320){S=c[2385338]|0;if((a[S+(15-(c[p>>2]|0))|0]|0)==15){break}T=O+4|0;if((e[T>>1]|0)>(l|0)){break}b[T>>1]=m;b[N+4>>1]=c[n+(d[S+(15-(c[p>>2]|0))|0]<<2)>>2]&65535}}while(0);do{if((i+3|0)>>>0<320){S=c[2385338]|0;if((a[S+(15-(c[q>>2]|0))|0]|0)==15){break}T=O+6|0;if((e[T>>1]|0)>(l|0)){break}b[T>>1]=m;b[N+6>>1]=c[n+(d[S+(15-(c[q>>2]|0))|0]<<2)>>2]&65535}}while(0);do{if((i+4|0)>>>0<320){S=c[2385338]|0;if((a[S+(15-(c[r>>2]|0))|0]|0)==15){break}T=O+8|0;if((e[T>>1]|0)>(l|0)){break}b[T>>1]=m;b[N+8>>1]=c[n+(d[S+(15-(c[r>>2]|0))|0]<<2)>>2]&65535}}while(0);do{if((i+5|0)>>>0<320){S=c[2385338]|0;if((a[S+(15-(c[s>>2]|0))|0]|0)==15){break}T=O+10|0;if((e[T>>1]|0)>(l|0)){break}b[T>>1]=m;b[N+10>>1]=c[n+(d[S+(15-(c[s>>2]|0))|0]<<2)>>2]&65535}}while(0);do{if((i+6|0)>>>0<320){S=c[2385338]|0;if((a[S+(15-(c[t>>2]|0))|0]|0)==15){break}T=O+12|0;if((e[T>>1]|0)>(l|0)){break}b[T>>1]=m;b[N+12>>1]=c[n+(d[S+(15-(c[t>>2]|0))|0]<<2)>>2]&65535}}while(0);do{if((i+7|0)>>>0<320){S=c[2385338]|0;if((a[S+(15-(c[u>>2]|0))|0]|0)==15){break}T=O+14|0;if((e[T>>1]|0)>(l|0)){break}b[T>>1]=m;b[N+14>>1]=c[n+(d[S+(15-(c[u>>2]|0))|0]<<2)>>2]&65535}}while(0);if(w){break}do{if(x){S=c[2385338]|0;if((a[S+(15-(c[y>>2]|0))|0]|0)==15){break}T=O+16|0;if((e[T>>1]|0)>(l|0)){break}b[T>>1]=m;b[N+16>>1]=c[n+(d[S+(15-(c[y>>2]|0))|0]<<2)>>2]&65535}}while(0);if((v|0)<10){break}do{if(z){S=c[2385338]|0;if((a[S+(15-(c[A>>2]|0))|0]|0)==15){break}T=O+18|0;if((e[T>>1]|0)>(l|0)){break}b[T>>1]=m;b[N+18>>1]=c[n+(d[S+(15-(c[A>>2]|0))|0]<<2)>>2]&65535}}while(0);if((v|0)<11){break}do{if(B){S=c[2385338]|0;if((a[S+(15-(c[C>>2]|0))|0]|0)==15){break}T=O+20|0;if((e[T>>1]|0)>(l|0)){break}b[T>>1]=m;b[N+20>>1]=c[n+(d[S+(15-(c[C>>2]|0))|0]<<2)>>2]&65535}}while(0);if((v|0)<12){break}do{if(D){S=c[2385338]|0;if((a[S+(15-(c[E>>2]|0))|0]|0)==15){break}T=O+22|0;if((e[T>>1]|0)>(l|0)){break}b[T>>1]=m;b[N+22>>1]=c[n+(d[S+(15-(c[E>>2]|0))|0]<<2)>>2]&65535}}while(0);if((v|0)<13){break}do{if(F){S=c[2385338]|0;if((a[S+(15-(c[G>>2]|0))|0]|0)==15){break}T=O+24|0;if((e[T>>1]|0)>(l|0)){break}b[T>>1]=m;b[N+24>>1]=c[n+(d[S+(15-(c[G>>2]|0))|0]<<2)>>2]&65535}}while(0);if((v|0)<14){break}do{if(H){S=c[2385338]|0;if((a[S+(15-(c[I>>2]|0))|0]|0)==15){break}T=O+26|0;if((e[T>>1]|0)>(l|0)){break}b[T>>1]=m;b[N+26>>1]=c[n+(d[S+(15-(c[I>>2]|0))|0]<<2)>>2]&65535}}while(0);if((v|0)<15){break}do{if(J){S=c[2385338]|0;if((a[S+(15-(c[K>>2]|0))|0]|0)==15){break}T=O+28|0;if((e[T>>1]|0)>(l|0)){break}b[T>>1]=m;b[N+28>>1]=c[n+(d[S+(15-(c[K>>2]|0))|0]<<2)>>2]&65535}}while(0);if((v|0)<16|L^1){break}S=c[2385338]|0;if((a[S+(15-(c[M>>2]|0))|0]|0)==15){break}T=O+30|0;if((e[T>>1]|0)>(l|0)){break}b[T>>1]=m;b[N+30>>1]=c[n+(d[S+(15-(c[M>>2]|0))|0]<<2)>>2]&65535}}while(0);c[2385338]=(c[2385338]|0)+(c[h+(P<<2)>>2]|0);Q=P+1|0;if((Q|0)>=(f|0)){R=29737;break}N=N+640|0;O=O+640|0;P=Q}if((R|0)==29735){return}else if((R|0)==29737){return}}function dW9(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=c[3528502]|0;e=d-1|0;if((d|0)<=0){return}f=c[3528424]|0;g=c[3528504]|0;h=(g|0)<9;i=c[3528422]|0;j=f+32|0;k=f+36|0;l=f+40|0;m=f+44|0;n=f+48|0;o=f+52|0;p=f+56|0;q=f+60|0;r=c[2440386]|0;s=(c[2415150]|0)+(e*640|0)|0;t=e;e=c[2385338]|0;while(1){u=a[e+(c[f>>2]|0)|0]|0;if(u<<24>>24!=15){b[s>>1]=c[r+((u&255)<<2)>>2]&65535}u=a[e+(c[f+4>>2]|0)|0]|0;if(u<<24>>24!=15){b[s+2>>1]=c[r+((u&255)<<2)>>2]&65535}u=a[e+(c[f+8>>2]|0)|0]|0;if(u<<24>>24!=15){b[s+4>>1]=c[r+((u&255)<<2)>>2]&65535}u=a[e+(c[f+12>>2]|0)|0]|0;if(u<<24>>24!=15){b[s+6>>1]=c[r+((u&255)<<2)>>2]&65535}u=a[e+(c[f+16>>2]|0)|0]|0;if(u<<24>>24!=15){b[s+8>>1]=c[r+((u&255)<<2)>>2]&65535}u=a[e+(c[f+20>>2]|0)|0]|0;if(u<<24>>24!=15){b[s+10>>1]=c[r+((u&255)<<2)>>2]&65535}u=a[e+(c[f+24>>2]|0)|0]|0;if(u<<24>>24!=15){b[s+12>>1]=c[r+((u&255)<<2)>>2]&65535}u=a[e+(c[f+28>>2]|0)|0]|0;if(u<<24>>24!=15){b[s+14>>1]=c[r+((u&255)<<2)>>2]&65535}do{if(!h){u=a[e+(c[j>>2]|0)|0]|0;if(u<<24>>24!=15){b[s+16>>1]=c[r+((u&255)<<2)>>2]&65535}if((g|0)<10){break}u=a[e+(c[k>>2]|0)|0]|0;if(u<<24>>24!=15){b[s+18>>1]=c[r+((u&255)<<2)>>2]&65535}if((g|0)<11){break}u=a[e+(c[l>>2]|0)|0]|0;if(u<<24>>24!=15){b[s+20>>1]=c[r+((u&255)<<2)>>2]&65535}if((g|0)<12){break}u=a[e+(c[m>>2]|0)|0]|0;if(u<<24>>24!=15){b[s+22>>1]=c[r+((u&255)<<2)>>2]&65535}if((g|0)<13){break}u=a[e+(c[n>>2]|0)|0]|0;if(u<<24>>24!=15){b[s+24>>1]=c[r+((u&255)<<2)>>2]&65535}if((g|0)<14){break}u=a[e+(c[o>>2]|0)|0]|0;if(u<<24>>24!=15){b[s+26>>1]=c[r+((u&255)<<2)>>2]&65535}if((g|0)<15){break}u=a[e+(c[p>>2]|0)|0]|0;if(u<<24>>24!=15){b[s+28>>1]=c[r+((u&255)<<2)>>2]&65535}if((g|0)<16){break}u=a[e+(c[q>>2]|0)|0]|0;if(u<<24>>24==15){break}b[s+30>>1]=c[r+((u&255)<<2)>>2]&65535}}while(0);v=e+(c[i+(d+~t<<2)>>2]|0)|0;if((t|0)<=0){break}s=s-640|0;t=t-1|0;e=v}c[2385338]=v;return}function dXa(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;d=c[3528502]|0;e=d-1|0;if((d|0)<=0){return}f=c[2385456]|0;g=f+e|0;if((g|0)<0){return}h=c[3528422]|0;i=c[2385468]|0;j=i>>>0<320;k=c[3528424]|0;l=c[2440386]|0;m=k+4|0;n=k+8|0;o=k+12|0;p=k+16|0;q=k+20|0;r=k+24|0;s=k+28|0;t=c[3528504]|0;u=(t|0)<9;v=(i+8|0)>>>0<320;w=k+32|0;x=(i+9|0)>>>0<320;y=k+36|0;z=(i+10|0)>>>0<320;A=k+40|0;B=(i+11|0)>>>0<320;C=k+44|0;D=(i+12|0)>>>0<320;E=k+48|0;F=(i+13|0)>>>0<320;G=k+52|0;H=(i+14|0)>>>0<320;I=k+56|0;J=(i+15|0)>>>0<320;K=k+60|0;L=e;M=(c[2415150]|0)+(e*640|0)|0;e=g;g=c[2385338]|0;while(1){do{if((e|0)<=223){do{if(j){N=a[g+(c[k>>2]|0)|0]|0;if(N<<24>>24==15){break}b[M>>1]=c[l+((N&255)<<2)>>2]&65535}}while(0);do{if((i+1|0)>>>0<320){N=a[g+(c[m>>2]|0)|0]|0;if(N<<24>>24==15){break}b[M+2>>1]=c[l+((N&255)<<2)>>2]&65535}}while(0);do{if((i+2|0)>>>0<320){N=a[g+(c[n>>2]|0)|0]|0;if(N<<24>>24==15){break}b[M+4>>1]=c[l+((N&255)<<2)>>2]&65535}}while(0);do{if((i+3|0)>>>0<320){N=a[g+(c[o>>2]|0)|0]|0;if(N<<24>>24==15){break}b[M+6>>1]=c[l+((N&255)<<2)>>2]&65535}}while(0);do{if((i+4|0)>>>0<320){N=a[g+(c[p>>2]|0)|0]|0;if(N<<24>>24==15){break}b[M+8>>1]=c[l+((N&255)<<2)>>2]&65535}}while(0);do{if((i+5|0)>>>0<320){N=a[g+(c[q>>2]|0)|0]|0;if(N<<24>>24==15){break}b[M+10>>1]=c[l+((N&255)<<2)>>2]&65535}}while(0);do{if((i+6|0)>>>0<320){N=a[g+(c[r>>2]|0)|0]|0;if(N<<24>>24==15){break}b[M+12>>1]=c[l+((N&255)<<2)>>2]&65535}}while(0);do{if((i+7|0)>>>0<320){N=a[g+(c[s>>2]|0)|0]|0;if(N<<24>>24==15){break}b[M+14>>1]=c[l+((N&255)<<2)>>2]&65535}}while(0);if(u){break}do{if(v){N=a[g+(c[w>>2]|0)|0]|0;if(N<<24>>24==15){break}b[M+16>>1]=c[l+((N&255)<<2)>>2]&65535}}while(0);if((t|0)<10){break}do{if(x){N=a[g+(c[y>>2]|0)|0]|0;if(N<<24>>24==15){break}b[M+18>>1]=c[l+((N&255)<<2)>>2]&65535}}while(0);if((t|0)<11){break}do{if(z){N=a[g+(c[A>>2]|0)|0]|0;if(N<<24>>24==15){break}b[M+20>>1]=c[l+((N&255)<<2)>>2]&65535}}while(0);if((t|0)<12){break}do{if(B){N=a[g+(c[C>>2]|0)|0]|0;if(N<<24>>24==15){break}b[M+22>>1]=c[l+((N&255)<<2)>>2]&65535}}while(0);if((t|0)<13){break}do{if(D){N=a[g+(c[E>>2]|0)|0]|0;if(N<<24>>24==15){break}b[M+24>>1]=c[l+((N&255)<<2)>>2]&65535}}while(0);if((t|0)<14){break}do{if(F){N=a[g+(c[G>>2]|0)|0]|0;if(N<<24>>24==15){break}b[M+26>>1]=c[l+((N&255)<<2)>>2]&65535}}while(0);if((t|0)<15){break}do{if(H){N=a[g+(c[I>>2]|0)|0]|0;if(N<<24>>24==15){break}b[M+28>>1]=c[l+((N&255)<<2)>>2]&65535}}while(0);if((t|0)<16|J^1){break}N=a[g+(c[K>>2]|0)|0]|0;if(N<<24>>24==15){break}b[M+30>>1]=c[l+((N&255)<<2)>>2]&65535}}while(0);O=g+(c[h+(d+~L<<2)>>2]|0)|0;if((L|0)<=0){break}N=L-1|0;P=f+N|0;if((P|0)<0){break}else{L=N;M=M-640|0;e=P;g=O}}c[2385338]=O;return}function dXb(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;d=c[3528502]|0;f=d-1|0;if((d|0)<=0){return}g=c[3528424]|0;h=c[3528504]|0;i=(h|0)<9;j=c[3528422]|0;k=g+32|0;l=g+36|0;m=g+40|0;n=g+44|0;o=g+48|0;p=g+52|0;q=g+56|0;r=g+60|0;s=c[2415164]|0;t=c[2440386]|0;u=(c[2415150]|0)+(f*640|0)|0;v=(c[2409606]|0)+((f*320|0)<<1)|0;w=f;f=c[2385338]|0;while(1){x=a[f+(c[g>>2]|0)|0]|0;y=x&255;do{if(x<<24>>24==15){z=f}else{if((e[v>>1]|0|0)>(s|0)){z=f;break}b[u>>1]=c[t+(y<<2)>>2]&65535;z=f}}while(0);y=a[z+(c[g+4>>2]|0)|0]|0;x=y&255;do{if(y<<24>>24==15){A=z}else{if((e[v+2>>1]|0|0)>(s|0)){A=z;break}b[u+2>>1]=c[t+(x<<2)>>2]&65535;A=f}}while(0);x=a[A+(c[g+8>>2]|0)|0]|0;y=x&255;do{if(x<<24>>24==15){B=A}else{if((e[v+4>>1]|0|0)>(s|0)){B=A;break}b[u+4>>1]=c[t+(y<<2)>>2]&65535;B=f}}while(0);y=a[B+(c[g+12>>2]|0)|0]|0;x=y&255;do{if(y<<24>>24==15){C=B}else{if((e[v+6>>1]|0|0)>(s|0)){C=B;break}b[u+6>>1]=c[t+(x<<2)>>2]&65535;C=f}}while(0);x=a[C+(c[g+16>>2]|0)|0]|0;y=x&255;do{if(x<<24>>24==15){D=C}else{if((e[v+8>>1]|0|0)>(s|0)){D=C;break}b[u+8>>1]=c[t+(y<<2)>>2]&65535;D=f}}while(0);y=a[D+(c[g+20>>2]|0)|0]|0;x=y&255;do{if(y<<24>>24==15){E=D}else{if((e[v+10>>1]|0|0)>(s|0)){E=D;break}b[u+10>>1]=c[t+(x<<2)>>2]&65535;E=f}}while(0);x=a[E+(c[g+24>>2]|0)|0]|0;y=x&255;do{if(x<<24>>24==15){F=E}else{if((e[v+12>>1]|0|0)>(s|0)){F=E;break}b[u+12>>1]=c[t+(y<<2)>>2]&65535;F=f}}while(0);y=a[F+(c[g+28>>2]|0)|0]|0;x=y&255;do{if(y<<24>>24!=15){if((e[v+14>>1]|0|0)>(s|0)){break}b[u+14>>1]=c[t+(x<<2)>>2]&65535}}while(0);do{if(!i){x=a[f+(c[k>>2]|0)|0]|0;y=x&255;do{if(x<<24>>24!=15){if((e[v+16>>1]|0|0)>(s|0)){break}b[u+16>>1]=c[t+(y<<2)>>2]&65535}}while(0);if((h|0)<10){break}y=a[f+(c[l>>2]|0)|0]|0;x=y&255;do{if(y<<24>>24!=15){if((e[v+18>>1]|0|0)>(s|0)){break}b[u+18>>1]=c[t+(x<<2)>>2]&65535}}while(0);if((h|0)<11){break}x=a[f+(c[m>>2]|0)|0]|0;y=x&255;do{if(x<<24>>24!=15){if((e[v+20>>1]|0|0)>(s|0)){break}b[u+20>>1]=c[t+(y<<2)>>2]&65535}}while(0);if((h|0)<12){break}y=a[f+(c[n>>2]|0)|0]|0;x=y&255;do{if(y<<24>>24!=15){if((e[v+22>>1]|0|0)>(s|0)){break}b[u+22>>1]=c[t+(x<<2)>>2]&65535}}while(0);if((h|0)<13){break}x=a[f+(c[o>>2]|0)|0]|0;y=x&255;do{if(x<<24>>24!=15){if((e[v+24>>1]|0|0)>(s|0)){break}b[u+24>>1]=c[t+(y<<2)>>2]&65535}}while(0);if((h|0)<14){break}y=a[f+(c[p>>2]|0)|0]|0;x=y&255;do{if(y<<24>>24!=15){if((e[v+26>>1]|0|0)>(s|0)){break}b[u+26>>1]=c[t+(x<<2)>>2]&65535}}while(0);if((h|0)<15){break}x=a[f+(c[q>>2]|0)|0]|0;y=x&255;do{if(x<<24>>24!=15){if((e[v+28>>1]|0|0)>(s|0)){break}b[u+28>>1]=c[t+(y<<2)>>2]&65535}}while(0);if((h|0)<16){break}y=a[f+(c[r>>2]|0)|0]|0;if(y<<24>>24==15){break}if((e[v+30>>1]|0|0)>(s|0)){break}b[u+30>>1]=c[t+((y&255)<<2)>>2]&65535}}while(0);G=f+(c[j+(d+~w<<2)>>2]|0)|0;if((w|0)<=0){break}u=u-640|0;v=v-640|0;w=w-1|0;f=G}c[2385338]=G;return}function dXc(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;d=c[3528502]|0;f=d-1|0;if((d|0)<=0){return}g=c[2385456]|0;h=g+f|0;if((h|0)<0){return}i=c[3528422]|0;j=c[2385468]|0;k=j>>>0<320;l=c[3528424]|0;m=c[2415164]|0;n=c[2440386]|0;o=l+4|0;p=l+8|0;q=l+12|0;r=l+16|0;s=l+20|0;t=l+24|0;u=l+28|0;v=c[3528504]|0;w=(v|0)<9;x=(j+8|0)>>>0<320;y=l+32|0;z=(j+9|0)>>>0<320;A=l+36|0;B=(j+10|0)>>>0<320;C=l+40|0;D=(j+11|0)>>>0<320;E=l+44|0;F=(j+12|0)>>>0<320;G=l+48|0;H=(j+13|0)>>>0<320;I=l+52|0;J=(j+14|0)>>>0<320;K=l+56|0;L=(j+15|0)>>>0<320;M=l+60|0;N=f;O=(c[2409606]|0)+((f*320|0)<<1)|0;P=(c[2415150]|0)+(f*640|0)|0;f=h;h=c[2385338]|0;while(1){do{if((f|0)<=223){do{if(k){Q=a[h+(c[l>>2]|0)|0]|0;if(Q<<24>>24==15){break}if((e[O>>1]|0|0)>(m|0)){break}b[P>>1]=c[n+((Q&255)<<2)>>2]&65535}}while(0);do{if((j+1|0)>>>0<320){Q=a[h+(c[o>>2]|0)|0]|0;if(Q<<24>>24==15){break}if((e[O+2>>1]|0|0)>(m|0)){break}b[P+2>>1]=c[n+((Q&255)<<2)>>2]&65535}}while(0);do{if((j+2|0)>>>0<320){Q=a[h+(c[p>>2]|0)|0]|0;if(Q<<24>>24==15){break}if((e[O+4>>1]|0|0)>(m|0)){break}b[P+4>>1]=c[n+((Q&255)<<2)>>2]&65535}}while(0);do{if((j+3|0)>>>0<320){Q=a[h+(c[q>>2]|0)|0]|0;if(Q<<24>>24==15){break}if((e[O+6>>1]|0|0)>(m|0)){break}b[P+6>>1]=c[n+((Q&255)<<2)>>2]&65535}}while(0);do{if((j+4|0)>>>0<320){Q=a[h+(c[r>>2]|0)|0]|0;if(Q<<24>>24==15){break}if((e[O+8>>1]|0|0)>(m|0)){break}b[P+8>>1]=c[n+((Q&255)<<2)>>2]&65535}}while(0);do{if((j+5|0)>>>0<320){Q=a[h+(c[s>>2]|0)|0]|0;if(Q<<24>>24==15){break}if((e[O+10>>1]|0|0)>(m|0)){break}b[P+10>>1]=c[n+((Q&255)<<2)>>2]&65535}}while(0);do{if((j+6|0)>>>0<320){Q=a[h+(c[t>>2]|0)|0]|0;if(Q<<24>>24==15){break}if((e[O+12>>1]|0|0)>(m|0)){break}b[P+12>>1]=c[n+((Q&255)<<2)>>2]&65535}}while(0);do{if((j+7|0)>>>0<320){Q=a[h+(c[u>>2]|0)|0]|0;if(Q<<24>>24==15){break}if((e[O+14>>1]|0|0)>(m|0)){break}b[P+14>>1]=c[n+((Q&255)<<2)>>2]&65535}}while(0);if(w){break}do{if(x){Q=a[h+(c[y>>2]|0)|0]|0;if(Q<<24>>24==15){break}if((e[O+16>>1]|0|0)>(m|0)){break}b[P+16>>1]=c[n+((Q&255)<<2)>>2]&65535}}while(0);if((v|0)<10){break}do{if(z){Q=a[h+(c[A>>2]|0)|0]|0;if(Q<<24>>24==15){break}if((e[O+18>>1]|0|0)>(m|0)){break}b[P+18>>1]=c[n+((Q&255)<<2)>>2]&65535}}while(0);if((v|0)<11){break}do{if(B){Q=a[h+(c[C>>2]|0)|0]|0;if(Q<<24>>24==15){break}if((e[O+20>>1]|0|0)>(m|0)){break}b[P+20>>1]=c[n+((Q&255)<<2)>>2]&65535}}while(0);if((v|0)<12){break}do{if(D){Q=a[h+(c[E>>2]|0)|0]|0;if(Q<<24>>24==15){break}if((e[O+22>>1]|0|0)>(m|0)){break}b[P+22>>1]=c[n+((Q&255)<<2)>>2]&65535}}while(0);if((v|0)<13){break}do{if(F){Q=a[h+(c[G>>2]|0)|0]|0;if(Q<<24>>24==15){break}if((e[O+24>>1]|0|0)>(m|0)){break}b[P+24>>1]=c[n+((Q&255)<<2)>>2]&65535}}while(0);if((v|0)<14){break}do{if(H){Q=a[h+(c[I>>2]|0)|0]|0;if(Q<<24>>24==15){break}if((e[O+26>>1]|0|0)>(m|0)){break}b[P+26>>1]=c[n+((Q&255)<<2)>>2]&65535}}while(0);if((v|0)<15){break}do{if(J){Q=a[h+(c[K>>2]|0)|0]|0;if(Q<<24>>24==15){break}if((e[O+28>>1]|0|0)>(m|0)){break}b[P+28>>1]=c[n+((Q&255)<<2)>>2]&65535}}while(0);if((v|0)<16|L^1){break}Q=a[h+(c[M>>2]|0)|0]|0;if(Q<<24>>24==15){break}if((e[O+30>>1]|0|0)>(m|0)){break}b[P+30>>1]=c[n+((Q&255)<<2)>>2]&65535}}while(0);R=h+(c[i+(d+~N<<2)>>2]|0)|0;if((N|0)<=0){break}Q=N-1|0;S=g+Q|0;if((S|0)<0){break}else{N=Q;O=O-640|0;P=P-640|0;f=S;h=R}}c[2385338]=R;return}function dXd(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;e=c[3528502]|0;f=e-1|0;if((e|0)<=0){return}g=c[3528424]|0;h=c[3528504]|0;i=(h|0)<9;j=c[3528422]|0;k=g+32|0;l=g+36|0;m=g+40|0;n=g+44|0;o=g+48|0;p=g+52|0;q=g+56|0;r=g+60|0;s=c[2415164]&65535;t=c[2440386]|0;u=g+28|0;v=g+24|0;w=g+20|0;x=g+16|0;y=g+12|0;z=g+8|0;A=g+4|0;B=(c[2415150]|0)+(f*640|0)|0;C=(c[2409606]|0)+((f*320|0)<<1)|0;D=f;f=c[2385338]|0;while(1){if((a[f+(c[g>>2]|0)|0]|0)!=15){b[C>>1]=s;b[B>>1]=c[t+(d[f+(c[g>>2]|0)|0]<<2)>>2]&65535}if((a[f+(c[A>>2]|0)|0]|0)!=15){b[C+2>>1]=s;b[B+2>>1]=c[t+(d[f+(c[A>>2]|0)|0]<<2)>>2]&65535}if((a[f+(c[z>>2]|0)|0]|0)!=15){b[C+4>>1]=s;b[B+4>>1]=c[t+(d[f+(c[z>>2]|0)|0]<<2)>>2]&65535}if((a[f+(c[y>>2]|0)|0]|0)!=15){b[C+6>>1]=s;b[B+6>>1]=c[t+(d[f+(c[y>>2]|0)|0]<<2)>>2]&65535}if((a[f+(c[x>>2]|0)|0]|0)!=15){b[C+8>>1]=s;b[B+8>>1]=c[t+(d[f+(c[x>>2]|0)|0]<<2)>>2]&65535}if((a[f+(c[w>>2]|0)|0]|0)!=15){b[C+10>>1]=s;b[B+10>>1]=c[t+(d[f+(c[w>>2]|0)|0]<<2)>>2]&65535}if((a[f+(c[v>>2]|0)|0]|0)!=15){b[C+12>>1]=s;b[B+12>>1]=c[t+(d[f+(c[v>>2]|0)|0]<<2)>>2]&65535}if((a[f+(c[u>>2]|0)|0]|0)!=15){b[C+14>>1]=s;b[B+14>>1]=c[t+(d[f+(c[u>>2]|0)|0]<<2)>>2]&65535}do{if(!i){if((a[f+(c[k>>2]|0)|0]|0)!=15){b[C+16>>1]=s;b[B+16>>1]=c[t+(d[f+(c[k>>2]|0)|0]<<2)>>2]&65535}if((h|0)<10){break}if((a[f+(c[l>>2]|0)|0]|0)!=15){b[C+18>>1]=s;b[B+18>>1]=c[t+(d[f+(c[l>>2]|0)|0]<<2)>>2]&65535}if((h|0)<11){break}if((a[f+(c[m>>2]|0)|0]|0)!=15){b[C+20>>1]=s;b[B+20>>1]=c[t+(d[f+(c[m>>2]|0)|0]<<2)>>2]&65535}if((h|0)<12){break}if((a[f+(c[n>>2]|0)|0]|0)!=15){b[C+22>>1]=s;b[B+22>>1]=c[t+(d[f+(c[n>>2]|0)|0]<<2)>>2]&65535}if((h|0)<13){break}if((a[f+(c[o>>2]|0)|0]|0)!=15){b[C+24>>1]=s;b[B+24>>1]=c[t+(d[f+(c[o>>2]|0)|0]<<2)>>2]&65535}if((h|0)<14){break}if((a[f+(c[p>>2]|0)|0]|0)!=15){b[C+26>>1]=s;b[B+26>>1]=c[t+(d[f+(c[p>>2]|0)|0]<<2)>>2]&65535}if((h|0)<15){break}if((a[f+(c[q>>2]|0)|0]|0)!=15){b[C+28>>1]=s;b[B+28>>1]=c[t+(d[f+(c[q>>2]|0)|0]<<2)>>2]&65535}if((h|0)<16){break}if((a[f+(c[r>>2]|0)|0]|0)==15){break}b[C+30>>1]=s;b[B+30>>1]=c[t+(d[f+(c[r>>2]|0)|0]<<2)>>2]&65535}}while(0);E=f+(c[j+(e+~D<<2)>>2]|0)|0;if((D|0)<=0){break}B=B-640|0;C=C-640|0;D=D-1|0;f=E}c[2385338]=E;return}function dXe(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;e=c[3528502]|0;f=e-1|0;if((e|0)<=0){return}g=c[2385456]|0;h=g+f|0;if((h|0)<0){return}i=c[3528422]|0;j=c[2385468]|0;k=j>>>0<320;l=c[3528424]|0;m=c[2415164]&65535;n=c[2440386]|0;o=l+4|0;p=l+8|0;q=l+12|0;r=l+16|0;s=l+20|0;t=l+24|0;u=l+28|0;v=c[3528504]|0;w=(v|0)<9;x=(j+8|0)>>>0<320;y=l+32|0;z=(j+9|0)>>>0<320;A=l+36|0;B=(j+10|0)>>>0<320;C=l+40|0;D=(j+11|0)>>>0<320;E=l+44|0;F=(j+12|0)>>>0<320;G=l+48|0;H=(j+13|0)>>>0<320;I=l+52|0;J=(j+14|0)>>>0<320;K=l+56|0;L=(j+15|0)>>>0<320;M=l+60|0;N=f;O=(c[2409606]|0)+((f*320|0)<<1)|0;P=(c[2415150]|0)+(f*640|0)|0;f=h;h=c[2385338]|0;while(1){do{if((f|0)<=223){do{if(k){if((a[h+(c[l>>2]|0)|0]|0)==15){break}b[O>>1]=m;b[P>>1]=c[n+(d[h+(c[l>>2]|0)|0]<<2)>>2]&65535}}while(0);do{if((j+1|0)>>>0<320){if((a[h+(c[o>>2]|0)|0]|0)==15){break}b[O+2>>1]=m;b[P+2>>1]=c[n+(d[h+(c[o>>2]|0)|0]<<2)>>2]&65535}}while(0);do{if((j+2|0)>>>0<320){if((a[h+(c[p>>2]|0)|0]|0)==15){break}b[O+4>>1]=m;b[P+4>>1]=c[n+(d[h+(c[p>>2]|0)|0]<<2)>>2]&65535}}while(0);do{if((j+3|0)>>>0<320){if((a[h+(c[q>>2]|0)|0]|0)==15){break}b[O+6>>1]=m;b[P+6>>1]=c[n+(d[h+(c[q>>2]|0)|0]<<2)>>2]&65535}}while(0);do{if((j+4|0)>>>0<320){if((a[h+(c[r>>2]|0)|0]|0)==15){break}b[O+8>>1]=m;b[P+8>>1]=c[n+(d[h+(c[r>>2]|0)|0]<<2)>>2]&65535}}while(0);do{if((j+5|0)>>>0<320){if((a[h+(c[s>>2]|0)|0]|0)==15){break}b[O+10>>1]=m;b[P+10>>1]=c[n+(d[h+(c[s>>2]|0)|0]<<2)>>2]&65535}}while(0);do{if((j+6|0)>>>0<320){if((a[h+(c[t>>2]|0)|0]|0)==15){break}b[O+12>>1]=m;b[P+12>>1]=c[n+(d[h+(c[t>>2]|0)|0]<<2)>>2]&65535}}while(0);do{if((j+7|0)>>>0<320){if((a[h+(c[u>>2]|0)|0]|0)==15){break}b[O+14>>1]=m;b[P+14>>1]=c[n+(d[h+(c[u>>2]|0)|0]<<2)>>2]&65535}}while(0);if(w){break}do{if(x){if((a[h+(c[y>>2]|0)|0]|0)==15){break}b[O+16>>1]=m;b[P+16>>1]=c[n+(d[h+(c[y>>2]|0)|0]<<2)>>2]&65535}}while(0);if((v|0)<10){break}do{if(z){if((a[h+(c[A>>2]|0)|0]|0)==15){break}b[O+18>>1]=m;b[P+18>>1]=c[n+(d[h+(c[A>>2]|0)|0]<<2)>>2]&65535}}while(0);if((v|0)<11){break}do{if(B){if((a[h+(c[C>>2]|0)|0]|0)==15){break}b[O+20>>1]=m;b[P+20>>1]=c[n+(d[h+(c[C>>2]|0)|0]<<2)>>2]&65535}}while(0);if((v|0)<12){break}do{if(D){if((a[h+(c[E>>2]|0)|0]|0)==15){break}b[O+22>>1]=m;b[P+22>>1]=c[n+(d[h+(c[E>>2]|0)|0]<<2)>>2]&65535}}while(0);if((v|0)<13){break}do{if(F){if((a[h+(c[G>>2]|0)|0]|0)==15){break}b[O+24>>1]=m;b[P+24>>1]=c[n+(d[h+(c[G>>2]|0)|0]<<2)>>2]&65535}}while(0);if((v|0)<14){break}do{if(H){if((a[h+(c[I>>2]|0)|0]|0)==15){break}b[O+26>>1]=m;b[P+26>>1]=c[n+(d[h+(c[I>>2]|0)|0]<<2)>>2]&65535}}while(0);if((v|0)<15){break}do{if(J){if((a[h+(c[K>>2]|0)|0]|0)==15){break}b[O+28>>1]=m;b[P+28>>1]=c[n+(d[h+(c[K>>2]|0)|0]<<2)>>2]&65535}}while(0);if((v|0)<16|L^1){break}if((a[h+(c[M>>2]|0)|0]|0)==15){break}b[O+30>>1]=m;b[P+30>>1]=c[n+(d[h+(c[M>>2]|0)|0]<<2)>>2]&65535}}while(0);Q=h+(c[i+(e+~N<<2)>>2]|0)|0;if((N|0)<=0){break}R=N-1|0;S=g+R|0;if((S|0)<0){break}else{N=R;O=O-640|0;P=P-640|0;f=S;h=Q}}c[2385338]=Q;return}function dXf(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;f=c[3528502]|0;g=f-1|0;if((f|0)<=0){return}h=c[3528424]|0;i=c[3528504]|0;j=(i|0)<9;k=c[3528422]|0;l=h+32|0;m=h+36|0;n=h+40|0;o=h+44|0;p=h+48|0;q=h+52|0;r=h+56|0;s=h+60|0;t=c[2415164]|0;u=t&65535;v=c[2440386]|0;w=h+28|0;x=h+24|0;y=h+20|0;z=h+16|0;A=h+12|0;B=h+8|0;C=h+4|0;D=(c[2415150]|0)+(g*640|0)|0;E=(c[2409606]|0)+((g*320|0)<<1)|0;F=g;g=c[2385338]|0;while(1){do{if((a[g+(c[h>>2]|0)|0]|0)==15){G=g}else{if((e[E>>1]|0)>(t|0)){G=g;break}b[E>>1]=u;b[D>>1]=c[v+(d[g+(c[h>>2]|0)|0]<<2)>>2]&65535;G=g}}while(0);do{if((a[G+(c[C>>2]|0)|0]|0)==15){H=G}else{I=E+2|0;if((e[I>>1]|0)>(t|0)){H=G;break}b[I>>1]=u;b[D+2>>1]=c[v+(d[g+(c[C>>2]|0)|0]<<2)>>2]&65535;H=g}}while(0);do{if((a[H+(c[B>>2]|0)|0]|0)==15){J=H}else{I=E+4|0;if((e[I>>1]|0)>(t|0)){J=H;break}b[I>>1]=u;b[D+4>>1]=c[v+(d[g+(c[B>>2]|0)|0]<<2)>>2]&65535;J=g}}while(0);do{if((a[J+(c[A>>2]|0)|0]|0)==15){K=J}else{I=E+6|0;if((e[I>>1]|0)>(t|0)){K=J;break}b[I>>1]=u;b[D+6>>1]=c[v+(d[g+(c[A>>2]|0)|0]<<2)>>2]&65535;K=g}}while(0);do{if((a[K+(c[z>>2]|0)|0]|0)==15){L=K}else{I=E+8|0;if((e[I>>1]|0)>(t|0)){L=K;break}b[I>>1]=u;b[D+8>>1]=c[v+(d[g+(c[z>>2]|0)|0]<<2)>>2]&65535;L=g}}while(0);do{if((a[L+(c[y>>2]|0)|0]|0)==15){M=L}else{I=E+10|0;if((e[I>>1]|0)>(t|0)){M=L;break}b[I>>1]=u;b[D+10>>1]=c[v+(d[g+(c[y>>2]|0)|0]<<2)>>2]&65535;M=g}}while(0);do{if((a[M+(c[x>>2]|0)|0]|0)==15){N=M}else{I=E+12|0;if((e[I>>1]|0)>(t|0)){N=M;break}b[I>>1]=u;b[D+12>>1]=c[v+(d[g+(c[x>>2]|0)|0]<<2)>>2]&65535;N=g}}while(0);do{if((a[N+(c[w>>2]|0)|0]|0)!=15){I=E+14|0;if((e[I>>1]|0)>(t|0)){break}b[I>>1]=u;b[D+14>>1]=c[v+(d[g+(c[w>>2]|0)|0]<<2)>>2]&65535}}while(0);do{if(!j){do{if((a[g+(c[l>>2]|0)|0]|0)!=15){I=E+16|0;if((e[I>>1]|0)>(t|0)){break}b[I>>1]=u;b[D+16>>1]=c[v+(d[g+(c[l>>2]|0)|0]<<2)>>2]&65535}}while(0);if((i|0)<10){break}do{if((a[g+(c[m>>2]|0)|0]|0)!=15){I=E+18|0;if((e[I>>1]|0)>(t|0)){break}b[I>>1]=u;b[D+18>>1]=c[v+(d[g+(c[m>>2]|0)|0]<<2)>>2]&65535}}while(0);if((i|0)<11){break}do{if((a[g+(c[n>>2]|0)|0]|0)!=15){I=E+20|0;if((e[I>>1]|0)>(t|0)){break}b[I>>1]=u;b[D+20>>1]=c[v+(d[g+(c[n>>2]|0)|0]<<2)>>2]&65535}}while(0);if((i|0)<12){break}do{if((a[g+(c[o>>2]|0)|0]|0)!=15){I=E+22|0;if((e[I>>1]|0)>(t|0)){break}b[I>>1]=u;b[D+22>>1]=c[v+(d[g+(c[o>>2]|0)|0]<<2)>>2]&65535}}while(0);if((i|0)<13){break}do{if((a[g+(c[p>>2]|0)|0]|0)!=15){I=E+24|0;if((e[I>>1]|0)>(t|0)){break}b[I>>1]=u;b[D+24>>1]=c[v+(d[g+(c[p>>2]|0)|0]<<2)>>2]&65535}}while(0);if((i|0)<14){break}do{if((a[g+(c[q>>2]|0)|0]|0)!=15){I=E+26|0;if((e[I>>1]|0)>(t|0)){break}b[I>>1]=u;b[D+26>>1]=c[v+(d[g+(c[q>>2]|0)|0]<<2)>>2]&65535}}while(0);if((i|0)<15){break}do{if((a[g+(c[r>>2]|0)|0]|0)!=15){I=E+28|0;if((e[I>>1]|0)>(t|0)){break}b[I>>1]=u;b[D+28>>1]=c[v+(d[g+(c[r>>2]|0)|0]<<2)>>2]&65535}}while(0);if((i|0)<16){break}if((a[g+(c[s>>2]|0)|0]|0)==15){break}I=E+30|0;if((e[I>>1]|0)>(t|0)){break}b[I>>1]=u;b[D+30>>1]=c[v+(d[g+(c[s>>2]|0)|0]<<2)>>2]&65535}}while(0);O=g+(c[k+(f+~F<<2)>>2]|0)|0;if((F|0)<=0){break}D=D-640|0;E=E-640|0;F=F-1|0;g=O}c[2385338]=O;return}function dXg(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;f=c[3528502]|0;g=f-1|0;if((f|0)<=0){return}h=c[2385456]|0;i=h+g|0;if((i|0)<0){return}j=c[3528422]|0;k=c[2385468]|0;l=k>>>0<320;m=c[3528424]|0;n=c[2415164]|0;o=n&65535;p=c[2440386]|0;q=m+4|0;r=m+8|0;s=m+12|0;t=m+16|0;u=m+20|0;v=m+24|0;w=m+28|0;x=c[3528504]|0;y=(x|0)<9;z=(k+8|0)>>>0<320;A=m+32|0;B=(k+9|0)>>>0<320;C=m+36|0;D=(k+10|0)>>>0<320;E=m+40|0;F=(k+11|0)>>>0<320;G=m+44|0;H=(k+12|0)>>>0<320;I=m+48|0;J=(k+13|0)>>>0<320;K=m+52|0;L=(k+14|0)>>>0<320;M=m+56|0;N=(k+15|0)>>>0<320;O=m+60|0;P=g;Q=(c[2409606]|0)+((g*320|0)<<1)|0;R=(c[2415150]|0)+(g*640|0)|0;g=i;i=c[2385338]|0;while(1){do{if((g|0)<=223){do{if(l){if((a[i+(c[m>>2]|0)|0]|0)==15){break}if((e[Q>>1]|0)>(n|0)){break}b[Q>>1]=o;b[R>>1]=c[p+(d[i+(c[m>>2]|0)|0]<<2)>>2]&65535}}while(0);do{if((k+1|0)>>>0<320){if((a[i+(c[q>>2]|0)|0]|0)==15){break}S=Q+2|0;if((e[S>>1]|0)>(n|0)){break}b[S>>1]=o;b[R+2>>1]=c[p+(d[i+(c[q>>2]|0)|0]<<2)>>2]&65535}}while(0);do{if((k+2|0)>>>0<320){if((a[i+(c[r>>2]|0)|0]|0)==15){break}S=Q+4|0;if((e[S>>1]|0)>(n|0)){break}b[S>>1]=o;b[R+4>>1]=c[p+(d[i+(c[r>>2]|0)|0]<<2)>>2]&65535}}while(0);do{if((k+3|0)>>>0<320){if((a[i+(c[s>>2]|0)|0]|0)==15){break}S=Q+6|0;if((e[S>>1]|0)>(n|0)){break}b[S>>1]=o;b[R+6>>1]=c[p+(d[i+(c[s>>2]|0)|0]<<2)>>2]&65535}}while(0);do{if((k+4|0)>>>0<320){if((a[i+(c[t>>2]|0)|0]|0)==15){break}S=Q+8|0;if((e[S>>1]|0)>(n|0)){break}b[S>>1]=o;b[R+8>>1]=c[p+(d[i+(c[t>>2]|0)|0]<<2)>>2]&65535}}while(0);do{if((k+5|0)>>>0<320){if((a[i+(c[u>>2]|0)|0]|0)==15){break}S=Q+10|0;if((e[S>>1]|0)>(n|0)){break}b[S>>1]=o;b[R+10>>1]=c[p+(d[i+(c[u>>2]|0)|0]<<2)>>2]&65535}}while(0);do{if((k+6|0)>>>0<320){if((a[i+(c[v>>2]|0)|0]|0)==15){break}S=Q+12|0;if((e[S>>1]|0)>(n|0)){break}b[S>>1]=o;b[R+12>>1]=c[p+(d[i+(c[v>>2]|0)|0]<<2)>>2]&65535}}while(0);do{if((k+7|0)>>>0<320){if((a[i+(c[w>>2]|0)|0]|0)==15){break}S=Q+14|0;if((e[S>>1]|0)>(n|0)){break}b[S>>1]=o;b[R+14>>1]=c[p+(d[i+(c[w>>2]|0)|0]<<2)>>2]&65535}}while(0);if(y){break}do{if(z){if((a[i+(c[A>>2]|0)|0]|0)==15){break}S=Q+16|0;if((e[S>>1]|0)>(n|0)){break}b[S>>1]=o;b[R+16>>1]=c[p+(d[i+(c[A>>2]|0)|0]<<2)>>2]&65535}}while(0);if((x|0)<10){break}do{if(B){if((a[i+(c[C>>2]|0)|0]|0)==15){break}S=Q+18|0;if((e[S>>1]|0)>(n|0)){break}b[S>>1]=o;b[R+18>>1]=c[p+(d[i+(c[C>>2]|0)|0]<<2)>>2]&65535}}while(0);if((x|0)<11){break}do{if(D){if((a[i+(c[E>>2]|0)|0]|0)==15){break}S=Q+20|0;if((e[S>>1]|0)>(n|0)){break}b[S>>1]=o;b[R+20>>1]=c[p+(d[i+(c[E>>2]|0)|0]<<2)>>2]&65535}}while(0);if((x|0)<12){break}do{if(F){if((a[i+(c[G>>2]|0)|0]|0)==15){break}S=Q+22|0;if((e[S>>1]|0)>(n|0)){break}b[S>>1]=o;b[R+22>>1]=c[p+(d[i+(c[G>>2]|0)|0]<<2)>>2]&65535}}while(0);if((x|0)<13){break}do{if(H){if((a[i+(c[I>>2]|0)|0]|0)==15){break}S=Q+24|0;if((e[S>>1]|0)>(n|0)){break}b[S>>1]=o;b[R+24>>1]=c[p+(d[i+(c[I>>2]|0)|0]<<2)>>2]&65535}}while(0);if((x|0)<14){break}do{if(J){if((a[i+(c[K>>2]|0)|0]|0)==15){break}S=Q+26|0;if((e[S>>1]|0)>(n|0)){break}b[S>>1]=o;b[R+26>>1]=c[p+(d[i+(c[K>>2]|0)|0]<<2)>>2]&65535}}while(0);if((x|0)<15){break}do{if(L){if((a[i+(c[M>>2]|0)|0]|0)==15){break}S=Q+28|0;if((e[S>>1]|0)>(n|0)){break}b[S>>1]=o;b[R+28>>1]=c[p+(d[i+(c[M>>2]|0)|0]<<2)>>2]&65535}}while(0);if((x|0)<16|N^1){break}if((a[i+(c[O>>2]|0)|0]|0)==15){break}S=Q+30|0;if((e[S>>1]|0)>(n|0)){break}b[S>>1]=o;b[R+30>>1]=c[p+(d[i+(c[O>>2]|0)|0]<<2)>>2]&65535}}while(0);T=i+(c[j+(f+~P<<2)>>2]|0)|0;if((P|0)<=0){break}S=P-1|0;U=h+S|0;if((U|0)<0){break}else{P=S;Q=Q-640|0;R=R-640|0;g=U;i=T}}c[2385338]=T;return}function dXh(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=c[3528502]|0;e=d-1|0;if((d|0)<=0){return}f=c[3528424]|0;g=c[3528504]|0;h=(g|0)<9;i=c[3528422]|0;j=f+32|0;k=f+36|0;l=f+40|0;m=f+44|0;n=f+48|0;o=f+52|0;p=f+56|0;q=f+60|0;r=c[2440386]|0;s=(c[2415150]|0)+(e*640|0)|0;t=e;e=c[2385338]|0;while(1){u=a[e+(15-(c[f>>2]|0))|0]|0;if(u<<24>>24!=15){b[s>>1]=c[r+((u&255)<<2)>>2]&65535}u=a[e+(15-(c[f+4>>2]|0))|0]|0;if(u<<24>>24!=15){b[s+2>>1]=c[r+((u&255)<<2)>>2]&65535}u=a[e+(15-(c[f+8>>2]|0))|0]|0;if(u<<24>>24!=15){b[s+4>>1]=c[r+((u&255)<<2)>>2]&65535}u=a[e+(15-(c[f+12>>2]|0))|0]|0;if(u<<24>>24!=15){b[s+6>>1]=c[r+((u&255)<<2)>>2]&65535}u=a[e+(15-(c[f+16>>2]|0))|0]|0;if(u<<24>>24!=15){b[s+8>>1]=c[r+((u&255)<<2)>>2]&65535}u=a[e+(15-(c[f+20>>2]|0))|0]|0;if(u<<24>>24!=15){b[s+10>>1]=c[r+((u&255)<<2)>>2]&65535}u=a[e+(15-(c[f+24>>2]|0))|0]|0;if(u<<24>>24!=15){b[s+12>>1]=c[r+((u&255)<<2)>>2]&65535}u=a[e+(15-(c[f+28>>2]|0))|0]|0;if(u<<24>>24!=15){b[s+14>>1]=c[r+((u&255)<<2)>>2]&65535}do{if(!h){u=a[e+(15-(c[j>>2]|0))|0]|0;if(u<<24>>24!=15){b[s+16>>1]=c[r+((u&255)<<2)>>2]&65535}if((g|0)<10){break}u=a[e+(15-(c[k>>2]|0))|0]|0;if(u<<24>>24!=15){b[s+18>>1]=c[r+((u&255)<<2)>>2]&65535}if((g|0)<11){break}u=a[e+(15-(c[l>>2]|0))|0]|0;if(u<<24>>24!=15){b[s+20>>1]=c[r+((u&255)<<2)>>2]&65535}if((g|0)<12){break}u=a[e+(15-(c[m>>2]|0))|0]|0;if(u<<24>>24!=15){b[s+22>>1]=c[r+((u&255)<<2)>>2]&65535}if((g|0)<13){break}u=a[e+(15-(c[n>>2]|0))|0]|0;if(u<<24>>24!=15){b[s+24>>1]=c[r+((u&255)<<2)>>2]&65535}if((g|0)<14){break}u=a[e+(15-(c[o>>2]|0))|0]|0;if(u<<24>>24!=15){b[s+26>>1]=c[r+((u&255)<<2)>>2]&65535}if((g|0)<15){break}u=a[e+(15-(c[p>>2]|0))|0]|0;if(u<<24>>24!=15){b[s+28>>1]=c[r+((u&255)<<2)>>2]&65535}if((g|0)<16){break}u=a[e+(15-(c[q>>2]|0))|0]|0;if(u<<24>>24==15){break}b[s+30>>1]=c[r+((u&255)<<2)>>2]&65535}}while(0);v=e+(c[i+(d+~t<<2)>>2]|0)|0;if((t|0)<=0){break}s=s-640|0;t=t-1|0;e=v}c[2385338]=v;return}function dXi(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;d=c[3528502]|0;e=d-1|0;if((d|0)<=0){return}f=c[2385456]|0;g=f+e|0;if((g|0)<0){return}h=c[3528422]|0;i=c[2385468]|0;j=i>>>0<320;k=c[3528424]|0;l=c[2440386]|0;m=k+4|0;n=k+8|0;o=k+12|0;p=k+16|0;q=k+20|0;r=k+24|0;s=k+28|0;t=c[3528504]|0;u=(t|0)<9;v=(i+8|0)>>>0<320;w=k+32|0;x=(i+9|0)>>>0<320;y=k+36|0;z=(i+10|0)>>>0<320;A=k+40|0;B=(i+11|0)>>>0<320;C=k+44|0;D=(i+12|0)>>>0<320;E=k+48|0;F=(i+13|0)>>>0<320;G=k+52|0;H=(i+14|0)>>>0<320;I=k+56|0;J=(i+15|0)>>>0<320;K=k+60|0;L=e;M=(c[2415150]|0)+(e*640|0)|0;e=g;g=c[2385338]|0;while(1){do{if((e|0)<=223){do{if(j){N=a[g+(15-(c[k>>2]|0))|0]|0;if(N<<24>>24==15){break}b[M>>1]=c[l+((N&255)<<2)>>2]&65535}}while(0);do{if((i+1|0)>>>0<320){N=a[g+(15-(c[m>>2]|0))|0]|0;if(N<<24>>24==15){break}b[M+2>>1]=c[l+((N&255)<<2)>>2]&65535}}while(0);do{if((i+2|0)>>>0<320){N=a[g+(15-(c[n>>2]|0))|0]|0;if(N<<24>>24==15){break}b[M+4>>1]=c[l+((N&255)<<2)>>2]&65535}}while(0);do{if((i+3|0)>>>0<320){N=a[g+(15-(c[o>>2]|0))|0]|0;if(N<<24>>24==15){break}b[M+6>>1]=c[l+((N&255)<<2)>>2]&65535}}while(0);do{if((i+4|0)>>>0<320){N=a[g+(15-(c[p>>2]|0))|0]|0;if(N<<24>>24==15){break}b[M+8>>1]=c[l+((N&255)<<2)>>2]&65535}}while(0);do{if((i+5|0)>>>0<320){N=a[g+(15-(c[q>>2]|0))|0]|0;if(N<<24>>24==15){break}b[M+10>>1]=c[l+((N&255)<<2)>>2]&65535}}while(0);do{if((i+6|0)>>>0<320){N=a[g+(15-(c[r>>2]|0))|0]|0;if(N<<24>>24==15){break}b[M+12>>1]=c[l+((N&255)<<2)>>2]&65535}}while(0);do{if((i+7|0)>>>0<320){N=a[g+(15-(c[s>>2]|0))|0]|0;if(N<<24>>24==15){break}b[M+14>>1]=c[l+((N&255)<<2)>>2]&65535}}while(0);if(u){break}do{if(v){N=a[g+(15-(c[w>>2]|0))|0]|0;if(N<<24>>24==15){break}b[M+16>>1]=c[l+((N&255)<<2)>>2]&65535}}while(0);if((t|0)<10){break}do{if(x){N=a[g+(15-(c[y>>2]|0))|0]|0;if(N<<24>>24==15){break}b[M+18>>1]=c[l+((N&255)<<2)>>2]&65535}}while(0);if((t|0)<11){break}do{if(z){N=a[g+(15-(c[A>>2]|0))|0]|0;if(N<<24>>24==15){break}b[M+20>>1]=c[l+((N&255)<<2)>>2]&65535}}while(0);if((t|0)<12){break}do{if(B){N=a[g+(15-(c[C>>2]|0))|0]|0;if(N<<24>>24==15){break}b[M+22>>1]=c[l+((N&255)<<2)>>2]&65535}}while(0);if((t|0)<13){break}do{if(D){N=a[g+(15-(c[E>>2]|0))|0]|0;if(N<<24>>24==15){break}b[M+24>>1]=c[l+((N&255)<<2)>>2]&65535}}while(0);if((t|0)<14){break}do{if(F){N=a[g+(15-(c[G>>2]|0))|0]|0;if(N<<24>>24==15){break}b[M+26>>1]=c[l+((N&255)<<2)>>2]&65535}}while(0);if((t|0)<15){break}do{if(H){N=a[g+(15-(c[I>>2]|0))|0]|0;if(N<<24>>24==15){break}b[M+28>>1]=c[l+((N&255)<<2)>>2]&65535}}while(0);if((t|0)<16|J^1){break}N=a[g+(15-(c[K>>2]|0))|0]|0;if(N<<24>>24==15){break}b[M+30>>1]=c[l+((N&255)<<2)>>2]&65535}}while(0);O=g+(c[h+(d+~L<<2)>>2]|0)|0;if((L|0)<=0){break}N=L-1|0;P=f+N|0;if((P|0)<0){break}else{L=N;M=M-640|0;e=P;g=O}}c[2385338]=O;return}function dXj(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;d=c[3528502]|0;f=d-1|0;if((d|0)<=0){return}g=c[3528424]|0;h=c[3528504]|0;i=(h|0)<9;j=c[3528422]|0;k=g+32|0;l=g+36|0;m=g+40|0;n=g+44|0;o=g+48|0;p=g+52|0;q=g+56|0;r=g+60|0;s=c[2415164]|0;t=c[2440386]|0;u=(c[2415150]|0)+(f*640|0)|0;v=(c[2409606]|0)+((f*320|0)<<1)|0;w=f;f=c[2385338]|0;while(1){x=a[f+(15-(c[g>>2]|0))|0]|0;y=x&255;do{if(x<<24>>24==15){z=f}else{if((e[v>>1]|0|0)>(s|0)){z=f;break}b[u>>1]=c[t+(y<<2)>>2]&65535;z=f}}while(0);y=a[z+(15-(c[g+4>>2]|0))|0]|0;x=y&255;do{if(y<<24>>24==15){A=z}else{if((e[v+2>>1]|0|0)>(s|0)){A=z;break}b[u+2>>1]=c[t+(x<<2)>>2]&65535;A=f}}while(0);x=a[A+(15-(c[g+8>>2]|0))|0]|0;y=x&255;do{if(x<<24>>24==15){B=A}else{if((e[v+4>>1]|0|0)>(s|0)){B=A;break}b[u+4>>1]=c[t+(y<<2)>>2]&65535;B=f}}while(0);y=a[B+(15-(c[g+12>>2]|0))|0]|0;x=y&255;do{if(y<<24>>24==15){C=B}else{if((e[v+6>>1]|0|0)>(s|0)){C=B;break}b[u+6>>1]=c[t+(x<<2)>>2]&65535;C=f}}while(0);x=a[C+(15-(c[g+16>>2]|0))|0]|0;y=x&255;do{if(x<<24>>24==15){D=C}else{if((e[v+8>>1]|0|0)>(s|0)){D=C;break}b[u+8>>1]=c[t+(y<<2)>>2]&65535;D=f}}while(0);y=a[D+(15-(c[g+20>>2]|0))|0]|0;x=y&255;do{if(y<<24>>24==15){E=D}else{if((e[v+10>>1]|0|0)>(s|0)){E=D;break}b[u+10>>1]=c[t+(x<<2)>>2]&65535;E=f}}while(0);x=a[E+(15-(c[g+24>>2]|0))|0]|0;y=x&255;do{if(x<<24>>24==15){F=E}else{if((e[v+12>>1]|0|0)>(s|0)){F=E;break}b[u+12>>1]=c[t+(y<<2)>>2]&65535;F=f}}while(0);y=a[F+(15-(c[g+28>>2]|0))|0]|0;x=y&255;do{if(y<<24>>24!=15){if((e[v+14>>1]|0|0)>(s|0)){break}b[u+14>>1]=c[t+(x<<2)>>2]&65535}}while(0);do{if(!i){x=a[f+(15-(c[k>>2]|0))|0]|0;y=x&255;do{if(x<<24>>24!=15){if((e[v+16>>1]|0|0)>(s|0)){break}b[u+16>>1]=c[t+(y<<2)>>2]&65535}}while(0);if((h|0)<10){break}y=a[f+(15-(c[l>>2]|0))|0]|0;x=y&255;do{if(y<<24>>24!=15){if((e[v+18>>1]|0|0)>(s|0)){break}b[u+18>>1]=c[t+(x<<2)>>2]&65535}}while(0);if((h|0)<11){break}x=a[f+(15-(c[m>>2]|0))|0]|0;y=x&255;do{if(x<<24>>24!=15){if((e[v+20>>1]|0|0)>(s|0)){break}b[u+20>>1]=c[t+(y<<2)>>2]&65535}}while(0);if((h|0)<12){break}y=a[f+(15-(c[n>>2]|0))|0]|0;x=y&255;do{if(y<<24>>24!=15){if((e[v+22>>1]|0|0)>(s|0)){break}b[u+22>>1]=c[t+(x<<2)>>2]&65535}}while(0);if((h|0)<13){break}x=a[f+(15-(c[o>>2]|0))|0]|0;y=x&255;do{if(x<<24>>24!=15){if((e[v+24>>1]|0|0)>(s|0)){break}b[u+24>>1]=c[t+(y<<2)>>2]&65535}}while(0);if((h|0)<14){break}y=a[f+(15-(c[p>>2]|0))|0]|0;x=y&255;do{if(y<<24>>24!=15){if((e[v+26>>1]|0|0)>(s|0)){break}b[u+26>>1]=c[t+(x<<2)>>2]&65535}}while(0);if((h|0)<15){break}x=a[f+(15-(c[q>>2]|0))|0]|0;y=x&255;do{if(x<<24>>24!=15){if((e[v+28>>1]|0|0)>(s|0)){break}b[u+28>>1]=c[t+(y<<2)>>2]&65535}}while(0);if((h|0)<16){break}y=a[f+(15-(c[r>>2]|0))|0]|0;if(y<<24>>24==15){break}if((e[v+30>>1]|0|0)>(s|0)){break}b[u+30>>1]=c[t+((y&255)<<2)>>2]&65535}}while(0);G=f+(c[j+(d+~w<<2)>>2]|0)|0;if((w|0)<=0){break}u=u-640|0;v=v-640|0;w=w-1|0;f=G}c[2385338]=G;return}function dXk(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;d=c[3528502]|0;f=d-1|0;if((d|0)<=0){return}g=c[2385456]|0;h=g+f|0;if((h|0)<0){return}i=c[3528422]|0;j=c[2385468]|0;k=j>>>0<320;l=c[3528424]|0;m=c[2415164]|0;n=c[2440386]|0;o=l+4|0;p=l+8|0;q=l+12|0;r=l+16|0;s=l+20|0;t=l+24|0;u=l+28|0;v=c[3528504]|0;w=(v|0)<9;x=(j+8|0)>>>0<320;y=l+32|0;z=(j+9|0)>>>0<320;A=l+36|0;B=(j+10|0)>>>0<320;C=l+40|0;D=(j+11|0)>>>0<320;E=l+44|0;F=(j+12|0)>>>0<320;G=l+48|0;H=(j+13|0)>>>0<320;I=l+52|0;J=(j+14|0)>>>0<320;K=l+56|0;L=(j+15|0)>>>0<320;M=l+60|0;N=f;O=(c[2409606]|0)+((f*320|0)<<1)|0;P=(c[2415150]|0)+(f*640|0)|0;f=h;h=c[2385338]|0;while(1){do{if((f|0)<=223){do{if(k){Q=a[h+(15-(c[l>>2]|0))|0]|0;if(Q<<24>>24==15){break}if((e[O>>1]|0|0)>(m|0)){break}b[P>>1]=c[n+((Q&255)<<2)>>2]&65535}}while(0);do{if((j+1|0)>>>0<320){Q=a[h+(15-(c[o>>2]|0))|0]|0;if(Q<<24>>24==15){break}if((e[O+2>>1]|0|0)>(m|0)){break}b[P+2>>1]=c[n+((Q&255)<<2)>>2]&65535}}while(0);do{if((j+2|0)>>>0<320){Q=a[h+(15-(c[p>>2]|0))|0]|0;if(Q<<24>>24==15){break}if((e[O+4>>1]|0|0)>(m|0)){break}b[P+4>>1]=c[n+((Q&255)<<2)>>2]&65535}}while(0);do{if((j+3|0)>>>0<320){Q=a[h+(15-(c[q>>2]|0))|0]|0;if(Q<<24>>24==15){break}if((e[O+6>>1]|0|0)>(m|0)){break}b[P+6>>1]=c[n+((Q&255)<<2)>>2]&65535}}while(0);do{if((j+4|0)>>>0<320){Q=a[h+(15-(c[r>>2]|0))|0]|0;if(Q<<24>>24==15){break}if((e[O+8>>1]|0|0)>(m|0)){break}b[P+8>>1]=c[n+((Q&255)<<2)>>2]&65535}}while(0);do{if((j+5|0)>>>0<320){Q=a[h+(15-(c[s>>2]|0))|0]|0;if(Q<<24>>24==15){break}if((e[O+10>>1]|0|0)>(m|0)){break}b[P+10>>1]=c[n+((Q&255)<<2)>>2]&65535}}while(0);do{if((j+6|0)>>>0<320){Q=a[h+(15-(c[t>>2]|0))|0]|0;if(Q<<24>>24==15){break}if((e[O+12>>1]|0|0)>(m|0)){break}b[P+12>>1]=c[n+((Q&255)<<2)>>2]&65535}}while(0);do{if((j+7|0)>>>0<320){Q=a[h+(15-(c[u>>2]|0))|0]|0;if(Q<<24>>24==15){break}if((e[O+14>>1]|0|0)>(m|0)){break}b[P+14>>1]=c[n+((Q&255)<<2)>>2]&65535}}while(0);if(w){break}do{if(x){Q=a[h+(15-(c[y>>2]|0))|0]|0;if(Q<<24>>24==15){break}if((e[O+16>>1]|0|0)>(m|0)){break}b[P+16>>1]=c[n+((Q&255)<<2)>>2]&65535}}while(0);if((v|0)<10){break}do{if(z){Q=a[h+(15-(c[A>>2]|0))|0]|0;if(Q<<24>>24==15){break}if((e[O+18>>1]|0|0)>(m|0)){break}b[P+18>>1]=c[n+((Q&255)<<2)>>2]&65535}}while(0);if((v|0)<11){break}do{if(B){Q=a[h+(15-(c[C>>2]|0))|0]|0;if(Q<<24>>24==15){break}if((e[O+20>>1]|0|0)>(m|0)){break}b[P+20>>1]=c[n+((Q&255)<<2)>>2]&65535}}while(0);if((v|0)<12){break}do{if(D){Q=a[h+(15-(c[E>>2]|0))|0]|0;if(Q<<24>>24==15){break}if((e[O+22>>1]|0|0)>(m|0)){break}b[P+22>>1]=c[n+((Q&255)<<2)>>2]&65535}}while(0);if((v|0)<13){break}do{if(F){Q=a[h+(15-(c[G>>2]|0))|0]|0;if(Q<<24>>24==15){break}if((e[O+24>>1]|0|0)>(m|0)){break}b[P+24>>1]=c[n+((Q&255)<<2)>>2]&65535}}while(0);if((v|0)<14){break}do{if(H){Q=a[h+(15-(c[I>>2]|0))|0]|0;if(Q<<24>>24==15){break}if((e[O+26>>1]|0|0)>(m|0)){break}b[P+26>>1]=c[n+((Q&255)<<2)>>2]&65535}}while(0);if((v|0)<15){break}do{if(J){Q=a[h+(15-(c[K>>2]|0))|0]|0;if(Q<<24>>24==15){break}if((e[O+28>>1]|0|0)>(m|0)){break}b[P+28>>1]=c[n+((Q&255)<<2)>>2]&65535}}while(0);if((v|0)<16|L^1){break}Q=a[h+(15-(c[M>>2]|0))|0]|0;if(Q<<24>>24==15){break}if((e[O+30>>1]|0|0)>(m|0)){break}b[P+30>>1]=c[n+((Q&255)<<2)>>2]&65535}}while(0);R=h+(c[i+(d+~N<<2)>>2]|0)|0;if((N|0)<=0){break}Q=N-1|0;S=g+Q|0;if((S|0)<0){break}else{N=Q;O=O-640|0;P=P-640|0;f=S;h=R}}c[2385338]=R;return}function dXl(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;e=c[3528502]|0;f=e-1|0;if((e|0)<=0){return}g=c[3528424]|0;h=c[3528504]|0;i=(h|0)<9;j=c[3528422]|0;k=g+32|0;l=g+36|0;m=g+40|0;n=g+44|0;o=g+48|0;p=g+52|0;q=g+56|0;r=g+60|0;s=c[2415164]&65535;t=c[2440386]|0;u=g+28|0;v=g+24|0;w=g+20|0;x=g+16|0;y=g+12|0;z=g+8|0;A=g+4|0;B=(c[2415150]|0)+(f*640|0)|0;C=(c[2409606]|0)+((f*320|0)<<1)|0;D=f;f=c[2385338]|0;while(1){if((a[f+(15-(c[g>>2]|0))|0]|0)!=15){b[C>>1]=s;b[B>>1]=c[t+(d[f+(15-(c[g>>2]|0))|0]<<2)>>2]&65535}if((a[f+(15-(c[A>>2]|0))|0]|0)!=15){b[C+2>>1]=s;b[B+2>>1]=c[t+(d[f+(15-(c[A>>2]|0))|0]<<2)>>2]&65535}if((a[f+(15-(c[z>>2]|0))|0]|0)!=15){b[C+4>>1]=s;b[B+4>>1]=c[t+(d[f+(15-(c[z>>2]|0))|0]<<2)>>2]&65535}if((a[f+(15-(c[y>>2]|0))|0]|0)!=15){b[C+6>>1]=s;b[B+6>>1]=c[t+(d[f+(15-(c[y>>2]|0))|0]<<2)>>2]&65535}if((a[f+(15-(c[x>>2]|0))|0]|0)!=15){b[C+8>>1]=s;b[B+8>>1]=c[t+(d[f+(15-(c[x>>2]|0))|0]<<2)>>2]&65535}if((a[f+(15-(c[w>>2]|0))|0]|0)!=15){b[C+10>>1]=s;b[B+10>>1]=c[t+(d[f+(15-(c[w>>2]|0))|0]<<2)>>2]&65535}if((a[f+(15-(c[v>>2]|0))|0]|0)!=15){b[C+12>>1]=s;b[B+12>>1]=c[t+(d[f+(15-(c[v>>2]|0))|0]<<2)>>2]&65535}if((a[f+(15-(c[u>>2]|0))|0]|0)!=15){b[C+14>>1]=s;b[B+14>>1]=c[t+(d[f+(15-(c[u>>2]|0))|0]<<2)>>2]&65535}do{if(!i){if((a[f+(15-(c[k>>2]|0))|0]|0)!=15){b[C+16>>1]=s;b[B+16>>1]=c[t+(d[f+(15-(c[k>>2]|0))|0]<<2)>>2]&65535}if((h|0)<10){break}if((a[f+(15-(c[l>>2]|0))|0]|0)!=15){b[C+18>>1]=s;b[B+18>>1]=c[t+(d[f+(15-(c[l>>2]|0))|0]<<2)>>2]&65535}if((h|0)<11){break}if((a[f+(15-(c[m>>2]|0))|0]|0)!=15){b[C+20>>1]=s;b[B+20>>1]=c[t+(d[f+(15-(c[m>>2]|0))|0]<<2)>>2]&65535}if((h|0)<12){break}if((a[f+(15-(c[n>>2]|0))|0]|0)!=15){b[C+22>>1]=s;b[B+22>>1]=c[t+(d[f+(15-(c[n>>2]|0))|0]<<2)>>2]&65535}if((h|0)<13){break}if((a[f+(15-(c[o>>2]|0))|0]|0)!=15){b[C+24>>1]=s;b[B+24>>1]=c[t+(d[f+(15-(c[o>>2]|0))|0]<<2)>>2]&65535}if((h|0)<14){break}if((a[f+(15-(c[p>>2]|0))|0]|0)!=15){b[C+26>>1]=s;b[B+26>>1]=c[t+(d[f+(15-(c[p>>2]|0))|0]<<2)>>2]&65535}if((h|0)<15){break}if((a[f+(15-(c[q>>2]|0))|0]|0)!=15){b[C+28>>1]=s;b[B+28>>1]=c[t+(d[f+(15-(c[q>>2]|0))|0]<<2)>>2]&65535}if((h|0)<16){break}if((a[f+(15-(c[r>>2]|0))|0]|0)==15){break}b[C+30>>1]=s;b[B+30>>1]=c[t+(d[f+(15-(c[r>>2]|0))|0]<<2)>>2]&65535}}while(0);E=f+(c[j+(e+~D<<2)>>2]|0)|0;if((D|0)<=0){break}B=B-640|0;C=C-640|0;D=D-1|0;f=E}c[2385338]=E;return}function dXm(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;e=c[3528502]|0;f=e-1|0;if((e|0)<=0){return}g=c[2385456]|0;h=g+f|0;if((h|0)<0){return}i=c[3528422]|0;j=c[2385468]|0;k=j>>>0<320;l=c[3528424]|0;m=c[2415164]&65535;n=c[2440386]|0;o=l+4|0;p=l+8|0;q=l+12|0;r=l+16|0;s=l+20|0;t=l+24|0;u=l+28|0;v=c[3528504]|0;w=(v|0)<9;x=(j+8|0)>>>0<320;y=l+32|0;z=(j+9|0)>>>0<320;A=l+36|0;B=(j+10|0)>>>0<320;C=l+40|0;D=(j+11|0)>>>0<320;E=l+44|0;F=(j+12|0)>>>0<320;G=l+48|0;H=(j+13|0)>>>0<320;I=l+52|0;J=(j+14|0)>>>0<320;K=l+56|0;L=(j+15|0)>>>0<320;M=l+60|0;N=f;O=(c[2409606]|0)+((f*320|0)<<1)|0;P=(c[2415150]|0)+(f*640|0)|0;f=h;h=c[2385338]|0;while(1){do{if((f|0)<=223){do{if(k){if((a[h+(15-(c[l>>2]|0))|0]|0)==15){break}b[O>>1]=m;b[P>>1]=c[n+(d[h+(15-(c[l>>2]|0))|0]<<2)>>2]&65535}}while(0);do{if((j+1|0)>>>0<320){if((a[h+(15-(c[o>>2]|0))|0]|0)==15){break}b[O+2>>1]=m;b[P+2>>1]=c[n+(d[h+(15-(c[o>>2]|0))|0]<<2)>>2]&65535}}while(0);do{if((j+2|0)>>>0<320){if((a[h+(15-(c[p>>2]|0))|0]|0)==15){break}b[O+4>>1]=m;b[P+4>>1]=c[n+(d[h+(15-(c[p>>2]|0))|0]<<2)>>2]&65535}}while(0);do{if((j+3|0)>>>0<320){if((a[h+(15-(c[q>>2]|0))|0]|0)==15){break}b[O+6>>1]=m;b[P+6>>1]=c[n+(d[h+(15-(c[q>>2]|0))|0]<<2)>>2]&65535}}while(0);do{if((j+4|0)>>>0<320){if((a[h+(15-(c[r>>2]|0))|0]|0)==15){break}b[O+8>>1]=m;b[P+8>>1]=c[n+(d[h+(15-(c[r>>2]|0))|0]<<2)>>2]&65535}}while(0);do{if((j+5|0)>>>0<320){if((a[h+(15-(c[s>>2]|0))|0]|0)==15){break}b[O+10>>1]=m;b[P+10>>1]=c[n+(d[h+(15-(c[s>>2]|0))|0]<<2)>>2]&65535}}while(0);do{if((j+6|0)>>>0<320){if((a[h+(15-(c[t>>2]|0))|0]|0)==15){break}b[O+12>>1]=m;b[P+12>>1]=c[n+(d[h+(15-(c[t>>2]|0))|0]<<2)>>2]&65535}}while(0);do{if((j+7|0)>>>0<320){if((a[h+(15-(c[u>>2]|0))|0]|0)==15){break}b[O+14>>1]=m;b[P+14>>1]=c[n+(d[h+(15-(c[u>>2]|0))|0]<<2)>>2]&65535}}while(0);if(w){break}do{if(x){if((a[h+(15-(c[y>>2]|0))|0]|0)==15){break}b[O+16>>1]=m;b[P+16>>1]=c[n+(d[h+(15-(c[y>>2]|0))|0]<<2)>>2]&65535}}while(0);if((v|0)<10){break}do{if(z){if((a[h+(15-(c[A>>2]|0))|0]|0)==15){break}b[O+18>>1]=m;b[P+18>>1]=c[n+(d[h+(15-(c[A>>2]|0))|0]<<2)>>2]&65535}}while(0);if((v|0)<11){break}do{if(B){if((a[h+(15-(c[C>>2]|0))|0]|0)==15){break}b[O+20>>1]=m;b[P+20>>1]=c[n+(d[h+(15-(c[C>>2]|0))|0]<<2)>>2]&65535}}while(0);if((v|0)<12){break}do{if(D){if((a[h+(15-(c[E>>2]|0))|0]|0)==15){break}b[O+22>>1]=m;b[P+22>>1]=c[n+(d[h+(15-(c[E>>2]|0))|0]<<2)>>2]&65535}}while(0);if((v|0)<13){break}do{if(F){if((a[h+(15-(c[G>>2]|0))|0]|0)==15){break}b[O+24>>1]=m;b[P+24>>1]=c[n+(d[h+(15-(c[G>>2]|0))|0]<<2)>>2]&65535}}while(0);if((v|0)<14){break}do{if(H){if((a[h+(15-(c[I>>2]|0))|0]|0)==15){break}b[O+26>>1]=m;b[P+26>>1]=c[n+(d[h+(15-(c[I>>2]|0))|0]<<2)>>2]&65535}}while(0);if((v|0)<15){break}do{if(J){if((a[h+(15-(c[K>>2]|0))|0]|0)==15){break}b[O+28>>1]=m;b[P+28>>1]=c[n+(d[h+(15-(c[K>>2]|0))|0]<<2)>>2]&65535}}while(0);if((v|0)<16|L^1){break}if((a[h+(15-(c[M>>2]|0))|0]|0)==15){break}b[O+30>>1]=m;b[P+30>>1]=c[n+(d[h+(15-(c[M>>2]|0))|0]<<2)>>2]&65535}}while(0);Q=h+(c[i+(e+~N<<2)>>2]|0)|0;if((N|0)<=0){break}R=N-1|0;S=g+R|0;if((S|0)<0){break}else{N=R;O=O-640|0;P=P-640|0;f=S;h=Q}}c[2385338]=Q;return}function dXn(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;f=c[3528502]|0;g=f-1|0;if((f|0)<=0){return}h=c[3528424]|0;i=c[3528504]|0;j=(i|0)<9;k=c[3528422]|0;l=h+32|0;m=h+36|0;n=h+40|0;o=h+44|0;p=h+48|0;q=h+52|0;r=h+56|0;s=h+60|0;t=c[2415164]|0;u=t&65535;v=c[2440386]|0;w=h+28|0;x=h+24|0;y=h+20|0;z=h+16|0;A=h+12|0;B=h+8|0;C=h+4|0;D=(c[2415150]|0)+(g*640|0)|0;E=(c[2409606]|0)+((g*320|0)<<1)|0;F=g;g=c[2385338]|0;while(1){do{if((a[g+(15-(c[h>>2]|0))|0]|0)==15){G=g}else{if((e[E>>1]|0)>(t|0)){G=g;break}b[E>>1]=u;b[D>>1]=c[v+(d[g+(15-(c[h>>2]|0))|0]<<2)>>2]&65535;G=g}}while(0);do{if((a[G+(15-(c[C>>2]|0))|0]|0)==15){H=G}else{I=E+2|0;if((e[I>>1]|0)>(t|0)){H=G;break}b[I>>1]=u;b[D+2>>1]=c[v+(d[g+(15-(c[C>>2]|0))|0]<<2)>>2]&65535;H=g}}while(0);do{if((a[H+(15-(c[B>>2]|0))|0]|0)==15){J=H}else{I=E+4|0;if((e[I>>1]|0)>(t|0)){J=H;break}b[I>>1]=u;b[D+4>>1]=c[v+(d[g+(15-(c[B>>2]|0))|0]<<2)>>2]&65535;J=g}}while(0);do{if((a[J+(15-(c[A>>2]|0))|0]|0)==15){K=J}else{I=E+6|0;if((e[I>>1]|0)>(t|0)){K=J;break}b[I>>1]=u;b[D+6>>1]=c[v+(d[g+(15-(c[A>>2]|0))|0]<<2)>>2]&65535;K=g}}while(0);do{if((a[K+(15-(c[z>>2]|0))|0]|0)==15){L=K}else{I=E+8|0;if((e[I>>1]|0)>(t|0)){L=K;break}b[I>>1]=u;b[D+8>>1]=c[v+(d[g+(15-(c[z>>2]|0))|0]<<2)>>2]&65535;L=g}}while(0);do{if((a[L+(15-(c[y>>2]|0))|0]|0)==15){M=L}else{I=E+10|0;if((e[I>>1]|0)>(t|0)){M=L;break}b[I>>1]=u;b[D+10>>1]=c[v+(d[g+(15-(c[y>>2]|0))|0]<<2)>>2]&65535;M=g}}while(0);do{if((a[M+(15-(c[x>>2]|0))|0]|0)==15){N=M}else{I=E+12|0;if((e[I>>1]|0)>(t|0)){N=M;break}b[I>>1]=u;b[D+12>>1]=c[v+(d[g+(15-(c[x>>2]|0))|0]<<2)>>2]&65535;N=g}}while(0);do{if((a[N+(15-(c[w>>2]|0))|0]|0)!=15){I=E+14|0;if((e[I>>1]|0)>(t|0)){break}b[I>>1]=u;b[D+14>>1]=c[v+(d[g+(15-(c[w>>2]|0))|0]<<2)>>2]&65535}}while(0);do{if(!j){do{if((a[g+(15-(c[l>>2]|0))|0]|0)!=15){I=E+16|0;if((e[I>>1]|0)>(t|0)){break}b[I>>1]=u;b[D+16>>1]=c[v+(d[g+(15-(c[l>>2]|0))|0]<<2)>>2]&65535}}while(0);if((i|0)<10){break}do{if((a[g+(15-(c[m>>2]|0))|0]|0)!=15){I=E+18|0;if((e[I>>1]|0)>(t|0)){break}b[I>>1]=u;b[D+18>>1]=c[v+(d[g+(15-(c[m>>2]|0))|0]<<2)>>2]&65535}}while(0);if((i|0)<11){break}do{if((a[g+(15-(c[n>>2]|0))|0]|0)!=15){I=E+20|0;if((e[I>>1]|0)>(t|0)){break}b[I>>1]=u;b[D+20>>1]=c[v+(d[g+(15-(c[n>>2]|0))|0]<<2)>>2]&65535}}while(0);if((i|0)<12){break}do{if((a[g+(15-(c[o>>2]|0))|0]|0)!=15){I=E+22|0;if((e[I>>1]|0)>(t|0)){break}b[I>>1]=u;b[D+22>>1]=c[v+(d[g+(15-(c[o>>2]|0))|0]<<2)>>2]&65535}}while(0);if((i|0)<13){break}do{if((a[g+(15-(c[p>>2]|0))|0]|0)!=15){I=E+24|0;if((e[I>>1]|0)>(t|0)){break}b[I>>1]=u;b[D+24>>1]=c[v+(d[g+(15-(c[p>>2]|0))|0]<<2)>>2]&65535}}while(0);if((i|0)<14){break}do{if((a[g+(15-(c[q>>2]|0))|0]|0)!=15){I=E+26|0;if((e[I>>1]|0)>(t|0)){break}b[I>>1]=u;b[D+26>>1]=c[v+(d[g+(15-(c[q>>2]|0))|0]<<2)>>2]&65535}}while(0);if((i|0)<15){break}do{if((a[g+(15-(c[r>>2]|0))|0]|0)!=15){I=E+28|0;if((e[I>>1]|0)>(t|0)){break}b[I>>1]=u;b[D+28>>1]=c[v+(d[g+(15-(c[r>>2]|0))|0]<<2)>>2]&65535}}while(0);if((i|0)<16){break}if((a[g+(15-(c[s>>2]|0))|0]|0)==15){break}I=E+30|0;if((e[I>>1]|0)>(t|0)){break}b[I>>1]=u;b[D+30>>1]=c[v+(d[g+(15-(c[s>>2]|0))|0]<<2)>>2]&65535}}while(0);O=g+(c[k+(f+~F<<2)>>2]|0)|0;if((F|0)<=0){break}D=D-640|0;E=E-640|0;F=F-1|0;g=O}c[2385338]=O;return}function dXo(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;f=c[3528502]|0;g=f-1|0;if((f|0)<=0){return}h=c[2385456]|0;i=h+g|0;if((i|0)<0){return}j=c[3528422]|0;k=c[2385468]|0;l=k>>>0<320;m=c[3528424]|0;n=c[2415164]|0;o=n&65535;p=c[2440386]|0;q=m+4|0;r=m+8|0;s=m+12|0;t=m+16|0;u=m+20|0;v=m+24|0;w=m+28|0;x=c[3528504]|0;y=(x|0)<9;z=(k+8|0)>>>0<320;A=m+32|0;B=(k+9|0)>>>0<320;C=m+36|0;D=(k+10|0)>>>0<320;E=m+40|0;F=(k+11|0)>>>0<320;G=m+44|0;H=(k+12|0)>>>0<320;I=m+48|0;J=(k+13|0)>>>0<320;K=m+52|0;L=(k+14|0)>>>0<320;M=m+56|0;N=(k+15|0)>>>0<320;O=m+60|0;P=g;Q=(c[2409606]|0)+((g*320|0)<<1)|0;R=(c[2415150]|0)+(g*640|0)|0;g=i;i=c[2385338]|0;while(1){do{if((g|0)<=223){do{if(l){if((a[i+(15-(c[m>>2]|0))|0]|0)==15){break}if((e[Q>>1]|0)>(n|0)){break}b[Q>>1]=o;b[R>>1]=c[p+(d[i+(15-(c[m>>2]|0))|0]<<2)>>2]&65535}}while(0);do{if((k+1|0)>>>0<320){if((a[i+(15-(c[q>>2]|0))|0]|0)==15){break}S=Q+2|0;if((e[S>>1]|0)>(n|0)){break}b[S>>1]=o;b[R+2>>1]=c[p+(d[i+(15-(c[q>>2]|0))|0]<<2)>>2]&65535}}while(0);do{if((k+2|0)>>>0<320){if((a[i+(15-(c[r>>2]|0))|0]|0)==15){break}S=Q+4|0;if((e[S>>1]|0)>(n|0)){break}b[S>>1]=o;b[R+4>>1]=c[p+(d[i+(15-(c[r>>2]|0))|0]<<2)>>2]&65535}}while(0);do{if((k+3|0)>>>0<320){if((a[i+(15-(c[s>>2]|0))|0]|0)==15){break}S=Q+6|0;if((e[S>>1]|0)>(n|0)){break}b[S>>1]=o;b[R+6>>1]=c[p+(d[i+(15-(c[s>>2]|0))|0]<<2)>>2]&65535}}while(0);do{if((k+4|0)>>>0<320){if((a[i+(15-(c[t>>2]|0))|0]|0)==15){break}S=Q+8|0;if((e[S>>1]|0)>(n|0)){break}b[S>>1]=o;b[R+8>>1]=c[p+(d[i+(15-(c[t>>2]|0))|0]<<2)>>2]&65535}}while(0);do{if((k+5|0)>>>0<320){if((a[i+(15-(c[u>>2]|0))|0]|0)==15){break}S=Q+10|0;if((e[S>>1]|0)>(n|0)){break}b[S>>1]=o;b[R+10>>1]=c[p+(d[i+(15-(c[u>>2]|0))|0]<<2)>>2]&65535}}while(0);do{if((k+6|0)>>>0<320){if((a[i+(15-(c[v>>2]|0))|0]|0)==15){break}S=Q+12|0;if((e[S>>1]|0)>(n|0)){break}b[S>>1]=o;b[R+12>>1]=c[p+(d[i+(15-(c[v>>2]|0))|0]<<2)>>2]&65535}}while(0);do{if((k+7|0)>>>0<320){if((a[i+(15-(c[w>>2]|0))|0]|0)==15){break}S=Q+14|0;if((e[S>>1]|0)>(n|0)){break}b[S>>1]=o;b[R+14>>1]=c[p+(d[i+(15-(c[w>>2]|0))|0]<<2)>>2]&65535}}while(0);if(y){break}do{if(z){if((a[i+(15-(c[A>>2]|0))|0]|0)==15){break}S=Q+16|0;if((e[S>>1]|0)>(n|0)){break}b[S>>1]=o;b[R+16>>1]=c[p+(d[i+(15-(c[A>>2]|0))|0]<<2)>>2]&65535}}while(0);if((x|0)<10){break}do{if(B){if((a[i+(15-(c[C>>2]|0))|0]|0)==15){break}S=Q+18|0;if((e[S>>1]|0)>(n|0)){break}b[S>>1]=o;b[R+18>>1]=c[p+(d[i+(15-(c[C>>2]|0))|0]<<2)>>2]&65535}}while(0);if((x|0)<11){break}do{if(D){if((a[i+(15-(c[E>>2]|0))|0]|0)==15){break}S=Q+20|0;if((e[S>>1]|0)>(n|0)){break}b[S>>1]=o;b[R+20>>1]=c[p+(d[i+(15-(c[E>>2]|0))|0]<<2)>>2]&65535}}while(0);if((x|0)<12){break}do{if(F){if((a[i+(15-(c[G>>2]|0))|0]|0)==15){break}S=Q+22|0;if((e[S>>1]|0)>(n|0)){break}b[S>>1]=o;b[R+22>>1]=c[p+(d[i+(15-(c[G>>2]|0))|0]<<2)>>2]&65535}}while(0);if((x|0)<13){break}do{if(H){if((a[i+(15-(c[I>>2]|0))|0]|0)==15){break}S=Q+24|0;if((e[S>>1]|0)>(n|0)){break}b[S>>1]=o;b[R+24>>1]=c[p+(d[i+(15-(c[I>>2]|0))|0]<<2)>>2]&65535}}while(0);if((x|0)<14){break}do{if(J){if((a[i+(15-(c[K>>2]|0))|0]|0)==15){break}S=Q+26|0;if((e[S>>1]|0)>(n|0)){break}b[S>>1]=o;b[R+26>>1]=c[p+(d[i+(15-(c[K>>2]|0))|0]<<2)>>2]&65535}}while(0);if((x|0)<15){break}do{if(L){if((a[i+(15-(c[M>>2]|0))|0]|0)==15){break}S=Q+28|0;if((e[S>>1]|0)>(n|0)){break}b[S>>1]=o;b[R+28>>1]=c[p+(d[i+(15-(c[M>>2]|0))|0]<<2)>>2]&65535}}while(0);if((x|0)<16|N^1){break}if((a[i+(15-(c[O>>2]|0))|0]|0)==15){break}S=Q+30|0;if((e[S>>1]|0)>(n|0)){break}b[S>>1]=o;b[R+30>>1]=c[p+(d[i+(15-(c[O>>2]|0))|0]<<2)>>2]&65535}}while(0);T=i+(c[j+(f+~P<<2)>>2]|0)|0;if((P|0)<=0){break}S=P-1|0;U=h+S|0;if((U|0)<0){break}else{P=S;Q=Q-640|0;R=R-640|0;g=U;i=T}}c[2385338]=T;return}function dXp(){var d=0,e=0,f=0,g=0,h=0,i=0;d=c[2440386]|0;e=c[2415150]|0;f=0;g=c[2385338]|0;while(1){h=a[g]|0;if(h<<24>>24!=0){b[e>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+1|0]|0;if(h<<24>>24!=0){b[e+2>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+2|0]|0;if(h<<24>>24!=0){b[e+4>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+3|0]|0;if(h<<24>>24!=0){b[e+6>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+4|0]|0;if(h<<24>>24!=0){b[e+8>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+5|0]|0;if(h<<24>>24!=0){b[e+10>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+6|0]|0;if(h<<24>>24!=0){b[e+12>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+7|0]|0;if(h<<24>>24!=0){b[e+14>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+8|0]|0;if(h<<24>>24!=0){b[e+16>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+9|0]|0;if(h<<24>>24!=0){b[e+18>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+10|0]|0;if(h<<24>>24!=0){b[e+20>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+11|0]|0;if(h<<24>>24!=0){b[e+22>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+12|0]|0;if(h<<24>>24!=0){b[e+24>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+13|0]|0;if(h<<24>>24!=0){b[e+26>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+14|0]|0;if(h<<24>>24!=0){b[e+28>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+15|0]|0;if(h<<24>>24!=0){b[e+30>>1]=c[d+((h&255)<<2)>>2]&65535}h=f+1|0;i=g+16|0;if((h|0)<16){e=e+640|0;f=h;g=i}else{break}}c[2385338]=i;return}function dXq(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[2385456]|0;e=c[2385468]|0;f=e>>>0<320;g=c[2440386]|0;h=c[2415150]|0;i=0;L40715:while(1){j=d+i|0;do{if((j|0)>=0){if((j|0)>223){k=30867;break L40715}do{if(f){l=a[c[2385338]|0]|0;if(l<<24>>24==0){break}b[h>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+1|0)>>>0<320){l=a[(c[2385338]|0)+1|0]|0;if(l<<24>>24==0){break}b[h+2>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+2|0)>>>0<320){l=a[(c[2385338]|0)+2|0]|0;if(l<<24>>24==0){break}b[h+4>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+3|0)>>>0<320){l=a[(c[2385338]|0)+3|0]|0;if(l<<24>>24==0){break}b[h+6>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+4|0)>>>0<320){l=a[(c[2385338]|0)+4|0]|0;if(l<<24>>24==0){break}b[h+8>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+5|0)>>>0<320){l=a[(c[2385338]|0)+5|0]|0;if(l<<24>>24==0){break}b[h+10>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+6|0)>>>0<320){l=a[(c[2385338]|0)+6|0]|0;if(l<<24>>24==0){break}b[h+12>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+7|0)>>>0<320){l=a[(c[2385338]|0)+7|0]|0;if(l<<24>>24==0){break}b[h+14>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+8|0)>>>0<320){l=a[(c[2385338]|0)+8|0]|0;if(l<<24>>24==0){break}b[h+16>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+9|0)>>>0<320){l=a[(c[2385338]|0)+9|0]|0;if(l<<24>>24==0){break}b[h+18>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+10|0)>>>0<320){l=a[(c[2385338]|0)+10|0]|0;if(l<<24>>24==0){break}b[h+20>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+11|0)>>>0<320){l=a[(c[2385338]|0)+11|0]|0;if(l<<24>>24==0){break}b[h+22>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+12|0)>>>0<320){l=a[(c[2385338]|0)+12|0]|0;if(l<<24>>24==0){break}b[h+24>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+13|0)>>>0<320){l=a[(c[2385338]|0)+13|0]|0;if(l<<24>>24==0){break}b[h+26>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+14|0)>>>0<320){l=a[(c[2385338]|0)+14|0]|0;if(l<<24>>24==0){break}b[h+28>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);if((e+15|0)>>>0>=320){break}l=a[(c[2385338]|0)+15|0]|0;if(l<<24>>24==0){break}b[h+30>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);j=i+1|0;c[2385338]=(c[2385338]|0)+16;if((j|0)>=16){k=30868;break}h=h+640|0;i=j}if((k|0)==30868){return}else if((k|0)==30867){return}}function dXr(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;d=c[2415164]|0;f=c[2440386]|0;g=c[2415150]|0;h=c[2409606]|0;i=0;j=c[2385338]|0;while(1){k=a[j]|0;l=k&255;do{if(k<<24>>24==0){m=j}else{if((e[h>>1]|0|0)>(d|0)){m=j;break}b[g>>1]=c[f+(l<<2)>>2]&65535;m=j}}while(0);l=a[m+1|0]|0;k=l&255;do{if(l<<24>>24==0){n=m}else{if((e[h+2>>1]|0|0)>(d|0)){n=m;break}b[g+2>>1]=c[f+(k<<2)>>2]&65535;n=j}}while(0);k=a[n+2|0]|0;l=k&255;do{if(k<<24>>24==0){o=n}else{if((e[h+4>>1]|0|0)>(d|0)){o=n;break}b[g+4>>1]=c[f+(l<<2)>>2]&65535;o=j}}while(0);l=a[o+3|0]|0;k=l&255;do{if(l<<24>>24==0){p=o}else{if((e[h+6>>1]|0|0)>(d|0)){p=o;break}b[g+6>>1]=c[f+(k<<2)>>2]&65535;p=j}}while(0);k=a[p+4|0]|0;l=k&255;do{if(k<<24>>24==0){q=p}else{if((e[h+8>>1]|0|0)>(d|0)){q=p;break}b[g+8>>1]=c[f+(l<<2)>>2]&65535;q=j}}while(0);l=a[q+5|0]|0;k=l&255;do{if(l<<24>>24==0){r=q}else{if((e[h+10>>1]|0|0)>(d|0)){r=q;break}b[g+10>>1]=c[f+(k<<2)>>2]&65535;r=j}}while(0);k=a[r+6|0]|0;l=k&255;do{if(k<<24>>24==0){s=r}else{if((e[h+12>>1]|0|0)>(d|0)){s=r;break}b[g+12>>1]=c[f+(l<<2)>>2]&65535;s=j}}while(0);l=a[s+7|0]|0;k=l&255;do{if(l<<24>>24==0){t=s}else{if((e[h+14>>1]|0|0)>(d|0)){t=s;break}b[g+14>>1]=c[f+(k<<2)>>2]&65535;t=j}}while(0);k=a[t+8|0]|0;l=k&255;do{if(k<<24>>24==0){u=t}else{if((e[h+16>>1]|0|0)>(d|0)){u=t;break}b[g+16>>1]=c[f+(l<<2)>>2]&65535;u=j}}while(0);l=a[u+9|0]|0;k=l&255;do{if(l<<24>>24==0){v=u}else{if((e[h+18>>1]|0|0)>(d|0)){v=u;break}b[g+18>>1]=c[f+(k<<2)>>2]&65535;v=j}}while(0);k=a[v+10|0]|0;l=k&255;do{if(k<<24>>24==0){w=v}else{if((e[h+20>>1]|0|0)>(d|0)){w=v;break}b[g+20>>1]=c[f+(l<<2)>>2]&65535;w=j}}while(0);l=a[w+11|0]|0;k=l&255;do{if(l<<24>>24==0){x=w}else{if((e[h+22>>1]|0|0)>(d|0)){x=w;break}b[g+22>>1]=c[f+(k<<2)>>2]&65535;x=j}}while(0);k=a[x+12|0]|0;l=k&255;do{if(k<<24>>24==0){y=x}else{if((e[h+24>>1]|0|0)>(d|0)){y=x;break}b[g+24>>1]=c[f+(l<<2)>>2]&65535;y=j}}while(0);l=a[y+13|0]|0;k=l&255;do{if(l<<24>>24==0){z=y}else{if((e[h+26>>1]|0|0)>(d|0)){z=y;break}b[g+26>>1]=c[f+(k<<2)>>2]&65535;z=j}}while(0);k=a[z+14|0]|0;l=k&255;do{if(k<<24>>24==0){A=z}else{if((e[h+28>>1]|0|0)>(d|0)){A=z;break}b[g+28>>1]=c[f+(l<<2)>>2]&65535;A=j}}while(0);l=a[A+15|0]|0;k=l&255;do{if(l<<24>>24==0){B=A}else{if((e[h+30>>1]|0|0)>(d|0)){B=A;break}b[g+30>>1]=c[f+(k<<2)>>2]&65535;B=j}}while(0);k=i+1|0;C=B+16|0;if((k|0)<16){g=g+640|0;h=h+640|0;i=k;j=C}else{break}}c[2385338]=C;return}function dXs(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=c[2385456]|0;f=c[2385468]|0;g=f>>>0<320;h=c[2415164]|0;i=c[2440386]|0;j=c[2415150]|0;k=c[2409606]|0;l=0;L40856:while(1){m=d+l|0;do{if((m|0)>=0){if((m|0)>223){n=30990;break L40856}do{if(g){o=a[c[2385338]|0]|0;if(o<<24>>24==0){break}if((e[k>>1]|0|0)>(h|0)){break}b[j>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);do{if((f+1|0)>>>0<320){o=a[(c[2385338]|0)+1|0]|0;if(o<<24>>24==0){break}if((e[k+2>>1]|0|0)>(h|0)){break}b[j+2>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);do{if((f+2|0)>>>0<320){o=a[(c[2385338]|0)+2|0]|0;if(o<<24>>24==0){break}if((e[k+4>>1]|0|0)>(h|0)){break}b[j+4>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);do{if((f+3|0)>>>0<320){o=a[(c[2385338]|0)+3|0]|0;if(o<<24>>24==0){break}if((e[k+6>>1]|0|0)>(h|0)){break}b[j+6>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);do{if((f+4|0)>>>0<320){o=a[(c[2385338]|0)+4|0]|0;if(o<<24>>24==0){break}if((e[k+8>>1]|0|0)>(h|0)){break}b[j+8>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);do{if((f+5|0)>>>0<320){o=a[(c[2385338]|0)+5|0]|0;if(o<<24>>24==0){break}if((e[k+10>>1]|0|0)>(h|0)){break}b[j+10>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);do{if((f+6|0)>>>0<320){o=a[(c[2385338]|0)+6|0]|0;if(o<<24>>24==0){break}if((e[k+12>>1]|0|0)>(h|0)){break}b[j+12>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);do{if((f+7|0)>>>0<320){o=a[(c[2385338]|0)+7|0]|0;if(o<<24>>24==0){break}if((e[k+14>>1]|0|0)>(h|0)){break}b[j+14>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);do{if((f+8|0)>>>0<320){o=a[(c[2385338]|0)+8|0]|0;if(o<<24>>24==0){break}if((e[k+16>>1]|0|0)>(h|0)){break}b[j+16>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);do{if((f+9|0)>>>0<320){o=a[(c[2385338]|0)+9|0]|0;if(o<<24>>24==0){break}if((e[k+18>>1]|0|0)>(h|0)){break}b[j+18>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);do{if((f+10|0)>>>0<320){o=a[(c[2385338]|0)+10|0]|0;if(o<<24>>24==0){break}if((e[k+20>>1]|0|0)>(h|0)){break}b[j+20>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);do{if((f+11|0)>>>0<320){o=a[(c[2385338]|0)+11|0]|0;if(o<<24>>24==0){break}if((e[k+22>>1]|0|0)>(h|0)){break}b[j+22>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);do{if((f+12|0)>>>0<320){o=a[(c[2385338]|0)+12|0]|0;if(o<<24>>24==0){break}if((e[k+24>>1]|0|0)>(h|0)){break}b[j+24>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);do{if((f+13|0)>>>0<320){o=a[(c[2385338]|0)+13|0]|0;if(o<<24>>24==0){break}if((e[k+26>>1]|0|0)>(h|0)){break}b[j+26>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);do{if((f+14|0)>>>0<320){o=a[(c[2385338]|0)+14|0]|0;if(o<<24>>24==0){break}if((e[k+28>>1]|0|0)>(h|0)){break}b[j+28>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);if((f+15|0)>>>0>=320){break}o=a[(c[2385338]|0)+15|0]|0;if(o<<24>>24==0){break}if((e[k+30>>1]|0|0)>(h|0)){break}b[j+30>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);m=l+1|0;c[2385338]=(c[2385338]|0)+16;if((m|0)>=16){n=30991;break}j=j+640|0;k=k+640|0;l=m}if((n|0)==30990){return}else if((n|0)==30991){return}}function dXt(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=c[2415164]&65535;f=c[2440386]|0;g=c[2415150]|0;h=c[2409606]|0;i=0;j=c[2385338]|0;while(1){if((a[j]|0)!=0){b[h>>1]=e;b[g>>1]=c[f+(d[j]<<2)>>2]&65535}if((a[j+1|0]|0)!=0){b[h+2>>1]=e;b[g+2>>1]=c[f+(d[j+1|0]<<2)>>2]&65535}if((a[j+2|0]|0)!=0){b[h+4>>1]=e;b[g+4>>1]=c[f+(d[j+2|0]<<2)>>2]&65535}if((a[j+3|0]|0)!=0){b[h+6>>1]=e;b[g+6>>1]=c[f+(d[j+3|0]<<2)>>2]&65535}if((a[j+4|0]|0)!=0){b[h+8>>1]=e;b[g+8>>1]=c[f+(d[j+4|0]<<2)>>2]&65535}if((a[j+5|0]|0)!=0){b[h+10>>1]=e;b[g+10>>1]=c[f+(d[j+5|0]<<2)>>2]&65535}if((a[j+6|0]|0)!=0){b[h+12>>1]=e;b[g+12>>1]=c[f+(d[j+6|0]<<2)>>2]&65535}if((a[j+7|0]|0)!=0){b[h+14>>1]=e;b[g+14>>1]=c[f+(d[j+7|0]<<2)>>2]&65535}if((a[j+8|0]|0)!=0){b[h+16>>1]=e;b[g+16>>1]=c[f+(d[j+8|0]<<2)>>2]&65535}if((a[j+9|0]|0)!=0){b[h+18>>1]=e;b[g+18>>1]=c[f+(d[j+9|0]<<2)>>2]&65535}if((a[j+10|0]|0)!=0){b[h+20>>1]=e;b[g+20>>1]=c[f+(d[j+10|0]<<2)>>2]&65535}if((a[j+11|0]|0)!=0){b[h+22>>1]=e;b[g+22>>1]=c[f+(d[j+11|0]<<2)>>2]&65535}if((a[j+12|0]|0)!=0){b[h+24>>1]=e;b[g+24>>1]=c[f+(d[j+12|0]<<2)>>2]&65535}if((a[j+13|0]|0)!=0){b[h+26>>1]=e;b[g+26>>1]=c[f+(d[j+13|0]<<2)>>2]&65535}if((a[j+14|0]|0)!=0){b[h+28>>1]=e;b[g+28>>1]=c[f+(d[j+14|0]<<2)>>2]&65535}if((a[j+15|0]|0)!=0){b[h+30>>1]=e;b[g+30>>1]=c[f+(d[j+15|0]<<2)>>2]&65535}k=i+1|0;l=j+16|0;if((k|0)<16){g=g+640|0;h=h+640|0;i=k;j=l}else{break}}c[2385338]=l;return}function dXu(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=c[2385456]|0;f=c[2385468]|0;g=f>>>0<320;h=c[2415164]&65535;i=c[2440386]|0;j=c[2415150]|0;k=c[2409606]|0;l=0;L40997:while(1){m=e+l|0;do{if((m|0)>=0){if((m|0)>223){n=31081;break L40997}do{if(g){o=c[2385338]|0;if((a[o]|0)==0){break}b[k>>1]=h;b[j>>1]=c[i+(d[o]<<2)>>2]&65535}}while(0);do{if((f+1|0)>>>0<320){o=(c[2385338]|0)+1|0;if((a[o]|0)==0){break}b[k+2>>1]=h;b[j+2>>1]=c[i+(d[o]<<2)>>2]&65535}}while(0);do{if((f+2|0)>>>0<320){o=(c[2385338]|0)+2|0;if((a[o]|0)==0){break}b[k+4>>1]=h;b[j+4>>1]=c[i+(d[o]<<2)>>2]&65535}}while(0);do{if((f+3|0)>>>0<320){o=(c[2385338]|0)+3|0;if((a[o]|0)==0){break}b[k+6>>1]=h;b[j+6>>1]=c[i+(d[o]<<2)>>2]&65535}}while(0);do{if((f+4|0)>>>0<320){o=(c[2385338]|0)+4|0;if((a[o]|0)==0){break}b[k+8>>1]=h;b[j+8>>1]=c[i+(d[o]<<2)>>2]&65535}}while(0);do{if((f+5|0)>>>0<320){o=(c[2385338]|0)+5|0;if((a[o]|0)==0){break}b[k+10>>1]=h;b[j+10>>1]=c[i+(d[o]<<2)>>2]&65535}}while(0);do{if((f+6|0)>>>0<320){o=(c[2385338]|0)+6|0;if((a[o]|0)==0){break}b[k+12>>1]=h;b[j+12>>1]=c[i+(d[o]<<2)>>2]&65535}}while(0);do{if((f+7|0)>>>0<320){o=(c[2385338]|0)+7|0;if((a[o]|0)==0){break}b[k+14>>1]=h;b[j+14>>1]=c[i+(d[o]<<2)>>2]&65535}}while(0);do{if((f+8|0)>>>0<320){o=(c[2385338]|0)+8|0;if((a[o]|0)==0){break}b[k+16>>1]=h;b[j+16>>1]=c[i+(d[o]<<2)>>2]&65535}}while(0);do{if((f+9|0)>>>0<320){o=(c[2385338]|0)+9|0;if((a[o]|0)==0){break}b[k+18>>1]=h;b[j+18>>1]=c[i+(d[o]<<2)>>2]&65535}}while(0);do{if((f+10|0)>>>0<320){o=(c[2385338]|0)+10|0;if((a[o]|0)==0){break}b[k+20>>1]=h;b[j+20>>1]=c[i+(d[o]<<2)>>2]&65535}}while(0);do{if((f+11|0)>>>0<320){o=(c[2385338]|0)+11|0;if((a[o]|0)==0){break}b[k+22>>1]=h;b[j+22>>1]=c[i+(d[o]<<2)>>2]&65535}}while(0);do{if((f+12|0)>>>0<320){o=(c[2385338]|0)+12|0;if((a[o]|0)==0){break}b[k+24>>1]=h;b[j+24>>1]=c[i+(d[o]<<2)>>2]&65535}}while(0);do{if((f+13|0)>>>0<320){o=(c[2385338]|0)+13|0;if((a[o]|0)==0){break}b[k+26>>1]=h;b[j+26>>1]=c[i+(d[o]<<2)>>2]&65535}}while(0);do{if((f+14|0)>>>0<320){o=(c[2385338]|0)+14|0;if((a[o]|0)==0){break}b[k+28>>1]=h;b[j+28>>1]=c[i+(d[o]<<2)>>2]&65535}}while(0);if((f+15|0)>>>0>=320){break}o=(c[2385338]|0)+15|0;if((a[o]|0)==0){break}b[k+30>>1]=h;b[j+30>>1]=c[i+(d[o]<<2)>>2]&65535}}while(0);m=l+1|0;c[2385338]=(c[2385338]|0)+16;if((m|0)>=16){n=31082;break}j=j+640|0;k=k+640|0;l=m}if((n|0)==31081){return}else if((n|0)==31082){return}}function dXv(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;f=c[2415164]|0;g=f&65535;h=c[2440386]|0;i=c[2415150]|0;j=c[2409606]|0;k=0;l=c[2385338]|0;while(1){do{if((a[l]|0)==0){m=l}else{if((e[j>>1]|0)>(f|0)){m=l;break}b[j>>1]=g;b[i>>1]=c[h+(d[l]<<2)>>2]&65535;m=l}}while(0);do{if((a[m+1|0]|0)==0){n=m}else{o=j+2|0;if((e[o>>1]|0)>(f|0)){n=m;break}b[o>>1]=g;b[i+2>>1]=c[h+(d[l+1|0]<<2)>>2]&65535;n=l}}while(0);do{if((a[n+2|0]|0)==0){p=n}else{o=j+4|0;if((e[o>>1]|0)>(f|0)){p=n;break}b[o>>1]=g;b[i+4>>1]=c[h+(d[l+2|0]<<2)>>2]&65535;p=l}}while(0);do{if((a[p+3|0]|0)==0){q=p}else{o=j+6|0;if((e[o>>1]|0)>(f|0)){q=p;break}b[o>>1]=g;b[i+6>>1]=c[h+(d[l+3|0]<<2)>>2]&65535;q=l}}while(0);do{if((a[q+4|0]|0)==0){r=q}else{o=j+8|0;if((e[o>>1]|0)>(f|0)){r=q;break}b[o>>1]=g;b[i+8>>1]=c[h+(d[l+4|0]<<2)>>2]&65535;r=l}}while(0);do{if((a[r+5|0]|0)==0){s=r}else{o=j+10|0;if((e[o>>1]|0)>(f|0)){s=r;break}b[o>>1]=g;b[i+10>>1]=c[h+(d[l+5|0]<<2)>>2]&65535;s=l}}while(0);do{if((a[s+6|0]|0)==0){t=s}else{o=j+12|0;if((e[o>>1]|0)>(f|0)){t=s;break}b[o>>1]=g;b[i+12>>1]=c[h+(d[l+6|0]<<2)>>2]&65535;t=l}}while(0);do{if((a[t+7|0]|0)==0){u=t}else{o=j+14|0;if((e[o>>1]|0)>(f|0)){u=t;break}b[o>>1]=g;b[i+14>>1]=c[h+(d[l+7|0]<<2)>>2]&65535;u=l}}while(0);do{if((a[u+8|0]|0)==0){v=u}else{o=j+16|0;if((e[o>>1]|0)>(f|0)){v=u;break}b[o>>1]=g;b[i+16>>1]=c[h+(d[l+8|0]<<2)>>2]&65535;v=l}}while(0);do{if((a[v+9|0]|0)==0){w=v}else{o=j+18|0;if((e[o>>1]|0)>(f|0)){w=v;break}b[o>>1]=g;b[i+18>>1]=c[h+(d[l+9|0]<<2)>>2]&65535;w=l}}while(0);do{if((a[w+10|0]|0)==0){x=w}else{o=j+20|0;if((e[o>>1]|0)>(f|0)){x=w;break}b[o>>1]=g;b[i+20>>1]=c[h+(d[l+10|0]<<2)>>2]&65535;x=l}}while(0);do{if((a[x+11|0]|0)==0){y=x}else{o=j+22|0;if((e[o>>1]|0)>(f|0)){y=x;break}b[o>>1]=g;b[i+22>>1]=c[h+(d[l+11|0]<<2)>>2]&65535;y=l}}while(0);do{if((a[y+12|0]|0)==0){z=y}else{o=j+24|0;if((e[o>>1]|0)>(f|0)){z=y;break}b[o>>1]=g;b[i+24>>1]=c[h+(d[l+12|0]<<2)>>2]&65535;z=l}}while(0);do{if((a[z+13|0]|0)==0){A=z}else{o=j+26|0;if((e[o>>1]|0)>(f|0)){A=z;break}b[o>>1]=g;b[i+26>>1]=c[h+(d[l+13|0]<<2)>>2]&65535;A=l}}while(0);do{if((a[A+14|0]|0)==0){B=A}else{o=j+28|0;if((e[o>>1]|0)>(f|0)){B=A;break}b[o>>1]=g;b[i+28>>1]=c[h+(d[l+14|0]<<2)>>2]&65535;B=l}}while(0);do{if((a[B+15|0]|0)==0){C=B}else{o=j+30|0;if((e[o>>1]|0)>(f|0)){C=B;break}b[o>>1]=g;b[i+30>>1]=c[h+(d[l+15|0]<<2)>>2]&65535;C=l}}while(0);o=k+1|0;D=C+16|0;if((o|0)<16){i=i+640|0;j=j+640|0;k=o;l=D}else{break}}c[2385338]=D;return}function dXw(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=c[2385456]|0;g=c[2385468]|0;h=g>>>0<320;i=c[2415164]|0;j=i&65535;k=c[2440386]|0;l=c[2415150]|0;m=c[2409606]|0;n=0;L41138:while(1){o=f+n|0;do{if((o|0)>=0){if((o|0)>223){p=31204;break L41138}do{if(h){q=c[2385338]|0;if((a[q]|0)==0){break}if((e[m>>1]|0)>(i|0)){break}b[m>>1]=j;b[l>>1]=c[k+(d[q]<<2)>>2]&65535}}while(0);do{if((g+1|0)>>>0<320){q=(c[2385338]|0)+1|0;if((a[q]|0)==0){break}r=m+2|0;if((e[r>>1]|0)>(i|0)){break}b[r>>1]=j;b[l+2>>1]=c[k+(d[q]<<2)>>2]&65535}}while(0);do{if((g+2|0)>>>0<320){q=(c[2385338]|0)+2|0;if((a[q]|0)==0){break}r=m+4|0;if((e[r>>1]|0)>(i|0)){break}b[r>>1]=j;b[l+4>>1]=c[k+(d[q]<<2)>>2]&65535}}while(0);do{if((g+3|0)>>>0<320){q=(c[2385338]|0)+3|0;if((a[q]|0)==0){break}r=m+6|0;if((e[r>>1]|0)>(i|0)){break}b[r>>1]=j;b[l+6>>1]=c[k+(d[q]<<2)>>2]&65535}}while(0);do{if((g+4|0)>>>0<320){q=(c[2385338]|0)+4|0;if((a[q]|0)==0){break}r=m+8|0;if((e[r>>1]|0)>(i|0)){break}b[r>>1]=j;b[l+8>>1]=c[k+(d[q]<<2)>>2]&65535}}while(0);do{if((g+5|0)>>>0<320){q=(c[2385338]|0)+5|0;if((a[q]|0)==0){break}r=m+10|0;if((e[r>>1]|0)>(i|0)){break}b[r>>1]=j;b[l+10>>1]=c[k+(d[q]<<2)>>2]&65535}}while(0);do{if((g+6|0)>>>0<320){q=(c[2385338]|0)+6|0;if((a[q]|0)==0){break}r=m+12|0;if((e[r>>1]|0)>(i|0)){break}b[r>>1]=j;b[l+12>>1]=c[k+(d[q]<<2)>>2]&65535}}while(0);do{if((g+7|0)>>>0<320){q=(c[2385338]|0)+7|0;if((a[q]|0)==0){break}r=m+14|0;if((e[r>>1]|0)>(i|0)){break}b[r>>1]=j;b[l+14>>1]=c[k+(d[q]<<2)>>2]&65535}}while(0);do{if((g+8|0)>>>0<320){q=(c[2385338]|0)+8|0;if((a[q]|0)==0){break}r=m+16|0;if((e[r>>1]|0)>(i|0)){break}b[r>>1]=j;b[l+16>>1]=c[k+(d[q]<<2)>>2]&65535}}while(0);do{if((g+9|0)>>>0<320){q=(c[2385338]|0)+9|0;if((a[q]|0)==0){break}r=m+18|0;if((e[r>>1]|0)>(i|0)){break}b[r>>1]=j;b[l+18>>1]=c[k+(d[q]<<2)>>2]&65535}}while(0);do{if((g+10|0)>>>0<320){q=(c[2385338]|0)+10|0;if((a[q]|0)==0){break}r=m+20|0;if((e[r>>1]|0)>(i|0)){break}b[r>>1]=j;b[l+20>>1]=c[k+(d[q]<<2)>>2]&65535}}while(0);do{if((g+11|0)>>>0<320){q=(c[2385338]|0)+11|0;if((a[q]|0)==0){break}r=m+22|0;if((e[r>>1]|0)>(i|0)){break}b[r>>1]=j;b[l+22>>1]=c[k+(d[q]<<2)>>2]&65535}}while(0);do{if((g+12|0)>>>0<320){q=(c[2385338]|0)+12|0;if((a[q]|0)==0){break}r=m+24|0;if((e[r>>1]|0)>(i|0)){break}b[r>>1]=j;b[l+24>>1]=c[k+(d[q]<<2)>>2]&65535}}while(0);do{if((g+13|0)>>>0<320){q=(c[2385338]|0)+13|0;if((a[q]|0)==0){break}r=m+26|0;if((e[r>>1]|0)>(i|0)){break}b[r>>1]=j;b[l+26>>1]=c[k+(d[q]<<2)>>2]&65535}}while(0);do{if((g+14|0)>>>0<320){q=(c[2385338]|0)+14|0;if((a[q]|0)==0){break}r=m+28|0;if((e[r>>1]|0)>(i|0)){break}b[r>>1]=j;b[l+28>>1]=c[k+(d[q]<<2)>>2]&65535}}while(0);if((g+15|0)>>>0>=320){break}q=(c[2385338]|0)+15|0;if((a[q]|0)==0){break}r=m+30|0;if((e[r>>1]|0)>(i|0)){break}b[r>>1]=j;b[l+30>>1]=c[k+(d[q]<<2)>>2]&65535}}while(0);o=n+1|0;c[2385338]=(c[2385338]|0)+16;if((o|0)>=16){p=31205;break}l=l+640|0;m=m+640|0;n=o}if((p|0)==31204){return}else if((p|0)==31205){return}}function dXx(){var d=0,e=0,f=0,g=0,h=0,i=0;d=c[2440386]|0;e=c[2415150]|0;f=0;g=c[2385338]|0;while(1){h=a[g+15|0]|0;if(h<<24>>24!=0){b[e>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+14|0]|0;if(h<<24>>24!=0){b[e+2>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+13|0]|0;if(h<<24>>24!=0){b[e+4>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+12|0]|0;if(h<<24>>24!=0){b[e+6>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+11|0]|0;if(h<<24>>24!=0){b[e+8>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+10|0]|0;if(h<<24>>24!=0){b[e+10>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+9|0]|0;if(h<<24>>24!=0){b[e+12>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+8|0]|0;if(h<<24>>24!=0){b[e+14>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+7|0]|0;if(h<<24>>24!=0){b[e+16>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+6|0]|0;if(h<<24>>24!=0){b[e+18>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+5|0]|0;if(h<<24>>24!=0){b[e+20>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+4|0]|0;if(h<<24>>24!=0){b[e+22>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+3|0]|0;if(h<<24>>24!=0){b[e+24>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+2|0]|0;if(h<<24>>24!=0){b[e+26>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+1|0]|0;if(h<<24>>24!=0){b[e+28>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g]|0;if(h<<24>>24!=0){b[e+30>>1]=c[d+((h&255)<<2)>>2]&65535}h=f+1|0;i=g+16|0;if((h|0)<16){e=e+640|0;f=h;g=i}else{break}}c[2385338]=i;return}function dXy(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[2385456]|0;e=c[2385468]|0;f=e>>>0<320;g=c[2440386]|0;h=c[2415150]|0;i=0;L41279:while(1){j=d+i|0;do{if((j|0)>=0){if((j|0)>223){k=31296;break L41279}do{if(f){l=a[(c[2385338]|0)+15|0]|0;if(l<<24>>24==0){break}b[h>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+1|0)>>>0<320){l=a[(c[2385338]|0)+14|0]|0;if(l<<24>>24==0){break}b[h+2>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+2|0)>>>0<320){l=a[(c[2385338]|0)+13|0]|0;if(l<<24>>24==0){break}b[h+4>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+3|0)>>>0<320){l=a[(c[2385338]|0)+12|0]|0;if(l<<24>>24==0){break}b[h+6>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+4|0)>>>0<320){l=a[(c[2385338]|0)+11|0]|0;if(l<<24>>24==0){break}b[h+8>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+5|0)>>>0<320){l=a[(c[2385338]|0)+10|0]|0;if(l<<24>>24==0){break}b[h+10>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+6|0)>>>0<320){l=a[(c[2385338]|0)+9|0]|0;if(l<<24>>24==0){break}b[h+12>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+7|0)>>>0<320){l=a[(c[2385338]|0)+8|0]|0;if(l<<24>>24==0){break}b[h+14>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+8|0)>>>0<320){l=a[(c[2385338]|0)+7|0]|0;if(l<<24>>24==0){break}b[h+16>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+9|0)>>>0<320){l=a[(c[2385338]|0)+6|0]|0;if(l<<24>>24==0){break}b[h+18>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+10|0)>>>0<320){l=a[(c[2385338]|0)+5|0]|0;if(l<<24>>24==0){break}b[h+20>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+11|0)>>>0<320){l=a[(c[2385338]|0)+4|0]|0;if(l<<24>>24==0){break}b[h+22>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+12|0)>>>0<320){l=a[(c[2385338]|0)+3|0]|0;if(l<<24>>24==0){break}b[h+24>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+13|0)>>>0<320){l=a[(c[2385338]|0)+2|0]|0;if(l<<24>>24==0){break}b[h+26>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);do{if((e+14|0)>>>0<320){l=a[(c[2385338]|0)+1|0]|0;if(l<<24>>24==0){break}b[h+28>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);if((e+15|0)>>>0>=320){break}l=a[c[2385338]|0]|0;if(l<<24>>24==0){break}b[h+30>>1]=c[g+((l&255)<<2)>>2]&65535}}while(0);j=i+1|0;c[2385338]=(c[2385338]|0)+16;if((j|0)>=16){k=31295;break}h=h+640|0;i=j}if((k|0)==31295){return}else if((k|0)==31296){return}}function dXz(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;d=c[2415164]|0;f=c[2440386]|0;g=c[2415150]|0;h=c[2409606]|0;i=0;j=c[2385338]|0;while(1){k=a[j+15|0]|0;l=k&255;do{if(k<<24>>24==0){m=j}else{if((e[h>>1]|0|0)>(d|0)){m=j;break}b[g>>1]=c[f+(l<<2)>>2]&65535;m=j}}while(0);l=a[m+14|0]|0;k=l&255;do{if(l<<24>>24==0){n=m}else{if((e[h+2>>1]|0|0)>(d|0)){n=m;break}b[g+2>>1]=c[f+(k<<2)>>2]&65535;n=j}}while(0);k=a[n+13|0]|0;l=k&255;do{if(k<<24>>24==0){o=n}else{if((e[h+4>>1]|0|0)>(d|0)){o=n;break}b[g+4>>1]=c[f+(l<<2)>>2]&65535;o=j}}while(0);l=a[o+12|0]|0;k=l&255;do{if(l<<24>>24==0){p=o}else{if((e[h+6>>1]|0|0)>(d|0)){p=o;break}b[g+6>>1]=c[f+(k<<2)>>2]&65535;p=j}}while(0);k=a[p+11|0]|0;l=k&255;do{if(k<<24>>24==0){q=p}else{if((e[h+8>>1]|0|0)>(d|0)){q=p;break}b[g+8>>1]=c[f+(l<<2)>>2]&65535;q=j}}while(0);l=a[q+10|0]|0;k=l&255;do{if(l<<24>>24==0){r=q}else{if((e[h+10>>1]|0|0)>(d|0)){r=q;break}b[g+10>>1]=c[f+(k<<2)>>2]&65535;r=j}}while(0);k=a[r+9|0]|0;l=k&255;do{if(k<<24>>24==0){s=r}else{if((e[h+12>>1]|0|0)>(d|0)){s=r;break}b[g+12>>1]=c[f+(l<<2)>>2]&65535;s=j}}while(0);l=a[s+8|0]|0;k=l&255;do{if(l<<24>>24==0){t=s}else{if((e[h+14>>1]|0|0)>(d|0)){t=s;break}b[g+14>>1]=c[f+(k<<2)>>2]&65535;t=j}}while(0);k=a[t+7|0]|0;l=k&255;do{if(k<<24>>24==0){u=t}else{if((e[h+16>>1]|0|0)>(d|0)){u=t;break}b[g+16>>1]=c[f+(l<<2)>>2]&65535;u=j}}while(0);l=a[u+6|0]|0;k=l&255;do{if(l<<24>>24==0){v=u}else{if((e[h+18>>1]|0|0)>(d|0)){v=u;break}b[g+18>>1]=c[f+(k<<2)>>2]&65535;v=j}}while(0);k=a[v+5|0]|0;l=k&255;do{if(k<<24>>24==0){w=v}else{if((e[h+20>>1]|0|0)>(d|0)){w=v;break}b[g+20>>1]=c[f+(l<<2)>>2]&65535;w=j}}while(0);l=a[w+4|0]|0;k=l&255;do{if(l<<24>>24==0){x=w}else{if((e[h+22>>1]|0|0)>(d|0)){x=w;break}b[g+22>>1]=c[f+(k<<2)>>2]&65535;x=j}}while(0);k=a[x+3|0]|0;l=k&255;do{if(k<<24>>24==0){y=x}else{if((e[h+24>>1]|0|0)>(d|0)){y=x;break}b[g+24>>1]=c[f+(l<<2)>>2]&65535;y=j}}while(0);l=a[y+2|0]|0;k=l&255;do{if(l<<24>>24==0){z=y}else{if((e[h+26>>1]|0|0)>(d|0)){z=y;break}b[g+26>>1]=c[f+(k<<2)>>2]&65535;z=j}}while(0);k=a[z+1|0]|0;l=k&255;do{if(k<<24>>24==0){A=z}else{if((e[h+28>>1]|0|0)>(d|0)){A=z;break}b[g+28>>1]=c[f+(l<<2)>>2]&65535;A=j}}while(0);l=a[A]|0;k=l&255;do{if(l<<24>>24==0){B=A}else{if((e[h+30>>1]|0|0)>(d|0)){B=A;break}b[g+30>>1]=c[f+(k<<2)>>2]&65535;B=j}}while(0);k=i+1|0;C=B+16|0;if((k|0)<16){g=g+640|0;h=h+640|0;i=k;j=C}else{break}}c[2385338]=C;return}function dXA(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=c[2385456]|0;f=c[2385468]|0;g=f>>>0<320;h=c[2415164]|0;i=c[2440386]|0;j=c[2415150]|0;k=c[2409606]|0;l=0;L41420:while(1){m=d+l|0;do{if((m|0)>=0){if((m|0)>223){n=31419;break L41420}do{if(g){o=a[(c[2385338]|0)+15|0]|0;if(o<<24>>24==0){break}if((e[k>>1]|0|0)>(h|0)){break}b[j>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);do{if((f+1|0)>>>0<320){o=a[(c[2385338]|0)+14|0]|0;if(o<<24>>24==0){break}if((e[k+2>>1]|0|0)>(h|0)){break}b[j+2>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);do{if((f+2|0)>>>0<320){o=a[(c[2385338]|0)+13|0]|0;if(o<<24>>24==0){break}if((e[k+4>>1]|0|0)>(h|0)){break}b[j+4>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);do{if((f+3|0)>>>0<320){o=a[(c[2385338]|0)+12|0]|0;if(o<<24>>24==0){break}if((e[k+6>>1]|0|0)>(h|0)){break}b[j+6>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);do{if((f+4|0)>>>0<320){o=a[(c[2385338]|0)+11|0]|0;if(o<<24>>24==0){break}if((e[k+8>>1]|0|0)>(h|0)){break}b[j+8>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);do{if((f+5|0)>>>0<320){o=a[(c[2385338]|0)+10|0]|0;if(o<<24>>24==0){break}if((e[k+10>>1]|0|0)>(h|0)){break}b[j+10>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);do{if((f+6|0)>>>0<320){o=a[(c[2385338]|0)+9|0]|0;if(o<<24>>24==0){break}if((e[k+12>>1]|0|0)>(h|0)){break}b[j+12>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);do{if((f+7|0)>>>0<320){o=a[(c[2385338]|0)+8|0]|0;if(o<<24>>24==0){break}if((e[k+14>>1]|0|0)>(h|0)){break}b[j+14>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);do{if((f+8|0)>>>0<320){o=a[(c[2385338]|0)+7|0]|0;if(o<<24>>24==0){break}if((e[k+16>>1]|0|0)>(h|0)){break}b[j+16>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);do{if((f+9|0)>>>0<320){o=a[(c[2385338]|0)+6|0]|0;if(o<<24>>24==0){break}if((e[k+18>>1]|0|0)>(h|0)){break}b[j+18>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);do{if((f+10|0)>>>0<320){o=a[(c[2385338]|0)+5|0]|0;if(o<<24>>24==0){break}if((e[k+20>>1]|0|0)>(h|0)){break}b[j+20>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);do{if((f+11|0)>>>0<320){o=a[(c[2385338]|0)+4|0]|0;if(o<<24>>24==0){break}if((e[k+22>>1]|0|0)>(h|0)){break}b[j+22>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);do{if((f+12|0)>>>0<320){o=a[(c[2385338]|0)+3|0]|0;if(o<<24>>24==0){break}if((e[k+24>>1]|0|0)>(h|0)){break}b[j+24>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);do{if((f+13|0)>>>0<320){o=a[(c[2385338]|0)+2|0]|0;if(o<<24>>24==0){break}if((e[k+26>>1]|0|0)>(h|0)){break}b[j+26>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);do{if((f+14|0)>>>0<320){o=a[(c[2385338]|0)+1|0]|0;if(o<<24>>24==0){break}if((e[k+28>>1]|0|0)>(h|0)){break}b[j+28>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);if((f+15|0)>>>0>=320){break}o=a[c[2385338]|0]|0;if(o<<24>>24==0){break}if((e[k+30>>1]|0|0)>(h|0)){break}b[j+30>>1]=c[i+((o&255)<<2)>>2]&65535}}while(0);m=l+1|0;c[2385338]=(c[2385338]|0)+16;if((m|0)>=16){n=31418;break}j=j+640|0;k=k+640|0;l=m}if((n|0)==31418){return}else if((n|0)==31419){return}}function dXB(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=c[2415164]&65535;f=c[2440386]|0;g=c[2415150]|0;h=c[2409606]|0;i=0;j=c[2385338]|0;while(1){if((a[j+15|0]|0)!=0){b[h>>1]=e;b[g>>1]=c[f+(d[j+15|0]<<2)>>2]&65535}if((a[j+14|0]|0)!=0){b[h+2>>1]=e;b[g+2>>1]=c[f+(d[j+14|0]<<2)>>2]&65535}if((a[j+13|0]|0)!=0){b[h+4>>1]=e;b[g+4>>1]=c[f+(d[j+13|0]<<2)>>2]&65535}if((a[j+12|0]|0)!=0){b[h+6>>1]=e;b[g+6>>1]=c[f+(d[j+12|0]<<2)>>2]&65535}if((a[j+11|0]|0)!=0){b[h+8>>1]=e;b[g+8>>1]=c[f+(d[j+11|0]<<2)>>2]&65535}if((a[j+10|0]|0)!=0){b[h+10>>1]=e;b[g+10>>1]=c[f+(d[j+10|0]<<2)>>2]&65535}if((a[j+9|0]|0)!=0){b[h+12>>1]=e;b[g+12>>1]=c[f+(d[j+9|0]<<2)>>2]&65535}if((a[j+8|0]|0)!=0){b[h+14>>1]=e;b[g+14>>1]=c[f+(d[j+8|0]<<2)>>2]&65535}if((a[j+7|0]|0)!=0){b[h+16>>1]=e;b[g+16>>1]=c[f+(d[j+7|0]<<2)>>2]&65535}if((a[j+6|0]|0)!=0){b[h+18>>1]=e;b[g+18>>1]=c[f+(d[j+6|0]<<2)>>2]&65535}if((a[j+5|0]|0)!=0){b[h+20>>1]=e;b[g+20>>1]=c[f+(d[j+5|0]<<2)>>2]&65535}if((a[j+4|0]|0)!=0){b[h+22>>1]=e;b[g+22>>1]=c[f+(d[j+4|0]<<2)>>2]&65535}if((a[j+3|0]|0)!=0){b[h+24>>1]=e;b[g+24>>1]=c[f+(d[j+3|0]<<2)>>2]&65535}if((a[j+2|0]|0)!=0){b[h+26>>1]=e;b[g+26>>1]=c[f+(d[j+2|0]<<2)>>2]&65535}if((a[j+1|0]|0)!=0){b[h+28>>1]=e;b[g+28>>1]=c[f+(d[j+1|0]<<2)>>2]&65535}if((a[j]|0)!=0){b[h+30>>1]=e;b[g+30>>1]=c[f+(d[j]<<2)>>2]&65535}k=i+1|0;l=j+16|0;if((k|0)<16){g=g+640|0;h=h+640|0;i=k;j=l}else{break}}c[2385338]=l;return}function dXC(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=c[2385456]|0;f=c[2385468]|0;g=f>>>0<320;h=c[2415164]&65535;i=c[2440386]|0;j=c[2415150]|0;k=c[2409606]|0;l=0;L41561:while(1){m=e+l|0;do{if((m|0)>=0){if((m|0)>223){n=31509;break L41561}do{if(g){o=(c[2385338]|0)+15|0;if((a[o]|0)==0){break}b[k>>1]=h;b[j>>1]=c[i+(d[o]<<2)>>2]&65535}}while(0);do{if((f+1|0)>>>0<320){o=(c[2385338]|0)+14|0;if((a[o]|0)==0){break}b[k+2>>1]=h;b[j+2>>1]=c[i+(d[o]<<2)>>2]&65535}}while(0);do{if((f+2|0)>>>0<320){o=(c[2385338]|0)+13|0;if((a[o]|0)==0){break}b[k+4>>1]=h;b[j+4>>1]=c[i+(d[o]<<2)>>2]&65535}}while(0);do{if((f+3|0)>>>0<320){o=(c[2385338]|0)+12|0;if((a[o]|0)==0){break}b[k+6>>1]=h;b[j+6>>1]=c[i+(d[o]<<2)>>2]&65535}}while(0);do{if((f+4|0)>>>0<320){o=(c[2385338]|0)+11|0;if((a[o]|0)==0){break}b[k+8>>1]=h;b[j+8>>1]=c[i+(d[o]<<2)>>2]&65535}}while(0);do{if((f+5|0)>>>0<320){o=(c[2385338]|0)+10|0;if((a[o]|0)==0){break}b[k+10>>1]=h;b[j+10>>1]=c[i+(d[o]<<2)>>2]&65535}}while(0);do{if((f+6|0)>>>0<320){o=(c[2385338]|0)+9|0;if((a[o]|0)==0){break}b[k+12>>1]=h;b[j+12>>1]=c[i+(d[o]<<2)>>2]&65535}}while(0);do{if((f+7|0)>>>0<320){o=(c[2385338]|0)+8|0;if((a[o]|0)==0){break}b[k+14>>1]=h;b[j+14>>1]=c[i+(d[o]<<2)>>2]&65535}}while(0);do{if((f+8|0)>>>0<320){o=(c[2385338]|0)+7|0;if((a[o]|0)==0){break}b[k+16>>1]=h;b[j+16>>1]=c[i+(d[o]<<2)>>2]&65535}}while(0);do{if((f+9|0)>>>0<320){o=(c[2385338]|0)+6|0;if((a[o]|0)==0){break}b[k+18>>1]=h;b[j+18>>1]=c[i+(d[o]<<2)>>2]&65535}}while(0);do{if((f+10|0)>>>0<320){o=(c[2385338]|0)+5|0;if((a[o]|0)==0){break}b[k+20>>1]=h;b[j+20>>1]=c[i+(d[o]<<2)>>2]&65535}}while(0);do{if((f+11|0)>>>0<320){o=(c[2385338]|0)+4|0;if((a[o]|0)==0){break}b[k+22>>1]=h;b[j+22>>1]=c[i+(d[o]<<2)>>2]&65535}}while(0);do{if((f+12|0)>>>0<320){o=(c[2385338]|0)+3|0;if((a[o]|0)==0){break}b[k+24>>1]=h;b[j+24>>1]=c[i+(d[o]<<2)>>2]&65535}}while(0);do{if((f+13|0)>>>0<320){o=(c[2385338]|0)+2|0;if((a[o]|0)==0){break}b[k+26>>1]=h;b[j+26>>1]=c[i+(d[o]<<2)>>2]&65535}}while(0);do{if((f+14|0)>>>0<320){o=(c[2385338]|0)+1|0;if((a[o]|0)==0){break}b[k+28>>1]=h;b[j+28>>1]=c[i+(d[o]<<2)>>2]&65535}}while(0);if((f+15|0)>>>0>=320){break}o=c[2385338]|0;if((a[o]|0)==0){break}b[k+30>>1]=h;b[j+30>>1]=c[i+(d[o]<<2)>>2]&65535}}while(0);m=l+1|0;c[2385338]=(c[2385338]|0)+16;if((m|0)>=16){n=31510;break}j=j+640|0;k=k+640|0;l=m}if((n|0)==31509){return}else if((n|0)==31510){return}}function dXD(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;f=c[2415164]|0;g=f&65535;h=c[2440386]|0;i=c[2415150]|0;j=c[2409606]|0;k=0;l=c[2385338]|0;while(1){do{if((a[l+15|0]|0)==0){m=l}else{if((e[j>>1]|0)>(f|0)){m=l;break}b[j>>1]=g;b[i>>1]=c[h+(d[l+15|0]<<2)>>2]&65535;m=l}}while(0);do{if((a[m+14|0]|0)==0){n=m}else{o=j+2|0;if((e[o>>1]|0)>(f|0)){n=m;break}b[o>>1]=g;b[i+2>>1]=c[h+(d[l+14|0]<<2)>>2]&65535;n=l}}while(0);do{if((a[n+13|0]|0)==0){p=n}else{o=j+4|0;if((e[o>>1]|0)>(f|0)){p=n;break}b[o>>1]=g;b[i+4>>1]=c[h+(d[l+13|0]<<2)>>2]&65535;p=l}}while(0);do{if((a[p+12|0]|0)==0){q=p}else{o=j+6|0;if((e[o>>1]|0)>(f|0)){q=p;break}b[o>>1]=g;b[i+6>>1]=c[h+(d[l+12|0]<<2)>>2]&65535;q=l}}while(0);do{if((a[q+11|0]|0)==0){r=q}else{o=j+8|0;if((e[o>>1]|0)>(f|0)){r=q;break}b[o>>1]=g;b[i+8>>1]=c[h+(d[l+11|0]<<2)>>2]&65535;r=l}}while(0);do{if((a[r+10|0]|0)==0){s=r}else{o=j+10|0;if((e[o>>1]|0)>(f|0)){s=r;break}b[o>>1]=g;b[i+10>>1]=c[h+(d[l+10|0]<<2)>>2]&65535;s=l}}while(0);do{if((a[s+9|0]|0)==0){t=s}else{o=j+12|0;if((e[o>>1]|0)>(f|0)){t=s;break}b[o>>1]=g;b[i+12>>1]=c[h+(d[l+9|0]<<2)>>2]&65535;t=l}}while(0);do{if((a[t+8|0]|0)==0){u=t}else{o=j+14|0;if((e[o>>1]|0)>(f|0)){u=t;break}b[o>>1]=g;b[i+14>>1]=c[h+(d[l+8|0]<<2)>>2]&65535;u=l}}while(0);do{if((a[u+7|0]|0)==0){v=u}else{o=j+16|0;if((e[o>>1]|0)>(f|0)){v=u;break}b[o>>1]=g;b[i+16>>1]=c[h+(d[l+7|0]<<2)>>2]&65535;v=l}}while(0);do{if((a[v+6|0]|0)==0){w=v}else{o=j+18|0;if((e[o>>1]|0)>(f|0)){w=v;break}b[o>>1]=g;b[i+18>>1]=c[h+(d[l+6|0]<<2)>>2]&65535;w=l}}while(0);do{if((a[w+5|0]|0)==0){x=w}else{o=j+20|0;if((e[o>>1]|0)>(f|0)){x=w;break}b[o>>1]=g;b[i+20>>1]=c[h+(d[l+5|0]<<2)>>2]&65535;x=l}}while(0);do{if((a[x+4|0]|0)==0){y=x}else{o=j+22|0;if((e[o>>1]|0)>(f|0)){y=x;break}b[o>>1]=g;b[i+22>>1]=c[h+(d[l+4|0]<<2)>>2]&65535;y=l}}while(0);do{if((a[y+3|0]|0)==0){z=y}else{o=j+24|0;if((e[o>>1]|0)>(f|0)){z=y;break}b[o>>1]=g;b[i+24>>1]=c[h+(d[l+3|0]<<2)>>2]&65535;z=l}}while(0);do{if((a[z+2|0]|0)==0){A=z}else{o=j+26|0;if((e[o>>1]|0)>(f|0)){A=z;break}b[o>>1]=g;b[i+26>>1]=c[h+(d[l+2|0]<<2)>>2]&65535;A=l}}while(0);do{if((a[A+1|0]|0)==0){B=A}else{o=j+28|0;if((e[o>>1]|0)>(f|0)){B=A;break}b[o>>1]=g;b[i+28>>1]=c[h+(d[l+1|0]<<2)>>2]&65535;B=l}}while(0);do{if((a[B]|0)==0){C=B}else{o=j+30|0;if((e[o>>1]|0)>(f|0)){C=B;break}b[o>>1]=g;b[i+30>>1]=c[h+(d[l]<<2)>>2]&65535;C=l}}while(0);o=k+1|0;D=C+16|0;if((o|0)<16){i=i+640|0;j=j+640|0;k=o;l=D}else{break}}c[2385338]=D;return}function dXE(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=c[2385456]|0;g=c[2385468]|0;h=g>>>0<320;i=c[2415164]|0;j=i&65535;k=c[2440386]|0;l=c[2415150]|0;m=c[2409606]|0;n=0;L41702:while(1){o=f+n|0;do{if((o|0)>=0){if((o|0)>223){p=31633;break L41702}do{if(h){q=(c[2385338]|0)+15|0;if((a[q]|0)==0){break}if((e[m>>1]|0)>(i|0)){break}b[m>>1]=j;b[l>>1]=c[k+(d[q]<<2)>>2]&65535}}while(0);do{if((g+1|0)>>>0<320){q=(c[2385338]|0)+14|0;if((a[q]|0)==0){break}r=m+2|0;if((e[r>>1]|0)>(i|0)){break}b[r>>1]=j;b[l+2>>1]=c[k+(d[q]<<2)>>2]&65535}}while(0);do{if((g+2|0)>>>0<320){q=(c[2385338]|0)+13|0;if((a[q]|0)==0){break}r=m+4|0;if((e[r>>1]|0)>(i|0)){break}b[r>>1]=j;b[l+4>>1]=c[k+(d[q]<<2)>>2]&65535}}while(0);do{if((g+3|0)>>>0<320){q=(c[2385338]|0)+12|0;if((a[q]|0)==0){break}r=m+6|0;if((e[r>>1]|0)>(i|0)){break}b[r>>1]=j;b[l+6>>1]=c[k+(d[q]<<2)>>2]&65535}}while(0);do{if((g+4|0)>>>0<320){q=(c[2385338]|0)+11|0;if((a[q]|0)==0){break}r=m+8|0;if((e[r>>1]|0)>(i|0)){break}b[r>>1]=j;b[l+8>>1]=c[k+(d[q]<<2)>>2]&65535}}while(0);do{if((g+5|0)>>>0<320){q=(c[2385338]|0)+10|0;if((a[q]|0)==0){break}r=m+10|0;if((e[r>>1]|0)>(i|0)){break}b[r>>1]=j;b[l+10>>1]=c[k+(d[q]<<2)>>2]&65535}}while(0);do{if((g+6|0)>>>0<320){q=(c[2385338]|0)+9|0;if((a[q]|0)==0){break}r=m+12|0;if((e[r>>1]|0)>(i|0)){break}b[r>>1]=j;b[l+12>>1]=c[k+(d[q]<<2)>>2]&65535}}while(0);do{if((g+7|0)>>>0<320){q=(c[2385338]|0)+8|0;if((a[q]|0)==0){break}r=m+14|0;if((e[r>>1]|0)>(i|0)){break}b[r>>1]=j;b[l+14>>1]=c[k+(d[q]<<2)>>2]&65535}}while(0);do{if((g+8|0)>>>0<320){q=(c[2385338]|0)+7|0;if((a[q]|0)==0){break}r=m+16|0;if((e[r>>1]|0)>(i|0)){break}b[r>>1]=j;b[l+16>>1]=c[k+(d[q]<<2)>>2]&65535}}while(0);do{if((g+9|0)>>>0<320){q=(c[2385338]|0)+6|0;if((a[q]|0)==0){break}r=m+18|0;if((e[r>>1]|0)>(i|0)){break}b[r>>1]=j;b[l+18>>1]=c[k+(d[q]<<2)>>2]&65535}}while(0);do{if((g+10|0)>>>0<320){q=(c[2385338]|0)+5|0;if((a[q]|0)==0){break}r=m+20|0;if((e[r>>1]|0)>(i|0)){break}b[r>>1]=j;b[l+20>>1]=c[k+(d[q]<<2)>>2]&65535}}while(0);do{if((g+11|0)>>>0<320){q=(c[2385338]|0)+4|0;if((a[q]|0)==0){break}r=m+22|0;if((e[r>>1]|0)>(i|0)){break}b[r>>1]=j;b[l+22>>1]=c[k+(d[q]<<2)>>2]&65535}}while(0);do{if((g+12|0)>>>0<320){q=(c[2385338]|0)+3|0;if((a[q]|0)==0){break}r=m+24|0;if((e[r>>1]|0)>(i|0)){break}b[r>>1]=j;b[l+24>>1]=c[k+(d[q]<<2)>>2]&65535}}while(0);do{if((g+13|0)>>>0<320){q=(c[2385338]|0)+2|0;if((a[q]|0)==0){break}r=m+26|0;if((e[r>>1]|0)>(i|0)){break}b[r>>1]=j;b[l+26>>1]=c[k+(d[q]<<2)>>2]&65535}}while(0);do{if((g+14|0)>>>0<320){q=(c[2385338]|0)+1|0;if((a[q]|0)==0){break}r=m+28|0;if((e[r>>1]|0)>(i|0)){break}b[r>>1]=j;b[l+28>>1]=c[k+(d[q]<<2)>>2]&65535}}while(0);if((g+15|0)>>>0>=320){break}q=c[2385338]|0;if((a[q]|0)==0){break}r=m+30|0;if((e[r>>1]|0)>(i|0)){break}b[r>>1]=j;b[l+30>>1]=c[k+(d[q]<<2)>>2]&65535}}while(0);o=n+1|0;c[2385338]=(c[2385338]|0)+16;if((o|0)>=16){p=31632;break}l=l+640|0;m=m+640|0;n=o}if((p|0)==31632){return}else if((p|0)==31633){return}}function dXF(){var d=0,e=0,f=0,g=0,h=0,i=0;d=c[2440386]|0;e=(c[2415150]|0)+9600|0;f=15;g=c[2385338]|0;while(1){h=a[g]|0;if(h<<24>>24!=0){b[e>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+1|0]|0;if(h<<24>>24!=0){b[e+2>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+2|0]|0;if(h<<24>>24!=0){b[e+4>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+3|0]|0;if(h<<24>>24!=0){b[e+6>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+4|0]|0;if(h<<24>>24!=0){b[e+8>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+5|0]|0;if(h<<24>>24!=0){b[e+10>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+6|0]|0;if(h<<24>>24!=0){b[e+12>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+7|0]|0;if(h<<24>>24!=0){b[e+14>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+8|0]|0;if(h<<24>>24!=0){b[e+16>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+9|0]|0;if(h<<24>>24!=0){b[e+18>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+10|0]|0;if(h<<24>>24!=0){b[e+20>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+11|0]|0;if(h<<24>>24!=0){b[e+22>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+12|0]|0;if(h<<24>>24!=0){b[e+24>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+13|0]|0;if(h<<24>>24!=0){b[e+26>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+14|0]|0;if(h<<24>>24!=0){b[e+28>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+15|0]|0;if(h<<24>>24!=0){b[e+30>>1]=c[d+((h&255)<<2)>>2]&65535}i=g+16|0;if((f|0)>0){e=e-640|0;f=f-1|0;g=i}else{break}}c[2385338]=i;return}function dXG(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=c[2385456]|0;e=d+15|0;if((e|0)<0){return}f=c[2385468]|0;g=f>>>0<320;h=c[2440386]|0;i=15;j=(c[2415150]|0)+9600|0;k=e;e=c[2385338]|0;while(1){do{if((k|0)<=223){do{if(g){l=a[e]|0;if(l<<24>>24==0){break}b[j>>1]=c[h+((l&255)<<2)>>2]&65535}}while(0);do{if((f+1|0)>>>0<320){l=a[e+1|0]|0;if(l<<24>>24==0){break}b[j+2>>1]=c[h+((l&255)<<2)>>2]&65535}}while(0);do{if((f+2|0)>>>0<320){l=a[e+2|0]|0;if(l<<24>>24==0){break}b[j+4>>1]=c[h+((l&255)<<2)>>2]&65535}}while(0);do{if((f+3|0)>>>0<320){l=a[e+3|0]|0;if(l<<24>>24==0){break}b[j+6>>1]=c[h+((l&255)<<2)>>2]&65535}}while(0);do{if((f+4|0)>>>0<320){l=a[e+4|0]|0;if(l<<24>>24==0){break}b[j+8>>1]=c[h+((l&255)<<2)>>2]&65535}}while(0);do{if((f+5|0)>>>0<320){l=a[e+5|0]|0;if(l<<24>>24==0){break}b[j+10>>1]=c[h+((l&255)<<2)>>2]&65535}}while(0);do{if((f+6|0)>>>0<320){l=a[e+6|0]|0;if(l<<24>>24==0){break}b[j+12>>1]=c[h+((l&255)<<2)>>2]&65535}}while(0);do{if((f+7|0)>>>0<320){l=a[e+7|0]|0;if(l<<24>>24==0){break}b[j+14>>1]=c[h+((l&255)<<2)>>2]&65535}}while(0);do{if((f+8|0)>>>0<320){l=a[e+8|0]|0;if(l<<24>>24==0){break}b[j+16>>1]=c[h+((l&255)<<2)>>2]&65535}}while(0);do{if((f+9|0)>>>0<320){l=a[e+9|0]|0;if(l<<24>>24==0){break}b[j+18>>1]=c[h+((l&255)<<2)>>2]&65535}}while(0);do{if((f+10|0)>>>0<320){l=a[e+10|0]|0;if(l<<24>>24==0){break}b[j+20>>1]=c[h+((l&255)<<2)>>2]&65535}}while(0);do{if((f+11|0)>>>0<320){l=a[e+11|0]|0;if(l<<24>>24==0){break}b[j+22>>1]=c[h+((l&255)<<2)>>2]&65535}}while(0);do{if((f+12|0)>>>0<320){l=a[e+12|0]|0;if(l<<24>>24==0){break}b[j+24>>1]=c[h+((l&255)<<2)>>2]&65535}}while(0);do{if((f+13|0)>>>0<320){l=a[e+13|0]|0;if(l<<24>>24==0){break}b[j+26>>1]=c[h+((l&255)<<2)>>2]&65535}}while(0);do{if((f+14|0)>>>0<320){l=a[e+14|0]|0;if(l<<24>>24==0){break}b[j+28>>1]=c[h+((l&255)<<2)>>2]&65535}}while(0);if((f+15|0)>>>0>=320){break}l=a[e+15|0]|0;if(l<<24>>24==0){break}b[j+30>>1]=c[h+((l&255)<<2)>>2]&65535}}while(0);m=e+16|0;if((i|0)<=0){break}l=i-1|0;n=d+l|0;if((n|0)<0){break}else{i=l;j=j-640|0;k=n;e=m}}c[2385338]=m;return}function dXH(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;d=c[2415164]|0;f=c[2440386]|0;g=(c[2415150]|0)+9600|0;h=(c[2409606]|0)+9600|0;i=15;j=c[2385338]|0;while(1){k=a[j]|0;l=k&255;do{if(k<<24>>24==0){m=j}else{if((e[h>>1]|0|0)>(d|0)){m=j;break}b[g>>1]=c[f+(l<<2)>>2]&65535;m=j}}while(0);l=a[m+1|0]|0;k=l&255;do{if(l<<24>>24==0){n=m}else{if((e[h+2>>1]|0|0)>(d|0)){n=m;break}b[g+2>>1]=c[f+(k<<2)>>2]&65535;n=j}}while(0);k=a[n+2|0]|0;l=k&255;do{if(k<<24>>24==0){o=n}else{if((e[h+4>>1]|0|0)>(d|0)){o=n;break}b[g+4>>1]=c[f+(l<<2)>>2]&65535;o=j}}while(0);l=a[o+3|0]|0;k=l&255;do{if(l<<24>>24==0){p=o}else{if((e[h+6>>1]|0|0)>(d|0)){p=o;break}b[g+6>>1]=c[f+(k<<2)>>2]&65535;p=j}}while(0);k=a[p+4|0]|0;l=k&255;do{if(k<<24>>24==0){q=p}else{if((e[h+8>>1]|0|0)>(d|0)){q=p;break}b[g+8>>1]=c[f+(l<<2)>>2]&65535;q=j}}while(0);l=a[q+5|0]|0;k=l&255;do{if(l<<24>>24==0){r=q}else{if((e[h+10>>1]|0|0)>(d|0)){r=q;break}b[g+10>>1]=c[f+(k<<2)>>2]&65535;r=j}}while(0);k=a[r+6|0]|0;l=k&255;do{if(k<<24>>24==0){s=r}else{if((e[h+12>>1]|0|0)>(d|0)){s=r;break}b[g+12>>1]=c[f+(l<<2)>>2]&65535;s=j}}while(0);l=a[s+7|0]|0;k=l&255;do{if(l<<24>>24==0){t=s}else{if((e[h+14>>1]|0|0)>(d|0)){t=s;break}b[g+14>>1]=c[f+(k<<2)>>2]&65535;t=j}}while(0);k=a[t+8|0]|0;l=k&255;do{if(k<<24>>24==0){u=t}else{if((e[h+16>>1]|0|0)>(d|0)){u=t;break}b[g+16>>1]=c[f+(l<<2)>>2]&65535;u=j}}while(0);l=a[u+9|0]|0;k=l&255;do{if(l<<24>>24==0){v=u}else{if((e[h+18>>1]|0|0)>(d|0)){v=u;break}b[g+18>>1]=c[f+(k<<2)>>2]&65535;v=j}}while(0);k=a[v+10|0]|0;l=k&255;do{if(k<<24>>24==0){w=v}else{if((e[h+20>>1]|0|0)>(d|0)){w=v;break}b[g+20>>1]=c[f+(l<<2)>>2]&65535;w=j}}while(0);l=a[w+11|0]|0;k=l&255;do{if(l<<24>>24==0){x=w}else{if((e[h+22>>1]|0|0)>(d|0)){x=w;break}b[g+22>>1]=c[f+(k<<2)>>2]&65535;x=j}}while(0);k=a[x+12|0]|0;l=k&255;do{if(k<<24>>24==0){y=x}else{if((e[h+24>>1]|0|0)>(d|0)){y=x;break}b[g+24>>1]=c[f+(l<<2)>>2]&65535;y=j}}while(0);l=a[y+13|0]|0;k=l&255;do{if(l<<24>>24==0){z=y}else{if((e[h+26>>1]|0|0)>(d|0)){z=y;break}b[g+26>>1]=c[f+(k<<2)>>2]&65535;z=j}}while(0);k=a[z+14|0]|0;l=k&255;do{if(k<<24>>24==0){A=z}else{if((e[h+28>>1]|0|0)>(d|0)){A=z;break}b[g+28>>1]=c[f+(l<<2)>>2]&65535;A=j}}while(0);l=a[A+15|0]|0;k=l&255;do{if(l<<24>>24==0){B=A}else{if((e[h+30>>1]|0|0)>(d|0)){B=A;break}b[g+30>>1]=c[f+(k<<2)>>2]&65535;B=j}}while(0);C=B+16|0;if((i|0)>0){g=g-640|0;h=h-640|0;i=i-1|0;j=C}else{break}}c[2385338]=C;return}function dXI(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=c[2385456]|0;f=d+15|0;if((f|0)<0){return}g=c[2385468]|0;h=g>>>0<320;i=c[2415164]|0;j=c[2440386]|0;k=15;l=(c[2409606]|0)+9600|0;m=(c[2415150]|0)+9600|0;n=f;f=c[2385338]|0;while(1){do{if((n|0)<=223){do{if(h){o=a[f]|0;if(o<<24>>24==0){break}if((e[l>>1]|0|0)>(i|0)){break}b[m>>1]=c[j+((o&255)<<2)>>2]&65535}}while(0);do{if((g+1|0)>>>0<320){o=a[f+1|0]|0;if(o<<24>>24==0){break}if((e[l+2>>1]|0|0)>(i|0)){break}b[m+2>>1]=c[j+((o&255)<<2)>>2]&65535}}while(0);do{if((g+2|0)>>>0<320){o=a[f+2|0]|0;if(o<<24>>24==0){break}if((e[l+4>>1]|0|0)>(i|0)){break}b[m+4>>1]=c[j+((o&255)<<2)>>2]&65535}}while(0);do{if((g+3|0)>>>0<320){o=a[f+3|0]|0;if(o<<24>>24==0){break}if((e[l+6>>1]|0|0)>(i|0)){break}b[m+6>>1]=c[j+((o&255)<<2)>>2]&65535}}while(0);do{if((g+4|0)>>>0<320){o=a[f+4|0]|0;if(o<<24>>24==0){break}if((e[l+8>>1]|0|0)>(i|0)){break}b[m+8>>1]=c[j+((o&255)<<2)>>2]&65535}}while(0);do{if((g+5|0)>>>0<320){o=a[f+5|0]|0;if(o<<24>>24==0){break}if((e[l+10>>1]|0|0)>(i|0)){break}b[m+10>>1]=c[j+((o&255)<<2)>>2]&65535}}while(0);do{if((g+6|0)>>>0<320){o=a[f+6|0]|0;if(o<<24>>24==0){break}if((e[l+12>>1]|0|0)>(i|0)){break}b[m+12>>1]=c[j+((o&255)<<2)>>2]&65535}}while(0);do{if((g+7|0)>>>0<320){o=a[f+7|0]|0;if(o<<24>>24==0){break}if((e[l+14>>1]|0|0)>(i|0)){break}b[m+14>>1]=c[j+((o&255)<<2)>>2]&65535}}while(0);do{if((g+8|0)>>>0<320){o=a[f+8|0]|0;if(o<<24>>24==0){break}if((e[l+16>>1]|0|0)>(i|0)){break}b[m+16>>1]=c[j+((o&255)<<2)>>2]&65535}}while(0);do{if((g+9|0)>>>0<320){o=a[f+9|0]|0;if(o<<24>>24==0){break}if((e[l+18>>1]|0|0)>(i|0)){break}b[m+18>>1]=c[j+((o&255)<<2)>>2]&65535}}while(0);do{if((g+10|0)>>>0<320){o=a[f+10|0]|0;if(o<<24>>24==0){break}if((e[l+20>>1]|0|0)>(i|0)){break}b[m+20>>1]=c[j+((o&255)<<2)>>2]&65535}}while(0);do{if((g+11|0)>>>0<320){o=a[f+11|0]|0;if(o<<24>>24==0){break}if((e[l+22>>1]|0|0)>(i|0)){break}b[m+22>>1]=c[j+((o&255)<<2)>>2]&65535}}while(0);do{if((g+12|0)>>>0<320){o=a[f+12|0]|0;if(o<<24>>24==0){break}if((e[l+24>>1]|0|0)>(i|0)){break}b[m+24>>1]=c[j+((o&255)<<2)>>2]&65535}}while(0);do{if((g+13|0)>>>0<320){o=a[f+13|0]|0;if(o<<24>>24==0){break}if((e[l+26>>1]|0|0)>(i|0)){break}b[m+26>>1]=c[j+((o&255)<<2)>>2]&65535}}while(0);do{if((g+14|0)>>>0<320){o=a[f+14|0]|0;if(o<<24>>24==0){break}if((e[l+28>>1]|0|0)>(i|0)){break}b[m+28>>1]=c[j+((o&255)<<2)>>2]&65535}}while(0);if((g+15|0)>>>0>=320){break}o=a[f+15|0]|0;if(o<<24>>24==0){break}if((e[l+30>>1]|0|0)>(i|0)){break}b[m+30>>1]=c[j+((o&255)<<2)>>2]&65535}}while(0);p=f+16|0;if((k|0)<=0){break}o=k-1|0;q=d+o|0;if((q|0)<0){break}else{k=o;l=l-640|0;m=m-640|0;n=q;f=p}}c[2385338]=p;return}function dXJ(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=c[2415164]&65535;f=c[2440386]|0;g=(c[2415150]|0)+9600|0;h=(c[2409606]|0)+9600|0;i=15;j=c[2385338]|0;while(1){if((a[j]|0)!=0){b[h>>1]=e;b[g>>1]=c[f+(d[j]<<2)>>2]&65535}if((a[j+1|0]|0)!=0){b[h+2>>1]=e;b[g+2>>1]=c[f+(d[j+1|0]<<2)>>2]&65535}if((a[j+2|0]|0)!=0){b[h+4>>1]=e;b[g+4>>1]=c[f+(d[j+2|0]<<2)>>2]&65535}if((a[j+3|0]|0)!=0){b[h+6>>1]=e;b[g+6>>1]=c[f+(d[j+3|0]<<2)>>2]&65535}if((a[j+4|0]|0)!=0){b[h+8>>1]=e;b[g+8>>1]=c[f+(d[j+4|0]<<2)>>2]&65535}if((a[j+5|0]|0)!=0){b[h+10>>1]=e;b[g+10>>1]=c[f+(d[j+5|0]<<2)>>2]&65535}if((a[j+6|0]|0)!=0){b[h+12>>1]=e;b[g+12>>1]=c[f+(d[j+6|0]<<2)>>2]&65535}if((a[j+7|0]|0)!=0){b[h+14>>1]=e;b[g+14>>1]=c[f+(d[j+7|0]<<2)>>2]&65535}if((a[j+8|0]|0)!=0){b[h+16>>1]=e;b[g+16>>1]=c[f+(d[j+8|0]<<2)>>2]&65535}if((a[j+9|0]|0)!=0){b[h+18>>1]=e;b[g+18>>1]=c[f+(d[j+9|0]<<2)>>2]&65535}if((a[j+10|0]|0)!=0){b[h+20>>1]=e;b[g+20>>1]=c[f+(d[j+10|0]<<2)>>2]&65535}if((a[j+11|0]|0)!=0){b[h+22>>1]=e;b[g+22>>1]=c[f+(d[j+11|0]<<2)>>2]&65535}if((a[j+12|0]|0)!=0){b[h+24>>1]=e;b[g+24>>1]=c[f+(d[j+12|0]<<2)>>2]&65535}if((a[j+13|0]|0)!=0){b[h+26>>1]=e;b[g+26>>1]=c[f+(d[j+13|0]<<2)>>2]&65535}if((a[j+14|0]|0)!=0){b[h+28>>1]=e;b[g+28>>1]=c[f+(d[j+14|0]<<2)>>2]&65535}if((a[j+15|0]|0)!=0){b[h+30>>1]=e;b[g+30>>1]=c[f+(d[j+15|0]<<2)>>2]&65535}k=j+16|0;if((i|0)>0){g=g-640|0;h=h-640|0;i=i-1|0;j=k}else{break}}c[2385338]=k;return}function dXK(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=c[2385456]|0;f=e+15|0;if((f|0)<0){return}g=c[2385468]|0;h=g>>>0<320;i=c[2415164]&65535;j=c[2440386]|0;k=15;l=(c[2409606]|0)+9600|0;m=(c[2415150]|0)+9600|0;n=f;f=c[2385338]|0;while(1){do{if((n|0)<=223){do{if(h){if((a[f]|0)==0){break}b[l>>1]=i;b[m>>1]=c[j+(d[f]<<2)>>2]&65535}}while(0);do{if((g+1|0)>>>0<320){o=f+1|0;if((a[o]|0)==0){break}b[l+2>>1]=i;b[m+2>>1]=c[j+(d[o]<<2)>>2]&65535}}while(0);do{if((g+2|0)>>>0<320){o=f+2|0;if((a[o]|0)==0){break}b[l+4>>1]=i;b[m+4>>1]=c[j+(d[o]<<2)>>2]&65535}}while(0);do{if((g+3|0)>>>0<320){o=f+3|0;if((a[o]|0)==0){break}b[l+6>>1]=i;b[m+6>>1]=c[j+(d[o]<<2)>>2]&65535}}while(0);do{if((g+4|0)>>>0<320){o=f+4|0;if((a[o]|0)==0){break}b[l+8>>1]=i;b[m+8>>1]=c[j+(d[o]<<2)>>2]&65535}}while(0);do{if((g+5|0)>>>0<320){o=f+5|0;if((a[o]|0)==0){break}b[l+10>>1]=i;b[m+10>>1]=c[j+(d[o]<<2)>>2]&65535}}while(0);do{if((g+6|0)>>>0<320){o=f+6|0;if((a[o]|0)==0){break}b[l+12>>1]=i;b[m+12>>1]=c[j+(d[o]<<2)>>2]&65535}}while(0);do{if((g+7|0)>>>0<320){o=f+7|0;if((a[o]|0)==0){break}b[l+14>>1]=i;b[m+14>>1]=c[j+(d[o]<<2)>>2]&65535}}while(0);do{if((g+8|0)>>>0<320){o=f+8|0;if((a[o]|0)==0){break}b[l+16>>1]=i;b[m+16>>1]=c[j+(d[o]<<2)>>2]&65535}}while(0);do{if((g+9|0)>>>0<320){o=f+9|0;if((a[o]|0)==0){break}b[l+18>>1]=i;b[m+18>>1]=c[j+(d[o]<<2)>>2]&65535}}while(0);do{if((g+10|0)>>>0<320){o=f+10|0;if((a[o]|0)==0){break}b[l+20>>1]=i;b[m+20>>1]=c[j+(d[o]<<2)>>2]&65535}}while(0);do{if((g+11|0)>>>0<320){o=f+11|0;if((a[o]|0)==0){break}b[l+22>>1]=i;b[m+22>>1]=c[j+(d[o]<<2)>>2]&65535}}while(0);do{if((g+12|0)>>>0<320){o=f+12|0;if((a[o]|0)==0){break}b[l+24>>1]=i;b[m+24>>1]=c[j+(d[o]<<2)>>2]&65535}}while(0);do{if((g+13|0)>>>0<320){o=f+13|0;if((a[o]|0)==0){break}b[l+26>>1]=i;b[m+26>>1]=c[j+(d[o]<<2)>>2]&65535}}while(0);do{if((g+14|0)>>>0<320){o=f+14|0;if((a[o]|0)==0){break}b[l+28>>1]=i;b[m+28>>1]=c[j+(d[o]<<2)>>2]&65535}}while(0);if((g+15|0)>>>0>=320){break}o=f+15|0;if((a[o]|0)==0){break}b[l+30>>1]=i;b[m+30>>1]=c[j+(d[o]<<2)>>2]&65535}}while(0);p=f+16|0;if((k|0)<=0){break}o=k-1|0;q=e+o|0;if((q|0)<0){break}else{k=o;l=l-640|0;m=m-640|0;n=q;f=p}}c[2385338]=p;return}function dXL(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;f=c[2415164]|0;g=f&65535;h=c[2440386]|0;i=(c[2415150]|0)+9600|0;j=(c[2409606]|0)+9600|0;k=15;l=c[2385338]|0;while(1){do{if((a[l]|0)==0){m=l}else{if((e[j>>1]|0)>(f|0)){m=l;break}b[j>>1]=g;b[i>>1]=c[h+(d[l]<<2)>>2]&65535;m=l}}while(0);do{if((a[m+1|0]|0)==0){n=m}else{o=j+2|0;if((e[o>>1]|0)>(f|0)){n=m;break}b[o>>1]=g;b[i+2>>1]=c[h+(d[l+1|0]<<2)>>2]&65535;n=l}}while(0);do{if((a[n+2|0]|0)==0){p=n}else{o=j+4|0;if((e[o>>1]|0)>(f|0)){p=n;break}b[o>>1]=g;b[i+4>>1]=c[h+(d[l+2|0]<<2)>>2]&65535;p=l}}while(0);do{if((a[p+3|0]|0)==0){q=p}else{o=j+6|0;if((e[o>>1]|0)>(f|0)){q=p;break}b[o>>1]=g;b[i+6>>1]=c[h+(d[l+3|0]<<2)>>2]&65535;q=l}}while(0);do{if((a[q+4|0]|0)==0){r=q}else{o=j+8|0;if((e[o>>1]|0)>(f|0)){r=q;break}b[o>>1]=g;b[i+8>>1]=c[h+(d[l+4|0]<<2)>>2]&65535;r=l}}while(0);do{if((a[r+5|0]|0)==0){s=r}else{o=j+10|0;if((e[o>>1]|0)>(f|0)){s=r;break}b[o>>1]=g;b[i+10>>1]=c[h+(d[l+5|0]<<2)>>2]&65535;s=l}}while(0);do{if((a[s+6|0]|0)==0){t=s}else{o=j+12|0;if((e[o>>1]|0)>(f|0)){t=s;break}b[o>>1]=g;b[i+12>>1]=c[h+(d[l+6|0]<<2)>>2]&65535;t=l}}while(0);do{if((a[t+7|0]|0)==0){u=t}else{o=j+14|0;if((e[o>>1]|0)>(f|0)){u=t;break}b[o>>1]=g;b[i+14>>1]=c[h+(d[l+7|0]<<2)>>2]&65535;u=l}}while(0);do{if((a[u+8|0]|0)==0){v=u}else{o=j+16|0;if((e[o>>1]|0)>(f|0)){v=u;break}b[o>>1]=g;b[i+16>>1]=c[h+(d[l+8|0]<<2)>>2]&65535;v=l}}while(0);do{if((a[v+9|0]|0)==0){w=v}else{o=j+18|0;if((e[o>>1]|0)>(f|0)){w=v;break}b[o>>1]=g;b[i+18>>1]=c[h+(d[l+9|0]<<2)>>2]&65535;w=l}}while(0);do{if((a[w+10|0]|0)==0){x=w}else{o=j+20|0;if((e[o>>1]|0)>(f|0)){x=w;break}b[o>>1]=g;b[i+20>>1]=c[h+(d[l+10|0]<<2)>>2]&65535;x=l}}while(0);do{if((a[x+11|0]|0)==0){y=x}else{o=j+22|0;if((e[o>>1]|0)>(f|0)){y=x;break}b[o>>1]=g;b[i+22>>1]=c[h+(d[l+11|0]<<2)>>2]&65535;y=l}}while(0);do{if((a[y+12|0]|0)==0){z=y}else{o=j+24|0;if((e[o>>1]|0)>(f|0)){z=y;break}b[o>>1]=g;b[i+24>>1]=c[h+(d[l+12|0]<<2)>>2]&65535;z=l}}while(0);do{if((a[z+13|0]|0)==0){A=z}else{o=j+26|0;if((e[o>>1]|0)>(f|0)){A=z;break}b[o>>1]=g;b[i+26>>1]=c[h+(d[l+13|0]<<2)>>2]&65535;A=l}}while(0);do{if((a[A+14|0]|0)==0){B=A}else{o=j+28|0;if((e[o>>1]|0)>(f|0)){B=A;break}b[o>>1]=g;b[i+28>>1]=c[h+(d[l+14|0]<<2)>>2]&65535;B=l}}while(0);do{if((a[B+15|0]|0)==0){C=B}else{o=j+30|0;if((e[o>>1]|0)>(f|0)){C=B;break}b[o>>1]=g;b[i+30>>1]=c[h+(d[l+15|0]<<2)>>2]&65535;C=l}}while(0);D=C+16|0;if((k|0)>0){i=i-640|0;j=j-640|0;k=k-1|0;l=D}else{break}}c[2385338]=D;return}function dXM(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=c[2385456]|0;g=f+15|0;if((g|0)<0){return}h=c[2385468]|0;i=h>>>0<320;j=c[2415164]|0;k=j&65535;l=c[2440386]|0;m=15;n=(c[2409606]|0)+9600|0;o=(c[2415150]|0)+9600|0;p=g;g=c[2385338]|0;while(1){do{if((p|0)<=223){do{if(i){if((a[g]|0)==0){break}if((e[n>>1]|0)>(j|0)){break}b[n>>1]=k;b[o>>1]=c[l+(d[g]<<2)>>2]&65535}}while(0);do{if((h+1|0)>>>0<320){q=g+1|0;if((a[q]|0)==0){break}r=n+2|0;if((e[r>>1]|0)>(j|0)){break}b[r>>1]=k;b[o+2>>1]=c[l+(d[q]<<2)>>2]&65535}}while(0);do{if((h+2|0)>>>0<320){q=g+2|0;if((a[q]|0)==0){break}r=n+4|0;if((e[r>>1]|0)>(j|0)){break}b[r>>1]=k;b[o+4>>1]=c[l+(d[q]<<2)>>2]&65535}}while(0);do{if((h+3|0)>>>0<320){q=g+3|0;if((a[q]|0)==0){break}r=n+6|0;if((e[r>>1]|0)>(j|0)){break}b[r>>1]=k;b[o+6>>1]=c[l+(d[q]<<2)>>2]&65535}}while(0);do{if((h+4|0)>>>0<320){q=g+4|0;if((a[q]|0)==0){break}r=n+8|0;if((e[r>>1]|0)>(j|0)){break}b[r>>1]=k;b[o+8>>1]=c[l+(d[q]<<2)>>2]&65535}}while(0);do{if((h+5|0)>>>0<320){q=g+5|0;if((a[q]|0)==0){break}r=n+10|0;if((e[r>>1]|0)>(j|0)){break}b[r>>1]=k;b[o+10>>1]=c[l+(d[q]<<2)>>2]&65535}}while(0);do{if((h+6|0)>>>0<320){q=g+6|0;if((a[q]|0)==0){break}r=n+12|0;if((e[r>>1]|0)>(j|0)){break}b[r>>1]=k;b[o+12>>1]=c[l+(d[q]<<2)>>2]&65535}}while(0);do{if((h+7|0)>>>0<320){q=g+7|0;if((a[q]|0)==0){break}r=n+14|0;if((e[r>>1]|0)>(j|0)){break}b[r>>1]=k;b[o+14>>1]=c[l+(d[q]<<2)>>2]&65535}}while(0);do{if((h+8|0)>>>0<320){q=g+8|0;if((a[q]|0)==0){break}r=n+16|0;if((e[r>>1]|0)>(j|0)){break}b[r>>1]=k;b[o+16>>1]=c[l+(d[q]<<2)>>2]&65535}}while(0);do{if((h+9|0)>>>0<320){q=g+9|0;if((a[q]|0)==0){break}r=n+18|0;if((e[r>>1]|0)>(j|0)){break}b[r>>1]=k;b[o+18>>1]=c[l+(d[q]<<2)>>2]&65535}}while(0);do{if((h+10|0)>>>0<320){q=g+10|0;if((a[q]|0)==0){break}r=n+20|0;if((e[r>>1]|0)>(j|0)){break}b[r>>1]=k;b[o+20>>1]=c[l+(d[q]<<2)>>2]&65535}}while(0);do{if((h+11|0)>>>0<320){q=g+11|0;if((a[q]|0)==0){break}r=n+22|0;if((e[r>>1]|0)>(j|0)){break}b[r>>1]=k;b[o+22>>1]=c[l+(d[q]<<2)>>2]&65535}}while(0);do{if((h+12|0)>>>0<320){q=g+12|0;if((a[q]|0)==0){break}r=n+24|0;if((e[r>>1]|0)>(j|0)){break}b[r>>1]=k;b[o+24>>1]=c[l+(d[q]<<2)>>2]&65535}}while(0);do{if((h+13|0)>>>0<320){q=g+13|0;if((a[q]|0)==0){break}r=n+26|0;if((e[r>>1]|0)>(j|0)){break}b[r>>1]=k;b[o+26>>1]=c[l+(d[q]<<2)>>2]&65535}}while(0);do{if((h+14|0)>>>0<320){q=g+14|0;if((a[q]|0)==0){break}r=n+28|0;if((e[r>>1]|0)>(j|0)){break}b[r>>1]=k;b[o+28>>1]=c[l+(d[q]<<2)>>2]&65535}}while(0);if((h+15|0)>>>0>=320){break}q=g+15|0;if((a[q]|0)==0){break}r=n+30|0;if((e[r>>1]|0)>(j|0)){break}b[r>>1]=k;b[o+30>>1]=c[l+(d[q]<<2)>>2]&65535}}while(0);s=g+16|0;if((m|0)<=0){break}q=m-1|0;r=f+q|0;if((r|0)<0){break}else{m=q;n=n-640|0;o=o-640|0;p=r;g=s}}c[2385338]=s;return}function dXN(){var d=0,e=0,f=0,g=0,h=0,i=0;d=c[2440386]|0;e=(c[2415150]|0)+9600|0;f=15;g=c[2385338]|0;while(1){h=a[g+15|0]|0;if(h<<24>>24!=0){b[e>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+14|0]|0;if(h<<24>>24!=0){b[e+2>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+13|0]|0;if(h<<24>>24!=0){b[e+4>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+12|0]|0;if(h<<24>>24!=0){b[e+6>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+11|0]|0;if(h<<24>>24!=0){b[e+8>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+10|0]|0;if(h<<24>>24!=0){b[e+10>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+9|0]|0;if(h<<24>>24!=0){b[e+12>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+8|0]|0;if(h<<24>>24!=0){b[e+14>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+7|0]|0;if(h<<24>>24!=0){b[e+16>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+6|0]|0;if(h<<24>>24!=0){b[e+18>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+5|0]|0;if(h<<24>>24!=0){b[e+20>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+4|0]|0;if(h<<24>>24!=0){b[e+22>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+3|0]|0;if(h<<24>>24!=0){b[e+24>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+2|0]|0;if(h<<24>>24!=0){b[e+26>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g+1|0]|0;if(h<<24>>24!=0){b[e+28>>1]=c[d+((h&255)<<2)>>2]&65535}h=a[g]|0;if(h<<24>>24!=0){b[e+30>>1]=c[d+((h&255)<<2)>>2]&65535}i=g+16|0;if((f|0)>0){e=e-640|0;f=f-1|0;g=i}else{break}}c[2385338]=i;return}function dXO(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=c[2385456]|0;e=d+15|0;if((e|0)<0){return}f=c[2385468]|0;g=f>>>0<320;h=c[2440386]|0;i=15;j=(c[2415150]|0)+9600|0;k=e;e=c[2385338]|0;while(1){do{if((k|0)<=223){do{if(g){l=a[e+15|0]|0;if(l<<24>>24==0){break}b[j>>1]=c[h+((l&255)<<2)>>2]&65535}}while(0);do{if((f+1|0)>>>0<320){l=a[e+14|0]|0;if(l<<24>>24==0){break}b[j+2>>1]=c[h+((l&255)<<2)>>2]&65535}}while(0);do{if((f+2|0)>>>0<320){l=a[e+13|0]|0;if(l<<24>>24==0){break}b[j+4>>1]=c[h+((l&255)<<2)>>2]&65535}}while(0);do{if((f+3|0)>>>0<320){l=a[e+12|0]|0;if(l<<24>>24==0){break}b[j+6>>1]=c[h+((l&255)<<2)>>2]&65535}}while(0);do{if((f+4|0)>>>0<320){l=a[e+11|0]|0;if(l<<24>>24==0){break}b[j+8>>1]=c[h+((l&255)<<2)>>2]&65535}}while(0);do{if((f+5|0)>>>0<320){l=a[e+10|0]|0;if(l<<24>>24==0){break}b[j+10>>1]=c[h+((l&255)<<2)>>2]&65535}}while(0);do{if((f+6|0)>>>0<320){l=a[e+9|0]|0;if(l<<24>>24==0){break}b[j+12>>1]=c[h+((l&255)<<2)>>2]&65535}}while(0);do{if((f+7|0)>>>0<320){l=a[e+8|0]|0;if(l<<24>>24==0){break}b[j+14>>1]=c[h+((l&255)<<2)>>2]&65535}}while(0);do{if((f+8|0)>>>0<320){l=a[e+7|0]|0;if(l<<24>>24==0){break}b[j+16>>1]=c[h+((l&255)<<2)>>2]&65535}}while(0);do{if((f+9|0)>>>0<320){l=a[e+6|0]|0;if(l<<24>>24==0){break}b[j+18>>1]=c[h+((l&255)<<2)>>2]&65535}}while(0);do{if((f+10|0)>>>0<320){l=a[e+5|0]|0;if(l<<24>>24==0){break}b[j+20>>1]=c[h+((l&255)<<2)>>2]&65535}}while(0);do{if((f+11|0)>>>0<320){l=a[e+4|0]|0;if(l<<24>>24==0){break}b[j+22>>1]=c[h+((l&255)<<2)>>2]&65535}}while(0);do{if((f+12|0)>>>0<320){l=a[e+3|0]|0;if(l<<24>>24==0){break}b[j+24>>1]=c[h+((l&255)<<2)>>2]&65535}}while(0);do{if((f+13|0)>>>0<320){l=a[e+2|0]|0;if(l<<24>>24==0){break}b[j+26>>1]=c[h+((l&255)<<2)>>2]&65535}}while(0);do{if((f+14|0)>>>0<320){l=a[e+1|0]|0;if(l<<24>>24==0){break}b[j+28>>1]=c[h+((l&255)<<2)>>2]&65535}}while(0);if((f+15|0)>>>0>=320){break}l=a[e]|0;if(l<<24>>24==0){break}b[j+30>>1]=c[h+((l&255)<<2)>>2]&65535}}while(0);m=e+16|0;if((i|0)<=0){break}l=i-1|0;n=d+l|0;if((n|0)<0){break}else{i=l;j=j-640|0;k=n;e=m}}c[2385338]=m;return}function dXP(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;d=c[2415164]|0;f=c[2440386]|0;g=(c[2415150]|0)+9600|0;h=(c[2409606]|0)+9600|0;i=15;j=c[2385338]|0;while(1){k=a[j+15|0]|0;l=k&255;do{if(k<<24>>24==0){m=j}else{if((e[h>>1]|0|0)>(d|0)){m=j;break}b[g>>1]=c[f+(l<<2)>>2]&65535;m=j}}while(0);l=a[m+14|0]|0;k=l&255;do{if(l<<24>>24==0){n=m}else{if((e[h+2>>1]|0|0)>(d|0)){n=m;break}b[g+2>>1]=c[f+(k<<2)>>2]&65535;n=j}}while(0);k=a[n+13|0]|0;l=k&255;do{if(k<<24>>24==0){o=n}else{if((e[h+4>>1]|0|0)>(d|0)){o=n;break}b[g+4>>1]=c[f+(l<<2)>>2]&65535;o=j}}while(0);l=a[o+12|0]|0;k=l&255;do{if(l<<24>>24==0){p=o}else{if((e[h+6>>1]|0|0)>(d|0)){p=o;break}b[g+6>>1]=c[f+(k<<2)>>2]&65535;p=j}}while(0);k=a[p+11|0]|0;l=k&255;do{if(k<<24>>24==0){q=p}else{if((e[h+8>>1]|0|0)>(d|0)){q=p;break}b[g+8>>1]=c[f+(l<<2)>>2]&65535;q=j}}while(0);l=a[q+10|0]|0;k=l&255;do{if(l<<24>>24==0){r=q}else{if((e[h+10>>1]|0|0)>(d|0)){r=q;break}b[g+10>>1]=c[f+(k<<2)>>2]&65535;r=j}}while(0);k=a[r+9|0]|0;l=k&255;do{if(k<<24>>24==0){s=r}else{if((e[h+12>>1]|0|0)>(d|0)){s=r;break}b[g+12>>1]=c[f+(l<<2)>>2]&65535;s=j}}while(0);l=a[s+8|0]|0;k=l&255;do{if(l<<24>>24==0){t=s}else{if((e[h+14>>1]|0|0)>(d|0)){t=s;break}b[g+14>>1]=c[f+(k<<2)>>2]&65535;t=j}}while(0);k=a[t+7|0]|0;l=k&255;do{if(k<<24>>24==0){u=t}else{if((e[h+16>>1]|0|0)>(d|0)){u=t;break}b[g+16>>1]=c[f+(l<<2)>>2]&65535;u=j}}while(0);l=a[u+6|0]|0;k=l&255;do{if(l<<24>>24==0){v=u}else{if((e[h+18>>1]|0|0)>(d|0)){v=u;break}b[g+18>>1]=c[f+(k<<2)>>2]&65535;v=j}}while(0);k=a[v+5|0]|0;l=k&255;do{if(k<<24>>24==0){w=v}else{if((e[h+20>>1]|0|0)>(d|0)){w=v;break}b[g+20>>1]=c[f+(l<<2)>>2]&65535;w=j}}while(0);l=a[w+4|0]|0;k=l&255;do{if(l<<24>>24==0){x=w}else{if((e[h+22>>1]|0|0)>(d|0)){x=w;break}b[g+22>>1]=c[f+(k<<2)>>2]&65535;x=j}}while(0);k=a[x+3|0]|0;l=k&255;do{if(k<<24>>24==0){y=x}else{if((e[h+24>>1]|0|0)>(d|0)){y=x;break}b[g+24>>1]=c[f+(l<<2)>>2]&65535;y=j}}while(0);l=a[y+2|0]|0;k=l&255;do{if(l<<24>>24==0){z=y}else{if((e[h+26>>1]|0|0)>(d|0)){z=y;break}b[g+26>>1]=c[f+(k<<2)>>2]&65535;z=j}}while(0);k=a[z+1|0]|0;l=k&255;do{if(k<<24>>24==0){A=z}else{if((e[h+28>>1]|0|0)>(d|0)){A=z;break}b[g+28>>1]=c[f+(l<<2)>>2]&65535;A=j}}while(0);l=a[A]|0;k=l&255;do{if(l<<24>>24==0){B=A}else{if((e[h+30>>1]|0|0)>(d|0)){B=A;break}b[g+30>>1]=c[f+(k<<2)>>2]&65535;B=j}}while(0);C=B+16|0;if((i|0)>0){g=g-640|0;h=h-640|0;i=i-1|0;j=C}else{break}}c[2385338]=C;return}function dXQ(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=c[2385456]|0;f=d+15|0;if((f|0)<0){return}g=c[2385468]|0;h=g>>>0<320;i=c[2415164]|0;j=c[2440386]|0;k=15;l=(c[2409606]|0)+9600|0;m=(c[2415150]|0)+9600|0;n=f;f=c[2385338]|0;while(1){do{if((n|0)<=223){do{if(h){o=a[f+15|0]|0;if(o<<24>>24==0){break}if((e[l>>1]|0|0)>(i|0)){break}b[m>>1]=c[j+((o&255)<<2)>>2]&65535}}while(0);do{if((g+1|0)>>>0<320){o=a[f+14|0]|0;if(o<<24>>24==0){break}if((e[l+2>>1]|0|0)>(i|0)){break}b[m+2>>1]=c[j+((o&255)<<2)>>2]&65535}}while(0);do{if((g+2|0)>>>0<320){o=a[f+13|0]|0;if(o<<24>>24==0){break}if((e[l+4>>1]|0|0)>(i|0)){break}b[m+4>>1]=c[j+((o&255)<<2)>>2]&65535}}while(0);do{if((g+3|0)>>>0<320){o=a[f+12|0]|0;if(o<<24>>24==0){break}if((e[l+6>>1]|0|0)>(i|0)){break}b[m+6>>1]=c[j+((o&255)<<2)>>2]&65535}}while(0);do{if((g+4|0)>>>0<320){o=a[f+11|0]|0;if(o<<24>>24==0){break}if((e[l+8>>1]|0|0)>(i|0)){break}b[m+8>>1]=c[j+((o&255)<<2)>>2]&65535}}while(0);do{if((g+5|0)>>>0<320){o=a[f+10|0]|0;if(o<<24>>24==0){break}if((e[l+10>>1]|0|0)>(i|0)){break}b[m+10>>1]=c[j+((o&255)<<2)>>2]&65535}}while(0);do{if((g+6|0)>>>0<320){o=a[f+9|0]|0;if(o<<24>>24==0){break}if((e[l+12>>1]|0|0)>(i|0)){break}b[m+12>>1]=c[j+((o&255)<<2)>>2]&65535}}while(0);do{if((g+7|0)>>>0<320){o=a[f+8|0]|0;if(o<<24>>24==0){break}if((e[l+14>>1]|0|0)>(i|0)){break}b[m+14>>1]=c[j+((o&255)<<2)>>2]&65535}}while(0);do{if((g+8|0)>>>0<320){o=a[f+7|0]|0;if(o<<24>>24==0){break}if((e[l+16>>1]|0|0)>(i|0)){break}b[m+16>>1]=c[j+((o&255)<<2)>>2]&65535}}while(0);do{if((g+9|0)>>>0<320){o=a[f+6|0]|0;if(o<<24>>24==0){break}if((e[l+18>>1]|0|0)>(i|0)){break}b[m+18>>1]=c[j+((o&255)<<2)>>2]&65535}}while(0);do{if((g+10|0)>>>0<320){o=a[f+5|0]|0;if(o<<24>>24==0){break}if((e[l+20>>1]|0|0)>(i|0)){break}b[m+20>>1]=c[j+((o&255)<<2)>>2]&65535}}while(0);do{if((g+11|0)>>>0<320){o=a[f+4|0]|0;if(o<<24>>24==0){break}if((e[l+22>>1]|0|0)>(i|0)){break}b[m+22>>1]=c[j+((o&255)<<2)>>2]&65535}}while(0);do{if((g+12|0)>>>0<320){o=a[f+3|0]|0;if(o<<24>>24==0){break}if((e[l+24>>1]|0|0)>(i|0)){break}b[m+24>>1]=c[j+((o&255)<<2)>>2]&65535}}while(0);do{if((g+13|0)>>>0<320){o=a[f+2|0]|0;if(o<<24>>24==0){break}if((e[l+26>>1]|0|0)>(i|0)){break}b[m+26>>1]=c[j+((o&255)<<2)>>2]&65535}}while(0);do{if((g+14|0)>>>0<320){o=a[f+1|0]|0;if(o<<24>>24==0){break}if((e[l+28>>1]|0|0)>(i|0)){break}b[m+28>>1]=c[j+((o&255)<<2)>>2]&65535}}while(0);if((g+15|0)>>>0>=320){break}o=a[f]|0;if(o<<24>>24==0){break}if((e[l+30>>1]|0|0)>(i|0)){break}b[m+30>>1]=c[j+((o&255)<<2)>>2]&65535}}while(0);p=f+16|0;if((k|0)<=0){break}o=k-1|0;q=d+o|0;if((q|0)<0){break}else{k=o;l=l-640|0;m=m-640|0;n=q;f=p}}c[2385338]=p;return}function dXR(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=c[2415164]&65535;f=c[2440386]|0;g=(c[2415150]|0)+9600|0;h=(c[2409606]|0)+9600|0;i=15;j=c[2385338]|0;while(1){if((a[j+15|0]|0)!=0){b[h>>1]=e;b[g>>1]=c[f+(d[j+15|0]<<2)>>2]&65535}if((a[j+14|0]|0)!=0){b[h+2>>1]=e;b[g+2>>1]=c[f+(d[j+14|0]<<2)>>2]&65535}if((a[j+13|0]|0)!=0){b[h+4>>1]=e;b[g+4>>1]=c[f+(d[j+13|0]<<2)>>2]&65535}if((a[j+12|0]|0)!=0){b[h+6>>1]=e;b[g+6>>1]=c[f+(d[j+12|0]<<2)>>2]&65535}if((a[j+11|0]|0)!=0){b[h+8>>1]=e;b[g+8>>1]=c[f+(d[j+11|0]<<2)>>2]&65535}if((a[j+10|0]|0)!=0){b[h+10>>1]=e;b[g+10>>1]=c[f+(d[j+10|0]<<2)>>2]&65535}if((a[j+9|0]|0)!=0){b[h+12>>1]=e;b[g+12>>1]=c[f+(d[j+9|0]<<2)>>2]&65535}if((a[j+8|0]|0)!=0){b[h+14>>1]=e;b[g+14>>1]=c[f+(d[j+8|0]<<2)>>2]&65535}if((a[j+7|0]|0)!=0){b[h+16>>1]=e;b[g+16>>1]=c[f+(d[j+7|0]<<2)>>2]&65535}if((a[j+6|0]|0)!=0){b[h+18>>1]=e;b[g+18>>1]=c[f+(d[j+6|0]<<2)>>2]&65535}if((a[j+5|0]|0)!=0){b[h+20>>1]=e;b[g+20>>1]=c[f+(d[j+5|0]<<2)>>2]&65535}if((a[j+4|0]|0)!=0){b[h+22>>1]=e;b[g+22>>1]=c[f+(d[j+4|0]<<2)>>2]&65535}if((a[j+3|0]|0)!=0){b[h+24>>1]=e;b[g+24>>1]=c[f+(d[j+3|0]<<2)>>2]&65535}if((a[j+2|0]|0)!=0){b[h+26>>1]=e;b[g+26>>1]=c[f+(d[j+2|0]<<2)>>2]&65535}if((a[j+1|0]|0)!=0){b[h+28>>1]=e;b[g+28>>1]=c[f+(d[j+1|0]<<2)>>2]&65535}if((a[j]|0)!=0){b[h+30>>1]=e;b[g+30>>1]=c[f+(d[j]<<2)>>2]&65535}k=j+16|0;if((i|0)>0){g=g-640|0;h=h-640|0;i=i-1|0;j=k}else{break}}c[2385338]=k;return}function dXS(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=c[2385456]|0;f=e+15|0;if((f|0)<0){return}g=c[2385468]|0;h=g>>>0<320;i=c[2415164]&65535;j=c[2440386]|0;k=15;l=(c[2409606]|0)+9600|0;m=(c[2415150]|0)+9600|0;n=f;f=c[2385338]|0;while(1){do{if((n|0)<=223){do{if(h){o=f+15|0;if((a[o]|0)==0){break}b[l>>1]=i;b[m>>1]=c[j+(d[o]<<2)>>2]&65535}}while(0);do{if((g+1|0)>>>0<320){o=f+14|0;if((a[o]|0)==0){break}b[l+2>>1]=i;b[m+2>>1]=c[j+(d[o]<<2)>>2]&65535}}while(0);do{if((g+2|0)>>>0<320){o=f+13|0;if((a[o]|0)==0){break}b[l+4>>1]=i;b[m+4>>1]=c[j+(d[o]<<2)>>2]&65535}}while(0);do{if((g+3|0)>>>0<320){o=f+12|0;if((a[o]|0)==0){break}b[l+6>>1]=i;b[m+6>>1]=c[j+(d[o]<<2)>>2]&65535}}while(0);do{if((g+4|0)>>>0<320){o=f+11|0;if((a[o]|0)==0){break}b[l+8>>1]=i;b[m+8>>1]=c[j+(d[o]<<2)>>2]&65535}}while(0);do{if((g+5|0)>>>0<320){o=f+10|0;if((a[o]|0)==0){break}b[l+10>>1]=i;b[m+10>>1]=c[j+(d[o]<<2)>>2]&65535}}while(0);do{if((g+6|0)>>>0<320){o=f+9|0;if((a[o]|0)==0){break}b[l+12>>1]=i;b[m+12>>1]=c[j+(d[o]<<2)>>2]&65535}}while(0);do{if((g+7|0)>>>0<320){o=f+8|0;if((a[o]|0)==0){break}b[l+14>>1]=i;b[m+14>>1]=c[j+(d[o]<<2)>>2]&65535}}while(0);do{if((g+8|0)>>>0<320){o=f+7|0;if((a[o]|0)==0){break}b[l+16>>1]=i;b[m+16>>1]=c[j+(d[o]<<2)>>2]&65535}}while(0);do{if((g+9|0)>>>0<320){o=f+6|0;if((a[o]|0)==0){break}b[l+18>>1]=i;b[m+18>>1]=c[j+(d[o]<<2)>>2]&65535}}while(0);do{if((g+10|0)>>>0<320){o=f+5|0;if((a[o]|0)==0){break}b[l+20>>1]=i;b[m+20>>1]=c[j+(d[o]<<2)>>2]&65535}}while(0);do{if((g+11|0)>>>0<320){o=f+4|0;if((a[o]|0)==0){break}b[l+22>>1]=i;b[m+22>>1]=c[j+(d[o]<<2)>>2]&65535}}while(0);do{if((g+12|0)>>>0<320){o=f+3|0;if((a[o]|0)==0){break}b[l+24>>1]=i;b[m+24>>1]=c[j+(d[o]<<2)>>2]&65535}}while(0);do{if((g+13|0)>>>0<320){o=f+2|0;if((a[o]|0)==0){break}b[l+26>>1]=i;b[m+26>>1]=c[j+(d[o]<<2)>>2]&65535}}while(0);do{if((g+14|0)>>>0<320){o=f+1|0;if((a[o]|0)==0){break}b[l+28>>1]=i;b[m+28>>1]=c[j+(d[o]<<2)>>2]&65535}}while(0);if((g+15|0)>>>0>=320){break}if((a[f]|0)==0){break}b[l+30>>1]=i;b[m+30>>1]=c[j+(d[f]<<2)>>2]&65535}}while(0);p=f+16|0;if((k|0)<=0){break}o=k-1|0;q=e+o|0;if((q|0)<0){break}else{k=o;l=l-640|0;m=m-640|0;n=q;f=p}}c[2385338]=p;return}function dXT(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;f=c[2415164]|0;g=f&65535;h=c[2440386]|0;i=(c[2415150]|0)+9600|0;j=(c[2409606]|0)+9600|0;k=15;l=c[2385338]|0;while(1){do{if((a[l+15|0]|0)==0){m=l}else{if((e[j>>1]|0)>(f|0)){m=l;break}b[j>>1]=g;b[i>>1]=c[h+(d[l+15|0]<<2)>>2]&65535;m=l}}while(0);do{if((a[m+14|0]|0)==0){n=m}else{o=j+2|0;if((e[o>>1]|0)>(f|0)){n=m;break}b[o>>1]=g;b[i+2>>1]=c[h+(d[l+14|0]<<2)>>2]&65535;n=l}}while(0);do{if((a[n+13|0]|0)==0){p=n}else{o=j+4|0;if((e[o>>1]|0)>(f|0)){p=n;break}b[o>>1]=g;b[i+4>>1]=c[h+(d[l+13|0]<<2)>>2]&65535;p=l}}while(0);do{if((a[p+12|0]|0)==0){q=p}else{o=j+6|0;if((e[o>>1]|0)>(f|0)){q=p;break}b[o>>1]=g;b[i+6>>1]=c[h+(d[l+12|0]<<2)>>2]&65535;q=l}}while(0);do{if((a[q+11|0]|0)==0){r=q}else{o=j+8|0;if((e[o>>1]|0)>(f|0)){r=q;break}b[o>>1]=g;b[i+8>>1]=c[h+(d[l+11|0]<<2)>>2]&65535;r=l}}while(0);do{if((a[r+10|0]|0)==0){s=r}else{o=j+10|0;if((e[o>>1]|0)>(f|0)){s=r;break}b[o>>1]=g;b[i+10>>1]=c[h+(d[l+10|0]<<2)>>2]&65535;s=l}}while(0);do{if((a[s+9|0]|0)==0){t=s}else{o=j+12|0;if((e[o>>1]|0)>(f|0)){t=s;break}b[o>>1]=g;b[i+12>>1]=c[h+(d[l+9|0]<<2)>>2]&65535;t=l}}while(0);do{if((a[t+8|0]|0)==0){u=t}else{o=j+14|0;if((e[o>>1]|0)>(f|0)){u=t;break}b[o>>1]=g;b[i+14>>1]=c[h+(d[l+8|0]<<2)>>2]&65535;u=l}}while(0);do{if((a[u+7|0]|0)==0){v=u}else{o=j+16|0;if((e[o>>1]|0)>(f|0)){v=u;break}b[o>>1]=g;b[i+16>>1]=c[h+(d[l+7|0]<<2)>>2]&65535;v=l}}while(0);do{if((a[v+6|0]|0)==0){w=v}else{o=j+18|0;if((e[o>>1]|0)>(f|0)){w=v;break}b[o>>1]=g;b[i+18>>1]=c[h+(d[l+6|0]<<2)>>2]&65535;w=l}}while(0);do{if((a[w+5|0]|0)==0){x=w}else{o=j+20|0;if((e[o>>1]|0)>(f|0)){x=w;break}b[o>>1]=g;b[i+20>>1]=c[h+(d[l+5|0]<<2)>>2]&65535;x=l}}while(0);do{if((a[x+4|0]|0)==0){y=x}else{o=j+22|0;if((e[o>>1]|0)>(f|0)){y=x;break}b[o>>1]=g;b[i+22>>1]=c[h+(d[l+4|0]<<2)>>2]&65535;y=l}}while(0);do{if((a[y+3|0]|0)==0){z=y}else{o=j+24|0;if((e[o>>1]|0)>(f|0)){z=y;break}b[o>>1]=g;b[i+24>>1]=c[h+(d[l+3|0]<<2)>>2]&65535;z=l}}while(0);do{if((a[z+2|0]|0)==0){A=z}else{o=j+26|0;if((e[o>>1]|0)>(f|0)){A=z;break}b[o>>1]=g;b[i+26>>1]=c[h+(d[l+2|0]<<2)>>2]&65535;A=l}}while(0);do{if((a[A+1|0]|0)==0){B=A}else{o=j+28|0;if((e[o>>1]|0)>(f|0)){B=A;break}b[o>>1]=g;b[i+28>>1]=c[h+(d[l+1|0]<<2)>>2]&65535;B=l}}while(0);do{if((a[B]|0)==0){C=B}else{o=j+30|0;if((e[o>>1]|0)>(f|0)){C=B;break}b[o>>1]=g;b[i+30>>1]=c[h+(d[l]<<2)>>2]&65535;C=l}}while(0);D=C+16|0;if((k|0)>0){i=i-640|0;j=j-640|0;k=k-1|0;l=D}else{break}}c[2385338]=D;return}function dXU(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=c[2385456]|0;g=f+15|0;if((g|0)<0){return}h=c[2385468]|0;i=h>>>0<320;j=c[2415164]|0;k=j&65535;l=c[2440386]|0;m=15;n=(c[2409606]|0)+9600|0;o=(c[2415150]|0)+9600|0;p=g;g=c[2385338]|0;while(1){do{if((p|0)<=223){do{if(i){q=g+15|0;if((a[q]|0)==0){break}if((e[n>>1]|0)>(j|0)){break}b[n>>1]=k;b[o>>1]=c[l+(d[q]<<2)>>2]&65535}}while(0);do{if((h+1|0)>>>0<320){q=g+14|0;if((a[q]|0)==0){break}r=n+2|0;if((e[r>>1]|0)>(j|0)){break}b[r>>1]=k;b[o+2>>1]=c[l+(d[q]<<2)>>2]&65535}}while(0);do{if((h+2|0)>>>0<320){q=g+13|0;if((a[q]|0)==0){break}r=n+4|0;if((e[r>>1]|0)>(j|0)){break}b[r>>1]=k;b[o+4>>1]=c[l+(d[q]<<2)>>2]&65535}}while(0);do{if((h+3|0)>>>0<320){q=g+12|0;if((a[q]|0)==0){break}r=n+6|0;if((e[r>>1]|0)>(j|0)){break}b[r>>1]=k;b[o+6>>1]=c[l+(d[q]<<2)>>2]&65535}}while(0);do{if((h+4|0)>>>0<320){q=g+11|0;if((a[q]|0)==0){break}r=n+8|0;if((e[r>>1]|0)>(j|0)){break}b[r>>1]=k;b[o+8>>1]=c[l+(d[q]<<2)>>2]&65535}}while(0);do{if((h+5|0)>>>0<320){q=g+10|0;if((a[q]|0)==0){break}r=n+10|0;if((e[r>>1]|0)>(j|0)){break}b[r>>1]=k;b[o+10>>1]=c[l+(d[q]<<2)>>2]&65535}}while(0);do{if((h+6|0)>>>0<320){q=g+9|0;if((a[q]|0)==0){break}r=n+12|0;if((e[r>>1]|0)>(j|0)){break}b[r>>1]=k;b[o+12>>1]=c[l+(d[q]<<2)>>2]&65535}}while(0);do{if((h+7|0)>>>0<320){q=g+8|0;if((a[q]|0)==0){break}r=n+14|0;if((e[r>>1]|0)>(j|0)){break}b[r>>1]=k;b[o+14>>1]=c[l+(d[q]<<2)>>2]&65535}}while(0);do{if((h+8|0)>>>0<320){q=g+7|0;if((a[q]|0)==0){break}r=n+16|0;if((e[r>>1]|0)>(j|0)){break}b[r>>1]=k;b[o+16>>1]=c[l+(d[q]<<2)>>2]&65535}}while(0);do{if((h+9|0)>>>0<320){q=g+6|0;if((a[q]|0)==0){break}r=n+18|0;if((e[r>>1]|0)>(j|0)){break}b[r>>1]=k;b[o+18>>1]=c[l+(d[q]<<2)>>2]&65535}}while(0);do{if((h+10|0)>>>0<320){q=g+5|0;if((a[q]|0)==0){break}r=n+20|0;if((e[r>>1]|0)>(j|0)){break}b[r>>1]=k;b[o+20>>1]=c[l+(d[q]<<2)>>2]&65535}}while(0);do{if((h+11|0)>>>0<320){q=g+4|0;if((a[q]|0)==0){break}r=n+22|0;if((e[r>>1]|0)>(j|0)){break}b[r>>1]=k;b[o+22>>1]=c[l+(d[q]<<2)>>2]&65535}}while(0);do{if((h+12|0)>>>0<320){q=g+3|0;if((a[q]|0)==0){break}r=n+24|0;if((e[r>>1]|0)>(j|0)){break}b[r>>1]=k;b[o+24>>1]=c[l+(d[q]<<2)>>2]&65535}}while(0);do{if((h+13|0)>>>0<320){q=g+2|0;if((a[q]|0)==0){break}r=n+26|0;if((e[r>>1]|0)>(j|0)){break}b[r>>1]=k;b[o+26>>1]=c[l+(d[q]<<2)>>2]&65535}}while(0);do{if((h+14|0)>>>0<320){q=g+1|0;if((a[q]|0)==0){break}r=n+28|0;if((e[r>>1]|0)>(j|0)){break}b[r>>1]=k;b[o+28>>1]=c[l+(d[q]<<2)>>2]&65535}}while(0);if((h+15|0)>>>0>=320){break}if((a[g]|0)==0){break}q=n+30|0;if((e[q>>1]|0)>(j|0)){break}b[q>>1]=k;b[o+30>>1]=c[l+(d[g]<<2)>>2]&65535}}while(0);s=g+16|0;if((m|0)<=0){break}q=m-1|0;r=f+q|0;if((r|0)<0){break}else{m=q;n=n-640|0;o=o-640|0;p=r;g=s}}c[2385338]=s;return}function dXV(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=c[3528502]|0;if((d|0)<=0){return}e=c[3528424]|0;f=c[3528504]|0;g=(f|0)<9;h=c[3528422]|0;i=e+32|0;j=e+36|0;k=e+40|0;l=e+44|0;m=e+48|0;n=e+52|0;o=e+56|0;p=e+60|0;q=c[2440386]|0;r=c[2415150]|0;s=0;t=c[2385338]|0;while(1){u=a[t+(c[e>>2]|0)|0]|0;if(u<<24>>24!=0){b[r>>1]=c[q+((u&255)<<2)>>2]&65535}u=a[t+(c[e+4>>2]|0)|0]|0;if(u<<24>>24!=0){b[r+2>>1]=c[q+((u&255)<<2)>>2]&65535}u=a[t+(c[e+8>>2]|0)|0]|0;if(u<<24>>24!=0){b[r+4>>1]=c[q+((u&255)<<2)>>2]&65535}u=a[t+(c[e+12>>2]|0)|0]|0;if(u<<24>>24!=0){b[r+6>>1]=c[q+((u&255)<<2)>>2]&65535}u=a[t+(c[e+16>>2]|0)|0]|0;if(u<<24>>24!=0){b[r+8>>1]=c[q+((u&255)<<2)>>2]&65535}u=a[t+(c[e+20>>2]|0)|0]|0;if(u<<24>>24!=0){b[r+10>>1]=c[q+((u&255)<<2)>>2]&65535}u=a[t+(c[e+24>>2]|0)|0]|0;if(u<<24>>24!=0){b[r+12>>1]=c[q+((u&255)<<2)>>2]&65535}u=a[t+(c[e+28>>2]|0)|0]|0;if(u<<24>>24!=0){b[r+14>>1]=c[q+((u&255)<<2)>>2]&65535}do{if(!g){u=a[t+(c[i>>2]|0)|0]|0;if(u<<24>>24!=0){b[r+16>>1]=c[q+((u&255)<<2)>>2]&65535}if((f|0)<10){break}u=a[t+(c[j>>2]|0)|0]|0;if(u<<24>>24!=0){b[r+18>>1]=c[q+((u&255)<<2)>>2]&65535}if((f|0)<11){break}u=a[t+(c[k>>2]|0)|0]|0;if(u<<24>>24!=0){b[r+20>>1]=c[q+((u&255)<<2)>>2]&65535}if((f|0)<12){break}u=a[t+(c[l>>2]|0)|0]|0;if(u<<24>>24!=0){b[r+22>>1]=c[q+((u&255)<<2)>>2]&65535}if((f|0)<13){break}u=a[t+(c[m>>2]|0)|0]|0;if(u<<24>>24!=0){b[r+24>>1]=c[q+((u&255)<<2)>>2]&65535}if((f|0)<14){break}u=a[t+(c[n>>2]|0)|0]|0;if(u<<24>>24!=0){b[r+26>>1]=c[q+((u&255)<<2)>>2]&65535}if((f|0)<15){break}u=a[t+(c[o>>2]|0)|0]|0;if(u<<24>>24!=0){b[r+28>>1]=c[q+((u&255)<<2)>>2]&65535}if((f|0)<16){break}u=a[t+(c[p>>2]|0)|0]|0;if(u<<24>>24==0){break}b[r+30>>1]=c[q+((u&255)<<2)>>2]&65535}}while(0);v=t+(c[h+(s<<2)>>2]|0)|0;u=s+1|0;if((u|0)>=(d|0)){break}r=r+640|0;s=u;t=v}c[2385338]=v;return}function dXW(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;d=c[3528502]|0;if((d|0)<=0){return}e=c[2385456]|0;f=c[3528422]|0;g=c[2385468]|0;h=g>>>0<320;i=c[3528424]|0;j=c[2440386]|0;k=i+4|0;l=i+8|0;m=i+12|0;n=i+16|0;o=i+20|0;p=i+24|0;q=i+28|0;r=c[3528504]|0;s=(r|0)<9;t=(g+8|0)>>>0<320;u=i+32|0;v=(g+9|0)>>>0<320;w=i+36|0;x=(g+10|0)>>>0<320;y=i+40|0;z=(g+11|0)>>>0<320;A=i+44|0;B=(g+12|0)>>>0<320;C=i+48|0;D=(g+13|0)>>>0<320;E=i+52|0;F=(g+14|0)>>>0<320;G=i+56|0;H=(g+15|0)>>>0<320;I=i+60|0;J=c[2415150]|0;K=0;L42995:while(1){L=e+K|0;do{if((L|0)>=0){if((L|0)>223){M=32610;break L42995}do{if(h){N=a[(c[2385338]|0)+(c[i>>2]|0)|0]|0;if(N<<24>>24==0){break}b[J>>1]=c[j+((N&255)<<2)>>2]&65535}}while(0);do{if((g+1|0)>>>0<320){N=a[(c[2385338]|0)+(c[k>>2]|0)|0]|0;if(N<<24>>24==0){break}b[J+2>>1]=c[j+((N&255)<<2)>>2]&65535}}while(0);do{if((g+2|0)>>>0<320){N=a[(c[2385338]|0)+(c[l>>2]|0)|0]|0;if(N<<24>>24==0){break}b[J+4>>1]=c[j+((N&255)<<2)>>2]&65535}}while(0);do{if((g+3|0)>>>0<320){N=a[(c[2385338]|0)+(c[m>>2]|0)|0]|0;if(N<<24>>24==0){break}b[J+6>>1]=c[j+((N&255)<<2)>>2]&65535}}while(0);do{if((g+4|0)>>>0<320){N=a[(c[2385338]|0)+(c[n>>2]|0)|0]|0;if(N<<24>>24==0){break}b[J+8>>1]=c[j+((N&255)<<2)>>2]&65535}}while(0);do{if((g+5|0)>>>0<320){N=a[(c[2385338]|0)+(c[o>>2]|0)|0]|0;if(N<<24>>24==0){break}b[J+10>>1]=c[j+((N&255)<<2)>>2]&65535}}while(0);do{if((g+6|0)>>>0<320){N=a[(c[2385338]|0)+(c[p>>2]|0)|0]|0;if(N<<24>>24==0){break}b[J+12>>1]=c[j+((N&255)<<2)>>2]&65535}}while(0);do{if((g+7|0)>>>0<320){N=a[(c[2385338]|0)+(c[q>>2]|0)|0]|0;if(N<<24>>24==0){break}b[J+14>>1]=c[j+((N&255)<<2)>>2]&65535}}while(0);if(s){break}do{if(t){N=a[(c[2385338]|0)+(c[u>>2]|0)|0]|0;if(N<<24>>24==0){break}b[J+16>>1]=c[j+((N&255)<<2)>>2]&65535}}while(0);if((r|0)<10){break}do{if(v){N=a[(c[2385338]|0)+(c[w>>2]|0)|0]|0;if(N<<24>>24==0){break}b[J+18>>1]=c[j+((N&255)<<2)>>2]&65535}}while(0);if((r|0)<11){break}do{if(x){N=a[(c[2385338]|0)+(c[y>>2]|0)|0]|0;if(N<<24>>24==0){break}b[J+20>>1]=c[j+((N&255)<<2)>>2]&65535}}while(0);if((r|0)<12){break}do{if(z){N=a[(c[2385338]|0)+(c[A>>2]|0)|0]|0;if(N<<24>>24==0){break}b[J+22>>1]=c[j+((N&255)<<2)>>2]&65535}}while(0);if((r|0)<13){break}do{if(B){N=a[(c[2385338]|0)+(c[C>>2]|0)|0]|0;if(N<<24>>24==0){break}b[J+24>>1]=c[j+((N&255)<<2)>>2]&65535}}while(0);if((r|0)<14){break}do{if(D){N=a[(c[2385338]|0)+(c[E>>2]|0)|0]|0;if(N<<24>>24==0){break}b[J+26>>1]=c[j+((N&255)<<2)>>2]&65535}}while(0);if((r|0)<15){break}do{if(F){N=a[(c[2385338]|0)+(c[G>>2]|0)|0]|0;if(N<<24>>24==0){break}b[J+28>>1]=c[j+((N&255)<<2)>>2]&65535}}while(0);if((r|0)<16|H^1){break}N=a[(c[2385338]|0)+(c[I>>2]|0)|0]|0;if(N<<24>>24==0){break}b[J+30>>1]=c[j+((N&255)<<2)>>2]&65535}}while(0);c[2385338]=(c[2385338]|0)+(c[f+(K<<2)>>2]|0);L=K+1|0;if((L|0)>=(d|0)){M=32609;break}J=J+640|0;K=L}if((M|0)==32610){return}else if((M|0)==32609){return}}function dXX(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;d=c[3528502]|0;if((d|0)<=0){return}f=c[3528424]|0;g=c[3528504]|0;h=(g|0)<9;i=c[3528422]|0;j=f+32|0;k=f+36|0;l=f+40|0;m=f+44|0;n=f+48|0;o=f+52|0;p=f+56|0;q=f+60|0;r=c[2415164]|0;s=c[2440386]|0;t=c[2415150]|0;u=c[2409606]|0;v=0;w=c[2385338]|0;while(1){x=a[w+(c[f>>2]|0)|0]|0;y=x&255;do{if(x<<24>>24==0){z=w}else{if((e[u>>1]|0|0)>(r|0)){z=w;break}b[t>>1]=c[s+(y<<2)>>2]&65535;z=w}}while(0);y=a[z+(c[f+4>>2]|0)|0]|0;x=y&255;do{if(y<<24>>24==0){A=z}else{if((e[u+2>>1]|0|0)>(r|0)){A=z;break}b[t+2>>1]=c[s+(x<<2)>>2]&65535;A=w}}while(0);x=a[A+(c[f+8>>2]|0)|0]|0;y=x&255;do{if(x<<24>>24==0){B=A}else{if((e[u+4>>1]|0|0)>(r|0)){B=A;break}b[t+4>>1]=c[s+(y<<2)>>2]&65535;B=w}}while(0);y=a[B+(c[f+12>>2]|0)|0]|0;x=y&255;do{if(y<<24>>24==0){C=B}else{if((e[u+6>>1]|0|0)>(r|0)){C=B;break}b[t+6>>1]=c[s+(x<<2)>>2]&65535;C=w}}while(0);x=a[C+(c[f+16>>2]|0)|0]|0;y=x&255;do{if(x<<24>>24==0){D=C}else{if((e[u+8>>1]|0|0)>(r|0)){D=C;break}b[t+8>>1]=c[s+(y<<2)>>2]&65535;D=w}}while(0);y=a[D+(c[f+20>>2]|0)|0]|0;x=y&255;do{if(y<<24>>24==0){E=D}else{if((e[u+10>>1]|0|0)>(r|0)){E=D;break}b[t+10>>1]=c[s+(x<<2)>>2]&65535;E=w}}while(0);x=a[E+(c[f+24>>2]|0)|0]|0;y=x&255;do{if(x<<24>>24==0){F=E}else{if((e[u+12>>1]|0|0)>(r|0)){F=E;break}b[t+12>>1]=c[s+(y<<2)>>2]&65535;F=w}}while(0);y=a[F+(c[f+28>>2]|0)|0]|0;x=y&255;do{if(y<<24>>24!=0){if((e[u+14>>1]|0|0)>(r|0)){break}b[t+14>>1]=c[s+(x<<2)>>2]&65535}}while(0);do{if(!h){x=a[w+(c[j>>2]|0)|0]|0;y=x&255;do{if(x<<24>>24!=0){if((e[u+16>>1]|0|0)>(r|0)){break}b[t+16>>1]=c[s+(y<<2)>>2]&65535}}while(0);if((g|0)<10){break}y=a[w+(c[k>>2]|0)|0]|0;x=y&255;do{if(y<<24>>24!=0){if((e[u+18>>1]|0|0)>(r|0)){break}b[t+18>>1]=c[s+(x<<2)>>2]&65535}}while(0);if((g|0)<11){break}x=a[w+(c[l>>2]|0)|0]|0;y=x&255;do{if(x<<24>>24!=0){if((e[u+20>>1]|0|0)>(r|0)){break}b[t+20>>1]=c[s+(y<<2)>>2]&65535}}while(0);if((g|0)<12){break}y=a[w+(c[m>>2]|0)|0]|0;x=y&255;do{if(y<<24>>24!=0){if((e[u+22>>1]|0|0)>(r|0)){break}b[t+22>>1]=c[s+(x<<2)>>2]&65535}}while(0);if((g|0)<13){break}x=a[w+(c[n>>2]|0)|0]|0;y=x&255;do{if(x<<24>>24!=0){if((e[u+24>>1]|0|0)>(r|0)){break}b[t+24>>1]=c[s+(y<<2)>>2]&65535}}while(0);if((g|0)<14){break}y=a[w+(c[o>>2]|0)|0]|0;x=y&255;do{if(y<<24>>24!=0){if((e[u+26>>1]|0|0)>(r|0)){break}b[t+26>>1]=c[s+(x<<2)>>2]&65535}}while(0);if((g|0)<15){break}x=a[w+(c[p>>2]|0)|0]|0;y=x&255;do{if(x<<24>>24!=0){if((e[u+28>>1]|0|0)>(r|0)){break}b[t+28>>1]=c[s+(y<<2)>>2]&65535}}while(0);if((g|0)<16){break}y=a[w+(c[q>>2]|0)|0]|0;if(y<<24>>24==0){break}if((e[u+30>>1]|0|0)>(r|0)){break}b[t+30>>1]=c[s+((y&255)<<2)>>2]&65535}}while(0);G=w+(c[i+(v<<2)>>2]|0)|0;y=v+1|0;if((y|0)>=(d|0)){break}t=t+640|0;u=u+640|0;v=y;w=G}c[2385338]=G;return}function dXY(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;d=c[3528502]|0;if((d|0)<=0){return}f=c[2385456]|0;g=c[3528422]|0;h=c[2385468]|0;i=h>>>0<320;j=c[3528424]|0;k=c[2415164]|0;l=c[2440386]|0;m=j+4|0;n=j+8|0;o=j+12|0;p=j+16|0;q=j+20|0;r=j+24|0;s=j+28|0;t=c[3528504]|0;u=(t|0)<9;v=(h+8|0)>>>0<320;w=j+32|0;x=(h+9|0)>>>0<320;y=j+36|0;z=(h+10|0)>>>0<320;A=j+40|0;B=(h+11|0)>>>0<320;C=j+44|0;D=(h+12|0)>>>0<320;E=j+48|0;F=(h+13|0)>>>0<320;G=j+52|0;H=(h+14|0)>>>0<320;I=j+56|0;J=(h+15|0)>>>0<320;K=j+60|0;L=c[2415150]|0;M=c[2409606]|0;N=0;L43159:while(1){O=f+N|0;do{if((O|0)>=0){if((O|0)>223){P=32753;break L43159}do{if(i){Q=a[(c[2385338]|0)+(c[j>>2]|0)|0]|0;if(Q<<24>>24==0){break}if((e[M>>1]|0|0)>(k|0)){break}b[L>>1]=c[l+((Q&255)<<2)>>2]&65535}}while(0);do{if((h+1|0)>>>0<320){Q=a[(c[2385338]|0)+(c[m>>2]|0)|0]|0;if(Q<<24>>24==0){break}if((e[M+2>>1]|0|0)>(k|0)){break}b[L+2>>1]=c[l+((Q&255)<<2)>>2]&65535}}while(0);do{if((h+2|0)>>>0<320){Q=a[(c[2385338]|0)+(c[n>>2]|0)|0]|0;if(Q<<24>>24==0){break}if((e[M+4>>1]|0|0)>(k|0)){break}b[L+4>>1]=c[l+((Q&255)<<2)>>2]&65535}}while(0);do{if((h+3|0)>>>0<320){Q=a[(c[2385338]|0)+(c[o>>2]|0)|0]|0;if(Q<<24>>24==0){break}if((e[M+6>>1]|0|0)>(k|0)){break}b[L+6>>1]=c[l+((Q&255)<<2)>>2]&65535}}while(0);do{if((h+4|0)>>>0<320){Q=a[(c[2385338]|0)+(c[p>>2]|0)|0]|0;if(Q<<24>>24==0){break}if((e[M+8>>1]|0|0)>(k|0)){break}b[L+8>>1]=c[l+((Q&255)<<2)>>2]&65535}}while(0);do{if((h+5|0)>>>0<320){Q=a[(c[2385338]|0)+(c[q>>2]|0)|0]|0;if(Q<<24>>24==0){break}if((e[M+10>>1]|0|0)>(k|0)){break}b[L+10>>1]=c[l+((Q&255)<<2)>>2]&65535}}while(0);do{if((h+6|0)>>>0<320){Q=a[(c[2385338]|0)+(c[r>>2]|0)|0]|0;if(Q<<24>>24==0){break}if((e[M+12>>1]|0|0)>(k|0)){break}b[L+12>>1]=c[l+((Q&255)<<2)>>2]&65535}}while(0);do{if((h+7|0)>>>0<320){Q=a[(c[2385338]|0)+(c[s>>2]|0)|0]|0;if(Q<<24>>24==0){break}if((e[M+14>>1]|0|0)>(k|0)){break}b[L+14>>1]=c[l+((Q&255)<<2)>>2]&65535}}while(0);if(u){break}do{if(v){Q=a[(c[2385338]|0)+(c[w>>2]|0)|0]|0;if(Q<<24>>24==0){break}if((e[M+16>>1]|0|0)>(k|0)){break}b[L+16>>1]=c[l+((Q&255)<<2)>>2]&65535}}while(0);if((t|0)<10){break}do{if(x){Q=a[(c[2385338]|0)+(c[y>>2]|0)|0]|0;if(Q<<24>>24==0){break}if((e[M+18>>1]|0|0)>(k|0)){break}b[L+18>>1]=c[l+((Q&255)<<2)>>2]&65535}}while(0);if((t|0)<11){break}do{if(z){Q=a[(c[2385338]|0)+(c[A>>2]|0)|0]|0;if(Q<<24>>24==0){break}if((e[M+20>>1]|0|0)>(k|0)){break}b[L+20>>1]=c[l+((Q&255)<<2)>>2]&65535}}while(0);if((t|0)<12){break}do{if(B){Q=a[(c[2385338]|0)+(c[C>>2]|0)|0]|0;if(Q<<24>>24==0){break}if((e[M+22>>1]|0|0)>(k|0)){break}b[L+22>>1]=c[l+((Q&255)<<2)>>2]&65535}}while(0);if((t|0)<13){break}do{if(D){Q=a[(c[2385338]|0)+(c[E>>2]|0)|0]|0;if(Q<<24>>24==0){break}if((e[M+24>>1]|0|0)>(k|0)){break}b[L+24>>1]=c[l+((Q&255)<<2)>>2]&65535}}while(0);if((t|0)<14){break}do{if(F){Q=a[(c[2385338]|0)+(c[G>>2]|0)|0]|0;if(Q<<24>>24==0){break}if((e[M+26>>1]|0|0)>(k|0)){break}b[L+26>>1]=c[l+((Q&255)<<2)>>2]&65535}}while(0);if((t|0)<15){break}do{if(H){Q=a[(c[2385338]|0)+(c[I>>2]|0)|0]|0;if(Q<<24>>24==0){break}if((e[M+28>>1]|0|0)>(k|0)){break}b[L+28>>1]=c[l+((Q&255)<<2)>>2]&65535}}while(0);if((t|0)<16|J^1){break}Q=a[(c[2385338]|0)+(c[K>>2]|0)|0]|0;if(Q<<24>>24==0){break}if((e[M+30>>1]|0|0)>(k|0)){break}b[L+30>>1]=c[l+((Q&255)<<2)>>2]&65535}}while(0);c[2385338]=(c[2385338]|0)+(c[g+(N<<2)>>2]|0);O=N+1|0;if((O|0)>=(d|0)){P=32755;break}L=L+640|0;M=M+640|0;N=O}if((P|0)==32753){return}else if((P|0)==32755){return}}function dXZ(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;e=c[3528502]|0;if((e|0)<=0){return}f=c[3528424]|0;g=c[3528504]|0;h=(g|0)<9;i=c[3528422]|0;j=f+32|0;k=f+36|0;l=f+40|0;m=f+44|0;n=f+48|0;o=f+52|0;p=f+56|0;q=f+60|0;r=c[2415164]&65535;s=c[2440386]|0;t=f+28|0;u=f+24|0;v=f+20|0;w=f+16|0;x=f+12|0;y=f+8|0;z=f+4|0;A=c[2415150]|0;B=c[2409606]|0;C=0;D=c[2385338]|0;while(1){if((a[D+(c[f>>2]|0)|0]|0)!=0){b[B>>1]=r;b[A>>1]=c[s+(d[D+(c[f>>2]|0)|0]<<2)>>2]&65535}if((a[D+(c[z>>2]|0)|0]|0)!=0){b[B+2>>1]=r;b[A+2>>1]=c[s+(d[D+(c[z>>2]|0)|0]<<2)>>2]&65535}if((a[D+(c[y>>2]|0)|0]|0)!=0){b[B+4>>1]=r;b[A+4>>1]=c[s+(d[D+(c[y>>2]|0)|0]<<2)>>2]&65535}if((a[D+(c[x>>2]|0)|0]|0)!=0){b[B+6>>1]=r;b[A+6>>1]=c[s+(d[D+(c[x>>2]|0)|0]<<2)>>2]&65535}if((a[D+(c[w>>2]|0)|0]|0)!=0){b[B+8>>1]=r;b[A+8>>1]=c[s+(d[D+(c[w>>2]|0)|0]<<2)>>2]&65535}if((a[D+(c[v>>2]|0)|0]|0)!=0){b[B+10>>1]=r;b[A+10>>1]=c[s+(d[D+(c[v>>2]|0)|0]<<2)>>2]&65535}if((a[D+(c[u>>2]|0)|0]|0)!=0){b[B+12>>1]=r;b[A+12>>1]=c[s+(d[D+(c[u>>2]|0)|0]<<2)>>2]&65535}if((a[D+(c[t>>2]|0)|0]|0)!=0){b[B+14>>1]=r;b[A+14>>1]=c[s+(d[D+(c[t>>2]|0)|0]<<2)>>2]&65535}do{if(!h){if((a[D+(c[j>>2]|0)|0]|0)!=0){b[B+16>>1]=r;b[A+16>>1]=c[s+(d[D+(c[j>>2]|0)|0]<<2)>>2]&65535}if((g|0)<10){break}if((a[D+(c[k>>2]|0)|0]|0)!=0){b[B+18>>1]=r;b[A+18>>1]=c[s+(d[D+(c[k>>2]|0)|0]<<2)>>2]&65535}if((g|0)<11){break}if((a[D+(c[l>>2]|0)|0]|0)!=0){b[B+20>>1]=r;b[A+20>>1]=c[s+(d[D+(c[l>>2]|0)|0]<<2)>>2]&65535}if((g|0)<12){break}if((a[D+(c[m>>2]|0)|0]|0)!=0){b[B+22>>1]=r;b[A+22>>1]=c[s+(d[D+(c[m>>2]|0)|0]<<2)>>2]&65535}if((g|0)<13){break}if((a[D+(c[n>>2]|0)|0]|0)!=0){b[B+24>>1]=r;b[A+24>>1]=c[s+(d[D+(c[n>>2]|0)|0]<<2)>>2]&65535}if((g|0)<14){break}if((a[D+(c[o>>2]|0)|0]|0)!=0){b[B+26>>1]=r;b[A+26>>1]=c[s+(d[D+(c[o>>2]|0)|0]<<2)>>2]&65535}if((g|0)<15){break}if((a[D+(c[p>>2]|0)|0]|0)!=0){b[B+28>>1]=r;b[A+28>>1]=c[s+(d[D+(c[p>>2]|0)|0]<<2)>>2]&65535}if((g|0)<16){break}if((a[D+(c[q>>2]|0)|0]|0)==0){break}b[B+30>>1]=r;b[A+30>>1]=c[s+(d[D+(c[q>>2]|0)|0]<<2)>>2]&65535}}while(0);E=D+(c[i+(C<<2)>>2]|0)|0;F=C+1|0;if((F|0)>=(e|0)){break}A=A+640|0;B=B+640|0;C=F;D=E}c[2385338]=E;return}function dX_(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;e=c[3528502]|0;if((e|0)<=0){return}f=c[2385456]|0;g=c[3528422]|0;h=c[2385468]|0;i=h>>>0<320;j=c[3528424]|0;k=c[2415164]&65535;l=c[2440386]|0;m=j+4|0;n=j+8|0;o=j+12|0;p=j+16|0;q=j+20|0;r=j+24|0;s=j+28|0;t=c[3528504]|0;u=(t|0)<9;v=(h+8|0)>>>0<320;w=j+32|0;x=(h+9|0)>>>0<320;y=j+36|0;z=(h+10|0)>>>0<320;A=j+40|0;B=(h+11|0)>>>0<320;C=j+44|0;D=(h+12|0)>>>0<320;E=j+48|0;F=(h+13|0)>>>0<320;G=j+52|0;H=(h+14|0)>>>0<320;I=j+56|0;J=(h+15|0)>>>0<320;K=j+60|0;L=c[2415150]|0;M=c[2409606]|0;N=0;L43323:while(1){O=f+N|0;do{if((O|0)>=0){if((O|0)>223){P=32866;break L43323}do{if(i){Q=c[2385338]|0;if((a[Q+(c[j>>2]|0)|0]|0)==0){break}b[M>>1]=k;b[L>>1]=c[l+(d[Q+(c[j>>2]|0)|0]<<2)>>2]&65535}}while(0);do{if((h+1|0)>>>0<320){Q=c[2385338]|0;if((a[Q+(c[m>>2]|0)|0]|0)==0){break}b[M+2>>1]=k;b[L+2>>1]=c[l+(d[Q+(c[m>>2]|0)|0]<<2)>>2]&65535}}while(0);do{if((h+2|0)>>>0<320){Q=c[2385338]|0;if((a[Q+(c[n>>2]|0)|0]|0)==0){break}b[M+4>>1]=k;b[L+4>>1]=c[l+(d[Q+(c[n>>2]|0)|0]<<2)>>2]&65535}}while(0);do{if((h+3|0)>>>0<320){Q=c[2385338]|0;if((a[Q+(c[o>>2]|0)|0]|0)==0){break}b[M+6>>1]=k;b[L+6>>1]=c[l+(d[Q+(c[o>>2]|0)|0]<<2)>>2]&65535}}while(0);do{if((h+4|0)>>>0<320){Q=c[2385338]|0;if((a[Q+(c[p>>2]|0)|0]|0)==0){break}b[M+8>>1]=k;b[L+8>>1]=c[l+(d[Q+(c[p>>2]|0)|0]<<2)>>2]&65535}}while(0);do{if((h+5|0)>>>0<320){Q=c[2385338]|0;if((a[Q+(c[q>>2]|0)|0]|0)==0){break}b[M+10>>1]=k;b[L+10>>1]=c[l+(d[Q+(c[q>>2]|0)|0]<<2)>>2]&65535}}while(0);do{if((h+6|0)>>>0<320){Q=c[2385338]|0;if((a[Q+(c[r>>2]|0)|0]|0)==0){break}b[M+12>>1]=k;b[L+12>>1]=c[l+(d[Q+(c[r>>2]|0)|0]<<2)>>2]&65535}}while(0);do{if((h+7|0)>>>0<320){Q=c[2385338]|0;if((a[Q+(c[s>>2]|0)|0]|0)==0){break}b[M+14>>1]=k;b[L+14>>1]=c[l+(d[Q+(c[s>>2]|0)|0]<<2)>>2]&65535}}while(0);if(u){break}do{if(v){Q=c[2385338]|0;if((a[Q+(c[w>>2]|0)|0]|0)==0){break}b[M+16>>1]=k;b[L+16>>1]=c[l+(d[Q+(c[w>>2]|0)|0]<<2)>>2]&65535}}while(0);if((t|0)<10){break}do{if(x){Q=c[2385338]|0;if((a[Q+(c[y>>2]|0)|0]|0)==0){break}b[M+18>>1]=k;b[L+18>>1]=c[l+(d[Q+(c[y>>2]|0)|0]<<2)>>2]&65535}}while(0);if((t|0)<11){break}do{if(z){Q=c[2385338]|0;if((a[Q+(c[A>>2]|0)|0]|0)==0){break}b[M+20>>1]=k;b[L+20>>1]=c[l+(d[Q+(c[A>>2]|0)|0]<<2)>>2]&65535}}while(0);if((t|0)<12){break}do{if(B){Q=c[2385338]|0;if((a[Q+(c[C>>2]|0)|0]|0)==0){break}b[M+22>>1]=k;b[L+22>>1]=c[l+(d[Q+(c[C>>2]|0)|0]<<2)>>2]&65535}}while(0);if((t|0)<13){break}do{if(D){Q=c[2385338]|0;if((a[Q+(c[E>>2]|0)|0]|0)==0){break}b[M+24>>1]=k;b[L+24>>1]=c[l+(d[Q+(c[E>>2]|0)|0]<<2)>>2]&65535}}while(0);if((t|0)<14){break}do{if(F){Q=c[2385338]|0;if((a[Q+(c[G>>2]|0)|0]|0)==0){break}b[M+26>>1]=k;b[L+26>>1]=c[l+(d[Q+(c[G>>2]|0)|0]<<2)>>2]&65535}}while(0);if((t|0)<15){break}do{if(H){Q=c[2385338]|0;if((a[Q+(c[I>>2]|0)|0]|0)==0){break}b[M+28>>1]=k;b[L+28>>1]=c[l+(d[Q+(c[I>>2]|0)|0]<<2)>>2]&65535}}while(0);if((t|0)<16|J^1){break}Q=c[2385338]|0;if((a[Q+(c[K>>2]|0)|0]|0)==0){break}b[M+30>>1]=k;b[L+30>>1]=c[l+(d[Q+(c[K>>2]|0)|0]<<2)>>2]&65535}}while(0);c[2385338]=(c[2385338]|0)+(c[g+(N<<2)>>2]|0);O=N+1|0;if((O|0)>=(e|0)){P=32868;break}L=L+640|0;M=M+640|0;N=O}if((P|0)==32866){return}else if((P|0)==32868){return}}function dX$(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;f=c[3528502]|0;if((f|0)<=0){return}g=c[3528424]|0;h=c[3528504]|0;i=(h|0)<9;j=c[3528422]|0;k=g+32|0;l=g+36|0;m=g+40|0;n=g+44|0;o=g+48|0;p=g+52|0;q=g+56|0;r=g+60|0;s=c[2415164]|0;t=s&65535;u=c[2440386]|0;v=g+28|0;w=g+24|0;x=g+20|0;y=g+16|0;z=g+12|0;A=g+8|0;B=g+4|0;C=c[2415150]|0;D=c[2409606]|0;E=0;F=c[2385338]|0;while(1){do{if((a[F+(c[g>>2]|0)|0]|0)==0){G=F}else{if((e[D>>1]|0)>(s|0)){G=F;break}b[D>>1]=t;b[C>>1]=c[u+(d[F+(c[g>>2]|0)|0]<<2)>>2]&65535;G=F}}while(0);do{if((a[G+(c[B>>2]|0)|0]|0)==0){H=G}else{I=D+2|0;if((e[I>>1]|0)>(s|0)){H=G;break}b[I>>1]=t;b[C+2>>1]=c[u+(d[F+(c[B>>2]|0)|0]<<2)>>2]&65535;H=F}}while(0);do{if((a[H+(c[A>>2]|0)|0]|0)==0){J=H}else{I=D+4|0;if((e[I>>1]|0)>(s|0)){J=H;break}b[I>>1]=t;b[C+4>>1]=c[u+(d[F+(c[A>>2]|0)|0]<<2)>>2]&65535;J=F}}while(0);do{if((a[J+(c[z>>2]|0)|0]|0)==0){K=J}else{I=D+6|0;if((e[I>>1]|0)>(s|0)){K=J;break}b[I>>1]=t;b[C+6>>1]=c[u+(d[F+(c[z>>2]|0)|0]<<2)>>2]&65535;K=F}}while(0);do{if((a[K+(c[y>>2]|0)|0]|0)==0){L=K}else{I=D+8|0;if((e[I>>1]|0)>(s|0)){L=K;break}b[I>>1]=t;b[C+8>>1]=c[u+(d[F+(c[y>>2]|0)|0]<<2)>>2]&65535;L=F}}while(0);do{if((a[L+(c[x>>2]|0)|0]|0)==0){M=L}else{I=D+10|0;if((e[I>>1]|0)>(s|0)){M=L;break}b[I>>1]=t;b[C+10>>1]=c[u+(d[F+(c[x>>2]|0)|0]<<2)>>2]&65535;M=F}}while(0);do{if((a[M+(c[w>>2]|0)|0]|0)==0){N=M}else{I=D+12|0;if((e[I>>1]|0)>(s|0)){N=M;break}b[I>>1]=t;b[C+12>>1]=c[u+(d[F+(c[w>>2]|0)|0]<<2)>>2]&65535;N=F}}while(0);do{if((a[N+(c[v>>2]|0)|0]|0)!=0){I=D+14|0;if((e[I>>1]|0)>(s|0)){break}b[I>>1]=t;b[C+14>>1]=c[u+(d[F+(c[v>>2]|0)|0]<<2)>>2]&65535}}while(0);do{if(!i){do{if((a[F+(c[k>>2]|0)|0]|0)!=0){I=D+16|0;if((e[I>>1]|0)>(s|0)){break}b[I>>1]=t;b[C+16>>1]=c[u+(d[F+(c[k>>2]|0)|0]<<2)>>2]&65535}}while(0);if((h|0)<10){break}do{if((a[F+(c[l>>2]|0)|0]|0)!=0){I=D+18|0;if((e[I>>1]|0)>(s|0)){break}b[I>>1]=t;b[C+18>>1]=c[u+(d[F+(c[l>>2]|0)|0]<<2)>>2]&65535}}while(0);if((h|0)<11){break}do{if((a[F+(c[m>>2]|0)|0]|0)!=0){I=D+20|0;if((e[I>>1]|0)>(s|0)){break}b[I>>1]=t;b[C+20>>1]=c[u+(d[F+(c[m>>2]|0)|0]<<2)>>2]&65535}}while(0);if((h|0)<12){break}do{if((a[F+(c[n>>2]|0)|0]|0)!=0){I=D+22|0;if((e[I>>1]|0)>(s|0)){break}b[I>>1]=t;b[C+22>>1]=c[u+(d[F+(c[n>>2]|0)|0]<<2)>>2]&65535}}while(0);if((h|0)<13){break}do{if((a[F+(c[o>>2]|0)|0]|0)!=0){I=D+24|0;if((e[I>>1]|0)>(s|0)){break}b[I>>1]=t;b[C+24>>1]=c[u+(d[F+(c[o>>2]|0)|0]<<2)>>2]&65535}}while(0);if((h|0)<14){break}do{if((a[F+(c[p>>2]|0)|0]|0)!=0){I=D+26|0;if((e[I>>1]|0)>(s|0)){break}b[I>>1]=t;b[C+26>>1]=c[u+(d[F+(c[p>>2]|0)|0]<<2)>>2]&65535}}while(0);if((h|0)<15){break}do{if((a[F+(c[q>>2]|0)|0]|0)!=0){I=D+28|0;if((e[I>>1]|0)>(s|0)){break}b[I>>1]=t;b[C+28>>1]=c[u+(d[F+(c[q>>2]|0)|0]<<2)>>2]&65535}}while(0);if((h|0)<16){break}if((a[F+(c[r>>2]|0)|0]|0)==0){break}I=D+30|0;if((e[I>>1]|0)>(s|0)){break}b[I>>1]=t;b[C+30>>1]=c[u+(d[F+(c[r>>2]|0)|0]<<2)>>2]&65535}}while(0);O=F+(c[j+(E<<2)>>2]|0)|0;I=E+1|0;if((I|0)>=(f|0)){break}C=C+640|0;D=D+640|0;E=I;F=O}c[2385338]=O;return}function dX0(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;f=c[3528502]|0;if((f|0)<=0){return}g=c[2385456]|0;h=c[3528422]|0;i=c[2385468]|0;j=i>>>0<320;k=c[3528424]|0;l=c[2415164]|0;m=l&65535;n=c[2440386]|0;o=k+4|0;p=k+8|0;q=k+12|0;r=k+16|0;s=k+20|0;t=k+24|0;u=k+28|0;v=c[3528504]|0;w=(v|0)<9;x=(i+8|0)>>>0<320;y=k+32|0;z=(i+9|0)>>>0<320;A=k+36|0;B=(i+10|0)>>>0<320;C=k+40|0;D=(i+11|0)>>>0<320;E=k+44|0;F=(i+12|0)>>>0<320;G=k+48|0;H=(i+13|0)>>>0<320;I=k+52|0;J=(i+14|0)>>>0<320;K=k+56|0;L=(i+15|0)>>>0<320;M=k+60|0;N=c[2415150]|0;O=c[2409606]|0;P=0;L43487:while(1){Q=g+P|0;do{if((Q|0)>=0){if((Q|0)>223){R=33011;break L43487}do{if(j){S=c[2385338]|0;if((a[S+(c[k>>2]|0)|0]|0)==0){break}if((e[O>>1]|0)>(l|0)){break}b[O>>1]=m;b[N>>1]=c[n+(d[S+(c[k>>2]|0)|0]<<2)>>2]&65535}}while(0);do{if((i+1|0)>>>0<320){S=c[2385338]|0;if((a[S+(c[o>>2]|0)|0]|0)==0){break}T=O+2|0;if((e[T>>1]|0)>(l|0)){break}b[T>>1]=m;b[N+2>>1]=c[n+(d[S+(c[o>>2]|0)|0]<<2)>>2]&65535}}while(0);do{if((i+2|0)>>>0<320){S=c[2385338]|0;if((a[S+(c[p>>2]|0)|0]|0)==0){break}T=O+4|0;if((e[T>>1]|0)>(l|0)){break}b[T>>1]=m;b[N+4>>1]=c[n+(d[S+(c[p>>2]|0)|0]<<2)>>2]&65535}}while(0);do{if((i+3|0)>>>0<320){S=c[2385338]|0;if((a[S+(c[q>>2]|0)|0]|0)==0){break}T=O+6|0;if((e[T>>1]|0)>(l|0)){break}b[T>>1]=m;b[N+6>>1]=c[n+(d[S+(c[q>>2]|0)|0]<<2)>>2]&65535}}while(0);do{if((i+4|0)>>>0<320){S=c[2385338]|0;if((a[S+(c[r>>2]|0)|0]|0)==0){break}T=O+8|0;if((e[T>>1]|0)>(l|0)){break}b[T>>1]=m;b[N+8>>1]=c[n+(d[S+(c[r>>2]|0)|0]<<2)>>2]&65535}}while(0);do{if((i+5|0)>>>0<320){S=c[2385338]|0;if((a[S+(c[s>>2]|0)|0]|0)==0){break}T=O+10|0;if((e[T>>1]|0)>(l|0)){break}b[T>>1]=m;b[N+10>>1]=c[n+(d[S+(c[s>>2]|0)|0]<<2)>>2]&65535}}while(0);do{if((i+6|0)>>>0<320){S=c[2385338]|0;if((a[S+(c[t>>2]|0)|0]|0)==0){break}T=O+12|0;if((e[T>>1]|0)>(l|0)){break}b[T>>1]=m;b[N+12>>1]=c[n+(d[S+(c[t>>2]|0)|0]<<2)>>2]&65535}}while(0);do{if((i+7|0)>>>0<320){S=c[2385338]|0;if((a[S+(c[u>>2]|0)|0]|0)==0){break}T=O+14|0;if((e[T>>1]|0)>(l|0)){break}b[T>>1]=m;b[N+14>>1]=c[n+(d[S+(c[u>>2]|0)|0]<<2)>>2]&65535}}while(0);if(w){break}do{if(x){S=c[2385338]|0;if((a[S+(c[y>>2]|0)|0]|0)==0){break}T=O+16|0;if((e[T>>1]|0)>(l|0)){break}b[T>>1]=m;b[N+16>>1]=c[n+(d[S+(c[y>>2]|0)|0]<<2)>>2]&65535}}while(0);if((v|0)<10){break}do{if(z){S=c[2385338]|0;if((a[S+(c[A>>2]|0)|0]|0)==0){break}T=O+18|0;if((e[T>>1]|0)>(l|0)){break}b[T>>1]=m;b[N+18>>1]=c[n+(d[S+(c[A>>2]|0)|0]<<2)>>2]&65535}}while(0);if((v|0)<11){break}do{if(B){S=c[2385338]|0;if((a[S+(c[C>>2]|0)|0]|0)==0){break}T=O+20|0;if((e[T>>1]|0)>(l|0)){break}b[T>>1]=m;b[N+20>>1]=c[n+(d[S+(c[C>>2]|0)|0]<<2)>>2]&65535}}while(0);if((v|0)<12){break}do{if(D){S=c[2385338]|0;if((a[S+(c[E>>2]|0)|0]|0)==0){break}T=O+22|0;if((e[T>>1]|0)>(l|0)){break}b[T>>1]=m;b[N+22>>1]=c[n+(d[S+(c[E>>2]|0)|0]<<2)>>2]&65535}}while(0);if((v|0)<13){break}do{if(F){S=c[2385338]|0;if((a[S+(c[G>>2]|0)|0]|0)==0){break}T=O+24|0;if((e[T>>1]|0)>(l|0)){break}b[T>>1]=m;b[N+24>>1]=c[n+(d[S+(c[G>>2]|0)|0]<<2)>>2]&65535}}while(0);if((v|0)<14){break}do{if(H){S=c[2385338]|0;if((a[S+(c[I>>2]|0)|0]|0)==0){break}T=O+26|0;if((e[T>>1]|0)>(l|0)){break}b[T>>1]=m;b[N+26>>1]=c[n+(d[S+(c[I>>2]|0)|0]<<2)>>2]&65535}}while(0);if((v|0)<15){break}do{if(J){S=c[2385338]|0;if((a[S+(c[K>>2]|0)|0]|0)==0){break}T=O+28|0;if((e[T>>1]|0)>(l|0)){break}b[T>>1]=m;b[N+28>>1]=c[n+(d[S+(c[K>>2]|0)|0]<<2)>>2]&65535}}while(0);if((v|0)<16|L^1){break}S=c[2385338]|0;if((a[S+(c[M>>2]|0)|0]|0)==0){break}T=O+30|0;if((e[T>>1]|0)>(l|0)){break}b[T>>1]=m;b[N+30>>1]=c[n+(d[S+(c[M>>2]|0)|0]<<2)>>2]&65535}}while(0);c[2385338]=(c[2385338]|0)+(c[h+(P<<2)>>2]|0);Q=P+1|0;if((Q|0)>=(f|0)){R=33013;break}N=N+640|0;O=O+640|0;P=Q}if((R|0)==33011){return}else if((R|0)==33013){return}}function dX1(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=c[3528502]|0;if((d|0)<=0){return}e=c[3528424]|0;f=c[3528504]|0;g=(f|0)<9;h=c[3528422]|0;i=e+32|0;j=e+36|0;k=e+40|0;l=e+44|0;m=e+48|0;n=e+52|0;o=e+56|0;p=e+60|0;q=c[2440386]|0;r=c[2415150]|0;s=0;t=c[2385338]|0;while(1){u=a[t+(15-(c[e>>2]|0))|0]|0;if(u<<24>>24!=0){b[r>>1]=c[q+((u&255)<<2)>>2]&65535}u=a[t+(15-(c[e+4>>2]|0))|0]|0;if(u<<24>>24!=0){b[r+2>>1]=c[q+((u&255)<<2)>>2]&65535}u=a[t+(15-(c[e+8>>2]|0))|0]|0;if(u<<24>>24!=0){b[r+4>>1]=c[q+((u&255)<<2)>>2]&65535}u=a[t+(15-(c[e+12>>2]|0))|0]|0;if(u<<24>>24!=0){b[r+6>>1]=c[q+((u&255)<<2)>>2]&65535}u=a[t+(15-(c[e+16>>2]|0))|0]|0;if(u<<24>>24!=0){b[r+8>>1]=c[q+((u&255)<<2)>>2]&65535}u=a[t+(15-(c[e+20>>2]|0))|0]|0;if(u<<24>>24!=0){b[r+10>>1]=c[q+((u&255)<<2)>>2]&65535}u=a[t+(15-(c[e+24>>2]|0))|0]|0;if(u<<24>>24!=0){b[r+12>>1]=c[q+((u&255)<<2)>>2]&65535}u=a[t+(15-(c[e+28>>2]|0))|0]|0;if(u<<24>>24!=0){b[r+14>>1]=c[q+((u&255)<<2)>>2]&65535}do{if(!g){u=a[t+(15-(c[i>>2]|0))|0]|0;if(u<<24>>24!=0){b[r+16>>1]=c[q+((u&255)<<2)>>2]&65535}if((f|0)<10){break}u=a[t+(15-(c[j>>2]|0))|0]|0;if(u<<24>>24!=0){b[r+18>>1]=c[q+((u&255)<<2)>>2]&65535}if((f|0)<11){break}u=a[t+(15-(c[k>>2]|0))|0]|0;if(u<<24>>24!=0){b[r+20>>1]=c[q+((u&255)<<2)>>2]&65535}if((f|0)<12){break}u=a[t+(15-(c[l>>2]|0))|0]|0;if(u<<24>>24!=0){b[r+22>>1]=c[q+((u&255)<<2)>>2]&65535}if((f|0)<13){break}u=a[t+(15-(c[m>>2]|0))|0]|0;if(u<<24>>24!=0){b[r+24>>1]=c[q+((u&255)<<2)>>2]&65535}if((f|0)<14){break}u=a[t+(15-(c[n>>2]|0))|0]|0;if(u<<24>>24!=0){b[r+26>>1]=c[q+((u&255)<<2)>>2]&65535}if((f|0)<15){break}u=a[t+(15-(c[o>>2]|0))|0]|0;if(u<<24>>24!=0){b[r+28>>1]=c[q+((u&255)<<2)>>2]&65535}if((f|0)<16){break}u=a[t+(15-(c[p>>2]|0))|0]|0;if(u<<24>>24==0){break}b[r+30>>1]=c[q+((u&255)<<2)>>2]&65535}}while(0);v=t+(c[h+(s<<2)>>2]|0)|0;u=s+1|0;if((u|0)>=(d|0)){break}r=r+640|0;s=u;t=v}c[2385338]=v;return}function dX2(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;d=c[3528502]|0;if((d|0)<=0){return}e=c[2385456]|0;f=c[3528422]|0;g=c[2385468]|0;h=g>>>0<320;i=c[3528424]|0;j=c[2440386]|0;k=i+4|0;l=i+8|0;m=i+12|0;n=i+16|0;o=i+20|0;p=i+24|0;q=i+28|0;r=c[3528504]|0;s=(r|0)<9;t=(g+8|0)>>>0<320;u=i+32|0;v=(g+9|0)>>>0<320;w=i+36|0;x=(g+10|0)>>>0<320;y=i+40|0;z=(g+11|0)>>>0<320;A=i+44|0;B=(g+12|0)>>>0<320;C=i+48|0;D=(g+13|0)>>>0<320;E=i+52|0;F=(g+14|0)>>>0<320;G=i+56|0;H=(g+15|0)>>>0<320;I=i+60|0;J=c[2415150]|0;K=0;L43651:while(1){L=e+K|0;do{if((L|0)>=0){if((L|0)>223){M=33125;break L43651}do{if(h){N=a[(c[2385338]|0)+(15-(c[i>>2]|0))|0]|0;if(N<<24>>24==0){break}b[J>>1]=c[j+((N&255)<<2)>>2]&65535}}while(0);do{if((g+1|0)>>>0<320){N=a[(c[2385338]|0)+(15-(c[k>>2]|0))|0]|0;if(N<<24>>24==0){break}b[J+2>>1]=c[j+((N&255)<<2)>>2]&65535}}while(0);do{if((g+2|0)>>>0<320){N=a[(c[2385338]|0)+(15-(c[l>>2]|0))|0]|0;if(N<<24>>24==0){break}b[J+4>>1]=c[j+((N&255)<<2)>>2]&65535}}while(0);do{if((g+3|0)>>>0<320){N=a[(c[2385338]|0)+(15-(c[m>>2]|0))|0]|0;if(N<<24>>24==0){break}b[J+6>>1]=c[j+((N&255)<<2)>>2]&65535}}while(0);do{if((g+4|0)>>>0<320){N=a[(c[2385338]|0)+(15-(c[n>>2]|0))|0]|0;if(N<<24>>24==0){break}b[J+8>>1]=c[j+((N&255)<<2)>>2]&65535}}while(0);do{if((g+5|0)>>>0<320){N=a[(c[2385338]|0)+(15-(c[o>>2]|0))|0]|0;if(N<<24>>24==0){break}b[J+10>>1]=c[j+((N&255)<<2)>>2]&65535}}while(0);do{if((g+6|0)>>>0<320){N=a[(c[2385338]|0)+(15-(c[p>>2]|0))|0]|0;if(N<<24>>24==0){break}b[J+12>>1]=c[j+((N&255)<<2)>>2]&65535}}while(0);do{if((g+7|0)>>>0<320){N=a[(c[2385338]|0)+(15-(c[q>>2]|0))|0]|0;if(N<<24>>24==0){break}b[J+14>>1]=c[j+((N&255)<<2)>>2]&65535}}while(0);if(s){break}do{if(t){N=a[(c[2385338]|0)+(15-(c[u>>2]|0))|0]|0;if(N<<24>>24==0){break}b[J+16>>1]=c[j+((N&255)<<2)>>2]&65535}}while(0);if((r|0)<10){break}do{if(v){N=a[(c[2385338]|0)+(15-(c[w>>2]|0))|0]|0;if(N<<24>>24==0){break}b[J+18>>1]=c[j+((N&255)<<2)>>2]&65535}}while(0);if((r|0)<11){break}do{if(x){N=a[(c[2385338]|0)+(15-(c[y>>2]|0))|0]|0;if(N<<24>>24==0){break}b[J+20>>1]=c[j+((N&255)<<2)>>2]&65535}}while(0);if((r|0)<12){break}do{if(z){N=a[(c[2385338]|0)+(15-(c[A>>2]|0))|0]|0;if(N<<24>>24==0){break}b[J+22>>1]=c[j+((N&255)<<2)>>2]&65535}}while(0);if((r|0)<13){break}do{if(B){N=a[(c[2385338]|0)+(15-(c[C>>2]|0))|0]|0;if(N<<24>>24==0){break}b[J+24>>1]=c[j+((N&255)<<2)>>2]&65535}}while(0);if((r|0)<14){break}do{if(D){N=a[(c[2385338]|0)+(15-(c[E>>2]|0))|0]|0;if(N<<24>>24==0){break}b[J+26>>1]=c[j+((N&255)<<2)>>2]&65535}}while(0);if((r|0)<15){break}do{if(F){N=a[(c[2385338]|0)+(15-(c[G>>2]|0))|0]|0;if(N<<24>>24==0){break}b[J+28>>1]=c[j+((N&255)<<2)>>2]&65535}}while(0);if((r|0)<16|H^1){break}N=a[(c[2385338]|0)+(15-(c[I>>2]|0))|0]|0;if(N<<24>>24==0){break}b[J+30>>1]=c[j+((N&255)<<2)>>2]&65535}}while(0);c[2385338]=(c[2385338]|0)+(c[f+(K<<2)>>2]|0);L=K+1|0;if((L|0)>=(d|0)){M=33124;break}J=J+640|0;K=L}if((M|0)==33124){return}else if((M|0)==33125){return}}function dX3(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;d=c[3528502]|0;if((d|0)<=0){return}f=c[3528424]|0;g=c[3528504]|0;h=(g|0)<9;i=c[3528422]|0;j=f+32|0;k=f+36|0;l=f+40|0;m=f+44|0;n=f+48|0;o=f+52|0;p=f+56|0;q=f+60|0;r=c[2415164]|0;s=c[2440386]|0;t=c[2415150]|0;u=c[2409606]|0;v=0;w=c[2385338]|0;while(1){x=a[w+(15-(c[f>>2]|0))|0]|0;y=x&255;do{if(x<<24>>24==0){z=w}else{if((e[u>>1]|0|0)>(r|0)){z=w;break}b[t>>1]=c[s+(y<<2)>>2]&65535;z=w}}while(0);y=a[z+(15-(c[f+4>>2]|0))|0]|0;x=y&255;do{if(y<<24>>24==0){A=z}else{if((e[u+2>>1]|0|0)>(r|0)){A=z;break}b[t+2>>1]=c[s+(x<<2)>>2]&65535;A=w}}while(0);x=a[A+(15-(c[f+8>>2]|0))|0]|0;y=x&255;do{if(x<<24>>24==0){B=A}else{if((e[u+4>>1]|0|0)>(r|0)){B=A;break}b[t+4>>1]=c[s+(y<<2)>>2]&65535;B=w}}while(0);y=a[B+(15-(c[f+12>>2]|0))|0]|0;x=y&255;do{if(y<<24>>24==0){C=B}else{if((e[u+6>>1]|0|0)>(r|0)){C=B;break}b[t+6>>1]=c[s+(x<<2)>>2]&65535;C=w}}while(0);x=a[C+(15-(c[f+16>>2]|0))|0]|0;y=x&255;do{if(x<<24>>24==0){D=C}else{if((e[u+8>>1]|0|0)>(r|0)){D=C;break}b[t+8>>1]=c[s+(y<<2)>>2]&65535;D=w}}while(0);y=a[D+(15-(c[f+20>>2]|0))|0]|0;x=y&255;do{if(y<<24>>24==0){E=D}else{if((e[u+10>>1]|0|0)>(r|0)){E=D;break}b[t+10>>1]=c[s+(x<<2)>>2]&65535;E=w}}while(0);x=a[E+(15-(c[f+24>>2]|0))|0]|0;y=x&255;do{if(x<<24>>24==0){F=E}else{if((e[u+12>>1]|0|0)>(r|0)){F=E;break}b[t+12>>1]=c[s+(y<<2)>>2]&65535;F=w}}while(0);y=a[F+(15-(c[f+28>>2]|0))|0]|0;x=y&255;do{if(y<<24>>24!=0){if((e[u+14>>1]|0|0)>(r|0)){break}b[t+14>>1]=c[s+(x<<2)>>2]&65535}}while(0);do{if(!h){x=a[w+(15-(c[j>>2]|0))|0]|0;y=x&255;do{if(x<<24>>24!=0){if((e[u+16>>1]|0|0)>(r|0)){break}b[t+16>>1]=c[s+(y<<2)>>2]&65535}}while(0);if((g|0)<10){break}y=a[w+(15-(c[k>>2]|0))|0]|0;x=y&255;do{if(y<<24>>24!=0){if((e[u+18>>1]|0|0)>(r|0)){break}b[t+18>>1]=c[s+(x<<2)>>2]&65535}}while(0);if((g|0)<11){break}x=a[w+(15-(c[l>>2]|0))|0]|0;y=x&255;do{if(x<<24>>24!=0){if((e[u+20>>1]|0|0)>(r|0)){break}b[t+20>>1]=c[s+(y<<2)>>2]&65535}}while(0);if((g|0)<12){break}y=a[w+(15-(c[m>>2]|0))|0]|0;x=y&255;do{if(y<<24>>24!=0){if((e[u+22>>1]|0|0)>(r|0)){break}b[t+22>>1]=c[s+(x<<2)>>2]&65535}}while(0);if((g|0)<13){break}x=a[w+(15-(c[n>>2]|0))|0]|0;y=x&255;do{if(x<<24>>24!=0){if((e[u+24>>1]|0|0)>(r|0)){break}b[t+24>>1]=c[s+(y<<2)>>2]&65535}}while(0);if((g|0)<14){break}y=a[w+(15-(c[o>>2]|0))|0]|0;x=y&255;do{if(y<<24>>24!=0){if((e[u+26>>1]|0|0)>(r|0)){break}b[t+26>>1]=c[s+(x<<2)>>2]&65535}}while(0);if((g|0)<15){break}x=a[w+(15-(c[p>>2]|0))|0]|0;y=x&255;do{if(x<<24>>24!=0){if((e[u+28>>1]|0|0)>(r|0)){break}b[t+28>>1]=c[s+(y<<2)>>2]&65535}}while(0);if((g|0)<16){break}y=a[w+(15-(c[q>>2]|0))|0]|0;if(y<<24>>24==0){break}if((e[u+30>>1]|0|0)>(r|0)){break}b[t+30>>1]=c[s+((y&255)<<2)>>2]&65535}}while(0);G=w+(c[i+(v<<2)>>2]|0)|0;y=v+1|0;if((y|0)>=(d|0)){break}t=t+640|0;u=u+640|0;v=y;w=G}c[2385338]=G;return}function dX4(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;d=c[3528502]|0;if((d|0)<=0){return}f=c[2385456]|0;g=c[3528422]|0;h=c[2385468]|0;i=h>>>0<320;j=c[3528424]|0;k=c[2415164]|0;l=c[2440386]|0;m=j+4|0;n=j+8|0;o=j+12|0;p=j+16|0;q=j+20|0;r=j+24|0;s=j+28|0;t=c[3528504]|0;u=(t|0)<9;v=(h+8|0)>>>0<320;w=j+32|0;x=(h+9|0)>>>0<320;y=j+36|0;z=(h+10|0)>>>0<320;A=j+40|0;B=(h+11|0)>>>0<320;C=j+44|0;D=(h+12|0)>>>0<320;E=j+48|0;F=(h+13|0)>>>0<320;G=j+52|0;H=(h+14|0)>>>0<320;I=j+56|0;J=(h+15|0)>>>0<320;K=j+60|0;L=c[2415150]|0;M=c[2409606]|0;N=0;L43815:while(1){O=f+N|0;do{if((O|0)>=0){if((O|0)>223){P=33269;break L43815}do{if(i){Q=a[(c[2385338]|0)+(15-(c[j>>2]|0))|0]|0;if(Q<<24>>24==0){break}if((e[M>>1]|0|0)>(k|0)){break}b[L>>1]=c[l+((Q&255)<<2)>>2]&65535}}while(0);do{if((h+1|0)>>>0<320){Q=a[(c[2385338]|0)+(15-(c[m>>2]|0))|0]|0;if(Q<<24>>24==0){break}if((e[M+2>>1]|0|0)>(k|0)){break}b[L+2>>1]=c[l+((Q&255)<<2)>>2]&65535}}while(0);do{if((h+2|0)>>>0<320){Q=a[(c[2385338]|0)+(15-(c[n>>2]|0))|0]|0;if(Q<<24>>24==0){break}if((e[M+4>>1]|0|0)>(k|0)){break}b[L+4>>1]=c[l+((Q&255)<<2)>>2]&65535}}while(0);do{if((h+3|0)>>>0<320){Q=a[(c[2385338]|0)+(15-(c[o>>2]|0))|0]|0;if(Q<<24>>24==0){break}if((e[M+6>>1]|0|0)>(k|0)){break}b[L+6>>1]=c[l+((Q&255)<<2)>>2]&65535}}while(0);do{if((h+4|0)>>>0<320){Q=a[(c[2385338]|0)+(15-(c[p>>2]|0))|0]|0;if(Q<<24>>24==0){break}if((e[M+8>>1]|0|0)>(k|0)){break}b[L+8>>1]=c[l+((Q&255)<<2)>>2]&65535}}while(0);do{if((h+5|0)>>>0<320){Q=a[(c[2385338]|0)+(15-(c[q>>2]|0))|0]|0;if(Q<<24>>24==0){break}if((e[M+10>>1]|0|0)>(k|0)){break}b[L+10>>1]=c[l+((Q&255)<<2)>>2]&65535}}while(0);do{if((h+6|0)>>>0<320){Q=a[(c[2385338]|0)+(15-(c[r>>2]|0))|0]|0;if(Q<<24>>24==0){break}if((e[M+12>>1]|0|0)>(k|0)){break}b[L+12>>1]=c[l+((Q&255)<<2)>>2]&65535}}while(0);do{if((h+7|0)>>>0<320){Q=a[(c[2385338]|0)+(15-(c[s>>2]|0))|0]|0;if(Q<<24>>24==0){break}if((e[M+14>>1]|0|0)>(k|0)){break}b[L+14>>1]=c[l+((Q&255)<<2)>>2]&65535}}while(0);if(u){break}do{if(v){Q=a[(c[2385338]|0)+(15-(c[w>>2]|0))|0]|0;if(Q<<24>>24==0){break}if((e[M+16>>1]|0|0)>(k|0)){break}b[L+16>>1]=c[l+((Q&255)<<2)>>2]&65535}}while(0);if((t|0)<10){break}do{if(x){Q=a[(c[2385338]|0)+(15-(c[y>>2]|0))|0]|0;if(Q<<24>>24==0){break}if((e[M+18>>1]|0|0)>(k|0)){break}b[L+18>>1]=c[l+((Q&255)<<2)>>2]&65535}}while(0);if((t|0)<11){break}do{if(z){Q=a[(c[2385338]|0)+(15-(c[A>>2]|0))|0]|0;if(Q<<24>>24==0){break}if((e[M+20>>1]|0|0)>(k|0)){break}b[L+20>>1]=c[l+((Q&255)<<2)>>2]&65535}}while(0);if((t|0)<12){break}do{if(B){Q=a[(c[2385338]|0)+(15-(c[C>>2]|0))|0]|0;if(Q<<24>>24==0){break}if((e[M+22>>1]|0|0)>(k|0)){break}b[L+22>>1]=c[l+((Q&255)<<2)>>2]&65535}}while(0);if((t|0)<13){break}do{if(D){Q=a[(c[2385338]|0)+(15-(c[E>>2]|0))|0]|0;if(Q<<24>>24==0){break}if((e[M+24>>1]|0|0)>(k|0)){break}b[L+24>>1]=c[l+((Q&255)<<2)>>2]&65535}}while(0);if((t|0)<14){break}do{if(F){Q=a[(c[2385338]|0)+(15-(c[G>>2]|0))|0]|0;if(Q<<24>>24==0){break}if((e[M+26>>1]|0|0)>(k|0)){break}b[L+26>>1]=c[l+((Q&255)<<2)>>2]&65535}}while(0);if((t|0)<15){break}do{if(H){Q=a[(c[2385338]|0)+(15-(c[I>>2]|0))|0]|0;if(Q<<24>>24==0){break}if((e[M+28>>1]|0|0)>(k|0)){break}b[L+28>>1]=c[l+((Q&255)<<2)>>2]&65535}}while(0);if((t|0)<16|J^1){break}Q=a[(c[2385338]|0)+(15-(c[K>>2]|0))|0]|0;if(Q<<24>>24==0){break}if((e[M+30>>1]|0|0)>(k|0)){break}b[L+30>>1]=c[l+((Q&255)<<2)>>2]&65535}}while(0);c[2385338]=(c[2385338]|0)+(c[g+(N<<2)>>2]|0);O=N+1|0;if((O|0)>=(d|0)){P=33270;break}L=L+640|0;M=M+640|0;N=O}if((P|0)==33269){return}else if((P|0)==33270){return}}function dX5(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;e=c[3528502]|0;if((e|0)<=0){return}f=c[3528424]|0;g=c[3528504]|0;h=(g|0)<9;i=c[3528422]|0;j=f+32|0;k=f+36|0;l=f+40|0;m=f+44|0;n=f+48|0;o=f+52|0;p=f+56|0;q=f+60|0;r=c[2415164]&65535;s=c[2440386]|0;t=f+28|0;u=f+24|0;v=f+20|0;w=f+16|0;x=f+12|0;y=f+8|0;z=f+4|0;A=c[2415150]|0;B=c[2409606]|0;C=0;D=c[2385338]|0;while(1){if((a[D+(15-(c[f>>2]|0))|0]|0)!=0){b[B>>1]=r;b[A>>1]=c[s+(d[D+(15-(c[f>>2]|0))|0]<<2)>>2]&65535}if((a[D+(15-(c[z>>2]|0))|0]|0)!=0){b[B+2>>1]=r;b[A+2>>1]=c[s+(d[D+(15-(c[z>>2]|0))|0]<<2)>>2]&65535}if((a[D+(15-(c[y>>2]|0))|0]|0)!=0){b[B+4>>1]=r;b[A+4>>1]=c[s+(d[D+(15-(c[y>>2]|0))|0]<<2)>>2]&65535}if((a[D+(15-(c[x>>2]|0))|0]|0)!=0){b[B+6>>1]=r;b[A+6>>1]=c[s+(d[D+(15-(c[x>>2]|0))|0]<<2)>>2]&65535}if((a[D+(15-(c[w>>2]|0))|0]|0)!=0){b[B+8>>1]=r;b[A+8>>1]=c[s+(d[D+(15-(c[w>>2]|0))|0]<<2)>>2]&65535}if((a[D+(15-(c[v>>2]|0))|0]|0)!=0){b[B+10>>1]=r;b[A+10>>1]=c[s+(d[D+(15-(c[v>>2]|0))|0]<<2)>>2]&65535}if((a[D+(15-(c[u>>2]|0))|0]|0)!=0){b[B+12>>1]=r;b[A+12>>1]=c[s+(d[D+(15-(c[u>>2]|0))|0]<<2)>>2]&65535}if((a[D+(15-(c[t>>2]|0))|0]|0)!=0){b[B+14>>1]=r;b[A+14>>1]=c[s+(d[D+(15-(c[t>>2]|0))|0]<<2)>>2]&65535}do{if(!h){if((a[D+(15-(c[j>>2]|0))|0]|0)!=0){b[B+16>>1]=r;b[A+16>>1]=c[s+(d[D+(15-(c[j>>2]|0))|0]<<2)>>2]&65535}if((g|0)<10){break}if((a[D+(15-(c[k>>2]|0))|0]|0)!=0){b[B+18>>1]=r;b[A+18>>1]=c[s+(d[D+(15-(c[k>>2]|0))|0]<<2)>>2]&65535}if((g|0)<11){break}if((a[D+(15-(c[l>>2]|0))|0]|0)!=0){b[B+20>>1]=r;b[A+20>>1]=c[s+(d[D+(15-(c[l>>2]|0))|0]<<2)>>2]&65535}if((g|0)<12){break}if((a[D+(15-(c[m>>2]|0))|0]|0)!=0){b[B+22>>1]=r;b[A+22>>1]=c[s+(d[D+(15-(c[m>>2]|0))|0]<<2)>>2]&65535}if((g|0)<13){break}if((a[D+(15-(c[n>>2]|0))|0]|0)!=0){b[B+24>>1]=r;b[A+24>>1]=c[s+(d[D+(15-(c[n>>2]|0))|0]<<2)>>2]&65535}if((g|0)<14){break}if((a[D+(15-(c[o>>2]|0))|0]|0)!=0){b[B+26>>1]=r;b[A+26>>1]=c[s+(d[D+(15-(c[o>>2]|0))|0]<<2)>>2]&65535}if((g|0)<15){break}if((a[D+(15-(c[p>>2]|0))|0]|0)!=0){b[B+28>>1]=r;b[A+28>>1]=c[s+(d[D+(15-(c[p>>2]|0))|0]<<2)>>2]&65535}if((g|0)<16){break}if((a[D+(15-(c[q>>2]|0))|0]|0)==0){break}b[B+30>>1]=r;b[A+30>>1]=c[s+(d[D+(15-(c[q>>2]|0))|0]<<2)>>2]&65535}}while(0);E=D+(c[i+(C<<2)>>2]|0)|0;F=C+1|0;if((F|0)>=(e|0)){break}A=A+640|0;B=B+640|0;C=F;D=E}c[2385338]=E;return}function dX6(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;e=c[3528502]|0;if((e|0)<=0){return}f=c[2385456]|0;g=c[3528422]|0;h=c[2385468]|0;i=h>>>0<320;j=c[3528424]|0;k=c[2415164]&65535;l=c[2440386]|0;m=j+4|0;n=j+8|0;o=j+12|0;p=j+16|0;q=j+20|0;r=j+24|0;s=j+28|0;t=c[3528504]|0;u=(t|0)<9;v=(h+8|0)>>>0<320;w=j+32|0;x=(h+9|0)>>>0<320;y=j+36|0;z=(h+10|0)>>>0<320;A=j+40|0;B=(h+11|0)>>>0<320;C=j+44|0;D=(h+12|0)>>>0<320;E=j+48|0;F=(h+13|0)>>>0<320;G=j+52|0;H=(h+14|0)>>>0<320;I=j+56|0;J=(h+15|0)>>>0<320;K=j+60|0;L=c[2415150]|0;M=c[2409606]|0;N=0;L43979:while(1){O=f+N|0;do{if((O|0)>=0){if((O|0)>223){P=33382;break L43979}do{if(i){Q=c[2385338]|0;if((a[Q+(15-(c[j>>2]|0))|0]|0)==0){break}b[M>>1]=k;b[L>>1]=c[l+(d[Q+(15-(c[j>>2]|0))|0]<<2)>>2]&65535}}while(0);do{if((h+1|0)>>>0<320){Q=c[2385338]|0;if((a[Q+(15-(c[m>>2]|0))|0]|0)==0){break}b[M+2>>1]=k;b[L+2>>1]=c[l+(d[Q+(15-(c[m>>2]|0))|0]<<2)>>2]&65535}}while(0);do{if((h+2|0)>>>0<320){Q=c[2385338]|0;if((a[Q+(15-(c[n>>2]|0))|0]|0)==0){break}b[M+4>>1]=k;b[L+4>>1]=c[l+(d[Q+(15-(c[n>>2]|0))|0]<<2)>>2]&65535}}while(0);do{if((h+3|0)>>>0<320){Q=c[2385338]|0;if((a[Q+(15-(c[o>>2]|0))|0]|0)==0){break}b[M+6>>1]=k;b[L+6>>1]=c[l+(d[Q+(15-(c[o>>2]|0))|0]<<2)>>2]&65535}}while(0);do{if((h+4|0)>>>0<320){Q=c[2385338]|0;if((a[Q+(15-(c[p>>2]|0))|0]|0)==0){break}b[M+8>>1]=k;b[L+8>>1]=c[l+(d[Q+(15-(c[p>>2]|0))|0]<<2)>>2]&65535}}while(0);do{if((h+5|0)>>>0<320){Q=c[2385338]|0;if((a[Q+(15-(c[q>>2]|0))|0]|0)==0){break}b[M+10>>1]=k;b[L+10>>1]=c[l+(d[Q+(15-(c[q>>2]|0))|0]<<2)>>2]&65535}}while(0);do{if((h+6|0)>>>0<320){Q=c[2385338]|0;if((a[Q+(15-(c[r>>2]|0))|0]|0)==0){break}b[M+12>>1]=k;b[L+12>>1]=c[l+(d[Q+(15-(c[r>>2]|0))|0]<<2)>>2]&65535}}while(0);do{if((h+7|0)>>>0<320){Q=c[2385338]|0;if((a[Q+(15-(c[s>>2]|0))|0]|0)==0){break}b[M+14>>1]=k;b[L+14>>1]=c[l+(d[Q+(15-(c[s>>2]|0))|0]<<2)>>2]&65535}}while(0);if(u){break}do{if(v){Q=c[2385338]|0;if((a[Q+(15-(c[w>>2]|0))|0]|0)==0){break}b[M+16>>1]=k;b[L+16>>1]=c[l+(d[Q+(15-(c[w>>2]|0))|0]<<2)>>2]&65535}}while(0);if((t|0)<10){break}do{if(x){Q=c[2385338]|0;if((a[Q+(15-(c[y>>2]|0))|0]|0)==0){break}b[M+18>>1]=k;b[L+18>>1]=c[l+(d[Q+(15-(c[y>>2]|0))|0]<<2)>>2]&65535}}while(0);if((t|0)<11){break}do{if(z){Q=c[2385338]|0;if((a[Q+(15-(c[A>>2]|0))|0]|0)==0){break}b[M+20>>1]=k;b[L+20>>1]=c[l+(d[Q+(15-(c[A>>2]|0))|0]<<2)>>2]&65535}}while(0);if((t|0)<12){break}do{if(B){Q=c[2385338]|0;if((a[Q+(15-(c[C>>2]|0))|0]|0)==0){break}b[M+22>>1]=k;b[L+22>>1]=c[l+(d[Q+(15-(c[C>>2]|0))|0]<<2)>>2]&65535}}while(0);if((t|0)<13){break}do{if(D){Q=c[2385338]|0;if((a[Q+(15-(c[E>>2]|0))|0]|0)==0){break}b[M+24>>1]=k;b[L+24>>1]=c[l+(d[Q+(15-(c[E>>2]|0))|0]<<2)>>2]&65535}}while(0);if((t|0)<14){break}do{if(F){Q=c[2385338]|0;if((a[Q+(15-(c[G>>2]|0))|0]|0)==0){break}b[M+26>>1]=k;b[L+26>>1]=c[l+(d[Q+(15-(c[G>>2]|0))|0]<<2)>>2]&65535}}while(0);if((t|0)<15){break}do{if(H){Q=c[2385338]|0;if((a[Q+(15-(c[I>>2]|0))|0]|0)==0){break}b[M+28>>1]=k;b[L+28>>1]=c[l+(d[Q+(15-(c[I>>2]|0))|0]<<2)>>2]&65535}}while(0);if((t|0)<16|J^1){break}Q=c[2385338]|0;if((a[Q+(15-(c[K>>2]|0))|0]|0)==0){break}b[M+30>>1]=k;b[L+30>>1]=c[l+(d[Q+(15-(c[K>>2]|0))|0]<<2)>>2]&65535}}while(0);c[2385338]=(c[2385338]|0)+(c[g+(N<<2)>>2]|0);O=N+1|0;if((O|0)>=(e|0)){P=33383;break}L=L+640|0;M=M+640|0;N=O}if((P|0)==33382){return}else if((P|0)==33383){return}}function dX7(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;f=c[3528502]|0;if((f|0)<=0){return}g=c[3528424]|0;h=c[3528504]|0;i=(h|0)<9;j=c[3528422]|0;k=g+32|0;l=g+36|0;m=g+40|0;n=g+44|0;o=g+48|0;p=g+52|0;q=g+56|0;r=g+60|0;s=c[2415164]|0;t=s&65535;u=c[2440386]|0;v=g+28|0;w=g+24|0;x=g+20|0;y=g+16|0;z=g+12|0;A=g+8|0;B=g+4|0;C=c[2415150]|0;D=c[2409606]|0;E=0;F=c[2385338]|0;while(1){do{if((a[F+(15-(c[g>>2]|0))|0]|0)==0){G=F}else{if((e[D>>1]|0)>(s|0)){G=F;break}b[D>>1]=t;b[C>>1]=c[u+(d[F+(15-(c[g>>2]|0))|0]<<2)>>2]&65535;G=F}}while(0);do{if((a[G+(15-(c[B>>2]|0))|0]|0)==0){H=G}else{I=D+2|0;if((e[I>>1]|0)>(s|0)){H=G;break}b[I>>1]=t;b[C+2>>1]=c[u+(d[F+(15-(c[B>>2]|0))|0]<<2)>>2]&65535;H=F}}while(0);do{if((a[H+(15-(c[A>>2]|0))|0]|0)==0){J=H}else{I=D+4|0;if((e[I>>1]|0)>(s|0)){J=H;break}b[I>>1]=t;b[C+4>>1]=c[u+(d[F+(15-(c[A>>2]|0))|0]<<2)>>2]&65535;J=F}}while(0);do{if((a[J+(15-(c[z>>2]|0))|0]|0)==0){K=J}else{I=D+6|0;if((e[I>>1]|0)>(s|0)){K=J;break}b[I>>1]=t;b[C+6>>1]=c[u+(d[F+(15-(c[z>>2]|0))|0]<<2)>>2]&65535;K=F}}while(0);do{if((a[K+(15-(c[y>>2]|0))|0]|0)==0){L=K}else{I=D+8|0;if((e[I>>1]|0)>(s|0)){L=K;break}b[I>>1]=t;b[C+8>>1]=c[u+(d[F+(15-(c[y>>2]|0))|0]<<2)>>2]&65535;L=F}}while(0);do{if((a[L+(15-(c[x>>2]|0))|0]|0)==0){M=L}else{I=D+10|0;if((e[I>>1]|0)>(s|0)){M=L;break}b[I>>1]=t;b[C+10>>1]=c[u+(d[F+(15-(c[x>>2]|0))|0]<<2)>>2]&65535;M=F}}while(0);do{if((a[M+(15-(c[w>>2]|0))|0]|0)==0){N=M}else{I=D+12|0;if((e[I>>1]|0)>(s|0)){N=M;break}b[I>>1]=t;b[C+12>>1]=c[u+(d[F+(15-(c[w>>2]|0))|0]<<2)>>2]&65535;N=F}}while(0);do{if((a[N+(15-(c[v>>2]|0))|0]|0)!=0){I=D+14|0;if((e[I>>1]|0)>(s|0)){break}b[I>>1]=t;b[C+14>>1]=c[u+(d[F+(15-(c[v>>2]|0))|0]<<2)>>2]&65535}}while(0);do{if(!i){do{if((a[F+(15-(c[k>>2]|0))|0]|0)!=0){I=D+16|0;if((e[I>>1]|0)>(s|0)){break}b[I>>1]=t;b[C+16>>1]=c[u+(d[F+(15-(c[k>>2]|0))|0]<<2)>>2]&65535}}while(0);if((h|0)<10){break}do{if((a[F+(15-(c[l>>2]|0))|0]|0)!=0){I=D+18|0;if((e[I>>1]|0)>(s|0)){break}b[I>>1]=t;b[C+18>>1]=c[u+(d[F+(15-(c[l>>2]|0))|0]<<2)>>2]&65535}}while(0);if((h|0)<11){break}do{if((a[F+(15-(c[m>>2]|0))|0]|0)!=0){I=D+20|0;if((e[I>>1]|0)>(s|0)){break}b[I>>1]=t;b[C+20>>1]=c[u+(d[F+(15-(c[m>>2]|0))|0]<<2)>>2]&65535}}while(0);if((h|0)<12){break}do{if((a[F+(15-(c[n>>2]|0))|0]|0)!=0){I=D+22|0;if((e[I>>1]|0)>(s|0)){break}b[I>>1]=t;b[C+22>>1]=c[u+(d[F+(15-(c[n>>2]|0))|0]<<2)>>2]&65535}}while(0);if((h|0)<13){break}do{if((a[F+(15-(c[o>>2]|0))|0]|0)!=0){I=D+24|0;if((e[I>>1]|0)>(s|0)){break}b[I>>1]=t;b[C+24>>1]=c[u+(d[F+(15-(c[o>>2]|0))|0]<<2)>>2]&65535}}while(0);if((h|0)<14){break}do{if((a[F+(15-(c[p>>2]|0))|0]|0)!=0){I=D+26|0;if((e[I>>1]|0)>(s|0)){break}b[I>>1]=t;b[C+26>>1]=c[u+(d[F+(15-(c[p>>2]|0))|0]<<2)>>2]&65535}}while(0);if((h|0)<15){break}do{if((a[F+(15-(c[q>>2]|0))|0]|0)!=0){I=D+28|0;if((e[I>>1]|0)>(s|0)){break}b[I>>1]=t;b[C+28>>1]=c[u+(d[F+(15-(c[q>>2]|0))|0]<<2)>>2]&65535}}while(0);if((h|0)<16){break}if((a[F+(15-(c[r>>2]|0))|0]|0)==0){break}I=D+30|0;if((e[I>>1]|0)>(s|0)){break}b[I>>1]=t;b[C+30>>1]=c[u+(d[F+(15-(c[r>>2]|0))|0]<<2)>>2]&65535}}while(0);O=F+(c[j+(E<<2)>>2]|0)|0;I=E+1|0;if((I|0)>=(f|0)){break}C=C+640|0;D=D+640|0;E=I;F=O}c[2385338]=O;return}function dX8(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;f=c[3528502]|0;if((f|0)<=0){return}g=c[2385456]|0;h=c[3528422]|0;i=c[2385468]|0;j=i>>>0<320;k=c[3528424]|0;l=c[2415164]|0;m=l&65535;n=c[2440386]|0;o=k+4|0;p=k+8|0;q=k+12|0;r=k+16|0;s=k+20|0;t=k+24|0;u=k+28|0;v=c[3528504]|0;w=(v|0)<9;x=(i+8|0)>>>0<320;y=k+32|0;z=(i+9|0)>>>0<320;A=k+36|0;B=(i+10|0)>>>0<320;C=k+40|0;D=(i+11|0)>>>0<320;E=k+44|0;F=(i+12|0)>>>0<320;G=k+48|0;H=(i+13|0)>>>0<320;I=k+52|0;J=(i+14|0)>>>0<320;K=k+56|0;L=(i+15|0)>>>0<320;M=k+60|0;N=c[2415150]|0;O=c[2409606]|0;P=0;L44143:while(1){Q=g+P|0;do{if((Q|0)>=0){if((Q|0)>223){R=33527;break L44143}do{if(j){S=c[2385338]|0;if((a[S+(15-(c[k>>2]|0))|0]|0)==0){break}if((e[O>>1]|0)>(l|0)){break}b[O>>1]=m;b[N>>1]=c[n+(d[S+(15-(c[k>>2]|0))|0]<<2)>>2]&65535}}while(0);do{if((i+1|0)>>>0<320){S=c[2385338]|0;if((a[S+(15-(c[o>>2]|0))|0]|0)==0){break}T=O+2|0;if((e[T>>1]|0)>(l|0)){break}b[T>>1]=m;b[N+2>>1]=c[n+(d[S+(15-(c[o>>2]|0))|0]<<2)>>2]&65535}}while(0);do{if((i+2|0)>>>0<320){S=c[2385338]|0;if((a[S+(15-(c[p>>2]|0))|0]|0)==0){break}T=O+4|0;if((e[T>>1]|0)>(l|0)){break}b[T>>1]=m;b[N+4>>1]=c[n+(d[S+(15-(c[p>>2]|0))|0]<<2)>>2]&65535}}while(0);do{if((i+3|0)>>>0<320){S=c[2385338]|0;if((a[S+(15-(c[q>>2]|0))|0]|0)==0){break}T=O+6|0;if((e[T>>1]|0)>(l|0)){break}b[T>>1]=m;b[N+6>>1]=c[n+(d[S+(15-(c[q>>2]|0))|0]<<2)>>2]&65535}}while(0);do{if((i+4|0)>>>0<320){S=c[2385338]|0;if((a[S+(15-(c[r>>2]|0))|0]|0)==0){break}T=O+8|0;if((e[T>>1]|0)>(l|0)){break}b[T>>1]=m;b[N+8>>1]=c[n+(d[S+(15-(c[r>>2]|0))|0]<<2)>>2]&65535}}while(0);do{if((i+5|0)>>>0<320){S=c[2385338]|0;if((a[S+(15-(c[s>>2]|0))|0]|0)==0){break}T=O+10|0;if((e[T>>1]|0)>(l|0)){break}b[T>>1]=m;b[N+10>>1]=c[n+(d[S+(15-(c[s>>2]|0))|0]<<2)>>2]&65535}}while(0);do{if((i+6|0)>>>0<320){S=c[2385338]|0;if((a[S+(15-(c[t>>2]|0))|0]|0)==0){break}T=O+12|0;if((e[T>>1]|0)>(l|0)){break}b[T>>1]=m;b[N+12>>1]=c[n+(d[S+(15-(c[t>>2]|0))|0]<<2)>>2]&65535}}while(0);do{if((i+7|0)>>>0<320){S=c[2385338]|0;if((a[S+(15-(c[u>>2]|0))|0]|0)==0){break}T=O+14|0;if((e[T>>1]|0)>(l|0)){break}b[T>>1]=m;b[N+14>>1]=c[n+(d[S+(15-(c[u>>2]|0))|0]<<2)>>2]&65535}}while(0);if(w){break}do{if(x){S=c[2385338]|0;if((a[S+(15-(c[y>>2]|0))|0]|0)==0){break}T=O+16|0;if((e[T>>1]|0)>(l|0)){break}b[T>>1]=m;b[N+16>>1]=c[n+(d[S+(15-(c[y>>2]|0))|0]<<2)>>2]&65535}}while(0);if((v|0)<10){break}do{if(z){S=c[2385338]|0;if((a[S+(15-(c[A>>2]|0))|0]|0)==0){break}T=O+18|0;if((e[T>>1]|0)>(l|0)){break}b[T>>1]=m;b[N+18>>1]=c[n+(d[S+(15-(c[A>>2]|0))|0]<<2)>>2]&65535}}while(0);if((v|0)<11){break}do{if(B){S=c[2385338]|0;if((a[S+(15-(c[C>>2]|0))|0]|0)==0){break}T=O+20|0;if((e[T>>1]|0)>(l|0)){break}b[T>>1]=m;b[N+20>>1]=c[n+(d[S+(15-(c[C>>2]|0))|0]<<2)>>2]&65535}}while(0);if((v|0)<12){break}do{if(D){S=c[2385338]|0;if((a[S+(15-(c[E>>2]|0))|0]|0)==0){break}T=O+22|0;if((e[T>>1]|0)>(l|0)){break}b[T>>1]=m;b[N+22>>1]=c[n+(d[S+(15-(c[E>>2]|0))|0]<<2)>>2]&65535}}while(0);if((v|0)<13){break}do{if(F){S=c[2385338]|0;if((a[S+(15-(c[G>>2]|0))|0]|0)==0){break}T=O+24|0;if((e[T>>1]|0)>(l|0)){break}b[T>>1]=m;b[N+24>>1]=c[n+(d[S+(15-(c[G>>2]|0))|0]<<2)>>2]&65535}}while(0);if((v|0)<14){break}do{if(H){S=c[2385338]|0;if((a[S+(15-(c[I>>2]|0))|0]|0)==0){break}T=O+26|0;if((e[T>>1]|0)>(l|0)){break}b[T>>1]=m;b[N+26>>1]=c[n+(d[S+(15-(c[I>>2]|0))|0]<<2)>>2]&65535}}while(0);if((v|0)<15){break}do{if(J){S=c[2385338]|0;if((a[S+(15-(c[K>>2]|0))|0]|0)==0){break}T=O+28|0;if((e[T>>1]|0)>(l|0)){break}b[T>>1]=m;b[N+28>>1]=c[n+(d[S+(15-(c[K>>2]|0))|0]<<2)>>2]&65535}}while(0);if((v|0)<16|L^1){break}S=c[2385338]|0;if((a[S+(15-(c[M>>2]|0))|0]|0)==0){break}T=O+30|0;if((e[T>>1]|0)>(l|0)){break}b[T>>1]=m;b[N+30>>1]=c[n+(d[S+(15-(c[M>>2]|0))|0]<<2)>>2]&65535}}while(0);c[2385338]=(c[2385338]|0)+(c[h+(P<<2)>>2]|0);Q=P+1|0;if((Q|0)>=(f|0)){R=33529;break}N=N+640|0;O=O+640|0;P=Q}if((R|0)==33527){return}else if((R|0)==33529){return}}function dX9(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=c[3528502]|0;e=d-1|0;if((d|0)<=0){return}f=c[3528424]|0;g=c[3528504]|0;h=(g|0)<9;i=c[3528422]|0;j=f+32|0;k=f+36|0;l=f+40|0;m=f+44|0;n=f+48|0;o=f+52|0;p=f+56|0;q=f+60|0;r=c[2440386]|0;s=(c[2415150]|0)+(e*640|0)|0;t=e;e=c[2385338]|0;while(1){u=a[e+(c[f>>2]|0)|0]|0;if(u<<24>>24!=0){b[s>>1]=c[r+((u&255)<<2)>>2]&65535}u=a[e+(c[f+4>>2]|0)|0]|0;if(u<<24>>24!=0){b[s+2>>1]=c[r+((u&255)<<2)>>2]&65535}u=a[e+(c[f+8>>2]|0)|0]|0;if(u<<24>>24!=0){b[s+4>>1]=c[r+((u&255)<<2)>>2]&65535}u=a[e+(c[f+12>>2]|0)|0]|0;if(u<<24>>24!=0){b[s+6>>1]=c[r+((u&255)<<2)>>2]&65535}u=a[e+(c[f+16>>2]|0)|0]|0;if(u<<24>>24!=0){b[s+8>>1]=c[r+((u&255)<<2)>>2]&65535}u=a[e+(c[f+20>>2]|0)|0]|0;if(u<<24>>24!=0){b[s+10>>1]=c[r+((u&255)<<2)>>2]&65535}u=a[e+(c[f+24>>2]|0)|0]|0;if(u<<24>>24!=0){b[s+12>>1]=c[r+((u&255)<<2)>>2]&65535}u=a[e+(c[f+28>>2]|0)|0]|0;if(u<<24>>24!=0){b[s+14>>1]=c[r+((u&255)<<2)>>2]&65535}do{if(!h){u=a[e+(c[j>>2]|0)|0]|0;if(u<<24>>24!=0){b[s+16>>1]=c[r+((u&255)<<2)>>2]&65535}if((g|0)<10){break}u=a[e+(c[k>>2]|0)|0]|0;if(u<<24>>24!=0){b[s+18>>1]=c[r+((u&255)<<2)>>2]&65535}if((g|0)<11){break}u=a[e+(c[l>>2]|0)|0]|0;if(u<<24>>24!=0){b[s+20>>1]=c[r+((u&255)<<2)>>2]&65535}if((g|0)<12){break}u=a[e+(c[m>>2]|0)|0]|0;if(u<<24>>24!=0){b[s+22>>1]=c[r+((u&255)<<2)>>2]&65535}if((g|0)<13){break}u=a[e+(c[n>>2]|0)|0]|0;if(u<<24>>24!=0){b[s+24>>1]=c[r+((u&255)<<2)>>2]&65535}if((g|0)<14){break}u=a[e+(c[o>>2]|0)|0]|0;if(u<<24>>24!=0){b[s+26>>1]=c[r+((u&255)<<2)>>2]&65535}if((g|0)<15){break}u=a[e+(c[p>>2]|0)|0]|0;if(u<<24>>24!=0){b[s+28>>1]=c[r+((u&255)<<2)>>2]&65535}if((g|0)<16){break}u=a[e+(c[q>>2]|0)|0]|0;if(u<<24>>24==0){break}b[s+30>>1]=c[r+((u&255)<<2)>>2]&65535}}while(0);v=e+(c[i+(d+~t<<2)>>2]|0)|0;if((t|0)<=0){break}s=s-640|0;t=t-1|0;e=v}c[2385338]=v;return}function dYa(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;d=c[3528502]|0;e=d-1|0;if((d|0)<=0){return}f=c[2385456]|0;g=f+e|0;if((g|0)<0){return}h=c[3528422]|0;i=c[2385468]|0;j=i>>>0<320;k=c[3528424]|0;l=c[2440386]|0;m=k+4|0;n=k+8|0;o=k+12|0;p=k+16|0;q=k+20|0;r=k+24|0;s=k+28|0;t=c[3528504]|0;u=(t|0)<9;v=(i+8|0)>>>0<320;w=k+32|0;x=(i+9|0)>>>0<320;y=k+36|0;z=(i+10|0)>>>0<320;A=k+40|0;B=(i+11|0)>>>0<320;C=k+44|0;D=(i+12|0)>>>0<320;E=k+48|0;F=(i+13|0)>>>0<320;G=k+52|0;H=(i+14|0)>>>0<320;I=k+56|0;J=(i+15|0)>>>0<320;K=k+60|0;L=e;M=(c[2415150]|0)+(e*640|0)|0;e=g;g=c[2385338]|0;while(1){do{if((e|0)<=223){do{if(j){N=a[g+(c[k>>2]|0)|0]|0;if(N<<24>>24==0){break}b[M>>1]=c[l+((N&255)<<2)>>2]&65535}}while(0);do{if((i+1|0)>>>0<320){N=a[g+(c[m>>2]|0)|0]|0;if(N<<24>>24==0){break}b[M+2>>1]=c[l+((N&255)<<2)>>2]&65535}}while(0);do{if((i+2|0)>>>0<320){N=a[g+(c[n>>2]|0)|0]|0;if(N<<24>>24==0){break}b[M+4>>1]=c[l+((N&255)<<2)>>2]&65535}}while(0);do{if((i+3|0)>>>0<320){N=a[g+(c[o>>2]|0)|0]|0;if(N<<24>>24==0){break}b[M+6>>1]=c[l+((N&255)<<2)>>2]&65535}}while(0);do{if((i+4|0)>>>0<320){N=a[g+(c[p>>2]|0)|0]|0;if(N<<24>>24==0){break}b[M+8>>1]=c[l+((N&255)<<2)>>2]&65535}}while(0);do{if((i+5|0)>>>0<320){N=a[g+(c[q>>2]|0)|0]|0;if(N<<24>>24==0){break}b[M+10>>1]=c[l+((N&255)<<2)>>2]&65535}}while(0);do{if((i+6|0)>>>0<320){N=a[g+(c[r>>2]|0)|0]|0;if(N<<24>>24==0){break}b[M+12>>1]=c[l+((N&255)<<2)>>2]&65535}}while(0);do{if((i+7|0)>>>0<320){N=a[g+(c[s>>2]|0)|0]|0;if(N<<24>>24==0){break}b[M+14>>1]=c[l+((N&255)<<2)>>2]&65535}}while(0);if(u){break}do{if(v){N=a[g+(c[w>>2]|0)|0]|0;if(N<<24>>24==0){break}b[M+16>>1]=c[l+((N&255)<<2)>>2]&65535}}while(0);if((t|0)<10){break}do{if(x){N=a[g+(c[y>>2]|0)|0]|0;if(N<<24>>24==0){break}b[M+18>>1]=c[l+((N&255)<<2)>>2]&65535}}while(0);if((t|0)<11){break}do{if(z){N=a[g+(c[A>>2]|0)|0]|0;if(N<<24>>24==0){break}b[M+20>>1]=c[l+((N&255)<<2)>>2]&65535}}while(0);if((t|0)<12){break}do{if(B){N=a[g+(c[C>>2]|0)|0]|0;if(N<<24>>24==0){break}b[M+22>>1]=c[l+((N&255)<<2)>>2]&65535}}while(0);if((t|0)<13){break}do{if(D){N=a[g+(c[E>>2]|0)|0]|0;if(N<<24>>24==0){break}b[M+24>>1]=c[l+((N&255)<<2)>>2]&65535}}while(0);if((t|0)<14){break}do{if(F){N=a[g+(c[G>>2]|0)|0]|0;if(N<<24>>24==0){break}b[M+26>>1]=c[l+((N&255)<<2)>>2]&65535}}while(0);if((t|0)<15){break}do{if(H){N=a[g+(c[I>>2]|0)|0]|0;if(N<<24>>24==0){break}b[M+28>>1]=c[l+((N&255)<<2)>>2]&65535}}while(0);if((t|0)<16|J^1){break}N=a[g+(c[K>>2]|0)|0]|0;if(N<<24>>24==0){break}b[M+30>>1]=c[l+((N&255)<<2)>>2]&65535}}while(0);O=g+(c[h+(d+~L<<2)>>2]|0)|0;if((L|0)<=0){break}N=L-1|0;P=f+N|0;if((P|0)<0){break}else{L=N;M=M-640|0;e=P;g=O}}c[2385338]=O;return}function dYb(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;d=c[3528502]|0;f=d-1|0;if((d|0)<=0){return}g=c[3528424]|0;h=c[3528504]|0;i=(h|0)<9;j=c[3528422]|0;k=g+32|0;l=g+36|0;m=g+40|0;n=g+44|0;o=g+48|0;p=g+52|0;q=g+56|0;r=g+60|0;s=c[2415164]|0;t=c[2440386]|0;u=(c[2415150]|0)+(f*640|0)|0;v=(c[2409606]|0)+((f*320|0)<<1)|0;w=f;f=c[2385338]|0;while(1){x=a[f+(c[g>>2]|0)|0]|0;y=x&255;do{if(x<<24>>24==0){z=f}else{if((e[v>>1]|0|0)>(s|0)){z=f;break}b[u>>1]=c[t+(y<<2)>>2]&65535;z=f}}while(0);y=a[z+(c[g+4>>2]|0)|0]|0;x=y&255;do{if(y<<24>>24==0){A=z}else{if((e[v+2>>1]|0|0)>(s|0)){A=z;break}b[u+2>>1]=c[t+(x<<2)>>2]&65535;A=f}}while(0);x=a[A+(c[g+8>>2]|0)|0]|0;y=x&255;do{if(x<<24>>24==0){B=A}else{if((e[v+4>>1]|0|0)>(s|0)){B=A;break}b[u+4>>1]=c[t+(y<<2)>>2]&65535;B=f}}while(0);y=a[B+(c[g+12>>2]|0)|0]|0;x=y&255;do{if(y<<24>>24==0){C=B}else{if((e[v+6>>1]|0|0)>(s|0)){C=B;break}b[u+6>>1]=c[t+(x<<2)>>2]&65535;C=f}}while(0);x=a[C+(c[g+16>>2]|0)|0]|0;y=x&255;do{if(x<<24>>24==0){D=C}else{if((e[v+8>>1]|0|0)>(s|0)){D=C;break}b[u+8>>1]=c[t+(y<<2)>>2]&65535;D=f}}while(0);y=a[D+(c[g+20>>2]|0)|0]|0;x=y&255;do{if(y<<24>>24==0){E=D}else{if((e[v+10>>1]|0|0)>(s|0)){E=D;break}b[u+10>>1]=c[t+(x<<2)>>2]&65535;E=f}}while(0);x=a[E+(c[g+24>>2]|0)|0]|0;y=x&255;do{if(x<<24>>24==0){F=E}else{if((e[v+12>>1]|0|0)>(s|0)){F=E;break}b[u+12>>1]=c[t+(y<<2)>>2]&65535;F=f}}while(0);y=a[F+(c[g+28>>2]|0)|0]|0;x=y&255;do{if(y<<24>>24!=0){if((e[v+14>>1]|0|0)>(s|0)){break}b[u+14>>1]=c[t+(x<<2)>>2]&65535}}while(0);do{if(!i){x=a[f+(c[k>>2]|0)|0]|0;y=x&255;do{if(x<<24>>24!=0){if((e[v+16>>1]|0|0)>(s|0)){break}b[u+16>>1]=c[t+(y<<2)>>2]&65535}}while(0);if((h|0)<10){break}y=a[f+(c[l>>2]|0)|0]|0;x=y&255;do{if(y<<24>>24!=0){if((e[v+18>>1]|0|0)>(s|0)){break}b[u+18>>1]=c[t+(x<<2)>>2]&65535}}while(0);if((h|0)<11){break}x=a[f+(c[m>>2]|0)|0]|0;y=x&255;do{if(x<<24>>24!=0){if((e[v+20>>1]|0|0)>(s|0)){break}b[u+20>>1]=c[t+(y<<2)>>2]&65535}}while(0);if((h|0)<12){break}y=a[f+(c[n>>2]|0)|0]|0;x=y&255;do{if(y<<24>>24!=0){if((e[v+22>>1]|0|0)>(s|0)){break}b[u+22>>1]=c[t+(x<<2)>>2]&65535}}while(0);if((h|0)<13){break}x=a[f+(c[o>>2]|0)|0]|0;y=x&255;do{if(x<<24>>24!=0){if((e[v+24>>1]|0|0)>(s|0)){break}b[u+24>>1]=c[t+(y<<2)>>2]&65535}}while(0);if((h|0)<14){break}y=a[f+(c[p>>2]|0)|0]|0;x=y&255;do{if(y<<24>>24!=0){if((e[v+26>>1]|0|0)>(s|0)){break}b[u+26>>1]=c[t+(x<<2)>>2]&65535}}while(0);if((h|0)<15){break}x=a[f+(c[q>>2]|0)|0]|0;y=x&255;do{if(x<<24>>24!=0){if((e[v+28>>1]|0|0)>(s|0)){break}b[u+28>>1]=c[t+(y<<2)>>2]&65535}}while(0);if((h|0)<16){break}y=a[f+(c[r>>2]|0)|0]|0;if(y<<24>>24==0){break}if((e[v+30>>1]|0|0)>(s|0)){break}b[u+30>>1]=c[t+((y&255)<<2)>>2]&65535}}while(0);G=f+(c[j+(d+~w<<2)>>2]|0)|0;if((w|0)<=0){break}u=u-640|0;v=v-640|0;w=w-1|0;f=G}c[2385338]=G;return}function dYc(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;d=c[3528502]|0;f=d-1|0;if((d|0)<=0){return}g=c[2385456]|0;h=g+f|0;if((h|0)<0){return}i=c[3528422]|0;j=c[2385468]|0;k=j>>>0<320;l=c[3528424]|0;m=c[2415164]|0;n=c[2440386]|0;o=l+4|0;p=l+8|0;q=l+12|0;r=l+16|0;s=l+20|0;t=l+24|0;u=l+28|0;v=c[3528504]|0;w=(v|0)<9;x=(j+8|0)>>>0<320;y=l+32|0;z=(j+9|0)>>>0<320;A=l+36|0;B=(j+10|0)>>>0<320;C=l+40|0;D=(j+11|0)>>>0<320;E=l+44|0;F=(j+12|0)>>>0<320;G=l+48|0;H=(j+13|0)>>>0<320;I=l+52|0;J=(j+14|0)>>>0<320;K=l+56|0;L=(j+15|0)>>>0<320;M=l+60|0;N=f;O=(c[2409606]|0)+((f*320|0)<<1)|0;P=(c[2415150]|0)+(f*640|0)|0;f=h;h=c[2385338]|0;while(1){do{if((f|0)<=223){do{if(k){Q=a[h+(c[l>>2]|0)|0]|0;if(Q<<24>>24==0){break}if((e[O>>1]|0|0)>(m|0)){break}b[P>>1]=c[n+((Q&255)<<2)>>2]&65535}}while(0);do{if((j+1|0)>>>0<320){Q=a[h+(c[o>>2]|0)|0]|0;if(Q<<24>>24==0){break}if((e[O+2>>1]|0|0)>(m|0)){break}b[P+2>>1]=c[n+((Q&255)<<2)>>2]&65535}}while(0);do{if((j+2|0)>>>0<320){Q=a[h+(c[p>>2]|0)|0]|0;if(Q<<24>>24==0){break}if((e[O+4>>1]|0|0)>(m|0)){break}b[P+4>>1]=c[n+((Q&255)<<2)>>2]&65535}}while(0);do{if((j+3|0)>>>0<320){Q=a[h+(c[q>>2]|0)|0]|0;if(Q<<24>>24==0){break}if((e[O+6>>1]|0|0)>(m|0)){break}b[P+6>>1]=c[n+((Q&255)<<2)>>2]&65535}}while(0);do{if((j+4|0)>>>0<320){Q=a[h+(c[r>>2]|0)|0]|0;if(Q<<24>>24==0){break}if((e[O+8>>1]|0|0)>(m|0)){break}b[P+8>>1]=c[n+((Q&255)<<2)>>2]&65535}}while(0);do{if((j+5|0)>>>0<320){Q=a[h+(c[s>>2]|0)|0]|0;if(Q<<24>>24==0){break}if((e[O+10>>1]|0|0)>(m|0)){break}b[P+10>>1]=c[n+((Q&255)<<2)>>2]&65535}}while(0);do{if((j+6|0)>>>0<320){Q=a[h+(c[t>>2]|0)|0]|0;if(Q<<24>>24==0){break}if((e[O+12>>1]|0|0)>(m|0)){break}b[P+12>>1]=c[n+((Q&255)<<2)>>2]&65535}}while(0);do{if((j+7|0)>>>0<320){Q=a[h+(c[u>>2]|0)|0]|0;if(Q<<24>>24==0){break}if((e[O+14>>1]|0|0)>(m|0)){break}b[P+14>>1]=c[n+((Q&255)<<2)>>2]&65535}}while(0);if(w){break}do{if(x){Q=a[h+(c[y>>2]|0)|0]|0;if(Q<<24>>24==0){break}if((e[O+16>>1]|0|0)>(m|0)){break}b[P+16>>1]=c[n+((Q&255)<<2)>>2]&65535}}while(0);if((v|0)<10){break}do{if(z){Q=a[h+(c[A>>2]|0)|0]|0;if(Q<<24>>24==0){break}if((e[O+18>>1]|0|0)>(m|0)){break}b[P+18>>1]=c[n+((Q&255)<<2)>>2]&65535}}while(0);if((v|0)<11){break}do{if(B){Q=a[h+(c[C>>2]|0)|0]|0;if(Q<<24>>24==0){break}if((e[O+20>>1]|0|0)>(m|0)){break}b[P+20>>1]=c[n+((Q&255)<<2)>>2]&65535}}while(0);if((v|0)<12){break}do{if(D){Q=a[h+(c[E>>2]|0)|0]|0;if(Q<<24>>24==0){break}if((e[O+22>>1]|0|0)>(m|0)){break}b[P+22>>1]=c[n+((Q&255)<<2)>>2]&65535}}while(0);if((v|0)<13){break}do{if(F){Q=a[h+(c[G>>2]|0)|0]|0;if(Q<<24>>24==0){break}if((e[O+24>>1]|0|0)>(m|0)){break}b[P+24>>1]=c[n+((Q&255)<<2)>>2]&65535}}while(0);if((v|0)<14){break}do{if(H){Q=a[h+(c[I>>2]|0)|0]|0;if(Q<<24>>24==0){break}if((e[O+26>>1]|0|0)>(m|0)){break}b[P+26>>1]=c[n+((Q&255)<<2)>>2]&65535}}while(0);if((v|0)<15){break}do{if(J){Q=a[h+(c[K>>2]|0)|0]|0;if(Q<<24>>24==0){break}if((e[O+28>>1]|0|0)>(m|0)){break}b[P+28>>1]=c[n+((Q&255)<<2)>>2]&65535}}while(0);if((v|0)<16|L^1){break}Q=a[h+(c[M>>2]|0)|0]|0;if(Q<<24>>24==0){break}if((e[O+30>>1]|0|0)>(m|0)){break}b[P+30>>1]=c[n+((Q&255)<<2)>>2]&65535}}while(0);R=h+(c[i+(d+~N<<2)>>2]|0)|0;if((N|0)<=0){break}Q=N-1|0;S=g+Q|0;if((S|0)<0){break}else{N=Q;O=O-640|0;P=P-640|0;f=S;h=R}}c[2385338]=R;return}function dYd(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;e=c[3528502]|0;f=e-1|0;if((e|0)<=0){return}g=c[3528424]|0;h=c[3528504]|0;i=(h|0)<9;j=c[3528422]|0;k=g+32|0;l=g+36|0;m=g+40|0;n=g+44|0;o=g+48|0;p=g+52|0;q=g+56|0;r=g+60|0;s=c[2415164]&65535;t=c[2440386]|0;u=g+28|0;v=g+24|0;w=g+20|0;x=g+16|0;y=g+12|0;z=g+8|0;A=g+4|0;B=(c[2415150]|0)+(f*640|0)|0;C=(c[2409606]|0)+((f*320|0)<<1)|0;D=f;f=c[2385338]|0;while(1){if((a[f+(c[g>>2]|0)|0]|0)!=0){b[C>>1]=s;b[B>>1]=c[t+(d[f+(c[g>>2]|0)|0]<<2)>>2]&65535}if((a[f+(c[A>>2]|0)|0]|0)!=0){b[C+2>>1]=s;b[B+2>>1]=c[t+(d[f+(c[A>>2]|0)|0]<<2)>>2]&65535}if((a[f+(c[z>>2]|0)|0]|0)!=0){b[C+4>>1]=s;b[B+4>>1]=c[t+(d[f+(c[z>>2]|0)|0]<<2)>>2]&65535}if((a[f+(c[y>>2]|0)|0]|0)!=0){b[C+6>>1]=s;b[B+6>>1]=c[t+(d[f+(c[y>>2]|0)|0]<<2)>>2]&65535}if((a[f+(c[x>>2]|0)|0]|0)!=0){b[C+8>>1]=s;b[B+8>>1]=c[t+(d[f+(c[x>>2]|0)|0]<<2)>>2]&65535}if((a[f+(c[w>>2]|0)|0]|0)!=0){b[C+10>>1]=s;b[B+10>>1]=c[t+(d[f+(c[w>>2]|0)|0]<<2)>>2]&65535}if((a[f+(c[v>>2]|0)|0]|0)!=0){b[C+12>>1]=s;b[B+12>>1]=c[t+(d[f+(c[v>>2]|0)|0]<<2)>>2]&65535}if((a[f+(c[u>>2]|0)|0]|0)!=0){b[C+14>>1]=s;b[B+14>>1]=c[t+(d[f+(c[u>>2]|0)|0]<<2)>>2]&65535}do{if(!i){if((a[f+(c[k>>2]|0)|0]|0)!=0){b[C+16>>1]=s;b[B+16>>1]=c[t+(d[f+(c[k>>2]|0)|0]<<2)>>2]&65535}if((h|0)<10){break}if((a[f+(c[l>>2]|0)|0]|0)!=0){b[C+18>>1]=s;b[B+18>>1]=c[t+(d[f+(c[l>>2]|0)|0]<<2)>>2]&65535}if((h|0)<11){break}if((a[f+(c[m>>2]|0)|0]|0)!=0){b[C+20>>1]=s;b[B+20>>1]=c[t+(d[f+(c[m>>2]|0)|0]<<2)>>2]&65535}if((h|0)<12){break}if((a[f+(c[n>>2]|0)|0]|0)!=0){b[C+22>>1]=s;b[B+22>>1]=c[t+(d[f+(c[n>>2]|0)|0]<<2)>>2]&65535}if((h|0)<13){break}if((a[f+(c[o>>2]|0)|0]|0)!=0){b[C+24>>1]=s;b[B+24>>1]=c[t+(d[f+(c[o>>2]|0)|0]<<2)>>2]&65535}if((h|0)<14){break}if((a[f+(c[p>>2]|0)|0]|0)!=0){b[C+26>>1]=s;b[B+26>>1]=c[t+(d[f+(c[p>>2]|0)|0]<<2)>>2]&65535}if((h|0)<15){break}if((a[f+(c[q>>2]|0)|0]|0)!=0){b[C+28>>1]=s;b[B+28>>1]=c[t+(d[f+(c[q>>2]|0)|0]<<2)>>2]&65535}if((h|0)<16){break}if((a[f+(c[r>>2]|0)|0]|0)==0){break}b[C+30>>1]=s;b[B+30>>1]=c[t+(d[f+(c[r>>2]|0)|0]<<2)>>2]&65535}}while(0);E=f+(c[j+(e+~D<<2)>>2]|0)|0;if((D|0)<=0){break}B=B-640|0;C=C-640|0;D=D-1|0;f=E}c[2385338]=E;return}function dYe(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;e=c[3528502]|0;f=e-1|0;if((e|0)<=0){return}g=c[2385456]|0;h=g+f|0;if((h|0)<0){return}i=c[3528422]|0;j=c[2385468]|0;k=j>>>0<320;l=c[3528424]|0;m=c[2415164]&65535;n=c[2440386]|0;o=l+4|0;p=l+8|0;q=l+12|0;r=l+16|0;s=l+20|0;t=l+24|0;u=l+28|0;v=c[3528504]|0;w=(v|0)<9;x=(j+8|0)>>>0<320;y=l+32|0;z=(j+9|0)>>>0<320;A=l+36|0;B=(j+10|0)>>>0<320;C=l+40|0;D=(j+11|0)>>>0<320;E=l+44|0;F=(j+12|0)>>>0<320;G=l+48|0;H=(j+13|0)>>>0<320;I=l+52|0;J=(j+14|0)>>>0<320;K=l+56|0;L=(j+15|0)>>>0<320;M=l+60|0;N=f;O=(c[2409606]|0)+((f*320|0)<<1)|0;P=(c[2415150]|0)+(f*640|0)|0;f=h;h=c[2385338]|0;while(1){do{if((f|0)<=223){do{if(k){if((a[h+(c[l>>2]|0)|0]|0)==0){break}b[O>>1]=m;b[P>>1]=c[n+(d[h+(c[l>>2]|0)|0]<<2)>>2]&65535}}while(0);do{if((j+1|0)>>>0<320){if((a[h+(c[o>>2]|0)|0]|0)==0){break}b[O+2>>1]=m;b[P+2>>1]=c[n+(d[h+(c[o>>2]|0)|0]<<2)>>2]&65535}}while(0);do{if((j+2|0)>>>0<320){if((a[h+(c[p>>2]|0)|0]|0)==0){break}b[O+4>>1]=m;b[P+4>>1]=c[n+(d[h+(c[p>>2]|0)|0]<<2)>>2]&65535}}while(0);do{if((j+3|0)>>>0<320){if((a[h+(c[q>>2]|0)|0]|0)==0){break}b[O+6>>1]=m;b[P+6>>1]=c[n+(d[h+(c[q>>2]|0)|0]<<2)>>2]&65535}}while(0);do{if((j+4|0)>>>0<320){if((a[h+(c[r>>2]|0)|0]|0)==0){break}b[O+8>>1]=m;b[P+8>>1]=c[n+(d[h+(c[r>>2]|0)|0]<<2)>>2]&65535}}while(0);do{if((j+5|0)>>>0<320){if((a[h+(c[s>>2]|0)|0]|0)==0){break}b[O+10>>1]=m;b[P+10>>1]=c[n+(d[h+(c[s>>2]|0)|0]<<2)>>2]&65535}}while(0);do{if((j+6|0)>>>0<320){if((a[h+(c[t>>2]|0)|0]|0)==0){break}b[O+12>>1]=m;b[P+12>>1]=c[n+(d[h+(c[t>>2]|0)|0]<<2)>>2]&65535}}while(0);do{if((j+7|0)>>>0<320){if((a[h+(c[u>>2]|0)|0]|0)==0){break}b[O+14>>1]=m;b[P+14>>1]=c[n+(d[h+(c[u>>2]|0)|0]<<2)>>2]&65535}}while(0);if(w){break}do{if(x){if((a[h+(c[y>>2]|0)|0]|0)==0){break}b[O+16>>1]=m;b[P+16>>1]=c[n+(d[h+(c[y>>2]|0)|0]<<2)>>2]&65535}}while(0);if((v|0)<10){break}do{if(z){if((a[h+(c[A>>2]|0)|0]|0)==0){break}b[O+18>>1]=m;b[P+18>>1]=c[n+(d[h+(c[A>>2]|0)|0]<<2)>>2]&65535}}while(0);if((v|0)<11){break}do{if(B){if((a[h+(c[C>>2]|0)|0]|0)==0){break}b[O+20>>1]=m;b[P+20>>1]=c[n+(d[h+(c[C>>2]|0)|0]<<2)>>2]&65535}}while(0);if((v|0)<12){break}do{if(D){if((a[h+(c[E>>2]|0)|0]|0)==0){break}b[O+22>>1]=m;b[P+22>>1]=c[n+(d[h+(c[E>>2]|0)|0]<<2)>>2]&65535}}while(0);if((v|0)<13){break}do{if(F){if((a[h+(c[G>>2]|0)|0]|0)==0){break}b[O+24>>1]=m;b[P+24>>1]=c[n+(d[h+(c[G>>2]|0)|0]<<2)>>2]&65535}}while(0);if((v|0)<14){break}do{if(H){if((a[h+(c[I>>2]|0)|0]|0)==0){break}b[O+26>>1]=m;b[P+26>>1]=c[n+(d[h+(c[I>>2]|0)|0]<<2)>>2]&65535}}while(0);if((v|0)<15){break}do{if(J){if((a[h+(c[K>>2]|0)|0]|0)==0){break}b[O+28>>1]=m;b[P+28>>1]=c[n+(d[h+(c[K>>2]|0)|0]<<2)>>2]&65535}}while(0);if((v|0)<16|L^1){break}if((a[h+(c[M>>2]|0)|0]|0)==0){break}b[O+30>>1]=m;b[P+30>>1]=c[n+(d[h+(c[M>>2]|0)|0]<<2)>>2]&65535}}while(0);Q=h+(c[i+(e+~N<<2)>>2]|0)|0;if((N|0)<=0){break}R=N-1|0;S=g+R|0;if((S|0)<0){break}else{N=R;O=O-640|0;P=P-640|0;f=S;h=Q}}c[2385338]=Q;return}function dYf(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;f=c[3528502]|0;g=f-1|0;if((f|0)<=0){return}h=c[3528424]|0;i=c[3528504]|0;j=(i|0)<9;k=c[3528422]|0;l=h+32|0;m=h+36|0;n=h+40|0;o=h+44|0;p=h+48|0;q=h+52|0;r=h+56|0;s=h+60|0;t=c[2415164]|0;u=t&65535;v=c[2440386]|0;w=h+28|0;x=h+24|0;y=h+20|0;z=h+16|0;A=h+12|0;B=h+8|0;C=h+4|0;D=(c[2415150]|0)+(g*640|0)|0;E=(c[2409606]|0)+((g*320|0)<<1)|0;F=g;g=c[2385338]|0;while(1){do{if((a[g+(c[h>>2]|0)|0]|0)==0){G=g}else{if((e[E>>1]|0)>(t|0)){G=g;break}b[E>>1]=u;b[D>>1]=c[v+(d[g+(c[h>>2]|0)|0]<<2)>>2]&65535;G=g}}while(0);do{if((a[G+(c[C>>2]|0)|0]|0)==0){H=G}else{I=E+2|0;if((e[I>>1]|0)>(t|0)){H=G;break}b[I>>1]=u;b[D+2>>1]=c[v+(d[g+(c[C>>2]|0)|0]<<2)>>2]&65535;H=g}}while(0);do{if((a[H+(c[B>>2]|0)|0]|0)==0){J=H}else{I=E+4|0;if((e[I>>1]|0)>(t|0)){J=H;break}b[I>>1]=u;b[D+4>>1]=c[v+(d[g+(c[B>>2]|0)|0]<<2)>>2]&65535;J=g}}while(0);do{if((a[J+(c[A>>2]|0)|0]|0)==0){K=J}else{I=E+6|0;if((e[I>>1]|0)>(t|0)){K=J;break}b[I>>1]=u;b[D+6>>1]=c[v+(d[g+(c[A>>2]|0)|0]<<2)>>2]&65535;K=g}}while(0);do{if((a[K+(c[z>>2]|0)|0]|0)==0){L=K}else{I=E+8|0;if((e[I>>1]|0)>(t|0)){L=K;break}b[I>>1]=u;b[D+8>>1]=c[v+(d[g+(c[z>>2]|0)|0]<<2)>>2]&65535;L=g}}while(0);do{if((a[L+(c[y>>2]|0)|0]|0)==0){M=L}else{I=E+10|0;if((e[I>>1]|0)>(t|0)){M=L;break}b[I>>1]=u;b[D+10>>1]=c[v+(d[g+(c[y>>2]|0)|0]<<2)>>2]&65535;M=g}}while(0);do{if((a[M+(c[x>>2]|0)|0]|0)==0){N=M}else{I=E+12|0;if((e[I>>1]|0)>(t|0)){N=M;break}b[I>>1]=u;b[D+12>>1]=c[v+(d[g+(c[x>>2]|0)|0]<<2)>>2]&65535;N=g}}while(0);do{if((a[N+(c[w>>2]|0)|0]|0)!=0){I=E+14|0;if((e[I>>1]|0)>(t|0)){break}b[I>>1]=u;b[D+14>>1]=c[v+(d[g+(c[w>>2]|0)|0]<<2)>>2]&65535}}while(0);do{if(!j){do{if((a[g+(c[l>>2]|0)|0]|0)!=0){I=E+16|0;if((e[I>>1]|0)>(t|0)){break}b[I>>1]=u;b[D+16>>1]=c[v+(d[g+(c[l>>2]|0)|0]<<2)>>2]&65535}}while(0);if((i|0)<10){break}do{if((a[g+(c[m>>2]|0)|0]|0)!=0){I=E+18|0;if((e[I>>1]|0)>(t|0)){break}b[I>>1]=u;b[D+18>>1]=c[v+(d[g+(c[m>>2]|0)|0]<<2)>>2]&65535}}while(0);if((i|0)<11){break}do{if((a[g+(c[n>>2]|0)|0]|0)!=0){I=E+20|0;if((e[I>>1]|0)>(t|0)){break}b[I>>1]=u;b[D+20>>1]=c[v+(d[g+(c[n>>2]|0)|0]<<2)>>2]&65535}}while(0);if((i|0)<12){break}do{if((a[g+(c[o>>2]|0)|0]|0)!=0){I=E+22|0;if((e[I>>1]|0)>(t|0)){break}b[I>>1]=u;b[D+22>>1]=c[v+(d[g+(c[o>>2]|0)|0]<<2)>>2]&65535}}while(0);if((i|0)<13){break}do{if((a[g+(c[p>>2]|0)|0]|0)!=0){I=E+24|0;if((e[I>>1]|0)>(t|0)){break}b[I>>1]=u;b[D+24>>1]=c[v+(d[g+(c[p>>2]|0)|0]<<2)>>2]&65535}}while(0);if((i|0)<14){break}do{if((a[g+(c[q>>2]|0)|0]|0)!=0){I=E+26|0;if((e[I>>1]|0)>(t|0)){break}b[I>>1]=u;b[D+26>>1]=c[v+(d[g+(c[q>>2]|0)|0]<<2)>>2]&65535}}while(0);if((i|0)<15){break}do{if((a[g+(c[r>>2]|0)|0]|0)!=0){I=E+28|0;if((e[I>>1]|0)>(t|0)){break}b[I>>1]=u;b[D+28>>1]=c[v+(d[g+(c[r>>2]|0)|0]<<2)>>2]&65535}}while(0);if((i|0)<16){break}if((a[g+(c[s>>2]|0)|0]|0)==0){break}I=E+30|0;if((e[I>>1]|0)>(t|0)){break}b[I>>1]=u;b[D+30>>1]=c[v+(d[g+(c[s>>2]|0)|0]<<2)>>2]&65535}}while(0);O=g+(c[k+(f+~F<<2)>>2]|0)|0;if((F|0)<=0){break}D=D-640|0;E=E-640|0;F=F-1|0;g=O}c[2385338]=O;return}function dYg(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;f=c[3528502]|0;g=f-1|0;if((f|0)<=0){return}h=c[2385456]|0;i=h+g|0;if((i|0)<0){return}j=c[3528422]|0;k=c[2385468]|0;l=k>>>0<320;m=c[3528424]|0;n=c[2415164]|0;o=n&65535;p=c[2440386]|0;q=m+4|0;r=m+8|0;s=m+12|0;t=m+16|0;u=m+20|0;v=m+24|0;w=m+28|0;x=c[3528504]|0;y=(x|0)<9;z=(k+8|0)>>>0<320;A=m+32|0;B=(k+9|0)>>>0<320;C=m+36|0;D=(k+10|0)>>>0<320;E=m+40|0;F=(k+11|0)>>>0<320;G=m+44|0;H=(k+12|0)>>>0<320;I=m+48|0;J=(k+13|0)>>>0<320;K=m+52|0;L=(k+14|0)>>>0<320;M=m+56|0;N=(k+15|0)>>>0<320;O=m+60|0;P=g;Q=(c[2409606]|0)+((g*320|0)<<1)|0;R=(c[2415150]|0)+(g*640|0)|0;g=i;i=c[2385338]|0;while(1){do{if((g|0)<=223){do{if(l){if((a[i+(c[m>>2]|0)|0]|0)==0){break}if((e[Q>>1]|0)>(n|0)){break}b[Q>>1]=o;b[R>>1]=c[p+(d[i+(c[m>>2]|0)|0]<<2)>>2]&65535}}while(0);do{if((k+1|0)>>>0<320){if((a[i+(c[q>>2]|0)|0]|0)==0){break}S=Q+2|0;if((e[S>>1]|0)>(n|0)){break}b[S>>1]=o;b[R+2>>1]=c[p+(d[i+(c[q>>2]|0)|0]<<2)>>2]&65535}}while(0);do{if((k+2|0)>>>0<320){if((a[i+(c[r>>2]|0)|0]|0)==0){break}S=Q+4|0;if((e[S>>1]|0)>(n|0)){break}b[S>>1]=o;b[R+4>>1]=c[p+(d[i+(c[r>>2]|0)|0]<<2)>>2]&65535}}while(0);do{if((k+3|0)>>>0<320){if((a[i+(c[s>>2]|0)|0]|0)==0){break}S=Q+6|0;if((e[S>>1]|0)>(n|0)){break}b[S>>1]=o;b[R+6>>1]=c[p+(d[i+(c[s>>2]|0)|0]<<2)>>2]&65535}}while(0);do{if((k+4|0)>>>0<320){if((a[i+(c[t>>2]|0)|0]|0)==0){break}S=Q+8|0;if((e[S>>1]|0)>(n|0)){break}b[S>>1]=o;b[R+8>>1]=c[p+(d[i+(c[t>>2]|0)|0]<<2)>>2]&65535}}while(0);do{if((k+5|0)>>>0<320){if((a[i+(c[u>>2]|0)|0]|0)==0){break}S=Q+10|0;if((e[S>>1]|0)>(n|0)){break}b[S>>1]=o;b[R+10>>1]=c[p+(d[i+(c[u>>2]|0)|0]<<2)>>2]&65535}}while(0);do{if((k+6|0)>>>0<320){if((a[i+(c[v>>2]|0)|0]|0)==0){break}S=Q+12|0;if((e[S>>1]|0)>(n|0)){break}b[S>>1]=o;b[R+12>>1]=c[p+(d[i+(c[v>>2]|0)|0]<<2)>>2]&65535}}while(0);do{if((k+7|0)>>>0<320){if((a[i+(c[w>>2]|0)|0]|0)==0){break}S=Q+14|0;if((e[S>>1]|0)>(n|0)){break}b[S>>1]=o;b[R+14>>1]=c[p+(d[i+(c[w>>2]|0)|0]<<2)>>2]&65535}}while(0);if(y){break}do{if(z){if((a[i+(c[A>>2]|0)|0]|0)==0){break}S=Q+16|0;if((e[S>>1]|0)>(n|0)){break}b[S>>1]=o;b[R+16>>1]=c[p+(d[i+(c[A>>2]|0)|0]<<2)>>2]&65535}}while(0);if((x|0)<10){break}do{if(B){if((a[i+(c[C>>2]|0)|0]|0)==0){break}S=Q+18|0;if((e[S>>1]|0)>(n|0)){break}b[S>>1]=o;b[R+18>>1]=c[p+(d[i+(c[C>>2]|0)|0]<<2)>>2]&65535}}while(0);if((x|0)<11){break}do{if(D){if((a[i+(c[E>>2]|0)|0]|0)==0){break}S=Q+20|0;if((e[S>>1]|0)>(n|0)){break}b[S>>1]=o;b[R+20>>1]=c[p+(d[i+(c[E>>2]|0)|0]<<2)>>2]&65535}}while(0);if((x|0)<12){break}do{if(F){if((a[i+(c[G>>2]|0)|0]|0)==0){break}S=Q+22|0;if((e[S>>1]|0)>(n|0)){break}b[S>>1]=o;b[R+22>>1]=c[p+(d[i+(c[G>>2]|0)|0]<<2)>>2]&65535}}while(0);if((x|0)<13){break}do{if(H){if((a[i+(c[I>>2]|0)|0]|0)==0){break}S=Q+24|0;if((e[S>>1]|0)>(n|0)){break}b[S>>1]=o;b[R+24>>1]=c[p+(d[i+(c[I>>2]|0)|0]<<2)>>2]&65535}}while(0);if((x|0)<14){break}do{if(J){if((a[i+(c[K>>2]|0)|0]|0)==0){break}S=Q+26|0;if((e[S>>1]|0)>(n|0)){break}b[S>>1]=o;b[R+26>>1]=c[p+(d[i+(c[K>>2]|0)|0]<<2)>>2]&65535}}while(0);if((x|0)<15){break}do{if(L){if((a[i+(c[M>>2]|0)|0]|0)==0){break}S=Q+28|0;if((e[S>>1]|0)>(n|0)){break}b[S>>1]=o;b[R+28>>1]=c[p+(d[i+(c[M>>2]|0)|0]<<2)>>2]&65535}}while(0);if((x|0)<16|N^1){break}if((a[i+(c[O>>2]|0)|0]|0)==0){break}S=Q+30|0;if((e[S>>1]|0)>(n|0)){break}b[S>>1]=o;b[R+30>>1]=c[p+(d[i+(c[O>>2]|0)|0]<<2)>>2]&65535}}while(0);T=i+(c[j+(f+~P<<2)>>2]|0)|0;if((P|0)<=0){break}S=P-1|0;U=h+S|0;if((U|0)<0){break}else{P=S;Q=Q-640|0;R=R-640|0;g=U;i=T}}c[2385338]=T;return}function dYh(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=c[3528502]|0;e=d-1|0;if((d|0)<=0){return}f=c[3528424]|0;g=c[3528504]|0;h=(g|0)<9;i=c[3528422]|0;j=f+32|0;k=f+36|0;l=f+40|0;m=f+44|0;n=f+48|0;o=f+52|0;p=f+56|0;q=f+60|0;r=c[2440386]|0;s=(c[2415150]|0)+(e*640|0)|0;t=e;e=c[2385338]|0;while(1){u=a[e+(15-(c[f>>2]|0))|0]|0;if(u<<24>>24!=0){b[s>>1]=c[r+((u&255)<<2)>>2]&65535}u=a[e+(15-(c[f+4>>2]|0))|0]|0;if(u<<24>>24!=0){b[s+2>>1]=c[r+((u&255)<<2)>>2]&65535}u=a[e+(15-(c[f+8>>2]|0))|0]|0;if(u<<24>>24!=0){b[s+4>>1]=c[r+((u&255)<<2)>>2]&65535}u=a[e+(15-(c[f+12>>2]|0))|0]|0;if(u<<24>>24!=0){b[s+6>>1]=c[r+((u&255)<<2)>>2]&65535}u=a[e+(15-(c[f+16>>2]|0))|0]|0;if(u<<24>>24!=0){b[s+8>>1]=c[r+((u&255)<<2)>>2]&65535}u=a[e+(15-(c[f+20>>2]|0))|0]|0;if(u<<24>>24!=0){b[s+10>>1]=c[r+((u&255)<<2)>>2]&65535}u=a[e+(15-(c[f+24>>2]|0))|0]|0;if(u<<24>>24!=0){b[s+12>>1]=c[r+((u&255)<<2)>>2]&65535}u=a[e+(15-(c[f+28>>2]|0))|0]|0;if(u<<24>>24!=0){b[s+14>>1]=c[r+((u&255)<<2)>>2]&65535}do{if(!h){u=a[e+(15-(c[j>>2]|0))|0]|0;if(u<<24>>24!=0){b[s+16>>1]=c[r+((u&255)<<2)>>2]&65535}if((g|0)<10){break}u=a[e+(15-(c[k>>2]|0))|0]|0;if(u<<24>>24!=0){b[s+18>>1]=c[r+((u&255)<<2)>>2]&65535}if((g|0)<11){break}u=a[e+(15-(c[l>>2]|0))|0]|0;if(u<<24>>24!=0){b[s+20>>1]=c[r+((u&255)<<2)>>2]&65535}if((g|0)<12){break}u=a[e+(15-(c[m>>2]|0))|0]|0;if(u<<24>>24!=0){b[s+22>>1]=c[r+((u&255)<<2)>>2]&65535}if((g|0)<13){break}u=a[e+(15-(c[n>>2]|0))|0]|0;if(u<<24>>24!=0){b[s+24>>1]=c[r+((u&255)<<2)>>2]&65535}if((g|0)<14){break}u=a[e+(15-(c[o>>2]|0))|0]|0;if(u<<24>>24!=0){b[s+26>>1]=c[r+((u&255)<<2)>>2]&65535}if((g|0)<15){break}u=a[e+(15-(c[p>>2]|0))|0]|0;if(u<<24>>24!=0){b[s+28>>1]=c[r+((u&255)<<2)>>2]&65535}if((g|0)<16){break}u=a[e+(15-(c[q>>2]|0))|0]|0;if(u<<24>>24==0){break}b[s+30>>1]=c[r+((u&255)<<2)>>2]&65535}}while(0);v=e+(c[i+(d+~t<<2)>>2]|0)|0;if((t|0)<=0){break}s=s-640|0;t=t-1|0;e=v}c[2385338]=v;return}function dYi(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;d=c[3528502]|0;e=d-1|0;if((d|0)<=0){return}f=c[2385456]|0;g=f+e|0;if((g|0)<0){return}h=c[3528422]|0;i=c[2385468]|0;j=i>>>0<320;k=c[3528424]|0;l=c[2440386]|0;m=k+4|0;n=k+8|0;o=k+12|0;p=k+16|0;q=k+20|0;r=k+24|0;s=k+28|0;t=c[3528504]|0;u=(t|0)<9;v=(i+8|0)>>>0<320;w=k+32|0;x=(i+9|0)>>>0<320;y=k+36|0;z=(i+10|0)>>>0<320;A=k+40|0;B=(i+11|0)>>>0<320;C=k+44|0;D=(i+12|0)>>>0<320;E=k+48|0;F=(i+13|0)>>>0<320;G=k+52|0;H=(i+14|0)>>>0<320;I=k+56|0;J=(i+15|0)>>>0<320;K=k+60|0;L=e;M=(c[2415150]|0)+(e*640|0)|0;e=g;g=c[2385338]|0;while(1){do{if((e|0)<=223){do{if(j){N=a[g+(15-(c[k>>2]|0))|0]|0;if(N<<24>>24==0){break}b[M>>1]=c[l+((N&255)<<2)>>2]&65535}}while(0);do{if((i+1|0)>>>0<320){N=a[g+(15-(c[m>>2]|0))|0]|0;if(N<<24>>24==0){break}b[M+2>>1]=c[l+((N&255)<<2)>>2]&65535}}while(0);do{if((i+2|0)>>>0<320){N=a[g+(15-(c[n>>2]|0))|0]|0;if(N<<24>>24==0){break}b[M+4>>1]=c[l+((N&255)<<2)>>2]&65535}}while(0);do{if((i+3|0)>>>0<320){N=a[g+(15-(c[o>>2]|0))|0]|0;if(N<<24>>24==0){break}b[M+6>>1]=c[l+((N&255)<<2)>>2]&65535}}while(0);do{if((i+4|0)>>>0<320){N=a[g+(15-(c[p>>2]|0))|0]|0;if(N<<24>>24==0){break}b[M+8>>1]=c[l+((N&255)<<2)>>2]&65535}}while(0);do{if((i+5|0)>>>0<320){N=a[g+(15-(c[q>>2]|0))|0]|0;if(N<<24>>24==0){break}b[M+10>>1]=c[l+((N&255)<<2)>>2]&65535}}while(0);do{if((i+6|0)>>>0<320){N=a[g+(15-(c[r>>2]|0))|0]|0;if(N<<24>>24==0){break}b[M+12>>1]=c[l+((N&255)<<2)>>2]&65535}}while(0);do{if((i+7|0)>>>0<320){N=a[g+(15-(c[s>>2]|0))|0]|0;if(N<<24>>24==0){break}b[M+14>>1]=c[l+((N&255)<<2)>>2]&65535}}while(0);if(u){break}do{if(v){N=a[g+(15-(c[w>>2]|0))|0]|0;if(N<<24>>24==0){break}b[M+16>>1]=c[l+((N&255)<<2)>>2]&65535}}while(0);if((t|0)<10){break}do{if(x){N=a[g+(15-(c[y>>2]|0))|0]|0;if(N<<24>>24==0){break}b[M+18>>1]=c[l+((N&255)<<2)>>2]&65535}}while(0);if((t|0)<11){break}do{if(z){N=a[g+(15-(c[A>>2]|0))|0]|0;if(N<<24>>24==0){break}b[M+20>>1]=c[l+((N&255)<<2)>>2]&65535}}while(0);if((t|0)<12){break}do{if(B){N=a[g+(15-(c[C>>2]|0))|0]|0;if(N<<24>>24==0){break}b[M+22>>1]=c[l+((N&255)<<2)>>2]&65535}}while(0);if((t|0)<13){break}do{if(D){N=a[g+(15-(c[E>>2]|0))|0]|0;if(N<<24>>24==0){break}b[M+24>>1]=c[l+((N&255)<<2)>>2]&65535}}while(0);if((t|0)<14){break}do{if(F){N=a[g+(15-(c[G>>2]|0))|0]|0;if(N<<24>>24==0){break}b[M+26>>1]=c[l+((N&255)<<2)>>2]&65535}}while(0);if((t|0)<15){break}do{if(H){N=a[g+(15-(c[I>>2]|0))|0]|0;if(N<<24>>24==0){break}b[M+28>>1]=c[l+((N&255)<<2)>>2]&65535}}while(0);if((t|0)<16|J^1){break}N=a[g+(15-(c[K>>2]|0))|0]|0;if(N<<24>>24==0){break}b[M+30>>1]=c[l+((N&255)<<2)>>2]&65535}}while(0);O=g+(c[h+(d+~L<<2)>>2]|0)|0;if((L|0)<=0){break}N=L-1|0;P=f+N|0;if((P|0)<0){break}else{L=N;M=M-640|0;e=P;g=O}}c[2385338]=O;return}function dYj(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;d=c[3528502]|0;f=d-1|0;if((d|0)<=0){return}g=c[3528424]|0;h=c[3528504]|0;i=(h|0)<9;j=c[3528422]|0;k=g+32|0;l=g+36|0;m=g+40|0;n=g+44|0;o=g+48|0;p=g+52|0;q=g+56|0;r=g+60|0;s=c[2415164]|0;t=c[2440386]|0;u=(c[2415150]|0)+(f*640|0)|0;v=(c[2409606]|0)+((f*320|0)<<1)|0;w=f;f=c[2385338]|0;while(1){x=a[f+(15-(c[g>>2]|0))|0]|0;y=x&255;do{if(x<<24>>24==0){z=f}else{if((e[v>>1]|0|0)>(s|0)){z=f;break}b[u>>1]=c[t+(y<<2)>>2]&65535;z=f}}while(0);y=a[z+(15-(c[g+4>>2]|0))|0]|0;x=y&255;do{if(y<<24>>24==0){A=z}else{if((e[v+2>>1]|0|0)>(s|0)){A=z;break}b[u+2>>1]=c[t+(x<<2)>>2]&65535;A=f}}while(0);x=a[A+(15-(c[g+8>>2]|0))|0]|0;y=x&255;do{if(x<<24>>24==0){B=A}else{if((e[v+4>>1]|0|0)>(s|0)){B=A;break}b[u+4>>1]=c[t+(y<<2)>>2]&65535;B=f}}while(0);y=a[B+(15-(c[g+12>>2]|0))|0]|0;x=y&255;do{if(y<<24>>24==0){C=B}else{if((e[v+6>>1]|0|0)>(s|0)){C=B;break}b[u+6>>1]=c[t+(x<<2)>>2]&65535;C=f}}while(0);x=a[C+(15-(c[g+16>>2]|0))|0]|0;y=x&255;do{if(x<<24>>24==0){D=C}else{if((e[v+8>>1]|0|0)>(s|0)){D=C;break}b[u+8>>1]=c[t+(y<<2)>>2]&65535;D=f}}while(0);y=a[D+(15-(c[g+20>>2]|0))|0]|0;x=y&255;do{if(y<<24>>24==0){E=D}else{if((e[v+10>>1]|0|0)>(s|0)){E=D;break}b[u+10>>1]=c[t+(x<<2)>>2]&65535;E=f}}while(0);x=a[E+(15-(c[g+24>>2]|0))|0]|0;y=x&255;do{if(x<<24>>24==0){F=E}else{if((e[v+12>>1]|0|0)>(s|0)){F=E;break}b[u+12>>1]=c[t+(y<<2)>>2]&65535;F=f}}while(0);y=a[F+(15-(c[g+28>>2]|0))|0]|0;x=y&255;do{if(y<<24>>24!=0){if((e[v+14>>1]|0|0)>(s|0)){break}b[u+14>>1]=c[t+(x<<2)>>2]&65535}}while(0);do{if(!i){x=a[f+(15-(c[k>>2]|0))|0]|0;y=x&255;do{if(x<<24>>24!=0){if((e[v+16>>1]|0|0)>(s|0)){break}b[u+16>>1]=c[t+(y<<2)>>2]&65535}}while(0);if((h|0)<10){break}y=a[f+(15-(c[l>>2]|0))|0]|0;x=y&255;do{if(y<<24>>24!=0){if((e[v+18>>1]|0|0)>(s|0)){break}b[u+18>>1]=c[t+(x<<2)>>2]&65535}}while(0);if((h|0)<11){break}x=a[f+(15-(c[m>>2]|0))|0]|0;y=x&255;do{if(x<<24>>24!=0){if((e[v+20>>1]|0|0)>(s|0)){break}b[u+20>>1]=c[t+(y<<2)>>2]&65535}}while(0);if((h|0)<12){break}y=a[f+(15-(c[n>>2]|0))|0]|0;x=y&255;do{if(y<<24>>24!=0){if((e[v+22>>1]|0|0)>(s|0)){break}b[u+22>>1]=c[t+(x<<2)>>2]&65535}}while(0);if((h|0)<13){break}x=a[f+(15-(c[o>>2]|0))|0]|0;y=x&255;do{if(x<<24>>24!=0){if((e[v+24>>1]|0|0)>(s|0)){break}b[u+24>>1]=c[t+(y<<2)>>2]&65535}}while(0);if((h|0)<14){break}y=a[f+(15-(c[p>>2]|0))|0]|0;x=y&255;do{if(y<<24>>24!=0){if((e[v+26>>1]|0|0)>(s|0)){break}b[u+26>>1]=c[t+(x<<2)>>2]&65535}}while(0);if((h|0)<15){break}x=a[f+(15-(c[q>>2]|0))|0]|0;y=x&255;do{if(x<<24>>24!=0){if((e[v+28>>1]|0|0)>(s|0)){break}b[u+28>>1]=c[t+(y<<2)>>2]&65535}}while(0);if((h|0)<16){break}y=a[f+(15-(c[r>>2]|0))|0]|0;if(y<<24>>24==0){break}if((e[v+30>>1]|0|0)>(s|0)){break}b[u+30>>1]=c[t+((y&255)<<2)>>2]&65535}}while(0);G=f+(c[j+(d+~w<<2)>>2]|0)|0;if((w|0)<=0){break}u=u-640|0;v=v-640|0;w=w-1|0;f=G}c[2385338]=G;return}function dYk(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;d=c[3528502]|0;f=d-1|0;if((d|0)<=0){return}g=c[2385456]|0;h=g+f|0;if((h|0)<0){return}i=c[3528422]|0;j=c[2385468]|0;k=j>>>0<320;l=c[3528424]|0;m=c[2415164]|0;n=c[2440386]|0;o=l+4|0;p=l+8|0;q=l+12|0;r=l+16|0;s=l+20|0;t=l+24|0;u=l+28|0;v=c[3528504]|0;w=(v|0)<9;x=(j+8|0)>>>0<320;y=l+32|0;z=(j+9|0)>>>0<320;A=l+36|0;B=(j+10|0)>>>0<320;C=l+40|0;D=(j+11|0)>>>0<320;E=l+44|0;F=(j+12|0)>>>0<320;G=l+48|0;H=(j+13|0)>>>0<320;I=l+52|0;J=(j+14|0)>>>0<320;K=l+56|0;L=(j+15|0)>>>0<320;M=l+60|0;N=f;O=(c[2409606]|0)+((f*320|0)<<1)|0;P=(c[2415150]|0)+(f*640|0)|0;f=h;h=c[2385338]|0;while(1){do{if((f|0)<=223){do{if(k){Q=a[h+(15-(c[l>>2]|0))|0]|0;if(Q<<24>>24==0){break}if((e[O>>1]|0|0)>(m|0)){break}b[P>>1]=c[n+((Q&255)<<2)>>2]&65535}}while(0);do{if((j+1|0)>>>0<320){Q=a[h+(15-(c[o>>2]|0))|0]|0;if(Q<<24>>24==0){break}if((e[O+2>>1]|0|0)>(m|0)){break}b[P+2>>1]=c[n+((Q&255)<<2)>>2]&65535}}while(0);do{if((j+2|0)>>>0<320){Q=a[h+(15-(c[p>>2]|0))|0]|0;if(Q<<24>>24==0){break}if((e[O+4>>1]|0|0)>(m|0)){break}b[P+4>>1]=c[n+((Q&255)<<2)>>2]&65535}}while(0);do{if((j+3|0)>>>0<320){Q=a[h+(15-(c[q>>2]|0))|0]|0;if(Q<<24>>24==0){break}if((e[O+6>>1]|0|0)>(m|0)){break}b[P+6>>1]=c[n+((Q&255)<<2)>>2]&65535}}while(0);do{if((j+4|0)>>>0<320){Q=a[h+(15-(c[r>>2]|0))|0]|0;if(Q<<24>>24==0){break}if((e[O+8>>1]|0|0)>(m|0)){break}b[P+8>>1]=c[n+((Q&255)<<2)>>2]&65535}}while(0);do{if((j+5|0)>>>0<320){Q=a[h+(15-(c[s>>2]|0))|0]|0;if(Q<<24>>24==0){break}if((e[O+10>>1]|0|0)>(m|0)){break}b[P+10>>1]=c[n+((Q&255)<<2)>>2]&65535}}while(0);do{if((j+6|0)>>>0<320){Q=a[h+(15-(c[t>>2]|0))|0]|0;if(Q<<24>>24==0){break}if((e[O+12>>1]|0|0)>(m|0)){break}b[P+12>>1]=c[n+((Q&255)<<2)>>2]&65535}}while(0);do{if((j+7|0)>>>0<320){Q=a[h+(15-(c[u>>2]|0))|0]|0;if(Q<<24>>24==0){break}if((e[O+14>>1]|0|0)>(m|0)){break}b[P+14>>1]=c[n+((Q&255)<<2)>>2]&65535}}while(0);if(w){break}do{if(x){Q=a[h+(15-(c[y>>2]|0))|0]|0;if(Q<<24>>24==0){break}if((e[O+16>>1]|0|0)>(m|0)){break}b[P+16>>1]=c[n+((Q&255)<<2)>>2]&65535}}while(0);if((v|0)<10){break}do{if(z){Q=a[h+(15-(c[A>>2]|0))|0]|0;if(Q<<24>>24==0){break}if((e[O+18>>1]|0|0)>(m|0)){break}b[P+18>>1]=c[n+((Q&255)<<2)>>2]&65535}}while(0);if((v|0)<11){break}do{if(B){Q=a[h+(15-(c[C>>2]|0))|0]|0;if(Q<<24>>24==0){break}if((e[O+20>>1]|0|0)>(m|0)){break}b[P+20>>1]=c[n+((Q&255)<<2)>>2]&65535}}while(0);if((v|0)<12){break}do{if(D){Q=a[h+(15-(c[E>>2]|0))|0]|0;if(Q<<24>>24==0){break}if((e[O+22>>1]|0|0)>(m|0)){break}b[P+22>>1]=c[n+((Q&255)<<2)>>2]&65535}}while(0);if((v|0)<13){break}do{if(F){Q=a[h+(15-(c[G>>2]|0))|0]|0;if(Q<<24>>24==0){break}if((e[O+24>>1]|0|0)>(m|0)){break}b[P+24>>1]=c[n+((Q&255)<<2)>>2]&65535}}while(0);if((v|0)<14){break}do{if(H){Q=a[h+(15-(c[I>>2]|0))|0]|0;if(Q<<24>>24==0){break}if((e[O+26>>1]|0|0)>(m|0)){break}b[P+26>>1]=c[n+((Q&255)<<2)>>2]&65535}}while(0);if((v|0)<15){break}do{if(J){Q=a[h+(15-(c[K>>2]|0))|0]|0;if(Q<<24>>24==0){break}if((e[O+28>>1]|0|0)>(m|0)){break}b[P+28>>1]=c[n+((Q&255)<<2)>>2]&65535}}while(0);if((v|0)<16|L^1){break}Q=a[h+(15-(c[M>>2]|0))|0]|0;if(Q<<24>>24==0){break}if((e[O+30>>1]|0|0)>(m|0)){break}b[P+30>>1]=c[n+((Q&255)<<2)>>2]&65535}}while(0);R=h+(c[i+(d+~N<<2)>>2]|0)|0;if((N|0)<=0){break}Q=N-1|0;S=g+Q|0;if((S|0)<0){break}else{N=Q;O=O-640|0;P=P-640|0;f=S;h=R}}c[2385338]=R;return}function dYl(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;e=c[3528502]|0;f=e-1|0;if((e|0)<=0){return}g=c[3528424]|0;h=c[3528504]|0;i=(h|0)<9;j=c[3528422]|0;k=g+32|0;l=g+36|0;m=g+40|0;n=g+44|0;o=g+48|0;p=g+52|0;q=g+56|0;r=g+60|0;s=c[2415164]&65535;t=c[2440386]|0;u=g+28|0;v=g+24|0;w=g+20|0;x=g+16|0;y=g+12|0;z=g+8|0;A=g+4|0;B=(c[2415150]|0)+(f*640|0)|0;C=(c[2409606]|0)+((f*320|0)<<1)|0;D=f;f=c[2385338]|0;while(1){if((a[f+(15-(c[g>>2]|0))|0]|0)!=0){b[C>>1]=s;b[B>>1]=c[t+(d[f+(15-(c[g>>2]|0))|0]<<2)>>2]&65535}if((a[f+(15-(c[A>>2]|0))|0]|0)!=0){b[C+2>>1]=s;b[B+2>>1]=c[t+(d[f+(15-(c[A>>2]|0))|0]<<2)>>2]&65535}if((a[f+(15-(c[z>>2]|0))|0]|0)!=0){b[C+4>>1]=s;b[B+4>>1]=c[t+(d[f+(15-(c[z>>2]|0))|0]<<2)>>2]&65535}if((a[f+(15-(c[y>>2]|0))|0]|0)!=0){b[C+6>>1]=s;b[B+6>>1]=c[t+(d[f+(15-(c[y>>2]|0))|0]<<2)>>2]&65535}if((a[f+(15-(c[x>>2]|0))|0]|0)!=0){b[C+8>>1]=s;b[B+8>>1]=c[t+(d[f+(15-(c[x>>2]|0))|0]<<2)>>2]&65535}if((a[f+(15-(c[w>>2]|0))|0]|0)!=0){b[C+10>>1]=s;b[B+10>>1]=c[t+(d[f+(15-(c[w>>2]|0))|0]<<2)>>2]&65535}if((a[f+(15-(c[v>>2]|0))|0]|0)!=0){b[C+12>>1]=s;b[B+12>>1]=c[t+(d[f+(15-(c[v>>2]|0))|0]<<2)>>2]&65535}if((a[f+(15-(c[u>>2]|0))|0]|0)!=0){b[C+14>>1]=s;b[B+14>>1]=c[t+(d[f+(15-(c[u>>2]|0))|0]<<2)>>2]&65535}do{if(!i){if((a[f+(15-(c[k>>2]|0))|0]|0)!=0){b[C+16>>1]=s;b[B+16>>1]=c[t+(d[f+(15-(c[k>>2]|0))|0]<<2)>>2]&65535}if((h|0)<10){break}if((a[f+(15-(c[l>>2]|0))|0]|0)!=0){b[C+18>>1]=s;b[B+18>>1]=c[t+(d[f+(15-(c[l>>2]|0))|0]<<2)>>2]&65535}if((h|0)<11){break}if((a[f+(15-(c[m>>2]|0))|0]|0)!=0){b[C+20>>1]=s;b[B+20>>1]=c[t+(d[f+(15-(c[m>>2]|0))|0]<<2)>>2]&65535}if((h|0)<12){break}if((a[f+(15-(c[n>>2]|0))|0]|0)!=0){b[C+22>>1]=s;b[B+22>>1]=c[t+(d[f+(15-(c[n>>2]|0))|0]<<2)>>2]&65535}if((h|0)<13){break}if((a[f+(15-(c[o>>2]|0))|0]|0)!=0){b[C+24>>1]=s;b[B+24>>1]=c[t+(d[f+(15-(c[o>>2]|0))|0]<<2)>>2]&65535}if((h|0)<14){break}if((a[f+(15-(c[p>>2]|0))|0]|0)!=0){b[C+26>>1]=s;b[B+26>>1]=c[t+(d[f+(15-(c[p>>2]|0))|0]<<2)>>2]&65535}if((h|0)<15){break}if((a[f+(15-(c[q>>2]|0))|0]|0)!=0){b[C+28>>1]=s;b[B+28>>1]=c[t+(d[f+(15-(c[q>>2]|0))|0]<<2)>>2]&65535}if((h|0)<16){break}if((a[f+(15-(c[r>>2]|0))|0]|0)==0){break}b[C+30>>1]=s;b[B+30>>1]=c[t+(d[f+(15-(c[r>>2]|0))|0]<<2)>>2]&65535}}while(0);E=f+(c[j+(e+~D<<2)>>2]|0)|0;if((D|0)<=0){break}B=B-640|0;C=C-640|0;D=D-1|0;f=E}c[2385338]=E;return}function dYm(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;e=c[3528502]|0;f=e-1|0;if((e|0)<=0){return}g=c[2385456]|0;h=g+f|0;if((h|0)<0){return}i=c[3528422]|0;j=c[2385468]|0;k=j>>>0<320;l=c[3528424]|0;m=c[2415164]&65535;n=c[2440386]|0;o=l+4|0;p=l+8|0;q=l+12|0;r=l+16|0;s=l+20|0;t=l+24|0;u=l+28|0;v=c[3528504]|0;w=(v|0)<9;x=(j+8|0)>>>0<320;y=l+32|0;z=(j+9|0)>>>0<320;A=l+36|0;B=(j+10|0)>>>0<320;C=l+40|0;D=(j+11|0)>>>0<320;E=l+44|0;F=(j+12|0)>>>0<320;G=l+48|0;H=(j+13|0)>>>0<320;I=l+52|0;J=(j+14|0)>>>0<320;K=l+56|0;L=(j+15|0)>>>0<320;M=l+60|0;N=f;O=(c[2409606]|0)+((f*320|0)<<1)|0;P=(c[2415150]|0)+(f*640|0)|0;f=h;h=c[2385338]|0;while(1){do{if((f|0)<=223){do{if(k){if((a[h+(15-(c[l>>2]|0))|0]|0)==0){break}b[O>>1]=m;b[P>>1]=c[n+(d[h+(15-(c[l>>2]|0))|0]<<2)>>2]&65535}}while(0);do{if((j+1|0)>>>0<320){if((a[h+(15-(c[o>>2]|0))|0]|0)==0){break}b[O+2>>1]=m;b[P+2>>1]=c[n+(d[h+(15-(c[o>>2]|0))|0]<<2)>>2]&65535}}while(0);do{if((j+2|0)>>>0<320){if((a[h+(15-(c[p>>2]|0))|0]|0)==0){break}b[O+4>>1]=m;b[P+4>>1]=c[n+(d[h+(15-(c[p>>2]|0))|0]<<2)>>2]&65535}}while(0);do{if((j+3|0)>>>0<320){if((a[h+(15-(c[q>>2]|0))|0]|0)==0){break}b[O+6>>1]=m;b[P+6>>1]=c[n+(d[h+(15-(c[q>>2]|0))|0]<<2)>>2]&65535}}while(0);do{if((j+4|0)>>>0<320){if((a[h+(15-(c[r>>2]|0))|0]|0)==0){break}b[O+8>>1]=m;b[P+8>>1]=c[n+(d[h+(15-(c[r>>2]|0))|0]<<2)>>2]&65535}}while(0);do{if((j+5|0)>>>0<320){if((a[h+(15-(c[s>>2]|0))|0]|0)==0){break}b[O+10>>1]=m;b[P+10>>1]=c[n+(d[h+(15-(c[s>>2]|0))|0]<<2)>>2]&65535}}while(0);do{if((j+6|0)>>>0<320){if((a[h+(15-(c[t>>2]|0))|0]|0)==0){break}b[O+12>>1]=m;b[P+12>>1]=c[n+(d[h+(15-(c[t>>2]|0))|0]<<2)>>2]&65535}}while(0);do{if((j+7|0)>>>0<320){if((a[h+(15-(c[u>>2]|0))|0]|0)==0){break}b[O+14>>1]=m;b[P+14>>1]=c[n+(d[h+(15-(c[u>>2]|0))|0]<<2)>>2]&65535}}while(0);if(w){break}do{if(x){if((a[h+(15-(c[y>>2]|0))|0]|0)==0){break}b[O+16>>1]=m;b[P+16>>1]=c[n+(d[h+(15-(c[y>>2]|0))|0]<<2)>>2]&65535}}while(0);if((v|0)<10){break}do{if(z){if((a[h+(15-(c[A>>2]|0))|0]|0)==0){break}b[O+18>>1]=m;b[P+18>>1]=c[n+(d[h+(15-(c[A>>2]|0))|0]<<2)>>2]&65535}}while(0);if((v|0)<11){break}do{if(B){if((a[h+(15-(c[C>>2]|0))|0]|0)==0){break}b[O+20>>1]=m;b[P+20>>1]=c[n+(d[h+(15-(c[C>>2]|0))|0]<<2)>>2]&65535}}while(0);if((v|0)<12){break}do{if(D){if((a[h+(15-(c[E>>2]|0))|0]|0)==0){break}b[O+22>>1]=m;b[P+22>>1]=c[n+(d[h+(15-(c[E>>2]|0))|0]<<2)>>2]&65535}}while(0);if((v|0)<13){break}do{if(F){if((a[h+(15-(c[G>>2]|0))|0]|0)==0){break}b[O+24>>1]=m;b[P+24>>1]=c[n+(d[h+(15-(c[G>>2]|0))|0]<<2)>>2]&65535}}while(0);if((v|0)<14){break}do{if(H){if((a[h+(15-(c[I>>2]|0))|0]|0)==0){break}b[O+26>>1]=m;b[P+26>>1]=c[n+(d[h+(15-(c[I>>2]|0))|0]<<2)>>2]&65535}}while(0);if((v|0)<15){break}do{if(J){if((a[h+(15-(c[K>>2]|0))|0]|0)==0){break}b[O+28>>1]=m;b[P+28>>1]=c[n+(d[h+(15-(c[K>>2]|0))|0]<<2)>>2]&65535}}while(0);if((v|0)<16|L^1){break}if((a[h+(15-(c[M>>2]|0))|0]|0)==0){break}b[O+30>>1]=m;b[P+30>>1]=c[n+(d[h+(15-(c[M>>2]|0))|0]<<2)>>2]&65535}}while(0);Q=h+(c[i+(e+~N<<2)>>2]|0)|0;if((N|0)<=0){break}R=N-1|0;S=g+R|0;if((S|0)<0){break}else{N=R;O=O-640|0;P=P-640|0;f=S;h=Q}}c[2385338]=Q;return}function dYn(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;f=c[3528502]|0;g=f-1|0;if((f|0)<=0){return}h=c[3528424]|0;i=c[3528504]|0;j=(i|0)<9;k=c[3528422]|0;l=h+32|0;m=h+36|0;n=h+40|0;o=h+44|0;p=h+48|0;q=h+52|0;r=h+56|0;s=h+60|0;t=c[2415164]|0;u=t&65535;v=c[2440386]|0;w=h+28|0;x=h+24|0;y=h+20|0;z=h+16|0;A=h+12|0;B=h+8|0;C=h+4|0;D=(c[2415150]|0)+(g*640|0)|0;E=(c[2409606]|0)+((g*320|0)<<1)|0;F=g;g=c[2385338]|0;while(1){do{if((a[g+(15-(c[h>>2]|0))|0]|0)==0){G=g}else{if((e[E>>1]|0)>(t|0)){G=g;break}b[E>>1]=u;b[D>>1]=c[v+(d[g+(15-(c[h>>2]|0))|0]<<2)>>2]&65535;G=g}}while(0);do{if((a[G+(15-(c[C>>2]|0))|0]|0)==0){H=G}else{I=E+2|0;if((e[I>>1]|0)>(t|0)){H=G;break}b[I>>1]=u;b[D+2>>1]=c[v+(d[g+(15-(c[C>>2]|0))|0]<<2)>>2]&65535;H=g}}while(0);do{if((a[H+(15-(c[B>>2]|0))|0]|0)==0){J=H}else{I=E+4|0;if((e[I>>1]|0)>(t|0)){J=H;break}b[I>>1]=u;b[D+4>>1]=c[v+(d[g+(15-(c[B>>2]|0))|0]<<2)>>2]&65535;J=g}}while(0);do{if((a[J+(15-(c[A>>2]|0))|0]|0)==0){K=J}else{I=E+6|0;if((e[I>>1]|0)>(t|0)){K=J;break}b[I>>1]=u;b[D+6>>1]=c[v+(d[g+(15-(c[A>>2]|0))|0]<<2)>>2]&65535;K=g}}while(0);do{if((a[K+(15-(c[z>>2]|0))|0]|0)==0){L=K}else{I=E+8|0;if((e[I>>1]|0)>(t|0)){L=K;break}b[I>>1]=u;b[D+8>>1]=c[v+(d[g+(15-(c[z>>2]|0))|0]<<2)>>2]&65535;L=g}}while(0);do{if((a[L+(15-(c[y>>2]|0))|0]|0)==0){M=L}else{I=E+10|0;if((e[I>>1]|0)>(t|0)){M=L;break}b[I>>1]=u;b[D+10>>1]=c[v+(d[g+(15-(c[y>>2]|0))|0]<<2)>>2]&65535;M=g}}while(0);do{if((a[M+(15-(c[x>>2]|0))|0]|0)==0){N=M}else{I=E+12|0;if((e[I>>1]|0)>(t|0)){N=M;break}b[I>>1]=u;b[D+12>>1]=c[v+(d[g+(15-(c[x>>2]|0))|0]<<2)>>2]&65535;N=g}}while(0);do{if((a[N+(15-(c[w>>2]|0))|0]|0)!=0){I=E+14|0;if((e[I>>1]|0)>(t|0)){break}b[I>>1]=u;b[D+14>>1]=c[v+(d[g+(15-(c[w>>2]|0))|0]<<2)>>2]&65535}}while(0);do{if(!j){do{if((a[g+(15-(c[l>>2]|0))|0]|0)!=0){I=E+16|0;if((e[I>>1]|0)>(t|0)){break}b[I>>1]=u;b[D+16>>1]=c[v+(d[g+(15-(c[l>>2]|0))|0]<<2)>>2]&65535}}while(0);if((i|0)<10){break}do{if((a[g+(15-(c[m>>2]|0))|0]|0)!=0){I=E+18|0;if((e[I>>1]|0)>(t|0)){break}b[I>>1]=u;b[D+18>>1]=c[v+(d[g+(15-(c[m>>2]|0))|0]<<2)>>2]&65535}}while(0);if((i|0)<11){break}do{if((a[g+(15-(c[n>>2]|0))|0]|0)!=0){I=E+20|0;if((e[I>>1]|0)>(t|0)){break}b[I>>1]=u;b[D+20>>1]=c[v+(d[g+(15-(c[n>>2]|0))|0]<<2)>>2]&65535}}while(0);if((i|0)<12){break}do{if((a[g+(15-(c[o>>2]|0))|0]|0)!=0){I=E+22|0;if((e[I>>1]|0)>(t|0)){break}b[I>>1]=u;b[D+22>>1]=c[v+(d[g+(15-(c[o>>2]|0))|0]<<2)>>2]&65535}}while(0);if((i|0)<13){break}do{if((a[g+(15-(c[p>>2]|0))|0]|0)!=0){I=E+24|0;if((e[I>>1]|0)>(t|0)){break}b[I>>1]=u;b[D+24>>1]=c[v+(d[g+(15-(c[p>>2]|0))|0]<<2)>>2]&65535}}while(0);if((i|0)<14){break}do{if((a[g+(15-(c[q>>2]|0))|0]|0)!=0){I=E+26|0;if((e[I>>1]|0)>(t|0)){break}b[I>>1]=u;b[D+26>>1]=c[v+(d[g+(15-(c[q>>2]|0))|0]<<2)>>2]&65535}}while(0);if((i|0)<15){break}do{if((a[g+(15-(c[r>>2]|0))|0]|0)!=0){I=E+28|0;if((e[I>>1]|0)>(t|0)){break}b[I>>1]=u;b[D+28>>1]=c[v+(d[g+(15-(c[r>>2]|0))|0]<<2)>>2]&65535}}while(0);if((i|0)<16){break}if((a[g+(15-(c[s>>2]|0))|0]|0)==0){break}I=E+30|0;if((e[I>>1]|0)>(t|0)){break}b[I>>1]=u;b[D+30>>1]=c[v+(d[g+(15-(c[s>>2]|0))|0]<<2)>>2]&65535}}while(0);O=g+(c[k+(f+~F<<2)>>2]|0)|0;if((F|0)<=0){break}D=D-640|0;E=E-640|0;F=F-1|0;g=O}c[2385338]=O;return}function dYo(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;f=c[3528502]|0;g=f-1|0;if((f|0)<=0){return}h=c[2385456]|0;i=h+g|0;if((i|0)<0){return}j=c[3528422]|0;k=c[2385468]|0;l=k>>>0<320;m=c[3528424]|0;n=c[2415164]|0;o=n&65535;p=c[2440386]|0;q=m+4|0;r=m+8|0;s=m+12|0;t=m+16|0;u=m+20|0;v=m+24|0;w=m+28|0;x=c[3528504]|0;y=(x|0)<9;z=(k+8|0)>>>0<320;A=m+32|0;B=(k+9|0)>>>0<320;C=m+36|0;D=(k+10|0)>>>0<320;E=m+40|0;F=(k+11|0)>>>0<320;G=m+44|0;H=(k+12|0)>>>0<320;I=m+48|0;J=(k+13|0)>>>0<320;K=m+52|0;L=(k+14|0)>>>0<320;M=m+56|0;N=(k+15|0)>>>0<320;O=m+60|0;P=g;Q=(c[2409606]|0)+((g*320|0)<<1)|0;R=(c[2415150]|0)+(g*640|0)|0;g=i;i=c[2385338]|0;while(1){do{if((g|0)<=223){do{if(l){if((a[i+(15-(c[m>>2]|0))|0]|0)==0){break}if((e[Q>>1]|0)>(n|0)){break}b[Q>>1]=o;b[R>>1]=c[p+(d[i+(15-(c[m>>2]|0))|0]<<2)>>2]&65535}}while(0);do{if((k+1|0)>>>0<320){if((a[i+(15-(c[q>>2]|0))|0]|0)==0){break}S=Q+2|0;if((e[S>>1]|0)>(n|0)){break}b[S>>1]=o;b[R+2>>1]=c[p+(d[i+(15-(c[q>>2]|0))|0]<<2)>>2]&65535}}while(0);do{if((k+2|0)>>>0<320){if((a[i+(15-(c[r>>2]|0))|0]|0)==0){break}S=Q+4|0;if((e[S>>1]|0)>(n|0)){break}b[S>>1]=o;b[R+4>>1]=c[p+(d[i+(15-(c[r>>2]|0))|0]<<2)>>2]&65535}}while(0);do{if((k+3|0)>>>0<320){if((a[i+(15-(c[s>>2]|0))|0]|0)==0){break}S=Q+6|0;if((e[S>>1]|0)>(n|0)){break}b[S>>1]=o;b[R+6>>1]=c[p+(d[i+(15-(c[s>>2]|0))|0]<<2)>>2]&65535}}while(0);do{if((k+4|0)>>>0<320){if((a[i+(15-(c[t>>2]|0))|0]|0)==0){break}S=Q+8|0;if((e[S>>1]|0)>(n|0)){break}b[S>>1]=o;b[R+8>>1]=c[p+(d[i+(15-(c[t>>2]|0))|0]<<2)>>2]&65535}}while(0);do{if((k+5|0)>>>0<320){if((a[i+(15-(c[u>>2]|0))|0]|0)==0){break}S=Q+10|0;if((e[S>>1]|0)>(n|0)){break}b[S>>1]=o;b[R+10>>1]=c[p+(d[i+(15-(c[u>>2]|0))|0]<<2)>>2]&65535}}while(0);do{if((k+6|0)>>>0<320){if((a[i+(15-(c[v>>2]|0))|0]|0)==0){break}S=Q+12|0;if((e[S>>1]|0)>(n|0)){break}b[S>>1]=o;b[R+12>>1]=c[p+(d[i+(15-(c[v>>2]|0))|0]<<2)>>2]&65535}}while(0);do{if((k+7|0)>>>0<320){if((a[i+(15-(c[w>>2]|0))|0]|0)==0){break}S=Q+14|0;if((e[S>>1]|0)>(n|0)){break}b[S>>1]=o;b[R+14>>1]=c[p+(d[i+(15-(c[w>>2]|0))|0]<<2)>>2]&65535}}while(0);if(y){break}do{if(z){if((a[i+(15-(c[A>>2]|0))|0]|0)==0){break}S=Q+16|0;if((e[S>>1]|0)>(n|0)){break}b[S>>1]=o;b[R+16>>1]=c[p+(d[i+(15-(c[A>>2]|0))|0]<<2)>>2]&65535}}while(0);if((x|0)<10){break}do{if(B){if((a[i+(15-(c[C>>2]|0))|0]|0)==0){break}S=Q+18|0;if((e[S>>1]|0)>(n|0)){break}b[S>>1]=o;b[R+18>>1]=c[p+(d[i+(15-(c[C>>2]|0))|0]<<2)>>2]&65535}}while(0);if((x|0)<11){break}do{if(D){if((a[i+(15-(c[E>>2]|0))|0]|0)==0){break}S=Q+20|0;if((e[S>>1]|0)>(n|0)){break}b[S>>1]=o;b[R+20>>1]=c[p+(d[i+(15-(c[E>>2]|0))|0]<<2)>>2]&65535}}while(0);if((x|0)<12){break}do{if(F){if((a[i+(15-(c[G>>2]|0))|0]|0)==0){break}S=Q+22|0;if((e[S>>1]|0)>(n|0)){break}b[S>>1]=o;b[R+22>>1]=c[p+(d[i+(15-(c[G>>2]|0))|0]<<2)>>2]&65535}}while(0);if((x|0)<13){break}do{if(H){if((a[i+(15-(c[I>>2]|0))|0]|0)==0){break}S=Q+24|0;if((e[S>>1]|0)>(n|0)){break}b[S>>1]=o;b[R+24>>1]=c[p+(d[i+(15-(c[I>>2]|0))|0]<<2)>>2]&65535}}while(0);if((x|0)<14){break}do{if(J){if((a[i+(15-(c[K>>2]|0))|0]|0)==0){break}S=Q+26|0;if((e[S>>1]|0)>(n|0)){break}b[S>>1]=o;b[R+26>>1]=c[p+(d[i+(15-(c[K>>2]|0))|0]<<2)>>2]&65535}}while(0);if((x|0)<15){break}do{if(L){if((a[i+(15-(c[M>>2]|0))|0]|0)==0){break}S=Q+28|0;if((e[S>>1]|0)>(n|0)){break}b[S>>1]=o;b[R+28>>1]=c[p+(d[i+(15-(c[M>>2]|0))|0]<<2)>>2]&65535}}while(0);if((x|0)<16|N^1){break}if((a[i+(15-(c[O>>2]|0))|0]|0)==0){break}S=Q+30|0;if((e[S>>1]|0)>(n|0)){break}b[S>>1]=o;b[R+30>>1]=c[p+(d[i+(15-(c[O>>2]|0))|0]<<2)>>2]&65535}}while(0);T=i+(c[j+(f+~P<<2)>>2]|0)|0;if((P|0)<=0){break}S=P-1|0;U=h+S|0;if((U|0)<0){break}else{P=S;Q=Q-640|0;R=R-640|0;g=U;i=T}}c[2385338]=T;return}function dYp(b,d){b=b|0;d=d|0;if(!(a[673112]&(b|0)==1048590)){return}a[c[2385214]|0]=(d&255)>>>2&15;return}function dYq(d,e){d=d|0;e=e|0;if(a[673112]|0){if((d|0)==1048586){b[c[3526956]>>1]=(e^170)+7&511;return}else if((d|0)==2555904){a[c[3528284]|0]=e&255;return}else if((d|0)==1048582){b[c[3525082]>>1]=(e^340)+7&511;return}else if((d|0)==1048588){b[c[3526964]>>1]=e+452&511;return}else if((d|0)==1048580){b[c[3525090]>>1]=e+32&511;return}else{return}}else{if((d|0)==1048578){b[c[3525082]>>1]=e+8&511;return}else if((d|0)==1048582){b[c[3526956]>>1]=e+8&511;return}else if((d|0)==2555904){a[c[3528284]|0]=e&255;return}else if((d|0)==1048580){b[c[3526964]>>1]=e+4&511;return}else if((d|0)==1048584){b[c[3525090]>>1]=e&511;return}else{return}}}function dYr(a){a=a|0;var b=0;if((a|0)!=2621442){b=0;return b|0}b=(e[4775277]|0)>>>8&255;return b|0}function dYs(a){a=a|0;var c=0;if(!((a|0)==2621440|(a|0)==2621442|(a|0)==2621444)){c=0;return c|0}c=b[9550552+((a>>>1&3)<<1)>>1]|0;return c|0}function dYt(b,e){b=b|0;e=e|0;var f=0,g=0;f=b&255;if((f|0)==1){b=c[3540984]|0;g=c[b+5876>>2]|0;if((g|0)!=0){gg[g&4095](c[b+5880>>2]|0,0)}lH(b,d[b+5885|0]|0,e&255);return}else if((f|0)==0){a[(c[3540984]|0)+5885|0]=e;return}else if((f|0)==2){Uv(0,e);return}else{return}}function dYu(b){b=b|0;var e=0,f=0,g=0,h=0;e=b&255;if((e|0)==6){f=a[c[3528284]|0]|0;return f|0}else if((e|0)==0){b=c[3540984]|0;g=(d[b+5887|0]|0|128)&(d[b+5886|0]|0);if((a[b+5884|0]&2)==0){h=g&255}else{h=(a[(c[b+5828>>2]|0)+100|0]&1|g)&255}f=h|6;return f|0}else if((e|0)==2){f=c[2113156]&255;return f|0}else{f=0;return f|0}return 0}function dYv(b,c){b=b|0;c=c|0;a[9706117]=(c|0)!=0|0;return}function dYw(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2997924+(b*112|0)>>2];c[a+104>>2]=c[2997928+(b*112|0)>>2];c[a+108>>2]=c[2997932+(b*112|0)>>2];d=0;return d|0}function dYx(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=2997824+(b*112|0);e=0;return e|0}function dYy(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1289224+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dYz(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4140968+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dYA(){return dYN(3508)|0}function dYB(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}b=a[7452584]|0;if(b){d=0;e=b&1;while(1){b=14163936+(d<<2)|0;f=c[b>>2]|0;g=c[2113006]|0;if((g|0)==0){h=34667}else{i=g-1|0;c[2113006]=i;if((i|0)==0){h=34667}}if((h|0)==34667){h=0;c[2383474]=0}if((f|0)==0){j=e}else{gGr(f);j=a[7452584]&1}c[b>>2]=0;b=d+1|0;if((b|0)<(j|0)){d=b;e=j}else{break}}}a[7452584]=0;c[2438224]=0;c[2433522]=0;c[2406672]=0;c[3528468]=0;j=c[2406688]|0;if((j|0)!=0){gGr(j);c[2406688]=0}c[2432972]=0;Uw(0);if((c[2392]|0)>=0){j=0;do{e=14130368+(j<<2)|0;d=c[e>>2]|0;if((d|0)!=0){gGr(d);c[e>>2]=0}e=14130384+(j<<2)|0;d=c[e>>2]|0;if((d|0)!=0){gGr(d);c[e>>2]=0}j=j+1|0;}while((j|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;fwZ();j=c[2414978]|0;e=0;while(1){if((e|0)>=1024){h=34685;break}k=9638528+(e<<2)|0;if((c[k>>2]|0)==(j|0)){break}else{e=e+1|0}}if((h|0)==34685){c[2414978]=0;c[3541206]=0;a[673112]=0;return 0}gGr(j);c[k>>2]=0;c[2414978]=0;c[3541206]=0;a[673112]=0;return 0}function dYC(){var e=0,f=0,g=0,i=0,j=0;if((a[9624280]|0)!=0){a[9624280]=0;e=c[2414682]|0;gGz(e|0,0,(c[2411692]|0)-e|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060]}RI();e=c[2394]|0;f=c[14130368+(e<<2)>>2]|0;if((f|0)!=0){gGC(f|0,9104152,280)|0}c[8452240+(e<<2)>>2]=c[2113054];c[2394]=-1;e=c[2439330]|0;f=(e|0)==0;if(!f){g=e;gGC(9706056,g|0,76)|0}g=c[2438118]|0;c[2433530]=g;i=c[3528484]|0;c[2076596]=i;j=c[2417276]|0;c[3541536]=j;c[1836236]=0;gGz(9706056,0,76);if(!f){f=e;gGC(f|0,9706056,76)|0}c[2438118]=g;c[3528484]=i;c[2417276]=j;c[1836236]=-1;c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;lw(c[3540984]|0);c[2113156]=0;a[9628264]=0;c[2407033]=0;j=c[3541206]|0;c[3541190]=j;c[3541198]=j;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=j+256;c[3541199]=j+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=j+512;c[3541200]=j+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=j+768;c[3541201]=j+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4}b[4775277]=-1;b[4775276]=-1;j=0;i=-1;g=-1;do{i=((a[9633584+j|0]&1)<<j^i&65535)&65535;g=((a[9631432+j|0]&1)<<j^g&65535)&65535;j=j+1|0;}while((j|0)<16);b[4775276]=i;b[4775277]=g;b[4775278]=d[9635153]<<8|d[9635152];g=c[2392]|0;if((g|0)>=0){gGz(8452240,0,((g|0)>0?(g<<2)+4|0:4)|0)}c[2113054]=0;g=c[2385548]|0;if((g|0)>0){gGz(9752472,0,((g|0)>1?g<<2:4)|0)}c[2433530]=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];g=c[3532592]|0;if((g|0)!=0){gGC(9104152,g|0,280)|0}c[2113054]=c[2113060]}g=c[2439330]|0;if((g|0)!=0){i=g;gGC(9706056,i|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;c[2113056]=119318;i=RG(119318)|0;c[2113054]=(c[2113054]|0)+i;c[2276108]=-1;c[2113056]=-1;c[8452200+(c[2394]<<2)>>2]=8198;c[2276080]=1536;if((c[2276079]|0)>>>0<1536){RH(6)}if((c[2112964]|0)!=0){i=c[2438224]|0;g=gGS(-1597636608,28447,i,(i|0)<0|0?-1:0)|0;i=g;UF(59659)|0;g=c[2443826]|0;if((g|0)<1073676288){c[2443826]=g-i}g=c[2443827]|0;if((g|0)<1073676288){c[2443827]=g-i}g=(c[3528508]|0)-i|0;c[3528508]=(g|0)<0?0:g;gg[c[3542112]&4095](c[2112964]|0,a[9688]|0?534:0);Uu(0,c[2112964]|0,a[9688]|0?534:0)}g=c[1836236]|0;i=c[9757320+(g<<2)>>2]|0;if((i|0)!=0){j=i;gGC(j|0,9706056,76)|0}c[9752472+(g<<2)>>2]=c[2433530];c[14113936+(g<<2)>>2]=c[2076596];c[9669104+(g<<2)>>2]=c[3541536];c[1836236]=-1;g=c[2394]|0;j=c[14130368+(g<<2)>>2]|0;if((j|0)!=0){gGC(j|0,9104152,280)|0}c[8452240+(g<<2)>>2]=c[2113054];c[2394]=-1;if((c[2112968]|0)==0){return 0}dYD()|0;return 0}function dYD(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;if((a[9547512]|0)!=0){f=c[2387212]|0;g=c[3530028]|0;h=0;do{i=b[f+(h<<1)>>1]|0;c[g+(h<<2)>>2]=((i&65535)>>>10<<3&248)<<8|((i&255)<<3&255)>>>3|(((i&65535)>>>5<<3&255|(i&65535)>>>7&4)&255)<<3&2016;h=h+1|0;}while((h|0)<768)}h=e[c[3526964]>>1]|0;g=e[c[3526956]>>1]|0;f=c[2406570]|0;i=c[2385214]|0;j=c[2112926]|0;k=c[3530852]|0;l=c[2113070]|0;m=c[2113068]|0;n=0;do{o=(n<<4&496)-h|0;p=(o|0)<-15?o+512|0:o;o=(n>>5<<4)-g|0;q=(o|0)<-15?o+512|0:o;if((q|0)<(l|0)&(p|0)<(m|0)){o=e[f+(n<<1)>>1]|0;Sz(j,d[i]<<12|o&4095,p,q,o>>>12|32,4,0,k)}n=n+1|0;}while((n|0)<1024);n=e[c[3525090]>>1]|0;f=e[c[3525082]>>1]|0;g=c[2406492]|0;h=0;do{o=(h<<4&496)-n|0;q=(o|0)<-15?o+512|0:o;o=(h>>5<<4)-f|0;p=(o|0)<-15?o+512|0:o;do{if((p|0)<(l|0)&(q|0)<(m|0)){o=e[g+(h<<1)>>1]|0;r=o&4095;if((r|0)==0){break}SH(j,d[i]<<12|r,q,p,o>>>12|16,4,0,0,k)}}while(0);h=h+1|0;}while((h|0)<1024);h=c[2386466]|0;k=c[3530616]|0;i=(c[2113222]&1|0)==0;g=0;do{m=b[h+((g|1)<<1)>>1]&32767;L45773:do{if((m|0)!=0){l=e[h+(g<<1)>>1]|0;if(!((l&4096|0)==0|i)){break}f=e[h+((g|2)<<1)>>1]|0;n=f>>>9&15;p=l&16384;q=1<<(l>>>9&3);o=q-1|0;r=f&511;s=l&511;t=304-(r>>>0>319?f|-512:r)-5|0;r=(p|0)!=0;f=(r?0:o)+m|0;u=(p>>>13^2)-1|0;if((q|0)<=0){break}q=(l&8192|0)!=0;p=233-(s>>>0>255?l|-512:s)|0;if(r){v=o}else{if(q){r=o;while(1){SJ(j,f-(ag(r,u)|0)|0,t,p-(r<<4)|0,n,4,0,0,k);if((r|0)>0){r=r-1|0}else{break L45773}}}else{r=o;while(1){SH(j,f-(ag(r,u)|0)|0,t,p-(r<<4)|0,n,4,0,0,k);if((r|0)>0){r=r-1|0}else{break L45773}}}}while(1){r=f-(ag(v,u)|0)|0;o=p-(v<<4)|0;if(q){SN(j,r,t,o,n,4,0,0,k)}else{SL(j,r,t,o,n,4,0,0,k)}if((v|0)>0){v=v-1|0}else{break}}}}while(0);g=g+4|0;}while((g|0)<1024);R8(c[3530028]|0);return 0}function dYE(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=i;i=i+64|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;if((d|0)!=0){c[d>>2]=169624}if((b&96|0)==0){i=e;return 0}gGz(j|0,0,12);k=c[2414682]|0;c[j>>2]=k;c[j+4>>2]=(c[2411692]|0)-k;c[j+12>>2]=162152;gj[c[2076592]&4095](j)|0;j=h|0;do{if((b&64|0)!=0){gGz(g|0,0,16);c[2394]=-1;if((c[2392]|0)<0){break}k=h+9|0;l=f;m=f|0;n=f+4|0;o=f+12|0;p=g|0;q=g+4|0;r=g+12|0;s=0;do{gGC(j|0,614896,11)|0;a[k]=s+48&255;t=8452256+(s<<2)|0;gGz(l|0,0,12);c[m>>2]=t;c[n>>2]=4;c[o>>2]=164976;gj[c[2076592]&4095](f)|0;if((c[t>>2]|0)!=0){c[p>>2]=c[14130368+(s<<2)>>2];c[q>>2]=c[8452184+(s<<2)>>2];c[r>>2]=j;t=c[2076592]|0;gj[t&4095](g)|0}s=s+1|0;}while((s|0)<=(c[2392]|0))}}while(0);fw$(b);UQ(b,d);Ut(0);i=e;return 0}function dYF(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4670012+(b*112|0)>>2];c[a+104>>2]=c[4670016+(b*112|0)>>2];c[a+108>>2]=c[4670020+(b*112|0)>>2];d=0;return d|0}function dYG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=4669912+(b*112|0);e=0;return e|0}function dYH(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5357648+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dYI(){return dYN(1848)|0}function dYJ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5943220+(b*112|0)>>2];c[a+104>>2]=c[5943224+(b*112|0)>>2];c[a+108>>2]=c[5943228+(b*112|0)>>2];d=0;return d|0}function dYK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=5943120+(b*112|0);e=0;return e|0}function dYL(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6416728+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dYM(){a[673112]=1;return dYN(1392)|0}function dYN(d){d=d|0;var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;e=i;i=i+240|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;c[2414978]=0;c[2388166]=0;c[2385930]=1048576;c[3530852]=1114112;c[3530616]=5308416;c[3541206]=9502720;c[2386654]=9502720;c[3530028]=9764864;c[2414682]=9767936;c[2388290]=9767936;c[2387212]=9833472;c[2406492]=9835520;c[2406570]=9837568;c[2386466]=9839616;c[2386084]=9841664;c[3528284]=9843712;c[2385214]=9843713;c[3525090]=9843714;c[3526964]=9843716;c[3525082]=9843718;c[3526956]=9843720;c[2411692]=9843722;l=0;while(1){if((l|0)>=1024){break}m=9638528+(l<<2)|0;if((c[m>>2]|0)==0){n=34809;break}else{l=l+1|0}}do{if((n|0)==34809){l=gGq(9843722)|0;c[m>>2]=l;if((l|0)==0){break}c[2414978]=l;gGz(l|0,0,9843722);c[2388166]=l;c[2385930]=l+1048576;c[3530852]=l+1114112;c[3530616]=l+5308416;o=l+9502720|0;c[3541206]=o;c[2386654]=o;c[3530028]=l+9764864;o=l+9767936|0;c[2414682]=o;c[2388290]=o;c[2387212]=l+9833472;c[2406492]=l+9835520;c[2406570]=l+9837568;c[2386466]=l+9839616;c[2386084]=l+9841664;c[3528284]=l+9843712;c[2385214]=l+9843713;c[3525090]=l+9843714;c[3526964]=l+9843716;c[3525082]=l+9843718;c[3526956]=l+9843720;o=l+9843722|0;c[2411692]=o;c[2414232]=o;if((R6(l,0,2)|0)!=0){p=1;i=e;return p|0}if((R6((c[2388166]|0)+1|0,1,2)|0)!=0){p=1;i=e;return p|0}l=c[2385930]|0;if((c[3542200]|0)==0){p=1;i=e;return p|0}o=j+108|0;c[o>>2]=0;q=j+100|0;c[q>>2]=0;r=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[r&16383](j,2)|0;do{if((c[o>>2]|0)!=0){r=c[q>>2]|0;c[k>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](k,2,0)|0;if((r|0)<1){p=1;i=e;return p|0}if((gzL(l,0,2)|0)==0){break}else{p=1}i=e;return p|0}}while(0);l=c[2386654]|0;if((c[3542200]|0)==0){p=1;i=e;return p|0}q=f+108|0;c[q>>2]=0;o=f+100|0;c[o>>2]=0;r=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[r&16383](f,3)|0;do{if((c[q>>2]|0)!=0){r=c[o>>2]|0;c[g>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](g,3,0)|0;if((r|0)<1){p=1;i=e;return p|0}if((gzL(l,0,3)|0)==0){break}else{p=1}i=e;return p|0}}while(0);if((R6(c[3530852]|0,4,2)|0)!=0){p=1;i=e;return p|0}if((R6((c[3530852]|0)+1|0,5,2)|0)!=0){p=1;i=e;return p|0}do{if((d|0)!=0){if((gD[d&8191]()|0)==0){break}else{p=1}i=e;return p|0}}while(0);fxU(0,425984);if((c[2394]|0)==0){t=c[2112932]|0}else{c[2394]=0;l=c[3532596]|0;c[2112932]=l;o=c[3532592]|0;if((o|0)!=0){gGC(9104152,o|0,280)|0}c[2113054]=c[2113060];t=l}l=c[2388166]|0;o=t|0;q=0;while(1){r=l+q|0;c[o>>2]=r;c[o+131072>>2]=r;r=q+1024|0;if(r>>>0>1048575){break}else{o=o+4|0;q=r}}q=c[2406492]|0;c[t+4608>>2]=q;c[t+70144>>2]=q;c[t+135680>>2]=q;o=q+1024|0;c[t+4612>>2]=o;c[t+70148>>2]=o;c[t+135684>>2]=o;o=c[2406570]|0;c[t+4640>>2]=o;c[t+70176>>2]=o;c[t+135712>>2]=o;q=o+1024|0;c[t+4644>>2]=q;c[t+70180>>2]=q;c[t+135716>>2]=q;q=c[2387212]|0;c[t+8192>>2]=q;c[t+73728>>2]=q;c[t+139264>>2]=q;o=q+1024|0;c[t+8196>>2]=o;c[t+73732>>2]=o;c[t+139268>>2]=o;o=c[2386466]|0;c[t+8448>>2]=o;c[t+73984>>2]=o;c[t+139520>>2]=o;q=o+1024|0;c[t+8452>>2]=q;c[t+73988>>2]=q;c[t+139524>>2]=q;q=c[2388290]|0;o=t+12800|0;l=3276800;while(1){r=q+(l-3276800)|0;c[o>>2]=r;c[o+65536>>2]=r;c[o+131072>>2]=r;r=l+1024|0;if(r>>>0>3342335){break}else{o=o+4|0;l=r}}l=t+14848|0;o=3801088;while(1){r=q+(o-3801088)|0;c[l>>2]=r;c[l+65536>>2]=r;c[l+131072>>2]=r;r=o+1024|0;if(r>>>0>3866623){break}else{l=l+4|0;o=r}}c[t+196648>>2]=2344;c[t+196728>>2]=2230;c[t+196608>>2]=2854;c[t+196688>>2]=3200;o=c[3532592]|0;if((o|0)!=0){gGC(o|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);o=c[2439330]|0;l=(o|0)==0;if(!l){q=o;gGC(9706056,q|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];q=c[3528484]|0;c[2076596]=q;r=c[2417276]|0;c[3541536]=r;c[1836236]=0;s=c[2385930]|0;u=0;v=0;while(1){c[o+76+(v<<2)>>2]=s+(v<<8);w=u+1&65535;if((w&65535)>191){x=0;y=0;break}else{u=w;v=w&65535}}while(1){v=s+(y<<8)|0;c[o+76+(y+512<<2)>>2]=v;c[o+76+(y+768<<2)>>2]=v;v=x+1&65535;if((v&65535)>191){break}else{x=v;y=v&65535}}s=c[2386084]|0;c[o+844>>2]=s;v=s+256|0;c[o+848>>2]=v;u=s+512|0;c[o+852>>2]=u;w=s+768|0;c[o+856>>2]=w;z=s+1024|0;c[o+860>>2]=z;A=s+1280|0;c[o+864>>2]=A;B=s+1536|0;c[o+868>>2]=B;C=s+1792|0;c[o+872>>2]=C;c[o+1868>>2]=s;c[o+1872>>2]=v;c[o+1876>>2]=u;c[o+1880>>2]=w;c[o+1884>>2]=z;c[o+1888>>2]=A;c[o+1892>>2]=B;c[o+1896>>2]=C;c[o+2892>>2]=s;c[o+3916>>2]=s;c[o+2896>>2]=v;c[o+3920>>2]=v;c[o+2900>>2]=u;c[o+3924>>2]=u;c[o+2904>>2]=w;c[o+3928>>2]=w;c[o+2908>>2]=z;c[o+3932>>2]=z;c[o+2912>>2]=A;c[o+3936>>2]=A;c[o+2916>>2]=B;c[o+3940>>2]=B;c[o+2920>>2]=C;c[o+3944>>2]=C;c[o+4176>>2]=3386;c[o+4172>>2]=414;if(!l){C=o;gGC(C|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=q;c[2417276]=r;c[1836236]=-1;UL(3579545,2858,622,0);c[2438224]=3579545;c[2433522]=3416;c[2406672]=1752;c[3528468]=9362;c[2443842]=571;h[745398]=1.0;a[3203264]=1;Ux(0,8e3,1);c[2407030]=256;c[2407068]=3;C=c[642608+(c[2436]<<2)>>2]|0;B=c[C+128>>2]|0;if((c[C+52>>2]&4|0)==0){c[2113068]=B;A=c[C+132>>2]|0;c[2113070]=A;c[2443814]=B;c[2440436]=A;D=B;E=A}else{c[2113070]=B;A=c[C+132>>2]|0;c[2113068]=A;c[2440436]=B;c[2443814]=A;D=A;E=B}B=ag(D<<1,E)|0;A=gGq(B)|0;c[2112926]=A;if((A|0)!=0){gGz(A|0,0,B|0)}a[9624280]=0;B=c[2414682]|0;gGz(B|0,0,(c[2411692]|0)-B|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];B=c[3532592]|0;if((B|0)!=0){gGC(9104152,B|0,280)|0}c[2113054]=c[2113060]}RI();B=c[2394]|0;A=c[14130368+(B<<2)>>2]|0;if((A|0)!=0){gGC(A|0,9104152,280)|0}c[8452240+(B<<2)>>2]=c[2113054];c[2394]=-1;B=c[2439330]|0;A=(B|0)==0;if(!A){C=B;gGC(9706056,C|0,76)|0}C=c[2438118]|0;c[2433530]=C;z=c[3528484]|0;c[2076596]=z;w=c[2417276]|0;c[3541536]=w;c[1836236]=0;gGz(9706056,0,76);if(!A){A=B;gGC(A|0,9706056,76)|0}c[2438118]=C;c[3528484]=z;c[2417276]=w;c[1836236]=-1;c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;lw(c[3540984]|0);c[2113156]=0;a[9628264]=0;c[2407033]=0;w=c[3541206]|0;c[3541190]=w;c[3541198]=w;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=w+256;c[3541199]=w+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=w+512;c[3541200]=w+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=w+768;c[3541201]=w+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;p=0;i=e;return p|0}}while(0);c[2414978]=0;p=1;i=e;return p|0}function dYO(){var a=0;if((R6((c[3530852]|0)+1048576|0,6,2)|0)!=0){a=1;return a|0}if((R6((c[3530852]|0)+1048577|0,7,2)|0)!=0){a=1;return a|0}if((R6(c[3530616]|0,8,2)|0)!=0){a=1;return a|0}if((R6((c[3530616]|0)+1|0,9,2)|0)!=0){a=1;return a|0}if((R6((c[3530616]|0)+1048576|0,10,2)|0)!=0){a=1;return a|0}if((R6((c[3530616]|0)+1048577|0,11,2)|0)!=0){a=1;return a|0}dYP(2097152,2097152,1);a=0;return a|0}function dYP(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;g=i;i=i+32|0;h=g|0;j=g+16|0;k=(b|0)/2|0;l=k<<3;c[h>>2]=l+8;c[h+4>>2]=l;c[h+8>>2]=8;c[h+12>>2]=0;l=((e|0)/2|0)<<3;c[j>>2]=l+8;c[j+4>>2]=l;c[j+8>>2]=8;c[j+12>>2]=0;l=(e-1|b-1)+1|0;m=0;while(1){if((m|0)>=1024){n=34924;break}o=9638528+(m<<2)|0;if((c[o>>2]|0)==0){break}else{m=m+1|0}}if((n|0)==34924){i=g;return}m=gGq(l)|0;c[o>>2]=m;if((m|0)==0){i=g;return}gGz(m|0,0,l|0);if((b|0)>0){l=(f|0)==0;f=k^32;k=c[3530852]|0;o=0;while(1){if(l){p=o}else{p=o>>>1&786432|o&262143|o<<2&1048576}a[m+(f^p)|0]=a[k+o|0]|0;q=o+1|0;if((q|0)<(b|0)){o=q}else{r=k;break}}}else{r=c[3530852]|0}k=b<<1;b=(k|0)/256|0;if((k|0)>255){k=0;do{o=k<<8;gGz(r+o|0,0,256);p=k<<9;f=0;do{l=1<<3-f;q=(c[h+(f<<2)>>2]|0)+p|0;s=0;do{t=q+(c[608544+(s<<2)>>2]|0)|0;u=(s<<4)+o|0;v=0;do{w=t+(c[613816+(v<<2)>>2]|0)|0;if(((d[m+((w|0)/8|0)|0]|0)&128>>>((w&7)>>>0)|0)!=0){w=r+(u+v)|0;a[w]=(d[w]|0|l)&255}v=v+1|0;}while((v|0)<16);s=s+1|0;}while((s|0)<16);f=f+1|0;}while((f|0)<4);k=k+1|0;}while((k|0)<(b|0))}b=c[3530616]|0;gGC(m|0,b|0,e)|0;k=e<<1;e=(k|0)/256|0;if((k|0)>255){k=0;while(1){r=k<<8;gGz(b+r|0,0,256);h=k<<9;f=0;do{o=1<<3-f;p=(c[j+(f<<2)>>2]|0)+h|0;s=0;do{l=p+(c[608544+(s<<2)>>2]|0)|0;q=(s<<4)+r|0;v=0;do{u=l+(c[613816+(v<<2)>>2]|0)|0;if(((d[m+((u|0)/8|0)|0]|0)&128>>>((u&7)>>>0)|0)!=0){u=b+(q+v)|0;a[u]=(d[u]|0|o)&255}v=v+1|0;}while((v|0)<16);s=s+1|0;}while((s|0)<16);f=f+1|0;}while((f|0)<4);f=k+1|0;if((f|0)<(e|0)){k=f}else{x=0;break}}}else{x=0}while(1){if((x|0)>=1024){n=34925;break}y=9638528+(x<<2)|0;if((c[y>>2]|0)==(m|0)){break}else{x=x+1|0}}if((n|0)==34925){i=g;return}gGr(m);c[y>>2]=0;i=g;return}function dYQ(a){a=a|0;return(ag((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0,a)|0)/3579545|0|0}function dYR(){var a=0;if((R6(c[3530616]|0,6,2)|0)!=0){a=1;return a|0}if((R6((c[3530616]|0)+1|0,7,2)|0)!=0){a=1;return a|0}if((R6((c[3530616]|0)+524288|0,8,2)|0)!=0){a=1;return a|0}if((R6((c[3530616]|0)+524289|0,9,2)|0)!=0){a=1;return a|0}dYP(2097152,1048576,1);a=0;return a|0}function dYS(){var a=0;if((R6(c[3530616]|0,6,2)|0)!=0){a=1;return a|0}if((R6((c[3530616]|0)+1|0,7,2)|0)!=0){a=1;return a|0}if((R6((c[3530616]|0)+1048576|0,8,2)|0)!=0){a=1;return a|0}if((R6((c[3530616]|0)+1048577|0,9,2)|0)!=0){a=1;return a|0}dYP(524288,2097152,0);a=0;return a|0}function dYT(b,e){b=b|0;e=e|0;var f=0,g=0;if((b-10485760|0)>>>0<262144){f=c[2387210]|0;a[f+(b&262143^1)|0]=e;g=b&262140;c[(c[3530026]|0)+(g>>>2<<2)>>2]=(d[f+(g|3)|0]|0)<<3&2016|(d[f+g|0]|0)<<8&63488|(d[f+(g|2)|0]|0)>>>3;return}if((b|0)==12058633){c[2113012]=e&255;return}else if((b|0)==12058635){Ui(e);return}else if((b|0)==10092545){b=e&255;c[2415256]=b&4;e=b&1;c[3528406]=e^1;if((e|0)==0){c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2]}Tr(b>>>1&1);return}else{return}}function dYU(a,f){a=a|0;f=f|0;var g=0,h=0;if((a-10485760|0)>>>0<262144){g=c[2387210]|0;b[g+(a&262142)>>1]=f;h=a&262140;c[(c[3530026]|0)+(h>>>2<<2)>>2]=(d[g+(h|3)|0]|0)<<3&2016|(d[g+h|0]|0)<<8&63488|(d[g+(h|2)|0]|0)>>>3;return}if((a|0)==10223620){b[(c[3530280]|0)+4>>1]=f;return}else if((a|0)==10223618){h=c[3530280]|0;b[h+2>>1]=f;b[(c[2387838]|0)+((e[h>>1]|0)<<1)>>1]=f;b[h>>1]=(b[h>>1]|0)+(b[h+4>>1]|0)&65535;return}else if((a|0)==10223616){b[c[3530280]>>1]=f;return}else{return}}function dYV(a){a=a|0;var d=0,f=0,g=0,h=0;if((a|0)==12189697){d=b[4775272]&255;return d|0}else if((a|0)==9437185){d=b[4775273]&255;return d|0}else if((a|0)==12320769){d=b[4775271]&255;return d|0}else if((a|0)==9961472){d=(e[4775269]|0)>>>8&255;return d|0}else if((a|0)==9568257){f=b[4775270]&255;do{if((c[2406632]|0)==0){g=c[2443744]|0;if((g|0)<=0){h=8;break}c[2443744]=g-1;h=0}else{h=(1<<c[(c[2420380]|0)+4>>2]&c[2432962]|0)!=0?8:0}}while(0);d=h|f;return d|0}else if((a|0)==12058635){f=c[2113010]|0;c[2113010]=0;c[2430402]=0;h=c[3531294]|0;if((h|0)!=0){gf[h&2047](0)}d=f&255;return d|0}else if((a|0)==9699328){d=(e[4775268]|0)>>>8&255;return d|0}else{d=0;return d|0}return 0}function dYW(a){a=a|0;var c=0;if((a|0)==12320768){c=b[4775271]|0}else if((a|0)==9437184){c=b[4775273]|0}else if((a|0)==9961472){c=b[4775269]|0}else if((a|0)==11534336|(a|0)==11665408|(a|0)==11796480|(a|0)==11927552){c=-1}else{c=0}return c|0}function dYX(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[2640012+(b*112|0)>>2];c[a+104>>2]=c[2640016+(b*112|0)>>2];c[a+108>>2]=c[2640020+(b*112|0)>>2];d=0;return d|0}function dYY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=2639912+(b*112|0);e=0;return e|0}function dYZ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1234704+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dY_(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>3){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3796504+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dY$(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0.0,W=0.0,X=0,Y=0,Z=0;e=i;i=i+840|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;c[2414976]=0;c[2388164]=0;c[2386320]=2097152;c[2386366]=2359296;c[2438734]=10747904;c[2438750]=10752e3;c[3531292]=10784768;c[3530026]=12881920;c[2414680]=13144064;c[3531168]=13144064;c[3531146]=13275136;c[2387210]=13537280;c[2387838]=14061568;c[3530280]=14192640;c[2411690]=14192646;v=0;while(1){if((v|0)>=1024){break}w=9638528+(v<<2)|0;if((c[w>>2]|0)==0){x=35035;break}else{v=v+1|0}}do{if((x|0)==35035){v=gGq(14192646)|0;c[w>>2]=v;if((v|0)==0){break}c[2414976]=v;gGz(v|0,0,14192646);c[2388164]=v;c[2386320]=v+2097152;c[2386366]=v+2359296;c[2438734]=v+10747904;c[2438750]=v+10752e3;c[3531292]=v+10784768;c[3530026]=v+12881920;y=v+13144064|0;c[2414680]=y;c[3531168]=y;c[3531146]=v+13275136;c[2387210]=v+13537280;c[2387838]=v+14061568;c[3530280]=v+14192640;y=v+14192646|0;c[2411690]=y;c[2414230]=y;if((c[3542200]|0)==0){z=1;i=e;return z|0}y=t+108|0;c[y>>2]=0;A=t+100|0;c[A>>2]=0;B=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[B&16383](t,0)|0;do{if((c[y>>2]|0)!=0){B=c[A>>2]|0;c[u>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](u,0,0)|0;if((B|0)<1){z=1;i=e;return z|0}if((gzL(v,0,0)|0)==0){break}else{z=1}i=e;return z|0}}while(0);v=c[2386320]|0;if((c[3542200]|0)==0){z=1;i=e;return z|0}A=r+108|0;c[A>>2]=0;y=r+100|0;c[y>>2]=0;B=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[B&16383](r,7)|0;do{if((c[A>>2]|0)!=0){B=c[y>>2]|0;c[s>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](s,7,0)|0;if((B|0)<1){z=1;i=e;return z|0}if((gzL(v,0,7)|0)==0){break}else{z=1}i=e;return z|0}}while(0);v=c[2386366]|0;if((c[3542200]|0)==0){z=1;i=e;return z|0}y=p+108|0;c[y>>2]=0;A=p+100|0;c[A>>2]=0;B=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[B&16383](p,3)|0;do{if((c[y>>2]|0)!=0){B=c[A>>2]|0;c[q>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](q,3,0)|0;if((B|0)<1){z=1;i=e;return z|0}if((gzL(v,0,3)|0)==0){break}else{z=1}i=e;return z|0}}while(0);v=(c[2386366]|0)+2097152|0;if((c[3542200]|0)==0){z=1;i=e;return z|0}A=n+108|0;c[A>>2]=0;y=n+100|0;c[y>>2]=0;B=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[B&16383](n,4)|0;do{if((c[A>>2]|0)!=0){B=c[y>>2]|0;c[o>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](o,4,0)|0;if((B|0)<1){z=1;i=e;return z|0}if((gzL(v,0,4)|0)==0){break}else{z=1}i=e;return z|0}}while(0);v=(c[2386366]|0)+4194304|0;if((c[3542200]|0)==0){z=1;i=e;return z|0}y=l+108|0;c[y>>2]=0;A=l+100|0;c[A>>2]=0;B=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[B&16383](l,5)|0;do{if((c[y>>2]|0)!=0){B=c[A>>2]|0;c[m>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](m,5,0)|0;if((B|0)<1){z=1;i=e;return z|0}if((gzL(v,0,5)|0)==0){break}else{z=1}i=e;return z|0}}while(0);v=(c[2386366]|0)+6291456|0;if((c[3542200]|0)==0){z=1;i=e;return z|0}A=j+108|0;c[A>>2]=0;y=j+100|0;c[y>>2]=0;B=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[B&16383](j,6)|0;do{if((c[A>>2]|0)!=0){B=c[y>>2]|0;c[k>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](k,6,0)|0;if((B|0)<1){z=1;i=e;return z|0}if((gzL(v,0,6)|0)==0){break}else{z=1}i=e;return z|0}}while(0);v=c[3531292]|0;if((c[3542200]|0)==0){z=1;i=e;return z|0}y=f+108|0;c[y>>2]=0;A=f+100|0;c[A>>2]=0;B=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[B&16383](f,8)|0;do{if((c[y>>2]|0)==0){D=0}else{B=c[A>>2]|0;c[g>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](g,8,0)|0;if((B|0)<1){z=1;i=e;return z|0}if((gzL(v,0,8)|0)==0){D=0;break}else{z=1}i=e;return z|0}}while(0);while(1){if((D|0)>=1024){break}E=9638528+(D<<2)|0;if((c[E>>2]|0)==0){x=35067;break}else{D=D+1|0}}L46226:do{if((x|0)==35067){v=gGq(8388608)|0;c[E>>2]=v;if((v|0)==0){break}gGz(v|0,0,8388608);A=c[2386366]|0;gGC(v|0,A|0,8388608)|0;y=0;do{B=y<<8;gGz(A+B|0,0,256);C=y<<9;F=0;do{G=1<<7-F;H=(c[611568+(F<<2)>>2]|0)+C|0;I=0;do{J=H+(c[608544+(I<<2)>>2]|0)|0;K=(I<<4)+B|0;L=0;do{M=J+(c[610864+(L<<2)>>2]|0)|0;if((d[v+((M|0)/8|0)|0]&128>>>((M&7)>>>0)|0)!=0){M=A+(K+L)|0;a[M]=(d[M]|G)&255}L=L+1|0;}while((L|0)<16);I=I+1|0;}while((I|0)<16);F=F+1|0;}while((F|0)<8);y=y+1|0;}while((y|0)<32768);y=c[2386320]|0;gGC(v|0,y|0,262144)|0;F=0;do{B=F<<6;gGz(y+B|0,0,64);C=F<<9;I=0;do{G=1<<7-I;H=(c[683936+(I<<2)>>2]|0)+C|0;L=0;do{K=H+(c[6669224+(L<<2)>>2]|0)|0;J=(L<<3)+B|0;M=0;do{N=K+(c[609968+(M<<2)>>2]|0)|0;if((d[v+((N|0)/8|0)|0]&128>>>((N&7)>>>0)|0)!=0){N=y+(J+M)|0;a[N]=(d[N]|G)&255}M=M+1|0;}while((M|0)<8);L=L+1|0;}while((L|0)<8);I=I+1|0;}while((I|0)<8);F=F+1|0;}while((F|0)<4096);F=c[2438750]|0;I=0;do{B=F+((I|0)/256|0)|0;a[B]=0;C=0;L=0;G=0;while(1){if((a[A+(L+I)|0]|0)==0){O=C;P=G}else{a[B]=1;O=C+1|0;P=1}H=L+1|0;if((H|0)<256){C=O;L=H;G=P}else{break}}if((O|0)>=255){a[B]=P|2}I=I+256|0;}while((I|0)<8388608);I=c[2438734]|0;A=0;while(1){F=I+((A|0)/64|0)|0;a[F]=0;G=0;L=0;C=0;while(1){if((a[y+(L+A)|0]|0)==0){Q=G;R=C}else{a[F]=1;Q=G+1|0;R=1}H=L+1|0;if((H|0)<64){G=Q;L=H;C=R}else{break}}if((Q|0)>=63){a[F]=R|2}C=A+64|0;if((C|0)<262144){A=C}else{S=0;break}}while(1){if((S|0)>=1024){break L46226}T=9638528+(S<<2)|0;if((c[T>>2]|0)==(v|0)){break}else{S=S+1|0}}gGr(v);c[T>>2]=0}}while(0);b[(c[2388164]|0)+1258586>>1]=20085;fxU(0,425984);if((c[2394]|0)==0){U=c[2112932]|0}else{c[2394]=0;A=c[3532596]|0;c[2112932]=A;y=c[3532592]|0;if((y|0)!=0){gGC(9104152,y|0,280)|0}c[2113054]=c[2113060];U=A}A=c[2388164]|0;y=U|0;I=0;while(1){C=A+I|0;c[y>>2]=C;c[y+131072>>2]=C;C=I+1024|0;if(C>>>0>2097151){break}else{y=y+4|0;I=C}}I=c[2387210]|0;y=U+40960|0;A=10485760;while(1){C=I+(A-10485760)|0;c[y>>2]=C;c[y+131072>>2]=C;C=A+1024|0;if(C>>>0>10747903){break}else{y=y+4|0;A=C}}A=U+41984|0;y=10747904;while(1){C=I+(y-10485761)|0;c[A>>2]=C;c[A+65536>>2]=C;c[A+131072>>2]=C;C=y+1024|0;if(C>>>0>11010047){break}else{A=A+4|0;y=C}}y=c[3531168]|0;A=U+53248|0;I=13631488;while(1){C=y+(I-13631488)|0;c[A>>2]=C;c[A+65536>>2]=C;c[A+131072>>2]=C;C=I+1024|0;if(C>>>0>13762559){break}else{A=A+4|0;I=C}}I=c[3531146]|0;A=U+57344|0;y=14680064;while(1){C=I+(y-14680064)|0;c[A>>2]=C;c[A+65536>>2]=C;c[A+131072>>2]=C;C=y+1024|0;if(C>>>0>14942207){break}else{A=A+4|0;y=C}}y=c[2387838]|0;A=U+63744|0;I=16318464;while(1){C=y+(I-16318464)|0;c[A>>2]=C;c[A+65536>>2]=C;c[A+131072>>2]=C;C=I+1024|0;if(C>>>0>16449535){break}else{A=A+4|0;I=C}}c[U+196648>>2]=2812;c[U+196728>>2]=822;c[U+196608>>2]=468;c[U+196688>>2]=342;I=c[3532592]|0;if((I|0)!=0){gGC(I|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;Uf(16934400,0);h[607287]=.8;c[2433116]=1;h[607286]=.8;c[2433114]=2;Tq(690216);b[7056092]=-1;I=1;do{V=15.0/+(I|0);A=0;do{W=V*+(A|0);if(W<16.0){X=~~W&65535}else{X=-1}b[14112184+(I<<5)+(A<<1)>>1]=X;A=A+1|0;}while((A|0)<16);I=I+1|0;}while((I|0)<16);I=c[642608+(c[2436]<<2)>>2]|0;A=c[I+128>>2]|0;if((c[I+52>>2]&4|0)==0){c[2113068]=A;v=c[I+132>>2]|0;c[2113070]=v;c[2443814]=A;c[2440436]=v;Y=A;Z=v}else{c[2113070]=A;v=c[I+132>>2]|0;c[2113068]=v;c[2440436]=A;c[2443814]=v;Y=v;Z=A}A=ag(Y<<1,Z)|0;v=gGq(A)|0;c[2112926]=v;if((v|0)!=0){gGz(v|0,0,A|0)}a[9624272]=0;A=c[2414680]|0;gGz(A|0,0,(c[2411690]|0)-A|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];A=c[3532592]|0;if((A|0)!=0){gGC(9104152,A|0,280)|0}c[2113054]=c[2113060]}RI();A=c[2394]|0;v=c[14130368+(A<<2)>>2]|0;if((v|0)!=0){gGC(v|0,9104152,280)|0}c[8452240+(A<<2)>>2]=c[2113054];c[2394]=-1;c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];gGz(14125184,0,668);c[2433532]=0;c[2430402]=0;c[2113010]=0;a[9753304]=0;c[2433552]=0;gGz(c[2430036]|0,0,16384);c[3531316]=4;gGz(c[2430037]|0,0,16384);c[3531337]=4;gGz(c[2430038]|0,0,16384);c[3531358]=4;gGz(c[2430039]|0,0,16384);c[3531379]=4;gGz(c[2430040]|0,0,16384);c[3531400]=4;gGz(c[2430041]|0,0,16384);c[3531421]=4;gGz(c[2430042]|0,0,16384);c[3531442]=4;gGz(c[2430043]|0,0,16384);c[3531463]=4;z=0;i=e;return z|0}}while(0);c[2414976]=0;z=1;i=e;return z|0}function dY0(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;i=i+128|0;c[2113070]=0;c[2113068]=0;d=c[2112926]|0;if((d|0)!=0){gGr(d);c[2112926]=0}d=c[2406694]|0;if((d|0)!=0){gGr(d);c[2406694]=0}c[3531294]=0;c[3531292]=0;d=b|0;e=c[c[642608+(c[2436]<<2)>>2]>>2]|0;be(d|0,128,179600,(f=i,i=i+24|0,c[f>>2]=9374064,c[f+8>>2]=47,c[f+16>>2]=e,f)|0)|0;i=f;a[1040128]=0;f=c[2420380]|0;e=c[f>>2]|0;g=c[f+4>>2]|0;f=fw(d|0,389440)|0;if((f|0)!=0){d=g>>3<<e&1023;cj(14100392,d|0,1,f|0)|0;aY(f|0)|0}if((c[2392]|0)>=0){f=0;do{d=14130368+(f<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}d=14130384+(f<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}f=f+1|0;}while((f|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;f=c[2414976]|0;d=0;while(1){if((d|0)>=1024){h=35185;break}j=9638528+(d<<2)|0;if((c[j>>2]|0)==(f|0)){break}else{d=d+1|0}}if((h|0)==35185){c[2414976]=0;c[3529846]=0;i=b;return 0}gGr(f);c[j>>2]=0;c[2414976]=0;c[3529846]=0;i=b;return 0}function dY1(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if((a[9624272]|0)!=0){a[9624272]=0;e=c[2414680]|0;gGz(e|0,0,(c[2411690]|0)-e|0);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060]}RI();e=c[2394]|0;f=c[14130368+(e<<2)>>2]|0;if((f|0)!=0){gGC(f|0,9104152,280)|0}c[8452240+(e<<2)>>2]=c[2113054];c[2394]=-1;c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2];gGz(14125184,0,668);c[2433532]=0;c[2430402]=0;c[2113010]=0;a[9753304]=0;c[2433552]=0;gGz(c[2430036]|0,0,16384);c[3531316]=4;gGz(c[2430037]|0,0,16384);c[3531337]=4;gGz(c[2430038]|0,0,16384);c[3531358]=4;gGz(c[2430039]|0,0,16384);c[3531379]=4;gGz(c[2430040]|0,0,16384);c[3531400]=4;gGz(c[2430041]|0,0,16384);c[3531421]=4;gGz(c[2430042]|0,0,16384);c[3531442]=4;gGz(c[2430043]|0,0,16384);c[3531463]=4}gGz(9550536,-1|0,12);e=0;f=-1;g=-1;h=-1;i=-1;j=-1;k=-1;do{f=((a[9633568+e|0]&1)<<e^f&65535)&65535;g=((a[9631416+e|0]&1)<<e^g&65535)&65535;h=((a[9629608+e|0]&1)<<e^h&65535)&65535;i=((a[9628984+e|0]&1)<<e^i&65535)&65535;j=((a[9628752+e|0]&1)<<e^j&65535)&65535;k=((a[9628664+e|0]&1)<<e^k&65535)&65535;e=e+1|0;}while((e|0)<16);b[4775268]=f;b[4775269]=g;b[4775271]=i;b[4775272]=j;b[4775270]=h&-9;b[4775273]=d[9635144]|k&-256;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];k=c[3532592]|0;if((k|0)!=0){gGC(9104152,k|0,280)|0}c[2113054]=c[2113060]}c[2113056]=2e5;k=RG(2e5)|0;c[2113054]=(c[2113054]|0)+k;c[2276108]=-1;c[2113056]=-1;k=c[2394]|0;c[8452200+(k<<2)>>2]=8193;c[2276080]=256;if((c[2276079]|0)>>>0<256){RH(1);l=c[2394]|0}else{l=k}k=c[14130368+(l<<2)>>2]|0;if((k|0)!=0){gGC(k|0,9104152,280)|0}c[8452240+(l<<2)>>2]=c[2113054];c[2394]=-1;l=c[2112964]|0;if((l|0)!=0){Ug(l,a[9688]|0?534:0)}if((c[2112968]|0)==0){return 0}dY2()|0;return 0}function dY2(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;f=c[2113308]|0;if((c[3529846]|0)!=(f|0)){g=c[2387210]|0;h=c[3530026]|0;i=0;do{c[h+(((i|0)/4|0)<<2)>>2]=(d[g+(i|3)|0]|0)<<3&2016|(d[g+i|0]|0)<<8&63488|(d[g+(i|2)|0]|0)>>>3;i=i+4|0;}while((i|0)<262144);c[3529846]=f}f=c[2113068]|0;i=c[2113070]|0;g=ag(i,f)|0;h=c[2112926]|0;if((g|0)>0){j=0;while(1){b[h+(j<<1)>>1]=4095;k=j+1|0;if((k|0)<(g|0)){j=k}else{l=h;break}}}else{l=h}h=c[2387838]|0;j=c[2438750]|0;g=c[2386366]|0;k=0;m=0;n=0;o=0;p=0;q=h+65536|0;r=h;while(1){s=e[q>>1]|0;t=e[q+1024>>1]|0;u=s>>>8&15;v=u+1|0;w=(s&127)+1|0;if((t&64|0)==0){s=t&63;x=(e[q+2048>>1]|0)>>>7;y=512-(t>>>7)|0;z=s>>>0>32?32:s}else{x=m+p|0;y=o;z=n}s=(x|0)>495?x-512|0:x;t=y<<16;A=w<<13;B=w>>>3;if((z|0)>0){w=(B|0)==16&(v|0)==16;C=(s|0)<0;D=(B|0)==1|(u|0)==0;E=B-1|0;B=0;do{F=B<<1;G=e[r+(F<<1)>>1]|0;L46426:do{if((G&32768|0)==0){H=b[r+((F|1)<<1)>>1]|0;I=H&65535;J=(((ag(A,B)|0)+t|0)>>>16&511)-16|0;if(!((s|0)<(f|0)&(J|0)<(i|0))){break}K=a[j+G|0]|0;if(K<<24>>24==0){break}if(!w){L=H&-256;if(D){break}H=-(I&1)&15;M=-(I>>>1&1)&15;N=G<<8;O=0;while(1){P=O+J|0;Q=b[14112184+(E<<5)+((O^M)<<1)>>1]|0;R=Q<<16>>16;do{if(Q<<16>>16!=-1){S=(P|0)<0;if(!((P|0)<(i|0)&(S^1))){break}T=R<<4;U=ag(f,P)|0;V=0;do{W=b[14112184+(u<<5)+((V^H)<<1)>>1]|0;do{if(W<<16>>16!=-1){X=V+s|0;Y=a[g+((W<<16>>16|T)+N)|0]|0;if(Y<<24>>24==0|(X|0)<0){break}if((X|0)>=(f|0)|S){break}b[l+(U+X<<1)>>1]=Y&255|L}}while(0);V=V+1|0;}while((V|0)<16)}}while(0);O=O+1|0;if((O|0)>=16){break L46426}}}if((K&2)==0){do{if(!C){if((s|0)>(f-16|0)|(J|0)<0){break}if((J|0)>(i-16|0)){break}O=(I&1|0)!=0;L=I>>>8;if((I&2|0)==0){if(O){SI(l,G,s,J,L,8,0,0,g);break L46426}else{SG(l,G,s,J,L,8,0,0,g);break L46426}}else{if(O){SM(l,G,s,J,L,8,0,0,g);break L46426}else{SK(l,G,s,J,L,8,0,0,g);break L46426}}}}while(0);K=(I&1|0)!=0;L=I>>>8;if((I&2|0)==0){if(K){SJ(l,G,s,J,L,8,0,0,g);break}else{SH(l,G,s,J,L,8,0,0,g);break}}else{if(K){SN(l,G,s,J,L,8,0,0,g);break}else{SL(l,G,s,J,L,8,0,0,g);break}}}else{do{if(!C){if((s|0)>(f-16|0)|(J|0)<0){break}if((J|0)>(i-16|0)){break}L=(I&1|0)!=0;K=I>>>8;if((I&2|0)==0){if(L){SA(l,G,s,J,K,8,0,g);break L46426}else{Sy(l,G,s,J,K,8,0,g);break L46426}}else{if(L){SE(l,G,s,J,K,8,0,g);break L46426}else{SC(l,G,s,J,K,8,0,g);break L46426}}}}while(0);K=(I&1|0)!=0;L=I>>>8;if((I&2|0)==0){if(K){SB(l,G,s,J,L,8,0,g);break}else{Sz(l,G,s,J,L,8,0,g);break}}else{if(K){SF(l,G,s,J,L,8,0,g);break}else{SD(l,G,s,J,L,8,0,g);break}}}}}while(0);B=B+1|0;}while((B|0)<(z|0))}B=k+1|0;if((B|0)<384){k=B;m=v;n=z;o=y;p=s;q=q+2|0;r=r+128|0}else{break}}r=h+57344|0;h=c[2438734]|0;q=c[2386320]|0;p=0;do{y=p>>5<<3;o=(p<<3&248)-16|0;z=e[r+(p<<1)>>1]|0;n=z&4095;m=z>>>12;do{if((o|0)>-1&(o|0)<(i|0)){z=a[h+n|0]|0;if(z<<24>>24==0){break}if((z&2)==0){Sq(l,n,y,o,m,8,0,0,q);break}else{Si(l,n,y,o,m,8,0,q);break}}}while(0);p=p+1|0;}while((p|0)<1280);R8(c[3530026]|0);return 0}function dY3(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=i;i=i+64|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;if((d|0)!=0){c[d>>2]=169624}Ts(b,d);if((b&96|0)==0){i=e;return 0}gGz(j|0,0,12);d=c[2414680]|0;c[j>>2]=d;c[j+4>>2]=(c[2411690]|0)-d;c[j+12>>2]=196728;gj[c[2076592]&4095](j)|0;j=h|0;do{if((b&64|0)!=0){gGz(g|0,0,16);c[2394]=-1;if((c[2392]|0)<0){break}d=h+9|0;k=f;l=f|0;m=f+4|0;n=f+12|0;o=g|0;p=g+4|0;q=g+12|0;r=0;do{gGC(j|0,614896,11)|0;a[d]=r+48&255;s=8452256+(r<<2)|0;gGz(k|0,0,12);c[l>>2]=s;c[m>>2]=4;c[n>>2]=164976;gj[c[2076592]&4095](f)|0;if((c[s>>2]|0)!=0){c[o>>2]=c[14130368+(r<<2)>>2];c[p>>2]=c[8452184+(r<<2)>>2];c[q>>2]=j;s=c[2076592]|0;gj[s&4095](g)|0}r=r+1|0;}while((r|0)<=(c[2392]|0))}}while(0);Ue();i=e;return 0}function dY4(b){b=b|0;var c=0,d=0,e=0;do{if((b|0)==1048577){c=-1}else if((b|0)==1572867){c=a[9657968]|0}else if((b|0)==1572874){c=0}else if((b|0)==1572873){if(a[641824]|0){c=~a[9625754];break}d=a[671672]|0;e=a[9625754]|0;if((a[9545160]|0)==0){if(d){c=-5-e&255;break}else{c=~e;break}}else{if(d){c=-13-e&255;break}else{c=-9-e&255;break}}}else if((b|0)==1572866){c=a[9657969]|0}else{c=0}}while(0);return c|0}function dY5(d,e){d=d|0;e=e|0;if((d|0)==1048577){if(!(a[808496]|0)){return}c[2439544]=e&255;return}else if((d|0)==1048576){if(a[641800]|0){dY6(e&255);return}else{Uv(0,e);return}}else if((d|0)==1048578){if(a[642528]|0){b[7054508]=(e&255)<<9}if(!(a[673544]|0)){return}b[7054508]=(e&255)<<8;return}else{return}}function dY6(a){a=a|0;var b=0,d=0,e=0,f=0;b=a&65535;d=c[801648+((b&255)<<2)>>2]|0;if((d|0)==0){return}else if((d|0)==(-2|0)){if(a<<16>>16==1){if((c[2113156]&8|0)==0){return}Uv(0,64);c[2427074]=0;return}if((c[2427074]|0)==(b|0)){return}c[2427074]=b;Uv(0,64);switch(b|0){case 7:{c[2430800]=4;c[2429454]=56;e=360448;f=-72;break};case 9:{c[2430800]=4;c[2429454]=56;e=360448;f=-72;break};case 4:{c[2430800]=1;c[2429454]=56;e=262144;f=-72;break};case 13:{c[2430800]=7;c[2429454]=56;e=458752;f=-72;break};case 10:{c[2430800]=2;c[2429454]=56;e=294912;f=-72;break};case 11:{c[2430800]=5;c[2429454]=56;e=393216;f=-72;break};case 8:{c[2430800]=3;c[2429454]=56;e=327680;f=-72;break};case 15:{c[2430800]=0;c[2429454]=51;e=229376;f=-77;break};case 6:{c[2430800]=2;c[2429454]=56;e=294912;f=-72;break};case 18:{c[2430800]=0;c[2429454]=52;e=229376;f=-76;break};case 12:{c[2430800]=6;c[2429454]=56;e=425984;f=-72;break};case 16:{c[2430800]=8;c[2429454]=56;e=491520;f=-72;break};case 5:{c[2430800]=6;c[2429454]=56;e=425984;f=-72;break};default:{c[2430800]=8;c[2429454]=56;e=491520;f=-72}}b=(c[3541206]|0)+229376|0;a=(c[2433470]|0)+e|0;gGC(b|0,a|0,32768)|0;if((c[2427074]|0)==0){return}if((c[2113156]&8|0)!=0){return}Uv(0,f);Uv(0,-126);return}else{f=c[2113156]|0;if((f&1|0)==0){Uv(0,d&255|-128);Uv(0,18);return}if((f&2|0)==0){Uv(0,d&255|-128);Uv(0,34);return}if((f&4|0)!=0){return}Uv(0,d&255|-128);Uv(0,66);return}}function dY7(b){b=b|0;var e=0,f=0,g=0;do{if((b|0)==1572866){e=d[9657969]<<8|d[9657968]}else if((b|0)==1572864){e=~(d[9625752]|d[9625753]<<8)}else if((b|0)==1048580){e=(cT()|0)&65535}else if((b|0)==1572872){if(a[673544]&(c[2276056]|0)==1376){e=416;break}if(a[641824]|0){e=~d[9625754];break}f=a[671672]|0;g=d[9625754]|0;if((a[9545160]|0)==0){if(f){e=65523-g&65535;break}else{e=(g^65535)&65535;break}}else{if(f){e=65523-g&65535;break}else{e=65527-g&65535;break}}}else{e=0}}while(0);return e|0}function dY8(d,e){d=d|0;e=e|0;var f=0,g=0;f=d-3145728|0;if(f>>>0<16){b[(c[3530986]|0)+(f>>>1<<1)>>1]=e;return}if((d|0)==1048578){if(!(a[673128]|0)){return}b[7054508]=e&16384;return}else if((d|0)==1048576){if(a[641800]|0){dY6(e);return}if(a[642464]|0){c[2439544]=e&255;d=c[2439330]|0;if((d|0)!=0){f=d;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0;f=c[1836236]|0;d=c[9757320+(f<<2)>>2]|0;if((d|0)!=0){g=d;gGC(g|0,9706056,76)|0}c[9752472+(f<<2)>>2]=c[2433530];c[14113936+(f<<2)>>2]=c[2076596];c[9669104+(f<<2)>>2]=c[3541536];c[1836236]=-1;return}f=e&255;if(!(a[808496]|0)){Uv(0,e&255);return}if((f|0)==0){return}c[2439544]=f;return}else{return}}function dY9(a){a=a|0;var b=0;if((a|0)==15204354){b=d[9657968]|0|-256}else if((a|0)==14680064){b=~(d[9625752]|0|(d[9625753]|0)<<8)}else if((a|0)==14942208){b=~(d[9625754]|0)}else{b=0}return b|0}function dZa(d,e){d=d|0;e=e|0;var f=0;f=d-10485760|0;if(f>>>0<16){b[(c[3530986]|0)+(f>>>1<<1)>>1]=e;return}if((d|0)==15466496){if(!(a[808496]|0)){return}f=e&255;if((f|0)==0){return}c[2439544]=f;return}else if((d|0)==14680064){b[7054508]=e<<14;return}else{return}}function dZb(b){b=b|0;var d=0,e=0;do{if((b|0)==1048581){d=c[2113156]&255}else if((b|0)==1572866){d=a[9657969]|0}else if((b|0)==1572873){e=a[9625754]|0;if((a[9545160]|0)==0){d=~e;break}else{d=-9-e&255;break}}else{d=0}}while(0);return d|0}function dZc(b,d){b=b|0;d=d|0;var e=0;if((b|0)==1048579){e=c[2113304]|0;a[14168504+e|0]=d;mv(0,e,d&255);return}else if((b|0)==1048581){Uv(0,d);return}else if((b|0)==1048577){c[2113304]=d&255;return}else{return}}function dZd(b){b=b|0;var c=0,e=0;if((b|0)==1572872){c=d[9625754]|0;if((a[9545160]|0)==0){e=(c^65535)&65535;return e|0}else{e=65527-c&65535;return e|0}}else if((b|0)==1572866){e=d[9657969]<<8|d[9657968];return e|0}else if((b|0)==1572864){e=~(d[9625752]|d[9625753]<<8);return e|0}else{e=0;return e|0}return 0}function dZe(a,d){a=a|0;d=d|0;var e=0;if((a-1443840|0)>>>0<8){return}e=a-3145728|0;if(e>>>0<16){b[(c[3530986]|0)+(e>>>1<<1)>>1]=d;return}if((a|0)!=1048576){return}c[2113304]=d&255;return}function dZf(a){a=a|0;var b=0;if((a|0)==1572870){b=(d[9657969]|0)<<8|(d[9657968]|0);return b|0}else if((a|0)==1572866){b=~(d[9625752]|0|(d[9625753]|0)<<8);return b|0}else if((a|0)==1572868){b=~(d[9625754]|0);return b|0}else{b=0;return b|0}return 0}function dZg(d,e){d=d|0;e=e|0;var f=0,g=0,h=0;f=d-3670016|0;if(f>>>0<16){b[(c[3530986]|0)+(f>>>1<<1)>>1]=e;return}if((d|0)!=1572876){return}c[2439544]=e&255;e=c[2439330]|0;d=(e|0)==0;if(!d){f=e;gGC(9706056,f|0,76)|0}b[4853030]=c[2426515]&65535;f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;h=c[2417276]|0;c[3541536]=h;c[1836236]=0;a[9706117]=1;if(!d){d=e;gGC(d|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=h;c[1836236]=-1;return}function dZh(a){a=a|0;var b=0,d=0;b=a&65535;if((b|0)==38912){d=c[2113156]&255}else if((b|0)==40960){d=c[2439544]&255}else{d=0}return d|0}function dZi(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;e=b&65535;if((e|0)==36864){b=d&3;a[14121016]=b;f=(c[3541206]|0)+131072|0;g=(c[2433470]|0)+((b&255)<<17)|0;gGC(f|0,g|0,131072)|0;return}else if((e|0)==38912){Uv(0,d);return}else{return}}function dZj(a){a=a|0;var b=0,d=0;b=a&65535;if((b|0)==61442){d=c[2113156]&255}else if((b|0)==61448){d=c[2439544]&255}else if((b|0)==61441){d=c[(c[3531464]|0)+4240>>2]&255}else{d=0}return d|0}function dZk(b,d){b=b|0;d=d|0;var e=0,f=0;e=b&65535;if((e|0)==61440){c[2113304]=d&255;return}else if((e|0)==61454){a[14121016]=d;b=(c[3541206]|0)+196608|0;f=(c[2433470]|0)+(((d&255)<<16)+196608)|0;gGC(b|0,f|0,65536)|0;return}else if((e|0)==61442){Uv(0,d);return}else if((e|0)==61441){e=c[2113304]|0;a[14168504+e|0]=d;mv(0,e,d&255);return}else{return}}function dZl(b){b=b|0;var d=0,e=0;d=b&255;if((d|0)==2){e=c[2113156]&255}else if((d|0)==3){a[9706117]=0;e=c[2439544]&255}else{e=0}return e|0}function dZm(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=b&255;if((f|0)==5){a[14117472]=e;b=c[2385836]|0;g=c[9757320+(c[1836236]<<2)>>2]|0;h=((e&255)<<14)-32768|0;i=128;j=128;while(1){c[g+76+(j<<2)>>2]=b+(h+(j<<8));k=i+1&65535;if((k&65535)>191){l=128;m=128;break}else{i=k;j=k&65535}}while(1){j=b+(h+(m<<8))|0;c[g+76+(m+512<<2)>>2]=j;c[g+76+(m+768<<2)>>2]=j;j=l+1&65535;if((j&65535)>191){break}else{l=j;m=j&65535}}return}else if((f|0)==1){m=c[3540984]|0;l=c[m+5876>>2]|0;if((l|0)!=0){gg[l&4095](c[m+5880>>2]|0,0)}lH(m,d[m+5885|0]|0,e&255);return}else if((f|0)==2){Uv(0,e);return}else if((f|0)==0){a[(c[3540984]|0)+5885|0]=e;return}else{return}}function dZn(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4913500+(b*112|0)>>2];c[a+104>>2]=c[4913504+(b*112|0)>>2];c[a+108>>2]=c[4913508+(b*112|0)>>2];d=0;return d|0}function dZo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=4913400+(b*112|0);e=0;return e|0}function dZp(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1653008+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dZq(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>41){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4914184+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dZr(){c[3527442]=4922;c[2387344]=11516;c[2386748]=9962;return d_M(2048,16383,-1,0,8192,16384,4096,58.0,8e5)|0}function dZs(){var d=0,e=0,f=0,g=0,h=0;if((c[2392]|0)>=0){d=0;do{e=14130368+(d<<2)|0;f=c[e>>2]|0;if((f|0)!=0){gGr(f);c[e>>2]=0}e=14130384+(d<<2)|0;f=c[e>>2]|0;if((f|0)!=0){gGr(f);c[e>>2]=0}d=d+1|0;}while((d|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;if(a[638032]|0){fwZ()}do{if(a[6939728]|0){d=c[3531464]|0;c[d+44344>>2]=0;c[d+44348>>2]=0;if((d|0)!=0){gGr(d);c[3531464]=0}d=c[2406684]|0;if((d|0)==0){break}gGr(d);c[2406684]=0}}while(0);Uw(0);c[2113070]=0;c[2113068]=0;d=c[2112926]|0;if((d|0)!=0){gGr(d);c[2112926]=0}a[9545160]=0;a[14121016]=0;a[14117472]=0;b[7054508]=0;c[2439544]=0;c[2429454]=0;c[2430800]=0;c[2427074]=0;c[2433436]=0;c[2433434]=0;c[2433438]=0;c[2439530]=0;c[2429756]=0;c[2439504]=0;c[2439650]=0;c[3527370]=0;c[3527366]=0;a[638032]=0;a[6939728]=0;a[6939712]=0;c[3530276]=0;a[641800]=0;a[642464]=0;a[642528]=0;a[673128]=0;a[671672]=0;a[673544]=0;a[641824]=0;a[808496]=0;c[3528986]=0;a[7388296]=0;c[3528984]=0;a[7388288]=0;c[3527442]=0;c[2387344]=0;c[2387340]=0;c[2386748]=0;d=c[2426734]|0;e=0;while(1){if((e|0)>=1024){g=35584;break}h=9638528+(e<<2)|0;if((c[h>>2]|0)==(d|0)){break}else{e=e+1|0}}if((g|0)==35584){c[2426734]=0;return 0}gGr(d);c[h>>2]=0;c[2426734]=0;return 0}function dZt(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;if((a[9624256]|0)!=0){d_E()}a[9625754]=0;a[9625753]=0;a[9625752]=0;d=0;e=0;f=0;g=0;do{e=((a[9759192+d|0]&1)<<d|e&255)&255;f=((a[9759e3+d|0]&1)<<d|f&255)&255;g=((a[9758816+d|0]&1)<<d|g&255)&255;d=d+1|0;}while((d|0)<8);a[9625752]=e;a[9625753]=f;a[9625754]=g;if((e&3)==3){g=e&-4;a[9625752]=g;h=g}else{h=e}if((h&12)==12){a[9625752]=h&-13}if((f&3)==3){h=f&-4;a[9625753]=h;i=h}else{i=f}if((i&12)==12){a[9625753]=i&-13}c[2444089]=0;c[2444088]=0;i=c[2392]|0;if((i|0)>=0){gGz(8452240,0,((i|0)>0?(i<<2)+4|0:4)|0)}c[2113054]=0;if(a[638032]|0){i=c[2385548]|0;if((i|0)>0){gGz(9752472,0,((i|0)>1?i<<2:4)|0)}c[2433530]=0}a[9545160]=0;i=0;f=0;L46904:while(1){h=f;while(1){if((h|0)>=315){break L46904}if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];e=c[3532592]|0;if((e|0)!=0){gGC(9104152,e|0,280)|0}c[2113054]=c[2113060]}j=h+1|0;e=(ag(c[2440532]|0,j)|0)/315|0;g=e-(c[2444088]|0)|0;c[2438190]=g;c[2113056]=g;e=RG(g)|0;c[2113054]=(c[2113054]|0)+e;c[2276108]=-1;c[2113056]=-1;c[2444088]=(c[2444088]|0)+e;do{if((h|0)==37){a[9545160]=1}else if((h|0)==314){c[8452200+(c[2394]<<2)>>2]=8198;c[2276080]=1536;if((c[2276079]|0)>>>0<1536){RH(6)}if((c[2427074]|0)==0|a[641800]^1){break}if((c[2113156]&8|0)!=0){break}Uv(0,(c[2429454]|128)&255);Uv(0,-126)}else if((h|0)==277){a[9545160]=0}}while(0);e=c[2394]|0;g=c[14130368+(e<<2)>>2]|0;if((g|0)!=0){gGC(g|0,9104152,280)|0}c[8452240+(e<<2)>>2]=c[2113054];c[2394]=-1;if(a[638032]|0){e=c[2439330]|0;if((e|0)!=0){g=e;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;g=c[2438118]|0;c[2433530]=g;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;d=(ag(c[2440484]|0,j)|0)/315|0;k=c[2444089]|0;l=d-k|0;c[2438190]=l;do{if((l|0)<1){m=0;n=k;o=0;p=e;q=g}else{if((a[e+4188|0]|0)==0){d=gfc(l)|0;r=(c[2433530]|0)+d|0;c[2433530]=r;s=c[1836236]|0;m=d;n=c[2444089]|0;o=s;p=c[9757320+(s<<2)>>2]|0;q=r;break}else{r=g+l|0;c[2433530]=r;m=l;n=k;o=0;p=e;q=r;break}}}while(0);c[2438190]=m;c[2444089]=n+m;if((p|0)!=0){e=p;gGC(e|0,9706056,76)|0}c[9752472+(o<<2)>>2]=q;c[14113936+(o<<2)>>2]=c[2076596];c[9669104+(o<<2)>>2]=c[3541536];c[1836236]=-1}t=c[2112964]|0;if((t|0)==0){h=j}else{break}}h=a[9688]&1;e=t+(i<<1<<1)|0;do{if(a[6939728]|0){if(a[638032]|0){k=c[2439330]|0;if((k|0)!=0){l=k;gGC(9706056,l|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0}gg[c[3542124]&4095](e,h);if(!(a[638032]|0)){break}l=c[1836236]|0;k=c[9757320+(l<<2)>>2]|0;if((k|0)!=0){g=k;gGC(g|0,9706056,76)|0}c[9752472+(l<<2)>>2]=c[2433530];c[14113936+(l<<2)>>2]=c[2076596];c[9669104+(l<<2)>>2]=c[3541536];c[1836236]=-1}}while(0);Uu(0,e,h);i=h+i|0;f=j}j=c[2112964]|0;do{if((j|0)!=0){f=a[9688]|0?534:0;t=f-i|0;o=j+(i<<1<<1)|0;if((f|0)==(i|0)){break}do{if(a[6939728]|0){if(a[638032]|0){f=c[2439330]|0;if((f|0)!=0){q=f;gGC(9706056,q|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0}gg[c[3542124]&4095](o,t);if(!(a[638032]|0)){break}q=c[1836236]|0;f=c[9757320+(q<<2)>>2]|0;if((f|0)!=0){p=f;gGC(p|0,9706056,76)|0}c[9752472+(q<<2)>>2]=c[2433530];c[14113936+(q<<2)>>2]=c[2076596];c[9669104+(q<<2)>>2]=c[3541536];c[1836236]=-1}}while(0);Uu(0,o,t)}}while(0);if((c[2112968]|0)==0){return 0}gu[c[2386748]&16383]();return 0}function dZu(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;g=i;i=i+288|0;h=g|0;j=g+16|0;k=g+32|0;l=g+48|0;m=g+64|0;n=g+80|0;o=g+96|0;p=g+112|0;q=g+128|0;r=g+144|0;s=g+160|0;t=g+176|0;u=g+192|0;v=g+208|0;w=g+224|0;x=g+240|0;y=g+256|0;z=g+272|0;if((f|0)!=0){c[f>>2]=169590}if((e&32|0)!=0){gGz(z|0,0,12);f=c[2405668]|0;c[z>>2]=f;c[z+4>>2]=(c[2411686]|0)-f;c[z+12>>2]=162152;f=c[2076592]|0;gj[f&4095](z)|0}if((e&64|0)!=0){z=m|0;gGz(l|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){f=m+9|0;m=k;A=k|0;B=k+4|0;C=k+12|0;D=l|0;E=l+4|0;F=l+12|0;G=0;do{gGC(z|0,614896,11)|0;a[f]=G+48&255;H=8452256+(G<<2)|0;gGz(m|0,0,12);c[A>>2]=H;c[B>>2]=4;c[C>>2]=164976;gj[c[2076592]&4095](k)|0;if((c[H>>2]|0)!=0){c[D>>2]=c[14130368+(G<<2)>>2];c[E>>2]=c[8452184+(G<<2)>>2];c[F>>2]=z;H=c[2076592]|0;gj[H&4095](l)|0}G=G+1|0;}while((G|0)<=(c[2392]|0))}if(a[638032]|0){fw$(e)}do{if(a[6939728]|0){gGz(j|0,0,12);c[j>>2]=8453216;c[j+4>>2]=4;c[j+12>>2]=107480;G=c[2076592]|0;gj[G&4095](j)|0;gGz(h|0,0,12);c[h>>2]=14168504;c[h+4>>2]=256;c[h+12>>2]=476464;G=c[2076592]|0;gj[G&4095](h)|0;if((e&2|0)==0){break}else{I=0}do{mv(0,I,d[14168504+I|0]|0);I=I+1|0;}while((I|0)<256)}}while(0);Ut(0);gGz(y|0,0,12);c[y>>2]=9776352;c[y+4>>2]=8;c[y+12>>2]=212472;I=c[2076592]|0;gj[I&4095](y)|0;gGz(x|0,0,12);c[x>>2]=9752760;c[x+4>>2]=4;c[x+12>>2]=436576;y=c[2076592]|0;gj[y&4095](x)|0;gGz(w|0,0,12);c[w>>2]=9657968;c[w+4>>2]=2;c[w+12>>2]=483352;x=c[2076592]|0;gj[x&4095](w)|0;gGz(v|0,0,12);c[v>>2]=9625752;c[v+4>>2]=3;c[v+12>>2]=215728;w=c[2076592]|0;gj[w&4095](v)|0;gGz(u|0,0,12);c[u>>2]=9545160;c[u+4>>2]=1;c[u+12>>2]=449152;v=c[2076592]|0;gj[v&4095](u)|0;gGz(t|0,0,12);c[t>>2]=14121016;c[t+4>>2]=1;c[t+12>>2]=491248;u=c[2076592]|0;gj[u&4095](t)|0;gGz(s|0,0,12);c[s>>2]=14117472;c[s+4>>2]=1;c[s+12>>2]=435944;t=c[2076592]|0;gj[t&4095](s)|0;gGz(r|0,0,12);c[r>>2]=14109016;c[r+4>>2]=2;c[r+12>>2]=434632;s=c[2076592]|0;gj[s&4095](r)|0;gGz(q|0,0,12);c[q>>2]=9758176;c[q+4>>2]=4;c[q+12>>2]=497064;r=c[2076592]|0;gj[r&4095](q)|0;gGz(p|0,0,12);c[p>>2]=9717816;c[p+4>>2]=4;c[p+12>>2]=432864;q=c[2076592]|0;gj[q&4095](p)|0;gGz(o|0,0,12);c[o>>2]=9723200;c[o+4>>2]=4;c[o+12>>2]=432112;p=c[2076592]|0;gj[p&4095](o)|0;gGz(n|0,0,12);c[n>>2]=9708296;c[n+4>>2]=4;c[n+12>>2]=431176;o=c[2076592]|0;gj[o&4095](n)|0}if((e&2|0)==0){i=g;return 0}e=a[14121016]|0;do{if(e<<24>>24!=0){n=c[3541206]|0;if(a[642464]|0){o=n+131072|0;p=(c[2433470]|0)+((e&255)<<17)|0;gGC(o|0,p|0,131072)|0;break}else{p=n+196608|0;n=(c[2433470]|0)+(((e&255)<<16)+196608)|0;gGC(p|0,n|0,65536)|0;break}}}while(0);e=a[14117472]|0;if(e<<24>>24==0){i=g;return 0}n=c[2439330]|0;p=(n|0)==0;if(!p){o=n;gGC(9706056,o|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];o=c[3528484]|0;c[2076596]=o;q=c[2417276]|0;c[3541536]=q;c[1836236]=0;r=c[2385836]|0;s=((e&255)<<14)-32768|0;e=128;t=128;while(1){c[n+76+(t<<2)>>2]=r+(s+(t<<8));u=e+1&65535;if((u&65535)>191){J=128;K=128;break}else{e=u;t=u&65535}}while(1){t=r+(s+(K<<8))|0;c[n+76+(K+512<<2)>>2]=t;c[n+76+(K+768<<2)>>2]=t;t=J+1&65535;if((t&65535)>191){break}else{J=t;K=t&65535}}if(!p){p=n;gGC(p|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=o;c[2417276]=q;c[1836236]=-1;i=g;return 0}function dZv(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3279476+(b*112|0)>>2];c[a+104>>2]=c[3279480+(b*112|0)>>2];c[a+108>>2]=c[3279484+(b*112|0)>>2];d=0;return d|0}function dZw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=3279376+(b*112|0);e=0;return e|0}function dZx(){a[641800]=1;c[3527442]=4922;c[2387344]=11516;c[2386748]=9962;return d_M(2048,16383,-1,0,8192,16384,4096,58.0,8e5)|0}function dZy(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3840484+(b*112|0)>>2];c[a+104>>2]=c[3840488+(b*112|0)>>2];c[a+108>>2]=c[3840492+(b*112|0)>>2];d=0;return d|0}function dZz(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=3840384+(b*112|0);e=0;return e|0}function dZA(){var b=0;a[642464]=1;a[638032]=1;c[3527442]=4340;c[2387344]=11516;c[2387340]=9124;c[2386748]=9962;b=d_M(2048,32767,-1,0,8192,16384,4096,60.0,1e6)|0;c[2440532]=2e5;c[2440484]=66666;return b|0}function dZB(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3742756+(b*112|0)>>2];c[a+104>>2]=c[3742760+(b*112|0)>>2];c[a+108>>2]=c[3742764+(b*112|0)>>2];d=0;return d|0}function dZC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=3742656+(b*112|0);e=0;return e|0}function dZD(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1231400+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dZE(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>31){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3744e3+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dZF(){var b=0;a[638032]=1;a[6939728]=1;c[3530276]=1;a[808496]=1;c[3527442]=1920;c[2387344]=11920;c[2387340]=4858;c[2386748]=9962;b=d_M(4096,32767,-1,0,16384,16384,4096,60.0,1024e3)|0;c[2440532]=25e4;c[2440484]=62500;return b|0}function dZG(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3631788+(b*112|0)>>2];c[a+104>>2]=c[3631792+(b*112|0)>>2];c[a+108>>2]=c[3631796+(b*112|0)>>2];d=0;return d|0}function dZH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=3631688+(b*112|0);e=0;return e|0}function dZI(){var b=0;a[641800]=1;c[3527442]=696;c[2387344]=10910;c[2386748]=5816;b=d_M(2048,32767,-1,0,8192,32768,8192,58.0,8e5)|0;c[2407030]=179;c[2407068]=3;return b|0}function dZJ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3329916+(b*112|0)>>2];c[a+104>>2]=c[3329920+(b*112|0)>>2];c[a+108>>2]=c[3329924+(b*112|0)>>2];d=0;return d|0}function dZK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=3329816+(b*112|0);e=0;return e|0}function dZL(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1184936+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dZM(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>23){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3331048+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dZN(){var b=0;a[638032]=1;a[808496]=1;c[3527442]=4104;c[2387344]=9740;c[2387340]=4858;c[2386748]=3812;b=d_M(2048,32767,0,0,8192,32768,8192,60.0,875e3)|0;c[3528986]=-6;c[3528984]=-2;c[2440484]=133333;c[2407030]=128;c[2407068]=3;return b|0}function dZO(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3859532+(b*112|0)>>2];c[a+104>>2]=c[3859536+(b*112|0)>>2];c[a+108>>2]=c[3859540+(b*112|0)>>2];d=0;return d|0}function dZP(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=3859432+(b*112|0);e=0;return e|0}function dZQ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1239072+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function dZR(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>24){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3860776+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dZS(){var b=0;a[638032]=1;a[6939728]=1;c[3530276]=1;a[808496]=1;c[3527442]=3790;c[2387344]=11920;c[2387340]=4858;c[2386748]=3382;b=d_M(4096,32767,-1,0,4096,16384,4096,60.0,1024e3)|0;c[2440532]=25e4;c[2440484]=62500;return b|0}function dZT(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5530884+(b*112|0)>>2];c[a+104>>2]=c[5530888+(b*112|0)>>2];c[a+108>>2]=c[5530892+(b*112|0)>>2];d=0;return d|0}function dZU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=5530784+(b*112|0);e=0;return e|0}function dZV(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>24){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5532128+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dZW(){var b=0;a[638032]=1;a[6939728]=1;c[3530276]=1;a[808496]=1;c[3527442]=3790;c[2387344]=11920;c[2387340]=4858;c[2386748]=3382;b=d_M(4096,32767,-1,0,4096,16384,4096,60.0,1024e3)|0;c[2440532]=25e4;c[2440484]=62500;c[3528986]=-5;a[7388296]=0;c[3528984]=-1;a[7388288]=1;return b|0}function dZX(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4160004+(b*112|0)>>2];c[a+104>>2]=c[4160008+(b*112|0)>>2];c[a+108>>2]=c[4160012+(b*112|0)>>2];d=0;return d|0}function dZY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=4159904+(b*112|0);e=0;return e|0}function dZZ(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>32){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4161248+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dZ_(){var b=0;a[642528]=1;a[638032]=1;a[6939728]=1;c[3530276]=1;a[808496]=1;c[3527442]=3120;c[2387344]=11920;c[2387340]=4858;c[2386748]=9962;b=d_M(4096,32767,-1,0,16384,65536,16384,60.0,1024e3)|0;c[2440532]=25e4;c[2440484]=62500;c[3528986]=-5;a[7388296]=0;c[3528984]=-1;a[7388288]=1;return b|0}function dZ$(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5991236+(b*112|0)>>2];c[a+104>>2]=c[5991240+(b*112|0)>>2];c[a+108>>2]=c[5991244+(b*112|0)>>2];d=0;return d|0}function dZ0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=5991136+(b*112|0);e=0;return e|0}function dZ1(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>33){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5992368+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dZ2(){var b=0;a[673128]=1;a[638032]=1;a[6939728]=1;c[3530276]=1;a[808496]=1;c[3527442]=3120;c[2387344]=11920;c[2387340]=4858;c[2386748]=3382;b=d_M(4096,32767,-1,0,16384,65536,16384,60.0,1024e3)|0;c[2440532]=25e4;c[2440484]=62500;c[3528986]=-5;a[7388296]=0;c[3528984]=-1;a[7388288]=1;return b|0}function dZ3(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4871804+(b*112|0)>>2];c[a+104>>2]=c[4871808+(b*112|0)>>2];c[a+108>>2]=c[4871812+(b*112|0)>>2];d=0;return d|0}function dZ4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=4871704+(b*112|0);e=0;return e|0}function dZ5(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>34){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4872936+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function dZ6(){var b=0;a[673128]=1;a[671672]=1;a[638032]=1;a[6939728]=1;c[3530276]=2;a[808496]=1;c[3527442]=3120;c[2387344]=11920;c[2387340]=4858;c[2386748]=3382;b=d_M(4096,32767,-1,0,16384,65536,16384,60.0,1024e3)|0;c[2440532]=25e4;c[2440484]=62500;c[3528986]=-5;a[7388296]=0;c[3528984]=-1;a[7388288]=1;return b|0}function dZ7(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5404468+(b*112|0)>>2];c[a+104>>2]=c[5404472+(b*112|0)>>2];c[a+108>>2]=c[5404476+(b*112|0)>>2];d=0;return d|0}function dZ8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=5404368+(b*112|0);e=0;return e|0}function dZ9(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1922240+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function d_a(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>38){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5405600+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function d_b(){var b=0;a[6939728]=1;a[638032]=0;c[2439504]=358e4;c[3527442]=2974;c[2387344]=5430;c[2386748]=4560;b=d_M(2048,16383,-1,0,8192,32768,8192,60.0,1023924)|0;c[2440532]=2e5;c[2429756]=63;h[745421]=.2;c[2436794]=1;h[745420]=.2;c[2436792]=2;return b|0}function d_c(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5082876+(b*112|0)>>2];c[a+104>>2]=c[5082880+(b*112|0)>>2];c[a+108>>2]=c[5082884+(b*112|0)>>2];d=0;return d|0}function d_d(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=5082776+(b*112|0);e=0;return e|0}function d_e(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>36){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5084792+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function d_f(){var b=0;a[673544]=1;a[638032]=1;a[6939728]=1;c[2439504]=3427190;c[3530276]=1;a[808496]=1;c[3527442]=738;c[2387344]=11920;c[2387340]=4858;c[2386748]=10064;b=d_M(4096,32767,0,1,32768,65536,16384,60.0,1024e3)|0;c[2440532]=25e4;c[2440484]=62500;c[3528986]=-5;a[7388296]=1;c[3528984]=-1;a[7388288]=0;return b|0}function d_g(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6416948+(b*112|0)>>2];c[a+104>>2]=c[6416952+(b*112|0)>>2];c[a+108>>2]=c[6416956+(b*112|0)>>2];d=0;return d|0}function d_h(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=6416848+(b*112|0);e=0;return e|0}function d_i(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>37){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6418864+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function d_j(){var b=0;a[673544]=1;a[638032]=1;a[6939728]=1;c[2439504]=3427190;c[3530276]=1;a[808496]=1;c[3527442]=5058;c[2387344]=11920;c[2387340]=4858;c[2386748]=3382;b=d_M(4096,32767,-1,0,32768,65536,16384,60.0,1024e3)|0;c[2440532]=25e4;c[2440484]=62500;c[3528986]=-5;a[7388296]=0;c[3528984]=-1;a[7388288]=0;return b|0}function d_k(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5575236+(b*112|0)>>2];c[a+104>>2]=c[5575240+(b*112|0)>>2];c[a+108>>2]=c[5575244+(b*112|0)>>2];d=0;return d|0}function d_l(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=5575136+(b*112|0);e=0;return e|0}function d_m(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3507476+(b*112|0)>>2];c[a+104>>2]=c[3507480+(b*112|0)>>2];c[a+108>>2]=c[3507484+(b*112|0)>>2];d=0;return d|0}function d_n(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=3507376+(b*112|0);e=0;return e|0}function d_o(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1196688+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function d_p(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>37){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3509392+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function d_q(){var b=0;a[641824]=1;a[673544]=1;a[638032]=1;a[6939728]=1;c[2439504]=3427190;c[3530276]=1;a[808496]=1;c[3527442]=5058;c[2387344]=11920;c[2387340]=4858;c[2386748]=3382;b=d_M(4096,32767,-1,0,32768,65536,16384,60.0,1024e3)|0;c[2440532]=25e4;c[2440484]=62500;c[3528986]=-2;a[7388296]=0;c[3528984]=-1;a[7388288]=0;return b|0}function d_r(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5450876+(b*112|0)>>2];c[a+104>>2]=c[5450880+(b*112|0)>>2];c[a+108>>2]=c[5450884+(b*112|0)>>2];d=0;return d|0}function d_s(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=5450776+(b*112|0);e=0;return e|0}function d_t(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>33){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5452120+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function d_u(){var b=0;a[638032]=1;a[6939728]=1;c[3530276]=2;a[808496]=1;c[3527442]=1920;c[2387344]=11920;c[2387340]=4858;c[2386748]=3382;b=d_M(4096,32767,-1,0,16384,16384,4096,60.0,1024e3)|0;c[2440532]=25e4;c[2440484]=62500;c[3528986]=-5;a[7388296]=0;c[3528984]=-1;a[7388288]=1;return b|0}function d_v(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5334172+(b*112|0)>>2];c[a+104>>2]=c[5334176+(b*112|0)>>2];c[a+108>>2]=c[5334180+(b*112|0)>>2];d=0;return d|0}function d_w(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=5334072+(b*112|0);e=0;return e|0}function d_x(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1867216+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function d_y(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>47){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5334856+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function d_z(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0;e=i;i=i+1080|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;v=e+840|0;w=e+952|0;x=e+960|0;y=e+1072|0;c[2433438]=4096;c[2439650]=16384;c[3527370]=32768;c[3527366]=8192;a[638032]=1;a[6939712]=1;c[2426734]=0;c[2388030]=0;c[2385836]=524288;c[3541206]=786432;c[2405668]=1048576;c[2388050]=1048576;c[2385854]=1835008;c[2443416]=1837056;c[2387072]=1841152;c[2387062]=1857536;c[2439616]=1873920;c[3530986]=1875968;c[2411686]=1875984;c[2406522]=1875984;c[2405814]=3973136;c[3529576]=6070288;c[3530024]=10264592;z=0;while(1){if((z|0)>=1024){break}A=9638528+(z<<2)|0;if((c[A>>2]|0)==0){B=36048;break}else{z=z+1|0}}do{if((B|0)==36048){z=gGq(10268688)|0;c[A>>2]=z;if((z|0)==0){break}c[2426734]=z;gGz(z|0,0,10268688);c[2388030]=z;c[2385836]=z+524288;c[3541206]=z+786432;C=z+1048576|0;c[2405668]=C;c[2388050]=C;c[2385854]=z+1835008;c[2443416]=z+1837056;C=c[2433438]|0;c[2387072]=z+(C+1837056);c[2387062]=z+(C+1853440);c[2439616]=z+(C+1869824);c[3530986]=z+(C+1871872);D=C+1871888|0;C=z+D|0;c[2411686]=C;c[2406522]=C;C=(c[3527370]<<6)+D|0;c[2405814]=z+C;D=C+(c[3527366]<<8)|0;c[3529576]=z+D;C=D+(c[2439650]<<8)|0;c[3530024]=z+C;c[2414228]=z+(C+4096);C=0;while(1){if((C|0)>=1024){E=0;break}F=9638528+(C<<2)|0;if((c[F>>2]|0)==0){B=36053;break}else{C=C+1|0}}do{if((B|0)==36053){C=gGq(2097152)|0;c[F>>2]=C;if((C|0)==0){E=0;break}gGz(C|0,0,2097152);E=C}}while(0);c[3529524]=E;C=c[642608+(c[2436]<<2)>>2]|0;z=(fa(c[C>>2]|0,164064)|0)==0;D=c[2388030]|0;do{if(z){if((R6(D+1|0,0,2)|0)!=0){G=1;i=e;return G|0}if((R6(c[2388030]|0,1,2)|0)!=0){G=1;i=e;return G|0}H=c[2385836]|0;if((c[3542200]|0)==0){G=1;i=e;return G|0}I=x+108|0;c[I>>2]=0;J=x+100|0;c[J>>2]=0;K=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[K&16383](x,2)|0;do{if((c[I>>2]|0)!=0){K=c[J>>2]|0;c[y>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](y,2,0)|0;if((K|0)<1){G=1;i=e;return G|0}if((gzL(H,0,2)|0)==0){break}else{G=1}i=e;return G|0}}while(0);H=c[3529524]|0;gGz(H|0,0,2097152);if((R6(H,7,4)|0)!=0){G=1;i=e;return G|0}if((R6((c[3529524]|0)+1|0,8,4)|0)!=0){G=1;i=e;return G|0}if((R6((c[3529524]|0)+2|0,9,4)|0)!=0){G=1;i=e;return G|0}if((R6((c[3529524]|0)+3|0,10,4)|0)!=0){G=1;i=e;return G|0}H=c[3527370]|0;J=c[3529524]|0;I=c[2406522]|0;if((H|0)>0){K=0;do{L=K<<6;gGz(I+L|0,0,64);M=K<<9;N=0;do{O=1<<7-N;P=(c[614800+(N<<2)>>2]|0)+M|0;Q=0;do{R=P+(c[3843568+(Q<<2)>>2]|0)|0;S=(Q<<3)+L|0;T=0;do{U=R+(c[3843600+(T<<2)>>2]|0)|0;if(((d[J+((U|0)/8|0)|0]|0)&128>>>((U&7)>>>0)|0)!=0){U=I+(S+T)|0;a[U]=(d[U]|0|O)&255}T=T+1|0;}while((T|0)<8);Q=Q+1|0;}while((Q|0)<8);N=N+1|0;}while((N|0)<8);K=K+1|0;}while((K|0)<(H|0))}H=c[3527366]|0;K=c[2405814]|0;if((H|0)>0){I=0;do{N=I<<8;gGz(K+N|0,0,256);L=I<<11;M=0;do{Q=1<<7-M;O=(c[614800+(M<<2)>>2]|0)+L|0;P=0;do{T=O+(c[1942600+(P<<2)>>2]|0)|0;S=(P<<4)+N|0;R=0;do{U=T+(c[598320+(R<<2)>>2]|0)|0;if(((d[J+((U|0)/8|0)|0]|0)&128>>>((U&7)>>>0)|0)!=0){U=K+(S+R)|0;a[U]=(d[U]|0|Q)&255}R=R+1|0;}while((R|0)<16);P=P+1|0;}while((P|0)<16);M=M+1|0;}while((M|0)<8);I=I+1|0;}while((I|0)<(H|0))}gGz(J|0,0,2097152);if((R6(J,3,2)|0)!=0){G=1;i=e;return G|0}if((R6((c[3529524]|0)+1|0,4,2)|0)!=0){G=1;i=e;return G|0}if((R6((c[3529524]|0)+1048576|0,5,2)|0)!=0){G=1;i=e;return G|0}if((R6((c[3529524]|0)+1048577|0,6,2)|0)!=0){G=1;i=e;return G|0}H=c[2439650]|0;I=c[3529524]|0;K=c[3529576]|0;if((H|0)>0){M=0;do{N=M<<8;gGz(K+N|0,0,256);L=M<<9;P=0;do{Q=1<<3-P;O=(c[687296+(P<<2)>>2]|0)+L|0;R=0;do{S=O+(c[608544+(R<<2)>>2]|0)|0;T=(R<<4)+N|0;U=0;do{V=S+(c[613816+(U<<2)>>2]|0)|0;if(((d[I+((V|0)/8|0)|0]|0)&128>>>((V&7)>>>0)|0)!=0){V=K+(T+U)|0;a[V]=(d[V]|0|Q)&255}U=U+1|0;}while((U|0)<16);R=R+1|0;}while((R|0)<16);P=P+1|0;}while((P|0)<4);M=M+1|0;}while((M|0)<(H|0))}H=c[3541206]|0;if((c[3542200]|0)==0){G=1;i=e;return G|0}M=v+108|0;c[M>>2]=0;K=v+100|0;c[K>>2]=0;I=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[I&16383](v,11)|0;if((c[M>>2]|0)==0){break}M=c[K>>2]|0;c[w>>2]=9534384;K=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[K&16383](w,11,0)|0;if((M|0)<1){G=1;i=e;return G|0}if((gzL(H,0,11)|0)==0){break}else{G=1}i=e;return G|0}else{if((c[3542200]|0)==0){G=1;i=e;return G|0}H=t+108|0;c[H>>2]=0;M=t+100|0;c[M>>2]=0;K=c[C+76>>2]|0;gA[K&16383](t,0)|0;do{if((c[H>>2]|0)!=0){K=c[M>>2]|0;c[u>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](u,0,0)|0;if((K|0)<1){G=1;i=e;return G|0}if((gzL(D,0,0)|0)==0){break}else{G=1}i=e;return G|0}}while(0);M=c[2385836]|0;if((c[3542200]|0)==0){G=1;i=e;return G|0}H=r+108|0;c[H>>2]=0;K=r+100|0;c[K>>2]=0;I=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[I&16383](r,1)|0;do{if((c[H>>2]|0)!=0){I=c[K>>2]|0;c[s>>2]=9534384;J=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[J&16383](s,1,0)|0;if((I|0)<1){G=1;i=e;return G|0}if((gzL(M,0,1)|0)==0){break}else{G=1}i=e;return G|0}}while(0);M=c[3529524]|0;gGz(M|0,0,2097152);if((c[3542200]|0)==0){G=1;i=e;return G|0}K=p+108|0;c[K>>2]=0;H=p+100|0;c[H>>2]=0;I=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[I&16383](p,2)|0;do{if((c[K>>2]|0)!=0){I=c[H>>2]|0;c[q>>2]=9534384;J=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[J&16383](q,2,0)|0;if((I|0)<1){G=1;i=e;return G|0}if((gzL(M,0,2)|0)==0){break}else{G=1}i=e;return G|0}}while(0);M=(c[3529524]|0)+1048576|0;if((c[3542200]|0)==0){G=1;i=e;return G|0}H=n+108|0;c[H>>2]=0;K=n+100|0;c[K>>2]=0;I=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[I&16383](n,3)|0;do{if((c[H>>2]|0)!=0){I=c[K>>2]|0;c[o>>2]=9534384;J=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[J&16383](o,3,0)|0;if((I|0)<1){G=1;i=e;return G|0}if((gzL(M,0,3)|0)==0){break}else{G=1}i=e;return G|0}}while(0);M=c[3527370]|0;K=c[3529524]|0;H=c[2406522]|0;if((M|0)>0){I=0;do{J=I<<6;gGz(H+J|0,0,64);P=I<<8;N=0;do{L=1<<7-N;R=(c[614800+(N<<2)>>2]|0)+P|0;Q=0;do{O=R+(c[1183816+(Q<<2)>>2]|0)|0;U=(Q<<3)+J|0;T=0;do{S=O+(c[5340808+(T<<2)>>2]|0)|0;if(((d[K+((S|0)/8|0)|0]|0)&128>>>((S&7)>>>0)|0)!=0){S=H+(U+T)|0;a[S]=(d[S]|0|L)&255}T=T+1|0;}while((T|0)<8);Q=Q+1|0;}while((Q|0)<8);N=N+1|0;}while((N|0)<8);I=I+1|0;}while((I|0)<(M|0))}M=c[3527366]|0;I=c[2405814]|0;if((M|0)>0){H=0;do{N=H<<8;gGz(I+N|0,0,256);J=H<<10;P=0;do{Q=1<<7-P;L=(c[614800+(P<<2)>>2]|0)+J|0;R=0;do{T=L+(c[3946808+(R<<2)>>2]|0)|0;U=(R<<4)+N|0;O=0;do{S=T+(c[5340744+(O<<2)>>2]|0)|0;if(((d[K+((S|0)/8|0)|0]|0)&128>>>((S&7)>>>0)|0)!=0){S=I+(U+O)|0;a[S]=(d[S]|0|Q)&255}O=O+1|0;}while((O|0)<16);R=R+1|0;}while((R|0)<16);P=P+1|0;}while((P|0)<8);H=H+1|0;}while((H|0)<(M|0))}gGz(K|0,0,2097152);if((c[3542200]|0)==0){G=1;i=e;return G|0}M=l+108|0;c[M>>2]=0;H=l+100|0;c[H>>2]=0;I=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[I&16383](l,4)|0;do{if((c[M>>2]|0)!=0){I=c[H>>2]|0;c[m>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](m,4,0)|0;if((I|0)<1){G=1;i=e;return G|0}if((gzL(K,0,4)|0)==0){break}else{G=1}i=e;return G|0}}while(0);K=(c[3529524]|0)+1048576|0;if((c[3542200]|0)==0){G=1;i=e;return G|0}H=j+108|0;c[H>>2]=0;M=j+100|0;c[M>>2]=0;I=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[I&16383](j,5)|0;do{if((c[H>>2]|0)!=0){I=c[M>>2]|0;c[k>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](k,5,0)|0;if((I|0)<1){G=1;i=e;return G|0}if((gzL(K,0,5)|0)==0){break}else{G=1}i=e;return G|0}}while(0);K=c[2439650]|0;M=c[3529524]|0;H=c[3529576]|0;if((K|0)>0){I=0;do{P=I<<8;gGz(H+P|0,0,256);N=I<<9;J=0;do{R=1<<3-J;Q=(c[687296+(J<<2)>>2]|0)+N|0;L=0;do{O=Q+(c[608544+(L<<2)>>2]|0)|0;U=(L<<4)+P|0;T=0;do{S=O+(c[613816+(T<<2)>>2]|0)|0;if(((d[M+((S|0)/8|0)|0]|0)&128>>>((S&7)>>>0)|0)!=0){S=H+(U+T)|0;a[S]=(d[S]|0|R)&255}T=T+1|0;}while((T|0)<16);L=L+1|0;}while((L|0)<16);J=J+1|0;}while((J|0)<4);I=I+1|0;}while((I|0)<(K|0))}K=c[3541206]|0;if((c[3542200]|0)==0){G=1;i=e;return G|0}I=f+108|0;c[I>>2]=0;H=f+100|0;c[H>>2]=0;M=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[M&16383](f,6)|0;if((c[I>>2]|0)==0){break}I=c[H>>2]|0;c[g>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](g,6,0)|0;if((I|0)<1){G=1;i=e;return G|0}if((gzL(K,0,6)|0)==0){break}else{G=1}i=e;return G|0}}while(0);D=c[3529524]|0;C=0;while(1){if((C|0)>=1024){break}W=9638528+(C<<2)|0;if((c[W>>2]|0)==(D|0)){B=36165;break}else{C=C+1|0}}if((B|0)==36165){gGr(D);c[W>>2]=0}c[3529524]=0;fxU(0,425984);if((c[2394]|0)==0){X=c[2112932]|0}else{c[2394]=0;C=c[3532596]|0;c[2112932]=C;z=c[3532592]|0;if((z|0)!=0){gGC(9104152,z|0,280)|0}c[2113054]=c[2113060];X=C}C=c[2388030]|0;z=X|0;K=0;while(1){I=C+K|0;c[z>>2]=I;c[z+131072>>2]=I;I=K+1024|0;if(I>>>0>524287){break}else{z=z+4|0;K=I}}K=c[2388050]|0;c[X+4608>>2]=K;c[X+70144>>2]=K;c[X+135680>>2]=K;z=K+1024|0;c[X+4612>>2]=z;c[X+70148>>2]=z;c[X+135684>>2]=z;z=K+2048|0;c[X+4616>>2]=z;c[X+70152>>2]=z;c[X+135688>>2]=z;z=K+3072|0;c[X+4620>>2]=z;c[X+70156>>2]=z;c[X+135692>>2]=z;z=K+4096|0;c[X+4624>>2]=z;c[X+70160>>2]=z;c[X+135696>>2]=z;z=K+5120|0;c[X+4628>>2]=z;c[X+70164>>2]=z;c[X+135700>>2]=z;z=K+6144|0;c[X+4632>>2]=z;c[X+70168>>2]=z;c[X+135704>>2]=z;z=K+7168|0;c[X+4636>>2]=z;c[X+70172>>2]=z;c[X+135708>>2]=z;z=K+8192|0;c[X+4640>>2]=z;c[X+70176>>2]=z;c[X+135712>>2]=z;z=K+9216|0;c[X+4644>>2]=z;c[X+70180>>2]=z;c[X+135716>>2]=z;z=K+10240|0;c[X+4648>>2]=z;c[X+70184>>2]=z;c[X+135720>>2]=z;z=K+11264|0;c[X+4652>>2]=z;c[X+70188>>2]=z;c[X+135724>>2]=z;z=K+12288|0;c[X+4656>>2]=z;c[X+70192>>2]=z;c[X+135728>>2]=z;z=K+13312|0;c[X+4660>>2]=z;c[X+70196>>2]=z;c[X+135732>>2]=z;z=K+14336|0;c[X+4664>>2]=z;c[X+70200>>2]=z;c[X+135736>>2]=z;z=K+15360|0;c[X+4668>>2]=z;c[X+70204>>2]=z;c[X+135740>>2]=z;z=c[2439616]|0;c[X+5120>>2]=z;c[X+70656>>2]=z;c[X+136192>>2]=z;C=z+1024|0;c[X+5124>>2]=C;c[X+70660>>2]=C;c[X+136196>>2]=C;C=c[2443416]|0;c[X+5632>>2]=C;c[X+71168>>2]=C;c[X+136704>>2]=C;z=C+1024|0;c[X+5636>>2]=z;c[X+71172>>2]=z;c[X+136708>>2]=z;z=C+2048|0;c[X+5640>>2]=z;c[X+71176>>2]=z;c[X+136712>>2]=z;z=C+3072|0;c[X+5644>>2]=z;c[X+71180>>2]=z;c[X+136716>>2]=z;z=X+6656|0;C=1703936;while(1){D=K+(C-1687552)|0;c[z>>2]=D;c[z+65536>>2]=D;c[z+131072>>2]=D;D=C+1024|0;if(D>>>0>1736703){break}else{z=z+4|0;C=D}}C=c[2387072]|0;c[X+12800>>2]=C;c[X+78336>>2]=C;c[X+143872>>2]=C;z=C+1024|0;c[X+12804>>2]=z;c[X+78340>>2]=z;c[X+143876>>2]=z;z=C+2048|0;c[X+12808>>2]=z;c[X+78344>>2]=z;c[X+143880>>2]=z;z=C+3072|0;c[X+12812>>2]=z;c[X+78348>>2]=z;c[X+143884>>2]=z;z=C+4096|0;c[X+12816>>2]=z;c[X+78352>>2]=z;c[X+143888>>2]=z;z=C+5120|0;c[X+12820>>2]=z;c[X+78356>>2]=z;c[X+143892>>2]=z;z=C+6144|0;c[X+12824>>2]=z;c[X+78360>>2]=z;c[X+143896>>2]=z;z=C+7168|0;c[X+12828>>2]=z;c[X+78364>>2]=z;c[X+143900>>2]=z;z=C+8192|0;c[X+12832>>2]=z;c[X+78368>>2]=z;c[X+143904>>2]=z;z=C+9216|0;c[X+12836>>2]=z;c[X+78372>>2]=z;c[X+143908>>2]=z;z=C+10240|0;c[X+12840>>2]=z;c[X+78376>>2]=z;c[X+143912>>2]=z;z=C+11264|0;c[X+12844>>2]=z;c[X+78380>>2]=z;c[X+143916>>2]=z;z=C+12288|0;c[X+12848>>2]=z;c[X+78384>>2]=z;c[X+143920>>2]=z;z=C+13312|0;c[X+12852>>2]=z;c[X+78388>>2]=z;c[X+143924>>2]=z;z=C+14336|0;c[X+12856>>2]=z;c[X+78392>>2]=z;c[X+143928>>2]=z;z=C+15360|0;c[X+12860>>2]=z;c[X+78396>>2]=z;c[X+143932>>2]=z;z=c[2387062]|0;c[X+12288>>2]=z;c[X+77824>>2]=z;c[X+143360>>2]=z;C=z+1024|0;c[X+12292>>2]=C;c[X+77828>>2]=C;c[X+143364>>2]=C;C=z+2048|0;c[X+12296>>2]=C;c[X+77832>>2]=C;c[X+143368>>2]=C;C=z+3072|0;c[X+12300>>2]=C;c[X+77836>>2]=C;c[X+143372>>2]=C;C=z+4096|0;c[X+12304>>2]=C;c[X+77840>>2]=C;c[X+143376>>2]=C;C=z+5120|0;c[X+12308>>2]=C;c[X+77844>>2]=C;c[X+143380>>2]=C;C=z+6144|0;c[X+12312>>2]=C;c[X+77848>>2]=C;c[X+143384>>2]=C;C=z+7168|0;c[X+12316>>2]=C;c[X+77852>>2]=C;c[X+143388>>2]=C;C=z+8192|0;c[X+12320>>2]=C;c[X+77856>>2]=C;c[X+143392>>2]=C;C=z+9216|0;c[X+12324>>2]=C;c[X+77860>>2]=C;c[X+143396>>2]=C;C=z+10240|0;c[X+12328>>2]=C;c[X+77864>>2]=C;c[X+143400>>2]=C;C=z+11264|0;c[X+12332>>2]=C;c[X+77868>>2]=C;c[X+143404>>2]=C;C=z+12288|0;c[X+12336>>2]=C;c[X+77872>>2]=C;c[X+143408>>2]=C;C=z+13312|0;c[X+12340>>2]=C;c[X+77876>>2]=C;c[X+143412>>2]=C;C=z+14336|0;c[X+12344>>2]=C;c[X+77880>>2]=C;c[X+143416>>2]=C;C=z+15360|0;c[X+12348>>2]=C;c[X+77884>>2]=C;c[X+143420>>2]=C;c[X+196688>>2]=834;c[X+196728>>2]=2704;C=c[3532592]|0;if((C|0)!=0){gGC(C|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);C=c[2439330]|0;z=(C|0)==0;if(!z){K=C;gGC(9706056,K|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];K=c[3528484]|0;c[2076596]=K;D=c[2417276]|0;c[3541536]=D;c[1836236]=0;c[C+4172>>2]=1448;c[C+4176>>2]=2192;I=c[2385836]|0;H=0;M=0;while(1){c[C+76+(M<<2)>>2]=I+(M<<8);J=H+1&65535;if((J&65535)>47){Y=0;Z=0;break}else{H=J;M=J&65535}}while(1){M=I+(Z<<8)|0;c[C+76+(Z+512<<2)>>2]=M;c[C+76+(Z+768<<2)>>2]=M;M=Y+1&65535;if((M&65535)>47){_=128;$=128;break}else{Y=M;Z=M&65535}}while(1){c[C+76+($<<2)>>2]=I+($<<8);M=_+1&65535;if((M&65535)>191){aa=128;ab=128;break}else{_=M;$=M&65535}}while(1){M=I+(ab<<8)|0;c[C+76+(ab+512<<2)>>2]=M;c[C+76+(ab+768<<2)>>2]=M;M=aa+1&65535;if((M&65535)>191){break}else{aa=M;ab=M&65535}}I=c[2385854]|0;c[C+1068>>2]=I;M=I+256|0;c[C+1072>>2]=M;H=I+512|0;c[C+1076>>2]=H;J=I+768|0;c[C+1080>>2]=J;P=I+1024|0;c[C+1084>>2]=P;N=I+1280|0;c[C+1088>>2]=N;L=I+1536|0;c[C+1092>>2]=L;R=I+1792|0;c[C+1096>>2]=R;c[C+2092>>2]=I;c[C+2096>>2]=M;c[C+2100>>2]=H;c[C+2104>>2]=J;c[C+2108>>2]=P;c[C+2112>>2]=N;c[C+2116>>2]=L;c[C+2120>>2]=R;c[C+3116>>2]=I;c[C+4140>>2]=I;c[C+3120>>2]=M;c[C+4144>>2]=M;c[C+3124>>2]=H;c[C+4148>>2]=H;c[C+3128>>2]=J;c[C+4152>>2]=J;c[C+3132>>2]=P;c[C+4156>>2]=P;c[C+3136>>2]=N;c[C+4160>>2]=N;c[C+3140>>2]=L;c[C+4164>>2]=L;c[C+3144>>2]=R;c[C+4168>>2]=R;if(!z){R=C;gGC(R|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=K;c[2417276]=D;c[1836236]=-1;UL(35e5,0,3584,0);c[2438224]=35e5;c[2433522]=3416;c[2406672]=1752;c[3528468]=9362;c[2443842]=584;h[745398]=.7;a[3203264]=1;Ux(0,6628,1);c[2407030]=128;c[2407068]=3;c[2424]=6e3;c[2440532]=266666;c[2440484]=58333;c[2433436]=1;c[2433434]=0;c[2439530]=32767;c[2429756]=15;c[3528986]=-928;a[7388296]=0;c[3528984]=-930;a[7388288]=0;R=c[642608+(c[2436]<<2)>>2]|0;L=c[R+128>>2]|0;if((c[R+52>>2]&4|0)==0){c[2113068]=L;N=c[R+132>>2]|0;c[2113070]=N;c[2443814]=L;c[2440436]=N;ac=L;ad=N}else{c[2113070]=L;N=c[R+132>>2]|0;c[2113068]=N;c[2440436]=L;c[2443814]=N;ac=N;ad=L}L=ag(ac<<1,ad)|0;N=gGq(L)|0;c[2112926]=N;if((N|0)!=0){gGz(N|0,0,L|0)}c[2386748]=12664;d_E();G=0;i=e;return G|0}}while(0);c[2426734]=0;G=1;i=e;return G|0}function d_A(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=a[7452584]|0;if(b){d=0;e=b&1;while(1){b=14163936+(d<<2)|0;f=c[b>>2]|0;g=c[2113006]|0;if((g|0)==0){h=36236}else{i=g-1|0;c[2113006]=i;if((i|0)==0){h=36236}}if((h|0)==36236){h=0;c[2383474]=0}if((f|0)==0){j=e}else{gGr(f);j=a[7452584]&1}c[b>>2]=0;b=d+1|0;if((b|0)<(j|0)){d=b;e=j}else{break}}}a[7452584]=0;c[2438224]=0;c[2433522]=0;c[2406672]=0;c[3528468]=0;j=c[2406688]|0;if((j|0)==0){c[2432972]=0;k=dZs()|0;return 0}gGr(j);c[2406688]=0;c[2432972]=0;k=dZs()|0;return 0}function d_B(){var d=0,e=0,f=0,g=0,h=0,i=0;if((a[9624256]|0)!=0){d_E()}a[9625754]=0;a[9625753]=0;a[9625752]=0;d=0;e=0;f=0;g=0;do{e=((a[9759192+d|0]&1)<<d|e&255)&255;f=((a[9759e3+d|0]&1)<<d|f&255)&255;g=((a[9758816+d|0]&1)<<d|g&255)&255;d=d+1|0;}while((d|0)<8);a[9625752]=e;a[9625753]=f;a[9625754]=g;if((e&3)==3){g=e&-4;a[9625752]=g;h=g}else{h=e}if((h&12)==12){a[9625752]=h&-13}if((f&3)==3){h=f&-4;a[9625753]=h;i=h}else{i=f}if((i&12)==12){a[9625753]=i&-13}c[2444089]=0;c[2444088]=0;i=c[2392]|0;if((i|0)>=0){gGz(8452240,0,((i|0)>0?(i<<2)+4|0:4)|0)}c[2113054]=0;i=c[2385548]|0;if((i|0)>0){gGz(9752472,0,((i|0)>1?i<<2:4)|0)}c[2433530]=0;i=0;while(1){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060]}f=i+1|0;h=(ag(c[2440532]|0,f)|0)/32|0;e=h-(c[2444088]|0)|0;c[2438190]=e;c[2113056]=e;h=RG(e)|0;c[2113054]=(c[2113054]|0)+h;c[2276108]=-1;c[2113056]=-1;c[2444088]=(c[2444088]|0)+h;do{if((i|0)==31){c[8452200+(c[2394]<<2)>>2]=8198;c[2276080]=1536;if((c[2276079]|0)>>>0>=1536){break}RH(6)}}while(0);h=c[2394]|0;e=c[14130368+(h<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(h<<2)>>2]=c[2113054];c[2394]=-1;h=c[2439330]|0;if((h|0)!=0){e=h;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;UF(ag((c[2440484]|0)/32|0,i)|0)|0;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;e=(c[2433530]|0)+12|0;c[2433530]=e;h=c[1836236]|0;g=c[9757320+(h<<2)>>2]|0;if((g|0)!=0){d=g;gGC(d|0,9706056,76)|0}c[9752472+(h<<2)>>2]=e;c[14113936+(h<<2)>>2]=c[2076596];c[9669104+(h<<2)>>2]=c[3541536];c[1836236]=-1;if((f|0)<32){i=f}else{break}}i=c[2439330]|0;if((i|0)!=0){h=i;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;h=c[2440484]|0;i=gGU(h,(h|0)<0|0?-1:0,2048e6,0)|0;e=c[2438224]|0;d=gGS(i,K,e,(e|0)<0|0?-1:0)|0;e=d;UF(h)|0;h=c[2443826]|0;if((h|0)<1073676288){c[2443826]=h-e}h=c[2443827]|0;if((h|0)<1073676288){c[2443827]=h-e}h=(c[3528508]|0)-e|0;c[3528508]=(h|0)<0?0:h;gg[c[3542112]&4095](c[2112964]|0,a[9688]|0?534:0);h=c[1836236]|0;e=c[9757320+(h<<2)>>2]|0;if((e|0)!=0){d=e;gGC(d|0,9706056,76)|0}c[9752472+(h<<2)>>2]=c[2433530];c[14113936+(h<<2)>>2]=c[2076596];c[9669104+(h<<2)>>2]=c[3541536];c[1836236]=-1;Uu(0,c[2112964]|0,a[9688]|0?534:0);if((c[2112968]|0)==0){return 0}d_F();return 0}function d_C(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3839140+(b*112|0)>>2];c[a+104>>2]=c[3839144+(b*112|0)>>2];c[a+108>>2]=c[3839148+(b*112|0)>>2];d=0;return d|0}function d_D(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=3839040+(b*112|0);e=0;return e|0}function d_E(){var d=0,e=0,f=0,g=0,i=0;d=c[3530276]|0;if((d|0)==2){e=(c[2388050]|0)+512|0;f=c[3527338]|0;gGC(e|0,f|0,512)|0}else if((d|0)==1){d=c[2388050]|0;f=c[3527338]|0;gGC(d|0,f|0,512)|0}if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060]}RI();f=c[2394]|0;d=c[14130368+(f<<2)>>2]|0;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[8452240+(f<<2)>>2]=c[2113054];c[2394]=-1;if(a[638032]|0){f=c[2439330]|0;d=(f|0)==0;if(!d){e=f;gGC(9706056,e|0,76)|0}e=c[2438118]|0;c[2433530]=e;g=c[3528484]|0;c[2076596]=g;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);if(!d){d=f;gGC(d|0,9706056,76)|0}c[2438118]=e;c[3528484]=g;c[2417276]=i;c[1836236]=-1}if(a[6939728]|0){mx(0)}if(a[6939712]|0){c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;lw(c[3540984]|0)}c[2113156]=0;a[9628264]=0;c[2407033]=0;i=c[3541206]|0;c[3541190]=i;c[3541198]=i;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=i+256;c[3541199]=i+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=i+512;c[3541200]=i+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=i+768;c[3541201]=i+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;a[9545160]=0;a[14121016]=0;b[7054508]=0;c[2439544]=0;c[2429454]=0;c[2430800]=0;c[2427074]=0;i=c[3530986]|0;g=i|0;C=0;b[g>>1]=C&65535;b[g+2>>1]=C>>16;g=i+4|0;C=0;b[g>>1]=C&65535;b[g+2>>1]=C>>16;return}function d_F(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;d=c[2112926]|0;gGz(d|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);f=c[3530024]|0;g=0;h=c[2439616]|0;i=f;while(1){j=b[h>>1]|0;c[i>>2]=((j&65535)>>>10<<3&248)<<8|((j&255)<<3&255)>>>3|(((j&65535)>>>7&4|(j&65535)>>>5<<3&255)&255)<<3&2016;j=g+1|0;if((j|0)<1024){g=j;h=h+2|0;i=i+4|0}else{break}}i=c[3530986]|0;h=i+14|0;g=c[2387062]|0;if((b[h>>1]&1)==0){j=c[3528984]|0;k=i+2|0;l=a[7388288]|0?2:0;m=c[2406522]|0;n=0;o=0;while(1){p=n<<3;q=o;r=0;while(1){s=e[g+(q<<1)>>1]|0;t=(r<<3)-((e[i>>1]|0)+j&1023)|0;u=p-(l+(e[k>>1]|0)&511)|0;v=(t|0)<-8?t+1024|0:t;t=(u|0)<-8?u+512|0:u;u=t-8|0;do{if((v-1|0)>>>0<311){if((t-9|0)>>>0>=231){w=36340;break}Sq(d,s,v,u,0,8,0,512,m)}else{w=36340}}while(0);if((w|0)==36340){w=0;Sr(d,s,v,u,0,8,0,512,m)}t=r+1|0;if((t|0)>=128){break}q=q+1|0;r=t}r=n+1|0;if((r|0)<64){n=r;o=o+128|0}else{break}}}else{o=(c[3527366]|0)+65535|0;n=c[3528984]|0;m=i+2|0;k=a[7388288]|0?2:0;l=c[2405814]|0;j=0;r=0;while(1){q=j<<4;p=r;t=0;while(1){x=o&(e[g+(p<<1)>>1]|0);y=(t<<4)-((e[i>>1]|0)+n&1023)|0;z=q-(k+(e[m>>1]|0)&1023)|0;A=(y|0)<-16?y+1024|0:y;y=(z|0)<-16?z+1024|0:z;z=y-8|0;do{if((A-1|0)>>>0<303){if((y-9|0)>>>0>=223){w=36332;break}Sy(d,x,A,z,0,8,512,l)}else{w=36332}}while(0);if((w|0)==36332){w=0;Sz(d,x,A,z,0,8,512,l)}y=t+1|0;if((y|0)>=64){break}p=p+1|0;t=y}t=j+1|0;if((t|0)<64){j=t;r=r+64|0}else{break}}}r=c[2387072]|0;if((b[h>>1]&2)==0){h=i+4|0;j=c[3528986]|0;l=i+6|0;m=a[7388296]|0?496:0;k=c[2406522]|0;n=0;g=0;while(1){o=n<<3;t=g;p=0;while(1){q=e[r+(t<<1)>>1]|0;y=(p<<3)-((e[h>>1]|0)+j&1023)|0;u=o-(m+(e[l>>1]|0)&511)|0;v=(y|0)<-8?y+1024|0:y;y=(u|0)<-8?u+512|0:u;u=y-8|0;do{if((v-1|0)>>>0<311){if((y-9|0)>>>0>=231){w=36359;break}Sq(d,q,v,u,0,8,0,256,k)}else{w=36359}}while(0);if((w|0)==36359){w=0;Sr(d,q,v,u,0,8,0,256,k)}y=p+1|0;if((y|0)>=128){break}t=t+1|0;p=y}p=n+1|0;if((p|0)<64){n=p;g=g+128|0}else{break}}d_G(0,1);R8(f);return}else{g=(c[3527366]|0)-1|0;n=i+4|0;k=c[3528986]|0;l=i+6|0;i=a[7388296]|0?1008:0;m=c[2405814]|0;j=0;h=0;while(1){p=j<<4;t=h;o=0;while(1){y=b[r+(t<<1)>>1]&8191&g;z=(o<<4)-((e[n>>1]|0)+k&1023)|0;A=p-(i+(e[l>>1]|0)&1023)|0;x=(z|0)<-16?z+1024|0:z;z=(A|0)<-16?A+1024|0:A;A=z-8|0;do{if((x-1|0)>>>0<303){if((z-9|0)>>>0>=223){w=36351;break}SG(d,y,x,A,0,8,0,256,m)}else{w=36351}}while(0);if((w|0)==36351){w=0;SH(d,y,x,A,0,8,0,256,m)}z=o+1|0;if((z|0)>=64){break}t=t+1|0;o=z}o=j+1|0;if((o|0)<64){j=o;h=h+64|0}else{break}}d_G(0,1);R8(f);return}}function d_G(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;d=c[2443416]|0;f=c[2433438]|0;if((f|0)<=1){return}g=(b|0)==0;b=c[2439530]|0;h=c[2429756]|0;i=c[2433436]|0;j=c[2433434]|0;k=(c[2439650]|0)-1|0;l=c[2112926]|0;m=c[3529576]|0;n=(c[2113222]&1|0)==0;o=0;do{p=(e[d+((o|1)<<1)>>1]|0)&b;do{if((p|0)!=0){q=e[d+(o<<1)>>1]|0;if(!((q&4096|0)==0|n)){break}r=e[d+((o|2)<<1)>>1]|0;s=r>>>9&h;t=q&8192;u=q&16384;v=1<<(q>>>9&3);w=v-1|0;x=r&511;y=q&511;z=x>>>0>319?r|-512:x;x=(u|0)!=0;r=(x?0:w)+p|0;A=(u>>>13^2)-1|0;if(g){B=304-z|0;C=t}else{B=z;C=t>>>13^1}if((v|0)<=0){break}v=232-(y>>>0>255?q|-512:y)|0;y=i+B|0;q=(y-17|0)>>>0<287;if((C|0)==0){t=w;while(1){z=(t*-16|0)+v+j|0;u=k&r-(ag(t,A)|0);do{if(q){if((z-17|0)>>>0>=207){D=36376;break}if(x){SK(l,u,y,z,s,4,a,0,m);break}else{SG(l,u,y,z,s,4,a,0,m);break}}else{D=36376}}while(0);do{if((D|0)==36376){D=0;if(x){SL(l,u,y,z,s,4,a,0,m);break}else{SH(l,u,y,z,s,4,a,0,m);break}}}while(0);if((t|0)>0){t=t-1|0}else{break}}}else{t=w;while(1){z=(t*-16|0)+v+j|0;u=k&r-(ag(t,A)|0);do{if(q){if((z-17|0)>>>0>=207){D=36388;break}if(x){SM(l,u,y,z,s,4,a,0,m);break}else{SI(l,u,y,z,s,4,a,0,m);break}}else{D=36388}}while(0);do{if((D|0)==36388){D=0;if(x){SN(l,u,y,z,s,4,a,0,m);break}else{SJ(l,u,y,z,s,4,a,0,m);break}}}while(0);if((t|0)>0){t=t-1|0}else{break}}}}}while(0);o=o+4|0;}while((o|0)<((f|0)/2|0|0));return}function d_H(a){a=a|0;return(ag((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0,a)|0)/35e5|0|0}function d_I(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;b=i;i=i+360|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;l=0;while(1){if((l|0)>=1024){m=0;break}n=9638528+(l<<2)|0;if((c[n>>2]|0)==0){o=36400;break}else{l=l+1|0}}do{if((o|0)==36400){l=gGq(2097152)|0;c[n>>2]=l;if((l|0)==0){m=0;break}gGz(l|0,0,2097152);m=l}}while(0);c[3529524]=m;if((R6((c[2388030]|0)+1|0,0,2)|0)!=0){p=1;i=b;return p|0}if((R6(c[2388030]|0,1,2)|0)!=0){p=1;i=b;return p|0}m=c[2385836]|0;if((c[3542200]|0)==0){p=1;i=b;return p|0}n=j+108|0;c[n>>2]=0;l=j+100|0;c[l>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,2)|0;do{if((c[n>>2]|0)!=0){j=c[l>>2]|0;c[k>>2]=9534384;q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[q&16383](k,2,0)|0;if((j|0)<1){p=1;i=b;return p|0}if((gzL(m,0,2)|0)==0){break}else{p=1}i=b;return p|0}}while(0);m=c[3527338]|0;if((c[3542200]|0)==0){p=1;i=b;return p|0}k=g+108|0;c[k>>2]=0;l=g+100|0;c[l>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,3)|0;do{if((c[k>>2]|0)!=0){g=c[l>>2]|0;c[h>>2]=9534384;n=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[n&16383](h,3,0)|0;if((g|0)<1){p=1;i=b;return p|0}if((gzL(m,0,3)|0)==0){break}else{p=1}i=b;return p|0}}while(0);m=0;h=c[3527338]|0;while(1){l=a[h]|0;k=h+1|0;a[h]=a[k]|0;a[k]=l;l=m+1|0;if((l|0)<256){m=l;h=h+2|0}else{break}}if((R6((c[3529524]|0)+1|0,4,2)|0)!=0){p=1;i=b;return p|0}if((R6(c[3529524]|0,5,2)|0)!=0){p=1;i=b;return p|0}h=c[3529524]|0;m=c[3527366]|0;l=m<<7;do{if((l|0)>0){k=0;do{if((k&32|0)==0){g=h+k|0;n=a[g]|0;j=h+(k+32)|0;a[g]=a[j]|0;a[j]=n}k=k+1|0;}while((k|0)<(l|0));k=(l|0)/2|0;if((l|0)>1){r=0}else{break}do{n=h+r|0;j=a[n]|0;g=h+(r+k)|0;a[n]=a[g]|0;a[g]=j;r=r+1|0;}while((r|0)<(k|0))}}while(0);r=c[3527370]|0;l=c[2406522]|0;if((r|0)>0){k=0;do{j=k<<6;gGz(l+j|0,0,64);g=k<<7;n=0;do{q=1<<3-n;s=(c[683256+(n<<2)>>2]|0)+g|0;t=0;do{u=s+(c[6669224+(t<<2)>>2]|0)|0;v=(t<<3)+j|0;w=0;do{x=u+(c[614800+(w<<2)>>2]|0)|0;if(((d[h+((x|0)/8|0)|0]|0)&128>>>((x&7)>>>0)|0)!=0){x=l+(v+w)|0;a[x]=(d[x]|0|q)&255}w=w+1|0;}while((w|0)<8);t=t+1|0;}while((t|0)<8);n=n+1|0;}while((n|0)<4);k=k+1|0;}while((k|0)<(r|0))}r=c[2405814]|0;if((m|0)>0){k=0;do{l=k<<8;gGz(r+l|0,0,256);n=k<<9;j=0;do{g=1<<3-j;t=(c[683256+(j<<2)>>2]|0)+n|0;q=0;do{s=t+(c[608544+(q<<2)>>2]|0)|0;w=(q<<4)+l|0;v=0;do{u=s+(c[613816+(v<<2)>>2]|0)|0;if(((d[h+((u|0)/8|0)|0]|0)&128>>>((u&7)>>>0)|0)!=0){u=r+(w+v)|0;a[u]=(d[u]|0|g)&255}v=v+1|0;}while((v|0)<16);q=q+1|0;}while((q|0)<16);j=j+1|0;}while((j|0)<4);k=k+1|0;}while((k|0)<(m|0))}gGz(h|0,0,2097152);if((R6(h,6,2)|0)!=0){p=1;i=b;return p|0}if((R6((c[3529524]|0)+1|0,7,2)|0)!=0){p=1;i=b;return p|0}if((R6((c[3529524]|0)+1048576|0,8,2)|0)!=0){p=1;i=b;return p|0}if((R6((c[3529524]|0)+1048577|0,9,2)|0)!=0){p=1;i=b;return p|0}h=c[2439650]|0;m=c[3529524]|0;k=c[3529576]|0;if((h|0)>0){r=0;do{j=r<<8;gGz(k+j|0,0,256);l=r<<9;n=0;do{q=1<<3-n;g=(c[687296+(n<<2)>>2]|0)+l|0;t=0;do{v=g+(c[608544+(t<<2)>>2]|0)|0;w=(t<<4)+j|0;s=0;do{u=v+(c[613816+(s<<2)>>2]|0)|0;if(((d[m+((u|0)/8|0)|0]|0)&128>>>((u&7)>>>0)|0)!=0){u=k+(w+s)|0;a[u]=(d[u]|0|q)&255}s=s+1|0;}while((s|0)<16);t=t+1|0;}while((t|0)<16);n=n+1|0;}while((n|0)<4);r=r+1|0;}while((r|0)<(h|0))}h=c[3541206]|0;if((c[3542200]|0)==0){p=1;i=b;return p|0}r=e+108|0;c[r>>2]=0;k=e+100|0;c[k>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,10)|0;do{if((c[r>>2]|0)!=0){e=c[k>>2]|0;c[f>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](f,10,0)|0;if((e|0)<1){p=1;i=b;return p|0}if((gzL(h,0,10)|0)==0){break}else{p=1}i=b;return p|0}}while(0);h=c[3529524]|0;f=0;while(1){if((f|0)>=1024){break}y=9638528+(f<<2)|0;if((c[y>>2]|0)==(h|0)){o=36463;break}else{f=f+1|0}}if((o|0)==36463){gGr(h);c[y>>2]=0}c[3529524]=0;p=0;i=b;return p|0}function d_J(){var a=0,b=0,d=0,e=0,f=0,g=0;fxU(0,425984);if((c[2394]|0)==0){a=c[2112932]|0}else{c[2394]=0;b=c[3532596]|0;c[2112932]=b;d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];a=b}b=c[2388030]|0;d=a|0;e=0;while(1){f=b+e|0;c[d>>2]=f;c[d+131072>>2]=f;f=e+1024|0;if(f>>>0>1048575){break}else{d=d+4|0;e=f}}e=c[2388050]|0;c[a+4608>>2]=e;c[a+70144>>2]=e;c[a+135680>>2]=e;d=e+1024|0;c[a+4612>>2]=d;c[a+70148>>2]=d;c[a+135684>>2]=d;d=e+2048|0;c[a+4616>>2]=d;c[a+70152>>2]=d;c[a+135688>>2]=d;d=e+3072|0;c[a+4620>>2]=d;c[a+70156>>2]=d;c[a+135692>>2]=d;d=e+4096|0;c[a+4624>>2]=d;c[a+70160>>2]=d;c[a+135696>>2]=d;d=e+5120|0;c[a+4628>>2]=d;c[a+70164>>2]=d;c[a+135700>>2]=d;d=e+6144|0;c[a+4632>>2]=d;c[a+70168>>2]=d;c[a+135704>>2]=d;d=e+7168|0;c[a+4636>>2]=d;c[a+70172>>2]=d;c[a+135708>>2]=d;d=e+8192|0;c[a+4640>>2]=d;c[a+70176>>2]=d;c[a+135712>>2]=d;d=e+9216|0;c[a+4644>>2]=d;c[a+70180>>2]=d;c[a+135716>>2]=d;d=e+10240|0;c[a+4648>>2]=d;c[a+70184>>2]=d;c[a+135720>>2]=d;d=e+11264|0;c[a+4652>>2]=d;c[a+70188>>2]=d;c[a+135724>>2]=d;d=e+12288|0;c[a+4656>>2]=d;c[a+70192>>2]=d;c[a+135728>>2]=d;d=e+13312|0;c[a+4660>>2]=d;c[a+70196>>2]=d;c[a+135732>>2]=d;d=e+14336|0;c[a+4664>>2]=d;c[a+70200>>2]=d;c[a+135736>>2]=d;d=e+15360|0;c[a+4668>>2]=d;c[a+70204>>2]=d;c[a+135740>>2]=d;d=c[2439616]|0;c[a+5120>>2]=d;c[a+70656>>2]=d;c[a+136192>>2]=d;b=d+1024|0;c[a+5124>>2]=b;c[a+70660>>2]=b;c[a+136196>>2]=b;b=c[2443416]|0;c[a+5632>>2]=b;c[a+71168>>2]=b;c[a+136704>>2]=b;d=b+1024|0;c[a+5636>>2]=d;c[a+71172>>2]=d;c[a+136708>>2]=d;d=b+2048|0;c[a+5640>>2]=d;c[a+71176>>2]=d;c[a+136712>>2]=d;d=b+3072|0;c[a+5644>>2]=d;c[a+71180>>2]=d;c[a+136716>>2]=d;d=e+16384|0;c[a+6656>>2]=d;c[a+72192>>2]=d;c[a+137728>>2]=d;d=e+17408|0;c[a+6660>>2]=d;c[a+72196>>2]=d;c[a+137732>>2]=d;d=e+18432|0;c[a+6664>>2]=d;c[a+72200>>2]=d;c[a+137736>>2]=d;d=e+19456|0;c[a+6668>>2]=d;c[a+72204>>2]=d;c[a+137740>>2]=d;d=c[2387072]|0;c[a+12800>>2]=d;c[a+78336>>2]=d;c[a+143872>>2]=d;b=d+1024|0;c[a+12804>>2]=b;c[a+78340>>2]=b;c[a+143876>>2]=b;b=d+2048|0;c[a+12808>>2]=b;c[a+78344>>2]=b;c[a+143880>>2]=b;b=d+3072|0;c[a+12812>>2]=b;c[a+78348>>2]=b;c[a+143884>>2]=b;b=d+4096|0;c[a+12816>>2]=b;c[a+78352>>2]=b;c[a+143888>>2]=b;b=d+5120|0;c[a+12820>>2]=b;c[a+78356>>2]=b;c[a+143892>>2]=b;b=d+6144|0;c[a+12824>>2]=b;c[a+78360>>2]=b;c[a+143896>>2]=b;b=d+7168|0;c[a+12828>>2]=b;c[a+78364>>2]=b;c[a+143900>>2]=b;b=c[2387062]|0;c[a+12832>>2]=b;c[a+78368>>2]=b;c[a+143904>>2]=b;d=b+1024|0;c[a+12836>>2]=d;c[a+78372>>2]=d;c[a+143908>>2]=d;d=b+2048|0;c[a+12840>>2]=d;c[a+78376>>2]=d;c[a+143912>>2]=d;d=b+3072|0;c[a+12844>>2]=d;c[a+78380>>2]=d;c[a+143916>>2]=d;d=e+20480|0;c[a+13328>>2]=d;c[a+78864>>2]=d;c[a+144400>>2]=d;d=e+21504|0;c[a+13332>>2]=d;c[a+78868>>2]=d;c[a+144404>>2]=d;d=e+22528|0;c[a+13336>>2]=d;c[a+78872>>2]=d;c[a+144408>>2]=d;d=e+23552|0;c[a+13340>>2]=d;c[a+78876>>2]=d;c[a+144412>>2]=d;d=e+24576|0;c[a+13344>>2]=d;c[a+78880>>2]=d;c[a+144416>>2]=d;d=e+25600|0;c[a+13348>>2]=d;c[a+78884>>2]=d;c[a+144420>>2]=d;d=e+26624|0;c[a+13352>>2]=d;c[a+78888>>2]=d;c[a+144424>>2]=d;d=e+27648|0;c[a+13356>>2]=d;c[a+78892>>2]=d;c[a+144428>>2]=d;c[a+196688>>2]=1430;c[a+196728>>2]=2802;c[a+196608>>2]=3156;c[a+196648>>2]=3314;a=c[3532592]|0;if((a|0)==0){g=c[2113054]|0;c[2113060]=g;c[2394]=-1;return}gGC(a|0,9104152,280)|0;g=c[2113054]|0;c[2113060]=g;c[2394]=-1;return}function d_K(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;fwR(0);a=c[2439330]|0;d=(a|0)==0;if(!d){e=a;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];e=c[3528484]|0;c[2076596]=e;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;c[a+4180>>2]=922;c[a+4184>>2]=3394;g=c[2385836]|0;h=0;i=0;while(1){c[a+76+(i<<2)>>2]=g+(i<<8);j=h+1&65535;if((j&65535)>207){k=0;l=0;break}else{h=j;i=j&65535}}while(1){i=g+(l<<8)|0;c[a+76+(l+512<<2)>>2]=i;c[a+76+(l+768<<2)>>2]=i;i=k+1&65535;if((i&65535)>207){break}else{k=i;l=i&65535}}l=c[2385854]|0;c[a+908>>2]=l;k=l+256|0;c[a+912>>2]=k;g=l+512|0;c[a+916>>2]=g;i=l+768|0;c[a+920>>2]=i;h=l+1024|0;c[a+924>>2]=h;j=l+1280|0;c[a+928>>2]=j;m=l+1536|0;c[a+932>>2]=m;n=l+1792|0;c[a+936>>2]=n;c[a+1932>>2]=l;c[a+1936>>2]=k;c[a+1940>>2]=g;c[a+1944>>2]=i;c[a+1948>>2]=h;c[a+1952>>2]=j;c[a+1956>>2]=m;c[a+1960>>2]=n;c[a+2956>>2]=l;c[a+3980>>2]=l;c[a+2960>>2]=k;c[a+3984>>2]=k;c[a+2964>>2]=g;c[a+3988>>2]=g;c[a+2968>>2]=i;c[a+3992>>2]=i;c[a+2972>>2]=h;c[a+3996>>2]=h;c[a+2976>>2]=j;c[a+4e3>>2]=j;c[a+2980>>2]=m;c[a+4004>>2]=m;c[a+2984>>2]=n;c[a+4008>>2]=n;if(d){o=c[2433530]|0;c[2438118]=o;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}d=a;gGC(d|0,9706056,76)|0;o=c[2433530]|0;c[2438118]=o;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}function d_L(){var a=0,d=0,f=0,g=0,h=0;a=c[2112926]|0;gGz(a|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);a=c[3530024]|0;d=0;f=c[2439616]|0;g=a;while(1){h=b[f>>1]|0;c[g>>2]=((h&65535)>>>10<<3&248)>>>3|((h&255)<<3&255)<<8|(((h&65535)>>>7&4|(h&65535)>>>5<<3&255)&255)<<3&2016;h=d+1|0;if((h|0)<1024){d=h;f=f+2|0;g=g+4|0}else{break}}g=c[3530986]|0;d_O(e[g+6>>1]|0,e[g+8>>1]|0);if((b[g+12>>1]&128)==0){d_Q(e[g+2>>1]|0,e[g+4>>1]|0);d_G(0,0);R8(a);return}else{d_P();d_G(0,0);R8(a);return}}function d_M(b,d,e,f,g,i,j,k,l){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;i=i|0;j=j|0;k=+k;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;c[2433438]=b;c[2439650]=g;c[3527370]=i;c[3527366]=j;c[2426734]=0;c[2388030]=0;m=a[638032]|0;if(m){c[2385836]=1048576}if((c[3530276]|0)!=0){c[3527338]=1114112}c[3541206]=1114624;c[2433470]=1376768;c[2405668]=2425344;c[2388050]=2425344;if(m){c[2385854]=2492928}c[2443416]=2494976;c[2387072]=b+2494976;c[2387062]=b+2503168;c[2439616]=b+2511360;c[3530986]=b+2515456;m=b+2515472|0;b=m|0;c[2411686]=b;c[2406522]=b;b=(i<<6)+m|0;c[2405814]=b;m=b+(j<<8)|0;c[3529576]=m;j=m+(g<<8)|0;c[3530024]=j;g=j+8192|0;c[2414228]=g;j=g;g=0;while(1){if((g|0)>=1024){break}n=9638528+(g<<2)|0;if((c[n>>2]|0)==0){o=36523;break}else{g=g+1|0}}do{if((o|0)==36523){g=gGq(j)|0;c[n>>2]=g;if((g|0)==0){break}gGz(g|0,0,j|0);c[2426734]=g;gGz(g|0,0,j|0);c[2388030]=g;m=a[638032]|0;if(m){c[2385836]=g+1048576}if((c[3530276]|0)!=0){c[3527338]=g+1114112}c[3541206]=g+1114624;c[2433470]=g+1376768;b=g+2425344|0;c[2405668]=b;c[2388050]=b;if(m){c[2385854]=g+2492928}c[2443416]=g+2494976;m=c[2433438]|0;c[2387072]=g+(m+2494976);c[2387062]=g+(m+2503168);c[2439616]=g+(m+2511360);c[3530986]=g+(m+2515456);b=m+2515472|0;m=g+b|0;c[2411686]=m;c[2406522]=m;m=(c[3527370]<<6)+b|0;c[2405814]=g+m;b=m+(c[3527366]<<8)|0;c[3529576]=g+b;m=b+(c[2439650]<<8)|0;c[3530024]=g+m;c[2414228]=g+(m+8192);m=c[3527442]|0;gD[m&8191]()|0;gu[c[2387344]&16383]();if(a[638032]|0){gu[c[2387340]&16383]()}do{if(a[6939728]|0){m=c[2439504]|0;if((m|0)==0){c[2439504]=3427190;p=3427190}else{p=m}Vc(p);h[745421]=.1;c[2436794]=1;h[745420]=.1;c[2436792]=2;if(a[638032]|0){c[(c[3531464]|0)+44344>>2]=1474}m=(l|0)/132|0;if(!(a[6939728]|0)){q=m;o=36541;break}Ux(0,m,1);r=256}else{q=(l|0)/132|0;o=36541}}while(0);if((o|0)==36541){Ux(0,q,0);r=179}c[2407030]=r;c[2407068]=3;c[2424]=~~(k*100.0);c[2440532]=233333;c[2433436]=e;c[2433434]=f;c[2439530]=d;c[2429756]=15;c[3528986]=-5;a[7388296]=0;c[3528984]=-1;a[7388288]=0;m=c[642608+(c[2436]<<2)>>2]|0;g=c[m+128>>2]|0;if((c[m+52>>2]&4|0)==0){c[2113068]=g;b=c[m+132>>2]|0;c[2113070]=b;c[2443814]=g;c[2440436]=b;s=g;t=b}else{c[2113070]=g;b=c[m+132>>2]|0;c[2113068]=b;c[2440436]=g;c[2443814]=b;s=b;t=g}g=ag(s<<1,t)|0;b=gGq(g)|0;c[2112926]=b;if((b|0)!=0){gGz(b|0,0,g|0)}d_E();u=0;return u|0}}while(0);c[2426734]=0;u=1;return u|0}function d_N(b){b=b|0;a[9706117]=(b|0)!=0|0;return}function d_O(b,d){b=b|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=c[2387062]|0;g=(c[3527366]|0)-1|0;h=(c[3528984]|0)+b&1023;b=(a[7388288]|0?2:0)+d&511;d=c[2112926]|0;i=c[2405814]|0;j=0;do{k=j<<5;l=(j<<4)-b|0;m=(l|0)<-16?l+512|0:l;l=m-8|0;n=(m-9|0)>>>0<223;m=0;do{o=e[f+((m&31|k|m<<5&3072)<<1)>>1]|0;p=o>>>12;q=((e[7054508]|0)>>>2|o&4095)&g;o=(m<<4)-h|0;r=(o|0)<-16?o+1024|0:o;if((r-1|0)>>>0<303^1|n^1){Sz(d,q,r,l,p,4,512,i)}else{Sy(d,q,r,l,p,4,512,i)}m=m+1|0;}while((m|0)<64);j=j+1|0;}while((j|0)<32);return}function d_P(){var b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;b=c[2387072]|0;d=(c[3527370]|0)-1|0;f=c[3530986]|0;g=f+2|0;h=c[3528986]|0;i=f+4|0;f=a[7388296]|0?240:0;j=c[2112926]|0;k=c[2406522]|0;l=0;m=0;while(1){n=l<<3;o=m;p=0;while(1){q=e[b+(o<<1)>>1]|0;r=q>>>12;s=(q&4095|(e[7054508]|0))&d;q=(p<<3)-((e[g>>1]|0)+h&511)|0;t=n-(f+(e[i>>1]|0)&255)|0;u=(q|0)<-8?q+512|0:q;q=(t|0)<-8?t+256|0:t;t=q-8|0;do{if((u-1|0)>>>0<311){if((q-9|0)>>>0>=231){v=36565;break}Sq(j,s,u,t,r,4,0,256,k)}else{v=36565}}while(0);if((v|0)==36565){v=0;Sr(j,s,u,t,r,4,0,256,k)}q=p+1|0;if((q|0)<64){o=o+1|0;p=q}else{break}}p=l+1|0;if((p|0)<32){l=p;m=m+64|0}else{break}}return}function d_Q(b,d){b=b|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=c[2387072]|0;g=(c[3527366]|0)-1|0;h=(c[3528986]|0)+b&1023;b=(a[7388296]|0?496:0)+d&511;d=c[2112926]|0;i=c[2405814]|0;j=0;do{k=j<<5;l=(j<<4)-b|0;m=(l|0)<-16?l+512|0:l;l=m-8|0;n=(m-9|0)>>>0<223;m=0;do{o=e[f+((m&31|k|m<<5&3072)<<1)>>1]|0;p=o>>>12;q=((e[7054508]|0)>>>2|o&4095)&g;o=(m<<4)-h|0;r=(o|0)<-16?o+1024|0:o;if((r-1|0)>>>0<303^1|n^1){SH(d,q,r,l,p,4,0,256,i)}else{SG(d,q,r,l,p,4,0,256,i)}m=m+1|0;}while((m|0)<64);j=j+1|0;}while((j|0)<32);return}function d_R(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;b=i;i=i+360|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;l=0;while(1){if((l|0)>=1024){m=0;break}n=9638528+(l<<2)|0;if((c[n>>2]|0)==0){o=36580;break}else{l=l+1|0}}do{if((o|0)==36580){l=gGq(4194304)|0;c[n>>2]=l;if((l|0)==0){m=0;break}gGz(l|0,0,4194304);m=l}}while(0);c[3529524]=m;if((R6(m+1|0,0,2)|0)!=0){p=1;i=b;return p|0}if((R6(c[3529524]|0,1,2)|0)!=0){p=1;i=b;return p|0}m=c[2388030]|0;n=m+262144|0;l=c[3529524]|0;gGC(n|0,l|0,262144)|0;n=l+262144|0;gGC(m|0,n|0,262144)|0;gGz(l|0,0,4194304);if((c[3542200]|0)==0){p=1;i=b;return p|0}n=j+108|0;c[n>>2]=0;m=j+100|0;c[m>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,2)|0;do{if((c[n>>2]|0)!=0){j=c[m>>2]|0;c[k>>2]=9534384;q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[q&16383](k,2,0)|0;if((j|0)<1){p=1;i=b;return p|0}if((gzL(l,0,2)|0)==0){break}else{p=1}i=b;return p|0}}while(0);l=c[2385836]|0;k=l+16384|0;m=c[3529524]|0;gGC(k|0,m|0,16384)|0;k=m+16384|0;gGC(l|0,k|0,16384)|0;k=l+49152|0;n=m+32768|0;gGC(k|0,n|0,16384)|0;n=l+32768|0;l=m+49152|0;gGC(n|0,l|0,16384)|0;gGz(m|0,0,4194304);m=c[3527338]|0;if((c[3542200]|0)==0){p=1;i=b;return p|0}l=g+108|0;c[l>>2]=0;n=g+100|0;c[n>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,3)|0;do{if((c[l>>2]|0)!=0){g=c[n>>2]|0;c[h>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](h,3,0)|0;if((g|0)<1){p=1;i=b;return p|0}if((gzL(m,0,3)|0)==0){break}else{p=1}i=b;return p|0}}while(0);m=0;h=c[3527338]|0;while(1){n=a[h]|0;l=h+1|0;a[h]=a[l]|0;a[l]=n;n=m+1|0;if((n|0)<256){m=n;h=h+2|0}else{break}}h=c[3529524]|0;gGz(h|0,0,4194304);if((R6(h+2097152|0,4,2)|0)!=0){p=1;i=b;return p|0}if((R6((c[3529524]|0)+2097153|0,5,2)|0)!=0){p=1;i=b;return p|0}if((R6((c[3529524]|0)+3145728|0,6,2)|0)!=0){p=1;i=b;return p|0}if((R6((c[3529524]|0)+3145729|0,7,2)|0)!=0){p=1;i=b;return p|0}h=c[3529524]|0;m=h+2097152|0;gGC(h|0,m|0,262144)|0;m=h+1048576|0;n=h+2359296|0;gGC(m|0,n|0,262144)|0;n=h+262144|0;m=h+2621440|0;gGC(n|0,m|0,262144)|0;m=h+1310720|0;n=h+2883584|0;gGC(m|0,n|0,262144)|0;n=h+524288|0;m=h+3145728|0;gGC(n|0,m|0,262144)|0;m=h+1572864|0;n=h+3407872|0;gGC(m|0,n|0,262144)|0;n=h+786432|0;m=h+3670016|0;gGC(n|0,m|0,262144)|0;m=h+1835008|0;n=h+3932160|0;gGC(m|0,n|0,262144)|0;n=c[3527366]|0;m=n<<7;do{if((m|0)>0){l=0;do{if((l&32|0)==0){g=h+l|0;k=a[g]|0;j=h+(l+32)|0;a[g]=a[j]|0;a[j]=k}l=l+1|0;}while((l|0)<(m|0));l=(m|0)/2|0;if((m|0)>1){r=0}else{break}do{k=h+r|0;j=a[k]|0;g=h+(r+l)|0;a[k]=a[g]|0;a[g]=j;r=r+1|0;}while((r|0)<(l|0))}}while(0);r=c[3527370]|0;m=c[2406522]|0;if((r|0)>0){l=0;do{j=l<<6;gGz(m+j|0,0,64);g=l<<7;k=0;do{q=1<<3-k;s=(c[687296+(k<<2)>>2]|0)+g|0;t=0;do{u=s+(c[6669224+(t<<2)>>2]|0)|0;v=(t<<3)+j|0;w=0;do{x=u+(c[614800+(w<<2)>>2]|0)|0;if(((d[h+((x|0)/8|0)|0]|0)&128>>>((x&7)>>>0)|0)!=0){x=m+(v+w)|0;a[x]=(d[x]|0|q)&255}w=w+1|0;}while((w|0)<8);t=t+1|0;}while((t|0)<8);k=k+1|0;}while((k|0)<4);l=l+1|0;}while((l|0)<(r|0))}r=c[2405814]|0;if((n|0)>0){l=0;do{m=l<<8;gGz(r+m|0,0,256);k=l<<9;j=0;do{g=1<<3-j;t=(c[687296+(j<<2)>>2]|0)+k|0;q=0;do{s=t+(c[608544+(q<<2)>>2]|0)|0;w=(q<<4)+m|0;v=0;do{u=s+(c[613816+(v<<2)>>2]|0)|0;if(((d[h+((u|0)/8|0)|0]|0)&128>>>((u&7)>>>0)|0)!=0){u=r+(w+v)|0;a[u]=(d[u]|0|g)&255}v=v+1|0;}while((v|0)<16);q=q+1|0;}while((q|0)<16);j=j+1|0;}while((j|0)<4);l=l+1|0;}while((l|0)<(n|0))}gGz(h|0,0,2097152);if((R6(h,8,2)|0)!=0){p=1;i=b;return p|0}if((R6((c[3529524]|0)+1|0,9,2)|0)!=0){p=1;i=b;return p|0}if((R6((c[3529524]|0)+1048576|0,10,2)|0)!=0){p=1;i=b;return p|0}if((R6((c[3529524]|0)+1048577|0,11,2)|0)!=0){p=1;i=b;return p|0}if((R6((c[3529524]|0)+2097152|0,12,2)|0)!=0){p=1;i=b;return p|0}if((R6((c[3529524]|0)+2097153|0,13,2)|0)!=0){p=1;i=b;return p|0}if((R6((c[3529524]|0)+3145728|0,14,2)|0)!=0){p=1;i=b;return p|0}if((R6((c[3529524]|0)+3145729|0,15,2)|0)!=0){p=1;i=b;return p|0}h=c[2439650]|0;n=c[3529524]|0;l=c[3529576]|0;if((h|0)>0){r=0;do{j=r<<8;gGz(l+j|0,0,256);m=r<<9;k=0;do{q=1<<3-k;g=(c[808192+(k<<2)>>2]|0)+m|0;t=0;do{v=g+(c[608544+(t<<2)>>2]|0)|0;w=(t<<4)+j|0;s=0;do{u=v+(c[613816+(s<<2)>>2]|0)|0;if(((d[n+((u|0)/8|0)|0]|0)&128>>>((u&7)>>>0)|0)!=0){u=l+(w+s)|0;a[u]=(d[u]|0|q)&255}s=s+1|0;}while((s|0)<16);t=t+1|0;}while((t|0)<16);k=k+1|0;}while((k|0)<4);r=r+1|0;}while((r|0)<(h|0))}h=c[3541206]|0;if((c[3542200]|0)==0){p=1;i=b;return p|0}r=e+108|0;c[r>>2]=0;l=e+100|0;c[l>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,16)|0;do{if((c[r>>2]|0)!=0){e=c[l>>2]|0;c[f>>2]=9534384;n=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[n&16383](f,16,0)|0;if((e|0)<1){p=1;i=b;return p|0}if((gzL(h,0,16)|0)==0){break}else{p=1}i=b;return p|0}}while(0);h=c[3529524]|0;f=0;while(1){if((f|0)>=1024){break}y=9638528+(f<<2)|0;if((c[y>>2]|0)==(h|0)){o=36649;break}else{f=f+1|0}}if((o|0)==36649){gGr(h);c[y>>2]=0}c[3529524]=0;p=0;i=b;return p|0}function d_S(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;b=i;i=i+360|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;l=0;while(1){if((l|0)>=1024){m=0;break}n=9638528+(l<<2)|0;if((c[n>>2]|0)==0){o=36679;break}else{l=l+1|0}}do{if((o|0)==36679){l=gGq(4194304)|0;c[n>>2]=l;if((l|0)==0){m=0;break}gGz(l|0,0,4194304);m=l}}while(0);c[3529524]=m;if((R6(m+1|0,0,2)|0)!=0){p=1;i=b;return p|0}if((R6(c[3529524]|0,1,2)|0)!=0){p=1;i=b;return p|0}m=c[2388030]|0;n=m+786432|0;l=c[3529524]|0;gGC(n|0,l|0,262144)|0;n=m+524288|0;q=l+262144|0;gGC(n|0,q|0,262144)|0;q=m+262144|0;n=l+524288|0;gGC(q|0,n|0,262144)|0;n=l+786432|0;gGC(m|0,n|0,262144)|0;n=c[2385836]|0;if((c[3542200]|0)==0){p=1;i=b;return p|0}m=j+108|0;c[m>>2]=0;l=j+100|0;c[l>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,2)|0;do{if((c[m>>2]|0)!=0){j=c[l>>2]|0;c[k>>2]=9534384;q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[q&16383](k,2,0)|0;if((j|0)<1){p=1;i=b;return p|0}if((gzL(n,0,2)|0)==0){break}else{p=1}i=b;return p|0}}while(0);n=c[3527338]|0;if((c[3542200]|0)==0){p=1;i=b;return p|0}k=g+108|0;c[k>>2]=0;l=g+100|0;c[l>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,3)|0;do{if((c[k>>2]|0)!=0){g=c[l>>2]|0;c[h>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](h,3,0)|0;if((g|0)<1){p=1;i=b;return p|0}if((gzL(n,0,3)|0)==0){break}else{p=1}i=b;return p|0}}while(0);n=0;h=c[3527338]|0;while(1){l=a[h]|0;k=h+1|0;a[h]=a[k]|0;a[k]=l;l=n+1|0;if((l|0)<256){n=l;h=h+2|0}else{break}}h=c[3529524]|0;gGz(h|0,0,4194304);if((R6(h+2097153|0,4,2)|0)!=0){p=1;i=b;return p|0}if((R6((c[3529524]|0)+2097152|0,5,2)|0)!=0){p=1;i=b;return p|0}if((R6((c[3529524]|0)+3145729|0,6,2)|0)!=0){p=1;i=b;return p|0}if((R6((c[3529524]|0)+3145728|0,7,2)|0)!=0){p=1;i=b;return p|0}h=c[3529524]|0;n=h+2097152|0;gGC(h|0,n|0,262144)|0;n=h+1048576|0;l=h+2359296|0;gGC(n|0,l|0,262144)|0;l=h+262144|0;n=h+2621440|0;gGC(l|0,n|0,262144)|0;n=h+1310720|0;l=h+2883584|0;gGC(n|0,l|0,262144)|0;l=h+524288|0;n=h+3145728|0;gGC(l|0,n|0,262144)|0;n=h+1572864|0;l=h+3407872|0;gGC(n|0,l|0,262144)|0;l=h+786432|0;n=h+3670016|0;gGC(l|0,n|0,262144)|0;n=h+1835008|0;l=h+3932160|0;gGC(n|0,l|0,262144)|0;l=c[3527366]|0;n=l<<7;do{if((n|0)>0){k=0;do{if((k&32|0)==0){g=h+k|0;m=a[g]|0;j=h+(k+32)|0;a[g]=a[j]|0;a[j]=m}k=k+1|0;}while((k|0)<(n|0));k=(n|0)/2|0;if((n|0)>1){r=0}else{break}do{m=h+r|0;j=a[m]|0;g=h+(r+k)|0;a[m]=a[g]|0;a[g]=j;r=r+1|0;}while((r|0)<(k|0))}}while(0);r=c[3527370]|0;n=c[2406522]|0;if((r|0)>0){k=0;do{j=k<<6;gGz(n+j|0,0,64);g=k<<7;m=0;do{q=1<<3-m;s=(c[687296+(m<<2)>>2]|0)+g|0;t=0;do{u=s+(c[6669224+(t<<2)>>2]|0)|0;v=(t<<3)+j|0;w=0;do{x=u+(c[614800+(w<<2)>>2]|0)|0;if(((d[h+((x|0)/8|0)|0]|0)&128>>>((x&7)>>>0)|0)!=0){x=n+(v+w)|0;a[x]=(d[x]|0|q)&255}w=w+1|0;}while((w|0)<8);t=t+1|0;}while((t|0)<8);m=m+1|0;}while((m|0)<4);k=k+1|0;}while((k|0)<(r|0))}r=c[2405814]|0;if((l|0)>0){k=0;do{n=k<<8;gGz(r+n|0,0,256);m=k<<9;j=0;do{g=1<<3-j;t=(c[687296+(j<<2)>>2]|0)+m|0;q=0;do{s=t+(c[608544+(q<<2)>>2]|0)|0;w=(q<<4)+n|0;v=0;do{u=s+(c[613816+(v<<2)>>2]|0)|0;if(((d[h+((u|0)/8|0)|0]|0)&128>>>((u&7)>>>0)|0)!=0){u=r+(w+v)|0;a[u]=(d[u]|0|g)&255}v=v+1|0;}while((v|0)<16);q=q+1|0;}while((q|0)<16);j=j+1|0;}while((j|0)<4);k=k+1|0;}while((k|0)<(l|0))}gGz(h|0,0,2097152);if((R6(h,8,2)|0)!=0){p=1;i=b;return p|0}if((R6((c[3529524]|0)+1|0,9,2)|0)!=0){p=1;i=b;return p|0}if((R6((c[3529524]|0)+1048576|0,10,2)|0)!=0){p=1;i=b;return p|0}if((R6((c[3529524]|0)+1048577|0,11,2)|0)!=0){p=1;i=b;return p|0}if((R6((c[3529524]|0)+2097152|0,12,2)|0)!=0){p=1;i=b;return p|0}if((R6((c[3529524]|0)+2097153|0,13,2)|0)!=0){p=1;i=b;return p|0}if((R6((c[3529524]|0)+3145728|0,14,2)|0)!=0){p=1;i=b;return p|0}if((R6((c[3529524]|0)+3145729|0,15,2)|0)!=0){p=1;i=b;return p|0}h=c[2439650]|0;l=c[3529524]|0;k=c[3529576]|0;if((h|0)>0){r=0;do{j=r<<8;gGz(k+j|0,0,256);n=r<<9;m=0;do{q=1<<3-m;g=(c[808192+(m<<2)>>2]|0)+n|0;t=0;do{v=g+(c[608544+(t<<2)>>2]|0)|0;w=(t<<4)+j|0;s=0;do{u=v+(c[613816+(s<<2)>>2]|0)|0;if(((d[l+((u|0)/8|0)|0]|0)&128>>>((u&7)>>>0)|0)!=0){u=k+(w+s)|0;a[u]=(d[u]|0|q)&255}s=s+1|0;}while((s|0)<16);t=t+1|0;}while((t|0)<16);m=m+1|0;}while((m|0)<4);r=r+1|0;}while((r|0)<(h|0))}h=c[3541206]|0;if((c[3542200]|0)==0){p=1;i=b;return p|0}r=e+108|0;c[r>>2]=0;k=e+100|0;c[k>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,16)|0;do{if((c[r>>2]|0)!=0){e=c[k>>2]|0;c[f>>2]=9534384;l=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[l&16383](f,16,0)|0;if((e|0)<1){p=1;i=b;return p|0}if((gzL(h,0,16)|0)==0){break}else{p=1}i=b;return p|0}}while(0);h=c[3529524]|0;f=0;while(1){if((f|0)>=1024){break}y=9638528+(f<<2)|0;if((c[y>>2]|0)==(h|0)){o=36748;break}else{f=f+1|0}}if((o|0)==36748){gGr(h);c[y>>2]=0}c[3529524]=0;p=0;i=b;return p|0}function d_T(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=c[2112926]|0;gGz(d|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);f=c[3530024]|0;g=0;h=c[2439616]|0;i=f;while(1){j=b[h>>1]|0;c[i>>2]=((j&65535)>>>10<<3&248)>>>3|((j&255)<<3&255)<<8|(((j&65535)>>>7&4|(j&65535)>>>5<<3&255)&255)<<3&2016;j=g+1|0;if((j|0)<1024){g=j;h=h+2|0;i=i+4|0}else{break}}i=c[3530986]|0;d_O(e[i+6>>1]|0,e[i+8>>1]|0);if((b[i+12>>1]&128)==0){d_Q(e[i+2>>1]|0,e[i+4>>1]|0);d_G(0,0);R8(f);return}h=c[2387072]|0;g=(c[3527370]|0)-1|0;j=i+2|0;k=c[3528986]|0;l=i+4|0;i=a[7388296]|0?496:0;m=c[2406522]|0;n=0;o=0;while(1){p=n<<3;q=o;r=0;while(1){s=e[h+(q<<1)>>1]|0;t=s>>>12;u=(s&4095|(e[7054508]|0))&g;s=(r<<3)-((e[j>>1]|0)+k&511)|0;v=p-(i+(e[l>>1]|0)&511)|0;w=(s|0)<-8?s+512|0:s;s=(v|0)<-8?v+512|0:v;v=s-8|0;do{if((w-1|0)>>>0<311){if((s-9|0)>>>0>=231){x=36783;break}Sq(d,u,w,v,t,4,0,256,m)}else{x=36783}}while(0);if((x|0)==36783){x=0;Sr(d,u,w,v,t,4,0,256,m)}s=r+1|0;if((s|0)>=64){break}q=q+1|0;r=s}r=n+1|0;if((r|0)<64){n=r;o=o+64|0}else{break}}d_G(0,0);R8(f);return}function d_U(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;b=i;i=i+120|0;e=b|0;f=b+112|0;g=0;while(1){if((g|0)>=1024){h=0;break}j=9638528+(g<<2)|0;if((c[j>>2]|0)==0){k=36794;break}else{g=g+1|0}}do{if((k|0)==36794){g=gGq(1048576)|0;c[j>>2]=g;if((g|0)==0){h=0;break}gGz(g|0,0,1048576);h=g}}while(0);c[3529524]=h;if((R6((c[2388030]|0)+1|0,0,2)|0)!=0){l=1;i=b;return l|0}if((R6(c[2388030]|0,1,2)|0)!=0){l=1;i=b;return l|0}if((R6(c[3529524]|0,2,2)|0)!=0){l=1;i=b;return l|0}if((R6((c[3529524]|0)+1|0,3,2)|0)!=0){l=1;i=b;return l|0}if((R6((c[3529524]|0)+524288|0,4,2)|0)!=0){l=1;i=b;return l|0}if((R6((c[3529524]|0)+524289|0,5,2)|0)!=0){l=1;i=b;return l|0}h=c[3529524]|0;j=c[3527366]|0;g=j<<7;do{if((g|0)>0){m=0;do{if((m&32|0)==0){n=h+m|0;o=a[n]|0;p=h+(m+32)|0;a[n]=a[p]|0;a[p]=o}m=m+1|0;}while((m|0)<(g|0));m=(g|0)/2|0;if((g|0)>1){q=0}else{break}do{o=h+q|0;p=a[o]|0;n=h+(q+m)|0;a[o]=a[n]|0;a[n]=p;q=q+1|0;}while((q|0)<(m|0))}}while(0);q=c[3527370]|0;g=c[2406522]|0;if((q|0)>0){m=0;do{p=m<<6;gGz(g+p|0,0,64);n=m<<7;o=0;do{r=1<<3-o;s=(c[961456+(o<<2)>>2]|0)+n|0;t=0;do{u=s+(c[6669224+(t<<2)>>2]|0)|0;v=(t<<3)+p|0;w=0;do{x=u+(c[614800+(w<<2)>>2]|0)|0;if(((d[h+((x|0)/8|0)|0]|0)&128>>>((x&7)>>>0)|0)!=0){x=g+(v+w)|0;a[x]=(d[x]|0|r)&255}w=w+1|0;}while((w|0)<8);t=t+1|0;}while((t|0)<8);o=o+1|0;}while((o|0)<4);m=m+1|0;}while((m|0)<(q|0))}q=c[2405814]|0;if((j|0)>0){m=0;do{g=m<<8;gGz(q+g|0,0,256);o=m<<9;p=0;do{n=1<<3-p;t=(c[961456+(p<<2)>>2]|0)+o|0;r=0;do{s=t+(c[608544+(r<<2)>>2]|0)|0;w=(r<<4)+g|0;v=0;do{u=s+(c[613816+(v<<2)>>2]|0)|0;if(((d[h+((u|0)/8|0)|0]|0)&128>>>((u&7)>>>0)|0)!=0){u=q+(w+v)|0;a[u]=(d[u]|0|n)&255}v=v+1|0;}while((v|0)<16);r=r+1|0;}while((r|0)<16);p=p+1|0;}while((p|0)<4);m=m+1|0;}while((m|0)<(j|0))}gGz(h|0,0,1048576);if((R6(h,6,2)|0)!=0){l=1;i=b;return l|0}if((R6((c[3529524]|0)+1|0,7,2)|0)!=0){l=1;i=b;return l|0}if((R6((c[3529524]|0)+524288|0,8,2)|0)!=0){l=1;i=b;return l|0}if((R6((c[3529524]|0)+524289|0,9,2)|0)!=0){l=1;i=b;return l|0}h=c[2439650]|0;j=c[3529524]|0;m=c[3529576]|0;if((h|0)>0){q=0;do{p=q<<8;gGz(m+p|0,0,256);g=q<<9;o=0;do{r=1<<3-o;n=(c[961456+(o<<2)>>2]|0)+g|0;t=0;do{v=n+(c[608544+(t<<2)>>2]|0)|0;w=(t<<4)+p|0;s=0;do{u=v+(c[613816+(s<<2)>>2]|0)|0;if(((d[j+((u|0)/8|0)|0]|0)&128>>>((u&7)>>>0)|0)!=0){u=m+(w+s)|0;a[u]=(d[u]|0|r)&255}s=s+1|0;}while((s|0)<16);t=t+1|0;}while((t|0)<16);o=o+1|0;}while((o|0)<4);q=q+1|0;}while((q|0)<(h|0))}h=c[3541206]|0;if((c[3542200]|0)==0){l=1;i=b;return l|0}q=e+108|0;c[q>>2]=0;m=e+100|0;c[m>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,10)|0;do{if((c[q>>2]|0)!=0){e=c[m>>2]|0;c[f>>2]=9534384;j=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[j&16383](f,10,0)|0;if((e|0)<1){l=1;i=b;return l|0}if((gzL(h,0,10)|0)==0){break}else{l=1}i=b;return l|0}}while(0);h=c[3529524]|0;f=0;while(1){if((f|0)>=1024){break}y=9638528+(f<<2)|0;if((c[y>>2]|0)==(h|0)){k=36849;break}else{f=f+1|0}}if((k|0)==36849){gGr(h);c[y>>2]=0}c[3529524]=0;l=0;i=b;return l|0}function d_V(){var a=0,b=0,d=0,e=0,f=0,g=0;fxU(0,425984);if((c[2394]|0)==0){a=c[2112932]|0}else{c[2394]=0;b=c[3532596]|0;c[2112932]=b;d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];a=b}b=c[2388030]|0;d=a|0;e=0;while(1){f=b+e|0;c[d>>2]=f;c[d+131072>>2]=f;f=e+1024|0;if(f>>>0>1048575){break}else{d=d+4|0;e=f}}e=c[2439616]|0;c[a+5120>>2]=e;c[a+70656>>2]=e;c[a+136192>>2]=e;d=e+1024|0;c[a+5124>>2]=d;c[a+70660>>2]=d;c[a+136196>>2]=d;d=e+2048|0;c[a+5128>>2]=d;c[a+70664>>2]=d;c[a+136200>>2]=d;d=e+3072|0;c[a+5132>>2]=d;c[a+70668>>2]=d;c[a+136204>>2]=d;d=c[2443416]|0;c[a+5632>>2]=d;c[a+71168>>2]=d;c[a+136704>>2]=d;e=d+1024|0;c[a+5636>>2]=e;c[a+71172>>2]=e;c[a+136708>>2]=e;e=c[2387072]|0;c[a+12800>>2]=e;c[a+78336>>2]=e;c[a+143872>>2]=e;d=e+1024|0;c[a+12804>>2]=d;c[a+78340>>2]=d;c[a+143876>>2]=d;d=e+2048|0;c[a+12808>>2]=d;c[a+78344>>2]=d;c[a+143880>>2]=d;d=e+3072|0;c[a+12812>>2]=d;c[a+78348>>2]=d;c[a+143884>>2]=d;d=e+4096|0;c[a+12816>>2]=d;c[a+78352>>2]=d;c[a+143888>>2]=d;d=e+5120|0;c[a+12820>>2]=d;c[a+78356>>2]=d;c[a+143892>>2]=d;d=e+6144|0;c[a+12824>>2]=d;c[a+78360>>2]=d;c[a+143896>>2]=d;d=e+7168|0;c[a+12828>>2]=d;c[a+78364>>2]=d;c[a+143900>>2]=d;d=c[2387062]|0;c[a+12832>>2]=d;c[a+78368>>2]=d;c[a+143904>>2]=d;e=d+1024|0;c[a+12836>>2]=e;c[a+78372>>2]=e;c[a+143908>>2]=e;e=d+2048|0;c[a+12840>>2]=e;c[a+78376>>2]=e;c[a+143912>>2]=e;e=d+3072|0;c[a+12844>>2]=e;c[a+78380>>2]=e;c[a+143916>>2]=e;e=d+4096|0;c[a+12848>>2]=e;c[a+78384>>2]=e;c[a+143920>>2]=e;e=d+5120|0;c[a+12852>>2]=e;c[a+78388>>2]=e;c[a+143924>>2]=e;e=d+6144|0;c[a+12856>>2]=e;c[a+78392>>2]=e;c[a+143928>>2]=e;e=d+7168|0;c[a+12860>>2]=e;c[a+78396>>2]=e;c[a+143932>>2]=e;e=c[2388050]|0;d=a+65280|0;b=16711680;while(1){f=e+(b-16711680)|0;c[d>>2]=f;c[d+65536>>2]=f;c[d+131072>>2]=f;f=b+1024|0;if(f>>>0>16777215){break}else{d=d+4|0;b=f}}c[a+196688>>2]=1672;c[a+196728>>2]=362;c[a+196608>>2]=278;c[a+196648>>2]=2712;a=c[3532592]|0;if((a|0)==0){g=c[2113054]|0;c[2113060]=g;c[2394]=-1;return}gGC(a|0,9104152,280)|0;g=c[2113054]|0;c[2113060]=g;c[2394]=-1;return}function d_W(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;d=c[2112926]|0;gGz(d|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);f=c[3530024]|0;g=0;h=c[2439616]|0;i=f;while(1){j=b[h>>1]|0;k=(j&65535)>>>8;l=(j&65535)>>>4;m=j&255;c[i>>2]=((l<<4&255|l&12)&255)<<3&2016|((m<<4|m&8)&255)>>>3|((k<<4&255|k&8)&255)<<8&63488;k=g+1|0;if((k|0)<2048){g=k;h=h+2|0;i=i+4|0}else{break}}i=c[2387062]|0;h=(c[3527366]|0)+65535|0;g=c[3530986]|0;k=g+6|0;m=c[3528984]|0;l=g+8|0;j=a[7388288]|0?2:0;n=c[2405814]|0;o=0;do{p=o<<5;q=o<<4;r=0;do{s=(r&31|p|r<<5&3072)<<1;t=b[i+((s|1)<<1)>>1]&31;u=h&(e[i+(s<<1)>>1]|0);s=(r<<4)-((e[k>>1]|0)+m&1023)|0;v=q-(j+(e[l>>1]|0)&511)|0;w=(s|0)<-16?s+1024|0:s;s=(v|0)<-16?v+512|0:v;v=s-8|0;do{if((w-1|0)>>>0<303){if((s-9|0)>>>0>=223){x=36887;break}Sy(d,u,w,v,t,4,1024,n)}else{x=36887}}while(0);if((x|0)==36887){x=0;Sz(d,u,w,v,t,4,1024,n)}r=r+1|0;}while((r|0)<64);o=o+1|0;}while((o|0)<32);o=c[2387072]|0;if((b[g+12>>1]&128)==0){l=g+2|0;j=c[3528986]|0;m=g+4|0;k=a[7388296]|0?496:0;i=0;do{r=i<<5;q=i<<4;p=0;do{s=(p&31|r|p<<5&3072)<<1;y=b[o+((s|1)<<1)>>1]&31;z=h&(e[o+(s<<1)>>1]|0);s=(p<<4)-((e[l>>1]|0)+j&1023)|0;A=q-(k+(e[m>>1]|0)&511)|0;B=(s|0)<-16?s+1024|0:s;s=(A|0)<-16?A+512|0:A;A=s-8|0;do{if((B-1|0)>>>0<303){if((s-9|0)>>>0>=223){x=36905;break}SG(d,z,B,A,y,4,15,512,n)}else{x=36905}}while(0);if((x|0)==36905){x=0;SH(d,z,B,A,y,4,15,512,n)}p=p+1|0;}while((p|0)<64);i=i+1|0;}while((i|0)<32);d_G(15,0);R8(f);return}i=(c[3527370]|0)+8191|0;n=g+2|0;x=c[3528986]|0;m=g+4|0;g=a[7388296]|0?240:0;k=c[2406522]|0;j=0;l=0;while(1){h=j<<3;p=l;q=0;while(1){r=p<<1;s=b[o+(r<<1)>>1]&8191;L48663:do{if((s|0)!=0){t=b[o+((r|1)<<1)>>1]&31;v=i&s;w=(q<<3)-((e[n>>1]|0)+x&511)|0;u=h-(g+(e[m>>1]|0)&255)|0;C=(w|0)<-8?w+512|0:w;w=(u|0)<-8?u+256|0:u;u=w-8|0;do{if((C-1|0)>>>0<311){if((w-9|0)>>>0>=231){break}Sq(d,v,C,u,t,4,15,1024,k);break L48663}}while(0);Sr(d,v,C,u,t,4,15,1024,k)}}while(0);s=q+1|0;if((s|0)<64){p=p+1|0;q=s}else{break}}q=j+1|0;if((q|0)<32){j=q;l=l+64|0}else{break}}d_G(15,0);R8(f);return}function d_X(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;b=i;i=i+360|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;l=0;while(1){if((l|0)>=1024){m=0;break}n=9638528+(l<<2)|0;if((c[n>>2]|0)==0){o=36914;break}else{l=l+1|0}}do{if((o|0)==36914){l=gGq(2097152)|0;c[n>>2]=l;if((l|0)==0){m=0;break}gGz(l|0,0,2097152);m=l}}while(0);c[3529524]=m;if((R6((c[2388030]|0)+1|0,0,2)|0)!=0){p=1;i=b;return p|0}if((R6(c[2388030]|0,1,2)|0)!=0){p=1;i=b;return p|0}m=c[2385836]|0;if((c[3542200]|0)==0){p=1;i=b;return p|0}n=j+108|0;c[n>>2]=0;l=j+100|0;c[l>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,2)|0;do{if((c[n>>2]|0)!=0){j=c[l>>2]|0;c[k>>2]=9534384;q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[q&16383](k,2,0)|0;if((j|0)<1){p=1;i=b;return p|0}if((gzL(m,0,2)|0)==0){break}else{p=1}i=b;return p|0}}while(0);m=c[3527338]|0;if((c[3542200]|0)==0){p=1;i=b;return p|0}k=g+108|0;c[k>>2]=0;l=g+100|0;c[l>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,3)|0;do{if((c[k>>2]|0)!=0){g=c[l>>2]|0;c[h>>2]=9534384;n=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[n&16383](h,3,0)|0;if((g|0)<1){p=1;i=b;return p|0}if((gzL(m,0,3)|0)==0){break}else{p=1}i=b;return p|0}}while(0);m=0;h=c[3527338]|0;while(1){l=a[h]|0;k=h+1|0;a[h]=a[k]|0;a[k]=l;l=m+1|0;if((l|0)<256){m=l;h=h+2|0}else{break}}if((R6((c[3529524]|0)+1|0,4,2)|0)!=0){p=1;i=b;return p|0}if((R6(c[3529524]|0,5,2)|0)==0){r=0}else{p=1;i=b;return p|0}while(1){if((r|0)>=1024){s=0;break}t=9638528+(r<<2)|0;if((c[t>>2]|0)==0){o=36932;break}else{r=r+1|0}}do{if((o|0)==36932){r=gGq(1048576)|0;c[t>>2]=r;if((r|0)==0){s=0;break}gGz(r|0,0,1048576);s=r}}while(0);t=c[3529524]|0;gGC(s|0,t|0,1048576)|0;gGz(t|0,0,2097152);gGC(t|0,s|0,262144)|0;r=t+1048576|0;h=s+262144|0;gGC(r|0,h|0,262144)|0;h=t+262144|0;r=s+524288|0;gGC(h|0,r|0,262144)|0;r=t+1310720|0;h=s+786432|0;gGC(r|0,h|0,262144)|0;h=0;while(1){if((h|0)>=1024){u=t;break}v=9638528+(h<<2)|0;if((c[v>>2]|0)==(s|0)){o=36937;break}else{h=h+1|0}}if((o|0)==36937){gGr(s);c[v>>2]=0;u=c[3529524]|0}v=c[3527366]|0;s=v<<7;do{if((s|0)>0){h=0;do{if((h&32|0)==0){t=u+h|0;r=a[t]|0;m=u+(h+32)|0;a[t]=a[m]|0;a[m]=r}h=h+1|0;}while((h|0)<(s|0));h=(s|0)/2|0;if((s|0)>1){w=0}else{break}do{r=u+w|0;m=a[r]|0;t=u+(w+h)|0;a[r]=a[t]|0;a[t]=m;w=w+1|0;}while((w|0)<(h|0))}}while(0);w=c[3527370]|0;s=c[2406522]|0;if((w|0)>0){h=0;do{m=h<<6;gGz(s+m|0,0,64);t=h<<7;r=0;do{l=1<<3-r;k=(c[687296+(r<<2)>>2]|0)+t|0;g=0;do{n=k+(c[6669224+(g<<2)>>2]|0)|0;j=(g<<3)+m|0;q=0;do{x=n+(c[614800+(q<<2)>>2]|0)|0;if(((d[u+((x|0)/8|0)|0]|0)&128>>>((x&7)>>>0)|0)!=0){x=s+(j+q)|0;a[x]=(d[x]|0|l)&255}q=q+1|0;}while((q|0)<8);g=g+1|0;}while((g|0)<8);r=r+1|0;}while((r|0)<4);h=h+1|0;}while((h|0)<(w|0))}w=c[2405814]|0;if((v|0)>0){h=0;do{s=h<<8;gGz(w+s|0,0,256);r=h<<9;m=0;do{t=1<<3-m;g=(c[687296+(m<<2)>>2]|0)+r|0;l=0;do{k=g+(c[608544+(l<<2)>>2]|0)|0;q=(l<<4)+s|0;j=0;do{n=k+(c[613816+(j<<2)>>2]|0)|0;if(((d[u+((n|0)/8|0)|0]|0)&128>>>((n&7)>>>0)|0)!=0){n=w+(q+j)|0;a[n]=(d[n]|0|t)&255}j=j+1|0;}while((j|0)<16);l=l+1|0;}while((l|0)<16);m=m+1|0;}while((m|0)<4);h=h+1|0;}while((h|0)<(v|0))}gGz(u|0,0,2097152);if((R6(u,6,2)|0)!=0){p=1;i=b;return p|0}if((R6((c[3529524]|0)+1|0,7,2)|0)!=0){p=1;i=b;return p|0}if((R6((c[3529524]|0)+1048576|0,8,2)|0)!=0){p=1;i=b;return p|0}if((R6((c[3529524]|0)+1048577|0,9,2)|0)!=0){p=1;i=b;return p|0}u=c[2439650]|0;v=c[3529524]|0;h=c[3529576]|0;if((u|0)>0){w=0;do{m=w<<8;gGz(h+m|0,0,256);s=w<<9;r=0;do{l=1<<3-r;t=(c[687296+(r<<2)>>2]|0)+s|0;g=0;do{j=t+(c[608544+(g<<2)>>2]|0)|0;q=(g<<4)+m|0;k=0;do{n=j+(c[613816+(k<<2)>>2]|0)|0;if(((d[v+((n|0)/8|0)|0]|0)&128>>>((n&7)>>>0)|0)!=0){n=h+(q+k)|0;a[n]=(d[n]|0|l)&255}k=k+1|0;}while((k|0)<16);g=g+1|0;}while((g|0)<16);r=r+1|0;}while((r|0)<4);w=w+1|0;}while((w|0)<(u|0))}u=c[3541206]|0;if((c[3542200]|0)==0){p=1;i=b;return p|0}w=e+108|0;c[w>>2]=0;h=e+100|0;c[h>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,10)|0;do{if((c[w>>2]|0)!=0){e=c[h>>2]|0;c[f>>2]=9534384;v=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[v&16383](f,10,0)|0;if((e|0)<1){p=1;i=b;return p|0}if((gzL(u,0,10)|0)==0){break}else{p=1}i=b;return p|0}}while(0);u=c[3529524]|0;f=0;while(1){if((f|0)>=1024){break}y=9638528+(f<<2)|0;if((c[y>>2]|0)==(u|0)){o=36985;break}else{f=f+1|0}}if((o|0)==36985){gGr(u);c[y>>2]=0}c[3529524]=0;p=0;i=b;return p|0}function d_Y(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[2112926]|0;gGz(a|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);a=c[3530024]|0;d=0;f=c[2439616]|0;g=a;while(1){h=b[f>>1]|0;i=h&255;j=(h&65535)>>>4;k=(h&65535)>>>8;c[g>>2]=((k<<4&255|k&8)&255)>>>3|((i<<4|i&8)&255)<<8&63488|((j<<4&255|j&12)&255)<<3&2016;j=d+1|0;if((j|0)<1024){d=j;f=f+2|0;g=g+4|0}else{break}}g=c[3530986]|0;d_O(e[g+6>>1]|0,e[g+8>>1]|0);if((b[g+12>>1]&128)==0){d_Q(e[g+2>>1]|0,e[g+4>>1]|0);d_G(0,0);R8(a);return}else{d_P();d_G(0,0);R8(a);return}}function d_Z(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;b=i;i=i+360|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;l=0;while(1){if((l|0)>=1024){m=0;break}n=9638528+(l<<2)|0;if((c[n>>2]|0)==0){o=37017;break}else{l=l+1|0}}do{if((o|0)==37017){l=gGq(1048576)|0;c[n>>2]=l;if((l|0)==0){m=0;break}gGz(l|0,0,1048576);m=l}}while(0);c[3529524]=m;if((R6((c[2388030]|0)+1|0,0,2)|0)!=0){p=1;i=b;return p|0}if((R6(c[2388030]|0,1,2)|0)!=0){p=1;i=b;return p|0}m=c[2385836]|0;if((c[3542200]|0)==0){p=1;i=b;return p|0}n=j+108|0;c[n>>2]=0;l=j+100|0;c[l>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,2)|0;do{if((c[n>>2]|0)!=0){j=c[l>>2]|0;c[k>>2]=9534384;q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[q&16383](k,2,0)|0;if((j|0)<1){p=1;i=b;return p|0}if((gzL(m,0,2)|0)==0){break}else{p=1}i=b;return p|0}}while(0);m=c[3527338]|0;if((c[3542200]|0)==0){p=1;i=b;return p|0}k=g+108|0;c[k>>2]=0;l=g+100|0;c[l>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,3)|0;do{if((c[k>>2]|0)!=0){g=c[l>>2]|0;c[h>>2]=9534384;n=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[n&16383](h,3,0)|0;if((g|0)<1){p=1;i=b;return p|0}if((gzL(m,0,3)|0)==0){break}else{p=1}i=b;return p|0}}while(0);m=0;h=c[3527338]|0;while(1){l=a[h]|0;k=h+1|0;a[h]=a[k]|0;a[k]=l;l=m+1|0;if((l|0)<256){m=l;h=h+2|0}else{break}}if((R6((c[3529524]|0)+1|0,4,2)|0)!=0){p=1;i=b;return p|0}if((R6(c[3529524]|0,5,2)|0)!=0){p=1;i=b;return p|0}h=c[3529524]|0;m=c[3527366]|0;l=m<<7;do{if((l|0)>0){k=0;do{if((k&32|0)==0){g=h+k|0;n=a[g]|0;j=h+(k+32)|0;a[g]=a[j]|0;a[j]=n}k=k+1|0;}while((k|0)<(l|0));k=(l|0)/2|0;if((l|0)>1){r=0}else{break}do{n=h+r|0;j=a[n]|0;g=h+(r+k)|0;a[n]=a[g]|0;a[g]=j;r=r+1|0;}while((r|0)<(k|0))}}while(0);r=c[3527370]|0;l=c[2406522]|0;if((r|0)>0){k=0;do{j=k<<6;gGz(l+j|0,0,64);g=k<<7;n=0;do{q=1<<3-n;s=(c[683256+(n<<2)>>2]|0)+g|0;t=0;do{u=s+(c[6669224+(t<<2)>>2]|0)|0;v=(t<<3)+j|0;w=0;do{x=u+(c[614800+(w<<2)>>2]|0)|0;if(((d[h+((x|0)/8|0)|0]|0)&128>>>((x&7)>>>0)|0)!=0){x=l+(v+w)|0;a[x]=(d[x]|0|q)&255}w=w+1|0;}while((w|0)<8);t=t+1|0;}while((t|0)<8);n=n+1|0;}while((n|0)<4);k=k+1|0;}while((k|0)<(r|0))}r=c[2405814]|0;if((m|0)>0){k=0;do{l=k<<8;gGz(r+l|0,0,256);n=k<<9;j=0;do{g=1<<3-j;t=(c[683256+(j<<2)>>2]|0)+n|0;q=0;do{s=t+(c[608544+(q<<2)>>2]|0)|0;w=(q<<4)+l|0;v=0;do{u=s+(c[613816+(v<<2)>>2]|0)|0;if(((d[h+((u|0)/8|0)|0]|0)&128>>>((u&7)>>>0)|0)!=0){u=r+(w+v)|0;a[u]=(d[u]|0|g)&255}v=v+1|0;}while((v|0)<16);q=q+1|0;}while((q|0)<16);j=j+1|0;}while((j|0)<4);k=k+1|0;}while((k|0)<(m|0))}gGz(h|0,0,1048576);if((R6(h,6,2)|0)!=0){p=1;i=b;return p|0}if((R6((c[3529524]|0)+1|0,7,2)|0)!=0){p=1;i=b;return p|0}if((R6((c[3529524]|0)+262144|0,8,2)|0)!=0){p=1;i=b;return p|0}if((R6((c[3529524]|0)+262145|0,9,2)|0)!=0){p=1;i=b;return p|0}h=c[2439650]|0;m=c[3529524]|0;k=c[3529576]|0;if((h|0)>0){r=0;do{j=r<<8;gGz(k+j|0,0,256);l=r<<9;n=0;do{q=1<<3-n;g=(c[683256+(n<<2)>>2]|0)+l|0;t=0;do{v=g+(c[608544+(t<<2)>>2]|0)|0;w=(t<<4)+j|0;s=0;do{u=v+(c[613816+(s<<2)>>2]|0)|0;if(((d[m+((u|0)/8|0)|0]|0)&128>>>((u&7)>>>0)|0)!=0){u=k+(w+s)|0;a[u]=(d[u]|0|q)&255}s=s+1|0;}while((s|0)<16);t=t+1|0;}while((t|0)<16);n=n+1|0;}while((n|0)<4);r=r+1|0;}while((r|0)<(h|0))}h=c[3541206]|0;if((c[3542200]|0)==0){p=1;i=b;return p|0}r=e+108|0;c[r>>2]=0;k=e+100|0;c[k>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,10)|0;do{if((c[r>>2]|0)!=0){e=c[k>>2]|0;c[f>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](f,10,0)|0;if((e|0)<1){p=1;i=b;return p|0}if((gzL(h,0,10)|0)==0){break}else{p=1}i=b;return p|0}}while(0);h=c[3529524]|0;f=0;while(1){if((f|0)>=1024){break}y=9638528+(f<<2)|0;if((c[y>>2]|0)==(h|0)){o=37080;break}else{f=f+1|0}}if((o|0)==37080){gGr(h);c[y>>2]=0}c[3529524]=0;p=0;i=b;return p|0}function d__(){var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;e=i;i=i+600|0;f=e|0;g=e+112|0;h=e+120|0;j=e+232|0;k=e+240|0;l=e+352|0;m=e+360|0;n=e+472|0;o=e+480|0;p=e+592|0;q=0;while(1){if((q|0)>=1024){r=0;break}s=9638528+(q<<2)|0;if((c[s>>2]|0)==0){t=37104;break}else{q=q+1|0}}do{if((t|0)==37104){q=gGq(1048576)|0;c[s>>2]=q;if((q|0)==0){r=0;break}gGz(q|0,0,1048576);r=q}}while(0);c[3529524]=r;if((R6((c[2388030]|0)+1|0,0,2)|0)!=0){u=1;i=e;return u|0}if((R6(c[2388030]|0,1,2)|0)!=0){u=1;i=e;return u|0}r=c[2388030]|0;s=r;q=0;while(1){if((q|0)>=1024){v=0;break}w=9638528+(q<<2)|0;if((c[w>>2]|0)==0){t=37111;break}else{q=q+1|0}}do{if((t|0)==37111){q=gGq(524288)|0;c[w>>2]=q;if((q|0)==0){v=0;break}gGz(q|0,0,524288);v=q}}while(0);w=v;gGC(v|0,r|0,524288)|0;r=0;while(1){q=(r<<1&2|4)^r;b[s+(r<<1)>>1]=b[w+(((r&3|0)==0?q^8:q)<<1)>>1]|0;q=r+1|0;if((q|0)<262144){r=q}else{x=0;break}}while(1){if((x|0)>=1024){break}y=9638528+(x<<2)|0;if((c[y>>2]|0)==(v|0)){t=37117;break}else{x=x+1|0}}if((t|0)==37117){gGr(v);c[y>>2]=0}y=c[2385836]|0;if((c[3542200]|0)==0){u=1;i=e;return u|0}v=o+108|0;c[v>>2]=0;x=o+100|0;c[x>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](o,2)|0;do{if((c[v>>2]|0)!=0){o=c[x>>2]|0;c[p>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](p,2,0)|0;if((o|0)<1){u=1;i=e;return u|0}if((gzL(y,0,2)|0)==0){break}else{u=1}i=e;return u|0}}while(0);y=c[3529524]|0;if((c[3542200]|0)==0){u=1;i=e;return u|0}p=m+108|0;c[p>>2]=0;x=m+100|0;c[x>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,3)|0;do{if((c[p>>2]|0)!=0){m=c[x>>2]|0;c[n>>2]=9534384;v=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[v&16383](n,3,0)|0;if((m|0)<1){u=1;i=e;return u|0}if((gzL(y,0,3)|0)==0){break}else{u=1}i=e;return u|0}}while(0);y=(c[3529524]|0)+524288|0;if((c[3542200]|0)==0){u=1;i=e;return u|0}n=k+108|0;c[n>>2]=0;x=k+100|0;c[x>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,4)|0;do{if((c[n>>2]|0)==0){z=0}else{k=c[x>>2]|0;c[l>>2]=9534384;p=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[p&16383](l,4,0)|0;if((k|0)<1){u=1;i=e;return u|0}if((gzL(y,0,4)|0)==0){z=0;break}else{u=1}i=e;return u|0}}while(0);while(1){if((z|0)>=1024){A=0;break}B=9638528+(z<<2)|0;if((c[B>>2]|0)==0){t=37132;break}else{z=z+1|0}}do{if((t|0)==37132){z=gGq(1048576)|0;c[B>>2]=z;if((z|0)==0){A=0;break}gGz(z|0,0,1048576);A=z}}while(0);B=c[3529524]|0;gGC(A|0,B|0,1048576)|0;gGz(B|0,0,1048576);gGC(B|0,A|0,131072)|0;z=B+262144|0;y=A+131072|0;gGC(z|0,y|0,131072)|0;y=B+131072|0;z=A+262144|0;gGC(y|0,z|0,131072)|0;z=B+393216|0;y=A+393216|0;gGC(z|0,y|0,131072)|0;y=B+524288|0;z=A+524288|0;gGC(y|0,z|0,131072)|0;z=B+786432|0;y=A+655360|0;gGC(z|0,y|0,131072)|0;y=B+655360|0;z=A+786432|0;gGC(y|0,z|0,131072)|0;z=B+917504|0;y=A+917504|0;gGC(z|0,y|0,131072)|0;y=0;while(1){if((y|0)>=1024){C=B;break}D=9638528+(y<<2)|0;if((c[D>>2]|0)==(A|0)){t=37137;break}else{y=y+1|0}}if((t|0)==37137){gGr(A);c[D>>2]=0;C=c[3529524]|0}D=C;A=0;while(1){if((A|0)>=1024){E=0;break}F=9638528+(A<<2)|0;if((c[F>>2]|0)==0){t=37141;break}else{A=A+1|0}}do{if((t|0)==37141){A=gGq(1048576)|0;c[F>>2]=A;if((A|0)==0){E=0;break}gGz(A|0,0,1048576);E=A}}while(0);F=E;gGC(E|0,C|0,1048576)|0;C=0;while(1){b[D+(C<<1)>>1]=b[F+(((C<<2&4|2)^C)<<1)>>1]|0;A=C+1|0;if((A|0)<524288){C=A}else{G=0;break}}while(1){if((G|0)>=1024){break}H=9638528+(G<<2)|0;if((c[H>>2]|0)==(E|0)){t=37147;break}else{G=G+1|0}}if((t|0)==37147){gGr(E);c[H>>2]=0}H=c[3527366]|0;E=c[3529524]|0;G=c[2405814]|0;if((H|0)>0){C=0;do{F=C<<8;gGz(G+F|0,0,256);D=0;do{A=1<<3-D;y=(c[725192+(D<<2)>>2]|0)+F|0;B=0;do{z=y+(c[1666944+(B<<2)>>2]|0)|0;l=(B<<4)+F|0;x=0;do{n=z+(c[597864+(x<<2)>>2]|0)|0;if(((d[E+((n|0)/8|0)|0]|0)&128>>>((n&7)>>>0)|0)!=0){n=G+(l+x)|0;a[n]=(d[n]|0|A)&255}x=x+1|0;}while((x|0)<16);B=B+1|0;}while((B|0)<16);D=D+1|0;}while((D|0)<4);C=C+1|0;}while((C|0)<(H|0))}gGz(E|0,0,1048576);if((R6(E,5,2)|0)!=0){u=1;i=e;return u|0}if((R6((c[3529524]|0)+1|0,6,2)|0)!=0){u=1;i=e;return u|0}if((R6((c[3529524]|0)+524288|0,7,2)|0)!=0){u=1;i=e;return u|0}if((R6((c[3529524]|0)+524289|0,8,2)|0)!=0){u=1;i=e;return u|0}E=c[2439650]|0;H=c[3529524]|0;C=c[3529576]|0;if((E|0)>0){G=0;do{D=G<<8;gGz(C+D|0,0,256);F=G<<9;B=0;do{A=1<<3-B;y=(c[961456+(B<<2)>>2]|0)+F|0;x=0;do{l=y+(c[608544+(x<<2)>>2]|0)|0;z=(x<<4)+D|0;n=0;do{k=l+(c[613816+(n<<2)>>2]|0)|0;if(((d[H+((k|0)/8|0)|0]|0)&128>>>((k&7)>>>0)|0)!=0){k=C+(z+n)|0;a[k]=(d[k]|0|A)&255}n=n+1|0;}while((n|0)<16);x=x+1|0;}while((x|0)<16);B=B+1|0;}while((B|0)<4);G=G+1|0;}while((G|0)<(E|0))}E=c[2433470]|0;if((c[3542200]|0)==0){u=1;i=e;return u|0}G=h+108|0;c[G>>2]=0;C=h+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](h,9)|0;do{if((c[G>>2]|0)!=0){h=c[C>>2]|0;c[j>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](j,9,0)|0;if((h|0)<1){u=1;i=e;return u|0}if((gzL(E,0,9)|0)==0){break}else{u=1}i=e;return u|0}}while(0);E=(c[2433470]|0)+524288|0;if((c[3542200]|0)==0){u=1;i=e;return u|0}j=f+108|0;c[j>>2]=0;C=f+100|0;c[C>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,10)|0;do{if((c[j>>2]|0)!=0){f=c[C>>2]|0;c[g>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](g,10,0)|0;if((f|0)<1){u=1;i=e;return u|0}if((gzL(E,0,10)|0)==0){break}else{u=1}i=e;return u|0}}while(0);E=c[3541206]|0;g=c[2433470]|0;gGC(E|0,g|0,262144)|0;g=c[3529524]|0;E=0;while(1){if((E|0)>=1024){break}I=9638528+(E<<2)|0;if((c[I>>2]|0)==(g|0)){t=37183;break}else{E=E+1|0}}if((t|0)==37183){gGr(g);c[I>>2]=0}c[3529524]=0;u=0;i=e;return u|0}function d_$(){var a=0,b=0,d=0,e=0,f=0,g=0;fxU(0,425984);if((c[2394]|0)==0){a=c[2112932]|0}else{c[2394]=0;b=c[3532596]|0;c[2112932]=b;d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];a=b}b=c[2388030]|0;d=a|0;e=0;while(1){f=b+e|0;c[d>>2]=f;c[d+131072>>2]=f;f=e+1024|0;if(f>>>0>524287){break}else{d=d+4|0;e=f}}e=c[2443416]|0;c[a+28672>>2]=e;c[a+94208>>2]=e;c[a+159744>>2]=e;d=e+1024|0;c[a+28676>>2]=d;c[a+94212>>2]=d;c[a+159748>>2]=d;d=c[2387072]|0;c[a+41472>>2]=d;c[a+107008>>2]=d;c[a+172544>>2]=d;e=d+1024|0;c[a+41476>>2]=e;c[a+107012>>2]=e;c[a+172548>>2]=e;e=d+2048|0;c[a+41480>>2]=e;c[a+107016>>2]=e;c[a+172552>>2]=e;e=d+3072|0;c[a+41484>>2]=e;c[a+107020>>2]=e;c[a+172556>>2]=e;e=c[2387062]|0;c[a+41504>>2]=e;c[a+107040>>2]=e;c[a+172576>>2]=e;d=e+1024|0;c[a+41508>>2]=d;c[a+107044>>2]=d;c[a+172580>>2]=d;d=e+2048|0;c[a+41512>>2]=d;c[a+107048>>2]=d;c[a+172584>>2]=d;d=e+3072|0;c[a+41516>>2]=d;c[a+107052>>2]=d;c[a+172588>>2]=d;d=c[2439616]|0;c[a+52992>>2]=d;c[a+118528>>2]=d;c[a+184064>>2]=d;e=d+1024|0;c[a+52996>>2]=e;c[a+118532>>2]=e;c[a+184068>>2]=e;e=c[2388050]|0;d=a+61440|0;b=15728640;while(1){f=e+(b-15728640)|0;c[d>>2]=f;c[d+65536>>2]=f;c[d+131072>>2]=f;f=b+1024|0;if(f>>>0>15761407){break}else{d=d+4|0;b=f}}c[a+196688>>2]=388;c[a+196728>>2]=3e3;a=c[3532592]|0;if((a|0)==0){g=c[2113054]|0;c[2113060]=g;c[2394]=-1;return}gGC(a|0,9104152,280)|0;g=c[2113054]|0;c[2113060]=g;c[2394]=-1;return}function d_0(){var a=0,d=0,f=0,g=0,h=0;a=c[2112926]|0;gGz(a|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);a=c[3530024]|0;d=0;f=c[2439616]|0;g=a;while(1){h=b[f>>1]|0;c[g>>2]=((h&65535)>>>10<<3&248)>>>3|((h&255)<<3&255)<<8|(((h&65535)>>>7&4|(h&65535)>>>5<<3&255)&255)<<3&2016;h=d+1|0;if((h|0)<1024){d=h;f=f+2|0;g=g+4|0}else{break}}g=c[3530986]|0;d_O(-(e[g+6>>1]|0)|0,-(e[g+8>>1]|0)|0);d_Q(-(e[g+2>>1]|0)|0,-(e[g+4>>1]|0)|0);d_G(0,0);R8(a);return}function d_1(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;b=i;i=i+120|0;e=b|0;f=b+112|0;g=0;while(1){if((g|0)>=1024){h=0;break}j=9638528+(g<<2)|0;if((c[j>>2]|0)==0){k=37228;break}else{g=g+1|0}}do{if((k|0)==37228){g=gGq(1048576)|0;c[j>>2]=g;if((g|0)==0){h=0;break}gGz(g|0,0,1048576);h=g}}while(0);c[3529524]=h;if((R6((c[2388030]|0)+1|0,0,2)|0)!=0){l=1;i=b;return l|0}if((R6(c[2388030]|0,1,2)|0)!=0){l=1;i=b;return l|0}if((R6(c[3529524]|0,2,2)|0)!=0){l=1;i=b;return l|0}if((R6((c[3529524]|0)+1|0,3,2)|0)!=0){l=1;i=b;return l|0}if((R6((c[3529524]|0)+524288|0,4,2)|0)!=0){l=1;i=b;return l|0}if((R6((c[3529524]|0)+524289|0,5,2)|0)==0){m=0}else{l=1;i=b;return l|0}while(1){if((m|0)>=1024){n=0;break}o=9638528+(m<<2)|0;if((c[o>>2]|0)==0){k=37238;break}else{m=m+1|0}}do{if((k|0)==37238){m=gGq(1048576)|0;c[o>>2]=m;if((m|0)==0){n=0;break}gGz(m|0,0,1048576);n=m}}while(0);o=c[3529524]|0;gGC(n|0,o|0,1048576)|0;gGz(o|0,0,1048576);gGC(o|0,n|0,262144)|0;m=o+524288|0;h=n+262144|0;gGC(m|0,h|0,262144)|0;h=o+262144|0;m=n+524288|0;gGC(h|0,m|0,262144)|0;m=o+786432|0;h=n+786432|0;gGC(m|0,h|0,262144)|0;h=0;while(1){if((h|0)>=1024){p=o;break}q=9638528+(h<<2)|0;if((c[q>>2]|0)==(n|0)){k=37243;break}else{h=h+1|0}}if((k|0)==37243){gGr(n);c[q>>2]=0;p=c[3529524]|0}q=c[3527366]|0;n=q<<7;do{if((n|0)>0){h=0;do{if((h&32|0)==0){o=p+h|0;m=a[o]|0;j=p+(h+32)|0;a[o]=a[j]|0;a[j]=m}h=h+1|0;}while((h|0)<(n|0));h=(n|0)/2|0;if((n|0)>1){r=0}else{break}do{m=p+r|0;j=a[m]|0;o=p+(r+h)|0;a[m]=a[o]|0;a[o]=j;r=r+1|0;}while((r|0)<(h|0))}}while(0);r=c[3527370]|0;n=c[2406522]|0;if((r|0)>0){h=0;do{j=h<<6;gGz(n+j|0,0,64);o=h<<7;m=0;do{g=1<<3-m;s=(c[961456+(m<<2)>>2]|0)+o|0;t=0;do{u=s+(c[6669224+(t<<2)>>2]|0)|0;v=(t<<3)+j|0;w=0;do{x=u+(c[614800+(w<<2)>>2]|0)|0;if(((d[p+((x|0)/8|0)|0]|0)&128>>>((x&7)>>>0)|0)!=0){x=n+(v+w)|0;a[x]=(d[x]|0|g)&255}w=w+1|0;}while((w|0)<8);t=t+1|0;}while((t|0)<8);m=m+1|0;}while((m|0)<4);h=h+1|0;}while((h|0)<(r|0))}r=c[2405814]|0;if((q|0)>0){h=0;do{n=h<<8;gGz(r+n|0,0,256);m=h<<9;j=0;do{o=1<<3-j;t=(c[961456+(j<<2)>>2]|0)+m|0;g=0;do{s=t+(c[608544+(g<<2)>>2]|0)|0;w=(g<<4)+n|0;v=0;do{u=s+(c[613816+(v<<2)>>2]|0)|0;if(((d[p+((u|0)/8|0)|0]|0)&128>>>((u&7)>>>0)|0)!=0){u=r+(w+v)|0;a[u]=(d[u]|0|o)&255}v=v+1|0;}while((v|0)<16);g=g+1|0;}while((g|0)<16);j=j+1|0;}while((j|0)<4);h=h+1|0;}while((h|0)<(q|0))}gGz(p|0,0,1048576);if((R6(p,6,2)|0)!=0){l=1;i=b;return l|0}if((R6((c[3529524]|0)+1|0,7,2)|0)!=0){l=1;i=b;return l|0}if((R6((c[3529524]|0)+524288|0,8,2)|0)!=0){l=1;i=b;return l|0}if((R6((c[3529524]|0)+524289|0,9,2)|0)!=0){l=1;i=b;return l|0}p=c[2439650]|0;q=c[3529524]|0;h=c[3529576]|0;if((p|0)>0){r=0;do{j=r<<8;gGz(h+j|0,0,256);n=r<<9;m=0;do{g=1<<3-m;o=(c[961456+(m<<2)>>2]|0)+n|0;t=0;do{v=o+(c[608544+(t<<2)>>2]|0)|0;w=(t<<4)+j|0;s=0;do{u=v+(c[613816+(s<<2)>>2]|0)|0;if(((d[q+((u|0)/8|0)|0]|0)&128>>>((u&7)>>>0)|0)!=0){u=h+(w+s)|0;a[u]=(d[u]|0|g)&255}s=s+1|0;}while((s|0)<16);t=t+1|0;}while((t|0)<16);m=m+1|0;}while((m|0)<4);r=r+1|0;}while((r|0)<(p|0))}p=c[2433470]|0;if((c[3542200]|0)==0){l=1;i=b;return l|0}r=e+108|0;c[r>>2]=0;h=e+100|0;c[h>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,10)|0;do{if((c[r>>2]|0)!=0){e=c[h>>2]|0;c[f>>2]=9534384;q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[q&16383](f,10,0)|0;if((e|0)<1){l=1;i=b;return l|0}if((gzL(p,0,10)|0)==0){break}else{l=1}i=b;return l|0}}while(0);p=c[3541206]|0;f=c[2433470]|0;gGC(p|0,f|0,262144)|0;f=c[3529524]|0;p=0;while(1){if((p|0)>=1024){break}y=9638528+(p<<2)|0;if((c[y>>2]|0)==(f|0)){k=37291;break}else{p=p+1|0}}if((k|0)==37291){gGr(f);c[y>>2]=0}c[3529524]=0;l=0;i=b;return l|0}function d_2(){var a=0,b=0,d=0,e=0,f=0,g=0;fxU(0,425984);if((c[2394]|0)==0){a=c[2112932]|0}else{c[2394]=0;b=c[3532596]|0;c[2112932]=b;d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];a=b}b=c[2388030]|0;d=a|0;e=0;while(1){f=b+e|0;c[d>>2]=f;c[d+131072>>2]=f;f=e+1024|0;if(f>>>0>524287){break}else{d=d+4|0;e=f}}e=c[2388050]|0;c[a+4608>>2]=e;c[a+70144>>2]=e;c[a+135680>>2]=e;d=e+1024|0;c[a+4612>>2]=d;c[a+70148>>2]=d;c[a+135684>>2]=d;d=e+2048|0;c[a+4616>>2]=d;c[a+70152>>2]=d;c[a+135688>>2]=d;d=e+3072|0;c[a+4620>>2]=d;c[a+70156>>2]=d;c[a+135692>>2]=d;d=e+4096|0;c[a+4624>>2]=d;c[a+70160>>2]=d;c[a+135696>>2]=d;d=e+5120|0;c[a+4628>>2]=d;c[a+70164>>2]=d;c[a+135700>>2]=d;d=e+6144|0;c[a+4632>>2]=d;c[a+70168>>2]=d;c[a+135704>>2]=d;d=e+7168|0;c[a+4636>>2]=d;c[a+70172>>2]=d;c[a+135708>>2]=d;d=e+8192|0;c[a+4640>>2]=d;c[a+70176>>2]=d;c[a+135712>>2]=d;d=e+9216|0;c[a+4644>>2]=d;c[a+70180>>2]=d;c[a+135716>>2]=d;d=e+10240|0;c[a+4648>>2]=d;c[a+70184>>2]=d;c[a+135720>>2]=d;d=e+11264|0;c[a+4652>>2]=d;c[a+70188>>2]=d;c[a+135724>>2]=d;d=e+12288|0;c[a+4656>>2]=d;c[a+70192>>2]=d;c[a+135728>>2]=d;d=e+13312|0;c[a+4660>>2]=d;c[a+70196>>2]=d;c[a+135732>>2]=d;d=e+14336|0;c[a+4664>>2]=d;c[a+70200>>2]=d;c[a+135736>>2]=d;d=e+15360|0;c[a+4668>>2]=d;c[a+70204>>2]=d;c[a+135740>>2]=d;d=c[2439616]|0;c[a+5120>>2]=d;c[a+70656>>2]=d;c[a+136192>>2]=d;b=d+1024|0;c[a+5124>>2]=b;c[a+70660>>2]=b;c[a+136196>>2]=b;b=c[2443416]|0;c[a+5632>>2]=b;c[a+71168>>2]=b;c[a+136704>>2]=b;d=b+1024|0;c[a+5636>>2]=d;c[a+71172>>2]=d;c[a+136708>>2]=d;d=e+16384|0;c[a+6656>>2]=d;c[a+72192>>2]=d;c[a+137728>>2]=d;d=e+17408|0;c[a+6660>>2]=d;c[a+72196>>2]=d;c[a+137732>>2]=d;d=c[2387072]|0;c[a+12800>>2]=d;c[a+78336>>2]=d;c[a+143872>>2]=d;e=d+1024|0;c[a+12804>>2]=e;c[a+78340>>2]=e;c[a+143876>>2]=e;e=d+2048|0;c[a+12808>>2]=e;c[a+78344>>2]=e;c[a+143880>>2]=e;e=d+3072|0;c[a+12812>>2]=e;c[a+78348>>2]=e;c[a+143884>>2]=e;e=d+4096|0;c[a+12816>>2]=e;c[a+78352>>2]=e;c[a+143888>>2]=e;e=d+5120|0;c[a+12820>>2]=e;c[a+78356>>2]=e;c[a+143892>>2]=e;e=d+6144|0;c[a+12824>>2]=e;c[a+78360>>2]=e;c[a+143896>>2]=e;e=d+7168|0;c[a+12828>>2]=e;c[a+78364>>2]=e;c[a+143900>>2]=e;e=c[2387062]|0;c[a+13312>>2]=e;c[a+78848>>2]=e;c[a+144384>>2]=e;d=e+1024|0;c[a+13316>>2]=d;c[a+78852>>2]=d;c[a+144388>>2]=d;d=e+2048|0;c[a+13320>>2]=d;c[a+78856>>2]=d;c[a+144392>>2]=d;d=e+3072|0;c[a+13324>>2]=d;c[a+78860>>2]=d;c[a+144396>>2]=d;d=e+4096|0;c[a+13328>>2]=d;c[a+78864>>2]=d;c[a+144400>>2]=d;d=e+5120|0;c[a+13332>>2]=d;c[a+78868>>2]=d;c[a+144404>>2]=d;d=e+6144|0;c[a+13336>>2]=d;c[a+78872>>2]=d;c[a+144408>>2]=d;d=e+7168|0;c[a+13340>>2]=d;c[a+78876>>2]=d;c[a+144412>>2]=d;c[a+196688>>2]=1430;c[a+196728>>2]=2802;c[a+196608>>2]=3156;c[a+196648>>2]=3314;a=c[3532592]|0;if((a|0)==0){g=c[2113054]|0;c[2113060]=g;c[2394]=-1;return}gGC(a|0,9104152,280)|0;g=c[2113054]|0;c[2113060]=g;c[2394]=-1;return}function d_3(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;d=c[2112926]|0;gGz(d|0,0,ag(c[2443814]<<1,c[2440436]|0)|0);f=c[3530024]|0;g=0;h=c[2439616]|0;i=f;while(1){j=b[h>>1]|0;k=j&255;l=(j&65535)>>>4;m=(j&65535)>>>8;c[i>>2]=((m<<4&255|m&8)&255)>>>3|((k<<4|k&8)&255)<<8&63488|((l<<4&255|l&12)&255)<<3&2016;l=g+1|0;if((l|0)<1024){g=l;h=h+2|0;i=i+4|0}else{break}}i=c[2387062]|0;h=c[3527366]|0;g=h-1|0;l=c[3530986]|0;k=l+6|0;m=c[3528984]|0;j=l+8|0;n=a[7388288]|0?2:0;o=c[2405814]|0;p=0;do{q=p<<5;r=p<<4;s=0;do{t=(s&31|q|s<<5&3072)<<1;u=(e[i+(t<<1)>>1]|0)>>>12;v=(b[i+((t|1)<<1)>>1]&4095|4096)&g;t=(s<<4)-((e[k>>1]|0)+m&1023)|0;w=r-(n+(e[j>>1]|0)&511)|0;x=(t|0)<-16?t+1024|0:t;t=(w|0)<-16?w+512|0:w;w=t-8|0;do{if((x-1|0)>>>0<303){if((t-9|0)>>>0>=223){y=37327;break}Sy(d,v,x,w,u,4,512,o)}else{y=37327}}while(0);if((y|0)==37327){y=0;Sz(d,v,x,w,u,4,512,o)}s=s+1|0;}while((s|0)<64);p=p+1|0;}while((p|0)<32);p=c[2387072]|0;if((b[l+12>>1]&128)==0){j=h+65535|0;h=l+2|0;n=c[3528986]|0;m=l+4|0;k=a[7388296]|0?496:0;g=0;do{i=g<<5;s=g<<4;r=0;do{q=(r&31|i|r<<5&3072)<<1;t=(e[p+(q<<1)>>1]|0)>>>12;z=j&(e[p+((q|1)<<1)>>1]|0);q=(r<<4)-((e[h>>1]|0)+n&1023)|0;A=s-(k+(e[m>>1]|0)&511)|0;B=(q|0)<-16?q+1024|0:q;q=(A|0)<-16?A+512|0:A;A=q-8|0;do{if((B-1|0)>>>0<303){if((q-9|0)>>>0>=223){y=37345;break}SG(d,z,B,A,t,4,0,256,o)}else{y=37345}}while(0);if((y|0)==37345){y=0;SH(d,z,B,A,t,4,0,256,o)}r=r+1|0;}while((r|0)<64);g=g+1|0;}while((g|0)<32);d_G(0,0);R8(f);return}g=(c[3527370]|0)-1|0;o=l+2|0;m=c[3528986]|0;k=l+4|0;l=a[7388296]|0?240:0;n=c[2406522]|0;h=0;j=0;while(1){r=h<<3;s=j;i=0;while(1){q=s<<1;u=(e[p+(q<<1)>>1]|0)>>>12;w=b[p+((q|1)<<1)>>1]&8191&g;q=(i<<3)-((e[o>>1]|0)+m&511)|0;x=r-(l+(e[k>>1]|0)&255)|0;v=(q|0)<-8?q+512|0:q;q=(x|0)<-8?x+256|0:x;x=q-8|0;do{if((v-1|0)>>>0<311){if((q-9|0)>>>0>=231){y=37337;break}Sq(d,w,v,x,u,4,0,256,n)}else{y=37337}}while(0);if((y|0)==37337){y=0;Sr(d,w,v,x,u,4,0,256,n)}q=i+1|0;if((q|0)>=64){break}s=s+1|0;i=q}i=h+1|0;if((i|0)<32){h=i;j=j+64|0}else{break}}d_G(0,0);R8(f);return}function d_4(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;b=i;i=i+360|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;l=0;while(1){if((l|0)>=1024){m=0;break}n=9638528+(l<<2)|0;if((c[n>>2]|0)==0){o=37354;break}else{l=l+1|0}}do{if((o|0)==37354){l=gGq(1048576)|0;c[n>>2]=l;if((l|0)==0){m=0;break}gGz(l|0,0,1048576);m=l}}while(0);c[3529524]=m;if((R6((c[2388030]|0)+1|0,0,2)|0)!=0){p=1;i=b;return p|0}if((R6(c[2388030]|0,1,2)|0)!=0){p=1;i=b;return p|0}m=c[2385836]|0;if((c[3542200]|0)==0){p=1;i=b;return p|0}n=j+108|0;c[n>>2]=0;l=j+100|0;c[l>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,2)|0;do{if((c[n>>2]|0)!=0){j=c[l>>2]|0;c[k>>2]=9534384;q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[q&16383](k,2,0)|0;if((j|0)<1){p=1;i=b;return p|0}if((gzL(m,0,2)|0)==0){break}else{p=1}i=b;return p|0}}while(0);if((R6(c[3529524]|0,3,2)|0)!=0){p=1;i=b;return p|0}if((R6((c[3529524]|0)+1|0,4,2)|0)!=0){p=1;i=b;return p|0}m=c[3529524]|0;k=c[3527366]|0;l=k<<7;do{if((l|0)>0){n=0;do{if((n&32|0)==0){j=m+n|0;q=a[j]|0;r=m+(n+32)|0;a[j]=a[r]|0;a[r]=q}n=n+1|0;}while((n|0)<(l|0));n=(l|0)/2|0;if((l|0)>1){s=0}else{break}do{q=m+s|0;r=a[q]|0;j=m+(s+n)|0;a[q]=a[j]|0;a[j]=r;s=s+1|0;}while((s|0)<(n|0))}}while(0);s=c[3527370]|0;l=c[2406522]|0;if((s|0)>0){n=0;do{r=n<<6;gGz(l+r|0,0,64);j=n<<7;q=0;do{t=1<<3-q;u=(c[683256+(q<<2)>>2]|0)+j|0;v=0;do{w=u+(c[6669224+(v<<2)>>2]|0)|0;x=(v<<3)+r|0;y=0;do{z=w+(c[614800+(y<<2)>>2]|0)|0;if(((d[m+((z|0)/8|0)|0]|0)&128>>>((z&7)>>>0)|0)!=0){z=l+(x+y)|0;a[z]=(d[z]|0|t)&255}y=y+1|0;}while((y|0)<8);v=v+1|0;}while((v|0)<8);q=q+1|0;}while((q|0)<4);n=n+1|0;}while((n|0)<(s|0))}s=c[2405814]|0;if((k|0)>0){n=0;do{l=n<<8;gGz(s+l|0,0,256);q=n<<9;r=0;do{j=1<<3-r;v=(c[683256+(r<<2)>>2]|0)+q|0;t=0;do{u=v+(c[608544+(t<<2)>>2]|0)|0;y=(t<<4)+l|0;x=0;do{w=u+(c[613816+(x<<2)>>2]|0)|0;if(((d[m+((w|0)/8|0)|0]|0)&128>>>((w&7)>>>0)|0)!=0){w=s+(y+x)|0;a[w]=(d[w]|0|j)&255}x=x+1|0;}while((x|0)<16);t=t+1|0;}while((t|0)<16);r=r+1|0;}while((r|0)<4);n=n+1|0;}while((n|0)<(k|0))}gGz(m|0,0,1048576);if((R6(m,5,2)|0)!=0){p=1;i=b;return p|0}if((R6((c[3529524]|0)+1|0,6,2)|0)!=0){p=1;i=b;return p|0}if((R6((c[3529524]|0)+524288|0,7,2)|0)!=0){p=1;i=b;return p|0}if((R6((c[3529524]|0)+524289|0,8,2)|0)!=0){p=1;i=b;return p|0}m=c[2439650]|0;k=c[3529524]|0;n=c[3529576]|0;if((m|0)>0){s=0;do{r=s<<8;gGz(n+r|0,0,256);l=s<<9;q=0;do{t=1<<3-q;j=(c[961456+(q<<2)>>2]|0)+l|0;v=0;do{x=j+(c[608544+(v<<2)>>2]|0)|0;y=(v<<4)+r|0;u=0;do{w=x+(c[613816+(u<<2)>>2]|0)|0;if(((d[k+((w|0)/8|0)|0]|0)&128>>>((w&7)>>>0)|0)!=0){w=n+(y+u)|0;a[w]=(d[w]|0|t)&255}u=u+1|0;}while((u|0)<16);v=v+1|0;}while((v|0)<16);q=q+1|0;}while((q|0)<4);s=s+1|0;}while((s|0)<(m|0))}m=c[2433470]|0;if((c[3542200]|0)==0){p=1;i=b;return p|0}s=g+108|0;c[s>>2]=0;n=g+100|0;c[n>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,9)|0;do{if((c[s>>2]|0)!=0){g=c[n>>2]|0;c[h>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](h,9,0)|0;if((g|0)<1){p=1;i=b;return p|0}if((gzL(m,0,9)|0)==0){break}else{p=1}i=b;return p|0}}while(0);m=c[3541206]|0;if((c[3542200]|0)==0){p=1;i=b;return p|0}h=e+108|0;c[h>>2]=0;n=e+100|0;c[n>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,10)|0;do{if((c[h>>2]|0)!=0){e=c[n>>2]|0;c[f>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](f,10,0)|0;if((e|0)<1){p=1;i=b;return p|0}if((gzL(m,0,10)|0)==0){break}else{p=1}i=b;return p|0}}while(0);m=c[3529524]|0;f=0;while(1){if((f|0)>=1024){break}A=9638528+(f<<2)|0;if((c[A>>2]|0)==(m|0)){o=37415;break}else{f=f+1|0}}if((o|0)==37415){gGr(m);c[A>>2]=0}c[3529524]=0;p=0;i=b;return p|0}function d_5(){var a=0,b=0,d=0,e=0,f=0,g=0;fxU(0,425984);if((c[2394]|0)==0){a=c[2112932]|0}else{c[2394]=0;b=c[3532596]|0;c[2112932]=b;d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060];a=b}b=c[2388030]|0;d=a|0;e=0;while(1){f=b+e|0;c[d>>2]=f;c[d+131072>>2]=f;f=e+1024|0;if(f>>>0>524287){break}else{d=d+4|0;e=f}}e=c[2388050]|0;c[a+4608>>2]=e;c[a+70144>>2]=e;c[a+135680>>2]=e;d=e+1024|0;c[a+4612>>2]=d;c[a+70148>>2]=d;c[a+135684>>2]=d;d=e+2048|0;c[a+4616>>2]=d;c[a+70152>>2]=d;c[a+135688>>2]=d;d=e+3072|0;c[a+4620>>2]=d;c[a+70156>>2]=d;c[a+135692>>2]=d;d=e+4096|0;c[a+4624>>2]=d;c[a+70160>>2]=d;c[a+135696>>2]=d;d=e+5120|0;c[a+4628>>2]=d;c[a+70164>>2]=d;c[a+135700>>2]=d;d=e+6144|0;c[a+4632>>2]=d;c[a+70168>>2]=d;c[a+135704>>2]=d;d=e+7168|0;c[a+4636>>2]=d;c[a+70172>>2]=d;c[a+135708>>2]=d;d=e+8192|0;c[a+4640>>2]=d;c[a+70176>>2]=d;c[a+135712>>2]=d;d=e+9216|0;c[a+4644>>2]=d;c[a+70180>>2]=d;c[a+135716>>2]=d;d=e+10240|0;c[a+4648>>2]=d;c[a+70184>>2]=d;c[a+135720>>2]=d;d=e+11264|0;c[a+4652>>2]=d;c[a+70188>>2]=d;c[a+135724>>2]=d;d=e+12288|0;c[a+4656>>2]=d;c[a+70192>>2]=d;c[a+135728>>2]=d;d=e+13312|0;c[a+4660>>2]=d;c[a+70196>>2]=d;c[a+135732>>2]=d;d=e+14336|0;c[a+4664>>2]=d;c[a+70200>>2]=d;c[a+135736>>2]=d;d=e+15360|0;c[a+4668>>2]=d;c[a+70204>>2]=d;c[a+135740>>2]=d;d=c[2439616]|0;c[a+5120>>2]=d;c[a+70656>>2]=d;c[a+136192>>2]=d;b=d+1024|0;c[a+5124>>2]=b;c[a+70660>>2]=b;c[a+136196>>2]=b;b=c[2443416]|0;c[a+5632>>2]=b;c[a+71168>>2]=b;c[a+136704>>2]=b;d=b+1024|0;c[a+5636>>2]=d;c[a+71172>>2]=d;c[a+136708>>2]=d;d=e+16384|0;c[a+6656>>2]=d;c[a+72192>>2]=d;c[a+137728>>2]=d;d=e+17408|0;c[a+6660>>2]=d;c[a+72196>>2]=d;c[a+137732>>2]=d;d=c[2387072]|0;c[a+12800>>2]=d;c[a+78336>>2]=d;c[a+143872>>2]=d;e=d+1024|0;c[a+12804>>2]=e;c[a+78340>>2]=e;c[a+143876>>2]=e;e=d+2048|0;c[a+12808>>2]=e;c[a+78344>>2]=e;c[a+143880>>2]=e;e=d+3072|0;c[a+12812>>2]=e;c[a+78348>>2]=e;c[a+143884>>2]=e;e=c[2387062]|0;c[a+12832>>2]=e;c[a+78368>>2]=e;c[a+143904>>2]=e;d=e+1024|0;c[a+12836>>2]=d;c[a+78372>>2]=d;c[a+143908>>2]=d;d=e+2048|0;c[a+12840>>2]=d;c[a+78376>>2]=d;c[a+143912>>2]=d;d=e+3072|0;c[a+12844>>2]=d;c[a+78380>>2]=d;c[a+143916>>2]=d;c[a+196688>>2]=1430;c[a+196728>>2]=2802;c[a+196608>>2]=3156;c[a+196648>>2]=3314;a=c[3532592]|0;if((a|0)==0){g=c[2113054]|0;c[2113060]=g;c[2394]=-1;return}gGC(a|0,9104152,280)|0;g=c[2113054]|0;c[2113060]=g;c[2394]=-1;return}function d_6(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;fwR(0);a=c[2439330]|0;d=(a|0)==0;if(!d){e=a;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];e=c[3528484]|0;c[2076596]=e;f=c[2417276]|0;c[3541536]=f;c[1836236]=0;c[a+4180>>2]=2174;c[a+4184>>2]=2746;g=c[2385836]|0;h=0;i=0;while(1){c[a+76+(i<<2)>>2]=g+(i<<8);j=h+1&65535;if((j&65535)>127){k=0;l=0;break}else{h=j;i=j&65535}}while(1){i=g+(l<<8)|0;c[a+76+(l+512<<2)>>2]=i;c[a+76+(l+768<<2)>>2]=i;i=k+1&65535;if((i&65535)>127){break}else{k=i;l=i&65535}}l=c[2385854]|0;c[a+588>>2]=l;k=l+256|0;c[a+592>>2]=k;g=l+512|0;c[a+596>>2]=g;i=l+768|0;c[a+600>>2]=i;h=l+1024|0;c[a+604>>2]=h;j=l+1280|0;c[a+608>>2]=j;m=l+1536|0;c[a+612>>2]=m;n=l+1792|0;c[a+616>>2]=n;c[a+1612>>2]=l;c[a+1616>>2]=k;c[a+1620>>2]=g;c[a+1624>>2]=i;c[a+1628>>2]=h;c[a+1632>>2]=j;c[a+1636>>2]=m;c[a+1640>>2]=n;c[a+2636>>2]=l;c[a+3660>>2]=l;c[a+2640>>2]=k;c[a+3664>>2]=k;c[a+2644>>2]=g;c[a+3668>>2]=g;c[a+2648>>2]=i;c[a+3672>>2]=i;c[a+2652>>2]=h;c[a+3676>>2]=h;c[a+2656>>2]=j;c[a+3680>>2]=j;c[a+2660>>2]=m;c[a+3684>>2]=m;c[a+2664>>2]=n;c[a+3688>>2]=n;if(d){o=c[2433530]|0;c[2438118]=o;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}d=a;gGC(d|0,9706056,76)|0;o=c[2433530]|0;c[2438118]=o;c[3528484]=e;c[2417276]=f;c[1836236]=-1;return}function d_7(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;b=i;i=i+480|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;l=b+360|0;m=b+472|0;n=0;while(1){if((n|0)>=1024){o=0;break}p=9638528+(n<<2)|0;if((c[p>>2]|0)==0){q=37461;break}else{n=n+1|0}}do{if((q|0)==37461){n=gGq(1048576)|0;c[p>>2]=n;if((n|0)==0){o=0;break}gGz(n|0,0,1048576);o=n}}while(0);c[3529524]=o;if((R6((c[2388030]|0)+1|0,0,2)|0)!=0){r=1;i=b;return r|0}if((R6(c[2388030]|0,1,2)|0)!=0){r=1;i=b;return r|0}if((R6(c[3529524]|0,2,2)|0)!=0){r=1;i=b;return r|0}if((R6((c[3529524]|0)+1|0,3,2)|0)!=0){r=1;i=b;return r|0}o=c[3529524]|0;p=c[3527366]|0;n=p<<7;do{if((n|0)>0){s=0;do{if((s&32|0)==0){t=o+s|0;u=a[t]|0;v=o+(s+32)|0;a[t]=a[v]|0;a[v]=u}s=s+1|0;}while((s|0)<(n|0));s=(n|0)/2|0;if((n|0)>1){w=0}else{break}do{u=o+w|0;v=a[u]|0;t=o+(w+s)|0;a[u]=a[t]|0;a[t]=v;w=w+1|0;}while((w|0)<(s|0))}}while(0);w=c[3527370]|0;n=c[2406522]|0;if((w|0)>0){s=0;do{v=s<<6;gGz(n+v|0,0,64);t=s<<7;u=0;do{x=1<<3-u;y=(c[683256+(u<<2)>>2]|0)+t|0;z=0;do{A=y+(c[6669224+(z<<2)>>2]|0)|0;B=(z<<3)+v|0;C=0;do{D=A+(c[614800+(C<<2)>>2]|0)|0;if(((d[o+((D|0)/8|0)|0]|0)&128>>>((D&7)>>>0)|0)!=0){D=n+(B+C)|0;a[D]=(d[D]|0|x)&255}C=C+1|0;}while((C|0)<8);z=z+1|0;}while((z|0)<8);u=u+1|0;}while((u|0)<4);s=s+1|0;}while((s|0)<(w|0))}w=c[2405814]|0;if((p|0)>0){s=0;do{n=s<<8;gGz(w+n|0,0,256);u=s<<9;v=0;do{t=1<<3-v;z=(c[683256+(v<<2)>>2]|0)+u|0;x=0;do{y=z+(c[608544+(x<<2)>>2]|0)|0;C=(x<<4)+n|0;B=0;do{A=y+(c[613816+(B<<2)>>2]|0)|0;if(((d[o+((A|0)/8|0)|0]|0)&128>>>((A&7)>>>0)|0)!=0){A=w+(C+B)|0;a[A]=(d[A]|0|t)&255}B=B+1|0;}while((B|0)<16);x=x+1|0;}while((x|0)<16);v=v+1|0;}while((v|0)<4);s=s+1|0;}while((s|0)<(p|0))}gGz(o|0,0,1048576);if((c[3542200]|0)==0){r=1;i=b;return r|0}p=j+108|0;c[p>>2]=0;s=j+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,4)|0;do{if((c[p>>2]|0)!=0){j=c[s>>2]|0;c[k>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](k,4,0)|0;if((j|0)<1){r=1;i=b;return r|0}if((gzL(o,0,4)|0)==0){break}else{r=1}i=b;return r|0}}while(0);o=(c[3529524]|0)+524288|0;if((c[3542200]|0)==0){r=1;i=b;return r|0}k=g+108|0;c[k>>2]=0;s=g+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,5)|0;do{if((c[k>>2]|0)!=0){g=c[s>>2]|0;c[h>>2]=9534384;p=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[p&16383](h,5,0)|0;if((g|0)<1){r=1;i=b;return r|0}if((gzL(o,0,5)|0)==0){break}else{r=1}i=b;return r|0}}while(0);o=c[2439650]|0;h=c[3529524]|0;s=c[3529576]|0;if((o|0)>0){k=0;do{g=k<<8;gGz(s+g|0,0,256);p=k<<9;j=0;do{w=1<<3-j;v=(c[961456+(j<<2)>>2]|0)+p|0;n=0;do{u=v+(c[608544+(n<<2)>>2]|0)|0;x=(n<<4)+g|0;t=0;do{z=u+(c[613816+(t<<2)>>2]|0)|0;if(((d[h+((z|0)/8|0)|0]|0)&128>>>((z&7)>>>0)|0)!=0){z=s+(x+t)|0;a[z]=(d[z]|0|w)&255}t=t+1|0;}while((t|0)<16);n=n+1|0;}while((n|0)<16);j=j+1|0;}while((j|0)<4);k=k+1|0;}while((k|0)<(o|0))}o=c[2433470]|0;if((c[3542200]|0)==0){r=1;i=b;return r|0}k=e+108|0;c[k>>2]=0;s=e+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,6)|0;do{if((c[k>>2]|0)!=0){e=c[s>>2]|0;c[f>>2]=9534384;h=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[h&16383](f,6,0)|0;if((e|0)<1){r=1;i=b;return r|0}if((gzL(o,0,6)|0)==0){break}else{r=1}i=b;return r|0}}while(0);do{if(a[641800]|0){o=(c[2433470]|0)+524288|0;if((c[3542200]|0)==0){r=1;i=b;return r|0}f=l+108|0;c[f>>2]=0;s=l+100|0;c[s>>2]=0;k=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[k&16383](l,6)|0;if((c[f>>2]|0)==0){break}f=c[s>>2]|0;c[m>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](m,6,0)|0;if((f|0)<1){r=1;i=b;return r|0}if((gzL(o,0,6)|0)==0){break}else{r=1}i=b;return r|0}}while(0);m=c[3541206]|0;l=c[2433470]|0;gGC(m|0,l|0,262144)|0;l=c[3529524]|0;m=0;while(1){if((m|0)>=1024){break}E=9638528+(m<<2)|0;if((c[E>>2]|0)==(l|0)){q=37523;break}else{m=m+1|0}}if((q|0)==37523){gGr(l);c[E>>2]=0}c[3529524]=0;r=0;i=b;return r|0}function d_8(b){b=b|0;var c=0,d=0,e=0;if((b|0)==5242884){c=a[9757970]|0}else if((b|0)==2097152){if(a[6669480]|0){c=10}else{d=0;e=37546}}else if((b|0)==5242883){c=a[14108665]|0}else if((b|0)==5242881){c=a[14108664]|0}else if((b|0)==2097153){d=a[6669480]|0;e=37546}else if((b|0)==5242882){c=a[9757969]|0}else if((b|0)==5242880){e=37547}else{c=0}if((e|0)==37546){if(a[642440]|d){c=10}else{e=37547}}if((e|0)==37547){c=a[9757968]|0}return c|0}function d_9(b){b=b|0;var c=0,d=0;if((b|0)==5242882){c=127-(a[9757969]|0)&255}else if((b|0)==5242880){d=37555}else if((b|0)==2097153){if(a[7216728]|0){c=2}else{d=37555}}else if((b|0)==5242885){c=~a[9757970]}else if((b|0)==5242883){c=a[14108665]|0}else if((b|0)==5242884){c=~a[9757970]}else if((b|0)==5242881){c=a[14108664]|0}else{c=-1}if((d|0)==37555){c=127-(a[9757968]|0)&255}return c|0}function d$a(a,b){a=a|0;b=b|0;if((a|0)!=3145729){return}c[2430194]=b&255;return}function d$b(b,d){b=b|0;d=d|0;if((b|0)!=3145729){return}c[2430194]=d&255;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12;return}function d$c(b){b=b|0;return((b|0)==2097152&a[642520]?10794:0)|0}function d$d(a){a=a|0;var b=0,d=0;if(!((a|0)==5242880|(a|0)==5242882|(a|0)==5242884)){b=-1;return b|0}d=((gj[c[(c[2112932]|0)+196608>>2]&4095](a)|0)&255)<<8;b=(gj[c[(c[2112932]|0)+196608>>2]&4095](a+1|0)|0)&255|d;return b|0}function d$e(b,d){b=b|0;d=d|0;do{if((b|0)==47062|(b|0)==47064){if(!(a[642496]|a[7216728])){break}return}else if((b|0)==2097152){if(!(a[7216728]|0)){break}return}else if((b|0)!=3145728){return}}while(0);gg[c[(c[2112932]|0)+196648>>2]&4095](b,(d&65535)>>>8&255);gg[c[(c[2112932]|0)+196648>>2]&4095](b+1|0,d&255);return}function d$f(b){b=b|0;var c=0;switch(b|0){case 9437185:{c=a[14108664]|0;break};case 9437188:{c=~a[9757970];break};case 9437187:{c=a[14108665]|0;break};case 9437186:{c=127-(a[9757969]|0)&255;break};case 9437189:{c=-1;break};case 9437184:{c=127-(a[9757968]|0)&255;break};default:{c=0}}return c|0}function d$g(a){a=a|0;var b=0,d=0;if(!((a|0)==9437184|(a|0)==9437186|(a|0)==9437188)){b=0;return b|0}d=((gj[c[(c[2112932]|0)+196608>>2]&4095](a)|0)&255)<<8;b=(gj[c[(c[2112932]|0)+196608>>2]&4095](a+1|0)|0)&255|d;return b|0}function d$h(b,d){b=b|0;d=d|0;var e=0;if((b|0)!=3145729){return}c[2430194]=d&255;d=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;b=c[2440482]|0;e=gGU(d,(d|0)<0|0?-1:0,b,(b|0)<0|0?-1:0)|0;b=c[2440530]|0;d=gGS(e,K,b,(b|0)<0|0?-1:0)|0;b=d;if((b|0)>((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)){c[2438216]=b;UF(b)|0}if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12;return}function d$i(a,b){a=a|0;b=b|0;if((a|0)!=3145728){return}gg[c[(c[2112932]|0)+196648>>2]&4095](3145728,(b&65535)>>>8&255);gg[c[(c[2112932]|0)+196648>>2]&4095](3145729,b&255);return}function d$j(b){b=b|0;var d=0,e=0;d=b&65535;if((d|0)==61448){b=c[2430194]|0;if(a[7216728]|0){return((b|0)==255?0:b&255)|0}e=b&255;return e|0}else if((d|0)==61441){e=c[(c[3531464]|0)+4240>>2]&255;return e|0}else{e=0;return e|0}return 0}function d$k(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((e|0)==61440){c[2113304]=d&255;return}else if((e|0)==61442){Uv(0,d);return}else if((e|0)==61441){e=c[2113304]|0;a[14168504+e|0]=d;mv(0,e,d&255);return}else{return}}function d$l(a){a=a|0;var b=0,d=0;b=a&255;if((b|0)==6){d=c[2113156]&255}else if((b|0)==2){d=c[2430194]&255}else{d=0}return d|0}function d$m(a,b){a=a|0;b=b|0;var d=0,e=0;d=a&255;if((d|0)==2){c[2430194]=b&255;return}else if((d|0)==4){a=c[3541206]|0;e=a+((b&255)>>>1<<18&262144)|0;gGC(a|0,e|0,262144)|0;return}else if((d|0)==6){Uv(0,b);return}else{return}}function d$n(a){a=a|0;var b=0;if(a<<16>>16!=-8176){b=0;return b|0}b=c[2113156]&255;return b|0}function d$o(a,b){a=a|0;b=b|0;if(a<<16>>16!=-8176){return}Uv(0,b);return}function d$p(a){a=a|0;var b=0,d=0;if(!((a|0)==3145728|(a|0)==5242880|(a|0)==5242882|(a|0)==5242884)){b=0;return b|0}d=((gj[c[(c[2112932]|0)+196608>>2]&4095](a)|0)&255)<<8;b=(gj[c[(c[2112932]|0)+196608>>2]&4095](a+1|0)|0)&255|d;return b|0}function d$q(b){b=b|0;var d=0,e=0,f=0,g=0;if((b|0)==5242880){d=127-(a[9757968]|0)&255;return d|0}else if((b|0)==5242882){d=~a[9757969];return d|0}else if((b|0)==3145729){e=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;f=c[2440482]|0;g=gGU(e,(e|0)<0|0?-1:0,f,(f|0)<0|0?-1:0)|0;f=c[2440530]|0;e=gGS(g,K,f,(f|0)<0|0?-1:0)|0;f=gGK(e,K,256,0)|0;e=f;if((e|0)>((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)){c[2438216]=e-256;UF(e)|0}d=c[2430194]&255;return d|0}else if((b|0)==5242883){d=~a[14108665];return d|0}else if((b|0)==5242884){d=~a[9757970];return d|0}else if((b|0)==5242881){d=~a[14108664];return d|0}else{d=0;return d|0}return 0}function d$r(a,b){a=a|0;b=b|0;if((a|0)!=3145728){return}gg[c[(c[2112932]|0)+196648>>2]&4095](3145728,(b&65535)>>>8&255);gg[c[(c[2112932]|0)+196648>>2]&4095](3145729,b&255);return}function d$s(b,d){b=b|0;d=d|0;var e=0;if((b|0)!=3145729){return}c[2430194]=d&255;d=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;b=c[2440482]|0;e=gGU(d,(d|0)<0|0?-1:0,b,(b|0)<0|0?-1:0)|0;b=c[2440530]|0;d=gGS(e,K,b,(b|0)<0|0?-1:0)|0;b=d;if((b|0)>((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)){c[2438216]=b;UF(b)|0}if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12;return}function d$t(a){a=a|0;var b=0,d=0;if((a|0)==5242880|(a|0)==5242882|(a|0)==5242884){b=((gj[c[(c[2112932]|0)+196608>>2]&4095](a)|0)&255)<<8;d=(gj[c[(c[2112932]|0)+196608>>2]&4095](a+1|0)|0)&255|b;return d|0}else if((a|0)==3145728){d=3;return d|0}else{d=0;return d|0}return 0}function d$u(b){b=b|0;var c=0;switch(b|0){case 5242885:{c=-1;break};case 5242883:{c=~a[14108665];break};case 5242882:{c=~a[9757969];break};case 5242884:{c=~a[9757970];break};case 5242880:{c=127-(a[9757968]|0)&255;break};case 5242881:{c=~a[14108664];break};default:{c=0}}return c|0}function d$v(a,b){a=a|0;b=b|0;var d=0;if((a|0)!=3145728){return}if(b<<16>>16==254){c[2429486]=0;Uv(0,120);return}a=(b&65535)>>>8&65535;if((b&65535)<8704){d$w(a)}L49788:do{if((b-8704&65535)<4096){c[2439404]=a;switch(a|0){case 36:{d=c[3541206]|0;gGC(d+131072|0,d+655360|0,131072)|0;c[2429486]=1;break L49788;break};case 38:{d=c[3541206]|0;gGC(d+131072|0,d+524288|0,131072)|0;c[2429486]=1;break L49788;break};case 35:{d=c[3541206]|0;gGC(d+131072|0,d+524288|0,131072)|0;c[2429486]=1;break L49788;break};case 39:case 40:case 41:case 42:case 43:case 44:case 45:{d=c[3541206]|0;gGC(d+131072|0,d+786432|0,131072)|0;c[2429486]=1;break L49788;break};case 46:{c[2429486]=0;break L49788;break};case 37:{d=c[3541206]|0;gGC(d+131072|0,d+786432|0,131072)|0;c[2429486]=1;break L49788;break};default:{break L49788}}}}while(0);if((b-12288&65535)<8704){d$w(a-48|0)}if((b-20992&65535)>=3584){return}c[2439404]=a-48;switch(a|0){case 87:case 88:case 89:case 90:case 91:case 92:case 93:{a=c[3541206]|0;gGC(a+131072|0,a+786432|0,131072)|0;c[2429486]=1;return};case 83:{a=c[3541206]|0;gGC(a+131072|0,a+524288|0,131072)|0;c[2429486]=1;return};case 84:{a=c[3541206]|0;gGC(a+131072|0,a+655360|0,131072)|0;c[2429486]=1;return};case 85:{a=c[3541206]|0;gGC(a+131072|0,a+786432|0,131072)|0;c[2429486]=1;return};case 94:{c[2429486]=0;return};case 86:{a=c[3541206]|0;gGC(a+131072|0,a+524288|0,131072)|0;c[2429486]=1;return};default:{return}}}function d$w(a){a=a|0;var b=0;b=c[2113156]|0;if((b&1|0)==0){Uv(0,(a|128)&255);Uv(0,18);return}if((b&2|0)==0){Uv(0,(a|128)&255);Uv(0,18);return}if((b&4|0)!=0){return}Uv(0,(a|128)&255);Uv(0,66);return}function d$x(a,b){a=a|0;b=b|0;var d=0;if((a|0)!=3145728){return}a=b&255;if(b<<24>>24==-2){c[2429486]=0;Uv(0,120);return}if((b&255)<34){d$w(a)}L49842:do{if((b-34&255)<16){c[2439404]=a;switch(a|0){case 46:{c[2429486]=0;break L49842;break};case 38:{d=c[3541206]|0;gGC(d+131072|0,d+524288|0,131072)|0;c[2429486]=1;break L49842;break};case 35:{d=c[3541206]|0;gGC(d+131072|0,d+524288|0,131072)|0;c[2429486]=1;break L49842;break};case 39:case 40:case 41:case 42:case 43:case 44:case 45:{d=c[3541206]|0;gGC(d+131072|0,d+786432|0,131072)|0;c[2429486]=1;break L49842;break};case 36:{d=c[3541206]|0;gGC(d+131072|0,d+655360|0,131072)|0;c[2429486]=1;break L49842;break};case 37:{d=c[3541206]|0;gGC(d+131072|0,d+786432|0,131072)|0;c[2429486]=1;break L49842;break};default:{break L49842}}}}while(0);if((b-48&255)<34){d$w(a-48|0)}if((b-82&255)>=14){return}c[2439404]=a-48;switch(a|0){case 86:{a=c[3541206]|0;gGC(a+131072|0,a+524288|0,131072)|0;c[2429486]=1;return};case 94:{c[2429486]=0;return};case 85:{a=c[3541206]|0;gGC(a+131072|0,a+786432|0,131072)|0;c[2429486]=1;return};case 83:{a=c[3541206]|0;gGC(a+131072|0,a+524288|0,131072)|0;c[2429486]=1;return};case 87:case 88:case 89:case 90:case 91:case 92:case 93:{a=c[3541206]|0;gGC(a+131072|0,a+786432|0,131072)|0;c[2429486]=1;return};case 84:{a=c[3541206]|0;gGC(a+131072|0,a+655360|0,131072)|0;c[2429486]=1;return};default:{return}}}function d$y(b){b=b|0;var e=0,f=0,g=0;e=b&255;if((e|0)==4){if(((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)>(c[2438216]|0)){gu[c[3528468]&16383]();c[2443834]=0}f=c[2430194]&255;return f|0}else if((e|0)==2){e=c[3540984]|0;b=(d[e+5887|0]|0|128)&(d[e+5886|0]|0);if((a[e+5884|0]&2)==0){g=b&255}else{g=(a[(c[e+5828>>2]|0)+100|0]&1|b)&255}f=g|6;return f|0}else{f=0;return f|0}return 0}function d$z(b,e){b=b|0;e=e|0;var f=0,g=0;f=b&255;if((f|0)==3){b=c[3540984]|0;g=c[b+5876>>2]|0;if((g|0)!=0){gg[g&4095](c[b+5880>>2]|0,0)}lH(b,d[b+5885|0]|0,e&255);return}else if((f|0)==2){a[(c[3540984]|0)+5885|0]=e;return}else if((f|0)==4){c[2430194]=e&255;return}else{return}}function d$A(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3846636+(b*112|0)>>2];c[a+104>>2]=c[3846640+(b*112|0)>>2];c[a+108>>2]=c[3846644+(b*112|0)>>2];d=0;return d|0}function d$B(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=3846536+(b*112|0);e=0;return e|0}function d$C(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1238496+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function d$D(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>24){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3847432+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function d$E(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;b=i;i=i+600|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;l=b+360|0;m=b+472|0;n=b+480|0;o=b+592|0;c[2433424]=6144;c[2426732]=0;c[3527162]=0;c[2438710]=1048576;p=a[671688]|0;c[3541206]=1114112;q=p?1638400:1376256;c[2405666]=q;c[3527164]=q;p=a[642472]|0;c[2430196]=q+65536;r=p?q+67584|0:q+66048|0;c[2432692]=r;c[2438712]=r+8192;q=r+10240|0;c[2411684]=q;c[2437710]=q;c[2429744]=r+1583104;q=c[2429510]<<8;s=q+1583104|0;c[2433422]=r+s;c[2437712]=r+(q+1583616);q=r+(s+(p?8704:2560))|0;c[2414224]=q;p=q;q=0;while(1){if((q|0)>=1024){break}t=9638528+(q<<2)|0;if((c[t>>2]|0)==0){u=37838;break}else{q=q+1|0}}do{if((u|0)==37838){q=gGq(p)|0;c[t>>2]=q;if((q|0)==0){break}gGz(q|0,0,p|0);c[2426732]=q;gGz(q|0,0,p|0);c[3527162]=q;c[2438710]=q+1048576;s=a[671688]|0;c[3541206]=q+1114112;r=s?q+1638400|0:q+1376256|0;c[2405666]=r;c[3527164]=r;q=a[642472]|0;c[2430196]=r+65536;s=q?r+67584|0:r+66048|0;c[2432692]=s;c[2438712]=s+8192;r=s+10240|0;c[2411684]=r;c[2437710]=r;r=(c[2433424]<<8)+10240|0;c[2429744]=s+r;v=r+(c[2429510]<<8)|0;c[2433422]=s+v;c[2437712]=s+(v+512);c[2414224]=s+(v+(q?8704:2560));q=0;while(1){if((q|0)>=1024){w=0;break}x=9638528+(q<<2)|0;if((c[x>>2]|0)==0){u=37843;break}else{q=q+1|0}}do{if((u|0)==37843){q=gGq(786432)|0;c[x>>2]=q;if((q|0)==0){w=0;break}gGz(q|0,0,786432);w=q}}while(0);c[2437708]=w;if((R6(c[3527162]|0,0,2)|0)!=0){y=1;i=b;return y|0}if((R6((c[3527162]|0)+1|0,1,2)|0)!=0){y=1;i=b;return y|0}q=c[2438710]|0;if((c[3542200]|0)==0){y=1;i=b;return y|0}v=n+108|0;c[v>>2]=0;s=n+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,5)|0;do{if((c[v>>2]|0)!=0){r=c[s>>2]|0;c[o>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](o,5,0)|0;if((r|0)<1){y=1;i=b;return y|0}if((gzL(q,0,5)|0)==0){break}else{y=1}i=b;return y|0}}while(0);q=c[642608+(c[2436]<<2)>>2]|0;if((fa(c[q>>2]|0,283344)|0)==0){s=c[3527164]|0;a[s+57344|0]=-7;a[s+57345|0]=78;a[s+57346|0]=0;a[s+57347|0]=0;a[s+57348|0]=44;a[s+57349|0]=6;a[s+57472|0]=-36;a[s+57473|0]=-2;a[s+57474|0]=-104;a[s+57475|0]=-70;a[s+57476|0]=84;a[s+57477|0]=118;a[s+57478|0]=16;a[s+57479|0]=50}s=c[2437708]|0;if((c[3542200]|0)==0){y=1;i=b;return y|0}v=l+108|0;c[v>>2]=0;r=l+100|0;c[r>>2]=0;gA[c[q+76>>2]&16383](l,2)|0;do{if((c[v>>2]|0)!=0){q=c[r>>2]|0;c[m>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](m,2,0)|0;if((q|0)<1){y=1;i=b;return y|0}if((gzL(s,0,2)|0)==0){break}else{y=1}i=b;return y|0}}while(0);s=(c[2437708]|0)+262144|0;if((c[3542200]|0)==0){y=1;i=b;return y|0}r=j+108|0;c[r>>2]=0;v=j+100|0;c[v>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,3)|0;do{if((c[r>>2]|0)!=0){q=c[v>>2]|0;c[k>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](k,3,0)|0;if((q|0)<1){y=1;i=b;return y|0}if((gzL(s,0,3)|0)==0){break}else{y=1}i=b;return y|0}}while(0);s=(c[2437708]|0)+524288|0;if((c[3542200]|0)==0){y=1;i=b;return y|0}v=g+108|0;c[v>>2]=0;r=g+100|0;c[r>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,4)|0;do{if((c[v>>2]|0)!=0){q=c[r>>2]|0;c[h>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](h,4,0)|0;if((q|0)<1){y=1;i=b;return y|0}if((gzL(s,0,4)|0)==0){break}else{y=1}i=b;return y|0}}while(0);s=c[2433424]|0;r=c[2437708]|0;v=c[2437710]|0;if((s|0)>0){q=0;while(1){z=q<<8;gGz(v+z|0,0,256);A=q<<10;B=0;do{C=1<<3-B;D=(c[703416+(B<<2)>>2]|0)+A|0;E=0;do{F=D+(c[691048+(E<<2)>>2]|0)|0;G=(E<<4)+z|0;H=0;do{I=F+(c[691112+(H<<2)>>2]|0)|0;if(((d[r+((I|0)/8|0)|0]|0)&128>>>((I&7)>>>0)|0)!=0){I=v+(G+H)|0;a[I]=(d[I]|0|C)&255}H=H+1|0;}while((H|0)<16);E=E+1|0;}while((E|0)<16);B=B+1|0;}while((B|0)<4);B=q+1|0;if((B|0)<(s|0)){q=B}else{J=0;break}}}else{J=0}while(1){if((J|0)>=1024){break}K=9638528+(J<<2)|0;if((c[K>>2]|0)==(r|0)){u=37877;break}else{J=J+1|0}}if((u|0)==37877){gGr(r);c[K>>2]=0}c[2437708]=0;q=c[3541206]|0;if((c[3542200]|0)==0){y=1;i=b;return y|0}s=e+108|0;c[s>>2]=0;v=e+100|0;c[v>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,6)|0;do{if((c[s>>2]|0)!=0){B=c[v>>2]|0;c[f>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](f,6,0)|0;if((B|0)<1){y=1;i=b;return y|0}if((gzL(q,0,6)|0)==0){break}else{y=1}i=b;return y|0}}while(0);d01();y=0;i=b;return y|0}}while(0);c[2426732]=0;y=1;i=b;return y|0}function d$F(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;Uw(0);if((c[2392]|0)>=0){b=0;do{d=14130368+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}d=14130384+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}b=b+1|0;}while((b|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;fwZ();c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}b=a[642472]|0;if(a[671688]|b){if(b){f=37918}}else{b=c[3531464]|0;c[b+44344>>2]=0;c[b+44348>>2]=0;if((b|0)!=0){gGr(b);c[3531464]=0}b=c[2406684]|0;if((b|0)!=0){gGr(b);c[2406684]=0}if(a[642472]|0){f=37918}}if((f|0)==37918){b=a[7452584]|0;if(b){d=0;e=b&1;while(1){b=14163936+(d<<2)|0;g=c[b>>2]|0;h=c[2113006]|0;if((h|0)==0){f=37922}else{i=h-1|0;c[2113006]=i;if((i|0)==0){f=37922}}if((f|0)==37922){f=0;c[2383474]=0}if((g|0)==0){j=e}else{gGr(g);j=a[7452584]&1}c[b>>2]=0;b=d+1|0;if((b|0)<(j|0)){d=b;e=j}else{break}}}a[7452584]=0;c[2438224]=0;c[2433522]=0;c[2406672]=0;c[3528468]=0;j=c[2406688]|0;if((j|0)!=0){gGr(j);c[2406688]=0}c[2432972]=0}j=c[2426732]|0;e=0;while(1){if((e|0)>=1024){f=37935;break}k=9638528+(e<<2)|0;if((c[k>>2]|0)==(j|0)){break}else{e=e+1|0}}if((f|0)==37935){c[2426732]=0;c[2433424]=0;c[2429510]=0;a[642440]=0;a[6669480]=0;a[642520]=0;a[7216728]=0;a[642496]=0;a[671688]=0;a[642472]=0;a[641816]=0;return 0}gGr(j);c[k>>2]=0;c[2426732]=0;c[2433424]=0;c[2429510]=0;a[642440]=0;a[6669480]=0;a[642520]=0;a[7216728]=0;a[642496]=0;a[671688]=0;a[642472]=0;a[641816]=0;return 0}function d$G(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((a[9757960]|0)!=0){d0_()}a[9757970]=0;a[9757969]=0;a[9757968]=0;d=0;f=0;g=0;h=0;do{f=((a[9720808+d|0]&1)<<d|f&255)&255;g=((a[9720800+d|0]&1)<<d|g&255)&255;h=((a[9720792+d|0]&1)<<d|h&255)&255;d=d+1|0;}while((d|0)<8);a[9757968]=f;a[9757969]=g;a[9757970]=h;if((f&3)==3){h=f&-4;a[9757968]=h;i=h}else{i=f}if((i&12)==12){a[9757968]=i&-13}if((g&3)==3){i=g&-4;a[9757969]=i;j=i}else{j=g}if((j&12)==12){a[9757969]=j&-13}c[2440530]=266666;c[2440482]=66666;c[2444087]=0;c[2444086]=0;j=c[2392]|0;if((j|0)>=0){gGz(8452240,0,((j|0)>0?(j<<2)+4|0:4)|0)}c[2113054]=0;j=c[2385548]|0;if((j|0)>0){gGz(9752472,0,((j|0)>1?j<<2:4)|0)}c[2433530]=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];j=c[3532592]|0;if((j|0)!=0){gGC(9104152,j|0,280)|0}c[2113054]=c[2113060]}j=c[2439330]|0;if((j|0)!=0){g=j;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;g=0;j=0;i=266666;f=0;while(1){h=g+1|0;d=((ag(i,h)|0)/4|0)-f|0;c[2113056]=d;k=RG(d)|0;c[2113054]=(c[2113054]|0)+k;c[2276108]=-1;c[2113056]=-1;c[2444086]=(c[2444086]|0)+k;k=(ag(c[2440482]|0,h)|0)/4|0;d=c[2444087]|0;l=k-d|0;do{if((l|0)<1){m=0;n=d}else{if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){k=gfc(l)|0;c[2433530]=(c[2433530]|0)+k;m=k;n=c[2444087]|0;break}else{c[2433530]=(c[2433530]|0)+l;m=l;n=d;break}}}while(0);c[2444087]=n+m;d=c[2112964]|0;if((d|0)==0){o=j}else{l=a[9688]|0?133:0;k=d+(j<<1<<1)|0;gg[c[3542124]&4095](k,l);Uu(0,k,l);o=l+j|0}do{if((g|0)==2){c[8452200+(c[2394]<<2)>>2]=8195;c[2276080]=768;if((c[2276079]|0)>>>0>=768){break}RH(3)}else if((g|0)==3){c[8452200+(c[2394]<<2)>>2]=8194;c[2276080]=512;if((c[2276079]|0)>>>0>=512){break}RH(2)}else if((g|0)==1){c[8452200+(c[2394]<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0>=1024){break}RH(4)}}while(0);if((h|0)>=4){break}g=h;j=o;i=c[2440530]|0;f=c[2444086]|0}f=c[2394]|0;i=c[14130368+(f<<2)>>2]|0;if((i|0)!=0){gGC(i|0,9104152,280)|0}c[8452240+(f<<2)>>2]=c[2113054];c[2394]=-1;f=c[2112964]|0;do{if((f|0)!=0){i=a[9688]|0?534:0;j=i-o|0;g=f+(o<<1<<1)|0;if((i|0)==(o|0)){break}gg[c[3542124]&4095](g,j);Uu(0,g,j)}}while(0);o=c[1836236]|0;f=c[9757320+(o<<2)>>2]|0;if((f|0)!=0){j=f;gGC(j|0,9706056,76)|0}c[9752472+(o<<2)>>2]=c[2433530];c[14113936+(o<<2)>>2]=c[2076596];c[9669104+(o<<2)>>2]=c[3541536];c[1836236]=-1;if((c[2112968]|0)==0){return 0}o=c[2437712]|0;j=0;f=c[2430196]|0;g=o;while(1){i=e[f>>1]|0;m=i>>>5&31;c[g>>2]=i>>>10&31|i<<11&63488|(m<<3|m>>>2)<<3&2016;m=j+1|0;if((m|0)<512){j=m;f=f+2|0;g=g+4|0}else{break}}g=ag(c[2113068]|0,c[2113070]|0)|0;if((g|0)>0){f=c[2112926]|0;j=0;do{b[f+(j<<1)>>1]=240;j=j+1|0;}while((j|0)<(g|0))}d00();R8(o);return 0}function d$H(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;f=i;i=i+144|0;g=f|0;h=f+16|0;j=f+32|0;k=f+48|0;l=f+64|0;m=f+80|0;n=f+96|0;o=f+112|0;p=f+128|0;if((e|0)!=0){c[e>>2]=10564}if((b&32|0)!=0){gGz(p|0,0,12);e=c[2405666]|0;c[p>>2]=e;c[p+4>>2]=(c[2411684]|0)-e;c[p+12>>2]=162152;e=c[2076592]|0;gj[e&4095](p)|0}if((b&64|0)==0){i=f;return 0}p=l|0;gGz(k|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){e=l+9|0;l=j;q=j|0;r=j+4|0;s=j+12|0;t=k|0;u=k+4|0;v=k+12|0;w=0;do{gGC(p|0,614896,11)|0;a[e]=w+48&255;x=8452256+(w<<2)|0;gGz(l|0,0,12);c[q>>2]=x;c[r>>2]=4;c[s>>2]=164976;gj[c[2076592]&4095](j)|0;if((c[x>>2]|0)!=0){c[t>>2]=c[14130368+(w<<2)>>2];c[u>>2]=c[8452184+(w<<2)>>2];c[v>>2]=p;x=c[2076592]|0;gj[x&4095](k)|0}w=w+1|0;}while((w|0)<=(c[2392]|0))}fw$(b);Ut(0);gGz(h|0,0,12);c[h>>2]=8453216;c[h+4>>2]=4;c[h+12>>2]=107480;gj[c[2076592]&4095](h)|0;gGz(g|0,0,12);c[g>>2]=14168504;c[g+4>>2]=256;c[g+12>>2]=476464;gj[c[2076592]&4095](g)|0;if((b&2|0)!=0){b=0;do{mv(0,b,d[14168504+b|0]|0);b=b+1|0;}while((b|0)<256)}gGz(o|0,0,12);c[o>>2]=9720776;c[o+4>>2]=4;c[o+12>>2]=132640;gj[c[2076592]&4095](o)|0;gGz(n|0,0,12);c[n>>2]=9757968;c[n+4>>2]=3;c[n+12>>2]=129624;gj[c[2076592]&4095](n)|0;gGz(m|0,0,12);c[m>>2]=14108664;c[m+4>>2]=2;c[m+12>>2]=127032;gj[c[2076592]&4095](m)|0;i=f;return 0}function d$I(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1868420+(b*112|0)>>2];c[a+104>>2]=c[1868424+(b*112|0)>>2];c[a+108>>2]=c[1868428+(b*112|0)>>2];d=0;return d|0}function d$J(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=1868320+(b*112|0);e=0;return e|0}function d$K(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4150180+(b*112|0)>>2];c[a+104>>2]=c[4150184+(b*112|0)>>2];c[a+108>>2]=c[4150188+(b*112|0)>>2];d=0;return d|0}function d$L(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=4150080+(b*112|0);e=0;return e|0}function d$M(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>24){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4151088+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function d$N(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;b=i;i=i+720|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;l=b+360|0;m=b+472|0;n=b+480|0;o=b+592|0;p=b+600|0;q=b+712|0;c[2433424]=10240;c[2426732]=0;c[3527162]=0;c[2438710]=1048576;r=a[671688]|0;c[3541206]=1114112;s=r?1638400:1376256;c[2405666]=s;c[3527164]=s;r=a[642472]|0;c[2430196]=s+65536;t=r?s+67584|0:s+66048|0;c[2432692]=t;c[2438712]=t+8192;s=t+10240|0;c[2411684]=s;c[2437710]=s;c[2429744]=t+2631680;s=c[2429510]<<8;u=s+2631680|0;c[2433422]=t+u;c[2437712]=t+(s+2632192);s=t+(u+(r?8704:2560))|0;c[2414224]=s;r=s;s=0;while(1){if((s|0)>=1024){break}v=9638528+(s<<2)|0;if((c[v>>2]|0)==0){w=38041;break}else{s=s+1|0}}do{if((w|0)==38041){s=gGq(r)|0;c[v>>2]=s;if((s|0)==0){break}gGz(s|0,0,r|0);c[2426732]=s;gGz(s|0,0,r|0);c[3527162]=s;c[2438710]=s+1048576;u=a[671688]|0;c[3541206]=s+1114112;t=u?s+1638400|0:s+1376256|0;c[2405666]=t;c[3527164]=t;s=a[642472]|0;c[2430196]=t+65536;u=s?t+67584|0:t+66048|0;c[2432692]=u;c[2438712]=u+8192;t=u+10240|0;c[2411684]=t;c[2437710]=t;t=(c[2433424]<<8)+10240|0;c[2429744]=u+t;x=t+(c[2429510]<<8)|0;c[2433422]=u+x;c[2437712]=u+(x+512);c[2414224]=u+(x+(s?8704:2560));s=0;while(1){if((s|0)>=1024){y=0;break}z=9638528+(s<<2)|0;if((c[z>>2]|0)==0){w=38046;break}else{s=s+1|0}}do{if((w|0)==38046){s=gGq(1310720)|0;c[z>>2]=s;if((s|0)==0){y=0;break}gGz(s|0,0,1310720);y=s}}while(0);c[2437708]=y;if((R6(c[3527162]|0,0,2)|0)!=0){A=1;i=b;return A|0}if((R6((c[3527162]|0)+1|0,1,2)|0)!=0){A=1;i=b;return A|0}s=c[2438710]|0;if((c[3542200]|0)==0){A=1;i=b;return A|0}x=p+108|0;c[x>>2]=0;u=p+100|0;c[u>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,5)|0;do{if((c[x>>2]|0)!=0){t=c[u>>2]|0;c[q>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](q,5,0)|0;if((t|0)<1){A=1;i=b;return A|0}if((gzL(s,0,5)|0)==0){break}else{A=1}i=b;return A|0}}while(0);s=c[2437708]|0;if((c[3542200]|0)==0){A=1;i=b;return A|0}u=n+108|0;c[u>>2]=0;x=n+100|0;c[x>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,2)|0;do{if((c[u>>2]|0)!=0){t=c[x>>2]|0;c[o>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](o,2,0)|0;if((t|0)<1){A=1;i=b;return A|0}if((gzL(s,0,2)|0)==0){break}else{A=1}i=b;return A|0}}while(0);s=(c[2437708]|0)+524288|0;if((c[3542200]|0)==0){A=1;i=b;return A|0}x=l+108|0;c[x>>2]=0;u=l+100|0;c[u>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,3)|0;do{if((c[x>>2]|0)!=0){t=c[u>>2]|0;c[m>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](m,3,0)|0;if((t|0)<1){A=1;i=b;return A|0}if((gzL(s,0,3)|0)==0){break}else{A=1}i=b;return A|0}}while(0);s=(c[2437708]|0)+1048576|0;if((c[3542200]|0)==0){A=1;i=b;return A|0}u=j+108|0;c[u>>2]=0;x=j+100|0;c[x>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,4)|0;do{if((c[u>>2]|0)!=0){t=c[x>>2]|0;c[k>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](k,4,0)|0;if((t|0)<1){A=1;i=b;return A|0}if((gzL(s,0,4)|0)==0){break}else{A=1}i=b;return A|0}}while(0);s=c[2433424]|0;x=c[2437708]|0;u=c[2437710]|0;if((s|0)>0){t=0;while(1){B=t<<8;gGz(u+B|0,0,256);C=t<<10;D=0;do{E=1<<3-D;F=(c[703416+(D<<2)>>2]|0)+C|0;G=0;do{H=F+(c[691048+(G<<2)>>2]|0)|0;I=(G<<4)+B|0;J=0;do{K=H+(c[691112+(J<<2)>>2]|0)|0;if(((d[x+((K|0)/8|0)|0]|0)&128>>>((K&7)>>>0)|0)!=0){K=u+(I+J)|0;a[K]=(d[K]|0|E)&255}J=J+1|0;}while((J|0)<16);G=G+1|0;}while((G|0)<16);D=D+1|0;}while((D|0)<4);D=t+1|0;if((D|0)<(s|0)){t=D}else{L=0;break}}}else{L=0}while(1){if((L|0)>=1024){break}M=9638528+(L<<2)|0;if((c[M>>2]|0)==(x|0)){w=38078;break}else{L=L+1|0}}if((w|0)==38078){gGr(x);c[M>>2]=0}c[2437708]=0;t=c[3541206]|0;if((c[3542200]|0)==0){A=1;i=b;return A|0}s=g+108|0;c[s>>2]=0;u=g+100|0;c[u>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,6)|0;do{if((c[s>>2]|0)!=0){D=c[u>>2]|0;c[h>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](h,6,0)|0;if((D|0)<1){A=1;i=b;return A|0}if((gzL(t,0,6)|0)==0){break}else{A=1}i=b;return A|0}}while(0);t=c[2433422]|0;if((c[3542200]|0)==0){A=1;i=b;return A|0}u=e+108|0;c[u>>2]=0;s=e+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,8)|0;do{if((c[u>>2]|0)!=0){x=c[s>>2]|0;c[f>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](f,8,0)|0;if((x|0)<1){A=1;i=b;return A|0}if((gzL(t,0,8)|0)==0){break}else{A=1}i=b;return A|0}}while(0);t=0;s=c[2433422]|0;while(1){u=a[s]|0;x=s+1|0;a[s]=a[x]|0;a[x]=u;u=t+1|0;if((u|0)<256){t=u;s=s+2|0}else{break}}d01();A=0;i=b;return A|0}}while(0);c[2426732]=0;A=1;i=b;return A|0}function d$O(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4148820+(b*112|0)>>2];c[a+104>>2]=c[4148824+(b*112|0)>>2];c[a+108>>2]=c[4148828+(b*112|0)>>2];d=0;return d|0}function d$P(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=4148720+(b*112|0);e=0;return e|0}function d$Q(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>28){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4149728+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function d$R(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;b=i;i=i+720|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;l=b+360|0;m=b+472|0;n=b+480|0;o=b+592|0;p=b+600|0;q=b+712|0;c[2433424]=16384;a[642520]=1;c[2426732]=0;c[3527162]=0;c[2438710]=1048576;r=a[671688]|0;c[3541206]=1114112;s=r?1638400:1376256;c[2405666]=s;c[3527164]=s;r=a[642472]|0;c[2430196]=s+65536;t=r?s+67584|0:s+66048|0;c[2432692]=t;c[2438712]=t+8192;s=t+10240|0;c[2411684]=s;c[2437710]=s;c[2429744]=t+4204544;s=c[2429510]<<8;u=s+4204544|0;c[2433422]=t+u;c[2437712]=t+(s+4205056);s=t+(u+(r?8704:2560))|0;c[2414224]=s;r=s;s=0;while(1){if((s|0)>=1024){break}v=9638528+(s<<2)|0;if((c[v>>2]|0)==0){w=38135;break}else{s=s+1|0}}do{if((w|0)==38135){s=gGq(r)|0;c[v>>2]=s;if((s|0)==0){break}gGz(s|0,0,r|0);c[2426732]=s;gGz(s|0,0,r|0);c[3527162]=s;c[2438710]=s+1048576;u=a[671688]|0;c[3541206]=s+1114112;t=u?s+1638400|0:s+1376256|0;c[2405666]=t;c[3527164]=t;s=a[642472]|0;c[2430196]=t+65536;u=s?t+67584|0:t+66048|0;c[2432692]=u;c[2438712]=u+8192;t=u+10240|0;c[2411684]=t;c[2437710]=t;t=(c[2433424]<<8)+10240|0;c[2429744]=u+t;x=t+(c[2429510]<<8)|0;c[2433422]=u+x;c[2437712]=u+(x+512);c[2414224]=u+(x+(s?8704:2560));s=0;while(1){if((s|0)>=1024){y=0;break}z=9638528+(s<<2)|0;if((c[z>>2]|0)==0){w=38140;break}else{s=s+1|0}}do{if((w|0)==38140){s=gGq(2097152)|0;c[z>>2]=s;if((s|0)==0){y=0;break}gGz(s|0,0,2097152);y=s}}while(0);c[2437708]=y;if((R6(c[3527162]|0,0,2)|0)!=0){A=1;i=b;return A|0}if((R6((c[3527162]|0)+1|0,1,2)|0)!=0){A=1;i=b;return A|0}s=c[2438710]|0;if((c[3542200]|0)==0){A=1;i=b;return A|0}x=p+108|0;c[x>>2]=0;u=p+100|0;c[u>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,5)|0;do{if((c[x>>2]|0)==0){B=0}else{t=c[u>>2]|0;c[q>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](q,5,0)|0;if((t|0)<1){A=1;i=b;return A|0}if((gzL(s,0,5)|0)==0){B=0;break}else{A=1}i=b;return A|0}}while(0);while(1){if((B|0)>=1024){D=0;break}E=9638528+(B<<2)|0;if((c[E>>2]|0)==0){w=38150;break}else{B=B+1|0}}do{if((w|0)==38150){s=gGq(65536)|0;c[E>>2]=s;if((s|0)==0){D=0;break}gGz(s|0,0,65536);D=s}}while(0);s=c[2438710]|0;gGC(D|0,s|0,65536)|0;u=s+49152|0;gGC(u|0,s|0,16384)|0;u=s+32768|0;x=D+16384|0;gGC(u|0,x|0,16384)|0;x=s+16384|0;u=D+32768|0;gGC(x|0,u|0,16384)|0;u=D+49152|0;gGC(s|0,u|0,16384)|0;u=0;while(1){if((u|0)>=1024){break}F=9638528+(u<<2)|0;if((c[F>>2]|0)==(D|0)){w=38155;break}else{u=u+1|0}}if((w|0)==38155){gGr(D);c[F>>2]=0}u=c[2437708]|0;if((c[3542200]|0)==0){A=1;i=b;return A|0}s=n+108|0;c[s>>2]=0;x=n+100|0;c[x>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,2)|0;do{if((c[s>>2]|0)!=0){t=c[x>>2]|0;c[o>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](o,2,0)|0;if((t|0)<1){A=1;i=b;return A|0}if((gzL(u,0,2)|0)==0){break}else{A=1}i=b;return A|0}}while(0);u=(c[2437708]|0)+524288|0;if((c[3542200]|0)==0){A=1;i=b;return A|0}x=l+108|0;c[x>>2]=0;s=l+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,3)|0;do{if((c[x>>2]|0)!=0){t=c[s>>2]|0;c[m>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](m,3,0)|0;if((t|0)<1){A=1;i=b;return A|0}if((gzL(u,0,3)|0)==0){break}else{A=1}i=b;return A|0}}while(0);u=(c[2437708]|0)+1048576|0;if((c[3542200]|0)==0){A=1;i=b;return A|0}s=j+108|0;c[s>>2]=0;x=j+100|0;c[x>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,4)|0;do{if((c[s>>2]|0)!=0){t=c[x>>2]|0;c[k>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](k,4,0)|0;if((t|0)<1){A=1;i=b;return A|0}if((gzL(u,0,4)|0)==0){break}else{A=1}i=b;return A|0}}while(0);u=c[2433424]|0;x=c[2437708]|0;s=c[2437710]|0;if((u|0)>0){t=0;while(1){C=t<<8;gGz(s+C|0,0,256);G=t<<10;H=0;do{I=1<<3-H;J=(c[703416+(H<<2)>>2]|0)+G|0;K=0;do{L=J+(c[691048+(K<<2)>>2]|0)|0;M=(K<<4)+C|0;N=0;do{O=L+(c[691112+(N<<2)>>2]|0)|0;if(((d[x+((O|0)/8|0)|0]|0)&128>>>((O&7)>>>0)|0)!=0){O=s+(M+N)|0;a[O]=(d[O]|0|I)&255}N=N+1|0;}while((N|0)<16);K=K+1|0;}while((K|0)<16);H=H+1|0;}while((H|0)<4);H=t+1|0;if((H|0)<(u|0)){t=H}else{P=0;break}}}else{P=0}while(1){if((P|0)>=1024){break}Q=9638528+(P<<2)|0;if((c[Q>>2]|0)==(x|0)){w=38180;break}else{P=P+1|0}}if((w|0)==38180){gGr(x);c[Q>>2]=0}c[2437708]=0;t=c[3541206]|0;if((c[3542200]|0)==0){A=1;i=b;return A|0}u=g+108|0;c[u>>2]=0;s=g+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,6)|0;do{if((c[u>>2]|0)!=0){H=c[s>>2]|0;c[h>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](h,6,0)|0;if((H|0)<1){A=1;i=b;return A|0}if((gzL(t,0,6)|0)==0){break}else{A=1}i=b;return A|0}}while(0);t=c[2433422]|0;if((c[3542200]|0)==0){A=1;i=b;return A|0}s=e+108|0;c[s>>2]=0;u=e+100|0;c[u>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,8)|0;do{if((c[s>>2]|0)!=0){x=c[u>>2]|0;c[f>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](f,8,0)|0;if((x|0)<1){A=1;i=b;return A|0}if((gzL(t,0,8)|0)==0){break}else{A=1}i=b;return A|0}}while(0);t=0;u=c[2433422]|0;while(1){s=a[u]|0;x=u+1|0;a[u]=a[x]|0;a[x]=s;s=t+1|0;if((s|0)<256){t=s;u=u+2|0}else{break}}d01();A=0;i=b;return A|0}}while(0);c[2426732]=0;A=1;i=b;return A|0}function d$S(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3703036+(b*112|0)>>2];c[a+104>>2]=c[3703040+(b*112|0)>>2];c[a+108>>2]=c[3703044+(b*112|0)>>2];d=0;return d|0}function d$T(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=3702936+(b*112|0);e=0;return e|0}function d$U(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>28){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4149728+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function d$V(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;b=i;i=i+840|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;l=b+360|0;m=b+472|0;n=b+480|0;o=b+592|0;p=b+600|0;q=b+712|0;r=b+720|0;s=b+832|0;c[2433424]=16384;t=c[c[642608+(c[2436]<<2)>>2]>>2]|0;if((fa(t|0,535696)|0)==0){u=38236}else{if((fa(t|0,471808)|0)==0){u=38236}}if((u|0)==38236){a[642440]=1}if((fa(t|0,449976)|0)==0){a[6669480]=1}c[2426732]=0;c[3527162]=0;c[2438710]=1048576;t=a[671688]|0;c[3541206]=1114112;v=t?1638400:1376256;c[2405666]=v;c[3527164]=v;t=a[642472]|0;c[2430196]=v+65536;w=t?v+67584|0:v+66048|0;c[2432692]=w;c[2438712]=w+8192;v=w+10240|0;c[2411684]=v;c[2437710]=v;c[2429744]=w+4204544;v=c[2429510]<<8;x=v+4204544|0;c[2433422]=w+x;c[2437712]=w+(v+4205056);v=w+(x+(t?8704:2560))|0;c[2414224]=v;t=v;v=0;while(1){if((v|0)>=1024){break}y=9638528+(v<<2)|0;if((c[y>>2]|0)==0){u=38242;break}else{v=v+1|0}}do{if((u|0)==38242){v=gGq(t)|0;c[y>>2]=v;if((v|0)==0){break}gGz(v|0,0,t|0);c[2426732]=v;gGz(v|0,0,t|0);c[3527162]=v;c[2438710]=v+1048576;x=a[671688]|0;c[3541206]=v+1114112;w=x?v+1638400|0:v+1376256|0;c[2405666]=w;c[3527164]=w;v=a[642472]|0;c[2430196]=w+65536;x=v?w+67584|0:w+66048|0;c[2432692]=x;c[2438712]=x+8192;w=x+10240|0;c[2411684]=w;c[2437710]=w;w=(c[2433424]<<8)+10240|0;c[2429744]=x+w;z=w+(c[2429510]<<8)|0;c[2433422]=x+z;c[2437712]=x+(z+512);c[2414224]=x+(z+(v?8704:2560));v=0;while(1){if((v|0)>=1024){A=0;break}B=9638528+(v<<2)|0;if((c[B>>2]|0)==0){u=38247;break}else{v=v+1|0}}do{if((u|0)==38247){v=gGq(2097152)|0;c[B>>2]=v;if((v|0)==0){A=0;break}gGz(v|0,0,2097152);A=v}}while(0);c[2437708]=A;if((R6(c[3527162]|0,0,2)|0)!=0){C=1;i=b;return C|0}if((R6((c[3527162]|0)+1|0,1,2)|0)!=0){C=1;i=b;return C|0}v=c[2438710]|0;if((c[3542200]|0)==0){C=1;i=b;return C|0}z=p+108|0;c[z>>2]=0;x=p+100|0;c[x>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,6)|0;do{if((c[z>>2]|0)!=0){w=c[x>>2]|0;c[q>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](q,6,0)|0;if((w|0)<1){C=1;i=b;return C|0}if((gzL(v,0,6)|0)==0){break}else{C=1}i=b;return C|0}}while(0);v=c[2437708]|0;if((c[3542200]|0)==0){C=1;i=b;return C|0}x=n+108|0;c[x>>2]=0;z=n+100|0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,2)|0;do{if((c[x>>2]|0)!=0){w=c[z>>2]|0;c[o>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](o,2,0)|0;if((w|0)<1){C=1;i=b;return C|0}if((gzL(v,0,2)|0)==0){break}else{C=1}i=b;return C|0}}while(0);v=(c[2437708]|0)+524288|0;if((c[3542200]|0)==0){C=1;i=b;return C|0}z=l+108|0;c[z>>2]=0;x=l+100|0;c[x>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,3)|0;do{if((c[z>>2]|0)!=0){w=c[x>>2]|0;c[m>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](m,3,0)|0;if((w|0)<1){C=1;i=b;return C|0}if((gzL(v,0,3)|0)==0){break}else{C=1}i=b;return C|0}}while(0);v=(c[2437708]|0)+1048576|0;if((c[3542200]|0)==0){C=1;i=b;return C|0}x=j+108|0;c[x>>2]=0;z=j+100|0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,4)|0;do{if((c[x>>2]|0)!=0){w=c[z>>2]|0;c[k>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](k,4,0)|0;if((w|0)<1){C=1;i=b;return C|0}if((gzL(v,0,4)|0)==0){break}else{C=1}i=b;return C|0}}while(0);v=(c[2437708]|0)+1572864|0;if((c[3542200]|0)==0){C=1;i=b;return C|0}z=g+108|0;c[z>>2]=0;x=g+100|0;c[x>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,5)|0;do{if((c[z>>2]|0)!=0){w=c[x>>2]|0;c[h>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](h,5,0)|0;if((w|0)<1){C=1;i=b;return C|0}if((gzL(v,0,5)|0)==0){break}else{C=1}i=b;return C|0}}while(0);v=c[2433424]|0;x=c[2437708]|0;z=c[2437710]|0;if((v|0)>0){w=0;while(1){D=w<<8;gGz(z+D|0,0,256);E=w<<10;F=0;do{G=1<<3-F;H=(c[703416+(F<<2)>>2]|0)+E|0;I=0;do{J=H+(c[691048+(I<<2)>>2]|0)|0;K=(I<<4)+D|0;L=0;do{M=J+(c[691112+(L<<2)>>2]|0)|0;if(((d[x+((M|0)/8|0)|0]|0)&128>>>((M&7)>>>0)|0)!=0){M=z+(K+L)|0;a[M]=(d[M]|0|G)&255}L=L+1|0;}while((L|0)<16);I=I+1|0;}while((I|0)<16);F=F+1|0;}while((F|0)<4);F=w+1|0;if((F|0)<(v|0)){w=F}else{N=0;break}}}else{N=0}while(1){if((N|0)>=1024){break}O=9638528+(N<<2)|0;if((c[O>>2]|0)==(x|0)){u=38283;break}else{N=N+1|0}}if((u|0)==38283){gGr(x);c[O>>2]=0}c[2437708]=0;w=c[3541206]|0;if((c[3542200]|0)==0){C=1;i=b;return C|0}v=e+108|0;c[v>>2]=0;z=e+100|0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,7)|0;do{if((c[v>>2]|0)!=0){F=c[z>>2]|0;c[f>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](f,7,0)|0;if((F|0)<1){C=1;i=b;return C|0}if((gzL(w,0,7)|0)==0){break}else{C=1}i=b;return C|0}}while(0);w=c[2433422]|0;if((c[3542200]|0)==0){C=1;i=b;return C|0}z=r+108|0;c[z>>2]=0;v=r+100|0;c[v>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,9)|0;do{if((c[z>>2]|0)!=0){x=c[v>>2]|0;c[s>>2]=9534384;F=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[F&16383](s,9,0)|0;if((x|0)<1){C=1;i=b;return C|0}if((gzL(w,0,9)|0)==0){break}else{C=1}i=b;return C|0}}while(0);w=0;v=c[2433422]|0;while(1){z=a[v]|0;x=v+1|0;a[v]=a[x]|0;a[x]=z;z=w+1|0;if((z|0)<256){w=z;v=v+2|0}else{break}}d01();C=0;i=b;return C|0}}while(0);c[2426732]=0;C=1;i=b;return C|0}function d$W(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3701916+(b*112|0)>>2];c[a+104>>2]=c[3701920+(b*112|0)>>2];c[a+108>>2]=c[3701924+(b*112|0)>>2];d=0;return d|0}function d$X(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=3701816+(b*112|0);e=0;return e|0}function d$Y(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[802772+(b*112|0)>>2];c[a+104>>2]=c[802776+(b*112|0)>>2];c[a+108>>2]=c[802780+(b*112|0)>>2];d=0;return d|0}function d$Z(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=802672+(b*112|0);e=0;return e|0}function d$_(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3302636+(b*112|0)>>2];c[a+104>>2]=c[3302640+(b*112|0)>>2];c[a+108>>2]=c[3302644+(b*112|0)>>2];d=0;return d|0}function d$$(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=3302536+(b*112|0);e=0;return e|0}function d$0(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>40){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3303656+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function d$1(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4908484+(b*112|0)>>2];c[a+104>>2]=c[4908488+(b*112|0)>>2];c[a+108>>2]=c[4908492+(b*112|0)>>2];d=0;return d|0}function d$2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=4908384+(b*112|0);e=0;return e|0}function d$3(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;b=i;i=i+480|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;l=b+360|0;m=b+472|0;c[2433424]=4096;c[2426732]=0;c[3527162]=0;c[2438710]=1048576;n=a[671688]|0;c[3541206]=1114112;o=n?1638400:1376256;c[2405666]=o;c[3527164]=o;n=a[642472]|0;c[2430196]=o+65536;p=n?o+67584|0:o+66048|0;c[2432692]=p;c[2438712]=p+8192;o=p+10240|0;c[2411684]=o;c[2437710]=o;c[2429744]=p+1058816;o=c[2429510]<<8;q=o+1058816|0;c[2433422]=p+q;c[2437712]=p+(o+1059328);o=p+(q+(n?8704:2560))|0;c[2414224]=o;n=o;o=0;while(1){if((o|0)>=1024){break}r=9638528+(o<<2)|0;if((c[r>>2]|0)==0){s=38379;break}else{o=o+1|0}}do{if((s|0)==38379){o=gGq(n)|0;c[r>>2]=o;if((o|0)==0){break}gGz(o|0,0,n|0);c[2426732]=o;gGz(o|0,0,n|0);c[3527162]=o;c[2438710]=o+1048576;q=a[671688]|0;c[3541206]=o+1114112;p=q?o+1638400|0:o+1376256|0;c[2405666]=p;c[3527164]=p;o=a[642472]|0;c[2430196]=p+65536;q=o?p+67584|0:p+66048|0;c[2432692]=q;c[2438712]=q+8192;p=q+10240|0;c[2411684]=p;c[2437710]=p;p=(c[2433424]<<8)+10240|0;c[2429744]=q+p;t=p+(c[2429510]<<8)|0;c[2433422]=q+t;c[2437712]=q+(t+512);c[2414224]=q+(t+(o?8704:2560));o=0;while(1){if((o|0)>=1024){u=0;break}v=9638528+(o<<2)|0;if((c[v>>2]|0)==0){s=38384;break}else{o=o+1|0}}do{if((s|0)==38384){o=gGq(524288)|0;c[v>>2]=o;if((o|0)==0){u=0;break}gGz(o|0,0,524288);u=o}}while(0);c[2437708]=u;if((R6(c[3527162]|0,0,2)|0)!=0){w=1;i=b;return w|0}if((R6((c[3527162]|0)+1|0,1,2)|0)!=0){w=1;i=b;return w|0}o=c[2438710]|0;if((c[3542200]|0)==0){w=1;i=b;return w|0}t=l+108|0;c[t>>2]=0;q=l+100|0;c[q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,3)|0;do{if((c[t>>2]|0)!=0){p=c[q>>2]|0;c[m>>2]=9534384;x=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[x&16383](m,3,0)|0;if((p|0)<1){w=1;i=b;return w|0}if((gzL(o,0,3)|0)==0){break}else{w=1}i=b;return w|0}}while(0);o=c[2437708]|0;if((c[3542200]|0)==0){w=1;i=b;return w|0}q=j+108|0;c[q>>2]=0;t=j+100|0;c[t>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,2)|0;do{if((c[q>>2]|0)!=0){p=c[t>>2]|0;c[k>>2]=9534384;x=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[x&16383](k,2,0)|0;if((p|0)<1){w=1;i=b;return w|0}if((gzL(o,0,2)|0)==0){break}else{w=1}i=b;return w|0}}while(0);o=c[2433424]|0;t=c[2437708]|0;q=c[2437710]|0;if((o|0)>0){p=0;while(1){x=p<<8;gGz(q+x|0,0,256);y=p<<10;z=0;do{A=1<<3-z;B=(c[703416+(z<<2)>>2]|0)+y|0;C=0;do{D=B+(c[691048+(C<<2)>>2]|0)|0;E=(C<<4)+x|0;F=0;do{G=D+(c[691112+(F<<2)>>2]|0)|0;if(((d[t+((G|0)/8|0)|0]|0)&128>>>((G&7)>>>0)|0)!=0){G=q+(E+F)|0;a[G]=(d[G]|0|A)&255}F=F+1|0;}while((F|0)<16);C=C+1|0;}while((C|0)<16);z=z+1|0;}while((z|0)<4);z=p+1|0;if((z|0)<(o|0)){p=z}else{H=0;break}}}else{H=0}while(1){if((H|0)>=1024){break}I=9638528+(H<<2)|0;if((c[I>>2]|0)==(t|0)){s=38408;break}else{H=H+1|0}}if((s|0)==38408){gGr(t);c[I>>2]=0}c[2437708]=0;p=c[3541206]|0;if((c[3542200]|0)==0){w=1;i=b;return w|0}o=g+108|0;c[o>>2]=0;q=g+100|0;c[q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,4)|0;do{if((c[o>>2]|0)!=0){z=c[q>>2]|0;c[h>>2]=9534384;x=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[x&16383](h,4,0)|0;if((z|0)<1){w=1;i=b;return w|0}if((gzL(p,0,4)|0)==0){break}else{w=1}i=b;return w|0}}while(0);p=c[2433422]|0;if((c[3542200]|0)==0){w=1;i=b;return w|0}q=e+108|0;c[q>>2]=0;o=e+100|0;c[o>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,6)|0;do{if((c[q>>2]|0)!=0){t=c[o>>2]|0;c[f>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](f,6,0)|0;if((t|0)<1){w=1;i=b;return w|0}if((gzL(p,0,6)|0)==0){break}else{w=1}i=b;return w|0}}while(0);p=0;o=c[2433422]|0;while(1){q=a[o]|0;t=o+1|0;a[o]=a[t]|0;a[t]=q;q=p+1|0;if((q|0)<256){p=q;o=o+2|0}else{break}}d01();w=0;i=b;return w|0}}while(0);c[2426732]=0;w=1;i=b;return w|0}function d$4(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3598372+(b*112|0)>>2];c[a+104>>2]=c[3598376+(b*112|0)>>2];c[a+108>>2]=c[3598380+(b*112|0)>>2];d=0;return d|0}function d$5(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=3598272+(b*112|0);e=0;return e|0}function d$6(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;b=i;i=i+600|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;l=b+360|0;m=b+472|0;n=b+480|0;o=b+592|0;c[2433424]=8192;c[2426732]=0;c[3527162]=0;c[2438710]=1048576;p=a[671688]|0;c[3541206]=1114112;q=p?1638400:1376256;c[2405666]=q;c[3527164]=q;p=a[642472]|0;c[2430196]=q+65536;r=p?q+67584|0:q+66048|0;c[2432692]=r;c[2438712]=r+8192;q=r+10240|0;c[2411684]=q;c[2437710]=q;c[2429744]=r+2107392;q=c[2429510]<<8;s=q+2107392|0;c[2433422]=r+s;c[2437712]=r+(q+2107904);q=r+(s+(p?8704:2560))|0;c[2414224]=q;p=q;q=0;while(1){if((q|0)>=1024){break}t=9638528+(q<<2)|0;if((c[t>>2]|0)==0){u=38452;break}else{q=q+1|0}}do{if((u|0)==38452){q=gGq(p)|0;c[t>>2]=q;if((q|0)==0){break}gGz(q|0,0,p|0);c[2426732]=q;gGz(q|0,0,p|0);c[3527162]=q;c[2438710]=q+1048576;s=a[671688]|0;c[3541206]=q+1114112;r=s?q+1638400|0:q+1376256|0;c[2405666]=r;c[3527164]=r;q=a[642472]|0;c[2430196]=r+65536;s=q?r+67584|0:r+66048|0;c[2432692]=s;c[2438712]=s+8192;r=s+10240|0;c[2411684]=r;c[2437710]=r;r=(c[2433424]<<8)+10240|0;c[2429744]=s+r;v=r+(c[2429510]<<8)|0;c[2433422]=s+v;c[2437712]=s+(v+512);c[2414224]=s+(v+(q?8704:2560));q=0;while(1){if((q|0)>=1024){w=0;break}x=9638528+(q<<2)|0;if((c[x>>2]|0)==0){u=38457;break}else{q=q+1|0}}do{if((u|0)==38457){q=gGq(1048576)|0;c[x>>2]=q;if((q|0)==0){w=0;break}gGz(q|0,0,1048576);w=q}}while(0);c[2437708]=w;if((R6(c[3527162]|0,0,2)|0)!=0){y=1;i=b;return y|0}if((R6((c[3527162]|0)+1|0,1,2)|0)!=0){y=1;i=b;return y|0}q=c[2438710]|0;if((c[3542200]|0)==0){y=1;i=b;return y|0}v=n+108|0;c[v>>2]=0;s=n+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,4)|0;do{if((c[v>>2]|0)!=0){r=c[s>>2]|0;c[o>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](o,4,0)|0;if((r|0)<1){y=1;i=b;return y|0}if((gzL(q,0,4)|0)==0){break}else{y=1}i=b;return y|0}}while(0);q=c[2437708]|0;if((c[3542200]|0)==0){y=1;i=b;return y|0}s=l+108|0;c[s>>2]=0;v=l+100|0;c[v>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,2)|0;do{if((c[s>>2]|0)!=0){r=c[v>>2]|0;c[m>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](m,2,0)|0;if((r|0)<1){y=1;i=b;return y|0}if((gzL(q,0,2)|0)==0){break}else{y=1}i=b;return y|0}}while(0);q=(c[2437708]|0)+524288|0;if((c[3542200]|0)==0){y=1;i=b;return y|0}v=j+108|0;c[v>>2]=0;s=j+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,3)|0;do{if((c[v>>2]|0)!=0){r=c[s>>2]|0;c[k>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](k,3,0)|0;if((r|0)<1){y=1;i=b;return y|0}if((gzL(q,0,3)|0)==0){break}else{y=1}i=b;return y|0}}while(0);q=c[2433424]|0;s=c[2437708]|0;v=c[2437710]|0;if((q|0)>0){r=0;while(1){z=r<<8;gGz(v+z|0,0,256);A=r<<10;B=0;do{C=1<<3-B;D=(c[703416+(B<<2)>>2]|0)+A|0;E=0;do{F=D+(c[691048+(E<<2)>>2]|0)|0;G=(E<<4)+z|0;H=0;do{I=F+(c[691112+(H<<2)>>2]|0)|0;if(((d[s+((I|0)/8|0)|0]|0)&128>>>((I&7)>>>0)|0)!=0){I=v+(G+H)|0;a[I]=(d[I]|0|C)&255}H=H+1|0;}while((H|0)<16);E=E+1|0;}while((E|0)<16);B=B+1|0;}while((B|0)<4);B=r+1|0;if((B|0)<(q|0)){r=B}else{J=0;break}}}else{J=0}while(1){if((J|0)>=1024){break}K=9638528+(J<<2)|0;if((c[K>>2]|0)==(s|0)){u=38485;break}else{J=J+1|0}}if((u|0)==38485){gGr(s);c[K>>2]=0}c[2437708]=0;r=c[3541206]|0;if((c[3542200]|0)==0){y=1;i=b;return y|0}q=g+108|0;c[q>>2]=0;v=g+100|0;c[v>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,5)|0;do{if((c[q>>2]|0)!=0){B=c[v>>2]|0;c[h>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](h,5,0)|0;if((B|0)<1){y=1;i=b;return y|0}if((gzL(r,0,5)|0)==0){break}else{y=1}i=b;return y|0}}while(0);r=c[2433422]|0;if((c[3542200]|0)==0){y=1;i=b;return y|0}v=e+108|0;c[v>>2]=0;q=e+100|0;c[q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,7)|0;do{if((c[v>>2]|0)!=0){s=c[q>>2]|0;c[f>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](f,7,0)|0;if((s|0)<1){y=1;i=b;return y|0}if((gzL(r,0,7)|0)==0){break}else{y=1}i=b;return y|0}}while(0);r=0;q=c[2433422]|0;while(1){v=a[q]|0;s=q+1|0;a[q]=a[s]|0;a[s]=v;v=r+1|0;if((v|0)<256){r=v;q=q+2|0}else{break}}d01();y=0;i=b;return y|0}}while(0);c[2426732]=0;y=1;i=b;return y|0}function d$7(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((a[9757960]|0)!=0){d0_()}a[9757970]=0;a[9757969]=0;a[9757968]=0;d=0;f=0;g=0;h=0;do{f=((a[9720808+d|0]&1)<<d|f&255)&255;g=((a[9720800+d|0]&1)<<d|g&255)&255;h=((a[9720792+d|0]&1)<<d|h&255)&255;d=d+1|0;}while((d|0)<8);a[9757968]=f;a[9757969]=g;a[9757970]=h;if((f&3)==3){h=f&-4;a[9757968]=h;i=h}else{i=f}if((i&12)==12){a[9757968]=i&-13}if((g&3)==3){i=g&-4;a[9757969]=i;j=i}else{j=g}if((j&12)==12){a[9757969]=j&-13}c[2440530]=266666;c[2440482]=66666;c[2444087]=0;c[2444086]=0;j=c[2392]|0;if((j|0)>=0){gGz(8452240,0,((j|0)>0?(j<<2)+4|0:4)|0)}c[2113054]=0;j=c[2385548]|0;if((j|0)>0){gGz(9752472,0,((j|0)>1?j<<2:4)|0)}c[2433530]=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];j=c[3532592]|0;if((j|0)!=0){gGC(9104152,j|0,280)|0}c[2113054]=c[2113060]}j=c[2439330]|0;if((j|0)!=0){g=j;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;g=0;j=0;i=266666;f=0;while(1){h=g+1|0;d=((ag(i,h)|0)/4|0)-f|0;c[2113056]=d;k=RG(d)|0;c[2113054]=(c[2113054]|0)+k;c[2276108]=-1;c[2113056]=-1;c[2444086]=(c[2444086]|0)+k;k=(ag(c[2440482]|0,h)|0)/4|0;d=c[2444087]|0;l=k-d|0;do{if((l|0)<1){m=0;n=d}else{if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){k=gfc(l)|0;c[2433530]=(c[2433530]|0)+k;m=k;n=c[2444087]|0;break}else{c[2433530]=(c[2433530]|0)+l;m=l;n=d;break}}}while(0);c[2444087]=n+m;d=c[2112964]|0;if((d|0)==0){o=j}else{l=a[9688]|0?133:0;k=d+(j<<1<<1)|0;gg[c[3542124]&4095](k,l);Uu(0,k,l);o=l+j|0}do{if((g|0)==3){c[8452200+(c[2394]<<2)>>2]=8194;c[2276080]=512;if((c[2276079]|0)>>>0>=512){break}RH(2)}else if((g|0)==1){c[8452200+(c[2394]<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0>=1024){break}RH(4)}else if((g|0)==2){c[8452200+(c[2394]<<2)>>2]=8195;c[2276080]=768;if((c[2276079]|0)>>>0>=768){break}RH(3)}}while(0);if((h|0)>=4){break}g=h;j=o;i=c[2440530]|0;f=c[2444086]|0}f=c[2394]|0;i=c[14130368+(f<<2)>>2]|0;if((i|0)!=0){gGC(i|0,9104152,280)|0}c[8452240+(f<<2)>>2]=c[2113054];c[2394]=-1;f=c[2112964]|0;do{if((f|0)!=0){i=a[9688]|0?534:0;j=i-o|0;g=f+(o<<1<<1)|0;if((i|0)==(o|0)){break}gg[c[3542124]&4095](g,j);Uu(0,g,j)}}while(0);o=c[1836236]|0;f=c[9757320+(o<<2)>>2]|0;if((f|0)!=0){j=f;gGC(j|0,9706056,76)|0}c[9752472+(o<<2)>>2]=c[2433530];c[14113936+(o<<2)>>2]=c[2076596];c[9669104+(o<<2)>>2]=c[3541536];c[1836236]=-1;if((c[2112968]|0)==0){return 0}o=c[2437712]|0;j=0;f=c[2430196]|0;g=o;while(1){i=e[f>>1]|0;m=i>>>5&31;c[g>>2]=i>>>10&31|i<<11&63488|(m<<3|m>>>2)<<3&2016;m=j+1|0;if((m|0)<512){j=m;f=f+2|0;g=g+4|0}else{break}}g=ag(c[2113068]|0,c[2113070]|0)|0;if((g|0)>0){f=c[2112926]|0;j=0;do{b[f+(j<<1)>>1]=192;j=j+1|0;}while((j|0)<(g|0))}d00();R8(o);return 0}function d$8(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>4){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[980540+(b*112|0)>>2];c[a+104>>2]=c[980544+(b*112|0)>>2];c[a+108>>2]=c[980548+(b*112|0)>>2];d=0;return d|0}function d$9(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<5&(d|0)==0)){e=1;return e|0}c[a>>2]=980440+(b*112|0);e=0;return e|0}function d0a(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>37){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=981e3+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function d0b(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;b=i;i=i+360|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;c[2433424]=16384;a[7216728]=1;c[2426732]=0;c[3527162]=0;c[2438710]=1048576;l=a[671688]|0;c[3541206]=1114112;m=l?1638400:1376256;c[2405666]=m;c[3527164]=m;l=a[642472]|0;c[2430196]=m+65536;n=l?m+67584|0:m+66048|0;c[2432692]=n;c[2438712]=n+8192;m=n+10240|0;c[2411684]=m;c[2437710]=m;c[2429744]=n+4204544;m=c[2429510]<<8;o=m+4204544|0;c[2433422]=n+o;c[2437712]=n+(m+4205056);m=n+(o+(l?8704:2560))|0;c[2414224]=m;l=m;m=0;while(1){if((m|0)>=1024){break}p=9638528+(m<<2)|0;if((c[p>>2]|0)==0){q=38594;break}else{m=m+1|0}}do{if((q|0)==38594){m=gGq(l)|0;c[p>>2]=m;if((m|0)==0){break}gGz(m|0,0,l|0);c[2426732]=m;gGz(m|0,0,l|0);c[3527162]=m;c[2438710]=m+1048576;o=a[671688]|0;c[3541206]=m+1114112;n=o?m+1638400|0:m+1376256|0;c[2405666]=n;c[3527164]=n;m=a[642472]|0;c[2430196]=n+65536;o=m?n+67584|0:n+66048|0;c[2432692]=o;c[2438712]=o+8192;n=o+10240|0;c[2411684]=n;c[2437710]=n;n=(c[2433424]<<8)+10240|0;c[2429744]=o+n;r=n+(c[2429510]<<8)|0;c[2433422]=o+r;c[2437712]=o+(r+512);c[2414224]=o+(r+(m?8704:2560));m=0;while(1){if((m|0)>=1024){s=0;break}t=9638528+(m<<2)|0;if((c[t>>2]|0)==0){q=38599;break}else{m=m+1|0}}do{if((q|0)==38599){m=gGq(2097152)|0;c[t>>2]=m;if((m|0)==0){s=0;break}gGz(m|0,0,2097152);s=m}}while(0);c[2437708]=s;if((R6(c[3527162]|0,0,2)|0)!=0){u=1;i=b;return u|0}if((R6((c[3527162]|0)+1|0,1,2)|0)!=0){u=1;i=b;return u|0}m=c[2438710]|0;if((c[3542200]|0)==0){u=1;i=b;return u|0}r=j+108|0;c[r>>2]=0;o=j+100|0;c[o>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,3)|0;do{if((c[r>>2]|0)!=0){n=c[o>>2]|0;c[k>>2]=9534384;v=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[v&16383](k,3,0)|0;if((n|0)<1){u=1;i=b;return u|0}if((gzL(m,0,3)|0)==0){break}else{u=1}i=b;return u|0}}while(0);m=c[3527162]|0;o=0;while(1){if((o|0)>=1024){break}w=9638528+(o<<2)|0;if((c[w>>2]|0)==0){q=38610;break}else{o=o+1|0}}L50987:do{if((q|0)==38610){o=gGq(1048576)|0;c[w>>2]=o;if((o|0)==0){break}gGz(o|0,0,1048576);r=0;do{n=a[m+r|0]|0;if((r&1|0)==0){a[o+r|0]=n}else{a[o+r|0]=(n&255)>>>7<<6|n&63|(n&255)>>>6<<7}r=r+1|0;}while((r|0)<1048576);gGC(m|0,o|0,1048576)|0;r=0;while(1){if((r|0)>=1024){break L50987}x=9638528+(r<<2)|0;if((c[x>>2]|0)==(o|0)){break}else{r=r+1|0}}gGr(o);c[x>>2]=0}}while(0);m=c[2438710]|0;r=0;while(1){if((r|0)>=1024){break}y=9638528+(r<<2)|0;if((c[y>>2]|0)==0){q=38623;break}else{r=r+1|0}}L51005:do{if((q|0)==38623){r=gGq(65536)|0;c[y>>2]=r;if((r|0)==0){break}gGz(r|0,0,65536);n=0;do{a[r+n|0]=a[m+(n^16384)|0]|0;n=n+1|0;}while((n|0)<65536);gGC(m|0,r|0,65536)|0;n=0;while(1){if((n|0)>=1024){break L51005}z=9638528+(n<<2)|0;if((c[z>>2]|0)==(r|0)){break}else{n=n+1|0}}gGr(r);c[z>>2]=0}}while(0);m=c[2437708]|0;if((c[3542200]|0)==0){u=1;i=b;return u|0}n=g+108|0;c[n>>2]=0;o=g+100|0;c[o>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,2)|0;do{if((c[n>>2]|0)!=0){v=c[o>>2]|0;c[h>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](h,2,0)|0;if((v|0)<1){u=1;i=b;return u|0}if((gzL(m,0,2)|0)==0){break}else{u=1}i=b;return u|0}}while(0);m=c[2433424]|0;o=c[2437708]|0;n=c[2437710]|0;if((m|0)>0){v=0;while(1){A=v<<8;gGz(n+A|0,0,256);B=v<<10;C=0;do{D=1<<3-C;E=(c[703416+(C<<2)>>2]|0)+B|0;F=0;do{G=E+(c[3946808+(F<<2)>>2]|0)|0;H=(F<<4)+A|0;I=0;do{J=G+(c[3946872+(I<<2)>>2]|0)|0;if(((d[o+((J|0)/8|0)|0]|0)&128>>>((J&7)>>>0)|0)!=0){J=n+(H+I)|0;a[J]=(d[J]|0|D)&255}I=I+1|0;}while((I|0)<16);F=F+1|0;}while((F|0)<16);C=C+1|0;}while((C|0)<4);C=v+1|0;if((C|0)<(m|0)){v=C}else{K=0;break}}}else{K=0}while(1){if((K|0)>=1024){break}L=9638528+(K<<2)|0;if((c[L>>2]|0)==(o|0)){q=38646;break}else{K=K+1|0}}if((q|0)==38646){gGr(o);c[L>>2]=0}c[2437708]=0;v=c[3541206]|0;if((c[3542200]|0)==0){u=1;i=b;return u|0}m=e+108|0;c[m>>2]=0;n=e+100|0;c[n>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,4)|0;do{if((c[m>>2]|0)!=0){C=c[n>>2]|0;c[f>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](f,4,0)|0;if((C|0)<1){u=1;i=b;return u|0}if((gzL(v,0,4)|0)==0){break}else{u=1}i=b;return u|0}}while(0);d01();u=0;i=b;return u|0}}while(0);c[2426732]=0;u=1;i=b;return u|0}function d0c(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3960508+(b*112|0)>>2];c[a+104>>2]=c[3960512+(b*112|0)>>2];c[a+108>>2]=c[3960516+(b*112|0)>>2];d=0;return d|0}function d0d(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=3960408+(b*112|0);e=0;return e|0}function d0e(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3961528+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function d0f(){var b=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;b=i;i=i+840|0;e=b|0;f=b+112|0;g=b+120|0;j=b+232|0;k=b+240|0;l=b+352|0;m=b+360|0;n=b+472|0;o=b+480|0;p=b+592|0;q=b+600|0;r=b+712|0;s=b+720|0;t=b+832|0;c[2433424]=8192;a[642496]=1;c[2426732]=0;c[3527162]=0;c[2438710]=1048576;u=a[671688]|0;c[3541206]=1114112;v=u?1638400:1376256;c[2405666]=v;c[3527164]=v;u=a[642472]|0;c[2430196]=v+65536;w=u?v+67584|0:v+66048|0;c[2432692]=w;c[2438712]=w+8192;v=w+10240|0;c[2411684]=v;c[2437710]=v;c[2429744]=w+2107392;v=c[2429510]<<8;x=v+2107392|0;c[2433422]=w+x;c[2437712]=w+(v+2107904);v=w+(x+(u?8704:2560))|0;c[2414224]=v;u=v;v=0;while(1){if((v|0)>=1024){break}y=9638528+(v<<2)|0;if((c[y>>2]|0)==0){z=38688;break}else{v=v+1|0}}do{if((z|0)==38688){v=gGq(u)|0;c[y>>2]=v;if((v|0)==0){break}gGz(v|0,0,u|0);c[2426732]=v;gGz(v|0,0,u|0);c[3527162]=v;c[2438710]=v+1048576;x=a[671688]|0;c[3541206]=v+1114112;w=x?v+1638400|0:v+1376256|0;c[2405666]=w;c[3527164]=w;v=a[642472]|0;c[2430196]=w+65536;x=v?w+67584|0:w+66048|0;c[2432692]=x;c[2438712]=x+8192;w=x+10240|0;c[2411684]=w;c[2437710]=w;w=(c[2433424]<<8)+10240|0;c[2429744]=x+w;A=w+(c[2429510]<<8)|0;c[2433422]=x+A;c[2437712]=x+(A+512);c[2414224]=x+(A+(v?8704:2560));v=0;while(1){if((v|0)>=1024){B=0;break}C=9638528+(v<<2)|0;if((c[C>>2]|0)==0){z=38693;break}else{v=v+1|0}}do{if((z|0)==38693){v=gGq(1048576)|0;c[C>>2]=v;if((v|0)==0){B=0;break}gGz(v|0,0,1048576);B=v}}while(0);c[2437708]=B;if((R6((c[3527162]|0)+1|0,0,2)|0)!=0){D=1;i=b;return D|0}if((R6(c[3527162]|0,1,2)|0)!=0){D=1;i=b;return D|0}v=c[2438710]|0;if((c[3542200]|0)==0){D=1;i=b;return D|0}A=s+108|0;c[A>>2]=0;x=s+100|0;c[x>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](s,6)|0;do{if((c[A>>2]|0)!=0){w=c[x>>2]|0;c[t>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](t,6,0)|0;if((w|0)<1){D=1;i=b;return D|0}if((gzL(v,0,6)|0)==0){break}else{D=1}i=b;return D|0}}while(0);v=c[2437708]|0;if((c[3542200]|0)==0){D=1;i=b;return D|0}x=q+108|0;c[x>>2]=0;A=q+100|0;c[A>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](q,2)|0;do{if((c[x>>2]|0)!=0){w=c[A>>2]|0;c[r>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](r,2,0)|0;if((w|0)<1){D=1;i=b;return D|0}if((gzL(v,0,2)|0)==0){break}else{D=1}i=b;return D|0}}while(0);v=(c[2437708]|0)+262144|0;if((c[3542200]|0)==0){D=1;i=b;return D|0}A=o+108|0;c[A>>2]=0;x=o+100|0;c[x>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](o,3)|0;do{if((c[A>>2]|0)!=0){w=c[x>>2]|0;c[p>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](p,3,0)|0;if((w|0)<1){D=1;i=b;return D|0}if((gzL(v,0,3)|0)==0){break}else{D=1}i=b;return D|0}}while(0);v=(c[2437708]|0)+524288|0;if((c[3542200]|0)==0){D=1;i=b;return D|0}x=m+108|0;c[x>>2]=0;A=m+100|0;c[A>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,4)|0;do{if((c[x>>2]|0)!=0){w=c[A>>2]|0;c[n>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](n,4,0)|0;if((w|0)<1){D=1;i=b;return D|0}if((gzL(v,0,4)|0)==0){break}else{D=1}i=b;return D|0}}while(0);v=(c[2437708]|0)+786432|0;if((c[3542200]|0)==0){D=1;i=b;return D|0}A=k+108|0;c[A>>2]=0;x=k+100|0;c[x>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,5)|0;do{if((c[A>>2]|0)!=0){w=c[x>>2]|0;c[l>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](l,5,0)|0;if((w|0)<1){D=1;i=b;return D|0}if((gzL(v,0,5)|0)==0){break}else{D=1}i=b;return D|0}}while(0);v=c[2433424]|0;x=c[2437708]|0;A=c[2437710]|0;if((v|0)>0){w=0;while(1){E=w<<8;gGz(A+E|0,0,256);F=w<<10;G=0;do{H=1<<3-G;I=(c[703416+(G<<2)>>2]|0)+F|0;J=0;do{K=I+(c[691048+(J<<2)>>2]|0)|0;L=(J<<4)+E|0;M=0;do{N=K+(c[691112+(M<<2)>>2]|0)|0;if(((d[x+((N|0)/8|0)|0]|0)&128>>>((N&7)>>>0)|0)!=0){N=A+(L+M)|0;a[N]=(d[N]|0|H)&255}M=M+1|0;}while((M|0)<16);J=J+1|0;}while((J|0)<16);G=G+1|0;}while((G|0)<4);G=w+1|0;if((G|0)<(v|0)){w=G}else{O=0;break}}}else{O=0}while(1){if((O|0)>=1024){break}P=9638528+(O<<2)|0;if((c[P>>2]|0)==(x|0)){z=38729;break}else{O=O+1|0}}if((z|0)==38729){gGr(x);c[P>>2]=0}c[2437708]=0;w=c[3541206]|0;if((c[3542200]|0)==0){D=1;i=b;return D|0}v=g+108|0;c[v>>2]=0;A=g+100|0;c[A>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,7)|0;do{if((c[v>>2]|0)!=0){G=c[A>>2]|0;c[j>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](j,7,0)|0;if((G|0)<1){D=1;i=b;return D|0}if((gzL(w,0,7)|0)==0){break}else{D=1}i=b;return D|0}}while(0);w=c[2433422]|0;if((c[3542200]|0)==0){D=1;i=b;return D|0}A=e+108|0;c[A>>2]=0;v=e+100|0;c[v>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,9)|0;do{if((c[A>>2]|0)!=0){x=c[v>>2]|0;c[f>>2]=9534384;G=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[G&16383](f,9,0)|0;if((x|0)<1){D=1;i=b;return D|0}if((gzL(w,0,9)|0)==0){break}else{D=1}i=b;return D|0}}while(0);w=0;v=c[2433422]|0;while(1){A=a[v]|0;x=v+1|0;a[v]=a[x]|0;a[x]=A;A=w+1|0;if((A|0)<256){w=A;v=v+2|0}else{break}}d01();h[745421]=.08;c[2436794]=3;h[745420]=.08;c[2436792]=3;c[2407030]=102;c[2407068]=3;D=0;i=b;return D|0}}while(0);c[2426732]=0;D=1;i=b;return D|0}function d0g(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((a[9757960]|0)!=0){d0_()}a[9757970]=0;a[9757969]=0;a[9757968]=0;d=0;f=0;g=0;h=0;do{f=((a[9720808+d|0]&1)<<d|f&255)&255;g=((a[9720800+d|0]&1)<<d|g&255)&255;h=((a[9720792+d|0]&1)<<d|h&255)&255;d=d+1|0;}while((d|0)<8);a[9757968]=f;a[9757969]=g;a[9757970]=h;if((f&3)==3){h=f&-4;a[9757968]=h;i=h}else{i=f}if((i&12)==12){a[9757968]=i&-13}if((g&3)==3){i=g&-4;a[9757969]=i;j=i}else{j=g}if((j&12)==12){a[9757969]=j&-13}c[2440530]=2e5;c[2440482]=59642;c[2444087]=0;c[2444086]=0;j=c[2392]|0;if((j|0)>=0){gGz(8452240,0,((j|0)>0?(j<<2)+4|0:4)|0)}c[2113054]=0;j=c[2385548]|0;if((j|0)>0){gGz(9752472,0,((j|0)>1?j<<2:4)|0)}c[2433530]=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];j=c[3532592]|0;if((j|0)!=0){gGC(9104152,j|0,280)|0}c[2113054]=c[2113060]}j=c[2439330]|0;if((j|0)!=0){g=j;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;g=0;j=0;i=2e5;f=0;while(1){h=g+1|0;d=((ag(i,h)|0)/4|0)-f|0;c[2113056]=d;k=RG(d)|0;c[2113054]=(c[2113054]|0)+k;c[2276108]=-1;c[2113056]=-1;c[2444086]=(c[2444086]|0)+k;k=(ag(c[2440482]|0,h)|0)/4|0;d=c[2444087]|0;l=k-d|0;do{if((l|0)<1){m=0;n=d}else{if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){k=gfc(l)|0;c[2433530]=(c[2433530]|0)+k;m=k;n=c[2444087]|0;break}else{c[2433530]=(c[2433530]|0)+l;m=l;n=d;break}}}while(0);c[2444087]=n+m;d=c[2112964]|0;if((d|0)==0){o=j}else{l=a[9688]|0?133:0;k=d+(j<<1<<1)|0;gg[c[3542124]&4095](k,l);Uu(0,k,l);o=l+j|0}do{if((g|0)==2){c[8452200+(c[2394]<<2)>>2]=8195;c[2276080]=768;if((c[2276079]|0)>>>0>=768){break}RH(3)}else if((g|0)==3){c[8452200+(c[2394]<<2)>>2]=8194;c[2276080]=512;if((c[2276079]|0)>>>0>=512){break}RH(2)}else if((g|0)==1){c[8452200+(c[2394]<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0>=1024){break}RH(4)}}while(0);if((h|0)>=4){break}g=h;j=o;i=c[2440530]|0;f=c[2444086]|0}f=c[2394]|0;i=c[14130368+(f<<2)>>2]|0;if((i|0)!=0){gGC(i|0,9104152,280)|0}c[8452240+(f<<2)>>2]=c[2113054];c[2394]=-1;f=c[2112964]|0;do{if((f|0)!=0){i=a[9688]|0?534:0;j=i-o|0;g=f+(o<<1<<1)|0;if((i|0)==(o|0)){break}gg[c[3542124]&4095](g,j);Uu(0,g,j)}}while(0);o=c[1836236]|0;f=c[9757320+(o<<2)>>2]|0;if((f|0)!=0){j=f;gGC(j|0,9706056,76)|0}c[9752472+(o<<2)>>2]=c[2433530];c[14113936+(o<<2)>>2]=c[2076596];c[9669104+(o<<2)>>2]=c[3541536];c[1836236]=-1;if((c[2112968]|0)==0){return 0}o=c[2437712]|0;j=0;f=c[2430196]|0;g=o;while(1){i=e[f>>1]|0;m=i>>>5&31;c[g>>2]=i>>>10&31|i<<11&63488|(m<<3|m>>>2)<<3&2016;m=j+1|0;if((m|0)<512){j=m;f=f+2|0;g=g+4|0}else{break}}g=ag(c[2113068]|0,c[2113070]|0)|0;if((g|0)>0){f=c[2112926]|0;j=0;do{b[f+(j<<1)>>1]=240;j=j+1|0;}while((j|0)<(g|0))}d00();R8(o);return 0}function d0h(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4909268+(b*112|0)>>2];c[a+104>>2]=c[4909272+(b*112|0)>>2];c[a+108>>2]=c[4909276+(b*112|0)>>2];d=0;return d|0}function d0i(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=4909168+(b*112|0);e=0;return e|0}function d0j(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>32){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4910064+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function d0k(){var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;e=i;i=i+720|0;f=e|0;g=e+112|0;h=e+120|0;j=e+232|0;k=e+240|0;l=e+352|0;m=e+360|0;n=e+472|0;o=e+480|0;p=e+592|0;q=e+600|0;r=e+712|0;c[2433424]=12288;a[671688]=1;c[2426732]=0;c[3527162]=0;c[2438710]=1048576;c[3541206]=1114112;c[2405666]=1638400;c[3527164]=1638400;s=a[642472]|0;c[2430196]=1703936;t=s?1705984:1704448;c[2432692]=t;c[2438712]=t+8192;u=t+10240|0;c[2411684]=u;c[2437710]=u;c[2429744]=t+3155968;u=c[2429510]<<8;v=u+3155968|0;c[2433422]=t+v;c[2437712]=t+(u+3156480);u=t+(v+(s?8704:2560))|0;c[2414224]=u;s=u;u=0;while(1){if((u|0)>=1024){break}w=9638528+(u<<2)|0;if((c[w>>2]|0)==0){x=38844;break}else{u=u+1|0}}do{if((x|0)==38844){u=gGq(s)|0;c[w>>2]=u;if((u|0)==0){break}gGz(u|0,0,s|0);c[2426732]=u;gGz(u|0,0,s|0);c[3527162]=u;c[2438710]=u+1048576;v=a[671688]|0;c[3541206]=u+1114112;t=v?u+1638400|0:u+1376256|0;c[2405666]=t;c[3527164]=t;u=a[642472]|0;c[2430196]=t+65536;v=u?t+67584|0:t+66048|0;c[2432692]=v;c[2438712]=v+8192;t=v+10240|0;c[2411684]=t;c[2437710]=t;t=(c[2433424]<<8)+10240|0;c[2429744]=v+t;y=t+(c[2429510]<<8)|0;c[2433422]=v+y;c[2437712]=v+(y+512);c[2414224]=v+(y+(u?8704:2560));u=0;while(1){if((u|0)>=1024){z=0;break}A=9638528+(u<<2)|0;if((c[A>>2]|0)==0){x=38849;break}else{u=u+1|0}}do{if((x|0)==38849){u=gGq(1572864)|0;c[A>>2]=u;if((u|0)==0){z=0;break}gGz(u|0,0,1572864);z=u}}while(0);c[2437708]=z;if((R6(c[3527162]|0,0,2)|0)!=0){B=1;i=e;return B|0}if((R6((c[3527162]|0)+1|0,1,2)|0)!=0){B=1;i=e;return B|0}u=c[2438710]|0;if((c[3542200]|0)==0){B=1;i=e;return B|0}y=q+108|0;c[y>>2]=0;v=q+100|0;c[v>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](q,5)|0;do{if((c[y>>2]|0)!=0){t=c[v>>2]|0;c[r>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](r,5,0)|0;if((t|0)<1){B=1;i=e;return B|0}if((gzL(u,0,5)|0)==0){break}else{B=1}i=e;return B|0}}while(0);u=c[2437708]|0;if((c[3542200]|0)==0){B=1;i=e;return B|0}v=o+108|0;c[v>>2]=0;y=o+100|0;c[y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](o,2)|0;do{if((c[v>>2]|0)!=0){t=c[y>>2]|0;c[p>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](p,2,0)|0;if((t|0)<1){B=1;i=e;return B|0}if((gzL(u,0,2)|0)==0){break}else{B=1}i=e;return B|0}}while(0);u=(c[2437708]|0)+524288|0;if((c[3542200]|0)==0){B=1;i=e;return B|0}y=m+108|0;c[y>>2]=0;v=m+100|0;c[v>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,3)|0;do{if((c[y>>2]|0)!=0){t=c[v>>2]|0;c[n>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](n,3,0)|0;if((t|0)<1){B=1;i=e;return B|0}if((gzL(u,0,3)|0)==0){break}else{B=1}i=e;return B|0}}while(0);u=(c[2437708]|0)+1048576|0;if((c[3542200]|0)==0){B=1;i=e;return B|0}v=k+108|0;c[v>>2]=0;y=k+100|0;c[y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,4)|0;do{if((c[v>>2]|0)!=0){t=c[y>>2]|0;c[l>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](l,4,0)|0;if((t|0)<1){B=1;i=e;return B|0}if((gzL(u,0,4)|0)==0){break}else{B=1}i=e;return B|0}}while(0);u=c[2433424]|0;y=c[2437708]|0;v=c[2437710]|0;if((u|0)>0){t=0;while(1){C=t<<8;gGz(v+C|0,0,256);D=t<<10;E=0;do{F=1<<3-E;G=(c[703416+(E<<2)>>2]|0)+D|0;H=0;do{I=G+(c[3946808+(H<<2)>>2]|0)|0;J=(H<<4)+C|0;K=0;do{L=I+(c[3946872+(K<<2)>>2]|0)|0;if(((d[y+((L|0)/8|0)|0]|0)&128>>>((L&7)>>>0)|0)!=0){L=v+(J+K)|0;a[L]=(d[L]|0|F)&255}K=K+1|0;}while((K|0)<16);H=H+1|0;}while((H|0)<16);E=E+1|0;}while((E|0)<4);E=t+1|0;if((E|0)<(u|0)){t=E}else{M=0;break}}}else{M=0}while(1){if((M|0)>=1024){break}N=9638528+(M<<2)|0;if((c[N>>2]|0)==(y|0)){x=38881;break}else{M=M+1|0}}if((x|0)==38881){gGr(y);c[N>>2]=0}c[2437708]=0;t=c[3541206]|0;if((c[3542200]|0)==0){B=1;i=e;return B|0}u=h+108|0;c[u>>2]=0;v=h+100|0;c[v>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](h,6)|0;do{if((c[u>>2]|0)!=0){E=c[v>>2]|0;c[j>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](j,6,0)|0;if((E|0)<1){B=1;i=e;return B|0}if((gzL(t,0,6)|0)==0){break}else{B=1}i=e;return B|0}}while(0);t=(c[3541206]|0)+262144|0;if((c[3542200]|0)==0){B=1;i=e;return B|0}v=f+108|0;c[v>>2]=0;u=f+100|0;c[u>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,7)|0;do{if((c[v>>2]|0)!=0){y=c[u>>2]|0;c[g>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](g,7,0)|0;if((y|0)<1){B=1;i=e;return B|0}if((gzL(t,0,7)|0)==0){break}else{B=1}i=e;return B|0}}while(0);c[2424]=5750;fxU(0,425984);if((c[2394]|0)==0){O=c[2112932]|0}else{c[2394]=0;t=c[3532596]|0;c[2112932]=t;u=c[3532592]|0;if((u|0)!=0){gGC(9104152,u|0,280)|0}c[2113054]=c[2113060];O=t}t=c[3527162]|0;u=O|0;v=0;while(1){y=t+v|0;c[u>>2]=y;c[u+131072>>2]=y;y=v+1024|0;if(y>>>0>262143){break}else{u=u+4|0;v=y}}v=c[3527164]|0;u=O+4096|0;t=1048576;while(1){y=v+(t-1048576)|0;c[u>>2]=y;c[u+65536>>2]=y;c[u+131072>>2]=y;y=t+1024|0;if(y>>>0>1114111){break}else{u=u+4|0;t=y}}t=c[2430196]|0;c[O+24576>>2]=t;c[O+90112>>2]=t;c[O+155648>>2]=t;t=c[2432692]|0;c[O+28672>>2]=t;c[O+94208>>2]=t;c[O+159744>>2]=t;u=t+1024|0;c[O+28676>>2]=u;c[O+94212>>2]=u;c[O+159748>>2]=u;u=t+2048|0;c[O+28680>>2]=u;c[O+94216>>2]=u;c[O+159752>>2]=u;u=t+3072|0;c[O+28684>>2]=u;c[O+94220>>2]=u;c[O+159756>>2]=u;u=t+4096|0;c[O+28688>>2]=u;c[O+94224>>2]=u;c[O+159760>>2]=u;u=t+5120|0;c[O+28692>>2]=u;c[O+94228>>2]=u;c[O+159764>>2]=u;u=t+6144|0;c[O+28696>>2]=u;c[O+94232>>2]=u;c[O+159768>>2]=u;u=t+7168|0;c[O+28700>>2]=u;c[O+94236>>2]=u;c[O+159772>>2]=u;c[O+196608>>2]=890;c[O+196688>>2]=632;c[O+196648>>2]=1472;c[O+196728>>2]=3236;u=c[3532592]|0;if((u|0)!=0){gGC(u|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);u=c[2439330]|0;t=(u|0)==0;if(!t){v=u;gGC(9706056,v|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];v=c[3528484]|0;c[2076596]=v;y=c[2417276]|0;c[3541536]=y;c[1836236]=0;E=c[2438710]|0;C=0;D=0;while(1){c[u+76+(D<<2)>>2]=E+(D<<8);H=C+1&65535;if((H&65535)>127){P=0;Q=0;break}else{C=H;D=H&65535}}while(1){D=E+(Q<<8)|0;c[u+76+(Q+512<<2)>>2]=D;c[u+76+(Q+768<<2)>>2]=D;D=P+1&65535;if((D&65535)>127){break}else{P=D;Q=D&65535}}E=c[2438712]|0;c[u+588>>2]=E;D=E+256|0;c[u+592>>2]=D;C=E+512|0;c[u+596>>2]=C;H=E+768|0;c[u+600>>2]=H;F=E+1024|0;c[u+604>>2]=F;G=E+1280|0;c[u+608>>2]=G;K=E+1536|0;c[u+612>>2]=K;J=E+1792|0;c[u+616>>2]=J;c[u+1612>>2]=E;c[u+1616>>2]=D;c[u+1620>>2]=C;c[u+1624>>2]=H;c[u+1628>>2]=F;c[u+1632>>2]=G;c[u+1636>>2]=K;c[u+1640>>2]=J;c[u+2636>>2]=E;c[u+3660>>2]=E;c[u+2640>>2]=D;c[u+3664>>2]=D;c[u+2644>>2]=C;c[u+3668>>2]=C;c[u+2648>>2]=H;c[u+3672>>2]=H;c[u+2652>>2]=F;c[u+3676>>2]=F;c[u+2656>>2]=G;c[u+3680>>2]=G;c[u+2660>>2]=K;c[u+3684>>2]=K;c[u+2664>>2]=J;c[u+3688>>2]=J;c[u+4172>>2]=2830;c[u+4176>>2]=2026;if(!t){J=u;gGC(J|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=v;c[2417276]=y;c[1836236]=-1;Ux(0,7575,0);c[2407030]=256;c[2407068]=3;J=c[642608+(c[2436]<<2)>>2]|0;K=c[J+128>>2]|0;if((c[J+52>>2]&4|0)==0){c[2113068]=K;G=c[J+132>>2]|0;c[2113070]=G;c[2443814]=K;c[2440436]=G;R=K;S=G}else{c[2113070]=K;G=c[J+132>>2]|0;c[2113068]=G;c[2440436]=K;c[2443814]=G;R=G;S=K}K=ag(R<<1,S)|0;G=gGq(K)|0;c[2112926]=G;if((G|0)!=0){gGz(G|0,0,K|0)}d0_();B=0;i=e;return B|0}}while(0);c[2426732]=0;B=1;i=e;return B|0}function d0l(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;if((a[9757960]|0)!=0){d0_()}a[9757970]=0;a[9757969]=0;a[9757968]=0;f=0;g=0;h=0;i=0;do{g=((a[9720808+f|0]&1)<<f|g&255)&255;h=((a[9720800+f|0]&1)<<f|h&255)&255;i=((a[9720792+f|0]&1)<<f|i&255)&255;f=f+1|0;}while((f|0)<8);a[9757968]=g;a[9757969]=h;a[9757970]=i;if((g&3)==3){i=g&-4;a[9757968]=i;j=i}else{j=g}if((j&12)==12){a[9757968]=j&-13}if((h&3)==3){j=h&-4;a[9757969]=j;k=j}else{k=h}if((k&12)==12){a[9757969]=k&-13}c[2440530]=266666;c[2440482]=66666;c[2444087]=0;c[2444086]=0;k=c[2392]|0;if((k|0)>=0){gGz(8452240,0,((k|0)>0?(k<<2)+4|0:4)|0)}c[2113054]=0;k=c[2385548]|0;if((k|0)>0){gGz(9752472,0,((k|0)>1?k<<2:4)|0)}c[2433530]=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];k=c[3532592]|0;if((k|0)!=0){gGC(9104152,k|0,280)|0}c[2113054]=c[2113060]}k=c[2439330]|0;if((k|0)!=0){h=k;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;h=0;k=0;j=266666;g=0;while(1){i=h+1|0;f=((ag(j,i)|0)/4|0)-g|0;c[2113056]=f;l=RG(f)|0;c[2113054]=(c[2113054]|0)+l;c[2276108]=-1;c[2113056]=-1;c[2444086]=(c[2444086]|0)+l;l=(ag(c[2440482]|0,i)|0)/4|0;f=c[2444087]|0;m=l-f|0;do{if((m|0)<1){n=0;o=f}else{if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){l=gfc(m)|0;c[2433530]=(c[2433530]|0)+l;n=l;o=c[2444087]|0;break}else{c[2433530]=(c[2433530]|0)+m;n=m;o=f;break}}}while(0);c[2444087]=o+n;f=(h|0)==2;if(f){a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0}m=c[2112964]|0;if((m|0)==0){p=k}else{l=a[9688]|0?133:0;Uu(0,m+(k<<1<<1)|0,l);p=l+k|0}do{if((h|0)==1){c[8452200+(c[2394]<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0>=1024){break}RH(4)}}while(0);do{if(f){c[8452200+(c[2394]<<2)>>2]=8195;c[2276080]=768;if((c[2276079]|0)>>>0>=768){break}RH(3)}else{if((h|0)!=3){break}c[8452200+(c[2394]<<2)>>2]=8194;c[2276080]=512;if((c[2276079]|0)>>>0>=512){break}RH(2)}}while(0);if((i|0)>=4){break}h=i;k=p;j=c[2440530]|0;g=c[2444086]|0}g=c[2394]|0;j=c[14130368+(g<<2)>>2]|0;if((j|0)!=0){gGC(j|0,9104152,280)|0}c[8452240+(g<<2)>>2]=c[2113054];c[2394]=-1;g=c[1836236]|0;j=c[9757320+(g<<2)>>2]|0;if((j|0)!=0){k=j;gGC(k|0,9706056,76)|0}c[9752472+(g<<2)>>2]=c[2433530];c[14113936+(g<<2)>>2]=c[2076596];c[9669104+(g<<2)>>2]=c[3541536];c[1836236]=-1;g=c[2112964]|0;do{if((g|0)!=0){k=a[9688]|0?534:0;if((k|0)==(p|0)){break}Uu(0,g+(p<<1<<1)|0,k-p|0)}}while(0);if((c[2112968]|0)==0){return 0}p=c[2437712]|0;g=0;k=c[2430196]|0;j=p;while(1){h=e[k>>1]|0;n=h>>>5&31;c[j>>2]=h>>>10&31|h<<11&63488|(n<<3|n>>>2)<<3&2016;n=g+1|0;if((n|0)<512){g=n;k=k+2|0;j=j+4|0}else{break}}j=ag(c[2113068]|0,c[2113070]|0)|0;if((j|0)>0){k=c[2112926]|0;g=0;do{b[k+(g<<1)>>1]=240;g=g+1|0;}while((g|0)<(j|0))}j=c[2432692]|0;g=c[2112926]|0;k=0;do{n=a[j+(k|8)|0]|0;h=n&255;o=d[j+(k|10)|0]|0;f=d[j+(k|14)|0]|0;l=f&128;m=f<<1&128;q=f<<8&16128|d[j+(k|12)|0];f=(d[j+(k|6)|0]|0)>>>4^15;r=o-16|0;do{if((n-16&255)<224){if((o-32|0)>>>0>=193){s=39002;break}t=(l|0)!=0;u=c[2437710]|0;if((m|0)==0){if(t){SI(g,q,h,r,f,4,0,0,u);break}else{SG(g,q,h,r,f,4,0,0,u);break}}else{if(t){SM(g,q,h,r,f,4,0,0,u);break}else{SK(g,q,h,r,f,4,0,0,u);break}}}else{s=39002}}while(0);do{if((s|0)==39002){s=0;o=(l|0)!=0;n=c[2437710]|0;if((m|0)==0){if(o){SJ(g,q,h,r,f,4,0,0,n);break}else{SH(g,q,h,r,f,4,0,0,n);break}}else{if(o){SN(g,q,h,r,f,4,0,0,n);break}else{SL(g,q,h,r,f,4,0,0,n);break}}}}while(0);k=k+16|0;}while((k|0)<8192);R8(p);return 0}function d0m(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>7){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3277588+(b*112|0)>>2];c[a+104>>2]=c[3277592+(b*112|0)>>2];c[a+108>>2]=c[3277596+(b*112|0)>>2];d=0;return d|0}function d0n(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<8&(d|0)==0)){e=1;return e|0}c[a>>2]=3277488+(b*112|0);e=0;return e|0}function d0o(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3865476+(b*112|0)>>2];c[a+104>>2]=c[3865480+(b*112|0)>>2];c[a+108>>2]=c[3865484+(b*112|0)>>2];d=0;return d|0}function d0p(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=3865376+(b*112|0);e=0;return e|0}function d0q(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>36){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3866384+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function d0r(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;e=i;i=i+840|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;n=e+360|0;o=e+472|0;p=e+480|0;q=e+592|0;r=e+600|0;s=e+712|0;t=e+720|0;u=e+832|0;c[2433424]=4096;c[2429510]=8192;a[642472]=1;c[2426732]=0;c[3527162]=0;c[2438710]=1048576;v=a[671688]|0;c[3541206]=1114112;w=v?1638400:1376256;c[2405666]=w;c[3527164]=w;c[2430196]=w+65536;c[2432692]=w+67584;c[2438712]=w+75776;v=w+77824|0;c[2411684]=v;c[2437710]=v;c[2429744]=w+1126400;c[2433422]=w+3223552;c[2437712]=w+3224064;v=w+3232256|0;c[2414224]=v;w=v;v=0;while(1){if((v|0)>=1024){break}x=9638528+(v<<2)|0;if((c[x>>2]|0)==0){y=39048;break}else{v=v+1|0}}do{if((y|0)==39048){v=gGq(w)|0;c[x>>2]=v;if((v|0)==0){break}gGz(v|0,0,w|0);c[2426732]=v;gGz(v|0,0,w|0);c[3527162]=v;c[2438710]=v+1048576;z=a[671688]|0;c[3541206]=v+1114112;A=z?v+1638400|0:v+1376256|0;c[2405666]=A;c[3527164]=A;v=a[642472]|0;c[2430196]=A+65536;z=v?A+67584|0:A+66048|0;c[2432692]=z;c[2438712]=z+8192;A=z+10240|0;c[2411684]=A;c[2437710]=A;A=(c[2433424]<<8)+10240|0;c[2429744]=z+A;B=A+(c[2429510]<<8)|0;c[2433422]=z+B;c[2437712]=z+(B+512);c[2414224]=z+(B+(v?8704:2560));v=0;while(1){if((v|0)>=1024){C=0;break}D=9638528+(v<<2)|0;if((c[D>>2]|0)==0){y=39053;break}else{v=v+1|0}}do{if((y|0)==39053){v=gGq(2097152)|0;c[D>>2]=v;if((v|0)==0){C=0;break}gGz(v|0,0,2097152);C=v}}while(0);c[2437708]=C;if((R6(c[3527162]|0,0,2)|0)!=0){E=1;i=e;return E|0}if((R6((c[3527162]|0)+1|0,1,2)|0)!=0){E=1;i=e;return E|0}v=c[2438710]|0;if((c[3542200]|0)==0){E=1;i=e;return E|0}B=t+108|0;c[B>>2]=0;z=t+100|0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,7)|0;do{if((c[B>>2]|0)!=0){A=c[z>>2]|0;c[u>>2]=9534384;F=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[F&16383](u,7,0)|0;if((A|0)<1){E=1;i=e;return E|0}if((gzL(v,0,7)|0)==0){break}else{E=1}i=e;return E|0}}while(0);v=c[2437708]|0;if((c[3542200]|0)==0){E=1;i=e;return E|0}z=r+108|0;c[z>>2]=0;B=r+100|0;c[B>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,2)|0;do{if((c[z>>2]|0)!=0){A=c[B>>2]|0;c[s>>2]=9534384;F=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[F&16383](s,2,0)|0;if((A|0)<1){E=1;i=e;return E|0}if((gzL(v,0,2)|0)==0){break}else{E=1}i=e;return E|0}}while(0);v=c[2433424]|0;B=c[2437708]|0;z=c[2437710]|0;if((v|0)>0){A=0;do{F=A<<8;gGz(z+F|0,0,256);G=A<<10;H=0;do{I=1<<3-H;J=(c[703416+(H<<2)>>2]|0)+G|0;K=0;do{L=J+(c[3946808+(K<<2)>>2]|0)|0;M=(K<<4)+F|0;N=0;do{O=L+(c[3946872+(N<<2)>>2]|0)|0;if(((d[B+((O|0)/8|0)|0]|0)&128>>>((O&7)>>>0)|0)!=0){O=z+(M+N)|0;a[O]=(d[O]|0|I)&255}N=N+1|0;}while((N|0)<16);K=K+1|0;}while((K|0)<16);H=H+1|0;}while((H|0)<4);A=A+1|0;}while((A|0)<(v|0))}gGz(B|0,0,2097152);if((c[3542200]|0)==0){E=1;i=e;return E|0}v=p+108|0;c[v>>2]=0;A=p+100|0;c[A>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,3)|0;do{if((c[v>>2]|0)!=0){z=c[A>>2]|0;c[q>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](q,3,0)|0;if((z|0)<1){E=1;i=e;return E|0}if((gzL(B,0,3)|0)==0){break}else{E=1}i=e;return E|0}}while(0);B=(c[2437708]|0)+524288|0;if((c[3542200]|0)==0){E=1;i=e;return E|0}A=n+108|0;c[A>>2]=0;v=n+100|0;c[v>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](n,4)|0;do{if((c[A>>2]|0)!=0){z=c[v>>2]|0;c[o>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](o,4,0)|0;if((z|0)<1){E=1;i=e;return E|0}if((gzL(B,0,4)|0)==0){break}else{E=1}i=e;return E|0}}while(0);B=(c[2437708]|0)+1048576|0;if((c[3542200]|0)==0){E=1;i=e;return E|0}v=l+108|0;c[v>>2]=0;A=l+100|0;c[A>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,5)|0;do{if((c[v>>2]|0)!=0){z=c[A>>2]|0;c[m>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](m,5,0)|0;if((z|0)<1){E=1;i=e;return E|0}if((gzL(B,0,5)|0)==0){break}else{E=1}i=e;return E|0}}while(0);B=(c[2437708]|0)+1572864|0;if((c[3542200]|0)==0){E=1;i=e;return E|0}A=j+108|0;c[A>>2]=0;v=j+100|0;c[v>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,6)|0;do{if((c[A>>2]|0)!=0){z=c[v>>2]|0;c[k>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](k,6,0)|0;if((z|0)<1){E=1;i=e;return E|0}if((gzL(B,0,6)|0)==0){break}else{E=1}i=e;return E|0}}while(0);B=c[2429510]|0;v=c[2437708]|0;A=c[2429744]|0;if((B|0)>0){z=0;while(1){H=z<<8;gGz(A+H|0,0,256);F=z<<10;G=0;do{K=1<<7-G;I=(c[684e3+(G<<2)>>2]|0)+F|0;J=0;do{N=I+(c[3946808+(J<<2)>>2]|0)|0;M=(J<<4)+H|0;L=0;do{O=N+(c[3946872+(L<<2)>>2]|0)|0;if(((d[v+((O|0)/8|0)|0]|0)&128>>>((O&7)>>>0)|0)!=0){O=A+(M+L)|0;a[O]=(d[O]|0|K)&255}L=L+1|0;}while((L|0)<16);J=J+1|0;}while((J|0)<16);G=G+1|0;}while((G|0)<8);G=z+1|0;if((G|0)<(B|0)){z=G}else{P=0;break}}}else{P=0}while(1){if((P|0)>=1024){break}Q=9638528+(P<<2)|0;if((c[Q>>2]|0)==(v|0)){y=39103;break}else{P=P+1|0}}if((y|0)==39103){gGr(v);c[Q>>2]=0}c[2437708]=0;z=c[3541206]|0;if((c[3542200]|0)==0){E=1;i=e;return E|0}B=f+108|0;c[B>>2]=0;A=f+100|0;c[A>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,8)|0;do{if((c[B>>2]|0)!=0){G=c[A>>2]|0;c[g>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](g,8,0)|0;if((G|0)<1){E=1;i=e;return E|0}if((gzL(z,0,8)|0)==0){break}else{E=1}i=e;return E|0}}while(0);c[2424]=5750;fxU(0,425984);if((c[2394]|0)==0){R=c[2112932]|0}else{c[2394]=0;z=c[3532596]|0;c[2112932]=z;A=c[3532592]|0;if((A|0)!=0){gGC(9104152,A|0,280)|0}c[2113054]=c[2113060];R=z}z=c[3527162]|0;A=R|0;B=0;while(1){v=z+B|0;c[A>>2]=v;c[A+131072>>2]=v;v=B+1024|0;if(v>>>0>262143){break}else{A=A+4|0;B=v}}B=c[3527164]|0;A=R+4096|0;z=1048576;while(1){v=B+(z-1048576)|0;c[A>>2]=v;c[A+65536>>2]=v;c[A+131072>>2]=v;v=z+1024|0;if(v>>>0>1114111){break}else{A=A+4|0;z=v}}z=c[2430196]|0;c[R+40960>>2]=z;c[R+106496>>2]=z;c[R+172032>>2]=z;A=z+1024|0;c[R+40964>>2]=A;c[R+106500>>2]=A;c[R+172036>>2]=A;A=c[2432692]|0;c[R+45056>>2]=A;c[R+110592>>2]=A;c[R+176128>>2]=A;z=A+1024|0;c[R+45060>>2]=z;c[R+110596>>2]=z;c[R+176132>>2]=z;z=A+2048|0;c[R+45064>>2]=z;c[R+110600>>2]=z;c[R+176136>>2]=z;z=A+3072|0;c[R+45068>>2]=z;c[R+110604>>2]=z;c[R+176140>>2]=z;z=A+4096|0;c[R+45072>>2]=z;c[R+110608>>2]=z;c[R+176144>>2]=z;z=A+5120|0;c[R+45076>>2]=z;c[R+110612>>2]=z;c[R+176148>>2]=z;z=A+6144|0;c[R+45080>>2]=z;c[R+110616>>2]=z;c[R+176152>>2]=z;z=A+7168|0;c[R+45084>>2]=z;c[R+110620>>2]=z;c[R+176156>>2]=z;c[R+196608>>2]=3532;c[R+196688>>2]=1128;c[R+196648>>2]=752;c[R+196728>>2]=360;z=c[3532592]|0;if((z|0)!=0){gGC(z|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);z=c[2439330]|0;A=(z|0)==0;if(!A){B=z;gGC(9706056,B|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];B=c[3528484]|0;c[2076596]=B;v=c[2417276]|0;c[3541536]=v;c[1836236]=0;G=c[2438710]|0;H=0;F=0;while(1){c[z+76+(F<<2)>>2]=G+(F<<8);J=H+1&65535;if((J&65535)>127){S=0;T=0;break}else{H=J;F=J&65535}}while(1){F=G+(T<<8)|0;c[z+76+(T+512<<2)>>2]=F;c[z+76+(T+768<<2)>>2]=F;F=S+1&65535;if((F&65535)>127){break}else{S=F;T=F&65535}}G=c[2438712]|0;c[z+588>>2]=G;F=G+256|0;c[z+592>>2]=F;H=G+512|0;c[z+596>>2]=H;J=G+768|0;c[z+600>>2]=J;K=G+1024|0;c[z+604>>2]=K;I=G+1280|0;c[z+608>>2]=I;L=G+1536|0;c[z+612>>2]=L;M=G+1792|0;c[z+616>>2]=M;c[z+1612>>2]=G;c[z+1616>>2]=F;c[z+1620>>2]=H;c[z+1624>>2]=J;c[z+1628>>2]=K;c[z+1632>>2]=I;c[z+1636>>2]=L;c[z+1640>>2]=M;c[z+2636>>2]=G;c[z+3660>>2]=G;c[z+2640>>2]=F;c[z+3664>>2]=F;c[z+2644>>2]=H;c[z+3668>>2]=H;c[z+2648>>2]=J;c[z+3672>>2]=J;c[z+2652>>2]=K;c[z+3676>>2]=K;c[z+2656>>2]=I;c[z+3680>>2]=I;c[z+2660>>2]=L;c[z+3684>>2]=L;c[z+2664>>2]=M;c[z+3688>>2]=M;c[z+4172>>2]=3048;c[z+4176>>2]=1856;c[z+4180>>2]=1988;c[z+4184>>2]=874;if(!A){M=z;gGC(M|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=B;c[2417276]=v;c[1836236]=-1;UL(3e6,1916,1522,0);c[2438224]=4e6;c[2433522]=3416;c[2406672]=1752;c[3528468]=9362;c[2443842]=511;h[745398]=1.0;a[3203264]=1;Ux(0,7575,1);c[2407030]=256;c[2407068]=3;M=c[642608+(c[2436]<<2)>>2]|0;L=c[M+128>>2]|0;if((c[M+52>>2]&4|0)==0){c[2113068]=L;I=c[M+132>>2]|0;c[2113070]=I;c[2443814]=L;c[2440436]=I;U=L;V=I}else{c[2113070]=L;I=c[M+132>>2]|0;c[2113068]=I;c[2440436]=L;c[2443814]=I;U=I;V=L}L=ag(U<<1,V)|0;I=gGq(L)|0;c[2112926]=I;if((I|0)!=0){gGz(I|0,0,L|0)}d0_();E=0;i=e;return E|0}}while(0);c[2426732]=0;E=1;i=e;return E|0}function d0s(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;if((a[9757960]|0)!=0){d0_()}a[9757970]=0;a[9757969]=0;a[9757968]=0;f=0;g=0;h=0;i=0;do{g=((a[9720808+f|0]&1)<<f|g&255)&255;h=((a[9720800+f|0]&1)<<f|h&255)&255;i=((a[9720792+f|0]&1)<<f|i&255)&255;f=f+1|0;}while((f|0)<8);a[9757968]=g;a[9757969]=h;a[9757970]=i;if((g&3)==3){i=g&-4;a[9757968]=i;j=i}else{j=g}if((j&12)==12){a[9757968]=j&-13}if((h&3)==3){j=h&-4;a[9757969]=j;k=j}else{k=h}if((k&12)==12){a[9757969]=k&-13}k=c[2392]|0;if((k|0)>=0){gGz(8452240,0,((k|0)>0?(k<<2)+4|0:4)|0)}c[2113054]=0;k=c[2385548]|0;if((k|0)>0){gGz(9752472,0,((k|0)>1?k<<2:4)|0)}c[2433530]=0;if((c[2394]|0)==0){l=0}else{c[2394]=0;c[2112932]=c[3532596];k=c[3532592]|0;if((k|0)!=0){gGC(9104152,k|0,280)|0}k=c[2113060]|0;c[2113054]=k;l=k}k=c[2439330]|0;if((k|0)!=0){h=k;gGC(9706056,h|0,76)|0}b[4853030]=c[2426515]&65535;h=c[2438118]|0;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;k=l+(c[2444086]|0)|0;c[2113054]=k;c[2433530]=h+(c[2444087]|0);c[2440530]=266666;c[2440482]=66666;h=66666-k-(c[2113056]|0)+(c[2276108]|0)|0;c[2113056]=h;k=RG(h)|0;h=(c[2113054]|0)+k|0;c[2113054]=h;c[2276108]=-1;k=((c[2440530]<<1|0)/4|0)-h|0;c[2113056]=k;h=RG(k)|0;k=(c[2113054]|0)+h|0;c[2113054]=k;c[2276108]=-1;c[2113056]=-1;c[8452200+(c[2394]<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0<1024){RH(4);m=c[2113054]|0;n=c[2113056]|0;o=c[2276108]|0}else{m=k;n=-1;o=-1}k=(((c[2440530]|0)*3|0|0)/4|0)-m-n+o|0;c[2113056]=k;o=RG(k)|0;k=(c[2113054]|0)+o|0;c[2113054]=k;c[2276108]=-1;c[2113056]=-1;c[8452200+(c[2394]<<2)>>2]=8195;c[2276080]=768;if((c[2276079]|0)>>>0<768){RH(3);p=c[2113054]|0;q=c[2113056]|0;r=c[2276108]|0}else{p=k;q=-1;r=-1}k=(c[2440530]|0)-p-q+r|0;c[2113056]=k;r=RG(k)|0;k=(c[2113054]|0)+r|0;c[2113054]=k;c[2276108]=-1;c[2113056]=-1;c[8452200+(c[2394]<<2)>>2]=8194;c[2276080]=512;if((c[2276079]|0)>>>0<512){RH(2);s=c[2113054]|0;t=c[2113056]|0;u=c[2276108]|0}else{s=k;t=-1;u=-1}c[2438216]=t+s-u;u=c[2440482]|0;s=gGU(u,(u|0)<0|0?-1:0,2048e6,0)|0;t=c[2438224]|0;k=gGS(s,K,t,(t|0)<0|0?-1:0)|0;t=k;UF(u)|0;u=c[2443826]|0;if((u|0)<1073676288){c[2443826]=u-t}u=c[2443827]|0;if((u|0)<1073676288){c[2443827]=u-t}u=(c[3528508]|0)-t|0;c[3528508]=(u|0)<0?0:u;u=c[2112964]|0;if((u|0)!=0){gg[c[3542112]&4095](u,a[9688]|0?534:0);Uu(0,c[2112964]|0,a[9688]|0?534:0)}u=c[2113054]|0;c[2444086]=(c[2113056]|0)+u-(c[2276108]|0)-(c[2440530]|0);t=c[2433530]|0;k=c[2076596]|0;c[2444087]=(c[2426530]|0)+t-k-(c[2440482]|0);s=c[1836236]|0;r=c[9757320+(s<<2)>>2]|0;if((r|0)!=0){q=r;gGC(q|0,9706056,76)|0}c[9752472+(s<<2)>>2]=t;c[14113936+(s<<2)>>2]=k;c[9669104+(s<<2)>>2]=c[3541536];c[1836236]=-1;s=c[2394]|0;k=c[14130368+(s<<2)>>2]|0;if((k|0)!=0){gGC(k|0,9104152,280)|0}c[8452240+(s<<2)>>2]=u;c[2394]=-1;if((c[2112968]|0)==0){return 0}u=c[2437712]|0;s=0;k=c[2430196]|0;t=u;while(1){q=e[k>>1]|0;r=q>>>5&31;c[t>>2]=q>>>10&31|q<<11&63488|(r<<3|r>>>2)<<3&2016;r=s+1|0;if((r|0)<2048){s=r;k=k+2|0;t=t+4|0}else{break}}t=ag(c[2113068]|0,c[2113070]|0)|0;if((t|0)>0){k=c[2112926]|0;s=0;do{b[k+(s<<1)>>1]=240;s=s+1|0;}while((s|0)<(t|0))}t=c[2432692]|0;s=c[2112926]|0;k=0;do{r=a[t+(k|9)|0]|0;q=r&255;p=k|8;o=d[t+(k|11)|0]|0;n=k|10;m=t+(k|7)|0;h=k|6;l=a[m]&3;j=d[t+(k|15)|0]|0;g=k|14;i=k|12;f=j&128;v=j<<1&128;w=j<<8&16128|d[t+(k|13)|0];j=o-16|0;do{if((r-16&255)<224){if((o-32|0)>>>0>=193){x=39191;break}y=(f|0)!=0;z=c[2429744]|0;if((v|0)==0){if(y){SI(s,w,q,j,l,8,0,0,z);break}else{SG(s,w,q,j,l,8,0,0,z);break}}else{if(y){SM(s,w,q,j,l,8,0,0,z);break}else{SK(s,w,q,j,l,8,0,0,z);break}}}else{x=39191}}while(0);do{if((x|0)==39191){x=0;o=(f|0)!=0;r=c[2429744]|0;if((v|0)==0){if(o){SJ(s,w,q,j,l,8,0,0,r);break}else{SH(s,w,q,j,l,8,0,0,r);break}}else{if(o){SN(s,w,q,j,l,8,0,0,r);break}else{SL(s,w,q,j,l,8,0,0,r);break}}}}while(0);l=a[t+p|0]|0;j=l&255;q=d[t+n|0]|0;w=d[t+g|0]|0;v=w&128;f=w<<1&128;r=w<<8&16128|d[t+i|0];w=(d[m]<<8|d[t+h|0])>>>4&63^63;o=q-16|0;do{if((l-16&255)<224){if((q-32|0)>>>0>=193){x=39207;break}z=(v|0)!=0;y=c[2437710]|0;if((f|0)==0){if(z){SI(s,r,j,o,w,4,0,0,y);break}else{SG(s,r,j,o,w,4,0,0,y);break}}else{if(z){SM(s,r,j,o,w,4,0,0,y);break}else{SK(s,r,j,o,w,4,0,0,y);break}}}else{x=39207}}while(0);do{if((x|0)==39207){x=0;q=(v|0)!=0;l=c[2437710]|0;if((f|0)==0){if(q){SJ(s,r,j,o,w,4,0,0,l);break}else{SH(s,r,j,o,w,4,0,0,l);break}}else{if(q){SN(s,r,j,o,w,4,0,0,l);break}else{SL(s,r,j,o,w,4,0,0,l);break}}}}while(0);k=k+16|0;}while((k|0)<8192);R8(u);return 0}function d0t(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>3){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3419228+(b*112|0)>>2];c[a+104>>2]=c[3419232+(b*112|0)>>2];c[a+108>>2]=c[3419236+(b*112|0)>>2];d=0;return d|0}function d0u(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<4&(d|0)==0)){e=1;return e|0}c[a>>2]=3419128+(b*112|0);e=0;return e|0}function d0v(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1191912+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function d0w(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>44){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3419576+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function d0x(){var e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;e=i;i=i+360|0;f=e|0;g=e+112|0;j=e+120|0;k=e+232|0;l=e+240|0;m=e+352|0;c[2424]=5750;c[2433424]=4096;c[2426732]=0;c[3527162]=0;c[2438710]=262144;n=a[671680]|0?327680:294912;o=n|0;c[2405666]=o;c[3527164]=o;c[2430196]=n|16384;c[2432692]=n|16896;c[2438712]=n|25088;o=n|27136|0;c[2411684]=o;c[2437710]=o;o=n|1075712;c[2437712]=o;n=o+2048|0;c[2414224]=n;o=n;n=0;while(1){if((n|0)>=1024){break}p=9638528+(n<<2)|0;if((c[p>>2]|0)==0){q=39269;break}else{n=n+1|0}}do{if((q|0)==39269){n=gGq(o)|0;c[p>>2]=n;if((n|0)==0){break}gGz(n|0,0,o|0);c[2426732]=n;gGz(n|0,0,o|0);c[3527162]=n;c[2438710]=n+262144;r=a[671680]|0?327680:294912;s=n+r|0;c[2405666]=s;c[3527164]=s;c[2430196]=n+(r|16384);c[2432692]=n+(r|16896);c[2438712]=n+(r|25088);s=r|27136;r=n+s|0;c[2411684]=r;c[2437710]=r;r=s+(c[2433424]<<8)|0;c[2437712]=n+r;c[2414224]=n+(r+2048);r=0;while(1){if((r|0)>=1024){t=0;break}u=9638528+(r<<2)|0;if((c[u>>2]|0)==0){q=39274;break}else{r=r+1|0}}do{if((q|0)==39274){r=gGq(524288)|0;c[u>>2]=r;if((r|0)==0){t=0;break}gGz(r|0,0,524288);t=r}}while(0);c[2437708]=t;r=a[671680]|0;n=(R6((c[3527162]|0)+1|0,0,2)|0)!=0;L51906:do{if(r){if(n){v=1;i=e;return v|0}if((R6(c[3527162]|0,1,2)|0)!=0){v=1;i=e;return v|0}if((R6((c[3527162]|0)+131073|0,2,2)|0)!=0){v=1;i=e;return v|0}if((R6((c[3527162]|0)+131072|0,3,2)|0)!=0){v=1;i=e;return v|0}s=c[2438710]|0;if((c[3542200]|0)==0){v=1;i=e;return v|0}w=l+108|0;c[w>>2]=0;x=l+100|0;c[x>>2]=0;y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[y&16383](l,12)|0;do{if((c[w>>2]|0)!=0){y=c[x>>2]|0;c[m>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](m,12,0)|0;if((y|0)<1){v=1;i=e;return v|0}if((gzL(s,0,12)|0)==0){break}else{v=1}i=e;return v|0}}while(0);if((R6(c[2437708]|0,4,2)|0)!=0){v=1;i=e;return v|0}if((R6((c[2437708]|0)+1|0,5,2)|0)!=0){v=1;i=e;return v|0}if((R6((c[2437708]|0)+131072|0,6,2)|0)!=0){v=1;i=e;return v|0}if((R6((c[2437708]|0)+131073|0,7,2)|0)!=0){v=1;i=e;return v|0}if((R6((c[2437708]|0)+262144|0,8,2)|0)!=0){v=1;i=e;return v|0}if((R6((c[2437708]|0)+262145|0,9,2)|0)!=0){v=1;i=e;return v|0}if((R6((c[2437708]|0)+393216|0,10,2)|0)!=0){v=1;i=e;return v|0}if((R6((c[2437708]|0)+393217|0,11,2)|0)!=0){v=1;i=e;return v|0}s=c[2433424]|0;x=c[2437708]|0;w=c[2437710]|0;if((s|0)>0){y=0;while(1){z=y<<8;gGz(w+z|0,0,256);A=y<<10;B=0;do{C=1<<3-B;D=(c[703416+(B<<2)>>2]|0)+A|0;E=0;do{F=D+(c[611904+(E<<2)>>2]|0)|0;G=(E<<4)+z|0;H=0;do{I=F+(c[699848+(H<<2)>>2]|0)|0;if(((d[x+((I|0)/8|0)|0]|0)&128>>>((I&7)>>>0)|0)!=0){I=w+(G+H)|0;a[I]=(d[I]|0|C)&255}H=H+1|0;}while((H|0)<16);E=E+1|0;}while((E|0)<16);B=B+1|0;}while((B|0)<4);B=y+1|0;if((B|0)<(s|0)){y=B}else{J=0;break}}}else{J=0}while(1){if((J|0)>=1024){break L51906}K=9638528+(J<<2)|0;if((c[K>>2]|0)==(x|0)){break}else{J=J+1|0}}gGr(x);c[K>>2]=0}else{if(n){v=1;i=e;return v|0}if((R6(c[3527162]|0,1,2)|0)!=0){v=1;i=e;return v|0}y=c[2438710]|0;if((c[3542200]|0)==0){v=1;i=e;return v|0}s=j+108|0;c[s>>2]=0;w=j+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,3)|0;do{if((c[s>>2]|0)!=0){B=c[w>>2]|0;c[k>>2]=9534384;z=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[z&16383](k,3,0)|0;if((B|0)<1){v=1;i=e;return v|0}if((gzL(y,0,3)|0)==0){break}else{v=1}i=e;return v|0}}while(0);y=c[2437708]|0;if((c[3542200]|0)==0){v=1;i=e;return v|0}w=f+108|0;c[w>>2]=0;s=f+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,2)|0;do{if((c[w>>2]|0)!=0){x=c[s>>2]|0;c[g>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](g,2,0)|0;if((x|0)<1){v=1;i=e;return v|0}if((gzL(y,0,2)|0)==0){break}else{v=1}i=e;return v|0}}while(0);y=c[2433424]|0;s=c[2437708]|0;w=c[2437710]|0;if((y|0)>0){x=0;while(1){B=x<<8;gGz(w+B|0,0,256);z=x<<10;A=0;do{E=1<<3-A;C=(c[703416+(A<<2)>>2]|0)+z|0;D=0;do{H=C+(c[3946808+(D<<2)>>2]|0)|0;G=(D<<4)+B|0;F=0;do{I=H+(c[3946872+(F<<2)>>2]|0)|0;if(((d[s+((I|0)/8|0)|0]|0)&128>>>((I&7)>>>0)|0)!=0){I=w+(G+F)|0;a[I]=(d[I]|0|E)&255}F=F+1|0;}while((F|0)<16);D=D+1|0;}while((D|0)<16);A=A+1|0;}while((A|0)<4);A=x+1|0;if((A|0)<(y|0)){x=A}else{L=0;break}}}else{L=0}while(1){if((L|0)>=1024){break L51906}M=9638528+(L<<2)|0;if((c[M>>2]|0)==(s|0)){break}else{L=L+1|0}}gGr(s);c[M>>2]=0}}while(0);c[2437708]=0;fxU(0,425984);if((c[2394]|0)==0){N=c[2112932]|0}else{c[2394]=0;n=c[3532596]|0;c[2112932]=n;r=c[3532592]|0;if((r|0)!=0){gGC(9104152,r|0,280)|0}c[2113054]=c[2113060];N=n}n=c[3527162]|0;r=N|0;x=0;while(1){y=n+x|0;c[r>>2]=y;c[r+131072>>2]=y;y=x+1024|0;if(y>>>0>262143){break}else{r=r+4|0;x=y}}x=c[3527164]|0;c[N+4096>>2]=x;c[N+69632>>2]=x;c[N+135168>>2]=x;r=x+1024|0;c[N+4100>>2]=r;c[N+69636>>2]=r;c[N+135172>>2]=r;r=x+2048|0;c[N+4104>>2]=r;c[N+69640>>2]=r;c[N+135176>>2]=r;r=x+3072|0;c[N+4108>>2]=r;c[N+69644>>2]=r;c[N+135180>>2]=r;r=x+4096|0;c[N+4112>>2]=r;c[N+69648>>2]=r;c[N+135184>>2]=r;r=x+5120|0;c[N+4116>>2]=r;c[N+69652>>2]=r;c[N+135188>>2]=r;r=x+6144|0;c[N+4120>>2]=r;c[N+69656>>2]=r;c[N+135192>>2]=r;r=x+7168|0;c[N+4124>>2]=r;c[N+69660>>2]=r;c[N+135196>>2]=r;r=x+8192|0;c[N+4128>>2]=r;c[N+69664>>2]=r;c[N+135200>>2]=r;r=x+9216|0;c[N+4132>>2]=r;c[N+69668>>2]=r;c[N+135204>>2]=r;r=x+10240|0;c[N+4136>>2]=r;c[N+69672>>2]=r;c[N+135208>>2]=r;r=x+11264|0;c[N+4140>>2]=r;c[N+69676>>2]=r;c[N+135212>>2]=r;r=x+12288|0;c[N+4144>>2]=r;c[N+69680>>2]=r;c[N+135216>>2]=r;r=x+13312|0;c[N+4148>>2]=r;c[N+69684>>2]=r;c[N+135220>>2]=r;r=x+14336|0;c[N+4152>>2]=r;c[N+69688>>2]=r;c[N+135224>>2]=r;r=x+15360|0;c[N+4156>>2]=r;c[N+69692>>2]=r;c[N+135228>>2]=r;r=c[2430196]|0;c[N+24576>>2]=r;c[N+90112>>2]=r;c[N+155648>>2]=r;r=c[2432692]|0;c[N+28672>>2]=r;c[N+94208>>2]=r;c[N+159744>>2]=r;x=r+1024|0;c[N+28676>>2]=x;c[N+94212>>2]=x;c[N+159748>>2]=x;x=r+2048|0;c[N+28680>>2]=x;c[N+94216>>2]=x;c[N+159752>>2]=x;x=r+3072|0;c[N+28684>>2]=x;c[N+94220>>2]=x;c[N+159756>>2]=x;x=r+4096|0;c[N+28688>>2]=x;c[N+94224>>2]=x;c[N+159760>>2]=x;x=r+5120|0;c[N+28692>>2]=x;c[N+94228>>2]=x;c[N+159764>>2]=x;x=r+6144|0;c[N+28696>>2]=x;c[N+94232>>2]=x;c[N+159768>>2]=x;x=r+7168|0;c[N+28700>>2]=x;c[N+94236>>2]=x;c[N+159772>>2]=x;c[N+196688>>2]=1186;c[N+196728>>2]=296;c[N+196608>>2]=2648;c[N+196648>>2]=2500;x=c[3532592]|0;if((x|0)!=0){gGC(x|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);x=c[2439330]|0;r=(x|0)==0;if(!r){n=x;gGC(9706056,n|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];n=c[3528484]|0;c[2076596]=n;y=c[2417276]|0;c[3541536]=y;c[1836236]=0;w=c[2438710]|0;A=0;B=0;while(1){c[x+76+(B<<2)>>2]=w+(B<<8);z=A+1&65535;if((z&65535)>127){O=0;P=0;break}else{A=z;B=z&65535}}while(1){B=w+(P<<8)|0;c[x+76+(P+512<<2)>>2]=B;c[x+76+(P+768<<2)>>2]=B;B=O+1&65535;if((B&65535)>127){break}else{O=B;P=B&65535}}w=c[2438712]|0;c[x+588>>2]=w;B=w+256|0;c[x+592>>2]=B;A=w+512|0;c[x+596>>2]=A;z=w+768|0;c[x+600>>2]=z;D=w+1024|0;c[x+604>>2]=D;E=w+1280|0;c[x+608>>2]=E;C=w+1536|0;c[x+612>>2]=C;F=w+1792|0;c[x+616>>2]=F;c[x+1612>>2]=w;c[x+1616>>2]=B;c[x+1620>>2]=A;c[x+1624>>2]=z;c[x+1628>>2]=D;c[x+1632>>2]=E;c[x+1636>>2]=C;c[x+1640>>2]=F;c[x+2636>>2]=w;c[x+3660>>2]=w;c[x+2640>>2]=B;c[x+3664>>2]=B;c[x+2644>>2]=A;c[x+3668>>2]=A;c[x+2648>>2]=z;c[x+3672>>2]=z;c[x+2652>>2]=D;c[x+3676>>2]=D;c[x+2656>>2]=E;c[x+3680>>2]=E;c[x+2660>>2]=C;c[x+3684>>2]=C;c[x+2664>>2]=F;c[x+3688>>2]=F;c[x+4172>>2]=3048;c[x+4176>>2]=1856;if(!r){F=x;gGC(F|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=n;c[2417276]=y;c[1836236]=-1;UL(3e6,1916,1868,0);c[2438224]=6e6;c[2433522]=3416;c[2406672]=1752;c[3528468]=9362;c[2443842]=340;h[745398]=1.0;a[3203264]=1;F=c[642608+(c[2436]<<2)>>2]|0;C=c[F+128>>2]|0;if((c[F+52>>2]&4|0)==0){c[2113068]=C;E=c[F+132>>2]|0;c[2113070]=E;c[2443814]=C;c[2440436]=E;Q=C;R=E}else{c[2113070]=C;E=c[F+132>>2]|0;c[2113068]=E;c[2440436]=C;c[2443814]=E;Q=E;R=C}C=ag(Q<<1,R)|0;E=gGq(C)|0;c[2112926]=E;if((E|0)!=0){gGz(E|0,0,C|0)}c[2430194]=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];C=c[3532592]|0;if((C|0)!=0){gGC(9104152,C|0,280)|0}c[2113054]=c[2113060]}RI();C=c[2394]|0;E=c[14130368+(C<<2)>>2]|0;if((E|0)!=0){gGC(E|0,9104152,280)|0}c[8452240+(C<<2)>>2]=c[2113054];c[2394]=-1;C=c[2439330]|0;E=(C|0)==0;if(!E){F=C;gGC(9706056,F|0,76)|0}F=c[2438118]|0;c[2433530]=F;D=c[3528484]|0;c[2076596]=D;z=c[2417276]|0;c[3541536]=z;c[1836236]=0;gGz(9706056,0,76);if(!E){E=C;gGC(E|0,9706056,76)|0}c[2438118]=F;c[3528484]=D;c[2417276]=z;c[1836236]=-1;c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;lw(c[3540984]|0);v=0;i=e;return v|0}}while(0);c[2426732]=0;v=1;i=e;return v|0}function d0y(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if(a[641816]|0){b=39399}else{d=a[7452584]|0;if(d){e=0;f=d&1;while(1){d=14163936+(e<<2)|0;g=c[d>>2]|0;h=c[2113006]|0;if((h|0)==0){b=39392}else{i=h-1|0;c[2113006]=i;if((i|0)==0){b=39392}}if((b|0)==39392){b=0;c[2383474]=0}if((g|0)==0){j=f}else{gGr(g);j=a[7452584]&1}c[d>>2]=0;d=e+1|0;if((d|0)<(j|0)){e=d;f=j}else{break}}}a[7452584]=0;c[2438224]=0;c[2433522]=0;c[2406672]=0;c[3528468]=0;j=c[2406688]|0;if((j|0)!=0){gGr(j);c[2406688]=0}c[2432972]=0;if(a[641816]|0){b=39399}}if((b|0)==39399){Uw(0)}if((c[2392]|0)>=0){j=0;do{f=14130368+(j<<2)|0;e=c[f>>2]|0;if((e|0)!=0){gGr(e);c[f>>2]=0}f=14130384+(j<<2)|0;e=c[f>>2]|0;if((e|0)!=0){gGr(e);c[f>>2]=0}j=j+1|0;}while((j|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;if(!(a[641816]|0)){fwZ()}c[2113070]=0;c[2113068]=0;j=c[2112926]|0;if((j|0)!=0){gGr(j);c[2112926]=0}j=c[2426732]|0;f=0;while(1){if((f|0)>=1024){b=39415;break}k=9638528+(f<<2)|0;if((c[k>>2]|0)==(j|0)){break}else{f=f+1|0}}if((b|0)==39415){c[2426732]=0;c[2433424]=0;c[2429510]=0;a[671680]=0;c[2439404]=0;c[2429486]=0;a[641816]=0;return 0}gGr(j);c[k>>2]=0;c[2426732]=0;c[2433424]=0;c[2429510]=0;a[671680]=0;c[2439404]=0;c[2429486]=0;a[641816]=0;return 0}function d0z(){var f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;if((a[9757960]|0)!=0){c[2430194]=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060]}RI();f=c[2394]|0;g=c[14130368+(f<<2)>>2]|0;if((g|0)!=0){gGC(g|0,9104152,280)|0}c[8452240+(f<<2)>>2]=c[2113054];c[2394]=-1;f=c[2439330]|0;g=(f|0)==0;if(!g){i=f;gGC(9706056,i|0,76)|0}i=c[2438118]|0;c[2433530]=i;j=c[3528484]|0;c[2076596]=j;k=c[2417276]|0;c[3541536]=k;c[1836236]=0;gGz(9706056,0,76);if(!g){g=f;gGC(g|0,9706056,76)|0}c[2438118]=i;c[3528484]=j;c[2417276]=k;c[1836236]=-1;c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;lw(c[3540984]|0)}a[9757970]=0;a[9757969]=0;a[9757968]=0;k=0;j=0;i=0;g=0;do{j=((a[9720808+k|0]&1)<<k|j&255)&255;i=((a[9720800+k|0]&1)<<k|i&255)&255;g=((a[9720792+k|0]&1)<<k|g&255)&255;k=k+1|0;}while((k|0)<8);a[9757968]=j;a[9757969]=i;a[9757970]=g;if((j&3)==3){g=j&-4;a[9757968]=g;l=g}else{l=j}if((l&12)==12){a[9757968]=l&-13}if((i&3)==3){l=i&-4;a[9757969]=l;m=l}else{m=i}if((m&12)==12){a[9757969]=m&-13}m=c[2392]|0;if((m|0)>=0){gGz(8452240,0,((m|0)>0?(m<<2)+4|0:4)|0)}c[2113054]=0;m=c[2385548]|0;if((m|0)>0){gGz(9752472,0,((m|0)>1?m<<2:4)|0)}c[2433530]=0;if((c[2394]|0)==0){n=0}else{c[2394]=0;c[2112932]=c[3532596];m=c[3532592]|0;if((m|0)!=0){gGC(9104152,m|0,280)|0}m=c[2113060]|0;c[2113054]=m;n=m}m=c[2439330]|0;if((m|0)!=0){i=m;gGC(9706056,i|0,76)|0}b[4853030]=c[2426515]&65535;i=c[2438118]|0;c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;m=n+(c[2444086]|0)|0;c[2113054]=m;c[2433530]=i+(c[2444087]|0);i=a[671680]|0?2e5:133333;c[2440530]=i;c[2440482]=1e5;n=(i>>>2)-m-(c[2113056]|0)+(c[2276108]|0)|0;c[2113056]=n;m=RG(n)|0;n=(c[2113054]|0)+m|0;c[2113054]=n;c[2276108]=-1;m=((c[2440530]<<1|0)/4|0)-n|0;c[2113056]=m;n=RG(m)|0;m=(c[2113054]|0)+n|0;c[2113054]=m;c[2276108]=-1;c[2113056]=-1;c[8452200+(c[2394]<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0<1024){RH(4);o=c[2113054]|0;p=c[2113056]|0;q=c[2276108]|0}else{o=m;p=-1;q=-1}m=(((c[2440530]|0)*3|0|0)/4|0)-o-p+q|0;c[2113056]=m;q=RG(m)|0;m=(c[2113054]|0)+q|0;c[2113054]=m;c[2276108]=-1;c[2113056]=-1;c[8452200+(c[2394]<<2)>>2]=8195;c[2276080]=768;if((c[2276079]|0)>>>0<768){RH(3);r=c[2113054]|0;s=c[2113056]|0;t=c[2276108]|0}else{r=m;s=-1;t=-1}m=(c[2440530]|0)-r-s+t|0;c[2113056]=m;t=RG(m)|0;m=(c[2113054]|0)+t|0;c[2113054]=m;c[2276108]=-1;c[2113056]=-1;c[8452200+(c[2394]<<2)>>2]=8194;c[2276080]=512;if((c[2276079]|0)>>>0<512){RH(2);u=c[2113054]|0;v=c[2113056]|0;w=c[2276108]|0}else{u=m;v=-1;w=-1}c[2438216]=v+u-w;w=c[2440482]|0;u=gGU(w,(w|0)<0|0?-1:0,2048e6,0)|0;v=c[2438224]|0;m=gGS(u,K,v,(v|0)<0|0?-1:0)|0;v=m;UF(w)|0;w=c[2443826]|0;if((w|0)<1073676288){c[2443826]=w-v}w=c[2443827]|0;if((w|0)<1073676288){c[2443827]=w-v}w=(c[3528508]|0)-v|0;c[3528508]=(w|0)<0?0:w;w=c[2112964]|0;if((w|0)!=0){gg[c[3542112]&4095](w,a[9688]|0?534:0)}w=c[2113054]|0;c[2444086]=(c[2113056]|0)+w-(c[2276108]|0)-(c[2440530]|0);v=c[2433530]|0;m=c[2076596]|0;c[2444087]=(c[2426530]|0)+v-m-(c[2440482]|0);u=c[1836236]|0;t=c[9757320+(u<<2)>>2]|0;if((t|0)!=0){s=t;gGC(s|0,9706056,76)|0}c[9752472+(u<<2)>>2]=v;c[14113936+(u<<2)>>2]=m;c[9669104+(u<<2)>>2]=c[3541536];c[1836236]=-1;u=c[2394]|0;m=c[14130368+(u<<2)>>2]|0;if((m|0)!=0){gGC(m|0,9104152,280)|0}c[8452240+(u<<2)>>2]=w;c[2394]=-1;if((c[2112968]|0)==0){return 0}w=c[2437712]|0;u=0;m=c[2430196]|0;v=w;while(1){s=e[m>>1]|0;t=s>>>5&31;c[v>>2]=s>>>10&31|s<<11&63488|(t<<3|t>>>2)<<3&2016;t=u+1|0;if((t|0)<512){u=t;m=m+2|0;v=v+4|0}else{break}}v=ag(c[2113068]|0,c[2113070]|0)|0;if((v|0)>0){m=c[2112926]|0;u=0;do{b[m+(u<<1)>>1]=240;u=u+1|0;}while((u|0)<(v|0))}v=c[2432692]|0;if(a[671680]|0){u=v;m=c[2112926]|0;t=0;do{s=e[u+(t<<1)>>1]|0;r=b[u+((t|4)<<1)>>1]&255;q=e[u+((t|1)<<1)>>1]|0;p=q>>>4&15;o=e[u+((t|2)<<1)>>1]|0;n=o&128;i=o<<1&128;l=(q&8|0)==0?s&255:s|-256;s=o<<8&3840|b[u+((t|3)<<1)>>1]&255;L52232:do{if((q&2|0)==0){o=r-16|0;do{if((l-16|0)>>>0<224){if((r-32|0)>>>0>=193){break}j=(n|0)!=0;g=c[2437710]|0;if((i|0)==0){if(j){SI(m,s,l,o,p,4,0,0,g);break L52232}else{SG(m,s,l,o,p,4,0,0,g);break L52232}}else{if(j){SM(m,s,l,o,p,4,0,0,g);break L52232}else{SK(m,s,l,o,p,4,0,0,g);break L52232}}}}while(0);g=(n|0)!=0;j=c[2437710]|0;if((i|0)==0){if(g){SJ(m,s,l,o,p,4,0,0,j);break}else{SH(m,s,l,o,p,4,0,0,j);break}}else{if(g){SN(m,s,l,o,p,4,0,0,j);break}else{SL(m,s,l,o,p,4,0,0,j);break}}}}while(0);t=t+8|0;}while((t|0)<4096)}else{t=c[2112926]|0;m=0;u=0;p=0;do{l=d[v+(m|8)|0]|0;s=d[v+(m|10)|0]|0;i=d[v+(m|6)|0]|0;n=d[v+(m|14)|0]|0;r=n&128;q=n<<1&128;j=n<<8&7936|d[v+(m|12)|0];n=i>>>4;g=(i&1|0)==0?l:l|-256;l=(i&2|0)==0?s:s|-256;if((i&4|0)==0){x=g;y=l}else{x=g+p|0;y=l+u|0}p=(x|0)>511?x&511:x;u=(y|0)>511?y&511:y;l=u-16|0;do{if((p-16|0)>>>0<224){if((u-32|0)>>>0>=193){z=39482;break}g=(r|0)!=0;i=c[2437710]|0;if((q|0)==0){if(g){SI(t,j,p,l,n,4,0,0,i);break}else{SG(t,j,p,l,n,4,0,0,i);break}}else{if(g){SM(t,j,p,l,n,4,0,0,i);break}else{SK(t,j,p,l,n,4,0,0,i);break}}}else{z=39482}}while(0);do{if((z|0)==39482){z=0;i=(r|0)!=0;g=c[2437710]|0;if((q|0)==0){if(i){SJ(t,j,p,l,n,4,0,0,g);break}else{SH(t,j,p,l,n,4,0,0,g);break}}else{if(i){SN(t,j,p,l,n,4,0,0,g);break}else{SL(t,j,p,l,n,4,0,0,g);break}}}}while(0);m=m+16|0;}while((m|0)<8192)}R8(w);return 0}function d0A(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;e=i;i=i+128|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;l=e+80|0;m=e+96|0;n=e+112|0;if((d|0)!=0){c[d>>2]=169241}if((b&32|0)!=0){gGz(n|0,0,12);o=c[2405666]|0;c[n>>2]=o;c[n+4>>2]=(c[2411684]|0)-o;c[n+12>>2]=162152;o=c[2076592]|0;gj[o&4095](n)|0}if((b&64|0)==0){i=e;return 0}n=h|0;gGz(g|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){o=h+9|0;h=f;p=f|0;q=f+4|0;r=f+12|0;s=g|0;t=g+4|0;u=g+12|0;v=0;do{gGC(n|0,614896,11)|0;a[o]=v+48&255;w=8452256+(v<<2)|0;gGz(h|0,0,12);c[p>>2]=w;c[q>>2]=4;c[r>>2]=164976;gj[c[2076592]&4095](f)|0;if((c[w>>2]|0)!=0){c[s>>2]=c[14130368+(v<<2)>>2];c[t>>2]=c[8452184+(v<<2)>>2];c[u>>2]=n;w=c[2076592]|0;gj[w&4095](g)|0}v=v+1|0;}while((v|0)<=(c[2392]|0))}fw$(b);gGz(m|0,0,12);c[m>>2]=9776344;c[m+4>>2]=8;c[m+12>>2]=212472;gj[c[2076592]&4095](m)|0;UQ(b,d);gGz(l|0,0,12);c[l>>2]=9720776;c[l+4>>2]=4;c[l+12>>2]=132640;gj[c[2076592]&4095](l)|0;gGz(k|0,0,12);c[k>>2]=9757968;c[k+4>>2]=3;c[k+12>>2]=129624;gj[c[2076592]&4095](k)|0;gGz(j|0,0,12);c[j>>2]=14108664;c[j+4>>2]=2;c[j+12>>2]=127032;gj[c[2076592]&4095](j)|0;i=e;return 0}function d0B(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>3){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3422556+(b*112|0)>>2];c[a+104>>2]=c[3422560+(b*112|0)>>2];c[a+108>>2]=c[3422564+(b*112|0)>>2];d=0;return d|0}function d0C(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<4&(d|0)==0)){e=1;return e|0}c[a>>2]=3422456+(b*112|0);e=0;return e|0}function d0D(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>3){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3422108+(b*112|0)>>2];c[a+104>>2]=c[3422112+(b*112|0)>>2];c[a+108>>2]=c[3422116+(b*112|0)>>2];d=0;return d|0}function d0E(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<4&(d|0)==0)){e=1;return e|0}c[a>>2]=3422008+(b*112|0);e=0;return e|0}function d0F(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>3){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3421660+(b*112|0)>>2];c[a+104>>2]=c[3421664+(b*112|0)>>2];c[a+108>>2]=c[3421668+(b*112|0)>>2];d=0;return d|0}function d0G(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<4&(d|0)==0)){e=1;return e|0}c[a>>2]=3421560+(b*112|0);e=0;return e|0}function d0H(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>3){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3420220+(b*112|0)>>2];c[a+104>>2]=c[3420224+(b*112|0)>>2];c[a+108>>2]=c[3420228+(b*112|0)>>2];d=0;return d|0}function d0I(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<4&(d|0)==0)){e=1;return e|0}c[a>>2]=3420120+(b*112|0);e=0;return e|0}function d0J(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>44){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3420568+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function d0K(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>3){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3421212+(b*112|0)>>2];c[a+104>>2]=c[3421216+(b*112|0)>>2];c[a+108>>2]=c[3421220+(b*112|0)>>2];d=0;return d|0}function d0L(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<4&(d|0)==0)){e=1;return e|0}c[a>>2]=3421112+(b*112|0);e=0;return e|0}function d0M(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4881340+(b*112|0)>>2];c[a+104>>2]=c[4881344+(b*112|0)>>2];c[a+108>>2]=c[4881348+(b*112|0)>>2];d=0;return d|0}function d0N(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=4881240+(b*112|0);e=0;return e|0}function d0O(){a[671680]=1;return d0x()|0}function d0P(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1190556+(b*112|0)>>2];c[a+104>>2]=c[1190560+(b*112|0)>>2];c[a+108>>2]=c[1190564+(b*112|0)>>2];d=0;return d|0}function d0Q(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=1190456+(b*112|0);e=0;return e|0}function d0R(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3423004+(b*112|0)>>2];c[a+104>>2]=c[3423008+(b*112|0)>>2];c[a+108>>2]=c[3423012+(b*112|0)>>2];d=0;return d|0}function d0S(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=3422904+(b*112|0);e=0;return e|0}function d0T(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;b=i;i=i+480|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;l=b+360|0;m=b+472|0;a[641816]=1;c[2433424]=4096;c[2429510]=16384;c[2426732]=0;c[3527162]=0;c[3541206]=262144;c[2405666]=1179648;c[3527164]=1179648;c[2430196]=1196032;c[2432692]=1197056;c[2411684]=1205760;c[2437710]=1205760;c[2429744]=2254336;c[2437712]=6448640;n=0;while(1){if((n|0)>=1024){break}o=9638528+(n<<2)|0;if((c[o>>2]|0)==0){p=39636;break}else{n=n+1|0}}do{if((p|0)==39636){n=gGq(6452736)|0;c[o>>2]=n;if((n|0)==0){break}c[2426732]=n;gGz(n|0,0,6452736);c[3527162]=n;c[3541206]=n+262144;q=n+1179648|0;c[2405666]=q;c[3527164]=q;c[2430196]=n+1196032;c[2432692]=n+1197056;q=n+1205760|0;c[2411684]=q;c[2437710]=q;q=(c[2433424]<<8)+1205760|0;c[2429744]=n+q;r=q+(c[2429510]<<8)|0;c[2437712]=n+r;c[2414224]=n+(r+4096);r=0;while(1){if((r|0)>=1024){s=0;break}t=9638528+(r<<2)|0;if((c[t>>2]|0)==0){p=39641;break}else{r=r+1|0}}do{if((p|0)==39641){r=gGq(4194304)|0;c[t>>2]=r;if((r|0)==0){s=0;break}gGz(r|0,0,4194304);s=r}}while(0);c[2437708]=s;if((R6((c[3527162]|0)+1|0,0,2)|0)!=0){u=1;i=b;return u|0}if((R6(c[3527162]|0,1,2)|0)==0){v=0}else{u=1;i=b;return u|0}while(1){if((v|0)>=1024){w=0;break}x=9638528+(v<<2)|0;if((c[x>>2]|0)==0){p=39647;break}else{v=v+1|0}}do{if((p|0)==39647){r=gGq(262144)|0;c[x>>2]=r;if((r|0)==0){w=0;break}gGz(r|0,0,262144);w=r}}while(0);r=c[3527162]|0;n=0;do{a[w+n|0]=a[r+(n>>>3<<4&16|n&16777185|n>>>4<<3&8|n>>>1<<2&4|n>>>2<<1&2)|0]|0;n=n+1|0;}while((n|0)<262144);gGC(r|0,w|0,262144)|0;n=0;while(1){if((n|0)>=1024){break}y=9638528+(n<<2)|0;if((c[y>>2]|0)==(w|0)){p=39654;break}else{n=n+1|0}}if((p|0)==39654){gGr(w);c[y>>2]=0}n=c[2437708]|0;if((c[3542200]|0)==0){u=1;i=b;return u|0}r=l+108|0;c[r>>2]=0;q=l+100|0;c[q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,2)|0;do{if((c[r>>2]|0)!=0){z=c[q>>2]|0;c[m>>2]=9534384;A=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[A&16383](m,2,0)|0;if((z|0)<1){u=1;i=b;return u|0}if((gzL(n,0,2)|0)==0){break}else{u=1}i=b;return u|0}}while(0);n=c[2433424]|0;q=c[2437708]|0;r=c[2437710]|0;if((n|0)>0){z=0;do{A=z<<8;gGz(r+A|0,0,256);B=z<<10;C=0;do{D=1<<3-C;E=(c[703416+(C<<2)>>2]|0)+B|0;F=0;do{G=E+(c[3946808+(F<<2)>>2]|0)|0;H=(F<<4)+A|0;I=0;do{J=G+(c[3946872+(I<<2)>>2]|0)|0;if(((d[q+((J|0)/8|0)|0]|0)&128>>>((J&7)>>>0)|0)!=0){J=r+(H+I)|0;a[J]=(d[J]|0|D)&255}I=I+1|0;}while((I|0)<16);F=F+1|0;}while((F|0)<16);C=C+1|0;}while((C|0)<4);z=z+1|0;}while((z|0)<(n|0))}gGz(q|0,0,4194304);if((c[3542200]|0)==0){u=1;i=b;return u|0}n=j+108|0;c[n>>2]=0;z=j+100|0;c[z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,3)|0;do{if((c[n>>2]|0)!=0){r=c[z>>2]|0;c[k>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](k,3,0)|0;if((r|0)<1){u=1;i=b;return u|0}if((gzL(q,0,3)|0)==0){break}else{u=1}i=b;return u|0}}while(0);q=(c[2437708]|0)+2097152|0;if((c[3542200]|0)==0){u=1;i=b;return u|0}z=g+108|0;c[z>>2]=0;n=g+100|0;c[n>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,4)|0;do{if((c[z>>2]|0)!=0){r=c[n>>2]|0;c[h>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](h,4,0)|0;if((r|0)<1){u=1;i=b;return u|0}if((gzL(q,0,4)|0)==0){break}else{u=1}i=b;return u|0}}while(0);q=c[2429510]|0;n=c[2437708]|0;z=c[2429744]|0;if((q|0)>0){r=0;do{C=r<<8;gGz(z+C|0,0,256);A=r<<11;B=0;do{F=1<<7-B;D=(c[683936+(B<<2)>>2]|0)+A|0;E=0;do{I=D+(c[1942600+(E<<2)>>2]|0)|0;H=(E<<4)+C|0;G=0;do{J=I+(c[725816+(G<<2)>>2]|0)|0;if(((d[n+((J|0)/8|0)|0]|0)&128>>>((J&7)>>>0)|0)!=0){J=z+(H+G)|0;a[J]=(d[J]|0|F)&255}G=G+1|0;}while((G|0)<16);E=E+1|0;}while((E|0)<16);B=B+1|0;}while((B|0)<8);r=r+1|0;}while((r|0)<(q|0))}gGz(n|0,0,4194304);if((c[3542200]|0)==0){u=1;i=b;return u|0}q=e+108|0;c[q>>2]=0;r=e+100|0;c[r>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,5)|0;do{if((c[q>>2]|0)!=0){z=c[r>>2]|0;c[f>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](f,5,0)|0;if((z|0)<1){u=1;i=b;return u|0}if((gzL(n,0,5)|0)==0){break}else{u=1}i=b;return u|0}}while(0);n=c[3541206]|0;r=c[2437708]|0;gGC(n|0,r|0,131072)|0;q=n+524288|0;n=r+131072|0;gGC(q|0,n|0,393216)|0;n=0;while(1){if((n|0)>=1024){break}K=9638528+(n<<2)|0;if((c[K>>2]|0)==(r|0)){p=39694;break}else{n=n+1|0}}if((p|0)==39694){gGr(r);c[K>>2]=0}c[2437708]=0;fxU(0,425984);if((c[2394]|0)==0){L=c[2112932]|0}else{c[2394]=0;n=c[3532596]|0;c[2112932]=n;q=c[3532592]|0;if((q|0)!=0){gGC(9104152,q|0,280)|0}c[2113054]=c[2113060];L=n}n=c[3527162]|0;q=L|0;z=0;while(1){B=n+z|0;c[q>>2]=B;c[q+131072>>2]=B;B=z+1024|0;if(B>>>0>262143){break}else{q=q+4|0;z=B}}z=c[3527164]|0;c[L+4096>>2]=z;c[L+69632>>2]=z;c[L+135168>>2]=z;q=z+1024|0;c[L+4100>>2]=q;c[L+69636>>2]=q;c[L+135172>>2]=q;q=z+2048|0;c[L+4104>>2]=q;c[L+69640>>2]=q;c[L+135176>>2]=q;q=z+3072|0;c[L+4108>>2]=q;c[L+69644>>2]=q;c[L+135180>>2]=q;q=z+4096|0;c[L+4112>>2]=q;c[L+69648>>2]=q;c[L+135184>>2]=q;q=z+5120|0;c[L+4116>>2]=q;c[L+69652>>2]=q;c[L+135188>>2]=q;q=z+6144|0;c[L+4120>>2]=q;c[L+69656>>2]=q;c[L+135192>>2]=q;q=z+7168|0;c[L+4124>>2]=q;c[L+69660>>2]=q;c[L+135196>>2]=q;q=z+8192|0;c[L+4128>>2]=q;c[L+69664>>2]=q;c[L+135200>>2]=q;q=z+9216|0;c[L+4132>>2]=q;c[L+69668>>2]=q;c[L+135204>>2]=q;q=z+10240|0;c[L+4136>>2]=q;c[L+69672>>2]=q;c[L+135208>>2]=q;q=z+11264|0;c[L+4140>>2]=q;c[L+69676>>2]=q;c[L+135212>>2]=q;q=z+12288|0;c[L+4144>>2]=q;c[L+69680>>2]=q;c[L+135216>>2]=q;q=z+13312|0;c[L+4148>>2]=q;c[L+69684>>2]=q;c[L+135220>>2]=q;q=z+14336|0;c[L+4152>>2]=q;c[L+69688>>2]=q;c[L+135224>>2]=q;q=z+15360|0;c[L+4156>>2]=q;c[L+69692>>2]=q;c[L+135228>>2]=q;q=c[2430196]|0;c[L+24576>>2]=q;c[L+90112>>2]=q;c[L+155648>>2]=q;q=c[2432692]|0;c[L+28672>>2]=q;c[L+94208>>2]=q;c[L+159744>>2]=q;z=q+1024|0;c[L+28676>>2]=z;c[L+94212>>2]=z;c[L+159748>>2]=z;z=q+2048|0;c[L+28680>>2]=z;c[L+94216>>2]=z;c[L+159752>>2]=z;z=q+3072|0;c[L+28684>>2]=z;c[L+94220>>2]=z;c[L+159756>>2]=z;z=q+4096|0;c[L+28688>>2]=z;c[L+94224>>2]=z;c[L+159760>>2]=z;z=q+5120|0;c[L+28692>>2]=z;c[L+94228>>2]=z;c[L+159764>>2]=z;z=q+6144|0;c[L+28696>>2]=z;c[L+94232>>2]=z;c[L+159768>>2]=z;z=q+7168|0;c[L+28700>>2]=z;c[L+94236>>2]=z;c[L+159772>>2]=z;z=q+8192|0;c[L+28704>>2]=z;c[L+94240>>2]=z;c[L+159776>>2]=z;c[L+196688>>2]=1334;c[L+196728>>2]=942;c[L+196608>>2]=3604;c[L+196648>>2]=260;z=c[3532592]|0;if((z|0)!=0){gGC(z|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;Ux(0,7575,0);c[2407030]=256;c[2407068]=3;z=c[642608+(c[2436]<<2)>>2]|0;q=c[z+128>>2]|0;if((c[z+52>>2]&4|0)==0){c[2113068]=q;n=c[z+132>>2]|0;c[2113070]=n;c[2443814]=q;c[2440436]=n;M=q;N=n}else{c[2113070]=q;n=c[z+132>>2]|0;c[2113068]=n;c[2440436]=q;c[2443814]=n;M=n;N=q}q=ag(M<<1,N)|0;n=gGq(q)|0;c[2112926]=n;if((n|0)!=0){gGz(n|0,0,q|0)}if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];q=c[3532592]|0;if((q|0)!=0){gGC(9104152,q|0,280)|0}c[2113054]=c[2113060]}RI();q=c[2394]|0;n=c[14130368+(q<<2)>>2]|0;if((n|0)!=0){gGC(n|0,9104152,280)|0}c[8452240+(q<<2)>>2]=c[2113054];c[2394]=-1;c[2113156]=0;a[9628264]=0;c[2407033]=0;q=c[3541206]|0;c[3541190]=q;c[3541198]=q;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=q+256;c[3541199]=q+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=q+512;c[3541200]=q+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=q+768;c[3541201]=q+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2439404]=0;c[2429486]=0;u=0;i=b;return u|0}}while(0);c[2426732]=0;u=1;i=b;return u|0}function d0U(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;if((a[9757960]|0)!=0){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;f=c[14130368+(d<<2)>>2]|0;if((f|0)!=0){gGC(f|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;c[2113156]=0;a[9628264]=0;c[2407033]=0;d=c[3541206]|0;c[3541190]=d;c[3541198]=d;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=d+256;c[3541199]=d+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=d+512;c[3541200]=d+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=d+768;c[3541201]=d+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;c[2439404]=0;c[2429486]=0}a[9757970]=0;a[9757969]=0;a[9757968]=0;d=0;f=0;g=0;h=0;do{f=((a[9720808+d|0]&1)<<d|f&255)&255;g=((a[9720800+d|0]&1)<<d|g&255)&255;h=((a[9720792+d|0]&1)<<d|h&255)&255;d=d+1|0;}while((d|0)<8);a[9757968]=f;a[9757969]=g;a[9757970]=h;if((f&3)==3){h=f&-4;a[9757968]=h;i=h}else{i=f}if((i&12)==12){a[9757968]=i&-13}if((g&3)==3){i=g&-4;a[9757969]=i;j=i}else{j=g}if((j&12)==12){a[9757969]=j&-13}if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];j=c[3532592]|0;if((j|0)!=0){gGC(9104152,j|0,280)|0}c[2113054]=c[2113060]}j=c[2392]|0;if((j|0)>=0){gGz(8452240,0,((j|0)>0?(j<<2)+4|0:4)|0)}j=c[2444086]|0;c[2113054]=j;c[2440530]=266666;g=0;i=266666;f=j;while(1){j=g+1|0;h=(ag(j,i)|0)/4|0;d=h-f-(c[2113056]|0)+(c[2276108]|0)|0;c[2113056]=d;h=RG(d)|0;c[2113054]=(c[2113054]|0)+h;c[2276108]=-1;c[2113056]=-1;do{if((g|0)==1){c[8452200+(c[2394]<<2)>>2]=8196;c[2276080]=1024;if((c[2276079]|0)>>>0>=1024){break}RH(4)}else if((g|0)==3){c[8452200+(c[2394]<<2)>>2]=8194;c[2276080]=512;if((c[2276079]|0)>>>0>=512){break}RH(2)}else if((g|0)==2){c[8452200+(c[2394]<<2)>>2]=8195;c[2276080]=768;if((c[2276079]|0)>>>0>=768){break}RH(3)}}while(0);h=(c[2113156]&8|0)==0;do{if((c[2429486]|0)==0){if(!h){break}Uv(0,64)}else{if(!h){break}Uv(0,(c[2439404]|128)&255);Uv(0,-126)}}while(0);if((j|0)>=4){break}g=j;i=c[2440530]|0;f=c[2113054]|0}f=c[2113054]|0;c[2444086]=(c[2113056]|0)+f-(c[2276108]|0)-(c[2440530]|0);i=c[2394]|0;g=c[14130368+(i<<2)>>2]|0;if((g|0)!=0){gGC(g|0,9104152,280)|0}c[8452240+(i<<2)>>2]=f;c[2394]=-1;f=c[2112964]|0;if((f|0)!=0){Uu(0,f,a[9688]|0?534:0)}if((c[2112968]|0)==0){return 0}f=c[2437712]|0;i=0;g=c[2430196]|0;h=f;while(1){d=e[g>>1]|0;k=d>>>5&31;c[h>>2]=d>>>10&31|d<<11&63488|(k<<3|k>>>2)<<3&2016;k=i+1|0;if((k|0)<1024){i=k;g=g+2|0;h=h+4|0}else{break}}h=ag(c[2113068]|0,c[2113070]|0)|0;if((h|0)>0){g=c[2112926]|0;i=0;do{b[g+(i<<1)>>1]=240;i=i+1|0;}while((i|0)<(h|0))}h=c[2432692]|0;i=c[2112926]|0;g=0;k=0;d=0;do{l=e[h+((g|4)<<1)>>1]|0;m=e[h+((g|5)<<1)>>1]|0;n=e[h+((g|3)<<1)>>1]|0;o=e[h+((g|7)<<1)>>1]|0;p=o&128;q=o<<1&128;r=o<<8&65280|b[h+((g|6)<<1)>>1]&255;o=(n&1|0)==0?l&255:l|-256;l=(n&2|0)==0?m&255:m|-256;if((n&4|0)==0){s=o;t=l}else{s=o+d|0;t=l+k|0}d=(s|0)>511?s&511:s;k=(t|0)>511?t&511:t;if((g|0)<2048){u=r&16383;v=9718976;w=8;x=1}else{u=r&4095;v=9750840;w=4;x=n>>>4&15}n=c[v>>2]|0;r=k-16|0;do{if((d-16|0)>>>0<224){if((k-32|0)>>>0>=193){y=39797;break}l=(p|0)!=0;if((q|0)==0){if(l){SI(i,u,d,r,x,w,0,0,n);break}else{SG(i,u,d,r,x,w,0,0,n);break}}else{if(l){SM(i,u,d,r,x,w,0,0,n);break}else{SK(i,u,d,r,x,w,0,0,n);break}}}else{y=39797}}while(0);do{if((y|0)==39797){y=0;j=(p|0)!=0;if((q|0)==0){if(j){SJ(i,u,d,r,x,w,0,0,n);break}else{SH(i,u,d,r,x,w,0,0,n);break}}else{if(j){SN(i,u,d,r,x,w,0,0,n);break}else{SL(i,u,d,r,x,w,0,0,n);break}}}}while(0);g=g+8|0;}while((g|0)<4352);R8(f);return 0}function d0V(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=i;i=i+144|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;l=e+80|0;m=e+96|0;n=e+112|0;o=e+128|0;if((d|0)!=0){c[d>>2]=169586}if((b&32|0)!=0){gGz(o|0,0,12);d=c[2405666]|0;c[o>>2]=d;c[o+4>>2]=(c[2411684]|0)-d;c[o+12>>2]=162152;d=c[2076592]|0;gj[d&4095](o)|0}if((b&64|0)==0){i=e;return 0}b=h|0;gGz(g|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){o=h+9|0;h=f;d=f|0;p=f+4|0;q=f+12|0;r=g|0;s=g+4|0;t=g+12|0;u=0;do{gGC(b|0,614896,11)|0;a[o]=u+48&255;v=8452256+(u<<2)|0;gGz(h|0,0,12);c[d>>2]=v;c[p>>2]=4;c[q>>2]=164976;gj[c[2076592]&4095](f)|0;if((c[v>>2]|0)!=0){c[r>>2]=c[14130368+(u<<2)>>2];c[s>>2]=c[8452184+(u<<2)>>2];c[t>>2]=b;v=c[2076592]|0;gj[v&4095](g)|0}u=u+1|0;}while((u|0)<=(c[2392]|0))}Ut(0);gGz(n|0,0,12);c[n>>2]=9720776;c[n+4>>2]=4;c[n+12>>2]=132640;gj[c[2076592]&4095](n)|0;gGz(m|0,0,12);c[m>>2]=9757968;c[m+4>>2]=3;c[m+12>>2]=129624;gj[c[2076592]&4095](m)|0;gGz(l|0,0,12);c[l>>2]=14108664;c[l+4>>2]=2;c[l+12>>2]=127032;gj[c[2076592]&4095](l)|0;gGz(k|0,0,12);c[k>>2]=9757616;c[k+4>>2]=4;c[k+12>>2]=123984;gj[c[2076592]&4095](k)|0;gGz(j|0,0,12);c[j>>2]=9717944;c[j+4>>2]=4;c[j+12>>2]=120192;gj[c[2076592]&4095](j)|0;i=e;return 0}function d0W(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>6){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5584556+(b*112|0)>>2];c[a+104>>2]=c[5584560+(b*112|0)>>2];c[a+108>>2]=c[5584564+(b*112|0)>>2];d=0;return d|0}function d0X(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<7&(d|0)==0)){e=1;return e|0}c[a>>2]=5584456+(b*112|0);e=0;return e|0}function d0Y(b,c){b=b|0;c=c|0;a[9706117]=(c|0)!=0|0;return}function d0Z(a){a=a|0;var b=0,d=0;b=(c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,6e6,0)|0;return a|0}function d0_(){var b=0,d=0,e=0,f=0,g=0,i=0;c[2430194]=0;b=c[2433422]|0;d=a[642496]|0;if(!((b|0)==0|d)){e=(c[3527164]|0)+61440|0;gGC(e|0,b|0,512)|0}if((b|0)!=0&d){d=(c[3527164]|0)+8192|0;gGC(d|0,b|0,512)|0}if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];b=c[3532592]|0;if((b|0)!=0){gGC(9104152,b|0,280)|0}c[2113054]=c[2113060]}RI();b=c[2394]|0;d=c[14130368+(b<<2)>>2]|0;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[8452240+(b<<2)>>2]=c[2113054];c[2394]=-1;b=c[2439330]|0;d=(b|0)==0;if(!d){e=b;gGC(9706056,e|0,76)|0}e=c[2438118]|0;c[2433530]=e;f=c[3528484]|0;c[2076596]=f;g=c[2417276]|0;c[3541536]=g;c[1836236]=0;gGz(9706056,0,76);if(!d){d=b;gGC(d|0,9706056,76)|0}c[2438118]=e;c[3528484]=f;c[2417276]=g;c[1836236]=-1;c[2113156]=0;a[9628264]=0;c[2407033]=0;g=c[3541206]|0;c[3541190]=g;c[3541198]=g;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=g+256;c[3541199]=g+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=g+512;c[3541200]=g+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=g+768;c[3541201]=g+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;if(a[642472]|0){c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;lw(c[3540984]|0);i=a[642472]|0}else{i=0}if(a[671688]|i){return}mx(0);return}function d0$(a){a=a|0;var b=0,d=0;b=(c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,4e6,0)|0;return a|0}function d00(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;a=c[2432692]|0;b=c[2112926]|0;e=0;f=0;g=0;do{h=d[a+(e|8)|0]|0;i=d[a+(e|10)|0]|0;j=d[a+(e|6)|0]|0;k=d[a+(e|14)|0]|0;l=k&128;m=k<<1&128;n=k<<8&16128|(d[a+(e|12)|0]|0);k=j>>>4;o=(j&1|0)==0?h:h|-256;h=(j&2|0)==0?i:i|-256;if((j&4|0)==0){p=o;q=h}else{p=o+g|0;q=h+f|0}g=(p|0)>511?p&511:p;f=(q|0)>511?q&511:q;h=f-16|0;do{if((g-16|0)>>>0<224){if((f-32|0)>>>0>=193){r=39871;break}o=(l|0)!=0;j=c[2437710]|0;if((m|0)==0){if(o){SI(b,n,g,h,k,4,0,0,j);break}else{SG(b,n,g,h,k,4,0,0,j);break}}else{if(o){SM(b,n,g,h,k,4,0,0,j);break}else{SK(b,n,g,h,k,4,0,0,j);break}}}else{r=39871}}while(0);do{if((r|0)==39871){r=0;j=(l|0)!=0;o=c[2437710]|0;if((m|0)==0){if(j){SJ(b,n,g,h,k,4,0,0,o);break}else{SH(b,n,g,h,k,4,0,0,o);break}}else{if(j){SN(b,n,g,h,k,4,0,0,o);break}else{SL(b,n,g,h,k,4,0,0,o);break}}}}while(0);e=e+16|0;}while((e|0)<8192);return}function d01(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;c[2424]=5750;fxU(0,425984);if((c[2394]|0)==0){d=c[2112932]|0}else{c[2394]=0;e=c[3532596]|0;c[2112932]=e;f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];d=e}e=c[3527162]|0;f=d|0;g=0;while(1){i=e+g|0;c[f>>2]=i;c[f+131072>>2]=i;i=g+1024|0;if(i>>>0>1048575){break}else{f=f+4|0;g=i}}g=a[642496]|0;f=c[3527164]|0;e=d+4096|0;if(g){c[e>>2]=f;c[d+69632>>2]=f;c[d+135168>>2]=f;i=f+1024|0;c[d+4100>>2]=i;c[d+69636>>2]=i;c[d+135172>>2]=i;i=f+2048|0;c[d+4104>>2]=i;c[d+69640>>2]=i;c[d+135176>>2]=i;i=f+3072|0;c[d+4108>>2]=i;c[d+69644>>2]=i;c[d+135180>>2]=i;i=f+4096|0;c[d+4112>>2]=i;c[d+69648>>2]=i;c[d+135184>>2]=i;i=f+5120|0;c[d+4116>>2]=i;c[d+69652>>2]=i;c[d+135188>>2]=i;i=f+6144|0;c[d+4120>>2]=i;c[d+69656>>2]=i;c[d+135192>>2]=i;i=f+7168|0;c[d+4124>>2]=i;c[d+69660>>2]=i;c[d+135196>>2]=i;i=f+8192|0;c[d+4128>>2]=i;c[d+69664>>2]=i;c[d+135200>>2]=i;i=f+9216|0;c[d+4132>>2]=i;c[d+69668>>2]=i;c[d+135204>>2]=i;i=f+10240|0;c[d+4136>>2]=i;c[d+69672>>2]=i;c[d+135208>>2]=i;i=f+11264|0;c[d+4140>>2]=i;c[d+69676>>2]=i;c[d+135212>>2]=i;i=f+12288|0;c[d+4144>>2]=i;c[d+69680>>2]=i;c[d+135216>>2]=i;i=f+13312|0;c[d+4148>>2]=i;c[d+69684>>2]=i;c[d+135220>>2]=i;i=f+14336|0;c[d+4152>>2]=i;c[d+69688>>2]=i;c[d+135224>>2]=i;i=f+15360|0;c[d+4156>>2]=i;c[d+69692>>2]=i;c[d+135228>>2]=i}else{i=e;e=1048576;while(1){j=f+(e-1048576)|0;c[i>>2]=j;c[i+65536>>2]=j;c[i+131072>>2]=j;j=e+1024|0;if(j>>>0>1114111){break}else{i=i+4|0;e=j}}}e=c[2430196]|0;c[d+24576>>2]=e;c[d+90112>>2]=e;c[d+155648>>2]=e;e=c[2432692]|0;c[d+28672>>2]=e;c[d+94208>>2]=e;c[d+159744>>2]=e;i=e+1024|0;c[d+28676>>2]=i;c[d+94212>>2]=i;c[d+159748>>2]=i;i=e+2048|0;c[d+28680>>2]=i;c[d+94216>>2]=i;c[d+159752>>2]=i;i=e+3072|0;c[d+28684>>2]=i;c[d+94220>>2]=i;c[d+159756>>2]=i;i=e+4096|0;c[d+28688>>2]=i;c[d+94224>>2]=i;c[d+159760>>2]=i;i=e+5120|0;c[d+28692>>2]=i;c[d+94228>>2]=i;c[d+159764>>2]=i;i=e+6144|0;c[d+28696>>2]=i;c[d+94232>>2]=i;c[d+159768>>2]=i;i=e+7168|0;c[d+28700>>2]=i;c[d+94236>>2]=i;c[d+159772>>2]=i;i=d+196608|0;if(a[7216728]|g){c[i>>2]=890;c[d+196688>>2]=632}else{c[i>>2]=1530;c[d+196688>>2]=3342}c[d+196648>>2]=694;c[d+196728>>2]=3236;d=c[3532592]|0;if((d|0)!=0){gGC(d|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;fwR(0);d=c[2439330]|0;i=(d|0)==0;if(!i){g=d;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];g=c[3528484]|0;c[2076596]=g;e=c[2417276]|0;c[3541536]=e;c[1836236]=0;f=c[2438710]|0;j=0;k=0;while(1){c[d+76+(k<<2)>>2]=f+(k<<8);l=j+1&65535;if((l&65535)>207){m=0;n=0;break}else{j=l;k=l&65535}}while(1){k=f+(n<<8)|0;c[d+76+(n+512<<2)>>2]=k;c[d+76+(n+768<<2)>>2]=k;k=m+1&65535;if((k&65535)>207){break}else{m=k;n=k&65535}}n=c[2438712]|0;c[d+908>>2]=n;m=n+256|0;c[d+912>>2]=m;f=n+512|0;c[d+916>>2]=f;k=n+768|0;c[d+920>>2]=k;j=n+1024|0;c[d+924>>2]=j;l=n+1280|0;c[d+928>>2]=l;o=n+1536|0;c[d+932>>2]=o;p=n+1792|0;c[d+936>>2]=p;c[d+1932>>2]=n;c[d+1936>>2]=m;c[d+1940>>2]=f;c[d+1944>>2]=k;c[d+1948>>2]=j;c[d+1952>>2]=l;c[d+1956>>2]=o;c[d+1960>>2]=p;c[d+2956>>2]=n;c[d+3980>>2]=n;c[d+2960>>2]=m;c[d+3984>>2]=m;c[d+2964>>2]=f;c[d+3988>>2]=f;c[d+2968>>2]=k;c[d+3992>>2]=k;c[d+2972>>2]=j;c[d+3996>>2]=j;c[d+2976>>2]=l;c[d+4e3>>2]=l;c[d+2980>>2]=o;c[d+4004>>2]=o;c[d+2984>>2]=p;c[d+4008>>2]=p;c[d+4180>>2]=1582;c[d+4184>>2]=534;if(!i){i=d;gGC(i|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=g;c[2417276]=e;c[1836236]=-1;e=a[9680]|0;g=e?32e3:0;if(e){if(a[9624]|0){e=g*3|0;i=62500;while(1){if((i|0)>(e|0)){i=i>>1}else{q=1222;r=i;break}}}else{q=2462;r=g}c[2429380]=r;c[3542124]=q;mw(4e6,r);r=gGq(262144)|0;c[2406684]=r;gGz(r|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3}else{mw(4e6,11025)}c[(c[3531464]|0)+44344>>2]=490;h[745421]=.1;c[2436794]=3;h[745420]=.1;c[2436792]=3;Ux(0,7575,1);c[2407030]=256;c[2407068]=3;r=c[642608+(c[2436]<<2)>>2]|0;q=c[r+128>>2]|0;if((c[r+52>>2]&4|0)==0){c[2113068]=q;g=c[r+132>>2]|0;c[2113070]=g;c[2443814]=q;c[2440436]=g;s=q;t=g}else{c[2113070]=q;g=c[r+132>>2]|0;c[2113068]=g;c[2440436]=q;c[2443814]=g;s=g;t=q}q=ag(s<<1,t)|0;t=gGq(q)|0;c[2112926]=t;if((t|0)==0){d0_();return}gGz(t|0,0,q|0);d0_();return}function d02(b){b=b|0;a[9706117]=(b|0)!=0|0;return}function d03(a){a=a|0;var d=0,e=0;if((a|0)==11534336){d=(c[2113156]|65520)&65535;return d|0}else if((a|0)==8388610){d=~b[4885949];return d|0}else if((a|0)==12582912){c[3528174]=180;d=-1;return d|0}else if((a|0)==8388608){d=~b[4885948];return d|0}else{e=((gj[c[(c[2112932]|0)+196608>>2]&4095](a)|0)&255)<<8;d=(gj[c[(c[2112932]|0)+196608>>2]&4095](a+1|0)|0)&255|e;return d|0}return 0}function d04(b){b=b|0;var c=0;if((b|0)==10485760){c=a[14116008]|0}else if((b|0)==10485761|(b|0)==10485763){c=-1}else if((b|0)==10485762){c=a[14116009]|0}else{c=0}return c|0}function d05(a,b){a=a|0;b=b|0;if((a|0)==4194304){c[2438638]=(b&65535)-33260;return}else if((a|0)==9437184){gg[c[(c[2112932]|0)+196648>>2]&4095](9437184,(b&65535)>>>8&255);gg[c[(c[2112932]|0)+196648>>2]&4095](9437185,b&255);return}else if((a|0)==13631488){c[2430858]=b&32768;return}else if((a|0)==11534336){gg[c[(c[2112932]|0)+196648>>2]&4095](11534336,(b&65535)>>>8&255);gg[c[(c[2112932]|0)+196648>>2]&4095](11534337,b&255);return}else if((a|0)==4194306){c[2438636]=(b&65535)-33263;return}else{return}}function d06(a,b){a=a|0;b=b|0;var d=0,e=0;if((a-7405568|0)>>>0<16384){return}if((a|0)==11534337){Uv(0,b);return}else if((a|0)==9437185){a=(b&255)>>>((c[2438872]|0)>>>0)&15;if((c[2406812]|0)==(a|0)){return}c[2406812]=a;b=c[3541206]|0;d=b+131072|0;e=b+((a<<17)+262144)|0;gGC(d|0,e|0,131072)|0;return}else{return}}function d07(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;b=i;i=i+600|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;l=b+360|0;m=b+472|0;n=b+480|0;o=b+592|0;c[2426730]=0;c[3528998]=0;c[3541206]=524288;c[2405664]=2883584;c[3529e3]=2883584;c[2437036]=2981888;c[2430860]=2998272;c[2433352]=3000320;c[2411682]=3016704;c[3540982]=3016704;c[3540980]=4065280;c[2438640]=5113856;p=0;while(1){if((p|0)>=1024){break}q=9638528+(p<<2)|0;if((c[q>>2]|0)==0){r=39961;break}else{p=p+1|0}}do{if((r|0)==39961){p=gGq(5122048)|0;c[q>>2]=p;if((p|0)==0){break}c[2426730]=p;gGz(p|0,0,5122048);c[3528998]=p;c[3541206]=p+524288;s=p+2883584|0;c[2405664]=s;c[3529e3]=s;c[2437036]=p+2981888;c[2430860]=p+2998272;c[2433352]=p+3000320;s=p+3016704|0;c[2411682]=s;c[3540982]=s;c[3540980]=p+4065280;c[2438640]=p+5113856;c[2414222]=p+5122048;if((c[3542200]|0)==0){t=1;i=b;return t|0}s=n+108|0;c[s>>2]=0;u=n+100|0;c[u>>2]=0;v=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[v&16383](n,0)|0;do{if((c[s>>2]|0)==0){w=0}else{v=c[u>>2]|0;c[o>>2]=9534384;x=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[x&16383](o,0,0)|0;if((v|0)<1){t=1;i=b;return t|0}if((gzL(p,0,0)|0)==0){w=0;break}else{t=1}i=b;return t|0}}while(0);while(1){if((w|0)>=1024){y=0;break}z=9638528+(w<<2)|0;if((c[z>>2]|0)==0){r=39969;break}else{w=w+1|0}}do{if((r|0)==39969){p=gGq(524288)|0;c[z>>2]=p;if((p|0)==0){y=0;break}gGz(p|0,0,524288);y=p}}while(0);if((c[3542200]|0)==0){t=1;i=b;return t|0}p=l+108|0;c[p>>2]=0;u=l+100|0;c[u>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](l,1)|0;do{if((c[p>>2]|0)!=0){s=c[u>>2]|0;c[m>>2]=9534384;v=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[v&16383](m,1,0)|0;if((s|0)<1){t=1;i=b;return t|0}if((gzL(y,0,1)|0)==0){break}else{t=1}i=b;return t|0}}while(0);u=c[3540982]|0;p=0;do{s=p<<6;gGz(u+s|0,0,64);v=p<<8;x=0;do{A=1<<3-x;B=(c[703416+(x<<2)>>2]|0)+v|0;C=0;do{D=B+(c[1183816+(C<<2)>>2]|0)|0;E=(C<<3)+s|0;F=0;do{G=D+(c[1934976+(F<<2)>>2]|0)|0;if(((d[y+((G|0)/8|0)|0]|0)&128>>>((G&7)>>>0)|0)!=0){G=u+(E+F)|0;a[G]=(d[G]|0|A)&255}F=F+1|0;}while((F|0)<8);C=C+1|0;}while((C|0)<8);x=x+1|0;}while((x|0)<4);p=p+1|0;}while((p|0)<16384);gGz(y|0,0,524288);if((c[3542200]|0)==0){t=1;i=b;return t|0}p=j+108|0;c[p>>2]=0;u=j+100|0;c[u>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,2)|0;do{if((c[p>>2]|0)!=0){x=c[u>>2]|0;c[k>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](k,2,0)|0;if((x|0)<1){t=1;i=b;return t|0}if((gzL(y,0,2)|0)==0){break}else{t=1}i=b;return t|0}}while(0);u=c[3540980]|0;p=0;while(1){x=p<<8;gGz(u+x|0,0,256);s=p<<10;v=0;do{C=1<<3-v;A=(c[703416+(v<<2)>>2]|0)+s|0;B=0;do{F=A+(c[611904+(B<<2)>>2]|0)|0;E=(B<<4)+x|0;D=0;do{G=F+(c[4969688+(D<<2)>>2]|0)|0;if(((d[y+((G|0)/8|0)|0]|0)&128>>>((G&7)>>>0)|0)!=0){G=u+(E+D)|0;a[G]=(d[G]|0|C)&255}D=D+1|0;}while((D|0)<16);B=B+1|0;}while((B|0)<16);v=v+1|0;}while((v|0)<4);v=p+1|0;if((v|0)<4096){p=v}else{H=0;break}}while(1){if((H|0)>=1024){break}I=9638528+(H<<2)|0;if((c[I>>2]|0)==(y|0)){r=40001;break}else{H=H+1|0}}if((r|0)==40001){gGr(y);c[I>>2]=0}p=c[3541206]|0;if((c[3542200]|0)==0){t=1;i=b;return t|0}u=g+108|0;c[u>>2]=0;v=g+100|0;c[v>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,3)|0;do{if((c[u>>2]|0)!=0){x=c[v>>2]|0;c[h>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](h,3,0)|0;if((x|0)<1){t=1;i=b;return t|0}if((gzL(p,0,3)|0)==0){break}else{t=1}i=b;return t|0}}while(0);p=(c[3541206]|0)+262144|0;if((c[3542200]|0)==0){t=1;i=b;return t|0}v=e+108|0;c[v>>2]=0;u=e+100|0;c[u>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](e,3)|0;do{if((c[v>>2]|0)!=0){x=c[u>>2]|0;c[f>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](f,3,0)|0;if((x|0)<1){t=1;i=b;return t|0}if((gzL(p,0,3)|0)==0){break}else{t=1}i=b;return t|0}}while(0);fxU(0,425984);if((c[2394]|0)==0){J=c[2112932]|0}else{c[2394]=0;p=c[3532596]|0;c[2112932]=p;u=c[3532592]|0;if((u|0)!=0){gGC(9104152,u|0,280)|0}c[2113054]=c[2113060];J=p}p=c[3528998]|0;u=J|0;v=0;while(1){x=p+v|0;c[u>>2]=x;c[u+131072>>2]=x;x=v+1024|0;if(x>>>0>524287){break}else{u=u+4|0;v=x}}v=c[3529e3]|0;c[J+12288>>2]=v;c[J+77824>>2]=v;c[J+143360>>2]=v;u=v+1024|0;c[J+12292>>2]=u;c[J+77828>>2]=u;c[J+143364>>2]=u;u=v+2048|0;c[J+12296>>2]=u;c[J+77832>>2]=u;c[J+143368>>2]=u;u=v+3072|0;c[J+12300>>2]=u;c[J+77836>>2]=u;c[J+143372>>2]=u;u=v+4096|0;c[J+12304>>2]=u;c[J+77840>>2]=u;c[J+143376>>2]=u;u=v+5120|0;c[J+12308>>2]=u;c[J+77844>>2]=u;c[J+143380>>2]=u;u=v+6144|0;c[J+12312>>2]=u;c[J+77848>>2]=u;c[J+143384>>2]=u;u=v+7168|0;c[J+12316>>2]=u;c[J+77852>>2]=u;c[J+143388>>2]=u;u=v+8192|0;c[J+12320>>2]=u;c[J+77856>>2]=u;c[J+143392>>2]=u;u=v+9216|0;c[J+12324>>2]=u;c[J+77860>>2]=u;c[J+143396>>2]=u;u=v+10240|0;c[J+12328>>2]=u;c[J+77864>>2]=u;c[J+143400>>2]=u;u=v+11264|0;c[J+12332>>2]=u;c[J+77868>>2]=u;c[J+143404>>2]=u;u=v+12288|0;c[J+12336>>2]=u;c[J+77872>>2]=u;c[J+143408>>2]=u;u=v+13312|0;c[J+12340>>2]=u;c[J+77876>>2]=u;c[J+143412>>2]=u;u=v+14336|0;c[J+12344>>2]=u;c[J+77880>>2]=u;c[J+143416>>2]=u;u=v+15360|0;c[J+12348>>2]=u;c[J+77884>>2]=u;c[J+143420>>2]=u;u=c[2437036]|0;c[J+12352>>2]=u;c[J+77888>>2]=u;c[J+143424>>2]=u;p=u+1024|0;c[J+12356>>2]=p;c[J+77892>>2]=p;c[J+143428>>2]=p;p=u+2048|0;c[J+12360>>2]=p;c[J+77896>>2]=p;c[J+143432>>2]=p;p=u+3072|0;c[J+12364>>2]=p;c[J+77900>>2]=p;c[J+143436>>2]=p;p=u+4096|0;c[J+12368>>2]=p;c[J+77904>>2]=p;c[J+143440>>2]=p;p=u+5120|0;c[J+12372>>2]=p;c[J+77908>>2]=p;c[J+143444>>2]=p;p=u+6144|0;c[J+12376>>2]=p;c[J+77912>>2]=p;c[J+143448>>2]=p;p=u+7168|0;c[J+12380>>2]=p;c[J+77916>>2]=p;c[J+143452>>2]=p;p=u+8192|0;c[J+12384>>2]=p;c[J+77920>>2]=p;c[J+143456>>2]=p;p=u+9216|0;c[J+12388>>2]=p;c[J+77924>>2]=p;c[J+143460>>2]=p;p=u+10240|0;c[J+12392>>2]=p;c[J+77928>>2]=p;c[J+143464>>2]=p;p=u+11264|0;c[J+12396>>2]=p;c[J+77932>>2]=p;c[J+143468>>2]=p;p=u+12288|0;c[J+12400>>2]=p;c[J+77936>>2]=p;c[J+143472>>2]=p;p=u+13312|0;c[J+12404>>2]=p;c[J+77940>>2]=p;c[J+143476>>2]=p;p=u+14336|0;c[J+12408>>2]=p;c[J+77944>>2]=p;c[J+143480>>2]=p;p=u+15360|0;c[J+12412>>2]=p;c[J+77948>>2]=p;c[J+143484>>2]=p;p=J+12416|0;u=3178496;while(1){x=v+(u-3162112)|0;c[p>>2]=x;c[p+65536>>2]=x;c[p+131072>>2]=x;x=u+1024|0;if(x>>>0>3211263){break}else{p=p+4|0;u=x}}u=c[2430860]|0;p=J+24576|0;x=6291456;while(1){c[p+65536>>2]=u+(x-6291456);s=x+1024|0;if(s>>>0>6324223){break}else{p=p+4|0;x=s}}x=c[2433352]|0;c[J+28672>>2]=x;c[J+94208>>2]=x;c[J+159744>>2]=x;p=x+1024|0;c[J+28676>>2]=p;c[J+94212>>2]=p;c[J+159748>>2]=p;p=x+2048|0;c[J+28680>>2]=p;c[J+94216>>2]=p;c[J+159752>>2]=p;p=x+3072|0;c[J+28684>>2]=p;c[J+94220>>2]=p;c[J+159756>>2]=p;p=x+4096|0;c[J+28688>>2]=p;c[J+94224>>2]=p;c[J+159760>>2]=p;p=x+5120|0;c[J+28692>>2]=p;c[J+94228>>2]=p;c[J+159764>>2]=p;p=x+6144|0;c[J+28696>>2]=p;c[J+94232>>2]=p;c[J+159768>>2]=p;p=x+7168|0;c[J+28700>>2]=p;c[J+94236>>2]=p;c[J+159772>>2]=p;p=x+8192|0;c[J+28704>>2]=p;c[J+94240>>2]=p;c[J+159776>>2]=p;p=x+9216|0;c[J+28708>>2]=p;c[J+94244>>2]=p;c[J+159780>>2]=p;p=x+10240|0;c[J+28712>>2]=p;c[J+94248>>2]=p;c[J+159784>>2]=p;p=x+11264|0;c[J+28716>>2]=p;c[J+94252>>2]=p;c[J+159788>>2]=p;p=x+12288|0;c[J+28720>>2]=p;c[J+94256>>2]=p;c[J+159792>>2]=p;p=x+13312|0;c[J+28724>>2]=p;c[J+94260>>2]=p;c[J+159796>>2]=p;p=x+14336|0;c[J+28728>>2]=p;c[J+94264>>2]=p;c[J+159800>>2]=p;p=x+15360|0;c[J+28732>>2]=p;c[J+94268>>2]=p;c[J+159804>>2]=p;p=v+49152|0;c[J+28736>>2]=p;c[J+94272>>2]=p;c[J+159808>>2]=p;p=v+50176|0;c[J+28740>>2]=p;c[J+94276>>2]=p;c[J+159812>>2]=p;p=v+51200|0;c[J+28744>>2]=p;c[J+94280>>2]=p;c[J+159816>>2]=p;p=v+52224|0;c[J+28748>>2]=p;c[J+94284>>2]=p;c[J+159820>>2]=p;p=v+53248|0;c[J+28752>>2]=p;c[J+94288>>2]=p;c[J+159824>>2]=p;p=v+54272|0;c[J+28756>>2]=p;c[J+94292>>2]=p;c[J+159828>>2]=p;p=v+55296|0;c[J+28760>>2]=p;c[J+94296>>2]=p;c[J+159832>>2]=p;p=v+56320|0;c[J+28764>>2]=p;c[J+94300>>2]=p;c[J+159836>>2]=p;p=v+57344|0;c[J+28768>>2]=p;c[J+94304>>2]=p;c[J+159840>>2]=p;p=v+58368|0;c[J+28772>>2]=p;c[J+94308>>2]=p;c[J+159844>>2]=p;p=v+59392|0;c[J+28776>>2]=p;c[J+94312>>2]=p;c[J+159848>>2]=p;p=v+60416|0;c[J+28780>>2]=p;c[J+94316>>2]=p;c[J+159852>>2]=p;p=v+61440|0;c[J+28784>>2]=p;c[J+94320>>2]=p;c[J+159856>>2]=p;p=v+62464|0;c[J+28788>>2]=p;c[J+94324>>2]=p;c[J+159860>>2]=p;p=v+63488|0;c[J+28792>>2]=p;c[J+94328>>2]=p;c[J+159864>>2]=p;p=v+64512|0;c[J+28796>>2]=p;c[J+94332>>2]=p;c[J+159868>>2]=p;p=J+28800|0;x=7372800;while(1){u=v+(x-7307264)|0;c[p>>2]=u;c[p+65536>>2]=u;c[p+131072>>2]=u;u=x+1024|0;if(u>>>0>7405567){break}else{p=p+4|0;x=u}}c[J+196688>>2]=638;c[J+196728>>2]=1328;c[J+196608>>2]=1704;c[J+196648>>2]=564;x=c[3532592]|0;if((x|0)!=0){gGC(x|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;Ux(0,13257,0);c[2407030]=256;c[2407068]=3;x=c[642608+(c[2436]<<2)>>2]|0;p=c[x+128>>2]|0;if((c[x+52>>2]&4|0)==0){c[2113068]=p;v=c[x+132>>2]|0;c[2113070]=v;c[2443814]=p;c[2440436]=v;K=p;L=v}else{c[2113070]=p;v=c[x+132>>2]|0;c[2113068]=v;c[2440436]=p;c[2443814]=v;K=v;L=p}p=ag(K<<1,L)|0;v=gGq(p)|0;c[2112926]=v;if((v|0)!=0){gGz(v|0,0,p|0)}if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];p=c[3532592]|0;if((p|0)!=0){gGC(9104152,p|0,280)|0}c[2113054]=c[2113060]}RI();p=c[2394]|0;v=c[14130368+(p<<2)>>2]|0;if((v|0)!=0){gGC(v|0,9104152,280)|0}c[8452240+(p<<2)>>2]=c[2113054];c[2394]=-1;c[3528174]=180;p=(fa(c[c[642608+(c[2436]<<2)>>2]>>2]|0,281104)|0)==0;c[2438872]=p?4:0;c[2430858]=0;c[2406812]=0;p=c[3541206]|0;v=p+131072|0;x=p+262144|0;gGC(v|0,x|0,131072)|0;c[2113156]=0;a[9628264]=0;c[2407033]=0;c[3541190]=p;c[3541198]=p;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=p+256;c[3541199]=p+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=p+512;c[3541200]=v;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=p+768;c[3541201]=p+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;t=0;i=b;return t|0}}while(0);c[2426730]=0;t=1;i=b;return t|0}function d08(){var a=0,b=0,d=0,e=0,f=0;Uw(0);if((c[2392]|0)>=0){a=0;do{b=14130368+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}b=14130384+(a<<2)|0;d=c[b>>2]|0;if((d|0)!=0){gGr(d);c[b>>2]=0}a=a+1|0;}while((a|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;c[2113070]=0;c[2113068]=0;a=c[2112926]|0;if((a|0)!=0){gGr(a);c[2112926]=0}a=c[2426730]|0;b=0;while(1){if((b|0)>=1024){e=40068;break}f=9638528+(b<<2)|0;if((c[f>>2]|0)==(a|0)){break}else{b=b+1|0}}if((e|0)==40068){c[2426730]=0;return 0}gGr(a);c[f>>2]=0;c[2426730]=0;return 0}function d09(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;if((a[9771888]|0)!=0){if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060]}RI();f=c[2394]|0;g=c[14130368+(f<<2)>>2]|0;if((g|0)!=0){gGC(g|0,9104152,280)|0}c[8452240+(f<<2)>>2]=c[2113054];c[2394]=-1;c[3528174]=180;f=(fa(c[c[642608+(c[2436]<<2)>>2]>>2]|0,281104)|0)==0;c[2438872]=f?4:0;c[2430858]=0;c[2406812]=0;f=c[3541206]|0;g=f+131072|0;h=f+262144|0;gGC(g|0,h|0,131072)|0;c[2113156]=0;a[9628264]=0;c[2407033]=0;c[3541190]=f;c[3541198]=f;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=f+256;c[3541199]=f+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=f+512;c[3541200]=g;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=f+768;c[3541201]=f+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4}b[4885949]=0;b[4885948]=0;f=0;g=0;h=0;do{g=((a[9723464+f|0]&1)<<f|g&65535)&65535;h=((a[9723448+f|0]&1)<<f|h&65535)&65535;f=f+1|0;}while((f|0)<10);b[4885948]=g;b[4885949]=h;if((g&3)==3){f=g&-4;b[4885948]=f;i=f}else{i=g}if((i&12)==12){b[4885948]=i&-13}if((h&3)==3){i=h&-4;b[4885949]=i;j=i}else{j=h}if((j&12)==12){b[4885949]=j&-13}j=c[2392]|0;if((j|0)>=0){gGz(8452240,0,((j|0)>0?(j<<2)+4|0:4)|0)}c[2113054]=0;if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];j=c[3532592]|0;if((j|0)!=0){gGC(9104152,j|0,280)|0}c[2113054]=c[2113060]}c[2113056]=2e5;j=RG(2e5)|0;c[2113054]=(c[2113054]|0)+j;c[2276108]=-1;c[2113056]=-1;j=c[2394]|0;c[8452200+(j<<2)>>2]=8193;c[2276080]=256;if((c[2276079]|0)>>>0<256){RH(1);k=c[2394]|0}else{k=j}j=c[14130368+(k<<2)>>2]|0;if((j|0)!=0){gGC(j|0,9104152,280)|0}c[8452240+(k<<2)>>2]=c[2113054];c[2394]=-1;k=c[3528174]|0;do{if((k|0)>0){j=k-1|0;c[3528174]=j;if((j|0)!=0){break}c[2394]=0;c[2112932]=c[3532596];j=c[3532592]|0;if((j|0)!=0){gGC(9104152,j|0,280)|0}c[2113054]=c[2113060];RI();j=c[2394]|0;h=c[14130368+(j<<2)>>2]|0;if((h|0)!=0){gGC(h|0,9104152,280)|0}c[8452240+(j<<2)>>2]=c[2113054];c[2394]=-1;c[3528174]=180}}while(0);if((c[2112968]|0)!=0){k=c[2438640]|0;j=0;h=c[2430860]|0;i=k;while(1){g=e[h>>1]|0;c[i>>2]=g>>>5<<11&63488|g&31|(g>>>10<<3|g>>>12&4)<<3&2016;g=j+1|0;if((g|0)<2048){j=g;h=h+2|0;i=i+4|0}else{break}}i=c[2437036]|0;h=c[2112926]|0;j=c[3540982]|0;g=0;f=0;while(1){l=g<<3;m=0;n=f;while(1){o=n<<1;p=d[i+(o|3)|0]<<8|d[i+(o|2)|0];q=a[i+(o|1)|0]&15;o=(m<<3)-97-(c[2438638]|0)|0;r=l-(c[2438636]|0)|0;do{if((o-8|0)>>>0<304){if((r-8|0)>>>0>=224){s=40113;break}Si(h,p,o,r,q,4,0,j)}else{s=40113}}while(0);if((s|0)==40113){s=0;Sj(h,p,o,r,q,4,0,j)}t=m+1|0;if((t|0)<64){m=t;n=n+2|0}else{break}}n=g+1|0;if((n|0)<64){g=n;f=f+128|0}else{break}}f=(c[2430858]|0)!=0?8192:0;g=f+8192|0;j=c[2433352]|0;i=c[3540980]|0;n=f;do{f=d[j+(n|7)|0]<<8;m=f&3840|d[j+(n|6)|0];l=a[j+(n|4)|0]&15;t=d[j+(n|1)|0]<<8|d[j+n|0];u=d[j+(n|3)|0]<<8|d[j+(n|2)|0];v=u>>>0>32767?u|-65536:u;u=t-125|0;w=f&32768;do{if((t-141|0)>>>0<288){if((v-16|0)>>>0>=208){s=40122;break}if((w|0)==0){SG(h,m,u,v,l,4,0,512,i);break}else{SI(h,m,u,v,l,4,0,512,i);break}}else{s=40122}}while(0);do{if((s|0)==40122){s=0;if((w|0)==0){SH(h,m,u,v,l,4,0,512,i);break}else{SJ(h,m,u,v,l,4,0,512,i);break}}}while(0);n=n+8|0;}while((n|0)<(g|0));R8(k)}k=c[2112964]|0;if((k|0)==0){return 0}Uu(0,k,a[9688]|0?534:0);return 0}function d1a(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>3){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5196340+(b*112|0)>>2];c[a+104>>2]=c[5196344+(b*112|0)>>2];c[a+108>>2]=c[5196348+(b*112|0)>>2];d=0;return d|0}function d1b(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<4&(d|0)==0)){e=1;return e|0}c[a>>2]=5196240+(b*112|0);e=0;return e|0}function d1c(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1795768+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function d1d(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>55){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5196688+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function d1e(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;e=i;i=i+192|0;f=e|0;g=e+16|0;h=e+32|0;j=e+48|0;k=e+64|0;l=e+80|0;m=e+96|0;n=e+112|0;o=e+128|0;p=e+144|0;q=e+160|0;r=e+176|0;if((d|0)!=0){c[d>>2]=10564}if((b&32|0)!=0){gGz(r|0,0,12);d=c[2405664]|0;c[r>>2]=d;c[r+4>>2]=(c[2411682]|0)-d;c[r+12>>2]=162152;d=c[2076592]|0;gj[d&4095](r)|0}if((b&64|0)!=0){r=h|0;gGz(g|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){d=h+9|0;h=f;s=f|0;t=f+4|0;u=f+12|0;v=g|0;w=g+4|0;x=g+12|0;y=0;do{gGC(r|0,614896,11)|0;a[d]=y+48&255;z=8452256+(y<<2)|0;gGz(h|0,0,12);c[s>>2]=z;c[t>>2]=4;c[u>>2]=164976;gj[c[2076592]&4095](f)|0;if((c[z>>2]|0)!=0){c[v>>2]=c[14130368+(y<<2)>>2];c[w>>2]=c[8452184+(y<<2)>>2];c[x>>2]=r;z=c[2076592]|0;gj[z&4095](g)|0}y=y+1|0;}while((y|0)<=(c[2392]|0))}Ut(0);gGz(q|0,0,12);c[q>>2]=9771896;c[q+4>>2]=4;c[q+12>>2]=232688;y=c[2076592]|0;gj[y&4095](q)|0;gGz(p|0,0,12);c[p>>2]=14116008;c[p+4>>2]=2;c[p+12>>2]=226712;q=c[2076592]|0;gj[q&4095](p)|0;gGz(o|0,0,12);c[o>>2]=9755488;c[o+4>>2]=4;c[o+12>>2]=220832;p=c[2076592]|0;gj[p&4095](o)|0;gGz(n|0,0,12);c[n>>2]=9627248;c[n+4>>2]=4;c[n+12>>2]=544168;o=c[2076592]|0;gj[o&4095](n)|0;gGz(m|0,0,12);c[m>>2]=14112696;c[m+4>>2]=4;c[m+12>>2]=213328;n=c[2076592]|0;gj[n&4095](m)|0;gGz(l|0,0,12);c[l>>2]=9723432;c[l+4>>2]=4;c[l+12>>2]=209352;m=c[2076592]|0;gj[m&4095](l)|0;gGz(k|0,0,12);c[k>>2]=9754552;c[k+4>>2]=4;c[k+12>>2]=204280;l=c[2076592]|0;gj[l&4095](k)|0;gGz(j|0,0,12);c[j>>2]=9754544;c[j+4>>2]=4;c[j+12>>2]=198016;k=c[2076592]|0;gj[k&4095](j)|0}if((b&2|0)==0){i=e;return 0}b=c[3541206]|0;j=b+131072|0;k=b+((c[2406812]<<17)+262144)|0;gGC(j|0,k|0,131072)|0;i=e;return 0}function d1f(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>3){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6208692+(b*112|0)>>2];c[a+104>>2]=c[6208696+(b*112|0)>>2];c[a+108>>2]=c[6208700+(b*112|0)>>2];d=0;return d|0}function d1g(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<4&(d|0)==0)){e=1;return e|0}c[a>>2]=6208592+(b*112|0);e=0;return e|0}function d1h(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>55){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6209040+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function d1i(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=a[5766496]|0;do{if(!((d&268435424|0)==16773184&(f^1))){if((d&268435440|0)==16773152&f){break}if((d&16515072|0)==12582912){g=d&262142;h=(c[3529096]|0)+g|0;if((b[h>>1]|0)==e<<16>>16){return}b[h>>1]=e;h=g<<1;i=c[3530336]|0;a[i+h|0]=(e&65535)>>>12&255;a[i+(h|1)|0]=(e&65535)>>>8&15;a[i+(h|2)|0]=(e&65535)>>>4&15;a[i+(h|3)|0]=e&15;a[(c[2438814]|0)+(g>>>7)|0]=1;return}if((d&16744448|0)==13631488){g=(c[2443484]|0)+(d&8190)|0;if((b[g>>1]|0)==e<<16>>16){return}b[g>>1]=e;a[(c[3531072]|0)+(d>>>1&4095)|0]=1;return}switch(d|0){case 16773190:case 16773191:{b[c[2443564]>>1]=e+26&255;return};case 16773122:case 16773123:{b[c[2443572]>>1]=e&511;return};case 16773124:case 16773125:{b[c[2443564]>>1]=e&255;return};case 16773188:case 16773189:{b[c[2443572]>>1]=e+80&511;return};default:{return}}}}while(0);b[(c[2387986]|0)+((d>>>1&15)<<1)>>1]=e;return}function d1j(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;if((b&16744448|0)==13631488){e=b&8191^1;f=(c[2443484]|0)+e|0;if((a[f]|0)==d<<24>>24){return}a[f]=d;a[(c[3531072]|0)+(e>>>1)|0]=1;return}if((b|0)==16773129){e=c[2433530]|0;f=(((c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0)/2|0)-e-(c[2426530]|0)+(c[2076596]|0)|0;do{if((f|0)>0){if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){g=gfc(f)|0;c[2433530]=(c[2433530]|0)+g;break}else{c[2433530]=f+e;break}}}while(0);a[c[2433512]|0]=-1;a[c[3528282]|0]=d;if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12;return}else if((b|0)==16773121){a[c[3528698]|0]=d&32;a[c[2406750]|0]=d&-33;return}else if((b|0)==16773120){b=c[2394688]|0;if((a[b]|0)==d<<24>>24){return}a[b]=d;gGz(c[3531072]|0,1,4096);return}else{return}}function d1k(a){a=a|0;var b=0;if((a|0)==16773124){b=(d[9635137]|0)<<8|(d[9635136]|0)}else if((a|0)==16773126){b=(d[9635138]|0)<<8}else{b=0}return b|0}function d1l(b){b=b|0;var d=0;switch(b|0){case 16773120:case 16773121:{d=(e[4775e3]|0)>>>((b<<3&8^8)>>>0)&255;break};case 16773125:{d=a[9635137]|0;break};case 16773124:{d=a[9635136]|0;break};case 16773129:{d=a[c[2433512]|0]|0;break};case 16773126:{d=a[9635138]|0;break};case 16773131:case 16773201:{d=a[9635139]|0;break};default:{d=0}}return d|0}function d1m(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=b&65535;switch(e&255|0){case 20:{a[c[2433512]|0]=0;return};case 24:case 25:case 26:case 27:{l7(e&3,d);return};case 0:case 12:{e=d&1;d=e<<15;a[c[3529366]|0]=e&255;e=c[2385928]|0;b=c[9757320+(c[1836236]<<2)>>2]|0;f=128;g=128;while(1){c[b+76+(g<<2)>>2]=e+((g<<8)+d);h=f+1&65535;if((h&65535)>255){i=128;j=128;break}else{f=h;g=h&65535}}while(1){g=e+((j<<8)+d)|0;c[b+76+(j+512<<2)>>2]=g;c[b+76+(j+768<<2)>>2]=g;g=i+1&65535;if((g&65535)>255){break}else{i=g;j=g&65535}}return};default:{return}}}function d1n(b){b=b|0;var d=0,e=0;d=b&65535;switch(d&255|0){case 20:{e=a[c[3528282]|0]|0;break};case 24:case 25:case 26:case 27:{e=l8(d&3)|0;break};default:{e=0}}return e|0}function d1o(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7054748+(b*112|0)>>2];c[a+104>>2]=c[7054752+(b*112|0)>>2];c[a+108>>2]=c[7054756+(b*112|0)>>2];d=0;return d|0}function d1p(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<21&(d|0)==0)){e=1;return e|0}c[a>>2]=7054648+(b*112|0);e=0;return e|0}function d1q(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6320184+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function d1r(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>48){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=7216736+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function d1s(){return d1I(0)|0}function d1t(){var b=0,d=0,e=0,f=0,g=0;c[2113070]=0;c[2113068]=0;b=c[2112926]|0;if((b|0)!=0){gGr(b);c[2112926]=0}b=c[3541514]|0;if((b|0)!=0){gGr(b|0);c[3541514]=0}c[2113008]=0;c[2076598]=0;c[2383582]=0;c[2438228]=0;c[2433526]=0;c[2406676]=0;c[3528472]=0;b=c[2406698]|0;if((b|0)!=0){gGr(b);c[2406698]=0}b=c[2385412]|0;if((b|0)!=0){gGr(b);c[2385412]=0}a[64232]=0;if((c[2392]|0)>=0){b=0;do{d=14130368+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}d=14130384+(b<<2)|0;e=c[d>>2]|0;if((e|0)!=0){gGr(e);c[d>>2]=0}b=b+1|0;}while((b|0)<=(c[2392]|0))}c[2112932]=0;c[2394]=-1;c[2392]=-1;fwZ();b=c[2414974]|0;d=0;while(1){if((d|0)>=1024){f=40313;break}g=9638528+(d<<2)|0;if((c[g>>2]|0)==(b|0)){break}else{d=d+1|0}}if((f|0)==40313){c[2414974]=0;a[5766496]=0;return 0}gGr(b);c[g>>2]=0;c[2414974]=0;a[5766496]=0;return 0}function d1u(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0;if((a[9624248]|0)!=0){a[9624248]=0;d=c[2414678]|0;gGz(d|0,0,(c[2411680]|0)-d|0);gGz(c[3531072]|0,1,4096);gGz(c[2438814]|0,1,2048);if((c[2394]|0)!=0){c[2394]=0;c[2112932]=c[3532596];d=c[3532592]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113060]}RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=1;c[2112932]=c[3532597];d=c[3532593]|0;if((d|0)!=0){gGC(9104152,d|0,280)|0}c[2113054]=c[2113061];RI();d=c[2394]|0;e=c[14130368+(d<<2)>>2]|0;if((e|0)!=0){gGC(e|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=i;c[1836236]=-1;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;l6(0)}i=c[2392]|0;if((i|0)>=0){gGz(8452240,0,((i|0)>0?(i<<2)+4|0:4)|0)}c[2113054]=0;i=c[2385548]|0;if((i|0)>0){gGz(9752472,0,((i|0)>1?i<<2:4)|0)}c[2433530]=0;b[4775e3]=-1;i=0;g=-1;do{g=((a[9633536+i|0]&1)<<i^g&65535)&65535;i=i+1|0;}while((i|0)<16);b[4775e3]=g;g=c[2439330]|0;if((g|0)!=0){i=g;gGC(9706056,i|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;i=0;g=0;f=(c[2394]|0)==0;while(1){e=g+1|0;d=(e*1666|0)-i|0;if(!f){c[2394]=0;c[2112932]=c[3532596];j=c[3532592]|0;if((j|0)!=0){gGC(9104152,j|0,280)|0}c[2113054]=c[2113060]}c[2113056]=d;j=RG(d)|0;k=(c[2113054]|0)+j|0;c[2113054]=k;c[2276108]=-1;c[2113056]=-1;l=j+i|0;j=c[2394]|0;do{if((g|0)==99){c[8452200+(j<<2)>>2]=8193;c[2276080]=256;if((c[2276079]|0)>>>0<256){RH(1);m=c[2394]|0}else{m=j}n=c[14130368+(m<<2)>>2]|0;if((n|0)!=0){gGC(n|0,9104152,280)|0}c[8452240+(m<<2)>>2]=c[2113054];c[2394]=1;c[2112932]=c[3532597];n=c[3532593]|0;if((n|0)!=0){gGC(9104152,n|0,280)|0}c[2113054]=c[2113061];c[2113056]=d;n=RG(d)|0;c[2113054]=(c[2113054]|0)+n;c[2276108]=-1;c[2113056]=-1;c[8452200+(c[2394]<<2)>>2]=8193;c[2276080]=256;if((c[2276079]|0)>>>0>=256){break}RH(1)}else{n=c[14130368+(j<<2)>>2]|0;if((n|0)!=0){gGC(n|0,9104152,280)|0}c[8452240+(j<<2)>>2]=k;c[2394]=1;c[2112932]=c[3532597];n=c[3532593]|0;if((n|0)!=0){gGC(9104152,n|0,280)|0}c[2113054]=c[2113061];c[2113056]=d;n=RG(d)|0;c[2113054]=(c[2113054]|0)+n;c[2276108]=-1;c[2113056]=-1}}while(0);d=c[2394]|0;k=c[14130368+(d<<2)>>2]|0;if((k|0)!=0){gGC(k|0,9104152,280)|0}c[8452240+(d<<2)>>2]=c[2113054];c[2394]=-1;if((e|0)<100){i=l;g=e;f=0}else{break}}f=c[2438228]|0;g=gGS(1163526144,39736,f,(f|0)<0|0?-1:0)|0;f=g;Sb(83333);g=c[2443830]|0;if((g|0)<1073676288){c[2443830]=g-f}g=c[2443831]|0;if((g|0)<1073676288){c[2443831]=g-f}g=(c[3528512]|0)-f|0;c[3528512]=(g|0)<0?0:g;g=c[2112964]|0;if((g|0)!=0){gg[c[3542118]&4095](g,a[9688]|0?534:0)}g=c[1836236]|0;f=c[9757320+(g<<2)>>2]|0;if((f|0)!=0){i=f;gGC(i|0,9706056,76)|0}c[9752472+(g<<2)>>2]=c[2433530];c[14113936+(g<<2)>>2]=c[2076596];c[9669104+(g<<2)>>2]=c[3541536];c[1836236]=-1;if((c[2112968]|0)==0){return 0}g=c[(c[642608+(c[2436]<<2)>>2]|0)+112>>2]|0;if((g|0)==0){return 0}gD[g&8191]()|0;return 0}function d1v(){var d=0,e=0,f=0,g=0,h=0;if((a[9547504]|0)!=0){d=c[2387208]|0;e=c[3530022]|0;f=0;do{g=b[d+(f<<1)>>1]|0;c[e+(f<<2)>>2]=((g&65535)>>>10<<3&248)<<8|((g&255)<<3&255)>>>3|(((g&65535)>>>5<<3&255|(g&65535)>>>7&4)&255)<<3&2016;f=f+1|0;}while((f|0)<1024);c[e+4096>>2]=0}d1D();d1E(0);e=(a[c[2406750]|0]|0)==0;d1M(c[3527258]|0,c[2443446]|0,c[3530436]|0,32);if(e){d1M(c[3527260]|0,c[2443448]|0,c[3530614]|0,16);d1G(1);h=c[3530022]|0;R8(h);return 0}else{d1G(1);d1M(c[3527260]|0,c[2443448]|0,c[3530614]|0,16);h=c[3530022]|0;R8(h);return 0}return 0}function d1w(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=i;i=i+64|0;g=f|0;h=f+16|0;j=f+32|0;k=f+48|0;if((e|0)!=0){c[e>>2]=169730}if((d&32|0)!=0){gGz(k|0,0,12);l=c[2414678]|0;c[k>>2]=l;c[k+4>>2]=(c[2411680]|0)-l;c[k+12>>2]=162152;l=c[2076592]|0;gj[l&4095](k)|0}if((d&64|0)!=0){k=j|0;gGz(h|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){l=j+9|0;j=g;m=g|0;n=g+4|0;o=g+12|0;p=h|0;q=h+4|0;r=h+12|0;s=0;do{gGC(k|0,614896,11)|0;a[l]=s+48&255;t=8452256+(s<<2)|0;gGz(j|0,0,12);c[m>>2]=t;c[n>>2]=4;c[o>>2]=164976;gj[c[2076592]&4095](g)|0;if((c[t>>2]|0)!=0){c[p>>2]=c[14130368+(s<<2)>>2];c[q>>2]=c[8452184+(s<<2)>>2];c[r>>2]=k;t=c[2076592]|0;gj[t&4095](h)|0}s=s+1|0;}while((s|0)<=(c[2392]|0))}fw$(d);T0(d,e)}if((d&2|0)==0){i=f;return 0}if(!(a[5766496]|0)){d=c[3529096]|0;e=c[3530336]|0;s=c[2438814]|0;h=0;do{k=b[d+h>>1]|0;r=h<<1;a[e+r|0]=(k&65535)>>>12&255;a[e+(r|1)|0]=(k&65535)>>>8&15;a[e+(r|2)|0]=(k&65535)>>>4&15;a[e+(r|3)|0]=k&15;a[s+(r>>8)|0]=1;h=h+2|0;}while((h|0)<262144)}h=c[2439330]|0;s=(h|0)==0;if(!s){e=h;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];e=c[3528484]|0;c[2076596]=e;d=c[2417276]|0;c[3541536]=d;c[1836236]=0;r=c[3529366]|0;k=a[r]&1;q=k<<15;a[r]=k&255;k=c[2385928]|0;r=128;p=128;while(1){c[h+76+(p<<2)>>2]=k+((p<<8)+q);g=r+1&65535;if((g&65535)>255){u=128;v=128;break}else{r=g;p=g&65535}}while(1){p=k+((v<<8)+q)|0;c[h+76+(v+512<<2)>>2]=p;c[h+76+(v+768<<2)>>2]=p;p=u+1&65535;if((p&65535)>255){break}else{u=p;v=p&65535}}if(!s){s=h;gGC(s|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=e;c[2417276]=d;c[1836236]=-1;i=f;return 0}function d1x(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6578836+(b*112|0)>>2];c[a+104>>2]=c[6578840+(b*112|0)>>2];c[a+108>>2]=c[6578844+(b*112|0)>>2];d=0;return d|0}function d1y(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=6578736+(b*112|0);e=0;return e|0}function d1z(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5421312+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function d1A(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>44){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6888264+(b*12|0)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];d=0;return d|0}function d1B(){return d1I(1)|0}function d1C(){var e=0,f=0,g=0,h=0;if((a[9547504]|0)!=0){e=c[2387208]|0;f=c[3530022]|0;g=0;do{h=b[e+(g<<1)>>1]|0;c[f+(g<<2)>>2]=((h&65535)>>>10<<3&248)<<8|((h&255)<<3&255)>>>3|(((h&65535)>>>5<<3&255|(h&65535)>>>7&4)&255)<<3&2016;g=g+1|0;}while((g|0)<1024);c[f+4096>>2]=0}d1D();f=d[c[2406750]|0]|0;do{if((f&4|0)==0){g=f&3;if((g|0)==0){d1E(0);d1F();d1G(1);break}else if((g|0)==1){d1E(0);d1G(1);d1F();break}else if((g|0)==2){d1G(0);d1E(1);d1F();break}else{break}}}while(0);R8(c[3530022]|0);return 0}function d1D(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;e=c[2443484]|0;f=c[3531072]|0;g=c[2438814]|0;h=c[2406554]|0;i=c[2394688]|0;j=a[5766496]|0?256:768;k=c[3530336]|0;l=e;m=0;while(1){n=f+((m|0)/2|0)|0;if((a[n]|0)==0){if((a[g+(b[l>>1]&2047)|0]|0)!=0){o=40452}}else{o=40452}if((o|0)==40452){o=0;p=b[e+m>>1]|0;q=j|(p&65535)>>>12<<4;r=h+((m<<3&1008|m>>>7<<14)<<1)|0;s=k+((d[i]<<11|p&2047)<<8)|0;p=0;while(1){t=0;do{u=s+t|0;v=q|d[u];w=r+(t<<1)|0;b[w>>1]=v;if((a[u]|0)==15){b[w>>1]=v|-32768}t=t+1|0;}while((t|0)<16);t=p+1|0;if((t|0)<16){r=r+2048|0;s=s+16|0;p=t}else{break}}a[n]=0}p=m+2|0;if((p|0)>=8192){break}l=l+2|0;m=p}gGz(g|0,0,2048);return}function d1E(d){d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;e=c[2387986]|0;f=b[e>>1]<<8;g=b[e+2>>1]<<8;h=b[e+4>>1]|0;i=b[e+6>>1]|0;j=b[e+8>>1]|0;k=b[e+10>>1]|0;l=b[e+12>>1]|0;if((l&16384)==0){m=i;n=h}else{m=i<<8;n=h<<8}if((l&64)==0){o=k;p=j}else{o=k<<8;p=j<<8}if(a[5766496]|0){q=(m*21|0)+g+(o*48|0)|0;r=(n*21|0)+f+(p*48|0)|0}else{q=(m*10|0)+g+(o*58|0)|0;r=(n*10|0)+f+(p*58|0)|0}f=r<<5;r=q<<5;q=p<<5;p=o<<5;o=n<<5;n=m<<5;m=c[2112926]|0;g=c[2406554]|0;j=c[2113070]|0;if((j|0)<=0){return}k=c[2113068]|0;if((d|0)==0){d=m;l=r;h=0;i=f;while(1){if((k|0)>0){e=d;s=i;t=l;u=0;while(1){b[e>>1]=b[g+((t>>>16<<10&1047552|s>>>16&1023)<<1)>>1]&1023;v=u+1|0;w=e+2|0;if((v|0)<(k|0)){e=w;s=s+q|0;t=t+p|0;u=v}else{x=w;break}}}else{x=d}u=h+1|0;if((u|0)<(j|0)){d=x;l=l+n|0;h=u;i=i+o|0}else{break}}return}else{y=m;z=r;A=0;B=f}while(1){if((k|0)>0){f=y;r=B;m=z;i=0;while(1){h=b[g+((m>>>16<<10&1047552|r>>>16&1023)<<1)>>1]|0;if(h<<16>>16>-1){b[f>>1]=h}h=i+1|0;l=f+2|0;if((h|0)<(k|0)){f=l;r=r+q|0;m=m+p|0;i=h}else{C=l;break}}}else{C=y}i=A+1|0;if((i|0)<(j|0)){y=C;z=z+n|0;A=i;B=B+o|0}else{break}}return}function d1F(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;d=c[3527260]|0;f=c[2443448]|0;g=c[3528698]|0;h=c[3530614]|0;i=c[2113222]&15;j=0;while(1){k=e[d+(j<<1)>>1]|0;if((k&16384|0)!=0){l=40494;break}m=j+1|0;n=k<<2&2044;k=e[d+(n<<1)>>1]|0;o=k>>>9&7;p=e[d+((n|1)<<1)>>1]|0;q=p>>>9&7;r=e[d+((n|2)<<1)>>1]|0;s=32-(p>>>12)|0;t=32-(k>>>12)|0;u=k+16|0;k=p+16|0;p=((r&8447|0)==0?r>>>8&31:i)|32;v=q+1|0;w=0;x=b[d+((n|3)<<1)>>1]&32767;n=r&16384;y=r&32768;while(1){r=0;z=x;A=n;B=y;C=(u+((ag((y|0)==0?w:o-w|0,t)|0)/2|0)&511)-16|0;while(1){D=(A|0)!=0;E=k+((ag(D?q-r|0:r,s)|0)/2|0)&511;if((a[g]|0)==0){F=C;G=E-16|0;H=B;I=A}else{F=208-C|0;G=320-E|0;H=(B|0)==0|0;I=D&1^1}d1H(h,b[f+((z&16383)<<1)>>1]&16383,p,G,F,16,16,I,H);D=r+1|0;if((D|0)>(q|0)){break}else{r=D;z=z+1|0;A=I;B=H;C=F}}C=w+1|0;if((C|0)>(o|0)){break}else{w=C;x=v+x|0;n=I;y=H}}if((m|0)<1024){j=m}else{l=40493;break}}if((l|0)==40493){return}else if((l|0)==40494){return}}function d1G(b){b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=b*255|0;b=c[2386218]|0;f=a[5766496]|0?0:8;g=(d|0)==0;h=c[2443572]|0;i=c[2443564]|0;j=c[2112926]|0;k=c[3530850]|0;l=c[2113068]|0;m=c[2113070]|0;n=f;do{o=(n<<3&504)-(e[h>>1]|0)|0;p=(o|0)<-7?o+512|0:o;o=(n>>6<<3)-f-(e[i>>1]|0)|0;q=(o|0)<-7?o+256|0:o;o=e[b+(n<<1)>>1]|0;r=o&32767;do{if((p|0)<(l|0)&(q|0)<(m|0)){s=(o&32768|0)!=0;if(g){if(s){Sn(j,r,p,q,0,8,0,k);break}else{Sj(j,r,p,q,0,8,0,k);break}}else{if(s){Sv(j,r,p,q,0,8,d,0,k);break}else{Sr(j,r,p,q,0,8,d,0,k);break}}}}while(0);n=n+1|0;}while((n|0)<2048);return}function d1H(d,e,f,g,h,i,j,k,l){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;if((j|0)<2|(i|0)<2){return}if((j|0)==16&(i|0)==16){m=(k|0)!=0;n=c[2112926]|0;if((l|0)==0){if(m){SJ(n,e,g,h,f,4,15,0,d);return}else{SH(n,e,g,h,f,4,15,0,d);return}}else{if(m){SN(n,e,g,h,f,4,15,0,d);return}else{SL(n,e,g,h,f,4,15,0,d);return}}}else{n=k*15|0;k=(l>>1)*15|0;l=f<<4;f=e<<8;e=i-1|0;i=j-1|0;j=c[2113070]|0;m=c[2113068]|0;o=c[2112926]|0;p=0;do{q=p+h|0;r=b[14110072+(i*66|0)+((p^k)<<1)>>1]|0;s=r<<16>>16;do{if(r<<16>>16!=-1){t=(q|0)<0;if(!((q|0)<(j|0)&(t^1))){break}u=s<<4;v=ag(m,q)|0;w=0;do{x=b[14110072+(e*66|0)+((w^n)<<1)>>1]|0;do{if(x<<16>>16!=-1){y=w+g|0;z=a[d+((x<<16>>16|u)+f)|0]|0;if(z<<24>>24==15|(y|0)<0){break}if((y|0)>=(m|0)|t){break}b[o+(v+y<<1)>>1]=(z&255|l)&65535}}while(0);w=w+1|0;}while((w|0)<16)}}while(0);p=p+1|0;}while((p|0)<16);return}}
function Cd(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0);f=n&65535;o=f>>>6;e=o&31;j=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;l=p&-4;if((l|0)==(h|0)){q=p;r=g}else{c[2276083]=l;g=c[2276085]&l;l=g&16777212;h=c[2112932]|0;k=c[h+((l>>>10|32768)<<2)>>2]|0;if(k>>>0>9){b=g&1020;s=(d[k+(b|3)|0]|0)<<8|(d[k+(b|2)|0]|0)|((d[k+(b|1)|0]|0)<<8|(d[k+b|0]|0))<<16;t=p}else{p=gj[c[h+196768+(k<<2)>>2]&4095](l)|0;s=p;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;if((n&2048|0)==0){u=e}else{u=c[9104156+((o&7)<<2)>>2]|0}if((n&32|0)==0){v=f}else{v=c[9104156+((n&7)<<2)>>2]|0}n=(r>>>((q<<3&16^16)>>>0)<<16>>16)+j+((u|0)/8|0)|0;j=(u|0)%8|0;if((j|0)<0){w=n-1|0;x=j+8|0}else{w=n;x=j}j=v+31&31;v=-1<<(j^31);n=v>>>(x>>>0);u=c[2276085]|0;q=u&w;r=q&16777215;f=c[2112932]|0;o=c[f+(r>>>10<<2)>>2]|0;if(o>>>0>9){e=q&1023;y=(d[o+(e+3)|0]|0)<<8|(d[o+(e+2)|0]|0)|((d[o+(e+1)|0]|0)<<8|(d[o+e|0]|0))<<16;z=u;A=f}else{u=gj[c[f+196768+(o<<2)>>2]&4095](r)|0;y=u;z=c[2276085]|0;A=c[2112932]|0}c[2276075]=y<<x>>>24;c[2276076]=y&n;c[2276077]=0;c[2276078]=0;u=y^n;n=z&w;z=n&16777215;y=c[A+((z>>>10|16384)<<2)>>2]|0;if(y>>>0>9){r=n&1023;a[y+r|0]=u>>>16&255;a[y+(r+1)|0]=u>>>24&255;a[y+(r+2)|0]=u&255;a[y+(r+3)|0]=u>>>8&255}else{gg[c[A+196808+(y<<2)>>2]&4095](z,u)}if((j+1+x|0)>>>0<=32){return}x=w+4|0;w=c[2276085]|0;j=w&x;u=j&16777215;z=c[2112932]|0;y=c[z+(u>>>10<<2)>>2]|0;if(y>>>0>9){B=a[y+(j&1023^1)|0]|0;C=w;D=z}else{w=gj[c[z+196608+(y<<2)>>2]&4095](u)|0;B=w;C=c[2276085]|0;D=c[2112932]|0}w=B&255;c[2276076]=v&w|c[2276076];B=C&x;x=(w^v)&255;v=B&16777215;w=c[D+((v>>>10|16384)<<2)>>2]|0;if(w>>>0>9){a[w+(B&1023^1)|0]=x;return}else{gg[c[D+196648+(w<<2)>>2]&4095](v,x);return}}function Ce(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0);f=l&65535;g=f>>>6;m=xw(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;if((l&2048|0)==0){n=g&31}else{n=c[9104156+((g&7)<<2)>>2]|0}if((l&32|0)==0){o=f}else{o=c[9104156+((l&7)<<2)>>2]|0}l=((n|0)/8|0)+m|0;m=(n|0)%8|0;if((m|0)<0){p=l-1|0;q=m+8|0}else{p=l;q=m}m=o+31&31;o=-1<<(m^31);l=o>>>(q>>>0);n=c[2276085]|0;f=n&p;g=f&16777215;b=c[2112932]|0;e=c[b+(g>>>10<<2)>>2]|0;if(e>>>0>9){j=f&1023;r=(d[e+(j+3)|0]|0)<<8|(d[e+(j+2)|0]|0)|((d[e+(j+1)|0]|0)<<8|(d[e+j|0]|0))<<16;s=n;t=b}else{n=gj[c[b+196768+(e<<2)>>2]&4095](g)|0;r=n;s=c[2276085]|0;t=c[2112932]|0}c[2276075]=r<<q>>>24;c[2276076]=r&l;c[2276077]=0;c[2276078]=0;n=r^l;l=s&p;s=l&16777215;r=c[t+((s>>>10|16384)<<2)>>2]|0;if(r>>>0>9){g=l&1023;a[r+g|0]=n>>>16&255;a[r+(g+1)|0]=n>>>24&255;a[r+(g+2)|0]=n&255;a[r+(g+3)|0]=n>>>8&255}else{gg[c[t+196808+(r<<2)>>2]&4095](s,n)}if((m+1+q|0)>>>0<=32){return}q=p+4|0;p=c[2276085]|0;m=p&q;n=m&16777215;s=c[2112932]|0;r=c[s+(n>>>10<<2)>>2]|0;if(r>>>0>9){u=a[r+(m&1023^1)|0]|0;v=p;w=s}else{p=gj[c[s+196608+(r<<2)>>2]&4095](n)|0;u=p;v=c[2276085]|0;w=c[2112932]|0}p=u&255;c[2276076]=o&p|c[2276076];u=v&q;q=(p^o)&255;o=u&16777215;p=c[w+((o>>>10|16384)<<2)>>2]|0;if(p>>>0>9){a[p+(u&1023^1)|0]=q;return}else{gg[c[w+196648+(p<<2)>>2]&4095](o,q);return}}function Cf(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0);f=n&65535;o=f>>>6;e=o&31;j=p&-4;if((j|0)==(h|0)){q=p;r=g}else{c[2276083]=j;g=c[2276085]&j;j=g&16777212;h=c[2112932]|0;l=c[h+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){k=g&1020;s=(d[l+(k|3)|0]|0)<<8|(d[l+(k|2)|0]|0)|((d[l+(k|1)|0]|0)<<8|(d[l+k|0]|0))<<16;t=p}else{p=gj[c[h+196768+(l<<2)>>2]&4095](j)|0;s=p;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;if((n&2048|0)==0){u=e}else{u=c[9104156+((o&7)<<2)>>2]|0}if((n&32|0)==0){v=f}else{v=c[9104156+((n&7)<<2)>>2]|0}n=((u|0)/8|0)+(r>>>((q<<3&16^16)>>>0)<<16>>16)|0;q=(u|0)%8|0;if((q|0)<0){w=n-1|0;x=q+8|0}else{w=n;x=q}q=v+31&31;v=-1<<(q^31);n=v>>>(x>>>0);u=c[2276085]|0;r=u&w;f=r&16777215;o=c[2112932]|0;e=c[o+(f>>>10<<2)>>2]|0;if(e>>>0>9){s=r&1023;y=(d[e+(s+3)|0]|0)<<8|(d[e+(s+2)|0]|0)|((d[e+(s+1)|0]|0)<<8|(d[e+s|0]|0))<<16;z=u;A=o}else{u=gj[c[o+196768+(e<<2)>>2]&4095](f)|0;y=u;z=c[2276085]|0;A=c[2112932]|0}c[2276075]=y<<x>>>24;c[2276076]=y&n;c[2276077]=0;c[2276078]=0;u=y^n;n=z&w;z=n&16777215;y=c[A+((z>>>10|16384)<<2)>>2]|0;if(y>>>0>9){f=n&1023;a[y+f|0]=u>>>16&255;a[y+(f+1)|0]=u>>>24&255;a[y+(f+2)|0]=u&255;a[y+(f+3)|0]=u>>>8&255}else{gg[c[A+196808+(y<<2)>>2]&4095](z,u)}if((q+1+x|0)>>>0<=32){return}x=w+4|0;w=c[2276085]|0;q=w&x;u=q&16777215;z=c[2112932]|0;y=c[z+(u>>>10<<2)>>2]|0;if(y>>>0>9){B=a[y+(q&1023^1)|0]|0;C=w;D=z}else{w=gj[c[z+196608+(y<<2)>>2]&4095](u)|0;B=w;C=c[2276085]|0;D=c[2112932]|0}w=B&255;c[2276076]=v&w|c[2276076];B=C&x;x=(w^v)&255;v=B&16777215;w=c[D+((v>>>10|16384)<<2)>>2]|0;if(w>>>0>9){a[w+(B&1023^1)|0]=x;return}else{gg[c[D+196648+(w<<2)>>2]&4095](v,x);return}}function Cg(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0);f=n&65535;o=f>>>6;e=o&31;j=p&-4;if((j|0)==(h|0)){q=p;r=h;s=g}else{c[2276083]=j;g=c[2276085]&j;h=g&16777212;l=c[2112932]|0;k=c[l+((h>>>10|32768)<<2)>>2]|0;if(k>>>0>9){b=g&1020;t=(d[k+(b|3)|0]|0)<<8|(d[k+(b|2)|0]|0)|((d[k+(b|1)|0]|0)<<8|(d[k+b|0]|0))<<16;u=p;v=j}else{j=gj[c[l+196768+(k<<2)>>2]&4095](h)|0;t=j;u=c[2276056]|0;v=c[2276083]|0}c[2276084]=t;q=u;r=v;s=t}t=q+2|0;c[2276056]=t;q=t&-4;if((q|0)==(r|0)){w=s;x=t}else{c[2276083]=q;r=c[2276085]&q;q=r&16777212;v=c[2112932]|0;u=c[v+((q>>>10|32768)<<2)>>2]|0;if(u>>>0>9){j=r&1020;y=(d[u+(j|3)|0]|0)<<8|(d[u+(j|2)|0]|0)|((d[u+(j|1)|0]|0)<<8|(d[u+j|0]|0))<<16;z=t}else{t=gj[c[v+196768+(u<<2)>>2]&4095](q)|0;y=t;z=c[2276056]|0}c[2276084]=y;w=y>>>16|s<<16;x=z}c[2276056]=x+2;if((n&2048|0)==0){A=e}else{A=c[9104156+((o&7)<<2)>>2]|0}if((n&32|0)==0){B=f}else{B=c[9104156+((n&7)<<2)>>2]|0}n=((A|0)/8|0)+w|0;w=(A|0)%8|0;if((w|0)<0){C=n-1|0;D=w+8|0}else{C=n;D=w}w=B+31&31;B=-1<<(w^31);n=B>>>(D>>>0);A=c[2276085]|0;f=A&C;o=f&16777215;e=c[2112932]|0;x=c[e+(o>>>10<<2)>>2]|0;if(x>>>0>9){z=f&1023;E=(d[x+(z+3)|0]|0)<<8|(d[x+(z+2)|0]|0)|((d[x+(z+1)|0]|0)<<8|(d[x+z|0]|0))<<16;F=A;G=e}else{A=gj[c[e+196768+(x<<2)>>2]&4095](o)|0;E=A;F=c[2276085]|0;G=c[2112932]|0}c[2276075]=E<<D>>>24;c[2276076]=E&n;c[2276077]=0;c[2276078]=0;A=E^n;n=F&C;F=n&16777215;E=c[G+((F>>>10|16384)<<2)>>2]|0;if(E>>>0>9){o=n&1023;a[E+o|0]=A>>>16&255;a[E+(o+1)|0]=A>>>24&255;a[E+(o+2)|0]=A&255;a[E+(o+3)|0]=A>>>8&255}else{gg[c[G+196808+(E<<2)>>2]&4095](F,A)}if((w+1+D|0)>>>0<=32){return}D=C+4|0;C=c[2276085]|0;w=C&D;A=w&16777215;F=c[2112932]|0;E=c[F+(A>>>10<<2)>>2]|0;if(E>>>0>9){H=a[E+(w&1023^1)|0]|0;I=C;J=F}else{C=gj[c[F+196608+(E<<2)>>2]&4095](A)|0;H=C;I=c[2276085]|0;J=c[2112932]|0}C=H&255;c[2276076]=B&C|c[2276076];H=I&D;D=(C^B)&255;B=H&16777215;C=c[J+((B>>>10|16384)<<2)>>2]|0;if(C>>>0>9){a[C+(H&1023^1)|0]=D;return}else{gg[c[J+196648+(C<<2)>>2]&4095](B,D);return}}function Ch(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[2276038]&24|0)==0){Bl();return}a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=f>>>((e<<3&16^16)>>>0);e=k&65535;f=e>>>6;l=9104156+((c[2276069]&7)<<2)|0;if((k&2048|0)==0){m=f&31}else{m=c[9104156+((f&7)<<2)>>2]|0}if((k&32|0)==0){n=e}else{n=c[9104156+((k&7)<<2)>>2]|0}k=m&31;m=-1<<(n+31&31^31);n=32-k|0;e=(n>>>0<32?m<<n:0)|m>>>(k>>>0);c[2276075]=c[l>>2]<<k>>>24;c[2276076]=e&c[l>>2];c[2276077]=0;c[2276078]=0;c[l>>2]=c[l>>2]&~e;return}function Ci(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0);f=l&65535;g=f>>>6;if((l&2048|0)==0){n=g&31}else{n=c[9104156+((g&7)<<2)>>2]|0}if((l&32|0)==0){o=f}else{o=c[9104156+((l&7)<<2)>>2]|0}l=((n|0)/8|0)+(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;f=(n|0)%8|0;if((f|0)<0){p=l-1|0;q=f+8|0}else{p=l;q=f}f=o+31&31;o=-1<<(f^31);l=o>>>(q>>>0);n=c[2276085]|0;g=n&p;m=g&16777215;b=c[2112932]|0;e=c[b+(m>>>10<<2)>>2]|0;if(e>>>0>9){j=g&1023;r=(d[e+(j+3)|0]|0)<<8|(d[e+(j+2)|0]|0)|((d[e+(j+1)|0]|0)<<8|(d[e+j|0]|0))<<16;s=n;t=b}else{n=gj[c[b+196768+(e<<2)>>2]&4095](m)|0;r=n;s=c[2276085]|0;t=c[2112932]|0}c[2276075]=r<<q>>>24;c[2276076]=r&l;c[2276077]=0;c[2276078]=0;n=r&~l;l=s&p;s=l&16777215;r=c[t+((s>>>10|16384)<<2)>>2]|0;if(r>>>0>9){m=l&1023;a[r+m|0]=n>>>16&255;a[r+(m+1)|0]=n>>>24&255;a[r+(m+2)|0]=n&255;a[r+(m+3)|0]=n>>>8&255}else{gg[c[t+196808+(r<<2)>>2]&4095](s,n)}if((f+1+q|0)>>>0<=32){return}q=p+4|0;p=c[2276085]|0;f=p&q;n=f&16777215;s=c[2112932]|0;r=c[s+(n>>>10<<2)>>2]|0;if(r>>>0>9){u=a[r+(f&1023^1)|0]|0;v=p;w=s}else{p=gj[c[s+196608+(r<<2)>>2]&4095](n)|0;u=p;v=c[2276085]|0;w=c[2112932]|0}p=u&255;c[2276076]=p&o|c[2276076];u=v&q;q=p&(o^255)&255;o=u&16777215;p=c[w+((o>>>10|16384)<<2)>>2]|0;if(p>>>0>9){a[p+(u&1023^1)|0]=q;return}else{gg[c[w+196648+(p<<2)>>2]&4095](o,q);return}}function Cj(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0);f=n&65535;o=f>>>6;e=o&31;j=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;l=p&-4;if((l|0)==(h|0)){q=p;r=g}else{c[2276083]=l;g=c[2276085]&l;l=g&16777212;h=c[2112932]|0;k=c[h+((l>>>10|32768)<<2)>>2]|0;if(k>>>0>9){b=g&1020;s=(d[k+(b|3)|0]|0)<<8|(d[k+(b|2)|0]|0)|((d[k+(b|1)|0]|0)<<8|(d[k+b|0]|0))<<16;t=p}else{p=gj[c[h+196768+(k<<2)>>2]&4095](l)|0;s=p;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;if((n&2048|0)==0){u=e}else{u=c[9104156+((o&7)<<2)>>2]|0}if((n&32|0)==0){v=f}else{v=c[9104156+((n&7)<<2)>>2]|0}n=(r>>>((q<<3&16^16)>>>0)<<16>>16)+j+((u|0)/8|0)|0;j=(u|0)%8|0;if((j|0)<0){w=n-1|0;x=j+8|0}else{w=n;x=j}j=v+31&31;v=-1<<(j^31);n=v>>>(x>>>0);u=c[2276085]|0;q=u&w;r=q&16777215;f=c[2112932]|0;o=c[f+(r>>>10<<2)>>2]|0;if(o>>>0>9){e=q&1023;y=(d[o+(e+3)|0]|0)<<8|(d[o+(e+2)|0]|0)|((d[o+(e+1)|0]|0)<<8|(d[o+e|0]|0))<<16;z=u;A=f}else{u=gj[c[f+196768+(o<<2)>>2]&4095](r)|0;y=u;z=c[2276085]|0;A=c[2112932]|0}c[2276075]=y<<x>>>24;c[2276076]=y&n;c[2276077]=0;c[2276078]=0;u=y&~n;n=z&w;z=n&16777215;y=c[A+((z>>>10|16384)<<2)>>2]|0;if(y>>>0>9){r=n&1023;a[y+r|0]=u>>>16&255;a[y+(r+1)|0]=u>>>24&255;a[y+(r+2)|0]=u&255;a[y+(r+3)|0]=u>>>8&255}else{gg[c[A+196808+(y<<2)>>2]&4095](z,u)}if((j+1+x|0)>>>0<=32){return}x=w+4|0;w=c[2276085]|0;j=w&x;u=j&16777215;z=c[2112932]|0;y=c[z+(u>>>10<<2)>>2]|0;if(y>>>0>9){B=a[y+(j&1023^1)|0]|0;C=w;D=z}else{w=gj[c[z+196608+(y<<2)>>2]&4095](u)|0;B=w;C=c[2276085]|0;D=c[2112932]|0}w=B&255;c[2276076]=w&v|c[2276076];B=C&x;x=w&(v^255)&255;v=B&16777215;w=c[D+((v>>>10|16384)<<2)>>2]|0;if(w>>>0>9){a[w+(B&1023^1)|0]=x;return}else{gg[c[D+196648+(w<<2)>>2]&4095](v,x);return}}function Ck(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0);f=l&65535;g=f>>>6;m=xw(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;if((l&2048|0)==0){n=g&31}else{n=c[9104156+((g&7)<<2)>>2]|0}if((l&32|0)==0){o=f}else{o=c[9104156+((l&7)<<2)>>2]|0}l=((n|0)/8|0)+m|0;m=(n|0)%8|0;if((m|0)<0){p=l-1|0;q=m+8|0}else{p=l;q=m}m=o+31&31;o=-1<<(m^31);l=o>>>(q>>>0);n=c[2276085]|0;f=n&p;g=f&16777215;b=c[2112932]|0;e=c[b+(g>>>10<<2)>>2]|0;if(e>>>0>9){j=f&1023;r=(d[e+(j+3)|0]|0)<<8|(d[e+(j+2)|0]|0)|((d[e+(j+1)|0]|0)<<8|(d[e+j|0]|0))<<16;s=n;t=b}else{n=gj[c[b+196768+(e<<2)>>2]&4095](g)|0;r=n;s=c[2276085]|0;t=c[2112932]|0}c[2276075]=r<<q>>>24;c[2276076]=r&l;c[2276077]=0;c[2276078]=0;n=r&~l;l=s&p;s=l&16777215;r=c[t+((s>>>10|16384)<<2)>>2]|0;if(r>>>0>9){g=l&1023;a[r+g|0]=n>>>16&255;a[r+(g+1)|0]=n>>>24&255;a[r+(g+2)|0]=n&255;a[r+(g+3)|0]=n>>>8&255}else{gg[c[t+196808+(r<<2)>>2]&4095](s,n)}if((m+1+q|0)>>>0<=32){return}q=p+4|0;p=c[2276085]|0;m=p&q;n=m&16777215;s=c[2112932]|0;r=c[s+(n>>>10<<2)>>2]|0;if(r>>>0>9){u=a[r+(m&1023^1)|0]|0;v=p;w=s}else{p=gj[c[s+196608+(r<<2)>>2]&4095](n)|0;u=p;v=c[2276085]|0;w=c[2112932]|0}p=u&255;c[2276076]=p&o|c[2276076];u=v&q;q=p&(o^255)&255;o=u&16777215;p=c[w+((o>>>10|16384)<<2)>>2]|0;if(p>>>0>9){a[p+(u&1023^1)|0]=q;return}else{gg[c[w+196648+(p<<2)>>2]&4095](o,q);return}}function Cl(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0);f=n&65535;o=f>>>6;e=o&31;j=p&-4;if((j|0)==(h|0)){q=p;r=g}else{c[2276083]=j;g=c[2276085]&j;j=g&16777212;h=c[2112932]|0;l=c[h+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){k=g&1020;s=(d[l+(k|3)|0]|0)<<8|(d[l+(k|2)|0]|0)|((d[l+(k|1)|0]|0)<<8|(d[l+k|0]|0))<<16;t=p}else{p=gj[c[h+196768+(l<<2)>>2]&4095](j)|0;s=p;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;if((n&2048|0)==0){u=e}else{u=c[9104156+((o&7)<<2)>>2]|0}if((n&32|0)==0){v=f}else{v=c[9104156+((n&7)<<2)>>2]|0}n=((u|0)/8|0)+(r>>>((q<<3&16^16)>>>0)<<16>>16)|0;q=(u|0)%8|0;if((q|0)<0){w=n-1|0;x=q+8|0}else{w=n;x=q}q=v+31&31;v=-1<<(q^31);n=v>>>(x>>>0);u=c[2276085]|0;r=u&w;f=r&16777215;o=c[2112932]|0;e=c[o+(f>>>10<<2)>>2]|0;if(e>>>0>9){s=r&1023;y=(d[e+(s+3)|0]|0)<<8|(d[e+(s+2)|0]|0)|((d[e+(s+1)|0]|0)<<8|(d[e+s|0]|0))<<16;z=u;A=o}else{u=gj[c[o+196768+(e<<2)>>2]&4095](f)|0;y=u;z=c[2276085]|0;A=c[2112932]|0}c[2276075]=y<<x>>>24;c[2276076]=y&n;c[2276077]=0;c[2276078]=0;u=y&~n;n=z&w;z=n&16777215;y=c[A+((z>>>10|16384)<<2)>>2]|0;if(y>>>0>9){f=n&1023;a[y+f|0]=u>>>16&255;a[y+(f+1)|0]=u>>>24&255;a[y+(f+2)|0]=u&255;a[y+(f+3)|0]=u>>>8&255}else{gg[c[A+196808+(y<<2)>>2]&4095](z,u)}if((q+1+x|0)>>>0<=32){return}x=w+4|0;w=c[2276085]|0;q=w&x;u=q&16777215;z=c[2112932]|0;y=c[z+(u>>>10<<2)>>2]|0;if(y>>>0>9){B=a[y+(q&1023^1)|0]|0;C=w;D=z}else{w=gj[c[z+196608+(y<<2)>>2]&4095](u)|0;B=w;C=c[2276085]|0;D=c[2112932]|0}w=B&255;c[2276076]=w&v|c[2276076];B=C&x;x=w&(v^255)&255;v=B&16777215;w=c[D+((v>>>10|16384)<<2)>>2]|0;if(w>>>0>9){a[w+(B&1023^1)|0]=x;return}else{gg[c[D+196648+(w<<2)>>2]&4095](v,x);return}}function Cm(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0);f=n&65535;o=f>>>6;e=o&31;j=p&-4;if((j|0)==(h|0)){q=p;r=h;s=g}else{c[2276083]=j;g=c[2276085]&j;h=g&16777212;l=c[2112932]|0;k=c[l+((h>>>10|32768)<<2)>>2]|0;if(k>>>0>9){b=g&1020;t=(d[k+(b|3)|0]|0)<<8|(d[k+(b|2)|0]|0)|((d[k+(b|1)|0]|0)<<8|(d[k+b|0]|0))<<16;u=p;v=j}else{j=gj[c[l+196768+(k<<2)>>2]&4095](h)|0;t=j;u=c[2276056]|0;v=c[2276083]|0}c[2276084]=t;q=u;r=v;s=t}t=q+2|0;c[2276056]=t;q=t&-4;if((q|0)==(r|0)){w=s;x=t}else{c[2276083]=q;r=c[2276085]&q;q=r&16777212;v=c[2112932]|0;u=c[v+((q>>>10|32768)<<2)>>2]|0;if(u>>>0>9){j=r&1020;y=(d[u+(j|3)|0]|0)<<8|(d[u+(j|2)|0]|0)|((d[u+(j|1)|0]|0)<<8|(d[u+j|0]|0))<<16;z=t}else{t=gj[c[v+196768+(u<<2)>>2]&4095](q)|0;y=t;z=c[2276056]|0}c[2276084]=y;w=y>>>16|s<<16;x=z}c[2276056]=x+2;if((n&2048|0)==0){A=e}else{A=c[9104156+((o&7)<<2)>>2]|0}if((n&32|0)==0){B=f}else{B=c[9104156+((n&7)<<2)>>2]|0}n=((A|0)/8|0)+w|0;w=(A|0)%8|0;if((w|0)<0){C=n-1|0;D=w+8|0}else{C=n;D=w}w=B+31&31;B=-1<<(w^31);n=B>>>(D>>>0);A=c[2276085]|0;f=A&C;o=f&16777215;e=c[2112932]|0;x=c[e+(o>>>10<<2)>>2]|0;if(x>>>0>9){z=f&1023;E=(d[x+(z+3)|0]|0)<<8|(d[x+(z+2)|0]|0)|((d[x+(z+1)|0]|0)<<8|(d[x+z|0]|0))<<16;F=A;G=e}else{A=gj[c[e+196768+(x<<2)>>2]&4095](o)|0;E=A;F=c[2276085]|0;G=c[2112932]|0}c[2276075]=E<<D>>>24;c[2276076]=E&n;c[2276077]=0;c[2276078]=0;A=E&~n;n=F&C;F=n&16777215;E=c[G+((F>>>10|16384)<<2)>>2]|0;if(E>>>0>9){o=n&1023;a[E+o|0]=A>>>16&255;a[E+(o+1)|0]=A>>>24&255;a[E+(o+2)|0]=A&255;a[E+(o+3)|0]=A>>>8&255}else{gg[c[G+196808+(E<<2)>>2]&4095](F,A)}if((w+1+D|0)>>>0<=32){return}D=C+4|0;C=c[2276085]|0;w=C&D;A=w&16777215;F=c[2112932]|0;E=c[F+(A>>>10<<2)>>2]|0;if(E>>>0>9){H=a[E+(w&1023^1)|0]|0;I=C;J=F}else{C=gj[c[F+196608+(E<<2)>>2]&4095](A)|0;H=C;I=c[2276085]|0;J=c[2112932]|0}C=H&255;c[2276076]=C&B|c[2276076];H=I&D;D=C&(B^255)&255;B=H&16777215;C=c[J+((B>>>10|16384)<<2)>>2]|0;if(C>>>0>9){a[C+(H&1023^1)|0]=D;return}else{gg[c[J+196648+(C<<2)>>2]&4095](B,D);return}}function Cn(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[2276038]&24|0)==0){Bl();return}a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=f>>>((e<<3&16^16)>>>0);e=k&65535;f=e>>>6;l=c[9104156+((c[2276069]&7)<<2)>>2]|0;if((k&2048|0)==0){m=f&31}else{m=c[9104156+((f&7)<<2)>>2]|0}if((k&32|0)==0){n=e}else{n=c[9104156+((k&7)<<2)>>2]|0}e=m&31;m=32-e|0;f=(m>>>0<32?l>>>(m>>>0):0)|l<<e;c[2276075]=f>>>24;e=f>>(n+31&31^31);c[2276076]=e;c[2276077]=0;c[2276078]=0;c[9104156+((k>>>12&7)<<2)>>2]=e;return}function Co(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0);f=l&65535;g=f>>>6;if((l&2048|0)==0){n=g&31}else{n=c[9104156+((g&7)<<2)>>2]|0}if((l&32|0)==0){o=f}else{o=c[9104156+((l&7)<<2)>>2]|0}f=((n|0)/8|0)+(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;g=(n|0)%8|0;if((g|0)<0){p=f-1|0;q=g+8|0}else{p=f;q=g}g=o+31&31;o=c[2276085]&p;f=o&16777215;n=c[2112932]|0;m=c[n+(f>>>10<<2)>>2]|0;if(m>>>0>9){b=o&1023;r=(d[m+(b+3)|0]|0)<<8|(d[m+(b+2)|0]|0)|((d[m+(b+1)|0]|0)<<8|(d[m+b|0]|0))<<16}else{r=gj[c[n+196768+(m<<2)>>2]&4095](f)|0}f=r<<q;if((g+1+q|0)>>>0>32){r=c[2276085]&p+4;p=r&16777215;m=c[2112932]|0;n=c[m+(p>>>10<<2)>>2]|0;if(n>>>0>9){s=a[n+(r&1023^1)|0]|0}else{s=gj[c[m+196608+(n<<2)>>2]&4095](p)|0}t=(s&255)<<q>>>8|f}else{t=f}c[2276075]=t>>>24;f=t>>(g^31);c[2276076]=f;c[2276077]=0;c[2276078]=0;c[9104156+((l>>>12&7)<<2)>>2]=f;return}function Cp(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0);f=n&65535;o=f>>>6;e=o&31;j=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;l=p&-4;if((l|0)==(h|0)){q=p;r=g}else{c[2276083]=l;g=c[2276085]&l;l=g&16777212;h=c[2112932]|0;k=c[h+((l>>>10|32768)<<2)>>2]|0;if(k>>>0>9){b=g&1020;s=(d[k+(b|3)|0]|0)<<8|(d[k+(b|2)|0]|0)|((d[k+(b|1)|0]|0)<<8|(d[k+b|0]|0))<<16;t=p}else{p=gj[c[h+196768+(k<<2)>>2]&4095](l)|0;s=p;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;if((n&2048|0)==0){u=e}else{u=c[9104156+((o&7)<<2)>>2]|0}if((n&32|0)==0){v=f}else{v=c[9104156+((n&7)<<2)>>2]|0}f=(r>>>((q<<3&16^16)>>>0)<<16>>16)+j+((u|0)/8|0)|0;j=(u|0)%8|0;if((j|0)<0){w=f-1|0;x=j+8|0}else{w=f;x=j}j=v+31&31;v=c[2276085]&w;f=v&16777215;u=c[2112932]|0;q=c[u+(f>>>10<<2)>>2]|0;if(q>>>0>9){r=v&1023;y=(d[q+(r+3)|0]|0)<<8|(d[q+(r+2)|0]|0)|((d[q+(r+1)|0]|0)<<8|(d[q+r|0]|0))<<16}else{y=gj[c[u+196768+(q<<2)>>2]&4095](f)|0}f=y<<x;if((j+1+x|0)>>>0>32){y=c[2276085]&w+4;w=y&16777215;q=c[2112932]|0;u=c[q+(w>>>10<<2)>>2]|0;if(u>>>0>9){z=a[u+(y&1023^1)|0]|0}else{z=gj[c[q+196608+(u<<2)>>2]&4095](w)|0}A=(z&255)<<x>>>8|f}else{A=f}c[2276075]=A>>>24;f=A>>(j^31);c[2276076]=f;c[2276077]=0;c[2276078]=0;c[9104156+((n>>>12&7)<<2)>>2]=f;return}function Cq(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0);f=l&65535;g=f>>>6;m=xw(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;if((l&2048|0)==0){n=g&31}else{n=c[9104156+((g&7)<<2)>>2]|0}if((l&32|0)==0){o=f}else{o=c[9104156+((l&7)<<2)>>2]|0}f=((n|0)/8|0)+m|0;m=(n|0)%8|0;if((m|0)<0){p=f-1|0;q=m+8|0}else{p=f;q=m}m=o+31&31;o=c[2276085]&p;f=o&16777215;n=c[2112932]|0;g=c[n+(f>>>10<<2)>>2]|0;if(g>>>0>9){b=o&1023;r=(d[g+(b+3)|0]|0)<<8|(d[g+(b+2)|0]|0)|((d[g+(b+1)|0]|0)<<8|(d[g+b|0]|0))<<16}else{r=gj[c[n+196768+(g<<2)>>2]&4095](f)|0}f=r<<q;if((m+1+q|0)>>>0>32){r=c[2276085]&p+4;p=r&16777215;g=c[2112932]|0;n=c[g+(p>>>10<<2)>>2]|0;if(n>>>0>9){s=a[n+(r&1023^1)|0]|0}else{s=gj[c[g+196608+(n<<2)>>2]&4095](p)|0}t=(s&255)<<q>>>8|f}else{t=f}c[2276075]=t>>>24;f=t>>(m^31);c[2276076]=f;c[2276077]=0;c[2276078]=0;c[9104156+((l>>>12&7)<<2)>>2]=f;return}function Cr(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0);f=n&65535;o=f>>>6;e=o&31;j=p&-4;if((j|0)==(h|0)){q=p;r=g}else{c[2276083]=j;g=c[2276085]&j;j=g&16777212;h=c[2112932]|0;l=c[h+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){k=g&1020;s=(d[l+(k|3)|0]|0)<<8|(d[l+(k|2)|0]|0)|((d[l+(k|1)|0]|0)<<8|(d[l+k|0]|0))<<16;t=p}else{p=gj[c[h+196768+(l<<2)>>2]&4095](j)|0;s=p;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;if((n&2048|0)==0){u=e}else{u=c[9104156+((o&7)<<2)>>2]|0}if((n&32|0)==0){v=f}else{v=c[9104156+((n&7)<<2)>>2]|0}f=((u|0)/8|0)+(r>>>((q<<3&16^16)>>>0)<<16>>16)|0;q=(u|0)%8|0;if((q|0)<0){w=f-1|0;x=q+8|0}else{w=f;x=q}q=v+31&31;v=c[2276085]&w;f=v&16777215;u=c[2112932]|0;r=c[u+(f>>>10<<2)>>2]|0;if(r>>>0>9){o=v&1023;y=(d[r+(o+3)|0]|0)<<8|(d[r+(o+2)|0]|0)|((d[r+(o+1)|0]|0)<<8|(d[r+o|0]|0))<<16}else{y=gj[c[u+196768+(r<<2)>>2]&4095](f)|0}f=y<<x;if((q+1+x|0)>>>0>32){y=c[2276085]&w+4;w=y&16777215;r=c[2112932]|0;u=c[r+(w>>>10<<2)>>2]|0;if(u>>>0>9){z=a[u+(y&1023^1)|0]|0}else{z=gj[c[r+196608+(u<<2)>>2]&4095](w)|0}A=(z&255)<<x>>>8|f}else{A=f}c[2276075]=A>>>24;f=A>>(q^31);c[2276076]=f;c[2276077]=0;c[2276078]=0;c[9104156+((n>>>12&7)<<2)>>2]=f;return}function Cs(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0);f=n&65535;o=f>>>6;e=o&31;j=p&-4;if((j|0)==(h|0)){q=p;r=h;s=g}else{c[2276083]=j;g=c[2276085]&j;h=g&16777212;l=c[2112932]|0;k=c[l+((h>>>10|32768)<<2)>>2]|0;if(k>>>0>9){b=g&1020;t=(d[k+(b|3)|0]|0)<<8|(d[k+(b|2)|0]|0)|((d[k+(b|1)|0]|0)<<8|(d[k+b|0]|0))<<16;u=p;v=j}else{j=gj[c[l+196768+(k<<2)>>2]&4095](h)|0;t=j;u=c[2276056]|0;v=c[2276083]|0}c[2276084]=t;q=u;r=v;s=t}t=q+2|0;c[2276056]=t;q=t&-4;if((q|0)==(r|0)){w=s;x=t}else{c[2276083]=q;r=c[2276085]&q;q=r&16777212;v=c[2112932]|0;u=c[v+((q>>>10|32768)<<2)>>2]|0;if(u>>>0>9){j=r&1020;y=(d[u+(j|3)|0]|0)<<8|(d[u+(j|2)|0]|0)|((d[u+(j|1)|0]|0)<<8|(d[u+j|0]|0))<<16;z=t}else{t=gj[c[v+196768+(u<<2)>>2]&4095](q)|0;y=t;z=c[2276056]|0}c[2276084]=y;w=y>>>16|s<<16;x=z}c[2276056]=x+2;if((n&2048|0)==0){A=e}else{A=c[9104156+((o&7)<<2)>>2]|0}if((n&32|0)==0){B=f}else{B=c[9104156+((n&7)<<2)>>2]|0}f=((A|0)/8|0)+w|0;w=(A|0)%8|0;if((w|0)<0){C=f-1|0;D=w+8|0}else{C=f;D=w}w=B+31&31;B=c[2276085]&C;f=B&16777215;A=c[2112932]|0;o=c[A+(f>>>10<<2)>>2]|0;if(o>>>0>9){e=B&1023;E=(d[o+(e+3)|0]|0)<<8|(d[o+(e+2)|0]|0)|((d[o+(e+1)|0]|0)<<8|(d[o+e|0]|0))<<16}else{E=gj[c[A+196768+(o<<2)>>2]&4095](f)|0}f=E<<D;if((w+1+D|0)>>>0>32){E=c[2276085]&C+4;C=E&16777215;o=c[2112932]|0;A=c[o+(C>>>10<<2)>>2]|0;if(A>>>0>9){F=a[A+(E&1023^1)|0]|0}else{F=gj[c[o+196608+(A<<2)>>2]&4095](C)|0}G=(F&255)<<D>>>8|f}else{G=f}c[2276075]=G>>>24;f=G>>(w^31);c[2276076]=f;c[2276077]=0;c[2276078]=0;c[9104156+((n>>>12&7)<<2)>>2]=f;return}function Ct(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0);f=n&65535;o=f>>>6;e=o&31;j=p&-4;if((j|0)==(h|0)){q=p;r=g}else{c[2276083]=j;g=c[2276085]&j;j=g&16777212;h=c[2112932]|0;l=c[h+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){k=g&1020;s=(d[l+(k|3)|0]|0)<<8|(d[l+(k|2)|0]|0)|((d[l+(k|1)|0]|0)<<8|(d[l+k|0]|0))<<16;t=p}else{k=gj[c[h+196768+(l<<2)>>2]&4095](j)|0;s=k;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;if((n&2048|0)==0){u=e}else{u=c[9104156+((o&7)<<2)>>2]|0}if((n&32|0)==0){v=f}else{v=c[9104156+((n&7)<<2)>>2]|0}f=(r>>>((q<<3&16^16)>>>0)<<16>>16)+p+((u|0)/8|0)|0;p=(u|0)%8|0;if((p|0)<0){w=f-1|0;x=p+8|0}else{w=f;x=p}p=v+31&31;v=c[2276085]&w;f=v&16777215;u=c[2112932]|0;q=c[u+(f>>>10<<2)>>2]|0;if(q>>>0>9){r=v&1023;y=(d[q+(r+3)|0]|0)<<8|(d[q+(r+2)|0]|0)|((d[q+(r+1)|0]|0)<<8|(d[q+r|0]|0))<<16}else{y=gj[c[u+196768+(q<<2)>>2]&4095](f)|0}f=y<<x;if((p+1+x|0)>>>0>32){y=c[2276085]&w+4;w=y&16777215;q=c[2112932]|0;u=c[q+(w>>>10<<2)>>2]|0;if(u>>>0>9){z=a[u+(y&1023^1)|0]|0}else{z=gj[c[q+196608+(u<<2)>>2]&4095](w)|0}A=(z&255)<<x>>>8|f}else{A=f}c[2276075]=A>>>24;f=A>>(p^31);c[2276076]=f;c[2276077]=0;c[2276078]=0;c[9104156+((n>>>12&7)<<2)>>2]=f;return}function Cu(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}l=f+2|0;c[2276056]=l;m=g>>>((f<<3&16^16)>>>0);f=m&65535;g=f>>>6;b=xw(l)|0;if((m&2048|0)==0){n=g&31}else{n=c[9104156+((g&7)<<2)>>2]|0}if((m&32|0)==0){o=f}else{o=c[9104156+((m&7)<<2)>>2]|0}f=((n|0)/8|0)+b|0;b=(n|0)%8|0;if((b|0)<0){p=f-1|0;q=b+8|0}else{p=f;q=b}b=o+31&31;o=c[2276085]&p;f=o&16777215;n=c[2112932]|0;g=c[n+(f>>>10<<2)>>2]|0;if(g>>>0>9){l=o&1023;r=(d[g+(l+3)|0]|0)<<8|(d[g+(l+2)|0]|0)|((d[g+(l+1)|0]|0)<<8|(d[g+l|0]|0))<<16}else{r=gj[c[n+196768+(g<<2)>>2]&4095](f)|0}f=r<<q;if((b+1+q|0)>>>0>32){r=c[2276085]&p+4;p=r&16777215;g=c[2112932]|0;n=c[g+(p>>>10<<2)>>2]|0;if(n>>>0>9){s=a[n+(r&1023^1)|0]|0}else{s=gj[c[g+196608+(n<<2)>>2]&4095](p)|0}t=(s&255)<<q>>>8|f}else{t=f}c[2276075]=t>>>24;f=t>>(b^31);c[2276076]=f;c[2276077]=0;c[2276078]=0;c[9104156+((m>>>12&7)<<2)>>2]=f;return}function Cv(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[2276038]&24|0)==0){Bl();return}a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=f>>>((e<<3&16^16)>>>0);e=k&65535;f=e>>>6;l=c[9104156+((c[2276069]&7)<<2)>>2]|0;if((k&2048|0)==0){m=f&31}else{m=c[9104156+((f&7)<<2)>>2]|0}if((k&32|0)==0){n=e}else{n=c[9104156+((k&7)<<2)>>2]|0}e=m&31;m=32-e|0;f=(m>>>0<32?l>>>(m>>>0):0)|l<<e;c[2276075]=f>>>24;e=f>>>((n+31&31^31)>>>0);c[2276076]=e;c[2276077]=0;c[2276078]=0;c[9104156+((k>>>12&7)<<2)>>2]=e;return}function Cw(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0);f=l&65535;g=f>>>6;if((l&2048|0)==0){n=g&31}else{n=c[9104156+((g&7)<<2)>>2]|0}if((l&32|0)==0){o=f}else{o=c[9104156+((l&7)<<2)>>2]|0}f=((n|0)/8|0)+(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;g=(n|0)%8|0;if((g|0)<0){p=f-1|0;q=g+8|0}else{p=f;q=g}g=o+31&31;o=c[2276085]&p;f=o&16777215;n=c[2112932]|0;m=c[n+(f>>>10<<2)>>2]|0;if(m>>>0>9){b=o&1023;r=(d[m+(b+3)|0]|0)<<8|(d[m+(b+2)|0]|0)|((d[m+(b+1)|0]|0)<<8|(d[m+b|0]|0))<<16}else{r=gj[c[n+196768+(m<<2)>>2]&4095](f)|0}f=r<<q;if((g+1+q|0)>>>0>32){r=c[2276085]&p+4;p=r&16777215;m=c[2112932]|0;n=c[m+(p>>>10<<2)>>2]|0;if(n>>>0>9){s=a[n+(r&1023^1)|0]|0}else{s=gj[c[m+196608+(n<<2)>>2]&4095](p)|0}t=(s&255)<<q>>>8|f}else{t=f}c[2276075]=t>>>24;f=t>>>((g^31)>>>0);c[2276076]=f;c[2276077]=0;c[2276078]=0;c[9104156+((l>>>12&7)<<2)>>2]=f;return}function Cx(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0);f=n&65535;o=f>>>6;e=o&31;j=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;l=p&-4;if((l|0)==(h|0)){q=p;r=g}else{c[2276083]=l;g=c[2276085]&l;l=g&16777212;h=c[2112932]|0;k=c[h+((l>>>10|32768)<<2)>>2]|0;if(k>>>0>9){b=g&1020;s=(d[k+(b|3)|0]|0)<<8|(d[k+(b|2)|0]|0)|((d[k+(b|1)|0]|0)<<8|(d[k+b|0]|0))<<16;t=p}else{p=gj[c[h+196768+(k<<2)>>2]&4095](l)|0;s=p;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;if((n&2048|0)==0){u=e}else{u=c[9104156+((o&7)<<2)>>2]|0}if((n&32|0)==0){v=f}else{v=c[9104156+((n&7)<<2)>>2]|0}f=(r>>>((q<<3&16^16)>>>0)<<16>>16)+j+((u|0)/8|0)|0;j=(u|0)%8|0;if((j|0)<0){w=f-1|0;x=j+8|0}else{w=f;x=j}j=v+31&31;v=c[2276085]&w;f=v&16777215;u=c[2112932]|0;q=c[u+(f>>>10<<2)>>2]|0;if(q>>>0>9){r=v&1023;y=(d[q+(r+3)|0]|0)<<8|(d[q+(r+2)|0]|0)|((d[q+(r+1)|0]|0)<<8|(d[q+r|0]|0))<<16}else{y=gj[c[u+196768+(q<<2)>>2]&4095](f)|0}f=y<<x;if((j+1+x|0)>>>0>32){y=c[2276085]&w+4;w=y&16777215;q=c[2112932]|0;u=c[q+(w>>>10<<2)>>2]|0;if(u>>>0>9){z=a[u+(y&1023^1)|0]|0}else{z=gj[c[q+196608+(u<<2)>>2]&4095](w)|0}A=(z&255)<<x>>>8|f}else{A=f}c[2276075]=A>>>24;f=A>>>((j^31)>>>0);c[2276076]=f;c[2276077]=0;c[2276078]=0;c[9104156+((n>>>12&7)<<2)>>2]=f;return}function Cy(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0);f=l&65535;g=f>>>6;m=xw(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;if((l&2048|0)==0){n=g&31}else{n=c[9104156+((g&7)<<2)>>2]|0}if((l&32|0)==0){o=f}else{o=c[9104156+((l&7)<<2)>>2]|0}f=((n|0)/8|0)+m|0;m=(n|0)%8|0;if((m|0)<0){p=f-1|0;q=m+8|0}else{p=f;q=m}m=o+31&31;o=c[2276085]&p;f=o&16777215;n=c[2112932]|0;g=c[n+(f>>>10<<2)>>2]|0;if(g>>>0>9){b=o&1023;r=(d[g+(b+3)|0]|0)<<8|(d[g+(b+2)|0]|0)|((d[g+(b+1)|0]|0)<<8|(d[g+b|0]|0))<<16}else{r=gj[c[n+196768+(g<<2)>>2]&4095](f)|0}f=r<<q;if((m+1+q|0)>>>0>32){r=c[2276085]&p+4;p=r&16777215;g=c[2112932]|0;n=c[g+(p>>>10<<2)>>2]|0;if(n>>>0>9){s=a[n+(r&1023^1)|0]|0}else{s=gj[c[g+196608+(n<<2)>>2]&4095](p)|0}t=(s&255)<<q>>>8|f}else{t=f}c[2276075]=t>>>24;f=t>>>((m^31)>>>0);c[2276076]=f;c[2276077]=0;c[2276078]=0;c[9104156+((l>>>12&7)<<2)>>2]=f;return}function Cz(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0);f=n&65535;o=f>>>6;e=o&31;j=p&-4;if((j|0)==(h|0)){q=p;r=g}else{c[2276083]=j;g=c[2276085]&j;j=g&16777212;h=c[2112932]|0;l=c[h+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){k=g&1020;s=(d[l+(k|3)|0]|0)<<8|(d[l+(k|2)|0]|0)|((d[l+(k|1)|0]|0)<<8|(d[l+k|0]|0))<<16;t=p}else{p=gj[c[h+196768+(l<<2)>>2]&4095](j)|0;s=p;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;if((n&2048|0)==0){u=e}else{u=c[9104156+((o&7)<<2)>>2]|0}if((n&32|0)==0){v=f}else{v=c[9104156+((n&7)<<2)>>2]|0}f=((u|0)/8|0)+(r>>>((q<<3&16^16)>>>0)<<16>>16)|0;q=(u|0)%8|0;if((q|0)<0){w=f-1|0;x=q+8|0}else{w=f;x=q}q=v+31&31;v=c[2276085]&w;f=v&16777215;u=c[2112932]|0;r=c[u+(f>>>10<<2)>>2]|0;if(r>>>0>9){o=v&1023;y=(d[r+(o+3)|0]|0)<<8|(d[r+(o+2)|0]|0)|((d[r+(o+1)|0]|0)<<8|(d[r+o|0]|0))<<16}else{y=gj[c[u+196768+(r<<2)>>2]&4095](f)|0}f=y<<x;if((q+1+x|0)>>>0>32){y=c[2276085]&w+4;w=y&16777215;r=c[2112932]|0;u=c[r+(w>>>10<<2)>>2]|0;if(u>>>0>9){z=a[u+(y&1023^1)|0]|0}else{z=gj[c[r+196608+(u<<2)>>2]&4095](w)|0}A=(z&255)<<x>>>8|f}else{A=f}c[2276075]=A>>>24;f=A>>>((q^31)>>>0);c[2276076]=f;c[2276077]=0;c[2276078]=0;c[9104156+((n>>>12&7)<<2)>>2]=f;return}function CA(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0);f=n&65535;o=f>>>6;e=o&31;j=p&-4;if((j|0)==(h|0)){q=p;r=h;s=g}else{c[2276083]=j;g=c[2276085]&j;h=g&16777212;l=c[2112932]|0;k=c[l+((h>>>10|32768)<<2)>>2]|0;if(k>>>0>9){b=g&1020;t=(d[k+(b|3)|0]|0)<<8|(d[k+(b|2)|0]|0)|((d[k+(b|1)|0]|0)<<8|(d[k+b|0]|0))<<16;u=p;v=j}else{j=gj[c[l+196768+(k<<2)>>2]&4095](h)|0;t=j;u=c[2276056]|0;v=c[2276083]|0}c[2276084]=t;q=u;r=v;s=t}t=q+2|0;c[2276056]=t;q=t&-4;if((q|0)==(r|0)){w=s;x=t}else{c[2276083]=q;r=c[2276085]&q;q=r&16777212;v=c[2112932]|0;u=c[v+((q>>>10|32768)<<2)>>2]|0;if(u>>>0>9){j=r&1020;y=(d[u+(j|3)|0]|0)<<8|(d[u+(j|2)|0]|0)|((d[u+(j|1)|0]|0)<<8|(d[u+j|0]|0))<<16;z=t}else{t=gj[c[v+196768+(u<<2)>>2]&4095](q)|0;y=t;z=c[2276056]|0}c[2276084]=y;w=y>>>16|s<<16;x=z}c[2276056]=x+2;if((n&2048|0)==0){A=e}else{A=c[9104156+((o&7)<<2)>>2]|0}if((n&32|0)==0){B=f}else{B=c[9104156+((n&7)<<2)>>2]|0}f=((A|0)/8|0)+w|0;w=(A|0)%8|0;if((w|0)<0){C=f-1|0;D=w+8|0}else{C=f;D=w}w=B+31&31;B=c[2276085]&C;f=B&16777215;A=c[2112932]|0;o=c[A+(f>>>10<<2)>>2]|0;if(o>>>0>9){e=B&1023;E=(d[o+(e+3)|0]|0)<<8|(d[o+(e+2)|0]|0)|((d[o+(e+1)|0]|0)<<8|(d[o+e|0]|0))<<16}else{E=gj[c[A+196768+(o<<2)>>2]&4095](f)|0}f=E<<D;if((w+1+D|0)>>>0>32){E=c[2276085]&C+4;C=E&16777215;o=c[2112932]|0;A=c[o+(C>>>10<<2)>>2]|0;if(A>>>0>9){F=a[A+(E&1023^1)|0]|0}else{F=gj[c[o+196608+(A<<2)>>2]&4095](C)|0}G=(F&255)<<D>>>8|f}else{G=f}c[2276075]=G>>>24;f=G>>>((w^31)>>>0);c[2276076]=f;c[2276077]=0;c[2276078]=0;c[9104156+((n>>>12&7)<<2)>>2]=f;return}function CB(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0);f=n&65535;o=f>>>6;e=o&31;j=p&-4;if((j|0)==(h|0)){q=p;r=g}else{c[2276083]=j;g=c[2276085]&j;j=g&16777212;h=c[2112932]|0;l=c[h+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){k=g&1020;s=(d[l+(k|3)|0]|0)<<8|(d[l+(k|2)|0]|0)|((d[l+(k|1)|0]|0)<<8|(d[l+k|0]|0))<<16;t=p}else{k=gj[c[h+196768+(l<<2)>>2]&4095](j)|0;s=k;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;if((n&2048|0)==0){u=e}else{u=c[9104156+((o&7)<<2)>>2]|0}if((n&32|0)==0){v=f}else{v=c[9104156+((n&7)<<2)>>2]|0}f=(r>>>((q<<3&16^16)>>>0)<<16>>16)+p+((u|0)/8|0)|0;p=(u|0)%8|0;if((p|0)<0){w=f-1|0;x=p+8|0}else{w=f;x=p}p=v+31&31;v=c[2276085]&w;f=v&16777215;u=c[2112932]|0;q=c[u+(f>>>10<<2)>>2]|0;if(q>>>0>9){r=v&1023;y=(d[q+(r+3)|0]|0)<<8|(d[q+(r+2)|0]|0)|((d[q+(r+1)|0]|0)<<8|(d[q+r|0]|0))<<16}else{y=gj[c[u+196768+(q<<2)>>2]&4095](f)|0}f=y<<x;if((p+1+x|0)>>>0>32){y=c[2276085]&w+4;w=y&16777215;q=c[2112932]|0;u=c[q+(w>>>10<<2)>>2]|0;if(u>>>0>9){z=a[u+(y&1023^1)|0]|0}else{z=gj[c[q+196608+(u<<2)>>2]&4095](w)|0}A=(z&255)<<x>>>8|f}else{A=f}c[2276075]=A>>>24;f=A>>>((p^31)>>>0);c[2276076]=f;c[2276077]=0;c[2276078]=0;c[9104156+((n>>>12&7)<<2)>>2]=f;return}function CC(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}l=f+2|0;c[2276056]=l;m=g>>>((f<<3&16^16)>>>0);f=m&65535;g=f>>>6;b=xw(l)|0;if((m&2048|0)==0){n=g&31}else{n=c[9104156+((g&7)<<2)>>2]|0}if((m&32|0)==0){o=f}else{o=c[9104156+((m&7)<<2)>>2]|0}f=((n|0)/8|0)+b|0;b=(n|0)%8|0;if((b|0)<0){p=f-1|0;q=b+8|0}else{p=f;q=b}b=o+31&31;o=c[2276085]&p;f=o&16777215;n=c[2112932]|0;g=c[n+(f>>>10<<2)>>2]|0;if(g>>>0>9){l=o&1023;r=(d[g+(l+3)|0]|0)<<8|(d[g+(l+2)|0]|0)|((d[g+(l+1)|0]|0)<<8|(d[g+l|0]|0))<<16}else{r=gj[c[n+196768+(g<<2)>>2]&4095](f)|0}f=r<<q;if((b+1+q|0)>>>0>32){r=c[2276085]&p+4;p=r&16777215;g=c[2112932]|0;n=c[g+(p>>>10<<2)>>2]|0;if(n>>>0>9){s=a[n+(r&1023^1)|0]|0}else{s=gj[c[g+196608+(n<<2)>>2]&4095](p)|0}t=(s&255)<<q>>>8|f}else{t=f}c[2276075]=t>>>24;f=t>>>((b^31)>>>0);c[2276076]=f;c[2276077]=0;c[2276078]=0;c[9104156+((m>>>12&7)<<2)>>2]=f;return}function CD(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((c[2276038]&24|0)==0){Bl();return}a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=f>>>((e<<3&16^16)>>>0);e=k&65535;f=e>>>6;l=c[9104156+((c[2276069]&7)<<2)>>2]|0;if((k&2048|0)==0){m=f&31}else{m=c[9104156+((f&7)<<2)>>2]|0}if((k&32|0)==0){n=e}else{n=c[9104156+((k&7)<<2)>>2]|0}e=m&31;m=n+31&31;n=32-e|0;f=(n>>>0<32?l>>>(n>>>0):0)|l<<e;c[2276075]=f>>>24;l=f>>>((m^31)>>>0);c[2276076]=l;c[2276077]=0;c[2276078]=0;f=e;e=1<<m;while(1){if((e&l|0)!=0){o=f;break}m=f+1|0;n=e>>>1;if((n|0)==0){o=m;break}else{f=m;e=n}}c[9104156+((k>>>12&7)<<2)>>2]=o;return}function CE(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0);f=l&65535;g=f>>>6;if((l&2048|0)==0){n=g&31}else{n=c[9104156+((g&7)<<2)>>2]|0}if((l&32|0)==0){o=f}else{o=c[9104156+((l&7)<<2)>>2]|0}f=((n|0)/8|0)+(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;g=(n|0)%8|0;if((g|0)<0){p=f-1|0;q=g+8|0}else{p=f;q=g}g=o+31&31;o=c[2276085]&p;f=o&16777215;m=c[2112932]|0;b=c[m+(f>>>10<<2)>>2]|0;if(b>>>0>9){e=o&1023;r=(d[b+(e+3)|0]|0)<<8|(d[b+(e+2)|0]|0)|((d[b+(e+1)|0]|0)<<8|(d[b+e|0]|0))<<16}else{r=gj[c[m+196768+(b<<2)>>2]&4095](f)|0}f=r<<q;if((g+1+q|0)>>>0>32){r=c[2276085]&p+4;p=r&16777215;b=c[2112932]|0;m=c[b+(p>>>10<<2)>>2]|0;if(m>>>0>9){s=a[m+(r&1023^1)|0]|0}else{s=gj[c[b+196608+(m<<2)>>2]&4095](p)|0}t=(s&255)<<q>>>8|f}else{t=f}c[2276075]=t>>>24;f=t>>>((g^31)>>>0);c[2276076]=f;c[2276077]=0;c[2276078]=0;t=n;n=1<<g;while(1){if((n&f|0)!=0){u=t;break}g=t+1|0;q=n>>>1;if((q|0)==0){u=g;break}else{t=g;n=q}}c[9104156+((l>>>12&7)<<2)>>2]=u;return}function CF(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0);f=n&65535;o=f>>>6;e=o&31;j=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;l=p&-4;if((l|0)==(h|0)){q=p;r=g}else{c[2276083]=l;g=c[2276085]&l;l=g&16777212;h=c[2112932]|0;k=c[h+((l>>>10|32768)<<2)>>2]|0;if(k>>>0>9){b=g&1020;s=(d[k+(b|3)|0]|0)<<8|(d[k+(b|2)|0]|0)|((d[k+(b|1)|0]|0)<<8|(d[k+b|0]|0))<<16;t=p}else{p=gj[c[h+196768+(k<<2)>>2]&4095](l)|0;s=p;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;if((n&2048|0)==0){u=e}else{u=c[9104156+((o&7)<<2)>>2]|0}if((n&32|0)==0){v=f}else{v=c[9104156+((n&7)<<2)>>2]|0}f=(r>>>((q<<3&16^16)>>>0)<<16>>16)+j+((u|0)/8|0)|0;j=(u|0)%8|0;if((j|0)<0){w=f-1|0;x=j+8|0}else{w=f;x=j}j=v+31&31;v=c[2276085]&w;f=v&16777215;q=c[2112932]|0;r=c[q+(f>>>10<<2)>>2]|0;if(r>>>0>9){o=v&1023;y=(d[r+(o+3)|0]|0)<<8|(d[r+(o+2)|0]|0)|((d[r+(o+1)|0]|0)<<8|(d[r+o|0]|0))<<16}else{y=gj[c[q+196768+(r<<2)>>2]&4095](f)|0}f=y<<x;if((j+1+x|0)>>>0>32){y=c[2276085]&w+4;w=y&16777215;r=c[2112932]|0;q=c[r+(w>>>10<<2)>>2]|0;if(q>>>0>9){z=a[q+(y&1023^1)|0]|0}else{z=gj[c[r+196608+(q<<2)>>2]&4095](w)|0}A=(z&255)<<x>>>8|f}else{A=f}c[2276075]=A>>>24;f=A>>>((j^31)>>>0);c[2276076]=f;c[2276077]=0;c[2276078]=0;A=u;u=1<<j;while(1){if((u&f|0)!=0){B=A;break}j=A+1|0;x=u>>>1;if((x|0)==0){B=j;break}else{A=j;u=x}}c[9104156+((n>>>12&7)<<2)>>2]=B;return}function CG(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0);f=l&65535;g=f>>>6;m=xw(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;if((l&2048|0)==0){n=g&31}else{n=c[9104156+((g&7)<<2)>>2]|0}if((l&32|0)==0){o=f}else{o=c[9104156+((l&7)<<2)>>2]|0}f=((n|0)/8|0)+m|0;m=(n|0)%8|0;if((m|0)<0){p=f-1|0;q=m+8|0}else{p=f;q=m}m=o+31&31;o=c[2276085]&p;f=o&16777215;g=c[2112932]|0;b=c[g+(f>>>10<<2)>>2]|0;if(b>>>0>9){e=o&1023;r=(d[b+(e+3)|0]|0)<<8|(d[b+(e+2)|0]|0)|((d[b+(e+1)|0]|0)<<8|(d[b+e|0]|0))<<16}else{r=gj[c[g+196768+(b<<2)>>2]&4095](f)|0}f=r<<q;if((m+1+q|0)>>>0>32){r=c[2276085]&p+4;p=r&16777215;b=c[2112932]|0;g=c[b+(p>>>10<<2)>>2]|0;if(g>>>0>9){s=a[g+(r&1023^1)|0]|0}else{s=gj[c[b+196608+(g<<2)>>2]&4095](p)|0}t=(s&255)<<q>>>8|f}else{t=f}c[2276075]=t>>>24;f=t>>>((m^31)>>>0);c[2276076]=f;c[2276077]=0;c[2276078]=0;t=n;n=1<<m;while(1){if((n&f|0)!=0){u=t;break}m=t+1|0;q=n>>>1;if((q|0)==0){u=m;break}else{t=m;n=q}}c[9104156+((l>>>12&7)<<2)>>2]=u;return}function CH(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0);f=n&65535;o=f>>>6;e=o&31;j=p&-4;if((j|0)==(h|0)){q=p;r=g}else{c[2276083]=j;g=c[2276085]&j;j=g&16777212;h=c[2112932]|0;l=c[h+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){k=g&1020;s=(d[l+(k|3)|0]|0)<<8|(d[l+(k|2)|0]|0)|((d[l+(k|1)|0]|0)<<8|(d[l+k|0]|0))<<16;t=p}else{p=gj[c[h+196768+(l<<2)>>2]&4095](j)|0;s=p;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;if((n&2048|0)==0){u=e}else{u=c[9104156+((o&7)<<2)>>2]|0}if((n&32|0)==0){v=f}else{v=c[9104156+((n&7)<<2)>>2]|0}f=((u|0)/8|0)+(r>>>((q<<3&16^16)>>>0)<<16>>16)|0;q=(u|0)%8|0;if((q|0)<0){w=f-1|0;x=q+8|0}else{w=f;x=q}q=v+31&31;v=c[2276085]&w;f=v&16777215;r=c[2112932]|0;o=c[r+(f>>>10<<2)>>2]|0;if(o>>>0>9){e=v&1023;y=(d[o+(e+3)|0]|0)<<8|(d[o+(e+2)|0]|0)|((d[o+(e+1)|0]|0)<<8|(d[o+e|0]|0))<<16}else{y=gj[c[r+196768+(o<<2)>>2]&4095](f)|0}f=y<<x;if((q+1+x|0)>>>0>32){y=c[2276085]&w+4;w=y&16777215;o=c[2112932]|0;r=c[o+(w>>>10<<2)>>2]|0;if(r>>>0>9){z=a[r+(y&1023^1)|0]|0}else{z=gj[c[o+196608+(r<<2)>>2]&4095](w)|0}A=(z&255)<<x>>>8|f}else{A=f}c[2276075]=A>>>24;f=A>>>((q^31)>>>0);c[2276076]=f;c[2276077]=0;c[2276078]=0;A=u;u=1<<q;while(1){if((u&f|0)!=0){B=A;break}q=A+1|0;x=u>>>1;if((x|0)==0){B=q;break}else{A=q;u=x}}c[9104156+((n>>>12&7)<<2)>>2]=B;return}function CI(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0);f=n&65535;o=f>>>6;e=o&31;j=p&-4;if((j|0)==(h|0)){q=p;r=h;s=g}else{c[2276083]=j;g=c[2276085]&j;h=g&16777212;l=c[2112932]|0;k=c[l+((h>>>10|32768)<<2)>>2]|0;if(k>>>0>9){b=g&1020;t=(d[k+(b|3)|0]|0)<<8|(d[k+(b|2)|0]|0)|((d[k+(b|1)|0]|0)<<8|(d[k+b|0]|0))<<16;u=p;v=j}else{j=gj[c[l+196768+(k<<2)>>2]&4095](h)|0;t=j;u=c[2276056]|0;v=c[2276083]|0}c[2276084]=t;q=u;r=v;s=t}t=q+2|0;c[2276056]=t;q=t&-4;if((q|0)==(r|0)){w=s;x=t}else{c[2276083]=q;r=c[2276085]&q;q=r&16777212;v=c[2112932]|0;u=c[v+((q>>>10|32768)<<2)>>2]|0;if(u>>>0>9){j=r&1020;y=(d[u+(j|3)|0]|0)<<8|(d[u+(j|2)|0]|0)|((d[u+(j|1)|0]|0)<<8|(d[u+j|0]|0))<<16;z=t}else{t=gj[c[v+196768+(u<<2)>>2]&4095](q)|0;y=t;z=c[2276056]|0}c[2276084]=y;w=y>>>16|s<<16;x=z}c[2276056]=x+2;if((n&2048|0)==0){A=e}else{A=c[9104156+((o&7)<<2)>>2]|0}if((n&32|0)==0){B=f}else{B=c[9104156+((n&7)<<2)>>2]|0}f=((A|0)/8|0)+w|0;w=(A|0)%8|0;if((w|0)<0){C=f-1|0;D=w+8|0}else{C=f;D=w}w=B+31&31;B=c[2276085]&C;f=B&16777215;o=c[2112932]|0;e=c[o+(f>>>10<<2)>>2]|0;if(e>>>0>9){x=B&1023;E=(d[e+(x+3)|0]|0)<<8|(d[e+(x+2)|0]|0)|((d[e+(x+1)|0]|0)<<8|(d[e+x|0]|0))<<16}else{E=gj[c[o+196768+(e<<2)>>2]&4095](f)|0}f=E<<D;if((w+1+D|0)>>>0>32){E=c[2276085]&C+4;C=E&16777215;e=c[2112932]|0;o=c[e+(C>>>10<<2)>>2]|0;if(o>>>0>9){F=a[o+(E&1023^1)|0]|0}else{F=gj[c[e+196608+(o<<2)>>2]&4095](C)|0}G=(F&255)<<D>>>8|f}else{G=f}c[2276075]=G>>>24;f=G>>>((w^31)>>>0);c[2276076]=f;c[2276077]=0;c[2276078]=0;G=A;A=1<<w;while(1){if((A&f|0)!=0){H=G;break}w=G+1|0;D=A>>>1;if((D|0)==0){H=w;break}else{G=w;A=D}}c[9104156+((n>>>12&7)<<2)>>2]=H;return}function CJ(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0);f=n&65535;o=f>>>6;e=o&31;j=p&-4;if((j|0)==(h|0)){q=p;r=g}else{c[2276083]=j;g=c[2276085]&j;j=g&16777212;h=c[2112932]|0;l=c[h+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){k=g&1020;s=(d[l+(k|3)|0]|0)<<8|(d[l+(k|2)|0]|0)|((d[l+(k|1)|0]|0)<<8|(d[l+k|0]|0))<<16;t=p}else{k=gj[c[h+196768+(l<<2)>>2]&4095](j)|0;s=k;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;if((n&2048|0)==0){u=e}else{u=c[9104156+((o&7)<<2)>>2]|0}if((n&32|0)==0){v=f}else{v=c[9104156+((n&7)<<2)>>2]|0}f=(r>>>((q<<3&16^16)>>>0)<<16>>16)+p+((u|0)/8|0)|0;p=(u|0)%8|0;if((p|0)<0){w=f-1|0;x=p+8|0}else{w=f;x=p}p=v+31&31;v=c[2276085]&w;f=v&16777215;q=c[2112932]|0;r=c[q+(f>>>10<<2)>>2]|0;if(r>>>0>9){o=v&1023;y=(d[r+(o+3)|0]|0)<<8|(d[r+(o+2)|0]|0)|((d[r+(o+1)|0]|0)<<8|(d[r+o|0]|0))<<16}else{y=gj[c[q+196768+(r<<2)>>2]&4095](f)|0}f=y<<x;if((p+1+x|0)>>>0>32){y=c[2276085]&w+4;w=y&16777215;r=c[2112932]|0;q=c[r+(w>>>10<<2)>>2]|0;if(q>>>0>9){z=a[q+(y&1023^1)|0]|0}else{z=gj[c[r+196608+(q<<2)>>2]&4095](w)|0}A=(z&255)<<x>>>8|f}else{A=f}c[2276075]=A>>>24;f=A>>>((p^31)>>>0);c[2276076]=f;c[2276077]=0;c[2276078]=0;A=u;u=1<<p;while(1){if((u&f|0)!=0){B=A;break}p=A+1|0;x=u>>>1;if((x|0)==0){B=p;break}else{A=p;u=x}}c[9104156+((n>>>12&7)<<2)>>2]=B;return}function CK(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}l=f+2|0;c[2276056]=l;m=g>>>((f<<3&16^16)>>>0);f=m&65535;g=f>>>6;b=xw(l)|0;if((m&2048|0)==0){n=g&31}else{n=c[9104156+((g&7)<<2)>>2]|0}if((m&32|0)==0){o=f}else{o=c[9104156+((m&7)<<2)>>2]|0}f=((n|0)/8|0)+b|0;b=(n|0)%8|0;if((b|0)<0){p=f-1|0;q=b+8|0}else{p=f;q=b}b=o+31&31;o=c[2276085]&p;f=o&16777215;g=c[2112932]|0;l=c[g+(f>>>10<<2)>>2]|0;if(l>>>0>9){e=o&1023;r=(d[l+(e+3)|0]|0)<<8|(d[l+(e+2)|0]|0)|((d[l+(e+1)|0]|0)<<8|(d[l+e|0]|0))<<16}else{r=gj[c[g+196768+(l<<2)>>2]&4095](f)|0}f=r<<q;if((b+1+q|0)>>>0>32){r=c[2276085]&p+4;p=r&16777215;l=c[2112932]|0;g=c[l+(p>>>10<<2)>>2]|0;if(g>>>0>9){s=a[g+(r&1023^1)|0]|0}else{s=gj[c[l+196608+(g<<2)>>2]&4095](p)|0}t=(s&255)<<q>>>8|f}else{t=f}c[2276075]=t>>>24;f=t>>>((b^31)>>>0);c[2276076]=f;c[2276077]=0;c[2276078]=0;t=n;n=1<<b;while(1){if((n&f|0)!=0){u=t;break}b=t+1|0;q=n>>>1;if((q|0)==0){u=b;break}else{t=b;n=q}}c[9104156+((m>>>12&7)<<2)>>2]=u;return}function CL(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[2276038]&24|0)==0){Bl();return}a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=f>>>((e<<3&16^16)>>>0);e=k&65535;f=e>>>6;l=9104156+((c[2276069]&7)<<2)|0;if((k&2048|0)==0){m=f&31}else{m=c[9104156+((f&7)<<2)>>2]|0}if((k&32|0)==0){n=e}else{n=c[9104156+((k&7)<<2)>>2]|0}e=m&31;m=n+31&31^31;n=-1<<m;f=32-e|0;a=f>>>0<32;b=c[9104156+((k>>>12&7)<<2)>>2]<<m;c[2276075]=b>>>24;c[2276076]=b;c[2276077]=0;c[2276078]=0;c[l>>2]=(a?b<<f:0)|b>>>(e>>>0)|c[l>>2]&~((a?n<<f:0)|n>>>(e>>>0));return}function CM(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0);f=l&65535;g=f>>>6;if((l&2048|0)==0){n=g&31}else{n=c[9104156+((g&7)<<2)>>2]|0}if((l&32|0)==0){o=f}else{o=c[9104156+((l&7)<<2)>>2]|0}f=((n|0)/8|0)+(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;g=(n|0)%8|0;if((g|0)<0){p=f-1|0;q=g+8|0}else{p=f;q=g}g=o+31&31;o=g^31;f=-1<<o;n=c[9104156+((l>>>12&7)<<2)>>2]<<o;c[2276075]=n>>>24;c[2276076]=n;o=c[2276085]|0;l=o&p;m=l&16777215;b=c[2112932]|0;e=c[b+(m>>>10<<2)>>2]|0;if(e>>>0>9){j=l&1023;r=(d[e+(j+3)|0]|0)<<8|(d[e+(j+2)|0]|0)|((d[e+(j+1)|0]|0)<<8|(d[e+j|0]|0))<<16;s=o;t=b}else{o=gj[c[b+196768+(e<<2)>>2]&4095](m)|0;r=o;s=c[2276085]|0;t=c[2112932]|0}c[2276077]=0;c[2276078]=0;o=r&~(f>>>(q>>>0))|n>>>(q>>>0);r=s&p;s=r&16777215;m=c[t+((s>>>10|16384)<<2)>>2]|0;if(m>>>0>9){e=r&1023;a[m+e|0]=o>>>16&255;a[m+(e+1)|0]=o>>>24&255;a[m+(e+2)|0]=o&255;a[m+(e+3)|0]=o>>>8&255}else{gg[c[t+196808+(m<<2)>>2]&4095](s,o)}if((g+1+q|0)>>>0<=32){return}q=p+4|0;p=c[2276085]|0;g=p&q;o=g&16777215;s=c[2112932]|0;m=c[s+(o>>>10<<2)>>2]|0;if(m>>>0>9){u=a[m+(g&1023^1)|0]|0;v=p;w=s}else{p=gj[c[s+196608+(m<<2)>>2]&4095](o)|0;u=p;v=c[2276085]|0;w=c[2112932]|0}p=u&255;c[2276076]=p&f|c[2276076];u=v&q;q=(p&(f^255)|n)&255;n=u&16777215;f=c[w+((n>>>10|16384)<<2)>>2]|0;if(f>>>0>9){a[f+(u&1023^1)|0]=q;return}else{gg[c[w+196648+(f<<2)>>2]&4095](n,q);return}}function CN(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0);f=n&65535;o=f>>>6;e=o&31;j=c[9104156+((n>>>12&7)<<2)>>2]|0;l=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;k=p&-4;if((k|0)==(h|0)){q=p;r=g}else{c[2276083]=k;g=c[2276085]&k;k=g&16777212;h=c[2112932]|0;b=c[h+((k>>>10|32768)<<2)>>2]|0;if(b>>>0>9){m=g&1020;s=(d[b+(m|3)|0]|0)<<8|(d[b+(m|2)|0]|0)|((d[b+(m|1)|0]|0)<<8|(d[b+m|0]|0))<<16;t=p}else{p=gj[c[h+196768+(b<<2)>>2]&4095](k)|0;s=p;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;if((n&2048|0)==0){u=e}else{u=c[9104156+((o&7)<<2)>>2]|0}if((n&32|0)==0){v=f}else{v=c[9104156+((n&7)<<2)>>2]|0}n=(r>>>((q<<3&16^16)>>>0)<<16>>16)+l+((u|0)/8|0)|0;l=(u|0)%8|0;if((l|0)<0){w=n-1|0;x=l+8|0}else{w=n;x=l}l=v+31&31;v=l^31;n=-1<<v;u=j<<v;c[2276075]=u>>>24;c[2276076]=u;v=c[2276085]|0;j=v&w;q=j&16777215;r=c[2112932]|0;f=c[r+(q>>>10<<2)>>2]|0;if(f>>>0>9){o=j&1023;y=(d[f+(o+3)|0]|0)<<8|(d[f+(o+2)|0]|0)|((d[f+(o+1)|0]|0)<<8|(d[f+o|0]|0))<<16;z=v;A=r}else{v=gj[c[r+196768+(f<<2)>>2]&4095](q)|0;y=v;z=c[2276085]|0;A=c[2112932]|0}c[2276077]=0;c[2276078]=0;v=y&~(n>>>(x>>>0))|u>>>(x>>>0);y=z&w;z=y&16777215;q=c[A+((z>>>10|16384)<<2)>>2]|0;if(q>>>0>9){f=y&1023;a[q+f|0]=v>>>16&255;a[q+(f+1)|0]=v>>>24&255;a[q+(f+2)|0]=v&255;a[q+(f+3)|0]=v>>>8&255}else{gg[c[A+196808+(q<<2)>>2]&4095](z,v)}if((l+1+x|0)>>>0<=32){return}x=w+4|0;w=c[2276085]|0;l=w&x;v=l&16777215;z=c[2112932]|0;q=c[z+(v>>>10<<2)>>2]|0;if(q>>>0>9){B=a[q+(l&1023^1)|0]|0;C=w;D=z}else{w=gj[c[z+196608+(q<<2)>>2]&4095](v)|0;B=w;C=c[2276085]|0;D=c[2112932]|0}w=B&255;c[2276076]=w&n|c[2276076];B=C&x;x=(w&(n^255)|u)&255;u=B&16777215;n=c[D+((u>>>10|16384)<<2)>>2]|0;if(n>>>0>9){a[n+(B&1023^1)|0]=x;return}else{gg[c[D+196648+(n<<2)>>2]&4095](u,x);return}}function CO(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0);f=l&65535;g=f>>>6;m=c[9104156+((l>>>12&7)<<2)>>2]|0;b=xw(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;if((l&2048|0)==0){n=g&31}else{n=c[9104156+((g&7)<<2)>>2]|0}if((l&32|0)==0){o=f}else{o=c[9104156+((l&7)<<2)>>2]|0}l=((n|0)/8|0)+b|0;b=(n|0)%8|0;if((b|0)<0){p=l-1|0;q=b+8|0}else{p=l;q=b}b=o+31&31;o=b^31;l=-1<<o;n=m<<o;c[2276075]=n>>>24;c[2276076]=n;o=c[2276085]|0;m=o&p;f=m&16777215;g=c[2112932]|0;e=c[g+(f>>>10<<2)>>2]|0;if(e>>>0>9){j=m&1023;r=(d[e+(j+3)|0]|0)<<8|(d[e+(j+2)|0]|0)|((d[e+(j+1)|0]|0)<<8|(d[e+j|0]|0))<<16;s=o;t=g}else{o=gj[c[g+196768+(e<<2)>>2]&4095](f)|0;r=o;s=c[2276085]|0;t=c[2112932]|0}c[2276077]=0;c[2276078]=0;o=r&~(l>>>(q>>>0))|n>>>(q>>>0);r=s&p;s=r&16777215;f=c[t+((s>>>10|16384)<<2)>>2]|0;if(f>>>0>9){e=r&1023;a[f+e|0]=o>>>16&255;a[f+(e+1)|0]=o>>>24&255;a[f+(e+2)|0]=o&255;a[f+(e+3)|0]=o>>>8&255}else{gg[c[t+196808+(f<<2)>>2]&4095](s,o)}if((b+1+q|0)>>>0<=32){return}q=p+4|0;p=c[2276085]|0;b=p&q;o=b&16777215;s=c[2112932]|0;f=c[s+(o>>>10<<2)>>2]|0;if(f>>>0>9){u=a[f+(b&1023^1)|0]|0;v=p;w=s}else{p=gj[c[s+196608+(f<<2)>>2]&4095](o)|0;u=p;v=c[2276085]|0;w=c[2112932]|0}p=u&255;c[2276076]=p&l|c[2276076];u=v&q;q=(p&(l^255)|n)&255;n=u&16777215;l=c[w+((n>>>10|16384)<<2)>>2]|0;if(l>>>0>9){a[l+(u&1023^1)|0]=q;return}else{gg[c[w+196648+(l<<2)>>2]&4095](n,q);return}}function CP(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0);f=n&65535;o=f>>>6;e=o&31;j=c[9104156+((n>>>12&7)<<2)>>2]|0;l=p&-4;if((l|0)==(h|0)){q=p;r=g}else{c[2276083]=l;g=c[2276085]&l;l=g&16777212;h=c[2112932]|0;k=c[h+((l>>>10|32768)<<2)>>2]|0;if(k>>>0>9){b=g&1020;s=(d[k+(b|3)|0]|0)<<8|(d[k+(b|2)|0]|0)|((d[k+(b|1)|0]|0)<<8|(d[k+b|0]|0))<<16;t=p}else{p=gj[c[h+196768+(k<<2)>>2]&4095](l)|0;s=p;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;if((n&2048|0)==0){u=e}else{u=c[9104156+((o&7)<<2)>>2]|0}if((n&32|0)==0){v=f}else{v=c[9104156+((n&7)<<2)>>2]|0}n=((u|0)/8|0)+(r>>>((q<<3&16^16)>>>0)<<16>>16)|0;q=(u|0)%8|0;if((q|0)<0){w=n-1|0;x=q+8|0}else{w=n;x=q}q=v+31&31;v=q^31;n=-1<<v;u=j<<v;c[2276075]=u>>>24;c[2276076]=u;v=c[2276085]|0;j=v&w;r=j&16777215;f=c[2112932]|0;o=c[f+(r>>>10<<2)>>2]|0;if(o>>>0>9){e=j&1023;y=(d[o+(e+3)|0]|0)<<8|(d[o+(e+2)|0]|0)|((d[o+(e+1)|0]|0)<<8|(d[o+e|0]|0))<<16;z=v;A=f}else{v=gj[c[f+196768+(o<<2)>>2]&4095](r)|0;y=v;z=c[2276085]|0;A=c[2112932]|0}c[2276077]=0;c[2276078]=0;v=y&~(n>>>(x>>>0))|u>>>(x>>>0);y=z&w;z=y&16777215;r=c[A+((z>>>10|16384)<<2)>>2]|0;if(r>>>0>9){o=y&1023;a[r+o|0]=v>>>16&255;a[r+(o+1)|0]=v>>>24&255;a[r+(o+2)|0]=v&255;a[r+(o+3)|0]=v>>>8&255}else{gg[c[A+196808+(r<<2)>>2]&4095](z,v)}if((q+1+x|0)>>>0<=32){return}x=w+4|0;w=c[2276085]|0;q=w&x;v=q&16777215;z=c[2112932]|0;r=c[z+(v>>>10<<2)>>2]|0;if(r>>>0>9){B=a[r+(q&1023^1)|0]|0;C=w;D=z}else{w=gj[c[z+196608+(r<<2)>>2]&4095](v)|0;B=w;C=c[2276085]|0;D=c[2112932]|0}w=B&255;c[2276076]=w&n|c[2276076];B=C&x;x=(w&(n^255)|u)&255;u=B&16777215;n=c[D+((u>>>10|16384)<<2)>>2]|0;if(n>>>0>9){a[n+(B&1023^1)|0]=x;return}else{gg[c[D+196648+(n<<2)>>2]&4095](u,x);return}}function CQ(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0);f=n&65535;o=f>>>6;e=o&31;j=c[9104156+((n>>>12&7)<<2)>>2]|0;l=p&-4;if((l|0)==(h|0)){q=p;r=h;s=g}else{c[2276083]=l;g=c[2276085]&l;h=g&16777212;k=c[2112932]|0;b=c[k+((h>>>10|32768)<<2)>>2]|0;if(b>>>0>9){m=g&1020;t=(d[b+(m|3)|0]|0)<<8|(d[b+(m|2)|0]|0)|((d[b+(m|1)|0]|0)<<8|(d[b+m|0]|0))<<16;u=p;v=l}else{l=gj[c[k+196768+(b<<2)>>2]&4095](h)|0;t=l;u=c[2276056]|0;v=c[2276083]|0}c[2276084]=t;q=u;r=v;s=t}t=q+2|0;c[2276056]=t;q=t&-4;if((q|0)==(r|0)){w=s;x=t}else{c[2276083]=q;r=c[2276085]&q;q=r&16777212;v=c[2112932]|0;u=c[v+((q>>>10|32768)<<2)>>2]|0;if(u>>>0>9){l=r&1020;y=(d[u+(l|3)|0]|0)<<8|(d[u+(l|2)|0]|0)|((d[u+(l|1)|0]|0)<<8|(d[u+l|0]|0))<<16;z=t}else{t=gj[c[v+196768+(u<<2)>>2]&4095](q)|0;y=t;z=c[2276056]|0}c[2276084]=y;w=y>>>16|s<<16;x=z}c[2276056]=x+2;if((n&2048|0)==0){A=e}else{A=c[9104156+((o&7)<<2)>>2]|0}if((n&32|0)==0){B=f}else{B=c[9104156+((n&7)<<2)>>2]|0}n=((A|0)/8|0)+w|0;w=(A|0)%8|0;if((w|0)<0){C=n-1|0;D=w+8|0}else{C=n;D=w}w=B+31&31;B=w^31;n=-1<<B;A=j<<B;c[2276075]=A>>>24;c[2276076]=A;B=c[2276085]|0;j=B&C;f=j&16777215;o=c[2112932]|0;e=c[o+(f>>>10<<2)>>2]|0;if(e>>>0>9){x=j&1023;E=(d[e+(x+3)|0]|0)<<8|(d[e+(x+2)|0]|0)|((d[e+(x+1)|0]|0)<<8|(d[e+x|0]|0))<<16;F=B;G=o}else{B=gj[c[o+196768+(e<<2)>>2]&4095](f)|0;E=B;F=c[2276085]|0;G=c[2112932]|0}c[2276077]=0;c[2276078]=0;B=E&~(n>>>(D>>>0))|A>>>(D>>>0);E=F&C;F=E&16777215;f=c[G+((F>>>10|16384)<<2)>>2]|0;if(f>>>0>9){e=E&1023;a[f+e|0]=B>>>16&255;a[f+(e+1)|0]=B>>>24&255;a[f+(e+2)|0]=B&255;a[f+(e+3)|0]=B>>>8&255}else{gg[c[G+196808+(f<<2)>>2]&4095](F,B)}if((w+1+D|0)>>>0<=32){return}D=C+4|0;C=c[2276085]|0;w=C&D;B=w&16777215;F=c[2112932]|0;f=c[F+(B>>>10<<2)>>2]|0;if(f>>>0>9){H=a[f+(w&1023^1)|0]|0;I=C;J=F}else{C=gj[c[F+196608+(f<<2)>>2]&4095](B)|0;H=C;I=c[2276085]|0;J=c[2112932]|0}C=H&255;c[2276076]=C&n|c[2276076];H=I&D;D=(C&(n^255)|A)&255;A=H&16777215;n=c[J+((A>>>10|16384)<<2)>>2]|0;if(n>>>0>9){a[n+(H&1023^1)|0]=D;return}else{gg[c[J+196648+(n<<2)>>2]&4095](A,D);return}}function CR(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[2276038]&24|0)==0){Bl();return}a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=f>>>((e<<3&16^16)>>>0);e=k&65535;f=e>>>6;l=9104156+((c[2276069]&7)<<2)|0;if((k&2048|0)==0){m=f&31}else{m=c[9104156+((f&7)<<2)>>2]|0}if((k&32|0)==0){n=e}else{n=c[9104156+((k&7)<<2)>>2]|0}k=m&31;m=-1<<(n+31&31^31);n=32-k|0;e=(n>>>0<32?m<<n:0)|m>>>(k>>>0);c[2276075]=c[l>>2]<<k>>>24;c[2276076]=e&c[l>>2];c[2276077]=0;c[2276078]=0;c[l>>2]=e|c[l>>2];return}function CS(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0);f=l&65535;g=f>>>6;if((l&2048|0)==0){n=g&31}else{n=c[9104156+((g&7)<<2)>>2]|0}if((l&32|0)==0){o=f}else{o=c[9104156+((l&7)<<2)>>2]|0}l=((n|0)/8|0)+(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;f=(n|0)%8|0;if((f|0)<0){p=l-1|0;q=f+8|0}else{p=l;q=f}f=o+31&31;o=-1<<(f^31);l=o>>>(q>>>0);n=c[2276085]|0;g=n&p;m=g&16777215;b=c[2112932]|0;e=c[b+(m>>>10<<2)>>2]|0;if(e>>>0>9){j=g&1023;r=(d[e+(j+3)|0]|0)<<8|(d[e+(j+2)|0]|0)|((d[e+(j+1)|0]|0)<<8|(d[e+j|0]|0))<<16;s=n;t=b}else{n=gj[c[b+196768+(e<<2)>>2]&4095](m)|0;r=n;s=c[2276085]|0;t=c[2112932]|0}c[2276075]=r<<q>>>24;c[2276076]=r&l;c[2276077]=0;c[2276078]=0;n=r|l;l=s&p;s=l&16777215;r=c[t+((s>>>10|16384)<<2)>>2]|0;if(r>>>0>9){m=l&1023;a[r+m|0]=n>>>16&255;a[r+(m+1)|0]=n>>>24&255;a[r+(m+2)|0]=n&255;a[r+(m+3)|0]=n>>>8&255}else{gg[c[t+196808+(r<<2)>>2]&4095](s,n)}if((f+1+q|0)>>>0<=32){return}q=p+4|0;p=c[2276085]|0;f=p&q;n=f&16777215;s=c[2112932]|0;r=c[s+(n>>>10<<2)>>2]|0;if(r>>>0>9){u=a[r+(f&1023^1)|0]|0;v=p;w=s}else{p=gj[c[s+196608+(r<<2)>>2]&4095](n)|0;u=p;v=c[2276085]|0;w=c[2112932]|0}p=u&255;c[2276076]=o&p|c[2276076];u=v&q;q=(p|o)&255;o=u&16777215;p=c[w+((o>>>10|16384)<<2)>>2]|0;if(p>>>0>9){a[p+(u&1023^1)|0]=q;return}else{gg[c[w+196648+(p<<2)>>2]&4095](o,q);return}}function CT(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0);f=n&65535;o=f>>>6;e=o&31;j=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;l=p&-4;if((l|0)==(h|0)){q=p;r=g}else{c[2276083]=l;g=c[2276085]&l;l=g&16777212;h=c[2112932]|0;k=c[h+((l>>>10|32768)<<2)>>2]|0;if(k>>>0>9){b=g&1020;s=(d[k+(b|3)|0]|0)<<8|(d[k+(b|2)|0]|0)|((d[k+(b|1)|0]|0)<<8|(d[k+b|0]|0))<<16;t=p}else{p=gj[c[h+196768+(k<<2)>>2]&4095](l)|0;s=p;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;if((n&2048|0)==0){u=e}else{u=c[9104156+((o&7)<<2)>>2]|0}if((n&32|0)==0){v=f}else{v=c[9104156+((n&7)<<2)>>2]|0}n=(r>>>((q<<3&16^16)>>>0)<<16>>16)+j+((u|0)/8|0)|0;j=(u|0)%8|0;if((j|0)<0){w=n-1|0;x=j+8|0}else{w=n;x=j}j=v+31&31;v=-1<<(j^31);n=v>>>(x>>>0);u=c[2276085]|0;q=u&w;r=q&16777215;f=c[2112932]|0;o=c[f+(r>>>10<<2)>>2]|0;if(o>>>0>9){e=q&1023;y=(d[o+(e+3)|0]|0)<<8|(d[o+(e+2)|0]|0)|((d[o+(e+1)|0]|0)<<8|(d[o+e|0]|0))<<16;z=u;A=f}else{u=gj[c[f+196768+(o<<2)>>2]&4095](r)|0;y=u;z=c[2276085]|0;A=c[2112932]|0}c[2276075]=y<<x>>>24;c[2276076]=y&n;c[2276077]=0;c[2276078]=0;u=y|n;n=z&w;z=n&16777215;y=c[A+((z>>>10|16384)<<2)>>2]|0;if(y>>>0>9){r=n&1023;a[y+r|0]=u>>>16&255;a[y+(r+1)|0]=u>>>24&255;a[y+(r+2)|0]=u&255;a[y+(r+3)|0]=u>>>8&255}else{gg[c[A+196808+(y<<2)>>2]&4095](z,u)}if((j+1+x|0)>>>0<=32){return}x=w+4|0;w=c[2276085]|0;j=w&x;u=j&16777215;z=c[2112932]|0;y=c[z+(u>>>10<<2)>>2]|0;if(y>>>0>9){B=a[y+(j&1023^1)|0]|0;C=w;D=z}else{w=gj[c[z+196608+(y<<2)>>2]&4095](u)|0;B=w;C=c[2276085]|0;D=c[2112932]|0}w=B&255;c[2276076]=v&w|c[2276076];B=C&x;x=(w|v)&255;v=B&16777215;w=c[D+((v>>>10|16384)<<2)>>2]|0;if(w>>>0>9){a[w+(B&1023^1)|0]=x;return}else{gg[c[D+196648+(w<<2)>>2]&4095](v,x);return}}function CU(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0);f=l&65535;g=f>>>6;m=xw(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;if((l&2048|0)==0){n=g&31}else{n=c[9104156+((g&7)<<2)>>2]|0}if((l&32|0)==0){o=f}else{o=c[9104156+((l&7)<<2)>>2]|0}l=((n|0)/8|0)+m|0;m=(n|0)%8|0;if((m|0)<0){p=l-1|0;q=m+8|0}else{p=l;q=m}m=o+31&31;o=-1<<(m^31);l=o>>>(q>>>0);n=c[2276085]|0;f=n&p;g=f&16777215;b=c[2112932]|0;e=c[b+(g>>>10<<2)>>2]|0;if(e>>>0>9){j=f&1023;r=(d[e+(j+3)|0]|0)<<8|(d[e+(j+2)|0]|0)|((d[e+(j+1)|0]|0)<<8|(d[e+j|0]|0))<<16;s=n;t=b}else{n=gj[c[b+196768+(e<<2)>>2]&4095](g)|0;r=n;s=c[2276085]|0;t=c[2112932]|0}c[2276075]=r<<q>>>24;c[2276076]=r&l;c[2276077]=0;c[2276078]=0;n=r|l;l=s&p;s=l&16777215;r=c[t+((s>>>10|16384)<<2)>>2]|0;if(r>>>0>9){g=l&1023;a[r+g|0]=n>>>16&255;a[r+(g+1)|0]=n>>>24&255;a[r+(g+2)|0]=n&255;a[r+(g+3)|0]=n>>>8&255}else{gg[c[t+196808+(r<<2)>>2]&4095](s,n)}if((m+1+q|0)>>>0<=32){return}q=p+4|0;p=c[2276085]|0;m=p&q;n=m&16777215;s=c[2112932]|0;r=c[s+(n>>>10<<2)>>2]|0;if(r>>>0>9){u=a[r+(m&1023^1)|0]|0;v=p;w=s}else{p=gj[c[s+196608+(r<<2)>>2]&4095](n)|0;u=p;v=c[2276085]|0;w=c[2112932]|0}p=u&255;c[2276076]=o&p|c[2276076];u=v&q;q=(p|o)&255;o=u&16777215;p=c[w+((o>>>10|16384)<<2)>>2]|0;if(p>>>0>9){a[p+(u&1023^1)|0]=q;return}else{gg[c[w+196648+(p<<2)>>2]&4095](o,q);return}}function CV(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0);f=n&65535;o=f>>>6;e=o&31;j=p&-4;if((j|0)==(h|0)){q=p;r=g}else{c[2276083]=j;g=c[2276085]&j;j=g&16777212;h=c[2112932]|0;l=c[h+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){k=g&1020;s=(d[l+(k|3)|0]|0)<<8|(d[l+(k|2)|0]|0)|((d[l+(k|1)|0]|0)<<8|(d[l+k|0]|0))<<16;t=p}else{p=gj[c[h+196768+(l<<2)>>2]&4095](j)|0;s=p;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;if((n&2048|0)==0){u=e}else{u=c[9104156+((o&7)<<2)>>2]|0}if((n&32|0)==0){v=f}else{v=c[9104156+((n&7)<<2)>>2]|0}n=((u|0)/8|0)+(r>>>((q<<3&16^16)>>>0)<<16>>16)|0;q=(u|0)%8|0;if((q|0)<0){w=n-1|0;x=q+8|0}else{w=n;x=q}q=v+31&31;v=-1<<(q^31);n=v>>>(x>>>0);u=c[2276085]|0;r=u&w;f=r&16777215;o=c[2112932]|0;e=c[o+(f>>>10<<2)>>2]|0;if(e>>>0>9){s=r&1023;y=(d[e+(s+3)|0]|0)<<8|(d[e+(s+2)|0]|0)|((d[e+(s+1)|0]|0)<<8|(d[e+s|0]|0))<<16;z=u;A=o}else{u=gj[c[o+196768+(e<<2)>>2]&4095](f)|0;y=u;z=c[2276085]|0;A=c[2112932]|0}c[2276075]=y<<x>>>24;c[2276076]=y&n;c[2276077]=0;c[2276078]=0;u=y|n;n=z&w;z=n&16777215;y=c[A+((z>>>10|16384)<<2)>>2]|0;if(y>>>0>9){f=n&1023;a[y+f|0]=u>>>16&255;a[y+(f+1)|0]=u>>>24&255;a[y+(f+2)|0]=u&255;a[y+(f+3)|0]=u>>>8&255}else{gg[c[A+196808+(y<<2)>>2]&4095](z,u)}if((q+1+x|0)>>>0<=32){return}x=w+4|0;w=c[2276085]|0;q=w&x;u=q&16777215;z=c[2112932]|0;y=c[z+(u>>>10<<2)>>2]|0;if(y>>>0>9){B=a[y+(q&1023^1)|0]|0;C=w;D=z}else{w=gj[c[z+196608+(y<<2)>>2]&4095](u)|0;B=w;C=c[2276085]|0;D=c[2112932]|0}w=B&255;c[2276076]=v&w|c[2276076];B=C&x;x=(w|v)&255;v=B&16777215;w=c[D+((v>>>10|16384)<<2)>>2]|0;if(w>>>0>9){a[w+(B&1023^1)|0]=x;return}else{gg[c[D+196648+(w<<2)>>2]&4095](v,x);return}}function CW(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0);f=n&65535;o=f>>>6;e=o&31;j=p&-4;if((j|0)==(h|0)){q=p;r=h;s=g}else{c[2276083]=j;g=c[2276085]&j;h=g&16777212;l=c[2112932]|0;k=c[l+((h>>>10|32768)<<2)>>2]|0;if(k>>>0>9){b=g&1020;t=(d[k+(b|3)|0]|0)<<8|(d[k+(b|2)|0]|0)|((d[k+(b|1)|0]|0)<<8|(d[k+b|0]|0))<<16;u=p;v=j}else{j=gj[c[l+196768+(k<<2)>>2]&4095](h)|0;t=j;u=c[2276056]|0;v=c[2276083]|0}c[2276084]=t;q=u;r=v;s=t}t=q+2|0;c[2276056]=t;q=t&-4;if((q|0)==(r|0)){w=s;x=t}else{c[2276083]=q;r=c[2276085]&q;q=r&16777212;v=c[2112932]|0;u=c[v+((q>>>10|32768)<<2)>>2]|0;if(u>>>0>9){j=r&1020;y=(d[u+(j|3)|0]|0)<<8|(d[u+(j|2)|0]|0)|((d[u+(j|1)|0]|0)<<8|(d[u+j|0]|0))<<16;z=t}else{t=gj[c[v+196768+(u<<2)>>2]&4095](q)|0;y=t;z=c[2276056]|0}c[2276084]=y;w=y>>>16|s<<16;x=z}c[2276056]=x+2;if((n&2048|0)==0){A=e}else{A=c[9104156+((o&7)<<2)>>2]|0}if((n&32|0)==0){B=f}else{B=c[9104156+((n&7)<<2)>>2]|0}n=((A|0)/8|0)+w|0;w=(A|0)%8|0;if((w|0)<0){C=n-1|0;D=w+8|0}else{C=n;D=w}w=B+31&31;B=-1<<(w^31);n=B>>>(D>>>0);A=c[2276085]|0;f=A&C;o=f&16777215;e=c[2112932]|0;x=c[e+(o>>>10<<2)>>2]|0;if(x>>>0>9){z=f&1023;E=(d[x+(z+3)|0]|0)<<8|(d[x+(z+2)|0]|0)|((d[x+(z+1)|0]|0)<<8|(d[x+z|0]|0))<<16;F=A;G=e}else{A=gj[c[e+196768+(x<<2)>>2]&4095](o)|0;E=A;F=c[2276085]|0;G=c[2112932]|0}c[2276075]=E<<D>>>24;c[2276076]=E&n;c[2276077]=0;c[2276078]=0;A=E|n;n=F&C;F=n&16777215;E=c[G+((F>>>10|16384)<<2)>>2]|0;if(E>>>0>9){o=n&1023;a[E+o|0]=A>>>16&255;a[E+(o+1)|0]=A>>>24&255;a[E+(o+2)|0]=A&255;a[E+(o+3)|0]=A>>>8&255}else{gg[c[G+196808+(E<<2)>>2]&4095](F,A)}if((w+1+D|0)>>>0<=32){return}D=C+4|0;C=c[2276085]|0;w=C&D;A=w&16777215;F=c[2112932]|0;E=c[F+(A>>>10<<2)>>2]|0;if(E>>>0>9){H=a[E+(w&1023^1)|0]|0;I=C;J=F}else{C=gj[c[F+196608+(E<<2)>>2]&4095](A)|0;H=C;I=c[2276085]|0;J=c[2112932]|0}C=H&255;c[2276076]=B&C|c[2276076];H=I&D;D=(C|B)&255;B=H&16777215;C=c[J+((B>>>10|16384)<<2)>>2]|0;if(C>>>0>9){a[C+(H&1023^1)|0]=D;return}else{gg[c[J+196648+(C<<2)>>2]&4095](B,D);return}}function CX(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[2276038]&24|0)==0){Bl();return}a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=f>>>((e<<3&16^16)>>>0);e=k&65535;f=e>>>6;l=9104156+((c[2276069]&7)<<2)|0;if((k&2048|0)==0){m=f&31}else{m=c[9104156+((f&7)<<2)>>2]|0}if((k&32|0)==0){n=e}else{n=c[9104156+((k&7)<<2)>>2]|0}k=m&31;m=-1<<(n+31&31^31);n=32-k|0;c[2276075]=c[l>>2]<<k>>>24;c[2276076]=((n>>>0<32?m<<n:0)|m>>>(k>>>0))&c[l>>2];c[2276077]=0;c[2276078]=0;return}function CY(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0);f=l&65535;g=f>>>6;if((l&2048|0)==0){n=g&31}else{n=c[9104156+((g&7)<<2)>>2]|0}if((l&32|0)==0){o=f}else{o=c[9104156+((l&7)<<2)>>2]|0}l=((n|0)/8|0)+(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;f=(n|0)%8|0;if((f|0)<0){p=l-1|0;q=f+8|0}else{p=l;q=f}f=o+31&31;o=-1<<(f^31);l=c[2276085]&p;n=l&16777215;g=c[2112932]|0;m=c[g+(n>>>10<<2)>>2]|0;if(m>>>0>9){b=l&1023;r=(d[m+(b+3)|0]|0)<<8|(d[m+(b+2)|0]|0)|((d[m+(b+1)|0]|0)<<8|(d[m+b|0]|0))<<16}else{r=gj[c[g+196768+(m<<2)>>2]&4095](n)|0}c[2276075]=(r&-2147483648>>>(q>>>0))<<q>>>24;n=r&o>>>(q>>>0);c[2276076]=n;c[2276077]=0;c[2276078]=0;if((f+1+q|0)>>>0<=32){return}q=c[2276085]&p+4;p=q&16777215;f=c[2112932]|0;r=c[f+(p>>>10<<2)>>2]|0;if(r>>>0>9){s=a[r+(q&1023^1)|0]|0;t=n}else{n=gj[c[f+196608+(r<<2)>>2]&4095](p)|0;s=n;t=c[2276076]|0}c[2276076]=s&255&o|t;return}function CZ(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0);f=n&65535;o=f>>>6;e=o&31;j=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;l=p&-4;if((l|0)==(h|0)){q=p;r=g}else{c[2276083]=l;g=c[2276085]&l;l=g&16777212;h=c[2112932]|0;k=c[h+((l>>>10|32768)<<2)>>2]|0;if(k>>>0>9){b=g&1020;s=(d[k+(b|3)|0]|0)<<8|(d[k+(b|2)|0]|0)|((d[k+(b|1)|0]|0)<<8|(d[k+b|0]|0))<<16;t=p}else{p=gj[c[h+196768+(k<<2)>>2]&4095](l)|0;s=p;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;if((n&2048|0)==0){u=e}else{u=c[9104156+((o&7)<<2)>>2]|0}if((n&32|0)==0){v=f}else{v=c[9104156+((n&7)<<2)>>2]|0}n=(r>>>((q<<3&16^16)>>>0)<<16>>16)+j+((u|0)/8|0)|0;j=(u|0)%8|0;if((j|0)<0){w=n-1|0;x=j+8|0}else{w=n;x=j}j=v+31&31;v=-1<<(j^31);n=c[2276085]&w;u=n&16777215;q=c[2112932]|0;r=c[q+(u>>>10<<2)>>2]|0;if(r>>>0>9){f=n&1023;y=(d[r+(f+3)|0]|0)<<8|(d[r+(f+2)|0]|0)|((d[r+(f+1)|0]|0)<<8|(d[r+f|0]|0))<<16}else{y=gj[c[q+196768+(r<<2)>>2]&4095](u)|0}c[2276075]=(y&-2147483648>>>(x>>>0))<<x>>>24;u=y&v>>>(x>>>0);c[2276076]=u;c[2276077]=0;c[2276078]=0;if((j+1+x|0)>>>0<=32){return}x=c[2276085]&w+4;w=x&16777215;j=c[2112932]|0;y=c[j+(w>>>10<<2)>>2]|0;if(y>>>0>9){z=a[y+(x&1023^1)|0]|0;A=u}else{u=gj[c[j+196608+(y<<2)>>2]&4095](w)|0;z=u;A=c[2276076]|0}c[2276076]=z&255&v|A;return}function C_(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0);f=l&65535;g=f>>>6;m=xw(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;if((l&2048|0)==0){n=g&31}else{n=c[9104156+((g&7)<<2)>>2]|0}if((l&32|0)==0){o=f}else{o=c[9104156+((l&7)<<2)>>2]|0}l=((n|0)/8|0)+m|0;m=(n|0)%8|0;if((m|0)<0){p=l-1|0;q=m+8|0}else{p=l;q=m}m=o+31&31;o=-1<<(m^31);l=c[2276085]&p;n=l&16777215;f=c[2112932]|0;g=c[f+(n>>>10<<2)>>2]|0;if(g>>>0>9){b=l&1023;r=(d[g+(b+3)|0]|0)<<8|(d[g+(b+2)|0]|0)|((d[g+(b+1)|0]|0)<<8|(d[g+b|0]|0))<<16}else{r=gj[c[f+196768+(g<<2)>>2]&4095](n)|0}c[2276075]=(r&-2147483648>>>(q>>>0))<<q>>>24;n=r&o>>>(q>>>0);c[2276076]=n;c[2276077]=0;c[2276078]=0;if((m+1+q|0)>>>0<=32){return}q=c[2276085]&p+4;p=q&16777215;m=c[2112932]|0;r=c[m+(p>>>10<<2)>>2]|0;if(r>>>0>9){s=a[r+(q&1023^1)|0]|0;t=n}else{n=gj[c[m+196608+(r<<2)>>2]&4095](p)|0;s=n;t=c[2276076]|0}c[2276076]=s&255&o|t;return}function C$(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0);f=n&65535;o=f>>>6;e=o&31;j=p&-4;if((j|0)==(h|0)){q=p;r=g}else{c[2276083]=j;g=c[2276085]&j;j=g&16777212;h=c[2112932]|0;l=c[h+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){k=g&1020;s=(d[l+(k|3)|0]|0)<<8|(d[l+(k|2)|0]|0)|((d[l+(k|1)|0]|0)<<8|(d[l+k|0]|0))<<16;t=p}else{p=gj[c[h+196768+(l<<2)>>2]&4095](j)|0;s=p;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;if((n&2048|0)==0){u=e}else{u=c[9104156+((o&7)<<2)>>2]|0}if((n&32|0)==0){v=f}else{v=c[9104156+((n&7)<<2)>>2]|0}n=((u|0)/8|0)+(r>>>((q<<3&16^16)>>>0)<<16>>16)|0;q=(u|0)%8|0;if((q|0)<0){w=n-1|0;x=q+8|0}else{w=n;x=q}q=v+31&31;v=-1<<(q^31);n=c[2276085]&w;u=n&16777215;r=c[2112932]|0;f=c[r+(u>>>10<<2)>>2]|0;if(f>>>0>9){o=n&1023;y=(d[f+(o+3)|0]|0)<<8|(d[f+(o+2)|0]|0)|((d[f+(o+1)|0]|0)<<8|(d[f+o|0]|0))<<16}else{y=gj[c[r+196768+(f<<2)>>2]&4095](u)|0}c[2276075]=(y&-2147483648>>>(x>>>0))<<x>>>24;u=y&v>>>(x>>>0);c[2276076]=u;c[2276077]=0;c[2276078]=0;if((q+1+x|0)>>>0<=32){return}x=c[2276085]&w+4;w=x&16777215;q=c[2112932]|0;y=c[q+(w>>>10<<2)>>2]|0;if(y>>>0>9){z=a[y+(x&1023^1)|0]|0;A=u}else{u=gj[c[q+196608+(y<<2)>>2]&4095](w)|0;z=u;A=c[2276076]|0}c[2276076]=z&255&v|A;return}function C0(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0);f=n&65535;o=f>>>6;e=o&31;j=p&-4;if((j|0)==(h|0)){q=p;r=h;s=g}else{c[2276083]=j;g=c[2276085]&j;h=g&16777212;l=c[2112932]|0;k=c[l+((h>>>10|32768)<<2)>>2]|0;if(k>>>0>9){b=g&1020;t=(d[k+(b|3)|0]|0)<<8|(d[k+(b|2)|0]|0)|((d[k+(b|1)|0]|0)<<8|(d[k+b|0]|0))<<16;u=p;v=j}else{j=gj[c[l+196768+(k<<2)>>2]&4095](h)|0;t=j;u=c[2276056]|0;v=c[2276083]|0}c[2276084]=t;q=u;r=v;s=t}t=q+2|0;c[2276056]=t;q=t&-4;if((q|0)==(r|0)){w=s;x=t}else{c[2276083]=q;r=c[2276085]&q;q=r&16777212;v=c[2112932]|0;u=c[v+((q>>>10|32768)<<2)>>2]|0;if(u>>>0>9){j=r&1020;y=(d[u+(j|3)|0]|0)<<8|(d[u+(j|2)|0]|0)|((d[u+(j|1)|0]|0)<<8|(d[u+j|0]|0))<<16;z=t}else{t=gj[c[v+196768+(u<<2)>>2]&4095](q)|0;y=t;z=c[2276056]|0}c[2276084]=y;w=y>>>16|s<<16;x=z}c[2276056]=x+2;if((n&2048|0)==0){A=e}else{A=c[9104156+((o&7)<<2)>>2]|0}if((n&32|0)==0){B=f}else{B=c[9104156+((n&7)<<2)>>2]|0}n=((A|0)/8|0)+w|0;w=(A|0)%8|0;if((w|0)<0){C=n-1|0;D=w+8|0}else{C=n;D=w}w=B+31&31;B=-1<<(w^31);n=c[2276085]&C;A=n&16777215;f=c[2112932]|0;o=c[f+(A>>>10<<2)>>2]|0;if(o>>>0>9){e=n&1023;E=(d[o+(e+3)|0]|0)<<8|(d[o+(e+2)|0]|0)|((d[o+(e+1)|0]|0)<<8|(d[o+e|0]|0))<<16}else{E=gj[c[f+196768+(o<<2)>>2]&4095](A)|0}c[2276075]=(E&-2147483648>>>(D>>>0))<<D>>>24;A=E&B>>>(D>>>0);c[2276076]=A;c[2276077]=0;c[2276078]=0;if((w+1+D|0)>>>0<=32){return}D=c[2276085]&C+4;C=D&16777215;w=c[2112932]|0;E=c[w+(C>>>10<<2)>>2]|0;if(E>>>0>9){F=a[E+(D&1023^1)|0]|0;G=A}else{A=gj[c[w+196608+(E<<2)>>2]&4095](C)|0;F=A;G=c[2276076]|0}c[2276076]=F&255&B|G;return}function C1(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0);f=n&65535;o=f>>>6;e=o&31;j=p&-4;if((j|0)==(h|0)){q=p;r=g}else{c[2276083]=j;g=c[2276085]&j;j=g&16777212;h=c[2112932]|0;l=c[h+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){k=g&1020;s=(d[l+(k|3)|0]|0)<<8|(d[l+(k|2)|0]|0)|((d[l+(k|1)|0]|0)<<8|(d[l+k|0]|0))<<16;t=p}else{k=gj[c[h+196768+(l<<2)>>2]&4095](j)|0;s=k;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;if((n&2048|0)==0){u=e}else{u=c[9104156+((o&7)<<2)>>2]|0}if((n&32|0)==0){v=f}else{v=c[9104156+((n&7)<<2)>>2]|0}n=(r>>>((q<<3&16^16)>>>0)<<16>>16)+p+((u|0)/8|0)|0;p=(u|0)%8|0;if((p|0)<0){w=n-1|0;x=p+8|0}else{w=n;x=p}p=v+31&31;v=-1<<(p^31);n=c[2276085]&w;u=n&16777215;q=c[2112932]|0;r=c[q+(u>>>10<<2)>>2]|0;if(r>>>0>9){f=n&1023;y=(d[r+(f+3)|0]|0)<<8|(d[r+(f+2)|0]|0)|((d[r+(f+1)|0]|0)<<8|(d[r+f|0]|0))<<16}else{y=gj[c[q+196768+(r<<2)>>2]&4095](u)|0}c[2276075]=(y&-2147483648>>>(x>>>0))<<x>>>24;u=y&v>>>(x>>>0);c[2276076]=u;c[2276077]=0;c[2276078]=0;if((p+1+x|0)>>>0<=32){return}x=c[2276085]&w+4;w=x&16777215;p=c[2112932]|0;y=c[p+(w>>>10<<2)>>2]|0;if(y>>>0>9){z=a[y+(x&1023^1)|0]|0;A=u}else{u=gj[c[p+196608+(y<<2)>>2]&4095](w)|0;z=u;A=c[2276076]|0}c[2276076]=z&255&v|A;return}function C2(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}l=f+2|0;c[2276056]=l;m=g>>>((f<<3&16^16)>>>0);f=m&65535;g=f>>>6;b=xw(l)|0;if((m&2048|0)==0){n=g&31}else{n=c[9104156+((g&7)<<2)>>2]|0}if((m&32|0)==0){o=f}else{o=c[9104156+((m&7)<<2)>>2]|0}m=((n|0)/8|0)+b|0;b=(n|0)%8|0;if((b|0)<0){p=m-1|0;q=b+8|0}else{p=m;q=b}b=o+31&31;o=-1<<(b^31);m=c[2276085]&p;n=m&16777215;f=c[2112932]|0;g=c[f+(n>>>10<<2)>>2]|0;if(g>>>0>9){l=m&1023;r=(d[g+(l+3)|0]|0)<<8|(d[g+(l+2)|0]|0)|((d[g+(l+1)|0]|0)<<8|(d[g+l|0]|0))<<16}else{r=gj[c[f+196768+(g<<2)>>2]&4095](n)|0}c[2276075]=(r&-2147483648>>>(q>>>0))<<q>>>24;n=r&o>>>(q>>>0);c[2276076]=n;c[2276077]=0;c[2276078]=0;if((b+1+q|0)>>>0<=32){return}q=c[2276085]&p+4;p=q&16777215;b=c[2112932]|0;r=c[b+(p>>>10<<2)>>2]|0;if(r>>>0>9){s=a[r+(q&1023^1)|0]|0;t=n}else{n=gj[c[b+196608+(r<<2)>>2]&4095](p)|0;s=n;t=c[2276076]|0}c[2276076]=s&255&o|t;return}function C3(){Bl();return}function C4(){var a=0;a=(c[2276069]<<24>>24)+(c[2276056]|0)|0;c[2276056]=a;if((a|0)!=(c[2276055]|0)){return}c[2276108]=0;return}function C5(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}k=(f>>>((e<<3&16^16)>>>0)<<16>>16)+e|0;c[2276056]=k;if((k|0)!=(c[2276055]|0)){return}c[2276108]=0;return}function C6(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;if((c[2276038]&24|0)==0){Bl();return}a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=b;g=c[2276084]|0}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=o;g=m}m=e+2|0;c[2276056]=m;e=m&-4;if((e|0)==(f|0)){p=g;q=m}else{c[2276083]=e;f=c[2276085]&e;e=f&16777212;o=c[2112932]|0;n=c[o+((e>>>10|32768)<<2)>>2]|0;if(n>>>0>9){b=f&1020;r=(d[n+(b|3)|0]|0)<<8|(d[n+(b|2)|0]|0)|((d[n+(b|1)|0]|0)<<8|(d[n+b|0]|0))<<16;s=m}else{m=gj[c[o+196768+(n<<2)>>2]&4095](e)|0;r=m;s=c[2276056]|0}c[2276084]=r;p=r>>>16|g<<16;q=s}s=q-2+p|0;c[2276056]=s;if((s|0)!=(c[2276055]|0)){return}c[2276108]=0;return}function C7(){var a=0,b=0,d=0;a=c[2276069]|0;b=9104156+((a&7)<<2)|0;d=1<<(c[9104156+((a>>>9&7)<<2)>>2]&31);c[2276076]=d&c[b>>2];c[b>>2]=c[b>>2]|d;return}function C8(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=c[2276069]|0;d=c[9104156+((b&7|8)<<2)>>2]|0;e=c[2276085]|0;f=e&d;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=a[i+(f&1023^1)|0]|0;k=b;l=e;m=h}else{e=gj[c[h+196608+(i<<2)>>2]&4095](g)|0;j=e;k=c[2276069]|0;l=c[2276085]|0;m=c[2112932]|0}e=j&255;j=1<<(c[9104156+((k>>>9&7)<<2)>>2]&7);c[2276076]=j&e;k=l&d;d=(j|e)&255;e=k&16777215;j=c[m+((e>>>10|16384)<<2)>>2]|0;if(j>>>0>9){a[j+(k&1023^1)|0]=d;return}else{gg[c[m+196648+(j<<2)>>2]&4095](e,d);return}}function C9(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;b=c[2276085]|0;e=b&d;f=e&16777215;g=c[2112932]|0;h=c[g+(f>>>10<<2)>>2]|0;if(h>>>0>9){i=a[h+(e&1023^1)|0]|0;j=b;k=g}else{b=gj[c[g+196608+(h<<2)>>2]&4095](f)|0;i=b;j=c[2276085]|0;k=c[2112932]|0}b=i&255;i=1<<(c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]&7);c[2276076]=i&b;f=j&d;d=(i|b)&255;b=f&16777215;i=c[k+((b>>>10|16384)<<2)>>2]|0;if(i>>>0>9){a[i+(f&1023^1)|0]=d;return}else{gg[c[k+196648+(i<<2)>>2]&4095](b,d);return}}function Da(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[2276054]|0;c[2276054]=b+2;d=c[2276085]|0;e=d&b;f=e&16777215;g=c[2112932]|0;h=c[g+(f>>>10<<2)>>2]|0;if(h>>>0>9){i=a[h+(e&1023^1)|0]|0;j=d;k=g}else{d=gj[c[g+196608+(h<<2)>>2]&4095](f)|0;i=d;j=c[2276085]|0;k=c[2112932]|0}d=i&255;i=1<<(c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]&7);c[2276076]=i&d;f=j&b;b=(i|d)&255;d=f&16777215;i=c[k+((d>>>10|16384)<<2)>>2]|0;if(i>>>0>9){a[i+(f&1023^1)|0]=b;return}else{gg[c[k+196648+(i<<2)>>2]&4095](d,b);return}}function Db(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;b=c[2276085]|0;e=b&d;f=e&16777215;g=c[2112932]|0;h=c[g+(f>>>10<<2)>>2]|0;if(h>>>0>9){i=a[h+(e&1023^1)|0]|0;j=b;k=g}else{b=gj[c[g+196608+(h<<2)>>2]&4095](f)|0;i=b;j=c[2276085]|0;k=c[2112932]|0}b=i&255;i=1<<(c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]&7);c[2276076]=i&b;f=j&d;d=(i|b)&255;b=f&16777215;i=c[k+((b>>>10|16384)<<2)>>2]|0;if(i>>>0>9){a[i+(f&1023^1)|0]=d;return}else{gg[c[k+196648+(i<<2)>>2]&4095](b,d);return}}function Dc(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=(c[2276054]|0)-2|0;c[2276054]=b;d=c[2276085]|0;e=d&b;f=e&16777215;g=c[2112932]|0;h=c[g+(f>>>10<<2)>>2]|0;if(h>>>0>9){i=a[h+(e&1023^1)|0]|0;j=d;k=g}else{d=gj[c[g+196608+(h<<2)>>2]&4095](f)|0;i=d;j=c[2276085]|0;k=c[2112932]|0}d=i&255;i=1<<(c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]&7);c[2276076]=i&d;f=j&b;b=(i|d)&255;d=f&16777215;i=c[k+((d>>>10|16384)<<2)>>2]|0;if(i>>>0>9){a[i+(f&1023^1)|0]=b;return}else{gg[c[k+196648+(i<<2)>>2]&4095](d,b);return}}function Dd(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=(h>>>((g<<3&16^16)>>>0)<<16>>16)+b|0;b=c[2276085]|0;g=m&b;h=g&16777215;n=c[2112932]|0;e=c[n+(h>>>10<<2)>>2]|0;if(e>>>0>9){o=a[e+(g&1023^1)|0]|0;p=b;q=n}else{b=gj[c[n+196608+(e<<2)>>2]&4095](h)|0;o=b;p=c[2276085]|0;q=c[2112932]|0}b=o&255;o=1<<(c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]&7);c[2276076]=o&b;h=p&m;m=(o|b)&255;b=h&16777215;o=c[q+((b>>>10|16384)<<2)>>2]|0;if(o>>>0>9){a[o+(h&1023^1)|0]=m;return}else{gg[c[q+196648+(o<<2)>>2]&4095](b,m);return}}function De(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=xw(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;d=c[2276085]|0;e=d&b;f=e&16777215;g=c[2112932]|0;h=c[g+(f>>>10<<2)>>2]|0;if(h>>>0>9){i=a[h+(e&1023^1)|0]|0;j=d;k=g}else{d=gj[c[g+196608+(h<<2)>>2]&4095](f)|0;i=d;j=c[2276085]|0;k=c[2112932]|0}d=i&255;i=1<<(c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]&7);c[2276076]=i&d;f=j&b;b=(i|d)&255;d=f&16777215;i=c[k+((d>>>10|16384)<<2)>>2]|0;if(i>>>0>9){a[i+(f&1023^1)|0]=b;return}else{gg[c[k+196648+(i<<2)>>2]&4095](d,b);return}}function Df(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)<<16>>16;f=c[2276085]|0;g=l&f;m=g&16777215;b=c[2112932]|0;e=c[b+(m>>>10<<2)>>2]|0;if(e>>>0>9){n=a[e+(g&1023^1)|0]|0;o=f;p=b}else{f=gj[c[b+196608+(e<<2)>>2]&4095](m)|0;n=f;o=c[2276085]|0;p=c[2112932]|0}f=n&255;n=1<<(c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]&7);c[2276076]=n&f;m=o&l;l=(n|f)&255;f=m&16777215;n=c[p+((f>>>10|16384)<<2)>>2]|0;if(n>>>0>9){a[n+(m&1023^1)|0]=l;return}else{gg[c[p+196648+(n<<2)>>2]&4095](f,l);return}}function Dg(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[2276085]|0;t=r&q;h=t&16777215;s=c[2112932]|0;n=c[s+(h>>>10<<2)>>2]|0;if(n>>>0>9){u=a[n+(t&1023^1)|0]|0;v=r;w=s}else{r=gj[c[s+196608+(n<<2)>>2]&4095](h)|0;u=r;v=c[2276085]|0;w=c[2112932]|0}r=u&255;u=1<<(c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]&7);c[2276076]=u&r;h=v&q;q=(u|r)&255;r=h&16777215;u=c[w+((r>>>10|16384)<<2)>>2]|0;if(u>>>0>9){a[u+(h&1023^1)|0]=q;return}else{gg[c[w+196648+(u<<2)>>2]&4095](r,q);return}}function Dh(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=9104156+((c[2276069]&7)<<2)|0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=1<<(g>>>((f<<3&16^16)>>>0)&31);c[2276076]=l&c[a>>2];c[a>>2]=l|c[a>>2];return}function Di(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=1<<(g>>>((f<<3&16^16)>>>0)&7);f=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;g=c[2276085]|0;m=g&f;b=m&16777215;e=c[2112932]|0;j=c[e+(b>>>10<<2)>>2]|0;if(j>>>0>9){n=a[j+(m&1023^1)|0]|0;o=g;p=e}else{g=gj[c[e+196608+(j<<2)>>2]&4095](b)|0;n=g;o=c[2276085]|0;p=c[2112932]|0}g=n&255;c[2276076]=g&l;n=o&f;f=(g|l)&255;l=n&16777215;g=c[p+((l>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(n&1023^1)|0]=f;return}else{gg[c[p+196648+(g<<2)>>2]&4095](l,f);return}}function Dj(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=1<<(g>>>((f<<3&16^16)>>>0)&7);f=9104156+((c[2276069]&7|8)<<2)|0;g=c[f>>2]|0;c[f>>2]=g+1;f=c[2276085]|0;m=f&g;b=m&16777215;e=c[2112932]|0;j=c[e+(b>>>10<<2)>>2]|0;if(j>>>0>9){n=a[j+(m&1023^1)|0]|0;o=f;p=e}else{f=gj[c[e+196608+(j<<2)>>2]&4095](b)|0;n=f;o=c[2276085]|0;p=c[2112932]|0}f=n&255;c[2276076]=f&l;n=o&g;g=(f|l)&255;l=n&16777215;f=c[p+((l>>>10|16384)<<2)>>2]|0;if(f>>>0>9){a[f+(n&1023^1)|0]=g;return}else{gg[c[p+196648+(f<<2)>>2]&4095](l,g);return}}function Dk(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=1<<(g>>>((f<<3&16^16)>>>0)&7);f=c[2276054]|0;c[2276054]=f+2;g=c[2276085]|0;m=g&f;b=m&16777215;e=c[2112932]|0;j=c[e+(b>>>10<<2)>>2]|0;if(j>>>0>9){n=a[j+(m&1023^1)|0]|0;o=g;p=e}else{g=gj[c[e+196608+(j<<2)>>2]&4095](b)|0;n=g;o=c[2276085]|0;p=c[2112932]|0}g=n&255;c[2276076]=g&l;n=o&f;f=(g|l)&255;l=n&16777215;g=c[p+((l>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(n&1023^1)|0]=f;return}else{gg[c[p+196648+(g<<2)>>2]&4095](l,f);return}}function Dl(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=1<<(g>>>((f<<3&16^16)>>>0)&7);f=9104156+((c[2276069]&7|8)<<2)|0;g=(c[f>>2]|0)-1|0;c[f>>2]=g;f=c[2276085]|0;m=f&g;b=m&16777215;e=c[2112932]|0;j=c[e+(b>>>10<<2)>>2]|0;if(j>>>0>9){n=a[j+(m&1023^1)|0]|0;o=f;p=e}else{f=gj[c[e+196608+(j<<2)>>2]&4095](b)|0;n=f;o=c[2276085]|0;p=c[2112932]|0}f=n&255;c[2276076]=f&l;n=o&g;g=(f|l)&255;l=n&16777215;f=c[p+((l>>>10|16384)<<2)>>2]|0;if(f>>>0>9){a[f+(n&1023^1)|0]=g;return}else{gg[c[p+196648+(f<<2)>>2]&4095](l,g);return}}function Dm(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=1<<(g>>>((f<<3&16^16)>>>0)&7);f=(c[2276054]|0)-2|0;c[2276054]=f;g=c[2276085]|0;m=g&f;b=m&16777215;e=c[2112932]|0;j=c[e+(b>>>10<<2)>>2]|0;if(j>>>0>9){n=a[j+(m&1023^1)|0]|0;o=g;p=e}else{g=gj[c[e+196608+(j<<2)>>2]&4095](b)|0;n=g;o=c[2276085]|0;p=c[2112932]|0}g=n&255;c[2276076]=g&l;n=o&f;f=(g|l)&255;l=n&16777215;g=c[p+((l>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(n&1023^1)|0]=f;return}else{gg[c[p+196648+(g<<2)>>2]&4095](l,f);return}}function Dn(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=1<<(g>>>((f<<3&16^16)>>>0)&7);f=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;o=p&-4;if((o|0)==(h|0)){q=p;r=g}else{c[2276083]=o;g=c[2276085]&o;o=g&16777212;h=c[2112932]|0;e=c[h+((o>>>10|32768)<<2)>>2]|0;if(e>>>0>9){j=g&1020;s=(d[e+(j|3)|0]|0)<<8|(d[e+(j|2)|0]|0)|((d[e+(j|1)|0]|0)<<8|(d[e+j|0]|0))<<16;t=p}else{p=gj[c[h+196768+(e<<2)>>2]&4095](o)|0;s=p;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;s=(r>>>((q<<3&16^16)>>>0)<<16>>16)+f|0;f=c[2276085]|0;q=s&f;r=q&16777215;t=c[2112932]|0;p=c[t+(r>>>10<<2)>>2]|0;if(p>>>0>9){u=a[p+(q&1023^1)|0]|0;v=f;w=t}else{f=gj[c[t+196608+(p<<2)>>2]&4095](r)|0;u=f;v=c[2276085]|0;w=c[2112932]|0}f=u&255;c[2276076]=f&n;u=v&s;s=(f|n)&255;n=u&16777215;f=c[w+((n>>>10|16384)<<2)>>2]|0;if(f>>>0>9){a[f+(u&1023^1)|0]=s;return}else{gg[c[w+196648+(f<<2)>>2]&4095](n,s);return}}function Do(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=1<<(g>>>((f<<3&16^16)>>>0)&7);f=xw(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;g=c[2276085]|0;m=g&f;b=m&16777215;e=c[2112932]|0;j=c[e+(b>>>10<<2)>>2]|0;if(j>>>0>9){n=a[j+(m&1023^1)|0]|0;o=g;p=e}else{g=gj[c[e+196608+(j<<2)>>2]&4095](b)|0;n=g;o=c[2276085]|0;p=c[2112932]|0}g=n&255;c[2276076]=g&l;n=o&f;f=(g|l)&255;l=n&16777215;g=c[p+((l>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(n&1023^1)|0]=f;return}else{gg[c[p+196648+(g<<2)>>2]&4095](l,f);return}}function Dp(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=1<<(g>>>((f<<3&16^16)>>>0)&7);f=p&-4;if((f|0)==(h|0)){q=p;r=g}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;h=c[2112932]|0;o=c[h+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=p}else{p=gj[c[h+196768+(o<<2)>>2]&4095](f)|0;s=p;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;s=r>>>((q<<3&16^16)>>>0)<<16>>16;q=c[2276085]|0;r=s&q;t=r&16777215;p=c[2112932]|0;f=c[p+(t>>>10<<2)>>2]|0;if(f>>>0>9){u=a[f+(r&1023^1)|0]|0;v=q;w=p}else{q=gj[c[p+196608+(f<<2)>>2]&4095](t)|0;u=q;v=c[2276085]|0;w=c[2112932]|0}q=u&255;c[2276076]=q&n;u=v&s;s=(q|n)&255;n=u&16777215;q=c[w+((n>>>10|16384)<<2)>>2]|0;if(q>>>0>9){a[q+(u&1023^1)|0]=s;return}else{gg[c[w+196648+(q<<2)>>2]&4095](n,s);return}}function Dq(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=1<<(g>>>((f<<3&16^16)>>>0)&7);f=p&-4;if((f|0)==(h|0)){q=p;r=h;s=g}else{c[2276083]=f;g=c[2276085]&f;h=g&16777212;o=c[2112932]|0;e=c[o+((h>>>10|32768)<<2)>>2]|0;if(e>>>0>9){j=g&1020;t=(d[e+(j|3)|0]|0)<<8|(d[e+(j|2)|0]|0)|((d[e+(j|1)|0]|0)<<8|(d[e+j|0]|0))<<16;u=p;v=f}else{f=gj[c[o+196768+(e<<2)>>2]&4095](h)|0;t=f;u=c[2276056]|0;v=c[2276083]|0}c[2276084]=t;q=u;r=v;s=t}t=q+2|0;c[2276056]=t;q=t&-4;if((q|0)==(r|0)){w=s;x=t}else{c[2276083]=q;r=c[2276085]&q;q=r&16777212;v=c[2112932]|0;u=c[v+((q>>>10|32768)<<2)>>2]|0;if(u>>>0>9){f=r&1020;y=(d[u+(f|3)|0]|0)<<8|(d[u+(f|2)|0]|0)|((d[u+(f|1)|0]|0)<<8|(d[u+f|0]|0))<<16;z=t}else{t=gj[c[v+196768+(u<<2)>>2]&4095](q)|0;y=t;z=c[2276056]|0}c[2276084]=y;w=y>>>16|s<<16;x=z}c[2276056]=x+2;x=c[2276085]|0;z=x&w;s=z&16777215;y=c[2112932]|0;t=c[y+(s>>>10<<2)>>2]|0;if(t>>>0>9){A=a[t+(z&1023^1)|0]|0;B=x;C=y}else{x=gj[c[y+196608+(t<<2)>>2]&4095](s)|0;A=x;B=c[2276085]|0;C=c[2112932]|0}x=A&255;c[2276076]=x&n;A=B&w;w=(x|n)&255;n=A&16777215;x=c[C+((n>>>10|16384)<<2)>>2]|0;if(x>>>0>9){a[x+(A&1023^1)|0]=w;return}else{gg[c[C+196648+(x<<2)>>2]&4095](n,w);return}}function Dr(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=c[2276056]|0;d=(c[2276054]|0)-4|0;c[2276054]=d;e=c[2276085]&d;d=e&16777215;f=c[2112932]|0;g=c[f+((d>>>10|16384)<<2)>>2]|0;if(g>>>0>9){h=e&1023;a[g+h|0]=b>>>16&255;a[g+(h+1)|0]=b>>>24&255;a[g+(h+2)|0]=b&255;a[g+(h+3)|0]=b>>>8&255;i=c[2276069]|0;j=i<<24;k=j>>24;l=c[2276056]|0;m=k+l|0;c[2276056]=m;return}else{gg[c[f+196808+(g<<2)>>2]&4095](d,b);i=c[2276069]|0;j=i<<24;k=j>>24;l=c[2276056]|0;m=k+l|0;c[2276056]=m;return}}function Ds(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}l=f+2|0;c[2276056]=l;m=g>>>((f<<3&16^16)>>>0);f=(c[2276054]|0)-4|0;c[2276054]=f;g=c[2276085]&f;f=g&16777215;b=c[2112932]|0;e=c[b+((f>>>10|16384)<<2)>>2]|0;if(e>>>0>9){j=g&1023;a[e+j|0]=l>>>16&255;a[e+(j+1)|0]=l>>>24&255;a[e+(j+2)|0]=l&255;a[e+(j+3)|0]=l>>>8&255;n=c[2276056]|0;o=m<<16;p=o>>16;q=p-2|0;r=q+n|0;c[2276056]=r;return}else{gg[c[b+196808+(e<<2)>>2]&4095](f,l);n=c[2276056]|0;o=m<<16;p=o>>16;q=p-2|0;r=q+n|0;c[2276056]=r;return}}function Dt(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}t=r+2|0;c[2276056]=t;r=(c[2276054]|0)-4|0;c[2276054]=r;h=c[2276085]&r;r=h&16777215;s=c[2112932]|0;n=c[s+((r>>>10|16384)<<2)>>2]|0;if(n>>>0>9){f=h&1023;a[n+f|0]=t>>>16&255;a[n+(f+1)|0]=t>>>24&255;a[n+(f+2)|0]=t&255;a[n+(f+3)|0]=t>>>8&255}else{gg[c[s+196808+(n<<2)>>2]&4095](r,t)}c[2276056]=q-4+(c[2276056]|0);return}function Du(){var a=0;a=c[2276069]|0;c[2276076]=1<<(c[9104156+((a>>>9&7)<<2)>>2]&31)&c[9104156+((a&7)<<2)>>2];return}function Dv(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=c[2276069]|0;d=c[2276085]&c[9104156+((b&7|8)<<2)>>2];e=d&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=a[g+(d&1023^1)|0]|0;i=b}else{b=gj[c[f+196608+(g<<2)>>2]&4095](e)|0;h=b;i=c[2276069]|0}c[2276076]=1<<(c[9104156+((i>>>9&7)<<2)>>2]&7)&(h&255);return}function Dw(){var b=0,d=0,e=0,f=0,g=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;b=c[2276085]&d;d=b&16777215;e=c[2112932]|0;f=c[e+(d>>>10<<2)>>2]|0;if(f>>>0>9){g=a[f+(b&1023^1)|0]|0}else{g=gj[c[e+196608+(f<<2)>>2]&4095](d)|0}c[2276076]=1<<(c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]&7)&(g&255);return}function Dx(){var b=0,d=0,e=0,f=0,g=0;b=c[2276054]|0;c[2276054]=b+2;d=c[2276085]&b;b=d&16777215;e=c[2112932]|0;f=c[e+(b>>>10<<2)>>2]|0;if(f>>>0>9){g=a[f+(d&1023^1)|0]|0}else{g=gj[c[e+196608+(f<<2)>>2]&4095](b)|0}c[2276076]=1<<(c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]&7)&(g&255);return}function Dy(){var b=0,d=0,e=0,f=0,g=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;b=c[2276085]&d;d=b&16777215;e=c[2112932]|0;f=c[e+(d>>>10<<2)>>2]|0;if(f>>>0>9){g=a[f+(b&1023^1)|0]|0}else{g=gj[c[e+196608+(f<<2)>>2]&4095](d)|0}c[2276076]=1<<(c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]&7)&(g&255);return}function Dz(){var b=0,d=0,e=0,f=0,g=0;b=(c[2276054]|0)-2|0;c[2276054]=b;d=c[2276085]&b;b=d&16777215;e=c[2112932]|0;f=c[e+(b>>>10<<2)>>2]|0;if(f>>>0>9){g=a[f+(d&1023^1)|0]|0}else{g=gj[c[e+196608+(f<<2)>>2]&4095](b)|0}c[2276076]=1<<(c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]&7)&(g&255);return}function DA(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=(h>>>((g<<3&16^16)>>>0)<<16>>16)+b&c[2276085];b=m&16777215;g=c[2112932]|0;h=c[g+(b>>>10<<2)>>2]|0;if(h>>>0>9){o=a[h+(m&1023^1)|0]|0;p=o&255;q=c[2276069]|0;r=q>>>9;s=r&7;t=9104156+(s<<2)|0;u=c[t>>2]|0;v=u&7;w=1<<v;x=w&p;c[2276076]=x;return}else{o=gj[c[g+196608+(h<<2)>>2]&4095](b)|0;p=o&255;q=c[2276069]|0;r=q>>>9;s=r&7;t=9104156+(s<<2)|0;u=c[t>>2]|0;v=u&7;w=1<<v;x=w&p;c[2276076]=x;return}}function DB(){var b=0,d=0,e=0,f=0,g=0;b=xw(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;d=c[2276085]&b;b=d&16777215;e=c[2112932]|0;f=c[e+(b>>>10<<2)>>2]|0;if(f>>>0>9){g=a[f+(d&1023^1)|0]|0}else{g=gj[c[e+196608+(f<<2)>>2]&4095](b)|0}c[2276076]=1<<(c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]&7)&(g&255);return}function DC(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)<<16>>16&c[2276085];f=l&16777215;g=c[2112932]|0;m=c[g+(f>>>10<<2)>>2]|0;if(m>>>0>9){n=a[m+(l&1023^1)|0]|0;o=n&255;p=c[2276069]|0;q=p>>>9;r=q&7;s=9104156+(r<<2)|0;t=c[s>>2]|0;u=t&7;v=1<<u;w=v&o;c[2276076]=w;return}else{n=gj[c[g+196608+(m<<2)>>2]&4095](f)|0;o=n&255;p=c[2276069]|0;q=p>>>9;r=q&7;s=9104156+(r<<2)|0;t=c[s>>2]|0;u=t&7;v=1<<u;w=v&o;c[2276076]=w;return}}function DD(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[2276085]&q;q=r&16777215;t=c[2112932]|0;h=c[t+(q>>>10<<2)>>2]|0;if(h>>>0>9){u=a[h+(r&1023^1)|0]|0;v=u&255;w=c[2276069]|0;x=w>>>9;y=x&7;z=9104156+(y<<2)|0;A=c[z>>2]|0;B=A&7;C=1<<B;D=C&v;c[2276076]=D;return}else{u=gj[c[t+196608+(h<<2)>>2]&4095](q)|0;v=u&255;w=c[2276069]|0;x=w>>>9;y=x&7;z=9104156+(y<<2)|0;A=c[z>>2]|0;B=A&7;C=1<<B;D=C&v;c[2276076]=D;return}}function DE(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{k=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=k;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=(g>>>((f<<3&16^16)>>>0)<<16>>16)+b|0;b=l&16777215;f=c[2112932]|0;g=c[f+((b>>>10|32768)<<2)>>2]|0;if(g>>>0>9){n=a[g+(l&1023^1)|0]|0;o=n&255;p=c[2276069]|0;q=p>>>9;r=q&7;s=9104156+(r<<2)|0;t=c[s>>2]|0;u=t&7;v=1<<u;w=v&o;c[2276076]=w;return}else{n=gj[c[f+196608+(g<<2)>>2]&4095](b)|0;o=n&255;p=c[2276069]|0;q=p>>>9;r=q&7;s=9104156+(r<<2)|0;t=c[s>>2]|0;u=t&7;v=1<<u;w=v&o;c[2276076]=w;return}}function DF(){var b=0,d=0,e=0,f=0,g=0;b=xw(c[2276056]|0)|0;d=b&16777215;e=c[2112932]|0;f=c[e+((d>>>10|32768)<<2)>>2]|0;if(f>>>0>9){g=a[f+(b&1023^1)|0]|0}else{g=gj[c[e+196608+(f<<2)>>2]&4095](d)|0}c[2276076]=1<<(c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]&7)&(g&255);return}function DG(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;c[2276076]=f>>>((e<<3&16^16)>>>0)&255&1<<(c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]&7);return}function DH(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;a=c[9104156+((c[2276069]&7)<<2)>>2]|0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=f+2|0;c[2276056]=h;i=f<<3;j=i&16;k=j^16;l=g>>>(k>>>0);m=l&31;n=1<<m;o=n&a;c[2276076]=o;return}c[2276083]=e;p=c[2276085]&e;e=p&16777212;q=c[2112932]|0;r=c[q+((e>>>10|32768)<<2)>>2]|0;if(r>>>0>9){s=p&1020;t=(d[r+(s|3)|0]|0)<<8|(d[r+(s|2)|0]|0)|((d[r+(s|1)|0]|0)<<8|(d[r+s|0]|0))<<16;u=b}else{b=gj[c[q+196768+(r<<2)>>2]&4095](e)|0;t=b;u=c[2276056]|0}c[2276084]=t;f=u;g=t;h=f+2|0;c[2276056]=h;i=f<<3;j=i&16;k=j^16;l=g>>>(k>>>0);m=l&31;n=1<<m;o=n&a;c[2276076]=o;return}function DI(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)&7;f=c[2276085]&c[9104156+((c[2276069]&7|8)<<2)>>2];g=f&16777215;m=c[2112932]|0;b=c[m+(g>>>10<<2)>>2]|0;if(b>>>0>9){n=a[b+(f&1023^1)|0]|0;o=n&255;p=1<<l;q=o&p;c[2276076]=q;return}else{n=gj[c[m+196608+(b<<2)>>2]&4095](g)|0;o=n&255;p=1<<l;q=o&p;c[2276076]=q;return}}function DJ(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)&7;f=9104156+((c[2276069]&7|8)<<2)|0;g=c[f>>2]|0;c[f>>2]=g+1;f=c[2276085]&g;g=f&16777215;m=c[2112932]|0;b=c[m+(g>>>10<<2)>>2]|0;if(b>>>0>9){n=a[b+(f&1023^1)|0]|0;o=n&255;p=1<<l;q=o&p;c[2276076]=q;return}else{n=gj[c[m+196608+(b<<2)>>2]&4095](g)|0;o=n&255;p=1<<l;q=o&p;c[2276076]=q;return}}function DK(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)&7;f=c[2276054]|0;c[2276054]=f+2;g=c[2276085]&f;f=g&16777215;m=c[2112932]|0;b=c[m+(f>>>10<<2)>>2]|0;if(b>>>0>9){n=a[b+(g&1023^1)|0]|0;o=n&255;p=1<<l;q=o&p;c[2276076]=q;return}else{n=gj[c[m+196608+(b<<2)>>2]&4095](f)|0;o=n&255;p=1<<l;q=o&p;c[2276076]=q;return}}function DL(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)&7;f=9104156+((c[2276069]&7|8)<<2)|0;g=(c[f>>2]|0)-1|0;c[f>>2]=g;f=c[2276085]&g;g=f&16777215;m=c[2112932]|0;b=c[m+(g>>>10<<2)>>2]|0;if(b>>>0>9){n=a[b+(f&1023^1)|0]|0;o=n&255;p=1<<l;q=o&p;c[2276076]=q;return}else{n=gj[c[m+196608+(b<<2)>>2]&4095](g)|0;o=n&255;p=1<<l;q=o&p;c[2276076]=q;return}}function DM(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)&7;f=(c[2276054]|0)-2|0;c[2276054]=f;g=c[2276085]&f;f=g&16777215;m=c[2112932]|0;b=c[m+(f>>>10<<2)>>2]|0;if(b>>>0>9){n=a[b+(g&1023^1)|0]|0;o=n&255;p=1<<l;q=o&p;c[2276076]=q;return}else{n=gj[c[m+196608+(b<<2)>>2]&4095](f)|0;o=n&255;p=1<<l;q=o&p;c[2276076]=q;return}}function DN(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0)&7;f=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;o=p&-4;if((o|0)==(h|0)){q=p;r=g}else{c[2276083]=o;g=c[2276085]&o;o=g&16777212;h=c[2112932]|0;e=c[h+((o>>>10|32768)<<2)>>2]|0;if(e>>>0>9){j=g&1020;s=(d[e+(j|3)|0]|0)<<8|(d[e+(j|2)|0]|0)|((d[e+(j|1)|0]|0)<<8|(d[e+j|0]|0))<<16;t=p}else{p=gj[c[h+196768+(e<<2)>>2]&4095](o)|0;s=p;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;s=(r>>>((q<<3&16^16)>>>0)<<16>>16)+f&c[2276085];f=s&16777215;q=c[2112932]|0;r=c[q+(f>>>10<<2)>>2]|0;if(r>>>0>9){u=a[r+(s&1023^1)|0]|0;v=u&255;w=1<<n;x=v&w;c[2276076]=x;return}else{u=gj[c[q+196608+(r<<2)>>2]&4095](f)|0;v=u&255;w=1<<n;x=v&w;c[2276076]=x;return}}function DO(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)&7;f=xw(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;g=c[2276085]&f;f=g&16777215;m=c[2112932]|0;b=c[m+(f>>>10<<2)>>2]|0;if(b>>>0>9){n=a[b+(g&1023^1)|0]|0;o=n&255;p=1<<l;q=o&p;c[2276076]=q;return}else{n=gj[c[m+196608+(b<<2)>>2]&4095](f)|0;o=n&255;p=1<<l;q=o&p;c[2276076]=q;return}}function DP(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0)&7;f=p&-4;if((f|0)==(h|0)){q=p;r=g}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;h=c[2112932]|0;o=c[h+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=p}else{p=gj[c[h+196768+(o<<2)>>2]&4095](f)|0;s=p;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;s=r>>>((q<<3&16^16)>>>0)<<16>>16&c[2276085];q=s&16777215;r=c[2112932]|0;t=c[r+(q>>>10<<2)>>2]|0;if(t>>>0>9){u=a[t+(s&1023^1)|0]|0;v=u&255;w=1<<n;x=v&w;c[2276076]=x;return}else{u=gj[c[r+196608+(t<<2)>>2]&4095](q)|0;v=u&255;w=1<<n;x=v&w;c[2276076]=x;return}}function DQ(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0)&7;f=p&-4;if((f|0)==(h|0)){q=p;r=h;s=g}else{c[2276083]=f;g=c[2276085]&f;h=g&16777212;o=c[2112932]|0;e=c[o+((h>>>10|32768)<<2)>>2]|0;if(e>>>0>9){j=g&1020;t=(d[e+(j|3)|0]|0)<<8|(d[e+(j|2)|0]|0)|((d[e+(j|1)|0]|0)<<8|(d[e+j|0]|0))<<16;u=p;v=f}else{f=gj[c[o+196768+(e<<2)>>2]&4095](h)|0;t=f;u=c[2276056]|0;v=c[2276083]|0}c[2276084]=t;q=u;r=v;s=t}t=q+2|0;c[2276056]=t;q=t&-4;if((q|0)==(r|0)){w=s;x=t}else{c[2276083]=q;r=c[2276085]&q;q=r&16777212;v=c[2112932]|0;u=c[v+((q>>>10|32768)<<2)>>2]|0;if(u>>>0>9){f=r&1020;y=(d[u+(f|3)|0]|0)<<8|(d[u+(f|2)|0]|0)|((d[u+(f|1)|0]|0)<<8|(d[u+f|0]|0))<<16;z=t}else{t=gj[c[v+196768+(u<<2)>>2]&4095](q)|0;y=t;z=c[2276056]|0}c[2276084]=y;w=y>>>16|s<<16;x=z}c[2276056]=x+2;x=c[2276085]&w;w=x&16777215;z=c[2112932]|0;s=c[z+(w>>>10<<2)>>2]|0;if(s>>>0>9){A=a[s+(x&1023^1)|0]|0;B=A&255;C=1<<n;D=B&C;c[2276076]=D;return}else{A=gj[c[z+196608+(s<<2)>>2]&4095](w)|0;B=A&255;C=1<<n;D=B&C;c[2276076]=D;return}}function DR(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0)&7;f=p&-4;if((f|0)==(h|0)){q=p;r=g}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;h=c[2112932]|0;o=c[h+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=p}else{e=gj[c[h+196768+(o<<2)>>2]&4095](f)|0;s=e;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;s=(r>>>((q<<3&16^16)>>>0)<<16>>16)+p|0;p=s&16777215;q=c[2112932]|0;r=c[q+((p>>>10|32768)<<2)>>2]|0;if(r>>>0>9){u=a[r+(s&1023^1)|0]|0;v=u&255;w=1<<n;x=v&w;c[2276076]=x;return}else{u=gj[c[q+196608+(r<<2)>>2]&4095](p)|0;v=u&255;w=1<<n;x=v&w;c[2276076]=x;return}}function DS(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}l=f+2|0;c[2276056]=l;m=g>>>((f<<3&16^16)>>>0)&7;f=xw(l)|0;l=f&16777215;g=c[2112932]|0;b=c[g+((l>>>10|32768)<<2)>>2]|0;if(b>>>0>9){n=a[b+(f&1023^1)|0]|0;o=n&255;p=1<<m;q=o&p;c[2276076]=q;return}else{n=gj[c[g+196608+(b<<2)>>2]&4095](l)|0;o=n&255;p=1<<m;q=o&p;c[2276076]=q;return}}function DT(){if((c[2276038]&24|0)==0){Bl();return}else{c[2276056]=(c[2276056]|0)+2;return}}function DU(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if((c[2276038]&24|0)==0){Bl();return}a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a}else{c[2276083]=b;f=c[2276085]&b;b=f&16777212;g=c[2112932]|0;h=c[g+((b>>>10|32768)<<2)>>2]|0;if(h>>>0>9){i=f&1020;j=(d[h+(i|3)|0]|0)<<8|(d[h+(i|2)|0]|0)|((d[h+(i|1)|0]|0)<<8|(d[h+i|0]|0))<<16;k=a}else{a=gj[c[g+196768+(h<<2)>>2]&4095](b)|0;j=a;k=c[2276056]|0}c[2276084]=j;e=k}c[2276056]=e+4;return}function DV(){var a=0;if((c[2276038]&24|0)==0){Bl();return}else{a=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;xw(a)|0;c[2276056]=(c[2276056]|0)+2;return}}function DW(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if((c[2276038]&24|0)==0){Bl();return}a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a}else{c[2276083]=b;f=c[2276085]&b;b=f&16777212;g=c[2112932]|0;h=c[g+((b>>>10|32768)<<2)>>2]|0;if(h>>>0>9){i=f&1020;j=(d[h+(i|3)|0]|0)<<8|(d[h+(i|2)|0]|0)|((d[h+(i|1)|0]|0)<<8|(d[h+i|0]|0))<<16;k=a}else{a=gj[c[g+196768+(h<<2)>>2]&4095](b)|0;j=a;k=c[2276056]|0}c[2276084]=j;e=k}c[2276056]=e+4;return}function DX(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((c[2276038]&24|0)==0){Bl();return}a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=b}else{c[2276083]=b;g=c[2276085]&b;h=g&16777212;i=c[2112932]|0;j=c[i+((h>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=g&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=a;n=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](h)|0;l=b;m=c[2276056]|0;n=c[2276083]|0}c[2276084]=l;e=m;f=n}n=e+2|0;c[2276056]=n;e=n&-4;if((e|0)==(f|0)){o=n}else{c[2276083]=e;f=c[2276085]&e;e=f&16777212;m=c[2112932]|0;l=c[m+((e>>>10|32768)<<2)>>2]|0;if(l>>>0>9){b=f&1020;p=(d[l+(b|3)|0]|0)<<8|(d[l+(b|2)|0]|0)|((d[l+(b|1)|0]|0)<<8|(d[l+b|0]|0))<<16;q=n}else{n=gj[c[m+196768+(l<<2)>>2]&4095](e)|0;p=n;q=c[2276056]|0}c[2276084]=p;o=q}c[2276056]=o+4;return}function DY(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if((c[2276038]&24|0)==0){Bl();return}a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a}else{c[2276083]=b;f=c[2276085]&b;b=f&16777212;g=c[2112932]|0;h=c[g+((b>>>10|32768)<<2)>>2]|0;if(h>>>0>9){i=f&1020;j=(d[h+(i|3)|0]|0)<<8|(d[h+(i|2)|0]|0)|((d[h+(i|1)|0]|0)<<8|(d[h+i|0]|0))<<16;k=a}else{a=gj[c[g+196768+(h<<2)>>2]&4095](b)|0;j=a;k=c[2276056]|0}c[2276084]=j;e=k}c[2276056]=e+4;return}function DZ(){var a=0;if((c[2276038]&24|0)==0){Bl();return}else{a=c[2276056]|0;xw(a)|0;c[2276056]=(c[2276056]|0)+2;return}}function D_(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0);f=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;g=c[2276085]&f;m=g&16777215;b=c[2112932]|0;e=c[b+(m>>>10<<2)>>2]|0;if(e>>>0>9){n=a[e+(g&1023^1)|0]|0}else{n=gj[c[b+196608+(e<<2)>>2]&4095](m)|0}m=n&255;n=9104156+((l&7)<<2)|0;e=m-(c[n>>2]&255)|0;c[2276075]=e;b=e&255;c[2276076]=b;c[2276077]=(e^m)&(c[n>>2]^m);c[2276078]=e;if((b|0)!=0){c[n>>2]=c[n>>2]&-256|m;return}c[2276108]=(c[2276108]|0)-3;m=c[2276085]&f;f=c[9104156+((l>>>6&7)<<2)>>2]&255;l=m&16777215;n=c[2112932]|0;b=c[n+((l>>>10|16384)<<2)>>2]|0;if(b>>>0>9){a[b+(m&1023^1)|0]=f;return}else{gg[c[n+196648+(b<<2)>>2]&4095](l,f);return}}function D$(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0);f=9104156+((c[2276069]&7|8)<<2)|0;g=c[f>>2]|0;c[f>>2]=g+1;f=c[2276085]&g;m=f&16777215;b=c[2112932]|0;e=c[b+(m>>>10<<2)>>2]|0;if(e>>>0>9){n=a[e+(f&1023^1)|0]|0}else{n=gj[c[b+196608+(e<<2)>>2]&4095](m)|0}m=n&255;n=9104156+((l&7)<<2)|0;e=m-(c[n>>2]&255)|0;c[2276075]=e;b=e&255;c[2276076]=b;c[2276077]=(e^m)&(c[n>>2]^m);c[2276078]=e;if((b|0)!=0){c[n>>2]=c[n>>2]&-256|m;return}c[2276108]=(c[2276108]|0)-3;m=c[2276085]&g;g=c[9104156+((l>>>6&7)<<2)>>2]&255;l=m&16777215;n=c[2112932]|0;b=c[n+((l>>>10|16384)<<2)>>2]|0;if(b>>>0>9){a[b+(m&1023^1)|0]=g;return}else{gg[c[n+196648+(b<<2)>>2]&4095](l,g);return}}function D0(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0);f=c[2276054]|0;c[2276054]=f+2;g=c[2276085]&f;m=g&16777215;b=c[2112932]|0;e=c[b+(m>>>10<<2)>>2]|0;if(e>>>0>9){n=a[e+(g&1023^1)|0]|0}else{n=gj[c[b+196608+(e<<2)>>2]&4095](m)|0}m=n&255;n=9104156+((l&7)<<2)|0;e=m-(c[n>>2]&255)|0;c[2276075]=e;b=e&255;c[2276076]=b;c[2276077]=(e^m)&(c[n>>2]^m);c[2276078]=e;if((b|0)!=0){c[n>>2]=c[n>>2]&-256|m;return}c[2276108]=(c[2276108]|0)-3;m=c[2276085]&f;f=c[9104156+((l>>>6&7)<<2)>>2]&255;l=m&16777215;n=c[2112932]|0;b=c[n+((l>>>10|16384)<<2)>>2]|0;if(b>>>0>9){a[b+(m&1023^1)|0]=f;return}else{gg[c[n+196648+(b<<2)>>2]&4095](l,f);return}}function D1(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0);f=9104156+((c[2276069]&7|8)<<2)|0;g=(c[f>>2]|0)-1|0;c[f>>2]=g;f=c[2276085]&g;m=f&16777215;b=c[2112932]|0;e=c[b+(m>>>10<<2)>>2]|0;if(e>>>0>9){n=a[e+(f&1023^1)|0]|0}else{n=gj[c[b+196608+(e<<2)>>2]&4095](m)|0}m=n&255;n=9104156+((l&7)<<2)|0;e=m-(c[n>>2]&255)|0;c[2276075]=e;b=e&255;c[2276076]=b;c[2276077]=(e^m)&(c[n>>2]^m);c[2276078]=e;if((b|0)!=0){c[n>>2]=c[n>>2]&-256|m;return}c[2276108]=(c[2276108]|0)-3;m=c[2276085]&g;g=c[9104156+((l>>>6&7)<<2)>>2]&255;l=m&16777215;n=c[2112932]|0;b=c[n+((l>>>10|16384)<<2)>>2]|0;if(b>>>0>9){a[b+(m&1023^1)|0]=g;return}else{gg[c[n+196648+(b<<2)>>2]&4095](l,g);return}}function D2(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0);f=(c[2276054]|0)-2|0;c[2276054]=f;g=c[2276085]&f;m=g&16777215;b=c[2112932]|0;e=c[b+(m>>>10<<2)>>2]|0;if(e>>>0>9){n=a[e+(g&1023^1)|0]|0}else{n=gj[c[b+196608+(e<<2)>>2]&4095](m)|0}m=n&255;n=9104156+((l&7)<<2)|0;e=m-(c[n>>2]&255)|0;c[2276075]=e;b=e&255;c[2276076]=b;c[2276077]=(e^m)&(c[n>>2]^m);c[2276078]=e;if((b|0)!=0){c[n>>2]=c[n>>2]&-256|m;return}c[2276108]=(c[2276108]|0)-3;m=c[2276085]&f;f=c[9104156+((l>>>6&7)<<2)>>2]&255;l=m&16777215;n=c[2112932]|0;b=c[n+((l>>>10|16384)<<2)>>2]|0;if(b>>>0>9){a[b+(m&1023^1)|0]=f;return}else{gg[c[n+196648+(b<<2)>>2]&4095](l,f);return}}function D3(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0);f=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;o=p&-4;if((o|0)==(h|0)){q=p;r=g}else{c[2276083]=o;g=c[2276085]&o;o=g&16777212;h=c[2112932]|0;e=c[h+((o>>>10|32768)<<2)>>2]|0;if(e>>>0>9){j=g&1020;s=(d[e+(j|3)|0]|0)<<8|(d[e+(j|2)|0]|0)|((d[e+(j|1)|0]|0)<<8|(d[e+j|0]|0))<<16;t=p}else{p=gj[c[h+196768+(e<<2)>>2]&4095](o)|0;s=p;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;s=(r>>>((q<<3&16^16)>>>0)<<16>>16)+f|0;f=s&c[2276085];q=f&16777215;r=c[2112932]|0;t=c[r+(q>>>10<<2)>>2]|0;if(t>>>0>9){u=a[t+(f&1023^1)|0]|0}else{u=gj[c[r+196608+(t<<2)>>2]&4095](q)|0}q=u&255;u=9104156+((n&7)<<2)|0;t=q-(c[u>>2]&255)|0;c[2276075]=t;r=t&255;c[2276076]=r;c[2276077]=(t^q)&(c[u>>2]^q);c[2276078]=t;if((r|0)!=0){c[u>>2]=c[u>>2]&-256|q;return}c[2276108]=(c[2276108]|0)-3;q=c[2276085]&s;s=c[9104156+((n>>>6&7)<<2)>>2]&255;n=q&16777215;u=c[2112932]|0;r=c[u+((n>>>10|16384)<<2)>>2]|0;if(r>>>0>9){a[r+(q&1023^1)|0]=s;return}else{gg[c[u+196648+(r<<2)>>2]&4095](n,s);return}}function D4(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0);f=xw(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;g=c[2276085]&f;m=g&16777215;b=c[2112932]|0;e=c[b+(m>>>10<<2)>>2]|0;if(e>>>0>9){n=a[e+(g&1023^1)|0]|0}else{n=gj[c[b+196608+(e<<2)>>2]&4095](m)|0}m=n&255;n=9104156+((l&7)<<2)|0;e=m-(c[n>>2]&255)|0;c[2276075]=e;b=e&255;c[2276076]=b;c[2276077]=(e^m)&(c[n>>2]^m);c[2276078]=e;if((b|0)!=0){c[n>>2]=c[n>>2]&-256|m;return}c[2276108]=(c[2276108]|0)-3;m=c[2276085]&f;f=c[9104156+((l>>>6&7)<<2)>>2]&255;l=m&16777215;n=c[2112932]|0;b=c[n+((l>>>10|16384)<<2)>>2]|0;if(b>>>0>9){a[b+(m&1023^1)|0]=f;return}else{gg[c[n+196648+(b<<2)>>2]&4095](l,f);return}}function D5(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0);f=p&-4;if((f|0)==(h|0)){q=p;r=g}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;h=c[2112932]|0;o=c[h+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=p}else{p=gj[c[h+196768+(o<<2)>>2]&4095](f)|0;s=p;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;s=r>>>((q<<3&16^16)>>>0)<<16>>16;q=s&c[2276085];r=q&16777215;t=c[2112932]|0;p=c[t+(r>>>10<<2)>>2]|0;if(p>>>0>9){u=a[p+(q&1023^1)|0]|0}else{u=gj[c[t+196608+(p<<2)>>2]&4095](r)|0}r=u&255;u=9104156+((n&7)<<2)|0;p=r-(c[u>>2]&255)|0;c[2276075]=p;t=p&255;c[2276076]=t;c[2276077]=(p^r)&(c[u>>2]^r);c[2276078]=p;if((t|0)!=0){c[u>>2]=c[u>>2]&-256|r;return}c[2276108]=(c[2276108]|0)-3;r=c[2276085]&s;s=c[9104156+((n>>>6&7)<<2)>>2]&255;n=r&16777215;u=c[2112932]|0;t=c[u+((n>>>10|16384)<<2)>>2]|0;if(t>>>0>9){a[t+(r&1023^1)|0]=s;return}else{gg[c[u+196648+(t<<2)>>2]&4095](n,s);return}}function D6(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0);f=p&-4;if((f|0)==(h|0)){q=p;r=h;s=g}else{c[2276083]=f;g=c[2276085]&f;h=g&16777212;o=c[2112932]|0;e=c[o+((h>>>10|32768)<<2)>>2]|0;if(e>>>0>9){j=g&1020;t=(d[e+(j|3)|0]|0)<<8|(d[e+(j|2)|0]|0)|((d[e+(j|1)|0]|0)<<8|(d[e+j|0]|0))<<16;u=p;v=f}else{f=gj[c[o+196768+(e<<2)>>2]&4095](h)|0;t=f;u=c[2276056]|0;v=c[2276083]|0}c[2276084]=t;q=u;r=v;s=t}t=q+2|0;c[2276056]=t;q=t&-4;if((q|0)==(r|0)){w=s;x=t}else{c[2276083]=q;r=c[2276085]&q;q=r&16777212;v=c[2112932]|0;u=c[v+((q>>>10|32768)<<2)>>2]|0;if(u>>>0>9){f=r&1020;y=(d[u+(f|3)|0]|0)<<8|(d[u+(f|2)|0]|0)|((d[u+(f|1)|0]|0)<<8|(d[u+f|0]|0))<<16;z=t}else{t=gj[c[v+196768+(u<<2)>>2]&4095](q)|0;y=t;z=c[2276056]|0}c[2276084]=y;w=y>>>16|s<<16;x=z}c[2276056]=x+2;x=c[2276085]&w;z=x&16777215;s=c[2112932]|0;y=c[s+(z>>>10<<2)>>2]|0;if(y>>>0>9){A=a[y+(x&1023^1)|0]|0}else{A=gj[c[s+196608+(y<<2)>>2]&4095](z)|0}z=A&255;A=9104156+((n&7)<<2)|0;y=z-(c[A>>2]&255)|0;c[2276075]=y;s=y&255;c[2276076]=s;c[2276077]=(y^z)&(c[A>>2]^z);c[2276078]=y;if((s|0)!=0){c[A>>2]=c[A>>2]&-256|z;return}c[2276108]=(c[2276108]|0)-3;z=c[2276085]&w;w=c[9104156+((n>>>6&7)<<2)>>2]&255;n=z&16777215;A=c[2112932]|0;s=c[A+((n>>>10|16384)<<2)>>2]|0;if(s>>>0>9){a[s+(z&1023^1)|0]=w;return}else{gg[c[A+196648+(s<<2)>>2]&4095](n,w);return}}function D7(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0);f=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;g=c[2276085]&f;m=g&16777215;b=c[2112932]|0;e=c[b+(m>>>10<<2)>>2]|0;if(e>>>0>9){j=g&1023;n=(d[e+(j+1)|0]|0)<<8|(d[e+j|0]|0)}else{n=gj[c[b+196688+(e<<2)>>2]&4095](m)|0}m=n&65535;n=9104156+((l&7)<<2)|0;e=m-(c[n>>2]&65535)|0;b=e>>>8;c[2276075]=b;j=e&65535;c[2276076]=j;c[2276077]=((e^m)&(c[n>>2]^m))>>>8;c[2276078]=b;if((j|0)!=0){c[n>>2]=c[n>>2]&-65536|m;return}c[2276108]=(c[2276108]|0)-3;m=c[9104156+((l>>>6&7)<<2)>>2]|0;l=c[2276085]&f;f=m&65535;n=l&16777215;j=c[2112932]|0;b=c[j+((n>>>10|16384)<<2)>>2]|0;if(b>>>0>9){e=l&1023;a[b+e|0]=m&255;a[b+(e+1)|0]=(f&65535)>>>8&255;return}else{gg[c[j+196728+(b<<2)>>2]&4095](n,f);return}}function D8(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0);f=9104156+((c[2276069]&7|8)<<2)|0;g=c[f>>2]|0;c[f>>2]=g+2;f=c[2276085]&g;m=f&16777215;b=c[2112932]|0;e=c[b+(m>>>10<<2)>>2]|0;if(e>>>0>9){j=f&1023;n=(d[e+(j+1)|0]|0)<<8|(d[e+j|0]|0)}else{n=gj[c[b+196688+(e<<2)>>2]&4095](m)|0}m=n&65535;n=9104156+((l&7)<<2)|0;e=m-(c[n>>2]&65535)|0;b=e>>>8;c[2276075]=b;j=e&65535;c[2276076]=j;c[2276077]=((e^m)&(c[n>>2]^m))>>>8;c[2276078]=b;if((j|0)!=0){c[n>>2]=c[n>>2]&-65536|m;return}c[2276108]=(c[2276108]|0)-3;m=c[9104156+((l>>>6&7)<<2)>>2]|0;l=c[2276085]&g;g=m&65535;n=l&16777215;j=c[2112932]|0;b=c[j+((n>>>10|16384)<<2)>>2]|0;if(b>>>0>9){e=l&1023;a[b+e|0]=m&255;a[b+(e+1)|0]=(g&65535)>>>8&255;return}else{gg[c[j+196728+(b<<2)>>2]&4095](n,g);return}}function D9(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0);f=9104156+((c[2276069]&7|8)<<2)|0;g=(c[f>>2]|0)-2|0;c[f>>2]=g;f=c[2276085]&g;m=f&16777215;b=c[2112932]|0;e=c[b+(m>>>10<<2)>>2]|0;if(e>>>0>9){j=f&1023;n=(d[e+(j+1)|0]|0)<<8|(d[e+j|0]|0)}else{n=gj[c[b+196688+(e<<2)>>2]&4095](m)|0}m=n&65535;n=9104156+((l&7)<<2)|0;e=m-(c[n>>2]&65535)|0;b=e>>>8;c[2276075]=b;j=e&65535;c[2276076]=j;c[2276077]=((e^m)&(c[n>>2]^m))>>>8;c[2276078]=b;if((j|0)!=0){c[n>>2]=c[n>>2]&-65536|m;return}c[2276108]=(c[2276108]|0)-3;m=c[9104156+((l>>>6&7)<<2)>>2]|0;l=c[2276085]&g;g=m&65535;n=l&16777215;j=c[2112932]|0;b=c[j+((n>>>10|16384)<<2)>>2]|0;if(b>>>0>9){e=l&1023;a[b+e|0]=m&255;a[b+(e+1)|0]=(g&65535)>>>8&255;return}else{gg[c[j+196728+(b<<2)>>2]&4095](n,g);return}}function Ea(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0);f=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;o=p&-4;if((o|0)==(h|0)){q=p;r=g}else{c[2276083]=o;g=c[2276085]&o;o=g&16777212;h=c[2112932]|0;e=c[h+((o>>>10|32768)<<2)>>2]|0;if(e>>>0>9){j=g&1020;s=(d[e+(j|3)|0]|0)<<8|(d[e+(j|2)|0]|0)|((d[e+(j|1)|0]|0)<<8|(d[e+j|0]|0))<<16;t=p}else{p=gj[c[h+196768+(e<<2)>>2]&4095](o)|0;s=p;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;s=(r>>>((q<<3&16^16)>>>0)<<16>>16)+f|0;f=s&c[2276085];q=f&16777215;r=c[2112932]|0;t=c[r+(q>>>10<<2)>>2]|0;if(t>>>0>9){p=f&1023;u=(d[t+(p+1)|0]|0)<<8|(d[t+p|0]|0)}else{u=gj[c[r+196688+(t<<2)>>2]&4095](q)|0}q=u&65535;u=9104156+((n&7)<<2)|0;t=q-(c[u>>2]&65535)|0;r=t>>>8;c[2276075]=r;p=t&65535;c[2276076]=p;c[2276077]=((t^q)&(c[u>>2]^q))>>>8;c[2276078]=r;if((p|0)!=0){c[u>>2]=c[u>>2]&-65536|q;return}c[2276108]=(c[2276108]|0)-3;q=c[9104156+((n>>>6&7)<<2)>>2]|0;n=c[2276085]&s;s=q&65535;u=n&16777215;p=c[2112932]|0;r=c[p+((u>>>10|16384)<<2)>>2]|0;if(r>>>0>9){t=n&1023;a[r+t|0]=q&255;a[r+(t+1)|0]=(s&65535)>>>8&255;return}else{gg[c[p+196728+(r<<2)>>2]&4095](u,s);return}}function Eb(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0);f=xw(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;g=c[2276085]&f;m=g&16777215;b=c[2112932]|0;e=c[b+(m>>>10<<2)>>2]|0;if(e>>>0>9){j=g&1023;n=(d[e+(j+1)|0]|0)<<8|(d[e+j|0]|0)}else{n=gj[c[b+196688+(e<<2)>>2]&4095](m)|0}m=n&65535;n=9104156+((l&7)<<2)|0;e=m-(c[n>>2]&65535)|0;b=e>>>8;c[2276075]=b;j=e&65535;c[2276076]=j;c[2276077]=((e^m)&(c[n>>2]^m))>>>8;c[2276078]=b;if((j|0)!=0){c[n>>2]=c[n>>2]&-65536|m;return}c[2276108]=(c[2276108]|0)-3;m=c[9104156+((l>>>6&7)<<2)>>2]|0;l=c[2276085]&f;f=m&65535;n=l&16777215;j=c[2112932]|0;b=c[j+((n>>>10|16384)<<2)>>2]|0;if(b>>>0>9){e=l&1023;a[b+e|0]=m&255;a[b+(e+1)|0]=(f&65535)>>>8&255;return}else{gg[c[j+196728+(b<<2)>>2]&4095](n,f);return}}function Ec(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0);f=p&-4;if((f|0)==(h|0)){q=p;r=g}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;h=c[2112932]|0;o=c[h+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=p}else{p=gj[c[h+196768+(o<<2)>>2]&4095](f)|0;s=p;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;s=r>>>((q<<3&16^16)>>>0)<<16>>16;q=s&c[2276085];r=q&16777215;t=c[2112932]|0;p=c[t+(r>>>10<<2)>>2]|0;if(p>>>0>9){f=q&1023;u=(d[p+(f+1)|0]|0)<<8|(d[p+f|0]|0)}else{u=gj[c[t+196688+(p<<2)>>2]&4095](r)|0}r=u&65535;u=9104156+((n&7)<<2)|0;p=r-(c[u>>2]&65535)|0;t=p>>>8;c[2276075]=t;f=p&65535;c[2276076]=f;c[2276077]=((p^r)&(c[u>>2]^r))>>>8;c[2276078]=t;if((f|0)!=0){c[u>>2]=c[u>>2]&-65536|r;return}c[2276108]=(c[2276108]|0)-3;r=c[9104156+((n>>>6&7)<<2)>>2]|0;n=c[2276085]&s;s=r&65535;u=n&16777215;f=c[2112932]|0;t=c[f+((u>>>10|16384)<<2)>>2]|0;if(t>>>0>9){p=n&1023;a[t+p|0]=r&255;a[t+(p+1)|0]=(s&65535)>>>8&255;return}else{gg[c[f+196728+(t<<2)>>2]&4095](u,s);return}}function Ed(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0);f=p&-4;if((f|0)==(h|0)){q=p;r=h;s=g}else{c[2276083]=f;g=c[2276085]&f;h=g&16777212;o=c[2112932]|0;e=c[o+((h>>>10|32768)<<2)>>2]|0;if(e>>>0>9){j=g&1020;t=(d[e+(j|3)|0]|0)<<8|(d[e+(j|2)|0]|0)|((d[e+(j|1)|0]|0)<<8|(d[e+j|0]|0))<<16;u=p;v=f}else{f=gj[c[o+196768+(e<<2)>>2]&4095](h)|0;t=f;u=c[2276056]|0;v=c[2276083]|0}c[2276084]=t;q=u;r=v;s=t}t=q+2|0;c[2276056]=t;q=t&-4;if((q|0)==(r|0)){w=s;x=t}else{c[2276083]=q;r=c[2276085]&q;q=r&16777212;v=c[2112932]|0;u=c[v+((q>>>10|32768)<<2)>>2]|0;if(u>>>0>9){f=r&1020;y=(d[u+(f|3)|0]|0)<<8|(d[u+(f|2)|0]|0)|((d[u+(f|1)|0]|0)<<8|(d[u+f|0]|0))<<16;z=t}else{t=gj[c[v+196768+(u<<2)>>2]&4095](q)|0;y=t;z=c[2276056]|0}c[2276084]=y;w=y>>>16|s<<16;x=z}c[2276056]=x+2;x=c[2276085]&w;z=x&16777215;s=c[2112932]|0;y=c[s+(z>>>10<<2)>>2]|0;if(y>>>0>9){t=x&1023;A=(d[y+(t+1)|0]|0)<<8|(d[y+t|0]|0)}else{A=gj[c[s+196688+(y<<2)>>2]&4095](z)|0}z=A&65535;A=9104156+((n&7)<<2)|0;y=z-(c[A>>2]&65535)|0;s=y>>>8;c[2276075]=s;t=y&65535;c[2276076]=t;c[2276077]=((y^z)&(c[A>>2]^z))>>>8;c[2276078]=s;if((t|0)!=0){c[A>>2]=c[A>>2]&-65536|z;return}c[2276108]=(c[2276108]|0)-3;z=c[9104156+((n>>>6&7)<<2)>>2]|0;n=c[2276085]&w;w=z&65535;A=n&16777215;t=c[2112932]|0;s=c[t+((A>>>10|16384)<<2)>>2]|0;if(s>>>0>9){y=n&1023;a[s+y|0]=z&255;a[s+(y+1)|0]=(w&65535)>>>8&255;return}else{gg[c[t+196728+(s<<2)>>2]&4095](A,w);return}}function Ee(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0);f=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;g=c[2276085]&f;m=g&16777215;b=c[2112932]|0;e=c[b+(m>>>10<<2)>>2]|0;if(e>>>0>9){j=g&1023;n=(d[e+(j+3)|0]|0)<<8|(d[e+(j+2)|0]|0)|((d[e+(j+1)|0]|0)<<8|(d[e+j|0]|0))<<16}else{n=gj[c[b+196768+(e<<2)>>2]&4095](m)|0}m=9104156+((l&7)<<2)|0;e=c[m>>2]|0;b=n-e|0;c[2276075]=b>>>24;c[2276076]=b;c[2276077]=((c[m>>2]^n)&(b^n))>>>24;j=c[m>>2]|0;c[2276078]=((j|b)&(n^-8388608)|j&b)>>>23;if((n|0)!=(e|0)){c[m>>2]=n;return}c[2276108]=(c[2276108]|0)-3;n=c[9104156+((l>>>6&7)<<2)>>2]|0;l=c[2276085]&f;f=l&16777215;m=c[2112932]|0;e=c[m+((f>>>10|16384)<<2)>>2]|0;if(e>>>0>9){b=l&1023;a[e+b|0]=n>>>16&255;a[e+(b+1)|0]=n>>>24&255;a[e+(b+2)|0]=n&255;a[e+(b+3)|0]=n>>>8&255;return}else{gg[c[m+196808+(e<<2)>>2]&4095](f,n);return}}function Ef(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0);f=9104156+((c[2276069]&7|8)<<2)|0;g=c[f>>2]|0;c[f>>2]=g+4;f=c[2276085]&g;m=f&16777215;b=c[2112932]|0;e=c[b+(m>>>10<<2)>>2]|0;if(e>>>0>9){j=f&1023;n=(d[e+(j+3)|0]|0)<<8|(d[e+(j+2)|0]|0)|((d[e+(j+1)|0]|0)<<8|(d[e+j|0]|0))<<16}else{n=gj[c[b+196768+(e<<2)>>2]&4095](m)|0}m=9104156+((l&7)<<2)|0;e=c[m>>2]|0;b=n-e|0;c[2276075]=b>>>24;c[2276076]=b;c[2276077]=((c[m>>2]^n)&(b^n))>>>24;j=c[m>>2]|0;c[2276078]=((j|b)&(n^-8388608)|j&b)>>>23;if((n|0)!=(e|0)){c[m>>2]=n;return}c[2276108]=(c[2276108]|0)-3;n=c[9104156+((l>>>6&7)<<2)>>2]|0;l=c[2276085]&g;g=l&16777215;m=c[2112932]|0;e=c[m+((g>>>10|16384)<<2)>>2]|0;if(e>>>0>9){b=l&1023;a[e+b|0]=n>>>16&255;a[e+(b+1)|0]=n>>>24&255;a[e+(b+2)|0]=n&255;a[e+(b+3)|0]=n>>>8&255;return}else{gg[c[m+196808+(e<<2)>>2]&4095](g,n);return}}function Eg(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0);f=9104156+((c[2276069]&7|8)<<2)|0;g=(c[f>>2]|0)-4|0;c[f>>2]=g;f=c[2276085]&g;m=f&16777215;b=c[2112932]|0;e=c[b+(m>>>10<<2)>>2]|0;if(e>>>0>9){j=f&1023;n=(d[e+(j+3)|0]|0)<<8|(d[e+(j+2)|0]|0)|((d[e+(j+1)|0]|0)<<8|(d[e+j|0]|0))<<16}else{n=gj[c[b+196768+(e<<2)>>2]&4095](m)|0}m=9104156+((l&7)<<2)|0;e=c[m>>2]|0;b=n-e|0;c[2276075]=b>>>24;c[2276076]=b;c[2276077]=((c[m>>2]^n)&(b^n))>>>24;j=c[m>>2]|0;c[2276078]=((j|b)&(n^-8388608)|j&b)>>>23;if((n|0)!=(e|0)){c[m>>2]=n;return}c[2276108]=(c[2276108]|0)-3;n=c[9104156+((l>>>6&7)<<2)>>2]|0;l=c[2276085]&g;g=l&16777215;m=c[2112932]|0;e=c[m+((g>>>10|16384)<<2)>>2]|0;if(e>>>0>9){b=l&1023;a[e+b|0]=n>>>16&255;a[e+(b+1)|0]=n>>>24&255;a[e+(b+2)|0]=n&255;a[e+(b+3)|0]=n>>>8&255;return}else{gg[c[m+196808+(e<<2)>>2]&4095](g,n);return}}function Eh(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0);f=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;o=p&-4;if((o|0)==(h|0)){q=p;r=g}else{c[2276083]=o;g=c[2276085]&o;o=g&16777212;h=c[2112932]|0;e=c[h+((o>>>10|32768)<<2)>>2]|0;if(e>>>0>9){j=g&1020;s=(d[e+(j|3)|0]|0)<<8|(d[e+(j|2)|0]|0)|((d[e+(j|1)|0]|0)<<8|(d[e+j|0]|0))<<16;t=p}else{p=gj[c[h+196768+(e<<2)>>2]&4095](o)|0;s=p;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;s=(r>>>((q<<3&16^16)>>>0)<<16>>16)+f|0;f=s&c[2276085];q=f&16777215;r=c[2112932]|0;t=c[r+(q>>>10<<2)>>2]|0;if(t>>>0>9){p=f&1023;u=(d[t+(p+3)|0]|0)<<8|(d[t+(p+2)|0]|0)|((d[t+(p+1)|0]|0)<<8|(d[t+p|0]|0))<<16}else{u=gj[c[r+196768+(t<<2)>>2]&4095](q)|0}q=9104156+((n&7)<<2)|0;t=c[q>>2]|0;r=u-t|0;c[2276075]=r>>>24;c[2276076]=r;c[2276077]=((c[q>>2]^u)&(r^u))>>>24;p=c[q>>2]|0;c[2276078]=((p|r)&(u^-8388608)|p&r)>>>23;if((u|0)!=(t|0)){c[q>>2]=u;return}c[2276108]=(c[2276108]|0)-3;u=c[9104156+((n>>>6&7)<<2)>>2]|0;n=c[2276085]&s;s=n&16777215;q=c[2112932]|0;t=c[q+((s>>>10|16384)<<2)>>2]|0;if(t>>>0>9){r=n&1023;a[t+r|0]=u>>>16&255;a[t+(r+1)|0]=u>>>24&255;a[t+(r+2)|0]=u&255;a[t+(r+3)|0]=u>>>8&255;return}else{gg[c[q+196808+(t<<2)>>2]&4095](s,u);return}}function Ei(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0);f=xw(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;g=c[2276085]&f;m=g&16777215;b=c[2112932]|0;e=c[b+(m>>>10<<2)>>2]|0;if(e>>>0>9){j=g&1023;n=(d[e+(j+3)|0]|0)<<8|(d[e+(j+2)|0]|0)|((d[e+(j+1)|0]|0)<<8|(d[e+j|0]|0))<<16}else{n=gj[c[b+196768+(e<<2)>>2]&4095](m)|0}m=9104156+((l&7)<<2)|0;e=c[m>>2]|0;b=n-e|0;c[2276075]=b>>>24;c[2276076]=b;c[2276077]=((c[m>>2]^n)&(b^n))>>>24;j=c[m>>2]|0;c[2276078]=((j|b)&(n^-8388608)|j&b)>>>23;if((n|0)!=(e|0)){c[m>>2]=n;return}c[2276108]=(c[2276108]|0)-3;n=c[9104156+((l>>>6&7)<<2)>>2]|0;l=c[2276085]&f;f=l&16777215;m=c[2112932]|0;e=c[m+((f>>>10|16384)<<2)>>2]|0;if(e>>>0>9){b=l&1023;a[e+b|0]=n>>>16&255;a[e+(b+1)|0]=n>>>24&255;a[e+(b+2)|0]=n&255;a[e+(b+3)|0]=n>>>8&255;return}else{gg[c[m+196808+(e<<2)>>2]&4095](f,n);return}}function Ej(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0);f=p&-4;if((f|0)==(h|0)){q=p;r=g}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;h=c[2112932]|0;o=c[h+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=p}else{p=gj[c[h+196768+(o<<2)>>2]&4095](f)|0;s=p;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;s=r>>>((q<<3&16^16)>>>0)<<16>>16;q=s&c[2276085];r=q&16777215;t=c[2112932]|0;p=c[t+(r>>>10<<2)>>2]|0;if(p>>>0>9){f=q&1023;u=(d[p+(f+3)|0]|0)<<8|(d[p+(f+2)|0]|0)|((d[p+(f+1)|0]|0)<<8|(d[p+f|0]|0))<<16}else{u=gj[c[t+196768+(p<<2)>>2]&4095](r)|0}r=9104156+((n&7)<<2)|0;p=c[r>>2]|0;t=u-p|0;c[2276075]=t>>>24;c[2276076]=t;c[2276077]=((c[r>>2]^u)&(t^u))>>>24;f=c[r>>2]|0;c[2276078]=((f|t)&(u^-8388608)|f&t)>>>23;if((u|0)!=(p|0)){c[r>>2]=u;return}c[2276108]=(c[2276108]|0)-3;u=c[9104156+((n>>>6&7)<<2)>>2]|0;n=c[2276085]&s;s=n&16777215;r=c[2112932]|0;p=c[r+((s>>>10|16384)<<2)>>2]|0;if(p>>>0>9){t=n&1023;a[p+t|0]=u>>>16&255;a[p+(t+1)|0]=u>>>24&255;a[p+(t+2)|0]=u&255;a[p+(t+3)|0]=u>>>8&255;return}else{gg[c[r+196808+(p<<2)>>2]&4095](s,u);return}}function Ek(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0);f=p&-4;if((f|0)==(h|0)){q=p;r=h;s=g}else{c[2276083]=f;g=c[2276085]&f;h=g&16777212;o=c[2112932]|0;e=c[o+((h>>>10|32768)<<2)>>2]|0;if(e>>>0>9){j=g&1020;t=(d[e+(j|3)|0]|0)<<8|(d[e+(j|2)|0]|0)|((d[e+(j|1)|0]|0)<<8|(d[e+j|0]|0))<<16;u=p;v=f}else{f=gj[c[o+196768+(e<<2)>>2]&4095](h)|0;t=f;u=c[2276056]|0;v=c[2276083]|0}c[2276084]=t;q=u;r=v;s=t}t=q+2|0;c[2276056]=t;q=t&-4;if((q|0)==(r|0)){w=s;x=t}else{c[2276083]=q;r=c[2276085]&q;q=r&16777212;v=c[2112932]|0;u=c[v+((q>>>10|32768)<<2)>>2]|0;if(u>>>0>9){f=r&1020;y=(d[u+(f|3)|0]|0)<<8|(d[u+(f|2)|0]|0)|((d[u+(f|1)|0]|0)<<8|(d[u+f|0]|0))<<16;z=t}else{t=gj[c[v+196768+(u<<2)>>2]&4095](q)|0;y=t;z=c[2276056]|0}c[2276084]=y;w=y>>>16|s<<16;x=z}c[2276056]=x+2;x=c[2276085]&w;z=x&16777215;s=c[2112932]|0;y=c[s+(z>>>10<<2)>>2]|0;if(y>>>0>9){t=x&1023;A=(d[y+(t+3)|0]|0)<<8|(d[y+(t+2)|0]|0)|((d[y+(t+1)|0]|0)<<8|(d[y+t|0]|0))<<16}else{A=gj[c[s+196768+(y<<2)>>2]&4095](z)|0}z=9104156+((n&7)<<2)|0;y=c[z>>2]|0;s=A-y|0;c[2276075]=s>>>24;c[2276076]=s;c[2276077]=((c[z>>2]^A)&(s^A))>>>24;t=c[z>>2]|0;c[2276078]=((t|s)&(A^-8388608)|t&s)>>>23;if((A|0)!=(y|0)){c[z>>2]=A;return}c[2276108]=(c[2276108]|0)-3;A=c[9104156+((n>>>6&7)<<2)>>2]|0;n=c[2276085]&w;w=n&16777215;z=c[2112932]|0;y=c[z+((w>>>10|16384)<<2)>>2]|0;if(y>>>0>9){s=n&1023;a[y+s|0]=A>>>16&255;a[y+(s+1)|0]=A>>>24&255;a[y+(s+2)|0]=A&255;a[y+(s+3)|0]=A>>>8&255;return}else{gg[c[z+196808+(y<<2)>>2]&4095](w,A);return}}function El(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=9104156+((q>>>16&7)<<2)|0;t=c[9104156+(q>>>28<<2)>>2]|0;h=c[2276085]|0;s=h&t;n=s&16777215;f=c[2112932]|0;o=c[f+(n>>>10<<2)>>2]|0;if(o>>>0>9){p=s&1023;u=(d[o+(p+1)|0]|0)<<8|(d[o+p|0]|0);v=h;w=f}else{h=gj[c[f+196688+(o<<2)>>2]&4095](n)|0;u=h;v=c[2276085]|0;w=c[2112932]|0}h=u&65535;n=h-(c[r>>2]&65535)|0;o=9104156+((q&7)<<2)|0;f=c[9104156+((q>>>12&15)<<2)>>2]|0;p=v&f;v=p&16777215;s=c[w+(v>>>10<<2)>>2]|0;if(s>>>0>9){e=p&1023;x=(d[s+(e+1)|0]|0)<<8|(d[s+e|0]|0)}else{x=gj[c[w+196688+(s<<2)>>2]&4095](v)|0}v=x&65535;s=n>>>8;c[2276075]=s;w=n&65535;c[2276076]=w;c[2276077]=((c[r>>2]^h)&(n^h))>>>8;c[2276078]=s;do{if((w|0)==0){s=v-(c[o>>2]&65535)|0;n=s>>>8;c[2276075]=n;e=s&65535;c[2276076]=e;c[2276077]=((s^v)&(c[o>>2]^v))>>>8;c[2276078]=n;if((e|0)!=0){break}c[2276108]=(c[2276108]|0)-3;e=c[9104156+((q>>>22&7)<<2)>>2]|0;n=c[2276085]&t;s=e&65535;p=n&16777215;g=c[2112932]|0;j=c[g+((p>>>10|16384)<<2)>>2]|0;if(j>>>0>9){l=n&1023;a[j+l|0]=e&255;a[j+(l+1)|0]=(s&65535)>>>8&255;y=g}else{gg[c[g+196728+(j<<2)>>2]&4095](p,s);y=c[2112932]|0}s=c[9104156+((q>>>6&7)<<2)>>2]|0;p=c[2276085]&f;j=s&65535;g=p&16777215;l=c[y+((g>>>10|16384)<<2)>>2]|0;if(l>>>0>9){e=p&1023;a[l+e|0]=s&255;a[l+(e+1)|0]=(j&65535)>>>8&255;return}else{gg[c[y+196728+(l<<2)>>2]&4095](g,j);return}}}while(0);if((q|0)<0){z=u<<16>>16}else{z=c[r>>2]&-65536|h}c[r>>2]=z;if((q&32768|0)==0){A=c[o>>2]&-65536|v}else{A=x<<16>>16}c[o>>2]=A;return}function Em(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=9104156+((q>>>16&7)<<2)|0;t=c[9104156+(q>>>28<<2)>>2]|0;h=c[2276085]|0;s=h&t;n=s&16777215;f=c[2112932]|0;o=c[f+(n>>>10<<2)>>2]|0;if(o>>>0>9){p=s&1023;u=(d[o+(p+3)|0]|0)<<8|(d[o+(p+2)|0]|0)|((d[o+(p+1)|0]|0)<<8|(d[o+p|0]|0))<<16;v=h;w=f}else{h=gj[c[f+196768+(o<<2)>>2]&4095](n)|0;u=h;v=c[2276085]|0;w=c[2112932]|0}h=c[r>>2]|0;n=u-h|0;o=9104156+((q&7)<<2)|0;f=c[9104156+((q>>>12&15)<<2)>>2]|0;p=v&f;v=p&16777215;s=c[w+(v>>>10<<2)>>2]|0;if(s>>>0>9){e=p&1023;x=(d[s+(e+3)|0]|0)<<8|(d[s+(e+2)|0]|0)|((d[s+(e+1)|0]|0)<<8|(d[s+e|0]|0))<<16}else{x=gj[c[w+196768+(s<<2)>>2]&4095](v)|0}c[2276075]=n>>>24;c[2276076]=n;c[2276077]=((c[r>>2]^u)&(n^u))>>>24;v=c[r>>2]|0;c[2276078]=((v|n)&(u^-8388608)|v&n)>>>23;do{if((u|0)==(h|0)){n=c[o>>2]|0;v=x-n|0;c[2276075]=v>>>24;c[2276076]=v;c[2276077]=((c[o>>2]^x)&(v^x))>>>24;s=c[o>>2]|0;c[2276078]=((s|v)&(x^-8388608)|s&v)>>>23;if((x|0)!=(n|0)){break}c[2276108]=(c[2276108]|0)-3;n=c[9104156+((q>>>22&7)<<2)>>2]|0;v=c[2276085]&t;s=v&16777215;w=c[2112932]|0;e=c[w+((s>>>10|16384)<<2)>>2]|0;if(e>>>0>9){p=v&1023;a[e+p|0]=n>>>16&255;a[e+(p+1)|0]=n>>>24&255;a[e+(p+2)|0]=n&255;a[e+(p+3)|0]=n>>>8&255;y=w}else{gg[c[w+196808+(e<<2)>>2]&4095](s,n);y=c[2112932]|0}n=c[9104156+((q>>>6&7)<<2)>>2]|0;s=c[2276085]&f;e=s&16777215;w=c[y+((e>>>10|16384)<<2)>>2]|0;if(w>>>0>9){p=s&1023;a[w+p|0]=n>>>16&255;a[w+(p+1)|0]=n>>>24&255;a[w+(p+2)|0]=n&255;a[w+(p+3)|0]=n>>>8&255;return}else{gg[c[y+196808+(w<<2)>>2]&4095](e,n);return}}}while(0);c[r>>2]=u;c[o>>2]=x;return}function En(){var a=0,b=0,d=0,e=0,f=0;a=c[2276069]|0;b=c[9104156+((a>>>9&7)<<2)>>2]|0;d=b<<16;e=d>>16;f=c[9104156+((a&7)<<2)>>2]|0;c[2276076]=e&65535;c[2276077]=0;c[2276078]=0;do{if((d|0)>-65536){if((e|0)>(f<<16>>16|0)){break}return}}while(0);c[2276075]=b>>>15<<7&128;Eo();return}function Eo(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;b=c[2276072]|0;e=c[2276073]|0;f=c[2276071]|c[2276070]|b<<11|e<<11|c[2276079]|(c[2276074]|0)>>>4&16|(c[2276075]|0)>>>4&8|((c[2276076]|0)==0)<<2|(c[2276077]|0)>>>6&2|(c[2276078]|0)>>>8&1;c[2276071]=0;c[2276070]=0;c[9104228+((b>>>1&e|b)<<2)>>2]=c[2276054];c[2276072]=4;b=c[9104228+((c[2276073]&2|4)<<2)>>2]|0;c[2276054]=b;e=c[2276038]|0;do{if((e&7|0)==0){g=c[2276055]|0;h=b-4|0;c[2276054]=h;i=c[2276085]&h;h=i&16777215;j=c[2112932]|0;k=c[j+((h>>>10|16384)<<2)>>2]|0;if(k>>>0>9){l=i&1023;a[k+l|0]=g>>>16&255;a[k+(l+1)|0]=g>>>24&255;a[k+(l+2)|0]=g&255;a[k+(l+3)|0]=g>>>8&255;m=j}else{gg[c[j+196808+(k<<2)>>2]&4095](h,g);m=c[2112932]|0}g=(c[2276054]|0)-2|0;c[2276054]=g;h=c[2276085]&g;g=h&16777215;k=c[m+((g>>>10|16384)<<2)>>2]|0;if(k>>>0>9){j=h&1023;a[k+j|0]=24;a[k+(j+1)|0]=32;n=m}else{gg[c[m+196728+(k<<2)>>2]&4095](g,8216);n=c[2112932]|0}g=c[2276056]|0;k=(c[2276054]|0)-4|0;c[2276054]=k;j=c[2276085]&k;k=j&16777215;h=c[n+((k>>>10|16384)<<2)>>2]|0;if(h>>>0>9){l=j&1023;a[h+l|0]=g>>>16&255;a[h+(l+1)|0]=g>>>24&255;a[h+(l+2)|0]=g&255;a[h+(l+3)|0]=g>>>8&255;o=n}else{gg[c[n+196808+(h<<2)>>2]&4095](k,g);o=c[2112932]|0}g=(c[2276054]|0)-2|0;c[2276054]=g;k=c[2276085]&g;g=f&65535;h=k&16777215;l=c[o+((h>>>10|16384)<<2)>>2]|0;if(l>>>0>9){j=k&1023;a[l+j|0]=f&255;a[l+(j+1)|0]=(g&65535)>>>8&255;break}else{gg[c[o+196728+(l<<2)>>2]&4095](h,g);break}}else{g=c[2276056]|0;if((e-1|0)>>>0<2){h=b-4|0;c[2276054]=h;l=c[2276085]&h;h=l&16777215;j=c[2112932]|0;k=c[j+((h>>>10|16384)<<2)>>2]|0;if(k>>>0>9){i=l&1023;a[k+i|0]=g>>>16&255;a[k+(i+1)|0]=g>>>24&255;a[k+(i+2)|0]=g&255;a[k+(i+3)|0]=g>>>8&255;p=j}else{gg[c[j+196808+(k<<2)>>2]&4095](h,g);p=c[2112932]|0}h=(c[2276054]|0)-2|0;c[2276054]=h;k=c[2276085]&h;h=f&65535;j=k&16777215;i=c[p+((j>>>10|16384)<<2)>>2]|0;if(i>>>0>9){l=k&1023;a[i+l|0]=f&255;a[i+(l+1)|0]=(h&65535)>>>8&255;break}else{gg[c[p+196728+(i<<2)>>2]&4095](j,h);break}}h=b-2|0;c[2276054]=h;j=c[2276085]&h;h=j&16777215;i=c[2112932]|0;l=c[i+((h>>>10|16384)<<2)>>2]|0;if(l>>>0>9){k=j&1023;a[l+k|0]=24;a[l+(k+1)|0]=0;q=i}else{gg[c[i+196728+(l<<2)>>2]&4095](h,24);q=c[2112932]|0}h=(c[2276054]|0)-4|0;c[2276054]=h;l=c[2276085]&h;h=l&16777215;i=c[q+((h>>>10|16384)<<2)>>2]|0;if(i>>>0>9){k=l&1023;a[i+k|0]=g>>>16&255;a[i+(k+1)|0]=g>>>24&255;a[i+(k+2)|0]=g&255;a[i+(k+3)|0]=g>>>8&255;r=q}else{gg[c[q+196808+(i<<2)>>2]&4095](h,g);r=c[2112932]|0}g=(c[2276054]|0)-2|0;c[2276054]=g;h=c[2276085]&g;g=f&65535;i=h&16777215;k=c[r+((i>>>10|16384)<<2)>>2]|0;if(k>>>0>9){l=h&1023;a[k+l|0]=f&255;a[k+(l+1)|0]=(g&65535)>>>8&255;break}else{gg[c[r+196728+(k<<2)>>2]&4095](i,g);break}}}while(0);r=(c[2276064]|0)+24|0;c[2276056]=r;f=c[2276085]&r;r=f&16777215;q=c[2112932]|0;b=c[q+(r>>>10<<2)>>2]|0;if(b>>>0>9){p=f&1023;s=(d[b+(p+3)|0]|0)<<8|(d[b+(p+2)|0]|0)|((d[b+(p+1)|0]|0)<<8|(d[b+p|0]|0))<<16;c[2276056]=s;t=c[2276099]|0;u=t+6|0;v=a[u]|0;w=v&255;x=c[2276108]|0;y=x-w|0;c[2276108]=y;return}else{s=gj[c[q+196768+(b<<2)>>2]&4095](r)|0;c[2276056]=s;t=c[2276099]|0;u=t+6|0;v=a[u]|0;w=v&255;x=c[2276108]|0;y=x-w|0;c[2276108]=y;return}}function Ep(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[2276069]|0;b=c[9104156+((a>>>9&7)<<2)>>2]|0;e=b<<16;f=e>>16;g=c[2276085]&c[9104156+((a&7|8)<<2)>>2];a=g&16777215;h=c[2112932]|0;i=c[h+(a>>>10<<2)>>2]|0;if(i>>>0>9){j=g&1023;k=(d[i+(j+1)|0]|0)<<8|(d[i+j|0]|0)}else{k=gj[c[h+196688+(i<<2)>>2]&4095](a)|0}c[2276076]=f&65535;c[2276077]=0;c[2276078]=0;do{if((e|0)>-65536){if((f|0)>(k<<16>>16|0)){break}return}}while(0);c[2276075]=b>>>15<<7&128;Eo();return}function Eq(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[2276069]|0;b=c[9104156+((a>>>9&7)<<2)>>2]|0;e=b<<16;f=e>>16;g=9104156+((a&7|8)<<2)|0;a=c[g>>2]|0;c[g>>2]=a+2;g=c[2276085]&a;a=g&16777215;h=c[2112932]|0;i=c[h+(a>>>10<<2)>>2]|0;if(i>>>0>9){j=g&1023;k=(d[i+(j+1)|0]|0)<<8|(d[i+j|0]|0)}else{k=gj[c[h+196688+(i<<2)>>2]&4095](a)|0}c[2276076]=f&65535;c[2276077]=0;c[2276078]=0;do{if((e|0)>-65536){if((f|0)>(k<<16>>16|0)){break}return}}while(0);c[2276075]=b>>>15<<7&128;Eo();return}function Er(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[2276069]|0;b=c[9104156+((a>>>9&7)<<2)>>2]|0;e=b<<16;f=e>>16;g=9104156+((a&7|8)<<2)|0;a=(c[g>>2]|0)-2|0;c[g>>2]=a;g=c[2276085]&a;a=g&16777215;h=c[2112932]|0;i=c[h+(a>>>10<<2)>>2]|0;if(i>>>0>9){j=g&1023;k=(d[i+(j+1)|0]|0)<<8|(d[i+j|0]|0)}else{k=gj[c[h+196688+(i<<2)>>2]&4095](a)|0}c[2276076]=f&65535;c[2276077]=0;c[2276078]=0;do{if((e|0)>-65536){if((f|0)>(k<<16>>16|0)){break}return}}while(0);c[2276075]=b>>>15<<7&128;Eo();return}function Es(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;a=c[2276069]|0;b=c[9104156+((a>>>9&7)<<2)>>2]|0;e=b<<16;f=e>>16;g=c[9104156+((a&7|8)<<2)>>2]|0;a=c[2276056]|0;h=a&-4;if((h|0)==(c[2276083]|0)){i=a;j=c[2276084]|0}else{c[2276083]=h;k=c[2276085]&h;h=k&16777212;l=c[2112932]|0;m=c[l+((h>>>10|32768)<<2)>>2]|0;if(m>>>0>9){n=k&1020;o=(d[m+(n|3)|0]|0)<<8|(d[m+(n|2)|0]|0)|((d[m+(n|1)|0]|0)<<8|(d[m+n|0]|0))<<16;p=a}else{a=gj[c[l+196768+(m<<2)>>2]&4095](h)|0;o=a;p=c[2276056]|0}c[2276084]=o;i=p;j=o}c[2276056]=i+2;o=(j>>>((i<<3&16^16)>>>0)<<16>>16)+g&c[2276085];g=o&16777215;i=c[2112932]|0;j=c[i+(g>>>10<<2)>>2]|0;if(j>>>0>9){p=o&1023;q=(d[j+(p+1)|0]|0)<<8|(d[j+p|0]|0)}else{q=gj[c[i+196688+(j<<2)>>2]&4095](g)|0}c[2276076]=f&65535;c[2276077]=0;c[2276078]=0;do{if((e|0)>-65536){if((f|0)>(q<<16>>16|0)){break}return}}while(0);c[2276075]=b>>>15<<7&128;Eo();return}function Et(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[2276069]|0;b=c[9104156+((a>>>9&7)<<2)>>2]|0;e=b<<16;f=e>>16;g=xw(c[9104156+((a&7|8)<<2)>>2]|0)|0;a=c[2276085]&g;g=a&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=a&1023;k=(d[i+(j+1)|0]|0)<<8|(d[i+j|0]|0)}else{k=gj[c[h+196688+(i<<2)>>2]&4095](g)|0}c[2276076]=f&65535;c[2276077]=0;c[2276078]=0;do{if((e|0)>-65536){if((f|0)>(k<<16>>16|0)){break}return}}while(0);c[2276075]=b>>>15<<7&128;Eo();return}function Eu(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;a=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;b=a<<16;e=b>>16;f=c[2276056]|0;g=f&-4;if((g|0)==(c[2276083]|0)){h=f;i=c[2276084]|0}else{c[2276083]=g;j=c[2276085]&g;g=j&16777212;k=c[2112932]|0;l=c[k+((g>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=j&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=f}else{f=gj[c[k+196768+(l<<2)>>2]&4095](g)|0;n=f;o=c[2276056]|0}c[2276084]=n;h=o;i=n}c[2276056]=h+2;n=i>>>((h<<3&16^16)>>>0)<<16>>16&c[2276085];h=n&16777215;i=c[2112932]|0;o=c[i+(h>>>10<<2)>>2]|0;if(o>>>0>9){f=n&1023;p=(d[o+(f+1)|0]|0)<<8|(d[o+f|0]|0)}else{p=gj[c[i+196688+(o<<2)>>2]&4095](h)|0}c[2276076]=e&65535;c[2276077]=0;c[2276078]=0;do{if((b|0)>-65536){if((e|0)>(p<<16>>16|0)){break}return}}while(0);c[2276075]=a>>>15<<7&128;Eo();return}function Ev(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;a=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;b=a<<16;e=b>>16;f=c[2276056]|0;g=f&-4;if((g|0)==(c[2276083]|0)){h=f;i=g;j=c[2276084]|0}else{c[2276083]=g;k=c[2276085]&g;l=k&16777212;m=c[2112932]|0;n=c[m+((l>>>10|32768)<<2)>>2]|0;if(n>>>0>9){o=k&1020;p=(d[n+(o|3)|0]|0)<<8|(d[n+(o|2)|0]|0)|((d[n+(o|1)|0]|0)<<8|(d[n+o|0]|0))<<16;q=f;r=g}else{g=gj[c[m+196768+(n<<2)>>2]&4095](l)|0;p=g;q=c[2276056]|0;r=c[2276083]|0}c[2276084]=p;h=q;i=r;j=p}p=h+2|0;c[2276056]=p;h=p&-4;if((h|0)==(i|0)){s=j;t=p}else{c[2276083]=h;i=c[2276085]&h;h=i&16777212;r=c[2112932]|0;q=c[r+((h>>>10|32768)<<2)>>2]|0;if(q>>>0>9){g=i&1020;u=(d[q+(g|3)|0]|0)<<8|(d[q+(g|2)|0]|0)|((d[q+(g|1)|0]|0)<<8|(d[q+g|0]|0))<<16;v=p}else{p=gj[c[r+196768+(q<<2)>>2]&4095](h)|0;u=p;v=c[2276056]|0}c[2276084]=u;s=u>>>16|j<<16;t=v}c[2276056]=t+2;t=c[2276085]&s;s=t&16777215;v=c[2112932]|0;j=c[v+(s>>>10<<2)>>2]|0;if(j>>>0>9){u=t&1023;w=(d[j+(u+1)|0]|0)<<8|(d[j+u|0]|0)}else{w=gj[c[v+196688+(j<<2)>>2]&4095](s)|0}c[2276076]=e&65535;c[2276077]=0;c[2276078]=0;do{if((b|0)>-65536){if((e|0)>(w<<16>>16|0)){break}return}}while(0);c[2276075]=a>>>15<<7&128;Eo();return}function Ew(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;a=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;b=a<<16;e=b>>16;f=c[2276056]|0;g=f&-4;if((g|0)==(c[2276083]|0)){h=f;i=c[2276084]|0}else{c[2276083]=g;j=c[2276085]&g;g=j&16777212;k=c[2112932]|0;l=c[k+((g>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=j&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=f}else{m=gj[c[k+196768+(l<<2)>>2]&4095](g)|0;n=m;o=c[2276056]|0}c[2276084]=n;h=o;i=n}c[2276056]=h+2;n=(i>>>((h<<3&16^16)>>>0)<<16>>16)+f|0;f=n&16777215;h=c[2112932]|0;i=c[h+((f>>>10|32768)<<2)>>2]|0;if(i>>>0>9){o=n&1023;p=(d[i+(o+1)|0]|0)<<8|(d[i+o|0]|0)}else{p=gj[c[h+196688+(i<<2)>>2]&4095](f)|0}c[2276076]=e&65535;c[2276077]=0;c[2276078]=0;do{if((b|0)>-65536){if((e|0)>(p<<16>>16|0)){break}return}}while(0);c[2276075]=a>>>15<<7&128;Eo();return}function Ex(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;b=a<<16;e=b>>16;f=xw(c[2276056]|0)|0;g=f&16777215;h=c[2112932]|0;i=c[h+((g>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=f&1023;k=(d[i+(j+1)|0]|0)<<8|(d[i+j|0]|0)}else{k=gj[c[h+196688+(i<<2)>>2]&4095](g)|0}c[2276076]=e&65535;c[2276077]=0;c[2276078]=0;do{if((b|0)>-65536){if((e|0)>(k<<16>>16|0)){break}return}}while(0);c[2276075]=a>>>15<<7&128;Eo();return}function Ey(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;b=a<<16;e=b>>16;f=c[2276056]|0;g=f&-4;if((g|0)==(c[2276083]|0)){h=f;i=c[2276084]|0}else{c[2276083]=g;j=c[2276085]&g;g=j&16777212;k=c[2112932]|0;l=c[k+((g>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=j&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=f}else{f=gj[c[k+196768+(l<<2)>>2]&4095](g)|0;n=f;o=c[2276056]|0}c[2276084]=n;h=o;i=n}c[2276056]=h+2;c[2276076]=e&65535;c[2276077]=0;c[2276078]=0;do{if((b|0)>-65536){if((e|0)>(i>>>((h<<3&16^16)>>>0)<<16>>16|0)){break}return}}while(0);c[2276075]=a>>>15<<7&128;Eo();return}function Ez(){var a=0,b=0,d=0;if((c[2276038]&24|0)==0){Bl();return}a=c[2276069]|0;b=c[9104156+((a>>>9&7)<<2)>>2]|0;d=c[9104156+((a&7)<<2)>>2]|0;c[2276076]=b;c[2276077]=0;c[2276078]=0;if(!((b|0)<0|(b|0)>(d|0))){return}c[2276075]=b>>>31<<7;Eo();return}function EA(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0;if((c[2276038]&24|0)==0){Bl();return}a=c[2276069]|0;b=c[9104156+((a>>>9&7)<<2)>>2]|0;e=c[2276085]&c[9104156+((a&7|8)<<2)>>2];a=e&16777215;f=c[2112932]|0;g=c[f+(a>>>10<<2)>>2]|0;if(g>>>0>9){h=e&1023;i=(d[g+(h+3)|0]|0)<<8|(d[g+(h+2)|0]|0)|((d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0))<<16}else{i=gj[c[f+196768+(g<<2)>>2]&4095](a)|0}c[2276076]=b;c[2276077]=0;c[2276078]=0;if(!((b|0)<0|(b|0)>(i|0))){return}c[2276075]=b>>>31<<7;Eo();return}function EB(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0;if((c[2276038]&24|0)==0){Bl();return}a=c[2276069]|0;b=c[9104156+((a>>>9&7)<<2)>>2]|0;e=9104156+((a&7|8)<<2)|0;a=c[e>>2]|0;c[e>>2]=a+4;e=c[2276085]&a;a=e&16777215;f=c[2112932]|0;g=c[f+(a>>>10<<2)>>2]|0;if(g>>>0>9){h=e&1023;i=(d[g+(h+3)|0]|0)<<8|(d[g+(h+2)|0]|0)|((d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0))<<16}else{i=gj[c[f+196768+(g<<2)>>2]&4095](a)|0}c[2276076]=b;c[2276077]=0;c[2276078]=0;if(!((b|0)<0|(b|0)>(i|0))){return}c[2276075]=b>>>31<<7;Eo();return}function EC(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0;if((c[2276038]&24|0)==0){Bl();return}a=c[2276069]|0;b=c[9104156+((a>>>9&7)<<2)>>2]|0;e=9104156+((a&7|8)<<2)|0;a=(c[e>>2]|0)-4|0;c[e>>2]=a;e=c[2276085]&a;a=e&16777215;f=c[2112932]|0;g=c[f+(a>>>10<<2)>>2]|0;if(g>>>0>9){h=e&1023;i=(d[g+(h+3)|0]|0)<<8|(d[g+(h+2)|0]|0)|((d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0))<<16}else{i=gj[c[f+196768+(g<<2)>>2]&4095](a)|0}c[2276076]=b;c[2276077]=0;c[2276078]=0;if(!((b|0)<0|(b|0)>(i|0))){return}c[2276075]=b>>>31<<7;Eo();return}function ED(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((c[2276038]&24|0)==0){Bl();return}a=c[2276069]|0;b=c[9104156+((a>>>9&7)<<2)>>2]|0;e=c[9104156+((a&7|8)<<2)>>2]|0;a=c[2276056]|0;f=a&-4;if((f|0)==(c[2276083]|0)){g=a;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a}else{a=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=a;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=(h>>>((g<<3&16^16)>>>0)<<16>>16)+e&c[2276085];e=m&16777215;g=c[2112932]|0;h=c[g+(e>>>10<<2)>>2]|0;if(h>>>0>9){n=m&1023;o=(d[h+(n+3)|0]|0)<<8|(d[h+(n+2)|0]|0)|((d[h+(n+1)|0]|0)<<8|(d[h+n|0]|0))<<16}else{o=gj[c[g+196768+(h<<2)>>2]&4095](e)|0}c[2276076]=b;c[2276077]=0;c[2276078]=0;if(!((b|0)<0|(b|0)>(o|0))){return}c[2276075]=b>>>31<<7;Eo();return}function EE(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0;if((c[2276038]&24|0)==0){Bl();return}a=c[2276069]|0;b=c[9104156+((a>>>9&7)<<2)>>2]|0;e=xw(c[9104156+((a&7|8)<<2)>>2]|0)|0;a=c[2276085]&e;e=a&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=a&1023;i=(d[g+(h+3)|0]|0)<<8|(d[g+(h+2)|0]|0)|((d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0))<<16}else{i=gj[c[f+196768+(g<<2)>>2]&4095](e)|0}c[2276076]=b;c[2276077]=0;c[2276078]=0;if(!((b|0)<0|(b|0)>(i|0))){return}c[2276075]=b>>>31<<7;Eo();return}function EF(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[2276038]&24|0)==0){Bl();return}a=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)<<16>>16&c[2276085];f=l&16777215;g=c[2112932]|0;m=c[g+(f>>>10<<2)>>2]|0;if(m>>>0>9){b=l&1023;n=(d[m+(b+3)|0]|0)<<8|(d[m+(b+2)|0]|0)|((d[m+(b+1)|0]|0)<<8|(d[m+b|0]|0))<<16}else{n=gj[c[g+196768+(m<<2)>>2]&4095](f)|0}c[2276076]=a;c[2276077]=0;c[2276078]=0;if(!((a|0)<0|(a|0)>(n|0))){return}c[2276075]=a>>>31<<7;Eo();return}function EG(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;if((c[2276038]&24|0)==0){Bl();return}a=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[2276085]&q;q=r&16777215;t=c[2112932]|0;h=c[t+(q>>>10<<2)>>2]|0;if(h>>>0>9){s=r&1023;u=(d[h+(s+3)|0]|0)<<8|(d[h+(s+2)|0]|0)|((d[h+(s+1)|0]|0)<<8|(d[h+s|0]|0))<<16}else{u=gj[c[t+196768+(h<<2)>>2]&4095](q)|0}c[2276076]=a;c[2276077]=0;c[2276078]=0;if(!((a|0)<0|(a|0)>(u|0))){return}c[2276075]=a>>>31<<7;Eo();return}function EH(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[2276038]&24|0)==0){Bl();return}a=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{k=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=k;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=(g>>>((f<<3&16^16)>>>0)<<16>>16)+b|0;b=l&16777215;f=c[2112932]|0;g=c[f+((b>>>10|32768)<<2)>>2]|0;if(g>>>0>9){m=l&1023;n=(d[g+(m+3)|0]|0)<<8|(d[g+(m+2)|0]|0)|((d[g+(m+1)|0]|0)<<8|(d[g+m|0]|0))<<16}else{n=gj[c[f+196768+(g<<2)>>2]&4095](b)|0}c[2276076]=a;c[2276077]=0;c[2276078]=0;if(!((a|0)<0|(a|0)>(n|0))){return}c[2276075]=a>>>31<<7;Eo();return}function EI(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0;if((c[2276038]&24|0)==0){Bl();return}a=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;b=xw(c[2276056]|0)|0;e=b&16777215;f=c[2112932]|0;g=c[f+((e>>>10|32768)<<2)>>2]|0;if(g>>>0>9){h=b&1023;i=(d[g+(h+3)|0]|0)<<8|(d[g+(h+2)|0]|0)|((d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0))<<16}else{i=gj[c[f+196768+(g<<2)>>2]&4095](e)|0}c[2276076]=a;c[2276077]=0;c[2276078]=0;if(!((a|0)<0|(a|0)>(i|0))){return}c[2276075]=a>>>31<<7;Eo();return}function EJ(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;if((c[2276038]&24|0)==0){Bl();return}a=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;c[2276076]=a;c[2276077]=0;c[2276078]=0;if(!((a|0)<0|(a|0)>(q|0))){return}c[2276075]=a>>>31<<7;Eo();return}function EK(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0);f=c[9104156+((n>>>12&15)<<2)>>2]|0;o=f&255;e=p&-4;if((e|0)==(h|0)){q=p;r=g}else{c[2276083]=e;g=c[2276085]&e;e=g&16777212;h=c[2112932]|0;j=c[h+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){l=g&1020;s=(d[j+(l|3)|0]|0)<<8|(d[j+(l|2)|0]|0)|((d[j+(l|1)|0]|0)<<8|(d[j+l|0]|0))<<16;t=p}else{l=gj[c[h+196768+(j<<2)>>2]&4095](e)|0;s=l;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;s=(r>>>((q<<3&16^16)>>>0)<<16>>16)+p|0;p=s&16777215;q=c[2112932]|0;r=c[q+((p>>>10|32768)<<2)>>2]|0;if(r>>>0>9){u=a[r+(s&1023^1)|0]|0;v=q}else{t=gj[c[q+196608+(r<<2)>>2]&4095](p)|0;u=t;v=c[2112932]|0}t=u&255;p=s+1|0;s=p&16777215;r=c[v+((s>>>10|32768)<<2)>>2]|0;if(r>>>0>9){w=a[r+(p&1023^1)|0]|0}else{w=gj[c[v+196608+(r<<2)>>2]&4095](s)|0}s=w&255;if((n&32768|0)==0){x=(f<<24>>24)-(u<<24>>24)|0}else{x=o-t|0}c[2276078]=x;c[2276076]=((s|0)==(o|0)|(t|0)==(o|0))^1;if((x&256|0)!=0){if((n&2048|0)==0){return}Eo();return}x=s-o|0;c[2276078]=x;if((x&256|0)==0){return}if((n&2048|0)==0){return}Eo();return}function EL(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}l=f+2|0;c[2276056]=l;m=g>>>((f<<3&16^16)>>>0);f=c[9104156+((m>>>12&15)<<2)>>2]|0;g=f&255;b=xw(l)|0;l=b&16777215;e=c[2112932]|0;j=c[e+((l>>>10|32768)<<2)>>2]|0;if(j>>>0>9){n=a[j+(b&1023^1)|0]|0;o=e}else{i=gj[c[e+196608+(j<<2)>>2]&4095](l)|0;n=i;o=c[2112932]|0}i=n&255;l=b+1|0;b=l&16777215;j=c[o+((b>>>10|32768)<<2)>>2]|0;if(j>>>0>9){p=a[j+(l&1023^1)|0]|0}else{p=gj[c[o+196608+(j<<2)>>2]&4095](b)|0}b=p&255;if((m&32768|0)==0){q=(f<<24>>24)-(n<<24>>24)|0}else{q=g-i|0}c[2276078]=q;c[2276076]=((b|0)==(g|0)|(i|0)==(g|0))^1;if((q&256|0)!=0){if((m&2048|0)==0){return}Eo();return}q=b-g|0;c[2276078]=q;if((q&256|0)==0){return}if((m&2048|0)==0){return}Eo();return}function EM(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0);f=c[9104156+((l>>>12&15)<<2)>>2]|0;g=f&255;m=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;b=c[2276085]|0;e=b&m;j=e&16777215;i=c[2112932]|0;k=c[i+(j>>>10<<2)>>2]|0;if(k>>>0>9){n=a[k+(e&1023^1)|0]|0;o=b;p=i}else{b=gj[c[i+196608+(k<<2)>>2]&4095](j)|0;n=b;o=c[2276085]|0;p=c[2112932]|0}b=n&255;j=o&m+1;m=j&16777215;o=c[p+(m>>>10<<2)>>2]|0;if(o>>>0>9){q=a[o+(j&1023^1)|0]|0}else{q=gj[c[p+196608+(o<<2)>>2]&4095](m)|0}m=q&255;if((l&32768|0)==0){r=(f<<24>>24)-(n<<24>>24)|0}else{r=g-b|0}c[2276078]=r;c[2276076]=((m|0)==(g|0)|(b|0)==(g|0))^1;if((r&256|0)!=0){if((l&2048|0)==0){return}Eo();return}r=m-g|0;c[2276078]=r;if((r&256|0)==0){return}if((l&2048|0)==0){return}Eo();return}function EN(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0);f=c[9104156+((n>>>12&15)<<2)>>2]|0;o=f&255;e=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;j=p&-4;if((j|0)==(h|0)){q=p;r=g}else{c[2276083]=j;g=c[2276085]&j;j=g&16777212;h=c[2112932]|0;l=c[h+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){k=g&1020;s=(d[l+(k|3)|0]|0)<<8|(d[l+(k|2)|0]|0)|((d[l+(k|1)|0]|0)<<8|(d[l+k|0]|0))<<16;t=p}else{p=gj[c[h+196768+(l<<2)>>2]&4095](j)|0;s=p;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;s=(r>>>((q<<3&16^16)>>>0)<<16>>16)+e|0;e=c[2276085]|0;q=s&e;r=q&16777215;t=c[2112932]|0;p=c[t+(r>>>10<<2)>>2]|0;if(p>>>0>9){u=a[p+(q&1023^1)|0]|0;v=e;w=t}else{e=gj[c[t+196608+(p<<2)>>2]&4095](r)|0;u=e;v=c[2276085]|0;w=c[2112932]|0}e=u&255;r=v&s+1;s=r&16777215;v=c[w+(s>>>10<<2)>>2]|0;if(v>>>0>9){x=a[v+(r&1023^1)|0]|0}else{x=gj[c[w+196608+(v<<2)>>2]&4095](s)|0}s=x&255;if((n&32768|0)==0){y=(f<<24>>24)-(u<<24>>24)|0}else{y=o-e|0}c[2276078]=y;c[2276076]=((s|0)==(o|0)|(e|0)==(o|0))^1;if((y&256|0)!=0){if((n&2048|0)==0){return}Eo();return}y=s-o|0;c[2276078]=y;if((y&256|0)==0){return}if((n&2048|0)==0){return}Eo();return}function EO(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0);f=c[9104156+((l>>>12&15)<<2)>>2]|0;g=f&255;m=xw(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;b=c[2276085]|0;e=b&m;j=e&16777215;i=c[2112932]|0;k=c[i+(j>>>10<<2)>>2]|0;if(k>>>0>9){n=a[k+(e&1023^1)|0]|0;o=b;p=i}else{b=gj[c[i+196608+(k<<2)>>2]&4095](j)|0;n=b;o=c[2276085]|0;p=c[2112932]|0}b=n&255;j=o&m+1;m=j&16777215;o=c[p+(m>>>10<<2)>>2]|0;if(o>>>0>9){q=a[o+(j&1023^1)|0]|0}else{q=gj[c[p+196608+(o<<2)>>2]&4095](m)|0}m=q&255;if((l&32768|0)==0){r=(f<<24>>24)-(n<<24>>24)|0}else{r=g-b|0}c[2276078]=r;c[2276076]=((m|0)==(g|0)|(b|0)==(g|0))^1;if((r&256|0)!=0){if((l&2048|0)==0){return}Eo();return}r=m-g|0;c[2276078]=r;if((r&256|0)==0){return}if((l&2048|0)==0){return}Eo();return}function EP(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0);f=c[9104156+((n>>>12&15)<<2)>>2]|0;o=f&255;e=p&-4;if((e|0)==(h|0)){q=p;r=g}else{c[2276083]=e;g=c[2276085]&e;e=g&16777212;h=c[2112932]|0;j=c[h+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){l=g&1020;s=(d[j+(l|3)|0]|0)<<8|(d[j+(l|2)|0]|0)|((d[j+(l|1)|0]|0)<<8|(d[j+l|0]|0))<<16;t=p}else{p=gj[c[h+196768+(j<<2)>>2]&4095](e)|0;s=p;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;s=r>>>((q<<3&16^16)>>>0)<<16>>16;q=c[2276085]|0;r=s&q;t=r&16777215;p=c[2112932]|0;e=c[p+(t>>>10<<2)>>2]|0;if(e>>>0>9){u=a[e+(r&1023^1)|0]|0;v=q;w=p}else{q=gj[c[p+196608+(e<<2)>>2]&4095](t)|0;u=q;v=c[2276085]|0;w=c[2112932]|0}q=u&255;t=v&s+1;s=t&16777215;v=c[w+(s>>>10<<2)>>2]|0;if(v>>>0>9){x=a[v+(t&1023^1)|0]|0}else{x=gj[c[w+196608+(v<<2)>>2]&4095](s)|0}s=x&255;if((n&32768|0)==0){y=(f<<24>>24)-(u<<24>>24)|0}else{y=o-q|0}c[2276078]=y;c[2276076]=((s|0)==(o|0)|(q|0)==(o|0))^1;if((y&256|0)!=0){if((n&2048|0)==0){return}Eo();return}y=s-o|0;c[2276078]=y;if((y&256|0)==0){return}if((n&2048|0)==0){return}Eo();return}function EQ(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0);f=c[9104156+((n>>>12&15)<<2)>>2]|0;o=f&255;e=p&-4;if((e|0)==(h|0)){q=p;r=h;s=g}else{c[2276083]=e;g=c[2276085]&e;h=g&16777212;j=c[2112932]|0;l=c[j+((h>>>10|32768)<<2)>>2]|0;if(l>>>0>9){k=g&1020;t=(d[l+(k|3)|0]|0)<<8|(d[l+(k|2)|0]|0)|((d[l+(k|1)|0]|0)<<8|(d[l+k|0]|0))<<16;u=p;v=e}else{e=gj[c[j+196768+(l<<2)>>2]&4095](h)|0;t=e;u=c[2276056]|0;v=c[2276083]|0}c[2276084]=t;q=u;r=v;s=t}t=q+2|0;c[2276056]=t;q=t&-4;if((q|0)==(r|0)){w=s;x=t}else{c[2276083]=q;r=c[2276085]&q;q=r&16777212;v=c[2112932]|0;u=c[v+((q>>>10|32768)<<2)>>2]|0;if(u>>>0>9){e=r&1020;y=(d[u+(e|3)|0]|0)<<8|(d[u+(e|2)|0]|0)|((d[u+(e|1)|0]|0)<<8|(d[u+e|0]|0))<<16;z=t}else{t=gj[c[v+196768+(u<<2)>>2]&4095](q)|0;y=t;z=c[2276056]|0}c[2276084]=y;w=y>>>16|s<<16;x=z}c[2276056]=x+2;x=c[2276085]|0;z=x&w;s=z&16777215;y=c[2112932]|0;t=c[y+(s>>>10<<2)>>2]|0;if(t>>>0>9){A=a[t+(z&1023^1)|0]|0;B=x;C=y}else{x=gj[c[y+196608+(t<<2)>>2]&4095](s)|0;A=x;B=c[2276085]|0;C=c[2112932]|0}x=A&255;s=B&w+1;w=s&16777215;B=c[C+(w>>>10<<2)>>2]|0;if(B>>>0>9){D=a[B+(s&1023^1)|0]|0}else{D=gj[c[C+196608+(B<<2)>>2]&4095](w)|0}w=D&255;if((n&32768|0)==0){E=(f<<24>>24)-(A<<24>>24)|0}else{E=o-x|0}c[2276078]=E;c[2276076]=((w|0)==(o|0)|(x|0)==(o|0))^1;if((E&256|0)!=0){if((n&2048|0)==0){return}Eo();return}E=w-o|0;c[2276078]=E;if((E&256|0)==0){return}if((n&2048|0)==0){return}Eo();return}function ER(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;if((c[2276038]&24|0)==0){Bl();return}a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0;g=b}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=m;g=o}o=e+2|0;c[2276056]=o;m=f>>>((e<<3&16^16)>>>0);e=c[9104156+((m>>>12&15)<<2)>>2]|0;n=e&65535;b=o&-4;if((b|0)==(g|0)){p=o;q=f}else{c[2276083]=b;f=c[2276085]&b;b=f&16777212;g=c[2112932]|0;i=c[g+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){k=f&1020;r=(d[i+(k|3)|0]|0)<<8|(d[i+(k|2)|0]|0)|((d[i+(k|1)|0]|0)<<8|(d[i+k|0]|0))<<16;s=o}else{k=gj[c[g+196768+(i<<2)>>2]&4095](b)|0;r=k;s=c[2276056]|0}c[2276084]=r;p=s;q=r}c[2276056]=p+2;r=(q>>>((p<<3&16^16)>>>0)<<16>>16)+o|0;o=r&16777215;p=c[2112932]|0;q=c[p+((o>>>10|32768)<<2)>>2]|0;if(q>>>0>9){s=r&1023;t=(d[q+(s+1)|0]|0)<<8|(d[q+s|0]|0);u=p}else{s=gj[c[p+196688+(q<<2)>>2]&4095](o)|0;t=s;u=c[2112932]|0}s=t&65535;o=r+2|0;r=o&16777215;q=c[u+((r>>>10|32768)<<2)>>2]|0;if(q>>>0>9){p=o&1023;v=(d[q+(p+1)|0]|0)<<8|(d[q+p|0]|0)}else{v=gj[c[u+196688+(q<<2)>>2]&4095](r)|0}r=v&65535;q=(m&32768|0)!=0;if(q){w=n-s|0}else{w=(e<<16>>16)-(t<<16>>16)|0}c[2276076]=((r|0)==(n|0)|(s|0)==(n|0))^1;s=w>>>8;c[2276078]=s;if((s&256|0)!=0){if((m&2048|0)==0){return}Eo();return}if(q){x=r-n|0}else{x=(v<<16>>16)-(e<<16>>16)|0}e=x>>>8;c[2276078]=e;if((e&256|0)==0){return}if((m&2048|0)==0){return}Eo();return}function ES(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((c[2276038]&24|0)==0){Bl();return}a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}k=e+2|0;c[2276056]=k;l=f>>>((e<<3&16^16)>>>0);e=c[9104156+((l>>>12&15)<<2)>>2]|0;f=e&65535;a=xw(k)|0;k=a&16777215;b=c[2112932]|0;i=c[b+((k>>>10|32768)<<2)>>2]|0;if(i>>>0>9){h=a&1023;m=(d[i+(h+1)|0]|0)<<8|(d[i+h|0]|0);n=b}else{h=gj[c[b+196688+(i<<2)>>2]&4095](k)|0;m=h;n=c[2112932]|0}h=m&65535;k=a+2|0;a=k&16777215;i=c[n+((a>>>10|32768)<<2)>>2]|0;if(i>>>0>9){b=k&1023;o=(d[i+(b+1)|0]|0)<<8|(d[i+b|0]|0)}else{o=gj[c[n+196688+(i<<2)>>2]&4095](a)|0}a=o&65535;i=(l&32768|0)!=0;if(i){p=f-h|0}else{p=(e<<16>>16)-(m<<16>>16)|0}c[2276076]=((a|0)==(f|0)|(h|0)==(f|0))^1;h=p>>>8;c[2276078]=h;if((h&256|0)!=0){if((l&2048|0)==0){return}Eo();return}if(i){q=a-f|0}else{q=(o<<16>>16)-(e<<16>>16)|0}e=q>>>8;c[2276078]=e;if((e&256|0)==0){return}if((l&2048|0)==0){return}Eo();return}function ET(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if((c[2276038]&24|0)==0){Bl();return}a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=f>>>((e<<3&16^16)>>>0);e=c[9104156+((k>>>12&15)<<2)>>2]|0;f=e&65535;l=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;a=c[2276085]|0;b=a&l;i=b&16777215;h=c[2112932]|0;j=c[h+(i>>>10<<2)>>2]|0;if(j>>>0>9){g=b&1023;m=(d[j+(g+1)|0]|0)<<8|(d[j+g|0]|0);n=a;o=h}else{a=gj[c[h+196688+(j<<2)>>2]&4095](i)|0;m=a;n=c[2276085]|0;o=c[2112932]|0}a=m&65535;i=n&l+2;l=i&16777215;n=c[o+(l>>>10<<2)>>2]|0;if(n>>>0>9){j=i&1023;p=(d[n+(j+1)|0]|0)<<8|(d[n+j|0]|0)}else{p=gj[c[o+196688+(n<<2)>>2]&4095](l)|0}l=p&65535;n=(k&32768|0)!=0;if(n){q=f-a|0}else{q=(e<<16>>16)-(m<<16>>16)|0}c[2276076]=((l|0)==(f|0)|(a|0)==(f|0))^1;a=q>>>8;c[2276078]=a;if((a&256|0)!=0){if((k&2048|0)==0){return}Eo();return}if(n){r=l-f|0}else{r=(p<<16>>16)-(e<<16>>16)|0}e=r>>>8;c[2276078]=e;if((e&256|0)==0){return}if((k&2048|0)==0){return}Eo();return}function EU(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;if((c[2276038]&24|0)==0){Bl();return}a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0;g=b}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=m;g=o}o=e+2|0;c[2276056]=o;m=f>>>((e<<3&16^16)>>>0);e=c[9104156+((m>>>12&15)<<2)>>2]|0;n=e&65535;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;i=o&-4;if((i|0)==(g|0)){p=o;q=f}else{c[2276083]=i;f=c[2276085]&i;i=f&16777212;g=c[2112932]|0;k=c[g+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){j=f&1020;r=(d[k+(j|3)|0]|0)<<8|(d[k+(j|2)|0]|0)|((d[k+(j|1)|0]|0)<<8|(d[k+j|0]|0))<<16;s=o}else{o=gj[c[g+196768+(k<<2)>>2]&4095](i)|0;r=o;s=c[2276056]|0}c[2276084]=r;p=s;q=r}c[2276056]=p+2;r=(q>>>((p<<3&16^16)>>>0)<<16>>16)+b|0;b=c[2276085]|0;p=r&b;q=p&16777215;s=c[2112932]|0;o=c[s+(q>>>10<<2)>>2]|0;if(o>>>0>9){i=p&1023;t=(d[o+(i+1)|0]|0)<<8|(d[o+i|0]|0);u=b;v=s}else{b=gj[c[s+196688+(o<<2)>>2]&4095](q)|0;t=b;u=c[2276085]|0;v=c[2112932]|0}b=t&65535;q=u&r+2;r=q&16777215;u=c[v+(r>>>10<<2)>>2]|0;if(u>>>0>9){o=q&1023;w=(d[u+(o+1)|0]|0)<<8|(d[u+o|0]|0)}else{w=gj[c[v+196688+(u<<2)>>2]&4095](r)|0}r=w&65535;u=(m&32768|0)!=0;if(u){x=n-b|0}else{x=(e<<16>>16)-(t<<16>>16)|0}c[2276076]=((r|0)==(n|0)|(b|0)==(n|0))^1;b=x>>>8;c[2276078]=b;if((b&256|0)!=0){if((m&2048|0)==0){return}Eo();return}if(u){y=r-n|0}else{y=(w<<16>>16)-(e<<16>>16)|0}e=y>>>8;c[2276078]=e;if((e&256|0)==0){return}if((m&2048|0)==0){return}Eo();return}function EV(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if((c[2276038]&24|0)==0){Bl();return}a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=f>>>((e<<3&16^16)>>>0);e=c[9104156+((k>>>12&15)<<2)>>2]|0;f=e&65535;l=xw(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;a=c[2276085]|0;b=a&l;i=b&16777215;h=c[2112932]|0;j=c[h+(i>>>10<<2)>>2]|0;if(j>>>0>9){g=b&1023;m=(d[j+(g+1)|0]|0)<<8|(d[j+g|0]|0);n=a;o=h}else{a=gj[c[h+196688+(j<<2)>>2]&4095](i)|0;m=a;n=c[2276085]|0;o=c[2112932]|0}a=m&65535;i=n&l+2;l=i&16777215;n=c[o+(l>>>10<<2)>>2]|0;if(n>>>0>9){j=i&1023;p=(d[n+(j+1)|0]|0)<<8|(d[n+j|0]|0)}else{p=gj[c[o+196688+(n<<2)>>2]&4095](l)|0}l=p&65535;n=(k&32768|0)!=0;if(n){q=f-a|0}else{q=(e<<16>>16)-(m<<16>>16)|0}c[2276076]=((l|0)==(f|0)|(a|0)==(f|0))^1;a=q>>>8;c[2276078]=a;if((a&256|0)!=0){if((k&2048|0)==0){return}Eo();return}if(n){r=l-f|0}else{r=(p<<16>>16)-(e<<16>>16)|0}e=r>>>8;c[2276078]=e;if((e&256|0)==0){return}if((k&2048|0)==0){return}Eo();return}function EW(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;if((c[2276038]&24|0)==0){Bl();return}a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0;g=b}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=m;g=o}o=e+2|0;c[2276056]=o;m=f>>>((e<<3&16^16)>>>0);e=c[9104156+((m>>>12&15)<<2)>>2]|0;n=e&65535;b=o&-4;if((b|0)==(g|0)){p=o;q=f}else{c[2276083]=b;f=c[2276085]&b;b=f&16777212;g=c[2112932]|0;i=c[g+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){k=f&1020;r=(d[i+(k|3)|0]|0)<<8|(d[i+(k|2)|0]|0)|((d[i+(k|1)|0]|0)<<8|(d[i+k|0]|0))<<16;s=o}else{o=gj[c[g+196768+(i<<2)>>2]&4095](b)|0;r=o;s=c[2276056]|0}c[2276084]=r;p=s;q=r}c[2276056]=p+2;r=q>>>((p<<3&16^16)>>>0)<<16>>16;p=c[2276085]|0;q=r&p;s=q&16777215;o=c[2112932]|0;b=c[o+(s>>>10<<2)>>2]|0;if(b>>>0>9){i=q&1023;t=(d[b+(i+1)|0]|0)<<8|(d[b+i|0]|0);u=p;v=o}else{p=gj[c[o+196688+(b<<2)>>2]&4095](s)|0;t=p;u=c[2276085]|0;v=c[2112932]|0}p=t&65535;s=u&r+2;r=s&16777215;u=c[v+(r>>>10<<2)>>2]|0;if(u>>>0>9){b=s&1023;w=(d[u+(b+1)|0]|0)<<8|(d[u+b|0]|0)}else{w=gj[c[v+196688+(u<<2)>>2]&4095](r)|0}r=w&65535;u=(m&32768|0)!=0;if(u){x=n-p|0}else{x=(e<<16>>16)-(t<<16>>16)|0}c[2276076]=((r|0)==(n|0)|(p|0)==(n|0))^1;p=x>>>8;c[2276078]=p;if((p&256|0)!=0){if((m&2048|0)==0){return}Eo();return}if(u){y=r-n|0}else{y=(w<<16>>16)-(e<<16>>16)|0}e=y>>>8;c[2276078]=e;if((e&256|0)==0){return}if((m&2048|0)==0){return}Eo();return}function EX(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;if((c[2276038]&24|0)==0){Bl();return}a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0;g=b}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=m;g=o}o=e+2|0;c[2276056]=o;m=f>>>((e<<3&16^16)>>>0);e=c[9104156+((m>>>12&15)<<2)>>2]|0;n=e&65535;b=o&-4;if((b|0)==(g|0)){p=o;q=g;r=f}else{c[2276083]=b;f=c[2276085]&b;g=f&16777212;i=c[2112932]|0;k=c[i+((g>>>10|32768)<<2)>>2]|0;if(k>>>0>9){j=f&1020;s=(d[k+(j|3)|0]|0)<<8|(d[k+(j|2)|0]|0)|((d[k+(j|1)|0]|0)<<8|(d[k+j|0]|0))<<16;t=o;u=b}else{b=gj[c[i+196768+(k<<2)>>2]&4095](g)|0;s=b;t=c[2276056]|0;u=c[2276083]|0}c[2276084]=s;p=t;q=u;r=s}s=p+2|0;c[2276056]=s;p=s&-4;if((p|0)==(q|0)){v=r;w=s}else{c[2276083]=p;q=c[2276085]&p;p=q&16777212;u=c[2112932]|0;t=c[u+((p>>>10|32768)<<2)>>2]|0;if(t>>>0>9){b=q&1020;x=(d[t+(b|3)|0]|0)<<8|(d[t+(b|2)|0]|0)|((d[t+(b|1)|0]|0)<<8|(d[t+b|0]|0))<<16;y=s}else{s=gj[c[u+196768+(t<<2)>>2]&4095](p)|0;x=s;y=c[2276056]|0}c[2276084]=x;v=x>>>16|r<<16;w=y}c[2276056]=w+2;w=c[2276085]|0;y=w&v;r=y&16777215;x=c[2112932]|0;s=c[x+(r>>>10<<2)>>2]|0;if(s>>>0>9){p=y&1023;z=(d[s+(p+1)|0]|0)<<8|(d[s+p|0]|0);A=w;B=x}else{w=gj[c[x+196688+(s<<2)>>2]&4095](r)|0;z=w;A=c[2276085]|0;B=c[2112932]|0}w=z&65535;r=A&v+2;v=r&16777215;A=c[B+(v>>>10<<2)>>2]|0;if(A>>>0>9){s=r&1023;C=(d[A+(s+1)|0]|0)<<8|(d[A+s|0]|0)}else{C=gj[c[B+196688+(A<<2)>>2]&4095](v)|0}v=C&65535;A=(m&32768|0)!=0;if(A){D=n-w|0}else{D=(e<<16>>16)-(z<<16>>16)|0}c[2276076]=((v|0)==(n|0)|(w|0)==(n|0))^1;w=D>>>8;c[2276078]=w;if((w&256|0)!=0){if((m&2048|0)==0){return}Eo();return}if(A){E=v-n|0}else{E=(C<<16>>16)-(e<<16>>16)|0}e=E>>>8;c[2276078]=e;if((e&256|0)==0){return}if((m&2048|0)==0){return}Eo();return}function EY(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;if((c[2276038]&24|0)==0){Bl();return}a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0;g=b}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=m;g=o}o=e+2|0;c[2276056]=o;m=f>>>((e<<3&16^16)>>>0);e=c[9104156+((m>>>12&15)<<2)>>2]|0;n=o&-4;if((n|0)==(g|0)){p=o;q=f}else{c[2276083]=n;f=c[2276085]&n;n=f&16777212;g=c[2112932]|0;b=c[g+((n>>>10|32768)<<2)>>2]|0;if(b>>>0>9){i=f&1020;r=(d[b+(i|3)|0]|0)<<8|(d[b+(i|2)|0]|0)|((d[b+(i|1)|0]|0)<<8|(d[b+i|0]|0))<<16;s=o}else{i=gj[c[g+196768+(b<<2)>>2]&4095](n)|0;r=i;s=c[2276056]|0}c[2276084]=r;p=s;q=r}c[2276056]=p+2;r=(q>>>((p<<3&16^16)>>>0)<<16>>16)+o|0;o=r&16777215;p=c[2112932]|0;q=c[p+((o>>>10|32768)<<2)>>2]|0;if(q>>>0>9){s=r&1023;t=(d[q+(s+3)|0]|0)<<8|(d[q+(s+2)|0]|0)|((d[q+(s+1)|0]|0)<<8|(d[q+s|0]|0))<<16;u=p}else{s=gj[c[p+196768+(q<<2)>>2]&4095](o)|0;t=s;u=c[2112932]|0}s=r+4|0;r=s&16777215;o=c[u+((r>>>10|32768)<<2)>>2]|0;if(o>>>0>9){q=s&1023;v=(d[o+(q+3)|0]|0)<<8|(d[o+(q+2)|0]|0)|((d[o+(q+1)|0]|0)<<8|(d[o+q|0]|0))<<16}else{v=gj[c[u+196768+(o<<2)>>2]&4095](r)|0}r=e-t|0;c[2276076]=((v|0)==(e|0)|(t|0)==(e|0))^1;o=((r|t)&(e^-8388608)|r&t)>>>23;c[2276078]=o;if((o&256|0)!=0){if((m&2048|0)==0){return}Eo();return}o=v-e|0;t=((o|e)&(v^-8388608)|o&e)>>>23;c[2276078]=t;if((t&256|0)==0){return}if((m&2048|0)==0){return}Eo();return}function EZ(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((c[2276038]&24|0)==0){Bl();return}a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}k=e+2|0;c[2276056]=k;l=f>>>((e<<3&16^16)>>>0);e=c[9104156+((l>>>12&15)<<2)>>2]|0;f=xw(k)|0;k=f&16777215;a=c[2112932]|0;b=c[a+((k>>>10|32768)<<2)>>2]|0;if(b>>>0>9){i=f&1023;m=(d[b+(i+3)|0]|0)<<8|(d[b+(i+2)|0]|0)|((d[b+(i+1)|0]|0)<<8|(d[b+i|0]|0))<<16;n=a}else{i=gj[c[a+196768+(b<<2)>>2]&4095](k)|0;m=i;n=c[2112932]|0}i=f+4|0;f=i&16777215;k=c[n+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){b=i&1023;o=(d[k+(b+3)|0]|0)<<8|(d[k+(b+2)|0]|0)|((d[k+(b+1)|0]|0)<<8|(d[k+b|0]|0))<<16}else{o=gj[c[n+196768+(k<<2)>>2]&4095](f)|0}f=e-m|0;c[2276076]=((o|0)==(e|0)|(m|0)==(e|0))^1;k=((f|m)&(e^-8388608)|f&m)>>>23;c[2276078]=k;if((k&256|0)!=0){if((l&2048|0)==0){return}Eo();return}k=o-e|0;m=((k|e)&(o^-8388608)|k&e)>>>23;c[2276078]=m;if((m&256|0)==0){return}if((l&2048|0)==0){return}Eo();return}function E_(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;if((c[2276038]&24|0)==0){Bl();return}a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=f>>>((e<<3&16^16)>>>0);e=c[9104156+((k>>>12&15)<<2)>>2]|0;f=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;l=c[2276085]|0;a=l&f;b=a&16777215;i=c[2112932]|0;h=c[i+(b>>>10<<2)>>2]|0;if(h>>>0>9){j=a&1023;m=(d[h+(j+3)|0]|0)<<8|(d[h+(j+2)|0]|0)|((d[h+(j+1)|0]|0)<<8|(d[h+j|0]|0))<<16;n=l;o=i}else{l=gj[c[i+196768+(h<<2)>>2]&4095](b)|0;m=l;n=c[2276085]|0;o=c[2112932]|0}l=n&f+4;f=l&16777215;n=c[o+(f>>>10<<2)>>2]|0;if(n>>>0>9){b=l&1023;p=(d[n+(b+3)|0]|0)<<8|(d[n+(b+2)|0]|0)|((d[n+(b+1)|0]|0)<<8|(d[n+b|0]|0))<<16}else{p=gj[c[o+196768+(n<<2)>>2]&4095](f)|0}f=e-m|0;c[2276076]=((p|0)==(e|0)|(m|0)==(e|0))^1;n=((f|m)&(e^-8388608)|f&m)>>>23;c[2276078]=n;if((n&256|0)!=0){if((k&2048|0)==0){return}Eo();return}n=p-e|0;m=((n|e)&(p^-8388608)|n&e)>>>23;c[2276078]=m;if((m&256|0)==0){return}if((k&2048|0)==0){return}Eo();return}function E$(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;if((c[2276038]&24|0)==0){Bl();return}a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0;g=b}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=m;g=o}o=e+2|0;c[2276056]=o;m=f>>>((e<<3&16^16)>>>0);e=c[9104156+((m>>>12&15)<<2)>>2]|0;n=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;b=o&-4;if((b|0)==(g|0)){p=o;q=f}else{c[2276083]=b;f=c[2276085]&b;b=f&16777212;g=c[2112932]|0;i=c[g+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){k=f&1020;r=(d[i+(k|3)|0]|0)<<8|(d[i+(k|2)|0]|0)|((d[i+(k|1)|0]|0)<<8|(d[i+k|0]|0))<<16;s=o}else{o=gj[c[g+196768+(i<<2)>>2]&4095](b)|0;r=o;s=c[2276056]|0}c[2276084]=r;p=s;q=r}c[2276056]=p+2;r=(q>>>((p<<3&16^16)>>>0)<<16>>16)+n|0;n=c[2276085]|0;p=r&n;q=p&16777215;s=c[2112932]|0;o=c[s+(q>>>10<<2)>>2]|0;if(o>>>0>9){b=p&1023;t=(d[o+(b+3)|0]|0)<<8|(d[o+(b+2)|0]|0)|((d[o+(b+1)|0]|0)<<8|(d[o+b|0]|0))<<16;u=n;v=s}else{n=gj[c[s+196768+(o<<2)>>2]&4095](q)|0;t=n;u=c[2276085]|0;v=c[2112932]|0}n=u&r+4;r=n&16777215;u=c[v+(r>>>10<<2)>>2]|0;if(u>>>0>9){q=n&1023;w=(d[u+(q+3)|0]|0)<<8|(d[u+(q+2)|0]|0)|((d[u+(q+1)|0]|0)<<8|(d[u+q|0]|0))<<16}else{w=gj[c[v+196768+(u<<2)>>2]&4095](r)|0}r=e-t|0;c[2276076]=((w|0)==(e|0)|(t|0)==(e|0))^1;u=((r|t)&(e^-8388608)|r&t)>>>23;c[2276078]=u;if((u&256|0)!=0){if((m&2048|0)==0){return}Eo();return}u=w-e|0;t=((u|e)&(w^-8388608)|u&e)>>>23;c[2276078]=t;if((t&256|0)==0){return}if((m&2048|0)==0){return}Eo();return}function E0(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;if((c[2276038]&24|0)==0){Bl();return}a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=f>>>((e<<3&16^16)>>>0);e=c[9104156+((k>>>12&15)<<2)>>2]|0;f=xw(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;l=c[2276085]|0;a=l&f;b=a&16777215;i=c[2112932]|0;h=c[i+(b>>>10<<2)>>2]|0;if(h>>>0>9){j=a&1023;m=(d[h+(j+3)|0]|0)<<8|(d[h+(j+2)|0]|0)|((d[h+(j+1)|0]|0)<<8|(d[h+j|0]|0))<<16;n=l;o=i}else{l=gj[c[i+196768+(h<<2)>>2]&4095](b)|0;m=l;n=c[2276085]|0;o=c[2112932]|0}l=n&f+4;f=l&16777215;n=c[o+(f>>>10<<2)>>2]|0;if(n>>>0>9){b=l&1023;p=(d[n+(b+3)|0]|0)<<8|(d[n+(b+2)|0]|0)|((d[n+(b+1)|0]|0)<<8|(d[n+b|0]|0))<<16}else{p=gj[c[o+196768+(n<<2)>>2]&4095](f)|0}f=e-m|0;c[2276076]=((p|0)==(e|0)|(m|0)==(e|0))^1;n=((f|m)&(e^-8388608)|f&m)>>>23;c[2276078]=n;if((n&256|0)!=0){if((k&2048|0)==0){return}Eo();return}n=p-e|0;m=((n|e)&(p^-8388608)|n&e)>>>23;c[2276078]=m;if((m&256|0)==0){return}if((k&2048|0)==0){return}Eo();return}function E1(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;if((c[2276038]&24|0)==0){Bl();return}a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0;g=b}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=m;g=o}o=e+2|0;c[2276056]=o;m=f>>>((e<<3&16^16)>>>0);e=c[9104156+((m>>>12&15)<<2)>>2]|0;n=o&-4;if((n|0)==(g|0)){p=o;q=f}else{c[2276083]=n;f=c[2276085]&n;n=f&16777212;g=c[2112932]|0;b=c[g+((n>>>10|32768)<<2)>>2]|0;if(b>>>0>9){i=f&1020;r=(d[b+(i|3)|0]|0)<<8|(d[b+(i|2)|0]|0)|((d[b+(i|1)|0]|0)<<8|(d[b+i|0]|0))<<16;s=o}else{o=gj[c[g+196768+(b<<2)>>2]&4095](n)|0;r=o;s=c[2276056]|0}c[2276084]=r;p=s;q=r}c[2276056]=p+2;r=q>>>((p<<3&16^16)>>>0)<<16>>16;p=c[2276085]|0;q=r&p;s=q&16777215;o=c[2112932]|0;n=c[o+(s>>>10<<2)>>2]|0;if(n>>>0>9){b=q&1023;t=(d[n+(b+3)|0]|0)<<8|(d[n+(b+2)|0]|0)|((d[n+(b+1)|0]|0)<<8|(d[n+b|0]|0))<<16;u=p;v=o}else{p=gj[c[o+196768+(n<<2)>>2]&4095](s)|0;t=p;u=c[2276085]|0;v=c[2112932]|0}p=u&r+4;r=p&16777215;u=c[v+(r>>>10<<2)>>2]|0;if(u>>>0>9){s=p&1023;w=(d[u+(s+3)|0]|0)<<8|(d[u+(s+2)|0]|0)|((d[u+(s+1)|0]|0)<<8|(d[u+s|0]|0))<<16}else{w=gj[c[v+196768+(u<<2)>>2]&4095](r)|0}r=e-t|0;c[2276076]=((w|0)==(e|0)|(t|0)==(e|0))^1;u=((r|t)&(e^-8388608)|r&t)>>>23;c[2276078]=u;if((u&256|0)!=0){if((m&2048|0)==0){return}Eo();return}u=w-e|0;t=((u|e)&(w^-8388608)|u&e)>>>23;c[2276078]=t;if((t&256|0)==0){return}if((m&2048|0)==0){return}Eo();return}function E2(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;if((c[2276038]&24|0)==0){Bl();return}a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0;g=b}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=m;g=o}o=e+2|0;c[2276056]=o;m=f>>>((e<<3&16^16)>>>0);e=c[9104156+((m>>>12&15)<<2)>>2]|0;n=o&-4;if((n|0)==(g|0)){p=o;q=g;r=f}else{c[2276083]=n;f=c[2276085]&n;g=f&16777212;b=c[2112932]|0;i=c[b+((g>>>10|32768)<<2)>>2]|0;if(i>>>0>9){k=f&1020;s=(d[i+(k|3)|0]|0)<<8|(d[i+(k|2)|0]|0)|((d[i+(k|1)|0]|0)<<8|(d[i+k|0]|0))<<16;t=o;u=n}else{n=gj[c[b+196768+(i<<2)>>2]&4095](g)|0;s=n;t=c[2276056]|0;u=c[2276083]|0}c[2276084]=s;p=t;q=u;r=s}s=p+2|0;c[2276056]=s;p=s&-4;if((p|0)==(q|0)){v=r;w=s}else{c[2276083]=p;q=c[2276085]&p;p=q&16777212;u=c[2112932]|0;t=c[u+((p>>>10|32768)<<2)>>2]|0;if(t>>>0>9){n=q&1020;x=(d[t+(n|3)|0]|0)<<8|(d[t+(n|2)|0]|0)|((d[t+(n|1)|0]|0)<<8|(d[t+n|0]|0))<<16;y=s}else{s=gj[c[u+196768+(t<<2)>>2]&4095](p)|0;x=s;y=c[2276056]|0}c[2276084]=x;v=x>>>16|r<<16;w=y}c[2276056]=w+2;w=c[2276085]|0;y=w&v;r=y&16777215;x=c[2112932]|0;s=c[x+(r>>>10<<2)>>2]|0;if(s>>>0>9){p=y&1023;z=(d[s+(p+3)|0]|0)<<8|(d[s+(p+2)|0]|0)|((d[s+(p+1)|0]|0)<<8|(d[s+p|0]|0))<<16;A=w;B=x}else{w=gj[c[x+196768+(s<<2)>>2]&4095](r)|0;z=w;A=c[2276085]|0;B=c[2112932]|0}w=A&v+4;v=w&16777215;A=c[B+(v>>>10<<2)>>2]|0;if(A>>>0>9){r=w&1023;C=(d[A+(r+3)|0]|0)<<8|(d[A+(r+2)|0]|0)|((d[A+(r+1)|0]|0)<<8|(d[A+r|0]|0))<<16}else{C=gj[c[B+196768+(A<<2)>>2]&4095](v)|0}v=e-z|0;c[2276076]=((C|0)==(e|0)|(z|0)==(e|0))^1;A=((v|z)&(e^-8388608)|v&z)>>>23;c[2276078]=A;if((A&256|0)!=0){if((m&2048|0)==0){return}Eo();return}A=C-e|0;z=((A|e)&(C^-8388608)|A&e)>>>23;c[2276078]=z;if((z&256|0)==0){return}if((m&2048|0)==0){return}Eo();return}function E3(){var a=0;a=9104156+((c[2276069]&7)<<2)|0;c[a>>2]=c[a>>2]&-256;gGz(9104300,0,16);return}function E4(){var b=0,d=0,e=0,f=0;b=c[2276085]&c[9104156+((c[2276069]&7|8)<<2)>>2];d=b&16777215;e=c[2112932]|0;f=c[e+((d>>>10|16384)<<2)>>2]|0;if(f>>>0>9){a[f+(b&1023^1)|0]=0;gGz(9104300,0,16);return}else{gg[c[e+196648+(f<<2)>>2]&4095](d,0);gGz(9104300,0,16);return}}function E5(){var b=0,d=0,e=0,f=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;b=c[2276085]&d;d=b&16777215;e=c[2112932]|0;f=c[e+((d>>>10|16384)<<2)>>2]|0;if(f>>>0>9){a[f+(b&1023^1)|0]=0;gGz(9104300,0,16);return}else{gg[c[e+196648+(f<<2)>>2]&4095](d,0);gGz(9104300,0,16);return}}function E6(){var b=0,d=0,e=0,f=0;b=c[2276054]|0;c[2276054]=b+2;d=c[2276085]&b;b=d&16777215;e=c[2112932]|0;f=c[e+((b>>>10|16384)<<2)>>2]|0;if(f>>>0>9){a[f+(d&1023^1)|0]=0;gGz(9104300,0,16);return}else{gg[c[e+196648+(f<<2)>>2]&4095](b,0);gGz(9104300,0,16);return}}function E7(){var b=0,d=0,e=0,f=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;b=c[2276085]&d;d=b&16777215;e=c[2112932]|0;f=c[e+((d>>>10|16384)<<2)>>2]|0;if(f>>>0>9){a[f+(b&1023^1)|0]=0;gGz(9104300,0,16);return}else{gg[c[e+196648+(f<<2)>>2]&4095](d,0);gGz(9104300,0,16);return}}function E8(){var b=0,d=0,e=0,f=0;b=(c[2276054]|0)-2|0;c[2276054]=b;d=c[2276085]&b;b=d&16777215;e=c[2112932]|0;f=c[e+((b>>>10|16384)<<2)>>2]|0;if(f>>>0>9){a[f+(d&1023^1)|0]=0;gGz(9104300,0,16);return}else{gg[c[e+196648+(f<<2)>>2]&4095](b,0);gGz(9104300,0,16);return}}function E9(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=(h>>>((g<<3&16^16)>>>0)<<16>>16)+b&c[2276085];b=m&16777215;g=c[2112932]|0;h=c[g+((b>>>10|16384)<<2)>>2]|0;if(h>>>0>9){a[h+(m&1023^1)|0]=0;gGz(9104300,0,16);return}else{gg[c[g+196648+(h<<2)>>2]&4095](b,0);gGz(9104300,0,16);return}}function Fa(){var b=0,d=0,e=0,f=0;b=xw(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;d=c[2276085]&b;b=d&16777215;e=c[2112932]|0;f=c[e+((b>>>10|16384)<<2)>>2]|0;if(f>>>0>9){a[f+(d&1023^1)|0]=0;gGz(9104300,0,16);return}else{gg[c[e+196648+(f<<2)>>2]&4095](b,0);gGz(9104300,0,16);return}}function Fb(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)<<16>>16&c[2276085];f=l&16777215;g=c[2112932]|0;m=c[g+((f>>>10|16384)<<2)>>2]|0;if(m>>>0>9){a[m+(l&1023^1)|0]=0;gGz(9104300,0,16);return}else{gg[c[g+196648+(m<<2)>>2]&4095](f,0);gGz(9104300,0,16);return}}function Fc(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[2276085]&q;q=r&16777215;t=c[2112932]|0;h=c[t+((q>>>10|16384)<<2)>>2]|0;if(h>>>0>9){a[h+(r&1023^1)|0]=0;gGz(9104300,0,16);return}else{gg[c[t+196648+(h<<2)>>2]&4095](q,0);gGz(9104300,0,16);return}}function Fd(){var a=0;a=9104156+((c[2276069]&7)<<2)|0;c[a>>2]=c[a>>2]&-65536;gGz(9104300,0,16);return}function Fe(){var b=0,d=0,e=0,f=0,g=0;b=c[2276085]&c[9104156+((c[2276069]&7|8)<<2)>>2];d=b&16777215;e=c[2112932]|0;f=c[e+((d>>>10|16384)<<2)>>2]|0;if(f>>>0>9){g=b&1023;a[f+g|0]=0;a[f+(g+1)|0]=0;gGz(9104300,0,16);return}else{gg[c[e+196728+(f<<2)>>2]&4095](d,0);gGz(9104300,0,16);return}}function Ff(){var b=0,d=0,e=0,f=0,g=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+2;b=c[2276085]&d;d=b&16777215;e=c[2112932]|0;f=c[e+((d>>>10|16384)<<2)>>2]|0;if(f>>>0>9){g=b&1023;a[f+g|0]=0;a[f+(g+1)|0]=0;gGz(9104300,0,16);return}else{gg[c[e+196728+(f<<2)>>2]&4095](d,0);gGz(9104300,0,16);return}}function Fg(){var b=0,d=0,e=0,f=0,g=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=(c[b>>2]|0)-2|0;c[b>>2]=d;b=c[2276085]&d;d=b&16777215;e=c[2112932]|0;f=c[e+((d>>>10|16384)<<2)>>2]|0;if(f>>>0>9){g=b&1023;a[f+g|0]=0;a[f+(g+1)|0]=0;gGz(9104300,0,16);return}else{gg[c[e+196728+(f<<2)>>2]&4095](d,0);gGz(9104300,0,16);return}}function Fh(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=(h>>>((g<<3&16^16)>>>0)<<16>>16)+b&c[2276085];b=m&16777215;g=c[2112932]|0;h=c[g+((b>>>10|16384)<<2)>>2]|0;if(h>>>0>9){n=m&1023;a[h+n|0]=0;a[h+(n+1)|0]=0;gGz(9104300,0,16);return}else{gg[c[g+196728+(h<<2)>>2]&4095](b,0);gGz(9104300,0,16);return}}function Fi(){var b=0,d=0,e=0,f=0,g=0;b=xw(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;d=c[2276085]&b;b=d&16777215;e=c[2112932]|0;f=c[e+((b>>>10|16384)<<2)>>2]|0;if(f>>>0>9){g=d&1023;a[f+g|0]=0;a[f+(g+1)|0]=0;gGz(9104300,0,16);return}else{gg[c[e+196728+(f<<2)>>2]&4095](b,0);gGz(9104300,0,16);return}}function Fj(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)<<16>>16&c[2276085];f=l&16777215;g=c[2112932]|0;m=c[g+((f>>>10|16384)<<2)>>2]|0;if(m>>>0>9){b=l&1023;a[m+b|0]=0;a[m+(b+1)|0]=0;gGz(9104300,0,16);return}else{gg[c[g+196728+(m<<2)>>2]&4095](f,0);gGz(9104300,0,16);return}}function Fk(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[2276085]&q;q=r&16777215;t=c[2112932]|0;h=c[t+((q>>>10|16384)<<2)>>2]|0;if(h>>>0>9){s=r&1023;a[h+s|0]=0;a[h+(s+1)|0]=0;gGz(9104300,0,16);return}else{gg[c[t+196728+(h<<2)>>2]&4095](q,0);gGz(9104300,0,16);return}}function Fl(){c[9104156+((c[2276069]&7)<<2)>>2]=0;gGz(9104300,0,16);return}function Fm(){var b=0,d=0,e=0,f=0,g=0;b=c[2276085]&c[9104156+((c[2276069]&7|8)<<2)>>2];d=b&16777215;e=c[2112932]|0;f=c[e+((d>>>10|16384)<<2)>>2]|0;if(f>>>0>9){g=b&1023;a[f+g|0]=0;a[f+(g+1)|0]=0;a[f+(g+2)|0]=0;a[f+(g+3)|0]=0;gGz(9104300,0,16);return}else{gg[c[e+196808+(f<<2)>>2]&4095](d,0);gGz(9104300,0,16);return}}function Fn(){var b=0,d=0,e=0,f=0,g=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+4;b=c[2276085]&d;d=b&16777215;e=c[2112932]|0;f=c[e+((d>>>10|16384)<<2)>>2]|0;if(f>>>0>9){g=b&1023;a[f+g|0]=0;a[f+(g+1)|0]=0;a[f+(g+2)|0]=0;a[f+(g+3)|0]=0;gGz(9104300,0,16);return}else{gg[c[e+196808+(f<<2)>>2]&4095](d,0);gGz(9104300,0,16);return}}function Fo(){var b=0,d=0,e=0,f=0,g=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=(c[b>>2]|0)-4|0;c[b>>2]=d;b=c[2276085]&d;d=b&16777215;e=c[2112932]|0;f=c[e+((d>>>10|16384)<<2)>>2]|0;if(f>>>0>9){g=b&1023;a[f+g|0]=0;a[f+(g+1)|0]=0;a[f+(g+2)|0]=0;a[f+(g+3)|0]=0;gGz(9104300,0,16);return}else{gg[c[e+196808+(f<<2)>>2]&4095](d,0);gGz(9104300,0,16);return}}function Fp(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=(h>>>((g<<3&16^16)>>>0)<<16>>16)+b&c[2276085];b=m&16777215;g=c[2112932]|0;h=c[g+((b>>>10|16384)<<2)>>2]|0;if(h>>>0>9){n=m&1023;a[h+n|0]=0;a[h+(n+1)|0]=0;a[h+(n+2)|0]=0;a[h+(n+3)|0]=0;gGz(9104300,0,16);return}else{gg[c[g+196808+(h<<2)>>2]&4095](b,0);gGz(9104300,0,16);return}}function Fq(){var b=0,d=0,e=0,f=0,g=0;b=xw(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;d=c[2276085]&b;b=d&16777215;e=c[2112932]|0;f=c[e+((b>>>10|16384)<<2)>>2]|0;if(f>>>0>9){g=d&1023;a[f+g|0]=0;a[f+(g+1)|0]=0;a[f+(g+2)|0]=0;a[f+(g+3)|0]=0;gGz(9104300,0,16);return}else{gg[c[e+196808+(f<<2)>>2]&4095](b,0);gGz(9104300,0,16);return}}function Fr(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)<<16>>16&c[2276085];f=l&16777215;g=c[2112932]|0;m=c[g+((f>>>10|16384)<<2)>>2]|0;if(m>>>0>9){b=l&1023;a[m+b|0]=0;a[m+(b+1)|0]=0;a[m+(b+2)|0]=0;a[m+(b+3)|0]=0;gGz(9104300,0,16);return}else{gg[c[g+196808+(m<<2)>>2]&4095](f,0);gGz(9104300,0,16);return}}function Fs(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[2276085]&q;q=r&16777215;t=c[2112932]|0;h=c[t+((q>>>10|16384)<<2)>>2]|0;if(h>>>0>9){s=r&1023;a[h+s|0]=0;a[h+(s+1)|0]=0;a[h+(s+2)|0]=0;a[h+(s+3)|0]=0;gGz(9104300,0,16);return}else{gg[c[t+196808+(h<<2)>>2]&4095](q,0);gGz(9104300,0,16);return}}function Ft(){var a=0,b=0,d=0,e=0,f=0;a=c[2276069]|0;b=c[9104156+((a&7)<<2)>>2]|0;d=b&255;e=c[9104156+((a>>>9&7)<<2)>>2]|0;a=e&255;f=a-d|0;c[2276075]=f;c[2276076]=e-b&255;c[2276077]=(f^e)&(a^d);c[2276078]=f;return}function Fu(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=c[2276069]|0;d=c[2276085]&c[9104156+((b&7|8)<<2)>>2];e=d&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=a[g+(d&1023^1)|0]|0;i=b}else{b=gj[c[f+196608+(g<<2)>>2]&4095](e)|0;h=b;i=c[2276069]|0}b=h&255;h=c[9104156+((i>>>9&7)<<2)>>2]|0;i=h&255;e=i-b|0;c[2276075]=e;c[2276076]=h-b&255;c[2276077]=(e^h)&(i^b);c[2276078]=e;return}function Fv(){var b=0,d=0,e=0,f=0,g=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;b=c[2276085]&d;d=b&16777215;e=c[2112932]|0;f=c[e+(d>>>10<<2)>>2]|0;if(f>>>0>9){g=a[f+(b&1023^1)|0]|0}else{g=gj[c[e+196608+(f<<2)>>2]&4095](d)|0}d=g&255;g=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;f=g&255;e=f-d|0;c[2276075]=e;c[2276076]=g-d&255;c[2276077]=(e^g)&(f^d);c[2276078]=e;return}function Fw(){var b=0,d=0,e=0,f=0,g=0;b=c[2276054]|0;c[2276054]=b+2;d=c[2276085]&b;b=d&16777215;e=c[2112932]|0;f=c[e+(b>>>10<<2)>>2]|0;if(f>>>0>9){g=a[f+(d&1023^1)|0]|0}else{g=gj[c[e+196608+(f<<2)>>2]&4095](b)|0}b=g&255;g=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;f=g&255;e=f-b|0;c[2276075]=e;c[2276076]=g-b&255;c[2276077]=(e^g)&(f^b);c[2276078]=e;return}function Fx(){var b=0,d=0,e=0,f=0,g=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;b=c[2276085]&d;d=b&16777215;e=c[2112932]|0;f=c[e+(d>>>10<<2)>>2]|0;if(f>>>0>9){g=a[f+(b&1023^1)|0]|0}else{g=gj[c[e+196608+(f<<2)>>2]&4095](d)|0}d=g&255;g=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;f=g&255;e=f-d|0;c[2276075]=e;c[2276076]=g-d&255;c[2276077]=(e^g)&(f^d);c[2276078]=e;return}function Fy(){var b=0,d=0,e=0,f=0,g=0;b=(c[2276054]|0)-2|0;c[2276054]=b;d=c[2276085]&b;b=d&16777215;e=c[2112932]|0;f=c[e+(b>>>10<<2)>>2]|0;if(f>>>0>9){g=a[f+(d&1023^1)|0]|0}else{g=gj[c[e+196608+(f<<2)>>2]&4095](b)|0}b=g&255;g=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;f=g&255;e=f-b|0;c[2276075]=e;c[2276076]=g-b&255;c[2276077]=(e^g)&(f^b);c[2276078]=e;return}function Fz(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=(h>>>((g<<3&16^16)>>>0)<<16>>16)+b&c[2276085];b=m&16777215;g=c[2112932]|0;h=c[g+(b>>>10<<2)>>2]|0;if(h>>>0>9){o=a[h+(m&1023^1)|0]|0;p=o&255;q=c[2276069]|0;r=q>>>9;s=r&7;t=9104156+(s<<2)|0;u=c[t>>2]|0;v=u&255;w=v-p|0;c[2276075]=w;x=u-p|0;y=x&255;c[2276076]=y;z=v^p;A=w^u;B=A&z;c[2276077]=B;c[2276078]=w;return}else{o=gj[c[g+196608+(h<<2)>>2]&4095](b)|0;p=o&255;q=c[2276069]|0;r=q>>>9;s=r&7;t=9104156+(s<<2)|0;u=c[t>>2]|0;v=u&255;w=v-p|0;c[2276075]=w;x=u-p|0;y=x&255;c[2276076]=y;z=v^p;A=w^u;B=A&z;c[2276077]=B;c[2276078]=w;return}}function FA(){var b=0,d=0,e=0,f=0,g=0;b=xw(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;d=c[2276085]&b;b=d&16777215;e=c[2112932]|0;f=c[e+(b>>>10<<2)>>2]|0;if(f>>>0>9){g=a[f+(d&1023^1)|0]|0}else{g=gj[c[e+196608+(f<<2)>>2]&4095](b)|0}b=g&255;g=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;f=g&255;e=f-b|0;c[2276075]=e;c[2276076]=g-b&255;c[2276077]=(e^g)&(f^b);c[2276078]=e;return}function FB(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)<<16>>16&c[2276085];f=l&16777215;g=c[2112932]|0;m=c[g+(f>>>10<<2)>>2]|0;if(m>>>0>9){n=a[m+(l&1023^1)|0]|0;o=n&255;p=c[2276069]|0;q=p>>>9;r=q&7;s=9104156+(r<<2)|0;t=c[s>>2]|0;u=t&255;v=u-o|0;c[2276075]=v;w=t-o|0;x=w&255;c[2276076]=x;y=u^o;z=v^t;A=z&y;c[2276077]=A;c[2276078]=v;return}else{n=gj[c[g+196608+(m<<2)>>2]&4095](f)|0;o=n&255;p=c[2276069]|0;q=p>>>9;r=q&7;s=9104156+(r<<2)|0;t=c[s>>2]|0;u=t&255;v=u-o|0;c[2276075]=v;w=t-o|0;x=w&255;c[2276076]=x;y=u^o;z=v^t;A=z&y;c[2276077]=A;c[2276078]=v;return}}function FC(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[2276085]&q;q=r&16777215;t=c[2112932]|0;h=c[t+(q>>>10<<2)>>2]|0;if(h>>>0>9){u=a[h+(r&1023^1)|0]|0;v=u&255;w=c[2276069]|0;x=w>>>9;y=x&7;z=9104156+(y<<2)|0;A=c[z>>2]|0;B=A&255;C=B-v|0;c[2276075]=C;D=A-v|0;E=D&255;c[2276076]=E;F=B^v;G=C^A;H=G&F;c[2276077]=H;c[2276078]=C;return}else{u=gj[c[t+196608+(h<<2)>>2]&4095](q)|0;v=u&255;w=c[2276069]|0;x=w>>>9;y=x&7;z=9104156+(y<<2)|0;A=c[z>>2]|0;B=A&255;C=B-v|0;c[2276075]=C;D=A-v|0;E=D&255;c[2276076]=E;F=B^v;G=C^A;H=G&F;c[2276077]=H;c[2276078]=C;return}}function FD(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{k=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=k;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=(g>>>((f<<3&16^16)>>>0)<<16>>16)+b|0;b=l&16777215;f=c[2112932]|0;g=c[f+((b>>>10|32768)<<2)>>2]|0;if(g>>>0>9){n=a[g+(l&1023^1)|0]|0;o=n&255;p=c[2276069]|0;q=p>>>9;r=q&7;s=9104156+(r<<2)|0;t=c[s>>2]|0;u=t&255;v=u-o|0;c[2276075]=v;w=t-o|0;x=w&255;c[2276076]=x;y=u^o;z=v^t;A=z&y;c[2276077]=A;c[2276078]=v;return}else{n=gj[c[f+196608+(g<<2)>>2]&4095](b)|0;o=n&255;p=c[2276069]|0;q=p>>>9;r=q&7;s=9104156+(r<<2)|0;t=c[s>>2]|0;u=t&255;v=u-o|0;c[2276075]=v;w=t-o|0;x=w&255;c[2276076]=x;y=u^o;z=v^t;A=z&y;c[2276077]=A;c[2276078]=v;return}}function FE(){var b=0,d=0,e=0,f=0,g=0;b=xw(c[2276056]|0)|0;d=b&16777215;e=c[2112932]|0;f=c[e+((d>>>10|32768)<<2)>>2]|0;if(f>>>0>9){g=a[f+(b&1023^1)|0]|0}else{g=gj[c[e+196608+(f<<2)>>2]&4095](d)|0}d=g&255;g=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;f=g&255;e=f-d|0;c[2276075]=e;c[2276076]=g-d&255;c[2276077]=(e^g)&(f^d);c[2276078]=e;return}function FF(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=f>>>((e<<3&16^16)>>>0);e=k&255;f=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;l=f&255;a=l-e|0;c[2276075]=a;c[2276076]=f-k&255;c[2276077]=(a^f)&(e^l);c[2276078]=a;return}function FG(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[2276069]|0;b=c[9104156+((a&7)<<2)>>2]|0;d=b&65535;e=c[9104156+((a>>>9&7)<<2)>>2]|0;a=e&65535;f=a-d|0;g=f>>>8;c[2276075]=g;c[2276076]=e-b&65535;c[2276077]=((f^e)&(a^d))>>>8;c[2276078]=g;return}function FH(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[2276069]|0;b=c[9104156+((a&7|8)<<2)>>2]|0;d=b&65535;e=c[9104156+((a>>>9&7)<<2)>>2]|0;a=e&65535;f=a-d|0;g=f>>>8;c[2276075]=g;c[2276076]=e-b&65535;c[2276077]=((f^e)&(a^d))>>>8;c[2276078]=g;return}function FI(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0;a=c[2276069]|0;b=c[2276085]&c[9104156+((a&7|8)<<2)>>2];e=b&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=b&1023;i=(d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0);j=a}else{a=gj[c[f+196688+(g<<2)>>2]&4095](e)|0;i=a;j=c[2276069]|0}a=i&65535;i=c[9104156+((j>>>9&7)<<2)>>2]|0;j=i&65535;e=j-a|0;g=e>>>8;c[2276075]=g;c[2276076]=i-a&65535;c[2276077]=((e^i)&(j^a))>>>8;c[2276078]=g;return}function FJ(){var a=0,b=0,e=0,f=0,g=0,h=0;a=9104156+((c[2276069]&7|8)<<2)|0;b=c[a>>2]|0;c[a>>2]=b+2;a=c[2276085]&b;b=a&16777215;e=c[2112932]|0;f=c[e+(b>>>10<<2)>>2]|0;if(f>>>0>9){g=a&1023;h=(d[f+(g+1)|0]|0)<<8|(d[f+g|0]|0)}else{h=gj[c[e+196688+(f<<2)>>2]&4095](b)|0}b=h&65535;h=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;f=h&65535;e=f-b|0;g=e>>>8;c[2276075]=g;c[2276076]=h-b&65535;c[2276077]=((e^h)&(f^b))>>>8;c[2276078]=g;return}function FK(){var a=0,b=0,e=0,f=0,g=0,h=0;a=9104156+((c[2276069]&7|8)<<2)|0;b=(c[a>>2]|0)-2|0;c[a>>2]=b;a=c[2276085]&b;b=a&16777215;e=c[2112932]|0;f=c[e+(b>>>10<<2)>>2]|0;if(f>>>0>9){g=a&1023;h=(d[f+(g+1)|0]|0)<<8|(d[f+g|0]|0)}else{h=gj[c[e+196688+(f<<2)>>2]&4095](b)|0}b=h&65535;h=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;f=h&65535;e=f-b|0;g=e>>>8;c[2276075]=g;c[2276076]=h-b&65535;c[2276077]=((e^h)&(f^b))>>>8;c[2276078]=g;return}function FL(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;a=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=(g>>>((f<<3&16^16)>>>0)<<16>>16)+a&c[2276085];a=l&16777215;f=c[2112932]|0;g=c[f+(a>>>10<<2)>>2]|0;if(g>>>0>9){m=l&1023;n=(d[g+(m+1)|0]|0)<<8|(d[g+m|0]|0);o=n&65535;p=c[2276069]|0;q=p>>>9;r=q&7;s=9104156+(r<<2)|0;t=c[s>>2]|0;u=t&65535;v=u-o|0;w=v>>>8;c[2276075]=w;x=t-o|0;y=x&65535;c[2276076]=y;z=u^o;A=v^t;B=A&z;C=B>>>8;c[2276077]=C;c[2276078]=w;return}else{n=gj[c[f+196688+(g<<2)>>2]&4095](a)|0;o=n&65535;p=c[2276069]|0;q=p>>>9;r=q&7;s=9104156+(r<<2)|0;t=c[s>>2]|0;u=t&65535;v=u-o|0;w=v>>>8;c[2276075]=w;x=t-o|0;y=x&65535;c[2276076]=y;z=u^o;A=v^t;B=A&z;C=B>>>8;c[2276077]=C;c[2276078]=w;return}}function FM(){var a=0,b=0,e=0,f=0,g=0,h=0;a=xw(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;b=c[2276085]&a;a=b&16777215;e=c[2112932]|0;f=c[e+(a>>>10<<2)>>2]|0;if(f>>>0>9){g=b&1023;h=(d[f+(g+1)|0]|0)<<8|(d[f+g|0]|0)}else{h=gj[c[e+196688+(f<<2)>>2]&4095](a)|0}a=h&65535;h=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;f=h&65535;e=f-a|0;g=e>>>8;c[2276075]=g;c[2276076]=h-a&65535;c[2276077]=((e^h)&(f^a))>>>8;c[2276078]=g;return}function FN(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=f>>>((e<<3&16^16)>>>0)<<16>>16&c[2276085];e=k&16777215;f=c[2112932]|0;l=c[f+(e>>>10<<2)>>2]|0;if(l>>>0>9){a=k&1023;m=(d[l+(a+1)|0]|0)<<8|(d[l+a|0]|0);n=m&65535;o=c[2276069]|0;p=o>>>9;q=p&7;r=9104156+(q<<2)|0;s=c[r>>2]|0;t=s&65535;u=t-n|0;v=u>>>8;c[2276075]=v;w=s-n|0;x=w&65535;c[2276076]=x;y=t^n;z=u^s;A=z&y;B=A>>>8;c[2276077]=B;c[2276078]=v;return}else{m=gj[c[f+196688+(l<<2)>>2]&4095](e)|0;n=m&65535;o=c[2276069]|0;p=o>>>9;q=p&7;r=9104156+(q<<2)|0;s=c[r>>2]|0;t=s&65535;u=t-n|0;v=u>>>8;c[2276075]=v;w=s-n|0;x=w&65535;c[2276076]=x;y=t^n;z=u^s;A=z&y;B=A>>>8;c[2276077]=B;c[2276078]=v;return}}function FO(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=b;g=c[2276084]|0}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=o;g=m}m=e+2|0;c[2276056]=m;e=m&-4;if((e|0)==(f|0)){p=g;q=m}else{c[2276083]=e;f=c[2276085]&e;e=f&16777212;o=c[2112932]|0;n=c[o+((e>>>10|32768)<<2)>>2]|0;if(n>>>0>9){b=f&1020;r=(d[n+(b|3)|0]|0)<<8|(d[n+(b|2)|0]|0)|((d[n+(b|1)|0]|0)<<8|(d[n+b|0]|0))<<16;s=m}else{m=gj[c[o+196768+(n<<2)>>2]&4095](e)|0;r=m;s=c[2276056]|0}c[2276084]=r;p=r>>>16|g<<16;q=s}c[2276056]=q+2;q=c[2276085]&p;p=q&16777215;s=c[2112932]|0;g=c[s+(p>>>10<<2)>>2]|0;if(g>>>0>9){r=q&1023;t=(d[g+(r+1)|0]|0)<<8|(d[g+r|0]|0);u=t&65535;v=c[2276069]|0;w=v>>>9;x=w&7;y=9104156+(x<<2)|0;z=c[y>>2]|0;A=z&65535;B=A-u|0;C=B>>>8;c[2276075]=C;D=z-u|0;E=D&65535;c[2276076]=E;F=A^u;G=B^z;H=G&F;I=H>>>8;c[2276077]=I;c[2276078]=C;return}else{t=gj[c[s+196688+(g<<2)>>2]&4095](p)|0;u=t&65535;v=c[2276069]|0;w=v>>>9;x=w&7;y=9104156+(x<<2)|0;z=c[y>>2]|0;A=z&65535;B=A-u|0;C=B>>>8;c[2276075]=C;D=z-u|0;E=D&65535;c[2276076]=E;F=A^u;G=B^z;H=G&F;I=H>>>8;c[2276077]=I;c[2276078]=C;return}}function FP(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{j=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=j;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=(f>>>((e<<3&16^16)>>>0)<<16>>16)+a|0;a=k&16777215;e=c[2112932]|0;f=c[e+((a>>>10|32768)<<2)>>2]|0;if(f>>>0>9){l=k&1023;m=(d[f+(l+1)|0]|0)<<8|(d[f+l|0]|0);n=m&65535;o=c[2276069]|0;p=o>>>9;q=p&7;r=9104156+(q<<2)|0;s=c[r>>2]|0;t=s&65535;u=t-n|0;v=u>>>8;c[2276075]=v;w=s-n|0;x=w&65535;c[2276076]=x;y=t^n;z=u^s;A=z&y;B=A>>>8;c[2276077]=B;c[2276078]=v;return}else{m=gj[c[e+196688+(f<<2)>>2]&4095](a)|0;n=m&65535;o=c[2276069]|0;p=o>>>9;q=p&7;r=9104156+(q<<2)|0;s=c[r>>2]|0;t=s&65535;u=t-n|0;v=u>>>8;c[2276075]=v;w=s-n|0;x=w&65535;c[2276076]=x;y=t^n;z=u^s;A=z&y;B=A>>>8;c[2276077]=B;c[2276078]=v;return}}function FQ(){var a=0,b=0,e=0,f=0,g=0,h=0;a=xw(c[2276056]|0)|0;b=a&16777215;e=c[2112932]|0;f=c[e+((b>>>10|32768)<<2)>>2]|0;if(f>>>0>9){g=a&1023;h=(d[f+(g+1)|0]|0)<<8|(d[f+g|0]|0)}else{h=gj[c[e+196688+(f<<2)>>2]&4095](b)|0}b=h&65535;h=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;f=h&65535;e=f-b|0;g=e>>>8;c[2276075]=g;c[2276076]=h-b&65535;c[2276077]=((e^h)&(f^b))>>>8;c[2276078]=g;return}function FR(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=f>>>((e<<3&16^16)>>>0);e=k&65535;f=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;l=f&65535;a=l-e|0;b=a>>>8;c[2276075]=b;c[2276076]=f-k&65535;c[2276077]=((a^f)&(e^l))>>>8;c[2276078]=b;return}function FS(){var a=0,b=0,d=0;a=c[2276069]|0;b=c[9104156+((a&7)<<2)>>2]|0;d=c[9104156+((a>>>9&7)<<2)>>2]|0;a=d-b|0;c[2276075]=a>>>24;c[2276076]=a;c[2276077]=((a^d)&(d^b))>>>24;c[2276078]=((a|b)&(d^-8388608)|a&b)>>>23;return}function FT(){var a=0,b=0,d=0;a=c[2276069]|0;b=c[9104156+((a&7|8)<<2)>>2]|0;d=c[9104156+((a>>>9&7)<<2)>>2]|0;a=d-b|0;c[2276075]=a>>>24;c[2276076]=a;c[2276077]=((a^d)&(d^b))>>>24;c[2276078]=((a|b)&(d^-8388608)|a&b)>>>23;return}function FU(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0;a=c[2276069]|0;b=c[2276085]&c[9104156+((a&7|8)<<2)>>2];e=b&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=b&1023;i=(d[g+(h+3)|0]|0)<<8|(d[g+(h+2)|0]|0)|((d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0))<<16;j=a}else{a=gj[c[f+196768+(g<<2)>>2]&4095](e)|0;i=a;j=c[2276069]|0}a=c[9104156+((j>>>9&7)<<2)>>2]|0;j=a-i|0;c[2276075]=j>>>24;c[2276076]=j;c[2276077]=((j^a)&(a^i))>>>24;c[2276078]=((j|i)&(a^-8388608)|j&i)>>>23;return}function FV(){var a=0,b=0,e=0,f=0,g=0,h=0;a=9104156+((c[2276069]&7|8)<<2)|0;b=c[a>>2]|0;c[a>>2]=b+4;a=c[2276085]&b;b=a&16777215;e=c[2112932]|0;f=c[e+(b>>>10<<2)>>2]|0;if(f>>>0>9){g=a&1023;h=(d[f+(g+3)|0]|0)<<8|(d[f+(g+2)|0]|0)|((d[f+(g+1)|0]|0)<<8|(d[f+g|0]|0))<<16}else{h=gj[c[e+196768+(f<<2)>>2]&4095](b)|0}b=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;f=b-h|0;c[2276075]=f>>>24;c[2276076]=f;c[2276077]=((f^b)&(b^h))>>>24;c[2276078]=((f|h)&(b^-8388608)|f&h)>>>23;return}function FW(){var a=0,b=0,e=0,f=0,g=0,h=0;a=9104156+((c[2276069]&7|8)<<2)|0;b=(c[a>>2]|0)-4|0;c[a>>2]=b;a=c[2276085]&b;b=a&16777215;e=c[2112932]|0;f=c[e+(b>>>10<<2)>>2]|0;if(f>>>0>9){g=a&1023;h=(d[f+(g+3)|0]|0)<<8|(d[f+(g+2)|0]|0)|((d[f+(g+1)|0]|0)<<8|(d[f+g|0]|0))<<16}else{h=gj[c[e+196768+(f<<2)>>2]&4095](b)|0}b=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;f=b-h|0;c[2276075]=f>>>24;c[2276076]=f;c[2276077]=((f^b)&(b^h))>>>24;c[2276078]=((f|h)&(b^-8388608)|f&h)>>>23;return}function FX(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;a=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=(g>>>((f<<3&16^16)>>>0)<<16>>16)+a&c[2276085];a=l&16777215;f=c[2112932]|0;g=c[f+(a>>>10<<2)>>2]|0;if(g>>>0>9){m=l&1023;n=(d[g+(m+3)|0]|0)<<8|(d[g+(m+2)|0]|0)|((d[g+(m+1)|0]|0)<<8|(d[g+m|0]|0))<<16;o=c[2276069]|0;p=o>>>9;q=p&7;r=9104156+(q<<2)|0;s=c[r>>2]|0;t=s-n|0;u=t>>>24;c[2276075]=u;c[2276076]=t;v=s^n;w=t^s;x=w&v;y=x>>>24;c[2276077]=y;z=t&n;A=s^-8388608;B=t|n;C=B&A;D=C|z;E=D>>>23;c[2276078]=E;return}else{n=gj[c[f+196768+(g<<2)>>2]&4095](a)|0;o=c[2276069]|0;p=o>>>9;q=p&7;r=9104156+(q<<2)|0;s=c[r>>2]|0;t=s-n|0;u=t>>>24;c[2276075]=u;c[2276076]=t;v=s^n;w=t^s;x=w&v;y=x>>>24;c[2276077]=y;z=t&n;A=s^-8388608;B=t|n;C=B&A;D=C|z;E=D>>>23;c[2276078]=E;return}}function FY(){var a=0,b=0,e=0,f=0,g=0,h=0;a=xw(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;b=c[2276085]&a;a=b&16777215;e=c[2112932]|0;f=c[e+(a>>>10<<2)>>2]|0;if(f>>>0>9){g=b&1023;h=(d[f+(g+3)|0]|0)<<8|(d[f+(g+2)|0]|0)|((d[f+(g+1)|0]|0)<<8|(d[f+g|0]|0))<<16}else{h=gj[c[e+196768+(f<<2)>>2]&4095](a)|0}a=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;f=a-h|0;c[2276075]=f>>>24;c[2276076]=f;c[2276077]=((f^a)&(a^h))>>>24;c[2276078]=((f|h)&(a^-8388608)|f&h)>>>23;return}function FZ(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=f>>>((e<<3&16^16)>>>0)<<16>>16&c[2276085];e=k&16777215;f=c[2112932]|0;l=c[f+(e>>>10<<2)>>2]|0;if(l>>>0>9){a=k&1023;m=(d[l+(a+3)|0]|0)<<8|(d[l+(a+2)|0]|0)|((d[l+(a+1)|0]|0)<<8|(d[l+a|0]|0))<<16;n=c[2276069]|0;o=n>>>9;p=o&7;q=9104156+(p<<2)|0;r=c[q>>2]|0;s=r-m|0;t=s>>>24;c[2276075]=t;c[2276076]=s;u=r^m;v=s^r;w=v&u;x=w>>>24;c[2276077]=x;y=s&m;z=r^-8388608;A=s|m;B=A&z;C=B|y;D=C>>>23;c[2276078]=D;return}else{m=gj[c[f+196768+(l<<2)>>2]&4095](e)|0;n=c[2276069]|0;o=n>>>9;p=o&7;q=9104156+(p<<2)|0;r=c[q>>2]|0;s=r-m|0;t=s>>>24;c[2276075]=t;c[2276076]=s;u=r^m;v=s^r;w=v&u;x=w>>>24;c[2276077]=x;y=s&m;z=r^-8388608;A=s|m;B=A&z;C=B|y;D=C>>>23;c[2276078]=D;return}}function F_(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=b;g=c[2276084]|0}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=o;g=m}m=e+2|0;c[2276056]=m;e=m&-4;if((e|0)==(f|0)){p=g;q=m}else{c[2276083]=e;f=c[2276085]&e;e=f&16777212;o=c[2112932]|0;n=c[o+((e>>>10|32768)<<2)>>2]|0;if(n>>>0>9){b=f&1020;r=(d[n+(b|3)|0]|0)<<8|(d[n+(b|2)|0]|0)|((d[n+(b|1)|0]|0)<<8|(d[n+b|0]|0))<<16;s=m}else{m=gj[c[o+196768+(n<<2)>>2]&4095](e)|0;r=m;s=c[2276056]|0}c[2276084]=r;p=r>>>16|g<<16;q=s}c[2276056]=q+2;q=c[2276085]&p;p=q&16777215;s=c[2112932]|0;g=c[s+(p>>>10<<2)>>2]|0;if(g>>>0>9){r=q&1023;t=(d[g+(r+3)|0]|0)<<8|(d[g+(r+2)|0]|0)|((d[g+(r+1)|0]|0)<<8|(d[g+r|0]|0))<<16;u=c[2276069]|0;v=u>>>9;w=v&7;x=9104156+(w<<2)|0;y=c[x>>2]|0;z=y-t|0;A=z>>>24;c[2276075]=A;c[2276076]=z;B=y^t;C=z^y;D=C&B;E=D>>>24;c[2276077]=E;F=z&t;G=y^-8388608;H=z|t;I=H&G;J=I|F;K=J>>>23;c[2276078]=K;return}else{t=gj[c[s+196768+(g<<2)>>2]&4095](p)|0;u=c[2276069]|0;v=u>>>9;w=v&7;x=9104156+(w<<2)|0;y=c[x>>2]|0;z=y-t|0;A=z>>>24;c[2276075]=A;c[2276076]=z;B=y^t;C=z^y;D=C&B;E=D>>>24;c[2276077]=E;F=z&t;G=y^-8388608;H=z|t;I=H&G;J=I|F;K=J>>>23;c[2276078]=K;return}}function F$(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{j=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=j;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=(f>>>((e<<3&16^16)>>>0)<<16>>16)+a|0;a=k&16777215;e=c[2112932]|0;f=c[e+((a>>>10|32768)<<2)>>2]|0;if(f>>>0>9){l=k&1023;m=(d[f+(l+3)|0]|0)<<8|(d[f+(l+2)|0]|0)|((d[f+(l+1)|0]|0)<<8|(d[f+l|0]|0))<<16;n=c[2276069]|0;o=n>>>9;p=o&7;q=9104156+(p<<2)|0;r=c[q>>2]|0;s=r-m|0;t=s>>>24;c[2276075]=t;c[2276076]=s;u=r^m;v=s^r;w=v&u;x=w>>>24;c[2276077]=x;y=s&m;z=r^-8388608;A=s|m;B=A&z;C=B|y;D=C>>>23;c[2276078]=D;return}else{m=gj[c[e+196768+(f<<2)>>2]&4095](a)|0;n=c[2276069]|0;o=n>>>9;p=o&7;q=9104156+(p<<2)|0;r=c[q>>2]|0;s=r-m|0;t=s>>>24;c[2276075]=t;c[2276076]=s;u=r^m;v=s^r;w=v&u;x=w>>>24;c[2276077]=x;y=s&m;z=r^-8388608;A=s|m;B=A&z;C=B|y;D=C>>>23;c[2276078]=D;return}}function F0(){var a=0,b=0,e=0,f=0,g=0,h=0;a=xw(c[2276056]|0)|0;b=a&16777215;e=c[2112932]|0;f=c[e+((b>>>10|32768)<<2)>>2]|0;if(f>>>0>9){g=a&1023;h=(d[f+(g+3)|0]|0)<<8|(d[f+(g+2)|0]|0)|((d[f+(g+1)|0]|0)<<8|(d[f+g|0]|0))<<16}else{h=gj[c[e+196768+(f<<2)>>2]&4095](b)|0}b=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;f=b-h|0;c[2276075]=f>>>24;c[2276076]=f;c[2276077]=((f^b)&(b^h))>>>24;c[2276078]=((f|h)&(b^-8388608)|f&h)>>>23;return}function F1(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=b;g=c[2276084]|0}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=o;g=m}m=e+2|0;c[2276056]=m;e=m&-4;if((e|0)==(f|0)){p=g;q=m}else{c[2276083]=e;f=c[2276085]&e;e=f&16777212;o=c[2112932]|0;n=c[o+((e>>>10|32768)<<2)>>2]|0;if(n>>>0>9){b=f&1020;r=(d[n+(b|3)|0]|0)<<8|(d[n+(b|2)|0]|0)|((d[n+(b|1)|0]|0)<<8|(d[n+b|0]|0))<<16;s=m}else{m=gj[c[o+196768+(n<<2)>>2]&4095](e)|0;r=m;s=c[2276056]|0}c[2276084]=r;p=r>>>16|g<<16;q=s}c[2276056]=q+2;q=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;s=q-p|0;c[2276075]=s>>>24;c[2276076]=s;c[2276077]=((s^q)&(q^p))>>>24;c[2276078]=((s|p)&(q^-8388608)|s&p)>>>23;return}function F2(){var a=0,b=0,d=0;a=c[2276069]|0;b=c[9104156+((a&7)<<2)>>2]<<16>>16;d=c[9104156+((a>>>9&7|8)<<2)>>2]|0;a=d-b|0;c[2276075]=a>>>24;c[2276076]=a;c[2276077]=((a^d)&(b^d))>>>24;c[2276078]=((a|b)&(d^-8388608)|a&b)>>>23;return}function F3(){var a=0,b=0,d=0;a=c[2276069]|0;b=c[9104156+((a&7|8)<<2)>>2]<<16>>16;d=c[9104156+((a>>>9&7|8)<<2)>>2]|0;a=d-b|0;c[2276075]=a>>>24;c[2276076]=a;c[2276077]=((a^d)&(b^d))>>>24;c[2276078]=((a|b)&(d^-8388608)|a&b)>>>23;return}function F4(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0;a=c[2276069]|0;b=c[2276085]&c[9104156+((a&7|8)<<2)>>2];e=b&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=b&1023;i=(d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0);j=a}else{a=gj[c[f+196688+(g<<2)>>2]&4095](e)|0;i=a;j=c[2276069]|0}a=i<<16>>16;i=c[9104156+((j>>>9&7|8)<<2)>>2]|0;j=i-a|0;c[2276075]=j>>>24;c[2276076]=j;c[2276077]=((j^i)&(i^a))>>>24;c[2276078]=((j|a)&(i^-8388608)|j&a)>>>23;return}function F5(){var a=0,b=0,e=0,f=0,g=0,h=0;a=9104156+((c[2276069]&7|8)<<2)|0;b=c[a>>2]|0;c[a>>2]=b+2;a=c[2276085]&b;b=a&16777215;e=c[2112932]|0;f=c[e+(b>>>10<<2)>>2]|0;if(f>>>0>9){g=a&1023;h=(d[f+(g+1)|0]|0)<<8|(d[f+g|0]|0)}else{h=gj[c[e+196688+(f<<2)>>2]&4095](b)|0}b=h<<16>>16;h=c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2]|0;f=h-b|0;c[2276075]=f>>>24;c[2276076]=f;c[2276077]=((f^h)&(h^b))>>>24;c[2276078]=((f|b)&(h^-8388608)|f&b)>>>23;return}function F6(){var a=0,b=0,e=0,f=0,g=0,h=0;a=9104156+((c[2276069]&7|8)<<2)|0;b=(c[a>>2]|0)-2|0;c[a>>2]=b;a=c[2276085]&b;b=a&16777215;e=c[2112932]|0;f=c[e+(b>>>10<<2)>>2]|0;if(f>>>0>9){g=a&1023;h=(d[f+(g+1)|0]|0)<<8|(d[f+g|0]|0)}else{h=gj[c[e+196688+(f<<2)>>2]&4095](b)|0}b=h<<16>>16;h=c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2]|0;f=h-b|0;c[2276075]=f>>>24;c[2276076]=f;c[2276077]=((f^h)&(h^b))>>>24;c[2276078]=((f|b)&(h^-8388608)|f&b)>>>23;return}function F7(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=(g>>>((f<<3&16^16)>>>0)<<16>>16)+a&c[2276085];a=l&16777215;f=c[2112932]|0;g=c[f+(a>>>10<<2)>>2]|0;if(g>>>0>9){m=l&1023;n=(d[g+(m+1)|0]|0)<<8|(d[g+m|0]|0)}else{n=gj[c[f+196688+(g<<2)>>2]&4095](a)|0}a=n<<16>>16;n=c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2]|0;g=n-a|0;c[2276075]=g>>>24;c[2276076]=g;c[2276077]=((g^n)&(n^a))>>>24;c[2276078]=((g|a)&(n^-8388608)|g&a)>>>23;return}function F8(){var a=0,b=0,e=0,f=0,g=0,h=0;a=xw(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;b=c[2276085]&a;a=b&16777215;e=c[2112932]|0;f=c[e+(a>>>10<<2)>>2]|0;if(f>>>0>9){g=b&1023;h=(d[f+(g+1)|0]|0)<<8|(d[f+g|0]|0)}else{h=gj[c[e+196688+(f<<2)>>2]&4095](a)|0}a=h<<16>>16;h=c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2]|0;f=h-a|0;c[2276075]=f>>>24;c[2276076]=f;c[2276077]=((f^h)&(h^a))>>>24;c[2276078]=((f|a)&(h^-8388608)|f&a)>>>23;return}function F9(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=f>>>((e<<3&16^16)>>>0)<<16>>16&c[2276085];e=k&16777215;f=c[2112932]|0;l=c[f+(e>>>10<<2)>>2]|0;if(l>>>0>9){a=k&1023;m=(d[l+(a+1)|0]|0)<<8|(d[l+a|0]|0)}else{m=gj[c[f+196688+(l<<2)>>2]&4095](e)|0}e=m<<16>>16;m=c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2]|0;l=m-e|0;c[2276075]=l>>>24;c[2276076]=l;c[2276077]=((l^m)&(m^e))>>>24;c[2276078]=((l|e)&(m^-8388608)|l&e)>>>23;return}function Ga(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=b;g=c[2276084]|0}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=o;g=m}m=e+2|0;c[2276056]=m;e=m&-4;if((e|0)==(f|0)){p=g;q=m}else{c[2276083]=e;f=c[2276085]&e;e=f&16777212;o=c[2112932]|0;n=c[o+((e>>>10|32768)<<2)>>2]|0;if(n>>>0>9){b=f&1020;r=(d[n+(b|3)|0]|0)<<8|(d[n+(b|2)|0]|0)|((d[n+(b|1)|0]|0)<<8|(d[n+b|0]|0))<<16;s=m}else{m=gj[c[o+196768+(n<<2)>>2]&4095](e)|0;r=m;s=c[2276056]|0}c[2276084]=r;p=r>>>16|g<<16;q=s}c[2276056]=q+2;q=c[2276085]&p;p=q&16777215;s=c[2112932]|0;g=c[s+(p>>>10<<2)>>2]|0;if(g>>>0>9){r=q&1023;t=(d[g+(r+1)|0]|0)<<8|(d[g+r|0]|0);u=t<<16>>16;v=c[2276069]|0;w=v>>>9;x=w&7;y=x|8;z=9104156+(y<<2)|0;A=c[z>>2]|0;B=A-u|0;C=B>>>24;c[2276075]=C;c[2276076]=B;D=A^u;E=B^A;F=E&D;G=F>>>24;c[2276077]=G;H=B&u;I=A^-8388608;J=B|u;K=J&I;L=K|H;M=L>>>23;c[2276078]=M;return}else{t=gj[c[s+196688+(g<<2)>>2]&4095](p)|0;u=t<<16>>16;v=c[2276069]|0;w=v>>>9;x=w&7;y=x|8;z=9104156+(y<<2)|0;A=c[z>>2]|0;B=A-u|0;C=B>>>24;c[2276075]=C;c[2276076]=B;D=A^u;E=B^A;F=E&D;G=F>>>24;c[2276077]=G;H=B&u;I=A^-8388608;J=B|u;K=J&I;L=K|H;M=L>>>23;c[2276078]=M;return}}function Gb(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{j=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=j;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=(f>>>((e<<3&16^16)>>>0)<<16>>16)+a|0;a=k&16777215;e=c[2112932]|0;f=c[e+((a>>>10|32768)<<2)>>2]|0;if(f>>>0>9){l=k&1023;m=(d[f+(l+1)|0]|0)<<8|(d[f+l|0]|0)}else{m=gj[c[e+196688+(f<<2)>>2]&4095](a)|0}a=m<<16>>16;m=c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2]|0;f=m-a|0;c[2276075]=f>>>24;c[2276076]=f;c[2276077]=((f^m)&(m^a))>>>24;c[2276078]=((f|a)&(m^-8388608)|f&a)>>>23;return}function Gc(){var a=0,b=0,e=0,f=0,g=0,h=0;a=xw(c[2276056]|0)|0;b=a&16777215;e=c[2112932]|0;f=c[e+((b>>>10|32768)<<2)>>2]|0;if(f>>>0>9){g=a&1023;h=(d[f+(g+1)|0]|0)<<8|(d[f+g|0]|0)}else{h=gj[c[e+196688+(f<<2)>>2]&4095](b)|0}b=h<<16>>16;h=c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2]|0;f=h-b|0;c[2276075]=f>>>24;c[2276076]=f;c[2276077]=((f^h)&(h^b))>>>24;c[2276078]=((f|b)&(h^-8388608)|f&b)>>>23;return}function Gd(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=f>>>((e<<3&16^16)>>>0)<<16>>16;e=c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2]|0;f=e-k|0;c[2276075]=f>>>24;c[2276076]=f;c[2276077]=((f^e)&(k^e))>>>24;c[2276078]=((f|k)&(e^-8388608)|f&k)>>>23;return}function Ge(){var a=0,b=0,d=0;a=c[2276069]|0;b=c[9104156+((a&7)<<2)>>2]|0;d=c[9104156+((a>>>9&7|8)<<2)>>2]|0;a=d-b|0;c[2276075]=a>>>24;c[2276076]=a;c[2276077]=((a^d)&(d^b))>>>24;c[2276078]=((a|b)&(d^-8388608)|a&b)>>>23;return}function Gf(){var a=0,b=0,d=0;a=c[2276069]|0;b=c[9104156+((a&7|8)<<2)>>2]|0;d=c[9104156+((a>>>9&7|8)<<2)>>2]|0;a=d-b|0;c[2276075]=a>>>24;c[2276076]=a;c[2276077]=((a^d)&(d^b))>>>24;c[2276078]=((a|b)&(d^-8388608)|a&b)>>>23;return}function Gg(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0;a=c[2276069]|0;b=c[2276085]&c[9104156+((a&7|8)<<2)>>2];e=b&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=b&1023;i=(d[g+(h+3)|0]|0)<<8|(d[g+(h+2)|0]|0)|((d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0))<<16;j=a}else{a=gj[c[f+196768+(g<<2)>>2]&4095](e)|0;i=a;j=c[2276069]|0}a=c[9104156+((j>>>9&7|8)<<2)>>2]|0;j=a-i|0;c[2276075]=j>>>24;c[2276076]=j;c[2276077]=((j^a)&(a^i))>>>24;c[2276078]=((j|i)&(a^-8388608)|j&i)>>>23;return}function Gh(){var a=0,b=0,e=0,f=0,g=0,h=0;a=9104156+((c[2276069]&7|8)<<2)|0;b=c[a>>2]|0;c[a>>2]=b+4;a=c[2276085]&b;b=a&16777215;e=c[2112932]|0;f=c[e+(b>>>10<<2)>>2]|0;if(f>>>0>9){g=a&1023;h=(d[f+(g+3)|0]|0)<<8|(d[f+(g+2)|0]|0)|((d[f+(g+1)|0]|0)<<8|(d[f+g|0]|0))<<16}else{h=gj[c[e+196768+(f<<2)>>2]&4095](b)|0}b=c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2]|0;f=b-h|0;c[2276075]=f>>>24;c[2276076]=f;c[2276077]=((f^b)&(b^h))>>>24;c[2276078]=((f|h)&(b^-8388608)|f&h)>>>23;return}function Gi(){var a=0,b=0,e=0,f=0,g=0,h=0;a=9104156+((c[2276069]&7|8)<<2)|0;b=(c[a>>2]|0)-4|0;c[a>>2]=b;a=c[2276085]&b;b=a&16777215;e=c[2112932]|0;f=c[e+(b>>>10<<2)>>2]|0;if(f>>>0>9){g=a&1023;h=(d[f+(g+3)|0]|0)<<8|(d[f+(g+2)|0]|0)|((d[f+(g+1)|0]|0)<<8|(d[f+g|0]|0))<<16}else{h=gj[c[e+196768+(f<<2)>>2]&4095](b)|0}b=c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2]|0;f=b-h|0;c[2276075]=f>>>24;c[2276076]=f;c[2276077]=((f^b)&(b^h))>>>24;c[2276078]=((f|h)&(b^-8388608)|f&h)>>>23;return}function Gj(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;a=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=(g>>>((f<<3&16^16)>>>0)<<16>>16)+a&c[2276085];a=l&16777215;f=c[2112932]|0;g=c[f+(a>>>10<<2)>>2]|0;if(g>>>0>9){m=l&1023;n=(d[g+(m+3)|0]|0)<<8|(d[g+(m+2)|0]|0)|((d[g+(m+1)|0]|0)<<8|(d[g+m|0]|0))<<16;o=c[2276069]|0;p=o>>>9;q=p&7;r=q|8;s=9104156+(r<<2)|0;t=c[s>>2]|0;u=t-n|0;v=u>>>24;c[2276075]=v;c[2276076]=u;w=t^n;x=u^t;y=x&w;z=y>>>24;c[2276077]=z;A=u&n;B=t^-8388608;C=u|n;D=C&B;E=D|A;F=E>>>23;c[2276078]=F;return}else{n=gj[c[f+196768+(g<<2)>>2]&4095](a)|0;o=c[2276069]|0;p=o>>>9;q=p&7;r=q|8;s=9104156+(r<<2)|0;t=c[s>>2]|0;u=t-n|0;v=u>>>24;c[2276075]=v;c[2276076]=u;w=t^n;x=u^t;y=x&w;z=y>>>24;c[2276077]=z;A=u&n;B=t^-8388608;C=u|n;D=C&B;E=D|A;F=E>>>23;c[2276078]=F;return}}function Gk(){var a=0,b=0,e=0,f=0,g=0,h=0;a=xw(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;b=c[2276085]&a;a=b&16777215;e=c[2112932]|0;f=c[e+(a>>>10<<2)>>2]|0;if(f>>>0>9){g=b&1023;h=(d[f+(g+3)|0]|0)<<8|(d[f+(g+2)|0]|0)|((d[f+(g+1)|0]|0)<<8|(d[f+g|0]|0))<<16}else{h=gj[c[e+196768+(f<<2)>>2]&4095](a)|0}a=c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2]|0;f=a-h|0;c[2276075]=f>>>24;c[2276076]=f;c[2276077]=((f^a)&(a^h))>>>24;c[2276078]=((f|h)&(a^-8388608)|f&h)>>>23;return}function Gl(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=f>>>((e<<3&16^16)>>>0)<<16>>16&c[2276085];e=k&16777215;f=c[2112932]|0;l=c[f+(e>>>10<<2)>>2]|0;if(l>>>0>9){a=k&1023;m=(d[l+(a+3)|0]|0)<<8|(d[l+(a+2)|0]|0)|((d[l+(a+1)|0]|0)<<8|(d[l+a|0]|0))<<16;n=c[2276069]|0;o=n>>>9;p=o&7;q=p|8;r=9104156+(q<<2)|0;s=c[r>>2]|0;t=s-m|0;u=t>>>24;c[2276075]=u;c[2276076]=t;v=s^m;w=t^s;x=w&v;y=x>>>24;c[2276077]=y;z=t&m;A=s^-8388608;B=t|m;C=B&A;D=C|z;E=D>>>23;c[2276078]=E;return}else{m=gj[c[f+196768+(l<<2)>>2]&4095](e)|0;n=c[2276069]|0;o=n>>>9;p=o&7;q=p|8;r=9104156+(q<<2)|0;s=c[r>>2]|0;t=s-m|0;u=t>>>24;c[2276075]=u;c[2276076]=t;v=s^m;w=t^s;x=w&v;y=x>>>24;c[2276077]=y;z=t&m;A=s^-8388608;B=t|m;C=B&A;D=C|z;E=D>>>23;c[2276078]=E;return}}function Gm(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=b;g=c[2276084]|0}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=o;g=m}m=e+2|0;c[2276056]=m;e=m&-4;if((e|0)==(f|0)){p=g;q=m}else{c[2276083]=e;f=c[2276085]&e;e=f&16777212;o=c[2112932]|0;n=c[o+((e>>>10|32768)<<2)>>2]|0;if(n>>>0>9){b=f&1020;r=(d[n+(b|3)|0]|0)<<8|(d[n+(b|2)|0]|0)|((d[n+(b|1)|0]|0)<<8|(d[n+b|0]|0))<<16;s=m}else{m=gj[c[o+196768+(n<<2)>>2]&4095](e)|0;r=m;s=c[2276056]|0}c[2276084]=r;p=r>>>16|g<<16;q=s}c[2276056]=q+2;q=c[2276085]&p;p=q&16777215;s=c[2112932]|0;g=c[s+(p>>>10<<2)>>2]|0;if(g>>>0>9){r=q&1023;t=(d[g+(r+3)|0]|0)<<8|(d[g+(r+2)|0]|0)|((d[g+(r+1)|0]|0)<<8|(d[g+r|0]|0))<<16;u=c[2276069]|0;v=u>>>9;w=v&7;x=w|8;y=9104156+(x<<2)|0;z=c[y>>2]|0;A=z-t|0;B=A>>>24;c[2276075]=B;c[2276076]=A;C=z^t;D=A^z;E=D&C;F=E>>>24;c[2276077]=F;G=A&t;H=z^-8388608;I=A|t;J=I&H;K=J|G;L=K>>>23;c[2276078]=L;return}else{t=gj[c[s+196768+(g<<2)>>2]&4095](p)|0;u=c[2276069]|0;v=u>>>9;w=v&7;x=w|8;y=9104156+(x<<2)|0;z=c[y>>2]|0;A=z-t|0;B=A>>>24;c[2276075]=B;c[2276076]=A;C=z^t;D=A^z;E=D&C;F=E>>>24;c[2276077]=F;G=A&t;H=z^-8388608;I=A|t;J=I&H;K=J|G;L=K>>>23;c[2276078]=L;return}}function Gn(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{j=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=j;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=(f>>>((e<<3&16^16)>>>0)<<16>>16)+a|0;a=k&16777215;e=c[2112932]|0;f=c[e+((a>>>10|32768)<<2)>>2]|0;if(f>>>0>9){l=k&1023;m=(d[f+(l+3)|0]|0)<<8|(d[f+(l+2)|0]|0)|((d[f+(l+1)|0]|0)<<8|(d[f+l|0]|0))<<16;n=c[2276069]|0;o=n>>>9;p=o&7;q=p|8;r=9104156+(q<<2)|0;s=c[r>>2]|0;t=s-m|0;u=t>>>24;c[2276075]=u;c[2276076]=t;v=s^m;w=t^s;x=w&v;y=x>>>24;c[2276077]=y;z=t&m;A=s^-8388608;B=t|m;C=B&A;D=C|z;E=D>>>23;c[2276078]=E;return}else{m=gj[c[e+196768+(f<<2)>>2]&4095](a)|0;n=c[2276069]|0;o=n>>>9;p=o&7;q=p|8;r=9104156+(q<<2)|0;s=c[r>>2]|0;t=s-m|0;u=t>>>24;c[2276075]=u;c[2276076]=t;v=s^m;w=t^s;x=w&v;y=x>>>24;c[2276077]=y;z=t&m;A=s^-8388608;B=t|m;C=B&A;D=C|z;E=D>>>23;c[2276078]=E;return}}function Go(){var a=0,b=0,e=0,f=0,g=0,h=0;a=xw(c[2276056]|0)|0;b=a&16777215;e=c[2112932]|0;f=c[e+((b>>>10|32768)<<2)>>2]|0;if(f>>>0>9){g=a&1023;h=(d[f+(g+3)|0]|0)<<8|(d[f+(g+2)|0]|0)|((d[f+(g+1)|0]|0)<<8|(d[f+g|0]|0))<<16}else{h=gj[c[e+196768+(f<<2)>>2]&4095](b)|0}b=c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2]|0;f=b-h|0;c[2276075]=f>>>24;c[2276076]=f;c[2276077]=((f^b)&(b^h))>>>24;c[2276078]=((f|h)&(b^-8388608)|f&h)>>>23;return}function Gp(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=b;g=c[2276084]|0}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=o;g=m}m=e+2|0;c[2276056]=m;e=m&-4;if((e|0)==(f|0)){p=g;q=m}else{c[2276083]=e;f=c[2276085]&e;e=f&16777212;o=c[2112932]|0;n=c[o+((e>>>10|32768)<<2)>>2]|0;if(n>>>0>9){b=f&1020;r=(d[n+(b|3)|0]|0)<<8|(d[n+(b|2)|0]|0)|((d[n+(b|1)|0]|0)<<8|(d[n+b|0]|0))<<16;s=m}else{m=gj[c[o+196768+(n<<2)>>2]&4095](e)|0;r=m;s=c[2276056]|0}c[2276084]=r;p=r>>>16|g<<16;q=s}c[2276056]=q+2;q=c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2]|0;s=q-p|0;c[2276075]=s>>>24;c[2276076]=s;c[2276077]=((s^q)&(q^p))>>>24;c[2276078]=((s|p)&(q^-8388608)|s&p)>>>23;return}function Gq(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=f>>>((e<<3&16^16)>>>0);e=k&255;f=c[9104156+((c[2276069]&7)<<2)>>2]|0;l=f&255;a=l-e|0;c[2276075]=a;c[2276076]=f-k&255;c[2276077]=(a^f)&(e^l);c[2276078]=a;return}function Gr(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)&255;f=c[2276085]&c[9104156+((c[2276069]&7|8)<<2)>>2];g=f&16777215;m=c[2112932]|0;b=c[m+(g>>>10<<2)>>2]|0;if(b>>>0>9){n=a[b+(f&1023^1)|0]|0;o=n&255;p=o-l|0;c[2276075]=p;q=p&255;c[2276076]=q;r=o^l;s=p^o;t=s&r;c[2276077]=t;c[2276078]=p;return}else{n=gj[c[m+196608+(b<<2)>>2]&4095](g)|0;o=n&255;p=o-l|0;c[2276075]=p;q=p&255;c[2276076]=q;r=o^l;s=p^o;t=s&r;c[2276077]=t;c[2276078]=p;return}}function Gs(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)&255;f=9104156+((c[2276069]&7|8)<<2)|0;g=c[f>>2]|0;c[f>>2]=g+1;f=c[2276085]&g;g=f&16777215;m=c[2112932]|0;b=c[m+(g>>>10<<2)>>2]|0;if(b>>>0>9){n=a[b+(f&1023^1)|0]|0;o=n&255;p=o-l|0;c[2276075]=p;q=p&255;c[2276076]=q;r=o^l;s=p^o;t=s&r;c[2276077]=t;c[2276078]=p;return}else{n=gj[c[m+196608+(b<<2)>>2]&4095](g)|0;o=n&255;p=o-l|0;c[2276075]=p;q=p&255;c[2276076]=q;r=o^l;s=p^o;t=s&r;c[2276077]=t;c[2276078]=p;return}}function Gt(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)&255;f=c[2276054]|0;c[2276054]=f+2;g=c[2276085]&f;f=g&16777215;m=c[2112932]|0;b=c[m+(f>>>10<<2)>>2]|0;if(b>>>0>9){n=a[b+(g&1023^1)|0]|0;o=n&255;p=o-l|0;c[2276075]=p;q=p&255;c[2276076]=q;r=o^l;s=p^o;t=s&r;c[2276077]=t;c[2276078]=p;return}else{n=gj[c[m+196608+(b<<2)>>2]&4095](f)|0;o=n&255;p=o-l|0;c[2276075]=p;q=p&255;c[2276076]=q;r=o^l;s=p^o;t=s&r;c[2276077]=t;c[2276078]=p;return}}function Gu(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)&255;f=9104156+((c[2276069]&7|8)<<2)|0;g=(c[f>>2]|0)-1|0;c[f>>2]=g;f=c[2276085]&g;g=f&16777215;m=c[2112932]|0;b=c[m+(g>>>10<<2)>>2]|0;if(b>>>0>9){n=a[b+(f&1023^1)|0]|0;o=n&255;p=o-l|0;c[2276075]=p;q=p&255;c[2276076]=q;r=o^l;s=p^o;t=s&r;c[2276077]=t;c[2276078]=p;return}else{n=gj[c[m+196608+(b<<2)>>2]&4095](g)|0;o=n&255;p=o-l|0;c[2276075]=p;q=p&255;c[2276076]=q;r=o^l;s=p^o;t=s&r;c[2276077]=t;c[2276078]=p;return}}function Gv(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)&255;f=(c[2276054]|0)-2|0;c[2276054]=f;g=c[2276085]&f;f=g&16777215;m=c[2112932]|0;b=c[m+(f>>>10<<2)>>2]|0;if(b>>>0>9){n=a[b+(g&1023^1)|0]|0;o=n&255;p=o-l|0;c[2276075]=p;q=p&255;c[2276076]=q;r=o^l;s=p^o;t=s&r;c[2276077]=t;c[2276078]=p;return}else{n=gj[c[m+196608+(b<<2)>>2]&4095](f)|0;o=n&255;p=o-l|0;c[2276075]=p;q=p&255;c[2276076]=q;r=o^l;s=p^o;t=s&r;c[2276077]=t;c[2276078]=p;return}}function Gw(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0)&255;f=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;o=p&-4;if((o|0)==(h|0)){q=p;r=g}else{c[2276083]=o;g=c[2276085]&o;o=g&16777212;h=c[2112932]|0;e=c[h+((o>>>10|32768)<<2)>>2]|0;if(e>>>0>9){j=g&1020;s=(d[e+(j|3)|0]|0)<<8|(d[e+(j|2)|0]|0)|((d[e+(j|1)|0]|0)<<8|(d[e+j|0]|0))<<16;t=p}else{p=gj[c[h+196768+(e<<2)>>2]&4095](o)|0;s=p;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;s=(r>>>((q<<3&16^16)>>>0)<<16>>16)+f&c[2276085];f=s&16777215;q=c[2112932]|0;r=c[q+(f>>>10<<2)>>2]|0;if(r>>>0>9){u=a[r+(s&1023^1)|0]|0;v=u&255;w=v-n|0;c[2276075]=w;x=w&255;c[2276076]=x;y=v^n;z=w^v;A=z&y;c[2276077]=A;c[2276078]=w;return}else{u=gj[c[q+196608+(r<<2)>>2]&4095](f)|0;v=u&255;w=v-n|0;c[2276075]=w;x=w&255;c[2276076]=x;y=v^n;z=w^v;A=z&y;c[2276077]=A;c[2276078]=w;return}}function Gx(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)&255;f=xw(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;g=c[2276085]&f;f=g&16777215;m=c[2112932]|0;b=c[m+(f>>>10<<2)>>2]|0;if(b>>>0>9){n=a[b+(g&1023^1)|0]|0;o=n&255;p=o-l|0;c[2276075]=p;q=p&255;c[2276076]=q;r=o^l;s=p^o;t=s&r;c[2276077]=t;c[2276078]=p;return}else{n=gj[c[m+196608+(b<<2)>>2]&4095](f)|0;o=n&255;p=o-l|0;c[2276075]=p;q=p&255;c[2276076]=q;r=o^l;s=p^o;t=s&r;c[2276077]=t;c[2276078]=p;return}}function Gy(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0)&255;f=p&-4;if((f|0)==(h|0)){q=p;r=g}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;h=c[2112932]|0;o=c[h+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=p}else{p=gj[c[h+196768+(o<<2)>>2]&4095](f)|0;s=p;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;s=r>>>((q<<3&16^16)>>>0)<<16>>16&c[2276085];q=s&16777215;r=c[2112932]|0;t=c[r+(q>>>10<<2)>>2]|0;if(t>>>0>9){u=a[t+(s&1023^1)|0]|0;v=u&255;w=v-n|0;c[2276075]=w;x=w&255;c[2276076]=x;y=v^n;z=w^v;A=z&y;c[2276077]=A;c[2276078]=w;return}else{u=gj[c[r+196608+(t<<2)>>2]&4095](q)|0;v=u&255;w=v-n|0;c[2276075]=w;x=w&255;c[2276076]=x;y=v^n;z=w^v;A=z&y;c[2276077]=A;c[2276078]=w;return}}function Gz(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0)&255;f=p&-4;if((f|0)==(h|0)){q=p;r=h;s=g}else{c[2276083]=f;g=c[2276085]&f;h=g&16777212;o=c[2112932]|0;e=c[o+((h>>>10|32768)<<2)>>2]|0;if(e>>>0>9){j=g&1020;t=(d[e+(j|3)|0]|0)<<8|(d[e+(j|2)|0]|0)|((d[e+(j|1)|0]|0)<<8|(d[e+j|0]|0))<<16;u=p;v=f}else{f=gj[c[o+196768+(e<<2)>>2]&4095](h)|0;t=f;u=c[2276056]|0;v=c[2276083]|0}c[2276084]=t;q=u;r=v;s=t}t=q+2|0;c[2276056]=t;q=t&-4;if((q|0)==(r|0)){w=s;x=t}else{c[2276083]=q;r=c[2276085]&q;q=r&16777212;v=c[2112932]|0;u=c[v+((q>>>10|32768)<<2)>>2]|0;if(u>>>0>9){f=r&1020;y=(d[u+(f|3)|0]|0)<<8|(d[u+(f|2)|0]|0)|((d[u+(f|1)|0]|0)<<8|(d[u+f|0]|0))<<16;z=t}else{t=gj[c[v+196768+(u<<2)>>2]&4095](q)|0;y=t;z=c[2276056]|0}c[2276084]=y;w=y>>>16|s<<16;x=z}c[2276056]=x+2;x=c[2276085]&w;w=x&16777215;z=c[2112932]|0;s=c[z+(w>>>10<<2)>>2]|0;if(s>>>0>9){A=a[s+(x&1023^1)|0]|0;B=A&255;C=B-n|0;c[2276075]=C;D=C&255;c[2276076]=D;E=B^n;F=C^B;G=F&E;c[2276077]=G;c[2276078]=C;return}else{A=gj[c[z+196608+(s<<2)>>2]&4095](w)|0;B=A&255;C=B-n|0;c[2276075]=C;D=C&255;c[2276076]=D;E=B^n;F=C^B;G=F&E;c[2276077]=G;c[2276078]=C;return}}function GA(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0)&255;f=p&-4;if((f|0)==(h|0)){q=p;r=g}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;h=c[2112932]|0;o=c[h+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=p}else{e=gj[c[h+196768+(o<<2)>>2]&4095](f)|0;s=e;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;s=(r>>>((q<<3&16^16)>>>0)<<16>>16)+p|0;p=s&16777215;q=c[2112932]|0;r=c[q+((p>>>10|32768)<<2)>>2]|0;if(r>>>0>9){u=a[r+(s&1023^1)|0]|0}else{u=gj[c[q+196608+(r<<2)>>2]&4095](p)|0}p=u&255;u=p-n|0;c[2276075]=u;c[2276076]=u&255;c[2276077]=(u^p)&(p^n);c[2276078]=u;return}function GB(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}l=f+2|0;c[2276056]=l;m=g>>>((f<<3&16^16)>>>0)&255;f=xw(l)|0;l=f&16777215;g=c[2112932]|0;b=c[g+((l>>>10|32768)<<2)>>2]|0;if(b>>>0>9){n=a[b+(f&1023^1)|0]|0}else{n=gj[c[g+196608+(b<<2)>>2]&4095](l)|0}l=n&255;n=l-m|0;c[2276075]=n;c[2276076]=n&255;c[2276077]=(n^l)&(l^m);c[2276078]=n;return}function GC(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=f>>>((e<<3&16^16)>>>0);e=k&65535;f=c[9104156+((c[2276069]&7)<<2)>>2]|0;l=f&65535;a=l-e|0;b=a>>>8;c[2276075]=b;c[2276076]=f-k&65535;c[2276077]=((a^f)&(e^l))>>>8;c[2276078]=b;return}function GD(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=f>>>((e<<3&16^16)>>>0)&65535;e=c[2276085]&c[9104156+((c[2276069]&7|8)<<2)>>2];f=e&16777215;l=c[2112932]|0;a=c[l+(f>>>10<<2)>>2]|0;if(a>>>0>9){b=e&1023;m=(d[a+(b+1)|0]|0)<<8|(d[a+b|0]|0);n=m&65535;o=n-k|0;p=o>>>8;c[2276075]=p;q=o&65535;c[2276076]=q;r=n^k;s=o^n;t=s&r;u=t>>>8;c[2276077]=u;c[2276078]=p;return}else{m=gj[c[l+196688+(a<<2)>>2]&4095](f)|0;n=m&65535;o=n-k|0;p=o>>>8;c[2276075]=p;q=o&65535;c[2276076]=q;r=n^k;s=o^n;t=s&r;u=t>>>8;c[2276077]=u;c[2276078]=p;return}}function GE(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=f>>>((e<<3&16^16)>>>0)&65535;e=9104156+((c[2276069]&7|8)<<2)|0;f=c[e>>2]|0;c[e>>2]=f+2;e=c[2276085]&f;f=e&16777215;l=c[2112932]|0;a=c[l+(f>>>10<<2)>>2]|0;if(a>>>0>9){b=e&1023;m=(d[a+(b+1)|0]|0)<<8|(d[a+b|0]|0);n=m&65535;o=n-k|0;p=o>>>8;c[2276075]=p;q=o&65535;c[2276076]=q;r=n^k;s=o^n;t=s&r;u=t>>>8;c[2276077]=u;c[2276078]=p;return}else{m=gj[c[l+196688+(a<<2)>>2]&4095](f)|0;n=m&65535;o=n-k|0;p=o>>>8;c[2276075]=p;q=o&65535;c[2276076]=q;r=n^k;s=o^n;t=s&r;u=t>>>8;c[2276077]=u;c[2276078]=p;return}}function GF(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=f>>>((e<<3&16^16)>>>0)&65535;e=9104156+((c[2276069]&7|8)<<2)|0;f=(c[e>>2]|0)-2|0;c[e>>2]=f;e=c[2276085]&f;f=e&16777215;l=c[2112932]|0;a=c[l+(f>>>10<<2)>>2]|0;if(a>>>0>9){b=e&1023;m=(d[a+(b+1)|0]|0)<<8|(d[a+b|0]|0);n=m&65535;o=n-k|0;p=o>>>8;c[2276075]=p;q=o&65535;c[2276076]=q;r=n^k;s=o^n;t=s&r;u=t>>>8;c[2276077]=u;c[2276078]=p;return}else{m=gj[c[l+196688+(a<<2)>>2]&4095](f)|0;n=m&65535;o=n-k|0;p=o>>>8;c[2276075]=p;q=o&65535;c[2276076]=q;r=n^k;s=o^n;t=s&r;u=t>>>8;c[2276077]=u;c[2276078]=p;return}}function GG(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0;g=b}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=m;g=o}o=e+2|0;c[2276056]=o;m=f>>>((e<<3&16^16)>>>0)&65535;e=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;n=o&-4;if((n|0)==(g|0)){p=o;q=f}else{c[2276083]=n;f=c[2276085]&n;n=f&16777212;g=c[2112932]|0;b=c[g+((n>>>10|32768)<<2)>>2]|0;if(b>>>0>9){i=f&1020;r=(d[b+(i|3)|0]|0)<<8|(d[b+(i|2)|0]|0)|((d[b+(i|1)|0]|0)<<8|(d[b+i|0]|0))<<16;s=o}else{o=gj[c[g+196768+(b<<2)>>2]&4095](n)|0;r=o;s=c[2276056]|0}c[2276084]=r;p=s;q=r}c[2276056]=p+2;r=(q>>>((p<<3&16^16)>>>0)<<16>>16)+e&c[2276085];e=r&16777215;p=c[2112932]|0;q=c[p+(e>>>10<<2)>>2]|0;if(q>>>0>9){s=r&1023;t=(d[q+(s+1)|0]|0)<<8|(d[q+s|0]|0);u=t&65535;v=u-m|0;w=v>>>8;c[2276075]=w;x=v&65535;c[2276076]=x;y=u^m;z=v^u;A=z&y;B=A>>>8;c[2276077]=B;c[2276078]=w;return}else{t=gj[c[p+196688+(q<<2)>>2]&4095](e)|0;u=t&65535;v=u-m|0;w=v>>>8;c[2276075]=w;x=v&65535;c[2276076]=x;y=u^m;z=v^u;A=z&y;B=A>>>8;c[2276077]=B;c[2276078]=w;return}}function GH(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=f>>>((e<<3&16^16)>>>0)&65535;e=xw(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;f=c[2276085]&e;e=f&16777215;l=c[2112932]|0;a=c[l+(e>>>10<<2)>>2]|0;if(a>>>0>9){b=f&1023;m=(d[a+(b+1)|0]|0)<<8|(d[a+b|0]|0);n=m&65535;o=n-k|0;p=o>>>8;c[2276075]=p;q=o&65535;c[2276076]=q;r=n^k;s=o^n;t=s&r;u=t>>>8;c[2276077]=u;c[2276078]=p;return}else{m=gj[c[l+196688+(a<<2)>>2]&4095](e)|0;n=m&65535;o=n-k|0;p=o>>>8;c[2276075]=p;q=o&65535;c[2276076]=q;r=n^k;s=o^n;t=s&r;u=t>>>8;c[2276077]=u;c[2276078]=p;return}}function GI(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0;g=b}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=m;g=o}o=e+2|0;c[2276056]=o;m=f>>>((e<<3&16^16)>>>0)&65535;e=o&-4;if((e|0)==(g|0)){p=o;q=f}else{c[2276083]=e;f=c[2276085]&e;e=f&16777212;g=c[2112932]|0;n=c[g+((e>>>10|32768)<<2)>>2]|0;if(n>>>0>9){b=f&1020;r=(d[n+(b|3)|0]|0)<<8|(d[n+(b|2)|0]|0)|((d[n+(b|1)|0]|0)<<8|(d[n+b|0]|0))<<16;s=o}else{o=gj[c[g+196768+(n<<2)>>2]&4095](e)|0;r=o;s=c[2276056]|0}c[2276084]=r;p=s;q=r}c[2276056]=p+2;r=q>>>((p<<3&16^16)>>>0)<<16>>16&c[2276085];p=r&16777215;q=c[2112932]|0;s=c[q+(p>>>10<<2)>>2]|0;if(s>>>0>9){o=r&1023;t=(d[s+(o+1)|0]|0)<<8|(d[s+o|0]|0);u=t&65535;v=u-m|0;w=v>>>8;c[2276075]=w;x=v&65535;c[2276076]=x;y=u^m;z=v^u;A=z&y;B=A>>>8;c[2276077]=B;c[2276078]=w;return}else{t=gj[c[q+196688+(s<<2)>>2]&4095](p)|0;u=t&65535;v=u-m|0;w=v>>>8;c[2276075]=w;x=v&65535;c[2276076]=x;y=u^m;z=v^u;A=z&y;B=A>>>8;c[2276077]=B;c[2276078]=w;return}}function GJ(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0;g=b}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=m;g=o}o=e+2|0;c[2276056]=o;m=f>>>((e<<3&16^16)>>>0)&65535;e=o&-4;if((e|0)==(g|0)){p=o;q=g;r=f}else{c[2276083]=e;f=c[2276085]&e;g=f&16777212;n=c[2112932]|0;b=c[n+((g>>>10|32768)<<2)>>2]|0;if(b>>>0>9){i=f&1020;s=(d[b+(i|3)|0]|0)<<8|(d[b+(i|2)|0]|0)|((d[b+(i|1)|0]|0)<<8|(d[b+i|0]|0))<<16;t=o;u=e}else{e=gj[c[n+196768+(b<<2)>>2]&4095](g)|0;s=e;t=c[2276056]|0;u=c[2276083]|0}c[2276084]=s;p=t;q=u;r=s}s=p+2|0;c[2276056]=s;p=s&-4;if((p|0)==(q|0)){v=r;w=s}else{c[2276083]=p;q=c[2276085]&p;p=q&16777212;u=c[2112932]|0;t=c[u+((p>>>10|32768)<<2)>>2]|0;if(t>>>0>9){e=q&1020;x=(d[t+(e|3)|0]|0)<<8|(d[t+(e|2)|0]|0)|((d[t+(e|1)|0]|0)<<8|(d[t+e|0]|0))<<16;y=s}else{s=gj[c[u+196768+(t<<2)>>2]&4095](p)|0;x=s;y=c[2276056]|0}c[2276084]=x;v=x>>>16|r<<16;w=y}c[2276056]=w+2;w=c[2276085]&v;v=w&16777215;y=c[2112932]|0;r=c[y+(v>>>10<<2)>>2]|0;if(r>>>0>9){x=w&1023;z=(d[r+(x+1)|0]|0)<<8|(d[r+x|0]|0);A=z&65535;B=A-m|0;C=B>>>8;c[2276075]=C;D=B&65535;c[2276076]=D;E=A^m;F=B^A;G=F&E;H=G>>>8;c[2276077]=H;c[2276078]=C;return}else{z=gj[c[y+196688+(r<<2)>>2]&4095](v)|0;A=z&65535;B=A-m|0;C=B>>>8;c[2276075]=C;D=B&65535;c[2276076]=D;E=A^m;F=B^A;G=F&E;H=G>>>8;c[2276077]=H;c[2276078]=C;return}}function GK(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;if((c[2276038]&24|0)==0){Bl();return}a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0;g=b}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=m;g=o}o=e+2|0;c[2276056]=o;m=f>>>((e<<3&16^16)>>>0)&65535;e=o&-4;if((e|0)==(g|0)){p=o;q=f}else{c[2276083]=e;f=c[2276085]&e;e=f&16777212;g=c[2112932]|0;n=c[g+((e>>>10|32768)<<2)>>2]|0;if(n>>>0>9){b=f&1020;r=(d[n+(b|3)|0]|0)<<8|(d[n+(b|2)|0]|0)|((d[n+(b|1)|0]|0)<<8|(d[n+b|0]|0))<<16;s=o}else{b=gj[c[g+196768+(n<<2)>>2]&4095](e)|0;r=b;s=c[2276056]|0}c[2276084]=r;p=s;q=r}c[2276056]=p+2;r=(q>>>((p<<3&16^16)>>>0)<<16>>16)+o|0;o=r&16777215;p=c[2112932]|0;q=c[p+((o>>>10|32768)<<2)>>2]|0;if(q>>>0>9){s=r&1023;t=(d[q+(s+1)|0]|0)<<8|(d[q+s|0]|0)}else{t=gj[c[p+196688+(q<<2)>>2]&4095](o)|0}o=t&65535;t=o-m|0;q=t>>>8;c[2276075]=q;c[2276076]=t&65535;c[2276077]=((t^o)&(o^m))>>>8;c[2276078]=q;return}function GL(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((c[2276038]&24|0)==0){Bl();return}a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}k=e+2|0;c[2276056]=k;l=f>>>((e<<3&16^16)>>>0)&65535;e=xw(k)|0;k=e&16777215;f=c[2112932]|0;a=c[f+((k>>>10|32768)<<2)>>2]|0;if(a>>>0>9){b=e&1023;m=(d[a+(b+1)|0]|0)<<8|(d[a+b|0]|0)}else{m=gj[c[f+196688+(a<<2)>>2]&4095](k)|0}k=m&65535;m=k-l|0;a=m>>>8;c[2276075]=a;c[2276076]=m&65535;c[2276077]=((m^k)&(k^l))>>>8;c[2276078]=a;return}function GM(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=b;g=c[2276084]|0}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=o;g=m}m=e+2|0;c[2276056]=m;e=m&-4;if((e|0)==(f|0)){p=g;q=m}else{c[2276083]=e;f=c[2276085]&e;e=f&16777212;o=c[2112932]|0;n=c[o+((e>>>10|32768)<<2)>>2]|0;if(n>>>0>9){b=f&1020;r=(d[n+(b|3)|0]|0)<<8|(d[n+(b|2)|0]|0)|((d[n+(b|1)|0]|0)<<8|(d[n+b|0]|0))<<16;s=m}else{m=gj[c[o+196768+(n<<2)>>2]&4095](e)|0;r=m;s=c[2276056]|0}c[2276084]=r;p=r>>>16|g<<16;q=s}c[2276056]=q+2;q=c[2276069]&7;s=c[9104156+(q<<2)>>2]|0;g=s-p|0;r=c[(c[2112932]|0)+196860>>2]|0;if((r|0)==0){t=g>>>24;c[2276075]=t;c[2276076]=g;u=s^p;v=g^s;w=v&u;x=w>>>24;c[2276077]=x;y=g&p;z=s^-8388608;A=g|p;B=A&z;C=B|y;D=C>>>23;c[2276078]=D;return}gA[r&16383](p,q)|0;t=g>>>24;c[2276075]=t;c[2276076]=g;u=s^p;v=g^s;w=v&u;x=w>>>24;c[2276077]=x;y=g&p;z=s^-8388608;A=g|p;B=A&z;C=B|y;D=C>>>23;c[2276078]=D;return}function GN(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=b;g=c[2276084]|0}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=o;g=m}m=e+2|0;c[2276056]=m;e=m&-4;if((e|0)==(f|0)){p=g;q=m}else{c[2276083]=e;f=c[2276085]&e;e=f&16777212;o=c[2112932]|0;n=c[o+((e>>>10|32768)<<2)>>2]|0;if(n>>>0>9){b=f&1020;r=(d[n+(b|3)|0]|0)<<8|(d[n+(b|2)|0]|0)|((d[n+(b|1)|0]|0)<<8|(d[n+b|0]|0))<<16;s=m}else{m=gj[c[o+196768+(n<<2)>>2]&4095](e)|0;r=m;s=c[2276056]|0}c[2276084]=r;p=r>>>16|g<<16;q=s}c[2276056]=q+2;q=c[2276085]&c[9104156+((c[2276069]&7|8)<<2)>>2];s=q&16777215;g=c[2112932]|0;r=c[g+(s>>>10<<2)>>2]|0;if(r>>>0>9){m=q&1023;t=(d[r+(m+3)|0]|0)<<8|(d[r+(m+2)|0]|0)|((d[r+(m+1)|0]|0)<<8|(d[r+m|0]|0))<<16;u=t-p|0;v=u>>>24;c[2276075]=v;c[2276076]=u;w=t^p;x=u^t;y=x&w;z=y>>>24;c[2276077]=z;A=u&p;B=t^-8388608;C=u|p;D=C&B;E=D|A;F=E>>>23;c[2276078]=F;return}else{t=gj[c[g+196768+(r<<2)>>2]&4095](s)|0;u=t-p|0;v=u>>>24;c[2276075]=v;c[2276076]=u;w=t^p;x=u^t;y=x&w;z=y>>>24;c[2276077]=z;A=u&p;B=t^-8388608;C=u|p;D=C&B;E=D|A;F=E>>>23;c[2276078]=F;return}}function GO(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=b;g=c[2276084]|0}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=o;g=m}m=e+2|0;c[2276056]=m;e=m&-4;if((e|0)==(f|0)){p=g;q=m}else{c[2276083]=e;f=c[2276085]&e;e=f&16777212;o=c[2112932]|0;n=c[o+((e>>>10|32768)<<2)>>2]|0;if(n>>>0>9){b=f&1020;r=(d[n+(b|3)|0]|0)<<8|(d[n+(b|2)|0]|0)|((d[n+(b|1)|0]|0)<<8|(d[n+b|0]|0))<<16;s=m}else{m=gj[c[o+196768+(n<<2)>>2]&4095](e)|0;r=m;s=c[2276056]|0}c[2276084]=r;p=r>>>16|g<<16;q=s}c[2276056]=q+2;q=9104156+((c[2276069]&7|8)<<2)|0;s=c[q>>2]|0;c[q>>2]=s+4;q=c[2276085]&s;s=q&16777215;g=c[2112932]|0;r=c[g+(s>>>10<<2)>>2]|0;if(r>>>0>9){m=q&1023;t=(d[r+(m+3)|0]|0)<<8|(d[r+(m+2)|0]|0)|((d[r+(m+1)|0]|0)<<8|(d[r+m|0]|0))<<16;u=t-p|0;v=u>>>24;c[2276075]=v;c[2276076]=u;w=t^p;x=u^t;y=x&w;z=y>>>24;c[2276077]=z;A=u&p;B=t^-8388608;C=u|p;D=C&B;E=D|A;F=E>>>23;c[2276078]=F;return}else{t=gj[c[g+196768+(r<<2)>>2]&4095](s)|0;u=t-p|0;v=u>>>24;c[2276075]=v;c[2276076]=u;w=t^p;x=u^t;y=x&w;z=y>>>24;c[2276077]=z;A=u&p;B=t^-8388608;C=u|p;D=C&B;E=D|A;F=E>>>23;c[2276078]=F;return}}function GP(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=b;g=c[2276084]|0}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=o;g=m}m=e+2|0;c[2276056]=m;e=m&-4;if((e|0)==(f|0)){p=g;q=m}else{c[2276083]=e;f=c[2276085]&e;e=f&16777212;o=c[2112932]|0;n=c[o+((e>>>10|32768)<<2)>>2]|0;if(n>>>0>9){b=f&1020;r=(d[n+(b|3)|0]|0)<<8|(d[n+(b|2)|0]|0)|((d[n+(b|1)|0]|0)<<8|(d[n+b|0]|0))<<16;s=m}else{m=gj[c[o+196768+(n<<2)>>2]&4095](e)|0;r=m;s=c[2276056]|0}c[2276084]=r;p=r>>>16|g<<16;q=s}c[2276056]=q+2;q=9104156+((c[2276069]&7|8)<<2)|0;s=(c[q>>2]|0)-4|0;c[q>>2]=s;q=c[2276085]&s;s=q&16777215;g=c[2112932]|0;r=c[g+(s>>>10<<2)>>2]|0;if(r>>>0>9){m=q&1023;t=(d[r+(m+3)|0]|0)<<8|(d[r+(m+2)|0]|0)|((d[r+(m+1)|0]|0)<<8|(d[r+m|0]|0))<<16;u=t-p|0;v=u>>>24;c[2276075]=v;c[2276076]=u;w=t^p;x=u^t;y=x&w;z=y>>>24;c[2276077]=z;A=u&p;B=t^-8388608;C=u|p;D=C&B;E=D|A;F=E>>>23;c[2276078]=F;return}else{t=gj[c[g+196768+(r<<2)>>2]&4095](s)|0;u=t-p|0;v=u>>>24;c[2276075]=v;c[2276076]=u;w=t^p;x=u^t;y=x&w;z=y>>>24;c[2276077]=z;A=u&p;B=t^-8388608;C=u|p;D=C&B;E=D|A;F=E>>>23;c[2276078]=F;return}}function GQ(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0;g=b}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=m;g=o}o=e+2|0;c[2276056]=o;e=o&-4;if((e|0)==(g|0)){p=f;q=o;r=g;s=f}else{c[2276083]=e;g=c[2276085]&e;m=g&16777212;n=c[2112932]|0;b=c[n+((m>>>10|32768)<<2)>>2]|0;if(b>>>0>9){i=g&1020;t=(d[b+(i|3)|0]|0)<<8|(d[b+(i|2)|0]|0)|((d[b+(i|1)|0]|0)<<8|(d[b+i|0]|0))<<16;u=o;v=e}else{e=gj[c[n+196768+(b<<2)>>2]&4095](m)|0;t=e;u=c[2276056]|0;v=c[2276083]|0}c[2276084]=t;p=t>>>16|f<<16;q=u;r=v;s=t}t=q+2|0;c[2276056]=t;q=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;v=t&-4;if((v|0)==(r|0)){w=t;x=s}else{c[2276083]=v;s=c[2276085]&v;v=s&16777212;r=c[2112932]|0;u=c[r+((v>>>10|32768)<<2)>>2]|0;if(u>>>0>9){f=s&1020;y=(d[u+(f|3)|0]|0)<<8|(d[u+(f|2)|0]|0)|((d[u+(f|1)|0]|0)<<8|(d[u+f|0]|0))<<16;z=t}else{t=gj[c[r+196768+(u<<2)>>2]&4095](v)|0;y=t;z=c[2276056]|0}c[2276084]=y;w=z;x=y}c[2276056]=w+2;y=(x>>>((w<<3&16^16)>>>0)<<16>>16)+q&c[2276085];q=y&16777215;w=c[2112932]|0;x=c[w+(q>>>10<<2)>>2]|0;if(x>>>0>9){z=y&1023;A=(d[x+(z+3)|0]|0)<<8|(d[x+(z+2)|0]|0)|((d[x+(z+1)|0]|0)<<8|(d[x+z|0]|0))<<16;B=A-p|0;C=B>>>24;c[2276075]=C;c[2276076]=B;D=A^p;E=B^A;F=E&D;G=F>>>24;c[2276077]=G;H=B&p;I=A^-8388608;J=B|p;K=J&I;L=K|H;M=L>>>23;c[2276078]=M;return}else{A=gj[c[w+196768+(x<<2)>>2]&4095](q)|0;B=A-p|0;C=B>>>24;c[2276075]=C;c[2276076]=B;D=A^p;E=B^A;F=E&D;G=F>>>24;c[2276077]=G;H=B&p;I=A^-8388608;J=B|p;K=J&I;L=K|H;M=L>>>23;c[2276078]=M;return}}function GR(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=b;g=c[2276084]|0}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=o;g=m}m=e+2|0;c[2276056]=m;e=m&-4;if((e|0)==(f|0)){p=g;q=m}else{c[2276083]=e;f=c[2276085]&e;e=f&16777212;o=c[2112932]|0;n=c[o+((e>>>10|32768)<<2)>>2]|0;if(n>>>0>9){b=f&1020;r=(d[n+(b|3)|0]|0)<<8|(d[n+(b|2)|0]|0)|((d[n+(b|1)|0]|0)<<8|(d[n+b|0]|0))<<16;s=m}else{m=gj[c[o+196768+(n<<2)>>2]&4095](e)|0;r=m;s=c[2276056]|0}c[2276084]=r;p=r>>>16|g<<16;q=s}c[2276056]=q+2;q=xw(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;s=c[2276085]&q;q=s&16777215;g=c[2112932]|0;r=c[g+(q>>>10<<2)>>2]|0;if(r>>>0>9){m=s&1023;t=(d[r+(m+3)|0]|0)<<8|(d[r+(m+2)|0]|0)|((d[r+(m+1)|0]|0)<<8|(d[r+m|0]|0))<<16;u=t-p|0;v=u>>>24;c[2276075]=v;c[2276076]=u;w=t^p;x=u^t;y=x&w;z=y>>>24;c[2276077]=z;A=u&p;B=t^-8388608;C=u|p;D=C&B;E=D|A;F=E>>>23;c[2276078]=F;return}else{t=gj[c[g+196768+(r<<2)>>2]&4095](q)|0;u=t-p|0;v=u>>>24;c[2276075]=v;c[2276076]=u;w=t^p;x=u^t;y=x&w;z=y>>>24;c[2276077]=z;A=u&p;B=t^-8388608;C=u|p;D=C&B;E=D|A;F=E>>>23;c[2276078]=F;return}}function GS(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0;g=b}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=m;g=o}o=e+2|0;c[2276056]=o;e=o&-4;if((e|0)==(g|0)){p=f;q=o;r=g;s=f}else{c[2276083]=e;g=c[2276085]&e;m=g&16777212;n=c[2112932]|0;b=c[n+((m>>>10|32768)<<2)>>2]|0;if(b>>>0>9){i=g&1020;t=(d[b+(i|3)|0]|0)<<8|(d[b+(i|2)|0]|0)|((d[b+(i|1)|0]|0)<<8|(d[b+i|0]|0))<<16;u=o;v=e}else{e=gj[c[n+196768+(b<<2)>>2]&4095](m)|0;t=e;u=c[2276056]|0;v=c[2276083]|0}c[2276084]=t;p=t>>>16|f<<16;q=u;r=v;s=t}t=q+2|0;c[2276056]=t;q=t&-4;if((q|0)==(r|0)){w=t;x=s}else{c[2276083]=q;s=c[2276085]&q;q=s&16777212;r=c[2112932]|0;v=c[r+((q>>>10|32768)<<2)>>2]|0;if(v>>>0>9){u=s&1020;y=(d[v+(u|3)|0]|0)<<8|(d[v+(u|2)|0]|0)|((d[v+(u|1)|0]|0)<<8|(d[v+u|0]|0))<<16;z=t}else{t=gj[c[r+196768+(v<<2)>>2]&4095](q)|0;y=t;z=c[2276056]|0}c[2276084]=y;w=z;x=y}c[2276056]=w+2;y=x>>>((w<<3&16^16)>>>0)<<16>>16&c[2276085];w=y&16777215;x=c[2112932]|0;z=c[x+(w>>>10<<2)>>2]|0;if(z>>>0>9){t=y&1023;A=(d[z+(t+3)|0]|0)<<8|(d[z+(t+2)|0]|0)|((d[z+(t+1)|0]|0)<<8|(d[z+t|0]|0))<<16;B=A-p|0;C=B>>>24;c[2276075]=C;c[2276076]=B;D=A^p;E=B^A;F=E&D;G=F>>>24;c[2276077]=G;H=B&p;I=A^-8388608;J=B|p;K=J&I;L=K|H;M=L>>>23;c[2276078]=M;return}else{A=gj[c[x+196768+(z<<2)>>2]&4095](w)|0;B=A-p|0;C=B>>>24;c[2276075]=C;c[2276076]=B;D=A^p;E=B^A;F=E&D;G=F>>>24;c[2276077]=G;H=B&p;I=A^-8388608;J=B|p;K=J&I;L=K|H;M=L>>>23;c[2276078]=M;return}}function GT(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0;g=b}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=m;g=o}o=e+2|0;c[2276056]=o;e=o&-4;if((e|0)==(g|0)){p=f;q=o;r=g;s=f}else{c[2276083]=e;g=c[2276085]&e;m=g&16777212;n=c[2112932]|0;b=c[n+((m>>>10|32768)<<2)>>2]|0;if(b>>>0>9){i=g&1020;t=(d[b+(i|3)|0]|0)<<8|(d[b+(i|2)|0]|0)|((d[b+(i|1)|0]|0)<<8|(d[b+i|0]|0))<<16;u=o;v=e}else{e=gj[c[n+196768+(b<<2)>>2]&4095](m)|0;t=e;u=c[2276056]|0;v=c[2276083]|0}c[2276084]=t;p=t>>>16|f<<16;q=u;r=v;s=t}t=q+2|0;c[2276056]=t;q=t&-4;if((q|0)==(r|0)){w=t;x=r;y=s}else{c[2276083]=q;s=c[2276085]&q;r=s&16777212;v=c[2112932]|0;u=c[v+((r>>>10|32768)<<2)>>2]|0;if(u>>>0>9){f=s&1020;z=(d[u+(f|3)|0]|0)<<8|(d[u+(f|2)|0]|0)|((d[u+(f|1)|0]|0)<<8|(d[u+f|0]|0))<<16;A=t;B=q}else{q=gj[c[v+196768+(u<<2)>>2]&4095](r)|0;z=q;A=c[2276056]|0;B=c[2276083]|0}c[2276084]=z;w=A;x=B;y=z}z=w+2|0;c[2276056]=z;w=z&-4;if((w|0)==(x|0)){C=y;D=z}else{c[2276083]=w;x=c[2276085]&w;w=x&16777212;B=c[2112932]|0;A=c[B+((w>>>10|32768)<<2)>>2]|0;if(A>>>0>9){q=x&1020;E=(d[A+(q|3)|0]|0)<<8|(d[A+(q|2)|0]|0)|((d[A+(q|1)|0]|0)<<8|(d[A+q|0]|0))<<16;F=z}else{z=gj[c[B+196768+(A<<2)>>2]&4095](w)|0;E=z;F=c[2276056]|0}c[2276084]=E;C=E>>>16|y<<16;D=F}c[2276056]=D+2;D=c[2276085]&C;C=D&16777215;F=c[2112932]|0;y=c[F+(C>>>10<<2)>>2]|0;if(y>>>0>9){E=D&1023;G=(d[y+(E+3)|0]|0)<<8|(d[y+(E+2)|0]|0)|((d[y+(E+1)|0]|0)<<8|(d[y+E|0]|0))<<16;H=G-p|0;I=H>>>24;c[2276075]=I;c[2276076]=H;J=G^p;K=H^G;L=K&J;M=L>>>24;c[2276077]=M;N=H&p;O=G^-8388608;P=H|p;Q=P&O;R=Q|N;S=R>>>23;c[2276078]=S;return}else{G=gj[c[F+196768+(y<<2)>>2]&4095](C)|0;H=G-p|0;I=H>>>24;c[2276075]=I;c[2276076]=H;J=G^p;K=H^G;L=K&J;M=L>>>24;c[2276077]=M;N=H&p;O=G^-8388608;P=H|p;Q=P&O;R=Q|N;S=R>>>23;c[2276078]=S;return}}function GU(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;if((c[2276038]&24|0)==0){Bl();return}a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0;g=b}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=m;g=o}o=e+2|0;c[2276056]=o;e=o&-4;if((e|0)==(g|0)){p=f;q=o;r=g;s=f}else{c[2276083]=e;g=c[2276085]&e;m=g&16777212;n=c[2112932]|0;b=c[n+((m>>>10|32768)<<2)>>2]|0;if(b>>>0>9){i=g&1020;t=(d[b+(i|3)|0]|0)<<8|(d[b+(i|2)|0]|0)|((d[b+(i|1)|0]|0)<<8|(d[b+i|0]|0))<<16;u=o;v=e}else{e=gj[c[n+196768+(b<<2)>>2]&4095](m)|0;t=e;u=c[2276056]|0;v=c[2276083]|0}c[2276084]=t;p=t>>>16|f<<16;q=u;r=v;s=t}t=q+2|0;c[2276056]=t;q=t&-4;if((q|0)==(r|0)){w=t;x=s}else{c[2276083]=q;s=c[2276085]&q;q=s&16777212;r=c[2112932]|0;v=c[r+((q>>>10|32768)<<2)>>2]|0;if(v>>>0>9){u=s&1020;y=(d[v+(u|3)|0]|0)<<8|(d[v+(u|2)|0]|0)|((d[v+(u|1)|0]|0)<<8|(d[v+u|0]|0))<<16;z=t}else{u=gj[c[r+196768+(v<<2)>>2]&4095](q)|0;y=u;z=c[2276056]|0}c[2276084]=y;w=z;x=y}c[2276056]=w+2;y=(x>>>((w<<3&16^16)>>>0)<<16>>16)+t|0;t=y&16777215;w=c[2112932]|0;x=c[w+((t>>>10|32768)<<2)>>2]|0;if(x>>>0>9){z=y&1023;A=(d[x+(z+3)|0]|0)<<8|(d[x+(z+2)|0]|0)|((d[x+(z+1)|0]|0)<<8|(d[x+z|0]|0))<<16}else{A=gj[c[w+196768+(x<<2)>>2]&4095](t)|0}t=A-p|0;c[2276075]=t>>>24;c[2276076]=t;c[2276077]=((t^A)&(A^p))>>>24;c[2276078]=((t|p)&(A^-8388608)|t&p)>>>23;return}function GV(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;if((c[2276038]&24|0)==0){Bl();return}a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=b;g=c[2276084]|0}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=o;g=m}m=e+2|0;c[2276056]=m;e=m&-4;if((e|0)==(f|0)){p=g;q=m}else{c[2276083]=e;f=c[2276085]&e;e=f&16777212;o=c[2112932]|0;n=c[o+((e>>>10|32768)<<2)>>2]|0;if(n>>>0>9){b=f&1020;r=(d[n+(b|3)|0]|0)<<8|(d[n+(b|2)|0]|0)|((d[n+(b|1)|0]|0)<<8|(d[n+b|0]|0))<<16;s=m}else{m=gj[c[o+196768+(n<<2)>>2]&4095](e)|0;r=m;s=c[2276056]|0}c[2276084]=r;p=r>>>16|g<<16;q=s}s=q+2|0;c[2276056]=s;q=xw(s)|0;s=q&16777215;g=c[2112932]|0;r=c[g+((s>>>10|32768)<<2)>>2]|0;if(r>>>0>9){m=q&1023;t=(d[r+(m+3)|0]|0)<<8|(d[r+(m+2)|0]|0)|((d[r+(m+1)|0]|0)<<8|(d[r+m|0]|0))<<16}else{t=gj[c[g+196768+(r<<2)>>2]&4095](s)|0}s=t-p|0;c[2276075]=s>>>24;c[2276076]=s;c[2276077]=((s^t)&(t^p))>>>24;c[2276078]=((s|p)&(t^-8388608)|s&p)>>>23;return}function GW(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;b=c[2276085]|0;e=b&d;d=e&16777215;f=c[2112932]|0;g=c[f+(d>>>10<<2)>>2]|0;if(g>>>0>9){h=a[g+(e&1023^1)|0]|0;i=b;j=f}else{b=gj[c[f+196608+(g<<2)>>2]&4095](d)|0;h=b;i=c[2276085]|0;j=c[2112932]|0}b=h&255;d=c[2276054]|0;c[2276054]=d+2;g=i&d;d=g&16777215;i=c[j+(d>>>10<<2)>>2]|0;if(i>>>0>9){k=a[i+(g&1023^1)|0]|0;l=k&255;m=l-b|0;c[2276075]=m;n=m&255;c[2276076]=n;o=k^h;p=o&255;q=m^l;r=q&p;c[2276077]=r;c[2276078]=m;return}else{k=gj[c[j+196608+(i<<2)>>2]&4095](d)|0;l=k&255;m=l-b|0;c[2276075]=m;n=m&255;c[2276076]=n;o=k^h;p=o&255;q=m^l;r=q&p;c[2276077]=r;c[2276078]=m;return}}function GX(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276054]|0;c[2276054]=b+2;d=c[2276085]&b;b=d&16777215;e=c[2112932]|0;f=c[e+(b>>>10<<2)>>2]|0;if(f>>>0>9){g=a[f+(d&1023^1)|0]|0;h=e}else{d=gj[c[e+196608+(f<<2)>>2]&4095](b)|0;g=d;h=c[2112932]|0}d=g&255;b=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;f=c[b>>2]|0;c[b>>2]=f+1;b=c[2276085]&f;f=b&16777215;e=c[h+(f>>>10<<2)>>2]|0;if(e>>>0>9){i=a[e+(b&1023^1)|0]|0;j=i&255;k=j-d|0;c[2276075]=k;l=k&255;c[2276076]=l;m=i^g;n=m&255;o=k^j;p=o&n;c[2276077]=p;c[2276078]=k;return}else{i=gj[c[h+196608+(e<<2)>>2]&4095](f)|0;j=i&255;k=j-d|0;c[2276075]=k;l=k&255;c[2276076]=l;m=i^g;n=m&255;o=k^j;p=o&n;c[2276077]=p;c[2276078]=k;return}}function GY(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=c[2276054]|0;d=b+2|0;c[2276054]=d;e=c[2276085]|0;f=e&b;b=f&16777215;g=c[2112932]|0;h=c[g+(b>>>10<<2)>>2]|0;if(h>>>0>9){i=a[h+(f&1023^1)|0]|0;j=d;k=e;l=g}else{e=gj[c[g+196608+(h<<2)>>2]&4095](b)|0;i=e;j=c[2276054]|0;k=c[2276085]|0;l=c[2112932]|0}c[2276054]=j+2;e=k&j;j=e&16777215;k=c[l+(j>>>10<<2)>>2]|0;if(k>>>0>9){m=a[k+(e&1023^1)|0]|0}else{m=gj[c[l+196608+(k<<2)>>2]&4095](j)|0}j=m&255;k=j-(i&255)|0;c[2276075]=k;c[2276076]=k&255;c[2276077]=(k^j)&((m^i)&255);c[2276078]=k;return}function GZ(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;b=c[2276085]&d;d=b&16777215;e=c[2112932]|0;f=c[e+(d>>>10<<2)>>2]|0;if(f>>>0>9){g=a[f+(b&1023^1)|0]|0;h=e}else{b=gj[c[e+196608+(f<<2)>>2]&4095](d)|0;g=b;h=c[2112932]|0}b=g&255;d=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;f=c[d>>2]|0;c[d>>2]=f+1;d=c[2276085]&f;f=d&16777215;e=c[h+(f>>>10<<2)>>2]|0;if(e>>>0>9){i=a[e+(d&1023^1)|0]|0;j=i&255;k=j-b|0;c[2276075]=k;l=k&255;c[2276076]=l;m=i^g;n=m&255;o=k^j;p=o&n;c[2276077]=p;c[2276078]=k;return}else{i=gj[c[h+196608+(e<<2)>>2]&4095](f)|0;j=i&255;k=j-b|0;c[2276075]=k;l=k&255;c[2276076]=l;m=i^g;n=m&255;o=k^j;p=o&n;c[2276077]=p;c[2276078]=k;return}}function G_(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;a=9104156+((c[2276069]&7|8)<<2)|0;b=c[a>>2]|0;c[a>>2]=b+2;a=c[2276085]&b;b=a&16777215;e=c[2112932]|0;f=c[e+(b>>>10<<2)>>2]|0;if(f>>>0>9){g=a&1023;h=(d[f+(g+1)|0]|0)<<8|(d[f+g|0]|0);i=e}else{g=gj[c[e+196688+(f<<2)>>2]&4095](b)|0;h=g;i=c[2112932]|0}g=h&65535;b=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;f=c[b>>2]|0;c[b>>2]=f+2;b=c[2276085]&f;f=b&16777215;e=c[i+(f>>>10<<2)>>2]|0;if(e>>>0>9){a=b&1023;j=(d[e+(a+1)|0]|0)<<8|(d[e+a|0]|0);k=j&65535;l=k-g|0;m=l>>>8;c[2276075]=m;n=l&65535;c[2276076]=n;o=j^h;p=o&65535;q=l^k;r=q&p;s=r>>>8;c[2276077]=s;c[2276078]=m;return}else{j=gj[c[i+196688+(e<<2)>>2]&4095](f)|0;k=j&65535;l=k-g|0;m=l>>>8;c[2276075]=m;n=l&65535;c[2276076]=n;o=j^h;p=o&65535;q=l^k;r=q&p;s=r>>>8;c[2276077]=s;c[2276078]=m;return}}function G$(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;a=9104156+((c[2276069]&7|8)<<2)|0;b=c[a>>2]|0;c[a>>2]=b+4;a=c[2276085]&b;b=a&16777215;e=c[2112932]|0;f=c[e+(b>>>10<<2)>>2]|0;if(f>>>0>9){g=a&1023;h=(d[f+(g+3)|0]|0)<<8|(d[f+(g+2)|0]|0)|((d[f+(g+1)|0]|0)<<8|(d[f+g|0]|0))<<16;i=e}else{g=gj[c[e+196768+(f<<2)>>2]&4095](b)|0;h=g;i=c[2112932]|0}g=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;b=c[g>>2]|0;c[g>>2]=b+4;g=c[2276085]&b;b=g&16777215;f=c[i+(b>>>10<<2)>>2]|0;if(f>>>0>9){e=g&1023;j=(d[f+(e+3)|0]|0)<<8|(d[f+(e+2)|0]|0)|((d[f+(e+1)|0]|0)<<8|(d[f+e|0]|0))<<16;k=j-h|0;l=k>>>24;c[2276075]=l;c[2276076]=k;m=j^h;n=k^j;o=n&m;p=o>>>24;c[2276077]=p;q=k&h;r=j^-8388608;s=k|h;t=s&r;u=t|q;v=u>>>23;c[2276078]=v;return}else{j=gj[c[i+196768+(f<<2)>>2]&4095](b)|0;k=j-h|0;l=k>>>24;c[2276075]=l;c[2276076]=k;m=j^h;n=k^j;o=n&m;p=o>>>24;c[2276077]=p;q=k&h;r=j^-8388608;s=k|h;t=s&r;u=t|q;v=u>>>23;c[2276078]=v;return}}function G0(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((c[2276038]&24|0)!=0){return}b=c[2276072]|0;e=c[2276073]|0;f=c[2276071]|c[2276070]|b<<11|e<<11|c[2276079]|(c[2276074]|0)>>>4&16|(c[2276075]|0)>>>4&8|((c[2276076]|0)==0)<<2|(c[2276077]|0)>>>6&2|(c[2276078]|0)>>>8&1;c[2276071]=0;c[2276070]=0;c[9104228+((b>>>1&e|b)<<2)>>2]=c[2276054];c[2276072]=4;b=c[9104228+((c[2276073]&2|4)<<2)>>2]|0;c[2276054]=b;e=c[2276055]|0;do{if(((c[2276038]|0)-1|0)>>>0<2){g=b-4|0;c[2276054]=g;h=c[2276085]&g;g=h&16777215;i=c[2112932]|0;j=c[i+((g>>>10|16384)<<2)>>2]|0;if(j>>>0>9){k=h&1023;a[j+k|0]=e>>>16&255;a[j+(k+1)|0]=e>>>24&255;a[j+(k+2)|0]=e&255;a[j+(k+3)|0]=e>>>8&255;l=i}else{gg[c[i+196808+(j<<2)>>2]&4095](g,e);l=c[2112932]|0}g=(c[2276054]|0)-2|0;c[2276054]=g;j=c[2276085]&g;g=f&65535;i=j&16777215;k=c[l+((i>>>10|16384)<<2)>>2]|0;if(k>>>0>9){h=j&1023;a[k+h|0]=f&255;a[k+(h+1)|0]=(g&65535)>>>8&255;break}else{gg[c[l+196728+(k<<2)>>2]&4095](i,g);break}}else{g=b-2|0;c[2276054]=g;i=c[2276085]&g;g=i&16777215;k=c[2112932]|0;h=c[k+((g>>>10|16384)<<2)>>2]|0;if(h>>>0>9){j=i&1023;a[h+j|0]=44;a[h+(j+1)|0]=0;m=k}else{gg[c[k+196728+(h<<2)>>2]&4095](g,44);m=c[2112932]|0}g=(c[2276054]|0)-4|0;c[2276054]=g;h=c[2276085]&g;g=h&16777215;k=c[m+((g>>>10|16384)<<2)>>2]|0;if(k>>>0>9){j=h&1023;a[k+j|0]=e>>>16&255;a[k+(j+1)|0]=e>>>24&255;a[k+(j+2)|0]=e&255;a[k+(j+3)|0]=e>>>8&255;n=m}else{gg[c[m+196808+(k<<2)>>2]&4095](g,e);n=c[2112932]|0}g=(c[2276054]|0)-2|0;c[2276054]=g;k=c[2276085]&g;g=f&65535;j=k&16777215;h=c[n+((j>>>10|16384)<<2)>>2]|0;if(h>>>0>9){i=k&1023;a[h+i|0]=f&255;a[h+(i+1)|0]=(g&65535)>>>8&255;break}else{gg[c[n+196728+(h<<2)>>2]&4095](j,g);break}}}while(0);n=(c[2276064]|0)+44|0;c[2276056]=n;f=c[2276085]&n;n=f&16777215;e=c[2112932]|0;m=c[e+(n>>>10<<2)>>2]|0;if(m>>>0>9){b=f&1023;o=(d[m+(b+3)|0]|0)<<8|(d[m+(b+2)|0]|0)|((d[m+(b+1)|0]|0)<<8|(d[m+b|0]|0))<<16}else{o=gj[c[e+196768+(m<<2)>>2]&4095](n)|0}c[2276056]=o;c[2276108]=(d[(c[2276098]|0)+(c[2276069]|0)|0]|0)-(d[(c[2276099]|0)+11|0]|0)+(c[2276108]|0);return}function G1(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((c[2276038]&24|0)!=0){return}b=c[2276072]|0;e=c[2276073]|0;f=c[2276071]|c[2276070]|b<<11|e<<11|c[2276079]|(c[2276074]|0)>>>4&16|(c[2276075]|0)>>>4&8|((c[2276076]|0)==0)<<2|(c[2276077]|0)>>>6&2|(c[2276078]|0)>>>8&1;c[2276071]=0;c[2276070]=0;c[9104228+((b>>>1&e|b)<<2)>>2]=c[2276054];c[2276072]=4;b=c[9104228+((c[2276073]&2|4)<<2)>>2]|0;c[2276054]=b;e=c[2276055]|0;do{if(((c[2276038]|0)-1|0)>>>0<2){g=b-4|0;c[2276054]=g;h=c[2276085]&g;g=h&16777215;i=c[2112932]|0;j=c[i+((g>>>10|16384)<<2)>>2]|0;if(j>>>0>9){k=h&1023;a[j+k|0]=e>>>16&255;a[j+(k+1)|0]=e>>>24&255;a[j+(k+2)|0]=e&255;a[j+(k+3)|0]=e>>>8&255;l=i}else{gg[c[i+196808+(j<<2)>>2]&4095](g,e);l=c[2112932]|0}g=(c[2276054]|0)-2|0;c[2276054]=g;j=c[2276085]&g;g=f&65535;i=j&16777215;k=c[l+((i>>>10|16384)<<2)>>2]|0;if(k>>>0>9){h=j&1023;a[k+h|0]=f&255;a[k+(h+1)|0]=(g&65535)>>>8&255;break}else{gg[c[l+196728+(k<<2)>>2]&4095](i,g);break}}else{g=b-2|0;c[2276054]=g;i=c[2276085]&g;g=i&16777215;k=c[2112932]|0;h=c[k+((g>>>10|16384)<<2)>>2]|0;if(h>>>0>9){j=i&1023;a[h+j|0]=44;a[h+(j+1)|0]=0;m=k}else{gg[c[k+196728+(h<<2)>>2]&4095](g,44);m=c[2112932]|0}g=(c[2276054]|0)-4|0;c[2276054]=g;h=c[2276085]&g;g=h&16777215;k=c[m+((g>>>10|16384)<<2)>>2]|0;if(k>>>0>9){j=h&1023;a[k+j|0]=e>>>16&255;a[k+(j+1)|0]=e>>>24&255;a[k+(j+2)|0]=e&255;a[k+(j+3)|0]=e>>>8&255;n=m}else{gg[c[m+196808+(k<<2)>>2]&4095](g,e);n=c[2112932]|0}g=(c[2276054]|0)-2|0;c[2276054]=g;k=c[2276085]&g;g=f&65535;j=k&16777215;h=c[n+((j>>>10|16384)<<2)>>2]|0;if(h>>>0>9){i=k&1023;a[h+i|0]=f&255;a[h+(i+1)|0]=(g&65535)>>>8&255;break}else{gg[c[n+196728+(h<<2)>>2]&4095](j,g);break}}}while(0);n=(c[2276064]|0)+44|0;c[2276056]=n;f=c[2276085]&n;n=f&16777215;e=c[2112932]|0;m=c[e+(n>>>10<<2)>>2]|0;if(m>>>0>9){b=f&1023;o=(d[m+(b+3)|0]|0)<<8|(d[m+(b+2)|0]|0)|((d[m+(b+1)|0]|0)<<8|(d[m+b|0]|0))<<16}else{o=gj[c[e+196768+(m<<2)>>2]&4095](n)|0}c[2276056]=o;c[2276108]=(d[(c[2276098]|0)+(c[2276069]|0)|0]|0)-(d[(c[2276099]|0)+11|0]|0)+(c[2276108]|0);return}function G2(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((c[2276038]&24|0)!=0){return}b=c[2276072]|0;e=c[2276073]|0;f=c[2276071]|c[2276070]|b<<11|e<<11|c[2276079]|(c[2276074]|0)>>>4&16|(c[2276075]|0)>>>4&8|((c[2276076]|0)==0)<<2|(c[2276077]|0)>>>6&2|(c[2276078]|0)>>>8&1;c[2276071]=0;c[2276070]=0;c[9104228+((b>>>1&e|b)<<2)>>2]=c[2276054];c[2276072]=4;b=c[9104228+((c[2276073]&2|4)<<2)>>2]|0;c[2276054]=b;e=c[2276055]|0;do{if(((c[2276038]|0)-1|0)>>>0<2){g=b-4|0;c[2276054]=g;h=c[2276085]&g;g=h&16777215;i=c[2112932]|0;j=c[i+((g>>>10|16384)<<2)>>2]|0;if(j>>>0>9){k=h&1023;a[j+k|0]=e>>>16&255;a[j+(k+1)|0]=e>>>24&255;a[j+(k+2)|0]=e&255;a[j+(k+3)|0]=e>>>8&255;l=i}else{gg[c[i+196808+(j<<2)>>2]&4095](g,e);l=c[2112932]|0}g=(c[2276054]|0)-2|0;c[2276054]=g;j=c[2276085]&g;g=f&65535;i=j&16777215;k=c[l+((i>>>10|16384)<<2)>>2]|0;if(k>>>0>9){h=j&1023;a[k+h|0]=f&255;a[k+(h+1)|0]=(g&65535)>>>8&255;break}else{gg[c[l+196728+(k<<2)>>2]&4095](i,g);break}}else{g=b-2|0;c[2276054]=g;i=c[2276085]&g;g=i&16777215;k=c[2112932]|0;h=c[k+((g>>>10|16384)<<2)>>2]|0;if(h>>>0>9){j=i&1023;a[h+j|0]=44;a[h+(j+1)|0]=0;m=k}else{gg[c[k+196728+(h<<2)>>2]&4095](g,44);m=c[2112932]|0}g=(c[2276054]|0)-4|0;c[2276054]=g;h=c[2276085]&g;g=h&16777215;k=c[m+((g>>>10|16384)<<2)>>2]|0;if(k>>>0>9){j=h&1023;a[k+j|0]=e>>>16&255;a[k+(j+1)|0]=e>>>24&255;a[k+(j+2)|0]=e&255;a[k+(j+3)|0]=e>>>8&255;n=m}else{gg[c[m+196808+(k<<2)>>2]&4095](g,e);n=c[2112932]|0}g=(c[2276054]|0)-2|0;c[2276054]=g;k=c[2276085]&g;g=f&65535;j=k&16777215;h=c[n+((j>>>10|16384)<<2)>>2]|0;if(h>>>0>9){i=k&1023;a[h+i|0]=f&255;a[h+(i+1)|0]=(g&65535)>>>8&255;break}else{gg[c[n+196728+(h<<2)>>2]&4095](j,g);break}}}while(0);n=(c[2276064]|0)+44|0;c[2276056]=n;f=c[2276085]&n;n=f&16777215;e=c[2112932]|0;m=c[e+(n>>>10<<2)>>2]|0;if(m>>>0>9){b=f&1023;o=(d[m+(b+3)|0]|0)<<8|(d[m+(b+2)|0]|0)|((d[m+(b+1)|0]|0)<<8|(d[m+b|0]|0))<<16}else{o=gj[c[e+196768+(m<<2)>>2]&4095](n)|0}c[2276056]=o;c[2276108]=(d[(c[2276098]|0)+(c[2276069]|0)|0]|0)-(d[(c[2276099]|0)+11|0]|0)+(c[2276108]|0);return}function G3(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((c[2276038]&24|0)!=0){return}b=c[2276072]|0;e=c[2276073]|0;f=c[2276071]|c[2276070]|b<<11|e<<11|c[2276079]|(c[2276074]|0)>>>4&16|(c[2276075]|0)>>>4&8|((c[2276076]|0)==0)<<2|(c[2276077]|0)>>>6&2|(c[2276078]|0)>>>8&1;c[2276071]=0;c[2276070]=0;c[9104228+((b>>>1&e|b)<<2)>>2]=c[2276054];c[2276072]=4;b=c[9104228+((c[2276073]&2|4)<<2)>>2]|0;c[2276054]=b;e=c[2276055]|0;do{if(((c[2276038]|0)-1|0)>>>0<2){g=b-4|0;c[2276054]=g;h=c[2276085]&g;g=h&16777215;i=c[2112932]|0;j=c[i+((g>>>10|16384)<<2)>>2]|0;if(j>>>0>9){k=h&1023;a[j+k|0]=e>>>16&255;a[j+(k+1)|0]=e>>>24&255;a[j+(k+2)|0]=e&255;a[j+(k+3)|0]=e>>>8&255;l=i}else{gg[c[i+196808+(j<<2)>>2]&4095](g,e);l=c[2112932]|0}g=(c[2276054]|0)-2|0;c[2276054]=g;j=c[2276085]&g;g=f&65535;i=j&16777215;k=c[l+((i>>>10|16384)<<2)>>2]|0;if(k>>>0>9){h=j&1023;a[k+h|0]=f&255;a[k+(h+1)|0]=(g&65535)>>>8&255;break}else{gg[c[l+196728+(k<<2)>>2]&4095](i,g);break}}else{g=b-2|0;c[2276054]=g;i=c[2276085]&g;g=i&16777215;k=c[2112932]|0;h=c[k+((g>>>10|16384)<<2)>>2]|0;if(h>>>0>9){j=i&1023;a[h+j|0]=44;a[h+(j+1)|0]=0;m=k}else{gg[c[k+196728+(h<<2)>>2]&4095](g,44);m=c[2112932]|0}g=(c[2276054]|0)-4|0;c[2276054]=g;h=c[2276085]&g;g=h&16777215;k=c[m+((g>>>10|16384)<<2)>>2]|0;if(k>>>0>9){j=h&1023;a[k+j|0]=e>>>16&255;a[k+(j+1)|0]=e>>>24&255;a[k+(j+2)|0]=e&255;a[k+(j+3)|0]=e>>>8&255;n=m}else{gg[c[m+196808+(k<<2)>>2]&4095](g,e);n=c[2112932]|0}g=(c[2276054]|0)-2|0;c[2276054]=g;k=c[2276085]&g;g=f&65535;j=k&16777215;h=c[n+((j>>>10|16384)<<2)>>2]|0;if(h>>>0>9){i=k&1023;a[h+i|0]=f&255;a[h+(i+1)|0]=(g&65535)>>>8&255;break}else{gg[c[n+196728+(h<<2)>>2]&4095](j,g);break}}}while(0);n=(c[2276064]|0)+44|0;c[2276056]=n;f=c[2276085]&n;n=f&16777215;e=c[2112932]|0;m=c[e+(n>>>10<<2)>>2]|0;if(m>>>0>9){b=f&1023;o=(d[m+(b+3)|0]|0)<<8|(d[m+(b+2)|0]|0)|((d[m+(b+1)|0]|0)<<8|(d[m+b|0]|0))<<16}else{o=gj[c[e+196768+(m<<2)>>2]&4095](n)|0}c[2276056]=o;c[2276108]=(d[(c[2276098]|0)+(c[2276069]|0)|0]|0)-(d[(c[2276099]|0)+11|0]|0)+(c[2276108]|0);return}function G4(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((c[2276038]&24|0)!=0){return}b=c[2276072]|0;e=c[2276073]|0;f=c[2276071]|c[2276070]|b<<11|e<<11|c[2276079]|(c[2276074]|0)>>>4&16|(c[2276075]|0)>>>4&8|((c[2276076]|0)==0)<<2|(c[2276077]|0)>>>6&2|(c[2276078]|0)>>>8&1;c[2276071]=0;c[2276070]=0;c[9104228+((b>>>1&e|b)<<2)>>2]=c[2276054];c[2276072]=4;b=c[9104228+((c[2276073]&2|4)<<2)>>2]|0;c[2276054]=b;e=c[2276055]|0;do{if(((c[2276038]|0)-1|0)>>>0<2){g=b-4|0;c[2276054]=g;h=c[2276085]&g;g=h&16777215;i=c[2112932]|0;j=c[i+((g>>>10|16384)<<2)>>2]|0;if(j>>>0>9){k=h&1023;a[j+k|0]=e>>>16&255;a[j+(k+1)|0]=e>>>24&255;a[j+(k+2)|0]=e&255;a[j+(k+3)|0]=e>>>8&255;l=i}else{gg[c[i+196808+(j<<2)>>2]&4095](g,e);l=c[2112932]|0}g=(c[2276054]|0)-2|0;c[2276054]=g;j=c[2276085]&g;g=f&65535;i=j&16777215;k=c[l+((i>>>10|16384)<<2)>>2]|0;if(k>>>0>9){h=j&1023;a[k+h|0]=f&255;a[k+(h+1)|0]=(g&65535)>>>8&255;break}else{gg[c[l+196728+(k<<2)>>2]&4095](i,g);break}}else{g=b-2|0;c[2276054]=g;i=c[2276085]&g;g=i&16777215;k=c[2112932]|0;h=c[k+((g>>>10|16384)<<2)>>2]|0;if(h>>>0>9){j=i&1023;a[h+j|0]=44;a[h+(j+1)|0]=0;m=k}else{gg[c[k+196728+(h<<2)>>2]&4095](g,44);m=c[2112932]|0}g=(c[2276054]|0)-4|0;c[2276054]=g;h=c[2276085]&g;g=h&16777215;k=c[m+((g>>>10|16384)<<2)>>2]|0;if(k>>>0>9){j=h&1023;a[k+j|0]=e>>>16&255;a[k+(j+1)|0]=e>>>24&255;a[k+(j+2)|0]=e&255;a[k+(j+3)|0]=e>>>8&255;n=m}else{gg[c[m+196808+(k<<2)>>2]&4095](g,e);n=c[2112932]|0}g=(c[2276054]|0)-2|0;c[2276054]=g;k=c[2276085]&g;g=f&65535;j=k&16777215;h=c[n+((j>>>10|16384)<<2)>>2]|0;if(h>>>0>9){i=k&1023;a[h+i|0]=f&255;a[h+(i+1)|0]=(g&65535)>>>8&255;break}else{gg[c[n+196728+(h<<2)>>2]&4095](j,g);break}}}while(0);n=(c[2276064]|0)+44|0;c[2276056]=n;f=c[2276085]&n;n=f&16777215;e=c[2112932]|0;m=c[e+(n>>>10<<2)>>2]|0;if(m>>>0>9){b=f&1023;o=(d[m+(b+3)|0]|0)<<8|(d[m+(b+2)|0]|0)|((d[m+(b+1)|0]|0)<<8|(d[m+b|0]|0))<<16}else{o=gj[c[e+196768+(m<<2)>>2]&4095](n)|0}c[2276056]=o;c[2276108]=(d[(c[2276098]|0)+(c[2276069]|0)|0]|0)-(d[(c[2276099]|0)+11|0]|0)+(c[2276108]|0);return}function G5(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0;a=9104156+((c[2276069]&7)<<2)|0;b=154-(c[a>>2]|0)-((c[2276074]|0)>>>8&1)|0;d=b&255;if((d|0)==154){c[2276077]=0;e=154;f=0;c[2276078]=f;c[2276074]=f;c[2276075]=e;return}g=(b|-256)^255;c[2276077]=g;if((b&15|0)==10){h=(b&240)+16|0}else{h=d}d=h&255;c[2276077]=d&g;c[a>>2]=c[a>>2]&-256|d;c[2276076]=c[2276076]|d;e=d;f=256;c[2276078]=f;c[2276074]=f;c[2276075]=e;return}function G6(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;d=c[2276085]&b;e=d&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=a[g+(d&1023^1)|0]|0}else{h=gj[c[f+196608+(g<<2)>>2]&4095](e)|0}e=154-(h&255)-((c[2276074]|0)>>>8&1)|0;h=e&255;if((h|0)==154){c[2276077]=0;i=154;j=0;c[2276078]=j;c[2276074]=j;c[2276075]=i;return}g=(e|-256)^255;c[2276077]=g;if((e&15|0)==10){k=(e&240)+16|0}else{k=h}h=k&255;c[2276077]=h&g;g=c[2276085]&b;b=k&255;k=g&16777215;e=c[2112932]|0;f=c[e+((k>>>10|16384)<<2)>>2]|0;if(f>>>0>9){a[f+(g&1023^1)|0]=b}else{gg[c[e+196648+(f<<2)>>2]&4095](k,b)}c[2276076]=c[2276076]|h;i=h;j=256;c[2276078]=j;c[2276074]=j;c[2276075]=i;return}function G7(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;b=c[2276085]&d;e=b&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=a[g+(b&1023^1)|0]|0}else{h=gj[c[f+196608+(g<<2)>>2]&4095](e)|0}e=154-(h&255)-((c[2276074]|0)>>>8&1)|0;h=e&255;if((h|0)==154){c[2276077]=0;i=154;j=0;c[2276078]=j;c[2276074]=j;c[2276075]=i;return}g=(e|-256)^255;c[2276077]=g;if((e&15|0)==10){k=(e&240)+16|0}else{k=h}h=k&255;c[2276077]=h&g;g=c[2276085]&d;d=k&255;k=g&16777215;e=c[2112932]|0;f=c[e+((k>>>10|16384)<<2)>>2]|0;if(f>>>0>9){a[f+(g&1023^1)|0]=d}else{gg[c[e+196648+(f<<2)>>2]&4095](k,d)}c[2276076]=c[2276076]|h;i=h;j=256;c[2276078]=j;c[2276074]=j;c[2276075]=i;return}function G8(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[2276054]|0;c[2276054]=b+2;d=c[2276085]&b;e=d&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=a[g+(d&1023^1)|0]|0}else{h=gj[c[f+196608+(g<<2)>>2]&4095](e)|0}e=154-(h&255)-((c[2276074]|0)>>>8&1)|0;h=e&255;if((h|0)==154){c[2276077]=0;i=154;j=0;c[2276078]=j;c[2276074]=j;c[2276075]=i;return}g=(e|-256)^255;c[2276077]=g;if((e&15|0)==10){k=(e&240)+16|0}else{k=h}h=k&255;c[2276077]=h&g;g=c[2276085]&b;b=k&255;k=g&16777215;e=c[2112932]|0;f=c[e+((k>>>10|16384)<<2)>>2]|0;if(f>>>0>9){a[f+(g&1023^1)|0]=b}else{gg[c[e+196648+(f<<2)>>2]&4095](k,b)}c[2276076]=c[2276076]|h;i=h;j=256;c[2276078]=j;c[2276074]=j;c[2276075]=i;return}function G9(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;b=c[2276085]&d;e=b&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=a[g+(b&1023^1)|0]|0}else{h=gj[c[f+196608+(g<<2)>>2]&4095](e)|0}e=154-(h&255)-((c[2276074]|0)>>>8&1)|0;h=e&255;if((h|0)==154){c[2276077]=0;i=154;j=0;c[2276078]=j;c[2276074]=j;c[2276075]=i;return}g=(e|-256)^255;c[2276077]=g;if((e&15|0)==10){k=(e&240)+16|0}else{k=h}h=k&255;c[2276077]=h&g;g=c[2276085]&d;d=k&255;k=g&16777215;e=c[2112932]|0;f=c[e+((k>>>10|16384)<<2)>>2]|0;if(f>>>0>9){a[f+(g&1023^1)|0]=d}else{gg[c[e+196648+(f<<2)>>2]&4095](k,d)}c[2276076]=c[2276076]|h;i=h;j=256;c[2276078]=j;c[2276074]=j;c[2276075]=i;return}function Ha(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=(c[2276054]|0)-2|0;c[2276054]=b;d=c[2276085]&b;e=d&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=a[g+(d&1023^1)|0]|0}else{h=gj[c[f+196608+(g<<2)>>2]&4095](e)|0}e=154-(h&255)-((c[2276074]|0)>>>8&1)|0;h=e&255;if((h|0)==154){c[2276077]=0;i=154;j=0;c[2276078]=j;c[2276074]=j;c[2276075]=i;return}g=(e|-256)^255;c[2276077]=g;if((e&15|0)==10){k=(e&240)+16|0}else{k=h}h=k&255;c[2276077]=h&g;g=c[2276085]&b;b=k&255;k=g&16777215;e=c[2112932]|0;f=c[e+((k>>>10|16384)<<2)>>2]|0;if(f>>>0>9){a[f+(g&1023^1)|0]=b}else{gg[c[e+196648+(f<<2)>>2]&4095](k,b)}c[2276076]=c[2276076]|h;i=h;j=256;c[2276078]=j;c[2276074]=j;c[2276075]=i;return}function Hb(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=(h>>>((g<<3&16^16)>>>0)<<16>>16)+b|0;b=m&c[2276085];g=b&16777215;h=c[2112932]|0;n=c[h+(g>>>10<<2)>>2]|0;if(n>>>0>9){o=a[n+(b&1023^1)|0]|0}else{o=gj[c[h+196608+(n<<2)>>2]&4095](g)|0}g=154-(o&255)-((c[2276074]|0)>>>8&1)|0;o=g&255;if((o|0)==154){c[2276077]=0;p=154;q=0;c[2276078]=q;c[2276074]=q;c[2276075]=p;return}n=(g|-256)^255;c[2276077]=n;if((g&15|0)==10){r=(g&240)+16|0}else{r=o}o=r&255;c[2276077]=o&n;n=c[2276085]&m;m=r&255;r=n&16777215;g=c[2112932]|0;h=c[g+((r>>>10|16384)<<2)>>2]|0;if(h>>>0>9){a[h+(n&1023^1)|0]=m}else{gg[c[g+196648+(h<<2)>>2]&4095](r,m)}c[2276076]=c[2276076]|o;p=o;q=256;c[2276078]=q;c[2276074]=q;c[2276075]=p;return}function Hc(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=Hd(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;d=c[2276085]&b;e=d&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=a[g+(d&1023^1)|0]|0}else{h=gj[c[f+196608+(g<<2)>>2]&4095](e)|0}e=154-(h&255)-((c[2276074]|0)>>>8&1)|0;h=e&255;if((h|0)==154){c[2276077]=0;i=154;j=0;c[2276078]=j;c[2276074]=j;c[2276075]=i;return}g=(e|-256)^255;c[2276077]=g;if((e&15|0)==10){k=(e&240)+16|0}else{k=h}h=k&255;c[2276077]=h&g;g=c[2276085]&b;b=k&255;k=g&16777215;e=c[2112932]|0;f=c[e+((k>>>10|16384)<<2)>>2]|0;if(f>>>0>9){a[f+(g&1023^1)|0]=b}else{gg[c[e+196648+(f<<2)>>2]&4095](k,b)}c[2276076]=c[2276076]|h;i=h;j=256;c[2276078]=j;c[2276074]=j;c[2276075]=i;return}function Hd(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}l=f+2|0;c[2276056]=l;m=g>>>((f<<3&16^16)>>>0);f=m&65535;b=c[2276038]|0;if((b&7|0)!=0){e=c[9104156+(f>>>12<<2)>>2]|0;if((m&2048|0)==0){n=e<<16>>16}else{n=e}o=(m<<24>>24)+a+n|0;return o|0}if((m&256|0)==0){n=c[9104156+(f>>>12<<2)>>2]|0;if((m&2048|0)==0){p=n<<16>>16}else{p=n}if((b&24|0)==0){q=p}else{q=p<<(m>>>9&3)}o=(m<<24>>24)+a+q|0;return o|0}c[2276108]=(c[2276108]|0)-(d[11928+(m&63)|0]|0);q=(m&128|0)==0?a:0;if((m&64|0)==0){a=c[9104156+(f>>>12<<2)>>2]|0;if((m&2048|0)==0){r=a<<16>>16}else{r=a}s=r<<(m>>>9&3)}else{s=0}do{if((m&32|0)==0){t=0;u=l;v=g}else{r=l&-4;a=(r|0)==(c[2276083]|0);if((m&16|0)==0){if(a){w=l;x=g}else{c[2276083]=r;f=c[2276085]&r;p=f&16777212;b=c[2112932]|0;n=c[b+((p>>>10|32768)<<2)>>2]|0;if(n>>>0>9){e=f&1020;y=(d[n+(e|3)|0]|0)<<8|(d[n+(e|2)|0]|0)|((d[n+(e|1)|0]|0)<<8|(d[n+e|0]|0))<<16;z=l}else{e=gj[c[b+196768+(n<<2)>>2]&4095](p)|0;y=e;z=c[2276056]|0}c[2276084]=y;w=z;x=y}e=w+2|0;c[2276056]=e;t=x>>>((w<<3&16^16)>>>0)<<16>>16;u=e;v=x;break}if(a){A=l;B=r;C=g}else{c[2276083]=r;a=c[2276085]&r;e=a&16777212;p=c[2112932]|0;n=c[p+((e>>>10|32768)<<2)>>2]|0;if(n>>>0>9){b=a&1020;D=(d[n+(b|3)|0]|0)<<8|(d[n+(b|2)|0]|0)|((d[n+(b|1)|0]|0)<<8|(d[n+b|0]|0))<<16;E=l;F=r}else{r=gj[c[p+196768+(n<<2)>>2]&4095](e)|0;D=r;E=c[2276056]|0;F=c[2276083]|0}c[2276084]=D;A=E;B=F;C=D}r=A+2|0;c[2276056]=r;e=r&-4;if((e|0)==(B|0)){G=C;H=r;I=C}else{c[2276083]=e;n=c[2276085]&e;e=n&16777212;p=c[2112932]|0;b=c[p+((e>>>10|32768)<<2)>>2]|0;if(b>>>0>9){a=n&1020;J=(d[b+(a|3)|0]|0)<<8|(d[b+(a|2)|0]|0)|((d[b+(a|1)|0]|0)<<8|(d[b+a|0]|0))<<16;K=r}else{r=gj[c[p+196768+(b<<2)>>2]&4095](e)|0;J=r;K=c[2276056]|0}c[2276084]=J;G=J>>>16|C<<16;H=K;I=J}r=H+2|0;c[2276056]=r;t=G;u=r;v=I}}while(0);if((m&7|0)==0){o=s+q+t|0;return o|0}do{if((m&2|0)==0){L=0}else{I=u&-4;G=(I|0)==(c[2276083]|0);if((m&1|0)==0){if(G){M=u;N=v}else{c[2276083]=I;H=c[2276085]&I;J=H&16777212;K=c[2112932]|0;C=c[K+((J>>>10|32768)<<2)>>2]|0;if(C>>>0>9){B=H&1020;O=(d[C+(B|3)|0]|0)<<8|(d[C+(B|2)|0]|0)|((d[C+(B|1)|0]|0)<<8|(d[C+B|0]|0))<<16;P=u}else{B=gj[c[K+196768+(C<<2)>>2]&4095](J)|0;O=B;P=c[2276056]|0}c[2276084]=O;M=P;N=O}c[2276056]=M+2;L=N>>>((M<<3&16^16)>>>0)<<16>>16;break}if(G){Q=u;R=I;S=v}else{c[2276083]=I;G=c[2276085]&I;B=G&16777212;J=c[2112932]|0;C=c[J+((B>>>10|32768)<<2)>>2]|0;if(C>>>0>9){K=G&1020;T=(d[C+(K|3)|0]|0)<<8|(d[C+(K|2)|0]|0)|((d[C+(K|1)|0]|0)<<8|(d[C+K|0]|0))<<16;U=u;V=I}else{I=gj[c[J+196768+(C<<2)>>2]&4095](B)|0;T=I;U=c[2276056]|0;V=c[2276083]|0}c[2276084]=T;Q=U;R=V;S=T}I=Q+2|0;c[2276056]=I;B=I&-4;if((B|0)==(R|0)){W=S;X=I}else{c[2276083]=B;C=c[2276085]&B;B=C&16777212;J=c[2112932]|0;K=c[J+((B>>>10|32768)<<2)>>2]|0;if(K>>>0>9){G=C&1020;Y=(d[K+(G|3)|0]|0)<<8|(d[K+(G|2)|0]|0)|((d[K+(G|1)|0]|0)<<8|(d[K+G|0]|0))<<16;Z=I}else{I=gj[c[J+196768+(K<<2)>>2]&4095](B)|0;Y=I;Z=c[2276056]|0}c[2276084]=Y;W=Y>>>16|S<<16;X=Z}c[2276056]=X+2;L=W}}while(0);W=t+q|0;if((m&4|0)==0){m=c[2276085]&W+s;q=m&16777215;t=c[2112932]|0;X=c[t+(q>>>10<<2)>>2]|0;if(X>>>0>9){Z=m&1023;_=(d[X+(Z+3)|0]|0)<<8|(d[X+(Z+2)|0]|0)|((d[X+(Z+1)|0]|0)<<8|(d[X+Z|0]|0))<<16}else{_=gj[c[t+196768+(X<<2)>>2]&4095](q)|0}o=_+L|0;return o|0}else{_=c[2276085]&W;W=_&16777215;q=c[2112932]|0;X=c[q+(W>>>10<<2)>>2]|0;if(X>>>0>9){t=_&1023;$=(d[X+(t+3)|0]|0)<<8|(d[X+(t+2)|0]|0)|((d[X+(t+1)|0]|0)<<8|(d[X+t|0]|0))<<16}else{$=gj[c[q+196768+(X<<2)>>2]&4095](W)|0}o=L+s+$|0;return o|0}return 0}function He(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)<<16>>16;f=l&c[2276085];g=f&16777215;m=c[2112932]|0;b=c[m+(g>>>10<<2)>>2]|0;if(b>>>0>9){n=a[b+(f&1023^1)|0]|0}else{n=gj[c[m+196608+(b<<2)>>2]&4095](g)|0}g=154-(n&255)-((c[2276074]|0)>>>8&1)|0;n=g&255;if((n|0)==154){c[2276077]=0;o=154;p=0;c[2276078]=p;c[2276074]=p;c[2276075]=o;return}b=(g|-256)^255;c[2276077]=b;if((g&15|0)==10){q=(g&240)+16|0}else{q=n}n=q&255;c[2276077]=n&b;b=c[2276085]&l;l=q&255;q=b&16777215;g=c[2112932]|0;m=c[g+((q>>>10|16384)<<2)>>2]|0;if(m>>>0>9){a[m+(b&1023^1)|0]=l}else{gg[c[g+196648+(m<<2)>>2]&4095](q,l)}c[2276076]=c[2276076]|n;o=n;p=256;c[2276078]=p;c[2276074]=p;c[2276075]=o;return}function Hf(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[2276085]&q;t=r&16777215;h=c[2112932]|0;s=c[h+(t>>>10<<2)>>2]|0;if(s>>>0>9){u=a[s+(r&1023^1)|0]|0}else{u=gj[c[h+196608+(s<<2)>>2]&4095](t)|0}t=154-(u&255)-((c[2276074]|0)>>>8&1)|0;u=t&255;if((u|0)==154){c[2276077]=0;v=154;w=0;c[2276078]=w;c[2276074]=w;c[2276075]=v;return}s=(t|-256)^255;c[2276077]=s;if((t&15|0)==10){x=(t&240)+16|0}else{x=u}u=x&255;c[2276077]=u&s;s=c[2276085]&q;q=x&255;x=s&16777215;t=c[2112932]|0;h=c[t+((x>>>10|16384)<<2)>>2]|0;if(h>>>0>9){a[h+(s&1023^1)|0]=q}else{gg[c[t+196648+(h<<2)>>2]&4095](x,q)}c[2276076]=c[2276076]|u;v=u;w=256;c[2276078]=w;c[2276074]=w;c[2276075]=v;return}function Hg(){var a=0,b=0,d=0;a=9104156+((c[2276069]&7)<<2)|0;b=-(c[a>>2]&255)|0;c[2276075]=b;c[2276074]=b;c[2276078]=b;c[2276077]=c[a>>2]&b;d=b&255;c[2276076]=d;c[a>>2]=c[a>>2]&-256|d;return}function Hh(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;d=c[2276085]|0;e=d&b;f=e&16777215;g=c[2112932]|0;h=c[g+(f>>>10<<2)>>2]|0;if(h>>>0>9){i=a[h+(e&1023^1)|0]|0;j=d;k=g}else{d=gj[c[g+196608+(h<<2)>>2]&4095](f)|0;i=d;j=c[2276085]|0;k=c[2112932]|0}d=i&255;i=-d|0;c[2276075]=i;c[2276074]=i;c[2276078]=i;c[2276077]=d&i;c[2276076]=i&255;d=j&b;b=i&255;i=d&16777215;j=c[k+((i>>>10|16384)<<2)>>2]|0;if(j>>>0>9){a[j+(d&1023^1)|0]=b;return}else{gg[c[k+196648+(j<<2)>>2]&4095](i,b);return}}function Hi(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;b=c[2276085]|0;e=b&d;f=e&16777215;g=c[2112932]|0;h=c[g+(f>>>10<<2)>>2]|0;if(h>>>0>9){i=a[h+(e&1023^1)|0]|0;j=b;k=g}else{b=gj[c[g+196608+(h<<2)>>2]&4095](f)|0;i=b;j=c[2276085]|0;k=c[2112932]|0}b=i&255;i=-b|0;c[2276075]=i;c[2276074]=i;c[2276078]=i;c[2276077]=b&i;c[2276076]=i&255;b=j&d;d=i&255;i=b&16777215;j=c[k+((i>>>10|16384)<<2)>>2]|0;if(j>>>0>9){a[j+(b&1023^1)|0]=d;return}else{gg[c[k+196648+(j<<2)>>2]&4095](i,d);return}}function Hj(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[2276054]|0;c[2276054]=b+2;d=c[2276085]|0;e=d&b;f=e&16777215;g=c[2112932]|0;h=c[g+(f>>>10<<2)>>2]|0;if(h>>>0>9){i=a[h+(e&1023^1)|0]|0;j=d;k=g}else{d=gj[c[g+196608+(h<<2)>>2]&4095](f)|0;i=d;j=c[2276085]|0;k=c[2112932]|0}d=i&255;i=-d|0;c[2276075]=i;c[2276074]=i;c[2276078]=i;c[2276077]=d&i;c[2276076]=i&255;d=j&b;b=i&255;i=d&16777215;j=c[k+((i>>>10|16384)<<2)>>2]|0;if(j>>>0>9){a[j+(d&1023^1)|0]=b;return}else{gg[c[k+196648+(j<<2)>>2]&4095](i,b);return}}function Hk(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;b=c[2276085]|0;e=b&d;f=e&16777215;g=c[2112932]|0;h=c[g+(f>>>10<<2)>>2]|0;if(h>>>0>9){i=a[h+(e&1023^1)|0]|0;j=b;k=g}else{b=gj[c[g+196608+(h<<2)>>2]&4095](f)|0;i=b;j=c[2276085]|0;k=c[2112932]|0}b=i&255;i=-b|0;c[2276075]=i;c[2276074]=i;c[2276078]=i;c[2276077]=b&i;c[2276076]=i&255;b=j&d;d=i&255;i=b&16777215;j=c[k+((i>>>10|16384)<<2)>>2]|0;if(j>>>0>9){a[j+(b&1023^1)|0]=d;return}else{gg[c[k+196648+(j<<2)>>2]&4095](i,d);return}}function Hl(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=(c[2276054]|0)-2|0;c[2276054]=b;d=c[2276085]|0;e=d&b;f=e&16777215;g=c[2112932]|0;h=c[g+(f>>>10<<2)>>2]|0;if(h>>>0>9){i=a[h+(e&1023^1)|0]|0;j=d;k=g}else{d=gj[c[g+196608+(h<<2)>>2]&4095](f)|0;i=d;j=c[2276085]|0;k=c[2112932]|0}d=i&255;i=-d|0;c[2276075]=i;c[2276074]=i;c[2276078]=i;c[2276077]=d&i;c[2276076]=i&255;d=j&b;b=i&255;i=d&16777215;j=c[k+((i>>>10|16384)<<2)>>2]|0;if(j>>>0>9){a[j+(d&1023^1)|0]=b;return}else{gg[c[k+196648+(j<<2)>>2]&4095](i,b);return}}function Hm(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=(h>>>((g<<3&16^16)>>>0)<<16>>16)+b|0;b=c[2276085]|0;g=m&b;h=g&16777215;n=c[2112932]|0;e=c[n+(h>>>10<<2)>>2]|0;if(e>>>0>9){o=a[e+(g&1023^1)|0]|0;p=b;q=n}else{b=gj[c[n+196608+(e<<2)>>2]&4095](h)|0;o=b;p=c[2276085]|0;q=c[2112932]|0}b=o&255;o=-b|0;c[2276075]=o;c[2276074]=o;c[2276078]=o;c[2276077]=b&o;c[2276076]=o&255;b=p&m;m=o&255;o=b&16777215;p=c[q+((o>>>10|16384)<<2)>>2]|0;if(p>>>0>9){a[p+(b&1023^1)|0]=m;return}else{gg[c[q+196648+(p<<2)>>2]&4095](o,m);return}}function Hn(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=Hd(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;d=c[2276085]|0;e=d&b;f=e&16777215;g=c[2112932]|0;h=c[g+(f>>>10<<2)>>2]|0;if(h>>>0>9){i=a[h+(e&1023^1)|0]|0;j=d;k=g}else{d=gj[c[g+196608+(h<<2)>>2]&4095](f)|0;i=d;j=c[2276085]|0;k=c[2112932]|0}d=i&255;i=-d|0;c[2276075]=i;c[2276074]=i;c[2276078]=i;c[2276077]=d&i;c[2276076]=i&255;d=j&b;b=i&255;i=d&16777215;j=c[k+((i>>>10|16384)<<2)>>2]|0;if(j>>>0>9){a[j+(d&1023^1)|0]=b;return}else{gg[c[k+196648+(j<<2)>>2]&4095](i,b);return}}function Ho(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)<<16>>16;f=c[2276085]|0;g=l&f;m=g&16777215;b=c[2112932]|0;e=c[b+(m>>>10<<2)>>2]|0;if(e>>>0>9){n=a[e+(g&1023^1)|0]|0;o=f;p=b}else{f=gj[c[b+196608+(e<<2)>>2]&4095](m)|0;n=f;o=c[2276085]|0;p=c[2112932]|0}f=n&255;n=-f|0;c[2276075]=n;c[2276074]=n;c[2276078]=n;c[2276077]=f&n;c[2276076]=n&255;f=o&l;l=n&255;n=f&16777215;o=c[p+((n>>>10|16384)<<2)>>2]|0;if(o>>>0>9){a[o+(f&1023^1)|0]=l;return}else{gg[c[p+196648+(o<<2)>>2]&4095](n,l);return}}function Hp(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[2276085]|0;t=r&q;h=t&16777215;s=c[2112932]|0;n=c[s+(h>>>10<<2)>>2]|0;if(n>>>0>9){u=a[n+(t&1023^1)|0]|0;v=r;w=s}else{r=gj[c[s+196608+(n<<2)>>2]&4095](h)|0;u=r;v=c[2276085]|0;w=c[2112932]|0}r=u&255;u=-r|0;c[2276075]=u;c[2276074]=u;c[2276078]=u;c[2276077]=r&u;c[2276076]=u&255;r=v&q;q=u&255;u=r&16777215;v=c[w+((u>>>10|16384)<<2)>>2]|0;if(v>>>0>9){a[v+(r&1023^1)|0]=q;return}else{gg[c[w+196648+(v<<2)>>2]&4095](u,q);return}}function Hq(){var a=0,b=0,d=0;a=9104156+((c[2276069]&7)<<2)|0;b=-(c[a>>2]&65535)|0;d=b>>>8;c[2276075]=d;c[2276074]=d;c[2276078]=d;c[2276077]=(c[a>>2]&b)>>>8;d=b&65535;c[2276076]=d;c[a>>2]=c[a>>2]&-65536|d;return}function Hr(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276085]|0;f=e&b;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=f&1023;k=(d[i+(j+1)|0]|0)<<8|(d[i+j|0]|0);l=e;m=h}else{e=gj[c[h+196688+(i<<2)>>2]&4095](g)|0;k=e;l=c[2276085]|0;m=c[2112932]|0}e=k&65535;k=-e|0;g=k>>>8;c[2276075]=g;c[2276074]=g;c[2276078]=g;c[2276077]=(e&k)>>>8;c[2276076]=k&65535;e=l&b;b=k&65535;l=e&16777215;g=c[m+((l>>>10|16384)<<2)>>2]|0;if(g>>>0>9){i=e&1023;a[g+i|0]=k&255;a[g+(i+1)|0]=(b&65535)>>>8&255;return}else{gg[c[m+196728+(g<<2)>>2]&4095](l,b);return}}function Hs(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=c[b>>2]|0;c[b>>2]=e+2;b=c[2276085]|0;f=b&e;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=f&1023;k=(d[i+(j+1)|0]|0)<<8|(d[i+j|0]|0);l=b;m=h}else{b=gj[c[h+196688+(i<<2)>>2]&4095](g)|0;k=b;l=c[2276085]|0;m=c[2112932]|0}b=k&65535;k=-b|0;g=k>>>8;c[2276075]=g;c[2276074]=g;c[2276078]=g;c[2276077]=(b&k)>>>8;c[2276076]=k&65535;b=l&e;e=k&65535;l=b&16777215;g=c[m+((l>>>10|16384)<<2)>>2]|0;if(g>>>0>9){i=b&1023;a[g+i|0]=k&255;a[g+(i+1)|0]=(e&65535)>>>8&255;return}else{gg[c[m+196728+(g<<2)>>2]&4095](l,e);return}}function Ht(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=(c[b>>2]|0)-2|0;c[b>>2]=e;b=c[2276085]|0;f=b&e;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=f&1023;k=(d[i+(j+1)|0]|0)<<8|(d[i+j|0]|0);l=b;m=h}else{b=gj[c[h+196688+(i<<2)>>2]&4095](g)|0;k=b;l=c[2276085]|0;m=c[2112932]|0}b=k&65535;k=-b|0;g=k>>>8;c[2276075]=g;c[2276074]=g;c[2276078]=g;c[2276077]=(b&k)>>>8;c[2276076]=k&65535;b=l&e;e=k&65535;l=b&16777215;g=c[m+((l>>>10|16384)<<2)>>2]|0;if(g>>>0>9){i=b&1023;a[g+i|0]=k&255;a[g+(i+1)|0]=(e&65535)>>>8&255;return}else{gg[c[m+196728+(g<<2)>>2]&4095](l,e);return}}function Hu(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=(h>>>((g<<3&16^16)>>>0)<<16>>16)+b|0;b=c[2276085]|0;g=m&b;h=g&16777215;n=c[2112932]|0;e=c[n+(h>>>10<<2)>>2]|0;if(e>>>0>9){f=g&1023;o=(d[e+(f+1)|0]|0)<<8|(d[e+f|0]|0);p=b;q=n}else{b=gj[c[n+196688+(e<<2)>>2]&4095](h)|0;o=b;p=c[2276085]|0;q=c[2112932]|0}b=o&65535;o=-b|0;h=o>>>8;c[2276075]=h;c[2276074]=h;c[2276078]=h;c[2276077]=(b&o)>>>8;c[2276076]=o&65535;b=p&m;m=o&65535;p=b&16777215;h=c[q+((p>>>10|16384)<<2)>>2]|0;if(h>>>0>9){e=b&1023;a[h+e|0]=o&255;a[h+(e+1)|0]=(m&65535)>>>8&255;return}else{gg[c[q+196728+(h<<2)>>2]&4095](p,m);return}}function Hv(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=Hd(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;e=c[2276085]|0;f=e&b;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=f&1023;k=(d[i+(j+1)|0]|0)<<8|(d[i+j|0]|0);l=e;m=h}else{e=gj[c[h+196688+(i<<2)>>2]&4095](g)|0;k=e;l=c[2276085]|0;m=c[2112932]|0}e=k&65535;k=-e|0;g=k>>>8;c[2276075]=g;c[2276074]=g;c[2276078]=g;c[2276077]=(e&k)>>>8;c[2276076]=k&65535;e=l&b;b=k&65535;l=e&16777215;g=c[m+((l>>>10|16384)<<2)>>2]|0;if(g>>>0>9){i=e&1023;a[g+i|0]=k&255;a[g+(i+1)|0]=(b&65535)>>>8&255;return}else{gg[c[m+196728+(g<<2)>>2]&4095](l,b);return}}function Hw(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)<<16>>16;f=c[2276085]|0;g=l&f;m=g&16777215;b=c[2112932]|0;e=c[b+(m>>>10<<2)>>2]|0;if(e>>>0>9){j=g&1023;n=(d[e+(j+1)|0]|0)<<8|(d[e+j|0]|0);o=f;p=b}else{f=gj[c[b+196688+(e<<2)>>2]&4095](m)|0;n=f;o=c[2276085]|0;p=c[2112932]|0}f=n&65535;n=-f|0;m=n>>>8;c[2276075]=m;c[2276074]=m;c[2276078]=m;c[2276077]=(f&n)>>>8;c[2276076]=n&65535;f=o&l;l=n&65535;o=f&16777215;m=c[p+((o>>>10|16384)<<2)>>2]|0;if(m>>>0>9){e=f&1023;a[m+e|0]=n&255;a[m+(e+1)|0]=(l&65535)>>>8&255;return}else{gg[c[p+196728+(m<<2)>>2]&4095](o,l);return}}function Hx(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[2276085]|0;t=r&q;h=t&16777215;s=c[2112932]|0;n=c[s+(h>>>10<<2)>>2]|0;if(n>>>0>9){f=t&1023;u=(d[n+(f+1)|0]|0)<<8|(d[n+f|0]|0);v=r;w=s}else{r=gj[c[s+196688+(n<<2)>>2]&4095](h)|0;u=r;v=c[2276085]|0;w=c[2112932]|0}r=u&65535;u=-r|0;h=u>>>8;c[2276075]=h;c[2276074]=h;c[2276078]=h;c[2276077]=(r&u)>>>8;c[2276076]=u&65535;r=v&q;q=u&65535;v=r&16777215;h=c[w+((v>>>10|16384)<<2)>>2]|0;if(h>>>0>9){n=r&1023;a[h+n|0]=u&255;a[h+(n+1)|0]=(q&65535)>>>8&255;return}else{gg[c[w+196728+(h<<2)>>2]&4095](v,q);return}}function Hy(){var a=0,b=0,d=0;a=9104156+((c[2276069]&7)<<2)|0;b=-(c[a>>2]|0)|0;c[2276075]=b>>>24;d=(c[a>>2]|b)>>>23;c[2276074]=d;c[2276078]=d;c[2276077]=(c[a>>2]&b)>>>24;c[2276076]=b;c[a>>2]=b;return}function Hz(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276085]|0;f=e&b;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=f&1023;k=(d[i+(j+3)|0]|0)<<8|(d[i+(j+2)|0]|0)|((d[i+(j+1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=e;m=h}else{e=gj[c[h+196768+(i<<2)>>2]&4095](g)|0;k=e;l=c[2276085]|0;m=c[2112932]|0}e=-k|0;g=e>>>24;c[2276075]=g;i=(k|e)>>>23;c[2276074]=i;c[2276078]=i;c[2276077]=(k&e)>>>24;c[2276076]=e;k=l&b;b=k&16777215;l=c[m+((b>>>10|16384)<<2)>>2]|0;if(l>>>0>9){i=k&1023;a[l+i|0]=e>>>16&255;a[l+(i+1)|0]=g&255;a[l+(i+2)|0]=e&255;a[l+(i+3)|0]=e>>>8&255;return}else{gg[c[m+196808+(l<<2)>>2]&4095](b,e);return}}function HA(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=c[b>>2]|0;c[b>>2]=e+4;b=c[2276085]|0;f=b&e;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=f&1023;k=(d[i+(j+3)|0]|0)<<8|(d[i+(j+2)|0]|0)|((d[i+(j+1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=b;m=h}else{b=gj[c[h+196768+(i<<2)>>2]&4095](g)|0;k=b;l=c[2276085]|0;m=c[2112932]|0}b=-k|0;g=b>>>24;c[2276075]=g;i=(k|b)>>>23;c[2276074]=i;c[2276078]=i;c[2276077]=(k&b)>>>24;c[2276076]=b;k=l&e;e=k&16777215;l=c[m+((e>>>10|16384)<<2)>>2]|0;if(l>>>0>9){i=k&1023;a[l+i|0]=b>>>16&255;a[l+(i+1)|0]=g&255;a[l+(i+2)|0]=b&255;a[l+(i+3)|0]=b>>>8&255;return}else{gg[c[m+196808+(l<<2)>>2]&4095](e,b);return}}function HB(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=(c[b>>2]|0)-4|0;c[b>>2]=e;b=c[2276085]|0;f=b&e;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=f&1023;k=(d[i+(j+3)|0]|0)<<8|(d[i+(j+2)|0]|0)|((d[i+(j+1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=b;m=h}else{b=gj[c[h+196768+(i<<2)>>2]&4095](g)|0;k=b;l=c[2276085]|0;m=c[2112932]|0}b=-k|0;g=b>>>24;c[2276075]=g;i=(k|b)>>>23;c[2276074]=i;c[2276078]=i;c[2276077]=(k&b)>>>24;c[2276076]=b;k=l&e;e=k&16777215;l=c[m+((e>>>10|16384)<<2)>>2]|0;if(l>>>0>9){i=k&1023;a[l+i|0]=b>>>16&255;a[l+(i+1)|0]=g&255;a[l+(i+2)|0]=b&255;a[l+(i+3)|0]=b>>>8&255;return}else{gg[c[m+196808+(l<<2)>>2]&4095](e,b);return}}function HC(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=(h>>>((g<<3&16^16)>>>0)<<16>>16)+b|0;b=c[2276085]|0;g=m&b;h=g&16777215;n=c[2112932]|0;e=c[n+(h>>>10<<2)>>2]|0;if(e>>>0>9){f=g&1023;o=(d[e+(f+3)|0]|0)<<8|(d[e+(f+2)|0]|0)|((d[e+(f+1)|0]|0)<<8|(d[e+f|0]|0))<<16;p=b;q=n}else{b=gj[c[n+196768+(e<<2)>>2]&4095](h)|0;o=b;p=c[2276085]|0;q=c[2112932]|0}b=-o|0;h=b>>>24;c[2276075]=h;e=(o|b)>>>23;c[2276074]=e;c[2276078]=e;c[2276077]=(o&b)>>>24;c[2276076]=b;o=p&m;m=o&16777215;p=c[q+((m>>>10|16384)<<2)>>2]|0;if(p>>>0>9){e=o&1023;a[p+e|0]=b>>>16&255;a[p+(e+1)|0]=h&255;a[p+(e+2)|0]=b&255;a[p+(e+3)|0]=b>>>8&255;return}else{gg[c[q+196808+(p<<2)>>2]&4095](m,b);return}}function HD(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=Hd(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;e=c[2276085]|0;f=e&b;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=f&1023;k=(d[i+(j+3)|0]|0)<<8|(d[i+(j+2)|0]|0)|((d[i+(j+1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=e;m=h}else{e=gj[c[h+196768+(i<<2)>>2]&4095](g)|0;k=e;l=c[2276085]|0;m=c[2112932]|0}e=-k|0;g=e>>>24;c[2276075]=g;i=(k|e)>>>23;c[2276074]=i;c[2276078]=i;c[2276077]=(k&e)>>>24;c[2276076]=e;k=l&b;b=k&16777215;l=c[m+((b>>>10|16384)<<2)>>2]|0;if(l>>>0>9){i=k&1023;a[l+i|0]=e>>>16&255;a[l+(i+1)|0]=g&255;a[l+(i+2)|0]=e&255;a[l+(i+3)|0]=e>>>8&255;return}else{gg[c[m+196808+(l<<2)>>2]&4095](b,e);return}}function HE(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)<<16>>16;f=c[2276085]|0;g=l&f;m=g&16777215;b=c[2112932]|0;e=c[b+(m>>>10<<2)>>2]|0;if(e>>>0>9){j=g&1023;n=(d[e+(j+3)|0]|0)<<8|(d[e+(j+2)|0]|0)|((d[e+(j+1)|0]|0)<<8|(d[e+j|0]|0))<<16;o=f;p=b}else{f=gj[c[b+196768+(e<<2)>>2]&4095](m)|0;n=f;o=c[2276085]|0;p=c[2112932]|0}f=-n|0;m=f>>>24;c[2276075]=m;e=(n|f)>>>23;c[2276074]=e;c[2276078]=e;c[2276077]=(n&f)>>>24;c[2276076]=f;n=o&l;l=n&16777215;o=c[p+((l>>>10|16384)<<2)>>2]|0;if(o>>>0>9){e=n&1023;a[o+e|0]=f>>>16&255;a[o+(e+1)|0]=m&255;a[o+(e+2)|0]=f&255;a[o+(e+3)|0]=f>>>8&255;return}else{gg[c[p+196808+(o<<2)>>2]&4095](l,f);return}}function HF(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[2276085]|0;t=r&q;h=t&16777215;s=c[2112932]|0;n=c[s+(h>>>10<<2)>>2]|0;if(n>>>0>9){f=t&1023;u=(d[n+(f+3)|0]|0)<<8|(d[n+(f+2)|0]|0)|((d[n+(f+1)|0]|0)<<8|(d[n+f|0]|0))<<16;v=r;w=s}else{r=gj[c[s+196768+(n<<2)>>2]&4095](h)|0;u=r;v=c[2276085]|0;w=c[2112932]|0}r=-u|0;h=r>>>24;c[2276075]=h;n=(u|r)>>>23;c[2276074]=n;c[2276078]=n;c[2276077]=(u&r)>>>24;c[2276076]=r;u=v&q;q=u&16777215;v=c[w+((q>>>10|16384)<<2)>>2]|0;if(v>>>0>9){n=u&1023;a[v+n|0]=r>>>16&255;a[v+(n+1)|0]=h&255;a[v+(n+2)|0]=r&255;a[v+(n+3)|0]=r>>>8&255;return}else{gg[c[w+196808+(v<<2)>>2]&4095](q,r);return}}function HG(){var a=0,b=0,d=0;a=9104156+((c[2276069]&7)<<2)|0;b=-(((c[2276074]|0)>>>8&1)+(c[a>>2]&255)|0)|0;c[2276075]=b;c[2276078]=b;c[2276074]=b;c[2276077]=c[a>>2]&b;d=b&255;c[2276076]=d|c[2276076];c[a>>2]=c[a>>2]&-256|d;return}function HH(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;d=c[2276085]|0;e=d&b;f=e&16777215;g=c[2112932]|0;h=c[g+(f>>>10<<2)>>2]|0;if(h>>>0>9){i=a[h+(e&1023^1)|0]|0;j=d;k=g}else{d=gj[c[g+196608+(h<<2)>>2]&4095](f)|0;i=d;j=c[2276085]|0;k=c[2112932]|0}d=i&255;i=-(((c[2276074]|0)>>>8&1)+d|0)|0;c[2276075]=i;c[2276078]=i;c[2276074]=i;c[2276077]=d&i;c[2276076]=i&255|c[2276076];d=j&b;b=i&255;i=d&16777215;j=c[k+((i>>>10|16384)<<2)>>2]|0;if(j>>>0>9){a[j+(d&1023^1)|0]=b;return}else{gg[c[k+196648+(j<<2)>>2]&4095](i,b);return}}function HI(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;b=c[2276085]|0;e=b&d;f=e&16777215;g=c[2112932]|0;h=c[g+(f>>>10<<2)>>2]|0;if(h>>>0>9){i=a[h+(e&1023^1)|0]|0;j=b;k=g}else{b=gj[c[g+196608+(h<<2)>>2]&4095](f)|0;i=b;j=c[2276085]|0;k=c[2112932]|0}b=i&255;i=-(((c[2276074]|0)>>>8&1)+b|0)|0;c[2276075]=i;c[2276078]=i;c[2276074]=i;c[2276077]=b&i;c[2276076]=i&255|c[2276076];b=j&d;d=i&255;i=b&16777215;j=c[k+((i>>>10|16384)<<2)>>2]|0;if(j>>>0>9){a[j+(b&1023^1)|0]=d;return}else{gg[c[k+196648+(j<<2)>>2]&4095](i,d);return}}function HJ(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[2276054]|0;c[2276054]=b+2;d=c[2276085]|0;e=d&b;f=e&16777215;g=c[2112932]|0;h=c[g+(f>>>10<<2)>>2]|0;if(h>>>0>9){i=a[h+(e&1023^1)|0]|0;j=d;k=g}else{d=gj[c[g+196608+(h<<2)>>2]&4095](f)|0;i=d;j=c[2276085]|0;k=c[2112932]|0}d=i&255;i=-(((c[2276074]|0)>>>8&1)+d|0)|0;c[2276075]=i;c[2276078]=i;c[2276074]=i;c[2276077]=d&i;c[2276076]=i&255|c[2276076];d=j&b;b=i&255;i=d&16777215;j=c[k+((i>>>10|16384)<<2)>>2]|0;if(j>>>0>9){a[j+(d&1023^1)|0]=b;return}else{gg[c[k+196648+(j<<2)>>2]&4095](i,b);return}}function HK(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;b=c[2276085]|0;e=b&d;f=e&16777215;g=c[2112932]|0;h=c[g+(f>>>10<<2)>>2]|0;if(h>>>0>9){i=a[h+(e&1023^1)|0]|0;j=b;k=g}else{b=gj[c[g+196608+(h<<2)>>2]&4095](f)|0;i=b;j=c[2276085]|0;k=c[2112932]|0}b=i&255;i=-(((c[2276074]|0)>>>8&1)+b|0)|0;c[2276075]=i;c[2276078]=i;c[2276074]=i;c[2276077]=b&i;c[2276076]=i&255|c[2276076];b=j&d;d=i&255;i=b&16777215;j=c[k+((i>>>10|16384)<<2)>>2]|0;if(j>>>0>9){a[j+(b&1023^1)|0]=d;return}else{gg[c[k+196648+(j<<2)>>2]&4095](i,d);return}}function HL(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=(c[2276054]|0)-2|0;c[2276054]=b;d=c[2276085]|0;e=d&b;f=e&16777215;g=c[2112932]|0;h=c[g+(f>>>10<<2)>>2]|0;if(h>>>0>9){i=a[h+(e&1023^1)|0]|0;j=d;k=g}else{d=gj[c[g+196608+(h<<2)>>2]&4095](f)|0;i=d;j=c[2276085]|0;k=c[2112932]|0}d=i&255;i=-(((c[2276074]|0)>>>8&1)+d|0)|0;c[2276075]=i;c[2276078]=i;c[2276074]=i;c[2276077]=d&i;c[2276076]=i&255|c[2276076];d=j&b;b=i&255;i=d&16777215;j=c[k+((i>>>10|16384)<<2)>>2]|0;if(j>>>0>9){a[j+(d&1023^1)|0]=b;return}else{gg[c[k+196648+(j<<2)>>2]&4095](i,b);return}}function HM(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=(h>>>((g<<3&16^16)>>>0)<<16>>16)+b|0;b=c[2276085]|0;g=m&b;h=g&16777215;n=c[2112932]|0;e=c[n+(h>>>10<<2)>>2]|0;if(e>>>0>9){o=a[e+(g&1023^1)|0]|0;p=b;q=n}else{b=gj[c[n+196608+(e<<2)>>2]&4095](h)|0;o=b;p=c[2276085]|0;q=c[2112932]|0}b=o&255;o=-(((c[2276074]|0)>>>8&1)+b|0)|0;c[2276075]=o;c[2276078]=o;c[2276074]=o;c[2276077]=b&o;c[2276076]=o&255|c[2276076];b=p&m;m=o&255;o=b&16777215;p=c[q+((o>>>10|16384)<<2)>>2]|0;if(p>>>0>9){a[p+(b&1023^1)|0]=m;return}else{gg[c[q+196648+(p<<2)>>2]&4095](o,m);return}}function HN(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=Hd(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;d=c[2276085]|0;e=d&b;f=e&16777215;g=c[2112932]|0;h=c[g+(f>>>10<<2)>>2]|0;if(h>>>0>9){i=a[h+(e&1023^1)|0]|0;j=d;k=g}else{d=gj[c[g+196608+(h<<2)>>2]&4095](f)|0;i=d;j=c[2276085]|0;k=c[2112932]|0}d=i&255;i=-(((c[2276074]|0)>>>8&1)+d|0)|0;c[2276075]=i;c[2276078]=i;c[2276074]=i;c[2276077]=d&i;c[2276076]=i&255|c[2276076];d=j&b;b=i&255;i=d&16777215;j=c[k+((i>>>10|16384)<<2)>>2]|0;if(j>>>0>9){a[j+(d&1023^1)|0]=b;return}else{gg[c[k+196648+(j<<2)>>2]&4095](i,b);return}}function HO(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)<<16>>16;f=c[2276085]|0;g=l&f;m=g&16777215;b=c[2112932]|0;e=c[b+(m>>>10<<2)>>2]|0;if(e>>>0>9){n=a[e+(g&1023^1)|0]|0;o=f;p=b}else{f=gj[c[b+196608+(e<<2)>>2]&4095](m)|0;n=f;o=c[2276085]|0;p=c[2112932]|0}f=n&255;n=-(((c[2276074]|0)>>>8&1)+f|0)|0;c[2276075]=n;c[2276078]=n;c[2276074]=n;c[2276077]=f&n;c[2276076]=n&255|c[2276076];f=o&l;l=n&255;n=f&16777215;o=c[p+((n>>>10|16384)<<2)>>2]|0;if(o>>>0>9){a[o+(f&1023^1)|0]=l;return}else{gg[c[p+196648+(o<<2)>>2]&4095](n,l);return}}function HP(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[2276085]|0;t=r&q;h=t&16777215;s=c[2112932]|0;n=c[s+(h>>>10<<2)>>2]|0;if(n>>>0>9){u=a[n+(t&1023^1)|0]|0;v=r;w=s}else{r=gj[c[s+196608+(n<<2)>>2]&4095](h)|0;u=r;v=c[2276085]|0;w=c[2112932]|0}r=u&255;u=-(((c[2276074]|0)>>>8&1)+r|0)|0;c[2276075]=u;c[2276078]=u;c[2276074]=u;c[2276077]=r&u;c[2276076]=u&255|c[2276076];r=v&q;q=u&255;u=r&16777215;v=c[w+((u>>>10|16384)<<2)>>2]|0;if(v>>>0>9){a[v+(r&1023^1)|0]=q;return}else{gg[c[w+196648+(v<<2)>>2]&4095](u,q);return}}function HQ(){var a=0,b=0,d=0;a=9104156+((c[2276069]&7)<<2)|0;b=-(((c[2276074]|0)>>>8&1)+(c[a>>2]&65535)|0)|0;d=b>>>8;c[2276075]=d;c[2276078]=d;c[2276074]=d;c[2276077]=(c[a>>2]&b)>>>8;d=b&65535;c[2276076]=d|c[2276076];c[a>>2]=c[a>>2]&-65536|d;return}function HR(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276085]|0;f=e&b;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=f&1023;k=(d[i+(j+1)|0]|0)<<8|(d[i+j|0]|0);l=e;m=h}else{e=gj[c[h+196688+(i<<2)>>2]&4095](g)|0;k=e;l=c[2276085]|0;m=c[2112932]|0}e=k&65535;k=-(((c[2276074]|0)>>>8&1)+e|0)|0;g=k>>>8;c[2276075]=g;c[2276078]=g;c[2276074]=g;c[2276077]=(e&k)>>>8;c[2276076]=k&65535|c[2276076];e=l&b;b=k&65535;l=e&16777215;g=c[m+((l>>>10|16384)<<2)>>2]|0;if(g>>>0>9){i=e&1023;a[g+i|0]=k&255;a[g+(i+1)|0]=(b&65535)>>>8&255;return}else{gg[c[m+196728+(g<<2)>>2]&4095](l,b);return}}function HS(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=c[b>>2]|0;c[b>>2]=e+2;b=c[2276085]|0;f=b&e;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=f&1023;k=(d[i+(j+1)|0]|0)<<8|(d[i+j|0]|0);l=b;m=h}else{b=gj[c[h+196688+(i<<2)>>2]&4095](g)|0;k=b;l=c[2276085]|0;m=c[2112932]|0}b=k&65535;k=-(((c[2276074]|0)>>>8&1)+b|0)|0;g=k>>>8;c[2276075]=g;c[2276078]=g;c[2276074]=g;c[2276077]=(b&k)>>>8;c[2276076]=k&65535|c[2276076];b=l&e;e=k&65535;l=b&16777215;g=c[m+((l>>>10|16384)<<2)>>2]|0;if(g>>>0>9){i=b&1023;a[g+i|0]=k&255;a[g+(i+1)|0]=(e&65535)>>>8&255;return}else{gg[c[m+196728+(g<<2)>>2]&4095](l,e);return}}function HT(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=(c[b>>2]|0)-2|0;c[b>>2]=e;b=c[2276085]|0;f=b&e;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=f&1023;k=(d[i+(j+1)|0]|0)<<8|(d[i+j|0]|0);l=b;m=h}else{b=gj[c[h+196688+(i<<2)>>2]&4095](g)|0;k=b;l=c[2276085]|0;m=c[2112932]|0}b=k&65535;k=-(((c[2276074]|0)>>>8&1)+b|0)|0;g=k>>>8;c[2276075]=g;c[2276078]=g;c[2276074]=g;c[2276077]=(b&k)>>>8;c[2276076]=k&65535|c[2276076];b=l&e;e=k&65535;l=b&16777215;g=c[m+((l>>>10|16384)<<2)>>2]|0;if(g>>>0>9){i=b&1023;a[g+i|0]=k&255;a[g+(i+1)|0]=(e&65535)>>>8&255;return}else{gg[c[m+196728+(g<<2)>>2]&4095](l,e);return}}function HU(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=(h>>>((g<<3&16^16)>>>0)<<16>>16)+b|0;b=c[2276085]|0;g=m&b;h=g&16777215;n=c[2112932]|0;e=c[n+(h>>>10<<2)>>2]|0;if(e>>>0>9){f=g&1023;o=(d[e+(f+1)|0]|0)<<8|(d[e+f|0]|0);p=b;q=n}else{b=gj[c[n+196688+(e<<2)>>2]&4095](h)|0;o=b;p=c[2276085]|0;q=c[2112932]|0}b=o&65535;o=-(((c[2276074]|0)>>>8&1)+b|0)|0;h=o>>>8;c[2276075]=h;c[2276078]=h;c[2276074]=h;c[2276077]=(b&o)>>>8;c[2276076]=o&65535|c[2276076];b=p&m;m=o&65535;p=b&16777215;h=c[q+((p>>>10|16384)<<2)>>2]|0;if(h>>>0>9){e=b&1023;a[h+e|0]=o&255;a[h+(e+1)|0]=(m&65535)>>>8&255;return}else{gg[c[q+196728+(h<<2)>>2]&4095](p,m);return}}function HV(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=Hd(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;e=c[2276085]|0;f=e&b;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=f&1023;k=(d[i+(j+1)|0]|0)<<8|(d[i+j|0]|0);l=e;m=h}else{e=gj[c[h+196688+(i<<2)>>2]&4095](g)|0;k=e;l=c[2276085]|0;m=c[2112932]|0}e=k&65535;k=-(((c[2276074]|0)>>>8&1)+e|0)|0;g=k>>>8;c[2276075]=g;c[2276078]=g;c[2276074]=g;c[2276077]=(e&k)>>>8;c[2276076]=k&65535|c[2276076];e=l&b;b=k&65535;l=e&16777215;g=c[m+((l>>>10|16384)<<2)>>2]|0;if(g>>>0>9){i=e&1023;a[g+i|0]=k&255;a[g+(i+1)|0]=(b&65535)>>>8&255;return}else{gg[c[m+196728+(g<<2)>>2]&4095](l,b);return}}function HW(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)<<16>>16;f=c[2276085]|0;g=l&f;m=g&16777215;b=c[2112932]|0;e=c[b+(m>>>10<<2)>>2]|0;if(e>>>0>9){j=g&1023;n=(d[e+(j+1)|0]|0)<<8|(d[e+j|0]|0);o=f;p=b}else{f=gj[c[b+196688+(e<<2)>>2]&4095](m)|0;n=f;o=c[2276085]|0;p=c[2112932]|0}f=n&65535;n=-(((c[2276074]|0)>>>8&1)+f|0)|0;m=n>>>8;c[2276075]=m;c[2276078]=m;c[2276074]=m;c[2276077]=(f&n)>>>8;c[2276076]=n&65535|c[2276076];f=o&l;l=n&65535;o=f&16777215;m=c[p+((o>>>10|16384)<<2)>>2]|0;if(m>>>0>9){e=f&1023;a[m+e|0]=n&255;a[m+(e+1)|0]=(l&65535)>>>8&255;return}else{gg[c[p+196728+(m<<2)>>2]&4095](o,l);return}}function HX(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[2276085]|0;t=r&q;h=t&16777215;s=c[2112932]|0;n=c[s+(h>>>10<<2)>>2]|0;if(n>>>0>9){f=t&1023;u=(d[n+(f+1)|0]|0)<<8|(d[n+f|0]|0);v=r;w=s}else{r=gj[c[s+196688+(n<<2)>>2]&4095](h)|0;u=r;v=c[2276085]|0;w=c[2112932]|0}r=u&65535;u=-(((c[2276074]|0)>>>8&1)+r|0)|0;h=u>>>8;c[2276075]=h;c[2276078]=h;c[2276074]=h;c[2276077]=(r&u)>>>8;c[2276076]=u&65535|c[2276076];r=v&q;q=u&65535;v=r&16777215;h=c[w+((v>>>10|16384)<<2)>>2]|0;if(h>>>0>9){n=r&1023;a[h+n|0]=u&255;a[h+(n+1)|0]=(q&65535)>>>8&255;return}else{gg[c[w+196728+(h<<2)>>2]&4095](v,q);return}}function HY(){var a=0,b=0,d=0;a=9104156+((c[2276069]&7)<<2)|0;b=-(((c[2276074]|0)>>>8&1)+(c[a>>2]|0)|0)|0;c[2276075]=b>>>24;d=(c[a>>2]|b)>>>23;c[2276078]=d;c[2276074]=d;c[2276077]=(c[a>>2]&b)>>>24;c[2276076]=c[2276076]|b;c[a>>2]=b;return}function HZ(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276085]|0;f=e&b;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=f&1023;k=(d[i+(j+3)|0]|0)<<8|(d[i+(j+2)|0]|0)|((d[i+(j+1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=e;m=h}else{e=gj[c[h+196768+(i<<2)>>2]&4095](g)|0;k=e;l=c[2276085]|0;m=c[2112932]|0}e=-(((c[2276074]|0)>>>8&1)+k|0)|0;g=e>>>24;c[2276075]=g;i=(k|e)>>>23;c[2276078]=i;c[2276074]=i;c[2276077]=(k&e)>>>24;c[2276076]=c[2276076]|e;k=l&b;b=k&16777215;l=c[m+((b>>>10|16384)<<2)>>2]|0;if(l>>>0>9){i=k&1023;a[l+i|0]=e>>>16&255;a[l+(i+1)|0]=g&255;a[l+(i+2)|0]=e&255;a[l+(i+3)|0]=e>>>8&255;return}else{gg[c[m+196808+(l<<2)>>2]&4095](b,e);return}}function H_(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=c[b>>2]|0;c[b>>2]=e+4;b=c[2276085]|0;f=b&e;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=f&1023;k=(d[i+(j+3)|0]|0)<<8|(d[i+(j+2)|0]|0)|((d[i+(j+1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=b;m=h}else{b=gj[c[h+196768+(i<<2)>>2]&4095](g)|0;k=b;l=c[2276085]|0;m=c[2112932]|0}b=-(((c[2276074]|0)>>>8&1)+k|0)|0;g=b>>>24;c[2276075]=g;i=(k|b)>>>23;c[2276078]=i;c[2276074]=i;c[2276077]=(k&b)>>>24;c[2276076]=c[2276076]|b;k=l&e;e=k&16777215;l=c[m+((e>>>10|16384)<<2)>>2]|0;if(l>>>0>9){i=k&1023;a[l+i|0]=b>>>16&255;a[l+(i+1)|0]=g&255;a[l+(i+2)|0]=b&255;a[l+(i+3)|0]=b>>>8&255;return}else{gg[c[m+196808+(l<<2)>>2]&4095](e,b);return}}function H$(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=(c[b>>2]|0)-4|0;c[b>>2]=e;b=c[2276085]|0;f=b&e;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=f&1023;k=(d[i+(j+3)|0]|0)<<8|(d[i+(j+2)|0]|0)|((d[i+(j+1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=b;m=h}else{b=gj[c[h+196768+(i<<2)>>2]&4095](g)|0;k=b;l=c[2276085]|0;m=c[2112932]|0}b=-(((c[2276074]|0)>>>8&1)+k|0)|0;g=b>>>24;c[2276075]=g;i=(k|b)>>>23;c[2276078]=i;c[2276074]=i;c[2276077]=(k&b)>>>24;c[2276076]=c[2276076]|b;k=l&e;e=k&16777215;l=c[m+((e>>>10|16384)<<2)>>2]|0;if(l>>>0>9){i=k&1023;a[l+i|0]=b>>>16&255;a[l+(i+1)|0]=g&255;a[l+(i+2)|0]=b&255;a[l+(i+3)|0]=b>>>8&255;return}else{gg[c[m+196808+(l<<2)>>2]&4095](e,b);return}}function H0(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=(h>>>((g<<3&16^16)>>>0)<<16>>16)+b|0;b=c[2276085]|0;g=m&b;h=g&16777215;n=c[2112932]|0;e=c[n+(h>>>10<<2)>>2]|0;if(e>>>0>9){f=g&1023;o=(d[e+(f+3)|0]|0)<<8|(d[e+(f+2)|0]|0)|((d[e+(f+1)|0]|0)<<8|(d[e+f|0]|0))<<16;p=b;q=n}else{b=gj[c[n+196768+(e<<2)>>2]&4095](h)|0;o=b;p=c[2276085]|0;q=c[2112932]|0}b=-(((c[2276074]|0)>>>8&1)+o|0)|0;h=b>>>24;c[2276075]=h;e=(o|b)>>>23;c[2276078]=e;c[2276074]=e;c[2276077]=(o&b)>>>24;c[2276076]=c[2276076]|b;o=p&m;m=o&16777215;p=c[q+((m>>>10|16384)<<2)>>2]|0;if(p>>>0>9){e=o&1023;a[p+e|0]=b>>>16&255;a[p+(e+1)|0]=h&255;a[p+(e+2)|0]=b&255;a[p+(e+3)|0]=b>>>8&255;return}else{gg[c[q+196808+(p<<2)>>2]&4095](m,b);return}}function H1(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=Hd(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;e=c[2276085]|0;f=e&b;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=f&1023;k=(d[i+(j+3)|0]|0)<<8|(d[i+(j+2)|0]|0)|((d[i+(j+1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=e;m=h}else{e=gj[c[h+196768+(i<<2)>>2]&4095](g)|0;k=e;l=c[2276085]|0;m=c[2112932]|0}e=-(((c[2276074]|0)>>>8&1)+k|0)|0;g=e>>>24;c[2276075]=g;i=(k|e)>>>23;c[2276078]=i;c[2276074]=i;c[2276077]=(k&e)>>>24;c[2276076]=c[2276076]|e;k=l&b;b=k&16777215;l=c[m+((b>>>10|16384)<<2)>>2]|0;if(l>>>0>9){i=k&1023;a[l+i|0]=e>>>16&255;a[l+(i+1)|0]=g&255;a[l+(i+2)|0]=e&255;a[l+(i+3)|0]=e>>>8&255;return}else{gg[c[m+196808+(l<<2)>>2]&4095](b,e);return}}function H2(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)<<16>>16;f=c[2276085]|0;g=l&f;m=g&16777215;b=c[2112932]|0;e=c[b+(m>>>10<<2)>>2]|0;if(e>>>0>9){j=g&1023;n=(d[e+(j+3)|0]|0)<<8|(d[e+(j+2)|0]|0)|((d[e+(j+1)|0]|0)<<8|(d[e+j|0]|0))<<16;o=f;p=b}else{f=gj[c[b+196768+(e<<2)>>2]&4095](m)|0;n=f;o=c[2276085]|0;p=c[2112932]|0}f=-(((c[2276074]|0)>>>8&1)+n|0)|0;m=f>>>24;c[2276075]=m;e=(n|f)>>>23;c[2276078]=e;c[2276074]=e;c[2276077]=(n&f)>>>24;c[2276076]=c[2276076]|f;n=o&l;l=n&16777215;o=c[p+((l>>>10|16384)<<2)>>2]|0;if(o>>>0>9){e=n&1023;a[o+e|0]=f>>>16&255;a[o+(e+1)|0]=m&255;a[o+(e+2)|0]=f&255;a[o+(e+3)|0]=f>>>8&255;return}else{gg[c[p+196808+(o<<2)>>2]&4095](l,f);return}}function H3(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[2276085]|0;t=r&q;h=t&16777215;s=c[2112932]|0;n=c[s+(h>>>10<<2)>>2]|0;if(n>>>0>9){f=t&1023;u=(d[n+(f+3)|0]|0)<<8|(d[n+(f+2)|0]|0)|((d[n+(f+1)|0]|0)<<8|(d[n+f|0]|0))<<16;v=r;w=s}else{r=gj[c[s+196768+(n<<2)>>2]&4095](h)|0;u=r;v=c[2276085]|0;w=c[2112932]|0}r=-(((c[2276074]|0)>>>8&1)+u|0)|0;h=r>>>24;c[2276075]=h;n=(u|r)>>>23;c[2276078]=n;c[2276074]=n;c[2276077]=(u&r)>>>24;c[2276076]=c[2276076]|r;u=v&q;q=u&16777215;v=c[w+((q>>>10|16384)<<2)>>2]|0;if(v>>>0>9){n=u&1023;a[v+n|0]=r>>>16&255;a[v+(n+1)|0]=h&255;a[v+(n+2)|0]=r&255;a[v+(n+3)|0]=r>>>8&255;return}else{gg[c[w+196808+(v<<2)>>2]&4095](q,r);return}}function H4(){return}function H5(){var a=0,b=0,d=0;a=9104156+((c[2276069]&7)<<2)|0;b=c[a>>2]|0;d=b&255^255;c[a>>2]=d|b&-256;c[2276075]=d;c[2276076]=d;c[2276078]=0;c[2276077]=0;return}function H6(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;d=c[2276085]|0;e=d&b;f=e&16777215;g=c[2112932]|0;h=c[g+(f>>>10<<2)>>2]|0;if(h>>>0>9){i=a[h+(e&1023^1)|0]|0;j=d;k=g}else{d=gj[c[g+196608+(h<<2)>>2]&4095](f)|0;i=d;j=c[2276085]|0;k=c[2112932]|0}d=i&255^255;i=j&b;b=d&255;j=i&16777215;f=c[k+((j>>>10|16384)<<2)>>2]|0;if(f>>>0>9){a[f+(i&1023^1)|0]=b;c[2276075]=d;c[2276076]=d;c[2276078]=0;c[2276077]=0;return}else{gg[c[k+196648+(f<<2)>>2]&4095](j,b);c[2276075]=d;c[2276076]=d;c[2276078]=0;c[2276077]=0;return}}function H7(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;b=c[2276085]|0;e=b&d;f=e&16777215;g=c[2112932]|0;h=c[g+(f>>>10<<2)>>2]|0;if(h>>>0>9){i=a[h+(e&1023^1)|0]|0;j=b;k=g}else{b=gj[c[g+196608+(h<<2)>>2]&4095](f)|0;i=b;j=c[2276085]|0;k=c[2112932]|0}b=i&255^255;i=j&d;d=b&255;j=i&16777215;f=c[k+((j>>>10|16384)<<2)>>2]|0;if(f>>>0>9){a[f+(i&1023^1)|0]=d;c[2276075]=b;c[2276076]=b;c[2276078]=0;c[2276077]=0;return}else{gg[c[k+196648+(f<<2)>>2]&4095](j,d);c[2276075]=b;c[2276076]=b;c[2276078]=0;c[2276077]=0;return}}function H8(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[2276054]|0;c[2276054]=b+2;d=c[2276085]|0;e=d&b;f=e&16777215;g=c[2112932]|0;h=c[g+(f>>>10<<2)>>2]|0;if(h>>>0>9){i=a[h+(e&1023^1)|0]|0;j=d;k=g}else{d=gj[c[g+196608+(h<<2)>>2]&4095](f)|0;i=d;j=c[2276085]|0;k=c[2112932]|0}d=i&255^255;i=j&b;b=d&255;j=i&16777215;f=c[k+((j>>>10|16384)<<2)>>2]|0;if(f>>>0>9){a[f+(i&1023^1)|0]=b;c[2276075]=d;c[2276076]=d;c[2276078]=0;c[2276077]=0;return}else{gg[c[k+196648+(f<<2)>>2]&4095](j,b);c[2276075]=d;c[2276076]=d;c[2276078]=0;c[2276077]=0;return}}function H9(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;b=c[2276085]|0;e=b&d;f=e&16777215;g=c[2112932]|0;h=c[g+(f>>>10<<2)>>2]|0;if(h>>>0>9){i=a[h+(e&1023^1)|0]|0;j=b;k=g}else{b=gj[c[g+196608+(h<<2)>>2]&4095](f)|0;i=b;j=c[2276085]|0;k=c[2112932]|0}b=i&255^255;i=j&d;d=b&255;j=i&16777215;f=c[k+((j>>>10|16384)<<2)>>2]|0;if(f>>>0>9){a[f+(i&1023^1)|0]=d;c[2276075]=b;c[2276076]=b;c[2276078]=0;c[2276077]=0;return}else{gg[c[k+196648+(f<<2)>>2]&4095](j,d);c[2276075]=b;c[2276076]=b;c[2276078]=0;c[2276077]=0;return}}function Ia(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=(c[2276054]|0)-2|0;c[2276054]=b;d=c[2276085]|0;e=d&b;f=e&16777215;g=c[2112932]|0;h=c[g+(f>>>10<<2)>>2]|0;if(h>>>0>9){i=a[h+(e&1023^1)|0]|0;j=d;k=g}else{d=gj[c[g+196608+(h<<2)>>2]&4095](f)|0;i=d;j=c[2276085]|0;k=c[2112932]|0}d=i&255^255;i=j&b;b=d&255;j=i&16777215;f=c[k+((j>>>10|16384)<<2)>>2]|0;if(f>>>0>9){a[f+(i&1023^1)|0]=b;c[2276075]=d;c[2276076]=d;c[2276078]=0;c[2276077]=0;return}else{gg[c[k+196648+(f<<2)>>2]&4095](j,b);c[2276075]=d;c[2276076]=d;c[2276078]=0;c[2276077]=0;return}}function Ib(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=(h>>>((g<<3&16^16)>>>0)<<16>>16)+b|0;b=c[2276085]|0;g=m&b;h=g&16777215;n=c[2112932]|0;e=c[n+(h>>>10<<2)>>2]|0;if(e>>>0>9){o=a[e+(g&1023^1)|0]|0;p=b;q=n}else{b=gj[c[n+196608+(e<<2)>>2]&4095](h)|0;o=b;p=c[2276085]|0;q=c[2112932]|0}b=o&255^255;o=p&m;m=b&255;p=o&16777215;h=c[q+((p>>>10|16384)<<2)>>2]|0;if(h>>>0>9){a[h+(o&1023^1)|0]=m;c[2276075]=b;c[2276076]=b;c[2276078]=0;c[2276077]=0;return}else{gg[c[q+196648+(h<<2)>>2]&4095](p,m);c[2276075]=b;c[2276076]=b;c[2276078]=0;c[2276077]=0;return}}function Ic(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=Hd(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;d=c[2276085]|0;e=d&b;f=e&16777215;g=c[2112932]|0;h=c[g+(f>>>10<<2)>>2]|0;if(h>>>0>9){i=a[h+(e&1023^1)|0]|0;j=d;k=g}else{d=gj[c[g+196608+(h<<2)>>2]&4095](f)|0;i=d;j=c[2276085]|0;k=c[2112932]|0}d=i&255^255;i=j&b;b=d&255;j=i&16777215;f=c[k+((j>>>10|16384)<<2)>>2]|0;if(f>>>0>9){a[f+(i&1023^1)|0]=b;c[2276075]=d;c[2276076]=d;c[2276078]=0;c[2276077]=0;return}else{gg[c[k+196648+(f<<2)>>2]&4095](j,b);c[2276075]=d;c[2276076]=d;c[2276078]=0;c[2276077]=0;return}}function Id(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)<<16>>16;f=c[2276085]|0;g=l&f;m=g&16777215;b=c[2112932]|0;e=c[b+(m>>>10<<2)>>2]|0;if(e>>>0>9){n=a[e+(g&1023^1)|0]|0;o=f;p=b}else{f=gj[c[b+196608+(e<<2)>>2]&4095](m)|0;n=f;o=c[2276085]|0;p=c[2112932]|0}f=n&255^255;n=o&l;l=f&255;o=n&16777215;m=c[p+((o>>>10|16384)<<2)>>2]|0;if(m>>>0>9){a[m+(n&1023^1)|0]=l;c[2276075]=f;c[2276076]=f;c[2276078]=0;c[2276077]=0;return}else{gg[c[p+196648+(m<<2)>>2]&4095](o,l);c[2276075]=f;c[2276076]=f;c[2276078]=0;c[2276077]=0;return}}function Ie(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[2276085]|0;t=r&q;h=t&16777215;s=c[2112932]|0;n=c[s+(h>>>10<<2)>>2]|0;if(n>>>0>9){u=a[n+(t&1023^1)|0]|0;v=r;w=s}else{r=gj[c[s+196608+(n<<2)>>2]&4095](h)|0;u=r;v=c[2276085]|0;w=c[2112932]|0}r=u&255^255;u=v&q;q=r&255;v=u&16777215;h=c[w+((v>>>10|16384)<<2)>>2]|0;if(h>>>0>9){a[h+(u&1023^1)|0]=q;c[2276075]=r;c[2276076]=r;c[2276078]=0;c[2276077]=0;return}else{gg[c[w+196648+(h<<2)>>2]&4095](v,q);c[2276075]=r;c[2276076]=r;c[2276078]=0;c[2276077]=0;return}}function If(){var a=0,b=0,d=0;a=9104156+((c[2276069]&7)<<2)|0;b=c[a>>2]|0;d=b&65535^65535;c[a>>2]=d|b&-65536;c[2276075]=d>>>8;c[2276076]=d;c[2276078]=0;c[2276077]=0;return}function Ig(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276085]|0;f=e&b;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=f&1023;k=(d[i+(j+1)|0]|0)<<8|(d[i+j|0]|0);l=e;m=h}else{e=gj[c[h+196688+(i<<2)>>2]&4095](g)|0;k=e;l=c[2276085]|0;m=c[2112932]|0}e=k&65535^65535;k=l&b;b=e&65535;l=k&16777215;g=c[m+((l>>>10|16384)<<2)>>2]|0;if(g>>>0>9){i=k&1023;a[g+i|0]=e&255;a[g+(i+1)|0]=(b&65535)>>>8&255;n=e>>>8;c[2276075]=n;c[2276076]=e;c[2276078]=0;c[2276077]=0;return}else{gg[c[m+196728+(g<<2)>>2]&4095](l,b);n=e>>>8;c[2276075]=n;c[2276076]=e;c[2276078]=0;c[2276077]=0;return}}function Ih(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=c[b>>2]|0;c[b>>2]=e+2;b=c[2276085]|0;f=b&e;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=f&1023;k=(d[i+(j+1)|0]|0)<<8|(d[i+j|0]|0);l=b;m=h}else{b=gj[c[h+196688+(i<<2)>>2]&4095](g)|0;k=b;l=c[2276085]|0;m=c[2112932]|0}b=k&65535^65535;k=l&e;e=b&65535;l=k&16777215;g=c[m+((l>>>10|16384)<<2)>>2]|0;if(g>>>0>9){i=k&1023;a[g+i|0]=b&255;a[g+(i+1)|0]=(e&65535)>>>8&255;n=b>>>8;c[2276075]=n;c[2276076]=b;c[2276078]=0;c[2276077]=0;return}else{gg[c[m+196728+(g<<2)>>2]&4095](l,e);n=b>>>8;c[2276075]=n;c[2276076]=b;c[2276078]=0;c[2276077]=0;return}}function Ii(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=(c[b>>2]|0)-2|0;c[b>>2]=e;b=c[2276085]|0;f=b&e;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=f&1023;k=(d[i+(j+1)|0]|0)<<8|(d[i+j|0]|0);l=b;m=h}else{b=gj[c[h+196688+(i<<2)>>2]&4095](g)|0;k=b;l=c[2276085]|0;m=c[2112932]|0}b=k&65535^65535;k=l&e;e=b&65535;l=k&16777215;g=c[m+((l>>>10|16384)<<2)>>2]|0;if(g>>>0>9){i=k&1023;a[g+i|0]=b&255;a[g+(i+1)|0]=(e&65535)>>>8&255;n=b>>>8;c[2276075]=n;c[2276076]=b;c[2276078]=0;c[2276077]=0;return}else{gg[c[m+196728+(g<<2)>>2]&4095](l,e);n=b>>>8;c[2276075]=n;c[2276076]=b;c[2276078]=0;c[2276077]=0;return}}function Ij(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=(h>>>((g<<3&16^16)>>>0)<<16>>16)+b|0;b=c[2276085]|0;g=m&b;h=g&16777215;n=c[2112932]|0;e=c[n+(h>>>10<<2)>>2]|0;if(e>>>0>9){f=g&1023;o=(d[e+(f+1)|0]|0)<<8|(d[e+f|0]|0);p=b;q=n}else{b=gj[c[n+196688+(e<<2)>>2]&4095](h)|0;o=b;p=c[2276085]|0;q=c[2112932]|0}b=o&65535^65535;o=p&m;m=b&65535;p=o&16777215;h=c[q+((p>>>10|16384)<<2)>>2]|0;if(h>>>0>9){e=o&1023;a[h+e|0]=b&255;a[h+(e+1)|0]=(m&65535)>>>8&255;r=b>>>8;c[2276075]=r;c[2276076]=b;c[2276078]=0;c[2276077]=0;return}else{gg[c[q+196728+(h<<2)>>2]&4095](p,m);r=b>>>8;c[2276075]=r;c[2276076]=b;c[2276078]=0;c[2276077]=0;return}}function Ik(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=Hd(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;e=c[2276085]|0;f=e&b;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=f&1023;k=(d[i+(j+1)|0]|0)<<8|(d[i+j|0]|0);l=e;m=h}else{e=gj[c[h+196688+(i<<2)>>2]&4095](g)|0;k=e;l=c[2276085]|0;m=c[2112932]|0}e=k&65535^65535;k=l&b;b=e&65535;l=k&16777215;g=c[m+((l>>>10|16384)<<2)>>2]|0;if(g>>>0>9){i=k&1023;a[g+i|0]=e&255;a[g+(i+1)|0]=(b&65535)>>>8&255;n=e>>>8;c[2276075]=n;c[2276076]=e;c[2276078]=0;c[2276077]=0;return}else{gg[c[m+196728+(g<<2)>>2]&4095](l,b);n=e>>>8;c[2276075]=n;c[2276076]=e;c[2276078]=0;c[2276077]=0;return}}function Il(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)<<16>>16;f=c[2276085]|0;g=l&f;m=g&16777215;b=c[2112932]|0;e=c[b+(m>>>10<<2)>>2]|0;if(e>>>0>9){j=g&1023;n=(d[e+(j+1)|0]|0)<<8|(d[e+j|0]|0);o=f;p=b}else{f=gj[c[b+196688+(e<<2)>>2]&4095](m)|0;n=f;o=c[2276085]|0;p=c[2112932]|0}f=n&65535^65535;n=o&l;l=f&65535;o=n&16777215;m=c[p+((o>>>10|16384)<<2)>>2]|0;if(m>>>0>9){e=n&1023;a[m+e|0]=f&255;a[m+(e+1)|0]=(l&65535)>>>8&255;q=f>>>8;c[2276075]=q;c[2276076]=f;c[2276078]=0;c[2276077]=0;return}else{gg[c[p+196728+(m<<2)>>2]&4095](o,l);q=f>>>8;c[2276075]=q;c[2276076]=f;c[2276078]=0;c[2276077]=0;return}}function Im(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[2276085]|0;t=r&q;h=t&16777215;s=c[2112932]|0;n=c[s+(h>>>10<<2)>>2]|0;if(n>>>0>9){f=t&1023;u=(d[n+(f+1)|0]|0)<<8|(d[n+f|0]|0);v=r;w=s}else{r=gj[c[s+196688+(n<<2)>>2]&4095](h)|0;u=r;v=c[2276085]|0;w=c[2112932]|0}r=u&65535^65535;u=v&q;q=r&65535;v=u&16777215;h=c[w+((v>>>10|16384)<<2)>>2]|0;if(h>>>0>9){n=u&1023;a[h+n|0]=r&255;a[h+(n+1)|0]=(q&65535)>>>8&255;x=r>>>8;c[2276075]=x;c[2276076]=r;c[2276078]=0;c[2276077]=0;return}else{gg[c[w+196728+(h<<2)>>2]&4095](v,q);x=r>>>8;c[2276075]=x;c[2276076]=r;c[2276078]=0;c[2276077]=0;return}}function In(){var a=0,b=0;a=9104156+((c[2276069]&7)<<2)|0;b=~c[a>>2];c[a>>2]=b;c[2276075]=b>>>24;c[2276076]=b;c[2276078]=0;c[2276077]=0;return}function Io(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276085]|0;f=e&b;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=f&1023;k=(d[i+(j+3)|0]|0)<<8|(d[i+(j+2)|0]|0)|((d[i+(j+1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=e;m=h}else{e=gj[c[h+196768+(i<<2)>>2]&4095](g)|0;k=e;l=c[2276085]|0;m=c[2112932]|0}e=~k;k=l&b;b=k&16777215;l=c[m+((b>>>10|16384)<<2)>>2]|0;if(l>>>0>9){g=k&1023;a[l+g|0]=e>>>16&255;k=e>>>24;a[l+(g+1)|0]=k&255;a[l+(g+2)|0]=e&255;a[l+(g+3)|0]=e>>>8&255;n=k;c[2276075]=n;c[2276076]=e;c[2276078]=0;c[2276077]=0;return}else{gg[c[m+196808+(l<<2)>>2]&4095](b,e);n=e>>>24;c[2276075]=n;c[2276076]=e;c[2276078]=0;c[2276077]=0;return}}function Ip(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=c[b>>2]|0;c[b>>2]=e+4;b=c[2276085]|0;f=b&e;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=f&1023;k=(d[i+(j+3)|0]|0)<<8|(d[i+(j+2)|0]|0)|((d[i+(j+1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=b;m=h}else{b=gj[c[h+196768+(i<<2)>>2]&4095](g)|0;k=b;l=c[2276085]|0;m=c[2112932]|0}b=~k;k=l&e;e=k&16777215;l=c[m+((e>>>10|16384)<<2)>>2]|0;if(l>>>0>9){g=k&1023;a[l+g|0]=b>>>16&255;k=b>>>24;a[l+(g+1)|0]=k&255;a[l+(g+2)|0]=b&255;a[l+(g+3)|0]=b>>>8&255;n=k;c[2276075]=n;c[2276076]=b;c[2276078]=0;c[2276077]=0;return}else{gg[c[m+196808+(l<<2)>>2]&4095](e,b);n=b>>>24;c[2276075]=n;c[2276076]=b;c[2276078]=0;c[2276077]=0;return}}function Iq(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=(c[b>>2]|0)-4|0;c[b>>2]=e;b=c[2276085]|0;f=b&e;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=f&1023;k=(d[i+(j+3)|0]|0)<<8|(d[i+(j+2)|0]|0)|((d[i+(j+1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=b;m=h}else{b=gj[c[h+196768+(i<<2)>>2]&4095](g)|0;k=b;l=c[2276085]|0;m=c[2112932]|0}b=~k;k=l&e;e=k&16777215;l=c[m+((e>>>10|16384)<<2)>>2]|0;if(l>>>0>9){g=k&1023;a[l+g|0]=b>>>16&255;k=b>>>24;a[l+(g+1)|0]=k&255;a[l+(g+2)|0]=b&255;a[l+(g+3)|0]=b>>>8&255;n=k;c[2276075]=n;c[2276076]=b;c[2276078]=0;c[2276077]=0;return}else{gg[c[m+196808+(l<<2)>>2]&4095](e,b);n=b>>>24;c[2276075]=n;c[2276076]=b;c[2276078]=0;c[2276077]=0;return}}function Ir(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=(h>>>((g<<3&16^16)>>>0)<<16>>16)+b|0;b=c[2276085]|0;g=m&b;h=g&16777215;n=c[2112932]|0;e=c[n+(h>>>10<<2)>>2]|0;if(e>>>0>9){f=g&1023;o=(d[e+(f+3)|0]|0)<<8|(d[e+(f+2)|0]|0)|((d[e+(f+1)|0]|0)<<8|(d[e+f|0]|0))<<16;p=b;q=n}else{b=gj[c[n+196768+(e<<2)>>2]&4095](h)|0;o=b;p=c[2276085]|0;q=c[2112932]|0}b=~o;o=p&m;m=o&16777215;p=c[q+((m>>>10|16384)<<2)>>2]|0;if(p>>>0>9){h=o&1023;a[p+h|0]=b>>>16&255;o=b>>>24;a[p+(h+1)|0]=o&255;a[p+(h+2)|0]=b&255;a[p+(h+3)|0]=b>>>8&255;r=o;c[2276075]=r;c[2276076]=b;c[2276078]=0;c[2276077]=0;return}else{gg[c[q+196808+(p<<2)>>2]&4095](m,b);r=b>>>24;c[2276075]=r;c[2276076]=b;c[2276078]=0;c[2276077]=0;return}}function Is(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=Hd(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;e=c[2276085]|0;f=e&b;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=f&1023;k=(d[i+(j+3)|0]|0)<<8|(d[i+(j+2)|0]|0)|((d[i+(j+1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=e;m=h}else{e=gj[c[h+196768+(i<<2)>>2]&4095](g)|0;k=e;l=c[2276085]|0;m=c[2112932]|0}e=~k;k=l&b;b=k&16777215;l=c[m+((b>>>10|16384)<<2)>>2]|0;if(l>>>0>9){g=k&1023;a[l+g|0]=e>>>16&255;k=e>>>24;a[l+(g+1)|0]=k&255;a[l+(g+2)|0]=e&255;a[l+(g+3)|0]=e>>>8&255;n=k;c[2276075]=n;c[2276076]=e;c[2276078]=0;c[2276077]=0;return}else{gg[c[m+196808+(l<<2)>>2]&4095](b,e);n=e>>>24;c[2276075]=n;c[2276076]=e;c[2276078]=0;c[2276077]=0;return}}function It(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)<<16>>16;f=c[2276085]|0;g=l&f;m=g&16777215;b=c[2112932]|0;e=c[b+(m>>>10<<2)>>2]|0;if(e>>>0>9){j=g&1023;n=(d[e+(j+3)|0]|0)<<8|(d[e+(j+2)|0]|0)|((d[e+(j+1)|0]|0)<<8|(d[e+j|0]|0))<<16;o=f;p=b}else{f=gj[c[b+196768+(e<<2)>>2]&4095](m)|0;n=f;o=c[2276085]|0;p=c[2112932]|0}f=~n;n=o&l;l=n&16777215;o=c[p+((l>>>10|16384)<<2)>>2]|0;if(o>>>0>9){m=n&1023;a[o+m|0]=f>>>16&255;n=f>>>24;a[o+(m+1)|0]=n&255;a[o+(m+2)|0]=f&255;a[o+(m+3)|0]=f>>>8&255;q=n;c[2276075]=q;c[2276076]=f;c[2276078]=0;c[2276077]=0;return}else{gg[c[p+196808+(o<<2)>>2]&4095](l,f);q=f>>>24;c[2276075]=q;c[2276076]=f;c[2276078]=0;c[2276077]=0;return}}function Iu(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[2276085]|0;t=r&q;h=t&16777215;s=c[2112932]|0;n=c[s+(h>>>10<<2)>>2]|0;if(n>>>0>9){f=t&1023;u=(d[n+(f+3)|0]|0)<<8|(d[n+(f+2)|0]|0)|((d[n+(f+1)|0]|0)<<8|(d[n+f|0]|0))<<16;v=r;w=s}else{r=gj[c[s+196768+(n<<2)>>2]&4095](h)|0;u=r;v=c[2276085]|0;w=c[2112932]|0}r=~u;u=v&q;q=u&16777215;v=c[w+((q>>>10|16384)<<2)>>2]|0;if(v>>>0>9){h=u&1023;a[v+h|0]=r>>>16&255;u=r>>>24;a[v+(h+1)|0]=u&255;a[v+(h+2)|0]=r&255;a[v+(h+3)|0]=r>>>8&255;x=u;c[2276075]=x;c[2276076]=r;c[2276078]=0;c[2276077]=0;return}else{gg[c[w+196808+(v<<2)>>2]&4095](q,r);x=r>>>24;c[2276075]=x;c[2276076]=r;c[2276078]=0;c[2276077]=0;return}}function Iv(){var a=0,b=0,d=0;a=c[2276069]|0;b=9104156+((a>>>9&7)<<2)|0;d=c[b>>2]|c[9104156+((a&7)<<2)>>2]&255;c[b>>2]=d;b=d&255;c[2276075]=b;c[2276076]=b;c[2276078]=0;c[2276077]=0;return}function Iw(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=c[2276069]|0;d=c[2276085]&c[9104156+((b&7|8)<<2)>>2];e=d&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=a[g+(d&1023^1)|0]|0;i=b}else{b=gj[c[f+196608+(g<<2)>>2]&4095](e)|0;h=b;i=c[2276069]|0}b=9104156+((i>>>9&7)<<2)|0;i=c[b>>2]|h&255;c[b>>2]=i;b=i&255;c[2276075]=b;c[2276076]=b;c[2276078]=0;c[2276077]=0;return}function Ix(){var b=0,d=0,e=0,f=0,g=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;b=c[2276085]&d;d=b&16777215;e=c[2112932]|0;f=c[e+(d>>>10<<2)>>2]|0;if(f>>>0>9){g=a[f+(b&1023^1)|0]|0}else{g=gj[c[e+196608+(f<<2)>>2]&4095](d)|0}d=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;f=c[d>>2]|g&255;c[d>>2]=f;d=f&255;c[2276075]=d;c[2276076]=d;c[2276078]=0;c[2276077]=0;return}function Iy(){var b=0,d=0,e=0,f=0,g=0;b=c[2276054]|0;c[2276054]=b+2;d=c[2276085]&b;b=d&16777215;e=c[2112932]|0;f=c[e+(b>>>10<<2)>>2]|0;if(f>>>0>9){g=a[f+(d&1023^1)|0]|0}else{g=gj[c[e+196608+(f<<2)>>2]&4095](b)|0}b=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;f=c[b>>2]|g&255;c[b>>2]=f;b=f&255;c[2276075]=b;c[2276076]=b;c[2276078]=0;c[2276077]=0;return}function Iz(){var b=0,d=0,e=0,f=0,g=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;b=c[2276085]&d;d=b&16777215;e=c[2112932]|0;f=c[e+(d>>>10<<2)>>2]|0;if(f>>>0>9){g=a[f+(b&1023^1)|0]|0}else{g=gj[c[e+196608+(f<<2)>>2]&4095](d)|0}d=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;f=c[d>>2]|g&255;c[d>>2]=f;d=f&255;c[2276075]=d;c[2276076]=d;c[2276078]=0;c[2276077]=0;return}function IA(){var b=0,d=0,e=0,f=0,g=0;b=(c[2276054]|0)-2|0;c[2276054]=b;d=c[2276085]&b;b=d&16777215;e=c[2112932]|0;f=c[e+(b>>>10<<2)>>2]|0;if(f>>>0>9){g=a[f+(d&1023^1)|0]|0}else{g=gj[c[e+196608+(f<<2)>>2]&4095](b)|0}b=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;f=c[b>>2]|g&255;c[b>>2]=f;b=f&255;c[2276075]=b;c[2276076]=b;c[2276078]=0;c[2276077]=0;return}function IB(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=(h>>>((g<<3&16^16)>>>0)<<16>>16)+b&c[2276085];b=m&16777215;g=c[2112932]|0;h=c[g+(b>>>10<<2)>>2]|0;if(h>>>0>9){o=a[h+(m&1023^1)|0]|0;p=o&255;q=c[2276069]|0;r=q>>>9;s=r&7;t=9104156+(s<<2)|0;u=c[t>>2]|0;v=u|p;c[t>>2]=v;w=v&255;c[2276075]=w;c[2276076]=w;c[2276078]=0;c[2276077]=0;return}else{o=gj[c[g+196608+(h<<2)>>2]&4095](b)|0;p=o&255;q=c[2276069]|0;r=q>>>9;s=r&7;t=9104156+(s<<2)|0;u=c[t>>2]|0;v=u|p;c[t>>2]=v;w=v&255;c[2276075]=w;c[2276076]=w;c[2276078]=0;c[2276077]=0;return}}function IC(){var b=0,d=0,e=0,f=0,g=0;b=Hd(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;d=c[2276085]&b;b=d&16777215;e=c[2112932]|0;f=c[e+(b>>>10<<2)>>2]|0;if(f>>>0>9){g=a[f+(d&1023^1)|0]|0}else{g=gj[c[e+196608+(f<<2)>>2]&4095](b)|0}b=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;f=c[b>>2]|g&255;c[b>>2]=f;b=f&255;c[2276075]=b;c[2276076]=b;c[2276078]=0;c[2276077]=0;return}function ID(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)<<16>>16&c[2276085];f=l&16777215;g=c[2112932]|0;m=c[g+(f>>>10<<2)>>2]|0;if(m>>>0>9){n=a[m+(l&1023^1)|0]|0;o=n&255;p=c[2276069]|0;q=p>>>9;r=q&7;s=9104156+(r<<2)|0;t=c[s>>2]|0;u=t|o;c[s>>2]=u;v=u&255;c[2276075]=v;c[2276076]=v;c[2276078]=0;c[2276077]=0;return}else{n=gj[c[g+196608+(m<<2)>>2]&4095](f)|0;o=n&255;p=c[2276069]|0;q=p>>>9;r=q&7;s=9104156+(r<<2)|0;t=c[s>>2]|0;u=t|o;c[s>>2]=u;v=u&255;c[2276075]=v;c[2276076]=v;c[2276078]=0;c[2276077]=0;return}}function IE(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[2276085]&q;q=r&16777215;t=c[2112932]|0;h=c[t+(q>>>10<<2)>>2]|0;if(h>>>0>9){u=a[h+(r&1023^1)|0]|0;v=u&255;w=c[2276069]|0;x=w>>>9;y=x&7;z=9104156+(y<<2)|0;A=c[z>>2]|0;B=A|v;c[z>>2]=B;C=B&255;c[2276075]=C;c[2276076]=C;c[2276078]=0;c[2276077]=0;return}else{u=gj[c[t+196608+(h<<2)>>2]&4095](q)|0;v=u&255;w=c[2276069]|0;x=w>>>9;y=x&7;z=9104156+(y<<2)|0;A=c[z>>2]|0;B=A|v;c[z>>2]=B;C=B&255;c[2276075]=C;c[2276076]=C;c[2276078]=0;c[2276077]=0;return}}function IF(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{k=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=k;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=(g>>>((f<<3&16^16)>>>0)<<16>>16)+b|0;b=l&16777215;f=c[2112932]|0;g=c[f+((b>>>10|32768)<<2)>>2]|0;if(g>>>0>9){n=a[g+(l&1023^1)|0]|0;o=n&255;p=c[2276069]|0;q=p>>>9;r=q&7;s=9104156+(r<<2)|0;t=c[s>>2]|0;u=t|o;c[s>>2]=u;v=u&255;c[2276075]=v;c[2276076]=v;c[2276078]=0;c[2276077]=0;return}else{n=gj[c[f+196608+(g<<2)>>2]&4095](b)|0;o=n&255;p=c[2276069]|0;q=p>>>9;r=q&7;s=9104156+(r<<2)|0;t=c[s>>2]|0;u=t|o;c[s>>2]=u;v=u&255;c[2276075]=v;c[2276076]=v;c[2276078]=0;c[2276077]=0;return}}function IG(){var b=0,d=0,e=0,f=0,g=0;b=Hd(c[2276056]|0)|0;d=b&16777215;e=c[2112932]|0;f=c[e+((d>>>10|32768)<<2)>>2]|0;if(f>>>0>9){g=a[f+(b&1023^1)|0]|0}else{g=gj[c[e+196608+(f<<2)>>2]&4095](d)|0}d=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;f=c[d>>2]|g&255;c[d>>2]=f;d=f&255;c[2276075]=d;c[2276076]=d;c[2276078]=0;c[2276077]=0;return}function IH(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;l=f>>>((e<<3&16^16)>>>0)&255|c[k>>2];c[k>>2]=l;k=l&255;c[2276075]=k;c[2276076]=k;c[2276078]=0;c[2276077]=0;return}function II(){var a=0,b=0,d=0;a=c[2276069]|0;b=9104156+((a>>>9&7)<<2)|0;d=c[b>>2]|c[9104156+((a&7)<<2)>>2]&65535;c[b>>2]=d;b=d&65535;c[2276075]=b>>>8;c[2276076]=b;c[2276078]=0;c[2276077]=0;return}function IJ(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0;a=c[2276069]|0;b=c[2276085]&c[9104156+((a&7|8)<<2)>>2];e=b&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=b&1023;i=(d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0);j=a}else{a=gj[c[f+196688+(g<<2)>>2]&4095](e)|0;i=a;j=c[2276069]|0}a=9104156+((j>>>9&7)<<2)|0;j=c[a>>2]|i&65535;c[a>>2]=j;a=j&65535;c[2276075]=a>>>8;c[2276076]=a;c[2276078]=0;c[2276077]=0;return}function IK(){var a=0,b=0,e=0,f=0,g=0,h=0;a=9104156+((c[2276069]&7|8)<<2)|0;b=c[a>>2]|0;c[a>>2]=b+2;a=c[2276085]&b;b=a&16777215;e=c[2112932]|0;f=c[e+(b>>>10<<2)>>2]|0;if(f>>>0>9){g=a&1023;h=(d[f+(g+1)|0]|0)<<8|(d[f+g|0]|0)}else{h=gj[c[e+196688+(f<<2)>>2]&4095](b)|0}b=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;f=c[b>>2]|h&65535;c[b>>2]=f;b=f&65535;c[2276075]=b>>>8;c[2276076]=b;c[2276078]=0;c[2276077]=0;return}function IL(){var a=0,b=0,e=0,f=0,g=0,h=0;a=9104156+((c[2276069]&7|8)<<2)|0;b=(c[a>>2]|0)-2|0;c[a>>2]=b;a=c[2276085]&b;b=a&16777215;e=c[2112932]|0;f=c[e+(b>>>10<<2)>>2]|0;if(f>>>0>9){g=a&1023;h=(d[f+(g+1)|0]|0)<<8|(d[f+g|0]|0)}else{h=gj[c[e+196688+(f<<2)>>2]&4095](b)|0}b=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;f=c[b>>2]|h&65535;c[b>>2]=f;b=f&65535;c[2276075]=b>>>8;c[2276076]=b;c[2276078]=0;c[2276077]=0;return}function IM(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;a=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=(g>>>((f<<3&16^16)>>>0)<<16>>16)+a&c[2276085];a=l&16777215;f=c[2112932]|0;g=c[f+(a>>>10<<2)>>2]|0;if(g>>>0>9){m=l&1023;n=(d[g+(m+1)|0]|0)<<8|(d[g+m|0]|0);o=n&65535;p=c[2276069]|0;q=p>>>9;r=q&7;s=9104156+(r<<2)|0;t=c[s>>2]|0;u=t|o;c[s>>2]=u;v=u&65535;w=v>>>8;c[2276075]=w;c[2276076]=v;c[2276078]=0;c[2276077]=0;return}else{n=gj[c[f+196688+(g<<2)>>2]&4095](a)|0;o=n&65535;p=c[2276069]|0;q=p>>>9;r=q&7;s=9104156+(r<<2)|0;t=c[s>>2]|0;u=t|o;c[s>>2]=u;v=u&65535;w=v>>>8;c[2276075]=w;c[2276076]=v;c[2276078]=0;c[2276077]=0;return}}function IN(){var a=0,b=0,e=0,f=0,g=0,h=0;a=Hd(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;b=c[2276085]&a;a=b&16777215;e=c[2112932]|0;f=c[e+(a>>>10<<2)>>2]|0;if(f>>>0>9){g=b&1023;h=(d[f+(g+1)|0]|0)<<8|(d[f+g|0]|0)}else{h=gj[c[e+196688+(f<<2)>>2]&4095](a)|0}a=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;f=c[a>>2]|h&65535;c[a>>2]=f;a=f&65535;c[2276075]=a>>>8;c[2276076]=a;c[2276078]=0;c[2276077]=0;return}function IO(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=f>>>((e<<3&16^16)>>>0)<<16>>16&c[2276085];e=k&16777215;f=c[2112932]|0;l=c[f+(e>>>10<<2)>>2]|0;if(l>>>0>9){a=k&1023;m=(d[l+(a+1)|0]|0)<<8|(d[l+a|0]|0);n=m&65535;o=c[2276069]|0;p=o>>>9;q=p&7;r=9104156+(q<<2)|0;s=c[r>>2]|0;t=s|n;c[r>>2]=t;u=t&65535;v=u>>>8;c[2276075]=v;c[2276076]=u;c[2276078]=0;c[2276077]=0;return}else{m=gj[c[f+196688+(l<<2)>>2]&4095](e)|0;n=m&65535;o=c[2276069]|0;p=o>>>9;q=p&7;r=9104156+(q<<2)|0;s=c[r>>2]|0;t=s|n;c[r>>2]=t;u=t&65535;v=u>>>8;c[2276075]=v;c[2276076]=u;c[2276078]=0;c[2276077]=0;return}}function IP(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=b;g=c[2276084]|0}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=o;g=m}m=e+2|0;c[2276056]=m;e=m&-4;if((e|0)==(f|0)){p=g;q=m}else{c[2276083]=e;f=c[2276085]&e;e=f&16777212;o=c[2112932]|0;n=c[o+((e>>>10|32768)<<2)>>2]|0;if(n>>>0>9){b=f&1020;r=(d[n+(b|3)|0]|0)<<8|(d[n+(b|2)|0]|0)|((d[n+(b|1)|0]|0)<<8|(d[n+b|0]|0))<<16;s=m}else{m=gj[c[o+196768+(n<<2)>>2]&4095](e)|0;r=m;s=c[2276056]|0}c[2276084]=r;p=r>>>16|g<<16;q=s}c[2276056]=q+2;q=c[2276085]&p;p=q&16777215;s=c[2112932]|0;g=c[s+(p>>>10<<2)>>2]|0;if(g>>>0>9){r=q&1023;t=(d[g+(r+1)|0]|0)<<8|(d[g+r|0]|0);u=t&65535;v=c[2276069]|0;w=v>>>9;x=w&7;y=9104156+(x<<2)|0;z=c[y>>2]|0;A=z|u;c[y>>2]=A;B=A&65535;C=B>>>8;c[2276075]=C;c[2276076]=B;c[2276078]=0;c[2276077]=0;return}else{t=gj[c[s+196688+(g<<2)>>2]&4095](p)|0;u=t&65535;v=c[2276069]|0;w=v>>>9;x=w&7;y=9104156+(x<<2)|0;z=c[y>>2]|0;A=z|u;c[y>>2]=A;B=A&65535;C=B>>>8;c[2276075]=C;c[2276076]=B;c[2276078]=0;c[2276077]=0;return}}function IQ(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{j=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=j;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=(f>>>((e<<3&16^16)>>>0)<<16>>16)+a|0;a=k&16777215;e=c[2112932]|0;f=c[e+((a>>>10|32768)<<2)>>2]|0;if(f>>>0>9){l=k&1023;m=(d[f+(l+1)|0]|0)<<8|(d[f+l|0]|0);n=m&65535;o=c[2276069]|0;p=o>>>9;q=p&7;r=9104156+(q<<2)|0;s=c[r>>2]|0;t=s|n;c[r>>2]=t;u=t&65535;v=u>>>8;c[2276075]=v;c[2276076]=u;c[2276078]=0;c[2276077]=0;return}else{m=gj[c[e+196688+(f<<2)>>2]&4095](a)|0;n=m&65535;o=c[2276069]|0;p=o>>>9;q=p&7;r=9104156+(q<<2)|0;s=c[r>>2]|0;t=s|n;c[r>>2]=t;u=t&65535;v=u>>>8;c[2276075]=v;c[2276076]=u;c[2276078]=0;c[2276077]=0;return}}function IR(){var a=0,b=0,e=0,f=0,g=0,h=0;a=Hd(c[2276056]|0)|0;b=a&16777215;e=c[2112932]|0;f=c[e+((b>>>10|32768)<<2)>>2]|0;if(f>>>0>9){g=a&1023;h=(d[f+(g+1)|0]|0)<<8|(d[f+g|0]|0)}else{h=gj[c[e+196688+(f<<2)>>2]&4095](b)|0}b=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;f=c[b>>2]|h&65535;c[b>>2]=f;b=f&65535;c[2276075]=b>>>8;c[2276076]=b;c[2276078]=0;c[2276077]=0;return}function IS(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;l=f>>>((e<<3&16^16)>>>0)&65535|c[k>>2];c[k>>2]=l;k=l&65535;c[2276075]=k>>>8;c[2276076]=k;c[2276078]=0;c[2276077]=0;return}function IT(){var a=0,b=0,d=0;a=c[2276069]|0;b=9104156+((a>>>9&7)<<2)|0;d=c[b>>2]|c[9104156+((a&7)<<2)>>2];c[b>>2]=d;c[2276075]=d>>>24;c[2276076]=d;c[2276078]=0;c[2276077]=0;return}function IU(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0;a=c[2276069]|0;b=c[2276085]&c[9104156+((a&7|8)<<2)>>2];e=b&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=b&1023;i=(d[g+(h+3)|0]|0)<<8|(d[g+(h+2)|0]|0)|((d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0))<<16;j=a}else{a=gj[c[f+196768+(g<<2)>>2]&4095](e)|0;i=a;j=c[2276069]|0}a=9104156+((j>>>9&7)<<2)|0;j=c[a>>2]|i;c[a>>2]=j;c[2276075]=j>>>24;c[2276076]=j;c[2276078]=0;c[2276077]=0;return}function IV(){var a=0,b=0,e=0,f=0,g=0,h=0;a=9104156+((c[2276069]&7|8)<<2)|0;b=c[a>>2]|0;c[a>>2]=b+4;a=c[2276085]&b;b=a&16777215;e=c[2112932]|0;f=c[e+(b>>>10<<2)>>2]|0;if(f>>>0>9){g=a&1023;h=(d[f+(g+3)|0]|0)<<8|(d[f+(g+2)|0]|0)|((d[f+(g+1)|0]|0)<<8|(d[f+g|0]|0))<<16}else{h=gj[c[e+196768+(f<<2)>>2]&4095](b)|0}b=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;f=c[b>>2]|h;c[b>>2]=f;c[2276075]=f>>>24;c[2276076]=f;c[2276078]=0;c[2276077]=0;return}function IW(){var a=0,b=0,e=0,f=0,g=0,h=0;a=9104156+((c[2276069]&7|8)<<2)|0;b=(c[a>>2]|0)-4|0;c[a>>2]=b;a=c[2276085]&b;b=a&16777215;e=c[2112932]|0;f=c[e+(b>>>10<<2)>>2]|0;if(f>>>0>9){g=a&1023;h=(d[f+(g+3)|0]|0)<<8|(d[f+(g+2)|0]|0)|((d[f+(g+1)|0]|0)<<8|(d[f+g|0]|0))<<16}else{h=gj[c[e+196768+(f<<2)>>2]&4095](b)|0}b=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;f=c[b>>2]|h;c[b>>2]=f;c[2276075]=f>>>24;c[2276076]=f;c[2276078]=0;c[2276077]=0;return}function IX(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;a=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=(g>>>((f<<3&16^16)>>>0)<<16>>16)+a&c[2276085];a=l&16777215;f=c[2112932]|0;g=c[f+(a>>>10<<2)>>2]|0;if(g>>>0>9){m=l&1023;n=(d[g+(m+3)|0]|0)<<8|(d[g+(m+2)|0]|0)|((d[g+(m+1)|0]|0)<<8|(d[g+m|0]|0))<<16;o=c[2276069]|0;p=o>>>9;q=p&7;r=9104156+(q<<2)|0;s=c[r>>2]|0;t=s|n;c[r>>2]=t;u=t>>>24;c[2276075]=u;c[2276076]=t;c[2276078]=0;c[2276077]=0;return}else{n=gj[c[f+196768+(g<<2)>>2]&4095](a)|0;o=c[2276069]|0;p=o>>>9;q=p&7;r=9104156+(q<<2)|0;s=c[r>>2]|0;t=s|n;c[r>>2]=t;u=t>>>24;c[2276075]=u;c[2276076]=t;c[2276078]=0;c[2276077]=0;return}}function IY(){var a=0,b=0,e=0,f=0,g=0,h=0;a=Hd(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;b=c[2276085]&a;a=b&16777215;e=c[2112932]|0;f=c[e+(a>>>10<<2)>>2]|0;if(f>>>0>9){g=b&1023;h=(d[f+(g+3)|0]|0)<<8|(d[f+(g+2)|0]|0)|((d[f+(g+1)|0]|0)<<8|(d[f+g|0]|0))<<16}else{h=gj[c[e+196768+(f<<2)>>2]&4095](a)|0}a=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;f=c[a>>2]|h;c[a>>2]=f;c[2276075]=f>>>24;c[2276076]=f;c[2276078]=0;c[2276077]=0;return}function IZ(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=f>>>((e<<3&16^16)>>>0)<<16>>16&c[2276085];e=k&16777215;f=c[2112932]|0;l=c[f+(e>>>10<<2)>>2]|0;if(l>>>0>9){a=k&1023;m=(d[l+(a+3)|0]|0)<<8|(d[l+(a+2)|0]|0)|((d[l+(a+1)|0]|0)<<8|(d[l+a|0]|0))<<16;n=c[2276069]|0;o=n>>>9;p=o&7;q=9104156+(p<<2)|0;r=c[q>>2]|0;s=r|m;c[q>>2]=s;t=s>>>24;c[2276075]=t;c[2276076]=s;c[2276078]=0;c[2276077]=0;return}else{m=gj[c[f+196768+(l<<2)>>2]&4095](e)|0;n=c[2276069]|0;o=n>>>9;p=o&7;q=9104156+(p<<2)|0;r=c[q>>2]|0;s=r|m;c[q>>2]=s;t=s>>>24;c[2276075]=t;c[2276076]=s;c[2276078]=0;c[2276077]=0;return}}function I_(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=b;g=c[2276084]|0}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=o;g=m}m=e+2|0;c[2276056]=m;e=m&-4;if((e|0)==(f|0)){p=g;q=m}else{c[2276083]=e;f=c[2276085]&e;e=f&16777212;o=c[2112932]|0;n=c[o+((e>>>10|32768)<<2)>>2]|0;if(n>>>0>9){b=f&1020;r=(d[n+(b|3)|0]|0)<<8|(d[n+(b|2)|0]|0)|((d[n+(b|1)|0]|0)<<8|(d[n+b|0]|0))<<16;s=m}else{m=gj[c[o+196768+(n<<2)>>2]&4095](e)|0;r=m;s=c[2276056]|0}c[2276084]=r;p=r>>>16|g<<16;q=s}c[2276056]=q+2;q=c[2276085]&p;p=q&16777215;s=c[2112932]|0;g=c[s+(p>>>10<<2)>>2]|0;if(g>>>0>9){r=q&1023;t=(d[g+(r+3)|0]|0)<<8|(d[g+(r+2)|0]|0)|((d[g+(r+1)|0]|0)<<8|(d[g+r|0]|0))<<16;u=c[2276069]|0;v=u>>>9;w=v&7;x=9104156+(w<<2)|0;y=c[x>>2]|0;z=y|t;c[x>>2]=z;A=z>>>24;c[2276075]=A;c[2276076]=z;c[2276078]=0;c[2276077]=0;return}else{t=gj[c[s+196768+(g<<2)>>2]&4095](p)|0;u=c[2276069]|0;v=u>>>9;w=v&7;x=9104156+(w<<2)|0;y=c[x>>2]|0;z=y|t;c[x>>2]=z;A=z>>>24;c[2276075]=A;c[2276076]=z;c[2276078]=0;c[2276077]=0;return}}function I$(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{j=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=j;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=(f>>>((e<<3&16^16)>>>0)<<16>>16)+a|0;a=k&16777215;e=c[2112932]|0;f=c[e+((a>>>10|32768)<<2)>>2]|0;if(f>>>0>9){l=k&1023;m=(d[f+(l+3)|0]|0)<<8|(d[f+(l+2)|0]|0)|((d[f+(l+1)|0]|0)<<8|(d[f+l|0]|0))<<16;n=c[2276069]|0;o=n>>>9;p=o&7;q=9104156+(p<<2)|0;r=c[q>>2]|0;s=r|m;c[q>>2]=s;t=s>>>24;c[2276075]=t;c[2276076]=s;c[2276078]=0;c[2276077]=0;return}else{m=gj[c[e+196768+(f<<2)>>2]&4095](a)|0;n=c[2276069]|0;o=n>>>9;p=o&7;q=9104156+(p<<2)|0;r=c[q>>2]|0;s=r|m;c[q>>2]=s;t=s>>>24;c[2276075]=t;c[2276076]=s;c[2276078]=0;c[2276077]=0;return}}function I0(){var a=0,b=0,e=0,f=0,g=0,h=0;a=Hd(c[2276056]|0)|0;b=a&16777215;e=c[2112932]|0;f=c[e+((b>>>10|32768)<<2)>>2]|0;if(f>>>0>9){g=a&1023;h=(d[f+(g+3)|0]|0)<<8|(d[f+(g+2)|0]|0)|((d[f+(g+1)|0]|0)<<8|(d[f+g|0]|0))<<16}else{h=gj[c[e+196768+(f<<2)>>2]&4095](b)|0}b=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;f=c[b>>2]|h;c[b>>2]=f;c[2276075]=f>>>24;c[2276076]=f;c[2276078]=0;c[2276077]=0;return}function I1(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=b;g=c[2276084]|0}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=o;g=m}m=e+2|0;c[2276056]=m;e=m&-4;if((e|0)==(f|0)){p=g;q=m;r=q+2|0;c[2276056]=r;s=c[2276069]|0;t=s>>>9;u=t&7;v=9104156+(u<<2)|0;w=c[v>>2]|0;x=w|p;c[v>>2]=x;y=x>>>24;c[2276075]=y;c[2276076]=x;c[2276078]=0;c[2276077]=0;return}c[2276083]=e;f=c[2276085]&e;e=f&16777212;o=c[2112932]|0;n=c[o+((e>>>10|32768)<<2)>>2]|0;if(n>>>0>9){b=f&1020;z=(d[n+(b|3)|0]|0)<<8|(d[n+(b|2)|0]|0)|((d[n+(b|1)|0]|0)<<8|(d[n+b|0]|0))<<16;A=m}else{m=gj[c[o+196768+(n<<2)>>2]&4095](e)|0;z=m;A=c[2276056]|0}c[2276084]=z;p=z>>>16|g<<16;q=A;r=q+2|0;c[2276056]=r;s=c[2276069]|0;t=s>>>9;u=t&7;v=9104156+(u<<2)|0;w=c[v>>2]|0;x=w|p;c[v>>2]=x;y=x>>>24;c[2276075]=y;c[2276076]=x;c[2276078]=0;c[2276077]=0;return}function I2(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=c[2276069]|0;d=c[9104156+((b&7|8)<<2)>>2]|0;e=c[9104156+((b>>>9&7)<<2)>>2]|0;b=c[2276085]|0;f=b&d;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=a[i+(f&1023^1)|0]|0;k=b;l=h}else{b=gj[c[h+196608+(i<<2)>>2]&4095](g)|0;j=b;k=c[2276085]|0;l=c[2112932]|0}b=j&255|e&255;e=k&d;d=b&255;k=e&16777215;j=c[l+((k>>>10|16384)<<2)>>2]|0;if(j>>>0>9){a[j+(e&1023^1)|0]=d;c[2276075]=b;c[2276076]=b;c[2276078]=0;c[2276077]=0;return}else{gg[c[l+196648+(j<<2)>>2]&4095](k,d);c[2276075]=b;c[2276076]=b;c[2276078]=0;c[2276077]=0;return}}function I3(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;b=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;e=c[2276085]|0;f=e&d;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=a[i+(f&1023^1)|0]|0;k=e;l=h}else{e=gj[c[h+196608+(i<<2)>>2]&4095](g)|0;j=e;k=c[2276085]|0;l=c[2112932]|0}e=j&255|b&255;b=k&d;d=e&255;k=b&16777215;j=c[l+((k>>>10|16384)<<2)>>2]|0;if(j>>>0>9){a[j+(b&1023^1)|0]=d;c[2276075]=e;c[2276076]=e;c[2276078]=0;c[2276077]=0;return}else{gg[c[l+196648+(j<<2)>>2]&4095](k,d);c[2276075]=e;c[2276076]=e;c[2276078]=0;c[2276077]=0;return}}function I4(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=c[2276054]|0;c[2276054]=b+2;d=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;e=c[2276085]|0;f=e&b;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=a[i+(f&1023^1)|0]|0;k=e;l=h}else{e=gj[c[h+196608+(i<<2)>>2]&4095](g)|0;j=e;k=c[2276085]|0;l=c[2112932]|0}e=j&255|d&255;d=k&b;b=e&255;k=d&16777215;j=c[l+((k>>>10|16384)<<2)>>2]|0;if(j>>>0>9){a[j+(d&1023^1)|0]=b;c[2276075]=e;c[2276076]=e;c[2276078]=0;c[2276077]=0;return}else{gg[c[l+196648+(j<<2)>>2]&4095](k,b);c[2276075]=e;c[2276076]=e;c[2276078]=0;c[2276077]=0;return}}function I5(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;b=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;e=c[2276085]|0;f=e&d;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=a[i+(f&1023^1)|0]|0;k=e;l=h}else{e=gj[c[h+196608+(i<<2)>>2]&4095](g)|0;j=e;k=c[2276085]|0;l=c[2112932]|0}e=j&255|b&255;b=k&d;d=e&255;k=b&16777215;j=c[l+((k>>>10|16384)<<2)>>2]|0;if(j>>>0>9){a[j+(b&1023^1)|0]=d;c[2276075]=e;c[2276076]=e;c[2276078]=0;c[2276077]=0;return}else{gg[c[l+196648+(j<<2)>>2]&4095](k,d);c[2276075]=e;c[2276076]=e;c[2276078]=0;c[2276077]=0;return}}function I6(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=(c[2276054]|0)-2|0;c[2276054]=b;d=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;e=c[2276085]|0;f=e&b;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=a[i+(f&1023^1)|0]|0;k=e;l=h}else{e=gj[c[h+196608+(i<<2)>>2]&4095](g)|0;j=e;k=c[2276085]|0;l=c[2112932]|0}e=j&255|d&255;d=k&b;b=e&255;k=d&16777215;j=c[l+((k>>>10|16384)<<2)>>2]|0;if(j>>>0>9){a[j+(d&1023^1)|0]=b;c[2276075]=e;c[2276076]=e;c[2276078]=0;c[2276077]=0;return}else{gg[c[l+196648+(j<<2)>>2]&4095](k,b);c[2276075]=e;c[2276076]=e;c[2276078]=0;c[2276077]=0;return}}function I7(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=c[2276069]|0;e=c[9104156+((b&7|8)<<2)>>2]|0;f=c[2276056]|0;g=f&-4;if((g|0)==(c[2276083]|0)){h=f;i=c[2276084]|0;j=b}else{c[2276083]=g;k=c[2276085]&g;g=k&16777212;l=c[2112932]|0;m=c[l+((g>>>10|32768)<<2)>>2]|0;if(m>>>0>9){n=k&1020;o=(d[m+(n|3)|0]|0)<<8|(d[m+(n|2)|0]|0)|((d[m+(n|1)|0]|0)<<8|(d[m+n|0]|0))<<16;p=f;q=b}else{b=gj[c[l+196768+(m<<2)>>2]&4095](g)|0;o=b;p=c[2276056]|0;q=c[2276069]|0}c[2276084]=o;h=p;i=o;j=q}c[2276056]=h+2;q=(i>>>((h<<3&16^16)>>>0)<<16>>16)+e|0;e=c[9104156+((j>>>9&7)<<2)>>2]|0;j=c[2276085]|0;h=q&j;i=h&16777215;o=c[2112932]|0;p=c[o+(i>>>10<<2)>>2]|0;if(p>>>0>9){r=a[p+(h&1023^1)|0]|0;s=j;t=o}else{j=gj[c[o+196608+(p<<2)>>2]&4095](i)|0;r=j;s=c[2276085]|0;t=c[2112932]|0}j=r&255|e&255;e=s&q;q=j&255;s=e&16777215;r=c[t+((s>>>10|16384)<<2)>>2]|0;if(r>>>0>9){a[r+(e&1023^1)|0]=q;c[2276075]=j;c[2276076]=j;c[2276078]=0;c[2276077]=0;return}else{gg[c[t+196648+(r<<2)>>2]&4095](s,q);c[2276075]=j;c[2276076]=j;c[2276078]=0;c[2276077]=0;return}}function I8(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=Hd(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;d=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;e=c[2276085]|0;f=e&b;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=a[i+(f&1023^1)|0]|0;k=e;l=h}else{e=gj[c[h+196608+(i<<2)>>2]&4095](g)|0;j=e;k=c[2276085]|0;l=c[2112932]|0}e=j&255|d&255;d=k&b;b=e&255;k=d&16777215;j=c[l+((k>>>10|16384)<<2)>>2]|0;if(j>>>0>9){a[j+(d&1023^1)|0]=b;c[2276075]=e;c[2276076]=e;c[2276078]=0;c[2276077]=0;return}else{gg[c[l+196648+(j<<2)>>2]&4095](k,b);c[2276075]=e;c[2276076]=e;c[2276078]=0;c[2276077]=0;return}}function I9(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)<<16>>16;f=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;g=c[2276085]|0;m=l&g;b=m&16777215;e=c[2112932]|0;j=c[e+(b>>>10<<2)>>2]|0;if(j>>>0>9){n=a[j+(m&1023^1)|0]|0;o=g;p=e}else{g=gj[c[e+196608+(j<<2)>>2]&4095](b)|0;n=g;o=c[2276085]|0;p=c[2112932]|0}g=n&255|f&255;f=o&l;l=g&255;o=f&16777215;n=c[p+((o>>>10|16384)<<2)>>2]|0;if(n>>>0>9){a[n+(f&1023^1)|0]=l;c[2276075]=g;c[2276076]=g;c[2276078]=0;c[2276077]=0;return}else{gg[c[p+196648+(n<<2)>>2]&4095](o,l);c[2276075]=g;c[2276076]=g;c[2276078]=0;c[2276077]=0;return}}function Ja(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;t=c[2276085]|0;h=t&q;s=h&16777215;n=c[2112932]|0;f=c[n+(s>>>10<<2)>>2]|0;if(f>>>0>9){u=a[f+(h&1023^1)|0]|0;v=t;w=n}else{t=gj[c[n+196608+(f<<2)>>2]&4095](s)|0;u=t;v=c[2276085]|0;w=c[2112932]|0}t=u&255|r&255;r=v&q;q=t&255;v=r&16777215;u=c[w+((v>>>10|16384)<<2)>>2]|0;if(u>>>0>9){a[u+(r&1023^1)|0]=q;c[2276075]=t;c[2276076]=t;c[2276078]=0;c[2276077]=0;return}else{gg[c[w+196648+(u<<2)>>2]&4095](v,q);c[2276075]=t;c[2276076]=t;c[2276078]=0;c[2276077]=0;return}}function Jb(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=c[2276069]|0;e=c[9104156+((b&7|8)<<2)>>2]|0;f=c[9104156+((b>>>9&7)<<2)>>2]|0;b=c[2276085]|0;g=b&e;h=g&16777215;i=c[2112932]|0;j=c[i+(h>>>10<<2)>>2]|0;if(j>>>0>9){k=g&1023;l=(d[j+(k+1)|0]|0)<<8|(d[j+k|0]|0);m=b;n=i}else{b=gj[c[i+196688+(j<<2)>>2]&4095](h)|0;l=b;m=c[2276085]|0;n=c[2112932]|0}b=l&65535|f&65535;f=m&e;e=b&65535;m=f&16777215;l=c[n+((m>>>10|16384)<<2)>>2]|0;if(l>>>0>9){h=f&1023;a[l+h|0]=b&255;a[l+(h+1)|0]=(e&65535)>>>8&255;o=b>>>8;c[2276075]=o;c[2276076]=b;c[2276078]=0;c[2276077]=0;return}else{gg[c[n+196728+(l<<2)>>2]&4095](m,e);o=b>>>8;c[2276075]=o;c[2276076]=b;c[2276078]=0;c[2276077]=0;return}}function Jc(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=c[b>>2]|0;c[b>>2]=e+2;b=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;f=c[2276085]|0;g=f&e;h=g&16777215;i=c[2112932]|0;j=c[i+(h>>>10<<2)>>2]|0;if(j>>>0>9){k=g&1023;l=(d[j+(k+1)|0]|0)<<8|(d[j+k|0]|0);m=f;n=i}else{f=gj[c[i+196688+(j<<2)>>2]&4095](h)|0;l=f;m=c[2276085]|0;n=c[2112932]|0}f=l&65535|b&65535;b=m&e;e=f&65535;m=b&16777215;l=c[n+((m>>>10|16384)<<2)>>2]|0;if(l>>>0>9){h=b&1023;a[l+h|0]=f&255;a[l+(h+1)|0]=(e&65535)>>>8&255;o=f>>>8;c[2276075]=o;c[2276076]=f;c[2276078]=0;c[2276077]=0;return}else{gg[c[n+196728+(l<<2)>>2]&4095](m,e);o=f>>>8;c[2276075]=o;c[2276076]=f;c[2276078]=0;c[2276077]=0;return}}function Jd(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=(c[b>>2]|0)-2|0;c[b>>2]=e;b=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;f=c[2276085]|0;g=f&e;h=g&16777215;i=c[2112932]|0;j=c[i+(h>>>10<<2)>>2]|0;if(j>>>0>9){k=g&1023;l=(d[j+(k+1)|0]|0)<<8|(d[j+k|0]|0);m=f;n=i}else{f=gj[c[i+196688+(j<<2)>>2]&4095](h)|0;l=f;m=c[2276085]|0;n=c[2112932]|0}f=l&65535|b&65535;b=m&e;e=f&65535;m=b&16777215;l=c[n+((m>>>10|16384)<<2)>>2]|0;if(l>>>0>9){h=b&1023;a[l+h|0]=f&255;a[l+(h+1)|0]=(e&65535)>>>8&255;o=f>>>8;c[2276075]=o;c[2276076]=f;c[2276078]=0;c[2276077]=0;return}else{gg[c[n+196728+(l<<2)>>2]&4095](m,e);o=f>>>8;c[2276075]=o;c[2276076]=f;c[2276078]=0;c[2276077]=0;return}}function Je(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;b=c[2276069]|0;e=c[9104156+((b&7|8)<<2)>>2]|0;f=c[2276056]|0;g=f&-4;if((g|0)==(c[2276083]|0)){h=f;i=c[2276084]|0;j=b}else{c[2276083]=g;k=c[2276085]&g;g=k&16777212;l=c[2112932]|0;m=c[l+((g>>>10|32768)<<2)>>2]|0;if(m>>>0>9){n=k&1020;o=(d[m+(n|3)|0]|0)<<8|(d[m+(n|2)|0]|0)|((d[m+(n|1)|0]|0)<<8|(d[m+n|0]|0))<<16;p=f;q=b}else{b=gj[c[l+196768+(m<<2)>>2]&4095](g)|0;o=b;p=c[2276056]|0;q=c[2276069]|0}c[2276084]=o;h=p;i=o;j=q}c[2276056]=h+2;q=(i>>>((h<<3&16^16)>>>0)<<16>>16)+e|0;e=c[9104156+((j>>>9&7)<<2)>>2]|0;j=c[2276085]|0;h=q&j;i=h&16777215;o=c[2112932]|0;p=c[o+(i>>>10<<2)>>2]|0;if(p>>>0>9){b=h&1023;r=(d[p+(b+1)|0]|0)<<8|(d[p+b|0]|0);s=j;t=o}else{j=gj[c[o+196688+(p<<2)>>2]&4095](i)|0;r=j;s=c[2276085]|0;t=c[2112932]|0}j=r&65535|e&65535;e=s&q;q=j&65535;s=e&16777215;r=c[t+((s>>>10|16384)<<2)>>2]|0;if(r>>>0>9){i=e&1023;a[r+i|0]=j&255;a[r+(i+1)|0]=(q&65535)>>>8&255;u=j>>>8;c[2276075]=u;c[2276076]=j;c[2276078]=0;c[2276077]=0;return}else{gg[c[t+196728+(r<<2)>>2]&4095](s,q);u=j>>>8;c[2276075]=u;c[2276076]=j;c[2276078]=0;c[2276077]=0;return}}function Jf(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=Hd(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;e=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;f=c[2276085]|0;g=f&b;h=g&16777215;i=c[2112932]|0;j=c[i+(h>>>10<<2)>>2]|0;if(j>>>0>9){k=g&1023;l=(d[j+(k+1)|0]|0)<<8|(d[j+k|0]|0);m=f;n=i}else{f=gj[c[i+196688+(j<<2)>>2]&4095](h)|0;l=f;m=c[2276085]|0;n=c[2112932]|0}f=l&65535|e&65535;e=m&b;b=f&65535;m=e&16777215;l=c[n+((m>>>10|16384)<<2)>>2]|0;if(l>>>0>9){h=e&1023;a[l+h|0]=f&255;a[l+(h+1)|0]=(b&65535)>>>8&255;o=f>>>8;c[2276075]=o;c[2276076]=f;c[2276078]=0;c[2276077]=0;return}else{gg[c[n+196728+(l<<2)>>2]&4095](m,b);o=f>>>8;c[2276075]=o;c[2276076]=f;c[2276078]=0;c[2276077]=0;return}}function Jg(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)<<16>>16;f=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;g=c[2276085]|0;m=l&g;b=m&16777215;e=c[2112932]|0;j=c[e+(b>>>10<<2)>>2]|0;if(j>>>0>9){i=m&1023;n=(d[j+(i+1)|0]|0)<<8|(d[j+i|0]|0);o=g;p=e}else{g=gj[c[e+196688+(j<<2)>>2]&4095](b)|0;n=g;o=c[2276085]|0;p=c[2112932]|0}g=n&65535|f&65535;f=o&l;l=g&65535;o=f&16777215;n=c[p+((o>>>10|16384)<<2)>>2]|0;if(n>>>0>9){b=f&1023;a[n+b|0]=g&255;a[n+(b+1)|0]=(l&65535)>>>8&255;q=g>>>8;c[2276075]=q;c[2276076]=g;c[2276078]=0;c[2276077]=0;return}else{gg[c[p+196728+(n<<2)>>2]&4095](o,l);q=g>>>8;c[2276075]=q;c[2276076]=g;c[2276078]=0;c[2276077]=0;return}}function Jh(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;t=c[2276085]|0;h=t&q;s=h&16777215;n=c[2112932]|0;f=c[n+(s>>>10<<2)>>2]|0;if(f>>>0>9){o=h&1023;u=(d[f+(o+1)|0]|0)<<8|(d[f+o|0]|0);v=t;w=n}else{t=gj[c[n+196688+(f<<2)>>2]&4095](s)|0;u=t;v=c[2276085]|0;w=c[2112932]|0}t=u&65535|r&65535;r=v&q;q=t&65535;v=r&16777215;u=c[w+((v>>>10|16384)<<2)>>2]|0;if(u>>>0>9){s=r&1023;a[u+s|0]=t&255;a[u+(s+1)|0]=(q&65535)>>>8&255;x=t>>>8;c[2276075]=x;c[2276076]=t;c[2276078]=0;c[2276077]=0;return}else{gg[c[w+196728+(u<<2)>>2]&4095](v,q);x=t>>>8;c[2276075]=x;c[2276076]=t;c[2276078]=0;c[2276077]=0;return}}function Ji(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=c[2276069]|0;e=c[9104156+((b&7|8)<<2)>>2]|0;f=c[9104156+((b>>>9&7)<<2)>>2]|0;b=c[2276085]|0;g=b&e;h=g&16777215;i=c[2112932]|0;j=c[i+(h>>>10<<2)>>2]|0;if(j>>>0>9){k=g&1023;l=(d[j+(k+3)|0]|0)<<8|(d[j+(k+2)|0]|0)|((d[j+(k+1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b;n=i}else{b=gj[c[i+196768+(j<<2)>>2]&4095](h)|0;l=b;m=c[2276085]|0;n=c[2112932]|0}b=l|f;f=m&e;e=f&16777215;m=c[n+((e>>>10|16384)<<2)>>2]|0;if(m>>>0>9){l=f&1023;a[m+l|0]=b>>>16&255;f=b>>>24;a[m+(l+1)|0]=f&255;a[m+(l+2)|0]=b&255;a[m+(l+3)|0]=b>>>8&255;o=f;c[2276075]=o;c[2276076]=b;c[2276078]=0;c[2276077]=0;return}else{gg[c[n+196808+(m<<2)>>2]&4095](e,b);o=b>>>24;c[2276075]=o;c[2276076]=b;c[2276078]=0;c[2276077]=0;return}}function Jj(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=c[b>>2]|0;c[b>>2]=e+4;b=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;f=c[2276085]|0;g=f&e;h=g&16777215;i=c[2112932]|0;j=c[i+(h>>>10<<2)>>2]|0;if(j>>>0>9){k=g&1023;l=(d[j+(k+3)|0]|0)<<8|(d[j+(k+2)|0]|0)|((d[j+(k+1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=f;n=i}else{f=gj[c[i+196768+(j<<2)>>2]&4095](h)|0;l=f;m=c[2276085]|0;n=c[2112932]|0}f=l|b;b=m&e;e=b&16777215;m=c[n+((e>>>10|16384)<<2)>>2]|0;if(m>>>0>9){l=b&1023;a[m+l|0]=f>>>16&255;b=f>>>24;a[m+(l+1)|0]=b&255;a[m+(l+2)|0]=f&255;a[m+(l+3)|0]=f>>>8&255;o=b;c[2276075]=o;c[2276076]=f;c[2276078]=0;c[2276077]=0;return}else{gg[c[n+196808+(m<<2)>>2]&4095](e,f);o=f>>>24;c[2276075]=o;c[2276076]=f;c[2276078]=0;c[2276077]=0;return}}function Jk(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=(c[b>>2]|0)-4|0;c[b>>2]=e;b=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;f=c[2276085]|0;g=f&e;h=g&16777215;i=c[2112932]|0;j=c[i+(h>>>10<<2)>>2]|0;if(j>>>0>9){k=g&1023;l=(d[j+(k+3)|0]|0)<<8|(d[j+(k+2)|0]|0)|((d[j+(k+1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=f;n=i}else{f=gj[c[i+196768+(j<<2)>>2]&4095](h)|0;l=f;m=c[2276085]|0;n=c[2112932]|0}f=l|b;b=m&e;e=b&16777215;m=c[n+((e>>>10|16384)<<2)>>2]|0;if(m>>>0>9){l=b&1023;a[m+l|0]=f>>>16&255;b=f>>>24;a[m+(l+1)|0]=b&255;a[m+(l+2)|0]=f&255;a[m+(l+3)|0]=f>>>8&255;o=b;c[2276075]=o;c[2276076]=f;c[2276078]=0;c[2276077]=0;return}else{gg[c[n+196808+(m<<2)>>2]&4095](e,f);o=f>>>24;c[2276075]=o;c[2276076]=f;c[2276078]=0;c[2276077]=0;return}}function Jl(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;b=c[2276069]|0;e=c[9104156+((b&7|8)<<2)>>2]|0;f=c[2276056]|0;g=f&-4;if((g|0)==(c[2276083]|0)){h=f;i=c[2276084]|0;j=b}else{c[2276083]=g;k=c[2276085]&g;g=k&16777212;l=c[2112932]|0;m=c[l+((g>>>10|32768)<<2)>>2]|0;if(m>>>0>9){n=k&1020;o=(d[m+(n|3)|0]|0)<<8|(d[m+(n|2)|0]|0)|((d[m+(n|1)|0]|0)<<8|(d[m+n|0]|0))<<16;p=f;q=b}else{b=gj[c[l+196768+(m<<2)>>2]&4095](g)|0;o=b;p=c[2276056]|0;q=c[2276069]|0}c[2276084]=o;h=p;i=o;j=q}c[2276056]=h+2;q=(i>>>((h<<3&16^16)>>>0)<<16>>16)+e|0;e=c[9104156+((j>>>9&7)<<2)>>2]|0;j=c[2276085]|0;h=q&j;i=h&16777215;o=c[2112932]|0;p=c[o+(i>>>10<<2)>>2]|0;if(p>>>0>9){b=h&1023;r=(d[p+(b+3)|0]|0)<<8|(d[p+(b+2)|0]|0)|((d[p+(b+1)|0]|0)<<8|(d[p+b|0]|0))<<16;s=j;t=o}else{j=gj[c[o+196768+(p<<2)>>2]&4095](i)|0;r=j;s=c[2276085]|0;t=c[2112932]|0}j=r|e;e=s&q;q=e&16777215;s=c[t+((q>>>10|16384)<<2)>>2]|0;if(s>>>0>9){r=e&1023;a[s+r|0]=j>>>16&255;e=j>>>24;a[s+(r+1)|0]=e&255;a[s+(r+2)|0]=j&255;a[s+(r+3)|0]=j>>>8&255;u=e;c[2276075]=u;c[2276076]=j;c[2276078]=0;c[2276077]=0;return}else{gg[c[t+196808+(s<<2)>>2]&4095](q,j);u=j>>>24;c[2276075]=u;c[2276076]=j;c[2276078]=0;c[2276077]=0;return}}function Jm(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=Hd(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;e=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;f=c[2276085]|0;g=f&b;h=g&16777215;i=c[2112932]|0;j=c[i+(h>>>10<<2)>>2]|0;if(j>>>0>9){k=g&1023;l=(d[j+(k+3)|0]|0)<<8|(d[j+(k+2)|0]|0)|((d[j+(k+1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=f;n=i}else{f=gj[c[i+196768+(j<<2)>>2]&4095](h)|0;l=f;m=c[2276085]|0;n=c[2112932]|0}f=l|e;e=m&b;b=e&16777215;m=c[n+((b>>>10|16384)<<2)>>2]|0;if(m>>>0>9){l=e&1023;a[m+l|0]=f>>>16&255;e=f>>>24;a[m+(l+1)|0]=e&255;a[m+(l+2)|0]=f&255;a[m+(l+3)|0]=f>>>8&255;o=e;c[2276075]=o;c[2276076]=f;c[2276078]=0;c[2276077]=0;return}else{gg[c[n+196808+(m<<2)>>2]&4095](b,f);o=f>>>24;c[2276075]=o;c[2276076]=f;c[2276078]=0;c[2276077]=0;return}}function Jn(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)<<16>>16;f=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;g=c[2276085]|0;m=l&g;b=m&16777215;e=c[2112932]|0;j=c[e+(b>>>10<<2)>>2]|0;if(j>>>0>9){i=m&1023;n=(d[j+(i+3)|0]|0)<<8|(d[j+(i+2)|0]|0)|((d[j+(i+1)|0]|0)<<8|(d[j+i|0]|0))<<16;o=g;p=e}else{g=gj[c[e+196768+(j<<2)>>2]&4095](b)|0;n=g;o=c[2276085]|0;p=c[2112932]|0}g=n|f;f=o&l;l=f&16777215;o=c[p+((l>>>10|16384)<<2)>>2]|0;if(o>>>0>9){n=f&1023;a[o+n|0]=g>>>16&255;f=g>>>24;a[o+(n+1)|0]=f&255;a[o+(n+2)|0]=g&255;a[o+(n+3)|0]=g>>>8&255;q=f;c[2276075]=q;c[2276076]=g;c[2276078]=0;c[2276077]=0;return}else{gg[c[p+196808+(o<<2)>>2]&4095](l,g);q=g>>>24;c[2276075]=q;c[2276076]=g;c[2276078]=0;c[2276077]=0;return}}function Jo(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;t=c[2276085]|0;h=t&q;s=h&16777215;n=c[2112932]|0;f=c[n+(s>>>10<<2)>>2]|0;if(f>>>0>9){o=h&1023;u=(d[f+(o+3)|0]|0)<<8|(d[f+(o+2)|0]|0)|((d[f+(o+1)|0]|0)<<8|(d[f+o|0]|0))<<16;v=t;w=n}else{t=gj[c[n+196768+(f<<2)>>2]&4095](s)|0;u=t;v=c[2276085]|0;w=c[2112932]|0}t=u|r;r=v&q;q=r&16777215;v=c[w+((q>>>10|16384)<<2)>>2]|0;if(v>>>0>9){u=r&1023;a[v+u|0]=t>>>16&255;r=t>>>24;a[v+(u+1)|0]=r&255;a[v+(u+2)|0]=t&255;a[v+(u+3)|0]=t>>>8&255;x=r;c[2276075]=x;c[2276076]=t;c[2276078]=0;c[2276077]=0;return}else{gg[c[w+196808+(v<<2)>>2]&4095](q,t);x=t>>>24;c[2276075]=x;c[2276076]=t;c[2276078]=0;c[2276077]=0;return}}function Jp(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=9104156+((c[2276069]&7)<<2)|0;l=f>>>((e<<3&16^16)>>>0)&255|c[k>>2];c[k>>2]=l;k=l&255;c[2276075]=k;c[2276076]=k;c[2276078]=0;c[2276077]=0;return}function Jq(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;m=c[2276085]|0;b=m&l;e=b&16777215;j=c[2112932]|0;i=c[j+(e>>>10<<2)>>2]|0;if(i>>>0>9){n=a[i+(b&1023^1)|0]|0;o=m;p=j}else{m=gj[c[j+196608+(i<<2)>>2]&4095](e)|0;n=m;o=c[2276085]|0;p=c[2112932]|0}m=n&255|g>>>((f<<3&16^16)>>>0)&255;f=o&l;l=m&255;o=f&16777215;g=c[p+((o>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(f&1023^1)|0]=l;c[2276075]=m;c[2276076]=m;c[2276078]=0;c[2276077]=0;return}else{gg[c[p+196648+(g<<2)>>2]&4095](o,l);c[2276075]=m;c[2276076]=m;c[2276078]=0;c[2276077]=0;return}}function Jr(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=9104156+((c[2276069]&7|8)<<2)|0;m=c[l>>2]|0;c[l>>2]=m+1;l=c[2276085]|0;b=l&m;e=b&16777215;j=c[2112932]|0;i=c[j+(e>>>10<<2)>>2]|0;if(i>>>0>9){n=a[i+(b&1023^1)|0]|0;o=l;p=j}else{l=gj[c[j+196608+(i<<2)>>2]&4095](e)|0;n=l;o=c[2276085]|0;p=c[2112932]|0}l=n&255|g>>>((f<<3&16^16)>>>0)&255;f=o&m;m=l&255;o=f&16777215;g=c[p+((o>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(f&1023^1)|0]=m;c[2276075]=l;c[2276076]=l;c[2276078]=0;c[2276077]=0;return}else{gg[c[p+196648+(g<<2)>>2]&4095](o,m);c[2276075]=l;c[2276076]=l;c[2276078]=0;c[2276077]=0;return}}function Js(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=c[2276054]|0;c[2276054]=l+2;m=c[2276085]|0;b=m&l;e=b&16777215;j=c[2112932]|0;i=c[j+(e>>>10<<2)>>2]|0;if(i>>>0>9){n=a[i+(b&1023^1)|0]|0;o=m;p=j}else{m=gj[c[j+196608+(i<<2)>>2]&4095](e)|0;n=m;o=c[2276085]|0;p=c[2112932]|0}m=n&255|g>>>((f<<3&16^16)>>>0)&255;f=o&l;l=m&255;o=f&16777215;g=c[p+((o>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(f&1023^1)|0]=l;c[2276075]=m;c[2276076]=m;c[2276078]=0;c[2276077]=0;return}else{gg[c[p+196648+(g<<2)>>2]&4095](o,l);c[2276075]=m;c[2276076]=m;c[2276078]=0;c[2276077]=0;return}}function Jt(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=9104156+((c[2276069]&7|8)<<2)|0;m=(c[l>>2]|0)-1|0;c[l>>2]=m;l=c[2276085]|0;b=l&m;e=b&16777215;j=c[2112932]|0;i=c[j+(e>>>10<<2)>>2]|0;if(i>>>0>9){n=a[i+(b&1023^1)|0]|0;o=l;p=j}else{l=gj[c[j+196608+(i<<2)>>2]&4095](e)|0;n=l;o=c[2276085]|0;p=c[2112932]|0}l=n&255|g>>>((f<<3&16^16)>>>0)&255;f=o&m;m=l&255;o=f&16777215;g=c[p+((o>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(f&1023^1)|0]=m;c[2276075]=l;c[2276076]=l;c[2276078]=0;c[2276077]=0;return}else{gg[c[p+196648+(g<<2)>>2]&4095](o,m);c[2276075]=l;c[2276076]=l;c[2276078]=0;c[2276077]=0;return}}function Ju(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=(c[2276054]|0)-2|0;c[2276054]=l;m=c[2276085]|0;b=m&l;e=b&16777215;j=c[2112932]|0;i=c[j+(e>>>10<<2)>>2]|0;if(i>>>0>9){n=a[i+(b&1023^1)|0]|0;o=m;p=j}else{m=gj[c[j+196608+(i<<2)>>2]&4095](e)|0;n=m;o=c[2276085]|0;p=c[2112932]|0}m=n&255|g>>>((f<<3&16^16)>>>0)&255;f=o&l;l=m&255;o=f&16777215;g=c[p+((o>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(f&1023^1)|0]=l;c[2276075]=m;c[2276076]=m;c[2276078]=0;c[2276077]=0;return}else{gg[c[p+196648+(g<<2)>>2]&4095](o,l);c[2276075]=m;c[2276076]=m;c[2276078]=0;c[2276077]=0;return}}function Jv(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0);f=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;o=p&-4;if((o|0)==(h|0)){q=p;r=g}else{c[2276083]=o;g=c[2276085]&o;o=g&16777212;h=c[2112932]|0;e=c[h+((o>>>10|32768)<<2)>>2]|0;if(e>>>0>9){j=g&1020;s=(d[e+(j|3)|0]|0)<<8|(d[e+(j|2)|0]|0)|((d[e+(j|1)|0]|0)<<8|(d[e+j|0]|0))<<16;t=p}else{p=gj[c[h+196768+(e<<2)>>2]&4095](o)|0;s=p;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;s=(r>>>((q<<3&16^16)>>>0)<<16>>16)+f|0;f=c[2276085]|0;q=s&f;r=q&16777215;t=c[2112932]|0;p=c[t+(r>>>10<<2)>>2]|0;if(p>>>0>9){u=a[p+(q&1023^1)|0]|0;v=f;w=t}else{f=gj[c[t+196608+(p<<2)>>2]&4095](r)|0;u=f;v=c[2276085]|0;w=c[2112932]|0}f=u&255|n&255;n=v&s;s=f&255;v=n&16777215;u=c[w+((v>>>10|16384)<<2)>>2]|0;if(u>>>0>9){a[u+(n&1023^1)|0]=s;c[2276075]=f;c[2276076]=f;c[2276078]=0;c[2276077]=0;return}else{gg[c[w+196648+(u<<2)>>2]&4095](v,s);c[2276075]=f;c[2276076]=f;c[2276078]=0;c[2276077]=0;return}}function Jw(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=Hd(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;m=c[2276085]|0;b=m&l;e=b&16777215;j=c[2112932]|0;i=c[j+(e>>>10<<2)>>2]|0;if(i>>>0>9){n=a[i+(b&1023^1)|0]|0;o=m;p=j}else{m=gj[c[j+196608+(i<<2)>>2]&4095](e)|0;n=m;o=c[2276085]|0;p=c[2112932]|0}m=n&255|g>>>((f<<3&16^16)>>>0)&255;f=o&l;l=m&255;o=f&16777215;g=c[p+((o>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(f&1023^1)|0]=l;c[2276075]=m;c[2276076]=m;c[2276078]=0;c[2276077]=0;return}else{gg[c[p+196648+(g<<2)>>2]&4095](o,l);c[2276075]=m;c[2276076]=m;c[2276078]=0;c[2276077]=0;return}}function Jx(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0);f=p&-4;if((f|0)==(h|0)){q=p;r=g}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;h=c[2112932]|0;o=c[h+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=p}else{p=gj[c[h+196768+(o<<2)>>2]&4095](f)|0;s=p;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;s=r>>>((q<<3&16^16)>>>0)<<16>>16;q=c[2276085]|0;r=s&q;t=r&16777215;p=c[2112932]|0;f=c[p+(t>>>10<<2)>>2]|0;if(f>>>0>9){u=a[f+(r&1023^1)|0]|0;v=q;w=p}else{q=gj[c[p+196608+(f<<2)>>2]&4095](t)|0;u=q;v=c[2276085]|0;w=c[2112932]|0}q=u&255|n&255;n=v&s;s=q&255;v=n&16777215;u=c[w+((v>>>10|16384)<<2)>>2]|0;if(u>>>0>9){a[u+(n&1023^1)|0]=s;c[2276075]=q;c[2276076]=q;c[2276078]=0;c[2276077]=0;return}else{gg[c[w+196648+(u<<2)>>2]&4095](v,s);c[2276075]=q;c[2276076]=q;c[2276078]=0;c[2276077]=0;return}}function Jy(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0);f=p&-4;if((f|0)==(h|0)){q=p;r=h;s=g}else{c[2276083]=f;g=c[2276085]&f;h=g&16777212;o=c[2112932]|0;e=c[o+((h>>>10|32768)<<2)>>2]|0;if(e>>>0>9){j=g&1020;t=(d[e+(j|3)|0]|0)<<8|(d[e+(j|2)|0]|0)|((d[e+(j|1)|0]|0)<<8|(d[e+j|0]|0))<<16;u=p;v=f}else{f=gj[c[o+196768+(e<<2)>>2]&4095](h)|0;t=f;u=c[2276056]|0;v=c[2276083]|0}c[2276084]=t;q=u;r=v;s=t}t=q+2|0;c[2276056]=t;q=t&-4;if((q|0)==(r|0)){w=s;x=t}else{c[2276083]=q;r=c[2276085]&q;q=r&16777212;v=c[2112932]|0;u=c[v+((q>>>10|32768)<<2)>>2]|0;if(u>>>0>9){f=r&1020;y=(d[u+(f|3)|0]|0)<<8|(d[u+(f|2)|0]|0)|((d[u+(f|1)|0]|0)<<8|(d[u+f|0]|0))<<16;z=t}else{t=gj[c[v+196768+(u<<2)>>2]&4095](q)|0;y=t;z=c[2276056]|0}c[2276084]=y;w=y>>>16|s<<16;x=z}c[2276056]=x+2;x=c[2276085]|0;z=x&w;s=z&16777215;y=c[2112932]|0;t=c[y+(s>>>10<<2)>>2]|0;if(t>>>0>9){A=a[t+(z&1023^1)|0]|0;B=x;C=y}else{x=gj[c[y+196608+(t<<2)>>2]&4095](s)|0;A=x;B=c[2276085]|0;C=c[2112932]|0}x=A&255|n&255;n=B&w;w=x&255;B=n&16777215;A=c[C+((B>>>10|16384)<<2)>>2]|0;if(A>>>0>9){a[A+(n&1023^1)|0]=w;c[2276075]=x;c[2276076]=x;c[2276078]=0;c[2276077]=0;return}else{gg[c[C+196648+(A<<2)>>2]&4095](B,w);c[2276075]=x;c[2276076]=x;c[2276078]=0;c[2276077]=0;return}}function Jz(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=9104156+((c[2276069]&7)<<2)|0;l=f>>>((e<<3&16^16)>>>0)&65535|c[k>>2];c[k>>2]=l;k=l&65535;c[2276075]=k>>>8;c[2276076]=k;c[2276078]=0;c[2276077]=0;return}function JA(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;m=c[2276085]|0;b=m&l;e=b&16777215;j=c[2112932]|0;i=c[j+(e>>>10<<2)>>2]|0;if(i>>>0>9){k=b&1023;n=(d[i+(k+1)|0]|0)<<8|(d[i+k|0]|0);o=m;p=j}else{m=gj[c[j+196688+(i<<2)>>2]&4095](e)|0;n=m;o=c[2276085]|0;p=c[2112932]|0}m=n&65535|g>>>((f<<3&16^16)>>>0)&65535;f=o&l;l=m&65535;o=f&16777215;g=c[p+((o>>>10|16384)<<2)>>2]|0;if(g>>>0>9){n=f&1023;a[g+n|0]=m&255;a[g+(n+1)|0]=(l&65535)>>>8&255;q=m>>>8;c[2276075]=q;c[2276076]=m;c[2276078]=0;c[2276077]=0;return}else{gg[c[p+196728+(g<<2)>>2]&4095](o,l);q=m>>>8;c[2276075]=q;c[2276076]=m;c[2276078]=0;c[2276077]=0;return}}function JB(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=9104156+((c[2276069]&7|8)<<2)|0;m=c[l>>2]|0;c[l>>2]=m+2;l=c[2276085]|0;b=l&m;e=b&16777215;j=c[2112932]|0;i=c[j+(e>>>10<<2)>>2]|0;if(i>>>0>9){k=b&1023;n=(d[i+(k+1)|0]|0)<<8|(d[i+k|0]|0);o=l;p=j}else{l=gj[c[j+196688+(i<<2)>>2]&4095](e)|0;n=l;o=c[2276085]|0;p=c[2112932]|0}l=n&65535|g>>>((f<<3&16^16)>>>0)&65535;f=o&m;m=l&65535;o=f&16777215;g=c[p+((o>>>10|16384)<<2)>>2]|0;if(g>>>0>9){n=f&1023;a[g+n|0]=l&255;a[g+(n+1)|0]=(m&65535)>>>8&255;q=l>>>8;c[2276075]=q;c[2276076]=l;c[2276078]=0;c[2276077]=0;return}else{gg[c[p+196728+(g<<2)>>2]&4095](o,m);q=l>>>8;c[2276075]=q;c[2276076]=l;c[2276078]=0;c[2276077]=0;return}}function JC(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=9104156+((c[2276069]&7|8)<<2)|0;m=(c[l>>2]|0)-2|0;c[l>>2]=m;l=c[2276085]|0;b=l&m;e=b&16777215;j=c[2112932]|0;i=c[j+(e>>>10<<2)>>2]|0;if(i>>>0>9){k=b&1023;n=(d[i+(k+1)|0]|0)<<8|(d[i+k|0]|0);o=l;p=j}else{l=gj[c[j+196688+(i<<2)>>2]&4095](e)|0;n=l;o=c[2276085]|0;p=c[2112932]|0}l=n&65535|g>>>((f<<3&16^16)>>>0)&65535;f=o&m;m=l&65535;o=f&16777215;g=c[p+((o>>>10|16384)<<2)>>2]|0;if(g>>>0>9){n=f&1023;a[g+n|0]=l&255;a[g+(n+1)|0]=(m&65535)>>>8&255;q=l>>>8;c[2276075]=q;c[2276076]=l;c[2276078]=0;c[2276077]=0;return}else{gg[c[p+196728+(g<<2)>>2]&4095](o,m);q=l>>>8;c[2276075]=q;c[2276076]=l;c[2276078]=0;c[2276077]=0;return}}function JD(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0);f=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;o=p&-4;if((o|0)==(h|0)){q=p;r=g}else{c[2276083]=o;g=c[2276085]&o;o=g&16777212;h=c[2112932]|0;e=c[h+((o>>>10|32768)<<2)>>2]|0;if(e>>>0>9){j=g&1020;s=(d[e+(j|3)|0]|0)<<8|(d[e+(j|2)|0]|0)|((d[e+(j|1)|0]|0)<<8|(d[e+j|0]|0))<<16;t=p}else{p=gj[c[h+196768+(e<<2)>>2]&4095](o)|0;s=p;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;s=(r>>>((q<<3&16^16)>>>0)<<16>>16)+f|0;f=c[2276085]|0;q=s&f;r=q&16777215;t=c[2112932]|0;p=c[t+(r>>>10<<2)>>2]|0;if(p>>>0>9){o=q&1023;u=(d[p+(o+1)|0]|0)<<8|(d[p+o|0]|0);v=f;w=t}else{f=gj[c[t+196688+(p<<2)>>2]&4095](r)|0;u=f;v=c[2276085]|0;w=c[2112932]|0}f=u&65535|n&65535;n=v&s;s=f&65535;v=n&16777215;u=c[w+((v>>>10|16384)<<2)>>2]|0;if(u>>>0>9){r=n&1023;a[u+r|0]=f&255;a[u+(r+1)|0]=(s&65535)>>>8&255;x=f>>>8;c[2276075]=x;c[2276076]=f;c[2276078]=0;c[2276077]=0;return}else{gg[c[w+196728+(u<<2)>>2]&4095](v,s);x=f>>>8;c[2276075]=x;c[2276076]=f;c[2276078]=0;c[2276077]=0;return}}function JE(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=Hd(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;m=c[2276085]|0;b=m&l;e=b&16777215;j=c[2112932]|0;i=c[j+(e>>>10<<2)>>2]|0;if(i>>>0>9){k=b&1023;n=(d[i+(k+1)|0]|0)<<8|(d[i+k|0]|0);o=m;p=j}else{m=gj[c[j+196688+(i<<2)>>2]&4095](e)|0;n=m;o=c[2276085]|0;p=c[2112932]|0}m=n&65535|g>>>((f<<3&16^16)>>>0)&65535;f=o&l;l=m&65535;o=f&16777215;g=c[p+((o>>>10|16384)<<2)>>2]|0;if(g>>>0>9){n=f&1023;a[g+n|0]=m&255;a[g+(n+1)|0]=(l&65535)>>>8&255;q=m>>>8;c[2276075]=q;c[2276076]=m;c[2276078]=0;c[2276077]=0;return}else{gg[c[p+196728+(g<<2)>>2]&4095](o,l);q=m>>>8;c[2276075]=q;c[2276076]=m;c[2276078]=0;c[2276077]=0;return}}function JF(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0);f=p&-4;if((f|0)==(h|0)){q=p;r=g}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;h=c[2112932]|0;o=c[h+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=p}else{p=gj[c[h+196768+(o<<2)>>2]&4095](f)|0;s=p;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;s=r>>>((q<<3&16^16)>>>0)<<16>>16;q=c[2276085]|0;r=s&q;t=r&16777215;p=c[2112932]|0;f=c[p+(t>>>10<<2)>>2]|0;if(f>>>0>9){o=r&1023;u=(d[f+(o+1)|0]|0)<<8|(d[f+o|0]|0);v=q;w=p}else{q=gj[c[p+196688+(f<<2)>>2]&4095](t)|0;u=q;v=c[2276085]|0;w=c[2112932]|0}q=u&65535|n&65535;n=v&s;s=q&65535;v=n&16777215;u=c[w+((v>>>10|16384)<<2)>>2]|0;if(u>>>0>9){t=n&1023;a[u+t|0]=q&255;a[u+(t+1)|0]=(s&65535)>>>8&255;x=q>>>8;c[2276075]=x;c[2276076]=q;c[2276078]=0;c[2276077]=0;return}else{gg[c[w+196728+(u<<2)>>2]&4095](v,s);x=q>>>8;c[2276075]=x;c[2276076]=q;c[2276078]=0;c[2276077]=0;return}}function JG(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0);f=p&-4;if((f|0)==(h|0)){q=p;r=h;s=g}else{c[2276083]=f;g=c[2276085]&f;h=g&16777212;o=c[2112932]|0;e=c[o+((h>>>10|32768)<<2)>>2]|0;if(e>>>0>9){j=g&1020;t=(d[e+(j|3)|0]|0)<<8|(d[e+(j|2)|0]|0)|((d[e+(j|1)|0]|0)<<8|(d[e+j|0]|0))<<16;u=p;v=f}else{f=gj[c[o+196768+(e<<2)>>2]&4095](h)|0;t=f;u=c[2276056]|0;v=c[2276083]|0}c[2276084]=t;q=u;r=v;s=t}t=q+2|0;c[2276056]=t;q=t&-4;if((q|0)==(r|0)){w=s;x=t}else{c[2276083]=q;r=c[2276085]&q;q=r&16777212;v=c[2112932]|0;u=c[v+((q>>>10|32768)<<2)>>2]|0;if(u>>>0>9){f=r&1020;y=(d[u+(f|3)|0]|0)<<8|(d[u+(f|2)|0]|0)|((d[u+(f|1)|0]|0)<<8|(d[u+f|0]|0))<<16;z=t}else{t=gj[c[v+196768+(u<<2)>>2]&4095](q)|0;y=t;z=c[2276056]|0}c[2276084]=y;w=y>>>16|s<<16;x=z}c[2276056]=x+2;x=c[2276085]|0;z=x&w;s=z&16777215;y=c[2112932]|0;t=c[y+(s>>>10<<2)>>2]|0;if(t>>>0>9){q=z&1023;A=(d[t+(q+1)|0]|0)<<8|(d[t+q|0]|0);B=x;C=y}else{x=gj[c[y+196688+(t<<2)>>2]&4095](s)|0;A=x;B=c[2276085]|0;C=c[2112932]|0}x=A&65535|n&65535;n=B&w;w=x&65535;B=n&16777215;A=c[C+((B>>>10|16384)<<2)>>2]|0;if(A>>>0>9){s=n&1023;a[A+s|0]=x&255;a[A+(s+1)|0]=(w&65535)>>>8&255;D=x>>>8;c[2276075]=D;c[2276076]=x;c[2276078]=0;c[2276077]=0;return}else{gg[c[C+196728+(A<<2)>>2]&4095](B,w);D=x>>>8;c[2276075]=D;c[2276076]=x;c[2276078]=0;c[2276077]=0;return}}function JH(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=b;g=c[2276084]|0}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=o;g=m}m=e+2|0;c[2276056]=m;e=m&-4;if((e|0)==(f|0)){p=g;q=m;r=q+2|0;c[2276056]=r;s=c[2276069]|0;t=s&7;u=9104156+(t<<2)|0;v=c[u>>2]|0;w=v|p;c[u>>2]=w;x=w>>>24;c[2276075]=x;c[2276076]=w;c[2276078]=0;c[2276077]=0;return}c[2276083]=e;f=c[2276085]&e;e=f&16777212;o=c[2112932]|0;n=c[o+((e>>>10|32768)<<2)>>2]|0;if(n>>>0>9){b=f&1020;y=(d[n+(b|3)|0]|0)<<8|(d[n+(b|2)|0]|0)|((d[n+(b|1)|0]|0)<<8|(d[n+b|0]|0))<<16;z=m}else{m=gj[c[o+196768+(n<<2)>>2]&4095](e)|0;y=m;z=c[2276056]|0}c[2276084]=y;p=y>>>16|g<<16;q=z;r=q+2|0;c[2276056]=r;s=c[2276069]|0;t=s&7;u=9104156+(t<<2)|0;v=c[u>>2]|0;w=v|p;c[u>>2]=w;x=w>>>24;c[2276075]=x;c[2276076]=w;c[2276078]=0;c[2276077]=0;return}function JI(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;t=c[2276085]|0;h=t&r;s=h&16777215;n=c[2112932]|0;f=c[n+(s>>>10<<2)>>2]|0;if(f>>>0>9){o=h&1023;u=(d[f+(o+3)|0]|0)<<8|(d[f+(o+2)|0]|0)|((d[f+(o+1)|0]|0)<<8|(d[f+o|0]|0))<<16;v=t;w=n}else{t=gj[c[n+196768+(f<<2)>>2]&4095](s)|0;u=t;v=c[2276085]|0;w=c[2112932]|0}t=u|q;q=v&r;r=q&16777215;v=c[w+((r>>>10|16384)<<2)>>2]|0;if(v>>>0>9){u=q&1023;a[v+u|0]=t>>>16&255;q=t>>>24;a[v+(u+1)|0]=q&255;a[v+(u+2)|0]=t&255;a[v+(u+3)|0]=t>>>8&255;x=q;c[2276075]=x;c[2276076]=t;c[2276078]=0;c[2276077]=0;return}else{gg[c[w+196808+(v<<2)>>2]&4095](r,t);x=t>>>24;c[2276075]=x;c[2276076]=t;c[2276078]=0;c[2276077]=0;return}}function JJ(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=9104156+((c[2276069]&7|8)<<2)|0;t=c[r>>2]|0;c[r>>2]=t+4;r=c[2276085]|0;h=r&t;s=h&16777215;n=c[2112932]|0;f=c[n+(s>>>10<<2)>>2]|0;if(f>>>0>9){o=h&1023;u=(d[f+(o+3)|0]|0)<<8|(d[f+(o+2)|0]|0)|((d[f+(o+1)|0]|0)<<8|(d[f+o|0]|0))<<16;v=r;w=n}else{r=gj[c[n+196768+(f<<2)>>2]&4095](s)|0;u=r;v=c[2276085]|0;w=c[2112932]|0}r=u|q;q=v&t;t=q&16777215;v=c[w+((t>>>10|16384)<<2)>>2]|0;if(v>>>0>9){u=q&1023;a[v+u|0]=r>>>16&255;q=r>>>24;a[v+(u+1)|0]=q&255;a[v+(u+2)|0]=r&255;a[v+(u+3)|0]=r>>>8&255;x=q;c[2276075]=x;c[2276076]=r;c[2276078]=0;c[2276077]=0;return}else{gg[c[w+196808+(v<<2)>>2]&4095](t,r);x=r>>>24;c[2276075]=x;c[2276076]=r;c[2276078]=0;c[2276077]=0;return}}function JK(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=9104156+((c[2276069]&7|8)<<2)|0;t=(c[r>>2]|0)-4|0;c[r>>2]=t;r=c[2276085]|0;h=r&t;s=h&16777215;n=c[2112932]|0;f=c[n+(s>>>10<<2)>>2]|0;if(f>>>0>9){o=h&1023;u=(d[f+(o+3)|0]|0)<<8|(d[f+(o+2)|0]|0)|((d[f+(o+1)|0]|0)<<8|(d[f+o|0]|0))<<16;v=r;w=n}else{r=gj[c[n+196768+(f<<2)>>2]&4095](s)|0;u=r;v=c[2276085]|0;w=c[2112932]|0}r=u|q;q=v&t;t=q&16777215;v=c[w+((t>>>10|16384)<<2)>>2]|0;if(v>>>0>9){u=q&1023;a[v+u|0]=r>>>16&255;q=r>>>24;a[v+(u+1)|0]=q&255;a[v+(u+2)|0]=r&255;a[v+(u+3)|0]=r>>>8&255;x=q;c[2276075]=x;c[2276076]=r;c[2276078]=0;c[2276077]=0;return}else{gg[c[w+196808+(v<<2)>>2]&4095](t,r);x=r>>>24;c[2276075]=x;c[2276076]=r;c[2276078]=0;c[2276077]=0;return}}function JL(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;f=p&-4;if((f|0)==(h|0)){q=g;r=p;s=h;t=g}else{c[2276083]=f;h=c[2276085]&f;n=h&16777212;o=c[2112932]|0;e=c[o+((n>>>10|32768)<<2)>>2]|0;if(e>>>0>9){j=h&1020;u=(d[e+(j|3)|0]|0)<<8|(d[e+(j|2)|0]|0)|((d[e+(j|1)|0]|0)<<8|(d[e+j|0]|0))<<16;v=p;w=f}else{f=gj[c[o+196768+(e<<2)>>2]&4095](n)|0;u=f;v=c[2276056]|0;w=c[2276083]|0}c[2276084]=u;q=u>>>16|g<<16;r=v;s=w;t=u}u=r+2|0;c[2276056]=u;r=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;w=u&-4;if((w|0)==(s|0)){x=u;y=t}else{c[2276083]=w;t=c[2276085]&w;w=t&16777212;s=c[2112932]|0;v=c[s+((w>>>10|32768)<<2)>>2]|0;if(v>>>0>9){g=t&1020;z=(d[v+(g|3)|0]|0)<<8|(d[v+(g|2)|0]|0)|((d[v+(g|1)|0]|0)<<8|(d[v+g|0]|0))<<16;A=u}else{u=gj[c[s+196768+(v<<2)>>2]&4095](w)|0;z=u;A=c[2276056]|0}c[2276084]=z;x=A;y=z}c[2276056]=x+2;z=(y>>>((x<<3&16^16)>>>0)<<16>>16)+r|0;r=c[2276085]|0;x=z&r;y=x&16777215;A=c[2112932]|0;u=c[A+(y>>>10<<2)>>2]|0;if(u>>>0>9){w=x&1023;B=(d[u+(w+3)|0]|0)<<8|(d[u+(w+2)|0]|0)|((d[u+(w+1)|0]|0)<<8|(d[u+w|0]|0))<<16;C=r;D=A}else{r=gj[c[A+196768+(u<<2)>>2]&4095](y)|0;B=r;C=c[2276085]|0;D=c[2112932]|0}r=B|q;q=C&z;z=q&16777215;C=c[D+((z>>>10|16384)<<2)>>2]|0;if(C>>>0>9){B=q&1023;a[C+B|0]=r>>>16&255;q=r>>>24;a[C+(B+1)|0]=q&255;a[C+(B+2)|0]=r&255;a[C+(B+3)|0]=r>>>8&255;E=q;c[2276075]=E;c[2276076]=r;c[2276078]=0;c[2276077]=0;return}else{gg[c[D+196808+(C<<2)>>2]&4095](z,r);E=r>>>24;c[2276075]=E;c[2276076]=r;c[2276078]=0;c[2276077]=0;return}}function JM(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=Hd(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;t=c[2276085]|0;h=t&r;s=h&16777215;n=c[2112932]|0;f=c[n+(s>>>10<<2)>>2]|0;if(f>>>0>9){o=h&1023;u=(d[f+(o+3)|0]|0)<<8|(d[f+(o+2)|0]|0)|((d[f+(o+1)|0]|0)<<8|(d[f+o|0]|0))<<16;v=t;w=n}else{t=gj[c[n+196768+(f<<2)>>2]&4095](s)|0;u=t;v=c[2276085]|0;w=c[2112932]|0}t=u|q;q=v&r;r=q&16777215;v=c[w+((r>>>10|16384)<<2)>>2]|0;if(v>>>0>9){u=q&1023;a[v+u|0]=t>>>16&255;q=t>>>24;a[v+(u+1)|0]=q&255;a[v+(u+2)|0]=t&255;a[v+(u+3)|0]=t>>>8&255;x=q;c[2276075]=x;c[2276076]=t;c[2276078]=0;c[2276077]=0;return}else{gg[c[w+196808+(v<<2)>>2]&4095](r,t);x=t>>>24;c[2276075]=x;c[2276076]=t;c[2276078]=0;c[2276077]=0;return}}function JN(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;f=p&-4;if((f|0)==(h|0)){q=g;r=p;s=h;t=g}else{c[2276083]=f;h=c[2276085]&f;n=h&16777212;o=c[2112932]|0;e=c[o+((n>>>10|32768)<<2)>>2]|0;if(e>>>0>9){j=h&1020;u=(d[e+(j|3)|0]|0)<<8|(d[e+(j|2)|0]|0)|((d[e+(j|1)|0]|0)<<8|(d[e+j|0]|0))<<16;v=p;w=f}else{f=gj[c[o+196768+(e<<2)>>2]&4095](n)|0;u=f;v=c[2276056]|0;w=c[2276083]|0}c[2276084]=u;q=u>>>16|g<<16;r=v;s=w;t=u}u=r+2|0;c[2276056]=u;r=u&-4;if((r|0)==(s|0)){x=u;y=t}else{c[2276083]=r;t=c[2276085]&r;r=t&16777212;s=c[2112932]|0;w=c[s+((r>>>10|32768)<<2)>>2]|0;if(w>>>0>9){v=t&1020;z=(d[w+(v|3)|0]|0)<<8|(d[w+(v|2)|0]|0)|((d[w+(v|1)|0]|0)<<8|(d[w+v|0]|0))<<16;A=u}else{u=gj[c[s+196768+(w<<2)>>2]&4095](r)|0;z=u;A=c[2276056]|0}c[2276084]=z;x=A;y=z}c[2276056]=x+2;z=y>>>((x<<3&16^16)>>>0)<<16>>16;x=c[2276085]|0;y=z&x;A=y&16777215;u=c[2112932]|0;r=c[u+(A>>>10<<2)>>2]|0;if(r>>>0>9){w=y&1023;B=(d[r+(w+3)|0]|0)<<8|(d[r+(w+2)|0]|0)|((d[r+(w+1)|0]|0)<<8|(d[r+w|0]|0))<<16;C=x;D=u}else{x=gj[c[u+196768+(r<<2)>>2]&4095](A)|0;B=x;C=c[2276085]|0;D=c[2112932]|0}x=B|q;q=C&z;z=q&16777215;C=c[D+((z>>>10|16384)<<2)>>2]|0;if(C>>>0>9){B=q&1023;a[C+B|0]=x>>>16&255;q=x>>>24;a[C+(B+1)|0]=q&255;a[C+(B+2)|0]=x&255;a[C+(B+3)|0]=x>>>8&255;E=q;c[2276075]=E;c[2276076]=x;c[2276078]=0;c[2276077]=0;return}else{gg[c[D+196808+(C<<2)>>2]&4095](z,x);E=x>>>24;c[2276075]=E;c[2276076]=x;c[2276078]=0;c[2276077]=0;return}}function JO(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;f=p&-4;if((f|0)==(h|0)){q=g;r=p;s=h;t=g}else{c[2276083]=f;h=c[2276085]&f;n=h&16777212;o=c[2112932]|0;e=c[o+((n>>>10|32768)<<2)>>2]|0;if(e>>>0>9){j=h&1020;u=(d[e+(j|3)|0]|0)<<8|(d[e+(j|2)|0]|0)|((d[e+(j|1)|0]|0)<<8|(d[e+j|0]|0))<<16;v=p;w=f}else{f=gj[c[o+196768+(e<<2)>>2]&4095](n)|0;u=f;v=c[2276056]|0;w=c[2276083]|0}c[2276084]=u;q=u>>>16|g<<16;r=v;s=w;t=u}u=r+2|0;c[2276056]=u;r=u&-4;if((r|0)==(s|0)){x=u;y=s;z=t}else{c[2276083]=r;t=c[2276085]&r;s=t&16777212;w=c[2112932]|0;v=c[w+((s>>>10|32768)<<2)>>2]|0;if(v>>>0>9){g=t&1020;A=(d[v+(g|3)|0]|0)<<8|(d[v+(g|2)|0]|0)|((d[v+(g|1)|0]|0)<<8|(d[v+g|0]|0))<<16;B=u;C=r}else{r=gj[c[w+196768+(v<<2)>>2]&4095](s)|0;A=r;B=c[2276056]|0;C=c[2276083]|0}c[2276084]=A;x=B;y=C;z=A}A=x+2|0;c[2276056]=A;x=A&-4;if((x|0)==(y|0)){D=z;E=A}else{c[2276083]=x;y=c[2276085]&x;x=y&16777212;C=c[2112932]|0;B=c[C+((x>>>10|32768)<<2)>>2]|0;if(B>>>0>9){r=y&1020;F=(d[B+(r|3)|0]|0)<<8|(d[B+(r|2)|0]|0)|((d[B+(r|1)|0]|0)<<8|(d[B+r|0]|0))<<16;G=A}else{A=gj[c[C+196768+(B<<2)>>2]&4095](x)|0;F=A;G=c[2276056]|0}c[2276084]=F;D=F>>>16|z<<16;E=G}c[2276056]=E+2;E=c[2276085]|0;G=E&D;z=G&16777215;F=c[2112932]|0;A=c[F+(z>>>10<<2)>>2]|0;if(A>>>0>9){x=G&1023;H=(d[A+(x+3)|0]|0)<<8|(d[A+(x+2)|0]|0)|((d[A+(x+1)|0]|0)<<8|(d[A+x|0]|0))<<16;I=E;J=F}else{E=gj[c[F+196768+(A<<2)>>2]&4095](z)|0;H=E;I=c[2276085]|0;J=c[2112932]|0}E=H|q;q=I&D;D=q&16777215;I=c[J+((D>>>10|16384)<<2)>>2]|0;if(I>>>0>9){H=q&1023;a[I+H|0]=E>>>16&255;q=E>>>24;a[I+(H+1)|0]=q&255;a[I+(H+2)|0]=E&255;a[I+(H+3)|0]=E>>>8&255;K=q;c[2276075]=K;c[2276076]=E;c[2276078]=0;c[2276077]=0;return}else{gg[c[J+196808+(I<<2)>>2]&4095](D,E);K=E>>>24;c[2276075]=K;c[2276076]=E;c[2276078]=0;c[2276077]=0;return}}function JP(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=(c[2276075]|0)>>>4&8|(c[2276074]|0)>>>4&16|((c[2276076]|0)==0)<<2|(c[2276077]|0)>>>6&2|(c[2276078]|0)>>>8&1;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=a|g>>>((f<<3&16^16)>>>0)&65535;f=l<<4;c[2276074]=f&256;c[2276075]=f&128;c[2276076]=l>>>2&1^1;c[2276077]=l<<6&128;c[2276078]=l<<8&256;return}function JQ(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=c[2276072]|0;if((b|0)!=0){e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0;i=b}else{c[2276083]=f;j=c[2276085]&f;f=j&16777212;k=c[2112932]|0;l=c[k+((f>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=j&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=e;p=b}else{b=gj[c[k+196768+(l<<2)>>2]&4095](f)|0;n=b;o=c[2276056]|0;p=c[2276072]|0}c[2276084]=n;g=o;h=n;i=p}c[2276056]=g+2;JR(c[2276070]|i<<11|c[2276071]|c[2276073]<<11|c[2276079]|h>>>((g<<3&16^16)>>>0)&65535|(c[2276074]|0)>>>4&16|(c[2276075]|0)>>>4&8|((c[2276076]|0)==0)<<2|(c[2276077]|0)>>>6&2|(c[2276078]|0)>>>8&1);return}g=c[2276073]|0;h=c[2276071]|c[2276070]|g<<11|c[2276079]|(c[2276074]|0)>>>4&16|(c[2276075]|0)>>>4&8|((c[2276076]|0)==0)<<2|(c[2276077]|0)>>>6&2|(c[2276078]|0)>>>8&1;c[2276071]=0;c[2276070]=0;c[2276057]=c[2276054];c[2276072]=4;i=c[9104228+((g&2|4)<<2)>>2]|0;c[2276054]=i;g=c[2276055]|0;do{if(((c[2276038]|0)-1|0)>>>0<2){p=i-4|0;c[2276054]=p;n=c[2276085]&p;p=n&16777215;o=c[2112932]|0;b=c[o+((p>>>10|16384)<<2)>>2]|0;if(b>>>0>9){f=n&1023;a[b+f|0]=g>>>16&255;a[b+(f+1)|0]=g>>>24&255;a[b+(f+2)|0]=g&255;a[b+(f+3)|0]=g>>>8&255;q=o}else{gg[c[o+196808+(b<<2)>>2]&4095](p,g);q=c[2112932]|0}p=(c[2276054]|0)-2|0;c[2276054]=p;b=c[2276085]&p;p=h&65535;o=b&16777215;f=c[q+((o>>>10|16384)<<2)>>2]|0;if(f>>>0>9){n=b&1023;a[f+n|0]=h&255;a[f+(n+1)|0]=(p&65535)>>>8&255;break}else{gg[c[q+196728+(f<<2)>>2]&4095](o,p);break}}else{p=i-2|0;c[2276054]=p;o=c[2276085]&p;p=o&16777215;f=c[2112932]|0;n=c[f+((p>>>10|16384)<<2)>>2]|0;if(n>>>0>9){b=o&1023;a[n+b|0]=32;a[n+(b+1)|0]=0;r=f}else{gg[c[f+196728+(n<<2)>>2]&4095](p,32);r=c[2112932]|0}p=(c[2276054]|0)-4|0;c[2276054]=p;n=c[2276085]&p;p=n&16777215;f=c[r+((p>>>10|16384)<<2)>>2]|0;if(f>>>0>9){b=n&1023;a[f+b|0]=g>>>16&255;a[f+(b+1)|0]=g>>>24&255;a[f+(b+2)|0]=g&255;a[f+(b+3)|0]=g>>>8&255;s=r}else{gg[c[r+196808+(f<<2)>>2]&4095](p,g);s=c[2112932]|0}p=(c[2276054]|0)-2|0;c[2276054]=p;f=c[2276085]&p;p=h&65535;b=f&16777215;n=c[s+((b>>>10|16384)<<2)>>2]|0;if(n>>>0>9){o=f&1023;a[n+o|0]=h&255;a[n+(o+1)|0]=(p&65535)>>>8&255;break}else{gg[c[s+196728+(n<<2)>>2]&4095](b,p);break}}}while(0);s=(c[2276064]|0)+32|0;c[2276056]=s;h=c[2276085]&s;s=h&16777215;g=c[2112932]|0;r=c[g+(s>>>10<<2)>>2]|0;if(r>>>0>9){i=h&1023;t=(d[r+(i+3)|0]|0)<<8|(d[r+(i+2)|0]|0)|((d[r+(i+1)|0]|0)<<8|(d[r+i|0]|0))<<16}else{t=gj[c[g+196768+(r<<2)>>2]&4095](s)|0}c[2276056]=t;c[2276108]=(d[(c[2276098]|0)+(c[2276069]|0)|0]|0)-(d[(c[2276099]|0)+8|0]|0)+(c[2276108]|0);return}function JR(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=c[2276086]&b;c[2276070]=e&32768;c[2276071]=e&16384;c[2276079]=e&1792;b=e<<4;c[2276074]=b&256;c[2276075]=b&128;c[2276076]=e>>>2&1^1;c[2276077]=e<<6&128;c[2276078]=e<<8&256;b=e>>>11;e=c[2276072]|0;c[9104228+((e>>>1&c[2276073]|e)<<2)>>2]=c[2276054];e=b&4;c[2276072]=e;f=b&2;c[2276073]=f;c[2276054]=c[9104228+((e>>>1&f|e)<<2)>>2];e=c[2276080]|0;if(e>>>0<=(c[2276079]|0)>>>0){return}f=e>>>8;e=c[2276082]&-2;c[2276082]=e;if((e|0)!=0){return}e=8452200+(c[2394]<<2)|0;if((c[e>>2]&8192|0)!=0){c[2276080]=0;c[e>>2]=0}e=c[(c[2112932]|0)+196856>>2]|0;do{if((e|0)==0){g=34556}else{b=gj[e&4095](f)|0;if((b|0)==(-1|0)){g=34556;break}else if((b|0)==(-2|0)){h=24;break}if(b>>>0<=255){h=b;break}return}}while(0);if((g|0)==34556){h=f+24|0}g=c[2276072]|0;e=c[2276073]|0;b=c[2276071]|c[2276070]|g<<11|e<<11|c[2276079]|(c[2276074]|0)>>>4&16|(c[2276075]|0)>>>4&8|((c[2276076]|0)==0)<<2|(c[2276077]|0)>>>6&2|(c[2276078]|0)>>>8&1;c[2276071]=0;c[2276070]=0;c[9104228+((g>>>1&e|g)<<2)>>2]=c[2276054];c[2276072]=4;c[2276054]=c[9104228+((c[2276073]&2|4)<<2)>>2];c[2276079]=f<<8;f=h<<2;g=c[2276085]&(c[2276064]|0)+f;e=g&16777215;i=c[2112932]|0;j=c[i+(e>>>10<<2)>>2]|0;if(j>>>0>9){k=g&1023;l=(d[j+(k+3)|0]|0)<<8|(d[j+(k+2)|0]|0)|((d[j+(k+1)|0]|0)<<8|(d[j+k|0]|0))<<16}else{l=gj[c[i+196768+(j<<2)>>2]&4095](e)|0}do{if((l|0)==0){e=c[2276085]&(c[2276064]|0)+60;j=e&16777215;i=c[2112932]|0;k=c[i+(j>>>10<<2)>>2]|0;if(k>>>0>9){g=e&1023;m=(d[k+(g+3)|0]|0)<<8|(d[k+(g+2)|0]|0)|((d[k+(g+1)|0]|0)<<8|(d[k+g|0]|0))<<16;break}else{m=gj[c[i+196768+(k<<2)>>2]&4095](j)|0;break}}else{m=l}}while(0);l=c[2276056]|0;j=c[2276054]|0;do{if(((c[2276038]|0)-1|0)>>>0<2){k=j-4|0;c[2276054]=k;i=c[2276085]&k;k=i&16777215;g=c[2112932]|0;e=c[g+((k>>>10|16384)<<2)>>2]|0;if(e>>>0>9){n=i&1023;a[e+n|0]=l>>>16&255;a[e+(n+1)|0]=l>>>24&255;a[e+(n+2)|0]=l&255;a[e+(n+3)|0]=l>>>8&255;o=g}else{gg[c[g+196808+(e<<2)>>2]&4095](k,l);o=c[2112932]|0}k=(c[2276054]|0)-2|0;c[2276054]=k;e=c[2276085]&k;k=b&65535;g=e&16777215;n=c[o+((g>>>10|16384)<<2)>>2]|0;if(n>>>0>9){i=e&1023;a[n+i|0]=b&255;a[n+(i+1)|0]=(k&65535)>>>8&255;break}else{gg[c[o+196728+(n<<2)>>2]&4095](g,k);break}}else{k=j-2|0;c[2276054]=k;g=c[2276085]&k;k=g&16777215;n=c[2112932]|0;i=c[n+((k>>>10|16384)<<2)>>2]|0;if(i>>>0>9){e=g&1023;a[i+e|0]=f&255;a[i+(e+1)|0]=h>>>6&255;p=n}else{gg[c[n+196728+(i<<2)>>2]&4095](k,f&65535);p=c[2112932]|0}k=(c[2276054]|0)-4|0;c[2276054]=k;i=c[2276085]&k;k=i&16777215;n=c[p+((k>>>10|16384)<<2)>>2]|0;if(n>>>0>9){e=i&1023;a[n+e|0]=l>>>16&255;a[n+(e+1)|0]=l>>>24&255;a[n+(e+2)|0]=l&255;a[n+(e+3)|0]=l>>>8&255;q=p}else{gg[c[p+196808+(n<<2)>>2]&4095](k,l);q=c[2112932]|0}k=(c[2276054]|0)-2|0;c[2276054]=k;n=c[2276085]&k;k=b&65535;e=n&16777215;i=c[q+((e>>>10|16384)<<2)>>2]|0;if(i>>>0>9){g=n&1023;a[i+g|0]=b&255;a[i+(g+1)|0]=(k&65535)>>>8&255;break}else{gg[c[q+196728+(i<<2)>>2]&4095](e,k);break}}}while(0);q=c[2276073]|0;do{if((q|0)!=0){if((c[2276038]&24|0)==0){break}l=c[2276072]|0;c[9104228+((l>>>1&q|l)<<2)>>2]=c[2276054];p=l&4;c[2276072]=p;j=l&2;c[2276073]=j;l=c[2276056]|0;o=(c[9104228+((p>>>1&j|p)<<2)>>2]|0)-2|0;c[2276054]=o;p=c[2276085]&o;o=(f|4096)&65535;j=p&16777215;k=c[2112932]|0;e=c[k+((j>>>10|16384)<<2)>>2]|0;if(e>>>0>9){i=p&1023;a[e+i|0]=f&255;a[e+(i+1)|0]=(o&65535)>>>8&255;r=k}else{gg[c[k+196728+(e<<2)>>2]&4095](j,o);r=c[2112932]|0}o=(c[2276054]|0)-4|0;c[2276054]=o;j=c[2276085]&o;o=j&16777215;e=c[r+((o>>>10|16384)<<2)>>2]|0;if(e>>>0>9){k=j&1023;a[e+k|0]=l>>>16&255;a[e+(k+1)|0]=l>>>24&255;a[e+(k+2)|0]=l&255;a[e+(k+3)|0]=l>>>8&255;s=r}else{gg[c[r+196808+(e<<2)>>2]&4095](o,l);s=c[2112932]|0}l=(c[2276054]|0)-2|0;c[2276054]=l;o=c[2276085]&l;l=(b|8192)&65535;e=o&16777215;k=c[s+((e>>>10|16384)<<2)>>2]|0;if(k>>>0>9){j=o&1023;a[k+j|0]=b&255;a[k+(j+1)|0]=(l&65535)>>>8&255;break}else{gg[c[s+196728+(k<<2)>>2]&4095](e,l);break}}}while(0);c[2276056]=m;c[2276081]=(c[2276081]|0)+(d[(c[2276099]|0)+h|0]|0);return}function JS(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;if((c[2276038]&24|0)==0){JT();return}a=c[2276069]|0;b=c[9104156+((a&7)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0;i=a}else{c[2276083]=f;j=c[2276085]&f;f=j&16777212;k=c[2112932]|0;l=c[k+((f>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=j&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=e;p=a}else{a=gj[c[k+196768+(l<<2)>>2]&4095](f)|0;n=a;o=c[2276056]|0;p=c[2276069]|0}c[2276084]=n;g=o;h=n;i=p}c[2276056]=g+2;p=(h>>>((g<<3&16^16)>>>0))+b|0;b=9104156+((i>>>9&7)<<2)|0;c[b>>2]=p&15|c[b>>2]&-256|p>>>4&240;return}function JT(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;b=c[2276072]|0;e=c[2276073]|0;f=c[2276071]|c[2276070]|b<<11|e<<11|c[2276079]|(c[2276074]|0)>>>4&16|(c[2276075]|0)>>>4&8|((c[2276076]|0)==0)<<2|(c[2276077]|0)>>>6&2|(c[2276078]|0)>>>8&1;c[2276071]=0;c[2276070]=0;c[9104228+((b>>>1&e|b)<<2)>>2]=c[2276054];c[2276072]=4;b=c[9104228+((c[2276073]&2|4)<<2)>>2]|0;c[2276054]=b;e=c[2276055]|0;do{if(((c[2276038]|0)-1|0)>>>0<2){g=b-4|0;c[2276054]=g;h=c[2276085]&g;g=h&16777215;i=c[2112932]|0;j=c[i+((g>>>10|16384)<<2)>>2]|0;if(j>>>0>9){k=h&1023;a[j+k|0]=e>>>16&255;a[j+(k+1)|0]=e>>>24&255;a[j+(k+2)|0]=e&255;a[j+(k+3)|0]=e>>>8&255;l=i}else{gg[c[i+196808+(j<<2)>>2]&4095](g,e);l=c[2112932]|0}g=(c[2276054]|0)-2|0;c[2276054]=g;j=c[2276085]&g;g=f&65535;i=j&16777215;k=c[l+((i>>>10|16384)<<2)>>2]|0;if(k>>>0>9){h=j&1023;a[k+h|0]=f&255;a[k+(h+1)|0]=(g&65535)>>>8&255;break}else{gg[c[l+196728+(k<<2)>>2]&4095](i,g);break}}else{g=b-2|0;c[2276054]=g;i=c[2276085]&g;g=i&16777215;k=c[2112932]|0;h=c[k+((g>>>10|16384)<<2)>>2]|0;if(h>>>0>9){j=i&1023;a[h+j|0]=16;a[h+(j+1)|0]=0;m=k}else{gg[c[k+196728+(h<<2)>>2]&4095](g,16);m=c[2112932]|0}g=(c[2276054]|0)-4|0;c[2276054]=g;h=c[2276085]&g;g=h&16777215;k=c[m+((g>>>10|16384)<<2)>>2]|0;if(k>>>0>9){j=h&1023;a[k+j|0]=e>>>16&255;a[k+(j+1)|0]=e>>>24&255;a[k+(j+2)|0]=e&255;a[k+(j+3)|0]=e>>>8&255;n=m}else{gg[c[m+196808+(k<<2)>>2]&4095](g,e);n=c[2112932]|0}g=(c[2276054]|0)-2|0;c[2276054]=g;k=c[2276085]&g;g=f&65535;j=k&16777215;h=c[n+((j>>>10|16384)<<2)>>2]|0;if(h>>>0>9){i=k&1023;a[h+i|0]=f&255;a[h+(i+1)|0]=(g&65535)>>>8&255;break}else{gg[c[n+196728+(h<<2)>>2]&4095](j,g);break}}}while(0);n=(c[2276064]|0)+16|0;c[2276056]=n;f=c[2276085]&n;n=f&16777215;e=c[2112932]|0;m=c[e+(n>>>10<<2)>>2]|0;if(m>>>0>9){b=f&1023;o=(d[m+(b+3)|0]|0)<<8|(d[m+(b+2)|0]|0)|((d[m+(b+1)|0]|0)<<8|(d[m+b|0]|0))<<16;c[2276056]=o;p=c[2276099]|0;q=p+4|0;r=a[q]|0;s=r&255;t=c[2276069]|0;u=c[2276098]|0;v=u+t|0;w=a[v]|0;x=w&255;y=c[2276108]|0;z=x-s|0;A=z+y|0;c[2276108]=A;return}else{o=gj[c[e+196768+(m<<2)>>2]&4095](n)|0;c[2276056]=o;p=c[2276099]|0;q=p+4|0;r=a[q]|0;s=r&255;t=c[2276069]|0;u=c[2276098]|0;v=u+t|0;w=a[v]|0;x=w&255;y=c[2276108]|0;z=x-s|0;A=z+y|0;c[2276108]=A;return}}function JU(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((c[2276038]&24|0)==0){JT();return}b=9104156+((c[2276069]&7|8)<<2)|0;e=(c[b>>2]|0)-1|0;c[b>>2]=e;b=c[2276085]&e;e=b&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=a[g+(b&1023^1)|0]|0;i=f}else{b=gj[c[f+196608+(g<<2)>>2]&4095](e)|0;h=b;i=c[2112932]|0}b=9104156+((c[2276069]&7|8)<<2)|0;e=(c[b>>2]|0)-1|0;c[b>>2]=e;b=c[2276085]&e;e=b&16777215;g=c[i+(e>>>10<<2)>>2]|0;if(g>>>0>9){j=a[g+(b&1023^1)|0]|0}else{j=gj[c[i+196608+(g<<2)>>2]&4095](e)|0}e=j&255;j=e|(h&255)<<8;h=c[2276056]|0;g=h&-4;if((g|0)==(c[2276083]|0)){k=h;l=c[2276084]|0}else{c[2276083]=g;i=c[2276085]&g;g=i&16777212;b=c[2112932]|0;f=c[b+((g>>>10|32768)<<2)>>2]|0;if(f>>>0>9){m=i&1020;n=(d[f+(m|3)|0]|0)<<8|(d[f+(m|2)|0]|0)|((d[f+(m|1)|0]|0)<<8|(d[f+m|0]|0))<<16;o=h}else{h=gj[c[b+196768+(f<<2)>>2]&4095](g)|0;n=h;o=c[2276056]|0}c[2276084]=n;k=o;l=n}c[2276056]=k+2;n=l>>>((k<<3&16^16)>>>0);k=(c[2276054]|0)-2|0;c[2276054]=k;l=c[2276085]&k;k=((n+j|0)>>>4&240|n+e&15)&255;e=l&16777215;n=c[2112932]|0;j=c[n+((e>>>10|16384)<<2)>>2]|0;if(j>>>0>9){a[j+(l&1023^1)|0]=k;return}else{gg[c[n+196648+(j<<2)>>2]&4095](e,k);return}}function JV(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if((c[2276038]&24|0)==0){JT();return}b=(c[2276054]|0)-2|0;c[2276054]=b;e=c[2276085]|0;f=e&b;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=a[i+(f&1023^1)|0]|0;k=b;l=e;m=h}else{e=gj[c[h+196608+(i<<2)>>2]&4095](g)|0;j=e;k=c[2276054]|0;l=c[2276085]|0;m=c[2112932]|0}e=k-2|0;c[2276054]=e;k=l&e;e=k&16777215;l=c[m+(e>>>10<<2)>>2]|0;if(l>>>0>9){n=a[l+(k&1023^1)|0]|0}else{n=gj[c[m+196608+(l<<2)>>2]&4095](e)|0}e=n&255;n=e|(j&255)<<8;j=c[2276056]|0;l=j&-4;if((l|0)==(c[2276083]|0)){o=j;p=c[2276084]|0}else{c[2276083]=l;m=c[2276085]&l;l=m&16777212;k=c[2112932]|0;g=c[k+((l>>>10|32768)<<2)>>2]|0;if(g>>>0>9){i=m&1020;q=(d[g+(i|3)|0]|0)<<8|(d[g+(i|2)|0]|0)|((d[g+(i|1)|0]|0)<<8|(d[g+i|0]|0))<<16;r=j}else{j=gj[c[k+196768+(g<<2)>>2]&4095](l)|0;q=j;r=c[2276056]|0}c[2276084]=q;o=r;p=q}c[2276056]=o+2;q=p>>>((o<<3&16^16)>>>0);o=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;p=(c[o>>2]|0)-1|0;c[o>>2]=p;o=c[2276085]&p;p=((q+n|0)>>>4&240|q+e&15)&255;e=o&16777215;q=c[2112932]|0;n=c[q+((e>>>10|16384)<<2)>>2]|0;if(n>>>0>9){a[n+(o&1023^1)|0]=p;return}else{gg[c[q+196648+(n<<2)>>2]&4095](e,p);return}}function JW(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if((c[2276038]&24|0)==0){JT();return}b=(c[2276054]|0)-2|0;c[2276054]=b;e=c[2276085]|0;f=e&b;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=a[i+(f&1023^1)|0]|0;k=b;l=e;m=h}else{e=gj[c[h+196608+(i<<2)>>2]&4095](g)|0;j=e;k=c[2276054]|0;l=c[2276085]|0;m=c[2112932]|0}e=k-2|0;c[2276054]=e;k=l&e;e=k&16777215;l=c[m+(e>>>10<<2)>>2]|0;if(l>>>0>9){n=a[l+(k&1023^1)|0]|0}else{n=gj[c[m+196608+(l<<2)>>2]&4095](e)|0}e=n&255;n=e|(j&255)<<8;j=c[2276056]|0;l=j&-4;if((l|0)==(c[2276083]|0)){o=j;p=c[2276084]|0}else{c[2276083]=l;m=c[2276085]&l;l=m&16777212;k=c[2112932]|0;g=c[k+((l>>>10|32768)<<2)>>2]|0;if(g>>>0>9){i=m&1020;q=(d[g+(i|3)|0]|0)<<8|(d[g+(i|2)|0]|0)|((d[g+(i|1)|0]|0)<<8|(d[g+i|0]|0))<<16;r=j}else{j=gj[c[k+196768+(g<<2)>>2]&4095](l)|0;q=j;r=c[2276056]|0}c[2276084]=q;o=r;p=q}c[2276056]=o+2;q=p>>>((o<<3&16^16)>>>0);o=(c[2276054]|0)-2|0;c[2276054]=o;p=c[2276085]&o;o=((q+n|0)>>>4&240|q+e&15)&255;e=p&16777215;q=c[2112932]|0;n=c[q+((e>>>10|16384)<<2)>>2]|0;if(n>>>0>9){a[n+(p&1023^1)|0]=o;return}else{gg[c[q+196648+(n<<2)>>2]&4095](e,o);return}}function JX(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((c[2276038]&24|0)==0){JT();return}b=9104156+((c[2276069]&7|8)<<2)|0;e=(c[b>>2]|0)-1|0;c[b>>2]=e;b=c[2276085]&e;e=b&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=a[g+(b&1023^1)|0]|0;i=f}else{b=gj[c[f+196608+(g<<2)>>2]&4095](e)|0;h=b;i=c[2112932]|0}b=9104156+((c[2276069]&7|8)<<2)|0;e=(c[b>>2]|0)-1|0;c[b>>2]=e;b=c[2276085]&e;e=b&16777215;g=c[i+(e>>>10<<2)>>2]|0;if(g>>>0>9){j=a[g+(b&1023^1)|0]|0}else{j=gj[c[i+196608+(g<<2)>>2]&4095](e)|0}e=j&255;j=e|(h&255)<<8;h=c[2276056]|0;g=h&-4;if((g|0)==(c[2276083]|0)){k=h;l=c[2276084]|0}else{c[2276083]=g;i=c[2276085]&g;g=i&16777212;b=c[2112932]|0;f=c[b+((g>>>10|32768)<<2)>>2]|0;if(f>>>0>9){m=i&1020;n=(d[f+(m|3)|0]|0)<<8|(d[f+(m|2)|0]|0)|((d[f+(m|1)|0]|0)<<8|(d[f+m|0]|0))<<16;o=h}else{h=gj[c[b+196768+(f<<2)>>2]&4095](g)|0;n=h;o=c[2276056]|0}c[2276084]=n;k=o;l=n}c[2276056]=k+2;n=l>>>((k<<3&16^16)>>>0);k=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;l=(c[k>>2]|0)-1|0;c[k>>2]=l;k=c[2276085]&l;l=((n+j|0)>>>4&240|n+e&15)&255;e=k&16777215;n=c[2112932]|0;j=c[n+((e>>>10|16384)<<2)>>2]|0;if(j>>>0>9){a[j+(k&1023^1)|0]=l;return}else{gg[c[n+196648+(j<<2)>>2]&4095](e,l);return}}function JY(){var b=0,d=0,e=0,f=0,g=0,h=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;d=(c[2276054]|0)-4|0;c[2276054]=d;e=c[2276085]&d;d=e&16777215;f=c[2112932]|0;g=c[f+((d>>>10|16384)<<2)>>2]|0;if(g>>>0>9){h=e&1023;a[g+h|0]=b>>>16&255;a[g+(h+1)|0]=b>>>24&255;a[g+(h+2)|0]=b&255;a[g+(h+3)|0]=b>>>8&255;return}else{gg[c[f+196808+(g<<2)>>2]&4095](d,b);return}}function JZ(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=(h>>>((g<<3&16^16)>>>0)<<16>>16)+b|0;b=(c[2276054]|0)-4|0;c[2276054]=b;g=c[2276085]&b;b=g&16777215;h=c[2112932]|0;n=c[h+((b>>>10|16384)<<2)>>2]|0;if(n>>>0>9){e=g&1023;a[n+e|0]=m>>>16&255;a[n+(e+1)|0]=m>>>24&255;a[n+(e+2)|0]=m&255;a[n+(e+3)|0]=m>>>8&255;return}else{gg[c[h+196808+(n<<2)>>2]&4095](b,m);return}}function J_(){var b=0,d=0,e=0,f=0,g=0,h=0;b=Hd(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;d=(c[2276054]|0)-4|0;c[2276054]=d;e=c[2276085]&d;d=e&16777215;f=c[2112932]|0;g=c[f+((d>>>10|16384)<<2)>>2]|0;if(g>>>0>9){h=e&1023;a[g+h|0]=b>>>16&255;a[g+(h+1)|0]=b>>>24&255;a[g+(h+2)|0]=b&255;a[g+(h+3)|0]=b>>>8&255;return}else{gg[c[f+196808+(g<<2)>>2]&4095](d,b);return}}function J$(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)<<16>>16;f=(c[2276054]|0)-4|0;c[2276054]=f;g=c[2276085]&f;f=g&16777215;m=c[2112932]|0;b=c[m+((f>>>10|16384)<<2)>>2]|0;if(b>>>0>9){e=g&1023;a[b+e|0]=l>>>16&255;a[b+(e+1)|0]=l>>>24&255;a[b+(e+2)|0]=l&255;a[b+(e+3)|0]=l>>>8&255;return}else{gg[c[m+196808+(b<<2)>>2]&4095](f,l);return}}function J0(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=(c[2276054]|0)-4|0;c[2276054]=r;t=c[2276085]&r;r=t&16777215;h=c[2112932]|0;s=c[h+((r>>>10|16384)<<2)>>2]|0;if(s>>>0>9){n=t&1023;a[s+n|0]=q>>>16&255;a[s+(n+1)|0]=q>>>24&255;a[s+(n+2)|0]=q&255;a[s+(n+3)|0]=q>>>8&255;return}else{gg[c[h+196808+(s<<2)>>2]&4095](r,q);return}}function J1(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{k=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=k;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=(g>>>((f<<3&16^16)>>>0)<<16>>16)+b|0;b=(c[2276054]|0)-4|0;c[2276054]=b;f=c[2276085]&b;b=f&16777215;g=c[2112932]|0;m=c[g+((b>>>10|16384)<<2)>>2]|0;if(m>>>0>9){k=f&1023;a[m+k|0]=l>>>16&255;a[m+(k+1)|0]=l>>>24&255;a[m+(k+2)|0]=l&255;a[m+(k+3)|0]=l>>>8&255;return}else{gg[c[g+196808+(m<<2)>>2]&4095](b,l);return}}function J2(){var b=0,d=0,e=0,f=0,g=0,h=0;b=Hd(c[2276056]|0)|0;d=(c[2276054]|0)-4|0;c[2276054]=d;e=c[2276085]&d;d=e&16777215;f=c[2112932]|0;g=c[f+((d>>>10|16384)<<2)>>2]|0;if(g>>>0>9){h=e&1023;a[g+h|0]=b>>>16&255;a[g+(h+1)|0]=b>>>24&255;a[g+(h+2)|0]=b&255;a[g+(h+3)|0]=b>>>8&255;return}else{gg[c[f+196808+(g<<2)>>2]&4095](d,b);return}}function J3(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;if((c[2276072]|0)!=0){b=c[(c[2112932]|0)+196848>>2]|0;if((b|0)!=0){gD[b&8191]()|0}e=(c[2276108]|0)-(c[2276097]|0)|0;c[2276108]=e;return}b=c[2276073]|0;f=c[2276071]|c[2276070]|b<<11|c[2276079]|(c[2276074]|0)>>>4&16|(c[2276075]|0)>>>4&8|((c[2276076]|0)==0)<<2|(c[2276077]|0)>>>6&2|(c[2276078]|0)>>>8&1;c[2276071]=0;c[2276070]=0;c[2276057]=c[2276054];c[2276072]=4;g=c[9104228+((b&2|4)<<2)>>2]|0;c[2276054]=g;b=c[2276055]|0;do{if(((c[2276038]|0)-1|0)>>>0<2){h=g-4|0;c[2276054]=h;i=c[2276085]&h;h=i&16777215;j=c[2112932]|0;k=c[j+((h>>>10|16384)<<2)>>2]|0;if(k>>>0>9){l=i&1023;a[k+l|0]=b>>>16&255;a[k+(l+1)|0]=b>>>24&255;a[k+(l+2)|0]=b&255;a[k+(l+3)|0]=b>>>8&255;m=j}else{gg[c[j+196808+(k<<2)>>2]&4095](h,b);m=c[2112932]|0}h=(c[2276054]|0)-2|0;c[2276054]=h;k=c[2276085]&h;h=f&65535;j=k&16777215;l=c[m+((j>>>10|16384)<<2)>>2]|0;if(l>>>0>9){i=k&1023;a[l+i|0]=f&255;a[l+(i+1)|0]=(h&65535)>>>8&255;break}else{gg[c[m+196728+(l<<2)>>2]&4095](j,h);break}}else{h=g-2|0;c[2276054]=h;j=c[2276085]&h;h=j&16777215;l=c[2112932]|0;i=c[l+((h>>>10|16384)<<2)>>2]|0;if(i>>>0>9){k=j&1023;a[i+k|0]=32;a[i+(k+1)|0]=0;n=l}else{gg[c[l+196728+(i<<2)>>2]&4095](h,32);n=c[2112932]|0}h=(c[2276054]|0)-4|0;c[2276054]=h;i=c[2276085]&h;h=i&16777215;l=c[n+((h>>>10|16384)<<2)>>2]|0;if(l>>>0>9){k=i&1023;a[l+k|0]=b>>>16&255;a[l+(k+1)|0]=b>>>24&255;a[l+(k+2)|0]=b&255;a[l+(k+3)|0]=b>>>8&255;o=n}else{gg[c[n+196808+(l<<2)>>2]&4095](h,b);o=c[2112932]|0}h=(c[2276054]|0)-2|0;c[2276054]=h;l=c[2276085]&h;h=f&65535;k=l&16777215;i=c[o+((k>>>10|16384)<<2)>>2]|0;if(i>>>0>9){j=l&1023;a[i+j|0]=f&255;a[i+(j+1)|0]=(h&65535)>>>8&255;break}else{gg[c[o+196728+(i<<2)>>2]&4095](k,h);break}}}while(0);o=(c[2276064]|0)+32|0;c[2276056]=o;f=c[2276085]&o;o=f&16777215;b=c[2112932]|0;n=c[b+(o>>>10<<2)>>2]|0;if(n>>>0>9){g=f&1023;p=(d[n+(g+3)|0]|0)<<8|(d[n+(g+2)|0]|0)|((d[n+(g+1)|0]|0)<<8|(d[n+g|0]|0))<<16}else{p=gj[c[b+196768+(n<<2)>>2]&4095](o)|0}c[2276056]=p;e=(d[(c[2276098]|0)+(c[2276069]|0)|0]|0)-(d[(c[2276099]|0)+8|0]|0)+(c[2276108]|0)|0;c[2276108]=e;return}function J4(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[2276069]|0;b=9104156+((a&7)<<2)|0;d=a>>>9;a=d+7&7;e=d&7;d=c[b>>2]|0;f=d&255;g=(f<<8-e|f>>>(e>>>0))&255;c[2276108]=(c[2276108]|0)-(a+1<<c[2276096]);c[b>>2]=g|d&-256;c[2276075]=g;c[2276076]=g;c[2276078]=f<<8-a;c[2276077]=0;return}function J5(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[2276069]|0;b=9104156+((a&7)<<2)|0;d=(a>>>9)+7&7;a=d+1|0;e=c[b>>2]|0;f=e&65535;g=(f>>>(a>>>0)|f<<(d^15))&65535;c[2276108]=(c[2276108]|0)-(a<<c[2276096]);c[b>>2]=g|e&-65536;c[2276075]=g>>>8;c[2276076]=g;c[2276078]=f<<8-d;c[2276077]=0;return}function J6(){var a=0,b=0,d=0,e=0,f=0;a=c[2276069]|0;b=9104156+((a&7)<<2)|0;d=(a>>>9)+7&7;a=d+1|0;e=c[b>>2]|0;f=e>>>(a>>>0)|e<<(d^31);c[2276108]=(c[2276108]|0)-(a<<c[2276096]);c[b>>2]=f;c[2276075]=f>>>24;c[2276076]=f;c[2276078]=e<<8-d;c[2276077]=0;return}function J7(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a=c[2276069]|0;b=9104156+((a&7)<<2)|0;d=c[9104156+((a>>>9&7)<<2)>>2]|0;a=d&63;e=d&7;f=c[b>>2]|0;g=f&255;h=(g>>>(e>>>0)|g<<8-e)&255;if((a|0)==0){i=g;j=0}else{c[2276108]=(c[2276108]|0)-(a<<c[2276096]);c[b>>2]=h|f&-256;i=h;j=g<<8-(d+7&7)}c[2276078]=j;c[2276075]=i;c[2276076]=i;c[2276077]=0;return}function J8(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a=c[2276069]|0;b=9104156+((a&7)<<2)|0;d=c[9104156+((a>>>9&7)<<2)>>2]|0;a=d&63;e=d&15;f=c[b>>2]|0;g=f&65535;h=(g>>>(e>>>0)|g<<16-e)&65535;if((a|0)==0){i=g;j=0}else{c[2276108]=(c[2276108]|0)-(a<<c[2276096]);c[b>>2]=h|f&-65536;i=h;j=g>>>((d+15&15)>>>0)<<8}c[2276078]=j;c[2276075]=i>>>8;c[2276076]=i;c[2276077]=0;return}function J9(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a=c[2276069]|0;b=9104156+((a&7)<<2)|0;d=c[9104156+((a>>>9&7)<<2)>>2]|0;a=d&63;e=d&31;f=c[b>>2]|0;g=32-e|0;h=(g>>>0<32?f<<g:0)|f>>>(e>>>0);if((a|0)==0){i=f;j=0}else{c[2276108]=(c[2276108]|0)-(a<<c[2276096]);c[b>>2]=h;i=h;j=f>>>((d+31&31)>>>0)<<8}c[2276078]=j;c[2276075]=i>>>24;c[2276076]=i;c[2276077]=0;return}function Ka(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276085]|0;f=e&b;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=f&1023;k=(d[i+(j+1)|0]|0)<<8|(d[i+j|0]|0);l=e;m=h}else{e=gj[c[h+196688+(i<<2)>>2]&4095](g)|0;k=e;l=c[2276085]|0;m=c[2112932]|0}e=k&65535;k=e>>>1;g=e<<15&32768|k;i=l&b;b=g&65535;l=i&16777215;h=c[m+((l>>>10|16384)<<2)>>2]|0;if(h>>>0>9){j=i&1023;a[h+j|0]=k&255;a[h+(j+1)|0]=(b&65535)>>>8&255;n=g>>>8;c[2276075]=n;c[2276076]=g;o=e<<8;c[2276078]=o;c[2276077]=0;return}else{gg[c[m+196728+(h<<2)>>2]&4095](l,b);n=g>>>8;c[2276075]=n;c[2276076]=g;o=e<<8;c[2276078]=o;c[2276077]=0;return}}function Kb(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=c[b>>2]|0;c[b>>2]=e+2;b=c[2276085]|0;f=b&e;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=f&1023;k=(d[i+(j+1)|0]|0)<<8|(d[i+j|0]|0);l=b;m=h}else{b=gj[c[h+196688+(i<<2)>>2]&4095](g)|0;k=b;l=c[2276085]|0;m=c[2112932]|0}b=k&65535;k=b>>>1;g=b<<15&32768|k;i=l&e;e=g&65535;l=i&16777215;h=c[m+((l>>>10|16384)<<2)>>2]|0;if(h>>>0>9){j=i&1023;a[h+j|0]=k&255;a[h+(j+1)|0]=(e&65535)>>>8&255;n=g>>>8;c[2276075]=n;c[2276076]=g;o=b<<8;c[2276078]=o;c[2276077]=0;return}else{gg[c[m+196728+(h<<2)>>2]&4095](l,e);n=g>>>8;c[2276075]=n;c[2276076]=g;o=b<<8;c[2276078]=o;c[2276077]=0;return}}function Kc(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=(c[b>>2]|0)-2|0;c[b>>2]=e;b=c[2276085]|0;f=b&e;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=f&1023;k=(d[i+(j+1)|0]|0)<<8|(d[i+j|0]|0);l=b;m=h}else{b=gj[c[h+196688+(i<<2)>>2]&4095](g)|0;k=b;l=c[2276085]|0;m=c[2112932]|0}b=k&65535;k=b>>>1;g=b<<15&32768|k;i=l&e;e=g&65535;l=i&16777215;h=c[m+((l>>>10|16384)<<2)>>2]|0;if(h>>>0>9){j=i&1023;a[h+j|0]=k&255;a[h+(j+1)|0]=(e&65535)>>>8&255;n=g>>>8;c[2276075]=n;c[2276076]=g;o=b<<8;c[2276078]=o;c[2276077]=0;return}else{gg[c[m+196728+(h<<2)>>2]&4095](l,e);n=g>>>8;c[2276075]=n;c[2276076]=g;o=b<<8;c[2276078]=o;c[2276077]=0;return}}function Kd(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=(h>>>((g<<3&16^16)>>>0)<<16>>16)+b|0;b=c[2276085]|0;g=m&b;h=g&16777215;n=c[2112932]|0;e=c[n+(h>>>10<<2)>>2]|0;if(e>>>0>9){f=g&1023;o=(d[e+(f+1)|0]|0)<<8|(d[e+f|0]|0);p=b;q=n}else{b=gj[c[n+196688+(e<<2)>>2]&4095](h)|0;o=b;p=c[2276085]|0;q=c[2112932]|0}b=o&65535;o=b>>>1;h=b<<15&32768|o;e=p&m;m=h&65535;p=e&16777215;n=c[q+((p>>>10|16384)<<2)>>2]|0;if(n>>>0>9){f=e&1023;a[n+f|0]=o&255;a[n+(f+1)|0]=(m&65535)>>>8&255;r=h>>>8;c[2276075]=r;c[2276076]=h;s=b<<8;c[2276078]=s;c[2276077]=0;return}else{gg[c[q+196728+(n<<2)>>2]&4095](p,m);r=h>>>8;c[2276075]=r;c[2276076]=h;s=b<<8;c[2276078]=s;c[2276077]=0;return}}function Ke(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=Hd(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;e=c[2276085]|0;f=e&b;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=f&1023;k=(d[i+(j+1)|0]|0)<<8|(d[i+j|0]|0);l=e;m=h}else{e=gj[c[h+196688+(i<<2)>>2]&4095](g)|0;k=e;l=c[2276085]|0;m=c[2112932]|0}e=k&65535;k=e>>>1;g=e<<15&32768|k;i=l&b;b=g&65535;l=i&16777215;h=c[m+((l>>>10|16384)<<2)>>2]|0;if(h>>>0>9){j=i&1023;a[h+j|0]=k&255;a[h+(j+1)|0]=(b&65535)>>>8&255;n=g>>>8;c[2276075]=n;c[2276076]=g;o=e<<8;c[2276078]=o;c[2276077]=0;return}else{gg[c[m+196728+(h<<2)>>2]&4095](l,b);n=g>>>8;c[2276075]=n;c[2276076]=g;o=e<<8;c[2276078]=o;c[2276077]=0;return}}function Kf(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)<<16>>16;f=c[2276085]|0;g=l&f;m=g&16777215;b=c[2112932]|0;e=c[b+(m>>>10<<2)>>2]|0;if(e>>>0>9){j=g&1023;n=(d[e+(j+1)|0]|0)<<8|(d[e+j|0]|0);o=f;p=b}else{f=gj[c[b+196688+(e<<2)>>2]&4095](m)|0;n=f;o=c[2276085]|0;p=c[2112932]|0}f=n&65535;n=f>>>1;m=f<<15&32768|n;e=o&l;l=m&65535;o=e&16777215;b=c[p+((o>>>10|16384)<<2)>>2]|0;if(b>>>0>9){j=e&1023;a[b+j|0]=n&255;a[b+(j+1)|0]=(l&65535)>>>8&255;q=m>>>8;c[2276075]=q;c[2276076]=m;r=f<<8;c[2276078]=r;c[2276077]=0;return}else{gg[c[p+196728+(b<<2)>>2]&4095](o,l);q=m>>>8;c[2276075]=q;c[2276076]=m;r=f<<8;c[2276078]=r;c[2276077]=0;return}}function Kg(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[2276085]|0;t=r&q;h=t&16777215;s=c[2112932]|0;n=c[s+(h>>>10<<2)>>2]|0;if(n>>>0>9){f=t&1023;u=(d[n+(f+1)|0]|0)<<8|(d[n+f|0]|0);v=r;w=s}else{r=gj[c[s+196688+(n<<2)>>2]&4095](h)|0;u=r;v=c[2276085]|0;w=c[2112932]|0}r=u&65535;u=r>>>1;h=r<<15&32768|u;n=v&q;q=h&65535;v=n&16777215;s=c[w+((v>>>10|16384)<<2)>>2]|0;if(s>>>0>9){f=n&1023;a[s+f|0]=u&255;a[s+(f+1)|0]=(q&65535)>>>8&255;x=h>>>8;c[2276075]=x;c[2276076]=h;y=r<<8;c[2276078]=y;c[2276077]=0;return}else{gg[c[w+196728+(s<<2)>>2]&4095](v,q);x=h>>>8;c[2276075]=x;c[2276076]=h;y=r<<8;c[2276078]=y;c[2276077]=0;return}}function Kh(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[2276069]|0;b=9104156+((a&7)<<2)|0;d=a>>>9;a=(d+7&7)+1|0;e=d&7;d=c[b>>2]|0;f=d&255;g=(f>>>((8-e|0)>>>0)|f<<e)&255;c[2276108]=(c[2276108]|0)-(a<<c[2276096]);c[b>>2]=g|d&-256;c[2276075]=g;c[2276076]=g;c[2276078]=f<<a;c[2276077]=0;return}function Ki(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[2276069]|0;b=9104156+((a&7)<<2)|0;d=(a>>>9)+7&7;a=d+1|0;e=c[b>>2]|0;f=e&65535;g=(f<<a|f>>>((d^15)>>>0))&65535;c[2276108]=(c[2276108]|0)-(a<<c[2276096]);c[b>>2]=g|e&-65536;c[2276075]=g>>>8;c[2276076]=g;c[2276078]=f>>>((d^7)>>>0);c[2276077]=0;return}function Kj(){var a=0,b=0,d=0,e=0,f=0;a=c[2276069]|0;b=9104156+((a&7)<<2)|0;d=(a>>>9)+7&7;a=d+1|0;e=c[b>>2]|0;f=e<<a|e>>>((d^31)>>>0);c[2276108]=(c[2276108]|0)-(a<<c[2276096]);c[b>>2]=f;c[2276075]=f>>>24;c[2276076]=f;c[2276078]=e>>>((23-d|0)>>>0);c[2276077]=0;return}function Kk(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0;a=c[2276069]|0;b=9104156+((a&7)<<2)|0;d=c[9104156+((a>>>9&7)<<2)>>2]|0;a=d&63;e=d&7;d=c[b>>2]|0;f=d&255;g=f<<e;h=(g|f>>>((8-e|0)>>>0))&255;if((a|0)==0){c[2276078]=0;c[2276075]=f;c[2276076]=f;c[2276077]=0;return}c[2276108]=(c[2276108]|0)-(a<<c[2276096]);if((e|0)==0){c[2276078]=d<<8&256;c[2276075]=f;c[2276076]=f;c[2276077]=0;return}else{c[b>>2]=h|d&-256;c[2276078]=g;c[2276075]=h;c[2276076]=h;c[2276077]=0;return}}function Kl(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0;a=c[2276069]|0;b=9104156+((a&7)<<2)|0;d=c[9104156+((a>>>9&7)<<2)>>2]|0;a=d&63;e=d&15;d=c[b>>2]|0;f=d&65535;g=f<<e;h=(g|f>>>((16-e|0)>>>0))&65535;if((a|0)==0){c[2276078]=0;c[2276075]=f>>>8;c[2276076]=f;c[2276077]=0;return}c[2276108]=(c[2276108]|0)-(a<<c[2276096]);if((e|0)==0){c[2276078]=d<<8&256;c[2276075]=f>>>8;c[2276076]=f;c[2276077]=0;return}else{c[b>>2]=h|d&-65536;c[2276078]=g>>>8;c[2276075]=h>>>8;c[2276076]=h;c[2276077]=0;return}}function Km(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a=c[2276069]|0;b=9104156+((a&7)<<2)|0;d=c[9104156+((a>>>9&7)<<2)>>2]|0;a=d&63;e=d&31;d=c[b>>2]|0;f=32-e|0;g=d>>>(f>>>0);h=(f>>>0<32?g:0)|d<<e;if((a|0)==0){i=d;j=0}else{c[2276108]=(c[2276108]|0)-(a<<c[2276096]);c[b>>2]=h;i=h;j=g<<8}c[2276078]=j;c[2276075]=i>>>24;c[2276076]=i;c[2276077]=0;return}function Kn(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276085]|0;f=e&b;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=f&1023;k=(d[i+(j+1)|0]|0)<<8|(d[i+j|0]|0);l=e;m=h}else{e=gj[c[h+196688+(i<<2)>>2]&4095](g)|0;k=e;l=c[2276085]|0;m=c[2112932]|0}e=k&65535;k=e<<1&65534;g=k|e>>>15;i=l&b;b=g&65535;l=i&16777215;h=c[m+((l>>>10|16384)<<2)>>2]|0;if(h>>>0>9){j=i&1023;a[h+j|0]=g&255;a[h+(j+1)|0]=(b&65535)>>>8&255;n=k>>>8;c[2276075]=n;c[2276076]=g;o=e>>>7;c[2276078]=o;c[2276077]=0;return}else{gg[c[m+196728+(h<<2)>>2]&4095](l,b);n=k>>>8;c[2276075]=n;c[2276076]=g;o=e>>>7;c[2276078]=o;c[2276077]=0;return}}function Ko(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=c[b>>2]|0;c[b>>2]=e+2;b=c[2276085]|0;f=b&e;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=f&1023;k=(d[i+(j+1)|0]|0)<<8|(d[i+j|0]|0);l=b;m=h}else{b=gj[c[h+196688+(i<<2)>>2]&4095](g)|0;k=b;l=c[2276085]|0;m=c[2112932]|0}b=k&65535;k=b<<1&65534;g=k|b>>>15;i=l&e;e=g&65535;l=i&16777215;h=c[m+((l>>>10|16384)<<2)>>2]|0;if(h>>>0>9){j=i&1023;a[h+j|0]=g&255;a[h+(j+1)|0]=(e&65535)>>>8&255;n=k>>>8;c[2276075]=n;c[2276076]=g;o=b>>>7;c[2276078]=o;c[2276077]=0;return}else{gg[c[m+196728+(h<<2)>>2]&4095](l,e);n=k>>>8;c[2276075]=n;c[2276076]=g;o=b>>>7;c[2276078]=o;c[2276077]=0;return}}function Kp(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=(c[b>>2]|0)-2|0;c[b>>2]=e;b=c[2276085]|0;f=b&e;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=f&1023;k=(d[i+(j+1)|0]|0)<<8|(d[i+j|0]|0);l=b;m=h}else{b=gj[c[h+196688+(i<<2)>>2]&4095](g)|0;k=b;l=c[2276085]|0;m=c[2112932]|0}b=k&65535;k=b<<1&65534;g=k|b>>>15;i=l&e;e=g&65535;l=i&16777215;h=c[m+((l>>>10|16384)<<2)>>2]|0;if(h>>>0>9){j=i&1023;a[h+j|0]=g&255;a[h+(j+1)|0]=(e&65535)>>>8&255;n=k>>>8;c[2276075]=n;c[2276076]=g;o=b>>>7;c[2276078]=o;c[2276077]=0;return}else{gg[c[m+196728+(h<<2)>>2]&4095](l,e);n=k>>>8;c[2276075]=n;c[2276076]=g;o=b>>>7;c[2276078]=o;c[2276077]=0;return}}function Kq(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=(h>>>((g<<3&16^16)>>>0)<<16>>16)+b|0;b=c[2276085]|0;g=m&b;h=g&16777215;n=c[2112932]|0;e=c[n+(h>>>10<<2)>>2]|0;if(e>>>0>9){f=g&1023;o=(d[e+(f+1)|0]|0)<<8|(d[e+f|0]|0);p=b;q=n}else{b=gj[c[n+196688+(e<<2)>>2]&4095](h)|0;o=b;p=c[2276085]|0;q=c[2112932]|0}b=o&65535;o=b<<1&65534;h=o|b>>>15;e=p&m;m=h&65535;p=e&16777215;n=c[q+((p>>>10|16384)<<2)>>2]|0;if(n>>>0>9){f=e&1023;a[n+f|0]=h&255;a[n+(f+1)|0]=(m&65535)>>>8&255;r=o>>>8;c[2276075]=r;c[2276076]=h;s=b>>>7;c[2276078]=s;c[2276077]=0;return}else{gg[c[q+196728+(n<<2)>>2]&4095](p,m);r=o>>>8;c[2276075]=r;c[2276076]=h;s=b>>>7;c[2276078]=s;c[2276077]=0;return}}function Kr(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=Hd(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;e=c[2276085]|0;f=e&b;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=f&1023;k=(d[i+(j+1)|0]|0)<<8|(d[i+j|0]|0);l=e;m=h}else{e=gj[c[h+196688+(i<<2)>>2]&4095](g)|0;k=e;l=c[2276085]|0;m=c[2112932]|0}e=k&65535;k=e<<1&65534;g=k|e>>>15;i=l&b;b=g&65535;l=i&16777215;h=c[m+((l>>>10|16384)<<2)>>2]|0;if(h>>>0>9){j=i&1023;a[h+j|0]=g&255;a[h+(j+1)|0]=(b&65535)>>>8&255;n=k>>>8;c[2276075]=n;c[2276076]=g;o=e>>>7;c[2276078]=o;c[2276077]=0;return}else{gg[c[m+196728+(h<<2)>>2]&4095](l,b);n=k>>>8;c[2276075]=n;c[2276076]=g;o=e>>>7;c[2276078]=o;c[2276077]=0;return}}function Ks(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)<<16>>16;f=c[2276085]|0;g=l&f;m=g&16777215;b=c[2112932]|0;e=c[b+(m>>>10<<2)>>2]|0;if(e>>>0>9){j=g&1023;n=(d[e+(j+1)|0]|0)<<8|(d[e+j|0]|0);o=f;p=b}else{f=gj[c[b+196688+(e<<2)>>2]&4095](m)|0;n=f;o=c[2276085]|0;p=c[2112932]|0}f=n&65535;n=f<<1&65534;m=n|f>>>15;e=o&l;l=m&65535;o=e&16777215;b=c[p+((o>>>10|16384)<<2)>>2]|0;if(b>>>0>9){j=e&1023;a[b+j|0]=m&255;a[b+(j+1)|0]=(l&65535)>>>8&255;q=n>>>8;c[2276075]=q;c[2276076]=m;r=f>>>7;c[2276078]=r;c[2276077]=0;return}else{gg[c[p+196728+(b<<2)>>2]&4095](o,l);q=n>>>8;c[2276075]=q;c[2276076]=m;r=f>>>7;c[2276078]=r;c[2276077]=0;return}}function Kt(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[2276085]|0;t=r&q;h=t&16777215;s=c[2112932]|0;n=c[s+(h>>>10<<2)>>2]|0;if(n>>>0>9){f=t&1023;u=(d[n+(f+1)|0]|0)<<8|(d[n+f|0]|0);v=r;w=s}else{r=gj[c[s+196688+(n<<2)>>2]&4095](h)|0;u=r;v=c[2276085]|0;w=c[2112932]|0}r=u&65535;u=r<<1&65534;h=u|r>>>15;n=v&q;q=h&65535;v=n&16777215;s=c[w+((v>>>10|16384)<<2)>>2]|0;if(s>>>0>9){f=n&1023;a[s+f|0]=h&255;a[s+(f+1)|0]=(q&65535)>>>8&255;x=u>>>8;c[2276075]=x;c[2276076]=h;y=r>>>7;c[2276078]=y;c[2276077]=0;return}else{gg[c[w+196728+(s<<2)>>2]&4095](v,q);x=u>>>8;c[2276075]=x;c[2276076]=h;y=r>>>7;c[2276078]=y;c[2276077]=0;return}}function Ku(){var a=0,b=0,d=0,e=0,f=0;a=c[2276069]|0;b=9104156+((a&7)<<2)|0;d=(a>>>9)+7&7;a=d+1|0;e=c[2276074]&256|c[b>>2]&255;f=e>>>(a>>>0)|e<<8-d;c[2276108]=(c[2276108]|0)-(a<<c[2276096]);c[2276074]=f;c[2276078]=f;a=f&255;c[b>>2]=a|c[b>>2]&-256;c[2276075]=a;c[2276076]=a;c[2276077]=0;return}function Kv(){var a=0,b=0,d=0,e=0,f=0;a=c[2276069]|0;b=9104156+((a&7)<<2)|0;d=(a>>>9)+7&7;a=d+1|0;e=(c[2276074]|0)>>>8<<16&65536|c[b>>2]&65535;f=e>>>(a>>>0)|e<<16-d;c[2276108]=(c[2276108]|0)-(a<<c[2276096]);a=f>>>8;c[2276074]=a;c[2276078]=a;a=f&65535;c[b>>2]=a|c[b>>2]&-65536;c[2276075]=a>>>8;c[2276076]=a;c[2276077]=0;return}function Kw(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0;a=c[2276069]|0;b=9104156+((a&7)<<2)|0;d=(a>>>9)+7&7;a=d+1|0;e=c[b>>2]|0;f=32-d|0;g=d^31;h=((f>>>0<32?e<<f:0)|e>>>(a>>>0))&~(1<<g)|((c[2276074]|0)>>>8&1)<<g;c[2276108]=(c[2276108]|0)-(a<<c[2276096]);c[b>>2]=h;b=((1<<d&e|0)!=0)<<8;c[2276074]=b;c[2276078]=b;c[2276075]=h>>>24;c[2276076]=h;c[2276077]=0;return}function Kx(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[2276069]|0;b=9104156+((a&7)<<2)|0;d=c[9104156+((a>>>9&7)<<2)>>2]&63;if((d|0)==0){c[2276078]=c[2276074];c[2276075]=c[b>>2];e=c[b>>2]&255;c[2276076]=e;c[2276077]=0;return}else{a=(d>>>0)%9|0;f=c[2276074]&256|c[b>>2]&255;g=f>>>(a>>>0)|f<<9-a;c[2276108]=(c[2276108]|0)-(d<<c[2276096]);c[2276074]=g;c[2276078]=g;d=g&255;c[b>>2]=d|c[b>>2]&-256;c[2276075]=d;e=d;c[2276076]=e;c[2276077]=0;return}}function Ky(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[2276069]|0;b=9104156+((a&7)<<2)|0;d=c[9104156+((a>>>9&7)<<2)>>2]&63;if((d|0)==0){c[2276078]=c[2276074];c[2276075]=(c[b>>2]|0)>>>8;e=c[b>>2]&65535;c[2276076]=e;c[2276077]=0;return}else{a=(d>>>0)%17|0;f=(c[2276074]|0)>>>8<<16&65536|c[b>>2]&65535;g=f>>>(a>>>0)|f<<17-a;c[2276108]=(c[2276108]|0)-(d<<c[2276096]);d=g>>>8;c[2276074]=d;c[2276078]=d;d=g&65535;c[b>>2]=d|c[b>>2]&-65536;c[2276075]=d>>>8;e=d;c[2276076]=e;c[2276077]=0;return}}function Kz(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[2276069]|0;b=9104156+((a&7)<<2)|0;d=c[9104156+((a>>>9&7)<<2)>>2]&63;a=(d>>>0)%33|0;e=c[b>>2]|0;f=33-a|0;g=32-a|0;h=c[2276074]|0;i=((a>>>0<32?e>>>(a>>>0):0)|(f>>>0<32?e<<f:0))&~(1<<g)|(h>>>8&1)<<g;if((d|0)!=0){c[2276108]=(c[2276108]|0)-(d<<c[2276096])}if((a|0)==0){j=e;k=h;c[2276078]=k;l=j>>>24;c[2276075]=l;c[2276076]=j;c[2276077]=0;return}c[b>>2]=i;b=((1<<a-1&e|0)!=0)<<8;c[2276074]=b;j=i;k=b;c[2276078]=k;l=j>>>24;c[2276075]=l;c[2276076]=j;c[2276077]=0;return}function KA(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276085]|0;f=e&b;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=f&1023;k=(d[i+(j+1)|0]|0)<<8|(d[i+j|0]|0);l=e;m=h}else{e=gj[c[h+196688+(i<<2)>>2]&4095](g)|0;k=e;l=c[2276085]|0;m=c[2112932]|0}e=k&65535;k=(c[2276074]|0)>>>8<<16&65536|e;g=k>>>1;i=(g|e<<16)>>>8;c[2276074]=i;c[2276078]=i;i=l&b;b=i&16777215;l=c[m+((b>>>10|16384)<<2)>>2]|0;if(l>>>0>9){e=i&1023;a[l+e|0]=g&255;i=k>>>9;a[l+(e+1)|0]=i&255;n=i;c[2276075]=n;c[2276076]=g;c[2276077]=0;return}else{gg[c[m+196728+(l<<2)>>2]&4095](b,g&65535);n=k>>>9;c[2276075]=n;c[2276076]=g;c[2276077]=0;return}}function KB(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=c[b>>2]|0;c[b>>2]=e+2;b=c[2276085]|0;f=b&e;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=f&1023;k=(d[i+(j+1)|0]|0)<<8|(d[i+j|0]|0);l=b;m=h}else{b=gj[c[h+196688+(i<<2)>>2]&4095](g)|0;k=b;l=c[2276085]|0;m=c[2112932]|0}b=k&65535;k=(c[2276074]|0)>>>8<<16&65536|b;g=k>>>1;i=(g|b<<16)>>>8;c[2276074]=i;c[2276078]=i;i=l&e;e=i&16777215;l=c[m+((e>>>10|16384)<<2)>>2]|0;if(l>>>0>9){b=i&1023;a[l+b|0]=g&255;i=k>>>9;a[l+(b+1)|0]=i&255;n=i;c[2276075]=n;c[2276076]=g;c[2276077]=0;return}else{gg[c[m+196728+(l<<2)>>2]&4095](e,g&65535);n=k>>>9;c[2276075]=n;c[2276076]=g;c[2276077]=0;return}}function KC(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=(c[b>>2]|0)-2|0;c[b>>2]=e;b=c[2276085]|0;f=b&e;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=f&1023;k=(d[i+(j+1)|0]|0)<<8|(d[i+j|0]|0);l=b;m=h}else{b=gj[c[h+196688+(i<<2)>>2]&4095](g)|0;k=b;l=c[2276085]|0;m=c[2112932]|0}b=k&65535;k=(c[2276074]|0)>>>8<<16&65536|b;g=k>>>1;i=(g|b<<16)>>>8;c[2276074]=i;c[2276078]=i;i=l&e;e=i&16777215;l=c[m+((e>>>10|16384)<<2)>>2]|0;if(l>>>0>9){b=i&1023;a[l+b|0]=g&255;i=k>>>9;a[l+(b+1)|0]=i&255;n=i;c[2276075]=n;c[2276076]=g;c[2276077]=0;return}else{gg[c[m+196728+(l<<2)>>2]&4095](e,g&65535);n=k>>>9;c[2276075]=n;c[2276076]=g;c[2276077]=0;return}}function KD(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=(h>>>((g<<3&16^16)>>>0)<<16>>16)+b|0;b=c[2276085]|0;g=m&b;h=g&16777215;n=c[2112932]|0;e=c[n+(h>>>10<<2)>>2]|0;if(e>>>0>9){f=g&1023;o=(d[e+(f+1)|0]|0)<<8|(d[e+f|0]|0);p=b;q=n}else{b=gj[c[n+196688+(e<<2)>>2]&4095](h)|0;o=b;p=c[2276085]|0;q=c[2112932]|0}b=o&65535;o=(c[2276074]|0)>>>8<<16&65536|b;h=o>>>1;e=(h|b<<16)>>>8;c[2276074]=e;c[2276078]=e;e=p&m;m=e&16777215;p=c[q+((m>>>10|16384)<<2)>>2]|0;if(p>>>0>9){b=e&1023;a[p+b|0]=h&255;e=o>>>9;a[p+(b+1)|0]=e&255;r=e;c[2276075]=r;c[2276076]=h;c[2276077]=0;return}else{gg[c[q+196728+(p<<2)>>2]&4095](m,h&65535);r=o>>>9;c[2276075]=r;c[2276076]=h;c[2276077]=0;return}}function KE(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=Hd(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;e=c[2276085]|0;f=e&b;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=f&1023;k=(d[i+(j+1)|0]|0)<<8|(d[i+j|0]|0);l=e;m=h}else{e=gj[c[h+196688+(i<<2)>>2]&4095](g)|0;k=e;l=c[2276085]|0;m=c[2112932]|0}e=k&65535;k=(c[2276074]|0)>>>8<<16&65536|e;g=k>>>1;i=(g|e<<16)>>>8;c[2276074]=i;c[2276078]=i;i=l&b;b=i&16777215;l=c[m+((b>>>10|16384)<<2)>>2]|0;if(l>>>0>9){e=i&1023;a[l+e|0]=g&255;i=k>>>9;a[l+(e+1)|0]=i&255;n=i;c[2276075]=n;c[2276076]=g;c[2276077]=0;return}else{gg[c[m+196728+(l<<2)>>2]&4095](b,g&65535);n=k>>>9;c[2276075]=n;c[2276076]=g;c[2276077]=0;return}}function KF(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)<<16>>16;f=c[2276085]|0;g=l&f;m=g&16777215;b=c[2112932]|0;e=c[b+(m>>>10<<2)>>2]|0;if(e>>>0>9){j=g&1023;n=(d[e+(j+1)|0]|0)<<8|(d[e+j|0]|0);o=f;p=b}else{f=gj[c[b+196688+(e<<2)>>2]&4095](m)|0;n=f;o=c[2276085]|0;p=c[2112932]|0}f=n&65535;n=(c[2276074]|0)>>>8<<16&65536|f;m=n>>>1;e=(m|f<<16)>>>8;c[2276074]=e;c[2276078]=e;e=o&l;l=e&16777215;o=c[p+((l>>>10|16384)<<2)>>2]|0;if(o>>>0>9){f=e&1023;a[o+f|0]=m&255;e=n>>>9;a[o+(f+1)|0]=e&255;q=e;c[2276075]=q;c[2276076]=m;c[2276077]=0;return}else{gg[c[p+196728+(o<<2)>>2]&4095](l,m&65535);q=n>>>9;c[2276075]=q;c[2276076]=m;c[2276077]=0;return}}function KG(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[2276085]|0;t=r&q;h=t&16777215;s=c[2112932]|0;n=c[s+(h>>>10<<2)>>2]|0;if(n>>>0>9){f=t&1023;u=(d[n+(f+1)|0]|0)<<8|(d[n+f|0]|0);v=r;w=s}else{r=gj[c[s+196688+(n<<2)>>2]&4095](h)|0;u=r;v=c[2276085]|0;w=c[2112932]|0}r=u&65535;u=(c[2276074]|0)>>>8<<16&65536|r;h=u>>>1;n=(h|r<<16)>>>8;c[2276074]=n;c[2276078]=n;n=v&q;q=n&16777215;v=c[w+((q>>>10|16384)<<2)>>2]|0;if(v>>>0>9){r=n&1023;a[v+r|0]=h&255;n=u>>>9;a[v+(r+1)|0]=n&255;x=n;c[2276075]=x;c[2276076]=h;c[2276077]=0;return}else{gg[c[w+196728+(v<<2)>>2]&4095](q,h&65535);x=u>>>9;c[2276075]=x;c[2276076]=h;c[2276077]=0;return}}function KH(){var a=0,b=0,d=0,e=0,f=0;a=c[2276069]|0;b=9104156+((a&7)<<2)|0;d=(a>>>9)+7&7;a=d+1|0;e=c[2276074]&256|c[b>>2]&255;f=e<<a|e>>>((8-d|0)>>>0);c[2276108]=(c[2276108]|0)-(a<<c[2276096]);c[2276074]=f;c[2276078]=f;a=f&255;c[b>>2]=a|c[b>>2]&-256;c[2276075]=a;c[2276076]=a;c[2276077]=0;return}function KI(){var a=0,b=0,d=0,e=0,f=0;a=c[2276069]|0;b=9104156+((a&7)<<2)|0;d=(a>>>9)+7&7;a=d+1|0;e=(c[2276074]|0)>>>8<<16&65536|c[b>>2]&65535;f=e<<a|e>>>((16-d|0)>>>0);c[2276108]=(c[2276108]|0)-(a<<c[2276096]);a=f>>>8;c[2276074]=a;c[2276078]=a;a=f&65535;c[b>>2]=a|c[b>>2]&-65536;c[2276075]=a>>>8;c[2276076]=a;c[2276077]=0;return}function KJ(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[2276069]|0;b=9104156+((a&7)<<2)|0;d=(a>>>9)+7&7;a=d+1|0;e=c[b>>2]|0;f=32-d|0;g=((f>>>0<32?e>>>(f>>>0):0)|e<<a)&~(1<<d)|((c[2276074]|0)>>>8&1)<<d;c[2276108]=(c[2276108]|0)-(a<<c[2276096]);c[b>>2]=g;b=((1<<(d^31)&e|0)!=0)<<8;c[2276074]=b;c[2276078]=b;c[2276075]=g>>>24;c[2276076]=g;c[2276077]=0;return}function KK(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[2276069]|0;b=9104156+((a&7)<<2)|0;d=c[9104156+((a>>>9&7)<<2)>>2]&63;if((d|0)==0){c[2276078]=c[2276074];c[2276075]=c[b>>2];e=c[b>>2]&255;c[2276076]=e;c[2276077]=0;return}else{a=(d>>>0)%9|0;f=c[2276074]&256|c[b>>2]&255;g=f<<a|f>>>((9-a|0)>>>0);c[2276108]=(c[2276108]|0)-(d<<c[2276096]);c[2276074]=g;c[2276078]=g;d=g&255;c[b>>2]=d|c[b>>2]&-256;c[2276075]=d;e=d;c[2276076]=e;c[2276077]=0;return}}function KL(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[2276069]|0;b=9104156+((a&7)<<2)|0;d=c[9104156+((a>>>9&7)<<2)>>2]&63;if((d|0)==0){c[2276078]=c[2276074];c[2276075]=(c[b>>2]|0)>>>8;e=c[b>>2]&65535;c[2276076]=e;c[2276077]=0;return}else{a=(d>>>0)%17|0;f=(c[2276074]|0)>>>8<<16&65536|c[b>>2]&65535;g=f<<a|f>>>((17-a|0)>>>0);c[2276108]=(c[2276108]|0)-(d<<c[2276096]);d=g>>>8;c[2276074]=d;c[2276078]=d;d=g&65535;c[b>>2]=d|c[b>>2]&-65536;c[2276075]=d>>>8;e=d;c[2276076]=e;c[2276077]=0;return}}function KM(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[2276069]|0;b=9104156+((a&7)<<2)|0;d=c[9104156+((a>>>9&7)<<2)>>2]&63;a=(d>>>0)%33|0;e=c[b>>2]|0;f=33-a|0;g=a-1|0;h=c[2276074]|0;i=((a>>>0<32?e<<a:0)|(f>>>0<32?e>>>(f>>>0):0))&~(1<<g)|(h>>>8&1)<<g;if((d|0)!=0){c[2276108]=(c[2276108]|0)-(d<<c[2276096])}if((a|0)==0){j=e;k=h;c[2276078]=k;l=j>>>24;c[2276075]=l;c[2276076]=j;c[2276077]=0;return}c[b>>2]=i;b=((1<<32-a&e|0)!=0)<<8;c[2276074]=b;j=i;k=b;c[2276078]=k;l=j>>>24;c[2276075]=l;c[2276076]=j;c[2276077]=0;return}function KN(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276085]|0;f=e&b;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=f&1023;k=(d[i+(j+1)|0]|0)<<8|(d[i+j|0]|0);l=e;m=h}else{e=gj[c[h+196688+(i<<2)>>2]&4095](g)|0;k=e;l=c[2276085]|0;m=c[2112932]|0}e=k&65535;k=(c[2276074]|0)>>>8<<16&65536;g=(k|e)>>>7;c[2276074]=g;c[2276078]=g;g=e<<1&65534;e=k>>>16|g;k=l&b;b=e&65535;l=k&16777215;i=c[m+((l>>>10|16384)<<2)>>2]|0;if(i>>>0>9){h=k&1023;a[i+h|0]=e&255;a[i+(h+1)|0]=(b&65535)>>>8&255;n=g>>>8;c[2276075]=n;c[2276076]=e;c[2276077]=0;return}else{gg[c[m+196728+(i<<2)>>2]&4095](l,b);n=g>>>8;c[2276075]=n;c[2276076]=e;c[2276077]=0;return}}function KO(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=c[b>>2]|0;c[b>>2]=e+2;b=c[2276085]|0;f=b&e;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=f&1023;k=(d[i+(j+1)|0]|0)<<8|(d[i+j|0]|0);l=b;m=h}else{b=gj[c[h+196688+(i<<2)>>2]&4095](g)|0;k=b;l=c[2276085]|0;m=c[2112932]|0}b=k&65535;k=(c[2276074]|0)>>>8<<16&65536;g=(k|b)>>>7;c[2276074]=g;c[2276078]=g;g=b<<1&65534;b=k>>>16|g;k=l&e;e=b&65535;l=k&16777215;i=c[m+((l>>>10|16384)<<2)>>2]|0;if(i>>>0>9){h=k&1023;a[i+h|0]=b&255;a[i+(h+1)|0]=(e&65535)>>>8&255;n=g>>>8;c[2276075]=n;c[2276076]=b;c[2276077]=0;return}else{gg[c[m+196728+(i<<2)>>2]&4095](l,e);n=g>>>8;c[2276075]=n;c[2276076]=b;c[2276077]=0;return}}function KP(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=(c[b>>2]|0)-2|0;c[b>>2]=e;b=c[2276085]|0;f=b&e;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=f&1023;k=(d[i+(j+1)|0]|0)<<8|(d[i+j|0]|0);l=b;m=h}else{b=gj[c[h+196688+(i<<2)>>2]&4095](g)|0;k=b;l=c[2276085]|0;m=c[2112932]|0}b=k&65535;k=(c[2276074]|0)>>>8<<16&65536;g=(k|b)>>>7;c[2276074]=g;c[2276078]=g;g=b<<1&65534;b=k>>>16|g;k=l&e;e=b&65535;l=k&16777215;i=c[m+((l>>>10|16384)<<2)>>2]|0;if(i>>>0>9){h=k&1023;a[i+h|0]=b&255;a[i+(h+1)|0]=(e&65535)>>>8&255;n=g>>>8;c[2276075]=n;c[2276076]=b;c[2276077]=0;return}else{gg[c[m+196728+(i<<2)>>2]&4095](l,e);n=g>>>8;c[2276075]=n;c[2276076]=b;c[2276077]=0;return}}function KQ(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=(h>>>((g<<3&16^16)>>>0)<<16>>16)+b|0;b=c[2276085]|0;g=m&b;h=g&16777215;n=c[2112932]|0;e=c[n+(h>>>10<<2)>>2]|0;if(e>>>0>9){f=g&1023;o=(d[e+(f+1)|0]|0)<<8|(d[e+f|0]|0);p=b;q=n}else{b=gj[c[n+196688+(e<<2)>>2]&4095](h)|0;o=b;p=c[2276085]|0;q=c[2112932]|0}b=o&65535;o=(c[2276074]|0)>>>8<<16&65536;h=(o|b)>>>7;c[2276074]=h;c[2276078]=h;h=b<<1&65534;b=o>>>16|h;o=p&m;m=b&65535;p=o&16777215;e=c[q+((p>>>10|16384)<<2)>>2]|0;if(e>>>0>9){n=o&1023;a[e+n|0]=b&255;a[e+(n+1)|0]=(m&65535)>>>8&255;r=h>>>8;c[2276075]=r;c[2276076]=b;c[2276077]=0;return}else{gg[c[q+196728+(e<<2)>>2]&4095](p,m);r=h>>>8;c[2276075]=r;c[2276076]=b;c[2276077]=0;return}}function KR(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=Hd(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;e=c[2276085]|0;f=e&b;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=f&1023;k=(d[i+(j+1)|0]|0)<<8|(d[i+j|0]|0);l=e;m=h}else{e=gj[c[h+196688+(i<<2)>>2]&4095](g)|0;k=e;l=c[2276085]|0;m=c[2112932]|0}e=k&65535;k=(c[2276074]|0)>>>8<<16&65536;g=(k|e)>>>7;c[2276074]=g;c[2276078]=g;g=e<<1&65534;e=k>>>16|g;k=l&b;b=e&65535;l=k&16777215;i=c[m+((l>>>10|16384)<<2)>>2]|0;if(i>>>0>9){h=k&1023;a[i+h|0]=e&255;a[i+(h+1)|0]=(b&65535)>>>8&255;n=g>>>8;c[2276075]=n;c[2276076]=e;c[2276077]=0;return}else{gg[c[m+196728+(i<<2)>>2]&4095](l,b);n=g>>>8;c[2276075]=n;c[2276076]=e;c[2276077]=0;return}}function KS(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)<<16>>16;f=c[2276085]|0;g=l&f;m=g&16777215;b=c[2112932]|0;e=c[b+(m>>>10<<2)>>2]|0;if(e>>>0>9){j=g&1023;n=(d[e+(j+1)|0]|0)<<8|(d[e+j|0]|0);o=f;p=b}else{f=gj[c[b+196688+(e<<2)>>2]&4095](m)|0;n=f;o=c[2276085]|0;p=c[2112932]|0}f=n&65535;n=(c[2276074]|0)>>>8<<16&65536;m=(n|f)>>>7;c[2276074]=m;c[2276078]=m;m=f<<1&65534;f=n>>>16|m;n=o&l;l=f&65535;o=n&16777215;e=c[p+((o>>>10|16384)<<2)>>2]|0;if(e>>>0>9){b=n&1023;a[e+b|0]=f&255;a[e+(b+1)|0]=(l&65535)>>>8&255;q=m>>>8;c[2276075]=q;c[2276076]=f;c[2276077]=0;return}else{gg[c[p+196728+(e<<2)>>2]&4095](o,l);q=m>>>8;c[2276075]=q;c[2276076]=f;c[2276077]=0;return}}function KT(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[2276085]|0;t=r&q;h=t&16777215;s=c[2112932]|0;n=c[s+(h>>>10<<2)>>2]|0;if(n>>>0>9){f=t&1023;u=(d[n+(f+1)|0]|0)<<8|(d[n+f|0]|0);v=r;w=s}else{r=gj[c[s+196688+(n<<2)>>2]&4095](h)|0;u=r;v=c[2276085]|0;w=c[2112932]|0}r=u&65535;u=(c[2276074]|0)>>>8<<16&65536;h=(u|r)>>>7;c[2276074]=h;c[2276078]=h;h=r<<1&65534;r=u>>>16|h;u=v&q;q=r&65535;v=u&16777215;n=c[w+((v>>>10|16384)<<2)>>2]|0;if(n>>>0>9){s=u&1023;a[n+s|0]=r&255;a[n+(s+1)|0]=(q&65535)>>>8&255;x=h>>>8;c[2276075]=x;c[2276076]=r;c[2276077]=0;return}else{gg[c[w+196728+(n<<2)>>2]&4095](v,q);x=h>>>8;c[2276075]=x;c[2276076]=r;c[2276077]=0;return}}function KU(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[2276038]&28|0)==0){JT();return}a=c[2276054]|0;b=a+4|0;c[2276054]=b;e=c[2276085]&a;a=e&16777215;f=c[2112932]|0;g=c[f+(a>>>10<<2)>>2]|0;if(g>>>0>9){h=e&1023;i=(d[g+(h+3)|0]|0)<<8|(d[g+(h+2)|0]|0)|((d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0))<<16;j=b}else{b=gj[c[f+196768+(g<<2)>>2]&4095](a)|0;i=b;j=c[2276054]|0}b=c[2276056]|0;a=b&-4;if((a|0)==(c[2276083]|0)){k=b;l=c[2276084]|0}else{c[2276083]=a;g=c[2276085]&a;a=g&16777212;f=c[2112932]|0;h=c[f+((a>>>10|32768)<<2)>>2]|0;if(h>>>0>9){e=g&1020;m=(d[h+(e|3)|0]|0)<<8|(d[h+(e|2)|0]|0)|((d[h+(e|1)|0]|0)<<8|(d[h+e|0]|0))<<16;n=b}else{b=gj[c[f+196768+(h<<2)>>2]&4095](a)|0;m=b;n=c[2276056]|0}c[2276084]=m;k=n;l=m}c[2276054]=(l>>>((k<<3&16^16)>>>0)<<16>>16)+j;c[2276056]=i;return}function KV(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;if((c[2276072]|0)==0){b=c[2276073]|0;e=c[2276071]|c[2276070]|b<<11|c[2276079]|(c[2276074]|0)>>>4&16|(c[2276075]|0)>>>4&8|((c[2276076]|0)==0)<<2|(c[2276077]|0)>>>6&2|(c[2276078]|0)>>>8&1;c[2276071]=0;c[2276070]=0;c[2276057]=c[2276054];c[2276072]=4;f=c[9104228+((b&2|4)<<2)>>2]|0;c[2276054]=f;b=c[2276055]|0;do{if(((c[2276038]|0)-1|0)>>>0<2){g=f-4|0;c[2276054]=g;h=c[2276085]&g;g=h&16777215;i=c[2112932]|0;j=c[i+((g>>>10|16384)<<2)>>2]|0;if(j>>>0>9){k=h&1023;a[j+k|0]=b>>>16&255;a[j+(k+1)|0]=b>>>24&255;a[j+(k+2)|0]=b&255;a[j+(k+3)|0]=b>>>8&255;l=i}else{gg[c[i+196808+(j<<2)>>2]&4095](g,b);l=c[2112932]|0}g=(c[2276054]|0)-2|0;c[2276054]=g;j=c[2276085]&g;g=e&65535;i=j&16777215;k=c[l+((i>>>10|16384)<<2)>>2]|0;if(k>>>0>9){h=j&1023;a[k+h|0]=e&255;a[k+(h+1)|0]=(g&65535)>>>8&255;break}else{gg[c[l+196728+(k<<2)>>2]&4095](i,g);break}}else{g=f-2|0;c[2276054]=g;i=c[2276085]&g;g=i&16777215;k=c[2112932]|0;h=c[k+((g>>>10|16384)<<2)>>2]|0;if(h>>>0>9){j=i&1023;a[h+j|0]=32;a[h+(j+1)|0]=0;m=k}else{gg[c[k+196728+(h<<2)>>2]&4095](g,32);m=c[2112932]|0}g=(c[2276054]|0)-4|0;c[2276054]=g;h=c[2276085]&g;g=h&16777215;k=c[m+((g>>>10|16384)<<2)>>2]|0;if(k>>>0>9){j=h&1023;a[k+j|0]=b>>>16&255;a[k+(j+1)|0]=b>>>24&255;a[k+(j+2)|0]=b&255;a[k+(j+3)|0]=b>>>8&255;n=m}else{gg[c[m+196808+(k<<2)>>2]&4095](g,b);n=c[2112932]|0}g=(c[2276054]|0)-2|0;c[2276054]=g;k=c[2276085]&g;g=e&65535;j=k&16777215;h=c[n+((j>>>10|16384)<<2)>>2]|0;if(h>>>0>9){i=k&1023;a[h+i|0]=e&255;a[h+(i+1)|0]=(g&65535)>>>8&255;break}else{gg[c[n+196728+(h<<2)>>2]&4095](j,g);break}}}while(0);n=(c[2276064]|0)+32|0;c[2276056]=n;e=c[2276085]&n;n=e&16777215;b=c[2112932]|0;m=c[b+(n>>>10<<2)>>2]|0;if(m>>>0>9){f=e&1023;o=(d[m+(f+3)|0]|0)<<8|(d[m+(f+2)|0]|0)|((d[m+(f+1)|0]|0)<<8|(d[m+f|0]|0))<<16}else{o=gj[c[b+196768+(m<<2)>>2]&4095](n)|0}c[2276056]=o;c[2276108]=(d[(c[2276098]|0)+(c[2276069]|0)|0]|0)-(d[(c[2276099]|0)+8|0]|0)+(c[2276108]|0);return}o=c[(c[2112932]|0)+196852>>2]|0;if((o|0)!=0){gD[o&8191]()|0}o=c[2276038]|0;if((o-1|0)>>>0<2){n=c[2276054]|0;m=n+2|0;c[2276054]=m;b=c[2276085]|0;f=b&n;n=f&16777215;e=c[2112932]|0;l=c[e+(n>>>10<<2)>>2]|0;if(l>>>0>9){g=f&1023;p=(d[l+(g+1)|0]|0)<<8|(d[l+g|0]|0);q=m;r=b;s=e}else{b=gj[c[e+196688+(l<<2)>>2]&4095](n)|0;p=b;q=c[2276054]|0;r=c[2276085]|0;s=c[2112932]|0}c[2276054]=q+4;b=r&q;q=b&16777215;r=c[s+(q>>>10<<2)>>2]|0;if(r>>>0>9){n=b&1023;t=(d[r+(n+3)|0]|0)<<8|(d[r+(n+2)|0]|0)|((d[r+(n+1)|0]|0)<<8|(d[r+n|0]|0))<<16}else{t=gj[c[s+196768+(r<<2)>>2]&4095](q)|0}c[2276056]=t;JR(p&65535);c[2276087]=0;c[2276088]=0;return}p=c[2276054]|0;if((o|0)==4){o=c[2276085]&p+6;t=o&16777215;q=c[2112932]|0;r=c[q+(t>>>10<<2)>>2]|0;if(r>>>0>9){s=o&1023;u=(d[r+(s+1)|0]|0)<<8|(d[r+s|0]|0)}else{u=gj[c[q+196688+(r<<2)>>2]&4095](t)|0}if((u&65535)<4096){u=c[2276054]|0;t=u+2|0;c[2276054]=t;r=c[2276085]|0;q=r&u;u=q&16777215;s=c[2112932]|0;o=c[s+(u>>>10<<2)>>2]|0;if(o>>>0>9){n=q&1023;v=(d[o+(n+1)|0]|0)<<8|(d[o+n|0]|0);w=t;x=r;y=s}else{r=gj[c[s+196688+(o<<2)>>2]&4095](u)|0;v=r;w=c[2276054]|0;x=c[2276085]|0;y=c[2112932]|0}r=w+4|0;c[2276054]=r;u=x&w;w=u&16777215;x=c[y+(w>>>10<<2)>>2]|0;if(x>>>0>9){o=u&1023;z=(d[x+(o+3)|0]|0)<<8|(d[x+(o+2)|0]|0)|((d[x+(o+1)|0]|0)<<8|(d[x+o|0]|0))<<16;A=r}else{r=gj[c[y+196768+(x<<2)>>2]&4095](w)|0;z=r;A=c[2276054]|0}c[2276054]=A+2;c[2276056]=z;JR(v&65535);c[2276087]=0;c[2276088]=0;return}c[2276087]=0;c[2276088]=0;v=c[2276072]|0;z=c[2276073]|0;A=c[2276071]|c[2276070]|v<<11|z<<11|c[2276079]|(c[2276074]|0)>>>4&16|(c[2276075]|0)>>>4&8|((c[2276076]|0)==0)<<2|(c[2276077]|0)>>>6&2|(c[2276078]|0)>>>8&1;c[2276071]=0;c[2276070]=0;c[9104228+((v>>>1&z|v)<<2)>>2]=c[2276054];c[2276072]=4;v=c[9104228+((c[2276073]&2|4)<<2)>>2]|0;c[2276054]=v;z=c[2276056]|0;do{if(((c[2276038]|0)-1|0)>>>0<2){r=v-4|0;c[2276054]=r;w=c[2276085]&r;r=w&16777215;x=c[2112932]|0;y=c[x+((r>>>10|16384)<<2)>>2]|0;if(y>>>0>9){o=w&1023;a[y+o|0]=z>>>16&255;a[y+(o+1)|0]=z>>>24&255;a[y+(o+2)|0]=z&255;a[y+(o+3)|0]=z>>>8&255;B=x}else{gg[c[x+196808+(y<<2)>>2]&4095](r,z);B=c[2112932]|0}r=(c[2276054]|0)-2|0;c[2276054]=r;y=c[2276085]&r;r=A&65535;x=y&16777215;o=c[B+((x>>>10|16384)<<2)>>2]|0;if(o>>>0>9){w=y&1023;a[o+w|0]=A&255;a[o+(w+1)|0]=(r&65535)>>>8&255;break}else{gg[c[B+196728+(o<<2)>>2]&4095](x,r);break}}else{r=v-2|0;c[2276054]=r;x=c[2276085]&r;r=x&16777215;o=c[2112932]|0;w=c[o+((r>>>10|16384)<<2)>>2]|0;if(w>>>0>9){y=x&1023;a[w+y|0]=56;a[w+(y+1)|0]=0;C=o}else{gg[c[o+196728+(w<<2)>>2]&4095](r,56);C=c[2112932]|0}r=(c[2276054]|0)-4|0;c[2276054]=r;w=c[2276085]&r;r=w&16777215;o=c[C+((r>>>10|16384)<<2)>>2]|0;if(o>>>0>9){y=w&1023;a[o+y|0]=z>>>16&255;a[o+(y+1)|0]=z>>>24&255;a[o+(y+2)|0]=z&255;a[o+(y+3)|0]=z>>>8&255;D=C}else{gg[c[C+196808+(o<<2)>>2]&4095](r,z);D=c[2112932]|0}r=(c[2276054]|0)-2|0;c[2276054]=r;o=c[2276085]&r;r=A&65535;y=o&16777215;w=c[D+((y>>>10|16384)<<2)>>2]|0;if(w>>>0>9){x=o&1023;a[w+x|0]=A&255;a[w+(x+1)|0]=(r&65535)>>>8&255;break}else{gg[c[D+196728+(w<<2)>>2]&4095](y,r);break}}}while(0);D=(c[2276064]|0)+56|0;c[2276056]=D;A=c[2276085]&D;D=A&16777215;z=c[2112932]|0;C=c[z+(D>>>10<<2)>>2]|0;if(C>>>0>9){v=A&1023;E=(d[C+(v+3)|0]|0)<<8|(d[C+(v+2)|0]|0)|((d[C+(v+1)|0]|0)<<8|(d[C+v|0]|0))<<16}else{E=gj[c[z+196768+(C<<2)>>2]&4095](D)|0}c[2276056]=E;c[2276108]=(d[(c[2276098]|0)+(c[2276069]|0)|0]|0)-(d[(c[2276099]|0)+14|0]|0)+(c[2276108]|0);return}else{F=p}while(1){p=c[2276085]&F+6;E=p&16777215;D=c[2112932]|0;C=c[D+(E>>>10<<2)>>2]|0;if(C>>>0>9){z=p&1023;G=(d[C+(z+1)|0]|0)<<8|(d[C+z|0]|0)}else{G=gj[c[D+196688+(C<<2)>>2]&4095](E)|0}E=(G&65535)>>>12;if((E|0)==0){H=35300;break}else if((E|0)==2){H=35311;break}else if((E|0)!=1){H=35318;break}E=c[2276054]|0;C=E+2|0;c[2276054]=C;D=c[2276085]&E;E=D&16777215;z=c[2112932]|0;p=c[z+(E>>>10<<2)>>2]|0;if(p>>>0>9){v=D&1023;I=(d[p+(v+1)|0]|0)<<8|(d[p+v|0]|0);J=C}else{C=gj[c[z+196688+(p<<2)>>2]&4095](E)|0;I=C;J=c[2276054]|0}C=J+6|0;c[2276054]=C;E=c[2276086]&(I&65535);c[2276070]=E&32768;c[2276071]=E&16384;c[2276079]=E&1792;p=E<<4;c[2276074]=p&256;c[2276075]=p&128;c[2276076]=E>>>2&1^1;c[2276077]=E<<6&128;c[2276078]=E<<8&256;p=E>>>11;E=c[2276072]|0;c[9104228+((E>>>1&c[2276073]|E)<<2)>>2]=C;C=p&4;c[2276072]=C;E=p&2;c[2276073]=E;p=c[9104228+((C>>>1&E|C)<<2)>>2]|0;c[2276054]=p;F=p}if((H|0)==35318){c[2276087]=0;c[2276088]=0;F=c[2276072]|0;I=c[2276073]|0;J=c[2276071]|c[2276070]|F<<11|I<<11|c[2276079]|(c[2276074]|0)>>>4&16|(c[2276075]|0)>>>4&8|((c[2276076]|0)==0)<<2|(c[2276077]|0)>>>6&2|(c[2276078]|0)>>>8&1;c[2276071]=0;c[2276070]=0;c[9104228+((F>>>1&I|F)<<2)>>2]=c[2276054];c[2276072]=4;F=c[9104228+((c[2276073]&2|4)<<2)>>2]|0;c[2276054]=F;I=c[2276056]|0;do{if(((c[2276038]|0)-1|0)>>>0<2){G=F-4|0;c[2276054]=G;p=c[2276085]&G;G=p&16777215;C=c[2112932]|0;E=c[C+((G>>>10|16384)<<2)>>2]|0;if(E>>>0>9){z=p&1023;a[E+z|0]=I>>>16&255;a[E+(z+1)|0]=I>>>24&255;a[E+(z+2)|0]=I&255;a[E+(z+3)|0]=I>>>8&255;K=C}else{gg[c[C+196808+(E<<2)>>2]&4095](G,I);K=c[2112932]|0}G=(c[2276054]|0)-2|0;c[2276054]=G;E=c[2276085]&G;G=J&65535;C=E&16777215;z=c[K+((C>>>10|16384)<<2)>>2]|0;if(z>>>0>9){p=E&1023;a[z+p|0]=J&255;a[z+(p+1)|0]=(G&65535)>>>8&255;break}else{gg[c[K+196728+(z<<2)>>2]&4095](C,G);break}}else{G=F-2|0;c[2276054]=G;C=c[2276085]&G;G=C&16777215;z=c[2112932]|0;p=c[z+((G>>>10|16384)<<2)>>2]|0;if(p>>>0>9){E=C&1023;a[p+E|0]=56;a[p+(E+1)|0]=0;L=z}else{gg[c[z+196728+(p<<2)>>2]&4095](G,56);L=c[2112932]|0}G=(c[2276054]|0)-4|0;c[2276054]=G;p=c[2276085]&G;G=p&16777215;z=c[L+((G>>>10|16384)<<2)>>2]|0;if(z>>>0>9){E=p&1023;a[z+E|0]=I>>>16&255;a[z+(E+1)|0]=I>>>24&255;a[z+(E+2)|0]=I&255;a[z+(E+3)|0]=I>>>8&255;M=L}else{gg[c[L+196808+(z<<2)>>2]&4095](G,I);M=c[2112932]|0}G=(c[2276054]|0)-2|0;c[2276054]=G;z=c[2276085]&G;G=J&65535;E=z&16777215;p=c[M+((E>>>10|16384)<<2)>>2]|0;if(p>>>0>9){C=z&1023;a[p+C|0]=J&255;a[p+(C+1)|0]=(G&65535)>>>8&255;break}else{gg[c[M+196728+(p<<2)>>2]&4095](E,G);break}}}while(0);M=(c[2276064]|0)+56|0;c[2276056]=M;J=c[2276085]&M;M=J&16777215;I=c[2112932]|0;L=c[I+(M>>>10<<2)>>2]|0;if(L>>>0>9){F=J&1023;N=(d[L+(F+3)|0]|0)<<8|(d[L+(F+2)|0]|0)|((d[L+(F+1)|0]|0)<<8|(d[L+F|0]|0))<<16}else{N=gj[c[I+196768+(L<<2)>>2]&4095](M)|0}c[2276056]=N;c[2276108]=(d[(c[2276098]|0)+(c[2276069]|0)|0]|0)-(d[(c[2276099]|0)+14|0]|0)+(c[2276108]|0);return}else if((H|0)==35300){N=c[2276054]|0;M=N+2|0;c[2276054]=M;L=c[2276085]|0;I=L&N;N=I&16777215;F=c[2112932]|0;J=c[F+(N>>>10<<2)>>2]|0;if(J>>>0>9){K=I&1023;O=(d[J+(K+1)|0]|0)<<8|(d[J+K|0]|0);P=M;Q=L;R=F}else{L=gj[c[F+196688+(J<<2)>>2]&4095](N)|0;O=L;P=c[2276054]|0;Q=c[2276085]|0;R=c[2112932]|0}L=P+4|0;c[2276054]=L;N=Q&P;P=N&16777215;Q=c[R+(P>>>10<<2)>>2]|0;if(Q>>>0>9){J=N&1023;S=(d[Q+(J+3)|0]|0)<<8|(d[Q+(J+2)|0]|0)|((d[Q+(J+1)|0]|0)<<8|(d[Q+J|0]|0))<<16;T=L}else{L=gj[c[R+196768+(Q<<2)>>2]&4095](P)|0;S=L;T=c[2276054]|0}c[2276054]=T+2;c[2276056]=S;JR(O&65535);c[2276087]=0;c[2276088]=0;return}else if((H|0)==35311){H=c[2276054]|0;O=H+2|0;c[2276054]=O;S=c[2276085]|0;T=S&H;H=T&16777215;L=c[2112932]|0;P=c[L+(H>>>10<<2)>>2]|0;if(P>>>0>9){Q=T&1023;U=(d[P+(Q+1)|0]|0)<<8|(d[P+Q|0]|0);V=O;W=S;X=L}else{S=gj[c[L+196688+(P<<2)>>2]&4095](H)|0;U=S;V=c[2276054]|0;W=c[2276085]|0;X=c[2112932]|0}S=V+4|0;c[2276054]=S;H=W&V;V=H&16777215;W=c[X+(V>>>10<<2)>>2]|0;if(W>>>0>9){P=H&1023;Y=(d[W+(P+3)|0]|0)<<8|(d[W+(P+2)|0]|0)|((d[W+(P+1)|0]|0)<<8|(d[W+P|0]|0))<<16;Z=S}else{S=gj[c[X+196768+(W<<2)>>2]&4095](V)|0;Y=S;Z=c[2276054]|0}c[2276054]=Z+6;c[2276056]=Y;JR(U&65535);c[2276087]=0;c[2276088]=0;return}}function KW(){if((c[2276038]&24|0)!=0){return}JT();return}function KX(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[2276054]|0;b=a+2|0;c[2276054]=b;e=c[2276085]|0;f=e&a;a=f&16777215;g=c[2112932]|0;h=c[g+(a>>>10<<2)>>2]|0;if(h>>>0>9){i=f&1023;j=(d[h+(i+1)|0]|0)<<8|(d[h+i|0]|0);k=b;l=e;m=g}else{e=gj[c[g+196688+(h<<2)>>2]&4095](a)|0;j=e;k=c[2276054]|0;l=c[2276085]|0;m=c[2112932]|0}e=j&65535;j=e<<4;c[2276074]=j&256;c[2276075]=j&128;c[2276076]=e>>>2&1^1;c[2276077]=e<<6&128;c[2276078]=e<<8&256;c[2276054]=k+4;e=l&k;k=e&16777215;l=c[m+(k>>>10<<2)>>2]|0;if(l>>>0>9){j=e&1023;n=(d[l+(j+3)|0]|0)<<8|(d[l+(j+2)|0]|0)|((d[l+(j+1)|0]|0)<<8|(d[l+j|0]|0))<<16;c[2276056]=n;return}else{n=gj[c[m+196768+(l<<2)>>2]&4095](k)|0;c[2276056]=n;return}}function KY(){var a=0,b=0,e=0,f=0,g=0,h=0;a=c[2276054]|0;c[2276054]=a+4;b=c[2276085]&a;a=b&16777215;e=c[2112932]|0;f=c[e+(a>>>10<<2)>>2]|0;if(f>>>0>9){g=b&1023;h=(d[f+(g+3)|0]|0)<<8|(d[f+(g+2)|0]|0)|((d[f+(g+1)|0]|0)<<8|(d[f+g|0]|0))<<16;c[2276056]=h;return}else{h=gj[c[e+196768+(f<<2)>>2]&4095](a)|0;c[2276056]=h;return}}function KZ(){var a=0,b=0,d=0,e=0,f=0;a=c[2276069]|0;b=9104156+((a>>>9&7)<<2)|0;d=c[9104156+((a&7)<<2)>>2]|0;a=c[b>>2]|0;e=(a&15)-(d&15)-((c[2276074]|0)>>>8&1)|0;c[2276077]=0;f=(e>>>0>9?e-6|0:e)+((a&240)-(d&240))|0;d=f>>>0>153;a=d?256:0;c[2276078]=a;c[2276074]=a;c[2276075]=d?128:0;a=(d?f+160|0:f)&255;c[2276076]=a|c[2276076];c[b>>2]=a|c[b>>2]&-256;return}function K_(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;b=c[2276085]|0;e=b&d;d=e&16777215;f=c[2112932]|0;g=c[f+(d>>>10<<2)>>2]|0;if(g>>>0>9){h=a[g+(e&1023^1)|0]|0;i=b;j=f}else{b=gj[c[f+196608+(g<<2)>>2]&4095](d)|0;h=b;i=c[2276085]|0;j=c[2112932]|0}b=h&255;h=(c[2276054]|0)-2|0;c[2276054]=h;d=i&h;g=d&16777215;f=c[j+(g>>>10<<2)>>2]|0;if(f>>>0>9){k=a[f+(d&1023^1)|0]|0;l=i;m=j}else{i=gj[c[j+196608+(f<<2)>>2]&4095](g)|0;k=i;l=c[2276085]|0;m=c[2112932]|0}i=k&255;k=(i&15)-(b&15)-((c[2276074]|0)>>>8&1)|0;c[2276077]=0;g=(k>>>0>9?k-6|0:k)+((i&240)-(b&240))|0;b=g>>>0>153;i=b?256:0;k=b?g+160|0:g;c[2276078]=i;c[2276074]=i;c[2276075]=b?128:0;c[2276076]=k&255|c[2276076];b=l&h;h=k&255;k=b&16777215;l=c[m+((k>>>10|16384)<<2)>>2]|0;if(l>>>0>9){a[l+(b&1023^1)|0]=h;return}else{gg[c[m+196648+(l<<2)>>2]&4095](k,h);return}}function K$(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=(c[2276054]|0)-2|0;c[2276054]=b;d=c[2276085]&b;b=d&16777215;e=c[2112932]|0;f=c[e+(b>>>10<<2)>>2]|0;if(f>>>0>9){g=a[f+(d&1023^1)|0]|0;h=e}else{d=gj[c[e+196608+(f<<2)>>2]&4095](b)|0;g=d;h=c[2112932]|0}d=g&255;g=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;b=(c[g>>2]|0)-1|0;c[g>>2]=b;g=c[2276085]|0;f=g&b;e=f&16777215;i=c[h+(e>>>10<<2)>>2]|0;if(i>>>0>9){j=a[i+(f&1023^1)|0]|0;k=g;l=h}else{g=gj[c[h+196608+(i<<2)>>2]&4095](e)|0;j=g;k=c[2276085]|0;l=c[2112932]|0}g=j&255;j=(g&15)-(d&15)-((c[2276074]|0)>>>8&1)|0;c[2276077]=0;e=(j>>>0>9?j-6|0:j)+((g&240)-(d&240))|0;d=e>>>0>153;g=d?256:0;j=d?e+160|0:e;c[2276078]=g;c[2276074]=g;c[2276075]=d?128:0;c[2276076]=j&255|c[2276076];d=k&b;b=j&255;j=d&16777215;k=c[l+((j>>>10|16384)<<2)>>2]|0;if(k>>>0>9){a[k+(d&1023^1)|0]=b;return}else{gg[c[l+196648+(k<<2)>>2]&4095](j,b);return}}function K0(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=(c[2276054]|0)-2|0;c[2276054]=b;d=c[2276085]|0;e=d&b;f=e&16777215;g=c[2112932]|0;h=c[g+(f>>>10<<2)>>2]|0;if(h>>>0>9){i=a[h+(e&1023^1)|0]|0;j=b;k=d;l=g}else{d=gj[c[g+196608+(h<<2)>>2]&4095](f)|0;i=d;j=c[2276054]|0;k=c[2276085]|0;l=c[2112932]|0}d=i&255;i=j-2|0;c[2276054]=i;j=k&i;f=j&16777215;h=c[l+(f>>>10<<2)>>2]|0;if(h>>>0>9){m=a[h+(j&1023^1)|0]|0;n=k;o=l}else{k=gj[c[l+196608+(h<<2)>>2]&4095](f)|0;m=k;n=c[2276085]|0;o=c[2112932]|0}k=m&255;m=(k&15)-(d&15)-((c[2276074]|0)>>>8&1)|0;c[2276077]=0;f=(m>>>0>9?m-6|0:m)+((k&240)-(d&240))|0;d=f>>>0>153;k=d?256:0;m=d?f+160|0:f;c[2276078]=k;c[2276074]=k;c[2276075]=d?128:0;c[2276076]=m&255|c[2276076];d=n&i;i=m&255;m=d&16777215;n=c[o+((m>>>10|16384)<<2)>>2]|0;if(n>>>0>9){a[n+(d&1023^1)|0]=i;return}else{gg[c[o+196648+(n<<2)>>2]&4095](m,i);return}}function K1(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;b=c[2276085]&d;d=b&16777215;e=c[2112932]|0;f=c[e+(d>>>10<<2)>>2]|0;if(f>>>0>9){g=a[f+(b&1023^1)|0]|0;h=e}else{b=gj[c[e+196608+(f<<2)>>2]&4095](d)|0;g=b;h=c[2112932]|0}b=g&255;g=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;d=(c[g>>2]|0)-1|0;c[g>>2]=d;g=c[2276085]|0;f=g&d;e=f&16777215;i=c[h+(e>>>10<<2)>>2]|0;if(i>>>0>9){j=a[i+(f&1023^1)|0]|0;k=g;l=h}else{g=gj[c[h+196608+(i<<2)>>2]&4095](e)|0;j=g;k=c[2276085]|0;l=c[2112932]|0}g=j&255;j=(g&15)-(b&15)-((c[2276074]|0)>>>8&1)|0;c[2276077]=0;e=(j>>>0>9?j-6|0:j)+((g&240)-(b&240))|0;b=e>>>0>153;g=b?256:0;j=b?e+160|0:e;c[2276078]=g;c[2276074]=g;c[2276075]=b?128:0;c[2276076]=j&255|c[2276076];b=k&d;d=j&255;j=b&16777215;k=c[l+((j>>>10|16384)<<2)>>2]|0;if(k>>>0>9){a[k+(b&1023^1)|0]=d;return}else{gg[c[l+196648+(k<<2)>>2]&4095](j,d);return}}function K2(){var a=0;a=9104156+((c[2276069]&7)<<2)|0;c[a>>2]=c[a>>2]|255;return}function K3(){var b=0,d=0,e=0,f=0;b=c[2276085]&c[9104156+((c[2276069]&7|8)<<2)>>2];d=b&16777215;e=c[2112932]|0;f=c[e+((d>>>10|16384)<<2)>>2]|0;if(f>>>0>9){a[f+(b&1023^1)|0]=-1;return}else{gg[c[e+196648+(f<<2)>>2]&4095](d,-1);return}}function K4(){var b=0,d=0,e=0,f=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;b=c[2276085]&d;d=b&16777215;e=c[2112932]|0;f=c[e+((d>>>10|16384)<<2)>>2]|0;if(f>>>0>9){a[f+(b&1023^1)|0]=-1;return}else{gg[c[e+196648+(f<<2)>>2]&4095](d,-1);return}}function K5(){var b=0,d=0,e=0,f=0;b=c[2276054]|0;c[2276054]=b+2;d=c[2276085]&b;b=d&16777215;e=c[2112932]|0;f=c[e+((b>>>10|16384)<<2)>>2]|0;if(f>>>0>9){a[f+(d&1023^1)|0]=-1;return}else{gg[c[e+196648+(f<<2)>>2]&4095](b,-1);return}}function K6(){var b=0,d=0,e=0,f=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;b=c[2276085]&d;d=b&16777215;e=c[2112932]|0;f=c[e+((d>>>10|16384)<<2)>>2]|0;if(f>>>0>9){a[f+(b&1023^1)|0]=-1;return}else{gg[c[e+196648+(f<<2)>>2]&4095](d,-1);return}}function K7(){var b=0,d=0,e=0,f=0;b=(c[2276054]|0)-2|0;c[2276054]=b;d=c[2276085]&b;b=d&16777215;e=c[2112932]|0;f=c[e+((b>>>10|16384)<<2)>>2]|0;if(f>>>0>9){a[f+(d&1023^1)|0]=-1;return}else{gg[c[e+196648+(f<<2)>>2]&4095](b,-1);return}}function K8(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=(h>>>((g<<3&16^16)>>>0)<<16>>16)+b&c[2276085];b=m&16777215;g=c[2112932]|0;h=c[g+((b>>>10|16384)<<2)>>2]|0;if(h>>>0>9){a[h+(m&1023^1)|0]=-1;return}else{gg[c[g+196648+(h<<2)>>2]&4095](b,-1);return}}function K9(){var b=0,d=0,e=0,f=0;b=Hd(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;d=c[2276085]&b;b=d&16777215;e=c[2112932]|0;f=c[e+((b>>>10|16384)<<2)>>2]|0;if(f>>>0>9){a[f+(d&1023^1)|0]=-1;return}else{gg[c[e+196648+(f<<2)>>2]&4095](b,-1);return}}function La(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)<<16>>16&c[2276085];f=l&16777215;g=c[2112932]|0;m=c[g+((f>>>10|16384)<<2)>>2]|0;if(m>>>0>9){a[m+(l&1023^1)|0]=-1;return}else{gg[c[g+196648+(m<<2)>>2]&4095](f,-1);return}}function Lb(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[2276085]&q;q=r&16777215;t=c[2112932]|0;h=c[t+((q>>>10|16384)<<2)>>2]|0;if(h>>>0>9){a[h+(r&1023^1)|0]=-1;return}else{gg[c[t+196648+(h<<2)>>2]&4095](q,-1);return}}function Lc(){var a=0;a=9104156+((c[2276069]&7)<<2)|0;c[a>>2]=c[a>>2]&-256;return}function Ld(){var b=0,d=0,e=0,f=0;b=c[2276085]&c[9104156+((c[2276069]&7|8)<<2)>>2];d=b&16777215;e=c[2112932]|0;f=c[e+((d>>>10|16384)<<2)>>2]|0;if(f>>>0>9){a[f+(b&1023^1)|0]=0;return}else{gg[c[e+196648+(f<<2)>>2]&4095](d,0);return}}function Le(){var b=0,d=0,e=0,f=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;b=c[2276085]&d;d=b&16777215;e=c[2112932]|0;f=c[e+((d>>>10|16384)<<2)>>2]|0;if(f>>>0>9){a[f+(b&1023^1)|0]=0;return}else{gg[c[e+196648+(f<<2)>>2]&4095](d,0);return}}function Lf(){var b=0,d=0,e=0,f=0;b=c[2276054]|0;c[2276054]=b+2;d=c[2276085]&b;b=d&16777215;e=c[2112932]|0;f=c[e+((b>>>10|16384)<<2)>>2]|0;if(f>>>0>9){a[f+(d&1023^1)|0]=0;return}else{gg[c[e+196648+(f<<2)>>2]&4095](b,0);return}}function Lg(){var b=0,d=0,e=0,f=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;b=c[2276085]&d;d=b&16777215;e=c[2112932]|0;f=c[e+((d>>>10|16384)<<2)>>2]|0;if(f>>>0>9){a[f+(b&1023^1)|0]=0;return}else{gg[c[e+196648+(f<<2)>>2]&4095](d,0);return}}function Lh(){var b=0,d=0,e=0,f=0;b=(c[2276054]|0)-2|0;c[2276054]=b;d=c[2276085]&b;b=d&16777215;e=c[2112932]|0;f=c[e+((b>>>10|16384)<<2)>>2]|0;if(f>>>0>9){a[f+(d&1023^1)|0]=0;return}else{gg[c[e+196648+(f<<2)>>2]&4095](b,0);return}}function Li(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=(h>>>((g<<3&16^16)>>>0)<<16>>16)+b&c[2276085];b=m&16777215;g=c[2112932]|0;h=c[g+((b>>>10|16384)<<2)>>2]|0;if(h>>>0>9){a[h+(m&1023^1)|0]=0;return}else{gg[c[g+196648+(h<<2)>>2]&4095](b,0);return}}function Lj(){var b=0,d=0,e=0,f=0;b=Hd(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;d=c[2276085]&b;b=d&16777215;e=c[2112932]|0;f=c[e+((b>>>10|16384)<<2)>>2]|0;if(f>>>0>9){a[f+(d&1023^1)|0]=0;return}else{gg[c[e+196648+(f<<2)>>2]&4095](b,0);return}}function Lk(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)<<16>>16&c[2276085];f=l&16777215;g=c[2112932]|0;m=c[g+((f>>>10|16384)<<2)>>2]|0;if(m>>>0>9){a[m+(l&1023^1)|0]=0;return}else{gg[c[g+196648+(m<<2)>>2]&4095](f,0);return}}function Ll(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[2276085]&q;q=r&16777215;t=c[2112932]|0;h=c[t+((q>>>10|16384)<<2)>>2]|0;if(h>>>0>9){a[h+(r&1023^1)|0]=0;return}else{gg[c[t+196648+(h<<2)>>2]&4095](q,0);return}}function Lm(){var a=0,b=0;a=9104156+((c[2276069]&7)<<2)|0;b=c[a>>2]|0;if((c[2276078]&256|0)==0&(c[2276076]|0)!=0){c[a>>2]=b|255;c[2276108]=(c[2276108]|0)-(c[2276093]|0);return}else{c[a>>2]=b&-256;return}}function Ln(){var a=0,b=0;a=9104156+((c[2276069]&7)<<2)|0;b=c[a>>2]|0;if((c[2276078]&256|0)==0&(c[2276076]|0)!=0){c[a>>2]=b&-256;return}else{c[a>>2]=b|255;c[2276108]=(c[2276108]|0)-(c[2276093]|0);return}}function Lo(){var a=0,b=0;a=9104156+((c[2276069]&7)<<2)|0;b=c[a>>2]|0;if((c[2276078]&256|0)==0){c[a>>2]=b|255;c[2276108]=(c[2276108]|0)-(c[2276093]|0);return}else{c[a>>2]=b&-256;return}}function Lp(){var a=0,b=0;a=9104156+((c[2276069]&7)<<2)|0;b=c[a>>2]|0;if((c[2276078]&256|0)==0){c[a>>2]=b&-256;return}else{c[a>>2]=b|255;c[2276108]=(c[2276108]|0)-(c[2276093]|0);return}}function Lq(){var a=0,b=0;a=9104156+((c[2276069]&7)<<2)|0;b=c[a>>2]|0;if((c[2276076]|0)==0){c[a>>2]=b&-256;return}else{c[a>>2]=b|255;c[2276108]=(c[2276108]|0)-(c[2276093]|0);return}}function Lr(){var a=0,b=0;a=9104156+((c[2276069]&7)<<2)|0;b=c[a>>2]|0;if((c[2276076]|0)==0){c[a>>2]=b|255;c[2276108]=(c[2276108]|0)-(c[2276093]|0);return}else{c[a>>2]=b&-256;return}}function Ls(){var a=0,b=0;a=9104156+((c[2276069]&7)<<2)|0;b=c[a>>2]|0;if((c[2276077]&128|0)==0){c[a>>2]=b|255;c[2276108]=(c[2276108]|0)-(c[2276093]|0);return}else{c[a>>2]=b&-256;return}}function Lt(){var a=0,b=0;a=9104156+((c[2276069]&7)<<2)|0;b=c[a>>2]|0;if((c[2276077]&128|0)==0){c[a>>2]=b&-256;return}else{c[a>>2]=b|255;c[2276108]=(c[2276108]|0)-(c[2276093]|0);return}}function Lu(){var a=0,b=0;a=9104156+((c[2276069]&7)<<2)|0;b=c[a>>2]|0;if((c[2276075]&128|0)==0){c[a>>2]=b|255;c[2276108]=(c[2276108]|0)-(c[2276093]|0);return}else{c[a>>2]=b&-256;return}}function Lv(){var a=0,b=0;a=9104156+((c[2276069]&7)<<2)|0;b=c[a>>2]|0;if((c[2276075]&128|0)==0){c[a>>2]=b&-256;return}else{c[a>>2]=b|255;c[2276108]=(c[2276108]|0)-(c[2276093]|0);return}}function Lw(){var a=0,b=0;a=9104156+((c[2276069]&7)<<2)|0;b=c[a>>2]|0;if(((c[2276077]^c[2276075])&128|0)==0){c[a>>2]=b|255;c[2276108]=(c[2276108]|0)-(c[2276093]|0);return}else{c[a>>2]=b&-256;return}}function Lx(){var a=0,b=0;a=9104156+((c[2276069]&7)<<2)|0;b=c[a>>2]|0;if(((c[2276077]^c[2276075])&128|0)==0){c[a>>2]=b&-256;return}else{c[a>>2]=b|255;c[2276108]=(c[2276108]|0)-(c[2276093]|0);return}}function Ly(){var a=0,b=0;a=9104156+((c[2276069]&7)<<2)|0;b=c[a>>2]|0;if(((c[2276077]^c[2276075])&128|0)==0&(c[2276076]|0)!=0){c[a>>2]=b|255;c[2276108]=(c[2276108]|0)-(c[2276093]|0);return}else{c[a>>2]=b&-256;return}}function Lz(){var a=0,b=0;a=9104156+((c[2276069]&7)<<2)|0;b=c[a>>2]|0;if(((c[2276077]^c[2276075])&128|0)==0&(c[2276076]|0)!=0){c[a>>2]=b&-256;return}else{c[a>>2]=b|255;c[2276108]=(c[2276108]|0)-(c[2276093]|0);return}}function LA(){var b=0,d=0,e=0,f=0,g=0;if((c[2276078]&256|0)==0){b=((c[2276076]|0)!=0)<<31>>31}else{b=0}d=c[2276085]&c[9104156+((c[2276069]&7|8)<<2)>>2];e=d&16777215;f=c[2112932]|0;g=c[f+((e>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(d&1023^1)|0]=b;return}else{gg[c[f+196648+(g<<2)>>2]&4095](e,b);return}}function LB(){var b=0,d=0,e=0,f=0,g=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;if((c[2276078]&256|0)==0){e=((c[2276076]|0)!=0)<<31>>31}else{e=0}b=c[2276085]&d;d=b&16777215;f=c[2112932]|0;g=c[f+((d>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(b&1023^1)|0]=e;return}else{gg[c[f+196648+(g<<2)>>2]&4095](d,e);return}}function LC(){var b=0,d=0,e=0,f=0,g=0;b=c[2276054]|0;c[2276054]=b+2;if((c[2276078]&256|0)==0){d=((c[2276076]|0)!=0)<<31>>31}else{d=0}e=c[2276085]&b;b=e&16777215;f=c[2112932]|0;g=c[f+((b>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(e&1023^1)|0]=d;return}else{gg[c[f+196648+(g<<2)>>2]&4095](b,d);return}}function LD(){var b=0,d=0,e=0,f=0,g=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;if((c[2276078]&256|0)==0){e=((c[2276076]|0)!=0)<<31>>31}else{e=0}b=c[2276085]&d;d=b&16777215;f=c[2112932]|0;g=c[f+((d>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(b&1023^1)|0]=e;return}else{gg[c[f+196648+(g<<2)>>2]&4095](d,e);return}}function LE(){var b=0,d=0,e=0,f=0,g=0;b=(c[2276054]|0)-2|0;c[2276054]=b;if((c[2276078]&256|0)==0){d=((c[2276076]|0)!=0)<<31>>31}else{d=0}e=c[2276085]&b;b=e&16777215;f=c[2112932]|0;g=c[f+((b>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(e&1023^1)|0]=d;return}else{gg[c[f+196648+(g<<2)>>2]&4095](b,d);return}}function LF(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;if((c[2276078]&256|0)==0){o=((c[2276076]|0)!=0)<<31>>31}else{o=0}m=c[2276085]&(h>>>((g<<3&16^16)>>>0)<<16>>16)+b;b=m&16777215;g=c[2112932]|0;h=c[g+((b>>>10|16384)<<2)>>2]|0;if(h>>>0>9){a[h+(m&1023^1)|0]=o;return}else{gg[c[g+196648+(h<<2)>>2]&4095](b,o);return}}function LG(){var b=0,d=0,e=0,f=0,g=0;b=Hd(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;if((c[2276078]&256|0)==0){d=((c[2276076]|0)!=0)<<31>>31}else{d=0}e=c[2276085]&b;b=e&16777215;f=c[2112932]|0;g=c[f+((b>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(e&1023^1)|0]=d;return}else{gg[c[f+196648+(g<<2)>>2]&4095](b,d);return}}function LH(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;if((c[2276078]&256|0)==0){n=((c[2276076]|0)!=0)<<31>>31}else{n=0}l=c[2276085]&g>>>((f<<3&16^16)>>>0)<<16>>16;f=l&16777215;g=c[2112932]|0;m=c[g+((f>>>10|16384)<<2)>>2]|0;if(m>>>0>9){a[m+(l&1023^1)|0]=n;return}else{gg[c[g+196648+(m<<2)>>2]&4095](f,n);return}}function LI(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;if((c[2276078]&256|0)==0){u=((c[2276076]|0)!=0)<<31>>31}else{u=0}r=c[2276085]&q;q=r&16777215;t=c[2112932]|0;h=c[t+((q>>>10|16384)<<2)>>2]|0;if(h>>>0>9){a[h+(r&1023^1)|0]=u;return}else{gg[c[t+196648+(h<<2)>>2]&4095](q,u);return}}function LJ(){var b=0,d=0,e=0,f=0,g=0;if((c[2276078]&256|0)==0){b=((c[2276076]|0)==0)<<31>>31}else{b=-1}d=c[2276085]&c[9104156+((c[2276069]&7|8)<<2)>>2];e=d&16777215;f=c[2112932]|0;g=c[f+((e>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(d&1023^1)|0]=b;return}else{gg[c[f+196648+(g<<2)>>2]&4095](e,b);return}}function LK(){var b=0,d=0,e=0,f=0,g=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;if((c[2276078]&256|0)==0){e=((c[2276076]|0)==0)<<31>>31}else{e=-1}b=c[2276085]&d;d=b&16777215;f=c[2112932]|0;g=c[f+((d>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(b&1023^1)|0]=e;return}else{gg[c[f+196648+(g<<2)>>2]&4095](d,e);return}}function LL(){var b=0,d=0,e=0,f=0,g=0;b=c[2276054]|0;c[2276054]=b+2;if((c[2276078]&256|0)==0){d=((c[2276076]|0)==0)<<31>>31}else{d=-1}e=c[2276085]&b;b=e&16777215;f=c[2112932]|0;g=c[f+((b>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(e&1023^1)|0]=d;return}else{gg[c[f+196648+(g<<2)>>2]&4095](b,d);return}}function LM(){var b=0,d=0,e=0,f=0,g=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;if((c[2276078]&256|0)==0){e=((c[2276076]|0)==0)<<31>>31}else{e=-1}b=c[2276085]&d;d=b&16777215;f=c[2112932]|0;g=c[f+((d>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(b&1023^1)|0]=e;return}else{gg[c[f+196648+(g<<2)>>2]&4095](d,e);return}}function LN(){var b=0,d=0,e=0,f=0,g=0;b=(c[2276054]|0)-2|0;c[2276054]=b;if((c[2276078]&256|0)==0){d=((c[2276076]|0)==0)<<31>>31}else{d=-1}e=c[2276085]&b;b=e&16777215;f=c[2112932]|0;g=c[f+((b>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(e&1023^1)|0]=d;return}else{gg[c[f+196648+(g<<2)>>2]&4095](b,d);return}}function LO(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;if((c[2276078]&256|0)==0){o=((c[2276076]|0)==0)<<31>>31}else{o=-1}m=c[2276085]&(h>>>((g<<3&16^16)>>>0)<<16>>16)+b;b=m&16777215;g=c[2112932]|0;h=c[g+((b>>>10|16384)<<2)>>2]|0;if(h>>>0>9){a[h+(m&1023^1)|0]=o;return}else{gg[c[g+196648+(h<<2)>>2]&4095](b,o);return}}function LP(){var b=0,d=0,e=0,f=0,g=0;b=Hd(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;if((c[2276078]&256|0)==0){d=((c[2276076]|0)==0)<<31>>31}else{d=-1}e=c[2276085]&b;b=e&16777215;f=c[2112932]|0;g=c[f+((b>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(e&1023^1)|0]=d;return}else{gg[c[f+196648+(g<<2)>>2]&4095](b,d);return}}function LQ(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;if((c[2276078]&256|0)==0){n=((c[2276076]|0)==0)<<31>>31}else{n=-1}l=c[2276085]&g>>>((f<<3&16^16)>>>0)<<16>>16;f=l&16777215;g=c[2112932]|0;m=c[g+((f>>>10|16384)<<2)>>2]|0;if(m>>>0>9){a[m+(l&1023^1)|0]=n;return}else{gg[c[g+196648+(m<<2)>>2]&4095](f,n);return}}function LR(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;if((c[2276078]&256|0)==0){u=((c[2276076]|0)==0)<<31>>31}else{u=-1}r=c[2276085]&q;q=r&16777215;t=c[2112932]|0;h=c[t+((q>>>10|16384)<<2)>>2]|0;if(h>>>0>9){a[h+(r&1023^1)|0]=u;return}else{gg[c[t+196648+(h<<2)>>2]&4095](q,u);return}}function LS(){var b=0,d=0,e=0,f=0,g=0;b=c[2276085]&c[9104156+((c[2276069]&7|8)<<2)>>2];d=((c[2276078]|0)>>>8&1)+255&255;e=b&16777215;f=c[2112932]|0;g=c[f+((e>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(b&1023^1)|0]=d;return}else{gg[c[f+196648+(g<<2)>>2]&4095](e,d);return}}function LT(){var b=0,d=0,e=0,f=0,g=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;b=c[2276085]&d;d=((c[2276078]|0)>>>8&1)+255&255;e=b&16777215;f=c[2112932]|0;g=c[f+((e>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(b&1023^1)|0]=d;return}else{gg[c[f+196648+(g<<2)>>2]&4095](e,d);return}}function LU(){var b=0,d=0,e=0,f=0,g=0;b=c[2276054]|0;c[2276054]=b+2;d=c[2276085]&b;b=((c[2276078]|0)>>>8&1)+255&255;e=d&16777215;f=c[2112932]|0;g=c[f+((e>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(d&1023^1)|0]=b;return}else{gg[c[f+196648+(g<<2)>>2]&4095](e,b);return}}function LV(){var b=0,d=0,e=0,f=0,g=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;b=c[2276085]&d;d=((c[2276078]|0)>>>8&1)+255&255;e=b&16777215;f=c[2112932]|0;g=c[f+((e>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(b&1023^1)|0]=d;return}else{gg[c[f+196648+(g<<2)>>2]&4095](e,d);return}}function LW(){var b=0,d=0,e=0,f=0,g=0;b=(c[2276054]|0)-2|0;c[2276054]=b;d=c[2276085]&b;b=((c[2276078]|0)>>>8&1)+255&255;e=d&16777215;f=c[2112932]|0;g=c[f+((e>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(d&1023^1)|0]=b;return}else{gg[c[f+196648+(g<<2)>>2]&4095](e,b);return}}function LX(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=(h>>>((g<<3&16^16)>>>0)<<16>>16)+b&c[2276085];b=((c[2276078]|0)>>>8&1)+255&255;g=m&16777215;h=c[2112932]|0;n=c[h+((g>>>10|16384)<<2)>>2]|0;if(n>>>0>9){a[n+(m&1023^1)|0]=b;return}else{gg[c[h+196648+(n<<2)>>2]&4095](g,b);return}}function LY(){var b=0,d=0,e=0,f=0,g=0;b=Hd(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;d=c[2276085]&b;b=((c[2276078]|0)>>>8&1)+255&255;e=d&16777215;f=c[2112932]|0;g=c[f+((e>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(d&1023^1)|0]=b;return}else{gg[c[f+196648+(g<<2)>>2]&4095](e,b);return}}function LZ(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)<<16>>16&c[2276085];f=((c[2276078]|0)>>>8&1)+255&255;g=l&16777215;m=c[2112932]|0;b=c[m+((g>>>10|16384)<<2)>>2]|0;if(b>>>0>9){a[b+(l&1023^1)|0]=f;return}else{gg[c[m+196648+(b<<2)>>2]&4095](g,f);return}}function L_(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[2276085]&q;q=((c[2276078]|0)>>>8&1)+255&255;t=r&16777215;h=c[2112932]|0;s=c[h+((t>>>10|16384)<<2)>>2]|0;if(s>>>0>9){a[s+(r&1023^1)|0]=q;return}else{gg[c[h+196648+(s<<2)>>2]&4095](t,q);return}}function L$(){var b=0,d=0,e=0,f=0,g=0;b=c[2276085]&c[9104156+((c[2276069]&7|8)<<2)>>2];d=c[2276078]<<23>>31&255;e=b&16777215;f=c[2112932]|0;g=c[f+((e>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(b&1023^1)|0]=d;return}else{gg[c[f+196648+(g<<2)>>2]&4095](e,d);return}}function L0(){var b=0,d=0,e=0,f=0,g=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;b=c[2276085]&d;d=c[2276078]<<23>>31&255;e=b&16777215;f=c[2112932]|0;g=c[f+((e>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(b&1023^1)|0]=d;return}else{gg[c[f+196648+(g<<2)>>2]&4095](e,d);return}}function L1(){var b=0,d=0,e=0,f=0,g=0;b=c[2276054]|0;c[2276054]=b+2;d=c[2276085]&b;b=c[2276078]<<23>>31&255;e=d&16777215;f=c[2112932]|0;g=c[f+((e>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(d&1023^1)|0]=b;return}else{gg[c[f+196648+(g<<2)>>2]&4095](e,b);return}}function L2(){var b=0,d=0,e=0,f=0,g=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;b=c[2276085]&d;d=c[2276078]<<23>>31&255;e=b&16777215;f=c[2112932]|0;g=c[f+((e>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(b&1023^1)|0]=d;return}else{gg[c[f+196648+(g<<2)>>2]&4095](e,d);return}}function L3(){var b=0,d=0,e=0,f=0,g=0;b=(c[2276054]|0)-2|0;c[2276054]=b;d=c[2276085]&b;b=c[2276078]<<23>>31&255;e=d&16777215;f=c[2112932]|0;g=c[f+((e>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(d&1023^1)|0]=b;return}else{gg[c[f+196648+(g<<2)>>2]&4095](e,b);return}}function L4(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=(h>>>((g<<3&16^16)>>>0)<<16>>16)+b&c[2276085];b=c[2276078]<<23>>31&255;g=m&16777215;h=c[2112932]|0;n=c[h+((g>>>10|16384)<<2)>>2]|0;if(n>>>0>9){a[n+(m&1023^1)|0]=b;return}else{gg[c[h+196648+(n<<2)>>2]&4095](g,b);return}}function L5(){var b=0,d=0,e=0,f=0,g=0;b=Hd(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;d=c[2276085]&b;b=c[2276078]<<23>>31&255;e=d&16777215;f=c[2112932]|0;g=c[f+((e>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(d&1023^1)|0]=b;return}else{gg[c[f+196648+(g<<2)>>2]&4095](e,b);return}}function L6(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)<<16>>16&c[2276085];f=c[2276078]<<23>>31&255;g=l&16777215;m=c[2112932]|0;b=c[m+((g>>>10|16384)<<2)>>2]|0;if(b>>>0>9){a[b+(l&1023^1)|0]=f;return}else{gg[c[m+196648+(b<<2)>>2]&4095](g,f);return}}function L7(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[2276085]&q;q=c[2276078]<<23>>31&255;t=r&16777215;h=c[2112932]|0;s=c[h+((t>>>10|16384)<<2)>>2]|0;if(s>>>0>9){a[s+(r&1023^1)|0]=q;return}else{gg[c[h+196648+(s<<2)>>2]&4095](t,q);return}}function L8(){var b=0,d=0,e=0,f=0,g=0;b=c[2276085]&c[9104156+((c[2276069]&7|8)<<2)>>2];d=((c[2276076]|0)!=0)<<31>>31;e=b&16777215;f=c[2112932]|0;g=c[f+((e>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(b&1023^1)|0]=d;return}else{gg[c[f+196648+(g<<2)>>2]&4095](e,d);return}}function L9(){var b=0,d=0,e=0,f=0,g=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;b=c[2276085]&d;d=((c[2276076]|0)!=0)<<31>>31;e=b&16777215;f=c[2112932]|0;g=c[f+((e>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(b&1023^1)|0]=d;return}else{gg[c[f+196648+(g<<2)>>2]&4095](e,d);return}}function Ma(){var b=0,d=0,e=0,f=0,g=0;b=c[2276054]|0;c[2276054]=b+2;d=c[2276085]&b;b=((c[2276076]|0)!=0)<<31>>31;e=d&16777215;f=c[2112932]|0;g=c[f+((e>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(d&1023^1)|0]=b;return}else{gg[c[f+196648+(g<<2)>>2]&4095](e,b);return}}function Mb(){var b=0,d=0,e=0,f=0,g=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;b=c[2276085]&d;d=((c[2276076]|0)!=0)<<31>>31;e=b&16777215;f=c[2112932]|0;g=c[f+((e>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(b&1023^1)|0]=d;return}else{gg[c[f+196648+(g<<2)>>2]&4095](e,d);return}}function Mc(){var b=0,d=0,e=0,f=0,g=0;b=(c[2276054]|0)-2|0;c[2276054]=b;d=c[2276085]&b;b=((c[2276076]|0)!=0)<<31>>31;e=d&16777215;f=c[2112932]|0;g=c[f+((e>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(d&1023^1)|0]=b;return}else{gg[c[f+196648+(g<<2)>>2]&4095](e,b);return}}function Md(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=(h>>>((g<<3&16^16)>>>0)<<16>>16)+b&c[2276085];b=((c[2276076]|0)!=0)<<31>>31;g=m&16777215;h=c[2112932]|0;n=c[h+((g>>>10|16384)<<2)>>2]|0;if(n>>>0>9){a[n+(m&1023^1)|0]=b;return}else{gg[c[h+196648+(n<<2)>>2]&4095](g,b);return}}function Me(){var b=0,d=0,e=0,f=0,g=0;b=Hd(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;d=c[2276085]&b;b=((c[2276076]|0)!=0)<<31>>31;e=d&16777215;f=c[2112932]|0;g=c[f+((e>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(d&1023^1)|0]=b;return}else{gg[c[f+196648+(g<<2)>>2]&4095](e,b);return}}function Mf(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)<<16>>16&c[2276085];f=((c[2276076]|0)!=0)<<31>>31;g=l&16777215;m=c[2112932]|0;b=c[m+((g>>>10|16384)<<2)>>2]|0;if(b>>>0>9){a[b+(l&1023^1)|0]=f;return}else{gg[c[m+196648+(b<<2)>>2]&4095](g,f);return}}function Mg(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[2276085]&q;q=((c[2276076]|0)!=0)<<31>>31;t=r&16777215;h=c[2112932]|0;s=c[h+((t>>>10|16384)<<2)>>2]|0;if(s>>>0>9){a[s+(r&1023^1)|0]=q;return}else{gg[c[h+196648+(s<<2)>>2]&4095](t,q);return}}function Mh(){var b=0,d=0,e=0,f=0,g=0;b=c[2276085]&c[9104156+((c[2276069]&7|8)<<2)>>2];d=((c[2276076]|0)==0)<<31>>31;e=b&16777215;f=c[2112932]|0;g=c[f+((e>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(b&1023^1)|0]=d;return}else{gg[c[f+196648+(g<<2)>>2]&4095](e,d);return}}function Mi(){var b=0,d=0,e=0,f=0,g=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;b=c[2276085]&d;d=((c[2276076]|0)==0)<<31>>31;e=b&16777215;f=c[2112932]|0;g=c[f+((e>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(b&1023^1)|0]=d;return}else{gg[c[f+196648+(g<<2)>>2]&4095](e,d);return}}function Mj(){var b=0,d=0,e=0,f=0,g=0;b=c[2276054]|0;c[2276054]=b+2;d=c[2276085]&b;b=((c[2276076]|0)==0)<<31>>31;e=d&16777215;f=c[2112932]|0;g=c[f+((e>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(d&1023^1)|0]=b;return}else{gg[c[f+196648+(g<<2)>>2]&4095](e,b);return}}function Mk(){var b=0,d=0,e=0,f=0,g=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;b=c[2276085]&d;d=((c[2276076]|0)==0)<<31>>31;e=b&16777215;f=c[2112932]|0;g=c[f+((e>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(b&1023^1)|0]=d;return}else{gg[c[f+196648+(g<<2)>>2]&4095](e,d);return}}function Ml(){var b=0,d=0,e=0,f=0,g=0;b=(c[2276054]|0)-2|0;c[2276054]=b;d=c[2276085]&b;b=((c[2276076]|0)==0)<<31>>31;e=d&16777215;f=c[2112932]|0;g=c[f+((e>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(d&1023^1)|0]=b;return}else{gg[c[f+196648+(g<<2)>>2]&4095](e,b);return}}function Mm(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=(h>>>((g<<3&16^16)>>>0)<<16>>16)+b&c[2276085];b=((c[2276076]|0)==0)<<31>>31;g=m&16777215;h=c[2112932]|0;n=c[h+((g>>>10|16384)<<2)>>2]|0;if(n>>>0>9){a[n+(m&1023^1)|0]=b;return}else{gg[c[h+196648+(n<<2)>>2]&4095](g,b);return}}function Mn(){var b=0,d=0,e=0,f=0,g=0;b=Hd(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;d=c[2276085]&b;b=((c[2276076]|0)==0)<<31>>31;e=d&16777215;f=c[2112932]|0;g=c[f+((e>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(d&1023^1)|0]=b;return}else{gg[c[f+196648+(g<<2)>>2]&4095](e,b);return}}function Mo(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)<<16>>16&c[2276085];f=((c[2276076]|0)==0)<<31>>31;g=l&16777215;m=c[2112932]|0;b=c[m+((g>>>10|16384)<<2)>>2]|0;if(b>>>0>9){a[b+(l&1023^1)|0]=f;return}else{gg[c[m+196648+(b<<2)>>2]&4095](g,f);return}}function Mp(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[2276085]&q;q=((c[2276076]|0)==0)<<31>>31;t=r&16777215;h=c[2112932]|0;s=c[h+((t>>>10|16384)<<2)>>2]|0;if(s>>>0>9){a[s+(r&1023^1)|0]=q;return}else{gg[c[h+196648+(s<<2)>>2]&4095](t,q);return}}function Mq(){var b=0,d=0,e=0,f=0,g=0;b=c[2276085]&c[9104156+((c[2276069]&7|8)<<2)>>2];d=((c[2276077]|0)>>>7&1)+255&255;e=b&16777215;f=c[2112932]|0;g=c[f+((e>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(b&1023^1)|0]=d;return}else{gg[c[f+196648+(g<<2)>>2]&4095](e,d);return}}function Mr(){var b=0,d=0,e=0,f=0,g=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;b=c[2276085]&d;d=((c[2276077]|0)>>>7&1)+255&255;e=b&16777215;f=c[2112932]|0;g=c[f+((e>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(b&1023^1)|0]=d;return}else{gg[c[f+196648+(g<<2)>>2]&4095](e,d);return}}function Ms(){var b=0,d=0,e=0,f=0,g=0;b=c[2276054]|0;c[2276054]=b+2;d=c[2276085]&b;b=((c[2276077]|0)>>>7&1)+255&255;e=d&16777215;f=c[2112932]|0;g=c[f+((e>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(d&1023^1)|0]=b;return}else{gg[c[f+196648+(g<<2)>>2]&4095](e,b);return}}function Mt(){var b=0,d=0,e=0,f=0,g=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;b=c[2276085]&d;d=((c[2276077]|0)>>>7&1)+255&255;e=b&16777215;f=c[2112932]|0;g=c[f+((e>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(b&1023^1)|0]=d;return}else{gg[c[f+196648+(g<<2)>>2]&4095](e,d);return}}function Mu(){var b=0,d=0,e=0,f=0,g=0;b=(c[2276054]|0)-2|0;c[2276054]=b;d=c[2276085]&b;b=((c[2276077]|0)>>>7&1)+255&255;e=d&16777215;f=c[2112932]|0;g=c[f+((e>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(d&1023^1)|0]=b;return}else{gg[c[f+196648+(g<<2)>>2]&4095](e,b);return}}function Mv(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=(h>>>((g<<3&16^16)>>>0)<<16>>16)+b&c[2276085];b=((c[2276077]|0)>>>7&1)+255&255;g=m&16777215;h=c[2112932]|0;n=c[h+((g>>>10|16384)<<2)>>2]|0;if(n>>>0>9){a[n+(m&1023^1)|0]=b;return}else{gg[c[h+196648+(n<<2)>>2]&4095](g,b);return}}function Mw(){var b=0,d=0,e=0,f=0,g=0;b=Hd(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;d=c[2276085]&b;b=((c[2276077]|0)>>>7&1)+255&255;e=d&16777215;f=c[2112932]|0;g=c[f+((e>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(d&1023^1)|0]=b;return}else{gg[c[f+196648+(g<<2)>>2]&4095](e,b);return}}function Mx(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)<<16>>16&c[2276085];f=((c[2276077]|0)>>>7&1)+255&255;g=l&16777215;m=c[2112932]|0;b=c[m+((g>>>10|16384)<<2)>>2]|0;if(b>>>0>9){a[b+(l&1023^1)|0]=f;return}else{gg[c[m+196648+(b<<2)>>2]&4095](g,f);return}}function My(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[2276085]&q;q=((c[2276077]|0)>>>7&1)+255&255;t=r&16777215;h=c[2112932]|0;s=c[h+((t>>>10|16384)<<2)>>2]|0;if(s>>>0>9){a[s+(r&1023^1)|0]=q;return}else{gg[c[h+196648+(s<<2)>>2]&4095](t,q);return}}function Mz(){var b=0,d=0,e=0,f=0,g=0;b=c[2276085]&c[9104156+((c[2276069]&7|8)<<2)>>2];d=c[2276077]<<24>>31&255;e=b&16777215;f=c[2112932]|0;g=c[f+((e>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(b&1023^1)|0]=d;return}else{gg[c[f+196648+(g<<2)>>2]&4095](e,d);return}}function MA(){var b=0,d=0,e=0,f=0,g=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;b=c[2276085]&d;d=c[2276077]<<24>>31&255;e=b&16777215;f=c[2112932]|0;g=c[f+((e>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(b&1023^1)|0]=d;return}else{gg[c[f+196648+(g<<2)>>2]&4095](e,d);return}}function MB(){var b=0,d=0,e=0,f=0,g=0;b=c[2276054]|0;c[2276054]=b+2;d=c[2276085]&b;b=c[2276077]<<24>>31&255;e=d&16777215;f=c[2112932]|0;g=c[f+((e>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(d&1023^1)|0]=b;return}else{gg[c[f+196648+(g<<2)>>2]&4095](e,b);return}}function MC(){var b=0,d=0,e=0,f=0,g=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;b=c[2276085]&d;d=c[2276077]<<24>>31&255;e=b&16777215;f=c[2112932]|0;g=c[f+((e>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(b&1023^1)|0]=d;return}else{gg[c[f+196648+(g<<2)>>2]&4095](e,d);return}}function MD(){var b=0,d=0,e=0,f=0,g=0;b=(c[2276054]|0)-2|0;c[2276054]=b;d=c[2276085]&b;b=c[2276077]<<24>>31&255;e=d&16777215;f=c[2112932]|0;g=c[f+((e>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(d&1023^1)|0]=b;return}else{gg[c[f+196648+(g<<2)>>2]&4095](e,b);return}}function ME(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=(h>>>((g<<3&16^16)>>>0)<<16>>16)+b&c[2276085];b=c[2276077]<<24>>31&255;g=m&16777215;h=c[2112932]|0;n=c[h+((g>>>10|16384)<<2)>>2]|0;if(n>>>0>9){a[n+(m&1023^1)|0]=b;return}else{gg[c[h+196648+(n<<2)>>2]&4095](g,b);return}}function MF(){var b=0,d=0,e=0,f=0,g=0;b=Hd(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;d=c[2276085]&b;b=c[2276077]<<24>>31&255;e=d&16777215;f=c[2112932]|0;g=c[f+((e>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(d&1023^1)|0]=b;return}else{gg[c[f+196648+(g<<2)>>2]&4095](e,b);return}}function MG(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)<<16>>16&c[2276085];f=c[2276077]<<24>>31&255;g=l&16777215;m=c[2112932]|0;b=c[m+((g>>>10|16384)<<2)>>2]|0;if(b>>>0>9){a[b+(l&1023^1)|0]=f;return}else{gg[c[m+196648+(b<<2)>>2]&4095](g,f);return}}function MH(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[2276085]&q;q=c[2276077]<<24>>31&255;t=r&16777215;h=c[2112932]|0;s=c[h+((t>>>10|16384)<<2)>>2]|0;if(s>>>0>9){a[s+(r&1023^1)|0]=q;return}else{gg[c[h+196648+(s<<2)>>2]&4095](t,q);return}}function MI(){var b=0,d=0,e=0,f=0,g=0;b=c[2276085]&c[9104156+((c[2276069]&7|8)<<2)>>2];d=((c[2276075]|0)>>>7&1)+255&255;e=b&16777215;f=c[2112932]|0;g=c[f+((e>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(b&1023^1)|0]=d;return}else{gg[c[f+196648+(g<<2)>>2]&4095](e,d);return}}function MJ(){var b=0,d=0,e=0,f=0,g=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;b=c[2276085]&d;d=((c[2276075]|0)>>>7&1)+255&255;e=b&16777215;f=c[2112932]|0;g=c[f+((e>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(b&1023^1)|0]=d;return}else{gg[c[f+196648+(g<<2)>>2]&4095](e,d);return}}function MK(){var b=0,d=0,e=0,f=0,g=0;b=c[2276054]|0;c[2276054]=b+2;d=c[2276085]&b;b=((c[2276075]|0)>>>7&1)+255&255;e=d&16777215;f=c[2112932]|0;g=c[f+((e>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(d&1023^1)|0]=b;return}else{gg[c[f+196648+(g<<2)>>2]&4095](e,b);return}}function ML(){var b=0,d=0,e=0,f=0,g=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;b=c[2276085]&d;d=((c[2276075]|0)>>>7&1)+255&255;e=b&16777215;f=c[2112932]|0;g=c[f+((e>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(b&1023^1)|0]=d;return}else{gg[c[f+196648+(g<<2)>>2]&4095](e,d);return}}function MM(){var b=0,d=0,e=0,f=0,g=0;b=(c[2276054]|0)-2|0;c[2276054]=b;d=c[2276085]&b;b=((c[2276075]|0)>>>7&1)+255&255;e=d&16777215;f=c[2112932]|0;g=c[f+((e>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(d&1023^1)|0]=b;return}else{gg[c[f+196648+(g<<2)>>2]&4095](e,b);return}}function MN(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=(h>>>((g<<3&16^16)>>>0)<<16>>16)+b&c[2276085];b=((c[2276075]|0)>>>7&1)+255&255;g=m&16777215;h=c[2112932]|0;n=c[h+((g>>>10|16384)<<2)>>2]|0;if(n>>>0>9){a[n+(m&1023^1)|0]=b;return}else{gg[c[h+196648+(n<<2)>>2]&4095](g,b);return}}function MO(){var b=0,d=0,e=0,f=0,g=0;b=Hd(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;d=c[2276085]&b;b=((c[2276075]|0)>>>7&1)+255&255;e=d&16777215;f=c[2112932]|0;g=c[f+((e>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(d&1023^1)|0]=b;return}else{gg[c[f+196648+(g<<2)>>2]&4095](e,b);return}}function MP(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)<<16>>16&c[2276085];f=((c[2276075]|0)>>>7&1)+255&255;g=l&16777215;m=c[2112932]|0;b=c[m+((g>>>10|16384)<<2)>>2]|0;if(b>>>0>9){a[b+(l&1023^1)|0]=f;return}else{gg[c[m+196648+(b<<2)>>2]&4095](g,f);return}}function MQ(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[2276085]&q;q=((c[2276075]|0)>>>7&1)+255&255;t=r&16777215;h=c[2112932]|0;s=c[h+((t>>>10|16384)<<2)>>2]|0;if(s>>>0>9){a[s+(r&1023^1)|0]=q;return}else{gg[c[h+196648+(s<<2)>>2]&4095](t,q);return}}function MR(){var b=0,d=0,e=0,f=0,g=0;b=c[2276085]&c[9104156+((c[2276069]&7|8)<<2)>>2];d=c[2276075]<<24>>31&255;e=b&16777215;f=c[2112932]|0;g=c[f+((e>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(b&1023^1)|0]=d;return}else{gg[c[f+196648+(g<<2)>>2]&4095](e,d);return}}function MS(){var b=0,d=0,e=0,f=0,g=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;b=c[2276085]&d;d=c[2276075]<<24>>31&255;e=b&16777215;f=c[2112932]|0;g=c[f+((e>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(b&1023^1)|0]=d;return}else{gg[c[f+196648+(g<<2)>>2]&4095](e,d);return}}function MT(){var b=0,d=0,e=0,f=0,g=0;b=c[2276054]|0;c[2276054]=b+2;d=c[2276085]&b;b=c[2276075]<<24>>31&255;e=d&16777215;f=c[2112932]|0;g=c[f+((e>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(d&1023^1)|0]=b;return}else{gg[c[f+196648+(g<<2)>>2]&4095](e,b);return}}function MU(){var b=0,d=0,e=0,f=0,g=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;b=c[2276085]&d;d=c[2276075]<<24>>31&255;e=b&16777215;f=c[2112932]|0;g=c[f+((e>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(b&1023^1)|0]=d;return}else{gg[c[f+196648+(g<<2)>>2]&4095](e,d);return}}function MV(){var b=0,d=0,e=0,f=0,g=0;b=(c[2276054]|0)-2|0;c[2276054]=b;d=c[2276085]&b;b=c[2276075]<<24>>31&255;e=d&16777215;f=c[2112932]|0;g=c[f+((e>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(d&1023^1)|0]=b;return}else{gg[c[f+196648+(g<<2)>>2]&4095](e,b);return}}function MW(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=(h>>>((g<<3&16^16)>>>0)<<16>>16)+b&c[2276085];b=c[2276075]<<24>>31&255;g=m&16777215;h=c[2112932]|0;n=c[h+((g>>>10|16384)<<2)>>2]|0;if(n>>>0>9){a[n+(m&1023^1)|0]=b;return}else{gg[c[h+196648+(n<<2)>>2]&4095](g,b);return}}function MX(){var b=0,d=0,e=0,f=0,g=0;b=Hd(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;d=c[2276085]&b;b=c[2276075]<<24>>31&255;e=d&16777215;f=c[2112932]|0;g=c[f+((e>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(d&1023^1)|0]=b;return}else{gg[c[f+196648+(g<<2)>>2]&4095](e,b);return}}function MY(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)<<16>>16&c[2276085];f=c[2276075]<<24>>31&255;g=l&16777215;m=c[2112932]|0;b=c[m+((g>>>10|16384)<<2)>>2]|0;if(b>>>0>9){a[b+(l&1023^1)|0]=f;return}else{gg[c[m+196648+(b<<2)>>2]&4095](g,f);return}}function MZ(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[2276085]&q;q=c[2276075]<<24>>31&255;t=r&16777215;h=c[2112932]|0;s=c[h+((t>>>10|16384)<<2)>>2]|0;if(s>>>0>9){a[s+(r&1023^1)|0]=q;return}else{gg[c[h+196648+(s<<2)>>2]&4095](t,q);return}}function M_(){var b=0,d=0,e=0,f=0,g=0;b=c[2276085]&c[9104156+((c[2276069]&7|8)<<2)>>2];d=((c[2276077]^c[2276075])>>>7&1)+255&255;e=b&16777215;f=c[2112932]|0;g=c[f+((e>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(b&1023^1)|0]=d;return}else{gg[c[f+196648+(g<<2)>>2]&4095](e,d);return}}function M$(){var b=0,d=0,e=0,f=0,g=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;b=c[2276085]&d;d=((c[2276077]^c[2276075])>>>7&1)+255&255;e=b&16777215;f=c[2112932]|0;g=c[f+((e>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(b&1023^1)|0]=d;return}else{gg[c[f+196648+(g<<2)>>2]&4095](e,d);return}}function M0(){var b=0,d=0,e=0,f=0,g=0;b=c[2276054]|0;c[2276054]=b+2;d=c[2276085]&b;b=((c[2276077]^c[2276075])>>>7&1)+255&255;e=d&16777215;f=c[2112932]|0;g=c[f+((e>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(d&1023^1)|0]=b;return}else{gg[c[f+196648+(g<<2)>>2]&4095](e,b);return}}function M1(){var b=0,d=0,e=0,f=0,g=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;b=c[2276085]&d;d=((c[2276077]^c[2276075])>>>7&1)+255&255;e=b&16777215;f=c[2112932]|0;g=c[f+((e>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(b&1023^1)|0]=d;return}else{gg[c[f+196648+(g<<2)>>2]&4095](e,d);return}}function M2(){var b=0,d=0,e=0,f=0,g=0;b=(c[2276054]|0)-2|0;c[2276054]=b;d=c[2276085]&b;b=((c[2276077]^c[2276075])>>>7&1)+255&255;e=d&16777215;f=c[2112932]|0;g=c[f+((e>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(d&1023^1)|0]=b;return}else{gg[c[f+196648+(g<<2)>>2]&4095](e,b);return}}function M3(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=(h>>>((g<<3&16^16)>>>0)<<16>>16)+b&c[2276085];b=((c[2276077]^c[2276075])>>>7&1)+255&255;g=m&16777215;h=c[2112932]|0;n=c[h+((g>>>10|16384)<<2)>>2]|0;if(n>>>0>9){a[n+(m&1023^1)|0]=b;return}else{gg[c[h+196648+(n<<2)>>2]&4095](g,b);return}}function M4(){var b=0,d=0,e=0,f=0,g=0;b=Hd(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;d=c[2276085]&b;b=((c[2276077]^c[2276075])>>>7&1)+255&255;e=d&16777215;f=c[2112932]|0;g=c[f+((e>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(d&1023^1)|0]=b;return}else{gg[c[f+196648+(g<<2)>>2]&4095](e,b);return}}function M5(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)<<16>>16&c[2276085];f=((c[2276077]^c[2276075])>>>7&1)+255&255;g=l&16777215;m=c[2112932]|0;b=c[m+((g>>>10|16384)<<2)>>2]|0;if(b>>>0>9){a[b+(l&1023^1)|0]=f;return}else{gg[c[m+196648+(b<<2)>>2]&4095](g,f);return}}function M6(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[2276085]&q;q=((c[2276077]^c[2276075])>>>7&1)+255&255;t=r&16777215;h=c[2112932]|0;s=c[h+((t>>>10|16384)<<2)>>2]|0;if(s>>>0>9){a[s+(r&1023^1)|0]=q;return}else{gg[c[h+196648+(s<<2)>>2]&4095](t,q);return}}function M7(){var b=0,d=0,e=0,f=0,g=0;b=c[2276085]&c[9104156+((c[2276069]&7|8)<<2)>>2];d=(c[2276077]^c[2276075])<<24>>31&255;e=b&16777215;f=c[2112932]|0;g=c[f+((e>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(b&1023^1)|0]=d;return}else{gg[c[f+196648+(g<<2)>>2]&4095](e,d);return}}function M8(){var b=0,d=0,e=0,f=0,g=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;b=c[2276085]&d;d=(c[2276077]^c[2276075])<<24>>31&255;e=b&16777215;f=c[2112932]|0;g=c[f+((e>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(b&1023^1)|0]=d;return}else{gg[c[f+196648+(g<<2)>>2]&4095](e,d);return}}function M9(){var b=0,d=0,e=0,f=0,g=0;b=c[2276054]|0;c[2276054]=b+2;d=c[2276085]&b;b=(c[2276077]^c[2276075])<<24>>31&255;e=d&16777215;f=c[2112932]|0;g=c[f+((e>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(d&1023^1)|0]=b;return}else{gg[c[f+196648+(g<<2)>>2]&4095](e,b);return}}function Na(){var b=0,d=0,e=0,f=0,g=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;b=c[2276085]&d;d=(c[2276077]^c[2276075])<<24>>31&255;e=b&16777215;f=c[2112932]|0;g=c[f+((e>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(b&1023^1)|0]=d;return}else{gg[c[f+196648+(g<<2)>>2]&4095](e,d);return}}function Nb(){var b=0,d=0,e=0,f=0,g=0;b=(c[2276054]|0)-2|0;c[2276054]=b;d=c[2276085]&b;b=(c[2276077]^c[2276075])<<24>>31&255;e=d&16777215;f=c[2112932]|0;g=c[f+((e>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(d&1023^1)|0]=b;return}else{gg[c[f+196648+(g<<2)>>2]&4095](e,b);return}}function Nc(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=(h>>>((g<<3&16^16)>>>0)<<16>>16)+b&c[2276085];b=(c[2276077]^c[2276075])<<24>>31&255;g=m&16777215;h=c[2112932]|0;n=c[h+((g>>>10|16384)<<2)>>2]|0;if(n>>>0>9){a[n+(m&1023^1)|0]=b;return}else{gg[c[h+196648+(n<<2)>>2]&4095](g,b);return}}function Nd(){var b=0,d=0,e=0,f=0,g=0;b=Hd(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;d=c[2276085]&b;b=(c[2276077]^c[2276075])<<24>>31&255;e=d&16777215;f=c[2112932]|0;g=c[f+((e>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(d&1023^1)|0]=b;return}else{gg[c[f+196648+(g<<2)>>2]&4095](e,b);return}}function Ne(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)<<16>>16&c[2276085];f=(c[2276077]^c[2276075])<<24>>31&255;g=l&16777215;m=c[2112932]|0;b=c[m+((g>>>10|16384)<<2)>>2]|0;if(b>>>0>9){a[b+(l&1023^1)|0]=f;return}else{gg[c[m+196648+(b<<2)>>2]&4095](g,f);return}}function Nf(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[2276085]&q;q=(c[2276077]^c[2276075])<<24>>31&255;t=r&16777215;h=c[2112932]|0;s=c[h+((t>>>10|16384)<<2)>>2]|0;if(s>>>0>9){a[s+(r&1023^1)|0]=q;return}else{gg[c[h+196648+(s<<2)>>2]&4095](t,q);return}}function Ng(){var b=0,d=0,e=0,f=0,g=0;if(((c[2276077]^c[2276075])&128|0)==0){b=((c[2276076]|0)!=0)<<31>>31}else{b=0}d=c[2276085]&c[9104156+((c[2276069]&7|8)<<2)>>2];e=d&16777215;f=c[2112932]|0;g=c[f+((e>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(d&1023^1)|0]=b;return}else{gg[c[f+196648+(g<<2)>>2]&4095](e,b);return}}function Nh(){var b=0,d=0,e=0,f=0,g=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;if(((c[2276077]^c[2276075])&128|0)==0){e=((c[2276076]|0)!=0)<<31>>31}else{e=0}b=c[2276085]&d;d=b&16777215;f=c[2112932]|0;g=c[f+((d>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(b&1023^1)|0]=e;return}else{gg[c[f+196648+(g<<2)>>2]&4095](d,e);return}}function Ni(){var b=0,d=0,e=0,f=0,g=0;b=c[2276054]|0;c[2276054]=b+2;if(((c[2276077]^c[2276075])&128|0)==0){d=((c[2276076]|0)!=0)<<31>>31}else{d=0}e=c[2276085]&b;b=e&16777215;f=c[2112932]|0;g=c[f+((b>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(e&1023^1)|0]=d;return}else{gg[c[f+196648+(g<<2)>>2]&4095](b,d);return}}function Nj(){var b=0,d=0,e=0,f=0,g=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;if(((c[2276077]^c[2276075])&128|0)==0){e=((c[2276076]|0)!=0)<<31>>31}else{e=0}b=c[2276085]&d;d=b&16777215;f=c[2112932]|0;g=c[f+((d>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(b&1023^1)|0]=e;return}else{gg[c[f+196648+(g<<2)>>2]&4095](d,e);return}}function Nk(){var b=0,d=0,e=0,f=0,g=0;b=(c[2276054]|0)-2|0;c[2276054]=b;if(((c[2276077]^c[2276075])&128|0)==0){d=((c[2276076]|0)!=0)<<31>>31}else{d=0}e=c[2276085]&b;b=e&16777215;f=c[2112932]|0;g=c[f+((b>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(e&1023^1)|0]=d;return}else{gg[c[f+196648+(g<<2)>>2]&4095](b,d);return}}function Nl(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;if(((c[2276077]^c[2276075])&128|0)==0){o=((c[2276076]|0)!=0)<<31>>31}else{o=0}m=c[2276085]&(h>>>((g<<3&16^16)>>>0)<<16>>16)+b;b=m&16777215;g=c[2112932]|0;h=c[g+((b>>>10|16384)<<2)>>2]|0;if(h>>>0>9){a[h+(m&1023^1)|0]=o;return}else{gg[c[g+196648+(h<<2)>>2]&4095](b,o);return}}function Nm(){var b=0,d=0,e=0,f=0,g=0;b=Hd(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;if(((c[2276077]^c[2276075])&128|0)==0){d=((c[2276076]|0)!=0)<<31>>31}else{d=0}e=c[2276085]&b;b=e&16777215;f=c[2112932]|0;g=c[f+((b>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(e&1023^1)|0]=d;return}else{gg[c[f+196648+(g<<2)>>2]&4095](b,d);return}}function Nn(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;if(((c[2276077]^c[2276075])&128|0)==0){n=((c[2276076]|0)!=0)<<31>>31}else{n=0}l=c[2276085]&g>>>((f<<3&16^16)>>>0)<<16>>16;f=l&16777215;g=c[2112932]|0;m=c[g+((f>>>10|16384)<<2)>>2]|0;if(m>>>0>9){a[m+(l&1023^1)|0]=n;return}else{gg[c[g+196648+(m<<2)>>2]&4095](f,n);return}}function No(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;if(((c[2276077]^c[2276075])&128|0)==0){u=((c[2276076]|0)!=0)<<31>>31}else{u=0}r=c[2276085]&q;q=r&16777215;t=c[2112932]|0;h=c[t+((q>>>10|16384)<<2)>>2]|0;if(h>>>0>9){a[h+(r&1023^1)|0]=u;return}else{gg[c[t+196648+(h<<2)>>2]&4095](q,u);return}}function Np(){var b=0,d=0,e=0,f=0,g=0;if(((c[2276077]^c[2276075])&128|0)==0){b=((c[2276076]|0)==0)<<31>>31}else{b=-1}d=c[2276085]&c[9104156+((c[2276069]&7|8)<<2)>>2];e=d&16777215;f=c[2112932]|0;g=c[f+((e>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(d&1023^1)|0]=b;return}else{gg[c[f+196648+(g<<2)>>2]&4095](e,b);return}}function Nq(){var b=0,d=0,e=0,f=0,g=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;if(((c[2276077]^c[2276075])&128|0)==0){e=((c[2276076]|0)==0)<<31>>31}else{e=-1}b=c[2276085]&d;d=b&16777215;f=c[2112932]|0;g=c[f+((d>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(b&1023^1)|0]=e;return}else{gg[c[f+196648+(g<<2)>>2]&4095](d,e);return}}function Nr(){var b=0,d=0,e=0,f=0,g=0;b=c[2276054]|0;c[2276054]=b+2;if(((c[2276077]^c[2276075])&128|0)==0){d=((c[2276076]|0)==0)<<31>>31}else{d=-1}e=c[2276085]&b;b=e&16777215;f=c[2112932]|0;g=c[f+((b>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(e&1023^1)|0]=d;return}else{gg[c[f+196648+(g<<2)>>2]&4095](b,d);return}}function Ns(){var b=0,d=0,e=0,f=0,g=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;if(((c[2276077]^c[2276075])&128|0)==0){e=((c[2276076]|0)==0)<<31>>31}else{e=-1}b=c[2276085]&d;d=b&16777215;f=c[2112932]|0;g=c[f+((d>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(b&1023^1)|0]=e;return}else{gg[c[f+196648+(g<<2)>>2]&4095](d,e);return}}function Nt(){var b=0,d=0,e=0,f=0,g=0;b=(c[2276054]|0)-2|0;c[2276054]=b;if(((c[2276077]^c[2276075])&128|0)==0){d=((c[2276076]|0)==0)<<31>>31}else{d=-1}e=c[2276085]&b;b=e&16777215;f=c[2112932]|0;g=c[f+((b>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(e&1023^1)|0]=d;return}else{gg[c[f+196648+(g<<2)>>2]&4095](b,d);return}}function Nu(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;if(((c[2276077]^c[2276075])&128|0)==0){o=((c[2276076]|0)==0)<<31>>31}else{o=-1}m=c[2276085]&(h>>>((g<<3&16^16)>>>0)<<16>>16)+b;b=m&16777215;g=c[2112932]|0;h=c[g+((b>>>10|16384)<<2)>>2]|0;if(h>>>0>9){a[h+(m&1023^1)|0]=o;return}else{gg[c[g+196648+(h<<2)>>2]&4095](b,o);return}}function Nv(){var b=0,d=0,e=0,f=0,g=0;b=Hd(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;if(((c[2276077]^c[2276075])&128|0)==0){d=((c[2276076]|0)==0)<<31>>31}else{d=-1}e=c[2276085]&b;b=e&16777215;f=c[2112932]|0;g=c[f+((b>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(e&1023^1)|0]=d;return}else{gg[c[f+196648+(g<<2)>>2]&4095](b,d);return}}function Nw(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;if(((c[2276077]^c[2276075])&128|0)==0){n=((c[2276076]|0)==0)<<31>>31}else{n=-1}l=c[2276085]&g>>>((f<<3&16^16)>>>0)<<16>>16;f=l&16777215;g=c[2112932]|0;m=c[g+((f>>>10|16384)<<2)>>2]|0;if(m>>>0>9){a[m+(l&1023^1)|0]=n;return}else{gg[c[g+196648+(m<<2)>>2]&4095](f,n);return}}function Nx(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;if(((c[2276077]^c[2276075])&128|0)==0){u=((c[2276076]|0)==0)<<31>>31}else{u=-1}r=c[2276085]&q;q=r&16777215;t=c[2112932]|0;h=c[t+((q>>>10|16384)<<2)>>2]|0;if(h>>>0>9){a[h+(r&1023^1)|0]=u;return}else{gg[c[t+196648+(h<<2)>>2]&4095](q,u);return}}function Ny(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if((c[2276072]|0)!=0){b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;c[2276082]=c[2276082]|1;JR(g>>>((f<<3&16^16)>>>0)&65535);n=0;c[2276108]=n;return}f=c[2276073]|0;g=c[2276071]|c[2276070]|f<<11|c[2276079]|(c[2276074]|0)>>>4&16|(c[2276075]|0)>>>4&8|((c[2276076]|0)==0)<<2|(c[2276077]|0)>>>6&2|(c[2276078]|0)>>>8&1;c[2276071]=0;c[2276070]=0;c[2276057]=c[2276054];c[2276072]=4;l=c[9104228+((f&2|4)<<2)>>2]|0;c[2276054]=l;f=c[2276055]|0;do{if(((c[2276038]|0)-1|0)>>>0<2){m=l-4|0;c[2276054]=m;b=c[2276085]&m;m=b&16777215;e=c[2112932]|0;j=c[e+((m>>>10|16384)<<2)>>2]|0;if(j>>>0>9){i=b&1023;a[j+i|0]=f>>>16&255;a[j+(i+1)|0]=f>>>24&255;a[j+(i+2)|0]=f&255;a[j+(i+3)|0]=f>>>8&255;o=e}else{gg[c[e+196808+(j<<2)>>2]&4095](m,f);o=c[2112932]|0}m=(c[2276054]|0)-2|0;c[2276054]=m;j=c[2276085]&m;m=g&65535;e=j&16777215;i=c[o+((e>>>10|16384)<<2)>>2]|0;if(i>>>0>9){b=j&1023;a[i+b|0]=g&255;a[i+(b+1)|0]=(m&65535)>>>8&255;break}else{gg[c[o+196728+(i<<2)>>2]&4095](e,m);break}}else{m=l-2|0;c[2276054]=m;e=c[2276085]&m;m=e&16777215;i=c[2112932]|0;b=c[i+((m>>>10|16384)<<2)>>2]|0;if(b>>>0>9){j=e&1023;a[b+j|0]=32;a[b+(j+1)|0]=0;p=i}else{gg[c[i+196728+(b<<2)>>2]&4095](m,32);p=c[2112932]|0}m=(c[2276054]|0)-4|0;c[2276054]=m;b=c[2276085]&m;m=b&16777215;i=c[p+((m>>>10|16384)<<2)>>2]|0;if(i>>>0>9){j=b&1023;a[i+j|0]=f>>>16&255;a[i+(j+1)|0]=f>>>24&255;a[i+(j+2)|0]=f&255;a[i+(j+3)|0]=f>>>8&255;q=p}else{gg[c[p+196808+(i<<2)>>2]&4095](m,f);q=c[2112932]|0}m=(c[2276054]|0)-2|0;c[2276054]=m;i=c[2276085]&m;m=g&65535;j=i&16777215;b=c[q+((j>>>10|16384)<<2)>>2]|0;if(b>>>0>9){e=i&1023;a[b+e|0]=g&255;a[b+(e+1)|0]=(m&65535)>>>8&255;break}else{gg[c[q+196728+(b<<2)>>2]&4095](j,m);break}}}while(0);q=(c[2276064]|0)+32|0;c[2276056]=q;g=c[2276085]&q;q=g&16777215;f=c[2112932]|0;p=c[f+(q>>>10<<2)>>2]|0;if(p>>>0>9){l=g&1023;r=(d[p+(l+3)|0]|0)<<8|(d[p+(l+2)|0]|0)|((d[p+(l+1)|0]|0)<<8|(d[p+l|0]|0))<<16}else{r=gj[c[f+196768+(p<<2)>>2]&4095](q)|0}c[2276056]=r;n=(d[(c[2276098]|0)+(c[2276069]|0)|0]|0)-(d[(c[2276099]|0)+8|0]|0)+(c[2276108]|0)|0;c[2276108]=n;return}function Nz(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[2276069]|0;b=9104156+((a>>>9&7)<<2)|0;d=c[9104156+((a&7)<<2)>>2]|0;a=d&255;e=c[b>>2]|0;f=e&255;g=f-a|0;c[2276075]=g;c[2276078]=g;c[2276074]=g;c[2276077]=(g^e)&(f^a);a=e-d&255;c[2276076]=a;c[b>>2]=c[b>>2]&-256|a;return}function NA(){var b=0,d=0,e=0,f=0,g=0,h=0;b=c[2276069]|0;d=9104156+((b>>>9&7)<<2)|0;e=c[2276085]&c[9104156+((b&7|8)<<2)>>2];b=e&16777215;f=c[2112932]|0;g=c[f+(b>>>10<<2)>>2]|0;if(g>>>0>9){h=a[g+(e&1023^1)|0]|0}else{h=gj[c[f+196608+(g<<2)>>2]&4095](b)|0}b=h&255;h=c[d>>2]|0;g=h&255;f=g-b|0;c[2276075]=f;c[2276078]=f;c[2276074]=f;c[2276077]=(f^h)&(g^b);g=h-b&255;c[2276076]=g;c[d>>2]=c[d>>2]&-256|g;return}function NB(){var b=0,d=0,e=0,f=0,g=0,h=0;b=c[2276069]|0;d=9104156+((b>>>9&7)<<2)|0;e=9104156+((b&7|8)<<2)|0;b=c[e>>2]|0;c[e>>2]=b+1;e=c[2276085]&b;b=e&16777215;f=c[2112932]|0;g=c[f+(b>>>10<<2)>>2]|0;if(g>>>0>9){h=a[g+(e&1023^1)|0]|0}else{h=gj[c[f+196608+(g<<2)>>2]&4095](b)|0}b=h&255;h=c[d>>2]|0;g=h&255;f=g-b|0;c[2276075]=f;c[2276078]=f;c[2276074]=f;c[2276077]=(f^h)&(g^b);g=h-b&255;c[2276076]=g;c[d>>2]=c[d>>2]&-256|g;return}function NC(){var b=0,d=0,e=0,f=0,g=0,h=0;b=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;d=c[2276054]|0;c[2276054]=d+2;e=c[2276085]&d;d=e&16777215;f=c[2112932]|0;g=c[f+(d>>>10<<2)>>2]|0;if(g>>>0>9){h=a[g+(e&1023^1)|0]|0}else{h=gj[c[f+196608+(g<<2)>>2]&4095](d)|0}d=h&255;h=c[b>>2]|0;g=h&255;f=g-d|0;c[2276075]=f;c[2276078]=f;c[2276074]=f;c[2276077]=(f^h)&(g^d);g=h-d&255;c[2276076]=g;c[b>>2]=c[b>>2]&-256|g;return}function ND(){var b=0,d=0,e=0,f=0,g=0,h=0;b=c[2276069]|0;d=9104156+((b>>>9&7)<<2)|0;e=9104156+((b&7|8)<<2)|0;b=(c[e>>2]|0)-1|0;c[e>>2]=b;e=c[2276085]&b;b=e&16777215;f=c[2112932]|0;g=c[f+(b>>>10<<2)>>2]|0;if(g>>>0>9){h=a[g+(e&1023^1)|0]|0}else{h=gj[c[f+196608+(g<<2)>>2]&4095](b)|0}b=h&255;h=c[d>>2]|0;g=h&255;f=g-b|0;c[2276075]=f;c[2276078]=f;c[2276074]=f;c[2276077]=(f^h)&(g^b);g=h-b&255;c[2276076]=g;c[d>>2]=c[d>>2]&-256|g;return}function NE(){var b=0,d=0,e=0,f=0,g=0,h=0;b=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;d=(c[2276054]|0)-2|0;c[2276054]=d;e=c[2276085]&d;d=e&16777215;f=c[2112932]|0;g=c[f+(d>>>10<<2)>>2]|0;if(g>>>0>9){h=a[g+(e&1023^1)|0]|0}else{h=gj[c[f+196608+(g<<2)>>2]&4095](d)|0}d=h&255;h=c[b>>2]|0;g=h&255;f=g-d|0;c[2276075]=f;c[2276078]=f;c[2276074]=f;c[2276077]=(f^h)&(g^d);g=h-d&255;c[2276076]=g;c[b>>2]=c[b>>2]&-256|g;return}function NF(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;b=c[2276069]|0;e=9104156+((b>>>9&7)<<2)|0;f=c[9104156+((b&7|8)<<2)>>2]|0;b=c[2276056]|0;g=b&-4;if((g|0)==(c[2276083]|0)){h=b;i=c[2276084]|0}else{c[2276083]=g;j=c[2276085]&g;g=j&16777212;k=c[2112932]|0;l=c[k+((g>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=j&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b}else{b=gj[c[k+196768+(l<<2)>>2]&4095](g)|0;n=b;o=c[2276056]|0}c[2276084]=n;h=o;i=n}c[2276056]=h+2;n=(i>>>((h<<3&16^16)>>>0)<<16>>16)+f&c[2276085];f=n&16777215;h=c[2112932]|0;i=c[h+(f>>>10<<2)>>2]|0;if(i>>>0>9){p=a[i+(n&1023^1)|0]|0;q=p&255;r=c[e>>2]|0;s=r&255;t=s-q|0;c[2276075]=t;c[2276078]=t;c[2276074]=t;u=s^q;v=t^r;w=v&u;c[2276077]=w;x=r-q|0;y=x&255;c[2276076]=y;z=c[e>>2]|0;A=z&-256;B=A|y;c[e>>2]=B;return}else{p=gj[c[h+196608+(i<<2)>>2]&4095](f)|0;q=p&255;r=c[e>>2]|0;s=r&255;t=s-q|0;c[2276075]=t;c[2276078]=t;c[2276074]=t;u=s^q;v=t^r;w=v&u;c[2276077]=w;x=r-q|0;y=x&255;c[2276076]=y;z=c[e>>2]|0;A=z&-256;B=A|y;c[e>>2]=B;return}}function NG(){var b=0,d=0,e=0,f=0,g=0,h=0;b=c[2276069]|0;d=9104156+((b>>>9&7)<<2)|0;e=Hd(c[9104156+((b&7|8)<<2)>>2]|0)|0;b=c[2276085]&e;e=b&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=a[g+(b&1023^1)|0]|0}else{h=gj[c[f+196608+(g<<2)>>2]&4095](e)|0}e=h&255;h=c[d>>2]|0;g=h&255;f=g-e|0;c[2276075]=f;c[2276078]=f;c[2276074]=f;c[2276077]=(f^h)&(g^e);g=h-e&255;c[2276076]=g;c[d>>2]=c[d>>2]&-256|g;return}function NH(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;b=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=h>>>((g<<3&16^16)>>>0)<<16>>16&c[2276085];g=m&16777215;h=c[2112932]|0;n=c[h+(g>>>10<<2)>>2]|0;if(n>>>0>9){o=a[n+(m&1023^1)|0]|0;p=o&255;q=c[b>>2]|0;r=q&255;s=r-p|0;c[2276075]=s;c[2276078]=s;c[2276074]=s;t=r^p;u=s^q;v=u&t;c[2276077]=v;w=q-p|0;x=w&255;c[2276076]=x;y=c[b>>2]|0;z=y&-256;A=z|x;c[b>>2]=A;return}else{o=gj[c[h+196608+(n<<2)>>2]&4095](g)|0;p=o&255;q=c[b>>2]|0;r=q&255;s=r-p|0;c[2276075]=s;c[2276078]=s;c[2276074]=s;t=r^p;u=s^q;v=u&t;c[2276077]=v;w=q-p|0;x=w&255;c[2276076]=x;y=c[b>>2]|0;z=y&-256;A=z|x;c[b>>2]=A;return}}function NI(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;b=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=f;i=c[2276084]|0}else{c[2276083]=f;j=c[2276085]&f;k=j&16777212;l=c[2112932]|0;m=c[l+((k>>>10|32768)<<2)>>2]|0;if(m>>>0>9){n=j&1020;o=(d[m+(n|3)|0]|0)<<8|(d[m+(n|2)|0]|0)|((d[m+(n|1)|0]|0)<<8|(d[m+n|0]|0))<<16;p=e;q=f}else{f=gj[c[l+196768+(m<<2)>>2]&4095](k)|0;o=f;p=c[2276056]|0;q=c[2276083]|0}c[2276084]=o;g=p;h=q;i=o}o=g+2|0;c[2276056]=o;g=o&-4;if((g|0)==(h|0)){r=i;s=o}else{c[2276083]=g;h=c[2276085]&g;g=h&16777212;q=c[2112932]|0;p=c[q+((g>>>10|32768)<<2)>>2]|0;if(p>>>0>9){f=h&1020;t=(d[p+(f|3)|0]|0)<<8|(d[p+(f|2)|0]|0)|((d[p+(f|1)|0]|0)<<8|(d[p+f|0]|0))<<16;u=o}else{o=gj[c[q+196768+(p<<2)>>2]&4095](g)|0;t=o;u=c[2276056]|0}c[2276084]=t;r=t>>>16|i<<16;s=u}c[2276056]=s+2;s=c[2276085]&r;r=s&16777215;u=c[2112932]|0;i=c[u+(r>>>10<<2)>>2]|0;if(i>>>0>9){v=a[i+(s&1023^1)|0]|0;w=v&255;x=c[b>>2]|0;y=x&255;z=y-w|0;c[2276075]=z;c[2276078]=z;c[2276074]=z;A=y^w;B=z^x;C=B&A;c[2276077]=C;D=x-w|0;E=D&255;c[2276076]=E;F=c[b>>2]|0;G=F&-256;H=G|E;c[b>>2]=H;return}else{v=gj[c[u+196608+(i<<2)>>2]&4095](r)|0;w=v&255;x=c[b>>2]|0;y=x&255;z=y-w|0;c[2276075]=z;c[2276078]=z;c[2276074]=z;A=y^w;B=z^x;C=B&A;c[2276077]=C;D=x-w|0;E=D&255;c[2276076]=E;F=c[b>>2]|0;G=F&-256;H=G|E;c[b>>2]=H;return}}function NJ(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;b=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{l=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=l;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=(h>>>((g<<3&16^16)>>>0)<<16>>16)+e|0;e=m&16777215;g=c[2112932]|0;h=c[g+((e>>>10|32768)<<2)>>2]|0;if(h>>>0>9){o=a[h+(m&1023^1)|0]|0;p=o&255;q=c[b>>2]|0;r=q&255;s=r-p|0;c[2276075]=s;c[2276078]=s;c[2276074]=s;t=r^p;u=s^q;v=u&t;c[2276077]=v;w=q-p|0;x=w&255;c[2276076]=x;y=c[b>>2]|0;z=y&-256;A=z|x;c[b>>2]=A;return}else{o=gj[c[g+196608+(h<<2)>>2]&4095](e)|0;p=o&255;q=c[b>>2]|0;r=q&255;s=r-p|0;c[2276075]=s;c[2276078]=s;c[2276074]=s;t=r^p;u=s^q;v=u&t;c[2276077]=v;w=q-p|0;x=w&255;c[2276076]=x;y=c[b>>2]|0;z=y&-256;A=z|x;c[b>>2]=A;return}}function NK(){var b=0,d=0,e=0,f=0,g=0,h=0;b=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;d=Hd(c[2276056]|0)|0;e=d&16777215;f=c[2112932]|0;g=c[f+((e>>>10|32768)<<2)>>2]|0;if(g>>>0>9){h=a[g+(d&1023^1)|0]|0}else{h=gj[c[f+196608+(g<<2)>>2]&4095](e)|0}e=h&255;h=c[b>>2]|0;g=h&255;f=g-e|0;c[2276075]=f;c[2276078]=f;c[2276074]=f;c[2276077]=(f^h)&(g^e);g=h-e&255;c[2276076]=g;c[b>>2]=c[b>>2]&-256|g;return}function NL(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0);f=l&255;g=c[a>>2]|0;m=g&255;b=m-f|0;c[2276075]=b;c[2276078]=b;c[2276074]=b;c[2276077]=(b^g)&(f^m);m=g-l&255;c[2276076]=m;c[a>>2]=m|c[a>>2]&-256;return}function NM(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0;a=c[2276069]|0;b=9104156+((a>>>9&7)<<2)|0;d=c[9104156+((a&7)<<2)>>2]|0;a=d&65535;e=c[b>>2]|0;f=e&65535;g=f-a|0;h=g>>>8;c[2276075]=h;c[2276078]=h;c[2276074]=h;c[2276077]=((g^e)&(f^a))>>>8;a=e-d&65535;c[2276076]=a;c[b>>2]=c[b>>2]&-65536|a;return}function NN(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0;a=c[2276069]|0;b=9104156+((a>>>9&7)<<2)|0;d=c[9104156+((a&7|8)<<2)>>2]|0;a=d&65535;e=c[b>>2]|0;f=e&65535;g=f-a|0;h=g>>>8;c[2276075]=h;c[2276078]=h;c[2276074]=h;c[2276077]=((g^e)&(f^a))>>>8;a=e-d&65535;c[2276076]=a;c[b>>2]=c[b>>2]&-65536|a;return}function NO(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0;a=c[2276069]|0;b=9104156+((a>>>9&7)<<2)|0;e=c[2276085]&c[9104156+((a&7|8)<<2)>>2];a=e&16777215;f=c[2112932]|0;g=c[f+(a>>>10<<2)>>2]|0;if(g>>>0>9){h=e&1023;i=(d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0)}else{i=gj[c[f+196688+(g<<2)>>2]&4095](a)|0}a=i&65535;i=c[b>>2]|0;g=i&65535;f=g-a|0;h=f>>>8;c[2276075]=h;c[2276078]=h;c[2276074]=h;c[2276077]=((f^i)&(g^a))>>>8;g=i-a&65535;c[2276076]=g;c[b>>2]=c[b>>2]&-65536|g;return}function NP(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0;a=c[2276069]|0;b=9104156+((a>>>9&7)<<2)|0;e=9104156+((a&7|8)<<2)|0;a=c[e>>2]|0;c[e>>2]=a+2;e=c[2276085]&a;a=e&16777215;f=c[2112932]|0;g=c[f+(a>>>10<<2)>>2]|0;if(g>>>0>9){h=e&1023;i=(d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0)}else{i=gj[c[f+196688+(g<<2)>>2]&4095](a)|0}a=i&65535;i=c[b>>2]|0;g=i&65535;f=g-a|0;h=f>>>8;c[2276075]=h;c[2276078]=h;c[2276074]=h;c[2276077]=((f^i)&(g^a))>>>8;g=i-a&65535;c[2276076]=g;c[b>>2]=c[b>>2]&-65536|g;return}function NQ(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0;a=c[2276069]|0;b=9104156+((a>>>9&7)<<2)|0;e=9104156+((a&7|8)<<2)|0;a=(c[e>>2]|0)-2|0;c[e>>2]=a;e=c[2276085]&a;a=e&16777215;f=c[2112932]|0;g=c[f+(a>>>10<<2)>>2]|0;if(g>>>0>9){h=e&1023;i=(d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0)}else{i=gj[c[f+196688+(g<<2)>>2]&4095](a)|0}a=i&65535;i=c[b>>2]|0;g=i&65535;f=g-a|0;h=f>>>8;c[2276075]=h;c[2276078]=h;c[2276074]=h;c[2276077]=((f^i)&(g^a))>>>8;g=i-a&65535;c[2276076]=g;c[b>>2]=c[b>>2]&-65536|g;return}function NR(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;a=c[2276069]|0;b=9104156+((a>>>9&7)<<2)|0;e=c[9104156+((a&7|8)<<2)>>2]|0;a=c[2276056]|0;f=a&-4;if((f|0)==(c[2276083]|0)){g=a;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a}else{a=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=a;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=(h>>>((g<<3&16^16)>>>0)<<16>>16)+e&c[2276085];e=m&16777215;g=c[2112932]|0;h=c[g+(e>>>10<<2)>>2]|0;if(h>>>0>9){n=m&1023;o=(d[h+(n+1)|0]|0)<<8|(d[h+n|0]|0);p=o&65535;q=c[b>>2]|0;r=q&65535;s=r-p|0;t=s>>>8;c[2276075]=t;c[2276078]=t;c[2276074]=t;u=r^p;v=s^q;w=v&u;x=w>>>8;c[2276077]=x;y=q-p|0;z=y&65535;c[2276076]=z;A=c[b>>2]|0;B=A&-65536;C=B|z;c[b>>2]=C;return}else{o=gj[c[g+196688+(h<<2)>>2]&4095](e)|0;p=o&65535;q=c[b>>2]|0;r=q&65535;s=r-p|0;t=s>>>8;c[2276075]=t;c[2276078]=t;c[2276074]=t;u=r^p;v=s^q;w=v&u;x=w>>>8;c[2276077]=x;y=q-p|0;z=y&65535;c[2276076]=z;A=c[b>>2]|0;B=A&-65536;C=B|z;c[b>>2]=C;return}}function NS(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0;a=c[2276069]|0;b=9104156+((a>>>9&7)<<2)|0;e=Hd(c[9104156+((a&7|8)<<2)>>2]|0)|0;a=c[2276085]&e;e=a&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=a&1023;i=(d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0)}else{i=gj[c[f+196688+(g<<2)>>2]&4095](e)|0}e=i&65535;i=c[b>>2]|0;g=i&65535;f=g-e|0;h=f>>>8;c[2276075]=h;c[2276078]=h;c[2276074]=h;c[2276077]=((f^i)&(g^e))>>>8;g=i-e&65535;c[2276076]=g;c[b>>2]=c[b>>2]&-65536|g;return}function NT(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;a=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)<<16>>16&c[2276085];f=l&16777215;g=c[2112932]|0;m=c[g+(f>>>10<<2)>>2]|0;if(m>>>0>9){b=l&1023;n=(d[m+(b+1)|0]|0)<<8|(d[m+b|0]|0);o=n&65535;p=c[a>>2]|0;q=p&65535;r=q-o|0;s=r>>>8;c[2276075]=s;c[2276078]=s;c[2276074]=s;t=q^o;u=r^p;v=u&t;w=v>>>8;c[2276077]=w;x=p-o|0;y=x&65535;c[2276076]=y;z=c[a>>2]|0;A=z&-65536;B=A|y;c[a>>2]=B;return}else{n=gj[c[g+196688+(m<<2)>>2]&4095](f)|0;o=n&65535;p=c[a>>2]|0;q=p&65535;r=q-o|0;s=r>>>8;c[2276075]=s;c[2276078]=s;c[2276074]=s;t=q^o;u=r^p;v=u&t;w=v>>>8;c[2276077]=w;x=p-o|0;y=x&65535;c[2276076]=y;z=c[a>>2]|0;A=z&-65536;B=A|y;c[a>>2]=B;return}}function NU(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;a=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[2276085]&q;q=r&16777215;t=c[2112932]|0;h=c[t+(q>>>10<<2)>>2]|0;if(h>>>0>9){s=r&1023;u=(d[h+(s+1)|0]|0)<<8|(d[h+s|0]|0);v=u&65535;w=c[a>>2]|0;x=w&65535;y=x-v|0;z=y>>>8;c[2276075]=z;c[2276078]=z;c[2276074]=z;A=x^v;B=y^w;C=B&A;D=C>>>8;c[2276077]=D;E=w-v|0;F=E&65535;c[2276076]=F;G=c[a>>2]|0;H=G&-65536;I=H|F;c[a>>2]=I;return}else{u=gj[c[t+196688+(h<<2)>>2]&4095](q)|0;v=u&65535;w=c[a>>2]|0;x=w&65535;y=x-v|0;z=y>>>8;c[2276075]=z;c[2276078]=z;c[2276074]=z;A=x^v;B=y^w;C=B&A;D=C>>>8;c[2276077]=D;E=w-v|0;F=E&65535;c[2276076]=F;G=c[a>>2]|0;H=G&-65536;I=H|F;c[a>>2]=I;return}}function NV(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;a=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{k=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=k;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=(g>>>((f<<3&16^16)>>>0)<<16>>16)+b|0;b=l&16777215;f=c[2112932]|0;g=c[f+((b>>>10|32768)<<2)>>2]|0;if(g>>>0>9){m=l&1023;n=(d[g+(m+1)|0]|0)<<8|(d[g+m|0]|0);o=n&65535;p=c[a>>2]|0;q=p&65535;r=q-o|0;s=r>>>8;c[2276075]=s;c[2276078]=s;c[2276074]=s;t=q^o;u=r^p;v=u&t;w=v>>>8;c[2276077]=w;x=p-o|0;y=x&65535;c[2276076]=y;z=c[a>>2]|0;A=z&-65536;B=A|y;c[a>>2]=B;return}else{n=gj[c[f+196688+(g<<2)>>2]&4095](b)|0;o=n&65535;p=c[a>>2]|0;q=p&65535;r=q-o|0;s=r>>>8;c[2276075]=s;c[2276078]=s;c[2276074]=s;t=q^o;u=r^p;v=u&t;w=v>>>8;c[2276077]=w;x=p-o|0;y=x&65535;c[2276076]=y;z=c[a>>2]|0;A=z&-65536;B=A|y;c[a>>2]=B;return}}function NW(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0;a=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;b=Hd(c[2276056]|0)|0;e=b&16777215;f=c[2112932]|0;g=c[f+((e>>>10|32768)<<2)>>2]|0;if(g>>>0>9){h=b&1023;i=(d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0)}else{i=gj[c[f+196688+(g<<2)>>2]&4095](e)|0}e=i&65535;i=c[a>>2]|0;g=i&65535;f=g-e|0;h=f>>>8;c[2276075]=h;c[2276078]=h;c[2276074]=h;c[2276077]=((f^i)&(g^e))>>>8;g=i-e&65535;c[2276076]=g;c[a>>2]=c[a>>2]&-65536|g;return}function NX(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0);f=l&65535;g=c[a>>2]|0;m=g&65535;b=m-f|0;e=b>>>8;c[2276075]=e;c[2276078]=e;c[2276074]=e;c[2276077]=((b^g)&(f^m))>>>8;m=g-l&65535;c[2276076]=m;c[a>>2]=m|c[a>>2]&-65536;return}function NY(){var a=0,b=0,d=0,e=0,f=0;a=c[2276069]|0;b=9104156+((a>>>9&7)<<2)|0;d=c[9104156+((a&7)<<2)>>2]|0;a=c[b>>2]|0;e=a-d|0;c[2276075]=e>>>24;f=((e|d)&(a^-8388608)|e&d)>>>23;c[2276078]=f;c[2276074]=f;c[2276077]=((e^a)&(a^d))>>>24;c[2276076]=e;c[b>>2]=e;return}function NZ(){var a=0,b=0,d=0,e=0,f=0;a=c[2276069]|0;b=9104156+((a>>>9&7)<<2)|0;d=c[9104156+((a&7|8)<<2)>>2]|0;a=c[b>>2]|0;e=a-d|0;c[2276075]=e>>>24;f=((e|d)&(a^-8388608)|e&d)>>>23;c[2276078]=f;c[2276074]=f;c[2276077]=((e^a)&(a^d))>>>24;c[2276076]=e;c[b>>2]=e;return}function N_(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0;a=c[2276069]|0;b=9104156+((a>>>9&7)<<2)|0;e=c[2276085]&c[9104156+((a&7|8)<<2)>>2];a=e&16777215;f=c[2112932]|0;g=c[f+(a>>>10<<2)>>2]|0;if(g>>>0>9){h=e&1023;i=(d[g+(h+3)|0]|0)<<8|(d[g+(h+2)|0]|0)|((d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0))<<16}else{i=gj[c[f+196768+(g<<2)>>2]&4095](a)|0}a=c[b>>2]|0;g=a-i|0;c[2276075]=g>>>24;f=((g|i)&(a^-8388608)|g&i)>>>23;c[2276078]=f;c[2276074]=f;c[2276077]=((g^a)&(a^i))>>>24;c[2276076]=g;c[b>>2]=g;return}function N$(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0;a=c[2276069]|0;b=9104156+((a>>>9&7)<<2)|0;e=9104156+((a&7|8)<<2)|0;a=c[e>>2]|0;c[e>>2]=a+4;e=c[2276085]&a;a=e&16777215;f=c[2112932]|0;g=c[f+(a>>>10<<2)>>2]|0;if(g>>>0>9){h=e&1023;i=(d[g+(h+3)|0]|0)<<8|(d[g+(h+2)|0]|0)|((d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0))<<16}else{i=gj[c[f+196768+(g<<2)>>2]&4095](a)|0}a=c[b>>2]|0;g=a-i|0;c[2276075]=g>>>24;f=((g|i)&(a^-8388608)|g&i)>>>23;c[2276078]=f;c[2276074]=f;c[2276077]=((g^a)&(a^i))>>>24;c[2276076]=g;c[b>>2]=g;return}function N0(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0;a=c[2276069]|0;b=9104156+((a>>>9&7)<<2)|0;e=9104156+((a&7|8)<<2)|0;a=(c[e>>2]|0)-4|0;c[e>>2]=a;e=c[2276085]&a;a=e&16777215;f=c[2112932]|0;g=c[f+(a>>>10<<2)>>2]|0;if(g>>>0>9){h=e&1023;i=(d[g+(h+3)|0]|0)<<8|(d[g+(h+2)|0]|0)|((d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0))<<16}else{i=gj[c[f+196768+(g<<2)>>2]&4095](a)|0}a=c[b>>2]|0;g=a-i|0;c[2276075]=g>>>24;f=((g|i)&(a^-8388608)|g&i)>>>23;c[2276078]=f;c[2276074]=f;c[2276077]=((g^a)&(a^i))>>>24;c[2276076]=g;c[b>>2]=g;return}function N1(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;a=c[2276069]|0;b=9104156+((a>>>9&7)<<2)|0;e=c[9104156+((a&7|8)<<2)>>2]|0;a=c[2276056]|0;f=a&-4;if((f|0)==(c[2276083]|0)){g=a;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a}else{a=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=a;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=(h>>>((g<<3&16^16)>>>0)<<16>>16)+e&c[2276085];e=m&16777215;g=c[2112932]|0;h=c[g+(e>>>10<<2)>>2]|0;if(h>>>0>9){n=m&1023;o=(d[h+(n+3)|0]|0)<<8|(d[h+(n+2)|0]|0)|((d[h+(n+1)|0]|0)<<8|(d[h+n|0]|0))<<16;p=c[b>>2]|0;q=p-o|0;r=q>>>24;c[2276075]=r;s=q&o;t=p^-8388608;u=q|o;v=u&t;w=v|s;x=w>>>23;c[2276078]=x;c[2276074]=x;y=p^o;z=q^p;A=z&y;B=A>>>24;c[2276077]=B;c[2276076]=q;c[b>>2]=q;return}else{o=gj[c[g+196768+(h<<2)>>2]&4095](e)|0;p=c[b>>2]|0;q=p-o|0;r=q>>>24;c[2276075]=r;s=q&o;t=p^-8388608;u=q|o;v=u&t;w=v|s;x=w>>>23;c[2276078]=x;c[2276074]=x;y=p^o;z=q^p;A=z&y;B=A>>>24;c[2276077]=B;c[2276076]=q;c[b>>2]=q;return}}function N2(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0;a=c[2276069]|0;b=9104156+((a>>>9&7)<<2)|0;e=Hd(c[9104156+((a&7|8)<<2)>>2]|0)|0;a=c[2276085]&e;e=a&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=a&1023;i=(d[g+(h+3)|0]|0)<<8|(d[g+(h+2)|0]|0)|((d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0))<<16}else{i=gj[c[f+196768+(g<<2)>>2]&4095](e)|0}e=c[b>>2]|0;g=e-i|0;c[2276075]=g>>>24;f=((g|i)&(e^-8388608)|g&i)>>>23;c[2276078]=f;c[2276074]=f;c[2276077]=((g^e)&(e^i))>>>24;c[2276076]=g;c[b>>2]=g;return}function N3(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;a=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)<<16>>16&c[2276085];f=l&16777215;g=c[2112932]|0;m=c[g+(f>>>10<<2)>>2]|0;if(m>>>0>9){b=l&1023;n=(d[m+(b+3)|0]|0)<<8|(d[m+(b+2)|0]|0)|((d[m+(b+1)|0]|0)<<8|(d[m+b|0]|0))<<16;o=c[a>>2]|0;p=o-n|0;q=p>>>24;c[2276075]=q;r=p&n;s=o^-8388608;t=p|n;u=t&s;v=u|r;w=v>>>23;c[2276078]=w;c[2276074]=w;x=o^n;y=p^o;z=y&x;A=z>>>24;c[2276077]=A;c[2276076]=p;c[a>>2]=p;return}else{n=gj[c[g+196768+(m<<2)>>2]&4095](f)|0;o=c[a>>2]|0;p=o-n|0;q=p>>>24;c[2276075]=q;r=p&n;s=o^-8388608;t=p|n;u=t&s;v=u|r;w=v>>>23;c[2276078]=w;c[2276074]=w;x=o^n;y=p^o;z=y&x;A=z>>>24;c[2276077]=A;c[2276076]=p;c[a>>2]=p;return}}function N4(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;a=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[2276085]&q;q=r&16777215;t=c[2112932]|0;h=c[t+(q>>>10<<2)>>2]|0;if(h>>>0>9){s=r&1023;u=(d[h+(s+3)|0]|0)<<8|(d[h+(s+2)|0]|0)|((d[h+(s+1)|0]|0)<<8|(d[h+s|0]|0))<<16;v=c[a>>2]|0;w=v-u|0;x=w>>>24;c[2276075]=x;y=w&u;z=v^-8388608;A=w|u;B=A&z;C=B|y;D=C>>>23;c[2276078]=D;c[2276074]=D;E=v^u;F=w^v;G=F&E;H=G>>>24;c[2276077]=H;c[2276076]=w;c[a>>2]=w;return}else{u=gj[c[t+196768+(h<<2)>>2]&4095](q)|0;v=c[a>>2]|0;w=v-u|0;x=w>>>24;c[2276075]=x;y=w&u;z=v^-8388608;A=w|u;B=A&z;C=B|y;D=C>>>23;c[2276078]=D;c[2276074]=D;E=v^u;F=w^v;G=F&E;H=G>>>24;c[2276077]=H;c[2276076]=w;c[a>>2]=w;return}}function N5(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;a=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{k=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=k;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=(g>>>((f<<3&16^16)>>>0)<<16>>16)+b|0;b=l&16777215;f=c[2112932]|0;g=c[f+((b>>>10|32768)<<2)>>2]|0;if(g>>>0>9){m=l&1023;n=(d[g+(m+3)|0]|0)<<8|(d[g+(m+2)|0]|0)|((d[g+(m+1)|0]|0)<<8|(d[g+m|0]|0))<<16;o=c[a>>2]|0;p=o-n|0;q=p>>>24;c[2276075]=q;r=p&n;s=o^-8388608;t=p|n;u=t&s;v=u|r;w=v>>>23;c[2276078]=w;c[2276074]=w;x=o^n;y=p^o;z=y&x;A=z>>>24;c[2276077]=A;c[2276076]=p;c[a>>2]=p;return}else{n=gj[c[f+196768+(g<<2)>>2]&4095](b)|0;o=c[a>>2]|0;p=o-n|0;q=p>>>24;c[2276075]=q;r=p&n;s=o^-8388608;t=p|n;u=t&s;v=u|r;w=v>>>23;c[2276078]=w;c[2276074]=w;x=o^n;y=p^o;z=y&x;A=z>>>24;c[2276077]=A;c[2276076]=p;c[a>>2]=p;return}}function N6(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0;a=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;b=Hd(c[2276056]|0)|0;e=b&16777215;f=c[2112932]|0;g=c[f+((e>>>10|32768)<<2)>>2]|0;if(g>>>0>9){h=b&1023;i=(d[g+(h+3)|0]|0)<<8|(d[g+(h+2)|0]|0)|((d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0))<<16}else{i=gj[c[f+196768+(g<<2)>>2]&4095](e)|0}e=c[a>>2]|0;g=e-i|0;c[2276075]=g>>>24;f=((g|i)&(e^-8388608)|g&i)>>>23;c[2276078]=f;c[2276074]=f;c[2276077]=((g^e)&(e^i))>>>24;c[2276076]=g;c[a>>2]=g;return}function N7(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;a=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n;s=r+2|0;c[2276056]=s;t=c[a>>2]|0;u=t-q|0;v=u>>>24;c[2276075]=v;w=u&q;x=t^-8388608;y=u|q;z=y&x;A=z|w;B=A>>>23;c[2276078]=B;c[2276074]=B;C=t^q;D=u^t;E=D&C;F=E>>>24;c[2276077]=F;c[2276076]=u;c[a>>2]=u;return}c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;G=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;H=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;G=n;H=c[2276056]|0}c[2276084]=G;q=G>>>16|h<<16;r=H;s=r+2|0;c[2276056]=s;t=c[a>>2]|0;u=t-q|0;v=u>>>24;c[2276075]=v;w=u&q;x=t^-8388608;y=u|q;z=y&x;A=z|w;B=A>>>23;c[2276078]=B;c[2276074]=B;C=t^q;D=u^t;E=D&C;F=E>>>24;c[2276077]=F;c[2276076]=u;c[a>>2]=u;return}function N8(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=c[2276069]|0;d=c[9104156+((b&7|8)<<2)>>2]|0;e=c[9104156+((b>>>9&7)<<2)>>2]&255;b=c[2276085]|0;f=b&d;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=a[i+(f&1023^1)|0]|0;k=b;l=h}else{b=gj[c[h+196608+(i<<2)>>2]&4095](g)|0;j=b;k=c[2276085]|0;l=c[2112932]|0}b=j&255;j=b-e|0;c[2276075]=j;c[2276076]=j&255;c[2276078]=j;c[2276074]=j;c[2276077]=(j^b)&(b^e);e=k&d;d=j&255;j=e&16777215;k=c[l+((j>>>10|16384)<<2)>>2]|0;if(k>>>0>9){a[k+(e&1023^1)|0]=d;return}else{gg[c[l+196648+(k<<2)>>2]&4095](j,d);return}}function N9(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;b=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]&255;e=c[2276085]|0;f=e&d;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=a[i+(f&1023^1)|0]|0;k=e;l=h}else{e=gj[c[h+196608+(i<<2)>>2]&4095](g)|0;j=e;k=c[2276085]|0;l=c[2112932]|0}e=j&255;j=e-b|0;c[2276075]=j;c[2276076]=j&255;c[2276078]=j;c[2276074]=j;c[2276077]=(j^e)&(e^b);b=k&d;d=j&255;j=b&16777215;k=c[l+((j>>>10|16384)<<2)>>2]|0;if(k>>>0>9){a[k+(b&1023^1)|0]=d;return}else{gg[c[l+196648+(k<<2)>>2]&4095](j,d);return}}function Oa(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=c[2276054]|0;c[2276054]=b+2;d=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]&255;e=c[2276085]|0;f=e&b;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=a[i+(f&1023^1)|0]|0;k=e;l=h}else{e=gj[c[h+196608+(i<<2)>>2]&4095](g)|0;j=e;k=c[2276085]|0;l=c[2112932]|0}e=j&255;j=e-d|0;c[2276075]=j;c[2276076]=j&255;c[2276078]=j;c[2276074]=j;c[2276077]=(j^e)&(e^d);d=k&b;b=j&255;j=d&16777215;k=c[l+((j>>>10|16384)<<2)>>2]|0;if(k>>>0>9){a[k+(d&1023^1)|0]=b;return}else{gg[c[l+196648+(k<<2)>>2]&4095](j,b);return}}function Ob(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;b=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]&255;e=c[2276085]|0;f=e&d;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=a[i+(f&1023^1)|0]|0;k=e;l=h}else{e=gj[c[h+196608+(i<<2)>>2]&4095](g)|0;j=e;k=c[2276085]|0;l=c[2112932]|0}e=j&255;j=e-b|0;c[2276075]=j;c[2276076]=j&255;c[2276078]=j;c[2276074]=j;c[2276077]=(j^e)&(e^b);b=k&d;d=j&255;j=b&16777215;k=c[l+((j>>>10|16384)<<2)>>2]|0;if(k>>>0>9){a[k+(b&1023^1)|0]=d;return}else{gg[c[l+196648+(k<<2)>>2]&4095](j,d);return}}function Oc(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=(c[2276054]|0)-2|0;c[2276054]=b;d=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]&255;e=c[2276085]|0;f=e&b;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=a[i+(f&1023^1)|0]|0;k=e;l=h}else{e=gj[c[h+196608+(i<<2)>>2]&4095](g)|0;j=e;k=c[2276085]|0;l=c[2112932]|0}e=j&255;j=e-d|0;c[2276075]=j;c[2276076]=j&255;c[2276078]=j;c[2276074]=j;c[2276077]=(j^e)&(e^d);d=k&b;b=j&255;j=d&16777215;k=c[l+((j>>>10|16384)<<2)>>2]|0;if(k>>>0>9){a[k+(d&1023^1)|0]=b;return}else{gg[c[l+196648+(k<<2)>>2]&4095](j,b);return}}function Od(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=c[2276069]|0;e=c[9104156+((b&7|8)<<2)>>2]|0;f=c[2276056]|0;g=f&-4;if((g|0)==(c[2276083]|0)){h=f;i=c[2276084]|0;j=b}else{c[2276083]=g;k=c[2276085]&g;g=k&16777212;l=c[2112932]|0;m=c[l+((g>>>10|32768)<<2)>>2]|0;if(m>>>0>9){n=k&1020;o=(d[m+(n|3)|0]|0)<<8|(d[m+(n|2)|0]|0)|((d[m+(n|1)|0]|0)<<8|(d[m+n|0]|0))<<16;p=f;q=b}else{b=gj[c[l+196768+(m<<2)>>2]&4095](g)|0;o=b;p=c[2276056]|0;q=c[2276069]|0}c[2276084]=o;h=p;i=o;j=q}c[2276056]=h+2;q=(i>>>((h<<3&16^16)>>>0)<<16>>16)+e|0;e=c[9104156+((j>>>9&7)<<2)>>2]&255;j=c[2276085]|0;h=q&j;i=h&16777215;o=c[2112932]|0;p=c[o+(i>>>10<<2)>>2]|0;if(p>>>0>9){r=a[p+(h&1023^1)|0]|0;s=j;t=o}else{j=gj[c[o+196608+(p<<2)>>2]&4095](i)|0;r=j;s=c[2276085]|0;t=c[2112932]|0}j=r&255;r=j-e|0;c[2276075]=r;c[2276076]=r&255;c[2276078]=r;c[2276074]=r;c[2276077]=(r^j)&(j^e);e=s&q;q=r&255;r=e&16777215;s=c[t+((r>>>10|16384)<<2)>>2]|0;if(s>>>0>9){a[s+(e&1023^1)|0]=q;return}else{gg[c[t+196648+(s<<2)>>2]&4095](r,q);return}}function Oe(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=Hd(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;d=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]&255;e=c[2276085]|0;f=e&b;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=a[i+(f&1023^1)|0]|0;k=e;l=h}else{e=gj[c[h+196608+(i<<2)>>2]&4095](g)|0;j=e;k=c[2276085]|0;l=c[2112932]|0}e=j&255;j=e-d|0;c[2276075]=j;c[2276076]=j&255;c[2276078]=j;c[2276074]=j;c[2276077]=(j^e)&(e^d);d=k&b;b=j&255;j=d&16777215;k=c[l+((j>>>10|16384)<<2)>>2]|0;if(k>>>0>9){a[k+(d&1023^1)|0]=b;return}else{gg[c[l+196648+(k<<2)>>2]&4095](j,b);return}}function Of(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)<<16>>16;f=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]&255;g=c[2276085]|0;m=l&g;b=m&16777215;e=c[2112932]|0;j=c[e+(b>>>10<<2)>>2]|0;if(j>>>0>9){n=a[j+(m&1023^1)|0]|0;o=g;p=e}else{g=gj[c[e+196608+(j<<2)>>2]&4095](b)|0;n=g;o=c[2276085]|0;p=c[2112932]|0}g=n&255;n=g-f|0;c[2276075]=n;c[2276076]=n&255;c[2276078]=n;c[2276074]=n;c[2276077]=(n^g)&(g^f);f=o&l;l=n&255;n=f&16777215;o=c[p+((n>>>10|16384)<<2)>>2]|0;if(o>>>0>9){a[o+(f&1023^1)|0]=l;return}else{gg[c[p+196648+(o<<2)>>2]&4095](n,l);return}}function Og(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]&255;t=c[2276085]|0;h=t&q;s=h&16777215;n=c[2112932]|0;f=c[n+(s>>>10<<2)>>2]|0;if(f>>>0>9){u=a[f+(h&1023^1)|0]|0;v=t;w=n}else{t=gj[c[n+196608+(f<<2)>>2]&4095](s)|0;u=t;v=c[2276085]|0;w=c[2112932]|0}t=u&255;u=t-r|0;c[2276075]=u;c[2276076]=u&255;c[2276078]=u;c[2276074]=u;c[2276077]=(u^t)&(t^r);r=v&q;q=u&255;u=r&16777215;v=c[w+((u>>>10|16384)<<2)>>2]|0;if(v>>>0>9){a[v+(r&1023^1)|0]=q;return}else{gg[c[w+196648+(v<<2)>>2]&4095](u,q);return}}function Oh(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[2276069]|0;e=c[9104156+((b&7|8)<<2)>>2]|0;f=c[9104156+((b>>>9&7)<<2)>>2]&65535;b=c[2276085]|0;g=b&e;h=g&16777215;i=c[2112932]|0;j=c[i+(h>>>10<<2)>>2]|0;if(j>>>0>9){k=g&1023;l=(d[j+(k+1)|0]|0)<<8|(d[j+k|0]|0);m=b;n=i}else{b=gj[c[i+196688+(j<<2)>>2]&4095](h)|0;l=b;m=c[2276085]|0;n=c[2112932]|0}b=l&65535;l=b-f|0;h=l>>>8;c[2276075]=h;c[2276076]=l&65535;c[2276078]=h;c[2276074]=h;c[2276077]=((l^b)&(b^f))>>>8;f=m&e;e=l&65535;m=f&16777215;b=c[n+((m>>>10|16384)<<2)>>2]|0;if(b>>>0>9){h=f&1023;a[b+h|0]=l&255;a[b+(h+1)|0]=(e&65535)>>>8&255;return}else{gg[c[n+196728+(b<<2)>>2]&4095](m,e);return}}function Oi(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=c[b>>2]|0;c[b>>2]=e+2;b=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]&65535;f=c[2276085]|0;g=f&e;h=g&16777215;i=c[2112932]|0;j=c[i+(h>>>10<<2)>>2]|0;if(j>>>0>9){k=g&1023;l=(d[j+(k+1)|0]|0)<<8|(d[j+k|0]|0);m=f;n=i}else{f=gj[c[i+196688+(j<<2)>>2]&4095](h)|0;l=f;m=c[2276085]|0;n=c[2112932]|0}f=l&65535;l=f-b|0;h=l>>>8;c[2276075]=h;c[2276076]=l&65535;c[2276078]=h;c[2276074]=h;c[2276077]=((l^f)&(f^b))>>>8;b=m&e;e=l&65535;m=b&16777215;f=c[n+((m>>>10|16384)<<2)>>2]|0;if(f>>>0>9){h=b&1023;a[f+h|0]=l&255;a[f+(h+1)|0]=(e&65535)>>>8&255;return}else{gg[c[n+196728+(f<<2)>>2]&4095](m,e);return}}function Oj(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=(c[b>>2]|0)-2|0;c[b>>2]=e;b=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]&65535;f=c[2276085]|0;g=f&e;h=g&16777215;i=c[2112932]|0;j=c[i+(h>>>10<<2)>>2]|0;if(j>>>0>9){k=g&1023;l=(d[j+(k+1)|0]|0)<<8|(d[j+k|0]|0);m=f;n=i}else{f=gj[c[i+196688+(j<<2)>>2]&4095](h)|0;l=f;m=c[2276085]|0;n=c[2112932]|0}f=l&65535;l=f-b|0;h=l>>>8;c[2276075]=h;c[2276076]=l&65535;c[2276078]=h;c[2276074]=h;c[2276077]=((l^f)&(f^b))>>>8;b=m&e;e=l&65535;m=b&16777215;f=c[n+((m>>>10|16384)<<2)>>2]|0;if(f>>>0>9){h=b&1023;a[f+h|0]=l&255;a[f+(h+1)|0]=(e&65535)>>>8&255;return}else{gg[c[n+196728+(f<<2)>>2]&4095](m,e);return}}function Ok(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=c[2276069]|0;e=c[9104156+((b&7|8)<<2)>>2]|0;f=c[2276056]|0;g=f&-4;if((g|0)==(c[2276083]|0)){h=f;i=c[2276084]|0;j=b}else{c[2276083]=g;k=c[2276085]&g;g=k&16777212;l=c[2112932]|0;m=c[l+((g>>>10|32768)<<2)>>2]|0;if(m>>>0>9){n=k&1020;o=(d[m+(n|3)|0]|0)<<8|(d[m+(n|2)|0]|0)|((d[m+(n|1)|0]|0)<<8|(d[m+n|0]|0))<<16;p=f;q=b}else{b=gj[c[l+196768+(m<<2)>>2]&4095](g)|0;o=b;p=c[2276056]|0;q=c[2276069]|0}c[2276084]=o;h=p;i=o;j=q}c[2276056]=h+2;q=(i>>>((h<<3&16^16)>>>0)<<16>>16)+e|0;e=c[9104156+((j>>>9&7)<<2)>>2]&65535;j=c[2276085]|0;h=q&j;i=h&16777215;o=c[2112932]|0;p=c[o+(i>>>10<<2)>>2]|0;if(p>>>0>9){b=h&1023;r=(d[p+(b+1)|0]|0)<<8|(d[p+b|0]|0);s=j;t=o}else{j=gj[c[o+196688+(p<<2)>>2]&4095](i)|0;r=j;s=c[2276085]|0;t=c[2112932]|0}j=r&65535;r=j-e|0;i=r>>>8;c[2276075]=i;c[2276076]=r&65535;c[2276078]=i;c[2276074]=i;c[2276077]=((r^j)&(j^e))>>>8;e=s&q;q=r&65535;s=e&16777215;j=c[t+((s>>>10|16384)<<2)>>2]|0;if(j>>>0>9){i=e&1023;a[j+i|0]=r&255;a[j+(i+1)|0]=(q&65535)>>>8&255;return}else{gg[c[t+196728+(j<<2)>>2]&4095](s,q);return}}function Ol(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=Hd(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;e=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]&65535;f=c[2276085]|0;g=f&b;h=g&16777215;i=c[2112932]|0;j=c[i+(h>>>10<<2)>>2]|0;if(j>>>0>9){k=g&1023;l=(d[j+(k+1)|0]|0)<<8|(d[j+k|0]|0);m=f;n=i}else{f=gj[c[i+196688+(j<<2)>>2]&4095](h)|0;l=f;m=c[2276085]|0;n=c[2112932]|0}f=l&65535;l=f-e|0;h=l>>>8;c[2276075]=h;c[2276076]=l&65535;c[2276078]=h;c[2276074]=h;c[2276077]=((l^f)&(f^e))>>>8;e=m&b;b=l&65535;m=e&16777215;f=c[n+((m>>>10|16384)<<2)>>2]|0;if(f>>>0>9){h=e&1023;a[f+h|0]=l&255;a[f+(h+1)|0]=(b&65535)>>>8&255;return}else{gg[c[n+196728+(f<<2)>>2]&4095](m,b);return}}function Om(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)<<16>>16;f=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]&65535;g=c[2276085]|0;m=l&g;b=m&16777215;e=c[2112932]|0;j=c[e+(b>>>10<<2)>>2]|0;if(j>>>0>9){i=m&1023;n=(d[j+(i+1)|0]|0)<<8|(d[j+i|0]|0);o=g;p=e}else{g=gj[c[e+196688+(j<<2)>>2]&4095](b)|0;n=g;o=c[2276085]|0;p=c[2112932]|0}g=n&65535;n=g-f|0;b=n>>>8;c[2276075]=b;c[2276076]=n&65535;c[2276078]=b;c[2276074]=b;c[2276077]=((n^g)&(g^f))>>>8;f=o&l;l=n&65535;o=f&16777215;g=c[p+((o>>>10|16384)<<2)>>2]|0;if(g>>>0>9){b=f&1023;a[g+b|0]=n&255;a[g+(b+1)|0]=(l&65535)>>>8&255;return}else{gg[c[p+196728+(g<<2)>>2]&4095](o,l);return}}function On(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]&65535;t=c[2276085]|0;h=t&q;s=h&16777215;n=c[2112932]|0;f=c[n+(s>>>10<<2)>>2]|0;if(f>>>0>9){o=h&1023;u=(d[f+(o+1)|0]|0)<<8|(d[f+o|0]|0);v=t;w=n}else{t=gj[c[n+196688+(f<<2)>>2]&4095](s)|0;u=t;v=c[2276085]|0;w=c[2112932]|0}t=u&65535;u=t-r|0;s=u>>>8;c[2276075]=s;c[2276076]=u&65535;c[2276078]=s;c[2276074]=s;c[2276077]=((u^t)&(t^r))>>>8;r=v&q;q=u&65535;v=r&16777215;t=c[w+((v>>>10|16384)<<2)>>2]|0;if(t>>>0>9){s=r&1023;a[t+s|0]=u&255;a[t+(s+1)|0]=(q&65535)>>>8&255;return}else{gg[c[w+196728+(t<<2)>>2]&4095](v,q);return}}function Oo(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[2276069]|0;e=c[9104156+((b&7|8)<<2)>>2]|0;f=c[9104156+((b>>>9&7)<<2)>>2]|0;b=c[2276085]|0;g=b&e;h=g&16777215;i=c[2112932]|0;j=c[i+(h>>>10<<2)>>2]|0;if(j>>>0>9){k=g&1023;l=(d[j+(k+3)|0]|0)<<8|(d[j+(k+2)|0]|0)|((d[j+(k+1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b;n=i}else{b=gj[c[i+196768+(j<<2)>>2]&4095](h)|0;l=b;m=c[2276085]|0;n=c[2112932]|0}b=l-f|0;h=b>>>24;c[2276075]=h;c[2276076]=b;j=((b|f)&(l^-8388608)|b&f)>>>23;c[2276078]=j;c[2276074]=j;c[2276077]=((b^l)&(l^f))>>>24;f=m&e;e=f&16777215;m=c[n+((e>>>10|16384)<<2)>>2]|0;if(m>>>0>9){l=f&1023;a[m+l|0]=b>>>16&255;a[m+(l+1)|0]=h&255;a[m+(l+2)|0]=b&255;a[m+(l+3)|0]=b>>>8&255;return}else{gg[c[n+196808+(m<<2)>>2]&4095](e,b);return}}function Op(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=c[b>>2]|0;c[b>>2]=e+4;b=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;f=c[2276085]|0;g=f&e;h=g&16777215;i=c[2112932]|0;j=c[i+(h>>>10<<2)>>2]|0;if(j>>>0>9){k=g&1023;l=(d[j+(k+3)|0]|0)<<8|(d[j+(k+2)|0]|0)|((d[j+(k+1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=f;n=i}else{f=gj[c[i+196768+(j<<2)>>2]&4095](h)|0;l=f;m=c[2276085]|0;n=c[2112932]|0}f=l-b|0;h=f>>>24;c[2276075]=h;c[2276076]=f;j=((f|b)&(l^-8388608)|f&b)>>>23;c[2276078]=j;c[2276074]=j;c[2276077]=((f^l)&(l^b))>>>24;b=m&e;e=b&16777215;m=c[n+((e>>>10|16384)<<2)>>2]|0;if(m>>>0>9){l=b&1023;a[m+l|0]=f>>>16&255;a[m+(l+1)|0]=h&255;a[m+(l+2)|0]=f&255;a[m+(l+3)|0]=f>>>8&255;return}else{gg[c[n+196808+(m<<2)>>2]&4095](e,f);return}}function Oq(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=(c[b>>2]|0)-4|0;c[b>>2]=e;b=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;f=c[2276085]|0;g=f&e;h=g&16777215;i=c[2112932]|0;j=c[i+(h>>>10<<2)>>2]|0;if(j>>>0>9){k=g&1023;l=(d[j+(k+3)|0]|0)<<8|(d[j+(k+2)|0]|0)|((d[j+(k+1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=f;n=i}else{f=gj[c[i+196768+(j<<2)>>2]&4095](h)|0;l=f;m=c[2276085]|0;n=c[2112932]|0}f=l-b|0;h=f>>>24;c[2276075]=h;c[2276076]=f;j=((f|b)&(l^-8388608)|f&b)>>>23;c[2276078]=j;c[2276074]=j;c[2276077]=((f^l)&(l^b))>>>24;b=m&e;e=b&16777215;m=c[n+((e>>>10|16384)<<2)>>2]|0;if(m>>>0>9){l=b&1023;a[m+l|0]=f>>>16&255;a[m+(l+1)|0]=h&255;a[m+(l+2)|0]=f&255;a[m+(l+3)|0]=f>>>8&255;return}else{gg[c[n+196808+(m<<2)>>2]&4095](e,f);return}}function Or(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=c[2276069]|0;e=c[9104156+((b&7|8)<<2)>>2]|0;f=c[2276056]|0;g=f&-4;if((g|0)==(c[2276083]|0)){h=f;i=c[2276084]|0;j=b}else{c[2276083]=g;k=c[2276085]&g;g=k&16777212;l=c[2112932]|0;m=c[l+((g>>>10|32768)<<2)>>2]|0;if(m>>>0>9){n=k&1020;o=(d[m+(n|3)|0]|0)<<8|(d[m+(n|2)|0]|0)|((d[m+(n|1)|0]|0)<<8|(d[m+n|0]|0))<<16;p=f;q=b}else{b=gj[c[l+196768+(m<<2)>>2]&4095](g)|0;o=b;p=c[2276056]|0;q=c[2276069]|0}c[2276084]=o;h=p;i=o;j=q}c[2276056]=h+2;q=(i>>>((h<<3&16^16)>>>0)<<16>>16)+e|0;e=c[9104156+((j>>>9&7)<<2)>>2]|0;j=c[2276085]|0;h=q&j;i=h&16777215;o=c[2112932]|0;p=c[o+(i>>>10<<2)>>2]|0;if(p>>>0>9){b=h&1023;r=(d[p+(b+3)|0]|0)<<8|(d[p+(b+2)|0]|0)|((d[p+(b+1)|0]|0)<<8|(d[p+b|0]|0))<<16;s=j;t=o}else{j=gj[c[o+196768+(p<<2)>>2]&4095](i)|0;r=j;s=c[2276085]|0;t=c[2112932]|0}j=r-e|0;i=j>>>24;c[2276075]=i;c[2276076]=j;p=((j|e)&(r^-8388608)|j&e)>>>23;c[2276078]=p;c[2276074]=p;c[2276077]=((j^r)&(r^e))>>>24;e=s&q;q=e&16777215;s=c[t+((q>>>10|16384)<<2)>>2]|0;if(s>>>0>9){r=e&1023;a[s+r|0]=j>>>16&255;a[s+(r+1)|0]=i&255;a[s+(r+2)|0]=j&255;a[s+(r+3)|0]=j>>>8&255;return}else{gg[c[t+196808+(s<<2)>>2]&4095](q,j);return}}function Os(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=Hd(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;e=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;f=c[2276085]|0;g=f&b;h=g&16777215;i=c[2112932]|0;j=c[i+(h>>>10<<2)>>2]|0;if(j>>>0>9){k=g&1023;l=(d[j+(k+3)|0]|0)<<8|(d[j+(k+2)|0]|0)|((d[j+(k+1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=f;n=i}else{f=gj[c[i+196768+(j<<2)>>2]&4095](h)|0;l=f;m=c[2276085]|0;n=c[2112932]|0}f=l-e|0;h=f>>>24;c[2276075]=h;c[2276076]=f;j=((f|e)&(l^-8388608)|f&e)>>>23;c[2276078]=j;c[2276074]=j;c[2276077]=((f^l)&(l^e))>>>24;e=m&b;b=e&16777215;m=c[n+((b>>>10|16384)<<2)>>2]|0;if(m>>>0>9){l=e&1023;a[m+l|0]=f>>>16&255;a[m+(l+1)|0]=h&255;a[m+(l+2)|0]=f&255;a[m+(l+3)|0]=f>>>8&255;return}else{gg[c[n+196808+(m<<2)>>2]&4095](b,f);return}}function Ot(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)<<16>>16;f=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;g=c[2276085]|0;m=l&g;b=m&16777215;e=c[2112932]|0;j=c[e+(b>>>10<<2)>>2]|0;if(j>>>0>9){i=m&1023;n=(d[j+(i+3)|0]|0)<<8|(d[j+(i+2)|0]|0)|((d[j+(i+1)|0]|0)<<8|(d[j+i|0]|0))<<16;o=g;p=e}else{g=gj[c[e+196768+(j<<2)>>2]&4095](b)|0;n=g;o=c[2276085]|0;p=c[2112932]|0}g=n-f|0;b=g>>>24;c[2276075]=b;c[2276076]=g;j=((g|f)&(n^-8388608)|g&f)>>>23;c[2276078]=j;c[2276074]=j;c[2276077]=((g^n)&(n^f))>>>24;f=o&l;l=f&16777215;o=c[p+((l>>>10|16384)<<2)>>2]|0;if(o>>>0>9){n=f&1023;a[o+n|0]=g>>>16&255;a[o+(n+1)|0]=b&255;a[o+(n+2)|0]=g&255;a[o+(n+3)|0]=g>>>8&255;return}else{gg[c[p+196808+(o<<2)>>2]&4095](l,g);return}}function Ou(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;t=c[2276085]|0;h=t&q;s=h&16777215;n=c[2112932]|0;f=c[n+(s>>>10<<2)>>2]|0;if(f>>>0>9){o=h&1023;u=(d[f+(o+3)|0]|0)<<8|(d[f+(o+2)|0]|0)|((d[f+(o+1)|0]|0)<<8|(d[f+o|0]|0))<<16;v=t;w=n}else{t=gj[c[n+196768+(f<<2)>>2]&4095](s)|0;u=t;v=c[2276085]|0;w=c[2112932]|0}t=u-r|0;s=t>>>24;c[2276075]=s;c[2276076]=t;f=((t|r)&(u^-8388608)|t&r)>>>23;c[2276078]=f;c[2276074]=f;c[2276077]=((t^u)&(u^r))>>>24;r=v&q;q=r&16777215;v=c[w+((q>>>10|16384)<<2)>>2]|0;if(v>>>0>9){u=r&1023;a[v+u|0]=t>>>16&255;a[v+(u+1)|0]=s&255;a[v+(u+2)|0]=t&255;a[v+(u+3)|0]=t>>>8&255;return}else{gg[c[w+196808+(v<<2)>>2]&4095](q,t);return}}function Ov(){var a=0,b=0;a=c[2276069]|0;b=9104156+((a>>>9&7|8)<<2)|0;c[b>>2]=(c[b>>2]|0)-(c[9104156+((a&7)<<2)>>2]<<16>>16);return}function Ow(){var a=0,b=0;a=c[2276069]|0;b=9104156+((a>>>9&7|8)<<2)|0;c[b>>2]=(c[b>>2]|0)-(c[9104156+((a&7|8)<<2)>>2]<<16>>16);return}function Ox(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[2276069]|0;b=9104156+((a>>>9&7|8)<<2)|0;e=c[b>>2]|0;f=c[2276085]&c[9104156+((a&7|8)<<2)>>2];a=f&16777215;g=c[2112932]|0;h=c[g+(a>>>10<<2)>>2]|0;if(h>>>0>9){i=f&1023;j=(d[h+(i+1)|0]|0)<<8|(d[h+i|0]|0);k=j<<16>>16;l=e-k|0;c[b>>2]=l;return}else{j=gj[c[g+196688+(h<<2)>>2]&4095](a)|0;k=j<<16>>16;l=e-k|0;c[b>>2]=l;return}}function Oy(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[2276069]|0;b=9104156+((a>>>9&7|8)<<2)|0;e=c[b>>2]|0;f=9104156+((a&7|8)<<2)|0;a=c[f>>2]|0;c[f>>2]=a+2;f=c[2276085]&a;a=f&16777215;g=c[2112932]|0;h=c[g+(a>>>10<<2)>>2]|0;if(h>>>0>9){i=f&1023;j=(d[h+(i+1)|0]|0)<<8|(d[h+i|0]|0);k=j<<16>>16;l=e-k|0;c[b>>2]=l;return}else{j=gj[c[g+196688+(h<<2)>>2]&4095](a)|0;k=j<<16>>16;l=e-k|0;c[b>>2]=l;return}}function Oz(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[2276069]|0;b=9104156+((a>>>9&7|8)<<2)|0;e=c[b>>2]|0;f=9104156+((a&7|8)<<2)|0;a=(c[f>>2]|0)-2|0;c[f>>2]=a;f=c[2276085]&a;a=f&16777215;g=c[2112932]|0;h=c[g+(a>>>10<<2)>>2]|0;if(h>>>0>9){i=f&1023;j=(d[h+(i+1)|0]|0)<<8|(d[h+i|0]|0);k=j<<16>>16;l=e-k|0;c[b>>2]=l;return}else{j=gj[c[g+196688+(h<<2)>>2]&4095](a)|0;k=j<<16>>16;l=e-k|0;c[b>>2]=l;return}}function OA(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;a=c[2276069]|0;b=9104156+((a>>>9&7|8)<<2)|0;e=c[b>>2]|0;f=c[9104156+((a&7|8)<<2)>>2]|0;a=c[2276056]|0;g=a&-4;if((g|0)==(c[2276083]|0)){h=a;i=c[2276084]|0}else{c[2276083]=g;j=c[2276085]&g;g=j&16777212;k=c[2112932]|0;l=c[k+((g>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=j&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=a}else{a=gj[c[k+196768+(l<<2)>>2]&4095](g)|0;n=a;o=c[2276056]|0}c[2276084]=n;h=o;i=n}c[2276056]=h+2;n=(i>>>((h<<3&16^16)>>>0)<<16>>16)+f&c[2276085];f=n&16777215;h=c[2112932]|0;i=c[h+(f>>>10<<2)>>2]|0;if(i>>>0>9){o=n&1023;p=(d[i+(o+1)|0]|0)<<8|(d[i+o|0]|0);q=p<<16>>16;r=e-q|0;c[b>>2]=r;return}else{p=gj[c[h+196688+(i<<2)>>2]&4095](f)|0;q=p<<16>>16;r=e-q|0;c[b>>2]=r;return}}function OB(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[2276069]|0;b=9104156+((a>>>9&7|8)<<2)|0;e=c[b>>2]|0;f=Hd(c[9104156+((a&7|8)<<2)>>2]|0)|0;a=c[2276085]&f;f=a&16777215;g=c[2112932]|0;h=c[g+(f>>>10<<2)>>2]|0;if(h>>>0>9){i=a&1023;j=(d[h+(i+1)|0]|0)<<8|(d[h+i|0]|0);k=j<<16>>16;l=e-k|0;c[b>>2]=l;return}else{j=gj[c[g+196688+(h<<2)>>2]&4095](f)|0;k=j<<16>>16;l=e-k|0;c[b>>2]=l;return}}function OC(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;a=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;b=c[a>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=h>>>((g<<3&16^16)>>>0)<<16>>16&c[2276085];g=m&16777215;h=c[2112932]|0;n=c[h+(g>>>10<<2)>>2]|0;if(n>>>0>9){e=m&1023;o=(d[n+(e+1)|0]|0)<<8|(d[n+e|0]|0);p=o<<16>>16;q=b-p|0;c[a>>2]=q;return}else{o=gj[c[h+196688+(n<<2)>>2]&4095](g)|0;p=o<<16>>16;q=b-p|0;c[a>>2]=q;return}}function OD(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;a=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;b=c[a>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=f;i=c[2276084]|0}else{c[2276083]=f;j=c[2276085]&f;k=j&16777212;l=c[2112932]|0;m=c[l+((k>>>10|32768)<<2)>>2]|0;if(m>>>0>9){n=j&1020;o=(d[m+(n|3)|0]|0)<<8|(d[m+(n|2)|0]|0)|((d[m+(n|1)|0]|0)<<8|(d[m+n|0]|0))<<16;p=e;q=f}else{f=gj[c[l+196768+(m<<2)>>2]&4095](k)|0;o=f;p=c[2276056]|0;q=c[2276083]|0}c[2276084]=o;g=p;h=q;i=o}o=g+2|0;c[2276056]=o;g=o&-4;if((g|0)==(h|0)){r=i;s=o}else{c[2276083]=g;h=c[2276085]&g;g=h&16777212;q=c[2112932]|0;p=c[q+((g>>>10|32768)<<2)>>2]|0;if(p>>>0>9){f=h&1020;t=(d[p+(f|3)|0]|0)<<8|(d[p+(f|2)|0]|0)|((d[p+(f|1)|0]|0)<<8|(d[p+f|0]|0))<<16;u=o}else{o=gj[c[q+196768+(p<<2)>>2]&4095](g)|0;t=o;u=c[2276056]|0}c[2276084]=t;r=t>>>16|i<<16;s=u}c[2276056]=s+2;s=c[2276085]&r;r=s&16777215;u=c[2112932]|0;i=c[u+(r>>>10<<2)>>2]|0;if(i>>>0>9){t=s&1023;v=(d[i+(t+1)|0]|0)<<8|(d[i+t|0]|0);w=v<<16>>16;x=b-w|0;c[a>>2]=x;return}else{v=gj[c[u+196688+(i<<2)>>2]&4095](r)|0;w=v<<16>>16;x=b-w|0;c[a>>2]=x;return}}function OE(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;a=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;b=c[a>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{l=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=l;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=(h>>>((g<<3&16^16)>>>0)<<16>>16)+e|0;e=m&16777215;g=c[2112932]|0;h=c[g+((e>>>10|32768)<<2)>>2]|0;if(h>>>0>9){n=m&1023;o=(d[h+(n+1)|0]|0)<<8|(d[h+n|0]|0);p=o<<16>>16;q=b-p|0;c[a>>2]=q;return}else{o=gj[c[g+196688+(h<<2)>>2]&4095](e)|0;p=o<<16>>16;q=b-p|0;c[a>>2]=q;return}}function OF(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;b=c[a>>2]|0;e=Hd(c[2276056]|0)|0;f=e&16777215;g=c[2112932]|0;h=c[g+((f>>>10|32768)<<2)>>2]|0;if(h>>>0>9){i=e&1023;j=(d[h+(i+1)|0]|0)<<8|(d[h+i|0]|0);k=j<<16>>16;l=b-k|0;c[a>>2]=l;return}else{j=gj[c[g+196688+(h<<2)>>2]&4095](f)|0;k=j<<16>>16;l=b-k|0;c[a>>2]=l;return}}function OG(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;a=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;b=c[a>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0;i=g+2|0;c[2276056]=i;j=g<<3;k=j&16;l=k^16;m=h>>>(l>>>0);n=m<<16;o=n>>16;p=b-o|0;c[a>>2]=p;return}c[2276083]=f;q=c[2276085]&f;f=q&16777212;r=c[2112932]|0;s=c[r+((f>>>10|32768)<<2)>>2]|0;if(s>>>0>9){t=q&1020;u=(d[s+(t|3)|0]|0)<<8|(d[s+(t|2)|0]|0)|((d[s+(t|1)|0]|0)<<8|(d[s+t|0]|0))<<16;v=e}else{e=gj[c[r+196768+(s<<2)>>2]&4095](f)|0;u=e;v=c[2276056]|0}c[2276084]=u;g=v;h=u;i=g+2|0;c[2276056]=i;j=g<<3;k=j&16;l=k^16;m=h>>>(l>>>0);n=m<<16;o=n>>16;p=b-o|0;c[a>>2]=p;return}function OH(){var a=0,b=0;a=c[2276069]|0;b=9104156+((a>>>9&7|8)<<2)|0;c[b>>2]=(c[b>>2]|0)-(c[9104156+((a&7)<<2)>>2]|0);return}function OI(){var a=0,b=0;a=c[2276069]|0;b=9104156+((a>>>9&7|8)<<2)|0;c[b>>2]=(c[b>>2]|0)-(c[9104156+((a&7|8)<<2)>>2]|0);return}function OJ(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[2276069]|0;b=9104156+((a>>>9&7|8)<<2)|0;e=c[b>>2]|0;f=c[2276085]&c[9104156+((a&7|8)<<2)>>2];a=f&16777215;g=c[2112932]|0;h=c[g+(a>>>10<<2)>>2]|0;if(h>>>0>9){i=f&1023;j=(d[h+(i+3)|0]|0)<<8|(d[h+(i+2)|0]|0)|((d[h+(i+1)|0]|0)<<8|(d[h+i|0]|0))<<16;k=e-j|0;c[b>>2]=k;return}else{j=gj[c[g+196768+(h<<2)>>2]&4095](a)|0;k=e-j|0;c[b>>2]=k;return}}function OK(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[2276069]|0;b=9104156+((a>>>9&7|8)<<2)|0;e=c[b>>2]|0;f=9104156+((a&7|8)<<2)|0;a=c[f>>2]|0;c[f>>2]=a+4;f=c[2276085]&a;a=f&16777215;g=c[2112932]|0;h=c[g+(a>>>10<<2)>>2]|0;if(h>>>0>9){i=f&1023;j=(d[h+(i+3)|0]|0)<<8|(d[h+(i+2)|0]|0)|((d[h+(i+1)|0]|0)<<8|(d[h+i|0]|0))<<16;k=e-j|0;c[b>>2]=k;return}else{j=gj[c[g+196768+(h<<2)>>2]&4095](a)|0;k=e-j|0;c[b>>2]=k;return}}function OL(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[2276069]|0;b=9104156+((a>>>9&7|8)<<2)|0;e=c[b>>2]|0;f=9104156+((a&7|8)<<2)|0;a=(c[f>>2]|0)-4|0;c[f>>2]=a;f=c[2276085]&a;a=f&16777215;g=c[2112932]|0;h=c[g+(a>>>10<<2)>>2]|0;if(h>>>0>9){i=f&1023;j=(d[h+(i+3)|0]|0)<<8|(d[h+(i+2)|0]|0)|((d[h+(i+1)|0]|0)<<8|(d[h+i|0]|0))<<16;k=e-j|0;c[b>>2]=k;return}else{j=gj[c[g+196768+(h<<2)>>2]&4095](a)|0;k=e-j|0;c[b>>2]=k;return}}function OM(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;a=c[2276069]|0;b=9104156+((a>>>9&7|8)<<2)|0;e=c[b>>2]|0;f=c[9104156+((a&7|8)<<2)>>2]|0;a=c[2276056]|0;g=a&-4;if((g|0)==(c[2276083]|0)){h=a;i=c[2276084]|0}else{c[2276083]=g;j=c[2276085]&g;g=j&16777212;k=c[2112932]|0;l=c[k+((g>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=j&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=a}else{a=gj[c[k+196768+(l<<2)>>2]&4095](g)|0;n=a;o=c[2276056]|0}c[2276084]=n;h=o;i=n}c[2276056]=h+2;n=(i>>>((h<<3&16^16)>>>0)<<16>>16)+f&c[2276085];f=n&16777215;h=c[2112932]|0;i=c[h+(f>>>10<<2)>>2]|0;if(i>>>0>9){o=n&1023;p=(d[i+(o+3)|0]|0)<<8|(d[i+(o+2)|0]|0)|((d[i+(o+1)|0]|0)<<8|(d[i+o|0]|0))<<16;q=e-p|0;c[b>>2]=q;return}else{p=gj[c[h+196768+(i<<2)>>2]&4095](f)|0;q=e-p|0;c[b>>2]=q;return}}function ON(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[2276069]|0;b=9104156+((a>>>9&7|8)<<2)|0;e=c[b>>2]|0;f=Hd(c[9104156+((a&7|8)<<2)>>2]|0)|0;a=c[2276085]&f;f=a&16777215;g=c[2112932]|0;h=c[g+(f>>>10<<2)>>2]|0;if(h>>>0>9){i=a&1023;j=(d[h+(i+3)|0]|0)<<8|(d[h+(i+2)|0]|0)|((d[h+(i+1)|0]|0)<<8|(d[h+i|0]|0))<<16;k=e-j|0;c[b>>2]=k;return}else{j=gj[c[g+196768+(h<<2)>>2]&4095](f)|0;k=e-j|0;c[b>>2]=k;return}}function OO(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;a=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;b=c[a>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=h>>>((g<<3&16^16)>>>0)<<16>>16&c[2276085];g=m&16777215;h=c[2112932]|0;n=c[h+(g>>>10<<2)>>2]|0;if(n>>>0>9){e=m&1023;o=(d[n+(e+3)|0]|0)<<8|(d[n+(e+2)|0]|0)|((d[n+(e+1)|0]|0)<<8|(d[n+e|0]|0))<<16;p=b-o|0;c[a>>2]=p;return}else{o=gj[c[h+196768+(n<<2)>>2]&4095](g)|0;p=b-o|0;c[a>>2]=p;return}}function OP(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;a=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;b=c[a>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=f;i=c[2276084]|0}else{c[2276083]=f;j=c[2276085]&f;k=j&16777212;l=c[2112932]|0;m=c[l+((k>>>10|32768)<<2)>>2]|0;if(m>>>0>9){n=j&1020;o=(d[m+(n|3)|0]|0)<<8|(d[m+(n|2)|0]|0)|((d[m+(n|1)|0]|0)<<8|(d[m+n|0]|0))<<16;p=e;q=f}else{f=gj[c[l+196768+(m<<2)>>2]&4095](k)|0;o=f;p=c[2276056]|0;q=c[2276083]|0}c[2276084]=o;g=p;h=q;i=o}o=g+2|0;c[2276056]=o;g=o&-4;if((g|0)==(h|0)){r=i;s=o}else{c[2276083]=g;h=c[2276085]&g;g=h&16777212;q=c[2112932]|0;p=c[q+((g>>>10|32768)<<2)>>2]|0;if(p>>>0>9){f=h&1020;t=(d[p+(f|3)|0]|0)<<8|(d[p+(f|2)|0]|0)|((d[p+(f|1)|0]|0)<<8|(d[p+f|0]|0))<<16;u=o}else{o=gj[c[q+196768+(p<<2)>>2]&4095](g)|0;t=o;u=c[2276056]|0}c[2276084]=t;r=t>>>16|i<<16;s=u}c[2276056]=s+2;s=c[2276085]&r;r=s&16777215;u=c[2112932]|0;i=c[u+(r>>>10<<2)>>2]|0;if(i>>>0>9){t=s&1023;v=(d[i+(t+3)|0]|0)<<8|(d[i+(t+2)|0]|0)|((d[i+(t+1)|0]|0)<<8|(d[i+t|0]|0))<<16;w=b-v|0;c[a>>2]=w;return}else{v=gj[c[u+196768+(i<<2)>>2]&4095](r)|0;w=b-v|0;c[a>>2]=w;return}}function OQ(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;a=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;b=c[a>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{l=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=l;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=(h>>>((g<<3&16^16)>>>0)<<16>>16)+e|0;e=m&16777215;g=c[2112932]|0;h=c[g+((e>>>10|32768)<<2)>>2]|0;if(h>>>0>9){n=m&1023;o=(d[h+(n+3)|0]|0)<<8|(d[h+(n+2)|0]|0)|((d[h+(n+1)|0]|0)<<8|(d[h+n|0]|0))<<16;p=b-o|0;c[a>>2]=p;return}else{o=gj[c[g+196768+(h<<2)>>2]&4095](e)|0;p=b-o|0;c[a>>2]=p;return}}function OR(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;a=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;b=c[a>>2]|0;e=Hd(c[2276056]|0)|0;f=e&16777215;g=c[2112932]|0;h=c[g+((f>>>10|32768)<<2)>>2]|0;if(h>>>0>9){i=e&1023;j=(d[h+(i+3)|0]|0)<<8|(d[h+(i+2)|0]|0)|((d[h+(i+1)|0]|0)<<8|(d[h+i|0]|0))<<16;k=b-j|0;c[a>>2]=k;return}else{j=gj[c[g+196768+(h<<2)>>2]&4095](f)|0;k=b-j|0;c[a>>2]=k;return}}function OS(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;a=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;b=c[a>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=f;i=c[2276084]|0}else{c[2276083]=f;j=c[2276085]&f;k=j&16777212;l=c[2112932]|0;m=c[l+((k>>>10|32768)<<2)>>2]|0;if(m>>>0>9){n=j&1020;o=(d[m+(n|3)|0]|0)<<8|(d[m+(n|2)|0]|0)|((d[m+(n|1)|0]|0)<<8|(d[m+n|0]|0))<<16;p=e;q=f}else{f=gj[c[l+196768+(m<<2)>>2]&4095](k)|0;o=f;p=c[2276056]|0;q=c[2276083]|0}c[2276084]=o;g=p;h=q;i=o}o=g+2|0;c[2276056]=o;g=o&-4;if((g|0)==(h|0)){r=i;s=o;t=s+2|0;c[2276056]=t;u=b-r|0;c[a>>2]=u;return}c[2276083]=g;h=c[2276085]&g;g=h&16777212;q=c[2112932]|0;p=c[q+((g>>>10|32768)<<2)>>2]|0;if(p>>>0>9){f=h&1020;v=(d[p+(f|3)|0]|0)<<8|(d[p+(f|2)|0]|0)|((d[p+(f|1)|0]|0)<<8|(d[p+f|0]|0))<<16;w=o}else{o=gj[c[q+196768+(p<<2)>>2]&4095](g)|0;v=o;w=c[2276056]|0}c[2276084]=v;r=v>>>16|i<<16;s=w;t=s+2|0;c[2276056]=t;u=b-r|0;c[a>>2]=u;return}function OT(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=9104156+((c[2276069]&7)<<2)|0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0);f=l&255;g=c[a>>2]|0;m=g&255;b=m-f|0;c[2276075]=b;e=g-l&255;c[2276076]=e;c[2276078]=b;c[2276074]=b;c[2276077]=(b^g)&(f^m);c[a>>2]=e|c[a>>2]&-256;return}function OU(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)&255;f=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;g=c[2276085]|0;m=g&f;b=m&16777215;e=c[2112932]|0;j=c[e+(b>>>10<<2)>>2]|0;if(j>>>0>9){n=a[j+(m&1023^1)|0]|0;o=g;p=e}else{g=gj[c[e+196608+(j<<2)>>2]&4095](b)|0;n=g;o=c[2276085]|0;p=c[2112932]|0}g=n&255;n=g-l|0;c[2276075]=n;c[2276076]=n&255;c[2276078]=n;c[2276074]=n;c[2276077]=(n^g)&(g^l);l=o&f;f=n&255;n=l&16777215;o=c[p+((n>>>10|16384)<<2)>>2]|0;if(o>>>0>9){a[o+(l&1023^1)|0]=f;return}else{gg[c[p+196648+(o<<2)>>2]&4095](n,f);return}}function OV(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)&255;f=9104156+((c[2276069]&7|8)<<2)|0;g=c[f>>2]|0;c[f>>2]=g+1;f=c[2276085]|0;m=f&g;b=m&16777215;e=c[2112932]|0;j=c[e+(b>>>10<<2)>>2]|0;if(j>>>0>9){n=a[j+(m&1023^1)|0]|0;o=f;p=e}else{f=gj[c[e+196608+(j<<2)>>2]&4095](b)|0;n=f;o=c[2276085]|0;p=c[2112932]|0}f=n&255;n=f-l|0;c[2276075]=n;c[2276076]=n&255;c[2276078]=n;c[2276074]=n;c[2276077]=(n^f)&(f^l);l=o&g;g=n&255;n=l&16777215;o=c[p+((n>>>10|16384)<<2)>>2]|0;if(o>>>0>9){a[o+(l&1023^1)|0]=g;return}else{gg[c[p+196648+(o<<2)>>2]&4095](n,g);return}}function OW(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)&255;f=c[2276054]|0;c[2276054]=f+2;g=c[2276085]|0;m=g&f;b=m&16777215;e=c[2112932]|0;j=c[e+(b>>>10<<2)>>2]|0;if(j>>>0>9){n=a[j+(m&1023^1)|0]|0;o=g;p=e}else{g=gj[c[e+196608+(j<<2)>>2]&4095](b)|0;n=g;o=c[2276085]|0;p=c[2112932]|0}g=n&255;n=g-l|0;c[2276075]=n;c[2276076]=n&255;c[2276078]=n;c[2276074]=n;c[2276077]=(n^g)&(g^l);l=o&f;f=n&255;n=l&16777215;o=c[p+((n>>>10|16384)<<2)>>2]|0;if(o>>>0>9){a[o+(l&1023^1)|0]=f;return}else{gg[c[p+196648+(o<<2)>>2]&4095](n,f);return}}function OX(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)&255;f=9104156+((c[2276069]&7|8)<<2)|0;g=(c[f>>2]|0)-1|0;c[f>>2]=g;f=c[2276085]|0;m=f&g;b=m&16777215;e=c[2112932]|0;j=c[e+(b>>>10<<2)>>2]|0;if(j>>>0>9){n=a[j+(m&1023^1)|0]|0;o=f;p=e}else{f=gj[c[e+196608+(j<<2)>>2]&4095](b)|0;n=f;o=c[2276085]|0;p=c[2112932]|0}f=n&255;n=f-l|0;c[2276075]=n;c[2276076]=n&255;c[2276078]=n;c[2276074]=n;c[2276077]=(n^f)&(f^l);l=o&g;g=n&255;n=l&16777215;o=c[p+((n>>>10|16384)<<2)>>2]|0;if(o>>>0>9){a[o+(l&1023^1)|0]=g;return}else{gg[c[p+196648+(o<<2)>>2]&4095](n,g);return}}function OY(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)&255;f=(c[2276054]|0)-2|0;c[2276054]=f;g=c[2276085]|0;m=g&f;b=m&16777215;e=c[2112932]|0;j=c[e+(b>>>10<<2)>>2]|0;if(j>>>0>9){n=a[j+(m&1023^1)|0]|0;o=g;p=e}else{g=gj[c[e+196608+(j<<2)>>2]&4095](b)|0;n=g;o=c[2276085]|0;p=c[2112932]|0}g=n&255;n=g-l|0;c[2276075]=n;c[2276076]=n&255;c[2276078]=n;c[2276074]=n;c[2276077]=(n^g)&(g^l);l=o&f;f=n&255;n=l&16777215;o=c[p+((n>>>10|16384)<<2)>>2]|0;if(o>>>0>9){a[o+(l&1023^1)|0]=f;return}else{gg[c[p+196648+(o<<2)>>2]&4095](n,f);return}}function OZ(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0)&255;f=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;o=p&-4;if((o|0)==(h|0)){q=p;r=g}else{c[2276083]=o;g=c[2276085]&o;o=g&16777212;h=c[2112932]|0;e=c[h+((o>>>10|32768)<<2)>>2]|0;if(e>>>0>9){j=g&1020;s=(d[e+(j|3)|0]|0)<<8|(d[e+(j|2)|0]|0)|((d[e+(j|1)|0]|0)<<8|(d[e+j|0]|0))<<16;t=p}else{p=gj[c[h+196768+(e<<2)>>2]&4095](o)|0;s=p;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;s=(r>>>((q<<3&16^16)>>>0)<<16>>16)+f|0;f=c[2276085]|0;q=s&f;r=q&16777215;t=c[2112932]|0;p=c[t+(r>>>10<<2)>>2]|0;if(p>>>0>9){u=a[p+(q&1023^1)|0]|0;v=f;w=t}else{f=gj[c[t+196608+(p<<2)>>2]&4095](r)|0;u=f;v=c[2276085]|0;w=c[2112932]|0}f=u&255;u=f-n|0;c[2276075]=u;c[2276076]=u&255;c[2276078]=u;c[2276074]=u;c[2276077]=(u^f)&(f^n);n=v&s;s=u&255;u=n&16777215;v=c[w+((u>>>10|16384)<<2)>>2]|0;if(v>>>0>9){a[v+(n&1023^1)|0]=s;return}else{gg[c[w+196648+(v<<2)>>2]&4095](u,s);return}}function O_(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)&255;f=Hd(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;g=c[2276085]|0;m=g&f;b=m&16777215;e=c[2112932]|0;j=c[e+(b>>>10<<2)>>2]|0;if(j>>>0>9){n=a[j+(m&1023^1)|0]|0;o=g;p=e}else{g=gj[c[e+196608+(j<<2)>>2]&4095](b)|0;n=g;o=c[2276085]|0;p=c[2112932]|0}g=n&255;n=g-l|0;c[2276075]=n;c[2276076]=n&255;c[2276078]=n;c[2276074]=n;c[2276077]=(n^g)&(g^l);l=o&f;f=n&255;n=l&16777215;o=c[p+((n>>>10|16384)<<2)>>2]|0;if(o>>>0>9){a[o+(l&1023^1)|0]=f;return}else{gg[c[p+196648+(o<<2)>>2]&4095](n,f);return}}function O$(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0)&255;f=p&-4;if((f|0)==(h|0)){q=p;r=g}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;h=c[2112932]|0;o=c[h+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=p}else{p=gj[c[h+196768+(o<<2)>>2]&4095](f)|0;s=p;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;s=r>>>((q<<3&16^16)>>>0)<<16>>16;q=c[2276085]|0;r=s&q;t=r&16777215;p=c[2112932]|0;f=c[p+(t>>>10<<2)>>2]|0;if(f>>>0>9){u=a[f+(r&1023^1)|0]|0;v=q;w=p}else{q=gj[c[p+196608+(f<<2)>>2]&4095](t)|0;u=q;v=c[2276085]|0;w=c[2112932]|0}q=u&255;u=q-n|0;c[2276075]=u;c[2276076]=u&255;c[2276078]=u;c[2276074]=u;c[2276077]=(u^q)&(q^n);n=v&s;s=u&255;u=n&16777215;v=c[w+((u>>>10|16384)<<2)>>2]|0;if(v>>>0>9){a[v+(n&1023^1)|0]=s;return}else{gg[c[w+196648+(v<<2)>>2]&4095](u,s);return}}function O0(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0)&255;f=p&-4;if((f|0)==(h|0)){q=p;r=h;s=g}else{c[2276083]=f;g=c[2276085]&f;h=g&16777212;o=c[2112932]|0;e=c[o+((h>>>10|32768)<<2)>>2]|0;if(e>>>0>9){j=g&1020;t=(d[e+(j|3)|0]|0)<<8|(d[e+(j|2)|0]|0)|((d[e+(j|1)|0]|0)<<8|(d[e+j|0]|0))<<16;u=p;v=f}else{f=gj[c[o+196768+(e<<2)>>2]&4095](h)|0;t=f;u=c[2276056]|0;v=c[2276083]|0}c[2276084]=t;q=u;r=v;s=t}t=q+2|0;c[2276056]=t;q=t&-4;if((q|0)==(r|0)){w=s;x=t}else{c[2276083]=q;r=c[2276085]&q;q=r&16777212;v=c[2112932]|0;u=c[v+((q>>>10|32768)<<2)>>2]|0;if(u>>>0>9){f=r&1020;y=(d[u+(f|3)|0]|0)<<8|(d[u+(f|2)|0]|0)|((d[u+(f|1)|0]|0)<<8|(d[u+f|0]|0))<<16;z=t}else{t=gj[c[v+196768+(u<<2)>>2]&4095](q)|0;y=t;z=c[2276056]|0}c[2276084]=y;w=y>>>16|s<<16;x=z}c[2276056]=x+2;x=c[2276085]|0;z=x&w;s=z&16777215;y=c[2112932]|0;t=c[y+(s>>>10<<2)>>2]|0;if(t>>>0>9){A=a[t+(z&1023^1)|0]|0;B=x;C=y}else{x=gj[c[y+196608+(t<<2)>>2]&4095](s)|0;A=x;B=c[2276085]|0;C=c[2112932]|0}x=A&255;A=x-n|0;c[2276075]=A;c[2276076]=A&255;c[2276078]=A;c[2276074]=A;c[2276077]=(A^x)&(x^n);n=B&w;w=A&255;A=n&16777215;B=c[C+((A>>>10|16384)<<2)>>2]|0;if(B>>>0>9){a[B+(n&1023^1)|0]=w;return}else{gg[c[C+196648+(B<<2)>>2]&4095](A,w);return}}function O1(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=9104156+((c[2276069]&7)<<2)|0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0);f=l&65535;g=c[a>>2]|0;m=g&65535;b=m-f|0;e=b>>>8;c[2276075]=e;j=g-l&65535;c[2276076]=j;c[2276078]=e;c[2276074]=e;c[2276077]=((b^g)&(f^m))>>>8;c[a>>2]=j|c[a>>2]&-65536;return}function O2(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)&65535;f=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;g=c[2276085]|0;m=g&f;b=m&16777215;e=c[2112932]|0;j=c[e+(b>>>10<<2)>>2]|0;if(j>>>0>9){i=m&1023;n=(d[j+(i+1)|0]|0)<<8|(d[j+i|0]|0);o=g;p=e}else{g=gj[c[e+196688+(j<<2)>>2]&4095](b)|0;n=g;o=c[2276085]|0;p=c[2112932]|0}g=n&65535;n=g-l|0;b=n>>>8;c[2276075]=b;c[2276076]=n&65535;c[2276078]=b;c[2276074]=b;c[2276077]=((n^g)&(g^l))>>>8;l=o&f;f=n&65535;o=l&16777215;g=c[p+((o>>>10|16384)<<2)>>2]|0;if(g>>>0>9){b=l&1023;a[g+b|0]=n&255;a[g+(b+1)|0]=(f&65535)>>>8&255;return}else{gg[c[p+196728+(g<<2)>>2]&4095](o,f);return}}function O3(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)&65535;f=9104156+((c[2276069]&7|8)<<2)|0;g=c[f>>2]|0;c[f>>2]=g+2;f=c[2276085]|0;m=f&g;b=m&16777215;e=c[2112932]|0;j=c[e+(b>>>10<<2)>>2]|0;if(j>>>0>9){i=m&1023;n=(d[j+(i+1)|0]|0)<<8|(d[j+i|0]|0);o=f;p=e}else{f=gj[c[e+196688+(j<<2)>>2]&4095](b)|0;n=f;o=c[2276085]|0;p=c[2112932]|0}f=n&65535;n=f-l|0;b=n>>>8;c[2276075]=b;c[2276076]=n&65535;c[2276078]=b;c[2276074]=b;c[2276077]=((n^f)&(f^l))>>>8;l=o&g;g=n&65535;o=l&16777215;f=c[p+((o>>>10|16384)<<2)>>2]|0;if(f>>>0>9){b=l&1023;a[f+b|0]=n&255;a[f+(b+1)|0]=(g&65535)>>>8&255;return}else{gg[c[p+196728+(f<<2)>>2]&4095](o,g);return}}function O4(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)&65535;f=9104156+((c[2276069]&7|8)<<2)|0;g=(c[f>>2]|0)-2|0;c[f>>2]=g;f=c[2276085]|0;m=f&g;b=m&16777215;e=c[2112932]|0;j=c[e+(b>>>10<<2)>>2]|0;if(j>>>0>9){i=m&1023;n=(d[j+(i+1)|0]|0)<<8|(d[j+i|0]|0);o=f;p=e}else{f=gj[c[e+196688+(j<<2)>>2]&4095](b)|0;n=f;o=c[2276085]|0;p=c[2112932]|0}f=n&65535;n=f-l|0;b=n>>>8;c[2276075]=b;c[2276076]=n&65535;c[2276078]=b;c[2276074]=b;c[2276077]=((n^f)&(f^l))>>>8;l=o&g;g=n&65535;o=l&16777215;f=c[p+((o>>>10|16384)<<2)>>2]|0;if(f>>>0>9){b=l&1023;a[f+b|0]=n&255;a[f+(b+1)|0]=(g&65535)>>>8&255;return}else{gg[c[p+196728+(f<<2)>>2]&4095](o,g);return}}function O5(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0)&65535;f=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;o=p&-4;if((o|0)==(h|0)){q=p;r=g}else{c[2276083]=o;g=c[2276085]&o;o=g&16777212;h=c[2112932]|0;e=c[h+((o>>>10|32768)<<2)>>2]|0;if(e>>>0>9){j=g&1020;s=(d[e+(j|3)|0]|0)<<8|(d[e+(j|2)|0]|0)|((d[e+(j|1)|0]|0)<<8|(d[e+j|0]|0))<<16;t=p}else{p=gj[c[h+196768+(e<<2)>>2]&4095](o)|0;s=p;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;s=(r>>>((q<<3&16^16)>>>0)<<16>>16)+f|0;f=c[2276085]|0;q=s&f;r=q&16777215;t=c[2112932]|0;p=c[t+(r>>>10<<2)>>2]|0;if(p>>>0>9){o=q&1023;u=(d[p+(o+1)|0]|0)<<8|(d[p+o|0]|0);v=f;w=t}else{f=gj[c[t+196688+(p<<2)>>2]&4095](r)|0;u=f;v=c[2276085]|0;w=c[2112932]|0}f=u&65535;u=f-n|0;r=u>>>8;c[2276075]=r;c[2276076]=u&65535;c[2276078]=r;c[2276074]=r;c[2276077]=((u^f)&(f^n))>>>8;n=v&s;s=u&65535;v=n&16777215;f=c[w+((v>>>10|16384)<<2)>>2]|0;if(f>>>0>9){r=n&1023;a[f+r|0]=u&255;a[f+(r+1)|0]=(s&65535)>>>8&255;return}else{gg[c[w+196728+(f<<2)>>2]&4095](v,s);return}}function O6(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)&65535;f=Hd(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;g=c[2276085]|0;m=g&f;b=m&16777215;e=c[2112932]|0;j=c[e+(b>>>10<<2)>>2]|0;if(j>>>0>9){i=m&1023;n=(d[j+(i+1)|0]|0)<<8|(d[j+i|0]|0);o=g;p=e}else{g=gj[c[e+196688+(j<<2)>>2]&4095](b)|0;n=g;o=c[2276085]|0;p=c[2112932]|0}g=n&65535;n=g-l|0;b=n>>>8;c[2276075]=b;c[2276076]=n&65535;c[2276078]=b;c[2276074]=b;c[2276077]=((n^g)&(g^l))>>>8;l=o&f;f=n&65535;o=l&16777215;g=c[p+((o>>>10|16384)<<2)>>2]|0;if(g>>>0>9){b=l&1023;a[g+b|0]=n&255;a[g+(b+1)|0]=(f&65535)>>>8&255;return}else{gg[c[p+196728+(g<<2)>>2]&4095](o,f);return}}function O7(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0)&65535;f=p&-4;if((f|0)==(h|0)){q=p;r=g}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;h=c[2112932]|0;o=c[h+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=p}else{p=gj[c[h+196768+(o<<2)>>2]&4095](f)|0;s=p;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;s=r>>>((q<<3&16^16)>>>0)<<16>>16;q=c[2276085]|0;r=s&q;t=r&16777215;p=c[2112932]|0;f=c[p+(t>>>10<<2)>>2]|0;if(f>>>0>9){o=r&1023;u=(d[f+(o+1)|0]|0)<<8|(d[f+o|0]|0);v=q;w=p}else{q=gj[c[p+196688+(f<<2)>>2]&4095](t)|0;u=q;v=c[2276085]|0;w=c[2112932]|0}q=u&65535;u=q-n|0;t=u>>>8;c[2276075]=t;c[2276076]=u&65535;c[2276078]=t;c[2276074]=t;c[2276077]=((u^q)&(q^n))>>>8;n=v&s;s=u&65535;v=n&16777215;q=c[w+((v>>>10|16384)<<2)>>2]|0;if(q>>>0>9){t=n&1023;a[q+t|0]=u&255;a[q+(t+1)|0]=(s&65535)>>>8&255;return}else{gg[c[w+196728+(q<<2)>>2]&4095](v,s);return}}function O8(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0)&65535;f=p&-4;if((f|0)==(h|0)){q=p;r=h;s=g}else{c[2276083]=f;g=c[2276085]&f;h=g&16777212;o=c[2112932]|0;e=c[o+((h>>>10|32768)<<2)>>2]|0;if(e>>>0>9){j=g&1020;t=(d[e+(j|3)|0]|0)<<8|(d[e+(j|2)|0]|0)|((d[e+(j|1)|0]|0)<<8|(d[e+j|0]|0))<<16;u=p;v=f}else{f=gj[c[o+196768+(e<<2)>>2]&4095](h)|0;t=f;u=c[2276056]|0;v=c[2276083]|0}c[2276084]=t;q=u;r=v;s=t}t=q+2|0;c[2276056]=t;q=t&-4;if((q|0)==(r|0)){w=s;x=t}else{c[2276083]=q;r=c[2276085]&q;q=r&16777212;v=c[2112932]|0;u=c[v+((q>>>10|32768)<<2)>>2]|0;if(u>>>0>9){f=r&1020;y=(d[u+(f|3)|0]|0)<<8|(d[u+(f|2)|0]|0)|((d[u+(f|1)|0]|0)<<8|(d[u+f|0]|0))<<16;z=t}else{t=gj[c[v+196768+(u<<2)>>2]&4095](q)|0;y=t;z=c[2276056]|0}c[2276084]=y;w=y>>>16|s<<16;x=z}c[2276056]=x+2;x=c[2276085]|0;z=x&w;s=z&16777215;y=c[2112932]|0;t=c[y+(s>>>10<<2)>>2]|0;if(t>>>0>9){q=z&1023;A=(d[t+(q+1)|0]|0)<<8|(d[t+q|0]|0);B=x;C=y}else{x=gj[c[y+196688+(t<<2)>>2]&4095](s)|0;A=x;B=c[2276085]|0;C=c[2112932]|0}x=A&65535;A=x-n|0;s=A>>>8;c[2276075]=s;c[2276076]=A&65535;c[2276078]=s;c[2276074]=s;c[2276077]=((A^x)&(x^n))>>>8;n=B&w;w=A&65535;B=n&16777215;x=c[C+((B>>>10|16384)<<2)>>2]|0;if(x>>>0>9){s=n&1023;a[x+s|0]=A&255;a[x+(s+1)|0]=(w&65535)>>>8&255;return}else{gg[c[C+196728+(x<<2)>>2]&4095](B,w);return}}function O9(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;a=9104156+((c[2276069]&7)<<2)|0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n;s=r+2|0;c[2276056]=s;t=c[a>>2]|0;u=t-q|0;v=u>>>24;c[2276075]=v;c[2276076]=u;w=u&q;x=t^-8388608;y=u|q;z=y&x;A=z|w;B=A>>>23;c[2276078]=B;c[2276074]=B;C=t^q;D=u^t;E=D&C;F=E>>>24;c[2276077]=F;c[a>>2]=u;return}c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;G=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;H=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;G=n;H=c[2276056]|0}c[2276084]=G;q=G>>>16|h<<16;r=H;s=r+2|0;c[2276056]=s;t=c[a>>2]|0;u=t-q|0;v=u>>>24;c[2276075]=v;c[2276076]=u;w=u&q;x=t^-8388608;y=u|q;z=y&x;A=z|w;B=A>>>23;c[2276078]=B;c[2276074]=B;C=t^q;D=u^t;E=D&C;F=E>>>24;c[2276077]=F;c[a>>2]=u;return}function Pa(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;t=c[2276085]|0;h=t&r;s=h&16777215;n=c[2112932]|0;f=c[n+(s>>>10<<2)>>2]|0;if(f>>>0>9){o=h&1023;u=(d[f+(o+3)|0]|0)<<8|(d[f+(o+2)|0]|0)|((d[f+(o+1)|0]|0)<<8|(d[f+o|0]|0))<<16;v=t;w=n}else{t=gj[c[n+196768+(f<<2)>>2]&4095](s)|0;u=t;v=c[2276085]|0;w=c[2112932]|0}t=u-q|0;s=t>>>24;c[2276075]=s;c[2276076]=t;f=((t|q)&(u^-8388608)|t&q)>>>23;c[2276078]=f;c[2276074]=f;c[2276077]=((t^u)&(u^q))>>>24;q=v&r;r=q&16777215;v=c[w+((r>>>10|16384)<<2)>>2]|0;if(v>>>0>9){u=q&1023;a[v+u|0]=t>>>16&255;a[v+(u+1)|0]=s&255;a[v+(u+2)|0]=t&255;a[v+(u+3)|0]=t>>>8&255;return}else{gg[c[w+196808+(v<<2)>>2]&4095](r,t);return}}function Pb(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=9104156+((c[2276069]&7|8)<<2)|0;t=c[r>>2]|0;c[r>>2]=t+4;r=c[2276085]|0;h=r&t;s=h&16777215;n=c[2112932]|0;f=c[n+(s>>>10<<2)>>2]|0;if(f>>>0>9){o=h&1023;u=(d[f+(o+3)|0]|0)<<8|(d[f+(o+2)|0]|0)|((d[f+(o+1)|0]|0)<<8|(d[f+o|0]|0))<<16;v=r;w=n}else{r=gj[c[n+196768+(f<<2)>>2]&4095](s)|0;u=r;v=c[2276085]|0;w=c[2112932]|0}r=u-q|0;s=r>>>24;c[2276075]=s;c[2276076]=r;f=((r|q)&(u^-8388608)|r&q)>>>23;c[2276078]=f;c[2276074]=f;c[2276077]=((r^u)&(u^q))>>>24;q=v&t;t=q&16777215;v=c[w+((t>>>10|16384)<<2)>>2]|0;if(v>>>0>9){u=q&1023;a[v+u|0]=r>>>16&255;a[v+(u+1)|0]=s&255;a[v+(u+2)|0]=r&255;a[v+(u+3)|0]=r>>>8&255;return}else{gg[c[w+196808+(v<<2)>>2]&4095](t,r);return}}function Pc(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=9104156+((c[2276069]&7|8)<<2)|0;t=(c[r>>2]|0)-4|0;c[r>>2]=t;r=c[2276085]|0;h=r&t;s=h&16777215;n=c[2112932]|0;f=c[n+(s>>>10<<2)>>2]|0;if(f>>>0>9){o=h&1023;u=(d[f+(o+3)|0]|0)<<8|(d[f+(o+2)|0]|0)|((d[f+(o+1)|0]|0)<<8|(d[f+o|0]|0))<<16;v=r;w=n}else{r=gj[c[n+196768+(f<<2)>>2]&4095](s)|0;u=r;v=c[2276085]|0;w=c[2112932]|0}r=u-q|0;s=r>>>24;c[2276075]=s;c[2276076]=r;f=((r|q)&(u^-8388608)|r&q)>>>23;c[2276078]=f;c[2276074]=f;c[2276077]=((r^u)&(u^q))>>>24;q=v&t;t=q&16777215;v=c[w+((t>>>10|16384)<<2)>>2]|0;if(v>>>0>9){u=q&1023;a[v+u|0]=r>>>16&255;a[v+(u+1)|0]=s&255;a[v+(u+2)|0]=r&255;a[v+(u+3)|0]=r>>>8&255;return}else{gg[c[w+196808+(v<<2)>>2]&4095](t,r);return}}function Pd(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;f=p&-4;if((f|0)==(h|0)){q=g;r=p;s=h;t=g}else{c[2276083]=f;h=c[2276085]&f;n=h&16777212;o=c[2112932]|0;e=c[o+((n>>>10|32768)<<2)>>2]|0;if(e>>>0>9){j=h&1020;u=(d[e+(j|3)|0]|0)<<8|(d[e+(j|2)|0]|0)|((d[e+(j|1)|0]|0)<<8|(d[e+j|0]|0))<<16;v=p;w=f}else{f=gj[c[o+196768+(e<<2)>>2]&4095](n)|0;u=f;v=c[2276056]|0;w=c[2276083]|0}c[2276084]=u;q=u>>>16|g<<16;r=v;s=w;t=u}u=r+2|0;c[2276056]=u;r=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;w=u&-4;if((w|0)==(s|0)){x=u;y=t}else{c[2276083]=w;t=c[2276085]&w;w=t&16777212;s=c[2112932]|0;v=c[s+((w>>>10|32768)<<2)>>2]|0;if(v>>>0>9){g=t&1020;z=(d[v+(g|3)|0]|0)<<8|(d[v+(g|2)|0]|0)|((d[v+(g|1)|0]|0)<<8|(d[v+g|0]|0))<<16;A=u}else{u=gj[c[s+196768+(v<<2)>>2]&4095](w)|0;z=u;A=c[2276056]|0}c[2276084]=z;x=A;y=z}c[2276056]=x+2;z=(y>>>((x<<3&16^16)>>>0)<<16>>16)+r|0;r=c[2276085]|0;x=z&r;y=x&16777215;A=c[2112932]|0;u=c[A+(y>>>10<<2)>>2]|0;if(u>>>0>9){w=x&1023;B=(d[u+(w+3)|0]|0)<<8|(d[u+(w+2)|0]|0)|((d[u+(w+1)|0]|0)<<8|(d[u+w|0]|0))<<16;C=r;D=A}else{r=gj[c[A+196768+(u<<2)>>2]&4095](y)|0;B=r;C=c[2276085]|0;D=c[2112932]|0}r=B-q|0;y=r>>>24;c[2276075]=y;c[2276076]=r;u=((r|q)&(B^-8388608)|r&q)>>>23;c[2276078]=u;c[2276074]=u;c[2276077]=((r^B)&(B^q))>>>24;q=C&z;z=q&16777215;C=c[D+((z>>>10|16384)<<2)>>2]|0;if(C>>>0>9){B=q&1023;a[C+B|0]=r>>>16&255;a[C+(B+1)|0]=y&255;a[C+(B+2)|0]=r&255;a[C+(B+3)|0]=r>>>8&255;return}else{gg[c[D+196808+(C<<2)>>2]&4095](z,r);return}}function Pe(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=Hd(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;t=c[2276085]|0;h=t&r;s=h&16777215;n=c[2112932]|0;f=c[n+(s>>>10<<2)>>2]|0;if(f>>>0>9){o=h&1023;u=(d[f+(o+3)|0]|0)<<8|(d[f+(o+2)|0]|0)|((d[f+(o+1)|0]|0)<<8|(d[f+o|0]|0))<<16;v=t;w=n}else{t=gj[c[n+196768+(f<<2)>>2]&4095](s)|0;u=t;v=c[2276085]|0;w=c[2112932]|0}t=u-q|0;s=t>>>24;c[2276075]=s;c[2276076]=t;f=((t|q)&(u^-8388608)|t&q)>>>23;c[2276078]=f;c[2276074]=f;c[2276077]=((t^u)&(u^q))>>>24;q=v&r;r=q&16777215;v=c[w+((r>>>10|16384)<<2)>>2]|0;if(v>>>0>9){u=q&1023;a[v+u|0]=t>>>16&255;a[v+(u+1)|0]=s&255;a[v+(u+2)|0]=t&255;a[v+(u+3)|0]=t>>>8&255;return}else{gg[c[w+196808+(v<<2)>>2]&4095](r,t);return}}function Pf(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;f=p&-4;if((f|0)==(h|0)){q=g;r=p;s=h;t=g}else{c[2276083]=f;h=c[2276085]&f;n=h&16777212;o=c[2112932]|0;e=c[o+((n>>>10|32768)<<2)>>2]|0;if(e>>>0>9){j=h&1020;u=(d[e+(j|3)|0]|0)<<8|(d[e+(j|2)|0]|0)|((d[e+(j|1)|0]|0)<<8|(d[e+j|0]|0))<<16;v=p;w=f}else{f=gj[c[o+196768+(e<<2)>>2]&4095](n)|0;u=f;v=c[2276056]|0;w=c[2276083]|0}c[2276084]=u;q=u>>>16|g<<16;r=v;s=w;t=u}u=r+2|0;c[2276056]=u;r=u&-4;if((r|0)==(s|0)){x=u;y=t}else{c[2276083]=r;t=c[2276085]&r;r=t&16777212;s=c[2112932]|0;w=c[s+((r>>>10|32768)<<2)>>2]|0;if(w>>>0>9){v=t&1020;z=(d[w+(v|3)|0]|0)<<8|(d[w+(v|2)|0]|0)|((d[w+(v|1)|0]|0)<<8|(d[w+v|0]|0))<<16;A=u}else{u=gj[c[s+196768+(w<<2)>>2]&4095](r)|0;z=u;A=c[2276056]|0}c[2276084]=z;x=A;y=z}c[2276056]=x+2;z=y>>>((x<<3&16^16)>>>0)<<16>>16;x=c[2276085]|0;y=z&x;A=y&16777215;u=c[2112932]|0;r=c[u+(A>>>10<<2)>>2]|0;if(r>>>0>9){w=y&1023;B=(d[r+(w+3)|0]|0)<<8|(d[r+(w+2)|0]|0)|((d[r+(w+1)|0]|0)<<8|(d[r+w|0]|0))<<16;C=x;D=u}else{x=gj[c[u+196768+(r<<2)>>2]&4095](A)|0;B=x;C=c[2276085]|0;D=c[2112932]|0}x=B-q|0;A=x>>>24;c[2276075]=A;c[2276076]=x;r=((x|q)&(B^-8388608)|x&q)>>>23;c[2276078]=r;c[2276074]=r;c[2276077]=((x^B)&(B^q))>>>24;q=C&z;z=q&16777215;C=c[D+((z>>>10|16384)<<2)>>2]|0;if(C>>>0>9){B=q&1023;a[C+B|0]=x>>>16&255;a[C+(B+1)|0]=A&255;a[C+(B+2)|0]=x&255;a[C+(B+3)|0]=x>>>8&255;return}else{gg[c[D+196808+(C<<2)>>2]&4095](z,x);return}}function Pg(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;f=p&-4;if((f|0)==(h|0)){q=g;r=p;s=h;t=g}else{c[2276083]=f;h=c[2276085]&f;n=h&16777212;o=c[2112932]|0;e=c[o+((n>>>10|32768)<<2)>>2]|0;if(e>>>0>9){j=h&1020;u=(d[e+(j|3)|0]|0)<<8|(d[e+(j|2)|0]|0)|((d[e+(j|1)|0]|0)<<8|(d[e+j|0]|0))<<16;v=p;w=f}else{f=gj[c[o+196768+(e<<2)>>2]&4095](n)|0;u=f;v=c[2276056]|0;w=c[2276083]|0}c[2276084]=u;q=u>>>16|g<<16;r=v;s=w;t=u}u=r+2|0;c[2276056]=u;r=u&-4;if((r|0)==(s|0)){x=u;y=s;z=t}else{c[2276083]=r;t=c[2276085]&r;s=t&16777212;w=c[2112932]|0;v=c[w+((s>>>10|32768)<<2)>>2]|0;if(v>>>0>9){g=t&1020;A=(d[v+(g|3)|0]|0)<<8|(d[v+(g|2)|0]|0)|((d[v+(g|1)|0]|0)<<8|(d[v+g|0]|0))<<16;B=u;C=r}else{r=gj[c[w+196768+(v<<2)>>2]&4095](s)|0;A=r;B=c[2276056]|0;C=c[2276083]|0}c[2276084]=A;x=B;y=C;z=A}A=x+2|0;c[2276056]=A;x=A&-4;if((x|0)==(y|0)){D=z;E=A}else{c[2276083]=x;y=c[2276085]&x;x=y&16777212;C=c[2112932]|0;B=c[C+((x>>>10|32768)<<2)>>2]|0;if(B>>>0>9){r=y&1020;F=(d[B+(r|3)|0]|0)<<8|(d[B+(r|2)|0]|0)|((d[B+(r|1)|0]|0)<<8|(d[B+r|0]|0))<<16;G=A}else{A=gj[c[C+196768+(B<<2)>>2]&4095](x)|0;F=A;G=c[2276056]|0}c[2276084]=F;D=F>>>16|z<<16;E=G}c[2276056]=E+2;E=c[2276085]|0;G=E&D;z=G&16777215;F=c[2112932]|0;A=c[F+(z>>>10<<2)>>2]|0;if(A>>>0>9){x=G&1023;H=(d[A+(x+3)|0]|0)<<8|(d[A+(x+2)|0]|0)|((d[A+(x+1)|0]|0)<<8|(d[A+x|0]|0))<<16;I=E;J=F}else{E=gj[c[F+196768+(A<<2)>>2]&4095](z)|0;H=E;I=c[2276085]|0;J=c[2112932]|0}E=H-q|0;z=E>>>24;c[2276075]=z;c[2276076]=E;A=((E|q)&(H^-8388608)|E&q)>>>23;c[2276078]=A;c[2276074]=A;c[2276077]=((E^H)&(H^q))>>>24;q=I&D;D=q&16777215;I=c[J+((D>>>10|16384)<<2)>>2]|0;if(I>>>0>9){H=q&1023;a[I+H|0]=E>>>16&255;a[I+(H+1)|0]=z&255;a[I+(H+2)|0]=E&255;a[I+(H+3)|0]=E>>>8&255;return}else{gg[c[J+196808+(I<<2)>>2]&4095](D,E);return}}function Ph(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[2276069]|0;b=9104156+((a&7)<<2)|0;d=((a>>>9)+7&7)+1|0;a=c[b>>2]|0;e=a&255;f=e-d|0;c[2276075]=f;g=a-d&255;c[2276076]=g;c[2276078]=f;c[2276074]=f;c[2276077]=(f^e)&(d^e);c[b>>2]=g|c[b>>2]&-256;return}function Pi(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=c[2276069]|0;d=((b>>>9)+7&7)+1|0;e=c[9104156+((b&7|8)<<2)>>2]|0;b=c[2276085]|0;f=b&e;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=a[i+(f&1023^1)|0]|0;k=b;l=h}else{b=gj[c[h+196608+(i<<2)>>2]&4095](g)|0;j=b;k=c[2276085]|0;l=c[2112932]|0}b=j&255;j=b-d|0;c[2276075]=j;c[2276076]=j&255;c[2276078]=j;c[2276074]=j;c[2276077]=(j^b)&(b^d);d=k&e;e=j&255;j=d&16777215;k=c[l+((j>>>10|16384)<<2)>>2]|0;if(k>>>0>9){a[k+(d&1023^1)|0]=e;return}else{gg[c[l+196648+(k<<2)>>2]&4095](j,e);return}}function Pj(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=c[2276069]|0;d=((b>>>9)+7&7)+1|0;e=9104156+((b&7|8)<<2)|0;b=c[e>>2]|0;c[e>>2]=b+1;e=c[2276085]|0;f=e&b;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=a[i+(f&1023^1)|0]|0;k=e;l=h}else{e=gj[c[h+196608+(i<<2)>>2]&4095](g)|0;j=e;k=c[2276085]|0;l=c[2112932]|0}e=j&255;j=e-d|0;c[2276075]=j;c[2276076]=j&255;c[2276078]=j;c[2276074]=j;c[2276077]=(j^e)&(e^d);d=k&b;b=j&255;j=d&16777215;k=c[l+((j>>>10|16384)<<2)>>2]|0;if(k>>>0>9){a[k+(d&1023^1)|0]=b;return}else{gg[c[l+196648+(k<<2)>>2]&4095](j,b);return}}function Pk(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=(((c[2276069]|0)>>>9)+7&7)+1|0;d=c[2276054]|0;c[2276054]=d+2;e=c[2276085]|0;f=e&d;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=a[i+(f&1023^1)|0]|0;k=e;l=h}else{e=gj[c[h+196608+(i<<2)>>2]&4095](g)|0;j=e;k=c[2276085]|0;l=c[2112932]|0}e=j&255;j=e-b|0;c[2276075]=j;c[2276076]=j&255;c[2276078]=j;c[2276074]=j;c[2276077]=(j^e)&(e^b);b=k&d;d=j&255;j=b&16777215;k=c[l+((j>>>10|16384)<<2)>>2]|0;if(k>>>0>9){a[k+(b&1023^1)|0]=d;return}else{gg[c[l+196648+(k<<2)>>2]&4095](j,d);return}}function Pl(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=c[2276069]|0;d=((b>>>9)+7&7)+1|0;e=9104156+((b&7|8)<<2)|0;b=(c[e>>2]|0)-1|0;c[e>>2]=b;e=c[2276085]|0;f=e&b;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=a[i+(f&1023^1)|0]|0;k=e;l=h}else{e=gj[c[h+196608+(i<<2)>>2]&4095](g)|0;j=e;k=c[2276085]|0;l=c[2112932]|0}e=j&255;j=e-d|0;c[2276075]=j;c[2276076]=j&255;c[2276078]=j;c[2276074]=j;c[2276077]=(j^e)&(e^d);d=k&b;b=j&255;j=d&16777215;k=c[l+((j>>>10|16384)<<2)>>2]|0;if(k>>>0>9){a[k+(d&1023^1)|0]=b;return}else{gg[c[l+196648+(k<<2)>>2]&4095](j,b);return}}function Pm(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=(((c[2276069]|0)>>>9)+7&7)+1|0;d=(c[2276054]|0)-2|0;c[2276054]=d;e=c[2276085]|0;f=e&d;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=a[i+(f&1023^1)|0]|0;k=e;l=h}else{e=gj[c[h+196608+(i<<2)>>2]&4095](g)|0;j=e;k=c[2276085]|0;l=c[2112932]|0}e=j&255;j=e-b|0;c[2276075]=j;c[2276076]=j&255;c[2276078]=j;c[2276074]=j;c[2276077]=(j^e)&(e^b);b=k&d;d=j&255;j=b&16777215;k=c[l+((j>>>10|16384)<<2)>>2]|0;if(k>>>0>9){a[k+(b&1023^1)|0]=d;return}else{gg[c[l+196648+(k<<2)>>2]&4095](j,d);return}}function Pn(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=c[2276069]|0;e=((b>>>9)+7&7)+1|0;f=c[9104156+((b&7|8)<<2)>>2]|0;b=c[2276056]|0;g=b&-4;if((g|0)==(c[2276083]|0)){h=b;i=c[2276084]|0}else{c[2276083]=g;j=c[2276085]&g;g=j&16777212;k=c[2112932]|0;l=c[k+((g>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=j&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b}else{b=gj[c[k+196768+(l<<2)>>2]&4095](g)|0;n=b;o=c[2276056]|0}c[2276084]=n;h=o;i=n}c[2276056]=h+2;n=(i>>>((h<<3&16^16)>>>0)<<16>>16)+f|0;f=c[2276085]|0;h=n&f;i=h&16777215;o=c[2112932]|0;b=c[o+(i>>>10<<2)>>2]|0;if(b>>>0>9){p=a[b+(h&1023^1)|0]|0;q=f;r=o}else{f=gj[c[o+196608+(b<<2)>>2]&4095](i)|0;p=f;q=c[2276085]|0;r=c[2112932]|0}f=p&255;p=f-e|0;c[2276075]=p;c[2276076]=p&255;c[2276078]=p;c[2276074]=p;c[2276077]=(p^f)&(f^e);e=q&n;n=p&255;p=e&16777215;q=c[r+((p>>>10|16384)<<2)>>2]|0;if(q>>>0>9){a[q+(e&1023^1)|0]=n;return}else{gg[c[r+196648+(q<<2)>>2]&4095](p,n);return}}function Po(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=c[2276069]|0;d=((b>>>9)+7&7)+1|0;e=Hd(c[9104156+((b&7|8)<<2)>>2]|0)|0;b=c[2276085]|0;f=b&e;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=a[i+(f&1023^1)|0]|0;k=b;l=h}else{b=gj[c[h+196608+(i<<2)>>2]&4095](g)|0;j=b;k=c[2276085]|0;l=c[2112932]|0}b=j&255;j=b-d|0;c[2276075]=j;c[2276076]=j&255;c[2276078]=j;c[2276074]=j;c[2276077]=(j^b)&(b^d);d=k&e;e=j&255;j=d&16777215;k=c[l+((j>>>10|16384)<<2)>>2]|0;if(k>>>0>9){a[k+(d&1023^1)|0]=e;return}else{gg[c[l+196648+(k<<2)>>2]&4095](j,e);return}}function Pp(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=(((c[2276069]|0)>>>9)+7&7)+1|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=h>>>((g<<3&16^16)>>>0)<<16>>16;g=c[2276085]|0;h=m&g;n=h&16777215;e=c[2112932]|0;f=c[e+(n>>>10<<2)>>2]|0;if(f>>>0>9){o=a[f+(h&1023^1)|0]|0;p=g;q=e}else{g=gj[c[e+196608+(f<<2)>>2]&4095](n)|0;o=g;p=c[2276085]|0;q=c[2112932]|0}g=o&255;o=g-b|0;c[2276075]=o;c[2276076]=o&255;c[2276078]=o;c[2276074]=o;c[2276077]=(o^g)&(g^b);b=p&m;m=o&255;o=b&16777215;p=c[q+((o>>>10|16384)<<2)>>2]|0;if(p>>>0>9){a[p+(b&1023^1)|0]=m;return}else{gg[c[q+196648+(p<<2)>>2]&4095](o,m);return}}function Pq(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;b=(((c[2276069]|0)>>>9)+7&7)+1|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=f;i=c[2276084]|0}else{c[2276083]=f;j=c[2276085]&f;k=j&16777212;l=c[2112932]|0;m=c[l+((k>>>10|32768)<<2)>>2]|0;if(m>>>0>9){n=j&1020;o=(d[m+(n|3)|0]|0)<<8|(d[m+(n|2)|0]|0)|((d[m+(n|1)|0]|0)<<8|(d[m+n|0]|0))<<16;p=e;q=f}else{f=gj[c[l+196768+(m<<2)>>2]&4095](k)|0;o=f;p=c[2276056]|0;q=c[2276083]|0}c[2276084]=o;g=p;h=q;i=o}o=g+2|0;c[2276056]=o;g=o&-4;if((g|0)==(h|0)){r=i;s=o}else{c[2276083]=g;h=c[2276085]&g;g=h&16777212;q=c[2112932]|0;p=c[q+((g>>>10|32768)<<2)>>2]|0;if(p>>>0>9){f=h&1020;t=(d[p+(f|3)|0]|0)<<8|(d[p+(f|2)|0]|0)|((d[p+(f|1)|0]|0)<<8|(d[p+f|0]|0))<<16;u=o}else{o=gj[c[q+196768+(p<<2)>>2]&4095](g)|0;t=o;u=c[2276056]|0}c[2276084]=t;r=t>>>16|i<<16;s=u}c[2276056]=s+2;s=c[2276085]|0;u=s&r;i=u&16777215;t=c[2112932]|0;o=c[t+(i>>>10<<2)>>2]|0;if(o>>>0>9){v=a[o+(u&1023^1)|0]|0;w=s;x=t}else{s=gj[c[t+196608+(o<<2)>>2]&4095](i)|0;v=s;w=c[2276085]|0;x=c[2112932]|0}s=v&255;v=s-b|0;c[2276075]=v;c[2276076]=v&255;c[2276078]=v;c[2276074]=v;c[2276077]=(v^s)&(s^b);b=w&r;r=v&255;v=b&16777215;w=c[x+((v>>>10|16384)<<2)>>2]|0;if(w>>>0>9){a[w+(b&1023^1)|0]=r;return}else{gg[c[x+196648+(w<<2)>>2]&4095](v,r);return}}function Pr(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0;a=c[2276069]|0;b=9104156+((a&7)<<2)|0;d=((a>>>9)+7&7)+1|0;a=c[b>>2]|0;e=a&65535;f=e-d|0;g=f>>>8;c[2276075]=g;h=a-d&65535;c[2276076]=h;c[2276078]=g;c[2276074]=g;c[2276077]=((f^e)&(d^e))>>>8;c[b>>2]=h|c[b>>2]&-65536;return}function Ps(){var a=0,b=0;a=c[2276069]|0;b=9104156+((a&7|8)<<2)|0;c[b>>2]=(c[b>>2]|0)-1-((a>>>9)+7&7);return}function Pt(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[2276069]|0;e=((b>>>9)+7&7)+1|0;f=c[9104156+((b&7|8)<<2)>>2]|0;b=c[2276085]|0;g=b&f;h=g&16777215;i=c[2112932]|0;j=c[i+(h>>>10<<2)>>2]|0;if(j>>>0>9){k=g&1023;l=(d[j+(k+1)|0]|0)<<8|(d[j+k|0]|0);m=b;n=i}else{b=gj[c[i+196688+(j<<2)>>2]&4095](h)|0;l=b;m=c[2276085]|0;n=c[2112932]|0}b=l&65535;l=b-e|0;h=l>>>8;c[2276075]=h;c[2276076]=l&65535;c[2276078]=h;c[2276074]=h;c[2276077]=((l^b)&(b^e))>>>8;e=m&f;f=l&65535;m=e&16777215;b=c[n+((m>>>10|16384)<<2)>>2]|0;if(b>>>0>9){h=e&1023;a[b+h|0]=l&255;a[b+(h+1)|0]=(f&65535)>>>8&255;return}else{gg[c[n+196728+(b<<2)>>2]&4095](m,f);return}}function Pu(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[2276069]|0;e=((b>>>9)+7&7)+1|0;f=9104156+((b&7|8)<<2)|0;b=c[f>>2]|0;c[f>>2]=b+2;f=c[2276085]|0;g=f&b;h=g&16777215;i=c[2112932]|0;j=c[i+(h>>>10<<2)>>2]|0;if(j>>>0>9){k=g&1023;l=(d[j+(k+1)|0]|0)<<8|(d[j+k|0]|0);m=f;n=i}else{f=gj[c[i+196688+(j<<2)>>2]&4095](h)|0;l=f;m=c[2276085]|0;n=c[2112932]|0}f=l&65535;l=f-e|0;h=l>>>8;c[2276075]=h;c[2276076]=l&65535;c[2276078]=h;c[2276074]=h;c[2276077]=((l^f)&(f^e))>>>8;e=m&b;b=l&65535;m=e&16777215;f=c[n+((m>>>10|16384)<<2)>>2]|0;if(f>>>0>9){h=e&1023;a[f+h|0]=l&255;a[f+(h+1)|0]=(b&65535)>>>8&255;return}else{gg[c[n+196728+(f<<2)>>2]&4095](m,b);return}}function Pv(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[2276069]|0;e=((b>>>9)+7&7)+1|0;f=9104156+((b&7|8)<<2)|0;b=(c[f>>2]|0)-2|0;c[f>>2]=b;f=c[2276085]|0;g=f&b;h=g&16777215;i=c[2112932]|0;j=c[i+(h>>>10<<2)>>2]|0;if(j>>>0>9){k=g&1023;l=(d[j+(k+1)|0]|0)<<8|(d[j+k|0]|0);m=f;n=i}else{f=gj[c[i+196688+(j<<2)>>2]&4095](h)|0;l=f;m=c[2276085]|0;n=c[2112932]|0}f=l&65535;l=f-e|0;h=l>>>8;c[2276075]=h;c[2276076]=l&65535;c[2276078]=h;c[2276074]=h;c[2276077]=((l^f)&(f^e))>>>8;e=m&b;b=l&65535;m=e&16777215;f=c[n+((m>>>10|16384)<<2)>>2]|0;if(f>>>0>9){h=e&1023;a[f+h|0]=l&255;a[f+(h+1)|0]=(b&65535)>>>8&255;return}else{gg[c[n+196728+(f<<2)>>2]&4095](m,b);return}}function Pw(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=c[2276069]|0;e=((b>>>9)+7&7)+1|0;f=c[9104156+((b&7|8)<<2)>>2]|0;b=c[2276056]|0;g=b&-4;if((g|0)==(c[2276083]|0)){h=b;i=c[2276084]|0}else{c[2276083]=g;j=c[2276085]&g;g=j&16777212;k=c[2112932]|0;l=c[k+((g>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=j&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b}else{b=gj[c[k+196768+(l<<2)>>2]&4095](g)|0;n=b;o=c[2276056]|0}c[2276084]=n;h=o;i=n}c[2276056]=h+2;n=(i>>>((h<<3&16^16)>>>0)<<16>>16)+f|0;f=c[2276085]|0;h=n&f;i=h&16777215;o=c[2112932]|0;b=c[o+(i>>>10<<2)>>2]|0;if(b>>>0>9){g=h&1023;p=(d[b+(g+1)|0]|0)<<8|(d[b+g|0]|0);q=f;r=o}else{f=gj[c[o+196688+(b<<2)>>2]&4095](i)|0;p=f;q=c[2276085]|0;r=c[2112932]|0}f=p&65535;p=f-e|0;i=p>>>8;c[2276075]=i;c[2276076]=p&65535;c[2276078]=i;c[2276074]=i;c[2276077]=((p^f)&(f^e))>>>8;e=q&n;n=p&65535;q=e&16777215;f=c[r+((q>>>10|16384)<<2)>>2]|0;if(f>>>0>9){i=e&1023;a[f+i|0]=p&255;a[f+(i+1)|0]=(n&65535)>>>8&255;return}else{gg[c[r+196728+(f<<2)>>2]&4095](q,n);return}}function Px(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[2276069]|0;e=((b>>>9)+7&7)+1|0;f=Hd(c[9104156+((b&7|8)<<2)>>2]|0)|0;b=c[2276085]|0;g=b&f;h=g&16777215;i=c[2112932]|0;j=c[i+(h>>>10<<2)>>2]|0;if(j>>>0>9){k=g&1023;l=(d[j+(k+1)|0]|0)<<8|(d[j+k|0]|0);m=b;n=i}else{b=gj[c[i+196688+(j<<2)>>2]&4095](h)|0;l=b;m=c[2276085]|0;n=c[2112932]|0}b=l&65535;l=b-e|0;h=l>>>8;c[2276075]=h;c[2276076]=l&65535;c[2276078]=h;c[2276074]=h;c[2276077]=((l^b)&(b^e))>>>8;e=m&f;f=l&65535;m=e&16777215;b=c[n+((m>>>10|16384)<<2)>>2]|0;if(b>>>0>9){h=e&1023;a[b+h|0]=l&255;a[b+(h+1)|0]=(f&65535)>>>8&255;return}else{gg[c[n+196728+(b<<2)>>2]&4095](m,f);return}}function Py(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=(((c[2276069]|0)>>>9)+7&7)+1|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=h>>>((g<<3&16^16)>>>0)<<16>>16;g=c[2276085]|0;h=m&g;n=h&16777215;e=c[2112932]|0;f=c[e+(n>>>10<<2)>>2]|0;if(f>>>0>9){k=h&1023;o=(d[f+(k+1)|0]|0)<<8|(d[f+k|0]|0);p=g;q=e}else{g=gj[c[e+196688+(f<<2)>>2]&4095](n)|0;o=g;p=c[2276085]|0;q=c[2112932]|0}g=o&65535;o=g-b|0;n=o>>>8;c[2276075]=n;c[2276076]=o&65535;c[2276078]=n;c[2276074]=n;c[2276077]=((o^g)&(g^b))>>>8;b=p&m;m=o&65535;p=b&16777215;g=c[q+((p>>>10|16384)<<2)>>2]|0;if(g>>>0>9){n=b&1023;a[g+n|0]=o&255;a[g+(n+1)|0]=(m&65535)>>>8&255;return}else{gg[c[q+196728+(g<<2)>>2]&4095](p,m);return}}function Pz(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;b=(((c[2276069]|0)>>>9)+7&7)+1|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=f;i=c[2276084]|0}else{c[2276083]=f;j=c[2276085]&f;k=j&16777212;l=c[2112932]|0;m=c[l+((k>>>10|32768)<<2)>>2]|0;if(m>>>0>9){n=j&1020;o=(d[m+(n|3)|0]|0)<<8|(d[m+(n|2)|0]|0)|((d[m+(n|1)|0]|0)<<8|(d[m+n|0]|0))<<16;p=e;q=f}else{f=gj[c[l+196768+(m<<2)>>2]&4095](k)|0;o=f;p=c[2276056]|0;q=c[2276083]|0}c[2276084]=o;g=p;h=q;i=o}o=g+2|0;c[2276056]=o;g=o&-4;if((g|0)==(h|0)){r=i;s=o}else{c[2276083]=g;h=c[2276085]&g;g=h&16777212;q=c[2112932]|0;p=c[q+((g>>>10|32768)<<2)>>2]|0;if(p>>>0>9){f=h&1020;t=(d[p+(f|3)|0]|0)<<8|(d[p+(f|2)|0]|0)|((d[p+(f|1)|0]|0)<<8|(d[p+f|0]|0))<<16;u=o}else{o=gj[c[q+196768+(p<<2)>>2]&4095](g)|0;t=o;u=c[2276056]|0}c[2276084]=t;r=t>>>16|i<<16;s=u}c[2276056]=s+2;s=c[2276085]|0;u=s&r;i=u&16777215;t=c[2112932]|0;o=c[t+(i>>>10<<2)>>2]|0;if(o>>>0>9){g=u&1023;v=(d[o+(g+1)|0]|0)<<8|(d[o+g|0]|0);w=s;x=t}else{s=gj[c[t+196688+(o<<2)>>2]&4095](i)|0;v=s;w=c[2276085]|0;x=c[2112932]|0}s=v&65535;v=s-b|0;i=v>>>8;c[2276075]=i;c[2276076]=v&65535;c[2276078]=i;c[2276074]=i;c[2276077]=((v^s)&(s^b))>>>8;b=w&r;r=v&65535;w=b&16777215;s=c[x+((w>>>10|16384)<<2)>>2]|0;if(s>>>0>9){i=b&1023;a[s+i|0]=v&255;a[s+(i+1)|0]=(r&65535)>>>8&255;return}else{gg[c[x+196728+(s<<2)>>2]&4095](w,r);return}}function PA(){var a=0,b=0,d=0,e=0,f=0;a=c[2276069]|0;b=9104156+((a&7)<<2)|0;d=((a>>>9)+7&7)+1|0;a=c[b>>2]|0;e=a-d|0;c[2276075]=e>>>24;c[2276076]=e;f=((e|d)&(a^-8388608)|e&d)>>>23;c[2276078]=f;c[2276074]=f;c[2276077]=((e^a)&(d^a))>>>24;c[b>>2]=e;return}function PB(){var a=0,b=0;a=c[2276069]|0;b=9104156+((a&7|8)<<2)|0;c[b>>2]=(c[b>>2]|0)-1-((a>>>9)+7&7);return}function PC(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[2276069]|0;e=((b>>>9)+7&7)+1|0;f=c[9104156+((b&7|8)<<2)>>2]|0;b=c[2276085]|0;g=b&f;h=g&16777215;i=c[2112932]|0;j=c[i+(h>>>10<<2)>>2]|0;if(j>>>0>9){k=g&1023;l=(d[j+(k+3)|0]|0)<<8|(d[j+(k+2)|0]|0)|((d[j+(k+1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b;n=i}else{b=gj[c[i+196768+(j<<2)>>2]&4095](h)|0;l=b;m=c[2276085]|0;n=c[2112932]|0}b=l-e|0;h=b>>>24;c[2276075]=h;c[2276076]=b;j=((b|e)&(l^-8388608)|b&e)>>>23;c[2276078]=j;c[2276074]=j;c[2276077]=((b^l)&(l^e))>>>24;e=m&f;f=e&16777215;m=c[n+((f>>>10|16384)<<2)>>2]|0;if(m>>>0>9){l=e&1023;a[m+l|0]=b>>>16&255;a[m+(l+1)|0]=h&255;a[m+(l+2)|0]=b&255;a[m+(l+3)|0]=b>>>8&255;return}else{gg[c[n+196808+(m<<2)>>2]&4095](f,b);return}}function PD(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[2276069]|0;e=((b>>>9)+7&7)+1|0;f=9104156+((b&7|8)<<2)|0;b=c[f>>2]|0;c[f>>2]=b+4;f=c[2276085]|0;g=f&b;h=g&16777215;i=c[2112932]|0;j=c[i+(h>>>10<<2)>>2]|0;if(j>>>0>9){k=g&1023;l=(d[j+(k+3)|0]|0)<<8|(d[j+(k+2)|0]|0)|((d[j+(k+1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=f;n=i}else{f=gj[c[i+196768+(j<<2)>>2]&4095](h)|0;l=f;m=c[2276085]|0;n=c[2112932]|0}f=l-e|0;h=f>>>24;c[2276075]=h;c[2276076]=f;j=((f|e)&(l^-8388608)|f&e)>>>23;c[2276078]=j;c[2276074]=j;c[2276077]=((f^l)&(l^e))>>>24;e=m&b;b=e&16777215;m=c[n+((b>>>10|16384)<<2)>>2]|0;if(m>>>0>9){l=e&1023;a[m+l|0]=f>>>16&255;a[m+(l+1)|0]=h&255;a[m+(l+2)|0]=f&255;a[m+(l+3)|0]=f>>>8&255;return}else{gg[c[n+196808+(m<<2)>>2]&4095](b,f);return}}function PE(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[2276069]|0;e=((b>>>9)+7&7)+1|0;f=9104156+((b&7|8)<<2)|0;b=(c[f>>2]|0)-4|0;c[f>>2]=b;f=c[2276085]|0;g=f&b;h=g&16777215;i=c[2112932]|0;j=c[i+(h>>>10<<2)>>2]|0;if(j>>>0>9){k=g&1023;l=(d[j+(k+3)|0]|0)<<8|(d[j+(k+2)|0]|0)|((d[j+(k+1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=f;n=i}else{f=gj[c[i+196768+(j<<2)>>2]&4095](h)|0;l=f;m=c[2276085]|0;n=c[2112932]|0}f=l-e|0;h=f>>>24;c[2276075]=h;c[2276076]=f;j=((f|e)&(l^-8388608)|f&e)>>>23;c[2276078]=j;c[2276074]=j;c[2276077]=((f^l)&(l^e))>>>24;e=m&b;b=e&16777215;m=c[n+((b>>>10|16384)<<2)>>2]|0;if(m>>>0>9){l=e&1023;a[m+l|0]=f>>>16&255;a[m+(l+1)|0]=h&255;a[m+(l+2)|0]=f&255;a[m+(l+3)|0]=f>>>8&255;return}else{gg[c[n+196808+(m<<2)>>2]&4095](b,f);return}}function PF(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=c[2276069]|0;e=((b>>>9)+7&7)+1|0;f=c[9104156+((b&7|8)<<2)>>2]|0;b=c[2276056]|0;g=b&-4;if((g|0)==(c[2276083]|0)){h=b;i=c[2276084]|0}else{c[2276083]=g;j=c[2276085]&g;g=j&16777212;k=c[2112932]|0;l=c[k+((g>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=j&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b}else{b=gj[c[k+196768+(l<<2)>>2]&4095](g)|0;n=b;o=c[2276056]|0}c[2276084]=n;h=o;i=n}c[2276056]=h+2;n=(i>>>((h<<3&16^16)>>>0)<<16>>16)+f|0;f=c[2276085]|0;h=n&f;i=h&16777215;o=c[2112932]|0;b=c[o+(i>>>10<<2)>>2]|0;if(b>>>0>9){g=h&1023;p=(d[b+(g+3)|0]|0)<<8|(d[b+(g+2)|0]|0)|((d[b+(g+1)|0]|0)<<8|(d[b+g|0]|0))<<16;q=f;r=o}else{f=gj[c[o+196768+(b<<2)>>2]&4095](i)|0;p=f;q=c[2276085]|0;r=c[2112932]|0}f=p-e|0;i=f>>>24;c[2276075]=i;c[2276076]=f;b=((f|e)&(p^-8388608)|f&e)>>>23;c[2276078]=b;c[2276074]=b;c[2276077]=((f^p)&(p^e))>>>24;e=q&n;n=e&16777215;q=c[r+((n>>>10|16384)<<2)>>2]|0;if(q>>>0>9){p=e&1023;a[q+p|0]=f>>>16&255;a[q+(p+1)|0]=i&255;a[q+(p+2)|0]=f&255;a[q+(p+3)|0]=f>>>8&255;return}else{gg[c[r+196808+(q<<2)>>2]&4095](n,f);return}}function PG(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[2276069]|0;e=((b>>>9)+7&7)+1|0;f=Hd(c[9104156+((b&7|8)<<2)>>2]|0)|0;b=c[2276085]|0;g=b&f;h=g&16777215;i=c[2112932]|0;j=c[i+(h>>>10<<2)>>2]|0;if(j>>>0>9){k=g&1023;l=(d[j+(k+3)|0]|0)<<8|(d[j+(k+2)|0]|0)|((d[j+(k+1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b;n=i}else{b=gj[c[i+196768+(j<<2)>>2]&4095](h)|0;l=b;m=c[2276085]|0;n=c[2112932]|0}b=l-e|0;h=b>>>24;c[2276075]=h;c[2276076]=b;j=((b|e)&(l^-8388608)|b&e)>>>23;c[2276078]=j;c[2276074]=j;c[2276077]=((b^l)&(l^e))>>>24;e=m&f;f=e&16777215;m=c[n+((f>>>10|16384)<<2)>>2]|0;if(m>>>0>9){l=e&1023;a[m+l|0]=b>>>16&255;a[m+(l+1)|0]=h&255;a[m+(l+2)|0]=b&255;a[m+(l+3)|0]=b>>>8&255;return}else{gg[c[n+196808+(m<<2)>>2]&4095](f,b);return}}function PH(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=(((c[2276069]|0)>>>9)+7&7)+1|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=h>>>((g<<3&16^16)>>>0)<<16>>16;g=c[2276085]|0;h=m&g;n=h&16777215;e=c[2112932]|0;f=c[e+(n>>>10<<2)>>2]|0;if(f>>>0>9){k=h&1023;o=(d[f+(k+3)|0]|0)<<8|(d[f+(k+2)|0]|0)|((d[f+(k+1)|0]|0)<<8|(d[f+k|0]|0))<<16;p=g;q=e}else{g=gj[c[e+196768+(f<<2)>>2]&4095](n)|0;o=g;p=c[2276085]|0;q=c[2112932]|0}g=o-b|0;n=g>>>24;c[2276075]=n;c[2276076]=g;f=((g|b)&(o^-8388608)|g&b)>>>23;c[2276078]=f;c[2276074]=f;c[2276077]=((g^o)&(o^b))>>>24;b=p&m;m=b&16777215;p=c[q+((m>>>10|16384)<<2)>>2]|0;if(p>>>0>9){o=b&1023;a[p+o|0]=g>>>16&255;a[p+(o+1)|0]=n&255;a[p+(o+2)|0]=g&255;a[p+(o+3)|0]=g>>>8&255;return}else{gg[c[q+196808+(p<<2)>>2]&4095](m,g);return}}function PI(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;b=(((c[2276069]|0)>>>9)+7&7)+1|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=f;i=c[2276084]|0}else{c[2276083]=f;j=c[2276085]&f;k=j&16777212;l=c[2112932]|0;m=c[l+((k>>>10|32768)<<2)>>2]|0;if(m>>>0>9){n=j&1020;o=(d[m+(n|3)|0]|0)<<8|(d[m+(n|2)|0]|0)|((d[m+(n|1)|0]|0)<<8|(d[m+n|0]|0))<<16;p=e;q=f}else{f=gj[c[l+196768+(m<<2)>>2]&4095](k)|0;o=f;p=c[2276056]|0;q=c[2276083]|0}c[2276084]=o;g=p;h=q;i=o}o=g+2|0;c[2276056]=o;g=o&-4;if((g|0)==(h|0)){r=i;s=o}else{c[2276083]=g;h=c[2276085]&g;g=h&16777212;q=c[2112932]|0;p=c[q+((g>>>10|32768)<<2)>>2]|0;if(p>>>0>9){f=h&1020;t=(d[p+(f|3)|0]|0)<<8|(d[p+(f|2)|0]|0)|((d[p+(f|1)|0]|0)<<8|(d[p+f|0]|0))<<16;u=o}else{o=gj[c[q+196768+(p<<2)>>2]&4095](g)|0;t=o;u=c[2276056]|0}c[2276084]=t;r=t>>>16|i<<16;s=u}c[2276056]=s+2;s=c[2276085]|0;u=s&r;i=u&16777215;t=c[2112932]|0;o=c[t+(i>>>10<<2)>>2]|0;if(o>>>0>9){g=u&1023;v=(d[o+(g+3)|0]|0)<<8|(d[o+(g+2)|0]|0)|((d[o+(g+1)|0]|0)<<8|(d[o+g|0]|0))<<16;w=s;x=t}else{s=gj[c[t+196768+(o<<2)>>2]&4095](i)|0;v=s;w=c[2276085]|0;x=c[2112932]|0}s=v-b|0;i=s>>>24;c[2276075]=i;c[2276076]=s;o=((s|b)&(v^-8388608)|s&b)>>>23;c[2276078]=o;c[2276074]=o;c[2276077]=((s^v)&(v^b))>>>24;b=w&r;r=b&16777215;w=c[x+((r>>>10|16384)<<2)>>2]|0;if(w>>>0>9){v=b&1023;a[w+v|0]=s>>>16&255;a[w+(v+1)|0]=i&255;a[w+(v+2)|0]=s&255;a[w+(v+3)|0]=s>>>8&255;return}else{gg[c[x+196808+(w<<2)>>2]&4095](r,s);return}}function PJ(){var a=0,b=0,d=0,e=0,f=0;a=c[2276069]|0;b=9104156+((a>>>9&7)<<2)|0;d=c[9104156+((a&7)<<2)>>2]&255;a=c[b>>2]|0;e=a&255;f=e-d-((c[2276074]|0)>>>8&1)|0;c[2276075]=f;c[2276078]=f;c[2276074]=f;c[2276077]=(f^a)&(e^d);d=f&255;c[2276076]=d|c[2276076];c[b>>2]=d|c[b>>2]&-256;return}function PK(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[2276069]|0;b=9104156+((a>>>9&7)<<2)|0;d=c[9104156+((a&7)<<2)>>2]&65535;a=c[b>>2]|0;e=a&65535;f=e-d-((c[2276074]|0)>>>8&1)|0;g=f>>>8;c[2276075]=g;c[2276078]=g;c[2276074]=g;c[2276077]=((f^a)&(e^d))>>>8;d=f&65535;c[2276076]=d|c[2276076];c[b>>2]=d|c[b>>2]&-65536;return}function PL(){var a=0,b=0,d=0,e=0,f=0;a=c[2276069]|0;b=9104156+((a>>>9&7)<<2)|0;d=c[9104156+((a&7)<<2)>>2]|0;a=c[b>>2]|0;e=a-d-((c[2276074]|0)>>>8&1)|0;c[2276075]=e>>>24;f=((e|d)&(a^-8388608)|e&d)>>>23;c[2276078]=f;c[2276074]=f;c[2276077]=((e^a)&(a^d))>>>24;c[2276076]=e|c[2276076];c[b>>2]=e;return}function PM(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;b=c[2276085]|0;e=b&d;d=e&16777215;f=c[2112932]|0;g=c[f+(d>>>10<<2)>>2]|0;if(g>>>0>9){h=a[g+(e&1023^1)|0]|0;i=b;j=f}else{b=gj[c[f+196608+(g<<2)>>2]&4095](d)|0;h=b;i=c[2276085]|0;j=c[2112932]|0}b=(c[2276054]|0)-2|0;c[2276054]=b;d=i&b;g=d&16777215;f=c[j+(g>>>10<<2)>>2]|0;if(f>>>0>9){k=a[f+(d&1023^1)|0]|0;l=i;m=j}else{i=gj[c[j+196608+(f<<2)>>2]&4095](g)|0;k=i;l=c[2276085]|0;m=c[2112932]|0}i=k&255;g=i-(h&255)-((c[2276074]|0)>>>8&1)|0;c[2276075]=g;c[2276078]=g;c[2276074]=g;c[2276077]=(g^i)&((k^h)&255);c[2276076]=g&255|c[2276076];h=l&b;b=g&255;g=h&16777215;l=c[m+((g>>>10|16384)<<2)>>2]|0;if(l>>>0>9){a[l+(h&1023^1)|0]=b;return}else{gg[c[m+196648+(l<<2)>>2]&4095](g,b);return}}function PN(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=(c[2276054]|0)-2|0;c[2276054]=b;d=c[2276085]&b;b=d&16777215;e=c[2112932]|0;f=c[e+(b>>>10<<2)>>2]|0;if(f>>>0>9){g=a[f+(d&1023^1)|0]|0;h=e}else{d=gj[c[e+196608+(f<<2)>>2]&4095](b)|0;g=d;h=c[2112932]|0}d=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;b=(c[d>>2]|0)-1|0;c[d>>2]=b;d=c[2276085]|0;f=d&b;e=f&16777215;i=c[h+(e>>>10<<2)>>2]|0;if(i>>>0>9){j=a[i+(f&1023^1)|0]|0;k=d;l=h}else{d=gj[c[h+196608+(i<<2)>>2]&4095](e)|0;j=d;k=c[2276085]|0;l=c[2112932]|0}d=j&255;e=d-(g&255)-((c[2276074]|0)>>>8&1)|0;c[2276075]=e;c[2276078]=e;c[2276074]=e;c[2276077]=(e^d)&((j^g)&255);c[2276076]=e&255|c[2276076];g=k&b;b=e&255;e=g&16777215;k=c[l+((e>>>10|16384)<<2)>>2]|0;if(k>>>0>9){a[k+(g&1023^1)|0]=b;return}else{gg[c[l+196648+(k<<2)>>2]&4095](e,b);return}}function PO(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=(c[2276054]|0)-2|0;c[2276054]=b;d=c[2276085]|0;e=d&b;f=e&16777215;g=c[2112932]|0;h=c[g+(f>>>10<<2)>>2]|0;if(h>>>0>9){i=a[h+(e&1023^1)|0]|0;j=b;k=d;l=g}else{d=gj[c[g+196608+(h<<2)>>2]&4095](f)|0;i=d;j=c[2276054]|0;k=c[2276085]|0;l=c[2112932]|0}d=j-2|0;c[2276054]=d;j=k&d;f=j&16777215;h=c[l+(f>>>10<<2)>>2]|0;if(h>>>0>9){m=a[h+(j&1023^1)|0]|0;n=k;o=l}else{k=gj[c[l+196608+(h<<2)>>2]&4095](f)|0;m=k;n=c[2276085]|0;o=c[2112932]|0}k=m&255;f=k-(i&255)-((c[2276074]|0)>>>8&1)|0;c[2276075]=f;c[2276078]=f;c[2276074]=f;c[2276077]=(f^k)&((m^i)&255);c[2276076]=f&255|c[2276076];i=n&d;d=f&255;f=i&16777215;n=c[o+((f>>>10|16384)<<2)>>2]|0;if(n>>>0>9){a[n+(i&1023^1)|0]=d;return}else{gg[c[o+196648+(n<<2)>>2]&4095](f,d);return}}function PP(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;b=c[2276085]&d;d=b&16777215;e=c[2112932]|0;f=c[e+(d>>>10<<2)>>2]|0;if(f>>>0>9){g=a[f+(b&1023^1)|0]|0;h=e}else{b=gj[c[e+196608+(f<<2)>>2]&4095](d)|0;g=b;h=c[2112932]|0}b=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;b=c[2276085]|0;f=b&d;e=f&16777215;i=c[h+(e>>>10<<2)>>2]|0;if(i>>>0>9){j=a[i+(f&1023^1)|0]|0;k=b;l=h}else{b=gj[c[h+196608+(i<<2)>>2]&4095](e)|0;j=b;k=c[2276085]|0;l=c[2112932]|0}b=j&255;e=b-(g&255)-((c[2276074]|0)>>>8&1)|0;c[2276075]=e;c[2276078]=e;c[2276074]=e;c[2276077]=(e^b)&((j^g)&255);c[2276076]=e&255|c[2276076];g=k&d;d=e&255;e=g&16777215;k=c[l+((e>>>10|16384)<<2)>>2]|0;if(k>>>0>9){a[k+(g&1023^1)|0]=d;return}else{gg[c[l+196648+(k<<2)>>2]&4095](e,d);return}}function PQ(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=(c[b>>2]|0)-2|0;c[b>>2]=e;b=c[2276085]&e;e=b&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=b&1023;i=(d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0);j=f}else{h=gj[c[f+196688+(g<<2)>>2]&4095](e)|0;i=h;j=c[2112932]|0}h=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;e=(c[h>>2]|0)-2|0;c[h>>2]=e;h=c[2276085]|0;g=h&e;f=g&16777215;b=c[j+(f>>>10<<2)>>2]|0;if(b>>>0>9){k=g&1023;l=(d[b+(k+1)|0]|0)<<8|(d[b+k|0]|0);m=h;n=j}else{h=gj[c[j+196688+(b<<2)>>2]&4095](f)|0;l=h;m=c[2276085]|0;n=c[2112932]|0}h=l&65535;f=h-(i&65535)-((c[2276074]|0)>>>8&1)|0;b=f>>>8;c[2276075]=b;c[2276078]=b;c[2276074]=b;c[2276077]=((f^h)&((l^i)&65535))>>>8;c[2276076]=f&65535|c[2276076];i=m&e;e=f&65535;m=i&16777215;l=c[n+((m>>>10|16384)<<2)>>2]|0;if(l>>>0>9){h=i&1023;a[l+h|0]=f&255;a[l+(h+1)|0]=(e&65535)>>>8&255;return}else{gg[c[n+196728+(l<<2)>>2]&4095](m,e);return}}function PR(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=(c[b>>2]|0)-4|0;c[b>>2]=e;b=c[2276085]&e;e=b&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=b&1023;i=(d[g+(h+3)|0]|0)<<8|(d[g+(h+2)|0]|0)|((d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0))<<16;j=f}else{h=gj[c[f+196768+(g<<2)>>2]&4095](e)|0;i=h;j=c[2112932]|0}h=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;e=(c[h>>2]|0)-4|0;c[h>>2]=e;h=c[2276085]|0;g=h&e;f=g&16777215;b=c[j+(f>>>10<<2)>>2]|0;if(b>>>0>9){k=g&1023;l=(d[b+(k+3)|0]|0)<<8|(d[b+(k+2)|0]|0)|((d[b+(k+1)|0]|0)<<8|(d[b+k|0]|0))<<16;m=h;n=j}else{h=gj[c[j+196768+(b<<2)>>2]&4095](f)|0;l=h;m=c[2276085]|0;n=c[2112932]|0}h=l-i-((c[2276074]|0)>>>8&1)|0;f=h>>>24;c[2276075]=f;b=((h|i)&(l^-8388608)|h&i)>>>23;c[2276078]=b;c[2276074]=b;c[2276077]=((h^l)&(l^i))>>>24;c[2276076]=h|c[2276076];i=m&e;e=i&16777215;m=c[n+((e>>>10|16384)<<2)>>2]|0;if(m>>>0>9){l=i&1023;a[m+l|0]=h>>>16&255;a[m+(l+1)|0]=f&255;a[m+(l+2)|0]=h&255;a[m+(l+3)|0]=h>>>8&255;return}else{gg[c[n+196808+(m<<2)>>2]&4095](e,h);return}}function PS(){var a=0,b=0,d=0;a=9104156+((c[2276069]&7)<<2)|0;b=c[a>>2]<<16;c[2276076]=b;d=(c[a>>2]|0)>>>16|b;c[a>>2]=d;c[2276076]=d;c[2276075]=(c[a>>2]|0)>>>24;c[2276078]=0;c[2276077]=0;return}function PT(){var a=0;a=9104156+((c[2276069]&7)<<2)|0;c[2276076]=c[a>>2]&255;c[2276075]=c[a>>2];c[2276077]=0;c[2276078]=0;c[a>>2]=c[a>>2]|128;return}function PU(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;d=c[2276085]|0;e=d&b;f=e&16777215;g=c[2112932]|0;h=c[g+(f>>>10<<2)>>2]|0;if(h>>>0>9){i=a[h+(e&1023^1)|0]|0;j=d;k=g}else{d=gj[c[g+196608+(h<<2)>>2]&4095](f)|0;i=d;j=c[2276085]|0;k=c[2112932]|0}d=i&255;c[2276076]=d;c[2276075]=d;c[2276077]=0;c[2276078]=0;d=i|-128;i=j&b;b=i&16777215;j=c[k+((b>>>10|16384)<<2)>>2]|0;if(j>>>0>9){a[j+(i&1023^1)|0]=d;return}else{gg[c[k+196648+(j<<2)>>2]&4095](b,d);return}}function PV(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;b=c[2276085]|0;e=b&d;f=e&16777215;g=c[2112932]|0;h=c[g+(f>>>10<<2)>>2]|0;if(h>>>0>9){i=a[h+(e&1023^1)|0]|0;j=b;k=g}else{b=gj[c[g+196608+(h<<2)>>2]&4095](f)|0;i=b;j=c[2276085]|0;k=c[2112932]|0}b=i&255;c[2276076]=b;c[2276075]=b;c[2276077]=0;c[2276078]=0;b=i|-128;i=j&d;d=i&16777215;j=c[k+((d>>>10|16384)<<2)>>2]|0;if(j>>>0>9){a[j+(i&1023^1)|0]=b;return}else{gg[c[k+196648+(j<<2)>>2]&4095](d,b);return}}function PW(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[2276054]|0;c[2276054]=b+2;d=c[2276085]|0;e=d&b;f=e&16777215;g=c[2112932]|0;h=c[g+(f>>>10<<2)>>2]|0;if(h>>>0>9){i=a[h+(e&1023^1)|0]|0;j=d;k=g}else{d=gj[c[g+196608+(h<<2)>>2]&4095](f)|0;i=d;j=c[2276085]|0;k=c[2112932]|0}d=i&255;c[2276076]=d;c[2276075]=d;c[2276077]=0;c[2276078]=0;d=i|-128;i=j&b;b=i&16777215;j=c[k+((b>>>10|16384)<<2)>>2]|0;if(j>>>0>9){a[j+(i&1023^1)|0]=d;return}else{gg[c[k+196648+(j<<2)>>2]&4095](b,d);return}}function PX(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;b=c[2276085]|0;e=b&d;f=e&16777215;g=c[2112932]|0;h=c[g+(f>>>10<<2)>>2]|0;if(h>>>0>9){i=a[h+(e&1023^1)|0]|0;j=b;k=g}else{b=gj[c[g+196608+(h<<2)>>2]&4095](f)|0;i=b;j=c[2276085]|0;k=c[2112932]|0}b=i&255;c[2276076]=b;c[2276075]=b;c[2276077]=0;c[2276078]=0;b=i|-128;i=j&d;d=i&16777215;j=c[k+((d>>>10|16384)<<2)>>2]|0;if(j>>>0>9){a[j+(i&1023^1)|0]=b;return}else{gg[c[k+196648+(j<<2)>>2]&4095](d,b);return}}function PY(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=(c[2276054]|0)-2|0;c[2276054]=b;d=c[2276085]|0;e=d&b;f=e&16777215;g=c[2112932]|0;h=c[g+(f>>>10<<2)>>2]|0;if(h>>>0>9){i=a[h+(e&1023^1)|0]|0;j=d;k=g}else{d=gj[c[g+196608+(h<<2)>>2]&4095](f)|0;i=d;j=c[2276085]|0;k=c[2112932]|0}d=i&255;c[2276076]=d;c[2276075]=d;c[2276077]=0;c[2276078]=0;d=i|-128;i=j&b;b=i&16777215;j=c[k+((b>>>10|16384)<<2)>>2]|0;if(j>>>0>9){a[j+(i&1023^1)|0]=d;return}else{gg[c[k+196648+(j<<2)>>2]&4095](b,d);return}}function PZ(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=(h>>>((g<<3&16^16)>>>0)<<16>>16)+b|0;b=c[2276085]|0;g=m&b;h=g&16777215;n=c[2112932]|0;e=c[n+(h>>>10<<2)>>2]|0;if(e>>>0>9){o=a[e+(g&1023^1)|0]|0;p=b;q=n}else{b=gj[c[n+196608+(e<<2)>>2]&4095](h)|0;o=b;p=c[2276085]|0;q=c[2112932]|0}b=o&255;c[2276076]=b;c[2276075]=b;c[2276077]=0;c[2276078]=0;b=o|-128;o=p&m;m=o&16777215;p=c[q+((m>>>10|16384)<<2)>>2]|0;if(p>>>0>9){a[p+(o&1023^1)|0]=b;return}else{gg[c[q+196648+(p<<2)>>2]&4095](m,b);return}}function P_(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=Hd(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;d=c[2276085]|0;e=d&b;f=e&16777215;g=c[2112932]|0;h=c[g+(f>>>10<<2)>>2]|0;if(h>>>0>9){i=a[h+(e&1023^1)|0]|0;j=d;k=g}else{d=gj[c[g+196608+(h<<2)>>2]&4095](f)|0;i=d;j=c[2276085]|0;k=c[2112932]|0}d=i&255;c[2276076]=d;c[2276075]=d;c[2276077]=0;c[2276078]=0;d=i|-128;i=j&b;b=i&16777215;j=c[k+((b>>>10|16384)<<2)>>2]|0;if(j>>>0>9){a[j+(i&1023^1)|0]=d;return}else{gg[c[k+196648+(j<<2)>>2]&4095](b,d);return}}function P$(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)<<16>>16;f=c[2276085]|0;g=l&f;m=g&16777215;b=c[2112932]|0;e=c[b+(m>>>10<<2)>>2]|0;if(e>>>0>9){n=a[e+(g&1023^1)|0]|0;o=f;p=b}else{f=gj[c[b+196608+(e<<2)>>2]&4095](m)|0;n=f;o=c[2276085]|0;p=c[2112932]|0}f=n&255;c[2276076]=f;c[2276075]=f;c[2276077]=0;c[2276078]=0;f=n|-128;n=o&l;l=n&16777215;o=c[p+((l>>>10|16384)<<2)>>2]|0;if(o>>>0>9){a[o+(n&1023^1)|0]=f;return}else{gg[c[p+196648+(o<<2)>>2]&4095](l,f);return}}function P0(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[2276085]|0;t=r&q;h=t&16777215;s=c[2112932]|0;n=c[s+(h>>>10<<2)>>2]|0;if(n>>>0>9){u=a[n+(t&1023^1)|0]|0;v=r;w=s}else{r=gj[c[s+196608+(n<<2)>>2]&4095](h)|0;u=r;v=c[2276085]|0;w=c[2112932]|0}r=u&255;c[2276076]=r;c[2276075]=r;c[2276077]=0;c[2276078]=0;r=u|-128;u=v&q;q=u&16777215;v=c[w+((q>>>10|16384)<<2)>>2]|0;if(v>>>0>9){a[v+(u&1023^1)|0]=r;return}else{gg[c[w+196648+(v<<2)>>2]&4095](q,r);return}}function P1(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;b=c[2276069]&15|32;e=c[2276072]|0;f=c[2276073]|0;g=c[2276071]|c[2276070]|e<<11|f<<11|c[2276079]|(c[2276074]|0)>>>4&16|(c[2276075]|0)>>>4&8|((c[2276076]|0)==0)<<2|(c[2276077]|0)>>>6&2|(c[2276078]|0)>>>8&1;c[2276071]=0;c[2276070]=0;c[9104228+((e>>>1&f|e)<<2)>>2]=c[2276054];c[2276072]=4;e=c[9104228+((c[2276073]&2|4)<<2)>>2]|0;c[2276054]=e;f=c[2276056]|0;do{if(((c[2276038]|0)-1|0)>>>0<2){h=e-4|0;c[2276054]=h;i=c[2276085]&h;h=i&16777215;j=c[2112932]|0;k=c[j+((h>>>10|16384)<<2)>>2]|0;if(k>>>0>9){l=i&1023;a[k+l|0]=f>>>16&255;a[k+(l+1)|0]=f>>>24&255;a[k+(l+2)|0]=f&255;a[k+(l+3)|0]=f>>>8&255;m=j}else{gg[c[j+196808+(k<<2)>>2]&4095](h,f);m=c[2112932]|0}h=(c[2276054]|0)-2|0;c[2276054]=h;k=c[2276085]&h;h=g&65535;j=k&16777215;l=c[m+((j>>>10|16384)<<2)>>2]|0;if(l>>>0>9){i=k&1023;a[l+i|0]=g&255;a[l+(i+1)|0]=(h&65535)>>>8&255}else{gg[c[m+196728+(l<<2)>>2]&4095](j,h)}n=b<<2}else{h=b<<2;j=e-2|0;c[2276054]=j;l=c[2276085]&j;j=l&16777215;i=c[2112932]|0;k=c[i+((j>>>10|16384)<<2)>>2]|0;if(k>>>0>9){o=l&1023;a[k+o|0]=h&255;a[k+(o+1)|0]=0;p=i}else{gg[c[i+196728+(k<<2)>>2]&4095](j,h&65535);p=c[2112932]|0}j=(c[2276054]|0)-4|0;c[2276054]=j;k=c[2276085]&j;j=k&16777215;i=c[p+((j>>>10|16384)<<2)>>2]|0;if(i>>>0>9){o=k&1023;a[i+o|0]=f>>>16&255;a[i+(o+1)|0]=f>>>24&255;a[i+(o+2)|0]=f&255;a[i+(o+3)|0]=f>>>8&255;q=p}else{gg[c[p+196808+(i<<2)>>2]&4095](j,f);q=c[2112932]|0}j=(c[2276054]|0)-2|0;c[2276054]=j;i=c[2276085]&j;j=g&65535;o=i&16777215;k=c[q+((o>>>10|16384)<<2)>>2]|0;if(k>>>0>9){l=i&1023;a[k+l|0]=g&255;a[k+(l+1)|0]=(j&65535)>>>8&255;n=h;break}else{gg[c[q+196728+(k<<2)>>2]&4095](o,j);n=h;break}}}while(0);q=(c[2276064]|0)+n|0;c[2276056]=q;n=c[2276085]&q;q=n&16777215;g=c[2112932]|0;f=c[g+(q>>>10<<2)>>2]|0;if(f>>>0>9){p=n&1023;r=(d[f+(p+3)|0]|0)<<8|(d[f+(p+2)|0]|0)|((d[f+(p+1)|0]|0)<<8|(d[f+p|0]|0))<<16;c[2276056]=r;s=c[2276099]|0;t=s+b|0;u=a[t]|0;v=u&255;w=c[2276108]|0;x=w-v|0;c[2276108]=x;return}else{r=gj[c[g+196768+(f<<2)>>2]&4095](q)|0;c[2276056]=r;s=c[2276099]|0;t=s+b|0;u=a[t]|0;v=u&255;w=c[2276108]|0;x=w-v|0;c[2276108]=x;return}}function P2(){if((c[2276038]&24|0)==0){JT();return}else{P3();return}}function P3(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;b=c[2276072]|0;e=c[2276073]|0;f=c[2276071]|c[2276070]|b<<11|e<<11|c[2276079]|(c[2276074]|0)>>>4&16|(c[2276075]|0)>>>4&8|((c[2276076]|0)==0)<<2|(c[2276077]|0)>>>6&2|(c[2276078]|0)>>>8&1;c[2276071]=0;c[2276070]=0;c[9104228+((b>>>1&e|b)<<2)>>2]=c[2276054];c[2276072]=4;b=c[9104228+((c[2276073]&2|4)<<2)>>2]|0;c[2276054]=b;e=c[2276038]|0;do{if((e&7|0)==0){g=c[2276055]|0;h=b-4|0;c[2276054]=h;i=c[2276085]&h;h=i&16777215;j=c[2112932]|0;k=c[j+((h>>>10|16384)<<2)>>2]|0;if(k>>>0>9){l=i&1023;a[k+l|0]=g>>>16&255;a[k+(l+1)|0]=g>>>24&255;a[k+(l+2)|0]=g&255;a[k+(l+3)|0]=g>>>8&255;m=j}else{gg[c[j+196808+(k<<2)>>2]&4095](h,g);m=c[2112932]|0}g=(c[2276054]|0)-2|0;c[2276054]=g;h=c[2276085]&g;g=h&16777215;k=c[m+((g>>>10|16384)<<2)>>2]|0;if(k>>>0>9){j=h&1023;a[k+j|0]=28;a[k+(j+1)|0]=32;n=m}else{gg[c[m+196728+(k<<2)>>2]&4095](g,8220);n=c[2112932]|0}g=c[2276056]|0;k=(c[2276054]|0)-4|0;c[2276054]=k;j=c[2276085]&k;k=j&16777215;h=c[n+((k>>>10|16384)<<2)>>2]|0;if(h>>>0>9){l=j&1023;a[h+l|0]=g>>>16&255;a[h+(l+1)|0]=g>>>24&255;a[h+(l+2)|0]=g&255;a[h+(l+3)|0]=g>>>8&255;o=n}else{gg[c[n+196808+(h<<2)>>2]&4095](k,g);o=c[2112932]|0}g=(c[2276054]|0)-2|0;c[2276054]=g;k=c[2276085]&g;g=f&65535;h=k&16777215;l=c[o+((h>>>10|16384)<<2)>>2]|0;if(l>>>0>9){j=k&1023;a[l+j|0]=f&255;a[l+(j+1)|0]=(g&65535)>>>8&255;break}else{gg[c[o+196728+(l<<2)>>2]&4095](h,g);break}}else{g=c[2276056]|0;if((e-1|0)>>>0<2){h=b-4|0;c[2276054]=h;l=c[2276085]&h;h=l&16777215;j=c[2112932]|0;k=c[j+((h>>>10|16384)<<2)>>2]|0;if(k>>>0>9){i=l&1023;a[k+i|0]=g>>>16&255;a[k+(i+1)|0]=g>>>24&255;a[k+(i+2)|0]=g&255;a[k+(i+3)|0]=g>>>8&255;p=j}else{gg[c[j+196808+(k<<2)>>2]&4095](h,g);p=c[2112932]|0}h=(c[2276054]|0)-2|0;c[2276054]=h;k=c[2276085]&h;h=f&65535;j=k&16777215;i=c[p+((j>>>10|16384)<<2)>>2]|0;if(i>>>0>9){l=k&1023;a[i+l|0]=f&255;a[i+(l+1)|0]=(h&65535)>>>8&255;break}else{gg[c[p+196728+(i<<2)>>2]&4095](j,h);break}}h=b-2|0;c[2276054]=h;j=c[2276085]&h;h=j&16777215;i=c[2112932]|0;l=c[i+((h>>>10|16384)<<2)>>2]|0;if(l>>>0>9){k=j&1023;a[l+k|0]=28;a[l+(k+1)|0]=0;q=i}else{gg[c[i+196728+(l<<2)>>2]&4095](h,28);q=c[2112932]|0}h=(c[2276054]|0)-4|0;c[2276054]=h;l=c[2276085]&h;h=l&16777215;i=c[q+((h>>>10|16384)<<2)>>2]|0;if(i>>>0>9){k=l&1023;a[i+k|0]=g>>>16&255;a[i+(k+1)|0]=g>>>24&255;a[i+(k+2)|0]=g&255;a[i+(k+3)|0]=g>>>8&255;r=q}else{gg[c[q+196808+(i<<2)>>2]&4095](h,g);r=c[2112932]|0}g=(c[2276054]|0)-2|0;c[2276054]=g;h=c[2276085]&g;g=f&65535;i=h&16777215;k=c[r+((i>>>10|16384)<<2)>>2]|0;if(k>>>0>9){l=h&1023;a[k+l|0]=f&255;a[k+(l+1)|0]=(g&65535)>>>8&255;break}else{gg[c[r+196728+(k<<2)>>2]&4095](i,g);break}}}while(0);r=(c[2276064]|0)+28|0;c[2276056]=r;f=c[2276085]&r;r=f&16777215;q=c[2112932]|0;b=c[q+(r>>>10<<2)>>2]|0;if(b>>>0>9){p=f&1023;s=(d[b+(p+3)|0]|0)<<8|(d[b+(p+2)|0]|0)|((d[b+(p+1)|0]|0)<<8|(d[b+p|0]|0))<<16;c[2276056]=s;t=c[2276099]|0;u=t+7|0;v=a[u]|0;w=v&255;x=c[2276108]|0;y=x-w|0;c[2276108]=y;return}else{s=gj[c[q+196768+(b<<2)>>2]&4095](r)|0;c[2276056]=s;t=c[2276099]|0;u=t+7|0;v=a[u]|0;w=v&255;x=c[2276108]|0;y=x-w|0;c[2276108]=y;return}}function P4(){if((c[2276038]&24|0)==0){JT();return}else{P3();return}}function P5(){if((c[2276038]&24|0)==0){JT();return}else{P3();return}}function P6(){if((c[2276038]&24|0)!=0){return}JT();return}function P7(){if((c[2276038]&24|0)==0){JT();return}else{c[2276056]=(c[2276056]|0)+2;return}}function P8(){if((c[2276038]&24|0)==0){JT();return}else{c[2276056]=(c[2276056]|0)+4;return}}function P9(){if((c[2276038]&24|0)==0){JT();return}if(!((c[2276078]&256|0)==0&(c[2276076]|0)!=0)){return}P3();return}function Qa(){if((c[2276038]&24|0)==0){JT();return}if((c[2276078]&256|0)==0&(c[2276076]|0)!=0){return}P3();return}function Qb(){if((c[2276038]&24|0)==0){JT();return}if((c[2276078]&256|0)!=0){return}P3();return}function Qc(){if((c[2276038]&24|0)==0){JT();return}if((c[2276078]&256|0)==0){return}P3();return}function Qd(){if((c[2276038]&24|0)==0){JT();return}if((c[2276076]|0)==0){return}P3();return}function Qe(){if((c[2276038]&24|0)==0){JT();return}if((c[2276076]|0)!=0){return}P3();return}function Qf(){if((c[2276038]&24|0)==0){JT();return}if((c[2276077]&128|0)!=0){return}P3();return}function Qg(){if((c[2276038]&24|0)==0){JT();return}if((c[2276077]&128|0)==0){return}P3();return}function Qh(){if((c[2276038]&24|0)==0){JT();return}if((c[2276075]&128|0)!=0){return}P3();return}function Qi(){if((c[2276038]&24|0)==0){JT();return}if((c[2276075]&128|0)==0){return}P3();return}function Qj(){if((c[2276038]&24|0)==0){JT();return}if(((c[2276077]^c[2276075])&128|0)!=0){return}P3();return}function Qk(){if((c[2276038]&24|0)==0){JT();return}if(((c[2276077]^c[2276075])&128|0)==0){return}P3();return}function Ql(){if((c[2276038]&24|0)==0){JT();return}if(!(((c[2276077]^c[2276075])&128|0)==0&(c[2276076]|0)!=0)){return}P3();return}function Qm(){if((c[2276038]&24|0)==0){JT();return}if(((c[2276077]^c[2276075])&128|0)==0&(c[2276076]|0)!=0){return}P3();return}function Qn(){if((c[2276038]&24|0)==0){JT();return}if((c[2276078]&256|0)==0&(c[2276076]|0)!=0){P3();return}else{c[2276056]=(c[2276056]|0)+2;return}}function Qo(){if((c[2276038]&24|0)==0){JT();return}if((c[2276078]&256|0)==0&(c[2276076]|0)!=0){c[2276056]=(c[2276056]|0)+2;return}else{P3();return}}function Qp(){if((c[2276038]&24|0)==0){JT();return}if((c[2276078]&256|0)==0){P3();return}else{c[2276056]=(c[2276056]|0)+2;return}}function Qq(){if((c[2276038]&24|0)==0){JT();return}if((c[2276078]&256|0)==0){c[2276056]=(c[2276056]|0)+2;return}else{P3();return}}function Qr(){if((c[2276038]&24|0)==0){JT();return}if((c[2276076]|0)==0){c[2276056]=(c[2276056]|0)+2;return}else{P3();return}}function Qs(){if((c[2276038]&24|0)==0){JT();return}if((c[2276076]|0)==0){P3();return}else{c[2276056]=(c[2276056]|0)+2;return}}function Qt(){if((c[2276038]&24|0)==0){JT();return}if((c[2276077]&128|0)==0){P3();return}else{c[2276056]=(c[2276056]|0)+2;return}}function Qu(){if((c[2276038]&24|0)==0){JT();return}if((c[2276077]&128|0)==0){c[2276056]=(c[2276056]|0)+2;return}else{P3();return}}function Qv(){if((c[2276038]&24|0)==0){JT();return}if((c[2276075]&128|0)==0){P3();return}else{c[2276056]=(c[2276056]|0)+2;return}}function Qw(){if((c[2276038]&24|0)==0){JT();return}if((c[2276075]&128|0)==0){c[2276056]=(c[2276056]|0)+2;return}else{P3();return}}function Qx(){if((c[2276038]&24|0)==0){JT();return}if(((c[2276077]^c[2276075])&128|0)==0){P3();return}else{c[2276056]=(c[2276056]|0)+2;return}}function Qy(){if((c[2276038]&24|0)==0){JT();return}if(((c[2276077]^c[2276075])&128|0)==0){c[2276056]=(c[2276056]|0)+2;return}else{P3();return}}function Qz(){if((c[2276038]&24|0)==0){JT();return}if(((c[2276077]^c[2276075])&128|0)==0&(c[2276076]|0)!=0){P3();return}else{c[2276056]=(c[2276056]|0)+2;return}}function QA(){if((c[2276038]&24|0)==0){JT();return}if(((c[2276077]^c[2276075])&128|0)==0&(c[2276076]|0)!=0){c[2276056]=(c[2276056]|0)+2;return}else{P3();return}}function QB(){if((c[2276038]&24|0)==0){JT();return}if((c[2276078]&256|0)==0&(c[2276076]|0)!=0){P3();return}else{c[2276056]=(c[2276056]|0)+4;return}}function QC(){if((c[2276038]&24|0)==0){JT();return}if((c[2276078]&256|0)==0&(c[2276076]|0)!=0){c[2276056]=(c[2276056]|0)+4;return}else{P3();return}}function QD(){if((c[2276038]&24|0)==0){JT();return}if((c[2276078]&256|0)==0){P3();return}else{c[2276056]=(c[2276056]|0)+4;return}}function QE(){if((c[2276038]&24|0)==0){JT();return}if((c[2276078]&256|0)==0){c[2276056]=(c[2276056]|0)+4;return}else{P3();return}}function QF(){if((c[2276038]&24|0)==0){JT();return}if((c[2276076]|0)==0){c[2276056]=(c[2276056]|0)+4;return}else{P3();return}}function QG(){if((c[2276038]&24|0)==0){JT();return}if((c[2276076]|0)==0){P3();return}else{c[2276056]=(c[2276056]|0)+4;return}}function QH(){if((c[2276038]&24|0)==0){JT();return}if((c[2276077]&128|0)==0){P3();return}else{c[2276056]=(c[2276056]|0)+4;return}}function QI(){if((c[2276038]&24|0)==0){JT();return}if((c[2276077]&128|0)==0){c[2276056]=(c[2276056]|0)+4;return}else{P3();return}}function QJ(){if((c[2276038]&24|0)==0){JT();return}if((c[2276075]&128|0)==0){P3();return}else{c[2276056]=(c[2276056]|0)+4;return}}function QK(){if((c[2276038]&24|0)==0){JT();return}if((c[2276075]&128|0)==0){c[2276056]=(c[2276056]|0)+4;return}else{P3();return}}function QL(){if((c[2276038]&24|0)==0){JT();return}if(((c[2276077]^c[2276075])&128|0)==0){P3();return}else{c[2276056]=(c[2276056]|0)+4;return}}function QM(){if((c[2276038]&24|0)==0){JT();return}if(((c[2276077]^c[2276075])&128|0)==0){c[2276056]=(c[2276056]|0)+4;return}else{P3();return}}function QN(){if((c[2276038]&24|0)==0){JT();return}if(((c[2276077]^c[2276075])&128|0)==0&(c[2276076]|0)!=0){P3();return}else{c[2276056]=(c[2276056]|0)+4;return}}function QO(){if((c[2276038]&24|0)==0){JT();return}if(((c[2276077]^c[2276075])&128|0)==0&(c[2276076]|0)!=0){c[2276056]=(c[2276056]|0)+4;return}else{P3();return}}function QP(){if((c[2276077]&128|0)==0){return}P3();return}function QQ(){var a=0;a=c[9104156+((c[2276069]&7)<<2)>>2]&255;c[2276075]=a;c[2276076]=a;c[2276077]=0;c[2276078]=0;return}function QR(){var b=0,d=0,e=0,f=0,g=0;b=c[2276085]&c[9104156+((c[2276069]&7|8)<<2)>>2];d=b&16777215;e=c[2112932]|0;f=c[e+(d>>>10<<2)>>2]|0;if(f>>>0>9){g=a[f+(b&1023^1)|0]|0}else{g=gj[c[e+196608+(f<<2)>>2]&4095](d)|0}d=g&255;c[2276075]=d;c[2276076]=d;c[2276077]=0;c[2276078]=0;return}function QS(){var b=0,d=0,e=0,f=0,g=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;b=c[2276085]&d;d=b&16777215;e=c[2112932]|0;f=c[e+(d>>>10<<2)>>2]|0;if(f>>>0>9){g=a[f+(b&1023^1)|0]|0}else{g=gj[c[e+196608+(f<<2)>>2]&4095](d)|0}d=g&255;c[2276075]=d;c[2276076]=d;c[2276077]=0;c[2276078]=0;return}function QT(){var b=0,d=0,e=0,f=0,g=0;b=c[2276054]|0;c[2276054]=b+2;d=c[2276085]&b;b=d&16777215;e=c[2112932]|0;f=c[e+(b>>>10<<2)>>2]|0;if(f>>>0>9){g=a[f+(d&1023^1)|0]|0}else{g=gj[c[e+196608+(f<<2)>>2]&4095](b)|0}b=g&255;c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}function QU(){var b=0,d=0,e=0,f=0,g=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;b=c[2276085]&d;d=b&16777215;e=c[2112932]|0;f=c[e+(d>>>10<<2)>>2]|0;if(f>>>0>9){g=a[f+(b&1023^1)|0]|0}else{g=gj[c[e+196608+(f<<2)>>2]&4095](d)|0}d=g&255;c[2276075]=d;c[2276076]=d;c[2276077]=0;c[2276078]=0;return}function QV(){var b=0,d=0,e=0,f=0,g=0;b=(c[2276054]|0)-2|0;c[2276054]=b;d=c[2276085]&b;b=d&16777215;e=c[2112932]|0;f=c[e+(b>>>10<<2)>>2]|0;if(f>>>0>9){g=a[f+(d&1023^1)|0]|0}else{g=gj[c[e+196608+(f<<2)>>2]&4095](b)|0}b=g&255;c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}function QW(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=(h>>>((g<<3&16^16)>>>0)<<16>>16)+b&c[2276085];b=m&16777215;g=c[2112932]|0;h=c[g+(b>>>10<<2)>>2]|0;if(h>>>0>9){o=a[h+(m&1023^1)|0]|0;p=o&255;c[2276075]=p;c[2276076]=p;c[2276077]=0;c[2276078]=0;return}else{o=gj[c[g+196608+(h<<2)>>2]&4095](b)|0;p=o&255;c[2276075]=p;c[2276076]=p;c[2276077]=0;c[2276078]=0;return}}function QX(){var b=0,d=0,e=0,f=0,g=0;b=Hd(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;d=c[2276085]&b;b=d&16777215;e=c[2112932]|0;f=c[e+(b>>>10<<2)>>2]|0;if(f>>>0>9){g=a[f+(d&1023^1)|0]|0}else{g=gj[c[e+196608+(f<<2)>>2]&4095](b)|0}b=g&255;c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}function QY(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)<<16>>16&c[2276085];f=l&16777215;g=c[2112932]|0;m=c[g+(f>>>10<<2)>>2]|0;if(m>>>0>9){n=a[m+(l&1023^1)|0]|0;o=n&255;c[2276075]=o;c[2276076]=o;c[2276077]=0;c[2276078]=0;return}else{n=gj[c[g+196608+(m<<2)>>2]&4095](f)|0;o=n&255;c[2276075]=o;c[2276076]=o;c[2276077]=0;c[2276078]=0;return}}function QZ(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[2276085]&q;q=r&16777215;t=c[2112932]|0;h=c[t+(q>>>10<<2)>>2]|0;if(h>>>0>9){u=a[h+(r&1023^1)|0]|0;v=u&255;c[2276075]=v;c[2276076]=v;c[2276077]=0;c[2276078]=0;return}else{u=gj[c[t+196608+(h<<2)>>2]&4095](q)|0;v=u&255;c[2276075]=v;c[2276076]=v;c[2276077]=0;c[2276078]=0;return}}function Q_(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[2276038]&24|0)==0){JT();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{k=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=k;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=(g>>>((f<<3&16^16)>>>0)<<16>>16)+b|0;b=l&16777215;f=c[2112932]|0;g=c[f+((b>>>10|32768)<<2)>>2]|0;if(g>>>0>9){n=a[g+(l&1023^1)|0]|0}else{n=gj[c[f+196608+(g<<2)>>2]&4095](b)|0}b=n&255;c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}function Q$(){var b=0,d=0,e=0,f=0,g=0;if((c[2276038]&24|0)==0){JT();return}b=Hd(c[2276056]|0)|0;d=b&16777215;e=c[2112932]|0;f=c[e+((d>>>10|32768)<<2)>>2]|0;if(f>>>0>9){g=a[f+(b&1023^1)|0]|0}else{g=gj[c[e+196608+(f<<2)>>2]&4095](d)|0}d=g&255;c[2276075]=d;c[2276076]=d;c[2276077]=0;c[2276078]=0;return}function Q0(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if((c[2276038]&24|0)==0){JT();return}a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=f>>>((e<<3&16^16)>>>0)&255;c[2276075]=k;c[2276076]=k;c[2276077]=0;c[2276078]=0;return}function Q1(){var a=0;a=c[9104156+((c[2276069]&7)<<2)>>2]&65535;c[2276075]=a>>>8;c[2276076]=a;c[2276077]=0;c[2276078]=0;return}function Q2(){var a=0;if((c[2276038]&24|0)==0){JT();return}else{a=c[9104156+((c[2276069]&7|8)<<2)>>2]<<16>>16;c[2276075]=a>>>8;c[2276076]=a;c[2276077]=0;c[2276078]=0;return}}function Q3(){var a=0,b=0,e=0,f=0,g=0,h=0;a=c[2276085]&c[9104156+((c[2276069]&7|8)<<2)>>2];b=a&16777215;e=c[2112932]|0;f=c[e+(b>>>10<<2)>>2]|0;if(f>>>0>9){g=a&1023;h=(d[f+(g+1)|0]|0)<<8|(d[f+g|0]|0)}else{h=gj[c[e+196688+(f<<2)>>2]&4095](b)|0}b=h&65535;c[2276075]=b>>>8;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}function Q4(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0;a=9104156+((c[2276069]&7|8)<<2)|0;b=c[a>>2]|0;c[a>>2]=b+2;a=c[2276085]&b;b=a&16777215;e=c[2112932]|0;f=c[e+(b>>>10<<2)>>2]|0;if(f>>>0>9){g=a&1023;h=(d[f+(g+1)|0]|0)<<8|(d[f+g|0]|0);i=h&65535;j=i>>>8;c[2276075]=j;c[2276076]=i;c[2276077]=0;c[2276078]=0;return}else{h=gj[c[e+196688+(f<<2)>>2]&4095](b)|0;i=h&65535;j=i>>>8;c[2276075]=j;c[2276076]=i;c[2276077]=0;c[2276078]=0;return}}function Q5(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0;a=9104156+((c[2276069]&7|8)<<2)|0;b=(c[a>>2]|0)-2|0;c[a>>2]=b;a=c[2276085]&b;b=a&16777215;e=c[2112932]|0;f=c[e+(b>>>10<<2)>>2]|0;if(f>>>0>9){g=a&1023;h=(d[f+(g+1)|0]|0)<<8|(d[f+g|0]|0);i=h&65535;j=i>>>8;c[2276075]=j;c[2276076]=i;c[2276077]=0;c[2276078]=0;return}else{h=gj[c[e+196688+(f<<2)>>2]&4095](b)|0;i=h&65535;j=i>>>8;c[2276075]=j;c[2276076]=i;c[2276077]=0;c[2276078]=0;return}}function Q6(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;a=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=(g>>>((f<<3&16^16)>>>0)<<16>>16)+a&c[2276085];a=l&16777215;f=c[2112932]|0;g=c[f+(a>>>10<<2)>>2]|0;if(g>>>0>9){m=l&1023;n=(d[g+(m+1)|0]|0)<<8|(d[g+m|0]|0);o=n&65535;p=o>>>8;c[2276075]=p;c[2276076]=o;c[2276077]=0;c[2276078]=0;return}else{n=gj[c[f+196688+(g<<2)>>2]&4095](a)|0;o=n&65535;p=o>>>8;c[2276075]=p;c[2276076]=o;c[2276077]=0;c[2276078]=0;return}}function Q7(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0;a=Hd(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;b=c[2276085]&a;a=b&16777215;e=c[2112932]|0;f=c[e+(a>>>10<<2)>>2]|0;if(f>>>0>9){g=b&1023;h=(d[f+(g+1)|0]|0)<<8|(d[f+g|0]|0);i=h&65535;j=i>>>8;c[2276075]=j;c[2276076]=i;c[2276077]=0;c[2276078]=0;return}else{h=gj[c[e+196688+(f<<2)>>2]&4095](a)|0;i=h&65535;j=i>>>8;c[2276075]=j;c[2276076]=i;c[2276077]=0;c[2276078]=0;return}}function Q8(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=f>>>((e<<3&16^16)>>>0)<<16>>16&c[2276085];e=k&16777215;f=c[2112932]|0;l=c[f+(e>>>10<<2)>>2]|0;if(l>>>0>9){a=k&1023;m=(d[l+(a+1)|0]|0)<<8|(d[l+a|0]|0);n=m&65535;o=n>>>8;c[2276075]=o;c[2276076]=n;c[2276077]=0;c[2276078]=0;return}else{m=gj[c[f+196688+(l<<2)>>2]&4095](e)|0;n=m&65535;o=n>>>8;c[2276075]=o;c[2276076]=n;c[2276077]=0;c[2276078]=0;return}}function Q9(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=b;g=c[2276084]|0}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=o;g=m}m=e+2|0;c[2276056]=m;e=m&-4;if((e|0)==(f|0)){p=g;q=m}else{c[2276083]=e;f=c[2276085]&e;e=f&16777212;o=c[2112932]|0;n=c[o+((e>>>10|32768)<<2)>>2]|0;if(n>>>0>9){b=f&1020;r=(d[n+(b|3)|0]|0)<<8|(d[n+(b|2)|0]|0)|((d[n+(b|1)|0]|0)<<8|(d[n+b|0]|0))<<16;s=m}else{m=gj[c[o+196768+(n<<2)>>2]&4095](e)|0;r=m;s=c[2276056]|0}c[2276084]=r;p=r>>>16|g<<16;q=s}c[2276056]=q+2;q=c[2276085]&p;p=q&16777215;s=c[2112932]|0;g=c[s+(p>>>10<<2)>>2]|0;if(g>>>0>9){r=q&1023;t=(d[g+(r+1)|0]|0)<<8|(d[g+r|0]|0);u=t&65535;v=u>>>8;c[2276075]=v;c[2276076]=u;c[2276077]=0;c[2276078]=0;return}else{t=gj[c[s+196688+(g<<2)>>2]&4095](p)|0;u=t&65535;v=u>>>8;c[2276075]=v;c[2276076]=u;c[2276077]=0;c[2276078]=0;return}}function Ra(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((c[2276038]&24|0)==0){JT();return}a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{j=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=j;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=(f>>>((e<<3&16^16)>>>0)<<16>>16)+a|0;a=k&16777215;e=c[2112932]|0;f=c[e+((a>>>10|32768)<<2)>>2]|0;if(f>>>0>9){l=k&1023;m=(d[f+(l+1)|0]|0)<<8|(d[f+l|0]|0)}else{m=gj[c[e+196688+(f<<2)>>2]&4095](a)|0}a=m&65535;c[2276075]=a>>>8;c[2276076]=a;c[2276077]=0;c[2276078]=0;return}function Rb(){var a=0,b=0,e=0,f=0,g=0,h=0;if((c[2276038]&24|0)==0){JT();return}a=Hd(c[2276056]|0)|0;b=a&16777215;e=c[2112932]|0;f=c[e+((b>>>10|32768)<<2)>>2]|0;if(f>>>0>9){g=a&1023;h=(d[f+(g+1)|0]|0)<<8|(d[f+g|0]|0)}else{h=gj[c[e+196688+(f<<2)>>2]&4095](b)|0}b=h&65535;c[2276075]=b>>>8;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}function Rc(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if((c[2276038]&24|0)==0){JT();return}a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=f>>>((e<<3&16^16)>>>0)&65535;c[2276075]=k>>>8;c[2276076]=k;c[2276077]=0;c[2276078]=0;return}function Rd(){var a=0;a=c[9104156+((c[2276069]&7)<<2)>>2]|0;c[2276075]=a>>>24;c[2276076]=a;c[2276077]=0;c[2276078]=0;return}function Re(){var a=0;if((c[2276038]&24|0)==0){JT();return}else{a=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;c[2276075]=a>>>24;c[2276076]=a;c[2276077]=0;c[2276078]=0;return}}function Rf(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0;a=c[2276085]&c[9104156+((c[2276069]&7|8)<<2)>>2];b=a&16777215;e=c[2112932]|0;f=c[e+(b>>>10<<2)>>2]|0;if(f>>>0>9){g=a&1023;h=(d[f+(g+3)|0]|0)<<8|(d[f+(g+2)|0]|0)|((d[f+(g+1)|0]|0)<<8|(d[f+g|0]|0))<<16;i=h>>>24;c[2276075]=i;c[2276076]=h;c[2276077]=0;c[2276078]=0;return}else{h=gj[c[e+196768+(f<<2)>>2]&4095](b)|0;i=h>>>24;c[2276075]=i;c[2276076]=h;c[2276077]=0;c[2276078]=0;return}}function Rg(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0;a=9104156+((c[2276069]&7|8)<<2)|0;b=c[a>>2]|0;c[a>>2]=b+4;a=c[2276085]&b;b=a&16777215;e=c[2112932]|0;f=c[e+(b>>>10<<2)>>2]|0;if(f>>>0>9){g=a&1023;h=(d[f+(g+3)|0]|0)<<8|(d[f+(g+2)|0]|0)|((d[f+(g+1)|0]|0)<<8|(d[f+g|0]|0))<<16;i=h>>>24;c[2276075]=i;c[2276076]=h;c[2276077]=0;c[2276078]=0;return}else{h=gj[c[e+196768+(f<<2)>>2]&4095](b)|0;i=h>>>24;c[2276075]=i;c[2276076]=h;c[2276077]=0;c[2276078]=0;return}}function Rh(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0;a=9104156+((c[2276069]&7|8)<<2)|0;b=(c[a>>2]|0)-4|0;c[a>>2]=b;a=c[2276085]&b;b=a&16777215;e=c[2112932]|0;f=c[e+(b>>>10<<2)>>2]|0;if(f>>>0>9){g=a&1023;h=(d[f+(g+3)|0]|0)<<8|(d[f+(g+2)|0]|0)|((d[f+(g+1)|0]|0)<<8|(d[f+g|0]|0))<<16;i=h>>>24;c[2276075]=i;c[2276076]=h;c[2276077]=0;c[2276078]=0;return}else{h=gj[c[e+196768+(f<<2)>>2]&4095](b)|0;i=h>>>24;c[2276075]=i;c[2276076]=h;c[2276077]=0;c[2276078]=0;return}}function Ri(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=(g>>>((f<<3&16^16)>>>0)<<16>>16)+a&c[2276085];a=l&16777215;f=c[2112932]|0;g=c[f+(a>>>10<<2)>>2]|0;if(g>>>0>9){m=l&1023;n=(d[g+(m+3)|0]|0)<<8|(d[g+(m+2)|0]|0)|((d[g+(m+1)|0]|0)<<8|(d[g+m|0]|0))<<16;o=n>>>24;c[2276075]=o;c[2276076]=n;c[2276077]=0;c[2276078]=0;return}else{n=gj[c[f+196768+(g<<2)>>2]&4095](a)|0;o=n>>>24;c[2276075]=o;c[2276076]=n;c[2276077]=0;c[2276078]=0;return}}function Rj(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0;a=Hd(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;b=c[2276085]&a;a=b&16777215;e=c[2112932]|0;f=c[e+(a>>>10<<2)>>2]|0;if(f>>>0>9){g=b&1023;h=(d[f+(g+3)|0]|0)<<8|(d[f+(g+2)|0]|0)|((d[f+(g+1)|0]|0)<<8|(d[f+g|0]|0))<<16;i=h>>>24;c[2276075]=i;c[2276076]=h;c[2276077]=0;c[2276078]=0;return}else{h=gj[c[e+196768+(f<<2)>>2]&4095](a)|0;i=h>>>24;c[2276075]=i;c[2276076]=h;c[2276077]=0;c[2276078]=0;return}}function Rk(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=f>>>((e<<3&16^16)>>>0)<<16>>16&c[2276085];e=k&16777215;f=c[2112932]|0;l=c[f+(e>>>10<<2)>>2]|0;if(l>>>0>9){a=k&1023;m=(d[l+(a+3)|0]|0)<<8|(d[l+(a+2)|0]|0)|((d[l+(a+1)|0]|0)<<8|(d[l+a|0]|0))<<16;n=m>>>24;c[2276075]=n;c[2276076]=m;c[2276077]=0;c[2276078]=0;return}else{m=gj[c[f+196768+(l<<2)>>2]&4095](e)|0;n=m>>>24;c[2276075]=n;c[2276076]=m;c[2276077]=0;c[2276078]=0;return}}function Rl(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=b;g=c[2276084]|0}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=o;g=m}m=e+2|0;c[2276056]=m;e=m&-4;if((e|0)==(f|0)){p=g;q=m}else{c[2276083]=e;f=c[2276085]&e;e=f&16777212;o=c[2112932]|0;n=c[o+((e>>>10|32768)<<2)>>2]|0;if(n>>>0>9){b=f&1020;r=(d[n+(b|3)|0]|0)<<8|(d[n+(b|2)|0]|0)|((d[n+(b|1)|0]|0)<<8|(d[n+b|0]|0))<<16;s=m}else{m=gj[c[o+196768+(n<<2)>>2]&4095](e)|0;r=m;s=c[2276056]|0}c[2276084]=r;p=r>>>16|g<<16;q=s}c[2276056]=q+2;q=c[2276085]&p;p=q&16777215;s=c[2112932]|0;g=c[s+(p>>>10<<2)>>2]|0;if(g>>>0>9){r=q&1023;t=(d[g+(r+3)|0]|0)<<8|(d[g+(r+2)|0]|0)|((d[g+(r+1)|0]|0)<<8|(d[g+r|0]|0))<<16;u=t>>>24;c[2276075]=u;c[2276076]=t;c[2276077]=0;c[2276078]=0;return}else{t=gj[c[s+196768+(g<<2)>>2]&4095](p)|0;u=t>>>24;c[2276075]=u;c[2276076]=t;c[2276077]=0;c[2276078]=0;return}}function Rm(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((c[2276038]&24|0)==0){JT();return}a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{j=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=j;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=(f>>>((e<<3&16^16)>>>0)<<16>>16)+a|0;a=k&16777215;e=c[2112932]|0;f=c[e+((a>>>10|32768)<<2)>>2]|0;if(f>>>0>9){l=k&1023;m=(d[f+(l+3)|0]|0)<<8|(d[f+(l+2)|0]|0)|((d[f+(l+1)|0]|0)<<8|(d[f+l|0]|0))<<16}else{m=gj[c[e+196768+(f<<2)>>2]&4095](a)|0}c[2276075]=m>>>24;c[2276076]=m;c[2276077]=0;c[2276078]=0;return}function Rn(){var a=0,b=0,e=0,f=0,g=0,h=0;if((c[2276038]&24|0)==0){JT();return}a=Hd(c[2276056]|0)|0;b=a&16777215;e=c[2112932]|0;f=c[e+((b>>>10|32768)<<2)>>2]|0;if(f>>>0>9){g=a&1023;h=(d[f+(g+3)|0]|0)<<8|(d[f+(g+2)|0]|0)|((d[f+(g+1)|0]|0)<<8|(d[f+g|0]|0))<<16}else{h=gj[c[e+196768+(f<<2)>>2]&4095](b)|0}c[2276075]=h>>>24;c[2276076]=h;c[2276077]=0;c[2276078]=0;return}function Ro(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;if((c[2276038]&24|0)==0){JT();return}a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=b;g=c[2276084]|0}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=o;g=m}m=e+2|0;c[2276056]=m;e=m&-4;if((e|0)==(f|0)){p=g;q=m}else{c[2276083]=e;f=c[2276085]&e;e=f&16777212;o=c[2112932]|0;n=c[o+((e>>>10|32768)<<2)>>2]|0;if(n>>>0>9){b=f&1020;r=(d[n+(b|3)|0]|0)<<8|(d[n+(b|2)|0]|0)|((d[n+(b|1)|0]|0)<<8|(d[n+b|0]|0))<<16;s=m}else{m=gj[c[o+196768+(n<<2)>>2]&4095](e)|0;r=m;s=c[2276056]|0}c[2276084]=r;p=r>>>16|g<<16;q=s}c[2276056]=q+2;c[2276075]=p>>>24;c[2276076]=p;c[2276077]=0;c[2276078]=0;return}function Rp(){var a=0,b=0,e=0,f=0,g=0,h=0;a=c[2276085]&c[2276054];b=a&16777215;e=c[2112932]|0;f=c[e+(b>>>10<<2)>>2]|0;if(f>>>0>9){g=a&1023;h=(d[f+(g+3)|0]|0)<<8|(d[f+(g+2)|0]|0)|((d[f+(g+1)|0]|0)<<8|(d[f+g|0]|0))<<16;c[2276054]=h;return}else{h=gj[c[e+196768+(f<<2)>>2]&4095](b)|0;c[2276054]=h;return}}function Rq(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0;a=9104156+((c[2276069]&7|8)<<2)|0;b=c[a>>2]|0;c[2276054]=b+4;e=c[2276085]&b;b=e&16777215;f=c[2112932]|0;g=c[f+(b>>>10<<2)>>2]|0;if(g>>>0>9){h=e&1023;i=(d[g+(h+3)|0]|0)<<8|(d[g+(h+2)|0]|0)|((d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0))<<16;c[a>>2]=i;return}else{i=gj[c[f+196768+(g<<2)>>2]&4095](b)|0;c[a>>2]=i;return}}function Rr(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((c[2276038]&24|0)==0){JT();return}a=c[2276069]|0;b=c[9104156+((a&7)<<2)>>2]|0;e=9104156+((a>>>9&7)<<2)|0;a=c[e>>2]&-65536;f=b<<4&3840|b&15;b=c[2276056]|0;g=b&-4;if((g|0)==(c[2276083]|0)){h=b;i=c[2276084]|0}else{c[2276083]=g;j=c[2276085]&g;g=j&16777212;k=c[2112932]|0;l=c[k+((g>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=j&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b}else{b=gj[c[k+196768+(l<<2)>>2]&4095](g)|0;n=b;o=c[2276056]|0}c[2276084]=n;h=o;i=n}c[2276056]=h+2;c[e>>2]=(i>>>((h<<3&16^16)>>>0))+f&65535|a;return}function Rs(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;if((c[2276038]&24|0)==0){JT();return}b=9104156+((c[2276069]&7|8)<<2)|0;e=(c[b>>2]|0)-1|0;c[b>>2]=e;b=c[2276085]&e;e=b&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=a[g+(b&1023^1)|0]|0}else{h=gj[c[f+196608+(g<<2)>>2]&4095](e)|0}e=h&255;h=e&15;g=e<<4&3840|h;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){i=e;j=c[2276084]|0}else{c[2276083]=f;b=c[2276085]&f;f=b&16777212;k=c[2112932]|0;l=c[k+((f>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=b&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](f)|0;n=e;o=c[2276056]|0}c[2276084]=n;i=o;j=n}c[2276056]=i+2;n=j>>>((i<<3&16^16)>>>0);i=(c[2276054]|0)-2|0;c[2276054]=i;j=c[2276085]&i;i=(n+g|0)>>>8&255;g=j&16777215;o=c[2112932]|0;e=c[o+((g>>>10|16384)<<2)>>2]|0;if(e>>>0>9){a[e+(j&1023^1)|0]=i;p=o}else{gg[c[o+196648+(e<<2)>>2]&4095](g,i);p=c[2112932]|0}i=(c[2276054]|0)-2|0;c[2276054]=i;g=c[2276085]&i;i=n+h&255;h=g&16777215;n=c[p+((h>>>10|16384)<<2)>>2]|0;if(n>>>0>9){a[n+(g&1023^1)|0]=i;return}else{gg[c[p+196648+(n<<2)>>2]&4095](h,i);return}}function Rt(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;if((c[2276038]&24|0)==0){JT();return}b=(c[2276054]|0)-2|0;c[2276054]=b;e=c[2276085]&b;b=e&16777215;f=c[2112932]|0;g=c[f+(b>>>10<<2)>>2]|0;if(g>>>0>9){h=a[g+(e&1023^1)|0]|0}else{h=gj[c[f+196608+(g<<2)>>2]&4095](b)|0}b=h&255;h=b&15;g=b<<4&3840|h;b=c[2276056]|0;f=b&-4;if((f|0)==(c[2276083]|0)){i=b;j=c[2276084]|0}else{c[2276083]=f;e=c[2276085]&f;f=e&16777212;k=c[2112932]|0;l=c[k+((f>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=e&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b}else{b=gj[c[k+196768+(l<<2)>>2]&4095](f)|0;n=b;o=c[2276056]|0}c[2276084]=n;i=o;j=n}c[2276056]=i+2;n=j>>>((i<<3&16^16)>>>0);i=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;j=(c[i>>2]|0)-1|0;c[i>>2]=j;i=c[2276085]&j;j=(n+g|0)>>>8&255;g=i&16777215;o=c[2112932]|0;b=c[o+((g>>>10|16384)<<2)>>2]|0;if(b>>>0>9){a[b+(i&1023^1)|0]=j;p=o}else{gg[c[o+196648+(b<<2)>>2]&4095](g,j);p=c[2112932]|0}j=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;g=(c[j>>2]|0)-1|0;c[j>>2]=g;j=c[2276085]&g;g=n+h&255;h=j&16777215;n=c[p+((h>>>10|16384)<<2)>>2]|0;if(n>>>0>9){a[n+(j&1023^1)|0]=g;return}else{gg[c[p+196648+(n<<2)>>2]&4095](h,g);return}}function Ru(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;if((c[2276038]&24|0)==0){JT();return}b=(c[2276054]|0)-2|0;c[2276054]=b;e=c[2276085]&b;b=e&16777215;f=c[2112932]|0;g=c[f+(b>>>10<<2)>>2]|0;if(g>>>0>9){h=a[g+(e&1023^1)|0]|0}else{h=gj[c[f+196608+(g<<2)>>2]&4095](b)|0}b=h&255;h=b&15;g=b<<4&3840|h;b=c[2276056]|0;f=b&-4;if((f|0)==(c[2276083]|0)){i=b;j=c[2276084]|0}else{c[2276083]=f;e=c[2276085]&f;f=e&16777212;k=c[2112932]|0;l=c[k+((f>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=e&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b}else{b=gj[c[k+196768+(l<<2)>>2]&4095](f)|0;n=b;o=c[2276056]|0}c[2276084]=n;i=o;j=n}c[2276056]=i+2;n=j>>>((i<<3&16^16)>>>0);i=(c[2276054]|0)-2|0;c[2276054]=i;j=c[2276085]&i;i=(n+g|0)>>>8&255;g=j&16777215;o=c[2112932]|0;b=c[o+((g>>>10|16384)<<2)>>2]|0;if(b>>>0>9){a[b+(j&1023^1)|0]=i;p=o}else{gg[c[o+196648+(b<<2)>>2]&4095](g,i);p=c[2112932]|0}i=(c[2276054]|0)-2|0;c[2276054]=i;g=c[2276085]&i;i=n+h&255;h=g&16777215;n=c[p+((h>>>10|16384)<<2)>>2]|0;if(n>>>0>9){a[n+(g&1023^1)|0]=i;return}else{gg[c[p+196648+(n<<2)>>2]&4095](h,i);return}}function Rv(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;if((c[2276038]&24|0)==0){JT();return}b=9104156+((c[2276069]&7|8)<<2)|0;e=(c[b>>2]|0)-1|0;c[b>>2]=e;b=c[2276085]&e;e=b&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=a[g+(b&1023^1)|0]|0}else{h=gj[c[f+196608+(g<<2)>>2]&4095](e)|0}e=h&255;h=e&15;g=e<<4&3840|h;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){i=e;j=c[2276084]|0}else{c[2276083]=f;b=c[2276085]&f;f=b&16777212;k=c[2112932]|0;l=c[k+((f>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=b&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](f)|0;n=e;o=c[2276056]|0}c[2276084]=n;i=o;j=n}c[2276056]=i+2;n=j>>>((i<<3&16^16)>>>0);i=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;j=(c[i>>2]|0)-1|0;c[i>>2]=j;i=c[2276085]&j;j=(n+g|0)>>>8&255;g=i&16777215;o=c[2112932]|0;e=c[o+((g>>>10|16384)<<2)>>2]|0;if(e>>>0>9){a[e+(i&1023^1)|0]=j;p=o}else{gg[c[o+196648+(e<<2)>>2]&4095](g,j);p=c[2112932]|0}j=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;g=(c[j>>2]|0)-1|0;c[j>>2]=g;j=c[2276085]&g;g=n+h&255;h=j&16777215;n=c[p+((h>>>10|16384)<<2)>>2]|0;if(n>>>0>9){a[n+(j&1023^1)|0]=g;return}else{gg[c[p+196648+(n<<2)>>2]&4095](h,g);return}}function Rw(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;e=0;while(1){c[8645392+(e<<2)>>2]=7434;a[8907544+e|0]=0;a[8973080+e|0]=0;a[9038616+e|0]=0;f=e+1|0;if((f|0)<65536){e=f}else{g=0;break}}while(1){if((g&61440|0)==40960){c[8645392+(g<<2)>>2]=11104;a[8907544+g|0]=4;a[8973080+g|0]=4;a[9038616+g|0]=4}e=g+1|0;if((e|0)<65536){g=e}else{h=0;break}}while(1){if((h&61440|0)==61440){c[8645392+(h<<2)>>2]=5076;a[8907544+h|0]=4;a[8973080+h|0]=4;a[9038616+h|0]=4}g=h+1|0;if((g|0)<65536){h=g}else{i=0;break}}while(1){if((i&61696|0)==28672){c[8645392+(i<<2)>>2]=6462;a[8907544+i|0]=4;a[8973080+i|0]=4;a[9038616+i|0]=2}h=i+1|0;if((h|0)<65536){i=h}else{j=0;break}}while(1){if((j&61824|0)==61568){c[8645392+(j<<2)>>2]=12348;a[8907544+j|0]=0;a[8973080+j|0]=0;a[9038616+j|0]=4}i=j+1|0;if((i|0)<65536){j=i}else{k=0;break}}while(1){if((k&61888|0)==61440){c[8645392+(k<<2)>>2]=3268;a[8907544+k|0]=0;a[8973080+k|0]=0;a[9038616+k|0]=4}j=k+1|0;if((j|0)<65536){k=j}else{l=0;break}}while(1){if((l&61888|0)==61504){c[8645392+(l<<2)>>2]=8100;a[8907544+l|0]=0;a[8973080+l|0]=0;a[9038616+l|0]=4}k=l+1|0;if((k|0)<65536){l=k}else{m=12088;break}}while(1){l=m|0;k=m+8|0;j=m+12|0;i=m+13|0;h=m+14|0;g=0;do{e=c[k>>2]|g;c[8645392+(e<<2)>>2]=c[l>>2];a[8907544+e|0]=a[j]|0;a[8973080+(c[k>>2]|g)|0]=a[i]|0;a[9038616+(c[k>>2]|g)|0]=a[h]|0;g=g+1|0;}while((g|0)<256);g=m+16|0;h=c[m+20>>2]|0;if((h|0)==65280){m=g}else if((h|0)==61944){n=g;o=39414;break}else{p=g;q=h;break}}if((o|0)==39414){while(1){o=0;m=n+8|0;h=n|0;g=n+12|0;k=n+13|0;i=n+14|0;j=n+15|0;l=0;do{e=l<<9;f=0;do{r=f|e|c[m>>2];c[8645392+(r<<2)>>2]=c[h>>2];s=8907544+r|0;a[s]=a[g]|0;t=8973080+r|0;a[t]=a[k]|0;a[9038616+r|0]=a[i]|0;if((r&61472|0)==57344){r=((f<<1)+14&14)+2+(d[j]|0)&255;a[t]=r;a[s]=r}f=f+1|0;}while((f|0)<8);l=l+1|0;}while((l|0)<8);l=n+16|0;j=c[n+20>>2]|0;if((j|0)==61944){n=l;o=39414}else{p=l;q=j;break}}}if((q|0)==65520){o=p;while(1){n=o|0;j=o+8|0;l=o+12|0;i=o+13|0;k=o+14|0;g=0;do{h=c[j>>2]|g;c[8645392+(h<<2)>>2]=c[n>>2];a[8907544+h|0]=a[l]|0;a[8973080+(c[j>>2]|g)|0]=a[i]|0;a[9038616+(c[j>>2]|g)|0]=a[k]|0;g=g+1|0;}while((g|0)<16);g=o+16|0;k=c[o+20>>2]|0;if((k|0)==65520){o=g}else{u=g;v=k;break}}}else{u=p;v=q}if((v|0)==61951){q=u;while(1){p=q|0;o=q+8|0;k=q+12|0;g=q+13|0;j=q+14|0;i=0;do{l=i<<9;n=c[o>>2]|l;c[8645392+(n<<2)>>2]=c[p>>2];a[8907544+n|0]=a[k]|0;a[8973080+(c[o>>2]|l)|0]=a[g]|0;a[9038616+(c[o>>2]|l)|0]=a[j]|0;i=i+1|0;}while((i|0)<8);i=q+16|0;j=c[q+20>>2]|0;if((j|0)==61951){q=i}else{w=i;x=j;break}}}else{w=u;x=v}if((x|0)==65528){v=w;while(1){u=v|0;q=v+8|0;j=v+12|0;i=v+13|0;o=v+14|0;g=0;do{k=c[q>>2]|g;c[8645392+(k<<2)>>2]=c[u>>2];a[8907544+k|0]=a[j]|0;a[8973080+(c[q>>2]|g)|0]=a[i]|0;a[9038616+(c[q>>2]|g)|0]=a[o]|0;g=g+1|0;}while((g|0)<8);g=v+16|0;o=c[v+20>>2]|0;if((o|0)==65528){v=g}else{y=g;z=o;break}}}else{y=w;z=x}if((z|0)==65535){z=y;while(1){y=z+8|0;x=c[y>>2]|0;c[8645392+(x<<2)>>2]=c[z>>2];a[8907544+x|0]=a[z+12|0]|0;a[8973080+(c[y>>2]|0)|0]=a[z+13|0]|0;a[9038616+(c[y>>2]|0)|0]=a[z+14|0]|0;if((c[z+20>>2]|0)==65535){z=z+16|0}else{break}}}if((b|0)==0){return}c[2187715]=3194;return}function Rx(){return}function Ry(a){a=a|0;c[2276080]=0;return-1|0}function Rz(a){a=a|0;return}function RA(){return}function RB(a,b){a=a|0;b=b|0;return}function RC(){return}function RD(a){a=a|0;return}function RE(a){a=a|0;return}function RF(){return}function RG(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[2276082]|0)!=0){c[2276108]=0;c[2276081]=0;b=a;return b|0}c[2226884]=a;c[2276108]=a-(c[2276081]|0);c[2276081]=0;do{a=c[2276056]|0;c[2276055]=a;e=a&-4;if((e|0)==(c[2276083]|0)){f=a;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=a}else{a=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=a;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;a=g>>>((f<<3&16^16)>>>0)&65535;c[2276069]=a;gu[c[8645392+(a<<2)>>2]&16383]();n=(c[2276108]|0)-(d[(c[2276098]|0)+(c[2276069]|0)|0]|0)|0;c[2276108]=n;}while((n|0)>0);c[2276055]=c[2276056];f=n-(c[2276081]|0)|0;c[2276108]=f;c[2276081]=0;b=(c[2226884]|0)-f|0;return b|0}function RH(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=c[2276082]&-2;c[2276082]=e;if((e|0)!=0){return}e=8452200+(c[2394]<<2)|0;if((c[e>>2]&8192|0)!=0){c[2276080]=0;c[e>>2]=0}e=c[(c[2112932]|0)+196856>>2]|0;do{if((e|0)==0){f=39483}else{g=gj[e&4095](b)|0;if((g|0)==(-1|0)){f=39483;break}else if((g|0)==(-2|0)){h=24;break}if(g>>>0<=255){h=g;break}return}}while(0);if((f|0)==39483){h=b+24|0}f=c[2276072]|0;e=c[2276073]|0;g=c[2276071]|c[2276070]|f<<11|e<<11|c[2276079]|(c[2276074]|0)>>>4&16|(c[2276075]|0)>>>4&8|((c[2276076]|0)==0)<<2|(c[2276077]|0)>>>6&2|(c[2276078]|0)>>>8&1;c[2276071]=0;c[2276070]=0;c[9104228+((f>>>1&e|f)<<2)>>2]=c[2276054];c[2276072]=4;c[2276054]=c[9104228+((c[2276073]&2|4)<<2)>>2];c[2276079]=b<<8;b=h<<2;f=c[2276085]&(c[2276064]|0)+b;e=f&16777215;i=c[2112932]|0;j=c[i+(e>>>10<<2)>>2]|0;if(j>>>0>9){k=f&1023;l=(d[j+(k+3)|0]|0)<<8|(d[j+(k+2)|0]|0)|((d[j+(k+1)|0]|0)<<8|(d[j+k|0]|0))<<16}else{l=gj[c[i+196768+(j<<2)>>2]&4095](e)|0}do{if((l|0)==0){e=c[2276085]&(c[2276064]|0)+60;j=e&16777215;i=c[2112932]|0;k=c[i+(j>>>10<<2)>>2]|0;if(k>>>0>9){f=e&1023;m=(d[k+(f+3)|0]|0)<<8|(d[k+(f+2)|0]|0)|((d[k+(f+1)|0]|0)<<8|(d[k+f|0]|0))<<16;break}else{m=gj[c[i+196768+(k<<2)>>2]&4095](j)|0;break}}else{m=l}}while(0);l=c[2276056]|0;j=c[2276054]|0;do{if(((c[2276038]|0)-1|0)>>>0<2){k=j-4|0;c[2276054]=k;i=c[2276085]&k;k=i&16777215;f=c[2112932]|0;e=c[f+((k>>>10|16384)<<2)>>2]|0;if(e>>>0>9){n=i&1023;a[e+n|0]=l>>>16&255;a[e+(n+1)|0]=l>>>24&255;a[e+(n+2)|0]=l&255;a[e+(n+3)|0]=l>>>8&255;o=f}else{gg[c[f+196808+(e<<2)>>2]&4095](k,l);o=c[2112932]|0}k=(c[2276054]|0)-2|0;c[2276054]=k;e=c[2276085]&k;k=g&65535;f=e&16777215;n=c[o+((f>>>10|16384)<<2)>>2]|0;if(n>>>0>9){i=e&1023;a[n+i|0]=g&255;a[n+(i+1)|0]=(k&65535)>>>8&255;break}else{gg[c[o+196728+(n<<2)>>2]&4095](f,k);break}}else{k=j-2|0;c[2276054]=k;f=c[2276085]&k;k=f&16777215;n=c[2112932]|0;i=c[n+((k>>>10|16384)<<2)>>2]|0;if(i>>>0>9){e=f&1023;a[i+e|0]=b&255;a[i+(e+1)|0]=h>>>6&255;p=n}else{gg[c[n+196728+(i<<2)>>2]&4095](k,b&65535);p=c[2112932]|0}k=(c[2276054]|0)-4|0;c[2276054]=k;i=c[2276085]&k;k=i&16777215;n=c[p+((k>>>10|16384)<<2)>>2]|0;if(n>>>0>9){e=i&1023;a[n+e|0]=l>>>16&255;a[n+(e+1)|0]=l>>>24&255;a[n+(e+2)|0]=l&255;a[n+(e+3)|0]=l>>>8&255;q=p}else{gg[c[p+196808+(n<<2)>>2]&4095](k,l);q=c[2112932]|0}k=(c[2276054]|0)-2|0;c[2276054]=k;n=c[2276085]&k;k=g&65535;e=n&16777215;i=c[q+((e>>>10|16384)<<2)>>2]|0;if(i>>>0>9){f=n&1023;a[i+f|0]=g&255;a[i+(f+1)|0]=(k&65535)>>>8&255;break}else{gg[c[q+196728+(i<<2)>>2]&4095](e,k);break}}}while(0);q=c[2276073]|0;do{if((q|0)!=0){if((c[2276038]&24|0)==0){break}l=c[2276072]|0;c[9104228+((l>>>1&q|l)<<2)>>2]=c[2276054];p=l&4;c[2276072]=p;j=l&2;c[2276073]=j;l=c[2276056]|0;o=(c[9104228+((p>>>1&j|p)<<2)>>2]|0)-2|0;c[2276054]=o;p=c[2276085]&o;o=(b|4096)&65535;j=p&16777215;k=c[2112932]|0;e=c[k+((j>>>10|16384)<<2)>>2]|0;if(e>>>0>9){i=p&1023;a[e+i|0]=b&255;a[e+(i+1)|0]=(o&65535)>>>8&255;r=k}else{gg[c[k+196728+(e<<2)>>2]&4095](j,o);r=c[2112932]|0}o=(c[2276054]|0)-4|0;c[2276054]=o;j=c[2276085]&o;o=j&16777215;e=c[r+((o>>>10|16384)<<2)>>2]|0;if(e>>>0>9){k=j&1023;a[e+k|0]=l>>>16&255;a[e+(k+1)|0]=l>>>24&255;a[e+(k+2)|0]=l&255;a[e+(k+3)|0]=l>>>8&255;s=r}else{gg[c[r+196808+(e<<2)>>2]&4095](o,l);s=c[2112932]|0}l=(c[2276054]|0)-2|0;c[2276054]=l;o=c[2276085]&l;l=(g|8192)&65535;e=o&16777215;k=c[s+((e>>>10|16384)<<2)>>2]|0;if(k>>>0>9){j=o&1023;a[k+j|0]=g&255;a[k+(j+1)|0]=(l&65535)>>>8&255;break}else{gg[c[s+196728+(k<<2)>>2]&4095](e,l);break}}}while(0);c[2276056]=m;c[2276081]=(c[2276081]|0)+(d[(c[2276099]|0)+h|0]|0);return}function RI(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;c[2276082]=0;c[2276108]=0;c[2276088]=1;c[2276071]=0;c[2276070]=0;c[2276079]=1792;c[2276064]=0;a=c[2276072]|0;c[9104228+((a>>>1&c[2276073]|a)<<2)>>2]=c[2276054];c[2276072]=4;c[2276073]=0;c[2276054]=c[2276061];c[2276056]=0;c[2276083]=0;a=c[2112932]|0;b=c[a+131072>>2]|0;if(b>>>0>9){e=(d[b+3|0]|0)<<8|(d[b+2|0]|0)|((d[b+1|0]|0)<<8|(d[b]|0))<<16;f=2;g=0}else{h=gj[c[a+196768+(b<<2)>>2]&4095](0)|0;e=h;f=(c[2276056]|0)+2|0;g=c[2276083]|0}c[2276084]=e;c[2276056]=f;h=f&-4;if((h|0)==(g|0)){i=e;j=f;k=g;l=e}else{c[2276083]=h;g=c[2276085]&h;b=g&16777212;a=c[2112932]|0;m=c[a+((b>>>10|32768)<<2)>>2]|0;if(m>>>0>9){n=g&1020;o=(d[m+(n|3)|0]|0)<<8|(d[m+(n|2)|0]|0)|((d[m+(n|1)|0]|0)<<8|(d[m+n|0]|0))<<16;p=f;q=h}else{h=gj[c[a+196768+(m<<2)>>2]&4095](b)|0;o=h;p=c[2276056]|0;q=c[2276083]|0}c[2276084]=o;i=o>>>16|e<<16;j=p;k=q;l=o}o=j+2|0;c[2276056]=o;c[2276054]=i;i=o&-4;if((i|0)==(k|0)){r=o;s=k;t=l}else{c[2276083]=i;l=c[2276085]&i;k=l&16777212;j=c[2112932]|0;q=c[j+((k>>>10|32768)<<2)>>2]|0;if(q>>>0>9){p=l&1020;u=(d[q+(p|3)|0]|0)<<8|(d[q+(p|2)|0]|0)|((d[q+(p|1)|0]|0)<<8|(d[q+p|0]|0))<<16;v=o;w=i}else{i=gj[c[j+196768+(q<<2)>>2]&4095](k)|0;u=i;v=c[2276056]|0;w=c[2276083]|0}c[2276084]=u;r=v;s=w;t=u}u=r+2|0;c[2276056]=u;r=u&-4;if((r|0)==(s|0)){x=t;c[2276056]=x;c[2276088]=0;return}c[2276083]=r;s=c[2276085]&r;r=s&16777212;u=c[2112932]|0;w=c[u+((r>>>10|32768)<<2)>>2]|0;if(w>>>0>9){v=s&1020;y=(d[w+(v|3)|0]|0)<<8|(d[w+(v|2)|0]|0)|((d[w+(v|1)|0]|0)<<8|(d[w+v|0]|0))<<16}else{y=gj[c[u+196768+(w<<2)>>2]&4095](r)|0}c[2276084]=y;x=y>>>16|t<<16;c[2276056]=x;c[2276088]=0;return}function RJ(d,f,g,h,j,k){d=d|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;l=i;i=i+32|0;m=l|0;n=i;i=i+32|0;gGz(m|0,0,32);o=(g|0)==0;if(!o){p=0;do{q=m+(e[f+(p<<1)>>1]<<1)|0;b[q>>1]=(b[q>>1]|0)+1&65535;p=p+1|0;}while(p>>>0<g>>>0)}p=c[j>>2]|0;q=15;while(1){if((q|0)==0){r=39551;break}if((b[m+(q<<1)>>1]|0)==0){q=q-1|0}else{break}}if((r|0)==39551){s=c[h>>2]|0;c[h>>2]=s+4;a[s|0]=64;a[s+1|0]=1;b[s+2>>1]=0;s=c[h>>2]|0;c[h>>2]=s+4;a[s|0]=64;a[s+1|0]=1;b[s+2>>1]=0;c[j>>2]=1;t=0;i=l;return t|0}s=p>>>0>q>>>0?q:p;p=1;while(1){if(p>>>0>=q>>>0){break}if((b[m+(p<<1)>>1]|0)==0){p=p+1|0}else{break}}u=s>>>0<p>>>0?p:s;s=1;v=1;while(1){if(v>>>0>=16){break}w=(s<<1)-(e[m+(v<<1)>>1]|0)|0;if((w|0)<0){t=-1;r=39593;break}else{s=w;v=v+1|0}}if((r|0)==39593){i=l;return t|0}do{if((s|0)>0){if((d|0)!=0&(q|0)==1){break}else{t=-1}i=l;return t|0}}while(0);b[n+2>>1]=0;s=b[m+2>>1]|0;b[n+4>>1]=s;v=(b[m+4>>1]|0)+s&65535;b[n+6>>1]=v;s=(b[m+6>>1]|0)+v&65535;b[n+8>>1]=s;v=(b[m+8>>1]|0)+s&65535;b[n+10>>1]=v;s=(b[m+10>>1]|0)+v&65535;b[n+12>>1]=s;v=(b[m+12>>1]|0)+s&65535;b[n+14>>1]=v;s=(b[m+14>>1]|0)+v&65535;b[n+16>>1]=s;v=(b[m+16>>1]|0)+s&65535;b[n+18>>1]=v;s=(b[m+18>>1]|0)+v&65535;b[n+20>>1]=s;v=(b[m+20>>1]|0)+s&65535;b[n+22>>1]=v;s=(b[m+22>>1]|0)+v&65535;b[n+24>>1]=s;v=(b[m+24>>1]|0)+s&65535;b[n+26>>1]=v;s=(b[m+26>>1]|0)+v&65535;b[n+28>>1]=s;b[n+30>>1]=(b[m+28>>1]|0)+s&65535;if(!o){o=0;do{s=b[f+(o<<1)>>1]|0;if(s<<16>>16!=0){v=n+((s&65535)<<1)|0;s=b[v>>1]|0;b[v>>1]=s+1&65535;b[k+((s&65535)<<1)>>1]=o&65535}o=o+1|0;}while(o>>>0<g>>>0)}do{if((d|0)==0){x=0;y=1<<u;z=19;A=k;B=k;C=0}else if((d|0)==1){g=1<<u;if(g>>>0>852){t=1}else{x=1;y=g;z=256;A=47342;B=47406;C=0;break}i=l;return t|0}else{g=1<<u;o=(d|0)==2;if(o&g>>>0>592){t=1}else{x=0;y=g;z=-1;A=47984;B=48048;C=o;break}i=l;return t|0}}while(0);d=y-1|0;o=u&255;g=c[h>>2]|0;n=-1;s=0;v=y;y=0;w=u;D=0;E=p;L50493:while(1){p=1<<w;F=s;G=D;H=E;while(1){I=H-y|0;J=I&255;K=b[k+(G<<1)>>1]|0;L=K&65535;do{if((L|0)<(z|0)){M=0;N=K}else{if((L|0)<=(z|0)){M=96;N=0;break}M=b[A+(L<<1)>>1]&255;N=b[B+(L<<1)>>1]|0}}while(0);L=1<<I;K=F>>>(y>>>0);O=p;while(1){P=O-L|0;Q=P+K|0;a[g+(Q<<2)|0]=M;a[g+(Q<<2)+1|0]=J;b[g+(Q<<2)+2>>1]=N;if((O|0)==(L|0)){break}else{O=P}}O=1<<H-1;while(1){if((O&F|0)==0){break}else{O=O>>>1}}if((O|0)==0){R=0}else{R=(O-1&F)+O|0}S=G+1|0;L=m+(H<<1)|0;K=(b[L>>1]|0)-1&65535;b[L>>1]=K;if(K<<16>>16==0){if((H|0)==(q|0)){break L50493}T=e[f+(e[k+(S<<1)>>1]<<1)>>1]|0}else{T=H}if(T>>>0<=u>>>0){F=R;G=S;H=T;continue}U=R&d;if((U|0)==(n|0)){F=R;G=S;H=T}else{break}}H=(y|0)==0?u:y;G=g+(p<<2)|0;F=T-H|0;L50516:do{if(T>>>0<q>>>0){K=F;L=1<<F;I=T;while(1){P=L-(e[m+(I<<1)>>1]|0)|0;if((P|0)<1){V=K;break L50516}Q=K+1|0;W=Q+H|0;if(W>>>0<q>>>0){K=Q;L=P<<1;I=W}else{V=Q;break}}}else{V=F}}while(0);F=(1<<V)+v|0;if(x&F>>>0>852|C&F>>>0>592){t=1;r=39596;break}a[(c[h>>2]|0)+(U<<2)|0]=V&255;a[(c[h>>2]|0)+(U<<2)+1|0]=o;p=c[h>>2]|0;b[p+(U<<2)+2>>1]=(G-p|0)>>>2&65535;g=G;n=U;s=R;v=F;y=H;w=V;D=S;E=T}if((r|0)==39596){i=l;return t|0}if((R|0)!=0){a[g+(R<<2)|0]=64;a[g+(R<<2)+1|0]=J;b[g+(R<<2)+2>>1]=0}c[h>>2]=(c[h>>2]|0)+(v<<2);c[j>>2]=u;t=0;i=l;return t|0}function RK(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;if((b|0)==0){f=0;return f|0}g=~a;L50534:do{if((e|0)==0){h=g}else{a=b;i=e;j=g;while(1){if((a&3|0)==0){break}k=c[53408+(((d[a]|0)^j&255)<<2)>>2]^j>>>8;l=i-1|0;if((l|0)==0){h=k;break L50534}else{a=a+1|0;i=l;j=k}}k=a;if(i>>>0>31){l=i;m=j;n=k;while(1){o=c[n>>2]^m;p=c[55456+((o>>>8&255)<<2)>>2]^c[56480+((o&255)<<2)>>2]^c[54432+((o>>>16&255)<<2)>>2]^c[53408+(o>>>24<<2)>>2]^c[n+4>>2];o=c[55456+((p>>>8&255)<<2)>>2]^c[56480+((p&255)<<2)>>2]^c[54432+((p>>>16&255)<<2)>>2]^c[53408+(p>>>24<<2)>>2]^c[n+8>>2];p=c[55456+((o>>>8&255)<<2)>>2]^c[56480+((o&255)<<2)>>2]^c[54432+((o>>>16&255)<<2)>>2]^c[53408+(o>>>24<<2)>>2]^c[n+12>>2];o=c[55456+((p>>>8&255)<<2)>>2]^c[56480+((p&255)<<2)>>2]^c[54432+((p>>>16&255)<<2)>>2]^c[53408+(p>>>24<<2)>>2]^c[n+16>>2];p=c[55456+((o>>>8&255)<<2)>>2]^c[56480+((o&255)<<2)>>2]^c[54432+((o>>>16&255)<<2)>>2]^c[53408+(o>>>24<<2)>>2]^c[n+20>>2];o=c[55456+((p>>>8&255)<<2)>>2]^c[56480+((p&255)<<2)>>2]^c[54432+((p>>>16&255)<<2)>>2]^c[53408+(p>>>24<<2)>>2]^c[n+24>>2];p=n+32|0;q=c[55456+((o>>>8&255)<<2)>>2]^c[56480+((o&255)<<2)>>2]^c[54432+((o>>>16&255)<<2)>>2]^c[53408+(o>>>24<<2)>>2]^c[n+28>>2];o=c[55456+((q>>>8&255)<<2)>>2]^c[56480+((q&255)<<2)>>2]^c[54432+((q>>>16&255)<<2)>>2]^c[53408+(q>>>24<<2)>>2];q=l-32|0;if(q>>>0>31){l=q;m=o;n=p}else{r=q;s=o;t=p;break}}}else{r=i;s=j;t=k}if(r>>>0>3){n=r;m=s;l=t;while(1){a=l+4|0;p=c[l>>2]^m;o=c[55456+((p>>>8&255)<<2)>>2]^c[56480+((p&255)<<2)>>2]^c[54432+((p>>>16&255)<<2)>>2]^c[53408+(p>>>24<<2)>>2];p=n-4|0;if(p>>>0>3){n=p;m=o;l=a}else{u=p;v=o;w=a;break}}}else{u=r;v=s;w=t}if((u|0)==0){h=v;break}l=v;m=u;n=w;while(1){k=c[53408+(((d[n]|0)^l&255)<<2)>>2]^l>>>8;j=m-1|0;if((j|0)==0){h=k;break}else{l=k;m=j;n=n+1|0}}}}while(0);f=~h;return f|0}function RL(a){a=a|0;var d=0;d=0;do{b[a+148+(d<<2)>>1]=0;d=d+1|0;}while((d|0)<286);b[a+2440>>1]=0;b[a+2444>>1]=0;b[a+2448>>1]=0;b[a+2452>>1]=0;b[a+2456>>1]=0;b[a+2460>>1]=0;b[a+2464>>1]=0;b[a+2468>>1]=0;b[a+2472>>1]=0;b[a+2476>>1]=0;b[a+2480>>1]=0;b[a+2484>>1]=0;b[a+2488>>1]=0;b[a+2492>>1]=0;b[a+2496>>1]=0;b[a+2500>>1]=0;b[a+2504>>1]=0;b[a+2508>>1]=0;b[a+2512>>1]=0;b[a+2516>>1]=0;b[a+2520>>1]=0;b[a+2524>>1]=0;b[a+2528>>1]=0;b[a+2532>>1]=0;b[a+2536>>1]=0;b[a+2540>>1]=0;b[a+2544>>1]=0;b[a+2548>>1]=0;b[a+2552>>1]=0;b[a+2556>>1]=0;b[a+2684>>1]=0;b[a+2688>>1]=0;b[a+2692>>1]=0;b[a+2696>>1]=0;b[a+2700>>1]=0;b[a+2704>>1]=0;b[a+2708>>1]=0;b[a+2712>>1]=0;b[a+2716>>1]=0;b[a+2720>>1]=0;b[a+2724>>1]=0;b[a+2728>>1]=0;b[a+2732>>1]=0;b[a+2736>>1]=0;b[a+2740>>1]=0;b[a+2744>>1]=0;b[a+2748>>1]=0;b[a+2752>>1]=0;b[a+2756>>1]=0;b[a+1172>>1]=1;c[a+5804>>2]=0;c[a+5800>>2]=0;c[a+5808>>2]=0;c[a+5792>>2]=0;return}function RM(d,f,g,h){d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;i=d+5820|0;j=c[i>>2]|0;k=h&65535;h=d+5816|0;l=e[h>>1]|0|k<<j;b[h>>1]=l&65535;if((j|0)>13){m=d+20|0;n=c[m>>2]|0;c[m>>2]=n+1;o=d+8|0;a[(c[o>>2]|0)+n|0]=l&255;n=(e[h>>1]|0)>>>8&255;p=c[m>>2]|0;c[m>>2]=p+1;a[(c[o>>2]|0)+p|0]=n;n=c[i>>2]|0;p=k>>>((16-n|0)>>>0);b[h>>1]=p&65535;q=n-13|0;r=p}else{q=j+3|0;r=l}l=r&255;c[i>>2]=q;do{if((q|0)>8){r=d+20|0;j=c[r>>2]|0;c[r>>2]=j+1;p=d+8|0;a[(c[p>>2]|0)+j|0]=l;j=(e[h>>1]|0)>>>8&255;n=c[r>>2]|0;c[r>>2]=n+1;a[(c[p>>2]|0)+n|0]=j;s=r;t=p}else{p=d+20|0;if((q|0)>0){r=c[p>>2]|0;c[p>>2]=r+1;j=d+8|0;a[(c[j>>2]|0)+r|0]=l;s=p;t=j;break}else{s=p;t=d+8|0;break}}}while(0);b[h>>1]=0;c[i>>2]=0;i=c[s>>2]|0;c[s>>2]=i+1;a[(c[t>>2]|0)+i|0]=g&255;i=c[s>>2]|0;c[s>>2]=i+1;a[(c[t>>2]|0)+i|0]=g>>>8&255;i=g&65535^65535;h=c[s>>2]|0;c[s>>2]=h+1;a[(c[t>>2]|0)+h|0]=i&255;h=c[s>>2]|0;c[s>>2]=h+1;a[(c[t>>2]|0)+h|0]=i>>>8&255;if((g|0)==0){return}else{u=g;v=f}while(1){f=u-1|0;g=a[v]|0;i=c[s>>2]|0;c[s>>2]=i+1;a[(c[t>>2]|0)+i|0]=g;if((f|0)==0){break}else{u=f;v=v+1|0}}return}function RN(f,g,h,i){f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;if((c[f+132>>2]|0)>0){j=(c[f>>2]|0)+44|0;if((c[j>>2]|0)==2){k=-201342849;l=0;while(1){if((k&1|0)!=0){if((b[f+148+(l<<2)>>1]|0)!=0){m=0;break}}n=l+1|0;if((n|0)<32){k=k>>>1;l=n}else{o=39636;break}}L50582:do{if((o|0)==39636){if((b[f+184>>1]|0)!=0){m=1;break}if((b[f+188>>1]|0)!=0){m=1;break}if((b[f+200>>1]|0)==0){p=32}else{m=1;break}while(1){if((p|0)>=256){m=0;break L50582}if((b[f+148+(p<<2)>>1]|0)==0){p=p+1|0}else{m=1;break}}}}while(0);c[j>>2]=m}RO(f,f+2840|0);RO(f,f+2852|0);RR(f,f+148|0,c[f+2844>>2]|0);RR(f,f+2440|0,c[f+2856>>2]|0);RO(f,f+2864|0);m=18;while(1){if((m|0)<=2){break}if((b[f+2684+(d[62120+m|0]<<2)+2>>1]|0)==0){m=m-1|0}else{break}}j=f+5800|0;p=(m*3|0)+17+(c[j>>2]|0)|0;c[j>>2]=p;j=(p+10|0)>>>3;p=((c[f+5804>>2]|0)+10|0)>>>3;q=p>>>0>j>>>0?j:p;r=p;s=m}else{m=h+5|0;q=m;r=m;s=0}do{if((h+4|0)>>>0>q>>>0|(g|0)==0){m=f+5820|0;p=c[m>>2]|0;j=(p|0)>13;if((c[f+136>>2]|0)==4|(r|0)==(q|0)){o=i+2&65535;l=f+5816|0;k=e[l>>1]|o<<p;b[l>>1]=k&65535;if(j){n=f+20|0;t=c[n>>2]|0;c[n>>2]=t+1;u=f+8|0;a[(c[u>>2]|0)+t|0]=k&255;k=(e[l>>1]|0)>>>8&255;t=c[n>>2]|0;c[n>>2]=t+1;a[(c[u>>2]|0)+t|0]=k;k=c[m>>2]|0;b[l>>1]=o>>>((16-k|0)>>>0)&65535;v=k-13|0}else{v=p+3|0}c[m>>2]=v;RP(f,1192,2368);break}k=i+4&65535;o=f+5816|0;l=e[o>>1]|k<<p;t=l&65535;b[o>>1]=t;if(j){j=f+20|0;u=c[j>>2]|0;c[j>>2]=u+1;n=f+8|0;a[(c[n>>2]|0)+u|0]=l&255;l=(e[o>>1]|0)>>>8&255;u=c[j>>2]|0;c[j>>2]=u+1;a[(c[n>>2]|0)+u|0]=l;l=c[m>>2]|0;u=k>>>((16-l|0)>>>0)&65535;b[o>>1]=u;w=l-13|0;x=u}else{w=p+3|0;x=t}c[m>>2]=w;t=c[f+2844>>2]|0;p=c[f+2856>>2]|0;u=s+1|0;l=t+65280&65535;k=l<<w|x&65535;n=k&65535;b[o>>1]=n;if((w|0)>11){j=f+20|0;y=c[j>>2]|0;c[j>>2]=y+1;z=f+8|0;a[(c[z>>2]|0)+y|0]=k&255;k=(e[o>>1]|0)>>>8&255;y=c[j>>2]|0;c[j>>2]=y+1;a[(c[z>>2]|0)+y|0]=k;k=c[m>>2]|0;y=l>>>((16-k|0)>>>0)&65535;b[o>>1]=y;A=k-11|0;B=y}else{A=w+5|0;B=n}c[m>>2]=A;n=p&65535;y=n<<A|B&65535;k=y&65535;b[o>>1]=k;if((A|0)>11){l=f+20|0;z=c[l>>2]|0;c[l>>2]=z+1;j=f+8|0;a[(c[j>>2]|0)+z|0]=y&255;y=(e[o>>1]|0)>>>8&255;z=c[l>>2]|0;c[l>>2]=z+1;a[(c[j>>2]|0)+z|0]=y;y=c[m>>2]|0;z=n>>>((16-y|0)>>>0)&65535;b[o>>1]=z;C=y-11|0;D=z}else{C=A+5|0;D=k}c[m>>2]=C;k=s+65533&65535;z=k<<C|D&65535;y=z&65535;b[o>>1]=y;if((C|0)>12){n=f+20|0;j=c[n>>2]|0;c[n>>2]=j+1;l=f+8|0;a[(c[l>>2]|0)+j|0]=z&255;z=(e[o>>1]|0)>>>8&255;j=c[n>>2]|0;c[n>>2]=j+1;a[(c[l>>2]|0)+j|0]=z;z=c[m>>2]|0;j=k>>>((16-z|0)>>>0)&65535;b[o>>1]=j;E=z-12|0;F=j}else{E=C+4|0;F=y}c[m>>2]=E;if((u|0)>0){y=f+20|0;j=f+8|0;z=0;k=E;l=F;while(1){n=e[f+2684+(d[62120+z|0]<<2)+2>>1]|0;G=n<<k|l&65535;H=G&65535;b[o>>1]=H;if((k|0)>13){I=c[y>>2]|0;c[y>>2]=I+1;a[(c[j>>2]|0)+I|0]=G&255;G=(e[o>>1]|0)>>>8&255;I=c[y>>2]|0;c[y>>2]=I+1;a[(c[j>>2]|0)+I|0]=G;G=c[m>>2]|0;I=n>>>((16-G|0)>>>0)&65535;b[o>>1]=I;J=G-13|0;K=I}else{J=k+3|0;K=H}c[m>>2]=J;H=z+1|0;if((H|0)<(u|0)){z=H;k=J;l=K}else{break}}}l=f+148|0;RQ(f,l,t);k=f+2440|0;RQ(f,k,p);RP(f,l,k)}else{RM(f,g,h,i)}}while(0);RL(f);if((i|0)==0){return}i=f+5820|0;h=c[i>>2]|0;do{if((h|0)>8){g=f+5816|0;K=b[g>>1]&255;J=f+20|0;F=c[J>>2]|0;c[J>>2]=F+1;E=f+8|0;a[(c[E>>2]|0)+F|0]=K;K=(e[g>>1]|0)>>>8&255;F=c[J>>2]|0;c[J>>2]=F+1;a[(c[E>>2]|0)+F|0]=K;L=g}else{g=f+5816|0;if((h|0)<=0){L=g;break}K=b[g>>1]&255;F=f+20|0;E=c[F>>2]|0;c[F>>2]=E+1;a[(c[f+8>>2]|0)+E|0]=K;L=g}}while(0);b[L>>1]=0;c[i>>2]=0;return}function RO(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;h=i;i=i+32|0;j=h|0;k=g|0;l=c[k>>2]|0;m=g+8|0;n=c[m>>2]|0;o=c[n>>2]|0;p=c[n+12>>2]|0;n=f+5200|0;c[n>>2]=0;q=f+5204|0;c[q>>2]=573;if((p|0)>0){r=0;s=-1;while(1){if((b[l+(r<<2)>>1]|0)==0){b[l+(r<<2)+2>>1]=0;t=s}else{u=(c[n>>2]|0)+1|0;c[n>>2]=u;c[f+2908+(u<<2)>>2]=r;a[f+5208+r|0]=0;t=r}u=r+1|0;if((u|0)<(p|0)){r=u;s=t}else{break}}s=c[n>>2]|0;if((s|0)<2){v=s;w=t;x=39684}else{y=t}}else{v=0;w=-1;x=39684}if((x|0)==39684){x=f+5800|0;t=f+5804|0;if((o|0)==0){s=w;r=v;while(1){u=(s|0)<2;z=s+1|0;A=u?z:s;B=u?z:0;z=r+1|0;c[n>>2]=z;c[f+2908+(z<<2)>>2]=B;b[l+(B<<2)>>1]=1;a[f+5208+B|0]=0;c[x>>2]=(c[x>>2]|0)-1;B=c[n>>2]|0;if((B|0)<2){s=A;r=B}else{y=A;break}}}else{r=w;w=v;while(1){v=(r|0)<2;s=r+1|0;A=v?s:r;B=v?s:0;s=w+1|0;c[n>>2]=s;c[f+2908+(s<<2)>>2]=B;b[l+(B<<2)>>1]=1;a[f+5208+B|0]=0;c[x>>2]=(c[x>>2]|0)-1;c[t>>2]=(c[t>>2]|0)-(e[o+(B<<2)+2>>1]|0);B=c[n>>2]|0;if((B|0)<2){r=A;w=B}else{y=A;break}}}}w=g+4|0;c[w>>2]=y;g=c[n>>2]|0;if((g|0)>1){r=(g|0)/2|0;o=g;while(1){t=c[f+2908+(r<<2)>>2]|0;x=f+5208+t|0;A=r<<1;L50663:do{if((A|0)>(o|0)){C=r}else{B=l+(t<<2)|0;s=r;v=A;z=o;while(1){do{if((v|0)<(z|0)){u=v|1;D=c[f+2908+(u<<2)>>2]|0;E=b[l+(D<<2)>>1]|0;F=c[f+2908+(v<<2)>>2]|0;G=b[l+(F<<2)>>1]|0;if((E&65535)>=(G&65535)){if(E<<16>>16!=G<<16>>16){H=v;break}if((d[f+5208+D|0]|0)>(d[f+5208+F|0]|0)){H=v;break}}H=u}else{H=v}}while(0);u=b[B>>1]|0;F=c[f+2908+(H<<2)>>2]|0;D=b[l+(F<<2)>>1]|0;if((u&65535)<(D&65535)){C=s;break L50663}if(u<<16>>16==D<<16>>16){if((d[x]|0)<=(d[f+5208+F|0]|0)){C=s;break L50663}}c[f+2908+(s<<2)>>2]=F;F=H<<1;D=c[n>>2]|0;if((F|0)>(D|0)){C=H;break}else{s=H;v=F;z=D}}}}while(0);c[f+2908+(C<<2)>>2]=t;x=r-1|0;A=c[n>>2]|0;if((x|0)>0){r=x;o=A}else{I=A;break}}}else{I=g}g=f+2912|0;o=p;p=I;while(1){I=c[g>>2]|0;r=p-1|0;c[n>>2]=r;C=c[f+2908+(p<<2)>>2]|0;c[g>>2]=C;H=f+5208+C|0;L50682:do{if((r|0)<2){J=1}else{A=l+(C<<2)|0;x=1;z=2;v=r;while(1){do{if((z|0)<(v|0)){s=z|1;B=c[f+2908+(s<<2)>>2]|0;D=b[l+(B<<2)>>1]|0;F=c[f+2908+(z<<2)>>2]|0;u=b[l+(F<<2)>>1]|0;if((D&65535)>=(u&65535)){if(D<<16>>16!=u<<16>>16){K=z;break}if((d[f+5208+B|0]|0)>(d[f+5208+F|0]|0)){K=z;break}}K=s}else{K=z}}while(0);s=b[A>>1]|0;F=c[f+2908+(K<<2)>>2]|0;B=b[l+(F<<2)>>1]|0;if((s&65535)<(B&65535)){J=x;break L50682}if(s<<16>>16==B<<16>>16){if((d[H]|0)<=(d[f+5208+F|0]|0)){J=x;break L50682}}c[f+2908+(x<<2)>>2]=F;F=K<<1;B=c[n>>2]|0;if((F|0)>(B|0)){J=K;break}else{x=K;z=F;v=B}}}}while(0);c[f+2908+(J<<2)>>2]=C;H=c[g>>2]|0;r=(c[q>>2]|0)-1|0;c[q>>2]=r;c[f+2908+(r<<2)>>2]=I;r=(c[q>>2]|0)-1|0;c[q>>2]=r;c[f+2908+(r<<2)>>2]=H;r=l+(o<<2)|0;b[r>>1]=(b[l+(H<<2)>>1]|0)+(b[l+(I<<2)>>1]|0)&65535;t=a[f+5208+I|0]|0;v=a[f+5208+H|0]|0;z=f+5208+o|0;a[z]=((t&255)<(v&255)?v:t)+1&255;t=o&65535;b[l+(H<<2)+2>>1]=t;b[l+(I<<2)+2>>1]=t;t=o+1|0;c[g>>2]=o;H=c[n>>2]|0;L50698:do{if((H|0)<2){L=1}else{v=1;x=2;A=H;while(1){do{if((x|0)<(A|0)){B=x|1;F=c[f+2908+(B<<2)>>2]|0;s=b[l+(F<<2)>>1]|0;u=c[f+2908+(x<<2)>>2]|0;D=b[l+(u<<2)>>1]|0;if((s&65535)>=(D&65535)){if(s<<16>>16!=D<<16>>16){M=x;break}if((d[f+5208+F|0]|0)>(d[f+5208+u|0]|0)){M=x;break}}M=B}else{M=x}}while(0);B=b[r>>1]|0;u=c[f+2908+(M<<2)>>2]|0;F=b[l+(u<<2)>>1]|0;if((B&65535)<(F&65535)){L=v;break L50698}if(B<<16>>16==F<<16>>16){if((d[z]|0)<=(d[f+5208+u|0]|0)){L=v;break L50698}}c[f+2908+(v<<2)>>2]=u;u=M<<1;F=c[n>>2]|0;if((u|0)>(F|0)){L=M;break}else{v=M;x=u;A=F}}}}while(0);c[f+2908+(L<<2)>>2]=o;z=c[n>>2]|0;if((z|0)>1){o=t;p=z}else{break}}p=c[g>>2]|0;g=(c[q>>2]|0)-1|0;c[q>>2]=g;c[f+2908+(g<<2)>>2]=p;p=c[k>>2]|0;k=c[w>>2]|0;w=c[m>>2]|0;m=c[w>>2]|0;g=c[w+4>>2]|0;o=c[w+8>>2]|0;n=c[w+16>>2]|0;w=f+2876|0;gGz(w|0,0,32);b[p+(c[f+2908+(c[q>>2]<<2)>>2]<<2)+2>>1]=0;L=(c[q>>2]|0)+1|0;L50714:do{if((L|0)<573){q=f+5800|0;M=f+5804|0;if((m|0)==0){J=0;K=L;while(1){z=c[f+2908+(K<<2)>>2]|0;r=p+(z<<2)+2|0;H=(e[p+(e[r>>1]<<2)+2>>1]|0)+1|0;I=(H|0)>(n|0);C=I?n:H;H=(I&1)+J|0;b[r>>1]=C&65535;if((z|0)<=(k|0)){r=f+2876+(C<<1)|0;b[r>>1]=(b[r>>1]|0)+1&65535;if((z|0)<(o|0)){N=0}else{N=c[g+(z-o<<2)>>2]|0}r=ag(e[p+(z<<2)>>1]|0,N+C|0)|0;c[q>>2]=r+(c[q>>2]|0)}r=K+1|0;if((r|0)<573){J=H;K=r}else{O=H;break}}}else{K=0;J=L;while(1){t=c[f+2908+(J<<2)>>2]|0;H=p+(t<<2)+2|0;r=(e[p+(e[H>>1]<<2)+2>>1]|0)+1|0;C=(r|0)>(n|0);z=C?n:r;r=(C&1)+K|0;b[H>>1]=z&65535;if((t|0)<=(k|0)){H=f+2876+(z<<1)|0;b[H>>1]=(b[H>>1]|0)+1&65535;if((t|0)<(o|0)){P=0}else{P=c[g+(t-o<<2)>>2]|0}H=e[p+(t<<2)>>1]|0;C=ag(H,P+z|0)|0;c[q>>2]=C+(c[q>>2]|0);C=ag((e[m+(t<<2)+2>>1]|0)+P|0,H)|0;c[M>>2]=C+(c[M>>2]|0)}C=J+1|0;if((C|0)<573){K=r;J=C}else{O=r;break}}}if((O|0)==0){break}J=f+2876+(n<<1)|0;K=O;do{M=n;while(1){r=M-1|0;Q=f+2876+(r<<1)|0;R=b[Q>>1]|0;if(R<<16>>16==0){M=r}else{break}}b[Q>>1]=R-1&65535;r=f+2876+(M<<1)|0;b[r>>1]=(b[r>>1]|0)+2&65535;S=(b[J>>1]|0)-1&65535;b[J>>1]=S;K=K-2|0;}while((K|0)>0);if((n|0)==0){break}else{T=n;U=573;V=S}while(1){K=T&65535;if(V<<16>>16==0){W=U}else{J=V&65535;r=U;while(1){C=r;do{C=C-1|0;X=c[f+2908+(C<<2)>>2]|0;}while((X|0)>(k|0));H=p+(X<<2)+2|0;t=e[H>>1]|0;if((t|0)!=(T|0)){z=ag(e[p+(X<<2)>>1]|0,T-t|0)|0;c[q>>2]=z+(c[q>>2]|0);b[H>>1]=K}H=J-1|0;if((H|0)==0){W=C;break}else{J=H;r=C}}}r=T-1|0;if((r|0)==0){break L50714}T=r;U=W;V=b[f+2876+(r<<1)>>1]|0}}}while(0);V=b[w>>1]<<1;b[j+2>>1]=V;w=((b[f+2878>>1]|0)+V&65535)<<1;b[j+4>>1]=w;V=(w+(b[f+2880>>1]|0)&65535)<<1;b[j+6>>1]=V;w=(V+(b[f+2882>>1]|0)&65535)<<1;b[j+8>>1]=w;V=(w+(b[f+2884>>1]|0)&65535)<<1;b[j+10>>1]=V;w=(V+(b[f+2886>>1]|0)&65535)<<1;b[j+12>>1]=w;V=(w+(b[f+2888>>1]|0)&65535)<<1;b[j+14>>1]=V;w=(V+(b[f+2890>>1]|0)&65535)<<1;b[j+16>>1]=w;V=(w+(b[f+2892>>1]|0)&65535)<<1;b[j+18>>1]=V;w=(V+(b[f+2894>>1]|0)&65535)<<1;b[j+20>>1]=w;V=(w+(b[f+2896>>1]|0)&65535)<<1;b[j+22>>1]=V;w=(V+(b[f+2898>>1]|0)&65535)<<1;b[j+24>>1]=w;V=(w+(b[f+2900>>1]|0)&65535)<<1;b[j+26>>1]=V;w=(V+(b[f+2902>>1]|0)&65535)<<1;b[j+28>>1]=w;b[j+30>>1]=(w+(b[f+2904>>1]|0)&65535)<<1;if((y|0)<0){i=h;return}else{Y=0}do{f=b[l+(Y<<2)+2>>1]|0;w=f&65535;if(f<<16>>16!=0){f=j+(w<<1)|0;V=b[f>>1]|0;b[f>>1]=V+1&65535;f=0;W=w;w=V&65535;while(1){Z=f|w&1;V=W-1|0;if((V|0)>0){f=Z<<1;W=V;w=w>>>1}else{break}}b[l+(Y<<2)>>1]=Z&65535}Y=Y+1|0;}while((Y|0)<=(y|0));i=h;return}function RP(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;i=f+5792|0;if((c[i>>2]|0)==0){j=c[f+5820>>2]|0;k=b[f+5816>>1]|0}else{l=f+5796|0;m=f+5784|0;n=f+5820|0;o=f+5816|0;p=f+20|0;q=f+8|0;r=0;while(1){s=b[(c[l>>2]|0)+(r<<1)>>1]|0;t=s&65535;u=r+1|0;v=d[(c[m>>2]|0)+r|0]|0;do{if(s<<16>>16==0){w=e[g+(v<<2)+2>>1]|0;x=c[n>>2]|0;y=e[g+(v<<2)>>1]|0;z=e[o>>1]|0|y<<x;A=z&65535;b[o>>1]=A;if((x|0)>(16-w|0)){B=c[p>>2]|0;c[p>>2]=B+1;a[(c[q>>2]|0)+B|0]=z&255;z=(e[o>>1]|0)>>>8&255;B=c[p>>2]|0;c[p>>2]=B+1;a[(c[q>>2]|0)+B|0]=z;z=c[n>>2]|0;B=y>>>((16-z|0)>>>0)&65535;b[o>>1]=B;y=w-16+z|0;c[n>>2]=y;C=y;D=B;break}else{B=x+w|0;c[n>>2]=B;C=B;D=A;break}}else{A=d[589976+v|0]|0;B=(A|256)+1|0;w=e[g+(B<<2)+2>>1]|0;x=c[n>>2]|0;y=e[g+(B<<2)>>1]|0;B=e[o>>1]|0|y<<x;z=B&65535;b[o>>1]=z;if((x|0)>(16-w|0)){E=c[p>>2]|0;c[p>>2]=E+1;a[(c[q>>2]|0)+E|0]=B&255;B=(e[o>>1]|0)>>>8&255;E=c[p>>2]|0;c[p>>2]=E+1;a[(c[q>>2]|0)+E|0]=B;B=c[n>>2]|0;E=y>>>((16-B|0)>>>0)&65535;b[o>>1]=E;F=w-16+B|0;G=E}else{F=x+w|0;G=z}c[n>>2]=F;z=c[51472+(A<<2)>>2]|0;do{if((A-8|0)>>>0<20){w=v-(c[63992+(A<<2)>>2]|0)&65535;x=w<<F|G&65535;E=x&65535;b[o>>1]=E;if((F|0)>(16-z|0)){B=c[p>>2]|0;c[p>>2]=B+1;a[(c[q>>2]|0)+B|0]=x&255;x=(e[o>>1]|0)>>>8&255;B=c[p>>2]|0;c[p>>2]=B+1;a[(c[q>>2]|0)+B|0]=x;x=c[n>>2]|0;B=w>>>((16-x|0)>>>0)&65535;b[o>>1]=B;w=z-16+x|0;c[n>>2]=w;H=w;I=B;break}else{B=z+F|0;c[n>>2]=B;H=B;I=E;break}}else{H=F;I=G}}while(0);z=t-1|0;if(z>>>0<256){J=z}else{J=(z>>>7)+256|0}A=d[590232+J|0]|0;E=e[h+(A<<2)+2>>1]|0;B=e[h+(A<<2)>>1]|0;w=B<<H|I&65535;x=w&65535;b[o>>1]=x;if((H|0)>(16-E|0)){y=c[p>>2]|0;c[p>>2]=y+1;a[(c[q>>2]|0)+y|0]=w&255;w=(e[o>>1]|0)>>>8&255;y=c[p>>2]|0;c[p>>2]=y+1;a[(c[q>>2]|0)+y|0]=w;w=c[n>>2]|0;y=B>>>((16-w|0)>>>0)&65535;b[o>>1]=y;K=E-16+w|0;L=y}else{K=E+H|0;L=x}c[n>>2]=K;x=c[51592+(A<<2)>>2]|0;if((A-4|0)>>>0>=26){C=K;D=L;break}E=z-(c[64112+(A<<2)>>2]|0)&65535;A=E<<K|L&65535;z=A&65535;b[o>>1]=z;if((K|0)>(16-x|0)){y=c[p>>2]|0;c[p>>2]=y+1;a[(c[q>>2]|0)+y|0]=A&255;A=(e[o>>1]|0)>>>8&255;y=c[p>>2]|0;c[p>>2]=y+1;a[(c[q>>2]|0)+y|0]=A;A=c[n>>2]|0;y=E>>>((16-A|0)>>>0)&65535;b[o>>1]=y;E=x-16+A|0;c[n>>2]=E;C=E;D=y;break}else{y=x+K|0;c[n>>2]=y;C=y;D=z;break}}}while(0);if(u>>>0<(c[i>>2]|0)>>>0){r=u}else{j=C;k=D;break}}}D=e[g+1026>>1]|0;C=f+5820|0;r=e[g+1024>>1]|0;g=f+5816|0;i=r<<j|k&65535;b[g>>1]=i&65535;if((j|0)>(16-D|0)){k=f+20|0;n=c[k>>2]|0;c[k>>2]=n+1;K=f+8|0;a[(c[K>>2]|0)+n|0]=i&255;i=(e[g>>1]|0)>>>8&255;n=c[k>>2]|0;c[k>>2]=n+1;a[(c[K>>2]|0)+n|0]=i;i=c[C>>2]|0;b[g>>1]=r>>>((16-i|0)>>>0)&65535;M=D-16+i|0;c[C>>2]=M;return}else{M=D+j|0;c[C>>2]=M;return}}function RQ(d,f,g){d=d|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;h=b[f+2>>1]|0;i=h<<16>>16==0;j=d+2754|0;k=d+5820|0;l=d+2752|0;m=d+5816|0;n=d+20|0;o=d+8|0;p=d+2758|0;q=d+2756|0;r=d+2750|0;s=d+2748|0;t=0;u=-1;v=h&65535;h=i?138:7;w=i?3:4;L50808:while(1){i=t;x=0;while(1){if((i|0)>(g|0)){break L50808}y=i+1|0;z=b[f+(y<<2)+2>>1]|0;A=z&65535;B=x+1|0;C=(v|0)==(A|0);if((B|0)<(h|0)&C){i=y;x=B}else{break}}do{if((B|0)<(w|0)){i=d+2684+(v<<2)+2|0;D=d+2684+(v<<2)|0;E=B;F=c[k>>2]|0;G=b[m>>1]|0;while(1){H=e[i>>1]|0;I=e[D>>1]|0;J=I<<F|G&65535;K=J&65535;b[m>>1]=K;if((F|0)>(16-H|0)){L=c[n>>2]|0;c[n>>2]=L+1;a[(c[o>>2]|0)+L|0]=J&255;J=(e[m>>1]|0)>>>8&255;L=c[n>>2]|0;c[n>>2]=L+1;a[(c[o>>2]|0)+L|0]=J;J=c[k>>2]|0;L=I>>>((16-J|0)>>>0)&65535;b[m>>1]=L;M=H-16+J|0;N=L}else{M=H+F|0;N=K}c[k>>2]=M;K=E-1|0;if((K|0)==0){break}else{E=K;F=M;G=N}}}else{if((v|0)!=0){if((v|0)==(u|0)){O=B;P=c[k>>2]|0;Q=b[m>>1]|0}else{G=e[d+2684+(v<<2)+2>>1]|0;F=c[k>>2]|0;E=e[d+2684+(v<<2)>>1]|0;D=e[m>>1]|0|E<<F;i=D&65535;b[m>>1]=i;if((F|0)>(16-G|0)){K=c[n>>2]|0;c[n>>2]=K+1;a[(c[o>>2]|0)+K|0]=D&255;D=(e[m>>1]|0)>>>8&255;K=c[n>>2]|0;c[n>>2]=K+1;a[(c[o>>2]|0)+K|0]=D;D=c[k>>2]|0;K=E>>>((16-D|0)>>>0)&65535;b[m>>1]=K;R=G-16+D|0;S=K}else{R=F+G|0;S=i}c[k>>2]=R;O=x;P=R;Q=S}i=e[r>>1]|0;G=e[s>>1]|0;F=G<<P|Q&65535;K=F&65535;b[m>>1]=K;if((P|0)>(16-i|0)){D=c[n>>2]|0;c[n>>2]=D+1;a[(c[o>>2]|0)+D|0]=F&255;F=(e[m>>1]|0)>>>8&255;D=c[n>>2]|0;c[n>>2]=D+1;a[(c[o>>2]|0)+D|0]=F;F=c[k>>2]|0;D=G>>>((16-F|0)>>>0)&65535;b[m>>1]=D;T=i-16+F|0;U=D}else{T=i+P|0;U=K}c[k>>2]=T;K=O+65533&65535;i=K<<T|U&65535;b[m>>1]=i&65535;if((T|0)>14){D=c[n>>2]|0;c[n>>2]=D+1;a[(c[o>>2]|0)+D|0]=i&255;i=(e[m>>1]|0)>>>8&255;D=c[n>>2]|0;c[n>>2]=D+1;a[(c[o>>2]|0)+D|0]=i;i=c[k>>2]|0;b[m>>1]=K>>>((16-i|0)>>>0)&65535;c[k>>2]=i-14;break}else{c[k>>2]=T+2;break}}if((B|0)<11){i=e[j>>1]|0;K=c[k>>2]|0;D=e[l>>1]|0;F=e[m>>1]|0|D<<K;G=F&65535;b[m>>1]=G;if((K|0)>(16-i|0)){E=c[n>>2]|0;c[n>>2]=E+1;a[(c[o>>2]|0)+E|0]=F&255;F=(e[m>>1]|0)>>>8&255;E=c[n>>2]|0;c[n>>2]=E+1;a[(c[o>>2]|0)+E|0]=F;F=c[k>>2]|0;E=D>>>((16-F|0)>>>0)&65535;b[m>>1]=E;V=i-16+F|0;W=E}else{V=K+i|0;W=G}c[k>>2]=V;G=x+65534&65535;i=G<<V|W&65535;b[m>>1]=i&65535;if((V|0)>13){K=c[n>>2]|0;c[n>>2]=K+1;a[(c[o>>2]|0)+K|0]=i&255;i=(e[m>>1]|0)>>>8&255;K=c[n>>2]|0;c[n>>2]=K+1;a[(c[o>>2]|0)+K|0]=i;i=c[k>>2]|0;b[m>>1]=G>>>((16-i|0)>>>0)&65535;c[k>>2]=i-13;break}else{c[k>>2]=V+3;break}}else{i=e[p>>1]|0;G=c[k>>2]|0;K=e[q>>1]|0;E=e[m>>1]|0|K<<G;F=E&65535;b[m>>1]=F;if((G|0)>(16-i|0)){D=c[n>>2]|0;c[n>>2]=D+1;a[(c[o>>2]|0)+D|0]=E&255;E=(e[m>>1]|0)>>>8&255;D=c[n>>2]|0;c[n>>2]=D+1;a[(c[o>>2]|0)+D|0]=E;E=c[k>>2]|0;D=K>>>((16-E|0)>>>0)&65535;b[m>>1]=D;X=i-16+E|0;Y=D}else{X=G+i|0;Y=F}c[k>>2]=X;F=x+65526&65535;i=F<<X|Y&65535;b[m>>1]=i&65535;if((X|0)>9){G=c[n>>2]|0;c[n>>2]=G+1;a[(c[o>>2]|0)+G|0]=i&255;i=(e[m>>1]|0)>>>8&255;G=c[n>>2]|0;c[n>>2]=G+1;a[(c[o>>2]|0)+G|0]=i;i=c[k>>2]|0;b[m>>1]=F>>>((16-i|0)>>>0)&65535;c[k>>2]=i-9;break}else{c[k>>2]=X+7;break}}}}while(0);if(z<<16>>16==0){t=y;u=v;v=A;h=138;w=3;continue}t=y;u=v;v=A;h=C?6:7;w=C?3:4}return}function RR(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=b[c+2>>1]|0;g=f<<16>>16==0;b[c+(d+1<<2)+2>>1]=-1;h=a+2752|0;i=a+2756|0;j=a+2748|0;k=g?3:4;l=g?138:7;g=f&65535;f=0;m=-1;L50862:while(1){n=0;o=f;do{if((o|0)>(d|0)){break L50862}o=o+1|0;p=b[c+(o<<2)+2>>1]|0;q=p&65535;n=n+1|0;r=(g|0)==(q|0);}while((n|0)<(l|0)&r);do{if((n|0)<(k|0)){s=a+2684+(g<<2)|0;b[s>>1]=(e[s>>1]|0)+n&65535}else{if((g|0)==0){if((n|0)<11){b[h>>1]=(b[h>>1]|0)+1&65535;break}else{b[i>>1]=(b[i>>1]|0)+1&65535;break}}else{if((g|0)!=(m|0)){s=a+2684+(g<<2)|0;b[s>>1]=(b[s>>1]|0)+1&65535}b[j>>1]=(b[j>>1]|0)+1&65535;break}}}while(0);if(p<<16>>16==0){k=3;l=138;m=g;g=q;f=o;continue}k=r?3:4;l=r?6:7;m=g;g=q;f=o}return}function RS(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0,cf=0,cg=0,ch=0,ci=0,cj=0,ck=0,cl=0,cm=0,cn=0,co=0,cp=0,cq=0,cr=0,cs=0,ct=0,cu=0,cv=0,cw=0,cx=0,cy=0,cz=0,cA=0,cB=0,cC=0,cD=0,cE=0,cF=0,cG=0,cH=0,cI=0,cJ=0,cK=0,cL=0,cM=0,cN=0,cO=0,cP=0,cQ=0,cR=0,cS=0,cT=0,cU=0,cV=0,cW=0,cX=0,cY=0,cZ=0,c_=0,c$=0,c0=0,c1=0,c2=0,c3=0,c4=0,c5=0,c6=0,c7=0,c8=0,da=0,db=0,dc=0,dd=0,de=0,df=0,dg=0,dh=0,di=0,dj=0,dk=0,dl=0,dm=0,dn=0,dp=0,dq=0,dr=0,ds=0,dt=0,du=0,dv=0,dw=0,dx=0,dy=0,dz=0,dA=0,dB=0,dC=0,dD=0,dE=0,dF=0,dG=0,dH=0,dI=0,dJ=0,dK=0,dL=0,dM=0,dN=0,dO=0,dP=0,dQ=0,dR=0,dS=0,dT=0,dU=0,dV=0,dW=0,dX=0,dY=0,dZ=0,d_=0,d$=0,d0=0,d1=0,d2=0,d3=0,d4=0,d5=0,d6=0,d7=0,d8=0,d9=0,ea=0,eb=0,ec=0,ed=0,ee=0,ef=0,eg=0,eh=0,ei=0,ej=0,ek=0,el=0,em=0,en=0,eo=0,ep=0,eq=0,er=0,es=0,et=0,eu=0,ev=0,ew=0,ex=0,ey=0,ez=0,eA=0,eB=0,eC=0,eD=0,eE=0,eF=0,eG=0,eH=0,eI=0,eJ=0,eK=0,eL=0,eM=0,eN=0,eO=0,eP=0,eQ=0,eR=0,eS=0,eT=0,eU=0,eV=0,eW=0,eX=0,eY=0,eZ=0,e_=0,e$=0,e0=0,e1=0,e2=0,e3=0,e4=0,e5=0,e6=0,e7=0,e8=0,e9=0,fa=0,fb=0,fc=0,fd=0,fe=0,ff=0,fg=0,fh=0,fi=0,fj=0,fk=0,fl=0,fm=0,fn=0,fo=0,fp=0,fq=0,fr=0,fs=0,ft=0,fu=0,fv=0,fw=0,fx=0,fy=0,fz=0,fA=0,fB=0,fC=0,fD=0,fE=0,fF=0,fG=0,fH=0,fI=0,fJ=0,fK=0,fL=0,fM=0,fN=0,fO=0,fP=0,fQ=0,fR=0,fS=0,fT=0,fU=0,fV=0,fW=0,fX=0,fY=0,fZ=0,f_=0,f$=0,f0=0,f1=0,f2=0,f3=0,f4=0,f5=0,f6=0,f7=0,f8=0,f9=0,ga=0,gb=0,gc=0,gd=0,ge=0,gf=0,gg=0,gh=0,gi=0,gj=0,gk=0,gl=0,gm=0,gn=0,go=0,gq=0,gr=0,gs=0,gt=0,gu=0,gv=0,gw=0,gx=0,gy=0,gz=0,gA=0,gB=0,gC=0,gD=0,gE=0,gF=0,gG=0,gH=0,gI=0,gJ=0,gK=0,gL=0,gM=0,gN=0,gO=0,gP=0,gQ=0,gR=0,gS=0,gT=0,gU=0,gV=0,gW=0,gX=0,gY=0,gZ=0;h=i;i=i+8|0;j=h|0;if((f|0)==0){k=-2;i=h;return k|0}l=f+28|0;m=c[l>>2]|0;if((m|0)==0){k=-2;i=h;return k|0}n=f+12|0;o=c[n>>2]|0;if((o|0)==0){k=-2;i=h;return k|0}p=f|0;q=c[p>>2]|0;do{if((q|0)==0){if((c[f+4>>2]|0)==0){break}else{k=-2}i=h;return k|0}}while(0);r=m;s=m|0;t=c[s>>2]|0;if((t|0)==11){c[s>>2]=12;u=c[n>>2]|0;v=c[p>>2]|0;w=12}else{u=o;v=q;w=t}t=f+16|0;q=c[t>>2]|0;o=f+4|0;x=c[o>>2]|0;y=m+56|0;z=m+60|0;A=m+8|0;B=m+24|0;C=j|0;D=j+1|0;E=m+16|0;F=m+32|0;G=f+24|0;H=m+36|0;I=m+20|0;J=f+48|0;K=m+64|0;L=m+12|0;M=(g-5|0)>>>0<2;N=m+4|0;O=m+76|0;P=O;Q=m+84|0;R=m+80|0;S=R;T=m+88|0;U=(g|0)==6;V=m+7108|0;W=m+72|0;X=m+7112|0;Y=m+68|0;Z=m+44|0;_=m+7104|0;$=m+48|0;aa=m+52|0;ab=m+40|0;ac=f+20|0;ad=m+28|0;ae=m+96|0;af=m+100|0;ag=m+92|0;ah=m+104|0;ai=m+108|0;aj=ai;ak=m+112|0;al=m+752|0;am=m+624|0;an=j+2|0;ao=j+3|0;j=O|0;O=R|0;R=ai|0;ai=m+1328|0;m=0;ap=q;aq=c[z>>2]|0;ar=c[y>>2]|0;as=q;q=x;at=u;u=v;v=w;L50900:while(1){L50902:do{switch(v|0){case 8:{au=aq;av=ar;aw=q;ax=u;ay=39958;break};case 17:{w=c[ah>>2]|0;if(w>>>0<(c[ag>>2]|0)>>>0){az=u;aA=q;aB=ar;aC=aq;aD=w;ay=40003}else{aE=u;aF=q;aG=ar;aH=aq;aI=w;ay=40007}break};case 21:{aJ=m;aK=aq;aL=ar;aM=q;aN=u;aO=c[W>>2]|0;ay=40128;break};case 23:{aP=m;aQ=aq;aR=ar;aS=q;aT=u;aU=c[W>>2]|0;ay=40147;break};case 18:{aV=m;aW=aq;aX=ar;aY=q;aZ=u;a_=c[ah>>2]|0;ay=40012;break};case 1:{if(aq>>>0<16){w=u;a$=q;a0=ar;a1=aq;while(1){if((a$|0)==0){a2=m;a3=ap;a4=a1;a5=a0;a6=0;a7=w;a8=as;break L50900}a9=a$-1|0;ba=w+1|0;bb=(d[w]<<a1)+a0|0;bc=a1+8|0;if(bc>>>0<16){w=ba;a$=a9;a0=bb;a1=bc}else{bd=ba;be=a9;bf=bb;bg=bc;break}}}else{bd=u;be=q;bf=ar;bg=aq}c[E>>2]=bf;if((bf&255|0)!=8){c[G>>2]=432664;c[s>>2]=29;bh=m;bi=ap;bj=bg;bk=bf;bl=as;bm=be;bn=at;bo=bd;break L50902}if((bf&57344|0)!=0){c[G>>2]=257640;c[s>>2]=29;bh=m;bi=ap;bj=bg;bk=bf;bl=as;bm=be;bn=at;bo=bd;break L50902}a1=c[F>>2]|0;if((a1|0)==0){bp=bf}else{c[a1>>2]=bf>>>8&1;bp=c[E>>2]|0}if((bp&512|0)!=0){a[C]=bf&255;a[D]=bf>>>8&255;c[B>>2]=RK(c[B>>2]|0,C,2)|0}c[s>>2]=2;bq=bd;br=be;bs=0;bt=0;ay=39896;break};case 6:{bu=aq;bv=ar;bw=q;bx=u;by=c[E>>2]|0;ay=39932;break};case 0:{a1=c[A>>2]|0;if((a1|0)==0){c[s>>2]=12;bh=m;bi=ap;bj=aq;bk=ar;bl=as;bm=q;bn=at;bo=u;break L50902}if(aq>>>0<16){a0=u;a$=q;w=ar;bc=aq;while(1){if((a$|0)==0){a2=m;a3=ap;a4=bc;a5=w;a6=0;a7=a0;a8=as;break L50900}bb=a$-1|0;a9=a0+1|0;ba=(d[a0]<<bc)+w|0;bz=bc+8|0;if(bz>>>0<16){a0=a9;a$=bb;w=ba;bc=bz}else{bA=a9;bB=bb;bC=ba;bD=bz;break}}}else{bA=u;bB=q;bC=ar;bD=aq}if((a1&2|0)!=0&(bC|0)==35615){c[B>>2]=0;a[C]=31;a[D]=-117;c[B>>2]=RK(c[B>>2]|0,C,2)|0;c[s>>2]=1;bh=m;bi=ap;bj=0;bk=0;bl=as;bm=bB;bn=at;bo=bA;break L50902}c[E>>2]=0;bc=c[F>>2]|0;if((bc|0)==0){bE=a1}else{c[bc+48>>2]=-1;bE=c[A>>2]|0}do{if((bE&1|0)!=0){if(((((bC<<8&65280)+(bC>>>8)|0)>>>0)%31|0|0)!=0){break}if((bC&15|0)!=8){c[G>>2]=432664;c[s>>2]=29;bh=m;bi=ap;bj=bD;bk=bC;bl=as;bm=bB;bn=at;bo=bA;break L50902}bc=bC>>>4;w=bD-4|0;a$=(bc&15)+8|0;a0=c[H>>2]|0;do{if((a0|0)==0){c[H>>2]=a$}else{if(a$>>>0<=a0>>>0){break}c[G>>2]=335264;c[s>>2]=29;bh=m;bi=ap;bj=w;bk=bc;bl=as;bm=bB;bn=at;bo=bA;break L50902}}while(0);c[I>>2]=1<<a$;c[B>>2]=1;c[J>>2]=1;c[s>>2]=bC>>>12&2^11;bh=m;bi=ap;bj=0;bk=0;bl=as;bm=bB;bn=at;bo=bA;break L50902}}while(0);c[G>>2]=558552;c[s>>2]=29;bh=m;bi=ap;bj=bD;bk=bC;bl=as;bm=bB;bn=at;bo=bA;break};case 5:{bF=aq;bG=ar;bH=q;bI=u;ay=39922;break};case 9:{if(aq>>>0<32){a1=u;bc=q;w=ar;a0=aq;while(1){if((bc|0)==0){a2=m;a3=ap;a4=a0;a5=w;a6=0;a7=a1;a8=as;break L50900}bz=bc-1|0;ba=a1+1|0;bb=(d[a1]<<a0)+w|0;a9=a0+8|0;if(a9>>>0<32){a1=ba;bc=bz;w=bb;a0=a9}else{bJ=ba;bK=bz;bL=bb;break}}}else{bJ=u;bK=q;bL=ar}a0=c9(bL|0)|0;c[B>>2]=a0;c[J>>2]=a0;c[s>>2]=10;bM=0;bN=0;bO=bK;bP=bJ;ay=39970;break};case 16:{if(aq>>>0<14){a0=u;w=q;bc=ar;a1=aq;while(1){if((w|0)==0){a2=m;a3=ap;a4=a1;a5=bc;a6=0;a7=a0;a8=as;break L50900}bb=w-1|0;bz=a0+1|0;ba=(d[a0]<<a1)+bc|0;a9=a1+8|0;if(a9>>>0<14){a0=bz;w=bb;bc=ba;a1=a9}else{bQ=bz;bR=bb;bS=ba;bT=a9;break}}}else{bQ=u;bR=q;bS=ar;bT=aq}a1=(bS&31)+257|0;c[ae>>2]=a1;bc=(bS>>>5&31)+1|0;c[af>>2]=bc;c[ag>>2]=(bS>>>10&15)+4;w=bS>>>14;a0=bT-14|0;if(a1>>>0>286|bc>>>0>30){c[G>>2]=103152;c[s>>2]=29;bh=m;bi=ap;bj=a0;bk=w;bl=as;bm=bR;bn=at;bo=bQ;break L50902}else{c[ah>>2]=0;c[s>>2]=17;az=bQ;aA=bR;aB=w;aC=a0;aD=0;ay=40003;break L50902}break};case 14:{bU=aq;bV=ar;bW=q;bX=u;ay=39992;break};case 15:{bY=aq;bZ=ar;b_=q;b$=u;ay=39993;break};case 2:{if(aq>>>0<32){bq=u;br=q;bs=ar;bt=aq;ay=39896}else{b0=u;b1=q;b2=ar;ay=39898}break};case 7:{b3=aq;b4=ar;b5=q;b6=u;ay=39945;break};case 19:{b7=m;b8=aq;b9=ar;ca=q;cb=u;ay=40046;break};case 20:{cc=m;cd=aq;ce=ar;cf=q;cg=u;ay=40047;break};case 10:{bM=aq;bN=ar;bO=q;bP=u;ay=39970;break};case 11:{ch=aq;ci=ar;cj=q;ck=u;ay=39973;break};case 12:{cl=aq;cm=ar;cn=q;co=u;ay=39974;break};case 4:{cp=aq;cq=ar;cr=q;cs=u;ay=39911;break};case 13:{a0=aq&7;w=ar>>>(a0>>>0);bc=aq-a0|0;if(bc>>>0<32){a0=u;a1=q;a9=w;ba=bc;while(1){if((a1|0)==0){a2=m;a3=ap;a4=ba;a5=a9;a6=0;a7=a0;a8=as;break L50900}bb=a1-1|0;bz=a0+1|0;ct=(d[a0]<<ba)+a9|0;cu=ba+8|0;if(cu>>>0<32){a0=bz;a1=bb;a9=ct;ba=cu}else{cv=bz;cw=bb;cx=ct;cy=cu;break}}}else{cv=u;cw=q;cx=w;cy=bc}ba=cx&65535;if((ba|0)==(cx>>>16^65535|0)){c[K>>2]=ba;c[s>>2]=14;if(U){cz=m;cA=0;cB=0;cC=cw;cD=cv;cE=as;ay=40192;break L50900}else{bU=0;bV=0;bW=cw;bX=cv;ay=39992;break L50902}}else{c[G>>2]=128048;c[s>>2]=29;bh=m;bi=ap;bj=cy;bk=cx;bl=as;bm=cw;bn=at;bo=cv;break L50902}break};case 3:{if(aq>>>0<16){cF=u;cG=q;cH=ar;cI=aq;ay=39904}else{cJ=u;cK=q;cL=ar;ay=39906}break};case 22:{cM=m;cN=aq;cO=ar;cP=q;cQ=u;ay=40135;break};case 24:{cR=m;cS=aq;cT=ar;cU=q;cV=u;ay=40153;break};case 25:{if((as|0)==0){cz=m;cA=aq;cB=ar;cC=q;cD=u;cE=0;ay=40192;break L50900}a[at]=c[K>>2]&255;c[s>>2]=20;bh=m;bi=ap;bj=aq;bk=ar;bl=as-1|0;bm=q;bn=at+1|0;bo=u;break};case 26:{do{if((c[A>>2]|0)==0){cW=ap;cX=aq;cY=ar;cZ=q;c_=u}else{if(aq>>>0<32){ba=u;a9=q;a1=ar;a0=aq;while(1){if((a9|0)==0){a2=m;a3=ap;a4=a0;a5=a1;a6=0;a7=ba;a8=as;break L50900}cu=a9-1|0;ct=ba+1|0;bb=(d[ba]<<a0)+a1|0;bz=a0+8|0;if(bz>>>0<32){ba=ct;a9=cu;a1=bb;a0=bz}else{c$=ct;c0=cu;c1=bb;c2=bz;break}}}else{c$=u;c0=q;c1=ar;c2=aq}a0=ap-as|0;c[ac>>2]=(c[ac>>2]|0)+a0;c[ad>>2]=(c[ad>>2]|0)+a0;if((ap|0)!=(as|0)){a1=c[B>>2]|0;a9=at+(-a0|0)|0;if((c[E>>2]|0)==0){c3=RT(a1,a9,a0)|0}else{c3=RK(a1,a9,a0)|0}c[B>>2]=c3;c[J>>2]=c3}if((c[E>>2]|0)==0){c4=c9(c1|0)|0}else{c4=c1}if((c4|0)==(c[B>>2]|0)){cW=as;cX=0;cY=0;cZ=c0;c_=c$;break}c[G>>2]=487600;c[s>>2]=29;bh=m;bi=as;bj=c2;bk=c1;bl=as;bm=c0;bn=at;bo=c$;break L50902}}while(0);c[s>>2]=27;c5=cW;c6=cX;c7=cY;c8=cZ;da=c_;ay=40184;break};case 27:{c5=ap;c6=aq;c7=ar;c8=q;da=u;ay=40184;break};case 28:{cz=1;cA=aq;cB=ar;cC=q;cD=u;cE=as;ay=40192;break L50900;break};case 29:{a2=-3;a3=ap;a4=aq;a5=ar;a6=q;a7=u;a8=as;break L50900;break};case 30:{ay=40219;break L50900;break};default:{k=-2;ay=40223;break L50900}}}while(0);if((ay|0)==40003){while(1){ay=0;if(aC>>>0<3){bc=az;w=aA;a0=aB;a9=aC;while(1){if((w|0)==0){a2=m;a3=ap;a4=a9;a5=a0;a6=0;a7=bc;a8=as;break L50900}a1=w-1|0;ba=bc+1|0;a$=(d[bc]<<a9)+a0|0;bz=a9+8|0;if(bz>>>0<3){bc=ba;w=a1;a0=a$;a9=bz}else{db=ba;dc=a1;dd=a$;de=bz;break}}}else{db=az;dc=aA;dd=aB;de=aC}c[ah>>2]=aD+1;b[r+112+(e[48112+(aD<<1)>>1]<<1)>>1]=dd&7;a9=dd>>>3;a0=de-3|0;w=c[ah>>2]|0;if(w>>>0<(c[ag>>2]|0)>>>0){az=db;aA=dc;aB=a9;aC=a0;aD=w;ay=40003}else{aE=db;aF=dc;aG=a9;aH=a0;aI=w;ay=40007;break}}}else if((ay|0)==39992){ay=0;c[s>>2]=15;bY=bU;bZ=bV;b_=bW;b$=bX;ay=39993}else if((ay|0)==39896){while(1){ay=0;if((br|0)==0){a2=m;a3=ap;a4=bt;a5=bs;a6=0;a7=bq;a8=as;break L50900}w=br-1|0;a0=bq+1|0;a9=(d[bq]<<bt)+bs|0;bc=bt+8|0;if(bc>>>0<32){bq=a0;br=w;bs=a9;bt=bc;ay=39896}else{b0=a0;b1=w;b2=a9;ay=39898;break}}}else if((ay|0)==39970){ay=0;if((c[L>>2]|0)==0){ay=39971;break}c[B>>2]=1;c[J>>2]=1;c[s>>2]=11;ch=bM;ci=bN;cj=bO;ck=bP;ay=39973}else if((ay|0)==40184){ay=0;if((c[A>>2]|0)==0){df=c6;dg=c7;dh=c8;di=da;ay=40191;break}if((c[E>>2]|0)==0){df=c6;dg=c7;dh=c8;di=da;ay=40191;break}if(c6>>>0<32){a9=da;w=c8;a0=c7;bc=c6;while(1){if((w|0)==0){a2=m;a3=c5;a4=bc;a5=a0;a6=0;a7=a9;a8=as;break L50900}bz=w-1|0;a$=a9+1|0;a1=(d[a9]<<bc)+a0|0;ba=bc+8|0;if(ba>>>0<32){a9=a$;w=bz;a0=a1;bc=ba}else{dj=a$;dk=bz;dl=a1;dm=ba;break}}}else{dj=da;dk=c8;dl=c7;dm=c6}if((dl|0)==(c[ad>>2]|0)){df=0;dg=0;dh=dk;di=dj;ay=40191;break}c[G>>2]=474696;c[s>>2]=29;bh=m;bi=c5;bj=dm;bk=dl;bl=as;bm=dk;bn=at;bo=dj}do{if((ay|0)==39898){ay=0;bc=c[F>>2]|0;if((bc|0)!=0){c[bc+4>>2]=b2}if((c[E>>2]&512|0)!=0){a[C]=b2&255;a[D]=b2>>>8&255;a[an]=b2>>>16&255;a[ao]=b2>>>24&255;c[B>>2]=RK(c[B>>2]|0,C,4)|0}c[s>>2]=3;cF=b0;cG=b1;cH=0;cI=0;ay=39904}else if((ay|0)==40007){ay=0;if(aI>>>0<19){bc=aI;do{c[ah>>2]=bc+1;b[r+112+(e[48112+(bc<<1)>>1]<<1)>>1]=0;bc=c[ah>>2]|0;}while(bc>>>0<19)}c[R>>2]=ai;c[j>>2]=ai;c[Q>>2]=7;bc=RJ(0,ak,19,aj,Q,al)|0;if((bc|0)==0){c[ah>>2]=0;c[s>>2]=18;aV=0;aW=aH;aX=aG;aY=aF;aZ=aE;a_=0;ay=40012;break}else{c[G>>2]=79824;c[s>>2]=29;bh=bc;bi=ap;bj=aH;bk=aG;bl=as;bm=aF;bn=at;bo=aE;break}}else if((ay|0)==39993){ay=0;bc=c[K>>2]|0;if((bc|0)==0){c[s>>2]=11;bh=m;bi=ap;bj=bY;bk=bZ;bl=as;bm=b_;bn=at;bo=b$;break}a0=bc>>>0>b_>>>0?b_:bc;bc=a0>>>0>as>>>0?as:a0;if((bc|0)==0){cz=m;cA=bY;cB=bZ;cC=b_;cD=b$;cE=as;ay=40192;break L50900}gGC(at|0,b$|0,bc)|0;c[K>>2]=(c[K>>2]|0)-bc;bh=m;bi=ap;bj=bY;bk=bZ;bl=as-bc|0;bm=b_-bc|0;bn=at+bc|0;bo=b$+bc|0}else if((ay|0)==39973){ay=0;if(M){cz=m;cA=ch;cB=ci;cC=cj;cD=ck;cE=as;ay=40192;break L50900}else{cl=ch;cm=ci;cn=cj;co=ck;ay=39974}}}while(0);L51046:do{if((ay|0)==40012){ay=0;bc=c[ae>>2]|0;a0=c[af>>2]|0;do{if(a_>>>0<(a0+bc|0)>>>0){w=aZ;a9=aY;ba=aX;a1=aW;bz=a_;a$=bc;bb=a0;L51049:while(1){cu=(1<<c[Q>>2])-1|0;ct=cu&ba;dn=c[P>>2]|0;dp=d[dn+(ct<<2)+1|0]|0;if(dp>>>0>a1>>>0){dq=w;dr=a9;ds=ba;dt=a1;while(1){if((dr|0)==0){a2=aV;a3=ap;a4=dt;a5=ds;a6=0;a7=dq;a8=as;break L50900}du=dr-1|0;dv=dq+1|0;dw=(d[dq]<<dt)+ds|0;dx=dt+8|0;dy=dw&cu;dz=d[dn+(dy<<2)+1|0]|0;if(dz>>>0>dx>>>0){dq=dv;dr=du;ds=dw;dt=dx}else{dA=dv;dB=du;dC=dw;dD=dx;dE=dy;dF=dz;break}}}else{dA=w;dB=a9;dC=ba;dD=a1;dE=ct;dF=dp}dt=b[dn+(dE<<2)+2>>1]|0;do{if((dt&65535)<16){c[ah>>2]=bz+1;b[r+112+(bz<<1)>>1]=dt;dG=dD-dF|0;dH=dC>>>(dF>>>0);dI=dB;dJ=dA}else{if((dt<<16>>16|0)==16){ds=dF+2|0;if(dD>>>0<ds>>>0){dr=dA;dq=dB;cu=dC;dz=dD;while(1){if((dq|0)==0){a2=aV;a3=ap;a4=dz;a5=cu;a6=0;a7=dr;a8=as;break L50900}dy=dq-1|0;dx=dr+1|0;dw=(d[dr]<<dz)+cu|0;du=dz+8|0;if(du>>>0<ds>>>0){dr=dx;dq=dy;cu=dw;dz=du}else{dK=dx;dL=dy;dM=dw;dN=du;break}}}else{dK=dA;dL=dB;dM=dC;dN=dD}dO=dM>>>(dF>>>0);dP=dN-dF|0;if((bz|0)==0){ay=40026;break L51049}dQ=b[r+112+(bz-1<<1)>>1]|0;dR=(dO&3)+3|0;dS=dP-2|0;dT=dO>>>2;dU=dL;dV=dK}else if((dt<<16>>16|0)==17){dz=dF+3|0;if(dD>>>0<dz>>>0){cu=dA;dq=dB;dr=dC;ds=dD;while(1){if((dq|0)==0){a2=aV;a3=ap;a4=ds;a5=dr;a6=0;a7=cu;a8=as;break L50900}du=dq-1|0;dw=cu+1|0;dy=(d[cu]<<ds)+dr|0;dx=ds+8|0;if(dx>>>0<dz>>>0){cu=dw;dq=du;dr=dy;ds=dx}else{dW=dw;dX=du;dY=dy;dZ=dx;break}}}else{dW=dA;dX=dB;dY=dC;dZ=dD}ds=dY>>>(dF>>>0);dQ=0;dR=(ds&7)+3|0;dS=-3-dF+dZ|0;dT=ds>>>3;dU=dX;dV=dW}else{ds=dF+7|0;if(dD>>>0<ds>>>0){dr=dA;dq=dB;cu=dC;dz=dD;while(1){if((dq|0)==0){a2=aV;a3=ap;a4=dz;a5=cu;a6=0;a7=dr;a8=as;break L50900}dx=dq-1|0;dy=dr+1|0;du=(d[dr]<<dz)+cu|0;dw=dz+8|0;if(dw>>>0<ds>>>0){dr=dy;dq=dx;cu=du;dz=dw}else{d_=dy;d$=dx;d0=du;d1=dw;break}}}else{d_=dA;d$=dB;d0=dC;d1=dD}dz=d0>>>(dF>>>0);dQ=0;dR=(dz&127)+11|0;dS=-7-dF+d1|0;dT=dz>>>7;dU=d$;dV=d_}if((dR+bz|0)>>>0>(a$+bb|0)>>>0){ay=40036;break L51049}dz=dR-1|0;c[ah>>2]=bz+1;b[r+112+(bz<<1)>>1]=dQ;if((dz|0)==0){dG=dS;dH=dT;dI=dU;dJ=dV;break}else{d2=dz}while(1){dz=c[ah>>2]|0;cu=d2-1|0;c[ah>>2]=dz+1;b[r+112+(dz<<1)>>1]=dQ;if((cu|0)==0){dG=dS;dH=dT;dI=dU;dJ=dV;break}else{d2=cu}}}}while(0);dt=c[ah>>2]|0;d3=c[ae>>2]|0;dn=c[af>>2]|0;if(dt>>>0<(dn+d3|0)>>>0){w=dJ;a9=dI;ba=dH;a1=dG;bz=dt;a$=d3;bb=dn}else{ay=40038;break}}if((ay|0)==40026){ay=0;c[G>>2]=586432;c[s>>2]=29;bh=aV;bi=ap;bj=dP;bk=dO;bl=as;bm=dL;bn=at;bo=dK;break L51046}else if((ay|0)==40036){ay=0;c[G>>2]=586432;c[s>>2]=29;bh=aV;bi=ap;bj=dS;bk=dT;bl=as;bm=dU;bn=at;bo=dV;break L51046}else if((ay|0)==40038){ay=0;if((c[s>>2]|0)==29){bh=aV;bi=ap;bj=dG;bk=dH;bl=as;bm=dI;bn=at;bo=dJ;break L51046}else{d4=d3;d5=dG;d6=dH;d7=dI;d8=dJ;break}}}else{d4=bc;d5=aW;d6=aX;d7=aY;d8=aZ}}while(0);if((b[am>>1]|0)==0){c[G>>2]=569752;c[s>>2]=29;bh=aV;bi=ap;bj=d5;bk=d6;bl=as;bm=d7;bn=at;bo=d8;break}c[R>>2]=ai;c[j>>2]=ai;c[Q>>2]=9;bc=RJ(1,ak,d4,aj,Q,al)|0;if((bc|0)!=0){c[G>>2]=553704;c[s>>2]=29;bh=bc;bi=ap;bj=d5;bk=d6;bl=as;bm=d7;bn=at;bo=d8;break}c[O>>2]=c[aj>>2];c[T>>2]=6;bc=RJ(2,r+112+(c[ae>>2]<<1)|0,c[af>>2]|0,aj,T,al)|0;if((bc|0)==0){c[s>>2]=19;if(U){cz=0;cA=d5;cB=d6;cC=d7;cD=d8;cE=as;ay=40192;break L50900}else{b7=0;b8=d5;b9=d6;ca=d7;cb=d8;ay=40046;break}}else{c[G>>2]=538968;c[s>>2]=29;bh=bc;bi=ap;bj=d5;bk=d6;bl=as;bm=d7;bn=at;bo=d8;break}}else if((ay|0)==39974){ay=0;if((c[N>>2]|0)!=0){bc=cl&7;c[s>>2]=26;bh=m;bi=ap;bj=cl-bc|0;bk=cm>>>(bc>>>0);bl=as;bm=cn;bn=at;bo=co;break}if(cl>>>0<3){bc=co;a0=cn;bb=cm;a$=cl;while(1){if((a0|0)==0){a2=m;a3=ap;a4=a$;a5=bb;a6=0;a7=bc;a8=as;break L50900}bz=a0-1|0;a1=bc+1|0;ba=(d[bc]<<a$)+bb|0;a9=a$+8|0;if(a9>>>0<3){bc=a1;a0=bz;bb=ba;a$=a9}else{d9=a1;ea=bz;eb=ba;ec=a9;break}}}else{d9=co;ea=cn;eb=cm;ec=cl}c[N>>2]=eb&1;a$=eb>>>1&3;if((a$|0)==0){c[s>>2]=13}else if((a$|0)==1){c[j>>2]=49280;c[Q>>2]=9;c[O>>2]=51328;c[T>>2]=5;c[s>>2]=19;if(U){ay=39982;break L50900}}else if((a$|0)==2){c[s>>2]=16}else if((a$|0)==3){c[G>>2]=158376;c[s>>2]=29}bh=m;bi=ap;bj=ec-3|0;bk=eb>>>3;bl=as;bm=ea;bn=at;bo=d9}else if((ay|0)==39904){while(1){ay=0;if((cG|0)==0){a2=m;a3=ap;a4=cI;a5=cH;a6=0;a7=cF;a8=as;break L50900}a$=cG-1|0;bb=cF+1|0;a0=(d[cF]<<cI)+cH|0;bc=cI+8|0;if(bc>>>0<16){cF=bb;cG=a$;cH=a0;cI=bc;ay=39904}else{cJ=bb;cK=a$;cL=a0;ay=39906;break}}}}while(0);if((ay|0)==39906){ay=0;a0=c[F>>2]|0;if((a0|0)!=0){c[a0+8>>2]=cL&255;c[(c[F>>2]|0)+12>>2]=cL>>>8}if((c[E>>2]&512|0)!=0){a[C]=cL&255;a[D]=cL>>>8&255;c[B>>2]=RK(c[B>>2]|0,C,2)|0}c[s>>2]=4;cp=0;cq=0;cr=cK;cs=cJ;ay=39911}else if((ay|0)==40046){ay=0;c[s>>2]=20;cc=b7;cd=b8;ce=b9;cf=ca;cg=cb;ay=40047}do{if((ay|0)==40047){ay=0;if(!(cf>>>0>5&as>>>0>257)){c[V>>2]=0;a0=(1<<c[Q>>2])-1|0;a$=a0&ce;bb=c[P>>2]|0;bc=a[bb+(a$<<2)+1|0]|0;a9=bc&255;if(a9>>>0>cd>>>0){ba=cg;bz=cf;a1=ce;w=cd;while(1){if((bz|0)==0){a2=cc;a3=ap;a4=w;a5=a1;a6=0;a7=ba;a8=as;break L50900}dn=bz-1|0;dt=ba+1|0;dp=(d[ba]<<w)+a1|0;ct=w+8|0;cu=dp&a0;dz=a[bb+(cu<<2)+1|0]|0;dq=dz&255;if(dq>>>0>ct>>>0){ba=dt;bz=dn;a1=dp;w=ct}else{ed=dt;ee=dn;ef=dp;eg=ct;eh=dz;ei=cu;ej=dq;break}}}else{ed=cg;ee=cf;ef=ce;eg=cd;eh=bc;ei=a$;ej=a9}w=a[bb+(ei<<2)|0]|0;a1=b[bb+(ei<<2)+2>>1]|0;bz=w&255;do{if(w<<24>>24==0){ek=0;el=eh;em=a1;en=eg;eo=ef;ep=ee;eq=ed;er=0}else{if((bz&240|0)!=0){ek=w;el=eh;em=a1;en=eg;eo=ef;ep=ee;eq=ed;er=0;break}ba=a1&65535;a0=(1<<bz+ej)-1|0;dq=((a0&ef)>>>(ej>>>0))+ba|0;cu=a[bb+(dq<<2)+1|0]|0;if(((cu&255)+ej|0)>>>0>eg>>>0){dz=ed;ct=ee;dp=ef;dn=eg;while(1){if((ct|0)==0){a2=cc;a3=ap;a4=dn;a5=dp;a6=0;a7=dz;a8=as;break L50900}dt=ct-1|0;dr=dz+1|0;ds=(d[dz]<<dn)+dp|0;dw=dn+8|0;du=((ds&a0)>>>(ej>>>0))+ba|0;dx=a[bb+(du<<2)+1|0]|0;if(((dx&255)+ej|0)>>>0>dw>>>0){dz=dr;ct=dt;dp=ds;dn=dw}else{es=dr;et=dt;eu=ds;ev=dw;ew=du;ex=dx;break}}}else{es=ed;et=ee;eu=ef;ev=eg;ew=dq;ex=cu}dn=b[bb+(ew<<2)+2>>1]|0;dp=a[bb+(ew<<2)|0]|0;c[V>>2]=ej;ek=dp;el=ex;em=dn;en=ev-ej|0;eo=eu>>>(ej>>>0);ep=et;eq=es;er=ej}}while(0);bb=el&255;bz=eo>>>(bb>>>0);a1=en-bb|0;c[V>>2]=bb+er;c[K>>2]=em&65535;bb=ek&255;if(ek<<24>>24==0){c[s>>2]=25;bh=cc;bi=ap;bj=a1;bk=bz;bl=as;bm=ep;bn=at;bo=eq;break}if((bb&32|0)!=0){c[V>>2]=-1;c[s>>2]=11;bh=cc;bi=ap;bj=a1;bk=bz;bl=as;bm=ep;bn=at;bo=eq;break}if((bb&64|0)==0){w=bb&15;c[W>>2]=w;c[s>>2]=21;aJ=cc;aK=a1;aL=bz;aM=ep;aN=eq;aO=w;ay=40128;break}else{c[G>>2]=428512;c[s>>2]=29;bh=cc;bi=ap;bj=a1;bk=bz;bl=as;bm=ep;bn=at;bo=eq;break}}c[n>>2]=at;c[t>>2]=as;c[p>>2]=cg;c[o>>2]=cf;c[y>>2]=ce;c[z>>2]=cd;bz=c[l>>2]|0;a1=c[p>>2]|0;w=a1+((c[o>>2]|0)-6)|0;bb=c[n>>2]|0;a9=c[t>>2]|0;a$=bb+(a9-258)|0;bc=c[bz+44>>2]|0;dn=c[bz+48>>2]|0;dp=c[bz+52>>2]|0;ct=bz+56|0;dz=bz+60|0;ba=c[bz+76>>2]|0;a0=c[bz+80>>2]|0;dx=(1<<c[bz+84>>2])-1|0;du=(1<<c[bz+88>>2])-1|0;dw=bb+(a9+~ap)|0;a9=bz+7104|0;ds=dp-1|0;dt=(dn|0)==0;dr=(c[bz+40>>2]|0)-1|0;dy=dn+dr|0;dv=dn-1|0;ey=dw-dn|0;ez=a1-1|0;a1=bb-1|0;bb=c[ct>>2]|0;eA=c[dz>>2]|0;L51153:while(1){if(eA>>>0<15){eB=ez+2|0;eC=eB;eD=(d[ez+1|0]<<eA)+bb+(d[eB]<<eA+8)|0;eE=eA+16|0}else{eC=ez;eD=bb;eE=eA}eB=eD&dx;eF=a[ba+(eB<<2)|0]|0;eG=b[ba+(eB<<2)+2>>1]|0;eH=d[ba+(eB<<2)+1|0]|0;eB=eD>>>(eH>>>0);eI=eE-eH|0;do{if(eF<<24>>24==0){eJ=eG&255;eK=eB;eL=eI;ay=40053}else{eH=eG;eM=eB;eN=eI;eO=eF;while(1){eP=eO&255;if((eP&16|0)!=0){break}if((eP&64|0)!=0){ay=40100;break L51153}eQ=((1<<eP)-1&eM)+(eH&65535)|0;eR=a[ba+(eQ<<2)|0]|0;eS=b[ba+(eQ<<2)+2>>1]|0;eT=d[ba+(eQ<<2)+1|0]|0;eU=eM>>>(eT>>>0);eV=eN-eT|0;if(eR<<24>>24==0){ay=40052;break}else{eH=eS;eM=eU;eN=eV;eO=eR}}if((ay|0)==40052){ay=0;eJ=eS&255;eK=eU;eL=eV;ay=40053;break}eO=eH&65535;eR=eP&15;if((eR|0)==0){eW=eO;eX=eC;eY=eM;eZ=eN}else{if(eN>>>0<eR>>>0){eT=eC+1|0;e_=eT;e$=(d[eT]<<eN)+eM|0;e0=eN+8|0}else{e_=eC;e$=eM;e0=eN}eW=(e$&(1<<eR)-1)+eO|0;eX=e_;eY=e$>>>(eR>>>0);eZ=e0-eR|0}if(eZ>>>0<15){eR=eX+2|0;e1=eR;e2=(d[eX+1|0]<<eZ)+eY+(d[eR]<<eZ+8)|0;e3=eZ+16|0}else{e1=eX;e2=eY;e3=eZ}eR=e2&du;eO=b[a0+(eR<<2)+2>>1]|0;eT=d[a0+(eR<<2)+1|0]|0;eQ=e2>>>(eT>>>0);e4=e3-eT|0;eT=d[a0+(eR<<2)|0]|0;if((eT&16|0)==0){eR=eO;e5=eQ;e6=e4;e7=eT;while(1){if((e7&64|0)!=0){ay=40097;break L51153}e8=(eR&65535)+(e5&(1<<e7)-1)|0;e9=b[a0+(e8<<2)+2>>1]|0;fa=d[a0+(e8<<2)+1|0]|0;fb=e5>>>(fa>>>0);fc=e6-fa|0;fa=d[a0+(e8<<2)|0]|0;if((fa&16|0)==0){eR=e9;e5=fb;e6=fc;e7=fa}else{fd=e9;fe=fb;ff=fc;fg=fa;break}}}else{fd=eO;fe=eQ;ff=e4;fg=eT}e7=fd&65535;eR=fg&15;do{if(ff>>>0<eR>>>0){eH=e1+1|0;fa=(d[eH]<<ff)+fe|0;fc=ff+8|0;if(fc>>>0>=eR>>>0){fh=eH;fi=fa;fj=fc;break}eH=e1+2|0;fh=eH;fi=(d[eH]<<fc)+fa|0;fj=ff+16|0}else{fh=e1;fi=fe;fj=ff}}while(0);eT=(fi&(1<<eR)-1)+e7|0;fk=fi>>>(eR>>>0);fl=fj-eR|0;e4=a1;eQ=e4-dw|0;if(eT>>>0<=eQ>>>0){eO=a1+(-eT|0)|0;fa=eW;fc=a1;while(1){a[fc+1|0]=a[eO+1|0]|0;a[fc+2|0]=a[eO+2|0]|0;eH=eO+3|0;fm=fc+3|0;a[fm]=a[eH]|0;fn=fa-3|0;if(fn>>>0>2){eO=eH;fa=fn;fc=fm}else{break}}if((fn|0)==0){fo=fh;fp=fm;fq=fk;fr=fl;break}fa=fc+4|0;a[fa]=a[eO+4|0]|0;if(fn>>>0<=1){fo=fh;fp=fa;fq=fk;fr=fl;break}fa=fc+5|0;a[fa]=a[eO+5|0]|0;fo=fh;fp=fa;fq=fk;fr=fl;break}fa=eT-eQ|0;if(fa>>>0>bc>>>0){if((c[a9>>2]|0)!=0){ay=40068;break L51153}}do{if(dt){eR=dp+(dr-fa)|0;if(fa>>>0>=eW>>>0){fs=eR;ft=eW;fu=a1;break}e7=eW-fa|0;eH=eR;eR=fa;fb=a1;do{eH=eH+1|0;fb=fb+1|0;a[fb]=a[eH]|0;eR=eR-1|0;}while((eR|0)!=0);eR=eT-e4|0;fs=a1+(dw-eT+eR)|0;ft=e7;fu=a1+(eR+dw)|0}else{if(dn>>>0>=fa>>>0){eR=dp+(dv-fa)|0;if(fa>>>0>=eW>>>0){fs=eR;ft=eW;fu=a1;break}eH=eW-fa|0;fb=eR;eR=fa;e9=a1;do{fb=fb+1|0;e9=e9+1|0;a[e9]=a[fb]|0;eR=eR-1|0;}while((eR|0)!=0);eR=eT-e4|0;fs=a1+(dw-eT+eR)|0;ft=eH;fu=a1+(eR+dw)|0;break}eR=dp+(dy-fa)|0;fb=fa-dn|0;if(fb>>>0>=eW>>>0){fs=eR;ft=eW;fu=a1;break}e9=eW-fb|0;e7=eR;eR=fb;fb=a1;do{e7=e7+1|0;fb=fb+1|0;a[fb]=a[e7]|0;eR=eR-1|0;}while((eR|0)!=0);eR=eT-e4|0;e7=a1+(ey+eR)|0;if(dn>>>0<e9>>>0){fv=ds;fw=dn;fx=e7}else{fs=ds;ft=e9;fu=e7;break}do{fv=fv+1|0;fx=fx+1|0;a[fx]=a[fv]|0;fw=fw-1|0;}while((fw|0)!=0);fs=a1+(dw-eT+eR)|0;ft=e9-dn|0;fu=a1+(eR+dw)|0}}while(0);if(ft>>>0>2){eT=fu;e4=ft;fa=fs;while(1){a[eT+1|0]=a[fa+1|0]|0;a[eT+2|0]=a[fa+2|0]|0;eQ=fa+3|0;eO=eT+3|0;a[eO]=a[eQ]|0;fc=e4-3|0;if(fc>>>0>2){eT=eO;e4=fc;fa=eQ}else{fy=eO;fz=fc;fA=eQ;break}}}else{fy=fu;fz=ft;fA=fs}if((fz|0)==0){fo=fh;fp=fy;fq=fk;fr=fl;break}fa=fy+1|0;a[fa]=a[fA+1|0]|0;if(fz>>>0<=1){fo=fh;fp=fa;fq=fk;fr=fl;break}fa=fy+2|0;a[fa]=a[fA+2|0]|0;fo=fh;fp=fa;fq=fk;fr=fl}}while(0);if((ay|0)==40053){ay=0;eF=a1+1|0;a[eF]=eJ;fo=eC;fp=eF;fq=eK;fr=eL}if(fo>>>0<w>>>0&fp>>>0<a$>>>0){ez=fo;a1=fp;bb=fq;eA=fr}else{fB=fo;fC=fp;fD=fq;fE=fr;break}}do{if((ay|0)==40097){ay=0;c[G>>2]=552136;c[bz>>2]=29;fB=e1;fC=a1;fD=e5;fE=e6}else if((ay|0)==40100){ay=0;if((eP&32|0)==0){c[G>>2]=428512;c[bz>>2]=29;fB=eC;fC=a1;fD=eM;fE=eN;break}else{c[bz>>2]=11;fB=eC;fC=a1;fD=eM;fE=eN;break}}else if((ay|0)==40068){ay=0;c[G>>2]=422592;c[bz>>2]=29;fB=fh;fC=a1;fD=fk;fE=fl}}while(0);a1=fE>>>3;bz=fB+(-a1|0)|0;eA=fE-(a1<<3)|0;c[p>>2]=fB+(1-a1);c[n>>2]=fC+1;if(bz>>>0<w>>>0){fF=w-bz|0}else{fF=w-bz|0}c[o>>2]=fF+5;if(fC>>>0<a$>>>0){fG=a$-fC|0}else{fG=a$-fC|0}c[t>>2]=fG+257;c[ct>>2]=(1<<eA)-1&fD;c[dz>>2]=eA;eA=c[n>>2]|0;bz=c[t>>2]|0;a1=c[p>>2]|0;bb=c[o>>2]|0;ez=c[y>>2]|0;dw=c[z>>2]|0;if((c[s>>2]|0)!=11){bh=cc;bi=ap;bj=dw;bk=ez;bl=bz;bm=bb;bn=eA;bo=a1;break}c[V>>2]=-1;bh=cc;bi=ap;bj=dw;bk=ez;bl=bz;bm=bb;bn=eA;bo=a1}else if((ay|0)==39911){ay=0;a1=c[E>>2]|0;do{if((a1&1024|0)==0){eA=c[F>>2]|0;if((eA|0)==0){fH=cp;fI=cq;fJ=cr;fK=cs;break}c[eA+16>>2]=0;fH=cp;fI=cq;fJ=cr;fK=cs}else{if(cp>>>0<16){eA=cs;bb=cr;bz=cq;ez=cp;while(1){if((bb|0)==0){a2=m;a3=ap;a4=ez;a5=bz;a6=0;a7=eA;a8=as;break L50900}dw=bb-1|0;dn=eA+1|0;ds=(d[eA]<<ez)+bz|0;ey=ez+8|0;if(ey>>>0<16){eA=dn;bb=dw;bz=ds;ez=ey}else{fL=dn;fM=dw;fN=ds;break}}}else{fL=cs;fM=cr;fN=cq}c[K>>2]=fN;ez=c[F>>2]|0;if((ez|0)==0){fO=a1}else{c[ez+20>>2]=fN;fO=c[E>>2]|0}if((fO&512|0)==0){fH=0;fI=0;fJ=fM;fK=fL;break}a[C]=fN&255;a[D]=fN>>>8&255;c[B>>2]=RK(c[B>>2]|0,C,2)|0;fH=0;fI=0;fJ=fM;fK=fL}}while(0);c[s>>2]=5;bF=fH;bG=fI;bH=fJ;bI=fK;ay=39922}}while(0);if((ay|0)==40128){ay=0;if((aO|0)==0){fP=aK;fQ=aL;fR=aM;fS=aN;fT=c[K>>2]|0}else{if(aK>>>0<aO>>>0){a1=aN;dz=aM;ct=aL;a$=aK;while(1){if((dz|0)==0){a2=aJ;a3=ap;a4=a$;a5=ct;a6=0;a7=a1;a8=as;break L50900}w=dz-1|0;ez=a1+1|0;bz=(d[a1]<<a$)+ct|0;bb=a$+8|0;if(bb>>>0<aO>>>0){a1=ez;dz=w;ct=bz;a$=bb}else{fU=ez;fV=w;fW=bz;fX=bb;break}}}else{fU=aN;fV=aM;fW=aL;fX=aK}a$=(c[K>>2]|0)+(fW&(1<<aO)-1)|0;c[K>>2]=a$;c[V>>2]=(c[V>>2]|0)+aO;fP=fX-aO|0;fQ=fW>>>(aO>>>0);fR=fV;fS=fU;fT=a$}c[X>>2]=fT;c[s>>2]=22;cM=aJ;cN=fP;cO=fQ;cP=fR;cQ=fS;ay=40135}else if((ay|0)==39922){ay=0;a$=c[E>>2]|0;if((a$&1024|0)==0){fY=bH;fZ=bI;f_=a$}else{ct=c[K>>2]|0;dz=ct>>>0>bH>>>0?bH:ct;if((dz|0)==0){f$=bH;f0=bI;f1=ct;f2=a$}else{a1=c[F>>2]|0;do{if((a1|0)==0){f3=a$}else{bb=c[a1+16>>2]|0;if((bb|0)==0){f3=a$;break}bz=(c[a1+20>>2]|0)-ct|0;w=bb+bz|0;bb=c[a1+24>>2]|0;ez=(bz+dz|0)>>>0>bb>>>0?bb-bz|0:dz;gGC(w|0,bI|0,ez)|0;f3=c[E>>2]|0}}while(0);if((f3&512|0)!=0){c[B>>2]=RK(c[B>>2]|0,bI,dz)|0}a1=(c[K>>2]|0)-dz|0;c[K>>2]=a1;f$=bH-dz|0;f0=bI+dz|0;f1=a1;f2=f3}if((f1|0)==0){fY=f$;fZ=f0;f_=f2}else{cz=m;cA=bF;cB=bG;cC=f$;cD=f0;cE=as;ay=40192;break}}c[K>>2]=0;c[s>>2]=6;bu=bF;bv=bG;bw=fY;bx=fZ;by=f_;ay=39932}do{if((ay|0)==39932){ay=0;do{if((by&2048|0)==0){a1=c[F>>2]|0;if((a1|0)==0){f4=bw;f5=bx;break}c[a1+28>>2]=0;f4=bw;f5=bx}else{if((bw|0)==0){cz=m;cA=bu;cB=bv;cC=0;cD=bx;cE=as;ay=40192;break L50900}else{f6=0}while(1){f7=f6+1|0;a1=a[bx+f6|0]|0;ct=c[F>>2]|0;do{if((ct|0)!=0){a$=ct+28|0;if((c[a$>>2]|0)==0){break}ez=c[K>>2]|0;if(ez>>>0>=(c[ct+32>>2]|0)>>>0){break}c[K>>2]=ez+1;a[(c[a$>>2]|0)+ez|0]=a1}}while(0);f8=a1<<24>>24!=0;if(f8&f7>>>0<bw>>>0){f6=f7}else{break}}if((c[E>>2]&512|0)!=0){c[B>>2]=RK(c[B>>2]|0,bx,f7)|0}ct=bw-f7|0;ez=bx+f7|0;if(f8){cz=m;cA=bu;cB=bv;cC=ct;cD=ez;cE=as;ay=40192;break L50900}else{f4=ct;f5=ez}}}while(0);c[K>>2]=0;c[s>>2]=7;b3=bu;b4=bv;b5=f4;b6=f5;ay=39945}else if((ay|0)==40135){ay=0;ez=(1<<c[T>>2])-1|0;ct=ez&cO;a$=c[S>>2]|0;w=a[a$+(ct<<2)+1|0]|0;bz=w&255;if(bz>>>0>cN>>>0){bb=cQ;eA=cP;ds=cO;dw=cN;while(1){if((eA|0)==0){a2=cM;a3=ap;a4=dw;a5=ds;a6=0;a7=bb;a8=as;break L50900}dn=eA-1|0;ey=bb+1|0;dy=(d[bb]<<dw)+ds|0;dp=dw+8|0;dv=dy&ez;dr=a[a$+(dv<<2)+1|0]|0;dt=dr&255;if(dt>>>0>dp>>>0){bb=ey;eA=dn;ds=dy;dw=dp}else{f9=ey;ga=dn;gb=dy;gc=dp;gd=dr;ge=dv;gf=dt;break}}}else{f9=cQ;ga=cP;gb=cO;gc=cN;gd=w;ge=ct;gf=bz}dw=a[a$+(ge<<2)|0]|0;ds=b[a$+(ge<<2)+2>>1]|0;eA=dw&255;if((eA&240|0)==0){bb=ds&65535;ez=(1<<eA+gf)-1|0;eA=((ez&gb)>>>(gf>>>0))+bb|0;dt=a[a$+(eA<<2)+1|0]|0;if(((dt&255)+gf|0)>>>0>gc>>>0){dv=f9;dr=ga;dp=gb;dy=gc;while(1){if((dr|0)==0){a2=cM;a3=ap;a4=dy;a5=dp;a6=0;a7=dv;a8=as;break L50900}dn=dr-1|0;ey=dv+1|0;a9=(d[dv]<<dy)+dp|0;bc=dy+8|0;a0=((a9&ez)>>>(gf>>>0))+bb|0;du=a[a$+(a0<<2)+1|0]|0;if(((du&255)+gf|0)>>>0>bc>>>0){dv=ey;dr=dn;dp=a9;dy=bc}else{gg=ey;gh=dn;gi=a9;gj=bc;gk=a0;gl=du;break}}}else{gg=f9;gh=ga;gi=gb;gj=gc;gk=eA;gl=dt}dy=b[a$+(gk<<2)+2>>1]|0;dp=a[a$+(gk<<2)|0]|0;dr=(c[V>>2]|0)+gf|0;c[V>>2]=dr;gm=dp;gn=gl;go=dy;gq=gj-gf|0;gr=gi>>>(gf>>>0);gs=gh;gt=gg;gu=dr}else{gm=dw;gn=gd;go=ds;gq=gc;gr=gb;gs=ga;gt=f9;gu=c[V>>2]|0}dr=gn&255;dy=gr>>>(dr>>>0);dp=gq-dr|0;c[V>>2]=dr+gu;dr=gm&255;if((dr&64|0)==0){c[Y>>2]=go&65535;dv=dr&15;c[W>>2]=dv;c[s>>2]=23;aP=cM;aQ=dp;aR=dy;aS=gs;aT=gt;aU=dv;ay=40147;break}else{c[G>>2]=552136;c[s>>2]=29;bh=cM;bi=ap;bj=dp;bk=dy;bl=as;bm=gs;bn=at;bo=gt;break}}}while(0);if((ay|0)==39945){ay=0;do{if((c[E>>2]&4096|0)==0){dz=c[F>>2]|0;if((dz|0)==0){gv=b5;gw=b6;break}c[dz+36>>2]=0;gv=b5;gw=b6}else{if((b5|0)==0){cz=m;cA=b3;cB=b4;cC=0;cD=b6;cE=as;ay=40192;break L50900}else{gx=0}while(1){gy=gx+1|0;dz=a[b6+gx|0]|0;dy=c[F>>2]|0;do{if((dy|0)!=0){dp=dy+36|0;if((c[dp>>2]|0)==0){break}dv=c[K>>2]|0;if(dv>>>0>=(c[dy+40>>2]|0)>>>0){break}c[K>>2]=dv+1;a[(c[dp>>2]|0)+dv|0]=dz}}while(0);gz=dz<<24>>24!=0;if(gz&gy>>>0<b5>>>0){gx=gy}else{break}}if((c[E>>2]&512|0)!=0){c[B>>2]=RK(c[B>>2]|0,b6,gy)|0}ds=b5-gy|0;dw=b6+gy|0;if(gz){cz=m;cA=b3;cB=b4;cC=ds;cD=dw;cE=as;ay=40192;break L50900}else{gv=ds;gw=dw}}}while(0);c[s>>2]=8;au=b3;av=b4;aw=gv;ax=gw;ay=39958}else if((ay|0)==40147){ay=0;if((aU|0)==0){gA=aQ;gB=aR;gC=aS;gD=aT}else{if(aQ>>>0<aU>>>0){dw=aT;ds=aS;a$=aR;dt=aQ;while(1){if((ds|0)==0){a2=aP;a3=ap;a4=dt;a5=a$;a6=0;a7=dw;a8=as;break L50900}eA=ds-1|0;dy=dw+1|0;dv=(d[dw]<<dt)+a$|0;dp=dt+8|0;if(dp>>>0<aU>>>0){dw=dy;ds=eA;a$=dv;dt=dp}else{gE=dy;gF=eA;gG=dv;gH=dp;break}}}else{gE=aT;gF=aS;gG=aR;gH=aQ}c[Y>>2]=(c[Y>>2]|0)+(gG&(1<<aU)-1);c[V>>2]=(c[V>>2]|0)+aU;gA=gH-aU|0;gB=gG>>>(aU>>>0);gC=gF;gD=gE}c[s>>2]=24;cR=aP;cS=gA;cT=gB;cU=gC;cV=gD;ay=40153}L51346:do{if((ay|0)==39958){ay=0;dt=c[E>>2]|0;do{if((dt&512|0)==0){gI=au;gJ=av;gK=aw;gL=ax}else{if(au>>>0<16){a$=ax;ds=aw;dw=av;dp=au;while(1){if((ds|0)==0){a2=m;a3=ap;a4=dp;a5=dw;a6=0;a7=a$;a8=as;break L50900}dv=ds-1|0;eA=a$+1|0;dy=(d[a$]<<dp)+dw|0;dr=dp+8|0;if(dr>>>0<16){a$=eA;ds=dv;dw=dy;dp=dr}else{gM=eA;gN=dv;gO=dy;gP=dr;break}}}else{gM=ax;gN=aw;gO=av;gP=au}if((gO|0)==(c[B>>2]&65535|0)){gI=0;gJ=0;gK=gN;gL=gM;break}c[G>>2]=200792;c[s>>2]=29;bh=m;bi=ap;bj=gP;bk=gO;bl=as;bm=gN;bn=at;bo=gM;break L51346}}while(0);dp=c[F>>2]|0;if((dp|0)!=0){c[dp+44>>2]=dt>>>9&1;c[(c[F>>2]|0)+48>>2]=1}c[B>>2]=0;c[J>>2]=0;c[s>>2]=11;bh=m;bi=ap;bj=gI;bk=gJ;bl=as;bm=gK;bn=at;bo=gL}else if((ay|0)==40153){ay=0;if((as|0)==0){cz=cR;cA=cS;cB=cT;cC=cU;cD=cV;cE=0;ay=40192;break L50900}dp=ap-as|0;dw=c[Y>>2]|0;if(dw>>>0>dp>>>0){ds=dw-dp|0;do{if(ds>>>0>(c[Z>>2]|0)>>>0){if((c[_>>2]|0)==0){break}c[G>>2]=422592;c[s>>2]=29;bh=cR;bi=ap;bj=cS;bk=cT;bl=as;bm=cU;bn=at;bo=cV;break L51346}}while(0);dt=c[$>>2]|0;if(ds>>>0>dt>>>0){dp=ds-dt|0;gQ=(c[aa>>2]|0)+((c[ab>>2]|0)-dp)|0;gR=dp}else{gQ=(c[aa>>2]|0)+(dt-ds)|0;gR=ds}dt=c[K>>2]|0;gS=gQ;gT=gR>>>0>dt>>>0?dt:gR;gU=dt}else{dt=c[K>>2]|0;gS=at+(-dw|0)|0;gT=dt;gU=dt}dt=gT>>>0>as>>>0?as:gT;c[K>>2]=gU-dt;dp=~as;a$=~gT;dz=dp>>>0>a$>>>0;dr=gS;dy=dt;dv=at;while(1){a[dv]=a[dr]|0;eA=dy-1|0;if((eA|0)==0){break}else{dr=dr+1|0;dy=eA;dv=dv+1|0}}dv=as-dt|0;dy=at+~(dz?dp:a$)|0;if((c[K>>2]|0)!=0){bh=cR;bi=ap;bj=cS;bk=cT;bl=dv;bm=cU;bn=dy;bo=cV;break}c[s>>2]=20;bh=cR;bi=ap;bj=cS;bk=cT;bl=dv;bm=cU;bn=dy;bo=cV}}while(0);m=bh;ap=bi;aq=bj;ar=bk;as=bl;q=bm;at=bn;u=bo;v=c[s>>2]|0}if((ay|0)==39971){c[n>>2]=at;c[t>>2]=as;c[p>>2]=bP;c[o>>2]=bO;c[y>>2]=bN;c[z>>2]=bM;k=2;i=h;return k|0}else if((ay|0)==39982){a2=m;a3=ap;a4=ec-3|0;a5=eb>>>3;a6=ea;a7=d9;a8=as}else if((ay|0)==40191){c[s>>2]=28;a2=1;a3=c5;a4=df;a5=dg;a6=dh;a7=di;a8=as}else if((ay|0)==40192){a2=cz;a3=ap;a4=cA;a5=cB;a6=cC;a7=cD;a8=cE}else if((ay|0)==40219){k=-4;i=h;return k|0}else if((ay|0)==40223){i=h;return k|0}c[n>>2]=at;c[t>>2]=a8;c[p>>2]=a7;c[o>>2]=a6;c[y>>2]=a5;c[z>>2]=a4;a4=c[t>>2]|0;do{if((c[ab>>2]|0)==0){if((a3|0)==(a4|0)){gV=a3;break}a5=c[s>>2]|0;if(a5>>>0>=29){gV=a4;break}if(a5>>>0>25&(g|0)==4){gV=a4}else{ay=40197}}else{ay=40197}}while(0);if((ay|0)==40197){ay=c[n>>2]|0;ab=a3-a4|0;a4=c[l>>2]|0;l=a4+52|0;a5=l;y=c[a5>>2]|0;do{if((y|0)==0){a6=gp[c[f+32>>2]&16383](c[f+40>>2]|0,1<<c[a4+36>>2],1)|0;c[l>>2]=a6;if((a6|0)!=0){gW=a6;break}c[s>>2]=30;k=-4;i=h;return k|0}else{gW=y}}while(0);y=a4+40|0;l=c[y>>2]|0;if((l|0)==0){a6=1<<c[a4+36>>2];c[y>>2]=a6;c[a4+48>>2]=0;c[a4+44>>2]=0;gX=a6}else{gX=l}do{if(gX>>>0>ab>>>0){l=a4+48|0;a6=c[l>>2]|0;a7=gX-a6|0;p=a7>>>0>ab>>>0?ab:a7;a7=gW+a6|0;a6=ay+(-ab|0)|0;gGC(a7|0,a6|0,p)|0;a6=ab-p|0;if((p|0)!=(ab|0)){p=c[a5>>2]|0;a7=ay+(-a6|0)|0;gGC(p|0,a7|0,a6)|0;c[l>>2]=a6;c[a4+44>>2]=c[y>>2];break}a6=(c[l>>2]|0)+ab|0;c[l>>2]=a6;a7=c[y>>2]|0;if((a6|0)==(a7|0)){c[l>>2]=0}l=a4+44|0;a6=c[l>>2]|0;if(a6>>>0>=a7>>>0){break}c[l>>2]=a6+ab}else{a6=ay+(-gX|0)|0;gGC(gW|0,a6|0,gX)|0;c[a4+48>>2]=0;c[a4+44>>2]=c[y>>2]}}while(0);gV=c[t>>2]|0}t=c[o>>2]|0;o=a3-gV|0;y=f+8|0;c[y>>2]=x-t+(c[y>>2]|0);c[ac>>2]=(c[ac>>2]|0)+o;c[ad>>2]=(c[ad>>2]|0)+o;ad=(a3|0)==(gV|0);if(!((c[A>>2]|0)==0|ad)){A=c[B>>2]|0;gV=(c[n>>2]|0)+(-o|0)|0;if((c[E>>2]|0)==0){gY=RT(A,gV,o)|0}else{gY=RK(A,gV,o)|0}c[B>>2]=gY;c[J>>2]=gY}gY=c[s>>2]|0;if((gY|0)==19){gZ=256}else{gZ=(gY|0)==14?256:0}c[f+44>>2]=((c[N>>2]|0)!=0?64:0)+(c[z>>2]|0)+((gY|0)==11?128:0)+gZ;k=((x|0)==(t|0)&ad|(g|0)==4)&(a2|0)==0?-5:a2;i=h;return k|0}function RT(a,b,c){a=a|0;b=b|0;c=c|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;e=a>>>16;f=a&65535;if((c|0)==1){a=(d[b]|0)+f|0;g=a>>>0>65520?a-65521|0:a;a=g+e|0;h=(a>>>0>65520?a+15|0:a)<<16|g;return h|0}if((b|0)==0){h=1;return h|0}if(c>>>0<16){if((c|0)==0){i=f;j=e}else{g=f;a=b;k=c;l=e;while(1){m=k-1|0;n=(d[a]|0)+g|0;o=n+l|0;if((m|0)==0){i=n;j=o;break}else{g=n;a=a+1|0;k=m;l=o}}}h=((j>>>0)%65521|0)<<16|(i>>>0>65520?i-65521|0:i);return h|0}do{if(c>>>0>5551){i=f;j=b;l=c;k=e;do{a=347;g=k;o=j;m=i;while(1){n=(d[o]|0)+m|0;p=n+(d[o+1|0]|0)|0;q=p+(d[o+2|0]|0)|0;r=q+(d[o+3|0]|0)|0;s=r+(d[o+4|0]|0)|0;t=s+(d[o+5|0]|0)|0;u=t+(d[o+6|0]|0)|0;v=u+(d[o+7|0]|0)|0;w=v+(d[o+8|0]|0)|0;x=w+(d[o+9|0]|0)|0;y=x+(d[o+10|0]|0)|0;z=y+(d[o+11|0]|0)|0;A=z+(d[o+12|0]|0)|0;B=A+(d[o+13|0]|0)|0;C=B+(d[o+14|0]|0)|0;D=C+(d[o+15|0]|0)|0;E=n+g+p+q+r+s+t+u+v+w+x+y+z+A+B+C+D|0;C=a-1|0;if((C|0)==0){break}else{a=C;g=E;o=o+16|0;m=D}}l=l-5552|0;j=j+5552|0;i=(D>>>0)%65521|0;k=(E>>>0)%65521|0;}while(l>>>0>5551);if((l|0)==0){F=k;G=i;break}if(l>>>0>15){H=i;I=j;J=l;K=k;L=40244}else{M=i;N=j;O=l;P=k;L=40245}}else{H=f;I=b;J=c;K=e;L=40244}}while(0);if((L|0)==40244){while(1){L=0;Q=J-16|0;e=(d[I]|0)+H|0;c=e+(d[I+1|0]|0)|0;b=c+(d[I+2|0]|0)|0;f=b+(d[I+3|0]|0)|0;E=f+(d[I+4|0]|0)|0;D=E+(d[I+5|0]|0)|0;m=D+(d[I+6|0]|0)|0;o=m+(d[I+7|0]|0)|0;g=o+(d[I+8|0]|0)|0;a=g+(d[I+9|0]|0)|0;C=a+(d[I+10|0]|0)|0;B=C+(d[I+11|0]|0)|0;A=B+(d[I+12|0]|0)|0;z=A+(d[I+13|0]|0)|0;y=z+(d[I+14|0]|0)|0;R=y+(d[I+15|0]|0)|0;S=e+K+c+b+f+E+D+m+o+g+a+C+B+A+z+y+R|0;T=I+16|0;if(Q>>>0>15){H=R;I=T;J=Q;K=S;L=40244}else{break}}if((Q|0)==0){U=R;V=S;L=40246}else{M=R;N=T;O=Q;P=S;L=40245}}if((L|0)==40245){while(1){L=0;S=O-1|0;Q=(d[N]|0)+M|0;T=Q+P|0;if((S|0)==0){U=Q;V=T;L=40246;break}else{M=Q;N=N+1|0;O=S;P=T;L=40245}}}if((L|0)==40246){F=(V>>>0)%65521|0;G=(U>>>0)%65521|0}h=F<<16|G;return h|0}function RU(a,b,c){a=a|0;b=b|0;c=c|0;return gGq(ag(c,b)|0)|0}function RV(a,b){a=a|0;b=b|0;gGr(b);return}function RW(a){a=a|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;f=a+44|0;g=c[f>>2]|0;h=a+60|0;i=a+116|0;j=a+108|0;k=g-262|0;l=a|0;m=a+56|0;n=a+5812|0;o=a+72|0;p=a+88|0;q=a+84|0;r=a+68|0;s=a+52|0;t=a+64|0;u=a+112|0;v=a+92|0;w=a+76|0;x=c[i>>2]|0;y=g;while(1){z=c[j>>2]|0;A=(c[h>>2]|0)-x-z|0;if(z>>>0<(k+y|0)>>>0){B=A}else{z=c[m>>2]|0;C=z+g|0;gGC(z|0,C|0,g)|0;c[u>>2]=(c[u>>2]|0)-g;c[j>>2]=(c[j>>2]|0)-g;c[v>>2]=(c[v>>2]|0)-g;C=c[w>>2]|0;z=C;D=(c[r>>2]|0)+(C<<1)|0;do{D=D-2|0;C=e[D>>1]|0;if(C>>>0<g>>>0){E=0}else{E=C-g&65535}b[D>>1]=E;z=z-1|0;}while((z|0)!=0);z=g;D=(c[t>>2]|0)+(g<<1)|0;do{D=D-2|0;C=e[D>>1]|0;if(C>>>0<g>>>0){F=0}else{F=C-g&65535}b[D>>1]=F;z=z-1|0;}while((z|0)!=0);B=A+g|0}z=c[l>>2]|0;D=z+4|0;C=c[D>>2]|0;if((C|0)==0){break}G=c[i>>2]|0;H=(c[m>>2]|0)+(G+(c[j>>2]|0))|0;I=C>>>0>B>>>0?B:C;if((I|0)==0){J=0;K=G}else{c[D>>2]=C-I;C=z|0;D=c[C>>2]|0;gGC(H|0,D|0,I)|0;D=c[(c[z+28>>2]|0)+24>>2]|0;if((D|0)==1){G=z+48|0;c[G>>2]=RT(c[G>>2]|0,H,I)|0}else if((D|0)==2){D=z+48|0;c[D>>2]=RK(c[D>>2]|0,H,I)|0}c[C>>2]=(c[C>>2]|0)+I;C=z+8|0;c[C>>2]=(c[C>>2]|0)+I;J=I;K=c[i>>2]|0}I=J+K|0;c[i>>2]=I;C=c[n>>2]|0;L51489:do{if((I+C|0)>>>0>2){z=(c[j>>2]|0)-C|0;H=c[m>>2]|0;D=d[H+z|0]|0;c[o>>2]=D;c[o>>2]=((d[H+(z+1)|0]|0)^D<<c[p>>2])&c[q>>2];D=z;z=C;H=I;while(1){if((z|0)==0){L=H;break L51489}G=((d[(c[m>>2]|0)+(D+2)|0]|0)^c[o>>2]<<c[p>>2])&c[q>>2];c[o>>2]=G;b[(c[t>>2]|0)+((c[s>>2]&D)<<1)>>1]=b[(c[r>>2]|0)+(G<<1)>>1]|0;b[(c[r>>2]|0)+(c[o>>2]<<1)>>1]=D&65535;G=(c[n>>2]|0)-1|0;c[n>>2]=G;M=c[i>>2]|0;if((M+G|0)>>>0<3){L=M;break}else{D=D+1|0;z=G;H=M}}}else{L=I}}while(0);if(L>>>0>=262){break}if((c[(c[l>>2]|0)+4>>2]|0)==0){break}x=L;y=c[f>>2]|0}f=a+5824|0;a=c[f>>2]|0;y=c[h>>2]|0;if(a>>>0>=y>>>0){return}h=(c[i>>2]|0)+(c[j>>2]|0)|0;if(a>>>0<h>>>0){j=y-h|0;i=j>>>0>258?258:j;gGz((c[m>>2]|0)+h|0,0,i|0);c[f>>2]=i+h;return}i=h+258|0;if(a>>>0>=i>>>0){return}h=i-a|0;i=y-a|0;y=h>>>0>i>>>0?i:h;gGz((c[m>>2]|0)+a|0,0,y|0);c[f>>2]=(c[f>>2]|0)+y;return}function RX(d,f){d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;g=(c[d+12>>2]|0)-5|0;h=g>>>0<65535?g:65535;g=d+116|0;i=d+108|0;j=d+92|0;k=d+44|0;l=d+56|0;m=d|0;n=d;while(1){o=c[g>>2]|0;if(o>>>0<2){RW(d);p=c[g>>2]|0;if((p|f|0)==0){q=0;r=40344;break}if((p|0)==0){r=40318;break}else{s=p}}else{s=o}o=(c[i>>2]|0)+s|0;c[i>>2]=o;c[g>>2]=0;p=c[j>>2]|0;t=p+h|0;if((o|0)!=0&o>>>0<t>>>0){u=o;v=p}else{c[g>>2]=o-t;c[i>>2]=t;if((p|0)>-1){w=(c[l>>2]|0)+p|0}else{w=0}RN(n,w,h,0);c[j>>2]=c[i>>2];p=c[m>>2]|0;t=c[p+28>>2]|0;o=t+5820|0;x=c[o>>2]|0;do{if((x|0)==16){y=t+5816|0;z=b[y>>1]&255;A=t+20|0;B=c[A>>2]|0;c[A>>2]=B+1;C=t+8|0;a[(c[C>>2]|0)+B|0]=z;z=(e[y>>1]|0)>>>8&255;B=c[A>>2]|0;c[A>>2]=B+1;a[(c[C>>2]|0)+B|0]=z;b[y>>1]=0;c[o>>2]=0;D=A}else{if((x|0)>7){A=t+5816|0;y=b[A>>1]&255;z=t+20|0;B=c[z>>2]|0;c[z>>2]=B+1;a[(c[t+8>>2]|0)+B|0]=y;b[A>>1]=(e[A>>1]|0)>>>8;c[o>>2]=(c[o>>2]|0)-8;D=z;break}else{D=t+20|0;break}}}while(0);o=c[D>>2]|0;x=p+16|0;z=c[x>>2]|0;A=o>>>0>z>>>0?z:o;do{if((A|0)!=0){o=p+12|0;z=c[o>>2]|0;y=t+16|0;B=c[y>>2]|0;gGC(z|0,B|0,A)|0;c[o>>2]=(c[o>>2]|0)+A;c[y>>2]=(c[y>>2]|0)+A;o=p+20|0;c[o>>2]=(c[o>>2]|0)+A;c[x>>2]=(c[x>>2]|0)-A;o=c[D>>2]|0;c[D>>2]=o-A;if((o|0)!=(A|0)){break}c[y>>2]=c[t+8>>2]}}while(0);if((c[(c[m>>2]|0)+16>>2]|0)==0){q=0;r=40345;break}u=c[i>>2]|0;v=c[j>>2]|0}t=u-v|0;if(t>>>0<((c[k>>2]|0)-262|0)>>>0){continue}if((v|0)>-1){E=(c[l>>2]|0)+v|0}else{E=0}RN(n,E,t,0);c[j>>2]=c[i>>2];t=c[m>>2]|0;A=c[t+28>>2]|0;x=A+5820|0;p=c[x>>2]|0;do{if((p|0)==16){y=A+5816|0;o=b[y>>1]&255;B=A+20|0;z=c[B>>2]|0;c[B>>2]=z+1;C=A+8|0;a[(c[C>>2]|0)+z|0]=o;o=(e[y>>1]|0)>>>8&255;z=c[B>>2]|0;c[B>>2]=z+1;a[(c[C>>2]|0)+z|0]=o;b[y>>1]=0;c[x>>2]=0;F=B}else{if((p|0)>7){B=A+5816|0;y=b[B>>1]&255;o=A+20|0;z=c[o>>2]|0;c[o>>2]=z+1;a[(c[A+8>>2]|0)+z|0]=y;b[B>>1]=(e[B>>1]|0)>>>8;c[x>>2]=(c[x>>2]|0)-8;F=o;break}else{F=A+20|0;break}}}while(0);x=c[F>>2]|0;p=t+16|0;o=c[p>>2]|0;B=x>>>0>o>>>0?o:x;do{if((B|0)!=0){x=t+12|0;o=c[x>>2]|0;y=A+16|0;z=c[y>>2]|0;gGC(o|0,z|0,B)|0;c[x>>2]=(c[x>>2]|0)+B;c[y>>2]=(c[y>>2]|0)+B;x=t+20|0;c[x>>2]=(c[x>>2]|0)+B;c[p>>2]=(c[p>>2]|0)-B;x=c[F>>2]|0;c[F>>2]=x-B;if((x|0)!=(B|0)){break}c[y>>2]=c[A+8>>2]}}while(0);if((c[(c[m>>2]|0)+16>>2]|0)==0){q=0;r=40346;break}}if((r|0)==40318){c[d+5812>>2]=0;if((f|0)==4){f=c[j>>2]|0;if((f|0)>-1){G=(c[l>>2]|0)+f|0}else{G=0}RN(n,G,(c[i>>2]|0)-f|0,1);c[j>>2]=c[i>>2];f=c[m>>2]|0;G=c[f+28>>2]|0;d=G+5820|0;F=c[d>>2]|0;do{if((F|0)==16){E=G+5816|0;v=b[E>>1]&255;k=G+20|0;u=c[k>>2]|0;c[k>>2]=u+1;D=G+8|0;a[(c[D>>2]|0)+u|0]=v;v=(e[E>>1]|0)>>>8&255;u=c[k>>2]|0;c[k>>2]=u+1;a[(c[D>>2]|0)+u|0]=v;b[E>>1]=0;c[d>>2]=0;H=k}else{if((F|0)>7){k=G+5816|0;E=b[k>>1]&255;v=G+20|0;u=c[v>>2]|0;c[v>>2]=u+1;a[(c[G+8>>2]|0)+u|0]=E;b[k>>1]=(e[k>>1]|0)>>>8;c[d>>2]=(c[d>>2]|0)-8;H=v;break}else{H=G+20|0;break}}}while(0);d=c[H>>2]|0;F=f+16|0;v=c[F>>2]|0;k=d>>>0>v>>>0?v:d;do{if((k|0)!=0){d=f+12|0;v=c[d>>2]|0;E=G+16|0;u=c[E>>2]|0;gGC(v|0,u|0,k)|0;c[d>>2]=(c[d>>2]|0)+k;c[E>>2]=(c[E>>2]|0)+k;d=f+20|0;c[d>>2]=(c[d>>2]|0)+k;c[F>>2]=(c[F>>2]|0)-k;d=c[H>>2]|0;c[H>>2]=d-k;if((d|0)!=(k|0)){break}c[E>>2]=c[G+8>>2]}}while(0);q=(c[(c[m>>2]|0)+16>>2]|0)==0?2:3;return q|0}G=c[i>>2]|0;k=c[j>>2]|0;do{if((G|0)>(k|0)){if((k|0)>-1){I=(c[l>>2]|0)+k|0}else{I=0}RN(n,I,G-k|0,0);c[j>>2]=c[i>>2];H=c[m>>2]|0;F=c[H+28>>2]|0;f=F+5820|0;E=c[f>>2]|0;do{if((E|0)==16){d=F+5816|0;u=b[d>>1]&255;v=F+20|0;D=c[v>>2]|0;c[v>>2]=D+1;h=F+8|0;a[(c[h>>2]|0)+D|0]=u;u=(e[d>>1]|0)>>>8&255;D=c[v>>2]|0;c[v>>2]=D+1;a[(c[h>>2]|0)+D|0]=u;b[d>>1]=0;c[f>>2]=0;J=v}else{if((E|0)>7){v=F+5816|0;d=b[v>>1]&255;u=F+20|0;D=c[u>>2]|0;c[u>>2]=D+1;a[(c[F+8>>2]|0)+D|0]=d;b[v>>1]=(e[v>>1]|0)>>>8;c[f>>2]=(c[f>>2]|0)-8;J=u;break}else{J=F+20|0;break}}}while(0);f=c[J>>2]|0;E=H+16|0;u=c[E>>2]|0;v=f>>>0>u>>>0?u:f;do{if((v|0)!=0){f=H+12|0;u=c[f>>2]|0;d=F+16|0;D=c[d>>2]|0;gGC(u|0,D|0,v)|0;c[f>>2]=(c[f>>2]|0)+v;c[d>>2]=(c[d>>2]|0)+v;f=H+20|0;c[f>>2]=(c[f>>2]|0)+v;c[E>>2]=(c[E>>2]|0)-v;f=c[J>>2]|0;c[J>>2]=f-v;if((f|0)!=(v|0)){break}c[d>>2]=c[F+8>>2]}}while(0);if((c[(c[m>>2]|0)+16>>2]|0)==0){q=0}else{break}return q|0}}while(0);q=1;return q|0}else if((r|0)==40344){return q|0}else if((r|0)==40345){return q|0}else if((r|0)==40346){return q|0}return 0}function RY(f,g){f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0;h=f+116|0;i=(g|0)==0;j=f+72|0;k=f+88|0;l=f+108|0;m=f+56|0;n=f+84|0;o=f+68|0;p=f+52|0;q=f+64|0;r=f+44|0;s=f+96|0;t=f+112|0;u=f+5792|0;v=f+5796|0;w=f+5784|0;x=f+5788|0;y=f+128|0;z=f+92|0;A=f|0;B=f;while(1){if((c[h>>2]|0)>>>0<262){RW(f);C=c[h>>2]|0;if(C>>>0<262&i){D=0;E=40407;break}if((C|0)==0){E=40380;break}if(C>>>0>2){E=40355}else{E=40358}}else{E=40355}do{if((E|0)==40355){E=0;C=c[l>>2]|0;F=((d[(c[m>>2]|0)+(C+2)|0]|0)^c[j>>2]<<c[k>>2])&c[n>>2];c[j>>2]=F;G=b[(c[o>>2]|0)+(F<<1)>>1]|0;b[(c[q>>2]|0)+((c[p>>2]&C)<<1)>>1]=G;C=G&65535;b[(c[o>>2]|0)+(c[j>>2]<<1)>>1]=c[l>>2]&65535;if(G<<16>>16==0){E=40358;break}if(((c[l>>2]|0)-C|0)>>>0>((c[r>>2]|0)-262|0)>>>0){E=40358;break}G=R_(f,C)|0;c[s>>2]=G;H=G}}while(0);if((E|0)==40358){E=0;H=c[s>>2]|0}do{if(H>>>0>2){G=H+253|0;C=(c[l>>2]|0)-(c[t>>2]|0)&65535;b[(c[v>>2]|0)+(c[u>>2]<<1)>>1]=C;F=c[u>>2]|0;c[u>>2]=F+1;a[(c[w>>2]|0)+F|0]=G&255;F=C-1&65535;C=f+148+((d[589976+(G&255)|0]|0|256)+1<<2)|0;b[C>>1]=(b[C>>1]|0)+1&65535;C=F&65535;if((F&65535)<256){I=C}else{I=(C>>>7)+256|0}C=f+2440+((d[590232+I|0]|0)<<2)|0;b[C>>1]=(b[C>>1]|0)+1&65535;C=(c[u>>2]|0)==((c[x>>2]|0)-1|0)|0;F=c[s>>2]|0;G=(c[h>>2]|0)-F|0;c[h>>2]=G;if(!(F>>>0<=(c[y>>2]|0)>>>0&G>>>0>2)){G=(c[l>>2]|0)+F|0;c[l>>2]=G;c[s>>2]=0;J=c[m>>2]|0;K=d[J+G|0]|0;c[j>>2]=K;c[j>>2]=((d[J+(G+1)|0]|0)^K<<c[k>>2])&c[n>>2];L=C;M=G;break}c[s>>2]=F-1;do{F=c[l>>2]|0;G=F+1|0;c[l>>2]=G;K=((d[(c[m>>2]|0)+(F+3)|0]|0)^c[j>>2]<<c[k>>2])&c[n>>2];c[j>>2]=K;b[(c[q>>2]|0)+((c[p>>2]&G)<<1)>>1]=b[(c[o>>2]|0)+(K<<1)>>1]|0;b[(c[o>>2]|0)+(c[j>>2]<<1)>>1]=c[l>>2]&65535;K=(c[s>>2]|0)-1|0;c[s>>2]=K;}while((K|0)!=0);K=(c[l>>2]|0)+1|0;c[l>>2]=K;L=C;M=K}else{K=a[(c[m>>2]|0)+(c[l>>2]|0)|0]|0;b[(c[v>>2]|0)+(c[u>>2]<<1)>>1]=0;G=c[u>>2]|0;c[u>>2]=G+1;a[(c[w>>2]|0)+G|0]=K;G=f+148+((K&255)<<2)|0;b[G>>1]=(b[G>>1]|0)+1&65535;G=(c[u>>2]|0)==((c[x>>2]|0)-1|0)|0;c[h>>2]=(c[h>>2]|0)-1;K=(c[l>>2]|0)+1|0;c[l>>2]=K;L=G;M=K}}while(0);if((L|0)==0){continue}K=c[z>>2]|0;if((K|0)>-1){N=(c[m>>2]|0)+K|0}else{N=0}RN(B,N,M-K|0,0);c[z>>2]=c[l>>2];K=c[A>>2]|0;G=c[K+28>>2]|0;F=G+5820|0;J=c[F>>2]|0;do{if((J|0)==16){O=G+5816|0;P=b[O>>1]&255;Q=G+20|0;R=c[Q>>2]|0;c[Q>>2]=R+1;S=G+8|0;a[(c[S>>2]|0)+R|0]=P;P=(e[O>>1]|0)>>>8&255;R=c[Q>>2]|0;c[Q>>2]=R+1;a[(c[S>>2]|0)+R|0]=P;b[O>>1]=0;c[F>>2]=0;T=Q}else{if((J|0)>7){Q=G+5816|0;O=b[Q>>1]&255;P=G+20|0;R=c[P>>2]|0;c[P>>2]=R+1;a[(c[G+8>>2]|0)+R|0]=O;b[Q>>1]=(e[Q>>1]|0)>>>8;c[F>>2]=(c[F>>2]|0)-8;T=P;break}else{T=G+20|0;break}}}while(0);F=c[T>>2]|0;J=K+16|0;P=c[J>>2]|0;Q=F>>>0>P>>>0?P:F;do{if((Q|0)!=0){F=K+12|0;P=c[F>>2]|0;O=G+16|0;R=c[O>>2]|0;gGC(P|0,R|0,Q)|0;c[F>>2]=(c[F>>2]|0)+Q;c[O>>2]=(c[O>>2]|0)+Q;F=K+20|0;c[F>>2]=(c[F>>2]|0)+Q;c[J>>2]=(c[J>>2]|0)-Q;F=c[T>>2]|0;c[T>>2]=F-Q;if((F|0)!=(Q|0)){break}c[O>>2]=c[G+8>>2]}}while(0);if((c[(c[A>>2]|0)+16>>2]|0)==0){D=0;E=40406;break}}if((E|0)==40380){T=c[l>>2]|0;c[f+5812>>2]=T>>>0<2?T:2;if((g|0)==4){g=c[z>>2]|0;if((g|0)>-1){U=(c[m>>2]|0)+g|0}else{U=0}RN(B,U,T-g|0,1);c[z>>2]=c[l>>2];g=c[A>>2]|0;U=c[g+28>>2]|0;f=U+5820|0;M=c[f>>2]|0;do{if((M|0)==16){N=U+5816|0;L=b[N>>1]&255;h=U+20|0;x=c[h>>2]|0;c[h>>2]=x+1;w=U+8|0;a[(c[w>>2]|0)+x|0]=L;L=(e[N>>1]|0)>>>8&255;x=c[h>>2]|0;c[h>>2]=x+1;a[(c[w>>2]|0)+x|0]=L;b[N>>1]=0;c[f>>2]=0;V=h}else{if((M|0)>7){h=U+5816|0;N=b[h>>1]&255;L=U+20|0;x=c[L>>2]|0;c[L>>2]=x+1;a[(c[U+8>>2]|0)+x|0]=N;b[h>>1]=(e[h>>1]|0)>>>8;c[f>>2]=(c[f>>2]|0)-8;V=L;break}else{V=U+20|0;break}}}while(0);f=c[V>>2]|0;M=g+16|0;L=c[M>>2]|0;h=f>>>0>L>>>0?L:f;do{if((h|0)!=0){f=g+12|0;L=c[f>>2]|0;N=U+16|0;x=c[N>>2]|0;gGC(L|0,x|0,h)|0;c[f>>2]=(c[f>>2]|0)+h;c[N>>2]=(c[N>>2]|0)+h;f=g+20|0;c[f>>2]=(c[f>>2]|0)+h;c[M>>2]=(c[M>>2]|0)-h;f=c[V>>2]|0;c[V>>2]=f-h;if((f|0)!=(h|0)){break}c[N>>2]=c[U+8>>2]}}while(0);D=(c[(c[A>>2]|0)+16>>2]|0)==0?2:3;return D|0}do{if((c[u>>2]|0)!=0){U=c[z>>2]|0;if((U|0)>-1){W=(c[m>>2]|0)+U|0}else{W=0}RN(B,W,T-U|0,0);c[z>>2]=c[l>>2];U=c[A>>2]|0;h=c[U+28>>2]|0;V=h+5820|0;M=c[V>>2]|0;do{if((M|0)==16){g=h+5816|0;N=b[g>>1]&255;f=h+20|0;x=c[f>>2]|0;c[f>>2]=x+1;L=h+8|0;a[(c[L>>2]|0)+x|0]=N;N=(e[g>>1]|0)>>>8&255;x=c[f>>2]|0;c[f>>2]=x+1;a[(c[L>>2]|0)+x|0]=N;b[g>>1]=0;c[V>>2]=0;X=f}else{if((M|0)>7){f=h+5816|0;g=b[f>>1]&255;N=h+20|0;x=c[N>>2]|0;c[N>>2]=x+1;a[(c[h+8>>2]|0)+x|0]=g;b[f>>1]=(e[f>>1]|0)>>>8;c[V>>2]=(c[V>>2]|0)-8;X=N;break}else{X=h+20|0;break}}}while(0);V=c[X>>2]|0;M=U+16|0;N=c[M>>2]|0;f=V>>>0>N>>>0?N:V;do{if((f|0)!=0){V=U+12|0;N=c[V>>2]|0;g=h+16|0;x=c[g>>2]|0;gGC(N|0,x|0,f)|0;c[V>>2]=(c[V>>2]|0)+f;c[g>>2]=(c[g>>2]|0)+f;V=U+20|0;c[V>>2]=(c[V>>2]|0)+f;c[M>>2]=(c[M>>2]|0)-f;V=c[X>>2]|0;c[X>>2]=V-f;if((V|0)!=(f|0)){break}c[g>>2]=c[h+8>>2]}}while(0);if((c[(c[A>>2]|0)+16>>2]|0)==0){D=0}else{break}return D|0}}while(0);D=1;return D|0}else if((E|0)==40407){return D|0}else if((E|0)==40406){return D|0}return 0}function RZ(f,g){f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0;h=f+116|0;i=(g|0)==0;j=f+72|0;k=f+88|0;l=f+108|0;m=f+56|0;n=f+84|0;o=f+68|0;p=f+52|0;q=f+64|0;r=f+96|0;s=f+120|0;t=f+112|0;u=f+100|0;v=f+5792|0;w=f+5796|0;x=f+5784|0;y=f+5788|0;z=f+104|0;A=f+92|0;B=f|0;C=f+128|0;D=f+44|0;E=f+136|0;F=f;L51675:while(1){G=c[h>>2]|0;while(1){do{if(G>>>0<262){RW(f);H=c[h>>2]|0;if(H>>>0<262&i){I=0;J=40491;break L51675}if((H|0)==0){J=40460;break L51675}if(H>>>0>2){J=40418;break}c[s>>2]=c[r>>2];c[u>>2]=c[t>>2];c[r>>2]=2;K=2;J=40426}else{J=40418}}while(0);do{if((J|0)==40418){J=0;H=c[l>>2]|0;L=((d[(c[m>>2]|0)+(H+2)|0]|0)^c[j>>2]<<c[k>>2])&c[n>>2];c[j>>2]=L;M=b[(c[o>>2]|0)+(L<<1)>>1]|0;b[(c[q>>2]|0)+((c[p>>2]&H)<<1)>>1]=M;H=M&65535;b[(c[o>>2]|0)+(c[j>>2]<<1)>>1]=c[l>>2]&65535;L=c[r>>2]|0;c[s>>2]=L;c[u>>2]=c[t>>2];c[r>>2]=2;if(M<<16>>16==0){K=2;J=40426;break}if(L>>>0>=(c[C>>2]|0)>>>0){N=L;O=2;break}if(((c[l>>2]|0)-H|0)>>>0>((c[D>>2]|0)-262|0)>>>0){K=2;J=40426;break}L=R_(f,H)|0;c[r>>2]=L;if(L>>>0>=6){K=L;J=40426;break}if((c[E>>2]|0)!=1){if((L|0)!=3){K=L;J=40426;break}if(((c[l>>2]|0)-(c[t>>2]|0)|0)>>>0<=4096){K=3;J=40426;break}}c[r>>2]=2;K=2;J=40426}}while(0);if((J|0)==40426){J=0;N=c[s>>2]|0;O=K}if(!(N>>>0<3|O>>>0>N>>>0)){break}if((c[z>>2]|0)==0){c[z>>2]=1;c[l>>2]=(c[l>>2]|0)+1;L=(c[h>>2]|0)-1|0;c[h>>2]=L;G=L;continue}L=a[(c[m>>2]|0)+((c[l>>2]|0)-1)|0]|0;b[(c[w>>2]|0)+(c[v>>2]<<1)>>1]=0;H=c[v>>2]|0;c[v>>2]=H+1;a[(c[x>>2]|0)+H|0]=L;H=f+148+((L&255)<<2)|0;b[H>>1]=(b[H>>1]|0)+1&65535;do{if((c[v>>2]|0)==((c[y>>2]|0)-1|0)){H=c[A>>2]|0;if((H|0)>-1){P=(c[m>>2]|0)+H|0}else{P=0}RN(F,P,(c[l>>2]|0)-H|0,0);c[A>>2]=c[l>>2];H=c[B>>2]|0;L=c[H+28>>2]|0;M=L+5820|0;Q=c[M>>2]|0;do{if((Q|0)==16){R=L+5816|0;S=b[R>>1]&255;T=L+20|0;U=c[T>>2]|0;c[T>>2]=U+1;V=L+8|0;a[(c[V>>2]|0)+U|0]=S;S=(e[R>>1]|0)>>>8&255;U=c[T>>2]|0;c[T>>2]=U+1;a[(c[V>>2]|0)+U|0]=S;b[R>>1]=0;c[M>>2]=0;W=T}else{if((Q|0)>7){T=L+5816|0;R=b[T>>1]&255;S=L+20|0;U=c[S>>2]|0;c[S>>2]=U+1;a[(c[L+8>>2]|0)+U|0]=R;b[T>>1]=(e[T>>1]|0)>>>8;c[M>>2]=(c[M>>2]|0)-8;W=S;break}else{W=L+20|0;break}}}while(0);M=c[W>>2]|0;Q=H+16|0;S=c[Q>>2]|0;T=M>>>0>S>>>0?S:M;if((T|0)==0){break}M=H+12|0;S=c[M>>2]|0;R=L+16|0;U=c[R>>2]|0;gGC(S|0,U|0,T)|0;c[M>>2]=(c[M>>2]|0)+T;c[R>>2]=(c[R>>2]|0)+T;M=H+20|0;c[M>>2]=(c[M>>2]|0)+T;c[Q>>2]=(c[Q>>2]|0)-T;Q=c[W>>2]|0;c[W>>2]=Q-T;if((Q|0)!=(T|0)){break}c[R>>2]=c[L+8>>2]}}while(0);c[l>>2]=(c[l>>2]|0)+1;R=(c[h>>2]|0)-1|0;c[h>>2]=R;if((c[(c[B>>2]|0)+16>>2]|0)==0){I=0;J=40492;break L51675}else{G=R}}G=c[l>>2]|0;R=G-3+(c[h>>2]|0)|0;T=N+253|0;Q=G+65535-(c[u>>2]|0)&65535;b[(c[w>>2]|0)+(c[v>>2]<<1)>>1]=Q;G=c[v>>2]|0;c[v>>2]=G+1;a[(c[x>>2]|0)+G|0]=T&255;G=Q-1&65535;Q=f+148+((d[589976+(T&255)|0]|0|256)+1<<2)|0;b[Q>>1]=(b[Q>>1]|0)+1&65535;Q=G&65535;if((G&65535)<256){X=Q}else{X=(Q>>>7)+256|0}Q=f+2440+((d[590232+X|0]|0)<<2)|0;b[Q>>1]=(b[Q>>1]|0)+1&65535;Q=c[v>>2]|0;G=c[y>>2]|0;T=c[s>>2]|0;c[h>>2]=1-T+(c[h>>2]|0);M=T-2|0;c[s>>2]=M;T=M;do{M=c[l>>2]|0;U=M+1|0;c[l>>2]=U;if(U>>>0>R>>>0){Y=T}else{S=((d[(c[m>>2]|0)+(M+3)|0]|0)^c[j>>2]<<c[k>>2])&c[n>>2];c[j>>2]=S;b[(c[q>>2]|0)+((c[p>>2]&U)<<1)>>1]=b[(c[o>>2]|0)+(S<<1)>>1]|0;b[(c[o>>2]|0)+(c[j>>2]<<1)>>1]=c[l>>2]&65535;Y=c[s>>2]|0}T=Y-1|0;c[s>>2]=T;}while((T|0)!=0);c[z>>2]=0;c[r>>2]=2;T=(c[l>>2]|0)+1|0;c[l>>2]=T;if((Q|0)!=(G-1|0)){continue}R=c[A>>2]|0;if((R|0)>-1){Z=(c[m>>2]|0)+R|0}else{Z=0}RN(F,Z,T-R|0,0);c[A>>2]=c[l>>2];R=c[B>>2]|0;T=c[R+28>>2]|0;S=T+5820|0;U=c[S>>2]|0;do{if((U|0)==16){M=T+5816|0;V=b[M>>1]&255;_=T+20|0;$=c[_>>2]|0;c[_>>2]=$+1;aa=T+8|0;a[(c[aa>>2]|0)+$|0]=V;V=(e[M>>1]|0)>>>8&255;$=c[_>>2]|0;c[_>>2]=$+1;a[(c[aa>>2]|0)+$|0]=V;b[M>>1]=0;c[S>>2]=0;ab=_}else{if((U|0)>7){_=T+5816|0;M=b[_>>1]&255;V=T+20|0;$=c[V>>2]|0;c[V>>2]=$+1;a[(c[T+8>>2]|0)+$|0]=M;b[_>>1]=(e[_>>1]|0)>>>8;c[S>>2]=(c[S>>2]|0)-8;ab=V;break}else{ab=T+20|0;break}}}while(0);S=c[ab>>2]|0;U=R+16|0;G=c[U>>2]|0;Q=S>>>0>G>>>0?G:S;do{if((Q|0)!=0){S=R+12|0;G=c[S>>2]|0;V=T+16|0;_=c[V>>2]|0;gGC(G|0,_|0,Q)|0;c[S>>2]=(c[S>>2]|0)+Q;c[V>>2]=(c[V>>2]|0)+Q;S=R+20|0;c[S>>2]=(c[S>>2]|0)+Q;c[U>>2]=(c[U>>2]|0)-Q;S=c[ab>>2]|0;c[ab>>2]=S-Q;if((S|0)!=(Q|0)){break}c[V>>2]=c[T+8>>2]}}while(0);if((c[(c[B>>2]|0)+16>>2]|0)==0){I=0;J=40490;break}}if((J|0)==40460){if((c[z>>2]|0)!=0){ab=a[(c[m>>2]|0)+((c[l>>2]|0)-1)|0]|0;b[(c[w>>2]|0)+(c[v>>2]<<1)>>1]=0;w=c[v>>2]|0;c[v>>2]=w+1;a[(c[x>>2]|0)+w|0]=ab;w=f+148+((ab&255)<<2)|0;b[w>>1]=(b[w>>1]|0)+1&65535;c[z>>2]=0}z=c[l>>2]|0;c[f+5812>>2]=z>>>0<2?z:2;if((g|0)==4){g=c[A>>2]|0;if((g|0)>-1){ac=(c[m>>2]|0)+g|0}else{ac=0}RN(F,ac,z-g|0,1);c[A>>2]=c[l>>2];g=c[B>>2]|0;ac=c[g+28>>2]|0;f=ac+5820|0;w=c[f>>2]|0;do{if((w|0)==16){ab=ac+5816|0;x=b[ab>>1]&255;Z=ac+20|0;r=c[Z>>2]|0;c[Z>>2]=r+1;s=ac+8|0;a[(c[s>>2]|0)+r|0]=x;x=(e[ab>>1]|0)>>>8&255;r=c[Z>>2]|0;c[Z>>2]=r+1;a[(c[s>>2]|0)+r|0]=x;b[ab>>1]=0;c[f>>2]=0;ad=Z}else{if((w|0)>7){Z=ac+5816|0;ab=b[Z>>1]&255;x=ac+20|0;r=c[x>>2]|0;c[x>>2]=r+1;a[(c[ac+8>>2]|0)+r|0]=ab;b[Z>>1]=(e[Z>>1]|0)>>>8;c[f>>2]=(c[f>>2]|0)-8;ad=x;break}else{ad=ac+20|0;break}}}while(0);f=c[ad>>2]|0;w=g+16|0;x=c[w>>2]|0;Z=f>>>0>x>>>0?x:f;do{if((Z|0)!=0){f=g+12|0;x=c[f>>2]|0;ab=ac+16|0;r=c[ab>>2]|0;gGC(x|0,r|0,Z)|0;c[f>>2]=(c[f>>2]|0)+Z;c[ab>>2]=(c[ab>>2]|0)+Z;f=g+20|0;c[f>>2]=(c[f>>2]|0)+Z;c[w>>2]=(c[w>>2]|0)-Z;f=c[ad>>2]|0;c[ad>>2]=f-Z;if((f|0)!=(Z|0)){break}c[ab>>2]=c[ac+8>>2]}}while(0);I=(c[(c[B>>2]|0)+16>>2]|0)==0?2:3;return I|0}do{if((c[v>>2]|0)!=0){ac=c[A>>2]|0;if((ac|0)>-1){ae=(c[m>>2]|0)+ac|0}else{ae=0}RN(F,ae,z-ac|0,0);c[A>>2]=c[l>>2];ac=c[B>>2]|0;Z=c[ac+28>>2]|0;ad=Z+5820|0;w=c[ad>>2]|0;do{if((w|0)==16){g=Z+5816|0;ab=b[g>>1]&255;f=Z+20|0;r=c[f>>2]|0;c[f>>2]=r+1;x=Z+8|0;a[(c[x>>2]|0)+r|0]=ab;ab=(e[g>>1]|0)>>>8&255;r=c[f>>2]|0;c[f>>2]=r+1;a[(c[x>>2]|0)+r|0]=ab;b[g>>1]=0;c[ad>>2]=0;af=f}else{if((w|0)>7){f=Z+5816|0;g=b[f>>1]&255;ab=Z+20|0;r=c[ab>>2]|0;c[ab>>2]=r+1;a[(c[Z+8>>2]|0)+r|0]=g;b[f>>1]=(e[f>>1]|0)>>>8;c[ad>>2]=(c[ad>>2]|0)-8;af=ab;break}else{af=Z+20|0;break}}}while(0);ad=c[af>>2]|0;w=ac+16|0;ab=c[w>>2]|0;f=ad>>>0>ab>>>0?ab:ad;do{if((f|0)!=0){ad=ac+12|0;ab=c[ad>>2]|0;g=Z+16|0;r=c[g>>2]|0;gGC(ab|0,r|0,f)|0;c[ad>>2]=(c[ad>>2]|0)+f;c[g>>2]=(c[g>>2]|0)+f;ad=ac+20|0;c[ad>>2]=(c[ad>>2]|0)+f;c[w>>2]=(c[w>>2]|0)-f;ad=c[af>>2]|0;c[af>>2]=ad-f;if((ad|0)!=(f|0)){break}c[g>>2]=c[Z+8>>2]}}while(0);if((c[(c[B>>2]|0)+16>>2]|0)==0){I=0}else{break}return I|0}}while(0);I=1;return I|0}else if((J|0)==40490){return I|0}else if((J|0)==40491){return I|0}else if((J|0)==40492){return I|0}return 0}function R_(b,d){b=b|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;f=c[b+124>>2]|0;g=c[b+56>>2]|0;h=c[b+108>>2]|0;i=g+h|0;j=c[b+120>>2]|0;k=c[b+144>>2]|0;l=(c[b+44>>2]|0)-262|0;m=h>>>0>l>>>0?h-l|0:0;l=c[b+64>>2]|0;n=c[b+52>>2]|0;o=g+(h+258)|0;p=c[b+116>>2]|0;q=k>>>0>p>>>0?p:k;k=b+112|0;r=g+(h+1)|0;s=g+(h+2)|0;t=o;u=h+257|0;v=a[g+(j+h)|0]|0;w=a[g+(h-1+j)|0]|0;x=d;d=j>>>0<(c[b+140>>2]|0)>>>0?f:f>>>2;f=j;L51787:while(1){j=g+x|0;do{if((a[g+(x+f)|0]|0)==v<<24>>24){if((a[g+(f-1+x)|0]|0)!=w<<24>>24){y=v;z=w;A=f;break}if((a[j]|0)!=(a[i]|0)){y=v;z=w;A=f;break}if((a[g+(x+1)|0]|0)!=(a[r]|0)){y=v;z=w;A=f;break}b=s;B=g+(x+2)|0;while(1){C=b+1|0;if((a[C]|0)!=(a[B+1|0]|0)){D=C;break}C=b+2|0;if((a[C]|0)!=(a[B+2|0]|0)){D=C;break}C=b+3|0;if((a[C]|0)!=(a[B+3|0]|0)){D=C;break}C=b+4|0;if((a[C]|0)!=(a[B+4|0]|0)){D=C;break}C=b+5|0;if((a[C]|0)!=(a[B+5|0]|0)){D=C;break}C=b+6|0;if((a[C]|0)!=(a[B+6|0]|0)){D=C;break}C=b+7|0;if((a[C]|0)!=(a[B+7|0]|0)){D=C;break}C=b+8|0;E=B+8|0;if((a[C]|0)==(a[E]|0)&C>>>0<o>>>0){b=C;B=E}else{D=C;break}}B=D-t|0;b=B+258|0;if((b|0)<=(f|0)){y=v;z=w;A=f;break}c[k>>2]=x;if((b|0)>=(q|0)){F=b;G=40514;break L51787}y=a[g+(b+h)|0]|0;z=a[g+(u+B)|0]|0;A=b}else{y=v;z=w;A=f}}while(0);j=e[l+((x&n)<<1)>>1]|0;if(j>>>0<=m>>>0){F=A;G=40515;break}b=d-1|0;if((b|0)==0){F=A;G=40516;break}else{v=y;w=z;x=j;d=b;f=A}}if((G|0)==40514){H=F>>>0>p>>>0;I=H?p:F;return I|0}else if((G|0)==40515){H=F>>>0>p>>>0;I=H?p:F;return I|0}else if((G|0)==40516){H=F>>>0>p>>>0;I=H?p:F;return I|0}return 0}function R$(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;if((c[2113150]|0)<=0){return}f=e+3|0;g=e+4|0;h=d|0;i=d+12|0;j=i;k=i+2|0;l=d+16|0;m=i+6|0;i=0;do{n=c[703416+(i<<2)>>2]|0;o=n>>4;switch(n&15|0){case 3:{R1(d,e,i,2,o);R2(d,e,i,2);R0(d,e,i);break};case 4:{R0(d,e,i);R3(d,e,i,16,o);break};case 7:{R0(d,e,i);R3(d,e,i,1,o);break};case 5:{R0(d,e,i);R3(d,e,i,17,o);break};case 6:{R0(d,e,i);R3(d,e,i,0,o);break};case 0:{do{if((gGE(672656+((i&3)<<2)|0,e|0,3)|0)==0){n=a[f]|0;if(n<<24>>24==0){break}if((fa(g|0,220880)|0)!=0){break}p=n<<24>>24==120;q=n<<24>>24==121;r=n<<24>>24==122;n=r?47:q?200:p?203:0;s=r?33:q?208:p?205:0;if((n|0)==0|(s|0)==0){break}a[h]=8;b[j>>1]=n&65535;b[k>>1]=s&65535;if((o|0)==2){b[l>>1]=1792;b[m>>1]=0;break}else{b[l>>1]=3584;b[m>>1]=10;break}}}while(0);R2(d,e,i,-1);R0(d,e,i);break};case 1:{R1(d,e,i,0,o);R2(d,e,i,0);R0(d,e,i);break};case 2:{R1(d,e,i,1,o);R2(d,e,i,1);R0(d,e,i);break};default:{R0(d,e,i)}}i=i+1|0;}while((i|0)<(c[2113150]|0));return}function R0(c,d,e){c=c|0;d=d|0;e=e|0;do{if((e|0)==2){if((fa(d|0,119272)|0)==0){a[c|0]=2;b[c+12>>1]=8;return}if((fa(d|0,114064)|0)!=0){break}a[c|0]=2;b[c+12>>1]=4;return}else if((e|0)==0){if((fa(d|0,83672)|0)==0){a[c|0]=2;b[c+12>>1]=60;return}if((fa(d|0,244008)|0)==0){a[c|0]=2;b[c+12>>1]=61;return}if((fa(d|0,527584)|0)==0){a[c|0]=2;b[c+12>>1]=10;return}if((fa(d|0,503936)|0)==0){a[c|0]=2;b[c+12>>1]=11;return}if((fa(d|0,488184)|0)==0){a[c|0]=2;b[c+12>>1]=12;return}if((fa(d|0,354592)|0)==0){a[c|0]=2;b[c+12>>1]=13;return}if((fa(d|0,78400)|0)==0){a[c|0]=2;b[c+12>>1]=20;return}if((fa(d|0,69240)|0)==0){a[c|0]=2;b[c+12>>1]=59;return}if((fa(d|0,69128)|0)==0){a[c|0]=2;b[c+12>>1]=34;return}if((fa(d|0,68952)|0)==0){a[c|0]=2;b[c+12>>1]=35;return}if((fa(d|0,351832)|0)==0){a[c|0]=2;b[c+12>>1]=30;return}if((fa(d|0,350760)|0)==0){a[c|0]=2;b[c+12>>1]=48;return}if((fa(d|0,349056)|0)==0){a[c|0]=2;b[c+12>>1]=46;return}if((fa(d|0,347560)|0)==0){a[c|0]=2;b[c+12>>1]=32;return}if((fa(d|0,345344)|0)==0){a[c|0]=2;b[c+12>>1]=18;return}if((fa(d|0,344096)|0)==0){a[c|0]=2;b[c+12>>1]=33;return}if((fa(d|0,342832)|0)==0){a[c|0]=2;b[c+12>>1]=34;return}if((fa(d|0,341496)|0)==0){a[c|0]=2;b[c+12>>1]=35;return}if((fa(d|0,339456)|0)==0){a[c|0]=2;b[c+12>>1]=23;return}if((fa(d|0,337400)|0)==0){a[c|0]=2;b[c+12>>1]=36;return}if((fa(d|0,335992)|0)==0){a[c|0]=2;b[c+12>>1]=37;return}if((fa(d|0,334784)|0)==0){a[c|0]=2;b[c+12>>1]=38;return}if((fa(d|0,333504)|0)==0){a[c|0]=2;b[c+12>>1]=50;return}if((fa(d|0,331824)|0)==0){a[c|0]=2;b[c+12>>1]=49;return}if((fa(d|0,329752)|0)==0){a[c|0]=2;b[c+12>>1]=29;return}if((fa(d|0,328224)|0)==0){a[c|0]=2;b[c+12>>1]=56;return}if((fa(d|0,326664)|0)==0){a[c|0]=2;b[c+12>>1]=57;return}if((fa(d|0,324664)|0)==0){a[c|0]=2;b[c+12>>1]=42;return}if((fa(d|0,322944)|0)==0){a[c|0]=2;b[c+12>>1]=44;return}if((fa(d|0,261168)|0)==0){a[c|0]=2;b[c+12>>1]=21;return}if((fa(d|0,265176)|0)==0){a[c|0]=2;b[c+12>>1]=184;return}if((fa(d|0,266264)|0)==0){a[c|0]=2;b[c+12>>1]=3;return}if((fa(d|0,263248)|0)==0){a[c|0]=2;b[c+12>>1]=157;return}if((fa(d|0,172216)|0)==0){a[c|0]=2;b[c+12>>1]=2;return}if((fa(d|0,282208)|0)==0){a[c|0]=2;b[c+12>>1]=4;return}if((fa(d|0,180216)|0)!=0){break}a[c|0]=2;b[c+12>>1]=6;return}else if((e|0)==1){if((fa(d|0,123016)|0)==0){a[c|0]=2;b[c+12>>1]=3;return}if((fa(d|0,80920)|0)==0){a[c|0]=2;b[c+12>>1]=5;return}if((fa(d|0,128576)|0)!=0){break}a[c|0]=2;b[c+12>>1]=7;return}else if((e|0)==3){if((fa(d|0,587040)|0)==0){a[c|0]=2;b[c+12>>1]=5;return}if((fa(d|0,377704)|0)!=0){break}a[c|0]=2;b[c+12>>1]=9;return}}while(0);if((dW(d|0,245912,5)|0)!=0){return}if((fa(d|0,119448)|0)==0){a[c|0]=16;a[c+13|0]=0;return}if((fa(d|0,114128)|0)==0){a[c|0]=16;a[c+13|0]=1;return}if((dW(d|0,538408,12)|0)!=0){return}e=dE(d+13|0,0,0)|0;a[c|0]=2;b[c+12>>1]=e+32896+(((e|0)>0)<<31>>31)&65535;return}function R1(d,e,f,g,h){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0;if((gGE(672656+((f&3)<<2)|0,e|0,3)|0)!=0){return}f=e+3|0;i=a[f]|0;if(i<<24>>24==0){return}if((dW(e+4|0,220880,5)|0)!=0){return}j=i<<24>>24==122?2:i<<24>>24==121|0;if((gGy(f|0)|0)>>>0>6){f=e+9|0;e=(fa(f|0,204416)|0)==0;i=(fa(f|0,198272)|0)==0;k=i?4:e?3:h}else{k=h}if((k|0)==1){a[d|0]=9;h=d+12|0;c[d+20>>2]=32768;b[d+16>>1]=3584;b[h+6>>1]=10;a[h+1|0]=j;a[h]=g&255;return}else if((k|0)==2){a[d|0]=9;h=d+12|0;c[d+20>>2]=32768;b[d+16>>1]=1792;b[h+6>>1]=0;a[h+1|0]=j;a[h]=g&255;return}else if((k|0)==3){a[d|0]=33;h=d+12|0;a[h+1|0]=j;a[h]=g&255;return}else if((k|0)==4){a[d|0]=34;k=d+12|0;a[k+1|0]=j;a[k]=g&255;return}else{a[d|0]=32;k=d+12|0;a[k+1|0]=j;a[k]=g&255;return}}function R2(d,e,f,g){d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0;if((gGE(672656+((f&3)<<2)|0,e|0,3)|0)!=0){return}f=e+3|0;if((g|0)<-1){if((fa(f|0,192464)|0)==0){h=40707}else{if((fa(f|0,186712)|0)==0){h=40707}else{i=0}}if((h|0)==40707){i=1}if((fa(f|0,181376)|0)==0){h=40710}else{if((fa(f|0,177240)|0)==0){h=40710}else{j=i}}if((h|0)==40710){j=1}if((fa(f|0,173408)|0)==0){h=40713}else{if((fa(f|0,169784)|0)==0){h=40713}else{k=j}}if((h|0)==40713){k=1}if((fa(f|0,166840)|0)==0){h=40716}else{if((fa(f|0,164016)|0)==0){h=40716}else{l=k}}if((h|0)==40716){l=1}if((l|0)==0&(dW(f|0,160160,5)|0)!=0){return}a[d|0]=1;a[d+12|0]=0;return}if((g|0)!=-1){l=g<<8;if((fa(f|0,192464)|0)==0){a[d|0]=2;b[d+12>>1]=(l|16386)&65535}if((fa(f|0,181376)|0)==0){a[d|0]=2;b[d+12>>1]=(l|16387)&65535}if((fa(f|0,173408)|0)==0){a[d|0]=2;b[d+12>>1]=(l|16384)&65535}if((fa(f|0,166840)|0)==0){a[d|0]=2;b[d+12>>1]=(l|16385)&65535}if((dW(f|0,160160,5)|0)!=0){return}g=dE(e+8|0,0,0)|0;a[d|0]=2;b[d+12>>1]=g+(l|16512)+(((g|0)>0)<<31>>31)&65535;return}if((fa(f|0,192464)|0)==0){h=40722}else{if((fa(f|0,186712)|0)==0){h=40722}}if((h|0)==40722){a[d|0]=2;b[d+12>>1]=200}if((fa(f|0,181376)|0)==0){h=40725}else{if((fa(f|0,177240)|0)==0){h=40725}}if((h|0)==40725){a[d|0]=2;b[d+12>>1]=208}if((fa(f|0,173408)|0)==0){h=40728}else{if((fa(f|0,169784)|0)==0){h=40728}}if((h|0)==40728){a[d|0]=2;b[d+12>>1]=203}if((fa(f|0,166840)|0)==0){h=40731}else{if((fa(f|0,164016)|0)==0){h=40731}}if((h|0)==40731){a[d|0]=2;b[d+12>>1]=205}if((c[2113210]|0)==4){if((fa(f|0,157168)|0)==0){a[d|0]=2;b[d+12>>1]=44}if((fa(f|0,153656)|0)==0){a[d|0]=2;b[d+12>>1]=45}if((fa(f|0,149688)|0)==0){a[d|0]=2;b[d+12>>1]=46}if((fa(f|0,146480)|0)!=0){return}a[d|0]=2;b[d+12>>1]=47;return}h=a[64256]|0;g=(fa(f|0,157168)|0)==0;if(h){if(g){a[d|0]=2;b[d+12>>1]=30}if((fa(f|0,153656)|0)==0){a[d|0]=2;b[d+12>>1]=31}if((fa(f|0,149688)|0)==0){a[d|0]=2;b[d+12>>1]=32}if((fa(f|0,146480)|0)==0){a[d|0]=2;b[d+12>>1]=44}if((fa(f|0,142552)|0)==0){a[d|0]=2;b[d+12>>1]=45}if((fa(f|0,139632)|0)==0){a[d|0]=2;b[d+12>>1]=46}if((gGF(f|0,137024)|0)==0){a[d+4|0]=1;b[d+32>>1]=33}if((gGF(f|0,134648)|0)!=0){return}a[d+4|0]=1;b[d+32>>1]=47;return}if(g){a[d|0]=2;b[d+12>>1]=44}if((fa(f|0,153656)|0)==0){a[d|0]=2;b[d+12>>1]=45}if((fa(f|0,149688)|0)==0){a[d|0]=2;b[d+12>>1]=46}if((fa(f|0,146480)|0)==0){a[d|0]=2;b[d+12>>1]=30}if((fa(f|0,142552)|0)==0){a[d|0]=2;b[d+12>>1]=31}if((fa(f|0,139632)|0)==0){a[d|0]=2;b[d+12>>1]=32}if((fa(f|0,132592)|0)==0){a[d|0]=2;b[d+12>>1]=16}if((fa(f|0,129576)|0)==0){a[d|0]=2;b[d+12>>1]=17}if((fa(f|0,126952)|0)!=0){return}a[d|0]=2;b[d+12>>1]=18;return}function R3(d,e,f,g,h){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;if((gGE(672656+((f&3)<<2)|0,e|0,3)|0)!=0){return}f=e+3|0;e=(fa(f|0,123960)|0)==0;if((g&1|0)==0){i=(fa(f|0,120104)|0)==0;j=i?72:e?75:0;k=i?80:e?77:0;if((fa(f|0,192464)|0)==0){l=40802}else{if((fa(f|0,186712)|0)==0){l=40802}}if((l|0)==40802){a[d|0]=2;b[d+12>>1]=72}if((fa(f|0,181376)|0)==0){l=40805}else{if((fa(f|0,177240)|0)==0){l=40805}}if((l|0)==40805){a[d|0]=2;b[d+12>>1]=80}if((fa(f|0,173408)|0)==0){l=40808}else{if((fa(f|0,169784)|0)==0){l=40808}}if((l|0)==40808){a[d|0]=2;b[d+12>>1]=75}if((fa(f|0,166840)|0)==0){l=40811}else{if((fa(f|0,164016)|0)==0){l=40811}}if((l|0)==40811){a[d|0]=2;b[d+12>>1]=77}do{if((c[2113210]|0)==4){if((fa(f|0,157168)|0)==0){a[d|0]=2;b[d+12>>1]=46}if((fa(f|0,153656)|0)==0){a[d|0]=2;b[d+12>>1]=42}if((fa(f|0,149688)|0)==0){a[d|0]=2;b[d+12>>1]=44}if((fa(f|0,146480)|0)!=0){break}a[d|0]=2;b[d+12>>1]=45}else{i=a[64256]|0;m=(fa(f|0,157168)|0)==0;if(!i){if(m){a[d|0]=2;b[d+12>>1]=42}if((fa(f|0,153656)|0)==0){a[d|0]=2;b[d+12>>1]=44}if((fa(f|0,149688)|0)==0){a[d|0]=2;b[d+12>>1]=45}if((fa(f|0,146480)|0)==0){a[d|0]=2;b[d+12>>1]=29}if((fa(f|0,142552)|0)==0){a[d|0]=2;b[d+12>>1]=56}if((fa(f|0,139632)|0)!=0){break}a[d|0]=2;b[d+12>>1]=57;break}if(m){a[d|0]=2;b[d+12>>1]=29}if((fa(f|0,153656)|0)==0){a[d|0]=2;b[d+12>>1]=56}if((fa(f|0,149688)|0)==0){a[d|0]=2;b[d+12>>1]=57}if((fa(f|0,146480)|0)==0){a[d|0]=2;b[d+12>>1]=42}if((fa(f|0,142552)|0)==0){a[d|0]=2;b[d+12>>1]=44}if((fa(f|0,139632)|0)==0){a[d|0]=2;b[d+12>>1]=45}if((g&16|0)==0){break}if((gGF(f|0,137024)|0)==0){a[d+4|0]=1;b[d+32>>1]=46}if((gGF(f|0,134648)|0)!=0){break}a[d+4|0]=1;b[d+32>>1]=6}}while(0);if((fa(f|0,117248)|0)==0){a[d|0]=2;b[d+12>>1]=2}if((fa(f|0,114560)|0)==0){l=40855}else{if((fa(f|0,112600)|0)==0){l=40855}}if((l|0)==40855){a[d|0]=2;b[d+12>>1]=4}if((j|0)==0|(k|0)==0){return}a[d|0]=8;m=d+12|0;i=m;b[m>>1]=j&65535;b[m+2>>1]=k&65535;k=d+16|0;if((h|0)==2){b[k>>1]=1792;b[i+6>>1]=0;return}else{b[k>>1]=3584;b[i+6>>1]=10;return}}else{i=(fa(f|0,120104)|0)==0;k=i?19:e?32:0;m=i?33:e?34:0;if((fa(f|0,192464)|0)==0){l=40862}else{if((fa(f|0,186712)|0)==0){l=40862}}if((l|0)==40862){a[d|0]=2;b[d+12>>1]=19}if((fa(f|0,181376)|0)==0){l=40865}else{if((fa(f|0,177240)|0)==0){l=40865}}if((l|0)==40865){a[d|0]=2;b[d+12>>1]=33}if((fa(f|0,173408)|0)==0){l=40868}else{if((fa(f|0,169784)|0)==0){l=40868}}if((l|0)==40868){a[d|0]=2;b[d+12>>1]=32}if((fa(f|0,166840)|0)==0){l=40871}else{if((fa(f|0,164016)|0)==0){l=40871}}if((l|0)==40871){a[d|0]=2;b[d+12>>1]=34}do{if((c[2113210]|0)==4){if((fa(f|0,157168)|0)==0){a[d|0]=2;b[d+12>>1]=27}if((fa(f|0,153656)|0)==0){a[d|0]=2;b[d+12>>1]=17}if((fa(f|0,149688)|0)==0){a[d|0]=2;b[d+12>>1]=18}if((fa(f|0,146480)|0)!=0){break}a[d|0]=2;b[d+12>>1]=26}else{e=a[64256]|0;i=(fa(f|0,157168)|0)==0;if(!e){if(i){a[d|0]=2;b[d+12>>1]=17}if((fa(f|0,153656)|0)==0){a[d|0]=2;b[d+12>>1]=18}if((fa(f|0,149688)|0)==0){a[d|0]=2;b[d+12>>1]=26}if((fa(f|0,146480)|0)==0){a[d|0]=2;b[d+12>>1]=30}if((fa(f|0,142552)|0)==0){a[d|0]=2;b[d+12>>1]=31}if((fa(f|0,139632)|0)!=0){break}a[d|0]=2;b[d+12>>1]=16;break}if(i){a[d|0]=2;b[d+12>>1]=30}if((fa(f|0,153656)|0)==0){a[d|0]=2;b[d+12>>1]=31}if((fa(f|0,149688)|0)==0){a[d|0]=2;b[d+12>>1]=16}if((fa(f|0,146480)|0)==0){a[d|0]=2;b[d+12>>1]=17}if((fa(f|0,142552)|0)==0){a[d|0]=2;b[d+12>>1]=18}if((fa(f|0,139632)|0)==0){a[d|0]=2;b[d+12>>1]=26}if((g&16|0)==0){break}if((gGF(f|0,137024)|0)==0){a[d+4|0]=1;b[d+32>>1]=27}if((gGF(f|0,134648)|0)!=0){break}a[d+4|0]=1;b[d+32>>1]=7}}while(0);if((fa(f|0,117248)|0)==0){a[d|0]=2;b[d+12>>1]=3}if((fa(f|0,114560)|0)==0){l=40915}else{if((fa(f|0,112600)|0)==0){l=40915}}if((l|0)==40915){a[d|0]=2;b[d+12>>1]=5}if((k|0)==0|(m|0)==0){return}a[d|0]=8;l=d+12|0;f=l;b[l>>1]=k&65535;b[l+2>>1]=m&65535;m=d+16|0;if((h|0)==2){b[m>>1]=1792;b[f+6>>1]=0;return}else{b[m>>1]=3584;b[f+6>>1]=10;return}}}function R4(b){b=b|0;var d=0,e=0,f=0,g=0,h=0;d=(b|0)!=0|0;if((c[1839550]|0)==(d|0)){return}c[1839550]=d;b=a[5804e3]|0;if((c[2438060]|0)==(d|0)){e=b?3:0}else{e=b?0:3}b=c[642608+(c[2436]<<2)>>2]|0;d=c[b+128>>2]|0;if((c[b+52>>2]&4|0)==0){c[2440444]=d;f=c[b+132>>2]|0;g=c[2394816]|0;h=g+1|0;c[2394814]=h;c[2394810]=0;if((e|0)==0){c[2394812]=1;c[2394808]=1;return}else if((e|0)==2){c[2394812]=1;c[2394808]=f+~g;return}else if((e|0)==1){c[2394812]=d-1-(ag(a[632536]|0?2:0,h)|0);c[2394808]=1;return}else{c[2394812]=d-1-(ag(a[632536]|0?2:0,h)|0);c[2394808]=f+~g;return}}else{g=c[b+132>>2]|0;c[2440444]=g;c[2394814]=0;b=c[2394816]|0;f=b+1|0;c[2394810]=f;if((e|0)==0){c[2394812]=g+~b;c[2394808]=1;return}else if((e|0)==2){c[2394812]=1;c[2394808]=1;return}else if((e|0)==3){c[2394812]=1;c[2394808]=d-1-(ag(a[632536]|0?2:0,f)|0);return}else{c[2394812]=g+~b;c[2394808]=d-1-(ag(a[632536]|0?2:0,f)|0);return}}}function R5(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;e=c[2394812]|0;f=a[632536]|0;g=f?2:0;if((e|0)<0|f^1){return}f=a[632544]|0;h=f?224:0;i=c[2394816]|0;j=c[2440444]|0;if((e|0)>(j-i|0)){return}k=c[2394808]|0;l=c[2394814]|0;m=c[2394810]|0;n=c[2113308]|0;o=c[2112968]|0;p=c[2432922]|0;q=ag(f?65280:0,c[2433642]|0)|0;f=e;e=0;r=k;while(1){if((c[14114352+(e<<2)>>2]|0)!=0&(i|0)>0){k=0;do{if((i|0)>0){s=o+(ag((ag(j,k+r|0)|0)+f|0,n)|0)|0;t=0;while(1){do{if((n|0)>3){u=s;v=c[u>>2]|0;w=(ag(p,v&16711935)|0)&-16711936;c[u>>2]=(w|(ag(p,v&65280)|0)+q&16711680)>>>8}else{if((n|0)==3){v=s+2|0;w=s+1|0;u=(d[w]|0)<<8;x=ag(p,d[s]|0|(d[v]|0)<<16)|0;y=(ag(u,p)|0)+q|0;a[v]=x>>>24&255;a[w]=y>>>16&255;a[s]=x>>>8&255;break}else if((n|0)==2){b[s>>1]=h;break}else{break}}}while(0);x=t+1|0;if((x|0)<(i|0)){s=s+n|0;t=x}else{break}}}k=k+1|0;}while((k|0)<(i|0))}k=l+f|0;t=e+1|0;if((t|0)>=(g|0)|(k|0)<0){z=40971;break}if((k|0)>(j-i|0)){z=40970;break}else{f=k;e=t;r=m+r|0}}if((z|0)==40970){return}else if((z|0)==40971){return}}function R6(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+128|0;g=f|0;h=f+112|0;j=f+120|0;if((c[3542200]|0)==0){k=1;i=f;return k|0}l=g+108|0;c[l>>2]=0;m=g+100|0;c[m>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,d)|0;if((c[l>>2]|0)==0){k=0;i=f;return k|0}l=c[m>>2]|0;c[h>>2]=9534384;gp[c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]&16383](h,d,0)|0;if((l|0)<1){k=1;i=f;return k|0}do{if((e|0)<2){if((gzL(b,0,d)|0)==0){break}else{k=1}i=f;return k|0}else{c[j>>2]=0;h=gGq(l)|0;if((h|0)==0){k=1;i=f;return k|0}gGz(h|0,0,l|0);if((gzL(h,j,d)|0)!=0){gGr(h);k=1;i=f;return k|0}m=c[j>>2]|0;if((m|0)<0){c[j>>2]=0;n=0}else{n=m}if((n|0)>(l|0)){c[j>>2]=l;o=l}else{o=n}m=h+o|0;g=h;p=b;while(1){q=g+1|0;a[p]=a[g]|0;if(q>>>0<m>>>0){g=q;p=p+e|0}else{break}}gGr(h)}}while(0);k=0;i=f;return k|0}function R7(d,e,f){d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if(a[801640]|(d|0)>3){return}g=c[2112968]|0;h=c[2440576]|0;i=c[2113308]|0;j=g+(ag((ag(h,f-1|0)|0)+e|0,i)|0)|0;g=(d|0)==3?63425:(d|0)==2?5279:(d|0)==1?8163:(d|0)==0?63645:0;d=g&65535;k=(c[2440574]|0)-1|0;l=h-1|0;m=(i|0)==2;n=j;j=0;do{n=n+(ag(h,i)|0)|0;o=j+f|0;if(!((o|0)<0|(o|0)>(k|0))){o=n;p=n;q=0;do{r=q+e|0;do{if(!((r|0)<0|(r|0)>(l|0))){if((a[7462200+(j*18|0)+q|0]|0)==0){break}if(m){b[o+(q<<1)>>1]=d;break}else{c[p+(q<<2)>>2]=g;break}}}while(0);q=q+1|0;}while((q|0)<17)}j=j+1|0;}while((j|0)<17);return}function R8(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=c[2112926]|0;g=c[2112968]|0;c[2112966]=d;h=c[2113308]|0;if((h|0)==2){i=c[2440436]|0;if((i|0)<=0){return}j=c[2443814]|0;k=c[2113300]|0;l=g;m=0;n=f;while(1){if((j|0)>0){o=l;p=0;do{b[o+(p<<1)>>1]=c[d+((e[n+(p<<1)>>1]|0)<<2)>>2]&65535;p=p+1|0;}while((p|0)<(j|0))}p=m+1|0;if((p|0)<(i|0)){l=l+k|0;m=p;n=n+(j<<1)|0}else{break}}return}else if((h|0)==3){j=c[2440436]|0;if((j|0)<=0){return}n=c[2443814]|0;m=c[2113300]|0;k=g;l=0;i=f;while(1){if((n|0)>0){p=0;do{o=c[d+((e[i+(p<<1)>>1]|0)<<2)>>2]|0;q=p*3|0;a[k+q|0]=o&255;a[k+(q+1)|0]=o>>>8&255;a[k+(q+2)|0]=o>>>16&255;p=p+1|0;}while((p|0)<(n|0))}p=l+1|0;if((p|0)<(j|0)){k=k+m|0;l=p;i=i+(n<<1)|0}else{break}}return}else if((h|0)==4){h=c[2440436]|0;if((h|0)<=0){return}n=c[2443814]|0;i=c[2113300]|0;l=g;g=f;f=0;while(1){if((n|0)>0){m=l;k=0;do{c[m+(k<<2)>>2]=c[d+((e[g+(k<<1)>>1]|0)<<2)>>2];k=k+1|0;}while((k|0)<(n|0))}k=f+1|0;if((k|0)<(h|0)){l=l+i|0;g=g+(n<<1)|0;f=k}else{break}}return}else{return}}function R9(a){a=a|0;return 1}function Sa(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0;a=i;i=i+16|0;b=a|0;d=c[2430396]|0;if((d|0)!=0){e=b|0;f=b+4|0;g=b+8|0;h=b+12|0;j=d;do{c[e>>2]=c[j+264>>2];c[f>>2]=c[j+268>>2];c[g>>2]=0;c[h>>2]=j+8;gj[c[2076592]&4095](b)|0;j=c[j>>2]|0;}while((j|0)!=0)}j=c[2443658]|0;if((j|0)!=0){gu[j&16383]()}j=c[2443659]|0;if((j|0)!=0){gu[j&16383]()}j=c[2443660]|0;if((j|0)!=0){gu[j&16383]()}j=c[2443661]|0;if((j|0)!=0){gu[j&16383]()}j=c[2443662]|0;if((j|0)!=0){gu[j&16383]()}j=c[2443663]|0;if((j|0)!=0){gu[j&16383]()}j=c[2443664]|0;if((j|0)!=0){gu[j&16383]()}j=c[2443665]|0;if((j|0)==0){i=a;return}gu[j&16383]();i=a;return}function Sb(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=gGU(a,(a|0)<0|0?-1:0,2048e6,0)|0;a=c[2438228]|0;d=gGS(b,K,a,(a|0)<0|0?-1:0)|0;b=d;c[2443838]=b;if((c[3528512]|0)<(b|0)){e=0;f=b;g=a}else{return}while(1){a=c[2443830]|0;b=c[2443831]|0;d=(a|0)>(b|0)?b:a;a=((d|0)>(f|0)?f:d)+(c[2443846]|0)|0;d=gGU(a,(a|0)<0|0?-1:0,g,(g|0)<0|0?-1:0)|0;a=gGS(d,K,2048e6,0)|0;d=c[2406676]|0;b=a-(gD[c[2433526]&8191]()|0)|0;gj[d&4095](b)|0;b=(gD[c[2433526]&8191]()|0)+1|0;d=gGU(b,(b|0)<0|0?-1:0,2048e6,0)|0;b=c[2438228]|0;a=gGS(d,K,b,(b|0)<0|0?-1:0)|0;b=gGK(a,K,-1,0)|0;a=b;c[3528512]=a;b=c[2443830]|0;if((a|0)<(b|0)){h=0}else{d=c[2443822]|0;c[2443830]=(d|0)==1073676288?1073676288:d+b|0;h=1}b=c[2443831]|0;if((a|0)<(b|0)){i=h}else{a=c[2443823]|0;c[2443831]=(a|0)==1073676288?1073676288:a+b|0;i=h|2}if((i&1|0)==0){j=e}else{j=gA[c[2429844]&16383](0,0)|0|e}if((i&2|0)==0){k=j}else{k=gA[c[2429844]&16383](0,1)|0|j}b=c[2443838]|0;if((c[3528512]|0)>=(b|0)){break}e=k;f=b;g=c[2438228]|0}return}function Sc(a,b,d,e){a=a|0;b=b|0;d=d|0;e=+e;var f=0;gu[c[3528472]&16383]();if((d|0)==0){c[9775320+(b<<2)>>2]=1073676288;return}else{a=9775320+(b<<2)|0;c[a>>2]=~~(+(d|0)*e*2048.0e6);d=gD[c[2433526]&8191]()|0;b=gGU(d,(d|0)<0|0?-1:0,2048e6,0)|0;d=c[2438228]|0;f=gGS(b,K,d,(d|0)<0|0?-1:0)|0;d=gGK(c[a>>2]|0,0,f,K)|0;c[a>>2]=d;return}}function Sd(a,b,d){a=a|0;b=b|0;d=+d;var e=0,f=0;gu[c[3528472]&16383]();if(d==0.0){c[9775320+(b<<2)>>2]=1073676288;c[9775288+(b<<2)>>2]=1073676288;return}else{a=~~(d*2048.0);e=9775320+(b<<2)|0;c[e>>2]=a;c[9775288+(b<<2)>>2]=a;a=gD[c[2433526]&8191]()|0;b=gGU(a,(a|0)<0|0?-1:0,2048e6,0)|0;a=c[2438228]|0;f=gGS(b,K,a,(a|0)<0|0?-1:0)|0;a=gGK(c[e>>2]|0,0,f,K)|0;c[e>>2]=a;return}}function Se(){return+0.0}function Sf(){return(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0}function Sg(){return c[2113158]|0}function Sh(){return c[2113194]|0}function Si(a,e,f,g,h,i,j,k){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0;l=h<<i|j;j=k+(e<<6)|0;c[2112928]=j;e=c[2113068]|0;k=a+((ag(e,g)|0)+f<<1)|0;f=0;g=j;while(1){b[k>>1]=(d[g]|0|l)&65535;b[k+2>>1]=(d[g+1|0]|0|l)&65535;b[k+4>>1]=(d[g+2|0]|0|l)&65535;b[k+6>>1]=(d[g+3|0]|0|l)&65535;b[k+8>>1]=(d[g+4|0]|0|l)&65535;b[k+10>>1]=(d[g+5|0]|0|l)&65535;b[k+12>>1]=(d[g+6|0]|0|l)&65535;b[k+14>>1]=(d[g+7|0]|0|l)&65535;j=f+1|0;m=g+8|0;if((j|0)<8){k=k+(e<<1)|0;f=j;g=m}else{break}}c[2112928]=m;return}function Sj(a,e,f,g,h,i,j,k){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;l=h<<i|j;j=k+(e<<6)|0;c[2112928]=j;e=c[2113068]|0;k=a+((ag(e,g)|0)+f<<1)|0;a=(f|0)>-1;i=f+1|0;h=(i|0)>-1;m=f+2|0;n=(m|0)>-1;o=f+3|0;p=(o|0)>-1;q=f+4|0;r=(q|0)>-1;s=f+5|0;t=(s|0)>-1;u=f+6|0;v=(u|0)>-1;w=f+7|0;x=(w|0)>-1;y=c[2113070]|0;z=k;k=0;A=j;while(1){j=k+g|0;do{if((j|0)>-1&(j|0)<(y|0)){if(a&(e|0)>(f|0)){b[z>>1]=(d[A]|0|l)&65535}if(h&(i|0)<(e|0)){b[z+2>>1]=(d[A+1|0]|0|l)&65535}if(n&(m|0)<(e|0)){b[z+4>>1]=(d[A+2|0]|0|l)&65535}if(p&(o|0)<(e|0)){b[z+6>>1]=(d[A+3|0]|0|l)&65535}if(r&(q|0)<(e|0)){b[z+8>>1]=(d[A+4|0]|0|l)&65535}if(t&(s|0)<(e|0)){b[z+10>>1]=(d[A+5|0]|0|l)&65535}if(v&(u|0)<(e|0)){b[z+12>>1]=(d[A+6|0]|0|l)&65535}if(!(x&(w|0)<(e|0))){break}b[z+14>>1]=(d[A+7|0]|0|l)&65535}}while(0);j=k+1|0;B=A+8|0;if((j|0)>=8){break}z=z+(e<<1)|0;k=j;A=B}c[2112928]=B;return}function Sk(a,e,f,g,h,i,j,k){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0;l=h<<i|j;j=k+(e<<6)|0;c[2112928]=j;e=c[2113068]|0;k=a+((ag(e,g)|0)+f<<1)|0;f=0;g=j;while(1){b[k+14>>1]=(d[g]|0|l)&65535;b[k+12>>1]=(d[g+1|0]|0|l)&65535;b[k+10>>1]=(d[g+2|0]|0|l)&65535;b[k+8>>1]=(d[g+3|0]|0|l)&65535;b[k+6>>1]=(d[g+4|0]|0|l)&65535;b[k+4>>1]=(d[g+5|0]|0|l)&65535;b[k+2>>1]=(d[g+6|0]|0|l)&65535;b[k>>1]=(d[g+7|0]|0|l)&65535;j=f+1|0;m=g+8|0;if((j|0)<8){k=k+(e<<1)|0;f=j;g=m}else{break}}c[2112928]=m;return}function Sl(a,e,f,g,h,i,j,k){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;l=h<<i|j;j=k+(e<<6)|0;c[2112928]=j;e=c[2113068]|0;k=a+((ag(e,g)|0)+f<<1)|0;a=f+7|0;i=(a|0)>-1;h=f+6|0;m=(h|0)>-1;n=f+5|0;o=(n|0)>-1;p=f+4|0;q=(p|0)>-1;r=f+3|0;s=(r|0)>-1;t=f+2|0;u=(t|0)>-1;v=f+1|0;w=(v|0)>-1;x=(f|0)>-1;y=c[2113070]|0;z=k;k=0;A=j;while(1){j=k+g|0;do{if((j|0)>-1&(j|0)<(y|0)){if(i&(a|0)<(e|0)){b[z+14>>1]=(d[A]|0|l)&65535}if(m&(h|0)<(e|0)){b[z+12>>1]=(d[A+1|0]|0|l)&65535}if(o&(n|0)<(e|0)){b[z+10>>1]=(d[A+2|0]|0|l)&65535}if(q&(p|0)<(e|0)){b[z+8>>1]=(d[A+3|0]|0|l)&65535}if(s&(r|0)<(e|0)){b[z+6>>1]=(d[A+4|0]|0|l)&65535}if(u&(t|0)<(e|0)){b[z+4>>1]=(d[A+5|0]|0|l)&65535}if(w&(v|0)<(e|0)){b[z+2>>1]=(d[A+6|0]|0|l)&65535}if(!(x&(e|0)>(f|0))){break}b[z>>1]=(d[A+7|0]|0|l)&65535}}while(0);j=k+1|0;B=A+8|0;if((j|0)>=8){break}z=z+(e<<1)|0;k=j;A=B}c[2112928]=B;return}function Sm(a,e,f,g,h,i,j,k){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0;l=h<<i|j;j=k+(e<<6)|0;c[2112928]=j;e=c[2113068]|0;k=-e|0;i=a+((ag(e,g+7|0)|0)+f<<1)|0;f=7;g=j;while(1){b[i>>1]=(d[g]|0|l)&65535;b[i+2>>1]=(d[g+1|0]|0|l)&65535;b[i+4>>1]=(d[g+2|0]|0|l)&65535;b[i+6>>1]=(d[g+3|0]|0|l)&65535;b[i+8>>1]=(d[g+4|0]|0|l)&65535;b[i+10>>1]=(d[g+5|0]|0|l)&65535;b[i+12>>1]=(d[g+6|0]|0|l)&65535;b[i+14>>1]=(d[g+7|0]|0|l)&65535;m=g+8|0;if((f|0)>0){i=i+(k<<1)|0;f=f-1|0;g=m}else{break}}c[2112928]=m;return}function Sn(a,e,f,g,h,i,j,k){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;l=h<<i|j;j=k+(e<<6)|0;c[2112928]=j;e=c[2113068]|0;k=a+((ag(e,g+7|0)|0)+f<<1)|0;a=(f|0)>-1;i=f+1|0;h=(i|0)>-1;m=f+2|0;n=(m|0)>-1;o=f+3|0;p=(o|0)>-1;q=f+4|0;r=(q|0)>-1;s=f+5|0;t=(s|0)>-1;u=f+6|0;v=(u|0)>-1;w=f+7|0;x=(w|0)>-1;y=c[2113070]|0;z=k;k=7;A=j;while(1){j=k+g|0;do{if((j|0)>-1&(j|0)<(y|0)){if(a&(e|0)>(f|0)){b[z>>1]=(d[A]|0|l)&65535}if(h&(i|0)<(e|0)){b[z+2>>1]=(d[A+1|0]|0|l)&65535}if(n&(m|0)<(e|0)){b[z+4>>1]=(d[A+2|0]|0|l)&65535}if(p&(o|0)<(e|0)){b[z+6>>1]=(d[A+3|0]|0|l)&65535}if(r&(q|0)<(e|0)){b[z+8>>1]=(d[A+4|0]|0|l)&65535}if(t&(s|0)<(e|0)){b[z+10>>1]=(d[A+5|0]|0|l)&65535}if(v&(u|0)<(e|0)){b[z+12>>1]=(d[A+6|0]|0|l)&65535}if(!(x&(w|0)<(e|0))){break}b[z+14>>1]=(d[A+7|0]|0|l)&65535}}while(0);B=A+8|0;if((k|0)<=0){break}z=z+(-e<<1)|0;k=k-1|0;A=B}c[2112928]=B;return}function So(a,e,f,g,h,i,j,k){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0;l=h<<i|j;j=k+(e<<6)|0;c[2112928]=j;e=c[2113068]|0;k=-e|0;i=a+((ag(e,g+7|0)|0)+f<<1)|0;f=7;g=j;while(1){b[i+14>>1]=(d[g]|0|l)&65535;b[i+12>>1]=(d[g+1|0]|0|l)&65535;b[i+10>>1]=(d[g+2|0]|0|l)&65535;b[i+8>>1]=(d[g+3|0]|0|l)&65535;b[i+6>>1]=(d[g+4|0]|0|l)&65535;b[i+4>>1]=(d[g+5|0]|0|l)&65535;b[i+2>>1]=(d[g+6|0]|0|l)&65535;b[i>>1]=(d[g+7|0]|0|l)&65535;m=g+8|0;if((f|0)>0){i=i+(k<<1)|0;f=f-1|0;g=m}else{break}}c[2112928]=m;return}function Sp(a,e,f,g,h,i,j,k){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;l=h<<i|j;j=k+(e<<6)|0;c[2112928]=j;e=c[2113068]|0;k=a+((ag(e,g+7|0)|0)+f<<1)|0;a=f+7|0;i=(a|0)>-1;h=f+6|0;m=(h|0)>-1;n=f+5|0;o=(n|0)>-1;p=f+4|0;q=(p|0)>-1;r=f+3|0;s=(r|0)>-1;t=f+2|0;u=(t|0)>-1;v=f+1|0;w=(v|0)>-1;x=(f|0)>-1;y=c[2113070]|0;z=k;k=7;A=j;while(1){j=k+g|0;do{if((j|0)>-1&(j|0)<(y|0)){if(i&(a|0)<(e|0)){b[z+14>>1]=(d[A]|0|l)&65535}if(m&(h|0)<(e|0)){b[z+12>>1]=(d[A+1|0]|0|l)&65535}if(o&(n|0)<(e|0)){b[z+10>>1]=(d[A+2|0]|0|l)&65535}if(q&(p|0)<(e|0)){b[z+8>>1]=(d[A+3|0]|0|l)&65535}if(s&(r|0)<(e|0)){b[z+6>>1]=(d[A+4|0]|0|l)&65535}if(u&(t|0)<(e|0)){b[z+4>>1]=(d[A+5|0]|0|l)&65535}if(w&(v|0)<(e|0)){b[z+2>>1]=(d[A+6|0]|0|l)&65535}if(!(x&(e|0)>(f|0))){break}b[z>>1]=(d[A+7|0]|0|l)&65535}}while(0);B=A+8|0;if((k|0)<=0){break}z=z+(-e<<1)|0;k=k-1|0;A=B}c[2112928]=B;return}function Sq(a,e,f,g,h,i,j,k,l){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0;m=h<<i|k;k=l+(e<<6)|0;c[2112928]=k;e=c[2113068]|0;l=a+((ag(e,g)|0)+f<<1)|0;f=0;g=k;while(1){k=d[g]|0;if((k|0)!=(j|0)){b[l>>1]=(k|m)&65535}k=d[g+1|0]|0;if((k|0)!=(j|0)){b[l+2>>1]=(k|m)&65535}k=d[g+2|0]|0;if((k|0)!=(j|0)){b[l+4>>1]=(k|m)&65535}k=d[g+3|0]|0;if((k|0)!=(j|0)){b[l+6>>1]=(k|m)&65535}k=d[g+4|0]|0;if((k|0)!=(j|0)){b[l+8>>1]=(k|m)&65535}k=d[g+5|0]|0;if((k|0)!=(j|0)){b[l+10>>1]=(k|m)&65535}k=d[g+6|0]|0;if((k|0)!=(j|0)){b[l+12>>1]=(k|m)&65535}k=d[g+7|0]|0;if((k|0)!=(j|0)){b[l+14>>1]=(k|m)&65535}k=f+1|0;n=g+8|0;if((k|0)<8){l=l+(e<<1)|0;f=k;g=n}else{break}}c[2112928]=n;return}function Sr(a,e,f,g,h,i,j,k,l){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;m=h<<i|k;k=l+(e<<6)|0;c[2112928]=k;e=c[2113068]|0;l=a+((ag(e,g)|0)+f<<1)|0;a=(f|0)>-1;i=f+1|0;h=(i|0)>-1;n=f+2|0;o=(n|0)>-1;p=f+3|0;q=(p|0)>-1;r=f+4|0;s=(r|0)>-1;t=f+5|0;u=(t|0)>-1;v=f+6|0;w=(v|0)>-1;x=f+7|0;y=(x|0)>-1;z=c[2113070]|0;A=l;l=0;B=k;while(1){k=l+g|0;do{if((k|0)>-1&(k|0)<(z|0)){do{if(a&(e|0)>(f|0)){C=d[B]|0;if((C|0)==(j|0)){break}b[A>>1]=(C|m)&65535}}while(0);do{if(h&(i|0)<(e|0)){C=d[B+1|0]|0;if((C|0)==(j|0)){break}b[A+2>>1]=(C|m)&65535}}while(0);do{if(o&(n|0)<(e|0)){C=d[B+2|0]|0;if((C|0)==(j|0)){break}b[A+4>>1]=(C|m)&65535}}while(0);do{if(q&(p|0)<(e|0)){C=d[B+3|0]|0;if((C|0)==(j|0)){break}b[A+6>>1]=(C|m)&65535}}while(0);do{if(s&(r|0)<(e|0)){C=d[B+4|0]|0;if((C|0)==(j|0)){break}b[A+8>>1]=(C|m)&65535}}while(0);do{if(u&(t|0)<(e|0)){C=d[B+5|0]|0;if((C|0)==(j|0)){break}b[A+10>>1]=(C|m)&65535}}while(0);do{if(w&(v|0)<(e|0)){C=d[B+6|0]|0;if((C|0)==(j|0)){break}b[A+12>>1]=(C|m)&65535}}while(0);if(!(y&(x|0)<(e|0))){break}C=d[B+7|0]|0;if((C|0)==(j|0)){break}b[A+14>>1]=(C|m)&65535}}while(0);k=l+1|0;D=B+8|0;if((k|0)>=8){break}A=A+(e<<1)|0;l=k;B=D}c[2112928]=D;return}function Ss(a,e,f,g,h,i,j,k,l){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0;m=h<<i|k;k=l+(e<<6)|0;c[2112928]=k;e=c[2113068]|0;l=a+((ag(e,g)|0)+f<<1)|0;f=0;g=k;while(1){k=d[g]|0;if((k|0)!=(j|0)){b[l+14>>1]=(k|m)&65535}k=d[g+1|0]|0;if((k|0)!=(j|0)){b[l+12>>1]=(k|m)&65535}k=d[g+2|0]|0;if((k|0)!=(j|0)){b[l+10>>1]=(k|m)&65535}k=d[g+3|0]|0;if((k|0)!=(j|0)){b[l+8>>1]=(k|m)&65535}k=d[g+4|0]|0;if((k|0)!=(j|0)){b[l+6>>1]=(k|m)&65535}k=d[g+5|0]|0;if((k|0)!=(j|0)){b[l+4>>1]=(k|m)&65535}k=d[g+6|0]|0;if((k|0)!=(j|0)){b[l+2>>1]=(k|m)&65535}k=d[g+7|0]|0;if((k|0)!=(j|0)){b[l>>1]=(k|m)&65535}k=f+1|0;n=g+8|0;if((k|0)<8){l=l+(e<<1)|0;f=k;g=n}else{break}}c[2112928]=n;return}function St(a,e,f,g,h,i,j,k,l){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;m=h<<i|k;k=l+(e<<6)|0;c[2112928]=k;e=c[2113068]|0;l=a+((ag(e,g)|0)+f<<1)|0;a=f+7|0;i=(a|0)>-1;h=f+6|0;n=(h|0)>-1;o=f+5|0;p=(o|0)>-1;q=f+4|0;r=(q|0)>-1;s=f+3|0;t=(s|0)>-1;u=f+2|0;v=(u|0)>-1;w=f+1|0;x=(w|0)>-1;y=(f|0)>-1;z=c[2113070]|0;A=l;l=0;B=k;while(1){k=l+g|0;do{if((k|0)>-1&(k|0)<(z|0)){do{if(i&(a|0)<(e|0)){C=d[B]|0;if((C|0)==(j|0)){break}b[A+14>>1]=(C|m)&65535}}while(0);do{if(n&(h|0)<(e|0)){C=d[B+1|0]|0;if((C|0)==(j|0)){break}b[A+12>>1]=(C|m)&65535}}while(0);do{if(p&(o|0)<(e|0)){C=d[B+2|0]|0;if((C|0)==(j|0)){break}b[A+10>>1]=(C|m)&65535}}while(0);do{if(r&(q|0)<(e|0)){C=d[B+3|0]|0;if((C|0)==(j|0)){break}b[A+8>>1]=(C|m)&65535}}while(0);do{if(t&(s|0)<(e|0)){C=d[B+4|0]|0;if((C|0)==(j|0)){break}b[A+6>>1]=(C|m)&65535}}while(0);do{if(v&(u|0)<(e|0)){C=d[B+5|0]|0;if((C|0)==(j|0)){break}b[A+4>>1]=(C|m)&65535}}while(0);do{if(x&(w|0)<(e|0)){C=d[B+6|0]|0;if((C|0)==(j|0)){break}b[A+2>>1]=(C|m)&65535}}while(0);if(!(y&(e|0)>(f|0))){break}C=d[B+7|0]|0;if((C|0)==(j|0)){break}b[A>>1]=(C|m)&65535}}while(0);k=l+1|0;D=B+8|0;if((k|0)>=8){break}A=A+(e<<1)|0;l=k;B=D}c[2112928]=D;return}function Su(a,e,f,g,h,i,j,k,l){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0;m=h<<i|k;k=l+(e<<6)|0;c[2112928]=k;e=c[2113068]|0;l=-e|0;i=a+((ag(e,g+7|0)|0)+f<<1)|0;f=7;g=k;while(1){k=d[g]|0;if((k|0)!=(j|0)){b[i>>1]=(k|m)&65535}k=d[g+1|0]|0;if((k|0)!=(j|0)){b[i+2>>1]=(k|m)&65535}k=d[g+2|0]|0;if((k|0)!=(j|0)){b[i+4>>1]=(k|m)&65535}k=d[g+3|0]|0;if((k|0)!=(j|0)){b[i+6>>1]=(k|m)&65535}k=d[g+4|0]|0;if((k|0)!=(j|0)){b[i+8>>1]=(k|m)&65535}k=d[g+5|0]|0;if((k|0)!=(j|0)){b[i+10>>1]=(k|m)&65535}k=d[g+6|0]|0;if((k|0)!=(j|0)){b[i+12>>1]=(k|m)&65535}k=d[g+7|0]|0;if((k|0)!=(j|0)){b[i+14>>1]=(k|m)&65535}n=g+8|0;if((f|0)>0){i=i+(l<<1)|0;f=f-1|0;g=n}else{break}}c[2112928]=n;return}function Sv(a,e,f,g,h,i,j,k,l){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;m=h<<i|k;k=l+(e<<6)|0;c[2112928]=k;e=c[2113068]|0;l=a+((ag(e,g+7|0)|0)+f<<1)|0;a=(f|0)>-1;i=f+1|0;h=(i|0)>-1;n=f+2|0;o=(n|0)>-1;p=f+3|0;q=(p|0)>-1;r=f+4|0;s=(r|0)>-1;t=f+5|0;u=(t|0)>-1;v=f+6|0;w=(v|0)>-1;x=f+7|0;y=(x|0)>-1;z=c[2113070]|0;A=l;l=7;B=k;while(1){k=l+g|0;do{if((k|0)>-1&(k|0)<(z|0)){do{if(a&(e|0)>(f|0)){C=d[B]|0;if((C|0)==(j|0)){break}b[A>>1]=(C|m)&65535}}while(0);do{if(h&(i|0)<(e|0)){C=d[B+1|0]|0;if((C|0)==(j|0)){break}b[A+2>>1]=(C|m)&65535}}while(0);do{if(o&(n|0)<(e|0)){C=d[B+2|0]|0;if((C|0)==(j|0)){break}b[A+4>>1]=(C|m)&65535}}while(0);do{if(q&(p|0)<(e|0)){C=d[B+3|0]|0;if((C|0)==(j|0)){break}b[A+6>>1]=(C|m)&65535}}while(0);do{if(s&(r|0)<(e|0)){C=d[B+4|0]|0;if((C|0)==(j|0)){break}b[A+8>>1]=(C|m)&65535}}while(0);do{if(u&(t|0)<(e|0)){C=d[B+5|0]|0;if((C|0)==(j|0)){break}b[A+10>>1]=(C|m)&65535}}while(0);do{if(w&(v|0)<(e|0)){C=d[B+6|0]|0;if((C|0)==(j|0)){break}b[A+12>>1]=(C|m)&65535}}while(0);if(!(y&(x|0)<(e|0))){break}C=d[B+7|0]|0;if((C|0)==(j|0)){break}b[A+14>>1]=(C|m)&65535}}while(0);D=B+8|0;if((l|0)<=0){break}A=A+(-e<<1)|0;l=l-1|0;B=D}c[2112928]=D;return}function Sw(a,e,f,g,h,i,j,k,l){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0;m=h<<i|k;k=l+(e<<6)|0;c[2112928]=k;e=c[2113068]|0;l=-e|0;i=a+((ag(e,g+7|0)|0)+f<<1)|0;f=7;g=k;while(1){k=d[g]|0;if((k|0)!=(j|0)){b[i+14>>1]=(k|m)&65535}k=d[g+1|0]|0;if((k|0)!=(j|0)){b[i+12>>1]=(k|m)&65535}k=d[g+2|0]|0;if((k|0)!=(j|0)){b[i+10>>1]=(k|m)&65535}k=d[g+3|0]|0;if((k|0)!=(j|0)){b[i+8>>1]=(k|m)&65535}k=d[g+4|0]|0;if((k|0)!=(j|0)){b[i+6>>1]=(k|m)&65535}k=d[g+5|0]|0;if((k|0)!=(j|0)){b[i+4>>1]=(k|m)&65535}k=d[g+6|0]|0;if((k|0)!=(j|0)){b[i+2>>1]=(k|m)&65535}k=d[g+7|0]|0;if((k|0)!=(j|0)){b[i>>1]=(k|m)&65535}n=g+8|0;if((f|0)>0){i=i+(l<<1)|0;f=f-1|0;g=n}else{break}}c[2112928]=n;return}function Sx(a,e,f,g,h,i,j,k,l){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;m=h<<i|k;k=l+(e<<6)|0;c[2112928]=k;e=c[2113068]|0;l=a+((ag(e,g+7|0)|0)+f<<1)|0;a=f+7|0;i=(a|0)>-1;h=f+6|0;n=(h|0)>-1;o=f+5|0;p=(o|0)>-1;q=f+4|0;r=(q|0)>-1;s=f+3|0;t=(s|0)>-1;u=f+2|0;v=(u|0)>-1;w=f+1|0;x=(w|0)>-1;y=(f|0)>-1;z=c[2113070]|0;A=l;l=7;B=k;while(1){k=l+g|0;do{if((k|0)>-1&(k|0)<(z|0)){do{if(i&(a|0)<(e|0)){C=d[B]|0;if((C|0)==(j|0)){break}b[A+14>>1]=(C|m)&65535}}while(0);do{if(n&(h|0)<(e|0)){C=d[B+1|0]|0;if((C|0)==(j|0)){break}b[A+12>>1]=(C|m)&65535}}while(0);do{if(p&(o|0)<(e|0)){C=d[B+2|0]|0;if((C|0)==(j|0)){break}b[A+10>>1]=(C|m)&65535}}while(0);do{if(r&(q|0)<(e|0)){C=d[B+3|0]|0;if((C|0)==(j|0)){break}b[A+8>>1]=(C|m)&65535}}while(0);do{if(t&(s|0)<(e|0)){C=d[B+4|0]|0;if((C|0)==(j|0)){break}b[A+6>>1]=(C|m)&65535}}while(0);do{if(v&(u|0)<(e|0)){C=d[B+5|0]|0;if((C|0)==(j|0)){break}b[A+4>>1]=(C|m)&65535}}while(0);do{if(x&(w|0)<(e|0)){C=d[B+6|0]|0;if((C|0)==(j|0)){break}b[A+2>>1]=(C|m)&65535}}while(0);if(!(y&(e|0)>(f|0))){break}C=d[B+7|0]|0;if((C|0)==(j|0)){break}b[A>>1]=(C|m)&65535}}while(0);D=B+8|0;if((l|0)<=0){break}A=A+(-e<<1)|0;l=l-1|0;B=D}c[2112928]=D;return}function Sy(a,e,f,g,h,i,j,k){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0;l=h<<i|j;j=k+(e<<8)|0;c[2112928]=j;e=c[2113068]|0;k=a+((ag(e,g)|0)+f<<1)|0;f=0;g=j;while(1){b[k>>1]=(d[g]|0|l)&65535;b[k+2>>1]=(d[g+1|0]|0|l)&65535;b[k+4>>1]=(d[g+2|0]|0|l)&65535;b[k+6>>1]=(d[g+3|0]|0|l)&65535;b[k+8>>1]=(d[g+4|0]|0|l)&65535;b[k+10>>1]=(d[g+5|0]|0|l)&65535;b[k+12>>1]=(d[g+6|0]|0|l)&65535;b[k+14>>1]=(d[g+7|0]|0|l)&65535;b[k+16>>1]=(d[g+8|0]|0|l)&65535;b[k+18>>1]=(d[g+9|0]|0|l)&65535;b[k+20>>1]=(d[g+10|0]|0|l)&65535;b[k+22>>1]=(d[g+11|0]|0|l)&65535;b[k+24>>1]=(d[g+12|0]|0|l)&65535;b[k+26>>1]=(d[g+13|0]|0|l)&65535;b[k+28>>1]=(d[g+14|0]|0|l)&65535;b[k+30>>1]=(d[g+15|0]|0|l)&65535;j=f+1|0;m=g+16|0;if((j|0)<16){k=k+(e<<1)|0;f=j;g=m}else{break}}c[2112928]=m;return}function Sz(a,e,f,g,h,i,j,k){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0;l=h<<i|j;j=k+(e<<8)|0;c[2112928]=j;e=c[2113068]|0;k=a+((ag(e,g)|0)+f<<1)|0;a=(f|0)>-1;i=f+1|0;h=(i|0)>-1;m=f+2|0;n=(m|0)>-1;o=f+3|0;p=(o|0)>-1;q=f+4|0;r=(q|0)>-1;s=f+5|0;t=(s|0)>-1;u=f+6|0;v=(u|0)>-1;w=f+7|0;x=(w|0)>-1;y=f+8|0;z=(y|0)>-1;A=f+9|0;B=(A|0)>-1;C=f+10|0;D=(C|0)>-1;E=f+11|0;F=(E|0)>-1;G=f+12|0;H=(G|0)>-1;I=f+13|0;J=(I|0)>-1;K=f+14|0;L=(K|0)>-1;M=f+15|0;N=(M|0)>-1;O=c[2113070]|0;P=k;k=0;Q=e;R=j;while(1){j=k+g|0;do{if((j|0)>-1&(j|0)<(O|0)){if(a&(Q|0)>(f|0)){b[P>>1]=(d[R]|0|l)&65535;S=e}else{S=Q}if(h&(i|0)<(S|0)){b[P+2>>1]=(d[R+1|0]|0|l)&65535;T=e}else{T=S}if(n&(m|0)<(T|0)){b[P+4>>1]=(d[R+2|0]|0|l)&65535;U=e}else{U=T}if(p&(o|0)<(U|0)){b[P+6>>1]=(d[R+3|0]|0|l)&65535;V=e}else{V=U}if(r&(q|0)<(V|0)){b[P+8>>1]=(d[R+4|0]|0|l)&65535;W=e}else{W=V}if(t&(s|0)<(W|0)){b[P+10>>1]=(d[R+5|0]|0|l)&65535;X=e}else{X=W}if(v&(u|0)<(X|0)){b[P+12>>1]=(d[R+6|0]|0|l)&65535;Y=e}else{Y=X}if(x&(w|0)<(Y|0)){b[P+14>>1]=(d[R+7|0]|0|l)&65535;Z=e}else{Z=Y}if(z&(y|0)<(Z|0)){b[P+16>>1]=(d[R+8|0]|0|l)&65535;_=e}else{_=Z}if(B&(A|0)<(_|0)){b[P+18>>1]=(d[R+9|0]|0|l)&65535;$=e}else{$=_}if(D&(C|0)<($|0)){b[P+20>>1]=(d[R+10|0]|0|l)&65535;aa=e}else{aa=$}if(F&(E|0)<(aa|0)){b[P+22>>1]=(d[R+11|0]|0|l)&65535;ab=e}else{ab=aa}if(H&(G|0)<(ab|0)){b[P+24>>1]=(d[R+12|0]|0|l)&65535;ac=e}else{ac=ab}if(J&(I|0)<(ac|0)){b[P+26>>1]=(d[R+13|0]|0|l)&65535;ad=e}else{ad=ac}if(L&(K|0)<(ad|0)){b[P+28>>1]=(d[R+14|0]|0|l)&65535;ae=e}else{ae=ad}if(!(N&(M|0)<(ae|0))){af=ae;break}b[P+30>>1]=(d[R+15|0]|0|l)&65535;af=e}else{af=Q}}while(0);j=k+1|0;ah=R+16|0;if((j|0)>=16){break}P=P+(af<<1)|0;k=j;Q=af;R=ah}c[2112928]=ah;return}function SA(a,e,f,g,h,i,j,k){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0;l=h<<i|j;j=k+(e<<8)|0;c[2112928]=j;e=c[2113068]|0;k=a+((ag(e,g)|0)+f<<1)|0;f=0;g=j;while(1){b[k+30>>1]=(d[g]|0|l)&65535;b[k+28>>1]=(d[g+1|0]|0|l)&65535;b[k+26>>1]=(d[g+2|0]|0|l)&65535;b[k+24>>1]=(d[g+3|0]|0|l)&65535;b[k+22>>1]=(d[g+4|0]|0|l)&65535;b[k+20>>1]=(d[g+5|0]|0|l)&65535;b[k+18>>1]=(d[g+6|0]|0|l)&65535;b[k+16>>1]=(d[g+7|0]|0|l)&65535;b[k+14>>1]=(d[g+8|0]|0|l)&65535;b[k+12>>1]=(d[g+9|0]|0|l)&65535;b[k+10>>1]=(d[g+10|0]|0|l)&65535;b[k+8>>1]=(d[g+11|0]|0|l)&65535;b[k+6>>1]=(d[g+12|0]|0|l)&65535;b[k+4>>1]=(d[g+13|0]|0|l)&65535;b[k+2>>1]=(d[g+14|0]|0|l)&65535;b[k>>1]=(d[g+15|0]|0|l)&65535;j=f+1|0;m=g+16|0;if((j|0)<16){k=k+(e<<1)|0;f=j;g=m}else{break}}c[2112928]=m;return}function SB(a,e,f,g,h,i,j,k){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0;l=h<<i|j;j=k+(e<<8)|0;c[2112928]=j;e=c[2113068]|0;k=a+((ag(e,g)|0)+f<<1)|0;a=f+15|0;i=(a|0)>-1;h=f+14|0;m=(h|0)>-1;n=f+13|0;o=(n|0)>-1;p=f+12|0;q=(p|0)>-1;r=f+11|0;s=(r|0)>-1;t=f+10|0;u=(t|0)>-1;v=f+9|0;w=(v|0)>-1;x=f+8|0;y=(x|0)>-1;z=f+7|0;A=(z|0)>-1;B=f+6|0;C=(B|0)>-1;D=f+5|0;E=(D|0)>-1;F=f+4|0;G=(F|0)>-1;H=f+3|0;I=(H|0)>-1;J=f+2|0;K=(J|0)>-1;L=f+1|0;M=(L|0)>-1;N=(f|0)>-1;O=c[2113070]|0;P=k;k=0;Q=e;R=j;while(1){j=k+g|0;do{if((j|0)>-1&(j|0)<(O|0)){if(i&(a|0)<(Q|0)){b[P+30>>1]=(d[R]|0|l)&65535;S=e}else{S=Q}if(m&(h|0)<(S|0)){b[P+28>>1]=(d[R+1|0]|0|l)&65535;T=e}else{T=S}if(o&(n|0)<(T|0)){b[P+26>>1]=(d[R+2|0]|0|l)&65535;U=e}else{U=T}if(q&(p|0)<(U|0)){b[P+24>>1]=(d[R+3|0]|0|l)&65535;V=e}else{V=U}if(s&(r|0)<(V|0)){b[P+22>>1]=(d[R+4|0]|0|l)&65535;W=e}else{W=V}if(u&(t|0)<(W|0)){b[P+20>>1]=(d[R+5|0]|0|l)&65535;X=e}else{X=W}if(w&(v|0)<(X|0)){b[P+18>>1]=(d[R+6|0]|0|l)&65535;Y=e}else{Y=X}if(y&(x|0)<(Y|0)){b[P+16>>1]=(d[R+7|0]|0|l)&65535;Z=e}else{Z=Y}if(A&(z|0)<(Z|0)){b[P+14>>1]=(d[R+8|0]|0|l)&65535;_=e}else{_=Z}if(C&(B|0)<(_|0)){b[P+12>>1]=(d[R+9|0]|0|l)&65535;$=e}else{$=_}if(E&(D|0)<($|0)){b[P+10>>1]=(d[R+10|0]|0|l)&65535;aa=e}else{aa=$}if(G&(F|0)<(aa|0)){b[P+8>>1]=(d[R+11|0]|0|l)&65535;ab=e}else{ab=aa}if(I&(H|0)<(ab|0)){b[P+6>>1]=(d[R+12|0]|0|l)&65535;ac=e}else{ac=ab}if(K&(J|0)<(ac|0)){b[P+4>>1]=(d[R+13|0]|0|l)&65535;ad=e}else{ad=ac}if(M&(L|0)<(ad|0)){b[P+2>>1]=(d[R+14|0]|0|l)&65535;ae=e}else{ae=ad}if(!(N&(ae|0)>(f|0))){af=ae;break}b[P>>1]=(d[R+15|0]|0|l)&65535;af=e}else{af=Q}}while(0);j=k+1|0;ah=R+16|0;if((j|0)>=16){break}P=P+(af<<1)|0;k=j;Q=af;R=ah}c[2112928]=ah;return}function SC(a,e,f,g,h,i,j,k){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0;l=h<<i|j;j=k+(e<<8)|0;c[2112928]=j;e=c[2113068]|0;k=-e|0;i=a+((ag(e,g+15|0)|0)+f<<1)|0;f=15;g=j;while(1){b[i>>1]=(d[g]|0|l)&65535;b[i+2>>1]=(d[g+1|0]|0|l)&65535;b[i+4>>1]=(d[g+2|0]|0|l)&65535;b[i+6>>1]=(d[g+3|0]|0|l)&65535;b[i+8>>1]=(d[g+4|0]|0|l)&65535;b[i+10>>1]=(d[g+5|0]|0|l)&65535;b[i+12>>1]=(d[g+6|0]|0|l)&65535;b[i+14>>1]=(d[g+7|0]|0|l)&65535;b[i+16>>1]=(d[g+8|0]|0|l)&65535;b[i+18>>1]=(d[g+9|0]|0|l)&65535;b[i+20>>1]=(d[g+10|0]|0|l)&65535;b[i+22>>1]=(d[g+11|0]|0|l)&65535;b[i+24>>1]=(d[g+12|0]|0|l)&65535;b[i+26>>1]=(d[g+13|0]|0|l)&65535;b[i+28>>1]=(d[g+14|0]|0|l)&65535;b[i+30>>1]=(d[g+15|0]|0|l)&65535;m=g+16|0;if((f|0)>0){i=i+(k<<1)|0;f=f-1|0;g=m}else{break}}c[2112928]=m;return}function SD(a,e,f,g,h,i,j,k){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0;l=h<<i|j;j=k+(e<<8)|0;c[2112928]=j;e=c[2113068]|0;k=a+((ag(e,g+15|0)|0)+f<<1)|0;a=(f|0)>-1;i=f+1|0;h=(i|0)>-1;m=f+2|0;n=(m|0)>-1;o=f+3|0;p=(o|0)>-1;q=f+4|0;r=(q|0)>-1;s=f+5|0;t=(s|0)>-1;u=f+6|0;v=(u|0)>-1;w=f+7|0;x=(w|0)>-1;y=f+8|0;z=(y|0)>-1;A=f+9|0;B=(A|0)>-1;C=f+10|0;D=(C|0)>-1;E=f+11|0;F=(E|0)>-1;G=f+12|0;H=(G|0)>-1;I=f+13|0;J=(I|0)>-1;K=f+14|0;L=(K|0)>-1;M=f+15|0;N=(M|0)>-1;O=c[2113070]|0;P=k;k=15;Q=e;R=j;while(1){j=k+g|0;do{if((j|0)>-1&(j|0)<(O|0)){if(a&(Q|0)>(f|0)){b[P>>1]=(d[R]|0|l)&65535;S=e}else{S=Q}if(h&(i|0)<(S|0)){b[P+2>>1]=(d[R+1|0]|0|l)&65535;T=e}else{T=S}if(n&(m|0)<(T|0)){b[P+4>>1]=(d[R+2|0]|0|l)&65535;U=e}else{U=T}if(p&(o|0)<(U|0)){b[P+6>>1]=(d[R+3|0]|0|l)&65535;V=e}else{V=U}if(r&(q|0)<(V|0)){b[P+8>>1]=(d[R+4|0]|0|l)&65535;W=e}else{W=V}if(t&(s|0)<(W|0)){b[P+10>>1]=(d[R+5|0]|0|l)&65535;X=e}else{X=W}if(v&(u|0)<(X|0)){b[P+12>>1]=(d[R+6|0]|0|l)&65535;Y=e}else{Y=X}if(x&(w|0)<(Y|0)){b[P+14>>1]=(d[R+7|0]|0|l)&65535;Z=e}else{Z=Y}if(z&(y|0)<(Z|0)){b[P+16>>1]=(d[R+8|0]|0|l)&65535;_=e}else{_=Z}if(B&(A|0)<(_|0)){b[P+18>>1]=(d[R+9|0]|0|l)&65535;$=e}else{$=_}if(D&(C|0)<($|0)){b[P+20>>1]=(d[R+10|0]|0|l)&65535;aa=e}else{aa=$}if(F&(E|0)<(aa|0)){b[P+22>>1]=(d[R+11|0]|0|l)&65535;ab=e}else{ab=aa}if(H&(G|0)<(ab|0)){b[P+24>>1]=(d[R+12|0]|0|l)&65535;ac=e}else{ac=ab}if(J&(I|0)<(ac|0)){b[P+26>>1]=(d[R+13|0]|0|l)&65535;ad=e}else{ad=ac}if(L&(K|0)<(ad|0)){b[P+28>>1]=(d[R+14|0]|0|l)&65535;ae=e}else{ae=ad}if(!(N&(M|0)<(ae|0))){af=ae;break}b[P+30>>1]=(d[R+15|0]|0|l)&65535;af=e}else{af=Q}}while(0);ah=R+16|0;if((k|0)<=0){break}P=P+(-af<<1)|0;k=k-1|0;Q=af;R=ah}c[2112928]=ah;return}function SE(a,e,f,g,h,i,j,k){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0;l=h<<i|j;j=k+(e<<8)|0;c[2112928]=j;e=c[2113068]|0;k=-e|0;i=a+((ag(e,g+15|0)|0)+f<<1)|0;f=15;g=j;while(1){b[i+30>>1]=(d[g]|0|l)&65535;b[i+28>>1]=(d[g+1|0]|0|l)&65535;b[i+26>>1]=(d[g+2|0]|0|l)&65535;b[i+24>>1]=(d[g+3|0]|0|l)&65535;b[i+22>>1]=(d[g+4|0]|0|l)&65535;b[i+20>>1]=(d[g+5|0]|0|l)&65535;b[i+18>>1]=(d[g+6|0]|0|l)&65535;b[i+16>>1]=(d[g+7|0]|0|l)&65535;b[i+14>>1]=(d[g+8|0]|0|l)&65535;b[i+12>>1]=(d[g+9|0]|0|l)&65535;b[i+10>>1]=(d[g+10|0]|0|l)&65535;b[i+8>>1]=(d[g+11|0]|0|l)&65535;b[i+6>>1]=(d[g+12|0]|0|l)&65535;b[i+4>>1]=(d[g+13|0]|0|l)&65535;b[i+2>>1]=(d[g+14|0]|0|l)&65535;b[i>>1]=(d[g+15|0]|0|l)&65535;m=g+16|0;if((f|0)>0){i=i+(k<<1)|0;f=f-1|0;g=m}else{break}}c[2112928]=m;return}function SF(a,e,f,g,h,i,j,k){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0;l=h<<i|j;j=k+(e<<8)|0;c[2112928]=j;e=c[2113068]|0;k=a+((ag(e,g+15|0)|0)+f<<1)|0;a=f+15|0;i=(a|0)>-1;h=f+14|0;m=(h|0)>-1;n=f+13|0;o=(n|0)>-1;p=f+12|0;q=(p|0)>-1;r=f+11|0;s=(r|0)>-1;t=f+10|0;u=(t|0)>-1;v=f+9|0;w=(v|0)>-1;x=f+8|0;y=(x|0)>-1;z=f+7|0;A=(z|0)>-1;B=f+6|0;C=(B|0)>-1;D=f+5|0;E=(D|0)>-1;F=f+4|0;G=(F|0)>-1;H=f+3|0;I=(H|0)>-1;J=f+2|0;K=(J|0)>-1;L=f+1|0;M=(L|0)>-1;N=(f|0)>-1;O=c[2113070]|0;P=k;k=15;Q=e;R=j;while(1){j=k+g|0;do{if((j|0)>-1&(j|0)<(O|0)){if(i&(a|0)<(Q|0)){b[P+30>>1]=(d[R]|0|l)&65535;S=e}else{S=Q}if(m&(h|0)<(S|0)){b[P+28>>1]=(d[R+1|0]|0|l)&65535;T=e}else{T=S}if(o&(n|0)<(T|0)){b[P+26>>1]=(d[R+2|0]|0|l)&65535;U=e}else{U=T}if(q&(p|0)<(U|0)){b[P+24>>1]=(d[R+3|0]|0|l)&65535;V=e}else{V=U}if(s&(r|0)<(V|0)){b[P+22>>1]=(d[R+4|0]|0|l)&65535;W=e}else{W=V}if(u&(t|0)<(W|0)){b[P+20>>1]=(d[R+5|0]|0|l)&65535;X=e}else{X=W}if(w&(v|0)<(X|0)){b[P+18>>1]=(d[R+6|0]|0|l)&65535;Y=e}else{Y=X}if(y&(x|0)<(Y|0)){b[P+16>>1]=(d[R+7|0]|0|l)&65535;Z=e}else{Z=Y}if(A&(z|0)<(Z|0)){b[P+14>>1]=(d[R+8|0]|0|l)&65535;_=e}else{_=Z}if(C&(B|0)<(_|0)){b[P+12>>1]=(d[R+9|0]|0|l)&65535;$=e}else{$=_}if(E&(D|0)<($|0)){b[P+10>>1]=(d[R+10|0]|0|l)&65535;aa=e}else{aa=$}if(G&(F|0)<(aa|0)){b[P+8>>1]=(d[R+11|0]|0|l)&65535;ab=e}else{ab=aa}if(I&(H|0)<(ab|0)){b[P+6>>1]=(d[R+12|0]|0|l)&65535;ac=e}else{ac=ab}if(K&(J|0)<(ac|0)){b[P+4>>1]=(d[R+13|0]|0|l)&65535;ad=e}else{ad=ac}if(M&(L|0)<(ad|0)){b[P+2>>1]=(d[R+14|0]|0|l)&65535;ae=e}else{ae=ad}if(!(N&(ae|0)>(f|0))){af=ae;break}b[P>>1]=(d[R+15|0]|0|l)&65535;af=e}else{af=Q}}while(0);ah=R+16|0;if((k|0)<=0){break}P=P+(-af<<1)|0;k=k-1|0;Q=af;R=ah}c[2112928]=ah;return}function SG(a,e,f,g,h,i,j,k,l){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0;m=h<<i|k;k=l+(e<<8)|0;c[2112928]=k;e=c[2113068]|0;l=a+((ag(e,g)|0)+f<<1)|0;f=0;g=k;while(1){k=d[g]|0;if((k|0)!=(j|0)){b[l>>1]=(k|m)&65535}k=d[g+1|0]|0;if((k|0)!=(j|0)){b[l+2>>1]=(k|m)&65535}k=d[g+2|0]|0;if((k|0)!=(j|0)){b[l+4>>1]=(k|m)&65535}k=d[g+3|0]|0;if((k|0)!=(j|0)){b[l+6>>1]=(k|m)&65535}k=d[g+4|0]|0;if((k|0)!=(j|0)){b[l+8>>1]=(k|m)&65535}k=d[g+5|0]|0;if((k|0)!=(j|0)){b[l+10>>1]=(k|m)&65535}k=d[g+6|0]|0;if((k|0)!=(j|0)){b[l+12>>1]=(k|m)&65535}k=d[g+7|0]|0;if((k|0)!=(j|0)){b[l+14>>1]=(k|m)&65535}k=d[g+8|0]|0;if((k|0)!=(j|0)){b[l+16>>1]=(k|m)&65535}k=d[g+9|0]|0;if((k|0)!=(j|0)){b[l+18>>1]=(k|m)&65535}k=d[g+10|0]|0;if((k|0)!=(j|0)){b[l+20>>1]=(k|m)&65535}k=d[g+11|0]|0;if((k|0)!=(j|0)){b[l+22>>1]=(k|m)&65535}k=d[g+12|0]|0;if((k|0)!=(j|0)){b[l+24>>1]=(k|m)&65535}k=d[g+13|0]|0;if((k|0)!=(j|0)){b[l+26>>1]=(k|m)&65535}k=d[g+14|0]|0;if((k|0)!=(j|0)){b[l+28>>1]=(k|m)&65535}k=d[g+15|0]|0;if((k|0)!=(j|0)){b[l+30>>1]=(k|m)&65535}k=f+1|0;n=g+16|0;if((k|0)<16){l=l+(e<<1)|0;f=k;g=n}else{break}}c[2112928]=n;return}function SH(a,e,f,g,h,i,j,k,l){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0;m=h<<i|k;k=l+(e<<8)|0;c[2112928]=k;e=c[2113068]|0;l=a+((ag(e,g)|0)+f<<1)|0;a=(f|0)>-1;i=f+1|0;h=(i|0)>-1;n=f+2|0;o=(n|0)>-1;p=f+3|0;q=(p|0)>-1;r=f+4|0;s=(r|0)>-1;t=f+5|0;u=(t|0)>-1;v=f+6|0;w=(v|0)>-1;x=f+7|0;y=(x|0)>-1;z=f+8|0;A=(z|0)>-1;B=f+9|0;C=(B|0)>-1;D=f+10|0;E=(D|0)>-1;F=f+11|0;G=(F|0)>-1;H=f+12|0;I=(H|0)>-1;J=f+13|0;K=(J|0)>-1;L=f+14|0;M=(L|0)>-1;N=f+15|0;O=(N|0)>-1;P=c[2113070]|0;Q=l;l=0;R=e;S=k;while(1){k=l+g|0;do{if((k|0)>-1&(k|0)<(P|0)){do{if(a&(R|0)>(f|0)){T=d[S]|0;if((T|0)==(j|0)){U=R;break}b[Q>>1]=(T|m)&65535;U=e}else{U=R}}while(0);do{if(h&(i|0)<(U|0)){T=d[S+1|0]|0;if((T|0)==(j|0)){V=U;break}b[Q+2>>1]=(T|m)&65535;V=e}else{V=U}}while(0);do{if(o&(n|0)<(V|0)){T=d[S+2|0]|0;if((T|0)==(j|0)){W=V;break}b[Q+4>>1]=(T|m)&65535;W=e}else{W=V}}while(0);do{if(q&(p|0)<(W|0)){T=d[S+3|0]|0;if((T|0)==(j|0)){X=W;break}b[Q+6>>1]=(T|m)&65535;X=e}else{X=W}}while(0);do{if(s&(r|0)<(X|0)){T=d[S+4|0]|0;if((T|0)==(j|0)){Y=X;break}b[Q+8>>1]=(T|m)&65535;Y=e}else{Y=X}}while(0);do{if(u&(t|0)<(Y|0)){T=d[S+5|0]|0;if((T|0)==(j|0)){Z=Y;break}b[Q+10>>1]=(T|m)&65535;Z=e}else{Z=Y}}while(0);do{if(w&(v|0)<(Z|0)){T=d[S+6|0]|0;if((T|0)==(j|0)){_=Z;break}b[Q+12>>1]=(T|m)&65535;_=e}else{_=Z}}while(0);do{if(y&(x|0)<(_|0)){T=d[S+7|0]|0;if((T|0)==(j|0)){$=_;break}b[Q+14>>1]=(T|m)&65535;$=e}else{$=_}}while(0);do{if(A&(z|0)<($|0)){T=d[S+8|0]|0;if((T|0)==(j|0)){aa=$;break}b[Q+16>>1]=(T|m)&65535;aa=e}else{aa=$}}while(0);do{if(C&(B|0)<(aa|0)){T=d[S+9|0]|0;if((T|0)==(j|0)){ab=aa;break}b[Q+18>>1]=(T|m)&65535;ab=e}else{ab=aa}}while(0);do{if(E&(D|0)<(ab|0)){T=d[S+10|0]|0;if((T|0)==(j|0)){ac=ab;break}b[Q+20>>1]=(T|m)&65535;ac=e}else{ac=ab}}while(0);do{if(G&(F|0)<(ac|0)){T=d[S+11|0]|0;if((T|0)==(j|0)){ad=ac;break}b[Q+22>>1]=(T|m)&65535;ad=e}else{ad=ac}}while(0);do{if(I&(H|0)<(ad|0)){T=d[S+12|0]|0;if((T|0)==(j|0)){ae=ad;break}b[Q+24>>1]=(T|m)&65535;ae=e}else{ae=ad}}while(0);do{if(K&(J|0)<(ae|0)){T=d[S+13|0]|0;if((T|0)==(j|0)){af=ae;break}b[Q+26>>1]=(T|m)&65535;af=e}else{af=ae}}while(0);do{if(M&(L|0)<(af|0)){T=d[S+14|0]|0;if((T|0)==(j|0)){ah=af;break}b[Q+28>>1]=(T|m)&65535;ah=e}else{ah=af}}while(0);if(!(O&(N|0)<(ah|0))){ai=ah;break}T=d[S+15|0]|0;if((T|0)==(j|0)){ai=ah;break}b[Q+30>>1]=(T|m)&65535;ai=e}else{ai=R}}while(0);k=l+1|0;aj=S+16|0;if((k|0)>=16){break}Q=Q+(ai<<1)|0;l=k;R=ai;S=aj}c[2112928]=aj;return}function SI(a,e,f,g,h,i,j,k,l){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0;m=h<<i|k;k=l+(e<<8)|0;c[2112928]=k;e=c[2113068]|0;l=a+((ag(e,g)|0)+f<<1)|0;f=0;g=k;while(1){k=d[g]|0;if((k|0)!=(j|0)){b[l+30>>1]=(k|m)&65535}k=d[g+1|0]|0;if((k|0)!=(j|0)){b[l+28>>1]=(k|m)&65535}k=d[g+2|0]|0;if((k|0)!=(j|0)){b[l+26>>1]=(k|m)&65535}k=d[g+3|0]|0;if((k|0)!=(j|0)){b[l+24>>1]=(k|m)&65535}k=d[g+4|0]|0;if((k|0)!=(j|0)){b[l+22>>1]=(k|m)&65535}k=d[g+5|0]|0;if((k|0)!=(j|0)){b[l+20>>1]=(k|m)&65535}k=d[g+6|0]|0;if((k|0)!=(j|0)){b[l+18>>1]=(k|m)&65535}k=d[g+7|0]|0;if((k|0)!=(j|0)){b[l+16>>1]=(k|m)&65535}k=d[g+8|0]|0;if((k|0)!=(j|0)){b[l+14>>1]=(k|m)&65535}k=d[g+9|0]|0;if((k|0)!=(j|0)){b[l+12>>1]=(k|m)&65535}k=d[g+10|0]|0;if((k|0)!=(j|0)){b[l+10>>1]=(k|m)&65535}k=d[g+11|0]|0;if((k|0)!=(j|0)){b[l+8>>1]=(k|m)&65535}k=d[g+12|0]|0;if((k|0)!=(j|0)){b[l+6>>1]=(k|m)&65535}k=d[g+13|0]|0;if((k|0)!=(j|0)){b[l+4>>1]=(k|m)&65535}k=d[g+14|0]|0;if((k|0)!=(j|0)){b[l+2>>1]=(k|m)&65535}k=d[g+15|0]|0;if((k|0)!=(j|0)){b[l>>1]=(k|m)&65535}k=f+1|0;n=g+16|0;if((k|0)<16){l=l+(e<<1)|0;f=k;g=n}else{break}}c[2112928]=n;return}function SJ(a,e,f,g,h,i,j,k,l){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0;m=h<<i|k;k=l+(e<<8)|0;c[2112928]=k;e=c[2113068]|0;l=a+((ag(e,g)|0)+f<<1)|0;a=f+15|0;i=(a|0)>-1;h=f+14|0;n=(h|0)>-1;o=f+13|0;p=(o|0)>-1;q=f+12|0;r=(q|0)>-1;s=f+11|0;t=(s|0)>-1;u=f+10|0;v=(u|0)>-1;w=f+9|0;x=(w|0)>-1;y=f+8|0;z=(y|0)>-1;A=f+7|0;B=(A|0)>-1;C=f+6|0;D=(C|0)>-1;E=f+5|0;F=(E|0)>-1;G=f+4|0;H=(G|0)>-1;I=f+3|0;J=(I|0)>-1;K=f+2|0;L=(K|0)>-1;M=f+1|0;N=(M|0)>-1;O=(f|0)>-1;P=c[2113070]|0;Q=l;l=0;R=e;S=k;while(1){k=l+g|0;do{if((k|0)>-1&(k|0)<(P|0)){do{if(i&(a|0)<(R|0)){T=d[S]|0;if((T|0)==(j|0)){U=R;break}b[Q+30>>1]=(T|m)&65535;U=e}else{U=R}}while(0);do{if(n&(h|0)<(U|0)){T=d[S+1|0]|0;if((T|0)==(j|0)){V=U;break}b[Q+28>>1]=(T|m)&65535;V=e}else{V=U}}while(0);do{if(p&(o|0)<(V|0)){T=d[S+2|0]|0;if((T|0)==(j|0)){W=V;break}b[Q+26>>1]=(T|m)&65535;W=e}else{W=V}}while(0);do{if(r&(q|0)<(W|0)){T=d[S+3|0]|0;if((T|0)==(j|0)){X=W;break}b[Q+24>>1]=(T|m)&65535;X=e}else{X=W}}while(0);do{if(t&(s|0)<(X|0)){T=d[S+4|0]|0;if((T|0)==(j|0)){Y=X;break}b[Q+22>>1]=(T|m)&65535;Y=e}else{Y=X}}while(0);do{if(v&(u|0)<(Y|0)){T=d[S+5|0]|0;if((T|0)==(j|0)){Z=Y;break}b[Q+20>>1]=(T|m)&65535;Z=e}else{Z=Y}}while(0);do{if(x&(w|0)<(Z|0)){T=d[S+6|0]|0;if((T|0)==(j|0)){_=Z;break}b[Q+18>>1]=(T|m)&65535;_=e}else{_=Z}}while(0);do{if(z&(y|0)<(_|0)){T=d[S+7|0]|0;if((T|0)==(j|0)){$=_;break}b[Q+16>>1]=(T|m)&65535;$=e}else{$=_}}while(0);do{if(B&(A|0)<($|0)){T=d[S+8|0]|0;if((T|0)==(j|0)){aa=$;break}b[Q+14>>1]=(T|m)&65535;aa=e}else{aa=$}}while(0);do{if(D&(C|0)<(aa|0)){T=d[S+9|0]|0;if((T|0)==(j|0)){ab=aa;break}b[Q+12>>1]=(T|m)&65535;ab=e}else{ab=aa}}while(0);do{if(F&(E|0)<(ab|0)){T=d[S+10|0]|0;if((T|0)==(j|0)){ac=ab;break}b[Q+10>>1]=(T|m)&65535;ac=e}else{ac=ab}}while(0);do{if(H&(G|0)<(ac|0)){T=d[S+11|0]|0;if((T|0)==(j|0)){ad=ac;break}b[Q+8>>1]=(T|m)&65535;ad=e}else{ad=ac}}while(0);do{if(J&(I|0)<(ad|0)){T=d[S+12|0]|0;if((T|0)==(j|0)){ae=ad;break}b[Q+6>>1]=(T|m)&65535;ae=e}else{ae=ad}}while(0);do{if(L&(K|0)<(ae|0)){T=d[S+13|0]|0;if((T|0)==(j|0)){af=ae;break}b[Q+4>>1]=(T|m)&65535;af=e}else{af=ae}}while(0);do{if(N&(M|0)<(af|0)){T=d[S+14|0]|0;if((T|0)==(j|0)){ah=af;break}b[Q+2>>1]=(T|m)&65535;ah=e}else{ah=af}}while(0);if(!(O&(ah|0)>(f|0))){ai=ah;break}T=d[S+15|0]|0;if((T|0)==(j|0)){ai=ah;break}b[Q>>1]=(T|m)&65535;ai=e}else{ai=R}}while(0);k=l+1|0;aj=S+16|0;if((k|0)>=16){break}Q=Q+(ai<<1)|0;l=k;R=ai;S=aj}c[2112928]=aj;return}function SK(a,e,f,g,h,i,j,k,l){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0;m=h<<i|k;k=l+(e<<8)|0;c[2112928]=k;e=c[2113068]|0;l=-e|0;i=a+((ag(e,g+15|0)|0)+f<<1)|0;f=15;g=k;while(1){k=d[g]|0;if((k|0)!=(j|0)){b[i>>1]=(k|m)&65535}k=d[g+1|0]|0;if((k|0)!=(j|0)){b[i+2>>1]=(k|m)&65535}k=d[g+2|0]|0;if((k|0)!=(j|0)){b[i+4>>1]=(k|m)&65535}k=d[g+3|0]|0;if((k|0)!=(j|0)){b[i+6>>1]=(k|m)&65535}k=d[g+4|0]|0;if((k|0)!=(j|0)){b[i+8>>1]=(k|m)&65535}k=d[g+5|0]|0;if((k|0)!=(j|0)){b[i+10>>1]=(k|m)&65535}k=d[g+6|0]|0;if((k|0)!=(j|0)){b[i+12>>1]=(k|m)&65535}k=d[g+7|0]|0;if((k|0)!=(j|0)){b[i+14>>1]=(k|m)&65535}k=d[g+8|0]|0;if((k|0)!=(j|0)){b[i+16>>1]=(k|m)&65535}k=d[g+9|0]|0;if((k|0)!=(j|0)){b[i+18>>1]=(k|m)&65535}k=d[g+10|0]|0;if((k|0)!=(j|0)){b[i+20>>1]=(k|m)&65535}k=d[g+11|0]|0;if((k|0)!=(j|0)){b[i+22>>1]=(k|m)&65535}k=d[g+12|0]|0;if((k|0)!=(j|0)){b[i+24>>1]=(k|m)&65535}k=d[g+13|0]|0;if((k|0)!=(j|0)){b[i+26>>1]=(k|m)&65535}k=d[g+14|0]|0;if((k|0)!=(j|0)){b[i+28>>1]=(k|m)&65535}k=d[g+15|0]|0;if((k|0)!=(j|0)){b[i+30>>1]=(k|m)&65535}n=g+16|0;if((f|0)>0){i=i+(l<<1)|0;f=f-1|0;g=n}else{break}}c[2112928]=n;return}function SL(a,e,f,g,h,i,j,k,l){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0;m=h<<i|k;k=l+(e<<8)|0;c[2112928]=k;e=c[2113068]|0;l=a+((ag(e,g+15|0)|0)+f<<1)|0;a=(f|0)>-1;i=f+1|0;h=(i|0)>-1;n=f+2|0;o=(n|0)>-1;p=f+3|0;q=(p|0)>-1;r=f+4|0;s=(r|0)>-1;t=f+5|0;u=(t|0)>-1;v=f+6|0;w=(v|0)>-1;x=f+7|0;y=(x|0)>-1;z=f+8|0;A=(z|0)>-1;B=f+9|0;C=(B|0)>-1;D=f+10|0;E=(D|0)>-1;F=f+11|0;G=(F|0)>-1;H=f+12|0;I=(H|0)>-1;J=f+13|0;K=(J|0)>-1;L=f+14|0;M=(L|0)>-1;N=f+15|0;O=(N|0)>-1;P=c[2113070]|0;Q=l;l=15;R=e;S=k;while(1){k=l+g|0;do{if((k|0)>-1&(k|0)<(P|0)){do{if(a&(R|0)>(f|0)){T=d[S]|0;if((T|0)==(j|0)){U=R;break}b[Q>>1]=(T|m)&65535;U=e}else{U=R}}while(0);do{if(h&(i|0)<(U|0)){T=d[S+1|0]|0;if((T|0)==(j|0)){V=U;break}b[Q+2>>1]=(T|m)&65535;V=e}else{V=U}}while(0);do{if(o&(n|0)<(V|0)){T=d[S+2|0]|0;if((T|0)==(j|0)){W=V;break}b[Q+4>>1]=(T|m)&65535;W=e}else{W=V}}while(0);do{if(q&(p|0)<(W|0)){T=d[S+3|0]|0;if((T|0)==(j|0)){X=W;break}b[Q+6>>1]=(T|m)&65535;X=e}else{X=W}}while(0);do{if(s&(r|0)<(X|0)){T=d[S+4|0]|0;if((T|0)==(j|0)){Y=X;break}b[Q+8>>1]=(T|m)&65535;Y=e}else{Y=X}}while(0);do{if(u&(t|0)<(Y|0)){T=d[S+5|0]|0;if((T|0)==(j|0)){Z=Y;break}b[Q+10>>1]=(T|m)&65535;Z=e}else{Z=Y}}while(0);do{if(w&(v|0)<(Z|0)){T=d[S+6|0]|0;if((T|0)==(j|0)){_=Z;break}b[Q+12>>1]=(T|m)&65535;_=e}else{_=Z}}while(0);do{if(y&(x|0)<(_|0)){T=d[S+7|0]|0;if((T|0)==(j|0)){$=_;break}b[Q+14>>1]=(T|m)&65535;$=e}else{$=_}}while(0);do{if(A&(z|0)<($|0)){T=d[S+8|0]|0;if((T|0)==(j|0)){aa=$;break}b[Q+16>>1]=(T|m)&65535;aa=e}else{aa=$}}while(0);do{if(C&(B|0)<(aa|0)){T=d[S+9|0]|0;if((T|0)==(j|0)){ab=aa;break}b[Q+18>>1]=(T|m)&65535;ab=e}else{ab=aa}}while(0);do{if(E&(D|0)<(ab|0)){T=d[S+10|0]|0;if((T|0)==(j|0)){ac=ab;break}b[Q+20>>1]=(T|m)&65535;ac=e}else{ac=ab}}while(0);do{if(G&(F|0)<(ac|0)){T=d[S+11|0]|0;if((T|0)==(j|0)){ad=ac;break}b[Q+22>>1]=(T|m)&65535;ad=e}else{ad=ac}}while(0);do{if(I&(H|0)<(ad|0)){T=d[S+12|0]|0;if((T|0)==(j|0)){ae=ad;break}b[Q+24>>1]=(T|m)&65535;ae=e}else{ae=ad}}while(0);do{if(K&(J|0)<(ae|0)){T=d[S+13|0]|0;if((T|0)==(j|0)){af=ae;break}b[Q+26>>1]=(T|m)&65535;af=e}else{af=ae}}while(0);do{if(M&(L|0)<(af|0)){T=d[S+14|0]|0;if((T|0)==(j|0)){ah=af;break}b[Q+28>>1]=(T|m)&65535;ah=e}else{ah=af}}while(0);if(!(O&(N|0)<(ah|0))){ai=ah;break}T=d[S+15|0]|0;if((T|0)==(j|0)){ai=ah;break}b[Q+30>>1]=(T|m)&65535;ai=e}else{ai=R}}while(0);aj=S+16|0;if((l|0)<=0){break}Q=Q+(-ai<<1)|0;l=l-1|0;R=ai;S=aj}c[2112928]=aj;return}function SM(a,e,f,g,h,i,j,k,l){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0;m=h<<i|k;k=l+(e<<8)|0;c[2112928]=k;e=c[2113068]|0;l=-e|0;i=a+((ag(e,g+15|0)|0)+f<<1)|0;f=15;g=k;while(1){k=d[g]|0;if((k|0)!=(j|0)){b[i+30>>1]=(k|m)&65535}k=d[g+1|0]|0;if((k|0)!=(j|0)){b[i+28>>1]=(k|m)&65535}k=d[g+2|0]|0;if((k|0)!=(j|0)){b[i+26>>1]=(k|m)&65535}k=d[g+3|0]|0;if((k|0)!=(j|0)){b[i+24>>1]=(k|m)&65535}k=d[g+4|0]|0;if((k|0)!=(j|0)){b[i+22>>1]=(k|m)&65535}k=d[g+5|0]|0;if((k|0)!=(j|0)){b[i+20>>1]=(k|m)&65535}k=d[g+6|0]|0;if((k|0)!=(j|0)){b[i+18>>1]=(k|m)&65535}k=d[g+7|0]|0;if((k|0)!=(j|0)){b[i+16>>1]=(k|m)&65535}k=d[g+8|0]|0;if((k|0)!=(j|0)){b[i+14>>1]=(k|m)&65535}k=d[g+9|0]|0;if((k|0)!=(j|0)){b[i+12>>1]=(k|m)&65535}k=d[g+10|0]|0;if((k|0)!=(j|0)){b[i+10>>1]=(k|m)&65535}k=d[g+11|0]|0;if((k|0)!=(j|0)){b[i+8>>1]=(k|m)&65535}k=d[g+12|0]|0;if((k|0)!=(j|0)){b[i+6>>1]=(k|m)&65535}k=d[g+13|0]|0;if((k|0)!=(j|0)){b[i+4>>1]=(k|m)&65535}k=d[g+14|0]|0;if((k|0)!=(j|0)){b[i+2>>1]=(k|m)&65535}k=d[g+15|0]|0;if((k|0)!=(j|0)){b[i>>1]=(k|m)&65535}n=g+16|0;if((f|0)>0){i=i+(l<<1)|0;f=f-1|0;g=n}else{break}}c[2112928]=n;return}function SN(a,e,f,g,h,i,j,k,l){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0;m=h<<i|k;k=l+(e<<8)|0;c[2112928]=k;e=c[2113068]|0;l=a+((ag(e,g+15|0)|0)+f<<1)|0;a=f+15|0;i=(a|0)>-1;h=f+14|0;n=(h|0)>-1;o=f+13|0;p=(o|0)>-1;q=f+12|0;r=(q|0)>-1;s=f+11|0;t=(s|0)>-1;u=f+10|0;v=(u|0)>-1;w=f+9|0;x=(w|0)>-1;y=f+8|0;z=(y|0)>-1;A=f+7|0;B=(A|0)>-1;C=f+6|0;D=(C|0)>-1;E=f+5|0;F=(E|0)>-1;G=f+4|0;H=(G|0)>-1;I=f+3|0;J=(I|0)>-1;K=f+2|0;L=(K|0)>-1;M=f+1|0;N=(M|0)>-1;O=(f|0)>-1;P=c[2113070]|0;Q=l;l=15;R=e;S=k;while(1){k=l+g|0;do{if((k|0)>-1&(k|0)<(P|0)){do{if(i&(a|0)<(R|0)){T=d[S]|0;if((T|0)==(j|0)){U=R;break}b[Q+30>>1]=(T|m)&65535;U=e}else{U=R}}while(0);do{if(n&(h|0)<(U|0)){T=d[S+1|0]|0;if((T|0)==(j|0)){V=U;break}b[Q+28>>1]=(T|m)&65535;V=e}else{V=U}}while(0);do{if(p&(o|0)<(V|0)){T=d[S+2|0]|0;if((T|0)==(j|0)){W=V;break}b[Q+26>>1]=(T|m)&65535;W=e}else{W=V}}while(0);do{if(r&(q|0)<(W|0)){T=d[S+3|0]|0;if((T|0)==(j|0)){X=W;break}b[Q+24>>1]=(T|m)&65535;X=e}else{X=W}}while(0);do{if(t&(s|0)<(X|0)){T=d[S+4|0]|0;if((T|0)==(j|0)){Y=X;break}b[Q+22>>1]=(T|m)&65535;Y=e}else{Y=X}}while(0);do{if(v&(u|0)<(Y|0)){T=d[S+5|0]|0;if((T|0)==(j|0)){Z=Y;break}b[Q+20>>1]=(T|m)&65535;Z=e}else{Z=Y}}while(0);do{if(x&(w|0)<(Z|0)){T=d[S+6|0]|0;if((T|0)==(j|0)){_=Z;break}b[Q+18>>1]=(T|m)&65535;_=e}else{_=Z}}while(0);do{if(z&(y|0)<(_|0)){T=d[S+7|0]|0;if((T|0)==(j|0)){$=_;break}b[Q+16>>1]=(T|m)&65535;$=e}else{$=_}}while(0);do{if(B&(A|0)<($|0)){T=d[S+8|0]|0;if((T|0)==(j|0)){aa=$;break}b[Q+14>>1]=(T|m)&65535;aa=e}else{aa=$}}while(0);do{if(D&(C|0)<(aa|0)){T=d[S+9|0]|0;if((T|0)==(j|0)){ab=aa;break}b[Q+12>>1]=(T|m)&65535;ab=e}else{ab=aa}}while(0);do{if(F&(E|0)<(ab|0)){T=d[S+10|0]|0;if((T|0)==(j|0)){ac=ab;break}b[Q+10>>1]=(T|m)&65535;ac=e}else{ac=ab}}while(0);do{if(H&(G|0)<(ac|0)){T=d[S+11|0]|0;if((T|0)==(j|0)){ad=ac;break}b[Q+8>>1]=(T|m)&65535;ad=e}else{ad=ac}}while(0);do{if(J&(I|0)<(ad|0)){T=d[S+12|0]|0;if((T|0)==(j|0)){ae=ad;break}b[Q+6>>1]=(T|m)&65535;ae=e}else{ae=ad}}while(0);do{if(L&(K|0)<(ae|0)){T=d[S+13|0]|0;if((T|0)==(j|0)){af=ae;break}b[Q+4>>1]=(T|m)&65535;af=e}else{af=ae}}while(0);do{if(N&(M|0)<(af|0)){T=d[S+14|0]|0;if((T|0)==(j|0)){ah=af;break}b[Q+2>>1]=(T|m)&65535;ah=e}else{ah=af}}while(0);if(!(O&(ah|0)>(f|0))){ai=ah;break}T=d[S+15|0]|0;if((T|0)==(j|0)){ai=ah;break}b[Q>>1]=(T|m)&65535;ai=e}else{ai=R}}while(0);aj=S+16|0;if((l|0)<=0){break}Q=Q+(-ai<<1)|0;l=l-1|0;R=ai;S=aj}c[2112928]=aj;return}function SO(a,e,f,g,h,i,j){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0;k=h<<i;i=j+(e<<10)|0;c[2112928]=i;e=c[2113068]|0;j=a+((ag(e,g)|0)+f<<1)|0;f=0;g=i;while(1){b[j>>1]=(d[g]|0|k)&65535;b[j+2>>1]=(d[g+1|0]|0|k)&65535;b[j+4>>1]=(d[g+2|0]|0|k)&65535;b[j+6>>1]=(d[g+3|0]|0|k)&65535;b[j+8>>1]=(d[g+4|0]|0|k)&65535;b[j+10>>1]=(d[g+5|0]|0|k)&65535;b[j+12>>1]=(d[g+6|0]|0|k)&65535;b[j+14>>1]=(d[g+7|0]|0|k)&65535;b[j+16>>1]=(d[g+8|0]|0|k)&65535;b[j+18>>1]=(d[g+9|0]|0|k)&65535;b[j+20>>1]=(d[g+10|0]|0|k)&65535;b[j+22>>1]=(d[g+11|0]|0|k)&65535;b[j+24>>1]=(d[g+12|0]|0|k)&65535;b[j+26>>1]=(d[g+13|0]|0|k)&65535;b[j+28>>1]=(d[g+14|0]|0|k)&65535;b[j+30>>1]=(d[g+15|0]|0|k)&65535;b[j+32>>1]=(d[g+16|0]|0|k)&65535;b[j+34>>1]=(d[g+17|0]|0|k)&65535;b[j+36>>1]=(d[g+18|0]|0|k)&65535;b[j+38>>1]=(d[g+19|0]|0|k)&65535;b[j+40>>1]=(d[g+20|0]|0|k)&65535;b[j+42>>1]=(d[g+21|0]|0|k)&65535;b[j+44>>1]=(d[g+22|0]|0|k)&65535;b[j+46>>1]=(d[g+23|0]|0|k)&65535;b[j+48>>1]=(d[g+24|0]|0|k)&65535;b[j+50>>1]=(d[g+25|0]|0|k)&65535;b[j+52>>1]=(d[g+26|0]|0|k)&65535;b[j+54>>1]=(d[g+27|0]|0|k)&65535;b[j+56>>1]=(d[g+28|0]|0|k)&65535;b[j+58>>1]=(d[g+29|0]|0|k)&65535;b[j+60>>1]=(d[g+30|0]|0|k)&65535;b[j+62>>1]=(d[g+31|0]|0|k)&65535;i=f+1|0;l=g+32|0;if((i|0)<32){j=j+(e<<1)|0;f=i;g=l}else{break}}c[2112928]=l;return}function SP(a,e,f,g,h,i,j,k){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0;l=h<<i|j;j=k+(e<<10)|0;c[2112928]=j;e=c[2113068]|0;k=a+((ag(e,g)|0)+f<<1)|0;a=(f|0)>-1;i=f+1|0;h=(i|0)>-1;m=f+2|0;n=(m|0)>-1;o=f+3|0;p=(o|0)>-1;q=f+4|0;r=(q|0)>-1;s=f+5|0;t=(s|0)>-1;u=f+6|0;v=(u|0)>-1;w=f+7|0;x=(w|0)>-1;y=f+8|0;z=(y|0)>-1;A=f+9|0;B=(A|0)>-1;C=f+10|0;D=(C|0)>-1;E=f+11|0;F=(E|0)>-1;G=f+12|0;H=(G|0)>-1;I=f+13|0;J=(I|0)>-1;K=f+14|0;L=(K|0)>-1;M=f+15|0;N=(M|0)>-1;O=f+16|0;P=(O|0)>-1;Q=f+17|0;R=(Q|0)>-1;S=f+18|0;T=(S|0)>-1;U=f+19|0;V=(U|0)>-1;W=f+20|0;X=(W|0)>-1;Y=f+21|0;Z=(Y|0)>-1;_=f+22|0;$=(_|0)>-1;aa=f+23|0;ab=(aa|0)>-1;ac=f+24|0;ad=(ac|0)>-1;ae=f+25|0;af=(ae|0)>-1;ah=f+26|0;ai=(ah|0)>-1;aj=f+27|0;ak=(aj|0)>-1;al=f+28|0;am=(al|0)>-1;an=f+29|0;ao=(an|0)>-1;ap=f+30|0;aq=(ap|0)>-1;ar=f+31|0;as=(ar|0)>-1;at=c[2113070]|0;au=k;k=0;av=e;aw=j;while(1){j=k+g|0;do{if((j|0)>-1&(j|0)<(at|0)){if(a&(av|0)>(f|0)){b[au>>1]=(d[aw]|0|l)&65535;ax=e}else{ax=av}if(h&(i|0)<(ax|0)){b[au+2>>1]=(d[aw+1|0]|0|l)&65535;ay=e}else{ay=ax}if(n&(m|0)<(ay|0)){b[au+4>>1]=(d[aw+2|0]|0|l)&65535;az=e}else{az=ay}if(p&(o|0)<(az|0)){b[au+6>>1]=(d[aw+3|0]|0|l)&65535;aA=e}else{aA=az}if(r&(q|0)<(aA|0)){b[au+8>>1]=(d[aw+4|0]|0|l)&65535;aB=e}else{aB=aA}if(t&(s|0)<(aB|0)){b[au+10>>1]=(d[aw+5|0]|0|l)&65535;aC=e}else{aC=aB}if(v&(u|0)<(aC|0)){b[au+12>>1]=(d[aw+6|0]|0|l)&65535;aD=e}else{aD=aC}if(x&(w|0)<(aD|0)){b[au+14>>1]=(d[aw+7|0]|0|l)&65535;aE=e}else{aE=aD}if(z&(y|0)<(aE|0)){b[au+16>>1]=(d[aw+8|0]|0|l)&65535;aF=e}else{aF=aE}if(B&(A|0)<(aF|0)){b[au+18>>1]=(d[aw+9|0]|0|l)&65535;aG=e}else{aG=aF}if(D&(C|0)<(aG|0)){b[au+20>>1]=(d[aw+10|0]|0|l)&65535;aH=e}else{aH=aG}if(F&(E|0)<(aH|0)){b[au+22>>1]=(d[aw+11|0]|0|l)&65535;aI=e}else{aI=aH}if(H&(G|0)<(aI|0)){b[au+24>>1]=(d[aw+12|0]|0|l)&65535;aJ=e}else{aJ=aI}if(J&(I|0)<(aJ|0)){b[au+26>>1]=(d[aw+13|0]|0|l)&65535;aK=e}else{aK=aJ}if(L&(K|0)<(aK|0)){b[au+28>>1]=(d[aw+14|0]|0|l)&65535;aL=e}else{aL=aK}if(N&(M|0)<(aL|0)){b[au+30>>1]=(d[aw+15|0]|0|l)&65535;aM=e}else{aM=aL}if(P&(O|0)<(aM|0)){b[au+32>>1]=(d[aw+16|0]|0|l)&65535;aN=e}else{aN=aM}if(R&(Q|0)<(aN|0)){b[au+34>>1]=(d[aw+17|0]|0|l)&65535;aO=e}else{aO=aN}if(T&(S|0)<(aO|0)){b[au+36>>1]=(d[aw+18|0]|0|l)&65535;aP=e}else{aP=aO}if(V&(U|0)<(aP|0)){b[au+38>>1]=(d[aw+19|0]|0|l)&65535;aQ=e}else{aQ=aP}if(X&(W|0)<(aQ|0)){b[au+40>>1]=(d[aw+20|0]|0|l)&65535;aR=e}else{aR=aQ}if(Z&(Y|0)<(aR|0)){b[au+42>>1]=(d[aw+21|0]|0|l)&65535;aS=e}else{aS=aR}if($&(_|0)<(aS|0)){b[au+44>>1]=(d[aw+22|0]|0|l)&65535;aT=e}else{aT=aS}if(ab&(aa|0)<(aT|0)){b[au+46>>1]=(d[aw+23|0]|0|l)&65535;aU=e}else{aU=aT}if(ad&(ac|0)<(aU|0)){b[au+48>>1]=(d[aw+24|0]|0|l)&65535;aV=e}else{aV=aU}if(af&(ae|0)<(aV|0)){b[au+50>>1]=(d[aw+25|0]|0|l)&65535;aW=e}else{aW=aV}if(ai&(ah|0)<(aW|0)){b[au+52>>1]=(d[aw+26|0]|0|l)&65535;aX=e}else{aX=aW}if(ak&(aj|0)<(aX|0)){b[au+54>>1]=(d[aw+27|0]|0|l)&65535;aY=e}else{aY=aX}if(am&(al|0)<(aY|0)){b[au+56>>1]=(d[aw+28|0]|0|l)&65535;aZ=e}else{aZ=aY}if(ao&(an|0)<(aZ|0)){b[au+58>>1]=(d[aw+29|0]|0|l)&65535;a_=e}else{a_=aZ}if(aq&(ap|0)<(a_|0)){b[au+60>>1]=(d[aw+30|0]|0|l)&65535;a$=e}else{a$=a_}if(!(as&(ar|0)<(a$|0))){a0=a$;break}b[au+62>>1]=(d[aw+31|0]|0|l)&65535;a0=e}else{a0=av}}while(0);j=k+1|0;a1=aw+32|0;if((j|0)>=32){break}au=au+(a0<<1)|0;k=j;av=a0;aw=a1}c[2112928]=a1;return}function SQ(a,e,f,g,h,i,j){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0;k=h<<i;i=j+(e<<10)|0;c[2112928]=i;e=c[2113068]|0;j=a+((ag(e,g)|0)+f<<1)|0;f=0;g=i;while(1){b[j+62>>1]=(d[g]|0|k)&65535;b[j+60>>1]=(d[g+1|0]|0|k)&65535;b[j+58>>1]=(d[g+2|0]|0|k)&65535;b[j+56>>1]=(d[g+3|0]|0|k)&65535;b[j+54>>1]=(d[g+4|0]|0|k)&65535;b[j+52>>1]=(d[g+5|0]|0|k)&65535;b[j+50>>1]=(d[g+6|0]|0|k)&65535;b[j+48>>1]=(d[g+7|0]|0|k)&65535;b[j+46>>1]=(d[g+8|0]|0|k)&65535;b[j+44>>1]=(d[g+9|0]|0|k)&65535;b[j+42>>1]=(d[g+10|0]|0|k)&65535;b[j+40>>1]=(d[g+11|0]|0|k)&65535;b[j+38>>1]=(d[g+12|0]|0|k)&65535;b[j+36>>1]=(d[g+13|0]|0|k)&65535;b[j+34>>1]=(d[g+14|0]|0|k)&65535;b[j+32>>1]=(d[g+15|0]|0|k)&65535;b[j+30>>1]=(d[g+16|0]|0|k)&65535;b[j+28>>1]=(d[g+17|0]|0|k)&65535;b[j+26>>1]=(d[g+18|0]|0|k)&65535;b[j+24>>1]=(d[g+19|0]|0|k)&65535;b[j+22>>1]=(d[g+20|0]|0|k)&65535;b[j+20>>1]=(d[g+21|0]|0|k)&65535;b[j+18>>1]=(d[g+22|0]|0|k)&65535;b[j+16>>1]=(d[g+23|0]|0|k)&65535;b[j+14>>1]=(d[g+24|0]|0|k)&65535;b[j+12>>1]=(d[g+25|0]|0|k)&65535;b[j+10>>1]=(d[g+26|0]|0|k)&65535;b[j+8>>1]=(d[g+27|0]|0|k)&65535;b[j+6>>1]=(d[g+28|0]|0|k)&65535;b[j+4>>1]=(d[g+29|0]|0|k)&65535;b[j+2>>1]=(d[g+30|0]|0|k)&65535;b[j>>1]=(d[g+31|0]|0|k)&65535;i=f+1|0;l=g+32|0;if((i|0)<32){j=j+(e<<1)|0;f=i;g=l}else{break}}c[2112928]=l;return}function SR(a,e,f,g,h,i,j,k){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0;l=h<<i|j;j=k+(e<<10)|0;c[2112928]=j;e=c[2113068]|0;k=a+((ag(e,g)|0)+f<<1)|0;a=f+31|0;i=(a|0)>-1;h=f+30|0;m=(h|0)>-1;n=f+29|0;o=(n|0)>-1;p=f+28|0;q=(p|0)>-1;r=f+27|0;s=(r|0)>-1;t=f+26|0;u=(t|0)>-1;v=f+25|0;w=(v|0)>-1;x=f+24|0;y=(x|0)>-1;z=f+23|0;A=(z|0)>-1;B=f+22|0;C=(B|0)>-1;D=f+21|0;E=(D|0)>-1;F=f+20|0;G=(F|0)>-1;H=f+19|0;I=(H|0)>-1;J=f+18|0;K=(J|0)>-1;L=f+17|0;M=(L|0)>-1;N=f+16|0;O=(N|0)>-1;P=f+15|0;Q=(P|0)>-1;R=f+14|0;S=(R|0)>-1;T=f+13|0;U=(T|0)>-1;V=f+12|0;W=(V|0)>-1;X=f+11|0;Y=(X|0)>-1;Z=f+10|0;_=(Z|0)>-1;$=f+9|0;aa=($|0)>-1;ab=f+8|0;ac=(ab|0)>-1;ad=f+7|0;ae=(ad|0)>-1;af=f+6|0;ah=(af|0)>-1;ai=f+5|0;aj=(ai|0)>-1;ak=f+4|0;al=(ak|0)>-1;am=f+3|0;an=(am|0)>-1;ao=f+2|0;ap=(ao|0)>-1;aq=f+1|0;ar=(aq|0)>-1;as=(f|0)>-1;at=c[2113070]|0;au=k;k=0;av=e;aw=j;while(1){j=k+g|0;do{if((j|0)>-1&(j|0)<(at|0)){if(i&(a|0)<(av|0)){b[au+62>>1]=(d[aw]|0|l)&65535;ax=e}else{ax=av}if(m&(h|0)<(ax|0)){b[au+60>>1]=(d[aw+1|0]|0|l)&65535;ay=e}else{ay=ax}if(o&(n|0)<(ay|0)){b[au+58>>1]=(d[aw+2|0]|0|l)&65535;az=e}else{az=ay}if(q&(p|0)<(az|0)){b[au+56>>1]=(d[aw+3|0]|0|l)&65535;aA=e}else{aA=az}if(s&(r|0)<(aA|0)){b[au+54>>1]=(d[aw+4|0]|0|l)&65535;aB=e}else{aB=aA}if(u&(t|0)<(aB|0)){b[au+52>>1]=(d[aw+5|0]|0|l)&65535;aC=e}else{aC=aB}if(w&(v|0)<(aC|0)){b[au+50>>1]=(d[aw+6|0]|0|l)&65535;aD=e}else{aD=aC}if(y&(x|0)<(aD|0)){b[au+48>>1]=(d[aw+7|0]|0|l)&65535;aE=e}else{aE=aD}if(A&(z|0)<(aE|0)){b[au+46>>1]=(d[aw+8|0]|0|l)&65535;aF=e}else{aF=aE}if(C&(B|0)<(aF|0)){b[au+44>>1]=(d[aw+9|0]|0|l)&65535;aG=e}else{aG=aF}if(E&(D|0)<(aG|0)){b[au+42>>1]=(d[aw+10|0]|0|l)&65535;aH=e}else{aH=aG}if(G&(F|0)<(aH|0)){b[au+40>>1]=(d[aw+11|0]|0|l)&65535;aI=e}else{aI=aH}if(I&(H|0)<(aI|0)){b[au+38>>1]=(d[aw+12|0]|0|l)&65535;aJ=e}else{aJ=aI}if(K&(J|0)<(aJ|0)){b[au+36>>1]=(d[aw+13|0]|0|l)&65535;aK=e}else{aK=aJ}if(M&(L|0)<(aK|0)){b[au+34>>1]=(d[aw+14|0]|0|l)&65535;aL=e}else{aL=aK}if(O&(N|0)<(aL|0)){b[au+32>>1]=(d[aw+15|0]|0|l)&65535;aM=e}else{aM=aL}if(Q&(P|0)<(aM|0)){b[au+30>>1]=(d[aw+16|0]|0|l)&65535;aN=e}else{aN=aM}if(S&(R|0)<(aN|0)){b[au+28>>1]=(d[aw+17|0]|0|l)&65535;aO=e}else{aO=aN}if(U&(T|0)<(aO|0)){b[au+26>>1]=(d[aw+18|0]|0|l)&65535;aP=e}else{aP=aO}if(W&(V|0)<(aP|0)){b[au+24>>1]=(d[aw+19|0]|0|l)&65535;aQ=e}else{aQ=aP}if(Y&(X|0)<(aQ|0)){b[au+22>>1]=(d[aw+20|0]|0|l)&65535;aR=e}else{aR=aQ}if(_&(Z|0)<(aR|0)){b[au+20>>1]=(d[aw+21|0]|0|l)&65535;aS=e}else{aS=aR}if(aa&($|0)<(aS|0)){b[au+18>>1]=(d[aw+22|0]|0|l)&65535;aT=e}else{aT=aS}if(ac&(ab|0)<(aT|0)){b[au+16>>1]=(d[aw+23|0]|0|l)&65535;aU=e}else{aU=aT}if(ae&(ad|0)<(aU|0)){b[au+14>>1]=(d[aw+24|0]|0|l)&65535;aV=e}else{aV=aU}if(ah&(af|0)<(aV|0)){b[au+12>>1]=(d[aw+25|0]|0|l)&65535;aW=e}else{aW=aV}if(aj&(ai|0)<(aW|0)){b[au+10>>1]=(d[aw+26|0]|0|l)&65535;aX=e}else{aX=aW}if(al&(ak|0)<(aX|0)){b[au+8>>1]=(d[aw+27|0]|0|l)&65535;aY=e}else{aY=aX}if(an&(am|0)<(aY|0)){b[au+6>>1]=(d[aw+28|0]|0|l)&65535;aZ=e}else{aZ=aY}if(ap&(ao|0)<(aZ|0)){b[au+4>>1]=(d[aw+29|0]|0|l)&65535;a_=e}else{a_=aZ}if(ar&(aq|0)<(a_|0)){b[au+2>>1]=(d[aw+30|0]|0|l)&65535;a$=e}else{a$=a_}if(!(as&(a$|0)>(f|0))){a0=a$;break}b[au>>1]=(d[aw+31|0]|0|l)&65535;a0=e}else{a0=av}}while(0);j=k+1|0;a1=aw+32|0;if((j|0)>=32){break}au=au+(a0<<1)|0;k=j;av=a0;aw=a1}c[2112928]=a1;return}function SS(a,e,f,g,h,i,j){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0;k=h<<i;i=j+(e<<10)|0;c[2112928]=i;e=c[2113068]|0;j=-e|0;h=a+((ag(e,g+31|0)|0)+f<<1)|0;f=31;g=i;while(1){b[h>>1]=(d[g]|0|k)&65535;b[h+2>>1]=(d[g+1|0]|0|k)&65535;b[h+4>>1]=(d[g+2|0]|0|k)&65535;b[h+6>>1]=(d[g+3|0]|0|k)&65535;b[h+8>>1]=(d[g+4|0]|0|k)&65535;b[h+10>>1]=(d[g+5|0]|0|k)&65535;b[h+12>>1]=(d[g+6|0]|0|k)&65535;b[h+14>>1]=(d[g+7|0]|0|k)&65535;b[h+16>>1]=(d[g+8|0]|0|k)&65535;b[h+18>>1]=(d[g+9|0]|0|k)&65535;b[h+20>>1]=(d[g+10|0]|0|k)&65535;b[h+22>>1]=(d[g+11|0]|0|k)&65535;b[h+24>>1]=(d[g+12|0]|0|k)&65535;b[h+26>>1]=(d[g+13|0]|0|k)&65535;b[h+28>>1]=(d[g+14|0]|0|k)&65535;b[h+30>>1]=(d[g+15|0]|0|k)&65535;b[h+32>>1]=(d[g+16|0]|0|k)&65535;b[h+34>>1]=(d[g+17|0]|0|k)&65535;b[h+36>>1]=(d[g+18|0]|0|k)&65535;b[h+38>>1]=(d[g+19|0]|0|k)&65535;b[h+40>>1]=(d[g+20|0]|0|k)&65535;b[h+42>>1]=(d[g+21|0]|0|k)&65535;b[h+44>>1]=(d[g+22|0]|0|k)&65535;b[h+46>>1]=(d[g+23|0]|0|k)&65535;b[h+48>>1]=(d[g+24|0]|0|k)&65535;b[h+50>>1]=(d[g+25|0]|0|k)&65535;b[h+52>>1]=(d[g+26|0]|0|k)&65535;b[h+54>>1]=(d[g+27|0]|0|k)&65535;b[h+56>>1]=(d[g+28|0]|0|k)&65535;b[h+58>>1]=(d[g+29|0]|0|k)&65535;b[h+60>>1]=(d[g+30|0]|0|k)&65535;b[h+62>>1]=(d[g+31|0]|0|k)&65535;l=g+32|0;if((f|0)>0){h=h+(j<<1)|0;f=f-1|0;g=l}else{break}}c[2112928]=l;return}function ST(a,e,f,g,h,i,j,k){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0;l=h<<i|j;j=k+(e<<10)|0;c[2112928]=j;e=c[2113068]|0;k=a+((ag(e,g+31|0)|0)+f<<1)|0;a=(f|0)>-1;i=f+1|0;h=(i|0)>-1;m=f+2|0;n=(m|0)>-1;o=f+3|0;p=(o|0)>-1;q=f+4|0;r=(q|0)>-1;s=f+5|0;t=(s|0)>-1;u=f+6|0;v=(u|0)>-1;w=f+7|0;x=(w|0)>-1;y=f+8|0;z=(y|0)>-1;A=f+9|0;B=(A|0)>-1;C=f+10|0;D=(C|0)>-1;E=f+11|0;F=(E|0)>-1;G=f+12|0;H=(G|0)>-1;I=f+13|0;J=(I|0)>-1;K=f+14|0;L=(K|0)>-1;M=f+15|0;N=(M|0)>-1;O=f+16|0;P=(O|0)>-1;Q=f+17|0;R=(Q|0)>-1;S=f+18|0;T=(S|0)>-1;U=f+19|0;V=(U|0)>-1;W=f+20|0;X=(W|0)>-1;Y=f+21|0;Z=(Y|0)>-1;_=f+22|0;$=(_|0)>-1;aa=f+23|0;ab=(aa|0)>-1;ac=f+24|0;ad=(ac|0)>-1;ae=f+25|0;af=(ae|0)>-1;ah=f+26|0;ai=(ah|0)>-1;aj=f+27|0;ak=(aj|0)>-1;al=f+28|0;am=(al|0)>-1;an=f+29|0;ao=(an|0)>-1;ap=f+30|0;aq=(ap|0)>-1;ar=f+31|0;as=(ar|0)>-1;at=c[2113070]|0;au=k;k=31;av=e;aw=j;while(1){j=k+g|0;do{if((j|0)>-1&(j|0)<(at|0)){if(a&(av|0)>(f|0)){b[au>>1]=(d[aw]|0|l)&65535;ax=e}else{ax=av}if(h&(i|0)<(ax|0)){b[au+2>>1]=(d[aw+1|0]|0|l)&65535;ay=e}else{ay=ax}if(n&(m|0)<(ay|0)){b[au+4>>1]=(d[aw+2|0]|0|l)&65535;az=e}else{az=ay}if(p&(o|0)<(az|0)){b[au+6>>1]=(d[aw+3|0]|0|l)&65535;aA=e}else{aA=az}if(r&(q|0)<(aA|0)){b[au+8>>1]=(d[aw+4|0]|0|l)&65535;aB=e}else{aB=aA}if(t&(s|0)<(aB|0)){b[au+10>>1]=(d[aw+5|0]|0|l)&65535;aC=e}else{aC=aB}if(v&(u|0)<(aC|0)){b[au+12>>1]=(d[aw+6|0]|0|l)&65535;aD=e}else{aD=aC}if(x&(w|0)<(aD|0)){b[au+14>>1]=(d[aw+7|0]|0|l)&65535;aE=e}else{aE=aD}if(z&(y|0)<(aE|0)){b[au+16>>1]=(d[aw+8|0]|0|l)&65535;aF=e}else{aF=aE}if(B&(A|0)<(aF|0)){b[au+18>>1]=(d[aw+9|0]|0|l)&65535;aG=e}else{aG=aF}if(D&(C|0)<(aG|0)){b[au+20>>1]=(d[aw+10|0]|0|l)&65535;aH=e}else{aH=aG}if(F&(E|0)<(aH|0)){b[au+22>>1]=(d[aw+11|0]|0|l)&65535;aI=e}else{aI=aH}if(H&(G|0)<(aI|0)){b[au+24>>1]=(d[aw+12|0]|0|l)&65535;aJ=e}else{aJ=aI}if(J&(I|0)<(aJ|0)){b[au+26>>1]=(d[aw+13|0]|0|l)&65535;aK=e}else{aK=aJ}if(L&(K|0)<(aK|0)){b[au+28>>1]=(d[aw+14|0]|0|l)&65535;aL=e}else{aL=aK}if(N&(M|0)<(aL|0)){b[au+30>>1]=(d[aw+15|0]|0|l)&65535;aM=e}else{aM=aL}if(P&(O|0)<(aM|0)){b[au+32>>1]=(d[aw+16|0]|0|l)&65535;aN=e}else{aN=aM}if(R&(Q|0)<(aN|0)){b[au+34>>1]=(d[aw+17|0]|0|l)&65535;aO=e}else{aO=aN}if(T&(S|0)<(aO|0)){b[au+36>>1]=(d[aw+18|0]|0|l)&65535;aP=e}else{aP=aO}if(V&(U|0)<(aP|0)){b[au+38>>1]=(d[aw+19|0]|0|l)&65535;aQ=e}else{aQ=aP}if(X&(W|0)<(aQ|0)){b[au+40>>1]=(d[aw+20|0]|0|l)&65535;aR=e}else{aR=aQ}if(Z&(Y|0)<(aR|0)){b[au+42>>1]=(d[aw+21|0]|0|l)&65535;aS=e}else{aS=aR}if($&(_|0)<(aS|0)){b[au+44>>1]=(d[aw+22|0]|0|l)&65535;aT=e}else{aT=aS}if(ab&(aa|0)<(aT|0)){b[au+46>>1]=(d[aw+23|0]|0|l)&65535;aU=e}else{aU=aT}if(ad&(ac|0)<(aU|0)){b[au+48>>1]=(d[aw+24|0]|0|l)&65535;aV=e}else{aV=aU}if(af&(ae|0)<(aV|0)){b[au+50>>1]=(d[aw+25|0]|0|l)&65535;aW=e}else{aW=aV}if(ai&(ah|0)<(aW|0)){b[au+52>>1]=(d[aw+26|0]|0|l)&65535;aX=e}else{aX=aW}if(ak&(aj|0)<(aX|0)){b[au+54>>1]=(d[aw+27|0]|0|l)&65535;aY=e}else{aY=aX}if(am&(al|0)<(aY|0)){b[au+56>>1]=(d[aw+28|0]|0|l)&65535;aZ=e}else{aZ=aY}if(ao&(an|0)<(aZ|0)){b[au+58>>1]=(d[aw+29|0]|0|l)&65535;a_=e}else{a_=aZ}if(aq&(ap|0)<(a_|0)){b[au+60>>1]=(d[aw+30|0]|0|l)&65535;a$=e}else{a$=a_}if(!(as&(ar|0)<(a$|0))){a0=a$;break}b[au+62>>1]=(d[aw+31|0]|0|l)&65535;a0=e}else{a0=av}}while(0);a1=aw+32|0;if((k|0)<=0){break}au=au+(-a0<<1)|0;k=k-1|0;av=a0;aw=a1}c[2112928]=a1;return}function SU(a,e,f,g,h,i,j){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0;k=h<<i;i=j+(e<<10)|0;c[2112928]=i;e=c[2113068]|0;j=-e|0;h=a+((ag(e,g+31|0)|0)+f<<1)|0;f=31;g=i;while(1){b[h+62>>1]=(d[g]|0|k)&65535;b[h+60>>1]=(d[g+1|0]|0|k)&65535;b[h+58>>1]=(d[g+2|0]|0|k)&65535;b[h+56>>1]=(d[g+3|0]|0|k)&65535;b[h+54>>1]=(d[g+4|0]|0|k)&65535;b[h+52>>1]=(d[g+5|0]|0|k)&65535;b[h+50>>1]=(d[g+6|0]|0|k)&65535;b[h+48>>1]=(d[g+7|0]|0|k)&65535;b[h+46>>1]=(d[g+8|0]|0|k)&65535;b[h+44>>1]=(d[g+9|0]|0|k)&65535;b[h+42>>1]=(d[g+10|0]|0|k)&65535;b[h+40>>1]=(d[g+11|0]|0|k)&65535;b[h+38>>1]=(d[g+12|0]|0|k)&65535;b[h+36>>1]=(d[g+13|0]|0|k)&65535;b[h+34>>1]=(d[g+14|0]|0|k)&65535;b[h+32>>1]=(d[g+15|0]|0|k)&65535;b[h+30>>1]=(d[g+16|0]|0|k)&65535;b[h+28>>1]=(d[g+17|0]|0|k)&65535;b[h+26>>1]=(d[g+18|0]|0|k)&65535;b[h+24>>1]=(d[g+19|0]|0|k)&65535;b[h+22>>1]=(d[g+20|0]|0|k)&65535;b[h+20>>1]=(d[g+21|0]|0|k)&65535;b[h+18>>1]=(d[g+22|0]|0|k)&65535;b[h+16>>1]=(d[g+23|0]|0|k)&65535;b[h+14>>1]=(d[g+24|0]|0|k)&65535;b[h+12>>1]=(d[g+25|0]|0|k)&65535;b[h+10>>1]=(d[g+26|0]|0|k)&65535;b[h+8>>1]=(d[g+27|0]|0|k)&65535;b[h+6>>1]=(d[g+28|0]|0|k)&65535;b[h+4>>1]=(d[g+29|0]|0|k)&65535;b[h+2>>1]=(d[g+30|0]|0|k)&65535;b[h>>1]=(d[g+31|0]|0|k)&65535;l=g+32|0;if((f|0)>0){h=h+(j<<1)|0;f=f-1|0;g=l}else{break}}c[2112928]=l;return}function SV(a,e,f,g,h,i,j,k){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0;l=h<<i|j;j=k+(e<<10)|0;c[2112928]=j;e=c[2113068]|0;k=a+((ag(e,g+31|0)|0)+f<<1)|0;a=f+31|0;i=(a|0)>-1;h=f+30|0;m=(h|0)>-1;n=f+29|0;o=(n|0)>-1;p=f+28|0;q=(p|0)>-1;r=f+27|0;s=(r|0)>-1;t=f+26|0;u=(t|0)>-1;v=f+25|0;w=(v|0)>-1;x=f+24|0;y=(x|0)>-1;z=f+23|0;A=(z|0)>-1;B=f+22|0;C=(B|0)>-1;D=f+21|0;E=(D|0)>-1;F=f+20|0;G=(F|0)>-1;H=f+19|0;I=(H|0)>-1;J=f+18|0;K=(J|0)>-1;L=f+17|0;M=(L|0)>-1;N=f+16|0;O=(N|0)>-1;P=f+15|0;Q=(P|0)>-1;R=f+14|0;S=(R|0)>-1;T=f+13|0;U=(T|0)>-1;V=f+12|0;W=(V|0)>-1;X=f+11|0;Y=(X|0)>-1;Z=f+10|0;_=(Z|0)>-1;$=f+9|0;aa=($|0)>-1;ab=f+8|0;ac=(ab|0)>-1;ad=f+7|0;ae=(ad|0)>-1;af=f+6|0;ah=(af|0)>-1;ai=f+5|0;aj=(ai|0)>-1;ak=f+4|0;al=(ak|0)>-1;am=f+3|0;an=(am|0)>-1;ao=f+2|0;ap=(ao|0)>-1;aq=f+1|0;ar=(aq|0)>-1;as=(f|0)>-1;at=c[2113070]|0;au=k;k=31;av=e;aw=j;while(1){j=k+g|0;do{if((j|0)>-1&(j|0)<(at|0)){if(i&(a|0)<(av|0)){b[au+62>>1]=(d[aw]|0|l)&65535;ax=e}else{ax=av}if(m&(h|0)<(ax|0)){b[au+60>>1]=(d[aw+1|0]|0|l)&65535;ay=e}else{ay=ax}if(o&(n|0)<(ay|0)){b[au+58>>1]=(d[aw+2|0]|0|l)&65535;az=e}else{az=ay}if(q&(p|0)<(az|0)){b[au+56>>1]=(d[aw+3|0]|0|l)&65535;aA=e}else{aA=az}if(s&(r|0)<(aA|0)){b[au+54>>1]=(d[aw+4|0]|0|l)&65535;aB=e}else{aB=aA}if(u&(t|0)<(aB|0)){b[au+52>>1]=(d[aw+5|0]|0|l)&65535;aC=e}else{aC=aB}if(w&(v|0)<(aC|0)){b[au+50>>1]=(d[aw+6|0]|0|l)&65535;aD=e}else{aD=aC}if(y&(x|0)<(aD|0)){b[au+48>>1]=(d[aw+7|0]|0|l)&65535;aE=e}else{aE=aD}if(A&(z|0)<(aE|0)){b[au+46>>1]=(d[aw+8|0]|0|l)&65535;aF=e}else{aF=aE}if(C&(B|0)<(aF|0)){b[au+44>>1]=(d[aw+9|0]|0|l)&65535;aG=e}else{aG=aF}if(E&(D|0)<(aG|0)){b[au+42>>1]=(d[aw+10|0]|0|l)&65535;aH=e}else{aH=aG}if(G&(F|0)<(aH|0)){b[au+40>>1]=(d[aw+11|0]|0|l)&65535;aI=e}else{aI=aH}if(I&(H|0)<(aI|0)){b[au+38>>1]=(d[aw+12|0]|0|l)&65535;aJ=e}else{aJ=aI}if(K&(J|0)<(aJ|0)){b[au+36>>1]=(d[aw+13|0]|0|l)&65535;aK=e}else{aK=aJ}if(M&(L|0)<(aK|0)){b[au+34>>1]=(d[aw+14|0]|0|l)&65535;aL=e}else{aL=aK}if(O&(N|0)<(aL|0)){b[au+32>>1]=(d[aw+15|0]|0|l)&65535;aM=e}else{aM=aL}if(Q&(P|0)<(aM|0)){b[au+30>>1]=(d[aw+16|0]|0|l)&65535;aN=e}else{aN=aM}if(S&(R|0)<(aN|0)){b[au+28>>1]=(d[aw+17|0]|0|l)&65535;aO=e}else{aO=aN}if(U&(T|0)<(aO|0)){b[au+26>>1]=(d[aw+18|0]|0|l)&65535;aP=e}else{aP=aO}if(W&(V|0)<(aP|0)){b[au+24>>1]=(d[aw+19|0]|0|l)&65535;aQ=e}else{aQ=aP}if(Y&(X|0)<(aQ|0)){b[au+22>>1]=(d[aw+20|0]|0|l)&65535;aR=e}else{aR=aQ}if(_&(Z|0)<(aR|0)){b[au+20>>1]=(d[aw+21|0]|0|l)&65535;aS=e}else{aS=aR}if(aa&($|0)<(aS|0)){b[au+18>>1]=(d[aw+22|0]|0|l)&65535;aT=e}else{aT=aS}if(ac&(ab|0)<(aT|0)){b[au+16>>1]=(d[aw+23|0]|0|l)&65535;aU=e}else{aU=aT}if(ae&(ad|0)<(aU|0)){b[au+14>>1]=(d[aw+24|0]|0|l)&65535;aV=e}else{aV=aU}if(ah&(af|0)<(aV|0)){b[au+12>>1]=(d[aw+25|0]|0|l)&65535;aW=e}else{aW=aV}if(aj&(ai|0)<(aW|0)){b[au+10>>1]=(d[aw+26|0]|0|l)&65535;aX=e}else{aX=aW}if(al&(ak|0)<(aX|0)){b[au+8>>1]=(d[aw+27|0]|0|l)&65535;aY=e}else{aY=aX}if(an&(am|0)<(aY|0)){b[au+6>>1]=(d[aw+28|0]|0|l)&65535;aZ=e}else{aZ=aY}if(ap&(ao|0)<(aZ|0)){b[au+4>>1]=(d[aw+29|0]|0|l)&65535;a_=e}else{a_=aZ}if(ar&(aq|0)<(a_|0)){b[au+2>>1]=(d[aw+30|0]|0|l)&65535;a$=e}else{a$=a_}if(!(as&(a$|0)>(f|0))){a0=a$;break}b[au>>1]=(d[aw+31|0]|0|l)&65535;a0=e}else{a0=av}}while(0);a1=aw+32|0;if((k|0)<=0){break}au=au+(-a0<<1)|0;k=k-1|0;av=a0;aw=a1}c[2112928]=a1;return}function SW(a,e,f,g,h,i,j,k,l){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0;m=h<<i|k;k=l+(e<<10)|0;c[2112928]=k;e=c[2113068]|0;l=a+((ag(e,g)|0)+f<<1)|0;f=0;g=k;while(1){k=d[g]|0;if((k|0)!=(j|0)){b[l>>1]=(k|m)&65535}k=d[g+1|0]|0;if((k|0)!=(j|0)){b[l+2>>1]=(k|m)&65535}k=d[g+2|0]|0;if((k|0)!=(j|0)){b[l+4>>1]=(k|m)&65535}k=d[g+3|0]|0;if((k|0)!=(j|0)){b[l+6>>1]=(k|m)&65535}k=d[g+4|0]|0;if((k|0)!=(j|0)){b[l+8>>1]=(k|m)&65535}k=d[g+5|0]|0;if((k|0)!=(j|0)){b[l+10>>1]=(k|m)&65535}k=d[g+6|0]|0;if((k|0)!=(j|0)){b[l+12>>1]=(k|m)&65535}k=d[g+7|0]|0;if((k|0)!=(j|0)){b[l+14>>1]=(k|m)&65535}k=d[g+8|0]|0;if((k|0)!=(j|0)){b[l+16>>1]=(k|m)&65535}k=d[g+9|0]|0;if((k|0)!=(j|0)){b[l+18>>1]=(k|m)&65535}k=d[g+10|0]|0;if((k|0)!=(j|0)){b[l+20>>1]=(k|m)&65535}k=d[g+11|0]|0;if((k|0)!=(j|0)){b[l+22>>1]=(k|m)&65535}k=d[g+12|0]|0;if((k|0)!=(j|0)){b[l+24>>1]=(k|m)&65535}k=d[g+13|0]|0;if((k|0)!=(j|0)){b[l+26>>1]=(k|m)&65535}k=d[g+14|0]|0;if((k|0)!=(j|0)){b[l+28>>1]=(k|m)&65535}k=d[g+15|0]|0;if((k|0)!=(j|0)){b[l+30>>1]=(k|m)&65535}k=d[g+16|0]|0;if((k|0)!=(j|0)){b[l+32>>1]=(k|m)&65535}k=d[g+17|0]|0;if((k|0)!=(j|0)){b[l+34>>1]=(k|m)&65535}k=d[g+18|0]|0;if((k|0)!=(j|0)){b[l+36>>1]=(k|m)&65535}k=d[g+19|0]|0;if((k|0)!=(j|0)){b[l+38>>1]=(k|m)&65535}k=d[g+20|0]|0;if((k|0)!=(j|0)){b[l+40>>1]=(k|m)&65535}k=d[g+21|0]|0;if((k|0)!=(j|0)){b[l+42>>1]=(k|m)&65535}k=d[g+22|0]|0;if((k|0)!=(j|0)){b[l+44>>1]=(k|m)&65535}k=d[g+23|0]|0;if((k|0)!=(j|0)){b[l+46>>1]=(k|m)&65535}k=d[g+24|0]|0;if((k|0)!=(j|0)){b[l+48>>1]=(k|m)&65535}k=d[g+25|0]|0;if((k|0)!=(j|0)){b[l+50>>1]=(k|m)&65535}k=d[g+26|0]|0;if((k|0)!=(j|0)){b[l+52>>1]=(k|m)&65535}k=d[g+27|0]|0;if((k|0)!=(j|0)){b[l+54>>1]=(k|m)&65535}k=d[g+28|0]|0;if((k|0)!=(j|0)){b[l+56>>1]=(k|m)&65535}k=d[g+29|0]|0;if((k|0)!=(j|0)){b[l+58>>1]=(k|m)&65535}k=d[g+30|0]|0;if((k|0)!=(j|0)){b[l+60>>1]=(k|m)&65535}k=d[g+31|0]|0;if((k|0)!=(j|0)){b[l+62>>1]=(k|m)&65535}k=f+1|0;n=g+32|0;if((k|0)<32){l=l+(e<<1)|0;f=k;g=n}else{break}}c[2112928]=n;return}function SX(a,e,f,g,h,i,j,k,l){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0;m=h<<i|k;k=l+(e<<10)|0;c[2112928]=k;e=c[2113068]|0;l=a+((ag(e,g)|0)+f<<1)|0;a=(f|0)>-1;i=f+1|0;h=(i|0)>-1;n=f+2|0;o=(n|0)>-1;p=f+3|0;q=(p|0)>-1;r=f+4|0;s=(r|0)>-1;t=f+5|0;u=(t|0)>-1;v=f+6|0;w=(v|0)>-1;x=f+7|0;y=(x|0)>-1;z=f+8|0;A=(z|0)>-1;B=f+9|0;C=(B|0)>-1;D=f+10|0;E=(D|0)>-1;F=f+11|0;G=(F|0)>-1;H=f+12|0;I=(H|0)>-1;J=f+13|0;K=(J|0)>-1;L=f+14|0;M=(L|0)>-1;N=f+15|0;O=(N|0)>-1;P=f+16|0;Q=(P|0)>-1;R=f+17|0;S=(R|0)>-1;T=f+18|0;U=(T|0)>-1;V=f+19|0;W=(V|0)>-1;X=f+20|0;Y=(X|0)>-1;Z=f+21|0;_=(Z|0)>-1;$=f+22|0;aa=($|0)>-1;ab=f+23|0;ac=(ab|0)>-1;ad=f+24|0;ae=(ad|0)>-1;af=f+25|0;ah=(af|0)>-1;ai=f+26|0;aj=(ai|0)>-1;ak=f+27|0;al=(ak|0)>-1;am=f+28|0;an=(am|0)>-1;ao=f+29|0;ap=(ao|0)>-1;aq=f+30|0;ar=(aq|0)>-1;as=f+31|0;at=(as|0)>-1;au=c[2113070]|0;av=l;l=0;aw=e;ax=k;while(1){k=l+g|0;do{if((k|0)>-1&(k|0)<(au|0)){do{if(a&(aw|0)>(f|0)){ay=d[ax]|0;if((ay|0)==(j|0)){az=aw;break}b[av>>1]=(ay|m)&65535;az=e}else{az=aw}}while(0);do{if(h&(i|0)<(az|0)){ay=d[ax+1|0]|0;if((ay|0)==(j|0)){aA=az;break}b[av+2>>1]=(ay|m)&65535;aA=e}else{aA=az}}while(0);do{if(o&(n|0)<(aA|0)){ay=d[ax+2|0]|0;if((ay|0)==(j|0)){aB=aA;break}b[av+4>>1]=(ay|m)&65535;aB=e}else{aB=aA}}while(0);do{if(q&(p|0)<(aB|0)){ay=d[ax+3|0]|0;if((ay|0)==(j|0)){aC=aB;break}b[av+6>>1]=(ay|m)&65535;aC=e}else{aC=aB}}while(0);do{if(s&(r|0)<(aC|0)){ay=d[ax+4|0]|0;if((ay|0)==(j|0)){aD=aC;break}b[av+8>>1]=(ay|m)&65535;aD=e}else{aD=aC}}while(0);do{if(u&(t|0)<(aD|0)){ay=d[ax+5|0]|0;if((ay|0)==(j|0)){aE=aD;break}b[av+10>>1]=(ay|m)&65535;aE=e}else{aE=aD}}while(0);do{if(w&(v|0)<(aE|0)){ay=d[ax+6|0]|0;if((ay|0)==(j|0)){aF=aE;break}b[av+12>>1]=(ay|m)&65535;aF=e}else{aF=aE}}while(0);do{if(y&(x|0)<(aF|0)){ay=d[ax+7|0]|0;if((ay|0)==(j|0)){aG=aF;break}b[av+14>>1]=(ay|m)&65535;aG=e}else{aG=aF}}while(0);do{if(A&(z|0)<(aG|0)){ay=d[ax+8|0]|0;if((ay|0)==(j|0)){aH=aG;break}b[av+16>>1]=(ay|m)&65535;aH=e}else{aH=aG}}while(0);do{if(C&(B|0)<(aH|0)){ay=d[ax+9|0]|0;if((ay|0)==(j|0)){aI=aH;break}b[av+18>>1]=(ay|m)&65535;aI=e}else{aI=aH}}while(0);do{if(E&(D|0)<(aI|0)){ay=d[ax+10|0]|0;if((ay|0)==(j|0)){aJ=aI;break}b[av+20>>1]=(ay|m)&65535;aJ=e}else{aJ=aI}}while(0);do{if(G&(F|0)<(aJ|0)){ay=d[ax+11|0]|0;if((ay|0)==(j|0)){aK=aJ;break}b[av+22>>1]=(ay|m)&65535;aK=e}else{aK=aJ}}while(0);do{if(I&(H|0)<(aK|0)){ay=d[ax+12|0]|0;if((ay|0)==(j|0)){aL=aK;break}b[av+24>>1]=(ay|m)&65535;aL=e}else{aL=aK}}while(0);do{if(K&(J|0)<(aL|0)){ay=d[ax+13|0]|0;if((ay|0)==(j|0)){aM=aL;break}b[av+26>>1]=(ay|m)&65535;aM=e}else{aM=aL}}while(0);do{if(M&(L|0)<(aM|0)){ay=d[ax+14|0]|0;if((ay|0)==(j|0)){aN=aM;break}b[av+28>>1]=(ay|m)&65535;aN=e}else{aN=aM}}while(0);do{if(O&(N|0)<(aN|0)){ay=d[ax+15|0]|0;if((ay|0)==(j|0)){aO=aN;break}b[av+30>>1]=(ay|m)&65535;aO=e}else{aO=aN}}while(0);do{if(Q&(P|0)<(aO|0)){ay=d[ax+16|0]|0;if((ay|0)==(j|0)){aP=aO;break}b[av+32>>1]=(ay|m)&65535;aP=e}else{aP=aO}}while(0);do{if(S&(R|0)<(aP|0)){ay=d[ax+17|0]|0;if((ay|0)==(j|0)){aQ=aP;break}b[av+34>>1]=(ay|m)&65535;aQ=e}else{aQ=aP}}while(0);do{if(U&(T|0)<(aQ|0)){ay=d[ax+18|0]|0;if((ay|0)==(j|0)){aR=aQ;break}b[av+36>>1]=(ay|m)&65535;aR=e}else{aR=aQ}}while(0);do{if(W&(V|0)<(aR|0)){ay=d[ax+19|0]|0;if((ay|0)==(j|0)){aS=aR;break}b[av+38>>1]=(ay|m)&65535;aS=e}else{aS=aR}}while(0);do{if(Y&(X|0)<(aS|0)){ay=d[ax+20|0]|0;if((ay|0)==(j|0)){aT=aS;break}b[av+40>>1]=(ay|m)&65535;aT=e}else{aT=aS}}while(0);do{if(_&(Z|0)<(aT|0)){ay=d[ax+21|0]|0;if((ay|0)==(j|0)){aU=aT;break}b[av+42>>1]=(ay|m)&65535;aU=e}else{aU=aT}}while(0);do{if(aa&($|0)<(aU|0)){ay=d[ax+22|0]|0;if((ay|0)==(j|0)){aV=aU;break}b[av+44>>1]=(ay|m)&65535;aV=e}else{aV=aU}}while(0);do{if(ac&(ab|0)<(aV|0)){ay=d[ax+23|0]|0;if((ay|0)==(j|0)){aW=aV;break}b[av+46>>1]=(ay|m)&65535;aW=e}else{aW=aV}}while(0);do{if(ae&(ad|0)<(aW|0)){ay=d[ax+24|0]|0;if((ay|0)==(j|0)){aX=aW;break}b[av+48>>1]=(ay|m)&65535;aX=e}else{aX=aW}}while(0);do{if(ah&(af|0)<(aX|0)){ay=d[ax+25|0]|0;if((ay|0)==(j|0)){aY=aX;break}b[av+50>>1]=(ay|m)&65535;aY=e}else{aY=aX}}while(0);do{if(aj&(ai|0)<(aY|0)){ay=d[ax+26|0]|0;if((ay|0)==(j|0)){aZ=aY;break}b[av+52>>1]=(ay|m)&65535;aZ=e}else{aZ=aY}}while(0);do{if(al&(ak|0)<(aZ|0)){ay=d[ax+27|0]|0;if((ay|0)==(j|0)){a_=aZ;break}b[av+54>>1]=(ay|m)&65535;a_=e}else{a_=aZ}}while(0);do{if(an&(am|0)<(a_|0)){ay=d[ax+28|0]|0;if((ay|0)==(j|0)){a$=a_;break}b[av+56>>1]=(ay|m)&65535;a$=e}else{a$=a_}}while(0);do{if(ap&(ao|0)<(a$|0)){ay=d[ax+29|0]|0;if((ay|0)==(j|0)){a0=a$;break}b[av+58>>1]=(ay|m)&65535;a0=e}else{a0=a$}}while(0);do{if(ar&(aq|0)<(a0|0)){ay=d[ax+30|0]|0;if((ay|0)==(j|0)){a1=a0;break}b[av+60>>1]=(ay|m)&65535;a1=e}else{a1=a0}}while(0);if(!(at&(as|0)<(a1|0))){a2=a1;break}ay=d[ax+31|0]|0;if((ay|0)==(j|0)){a2=a1;break}b[av+62>>1]=(ay|m)&65535;a2=e}else{a2=aw}}while(0);k=l+1|0;a3=ax+32|0;if((k|0)>=32){break}av=av+(a2<<1)|0;l=k;aw=a2;ax=a3}c[2112928]=a3;return}function SY(a,e,f,g,h,i,j,k,l){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0;m=h<<i|k;k=l+(e<<10)|0;c[2112928]=k;e=c[2113068]|0;l=a+((ag(e,g)|0)+f<<1)|0;f=0;g=k;while(1){k=d[g]|0;if((k|0)!=(j|0)){b[l+62>>1]=(k|m)&65535}k=d[g+1|0]|0;if((k|0)!=(j|0)){b[l+60>>1]=(k|m)&65535}k=d[g+2|0]|0;if((k|0)!=(j|0)){b[l+58>>1]=(k|m)&65535}k=d[g+3|0]|0;if((k|0)!=(j|0)){b[l+56>>1]=(k|m)&65535}k=d[g+4|0]|0;if((k|0)!=(j|0)){b[l+54>>1]=(k|m)&65535}k=d[g+5|0]|0;if((k|0)!=(j|0)){b[l+52>>1]=(k|m)&65535}k=d[g+6|0]|0;if((k|0)!=(j|0)){b[l+50>>1]=(k|m)&65535}k=d[g+7|0]|0;if((k|0)!=(j|0)){b[l+48>>1]=(k|m)&65535}k=d[g+8|0]|0;if((k|0)!=(j|0)){b[l+46>>1]=(k|m)&65535}k=d[g+9|0]|0;if((k|0)!=(j|0)){b[l+44>>1]=(k|m)&65535}k=d[g+10|0]|0;if((k|0)!=(j|0)){b[l+42>>1]=(k|m)&65535}k=d[g+11|0]|0;if((k|0)!=(j|0)){b[l+40>>1]=(k|m)&65535}k=d[g+12|0]|0;if((k|0)!=(j|0)){b[l+38>>1]=(k|m)&65535}k=d[g+13|0]|0;if((k|0)!=(j|0)){b[l+36>>1]=(k|m)&65535}k=d[g+14|0]|0;if((k|0)!=(j|0)){b[l+34>>1]=(k|m)&65535}k=d[g+15|0]|0;if((k|0)!=(j|0)){b[l+32>>1]=(k|m)&65535}k=d[g+16|0]|0;if((k|0)!=(j|0)){b[l+30>>1]=(k|m)&65535}k=d[g+17|0]|0;if((k|0)!=(j|0)){b[l+28>>1]=(k|m)&65535}k=d[g+18|0]|0;if((k|0)!=(j|0)){b[l+26>>1]=(k|m)&65535}k=d[g+19|0]|0;if((k|0)!=(j|0)){b[l+24>>1]=(k|m)&65535}k=d[g+20|0]|0;if((k|0)!=(j|0)){b[l+22>>1]=(k|m)&65535}k=d[g+21|0]|0;if((k|0)!=(j|0)){b[l+20>>1]=(k|m)&65535}k=d[g+22|0]|0;if((k|0)!=(j|0)){b[l+18>>1]=(k|m)&65535}k=d[g+23|0]|0;if((k|0)!=(j|0)){b[l+16>>1]=(k|m)&65535}k=d[g+24|0]|0;if((k|0)!=(j|0)){b[l+14>>1]=(k|m)&65535}k=d[g+25|0]|0;if((k|0)!=(j|0)){b[l+12>>1]=(k|m)&65535}k=d[g+26|0]|0;if((k|0)!=(j|0)){b[l+10>>1]=(k|m)&65535}k=d[g+27|0]|0;if((k|0)!=(j|0)){b[l+8>>1]=(k|m)&65535}k=d[g+28|0]|0;if((k|0)!=(j|0)){b[l+6>>1]=(k|m)&65535}k=d[g+29|0]|0;if((k|0)!=(j|0)){b[l+4>>1]=(k|m)&65535}k=d[g+30|0]|0;if((k|0)!=(j|0)){b[l+2>>1]=(k|m)&65535}k=d[g+31|0]|0;if((k|0)!=(j|0)){b[l>>1]=(k|m)&65535}k=f+1|0;n=g+32|0;if((k|0)<32){l=l+(e<<1)|0;f=k;g=n}else{break}}c[2112928]=n;return}function SZ(a,e,f,g,h,i,j,k,l){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0;m=h<<i|k;k=l+(e<<10)|0;c[2112928]=k;e=c[2113068]|0;l=a+((ag(e,g)|0)+f<<1)|0;a=f+31|0;i=(a|0)>-1;h=f+30|0;n=(h|0)>-1;o=f+29|0;p=(o|0)>-1;q=f+28|0;r=(q|0)>-1;s=f+27|0;t=(s|0)>-1;u=f+26|0;v=(u|0)>-1;w=f+25|0;x=(w|0)>-1;y=f+24|0;z=(y|0)>-1;A=f+23|0;B=(A|0)>-1;C=f+22|0;D=(C|0)>-1;E=f+21|0;F=(E|0)>-1;G=f+20|0;H=(G|0)>-1;I=f+19|0;J=(I|0)>-1;K=f+18|0;L=(K|0)>-1;M=f+17|0;N=(M|0)>-1;O=f+16|0;P=(O|0)>-1;Q=f+15|0;R=(Q|0)>-1;S=f+14|0;T=(S|0)>-1;U=f+13|0;V=(U|0)>-1;W=f+12|0;X=(W|0)>-1;Y=f+11|0;Z=(Y|0)>-1;_=f+10|0;$=(_|0)>-1;aa=f+9|0;ab=(aa|0)>-1;ac=f+8|0;ad=(ac|0)>-1;ae=f+7|0;af=(ae|0)>-1;ah=f+6|0;ai=(ah|0)>-1;aj=f+5|0;ak=(aj|0)>-1;al=f+4|0;am=(al|0)>-1;an=f+3|0;ao=(an|0)>-1;ap=f+2|0;aq=(ap|0)>-1;ar=f+1|0;as=(ar|0)>-1;at=(f|0)>-1;au=c[2113070]|0;av=l;l=0;aw=e;ax=k;while(1){k=l+g|0;do{if((k|0)>-1&(k|0)<(au|0)){do{if(i&(a|0)<(aw|0)){ay=d[ax]|0;if((ay|0)==(j|0)){az=aw;break}b[av+62>>1]=(ay|m)&65535;az=e}else{az=aw}}while(0);do{if(n&(h|0)<(az|0)){ay=d[ax+1|0]|0;if((ay|0)==(j|0)){aA=az;break}b[av+60>>1]=(ay|m)&65535;aA=e}else{aA=az}}while(0);do{if(p&(o|0)<(aA|0)){ay=d[ax+2|0]|0;if((ay|0)==(j|0)){aB=aA;break}b[av+58>>1]=(ay|m)&65535;aB=e}else{aB=aA}}while(0);do{if(r&(q|0)<(aB|0)){ay=d[ax+3|0]|0;if((ay|0)==(j|0)){aC=aB;break}b[av+56>>1]=(ay|m)&65535;aC=e}else{aC=aB}}while(0);do{if(t&(s|0)<(aC|0)){ay=d[ax+4|0]|0;if((ay|0)==(j|0)){aD=aC;break}b[av+54>>1]=(ay|m)&65535;aD=e}else{aD=aC}}while(0);do{if(v&(u|0)<(aD|0)){ay=d[ax+5|0]|0;if((ay|0)==(j|0)){aE=aD;break}b[av+52>>1]=(ay|m)&65535;aE=e}else{aE=aD}}while(0);do{if(x&(w|0)<(aE|0)){ay=d[ax+6|0]|0;if((ay|0)==(j|0)){aF=aE;break}b[av+50>>1]=(ay|m)&65535;aF=e}else{aF=aE}}while(0);do{if(z&(y|0)<(aF|0)){ay=d[ax+7|0]|0;if((ay|0)==(j|0)){aG=aF;break}b[av+48>>1]=(ay|m)&65535;aG=e}else{aG=aF}}while(0);do{if(B&(A|0)<(aG|0)){ay=d[ax+8|0]|0;if((ay|0)==(j|0)){aH=aG;break}b[av+46>>1]=(ay|m)&65535;aH=e}else{aH=aG}}while(0);do{if(D&(C|0)<(aH|0)){ay=d[ax+9|0]|0;if((ay|0)==(j|0)){aI=aH;break}b[av+44>>1]=(ay|m)&65535;aI=e}else{aI=aH}}while(0);do{if(F&(E|0)<(aI|0)){ay=d[ax+10|0]|0;if((ay|0)==(j|0)){aJ=aI;break}b[av+42>>1]=(ay|m)&65535;aJ=e}else{aJ=aI}}while(0);do{if(H&(G|0)<(aJ|0)){ay=d[ax+11|0]|0;if((ay|0)==(j|0)){aK=aJ;break}b[av+40>>1]=(ay|m)&65535;aK=e}else{aK=aJ}}while(0);do{if(J&(I|0)<(aK|0)){ay=d[ax+12|0]|0;if((ay|0)==(j|0)){aL=aK;break}b[av+38>>1]=(ay|m)&65535;aL=e}else{aL=aK}}while(0);do{if(L&(K|0)<(aL|0)){ay=d[ax+13|0]|0;if((ay|0)==(j|0)){aM=aL;break}b[av+36>>1]=(ay|m)&65535;aM=e}else{aM=aL}}while(0);do{if(N&(M|0)<(aM|0)){ay=d[ax+14|0]|0;if((ay|0)==(j|0)){aN=aM;break}b[av+34>>1]=(ay|m)&65535;aN=e}else{aN=aM}}while(0);do{if(P&(O|0)<(aN|0)){ay=d[ax+15|0]|0;if((ay|0)==(j|0)){aO=aN;break}b[av+32>>1]=(ay|m)&65535;aO=e}else{aO=aN}}while(0);do{if(R&(Q|0)<(aO|0)){ay=d[ax+16|0]|0;if((ay|0)==(j|0)){aP=aO;break}b[av+30>>1]=(ay|m)&65535;aP=e}else{aP=aO}}while(0);do{if(T&(S|0)<(aP|0)){ay=d[ax+17|0]|0;if((ay|0)==(j|0)){aQ=aP;break}b[av+28>>1]=(ay|m)&65535;aQ=e}else{aQ=aP}}while(0);do{if(V&(U|0)<(aQ|0)){ay=d[ax+18|0]|0;if((ay|0)==(j|0)){aR=aQ;break}b[av+26>>1]=(ay|m)&65535;aR=e}else{aR=aQ}}while(0);do{if(X&(W|0)<(aR|0)){ay=d[ax+19|0]|0;if((ay|0)==(j|0)){aS=aR;break}b[av+24>>1]=(ay|m)&65535;aS=e}else{aS=aR}}while(0);do{if(Z&(Y|0)<(aS|0)){ay=d[ax+20|0]|0;if((ay|0)==(j|0)){aT=aS;break}b[av+22>>1]=(ay|m)&65535;aT=e}else{aT=aS}}while(0);do{if($&(_|0)<(aT|0)){ay=d[ax+21|0]|0;if((ay|0)==(j|0)){aU=aT;break}b[av+20>>1]=(ay|m)&65535;aU=e}else{aU=aT}}while(0);do{if(ab&(aa|0)<(aU|0)){ay=d[ax+22|0]|0;if((ay|0)==(j|0)){aV=aU;break}b[av+18>>1]=(ay|m)&65535;aV=e}else{aV=aU}}while(0);do{if(ad&(ac|0)<(aV|0)){ay=d[ax+23|0]|0;if((ay|0)==(j|0)){aW=aV;break}b[av+16>>1]=(ay|m)&65535;aW=e}else{aW=aV}}while(0);do{if(af&(ae|0)<(aW|0)){ay=d[ax+24|0]|0;if((ay|0)==(j|0)){aX=aW;break}b[av+14>>1]=(ay|m)&65535;aX=e}else{aX=aW}}while(0);do{if(ai&(ah|0)<(aX|0)){ay=d[ax+25|0]|0;if((ay|0)==(j|0)){aY=aX;break}b[av+12>>1]=(ay|m)&65535;aY=e}else{aY=aX}}while(0);do{if(ak&(aj|0)<(aY|0)){ay=d[ax+26|0]|0;if((ay|0)==(j|0)){aZ=aY;break}b[av+10>>1]=(ay|m)&65535;aZ=e}else{aZ=aY}}while(0);do{if(am&(al|0)<(aZ|0)){ay=d[ax+27|0]|0;if((ay|0)==(j|0)){a_=aZ;break}b[av+8>>1]=(ay|m)&65535;a_=e}else{a_=aZ}}while(0);do{if(ao&(an|0)<(a_|0)){ay=d[ax+28|0]|0;if((ay|0)==(j|0)){a$=a_;break}b[av+6>>1]=(ay|m)&65535;a$=e}else{a$=a_}}while(0);do{if(aq&(ap|0)<(a$|0)){ay=d[ax+29|0]|0;if((ay|0)==(j|0)){a0=a$;break}b[av+4>>1]=(ay|m)&65535;a0=e}else{a0=a$}}while(0);do{if(as&(ar|0)<(a0|0)){ay=d[ax+30|0]|0;if((ay|0)==(j|0)){a1=a0;break}b[av+2>>1]=(ay|m)&65535;a1=e}else{a1=a0}}while(0);if(!(at&(a1|0)>(f|0))){a2=a1;break}ay=d[ax+31|0]|0;if((ay|0)==(j|0)){a2=a1;break}b[av>>1]=(ay|m)&65535;a2=e}else{a2=aw}}while(0);k=l+1|0;a3=ax+32|0;if((k|0)>=32){break}av=av+(a2<<1)|0;l=k;aw=a2;ax=a3}c[2112928]=a3;return}function S_(a,e,f,g,h,i,j,k){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0;l=h<<i;i=k+(e<<10)|0;c[2112928]=i;e=c[2113068]|0;k=-e|0;h=a+((ag(e,g+31|0)|0)+f<<1)|0;f=31;g=i;while(1){i=d[g]|0;if((i|0)!=(j|0)){b[h>>1]=(i|l)&65535}i=d[g+1|0]|0;if((i|0)!=(j|0)){b[h+2>>1]=(i|l)&65535}i=d[g+2|0]|0;if((i|0)!=(j|0)){b[h+4>>1]=(i|l)&65535}i=d[g+3|0]|0;if((i|0)!=(j|0)){b[h+6>>1]=(i|l)&65535}i=d[g+4|0]|0;if((i|0)!=(j|0)){b[h+8>>1]=(i|l)&65535}i=d[g+5|0]|0;if((i|0)!=(j|0)){b[h+10>>1]=(i|l)&65535}i=d[g+6|0]|0;if((i|0)!=(j|0)){b[h+12>>1]=(i|l)&65535}i=d[g+7|0]|0;if((i|0)!=(j|0)){b[h+14>>1]=(i|l)&65535}i=d[g+8|0]|0;if((i|0)!=(j|0)){b[h+16>>1]=(i|l)&65535}i=d[g+9|0]|0;if((i|0)!=(j|0)){b[h+18>>1]=(i|l)&65535}i=d[g+10|0]|0;if((i|0)!=(j|0)){b[h+20>>1]=(i|l)&65535}i=d[g+11|0]|0;if((i|0)!=(j|0)){b[h+22>>1]=(i|l)&65535}i=d[g+12|0]|0;if((i|0)!=(j|0)){b[h+24>>1]=(i|l)&65535}i=d[g+13|0]|0;if((i|0)!=(j|0)){b[h+26>>1]=(i|l)&65535}i=d[g+14|0]|0;if((i|0)!=(j|0)){b[h+28>>1]=(i|l)&65535}i=d[g+15|0]|0;if((i|0)!=(j|0)){b[h+30>>1]=(i|l)&65535}i=d[g+16|0]|0;if((i|0)!=(j|0)){b[h+32>>1]=(i|l)&65535}i=d[g+17|0]|0;if((i|0)!=(j|0)){b[h+34>>1]=(i|l)&65535}i=d[g+18|0]|0;if((i|0)!=(j|0)){b[h+36>>1]=(i|l)&65535}i=d[g+19|0]|0;if((i|0)!=(j|0)){b[h+38>>1]=(i|l)&65535}i=d[g+20|0]|0;if((i|0)!=(j|0)){b[h+40>>1]=(i|l)&65535}i=d[g+21|0]|0;if((i|0)!=(j|0)){b[h+42>>1]=(i|l)&65535}i=d[g+22|0]|0;if((i|0)!=(j|0)){b[h+44>>1]=(i|l)&65535}i=d[g+23|0]|0;if((i|0)!=(j|0)){b[h+46>>1]=(i|l)&65535}i=d[g+24|0]|0;if((i|0)!=(j|0)){b[h+48>>1]=(i|l)&65535}i=d[g+25|0]|0;if((i|0)!=(j|0)){b[h+50>>1]=(i|l)&65535}i=d[g+26|0]|0;if((i|0)!=(j|0)){b[h+52>>1]=(i|l)&65535}i=d[g+27|0]|0;if((i|0)!=(j|0)){b[h+54>>1]=(i|l)&65535}i=d[g+28|0]|0;if((i|0)!=(j|0)){b[h+56>>1]=(i|l)&65535}i=d[g+29|0]|0;if((i|0)!=(j|0)){b[h+58>>1]=(i|l)&65535}i=d[g+30|0]|0;if((i|0)!=(j|0)){b[h+60>>1]=(i|l)&65535}i=d[g+31|0]|0;if((i|0)!=(j|0)){b[h+62>>1]=(i|l)&65535}m=g+32|0;if((f|0)>0){h=h+(k<<1)|0;f=f-1|0;g=m}else{break}}c[2112928]=m;return}function S$(a,e,f,g,h,i,j,k,l){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0;m=h<<i|k;k=l+(e<<10)|0;c[2112928]=k;e=c[2113068]|0;l=a+((ag(e,g+31|0)|0)+f<<1)|0;a=(f|0)>-1;i=f+1|0;h=(i|0)>-1;n=f+2|0;o=(n|0)>-1;p=f+3|0;q=(p|0)>-1;r=f+4|0;s=(r|0)>-1;t=f+5|0;u=(t|0)>-1;v=f+6|0;w=(v|0)>-1;x=f+7|0;y=(x|0)>-1;z=f+8|0;A=(z|0)>-1;B=f+9|0;C=(B|0)>-1;D=f+10|0;E=(D|0)>-1;F=f+11|0;G=(F|0)>-1;H=f+12|0;I=(H|0)>-1;J=f+13|0;K=(J|0)>-1;L=f+14|0;M=(L|0)>-1;N=f+15|0;O=(N|0)>-1;P=f+16|0;Q=(P|0)>-1;R=f+17|0;S=(R|0)>-1;T=f+18|0;U=(T|0)>-1;V=f+19|0;W=(V|0)>-1;X=f+20|0;Y=(X|0)>-1;Z=f+21|0;_=(Z|0)>-1;$=f+22|0;aa=($|0)>-1;ab=f+23|0;ac=(ab|0)>-1;ad=f+24|0;ae=(ad|0)>-1;af=f+25|0;ah=(af|0)>-1;ai=f+26|0;aj=(ai|0)>-1;ak=f+27|0;al=(ak|0)>-1;am=f+28|0;an=(am|0)>-1;ao=f+29|0;ap=(ao|0)>-1;aq=f+30|0;ar=(aq|0)>-1;as=f+31|0;at=(as|0)>-1;au=c[2113070]|0;av=l;l=31;aw=e;ax=k;while(1){k=l+g|0;do{if((k|0)>-1&(k|0)<(au|0)){do{if(a&(aw|0)>(f|0)){ay=d[ax]|0;if((ay|0)==(j|0)){az=aw;break}b[av>>1]=(ay|m)&65535;az=e}else{az=aw}}while(0);do{if(h&(i|0)<(az|0)){ay=d[ax+1|0]|0;if((ay|0)==(j|0)){aA=az;break}b[av+2>>1]=(ay|m)&65535;aA=e}else{aA=az}}while(0);do{if(o&(n|0)<(aA|0)){ay=d[ax+2|0]|0;if((ay|0)==(j|0)){aB=aA;break}b[av+4>>1]=(ay|m)&65535;aB=e}else{aB=aA}}while(0);do{if(q&(p|0)<(aB|0)){ay=d[ax+3|0]|0;if((ay|0)==(j|0)){aC=aB;break}b[av+6>>1]=(ay|m)&65535;aC=e}else{aC=aB}}while(0);do{if(s&(r|0)<(aC|0)){ay=d[ax+4|0]|0;if((ay|0)==(j|0)){aD=aC;break}b[av+8>>1]=(ay|m)&65535;aD=e}else{aD=aC}}while(0);do{if(u&(t|0)<(aD|0)){ay=d[ax+5|0]|0;if((ay|0)==(j|0)){aE=aD;break}b[av+10>>1]=(ay|m)&65535;aE=e}else{aE=aD}}while(0);do{if(w&(v|0)<(aE|0)){ay=d[ax+6|0]|0;if((ay|0)==(j|0)){aF=aE;break}b[av+12>>1]=(ay|m)&65535;aF=e}else{aF=aE}}while(0);do{if(y&(x|0)<(aF|0)){ay=d[ax+7|0]|0;if((ay|0)==(j|0)){aG=aF;break}b[av+14>>1]=(ay|m)&65535;aG=e}else{aG=aF}}while(0);do{if(A&(z|0)<(aG|0)){ay=d[ax+8|0]|0;if((ay|0)==(j|0)){aH=aG;break}b[av+16>>1]=(ay|m)&65535;aH=e}else{aH=aG}}while(0);do{if(C&(B|0)<(aH|0)){ay=d[ax+9|0]|0;if((ay|0)==(j|0)){aI=aH;break}b[av+18>>1]=(ay|m)&65535;aI=e}else{aI=aH}}while(0);do{if(E&(D|0)<(aI|0)){ay=d[ax+10|0]|0;if((ay|0)==(j|0)){aJ=aI;break}b[av+20>>1]=(ay|m)&65535;aJ=e}else{aJ=aI}}while(0);do{if(G&(F|0)<(aJ|0)){ay=d[ax+11|0]|0;if((ay|0)==(j|0)){aK=aJ;break}b[av+22>>1]=(ay|m)&65535;aK=e}else{aK=aJ}}while(0);do{if(I&(H|0)<(aK|0)){ay=d[ax+12|0]|0;if((ay|0)==(j|0)){aL=aK;break}b[av+24>>1]=(ay|m)&65535;aL=e}else{aL=aK}}while(0);do{if(K&(J|0)<(aL|0)){ay=d[ax+13|0]|0;if((ay|0)==(j|0)){aM=aL;break}b[av+26>>1]=(ay|m)&65535;aM=e}else{aM=aL}}while(0);do{if(M&(L|0)<(aM|0)){ay=d[ax+14|0]|0;if((ay|0)==(j|0)){aN=aM;break}b[av+28>>1]=(ay|m)&65535;aN=e}else{aN=aM}}while(0);do{if(O&(N|0)<(aN|0)){ay=d[ax+15|0]|0;if((ay|0)==(j|0)){aO=aN;break}b[av+30>>1]=(ay|m)&65535;aO=e}else{aO=aN}}while(0);do{if(Q&(P|0)<(aO|0)){ay=d[ax+16|0]|0;if((ay|0)==(j|0)){aP=aO;break}b[av+32>>1]=(ay|m)&65535;aP=e}else{aP=aO}}while(0);do{if(S&(R|0)<(aP|0)){ay=d[ax+17|0]|0;if((ay|0)==(j|0)){aQ=aP;break}b[av+34>>1]=(ay|m)&65535;aQ=e}else{aQ=aP}}while(0);do{if(U&(T|0)<(aQ|0)){ay=d[ax+18|0]|0;if((ay|0)==(j|0)){aR=aQ;break}b[av+36>>1]=(ay|m)&65535;aR=e}else{aR=aQ}}while(0);do{if(W&(V|0)<(aR|0)){ay=d[ax+19|0]|0;if((ay|0)==(j|0)){aS=aR;break}b[av+38>>1]=(ay|m)&65535;aS=e}else{aS=aR}}while(0);do{if(Y&(X|0)<(aS|0)){ay=d[ax+20|0]|0;if((ay|0)==(j|0)){aT=aS;break}b[av+40>>1]=(ay|m)&65535;aT=e}else{aT=aS}}while(0);do{if(_&(Z|0)<(aT|0)){ay=d[ax+21|0]|0;if((ay|0)==(j|0)){aU=aT;break}b[av+42>>1]=(ay|m)&65535;aU=e}else{aU=aT}}while(0);do{if(aa&($|0)<(aU|0)){ay=d[ax+22|0]|0;if((ay|0)==(j|0)){aV=aU;break}b[av+44>>1]=(ay|m)&65535;aV=e}else{aV=aU}}while(0);do{if(ac&(ab|0)<(aV|0)){ay=d[ax+23|0]|0;if((ay|0)==(j|0)){aW=aV;break}b[av+46>>1]=(ay|m)&65535;aW=e}else{aW=aV}}while(0);do{if(ae&(ad|0)<(aW|0)){ay=d[ax+24|0]|0;if((ay|0)==(j|0)){aX=aW;break}b[av+48>>1]=(ay|m)&65535;aX=e}else{aX=aW}}while(0);do{if(ah&(af|0)<(aX|0)){ay=d[ax+25|0]|0;if((ay|0)==(j|0)){aY=aX;break}b[av+50>>1]=(ay|m)&65535;aY=e}else{aY=aX}}while(0);do{if(aj&(ai|0)<(aY|0)){ay=d[ax+26|0]|0;if((ay|0)==(j|0)){aZ=aY;break}b[av+52>>1]=(ay|m)&65535;aZ=e}else{aZ=aY}}while(0);do{if(al&(ak|0)<(aZ|0)){ay=d[ax+27|0]|0;if((ay|0)==(j|0)){a_=aZ;break}b[av+54>>1]=(ay|m)&65535;a_=e}else{a_=aZ}}while(0);do{if(an&(am|0)<(a_|0)){ay=d[ax+28|0]|0;if((ay|0)==(j|0)){a$=a_;break}b[av+56>>1]=(ay|m)&65535;a$=e}else{a$=a_}}while(0);do{if(ap&(ao|0)<(a$|0)){ay=d[ax+29|0]|0;if((ay|0)==(j|0)){a0=a$;break}b[av+58>>1]=(ay|m)&65535;a0=e}else{a0=a$}}while(0);do{if(ar&(aq|0)<(a0|0)){ay=d[ax+30|0]|0;if((ay|0)==(j|0)){a1=a0;break}b[av+60>>1]=(ay|m)&65535;a1=e}else{a1=a0}}while(0);if(!(at&(as|0)<(a1|0))){a2=a1;break}ay=d[ax+31|0]|0;if((ay|0)==(j|0)){a2=a1;break}b[av+62>>1]=(ay|m)&65535;a2=e}else{a2=aw}}while(0);a3=ax+32|0;if((l|0)<=0){break}av=av+(-a2<<1)|0;l=l-1|0;aw=a2;ax=a3}c[2112928]=a3;return}function S0(a,e,f,g,h,i,j,k){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0;l=h<<i;i=k+(e<<10)|0;c[2112928]=i;e=c[2113068]|0;k=-e|0;h=a+((ag(e,g+31|0)|0)+f<<1)|0;f=31;g=i;while(1){i=d[g]|0;if((i|0)!=(j|0)){b[h+62>>1]=(i|l)&65535}i=d[g+1|0]|0;if((i|0)!=(j|0)){b[h+60>>1]=(i|l)&65535}i=d[g+2|0]|0;if((i|0)!=(j|0)){b[h+58>>1]=(i|l)&65535}i=d[g+3|0]|0;if((i|0)!=(j|0)){b[h+56>>1]=(i|l)&65535}i=d[g+4|0]|0;if((i|0)!=(j|0)){b[h+54>>1]=(i|l)&65535}i=d[g+5|0]|0;if((i|0)!=(j|0)){b[h+52>>1]=(i|l)&65535}i=d[g+6|0]|0;if((i|0)!=(j|0)){b[h+50>>1]=(i|l)&65535}i=d[g+7|0]|0;if((i|0)!=(j|0)){b[h+48>>1]=(i|l)&65535}i=d[g+8|0]|0;if((i|0)!=(j|0)){b[h+46>>1]=(i|l)&65535}i=d[g+9|0]|0;if((i|0)!=(j|0)){b[h+44>>1]=(i|l)&65535}i=d[g+10|0]|0;if((i|0)!=(j|0)){b[h+42>>1]=(i|l)&65535}i=d[g+11|0]|0;if((i|0)!=(j|0)){b[h+40>>1]=(i|l)&65535}i=d[g+12|0]|0;if((i|0)!=(j|0)){b[h+38>>1]=(i|l)&65535}i=d[g+13|0]|0;if((i|0)!=(j|0)){b[h+36>>1]=(i|l)&65535}i=d[g+14|0]|0;if((i|0)!=(j|0)){b[h+34>>1]=(i|l)&65535}i=d[g+15|0]|0;if((i|0)!=(j|0)){b[h+32>>1]=(i|l)&65535}i=d[g+16|0]|0;if((i|0)!=(j|0)){b[h+30>>1]=(i|l)&65535}i=d[g+17|0]|0;if((i|0)!=(j|0)){b[h+28>>1]=(i|l)&65535}i=d[g+18|0]|0;if((i|0)!=(j|0)){b[h+26>>1]=(i|l)&65535}i=d[g+19|0]|0;if((i|0)!=(j|0)){b[h+24>>1]=(i|l)&65535}i=d[g+20|0]|0;if((i|0)!=(j|0)){b[h+22>>1]=(i|l)&65535}i=d[g+21|0]|0;if((i|0)!=(j|0)){b[h+20>>1]=(i|l)&65535}i=d[g+22|0]|0;if((i|0)!=(j|0)){b[h+18>>1]=(i|l)&65535}i=d[g+23|0]|0;if((i|0)!=(j|0)){b[h+16>>1]=(i|l)&65535}i=d[g+24|0]|0;if((i|0)!=(j|0)){b[h+14>>1]=(i|l)&65535}i=d[g+25|0]|0;if((i|0)!=(j|0)){b[h+12>>1]=(i|l)&65535}i=d[g+26|0]|0;if((i|0)!=(j|0)){b[h+10>>1]=(i|l)&65535}i=d[g+27|0]|0;if((i|0)!=(j|0)){b[h+8>>1]=(i|l)&65535}i=d[g+28|0]|0;if((i|0)!=(j|0)){b[h+6>>1]=(i|l)&65535}i=d[g+29|0]|0;if((i|0)!=(j|0)){b[h+4>>1]=(i|l)&65535}i=d[g+30|0]|0;if((i|0)!=(j|0)){b[h+2>>1]=(i|l)&65535}i=d[g+31|0]|0;if((i|0)!=(j|0)){b[h>>1]=(i|l)&65535}m=g+32|0;if((f|0)>0){h=h+(k<<1)|0;f=f-1|0;g=m}else{break}}c[2112928]=m;return}function S1(a,e,f,g,h,i,j,k,l){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0;m=h<<i|k;k=l+(e<<10)|0;c[2112928]=k;e=c[2113068]|0;l=a+((ag(e,g+31|0)|0)+f<<1)|0;a=f+31|0;i=(a|0)>-1;h=f+30|0;n=(h|0)>-1;o=f+29|0;p=(o|0)>-1;q=f+28|0;r=(q|0)>-1;s=f+27|0;t=(s|0)>-1;u=f+26|0;v=(u|0)>-1;w=f+25|0;x=(w|0)>-1;y=f+24|0;z=(y|0)>-1;A=f+23|0;B=(A|0)>-1;C=f+22|0;D=(C|0)>-1;E=f+21|0;F=(E|0)>-1;G=f+20|0;H=(G|0)>-1;I=f+19|0;J=(I|0)>-1;K=f+18|0;L=(K|0)>-1;M=f+17|0;N=(M|0)>-1;O=f+16|0;P=(O|0)>-1;Q=f+15|0;R=(Q|0)>-1;S=f+14|0;T=(S|0)>-1;U=f+13|0;V=(U|0)>-1;W=f+12|0;X=(W|0)>-1;Y=f+11|0;Z=(Y|0)>-1;_=f+10|0;$=(_|0)>-1;aa=f+9|0;ab=(aa|0)>-1;ac=f+8|0;ad=(ac|0)>-1;ae=f+7|0;af=(ae|0)>-1;ah=f+6|0;ai=(ah|0)>-1;aj=f+5|0;ak=(aj|0)>-1;al=f+4|0;am=(al|0)>-1;an=f+3|0;ao=(an|0)>-1;ap=f+2|0;aq=(ap|0)>-1;ar=f+1|0;as=(ar|0)>-1;at=(f|0)>-1;au=c[2113070]|0;av=l;l=31;aw=e;ax=k;while(1){k=l+g|0;do{if((k|0)>-1&(k|0)<(au|0)){do{if(i&(a|0)<(aw|0)){ay=d[ax]|0;if((ay|0)==(j|0)){az=aw;break}b[av+62>>1]=(ay|m)&65535;az=e}else{az=aw}}while(0);do{if(n&(h|0)<(az|0)){ay=d[ax+1|0]|0;if((ay|0)==(j|0)){aA=az;break}b[av+60>>1]=(ay|m)&65535;aA=e}else{aA=az}}while(0);do{if(p&(o|0)<(aA|0)){ay=d[ax+2|0]|0;if((ay|0)==(j|0)){aB=aA;break}b[av+58>>1]=(ay|m)&65535;aB=e}else{aB=aA}}while(0);do{if(r&(q|0)<(aB|0)){ay=d[ax+3|0]|0;if((ay|0)==(j|0)){aC=aB;break}b[av+56>>1]=(ay|m)&65535;aC=e}else{aC=aB}}while(0);do{if(t&(s|0)<(aC|0)){ay=d[ax+4|0]|0;if((ay|0)==(j|0)){aD=aC;break}b[av+54>>1]=(ay|m)&65535;aD=e}else{aD=aC}}while(0);do{if(v&(u|0)<(aD|0)){ay=d[ax+5|0]|0;if((ay|0)==(j|0)){aE=aD;break}b[av+52>>1]=(ay|m)&65535;aE=e}else{aE=aD}}while(0);do{if(x&(w|0)<(aE|0)){ay=d[ax+6|0]|0;if((ay|0)==(j|0)){aF=aE;break}b[av+50>>1]=(ay|m)&65535;aF=e}else{aF=aE}}while(0);do{if(z&(y|0)<(aF|0)){ay=d[ax+7|0]|0;if((ay|0)==(j|0)){aG=aF;break}b[av+48>>1]=(ay|m)&65535;aG=e}else{aG=aF}}while(0);do{if(B&(A|0)<(aG|0)){ay=d[ax+8|0]|0;if((ay|0)==(j|0)){aH=aG;break}b[av+46>>1]=(ay|m)&65535;aH=e}else{aH=aG}}while(0);do{if(D&(C|0)<(aH|0)){ay=d[ax+9|0]|0;if((ay|0)==(j|0)){aI=aH;break}b[av+44>>1]=(ay|m)&65535;aI=e}else{aI=aH}}while(0);do{if(F&(E|0)<(aI|0)){ay=d[ax+10|0]|0;if((ay|0)==(j|0)){aJ=aI;break}b[av+42>>1]=(ay|m)&65535;aJ=e}else{aJ=aI}}while(0);do{if(H&(G|0)<(aJ|0)){ay=d[ax+11|0]|0;if((ay|0)==(j|0)){aK=aJ;break}b[av+40>>1]=(ay|m)&65535;aK=e}else{aK=aJ}}while(0);do{if(J&(I|0)<(aK|0)){ay=d[ax+12|0]|0;if((ay|0)==(j|0)){aL=aK;break}b[av+38>>1]=(ay|m)&65535;aL=e}else{aL=aK}}while(0);do{if(L&(K|0)<(aL|0)){ay=d[ax+13|0]|0;if((ay|0)==(j|0)){aM=aL;break}b[av+36>>1]=(ay|m)&65535;aM=e}else{aM=aL}}while(0);do{if(N&(M|0)<(aM|0)){ay=d[ax+14|0]|0;if((ay|0)==(j|0)){aN=aM;break}b[av+34>>1]=(ay|m)&65535;aN=e}else{aN=aM}}while(0);do{if(P&(O|0)<(aN|0)){ay=d[ax+15|0]|0;if((ay|0)==(j|0)){aO=aN;break}b[av+32>>1]=(ay|m)&65535;aO=e}else{aO=aN}}while(0);do{if(R&(Q|0)<(aO|0)){ay=d[ax+16|0]|0;if((ay|0)==(j|0)){aP=aO;break}b[av+30>>1]=(ay|m)&65535;aP=e}else{aP=aO}}while(0);do{if(T&(S|0)<(aP|0)){ay=d[ax+17|0]|0;if((ay|0)==(j|0)){aQ=aP;break}b[av+28>>1]=(ay|m)&65535;aQ=e}else{aQ=aP}}while(0);do{if(V&(U|0)<(aQ|0)){ay=d[ax+18|0]|0;if((ay|0)==(j|0)){aR=aQ;break}b[av+26>>1]=(ay|m)&65535;aR=e}else{aR=aQ}}while(0);do{if(X&(W|0)<(aR|0)){ay=d[ax+19|0]|0;if((ay|0)==(j|0)){aS=aR;break}b[av+24>>1]=(ay|m)&65535;aS=e}else{aS=aR}}while(0);do{if(Z&(Y|0)<(aS|0)){ay=d[ax+20|0]|0;if((ay|0)==(j|0)){aT=aS;break}b[av+22>>1]=(ay|m)&65535;aT=e}else{aT=aS}}while(0);do{if($&(_|0)<(aT|0)){ay=d[ax+21|0]|0;if((ay|0)==(j|0)){aU=aT;break}b[av+20>>1]=(ay|m)&65535;aU=e}else{aU=aT}}while(0);do{if(ab&(aa|0)<(aU|0)){ay=d[ax+22|0]|0;if((ay|0)==(j|0)){aV=aU;break}b[av+18>>1]=(ay|m)&65535;aV=e}else{aV=aU}}while(0);do{if(ad&(ac|0)<(aV|0)){ay=d[ax+23|0]|0;if((ay|0)==(j|0)){aW=aV;break}b[av+16>>1]=(ay|m)&65535;aW=e}else{aW=aV}}while(0);do{if(af&(ae|0)<(aW|0)){ay=d[ax+24|0]|0;if((ay|0)==(j|0)){aX=aW;break}b[av+14>>1]=(ay|m)&65535;aX=e}else{aX=aW}}while(0);do{if(ai&(ah|0)<(aX|0)){ay=d[ax+25|0]|0;if((ay|0)==(j|0)){aY=aX;break}b[av+12>>1]=(ay|m)&65535;aY=e}else{aY=aX}}while(0);do{if(ak&(aj|0)<(aY|0)){ay=d[ax+26|0]|0;if((ay|0)==(j|0)){aZ=aY;break}b[av+10>>1]=(ay|m)&65535;aZ=e}else{aZ=aY}}while(0);do{if(am&(al|0)<(aZ|0)){ay=d[ax+27|0]|0;if((ay|0)==(j|0)){a_=aZ;break}b[av+8>>1]=(ay|m)&65535;a_=e}else{a_=aZ}}while(0);do{if(ao&(an|0)<(a_|0)){ay=d[ax+28|0]|0;if((ay|0)==(j|0)){a$=a_;break}b[av+6>>1]=(ay|m)&65535;a$=e}else{a$=a_}}while(0);do{if(aq&(ap|0)<(a$|0)){ay=d[ax+29|0]|0;if((ay|0)==(j|0)){a0=a$;break}b[av+4>>1]=(ay|m)&65535;a0=e}else{a0=a$}}while(0);do{if(as&(ar|0)<(a0|0)){ay=d[ax+30|0]|0;if((ay|0)==(j|0)){a1=a0;break}b[av+2>>1]=(ay|m)&65535;a1=e}else{a1=a0}}while(0);if(!(at&(a1|0)>(f|0))){a2=a1;break}ay=d[ax+31|0]|0;if((ay|0)==(j|0)){a2=a1;break}b[av>>1]=(ay|m)&65535;a2=e}else{a2=aw}}while(0);a3=ax+32|0;if((l|0)<=0){break}av=av+(-a2<<1)|0;l=l-1|0;aw=a2;ax=a3}c[2112928]=a3;return}function S2(a,e,f,g,h,i,j,k,l,m,n){a=a|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;o=(n<<4)+32768>>16;n=(m<<4)+32768>>16;if((o|0)==0|(n|0)==0){return}m=n+i|0;if((m|0)<0){return}p=o+j|0;q=c[2113068]|0;r=c[2113070]|0;if(!((p|0)>-1&(q|0)>(i|0)&(r|0)>(j|0))){return}s=(l|0)==0?0:240;l=(k|0)==0?s:s|15;s=65536/(o|0)|0;k=65536/(n|0)|0;t=(j|0)<0?-j|0:0;u=(i|0)<0?-i|0:0;v=(p|0)<(r|0)?o:r-j|0;r=(m|0)<(q|0)?n:q-i|0;n=f<<8;if((t|0)>=(v|0)){return}f=(u|0)<(r|0);m=a+((ag(q,t+j|0)|0)+i<<1)|0;i=t;while(1){t=(ag(i,s)|0)>>12<<4;if(f){j=u;do{a=d[e+((((ag(j,k)|0)>>12)+t^l)+n)|0]|0;if((a|0)!=(h|0)){b[m+(j<<1)>>1]=(a|g)&65535}j=j+1|0;}while((j|0)<(r|0))}j=i+1|0;if((j|0)<(v|0)){m=m+(q<<1)|0;i=j}else{break}}return}function S3(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;f=i;i=i+64|0;g=f|0;h=f+8|0;j=f+16|0;k=f+24|0;l=f+32|0;m=f+40|0;n=f+48|0;o=f+56|0;p=9668984+(d*27|0)|0;q=(e|0)%4|0;if((q|0)==3){r=-1;i=f;return r|0}else if((q|0)==0|(q|0)==1|(q|0)==2){a[o]=0;e=9668996+(d*27|0)+q|0;if((a[e]|0)==0){s=0}else{t=(d|0)==0;u=(q|0)==0;do{if((q|d|0)==0){v=c[3540906]|0;if((v|0)==0){w=0}else{w=gD[v&8191]()|0}a[9669002+(d*27|0)+q|0]=w;if((q|0)!=2){break}v=a[p|0]|0;if((v<<24>>24|0)==1){if((a[9668986+(d*27|0)|0]|0)==0){x=42873}else{y=0}}else if((v<<24>>24|0)==2){x=42873}else{y=0}do{if((x|0)==42873){v=9668990+(d*27|0)|0;if((a[v]|0)==0){y=0;break}if((w&64)!=0){y=0;break}a[v]=0;y=1}}while(0);do{if((a[9668985+(d*27|0)|0]|0)==1){if((a[9668987+(d*27|0)|0]|0)!=0){x=42881;break}v=9668991+(d*27|0)|0;if((a[v]|0)==0){x=42881;break}if((w&4)!=0){x=42881;break}a[v]=0}else{x=42881}}while(0);if((x|0)==42881){if((y|0)==0){break}}S5(p,2,d)}}while(0);y=(q|0)==1;do{if(t&y){w=c[3540904]|0;if((w|0)==0){z=0}else{z=gD[w&8191]()|0}a[9669003]=z;A=0}else{w=(q|0)==2;if(!(t&w)){A=w;break}w=c[3540902]|0;if((w|0)==0){B=0}else{B=gD[w&8191]()|0}a[9669004]=B;w=a[p|0]|0;if((w<<24>>24|0)==1){if((a[9668986]|0)!=0|(a[9668990]|0)==0){C=0}else{x=42893}}else if((w<<24>>24|0)==2){if((a[9668990]|0)==0){C=0}else{x=42893}}else{C=0}do{if((x|0)==42893){if((B&64)!=0){C=0;break}a[9668990]=0;C=1}}while(0);do{if((a[9668987]|0)!=0|(a[9668985]|0)!=1|(a[9668991]|0)==0){x=42898}else{if((B&4)!=0){x=42898;break}a[9668991]=0}}while(0);if((x|0)==42898){if((C|0)==0){A=1;break}}w=a[9669001]|0;a[m]=w&a[9669007]|~w;S7(p,m);w=a[m]|0;a[9669010]=w;v=c[3540896]|0;if((v|0)==0){A=1;break}gf[v&2047](w);A=1}}while(0);m=(d|0)==1;do{if(m&u){if((c[3540894]|0)==0){D=0}else{D=b[4775240]&255}a[9669029]=D;if(!A){E=0;break}C=a[p|0]|0;if((C<<24>>24|0)==1){if((a[9669013]|0)!=0|(a[9669017]|0)==0){F=0}else{x=42908}}else if((C<<24>>24|0)==2){if((a[9669017]|0)==0){F=0}else{x=42908}}else{F=0}do{if((x|0)==42908){if((D&64)!=0){F=0;break}a[9669017]=0;F=1}}while(0);do{if((a[9669014]|0)!=0|(a[9669012]|0)!=1|(a[9669018]|0)==0){x=42913}else{if((D&4)!=0){x=42913;break}a[9669018]=0}}while(0);if((x|0)==42913){if((F|0)==0){E=1;break}}C=a[9669028]|0;a[l]=C&a[9669034]|~C;S7(p,l);C=a[l]|0;a[9669037]=C;B=c[3540884]|0;if((B|0)==0){E=1;break}gf[B&2047](C);E=1}else{E=A}}while(0);do{if(m&y){if((c[3540892]|0)==0){G=0}else{G=b[4775241]&255}a[9669030]=G;if(!E){H=0;break}A=a[p|0]|0;if((A<<24>>24|0)==1){if((a[9669013]|0)!=0|(a[9669017]|0)==0){I=0}else{x=42923}}else if((A<<24>>24|0)==2){if((a[9669017]|0)==0){I=0}else{x=42923}}else{I=0}do{if((x|0)==42923){if((G&64)!=0){I=0;break}a[9669017]=0;I=1}}while(0);do{if((a[9669014]|0)!=0|(a[9669012]|0)!=1|(a[9669018]|0)==0){x=42928}else{if((G&4)!=0){x=42928;break}a[9669018]=0}}while(0);if((x|0)==42928){if((I|0)==0){x=42931;break}}A=a[9669028]|0;a[k]=A&a[9669034]|~A;S7(p,k);A=a[k]|0;a[9669037]=A;l=c[3540884]|0;if((l|0)==0){x=42931;break}gf[l&2047](A);x=42931}else{x=42931}}while(0);do{if((x|0)==42931){if(!(m&E)){H=E;break}k=c[3540890]|0;if((k|0)==0){J=0}else{J=gD[k&8191]()|0}a[9669029+q|0]=J;k=a[p|0]|0;if((k<<24>>24|0)==1){if((a[9669013]|0)!=0|(a[9669017]|0)==0){K=0}else{x=42937}}else if((k<<24>>24|0)==2){if((a[9669017]|0)==0){K=0}else{x=42937}}else{K=0}do{if((x|0)==42937){if((J&64)!=0){K=0;break}a[9669017]=0;K=1}}while(0);do{if((a[9669014]|0)!=0|(a[9669012]|0)!=1|(a[9669018]|0)==0){x=42942}else{if((J&4)!=0){x=42942;break}a[9669018]=0}}while(0);if((x|0)==42942){if((K|0)==0){H=1;break}}k=a[9669028]|0;a[j]=k&a[9669034]|~k;S7(p,j);k=a[j]|0;a[9669037]=k;I=c[3540884]|0;if((I|0)==0){H=1;break}gf[I&2047](k);H=1}}while(0);j=(d|0)==2;do{if(j&u){K=(c[3540882]|0)==0?0:a[14165496]|0;a[9669056]=K;if(!H){L=0;break}J=a[p|0]|0;if((J<<24>>24|0)==1){if((a[9669040]|0)!=0|(a[9669044]|0)==0){M=0}else{x=42950}}else if((J<<24>>24|0)==2){if((a[9669044]|0)==0){M=0}else{x=42950}}else{M=0}do{if((x|0)==42950){if((K&64)!=0){M=0;break}a[9669044]=0;M=1}}while(0);do{if((a[9669041]|0)!=0|(a[9669039]|0)!=1|(a[9669045]|0)==0){x=42955}else{if((K&4)!=0){x=42955;break}a[9669045]=0}}while(0);if((x|0)==42955){if((M|0)==0){L=1;break}}K=a[9669055]|0;a[h]=K&a[9669061]|~K;S7(p,h);a[9669064]=a[h]|0;L=1}else{L=H}}while(0);do{if(j&y){a[9669057]=0;if(!L){break}H=a[p|0]|0;if((H<<24>>24|0)==1){if((a[9669040]|0)!=0|(a[9669044]|0)==0){N=0}else{x=42962}}else if((H<<24>>24|0)==2){if((a[9669044]|0)==0){N=0}else{x=42962}}else{N=0}if((x|0)==42962){a[9669044]=0;N=1}if((a[9669041]|0)!=0|(a[9669039]|0)!=1|(a[9669045]|0)==0){if((N|0)==0){x=42967;break}}else{a[9669045]=0}H=a[9669055]|0;a[g]=H&a[9669061]|~H;S7(p,g);a[9669064]=a[g]|0;x=42967}else{x=42967}}while(0);do{if((x|0)==42967){if(!(j&L)){break}a[9669056+q|0]=0;g=a[p|0]|0;if((g<<24>>24|0)==2){if((a[9669044]|0)==0){O=0}else{x=42971}}else if((g<<24>>24|0)==1){if((a[9669040]|0)!=0|(a[9669044]|0)==0){O=0}else{x=42971}}else{O=0}if((x|0)==42971){a[9669044]=0;O=1}if((a[9669041]|0)!=0|(a[9669039]|0)!=1|(a[9669045]|0)==0){if((O|0)==0){break}}else{a[9669045]=0}g=a[9669055]|0;a[n]=g&a[9669061]|~g;S7(p,n);a[9669064]=a[n]|0}}while(0);n=a[e]&a[9669002+(d*27|0)+q|0];a[o]=n;s=n}n=a[9668999+(d*27|0)+q|0]&a[9669005+(d*27|0)+q|0]|s;a[o]=n;if((q|0)!=2){r=n;i=f;return r|0}S7(p,o);r=a[o]|0;i=f;return r|0}else{r=0;i=f;return r|0}return 0}function S4(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0;f=9668984+(b*27|0)|0;g=(c|0)%4|0;if((g|0)==0|(g|0)==1|(g|0)==2){a[9669005+(b*27|0)+g|0]=e;S5(f,g,b);if((g|0)==1){if((a[9668987+(b*27|0)|0]|0)!=0){return}if((a[9668985+(b*27|0)|0]|0)==0){return}a[9668991+(b*27|0)|0]=1;S5(f,2,b);return}else if((g|0)==0){if((a[9668986+(b*27|0)|0]|0)!=0){return}if((a[f|0]|0)==0){return}a[9668990+(b*27|0)|0]=1;S5(f,2,b);return}else{return}}else if((g|0)==3){g=e&255;if((g&128|0)!=0){S6(b,g&127,1);return}e=1<<(g>>>1&7);if((g&1|0)==0){g=9669007+(b*27|0)|0;a[g]=d[g]&(e^255)&255}else{g=9669007+(b*27|0)|0;a[g]=(d[g]|e)&255}S5(f,2,b);return}else{return}}function S5(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0;f=i;i=i+8|0;g=f|0;h=a[b+15+d|0]|0;j=h&a[b+21+d|0]|~h;a[g]=j;h=(d|0)==2;if(h){S7(b,g);k=a[g]|0}else{k=j}a[b+24+d|0]=k;if((e|0)==1){b=c[3540888]|0;if((d|0)==0&(b|0)!=0){gf[b&2047](k)}b=c[3540886]|0;if((d|0)==1&(b|0)!=0){gf[b&2047](k)}b=c[3540884]|0;if(!(h&(b|0)!=0)){i=f;return}gf[b&2047](k);i=f;return}else if((e|0)==0){e=c[3540900]|0;if((d|0)==0&(e|0)!=0){gf[e&2047](k)}e=c[3540898]|0;if((d|0)==1&(e|0)!=0){gf[e&2047](k)}e=c[3540896]|0;if(!(h&(e|0)!=0)){i=f;return}gf[e&2047](k);i=f;return}else{i=f;return}}function S6(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;f=9668984+(b*27|0)|0;g=d>>>5&3;h=f|0;a[h]=g;i=d>>>2&1;a[9668985+(b*27|0)|0]=i;j=d>>>4&1;a[9668986+(b*27|0)|0]=j;k=d>>>1&1;a[9668987+(b*27|0)|0]=k;l=d>>>3&1;a[9668988+(b*27|0)|0]=l;m=d&1;a[9668989+(b*27|0)|0]=m;if(g<<24>>24==3){a[h]=2;n=2}else{n=g}g=9668996+(b*27|0)|0;if(j<<24>>24==0){a[g]=0;a[9668999+(b*27|0)|0]=-1;o=0}else{a[g]=-1;a[9668999+(b*27|0)|0]=0;o=-1}g=9668997+(b*27|0)|0;if(k<<24>>24==0){a[g]=0;a[9669e3+(b*27|0)|0]=-1}else{a[g]=-1;a[9669e3+(b*27|0)|0]=0}g=9668998+(b*27|0)|0;if(l<<24>>24==0){a[g]=0;a[9669001+(b*27|0)|0]=-16;p=-16;q=0}else{a[g]=-16;a[9669001+(b*27|0)|0]=0;p=0;q=-16}if(m<<24>>24==0){m=p|15;a[9669001+(b*27|0)|0]=m;r=q;s=m}else{m=q|15;a[g]=m;r=m;s=p}p=n&255;if((p|0)==1){n=r&-57;a[g]=n;m=s&-57;a[9669001+(b*27|0)|0]=m;t=n;u=m}else if((p|0)==2){p=r&7;a[g]=p;m=s&7;a[9669001+(b*27|0)|0]=m;t=p;u=m}else{t=r;u=s}if(i<<24>>24!=0){a[g]=t&-8;a[9669001+(b*27|0)|0]=u&-8}a[9669007+(b*27|0)|0]=0;u=9669006+(b*27|0)|0;a[u]=0;a[9669005+(b*27|0)|0]=0;if((e|0)==0){return}a[9669008+(b*27|0)|0]=o;do{if((b|0)==1){e=c[3540888]|0;if((e|0)==0){t=~a[9669027];a[9669036]=t;v=t;w=43062;break}else{gf[e&2047](o);w=43059;break}}else if((b|0)==0){e=c[3540900]|0;if((e|0)==0){t=~a[9669e3];a[9669009]=t;x=t;w=43060;break}else{gf[e&2047](o);w=43059;break}}else if((b|0)==2){a[9669063]=~a[9669054]}else{w=43059}}while(0);if((w|0)==43059){o=a[9669e3+(b*27|0)|0]|0;e=o&a[u]|~o;a[9669009+(b*27|0)|0]=e;if((b|0)==0){x=e;w=43060}else if((b|0)==1){v=e;w=43062}}do{if((w|0)==43060){e=c[3540898]|0;if((e|0)==0){break}gf[e&2047](x)}else if((w|0)==43062){e=c[3540886]|0;if((e|0)==0){break}gf[e&2047](v)}}while(0);S5(f,2,b);return}function S7(b,c){b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=a[b|0]|0;do{if((d<<24>>24|0)==2){e=-88;f=((a[b+6|0]|0)!=0?0:-128)|((a[b+10|0]|0)!=0?8:0)|((a[b+8|0]|0)!=0?32:0)}else if((d<<24>>24|0)==1){if((a[b+2|0]|0)==0){g=(a[b+6|0]|0)!=0;if(g){h=(a[b+10|0]|0)!=0?8:0}else{h=0}e=-120;f=h|(g?0:-128);break}else{g=(a[b+8|0]|0)!=0;if(g){i=(a[b+10|0]|0)!=0?8:0}else{i=0}e=40;f=i|(g?32:0);break}}else{e=0;f=0}}while(0);if((a[b+1|0]|0)!=1){j=e;k=f;l=~j;m=a[c]|0;n=m&l;o=j&k;p=n|o;a[c]=p;return}if((a[b+2|0]|0)==0){i=(a[b+7|0]|0)!=0;if(i){q=(a[b+11|0]|0)!=0|0}else{q=0}j=e|3;k=(i?0:2)|f|q;l=~j;m=a[c]|0;n=m&l;o=j&k;p=n|o;a[c]=p;return}else{q=(a[b+9|0]|0)!=0;if(q){r=(a[b+11|0]|0)!=0|0}else{r=0}j=e|3;k=(q?2:0)|f|r;l=~j;m=a[c]|0;n=m&l;o=j&k;p=n|o;a[c]=p;return}}function S8(a){a=a|0;return 0}function S9(a,b){a=a|0;b=b|0;return}function Ta(a){a=a|0;return 0}function Tb(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=a[9642624]|0;if((e&16)==0){f=0}else{f=d[9681504]|0}g=d[9579192]|0;h=a[9660744]&e&255;e=f&3;i=1<<e;if((g&i|0)==0){if((h&i|0)==0){j=43096}else{k=e}}else{j=43096}do{if((j|0)==43096){e=f+1&3;i=1<<e;if((i&g|0)==0){if((h&i|0)!=0){k=e;break}}e=f+2&3;i=1<<e;if((i&g|0)==0){if((h&i|0)!=0){k=e;break}}k=f+3&3}}while(0);f=a[9579200+k|0]|0;h=9626952+(k<<1)|0;e=b[h>>1]|0;if(e<<16>>16==0){a[9579192]=(1<<k|g)&255}g=f&255;if((g|0)==1){f=9542352+(k<<1)|0;i=gj[c[2438248]&4095](b[f>>1]|0)|0;gg[c[9752960+(k<<2)>>2]&4095](b[f>>1]|0,i);b[f>>1]=(b[f>>1]|0)+1&65535;f=b[h>>1]|0;b[h>>1]=f-1&65535;l=f;j=43103}else if((g|0)==0){f=9542352+(k<<1)|0;b[f>>1]=(b[f>>1]|0)+1&65535;b[h>>1]=e-1&65535;l=e;j=43103}else if((g|0)==2){g=9542352+(k<<1)|0;e=gj[c[9757040+(k<<2)>>2]&4095](b[g>>1]|0)|0;gg[c[2433588]&4095](b[g>>1]|0,e);b[g>>1]=(b[g>>1]|0)+1&65535;g=b[h>>1]|0;b[h>>1]=g-1&65535;l=g;j=43103}do{if((j|0)==43103){if(l<<16>>16!=0){break}g=a[9642624]|0;h=(k|0)==2&g<<24>>24<0;if(h){b[4888324]=b[4888326]|0;b[4888325]=b[4888327]|0}a[9681504]=k+1&3;e=~(1<<k);a[9660744]=(d[9660744]|0)&e&255;if(h){return}h=g&255;if((h&64|0)==0){return}a[9642624]=h&e&255;return}}while(0);a[9681504]=k+1&3;return}function Tc(c,d){c=c|0;d=d|0;var e=0,f=0,g=0,h=0;switch(c&7|0){case 3:{c=b[4887344]&255|(d&255)<<8&768;b[4887344]=c;e=c&65535;f=b[4887340]|0;g=(f&65535)<64;h=f&65535;if((c&65535)<64){if(g){gGz(9760184,3,512);return}else{c=0;do{a[9760184+c|0]=(c|0)>(h|0)?3:1;c=c+1|0;}while((c|0)<512);return}}else{if(g){g=0;do{a[9760184+g|0]=(g|0)>(e|0)|2;g=g+1|0;}while((g|0)<512);return}else{g=0;do{c=(g|0)>(e|0)|0;a[9760184+g|0]=(g|0)>(h|0)?c|2:c;g=g+1|0;}while((g|0)<512);return}}break};case 0:{b[4880088]=b[4880088]&-256|d&255;a[9553576]=(d&255)>>>2&3;a[9730928]=d&1;a[9730920]=d&2;a[9553577]=(d&255)>>>6;a[9730929]=d&16;a[9730921]=d&32;return};case 5:{g=b[4887340]&255|(d&255)<<8&768;b[4887340]=g;h=b[4887344]|0;e=h&65535;c=(g&65535)<64;f=g&65535;if((h&65535)<64){if(c){gGz(9760184,3,512);return}else{h=0;do{a[9760184+h|0]=(h|0)>(f|0)?3:1;h=h+1|0;}while((h|0)<512);return}}else{if(c){c=0;do{a[9760184+c|0]=(c|0)>(e|0)|2;c=c+1|0;}while((c|0)<512);return}else{c=0;do{h=(c|0)>(e|0)|0;a[9760184+c|0]=(c|0)>(f|0)?h|2:h;c=c+1|0;}while((c|0)<512);return}}break};case 2:{c=b[4887344]&-256|d&255;b[4887344]=c;f=c&65535;e=b[4887340]|0;h=(e&65535)<64;g=e&65535;if((c&65535)<64){if(h){gGz(9760184,3,512);return}else{c=0;do{a[9760184+c|0]=(c|0)>(g|0)?3:1;c=c+1|0;}while((c|0)<512);return}}else{if(h){h=0;do{a[9760184+h|0]=(h|0)>(f|0)|2;h=h+1|0;}while((h|0)<512);return}else{h=0;do{c=(h|0)>(f|0)|0;a[9760184+h|0]=(h|0)>(g|0)?c|2:c;h=h+1|0;}while((h|0)<512);return}}break};case 6:{a[9751144]=d&1;return};case 4:{h=b[4887340]&-256|d&255;b[4887340]=h;g=b[4887344]|0;f=g&65535;c=(h&65535)<64;e=h&65535;if((g&65535)<64){if(c){gGz(9760184,3,512);return}else{g=0;do{a[9760184+g|0]=(g|0)>(e|0)?3:1;g=g+1|0;}while((g|0)<512);return}}else{if(c){c=0;do{a[9760184+c|0]=(c|0)>(f|0)|2;c=c+1|0;}while((c|0)<512);return}else{c=0;do{g=(c|0)>(f|0)|0;a[9760184+c|0]=(c|0)>(e|0)?g|2:g;c=c+1|0;}while((c|0)<512);return}}break};case 1:{b[4880088]=b[4880088]&255|(d&255)<<8;a[9553578]=(d&255)>>>2&3;a[9730930]=d&1;a[9730922]=d&2;a[9553579]=(d&255)>>>6;a[9730931]=d&16;a[9730923]=d&32;return};default:{return}}}function Td(){var a=0,d=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;a=i;i=i+688|0;d=a|0;f=c[2427024]|0;do{if((f-14|0)>>>0<242){g=b[4887356]<<2&512;h=c[2077640]|0;j=f*684|0;k=(c[2077642]|0)+512|0;l=0;do{b[h+(l+j<<1)>>1]=(b[k>>1]|0)+g&65535;l=l+1|0;}while((l|0)<684);if((b[4859140]|0)!=2){break}l=h+(((c[2427024]|0)*684|0)+86<<1)|0;g=d|0;gGz(g|0,0,684);if((b[4853980]|0)==0){m=b[4776804]|0}else{m=(b[4887348]|0)+1&65535}b[4887348]=m;Te(0,0,g,l);if((b[4776801]&64)==0){break}Tf(0,e[4853980]|0,g,l)}else{l=c[2077640]|0;g=f*684|0;k=0;do{b[l+(k+g<<1)>>1]=1024;k=k+1|0;}while((k|0)<684)}}while(0);c[2427024]=((c[2427024]|0)+1|0)%262|0;Tg(0);i=a;return}function Te(f,g,h,i){f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;j=e[9774696+(f<<1)>>1]|0;k=e[9553606+(f<<6)>>1]|0;l=e[9553610+(f<<6)>>1]|0;m=c[600176+((l>>>4&3)<<2)>>2]|0;n=((l<<2&256|248)&j)>>>3<<m+1;l=c[8310552+(f<<2)>>2]|0;o=(b[4887356]&128)!=0?512:0;if((b[9553602+(f<<6)>>1]&128)==0){return}p=9540760+(f<<1)|0;f=k>>>3&127;q=(2<<m-1)-1|0;m=j<<1&14;j=(g|0)==0;g=c[2077642]|0;r=0;s=0;t=-(k&7)|0;while(1){k=(r+f&q)<<1;u=d[l+((k|1)+n)|0]|0;v=u&240;w=(u<<8&1792|(d[l+(k+n)|0]|0))<<5|m;k=d[l+w|0]|0;u=d[l+(w|1)|0]|0;x=d[l+(w|16)|0]|0;y=d[l+(w|17)|0]|0;w=s;z=t;A=0;while(1){B=7-A|0;C=k>>>(B>>>0)&1|v|y>>>(B>>>0)<<3&8|x>>>(B>>>0)<<2&4|u>>>(B>>>0)<<1&2;B=(C&15|0)==0?0:C;L55542:do{if((z|0)>-1){if((z|0)>=(e[p>>1]|0|0)){D=w;break}C=(B|0)!=0;E=C&1;a[h+w|0]=E;F=C|j;if(F){b[i+(w<<1)>>1]=(e[g+(B<<1)>>1]|0)+o&65535}C=w+1|0;G=b[p>>1]|0;if(G<<16>>16==512){D=C;break}H=(z<<9)+512|0;if((C|0)>=((H|0)/(G&65535|0)|0|0)){D=C;break}if(!F){F=C;while(1){a[h+F|0]=E;G=F+1|0;if((G|0)<((H|0)/(e[p>>1]|0|0)|0|0)){F=G}else{D=G;break L55542}}}F=g+(B<<1)|0;G=C;while(1){a[h+G|0]=E;b[i+(G<<1)>>1]=(e[F>>1]|0)+o&65535;I=G+1|0;if((I|0)<((H|0)/(e[p>>1]|0|0)|0|0)){G=I}else{D=I;break}}}else{D=w}}while(0);B=A+1|0;if((B|0)<8){w=D;z=z+1|0;A=B}else{break}}A=r+1|0;if((A|0)>=(((e[p>>1]|0)>>>3)+1|0)){break}r=A;s=D;t=t+8|0}return}function Tf(d,f,g,h){d=d|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0;j=i;i=i+16|0;k=j|0;l=(b[4887356]&128)!=0?512:0;m=9540760+(d<<1)|0;n=9553602+(d<<6)|0;o=14112712+d|0;p=k|0;q=c[2077642]|0;r=0;s=0;while(1){t=s<<2;u=b[9751176+(d<<9)+(t<<1)>>1]&1023;v=u-64|0;w=b[9751176+(d<<9)+((t|1)<<1)>>1]&1023;x=w-32|0;y=e[9751176+(d<<9)+((t|2)<<1)>>1]|0;z=e[9751176+(d<<9)+((t|3)<<1)>>1]|0;t=z&256;A=z>>>12;B=z>>>11&1;C=z>>>15;D=z&15;E=z>>>7&1;z=c[595768+((A&3)<<2)>>2]|0;F=f-v|0;L55563:do{if((u|0)==0|(v|0)>(f|0)|(w|0)==0){G=r}else{H=e[m>>1]|0;if((x|0)>=(H|0)){G=r;break}if((z+v|0)<(f|0)){G=r;break}I=(t|0)==0;J=(t>>>7^2046)&y;K=(A&1|0)==0?J:J&2042;J=(A&2|0)==0?K:K&2034;if((F|0)>=(z|0)){G=r;break}K=r+1&255;if((K&255)>16){if((b[n>>1]&2)==0){G=K;break}a[o]=a[o]|2;if((a[9661085]|0)==1){G=K;break}a[9661085]=1;if((a[9661088]|0)!=0){G=K;break}a[9661088]=2;G=K;break}L=F>>4;if((C|0)==0){M=L}else{M=(z-1>>4)-L|0}L=(x<<9|0)/(H|0)|0;H=(M<<2)+J|0;if(I){Tj(d,H,F,B,C,p);I=(E|0)!=0;J=D<<4|256;N=s+2&255;O=0;P=L;Q=b[m>>1]|0;while(1){R=O+x|0;do{if((R|0)<(Q&65535|0)&(R|0)>-1){S=a[k+O|0]|0;if(S<<24>>24==0){T=Q;break}U=g+P|0;V=a[U]|0;if((V&255)<2){do{if(I|V<<24>>24==0){W=q+((S<<24>>24)+J<<1)|0;b[h+(P<<1)>>1]=(e[W>>1]|0)+l&65535;X=b[m>>1]|0;if(X<<16>>16==512){break}Y=P+1|0;Z=(R<<9)+512|0;if((Y|0)<((Z|0)/(X&65535|0)|0|0)){_=1;$=Y}else{break}do{a[g+$|0]=N;b[h+($<<1)>>1]=(e[W>>1]|0)+l&65535;_=_+1|0;$=_+P|0;}while(($|0)<((Z|0)/(e[m>>1]|0)|0|0))}}while(0);a[U]=N;T=b[m>>1]|0;break}else{if(V<<24>>24!=2){T=Q;break}do{if(!((b[n>>1]&1)==0|(a[9661085]|0)==1)){a[9661085]=1;if((a[9661088]|0)!=0){break}a[9661088]=2}}while(0);a[o]=a[o]|1;T=Q;break}}else{T=Q}}while(0);if(T<<16>>16==512){aa=P+1|0}else{aa=((R<<9)+512|0)/(T&65535|0)|0}V=O+1|0;if((V|0)<16){O=V;P=aa;Q=T}else{G=K;break L55563}}}K=B<<1;Tj(d,H+K|0,F,B,C,p);Q=(E|0)!=0;P=D<<4|256;O=s+2&255;N=0;J=L;I=b[m>>1]|0;while(1){V=N+x|0;do{if((V|0)<(I&65535|0)&(V|0)>-1){U=a[k+N|0]|0;if(U<<24>>24==0){ab=I;break}S=g+J|0;Z=a[S]|0;if((Z&255)<2){do{if(Q|Z<<24>>24==0){W=q+((U<<24>>24)+P<<1)|0;b[h+(J<<1)>>1]=(e[W>>1]|0)+l&65535;Y=b[m>>1]|0;if(Y<<16>>16==512){break}X=J+1|0;ac=(V<<9)+512|0;if((X|0)<((ac|0)/(Y&65535|0)|0|0)){ad=1;ae=X}else{break}do{a[g+ae|0]=O;b[h+(ae<<1)>>1]=(e[W>>1]|0)+l&65535;ad=ad+1|0;ae=ad+J|0;}while((ae|0)<((ac|0)/(e[m>>1]|0)|0|0))}}while(0);a[S]=O;ab=b[m>>1]|0;break}else{if(Z<<24>>24!=2){ab=I;break}do{if(!((b[n>>1]&1)==0|(a[9661085]|0)==1)){a[9661085]=1;if((a[9661088]|0)!=0){break}a[9661088]=2}}while(0);a[o]=a[o]|1;ab=I;break}}else{ab=I}}while(0);if(ab<<16>>16==512){af=J+1|0}else{af=((V<<9)+512|0)/(ab&65535|0)|0}R=N+1|0;if((R|0)<16){N=R;J=af;I=ab}else{break}}I=r+2&255;if((I&255)>16){if((b[n>>1]&2)==0){G=I;break}a[o]=a[o]|2;if((a[9661085]|0)==1){G=I;break}a[9661085]=1;if((a[9661088]|0)!=0){G=I;break}a[9661088]=2;G=I;break}Tj(d,H+(K^2)|0,F,B,C,p);J=w-16|0;N=0;L=af;R=b[m>>1]|0;while(1){Z=J+N|0;do{if((Z|0)<(R&65535|0)&(Z|0)>-1){S=a[k+N|0]|0;if(S<<24>>24==0){ag=R;break}U=g+L|0;ac=a[U]|0;if((ac&255)<2){do{if(Q|ac<<24>>24==0){W=q+((S<<24>>24)+P<<1)|0;b[h+(L<<1)>>1]=(e[W>>1]|0)+l&65535;X=b[m>>1]|0;if(X<<16>>16==512){break}Y=L+1|0;ah=(N+x<<9)+8704|0;if((Y|0)<((ah|0)/(X&65535|0)|0|0)){ai=1;aj=Y}else{break}do{a[g+aj|0]=O;b[h+(aj<<1)>>1]=(e[W>>1]|0)+l&65535;ai=ai+1|0;aj=ai+L|0;}while((aj|0)<((ah|0)/(e[m>>1]|0)|0|0))}}while(0);a[U]=O;ag=b[m>>1]|0;break}else{if(ac<<24>>24!=2){ag=R;break}do{if(!((b[n>>1]&1)==0|(a[9661085]|0)==1)){a[9661085]=1;if((a[9661088]|0)!=0){break}a[9661088]=2}}while(0);a[o]=a[o]|1;ag=R;break}}else{ag=R}}while(0);if(ag<<16>>16==512){ak=L+1|0}else{ak=((N+x<<9)+8704|0)/(ag&65535|0)|0}Z=N+1|0;if((Z|0)<16){N=Z;L=ak;R=ag}else{G=I;break}}}}while(0);x=s+1|0;if((x|0)<64){r=G;s=x}else{break}}i=j;return}function Tg(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;g=9774704+(f<<2)|0;h=(c[g>>2]|0)+1|0;c[g>>2]=h;i=9707960+(f<<1)|0;j=(b[i>>1]|0)+1&65535;b[i>>1]=j;k=9731040+(f<<2)|0;l=(c[k>>2]|0)+1|0;c[k>>2]=l;m=9719120+(f<<2)|0;n=c[m>>2]|0;do{if((n|0)==0){o=0}else{p=n-1|0;c[m>>2]=p;if((p|0)!=0){o=0;break}if((b[9553622+(f<<6)>>1]&1)==0){o=0;break}p=14112712+f|0;a[p]=a[p]|8;o=1}}while(0);n=9718280+(f<<1)|0;do{if((c[2427024]|0)==0){b[n>>1]=0;b[i>>1]=0;c[9717352+(f<<2)>>2]=0;c[g>>2]=0;q=0;r=0;s=43285}else{p=b[n>>1]|0;if((p<<16>>16|0)==0){q=h;r=j;s=43285;break}else if((p<<16>>16|0)==1){t=h;u=j&65535;v=b[9553616+(f<<6)>>1]|0;s=43287;break}else if((p<<16>>16|0)==2){w=h;x=l;y=j;s=43289;break}else if((p<<16>>16|0)!=3){z=h;A=l;B=o;break}if((j&65535)<=2){z=h;A=l;B=o;break}if((j&65535)>>>0<(b[9553620+(f<<6)>>1]&255)>>>0){z=h;A=l;B=o;break}b[n>>1]=0;b[i>>1]=0;c[g>>2]=0;z=0;A=l;B=o}}while(0);do{if((s|0)==43285){g=b[9553616+(f<<6)>>1]|0;if((r&65535)>>>0<(g&31)>>>0){z=q;A=l;B=o;break}b[n>>1]=1;b[i>>1]=0;t=q;u=0;v=g;s=43287}}while(0);do{if((s|0)==43287){if(u>>>0<(v&65535)>>>8>>>0){z=t;A=l;B=o;break}b[n>>1]=2;b[i>>1]=0;c[k>>2]=64;w=t;x=64;y=0;s=43289}}while(0);do{if((s|0)==43289){if((y&65535)>>>0<=(b[9553618+(f<<6)>>1]&511)>>>0){z=w;A=x;B=o;break}b[n>>1]=3;b[i>>1]=0;c[9717352+(f<<2)>>2]=1;if((b[9553602+(f<<6)>>1]&8)==0){C=o}else{t=14112712+f|0;a[t]=a[t]|32;C=1}t=b[9553622+(f<<6)>>1]|0;k=9733952+f|0;if((t&16)==0){if((a[k]|0)==0){z=w;A=x;B=C;break}}a[k]=0;k=c[8310552+(f<<2)>>2]|0;l=e[9553630+(f<<6)>>1]<<1;v=0;do{u=(v<<1)+l|0;b[9751176+(f<<9)+(v<<1)>>1]=d[k+(u|1)|0]<<8|d[k+u|0];v=v+1|0;}while((v|0)<256);if((t&1)==0){z=w;A=x;B=C;break}c[m>>2]=4;z=w;A=x;B=C}}while(0);do{if((A|0)==(e[9553604+(f<<6)>>1]|0)){if((b[9553602+(f<<6)>>1]&4)==0){D=B;break}C=14112712+f|0;a[C]=a[C]|4;D=1}else{D=B}}while(0);do{if((z|0)==261){B=9717352+(f<<2)|0;if((c[B>>2]|0)!=0){E=D;break}c[B>>2]=1;if((b[9553602+(f<<6)>>1]&8)==0){F=D}else{B=14112712+f|0;a[B]=a[B]|32;F=1}B=b[9553622+(f<<6)>>1]|0;A=9733952+f|0;if((B&16)==0){if((a[A]|0)==0){E=F;break}}a[A]=0;A=c[8310552+(f<<2)>>2]|0;C=e[9553630+(f<<6)>>1]<<1;x=0;do{w=(x<<1)+C|0;b[9751176+(f<<9)+(x<<1)>>1]=d[A+(w|1)|0]<<8|d[A+w|0];x=x+1|0;}while((x|0)<256);if((B&1)==0){E=F;break}c[m>>2]=4;E=F}else{E=D}}while(0);if((E|0)==0|(a[9661085]|0)==1){return}a[9661085]=1;if((a[9661088]|0)!=0){return}a[9661088]=2;return}function Th(){var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=i;i=i+3072|0;g=f|0;h=f+1024|0;j=c[2427024]|0;if((j-14|0)>>>0>=242){k=c[2077640]|0;l=j*684|0;m=0;do{b[k+(m+l<<1)>>1]=1024;m=m+1|0;}while((m|0)<684);n=c[2427024]|0;o=n+1|0;p=(o|0)%262|0;c[2427024]=p;Tg(0);Tg(1);i=f;return}m=b[4887356]<<2&512;l=c[2077640]|0;k=j*684|0;j=c[2077642]|0;q=0;do{b[l+(q+k<<1)>>1]=(b[j>>1]|0)+m&65535;q=q+1|0;}while((q|0)<684);if((b[4859140]|0)!=2){n=c[2427024]|0;o=n+1|0;p=(o|0)%262|0;c[2427024]=p;Tg(0);Tg(1);i=f;return}q=g|0;gGz(q|0,0,1024);if((b[4853980]|0)==0){r=b[4776804]|0}else{r=(b[4887348]|0)+1&65535}b[4887348]=r;if((b[4853981]|0)==0){s=b[4776836]|0}else{s=(b[4887349]|0)+1&65535}b[4887349]=s;s=h|0;Te(0,0,q,s);if((b[4776801]&64)!=0){Tf(0,e[4853980]|0,q,s)}s=g+512|0;q=h+1024|0;Te(1,1,s,q);if((b[4776833]&64)!=0){Tf(1,e[4853981]|0,s,q)}q=((c[2427024]|0)*684|0)+86|0;s=0;do{r=d[9760184+s|0]|0;m=(a[9730920+r|0]|0)!=0;do{if((a[9730928+r|0]|0)==0){if(!m){break}if((a[g+512+s|0]|0)==0){break}b[l+(s+q<<1)>>1]=b[h+1024+(s<<1)>>1]|0}else{if(!m){if((a[g+s|0]|0)==0){break}b[l+(s+q<<1)>>1]=b[h+(s<<1)>>1]|0;break}j=d[9553576+r|0]|0;if((j|0)==1){k=a[g+s|0]|0;if(k<<24>>24==0){if((a[g+512+s|0]|0)==0){break}b[l+(s+q<<1)>>1]=b[h+1024+(s<<1)>>1]|0;break}if((k&255)>1){b[l+(s+q<<1)>>1]=b[h+(s<<1)>>1]|0;break}if((d[g+512+s|0]|0)>1){b[l+(s+q<<1)>>1]=b[h+1024+(s<<1)>>1]|0;break}else{b[l+(s+q<<1)>>1]=b[h+(s<<1)>>1]|0;break}}else if((j|0)==2){k=a[g+s|0]|0;if(k<<24>>24==0){if((a[g+512+s|0]|0)==0){break}b[l+(s+q<<1)>>1]=b[h+1024+(s<<1)>>1]|0;break}if((k&255)<=1){b[l+(s+q<<1)>>1]=b[h+(s<<1)>>1]|0;break}if((a[g+512+s|0]|0)==1){b[l+(s+q<<1)>>1]=b[h+1024+(s<<1)>>1]|0;break}else{b[l+(s+q<<1)>>1]=b[h+(s<<1)>>1]|0;break}}else if((j|0)==0){if((a[g+s|0]|0)!=0){b[l+(s+q<<1)>>1]=b[h+(s<<1)>>1]|0;break}if((a[g+512+s|0]|0)==0){break}b[l+(s+q<<1)>>1]=b[h+1024+(s<<1)>>1]|0;break}else{break}}}while(0);s=s+1|0;}while((s|0)<512);n=c[2427024]|0;o=n+1|0;p=(o|0)%262|0;c[2427024]=p;Tg(0);Tg(1);i=f;return}function Ti(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;i=g&3;if((i|0)==3){g=d[9760720+f|0]|0;j=9553592+(f<<6)+(g<<1)|0;k=h&255;l=k<<8;b[j>>1]=(b[j>>1]&255|l)&65535;switch(g|0){case 5:{a[9626480+f|0]=a[614744+(k>>>3&3)|0]|0;return};case 8:{b[9774696+(f<<1)>>1]=b[9553608+(f<<6)>>1]|0;return};case 19:{a[9733952+f|0]=1;return};case 2:{k=9553592+(f<<6)|0;g=b[k>>1]|0;j=(g&65535)<<1;if((j&65536|0)==0){m=c[8310552+(f<<2)>>2]|0;a[m+j|0]=a[9540768+f|0]|0;a[m+(j|1)|0]=h;n=b[k>>1]|0}else{n=g}b[k>>1]=(d[9626480+f|0]|0)+n&65535;return};case 13:{n=14112720+(f<<1)|0;b[n>>1]=(b[n>>1]&255|l)&511;return};case 18:{l=9553624+(f<<6)|0;n=9553626+(f<<6)|0;k=9553628+(f<<6)|0;g=e[9553622+(f<<6)>>1]|0;j=(g>>>1&2^2)-1|0;m=(g>>>2&2^2)-1|0;o=c[8310552+(f<<2)>>2]|0;p=e[l>>1]|0;q=e[n>>1]|0;r=e[k>>1]|0;while(1){if((q&32768|0)==0){s=p<<1&65534;t=a[o+(s|1)|0]|0;u=q<<1;a[o+u|0]=a[o+s|0]|0;a[o+(u|1)|0]=t}v=j+p|0;w=m+q|0;x=r+65535|0;t=x&65535;if((t|0)==65535){break}p=v&65535;q=w&65535;r=t}r=14112712+f|0;a[r]=a[r]|16;b[l>>1]=v&65535;b[n>>1]=w&65535;b[k>>1]=x&65535;if((g&2|0)==0|(a[9661085]|0)==1){return}a[9661085]=1;if((a[9661088]|0)!=0){return}a[9661088]=2;return};default:{return}}}else if((i|0)==2){g=d[9760720+f|0]|0;x=9553592+(f<<6)+(g<<1)|0;k=h&255;b[x>>1]=(b[x>>1]&65280|k)&65535;if((g|0)==8){b[9774696+(f<<1)>>1]=b[9553608+(f<<6)>>1]|0;return}else if((g|0)==11){b[9540760+(f<<1)>>1]=(k<<3&504)+8&65535;return}else if((g|0)==13){x=14112720+(f<<1)|0;b[x>>1]=(b[x>>1]&256|k)&511;return}else if((g|0)==2){a[9540768+f|0]=h;return}else{return}}else if((i|0)==0){a[9760720+f|0]=h&31;return}else{return}}function Tj(b,e,f,g,h,i){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0;j=f&15;f=(((h|0)==0?j:j^15)|e<<5)<<1;e=c[8310552+(b<<2)>>2]|0;b=(d[e+(f|1)|0]|0)<<8|(d[e+f|0]|0);j=(d[e+(f|33)|0]|0)<<8|(d[e+(f|32)|0]|0);h=(d[e+(f+65)|0]|0)<<8|(d[e+(f+64)|0]|0);k=(d[e+(f+97)|0]|0)<<8|(d[e+(f+96)|0]|0);if((g|0)==0){g=0;do{f=15-g|0;a[i+g|0]=(h>>>(f>>>0)<<2&4|b>>>(f>>>0)&1|k>>>(f>>>0)<<3&8|j>>>(f>>>0)<<1&2)&255;g=g+1|0;}while((g|0)<16);return}else{g=0;do{a[i+g|0]=(h>>>(g>>>0)<<2&4|b>>>(g>>>0)&1|k>>>(g>>>0)<<3&8|j>>>(g>>>0)<<1&2)&255;g=g+1|0;}while((g|0)<16);return}}function Tk(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;L55844:do{if((b|0)==0){a[9660536]=1}else{switch(d[9660536]|0){case 9:{if((c[2388514]&b|0)==(c[2388515]|0)){a[9620560]=(a[9620560]|0)+1&3}if((c[2388516]&b|0)==(c[2388517]|0)){a[9620560]=(a[9620560]|0)+2&3}if((c[2388518]&b|0)!=(c[2388519]|0)){break L55844}a[9660536]=10;break L55844;break};case 10:{if(!((c[2388485]|0)==(b|0)|(c[2388486]|0)==(b|0)|(c[2388487]|0)==(b|0)|(c[2388488]|0)==(b|0))){break L55844}a[9660536]=0;a[9771528]=a[9620560]|0;break L55844;break};case 4:{if((c[2388495]&b|0)!=(c[2388496]|0)){break L55844}a[9660536]=0;a[9771528]=a[9620552]|0;break L55844;break};case 6:{e=a[9627080]|0;f=e&255^b;if((f&c[2388500]|0)==(c[2388501]|0)){a[9620512]=a[9620512]&-2;a[9627080]=e^3;break L55844}if((c[2388502]&f|0)==(c[2388503]|0)){a[9620512]=a[9620512]|1;a[9627080]=e^3;break L55844}if((c[2388504]&f|0)==(c[2388505]|0)){a[9620512]=a[9620512]&-3;a[9627080]=e^3;break L55844}if((c[2388506]&f|0)==(c[2388507]|0)){a[9620512]=a[9620512]|2;a[9627080]=e^3;break L55844}if((c[2388508]&b|0)!=(c[2388509]|0)){break L55844}a[9660536]=7;break L55844;break};case 1:{if((c[2388498]&b|0)==(c[2388499]|0)){a[9660536]=5;break L55844}if((c[2388510]&b|0)==(c[2388511]|0)){a[9660536]=8;break L55844}e=c[2388489]|0;f=c[2388490]|0;if((e&b|0)==(f|0)){a[9660536]=2;break L55844}if((c[2388491]&b|0)!=(c[2388492]|0)){if((c[2388485]|0)==(b|0)){a[9660536]=0;a[9771528]=0;break L55844}if((c[2388486]|0)==(b|0)){a[9660536]=0;a[9771528]=1;break L55844}if((c[2388487]|0)==(b|0)){a[9660536]=0;a[9771528]=2;break L55844}if((c[2388488]|0)!=(b|0)){break L55844}a[9660536]=0;a[9771528]=3;break L55844}do{if((a[14115672]|0)==0){g=3}else{h=c[2276056]|0;if((h>>1&e|0)!=(f|0)){g=1;break}i=h+16777212|0;h=i&16777215;j=c[2112932]|0;k=c[j+((h>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1023;m=d[k+(l+1)|0]<<8|d[k+l|0]}else{m=gj[c[j+196688+(k<<2)>>2]&4095](h)|0}h=m&65535;k=h&61944;if(!((k|0)==12432|(k|0)==45384)){g=1;break}switch(c[614072+((h>>>9&7)<<2)>>2]|0){case 10:{n=c[2276049]|0;break};case 3:{n=c[2276042]|0;break};case 4:{n=c[2276043]|0;break};case 5:{n=c[2276044]|0;break};case 6:{n=c[2276045]|0;break};case 7:{n=c[2276046]|0;break};case 26:{n=c[2276068]|0;break};case 18:{n=c[2276054]|0;break};case 8:{n=c[2276047]|0;break};case 16:{n=c[2276056]|0;break};case 17:{n=c[2276071]|c[2276070]|c[2276072]<<11|c[2276073]<<11|c[2276079]|(c[2276074]|0)>>>4&16|(c[2276075]|0)>>>4&8|((c[2276076]|0)==0)<<2|(c[2276077]|0)>>>6&2|(c[2276078]|0)>>>8&1;break};case 14:{n=c[2276053]|0;break};case 12:{n=c[2276051]|0;break};case 15:{n=c[2276054]|0;break};case 23:{n=c[2276065]|0;break};case 24:{n=c[2276066]|0;break};case 0:{n=c[2276039]|0;break};case 20:{n=(c[2276072]|0)!=0&(c[2276073]|0)==0?c[2276054]|0:c[2276061]|0;break};case 21:{n=(c[2276072]|0)==0|(c[2276073]|0)==0?c[2276063]|0:c[2276054]|0;break};case 22:{n=c[2276064]|0;break};case 19:{n=(c[2276072]|0)==0?c[2276054]|0:c[2276057]|0;break};case 13:{n=c[2276052]|0;break};case 1:{n=c[2276040]|0;break};case 11:{n=c[2276050]|0;break};case 2:{n=c[2276041]|0;break};case 25:{n=c[2276067]|0;break};case 9:{n=c[2276048]|0;break};default:{n=0}}h=n>>>1;if((h&c[2388493]|0)!=(c[2388494]|0)){g=1;break}a[9620552]=h>>>((c[2388497]|0)>>>0)&3;g=4}}while(0);a[9660536]=g;break L55844;break};case 3:{if((c[2388493]&b|0)==(c[2388494]|0)){a[9660536]=4;a[9620552]=b>>c[2388497]&3;break L55844}else{a[9660536]=1;break L55844}break};case 5:{if(!((c[2388485]|0)==(b|0)|(c[2388486]|0)==(b|0)|(c[2388487]|0)==(b|0)|(c[2388488]|0)==(b|0))){break L55844}a[9660536]=6;a[9620512]=a[9771528]|0;a[9627080]=0;break L55844;break};case 7:{if(!((c[2388485]|0)==(b|0)|(c[2388486]|0)==(b|0)|(c[2388487]|0)==(b|0)|(c[2388488]|0)==(b|0))){break L55844}a[9660536]=0;a[9771528]=a[9620512]|0;break L55844;break};case 8:{if((c[2388512]&b|0)==(c[2388513]|0)){a[9660536]=9;a[9620560]=a[9771528]|0;break L55844}else{a[9660536]=1;break L55844}break};case 2:{if((c[2388491]&b|0)==(c[2388492]|0)){a[9660536]=3;break L55844}else{a[9660536]=1;break L55844}break};default:{break L55844}}}}while(0);return d[9771528]|0}function Tl(d,e,f,g,h){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0;j=i;i=i+32|0;k=j|0;l=j+16|0;m=e+16384|0;n=c[h+4>>2]|0;if((n&8|0)!=0){i=j;return}o=c[h>>2]&64;p=(c[h+8>>2]|0)>>>6;q=(c[h+16>>2]|0)>>>6;r=(p&256|0)==0?p&511:p|-512;p=(q&256|0)==0?q&511:q|-512;q=(c[h+24>>2]|0)>>>6;s=k|0;c[s>>2]=q&1023;t=(c[h+28>>2]|0)>>>6;u=l|0;c[u>>2]=t&1023;if((q&512|0)!=0){c[s>>2]=q|-1024}if((t&512|0)!=0){c[u>>2]=t|-1024}t=(c[h+32>>2]|0)>>>6;u=k+4|0;c[u>>2]=t&1023;q=(c[h+36>>2]|0)>>>6;s=l+4|0;c[s>>2]=q&1023;if((t&512|0)!=0){c[u>>2]=t|-1024}if((q&512|0)!=0){c[s>>2]=q|-1024}q=(c[h+40>>2]|0)>>>6;s=k+8|0;c[s>>2]=q&1023;t=(c[h+44>>2]|0)>>>6;u=l+8|0;c[u>>2]=t&1023;if((q&512|0)!=0){c[s>>2]=q|-1024}if((t&512|0)!=0){c[u>>2]=t|-1024}t=(c[h+48>>2]|0)>>>6;u=k+12|0;c[u>>2]=t&1023;q=(c[h+52>>2]|0)>>>6;h=l+12|0;c[h>>2]=q&1023;if((t&512|0)!=0){c[u>>2]=t|-1024}if((q&512|0)!=0){c[h>>2]=q|-1024}q=(o|0)==0;o=(n&2|0)==0;h=(n&1|0)==0;n=g-1|0;t=0;u=0;s=0;v=0;w=e;do{e=c[w>>2]|0;x=e>>>9&1;y=e>>>8&1;z=e>>>24<<4&48;A=z+16|0;B=e>>>28<<4&48;C=B+16|0;D=ag(A,C)|0;E=e>>>13;F=c[w+8>>2]|0;G=F>>>6&1023;do{if((E&1|0)==0){H=c[w+12>>2]|0;I=p+G|0;J=r+(H>>>6&1023)|0;K=H>>>16&65535;L=H>>>24&65535;if(q){M=I;N=J;O=L;P=K;break}H=e>>>11&3;M=(c[k+(H<<2)>>2]|0)+I|0;N=(c[l+(H<<2)>>2]|0)+J|0;O=L;P=K}else{K=c[w+12>>2]|0;M=G+v|0;N=(K>>>6&1023)+u|0;O=K>>>24&65535;P=K>>>16&65535}}while(0);v=(M|0)>511?M-1024|0:M;u=(N|0)>511?N-1024|0:N;if(o){Q=v;R=x}else{Q=(c[2113068]|0)-v|0;R=x^1}if(h){S=u;T=y}else{S=(c[2113070]|0)-u|0;T=y^1}t=(E&2|0)==0?e&63:t;if((E&4|0)==0){U=c[w+4>>2]&134217727}else{U=s}G=F>>>24&65535;if((e&8388608|0)==0){V=O&252;W=F>>>16&65535;X=G&252;Y=P}else{V=0;W=G;X=0;Y=O}G=Y&252;K=W&252;L=U&n;if((D|0)>0){J=D;H=0;I=L;while(1){Z=I+1|0;_=a[f+((I|0)%(g|0)|0)|0]|0;$=_&255;aa=$&127;ab=J-1-aa|0;if(($&128|0)==0){ac=a[f+((Z|0)%(g|0)|0)|0]|0;ad=_;ae=H;while(1){a[9763320+((ae|0)%8192|0)|0]=ac;if(ad<<24>>24==0){break}else{ad=ad-1&255;ae=ae+1|0}}af=I+2|0;ah=H+1+$|0}else{ae=_&127;ad=Z;ac=aa&255;ai=H;while(1){a[9763320+((ai|0)%8192|0)|0]=a[f+((ad|0)%(g|0)|0)|0]|0;if(ac<<24>>24==0){break}else{ad=ad+1|0;ac=ac-1&255;ai=ai+1|0}}ai=ae&255;af=I+2+ai|0;ah=H+1+ai|0}if((ab|0)>0){J=ab;H=ah;I=af}else{aj=af;break}}}else{aj=L}s=(aj|0)%(g|0)|0;I=(t<<8)+16384|0;L56014:do{if((G|X|K|V)<<16>>16==0){H=(R|0)!=0;J=H^1;D=(T|0)==0;if(D&J){F=c[2113068]|0;e=c[2113070]|0;E=0;while(1){y=E+Q|0;if((y|0)<(F|0)&(y|0)>-1){x=0;do{ai=x+S|0;do{if((ai|0)<(e|0)&(ai|0)>-1){ac=a[9763320+((ag(x,A)|0)+E)|0]|0;if(ac<<24>>24==0){break}b[d+((ag(F,ai)|0)+y<<1)>>1]=(ac&255|I)&65535}}while(0);x=x+1|0;}while((x|0)<(C|0))}E=E+1|0;if((E|0)>=(A|0)){break L56014}}}if(!(H|D)){E=S-C|0;F=B|15;e=c[2113068]|0;ab=c[2113070]|0;ae=0;while(1){x=ae+Q|0;if((x|0)<(e|0)&(x|0)>-1){y=0;do{ai=F-y+E|0;do{if((ai|0)<(ab|0)&(ai|0)>-1){ac=a[9763320+((ag(y,A)|0)+ae)|0]|0;if(ac<<24>>24==0){break}b[d+((ag(e,ai)|0)+x<<1)>>1]=(ac&255|I)&65535}}while(0);y=y+1|0;}while((y|0)<(C|0))}ae=ae+1|0;if((ae|0)>=(A|0)){break L56014}}}if(H&D){ae=Q-A|0;e=z|15;ab=c[2113068]|0;E=c[2113070]|0;F=0;while(1){y=e-F+ae|0;if((y|0)<(ab|0)&(y|0)>-1){x=0;do{ai=x+S|0;do{if((ai|0)<(E|0)&(ai|0)>-1){ac=a[9763320+((ag(x,A)|0)+F)|0]|0;if(ac<<24>>24==0){break}b[d+((ag(ab,ai)|0)+y<<1)>>1]=(ac&255|I)&65535}}while(0);x=x+1|0;}while((x|0)<(C|0))}F=F+1|0;if((F|0)>=(A|0)){break L56014}}}if(D|J){break}F=Q-A|0;ab=S-C|0;E=z|15;ae=B|15;e=c[2113068]|0;H=c[2113070]|0;x=0;do{y=E-x+F|0;if((y|0)<(e|0)&(y|0)>-1){ai=0;do{ac=ae-ai+ab|0;do{if((ac|0)<(H|0)&(ac|0)>-1){ad=a[9763320+((ag(ai,A)|0)+x)|0]|0;if(ad<<24>>24==0){break}b[d+((ag(e,ac)|0)+y<<1)>>1]=(ad&255|I)&65535}}while(0);ai=ai+1|0;}while((ai|0)<(C|0))}x=x+1|0;}while((x|0)<(A|0))}else{gk[c[673096+((T|R<<1)<<2)>>2]&15](d,9763320,Q,S,A,C,X,K,V,G,I)}}while(0);w=w+16|0;}while(w>>>0<m>>>0);i=j;return}function Tm(d,e,f,g,h,i,j,k,l,m,n){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;o=64-((j&65535)>>>2)&65535;j=64-((k&65535)>>>2)&65535;k=64-((l&65535)>>>2)&65535;l=64-((m&65535)>>>2)&65535;m=c[2113068]|0;p=m<<6;q=c[2113070]|0;r=q<<6;s=h<<6;t=i<<6;i=f<<6;f=g<<6;if((i|0)<0){g=o&65535;u=j&65535;v=i;w=0;while(1){x=w+g|0;y=v+u|0;if((y|0)<0){v=y;w=x}else{z=y;A=x;break}}}else{z=i;A=0}if((f|0)<0){i=k&65535;w=l&65535;v=f;u=0;do{u=u+i|0;v=v+w|0;}while((v|0)<0);B=e+(ag(u>>6,h)|0)|0;C=v;D=u}else{B=e;C=f;D=0}if((D|0)>=(t|0)|(C|0)>(r|0)){return}f=(A|0)>=(s|0)|(z|0)>(p|0);e=k&65535;k=l&65535;l=o&65535;o=j&65535;j=D;D=C;C=B;while(1){if(f){E=D;F=j}else{B=D>>6;u=(B|0)<(q|0);v=ag(m,B)|0;B=z;w=A;while(1){i=a[C+(w>>6)|0]|0;do{if(i<<24>>24!=0&u){g=B>>6;if((g|0)>=(m|0)){G=w;H=B;break}b[d+(v+g<<1)>>1]=(i&255)+n&65535;G=w;H=B}else{G=w;H=B}}while(0);do{G=G+l|0;H=H+o|0;}while((H^B)>>>0<64);if((G|0)>=(s|0)|(H|0)>(p|0)){E=D;F=j;break}else{B=H;w=G}}}do{F=F+e|0;E=E+k|0;}while((E^D)>>>0<64);if((F^j)>>>0>63){w=j;B=C;while(1){v=B+h|0;u=w+64|0;if((u^F)>>>0>63){w=u;B=v}else{I=v;break}}}else{I=C}if((F|0)>=(t|0)|(E|0)>(r|0)){break}else{j=F;D=E;C=I}}return}function Tn(d,e,f,g,h,i,j,k,l,m,n){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;o=64-((j&65535)>>>2)&65535;j=64-((k&65535)>>>2)&65535;k=64-((l&65535)>>>2)&65535;l=64-((m&65535)>>>2)&65535;m=c[2113068]|0;p=m<<6;q=c[2113070]|0;r=q<<6;s=h<<6;t=i<<6;i=f<<6;f=g<<6;if((i|0)<0){g=o&65535;u=j&65535;v=i;w=0;while(1){x=w+g|0;y=v+u|0;if((y|0)<0){v=y;w=x}else{z=y;A=x;break}}}else{z=i;A=0}if((f|0)>(r|0)){i=k&65535;w=l&65535;v=f;u=0;do{u=u+i|0;v=v-w|0;}while((v|0)>(r|0));B=e+(ag(u>>6,h)|0)|0;C=v;D=u}else{B=e;C=f;D=0}if(!((D|0)<(t|0)&(C|0)>-1)){return}f=(A|0)>=(s|0)|(z|0)>(p|0);e=k&65535;k=l&65535;l=o&65535;o=j&65535;j=D;D=C;C=B;while(1){if(f){E=D;F=j}else{B=D>>6;u=(B|0)<(q|0);v=ag(m,B)|0;B=z;r=A;while(1){w=a[C+(r>>6)|0]|0;do{if(w<<24>>24!=0&u){i=B>>6;if((i|0)>=(m|0)){G=r;H=B;break}b[d+(v+i<<1)>>1]=(w&255)+n&65535;G=r;H=B}else{G=r;H=B}}while(0);do{G=G+l|0;H=H+o|0;}while((H^B)>>>0<64);if((G|0)>=(s|0)|(H|0)>(p|0)){E=D;F=j;break}else{B=H;r=G}}}do{F=F+e|0;E=E-k|0;}while((E^D)>>>0<64);if((F^j)>>>0>63){r=j;B=C;while(1){v=B+h|0;u=r+64|0;if((u^F)>>>0>63){r=u;B=v}else{I=v;break}}}else{I=C}if((F|0)<(t|0)&(E|0)>-1){j=F;D=E;C=I}else{break}}return}function To(d,e,f,g,h,i,j,k,l,m,n){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;o=64-((j&65535)>>>2)&65535;j=64-((k&65535)>>>2)&65535;k=64-((l&65535)>>>2)&65535;l=64-((m&65535)>>>2)&65535;m=c[2113068]|0;p=m<<6;q=c[2113070]|0;r=q<<6;s=h<<6;t=i<<6;i=f<<6;f=g<<6;if((i|0)>(p|0)){g=o&65535;u=j&65535;v=i;w=0;while(1){x=w+g|0;y=v-u|0;if((y|0)>(p|0)){v=y;w=x}else{z=y;A=x;break}}}else{z=i;A=0}if((f|0)<0){i=k&65535;w=l&65535;v=f;p=0;do{p=p+i|0;v=v+w|0;}while((v|0)<0);B=e+(ag(p>>6,h)|0)|0;C=v;D=p}else{B=e;C=f;D=0}if((D|0)>=(t|0)|(C|0)>(r|0)){return}f=(A|0)<(s|0)&(z|0)>-1;e=k&65535;k=l&65535;l=o&65535;o=j&65535;j=D;D=C;C=B;while(1){if(f){B=D>>6;p=(B|0)<(q|0);v=ag(m,B)|0;B=z;w=A;while(1){i=a[C+(w>>6)|0]|0;do{if(i<<24>>24!=0&p){u=B>>6;if((u|0)>=(m|0)){E=w;F=B;break}b[d+(v+u<<1)>>1]=(i&255)+n&65535;E=w;F=B}else{E=w;F=B}}while(0);do{E=E+l|0;F=F-o|0;}while((F^B)>>>0<64);if((E|0)<(s|0)&(F|0)>-1){B=F;w=E}else{G=D;H=j;break}}}else{G=D;H=j}do{H=H+e|0;G=G+k|0;}while((G^D)>>>0<64);if((H^j)>>>0>63){w=j;B=C;while(1){v=B+h|0;p=w+64|0;if((p^H)>>>0>63){w=p;B=v}else{I=v;break}}}else{I=C}if((H|0)>=(t|0)|(G|0)>(r|0)){break}else{j=H;D=G;C=I}}return}function Tp(d,e,f,g,h,i,j,k,l,m,n){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;o=64-((j&65535)>>>2)&65535;j=64-((k&65535)>>>2)&65535;k=64-((l&65535)>>>2)&65535;l=64-((m&65535)>>>2)&65535;m=c[2113068]|0;p=m<<6;q=c[2113070]|0;r=q<<6;s=h<<6;t=i<<6;i=f<<6;f=g<<6;if((i|0)>(p|0)){g=o&65535;u=j&65535;v=i;w=0;while(1){x=w+g|0;y=v-u|0;if((y|0)>(p|0)){v=y;w=x}else{z=y;A=x;break}}}else{z=i;A=0}if((f|0)>(r|0)){i=k&65535;w=l&65535;v=f;p=0;do{p=p+i|0;v=v-w|0;}while((v|0)>(r|0));B=e+(ag(p>>6,h)|0)|0;C=v;D=p}else{B=e;C=f;D=0}if(!((D|0)<(t|0)&(C|0)>-1)){return}f=(A|0)<(s|0)&(z|0)>-1;e=k&65535;k=l&65535;l=o&65535;o=j&65535;j=D;D=C;C=B;while(1){if(f){B=D>>6;p=(B|0)<(q|0);v=ag(m,B)|0;B=z;r=A;while(1){w=a[C+(r>>6)|0]|0;do{if(w<<24>>24!=0&p){i=B>>6;if((i|0)>=(m|0)){E=r;F=B;break}b[d+(v+i<<1)>>1]=(w&255)+n&65535;E=r;F=B}else{E=r;F=B}}while(0);do{E=E+l|0;F=F-o|0;}while((F^B)>>>0<64);if((E|0)<(s|0)&(F|0)>-1){B=F;r=E}else{G=D;H=j;break}}}else{G=D;H=j}do{H=H+e|0;G=G-k|0;}while((G^D)>>>0<64);if((H^j)>>>0>63){r=j;B=C;while(1){v=B+h|0;p=r+64|0;if((p^H)>>>0>63){r=p;B=v}else{I=v;break}}}else{I=C}if((H|0)<(t|0)&(G|0)>-1){j=H;D=G;C=I}else{break}}return}function Tq(b){b=b|0;var d=0,e=0,f=0,g=0;d=i;i=i+128|0;c[2420380]=b;gGz(14100392,-1|0,(c[b+4>>2]<<c[b>>2]|0)/8|0|0);c[2440216]=0;c[2415256]=0;c[3528406]=1;c[3528810]=1;c[2429648]=0;c[2406632]=0;c[2410658]=(c[b+24>>2]|0)!=0;b=d|0;e=c[c[642608+(c[2436]<<2)>>2]>>2]|0;be(b|0,128,179600,(f=i,i=i+24|0,c[f>>2]=9374064,c[f+8>>2]=47,c[f+16>>2]=e,f)|0)|0;i=f;a[1040128]=0;f=c[2420380]|0;e=c[f>>2]|0;g=c[f+4>>2]|0;f=fw(b|0,364392)|0;if((f|0)==0){i=d;return}a[1040128]=1;ew(14100392,g>>3<<e&1023|0,1,f|0)|0;aY(f|0)|0;i=d;return}function Tr(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0;do{if((b|0)==2){if((c[3528406]|0)==0){break}c[3528810]=b;return}else{if((c[3528810]|0)!=0){c[3528810]=b;return}if((b|0)!=0&(c[3528406]|0)==0){break}c[3528810]=b;return}}while(0);if((c[2406632]|0)!=0){e=c[2430030]|0;f=c[2420380]|0;g=f+4|0;do{if((e|0)==(c[g>>2]|0)){if((c[f+28>>2]|0)==0){h=e;break}i=(1<<c[f>>2])-1&(c[2429648]|0)+1;c[2429648]=i;if((c[g>>2]|0)==16){j=i<<1;k=d[14100392+j|0]<<8|d[14100392+(j|1)|0]}else{k=d[14100392+i|0]|0}c[2432962]=k;c[2430030]=0;h=0}else{h=e}}while(0);c[2432962]=c[2432962]<<1|1;c[2430030]=h+1;c[3528810]=b;return}h=c[2440216]|0;if((h|0)>38){c[3528810]=b;return}e=(c[2415256]|0)!=0?49:48;k=h+1|0;c[2440216]=k;a[9755624+h|0]=e;a[9755624+k|0]=0;e=c[2420380]|0;h=c[e>>2]|0;L56239:do{if((k|0)>(h|0)){g=c[e+8>>2]|0;f=gGy(9755624)|0;i=f-h|0;L56241:do{if(!((g|0)==0|(f|0)==(h|0))){L56243:do{if((i|0)>0){j=9755624;l=g;m=i;L56244:while(1){n=a[j]|0;o=n<<24>>24==0;p=l;q=a[l]|0;while(1){if(o|q<<24>>24==0){break L56244}if(q<<24>>24==48){r=48;s=43705;break}if((q<<24>>24|0)==88|(q<<24>>24|0)==120){s=43706;break}else if((q<<24>>24|0)==49){r=49;s=43705;break}else if((q<<24>>24|0)!=42){s=43697;break}t=p+1|0;u=a[t]|0;if(((u<<24>>24)-48|0)>>>0>=2){break L56241}if(n<<24>>24==u<<24>>24){p=t;q=n}else{v=p;break}}if((s|0)==43697){s=0;o=q<<24>>24;while(1){if((o|0)==88|(o|0)==120){s=43706;break}else if((o|0)==48|(o|0)==49){r=q;s=43705;break}}}if((s|0)==43705){s=0;if(n<<24>>24==r<<24>>24){s=43706}else{break L56241}}if((s|0)==43706){s=0;v=p+1|0}o=m-1|0;if((o|0)>0){j=j+1|0;l=v;m=o}else{w=v;s=43708;break L56243}}if(n<<24>>24!=q<<24>>24){break L56241}}else{w=g;s=43708}}while(0);if((s|0)==43708){if((a[w]|0)!=0){break}}if((h|0)>0){m=k-h|0;l=0;while(1){j=(a[9755624+m|0]|0)==49|l<<1;o=m+1|0;if((o|0)<(k|0)){m=o;l=j}else{x=j;break}}}else{x=0}if((c[e+4>>2]|0)==16){l=x<<1;y=d[14100392+l|0]<<8|d[14100392+(l|1)|0]}else{y=d[14100392+x|0]|0}c[2432962]=y;c[2429648]=x;c[2430030]=0;c[2406632]=1;c[2440216]=0;c[3528810]=b;return}}while(0);g=c[e+16>>2]|0;i=gGy(9755624)|0;f=i-h|0;if((g|0)==0|(i|0)==(h|0)){break}L56277:do{if((f|0)>0){i=9755624;l=g;m=f;L56278:while(1){z=a[i]|0;j=z<<24>>24==0;o=l;A=a[l]|0;while(1){if(j|A<<24>>24==0){break L56278}if(A<<24>>24==48){B=48;s=43727;break}if((A<<24>>24|0)==49){B=49;s=43727;break}else if((A<<24>>24|0)==88|(A<<24>>24|0)==120){s=43728;break}else if((A<<24>>24|0)!=42){s=43719;break}t=o+1|0;u=a[t]|0;if(((u<<24>>24)-48|0)>>>0>=2){break L56239}if(z<<24>>24==u<<24>>24){o=t;A=z}else{C=o;break}}if((s|0)==43719){s=0;j=A<<24>>24;while(1){if((j|0)==48|(j|0)==49){B=A;s=43727;break}else if((j|0)==88|(j|0)==120){s=43728;break}}}if((s|0)==43727){s=0;if(z<<24>>24==B<<24>>24){s=43728}else{break L56239}}if((s|0)==43728){s=0;C=o+1|0}j=m-1|0;if((j|0)>0){i=i+1|0;l=C;m=j}else{D=C;s=43730;break L56277}}if(z<<24>>24!=A<<24>>24){break L56239}}else{D=g;s=43730}}while(0);if((s|0)==43730){if((a[D]|0)!=0){break}}if((h|0)>0){g=k-h|0;f=0;while(1){m=(a[9755624+g|0]|0)==49|f<<1;l=g+1|0;if((l|0)<(k|0)){g=l;f=m}else{E=m;break}}}else{E=0}if((c[2410658]|0)!=0){c[2440216]=0;c[3528810]=b;return}if((c[e+4>>2]|0)==16){f=E<<1;a[14100392+f|0]=-1;a[14100392+(f|1)|0]=-1;c[3528810]=b;return}else{a[14100392+E|0]=-1;c[3528810]=b;return}}}while(0);E=c[e+4>>2]|0;D=E+h|0;L56314:do{if((k|0)>(D|0)){A=c[e+12>>2]|0;z=gGy(9755624)|0;C=z-D|0;if((A|0)==0|(z|0)==(D|0)){break}L56317:do{if((C|0)>0){z=9755624;B=A;x=C;L56318:while(1){F=a[z]|0;y=F<<24>>24==0;w=B;G=a[B]|0;while(1){if(y|G<<24>>24==0){break L56318}if(G<<24>>24==48){H=48;s=43751;break}if((G<<24>>24|0)==49){H=49;s=43751;break}else if((G<<24>>24|0)==88|(G<<24>>24|0)==120){s=43752;break}else if((G<<24>>24|0)!=42){s=43743;break}q=w+1|0;n=a[q]|0;if(((n<<24>>24)-48|0)>>>0>=2){break L56314}if(F<<24>>24==n<<24>>24){w=q;G=F}else{I=w;break}}if((s|0)==43743){s=0;y=G<<24>>24;while(1){if((y|0)==48|(y|0)==49){H=G;s=43751;break}else if((y|0)==88|(y|0)==120){s=43752;break}}}if((s|0)==43751){s=0;if(F<<24>>24==H<<24>>24){s=43752}else{break L56314}}if((s|0)==43752){s=0;I=w+1|0}y=x-1|0;if((y|0)>0){z=z+1|0;B=I;x=y}else{J=I;s=43754;break L56317}}if(F<<24>>24!=G<<24>>24){break L56314}}else{J=A;s=43754}}while(0);if((s|0)==43754){if((a[J]|0)!=0){break}}A=k-E|0;C=A-h|0;if((C|0)<(A|0)){x=C;C=0;while(1){B=(a[9755624+x|0]|0)==49|C<<1;z=x+1|0;if((z|0)<(A|0)){x=z;C=B}else{K=B;break}}}else{K=0}if((A|0)<(k|0)){C=A;x=0;while(1){L=(a[9755624+C|0]|0)==49|x<<1;B=C+1|0;if((B|0)<(k|0)){C=B;x=L}else{break}}M=x>>>7&255;N=L&255}else{M=0;N=0}if((c[2410658]|0)!=0){c[2440216]=0;c[3528810]=b;return}if((E|0)==16){C=K<<1;a[14100392+C|0]=M;a[14100392+(C|1)|0]=N;c[3528810]=b;return}else{a[14100392+K|0]=N;c[3528810]=b;return}}}while(0);N=c[e+20>>2]|0;K=gGy(9755624)|0;L56358:do{if(!((N|0)==0|(K|0)==0)){L56360:do{if((K|0)>0){M=9755624;E=N;L=K;L56361:while(1){O=a[M]|0;k=O<<24>>24==0;h=E;P=a[E]|0;while(1){if(k|P<<24>>24==0){break L56361}if(P<<24>>24==48){Q=48;s=43776;break}if((P<<24>>24|0)==49){Q=49;s=43776;break}else if((P<<24>>24|0)==88|(P<<24>>24|0)==120){s=43777;break}else if((P<<24>>24|0)!=42){s=43768;break}J=h+1|0;G=a[J]|0;if(((G<<24>>24)-48|0)>>>0>=2){break L56358}if(O<<24>>24==G<<24>>24){h=J;P=O}else{R=h;break}}if((s|0)==43768){s=0;k=P<<24>>24;while(1){if((k|0)==48|(k|0)==49){Q=P;s=43776;break}else if((k|0)==88|(k|0)==120){s=43777;break}}}if((s|0)==43776){s=0;if(O<<24>>24==Q<<24>>24){s=43777}else{break L56358}}if((s|0)==43777){s=0;R=h+1|0}k=L-1|0;if((k|0)>0){M=M+1|0;E=R;L=k}else{S=R;s=43779;break L56360}}if(O<<24>>24!=P<<24>>24){break L56358}}else{S=N;s=43779}}while(0);if((s|0)==43779){if((a[S]|0)!=0){break}}c[2410658]=1;c[2440216]=0;c[3528810]=b;return}}while(0);S=c[e+24>>2]|0;e=gGy(9755624)|0;if((S|0)==0|(e|0)==0){c[3528810]=b;return}L56387:do{if((e|0)>0){N=9755624;P=S;O=e;L56388:while(1){T=a[N]|0;R=T<<24>>24==0;Q=P;U=a[P]|0;while(1){if(R|U<<24>>24==0){s=43790;break L56388}if(U<<24>>24==48){V=48;s=43792;break}if((U<<24>>24|0)==49){V=49;s=43792;break}else if((U<<24>>24|0)==88|(U<<24>>24|0)==120){s=43793;break}else if((U<<24>>24|0)!=42){s=43784;break}K=Q+1|0;x=a[K]|0;if(((x<<24>>24)-48|0)>>>0>=2){s=43807;break L56388}if(T<<24>>24==x<<24>>24){Q=K;U=T}else{W=Q;break}}if((s|0)==43784){s=0;R=U<<24>>24;while(1){if((R|0)==48|(R|0)==49){V=U;s=43792;break}else if((R|0)==88|(R|0)==120){s=43793;break}}}if((s|0)==43792){s=0;if(T<<24>>24==V<<24>>24){s=43793}else{s=43808;break}}if((s|0)==43793){s=0;W=Q+1|0}R=O-1|0;if((R|0)>0){N=N+1|0;P=W;O=R}else{X=W;s=43795;break L56387}}if((s|0)==43790){if(T<<24>>24==U<<24>>24){break}c[3528810]=b;return}else if((s|0)==43807){c[3528810]=b;return}else if((s|0)==43808){c[3528810]=b;return}}else{X=S;s=43795}}while(0);do{if((s|0)==43795){if((a[X]|0)==0){break}c[3528810]=b;return}}while(0);c[2410658]=0;c[2440216]=0;c[3528810]=b;return}function Ts(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=i;i=i+176|0;e=d|0;f=d+16|0;g=d+32|0;h=d+48|0;j=d+64|0;k=d+80|0;l=d+96|0;m=d+112|0;n=d+128|0;o=d+144|0;p=d+160|0;if((a&64|0)==0){i=d;return}do{if((b|0)!=0){if((c[b>>2]|0)>=133378){break}c[b>>2]=169733}}while(0);gGz(p|0,0,12);c[p>>2]=9755624;c[p+4>>2]=40;c[p+12>>2]=302848;gj[c[2076592]&4095](p)|0;gGz(o|0,0,12);c[o>>2]=9760864;c[o+4>>2]=4;c[o+12>>2]=230816;gj[c[2076592]&4095](o)|0;gGz(n|0,0,12);c[n>>2]=9731848;c[n+4>>2]=4;c[n+12>>2]=180088;gj[c[2076592]&4095](n)|0;gGz(m|0,0,12);c[m>>2]=9718592;c[m+4>>2]=4;c[m+12>>2]=144904;gj[c[2076592]&4095](m)|0;gGz(l|0,0,12);c[l>>2]=9720120;c[l+4>>2]=4;c[l+12>>2]=116e3;gj[c[2076592]&4095](l)|0;gGz(k|0,0,12);c[k>>2]=9661024;c[k+4>>2]=4;c[k+12>>2]=102088;gj[c[2076592]&4095](k)|0;gGz(j|0,0,12);c[j>>2]=14113624;c[j+4>>2]=4;c[j+12>>2]=71240;gj[c[2076592]&4095](j)|0;gGz(h|0,0,12);c[h>>2]=14115240;c[h+4>>2]=4;c[h+12>>2]=579048;gj[c[2076592]&4095](h)|0;gGz(g|0,0,12);c[g>>2]=9626528;c[g+4>>2]=4;c[g+12>>2]=562392;gj[c[2076592]&4095](g)|0;gGz(f|0,0,12);c[f>>2]=9642632;c[f+4>>2]=4;c[f+12>>2]=546392;gj[c[2076592]&4095](f)|0;gGz(e|0,0,12);c[e>>2]=9774976;c[e+4>>2]=4;c[e+12>>2]=532488;gj[c[2076592]&4095](e)|0;i=d;return}function Tt(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;if((c[2424886]|0)!=(b|0)){e=c[2424884]|0;if(!((e|0)==4|(e|0)==2)){f=c[2424883]|0;g=f+b|0;a[g]=d;return}if((c[2424890]|0)!=(b|0)){f=c[2424883]|0;g=f+b|0;a[g]=d;return}a[9699524]=a[9699524]&-33|d&32;f=c[2424883]|0;g=f+b|0;a[g]=d;return}if((a[9699520]|0)<0&d<<24>>24>-1){if((b|0)>-1){h=a[(c[2424883]|0)+b|0]|0}else{h=0}a[9699520]=h;h=c[2424887]|0;if((h|0)>-1){i=a[(c[2424883]|0)+h|0]|0}else{i=0}a[9699521]=i;i=c[2424888]|0;if((i|0)>-1){j=a[(c[2424883]|0)+i|0]|0}else{j=0}a[9699522]=j;j=c[2424889]|0;if((j|0)>-1){k=a[(c[2424883]|0)+j|0]|0}else{k=0}a[9699523]=k;k=c[2424890]|0;if((k|0)>-1){l=a[(c[2424883]|0)+k|0]|0}else{l=0}a[9699524]=l;l=c[2424891]|0;if((l|0)>-1){m=a[(c[2424883]|0)+l|0]|0}else{m=0}a[9699525]=m;m=c[2424892]|0;if((m|0)>-1){n=a[(c[2424883]|0)+m|0]|0}else{n=0}a[9699526]=n;n=c[2424893]|0;if((n|0)>-1){o=a[(c[2424883]|0)+n|0]|0}else{o=0}a[9699527]=o;o=c[2424894]|0;if((o|0)>-1){p=a[(c[2424883]|0)+o|0]|0}else{p=0}a[9699528]=p}a[9699520]=d;f=c[2424883]|0;g=f+b|0;a[g]=d;return}function Tu(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=a[9699521]|0;e=a[9699520]|0;if((e|b)<<24>>24<0){return}f=b&255;b=f+1|0;do{if((b&14)>>>0>9){g=(b&112)+16|0;h=g>>>0>89;a[9699521]=((h?0:g&112)|f&128)&255;if(!h){break}h=d[9699522]|0;g=h+1|0;if((g&14)>>>0<=9){a[9699522]=(g&127|h&128)&255;break}i=(g&112)+16|0;g=i>>>0>89;a[9699522]=((g?0:i&112)|h&128)&255;if(!g){break}g=d[9699523]|0;h=g+1|0;if((h&14)>>>0<=9){a[9699523]=(h&63|g&192)&255;break}i=(h&48)+16|0;h=i>>>0>35;a[9699523]=((h?0:i&48)|g&192)&255;if(!h){break}h=a[9699524]|0;g=h+1&7|h&-8;a[9699524]=g;i=a[9699526]|0;j=(((i&255)>>>4)*10&255)+(i&15)&255;k=a[9699527]|0;l=j&255;if((j<<24>>24|0)==2){if(((((k&255)>>>4)*10&255)+k&3)==0){m=41}else{n=43868}}else if((j<<24>>24|0)==0){m=49}else{if((j&255)<13){n=43868}else{m=49}}if((n|0)==43868){m=d[619232+(l-1)|0]|0}l=d[9699525]|0;j=l+1|0;if((j&14)>>>0<=9){a[9699525]=(j&63|l&192)&255;break}o=(j&48)+16|0;j=o>>>0>m>>>0;a[9699525]=((j?1:o&48)|l&192)&255;if(!j){break}j=i&255;i=j+1|0;if((i&14)>>>0<=9){a[9699526]=(i&31|j&224)&255;break}l=(i&16)+16|0;i=l>>>0>18;a[9699526]=((i?1:l&16)|j&224)&255;if(!i){break}i=(k&255)+1|0;if((i&14)>>>0<=9){a[9699527]=i&255;break}k=(i&240)+16|0;i=k>>>0>153;a[9699527]=i?0:k&255;if(!i){break}i=(d[9699528]|0)+1|0;if((i&14)>>>0>9){k=(i&240)+16|0;p=k>>>0>153?0:k&255}else{p=i&255}a[9699528]=p;i=c[2424884]|0;if(!((i|0)==4|(i|0)==2)){break}if((h&32)==0){break}a[9699524]=g^16}else{a[9699521]=(b&127|f&128)&255}}while(0);if((e&64)!=0){return}f=c[2424886]|0;if((f|0)>-1){a[(c[2424883]|0)+f|0]=e}e=c[2424887]|0;if((e|0)>-1){a[(c[2424883]|0)+e|0]=a[9699521]|0}e=c[2424888]|0;if((e|0)>-1){a[(c[2424883]|0)+e|0]=a[9699522]|0}e=c[2424889]|0;if((e|0)>-1){a[(c[2424883]|0)+e|0]=a[9699523]|0}e=c[2424890]|0;if((e|0)>-1){a[(c[2424883]|0)+e|0]=a[9699524]|0}e=c[2424891]|0;if((e|0)>-1){a[(c[2424883]|0)+e|0]=a[9699525]|0}e=c[2424892]|0;if((e|0)>-1){a[(c[2424883]|0)+e|0]=a[9699526]|0}e=c[2424893]|0;if((e|0)>-1){a[(c[2424883]|0)+e|0]=a[9699527]|0}e=c[2424894]|0;if((e|0)<=-1){return}a[(c[2424883]|0)+e|0]=a[9699528]|0;return}function Tv(b){b=b|0;var d=0,e=0,f=0;d=i;i=i+8|0;e=d|0;c[2424884]=b;switch(b|0){case 4:{c[2424886]=8184;c[2424887]=8185;c[2424888]=8186;c[2424889]=8187;c[2424890]=8188;c[2424891]=8189;c[2424892]=8190;c[2424893]=8191;c[2424894]=-1;c[2424895]=-1;c[2424885]=8192;f=8192;break};case 3:{c[2424886]=32760;c[2424887]=32761;c[2424888]=32762;c[2424889]=32763;c[2424890]=32764;c[2424891]=32765;c[2424892]=32766;c[2424893]=32767;c[2424894]=32753;c[2424895]=32752;c[2424885]=32768;f=32768;break};case 1:{c[2424886]=2040;c[2424887]=2041;c[2424888]=2042;c[2424889]=2043;c[2424890]=2044;c[2424891]=2045;c[2424892]=2046;c[2424893]=2047;c[2424894]=-1;c[2424895]=-1;c[2424885]=2048;f=2048;break};case 5:{c[2424886]=8184;c[2424887]=8185;c[2424888]=8186;c[2424889]=8187;c[2424890]=8188;c[2424891]=8189;c[2424892]=8190;c[2424893]=8191;c[2424894]=8177;c[2424895]=8176;c[2424885]=8192;f=8192;break};case 2:{c[2424886]=32760;c[2424887]=32761;c[2424888]=32762;c[2424889]=32763;c[2424890]=32764;c[2424891]=32765;c[2424892]=32766;c[2424893]=32767;c[2424894]=-1;c[2424895]=-1;c[2424885]=32768;f=32768;break};default:{f=c[2424885]|0}}b=gGq(f)|0;gGz(b|0,-1|0,f|0);a[727232]=1;c[2424883]=b;gb(e|0)|0;b=a5(e|0)|0;a[9699520]=0;e=c[b>>2]&255;a[9699521]=((((e&255)/10|0)&255)%10|0)<<4|((e&255)%10|0);e=c[b+4>>2]&255;a[9699522]=((((e&255)/10|0)&255)%10|0)<<4|((e&255)%10|0);e=c[b+8>>2]&255;a[9699523]=((((e&255)/10|0)&255)%10|0)<<4|((e&255)%10|0);e=(c[b+24>>2]|0)+1&255;a[9699524]=((((e&255)/10|0)&255)%10|0)<<4|((e&255)%10|0);e=c[b+12>>2]&255;a[9699525]=((((e&255)/10|0)&255)%10|0)<<4|((e&255)%10|0);e=(c[b+16>>2]|0)+1&255;a[9699526]=((((e&255)/10|0)&255)%10|0)<<4|((e&255)%10|0);e=b+20|0;b=((c[e>>2]|0)%100|0)&255;a[9699527]=((((b&255)/10|0)&255)%10|0)<<4|((b&255)%10|0);b=((c[e>>2]|0)/100|0)&255;a[9699528]=((((b&255)/10|0)&255)%10|0)<<4|((b&255)%10|0);i=d;return}function Tw(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=b&65535;switch(f|0){case 16384:{c[2432908]=0;c[2432768]=1;return};case 16387:{c[2384374]=255;if((c[2384378]&255|0)!=255){return}a[9706117]=0;return};case 16392:{b=c[2438058]&3;if((b|0)==0){a[(c[3540984]|0)+5885|0]=e;return}else if((b|0)==2){g=c[3541518]|0;h=g+256|0;a[g+304|0]=e;i=e&255;if((e&255)<16){c[14168912+((c[2383582]|0)*252|0)>>2]=i&15}if((e-45&255)>=3){return}if((i|0)==46){j=g+312|0;k=a[j]|1;a[j]=k;l=k}else if((i|0)==45){k=g+312|0;j=a[k]|2;a[k]=j;l=j}else if((i|0)==0){a[g+312|0]=2;l=2}else if((i|0)==47){a[g+312|0]=0;l=0}else{l=a[g+312|0]|0}g=l&3;l=c[7461744+(g<<2)>>2]|0;lI(h,l,l,c[7461728+(g<<2)>>2]|0);return}else if((b|0)==1){c[2113304]=e&255;return}else{return}break};case 16385:{c[2384374]=255;c[2384378]=255;a[9706117]=0;return};case 24578:{if((c[2438058]&4|0)==0){return}Uv(1,e);return};case 16408:case 16409:{a[9553896+(f&1)|0]=e;return};case 24576:{Uv(0,e);return};case 16391:{b=e&1;c[2438576]=b;g=c[3532600]|0;l=c[9757320+(c[1836236]<<2)>>2]|0;h=(b<<15|65536)-32768|0;b=128;i=128;while(1){c[l+76+(i<<2)>>2]=g+(h+(i<<8));j=b+1&65535;if((j&65535)>255){m=128;n=128;break}else{b=j;i=j&65535}}while(1){i=g+(h+(n<<8))|0;c[l+76+(n+512<<2)>>2]=i;c[l+76+(n+768<<2)>>2]=i;i=m+1&65535;if((i&65535)>255){break}else{m=i;n=i&65535}}return};case 24585:case 24584:{if((c[2438058]|0)!=2){return}lS(1,f&1,e);return};case 16393:{f=c[2438058]&3;if((f|0)==2){lS(0,1,e);return}else if((f|0)==1){n=c[2113304]|0;a[14168504+n|0]=e;mv(0,n,e&255);return}else if((f|0)==0){f=c[3540984]|0;n=c[f+5876>>2]|0;if((n|0)!=0){gg[n&4095](c[f+5880>>2]|0,0)}lH(f,d[f+5885|0]|0,e&255);return}else{return}break};default:{return}}}function Tx(b){b=b|0;var e=0,f=0,g=0,i=0,j=0,k=0.0,l=0.0;e=b&65535;switch(e|0){case 24578:{if((c[2438058]&4|0)==0){f=0;return f|0}f=c[2113156]&255;return f|0};case 16392:{b=c[2438058]&3;if((b|0)==0){g=c[3540984]|0;i=(d[g+5887|0]|0|128)&(d[g+5886|0]|0);if((a[g+5884|0]&2)==0){j=i&255}else{j=(a[(c[g+5828>>2]|0)+100|0]&1|i)&255}f=j|6;return f|0}else if((b|0)==1){f=c[(c[3531464]|0)+4240>>2]&255;return f|0}else if((b|0)==2){b=c[3541518]|0;j=b+296|0;k=+h[j>>3];do{if(k!=0.0){l=+h[6675];if(k-(l+ +gC[c[2429842]&255]())<=0.0){h[j>>3]=0.0;break}f=a[b+307|0]|-128;return f|0}}while(0);f=a[b+307|0]|0;return f|0}else{f=0;return f|0}break};case 16393:{if((c[2438058]|0)<2){f=0;return f|0}if((d[(c[3541518]|0)+304|0]|0)>=16){f=0;return f|0}b=c[2383582]|0;j=c[14168912+(b*252|0)>>2]|0;if((j|0)>15){f=0;return f|0}do{if((j|0)==14){i=c[14168896+(b*252|0)>>2]|0;if((i|0)==0){break}a[14168930+(b*252|0)|0]=gj[i&4095](0)|0}else if((j|0)==15){i=c[14168900+(b*252|0)>>2]|0;if((i|0)==0){break}a[14168931+(b*252|0)|0]=gj[i&4095](0)|0}}while(0);f=a[14168916+(b*252|0)+j|0]|0;return f|0};case 16400:case 16401:{f=a[9579184+(e&1)|0]|0;return f|0};case 16402:{f=(c[2432768]|0)!=0|0;return f|0};case 16403:{f=c[2110938]&255;return f|0};case 24576:{f=c[2113156]&255;return f|0};default:{f=0;return f|0}}return 0}function Ty(){var d=0,e=0,f=0,g=0,i=0,j=0;d=c[2439330]|0;e=(d|0)==0;if(!e){f=d;gGC(9706056,f|0,76)|0}f=c[2438118]|0;c[2433530]=f;g=c[3528484]|0;c[2076596]=g;i=c[2417276]|0;c[3541536]=i;c[1836236]=0;gGz(9706056,0,76);c[2384374]=255;c[2384378]=255;a[9706117]=0;if(!e){e=d;gGC(e|0,9706056,76)|0}c[2438118]=f;c[3528484]=g;c[2417276]=i;c[1836236]=-1;i=c[2438058]&3;do{if((i|0)==1){mx(0)}else if((i|0)==0){c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;lw(c[3540984]|0)}else if((i|0)==2){c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){j=0}else{break}do{lN(j);mB(j);j=j+1|0;}while((j|0)<(c[2385508]|0))}}while(0);c[2113156]=0;a[9628264]=0;c[2407033]=0;j=c[3541206]|0;c[3541190]=j;c[3541198]=j;gGz(c[2430118]|0,0,16384);c[2407041]=4;c[3541191]=j+256;c[3541199]=j+65536;gGz(c[2430119]|0,0,16384);c[2407049]=4;c[3541192]=j+512;c[3541200]=j+131072;gGz(c[2430120]|0,0,16384);c[2407057]=4;c[3541193]=j+768;c[3541201]=j+196608;gGz(c[2430121]|0,0,16384);c[2407065]=4;if((c[2438058]&4|0)==0){b[4789592]=0;b[4776948]=0;c[2432908]=0;c[2432768]=0;c[2110938]=0;c[2438576]=0;return}c[2113157]=0;a[9628420]=0;c[2407072]=0;i=j+1048576|0;c[3541194]=i;c[3541202]=i;gGz(c[2430122]|0,0,16384);c[2407080]=4;c[3541195]=j+1048832;c[3541203]=j+1114112;gGz(c[2430123]|0,0,16384);c[2407088]=4;c[3541196]=j+1049088;c[3541204]=j+1179648;gGz(c[2430124]|0,0,16384);c[2407096]=4;c[3541197]=j+1049344;c[3541205]=j+1245184;gGz(c[2430125]|0,0,16384);c[2407104]=4;b[4789592]=0;b[4776948]=0;c[2432908]=0;c[2432768]=0;c[2110938]=0;c[2438576]=0;return}function Tz(e,f,g){e=e|0;f=f|0;g=g|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;c[2438058]=e;e=c[3532604]|0;do{if((f|0)!=0&(e|0)!=0){if((f|0)<=0){break}i=c[3532600]|0;j=0;do{k=i+j|0;l=d[k]|0;m=j>>>9;n=m&1;o=j>>>8;p=(o&1&m|0)==0?l:l^128;l=j>>>11;m=l&1;q=j>>>4;r=q&1;s=j>>>1;t=(s&l&r|0)==0?p:p^64;p=(m&s&((o|-2)^1)|0)==0;u=p?t:t^4;v=j>>>13;w=(j>>>6|-2)^1;x=(v&1&q&w|0)==0;q=j>>>2;y=n&q&(l^1);l=(x?u:u^2)^y;u=(r&v|0)==0;if(u){z=l}else{z=l<<1&2|l&252|l>>>1&1}l=(r&o|0)==0;if(l){A=z&255}else{A=(z>>>2<<3&8|z&243|z>>>3<<2&4)&255}a[k]=A;k=j>>>12;o=(k&1&(v^1)|0)==0?t:t^32;t=(s&1&w|0)==0?o:o^16;o=(q&1&(k^1)|0)==0?t:t^8;t=p?o:o^4;o=(x?t:t^2)^y;if(u){B=o}else{B=o<<1&2|o&252|o>>>1&1}if(l){C=B}else{C=B>>>2<<3&8|B&243|B>>>3<<2&4}if((n&k|0)==0){D=C}else{D=C>>>4<<5&32|C&207|C>>>5<<4&16}if((w&m|0)==0){E=D&255}else{E=(D>>>6<<7|D&63|D>>>7<<6&64)&255}a[e+j|0]=E;j=j+1|0;}while((j|0)<(f|0))}else{c[3532604]=c[3532600]}}while(0);a[688512]=1;fwR(0);f=c[2439330]|0;if((f|0)!=0){E=f;gGC(9706056,E|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];E=c[3528484]|0;c[2076596]=E;e=c[2417276]|0;c[3541536]=e;c[1836236]=0;D=c[3532600]|0;C=0;B=0;while(1){c[f+76+(B<<2)>>2]=D+(B<<8);A=C+1&65535;if((A&65535)>31){break}else{C=A;B=A&65535}}B=c[3532604]|0;C=0;A=0;while(1){z=A<<8;c[f+76+(A+512<<2)>>2]=B+z;c[f+76+(A+768<<2)>>2]=D+z;z=C+1&65535;if((z&65535)>31){break}else{C=z;A=z&65535}}A=c[3532602]|0;c[f+204>>2]=A;C=A+256|0;c[f+208>>2]=C;D=A+512|0;c[f+212>>2]=D;B=A+768|0;c[f+216>>2]=B;z=A+1024|0;c[f+220>>2]=z;j=A+1280|0;c[f+224>>2]=j;i=A+1536|0;c[f+228>>2]=i;m=A+1792|0;c[f+232>>2]=m;c[f+1228>>2]=A;c[f+1232>>2]=C;c[f+1236>>2]=D;c[f+1240>>2]=B;c[f+1244>>2]=z;c[f+1248>>2]=j;c[f+1252>>2]=i;c[f+1256>>2]=m;c[f+2252>>2]=A;c[f+3276>>2]=A;c[f+2256>>2]=C;c[f+3280>>2]=C;c[f+2260>>2]=D;c[f+3284>>2]=D;c[f+2264>>2]=B;c[f+3288>>2]=B;c[f+2268>>2]=z;c[f+3292>>2]=z;c[f+2272>>2]=j;c[f+3296>>2]=j;c[f+2276>>2]=i;c[f+3300>>2]=i;c[f+2280>>2]=m;c[f+3304>>2]=m;c[f+4184>>2]=3052;c[f+4180>>2]=1248;m=f;gGC(m|0,9706056,76)|0;c[2438118]=c[2433530];c[3528484]=E;c[2417276]=e;c[1836236]=-1;e=c[2438058]&3;if((e|0)==0){UL(3579545,214,2356,0);c[2438224]=3579545;c[2433522]=3416;c[2406672]=1752;c[3528468]=9362;c[2443842]=571}else if((e|0)==1){Vc(3579545);c[(c[3531464]|0)+44344>>2]=302;h[745421]=.5;c[2436794]=3;h[745420]=.5;c[2436792]=3}else if((e|0)==2){Vr(2,3579545,214,2356,72,0);c[2438228]=3579545;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=571}Ux(0,g,1);c[2407030]=102;c[2407068]=3;if((c[2438058]&4|0)!=0){Ux(1,g,1);c[2407069]=102;c[2407107]=3}if((fa(c[c[642608+(c[2436]<<2)>>2]>>2]|0,186768)|0)!=0){return}a[7045208]=1;return}function TA(b,d){b=b|0;d=d|0;if((d|0)!=0){c[2384378]=215;if((c[2384374]|0)!=223){return}a[14125144]=-41;a[9706117]=1;return}c[2384378]=255;d=c[2384374]|0;if((d&255|0)==255){a[9706117]=0;return}if((d|0)!=223){return}a[14125144]=-33;a[9706117]=1;return}function TB(a){a=a|0;var b=0,d=0;b=(c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0;d=gGU(b,(b|0)<0|0?-1:0,a,(a|0)<0|0?-1:0)|0;a=gGS(d,K,3579545,0)|0;return a|0}function TC(b){b=b|0;if((b|0)!=0){c[2384378]=215;if((c[2384374]|0)!=223){return}a[14125144]=-41;a[9706117]=1;return}c[2384378]=255;b=c[2384374]|0;if((b&255|0)==255){a[9706117]=0;return}if((b|0)!=223){return}a[14125144]=-33;a[9706117]=1;return}function TD(){return+(+((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)/(a[688512]|0?3579545.0:0.0))}function TE(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[2438058]&3;do{if((b|0)==0){d=a[7452584]|0;if(d){e=0;f=d&1;while(1){d=14163936+(e<<2)|0;g=c[d>>2]|0;h=c[2113006]|0;if((h|0)==0){i=44094}else{j=h-1|0;c[2113006]=j;if((j|0)==0){i=44094}}if((i|0)==44094){i=0;c[2383474]=0}if((g|0)==0){k=f}else{gGr(g);k=a[7452584]&1}c[d>>2]=0;d=e+1|0;if((d|0)<(k|0)){e=d;f=k}else{break}}}a[7452584]=0;c[2438224]=0;c[2433522]=0;c[2406672]=0;c[3528468]=0;f=c[2406688]|0;if((f|0)!=0){gGr(f);c[2406688]=0}c[2432972]=0}else if((b|0)==1){f=c[3531464]|0;c[f+44344>>2]=0;c[f+44348>>2]=0;if((f|0)!=0){gGr(f);c[3531464]=0}f=c[2406684]|0;if((f|0)==0){break}gGr(f);c[2406684]=0}else if((b|0)==2){f=c[3541518]|0;if((f|0)!=0){gGr(f|0);c[3541518]=0}if((c[2385508]|0)>0){c[2113008]=0;c[2076598]=0;c[2383582]=0}c[2438228]=0;c[2433526]=0;c[2406676]=0;c[3528472]=0;f=c[2406680]|0;if((f|0)!=0){gGr(f);c[2406680]=0}c[2385508]=0;c[2432978]=0;a[64240]=0}}while(0);Uw(0);if((c[2438058]&4|0)==0){fwZ();c[3541206]=0;c[3532604]=0;c[3532600]=0;c[3532602]=0;a[688512]=0;a[7045208]=0;return}Uw(1);fwZ();c[3541206]=0;c[3532604]=0;c[3532600]=0;c[3532602]=0;a[688512]=0;a[7045208]=0;return}function TF(a,e){a=a|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+144|0;g=f|0;h=f+16|0;j=f+32|0;k=f+48|0;l=f+64|0;m=f+80|0;n=f+96|0;o=f+112|0;p=f+128|0;if((e&96|0)!=0){fw$(e);q=c[2438058]&3;do{if((q|0)==2){if((e&64|0)==0){break}gGz(h|0,0,12);c[h>>2]=8453216;c[h+4>>2]=4;c[h+12>>2]=107480;r=c[2076592]|0;gj[r&4095](h)|0;gGz(g|0,0,12);c[g>>2]=14168504;c[g+4>>2]=256;c[g+12>>2]=476464;r=c[2076592]|0;gj[r&4095](g)|0;if((e&2|0)==0){break}else{s=0}do{mv(0,s,d[14168504+s|0]|0);s=s+1|0;}while((s|0)<256)}else if((q|0)==0){UQ(e,a)}else if((q|0)==1){Vx(e,a)}}while(0);Ut(0);if((c[2438058]&4|0)!=0){Ut(1)}gGz(p|0,0,12);c[p>>2]=9579184;c[p+4>>2]=1;c[p+12>>2]=504048;a=c[2076592]|0;gj[a&4095](p)|0;gGz(o|0,0,12);c[o>>2]=9579185;c[o+4>>2]=1;c[o+12>>2]=388040;p=c[2076592]|0;gj[p&4095](o)|0;gGz(n|0,0,12);c[n>>2]=9553896;c[n+4>>2]=1;c[n+12>>2]=301872;o=c[2076592]|0;gj[o&4095](n)|0;gGz(m|0,0,12);c[m>>2]=9553897;c[m+4>>2]=1;c[m+12>>2]=230176;n=c[2076592]|0;gj[n&4095](m)|0;gGz(l|0,0,12);c[l>>2]=9731632;c[l+4>>2]=4;c[l+12>>2]=392160;m=c[2076592]|0;gj[m&4095](l)|0;gGz(k|0,0,12);c[k>>2]=9731072;c[k+4>>2]=4;c[k+12>>2]=380848;l=c[2076592]|0;gj[l&4095](k)|0;gGz(j|0,0,12);c[j>>2]=9754304;c[j+4>>2]=4;c[j+12>>2]=115736;k=c[2076592]|0;gj[k&4095](j)|0}if((e&2|0)==0){i=f;return}e=c[2439330]|0;j=(e|0)==0;if(!j){k=e;gGC(9706056,k|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];k=c[3528484]|0;c[2076596]=k;l=c[2417276]|0;c[3541536]=l;c[1836236]=0;m=c[2438576]&1;c[2438576]=m;n=c[3532600]|0;o=(m<<15|65536)-32768|0;m=128;p=128;while(1){c[e+76+(p<<2)>>2]=n+(o+(p<<8));a=m+1&65535;if((a&65535)>255){t=128;u=128;break}else{m=a;p=a&65535}}while(1){p=n+(o+(u<<8))|0;c[e+76+(u+512<<2)>>2]=p;c[e+76+(u+768<<2)>>2]=p;p=t+1&65535;if((p&65535)>255){break}else{t=p;u=p&65535}}if(!j){j=e;gGC(j|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=k;c[2417276]=l;c[1836236]=-1;i=f;return}function TG(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;f=c[2438]|0;g=gGU(f,(f|0)<0|0?-1:0,7159090,0)|0;f=gGS(g,K,15360,0)|0;g=a[9688]|0?534:0;h=(ag(c[2415275]|0,g)|0)/(f|0)|0;f=(h|0)<(g|0);i=c[2429300]|0;j=(f?h:g)-i|0;if((j|0)<1){return}g=(c[2438892]|0)+(i<<1<<1)|0;c[2429300]=f?h:0;h=d[9681745]|0;f=c[596888+(h>>>4<<2)>>2]|0;i=c[596888+((h&15)<<2)>>2]|0;gGz(g|0,0,j<<2|0);h=62-f|0;f=62-i|0;i=0;do{k=a[9681750+(i*52|0)|0]|0;l=k&255;L56838:do{if((l&128|0)!=0){m=d[9681751+(i*52|0)|0]|0;n=l&31^31;o=h+n-(c[596888+(m>>>4<<2)>>2]|0)|0;p=f+n-(c[596888+((m&15)<<2)>>2]|0)|0;m=b[9682164+(((o|0)>31?31:o)<<1)>>1]|0;o=m<<16>>16;n=b[9682164+(((p|0)>31?31:p)<<1)>>1]|0;p=n<<16>>16;do{if((i|0)>3){q=d[9681788+(i*52|0)|0]|0;if((q&128|0)==0){break}r=c[9682228+((q&31^31)<<2)>>2]|0;q=9681792+(i*52|0)|0;s=g;t=0;while(1){u=(c[q>>2]|0)+r|0;c[q>>2]=u;if(u>>>0>2047){v=((cT()|0)&1|0)!=0;w=v?31:0;c[2384336]=w;x=c[q>>2]|0;y=w}else{x=u;y=c[2384336]|0}c[q>>2]=x&2047;u=y-16|0;w=ag(u,o)|0;b[s>>1]=(e[s>>1]|0)+w&65535;w=ag(u,p)|0;u=s+2|0;b[u>>1]=(e[u>>1]|0)+w&65535;w=t+1|0;if((w|0)<(j|0)){s=s+4|0;t=w}else{break L56838}}}}while(0);if((k&64)==0){t=c[9682356+((e[9681748+(i*52|0)>>1]|0)<<2)>>2]|0;s=9681796+(i*52|0)|0;q=g;r=0;while(1){w=c[s>>2]|0;c[s>>2]=w+t&131071;u=(d[(w>>>12&31)+(9681752+(i*52|0))|0]|0)-16|0;w=ag(u,o)|0;b[q>>1]=w+(e[q>>1]|0)&65535;w=ag(u,p)|0;u=q+2|0;b[u>>1]=(e[u>>1]|0)+w&65535;w=r+1|0;if((w|0)<(j|0)){q=q+4|0;r=w}else{break}}}else{r=9681786+(i*52|0)|0;q=g;p=0;while(1){o=ag((b[r>>1]|0)-16&65535,m)|0;b[q>>1]=o+(b[q>>1]|0)&65535;o=ag((b[r>>1]|0)-16&65535,n)|0;t=q+2|0;b[t>>1]=o+(b[t>>1]|0)&65535;t=p+1|0;if((t|0)<(j|0)){q=q+4|0;p=t}else{break}}}}}while(0);i=i+1|0;}while((i|0)<6);return}function TH(f,g,i){f=f|0;g=g|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;c[2424878]=9681232+(f<<6);c[2426622]=9622928+(f*48|0);j=c[2424800]|0;k=i<<2;gGz(j|0,0,k|0);l=c[2418166]|0;gGz(l|0,0,k|0);if((i|0)<=0){return}k=9622940+(f*48|0)|0;m=0;do{n=c[2424878]|0;L56865:do{if((c[n+36+(m<<2)>>2]|0)!=0){o=d[n+(m<<1)|0]<<1;p=d[n+(m<<1)+1|0]<<1;q=c[n+4+(m<<2)>>2]|0;r=c[n+12+(m<<2)>>2]|0;s=1<<m;t=m*6|0;u=t+4|0;v=t+3|0;w=t+2|0;t=9622932+(f*48|0)+(m<<2)|0;x=0;y=(q>>>12)+r|0;z=n;A=r;r=q;while(1){q=z+12+(m<<2)|0;B=(r>>>12)+A|0;C=y;while(1){if(C>>>0>B>>>0){D=B;break}if((a[(c[t>>2]|0)+C|0]|0)<0){E=44165;break}if(C>>>0<(c[k>>2]|0)>>>0){C=C+1|0}else{E=44165;break}}do{if((E|0)==44165){E=0;if((d[z+57|0]&s|0)==0){c[z+36+(m<<2)>>2]=0;D=B;break}else{c[q>>2]=d[z+44+u|0]<<16&65536|d[z+44+v|0]<<8|d[z+44+w|0]|c[z+28+(m<<2)>>2];C=c[2424878]|0;F=c[C+12+(m<<2)>>2]|0;c[C+4+(m<<2)>>2]=0;D=F;break}}}while(0);q=c[2424878]|0;if((c[q+36+(m<<2)>>2]|0)==0){break L56865}B=(ag(c[q+60>>2]|0,c[q+20+(m<<2)>>2]|0)|0)>>>16;F=q+4+(m<<2)|0;c[F>>2]=B+(c[F>>2]|0);F=(a[(c[t>>2]|0)+D|0]&127)-64|0;B=ag(F,o)|0;q=j+(x<<2)|0;c[q>>2]=B+(c[q>>2]|0);q=ag(F,p)|0;F=l+(x<<2)|0;c[F>>2]=(c[F>>2]|0)+q;q=x+1|0;if((q|0)>=(i|0)){break L56865}F=c[2424878]|0;x=q;y=D;z=F;A=c[F+12+(m<<2)>>2]|0;r=c[F+4+(m<<2)>>2]|0}}}while(0);m=m+1|0;}while((m|0)<2);m=9622968+(f*48|0)|0;D=9622972+(f*48|0)|0;E=9622960+(f*48|0)|0;k=9622952+(f*48|0)|0;f=0;n=g;while(1){g=c[m>>2]|0;if((g&1|0)==0){G=0}else{G=~~(+(c[j+(f<<2)>>2]|0)*+h[k>>3])}if((g&2|0)==0){H=0}else{H=~~(+(c[j+(f<<2)>>2]|0)*+h[k>>3])}g=c[D>>2]|0;if((g&1|0)==0){I=G}else{I=~~(+(c[l+(f<<2)>>2]|0)*+h[E>>3])+G|0}if((g&2|0)==0){J=H}else{J=~~(+(c[l+(f<<2)>>2]|0)*+h[E>>3])+H|0}if((I|0)<-32768){K=-32768}else{K=(I|0)>32767?32767:I}if((J|0)<-32768){L=-32768}else{L=(J|0)>32767?32767:J}b[n>>1]=(e[n>>1]|0)+K&65535;g=n+2|0;b[g>>1]=(e[g>>1]|0)+L&65535;g=f+1|0;if((g|0)>=(i|0)){break}f=g;n=n+4|0}return}function TI(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0;c[2424878]=9681232+(b<<6);c[2426622]=9622928+(b*48|0);a[9681276+(b<<6)+e|0]=f&255;if((e|0)==12){g=c[9622944+(b*48|0)>>2]|0;if((g|0)==0){return}gf[g&2047](f);return}else if((e|0)==13){return}else{f=(e|0)>5;g=f?e-6|0:e;e=f&1;if((g|0)==5){f=-e&6;h=(d[f+4+(9681276+(b<<6))|0]|0)<<16&65536|(d[f+3+(9681276+(b<<6))|0]|0)<<8|(d[f+2+(9681276+(b<<6))|0]|0)|c[9681260+(b<<6)+(e<<2)>>2];c[9681244+(b<<6)+(e<<2)>>2]=h;if(h>>>0>=(c[9622940+(b*48|0)>>2]|0)>>>0){return}c[9681268+(b<<6)+(e<<2)>>2]=1;c[9681236+(b<<6)+(e<<2)>>2]=0;return}else if((g|0)==0|(g|0)==1){g=-e&6;c[9681252+(b<<6)+(e<<2)>>2]=c[9642768+(((d[(g|1)+(9681276+(b<<6))|0]|0)<<8&256|(d[9681276+(b<<6)+g|0]|0))<<2)>>2];return}else{return}}}function TJ(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,i=0;f=9681232+(b<<6)|0;c[2424878]=f;g=9622928+(b*48|0)|0;c[2426622]=g;i=f|0;gGz(i|0,0,64);gGz(g|0,0,48);if((c[2424800]|0)==0){c[2424800]=gGq(a[9688]|0?2136:0)|0}if((c[2418166]|0)==0){c[2418166]=gGq(a[9688]|0?2136:0)|0}c[9622932+(b*48|0)>>2]=d;c[9622936+(b*48|0)>>2]=d;c[9622940+(b*48|0)>>2]=e;c[g>>2]=3579545;gGz(9681244+(b<<6)|0,0,32);a[i]=-1;a[9681233+(b<<6)|0]=0;a[9681234+(b<<6)|0]=0;a[9681235+(b<<6)|0]=-1;gGz(9681276+(b<<6)|0,0,16);i=0;do{c[9642768+(i<<2)>>2]=131072/(512-i|0)|0;i=i+1|0;}while((i|0)<512);c[9681292+(b<<6)>>2]=~~(27965.1953125/(a[9680]|0?32.0e3:0.0)*65536.0);h[9622952+(b*48|0)>>3]=1.0;h[9622960+(b*48|0)>>3]=1.0;c[9622968+(b*48|0)>>2]=3;c[9622972+(b*48|0)>>2]=3;return}function TK(f,g){f=f|0;g=g|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0.0,E=0.0,F=0.0,G=0.0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0;c[2420384]=9675200;i=c[2419508]|0;j=c[2419507]|0;k=j;l=c[2388478]|0;m=g<<2;gGz(l|0,0,m|0);n=c[2388476]|0;gGz(n|0,0,m|0);m=c[2419512]|0;o=c[2419514]|0;if((a[9678027]&1)==0){return}p=i+g|0;c[2419508]=p&16383;q=(g|0)>0;r=c[2443786]|0;s=0;do{t=1<<s;do{if((d[9678024]&t|0)!=0){u=s<<5;v=s<<1;w=v+9677980|0;x=d[9677468+(u|1)|0]<<8|d[9677468+u|0]|d[9677468+(u|2)|0]<<16;y=d[9677468+(u|3)|0]|0;z=(d[9677468+(u|4)|0]|0)+y|0;A=a[9677468+(u|5)|0]|0;B=A&255;if((A+127&255)<15){C=B-129|0}else{C=(A-17&255)<15?B-17|0:7}D=+h[9677376+(s<<3)>>3];E=+h[9675208+(y<<3)>>3];F=D*E*+h[9677256+(C<<3)>>3];G=F>1.8?1.8:F;F=D*E*+h[9677256+(14-C<<3)>>3];E=F>1.8?1.8:F;F=D*+h[9675208+(((z|0)>255?255:z)<<3)>>3]*.5;D=F>1.8?1.8:F;z=((d[9677468+(u|7)|0]<<8|d[9677468+(u|6)|0])>>>3)+i&16383;y=9677468+(u|12)|0;B=9677468+(u|13)|0;A=9677468+(u|14)|0;H=(d[B]<<8|d[y]|d[A]<<16)&o;I=a[w]|0;J=(I&32)==0;K=J?x:-x|0;x=J?-65536:65536;L=J?1:-1;J=9678088+(s<<4)|0;if((H|0)==(c[J>>2]|0)){M=c[9678100+(s<<4)>>2]|0;N=c[9678096+(s<<4)>>2]|0;O=c[9678092+(s<<4)>>2]|0;P=I}else{c[J>>2]=H;M=0;N=0;O=0;P=a[w]|0}w=P&12;L56949:do{if((w|0)==0){if(!q){Q=M;R=N;S=O;T=H;break}I=v+9677981|0;U=9677468+(u|8)|0;V=9677468+(u|9)|0;W=9677468+(u|10)|0;X=(ag(r,L)|0)>>>15;Y=H;Z=O;_=N;$=M;aa=z;ab=n;ac=0;ad=l;L56952:while(1){ae=Z+K|0;if(ae>>>0>65535){af=Y;ah=ae;ai=_;while(1){aj=ah+x|0;ak=af+X|0;al=a[m+ak|0]|0;am=(al&255)<<8<<16>>16;if(al<<24>>24==-128){if((a[I]&1)==0){an=am;ao=ak;break L56952}al=(d[V]<<8|d[U]|d[W]<<16)&o;ap=a[m+al|0]|0;aq=(ap&255)<<8<<16>>16;if(ap<<24>>24==-128){an=aq;ao=al;break L56952}else{ar=aq;as=al}}else{ar=am;as=ak}if(aj>>>0>65535){af=as;ah=aj;ai=ar}else{at=as;au=aj;av=ar;aw=ai;break}}}else{at=Y;au=ae;av=_;aw=$}F=+(av|0);c[ad>>2]=(~~(G*F)<<16>>16)+(c[ad>>2]|0);c[ab>>2]=(c[ab>>2]|0)+(~~(E*F)<<16>>16);ah=k+(aa<<1)|0;b[ah>>1]=(b[ah>>1]|0)+~~(D*F)&65535;ah=ac+1|0;if((ah|0)<(g|0)){Y=at;Z=au;_=av;$=aw;aa=aa+1&16383;ab=ab+4|0;ac=ah;ad=ad+4|0}else{Q=aw;R=av;S=au;T=at;break L56949}}if((a[9678027]|0)<0){Q=ai;R=an;S=aj;T=ao;break}a[9678024]=d[9678024]&(t^255)&255;Q=ai;R=an;S=aj;T=ao}else if((w|0)==4){if(!q){Q=M;R=N;S=O;T=H;break}ad=v+9677981|0;ac=9677468+(u|8)|0;ab=9677468+(u|9)|0;aa=9677468+(u|10)|0;$=(ag(L<<1,r)|0)>>>15;_=H;Z=O;Y=N;W=M;U=z;V=n;I=0;X=l;L56966:while(1){ah=Z+K|0;if(ah>>>0>65535){af=_;ak=ah;ax=Y;while(1){ay=ak+x|0;am=af+$|0;al=d[m+(am+1)|0]<<8|d[m+am|0];aq=al<<16>>16;if(al<<16>>16==-32768){if((a[ad]&1)==0){az=aq;aA=am;break L56966}al=(d[ab]<<8|d[ac]|d[aa]<<16)&o;ap=d[m+(al+1)|0]<<8|d[m+al|0];aB=ap<<16>>16;if(ap<<16>>16==-32768){az=aB;aA=al;break L56966}else{aC=aB;aD=al}}else{aC=aq;aD=am}if(ay>>>0>65535){af=aD;ak=ay;ax=aC}else{aE=aD;aF=ay;aG=aC;aH=ax;break}}}else{aE=_;aF=ah;aG=Y;aH=W}F=+(aG|0);c[X>>2]=(~~(G*F)<<16>>16)+(c[X>>2]|0);c[V>>2]=(c[V>>2]|0)+(~~(E*F)<<16>>16);ak=k+(U<<1)|0;b[ak>>1]=(b[ak>>1]|0)+~~(D*F)&65535;ak=I+1|0;if((ak|0)<(g|0)){_=aE;Z=aF;Y=aG;W=aH;U=U+1&16383;V=V+4|0;I=ak;X=X+4|0}else{Q=aH;R=aG;S=aF;T=aE;break L56949}}if((a[9678027]|0)<0){Q=ax;R=az;S=ay;T=aA;break}a[9678024]=d[9678024]&(t^255)&255;Q=ax;R=az;S=ay;T=aA}else if((w|0)==8){X=H<<1;I=O<<1;if((I&65536|0)==0){aI=I;aJ=X}else{aI=I&65534;aJ=X|1}L56982:do{if(q){X=v+9677981|0;I=9677468+(u|8)|0;V=9677468+(u|9)|0;U=9677468+(u|10)|0;W=(ag(r,L)|0)>>>15;Y=aJ;Z=aI;_=N;aa=M;ac=z;ab=n;ad=0;$=l;L56984:while(1){ak=Z+K|0;if(ak>>>0>65535){af=Y;ae=ak;aK=_;while(1){aL=ae+x|0;am=af+W|0;aq=a[m+(am>>1)|0]|0;al=aq&255;if(aq<<24>>24==-120){if((a[X]&1)==0){aM=al;aN=am;break L56984}aq=(d[V]<<8|d[I]|d[U]<<16)&o;aB=aq<<1;ap=a[m+aq|0]|0;aq=ap&255;if(ap<<24>>24==-120){aM=aq;aN=aB;break L56984}else{aO=aq;aP=aB}}else{aO=al;aP=am}am=(b[619464+(((aP&1|0)==0?aO&15:aO>>>4)<<1)>>1]|0)+aK|0;if((am|0)<-32768){aQ=-32768}else{aQ=(am|0)>32767?32767:am}if(aL>>>0>65535){af=aP;ae=aL;aK=aQ}else{aR=aP;aS=aL;aT=aQ;aU=aK;break}}}else{aR=Y;aS=ak;aT=_;aU=aa}F=+(aT|0);c[$>>2]=(~~(G*F)<<16>>16)+(c[$>>2]|0);c[ab>>2]=(c[ab>>2]|0)+(~~(E*F)<<16>>16);ae=k+(ac<<1)|0;b[ae>>1]=(b[ae>>1]|0)+~~(D*F)&65535;ae=ad+1|0;if((ae|0)<(g|0)){Y=aR;Z=aS;_=aT;aa=aU;ac=ac+1&16383;ab=ab+4|0;ad=ae;$=$+4|0}else{aV=aU;aW=aT;aX=aS;aY=aR;break L56982}}if((a[9678027]|0)<0){aV=aK;aW=aM;aX=aL;aY=aN;break}a[9678024]=d[9678024]&(t^255)&255;aV=aK;aW=aM;aX=aL;aY=aN}else{aV=M;aW=N;aX=aI;aY=aJ}}while(0);$=aX>>1;Q=aV;R=aW;S=(aY&1|0)==0?$:$|32768;T=aY>>1}else{Q=M;R=N;S=O;T=H}}while(0);c[J>>2]=T;c[9678092+(s<<4)>>2]=S;c[9678100+(s<<4)>>2]=Q;c[9678096+(s<<4)>>2]=R;if((a[9678027]|0)<0){break}a[y]=T&255;a[B]=T>>>8&255;a[A]=T>>>16&255}}while(0);s=s+1|0;}while((s|0)<8);do{if((c[2419366]&2|0)==0){if(q){aZ=0}else{break}while(1){s=b[k+((aZ+i&16383)<<1)>>1]|0;T=l+(aZ<<2)|0;c[T>>2]=(c[T>>2]|0)+s;T=n+(aZ<<2)|0;c[T>>2]=(c[T>>2]|0)+s;s=aZ+1|0;if((s|0)<(g|0)){aZ=s}else{a_=44263;break}}}else{a_=44263}}while(0);L57008:do{if((a_|0)==44263){if(q){a$=f;a0=0}else{break}while(1){aZ=c[2419520]|0;if((aZ&1|0)==0){a1=0}else{a1=~~(+(c[l+(a0<<2)>>2]|0)*+h[1209758])}if((aZ&2|0)==0){a2=0}else{a2=~~(+(c[l+(a0<<2)>>2]|0)*+h[1209758])}aZ=c[2419521]|0;if((aZ&1|0)==0){a3=a1}else{a3=~~(+(c[n+(a0<<2)>>2]|0)*+h[1209759])+a1|0}if((aZ&2|0)==0){a4=a2}else{a4=~~(+(c[n+(a0<<2)>>2]|0)*+h[1209759])+a2|0}if((a3|0)<-32768){a5=-32768}else{a5=(a3|0)>32767?32767:a3}if((a4|0)<-32768){a6=-32768}else{a6=(a4|0)>32767?32767:a4}b[a$>>1]=(e[a$>>1]|0)+a5&65535;aZ=a$+2|0;b[aZ>>1]=(e[aZ>>1]|0)+a6&65535;aZ=a0+1|0;if((aZ|0)>=(g|0)){break L57008}a$=a$+4|0;a0=aZ}}}while(0);if((p|0)>16384){p=16384-i|0;gGz(k+(i<<1)|0,0,p<<1|0);gGz(j|0,0,g-p<<1|0);return}else{gGz(k+(i<<1)|0,0,g<<1|0);return}}function TL(f,g){f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0,cf=0,cg=0,ch=0,ci=0,cj=0;if((g|0)==0){return}h=g;g=f;f=c[2420430]|0;while(1){i=(h|0)>1e4?1e4:h;j=c[f+2992>>2]|0;k=j+(i<<2)|0;do{if((i|0)==0){l=g;m=f}else{n=i<<2;gGz(j|0,0,n|0);gGz(k|0,0,n|0);n=(i|0)>0;o=0;p=f;while(1){q=p+48+(o*92|0)|0;r=c[q>>2]|0;s=c[p+4+(r>>>14<<2)>>2]|0;t=p+48+(o*92|0)+8|0;u=c[t>>2]|0;v=p+48+(o*92|0)+16|0;w=c[v>>2]|0;if((u|0)==(w|0)){x=r|1;c[q>>2]=x;y=x}else{y=r}L57050:do{if((s|0)==0){r=c[p+48+(o*92|0)+4>>2]|0;x=p+48+(o*92|0)+24|0;z=c[p+48+(o*92|0)+88>>2]|0;A=z&c[x>>2];L57392:do{if(n){B=p+48+(o*92|0)+36|0;C=p+48+(o*92|0)+20|0;D=p+48+(o*92|0)+32|0;E=p+48+(o*92|0)+52|0;F=p+48+(o*92|0)+44|0;G=p+48+(o*92|0)+85|0;H=p+48+(o*92|0)+40|0;I=p+48+(o*92|0)+48|0;J=p+48+(o*92|0)+28|0;K=p+48+(o*92|0)+12|0;L=u-w|0;M=w<<1;N=w-u|0;O=u<<1;P=A;Q=i;R=y;L57394:while(1){if((R&3|0)==0){S=Q;T=P;U=R}else{V=Q;W=P;break}L57396:while(1){X=S-1|0;Y=(S|0)==0;if((U&64|0)==0){if(Y){Z=X;_=T;$=U;break}aa=T;ab=X;ac=U;ad=c[B>>2]|0;L57453:while(1){ae=aa+r&z;if((ad|0)==0){af=0}else{ah=ad-1|0;c[B>>2]=ah;ai=c[C>>2]|0;do{if((ai|0)!=0){aj=(c[K>>2]|0)+(ai<<24>>24)|0;c[K>>2]=aj;if((aj|0)<0){c[K>>2]=0;break}if(aj>>>0<=65535){break}c[K>>2]=65535}}while(0);ai=c[D>>2]|0;do{if((ai|0)!=0){aj=(c[J>>2]|0)+(ai<<24>>24)|0;c[J>>2]=aj;if((aj|0)<0){c[J>>2]=0;break}if(aj>>>0<=65535){break}c[J>>2]=65535}}while(0);ai=c[E>>2]|0;do{if((ai|0)!=0){if((ai|0)<=-1){if((a[G]&7)!=0){break}}aj=(c[I>>2]|0)+(ai<<24>>24)|0;c[I>>2]=aj;if((aj|0)<0){c[I>>2]=0;break}if(aj>>>0<=65535){break}c[I>>2]=65535}}while(0);ai=c[F>>2]|0;do{if((ai|0)!=0){if((ai|0)<=-1){if((a[G]&7)!=0){break}}aj=(c[H>>2]|0)+(ai<<24>>24)|0;c[H>>2]=aj;if((aj|0)<0){c[H>>2]=0;break}if(aj>>>0<=65535){break}c[H>>2]=65535}}while(0);a[G]=(a[G]|0)+1&255;af=ah}do{if(ae>>>0>w>>>0){if((ac&4|0)!=0){ak=ae;al=ac;break}if((ac&32|0)==0){am=ac}else{ai=ac|128;c[q>>2]=ai;am=ai}ai=am&24;if((ai|0)==0){an=44335;break L57394}else if((ai|0)==8){ak=ae+L&z;al=am;break}else if((ai|0)==16){aj=am&-29|4;c[q>>2]=aj;ak=ae+L&z;al=aj;break}else if((ai|0)==24){break L57453}else{ak=ae;al=am;break}}else{ak=ae;al=ac}}while(0);ah=ab-1|0;if((ab|0)==0){Z=ah;_=ak;$=al;break L57396}else{aa=ak;ab=ah;ac=al;ad=af}}ao=ab;ap=M-ae|0;aq=am}else{if(Y){Z=X;_=T;$=U;break}ad=T;ar=X;ac=U;aa=c[B>>2]|0;L57401:while(1){as=ad-r&z;if((aa|0)==0){at=0}else{ah=aa-1|0;c[B>>2]=ah;ai=c[C>>2]|0;do{if((ai|0)!=0){aj=(c[K>>2]|0)+(ai<<24>>24)|0;c[K>>2]=aj;if((aj|0)<0){c[K>>2]=0;break}if(aj>>>0<=65535){break}c[K>>2]=65535}}while(0);ai=c[D>>2]|0;do{if((ai|0)!=0){aj=(c[J>>2]|0)+(ai<<24>>24)|0;c[J>>2]=aj;if((aj|0)<0){c[J>>2]=0;break}if(aj>>>0<=65535){break}c[J>>2]=65535}}while(0);ai=c[E>>2]|0;do{if((ai|0)!=0){if((ai|0)<=-1){if((a[G]&7)!=0){break}}aj=(c[I>>2]|0)+(ai<<24>>24)|0;c[I>>2]=aj;if((aj|0)<0){c[I>>2]=0;break}if(aj>>>0<=65535){break}c[I>>2]=65535}}while(0);ai=c[F>>2]|0;do{if((ai|0)!=0){if((ai|0)<=-1){if((a[G]&7)!=0){break}}aj=(c[H>>2]|0)+(ai<<24>>24)|0;c[H>>2]=aj;if((aj|0)<0){c[H>>2]=0;break}if(aj>>>0<=65535){break}c[H>>2]=65535}}while(0);a[G]=(a[G]|0)+1&255;at=ah}do{if(as>>>0<u>>>0){if((ac&4|0)!=0){au=as;av=ac;break}if((ac&32|0)==0){aw=ac}else{ai=ac|128;c[q>>2]=ai;aw=ai}ai=aw&24;if((ai|0)==24){break L57401}else if((ai|0)==0){an=44372;break L57394}else if((ai|0)==8){au=as+N&z;av=aw;break}else if((ai|0)==16){ai=aw&-29|4;c[q>>2]=ai;au=as+N&z;av=ai;break}else{au=as;av=aw;break}}else{au=as;av=ac}}while(0);ah=ar-1|0;if((ar|0)==0){Z=ah;_=au;$=av;break L57396}else{ad=au;ar=ah;ac=av;aa=at}}ao=ar;ap=O-as|0;aq=aw}aa=aq^64;c[q>>2]=aa;S=ao;T=ap&z;U=aa}if((Z|0)>0){P=_;Q=Z;R=$}else{ax=_;break L57392}}if((an|0)==44335){an=0;c[q>>2]=am|1;V=ab;W=ae}else if((an|0)==44372){an=0;c[q>>2]=aw|1;V=ar;W=as}c[x>>2]=W;if((V|0)<=0){break L57050}R=c[B>>2]|0;Q=(V|0)>1&(V|0)>(R|0)?R:V;c[B>>2]=R-Q;R=c[C>>2]|0;do{if((R|0)!=0){P=ag(R<<24>>24,Q)|0;O=(c[K>>2]|0)+P|0;c[K>>2]=O;if((O|0)<0){c[K>>2]=0;break}if(O>>>0<=65535){break}c[K>>2]=65535}}while(0);K=c[D>>2]|0;do{if((K|0)!=0){R=ag(K<<24>>24,Q)|0;C=(c[J>>2]|0)+R|0;c[J>>2]=C;if((C|0)<0){c[J>>2]=0;break}if(C>>>0<=65535){break}c[J>>2]=65535}}while(0);J=c[E>>2]|0;do{if((J|0)!=0){if((J|0)<=-1){if((a[G]&7)!=0){break}}K=ag(J<<24>>24,Q)|0;D=(c[I>>2]|0)+K|0;c[I>>2]=D;if((D|0)<0){c[I>>2]=0;break}if(D>>>0<=65535){break}c[I>>2]=65535}}while(0);I=c[F>>2]|0;do{if((I|0)!=0){if((I|0)<=-1){if((a[G]&7)!=0){break}}J=ag(I<<24>>24,Q)|0;E=(c[H>>2]|0)+J|0;c[H>>2]=E;if((E|0)<0){c[H>>2]=0;break}if(E>>>0<=65535){break}c[H>>2]=65535}}while(0);a[G]=(d[G]|0)+Q&255;break L57050}else{ax=A}}while(0);c[x>>2]=ax}else{A=c[p+48+(o*92|0)+4>>2]|0;z=p+48+(o*92|0)+24|0;r=p+48+(o*92|0)+88|0;H=c[r>>2]&c[z>>2];I=p+48+(o*92|0)+12|0;F=p+3e3|0;E=c[F>>2]|0;J=p+48+(o*92|0)+28|0;D=c[p+48+(o*92|0)+80>>2]|0;if((y&8192|0)==0){L57223:do{if(n){K=p+48+(o*92|0)+48|0;C=p+48+(o*92|0)+76|0;R=p+48+(o*92|0)+68|0;B=p+48+(o*92|0)+72|0;O=p+48+(o*92|0)+36|0;P=p+48+(o*92|0)+20|0;N=p+48+(o*92|0)+32|0;M=p+48+(o*92|0)+52|0;L=p+48+(o*92|0)+44|0;aa=p+48+(o*92|0)+85|0;ac=p+48+(o*92|0)+40|0;ad=p+48+(o*92|0)+60|0;X=p+48+(o*92|0)+64|0;Y=p+48+(o*92|0)+56|0;if((y&3|0)==0){ah=j;ai=k;aj=i;ay=H;az=e[E+((c[J>>2]|0)>>>4<<1)>>1]|0;aA=e[E+((c[I>>2]|0)>>>4<<1)>>1]|0;aB=y;L57228:while(1){aC=aj-1|0;aD=(aj|0)==0;L57230:do{if((aB&64|0)==0){if(aD){aE=ah;aF=ai;aG=aC;aH=ay;aI=az;aJ=aA;break}else{aK=aA;aL=az;aM=ay;aN=ai;aO=ah;aP=aC;aQ=aB}L57232:while(1){aR=c[r>>2]|0;aS=b[s+(((aR&aM+2048)>>>11)+D<<1)>>1]|0;aT=aM&2047;aU=ag(b[s+((aM>>>11)+D<<1)>>1]|0,2048-aT|0)|0;aV=(ag(aS,aT)|0)+aU>>11;aW=aR&aM+A;aR=c[K>>2]|0;aU=aR>>>2;aT=c[C>>2]|0;aS=((ag(aV-aT|0,aU)|0)/16384|0)+aT|0;c[C>>2]=aS;aT=c[R>>2]|0;aV=(ag(aS-aT|0,aU)|0)/16384|0;aS=aV+aT|0;c[B>>2]=aT;c[R>>2]=aS;aT=aQ&768;if((aT|0)==0){aX=(c[ac>>2]|0)>>>2;aY=c[ad>>2]|0;aZ=((ag(aX,aY)|0)/32768|0)+aV+((aY|0)/2|0)|0;c[X>>2]=aY;c[ad>>2]=aZ;aV=c[Y>>2]|0;a_=aZ-aY+((ag(aV,aX)|0)/32768|0)+((aV|0)/2|0)|0;c[Y>>2]=a_;a$=a_}else if((aT|0)==256){a_=c[ad>>2]|0;aV=(ag(aS-a_|0,aU)|0)/16384|0;c[X>>2]=a_;c[ad>>2]=aV+a_;a_=c[Y>>2]|0;aX=((ag((c[ac>>2]|0)>>>2,a_)|0)/32768|0)+aV+((a_|0)/2|0)|0;c[Y>>2]=aX;a$=aX}else if((aT|0)==512){aX=(c[ac>>2]|0)>>>2;a_=c[ad>>2]|0;aV=((ag(aS-a_|0,aX)|0)/16384|0)+a_|0;c[X>>2]=a_;c[ad>>2]=aV;a_=c[Y>>2]|0;aY=((ag(aV-a_|0,aX)|0)/16384|0)+a_|0;c[Y>>2]=aY;a$=aY}else if((aT|0)==768){aT=c[ad>>2]|0;aY=((ag(aS-aT|0,aU)|0)/16384|0)+aT|0;c[X>>2]=aT;c[ad>>2]=aY;aT=c[Y>>2]|0;aU=((ag(aY-aT|0,(c[ac>>2]|0)>>>2)|0)/16384|0)+aT|0;c[Y>>2]=aU;a$=aU}else{a$=aS}aS=c[O>>2]|0;if((aS|0)==0){a0=aL;a1=aK}else{c[O>>2]=aS-1;aS=c[P>>2]|0;do{if((aS|0)!=0){aU=(c[I>>2]|0)+(aS<<24>>24)|0;c[I>>2]=aU;if((aU|0)<0){c[I>>2]=0;break}if(aU>>>0<=65535){break}c[I>>2]=65535}}while(0);aS=c[N>>2]|0;do{if((aS|0)!=0){aU=(c[J>>2]|0)+(aS<<24>>24)|0;c[J>>2]=aU;if((aU|0)<0){c[J>>2]=0;break}if(aU>>>0<=65535){break}c[J>>2]=65535}}while(0);aS=c[M>>2]|0;do{if((aS|0)!=0){if((aS|0)<=-1){if((a[aa]&7)!=0){break}}aU=(aS<<24>>24)+aR|0;c[K>>2]=aU;if((aU|0)<0){c[K>>2]=0;break}if(aU>>>0<=65535){break}c[K>>2]=65535}}while(0);aR=c[L>>2]|0;do{if((aR|0)!=0){if((aR|0)<=-1){if((a[aa]&7)!=0){break}}aS=(c[ac>>2]|0)+(aR<<24>>24)|0;c[ac>>2]=aS;if((aS|0)<0){c[ac>>2]=0;break}if(aS>>>0<=65535){break}c[ac>>2]=65535}}while(0);a[aa]=(a[aa]|0)+1&255;aR=c[F>>2]|0;a0=e[aR+((c[J>>2]|0)>>>4<<1)>>1]|0;a1=e[aR+((c[I>>2]|0)>>>4<<1)>>1]|0}aR=(ag(a1,a$)|0)>>11;a2=aO+4|0;c[aO>>2]=(c[aO>>2]|0)+aR;aR=(ag(a0,a$)|0)>>11;a3=aN+4|0;c[aN>>2]=(c[aN>>2]|0)+aR;a4=c[v>>2]|0;do{if(aW>>>0>a4>>>0){aR=c[q>>2]|0;if((aR&4|0)!=0){a5=aW;break}if((aR&32|0)==0){a6=aR}else{aS=aR|128;c[q>>2]=aS;a6=aS}aS=a6&24;if((aS|0)==0){an=44572;break L57228}else if((aS|0)==8){a5=aW-a4+(c[t>>2]|0)&c[r>>2];break}else if((aS|0)==16){aR=aW-a4+(c[t>>2]|0)&c[r>>2];c[q>>2]=a6&-29|4;a5=aR;break}else if((aS|0)==24){break L57232}else{a5=aW;break}}else{a5=aW}}while(0);aS=aP-1|0;if((aP|0)==0){aE=a2;aF=a3;aG=aS;aH=a5;aI=a0;aJ=a1;break L57230}aK=a1;aL=a0;aM=a5;aN=a3;aO=a2;aP=aS;aQ=c[q>>2]|0}a7=a2;a8=a3;a9=aP;ba=c[r>>2]&(a4<<1)-aW;bb=a0;bc=a1;bd=a6;an=44576}else{if(aD){aE=ah;aF=ai;aG=aC;aH=ay;aI=az;aJ=aA;break}else{be=aA;bf=az;bg=ay;bh=ai;bi=ah;bj=aC;bk=aB}L57290:while(1){aS=c[r>>2]|0;aR=b[s+(((aS&bg+2048)>>>11)+D<<1)>>1]|0;aU=bg&2047;aT=ag(b[s+((bg>>>11)+D<<1)>>1]|0,2048-aU|0)|0;aY=(ag(aR,aU)|0)+aT>>11;bl=aS&bg-A;aS=c[K>>2]|0;aT=aS>>>2;aU=c[C>>2]|0;aR=((ag(aY-aU|0,aT)|0)/16384|0)+aU|0;c[C>>2]=aR;aU=c[R>>2]|0;aY=(ag(aR-aU|0,aT)|0)/16384|0;aR=aY+aU|0;c[B>>2]=aU;c[R>>2]=aR;aU=bk&768;if((aU|0)==0){a_=(c[ac>>2]|0)>>>2;aX=c[ad>>2]|0;aV=((ag(a_,aX)|0)/32768|0)+aY+((aX|0)/2|0)|0;c[X>>2]=aX;c[ad>>2]=aV;aY=c[Y>>2]|0;aZ=aV-aX+((ag(aY,a_)|0)/32768|0)+((aY|0)/2|0)|0;c[Y>>2]=aZ;bm=aZ}else if((aU|0)==256){aZ=c[ad>>2]|0;aY=(ag(aR-aZ|0,aT)|0)/16384|0;c[X>>2]=aZ;c[ad>>2]=aY+aZ;aZ=c[Y>>2]|0;a_=((ag((c[ac>>2]|0)>>>2,aZ)|0)/32768|0)+aY+((aZ|0)/2|0)|0;c[Y>>2]=a_;bm=a_}else if((aU|0)==512){a_=(c[ac>>2]|0)>>>2;aZ=c[ad>>2]|0;aY=((ag(aR-aZ|0,a_)|0)/16384|0)+aZ|0;c[X>>2]=aZ;c[ad>>2]=aY;aZ=c[Y>>2]|0;aX=((ag(aY-aZ|0,a_)|0)/16384|0)+aZ|0;c[Y>>2]=aX;bm=aX}else if((aU|0)==768){aU=c[ad>>2]|0;aX=((ag(aR-aU|0,aT)|0)/16384|0)+aU|0;c[X>>2]=aU;c[ad>>2]=aX;aU=c[Y>>2]|0;aT=((ag(aX-aU|0,(c[ac>>2]|0)>>>2)|0)/16384|0)+aU|0;c[Y>>2]=aT;bm=aT}else{bm=aR}aR=c[O>>2]|0;if((aR|0)==0){bn=bf;bo=be}else{c[O>>2]=aR-1;aR=c[P>>2]|0;do{if((aR|0)!=0){aT=(c[I>>2]|0)+(aR<<24>>24)|0;c[I>>2]=aT;if((aT|0)<0){c[I>>2]=0;break}if(aT>>>0<=65535){break}c[I>>2]=65535}}while(0);aR=c[N>>2]|0;do{if((aR|0)!=0){aT=(c[J>>2]|0)+(aR<<24>>24)|0;c[J>>2]=aT;if((aT|0)<0){c[J>>2]=0;break}if(aT>>>0<=65535){break}c[J>>2]=65535}}while(0);aR=c[M>>2]|0;do{if((aR|0)!=0){if((aR|0)<=-1){if((a[aa]&7)!=0){break}}aT=(aR<<24>>24)+aS|0;c[K>>2]=aT;if((aT|0)<0){c[K>>2]=0;break}if(aT>>>0<=65535){break}c[K>>2]=65535}}while(0);aS=c[L>>2]|0;do{if((aS|0)!=0){if((aS|0)<=-1){if((a[aa]&7)!=0){break}}aR=(c[ac>>2]|0)+(aS<<24>>24)|0;c[ac>>2]=aR;if((aR|0)<0){c[ac>>2]=0;break}if(aR>>>0<=65535){break}c[ac>>2]=65535}}while(0);a[aa]=(a[aa]|0)+1&255;aS=c[F>>2]|0;bn=e[aS+((c[J>>2]|0)>>>4<<1)>>1]|0;bo=e[aS+((c[I>>2]|0)>>>4<<1)>>1]|0}aS=(ag(bo,bm)|0)>>11;bp=bi+4|0;c[bi>>2]=(c[bi>>2]|0)+aS;aS=(ag(bn,bm)|0)>>11;bq=bh+4|0;c[bh>>2]=(c[bh>>2]|0)+aS;br=c[t>>2]|0;do{if(bl>>>0<br>>>0){aS=c[q>>2]|0;if((aS&4|0)!=0){bs=bl;break}if((aS&32|0)==0){bt=aS}else{aR=aS|128;c[q>>2]=aR;bt=aR}aR=bt&24;if((aR|0)==0){an=44615;break L57228}else if((aR|0)==8){bs=bl-br+(c[v>>2]|0)&c[r>>2];break}else if((aR|0)==16){aS=bl-br+(c[v>>2]|0)&c[r>>2];c[q>>2]=bt&-29|4;bs=aS;break}else if((aR|0)==24){break L57290}else{bs=bl;break}}else{bs=bl}}while(0);aR=bj-1|0;if((bj|0)==0){aE=bp;aF=bq;aG=aR;aH=bs;aI=bn;aJ=bo;break L57230}be=bo;bf=bn;bg=bs;bh=bq;bi=bp;bj=aR;bk=c[q>>2]|0}a7=bp;a8=bq;a9=bj;ba=c[r>>2]&(br<<1)-bl;bb=bn;bc=bo;bd=bt;an=44576}}while(0);if((an|0)==44576){an=0;aC=bd^64;c[q>>2]=aC;ah=a7;ai=a8;aj=a9;ay=ba;az=bb;aA=bc;aB=aC;continue}if((aG|0)<=0){bu=aH;break L57223}aC=c[q>>2]|0;if((aC&3|0)==0){ah=aE;ai=aF;aj=aG;ay=aH;az=aI;aA=aJ;aB=aC}else{bv=aG;bw=aH;break}}if((an|0)==44572){an=0;c[q>>2]=a6|1;bv=aP;bw=aW}else if((an|0)==44615){an=0;c[q>>2]=bt|1;bv=bj;bw=bl}c[z>>2]=bw;if((bv|0)>0){bx=bv}else{break L57050}}else{c[z>>2]=H;bx=i}aB=c[O>>2]|0;aA=(bx|0)>1&(bx|0)>(aB|0)?aB:bx;c[O>>2]=aB-aA;aB=c[P>>2]|0;do{if((aB|0)!=0){az=ag(aB<<24>>24,aA)|0;ay=(c[I>>2]|0)+az|0;c[I>>2]=ay;if((ay|0)<0){c[I>>2]=0;break}if(ay>>>0<=65535){break}c[I>>2]=65535}}while(0);aB=c[N>>2]|0;do{if((aB|0)!=0){P=ag(aB<<24>>24,aA)|0;O=(c[J>>2]|0)+P|0;c[J>>2]=O;if((O|0)<0){c[J>>2]=0;break}if(O>>>0<=65535){break}c[J>>2]=65535}}while(0);aB=c[M>>2]|0;do{if((aB|0)!=0){if((aB|0)<=-1){if((a[aa]&7)!=0){break}}N=ag(aB<<24>>24,aA)|0;O=(c[K>>2]|0)+N|0;c[K>>2]=O;if((O|0)<0){c[K>>2]=0;break}if(O>>>0<=65535){break}c[K>>2]=65535}}while(0);K=c[L>>2]|0;do{if((K|0)!=0){if((K|0)<=-1){if((a[aa]&7)!=0){break}}aB=ag(K<<24>>24,aA)|0;M=(c[ac>>2]|0)+aB|0;c[ac>>2]=M;if((M|0)<0){c[ac>>2]=0;break}if(M>>>0<=65535){break}c[ac>>2]=65535}}while(0);a[aa]=(d[aa]|0)+aA&255;break L57050}else{bu=H}}while(0);c[z>>2]=bu;break}else{L57054:do{if(n){x=p+48+(o*92|0)+48|0;ac=p+48+(o*92|0)+76|0;K=p+48+(o*92|0)+68|0;L=p+48+(o*92|0)+72|0;M=p+48+(o*92|0)+36|0;aB=p+48+(o*92|0)+20|0;O=p+48+(o*92|0)+32|0;N=p+48+(o*92|0)+52|0;P=p+48+(o*92|0)+44|0;ay=p+48+(o*92|0)+85|0;az=p+48+(o*92|0)+40|0;aj=p+48+(o*92|0)+60|0;ai=p+48+(o*92|0)+64|0;ah=p+48+(o*92|0)+56|0;if((y&3|0)==0){Y=p+2996|0;ad=j;X=k;R=i;B=H;C=e[E+((c[J>>2]|0)>>>4<<1)>>1]|0;Q=e[E+((c[I>>2]|0)>>>4<<1)>>1]|0;G=y;L57059:while(1){aC=R-1|0;aD=(R|0)==0;L57061:do{if((G&64|0)==0){if(aD){by=ad;bz=X;bA=aC;bB=B;bC=C;bD=Q;break}else{bE=Q;bF=C;bG=B;bH=X;bI=ad;bJ=aC;bK=G}L57063:while(1){aR=c[r>>2]|0;aS=c[Y>>2]|0;aT=b[aS+((e[s+(((aR&bG+2048)>>>11)+D<<1)>>1]|0)>>>8<<1)>>1]|0;aU=bG&2047;aX=ag(b[aS+((e[s+((bG>>>11)+D<<1)>>1]|0)>>>8<<1)>>1]|0,2048-aU|0)|0;aS=(ag(aT,aU)|0)+aX>>11;bL=aR&bG+A;aR=c[x>>2]|0;aX=aR>>>2;aU=c[ac>>2]|0;aT=((ag(aS-aU|0,aX)|0)/16384|0)+aU|0;c[ac>>2]=aT;aU=c[K>>2]|0;aS=(ag(aT-aU|0,aX)|0)/16384|0;aT=aS+aU|0;c[L>>2]=aU;c[K>>2]=aT;aU=bK&768;if((aU|0)==0){aZ=(c[az>>2]|0)>>>2;a_=c[aj>>2]|0;aY=((ag(aZ,a_)|0)/32768|0)+aS+((a_|0)/2|0)|0;c[ai>>2]=a_;c[aj>>2]=aY;aS=c[ah>>2]|0;aV=aY-a_+((ag(aS,aZ)|0)/32768|0)+((aS|0)/2|0)|0;c[ah>>2]=aV;bM=aV}else if((aU|0)==256){aV=c[aj>>2]|0;aS=(ag(aT-aV|0,aX)|0)/16384|0;c[ai>>2]=aV;c[aj>>2]=aS+aV;aV=c[ah>>2]|0;aZ=((ag((c[az>>2]|0)>>>2,aV)|0)/32768|0)+aS+((aV|0)/2|0)|0;c[ah>>2]=aZ;bM=aZ}else if((aU|0)==512){aZ=(c[az>>2]|0)>>>2;aV=c[aj>>2]|0;aS=((ag(aT-aV|0,aZ)|0)/16384|0)+aV|0;c[ai>>2]=aV;c[aj>>2]=aS;aV=c[ah>>2]|0;a_=((ag(aS-aV|0,aZ)|0)/16384|0)+aV|0;c[ah>>2]=a_;bM=a_}else if((aU|0)==768){aU=c[aj>>2]|0;a_=((ag(aT-aU|0,aX)|0)/16384|0)+aU|0;c[ai>>2]=aU;c[aj>>2]=a_;aU=c[ah>>2]|0;aX=((ag(a_-aU|0,(c[az>>2]|0)>>>2)|0)/16384|0)+aU|0;c[ah>>2]=aX;bM=aX}else{bM=aT}aT=c[M>>2]|0;if((aT|0)==0){bN=bF;bO=bE}else{c[M>>2]=aT-1;aT=c[aB>>2]|0;do{if((aT|0)!=0){aX=(c[I>>2]|0)+(aT<<24>>24)|0;c[I>>2]=aX;if((aX|0)<0){c[I>>2]=0;break}if(aX>>>0<=65535){break}c[I>>2]=65535}}while(0);aT=c[O>>2]|0;do{if((aT|0)!=0){aX=(c[J>>2]|0)+(aT<<24>>24)|0;c[J>>2]=aX;if((aX|0)<0){c[J>>2]=0;break}if(aX>>>0<=65535){break}c[J>>2]=65535}}while(0);aT=c[N>>2]|0;do{if((aT|0)!=0){if((aT|0)<=-1){if((a[ay]&7)!=0){break}}aX=(aT<<24>>24)+aR|0;c[x>>2]=aX;if((aX|0)<0){c[x>>2]=0;break}if(aX>>>0<=65535){break}c[x>>2]=65535}}while(0);aR=c[P>>2]|0;do{if((aR|0)!=0){if((aR|0)<=-1){if((a[ay]&7)!=0){break}}aT=(c[az>>2]|0)+(aR<<24>>24)|0;c[az>>2]=aT;if((aT|0)<0){c[az>>2]=0;break}if(aT>>>0<=65535){break}c[az>>2]=65535}}while(0);a[ay]=(a[ay]|0)+1&255;aR=c[F>>2]|0;bN=e[aR+((c[J>>2]|0)>>>4<<1)>>1]|0;bO=e[aR+((c[I>>2]|0)>>>4<<1)>>1]|0}aR=(ag(bO,bM)|0)>>11;bP=bI+4|0;c[bI>>2]=(c[bI>>2]|0)+aR;aR=(ag(bN,bM)|0)>>11;bQ=bH+4|0;c[bH>>2]=(c[bH>>2]|0)+aR;bR=c[v>>2]|0;do{if(bL>>>0>bR>>>0){aR=c[q>>2]|0;if((aR&4|0)!=0){bS=bL;break}if((aR&32|0)==0){bT=aR}else{aT=aR|128;c[q>>2]=aT;bT=aT}aT=bT&24;if((aT|0)==0){an=44451;break L57059}else if((aT|0)==8){bS=bL-bR+(c[t>>2]|0)&c[r>>2];break}else if((aT|0)==16){aR=bL-bR+(c[t>>2]|0)&c[r>>2];c[q>>2]=bT&-29|4;bS=aR;break}else if((aT|0)==24){break L57063}else{bS=bL;break}}else{bS=bL}}while(0);aT=bJ-1|0;if((bJ|0)==0){by=bP;bz=bQ;bA=aT;bB=bS;bC=bN;bD=bO;break L57061}bE=bO;bF=bN;bG=bS;bH=bQ;bI=bP;bJ=aT;bK=c[q>>2]|0}bU=bP;bV=bQ;bW=bJ;bX=c[r>>2]&(bR<<1)-bL;bY=bN;bZ=bO;b_=bT;an=44455}else{if(aD){by=ad;bz=X;bA=aC;bB=B;bC=C;bD=Q;break}else{b$=Q;b0=C;b1=B;b2=X;b3=ad;b4=aC;b5=G}L57121:while(1){aT=c[r>>2]|0;aR=c[Y>>2]|0;aX=b[aR+((e[s+(((aT&b1+2048)>>>11)+D<<1)>>1]|0)>>>8<<1)>>1]|0;aU=b1&2047;a_=ag(b[aR+((e[s+((b1>>>11)+D<<1)>>1]|0)>>>8<<1)>>1]|0,2048-aU|0)|0;aR=(ag(aX,aU)|0)+a_>>11;b6=aT&b1-A;aT=c[x>>2]|0;a_=aT>>>2;aU=c[ac>>2]|0;aX=((ag(aR-aU|0,a_)|0)/16384|0)+aU|0;c[ac>>2]=aX;aU=c[K>>2]|0;aR=(ag(aX-aU|0,a_)|0)/16384|0;aX=aR+aU|0;c[L>>2]=aU;c[K>>2]=aX;aU=b5&768;if((aU|0)==256){aV=c[aj>>2]|0;aZ=(ag(aX-aV|0,a_)|0)/16384|0;c[ai>>2]=aV;c[aj>>2]=aZ+aV;aV=c[ah>>2]|0;aS=((ag((c[az>>2]|0)>>>2,aV)|0)/32768|0)+aZ+((aV|0)/2|0)|0;c[ah>>2]=aS;b7=aS}else if((aU|0)==512){aS=(c[az>>2]|0)>>>2;aV=c[aj>>2]|0;aZ=((ag(aX-aV|0,aS)|0)/16384|0)+aV|0;c[ai>>2]=aV;c[aj>>2]=aZ;aV=c[ah>>2]|0;aY=((ag(aZ-aV|0,aS)|0)/16384|0)+aV|0;c[ah>>2]=aY;b7=aY}else if((aU|0)==768){aY=c[aj>>2]|0;aV=((ag(aX-aY|0,a_)|0)/16384|0)+aY|0;c[ai>>2]=aY;c[aj>>2]=aV;aY=c[ah>>2]|0;a_=((ag(aV-aY|0,(c[az>>2]|0)>>>2)|0)/16384|0)+aY|0;c[ah>>2]=a_;b7=a_}else if((aU|0)==0){aU=(c[az>>2]|0)>>>2;a_=c[aj>>2]|0;aY=((ag(aU,a_)|0)/32768|0)+aR+((a_|0)/2|0)|0;c[ai>>2]=a_;c[aj>>2]=aY;aR=c[ah>>2]|0;aV=aY-a_+((ag(aR,aU)|0)/32768|0)+((aR|0)/2|0)|0;c[ah>>2]=aV;b7=aV}else{b7=aX}aX=c[M>>2]|0;if((aX|0)==0){b8=b0;b9=b$}else{c[M>>2]=aX-1;aX=c[aB>>2]|0;do{if((aX|0)!=0){aV=(c[I>>2]|0)+(aX<<24>>24)|0;c[I>>2]=aV;if((aV|0)<0){c[I>>2]=0;break}if(aV>>>0<=65535){break}c[I>>2]=65535}}while(0);aX=c[O>>2]|0;do{if((aX|0)!=0){aV=(c[J>>2]|0)+(aX<<24>>24)|0;c[J>>2]=aV;if((aV|0)<0){c[J>>2]=0;break}if(aV>>>0<=65535){break}c[J>>2]=65535}}while(0);aX=c[N>>2]|0;do{if((aX|0)!=0){if((aX|0)<=-1){if((a[ay]&7)!=0){break}}aV=(aX<<24>>24)+aT|0;c[x>>2]=aV;if((aV|0)<0){c[x>>2]=0;break}if(aV>>>0<=65535){break}c[x>>2]=65535}}while(0);aT=c[P>>2]|0;do{if((aT|0)!=0){if((aT|0)<=-1){if((a[ay]&7)!=0){break}}aX=(c[az>>2]|0)+(aT<<24>>24)|0;c[az>>2]=aX;if((aX|0)<0){c[az>>2]=0;break}if(aX>>>0<=65535){break}c[az>>2]=65535}}while(0);a[ay]=(a[ay]|0)+1&255;aT=c[F>>2]|0;b8=e[aT+((c[J>>2]|0)>>>4<<1)>>1]|0;b9=e[aT+((c[I>>2]|0)>>>4<<1)>>1]|0}aT=(ag(b9,b7)|0)>>11;ca=b3+4|0;c[b3>>2]=(c[b3>>2]|0)+aT;aT=(ag(b8,b7)|0)>>11;cb=b2+4|0;c[b2>>2]=(c[b2>>2]|0)+aT;cc=c[t>>2]|0;do{if(b6>>>0<cc>>>0){aT=c[q>>2]|0;if((aT&4|0)!=0){cd=b6;break}if((aT&32|0)==0){ce=aT}else{aX=aT|128;c[q>>2]=aX;ce=aX}aX=ce&24;if((aX|0)==0){an=44494;break L57059}else if((aX|0)==8){cd=b6-cc+(c[v>>2]|0)&c[r>>2];break}else if((aX|0)==16){aT=b6-cc+(c[v>>2]|0)&c[r>>2];c[q>>2]=ce&-29|4;cd=aT;break}else if((aX|0)==24){break L57121}else{cd=b6;break}}else{cd=b6}}while(0);aX=b4-1|0;if((b4|0)==0){by=ca;bz=cb;bA=aX;bB=cd;bC=b8;bD=b9;break L57061}b$=b9;b0=b8;b1=cd;b2=cb;b3=ca;b4=aX;b5=c[q>>2]|0}bU=ca;bV=cb;bW=b4;bX=c[r>>2]&(cc<<1)-b6;bY=b8;bZ=b9;b_=ce;an=44455}}while(0);if((an|0)==44455){an=0;aC=b_^64;c[q>>2]=aC;ad=bU;X=bV;R=bW;B=bX;C=bY;Q=bZ;G=aC;continue}if((bA|0)<=0){cf=bB;break L57054}aC=c[q>>2]|0;if((aC&3|0)==0){ad=by;X=bz;R=bA;B=bB;C=bC;Q=bD;G=aC}else{cg=bA;ch=bB;break}}if((an|0)==44494){an=0;c[q>>2]=ce|1;cg=b4;ch=b6}else if((an|0)==44451){an=0;c[q>>2]=bT|1;cg=bJ;ch=bL}c[z>>2]=ch;if((cg|0)>0){ci=cg}else{break L57050}}else{c[z>>2]=H;ci=i}G=c[M>>2]|0;Q=(ci|0)>1&(ci|0)>(G|0)?G:ci;c[M>>2]=G-Q;G=c[aB>>2]|0;do{if((G|0)!=0){C=ag(G<<24>>24,Q)|0;B=(c[I>>2]|0)+C|0;c[I>>2]=B;if((B|0)<0){c[I>>2]=0;break}if(B>>>0<=65535){break}c[I>>2]=65535}}while(0);G=c[O>>2]|0;do{if((G|0)!=0){aB=ag(G<<24>>24,Q)|0;M=(c[J>>2]|0)+aB|0;c[J>>2]=M;if((M|0)<0){c[J>>2]=0;break}if(M>>>0<=65535){break}c[J>>2]=65535}}while(0);G=c[N>>2]|0;do{if((G|0)!=0){if((G|0)<=-1){if((a[ay]&7)!=0){break}}O=ag(G<<24>>24,Q)|0;M=(c[x>>2]|0)+O|0;c[x>>2]=M;if((M|0)<0){c[x>>2]=0;break}if(M>>>0<=65535){break}c[x>>2]=65535}}while(0);x=c[P>>2]|0;do{if((x|0)!=0){if((x|0)<=-1){if((a[ay]&7)!=0){break}}G=ag(x<<24>>24,Q)|0;N=(c[az>>2]|0)+G|0;c[az>>2]=N;if((N|0)<0){c[az>>2]=0;break}if(N>>>0<=65535){break}c[az>>2]=65535}}while(0);a[ay]=(d[ay]|0)+Q&255;break L57050}else{cf=H}}while(0);c[z>>2]=cf;break}}}while(0);do{if((c[q>>2]&128|0)==0){cj=p}else{v=p+46|0;if((a[v]|0)>=0){cj=p;break}a[v]=o&127;c[q>>2]=c[q>>2]&-129;v=c[p+32>>2]|0;if((v|0)==0){cj=p;break}gf[v&2047](1);cj=c[2420430]|0}}while(0);q=o+1|0;if((q|0)>(d[cj+41|0]|0)){break}else{o=q;p=cj}}if(!n){l=g;m=cj;break}p=(h|0)<1e4;o=g;q=0;while(1){b[o>>1]=(c[j+(q<<2)>>2]|0)>>>4&65535;b[o+2>>1]=(c[j+(q+i<<2)>>2]|0)>>>4&65535;v=q+1|0;if((v|0)<(i|0)){o=o+4|0;q=v}else{break}}l=g+((p?(~h*-2|0)-2|0:2e4)<<1)|0;m=cj}}while(0);if((h|0)==(i|0)){break}h=h-i|0;g=l;f=m}return}function TM(f,g){f=f|0;g=g|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0.0,af=0.0,ah=0,ai=0,aj=0,ak=0,al=0,am=0;j=i;i=i+160|0;k=j|0;l=j+16|0;m=j+32|0;n=j+48|0;o=j+64|0;p=j+80|0;q=j+96|0;r=j+112|0;s=j+128|0;t=j+144|0;c[2426862]=9674384;u=c[2418645]|0;v=c[2418647]|0;w=c[2443782]|0;x=0;do{c[q+(x<<2)>>2]=u+((c[9674604+(x*44|0)>>2]<<16)+(c[9674600+(x*44|0)>>2]|0));y=ag(c[v+(c[9674592+(x*44|0)>>2]<<2)>>2]|0,w)|0;z=r+(x<<2)|0;c[z>>2]=y>>>15;A=c[9674608+(x*44|0)>>2]|0;B=c[9674616+(x*44|0)>>2]|0;c[k+(x<<2)>>2]=ag(B,A)|0;c[l+(x<<2)>>2]=ag(8-B|0,A)|0;c[s+(x<<2)>>2]=c[9674596+(x*44|0)>>2];c[t+(x<<2)>>2]=c[9674620+(x*44|0)>>2];c[m+(x<<2)>>2]=c[9674612+(x*44|0)>>2];c[n+(x<<2)>>2]=c[9674624+(x*44|0)>>2];A=c[9674628+(x*44|0)>>2]|0;c[p+(x<<2)>>2]=A;c[o+(x<<2)>>2]=c[9674632+(x*44|0)>>2];if((A|0)!=0){c[z>>2]=y>>>16}x=x+1|0;}while((x|0)<4);if((g|0)>0){C=f;D=1}else{E=t|0;F=c[E>>2]|0;c[2418655]=F;G=m|0;H=c[G>>2]|0;c[2418653]=H;I=o|0;J=c[I>>2]|0;c[2418658]=J;K=t+4|0;L=c[K>>2]|0;c[2418666]=L;M=m+4|0;N=c[M>>2]|0;c[2418664]=N;O=o+4|0;P=c[O>>2]|0;c[2418669]=P;Q=t+8|0;R=c[Q>>2]|0;c[2418677]=R;S=m+8|0;T=c[S>>2]|0;c[2418675]=T;U=o+8|0;V=c[U>>2]|0;c[2418680]=V;W=t+12|0;X=c[W>>2]|0;c[2418688]=X;Y=m+12|0;Z=c[Y>>2]|0;c[2418686]=Z;_=o+12|0;$=c[_>>2]|0;c[2418691]=$;i=j;return}while(1){f=0;x=0;w=0;while(1){v=m+(f<<2)|0;L57572:do{if((c[v>>2]|0)==0){aa=w;ab=x}else{u=t+(f<<2)|0;y=c[u>>2]|0;do{if(y>>>16>>>0<(c[s+(f<<2)>>2]|0)>>>0){ac=y}else{c[o+(f<<2)>>2]=0;if((c[n+(f<<2)>>2]|0)==0){c[v>>2]=0;aa=w;ab=x;break L57572}else{c[u>>2]=0;ac=0;break}}}while(0);L57580:do{if((c[p+(f<<2)>>2]|0)==0){ad=a[(c[q+(f<<2)>>2]|0)+(ac>>>16)|0]|0}else{do{if((ac|0)!=0){if(((ac-(c[r+(f<<2)>>2]|0)^ac)&32768|0)!=0){break}ad=c[o+(f<<2)>>2]&255;break L57580}}while(0);y=d[(c[q+(f<<2)>>2]|0)+(ac>>>16)|0]|0;z=o+(f<<2)|0;A=(((c[z>>2]|0)*62|0)>>6)+(c[619496+((((ac&32768|0)==0?y:y>>>4)&15)<<2)>>2]|0)|0;c[z>>2]=A;if((A|0)>127){c[z>>2]=127;ad=127;break}if((A|0)<-128){c[z>>2]=-128;ad=-128;break}else{ad=A&255;break}}}while(0);c[u>>2]=(c[r+(f<<2)>>2]|0)+ac;if((c[2418596]&2|0)==0){aa=w;ab=x;break}A=ad<<24>>24;z=((ag(c[k+(f<<2)>>2]|0,A)|0)>>2)+x|0;aa=((ag(c[l+(f<<2)>>2]|0,A)|0)>>2)+w|0;ab=z}}while(0);v=f+1|0;if((v|0)<4){f=v;x=ab;w=aa}else{break}}if((ab|0)>16383){ae=16383.0}else{ae=(ab|0)<-16384?-16384.0:+(ab|0)}if((aa|0)>16383){af=16383.0}else{af=(aa|0)<-16384?-16384.0:+(aa|0)}w=c[2418696]|0;if((w&1|0)==0){ah=0}else{ah=~~(ae*+h[1209346])}if((w&2|0)==0){ai=0}else{ai=~~(ae*+h[1209346])}w=c[2418697]|0;if((w&1|0)==0){aj=ah}else{aj=~~(af*+h[1209347])+ah|0}if((w&2|0)==0){ak=ai}else{ak=~~(af*+h[1209347])+ai|0}if((aj|0)<-32768){al=-32768}else{al=(aj|0)>32767?32767:aj}if((ak|0)<-32768){am=-32768}else{am=(ak|0)>32767?32767:ak}b[C>>1]=(e[C>>1]|0)+al&65535;w=C+2|0;b[w>>1]=(e[w>>1]|0)+am&65535;if((D|0)>=(g|0)){break}C=C+4|0;D=D+1|0}E=t|0;F=c[E>>2]|0;c[2418655]=F;G=m|0;H=c[G>>2]|0;c[2418653]=H;I=o|0;J=c[I>>2]|0;c[2418658]=J;K=t+4|0;L=c[K>>2]|0;c[2418666]=L;M=m+4|0;N=c[M>>2]|0;c[2418664]=N;O=o+4|0;P=c[O>>2]|0;c[2418669]=P;Q=t+8|0;R=c[Q>>2]|0;c[2418677]=R;S=m+8|0;T=c[S>>2]|0;c[2418675]=T;U=o+8|0;V=c[U>>2]|0;c[2418680]=V;W=t+12|0;X=c[W>>2]|0;c[2418688]=X;Y=m+12|0;Z=c[Y>>2]|0;c[2418686]=Z;_=o+12|0;$=c[_>>2]|0;c[2418691]=$;i=j;return}function TN(b,d){b=b|0;d=d|0;var e=0,f=0.0,g=0,i=0;gGz(9674384,0,408);c[2443782]=~~(111860.0/(a[9680]|0?32.0e3:0.0)*32768.0);c[2418596]=0;c[2418645]=b;c[2418646]=d-1;c[2426862]=9674384;gGz(9674592,0,176);c[2418597]=0;d=1;do{c[9674388+(d<<2)>>2]=0;d=d+1|0;}while((d|0)<48);d=gGq(16384)|0;b=c[2426862]|0;e=b+204|0;c[e>>2]=d;d=0;do{f=3579545.0/+(4096-d|0);if(f==0.0){g=1}else{i=~~(65536.0/(111860.0/f));g=(i|0)==0?1:i}c[(c[e>>2]|0)+(d<<2)>>2]=g;d=d+1|0;}while((d|0)<4096);h[b+384>>3]=1.0;h[b+392>>3]=1.0;c[b+400>>2]=3;c[b+404>>2]=3;return}function TO(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=b&255;c[2426862]=9674384;if((a|0)>47){return}b=9674388+(a<<2)|0;if((a|0)==40){e=c[b>>2]^d;f=0;do{g=1<<f;do{if((g&e|0)!=0){h=9674612+(f*44|0)|0;if((g&d|0)==0){c[h>>2]=0;break}c[h>>2]=1;c[9674620+(f*44|0)>>2]=0;c[9674632+(f*44|0)>>2]=0;i=(c[9674604+(f*44|0)>>2]<<16)+(c[9674600+(f*44|0)>>2]|0)|0;j=9674596+(f*44|0)|0;k=c[2418646]|0;if((i|0)>(k|0)){c[h>>2]=0;break}if((i-1+(c[j>>2]|0)|0)<=(k|0)){break}c[j>>2]=k-i}}while(0);f=f+1|0;}while((f|0)<4);c[2418637]=d;return}c[b>>2]=d;if((a|0)<8){return}if((a|0)>=40){if((a|0)==47){c[2418596]=d&7;return}else if((a|0)==44){c[2418654]=d&7;c[2418665]=d>>>3&7;return}else if((a|0)==42){c[2418656]=d&1;c[2418667]=d>>>1&1;c[2418678]=d>>>2&1;c[2418689]=d>>>3&1;c[2418657]=d>>>4&1;c[2418668]=d>>>5&1;c[2418679]=d>>>6&1;c[2418690]=d>>>7;return}else if((a|0)==45){c[2418676]=d&7;c[2418687]=d>>>3&7;return}else{return}}b=a-8|0;a=(b|0)/8|0;switch(b&7|0){case 0:{b=9674592+(a*44|0)|0;c[b>>2]=c[b>>2]&3840|d;return};case 6:{c[9674604+(a*44|0)>>2]=d;return};case 1:{b=9674592+(a*44|0)|0;c[b>>2]=c[b>>2]&255|d<<8&3840;return};case 4:{b=9674600+(a*44|0)|0;c[b>>2]=c[b>>2]&65280|d;return};case 5:{b=9674600+(a*44|0)|0;c[b>>2]=c[b>>2]&255|d<<8;return};case 3:{b=9674596+(a*44|0)|0;c[b>>2]=c[b>>2]&255|d<<8;return};case 7:{c[9674608+(a*44|0)>>2]=d<<1&254|d&1;return};case 2:{b=9674596+(a*44|0)|0;c[b>>2]=c[b>>2]&65280|d;return};default:{return}}}function TP(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=i;i=i+64|0;d=b|0;e=b+16|0;if((a&64|0)==0){i=b;return}a=b+32|0;f=e|0;g=e+4|0;h=e+8|0;j=e+12|0;k=d;l=d|0;m=d+4|0;n=d+12|0;c[2426862]=9674384;cC(a|0,162496,(o=i,i=i+8|0,c[o>>2]=0,o)|0)|0;i=o;c[f>>2]=(c[2426862]|0)+4;c[g>>2]=192;c[h>>2]=0;c[j>>2]=a;gj[c[2076592]&4095](e)|0;cC(a|0,500608,(o=i,i=i+8|0,c[o>>2]=0,o)|0)|0;i=o;c[f>>2]=(c[2426862]|0)+208;c[g>>2]=176;c[h>>2]=0;c[j>>2]=a;gj[c[2076592]&4095](e)|0;p=c[2426862]|0;gGz(k|0,0,12);c[l>>2]=p;c[m>>2]=4;c[n>>2]=384936;gj[c[2076592]&4095](d)|0;c[2426862]=9674792;cC(a|0,162496,(o=i,i=i+8|0,c[o>>2]=0,o)|0)|0;i=o;c[f>>2]=(c[2426862]|0)+4;c[g>>2]=192;c[h>>2]=0;c[j>>2]=a;gj[c[2076592]&4095](e)|0;cC(a|0,500608,(o=i,i=i+8|0,c[o>>2]=0,o)|0)|0;i=o;c[f>>2]=(c[2426862]|0)+208;c[g>>2]=176;c[h>>2]=0;c[j>>2]=a;gj[c[2076592]&4095](e)|0;e=c[2426862]|0;gGz(k|0,0,12);c[l>>2]=e;c[m>>2]=4;c[n>>2]=384936;gj[c[2076592]&4095](d)|0;i=b;return}function TQ(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0;if((a|0)>4){return}f=c[((a|0)==4?9681360:(a|0)==3?9681368:(a|0)==2?9681376:(a|0)==1?9681384:9681392)>>2]|0;a=e<<16;g=f+104|0;do{if((c[g>>2]|0)==0){i=f+156|0;j=c[i>>2]|0;if((j|0)>(a|0)){break}c[i>>2]=j+a}}while(0);j=f+108|0;do{if((c[j>>2]|0)==0){i=f+160|0;k=c[i>>2]|0;if((k|0)>(a|0)){break}c[i>>2]=k+a}}while(0);k=f+112|0;do{if((c[k>>2]|0)==0){i=f+164|0;l=c[i>>2]|0;if((l|0)>(a|0)){break}c[i>>2]=l+a}}while(0);l=f+116|0;do{if((c[l>>2]|0)==0){i=f+168|0;m=c[i>>2]|0;if((m|0)>(a|0)){break}c[i>>2]=m+a}}while(0);if((e|0)<=0){return}a=f+168|0;m=f+184|0;i=f+124|0;n=f+120|0;o=f+132|0;p=f+136|0;q=f+128|0;r=f+152|0;s=f+200|0;t=f+188|0;u=f+192|0;v=f+172|0;w=f+156|0;x=f+140|0;y=f+176|0;z=f+160|0;A=f+144|0;B=f+180|0;C=f+164|0;D=f+148|0;f=d;d=e;while(1){e=c[v>>2]|0;E=c[w>>2]|0;F=(e|0)==0?0:E;G=E-65536|0;c[w>>2]=G;do{if((G|0)<1){E=c[x>>2]|0;H=G;I=F;while(1){J=H+E|0;if((J|0)>0){K=44771;break}L=J+E|0;M=I+E|0;if((L|0)<1){H=L;I=M}else{K=44773;break}}if((K|0)==44773){K=0;c[w>>2]=L;N=e;O=L;P=M;break}else if((K|0)==44771){K=0;c[w>>2]=J;H=e^1;c[v>>2]=H;N=H;O=J;P=I+((e|0)==1?0:E)|0;break}}else{N=e;O=G;P=F}}while(0);F=P-((N|0)==0?0:O)|0;G=c[y>>2]|0;e=c[z>>2]|0;H=(G|0)==0?0:e;Q=e-65536|0;c[z>>2]=Q;do{if((Q|0)<1){e=c[A>>2]|0;R=Q;S=H;while(1){T=R+e|0;if((T|0)>0){K=44819;break}U=T+e|0;V=S+e|0;if((U|0)<1){R=U;S=V}else{K=44818;break}}if((K|0)==44818){K=0;c[z>>2]=U;W=G;X=U;Y=V;break}else if((K|0)==44819){K=0;c[z>>2]=T;R=G^1;c[y>>2]=R;W=R;X=T;Y=S+((G|0)==1?0:e)|0;break}}else{W=G;X=Q;Y=H}}while(0);H=Y-((W|0)==0?0:X)|0;Q=c[B>>2]|0;G=c[C>>2]|0;R=(Q|0)==0?0:G;E=G-65536|0;c[C>>2]=E;do{if((E|0)<1){G=c[D>>2]|0;I=E;Z=R;while(1){_=I+G|0;if((_|0)>0){K=44825;break}$=_+G|0;aa=Z+G|0;if(($|0)<1){I=$;Z=aa}else{K=44824;break}}if((K|0)==44824){K=0;c[C>>2]=$;ab=Q;ac=$;ad=aa;break}else if((K|0)==44825){K=0;c[C>>2]=_;I=Q^1;c[B>>2]=I;ab=I;ac=_;ad=Z+((Q|0)==1?0:G)|0;break}}else{ab=Q;ac=E;ad=R}}while(0);R=ad-((ab|0)==0?0:ac)|0;E=65536;Q=c[a>>2]|0;I=c[m>>2]|0;e=0;while(1){S=(Q|0)<(E|0)?Q:E;ae=e+((I|0)==0?0:Q)|0;af=Q-S|0;do{if((af|0)<1){ah=c[n>>2]|0;if((c[i>>2]|0)==1){ai=c[o>>2]|0;aj=ai&ah;ak=ah>>1;if((aj|0)==(ai|0)|(aj|0)==0){al=ak}else{c[n>>2]=ak;al=c[q>>2]|ak}c[n>>2]=al;am=(c[p>>2]|0)!=0^al&1}else{ak=ah>>1;c[n>>2]=ak;if((ah&1|0)==0){an=ak}else{ah=c[q>>2]|ak;c[n>>2]=ah;an=ah}am=an&1}c[m>>2]=am;ah=c[r>>2]|0;ak=ah+af|0;if((am|0)==0){ao=ak;ap=0;aq=ae;break}ar=ak;as=am;at=ae+ah|0;K=44785}else{ar=af;as=I;at=ae;K=44785}}while(0);do{if((K|0)==44785){K=0;if((as|0)==0){ao=ar;ap=0;aq=at;break}ao=ar;ap=as;aq=at-ar|0}}while(0);ae=E-S|0;if((ae|0)>0){E=ae;Q=ao;I=ap;e=aq}else{break}}c[a>>2]=ao;e=ag(c[g>>2]|0,F)|0;I=(ag(c[j>>2]|0,H)|0)+e|0;e=I+(ag(c[k>>2]|0,R)|0)|0;I=e+(ag(c[l>>2]|0,aq)|0)|0;e=I>>>0>2147418112?32767:I>>>16;I=c[s>>2]|0;if((I&1|0)==0){au=0}else{au=~~(+(e>>>0>>>0)*+h[u>>3])}if((I&2|0)==0){av=0}else{av=~~(+(e>>>0>>>0)*+h[u>>3])}if((c[t>>2]|0)==0){if((au|0)<-32768){aw=-32768}else{aw=(au|0)>32767?32767:au&65535}b[f>>1]=aw;if((av|0)<-32768){ax=-32768}else{ax=(av|0)>32767?32767:av&65535}b[f+2>>1]=ax}else{e=(b[f>>1]|0)+au|0;if((e|0)<-32768){ay=-32768}else{ay=(e|0)>32767?32767:e&65535}b[f>>1]=ay;e=f+2|0;I=(b[e>>1]|0)+av|0;if((I|0)<-32768){az=-32768}else{az=(I|0)>32767?32767:I&65535}b[e>>1]=az}e=d-1|0;if((e|0)<=0){break}f=f+4|0;d=e}return}function TR(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if((a|0)>4){return}d=c[((a|0)==4?9681360:(a|0)==3?9681368:(a|0)==2?9681376:(a|0)==1?9681384:9681392)>>2]|0;a=(b&128|0)==0;if(a){e=c[d+100>>2]|0}else{f=b>>>4&7;c[d+100>>2]=f;g=d+68+(f<<2)|0;c[g>>2]=c[g>>2]&1008|b&15;e=f}f=(e|0)/2|0;switch(e|0){case 0:case 2:case 4:{g=d+68+(e<<2)|0;h=c[g>>2]|0;if(a){i=h&15|b<<4&1008;c[g>>2]=i;j=i}else{j=h}h=d|0;i=ag(c[h>>2]|0,j)|0;j=d+140+(f<<2)|0;c[j>>2]=i;if((i|0)==0){c[j>>2]=c[h>>2]}if((e|0)!=4){return}if((c[d+92>>2]&3|0)!=3){return}c[d+152>>2]=c[d+148>>2]<<1;return};case 1:case 3:case 5:case 7:{h=b&15;c[d+104+(f<<2)>>2]=c[d+4+(h<<2)>>2];if(!a){return}f=d+68+(e<<2)|0;c[f>>2]=c[f>>2]&1008|h;return};case 6:{h=d+92|0;f=c[h>>2]|0;if(a){a=f&1008|b&15;c[h>>2]=a;k=a}else{k=f}c[d+124>>2]=k>>>2&1;f=k&3;if((f|0)==3){l=c[d+148>>2]<<1}else{l=c[d>>2]<<f+5}c[d+152>>2]=l;l=c[d+128>>2]|0;c[d+120>>2]=l;c[d+184>>2]=l&1;return};default:{return}}}function TS(b,d,e,f,g,i){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;i=i|0;var j=0,k=0,l=0,m=0.0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;if((b|0)>4){return}c[2405760]=b;switch(b|0){case 1:{b=0;while(1){if((b|0)>=1024){j=0;break}k=9638528+(b<<2)|0;if((c[k>>2]|0)==0){l=44873;break}else{b=b+1|0}}do{if((l|0)==44873){b=gGq(208)|0;c[k>>2]=b;if((b|0)==0){j=0;break}gGz(b|0,0,208);j=b}}while(0);c[2420346]=j;gGz(j|0,0,208);k=~~((a[9680]|0?33554432.0e3:0.0)/+(d|0));c[j>>2]=k;c[j+68>>2]=0;gGz(j+100|0,0,20);c[j+72>>2]=15;c[j+76>>2]=0;c[j+80>>2]=15;c[j+84>>2]=0;c[j+88>>2]=15;c[j+92>>2]=0;c[j+96>>2]=15;c[j+172>>2]=0;c[j+156>>2]=k;c[j+140>>2]=k;c[j+176>>2]=0;c[j+160>>2]=k;c[j+144>>2]=k;c[j+180>>2]=0;c[j+164>>2]=k;c[j+148>>2]=k;c[j+168>>2]=k;c[j+152>>2]=k;c[j+128>>2]=16384;c[j+132>>2]=3;c[j+136>>2]=1;c[j+120>>2]=16384;c[j+184>>2]=0;j=c[2420346]|0;k=0;m=10922.0;while(1){if(m>10922.0){c[j+4+(k<<2)>>2]=10922}else{c[j+4+(k<<2)>>2]=~~m}b=k+1|0;if((b|0)<15){k=b;m=m/1.258925412}else{break}}c[j+64>>2]=0;c[(c[2420346]|0)+128>>2]=e;c[(c[2420346]|0)+132>>2]=f;c[(c[2420346]|0)+136>>2]=g;c[(c[2420346]|0)+188>>2]=i;j=c[2420346]|0;h[j+192>>3]=1.0;c[j+200>>2]=3;return};case 3:{j=0;while(1){if((j|0)>=1024){n=0;break}o=9638528+(j<<2)|0;if((c[o>>2]|0)==0){l=44893;break}else{j=j+1|0}}do{if((l|0)==44893){j=gGq(208)|0;c[o>>2]=j;if((j|0)==0){n=0;break}gGz(j|0,0,208);n=j}}while(0);c[2420342]=n;gGz(n|0,0,208);o=~~((a[9680]|0?33554432.0e3:0.0)/+(d|0));c[n>>2]=o;c[n+68>>2]=0;gGz(n+100|0,0,20);c[n+72>>2]=15;c[n+76>>2]=0;c[n+80>>2]=15;c[n+84>>2]=0;c[n+88>>2]=15;c[n+92>>2]=0;c[n+96>>2]=15;c[n+172>>2]=0;c[n+156>>2]=o;c[n+140>>2]=o;c[n+176>>2]=0;c[n+160>>2]=o;c[n+144>>2]=o;c[n+180>>2]=0;c[n+164>>2]=o;c[n+148>>2]=o;c[n+168>>2]=o;c[n+152>>2]=o;c[n+128>>2]=16384;c[n+132>>2]=3;c[n+136>>2]=1;c[n+120>>2]=16384;c[n+184>>2]=0;n=c[2420342]|0;o=0;m=10922.0;while(1){if(m>10922.0){c[n+4+(o<<2)>>2]=10922}else{c[n+4+(o<<2)>>2]=~~m}j=o+1|0;if((j|0)<15){o=j;m=m/1.258925412}else{break}}c[n+64>>2]=0;c[(c[2420342]|0)+128>>2]=e;c[(c[2420342]|0)+132>>2]=f;c[(c[2420342]|0)+136>>2]=g;c[(c[2420342]|0)+188>>2]=i;n=c[2420342]|0;h[n+192>>3]=1.0;c[n+200>>2]=3;return};case 2:{n=0;while(1){if((n|0)>=1024){p=0;break}q=9638528+(n<<2)|0;if((c[q>>2]|0)==0){l=44883;break}else{n=n+1|0}}do{if((l|0)==44883){n=gGq(208)|0;c[q>>2]=n;if((n|0)==0){p=0;break}gGz(n|0,0,208);p=n}}while(0);c[2420344]=p;gGz(p|0,0,208);q=~~((a[9680]|0?33554432.0e3:0.0)/+(d|0));c[p>>2]=q;c[p+68>>2]=0;gGz(p+100|0,0,20);c[p+72>>2]=15;c[p+76>>2]=0;c[p+80>>2]=15;c[p+84>>2]=0;c[p+88>>2]=15;c[p+92>>2]=0;c[p+96>>2]=15;c[p+172>>2]=0;c[p+156>>2]=q;c[p+140>>2]=q;c[p+176>>2]=0;c[p+160>>2]=q;c[p+144>>2]=q;c[p+180>>2]=0;c[p+164>>2]=q;c[p+148>>2]=q;c[p+168>>2]=q;c[p+152>>2]=q;c[p+128>>2]=16384;c[p+132>>2]=3;c[p+136>>2]=1;c[p+120>>2]=16384;c[p+184>>2]=0;p=c[2420344]|0;q=0;m=10922.0;while(1){if(m>10922.0){c[p+4+(q<<2)>>2]=10922}else{c[p+4+(q<<2)>>2]=~~m}n=q+1|0;if((n|0)<15){q=n;m=m/1.258925412}else{break}}c[p+64>>2]=0;c[(c[2420344]|0)+128>>2]=e;c[(c[2420344]|0)+132>>2]=f;c[(c[2420344]|0)+136>>2]=g;c[(c[2420344]|0)+188>>2]=i;p=c[2420344]|0;h[p+192>>3]=1.0;c[p+200>>2]=3;return};case 4:{p=0;while(1){if((p|0)>=1024){r=0;break}s=9638528+(p<<2)|0;if((c[s>>2]|0)==0){l=44903;break}else{p=p+1|0}}do{if((l|0)==44903){p=gGq(208)|0;c[s>>2]=p;if((p|0)==0){r=0;break}gGz(p|0,0,208);r=p}}while(0);c[2420340]=r;gGz(r|0,0,208);s=~~((a[9680]|0?33554432.0e3:0.0)/+(d|0));c[r>>2]=s;c[r+68>>2]=0;gGz(r+100|0,0,20);c[r+72>>2]=15;c[r+76>>2]=0;c[r+80>>2]=15;c[r+84>>2]=0;c[r+88>>2]=15;c[r+92>>2]=0;c[r+96>>2]=15;c[r+172>>2]=0;c[r+156>>2]=s;c[r+140>>2]=s;c[r+176>>2]=0;c[r+160>>2]=s;c[r+144>>2]=s;c[r+180>>2]=0;c[r+164>>2]=s;c[r+148>>2]=s;c[r+168>>2]=s;c[r+152>>2]=s;c[r+128>>2]=16384;c[r+132>>2]=3;c[r+136>>2]=1;c[r+120>>2]=16384;c[r+184>>2]=0;r=c[2420340]|0;s=0;m=10922.0;while(1){if(m>10922.0){c[r+4+(s<<2)>>2]=10922}else{c[r+4+(s<<2)>>2]=~~m}p=s+1|0;if((p|0)<15){s=p;m=m/1.258925412}else{break}}c[r+64>>2]=0;c[(c[2420340]|0)+128>>2]=e;c[(c[2420340]|0)+132>>2]=f;c[(c[2420340]|0)+136>>2]=g;c[(c[2420340]|0)+188>>2]=i;r=c[2420340]|0;h[r+192>>3]=1.0;c[r+200>>2]=3;return};case 0:{r=0;while(1){if((r|0)>=1024){t=0;break}u=9638528+(r<<2)|0;if((c[u>>2]|0)==0){l=44863;break}else{r=r+1|0}}do{if((l|0)==44863){r=gGq(208)|0;c[u>>2]=r;if((r|0)==0){t=0;break}gGz(r|0,0,208);t=r}}while(0);c[2420348]=t;gGz(t|0,0,208);u=~~((a[9680]|0?33554432.0e3:0.0)/+(d|0));c[t>>2]=u;c[t+68>>2]=0;gGz(t+100|0,0,20);c[t+72>>2]=15;c[t+76>>2]=0;c[t+80>>2]=15;c[t+84>>2]=0;c[t+88>>2]=15;c[t+92>>2]=0;c[t+96>>2]=15;c[t+172>>2]=0;c[t+156>>2]=u;c[t+140>>2]=u;c[t+176>>2]=0;c[t+160>>2]=u;c[t+144>>2]=u;c[t+180>>2]=0;c[t+164>>2]=u;c[t+148>>2]=u;c[t+168>>2]=u;c[t+152>>2]=u;c[t+128>>2]=16384;c[t+132>>2]=3;c[t+136>>2]=1;c[t+120>>2]=16384;c[t+184>>2]=0;t=c[2420348]|0;u=0;m=10922.0;while(1){if(m>10922.0){c[t+4+(u<<2)>>2]=10922}else{c[t+4+(u<<2)>>2]=~~m}d=u+1|0;if((d|0)<15){u=d;m=m/1.258925412}else{break}}c[t+64>>2]=0;c[(c[2420348]|0)+128>>2]=e;c[(c[2420348]|0)+132>>2]=f;c[(c[2420348]|0)+136>>2]=g;c[(c[2420348]|0)+188>>2]=i;i=c[2420348]|0;h[i+192>>3]=1.0;c[i+200>>2]=3;return};default:{return}}}function TT(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0;c[2405760]=0;a=c[2420348]|0;b=0;while(1){if((b|0)>=1024){break}d=9638528+(b<<2)|0;if((c[d>>2]|0)==(a|0)){e=44922;break}else{b=b+1|0}}if((e|0)==44922){gGr(a);c[d>>2]=0}c[2420348]=0;d=c[2420346]|0;a=0;while(1){if((a|0)>=1024){break}f=9638528+(a<<2)|0;if((c[f>>2]|0)==(d|0)){e=44926;break}else{a=a+1|0}}if((e|0)==44926){gGr(d);c[f>>2]=0}c[2420346]=0;f=c[2420344]|0;d=0;while(1){if((d|0)>=1024){break}g=9638528+(d<<2)|0;if((c[g>>2]|0)==(f|0)){e=44930;break}else{d=d+1|0}}if((e|0)==44930){gGr(f);c[g>>2]=0}c[2420344]=0;g=c[2420342]|0;f=0;while(1){if((f|0)>=1024){break}h=9638528+(f<<2)|0;if((c[h>>2]|0)==(g|0)){e=44934;break}else{f=f+1|0}}if((e|0)==44934){gGr(g);c[h>>2]=0}c[2420342]=0;h=c[2420340]|0;g=0;while(1){if((g|0)>=1024){e=44941;break}i=9638528+(g<<2)|0;if((c[i>>2]|0)==(h|0)){break}else{g=g+1|0}}if((e|0)==44941){c[2420340]=0;return}gGr(h);c[i>>2]=0;c[2420340]=0;return}function TU(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0;d=i;i=i+208|0;e=d|0;f=d+16|0;g=d+32|0;h=d+48|0;j=d+64|0;k=d+80|0;l=d+96|0;m=d+112|0;n=d+128|0;o=d+144|0;p=d+160|0;q=d+176|0;if((b|0)!=0){c[b>>2]=169753}if(!((a&64|0)!=0&(c[2405760]|0)>0)){i=d;return}a=d+192|0;b=q;r=q|0;s=q+4|0;t=q+12|0;u=p;v=p|0;w=p+4|0;x=p+12|0;y=o;z=o|0;A=o+4|0;B=o+12|0;C=n;D=n|0;E=n+4|0;F=n+12|0;G=m;H=m|0;I=m+4|0;J=m+12|0;K=l;L=l|0;M=l+4|0;N=l+12|0;O=k;P=k|0;Q=k+4|0;R=k+12|0;S=j;T=j|0;U=j+4|0;V=j+12|0;W=h;X=h|0;Y=h+4|0;Z=h+12|0;_=g;$=g|0;aa=g+4|0;ab=g+12|0;ac=f;ad=f|0;ae=f+4|0;af=f+12|0;ag=e;ah=e|0;ai=e+4|0;aj=e+12|0;ak=0;do{al=c[((ak|0)==4?9681360:(ak|0)==3?9681368:(ak|0)==2?9681376:(ak|0)==1?9681384:9681392)>>2]|0;gGz(a|0,0,16);cC(a|0,161944,(am=i,i=i+8|0,c[am>>2]=ak,am)|0)|0;i=am;gGz(b|0,0,12);c[r>>2]=al+4;c[s>>2]=64;c[t>>2]=a;gj[c[2076592]&4095](q)|0;gGz(a|0,0,16);cC(a|0,500432,(am=i,i=i+8|0,c[am>>2]=ak,am)|0)|0;i=am;gGz(u|0,0,12);c[v>>2]=al+68;c[w>>2]=32;c[x>>2]=a;gj[c[2076592]&4095](p)|0;gGz(a|0,0,16);cC(a|0,384672,(am=i,i=i+8|0,c[am>>2]=ak,am)|0)|0;i=am;gGz(y|0,0,12);c[z>>2]=al+104;c[A>>2]=16;c[B>>2]=a;gj[c[2076592]&4095](o)|0;gGz(a|0,0,16);cC(a|0,299400,(am=i,i=i+8|0,c[am>>2]=ak,am)|0)|0;i=am;gGz(C|0,0,12);c[D>>2]=al+140;c[E>>2]=16;c[F>>2]=a;gj[c[2076592]&4095](n)|0;gGz(a|0,0,16);cC(a|0,228216,(am=i,i=i+8|0,c[am>>2]=ak,am)|0)|0;i=am;gGz(G|0,0,12);c[H>>2]=al+156;c[I>>2]=16;c[J>>2]=a;gj[c[2076592]&4095](m)|0;gGz(a|0,0,16);cC(a|0,177896,(am=i,i=i+8|0,c[am>>2]=ak,am)|0)|0;i=am;gGz(K|0,0,12);c[L>>2]=al+172;c[M>>2]=16;c[N>>2]=a;gj[c[2076592]&4095](l)|0;gGz(O|0,0,12);c[P>>2]=al+100;c[Q>>2]=4;c[R>>2]=143160;gj[c[2076592]&4095](k)|0;gGz(S|0,0,12);c[T>>2]=al+120;c[U>>2]=4;c[V>>2]=114976;gj[c[2076592]&4095](j)|0;gGz(W|0,0,12);c[X>>2]=al+124;c[Y>>2]=4;c[Z>>2]=89976;gj[c[2076592]&4095](h)|0;gGz(_|0,0,12);c[$>>2]=al+128;c[aa>>2]=4;c[ab>>2]=70024;gj[c[2076592]&4095](g)|0;gGz(ac|0,0,12);c[ad>>2]=al+132;c[ae>>2]=4;c[af>>2]=578008;gj[c[2076592]&4095](f)|0;gGz(ag|0,0,12);c[ah>>2]=al+136;c[ai>>2]=4;c[aj>>2]=561632;gj[c[2076592]&4095](e)|0;ak=ak+1|0;}while((ak|0)<(c[2405760]|0));i=d;return}function TV(){var f=0,g=0,i=0,j=0,k=0,l=0,m=0.0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0.0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0;f=c[2112964]|0;g=a[9688]|0;gGz(f|0,0,(g?2136:0)|0);i=f+2|0;j=c[2076600]|0;k=c[3531862]|0;l=j|0;m=a[9680]|0?32.0e3:0.0;n=j+16576|0;o=j+16580|0;p=g?534:0;q=j+16568|0;r=j+16560|0;s=0;do{t=s<<3;u=j+12+t|0;v=a[u]|0;w=v&255;do{if((w&1|0)!=0){if((w&2|0)==0){x=(d[(t|4)+(j+12)|0]|0)<<12;y=256-(d[(t|5)+(j+12)|0]|0)<<12;z=d[(t|1)+(j+12)|0]|0;A=(z>>>4)*546|0;B=(z&15)*546|0;z=j+16396+(s<<2)|0;C=c[z>>2]|0;D=a[(t|2)+(j+12)|0]&31;E=~~(((D|0)==0?4.0:+(D|0))*+(c[l>>2]|0)/m*.125*256.0);L57957:do{if(g){D=C;F=0;G=f;H=i;while(1){I=(D>>>8)+x|0;if((I|0)>=(y|0)){break}J=a[k+I|0]|0;I=c[n>>2]|0;if((I&1|0)==0){K=0}else{L=+((ag(J<<24>>24,A)|0)/256|0|0);K=~~(L*+h[r>>3])}if((I&2|0)==0){M=0}else{L=+((ag(J<<24>>24,A)|0)/256|0|0);M=~~(L*+h[r>>3])}I=c[o>>2]|0;if((I&1|0)==0){N=K}else{L=+((ag(J<<24>>24,B)|0)/256|0|0);N=~~(L*+h[q>>3])+K|0}if((I&2|0)==0){O=M}else{L=+((ag(J<<24>>24,B)|0)/256|0|0);O=~~(L*+h[q>>3])+M|0}if((N|0)<-32768){P=-32768}else{P=(N|0)>32767?32767:N}if((O|0)<-32768){Q=-32768}else{Q=(O|0)>32767?32767:O}b[G>>1]=(e[G>>1]|0)+P&65535;b[H>>1]=(e[H>>1]|0)+Q&65535;J=D+E|0;I=F+1|0;if((I|0)<(p|0)){D=J;F=I;G=G+4|0;H=H+4|0}else{R=J;break L57957}}a[u]=a[u]&-2;R=D}else{R=C}}while(0);c[z>>2]=R;break}C=((d[(t|1)+(j+12)|0]|0)<<7)+4096|0;E=j+16396+(s<<2)|0;B=c[E>>2]|0;L=+(c[l>>2]|0)/m*.0078125*.25;A=~~(+((d[(t|3)+(j+12)|0]|0)<<8|(d[(t|2)+(j+12)|0]|0)|0)*L*256.0);y=(d[(t|5)+(j+12)|0]|0)<<7;x=j+16460+(s<<2)|0;H=c[x>>2]|0;G=~~(L*+(d[(t|4)+(j+12)|0]|0|0)*65536.0);L57982:do{if(g){L57984:do{if((v&4)!=0&H>>>0>8388607){S=v;T=H;U=B}else{F=i;J=f;I=1;V=H;W=B;while(1){X=d[(V>>>16&127|y)+(j+12)|0]|0;Y=(X>>>4)*546|0;Z=(X&15)*546|0;X=a[(W>>>8&127|C)+(j+12)|0]|0;_=c[n>>2]|0;if((_&1|0)==0){$=0}else{L=+((ag(Y,X<<24>>24)|0)/256|0|0);$=~~(L*+h[r>>3])}if((_&2|0)==0){aa=0}else{L=+((ag(Y,X<<24>>24)|0)/256|0|0);aa=~~(L*+h[r>>3])}Y=c[o>>2]|0;if((Y&1|0)==0){ab=$}else{L=+((ag(Z,X<<24>>24)|0)/256|0|0);ab=~~(L*+h[q>>3])+$|0}if((Y&2|0)==0){ac=aa}else{L=+((ag(Z,X<<24>>24)|0)/256|0|0);ac=~~(L*+h[q>>3])+aa|0}if((ab|0)<-32768){ad=-32768}else{ad=(ab|0)>32767?32767:ab}if((ac|0)<-32768){ae=-32768}else{ae=(ac|0)>32767?32767:ac}b[J>>1]=(e[J>>1]|0)+ad&65535;b[F>>1]=(e[F>>1]|0)+ae&65535;X=W+A|0;Z=V+G|0;if((I|0)>=(p|0)){af=X;ah=Z;break L57982}Y=a[u]|0;if((Y&4)!=0&Z>>>0>8388607){S=Y;T=Z;U=X;break L57984}F=F+4|0;J=J+4|0;I=I+1|0;V=Z;W=X}}}while(0);a[u]=S&-2;af=U;ah=T}else{af=B;ah=H}}while(0);c[E>>2]=af;c[x>>2]=ah}}while(0);s=s+1|0;}while((s|0)<16);return}function TW(b,d,e,f,g,j,k){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0;l=i;i=i+16|0;m=l|0;n=l+8|0;c[m>>2]=b;c[n>>2]=e;c[2438228]=0;c[2433526]=0;c[2406676]=0;c[3528472]=0;c[2429844]=2936;c[2429842]=(k|0)!=0?k:80;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;k=a[9680]|0;e=k?32e3:0;if(!k){c[2427016]=1170;c[3542118]=1562;k=mD(c[2383582]|0,8e6,11025)|0;c[3542220]=3824;b=c[2076598]|0;if((k|0)==0){k=b+1|0;c[2076598]=k;o=k}else{o=b}c[2383582]=(c[2113008]|0)-o;l3(11025,m,d,n,f,g);i=l;return}c[2427016]=j;if(a[9624]|0){j=e*3|0;o=55555;while(1){if((o|0)>(j|0)){o=o>>1}else{break}}c[2429374]=o;c[3542118]=1826;c[2443890]=(o<<16>>>0)/32e3|0;p=o}else{c[2429374]=e;c[3542118]=1506;p=e}e=mD(c[2383582]|0,8e6,p)|0;c[3542220]=3824;p=c[2076598]|0;if((e|0)==0){e=p+1|0;c[2076598]=e;q=e}else{q=p}c[2383582]=(c[2113008]|0)-q;l3(c[2429374]|0,m,d,n,f,g);g=gGq(49152)|0;c[2406698]=g;gGz(g|0,0,49152);g=gGq(16384)|0;c[2385412]=g;gGz(g|0,0,16384);c[2433540]=0;c[2433578]=0;c[2429614]=0;h[745406]=1.0;h[745405]=1.0;h[745404]=1.0;c[2436786]=1;c[2436784]=2;a[3203280]=1;a[64232]=0;h[146571]=1.0;h[146570]=1.0;h[146569]=1.0;h[118356]=1.0;h[118355]=1.0;h[118354]=1.0;i=l;return}function TX(a){a=a|0;return 0}function TY(a,b){a=a|0;b=b|0;return}function TZ(){var a=0,b=0,d=0,e=0,f=0,g=0;a=gj[c[2427016]&4095](c[2429374]|0)|0;b=c[2433578]|0;if((b|0)>=(a|0)){return}d=a-b|0;a=c[2406698]|0;e=a+(b+8196<<1)|0;c[2438948]=e;f=a+(b+12292<<1)|0;c[2438949]=f;g=a+(b+16388<<1)|0;c[2438950]=g;mA(0,e,f,g,d);c[2433578]=(c[2433578]|0)+d;return}function T_(d,e){d=d|0;e=e|0;var f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0.0,r=0.0,s=0.0,t=0.0,u=0.0,v=0.0,w=0,x=0,y=0,z=0,A=0.0,B=0.0,C=0.0,D=0,E=0.0,F=0.0,G=0.0,H=0.0,I=0.0,J=0.0,K=0.0,L=0.0,M=0.0,N=0.0,O=0.0,P=0.0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0;f=((ag(c[2429374]|0,e)|0)/32e3|0)+1|0;g=c[2433578]|0;i=(f|0)<(g|0)?g:f;f=c[2433540]|0;j=(i|0)<(f|0)?f:i;i=a[9688]|0?534:0;k=((i|0)<(e|0)?i:e)<<1;if((f|0)<(j|0)){i=j-f|0;l=c[2406698]|0;c[2438946]=l+(f+4<<1);c[2438947]=l+(f+4100<<1);l2(i);c[2433540]=(c[2433540]|0)+i;m=c[2433578]|0}else{m=g}if((m|0)<(j|0)){g=j-m|0;i=c[2406698]|0;f=i+(m+8196<<1)|0;c[2438948]=f;l=i+(m+12292<<1)|0;c[2438949]=l;n=i+(m+16388<<1)|0;c[2438950]=n;mA(0,f,l,n,g);c[2433578]=(c[2433578]|0)+g;o=i}else{o=c[2406698]|0}c[2438946]=o+8;c[2438947]=o+8200;c[2438948]=o+16392;c[2438949]=o+24584;c[2438950]=o+32776;c[2438951]=o+40968;i=c[2429614]|0;g=i>>16;do{if((g-4|0)<(j|0)){b[o+(g+20480<<1)>>1]=((b[o+(g+12288<<1)>>1]|0)+(b[o+(g+8192<<1)>>1]|0)&65535)+(b[o+(g+16384<<1)>>1]|0)&65535;n=g-3|0;if((n|0)<(j|0)){p=n}else{break}do{b[o+(p+20484<<1)>>1]=((b[o+(p+12292<<1)>>1]|0)+(b[o+(p+8196<<1)>>1]|0)&65535)+(b[o+(p+16388<<1)>>1]|0)&65535;p=p+1|0;}while((p|0)<(j|0))}}while(0);p=i>>>15&131070;if((p|0)<(k|0)){g=a[64232]|0;q=+h[146569];r=+h[146571];s=+h[146570];t=+h[118354];u=+h[118356];v=+h[118355];n=c[2443890]|0;l=a[3203280]|0?3:0;f=(l&1|0)==0;m=(l&2|0)==0;l=c[2436786]|0;w=(l&1|0)==0;x=(l&2|0)==0;l=c[2436784]|0;y=(l&1|0)==0;z=(l&2|0)==0;A=+h[745405];B=+h[745406];C=+h[745404];l=p;p=i;do{do{if(g){D=p>>16;E=+(b[o+(D+20481<<1)>>1]|0);F=+(b[o+(D+20482<<1)>>1]|0);G=+(b[o+(D+20483<<1)>>1]|0);H=+(b[o+(D+20484<<1)>>1]|0);I=+(b[o+(D+1<<1)>>1]|0);J=+(b[o+(D+2<<1)>>1]|0);K=+(b[o+(D+3<<1)>>1]|0);L=+(b[o+(D+4<<1)>>1]|0);M=+(b[o+(D+4097<<1)>>1]|0);N=+(b[o+(D+4098<<1)>>1]|0);O=+(b[o+(D+4099<<1)>>1]|0);P=+(b[o+(D+4100<<1)>>1]|0);Q=~~(I*u)+~~(E*t)+~~(M*v)|0;R=~~(J*u)+~~(F*t)+~~(N*v)|0;S=~~(K*u)+~~(G*t)+~~(O*v)|0;T=~~(L*u)+~~(H*t)+~~(P*v)|0;U=~~(I*r)+~~(E*q)+~~(M*s)|0;V=~~(r*J)+~~(q*F)+~~(s*N)|0;W=~~(r*K)+~~(q*G)+~~(s*O)|0;X=~~(r*L)+~~(q*H)+~~(s*P)|0}else{if(f){Y=0;Z=0;_=0;$=0}else{D=p>>16;Y=~~(+(b[o+(D+20481<<1)>>1]|0)*C);Z=~~(C*+(b[o+(D+20482<<1)>>1]|0));_=~~(C*+(b[o+(D+20483<<1)>>1]|0));$=~~(C*+(b[o+(D+20484<<1)>>1]|0))}if(m){aa=0;ab=0;ac=0;ad=0}else{D=p>>16;aa=~~(+(b[o+(D+20481<<1)>>1]|0)*C);ab=~~(C*+(b[o+(D+20482<<1)>>1]|0));ac=~~(C*+(b[o+(D+20483<<1)>>1]|0));ad=~~(C*+(b[o+(D+20484<<1)>>1]|0))}if(w){ae=Y;af=Z;ah=_;ai=$}else{D=p>>16;ae=~~(+(b[o+(D+1<<1)>>1]|0)*B)+Y|0;af=~~(B*+(b[o+(D+2<<1)>>1]|0))+Z|0;ah=~~(B*+(b[o+(D+3<<1)>>1]|0))+_|0;ai=~~(B*+(b[o+(D+4<<1)>>1]|0))+$|0}if(x){aj=aa;ak=ab;al=ac;am=ad}else{D=p>>16;aj=~~(+(b[o+(D+1<<1)>>1]|0)*B)+aa|0;ak=~~(B*+(b[o+(D+2<<1)>>1]|0))+ab|0;al=~~(B*+(b[o+(D+3<<1)>>1]|0))+ac|0;am=~~(B*+(b[o+(D+4<<1)>>1]|0))+ad|0}if(y){an=ae;ao=af;ap=ah;aq=ai}else{D=p>>16;an=~~(+(b[o+(D+4097<<1)>>1]|0)*A)+ae|0;ao=~~(A*+(b[o+(D+4098<<1)>>1]|0))+af|0;ap=~~(A*+(b[o+(D+4099<<1)>>1]|0))+ah|0;aq=~~(A*+(b[o+(D+4100<<1)>>1]|0))+ai|0}if(z){Q=aj;R=ak;S=al;T=am;U=an;V=ao;W=ap;X=aq;break}D=p>>16;Q=~~(+(b[o+(D+4097<<1)>>1]|0)*A)+aj|0;R=~~(A*+(b[o+(D+4098<<1)>>1]|0))+ak|0;S=~~(A*+(b[o+(D+4099<<1)>>1]|0))+al|0;T=~~(A*+(b[o+(D+4100<<1)>>1]|0))+am|0;U=an;V=ao;W=ap;X=aq}}while(0);D=p>>>4<<2&16380;ar=b[14130680+(D<<1)>>1]|0;as=ag(ar,U)|0;at=b[14130680+((D|1)<<1)>>1]|0;au=(ag(at,V)|0)+as|0;as=b[14130680+((D|2)<<1)>>1]|0;av=au+(ag(as,W)|0)|0;au=b[14130680+((D|3)<<1)>>1]|0;D=av+(ag(au,X)|0)|0;av=ag(ar,Q)|0;ar=(ag(at,R)|0)+av|0;av=ar+(ag(as,S)|0)|0;as=av+(ag(au,T)|0)|0;if((D|0)<-536887295){aw=-32768}else{aw=(D|0)>536870911?32767:((D|0)/16384|0)&65535}if((as|0)<-536887295){ax=-32768}else{ax=(as|0)>536870911?32767:((as|0)/16384|0)&65535}b[d+(l<<1)>>1]=aw;b[d+((l|1)<<1)>>1]=ax;l=l+2|0;p=p+n|0;}while((l|0)<(k|0));c[2429614]=p;ay=p}else{ay=i}if(((a[9688]|0?534:0)|0)>(e|0)){return}e=ay>>16;i=j-e|0;if((i|0)>-4){j=-4;do{p=e+j|0;b[o+(j+4<<1)>>1]=b[o+(p+4<<1)>>1]|0;b[o+(j+4100<<1)>>1]=b[o+(p+4100<<1)>>1]|0;b[o+(j+8196<<1)>>1]=b[o+(p+8196<<1)>>1]|0;b[o+(j+12292<<1)>>1]=b[o+(p+12292<<1)>>1]|0;b[o+(j+16388<<1)>>1]=b[o+(p+16388<<1)>>1]|0;j=j+1|0;}while((j|0)<(i|0))}c[2429614]=ay&65535;c[2433540]=i;c[2433578]=i;h[6675]=100.0/+(c[2424]|0)+ +h[6675];return}function T$(d,e){d=d|0;e=e|0;var f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0.0,p=0.0,q=0.0,r=0.0,s=0.0,t=0.0,u=0,v=0,w=0,x=0.0,y=0.0,z=0.0,A=0.0,B=0.0,C=0.0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;f=c[2433578]|0;g=(f|0)>(e|0)?f:e;i=c[2433540]|0;j=(g|0)<(i|0)?i:g;g=a[9688]|0?534:0;k=(g|0)<(e|0)?g:e;if((i|0)<(j|0)){e=j-i|0;g=c[2406698]|0;c[2438946]=g+(i+4<<1);c[2438947]=g+(i+4100<<1);l2(e);c[2433540]=(c[2433540]|0)+e;l=c[2433578]|0}else{l=f}if((l|0)<(j|0)){f=j-l|0;e=c[2406698]|0;i=e+(l+8196<<1)|0;c[2438948]=i;g=e+(l+12292<<1)|0;c[2438949]=g;m=e+(l+16388<<1)|0;c[2438950]=m;mA(0,i,g,m,f);c[2433578]=(c[2433578]|0)+f;n=e}else{n=c[2406698]|0}c[2438946]=n+8;c[2438947]=n+8200;c[2438948]=n+16392;c[2438949]=n+24584;c[2438950]=n+32776;e=c[2429614]|0;if((e|0)<(k|0)){f=a[64232]|0;o=+h[146569];p=+h[146571];q=+h[146570];r=+h[118354];s=+h[118356];t=+h[118355];m=a[3203280]|0?3:0;g=(m&1|0)==0;i=(m&2|0)==0;m=c[2436786]|0;l=(m&1|0)==0;u=(m&2|0)==0;m=c[2436784]|0;v=(m&1|0)==0;w=(m&2|0)==0;x=+h[745405];y=+h[745406];z=+h[745404];m=e;do{e=(b[n+(m+12292<<1)>>1]|0)+(b[n+(m+8196<<1)>>1]|0)+(b[n+(m+16388<<1)>>1]|0)|0;do{if(f){A=+(e|0);B=+(b[n+(m+4<<1)>>1]|0);C=+(b[n+(m+4100<<1)>>1]|0);D=~~(B*s)+~~(A*r)+~~(C*t)|0;E=~~(B*p)+~~(A*o)+~~(C*q)|0}else{if(g){F=0}else{F=~~(+(e|0)*z)}if(i){G=0}else{G=~~(+(e|0)*z)}if(l){H=F}else{H=~~(+(b[n+(m+4<<1)>>1]|0)*y)+F|0}if(u){I=G}else{I=~~(+(b[n+(m+4<<1)>>1]|0)*y)+G|0}if(v){J=H}else{J=~~(+(b[n+(m+4100<<1)>>1]|0)*x)+H|0}if(w){D=I;E=J;break}D=~~(+(b[n+(m+4100<<1)>>1]|0)*x)+I|0;E=J}}while(0);if((E|0)<-32768){K=-32768}else{K=(E|0)>32767?32767:E&65535}if((D|0)<-32768){L=-32768}else{L=(D|0)>32767?32767:D&65535}e=m<<1;b[d+(e<<1)>>1]=K;b[d+((e|1)<<1)>>1]=L;m=m+1|0;}while((m|0)<(k|0))}c[2429614]=k;k=a[9688]|0?534:0;if((j|0)<(k|0)){return}m=j-k|0;if((m|0)>0){j=0;do{L=j+k|0;b[n+(j+4<<1)>>1]=b[n+(L+4<<1)>>1]|0;b[n+(j+4100<<1)>>1]=b[n+(L+4100<<1)>>1]|0;b[n+(j+8196<<1)>>1]=b[n+(L+8196<<1)>>1]|0;b[n+(j+12292<<1)>>1]=b[n+(L+12292<<1)>>1]|0;b[n+(j+16388<<1)>>1]=b[n+(L+16388<<1)>>1]|0;j=j+1|0;}while((j|0)<(m|0))}c[2429614]=0;c[2433540]=m;c[2433578]=m;h[6675]=100.0/+(c[2424]|0)+ +h[6675];return}function T0(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;i=i+128|0;e=d|0;f=d+16|0;g=d+32|0;h=d+48|0;j=d+64|0;k=d+80|0;l=d+96|0;m=d+112|0;n=(b|0)==0;do{if(!n){if((c[b>>2]|0)>=169249){break}c[b>>2]=169249}}while(0);if((a&64|0)==0){i=d;return}gGz(k|0,0,12);c[k>>2]=9775320;c[k+4>>2]=8;c[k+12>>2]=111920;gj[c[2076592]&4095](k)|0;gGz(j|0,0,12);c[j>>2]=9775288;c[j+4>>2]=8;c[j+12>>2]=478936;gj[c[2076592]&4095](j)|0;gGz(h|0,0,12);c[h>>2]=53400;c[h+4>>2]=8;c[h+12>>2]=398448;gj[c[2076592]&4095](h)|0;gGz(g|0,0,12);c[g>>2]=14114048;c[g+4>>2]=4;c[g+12>>2]=287368;gj[c[2076592]&4095](g)|0;g=f|0;do{if(!n){if((c[b>>2]|0)>=169110){break}c[b>>2]=169110}}while(0);if((c[2113008]|0)>0){b=e|0;n=e+4|0;f=e+8|0;h=e+12|0;j=0;do{cC(g|0,531144,(k=i,i=i+8|0,c[k>>2]=j,k)|0)|0;i=k;c[b>>2]=14168888+(j*252|0);c[n>>2]=252;c[f>>2]=0;c[h>>2]=g;gj[c[2076592]&4095](e)|0;j=j+1|0;}while((j|0)<(c[2113008]|0))}gGz(m|0,0,12);c[m>>2]=9734160;c[m+4>>2]=4;c[m+12>>2]=157440;gj[c[2076592]&4095](m)|0;gGz(l|0,0,12);c[l>>2]=9734312;c[l+4>>2]=4;c[l+12>>2]=470080;gj[c[2076592]&4095](l)|0;i=d;return}function T1(a,f){a=a|0;f=f|0;var g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0;c[2420428]=9668600;g=c[2417187]|0;i=c[2417188]|0;j=(c[2417189]|0)-32|0;k=c[2417190]|0;l=c[2417193]|0;m=c[2417197]|0;n=c[2417198]|0;o=(c[2417199]|0)-32|0;p=c[2417200]|0;q=c[2417203]|0;r=c[2417207]|0;s=c[2417208]|0;t=(c[2417209]|0)-32|0;u=c[2417210]|0;v=c[2417213]|0;w=c[2417217]|0;x=c[2417218]|0;y=(c[2417219]|0)-32|0;z=c[2417220]|0;A=c[2417223]|0;B=c[2417150]|0;if((f|0)>0){C=c[2417204]|0;D=c[2417194]|0;E=c[2417184]|0;F=c[2438316]|0;G=ag(F,c[2417214]|0)|0;H=ag(F,C)|0;C=ag(F,D)|0;D=ag(F,E)|0;E=a;a=1;F=l;I=q;J=v;K=A;L=w;M=r;N=m;O=g;P=x;Q=s;R=n;S=i;while(1){if((F|0)==0){T=0;U=0;V=O;W=S}else{X=D+S|0;Y=(X>>>24)+O|0;T=ag((d[B+O|0]|0)-128|0,k)|0;U=Y>>>0<j>>>0|0;V=Y;W=X&16777215}if((I|0)==0){Z=T;_=0;$=N;aa=R}else{X=C+R|0;Y=(X>>>24)+N|0;Z=(ag((d[B+N|0]|0)-128|0,p)|0)+T|0;_=Y>>>0<o>>>0|0;$=Y;aa=X&16777215}if((J|0)==0){ab=Z;ac=0;ad=M;ae=Q}else{X=H+Q|0;Y=(X>>>24)+M|0;ab=(ag((d[B+M|0]|0)-128|0,u)|0)+Z|0;ac=Y>>>0<t>>>0|0;ad=Y;ae=X&16777215}if((K|0)==0){af=ab;ah=0;ai=L;aj=P}else{X=G+P|0;Y=(X>>>24)+L|0;af=(ag((d[B+L|0]|0)-128|0,z)|0)+ab|0;ah=Y>>>0<y>>>0|0;ai=Y;aj=X&16777215}X=af>>2;Y=c[2420428]|0;ak=c[Y+312>>2]|0;if((ak&1|0)==0){al=0}else{al=~~(+(X|0)*+h[Y+304>>3])}if((ak&2|0)==0){am=0}else{am=~~(+(X|0)*+h[Y+304>>3])}if((al|0)<-32768){an=-32768}else{an=(al|0)>32767?32767:al}if((am|0)<-32768){ao=-32768}else{ao=(am|0)>32767?32767:am}b[E>>1]=(e[E>>1]|0)+an&65535;Y=E+2|0;b[Y>>1]=(e[Y>>1]|0)+ao&65535;if((a|0)>=(f|0)){break}E=E+4|0;a=a+1|0;F=U;I=_;J=ac;K=ah;L=ai;M=ad;N=$;O=V;P=aj;Q=ae;R=aa;S=W}ap=V;aq=c[2420428]|0;ar=W;as=U;at=$;au=aa;av=_;aw=ad;ax=ae;ay=ac;az=ai;aA=aj;aB=ah}else{ap=g;aq=9668600;ar=i;as=l;at=m;au=n;av=q;aw=r;ax=s;ay=v;az=w;aA=x;aB=A}c[aq+148>>2]=ap;c[(c[2420428]|0)+152>>2]=ar;c[(c[2420428]|0)+172>>2]=as;c[(c[2420428]|0)+188>>2]=at;c[(c[2420428]|0)+192>>2]=au;c[(c[2420428]|0)+212>>2]=av;c[(c[2420428]|0)+228>>2]=aw;c[(c[2420428]|0)+232>>2]=ax;c[(c[2420428]|0)+252>>2]=ay;c[(c[2420428]|0)+268>>2]=az;c[(c[2420428]|0)+272>>2]=aA;c[(c[2420428]|0)+292>>2]=aB;return}function T2(b){b=b|0;var e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=gGU(b,(b|0)<0|0?-1:0,2048e6,0)|0;b=c[2438226]|0;f=gGS(e,K,b,(b|0)<0|0?-1:0)|0;e=f;c[2443836]=e;if((c[3528510]|0)<(e|0)){g=0;i=e;j=b}else{return}while(1){b=c[2443828]|0;e=c[2443829]|0;f=(b|0)>(e|0)?e:b;b=((f|0)>(i|0)?i:f)+(c[2443844]|0)|0;f=gGU(b,(b|0)<0|0?-1:0,j,(j|0)<0|0?-1:0)|0;b=gGS(f,K,2048e6,0)|0;f=c[2406674]|0;e=b-(gD[c[2433524]&8191]()|0)|0;gj[f&4095](e)|0;e=(gD[c[2433524]&8191]()|0)+1|0;f=gGU(e,(e|0)<0|0?-1:0,2048e6,0)|0;e=c[2438226]|0;b=gGS(f,K,e,(e|0)<0|0?-1:0)|0;e=gGK(b,K,-1,0)|0;b=e;c[3528510]=b;e=c[2443828]|0;if((b|0)<(e|0)){k=0}else{f=c[2443820]|0;c[2443828]=(f|0)==1073676288?1073676288:f+e|0;k=1}e=c[2443829]|0;if((b|0)<(e|0)){l=k}else{b=c[2443821]|0;c[2443829]=(b|0)==1073676288?1073676288:b+e|0;l=k|2}if((l&1|0)==0){m=g}else{m=ly(c[3540988]|0,0)|0|g}if((l&2|0)==0){n=m}else{e=c[3540988]|0;b=e+5886|0;f=a[b]|0;o=f&255;p=o|32;a[b]=p&255;do{if((o&128|0)==0){if(((d[e+5887|0]|0)&p|0)==0){break}a[b]=f|-96;q=c[e+5868>>2]|0;if((q|0)==0){break}gg[q&4095](c[e+5872>>2]|0,1)}}while(0);f=c[e+5860>>2]|0;if((f|0)!=0){gd[f&15]((c[e+5864>>2]|0)+1|0,+(c[e+5820>>2]|0)*+h[e+5912>>3])}n=(d[b]|0)>>>7|m}f=c[2443836]|0;if((c[3528510]|0)>=(f|0)){break}g=n;i=f;j=c[2438226]|0}return}function T3(a,b){a=a|0;b=+b;var d=0,e=0,f=0;gu[c[3528470]&16383]();if(b==0.0){c[9775312+(a<<2)>>2]=1073676288;return}else{d=9775312+(a<<2)|0;c[d>>2]=~~(b*2048.0e6);a=gD[c[2433524]&8191]()|0;e=gGU(a,(a|0)<0|0?-1:0,2048e6,0)|0;a=c[2438226]|0;f=gGS(e,K,a,(a|0)<0|0?-1:0)|0;a=gGK(c[d>>2]|0,0,f,K)|0;c[d>>2]=a;return}}function T4(){return c[2113158]|0}function T5(a,b){a=a|0;b=b|0;var d=0;b=gj[c[2427056]&4095](c[2429616]|0)|0;a=c[2438128]|0;if((a|0)>=(b|0)){return}d=b-a|0;lF(0,(c[2406696]|0)+(a+4<<1)|0,d);if((c[2385514]|0)>1){lF(1,(c[2406696]|0)+((c[2438128]|0)+4100<<1)|0,d)}c[2438128]=(c[2438128]|0)+d;return}function T6(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a=c[3531860]|0;if((a|0)>0){b=0;d=a;while(1){a=14163952+(b<<2)|0;e=c[a>>2]|0;f=c[2113006]|0;if((f|0)==0){g=45157}else{h=f-1|0;c[2113006]=h;if((h|0)==0){g=45157}}if((g|0)==45157){g=0;c[2383474]=0}if((e|0)==0){i=d}else{gGr(e);i=c[3531860]|0}c[a>>2]=0;a=b+1|0;if((a|0)<(i|0)){b=a;d=i}else{break}}}c[3531860]=0;c[2438226]=0;c[2433524]=0;c[2406674]=0;c[3528470]=0;i=c[2406696]|0;d=0;while(1){if((d|0)>=1024){g=45166;break}j=9638528+(d<<2)|0;if((c[j>>2]|0)==(i|0)){break}else{d=d+1|0}}if((g|0)==45166){c[2406696]=0;c[2385514]=0;c[2436764]=0;return}gGr(i);c[j>>2]=0;c[2406696]=0;c[2385514]=0;c[2436764]=0;return}function T7(b,d,e,f,g,i,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;c[2438226]=0;c[2433524]=0;c[2406674]=0;c[3528470]=0;c[2443829]=1073676288;c[2443828]=1073676288;c[2443821]=1073676288;c[2443820]=1073676288;h[920261]=0.0;c[3528510]=0;k=a[9680]|0;l=k?32e3:0;if(!k){c[2427056]=2450;c[3542190]=1272;if((c[3531860]|0)!=0){return}c[3531860]=b;if((b|0)>0){m=0}else{return}while(1){k=lv(14,3579545,11025)|0;n=14163952+(m<<2)|0;c[n>>2]=k;if((k|0)==0){break}c[(c[k+5828>>2]|0)+88>>2]=2090;c[(c[(c[n>>2]|0)+5828>>2]|0)+92>>2]=1230;a[(c[(c[n>>2]|0)+5828>>2]|0)+96|0]=m&255;a[(c[(c[n>>2]|0)+5828>>2]|0)+97|0]=16;a[(c[(c[n>>2]|0)+5828>>2]|0)+98|0]=8;lw(c[n>>2]|0);n=m+1|0;if((n|0)<(c[3531860]|0)){m=n}else{o=45195;break}}if((o|0)==45195){return}c[3531860]=0;return}c[2427056]=i;if(a[9624]|0){i=l*3|0;m=49715;while(1){if((m|0)>(i|0)){m=m>>1}else{break}}c[2429616]=m;c[3542190]=2404;c[2443888]=(m<<16>>>0)/32e3|0;c[2429612]=0;p=m}else{c[2429616]=l;c[3542190]=3012;p=l}L58273:do{if((c[3531860]|0)==0){c[3531860]=b;if((b|0)>0){q=0}else{break}while(1){l=lv(14,3579545,p)|0;m=14163952+(q<<2)|0;c[m>>2]=l;if((l|0)==0){break}c[(c[l+5828>>2]|0)+88>>2]=2090;c[(c[(c[m>>2]|0)+5828>>2]|0)+92>>2]=1230;a[(c[(c[m>>2]|0)+5828>>2]|0)+96|0]=q&255;a[(c[(c[m>>2]|0)+5828>>2]|0)+97|0]=16;a[(c[(c[m>>2]|0)+5828>>2]|0)+98|0]=8;lw(c[m>>2]|0);q=q+1|0;if((q|0)>=(c[3531860]|0)){break L58273}}c[3531860]=0}}while(0);q=c[3540988]|0;c[q+5868>>2]=0;c[q+5872>>2]=0;q=c[3540988]|0;c[q+5860>>2]=8;c[q+5864>>2]=0;q=c[3540988]|0;c[q+5876>>2]=1452;c[q+5880>>2]=0;q=(c[3540988]|0)+5828|0;c[c[q>>2]>>2]=d;c[(c[q>>2]|0)+24>>2]=e;if((b|0)>1){e=c[3540989]|0;c[e+5860>>2]=8;c[e+5864>>2]=0;e=c[3540989]|0;c[e+5876>>2]=1452;c[e+5880>>2]=0;e=(c[3540989]|0)+5828|0;c[c[e>>2]>>2]=f;c[(c[e>>2]|0)+24>>2]=g;r=1}else{r=0}g=b<<13;e=0;while(1){if((e|0)>=1024){s=0;break}t=9638528+(e<<2)|0;if((c[t>>2]|0)==0){o=45189;break}else{e=e+1|0}}do{if((o|0)==45189){e=gGq(g)|0;c[t>>2]=e;if((e|0)==0){s=0;break}gGz(e|0,0,g|0);s=e}}while(0);c[2406696]=s;gGz(s|0,0,g|0);c[2438128]=0;c[2429612]=0;c[2385514]=b;c[2436764]=j;h[826309]=1.0;c[2438350]=3;if(!r){return}h[826308]=1.0;c[2438348]=3;return}function T8(a){a=a|0;return 0}function T9(a,b){a=a|0;b=b|0;return}function Ua(d,f){d=d|0;f=f|0;var g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0.0,t=0,u=0,v=0.0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;g=((ag(c[2429616]|0,f)|0)/32e3|0)+1|0;i=c[2438128]|0;j=(g|0)<(i|0)?i:g;g=a[9688]|0?534:0;k=((g|0)<(f|0)?g:f)<<1;if((i|0)<(j|0)){g=j-i|0;lF(0,(c[2406696]|0)+(i+4<<1)|0,g);if((c[2385514]|0)>1){lF(1,(c[2406696]|0)+((c[2438128]|0)+4100<<1)|0,g)}c[2438128]=(c[2438128]|0)+g}g=c[2406696]|0;c[2440374]=g+8;i=(c[2385514]|0)>1;if(i){c[2440375]=g+8200}l=c[2429612]|0;m=l>>>15&131070;if((m|0)<(k|0)){n=c[2438350]|0;o=(n&1|0)==0;p=(n&2|0)==0;n=c[2438348]|0;q=(n&1|0)==0;r=(n&2|0)==0;n=c[2440375]|0;s=+h[826308];t=(c[2436764]|0)==0;u=c[2443888]|0;v=+h[826309];w=m;m=l;do{if(o){x=0;y=0;z=0;A=0}else{B=m>>16;x=~~(+(b[g+(B+1<<1)>>1]|0)*v);y=~~(v*+(b[g+(B+2<<1)>>1]|0));z=~~(v*+(b[g+(B+3<<1)>>1]|0));A=~~(v*+(b[g+(B+4<<1)>>1]|0))}if(p){C=0;D=0;E=0;F=0}else{B=m>>16;C=~~(+(b[g+(B+1<<1)>>1]|0)*v);D=~~(v*+(b[g+(B+2<<1)>>1]|0));E=~~(v*+(b[g+(B+3<<1)>>1]|0));F=~~(v*+(b[g+(B+4<<1)>>1]|0))}do{if(i){if(q){G=x;H=y;I=z;J=A}else{B=m>>16;G=~~(+(b[n+(B-3<<1)>>1]|0)*s)+x|0;H=~~(s*+(b[n+(B-2<<1)>>1]|0))+y|0;I=~~(s*+(b[n+(B-1<<1)>>1]|0))+z|0;J=~~(s*+(b[n+(B<<1)>>1]|0))+A|0}if(r){K=C;L=D;M=E;N=F;O=G;P=H;Q=I;R=J;break}B=m>>16;K=~~(+(b[n+(B-3<<1)>>1]|0)*s)+C|0;L=~~(s*+(b[n+(B-2<<1)>>1]|0))+D|0;M=~~(s*+(b[n+(B-1<<1)>>1]|0))+E|0;N=~~(s*+(b[n+(B<<1)>>1]|0))+F|0;O=G;P=H;Q=I;R=J}else{K=C;L=D;M=E;N=F;O=x;P=y;Q=z;R=A}}while(0);B=m>>>4<<2&16380;S=b[14130680+(B<<1)>>1]|0;T=ag(S,O)|0;U=b[14130680+((B|1)<<1)>>1]|0;V=(ag(U,P)|0)+T|0;T=b[14130680+((B|2)<<1)>>1]|0;W=V+(ag(T,Q)|0)|0;V=b[14130680+((B|3)<<1)>>1]|0;B=W+(ag(V,R)|0)|0;W=(B|0)/16384|0;X=ag(S,K)|0;S=(ag(U,L)|0)+X|0;X=S+(ag(T,M)|0)|0;T=X+(ag(V,N)|0)|0;V=(T|0)/16384|0;if((B|0)<-536887295){Y=-32768}else{Y=(W|0)>32767?32767:W}if((T|0)<-536887295){Z=-32768}else{Z=(V|0)>32767?32767:V}if(t){b[d+(w<<1)>>1]=Y&65535;b[d+((w|1)<<1)>>1]=Z&65535}else{V=d+(w<<1)|0;b[V>>1]=(e[V>>1]|0)+Y&65535;V=d+((w|1)<<1)|0;b[V>>1]=(e[V>>1]|0)+Z&65535}w=w+2|0;m=m+u|0;}while((w|0)<(k|0));c[2429612]=m;_=m}else{_=l}if(((a[9688]|0?534:0)|0)>(f|0)){return}f=_>>16;l=j-f|0;if((l|0)>-4){j=c[2440375]|0;m=-4;do{k=f+m|0;b[g+(m+4<<1)>>1]=b[g+(k+4<<1)>>1]|0;if(i){b[j+(m<<1)>>1]=b[j+(k<<1)>>1]|0}m=m+1|0;}while((m|0)<(l|0))}c[2429612]=_&65535;c[2438128]=l;return}function Ub(d,f){d=d|0;f=f|0;var g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0.0,r=0,s=0.0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;g=c[2438128]|0;i=(g|0)>(f|0)?g:f;j=a[9688]|0?534:0;k=(j|0)<(f|0)?j:f;if((g|0)<(i|0)){f=i-g|0;lF(0,(c[2406696]|0)+(g+4<<1)|0,f);if((c[2385514]|0)>1){lF(1,(c[2406696]|0)+((c[2438128]|0)+4100<<1)|0,f)}c[2438128]=(c[2438128]|0)+f}f=c[2406696]|0;c[2440374]=f+8;g=(c[2385514]|0)>1;if(g){c[2440375]=f+8200}j=c[2429612]|0;if((j|0)<(k|0)){l=c[2438350]|0;m=(l&1|0)==0;n=(l&2|0)==0;l=c[2438348]|0;o=(l&1|0)==0;p=(l&2|0)==0;l=c[2440375]|0;q=+h[826308];r=(c[2436764]|0)==0;s=+h[826309];t=j;do{if(m){u=0}else{u=~~(+(b[f+(t+4<<1)>>1]|0)*s)}if(n){v=0}else{v=~~(+(b[f+(t+4<<1)>>1]|0)*s)}do{if(g){if(o){w=u}else{w=~~(+(b[l+(t<<1)>>1]|0)*q)+u|0}if(p){x=v;y=w;break}x=~~(+(b[l+(t<<1)>>1]|0)*q)+v|0;y=w}else{x=v;y=u}}while(0);if((y|0)<-32768){z=-32768}else{z=(y|0)>32767?32767:y}if((x|0)<-32768){A=-32768}else{A=(x|0)>32767?32767:x}if(r){j=t<<1;b[d+(j<<1)>>1]=z&65535;b[d+((j|1)<<1)>>1]=A&65535}else{j=t<<1;B=d+(j<<1)|0;b[B>>1]=(e[B>>1]|0)+z&65535;B=d+((j|1)<<1)|0;b[B>>1]=(e[B>>1]|0)+A&65535}t=t+1|0;}while((t|0)<(k|0))}c[2429612]=k;k=a[9688]|0?534:0;if((i|0)<(k|0)){return}t=i-k|0;if((t|0)>0){i=0;do{c[9761496+(i<<2)>>2]=c[9761496+(i+k<<2)>>2];i=i+1|0;}while((i|0)<(t|0))}c[2429612]=0;c[2438128]=t;return}function Uc(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0;d=i;i=i+80|0;e=d|0;f=d+16|0;g=d+32|0;h=d+48|0;j=d+64|0;do{if((b|0)!=0){if((c[b>>2]|0)>=169249){break}c[b>>2]=169249}}while(0);if((a&64|0)==0){lG(3,a);i=d;return}else{gGz(j|0,0,12);c[j>>2]=9775312;c[j+4>>2]=8;c[j+12>>2]=111920;b=c[2076592]|0;gj[b&4095](j)|0;gGz(h|0,0,12);c[h>>2]=9775280;c[h+4>>2]=8;c[h+12>>2]=478936;j=c[2076592]|0;gj[j&4095](h)|0;gGz(g|0,0,12);c[g>>2]=7362088;c[g+4>>2]=8;c[g+12>>2]=380968;h=c[2076592]|0;gj[h&4095](g)|0;gGz(f|0,0,12);c[f>>2]=14114040;c[f+4>>2]=4;c[f+12>>2]=287368;g=c[2076592]|0;gj[g&4095](f)|0;lG(3,a);gGz(e|0,0,12);c[e>>2]=9752512;c[e+4>>2]=4;c[e+12>>2]=225896;a=c[2076592]|0;gj[a&4095](e)|0;i=d;return}}function Ud(d,f){d=d|0;f=f|0;var g=0.0,i=0,j=0.0,k=0,l=0,m=0,n=0,o=0.0,p=0,q=0,r=0,s=0,t=0;c[2420382]=9674032;g=+h[1209290];gGz(c[2418585]|0,0,f<<1|0);i=(f|0)>0;do{if(i){j=+((c[2443780]|0)>>>0>>>0);k=0;do{l=c[9674044+(k*56|0)>>2]|0;m=c[9674040+(k*56|0)>>2]|0;if(!((m|0)<9|(l|0)==0|(c[9674048+(k*56|0)>>2]|0)==0)){n=9674032+(k*56|0)|0;o=+((m<<4)+16|0);m=0;p=c[2418585]|0;q=c[n>>2]|0;while(1){r=~~(+(c[2418578]|0)/o*65536.0/+((c[2418579]|0)/32|0|0)*j*30517578125.0e-15)+q|0;s=(ag(a[(r>>>16&31)+(9674052+(k*56|0))|0]|0,l)|0)>>>3;b[p>>1]=s+(e[p>>1]|0)&65535;s=m+1|0;if((s|0)<(f|0)){m=s;p=p+2|0;q=r}else{break}}c[n>>2]=r;c[n+4>>2]=(r|0)<0|0?-1:0}k=k+1|0;}while((k|0)<5)}else{if(!((c[2418510]|0)<9|(c[2418511]|0)==0|(c[2418512]|0)==0)){k=c[2418508]|0;q=9674032;c[q>>2]=k;c[q+4>>2]=(k|0)<0|0?-1:0}if(!((c[2418524]|0)<9|(c[2418525]|0)==0|(c[2418526]|0)==0)){k=c[2418522]|0;q=9674088;c[q>>2]=k;c[q+4>>2]=(k|0)<0|0?-1:0}if(!((c[2418538]|0)<9|(c[2418539]|0)==0|(c[2418540]|0)==0)){k=c[2418536]|0;q=9674144;c[q>>2]=k;c[q+4>>2]=(k|0)<0|0?-1:0}if(!((c[2418552]|0)<9|(c[2418553]|0)==0|(c[2418554]|0)==0)){k=c[2418550]|0;q=9674200;c[q>>2]=k;c[q+4>>2]=(k|0)<0|0?-1:0}if((c[2418566]|0)<9|(c[2418567]|0)==0|(c[2418568]|0)==0){break}k=c[2418564]|0;q=9674256;c[q>>2]=k;c[q+4>>2]=(k|0)<0|0?-1:0}}while(0);if(!i){return}i=0;r=c[2418585]|0;k=d;while(1){d=~~(g*+(b[(c[2418584]|0)+(b[r>>1]<<1)>>1]|0));if((d|0)<-32768){t=-32768}else{t=(d|0)>32767?32767:d}d=c[2418582]|0;b[k>>1]=((d&1|0)==0?0:t)+(e[k>>1]|0)&65535;q=k+2|0;b[q>>1]=(e[q>>1]|0)+((d&2|0)==0?0:t)&65535;d=i+1|0;if((d|0)<(f|0)){i=d;r=r+2|0;k=k+4|0}else{break}}return}function Ue(){var a=0,b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0;a=i;i=i+128|0;b=a|0;d=a+16|0;e=a+32|0;f=a+48|0;g=a+64|0;j=a+80|0;k=a+96|0;l=a+112|0;gGz(l|0,0,12);c[l>>2]=8452040;c[l+4>>2]=4;c[l+12>>2]=143648;gj[c[2076592]&4095](l)|0;gGz(k|0,0,12);c[k>>2]=8452048;c[k+4>>2]=4;c[k+12>>2]=493272;gj[c[2076592]&4095](k)|0;gGz(j|0,0,12);c[j>>2]=9753304;c[j+4>>2]=1;c[j+12>>2]=379072;gj[c[2076592]&4095](j)|0;gGz(g|0,0,12);c[g>>2]=9722016;c[g+4>>2]=1;c[g+12>>2]=294904;gj[c[2076592]&4095](g)|0;gGz(f|0,0,12);c[f>>2]=9734128;c[f+4>>2]=4;c[f+12>>2]=224672;gj[c[2076592]&4095](f)|0;gGz(e|0,0,12);c[e>>2]=9721608;c[e+4>>2]=4;c[e+12>>2]=175768;gj[c[2076592]&4095](e)|0;gGz(d|0,0,12);c[d>>2]=9734208;c[d+4>>2]=4;c[d+12>>2]=141328;gj[c[2076592]&4095](d)|0;d=b;e=b|0;f=b+4|0;g=b+12|0;j=0;do{gGz(d|0,0,12);c[e>>2]=14125184+(j*84|0);c[f>>2]=84;c[g>>2]=113896;gj[c[2076592]&4095](b)|0;c[14125204+(j*84|0)>>2]=~~(+h[130017]*+((c[14125192+(j*84|0)>>2]|0)+1|0)*512.0/+((c[2429850]|0)*3|0|0));j=j+1|0;}while((j|0)<8);i=a;return}function Uf(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,i=0,j=0,k=0;h[130017]=+(b|0);b=a[9680]|0?32e3:11025;c[2429850]=b;e=0;do{f=e<<1&14|1;c[9723128+(e<<2)>>2]=(e&8|0)==0?f:-f|0;e=e+1|0;}while((e|0)<16);c[2409624]=-15;c[3531294]=d;d=c[2406694]|0;if((d|0)==0){g=b}else{gGr(d);c[2406694]=0;g=c[2429850]|0}c[2406694]=gGq(g<<3)|0;g=gGq(16384)|0;c[2430036]=g;d=gGq(16384)|0;c[2430037]=d;b=gGq(16384)|0;c[2430038]=b;e=gGq(16384)|0;c[2430039]=e;f=gGq(16384)|0;c[2430040]=f;i=gGq(16384)|0;c[2430041]=i;j=gGq(16384)|0;c[2430042]=j;k=gGq(16384)|0;c[2430043]=k;h[607287]=1.0;h[607286]=1.0;c[2433116]=1;c[2433114]=2;gGz(14125184,0,668);c[2433532]=0;c[2430402]=0;c[2113010]=0;a[9753304]=0;c[2433552]=0;gGz(g|0,0,16384);c[3531316]=4;gGz(d|0,0,16384);c[3531337]=4;gGz(b|0,0,16384);c[3531358]=4;gGz(e|0,0,16384);c[3531379]=4;gGz(f|0,0,16384);c[3531400]=4;gGz(i|0,0,16384);c[3531421]=4;gGz(j|0,0,16384);c[3531442]=4;gGz(k|0,0,16384);c[3531463]=4;return}function Ug(d,e){d=d|0;e=e|0;var f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0.0,X=0.0,Y=0,Z=0,_=0,$=0,aa=0,ab=0;f=c[2406694]|0;gGz(f|0,0,e<<3|0);c[2438230]=0;g=e-1|0;i=(e|0)==0;j=0;k=f;while(1){c[2409626]=e;c[2426464]=k;f=14125184+(j*84|0)|0;c[3526942]=f;L58452:do{if((a[14125185+(j*84|0)|0]&1)==0){Uh()}else{l=(a[f|0]&1)!=0;if(a[9608]|0){do{if(l){if((a[14125186+(j*84|0)|0]&1)==0){break}c[2409626]=g;if(i){break L58452}m=f;n=g;o=j;p=c[14125212+(j*84|0)>>2]|0;while(1){if((p|0)>16777215){q=m;r=o;do{s=q+24|0;t=c[s>>2]|0;do{if(t>>>0<(c[q+52>>2]|0)>>>0){if((t|0)!=(c[q+48>>2]|0)){break}c[q+36>>2]=c[q+32>>2];c[q+16>>2]=c[q+12>>2]}else{c[q+32>>2]=c[q+36>>2];c[q+12>>2]=c[q+16>>2];c[s>>2]=c[q+48>>2]}}while(0);gu[c[6589288+(c[14125188+(r*84|0)>>2]<<2)>>2]&16383]();q=c[3526942]|0;s=q+28|0;c[s>>2]=(c[s>>2]|0)-16777216;t=c[q+12>>2]|0;u=q+80|0;v=c[u>>2]|0;c[u>>2]=v+1;r=c[2438230]|0;c[(c[9720144+(r<<2)>>2]|0)+(v<<2)>>2]=t;}while((c[s>>2]|0)>16777215);w=q;x=c[2409626]|0;y=r}else{w=m;x=n;y=o}Uj();s=w+28|0;t=(c[s>>2]|0)+(c[w+20>>2]|0)|0;c[s>>2]=t;s=x-1|0;c[2409626]=s;if((x|0)==0){break L58452}else{m=w;n=s;o=y;p=t}}}}while(0);c[2409626]=g;if(i){break}p=f;o=g;n=j;m=c[14125212+(j*84|0)>>2]|0;L58475:while(1){if((m|0)>16777215){z=p;A=n;while(1){if((c[z+24>>2]|0)>>>0>=(c[z+44>>2]|0)>>>0){break L58475}gu[c[6589288+(c[14125188+(A*84|0)>>2]<<2)>>2]&16383]();B=c[3526942]|0;t=B+28|0;c[t>>2]=(c[t>>2]|0)-16777216;s=c[B+12>>2]|0;v=B+80|0;u=c[v>>2]|0;c[v>>2]=u+1;C=c[2438230]|0;c[(c[9720144+(C<<2)>>2]|0)+(u<<2)>>2]=s;if((c[t>>2]|0)>16777215){z=B;A=C}else{break}}D=B;E=c[2409626]|0;F=C}else{D=p;E=o;F=n}Uj();t=D+28|0;s=(c[t>>2]|0)+(c[D+20>>2]|0)|0;c[t>>2]=s;t=E-1|0;c[2409626]=t;if((E|0)==0){break L58452}else{p=D;o=t;n=F;m=s}}a[z+1|0]=0;Uh();m=c[2113010]|1<<A;c[2113010]=m;c[2430402]=0;do{if((a[9722016]&1)==0){G=0}else{if((c[2433532]&m|0)==0){G=0;break}c[2430402]=1;G=1}}while(0);m=c[3531294]|0;if((m|0)==0){break}gf[m&2047](G);break}do{if(l){if((a[14125186+(j*84|0)|0]&1)==0){break}c[2409626]=g;if(i){break L58452}m=f;n=k;o=g;p=c[14125212+(j*84|0)>>2]|0;while(1){s=c[m+72>>2]|0;if((p|0)>16777215){c[m+76>>2]=s;t=m;do{u=t+24|0;v=c[u>>2]|0;do{if((v|0)==(c[t+52>>2]|0)){c[t+32>>2]=c[t+36>>2];c[t+12>>2]=c[t+16>>2];c[u>>2]=c[t+48>>2]}else{if((v|0)!=(c[t+48>>2]|0)){break}c[t+36>>2]=c[t+32>>2];c[t+16>>2]=c[t+12>>2]}}while(0);gu[c[6589288+(c[14125188+((c[2438230]|0)*84|0)>>2]<<2)>>2]&16383]();t=c[3526942]|0;v=t+28|0;H=(c[v>>2]|0)-16777216|0;c[v>>2]=H;}while((H|0)>16777215);r=c[t+12>>2]|0;c[t+72>>2]=r;I=t;J=H;K=c[2426464]|0;L=c[2409626]|0;M=r}else{I=m;J=p;K=n;L=o;M=s}r=c[I+76>>2]|0;q=((ag(M-r|0,J>>12)|0)/4096|0)+r|0;c[2406712]=q;r=ag(c[I+60>>2]|0,q)|0;v=K+4|0;c[K>>2]=(c[K>>2]|0)+r;r=ag(c[I+64>>2]|0,q)|0;q=K+8|0;c[2426464]=q;c[v>>2]=(c[v>>2]|0)+r;r=I+28|0;v=(c[r>>2]|0)+(c[I+20>>2]|0)|0;c[r>>2]=v;r=L-1|0;c[2409626]=r;if((L|0)==0){break L58452}else{m=I;n=q;o=r;p=v}}}}while(0);c[2409626]=g;if(i){break}l=f;p=k;o=g;n=c[14125212+(j*84|0)>>2]|0;L58509:while(1){m=c[l+72>>2]|0;if((n|0)>16777215){c[l+76>>2]=m;N=l;while(1){if((c[N+24>>2]|0)>>>0>=(c[N+44>>2]|0)>>>0){break L58509}gu[c[6589288+(c[14125188+((c[2438230]|0)*84|0)>>2]<<2)>>2]&16383]();O=c[3526942]|0;v=O+28|0;P=(c[v>>2]|0)-16777216|0;c[v>>2]=P;if((P|0)>16777215){N=O}else{break}}v=c[O+12>>2]|0;c[O+72>>2]=v;Q=O;R=P;S=c[2426464]|0;T=c[2409626]|0;U=v}else{Q=l;R=n;S=p;T=o;U=m}v=c[Q+76>>2]|0;r=((ag(U-v|0,R>>12)|0)/4096|0)+v|0;c[2406712]=r;v=ag(c[Q+60>>2]|0,r)|0;q=S+4|0;c[S>>2]=(c[S>>2]|0)+v;v=ag(c[Q+64>>2]|0,r)|0;r=S+8|0;c[2426464]=r;c[q>>2]=(c[q>>2]|0)+v;v=Q+28|0;q=(c[v>>2]|0)+(c[Q+20>>2]|0)|0;c[v>>2]=q;v=T-1|0;c[2409626]=v;if((T|0)==0){break L58452}else{l=Q;p=r;o=v;n=q}}a[N+1|0]=0;Uh();n=c[2113010]|1<<c[2438230];c[2113010]=n;c[2430402]=0;do{if((a[9722016]&1)==0){V=0}else{if((c[2433532]&n|0)==0){V=0;break}c[2430402]=1;V=1}}while(0);n=c[3531294]|0;if((n|0)==0){break}gf[n&2047](V)}}while(0);f=(c[2438230]|0)+1|0;c[2438230]=f;if((f|0)>=8){break}j=f;k=c[2406694]|0}if((e|0)<=0){return}k=c[2433116]|0;j=(k&1|0)==0;V=(k&2|0)==0;k=c[2433114]|0;N=(k&1|0)==0;Q=(k&2|0)==0;k=c[2406694]|0;W=+h[607286];X=+h[607287];T=0;do{if(j){Y=0}else{Y=~~(X*+(c[k+(T<<1<<2)>>2]>>8|0))}if(V){Z=0}else{Z=~~(X*+(c[k+(T<<1<<2)>>2]>>8|0))}if(N){_=Y}else{_=~~(W*+(c[k+((T<<1|1)<<2)>>2]>>8|0))+Y|0}if(Q){$=Z}else{$=~~(W*+(c[k+((T<<1|1)<<2)>>2]>>8|0))+Z|0}if((_|0)<-32768){aa=-32768}else{aa=(_|0)>32767?32767:_&65535}S=T<<1;b[d+(S<<1)>>1]=aa;if(($|0)<-32768){ab=-32768}else{ab=($|0)>32767?32767:$&65535}b[d+((S|1)<<1)>>1]=ab;T=T+1|0;}while((T|0)<(e|0));return}function Uh(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;a=c[3526942]|0;b=a+12|0;d=c[b>>2]|0;if((d|0)==0){return}e=2091392/(c[2429850]|0)|0;if((d|0)>0){f=c[2409626]|0;g=f-1|0;c[2409626]=g;L58568:do{if((f|0)==0){h=d}else{i=a+60|0;j=a+64|0;k=g;l=d;while(1){if((l|0)<=(e|0)){h=l;break L58568}m=l-e|0;c[b>>2]=m;n=ag(c[i>>2]|0,m)|0;m=c[2426464]|0;o=m+4|0;c[m>>2]=(c[m>>2]|0)+n;n=ag(c[j>>2]|0,c[b>>2]|0)|0;c[2426464]=m+8;c[o>>2]=(c[o>>2]|0)+n;n=k-1|0;c[2409626]=n;o=c[b>>2]|0;if((k|0)==0){h=o;break}else{k=n;l=o}}}}while(0);if((h|0)>=(e|0)){return}c[b>>2]=0;return}else{h=-e|0;g=c[2409626]|0;f=g-1|0;c[2409626]=f;L58557:do{if((g|0)==0){p=d}else{l=a+60|0;k=a+64|0;j=f;i=d;while(1){if((i|0)>=(h|0)){p=i;break L58557}o=i+e|0;c[b>>2]=o;n=ag(c[l>>2]|0,o)|0;o=c[2426464]|0;m=o+4|0;c[o>>2]=(c[o>>2]|0)+n;n=ag(c[k>>2]|0,c[b>>2]|0)|0;c[2426464]=o+8;c[m>>2]=(c[m>>2]|0)+n;n=j-1|0;c[2409626]=n;m=c[b>>2]|0;if((j|0)==0){p=m;break}else{j=n;i=m}}}}while(0);if((p|0)<=(h|0)){return}c[b>>2]=0;return}}function Ui(b){b=b|0;var d=0,e=0,f=0,g=0;d=c[2113012]|0;if(d>>>0>=128){switch(d|0){case 255:{e=(b&255)>>>4&1;a[9722016]=e;c[2430402]=0;do{if(e<<24>>24==0){f=0}else{if((c[2433532]&c[2113010]|0)==0){f=0;break}c[2430402]=1;f=1}}while(0);e=c[3531294]|0;if((e|0)!=0){gf[e&2047](f)}f=b<<24>>24>-1;if((a[9753304]&1)!=0){if(!f){return}a[9753304]=0;a[14125185]=0;a[14125269]=0;a[14125353]=0;a[14125437]=0;a[14125521]=0;a[14125605]=0;a[14125689]=0;a[14125773]=0;return}if(f){return}a[9753304]=1;do{if((a[14125184]&1)!=0){if((a[14125186]&1)==0){break}a[14125185]=1}}while(0);do{if((a[14125268]&1)!=0){if((a[14125270]&1)==0){break}a[14125269]=1}}while(0);do{if((a[14125352]&1)!=0){if((a[14125354]&1)==0){break}a[14125353]=1}}while(0);do{if((a[14125436]&1)!=0){if((a[14125438]&1)==0){break}a[14125437]=1}}while(0);do{if((a[14125520]&1)!=0){if((a[14125522]&1)==0){break}a[14125521]=1}}while(0);do{if((a[14125604]&1)!=0){if((a[14125606]&1)==0){break}a[14125605]=1}}while(0);do{if((a[14125688]&1)!=0){if((a[14125690]&1)==0){break}a[14125689]=1}}while(0);if((a[14125772]&1)==0){return}if((a[14125774]&1)==0){return}a[14125773]=1;return};case 134:{c[2433552]=c[2433552]&16776960|b&255;return};case 254:{f=b&255;c[2433532]=f;c[2430402]=0;do{if((a[9722016]&1)==0){g=0}else{if((c[2113010]&f|0)==0){g=0;break}c[2430402]=1;g=1}}while(0);f=c[3531294]|0;if((f|0)==0){return}gf[f&2047](g);return};case 133:{c[2433552]=c[2433552]&16711935|(b&255)<<8;return};case 132:{c[2433552]=c[2433552]&65535|(b&255)<<16;return};default:{return}}}g=d>>>2&7;switch(d&99|0){case 3:{d=b&15;c[14125252+(g*84|0)>>2]=d;if((d|0)==8){f=c[14125240+(g*84|0)>>2]|0;c[14125244+(g*84|0)>>2]=f;c[14125248+(g*84|0)>>2]=f;return}f=c[14125240+(g*84|0)>>2]|0;if(d>>>0<8){c[14125244+(g*84|0)>>2]=f;c[14125248+(g*84|0)>>2]=(ag(f,d)|0)/8|0;return}else{c[14125244+(g*84|0)>>2]=(ag(f,d^15)|0)/8|0;c[14125248+(g*84|0)>>2]=f;return}break};case 96:{f=14125224+(g*84|0)|0;c[f>>2]=c[f>>2]&33553920|(b&255)<<1;return};case 1:{f=14125192+(g*84|0)|0;d=b&255;e=c[f>>2]&255|d<<8&256;c[f>>2]=e;c[14125204+(g*84|0)>>2]=~~(+h[130017]*+(e+1|0)*512.0/+((c[2429850]|0)*3|0|0));e=(b&255)>>>4&1;a[14125186+(g*84|0)|0]=e;c[14125188+(g*84|0)>>2]=d>>>5&3;f=14125184+(g*84|0)|0;if((d&128|0)==0){a[f]=0;if(e<<24>>24!=0){return}a[14125185+(g*84|0)|0]=0;return}if((a[f]&1)!=0){return}a[f]=1;a[14125185+(g*84|0)|0]=1;c[14125208+(g*84|0)>>2]=c[14125224+(g*84|0)>>2];c[14125216+(g*84|0)>>2]=127;c[14125196+(g*84|0)>>2]=0;f=14125212+(g*84|0)|0;if(a[9608]|0){c[f>>2]=50331648;c[(c[9720144+(g<<2)>>2]|0)+12>>2]=0;c[14125264+(g*84|0)>>2]=1;return}else{c[f>>2]=0;c[14125260+(g*84|0)>>2]=0;c[14125256+(g*84|0)>>2]=0;return}break};case 64:{f=14125224+(g*84|0)|0;c[f>>2]=c[f>>2]&33423870|(b&255)<<9;return};case 33:{f=14125232+(g*84|0)|0;c[f>>2]=c[f>>2]&131070|(b&255)<<17;return};case 35:{f=14125228+(g*84|0)|0;c[f>>2]=c[f>>2]&131070|(b&255)<<17;return};case 32:{f=14125224+(g*84|0)|0;c[f>>2]=c[f>>2]&131070|(b&255)<<17;return};case 99:{f=14125228+(g*84|0)|0;c[f>>2]=c[f>>2]&33553920|(b&255)<<1;return};case 2:{f=b&255;c[14125240+(g*84|0)>>2]=f;e=c[14125252+(g*84|0)>>2]|0;if((e|0)==8){c[14125244+(g*84|0)>>2]=f;c[14125248+(g*84|0)>>2]=f;return}if((e|0)<8){c[14125244+(g*84|0)>>2]=f;c[14125248+(g*84|0)>>2]=(ag(e,f)|0)/8|0;return}else{c[14125244+(g*84|0)>>2]=(ag(15-e|0,f)|0)/8|0;c[14125248+(g*84|0)>>2]=f;return}break};case 65:{f=14125232+(g*84|0)|0;c[f>>2]=c[f>>2]&33423870|(b&255)<<9;return};case 66:{f=14125236+(g*84|0)|0;c[f>>2]=c[f>>2]&33423870|(b&255)<<9;return};case 34:{f=14125236+(g*84|0)|0;c[f>>2]=c[f>>2]&131070|(b&255)<<17;return};case 98:{f=14125236+(g*84|0)|0;c[f>>2]=c[f>>2]&33553920|(b&255)<<1;return};case 97:{f=14125232+(g*84|0)|0;c[f>>2]=c[f>>2]&33553920|(b&255)<<1;return};case 67:{f=14125228+(g*84|0)|0;c[f>>2]=c[f>>2]&33423870|(b&255)<<9;return};case 0:{f=14125192+(g*84|0)|0;e=c[f>>2]&256|b&255;c[f>>2]=e;c[14125204+(g*84|0)>>2]=~~(+h[130017]*+(e+1|0)*512.0/+((c[2429850]|0)*3|0|0));return};default:{return}}}function Uj(){var a=0,d=0,e=0,f=0,g=0,h=0;a=c[3526942]|0;d=a+80|0;e=c[d>>2]|0;if((e|0)>4080){f=c[9720144+(c[2438230]<<2)>>2]|0;c[f>>2]=c[f+(e-4<<2)>>2];c[f+4>>2]=c[f+((c[d>>2]|0)-3<<2)>>2];c[f+8>>2]=c[f+((c[d>>2]|0)-2<<2)>>2];c[f+12>>2]=c[f+((c[d>>2]|0)-1<<2)>>2];c[d>>2]=4;g=4;h=f}else{g=e;h=c[9720144+(c[2438230]<<2)>>2]|0}e=c[a+28>>2]>>12<<2;f=ag(b[14130680+(e<<1)>>1]|0,c[h+(g-4<<2)>>2]|0)|0;d=(ag(b[14130680+((e|1)<<1)>>1]|0,c[h+(g-3<<2)>>2]|0)|0)+f|0;f=d+(ag(b[14130680+((e|2)<<1)>>1]|0,c[h+(g-2<<2)>>2]|0)|0)|0;d=(f+(ag(b[14130680+((e|3)<<1)>>1]|0,c[h+(g-1<<2)>>2]|0)|0)|0)/16384|0;c[2406712]=d;g=ag(c[a+60>>2]|0,d)|0;h=c[2426464]|0;e=h+4|0;c[h>>2]=(c[h>>2]|0)+g;g=ag(c[a+64>>2]|0,d)|0;c[2426464]=h+8;c[e>>2]=(c[e>>2]|0)+g;return}function Uk(){c[(c[3526942]|0)+12>>2]=0;return}function Ul(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[3526942]|0;b=a+24|0;e=c[b>>2]|0;f=d[(c[3531292]|0)+(e>>>1)|0]|0;g=(e&1|0)==0?f>>>4:f&15;c[2409624]=g;f=a+12|0;h=c[f>>2]|0;i=a+32|0;a=c[i>>2]|0;j=((ag(c[9723128+(g<<2)>>2]|0,a)|0)/8|0)+h|0;c[2406712]=j;do{if((j|0)>32767){c[2406712]=32767;k=32767}else{if((j|0)>=-32768){k=j;break}c[2406712]=-32768;k=-32768}}while(0);c[f>>2]=k;k=ag(c[1632856+((g&7)<<2)>>2]|0,a)|0;c[i>>2]=(k|0)/256|0;if((k|0)>6291711){c[i>>2]=24576;l=e+1|0;c[b>>2]=l;return}if((k|0)>=32512){l=e+1|0;c[b>>2]=l;return}c[i>>2]=127;l=e+1|0;c[b>>2]=l;return}function Um(){var b=0,d=0,e=0,f=0;b=c[3526942]|0;d=b+24|0;e=c[d>>2]|0;f=a[(c[3531292]|0)+(e>>>1)|0]|0;c[2409624]=f&255;c[b+12>>2]=f<<24>>24<<8;c[d>>2]=e+2;return}function Un(){var a=0,b=0,e=0,f=0,g=0,h=0;a=c[3526942]|0;b=a+24|0;e=c[b>>2]|0;f=e>>>1;g=c[3531292]|0;h=((d[g+(f+1)|0]|0)<<8|(d[g+f|0]|0))<<16>>16;c[2409624]=h;c[a+12>>2]=h;c[b>>2]=e+4;return}function Uo(b,d,e,f,g,i){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;i=i|0;var j=0,k=0;j=(b|0)>2?2:b;c[2438228]=0;c[2433526]=0;c[2406676]=0;c[3528472]=0;c[2429844]=5480;c[2429842]=(g|0)!=0?g:80;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;g=a[9680]|0;b=g?32e3:0;if(!g){c[2427014]=2546;c[3542116]=3004;mb(j,d,11025,e);return}c[2427014]=f;if(a[9624]|0){f=b*3|0;g=(d|0)/144|0;while(1){if((g|0)>(f|0)){g=g>>1}else{break}}c[2429372]=g;c[3542116]=2136;c[2443886]=(g<<16>>>0)/32e3|0;k=g}else{c[2429372]=b;c[3542116]=3214;k=b}mb(j,d,k,e);e=j<<14;k=gGq(e)|0;c[2406692]=k;gGz(k|0,0,e|0);c[2433538]=0;c[2429610]=0;c[2385512]=j;c[2432976]=i;h[745403]=1.0;h[745402]=1.0;c[2436782]=1;c[2436780]=2;if((j|0)<=0){return}h[745401]=1.0;h[745400]=1.0;c[2436778]=1;c[2436776]=2;return}function Up(a){a=a|0;return 0}function Uq(a,b){a=a|0;b=b|0;return}function Ur(d,f){d=d|0;f=f|0;var g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0.0,y=0,z=0.0,A=0,B=0,C=0.0,D=0.0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0;g=((ag(c[2429372]|0,f)|0)/32e3|0)+1|0;i=c[2433538]|0;j=(g|0)<(i|0)?i:g;g=a[9688]|0?534:0;k=((g|0)<(f|0)?g:f)<<1;if((i|0)<(j|0)){l=j-i|0;m=c[2406692]|0;n=m+(i+4<<1)|0;c[2438942]=n;o=m+(i+4100<<1)|0;c[2438943]=o;ma(0,n,o,l);o=c[2385512]|0;if((o|0)>1){n=c[2433538]|0;i=m+(n+8196<<1)|0;c[2438944]=i;p=m+(n+12292<<1)|0;c[2438945]=p;ma(1,i,p,l)}c[2433538]=(c[2433538]|0)+l;q=m;r=o}else{q=c[2406692]|0;r=c[2385512]|0}c[2438942]=q+8;c[2438943]=q+8200;o=(r|0)>1;if(o){c[2438944]=q+16392;c[2438945]=q+24584}r=c[2429610]|0;m=r>>>15&131070;if((m|0)<(k|0)){l=c[2436782]|0;p=(l&1|0)==0;i=(l&2|0)==0;l=c[2436780]|0;n=(l&1|0)==0;s=(l&2|0)==0;l=c[2436778]|0;t=(l&1|0)==0;u=(l&2|0)==0;l=c[2436776]|0;v=(l&1|0)==0;w=(l&2|0)==0;l=c[2438945]|0;x=+h[745400];y=c[2438944]|0;z=+h[745401];A=(c[2432976]|0)==0;B=c[2443886]|0;C=+h[745402];D=+h[745403];E=m;m=r;do{if(p){F=0;G=0;H=0;I=0}else{J=m>>16;F=~~(+(b[q+(J+1<<1)>>1]|0)*D);G=~~(D*+(b[q+(J+2<<1)>>1]|0));H=~~(D*+(b[q+(J+3<<1)>>1]|0));I=~~(D*+(b[q+(J+4<<1)>>1]|0))}if(i){K=0;L=0;M=0;N=0}else{J=m>>16;K=~~(+(b[q+(J+1<<1)>>1]|0)*D);L=~~(D*+(b[q+(J+2<<1)>>1]|0));M=~~(D*+(b[q+(J+3<<1)>>1]|0));N=~~(D*+(b[q+(J+4<<1)>>1]|0))}if(n){O=F;P=G;Q=H;R=I}else{J=m>>16;O=~~(+(b[q+(J+4097<<1)>>1]|0)*C)+F|0;P=~~(C*+(b[q+(J+4098<<1)>>1]|0))+G|0;Q=~~(C*+(b[q+(J+4099<<1)>>1]|0))+H|0;R=~~(C*+(b[q+(J+4100<<1)>>1]|0))+I|0}if(s){S=K;T=L;U=M;V=N}else{J=m>>16;S=~~(+(b[q+(J+4097<<1)>>1]|0)*C)+K|0;T=~~(C*+(b[q+(J+4098<<1)>>1]|0))+L|0;U=~~(C*+(b[q+(J+4099<<1)>>1]|0))+M|0;V=~~(C*+(b[q+(J+4100<<1)>>1]|0))+N|0}do{if(o){if(t){W=O;X=P;Y=Q;Z=R}else{J=m>>16;W=~~(+(b[y+(J-3<<1)>>1]|0)*z)+O|0;X=~~(z*+(b[y+(J-2<<1)>>1]|0))+P|0;Y=~~(z*+(b[y+(J-1<<1)>>1]|0))+Q|0;Z=~~(z*+(b[y+(J<<1)>>1]|0))+R|0}if(u){_=S;$=T;aa=U;ab=V}else{J=m>>16;_=~~(+(b[y+(J-3<<1)>>1]|0)*z)+S|0;$=~~(z*+(b[y+(J-2<<1)>>1]|0))+T|0;aa=~~(z*+(b[y+(J-1<<1)>>1]|0))+U|0;ab=~~(z*+(b[y+(J<<1)>>1]|0))+V|0}if(v){ac=W;ad=X;ae=Y;af=Z}else{J=m>>16;ac=~~(+(b[l+(J-3<<1)>>1]|0)*x)+W|0;ad=~~(x*+(b[l+(J-2<<1)>>1]|0))+X|0;ae=~~(x*+(b[l+(J-1<<1)>>1]|0))+Y|0;af=~~(x*+(b[l+(J<<1)>>1]|0))+Z|0}if(w){ah=_;ai=$;aj=aa;ak=ab;al=ac;am=ad;an=ae;ao=af;break}J=m>>16;ah=~~(+(b[l+(J-3<<1)>>1]|0)*x)+_|0;ai=~~(x*+(b[l+(J-2<<1)>>1]|0))+$|0;aj=~~(x*+(b[l+(J-1<<1)>>1]|0))+aa|0;ak=~~(x*+(b[l+(J<<1)>>1]|0))+ab|0;al=ac;am=ad;an=ae;ao=af}else{ah=S;ai=T;aj=U;ak=V;al=O;am=P;an=Q;ao=R}}while(0);J=m>>>4<<2&16380;ap=b[14130680+(J<<1)>>1]|0;aq=ag(ap,al)|0;ar=b[14130680+((J|1)<<1)>>1]|0;as=(ag(ar,am)|0)+aq|0;aq=b[14130680+((J|2)<<1)>>1]|0;at=as+(ag(aq,an)|0)|0;as=b[14130680+((J|3)<<1)>>1]|0;J=at+(ag(as,ao)|0)|0;at=(J|0)/16384|0;au=ag(ap,ah)|0;ap=(ag(ar,ai)|0)+au|0;au=ap+(ag(aq,aj)|0)|0;aq=au+(ag(as,ak)|0)|0;as=(aq|0)/16384|0;if((J|0)<-536887295){av=-32768}else{av=(at|0)>32767?32767:at}if((aq|0)<-536887295){aw=-32768}else{aw=(as|0)>32767?32767:as}if(A){b[d+(E<<1)>>1]=av&65535;b[d+((E|1)<<1)>>1]=aw&65535}else{as=d+(E<<1)|0;b[as>>1]=(e[as>>1]|0)+av&65535;as=d+((E|1)<<1)|0;b[as>>1]=(e[as>>1]|0)+aw&65535}E=E+2|0;m=m+B|0;}while((E|0)<(k|0));c[2429610]=m;ax=m}else{ax=r}if((g|0)>(f|0)){return}f=ax>>16;g=j-f|0;if((g|0)>-4){j=c[2438944]|0;r=c[2438945]|0;m=-4;do{k=f+m|0;b[q+(m+4<<1)>>1]=b[q+(k+4<<1)>>1]|0;b[q+(m+4100<<1)>>1]=b[q+(k+4100<<1)>>1]|0;if(o){b[j+(m<<1)>>1]=b[j+(k<<1)>>1]|0;b[r+(m<<1)>>1]=b[r+(k<<1)>>1]|0}m=m+1|0;}while((m|0)<(g|0))}c[2429610]=ax&65535;c[2433538]=g;h[6675]=100.0/+(c[2424]|0)+ +h[6675];return}function Us(d,f){d=d|0;f=f|0;var g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0.0,w=0,x=0.0,y=0,z=0.0,A=0.0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;g=c[2433538]|0;i=(g|0)>(f|0)?g:f;j=a[9688]|0?534:0;k=(j|0)<(f|0)?j:f;if((g|0)<(i|0)){f=i-g|0;l=c[2406692]|0;m=l+(g+4<<1)|0;c[2438942]=m;n=l+(g+4100<<1)|0;c[2438943]=n;ma(0,m,n,f);n=c[2385512]|0;if((n|0)>1){m=c[2433538]|0;g=l+(m+8196<<1)|0;c[2438944]=g;o=l+(m+12292<<1)|0;c[2438945]=o;ma(1,g,o,f)}c[2433538]=(c[2433538]|0)+f;p=l;q=n}else{p=c[2406692]|0;q=c[2385512]|0}c[2438942]=p+8;c[2438943]=p+8200;n=(q|0)>1;if(n){c[2438944]=p+16392;c[2438945]=p+24584}q=c[2429610]|0;if((q|0)<(k|0)){l=c[2436782]|0;f=(l&1|0)==0;o=(l&2|0)==0;l=c[2436780]|0;g=(l&1|0)==0;m=(l&2|0)==0;l=c[2436778]|0;r=(l&1|0)==0;s=(l&2|0)==0;l=c[2436776]|0;t=(l&1|0)==0;u=(l&2|0)==0;l=c[2438945]|0;v=+h[745400];w=c[2438944]|0;x=+h[745401];y=(c[2432976]|0)==0;z=+h[745402];A=+h[745403];B=q;do{if(f){C=0}else{C=~~(+(b[p+(B+4<<1)>>1]|0)*A)}if(o){D=0}else{D=~~(+(b[p+(B+4<<1)>>1]|0)*A)}if(g){E=C}else{E=~~(+(b[p+(B+4100<<1)>>1]|0)*z)+C|0}if(m){F=D}else{F=~~(+(b[p+(B+4100<<1)>>1]|0)*z)+D|0}do{if(n){if(r){G=E}else{G=~~(+(b[w+(B<<1)>>1]|0)*x)+E|0}if(s){H=F}else{H=~~(+(b[w+(B<<1)>>1]|0)*x)+F|0}if(t){I=G}else{I=~~(+(b[l+(B<<1)>>1]|0)*v)+G|0}if(u){J=H;K=I;break}J=~~(+(b[l+(B<<1)>>1]|0)*v)+H|0;K=I}else{J=F;K=E}}while(0);if((K|0)<-32768){L=-32768}else{L=(K|0)>32767?32767:K}if((J|0)<-32768){M=-32768}else{M=(J|0)>32767?32767:J}if(y){q=B<<1;b[d+(q<<1)>>1]=L&65535;b[d+((q|1)<<1)>>1]=M&65535}else{q=B<<1;N=d+(q<<1)|0;b[N>>1]=(e[N>>1]|0)+L&65535;N=d+((q|1)<<1)|0;b[N>>1]=(e[N>>1]|0)+M&65535}B=B+1|0;}while((B|0)<(k|0))}c[2429610]=k;if((i|0)<(j|0)){return}k=i-j|0;if((k|0)>0){i=c[2438944]|0;B=c[2438945]|0;M=0;do{d=M+j|0;b[p+(M+4<<1)>>1]=b[p+(d+4<<1)>>1]|0;b[p+(M+4100<<1)>>1]=b[p+(d+4100<<1)>>1]|0;if(n){b[i+(M<<1)>>1]=b[i+(d<<1)>>1]|0;b[B+(M<<1)>>1]=b[B+(d<<1)>>1]|0}M=M+1|0;}while((M|0)<(k|0))}c[2429610]=0;c[2433538]=k;h[6675]=100.0/+(c[2424]|0)+ +h[6675];return}function Ut(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=i;i=i+64|0;d=b|0;e=b+16|0;f=b+32|0;g=b+48|0;h=9628128+(a*156|0)|0;j=c[h>>2]|0;gGz(g|0,0,12);c[g>>2]=9628120+(a*156|0);c[g+4>>2]=156;c[g+12>>2]=138232;gj[c[2076592]&4095](g)|0;c[h>>2]=j;gGz(f|0,0,12);c[f>>2]=8452624+(a<<2);c[f+4>>2]=4;c[f+12>>2]=491608;gj[c[2076592]&4095](f)|0;f=e;j=e|0;h=e+4|0;g=e+12|0;k=d;l=d|0;m=d+4|0;n=d+12|0;o=0;p=c[3541206]|0;do{q=14164760+(a<<4)+(o<<2)|0;c[q>>2]=(c[q>>2]|0)+(-p|0);gGz(f|0,0,12);c[j>>2]=q;c[h>>2]=4;c[g>>2]=377304;gj[c[2076592]&4095](e)|0;r=c[3541206]|0;c[q>>2]=(c[q>>2]|0)+r;q=14164792+(a<<4)+(o<<2)|0;c[q>>2]=(c[q>>2]|0)+(-r|0);gGz(k|0,0,12);c[l>>2]=q;c[m>>2]=4;c[n>>2]=293664;gj[c[2076592]&4095](d)|0;p=c[3541206]|0;c[q>>2]=(c[q>>2]|0)+p;o=o+1|0;}while((o|0)<4);i=b;return}function Uu(e,f,g){e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0;h=c[2443770]|0;if((e|0)==0){i=g<<2;gGz(h|0,0,i|0);j=c[2440432]|0;gGz(j|0,0,i|0);k=j}else{k=c[2440432]|0}j=c[9628120+(e*156|0)>>2]|0;if(a[9608]|0){if((g|0)==0){return}i=9628132+(e*156|0)|0;l=8452624+(e<<2)|0;m=9628272+(e*156|0)|0;n=9628128+(e*156|0)|0;o=k;p=h;q=g;while(1){r=0;s=0;while(1){t=9628136+(e*156|0)+(r<<5)|0;u=c[i>>2]|0;v=1<<r;do{if((c[l>>2]&v|0)==0){w=t|0;x=c[w>>2]|0;if((x|0)==0){y=s;break}do{if((x|0)>0){if((x|0)>4194){z=x-4194|0;c[w>>2]=z;A=z;break}else{c[w>>2]=0;A=0;break}}else{if((x|0)<-4194){z=x+4194|0;c[w>>2]=z;A=z;break}else{c[w>>2]=0;A=0;break}}}while(0);y=((A|0)/16|0)+s|0}else{L58903:do{if((u|0)>4095){w=9628136+(e*156|0)+(r<<5)+12|0;x=9628136+(e*156|0)+(r<<5)+8|0;z=9628136+(e*156|0)+(r<<5)+24|0;B=9628136+(e*156|0)+(r<<5)+16|0;C=9628136+(e*156|0)+(r<<5)+20|0;D=9628136+(e*156|0)+(r<<5)+4|0;E=t|0;F=9628136+(e*156|0)+(r<<5)+28|0;G=9720472+(e<<4)+(r<<2)|0;H=u;while(1){I=c[w>>2]|0;c[w>>2]=I-1;if((I|0)<1){break}J=c[x>>2]|0;if((J&1|0)==0){K=d[(c[14164792+(e<<4)+(J>>17<<2)>>2]|0)+(J>>>1&65535)|0]|0;c[z>>2]=K;L=K>>>4}else{L=c[z>>2]&15}K=c[C>>2]|0;J=(c[9723544+((K<<4)+L<<2)>>2]|0)+(c[B>>2]|0)|0;if((J|0)>2047){M=2047}else{M=(J|0)<-2048?-2048:J}c[B>>2]=M;J=ag(c[D>>2]|0,M)|0;c[E>>2]=J;N=(c[7045224+((L&7)<<2)>>2]|0)+K|0;c[C>>2]=N;do{if((N|0)>48){c[C>>2]=48}else{if((N|0)>=0){break}c[C>>2]=0}}while(0);N=c[F>>2]|0;c[F>>2]=N+1;c[(c[G>>2]|0)+(N<<2)>>2]=(J|0)/16|0;c[x>>2]=(c[x>>2]|0)+1;N=H-4096|0;if((N|0)>4095){H=N}else{O=N;P=F;break L58903}}if((I|0)<0){c[l>>2]=c[l>>2]&~v}x=(c[E>>2]|0)/16|0;C=c[F>>2]|0;c[F>>2]=C+1;c[(c[G>>2]|0)+(C<<2)>>2]=x;O=H;P=F}else{O=u;P=9628136+(e*156|0)+(r<<5)+28|0}}while(0);x=c[P>>2]|0;if((x|0)>4080){C=9720472+(e<<4)+(r<<2)|0;D=c[C>>2]|0;c[D>>2]=c[D+(x-4<<2)>>2];D=c[C>>2]|0;c[D+4>>2]=c[D+((c[P>>2]|0)-3<<2)>>2];D=c[C>>2]|0;c[D+8>>2]=c[D+((c[P>>2]|0)-2<<2)>>2];D=c[C>>2]|0;c[D+12>>2]=c[D+((c[P>>2]|0)-1<<2)>>2];c[P>>2]=4;Q=4;R=C}else{Q=x;R=9720472+(e<<4)+(r<<2)|0}x=c[R>>2]|0;C=O<<2;D=ag(b[14130680+(C<<1)>>1]|0,c[x+(Q-4<<2)>>2]|0)|0;B=(ag(b[14130680+((C|1)<<1)>>1]|0,c[x+(Q-3<<2)>>2]|0)|0)+D|0;D=B+(ag(b[14130680+((C|2)<<1)>>1]|0,c[x+(Q-2<<2)>>2]|0)|0)|0;y=((D+(ag(b[14130680+((C|3)<<1)>>1]|0,c[x+(Q-1<<2)>>2]|0)|0)|0)/16384|0)+s|0}}while(0);u=r+1|0;if((u|0)<4){r=u;s=y}else{break}}s=q-1|0;r=ag(y,j)|0;u=c[m>>2]|0;if((u&1|0)==0){S=p;T=u}else{c[p>>2]=(c[p>>2]|0)+r;S=p+4|0;T=c[m>>2]|0}if((T&2|0)==0){U=o}else{c[o>>2]=(c[o>>2]|0)+r;U=o+4|0}c[i>>2]=(c[i>>2]&4095)+(c[n>>2]|0);if((s|0)==0){break}else{o=U;p=S;q=s}}}else{q=9628132+(e*156|0)|0;S=c[q>>2]|0;if((g|0)==0){V=S}else{p=9537264+(e<<2)|0;U=9537256+(e<<2)|0;o=8452624+(e<<2)|0;n=9628272+(e*156|0)|0;i=9628128+(e*156|0)|0;T=k;m=S;S=h;y=g;while(1){Q=y-1|0;if((m|0)>4095){O=c[p>>2]|0;c[U>>2]=O;R=m;P=c[o>>2]|0;while(1){l=0;I=P;L=0;while(1){M=1<<l;do{if((M&I|0)==0){W=I;X=L}else{A=9628136+(e*156|0)+(l<<5)+12|0;s=c[A>>2]|0;c[A>>2]=s-1;if((s|0)==0){s=I&~M;c[o>>2]=s;W=s;X=L;break}s=9628136+(e*156|0)+(l<<5)+8|0;A=c[s>>2]|0;if((A&1|0)==0){r=d[(c[14164792+(e<<4)+((A>>>17&3)<<2)>>2]|0)+(A>>>1&65535)|0]|0;c[9628136+(e*156|0)+(l<<5)+24>>2]=r;Y=r>>>4}else{Y=c[9628136+(e*156|0)+(l<<5)+24>>2]&15}r=9628136+(e*156|0)+(l<<5)+16|0;u=9628136+(e*156|0)+(l<<5)+20|0;v=c[u>>2]|0;t=(c[9723544+((v<<4)+Y<<2)>>2]|0)+(c[r>>2]|0)|0;if((t|0)>2047){Z=2047}else{Z=(t|0)<-2048?-2048:t}c[r>>2]=Z;r=ag(c[9628136+(e*156|0)+(l<<5)+4>>2]|0,Z)|0;c[9628136+(e*156|0)+(l<<5)>>2]=r;t=(c[7045224+((Y&7)<<2)>>2]|0)+v|0;c[u>>2]=t;do{if((t|0)>48){c[u>>2]=48}else{if((t|0)>=0){break}c[u>>2]=0}}while(0);c[s>>2]=A+1;W=I;X=((r|0)/16|0)+L|0}}while(0);M=l+1|0;if((M|0)<4){l=M;I=W;L=X}else{break}}L=R-4096|0;if((L|0)>4095){R=L;P=W}else{break}}c[p>>2]=X;_=m&4095;$=O;aa=X}else{_=m;$=c[U>>2]|0;aa=c[p>>2]|0}P=ag(((ag(aa-$|0,_)|0)>>12)+$|0,j)|0;R=c[n>>2]|0;if((R&1|0)==0){ab=S;ac=R}else{c[S>>2]=(c[S>>2]|0)+P;ab=S+4|0;ac=c[n>>2]|0}if((ac&2|0)==0){ad=T}else{c[T>>2]=(c[T>>2]|0)+P;ad=T+4|0}P=(c[i>>2]|0)+_|0;if((Q|0)==0){V=P;break}else{T=ad;m=P;S=ab;y=Q}}}c[q>>2]=V}if(!((c[2113184]|0)==(e|0)&(g|0)>0)){return}if((a[9698800]&1)==0){e=f;V=0;while(1){q=c[h+(V<<2)>>2]>>8;if((q|0)<-32768){ae=-32768}else{ae=(q|0)>32767?32767:q&65535}b[e>>1]=ae;q=c[k+(V<<2)>>2]>>8;if((q|0)<-32768){af=-32768}else{af=(q|0)>32767?32767:q&65535}b[e+2>>1]=af;q=V+1|0;if((q|0)>=(g|0)){break}e=e+4|0;V=q}return}else{V=f;f=0;while(1){e=(c[h+(f<<2)>>2]>>8)+(b[V>>1]|0)|0;if((e|0)<-32768){ah=-32768}else{ah=(e|0)>32767?32767:e&65535}b[V>>1]=ah;e=V+2|0;af=(c[k+(f<<2)>>2]>>8)+(b[e>>1]|0)|0;if((af|0)<-32768){ai=-32768}else{ai=(af|0)>32767?32767:af&65535}b[e>>1]=ai;e=f+1|0;if((e|0)>=(g|0)){break}V=V+4|0;f=e}return}}function Uv(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=9628264+(b*156|0)|0;g=e&255;if((a[f]&1)==0){if((g&128|0)==0){h=8452624+(b<<2)|0;c[h>>2]=c[h>>2]&~((e&255)>>>3&255);return}else{c[9628268+(b*156|0)>>2]=g<<3&1016;a[f]=1;return}}a[f]=0;f=(e&255)>>>4&255;e=9628268+(b*156|0)|0;h=9720408+((g&15)<<2)|0;g=8452624+(b<<2)|0;i=a[9608]|0;j=0;do{do{if((1<<j&f|0)!=0){k=c[e>>2]|0;l=k&255;c[e>>2]=l;m=c[14164760+(b<<4)+((k>>>8&3)<<2)>>2]|0;k=(((d[m+l|0]|0)<<8|(d[m+(l+1)|0]|0))<<8|(d[m+(l+2)|0]|0))<<1;n=(((d[m+(l+3)|0]|0)<<8|(d[m+(l+4)|0]|0))<<8|(d[m+(l+5)|0]|0))<<1;if(n>>>0>=524288){break}c[9628136+(b*156|0)+(j<<5)+4>>2]=c[h>>2];c[9628136+(b*156|0)+(j<<5)+8>>2]=k;c[9628136+(b*156|0)+(j<<5)+12>>2]=n-k;c[9628136+(b*156|0)+(j<<5)+20>>2]=0;c[9628136+(b*156|0)+(j<<5)+16>>2]=-1;c[9628136+(b*156|0)+(j<<5)>>2]=0;c[g>>2]=c[g>>2]|f;if(!i){break}k=9720472+(b<<4)+(j<<2)|0;c[c[k>>2]>>2]=0;c[(c[k>>2]|0)+4>>2]=0;c[(c[k>>2]|0)+8>>2]=0;c[(c[k>>2]|0)+12>>2]=0;c[9628136+(b*156|0)+(j<<5)+28>>2]=4}}while(0);j=j+1|0;}while((j|0)<4);return}function Uw(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[2443770]|0;d=0;while(1){if((d|0)>=1024){break}e=9638528+(d<<2)|0;if((c[e>>2]|0)==(b|0)){f=45752;break}else{d=d+1|0}}if((f|0)==45752){gGr(b);c[e>>2]=0}c[2443770]=0;e=c[2440432]|0;b=0;while(1){if((b|0)>=1024){break}g=9638528+(b<<2)|0;if((c[g>>2]|0)==(e|0)){f=45756;break}else{b=b+1|0}}if((f|0)==45756){gGr(e);c[g>>2]=0}c[2440432]=0;g=9720472+(a<<4)|0;e=c[g>>2]|0;b=0;while(1){if((b|0)>=1024){break}h=9638528+(b<<2)|0;if((c[h>>2]|0)==(e|0)){f=45760;break}else{b=b+1|0}}if((f|0)==45760){gGr(e);c[h>>2]=0}c[g>>2]=0;g=9720476+(a<<4)|0;h=c[g>>2]|0;e=0;while(1){if((e|0)>=1024){break}i=9638528+(e<<2)|0;if((c[i>>2]|0)==(h|0)){f=45764;break}else{e=e+1|0}}if((f|0)==45764){gGr(h);c[i>>2]=0}c[g>>2]=0;g=9720480+(a<<4)|0;i=c[g>>2]|0;h=0;while(1){if((h|0)>=1024){break}j=9638528+(h<<2)|0;if((c[j>>2]|0)==(i|0)){f=45768;break}else{h=h+1|0}}if((f|0)==45768){gGr(i);c[j>>2]=0}c[g>>2]=0;g=9720484+(a<<4)|0;a=c[g>>2]|0;j=0;while(1){if((j|0)>=1024){f=45775;break}k=9638528+(j<<2)|0;if((c[k>>2]|0)==(a|0)){break}else{j=j+1|0}}if((f|0)==45775){c[g>>2]=0;return}gGr(a);c[k>>2]=0;c[g>>2]=0;return}function Ux(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0.0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;f=a[9680]|0;g=f?128e3:0;do{if(f){if((c[2443770]|0)==0){h=0;while(1){if((h|0)>=1024){i=0;break}j=9638528+(h<<2)|0;if((c[j>>2]|0)==0){k=45780;break}else{h=h+1|0}}do{if((k|0)==45780){h=gGq(g)|0;c[j>>2]=h;if((h|0)==0){i=0;break}gGz(h|0,0,g|0);i=h}}while(0);c[2443770]=i}if((c[2440432]|0)!=0){break}h=a[9680]|0?128e3:0;l=0;while(1){if((l|0)>=1024){m=0;break}n=9638528+(l<<2)|0;if((c[n>>2]|0)==0){k=45787;break}else{l=l+1|0}}do{if((k|0)==45787){l=gGq(h)|0;c[n>>2]=l;if((l|0)==0){m=0;break}gGz(l|0,0,h|0);m=l}}while(0);c[2440432]=m}}while(0);a[9698800]=e&1;c[9628120+(b*156|0)>>2]=256;c[9628124+(b*156|0)>>2]=d;e=d<<12;if(a[9680]|0){c[9628128+(b*156|0)>>2]=(e|0)/32e3|0}else{c[9628128+(b*156|0)>>2]=(e|0)/11025|0}e=9628132+(b*156|0)|0;c[e>>2]=0;d=8452624+(b<<2)|0;c[d>>2]=0;m=9628264+(b*156|0)|0;a[m]=0;do{if((b|0)==0){c[2113184]=0;o=0}else{if((c[2113184]|0)>=(b|0)){o=0;break}c[2113184]=b;o=0}}while(0);while(1){n=~~(+X(1.1,+(+(o|0)))*16.0);i=n>>3;g=o<<4;j=n>>1;f=n>>2;h=0;do{l=((h&1|0)==0?0:f)+i+((h&2|0)==0?0:j)+((h&4|0)==0?0:n)|0;c[9723544+(h+g<<2)>>2]=(h&8|0)==0?l:-l|0;h=h+1|0;}while((h|0)<16);h=o+1|0;if((h|0)<49){o=h}else{p=0;break}}while(1){if((p|0)>0){q=256.0;o=p;do{q=q/1.412537545;o=o-1|0;}while((o|0)>0);r=~~(q+.5)}else{r=256}c[9720408+(p<<2)>>2]=r;o=p+1|0;if((o|0)<16){p=o}else{s=0;break}}while(1){if((s|0)>=1024){t=0;break}u=9638528+(s<<2)|0;if((c[u>>2]|0)==0){k=45803;break}else{s=s+1|0}}do{if((k|0)==45803){s=gGq(16384)|0;c[u>>2]=s;if((s|0)==0){t=0;break}gGz(s|0,0,16384);t=s}}while(0);u=9720472+(b<<4)|0;c[u>>2]=t;t=0;while(1){if((t|0)>=1024){v=0;break}w=9638528+(t<<2)|0;if((c[w>>2]|0)==0){k=45808;break}else{t=t+1|0}}do{if((k|0)==45808){t=gGq(16384)|0;c[w>>2]=t;if((t|0)==0){v=0;break}gGz(t|0,0,16384);v=t}}while(0);w=9720476+(b<<4)|0;c[w>>2]=v;v=0;while(1){if((v|0)>=1024){x=0;break}y=9638528+(v<<2)|0;if((c[y>>2]|0)==0){k=45813;break}else{v=v+1|0}}do{if((k|0)==45813){v=gGq(16384)|0;c[y>>2]=v;if((v|0)==0){x=0;break}gGz(v|0,0,16384);x=v}}while(0);y=9720480+(b<<4)|0;c[y>>2]=x;x=0;while(1){if((x|0)>=1024){z=0;break}A=9638528+(x<<2)|0;if((c[A>>2]|0)==0){k=45818;break}else{x=x+1|0}}do{if((k|0)==45818){x=gGq(16384)|0;c[A>>2]=x;if((x|0)==0){z=0;break}gGz(x|0,0,16384);z=x}}while(0);c[9720484+(b<<4)>>2]=z;c[9628272+(b*156|0)>>2]=3;c[d>>2]=0;a[m]=0;c[e>>2]=0;e=c[3541206]|0;m=b<<20;d=e+m|0;c[14164760+(b<<4)>>2]=d;c[14164792+(b<<4)>>2]=d;gGz(c[u>>2]|0,0,16384);c[9628164+(b*156|0)>>2]=4;c[14164764+(b<<4)>>2]=e+(m|256);c[14164796+(b<<4)>>2]=e+(m|65536);gGz(c[w>>2]|0,0,16384);c[9628196+(b*156|0)>>2]=4;c[14164768+(b<<4)>>2]=e+(m|512);c[14164800+(b<<4)>>2]=e+(m|131072);gGz(c[y>>2]|0,0,16384);c[9628228+(b*156|0)>>2]=4;c[14164772+(b<<4)>>2]=e+(m|768);c[14164804+(b<<4)>>2]=e+(m|196608);gGz(z|0,0,16384);c[9628260+(b*156|0)>>2]=4;return}function Uy(e,f){e=e|0;f=f|0;var g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0,cf=0,cg=0,ch=0,ci=0,cj=0,ck=0,cl=0,cm=0,cn=0,co=0,cp=0,cq=0,cr=0,cs=0,ct=0,cu=0,cv=0,cw=0,cx=0,cy=0,cz=0,cA=0,cB=0,cC=0,cD=0,cE=0,cF=0,cG=0.0,cH=0.0,cI=0,cJ=0,cK=0,cL=0,cM=0,cN=0;c[2439246]=(c[2439246]|0)+f;g=c[2406690]|0;c[2438960]=g;c[2438958]=g+(f<<1);i=c[3540990]|0;j=i+1684|0;k=a[j]&32;l=i;if((l|0)!=(c[2383470]|0)){c[2383470]=l;c[3532622]=i+1288;c[3532618]=i+1372;c[3532614]=i+1472;c[3532610]=i+1556}if((f|0)<=0){return}l=i+1692|0;m=i+1688|0;n=i+1700|0;o=i+1696|0;p=i+44|0;q=i+48|0;r=i+72|0;s=i+28|0;t=i+32|0;u=i+24|0;v=i+16|0;w=i+80|0;x=i+128|0;y=i+132|0;z=i+156|0;A=i+100|0;B=i+164|0;C=i+228|0;D=i+232|0;E=i+256|0;F=i+212|0;G=i+216|0;H=i+208|0;I=i+200|0;J=i+264|0;K=i+312|0;L=i+316|0;M=i+340|0;N=i+284|0;O=i+348|0;P=i+412|0;Q=i+416|0;R=i+440|0;S=i+396|0;T=i+400|0;U=i+392|0;V=i+384|0;W=i+448|0;X=i+496|0;Y=i+500|0;Z=i+524|0;_=i+468|0;$=i+532|0;aa=i+596|0;ab=i+600|0;ac=i+624|0;ad=i+580|0;ae=i+584|0;af=i+576|0;ah=i+568|0;ai=i+632|0;aj=i+680|0;ak=i+684|0;al=i+708|0;am=i+652|0;an=i+716|0;ao=i+780|0;ap=i+784|0;aq=i+808|0;ar=i+764|0;as=i+768|0;at=i+760|0;au=i+752|0;av=i+816|0;aw=i+864|0;ax=i+868|0;ay=i+892|0;az=i+836|0;aA=i+900|0;aB=i+964|0;aC=i+968|0;aD=i+992|0;aE=i+948|0;aF=i+952|0;aG=i+944|0;aH=i+936|0;aI=i+1e3|0;aJ=i+1048|0;aK=i+1052|0;aL=i+1076|0;aM=i+1020|0;aN=i+1084|0;aO=k<<24>>24==0;k=i+1148|0;aP=i+1152|0;aQ=i+1176|0;aR=i+1132|0;aS=i+1136|0;aT=i+1128|0;aU=i+1120|0;aV=i+1184|0;aW=i+1232|0;aX=i+1236|0;aY=i+1260|0;aZ=i+1204|0;a_=i+1268|0;a$=i+1332|0;a0=i+1336|0;a1=i+1360|0;a2=i+1316|0;a3=i+1320|0;a4=i+1312|0;a5=i+1304|0;a6=i+1368|0;a7=i+1416|0;a8=i+1420|0;a9=i+1444|0;ba=i+1388|0;bb=i+1452|0;bc=i+1516|0;bd=i+1520|0;be=i+1544|0;bf=i+1500|0;bg=i+1504|0;bh=i+1496|0;bi=i+1488|0;bj=i+1552|0;bk=i+1600|0;bl=i+1604|0;bm=i+1628|0;bn=i+1572|0;bo=i+1636|0;bp=i+1676|0;bq=i+1672|0;br=i+1680|0;bs=i+1668|0;bt=i+1712|0;bu=i+1708|0;bv=i+1704|0;bw=c[3532622]|0;bx=bw+44|0;by=bw+48|0;bz=bw+72|0;bA=bw+16|0;bB=c[3532610]|0;bC=bB+16|0;bD=bw+80|0;bw=c[3532618]|0;bE=bw+44|0;bF=bw+48|0;bG=bw+72|0;bH=bw+80|0;bw=c[3532614]|0;bI=bw+44|0;bJ=bw+48|0;bK=bw+72|0;bL=bw+16|0;bM=bw+80|0;bw=bB+44|0;bN=bB+48|0;bO=bB+72|0;bP=bB+80|0;bB=0;do{bQ=(c[m>>2]|0)+(c[l>>2]|0)|0;bR=bQ>>>0>3523215359?bQ+771751936|0:bQ;c[m>>2]=bR;bS=(d[44312+(bR>>>24)|0]|0)>>>1;bR=(c[o>>2]|0)+(c[n>>2]|0)|0;c[o>>2]=bR;bT=bR>>>24&7;bR=(c[q>>2]|0)+(c[p>>2]|0)+(c[r>>2]&bS)|0;bQ=c[s>>2]|0;bU=c[t>>2]|0;c[s>>2]=bU;c[t>>2]=0;if(bR>>>0<176){bV=a[u]|0;bW=(c[8419176+(((((bV<<24>>24==0?0:bU+bQ|0)<<(bV&255))+(c[v>>2]&67043328)|0)>>>16&1023)+(c[w>>2]|0)<<2)>>2]|0)+(bR<<5)|0;if(bW>>>0>5631){bX=0}else{bX=c[8363864+(bW<<2)>>2]|0}c[t>>2]=bX}bW=(c[y>>2]|0)+(c[x>>2]|0)+(c[z>>2]&bS)|0;do{if(bW>>>0<176){bR=(c[8419176+((((c[A>>2]&67043328)+(bU<<17)|0)>>>16&1023)+(c[B>>2]|0)<<2)>>2]|0)+(bW<<5)|0;if(bR>>>0>5631){bY=0;break}bY=c[8363864+(bR<<2)>>2]|0}else{bY=0}}while(0);bW=(c[D>>2]|0)+(c[C>>2]|0)+(c[E>>2]&bS)|0;bU=c[F>>2]|0;bR=c[G>>2]|0;c[F>>2]=bR;c[G>>2]=0;if(bW>>>0<176){bV=a[H]|0;bQ=(c[8419176+(((((bV<<24>>24==0?0:bR+bU|0)<<(bV&255))+(c[I>>2]&67043328)|0)>>>16&1023)+(c[J>>2]|0)<<2)>>2]|0)+(bW<<5)|0;if(bQ>>>0>5631){bZ=0}else{bZ=c[8363864+(bQ<<2)>>2]|0}c[G>>2]=bZ}bQ=(c[L>>2]|0)+(c[K>>2]|0)+(c[M>>2]&bS)|0;if(bQ>>>0<176){bW=(c[8419176+((((c[N>>2]&67043328)+(bR<<17)|0)>>>16&1023)+(c[O>>2]|0)<<2)>>2]|0)+(bQ<<5)|0;if(bW>>>0>5631){b_=0}else{b_=c[8363864+(bW<<2)>>2]|0}b$=bY+b_|0}else{b$=bY}bW=(c[Q>>2]|0)+(c[P>>2]|0)+(c[R>>2]&bS)|0;bQ=c[S>>2]|0;bR=c[T>>2]|0;c[S>>2]=bR;c[T>>2]=0;if(bW>>>0<176){bV=a[U]|0;bU=(c[8419176+(((((bV<<24>>24==0?0:bR+bQ|0)<<(bV&255))+(c[V>>2]&67043328)|0)>>>16&1023)+(c[W>>2]|0)<<2)>>2]|0)+(bW<<5)|0;if(bU>>>0>5631){b0=0}else{b0=c[8363864+(bU<<2)>>2]|0}c[T>>2]=b0}bU=(c[Y>>2]|0)+(c[X>>2]|0)+(c[Z>>2]&bS)|0;if(bU>>>0<176){bW=(c[8419176+((((c[_>>2]&67043328)+(bR<<17)|0)>>>16&1023)+(c[$>>2]|0)<<2)>>2]|0)+(bU<<5)|0;if(bW>>>0>5631){b1=0}else{b1=c[8363864+(bW<<2)>>2]|0}b2=b$+b1|0}else{b2=b$}bW=(c[ab>>2]|0)+(c[aa>>2]|0)+(c[ac>>2]&bS)|0;bU=c[ad>>2]|0;bR=c[ae>>2]|0;c[ad>>2]=bR;c[ae>>2]=0;if(bW>>>0<176){bV=a[af]|0;bQ=(c[8419176+(((((bV<<24>>24==0?0:bR+bU|0)<<(bV&255))+(c[ah>>2]&67043328)|0)>>>16&1023)+(c[ai>>2]|0)<<2)>>2]|0)+(bW<<5)|0;if(bQ>>>0>5631){b3=0}else{b3=c[8363864+(bQ<<2)>>2]|0}c[ae>>2]=b3}bQ=(c[ak>>2]|0)+(c[aj>>2]|0)+(c[al>>2]&bS)|0;if(bQ>>>0<176){bW=(c[8419176+((((c[am>>2]&67043328)+(bR<<17)|0)>>>16&1023)+(c[an>>2]|0)<<2)>>2]|0)+(bQ<<5)|0;if(bW>>>0>5631){b4=0}else{b4=c[8363864+(bW<<2)>>2]|0}b5=b2+b4|0}else{b5=b2}bW=(c[ap>>2]|0)+(c[ao>>2]|0)+(c[aq>>2]&bS)|0;bQ=c[ar>>2]|0;bR=c[as>>2]|0;c[ar>>2]=bR;c[as>>2]=0;if(bW>>>0<176){bV=a[at]|0;bU=(c[8419176+(((((bV<<24>>24==0?0:bR+bQ|0)<<(bV&255))+(c[au>>2]&67043328)|0)>>>16&1023)+(c[av>>2]|0)<<2)>>2]|0)+(bW<<5)|0;if(bU>>>0>5631){b6=0}else{b6=c[8363864+(bU<<2)>>2]|0}c[as>>2]=b6}bU=(c[ax>>2]|0)+(c[aw>>2]|0)+(c[ay>>2]&bS)|0;if(bU>>>0<176){bW=(c[8419176+((((c[az>>2]&67043328)+(bR<<17)|0)>>>16&1023)+(c[aA>>2]|0)<<2)>>2]|0)+(bU<<5)|0;if(bW>>>0>5631){b7=0}else{b7=c[8363864+(bW<<2)>>2]|0}b8=b5+b7|0}else{b8=b5}bW=(c[aC>>2]|0)+(c[aB>>2]|0)+(c[aD>>2]&bS)|0;bU=c[aE>>2]|0;bR=c[aF>>2]|0;c[aE>>2]=bR;c[aF>>2]=0;if(bW>>>0<176){bV=a[aG]|0;bQ=(c[8419176+(((((bV<<24>>24==0?0:bR+bU|0)<<(bV&255))+(c[aH>>2]&67043328)|0)>>>16&1023)+(c[aI>>2]|0)<<2)>>2]|0)+(bW<<5)|0;if(bQ>>>0>5631){b9=0}else{b9=c[8363864+(bQ<<2)>>2]|0}c[aF>>2]=b9}bQ=(c[aK>>2]|0)+(c[aJ>>2]|0)+(c[aL>>2]&bS)|0;if(bQ>>>0<176){bW=(c[8419176+((((c[aM>>2]&67043328)+(bR<<17)|0)>>>16&1023)+(c[aN>>2]|0)<<2)>>2]|0)+(bQ<<5)|0;if(bW>>>0>5631){ca=0}else{ca=c[8363864+(bW<<2)>>2]|0}cb=b8+ca|0}else{cb=b8}do{if(aO){bW=(c[aP>>2]|0)+(c[k>>2]|0)+(c[aQ>>2]&bS)|0;bQ=c[aR>>2]|0;bR=c[aS>>2]|0;c[aR>>2]=bR;c[aS>>2]=0;if(bW>>>0<176){bV=a[aT]|0;bU=(c[8419176+(((((bV<<24>>24==0?0:bR+bQ|0)<<(bV&255))+(c[aU>>2]&67043328)|0)>>>16&1023)+(c[aV>>2]|0)<<2)>>2]|0)+(bW<<5)|0;if(bU>>>0>5631){cc=0}else{cc=c[8363864+(bU<<2)>>2]|0}c[aS>>2]=cc}bU=(c[aX>>2]|0)+(c[aW>>2]|0)+(c[aY>>2]&bS)|0;if(bU>>>0<176){bW=(c[8419176+((((c[aZ>>2]&67043328)+(bR<<17)|0)>>>16&1023)+(c[a_>>2]|0)<<2)>>2]|0)+(bU<<5)|0;if(bW>>>0>5631){cd=0}else{cd=c[8363864+(bW<<2)>>2]|0}ce=cb+cd|0}else{ce=cb}bW=(c[a0>>2]|0)+(c[a$>>2]|0)+(c[a1>>2]&bS)|0;bU=c[a2>>2]|0;bR=c[a3>>2]|0;c[a2>>2]=bR;c[a3>>2]=0;if(bW>>>0<176){bV=a[a4]|0;bQ=(c[8419176+(((((bV<<24>>24==0?0:bR+bU|0)<<(bV&255))+(c[a5>>2]&67043328)|0)>>>16&1023)+(c[a6>>2]|0)<<2)>>2]|0)+(bW<<5)|0;if(bQ>>>0>5631){cf=0}else{cf=c[8363864+(bQ<<2)>>2]|0}c[a3>>2]=cf}bQ=(c[a8>>2]|0)+(c[a7>>2]|0)+(c[a9>>2]&bS)|0;if(bQ>>>0<176){bW=(c[8419176+((((c[ba>>2]&67043328)+(bR<<17)|0)>>>16&1023)+(c[bb>>2]|0)<<2)>>2]|0)+(bQ<<5)|0;if(bW>>>0>5631){cg=0}else{cg=c[8363864+(bW<<2)>>2]|0}ch=ce+cg|0}else{ch=ce}bW=(c[bd>>2]|0)+(c[bc>>2]|0)+(c[be>>2]&bS)|0;bQ=c[bf>>2]|0;bR=c[bg>>2]|0;c[bf>>2]=bR;c[bg>>2]=0;if(bW>>>0<176){bV=a[bh]|0;bU=(c[8419176+(((((bV<<24>>24==0?0:bR+bQ|0)<<(bV&255))+(c[bi>>2]&67043328)|0)>>>16&1023)+(c[bj>>2]|0)<<2)>>2]|0)+(bW<<5)|0;if(bU>>>0>5631){ci=0}else{ci=c[8363864+(bU<<2)>>2]|0}c[bg>>2]=ci}bU=(c[bl>>2]|0)+(c[bk>>2]|0)+(c[bm>>2]&bS)|0;if(bU>>>0>=176){cj=ch;ck=0;break}bW=(c[8419176+((((c[bn>>2]&67043328)+(bR<<17)|0)>>>16&1023)+(c[bo>>2]|0)<<2)>>2]|0)+(bU<<5)|0;if(bW>>>0>5631){cl=0}else{cl=c[8363864+(bW<<2)>>2]|0}cj=ch+cl|0;ck=0}else{bW=c[bv>>2]&1;bU=(c[aP>>2]|0)+(c[k>>2]|0)+(c[aQ>>2]&bS)|0;bR=c[aR>>2]|0;bV=c[aS>>2]|0;c[aR>>2]=bV;c[aS>>2]=0;if(bU>>>0<176){bQ=a[aT]|0;cm=(c[8419176+(((((bQ<<24>>24==0?0:bV+bR|0)<<(bQ&255))+(c[aU>>2]&67043328)|0)>>>16&1023)+(c[aV>>2]|0)<<2)>>2]|0)+(bU<<5)|0;if(cm>>>0>5631){cn=0}else{cn=c[8363864+(cm<<2)>>2]|0}c[aS>>2]=cn}cm=(c[aX>>2]|0)+(c[aW>>2]|0)+(c[aY>>2]&bS)|0;do{if(cm>>>0<176){bU=(c[8419176+((((c[aZ>>2]&67043328)+(bV<<17)|0)>>>16&1023)+(c[a_>>2]|0)<<2)>>2]|0)+(cm<<5)|0;if(bU>>>0>5631){co=0;break}co=c[8363864+(bU<<2)>>2]<<1}else{co=0}}while(0);cm=(c[by>>2]|0)+(c[bx>>2]|0)+(c[bz>>2]&bS)|0;if(cm>>>0<176){bV=c[bA>>2]|0;bU=c[bC>>2]|0;bQ=((bU>>>19|bU>>>21)&1|0)==0?((bV>>>18^bV>>>23|bV>>>19)&1|0)!=0?564:208:564;bV=(bW|0)!=0;if((bQ&512|0)==0){cp=bV?52:bQ}else{cp=bV?720:bQ}bQ=(c[8419176+((c[bD>>2]|0)+(cp&1023)<<2)>>2]|0)+(cm<<5)|0;if(bQ>>>0>5631){cq=0}else{cq=c[8363864+(bQ<<2)>>2]<<1}cr=co+cq|0}else{cr=co}bQ=(c[bF>>2]|0)+(c[bE>>2]|0)+(c[bG>>2]&bS)|0;if(bQ>>>0<176){cm=((c[bA>>2]|0)>>>16&256)+256|0;bV=(c[8419176+((((bW|0)==0?cm:cm^256)&768)+(c[bH>>2]|0)<<2)>>2]|0)+(bQ<<5)|0;if(bV>>>0>5631){cs=0}else{cs=c[8363864+(bV<<2)>>2]<<1}ct=cr+cs|0}else{ct=cr}bV=(c[bJ>>2]|0)+(c[bI>>2]|0)+(c[bK>>2]&bS)|0;if(bV>>>0<176){bQ=(c[8419176+(((c[bL>>2]|0)>>>16&1023)+(c[bM>>2]|0)<<2)>>2]|0)+(bV<<5)|0;if(bQ>>>0>5631){cu=0}else{cu=c[8363864+(bQ<<2)>>2]<<1}cv=ct+cu|0}else{cv=ct}bQ=(c[bN>>2]|0)+(c[bw>>2]|0)+(c[bO>>2]&bS)|0;if(bQ>>>0>=176){cj=cb;ck=cv;break}bV=c[bA>>2]|0;cm=c[bC>>2]|0;bU=(c[8419176+((((cm>>>19|cm>>>21)&1|0)==0?(bV>>>18^bV>>>23|bV>>>19)<<9&512|256:768)+(c[bP>>2]|0)<<2)>>2]|0)+(bQ<<5)|0;if(bU>>>0>5631){cw=0}else{cw=c[8363864+(bU<<2)>>2]<<1}cj=cb;ck=cv+cw|0}}while(0);if((cj|0)>32767){cx=32767}else{cx=(cj|0)<-32768?-32768:cj&65535}if((ck|0)>32767){cy=32767}else{cy=(ck|0)<-32768?-32768:ck&65535}b[g+(bB<<1)>>1]=cx;b[g+(bB+f<<1)>>1]=cy;bU=(c[bq>>2]|0)+(c[bp>>2]|0)|0;c[bq>>2]=bU;bQ=c[br>>2]|0;if(bU>>>0<bQ>>>0){cz=0}else{bV=bU;bU=bQ;while(1){c[bq>>2]=bV-bU;c[bs>>2]=(c[bs>>2]|0)+1;bQ=0;do{cm=bQ>>>1;bR=bQ&1;cA=i+(cm*184|0)+(bR*84|0)+37|0;L59303:do{switch(d[cA]|0){case 5:{cB=c[bs>>2]|0;cC=d[i+(cm*184|0)+(bR*84|0)+56|0]|0;if(((1<<cC)-1&cB|0)!=0){break L59303}cD=i+(cm*184|0)+(bR*84|0)+48|0;cE=(c[cD>>2]|0)+(d[52616+((d[i+(cm*184|0)+(bR*84|0)+57|0]|0)+(cB>>>(cC>>>0)&7))|0]|0)|0;c[cD>>2]=cE;if((cE|0)<=254){break L59303}c[cD>>2]=255;a[cA]=4;c[i+(cm*184|0)+(bR*84|0)+16>>2]=0;break};case 2:{if((a[i+(cm*184|0)+(bR*84|0)+36|0]|0)!=0){break L59303}cD=c[bs>>2]|0;cE=d[i+(cm*184|0)+(bR*84|0)+62|0]|0;if(((1<<cE)-1&cD|0)!=0){break L59303}cC=i+(cm*184|0)+(bR*84|0)+48|0;cB=(c[cC>>2]|0)+(d[52616+((d[i+(cm*184|0)+(bR*84|0)+63|0]|0)+(cD>>>(cE>>>0)&7))|0]|0)|0;c[cC>>2]=cB;if((cB|0)<=254){break L59303}c[cC>>2]=255;break};case 4:{cC=c[bs>>2]|0;cB=d[i+(cm*184|0)+(bR*84|0)+58|0]|0;if(((1<<cB)-1&cC|0)!=0){break L59303}cE=i+(cm*184|0)+(bR*84|0)+48|0;cD=c[cE>>2]|0;cF=((ag(d[52616+((d[i+(cm*184|0)+(bR*84|0)+59|0]|0)+(cC>>>(cB>>>0)&7))|0]|0,~cD)|0)>>2)+cD|0;c[cE>>2]=cF;if((cF|0)>=1){break L59303}c[cE>>2]=0;a[cA]=3;break};case 3:{cE=c[bs>>2]|0;cF=d[i+(cm*184|0)+(bR*84|0)+60|0]|0;if(((1<<cF)-1&cE|0)!=0){break L59303}cD=i+(cm*184|0)+(bR*84|0)+48|0;cB=(c[cD>>2]|0)+(d[52616+((d[i+(cm*184|0)+(bR*84|0)+61|0]|0)+(cE>>>(cF>>>0)&7))|0]|0)|0;c[cD>>2]=cB;if(cB>>>0<(c[i+(cm*184|0)+(bR*84|0)+52>>2]|0)>>>0){break L59303}a[cA]=2;break};case 1:{if((bR|0)==0){if(!((a[j]&32)!=0&bQ>>>0>11)){break L59303}}if((a[i+(cm*184|0)+(bR*84|0)+36|0]|0)==0){cB=c[bs>>2]|0;cD=d[i+(cm*184|0)+(bR*84|0)+64|0]|0;if(((1<<cD)-1&cB|0)!=0){break L59303}cF=i+(cm*184|0)+(bR*84|0)+48|0;cE=(c[cF>>2]|0)+(d[52616+((d[i+(cm*184|0)+(bR*84|0)+65|0]|0)+(cB>>>(cD>>>0)&7))|0]|0)|0;c[cF>>2]=cE;if((cE|0)<=254){break L59303}c[cF>>2]=255;a[cA]=0;break L59303}cF=c[bs>>2]|0;if((a[i+(cm*184|0)+181|0]|0)==0){cE=d[i+(cm*184|0)+(bR*84|0)+62|0]|0;if(((1<<cE)-1&cF|0)!=0){break L59303}cD=i+(cm*184|0)+(bR*84|0)+48|0;cB=(c[cD>>2]|0)+(d[52616+((d[i+(cm*184|0)+(bR*84|0)+63|0]|0)+(cF>>>(cE>>>0)&7))|0]|0)|0;c[cD>>2]=cB;if((cB|0)<=254){break L59303}c[cD>>2]=255;a[cA]=0;break L59303}else{cD=d[i+(cm*184|0)+(bR*84|0)+64|0]|0;if(((1<<cD)-1&cF|0)!=0){break L59303}cB=i+(cm*184|0)+(bR*84|0)+48|0;cE=(c[cB>>2]|0)+(d[52616+((d[i+(cm*184|0)+(bR*84|0)+65|0]|0)+(cF>>>(cD>>>0)&7))|0]|0)|0;c[cB>>2]=cE;if((cE|0)<=254){break L59303}c[cB>>2]=255;a[cA]=0;break L59303}break};default:{}}}while(0);bQ=bQ+1|0;}while(bQ>>>0<18);bQ=c[bq>>2]|0;bW=c[br>>2]|0;if(bQ>>>0<bW>>>0){cz=0;break}else{bV=bQ;bU=bW}}}do{bU=cz>>>1;bV=cz&1;do{if((a[i+(bU*184|0)+(bV*84|0)+76|0]|0)==0){bW=i+(bU*184|0)+(bV*84|0)+16|0;c[bW>>2]=(c[bW>>2]|0)+(c[i+(bU*184|0)+(bV*84|0)+20>>2]|0)}else{bW=c[i+(bU*184|0)+168>>2]|0;bQ=a[43408+(bW>>>6<<3&56|bT)|0]|0;if(bQ<<24>>24==0){cA=i+(bU*184|0)+(bV*84|0)+16|0;c[cA>>2]=(c[cA>>2]|0)+(c[i+(bU*184|0)+(bV*84|0)+20>>2]|0);break}else{cA=(bQ<<24>>24)+(bW<<1)|0;bW=ag(d[i+(bU*184|0)+(bV*84|0)+15|0]|0,(c[i+1876+((cA&1023)<<2)>>2]|0)>>>((cA>>>10&7^7)>>>0))|0;cA=i+(bU*184|0)+(bV*84|0)+16|0;c[cA>>2]=bW+(c[cA>>2]|0);break}}}while(0);cz=cz+1|0;}while(cz>>>0<18);bV=(c[bu>>2]|0)+(c[bt>>2]|0)|0;bU=bV>>>16;c[bu>>2]=bV&65535;if((bU|0)!=0){bV=bU;bU=c[bv>>2]|0;do{bU=((bU&1|0)==0?bU:bU^8389378)>>>1;bV=bV-1|0;}while((bV|0)!=0);c[bv>>2]=bU}bB=bB+1|0;}while((bB|0)<(f|0));c[3541210]=bT;c[2112984]=cj;c[2112982]=ck;c[3541214]=bS;bS=a[3203304]|0?3:0;ck=(bS&1|0)==0;cj=(bS&2|0)==0;bS=a[3203296]|0?3:0;bT=(bS&1|0)==0;bB=(bS&2|0)==0;cG=+h[745410];cH=+h[745411];bS=0;do{if(ck){cI=0}else{cI=~~(+(b[g+(bS<<1)>>1]|0)*cH)}if(cj){cJ=0}else{cJ=~~(+(b[g+(bS<<1)>>1]|0)*cH)}if(bT){cK=cI}else{cK=~~(+(b[g+(bS+f<<1)>>1]|0)*cG)+cI|0}if(bB){cL=cJ}else{cL=~~(+(b[g+(bS+f<<1)>>1]|0)*cG)+cJ|0}if((cK|0)<-32768){cM=-32768}else{cM=(cK|0)>32767?32767:cK&65535}if((cL|0)<-32768){cN=-32768}else{cN=(cL|0)>32767?32767:cL&65535}bv=bS<<1;b[e+(bv<<1)>>1]=cM;b[e+((bv|1)<<1)>>1]=cN;bS=bS+1|0;}while((bS|0)<(f|0));return}function Uz(d,f,g){d=d|0;f=f|0;g=g|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0.0,z=0,A=0,B=0;i=9635952+(d<<2)|0;j=c[i>>2]|0;c[2415126]=9662152+(d*3224|0);k=c[9662224+(d*3224|0)>>2]|0;d=(ag(c[2424]|0,a[9688]|0?534:0)|0)/100|0;l=gj[k&4095](d)|0;d=a[9688]|0;k=d?534:0;m=l>>>0>k>>>0?k:l;l=c[2415126]|0;k=l+84|0;n=c[k>>2]|0;do{if(n>>>0<m>>>0){o=m-n|0;c[k>>2]=m;p=c[i>>2]|0;if((n|0)==0){gGz(p|0,0,(d?1068:0)|0)}q=c[l+20>>2]|0;if((q|0)==0){gGz(p+(n<<1)|0,0,o<<1|0);break}r=~~(+(q<<4|0)*+h[l+32>>3])&65535;if((m|0)==(n|0)){break}else{s=0;t=o}while(1){b[p+(s+n<<1)>>1]=r;o=t-1|0;if((o|0)==0){break}else{s=s+1|0;t=o}}}}while(0);c[k>>2]=0;if((g|0)<=0){return}k=l+44|0;t=l+40|0;s=l+80|0;n=l+48|0;m=l+56|0;l=f;f=0;while(1){do{if((c[k>>2]|0)==0){d=c[t>>2]|0;if((d&1|0)==0){u=0}else{u=b[j+(f<<1)>>1]|0}if((d&2|0)==0){v=u;w=0;x=46004;break}v=u;w=b[j+(f<<1)>>1]|0;x=46004}else{y=+(b[j+(f<<1)>>1]|0);d=~~(y*+h[n>>3]);i=~~(y*+h[m>>3]);if((d|0)<-32768){z=-32768;A=i}else{v=d;w=i;x=46004}}}while(0);if((x|0)==46004){x=0;z=(v|0)>32767?32767:v;A=w}if((A|0)<-32768){B=-32768}else{B=(A|0)>32767?32767:A}if((c[s>>2]|0)==0){b[l>>1]=z&65535;b[l+2>>1]=B&65535}else{b[l>>1]=(e[l>>1]|0)+z&65535;i=l+2|0;b[i>>1]=(e[i>>1]|0)+B&65535}i=f+1|0;if((i|0)<(g|0)){l=l+4|0;f=i}else{break}}return}function UA(){var a=0,b=0,d=0;c[2415126]=9662152;if((c[2408988]|0)!=0){c[2415538]=0;c[2415539]=0;c[2415540]=0;c[2415543]=0;c[2415544]=0;a=c[2415557]|0;b=c[600992+((a>>>3&1)<<4)+((a&3)<<2)>>2]|0;d=(a>>>2&1)+3|0;if((c[2415541]|0)!=(b|0)){c[2415541]=b}if((c[2415542]|0)!=(d|0)){c[2415542]=d}c[2415559]=0}c[2415126]=9665376;if((c[2408989]|0)==0){return}c[2416344]=0;c[2416345]=0;c[2416346]=0;c[2416349]=0;c[2416350]=0;d=c[2416363]|0;b=c[600992+((d>>>3&1)<<4)+((d&3)<<2)>>2]|0;a=(d>>>2&1)+3|0;if((c[2416347]|0)!=(b|0)){c[2416347]=b}if((c[2416348]|0)!=(a|0)){c[2416348]=a}c[2416365]=0;return}function UB(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var i=0,j=0,k=0,l=0,m=0,n=0;i=9662152+(b*3224|0)|0;c[2415126]=i;gGz(i|0,0,3224);c[9662224+(b*3224|0)>>2]=d;c[9662220+(b*3224|0)>>2]=f;c[9662228+(b*3224|0)>>2]=g;c[9662216+(b*3224|0)>>2]=e;c[9662232+(b*3224|0)>>2]=1;h[9662184+(b*3224|0)>>3]=1.0;c[9662192+(b*3224|0)>>2]=3;h[9662200+(b*3224|0)>>3]=1.0;h[9662208+(b*3224|0)>>3]=1.0;c[9662196+(b*3224|0)>>2]=0;e=a[9688]|0?534:0;g=(~~(+(6e3-(c[2424]|0)|0)/6.0e3*+(e|0))+e<<1)+2|0;e=0;while(1){if((e|0)>=1024){j=0;break}k=9638528+(e<<2)|0;if((c[k>>2]|0)==0){l=46032;break}else{e=e+1|0}}do{if((l|0)==46032){e=gGq(g)|0;c[k>>2]=e;if((e|0)==0){j=0;break}gGz(e|0,0,g|0);j=e}}while(0);c[9635952+(b<<2)>>2]=j;c[2415126]=i;i=0;do{j=~~+U(+(+X(1.1,+(+(i|0)))*16.0));g=(j|0)/2|0;k=(j|0)/4|0;l=(j|0)/8|0;e=i<<4;f=0;do{d=c[604464+(f<<4)>>2]|0;m=ag(c[604468+(f<<4)>>2]|0,j)|0;n=ag(c[604472+(f<<4)>>2]|0,g)|0;c[9662240+(b*3224|0)+(f+e<<2)>>2]=ag(m+l+n+(ag(c[604476+(f<<4)>>2]|0,k)|0)|0,d)|0;f=f+1|0;}while((f|0)<16);i=i+1|0;}while((i|0)<49);return}function UC(d){d=d|0;var e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=9662152+(d*3224|0)|0;c[2415126]=e;f=c[9662220+(d*3224|0)>>2]|0;if((f|0)==0){g=e}else{gu[f&16383]();g=c[2415126]|0}do{if((c[g+8>>2]|0)==0){f=c[g>>2]|0;i=c[g+20>>2]|0;j=g+24|0;k=c[j>>2]|0;l=(c[g+88+((k<<4|f&15)<<2)>>2]|0)+i|0;if((l|0)>2047){m=2047}else{m=(l|0)<-2048?-2048:l}l=(c[7045224+((f&7)<<2)>>2]|0)+k|0;c[j>>2]=l;if((l|0)>48){c[j>>2]=48;n=m;o=i;break}if((l|0)>=0){n=m;o=i;break}c[j>>2]=0;n=m;o=i}else{c[g+24>>2]=0;n=0;o=c[g+20>>2]|0}}while(0);if((o|0)==(n|0)){return}c[2415126]=e;e=c[9662224+(d*3224|0)>>2]|0;o=(ag(c[2424]|0,a[9688]|0?534:0)|0)/100|0;g=gj[e&4095](o)|0;o=a[9688]|0;e=o?534:0;m=g>>>0>e>>>0?e:g;g=c[2415126]|0;e=g+84|0;i=c[e>>2]|0;do{if(i>>>0<m>>>0){j=m-i|0;c[e>>2]=m;l=c[9635952+(d<<2)>>2]|0;if((i|0)==0){gGz(l|0,0,(o?1068:0)|0)}k=g+20|0;f=c[k>>2]|0;if((f|0)==0){gGz(l+(i<<1)|0,0,j<<1|0);p=k;break}q=~~(+(f<<4|0)*+h[g+32>>3])&65535;if((m|0)==(i|0)){p=k;break}else{r=0;s=j}while(1){b[l+(r+i<<1)>>1]=q;j=s-1|0;if((j|0)==0){p=k;break}else{r=r+1|0;s=j}}}else{p=g+20|0}}while(0);c[p>>2]=n;return}function UD(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c[2415126]=9662152;do{if((c[2415541]|0)==0){if((c[2408988]|0)==0){break}c[2415126]=9662152;d=c[2415556]|0;e=(ag(c[2424]|0,a[9688]|0?534:0)|0)/100|0;f=gj[d&4095](e)|0;e=a[9688]|0;d=e?534:0;g=f>>>0>d>>>0?d:f;f=c[2415126]|0;d=f+84|0;i=c[d>>2]|0;if(i>>>0>=g>>>0){break}j=g-i|0;c[d>>2]=g;d=c[2408988]|0;if((i|0)==0){gGz(d|0,0,(e?1068:0)|0)}e=c[f+20>>2]|0;if((e|0)==0){gGz(d+(i<<1)|0,0,j<<1|0);break}k=~~(+(e<<4|0)*+h[f+32>>3])&65535;if((g|0)==(i|0)){break}else{l=0;m=j}while(1){b[d+(l+i<<1)>>1]=k;j=m-1|0;if((j|0)==0){break}else{l=l+1|0;m=j}}}else{UC(0)}}while(0);c[2415126]=9665376;if((c[2416347]|0)!=0){UC(1);return}if((c[2408989]|0)==0){return}c[2415126]=9665376;m=c[2416362]|0;l=(ag(c[2424]|0,a[9688]|0?534:0)|0)/100|0;k=gj[m&4095](l)|0;l=a[9688]|0;m=l?534:0;i=k>>>0>m>>>0?m:k;k=c[2415126]|0;m=k+84|0;d=c[m>>2]|0;if(d>>>0>=i>>>0){return}j=i-d|0;c[m>>2]=i;m=c[2408989]|0;if((d|0)==0){gGz(m|0,0,(l?1068:0)|0)}l=c[k+20>>2]|0;if((l|0)==0){gGz(m+(d<<1)|0,0,j<<1|0);return}g=~~(+(l<<4|0)*+h[k+32>>3])&65535;if((i|0)==(d|0)){return}else{n=0;o=j}while(1){b[m+(n+d<<1)>>1]=g;j=o-1|0;if((j|0)==0){break}else{n=n+1|0;o=j}}return}function UE(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;d=i;i=i+128|0;e=d|0;f=d+16|0;g=d+32|0;h=d+48|0;j=d+64|0;k=d+80|0;l=d+96|0;m=d+112|0;if((b|0)!=0){c[b>>2]=169736}if((a&64|0)==0){i=d;return}a=m;b=m|0;n=m+4|0;o=m+12|0;p=l;q=l|0;r=l+4|0;s=l+12|0;t=k;u=k|0;v=k+4|0;w=k+12|0;x=j;y=j|0;z=j+4|0;A=j+12|0;B=h;C=h|0;D=h+4|0;E=h+12|0;F=g;G=g|0;H=g+4|0;I=g+12|0;J=f;K=f|0;L=f+4|0;M=f+12|0;N=e;O=e|0;P=e+4|0;Q=e+12|0;c[2415126]=9662152;gGz(a|0,0,12);c[b>>2]=9662152;c[n>>2]=4;c[o>>2]=133352;gj[c[2076592]&4095](m)|0;R=(c[2415126]|0)+4|0;gGz(p|0,0,12);c[q>>2]=R;c[r>>2]=4;c[s>>2]=489960;gj[c[2076592]&4095](l)|0;R=(c[2415126]|0)+8|0;gGz(t|0,0,12);c[u>>2]=R;c[v>>2]=4;c[w>>2]=375824;gj[c[2076592]&4095](k)|0;R=(c[2415126]|0)+12|0;gGz(x|0,0,12);c[y>>2]=R;c[z>>2]=4;c[A>>2]=292560;gj[c[2076592]&4095](j)|0;R=(c[2415126]|0)+16|0;gGz(B|0,0,12);c[C>>2]=R;c[D>>2]=4;c[E>>2]=222880;gj[c[2076592]&4095](h)|0;R=(c[2415126]|0)+20|0;gGz(F|0,0,12);c[G>>2]=R;c[H>>2]=4;c[I>>2]=174864;gj[c[2076592]&4095](g)|0;R=(c[2415126]|0)+24|0;gGz(J|0,0,12);c[K>>2]=R;c[L>>2]=4;c[M>>2]=140704;gj[c[2076592]&4095](f)|0;R=(c[2415126]|0)+32|0;gGz(N|0,0,12);c[O>>2]=R;c[P>>2]=8;c[Q>>2]=113432;gj[c[2076592]&4095](e)|0;c[2415126]=9665376;gGz(a|0,0,12);c[b>>2]=9665376;c[n>>2]=4;c[o>>2]=133352;gj[c[2076592]&4095](m)|0;m=(c[2415126]|0)+4|0;gGz(p|0,0,12);c[q>>2]=m;c[r>>2]=4;c[s>>2]=489960;gj[c[2076592]&4095](l)|0;l=(c[2415126]|0)+8|0;gGz(t|0,0,12);c[u>>2]=l;c[v>>2]=4;c[w>>2]=375824;gj[c[2076592]&4095](k)|0;k=(c[2415126]|0)+12|0;gGz(x|0,0,12);c[y>>2]=k;c[z>>2]=4;c[A>>2]=292560;gj[c[2076592]&4095](j)|0;j=(c[2415126]|0)+16|0;gGz(B|0,0,12);c[C>>2]=j;c[D>>2]=4;c[E>>2]=222880;gj[c[2076592]&4095](h)|0;h=(c[2415126]|0)+20|0;gGz(F|0,0,12);c[G>>2]=h;c[H>>2]=4;c[I>>2]=174864;gj[c[2076592]&4095](g)|0;g=(c[2415126]|0)+24|0;gGz(J|0,0,12);c[K>>2]=g;c[L>>2]=4;c[M>>2]=140704;gj[c[2076592]&4095](f)|0;f=(c[2415126]|0)+32|0;gGz(N|0,0,12);c[O>>2]=f;c[P>>2]=8;c[Q>>2]=113432;gj[c[2076592]&4095](e)|0;i=d;return}function UF(b){b=b|0;var e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=gGU(b,(b|0)<0|0?-1:0,2048e6,0)|0;b=c[2438224]|0;f=gGS(e,K,b,(b|0)<0|0?-1:0)|0;e=f;c[2443834]=e;if((c[3528508]|0)<(e|0)){g=0;i=e;j=b}else{k=0;return k|0}while(1){b=c[2443826]|0;e=c[2443827]|0;f=(b|0)>(e|0)?e:b;b=((f|0)>(i|0)?i:f)+(c[2443842]|0)|0;f=gGU(b,(b|0)<0|0?-1:0,j,(j|0)<0|0?-1:0)|0;b=gGS(f,K,2048e6,0)|0;f=c[2406672]|0;e=b-(gD[c[2433522]&8191]()|0)|0;gj[f&4095](e)|0;e=(gD[c[2433522]&8191]()|0)+1|0;f=gGU(e,(e|0)<0|0?-1:0,2048e6,0)|0;e=c[2438224]|0;b=gGS(f,K,e,(e|0)<0|0?-1:0)|0;e=gGK(b,K,-1,0)|0;b=e;c[3528508]=b;e=c[2443826]|0;if((b|0)<(e|0)){l=0}else{f=c[2443818]|0;c[2443826]=(f|0)==1073676288?1073676288:f+e|0;l=1}e=c[2443827]|0;if((b|0)<(e|0)){m=l}else{b=c[2443819]|0;c[2443827]=(b|0)==1073676288?1073676288:b+e|0;m=l|2}if((m&1|0)==0){n=g}else{n=ly(c[3540984]|0,0)|0|g}if((m&2|0)==0){o=n}else{e=c[3540984]|0;b=e+5886|0;f=a[b]|0;p=f&255;q=p|32;a[b]=q&255;do{if((p&128|0)==0){if(((d[e+5887|0]|0)&q|0)==0){break}a[b]=f|-96;r=c[e+5868>>2]|0;if((r|0)==0){break}gg[r&4095](c[e+5872>>2]|0,1)}}while(0);f=c[e+5860>>2]|0;if((f|0)!=0){gd[f&15]((c[e+5864>>2]|0)+1|0,+(c[e+5820>>2]|0)*+h[e+5912>>3])}o=(d[b]|0)>>>7|n}f=c[2443834]|0;if((c[3528508]|0)>=(f|0)){k=o;break}g=o;i=f;j=c[2438224]|0}return k|0}function UG(a,b){a=a|0;b=+b;var d=0,e=0,f=0;gu[c[3528468]&16383]();if(b==0.0){c[9775304+(a<<2)>>2]=1073676288;return}else{d=9775304+(a<<2)|0;c[d>>2]=~~(b*2048.0e6);a=gD[c[2433522]&8191]()|0;e=gGU(a,(a|0)<0|0?-1:0,2048e6,0)|0;a=c[2438224]|0;f=gGS(e,K,a,(a|0)<0|0?-1:0)|0;a=gGK(c[d>>2]|0,0,f,K)|0;c[d>>2]=a;return}}function UH(){return(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0}function UI(){return c[2113158]|0}function UJ(){return c[2113164]|0}function UK(a,b){a=a|0;b=b|0;var d=0;b=gj[c[2427010]&4095](c[2429368]|0)|0;a=c[2433534]|0;if((a|0)>=(b|0)){return}d=b-a|0;lz((c[2406688]|0)+(a+4<<1)|0,d);c[2433534]=(c[2433534]|0)+d;return}function UL(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,i=0,j=0,k=0,l=0;c[2438224]=0;c[2433522]=0;c[2406672]=0;c[3528468]=0;c[2443827]=1073676288;c[2443826]=1073676288;c[2443819]=1073676288;c[2443818]=1073676288;h[883198]=0.0;c[3528508]=0;g=a[9680]|0;i=g?32e3:0;if(!g){c[2427010]=2946;c[3542112]=218;if(a[7452584]|0){return}a[7452584]=1;g=0;while(1){j=lv(1,b,11025)|0;c[14163936+(g<<2)>>2]=j;if((j|0)==0){break}lw(j);j=g+1|0;if((j|0)<(a[7452584]&1|0)){g=j}else{k=46149;break}}if((k|0)==46149){return}a[7452584]=0;return}c[2427010]=e;if(a[9624]|0){e=i*3|0;k=(b|0)/72|0;while(1){if((k|0)>(e|0)){k=k>>1}else{break}}c[2429368]=k;c[3542112]=1338;c[2443884]=(k<<16>>>0)/32e3|0;c[2429608]=0;l=k}else{c[2429368]=i;c[3542112]=152;l=i}L59580:do{if(!(a[7452584]|0)){a[7452584]=1;i=0;while(1){k=lv(1,b,l)|0;c[14163936+(i<<2)>>2]=k;if((k|0)==0){break}lw(k);i=i+1|0;if((i|0)>=(a[7452584]&1|0)){break L59580}}a[7452584]=0}}while(0);l=c[3540984]|0;c[l+5868>>2]=d;c[l+5872>>2]=0;l=c[3540984]|0;c[l+5860>>2]=6;c[l+5864>>2]=0;l=c[3540984]|0;c[l+5876>>2]=1134;c[l+5880>>2]=0;l=gGq(8192)|0;c[2406688]=l;gGz(l|0,0,8192);c[2433534]=0;c[2429608]=0;c[2432972]=f;h[745398]=1.0;a[3203264]=1;return}function UM(a){a=a|0;return 0}function UN(a,b){a=a|0;b=b|0;return}function UO(d,f){d=d|0;f=f|0;var g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0.0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;g=((ag(c[2429368]|0,f)|0)/32e3|0)+1|0;i=c[2433534]|0;j=(g|0)<(i|0)?i:g;g=a[9688]|0?534:0;k=((g|0)<(f|0)?g:f)<<1;if((i|0)<(j|0)){l=j-i|0;m=c[2406688]|0;lz(m+(i+4<<1)|0,l);c[2433534]=(c[2433534]|0)+l;n=m}else{n=c[2406688]|0}c[2438938]=n+8;m=c[2429608]|0;l=m>>>15&131070;if((l|0)<(k|0)){i=a[3203264]|0?3:0;o=(i&1|0)==0;p=(i&2|0)==0;i=(c[2432972]|0)==0;q=c[2443884]|0;r=+h[745398];s=l;l=m;do{if(o){t=0;u=0;v=0;w=0}else{x=l>>16;t=~~(+(b[n+(x+1<<1)>>1]|0)*r);u=~~(r*+(b[n+(x+2<<1)>>1]|0));v=~~(r*+(b[n+(x+3<<1)>>1]|0));w=~~(r*+(b[n+(x+4<<1)>>1]|0))}if(p){y=0;z=0;A=0;B=0}else{x=l>>16;y=~~(+(b[n+(x+1<<1)>>1]|0)*r);z=~~(r*+(b[n+(x+2<<1)>>1]|0));A=~~(r*+(b[n+(x+3<<1)>>1]|0));B=~~(r*+(b[n+(x+4<<1)>>1]|0))}x=l>>>4<<2&16380;C=b[14130680+(x<<1)>>1]|0;D=ag(C,t)|0;E=b[14130680+((x|1)<<1)>>1]|0;F=(ag(E,u)|0)+D|0;D=b[14130680+((x|2)<<1)>>1]|0;G=F+(ag(D,v)|0)|0;F=b[14130680+((x|3)<<1)>>1]|0;x=G+(ag(F,w)|0)|0;G=(x|0)/16384|0;H=ag(C,y)|0;C=(ag(E,z)|0)+H|0;H=C+(ag(D,A)|0)|0;D=H+(ag(F,B)|0)|0;F=(D|0)/16384|0;if((x|0)<-536887295){I=-32768}else{I=(G|0)>32767?32767:G}if((D|0)<-536887295){J=-32768}else{J=(F|0)>32767?32767:F}if(i){b[d+(s<<1)>>1]=I&65535;b[d+((s|1)<<1)>>1]=J&65535}else{F=d+(s<<1)|0;b[F>>1]=(e[F>>1]|0)+I&65535;F=d+((s|1)<<1)|0;b[F>>1]=(e[F>>1]|0)+J&65535}s=s+2|0;l=l+q|0;}while((s|0)<(k|0));c[2429608]=l;K=l}else{K=m}if((g|0)>(f|0)){return}f=K>>16;g=j-f|0;if((g|0)>-4){j=-4;do{b[n+(j+4<<1)>>1]=b[n+(f+j+4<<1)>>1]|0;j=j+1|0;}while((j|0)<(g|0))}c[2429608]=K&65535;c[2433534]=g;return}function UP(d,f){d=d|0;f=f|0;var g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0.0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;g=c[2433534]|0;i=(g|0)>(f|0)?g:f;j=a[9688]|0?534:0;k=(j|0)<(f|0)?j:f;if((g|0)<(i|0)){f=i-g|0;l=c[2406688]|0;lz(l+(g+4<<1)|0,f);c[2433534]=(c[2433534]|0)+f;m=l}else{m=c[2406688]|0}l=m+8|0;c[2438938]=l;f=c[2429608]|0;if((f|0)<(k|0)){g=a[3203264]|0?3:0;n=(g&1|0)==0;o=(g&2|0)==0;g=(c[2432972]|0)==0;p=+h[745398];q=f;do{if(n){r=0}else{r=~~(+(b[m+(q+4<<1)>>1]|0)*p)}if(o){s=0}else{s=~~(+(b[m+(q+4<<1)>>1]|0)*p)}if((r|0)<-32768){t=-32768}else{t=(r|0)>32767?32767:r}if((s|0)<-32768){u=-32768}else{u=(s|0)>32767?32767:s}if(g){f=q<<1;b[d+(f<<1)>>1]=t&65535;b[d+((f|1)<<1)>>1]=u&65535}else{f=q<<1;v=d+(f<<1)|0;b[v>>1]=(e[v>>1]|0)+t&65535;v=d+((f|1)<<1)|0;b[v>>1]=(e[v>>1]|0)+u&65535}q=q+1|0;}while((q|0)<(k|0))}c[2429608]=k;if((i|0)<(j|0)){return}k=i-j|0;do{if((k|0)>0){b[l>>1]=b[m+(j+4<<1)>>1]|0;if((k|0)>1){w=1}else{break}do{b[m+(w+4<<1)>>1]=b[m+(w+j+4<<1)>>1]|0;w=w+1|0;}while((w|0)<(k|0))}}while(0);c[2429608]=0;c[2433534]=k;return}function UQ(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0;d=i;i=i+80|0;e=d|0;f=d+16|0;g=d+32|0;h=d+48|0;j=d+64|0;do{if((b|0)!=0){if((c[b>>2]|0)>=169249){break}c[b>>2]=169249}}while(0);if((a&64|0)==0){lG(1,a);i=d;return}else{gGz(j|0,0,12);c[j>>2]=9775304;c[j+4>>2]=8;c[j+12>>2]=111920;b=c[2076592]|0;gj[b&4095](j)|0;gGz(h|0,0,12);c[h>>2]=9775272;c[h+4>>2]=8;c[h+12>>2]=478936;j=c[2076592]|0;gj[j&4095](h)|0;gGz(g|0,0,12);c[g>>2]=7065584;c[g+4>>2]=8;c[g+12>>2]=373912;h=c[2076592]|0;gj[h&4095](g)|0;gGz(f|0,0,12);c[f>>2]=14114032;c[f+4>>2]=4;c[f+12>>2]=287368;g=c[2076592]|0;gj[g&4095](f)|0;lG(1,a);gGz(e|0,0,12);c[e>>2]=9734136;c[e+4>>2]=4;c[e+12>>2]=221488;a=c[2076592]|0;gj[a&4095](e)|0;i=d;return}}function UR(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=c[2405758]|0;if((f|0)>0){g=0;while(1){US(g,a[9688]|0?534:0);h=g+1|0;i=c[2405758]|0;if((h|0)<(i|0)){g=h}else{j=i;break}}}else{j=f}f=c[2406740]|0;g=c[2406658]|0;i=(e|0)==0;do{if((c[3528842]|0)==0){if(i){break}else{k=e;l=d;m=f;n=g}while(1){h=k-1|0;b[l>>1]=b[m>>1]|0;b[l+2>>1]=b[n>>1]|0;b[m>>1]=0;b[n>>1]=0;if((h|0)==0){break}else{k=h;l=l+4|0;m=m+2|0;n=n+2|0}}}else{if(i){break}else{o=d;p=f;q=g;r=e}while(1){h=r-1|0;s=(b[o>>1]|0)+(b[p>>1]|0)|0;if((s|0)<-32768){t=-32768}else{t=(s|0)>32767?32767:s&65535}b[o>>1]=t;s=o+2|0;u=(b[s>>1]|0)+(b[q>>1]|0)|0;if((u|0)<-32768){v=-32768}else{v=(u|0)>32767?32767:u&65535}b[s>>1]=v;b[p>>1]=0;b[q>>1]=0;if((h|0)==0){break}else{o=o+4|0;p=p+2|0;q=q+2|0;r=h}}}}while(0);if((j|0)>0){w=0}else{return}do{c[9542560+(w<<5)>>2]=0;w=w+1|0;}while((w|0)<(j|0));return}function US(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;if((c[2406740]|0)==0){f=a[9688]|0?1068:0;g=0;while(1){if((g|0)>=1024){h=0;break}i=9638528+(g<<2)|0;if((c[i>>2]|0)==0){j=46233;break}else{g=g+1|0}}do{if((j|0)==46233){g=gGq(f)|0;c[i>>2]=g;if((g|0)==0){h=0;break}gGz(g|0,0,f|0);h=g}}while(0);c[2406740]=h;gGz(h|0,0,(a[9688]|0?1068:0)|0)}h=c[2406658]|0;if((h|0)==0){f=a[9688]|0?1068:0;i=0;while(1){if((i|0)>=1024){k=0;break}l=9638528+(i<<2)|0;if((c[l>>2]|0)==0){j=46240;break}else{i=i+1|0}}do{if((j|0)==46240){i=gGq(f)|0;c[l>>2]=i;if((i|0)==0){k=0;break}gGz(i|0,0,f|0);k=i}}while(0);f=k;c[2406658]=f;gGz(k|0,0,(a[9688]|0?1068:0)|0);m=f}else{m=h}h=9542544+(d<<5)|0;if((c[9542564+(d<<5)>>2]|0)==0){return}f=a[9688]|0?534:0;k=(f|0)<(e|0)?f:e;e=9542560+(d<<5)|0;f=c[e>>2]|0;l=k-f|0;if((l|0)<1){return}j=(c[2406740]|0)+(f<<1)|0;i=m+(f<<1)|0;m=c[9542568+(d<<5)>>2]|0;if((m&1|0)==0){n=0}else{n=b[h>>1]|0}do{if((m&2|0)==0){c[e>>2]=k;if(!(n<<16>>16==0|(k|0)==(f|0))){o=j;p=l;break}return}else{d=b[h>>1]|0;c[e>>2]=k;g=d<<16>>16==0;q=n<<16>>16==0;r=(k|0)==(f|0);if(!(q|g)){if(r){return}else{s=i;t=j;u=l}while(1){v=u-1|0;b[t>>1]=(b[t>>1]|0)+n&65535;b[s>>1]=(b[s>>1]|0)+d&65535;if((v|0)==0){break}else{s=s+2|0;t=t+2|0;u=v}}return}if(!q){if(!r){o=j;p=l;break}return}if(r|g){return}else{w=i;x=l}while(1){v=x-1|0;b[w>>1]=(b[w>>1]|0)+d&65535;if((v|0)==0){break}else{w=w+2|0;x=v}}return}}while(0);while(1){x=p-1|0;b[o>>1]=(b[o>>1]|0)+n&65535;if((x|0)==0){break}else{o=o+2|0;p=x}}return}function UT(){var a=0,b=0,d=0,e=0,f=0;c[2385641]=0;c[2385643]=0;c[2385649]=0;c[2385651]=0;c[2385657]=0;c[2385659]=0;c[2385665]=0;c[2385667]=0;c[2385673]=0;c[2385675]=0;c[2385681]=0;c[2385683]=0;c[2385689]=0;c[2385691]=0;c[2385697]=0;c[2385699]=0;c[2405758]=0;a=c[2406740]|0;b=0;while(1){if((b|0)>=1024){break}d=9638528+(b<<2)|0;if((c[d>>2]|0)==(a|0)){e=46270;break}else{b=b+1|0}}if((e|0)==46270){gGr(a);c[d>>2]=0}c[2406740]=0;d=c[2406658]|0;a=0;while(1){if((a|0)>=1024){e=46276;break}f=9638528+(a<<2)|0;if((c[f>>2]|0)==(d|0)){break}else{a=a+1|0}}if((e|0)==46276){c[2406658]=0;return}gGr(d);c[f>>2]=0;c[2406658]=0;return}function UU(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;switch(b&255|0){case 74:{e=d[(c[2420426]|0)+1239|0]|0;return e|0};case 15:{b=c[2420426]|0;f=0;while(1){if((f|0)>=32){e=-256;g=46311;break}h=b+516+(f*22|0)+21|0;i=a[h]|0;if((i&2)==0){f=f+1|0}else{break}}if((g|0)==46311){return e|0}a[h]=i&-3;i=(a[b+1239|0]&a[b+1238|0])<<24>>24!=0;h=i&1;if(i){j=h;k=1}else{i=h;h=0;while(1){g=(a[b+516+(h*22|0)+21|0]&2)==0?i:1;l=h+1|0;m=(g|0)!=0;if((l|0)<32&(m^1)){i=g;h=l}else{j=g;k=m;break}}}h=b+1240|0;do{if((j|0)!=(c[h>>2]|0)){c[h>>2]=j;if(k){a[9706117]=1;break}else{a[9706117]=0;break}}}while(0);e=(f<<8|16384)&65535;return e|0};case 65:{f=c[2420426]|0;k=f+1239|0;j=a[k]&-3;a[k]=j;k=(j&a[f+1238|0])<<24>>24!=0;j=k&1;if(k){n=j;o=1}else{k=j;j=0;while(1){h=(a[f+516+(j*22|0)+21|0]&2)==0?k:1;b=j+1|0;i=(h|0)!=0;if((b|0)<32&(i^1)){k=h;j=b}else{n=h;o=i;break}}}j=f+1240|0;do{if((n|0)!=(c[j>>2]|0)){c[j>>2]=n;if(o){a[9706117]=1;break}else{a[9706117]=0;break}}}while(0);e=d[f+1229|0]|0;return e|0};case 76:{e=1;return e|0};case 67:{e=a[(c[2420426]|0)+1239|0]&3;return e|0};case 75:{e=128;return e|0};case 64:{f=c[2420426]|0;o=f+1239|0;n=a[o]&-2;a[o]=n;o=(n&a[f+1238|0])<<24>>24!=0;n=o&1;if(o){p=n;q=1}else{o=n;n=0;while(1){j=(a[f+516+(n*22|0)+21|0]&2)==0?o:1;k=n+1|0;i=(j|0)!=0;if((k|0)<32&(i^1)){o=j;n=k}else{p=j;q=i;break}}}n=f+1240|0;do{if((p|0)!=(c[n>>2]|0)){c[n>>2]=p;if(q){a[9706117]=1;break}else{a[9706117]=0;break}}}while(0);e=d[f+1221|0]|0;return e|0};case 13:{e=256;return e|0};default:{e=0;return e|0}}return 0}function UV(e,f,g){e=e|0;f=f|0;g=g|0;var h=0,i=0.0,j=0,k=0.0,l=0.0,m=0,n=0,o=0,p=0,q=0,r=0.0;switch(e&255|0){case 2:{e=c[2420426]|0;h=e+516+((d[e+1237|0]|0)*22|0)+6|0;e=b[h>>1]|0;if((g|0)==0){b[h>>1]=e&-256|f&255;return}else{b[h>>1]=e&255|(f&255)<<8;return}break};case 64:{if((g|0)!=0){return}e=c[2420426]|0;a[e+1221|0]=f;h=a[e+1220|0]|0;if(h<<24>>24==0){i=0.0}else{j=h&255;i=+((ag((f&255)+1|0,(j&31)+1|0)|0)<<(j>>>5)+4|0)*1.0e9/33868800.0}j=e+1224|0;h=~~i;if((c[j>>2]|0)==(h|0)){return}c[j>>2]=h;h=e+1222|0;if(i!=0.0){a[h]=1;return}else{a[h]=0;return}break};case 13:{if((g|0)==0){return}h=c[2420426]|0;a[h+516+((d[h+1237|0]|0)*22|0)+20|0]=f;return};case 4:{h=c[2420426]|0;e=h+516+((d[h+1237|0]|0)*22|0)+8|0;h=b[e>>1]|0;if((g|0)==0){b[e>>1]=h&-256|f&255;return}else{b[e>>1]=h&255|(f&255)<<8;return}break};case 16:{if((g|0)==0){return}h=c[2420426]|0;e=h+1237|0;a[h+516+((d[e]|0)*22|0)+17|0]=f;if(f<<24>>24!=0){return}j=h+516+((d[e]|0)*22|0)+21|0;a[j]=a[j]|1;return};case 5:{if((g|0)==0){return}j=c[2420426]|0;a[j+516+((d[j+1237|0]|0)*22|0)+13|0]=f;return};case 3:{if((g|0)==0){return}j=c[2420426]|0;a[j+516+((d[j+1237|0]|0)*22|0)+12|0]=f;return};case 65:{if((g|0)!=0){return}j=c[2420426]|0;a[j+1229|0]=f;e=a[j+1228|0]|0;if(e<<24>>24==0){k=0.0}else{h=e&255;k=+((ag((f&255)+1|0,(h&31)+1|0)|0)<<(h>>>5)+4|0)*1.0e9/33868800.0}h=j+1232|0;e=~~k;if((c[h>>2]|0)==(e|0)){return}c[h>>2]=e;e=j+1230|0;if(k!=0.0){a[e]=1;return}else{a[e]=0;return}break};case 1:{e=c[2420426]|0;j=e+516+((d[e+1237|0]|0)*22|0)|0;e=b[j>>1]|0;if((g|0)==0){b[j>>1]=e&-256|f&255;return}else{b[j>>1]=e&255|(f&255)<<8;return}break};case 7:{if((g|0)==0){return}e=c[2420426]|0;a[e+516+((d[e+1237|0]|0)*22|0)+18|0]=f;return};case 0:{if((g|0)==0){return}e=c[2420426]|0;a[e+516+((d[e+1237|0]|0)*22|0)+16|0]=f;return};case 12:{if((g|0)==0){return}e=c[2420426]|0;a[e+516+((d[e+1237|0]|0)*22|0)+15|0]=f;return};case 66:{if((g|0)!=0){return}e=c[2420426]|0;a[e+1220|0]=f;if(f<<24>>24==0){l=0.0}else{j=f&255;l=+((ag((d[e+1221|0]|0)+1|0,(j&31)+1|0)|0)<<(j>>>5)+4|0)*1.0e9/33868800.0}j=e+1224|0;h=~~l;if((c[j>>2]|0)==(h|0)){return}c[j>>2]=h;h=e+1222|0;if(l!=0.0){a[h]=1;return}else{a[h]=0;return}break};case 8:{if((g|0)==0){return}h=c[2420426]|0;a[h+516+((d[h+1237|0]|0)*22|0)+19|0]=f;return};case 74:{if((g|0)!=0){return}h=c[2420426]|0;a[h+1238|0]=f;e=(a[h+1239|0]&f)<<24>>24!=0;j=e&1;if(e){m=j;n=1}else{e=j;j=0;while(1){o=(a[h+516+(j*22|0)+21|0]&2)==0?e:1;p=j+1|0;q=(o|0)!=0;if((p|0)<32&(q^1)){e=o;j=p}else{m=o;n=q;break}}}j=h+1240|0;if((m|0)==(c[j>>2]|0)){return}c[j>>2]=m;if(n){a[9706117]=1;return}else{a[9706117]=0;return}break};case 9:{n=c[2420426]|0;m=n+516+((d[n+1237|0]|0)*22|0)+10|0;n=b[m>>1]|0;if((g|0)==0){b[m>>1]=n&-256|f&255;return}else{b[m>>1]=n&255|(f&255)<<8;return}break};case 79:{if((g|0)!=0){return}a[(c[2420426]|0)+1237|0]=f&31;return};case 17:{if((g|0)==0){return}n=c[2420426]|0;a[n+516+((d[n+1237|0]|0)*22|0)+14|0]=f;return};case 10:{n=c[2420426]|0;m=n+516+((d[n+1237|0]|0)*22|0)+2|0;n=b[m>>1]|0;if((g|0)==0){b[m>>1]=n&-256|f&255;return}else{b[m>>1]=n&255|(f&255)<<8;return}break};case 67:{if((g|0)!=0){return}n=c[2420426]|0;a[n+1228|0]=f;if(f<<24>>24==0){r=0.0}else{m=f&255;r=+((ag((d[n+1229|0]|0)+1|0,(m&31)+1|0)|0)<<(m>>>5)+4|0)*1.0e9/33868800.0}m=n+1232|0;j=~~r;if((c[m>>2]|0)==(j|0)){return}c[m>>2]=j;j=n+1230|0;if(r!=0.0){a[j]=1;return}else{a[j]=0;return}break};case 11:{j=c[2420426]|0;n=j+516+((d[j+1237|0]|0)*22|0)+4|0;j=b[n>>1]|0;if((g|0)==0){b[n>>1]=j&-256|f&255;return}else{b[n>>1]=j&255|(f&255)<<8;return}break};default:{return}}}function UW(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[2420426]|0;gGz(d|0,0,1244);c[d>>2]=c[3541280];e=0;do{f=e^255;g=(f<<1&30|33)<<(f>>>4&7);b[d+4+(e<<1)>>1]=((f&128|0)==0?g+65503|0:33-g|0)&65535;e=e+1|0;}while((e|0)<256);c[2443874]=a[9688]|0?67745:196608;e=(a[d+1239|0]&a[d+1238|0])<<24>>24!=0;g=e&1;if(e){h=g;i=1}else{e=g;g=0;while(1){f=(a[d+516+(g*22|0)+21|0]&2)==0?e:1;j=g+1|0;k=(f|0)!=0;if((j|0)<32&(k^1)){e=f;g=j}else{h=f;i=k;break}}}g=d+1240|0;do{if((h|0)!=(c[g>>2]|0)){c[g>>2]=h;if(i){a[9706117]=1;break}else{a[9706117]=0;break}}}while(0);gGz(9775472,0,6);gGz(9747064,0,3);return}function UX(a,d){a=a|0;d=d|0;var f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;gGz(a|0,0,d<<2|0);f=c[2420424]|0;if((c[f+332>>2]|0)==0){return}g=f|0;i=f+320|0;if(g>>>0>=(c[i>>2]|0)>>>0){return}j=(d|0)>0;k=f+416|0;l=g;do{g=c[l+8>>2]|0;do{if((c[l+16>>2]|0)==0){if((g|0)==0){break}m=c[l>>2]|0;if((m|0)==0){break}n=c[l+36>>2]<<5;o=c[f+352+(g<<2)>>2]|0;p=l+4|0;q=c[p>>2]|0;if(j){r=q;s=a;t=d;while(1){u=t-1|0;v=c[f+440>>2]|0;if((v&1|0)==0){w=0}else{w=~~(+(b[o+((r>>>((c[f+344>>2]|0)>>>0)&31|n)<<1)>>1]|0)*+h[f+424>>3])}if((v&2|0)==0){x=0}else{x=~~(+(b[o+((r>>>((c[f+344>>2]|0)>>>0)&31|n)<<1)>>1]|0)*+h[f+424>>3])}if((w|0)<-32768){y=-32768}else{y=(w|0)>32767?32767:w}if((x|0)<-32768){z=-32768}else{z=(x|0)>32767?32767:x}v=s+2|0;b[s>>1]=(e[s>>1]|0)+y&65535;b[v>>1]=(e[v>>1]|0)+z&65535;v=(ag(c[k>>2]|0,m)|0)+r|0;if((u|0)>0){r=v;s=s+4|0;t=u}else{A=v;break}}}else{A=q}c[p>>2]=A}else{t=c[l>>2]&255;if((g|0)==0|(t|0)==0){break}s=1<<(c[f+344>>2]|0)-16;r=l+32|0;m=c[r>>2]|0;n=t<<4;t=l+28|0;o=c[t>>2]|0;L60030:do{if(j){v=l+20|0;u=(((g>>1)*1792|0|0)/(c[f+328>>2]|0)|0)<<16>>16;B=-u|0;C=l+24|0;D=m;E=o;F=a;G=1;while(1){H=F+2|0;b[F>>1]=(e[F>>1]|0)+((c[v>>2]|0)==0?B:u)&65535;do{if((D|0)==0){I=E+n|0;J=I>>>12;K=I&4095;if((J|0)==0){L=K;M=s;break}I=J;J=c[C>>2]|0;do{if((J+1&2|0)!=0){c[v>>2]=c[v>>2]^1}J=((J&1|0)==0?J:J^163840)>>1;I=I-1|0;}while((I|0)>0);c[C>>2]=J;L=K;M=s}else{L=E;M=D-1|0}}while(0);if((G|0)>=(d|0)){N=M;O=L;break L60030}D=M;E=L;F=H;G=G+1|0}}else{N=m;O=o}}while(0);c[t>>2]=O;c[r>>2]=N}}while(0);l=l+40|0;}while(l>>>0<(c[i>>2]|0)>>>0);return}function UY(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=e&15;e=c[2433528]|0;g=e+b|0;h=f&255;if((a[g]|0)==f<<24>>24){return}a[g]=f;do{if(b>>>0<16){i=((b-5|0)>>>0)/5|0}else{if((b|0)==16){i=0;break}i=((b-17|0)>>>0)/5|0}}while(0);f=c[2420424]|0;if((i|0)>=(c[f+328>>2]|0)){return}g=i*5|0;switch(b-g|0){case 5:{c[f+(i*40|0)+36>>2]=h&7;return};case 16:case 17:case 18:case 19:case 20:{if((i|0)==0){j=d[e+16|0]|0}else{j=0}b=f+(i*40|0)|0;c[b>>2]=j;k=(d[e+(g+17)|0]<<4)+j|0;c[b>>2]=k;j=(d[e+(g+18)|0]<<8)+k|0;c[b>>2]=j;k=(d[e+(g+19)|0]<<12)+j|0;c[b>>2]=k;c[b>>2]=(d[e+(g+20)|0]<<16)+k;return};case 21:{c[f+(i*40|0)+8>>2]=h;return};default:{return}}}function UZ(e,f){e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;if((e|0)<256){g=(c[2438116]|0)+e|0;if((d[g]|0|0)==(f|0)){return}a[g]=f&255;g=c[2420424]|0;h=f&255;if((c[g+324>>2]|0)==1){i=(h>>>4<<16)-524288>>8;j=e<<1;k=(h<<16&983040)-524288>>8;l=j|1;m=g+328|0;n=0;do{o=ag(n,i)|0;p=g+352+(n<<2)|0;b[(c[p>>2]|0)+(j<<1)>>1]=((o|0)/(c[m>>2]|0)|0)&65535;o=ag(n,k)|0;b[(c[p>>2]|0)+(l<<1)>>1]=((o|0)/(c[m>>2]|0)|0)&65535;n=n+1|0;}while((n|0)<16);return}else{n=(h<<8&3840)-2048|0;b[(c[g+352>>2]|0)+(e<<1)>>1]=0;h=g+328|0;m=1;do{l=ag(m,n)|0;b[(c[g+352+(m<<2)>>2]|0)+(e<<1)>>1]=((l|0)/(c[h>>2]|0)|0)&65535;m=m+1|0;}while((m|0)<16);return}}m=f&255;a[(c[2438116]|0)+e|0]=m;if((e|0)>=320){return}h=e-256|0;if((h|0)>63){return}e=c[2433528]|0;g=e+h|0;if((d[g]|0|0)==(f|0)){return}a[g]=m;m=(h|0)/8|0;g=c[2420424]|0;if((m|0)>=(c[g+328>>2]|0)){return}n=m<<3;switch(h-n|0){case 1:{c[g+(m*40|0)+36>>2]=f>>>4&15;break};case 2:case 3:{break};case 4:{c[g+(m*40|0)+12>>2]=f&15;h=g+((m+1|0)*40|0)|0;c[((h|0)==(c[g+320>>2]|0)?g|0:h)+16>>2]=f>>>7&1;return};case 0:{c[g+(m*40|0)+8>>2]=f&15;return};default:{return}}f=(d[e+(n|1)|0]|0)<<16&983040;h=g+(m*40|0)|0;c[h>>2]=f;m=(d[e+(n|2)|0]|0)<<8|f;c[h>>2]=m;c[h>>2]=m|(d[e+(n|3)|0]|0);return}function U_(a,e){a=a|0;e=e|0;var f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;f=gGq(448)|0;g=f;c[2420424]=g;gGz(f|0,0,448);i=gGq(64)|0;c[2433528]=i;gGz(i|0,0,64);c[f+328>>2]=e;c[f+320>>2]=g+(e*40|0);c[f+348>>2]=0;e=f+336|0;c[e>>2]=a;f=c[2420424]|0;if((a|0)<192e3){i=f+336|0;j=0;k=e;e=a;while(1){c[k>>2]=e<<1;a=c[i>>2]|0;if((a|0)<192e3){j=j+1|0;k=i;e=a}else{break}}l=j+16|0;m=f;n=f}else{l=15;m=g;n=f}c[m+344>>2]=l;c[n+340>>2]=c[n+336>>2];l=c[3541148]|0;do{if((l|0)==0){if((c[n+328>>2]|0)==3){o=46549;break}c[n+324>>2]=1;p=512}else{c[2438116]=l;o=46549}}while(0);if((o|0)==46549){c[n+324>>2]=0;p=256}n=gGq(p<<5)|0;o=c[2420424]|0;l=o+352|0;c[l>>2]=n;c[o+356>>2]=n+(p<<1);m=p<<1;c[o+360>>2]=n+(m<<1);f=m+p|0;c[o+364>>2]=n+(f<<1);m=f+p|0;c[o+368>>2]=n+(m<<1);f=m+p|0;c[o+372>>2]=n+(f<<1);m=f+p|0;c[o+376>>2]=n+(m<<1);f=m+p|0;c[o+380>>2]=n+(f<<1);m=f+p|0;c[o+384>>2]=n+(m<<1);f=m+p|0;c[o+388>>2]=n+(f<<1);m=f+p|0;c[o+392>>2]=n+(m<<1);f=m+p|0;c[o+396>>2]=n+(f<<1);m=f+p|0;c[o+400>>2]=n+(m<<1);f=m+p|0;c[o+404>>2]=n+(f<<1);m=f+p|0;c[o+408>>2]=n+(m<<1);c[o+412>>2]=n+(m+p<<1);p=c[2438116]|0;if((p|0)!=0){m=o+324|0;n=o+328|0;f=0;do{g=d[p+f|0]|0;if((c[m>>2]|0)==1){j=(g>>>4<<16)-524288>>8;e=f<<1;i=(g<<16&983040)-524288>>8;k=e|1;a=0;do{q=ag(a,j)|0;r=o+352+(a<<2)|0;b[(c[r>>2]|0)+(e<<1)>>1]=((q|0)/(c[n>>2]|0)|0)&65535;q=ag(a,i)|0;b[(c[r>>2]|0)+(k<<1)>>1]=((q|0)/(c[n>>2]|0)|0)&65535;a=a+1|0;}while((a|0)<16)}else{a=(g<<8&3840)-2048|0;b[(c[l>>2]|0)+(f<<1)>>1]=0;k=1;do{i=ag(k,a)|0;b[(c[o+352+(k<<2)>>2]|0)+(f<<1)>>1]=((i|0)/(c[n>>2]|0)|0)&65535;k=k+1|0;}while((k|0)<16)}f=f+1|0;}while((f|0)<256)}c[o+332>>2]=1;f=o|0;n=o+320|0;if(f>>>0<(c[n>>2]|0)>>>0){s=f}else{t=o+416|0;c[t>>2]=6;u=o+424|0;h[u>>3]=1.0;v=o+432|0;h[v>>3]=1.0;w=o+440|0;c[w>>2]=3;x=o+444|0;c[x>>2]=3;return}do{c[s+36>>2]=0;gGz(s|0,0,24);c[s+24>>2]=1;c[s+28>>2]=0;c[s+32>>2]=0;s=s+40|0;}while(s>>>0<(c[n>>2]|0)>>>0);t=o+416|0;c[t>>2]=6;u=o+424|0;h[u>>3]=1.0;v=o+432|0;h[v>>3]=1.0;w=o+440|0;c[w>>2]=3;x=o+444|0;c[x>>2]=3;return}function U$(f,g){f=f|0;g=g|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;i=c[2420422]|0;if((a[i+98|0]|0)==0){return}j=c[2420378]|0;k=g<<2;gGz(j|0,0,k|0);l=c[2415138]|0;gGz(l|0,0,k|0);if((g|0)<=0){return}k=c[2443778]|0;m=0;do{L60150:do{if((a[i+(m*12|0)|0]|0)!=0){n=d[i+(m*12|0)+2|0]|0;o=d[i+(m*12|0)+1|0]|0;p=ag(n&15,o)|0;q=ag(n>>>4,o)|0;o=i+(m*12|0)+10|0;n=i+(m*12|0)+4|0;r=i+(m*12|0)+8|0;s=0;do{t=c[n>>2]|0;u=a[(t>>>11&65535)+(i+99)|0]|0;if(u<<24>>24==-1){v=e[o>>1]|0;w=v<<11;c[n>>2]=w;x=a[i+99+v|0]|0;if(x<<24>>24==-1){break L60150}else{y=x;z=w}}else{y=u;z=t}t=y&255;c[n>>2]=((ag(e[r>>1]|0,k)|0)>>>15)+z;if((t&128|0)==0){u=(ag(t,p)|0)>>>5;w=j+(s<<2)|0;c[w>>2]=(c[w>>2]|0)-u;u=(ag(t,q)|0)>>>5;w=l+(s<<2)|0;c[w>>2]=(c[w>>2]|0)-u}else{u=t&127;t=(ag(u,p)|0)>>>5;w=j+(s<<2)|0;c[w>>2]=(c[w>>2]|0)+t;t=(ag(u,q)|0)>>>5;u=l+(s<<2)|0;c[u>>2]=(c[u>>2]|0)+t}s=s+1|0;}while((s|0)<(g|0))}}while(0);m=m+1|0;}while((m|0)<8);m=i+65656|0;z=i+65660|0;k=i+65648|0;y=i+65640|0;i=0;do{s=j+(i<<2)|0;q=c[s>>2]|0;if((q|0)<-32768){A=-32768}else{A=(q|0)>32767?32704:q&-64}c[s>>2]=A;q=l+(i<<2)|0;p=c[q>>2]|0;if((p|0)<-32768){B=-32768}else{B=(p|0)>32767?32704:p&-64}c[q>>2]=B;q=c[m>>2]|0;if((q&1|0)==0){C=0}else{C=~~(+(c[s>>2]|0)*+h[y>>3])}if((q&2|0)==0){D=0}else{D=~~(+(c[s>>2]|0)*+h[y>>3])}s=c[z>>2]|0;if((s&1|0)==0){E=C}else{E=~~(+(B|0)*+h[k>>3])+C|0}if((s&2|0)==0){F=D}else{F=~~(+(B|0)*+h[k>>3])+D|0}if((E|0)<-32768){G=-32768}else{G=(E|0)>32767?32767:E&65535}if((F|0)<-32768){H=-32768}else{H=(F|0)>32767?32767:F&65535}b[f+(i<<1)>>1]=G;i=i+1|0;b[f+(i<<1)>>1]=H;}while((i|0)<(g|0));return}function U0(a,d,f,g){a=a|0;d=d|0;f=f|0;g=g|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0.0,E=0,F=0,G=0,H=0,I=0.0;i=9762496+(a*80|0)|0;j=9762500+(a*80|0)|0;k=c[j>>2]|0;l=c[9762504+(a*80|0)>>2]|0;if((l|0)==0){if((g|0)==0){m=k;c[j>>2]=m;return}n=9762512+(a*80|0)|0;o=i|0;p=9762528+(a*80|0)|0;q=9762532+(a*80|0)|0;r=9762520+(a*80|0)|0;s=f;t=k;u=d;v=g;while(1){w=v-1|0;x=((ag(~~(+(b[u>>1]|0)*+h[n>>3])-t|0,c[o>>2]|0)|0)/65536|0)+t|0;y=c[p>>2]|0;if((y&1|0)==0){z=0}else{z=~~(+(x|0)*+h[r>>3])}if((y&2|0)==0){A=0}else{A=~~(+(x|0)*+h[r>>3])}if((z|0)<-32768){B=-32768}else{B=(z|0)>32767?32767:z}if((A|0)<-32768){C=-32768}else{C=(A|0)>32767?32767:A}if((c[q>>2]|0)==0){b[s>>1]=B&65535;b[s+2>>1]=C&65535}else{b[s>>1]=(e[s>>1]|0)+B&65535;y=s+2|0;b[y>>1]=(e[y>>1]|0)+C&65535}if((w|0)==0){m=x;break}else{s=s+4|0;t=x;u=u+2|0;v=w}}c[j>>2]=m;return}else if((l|0)==1|(l|0)==2){if((g|0)==0){m=k;c[j>>2]=m;return}l=9762512+(a*80|0)|0;v=9762528+(a*80|0)|0;u=9762532+(a*80|0)|0;t=i|0;i=9762520+(a*80|0)|0;a=f;f=k;s=d;d=g;D=+h[l>>3];while(1){g=d-1|0;C=~~(D*+(b[s>>1]|0))-f&65535;B=c[v>>2]|0;if((B&1|0)==0){E=0}else{E=~~(+(C<<16>>16|0)*+h[i>>3])}if((B&2|0)==0){F=0}else{F=~~(+(C<<16>>16|0)*+h[i>>3])}if((E|0)<-32768){G=-32768}else{G=(E|0)>32767?32767:E}if((F|0)<-32768){H=-32768}else{H=(F|0)>32767?32767:F}if((c[u>>2]|0)==0){b[a>>1]=G&65535;b[a+2>>1]=H&65535}else{b[a>>1]=(e[a>>1]|0)+G&65535;C=a+2|0;b[C>>1]=(e[C>>1]|0)+H&65535}I=+h[l>>3];C=((ag(~~(+(b[s>>1]|0)*I)-f|0,c[t>>2]|0)|0)/65536|0)+f|0;if((g|0)==0){m=C;break}else{a=a+4|0;f=C;s=s+2|0;d=g;D=I}}c[j>>2]=m;return}else{m=k;c[j>>2]=m;return}}function U1(b){b=b|0;var e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=gGU(b,(b|0)<0|0?-1:0,2048e6,0)|0;b=c[2438222]|0;f=gGS(e,K,b,(b|0)<0|0?-1:0)|0;e=f;c[2443832]=e;if((c[3528506]|0)<(e|0)){g=0;i=e;j=b}else{return}while(1){b=c[2443824]|0;e=c[2443825]|0;f=(b|0)>(e|0)?e:b;b=((f|0)>(i|0)?i:f)+(c[2443840]|0)|0;f=gGU(b,(b|0)<0|0?-1:0,j,(j|0)<0|0?-1:0)|0;b=gGS(f,K,2048e6,0)|0;f=c[2406670]|0;e=b-(gD[c[2433520]&8191]()|0)|0;gj[f&4095](e)|0;e=(gD[c[2433520]&8191]()|0)+1|0;f=gGU(e,(e|0)<0|0?-1:0,2048e6,0)|0;e=c[2438222]|0;b=gGS(f,K,e,(e|0)<0|0?-1:0)|0;e=gGK(b,K,-1,0)|0;b=e;c[3528506]=b;e=c[2443824]|0;if((b|0)<(e|0)){k=0}else{f=c[2443816]|0;c[2443824]=(f|0)==1073676288?1073676288:f+e|0;k=1}e=c[2443825]|0;if((b|0)<(e|0)){l=k}else{b=c[2443817]|0;c[2443825]=(b|0)==1073676288?1073676288:b+e|0;l=k|2}if((l&1|0)==0){m=g}else{m=ly(c[3540986]|0,0)|0|g}if((l&2|0)==0){n=m}else{e=c[3540986]|0;b=e+5886|0;f=a[b]|0;o=f&255;p=o|32;a[b]=p&255;do{if((o&128|0)==0){if(((d[e+5887|0]|0)&p|0)==0){break}a[b]=f|-96;q=c[e+5868>>2]|0;if((q|0)==0){break}gg[q&4095](c[e+5872>>2]|0,1)}}while(0);f=c[e+5860>>2]|0;if((f|0)!=0){gd[f&15]((c[e+5864>>2]|0)+1|0,+(c[e+5820>>2]|0)*+h[e+5912>>3])}n=(d[b]|0)>>>7|m}f=c[2443832]|0;if((c[3528506]|0)>=(f|0)){break}g=n;i=f;j=c[2438222]|0}return}function U2(a,b){a=a|0;b=+b;var d=0,e=0,f=0;gu[c[3528466]&16383]();if(b==0.0){c[9775296+(a<<2)>>2]=1073676288;return}else{d=9775296+(a<<2)|0;c[d>>2]=~~(b*2048.0e6);a=gD[c[2433520]&8191]()|0;e=gGU(a,(a|0)<0|0?-1:0,2048e6,0)|0;a=c[2438222]|0;f=gGS(e,K,a,(a|0)<0|0?-1:0)|0;a=gGK(c[d>>2]|0,0,f,K)|0;c[d>>2]=a;return}}function U3(){return c[2113158]|0}function U4(){return c[2113164]|0}function U5(a,b){a=a|0;b=b|0;var d=0;b=gj[c[2427012]&4095](c[2429370]|0)|0;a=c[2433536]|0;if((a|0)>=(b|0)){return}d=b-a|0;lC((c[2406686]|0)+(a+4<<1)|0,d);c[2433536]=(c[2433536]|0)+d;return}function U6(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,i=0,j=0,k=0,l=0;c[2438222]=0;c[2433520]=0;c[2406670]=0;c[3528466]=0;c[2443825]=1073676288;c[2443824]=1073676288;c[2443817]=1073676288;c[2443816]=1073676288;h[883199]=0.0;c[3528506]=0;g=a[9680]|0;i=g?32e3:0;if(!g){c[2427012]=1360;c[3542114]=2370;if(a[7452592]|0){return}a[7452592]=1;g=0;while(1){j=lv(0,b,11025)|0;c[14163944+(g<<2)>>2]=j;if((j|0)==0){break}lw(j);j=g+1|0;if((j|0)<(a[7452592]&1|0)){g=j}else{k=46685;break}}if((k|0)==46685){return}a[7452592]=0;return}c[2427012]=e;if(a[9624]|0){e=i*3|0;k=(b|0)/72|0;while(1){if((k|0)>(e|0)){k=k>>1}else{break}}c[2429370]=k;c[3542114]=1706;c[2443882]=(k<<16>>>0)/32e3|0;c[2429606]=0;l=k}else{c[2429370]=i;c[3542114]=2792;l=i}L60300:do{if(!(a[7452592]|0)){a[7452592]=1;i=0;while(1){k=lv(0,b,l)|0;c[14163944+(i<<2)>>2]=k;if((k|0)==0){break}lw(k);i=i+1|0;if((i|0)>=(a[7452592]&1|0)){break L60300}}a[7452592]=0}}while(0);l=c[3540986]|0;c[l+5868>>2]=d;c[l+5872>>2]=0;l=c[3540986]|0;c[l+5860>>2]=4;c[l+5864>>2]=0;l=c[3540986]|0;c[l+5876>>2]=508;c[l+5880>>2]=0;l=gGq(8192)|0;c[2406686]=l;gGz(l|0,0,8192);c[2433536]=0;c[2429606]=0;c[2432974]=f;h[745399]=1.0;a[3203272]=1;return}function U7(a){a=a|0;return 0}function U8(a,b){a=a|0;b=b|0;return}function U9(d,f){d=d|0;f=f|0;var g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0.0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;g=((ag(c[2429370]|0,f)|0)/32e3|0)+1|0;i=c[2433536]|0;j=(g|0)<(i|0)?i:g;g=a[9688]|0?534:0;k=((g|0)<(f|0)?g:f)<<1;if((i|0)<(j|0)){l=j-i|0;m=c[2406686]|0;lC(m+(i+4<<1)|0,l);c[2433536]=(c[2433536]|0)+l;n=m}else{n=c[2406686]|0}c[2438940]=n+8;m=c[2429606]|0;l=m>>>15&131070;if((l|0)<(k|0)){i=a[3203272]|0?3:0;o=(i&1|0)==0;p=(i&2|0)==0;i=(c[2432974]|0)==0;q=c[2443882]|0;r=+h[745399];s=l;l=m;do{if(o){t=0;u=0;v=0;w=0}else{x=l>>16;t=~~(+(b[n+(x+1<<1)>>1]|0)*r);u=~~(r*+(b[n+(x+2<<1)>>1]|0));v=~~(r*+(b[n+(x+3<<1)>>1]|0));w=~~(r*+(b[n+(x+4<<1)>>1]|0))}if(p){y=0;z=0;A=0;B=0}else{x=l>>16;y=~~(+(b[n+(x+1<<1)>>1]|0)*r);z=~~(r*+(b[n+(x+2<<1)>>1]|0));A=~~(r*+(b[n+(x+3<<1)>>1]|0));B=~~(r*+(b[n+(x+4<<1)>>1]|0))}x=l>>>4<<2&16380;C=b[14130680+(x<<1)>>1]|0;D=ag(C,t)|0;E=b[14130680+((x|1)<<1)>>1]|0;F=(ag(E,u)|0)+D|0;D=b[14130680+((x|2)<<1)>>1]|0;G=F+(ag(D,v)|0)|0;F=b[14130680+((x|3)<<1)>>1]|0;x=G+(ag(F,w)|0)|0;G=(x|0)/16384|0;H=ag(C,y)|0;C=(ag(E,z)|0)+H|0;H=C+(ag(D,A)|0)|0;D=H+(ag(F,B)|0)|0;F=(D|0)/16384|0;if((x|0)<-536887295){I=-32768}else{I=(G|0)>32767?32767:G}if((D|0)<-536887295){J=-32768}else{J=(F|0)>32767?32767:F}if(i){b[d+(s<<1)>>1]=I&65535;b[d+((s|1)<<1)>>1]=J&65535}else{F=d+(s<<1)|0;b[F>>1]=(e[F>>1]|0)+I&65535;F=d+((s|1)<<1)|0;b[F>>1]=(e[F>>1]|0)+J&65535}s=s+2|0;l=l+q|0;}while((s|0)<(k|0));c[2429606]=l;K=l}else{K=m}if((g|0)>(f|0)){return}f=K>>16;g=j-f|0;if((g|0)>-4){j=-4;do{b[n+(j+4<<1)>>1]=b[n+(f+j+4<<1)>>1]|0;j=j+1|0;}while((j|0)<(g|0))}c[2429606]=K&65535;c[2433536]=g;return}function Va(d,f){d=d|0;f=f|0;var g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0.0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;g=c[2433536]|0;i=(g|0)>(f|0)?g:f;j=a[9688]|0?534:0;k=(j|0)<(f|0)?j:f;if((g|0)<(i|0)){f=i-g|0;l=c[2406686]|0;lC(l+(g+4<<1)|0,f);c[2433536]=(c[2433536]|0)+f;m=l}else{m=c[2406686]|0}l=m+8|0;c[2438940]=l;f=c[2429606]|0;if((f|0)<(k|0)){g=a[3203272]|0?3:0;n=(g&1|0)==0;o=(g&2|0)==0;g=(c[2432974]|0)==0;p=+h[745399];q=f;do{if(n){r=0}else{r=~~(+(b[m+(q+4<<1)>>1]|0)*p)}if(o){s=0}else{s=~~(+(b[m+(q+4<<1)>>1]|0)*p)}if((r|0)<-32768){t=-32768}else{t=(r|0)>32767?32767:r}if((s|0)<-32768){u=-32768}else{u=(s|0)>32767?32767:s}if(g){f=q<<1;b[d+(f<<1)>>1]=t&65535;b[d+((f|1)<<1)>>1]=u&65535}else{f=q<<1;v=d+(f<<1)|0;b[v>>1]=(e[v>>1]|0)+t&65535;v=d+((f|1)<<1)|0;b[v>>1]=(e[v>>1]|0)+u&65535}q=q+1|0;}while((q|0)<(k|0))}c[2429606]=k;if((i|0)<(j|0)){return}k=i-j|0;do{if((k|0)>0){b[l>>1]=b[m+(j+4<<1)>>1]|0;if((k|0)>1){w=1}else{break}do{b[m+(w+4<<1)>>1]=b[m+(w+j+4<<1)>>1]|0;w=w+1|0;}while((w|0)<(k|0))}}while(0);c[2429606]=0;c[2433536]=k;return}function Vb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0;d=i;i=i+80|0;e=d|0;f=d+16|0;g=d+32|0;h=d+48|0;j=d+64|0;do{if((b|0)!=0){if((c[b>>2]|0)>=169249){break}c[b>>2]=169249}}while(0);if((a&64|0)==0){lG(2,a);i=d;return}else{gGz(j|0,0,12);c[j>>2]=9775296;c[j+4>>2]=8;c[j+12>>2]=111920;b=c[2076592]|0;gj[b&4095](j)|0;gGz(h|0,0,12);c[h>>2]=9775264;c[h+4>>2]=8;c[h+12>>2]=478936;j=c[2076592]|0;gj[j&4095](h)|0;gGz(g|0,0,12);c[g>>2]=7065592;c[g+4>>2]=8;c[g+12>>2]=367200;h=c[2076592]|0;gj[h&4095](g)|0;gGz(f|0,0,12);c[f>>2]=14114024;c[f+4>>2]=4;c[f+12>>2]=287368;g=c[2076592]|0;gj[g&4095](f)|0;lG(2,a);gGz(e|0,0,12);c[e>>2]=9734144;c[e+4>>2]=4;c[e+12>>2]=218760;a=c[2076592]|0;gj[a&4095](e)|0;i=d;return}}function Vc(b){b=b|0;var d=0,e=0,f=0,g=0,i=0;d=a[9680]|0;e=d?32e3:0;if(!d){mw(b,11025);return}if(a[9624]|0){d=e*3|0;f=b>>6;while(1){if((f|0)>(d|0)){f=f>>1}else{g=1222;i=f;break}}}else{g=2462;i=e}c[2429380]=i;c[3542124]=g;mw(b,i);i=gGq(262144)|0;c[2406684]=i;gGz(i|0,0,262144);c[2443880]=(c[2429380]<<16>>>0)/32e3|0;c[2429604]=262144;c[2432834]=0;c[2439244]=0;h[745421]=1.0;h[745420]=1.0;c[2436794]=3;c[2436792]=3;return}function Vd(d,e){d=d|0;e=e|0;var f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0.0,r=0.0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;f=(c[2439244]|0)+e|0;c[2439244]=f;if((f|0)<((a[9680]|0?32e3:0)|0)){g=f;i=c[2432834]|0}else{c[2439244]=e;f=c[2429604]|0;j=f>>>16;k=j-3|0;l=c[2438972]|0;b[l+2>>1]=b[l+(k<<1)>>1]|0;m=j-2|0;b[l+4>>1]=b[l+(m<<1)>>1]|0;n=j-1|0;b[l+6>>1]=b[l+(n<<1)>>1]|0;o=c[2438970]|0;b[o+2>>1]=b[o+(k<<1)>>1]|0;b[o+4>>1]=b[o+(m<<1)>>1]|0;b[o+6>>1]=b[o+(n<<1)>>1]|0;n=4-j+(c[2432834]|0)|0;c[2432834]=n;m=0;do{k=j+m|0;p=m+4|0;b[l+(p<<1)>>1]=b[l+(k<<1)>>1]|0;b[o+(p<<1)>>1]=b[o+(k<<1)>>1]|0;m=m+1|0;}while(m>>>0<=n>>>0);c[2429604]=f&65535|262144;g=e;i=n}n=c[2406684]|0;c[2438972]=n+(i+4<<1);c[2438970]=n+(i+65540<<1);my((((ag(c[2429380]|0,g+1|0)|0)>>>0)/32e3|0)-i|0);c[2432834]=((ag((c[2439244]|0)+1|0,c[2429380]|0)|0)>>>0)/32e3|0;i=c[2406684]|0;c[2438972]=i;c[2438970]=i+131072;g=e<<1;if((g|0)<=0){return}e=c[2436794]|0;n=(e&1|0)==0;f=(e&2|0)==0;e=c[2436792]|0;m=(e&1|0)==0;o=(e&2|0)==0;e=c[2443880]|0;q=+h[745420];r=+h[745421];l=0;j=c[2429604]|0;do{if(n){s=0;t=0;u=0;v=0}else{k=j>>>16;s=~~(+(b[i+(k-3<<1)>>1]|0)*r);t=~~(r*+(b[i+(k-2<<1)>>1]|0));u=~~(r*+(b[i+(k-1<<1)>>1]|0));v=~~(r*+(b[i+(k<<1)>>1]|0))}if(f){w=0;x=0;y=0;z=0}else{k=j>>>16;w=~~(+(b[i+(k-3<<1)>>1]|0)*r);x=~~(r*+(b[i+(k-2<<1)>>1]|0));y=~~(r*+(b[i+(k-1<<1)>>1]|0));z=~~(r*+(b[i+(k<<1)>>1]|0))}if(m){A=s;B=t;C=u;D=v}else{k=j>>>16;A=~~(+(b[i+(k+65533<<1)>>1]|0)*q)+s|0;B=~~(q*+(b[i+(k+65534<<1)>>1]|0))+t|0;C=~~(q*+(b[i+(k+65535<<1)>>1]|0))+u|0;D=~~(q*+(b[i+((k|65536)<<1)>>1]|0))+v|0}if(o){E=w;F=x;G=y;H=z}else{k=j>>>16;E=~~(+(b[i+(k+65533<<1)>>1]|0)*q)+w|0;F=~~(q*+(b[i+(k+65534<<1)>>1]|0))+x|0;G=~~(q*+(b[i+(k+65535<<1)>>1]|0))+y|0;H=~~(q*+(b[i+((k|65536)<<1)>>1]|0))+z|0}k=j>>>4<<2&16380;p=b[14130680+(k<<1)>>1]|0;I=ag(p,A)|0;J=b[14130680+((k|1)<<1)>>1]|0;K=(ag(J,B)|0)+I|0;I=b[14130680+((k|2)<<1)>>1]|0;L=K+(ag(I,C)|0)|0;K=b[14130680+((k|3)<<1)>>1]|0;k=L+(ag(K,D)|0)|0;L=ag(p,E)|0;p=(ag(J,F)|0)+L|0;L=p+(ag(I,G)|0)|0;I=L+(ag(K,H)|0)|0;if((k|0)<-536887295){M=-32768}else{M=(k|0)>536870911?32767:((k|0)/16384|0)&65535}if((I|0)<-536887295){N=-32768}else{N=(I|0)>536870911?32767:((I|0)/16384|0)&65535}b[d+(l<<1)>>1]=M;b[d+((l|1)<<1)>>1]=N;l=l+2|0;j=j+e|0;}while((l|0)<(g|0));c[2429604]=j;return}function Ve(a,d){a=a|0;d=d|0;var e=0,f=0,g=0,i=0,j=0,k=0.0,l=0,m=0.0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;c[2439244]=(c[2439244]|0)+d;e=c[2406684]|0;c[2438972]=e;c[2438970]=e+(d<<1);my(d);if((d|0)<=0){return}e=c[2436794]|0;f=(e&1|0)==0;g=(e&2|0)==0;e=c[2436792]|0;i=(e&1|0)==0;j=(e&2|0)==0;e=c[2438970]|0;k=+h[745420];l=c[2438972]|0;m=+h[745421];n=0;do{if(f){o=0}else{o=~~(+(b[l+(n<<1)>>1]|0)*m)}if(g){p=0}else{p=~~(+(b[l+(n<<1)>>1]|0)*m)}if(i){q=o}else{q=~~(+(b[e+(n<<1)>>1]|0)*k)+o|0}if(j){r=p}else{r=~~(+(b[e+(n<<1)>>1]|0)*k)+p|0}if((q|0)<-32768){s=-32768}else{s=(q|0)>32767?32767:q&65535}if((r|0)<-32768){t=-32768}else{t=(r|0)>32767?32767:r&65535}u=n<<1;b[a+(u<<1)>>1]=s;b[a+((u|1)<<1)>>1]=t;n=n+1|0;}while((n|0)<(d|0));return}function Vf(e){e=e|0;var f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0.0,W=0.0,X=0,Y=0,Z=0,_=0,$=0,aa=0;f=i;i=i+1464|0;g=f|0;j=f+88|0;k=f+176|0;l=f+440|0;m=f+1352|0;n=f+1456|0;if(!(a[9680]|0)){c[2439194]=0;i=f;return}o=f+1088|0;be(o|0,260,104928,(p=i,i=i+16|0,c[p>>2]=9374064,c[p+8>>2]=47,p)|0)|0;i=p;q=c[(c[642608+(c[2436]<<2)>>2]|0)+12>>2]|0;if((q|0)==0){c[2439194]=0;i=f;return}r=f+960|0;gGI(r|0,q|0)|0;q=f+704|0;be(q|0,256,475200,(p=i,i=i+16|0,c[p>>2]=o,c[p+8>>2]=r,p)|0)|0;i=p;s=fw(q|0,364392)|0;if((s|0)==0){i=f;return}aY(s|0)|0;c[2442914]=e;c[2439194]=0;e=m+100|0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+84>>2]&16383](m,0)|0;s=c[2439194]|0;if((c[e>>2]|0)==0){t=s}else{u=0;v=s;while(1){c[2439194]=v+1;s=u+1|0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+84>>2]&16383](m,s)|0;w=c[2439194]|0;if((c[e>>2]|0)==0){t=w;break}else{u=s;v=w}}}v=t*40|0;u=gGq(v)|0;c[2406652]=u;gGz(u|0,0,v|0);if((t|0)<=0){i=f;return}t=l|0;l=k|0;k=g+32|0;v=j+32|0;u=0;while(1){gA[c[(c[642608+(c[2436]<<2)>>2]|0)+84>>2]&16383](m,u)|0;c[n>>2]=0;gp[c[(c[642608+(c[2436]<<2)>>2]|0)+88>>2]&16383](n,u,0)|0;c[3528400]=(c[2406652]|0)+(u*40|0);if((c[e>>2]|0)==0){x=46880;break}cC(q|0,285248,(p=i,i=i+16|0,c[p>>2]=o,c[p+8>>2]=r,p)|0)|0;i=p;w=c[n>>2]|0;a[632384]=0;cC(l|0,328824,(p=i,i=i+8|0,c[p>>2]=q,p)|0)|0;i=p;s=li(l)|0;c[2426512]=s;L60481:do{if((s|0)==0){y=0;x=46870}else{a[632384]=1;z=s+120|0;A=c[z+4>>2]|0;B=s+88|0;c[B>>2]=c[z>>2];c[B+4>>2]=A;A=s+80|0;c[A>>2]=0;c[A+4>>2]=0;A=s+96|0;c[A>>2]=(ll(s,s+128|0,s+216|0,0,0)|0)==0;c[A+4>>2]=0;c[2385534]=0;if(!(a[632384]|0)){y=0;x=46870;break}A=c[2426512]|0;do{if((A|0)!=0){B=c[A+56>>2]|0;if((B|0)<1){lj(A);c[2426512]=0;break}z=A+120|0;C=c[z+4>>2]|0;D=A+88|0;c[D>>2]=c[z>>2];c[D+4>>2]=C;C=A+80|0;c[C>>2]=0;c[C+4>>2]=0;C=(ll(A,A+128|0,A+216|0,0,0)|0)==0;D=A+96|0;c[D>>2]=C&1;c[D+4>>2]=0;if(!C){lj(c[2426512]|0);y=0;x=46870;break L60481}do{if((w|0)==0){if((ll(c[2426512]|0,g,0,0,0)|0)==0){E=c[k>>2]|0;break}C=c[2426512]|0;if(a[632384]&(C|0)!=0){lj(C);c[2426512]=0}a[632384]=0;y=0;x=46870;break L60481}else{gGz(t|0,0,260);c[2385534]=0;L60494:do{if((B|0)>0){C=0;while(1){if((ll(c[2426512]|0,j,0,t,260)|0)==0){F=c[v>>2]|0;if((fa(t|0,w|0)|0)==0){break}else{G=F}}else{G=C}D=(c[2385534]|0)+1|0;c[2385534]=D;z=c[2426512]|0;if((z|0)==0){H=D;I=G;break L60494}J=z+96|0;if((c[J>>2]|0)==0&(c[J+4>>2]|0)==0){H=D;I=G;break L60494}L=z+56|0;M=c[L>>2]|0;N=c[L+4>>2]|0;L=z+80|0;O=gGK(c[L>>2]|0,c[L+4>>2]|0,1,0)|0;P=K;if(((M|0)!=65535|(N|0)!=0)&((O|0)==(M|0)&(P|0)==(N|0))){H=D;I=G;break L60494}D=z+88|0;N=gGK((c[z+168>>2]|0)+46+(c[z+172>>2]|0)+(c[z+176>>2]|0)|0,0,c[D>>2]|0,c[D+4>>2]|0)|0;c[D>>2]=N;c[D+4>>2]=K;c[L>>2]=O;c[L+4>>2]=P;P=(ll(z,z+128|0,z+216|0,0,0)|0)==0;c[J>>2]=P&1;c[J+4>>2]=0;J=c[2385534]|0;if((J|0)<(B|0)&P){C=G}else{H=J;I=G;break L60494}}H=c[2385534]|0;I=F}else{H=0;I=0}}while(0);if((H|0)!=(B|0)){E=I;break}C=c[2426512]|0;if(a[632384]&(C|0)!=0){lj(C);c[2426512]=0}a[632384]=0;y=0;x=46870;break L60481}}while(0);if((lm(c[2426512]|0)|0)!=0){B=c[2426512]|0;lk(B)|0;B=c[2426512]|0;if(a[632384]&(B|0)!=0){lj(B);c[2426512]=0}a[632384]=0;y=0;x=46870;break L60481}B=gGq(E)|0;C=c[2426512]|0;if((B|0)==0){lk(C)|0;J=c[2426512]|0;if(a[632384]&(J|0)!=0){lj(J);c[2426512]=0}a[632384]=0;y=0;x=46870;break L60481}J=ln(C,B,E)|0;C=(J|0)<0?0:J;J=lk(c[2426512]|0)|0;P=c[2426512]|0;if(a[632384]&(P|0)!=0){lj(P);c[2426512]=0}a[632384]=0;do{if((J|0)==0){Q=B;R=C}else if((J|0)==(-105|0)){if((B|0)==0){Q=0;R=C;break}gGr(B);Q=B;R=C}else{if((B|0)==0){Q=0;R=C;break}gGr(B);Q=B;R=C}}while(0);if((R|0)==0){y=Q;x=46870;break L60481}do{if((a[Q]|0)==82){if((a[Q+1|0]|0)!=73){S=Q;break}if((a[Q+2|0]|0)!=70){S=Q;break}if((a[Q+3|0]|0)!=70){S=Q;break}C=d[Q+18|0]<<16|d[Q+19|0]<<24|d[Q+17|0]<<8|d[Q+16|0];B=d[Q+23|0]<<8|d[Q+22|0];J=d[Q+26|0]<<16|d[Q+27|0]<<24|d[Q+25|0]<<8|d[Q+24|0];P=((d[Q+35|0]<<8|d[Q+34|0])&65535)>>>3;z=Q+(C+20)|0;do{if((a[z]|0)==100){if((a[Q+(C+21)|0]|0)!=97){x=46859;break}if((a[Q+(C+22)|0]|0)!=116){x=46859;break}if((a[Q+(C+23)|0]|0)==97){T=z;U=Q}else{x=46859}}else{x=46859}}while(0);if((x|0)==46859){x=0;T=Q+(C+28+(d[Q+(C+26)|0]<<16|d[Q+(C+27)|0]<<24|d[Q+(C+25)|0]<<8|d[Q+(C+24)|0]))|0;U=Q}z=d[T+6|0]<<16|d[T+7|0]<<24|d[T+5|0]<<8|d[T+4|0];L=T+8|0;O=U-L+R|0;V=+(J>>>0>>>0);W=(a[9680]|0?32.0e3:0.0)/V*+((O>>>0<z>>>0?O:z)>>>0>>>0);z=B&65535;O=~~(W/+(ag(P&65535,z)|0));if((O|0)==0){S=U;break}D=gGq(O<<2)|0;N=c[3528400]|0;c[N>>2]=D;M=D;D=L;L=z>>>1;X=L+8|0;if((P<<16>>16|0)==2){W=V/(a[9680]|0?32.0e3:0.0);Y=0;do{Z=ag(~~(+(Y>>>0>>>0)*W),z)|0;_=Y<<1;b[M+(_<<1)>>1]=b[D+(Z<<1)>>1]|0;b[M+((_|1)<<1)>>1]=b[D+(Z+L<<1)>>1]|0;Y=Y+1|0;}while(Y>>>0<O>>>0)}else if((P<<16>>16|0)==1){W=V/(a[9680]|0?32.0e3:0.0);Y=0;do{L=ag(~~(+(Y>>>0>>>0)*W),z)|0;D=Y<<1;b[M+(D<<1)>>1]=d[T+(L+8)|0]<<8^-32768;b[M+((D|1)<<1)>>1]=d[T+(X+L)|0]<<8^-32768;Y=Y+1|0;}while(Y>>>0<O>>>0)}Y=O<<1;if((Y|0)!=0){X=0;do{z=M+(X<<1)|0;P=b[z>>1]|0;b[z>>1]=P<<16>>16==-32768?-32767:P;X=X+1|0;}while(X>>>0<Y>>>0)}c[N+4>>2]=O;a[N+12|0]=0;c[N+8>>2]=0;S=U}else{S=Q}}while(0);Y=c[3528400]|0;a[Y+14|0]=c[e>>2]&255;$=Y;aa=S;break L60481}}while(0);a[632384]=0;y=0;x=46870}}while(0);if((x|0)==46870){x=0;w=c[3528400]|0;a[w+14|0]=1;$=w;aa=y}h[$+16>>3]=1.0;h[$+24>>3]=1.0;c[$+32>>2]=3;c[$+36>>2]=3;if((aa|0)!=0){gGr(aa)}w=u+1|0;if((w|0)<(c[2439194]|0)){u=w}else{x=46878;break}}if((x|0)==46878){i=f;return}else if((x|0)==46880){i=f;return}}function Vg(d,e){d=d|0;e=e|0;var f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0;f=c[2439194]|0;if(!((c[2112964]|0)!=0&(f|0)>0)){return}g=(e|0)>0;i=c[2406652]|0;j=c[2442914]|0;k=0;l=0;while(1){m=i+(k*40|0)|0;n=i+(k*40|0)+12|0;L60581:do{if((a[n]|0)==0){o=l}else{p=c[i+(k*40|0)+4>>2]|0;q=c[i+(k*40|0)+8>>2]|0;r=c[m>>2]|0;s=r;L60583:do{if((a[i+(k*40|0)+13|0]|0)==0){t=p-q|0;if((t|0)<1){a[n]=0;o=l;break L60581}u=(t|0)<(e|0)?t:e;t=s+(q<<2)|0;v=(u|0)>0;if((j|l|0)==0){if(v){w=d;x=t;y=1}else{z=u;break}while(1){A=c[i+(k*40|0)+32>>2]|0;if((A&1|0)==0){B=0}else{B=~~(+(b[x>>1]|0)*+h[i+(k*40|0)+16>>3])}if((A&2|0)==0){C=0}else{C=~~(+(b[x>>1]|0)*+h[i+(k*40|0)+16>>3])}A=c[i+(k*40|0)+36>>2]|0;if((A&1|0)==0){D=B}else{D=~~(+(b[x+2>>1]|0)*+h[i+(k*40|0)+24>>3])+B|0}if((A&2|0)==0){E=C}else{E=~~(+(b[x+2>>1]|0)*+h[i+(k*40|0)+24>>3])+C|0}if((D|0)<-32768){F=-32768}else{F=(D|0)>32767?32767:D&65535}if((E|0)<-32768){G=-32768}else{G=(E|0)>32767?32767:E&65535}b[w>>1]=F;b[w+2>>1]=G;if((y|0)>=(u|0)){z=u;break L60583}w=w+4|0;x=x+4|0;y=y+1|0}}else{if(v){H=d;I=t;J=1}else{z=u;break}while(1){A=c[i+(k*40|0)+32>>2]|0;if((A&1|0)==0){K=0}else{K=~~(+(b[I>>1]|0)*+h[i+(k*40|0)+16>>3])}if((A&2|0)==0){L=0}else{L=~~(+(b[I>>1]|0)*+h[i+(k*40|0)+16>>3])}A=c[i+(k*40|0)+36>>2]|0;if((A&1|0)==0){M=K}else{M=~~(+(b[I+2>>1]|0)*+h[i+(k*40|0)+24>>3])+K|0}if((A&2|0)==0){N=L}else{N=~~(+(b[I+2>>1]|0)*+h[i+(k*40|0)+24>>3])+L|0}A=(b[H>>1]|0)+M|0;if((A|0)<-32768){O=-32768}else{O=(A|0)>32767?32767:A&65535}A=H+2|0;P=(b[A>>1]|0)+N|0;if((P|0)<-32768){Q=-32768}else{Q=(P|0)>32767?32767:P&65535}b[H>>1]=O;b[A>>1]=Q;if((J|0)>=(u|0)){z=u;break L60583}H=H+4|0;I=I+4|0;J=J+1|0}}}else{u=q<<1;t=p<<1;v=r;if((j|l|0)==0){if(g){R=u;S=d;T=1}else{z=e;break}while(1){A=c[i+(k*40|0)+32>>2]|0;if((A&1|0)==0){U=0}else{U=~~(+(b[v+(((R|0)%(t|0)|0)<<1)>>1]|0)*+h[i+(k*40|0)+16>>3])}if((A&2|0)==0){V=0}else{V=~~(+(b[v+(((R|0)%(t|0)|0)<<1)>>1]|0)*+h[i+(k*40|0)+16>>3])}A=c[i+(k*40|0)+36>>2]|0;if((A&1|0)==0){W=U}else{W=~~(+(b[v+(((R|1|0)%(t|0)|0)<<1)>>1]|0)*+h[i+(k*40|0)+24>>3])+U|0}if((A&2|0)==0){X=V}else{X=~~(+(b[v+(((R|1|0)%(t|0)|0)<<1)>>1]|0)*+h[i+(k*40|0)+24>>3])+V|0}if((W|0)<-32768){Y=-32768}else{Y=(W|0)>32767?32767:W&65535}if((X|0)<-32768){Z=-32768}else{Z=(X|0)>32767?32767:X&65535}b[S>>1]=Y;b[S+2>>1]=Z;if((T|0)>=(e|0)){z=e;break L60583}R=R+2|0;S=S+4|0;T=T+1|0}}else{if(g){_=u;$=d;aa=1}else{z=e;break}while(1){A=c[i+(k*40|0)+32>>2]|0;if((A&1|0)==0){ab=0}else{ab=~~(+(b[v+(((_|0)%(t|0)|0)<<1)>>1]|0)*+h[i+(k*40|0)+16>>3])}if((A&2|0)==0){ac=0}else{ac=~~(+(b[v+(((_|0)%(t|0)|0)<<1)>>1]|0)*+h[i+(k*40|0)+16>>3])}A=c[i+(k*40|0)+36>>2]|0;if((A&1|0)==0){ad=ab}else{ad=~~(+(b[v+(((_|1|0)%(t|0)|0)<<1)>>1]|0)*+h[i+(k*40|0)+24>>3])+ab|0}if((A&2|0)==0){ae=ac}else{ae=~~(+(b[v+(((_|1|0)%(t|0)|0)<<1)>>1]|0)*+h[i+(k*40|0)+24>>3])+ac|0}A=(b[$>>1]|0)+ad|0;if((A|0)<-32768){af=-32768}else{af=(A|0)>32767?32767:A&65535}A=$+2|0;P=(b[A>>1]|0)+ae|0;if((P|0)<-32768){ag=-32768}else{ag=(P|0)>32767?32767:P&65535}b[$>>1]=af;b[A>>1]=ag;if((aa|0)>=(e|0)){z=e;break L60583}_=_+2|0;$=$+4|0;aa=aa+1|0}}}}while(0);r=i+(k*40|0)+8|0;c[r>>2]=(c[r>>2]|0)+z;o=l+1|0}}while(0);n=k+1|0;if((n|0)<(f|0)){k=n;l=o}else{break}}c[3528400]=m;return}function Vh(f,g){f=f|0;g=g|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0;i=c[2385510]|0;j=i+1|0;if((j|0)>0){k=g<<2;l=(g|0)>0;m=0;do{n=c[9699192+(m<<2)>>2]|0;gGz(n|0,0,k|0);o=c[9672656+(m<<2)>>2]|0;gGz(o|0,0,k|0);p=c[9699504+(m<<2)>>2]|0;if(l){q=p+2064|0;r=p+2072|0;s=p+2068|0;t=0;do{u=t<<3;v=p+(u+134)|0;w=d[v]|0;if((w&1|0)==0){x=c[q>>2]|0;y=(c[r>>2]&w)<<c[s>>2];w=p+(u+133)|0;z=p+(u+132)|0;A=p+2048+t|0;B=(d[p+(u|4)|0]|0)<<8|(d[p+(u|5)|0]|0)<<16;C=(a[p+(u|6)|0]|0)+1&255;D=C&255;E=p+(u|2)|0;F=p+(u|3)|0;G=p+(u|7)|0;u=(d[z]|0)<<8|(d[w]|0)<<16|(d[A]|0);H=0;while(1){if((u>>>16|0)==(D|0)){I=a[v]|0;if((I&2)==0){J=B}else{K=46964;break}}else{J=u}L=(a[x+((J>>>8)+y)|0]^-128)<<24>>24;M=ag(L,d[E]|0)|0;N=n+(H<<2)|0;c[N>>2]=(c[N>>2]|0)+M;M=ag(d[F]|0,L)|0;L=o+(H<<2)|0;c[L>>2]=(c[L>>2]|0)+M;O=((ag(c[p+2076>>2]|0,d[G]|0)|0)>>16)+J|0;M=H+1|0;if((M|0)<(g|0)){u=O&16777215;H=M}else{K=46968;break}}if((K|0)==46968){K=0;P=O>>>16&255;Q=O>>>8&255;R=O&255;S=a[v]|0}else if((K|0)==46964){K=0;H=I|1;a[v]=H;P=C;Q=u>>>8&255;R=u&255;S=H}a[z]=Q;a[w]=P;a[A]=(S&1)!=0?0:R}t=t+1|0;}while((t|0)<16)}else{t=0;do{o=t<<3;if((a[p+(o+134)|0]&1)==0){n=p+(o+133)|0;s=a[n]|0;r=p+(o+132)|0;o=p+2048+t|0;q=a[o]|0;a[r]=a[r]|0;a[n]=s;a[o]=q}t=t+1|0;}while((t|0)<16)}m=m+1|0;}while((m|0)<(j|0))}if((g|0)<=0){return}j=c[2424876]|0;m=j+2096|0;R=j+2100|0;S=(i|0)>0;i=c[2424877]|0;P=i+2096|0;Q=i+2100|0;I=c[2418165]|0;K=i+2088|0;O=c[2424799]|0;J=i+2080|0;i=c[2418164]|0;l=j+2088|0;k=c[2424798]|0;t=j+2080|0;j=f;f=0;while(1){p=c[m>>2]|0;if((p&1|0)==0){T=0}else{T=~~(+(c[k+(f<<2)>>2]|0)*+h[t>>3])}if((p&2|0)==0){U=0}else{U=~~(+(c[k+(f<<2)>>2]|0)*+h[t>>3])}p=c[R>>2]|0;if((p&1|0)==0){V=T}else{V=~~(+(c[i+(f<<2)>>2]|0)*+h[l>>3])+T|0}if((p&2|0)==0){W=U}else{W=~~(+(c[i+(f<<2)>>2]|0)*+h[l>>3])+U|0}if((V|0)<-32768){X=-32768}else{X=(V|0)>32767?32767:V}if((W|0)<-32768){Y=-32768}else{Y=(W|0)>32767?32767:W}do{if(S){p=c[P>>2]|0;if((p&1|0)==0){Z=X}else{Z=~~(+(c[O+(f<<2)>>2]|0)*+h[J>>3])+X|0}if((p&2|0)==0){_=Y}else{_=~~(+(c[O+(f<<2)>>2]|0)*+h[J>>3])+Y|0}p=c[Q>>2]|0;if((p&1|0)==0){$=Z}else{$=~~(+(c[I+(f<<2)>>2]|0)*+h[K>>3])+Z|0}if((p&2|0)==0){aa=_}else{aa=~~(+(c[I+(f<<2)>>2]|0)*+h[K>>3])+_|0}if(($|0)<-32768){ab=-32768}else{ab=($|0)>32767?32767:$}if((aa|0)<-32768){ac=-32768;ad=ab;break}ac=(aa|0)>32767?32767:aa;ad=ab}else{ac=Y;ad=X}}while(0);b[j>>1]=(e[j>>1]|0)+ad&65535;p=j+2|0;b[p>>1]=(e[p>>1]|0)+ac&65535;p=f+1|0;if((p|0)<(g|0)){j=j+4|0;f=p}else{break}}return}function Vi(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;i=0;while(1){if((i|0)>=1024){j=0;break}k=9638528+(i<<2)|0;if((c[k>>2]|0)==0){l=47006;break}else{i=i+1|0}}do{if((l|0)==47006){i=gGq(2104)|0;c[k>>2]=i;if((i|0)==0){j=0;break}gGz(i|0,0,2104);j=i}}while(0);k=9699504+(b<<2)|0;c[k>>2]=j;gGz(j|0,0,2104);c[j+2064>>2]=f;gGz(j|0,-1|0,2048);j=a[9688]|0?2136:0;f=0;while(1){if((f|0)>=1024){m=0;break}n=9638528+(f<<2)|0;if((c[n>>2]|0)==0){l=47011;break}else{f=f+1|0}}do{if((l|0)==47011){f=gGq(j)|0;c[n>>2]=f;if((f|0)==0){m=0;break}gGz(f|0,0,j|0);m=f}}while(0);c[9699192+(b<<2)>>2]=m;m=a[9688]|0?2136:0;j=0;while(1){if((j|0)>=1024){o=0;break}p=9638528+(j<<2)|0;if((c[p>>2]|0)==0){l=47016;break}else{j=j+1|0}}do{if((l|0)==47016){j=gGq(m)|0;c[p>>2]=j;if((j|0)==0){o=0;break}gGz(j|0,0,m|0);o=j}}while(0);c[9672656+(b<<2)>>2]=o;o=c[k>>2]|0;c[o+2068>>2]=e;k=e>>16;m=1;while(1){if((m|0)<(g|0)){m=m<<1}else{break}}c[o+2072>>2]=m-1>>e&((k|0)==0?112:k);c[o+2076>>2]=~~(+(d|0)*.0078125/(a[9680]|0?32.0e3:0.0)*65536.0);h[o+2080>>3]=1.0;h[o+2088>>3]=1.0;c[o+2096>>2]=1;c[o+2100>>2]=2;c[2385510]=b;return}function Vj(d,f,g){d=d|0;f=f|0;g=g|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;i=c[9674024+(d<<2)>>2]|0;c[2424874]=i;d=c[i+20>>2]|0;j=c[i+4>>2]|0;k=c[i>>2]|0;if((a[i+16|0]|0)==0|(g|0)==0){l=k;m=d;n=i}else{o=g;g=d;d=b[i+50>>1]|0;p=f;f=k;k=i;while(1){i=c[k+72>>2]|0;if((i&1|0)==0){q=0}else{q=~~(+(d<<16>>16<<7|0)*+h[k+64>>3])}if((i&2|0)==0){r=0}else{r=~~(+(d<<16>>16<<7|0)*+h[k+64>>3])}if((q|0)<-32768){s=-32768}else{s=(q|0)>32767?32767:q}if((r|0)<-32768){t=-32768}else{t=(r|0)>32767?32767:r}b[p>>1]=(e[p>>1]|0)+s&65535;i=p+2|0;b[i>>1]=(e[i>>1]|0)+t&65535;i=p+4|0;u=o-1|0;v=f+j|0;w=c[2424874]|0;L60796:do{if((c[w+52>>2]|0)==0){x=v;y=g;z=w;A=d}else{B=w;C=g;D=d;E=v;while(1){F=E;G=C;while(1){if(F>>>0<=1048575){x=F;y=G;z=B;A=D;break L60796}H=F>>>20;I=(H|0)>(G|0)?G:H;J=F-(I<<20)|0;K=G-I|0;if((G|0)==(I|0)){break}else{F=J;G=K}}Vk();G=c[2424874]|0;if((a[G+16|0]|0)==0){x=J;y=K;z=G;A=D;break L60796}F=c[G+20>>2]|0;I=b[G+50>>1]|0;if((c[G+52>>2]|0)==0){x=J;y=F;z=G;A=I;break}else{B=G;C=F;D=I;E=J}}}}while(0);if((u|0)==0){l=x;m=y;n=z;break}else{o=u;g=y;d=A;p=i;f=x;k=z}}}if(!(a[635136]&(m|0)>0)){L=n;M=L+20|0;c[M>>2]=m;N=c[2424874]|0;O=N|0;c[O>>2]=l;return}z=a[n+11|0]|0;Vk();n=c[2424874]|0;k=a[n+11|0]|0;if(z<<24>>24==k<<24>>24){L=n;M=L+20|0;c[M>>2]=m;N=c[2424874]|0;O=N|0;c[O>>2]=l;return}z=c[n+12>>2]|0;if((z|0)==0){L=n;M=L+20|0;c[M>>2]=m;N=c[2424874]|0;O=N|0;c[O>>2]=l;return}gf[z&2047](k&255);L=c[2424874]|0;M=L+20|0;c[M>>2]=m;N=c[2424874]|0;O=N|0;c[O>>2]=l;return}function Vk(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=c[2424874]|0;L60817:do{switch(a[f+16|0]|0){case 5:{a[f+11|0]=1;c[(c[2424874]|0)+20>>2]=32;a[(c[2424874]|0)+16|0]=6;break};case 9:{g=f+26|0;h=a[g]|0;if(h<<24>>24==0){i=f}else{a[g]=h-1&255;h=c[2424874]|0;c[h+40>>2]=c[h+44>>2];i=c[2424874]|0}if((c[i+52>>2]|0)==0){j=i+8|0;k=i}else{h=i+40|0;g=c[h>>2]|0;c[h>>2]=g+1;h=c[2424874]|0;j=(c[h+52>>2]|0)+(g&131071)|0;k=h}a[k+34|0]=a[j]|0;a[(c[2424874]|0)+11|0]=1;h=c[2424874]|0;g=a[h+34|0]|0;l=g&255;m=l&192;if((m|0)==128){a[h+35|0]=(g&63)+1&255;c[(c[2424874]|0)+20>>2]=36;a[(c[2424874]|0)+16|0]=10}else if((m|0)==64){a[h+35|0]=(g&63)+1&255;b[(c[2424874]|0)+24>>1]=256;c[(c[2424874]|0)+20>>2]=36;a[(c[2424874]|0)+16|0]=11}else if((m|0)==192){a[h+26|0]=(g&7)+1&255;g=c[2424874]|0;c[g+44>>2]=c[g+40>>2];c[(c[2424874]|0)+20>>2]=36;a[(c[2424874]|0)+16|0]=9}else if((m|0)==0){c[h+20>>2]=(l<<10&64512)+1024;l=c[2424874]|0;if((a[l+34|0]|0)==0){n=(a[l+36|0]|0)!=0?0:9}else{n=9}a[l+16|0]=n;b[(c[2424874]|0)+50>>1]=0;a[(c[2424874]|0)+48|0]=0}l=c[2424874]|0;if((a[l+34|0]|0)==0){break L60817}a[l+36|0]=1;break};case 1:{a[f+11|0]=0;l=c[2424874]|0;c[l+20>>2]=c[l+28>>2];l=c[2424874]|0;a[l+16|0]=a[l+27|0]|0;break};case 4:{l=c[f+52>>2]|0;a[f+33|0]=a[(l|0)==0?f+8|0:l]|0;a[(c[2424874]|0)+11|0]=1;c[(c[2424874]|0)+20>>2]=28;l=c[2424874]|0;a[l+16|0]=(d[l+32|0]|0)>(d[l+33|0]|0)?0:5;break};case 3:{a[f+11|0]=1;c[(c[2424874]|0)+20>>2]=44;a[(c[2424874]|0)+16|0]=4;break};case 0:{c[f+20>>2]=4;break};case 8:{l=f+40|0;c[l>>2]=(c[l>>2]|0)+1;a[(c[2424874]|0)+36|0]=0;a[(c[2424874]|0)+11|0]=1;c[(c[2424874]|0)+20>>2]=36;a[(c[2424874]|0)+16|0]=9;break};case 7:{l=c[f+52>>2]|0;if((l|0)==0){o=f+8|0}else{o=l+((d[f+32|0]<<1)+6)|0}l=f+40|0;c[l>>2]=d[o]<<1|c[l>>2];a[(c[2424874]|0)+11|0]=1;c[(c[2424874]|0)+20>>2]=36;a[(c[2424874]|0)+16|0]=8;break};case 2:{if((c[f+52>>2]|0)==0){p=16}else{p=a[f+8|0]|0}a[f+32|0]=p;c[(c[2424874]|0)+20>>2]=70;a[(c[2424874]|0)+16|0]=3;break};case 10:{if((c[f+52>>2]|0)==0){q=f+8|0;r=f}else{l=f+40|0;h=c[l>>2]|0;c[l>>2]=h+1;l=c[2424874]|0;q=(c[l+52>>2]|0)+(h&131071)|0;r=l}b[r+24>>1]=(d[q]|0)+1&65535;a[(c[2424874]|0)+11|0]=1;c[(c[2424874]|0)+20>>2]=36;a[(c[2424874]|0)+16|0]=11;break};case 12:{l=a[f+49|0]&15;h=f+50|0;b[h>>1]=(e[h>>1]|0)+(c[6459560+(a[f+48|0]<<6)+(l<<2)>>2]|0)&65535;h=(c[2424874]|0)+48|0;a[h]=(d[h]|0)+(c[5635824+(l<<2)>>2]|0)&255;l=(c[2424874]|0)+48|0;h=a[l]|0;do{if(h<<24>>24<0){a[l]=0}else{if(h<<24>>24<=15){break}a[l]=15}}while(0);l=c[2424874]|0;c[l+20>>2]=d[l+35|0]<<2;l=(c[2424874]|0)+24|0;h=(b[l>>1]|0)-1&65535;b[l>>1]=h;l=(c[2424874]|0)+16|0;if(h<<16>>16==0){a[l]=9;break L60817}else{a[l]=11;break L60817}break};case 6:{l=c[f+52>>2]|0;if((l|0)==0){s=f+8|0}else{s=l+((d[f+32|0]<<1)+5)|0}c[f+40>>2]=d[s]<<9;a[(c[2424874]|0)+11|0]=1;c[(c[2424874]|0)+20>>2]=44;a[(c[2424874]|0)+16|0]=7;break};case 11:{if((c[f+52>>2]|0)==0){t=f+8|0;u=f}else{l=f+40|0;h=c[l>>2]|0;c[l>>2]=h+1;l=c[2424874]|0;t=(c[l+52>>2]|0)+(h&131071)|0;u=l}a[u+49|0]=a[t]|0;l=c[2424874]|0;h=(d[l+49|0]|0)>>>4;m=l+50|0;b[m>>1]=(e[m>>1]|0)+(c[6459560+(a[l+48|0]<<6)+(h<<2)>>2]|0)&65535;l=(c[2424874]|0)+48|0;a[l]=(d[l]|0)+(c[5635824+(h<<2)>>2]|0)&255;h=(c[2424874]|0)+48|0;l=a[h]|0;do{if(l<<24>>24<0){a[h]=0}else{if(l<<24>>24<=15){break}a[h]=15}}while(0);a[(c[2424874]|0)+11|0]=1;h=c[2424874]|0;c[h+20>>2]=d[h+35|0]<<2;h=(c[2424874]|0)+24|0;l=(b[h>>1]|0)-1&65535;b[h>>1]=l;h=(c[2424874]|0)+16|0;if(l<<16>>16==0){a[h]=9;break L60817}else{a[h]=12;break L60817}break};default:{}}}while(0);t=c[2424874]|0;if((a[t+11|0]|0)==0){return}a[t+27|0]=a[t+16|0]|0;t=c[2424874]|0;c[t+28>>2]=(c[t+20>>2]|0)-21;a[(c[2424874]|0)+16|0]=1;c[(c[2424874]|0)+20>>2]=21;return}function Vl(){var d=0;d=c[2418506]|0;c[2424874]=d;if((d|0)!=0){c[d>>2]=0;a[(c[2424874]|0)+8|0]=0;a[(c[2424874]|0)+11|0]=0;a[(c[2424874]|0)+16|0]=0;c[(c[2424874]|0)+20>>2]=0;b[(c[2424874]|0)+24>>1]=0;a[(c[2424874]|0)+26|0]=0;a[(c[2424874]|0)+27|0]=0;c[(c[2424874]|0)+28>>2]=0;a[(c[2424874]|0)+32|0]=0;a[(c[2424874]|0)+33|0]=0;a[(c[2424874]|0)+34|0]=0;a[(c[2424874]|0)+35|0]=0;a[(c[2424874]|0)+36|0]=0;c[(c[2424874]|0)+40>>2]=0;c[(c[2424874]|0)+44>>2]=0;a[(c[2424874]|0)+48|0]=0;a[(c[2424874]|0)+49|0]=0;b[(c[2424874]|0)+50>>1]=0}d=c[2418507]|0;c[2424874]=d;if((d|0)==0){return}c[d>>2]=0;a[(c[2424874]|0)+8|0]=0;a[(c[2424874]|0)+11|0]=0;a[(c[2424874]|0)+16|0]=0;c[(c[2424874]|0)+20>>2]=0;b[(c[2424874]|0)+24>>1]=0;a[(c[2424874]|0)+26|0]=0;a[(c[2424874]|0)+27|0]=0;c[(c[2424874]|0)+28>>2]=0;a[(c[2424874]|0)+32|0]=0;a[(c[2424874]|0)+33|0]=0;a[(c[2424874]|0)+34|0]=0;a[(c[2424874]|0)+35|0]=0;a[(c[2424874]|0)+36|0]=0;c[(c[2424874]|0)+40>>2]=0;c[(c[2424874]|0)+44>>2]=0;a[(c[2424874]|0)+48|0]=0;a[(c[2424874]|0)+49|0]=0;b[(c[2424874]|0)+50>>1]=0;return}function Vm(a){a=a|0;return 0}function Vn(a,b){a=a|0;b=b|0;return}function Vo(){var a=0,b=0,d=0,e=0,f=0,g=0;a=gj[c[2427018]&4095](c[2429376]|0)|0;b=c[2433576]|0;if((b|0)>=(a|0)){return}d=a-b|0;a=c[2406682]|0;e=a+(b+8196<<1)|0;c[2438954]=e;f=a+(b+12292<<1)|0;c[2438955]=f;g=a+(b+16388<<1)|0;c[2438956]=g;mA(0,e,f,g,d);c[2433576]=(c[2433576]|0)+d;return}function Vp(d,e){d=d|0;e=e|0;var f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0.0,q=0,r=0,s=0,t=0.0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0;f=((ag(c[2429376]|0,e)|0)/32e3|0)+1|0;g=c[2433576]|0;i=(f|0)<(g|0)?g:f;f=c[2433542]|0;j=(i|0)<(f|0)?f:i;i=a[9688]|0?534:0;k=((i|0)<(e|0)?i:e)<<1;if((f|0)<(j|0)){i=j-f|0;l=c[2406682]|0;c[2438952]=l+(f+4<<1);c[2438953]=l+(f+4100<<1);lV(i);c[2433542]=(c[2433542]|0)+i;m=c[2433576]|0}else{m=g}if((m|0)<(j|0)){g=j-m|0;i=c[2406682]|0;f=i+(m+8196<<1)|0;c[2438954]=f;l=i+(m+12292<<1)|0;c[2438955]=l;n=i+(m+16388<<1)|0;c[2438956]=n;mA(0,f,l,n,g);c[2433576]=(c[2433576]|0)+g;o=i}else{o=c[2406682]|0}c[2438952]=o+8;c[2438953]=o+8200;c[2438954]=o+16392;c[2438955]=o+24584;c[2438956]=o+32776;c[2438957]=o+40968;i=c[2429602]|0;g=(i>>16)-4|0;if((g|0)<(j|0)){p=+h[745407];n=g;do{b[o+(n+20484<<1)>>1]=~~(p*+((b[o+(n+12292<<1)>>1]|0)+(b[o+(n+8196<<1)>>1]|0)+(b[o+(n+16388<<1)>>1]|0)|0))&65535;n=n+1|0;}while((n|0)<(j|0))}n=i>>>15&131070;if((n|0)<(k|0)){g=a[3203288]|0?3:0;l=(g&1|0)==0;f=(g&2|0)==0;g=c[2436790]|0;m=(g&1|0)==0;q=(g&2|0)==0;g=c[2436788]|0;r=(g&1|0)==0;s=(g&2|0)==0;g=c[2443878]|0;p=+h[745408];t=+h[745409];u=n;n=i;do{if(l){v=0;w=0;x=0;y=0}else{z=n>>16;v=b[o+(z+20481<<1)>>1]|0;w=b[o+(z+20482<<1)>>1]|0;x=b[o+(z+20483<<1)>>1]|0;y=b[o+(z+20484<<1)>>1]|0}if(f){A=0;B=0;C=0;D=0}else{z=n>>16;A=b[o+(z+20481<<1)>>1]|0;B=b[o+(z+20482<<1)>>1]|0;C=b[o+(z+20483<<1)>>1]|0;D=b[o+(z+20484<<1)>>1]|0}if(m){E=v;F=w;G=x;H=y}else{z=n>>16;E=~~(+(b[o+(z+1<<1)>>1]|0)*t)+v|0;F=~~(t*+(b[o+(z+2<<1)>>1]|0))+w|0;G=~~(t*+(b[o+(z+3<<1)>>1]|0))+x|0;H=~~(t*+(b[o+(z+4<<1)>>1]|0))+y|0}if(q){I=A;J=B;K=C;L=D}else{z=n>>16;I=~~(+(b[o+(z+1<<1)>>1]|0)*t)+A|0;J=~~(t*+(b[o+(z+2<<1)>>1]|0))+B|0;K=~~(t*+(b[o+(z+3<<1)>>1]|0))+C|0;L=~~(t*+(b[o+(z+4<<1)>>1]|0))+D|0}if(r){M=E;N=F;O=G;P=H}else{z=n>>16;M=~~(+(b[o+(z+4097<<1)>>1]|0)*p)+E|0;N=~~(p*+(b[o+(z+4098<<1)>>1]|0))+F|0;O=~~(p*+(b[o+(z+4099<<1)>>1]|0))+G|0;P=~~(p*+(b[o+(z+4100<<1)>>1]|0))+H|0}if(s){Q=I;R=J;S=K;T=L}else{z=n>>16;Q=~~(+(b[o+(z+4097<<1)>>1]|0)*p)+I|0;R=~~(p*+(b[o+(z+4098<<1)>>1]|0))+J|0;S=~~(p*+(b[o+(z+4099<<1)>>1]|0))+K|0;T=~~(p*+(b[o+(z+4100<<1)>>1]|0))+L|0}z=n>>>4<<2&16380;U=b[14130680+(z<<1)>>1]|0;V=ag(U,M)|0;W=b[14130680+((z|1)<<1)>>1]|0;X=(ag(W,N)|0)+V|0;V=b[14130680+((z|2)<<1)>>1]|0;Y=X+(ag(V,O)|0)|0;X=b[14130680+((z|3)<<1)>>1]|0;z=Y+(ag(X,P)|0)|0;Y=ag(U,Q)|0;U=(ag(W,R)|0)+Y|0;Y=U+(ag(V,S)|0)|0;V=Y+(ag(X,T)|0)|0;if((z|0)<-536887295){Z=-32768}else{Z=(z|0)>536870911?32767:((z|0)/16384|0)&65535}if((V|0)<-536887295){_=-32768}else{_=(V|0)>536870911?32767:((V|0)/16384|0)&65535}b[d+(u<<1)>>1]=Z;b[d+((u|1)<<1)>>1]=_;u=u+2|0;n=n+g|0;}while((u|0)<(k|0));c[2429602]=n;$=n}else{$=i}if(((a[9688]|0?534:0)|0)>(e|0)){return}e=$>>16;i=j-e|0;if((i|0)>-4){j=-4;do{n=e+j|0;b[o+(j+4<<1)>>1]=b[o+(n+4<<1)>>1]|0;b[o+(j+4100<<1)>>1]=b[o+(n+4100<<1)>>1]|0;b[o+(j+8196<<1)>>1]=b[o+(n+8196<<1)>>1]|0;b[o+(j+12292<<1)>>1]=b[o+(n+12292<<1)>>1]|0;b[o+(j+16388<<1)>>1]=b[o+(n+16388<<1)>>1]|0;j=j+1|0;}while((j|0)<(i|0))}c[2429602]=$&65535;c[2433542]=i;c[2433576]=i;h[6675]=100.0/+(c[2424]|0)+ +h[6675];return}function Vq(d,e){d=d|0;e=e|0;var f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0.0,r=0.0,s=0.0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;f=c[2433576]|0;g=(f|0)>(e|0)?f:e;i=c[2433542]|0;j=(g|0)<(i|0)?i:g;g=a[9688]|0?534:0;k=(g|0)<(e|0)?g:e;if((i|0)<(j|0)){e=j-i|0;g=c[2406682]|0;c[2438952]=g+(i+4<<1);c[2438953]=g+(i+4100<<1);lV(e);c[2433542]=(c[2433542]|0)+e;l=c[2433576]|0}else{l=f}if((l|0)<(j|0)){f=j-l|0;e=c[2406682]|0;i=e+(l+8196<<1)|0;c[2438954]=i;g=e+(l+12292<<1)|0;c[2438955]=g;m=e+(l+16388<<1)|0;c[2438956]=m;mA(0,i,g,m,f);c[2433576]=(c[2433576]|0)+f;n=e}else{n=c[2406682]|0}c[2438952]=n+8;c[2438953]=n+8200;c[2438954]=n+16392;c[2438955]=n+24584;c[2438956]=n+32776;e=c[2429602]|0;if((e|0)<(k|0)){f=a[3203288]|0?3:0;m=(f&1|0)==0;g=(f&2|0)==0;f=c[2436790]|0;i=(f&1|0)==0;l=(f&2|0)==0;f=c[2436788]|0;o=(f&1|0)==0;p=(f&2|0)==0;q=+h[745408];r=+h[745409];s=+h[745407];f=e;do{e=(b[n+(f+12292<<1)>>1]|0)+(b[n+(f+8196<<1)>>1]|0)+(b[n+(f+16388<<1)>>1]|0)|0;if(m){t=0}else{t=~~(+(e|0)*s)}if(g){u=0}else{u=~~(+(e|0)*s)}if(i){v=t}else{v=~~(+(b[n+(f+4<<1)>>1]|0)*r)+t|0}if(l){w=u}else{w=~~(+(b[n+(f+4<<1)>>1]|0)*r)+u|0}if(o){x=v}else{x=~~(+(b[n+(f+4100<<1)>>1]|0)*q)+v|0}if(p){y=w}else{y=~~(+(b[n+(f+4100<<1)>>1]|0)*q)+w|0}if((x|0)<-32768){z=-32768}else{z=(x|0)>32767?32767:x&65535}if((y|0)<-32768){A=-32768}else{A=(y|0)>32767?32767:y&65535}e=f<<1;b[d+(e<<1)>>1]=z;b[d+((e|1)<<1)>>1]=A;f=f+1|0;}while((f|0)<(k|0))}c[2429602]=k;k=a[9688]|0?534:0;if((j|0)<(k|0)){return}f=j-k|0;if((f|0)>0){j=0;do{A=j+k|0;b[n+(j+4<<1)>>1]=b[n+(A+4<<1)>>1]|0;b[n+(j+4100<<1)>>1]=b[n+(A+4100<<1)>>1]|0;b[n+(j+8196<<1)>>1]=b[n+(A+8196<<1)>>1]|0;b[n+(j+12292<<1)>>1]=b[n+(A+12292<<1)>>1]|0;b[n+(j+16388<<1)>>1]=b[n+(A+16388<<1)>>1]|0;j=j+1|0;}while((j|0)<(f|0))}c[2429602]=0;c[2433542]=f;c[2433576]=f;h[6675]=100.0/+(c[2424]|0)+ +h[6675];return}function Vr(b,d,e,f,g,i){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;j=(b|0)>2?2:b;c[2438228]=0;c[2433526]=0;c[2406676]=0;c[3528472]=0;c[2429844]=15636;c[2429842]=(g|0)!=0?g:80;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;g=a[9680]|0;b=g?32e3:0;if(!g){c[2427020]=2068;c[3542122]=106;if((j|0)>0){g=0;k=c[2383582]|0;do{l=mD(k+g|0,d,11025)|0;c[3542220]=504;m=c[2076598]|0;if((l|0)==0){l=m+1|0;c[2076598]=l;n=l}else{n=m}k=(c[2113008]|0)-n|0;c[2383582]=k;g=g+1|0;}while((g|0)<(j|0))}lQ(j,d,11025,e);return}c[2427020]=f;if(a[9624]|0){f=b*3|0;g=(d|0)/(j*144|0|0)|0;while(1){if((g|0)>(f|0)){g=g>>1}else{break}}c[2429378]=g;c[3542122]=2982;c[2443876]=(g<<16>>>0)/32e3|0;o=g}else{c[2429378]=b;c[3542122]=156;o=b}b=(j|0)>0;if(b){g=0;f=o;k=c[2383582]|0;while(1){n=mD(k+g|0,d,f)|0;c[3542220]=504;m=c[2076598]|0;if((n|0)==0){n=m+1|0;c[2076598]=n;p=n}else{p=m}m=(c[2113008]|0)-p|0;c[2383582]=m;n=g+1|0;l=c[2429378]|0;if((n|0)<(j|0)){g=n;f=l;k=m}else{q=l;break}}}else{q=o}lQ(j,d,q,e);e=j<<15;q=gGq(e)|0;c[2406680]=q;gGz(q|0,0,e|0);c[2433544]=0;c[2433574]=0;c[2429600]=0;c[2385508]=j;c[2432978]=i;h[745419]=1.0;h[745418]=1.0;h[745417]=1.0;h[745416]=1.0;a[3203368]=1;a[3203360]=1;a[3203352]=1;a[3203344]=1;a[64240]=0;h[146579]=1.0;h[146578]=1.0;h[146577]=1.0;h[146576]=1.0;h[118364]=1.0;h[118363]=1.0;h[118362]=1.0;h[118361]=1.0;if(!b){return}h[745415]=1.0;h[745414]=1.0;h[745413]=1.0;h[745412]=1.0;a[3203336]=1;a[3203328]=1;a[3203320]=1;a[3203312]=1;h[146575]=1.0;h[146574]=1.0;h[146573]=1.0;h[146572]=1.0;h[118360]=1.0;h[118359]=1.0;h[118358]=1.0;h[118357]=1.0;return}function Vs(a){a=a|0;return 0}function Vt(a,b){a=a|0;b=b|0;return}function Vu(){var a=0,b=0,d=0,e=0,f=0,g=0;a=gj[c[2427020]&4095](c[2429378]|0)|0;b=c[2433574]|0;if((b|0)>=(a|0)){return}d=a-b|0;a=c[2406680]|0;e=a+(b+4100<<1)|0;c[2438963]=e;f=a+(b+8196<<1)|0;c[2438964]=f;g=a+(b+12292<<1)|0;c[2438965]=g;mA(0,e,f,g,d);if((c[2385508]|0)>1){g=c[2433574]|0;f=a+(g+20484<<1)|0;c[2438967]=f;e=a+(g+24580<<1)|0;c[2438968]=e;b=a+(g+28676<<1)|0;c[2438969]=b;mA(1,f,e,b,d)}c[2433574]=(c[2433574]|0)+d;return}function Vv(d,f){d=d|0;f=f|0;var g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0.0,u=0.0,v=0.0,w=0.0,x=0.0,y=0.0,z=0.0,A=0.0,B=0.0,C=0.0,D=0.0,E=0.0,F=0.0,G=0.0,H=0.0,I=0.0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0.0,ab=0.0,ac=0.0,ad=0.0,ae=0.0,af=0.0,ah=0.0,ai=0.0,aj=0,ak=0,al=0.0,am=0,an=0.0,ao=0,ap=0.0,aq=0.0,ar=0.0,as=0.0,at=0.0,au=0.0,av=0.0,aw=0.0,ax=0.0,ay=0.0,az=0.0,aA=0,aB=0.0,aC=0,aD=0.0,aE=0,aF=0.0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0;g=((ag(c[2429378]|0,f)|0)/32e3|0)+1|0;i=c[2433574]|0;j=(g|0)<(i|0)?i:g;g=c[2433544]|0;k=(j|0)<(g|0)?g:j;j=a[9688]|0?534:0;l=((j|0)<(f|0)?j:f)<<1;if((g|0)<(k|0)){m=k-g|0;n=c[2406680]|0;o=n+(g+4<<1)|0;c[2438962]=o;lJ(0,o,m);if((c[2385508]|0)>1){o=n+((c[2433544]|0)+16388<<1)|0;c[2438966]=o;lJ(1,o,m)}c[2433544]=(c[2433544]|0)+m;p=c[2433574]|0}else{p=i}if((p|0)<(k|0)){i=k-p|0;m=c[2406680]|0;o=m+(p+4100<<1)|0;c[2438963]=o;n=m+(p+8196<<1)|0;c[2438964]=n;g=m+(p+12292<<1)|0;c[2438965]=g;mA(0,o,n,g,i);g=c[2385508]|0;if((g|0)>1){n=c[2433574]|0;o=m+(n+20484<<1)|0;c[2438967]=o;p=m+(n+24580<<1)|0;c[2438968]=p;q=m+(n+28676<<1)|0;c[2438969]=q;mA(1,o,p,q,i)}c[2433574]=(c[2433574]|0)+i;r=m;s=g}else{r=c[2406680]|0;s=c[2385508]|0}c[2438962]=r+8;c[2438963]=r+8200;c[2438964]=r+16392;c[2438965]=r+24584;g=(s|0)>1;if(g){c[2438966]=r+32776;c[2438967]=r+40968;c[2438968]=r+49160;c[2438969]=r+57352}s=c[2429600]|0;m=s>>>15&131070;if((m|0)<(l|0)){i=a[64240]|0;t=+h[146578];u=+h[146577];v=+h[146576];w=+h[146579];x=+h[118363];y=+h[118362];z=+h[118361];A=+h[118364];q=c[2438967]|0;B=+h[146574];p=c[2438968]|0;C=+h[146573];o=c[2438969]|0;D=+h[146572];n=c[2438966]|0;E=+h[146575];F=+h[118359];G=+h[118358];H=+h[118357];I=+h[118360];J=(c[2432978]|0)==0;K=c[2443876]|0;L=a[3203360]|0?3:0;M=(L&1|0)==0;N=(L&2|0)==0;L=a[3203352]|0?3:0;O=(L&1|0)==0;P=(L&2|0)==0;L=a[3203344]|0?3:0;Q=(L&1|0)==0;R=(L&2|0)==0;L=a[3203368]|0?3:0;S=(L&1|0)==0;T=(L&2|0)==0;L=a[3203328]|0?3:0;U=(L&1|0)==0;V=(L&2|0)==0;L=a[3203320]|0?3:0;W=(L&1|0)==0;X=(L&2|0)==0;L=a[3203312]|0?3:0;Y=(L&1|0)==0;Z=(L&2|0)==0;L=a[3203336]|0?3:0;_=(L&1|0)==0;$=(L&2|0)==0;aa=+h[745415];ab=+h[745412];ac=+h[745413];ad=+h[745414];ae=+h[745419];af=+h[745416];ah=+h[745417];ai=+h[745418];L=m;m=s;do{do{if(i){aj=m>>16;ak=aj-3|0;al=+(b[r+(aj+4097<<1)>>1]|0);am=aj-2|0;an=+(b[r+(aj+4098<<1)>>1]|0);ao=aj-1|0;ap=+(b[r+(aj+4099<<1)>>1]|0);aq=+(b[r+(aj+4100<<1)>>1]|0);ar=+(b[r+(aj+8193<<1)>>1]|0);as=+(b[r+(aj+8194<<1)>>1]|0);at=+(b[r+(aj+8195<<1)>>1]|0);au=+(b[r+(aj+8196<<1)>>1]|0);av=+(b[r+(aj+12289<<1)>>1]|0);aw=+(b[r+(aj+12290<<1)>>1]|0);ax=+(b[r+(aj+12291<<1)>>1]|0);ay=+(b[r+(aj+12292<<1)>>1]|0);az=+(b[r+(aj+1<<1)>>1]|0);aA=~~(ar*u)+~~(al*t)+~~(av*v)+~~(az*w)|0;aB=+(b[r+(aj+2<<1)>>1]|0);aC=~~(u*as)+~~(t*an)+~~(v*aw)+~~(w*aB)|0;aD=+(b[r+(aj+3<<1)>>1]|0);aE=~~(u*at)+~~(t*ap)+~~(v*ax)+~~(w*aD)|0;aF=+(b[r+(aj+4<<1)>>1]|0);aG=~~(u*au)+~~(t*aq)+~~(v*ay)+~~(w*aF)|0;aH=~~(ar*y)+~~(al*x)+~~(av*z)+~~(az*A)|0;aI=~~(as*y)+~~(an*x)+~~(aw*z)+~~(aB*A)|0;aJ=~~(at*y)+~~(ap*x)+~~(ax*z)+~~(aD*A)|0;aK=~~(au*y)+~~(aq*x)+~~(ay*z)+~~(aF*A)|0;if(!g){aL=aH;aM=aI;aN=aJ;aO=aK;aP=aA;aQ=aC;aR=aE;aS=aG;break}aF=+(b[q+(ak<<1)>>1]|0);ay=+(b[q+(am<<1)>>1]|0);aq=+(b[q+(ao<<1)>>1]|0);au=+(b[q+(aj<<1)>>1]|0);aD=+(b[p+(ak<<1)>>1]|0);ax=+(b[p+(am<<1)>>1]|0);ap=+(b[p+(ao<<1)>>1]|0);at=+(b[p+(aj<<1)>>1]|0);aB=+(b[o+(ak<<1)>>1]|0);aw=+(b[o+(am<<1)>>1]|0);an=+(b[o+(ao<<1)>>1]|0);as=+(b[o+(aj<<1)>>1]|0);az=+(b[n+(ak<<1)>>1]|0);av=+(b[n+(am<<1)>>1]|0);al=+(b[n+(ao<<1)>>1]|0);ar=+(b[n+(aj<<1)>>1]|0);aL=~~(aF*F)+aH+~~(aD*G)+~~(aB*H)+~~(az*I)|0;aM=~~(ay*F)+aI+~~(ax*G)+~~(aw*H)+~~(av*I)|0;aN=~~(aq*F)+aJ+~~(ap*G)+~~(an*H)+~~(al*I)|0;aO=~~(au*F)+aK+~~(at*G)+~~(as*H)+~~(ar*I)|0;aP=~~(aF*B)+aA+~~(aD*C)+~~(aB*D)+~~(az*E)|0;aQ=~~(B*ay)+aC+~~(C*ax)+~~(D*aw)+~~(E*av)|0;aR=~~(B*aq)+aE+~~(C*ap)+~~(D*an)+~~(E*al)|0;aS=~~(B*au)+aG+~~(C*at)+~~(D*as)+~~(E*ar)|0}else{if(M){aT=0;aU=0;aV=0;aW=0}else{aG=m>>16;aT=~~(+(b[r+(aG+4097<<1)>>1]|0)*ai);aU=~~(ai*+(b[r+(aG+4098<<1)>>1]|0));aV=~~(ai*+(b[r+(aG+4099<<1)>>1]|0));aW=~~(ai*+(b[r+(aG+4100<<1)>>1]|0))}if(N){aX=0;aY=0;aZ=0;a_=0}else{aG=m>>16;aX=~~(+(b[r+(aG+4097<<1)>>1]|0)*ai);aY=~~(ai*+(b[r+(aG+4098<<1)>>1]|0));aZ=~~(ai*+(b[r+(aG+4099<<1)>>1]|0));a_=~~(ai*+(b[r+(aG+4100<<1)>>1]|0))}if(O){a$=aT;a0=aU;a1=aV;a2=aW}else{aG=m>>16;a$=~~(+(b[r+(aG+8193<<1)>>1]|0)*ah)+aT|0;a0=~~(ah*+(b[r+(aG+8194<<1)>>1]|0))+aU|0;a1=~~(ah*+(b[r+(aG+8195<<1)>>1]|0))+aV|0;a2=~~(ah*+(b[r+(aG+8196<<1)>>1]|0))+aW|0}if(P){a3=aX;a4=aY;a5=aZ;a6=a_}else{aG=m>>16;a3=~~(+(b[r+(aG+8193<<1)>>1]|0)*ah)+aX|0;a4=~~(ah*+(b[r+(aG+8194<<1)>>1]|0))+aY|0;a5=~~(ah*+(b[r+(aG+8195<<1)>>1]|0))+aZ|0;a6=~~(ah*+(b[r+(aG+8196<<1)>>1]|0))+a_|0}if(Q){a7=a$;a8=a0;a9=a1;ba=a2}else{aG=m>>16;a7=~~(+(b[r+(aG+12289<<1)>>1]|0)*af)+a$|0;a8=~~(af*+(b[r+(aG+12290<<1)>>1]|0))+a0|0;a9=~~(af*+(b[r+(aG+12291<<1)>>1]|0))+a1|0;ba=~~(af*+(b[r+(aG+12292<<1)>>1]|0))+a2|0}if(R){bb=a3;bc=a4;bd=a5;be=a6}else{aG=m>>16;bb=~~(+(b[r+(aG+12289<<1)>>1]|0)*af)+a3|0;bc=~~(af*+(b[r+(aG+12290<<1)>>1]|0))+a4|0;bd=~~(af*+(b[r+(aG+12291<<1)>>1]|0))+a5|0;be=~~(af*+(b[r+(aG+12292<<1)>>1]|0))+a6|0}if(S){bf=a7;bg=a8;bh=a9;bi=ba}else{aG=m>>16;bf=~~(+(b[r+(aG+1<<1)>>1]|0)*ae)+a7|0;bg=~~(ae*+(b[r+(aG+2<<1)>>1]|0))+a8|0;bh=~~(ae*+(b[r+(aG+3<<1)>>1]|0))+a9|0;bi=~~(ae*+(b[r+(aG+4<<1)>>1]|0))+ba|0}if(T){bj=bb;bk=bc;bl=bd;bm=be}else{aG=m>>16;bj=~~(+(b[r+(aG+1<<1)>>1]|0)*ae)+bb|0;bk=~~(ae*+(b[r+(aG+2<<1)>>1]|0))+bc|0;bl=~~(ae*+(b[r+(aG+3<<1)>>1]|0))+bd|0;bm=~~(ae*+(b[r+(aG+4<<1)>>1]|0))+be|0}if(!g){aL=bj;aM=bk;aN=bl;aO=bm;aP=bf;aQ=bg;aR=bh;aS=bi;break}if(U){bn=bf;bo=bg;bp=bh;bq=bi}else{aG=m>>16;bn=~~(+(b[q+(aG-3<<1)>>1]|0)*ad)+bf|0;bo=~~(ad*+(b[q+(aG-2<<1)>>1]|0))+bg|0;bp=~~(ad*+(b[q+(aG-1<<1)>>1]|0))+bh|0;bq=~~(ad*+(b[q+(aG<<1)>>1]|0))+bi|0}if(V){br=bj;bs=bk;bt=bl;bu=bm}else{aG=m>>16;br=~~(+(b[q+(aG-3<<1)>>1]|0)*ad)+bj|0;bs=~~(ad*+(b[q+(aG-2<<1)>>1]|0))+bk|0;bt=~~(ad*+(b[q+(aG-1<<1)>>1]|0))+bl|0;bu=~~(ad*+(b[q+(aG<<1)>>1]|0))+bm|0}if(W){bv=bn;bw=bo;bx=bp;by=bq}else{aG=m>>16;bv=~~(+(b[p+(aG-3<<1)>>1]|0)*ac)+bn|0;bw=~~(ac*+(b[p+(aG-2<<1)>>1]|0))+bo|0;bx=~~(ac*+(b[p+(aG-1<<1)>>1]|0))+bp|0;by=~~(ac*+(b[p+(aG<<1)>>1]|0))+bq|0}if(X){bz=br;bA=bs;bB=bt;bC=bu}else{aG=m>>16;bz=~~(+(b[p+(aG-3<<1)>>1]|0)*ac)+br|0;bA=~~(ac*+(b[p+(aG-2<<1)>>1]|0))+bs|0;bB=~~(ac*+(b[p+(aG-1<<1)>>1]|0))+bt|0;bC=~~(ac*+(b[p+(aG<<1)>>1]|0))+bu|0}if(Y){bD=bv;bE=bw;bF=bx;bG=by}else{aG=m>>16;bD=~~(+(b[o+(aG-3<<1)>>1]|0)*ab)+bv|0;bE=~~(ab*+(b[o+(aG-2<<1)>>1]|0))+bw|0;bF=~~(ab*+(b[o+(aG-1<<1)>>1]|0))+bx|0;bG=~~(ab*+(b[o+(aG<<1)>>1]|0))+by|0}if(Z){bH=bz;bI=bA;bJ=bB;bK=bC}else{aG=m>>16;bH=~~(+(b[o+(aG-3<<1)>>1]|0)*ab)+bz|0;bI=~~(ab*+(b[o+(aG-2<<1)>>1]|0))+bA|0;bJ=~~(ab*+(b[o+(aG-1<<1)>>1]|0))+bB|0;bK=~~(ab*+(b[o+(aG<<1)>>1]|0))+bC|0}if(_){bL=bD;bM=bE;bN=bF;bO=bG}else{aG=m>>16;bL=~~(+(b[n+(aG-3<<1)>>1]|0)*aa)+bD|0;bM=~~(aa*+(b[n+(aG-2<<1)>>1]|0))+bE|0;bN=~~(aa*+(b[n+(aG-1<<1)>>1]|0))+bF|0;bO=~~(aa*+(b[n+(aG<<1)>>1]|0))+bG|0}if($){aL=bH;aM=bI;aN=bJ;aO=bK;aP=bL;aQ=bM;aR=bN;aS=bO;break}aG=m>>16;aL=~~(+(b[n+(aG-3<<1)>>1]|0)*aa)+bH|0;aM=~~(aa*+(b[n+(aG-2<<1)>>1]|0))+bI|0;aN=~~(aa*+(b[n+(aG-1<<1)>>1]|0))+bJ|0;aO=~~(aa*+(b[n+(aG<<1)>>1]|0))+bK|0;aP=bL;aQ=bM;aR=bN;aS=bO}}while(0);aG=m>>>4<<2&16380;aE=b[14130680+(aG<<1)>>1]|0;aC=ag(aE,aP)|0;aA=b[14130680+((aG|1)<<1)>>1]|0;aK=(ag(aA,aQ)|0)+aC|0;aC=b[14130680+((aG|2)<<1)>>1]|0;aJ=aK+(ag(aC,aR)|0)|0;aK=b[14130680+((aG|3)<<1)>>1]|0;aG=aJ+(ag(aK,aS)|0)|0;aJ=(aG|0)/16384|0;aI=ag(aE,aL)|0;aE=(ag(aA,aM)|0)+aI|0;aI=aE+(ag(aC,aN)|0)|0;aC=aI+(ag(aK,aO)|0)|0;aK=(aC|0)/16384|0;if((aG|0)<-536887295){bP=-32768}else{bP=(aJ|0)>32767?32767:aJ}if((aC|0)<-536887295){bQ=-32768}else{bQ=(aK|0)>32767?32767:aK}if(J){b[d+(L<<1)>>1]=bP&65535;b[d+((L|1)<<1)>>1]=bQ&65535}else{aK=d+(L<<1)|0;b[aK>>1]=(e[aK>>1]|0)+bP&65535;aK=d+((L|1)<<1)|0;b[aK>>1]=(e[aK>>1]|0)+bQ&65535}L=L+2|0;m=m+K|0;}while((L|0)<(l|0));c[2429600]=m;bR=m}else{bR=s}if((j|0)>(f|0)){return}f=bR>>16;j=k-f|0;if((j|0)>-4){k=c[2438966]|0;s=c[2438967]|0;m=c[2438968]|0;l=c[2438969]|0;L=-4;do{K=f+L|0;b[r+(L+4<<1)>>1]=b[r+(K+4<<1)>>1]|0;b[r+(L+4100<<1)>>1]=b[r+(K+4100<<1)>>1]|0;b[r+(L+8196<<1)>>1]=b[r+(K+8196<<1)>>1]|0;b[r+(L+12292<<1)>>1]=b[r+(K+12292<<1)>>1]|0;if(g){b[k+(L<<1)>>1]=b[k+(K<<1)>>1]|0;b[s+(L<<1)>>1]=b[s+(K<<1)>>1]|0;b[m+(L<<1)>>1]=b[m+(K<<1)>>1]|0;b[l+(L<<1)>>1]=b[l+(K<<1)>>1]|0}L=L+1|0;}while((L|0)<(j|0))}c[2429600]=bR&65535;c[2433544]=j;c[2433574]=j;h[6675]=100.0/+(c[2424]|0)+ +h[6675];return}function Vw(d,f){d=d|0;f=f|0;var g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0.0,t=0.0,u=0.0,v=0.0,w=0.0,x=0.0,y=0.0,z=0.0,A=0.0,B=0.0,C=0.0,D=0.0,E=0.0,F=0.0,G=0.0,H=0.0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0.0,_=0.0,$=0.0,aa=0.0,ab=0.0,ac=0.0,ad=0.0,ae=0.0,af=0.0,ag=0.0,ah=0.0,ai=0.0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0;g=c[2433574]|0;i=(g|0)>(f|0)?g:f;j=c[2433544]|0;k=(i|0)<(j|0)?j:i;i=a[9688]|0?534:0;l=(i|0)<(f|0)?i:f;if((j|0)<(k|0)){f=k-j|0;m=c[2406680]|0;n=m+(j+4<<1)|0;c[2438962]=n;lJ(0,n,f);if((c[2385508]|0)>1){n=m+((c[2433544]|0)+16388<<1)|0;c[2438966]=n;lJ(1,n,f)}c[2433544]=(c[2433544]|0)+f;o=c[2433574]|0}else{o=g}if((o|0)<(k|0)){g=k-o|0;f=c[2406680]|0;n=f+(o+4100<<1)|0;c[2438963]=n;m=f+(o+8196<<1)|0;c[2438964]=m;j=f+(o+12292<<1)|0;c[2438965]=j;mA(0,n,m,j,g);j=c[2385508]|0;if((j|0)>1){m=c[2433574]|0;n=f+(m+20484<<1)|0;c[2438967]=n;o=f+(m+24580<<1)|0;c[2438968]=o;p=f+(m+28676<<1)|0;c[2438969]=p;mA(1,n,o,p,g)}c[2433574]=(c[2433574]|0)+g;q=f;r=j}else{q=c[2406680]|0;r=c[2385508]|0}c[2438962]=q+8;c[2438963]=q+8200;c[2438964]=q+16392;c[2438965]=q+24584;j=(r|0)>1;if(j){c[2438966]=q+32776;c[2438967]=q+40968;c[2438968]=q+49160;c[2438969]=q+57352}r=c[2429600]|0;if((r|0)<(l|0)){f=a[64240]|0;s=+h[146578];t=+h[146577];u=+h[146576];v=+h[146579];w=+h[118363];x=+h[118362];y=+h[118361];z=+h[118364];g=c[2438967]|0;A=+h[146574];p=c[2438968]|0;B=+h[146573];o=c[2438969]|0;C=+h[146572];n=c[2438966]|0;D=+h[146575];E=+h[118359];F=+h[118358];G=+h[118357];H=+h[118360];m=(c[2432978]|0)==0;I=a[3203360]|0?3:0;J=(I&1|0)==0;K=(I&2|0)==0;I=a[3203352]|0?3:0;L=(I&1|0)==0;M=(I&2|0)==0;I=a[3203344]|0?3:0;N=(I&1|0)==0;O=(I&2|0)==0;I=a[3203368]|0?3:0;P=(I&1|0)==0;Q=(I&2|0)==0;I=a[3203328]|0?3:0;R=(I&1|0)==0;S=(I&2|0)==0;I=a[3203320]|0?3:0;T=(I&1|0)==0;U=(I&2|0)==0;I=a[3203312]|0?3:0;V=(I&1|0)==0;W=(I&2|0)==0;I=a[3203336]|0?3:0;X=(I&1|0)==0;Y=(I&2|0)==0;Z=+h[745415];_=+h[745412];$=+h[745413];aa=+h[745414];ab=+h[745419];ac=+h[745416];ad=+h[745417];ae=+h[745418];I=r;do{do{if(f){af=+(b[q+(I+4100<<1)>>1]|0);ag=+(b[q+(I+8196<<1)>>1]|0);ah=+(b[q+(I+12292<<1)>>1]|0);ai=+(b[q+(I+4<<1)>>1]|0);r=~~(ag*t)+~~(af*s)+~~(ah*u)+~~(ai*v)|0;aj=~~(ag*x)+~~(af*w)+~~(ah*y)+~~(ai*z)|0;if(!j){ak=aj;al=r;break}ai=+(b[g+(I<<1)>>1]|0);ah=+(b[p+(I<<1)>>1]|0);af=+(b[o+(I<<1)>>1]|0);ag=+(b[n+(I<<1)>>1]|0);ak=~~(ai*E)+aj+~~(ah*F)+~~(af*G)+~~(ag*H)|0;al=~~(ai*A)+r+~~(ah*B)+~~(af*C)+~~(ag*D)|0}else{if(J){am=0}else{am=~~(+(b[q+(I+4100<<1)>>1]|0)*ae)}if(K){an=0}else{an=~~(+(b[q+(I+4100<<1)>>1]|0)*ae)}if(L){ao=am}else{ao=~~(+(b[q+(I+8196<<1)>>1]|0)*ad)+am|0}if(M){ap=an}else{ap=~~(+(b[q+(I+8196<<1)>>1]|0)*ad)+an|0}if(N){aq=ao}else{aq=~~(+(b[q+(I+12292<<1)>>1]|0)*ac)+ao|0}if(O){ar=ap}else{ar=~~(+(b[q+(I+12292<<1)>>1]|0)*ac)+ap|0}if(P){as=aq}else{as=~~(+(b[q+(I+4<<1)>>1]|0)*ab)+aq|0}if(Q){at=ar}else{at=~~(+(b[q+(I+4<<1)>>1]|0)*ab)+ar|0}if(!j){ak=at;al=as;break}if(R){au=as}else{au=~~(+(b[g+(I<<1)>>1]|0)*aa)+as|0}if(S){av=at}else{av=~~(+(b[g+(I<<1)>>1]|0)*aa)+at|0}if(T){aw=au}else{aw=~~(+(b[p+(I<<1)>>1]|0)*$)+au|0}if(U){ax=av}else{ax=~~(+(b[p+(I<<1)>>1]|0)*$)+av|0}if(V){ay=aw}else{ay=~~(+(b[o+(I<<1)>>1]|0)*_)+aw|0}if(W){az=ax}else{az=~~(+(b[o+(I<<1)>>1]|0)*_)+ax|0}if(X){aA=ay}else{aA=~~(+(b[n+(I<<1)>>1]|0)*Z)+ay|0}if(Y){ak=az;al=aA;break}ak=~~(+(b[n+(I<<1)>>1]|0)*Z)+az|0;al=aA}}while(0);if((al|0)<-32768){aB=-32768}else{aB=(al|0)>32767?32767:al}if((ak|0)<-32768){aC=-32768}else{aC=(ak|0)>32767?32767:ak}if(m){r=I<<1;b[d+(r<<1)>>1]=aB&65535;b[d+((r|1)<<1)>>1]=aC&65535}else{r=I<<1;aj=d+(r<<1)|0;b[aj>>1]=(e[aj>>1]|0)+aB&65535;aj=d+((r|1)<<1)|0;b[aj>>1]=(e[aj>>1]|0)+aC&65535}I=I+1|0;}while((I|0)<(l|0))}c[2429600]=l;if((k|0)<(i|0)){return}l=k-i|0;if((l|0)>0){k=c[2438966]|0;I=c[2438967]|0;aC=c[2438968]|0;d=c[2438969]|0;aB=0;do{m=aB+i|0;b[q+(aB+4<<1)>>1]=b[q+(m+4<<1)>>1]|0;b[q+(aB+4100<<1)>>1]=b[q+(m+4100<<1)>>1]|0;b[q+(aB+8196<<1)>>1]=b[q+(m+8196<<1)>>1]|0;b[q+(aB+12292<<1)>>1]=b[q+(m+12292<<1)>>1]|0;if(j){b[k+(aB<<1)>>1]=b[k+(m<<1)>>1]|0;b[I+(aB<<1)>>1]=b[I+(m<<1)>>1]|0;b[aC+(aB<<1)>>1]=b[aC+(m<<1)>>1]|0;b[d+(aB<<1)>>1]=b[d+(m<<1)>>1]|0}aB=aB+1|0;}while((aB|0)<(l|0))}c[2429600]=0;c[2433544]=l;c[2433574]=l;h[6675]=100.0/+(c[2424]|0)+ +h[6675];return}function Vx(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;i=i+128|0;e=d|0;f=d+16|0;g=d+32|0;h=d+48|0;j=d+64|0;k=d+80|0;l=d+96|0;m=d+112|0;n=(b|0)==0;do{if(!n){if((c[b>>2]|0)>=169249){break}c[b>>2]=169249}}while(0);if((a&64|0)==0){i=d;return}gGz(k|0,0,12);c[k>>2]=9775320;c[k+4>>2]=8;c[k+12>>2]=111920;gj[c[2076592]&4095](k)|0;gGz(j|0,0,12);c[j>>2]=9775288;c[j+4>>2]=8;c[j+12>>2]=478936;gj[c[2076592]&4095](j)|0;gGz(h|0,0,12);c[h>>2]=53400;c[h+4>>2]=8;c[h+12>>2]=398448;gj[c[2076592]&4095](h)|0;gGz(g|0,0,12);c[g>>2]=14114048;c[g+4>>2]=4;c[g+12>>2]=287368;gj[c[2076592]&4095](g)|0;g=f|0;do{if(!n){if((c[b>>2]|0)>=169110){break}c[b>>2]=169110}}while(0);if((c[2113008]|0)>0){b=e|0;n=e+4|0;f=e+8|0;h=e+12|0;j=0;do{cC(g|0,531144,(k=i,i=i+8|0,c[k>>2]=j,k)|0)|0;i=k;c[b>>2]=14168888+(j*252|0);c[n>>2]=252;c[f>>2]=0;c[h>>2]=g;gj[c[2076592]&4095](e)|0;j=j+1|0;}while((j|0)<(c[2113008]|0))}gGz(m|0,0,12);c[m>>2]=9734176;c[m+4>>2]=4;c[m+12>>2]=93288;gj[c[2076592]&4095](m)|0;gGz(l|0,0,12);c[l>>2]=9734296;c[l+4>>2]=4;c[l+12>>2]=470080;gj[c[2076592]&4095](l)|0;i=d;return}function Vy(e){e=e|0;var f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0.0,S=0.0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;f=i;i=i+352800|0;j=f|0;k=c[2112964]|0;if(!(a[9680]|0)){i=f;return}l=c[2432828]|0;m=(l|0)>(e|0)?l:e;n=a[9688]|0?534:0;o=(n|0)<(e|0)?n:e;if((l|0)<(m|0)){e=m-l|0;p=c[2406678]|0;q=l+4|0;c[2438090]=p+(q<<1);r=l+4100|0;c[2438088]=p+(r<<1);gGz(j|0,0,e<<3|0);l=c[3531837]|0;s=j|0;if((e|0)>0){j=0;t=0;while(1){u=14125864+(t*60|0)|0;v=14125892+(t*60|0)|0;if((a[v]|0)==0){w=j}else{x=14125893+(t*60|0)|0;y=14125871+(t*60|0)|0;z=14125872+(t*60|0)|0;A=14125912+(t*60|0)|0;B=14125884+(t*60|0)|0;C=14125888+(t*60|0)|0;D=14125904+(t*60|0)|0;E=14125916+(t*60|0)|0;F=14125920+(t*60|0)|0;G=14125900+(t*60|0)|0;H=14125896+(t*60|0)|0;I=j;J=s;K=0;while(1){L=a[x]|0;do{if((L|0)==12){M=c[C>>2]|0;N=((M>>>17)*3|0)+(c[H>>2]|0)|0;if((M&1|0)==0){O=a[l+(N+1)|0]&240|d[l+N|0]<<8;break}else{O=d[l+(N+1)|0]<<4&240|d[l+(N+2)|0]<<8;break}}else if((L|0)==8){O=d[l+(((c[C>>2]|0)>>>16)+(c[H>>2]|0))|0]<<8}else if((L|0)==16){N=((c[C>>2]|0)>>>16<<1)+(c[H>>2]|0)|0;O=d[l+N|0]<<8|d[l+(N+1)|0]}else{O=I}}while(0);L=O<<16>>16;N=(ag(c[8306408+((c[8451632+(a[z]<<2)>>2]|0)+(a[y]|0)+((c[A>>2]|0)>>>23)<<2)>>2]|0,L)|0)>>17;M=J+4|0;c[J>>2]=N+(c[J>>2]|0);N=(ag(c[8306408+((c[8451568+(a[z]<<2)>>2]|0)+(a[y]|0)+((c[A>>2]|0)>>>23)<<2)>>2]|0,L)|0)>>17;L=J+8|0;c[M>>2]=N+(c[M>>2]|0);M=(c[C>>2]|0)+(c[B>>2]|0)|0;c[C>>2]=M;N=c[D>>2]|0;do{if(M>>>0>=N>>>0){P=(c[G>>2]|0)+(M-N)|0;c[C>>2]=P;if(P>>>0<N>>>0){break}c[A>>2]=-2147483648;c[E>>2]=0;c[F>>2]=0;a[v]=0;c[C>>2]=0;c[B>>2]=0}}while(0);N=(c[A>>2]|0)+(c[E>>2]|0)|0;c[A>>2]=N;if((N-(c[F>>2]|0)|0)>-1){mm(u,+g[3531838])}N=K+1|0;if((N|0)<(e|0)){I=O;J=L;K=N}else{w=O;break}}}K=t+1|0;if((K|0)<24){j=w;t=K}else{break}}t=c[8453296+(c[3531830]<<2)>>2]|0;w=c[8453296+(c[3531831]<<2)>>2]|0;j=s;s=0;while(1){b[p+(q+s<<1)>>1]=(ag(c[j>>2]|0,t)|0)>>>16&65535;b[p+(r+s<<1)>>1]=(ag(c[j+4>>2]|0,w)|0)>>>16&65535;O=s+1|0;if((O|0)<(e|0)){j=j+8|0;s=O}else{break}}}c[2432828]=m;Q=p}else{Q=c[2406678]|0}p=Q+8|0;c[2438090]=p;s=Q+8200|0;c[2438088]=s;j=c[2429598]|0;if((j|0)<(o|0)){e=c[2433120]|0;w=(e&1|0)==0;r=(e&2|0)==0;e=c[2433118]|0;t=(e&1|0)==0;q=(e&2|0)==0;R=+h[607288];S=+h[607289];e=j;do{if(w){T=0}else{T=~~(+(b[Q+(e+4<<1)>>1]|0)*S)}if(r){U=0}else{U=~~(+(b[Q+(e+4<<1)>>1]|0)*S)}if(t){V=T}else{V=~~(+(b[Q+(e+4100<<1)>>1]|0)*R)+T|0}if(q){W=U}else{W=~~(+(b[Q+(e+4100<<1)>>1]|0)*R)+U|0}if((V|0)<-32768){X=-32768}else{X=(V|0)>32767?32767:V&65535}if((W|0)<-32768){Y=-32768}else{Y=(W|0)>32767?32767:W&65535}j=e<<1;b[k+(j<<1)>>1]=X;b[k+((j|1)<<1)>>1]=Y;e=e+1|0;}while((e|0)<(o|0))}c[2429598]=o;if((m|0)<(n|0)){i=f;return}o=m-n|0;do{if((o|0)>0){b[p>>1]=b[Q+(n+4<<1)>>1]|0;b[s>>1]=b[Q+(n+4100<<1)>>1]|0;if((o|0)>1){Z=1}else{break}do{m=Z+n|0;b[Q+(Z+4<<1)>>1]=b[Q+(m+4<<1)>>1]|0;b[Q+(Z+4100<<1)>>1]=b[Q+(m+4100<<1)>>1]|0;Z=Z+1|0;}while((Z|0)<(o|0))}}while(0);c[2429598]=0;c[2432828]=o;i=f;return}function Vz(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,i=0;c[2438228]=0;c[2433526]=0;c[2406676]=0;c[3528472]=0;f=c[2406678]|0;if((f|0)!=0){gGr(f);c[2406678]=0}c[2426988]=(e|0)==0?2604:e;e=a[9680]|0?32e3:0;gGz(14125864,0,1488);c[3531837]=b;c[3531835]=d;c[3531836]=2;c[3531833]=0;g[3531838]=1.0;c[2161346]=e;e=0;do{c[8306408+(e<<2)>>2]=~~(+c$(+(+(e|0)*-.0625))*65536.0);e=e+1|0;}while((e|0)<256);gGz(8307432,0,3072);e=0;L61327:while(1){do{if((e|0)<7){c[8451632+(e<<2)>>2]=e<<3;i=0}else{c[8451632+(e<<2)>>2]=(e|0)<9?256:0;if((e|0)<8){c[8451568+(e<<2)>>2]=0;e=e+1|0;continue L61327}if((e|0)<10){i=256;break}i=16-e<<3}}while(0);c[8451568+(e<<2)>>2]=i;e=e+1|0;if((e|0)>=16){break}}c[2113324]=c[2076610];c[2113325]=c[2076618];c[2113326]=c[2076626];c[2113327]=c[2076634];c[2113328]=c[2076642];c[2113329]=c[2076650];c[2113330]=c[2076658];c[2113331]=0;c[2438228]=0;c[2433526]=0;c[2406676]=0;c[3528472]=0;c[2429844]=11894;c[2429842]=80;c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;e=gGq(16384)|0;c[2406678]=e;gGz(e|0,0,16384);c[2432828]=0;c[2429598]=0;h[607289]=1.0;h[607288]=1.0;c[2433120]=1;c[2433118]=2;return}function VA(a){a=a|0;return 0}function VB(){var b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;if((c[3541872]|0)==0){b=1;return b|0}c[1836238]=-1;d=-1;f=14166648;while(1){L61345:do{if((c[f+4>>2]|0)==0){g=c[f>>2]|0;h=d>>>0>12|0;c[2411218]=h;i=(g>>>4)+1|0;j=16-(g&15)|0;g=c[2113240]|0;c[2113230]=(d<<4)+16-(g&15);k=d+1|0;l=(g>>4)+k|0;g=l<<2&60|l<<8&12288;l=-1;m=h;while(1){c[2113234]=(m|0)!=0|l>>>0>22?10:8;h=g|i+l<<6&4032;n=c[3541872]|0;o=c[2439494]|0;p=(e[n+h>>1]|0)<<1;q=c[o>>2]|0;L61349:do{if((q|0)!=0){r=o;s=q;L61350:while(1){do{if((p|0)>=(c[r+4>>2]|0)){if((p|0)>(c[r+8>>2]|0)){break}if((s&4|0)!=0){break L61350}}}while(0);t=r+16|0;u=c[t>>2]|0;if((u|0)==0){break L61349}else{r=t;s=u}}s=c[r+12>>2]|0;if((s|0)>0){u=0;t=0;while(1){v=(c[9773320+(t<<2)>>2]|0)+u|0;w=t+1|0;if((w|0)<(s|0)){u=v;t=w}else{x=v;break}}}else{x=0}t=((c[9773320+(s<<2)>>2]|0)+131071&p)+x>>1;if((t|0)==-1){break}u=(c[2113262]|0)+(t<<7)|0;if((u|0)==(c[1836238]|0)){break}t=e[n+(h|2)>>1]|0;c[3541654]=(c[3541942]|0)+((t<<4&496|1024)<<2);c[2113232]=j+(l<<4);c[2113236]=u;c[2113238]=t>>>5&3;r=a[9760]|0;if(r){c[3541652]=e[(c[3541886]|0)+(c[14164744+((t>>>7&3)<<2)>>2]|0)>>1]|0}if((gD[c[7461952+((r&1)<<2)>>2]&8191]()|0)==0){break}c[1836238]=u}}while(0);h=l+1|0;if((h|0)>=24){y=k;break L61345}l=h;m=c[2411218]|0}}else{m=d>>>0>12|0;c[2411218]=m;l=f+8|0;k=c[l>>2]|0;j=(c[f+12>>2]|0)-k|0;i=c[2113240]|0;c[2113230]=(d<<4)+16-(i&15);c[3541650]=f+16;if((j|0)<=0){y=d+1|0;break}g=d+1|0;h=(i>>4)+g|0;i=h<<2&60|h<<8&12288;h=c[f+52>>2]|0;n=c[f+48>>2]|0;p=0;q=m;m=k;while(1){if((q|0)==0){z=(h|0)>368?1:n>>>31}else{z=q}c[2113234]=(z|0)==0?12:14;k=i|m+p<<6&4032;o=c[3541872]|0;u=c[2439494]|0;r=(e[o+k>>1]|0)<<1;t=c[u>>2]|0;L61378:do{if((t|0)!=0){v=u;w=t;L61379:while(1){do{if((r|0)>=(c[v+4>>2]|0)){if((r|0)>(c[v+8>>2]|0)){break}if((w&4|0)!=0){break L61379}}}while(0);A=v+16|0;B=c[A>>2]|0;if((B|0)==0){break L61378}else{v=A;w=B}}w=c[v+12>>2]|0;if((w|0)>0){s=0;B=0;while(1){A=(c[9773320+(B<<2)>>2]|0)+s|0;C=B+1|0;if((C|0)<(w|0)){s=A;B=C}else{D=A;break}}}else{D=0}B=((c[9773320+(w<<2)>>2]|0)+131071&r)+D>>1;if((B|0)==-1){break}s=(c[2113262]|0)+(B<<7)|0;if((s|0)==(c[1836238]|0)){break}B=e[o+(k|2)>>1]|0;c[3541654]=(c[3541942]|0)+((B<<4&496|1024)<<2);c[2113232]=p<<4;c[2113236]=s;c[2113238]=B>>>5&3;v=a[9760]|0;if(v){c[3541652]=e[(c[3541886]|0)+(c[14164744+((B>>>7&3)<<2)>>2]|0)>>1]|0}if((gD[c[7461952+((v&1)<<2)>>2]&8191]()|0)==0){break}c[1836238]=s}}while(0);k=p+1|0;if((k|0)>=(j|0)){y=g;break L61345}h=h+16|0;n=n+16|0;p=k;q=c[2411218]|0;m=c[l>>2]|0}}}while(0);if((y|0)<14){d=y;f=f+56|0}else{b=0;break}}return b|0}function VC(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;if((c[3541872]|0)==0){a=1;return a|0}c[1836238]=-1;b=c[2113214]|0;d=c[2113240]&15;f=d+b>>4;c[2409620]=f;g=c[2113038]|0;h=g+d>>4;d=h-1|0;if((d|0)>=(f|0)){a=0;return a|0}f=d;d=14166648+(h*56|0)|0;h=g;g=b;while(1){b=f<<4;i=b+16|0;j=(i|0)>=(g|0)|(b|0)<(h|0);c[2411218]=j;L61409:do{if((c[d+4>>2]|0)==0){b=c[d>>2]|0;k=(b>>>4)+1|0;l=16-(b&15)|0;b=c[2113240]|0;c[2113230]=i-(b&15);m=f+1|0;n=(b>>4)+m|0;b=n<<2&60|n<<8&12288;n=-1;o=j;while(1){c[2113234]=(o|0)!=0|n>>>0>22?10:8;p=b|k+n<<6&4032;q=c[3541872]|0;r=((e[q+p>>1]|0)<<7)+(c[2113262]|0)|0;do{if((r|0)!=(c[1836238]|0)){s=e[q+(p|2)>>1]|0;c[3541654]=(c[3541942]|0)+((s<<4&496|1024)<<2);c[2113232]=l+(n<<4);c[2113236]=r;c[2113238]=s>>>5&3;if((W2()|0)==0){break}c[1836238]=r}}while(0);r=n+1|0;if((r|0)>=24){t=m;break L61409}n=r;o=c[2411218]|0}}else{o=d+8|0;n=c[o>>2]|0;m=(c[d+12>>2]|0)-n|0;l=c[2113240]|0;c[2113230]=i-(l&15);c[3541650]=d+16;if((m|0)<=0){t=f+1|0;break}k=f+1|0;b=(l>>4)+k|0;l=b<<2&60|b<<8&12288;b=c[d+52>>2]|0;r=c[d+48>>2]|0;p=0;q=j;s=n;while(1){if((q|0)==0){u=(b|0)>368?1:r>>>31}else{u=q}c[2113234]=(u|0)==0?12:14;n=l|s+p<<6&4032;v=c[3541872]|0;w=((e[v+n>>1]|0)<<7)+(c[2113262]|0)|0;do{if((w|0)!=(c[1836238]|0)){x=e[v+(n|2)>>1]|0;c[3541654]=(c[3541942]|0)+((x<<4&496|1024)<<2);c[2113232]=p<<4;c[2113236]=w;c[2113238]=x>>>5&3;if((W2()|0)==0){break}c[1836238]=w}}while(0);w=p+1|0;if((w|0)>=(m|0)){t=k;break L61409}b=b+16|0;r=r+16|0;p=w;q=c[2411218]|0;s=c[o>>2]|0}}}while(0);if((t|0)>=(c[2409620]|0)){a=0;break}f=t;d=d+56|0;h=c[2113038]|0;g=c[2113214]|0}return a|0}function VD(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;f=c[3542064]|0;if((f|0)!=0){gD[f&8191]()|0;return}f=c[2394758]|0;g=9707412+(f<<4)|0;c[g>>2]=0;h=c[9707408+(f<<4)>>2]|0;i=9707400+(f<<4)|0;c[i>>2]=-64;j=9707404+(f<<4)|0;c[j>>2]=-16;k=(c[3542068]|0)==2;do{if(k){l=(c[3541934]|0)+(c[2113256]<<15^32768)|0;m=c[3541900]|0;c[i>>2]=-(d[m+9|0]|0);c[j>>2]=-(d[m+11|0]|0);n=l}else{l=e[c[3541926]>>1]<<8&16775168;if(l>>>0>9437183&(l+2048|0)>>>0<9633793){o=(c[3541932]|0)+(l-9437184)|0}else{o=0}if(!(a[7462152]|0)){n=o;break}n=(c[3541932]|0)+65536|0}}while(0);if((n|0)==0){return}o=c[2420374]|0;L61451:do{if((o|0)>0){j=a[7462176]|0;i=h;l=n;m=1;p=0;while(1){q=l;do{if(k){if((b[l+2>>1]|0)<0){break L61451}r=b[l+6>>1]|0;if((r&65535)>65279){break L61451}else{s=r}}else{r=b[l+6>>1]|0;if((r&65535)>65279){break L61451}if(!j){s=r;break}if((b[l+2>>1]|0)<0){break L61451}else{s=r}}}while(0);if((b[q>>1]|s)<<16>>16==0){t=i;u=p}else{r=l;v=i;w=r|0;x=r+4|0;r=d[x]|d[x+1|0]<<8|d[x+2|0]<<16|d[x+3|0]<<24|0;x=v|0;C=d[w]|d[w+1|0]<<8|d[w+2|0]<<16|d[w+3|0]<<24|0;a[x]=C&255;C=C>>8;a[x+1|0]=C&255;C=C>>8;a[x+2|0]=C&255;C=C>>8;a[x+3|0]=C&255;x=v+4|0;C=r;a[x]=C&255;C=C>>8;a[x+1|0]=C&255;C=C>>8;a[x+2|0]=C&255;C=C>>8;a[x+3|0]=C&255;x=p+1|0;c[g>>2]=x;t=i+8|0;u=x}if((m|0)>=(o|0)){break L61451}i=t;l=l+8|0;m=m+1|0;p=u}}}while(0);u=f+1|0;c[2394758]=u;if((u|0)<((a[7024720]|0?2:0)|0)){return}c[2394758]=0;return}function VE(b,d){b=b|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;if((c[3542066]|0)!=0){f=VM(b,d)|0;return f|0}d=c[2394758]|0;b=c[9707408+(d<<4)>>2]|0;g=9707412+(d<<4)|0;h=c[g>>2]|0;if(a[7461992]|0){i=b;j=4}else{i=b+((h<<2)-4<<1)|0;j=-4}if((h|0)<=0){f=0;return f|0}b=9707400+(d<<4)|0;k=9707404+(d<<4)|0;d=i;i=1;l=h;while(1){h=e[d+2>>1]|0;m=e[d+6>>1]|0;n=m>>>8&15;o=n+1|0;p=m>>>12;q=p+1|0;r=c[2439494]|0;s=(e[d+4>>1]|0)<<1;t=c[r>>2]|0;L61484:do{if((t|0)==0){u=l}else{v=r;w=t;L61485:while(1){do{if((s|0)>=(c[v+4>>2]|0)){if((s|0)>(c[v+8>>2]|0)){break}if((w&1|0)!=0){break L61485}}}while(0);x=v+16|0;y=c[x>>2]|0;if((y|0)==0){u=l;break L61484}else{v=x;w=y}}w=c[v+12>>2]|0;if((w|0)>0){y=0;x=0;while(1){z=(c[9773320+(x<<2)>>2]|0)+y|0;A=x+1|0;if((A|0)<(w|0)){y=z;x=A}else{B=z;break}}}else{B=0}x=((c[9773320+(w<<2)>>2]|0)+131071&s)+B>>1;if((x|0)==-1){u=l;break}y=e[d>>1]|0;v=h<<3&196608;z=y&511;A=(z>>>0>447?y|-512:z)+(c[b>>2]|0)|0;z=(c[k>>2]|0)+(h<<23>>23)|0;c[3541654]=(c[3541942]|0)+((m<<4&496)<<2);y=m>>>5;C=y&3;do{if((A|z|0)<0){D=10}else{if((A+(o<<4)|0)>384){D=10;break}D=(z+(q<<4)|0)>224?10:8}}while(0);c[2113234]=D;c[2113238]=C;w=(y&1|0)==0;E=(y&2|0)==0;F=x&33554416|v;G=0;do{H=G<<4;I=H+F|0;J=p-G|0;if(w){if(E){K=H+z|0;L=0;do{c[2113232]=(L<<4)+A;c[2113230]=K;c[2113236]=(L+x&15|I)<<7;W0()|0;L=L+1|0;}while((L|0)<(o|0))}else{L=(J<<4)+z|0;K=0;do{c[2113232]=(K<<4)+A;c[2113230]=L;c[2113236]=(K+x&15|I)<<7;W0()|0;K=K+1|0;}while((K|0)<(o|0))}}else{if(E){K=H+z|0;L=0;do{c[2113232]=(n-L<<4)+A;c[2113230]=K;c[2113236]=(L+x&15|I)<<7;W0()|0;L=L+1|0;}while((L|0)<(o|0))}else{L=(J<<4)+z|0;K=0;do{c[2113232]=(n-K<<4)+A;c[2113230]=L;c[2113236]=(K+x&15|I)<<7;W0()|0;K=K+1|0;}while((K|0)<(o|0))}}G=G+1|0;}while((G|0)<(q|0));u=c[g>>2]|0}}while(0);if((i|0)>=(u|0)){f=0;break}d=d+(j<<1)|0;i=i+1|0;l=u}return f|0}function VF(a,f){a=a|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;g=c[2394758]|0;h=c[9707408+(g<<4)>>2]|0;i=c[3528532]|0;j=c[2394732]|0;k=(c[9707412+(g<<4)>>2]|0)+j|0;l=i&65535;b[3726284]=l;m=i&65535;if((m|0)>(k|0)){return 0}n=9707400+(g<<4)|0;o=9707404+(g<<4)|0;g=0;p=h+((i-j<<2)-4<<1)|0;j=m;m=l;while(1){l=e[p>>1]|0;i=l>>>13;do{if((1<<i&255|0)==0){q=g;r=m}else{if((i|0)>(f|0)){q=1;r=m;break}if((i|0)<(a|0)){q=g;r=m;break}if(g){c[2385516]=j;s=7461948}else{c[3528532]=j;s=(c[2385516]|0)>(j|0)?7461948:7461944}h=c[s>>2]|0;t=e[p+2>>1]|0;u=e[p+4>>1]|0;v=e[p+6>>1]|0;if((v&128|0)==0){w=l}else{w=(d[(c[3541900]|0)+9|0]|0)+l|0}x=(w<<22>>22)+(c[n>>2]|0)|0;y=(c[o>>2]|0)+(t<<22>>22)|0;z=t<<3&196608;c[3541654]=(c[3541942]|0)+((v<<4&496)<<2);t=v>>>5;A=t&3;B=v>>>8&15;C=B+1|0;D=v>>>12;v=D+1|0;do{if((x|y|0)<0){E=10}else{if((x+(C<<4)|0)>383){E=10;break}E=(y+(v<<4)|0)>223?10:8}}while(0);c[2113234]=E;c[2113238]=A;F=(t&1|0)==0;G=(t&2|0)==0;H=z|u&65520;I=0;do{J=(I<<4)+H|0;K=((G?I:D-I|0)<<4)+y|0;if(F){L=0;do{c[2113232]=(L<<4)+x;c[2113230]=K;c[2113236]=(L+u&15|J)<<7;gD[h&8191]()|0;L=L+1|0;}while((L|0)<(C|0))}else{L=0;do{c[2113232]=(B-L<<4)+x;c[2113230]=K;c[2113236]=(L+u&15|J)<<7;gD[h&8191]()|0;L=L+1|0;}while((L|0)<(C|0))}I=I+1|0;}while((I|0)<(v|0));q=g;r=b[3726284]|0}}while(0);l=r+1&65535;b[3726284]=l;i=l&65535;if((i|0)>(k|0)){break}g=q;p=p+8|0;j=i;m=l}return 0}function VG(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=c[2394758]|0;e=9707412+(d<<4)|0;c[e>>2]=0;f=c[9707408+(d<<4)>>2]|0;c[9707400+(d<<4)>>2]=-64;c[9707404+(d<<4)>>2]=-16;g=(c[3541932]|0)+20680|0;if((g|0)==0){h=1;return h|0}i=c[2420374]|0;L61562:do{if((i|0)>0){j=f;k=g;l=0;m=0;while(1){n=b[k-2>>1]|0;if(n<<16>>16==-32768){break L61562}o=b[k>>1]|0;p=b[k+2>>1]|0;q=b[k+4>>1]|0;a[j]=o&255;a[j+1|0]=(o&65535)>>>8&255;a[j+2|0]=p&255;a[j+3|0]=(p&65535)>>>8&255;a[j+4|0]=q&255;a[j+5|0]=(q&65535)>>>8&255;a[j+6|0]=n&255;a[j+7|0]=(n&65535)>>>8&255;n=m+1|0;c[e>>2]=n;q=l+1|0;if((q|0)<(i|0)){j=j+8|0;k=k+8|0;l=q;m=n}else{break}}}}while(0);i=d+1|0;c[2394758]=i;if((i|0)<((a[7024720]|0?2:0)|0)){h=0;return h|0}c[2394758]=0;h=0;return h|0}function VH(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=c[2394758]|0;e=9707412+(d<<4)|0;c[e>>2]=0;f=c[9707408+(d<<4)>>2]|0;c[9707400+(d<<4)>>2]=-64;c[9707404+(d<<4)>>2]=-16;g=(c[3542036]|0)+4096|0;if((g|0)==0){h=1;return h|0}i=c[2420374]|0;L61575:do{if((i|0)>0){j=f;k=g;l=0;m=0;while(1){n=b[k-2>>1]|0;if(n<<16>>16==-1){break L61575}o=b[k>>1]|0;p=b[k+2>>1]|0;q=b[k+4>>1]|0;a[j]=o&255;a[j+1|0]=(o&65535)>>>8&255;a[j+2|0]=p&255;a[j+3|0]=(p&65535)>>>8&255;a[j+4|0]=q&255;a[j+5|0]=(q&65535)>>>8&255;a[j+6|0]=n&255;a[j+7|0]=(n&65535)>>>8&255;n=m+1|0;c[e>>2]=n;q=l+1|0;if((q|0)<(i|0)){j=j+8|0;k=k+8|0;l=q;m=n}else{break}}}}while(0);i=d+1|0;c[2394758]=i;if((i|0)<((a[7024720]|0?2:0)|0)){h=0;return h|0}c[2394758]=0;h=0;return h|0}function VI(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=c[2394758]|0;e=9707412+(d<<4)|0;c[e>>2]=0;f=c[9707408+(d<<4)>>2]|0;c[9707400+(d<<4)>>2]=-64;c[9707404+(d<<4)>>2]=-16;g=(c[3542036]|0)+4096|0;if((g|0)==0){h=1;return h|0}i=c[2420374]|0;L61588:do{if((i|0)>0){j=f;k=g;l=0;m=0;while(1){n=b[k-2>>1]|0;if(n<<16>>16==-32768){break L61588}o=b[k>>1]|0;p=b[k+2>>1]|0;q=b[k+4>>1]|0;a[j]=o&255;a[j+1|0]=(o&65535)>>>8&255;a[j+2|0]=p&255;a[j+3|0]=(p&65535)>>>8&255;a[j+4|0]=q&255;a[j+5|0]=(q&65535)>>>8&255;a[j+6|0]=n&255;a[j+7|0]=(n&65535)>>>8&255;n=m+1|0;c[e>>2]=n;q=l+1|0;if((q|0)<(i|0)){j=j+8|0;k=k+8|0;l=q;m=n}else{break}}}}while(0);i=d+1|0;c[2394758]=i;if((i|0)<((a[7024720]|0?2:0)|0)){h=0;return h|0}c[2394758]=0;h=0;return h|0}function VJ(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;d=c[2394758]|0;f=9707412+(d<<4)|0;c[f>>2]=0;g=c[9707408+(d<<4)>>2]|0;c[9707400+(d<<4)>>2]=-64;c[9707404+(d<<4)>>2]=-16;h=(c[3542036]|0)+4112|0;if((h|0)==0){i=1;return i|0}j=c[2420374]|0;L61601:do{if((j|0)>0){k=c[2439494]|0;l=k|0;m=g;n=h;o=0;p=0;while(1){q=b[n-2>>1]|0;if(q<<16>>16==-32768){break L61601}r=b[n+2>>1]|0;s=b[n+4>>1]|0;t=(e[n>>1]|0)<<1;u=c[l>>2]|0;L61606:do{if((u|0)==0){v=m;w=p}else{x=k;y=u;L61607:while(1){do{if((t|0)>=(c[x+4>>2]|0)){if((t|0)>(c[x+8>>2]|0)){break}if((y&1|0)!=0){break L61607}}}while(0);z=x+16|0;A=c[z>>2]|0;if((A|0)==0){v=m;w=p;break L61606}else{x=z;y=A}}y=c[x+12>>2]|0;if((y|0)>0){A=0;z=0;while(1){B=(c[9773320+(z<<2)>>2]|0)+A|0;C=z+1|0;if((C|0)<(y|0)){A=B;z=C}else{D=B;break}}}else{D=0}z=((c[9773320+(y<<2)>>2]|0)+131071&t)+D>>1;if((z|0)==-1){v=m;w=p;break}a[m]=z&255;a[m+1|0]=z>>>8&255;a[m+2|0]=r&255;a[m+3|0]=(r&65535)>>>8&255;a[m+4|0]=s&255;a[m+5|0]=(s&65535)>>>8&255;a[m+6|0]=q&255;a[m+7|0]=(q&65535)>>>8&255;z=p+1|0;c[f>>2]=z;v=m+8|0;w=z}}while(0);q=o+1|0;if((q|0)<(j|0)){m=v;n=n+8|0;o=q;p=w}else{break}}}}while(0);w=d+1|0;c[2394758]=w;if((w|0)<((a[7024720]|0?2:0)|0)){i=0;return i|0}c[2394758]=0;i=0;return i|0}function VK(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=c[2394758]|0;e=9707412+(d<<4)|0;c[e>>2]=0;f=c[9707408+(d<<4)>>2]|0;c[9707400+(d<<4)>>2]=-64;c[9707404+(d<<4)>>2]=-16;g=(c[3541932]|0)+4096|0;if((g|0)==0){h=1;return h|0}i=c[2420374]|0;L61629:do{if((i|0)>0){j=f;k=g;l=0;m=0;while(1){n=b[k-2>>1]|0;if(n<<16>>16==-32768){break L61629}o=b[k>>1]|0;p=b[k+2>>1]|0;q=b[k+4>>1]|0;a[j]=o&255;a[j+1|0]=(o&65535)>>>8&255;a[j+2|0]=p&255;a[j+3|0]=(p&65535)>>>8&255;a[j+4|0]=q&255;a[j+5|0]=(q&65535)>>>8&255;a[j+6|0]=n&255;a[j+7|0]=(n&65535)>>>8&255;n=m+1|0;c[e>>2]=n;q=l+1|0;if((q|0)<(i|0)){j=j+8|0;k=k+8|0;l=q;m=n}else{break}}}}while(0);i=d+1|0;c[2394758]=i;if((i|0)<((a[7024720]|0?2:0)|0)){h=0;return h|0}c[2394758]=0;h=0;return h|0}function VL(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=c[2394758]|0;f=9707412+(d<<4)|0;c[f>>2]=0;g=c[9707408+(d<<4)>>2]|0;c[9707400+(d<<4)>>2]=-64;c[9707404+(d<<4)>>2]=-16;h=(c[3542036]|0)+4096|0;if((h|0)==0){i=1;return i|0}j=c[2420374]|0;L61642:do{if((j|0)>0){k=g;l=h;m=0;n=0;while(1){o=b[l-2>>1]|0;if(o<<16>>16==-32768){break L61642}p=b[l>>1]|0;q=b[l+2>>1]|0;r=(e[l+4>>1]|0)+3|0;a[k]=p&255;a[k+1|0]=(p&65535)>>>8&255;a[k+2|0]=q&255;a[k+3|0]=(q&65535)>>>8&255;a[k+4|0]=r&255;a[k+5|0]=r>>>8&255;a[k+6|0]=o&255;a[k+7|0]=(o&65535)>>>8&255;o=n+1|0;c[f>>2]=o;r=m+1|0;if((r|0)<(j|0)){k=k+8|0;l=l+8|0;m=r;n=o}else{break}}}}while(0);j=d+1|0;c[2394758]=j;if((j|0)<((a[7024720]|0?2:0)|0)){i=0;return i|0}c[2394758]=0;i=0;return i|0}function VM(a,d){a=a|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0;d=c[2394758]|0;a=9707412+(d<<4)|0;if((c[a>>2]|0)<=0){return 0}f=c[9707408+(d<<4)>>2]|0;d=0;while(1){g=e[f>>1]|0;h=e[f+2>>1]|0;i=b[f+4>>1]&511;j=i-16|0;k=224-(b[f+6>>1]&511)|0;c[3541654]=(c[3541942]|0)+((h<<4&496)<<2);c[2113234]=(k|j|0)<0|i>>>0>384|(k+16|0)>224?10:8;c[2113238]=h>>>5&3;c[2113232]=j;c[2113230]=k;c[2113236]=g<<7;W0()|0;g=d+1|0;if((g|0)<(c[a>>2]|0)){f=f+8|0;d=g}else{break}}return 0}function VN(a){a=a|0;switch(a|0){case 6:{c[2443330]=16384;c[2443331]=16384;c[2443332]=16384;c[2443333]=16384;c[2439494]=939952;return};case 13:{c[2443330]=32768;c[2443331]=16384;c[2443332]=0;c[2443333]=0;c[2439494]=940704;return};case 18:{c[2443330]=16384;c[2443331]=16384;c[2443332]=0;c[2443333]=0;c[2439494]=942064;return};case 37:{c[2443330]=32768;c[2443331]=0;c[2443332]=0;c[2443333]=0;c[2439494]=793552;return};case 8:{c[2443330]=32768;c[2443331]=32768;c[2443332]=0;c[2443333]=0;c[2439494]=939584;return};case 5:{c[2443330]=32768;c[2443331]=32768;c[2443332]=0;c[2443333]=0;c[2439494]=793616;return};case 30:{c[2443330]=32768;c[2443331]=32768;c[2443332]=0;c[2443333]=0;c[2439494]=941760;return};case 1:{c[2443330]=32768;c[2443331]=32768;c[2443332]=0;c[2443333]=0;c[2439494]=941216;return};case 4:{c[2443330]=16384;c[2443331]=16384;c[2443332]=8192;c[2443333]=8192;c[2439494]=941584;return};case 26:{c[2443330]=32768;c[2443331]=0;c[2443332]=0;c[2443333]=0;c[2439494]=939664;return};case 9:{c[2443330]=32768;c[2443331]=0;c[2443332]=0;c[2443333]=0;c[2439494]=940080;return};case 41:{c[2443330]=131072;c[2443331]=0;c[2443332]=0;c[2443333]=0;c[2439494]=1086624;return};case 33:{c[2443330]=16384;c[2443331]=0;c[2443332]=0;c[2443333]=0;c[2439494]=940480;return};case 17:{c[2443330]=32768;c[2443331]=0;c[2443332]=0;c[2443333]=0;c[2439494]=941952;return};case 22:{c[2443330]=32768;c[2443331]=32768;c[2443332]=0;c[2443333]=0;c[2439494]=941424;return};case 24:{c[2443330]=32768;c[2443331]=32768;c[2443332]=0;c[2443333]=0;c[2439494]=941312;return};case 32:{c[2443330]=32768;c[2443331]=32768;c[2443332]=32768;c[2443333]=0;c[2439494]=941024;return};case 11:{c[2443330]=32768;c[2443331]=0;c[2443332]=0;c[2443333]=0;c[2439494]=942192;return};case 15:{c[2443330]=32768;c[2443331]=0;c[2443332]=0;c[2443333]=0;c[2439494]=941680;return};case 25:{c[2443330]=32768;c[2443331]=32768;c[2443332]=32768;c[2443333]=0;c[2439494]=793360;return};case 16:{c[2443330]=32768;c[2443331]=0;c[2443332]=0;c[2443333]=0;c[2439494]=940832;return};case 31:{c[2443330]=32768;c[2443331]=32768;c[2443332]=0;c[2443333]=0;c[2439494]=940624;return};case 12:{c[2443330]=16384;c[2443331]=16384;c[2443332]=0;c[2443333]=0;c[2439494]=942272;return};case 29:{c[2443330]=32768;c[2443331]=32768;c[2443332]=0;c[2443333]=0;c[2439494]=793216;return};case 3:{c[2443330]=32768;c[2443331]=32768;c[2443332]=0;c[2443333]=0;c[2439494]=793264;return};case 10:{c[2443330]=32768;c[2443331]=0;c[2443332]=0;c[2443333]=0;c[2439494]=939504;return};case 38:{c[2443330]=32768;c[2443331]=32768;c[2443332]=0;c[2443333]=0;c[2439494]=939424;return};case 20:{c[2443330]=32768;c[2443331]=32768;c[2443332]=0;c[2443333]=0;c[2439494]=940160;return};case 36:{c[2443330]=32768;c[2443331]=32768;c[2443332]=32768;c[2443333]=32768;c[2439494]=793472;return};case 7:{c[2443330]=16384;c[2443331]=16384;c[2443332]=16384;c[2443333]=16384;c[2439494]=939744;return};case 39:{c[2443330]=131072;c[2443331]=0;c[2443332]=0;c[2443333]=0;c[2439494]=939392;return};case 23:{c[2443330]=32768;c[2443331]=32768;c[2443332]=0;c[2443333]=0;c[2439494]=941840;return};case 40:{c[2443330]=131072;c[2443331]=131072;c[2443332]=0;c[2443333]=0;c[2439494]=1086656;return};case 21:{c[2443330]=16384;c[2443331]=16384;c[2443332]=16384;c[2443333]=16384;c[2439494]=940272;return};case 27:{c[2443330]=16384;c[2443331]=16384;c[2443332]=0;c[2443333]=0;c[2439494]=939696;return};case 2:{c[2443330]=32768;c[2443331]=8192;c[2443332]=8192;c[2443333]=0;c[2439494]=941520;return};case 0:{c[2443330]=32768;c[2443331]=32768;c[2443332]=0;c[2443333]=0;c[2439494]=941120;return};case 14:{c[2443330]=32768;c[2443331]=0;c[2443332]=0;c[2443333]=0;c[2439494]=940944;return};case 34:{c[2443330]=32768;c[2443331]=0;c[2443332]=0;c[2443333]=0;c[2439494]=940416;return};case 28:{c[2443330]=32768;c[2443331]=0;c[2443332]=0;c[2443333]=0;c[2439494]=940560;return};case 35:{c[2443330]=32768;c[2443331]=32768;c[2443332]=0;c[2443333]=0;c[2439494]=793136;return};case 19:{c[2443330]=32768;c[2443331]=32768;c[2443332]=32768;c[2443333]=0;c[2439494]=939840;return};default:{return}}}function VO(a,b){a=a|0;b=b|0;switch(a|0){case 3:{c[3542042]=96;c[3542040]=0;c[3542038]=4;gGz(14167824|0,0|0,16|0);c[2113258]=110;c[3541186]=102;c[3541187]=112;c[3541188]=104;c[3541189]=114;c[2113254]=106;c[3541969]=2;c[3541970]=4;c[3541971]=8;if((b|0)==0){return}c[3541972]=0;c[3541973]=0;return};case 8:{c[3542042]=94;c[3542040]=4;c[3542038]=4;gGz(14167824|0,0|0,16|0);c[2113258]=82;c[3541186]=84;c[3541187]=86;c[3541188]=88;c[3541189]=90;c[2113254]=92;c[3541969]=8;c[3541970]=32;c[3541971]=16;if((b|0)==0){return}c[3541972]=0;c[3541973]=0;return};case 30:{c[3542042]=0;c[3542040]=0;c[3542038]=0;gGz(14167824|0,0|0,16|0);c[2113258]=96;c[3541186]=102;c[3541187]=112;c[3541188]=104;c[3541189]=114;c[2113254]=106;c[3541969]=2;c[3541970]=4;c[3541971]=8;if((b|0)==0){return}c[3541972]=48;c[3541973]=48;return};case 27:{c[3542042]=0;c[3542040]=0;c[3542038]=0;gGz(14167824|0,0|0,16|0);c[2113258]=196;c[3541186]=82;c[3541187]=80;c[3541188]=78;c[3541189]=76;c[2113254]=74;c[3541969]=2;c[3541970]=2;c[3541971]=8;if((b|0)==0){return}c[3541972]=0;c[3541973]=0;return};case 25:{c[3542042]=94;c[3542040]=12;c[3542038]=2;gGz(14167824|0,0|0,16|0);c[2113258]=106;c[3541186]=108;c[3541187]=110;c[3541188]=112;c[3541189]=114;c[2113254]=92;c[3541969]=4;c[3541970]=8;c[3541971]=16;if((b|0)==0){return}c[3541972]=0;c[3541973]=0;return};case 1:{c[3542042]=96;c[3542040]=0;c[3542038]=2;gGz(14167824|0,0|0,16|0);c[2113258]=108;c[3541186]=106;c[3541187]=104;c[3541188]=102;c[3541189]=100;c[2113254]=98;c[3541969]=2;c[3541970]=4;c[3541971]=8;if((b|0)==0){return}c[3541972]=0;c[3541973]=0;return};case 0:{c[3542042]=0;c[3542040]=0;c[3542038]=0;gGz(14167824|0,0|0,16|0);c[2113258]=102;c[3541186]=104;c[3541187]=106;c[3541188]=108;c[3541189]=110;c[2113254]=112;c[3541969]=2;c[3541970]=4;c[3541971]=8;if((b|0)==0){return}c[3541972]=48;c[3541973]=48;return};case 21:{c[3542042]=0;c[3542040]=0;c[3542038]=0;gGz(14167824|0,0|0,16|0);c[2113258]=98;c[3541186]=100;c[3541187]=102;c[3541188]=104;c[3541189]=106;c[2113254]=108;c[3541969]=16;c[3541970]=8;c[3541971]=4;if((b|0)==0){return}c[3541972]=0;c[3541973]=0;return};case 22:{c[3542042]=0;c[3542040]=0;c[3542038]=0;gGz(14167824|0,0|0,16|0);c[2113258]=74;c[3541186]=76;c[3541187]=78;c[3541188]=64;c[3541189]=66;c[2113254]=68;c[3541969]=22;c[3541970]=22;c[3541971]=22;if((b|0)==0){return}c[3541972]=0;c[3541973]=0;return};case 4:{c[3542042]=96;c[3542040]=0;c[3542038]=5;gGz(14167824|0,0|0,16|0);c[2113258]=104;c[3541186]=106;c[3541187]=108;c[3541188]=110;c[3541189]=112;c[2113254]=114;c[3541969]=2;c[3541970]=8;c[3541971]=32;if((b|0)==0){return}c[3541972]=20;c[3541973]=20;return};case 11:{c[3542042]=72;c[3542040]=4;c[3542038]=7;gGz(14167824|0,0|0,16|0);c[2113258]=84;c[3541186]=82;c[3541187]=80;c[3541188]=78;c[3541189]=76;c[2113254]=74;c[3541969]=8;c[3541970]=16;c[3541971]=2;if((b|0)==0){return}c[3541972]=0;c[3541973]=0;return};case 6:{c[3542042]=96;c[3542040]=4;c[3542038]=2;gGz(14167824|0,0|0,16|0);c[2113258]=108;c[3541186]=106;c[3541187]=104;c[3541188]=102;c[3541189]=100;c[2113254]=98;c[3541969]=2;c[3541970]=4;c[3541971]=8;if((b|0)==0){return}c[3541972]=0;c[3541973]=0;return};case 9:{c[3542042]=78;c[3542040]=4;c[3542038]=5;gGz(14167824|0,0|0,16|0);c[2113258]=66;c[3541186]=68;c[3541187]=70;c[3541188]=72;c[3541189]=74;c[2113254]=76;c[3541969]=4;c[3541970]=2;c[3541971]=32;if((b|0)==0){return}c[3541972]=0;c[3541973]=0;return};case 7:{c[3542042]=110;c[3542040]=4;c[3542038]=3;gGz(14167824|0,0|0,16|0);c[2113258]=98;c[3541186]=100;c[3541187]=102;c[3541188]=104;c[3541189]=106;c[2113254]=108;c[3541969]=32;c[3541970]=2;c[3541971]=4;if((b|0)==0){return}c[3541972]=0;c[3541973]=0;return};case 24:{c[3542042]=110;c[3542040]=12;c[3542038]=1;gGz(14167824|0,0|0,16|0);c[2113258]=86;c[3541186]=64;c[3541187]=66;c[3541188]=104;c[3541189]=106;c[2113254]=108;c[3541969]=4;c[3541970]=8;c[3541971]=16;if((b|0)==0){return}c[3541972]=0;c[3541973]=0;return};case 13:{c[3542042]=50;c[3542040]=0;c[3542038]=0;c[3541956]=64;c[3541957]=66;c[3541958]=68;c[3541959]=70;c[2113258]=102;c[3541186]=104;c[3541187]=106;c[3541188]=108;c[3541189]=110;c[2113254]=112;c[3541969]=2;c[3541970]=4;c[3541971]=8;if((b|0)==0){return}c[3541972]=48;c[3541973]=48;return};case 2:{c[3542042]=0;c[3542040]=0;c[3542038]=0;gGz(14167824|0,0|0,16|0);c[2113258]=112;c[3541186]=110;c[3541187]=108;c[3541188]=106;c[3541189]=104;c[2113254]=102;c[3541969]=32;c[3541970]=16;c[3541971]=8;if((b|0)==0){return}c[3541972]=0;c[3541973]=0;return};case 18:{c[3542042]=50;c[3542040]=0;c[3542038]=0;c[3541956]=78;c[3541957]=76;c[3541958]=74;c[3541959]=72;c[2113258]=96;c[3541186]=110;c[3541187]=108;c[3541188]=106;c[3541189]=104;c[2113254]=112;c[3541969]=32;c[3541970]=4;c[3541971]=2;if((b|0)==0){return}c[3541972]=0;c[3541973]=0;return};case 19:{c[3542042]=0;c[3542040]=0;c[3542038]=0;gGz(14167824|0,0|0,16|0);c[2113258]=96;c[3541186]=110;c[3541187]=108;c[3541188]=106;c[3541189]=104;c[2113254]=112;c[3541969]=32;c[3541970]=20;c[3541971]=20;if((b|0)==0){return}c[3541972]=0;c[3541973]=0;return};case 28:{c[3542042]=0;c[3542040]=0;c[3542038]=0;gGz(14167824|0,0|0,16|0);c[2113258]=96;c[3541186]=104;c[3541187]=106;c[3541188]=108;c[3541189]=110;c[2113254]=106;c[3541969]=2;c[3541970]=4;c[3541971]=8;if((b|0)==0){return}c[3541972]=48;c[3541973]=48;return};case 20:{c[3542042]=0;c[3542040]=0;c[3542038]=0;gGz(14167824|0,0|0,16|0);c[2113258]=108;gGz(14164744|0,0|0,16|0);c[2113254]=82;c[3541969]=20;c[3541970]=2;c[3541971]=20;if((b|0)==0){return}c[3541972]=0;c[3541973]=0;return};case 12:{c[3542042]=208;c[3542040]=4;c[3542038]=8;gGz(14167824|0,0|0,16|0);c[2113258]=220;c[3541186]=218;c[3541187]=216;c[3541188]=214;c[3541189]=212;c[2113254]=210;c[3541969]=16;c[3541970]=8;c[3541971]=2;if((b|0)==0){return}c[3541972]=0;c[3541973]=0;return};case 16:{c[3542042]=0;c[3542040]=0;c[3542038]=0;c[3541956]=70;c[3541957]=68;c[3541958]=66;c[3541959]=64;c[2113258]=96;c[3541186]=110;c[3541187]=108;c[3541188]=106;c[3541189]=104;c[2113254]=112;c[3541969]=32;c[3541970]=18;c[3541971]=18;if((b|0)==0){return}c[3541972]=0;c[3541973]=0;return};case 10:{c[3542042]=64;c[3542040]=4;c[3542038]=6;gGz(14167824|0,0|0,16|0);c[2113258]=76;c[3541186]=74;c[3541187]=72;c[3541188]=70;c[3541189]=68;c[2113254]=66;c[3541969]=16;c[3541970]=10;c[3541971]=10;if((b|0)==0){return}c[3541972]=0;c[3541973]=0;return};case 31:{c[3542042]=0;c[3542040]=0;c[3542038]=0;gGz(14167824|0,0|0,16|0);c[2113258]=96;c[3541186]=102;c[3541187]=104;c[3541188]=108;c[3541189]=110;c[2113254]=106;c[3541969]=2;c[3541970]=4;c[3541971]=8;if((b|0)==0){return}c[3541972]=48;c[3541973]=48;return};case 5:{c[3542042]=114;c[3542040]=4;c[3542038]=1;gGz(14167824|0,0|0,16|0);c[2113258]=102;c[3541186]=104;c[3541187]=106;c[3541188]=108;c[3541189]=110;c[2113254]=112;c[3541969]=8;c[3541970]=16;c[3541971]=32;if((b|0)==0){return}c[3541972]=0;c[3541973]=0;return};case 14:{c[3542042]=114;c[3542040]=8;c[3542038]=0;c[3541956]=78;c[3541957]=76;c[3541958]=74;c[3541959]=72;c[2113258]=104;c[3541186]=102;c[3541187]=100;c[3541188]=98;c[3541189]=96;c[2113254]=112;c[3541969]=32;c[3541970]=4;c[3541971]=8;if((b|0)==0){return}c[3541972]=18;c[3541973]=18;return};case 15:{c[3542042]=0;c[3542040]=0;c[3542038]=0;c[3541956]=94;c[3541957]=92;c[3541958]=90;c[3541959]=88;c[2113258]=96;c[3541186]=110;c[3541187]=108;c[3541188]=106;c[3541189]=104;c[2113254]=112;c[3541969]=48;c[3541970]=8;c[3541971]=48;if((b|0)==0){return}c[3541972]=0;c[3541973]=0;return};case 23:{c[3542042]=78;c[3542040]=12;c[3542038]=0;gGz(14167824|0,0|0,16|0);c[2113258]=82;c[3541186]=84;c[3541187]=86;c[3541188]=72;c[3541189]=74;c[2113254]=76;c[3541969]=4;c[3541970]=2;c[3541971]=32;if((b|0)==0){return}c[3541972]=0;c[3541973]=0;return};case 26:{c[3542042]=0;c[3542040]=0;c[3542038]=0;gGz(14167824|0,0|0,16|0);c[2113258]=84;c[3541186]=82;c[3541187]=80;c[3541188]=78;c[3541189]=76;c[2113254]=74;c[3541969]=255;c[3541970]=255;c[3541971]=255;if((b|0)==0){return}c[3541972]=0;c[3541973]=0;return};case 17:{c[3542042]=0;c[3542040]=0;c[3542038]=0;c[3541956]=70;c[3541957]=68;c[3541958]=66;c[3541959]=64;c[2113258]=104;c[3541186]=102;c[3541187]=100;c[3541188]=98;c[3541189]=96;c[2113254]=112;c[3541969]=32;c[3541970]=16;c[3541971]=2;if((b|0)==0){return}c[3541972]=0;c[3541973]=0;return};case 29:{c[3542042]=0;c[3542040]=0;c[3542038]=0;gGz(14167824|0,0|0,16|0);c[2113258]=112;c[3541186]=110;c[3541187]=108;c[3541188]=106;c[3541189]=104;c[2113254]=102;c[3541969]=2;c[3541970]=4;c[3541971]=8;if((b|0)==0){return}c[3541972]=0;c[3541973]=0;return};default:{return}}}function VP(b,d){b=b|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=c[3542068]|0;L61909:do{if((f&1|0)!=0&(a[7462128]^1)){g=(b|0)==385;L61911:do{if(a[7462160]|0){do{if(g){h=c[3541938]|0;if((h|0)==0){i=f;j=47896;break L61909}else{k=h;j=47891}}else{if(!(a[7461712]|0)){break}h=c[3541938]|0;if((b-6|0)>>>0<2&(h|0)!=0){k=h;j=47891}}}while(0);if((j|0)==47891){gf[k&2047](d&255)}if((b|0)==65){j=47894;break}else if((b|0)==73){j=47895;break}i=c[3542068]|0;j=47896;break L61909}else{do{if(!g){if(a[7461712]|0){if((b-6|0)>>>0<2){break}}if((b|0)==65){j=47894;break L61911}else if((b|0)==73){j=47895;break L61911}else if((b|0)!=393){i=f;j=47896;break L61909}h=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;l=c[2113248]|0;m=gGU(h,(h|0)<0|0?-1:0,l,(l|0)<0|0?-1:0)|0;l=c[2113270]|0;h=gGS(m,K,l,(l|0)<0|0?-1:0)|0;Wv(h);a[14130584]=d;return}}while(0);h=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;l=c[2113248]|0;m=gGU(h,(h|0)<0|0?-1:0,l,(l|0)<0|0?-1:0)|0;l=c[2113270]|0;h=gGS(m,K,l,(l|0)<0|0?-1:0)|0;Wv(h);a[14130592]=d;return}}while(0);if((j|0)==47894){c[2394774]=0;break}else if((j|0)==47895){c[2394772]=0;break}}else{i=f;j=47896}}while(0);do{if((j|0)==47896){if((i|0)==1&a[7462136]&(b|0)==385){a[(c[3541878]|0)+1|0]=d}if((b-256|0)>>>0>=256){break}if(a[7461720]&(b|0)==379){f=d&255;c[2415256]=f&1;k=f>>>7;c[3528406]=k^1;if((k|0)!=1){c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2]}Tr(f>>>6&1);return}f=c[3541926]|0;a[f+(b&255^1)|0]=d;if((b|0)!=267){return}k=(e[f+10>>1]|0)<<8&16776192;do{if(k>>>0>9437183&(k+6144|0)>>>0<9633793){f=(c[3541932]|0)+(k-9437184)|0;if((f|0)==0){break}g=c[3541898]|0;gGC(g|0,f|0,6144)|0}}while(0);W9(c[3541898]|0);return}}while(0);do{if((c[3542068]|0)==2){if((b|0)==64){i=d&255;c[2415256]=i&16;j=i>>>6&1;c[3528406]=j^1;if((j|0)==0){c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2]}Tr(i>>>5&1);return}if((b&511|0)==225){Wz(d&1);return}else{if(!((b|0)==65&a[7461704])){break}c[3528978]=d&2;break}}}while(0);if(!((a[7462128]|a[7462008])&(b|0)==49159)){return}b=d&255;c[2415256]=b&1;d=b>>>7;c[3528406]=d^1;if((d|0)!=1){c[2440216]=0;c[2406632]=0;c[2443744]=c[(c[2420380]|0)+32>>2]}Tr(b>>>6&1);return}function VQ(b){b=b|0;var d=0,e=0;d=b&16744448;do{if((d|0)==8388608){e=VR(b&511)|0}else{if((c[3542068]|0)==2){if(!((d|0)==6684672&(b|0)==6701057)){e=0;break}e=c[2406718]&255;break}if((b-15843328|0)>>>0<8){e=VR(b&49167)|0;break}if(!(a[7461936]&(b|0)==16515073)){e=0;break}e=~a[9628472]}}while(0);return e|0}function VR(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0;L61992:do{switch(d|0){case 30:{f=~a[14168280];break};case 18:{f=~a[14165056];break};case 28:{f=~a[14168288];break};case 26:{f=~a[14168296];break};case 1:{g=~a[14165104];if(!(a[7461704]|0)){f=g;break L61992}if((c[3528978]|0)==0){f=c[3541950]&255;break L61992}else{f=(g&255)-(c[3541948]|0)&255;break L61992}break};case 16:{f=~a[14165072];break};case 24:{f=~a[14165048];break};case 0:{g=~a[14165112];if(!(a[7461704]|0)){f=g;break L61992}if((c[3528978]|0)==0){f=c[3541946]&255;break L61992}else{f=(g&255)-(c[3541944]|0)&255;break L61992}break};case 25:{f=~a[14165040];break};case 27:{f=~a[14165032];break};case 17:{f=~a[14165064];break};default:{if((c[3542068]|0)==2){if((d|0)==33){g=a[14165016]&-2^-2;do{if((c[2406632]|0)==0){h=c[2443744]|0;if((h|0)<=0){i=1;break}c[2443744]=h-1;i=0}else{i=(c[2432962]|0)>>>((c[(c[2420380]|0)+4>>2]|0)>>>0)&1}}while(0);f=(i|g&255)&255;break L61992}else if((d|0)==32){f=~a[14165024];break L61992}else if((d|0)==48){if(a[7461632]|0){f=32;break L61992}return(a[7462112]|0?-48:(e[7462016+(c[1865524]<<1)>>1]|0)>>>8&255)|0}else if((d|0)==49){f=b[7462016+(c[1865524]<<1)>>1]&255;break L61992}else{if((d-256|0)>>>0>=256){f=-1;break L61992}h=d&254;if((h|0)==82){if((d&1|0)==0){j=(c[2113190]|0)-(((c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0)/(c[2113058]|0)|0)|0;c[2384406]=j;f=j>>>8&255;break L61992}else{f=c[2384406]&255;break L61992}}else if((h|0)==80){if((d&1|0)==0){h=(c[2113192]|0)-(((c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0)/(c[2113058]|0)|0)|0;c[2384406]=h;f=h>>>8&255;break L61992}else{f=c[2384406]&255;break L61992}}else{f=-1;break L61992}}}h=c[3542042]|0;if((h+256|0)==(d|0)){f=c[3542040]&255;break L61992}if((h+257|0)==(d|0)){f=c[3542038]&255;break L61992}do{if(a[7461672]|0){if((d|0)==457){f=c[3542038]&255;break L61992}else if((d|0)==456){f=c[3542040]&255;break L61992}else if((d|0)==49159){k=47987;break}else{break}}else{if((d|0)==49159){k=47987}}}while(0);if((k|0)==47987){if(!(a[7462008]|a[7462128])){f=0;break L61992}if((c[2406632]|0)!=0){f=(c[2432962]|0)>>>((c[(c[2420380]|0)+4>>2]|0)>>>0)&1;break L61992}g=c[2443744]|0;if((g|0)<=0){f=1;break L61992}c[2443744]=g-1;f=0;break L61992}if(a[7461720]&(d|0)==379){if((c[2406632]|0)!=0){f=(c[2432962]|0)>>>((c[(c[2420380]|0)+4>>2]|0)>>>0)&1;break L61992}g=c[2443744]|0;if((g|0)<=0){f=1;break L61992}c[2443744]=g-1;f=0;break L61992}if((d|0)==374){f=~a[14165e3];break L61992}else if((d|0)==7){f=~a[14165088];break L61992}else if((d|0)==8){f=~a[14165080];break L61992}else if((d|0)==49154){f=~a[9628464];break L61992}else if((d|0)==49155){f=~a[9628456];break L61992}else if((d|0)==390){f=~a[14164976];break L61992}else if((d|0)==509){f=~a[14164968];break L61992}else if((d|0)==49152){f=~a[9628480];break L61992}else if((d|0)==49153){f=~a[9628472];break L61992}else if((d|0)==6){f=~a[14165096];break L61992}else if((d|0)==375){f=~a[14164992];break L61992}else if((d|0)==377){f=~a[14164984];break L61992}else if((d|0)==41){f=~a[14165008];break L61992}else{if(!(a[7461928]|0)){f=-1;break L61992}if((d|0)==93){f=(c[2394772]|0)>>>16&255;break L61992}else if((d|0)==83){f=(c[2394774]|0)>>>8&255;break L61992}else if((d|0)==85){f=(c[2394774]|0)>>>16&255;break L61992}else if((d|0)==91){f=(c[2394772]|0)>>>8&255;break L61992}else{f=-1;break L61992}}}}}while(0);return f|0}function VS(b,d){b=b|0;d=d|0;var e=0;e=b&16744448;if((e|0)==8388608){VP(b&511,d);return}if((c[3542068]|0)!=2){if(!((a[7462128]|a[7462008])&(b|0)==15843335)){return}VP(49159,d);return}if((b&16777200|0)==4194304){a[(c[3542030]|0)+(b&15)|0]=d;return}if(!((e|0)==6684672&(b|0)==6701057)){return}c[2406718]=d&255;return}function VT(a){a=a|0;var b=0,d=0;b=a&16748543;if((b|0)==((c[3541959]|0)+8388864|0)){d=(ag(c[2415180]|0,c[2415182]|0)|0)>>>16&65535;return d|0}if((b|0)==((c[3541958]|0)+8388864|0)){d=(ag(c[2415180]|0,c[2415182]|0)|0)&65535;return d|0}else{b=((gj[c[(c[2112932]|0)+196608>>2]&4095](a)|0)&255)<<8;d=(gj[c[(c[2112932]|0)+196608>>2]&4095](a+1|0)|0)&255|b;return d|0}return 0}function VU(b,d){b=b|0;d=d|0;var e=0;e=b&16748543;if((e|0)==((c[3541956]|0)+8388864|0)){c[2415182]=d&65535}if((e|0)==((c[3541957]|0)+8388864|0)){c[2415180]=d&65535}do{if((b|0)==8405056){if((d&8)!=0|a[7462104]){break}gGz(9706056,0,76)}}while(0);gg[c[(c[2112932]|0)+196648>>2]&4095](b,(d&65535)>>>8&255);gg[c[(c[2112932]|0)+196648>>2]&4095](b+1|0,d&255);return}function VV(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;a[14165112]=a[14168105]<<1&2|a[14168104]&1|a[14168106]<<2&4|a[14168107]<<3&8|a[14168108]<<4&16|a[14168109]<<5&32|a[14168110]<<6&64|a[14168111]<<7;a[14165104]=a[14168097]<<1&2|a[14168096]&1|a[14168098]<<2&4|a[14168099]<<3&8|a[14168100]<<4&16|a[14168101]<<5&32|a[14168102]<<6&64|a[14168103]<<7;a[14165096]=a[14168089]<<1&2|a[14168088]&1|a[14168090]<<2&4|a[14168091]<<3&8|a[14168092]<<4&16|a[14168093]<<5&32|a[14168094]<<6&64|a[14168095]<<7;a[14165088]=a[14168081]<<1&2|a[14168080]&1|a[14168082]<<2&4|a[14168083]<<3&8|a[14168084]<<4&16|a[14168085]<<5&32|a[14168086]<<6&64|a[14168087]<<7;a[14165080]=a[14168073]<<1&2|a[14168072]&1|a[14168074]<<2&4|a[14168075]<<3&8|a[14168076]<<4&16|a[14168077]<<5&32|a[14168078]<<6&64|a[14168079]<<7;a[14165072]=a[14168065]<<1&2|a[14168064]&1|a[14168066]<<2&4|a[14168067]<<3&8|a[14168068]<<4&16|a[14168069]<<5&32|a[14168070]<<6&64|a[14168071]<<7;d=a[14168057]<<1&2|a[14168056]&1;e=d|a[14168058]<<2&4|a[14168059]<<3&8|a[14168060]<<4&16|a[14168061]<<5&32|a[14168062]<<6&64|a[14168063]<<7;a[14165064]=e;a[14165056]=a[14168049]<<1&2|a[14168048]&1|a[14168050]<<2&4|a[14168051]<<3&8|a[14168052]<<4&16|a[14168053]<<5&32|a[14168054]<<6&64|a[14168055]<<7;a[14165048]=a[14168041]<<1&2|a[14168040]&1|a[14168042]<<2&4|a[14168043]<<3&8|a[14168044]<<4&16|a[14168045]<<5&32|a[14168046]<<6&64|a[14168047]<<7;a[14165040]=a[14168033]<<1&2|a[14168032]&1|a[14168034]<<2&4|a[14168035]<<3&8|a[14168036]<<4&16|a[14168037]<<5&32|a[14168038]<<6&64|a[14168039]<<7;a[14165032]=a[14168025]<<1&2|a[14168024]&1|a[14168026]<<2&4|a[14168027]<<3&8|a[14168028]<<4&16|a[14168029]<<5&32|a[14168030]<<6&64|a[14168031]<<7;a[14165024]=a[14168017]<<1&2|a[14168016]&1|a[14168018]<<2&4|a[14168019]<<3&8|a[14168020]<<4&16|a[14168021]<<5&32|a[14168022]<<6&64|a[14168023]<<7;a[14165016]=a[14168009]<<1&2|a[14168008]&1|a[14168010]<<2&4|a[14168011]<<3&8|a[14168012]<<4&16|a[14168013]<<5&32|a[14168014]<<6&64|a[14168015]<<7;a[14165008]=a[14168001]<<1&2|a[14168e3]&1|a[14168002]<<2&4|a[14168003]<<3&8|a[14168004]<<4&16|a[14168005]<<5&32|a[14168006]<<6&64|a[14168007]<<7;a[14165e3]=a[14167977]<<1&2|a[14167976]&1|a[14167978]<<2&4|a[14167979]<<3&8|a[14167980]<<4&16|a[14167981]<<5&32|a[14167982]<<6&64|a[14167983]<<7;f=a[14167969]<<1&2|a[14167968]&1;g=a[14167970]<<2&4|f|a[14167971]<<3&8|a[14167972]<<4&16|a[14167973]<<5&32|a[14167974]<<6&64|a[14167975]<<7;a[14164992]=g;h=a[14167961]<<1&2|a[14167960]&1;i=a[14167962]<<2&4|h|a[14167963]<<3&8|a[14167964]<<4&16|a[14167965]<<5&32|a[14167966]<<6&64|a[14167967]<<7;a[14164984]=i;a[14164976]=a[14167953]<<1&2|a[14167952]&1|a[14167954]<<2&4|a[14167955]<<3&8|a[14167956]<<4&16|a[14167957]<<5&32|a[14167958]<<6&64|a[14167959]<<7;a[14164968]=a[14167945]<<1&2|a[14167944]&1|a[14167946]<<2&4|a[14167947]<<3&8|a[14167948]<<4&16|a[14167949]<<5&32|a[14167950]<<6&64|a[14167951]<<7;a[9628480]=a[14167921]<<1&2|a[14167920]&1|a[14167922]<<2&4|a[14167923]<<3&8|a[14167924]<<4&16|a[14167925]<<5&32|a[14167926]<<6&64|a[14167927]<<7;j=a[14167913]<<1&2|a[14167912]&1;k=a[14167914]<<2&4|j|a[14167915]<<3&8|a[14167916]<<4&16|a[14167917]<<5&32|a[14167918]<<6&64|a[14167919]<<7;a[9628472]=k;a[9628464]=a[14167905]<<1&2|a[14167904]&1|a[14167906]<<2&4|a[14167907]<<3&8|a[14167908]<<4&16|a[14167909]<<5&32|a[14167910]<<6&64|a[14167911]<<7;l=a[14167897]<<1&2|a[14167896]&1;m=a[14167898]<<2&4|l|a[14167899]<<3&8|a[14167900]<<4&16|a[14167901]<<5&32|a[14167902]<<6&64|a[14167903]<<7;a[9628456]=m;if(a[7461928]|0){c[2394774]=(c[2394774]|0)+(b[7083996]|0);c[2394772]=(c[2394772]|0)+(b[7083992]|0)}if(a[7461704]|0){do{if((c[3528978]|0)==0){n=b[7083968]|0;o=b[7083964]|0}else{c[3541948]=0;c[3541944]=0;p=b[7083968]|0;do{if(p<<16>>16!=0){if((p&65535)>32768){c[3541948]=2}if((p&65535)>=32767){break}c[3541948]=1}}while(0);q=b[7083964]|0;if(q<<16>>16==0){n=p;o=0;break}if((q&65535)>32768){c[3541944]=2}if((q&65535)>=32767){n=p;o=q;break}c[3541944]=1;n=p;o=q}}while(0);c[3541950]=((n&65535)>>>8)+(c[3541950]|0);c[3541946]=(c[3541946]|0)+((o&65535)>>>8)}o=a[14165112]|0;if((o&3)==3){n=o&-4;a[14165112]=n;r=n}else{r=o}if((r&12)==12){o=r&-13;a[14165112]=o;s=o}else{s=r}r=a[14165104]|0;if((r&3)==3){o=r&-4;a[14165104]=o;t=o}else{t=r}if((t&12)==12){r=t&-13;a[14165104]=r;u=r}else{u=t}do{if(a[7461848]|0){t=s&255;if((t&3|0)==0|(t&12|0)==0){a[9539352]=s}else{a[14165112]=a[9539352]&15^s}t=u&255;if((t&3|0)==0|(t&12|0)==0){a[9539344]=u;break}else{a[14165104]=a[9539344]&15^u;break}}}while(0);u=c[2113150]|0;if((u|0)<=2){return}if((c[3542068]|0)==2){if(d<<24>>24==3){d=e&-4;a[14165064]=d;v=d}else{v=e}if((v&12)==12){a[14165064]=v&-13}if((u|0)!=4){return}v=a[14165072]|0;if((v&3)==3){e=v&-4;a[14165072]=e;w=e}else{w=v}if((w&12)!=12){return}a[14165072]=w&-13;return}if(f<<24>>24==3){f=g&-4;a[14164992]=f;x=f}else{x=g}if((x&12)==12){a[14164992]=x&-13}x=(u|0)==4;do{if(x){if(h<<24>>24==3){u=i&-4;a[14164984]=u;y=u}else{y=i}if((y&12)!=12){break}a[14164984]=y&-13}}while(0);if(!(a[7462128]|0)){return}if(j<<24>>24==3){j=k&-4;a[9628472]=j;z=j}else{z=k}if((z&12)==12){a[9628472]=z&-13}if(!x){return}if(l<<24>>24==3){l=m&-4;a[9628456]=l;A=l}else{A=m}if((A&12)!=12){return}a[9628456]=A&-13;return}function VW(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;e=i;i=i+928|0;f=e|0;g=e+112|0;h=e+120|0;j=e+232|0;k=e+240|0;l=e+352|0;m=e+360|0;n=e+472|0;o=e+480|0;p=e+592|0;q=e+704|0;r=e+816|0;s=r+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,b)|0;r=c[s>>2]|0;L62228:do{if((r|0)!=0){t=0;while(1){if((t|0)>=1024){break L62228}u=9638528+(t<<2)|0;if((c[u>>2]|0)==0){break}else{t=t+1|0}}t=gGq(r)|0;c[u>>2]=t;if((t|0)==0){break}gGz(t|0,0,r|0);do{if((c[3542200]|0)==0){v=0}else{w=m+108|0;c[w>>2]=0;x=m+100|0;c[x>>2]=0;y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[y&16383](m,b)|0;if((c[w>>2]|0)!=0){w=c[x>>2]|0;c[n>>2]=9534384;x=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[x&16383](n,b,0)|0;if((w|0)<1){v=0;break}if((gzL(t,0,b)|0)!=0){v=0;break}}w=c[s>>2]&-2;if((w|0)>0){x=a;y=t;z=0;while(1){A=z+2|0;B=x;c[B>>2]=c[9620648+((d[y+1|0]|0)<<2)>>2]<<1|c[9620648+((d[y]|0)<<2)>>2]|c[B>>2];if((A|0)<(w|0)){x=x+8|0;y=y+2|0;z=A}else{C=0;break}}}else{C=0}while(1){if((C|0)>=1024){break L62228}D=9638528+(C<<2)|0;if((c[D>>2]|0)==(t|0)){break}else{C=C+1|0}}gGr(t);c[D>>2]=0;break L62228}}while(0);while(1){if((v|0)>=1024){break L62228}E=9638528+(v<<2)|0;if((c[E>>2]|0)==(t|0)){break}else{v=v+1|0}}gGr(t);c[E>>2]=0}}while(0);E=b+1|0;v=q+100|0;c[v>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](q,E)|0;q=c[v>>2]|0;L62252:do{if((q|0)!=0){D=0;while(1){if((D|0)>=1024){break L62252}F=9638528+(D<<2)|0;if((c[F>>2]|0)==0){break}else{D=D+1|0}}D=gGq(q)|0;c[F>>2]=D;if((D|0)==0){break}gGz(D|0,0,q|0);do{if((c[3542200]|0)==0){G=0}else{t=k+108|0;c[t>>2]=0;C=k+100|0;c[C>>2]=0;s=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[s&16383](k,E)|0;if((c[t>>2]|0)!=0){t=c[C>>2]|0;c[l>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](l,E,0)|0;if((t|0)<1){G=0;break}if((gzL(D,0,E)|0)!=0){G=0;break}}t=c[v>>2]&-2;if((t|0)>0){C=a;s=D;n=0;while(1){m=n+2|0;r=C;c[r>>2]=(c[9620648+((d[s+1|0]|0)<<2)>>2]<<1|c[9620648+((d[s]|0)<<2)>>2])<<2|c[r>>2];if((m|0)<(t|0)){C=C+8|0;s=s+2|0;n=m}else{H=0;break}}}else{H=0}while(1){if((H|0)>=1024){break L62252}I=9638528+(H<<2)|0;if((c[I>>2]|0)==(D|0)){break}else{H=H+1|0}}gGr(D);c[I>>2]=0;break L62252}}while(0);while(1){if((G|0)>=1024){break L62252}J=9638528+(G<<2)|0;if((c[J>>2]|0)==(D|0)){break}else{G=G+1|0}}gGr(D);c[J>>2]=0}}while(0);J=a+4|0;a=b+2|0;G=p+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,a)|0;p=c[G>>2]|0;L62276:do{if((p|0)!=0){I=0;while(1){if((I|0)>=1024){break L62276}K=9638528+(I<<2)|0;if((c[K>>2]|0)==0){break}else{I=I+1|0}}I=gGq(p)|0;c[K>>2]=I;if((I|0)==0){break}gGz(I|0,0,p|0);do{if((c[3542200]|0)==0){L=0}else{D=h+108|0;c[D>>2]=0;H=h+100|0;c[H>>2]=0;v=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[v&16383](h,a)|0;if((c[D>>2]|0)!=0){D=c[H>>2]|0;c[j>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](j,a,0)|0;if((D|0)<1){L=0;break}if((gzL(I,0,a)|0)!=0){L=0;break}}D=c[G>>2]&-2;if((D|0)>0){H=J;v=I;E=0;while(1){l=E+2|0;k=H;c[k>>2]=c[9620648+((d[v+1|0]|0)<<2)>>2]<<1|c[9620648+((d[v]|0)<<2)>>2]|c[k>>2];if((l|0)<(D|0)){H=H+8|0;v=v+2|0;E=l}else{M=0;break}}}else{M=0}while(1){if((M|0)>=1024){break L62276}N=9638528+(M<<2)|0;if((c[N>>2]|0)==(I|0)){break}else{M=M+1|0}}gGr(I);c[N>>2]=0;break L62276}}while(0);while(1){if((L|0)>=1024){break L62276}O=9638528+(L<<2)|0;if((c[O>>2]|0)==(I|0)){break}else{L=L+1|0}}gGr(I);c[O>>2]=0}}while(0);O=b+3|0;b=o+100|0;c[b>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](o,O)|0;o=c[b>>2]|0;if((o|0)==0){i=e;return}else{P=0}while(1){if((P|0)>=1024){Q=48188;break}R=9638528+(P<<2)|0;if((c[R>>2]|0)==0){break}else{P=P+1|0}}if((Q|0)==48188){i=e;return}P=gGq(o)|0;c[R>>2]=P;if((P|0)==0){i=e;return}gGz(P|0,0,o|0);do{if((c[3542200]|0)==0){S=0}else{o=f+108|0;c[o>>2]=0;R=f+100|0;c[R>>2]=0;L=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[L&16383](f,O)|0;if((c[o>>2]|0)!=0){o=c[R>>2]|0;c[g>>2]=9534384;R=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[R&16383](g,O,0)|0;if((o|0)<1){S=0;break}if((gzL(P,0,O)|0)!=0){S=0;break}}o=c[b>>2]&-2;if((o|0)>0){R=J;L=P;N=0;while(1){M=N+2|0;G=R;c[G>>2]=(c[9620648+((d[L+1|0]|0)<<2)>>2]<<1|c[9620648+((d[L]|0)<<2)>>2])<<2|c[G>>2];if((M|0)<(o|0)){R=R+8|0;L=L+2|0;N=M}else{T=0;break}}}else{T=0}while(1){if((T|0)>=1024){Q=48189;break}U=9638528+(T<<2)|0;if((c[U>>2]|0)==(P|0)){break}else{T=T+1|0}}if((Q|0)==48189){i=e;return}gGr(P);c[U>>2]=0;i=e;return}}while(0);while(1){if((S|0)>=1024){Q=48191;break}V=9638528+(S<<2)|0;if((c[V>>2]|0)==(P|0)){break}else{S=S+1|0}}if((Q|0)==48191){i=e;return}gGr(P);c[V>>2]=0;i=e;return}function VX(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0;e=i;i=i+1856|0;f=e|0;g=e+112|0;h=e+120|0;j=e+232|0;k=e+240|0;l=e+352|0;m=e+360|0;n=e+472|0;o=e+480|0;p=e+592|0;q=e+600|0;r=e+712|0;s=e+720|0;t=e+832|0;u=e+840|0;v=e+952|0;w=e+960|0;x=e+1072|0;y=e+1184|0;z=e+1296|0;A=e+1408|0;B=e+1520|0;C=e+1632|0;D=e+1744|0;E=D+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](D,b)|0;D=c[E>>2]|0;L62335:do{if((D|0)!=0){F=0;while(1){if((F|0)>=1024){break L62335}G=9638528+(F<<2)|0;if((c[G>>2]|0)==0){break}else{F=F+1|0}}F=gGq(D)|0;c[G>>2]=F;if((F|0)==0){break}gGz(F|0,0,D|0);do{if((c[3542200]|0)==0){H=0}else{I=u+108|0;c[I>>2]=0;J=u+100|0;c[J>>2]=0;K=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[K&16383](u,b)|0;if((c[I>>2]|0)!=0){I=c[J>>2]|0;c[v>>2]=9534384;J=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[J&16383](v,b,0)|0;if((I|0)<1){H=0;break}if((gzL(F,0,b)|0)!=0){H=0;break}}I=c[E>>2]&-2;if((I|0)>0){J=a;K=F;L=0;while(1){M=L+1|0;N=J;c[N>>2]=c[N>>2]|c[9620648+((d[K]|0)<<2)>>2];if((M|0)<(I|0)){J=J+8|0;K=K+1|0;L=M}else{O=0;break}}}else{O=0}while(1){if((O|0)>=1024){break L62335}P=9638528+(O<<2)|0;if((c[P>>2]|0)==(F|0)){break}else{O=O+1|0}}gGr(F);c[P>>2]=0;break L62335}}while(0);while(1){if((H|0)>=1024){break L62335}Q=9638528+(H<<2)|0;if((c[Q>>2]|0)==(F|0)){break}else{H=H+1|0}}gGr(F);c[Q>>2]=0}}while(0);Q=b+1|0;H=C+100|0;c[H>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](C,Q)|0;C=c[H>>2]|0;L62359:do{if((C|0)!=0){P=0;while(1){if((P|0)>=1024){break L62359}R=9638528+(P<<2)|0;if((c[R>>2]|0)==0){break}else{P=P+1|0}}P=gGq(C)|0;c[R>>2]=P;if((P|0)==0){break}gGz(P|0,0,C|0);do{if((c[3542200]|0)==0){S=0}else{F=s+108|0;c[F>>2]=0;O=s+100|0;c[O>>2]=0;E=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[E&16383](s,Q)|0;if((c[F>>2]|0)!=0){F=c[O>>2]|0;c[t>>2]=9534384;O=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[O&16383](t,Q,0)|0;if((F|0)<1){S=0;break}if((gzL(P,0,Q)|0)!=0){S=0;break}}F=c[H>>2]&-2;if((F|0)>0){O=a;E=P;v=0;while(1){u=v+1|0;D=O;c[D>>2]=c[D>>2]|c[9620648+((d[E]|0)<<2)>>2]<<1;if((u|0)<(F|0)){O=O+8|0;E=E+1|0;v=u}else{T=0;break}}}else{T=0}while(1){if((T|0)>=1024){break L62359}U=9638528+(T<<2)|0;if((c[U>>2]|0)==(P|0)){break}else{T=T+1|0}}gGr(P);c[U>>2]=0;break L62359}}while(0);while(1){if((S|0)>=1024){break L62359}V=9638528+(S<<2)|0;if((c[V>>2]|0)==(P|0)){break}else{S=S+1|0}}gGr(P);c[V>>2]=0}}while(0);V=b+2|0;S=B+100|0;c[S>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](B,V)|0;B=c[S>>2]|0;L62383:do{if((B|0)!=0){U=0;while(1){if((U|0)>=1024){break L62383}W=9638528+(U<<2)|0;if((c[W>>2]|0)==0){break}else{U=U+1|0}}U=gGq(B)|0;c[W>>2]=U;if((U|0)==0){break}gGz(U|0,0,B|0);do{if((c[3542200]|0)==0){X=0}else{P=q+108|0;c[P>>2]=0;T=q+100|0;c[T>>2]=0;H=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[H&16383](q,V)|0;if((c[P>>2]|0)!=0){P=c[T>>2]|0;c[r>>2]=9534384;T=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[T&16383](r,V,0)|0;if((P|0)<1){X=0;break}if((gzL(U,0,V)|0)!=0){X=0;break}}P=c[S>>2]&-2;if((P|0)>0){T=a;H=U;Q=0;while(1){t=Q+1|0;s=T;c[s>>2]=c[s>>2]|c[9620648+((d[H]|0)<<2)>>2]<<2;if((t|0)<(P|0)){T=T+8|0;H=H+1|0;Q=t}else{Y=0;break}}}else{Y=0}while(1){if((Y|0)>=1024){break L62383}Z=9638528+(Y<<2)|0;if((c[Z>>2]|0)==(U|0)){break}else{Y=Y+1|0}}gGr(U);c[Z>>2]=0;break L62383}}while(0);while(1){if((X|0)>=1024){break L62383}_=9638528+(X<<2)|0;if((c[_>>2]|0)==(U|0)){break}else{X=X+1|0}}gGr(U);c[_>>2]=0}}while(0);_=b+3|0;X=A+100|0;c[X>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](A,_)|0;A=c[X>>2]|0;L62407:do{if((A|0)!=0){Z=0;while(1){if((Z|0)>=1024){break L62407}$=9638528+(Z<<2)|0;if((c[$>>2]|0)==0){break}else{Z=Z+1|0}}Z=gGq(A)|0;c[$>>2]=Z;if((Z|0)==0){break}gGz(Z|0,0,A|0);do{if((c[3542200]|0)==0){aa=0}else{U=o+108|0;c[U>>2]=0;Y=o+100|0;c[Y>>2]=0;S=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[S&16383](o,_)|0;if((c[U>>2]|0)!=0){U=c[Y>>2]|0;c[p>>2]=9534384;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Y&16383](p,_,0)|0;if((U|0)<1){aa=0;break}if((gzL(Z,0,_)|0)!=0){aa=0;break}}U=c[X>>2]&-2;if((U|0)>0){Y=a;S=Z;V=0;while(1){r=V+1|0;q=Y;c[q>>2]=c[q>>2]|c[9620648+((d[S]|0)<<2)>>2]<<3;if((r|0)<(U|0)){Y=Y+8|0;S=S+1|0;V=r}else{ab=0;break}}}else{ab=0}while(1){if((ab|0)>=1024){break L62407}ac=9638528+(ab<<2)|0;if((c[ac>>2]|0)==(Z|0)){break}else{ab=ab+1|0}}gGr(Z);c[ac>>2]=0;break L62407}}while(0);while(1){if((aa|0)>=1024){break L62407}ad=9638528+(aa<<2)|0;if((c[ad>>2]|0)==(Z|0)){break}else{aa=aa+1|0}}gGr(Z);c[ad>>2]=0}}while(0);ad=a+4|0;a=b+4|0;aa=z+100|0;c[aa>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,a)|0;z=c[aa>>2]|0;L62431:do{if((z|0)!=0){ac=0;while(1){if((ac|0)>=1024){break L62431}ae=9638528+(ac<<2)|0;if((c[ae>>2]|0)==0){break}else{ac=ac+1|0}}ac=gGq(z)|0;c[ae>>2]=ac;if((ac|0)==0){break}gGz(ac|0,0,z|0);do{if((c[3542200]|0)==0){af=0}else{Z=m+108|0;c[Z>>2]=0;ab=m+100|0;c[ab>>2]=0;X=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[X&16383](m,a)|0;if((c[Z>>2]|0)!=0){Z=c[ab>>2]|0;c[n>>2]=9534384;ab=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ab&16383](n,a,0)|0;if((Z|0)<1){af=0;break}if((gzL(ac,0,a)|0)!=0){af=0;break}}Z=c[aa>>2]&-2;if((Z|0)>0){ab=ad;X=ac;_=0;while(1){p=_+1|0;o=ab;c[o>>2]=c[o>>2]|c[9620648+((d[X]|0)<<2)>>2];if((p|0)<(Z|0)){ab=ab+8|0;X=X+1|0;_=p}else{ag=0;break}}}else{ag=0}while(1){if((ag|0)>=1024){break L62431}ah=9638528+(ag<<2)|0;if((c[ah>>2]|0)==(ac|0)){break}else{ag=ag+1|0}}gGr(ac);c[ah>>2]=0;break L62431}}while(0);while(1){if((af|0)>=1024){break L62431}ai=9638528+(af<<2)|0;if((c[ai>>2]|0)==(ac|0)){break}else{af=af+1|0}}gGr(ac);c[ai>>2]=0}}while(0);ai=b+5|0;af=y+100|0;c[af>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](y,ai)|0;y=c[af>>2]|0;L62455:do{if((y|0)!=0){ah=0;while(1){if((ah|0)>=1024){break L62455}aj=9638528+(ah<<2)|0;if((c[aj>>2]|0)==0){break}else{ah=ah+1|0}}ah=gGq(y)|0;c[aj>>2]=ah;if((ah|0)==0){break}gGz(ah|0,0,y|0);do{if((c[3542200]|0)==0){ak=0}else{ac=k+108|0;c[ac>>2]=0;ag=k+100|0;c[ag>>2]=0;aa=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aa&16383](k,ai)|0;if((c[ac>>2]|0)!=0){ac=c[ag>>2]|0;c[l>>2]=9534384;ag=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ag&16383](l,ai,0)|0;if((ac|0)<1){ak=0;break}if((gzL(ah,0,ai)|0)!=0){ak=0;break}}ac=c[af>>2]&-2;if((ac|0)>0){ag=ad;aa=ah;a=0;while(1){n=a+1|0;m=ag;c[m>>2]=c[m>>2]|c[9620648+((d[aa]|0)<<2)>>2]<<1;if((n|0)<(ac|0)){ag=ag+8|0;aa=aa+1|0;a=n}else{al=0;break}}}else{al=0}while(1){if((al|0)>=1024){break L62455}am=9638528+(al<<2)|0;if((c[am>>2]|0)==(ah|0)){break}else{al=al+1|0}}gGr(ah);c[am>>2]=0;break L62455}}while(0);while(1){if((ak|0)>=1024){break L62455}an=9638528+(ak<<2)|0;if((c[an>>2]|0)==(ah|0)){break}else{ak=ak+1|0}}gGr(ah);c[an>>2]=0}}while(0);an=b+6|0;ak=x+100|0;c[ak>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,an)|0;x=c[ak>>2]|0;L62479:do{if((x|0)!=0){am=0;while(1){if((am|0)>=1024){break L62479}ao=9638528+(am<<2)|0;if((c[ao>>2]|0)==0){break}else{am=am+1|0}}am=gGq(x)|0;c[ao>>2]=am;if((am|0)==0){break}gGz(am|0,0,x|0);do{if((c[3542200]|0)==0){ap=0}else{ah=h+108|0;c[ah>>2]=0;al=h+100|0;c[al>>2]=0;af=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[af&16383](h,an)|0;if((c[ah>>2]|0)!=0){ah=c[al>>2]|0;c[j>>2]=9534384;al=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[al&16383](j,an,0)|0;if((ah|0)<1){ap=0;break}if((gzL(am,0,an)|0)!=0){ap=0;break}}ah=c[ak>>2]&-2;if((ah|0)>0){al=ad;af=am;ai=0;while(1){l=ai+1|0;k=al;c[k>>2]=c[k>>2]|c[9620648+((d[af]|0)<<2)>>2]<<2;if((l|0)<(ah|0)){al=al+8|0;af=af+1|0;ai=l}else{aq=0;break}}}else{aq=0}while(1){if((aq|0)>=1024){break L62479}ar=9638528+(aq<<2)|0;if((c[ar>>2]|0)==(am|0)){break}else{aq=aq+1|0}}gGr(am);c[ar>>2]=0;break L62479}}while(0);while(1){if((ap|0)>=1024){break L62479}as=9638528+(ap<<2)|0;if((c[as>>2]|0)==(am|0)){break}else{ap=ap+1|0}}gGr(am);c[as>>2]=0}}while(0);as=b+7|0;b=w+100|0;c[b>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](w,as)|0;w=c[b>>2]|0;if((w|0)==0){i=e;return}else{at=0}while(1){if((at|0)>=1024){au=48328;break}av=9638528+(at<<2)|0;if((c[av>>2]|0)==0){break}else{at=at+1|0}}if((au|0)==48328){i=e;return}at=gGq(w)|0;c[av>>2]=at;if((at|0)==0){i=e;return}gGz(at|0,0,w|0);do{if((c[3542200]|0)==0){aw=0}else{w=f+108|0;c[w>>2]=0;av=f+100|0;c[av>>2]=0;ap=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ap&16383](f,as)|0;if((c[w>>2]|0)!=0){w=c[av>>2]|0;c[g>>2]=9534384;av=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[av&16383](g,as,0)|0;if((w|0)<1){aw=0;break}if((gzL(at,0,as)|0)!=0){aw=0;break}}w=c[b>>2]&-2;if((w|0)>0){av=ad;ap=at;ar=0;while(1){aq=ar+1|0;ak=av;c[ak>>2]=c[ak>>2]|c[9620648+((d[ap]|0)<<2)>>2]<<3;if((aq|0)<(w|0)){av=av+8|0;ap=ap+1|0;ar=aq}else{ax=0;break}}}else{ax=0}while(1){if((ax|0)>=1024){au=48324;break}ay=9638528+(ax<<2)|0;if((c[ay>>2]|0)==(at|0)){break}else{ax=ax+1|0}}if((au|0)==48324){i=e;return}gGr(at);c[ay>>2]=0;i=e;return}}while(0);while(1){if((aw|0)>=1024){au=48326;break}az=9638528+(aw<<2)|0;if((c[az>>2]|0)==(at|0)){break}else{aw=aw+1|0}}if((au|0)==48326){i=e;return}gGr(at);c[az>>2]=0;i=e;return}function VY(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0;b=i;i=i+4640|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;l=b+360|0;m=b+472|0;n=b+480|0;o=b+592|0;p=b+600|0;q=b+712|0;r=b+720|0;s=b+832|0;t=b+840|0;u=b+952|0;v=b+960|0;w=b+1072|0;x=b+1080|0;y=b+1192|0;z=b+1200|0;A=b+1312|0;B=b+1320|0;C=b+1432|0;D=b+1440|0;E=b+1552|0;F=b+1560|0;G=b+1672|0;H=b+1680|0;I=b+1792|0;J=b+1800|0;K=b+1912|0;L=b+1920|0;M=b+2032|0;N=b+2040|0;O=b+2152|0;P=b+2160|0;Q=b+2272|0;R=b+2280|0;S=b+2392|0;T=b+2400|0;U=b+2512|0;V=b+2624|0;W=b+2736|0;X=b+2848|0;Y=b+2960|0;Z=b+3072|0;_=b+3184|0;$=b+3296|0;aa=b+3408|0;ab=b+3520|0;ac=b+3632|0;ad=b+3744|0;ae=b+3856|0;af=b+3968|0;ag=b+4080|0;ah=b+4192|0;ai=b+4304|0;aj=b+4416|0;ak=b+4528|0;al=c[3542028]|0;am=ak+100|0;c[am>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](ak,a)|0;ak=c[am>>2]|0;L62538:do{if((ak|0)!=0){an=0;while(1){if((an|0)>=1024){break L62538}ao=9638528+(an<<2)|0;if((c[ao>>2]|0)==0){break}else{an=an+1|0}}an=gGq(ak)|0;c[ao>>2]=an;if((an|0)==0){break}gGz(an|0,0,ak|0);do{if((c[3542200]|0)==0){ap=0}else{aq=R+108|0;c[aq>>2]=0;ar=R+100|0;c[ar>>2]=0;as=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[as&16383](R,a)|0;if((c[aq>>2]|0)!=0){aq=c[ar>>2]|0;c[S>>2]=9534384;ar=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ar&16383](S,a,0)|0;if((aq|0)<1){ap=0;break}if((gzL(an,0,a)|0)!=0){ap=0;break}}aq=c[am>>2]&-2;if((aq|0)>0){ar=al;as=an;at=0;while(1){au=at+1|0;av=ar;c[av>>2]=c[av>>2]|c[9620648+((d[as]|0)<<2)>>2];if((au|0)<(aq|0)){ar=ar+8|0;as=as+1|0;at=au}else{aw=0;break}}}else{aw=0}while(1){if((aw|0)>=1024){break L62538}ax=9638528+(aw<<2)|0;if((c[ax>>2]|0)==(an|0)){break}else{aw=aw+1|0}}gGr(an);c[ax>>2]=0;break L62538}}while(0);while(1){if((ap|0)>=1024){break L62538}ay=9638528+(ap<<2)|0;if((c[ay>>2]|0)==(an|0)){break}else{ap=ap+1|0}}gGr(an);c[ay>>2]=0}}while(0);ay=c[3542028]|0;ap=a+1|0;ax=aj+100|0;c[ax>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](aj,ap)|0;aj=c[ax>>2]|0;L62562:do{if((aj|0)!=0){aw=0;while(1){if((aw|0)>=1024){break L62562}az=9638528+(aw<<2)|0;if((c[az>>2]|0)==0){break}else{aw=aw+1|0}}aw=gGq(aj)|0;c[az>>2]=aw;if((aw|0)==0){break}gGz(aw|0,0,aj|0);do{if((c[3542200]|0)==0){aA=0}else{an=P+108|0;c[an>>2]=0;al=P+100|0;c[al>>2]=0;am=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[am&16383](P,ap)|0;if((c[an>>2]|0)!=0){an=c[al>>2]|0;c[Q>>2]=9534384;al=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[al&16383](Q,ap,0)|0;if((an|0)<1){aA=0;break}if((gzL(aw,0,ap)|0)!=0){aA=0;break}}an=c[ax>>2]&-2;if((an|0)>0){al=ay;am=aw;S=0;while(1){R=S+1|0;ak=al;c[ak>>2]=c[ak>>2]|c[9620648+((d[am]|0)<<2)>>2]<<1;if((R|0)<(an|0)){al=al+8|0;am=am+1|0;S=R}else{aB=0;break}}}else{aB=0}while(1){if((aB|0)>=1024){break L62562}aC=9638528+(aB<<2)|0;if((c[aC>>2]|0)==(aw|0)){break}else{aB=aB+1|0}}gGr(aw);c[aC>>2]=0;break L62562}}while(0);while(1){if((aA|0)>=1024){break L62562}aD=9638528+(aA<<2)|0;if((c[aD>>2]|0)==(aw|0)){break}else{aA=aA+1|0}}gGr(aw);c[aD>>2]=0}}while(0);aD=c[3542028]|0;aA=a+2|0;aC=ai+100|0;c[aC>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](ai,aA)|0;ai=c[aC>>2]|0;L62586:do{if((ai|0)!=0){aB=0;while(1){if((aB|0)>=1024){break L62586}aE=9638528+(aB<<2)|0;if((c[aE>>2]|0)==0){break}else{aB=aB+1|0}}aB=gGq(ai)|0;c[aE>>2]=aB;if((aB|0)==0){break}gGz(aB|0,0,ai|0);do{if((c[3542200]|0)==0){aF=0}else{aw=N+108|0;c[aw>>2]=0;ay=N+100|0;c[ay>>2]=0;ax=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ax&16383](N,aA)|0;if((c[aw>>2]|0)!=0){aw=c[ay>>2]|0;c[O>>2]=9534384;ay=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ay&16383](O,aA,0)|0;if((aw|0)<1){aF=0;break}if((gzL(aB,0,aA)|0)!=0){aF=0;break}}aw=c[aC>>2]&-2;if((aw|0)>0){ay=aD;ax=aB;ap=0;while(1){Q=ap+2|0;P=ay;c[P>>2]=(c[9620648+((d[ax+1|0]|0)<<2)>>2]<<1|c[9620648+((d[ax]|0)<<2)>>2])<<2|c[P>>2];if((Q|0)<(aw|0)){ay=ay+8|0;ax=ax+2|0;ap=Q}else{aG=0;break}}}else{aG=0}while(1){if((aG|0)>=1024){break L62586}aH=9638528+(aG<<2)|0;if((c[aH>>2]|0)==(aB|0)){break}else{aG=aG+1|0}}gGr(aB);c[aH>>2]=0;break L62586}}while(0);while(1){if((aF|0)>=1024){break L62586}aI=9638528+(aF<<2)|0;if((c[aI>>2]|0)==(aB|0)){break}else{aF=aF+1|0}}gGr(aB);c[aI>>2]=0}}while(0);aI=(c[3542028]|0)+4|0;aF=a+3|0;aH=ah+100|0;c[aH>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](ah,aF)|0;ah=c[aH>>2]|0;L62610:do{if((ah|0)!=0){aG=0;while(1){if((aG|0)>=1024){break L62610}aJ=9638528+(aG<<2)|0;if((c[aJ>>2]|0)==0){break}else{aG=aG+1|0}}aG=gGq(ah)|0;c[aJ>>2]=aG;if((aG|0)==0){break}gGz(aG|0,0,ah|0);do{if((c[3542200]|0)==0){aK=0}else{aB=L+108|0;c[aB>>2]=0;aD=L+100|0;c[aD>>2]=0;aC=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aC&16383](L,aF)|0;if((c[aB>>2]|0)!=0){aB=c[aD>>2]|0;c[M>>2]=9534384;aD=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aD&16383](M,aF,0)|0;if((aB|0)<1){aK=0;break}if((gzL(aG,0,aF)|0)!=0){aK=0;break}}aB=c[aH>>2]&-2;if((aB|0)>0){aD=aI;aC=aG;aA=0;while(1){O=aA+2|0;N=aD;c[N>>2]=c[9620648+((d[aC+1|0]|0)<<2)>>2]<<1|c[9620648+((d[aC]|0)<<2)>>2]|c[N>>2];if((O|0)<(aB|0)){aD=aD+8|0;aC=aC+2|0;aA=O}else{aL=0;break}}}else{aL=0}while(1){if((aL|0)>=1024){break L62610}aM=9638528+(aL<<2)|0;if((c[aM>>2]|0)==(aG|0)){break}else{aL=aL+1|0}}gGr(aG);c[aM>>2]=0;break L62610}}while(0);while(1){if((aK|0)>=1024){break L62610}aN=9638528+(aK<<2)|0;if((c[aN>>2]|0)==(aG|0)){break}else{aK=aK+1|0}}gGr(aG);c[aN>>2]=0}}while(0);aN=(c[3542028]|0)+4|0;aK=a+4|0;aM=ag+100|0;c[aM>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](ag,aK)|0;ag=c[aM>>2]|0;L62634:do{if((ag|0)!=0){aL=0;while(1){if((aL|0)>=1024){break L62634}aO=9638528+(aL<<2)|0;if((c[aO>>2]|0)==0){break}else{aL=aL+1|0}}aL=gGq(ag)|0;c[aO>>2]=aL;if((aL|0)==0){break}gGz(aL|0,0,ag|0);do{if((c[3542200]|0)==0){aP=0}else{aG=J+108|0;c[aG>>2]=0;aI=J+100|0;c[aI>>2]=0;aH=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aH&16383](J,aK)|0;if((c[aG>>2]|0)!=0){aG=c[aI>>2]|0;c[K>>2]=9534384;aI=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aI&16383](K,aK,0)|0;if((aG|0)<1){aP=0;break}if((gzL(aL,0,aK)|0)!=0){aP=0;break}}aG=c[aM>>2]&-2;if((aG|0)>0){aI=aN;aH=aL;aF=0;while(1){M=aF+1|0;L=aI;c[L>>2]=c[L>>2]|c[9620648+((d[aH]|0)<<2)>>2]<<2;if((M|0)<(aG|0)){aI=aI+8|0;aH=aH+1|0;aF=M}else{aQ=0;break}}}else{aQ=0}while(1){if((aQ|0)>=1024){break L62634}aR=9638528+(aQ<<2)|0;if((c[aR>>2]|0)==(aL|0)){break}else{aQ=aQ+1|0}}gGr(aL);c[aR>>2]=0;break L62634}}while(0);while(1){if((aP|0)>=1024){break L62634}aS=9638528+(aP<<2)|0;if((c[aS>>2]|0)==(aL|0)){break}else{aP=aP+1|0}}gGr(aL);c[aS>>2]=0}}while(0);aS=(c[3542028]|0)+4|0;aP=a+5|0;aR=af+100|0;c[aR>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](af,aP)|0;af=c[aR>>2]|0;L62658:do{if((af|0)!=0){aQ=0;while(1){if((aQ|0)>=1024){break L62658}aT=9638528+(aQ<<2)|0;if((c[aT>>2]|0)==0){break}else{aQ=aQ+1|0}}aQ=gGq(af)|0;c[aT>>2]=aQ;if((aQ|0)==0){break}gGz(aQ|0,0,af|0);do{if((c[3542200]|0)==0){aU=0}else{aL=H+108|0;c[aL>>2]=0;aN=H+100|0;c[aN>>2]=0;aM=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aM&16383](H,aP)|0;if((c[aL>>2]|0)!=0){aL=c[aN>>2]|0;c[I>>2]=9534384;aN=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aN&16383](I,aP,0)|0;if((aL|0)<1){aU=0;break}if((gzL(aQ,0,aP)|0)!=0){aU=0;break}}aL=c[aR>>2]&-2;if((aL|0)>0){aN=aS;aM=aQ;aK=0;while(1){K=aK+1|0;J=aN;c[J>>2]=c[J>>2]|c[9620648+((d[aM]|0)<<2)>>2]<<3;if((K|0)<(aL|0)){aN=aN+8|0;aM=aM+1|0;aK=K}else{aV=0;break}}}else{aV=0}while(1){if((aV|0)>=1024){break L62658}aW=9638528+(aV<<2)|0;if((c[aW>>2]|0)==(aQ|0)){break}else{aV=aV+1|0}}gGr(aQ);c[aW>>2]=0;break L62658}}while(0);while(1){if((aU|0)>=1024){break L62658}aX=9638528+(aU<<2)|0;if((c[aX>>2]|0)==(aQ|0)){break}else{aU=aU+1|0}}gGr(aQ);c[aX>>2]=0}}while(0);aX=(c[3542028]|0)+1048576|0;aU=a+6|0;aW=ae+100|0;c[aW>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](ae,aU)|0;ae=c[aW>>2]|0;L62682:do{if((ae|0)!=0){aV=0;while(1){if((aV|0)>=1024){break L62682}aY=9638528+(aV<<2)|0;if((c[aY>>2]|0)==0){break}else{aV=aV+1|0}}aV=gGq(ae)|0;c[aY>>2]=aV;if((aV|0)==0){break}gGz(aV|0,0,ae|0);do{if((c[3542200]|0)==0){aZ=0}else{aQ=F+108|0;c[aQ>>2]=0;aS=F+100|0;c[aS>>2]=0;aR=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aR&16383](F,aU)|0;if((c[aQ>>2]|0)!=0){aQ=c[aS>>2]|0;c[G>>2]=9534384;aS=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aS&16383](G,aU,0)|0;if((aQ|0)<1){aZ=0;break}if((gzL(aV,0,aU)|0)!=0){aZ=0;break}}aQ=c[aW>>2]&-2;if((aQ|0)>0){aS=aX;aR=aV;aP=0;while(1){I=aP+1|0;H=aS;c[H>>2]=c[H>>2]|c[9620648+((d[aR]|0)<<2)>>2];if((I|0)<(aQ|0)){aS=aS+8|0;aR=aR+1|0;aP=I}else{a_=0;break}}}else{a_=0}while(1){if((a_|0)>=1024){break L62682}a$=9638528+(a_<<2)|0;if((c[a$>>2]|0)==(aV|0)){break}else{a_=a_+1|0}}gGr(aV);c[a$>>2]=0;break L62682}}while(0);while(1){if((aZ|0)>=1024){break L62682}a0=9638528+(aZ<<2)|0;if((c[a0>>2]|0)==(aV|0)){break}else{aZ=aZ+1|0}}gGr(aV);c[a0>>2]=0}}while(0);a0=(c[3542028]|0)+1048576|0;aZ=a+7|0;a$=ad+100|0;c[a$>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](ad,aZ)|0;ad=c[a$>>2]|0;L62706:do{if((ad|0)!=0){a_=0;while(1){if((a_|0)>=1024){break L62706}a1=9638528+(a_<<2)|0;if((c[a1>>2]|0)==0){break}else{a_=a_+1|0}}a_=gGq(ad)|0;c[a1>>2]=a_;if((a_|0)==0){break}gGz(a_|0,0,ad|0);do{if((c[3542200]|0)==0){a2=0}else{aV=D+108|0;c[aV>>2]=0;aX=D+100|0;c[aX>>2]=0;aW=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aW&16383](D,aZ)|0;if((c[aV>>2]|0)!=0){aV=c[aX>>2]|0;c[E>>2]=9534384;aX=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aX&16383](E,aZ,0)|0;if((aV|0)<1){a2=0;break}if((gzL(a_,0,aZ)|0)!=0){a2=0;break}}aV=c[a$>>2]&-2;if((aV|0)>0){aX=a0;aW=a_;aU=0;while(1){G=aU+1|0;F=aX;c[F>>2]=c[F>>2]|c[9620648+((d[aW]|0)<<2)>>2]<<1;if((G|0)<(aV|0)){aX=aX+8|0;aW=aW+1|0;aU=G}else{a3=0;break}}}else{a3=0}while(1){if((a3|0)>=1024){break L62706}a4=9638528+(a3<<2)|0;if((c[a4>>2]|0)==(a_|0)){break}else{a3=a3+1|0}}gGr(a_);c[a4>>2]=0;break L62706}}while(0);while(1){if((a2|0)>=1024){break L62706}a5=9638528+(a2<<2)|0;if((c[a5>>2]|0)==(a_|0)){break}else{a2=a2+1|0}}gGr(a_);c[a5>>2]=0}}while(0);a5=(c[3542028]|0)+1048580|0;a2=a+8|0;a4=ac+100|0;c[a4>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](ac,a2)|0;ac=c[a4>>2]|0;L62730:do{if((ac|0)!=0){a3=0;while(1){if((a3|0)>=1024){break L62730}a6=9638528+(a3<<2)|0;if((c[a6>>2]|0)==0){break}else{a3=a3+1|0}}a3=gGq(ac)|0;c[a6>>2]=a3;if((a3|0)==0){break}gGz(a3|0,0,ac|0);do{if((c[3542200]|0)==0){a7=0}else{a_=B+108|0;c[a_>>2]=0;a0=B+100|0;c[a0>>2]=0;a$=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[a$&16383](B,a2)|0;if((c[a_>>2]|0)!=0){a_=c[a0>>2]|0;c[C>>2]=9534384;a0=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[a0&16383](C,a2,0)|0;if((a_|0)<1){a7=0;break}if((gzL(a3,0,a2)|0)!=0){a7=0;break}}a_=c[a4>>2]&-2;if((a_|0)>0){a0=a5;a$=a3;aZ=0;while(1){E=aZ+1|0;D=a0;c[D>>2]=c[D>>2]|c[9620648+((d[a$]|0)<<2)>>2]<<2;if((E|0)<(a_|0)){a0=a0+8|0;a$=a$+1|0;aZ=E}else{a8=0;break}}}else{a8=0}while(1){if((a8|0)>=1024){break L62730}a9=9638528+(a8<<2)|0;if((c[a9>>2]|0)==(a3|0)){break}else{a8=a8+1|0}}gGr(a3);c[a9>>2]=0;break L62730}}while(0);while(1){if((a7|0)>=1024){break L62730}ba=9638528+(a7<<2)|0;if((c[ba>>2]|0)==(a3|0)){break}else{a7=a7+1|0}}gGr(a3);c[ba>>2]=0}}while(0);ba=(c[3542028]|0)+1048580|0;a7=a+9|0;a9=ab+100|0;c[a9>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](ab,a7)|0;ab=c[a9>>2]|0;L62754:do{if((ab|0)!=0){a8=0;while(1){if((a8|0)>=1024){break L62754}bb=9638528+(a8<<2)|0;if((c[bb>>2]|0)==0){break}else{a8=a8+1|0}}a8=gGq(ab)|0;c[bb>>2]=a8;if((a8|0)==0){break}gGz(a8|0,0,ab|0);do{if((c[3542200]|0)==0){bc=0}else{a3=z+108|0;c[a3>>2]=0;a5=z+100|0;c[a5>>2]=0;a4=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[a4&16383](z,a7)|0;if((c[a3>>2]|0)!=0){a3=c[a5>>2]|0;c[A>>2]=9534384;a5=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[a5&16383](A,a7,0)|0;if((a3|0)<1){bc=0;break}if((gzL(a8,0,a7)|0)!=0){bc=0;break}}a3=c[a9>>2]&-2;if((a3|0)>0){a5=ba;a4=a8;a2=0;while(1){C=a2+1|0;B=a5;c[B>>2]=c[B>>2]|c[9620648+((d[a4]|0)<<2)>>2]<<3;if((C|0)<(a3|0)){a5=a5+8|0;a4=a4+1|0;a2=C}else{bd=0;break}}}else{bd=0}while(1){if((bd|0)>=1024){break L62754}be=9638528+(bd<<2)|0;if((c[be>>2]|0)==(a8|0)){break}else{bd=bd+1|0}}gGr(a8);c[be>>2]=0;break L62754}}while(0);while(1){if((bc|0)>=1024){break L62754}bf=9638528+(bc<<2)|0;if((c[bf>>2]|0)==(a8|0)){break}else{bc=bc+1|0}}gGr(a8);c[bf>>2]=0}}while(0);bf=(c[3542028]|0)+2097152|0;bc=a+10|0;be=aa+100|0;c[be>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](aa,bc)|0;aa=c[be>>2]|0;L62778:do{if((aa|0)!=0){bd=0;while(1){if((bd|0)>=1024){break L62778}bg=9638528+(bd<<2)|0;if((c[bg>>2]|0)==0){break}else{bd=bd+1|0}}bd=gGq(aa)|0;c[bg>>2]=bd;if((bd|0)==0){break}gGz(bd|0,0,aa|0);do{if((c[3542200]|0)==0){bh=0}else{a8=x+108|0;c[a8>>2]=0;ba=x+100|0;c[ba>>2]=0;a9=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[a9&16383](x,bc)|0;if((c[a8>>2]|0)!=0){a8=c[ba>>2]|0;c[y>>2]=9534384;ba=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ba&16383](y,bc,0)|0;if((a8|0)<1){bh=0;break}if((gzL(bd,0,bc)|0)!=0){bh=0;break}}a8=c[be>>2]&-2;if((a8|0)>0){ba=bf;a9=bd;a7=0;while(1){A=a7+2|0;z=ba;c[z>>2]=c[9620648+((d[a9+1|0]|0)<<2)>>2]<<1|c[9620648+((d[a9]|0)<<2)>>2]|c[z>>2];if((A|0)<(a8|0)){ba=ba+8|0;a9=a9+2|0;a7=A}else{bi=0;break}}}else{bi=0}while(1){if((bi|0)>=1024){break L62778}bj=9638528+(bi<<2)|0;if((c[bj>>2]|0)==(bd|0)){break}else{bi=bi+1|0}}gGr(bd);c[bj>>2]=0;break L62778}}while(0);while(1){if((bh|0)>=1024){break L62778}bk=9638528+(bh<<2)|0;if((c[bk>>2]|0)==(bd|0)){break}else{bh=bh+1|0}}gGr(bd);c[bk>>2]=0}}while(0);bk=(c[3542028]|0)+2097152|0;bh=a+11|0;bj=$+100|0;c[bj>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383]($,bh)|0;$=c[bj>>2]|0;L62802:do{if(($|0)!=0){bi=0;while(1){if((bi|0)>=1024){break L62802}bl=9638528+(bi<<2)|0;if((c[bl>>2]|0)==0){break}else{bi=bi+1|0}}bi=gGq($)|0;c[bl>>2]=bi;if((bi|0)==0){break}gGz(bi|0,0,$|0);do{if((c[3542200]|0)==0){bm=0}else{bd=v+108|0;c[bd>>2]=0;bf=v+100|0;c[bf>>2]=0;be=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[be&16383](v,bh)|0;if((c[bd>>2]|0)!=0){bd=c[bf>>2]|0;c[w>>2]=9534384;bf=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[bf&16383](w,bh,0)|0;if((bd|0)<1){bm=0;break}if((gzL(bi,0,bh)|0)!=0){bm=0;break}}bd=c[bj>>2]&-2;if((bd|0)>0){bf=bk;be=bi;bc=0;while(1){y=bc+1|0;x=bf;c[x>>2]=c[x>>2]|c[9620648+((d[be]|0)<<2)>>2]<<2;if((y|0)<(bd|0)){bf=bf+8|0;be=be+1|0;bc=y}else{bn=0;break}}}else{bn=0}while(1){if((bn|0)>=1024){break L62802}bo=9638528+(bn<<2)|0;if((c[bo>>2]|0)==(bi|0)){break}else{bn=bn+1|0}}gGr(bi);c[bo>>2]=0;break L62802}}while(0);while(1){if((bm|0)>=1024){break L62802}bp=9638528+(bm<<2)|0;if((c[bp>>2]|0)==(bi|0)){break}else{bm=bm+1|0}}gGr(bi);c[bp>>2]=0}}while(0);bp=(c[3542028]|0)+2097152|0;bm=a+12|0;bo=_+100|0;c[bo>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](_,bm)|0;_=c[bo>>2]|0;L62826:do{if((_|0)!=0){bn=0;while(1){if((bn|0)>=1024){break L62826}bq=9638528+(bn<<2)|0;if((c[bq>>2]|0)==0){break}else{bn=bn+1|0}}bn=gGq(_)|0;c[bq>>2]=bn;if((bn|0)==0){break}gGz(bn|0,0,_|0);do{if((c[3542200]|0)==0){br=0}else{bi=t+108|0;c[bi>>2]=0;bk=t+100|0;c[bk>>2]=0;bj=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[bj&16383](t,bm)|0;if((c[bi>>2]|0)!=0){bi=c[bk>>2]|0;c[u>>2]=9534384;bk=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[bk&16383](u,bm,0)|0;if((bi|0)<1){br=0;break}if((gzL(bn,0,bm)|0)!=0){br=0;break}}bi=c[bo>>2]&-2;if((bi|0)>0){bk=bp;bj=bn;bh=0;while(1){w=bh+1|0;v=bk;c[v>>2]=c[v>>2]|c[9620648+((d[bj]|0)<<2)>>2]<<3;if((w|0)<(bi|0)){bk=bk+8|0;bj=bj+1|0;bh=w}else{bs=0;break}}}else{bs=0}while(1){if((bs|0)>=1024){break L62826}bt=9638528+(bs<<2)|0;if((c[bt>>2]|0)==(bn|0)){break}else{bs=bs+1|0}}gGr(bn);c[bt>>2]=0;break L62826}}while(0);while(1){if((br|0)>=1024){break L62826}bu=9638528+(br<<2)|0;if((c[bu>>2]|0)==(bn|0)){break}else{br=br+1|0}}gGr(bn);c[bu>>2]=0}}while(0);bu=(c[3542028]|0)+2097156|0;br=a+13|0;bt=Z+100|0;c[bt>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](Z,br)|0;Z=c[bt>>2]|0;L62850:do{if((Z|0)!=0){bs=0;while(1){if((bs|0)>=1024){break L62850}bv=9638528+(bs<<2)|0;if((c[bv>>2]|0)==0){break}else{bs=bs+1|0}}bs=gGq(Z)|0;c[bv>>2]=bs;if((bs|0)==0){break}gGz(bs|0,0,Z|0);do{if((c[3542200]|0)==0){bw=0}else{bn=r+108|0;c[bn>>2]=0;bp=r+100|0;c[bp>>2]=0;bo=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[bo&16383](r,br)|0;if((c[bn>>2]|0)!=0){bn=c[bp>>2]|0;c[s>>2]=9534384;bp=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[bp&16383](s,br,0)|0;if((bn|0)<1){bw=0;break}if((gzL(bs,0,br)|0)!=0){bw=0;break}}bn=c[bt>>2]&-2;if((bn|0)>0){bp=bu;bo=bs;bm=0;while(1){u=bm+2|0;t=bp;c[t>>2]=c[9620648+((d[bo+1|0]|0)<<2)>>2]<<1|c[9620648+((d[bo]|0)<<2)>>2]|c[t>>2];if((u|0)<(bn|0)){bp=bp+8|0;bo=bo+2|0;bm=u}else{bx=0;break}}}else{bx=0}while(1){if((bx|0)>=1024){break L62850}by=9638528+(bx<<2)|0;if((c[by>>2]|0)==(bs|0)){break}else{bx=bx+1|0}}gGr(bs);c[by>>2]=0;break L62850}}while(0);while(1){if((bw|0)>=1024){break L62850}bz=9638528+(bw<<2)|0;if((c[bz>>2]|0)==(bs|0)){break}else{bw=bw+1|0}}gGr(bs);c[bz>>2]=0}}while(0);bz=(c[3542028]|0)+2097156|0;bw=a+14|0;by=Y+100|0;c[by>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](Y,bw)|0;Y=c[by>>2]|0;L62874:do{if((Y|0)!=0){bx=0;while(1){if((bx|0)>=1024){break L62874}bA=9638528+(bx<<2)|0;if((c[bA>>2]|0)==0){break}else{bx=bx+1|0}}bx=gGq(Y)|0;c[bA>>2]=bx;if((bx|0)==0){break}gGz(bx|0,0,Y|0);do{if((c[3542200]|0)==0){bB=0}else{bs=p+108|0;c[bs>>2]=0;bu=p+100|0;c[bu>>2]=0;bt=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[bt&16383](p,bw)|0;if((c[bs>>2]|0)!=0){bs=c[bu>>2]|0;c[q>>2]=9534384;bu=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[bu&16383](q,bw,0)|0;if((bs|0)<1){bB=0;break}if((gzL(bx,0,bw)|0)!=0){bB=0;break}}bs=c[by>>2]&-2;if((bs|0)>0){bu=bz;bt=bx;br=0;while(1){s=br+1|0;r=bu;c[r>>2]=c[r>>2]|c[9620648+((d[bt]|0)<<2)>>2]<<2;if((s|0)<(bs|0)){bu=bu+8|0;bt=bt+1|0;br=s}else{bC=0;break}}}else{bC=0}while(1){if((bC|0)>=1024){break L62874}bD=9638528+(bC<<2)|0;if((c[bD>>2]|0)==(bx|0)){break}else{bC=bC+1|0}}gGr(bx);c[bD>>2]=0;break L62874}}while(0);while(1){if((bB|0)>=1024){break L62874}bE=9638528+(bB<<2)|0;if((c[bE>>2]|0)==(bx|0)){break}else{bB=bB+1|0}}gGr(bx);c[bE>>2]=0}}while(0);bE=(c[3542028]|0)+2097156|0;bB=a+15|0;bD=X+100|0;c[bD>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](X,bB)|0;X=c[bD>>2]|0;L62898:do{if((X|0)!=0){bC=0;while(1){if((bC|0)>=1024){break L62898}bF=9638528+(bC<<2)|0;if((c[bF>>2]|0)==0){break}else{bC=bC+1|0}}bC=gGq(X)|0;c[bF>>2]=bC;if((bC|0)==0){break}gGz(bC|0,0,X|0);do{if((c[3542200]|0)==0){bG=0}else{bx=n+108|0;c[bx>>2]=0;bz=n+100|0;c[bz>>2]=0;by=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[by&16383](n,bB)|0;if((c[bx>>2]|0)!=0){bx=c[bz>>2]|0;c[o>>2]=9534384;bz=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[bz&16383](o,bB,0)|0;if((bx|0)<1){bG=0;break}if((gzL(bC,0,bB)|0)!=0){bG=0;break}}bx=c[bD>>2]&-2;if((bx|0)>0){bz=bE;by=bC;bw=0;while(1){q=bw+1|0;p=bz;c[p>>2]=c[p>>2]|c[9620648+((d[by]|0)<<2)>>2]<<3;if((q|0)<(bx|0)){bz=bz+8|0;by=by+1|0;bw=q}else{bH=0;break}}}else{bH=0}while(1){if((bH|0)>=1024){break L62898}bI=9638528+(bH<<2)|0;if((c[bI>>2]|0)==(bC|0)){break}else{bH=bH+1|0}}gGr(bC);c[bI>>2]=0;break L62898}}while(0);while(1){if((bG|0)>=1024){break L62898}bJ=9638528+(bG<<2)|0;if((c[bJ>>2]|0)==(bC|0)){break}else{bG=bG+1|0}}gGr(bC);c[bJ>>2]=0}}while(0);bJ=(c[3542028]|0)+3145728|0;bG=a+16|0;bI=W+100|0;c[bI>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](W,bG)|0;W=c[bI>>2]|0;L62922:do{if((W|0)!=0){bH=0;while(1){if((bH|0)>=1024){break L62922}bK=9638528+(bH<<2)|0;if((c[bK>>2]|0)==0){break}else{bH=bH+1|0}}bH=gGq(W)|0;c[bK>>2]=bH;if((bH|0)==0){break}gGz(bH|0,0,W|0);do{if((c[3542200]|0)==0){bL=0}else{bC=l+108|0;c[bC>>2]=0;bE=l+100|0;c[bE>>2]=0;bD=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[bD&16383](l,bG)|0;if((c[bC>>2]|0)!=0){bC=c[bE>>2]|0;c[m>>2]=9534384;bE=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[bE&16383](m,bG,0)|0;if((bC|0)<1){bL=0;break}if((gzL(bH,0,bG)|0)!=0){bL=0;break}}bC=c[bI>>2]&-2;if((bC|0)>0){bE=bJ;bD=bH;bB=0;while(1){o=bB+1|0;n=bE;c[n>>2]=c[n>>2]|c[9620648+((d[bD]|0)<<2)>>2]<<2;if((o|0)<(bC|0)){bE=bE+8|0;bD=bD+1|0;bB=o}else{bM=0;break}}}else{bM=0}while(1){if((bM|0)>=1024){break L62922}bN=9638528+(bM<<2)|0;if((c[bN>>2]|0)==(bH|0)){break}else{bM=bM+1|0}}gGr(bH);c[bN>>2]=0;break L62922}}while(0);while(1){if((bL|0)>=1024){break L62922}bO=9638528+(bL<<2)|0;if((c[bO>>2]|0)==(bH|0)){break}else{bL=bL+1|0}}gGr(bH);c[bO>>2]=0}}while(0);bO=(c[3542028]|0)+3145728|0;bL=a+17|0;bN=V+100|0;c[bN>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](V,bL)|0;V=c[bN>>2]|0;L62946:do{if((V|0)!=0){bM=0;while(1){if((bM|0)>=1024){break L62946}bP=9638528+(bM<<2)|0;if((c[bP>>2]|0)==0){break}else{bM=bM+1|0}}bM=gGq(V)|0;c[bP>>2]=bM;if((bM|0)==0){break}gGz(bM|0,0,V|0);do{if((c[3542200]|0)==0){bQ=0}else{bH=j+108|0;c[bH>>2]=0;bJ=j+100|0;c[bJ>>2]=0;bI=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[bI&16383](j,bL)|0;if((c[bH>>2]|0)!=0){bH=c[bJ>>2]|0;c[k>>2]=9534384;bJ=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[bJ&16383](k,bL,0)|0;if((bH|0)<1){bQ=0;break}if((gzL(bM,0,bL)|0)!=0){bQ=0;break}}bH=c[bN>>2]&-2;if((bH|0)>0){bJ=bO;bI=bM;bG=0;while(1){m=bG+1|0;l=bJ;c[l>>2]=c[l>>2]|c[9620648+((d[bI]|0)<<2)>>2]<<3;if((m|0)<(bH|0)){bJ=bJ+8|0;bI=bI+1|0;bG=m}else{bR=0;break}}}else{bR=0}while(1){if((bR|0)>=1024){break L62946}bS=9638528+(bR<<2)|0;if((c[bS>>2]|0)==(bM|0)){break}else{bR=bR+1|0}}gGr(bM);c[bS>>2]=0;break L62946}}while(0);while(1){if((bQ|0)>=1024){break L62946}bT=9638528+(bQ<<2)|0;if((c[bT>>2]|0)==(bM|0)){break}else{bQ=bQ+1|0}}gGr(bM);c[bT>>2]=0}}while(0);bT=(c[3542028]|0)+3145732|0;bQ=a+18|0;bS=U+100|0;c[bS>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](U,bQ)|0;U=c[bS>>2]|0;L62970:do{if((U|0)!=0){bR=0;while(1){if((bR|0)>=1024){break L62970}bU=9638528+(bR<<2)|0;if((c[bU>>2]|0)==0){break}else{bR=bR+1|0}}bR=gGq(U)|0;c[bU>>2]=bR;if((bR|0)==0){break}gGz(bR|0,0,U|0);do{if((c[3542200]|0)==0){bV=0}else{bM=g+108|0;c[bM>>2]=0;bO=g+100|0;c[bO>>2]=0;bN=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[bN&16383](g,bQ)|0;if((c[bM>>2]|0)!=0){bM=c[bO>>2]|0;c[h>>2]=9534384;bO=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[bO&16383](h,bQ,0)|0;if((bM|0)<1){bV=0;break}if((gzL(bR,0,bQ)|0)!=0){bV=0;break}}bM=c[bS>>2]&-2;if((bM|0)>0){bO=bT;bN=bR;bL=0;while(1){k=bL+1|0;j=bO;c[j>>2]=c[j>>2]|c[9620648+((d[bN]|0)<<2)>>2]<<2;if((k|0)<(bM|0)){bO=bO+8|0;bN=bN+1|0;bL=k}else{bW=0;break}}}else{bW=0}while(1){if((bW|0)>=1024){break L62970}bX=9638528+(bW<<2)|0;if((c[bX>>2]|0)==(bR|0)){break}else{bW=bW+1|0}}gGr(bR);c[bX>>2]=0;break L62970}}while(0);while(1){if((bV|0)>=1024){break L62970}bY=9638528+(bV<<2)|0;if((c[bY>>2]|0)==(bR|0)){break}else{bV=bV+1|0}}gGr(bR);c[bY>>2]=0}}while(0);bY=(c[3542028]|0)+3145732|0;bV=a+19|0;a=T+100|0;c[a>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](T,bV)|0;T=c[a>>2]|0;if((T|0)==0){i=b;return 0}else{bZ=0}while(1){if((bZ|0)>=1024){b_=48651;break}b$=9638528+(bZ<<2)|0;if((c[b$>>2]|0)==0){break}else{bZ=bZ+1|0}}if((b_|0)==48651){i=b;return 0}bZ=gGq(T)|0;c[b$>>2]=bZ;if((bZ|0)==0){i=b;return 0}gGz(bZ|0,0,T|0);do{if((c[3542200]|0)==0){b0=0}else{T=e+108|0;c[T>>2]=0;b$=e+100|0;c[b$>>2]=0;bX=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[bX&16383](e,bV)|0;if((c[T>>2]|0)!=0){T=c[b$>>2]|0;c[f>>2]=9534384;b$=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[b$&16383](f,bV,0)|0;if((T|0)<1){b0=0;break}if((gzL(bZ,0,bV)|0)!=0){b0=0;break}}T=c[a>>2]&-2;if((T|0)>0){b$=bY;bX=bZ;bW=0;while(1){bT=bW+1|0;bS=b$;c[bS>>2]=c[bS>>2]|c[9620648+((d[bX]|0)<<2)>>2]<<3;if((bT|0)<(T|0)){b$=b$+8|0;bX=bX+1|0;bW=bT}else{b1=0;break}}}else{b1=0}while(1){if((b1|0)>=1024){b_=48655;break}b2=9638528+(b1<<2)|0;if((c[b2>>2]|0)==(bZ|0)){break}else{b1=b1+1|0}}if((b_|0)==48655){i=b;return 0}gGr(bZ);c[b2>>2]=0;i=b;return 0}}while(0);while(1){if((b0|0)>=1024){b_=48653;break}b3=9638528+(b0<<2)|0;if((c[b3>>2]|0)==(bZ|0)){break}else{b0=b0+1|0}}if((b_|0)==48653){i=b;return 0}gGr(bZ);c[b3>>2]=0;i=b;return 0}function VZ(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0;b=i;i=i+3944|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;l=b+360|0;m=b+472|0;n=b+480|0;o=b+592|0;p=b+600|0;q=b+712|0;r=b+720|0;s=b+832|0;t=b+840|0;u=b+952|0;v=b+960|0;w=b+1072|0;x=b+1080|0;y=b+1192|0;z=b+1200|0;A=b+1312|0;B=b+1320|0;C=b+1432|0;D=b+1440|0;E=b+1552|0;F=b+1560|0;G=b+1672|0;H=b+1680|0;I=b+1792|0;J=b+1800|0;K=b+1912|0;L=b+1920|0;M=b+2032|0;N=b+2040|0;O=b+2152|0;P=b+2264|0;Q=b+2376|0;R=b+2488|0;S=b+2600|0;T=b+2712|0;U=b+2824|0;V=b+2936|0;W=b+3048|0;X=b+3160|0;Y=b+3272|0;Z=b+3384|0;_=b+3496|0;$=b+3608|0;aa=b+3720|0;ab=b+3832|0;ac=c[3542028]|0;ad=ab+100|0;c[ad>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](ab,a)|0;ab=c[ad>>2]|0;L63029:do{if((ab|0)!=0){ae=0;while(1){if((ae|0)>=1024){break L63029}af=9638528+(ae<<2)|0;if((c[af>>2]|0)==0){break}else{ae=ae+1|0}}ae=gGq(ab)|0;c[af>>2]=ae;if((ae|0)==0){break}gGz(ae|0,0,ab|0);do{if((c[3542200]|0)==0){ag=0}else{ah=L+108|0;c[ah>>2]=0;ai=L+100|0;c[ai>>2]=0;aj=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aj&16383](L,a)|0;if((c[ah>>2]|0)!=0){ah=c[ai>>2]|0;c[M>>2]=9534384;ai=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ai&16383](M,a,0)|0;if((ah|0)<1){ag=0;break}if((gzL(ae,0,a)|0)!=0){ag=0;break}}ah=c[ad>>2]&-2;if((ah|0)>0){ai=ac;aj=ae;ak=0;while(1){al=ak+1|0;am=ai;c[am>>2]=c[am>>2]|c[9620648+((d[aj]|0)<<2)>>2];if((al|0)<(ah|0)){ai=ai+8|0;aj=aj+1|0;ak=al}else{an=0;break}}}else{an=0}while(1){if((an|0)>=1024){break L63029}ao=9638528+(an<<2)|0;if((c[ao>>2]|0)==(ae|0)){break}else{an=an+1|0}}gGr(ae);c[ao>>2]=0;break L63029}}while(0);while(1){if((ag|0)>=1024){break L63029}ap=9638528+(ag<<2)|0;if((c[ap>>2]|0)==(ae|0)){break}else{ag=ag+1|0}}gGr(ae);c[ap>>2]=0}}while(0);ap=c[3542028]|0;ag=a+1|0;ao=aa+100|0;c[ao>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](aa,ag)|0;aa=c[ao>>2]|0;L63053:do{if((aa|0)!=0){an=0;while(1){if((an|0)>=1024){break L63053}aq=9638528+(an<<2)|0;if((c[aq>>2]|0)==0){break}else{an=an+1|0}}an=gGq(aa)|0;c[aq>>2]=an;if((an|0)==0){break}gGz(an|0,0,aa|0);do{if((c[3542200]|0)==0){ar=0}else{ae=J+108|0;c[ae>>2]=0;ac=J+100|0;c[ac>>2]=0;ad=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ad&16383](J,ag)|0;if((c[ae>>2]|0)!=0){ae=c[ac>>2]|0;c[K>>2]=9534384;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ac&16383](K,ag,0)|0;if((ae|0)<1){ar=0;break}if((gzL(an,0,ag)|0)!=0){ar=0;break}}ae=c[ao>>2]&-2;if((ae|0)>0){ac=ap;ad=an;M=0;while(1){L=M+1|0;ab=ac;c[ab>>2]=c[ab>>2]|c[9620648+((d[ad]|0)<<2)>>2]<<1;if((L|0)<(ae|0)){ac=ac+8|0;ad=ad+1|0;M=L}else{as=0;break}}}else{as=0}while(1){if((as|0)>=1024){break L63053}at=9638528+(as<<2)|0;if((c[at>>2]|0)==(an|0)){break}else{as=as+1|0}}gGr(an);c[at>>2]=0;break L63053}}while(0);while(1){if((ar|0)>=1024){break L63053}au=9638528+(ar<<2)|0;if((c[au>>2]|0)==(an|0)){break}else{ar=ar+1|0}}gGr(an);c[au>>2]=0}}while(0);au=c[3542028]|0;ar=a+2|0;at=$+100|0;c[at>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383]($,ar)|0;$=c[at>>2]|0;L63077:do{if(($|0)!=0){as=0;while(1){if((as|0)>=1024){break L63077}av=9638528+(as<<2)|0;if((c[av>>2]|0)==0){break}else{as=as+1|0}}as=gGq($)|0;c[av>>2]=as;if((as|0)==0){break}gGz(as|0,0,$|0);do{if((c[3542200]|0)==0){aw=0}else{an=H+108|0;c[an>>2]=0;ap=H+100|0;c[ap>>2]=0;ao=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ao&16383](H,ar)|0;if((c[an>>2]|0)!=0){an=c[ap>>2]|0;c[I>>2]=9534384;ap=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ap&16383](I,ar,0)|0;if((an|0)<1){aw=0;break}if((gzL(as,0,ar)|0)!=0){aw=0;break}}an=c[at>>2]&-2;if((an|0)>0){ap=au;ao=as;ag=0;while(1){K=ag+2|0;J=ap;c[J>>2]=(c[9620648+((d[ao+1|0]|0)<<2)>>2]<<1|c[9620648+((d[ao]|0)<<2)>>2])<<2|c[J>>2];if((K|0)<(an|0)){ap=ap+8|0;ao=ao+2|0;ag=K}else{ax=0;break}}}else{ax=0}while(1){if((ax|0)>=1024){break L63077}ay=9638528+(ax<<2)|0;if((c[ay>>2]|0)==(as|0)){break}else{ax=ax+1|0}}gGr(as);c[ay>>2]=0;break L63077}}while(0);while(1){if((aw|0)>=1024){break L63077}az=9638528+(aw<<2)|0;if((c[az>>2]|0)==(as|0)){break}else{aw=aw+1|0}}gGr(as);c[az>>2]=0}}while(0);az=(c[3542028]|0)+4|0;aw=a+3|0;ay=_+100|0;c[ay>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](_,aw)|0;_=c[ay>>2]|0;L63101:do{if((_|0)!=0){ax=0;while(1){if((ax|0)>=1024){break L63101}aA=9638528+(ax<<2)|0;if((c[aA>>2]|0)==0){break}else{ax=ax+1|0}}ax=gGq(_)|0;c[aA>>2]=ax;if((ax|0)==0){break}gGz(ax|0,0,_|0);do{if((c[3542200]|0)==0){aB=0}else{as=F+108|0;c[as>>2]=0;au=F+100|0;c[au>>2]=0;at=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[at&16383](F,aw)|0;if((c[as>>2]|0)!=0){as=c[au>>2]|0;c[G>>2]=9534384;au=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[au&16383](G,aw,0)|0;if((as|0)<1){aB=0;break}if((gzL(ax,0,aw)|0)!=0){aB=0;break}}as=c[ay>>2]&-2;if((as|0)>0){au=az;at=ax;ar=0;while(1){I=ar+2|0;H=au;c[H>>2]=c[9620648+((d[at+1|0]|0)<<2)>>2]<<1|c[9620648+((d[at]|0)<<2)>>2]|c[H>>2];if((I|0)<(as|0)){au=au+8|0;at=at+2|0;ar=I}else{aC=0;break}}}else{aC=0}while(1){if((aC|0)>=1024){break L63101}aD=9638528+(aC<<2)|0;if((c[aD>>2]|0)==(ax|0)){break}else{aC=aC+1|0}}gGr(ax);c[aD>>2]=0;break L63101}}while(0);while(1){if((aB|0)>=1024){break L63101}aE=9638528+(aB<<2)|0;if((c[aE>>2]|0)==(ax|0)){break}else{aB=aB+1|0}}gGr(ax);c[aE>>2]=0}}while(0);aE=(c[3542028]|0)+4|0;aB=a+4|0;aD=Z+100|0;c[aD>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](Z,aB)|0;Z=c[aD>>2]|0;L63125:do{if((Z|0)!=0){aC=0;while(1){if((aC|0)>=1024){break L63125}aF=9638528+(aC<<2)|0;if((c[aF>>2]|0)==0){break}else{aC=aC+1|0}}aC=gGq(Z)|0;c[aF>>2]=aC;if((aC|0)==0){break}gGz(aC|0,0,Z|0);do{if((c[3542200]|0)==0){aG=0}else{ax=D+108|0;c[ax>>2]=0;az=D+100|0;c[az>>2]=0;ay=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ay&16383](D,aB)|0;if((c[ax>>2]|0)!=0){ax=c[az>>2]|0;c[E>>2]=9534384;az=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[az&16383](E,aB,0)|0;if((ax|0)<1){aG=0;break}if((gzL(aC,0,aB)|0)!=0){aG=0;break}}ax=c[aD>>2]&-2;if((ax|0)>0){az=aE;ay=aC;aw=0;while(1){G=aw+1|0;F=az;c[F>>2]=c[F>>2]|c[9620648+((d[ay]|0)<<2)>>2]<<2;if((G|0)<(ax|0)){az=az+8|0;ay=ay+1|0;aw=G}else{aH=0;break}}}else{aH=0}while(1){if((aH|0)>=1024){break L63125}aI=9638528+(aH<<2)|0;if((c[aI>>2]|0)==(aC|0)){break}else{aH=aH+1|0}}gGr(aC);c[aI>>2]=0;break L63125}}while(0);while(1){if((aG|0)>=1024){break L63125}aJ=9638528+(aG<<2)|0;if((c[aJ>>2]|0)==(aC|0)){break}else{aG=aG+1|0}}gGr(aC);c[aJ>>2]=0}}while(0);aJ=(c[3542028]|0)+4|0;aG=a+5|0;aI=Y+100|0;c[aI>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](Y,aG)|0;Y=c[aI>>2]|0;L63149:do{if((Y|0)!=0){aH=0;while(1){if((aH|0)>=1024){break L63149}aK=9638528+(aH<<2)|0;if((c[aK>>2]|0)==0){break}else{aH=aH+1|0}}aH=gGq(Y)|0;c[aK>>2]=aH;if((aH|0)==0){break}gGz(aH|0,0,Y|0);do{if((c[3542200]|0)==0){aL=0}else{aC=B+108|0;c[aC>>2]=0;aE=B+100|0;c[aE>>2]=0;aD=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aD&16383](B,aG)|0;if((c[aC>>2]|0)!=0){aC=c[aE>>2]|0;c[C>>2]=9534384;aE=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aE&16383](C,aG,0)|0;if((aC|0)<1){aL=0;break}if((gzL(aH,0,aG)|0)!=0){aL=0;break}}aC=c[aI>>2]&-2;if((aC|0)>0){aE=aJ;aD=aH;aB=0;while(1){E=aB+1|0;D=aE;c[D>>2]=c[D>>2]|c[9620648+((d[aD]|0)<<2)>>2]<<3;if((E|0)<(aC|0)){aE=aE+8|0;aD=aD+1|0;aB=E}else{aM=0;break}}}else{aM=0}while(1){if((aM|0)>=1024){break L63149}aN=9638528+(aM<<2)|0;if((c[aN>>2]|0)==(aH|0)){break}else{aM=aM+1|0}}gGr(aH);c[aN>>2]=0;break L63149}}while(0);while(1){if((aL|0)>=1024){break L63149}aO=9638528+(aL<<2)|0;if((c[aO>>2]|0)==(aH|0)){break}else{aL=aL+1|0}}gGr(aH);c[aO>>2]=0}}while(0);aO=(c[3542028]|0)+1048576|0;aL=a+6|0;aN=X+100|0;c[aN>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](X,aL)|0;X=c[aN>>2]|0;L63173:do{if((X|0)!=0){aM=0;while(1){if((aM|0)>=1024){break L63173}aP=9638528+(aM<<2)|0;if((c[aP>>2]|0)==0){break}else{aM=aM+1|0}}aM=gGq(X)|0;c[aP>>2]=aM;if((aM|0)==0){break}gGz(aM|0,0,X|0);do{if((c[3542200]|0)==0){aQ=0}else{aH=z+108|0;c[aH>>2]=0;aJ=z+100|0;c[aJ>>2]=0;aI=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aI&16383](z,aL)|0;if((c[aH>>2]|0)!=0){aH=c[aJ>>2]|0;c[A>>2]=9534384;aJ=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aJ&16383](A,aL,0)|0;if((aH|0)<1){aQ=0;break}if((gzL(aM,0,aL)|0)!=0){aQ=0;break}}aH=c[aN>>2]&-2;if((aH|0)>0){aJ=aO;aI=aM;aG=0;while(1){C=aG+1|0;B=aJ;c[B>>2]=c[B>>2]|c[9620648+((d[aI]|0)<<2)>>2];if((C|0)<(aH|0)){aJ=aJ+8|0;aI=aI+1|0;aG=C}else{aR=0;break}}}else{aR=0}while(1){if((aR|0)>=1024){break L63173}aS=9638528+(aR<<2)|0;if((c[aS>>2]|0)==(aM|0)){break}else{aR=aR+1|0}}gGr(aM);c[aS>>2]=0;break L63173}}while(0);while(1){if((aQ|0)>=1024){break L63173}aT=9638528+(aQ<<2)|0;if((c[aT>>2]|0)==(aM|0)){break}else{aQ=aQ+1|0}}gGr(aM);c[aT>>2]=0}}while(0);aT=(c[3542028]|0)+1048576|0;aQ=a+7|0;aS=W+100|0;c[aS>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](W,aQ)|0;W=c[aS>>2]|0;L63197:do{if((W|0)!=0){aR=0;while(1){if((aR|0)>=1024){break L63197}aU=9638528+(aR<<2)|0;if((c[aU>>2]|0)==0){break}else{aR=aR+1|0}}aR=gGq(W)|0;c[aU>>2]=aR;if((aR|0)==0){break}gGz(aR|0,0,W|0);do{if((c[3542200]|0)==0){aV=0}else{aM=x+108|0;c[aM>>2]=0;aO=x+100|0;c[aO>>2]=0;aN=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aN&16383](x,aQ)|0;if((c[aM>>2]|0)!=0){aM=c[aO>>2]|0;c[y>>2]=9534384;aO=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aO&16383](y,aQ,0)|0;if((aM|0)<1){aV=0;break}if((gzL(aR,0,aQ)|0)!=0){aV=0;break}}aM=c[aS>>2]&-2;if((aM|0)>0){aO=aT;aN=aR;aL=0;while(1){A=aL+1|0;z=aO;c[z>>2]=c[z>>2]|c[9620648+((d[aN]|0)<<2)>>2]<<1;if((A|0)<(aM|0)){aO=aO+8|0;aN=aN+1|0;aL=A}else{aW=0;break}}}else{aW=0}while(1){if((aW|0)>=1024){break L63197}aX=9638528+(aW<<2)|0;if((c[aX>>2]|0)==(aR|0)){break}else{aW=aW+1|0}}gGr(aR);c[aX>>2]=0;break L63197}}while(0);while(1){if((aV|0)>=1024){break L63197}aY=9638528+(aV<<2)|0;if((c[aY>>2]|0)==(aR|0)){break}else{aV=aV+1|0}}gGr(aR);c[aY>>2]=0}}while(0);aY=(c[3542028]|0)+1048580|0;aV=a+8|0;aX=V+100|0;c[aX>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](V,aV)|0;V=c[aX>>2]|0;L63221:do{if((V|0)!=0){aW=0;while(1){if((aW|0)>=1024){break L63221}aZ=9638528+(aW<<2)|0;if((c[aZ>>2]|0)==0){break}else{aW=aW+1|0}}aW=gGq(V)|0;c[aZ>>2]=aW;if((aW|0)==0){break}gGz(aW|0,0,V|0);do{if((c[3542200]|0)==0){a_=0}else{aR=v+108|0;c[aR>>2]=0;aT=v+100|0;c[aT>>2]=0;aS=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aS&16383](v,aV)|0;if((c[aR>>2]|0)!=0){aR=c[aT>>2]|0;c[w>>2]=9534384;aT=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aT&16383](w,aV,0)|0;if((aR|0)<1){a_=0;break}if((gzL(aW,0,aV)|0)!=0){a_=0;break}}aR=c[aX>>2]&-2;if((aR|0)>0){aT=aY;aS=aW;aQ=0;while(1){y=aQ+1|0;x=aT;c[x>>2]=c[x>>2]|c[9620648+((d[aS]|0)<<2)>>2]<<2;if((y|0)<(aR|0)){aT=aT+8|0;aS=aS+1|0;aQ=y}else{a$=0;break}}}else{a$=0}while(1){if((a$|0)>=1024){break L63221}a0=9638528+(a$<<2)|0;if((c[a0>>2]|0)==(aW|0)){break}else{a$=a$+1|0}}gGr(aW);c[a0>>2]=0;break L63221}}while(0);while(1){if((a_|0)>=1024){break L63221}a1=9638528+(a_<<2)|0;if((c[a1>>2]|0)==(aW|0)){break}else{a_=a_+1|0}}gGr(aW);c[a1>>2]=0}}while(0);a1=(c[3542028]|0)+1048580|0;a_=a+9|0;a0=U+100|0;c[a0>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](U,a_)|0;U=c[a0>>2]|0;L63245:do{if((U|0)!=0){a$=0;while(1){if((a$|0)>=1024){break L63245}a2=9638528+(a$<<2)|0;if((c[a2>>2]|0)==0){break}else{a$=a$+1|0}}a$=gGq(U)|0;c[a2>>2]=a$;if((a$|0)==0){break}gGz(a$|0,0,U|0);do{if((c[3542200]|0)==0){a3=0}else{aW=t+108|0;c[aW>>2]=0;aY=t+100|0;c[aY>>2]=0;aX=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aX&16383](t,a_)|0;if((c[aW>>2]|0)!=0){aW=c[aY>>2]|0;c[u>>2]=9534384;aY=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aY&16383](u,a_,0)|0;if((aW|0)<1){a3=0;break}if((gzL(a$,0,a_)|0)!=0){a3=0;break}}aW=c[a0>>2]&-2;if((aW|0)>0){aY=a1;aX=a$;aV=0;while(1){w=aV+1|0;v=aY;c[v>>2]=c[v>>2]|c[9620648+((d[aX]|0)<<2)>>2]<<3;if((w|0)<(aW|0)){aY=aY+8|0;aX=aX+1|0;aV=w}else{a4=0;break}}}else{a4=0}while(1){if((a4|0)>=1024){break L63245}a5=9638528+(a4<<2)|0;if((c[a5>>2]|0)==(a$|0)){break}else{a4=a4+1|0}}gGr(a$);c[a5>>2]=0;break L63245}}while(0);while(1){if((a3|0)>=1024){break L63245}a6=9638528+(a3<<2)|0;if((c[a6>>2]|0)==(a$|0)){break}else{a3=a3+1|0}}gGr(a$);c[a6>>2]=0}}while(0);a6=(c[3542028]|0)+2097152|0;a3=a+10|0;a5=T+100|0;c[a5>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](T,a3)|0;T=c[a5>>2]|0;L63269:do{if((T|0)!=0){a4=0;while(1){if((a4|0)>=1024){break L63269}a7=9638528+(a4<<2)|0;if((c[a7>>2]|0)==0){break}else{a4=a4+1|0}}a4=gGq(T)|0;c[a7>>2]=a4;if((a4|0)==0){break}gGz(a4|0,0,T|0);do{if((c[3542200]|0)==0){a8=0}else{a$=r+108|0;c[a$>>2]=0;a1=r+100|0;c[a1>>2]=0;a0=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[a0&16383](r,a3)|0;if((c[a$>>2]|0)!=0){a$=c[a1>>2]|0;c[s>>2]=9534384;a1=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[a1&16383](s,a3,0)|0;if((a$|0)<1){a8=0;break}if((gzL(a4,0,a3)|0)!=0){a8=0;break}}a$=c[a5>>2]&-2;if((a$|0)>0){a1=a6;a0=a4;a_=0;while(1){u=a_+2|0;t=a1;c[t>>2]=c[9620648+((d[a0+1|0]|0)<<2)>>2]<<1|c[9620648+((d[a0]|0)<<2)>>2]|c[t>>2];if((u|0)<(a$|0)){a1=a1+8|0;a0=a0+2|0;a_=u}else{a9=0;break}}}else{a9=0}while(1){if((a9|0)>=1024){break L63269}ba=9638528+(a9<<2)|0;if((c[ba>>2]|0)==(a4|0)){break}else{a9=a9+1|0}}gGr(a4);c[ba>>2]=0;break L63269}}while(0);while(1){if((a8|0)>=1024){break L63269}bb=9638528+(a8<<2)|0;if((c[bb>>2]|0)==(a4|0)){break}else{a8=a8+1|0}}gGr(a4);c[bb>>2]=0}}while(0);bb=(c[3542028]|0)+2097152|0;a8=a+11|0;ba=S+100|0;c[ba>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](S,a8)|0;S=c[ba>>2]|0;L63293:do{if((S|0)!=0){a9=0;while(1){if((a9|0)>=1024){break L63293}bc=9638528+(a9<<2)|0;if((c[bc>>2]|0)==0){break}else{a9=a9+1|0}}a9=gGq(S)|0;c[bc>>2]=a9;if((a9|0)==0){break}gGz(a9|0,0,S|0);do{if((c[3542200]|0)==0){bd=0}else{a4=p+108|0;c[a4>>2]=0;a6=p+100|0;c[a6>>2]=0;a5=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[a5&16383](p,a8)|0;if((c[a4>>2]|0)!=0){a4=c[a6>>2]|0;c[q>>2]=9534384;a6=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[a6&16383](q,a8,0)|0;if((a4|0)<1){bd=0;break}if((gzL(a9,0,a8)|0)!=0){bd=0;break}}a4=c[ba>>2]&-2;if((a4|0)>0){a6=bb;a5=a9;a3=0;while(1){s=a3+1|0;r=a6;c[r>>2]=c[r>>2]|c[9620648+((d[a5]|0)<<2)>>2]<<2;if((s|0)<(a4|0)){a6=a6+8|0;a5=a5+1|0;a3=s}else{be=0;break}}}else{be=0}while(1){if((be|0)>=1024){break L63293}bf=9638528+(be<<2)|0;if((c[bf>>2]|0)==(a9|0)){break}else{be=be+1|0}}gGr(a9);c[bf>>2]=0;break L63293}}while(0);while(1){if((bd|0)>=1024){break L63293}bg=9638528+(bd<<2)|0;if((c[bg>>2]|0)==(a9|0)){break}else{bd=bd+1|0}}gGr(a9);c[bg>>2]=0}}while(0);bg=(c[3542028]|0)+2097152|0;bd=a+12|0;bf=R+100|0;c[bf>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](R,bd)|0;R=c[bf>>2]|0;L63317:do{if((R|0)!=0){be=0;while(1){if((be|0)>=1024){break L63317}bh=9638528+(be<<2)|0;if((c[bh>>2]|0)==0){break}else{be=be+1|0}}be=gGq(R)|0;c[bh>>2]=be;if((be|0)==0){break}gGz(be|0,0,R|0);do{if((c[3542200]|0)==0){bi=0}else{a9=n+108|0;c[a9>>2]=0;bb=n+100|0;c[bb>>2]=0;ba=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ba&16383](n,bd)|0;if((c[a9>>2]|0)!=0){a9=c[bb>>2]|0;c[o>>2]=9534384;bb=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[bb&16383](o,bd,0)|0;if((a9|0)<1){bi=0;break}if((gzL(be,0,bd)|0)!=0){bi=0;break}}a9=c[bf>>2]&-2;if((a9|0)>0){bb=bg;ba=be;a8=0;while(1){q=a8+1|0;p=bb;c[p>>2]=c[p>>2]|c[9620648+((d[ba]|0)<<2)>>2]<<3;if((q|0)<(a9|0)){bb=bb+8|0;ba=ba+1|0;a8=q}else{bj=0;break}}}else{bj=0}while(1){if((bj|0)>=1024){break L63317}bk=9638528+(bj<<2)|0;if((c[bk>>2]|0)==(be|0)){break}else{bj=bj+1|0}}gGr(be);c[bk>>2]=0;break L63317}}while(0);while(1){if((bi|0)>=1024){break L63317}bl=9638528+(bi<<2)|0;if((c[bl>>2]|0)==(be|0)){break}else{bi=bi+1|0}}gGr(be);c[bl>>2]=0}}while(0);bl=(c[3542028]|0)+2097156|0;bi=a+13|0;bk=Q+100|0;c[bk>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](Q,bi)|0;Q=c[bk>>2]|0;L63341:do{if((Q|0)!=0){bj=0;while(1){if((bj|0)>=1024){break L63341}bm=9638528+(bj<<2)|0;if((c[bm>>2]|0)==0){break}else{bj=bj+1|0}}bj=gGq(Q)|0;c[bm>>2]=bj;if((bj|0)==0){break}gGz(bj|0,0,Q|0);do{if((c[3542200]|0)==0){bn=0}else{be=l+108|0;c[be>>2]=0;bg=l+100|0;c[bg>>2]=0;bf=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[bf&16383](l,bi)|0;if((c[be>>2]|0)!=0){be=c[bg>>2]|0;c[m>>2]=9534384;bg=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[bg&16383](m,bi,0)|0;if((be|0)<1){bn=0;break}if((gzL(bj,0,bi)|0)!=0){bn=0;break}}be=c[bk>>2]&-2;if((be|0)>0){bg=bl;bf=bj;bd=0;while(1){o=bd+2|0;n=bg;c[n>>2]=c[9620648+((d[bf+1|0]|0)<<2)>>2]<<1|c[9620648+((d[bf]|0)<<2)>>2]|c[n>>2];if((o|0)<(be|0)){bg=bg+8|0;bf=bf+2|0;bd=o}else{bo=0;break}}}else{bo=0}while(1){if((bo|0)>=1024){break L63341}bp=9638528+(bo<<2)|0;if((c[bp>>2]|0)==(bj|0)){break}else{bo=bo+1|0}}gGr(bj);c[bp>>2]=0;break L63341}}while(0);while(1){if((bn|0)>=1024){break L63341}bq=9638528+(bn<<2)|0;if((c[bq>>2]|0)==(bj|0)){break}else{bn=bn+1|0}}gGr(bj);c[bq>>2]=0}}while(0);bq=(c[3542028]|0)+2097156|0;bn=a+14|0;bp=P+100|0;c[bp>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](P,bn)|0;P=c[bp>>2]|0;L63365:do{if((P|0)!=0){bo=0;while(1){if((bo|0)>=1024){break L63365}br=9638528+(bo<<2)|0;if((c[br>>2]|0)==0){break}else{bo=bo+1|0}}bo=gGq(P)|0;c[br>>2]=bo;if((bo|0)==0){break}gGz(bo|0,0,P|0);do{if((c[3542200]|0)==0){bs=0}else{bj=j+108|0;c[bj>>2]=0;bl=j+100|0;c[bl>>2]=0;bk=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[bk&16383](j,bn)|0;if((c[bj>>2]|0)!=0){bj=c[bl>>2]|0;c[k>>2]=9534384;bl=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[bl&16383](k,bn,0)|0;if((bj|0)<1){bs=0;break}if((gzL(bo,0,bn)|0)!=0){bs=0;break}}bj=c[bp>>2]&-2;if((bj|0)>0){bl=bq;bk=bo;bi=0;while(1){m=bi+2|0;l=bl;c[l>>2]=(c[9620648+((d[bk+1|0]|0)<<2)>>2]<<1|c[9620648+((d[bk]|0)<<2)>>2])<<2|c[l>>2];if((m|0)<(bj|0)){bl=bl+8|0;bk=bk+2|0;bi=m}else{bt=0;break}}}else{bt=0}while(1){if((bt|0)>=1024){break L63365}bu=9638528+(bt<<2)|0;if((c[bu>>2]|0)==(bo|0)){break}else{bt=bt+1|0}}gGr(bo);c[bu>>2]=0;break L63365}}while(0);while(1){if((bs|0)>=1024){break L63365}bv=9638528+(bs<<2)|0;if((c[bv>>2]|0)==(bo|0)){break}else{bs=bs+1|0}}gGr(bo);c[bv>>2]=0}}while(0);bv=(c[3542028]|0)+3145728|0;bs=a+15|0;bu=O+100|0;c[bu>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](O,bs)|0;O=c[bu>>2]|0;L63389:do{if((O|0)!=0){bt=0;while(1){if((bt|0)>=1024){break L63389}bw=9638528+(bt<<2)|0;if((c[bw>>2]|0)==0){break}else{bt=bt+1|0}}bt=gGq(O)|0;c[bw>>2]=bt;if((bt|0)==0){break}gGz(bt|0,0,O|0);do{if((c[3542200]|0)==0){bx=0}else{bo=g+108|0;c[bo>>2]=0;bq=g+100|0;c[bq>>2]=0;bp=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[bp&16383](g,bs)|0;if((c[bo>>2]|0)!=0){bo=c[bq>>2]|0;c[h>>2]=9534384;bq=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[bq&16383](h,bs,0)|0;if((bo|0)<1){bx=0;break}if((gzL(bt,0,bs)|0)!=0){bx=0;break}}bo=c[bu>>2]&-2;if((bo|0)>0){bq=bv;bp=bt;bn=0;while(1){k=bn+1|0;j=bq;c[j>>2]=c[j>>2]|c[9620648+((d[bp]|0)<<2)>>2]<<2;if((k|0)<(bo|0)){bq=bq+8|0;bp=bp+1|0;bn=k}else{by=0;break}}}else{by=0}while(1){if((by|0)>=1024){break L63389}bz=9638528+(by<<2)|0;if((c[bz>>2]|0)==(bt|0)){break}else{by=by+1|0}}gGr(bt);c[bz>>2]=0;break L63389}}while(0);while(1){if((bx|0)>=1024){break L63389}bA=9638528+(bx<<2)|0;if((c[bA>>2]|0)==(bt|0)){break}else{bx=bx+1|0}}gGr(bt);c[bA>>2]=0}}while(0);bA=(c[3542028]|0)+3145728|0;bx=a+16|0;a=N+100|0;c[a>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](N,bx)|0;N=c[a>>2]|0;if((N|0)==0){i=b;return 0}else{bB=0}while(1){if((bB|0)>=1024){bC=48934;break}bD=9638528+(bB<<2)|0;if((c[bD>>2]|0)==0){break}else{bB=bB+1|0}}if((bC|0)==48934){i=b;return 0}bB=gGq(N)|0;c[bD>>2]=bB;if((bB|0)==0){i=b;return 0}gGz(bB|0,0,N|0);do{if((c[3542200]|0)==0){bE=0}else{N=e+108|0;c[N>>2]=0;bD=e+100|0;c[bD>>2]=0;bz=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[bz&16383](e,bx)|0;if((c[N>>2]|0)!=0){N=c[bD>>2]|0;c[f>>2]=9534384;bD=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[bD&16383](f,bx,0)|0;if((N|0)<1){bE=0;break}if((gzL(bB,0,bx)|0)!=0){bE=0;break}}N=c[a>>2]&-2;if((N|0)>0){bD=bA;bz=bB;by=0;while(1){bv=by+1|0;bu=bD;c[bu>>2]=c[bu>>2]|c[9620648+((d[bz]|0)<<2)>>2]<<3;if((bv|0)<(N|0)){bD=bD+8|0;bz=bz+1|0;by=bv}else{bF=0;break}}}else{bF=0}while(1){if((bF|0)>=1024){bC=48931;break}bG=9638528+(bF<<2)|0;if((c[bG>>2]|0)==(bB|0)){break}else{bF=bF+1|0}}if((bC|0)==48931){i=b;return 0}gGr(bB);c[bG>>2]=0;i=b;return 0}}while(0);while(1){if((bE|0)>=1024){bC=48936;break}bH=9638528+(bE<<2)|0;if((c[bH>>2]|0)==(bB|0)){break}else{bE=bE+1|0}}if((bC|0)==48936){i=b;return 0}gGr(bB);c[bH>>2]=0;i=b;return 0}function V_(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=i;i=i+232|0;g=f|0;h=f+112|0;j=f+120|0;k=j+100|0;c[k>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,b)|0;j=c[k>>2]|0;if((j|0)==0){i=f;return}else{l=0}while(1){if((l|0)>=1024){m=48958;break}n=9638528+(l<<2)|0;if((c[n>>2]|0)==0){break}else{l=l+1|0}}if((m|0)==48958){i=f;return}l=gGq(j)|0;c[n>>2]=l;if((l|0)==0){i=f;return}gGz(l|0,0,j|0);do{if((c[3542200]|0)==0){o=0}else{j=g+108|0;c[j>>2]=0;n=g+100|0;c[n>>2]=0;p=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[p&16383](g,b)|0;if((c[j>>2]|0)!=0){j=c[n>>2]|0;c[h>>2]=9534384;n=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[n&16383](h,b,0)|0;if((j|0)<1){o=0;break}if((gzL(l,0,b)|0)!=0){o=0;break}}j=c[k>>2]>>1;if((j|0)>0){n=a;p=l;q=0;while(1){r=q+2|0;s=n;c[s>>2]=(c[9620648+((d[p+1|0]|0)<<2)>>2]<<1|c[9620648+((d[p]|0)<<2)>>2])<<e|c[s>>2];if((r|0)<(j|0)){n=n+8|0;p=p+2|0;q=r}else{break}}q=a+4|0;p=l+j|0;n=0;while(1){r=n+2|0;s=q;c[s>>2]=(c[9620648+((d[p+1|0]|0)<<2)>>2]<<1|c[9620648+((d[p]|0)<<2)>>2])<<e|c[s>>2];if((r|0)<(j|0)){q=q+8|0;p=p+2|0;n=r}else{t=0;break}}}else{t=0}while(1){if((t|0)>=1024){m=48956;break}u=9638528+(t<<2)|0;if((c[u>>2]|0)==(l|0)){break}else{t=t+1|0}}if((m|0)==48956){i=f;return}gGr(l);c[u>>2]=0;i=f;return}}while(0);while(1){if((o|0)>=1024){m=48962;break}v=9638528+(o<<2)|0;if((c[v>>2]|0)==(l|0)){break}else{o=o+1|0}}if((m|0)==48962){i=f;return}gGr(l);c[v>>2]=0;i=f;return}function V$(a){a=a|0;V0(c[3542028]|0,a,0);return 0}function V0(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;f=i;i=i+480|0;g=f|0;h=f+112|0;j=f+120|0;k=f+232|0;l=f+240|0;m=f+352|0;n=f+464|0;o=m+100|0;c[o>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,b)|0;m=c[o>>2]|0;if((m|0)==0){i=f;return}else{p=0}while(1){if((p|0)>=1024){q=49005;break}r=9638528+(p<<2)|0;if((c[r>>2]|0)==0){break}else{p=p+1|0}}if((q|0)==49005){i=f;return}p=gGq(m)|0;c[r>>2]=p;if((p|0)==0){i=f;return}gGz(p|0,0,m|0);do{if((c[3542200]|0)==0){s=0}else{m=j+108|0;c[m>>2]=0;r=j+100|0;c[r>>2]=0;o=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[o&16383](j,b)|0;if((c[m>>2]|0)!=0){m=c[r>>2]|0;c[k>>2]=9534384;r=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[r&16383](k,b,0)|0;if((m|0)<1){s=0;break}if((gzL(p,0,b)|0)!=0){s=0;break}}m=b+1|0;r=l+100|0;c[r>>2]=0;o=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[o&16383](l,m)|0;o=c[r>>2]|0;if((o|0)==0){i=f;return}else{t=0}while(1){if((t|0)>=1024){q=49009;break}u=9638528+(t<<2)|0;if((c[u>>2]|0)==0){break}else{t=t+1|0}}if((q|0)==49009){i=f;return}r=gGq(o)|0;c[u>>2]=r;if((r|0)==0){i=f;return}gGz(r|0,0,o|0);do{if((c[3542200]|0)==0){v=0}else{w=g+108|0;c[w>>2]=0;x=g+100|0;c[x>>2]=0;y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[y&16383](g,m)|0;if((c[w>>2]|0)!=0){w=c[x>>2]|0;c[h>>2]=9534384;x=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[x&16383](h,m,0)|0;if((w|0)<1){v=0;break}if((gzL(r,0,m)|0)!=0){v=0;break}}w=n;c[w>>2]=c[414500];c[w+4>>2]=c[414501];c[w+8>>2]=c[414502];c[w+12>>2]=c[414503];if((e|0)==1){c[n+4>>2]=2097152;c[n+8>>2]=4;z=0}else{z=0}while(1){w=n+(z<<2)|0;x=z<<19;y=0;A=a+(c[w>>2]|0)|0;B=p+x|0;while(1){C=y+2|0;D=A;c[D>>2]=c[9620648+((d[B+1|0]|0)<<2)>>2]<<1|c[9620648+((d[B]|0)<<2)>>2]|c[D>>2];if((C|0)<524288){y=C;A=A+8|0;B=B+2|0}else{break}}B=0;A=a+(c[w>>2]|0)|0;y=r+x|0;while(1){C=B+2|0;D=A;c[D>>2]=(c[9620648+((d[y+1|0]|0)<<2)>>2]<<1|c[9620648+((d[y]|0)<<2)>>2])<<2|c[D>>2];if((C|0)<524288){B=C;A=A+8|0;y=y+2|0}else{break}}y=z+1|0;if((y|0)<4){z=y}else{E=0;break}}while(1){if((E|0)>=1024){F=0;break}G=9638528+(E<<2)|0;if((c[G>>2]|0)==(r|0)){q=48995;break}else{E=E+1|0}}if((q|0)==48995){gGr(r);c[G>>2]=0;F=0}while(1){if((F|0)>=1024){q=49010;break}H=9638528+(F<<2)|0;if((c[H>>2]|0)==(p|0)){break}else{F=F+1|0}}if((q|0)==49010){i=f;return}gGr(p);c[H>>2]=0;i=f;return}}while(0);while(1){if((v|0)>=1024){q=49011;break}I=9638528+(v<<2)|0;if((c[I>>2]|0)==(r|0)){break}else{v=v+1|0}}if((q|0)==49011){i=f;return}gGr(r);c[I>>2]=0;i=f;return}}while(0);while(1){if((s|0)>=1024){q=49007;break}J=9638528+(s<<2)|0;if((c[J>>2]|0)==(p|0)){break}else{s=s+1|0}}if((q|0)==49007){i=f;return}gGr(p);c[J>>2]=0;i=f;return}function V1(a){a=a|0;V0(c[3542028]|0,a,1);return 0}function V2(a){a=a|0;V_(c[3542028]|0,a,0);V_(c[3542028]|0,a+1|0,2);V_((c[3542028]|0)+2097152|0,a+2|0,0);V_((c[3542028]|0)+2097152|0,a+3|0,2);V_((c[3542028]|0)+4194304|0,a+4|0,0);V_((c[3542028]|0)+4194304|0,a+5|0,2);return 0}function V3(a){a=a|0;V4(c[3542028]|0,a,0);V4(c[3542028]|0,a+1|0,2);V4((c[3542028]|0)+2097152|0,a+2|0,0);V4((c[3542028]|0)+2097152|0,a+3|0,2);V4((c[3542028]|0)+4194304|0,a+4|0,0);V4((c[3542028]|0)+4194304|0,a+5|0,2);return 0}function V4(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=i;i=i+232|0;g=f|0;h=f+112|0;j=f+120|0;k=j+100|0;c[k>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,b)|0;j=c[k>>2]|0;if((j|0)==0){i=f;return}else{l=0}while(1){if((l|0)>=1024){m=49038;break}n=9638528+(l<<2)|0;if((c[n>>2]|0)==0){break}else{l=l+1|0}}if((m|0)==49038){i=f;return}l=gGq(j)|0;c[n>>2]=l;if((l|0)==0){i=f;return}gGz(l|0,0,j|0);do{if((c[3542200]|0)==0){o=0}else{j=g+108|0;c[j>>2]=0;n=g+100|0;c[n>>2]=0;p=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[p&16383](g,b)|0;if((c[j>>2]|0)!=0){j=c[n>>2]|0;c[h>>2]=9534384;n=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[n&16383](h,b,0)|0;if((j|0)<1){o=0;break}if((gzL(l,0,b)|0)!=0){o=0;break}}j=c[k>>2]>>1;if((j|0)>0){n=a;p=l+j|0;q=0;while(1){r=q+2|0;s=n;c[s>>2]=(c[9620648+((d[p+1|0]|0)<<2)>>2]<<1|c[9620648+((d[p]|0)<<2)>>2])<<e|c[s>>2];if((r|0)<(j|0)){n=n+8|0;p=p+2|0;q=r}else{break}}q=a+4|0;p=l;n=0;while(1){r=n+2|0;s=q;c[s>>2]=(c[9620648+((d[p+1|0]|0)<<2)>>2]<<1|c[9620648+((d[p]|0)<<2)>>2])<<e|c[s>>2];if((r|0)<(j|0)){q=q+8|0;p=p+2|0;n=r}else{t=0;break}}}else{t=0}while(1){if((t|0)>=1024){m=49035;break}u=9638528+(t<<2)|0;if((c[u>>2]|0)==(l|0)){break}else{t=t+1|0}}if((m|0)==49035){i=f;return}gGr(l);c[u>>2]=0;i=f;return}}while(0);while(1){if((o|0)>=1024){m=49037;break}v=9638528+(o<<2)|0;if((c[v>>2]|0)==(l|0)){break}else{o=o+1|0}}if((m|0)==49037){i=f;return}gGr(l);c[v>>2]=0;i=f;return}function V5(a){a=a|0;V6(c[3542028]|0,a);V6((c[3542028]|0)+2097152|0,a+4|0);V6((c[3542028]|0)+4194304|0,a+8|0);return 0}function V6(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;e=i;i=i+928|0;f=e|0;g=e+112|0;h=e+120|0;j=e+232|0;k=e+240|0;l=e+352|0;m=e+360|0;n=e+472|0;o=e+480|0;p=e+592|0;q=e+704|0;r=e+816|0;s=r+100|0;c[s>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,b)|0;r=c[s>>2]|0;L63601:do{if((r|0)!=0){t=0;while(1){if((t|0)>=1024){break L63601}u=9638528+(t<<2)|0;if((c[u>>2]|0)==0){break}else{t=t+1|0}}t=gGq(r)|0;c[u>>2]=t;if((t|0)==0){break}gGz(t|0,0,r|0);do{if((c[3542200]|0)==0){v=0}else{w=m+108|0;c[w>>2]=0;x=m+100|0;c[x>>2]=0;y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[y&16383](m,b)|0;if((c[w>>2]|0)!=0){w=c[x>>2]|0;c[n>>2]=9534384;x=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[x&16383](n,b,0)|0;if((w|0)<1){v=0;break}if((gzL(t,0,b)|0)!=0){v=0;break}}w=c[s>>2]&-2;if((w|0)>0){x=a;y=t;z=0;while(1){A=z+1|0;B=x;c[B>>2]=c[B>>2]|c[9620648+((d[y]|0)<<2)>>2];if((A|0)<(w|0)){x=x+4|0;y=y+1|0;z=A}else{C=0;break}}}else{C=0}while(1){if((C|0)>=1024){break L63601}D=9638528+(C<<2)|0;if((c[D>>2]|0)==(t|0)){break}else{C=C+1|0}}gGr(t);c[D>>2]=0;break L63601}}while(0);while(1){if((v|0)>=1024){break L63601}E=9638528+(v<<2)|0;if((c[E>>2]|0)==(t|0)){break}else{v=v+1|0}}gGr(t);c[E>>2]=0}}while(0);E=b+1|0;v=q+100|0;c[v>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](q,E)|0;q=c[v>>2]|0;L63625:do{if((q|0)!=0){D=0;while(1){if((D|0)>=1024){break L63625}F=9638528+(D<<2)|0;if((c[F>>2]|0)==0){break}else{D=D+1|0}}D=gGq(q)|0;c[F>>2]=D;if((D|0)==0){break}gGz(D|0,0,q|0);do{if((c[3542200]|0)==0){G=0}else{t=k+108|0;c[t>>2]=0;C=k+100|0;c[C>>2]=0;s=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[s&16383](k,E)|0;if((c[t>>2]|0)!=0){t=c[C>>2]|0;c[l>>2]=9534384;C=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[C&16383](l,E,0)|0;if((t|0)<1){G=0;break}if((gzL(D,0,E)|0)!=0){G=0;break}}t=c[v>>2]&-2;if((t|0)>0){C=a;s=D;n=0;while(1){m=n+1|0;r=C;c[r>>2]=c[r>>2]|c[9620648+((d[s]|0)<<2)>>2]<<1;if((m|0)<(t|0)){C=C+4|0;s=s+1|0;n=m}else{H=0;break}}}else{H=0}while(1){if((H|0)>=1024){break L63625}I=9638528+(H<<2)|0;if((c[I>>2]|0)==(D|0)){break}else{H=H+1|0}}gGr(D);c[I>>2]=0;break L63625}}while(0);while(1){if((G|0)>=1024){break L63625}J=9638528+(G<<2)|0;if((c[J>>2]|0)==(D|0)){break}else{G=G+1|0}}gGr(D);c[J>>2]=0}}while(0);J=b+2|0;G=p+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](p,J)|0;p=c[G>>2]|0;L63649:do{if((p|0)!=0){I=0;while(1){if((I|0)>=1024){break L63649}K=9638528+(I<<2)|0;if((c[K>>2]|0)==0){break}else{I=I+1|0}}I=gGq(p)|0;c[K>>2]=I;if((I|0)==0){break}gGz(I|0,0,p|0);do{if((c[3542200]|0)==0){L=0}else{D=h+108|0;c[D>>2]=0;H=h+100|0;c[H>>2]=0;v=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[v&16383](h,J)|0;if((c[D>>2]|0)!=0){D=c[H>>2]|0;c[j>>2]=9534384;H=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[H&16383](j,J,0)|0;if((D|0)<1){L=0;break}if((gzL(I,0,J)|0)!=0){L=0;break}}D=c[G>>2]&-2;if((D|0)>0){H=a;v=I;E=0;while(1){l=E+1|0;k=H;c[k>>2]=c[k>>2]|c[9620648+((d[v]|0)<<2)>>2]<<2;if((l|0)<(D|0)){H=H+4|0;v=v+1|0;E=l}else{M=0;break}}}else{M=0}while(1){if((M|0)>=1024){break L63649}N=9638528+(M<<2)|0;if((c[N>>2]|0)==(I|0)){break}else{M=M+1|0}}gGr(I);c[N>>2]=0;break L63649}}while(0);while(1){if((L|0)>=1024){break L63649}O=9638528+(L<<2)|0;if((c[O>>2]|0)==(I|0)){break}else{L=L+1|0}}gGr(I);c[O>>2]=0}}while(0);O=b+3|0;b=o+100|0;c[b>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](o,O)|0;o=c[b>>2]|0;if((o|0)==0){i=e;return}else{P=0}while(1){if((P|0)>=1024){Q=49110;break}R=9638528+(P<<2)|0;if((c[R>>2]|0)==0){break}else{P=P+1|0}}if((Q|0)==49110){i=e;return}P=gGq(o)|0;c[R>>2]=P;if((P|0)==0){i=e;return}gGz(P|0,0,o|0);do{if((c[3542200]|0)==0){S=0}else{o=f+108|0;c[o>>2]=0;R=f+100|0;c[R>>2]=0;L=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[L&16383](f,O)|0;if((c[o>>2]|0)!=0){o=c[R>>2]|0;c[g>>2]=9534384;R=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[R&16383](g,O,0)|0;if((o|0)<1){S=0;break}if((gzL(P,0,O)|0)!=0){S=0;break}}o=c[b>>2]&-2;if((o|0)>0){R=a;L=P;N=0;while(1){M=N+1|0;G=R;c[G>>2]=c[G>>2]|c[9620648+((d[L]|0)<<2)>>2]<<3;if((M|0)<(o|0)){R=R+4|0;L=L+1|0;N=M}else{T=0;break}}}else{T=0}while(1){if((T|0)>=1024){Q=49109;break}U=9638528+(T<<2)|0;if((c[U>>2]|0)==(P|0)){break}else{T=T+1|0}}if((Q|0)==49109){i=e;return}gGr(P);c[U>>2]=0;i=e;return}}while(0);while(1){if((S|0)>=1024){Q=49114;break}V=9638528+(S<<2)|0;if((c[V>>2]|0)==(P|0)){break}else{S=S+1|0}}if((Q|0)==49114){i=e;return}gGr(P);c[V>>2]=0;i=e;return}function V7(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0;b=i;i=i+1392|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;l=b+360|0;m=b+472|0;n=b+480|0;o=b+592|0;p=b+600|0;q=b+712|0;r=b+720|0;s=b+832|0;t=b+944|0;u=b+1056|0;v=b+1168|0;w=b+1280|0;x=c[3542028]|0;y=w+100|0;c[y>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](w,a)|0;w=c[y>>2]|0;L63708:do{if((w|0)!=0){z=0;while(1){if((z|0)>=1024){break L63708}A=9638528+(z<<2)|0;if((c[A>>2]|0)==0){break}else{z=z+1|0}}z=gGq(w)|0;c[A>>2]=z;if((z|0)==0){break}gGz(z|0,0,w|0);do{if((c[3542200]|0)==0){B=0}else{C=p+108|0;c[C>>2]=0;D=p+100|0;c[D>>2]=0;E=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[E&16383](p,a)|0;if((c[C>>2]|0)!=0){C=c[D>>2]|0;c[q>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](q,a,0)|0;if((C|0)<1){B=0;break}if((gzL(z,0,a)|0)!=0){B=0;break}}C=c[y>>2]&-2;if((C|0)>0){D=x;E=z;F=0;while(1){G=D;H=c[G>>2]|c[9620648+((d[E]|0)<<2)>>2];c[G>>2]=H;I=F+2|0;c[G>>2]=c[9620648+((d[E+1|0]|0)<<2)>>2]<<1|H;if((I|0)<(C|0)){D=D+4|0;E=E+2|0;F=I}else{J=0;break}}}else{J=0}while(1){if((J|0)>=1024){break L63708}K=9638528+(J<<2)|0;if((c[K>>2]|0)==(z|0)){break}else{J=J+1|0}}gGr(z);c[K>>2]=0;break L63708}}while(0);while(1){if((B|0)>=1024){break L63708}L=9638528+(B<<2)|0;if((c[L>>2]|0)==(z|0)){break}else{B=B+1|0}}gGr(z);c[L>>2]=0}}while(0);L=c[3542028]|0;B=a+1|0;K=v+100|0;c[K>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,B)|0;v=c[K>>2]|0;L63732:do{if((v|0)!=0){J=0;while(1){if((J|0)>=1024){break L63732}M=9638528+(J<<2)|0;if((c[M>>2]|0)==0){break}else{J=J+1|0}}J=gGq(v)|0;c[M>>2]=J;if((J|0)==0){break}gGz(J|0,0,v|0);do{if((c[3542200]|0)==0){N=0}else{z=n+108|0;c[z>>2]=0;x=n+100|0;c[x>>2]=0;y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[y&16383](n,B)|0;if((c[z>>2]|0)!=0){z=c[x>>2]|0;c[o>>2]=9534384;x=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[x&16383](o,B,0)|0;if((z|0)<1){N=0;break}if((gzL(J,0,B)|0)!=0){N=0;break}}z=c[K>>2]&-2;if((z|0)>0){x=L;y=J;q=0;while(1){p=x;w=c[p>>2]|c[9620648+((d[y]|0)<<2)>>2]<<2;c[p>>2]=w;A=q+2|0;c[p>>2]=c[9620648+((d[y+1|0]|0)<<2)>>2]<<3|w;if((A|0)<(z|0)){x=x+4|0;y=y+2|0;q=A}else{O=0;break}}}else{O=0}while(1){if((O|0)>=1024){break L63732}P=9638528+(O<<2)|0;if((c[P>>2]|0)==(J|0)){break}else{O=O+1|0}}gGr(J);c[P>>2]=0;break L63732}}while(0);while(1){if((N|0)>=1024){break L63732}Q=9638528+(N<<2)|0;if((c[Q>>2]|0)==(J|0)){break}else{N=N+1|0}}gGr(J);c[Q>>2]=0}}while(0);Q=(c[3542028]|0)+2097152|0;N=a+2|0;P=u+100|0;c[P>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](u,N)|0;u=c[P>>2]|0;L63756:do{if((u|0)!=0){O=0;while(1){if((O|0)>=1024){break L63756}R=9638528+(O<<2)|0;if((c[R>>2]|0)==0){break}else{O=O+1|0}}O=gGq(u)|0;c[R>>2]=O;if((O|0)==0){break}gGz(O|0,0,u|0);do{if((c[3542200]|0)==0){S=0}else{J=l+108|0;c[J>>2]=0;L=l+100|0;c[L>>2]=0;K=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[K&16383](l,N)|0;if((c[J>>2]|0)!=0){J=c[L>>2]|0;c[m>>2]=9534384;L=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[L&16383](m,N,0)|0;if((J|0)<1){S=0;break}if((gzL(O,0,N)|0)!=0){S=0;break}}J=c[P>>2]&-2;if((J|0)>0){L=Q;K=O;B=0;while(1){o=L;n=c[o>>2]|c[9620648+((d[K]|0)<<2)>>2];c[o>>2]=n;v=B+2|0;c[o>>2]=c[9620648+((d[K+1|0]|0)<<2)>>2]<<1|n;if((v|0)<(J|0)){L=L+4|0;K=K+2|0;B=v}else{T=0;break}}}else{T=0}while(1){if((T|0)>=1024){break L63756}U=9638528+(T<<2)|0;if((c[U>>2]|0)==(O|0)){break}else{T=T+1|0}}gGr(O);c[U>>2]=0;break L63756}}while(0);while(1){if((S|0)>=1024){break L63756}V=9638528+(S<<2)|0;if((c[V>>2]|0)==(O|0)){break}else{S=S+1|0}}gGr(O);c[V>>2]=0}}while(0);V=(c[3542028]|0)+2097152|0;S=a+3|0;U=t+100|0;c[U>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](t,S)|0;t=c[U>>2]|0;L63780:do{if((t|0)!=0){T=0;while(1){if((T|0)>=1024){break L63780}W=9638528+(T<<2)|0;if((c[W>>2]|0)==0){break}else{T=T+1|0}}T=gGq(t)|0;c[W>>2]=T;if((T|0)==0){break}gGz(T|0,0,t|0);do{if((c[3542200]|0)==0){X=0}else{O=j+108|0;c[O>>2]=0;Q=j+100|0;c[Q>>2]=0;P=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[P&16383](j,S)|0;if((c[O>>2]|0)!=0){O=c[Q>>2]|0;c[k>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](k,S,0)|0;if((O|0)<1){X=0;break}if((gzL(T,0,S)|0)!=0){X=0;break}}O=c[U>>2]&-2;if((O|0)>0){Q=V;P=T;N=0;while(1){m=Q;l=c[m>>2]|c[9620648+((d[P]|0)<<2)>>2]<<2;c[m>>2]=l;u=N+2|0;c[m>>2]=c[9620648+((d[P+1|0]|0)<<2)>>2]<<3|l;if((u|0)<(O|0)){Q=Q+4|0;P=P+2|0;N=u}else{Y=0;break}}}else{Y=0}while(1){if((Y|0)>=1024){break L63780}Z=9638528+(Y<<2)|0;if((c[Z>>2]|0)==(T|0)){break}else{Y=Y+1|0}}gGr(T);c[Z>>2]=0;break L63780}}while(0);while(1){if((X|0)>=1024){break L63780}_=9638528+(X<<2)|0;if((c[_>>2]|0)==(T|0)){break}else{X=X+1|0}}gGr(T);c[_>>2]=0}}while(0);_=(c[3542028]|0)+4194304|0;X=a+4|0;Z=s+100|0;c[Z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](s,X)|0;s=c[Z>>2]|0;L63804:do{if((s|0)!=0){Y=0;while(1){if((Y|0)>=1024){break L63804}$=9638528+(Y<<2)|0;if((c[$>>2]|0)==0){break}else{Y=Y+1|0}}Y=gGq(s)|0;c[$>>2]=Y;if((Y|0)==0){break}gGz(Y|0,0,s|0);do{if((c[3542200]|0)==0){aa=0}else{T=g+108|0;c[T>>2]=0;V=g+100|0;c[V>>2]=0;U=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[U&16383](g,X)|0;if((c[T>>2]|0)!=0){T=c[V>>2]|0;c[h>>2]=9534384;V=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[V&16383](h,X,0)|0;if((T|0)<1){aa=0;break}if((gzL(Y,0,X)|0)!=0){aa=0;break}}T=c[Z>>2]&-2;if((T|0)>0){V=_;U=Y;S=0;while(1){k=V;j=c[k>>2]|c[9620648+((d[U]|0)<<2)>>2];c[k>>2]=j;t=S+2|0;c[k>>2]=c[9620648+((d[U+1|0]|0)<<2)>>2]<<1|j;if((t|0)<(T|0)){V=V+4|0;U=U+2|0;S=t}else{ab=0;break}}}else{ab=0}while(1){if((ab|0)>=1024){break L63804}ac=9638528+(ab<<2)|0;if((c[ac>>2]|0)==(Y|0)){break}else{ab=ab+1|0}}gGr(Y);c[ac>>2]=0;break L63804}}while(0);while(1){if((aa|0)>=1024){break L63804}ad=9638528+(aa<<2)|0;if((c[ad>>2]|0)==(Y|0)){break}else{aa=aa+1|0}}gGr(Y);c[ad>>2]=0}}while(0);ad=(c[3542028]|0)+4194304|0;aa=a+5|0;a=r+100|0;c[a>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](r,aa)|0;r=c[a>>2]|0;if((r|0)==0){i=b;return 0}else{ae=0}while(1){if((ae|0)>=1024){af=49215;break}ag=9638528+(ae<<2)|0;if((c[ag>>2]|0)==0){break}else{ae=ae+1|0}}if((af|0)==49215){i=b;return 0}ae=gGq(r)|0;c[ag>>2]=ae;if((ae|0)==0){i=b;return 0}gGz(ae|0,0,r|0);do{if((c[3542200]|0)==0){ah=0}else{r=e+108|0;c[r>>2]=0;ag=e+100|0;c[ag>>2]=0;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ac&16383](e,aa)|0;if((c[r>>2]|0)!=0){r=c[ag>>2]|0;c[f>>2]=9534384;ag=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ag&16383](f,aa,0)|0;if((r|0)<1){ah=0;break}if((gzL(ae,0,aa)|0)!=0){ah=0;break}}r=c[a>>2]&-2;if((r|0)>0){ag=ad;ac=ae;ab=0;while(1){_=ag;Z=c[_>>2]|c[9620648+((d[ac]|0)<<2)>>2]<<2;c[_>>2]=Z;X=ab+2|0;c[_>>2]=c[9620648+((d[ac+1|0]|0)<<2)>>2]<<3|Z;if((X|0)<(r|0)){ag=ag+4|0;ac=ac+2|0;ab=X}else{ai=0;break}}}else{ai=0}while(1){if((ai|0)>=1024){af=49216;break}aj=9638528+(ai<<2)|0;if((c[aj>>2]|0)==(ae|0)){break}else{ai=ai+1|0}}if((af|0)==49216){i=b;return 0}gGr(ae);c[aj>>2]=0;i=b;return 0}}while(0);while(1){if((ah|0)>=1024){af=49218;break}ak=9638528+(ah<<2)|0;if((c[ak>>2]|0)==(ae|0)){break}else{ah=ah+1|0}}if((af|0)==49218){i=b;return 0}gGr(ae);c[ak>>2]=0;i=b;return 0}function V8(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;e=i;i=i+240|0;f=e|0;g=e+112|0;h=e+120|0;j=e+232|0;V9(c[3542028]|0,b,0);V9(c[3542028]|0,b+1|0,1);V9(c[3542028]|0,b+2|0,2);V9(c[3542028]|0,b+3|0,3);k=c[3542028]|0;l=k+4194304|0;m=0;while(1){if((m|0)>=1024){n=0;break}o=9638528+(m<<2)|0;if((c[o>>2]|0)==0){p=49222;break}else{m=m+1|0}}do{if((p|0)==49222){m=gGq(2097152)|0;c[o>>2]=m;if((m|0)==0){n=0;break}gGz(m|0,0,2097152);n=m}}while(0);o=0;while(1){if((o|0)>=1024){q=0;break}r=9638528+(o<<2)|0;if((c[r>>2]|0)==0){p=49227;break}else{o=o+1|0}}do{if((p|0)==49227){o=gGq(2097152)|0;c[r>>2]=o;if((o|0)==0){q=0;break}gGz(o|0,0,2097152);q=o}}while(0);if((n|0)==0){i=e;return 0}r=b+4|0;do{if((c[3542200]|0)==0){s=0}else{o=h+108|0;c[o>>2]=0;m=h+100|0;c[m>>2]=0;t=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[t&16383](h,r)|0;if((c[o>>2]|0)!=0){o=c[m>>2]|0;c[j>>2]=9534384;m=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[m&16383](j,r,0)|0;if((o|0)<1){s=0;break}if((gzL(q,0,r)|0)!=0){s=0;break}}o=q+1048576|0;m=b+5|0;do{if((c[3542200]|0)==0){u=0}else{t=f+108|0;c[t>>2]=0;v=f+100|0;c[v>>2]=0;w=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[w&16383](f,m)|0;if((c[t>>2]|0)==0){x=0}else{t=c[v>>2]|0;c[g>>2]=9534384;v=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[v&16383](g,m,0)|0;if((t|0)<1){u=0;break}if((gzL(o,0,m)|0)==0){x=0}else{u=0;break}}while(1){a[n+x|0]=a[q+x|0]|0;t=x+1048576|0;v=x|1;a[n+v|0]=a[q+t|0]|0;a[n+t|0]=a[q+v|0]|0;v=x+1048577|0;a[n+v|0]=a[q+v|0]|0;v=x+2|0;if((v|0)<1048576){x=v}else{y=0;break}}while(1){if((y|0)>=1024){z=0;A=n;B=l;break}C=9638528+(y<<2)|0;if((c[C>>2]|0)==(q|0)){p=49247;break}else{y=y+1|0}}if((p|0)==49247){gGr(q);c[C>>2]=0;z=0;A=n;B=l}while(1){v=z+2|0;t=B;c[t>>2]=c[9620648+((d[A+1|0]|0)<<2)>>2]<<1|c[9620648+((d[A]|0)<<2)>>2]|c[t>>2];if((v|0)<524288){z=v;A=A+2|0;B=B+8|0}else{break}}v=k+4194308|0;t=0;w=n+524288|0;D=v;while(1){E=t+2|0;F=D;c[F>>2]=c[9620648+((d[w+1|0]|0)<<2)>>2]<<1|c[9620648+((d[w]|0)<<2)>>2]|c[F>>2];if((E|0)<524288){t=E;w=w+2|0;D=D+8|0}else{break}}D=0;w=n+1048576|0;t=l;while(1){E=D+2|0;F=t;c[F>>2]=(c[9620648+((d[w+1|0]|0)<<2)>>2]<<1|c[9620648+((d[w]|0)<<2)>>2])<<2|c[F>>2];if((E|0)<524288){D=E;w=w+2|0;t=t+8|0}else{break}}t=0;w=n+1572864|0;D=v;while(1){E=t+2|0;F=D;c[F>>2]=(c[9620648+((d[w+1|0]|0)<<2)>>2]<<1|c[9620648+((d[w]|0)<<2)>>2])<<2|c[F>>2];if((E|0)<524288){t=E;w=w+2|0;D=D+8|0}else{G=0;break}}while(1){if((G|0)>=1024){p=49259;break}H=9638528+(G<<2)|0;if((c[H>>2]|0)==(n|0)){break}else{G=G+1|0}}if((p|0)==49259){i=e;return 0}gGr(n);c[H>>2]=0;i=e;return 0}}while(0);while(1){if((u|0)>=1024){p=49261;break}I=9638528+(u<<2)|0;if((c[I>>2]|0)==(n|0)){break}else{u=u+1|0}}if((p|0)==49261){i=e;return 0}gGr(n);c[I>>2]=0;i=e;return 0}}while(0);while(1){if((s|0)>=1024){p=49264;break}J=9638528+(s<<2)|0;if((c[J>>2]|0)==(n|0)){break}else{s=s+1|0}}if((p|0)==49264){i=e;return 0}gGr(n);c[J>>2]=0;i=e;return 0}function V9(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=i;i=i+232|0;g=f|0;h=f+112|0;j=f+120|0;k=j+100|0;c[k>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,b)|0;j=c[k>>2]|0;if((j|0)==0){i=f;return}else{l=0}while(1){if((l|0)>=1024){m=49290;break}n=9638528+(l<<2)|0;if((c[n>>2]|0)==0){break}else{l=l+1|0}}if((m|0)==49290){i=f;return}l=gGq(j)|0;c[n>>2]=l;if((l|0)==0){i=f;return}gGz(l|0,0,j|0);do{if((c[3542200]|0)==0){o=0}else{j=g+108|0;c[j>>2]=0;n=g+100|0;c[n>>2]=0;k=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[k&16383](g,b)|0;if((c[j>>2]|0)==0){p=a;q=l;r=0}else{j=c[n>>2]|0;c[h>>2]=9534384;n=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[n&16383](h,b,0)|0;if((j|0)<1){o=0;break}if((gzL(l,0,b)|0)==0){p=a;q=l;r=0}else{o=0;break}}while(1){j=r+1|0;n=p;c[n>>2]=c[n>>2]|c[9620648+((d[q]|0)<<2)>>2]<<e;if((j|0)<262144){p=p+8|0;q=q+1|0;r=j}else{break}}j=a+4|0;n=l+262144|0;k=0;while(1){s=k+1|0;t=j;c[t>>2]=c[t>>2]|c[9620648+((d[n]|0)<<2)>>2]<<e;if((s|0)<262144){j=j+8|0;n=n+1|0;k=s}else{break}}k=a+2097152|0;n=l+524288|0;j=0;while(1){s=j+1|0;t=k;c[t>>2]=c[t>>2]|c[9620648+((d[n]|0)<<2)>>2]<<e;if((s|0)<262144){k=k+8|0;n=n+1|0;j=s}else{break}}j=a+2097156|0;n=l+786432|0;k=0;while(1){s=k+1|0;t=j;c[t>>2]=c[t>>2]|c[9620648+((d[n]|0)<<2)>>2]<<e;if((s|0)<262144){j=j+8|0;n=n+1|0;k=s}else{u=0;break}}while(1){if((u|0)>=1024){m=49292;break}v=9638528+(u<<2)|0;if((c[v>>2]|0)==(l|0)){break}else{u=u+1|0}}if((m|0)==49292){i=f;return}gGr(l);c[v>>2]=0;i=f;return}}while(0);while(1){if((o|0)>=1024){m=49294;break}w=9638528+(o<<2)|0;if((c[w>>2]|0)==(l|0)){break}else{o=o+1|0}}if((m|0)==49294){i=f;return}gGr(l);c[w>>2]=0;i=f;return}function Wa(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0;e=i;i=i+1856|0;f=e|0;g=e+112|0;h=e+120|0;j=e+232|0;k=e+240|0;l=e+352|0;m=e+360|0;n=e+472|0;o=e+480|0;p=e+592|0;q=e+600|0;r=e+712|0;s=e+720|0;t=e+832|0;u=e+840|0;v=e+952|0;w=e+960|0;x=e+1072|0;y=e+1184|0;z=e+1296|0;A=e+1408|0;B=e+1520|0;C=e+1632|0;D=e+1744|0;E=c[3542028]|0;F=D+100|0;c[F>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](D,b)|0;D=c[F>>2]|0;L63973:do{if((D|0)!=0){F=0;while(1){if((F|0)>=1024){break L63973}G=9638528+(F<<2)|0;if((c[G>>2]|0)==0){break}else{F=F+1|0}}F=gGq(D)|0;c[G>>2]=F;if((F|0)==0){break}gGz(F|0,0,D|0);do{if((c[3542200]|0)==0){H=0}else{I=u+108|0;c[I>>2]=0;J=u+100|0;c[J>>2]=0;K=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[K&16383](u,b)|0;if((c[I>>2]|0)==0){L=E;M=F;N=0}else{I=c[J>>2]|0;c[v>>2]=9534384;J=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[J&16383](v,b,0)|0;if((I|0)<1){H=0;break}if((gzL(F,0,b)|0)==0){L=E;M=F;N=0}else{H=0;break}}while(1){I=N+1|0;J=L;c[J>>2]=c[J>>2]|c[9620648+((d[M]|0)<<2)>>2];if((I|0)<262144){L=L+8|0;M=M+1|0;N=I}else{break}}I=E+4|0;J=F+262144|0;K=0;while(1){O=K+1|0;P=I;c[P>>2]=c[P>>2]|c[9620648+((d[J]|0)<<2)>>2];if((O|0)<262144){I=I+8|0;J=J+1|0;K=O}else{Q=0;break}}while(1){if((Q|0)>=1024){break L63973}R=9638528+(Q<<2)|0;if((c[R>>2]|0)==(F|0)){break}else{Q=Q+1|0}}gGr(F);c[R>>2]=0;break L63973}}while(0);while(1){if((H|0)>=1024){break L63973}S=9638528+(H<<2)|0;if((c[S>>2]|0)==(F|0)){break}else{H=H+1|0}}gGr(F);c[S>>2]=0}}while(0);S=c[3542028]|0;H=S+2097152|0;R=b+1|0;Q=C+100|0;c[Q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](C,R)|0;C=c[Q>>2]|0;L63998:do{if((C|0)!=0){Q=0;while(1){if((Q|0)>=1024){break L63998}T=9638528+(Q<<2)|0;if((c[T>>2]|0)==0){break}else{Q=Q+1|0}}Q=gGq(C)|0;c[T>>2]=Q;if((Q|0)==0){break}gGz(Q|0,0,C|0);do{if((c[3542200]|0)==0){U=0}else{F=s+108|0;c[F>>2]=0;E=s+100|0;c[E>>2]=0;N=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[N&16383](s,R)|0;if((c[F>>2]|0)==0){V=H;W=Q;X=0}else{F=c[E>>2]|0;c[t>>2]=9534384;E=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[E&16383](t,R,0)|0;if((F|0)<1){U=0;break}if((gzL(Q,0,R)|0)==0){V=H;W=Q;X=0}else{U=0;break}}while(1){F=X+1|0;E=V;c[E>>2]=c[E>>2]|c[9620648+((d[W]|0)<<2)>>2];if((F|0)<262144){V=V+8|0;W=W+1|0;X=F}else{break}}F=S+2097156|0;E=Q+262144|0;N=0;while(1){M=N+1|0;L=F;c[L>>2]=c[L>>2]|c[9620648+((d[E]|0)<<2)>>2];if((M|0)<262144){F=F+8|0;E=E+1|0;N=M}else{Y=0;break}}while(1){if((Y|0)>=1024){break L63998}Z=9638528+(Y<<2)|0;if((c[Z>>2]|0)==(Q|0)){break}else{Y=Y+1|0}}gGr(Q);c[Z>>2]=0;break L63998}}while(0);while(1){if((U|0)>=1024){break L63998}_=9638528+(U<<2)|0;if((c[_>>2]|0)==(Q|0)){break}else{U=U+1|0}}gGr(Q);c[_>>2]=0}}while(0);_=c[3542028]|0;U=b+2|0;Z=B+100|0;c[Z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](B,U)|0;B=c[Z>>2]|0;L64023:do{if((B|0)!=0){Z=0;while(1){if((Z|0)>=1024){break L64023}$=9638528+(Z<<2)|0;if((c[$>>2]|0)==0){break}else{Z=Z+1|0}}Z=gGq(B)|0;c[$>>2]=Z;if((Z|0)==0){break}gGz(Z|0,0,B|0);do{if((c[3542200]|0)==0){aa=0}else{Q=q+108|0;c[Q>>2]=0;Y=q+100|0;c[Y>>2]=0;S=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[S&16383](q,U)|0;if((c[Q>>2]|0)==0){ab=_;ac=Z;ad=0}else{Q=c[Y>>2]|0;c[r>>2]=9534384;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Y&16383](r,U,0)|0;if((Q|0)<1){aa=0;break}if((gzL(Z,0,U)|0)==0){ab=_;ac=Z;ad=0}else{aa=0;break}}while(1){Q=ad+1|0;Y=ab;c[Y>>2]=c[Y>>2]|c[9620648+((d[ac]|0)<<2)>>2]<<1;if((Q|0)<262144){ab=ab+8|0;ac=ac+1|0;ad=Q}else{break}}Q=_+4|0;Y=Z+262144|0;S=0;while(1){X=S+1|0;W=Q;c[W>>2]=c[W>>2]|c[9620648+((d[Y]|0)<<2)>>2]<<1;if((X|0)<262144){Q=Q+8|0;Y=Y+1|0;S=X}else{ae=0;break}}while(1){if((ae|0)>=1024){break L64023}af=9638528+(ae<<2)|0;if((c[af>>2]|0)==(Z|0)){break}else{ae=ae+1|0}}gGr(Z);c[af>>2]=0;break L64023}}while(0);while(1){if((aa|0)>=1024){break L64023}ag=9638528+(aa<<2)|0;if((c[ag>>2]|0)==(Z|0)){break}else{aa=aa+1|0}}gGr(Z);c[ag>>2]=0}}while(0);ag=c[3542028]|0;aa=ag+2097152|0;af=b+3|0;ae=A+100|0;c[ae>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](A,af)|0;A=c[ae>>2]|0;L64048:do{if((A|0)!=0){ae=0;while(1){if((ae|0)>=1024){break L64048}ah=9638528+(ae<<2)|0;if((c[ah>>2]|0)==0){break}else{ae=ae+1|0}}ae=gGq(A)|0;c[ah>>2]=ae;if((ae|0)==0){break}gGz(ae|0,0,A|0);do{if((c[3542200]|0)==0){ai=0}else{Z=o+108|0;c[Z>>2]=0;_=o+100|0;c[_>>2]=0;ad=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ad&16383](o,af)|0;if((c[Z>>2]|0)==0){aj=aa;ak=ae;al=0}else{Z=c[_>>2]|0;c[p>>2]=9534384;_=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[_&16383](p,af,0)|0;if((Z|0)<1){ai=0;break}if((gzL(ae,0,af)|0)==0){aj=aa;ak=ae;al=0}else{ai=0;break}}while(1){Z=al+1|0;_=aj;c[_>>2]=c[_>>2]|c[9620648+((d[ak]|0)<<2)>>2]<<1;if((Z|0)<262144){aj=aj+8|0;ak=ak+1|0;al=Z}else{break}}Z=ag+2097156|0;_=ae+262144|0;ad=0;while(1){ac=ad+1|0;ab=Z;c[ab>>2]=c[ab>>2]|c[9620648+((d[_]|0)<<2)>>2]<<1;if((ac|0)<262144){Z=Z+8|0;_=_+1|0;ad=ac}else{am=0;break}}while(1){if((am|0)>=1024){break L64048}an=9638528+(am<<2)|0;if((c[an>>2]|0)==(ae|0)){break}else{am=am+1|0}}gGr(ae);c[an>>2]=0;break L64048}}while(0);while(1){if((ai|0)>=1024){break L64048}ao=9638528+(ai<<2)|0;if((c[ao>>2]|0)==(ae|0)){break}else{ai=ai+1|0}}gGr(ae);c[ao>>2]=0}}while(0);ao=c[3542028]|0;ai=b+4|0;an=z+100|0;c[an>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,ai)|0;z=c[an>>2]|0;L64073:do{if((z|0)!=0){an=0;while(1){if((an|0)>=1024){break L64073}ap=9638528+(an<<2)|0;if((c[ap>>2]|0)==0){break}else{an=an+1|0}}an=gGq(z)|0;c[ap>>2]=an;if((an|0)==0){break}gGz(an|0,0,z|0);do{if((c[3542200]|0)==0){aq=0}else{ae=m+108|0;c[ae>>2]=0;am=m+100|0;c[am>>2]=0;ag=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ag&16383](m,ai)|0;if((c[ae>>2]|0)==0){ar=ao;as=an;at=0}else{ae=c[am>>2]|0;c[n>>2]=9534384;am=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[am&16383](n,ai,0)|0;if((ae|0)<1){aq=0;break}if((gzL(an,0,ai)|0)==0){ar=ao;as=an;at=0}else{aq=0;break}}while(1){ae=at+1|0;am=ar;c[am>>2]=c[am>>2]|c[9620648+((d[as]|0)<<2)>>2]<<2;if((ae|0)<262144){ar=ar+8|0;as=as+1|0;at=ae}else{break}}ae=ao+4|0;am=an+262144|0;ag=0;while(1){al=ag+1|0;ak=ae;c[ak>>2]=c[ak>>2]|c[9620648+((d[am]|0)<<2)>>2]<<2;if((al|0)<262144){ae=ae+8|0;am=am+1|0;ag=al}else{au=0;break}}while(1){if((au|0)>=1024){break L64073}av=9638528+(au<<2)|0;if((c[av>>2]|0)==(an|0)){break}else{au=au+1|0}}gGr(an);c[av>>2]=0;break L64073}}while(0);while(1){if((aq|0)>=1024){break L64073}aw=9638528+(aq<<2)|0;if((c[aw>>2]|0)==(an|0)){break}else{aq=aq+1|0}}gGr(an);c[aw>>2]=0}}while(0);aw=c[3542028]|0;aq=aw+2097152|0;av=b+5|0;au=y+100|0;c[au>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](y,av)|0;y=c[au>>2]|0;L64098:do{if((y|0)!=0){au=0;while(1){if((au|0)>=1024){break L64098}ax=9638528+(au<<2)|0;if((c[ax>>2]|0)==0){break}else{au=au+1|0}}au=gGq(y)|0;c[ax>>2]=au;if((au|0)==0){break}gGz(au|0,0,y|0);do{if((c[3542200]|0)==0){ay=0}else{an=k+108|0;c[an>>2]=0;ao=k+100|0;c[ao>>2]=0;at=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[at&16383](k,av)|0;if((c[an>>2]|0)==0){az=aq;aA=au;aB=0}else{an=c[ao>>2]|0;c[l>>2]=9534384;ao=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ao&16383](l,av,0)|0;if((an|0)<1){ay=0;break}if((gzL(au,0,av)|0)==0){az=aq;aA=au;aB=0}else{ay=0;break}}while(1){an=aB+1|0;ao=az;c[ao>>2]=c[ao>>2]|c[9620648+((d[aA]|0)<<2)>>2]<<2;if((an|0)<262144){az=az+8|0;aA=aA+1|0;aB=an}else{break}}an=aw+2097156|0;ao=au+262144|0;at=0;while(1){as=at+1|0;ar=an;c[ar>>2]=c[ar>>2]|c[9620648+((d[ao]|0)<<2)>>2]<<2;if((as|0)<262144){an=an+8|0;ao=ao+1|0;at=as}else{aC=0;break}}while(1){if((aC|0)>=1024){break L64098}aD=9638528+(aC<<2)|0;if((c[aD>>2]|0)==(au|0)){break}else{aC=aC+1|0}}gGr(au);c[aD>>2]=0;break L64098}}while(0);while(1){if((ay|0)>=1024){break L64098}aE=9638528+(ay<<2)|0;if((c[aE>>2]|0)==(au|0)){break}else{ay=ay+1|0}}gGr(au);c[aE>>2]=0}}while(0);aE=c[3542028]|0;ay=b+6|0;aD=x+100|0;c[aD>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,ay)|0;x=c[aD>>2]|0;L64123:do{if((x|0)!=0){aD=0;while(1){if((aD|0)>=1024){break L64123}aF=9638528+(aD<<2)|0;if((c[aF>>2]|0)==0){break}else{aD=aD+1|0}}aD=gGq(x)|0;c[aF>>2]=aD;if((aD|0)==0){break}gGz(aD|0,0,x|0);do{if((c[3542200]|0)==0){aG=0}else{au=h+108|0;c[au>>2]=0;aC=h+100|0;c[aC>>2]=0;aw=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aw&16383](h,ay)|0;if((c[au>>2]|0)==0){aH=aE;aI=aD;aJ=0}else{au=c[aC>>2]|0;c[j>>2]=9534384;aC=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aC&16383](j,ay,0)|0;if((au|0)<1){aG=0;break}if((gzL(aD,0,ay)|0)==0){aH=aE;aI=aD;aJ=0}else{aG=0;break}}while(1){au=aJ+1|0;aC=aH;c[aC>>2]=c[aC>>2]|c[9620648+((d[aI]|0)<<2)>>2]<<3;if((au|0)<262144){aH=aH+8|0;aI=aI+1|0;aJ=au}else{break}}au=aE+4|0;aC=aD+262144|0;aw=0;while(1){aB=aw+1|0;aA=au;c[aA>>2]=c[aA>>2]|c[9620648+((d[aC]|0)<<2)>>2]<<3;if((aB|0)<262144){au=au+8|0;aC=aC+1|0;aw=aB}else{aK=0;break}}while(1){if((aK|0)>=1024){break L64123}aL=9638528+(aK<<2)|0;if((c[aL>>2]|0)==(aD|0)){break}else{aK=aK+1|0}}gGr(aD);c[aL>>2]=0;break L64123}}while(0);while(1){if((aG|0)>=1024){break L64123}aM=9638528+(aG<<2)|0;if((c[aM>>2]|0)==(aD|0)){break}else{aG=aG+1|0}}gGr(aD);c[aM>>2]=0}}while(0);aM=c[3542028]|0;aG=aM+2097152|0;aL=b+7|0;aK=w+100|0;c[aK>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](w,aL)|0;w=c[aK>>2]|0;L64148:do{if((w|0)!=0){aK=0;while(1){if((aK|0)>=1024){break L64148}aN=9638528+(aK<<2)|0;if((c[aN>>2]|0)==0){break}else{aK=aK+1|0}}aK=gGq(w)|0;c[aN>>2]=aK;if((aK|0)==0){break}gGz(aK|0,0,w|0);do{if((c[3542200]|0)==0){aO=0}else{aD=f+108|0;c[aD>>2]=0;aE=f+100|0;c[aE>>2]=0;aJ=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aJ&16383](f,aL)|0;if((c[aD>>2]|0)==0){aP=aG;aQ=aK;aR=0}else{aD=c[aE>>2]|0;c[g>>2]=9534384;aE=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aE&16383](g,aL,0)|0;if((aD|0)<1){aO=0;break}if((gzL(aK,0,aL)|0)==0){aP=aG;aQ=aK;aR=0}else{aO=0;break}}while(1){aD=aR+1|0;aE=aP;c[aE>>2]=c[aE>>2]|c[9620648+((d[aQ]|0)<<2)>>2]<<3;if((aD|0)<262144){aP=aP+8|0;aQ=aQ+1|0;aR=aD}else{break}}aD=aM+2097156|0;aE=aK+262144|0;aJ=0;while(1){aI=aJ+1|0;aH=aD;c[aH>>2]=c[aH>>2]|c[9620648+((d[aE]|0)<<2)>>2]<<3;if((aI|0)<262144){aD=aD+8|0;aE=aE+1|0;aJ=aI}else{aS=0;break}}while(1){if((aS|0)>=1024){break L64148}aT=9638528+(aS<<2)|0;if((c[aT>>2]|0)==(aK|0)){break}else{aS=aS+1|0}}gGr(aK);c[aT>>2]=0;break L64148}}while(0);while(1){if((aO|0)>=1024){break L64148}aU=9638528+(aO<<2)|0;if((c[aU>>2]|0)==(aK|0)){break}else{aO=aO+1|0}}gGr(aK);c[aU>>2]=0}}while(0);aU=c[3542028]|0;aO=aU+4194304|0;aT=0;while(1){if((aT|0)>=1024){aV=0;break}aW=9638528+(aT<<2)|0;if((c[aW>>2]|0)==0){aX=49434;break}else{aT=aT+1|0}}do{if((aX|0)==49434){aT=gGq(2097152)|0;c[aW>>2]=aT;if((aT|0)==0){aV=0;break}gGz(aT|0,0,2097152);aV=aT}}while(0);aW=0;while(1){if((aW|0)>=1024){aY=0;break}aZ=9638528+(aW<<2)|0;if((c[aZ>>2]|0)==0){aX=49439;break}else{aW=aW+1|0}}do{if((aX|0)==49439){aW=gGq(2097152)|0;c[aZ>>2]=aW;if((aW|0)==0){aY=0;break}gGz(aW|0,0,2097152);aY=aW}}while(0);if((aV|0)==0){i=e;return 0}if((R6(aY,b+8|0,2)|0)!=0){aZ=0;while(1){if((aZ|0)>=1024){aX=49474;break}a_=9638528+(aZ<<2)|0;if((c[a_>>2]|0)==(aV|0)){break}else{aZ=aZ+1|0}}if((aX|0)==49474){i=e;return 0}gGr(aV);c[a_>>2]=0;i=e;return 0}if((R6(aY+1|0,b+9|0,2)|0)!=0){a_=0;while(1){if((a_|0)>=1024){aX=49481;break}a$=9638528+(a_<<2)|0;if((c[a$>>2]|0)==(aV|0)){break}else{a_=a_+1|0}}if((aX|0)==49481){i=e;return 0}gGr(aV);c[a$>>2]=0;i=e;return 0}if((R6(aY+1048576|0,b+10|0,2)|0)!=0){a$=0;while(1){if((a$|0)>=1024){aX=49483;break}a0=9638528+(a$<<2)|0;if((c[a0>>2]|0)==(aV|0)){break}else{a$=a$+1|0}}if((aX|0)==49483){i=e;return 0}gGr(aV);c[a0>>2]=0;i=e;return 0}if((R6(aY+1048577|0,b+11|0,2)|0)==0){a1=0}else{b=0;while(1){if((b|0)>=1024){aX=49478;break}a2=9638528+(b<<2)|0;if((c[a2>>2]|0)==(aV|0)){break}else{b=b+1|0}}if((aX|0)==49478){i=e;return 0}gGr(aV);c[a2>>2]=0;i=e;return 0}while(1){a[aV+a1|0]=a[aY+a1|0]|0;a2=a1+1048576|0;b=a1|1;a[aV+b|0]=a[aY+a2|0]|0;a[aV+a2|0]=a[aY+b|0]|0;b=a1+1048577|0;a[aV+b|0]=a[aY+b|0]|0;b=a1+2|0;if((b|0)<1048576){a1=b}else{a3=0;break}}while(1){if((a3|0)>=1024){a4=0;a5=aV;a6=aO;break}a7=9638528+(a3<<2)|0;if((c[a7>>2]|0)==(aY|0)){aX=49461;break}else{a3=a3+1|0}}if((aX|0)==49461){gGr(aY);c[a7>>2]=0;a4=0;a5=aV;a6=aO}while(1){a7=a4+2|0;aY=a6;c[aY>>2]=c[9620648+((d[a5+1|0]|0)<<2)>>2]<<1|c[9620648+((d[a5]|0)<<2)>>2]|c[aY>>2];if((a7|0)<524288){a4=a7;a5=a5+2|0;a6=a6+8|0}else{break}}a6=aU+4194308|0;aU=0;a5=aV+524288|0;a4=a6;while(1){a7=aU+2|0;aY=a4;c[aY>>2]=c[9620648+((d[a5+1|0]|0)<<2)>>2]<<1|c[9620648+((d[a5]|0)<<2)>>2]|c[aY>>2];if((a7|0)<524288){aU=a7;a5=a5+2|0;a4=a4+8|0}else{break}}a4=0;a5=aV+1048576|0;aU=aO;while(1){aO=a4+2|0;a7=aU;c[a7>>2]=(c[9620648+((d[a5+1|0]|0)<<2)>>2]<<1|c[9620648+((d[a5]|0)<<2)>>2])<<2|c[a7>>2];if((aO|0)<524288){a4=aO;a5=a5+2|0;aU=aU+8|0}else{break}}aU=0;a5=aV+1572864|0;a4=a6;while(1){a6=aU+2|0;aO=a4;c[aO>>2]=(c[9620648+((d[a5+1|0]|0)<<2)>>2]<<1|c[9620648+((d[a5]|0)<<2)>>2])<<2|c[aO>>2];if((a6|0)<524288){aU=a6;a5=a5+2|0;a4=a4+8|0}else{a8=0;break}}while(1){if((a8|0)>=1024){aX=49475;break}a9=9638528+(a8<<2)|0;if((c[a9>>2]|0)==(aV|0)){break}else{a8=a8+1|0}}if((aX|0)==49475){i=e;return 0}gGr(aV);c[a9>>2]=0;i=e;return 0}function Wb(a){a=a|0;V6(c[3542028]|0,a);V6((c[3542028]|0)+524288|0,a+4|0);V6((c[3542028]|0)+1048576|0,a+8|0);V6((c[3542028]|0)+1572864|0,a+12|0);return 0}function Wc(a){a=a|0;V6(c[3542028]|0,a);return 0}function Wd(a){a=a|0;V9(c[3542028]|0,a,0);V9(c[3542028]|0,a+1|0,1);V9(c[3542028]|0,a+2|0,2);V9(c[3542028]|0,a+3|0,3);return 0}function We(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0;b=i;i=i+1856|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;l=b+360|0;m=b+472|0;n=b+480|0;o=b+592|0;p=b+600|0;q=b+712|0;r=b+720|0;s=b+832|0;t=b+840|0;u=b+952|0;v=b+960|0;w=b+1072|0;x=b+1184|0;y=b+1296|0;z=b+1408|0;A=b+1520|0;B=b+1632|0;C=b+1744|0;D=c[3542028]|0;E=A+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](A,a)|0;A=c[E>>2]|0;L64254:do{if((A|0)!=0){E=0;while(1){if((E|0)>=1024){break L64254}F=9638528+(E<<2)|0;if((c[F>>2]|0)==0){break}else{E=E+1|0}}E=gGq(A)|0;c[F>>2]=E;if((E|0)==0){break}gGz(E|0,0,A|0);do{if((c[3542200]|0)==0){G=0}else{H=t+108|0;c[H>>2]=0;I=t+100|0;c[I>>2]=0;J=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[J&16383](t,a)|0;if((c[H>>2]|0)==0){K=D;L=E;M=0}else{H=c[I>>2]|0;c[u>>2]=9534384;I=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[I&16383](u,a,0)|0;if((H|0)<1){G=0;break}if((gzL(E,0,a)|0)==0){K=D;L=E;M=0}else{G=0;break}}while(1){H=M+1|0;I=K;c[I>>2]=c[I>>2]|c[9620648+((d[L]|0)<<2)>>2];if((H|0)<262144){K=K+8|0;L=L+1|0;M=H}else{break}}H=D+4|0;I=E+262144|0;J=0;while(1){N=J+1|0;O=H;c[O>>2]=c[O>>2]|c[9620648+((d[I]|0)<<2)>>2];if((N|0)<262144){H=H+8|0;I=I+1|0;J=N}else{P=0;break}}while(1){if((P|0)>=1024){break L64254}Q=9638528+(P<<2)|0;if((c[Q>>2]|0)==(E|0)){break}else{P=P+1|0}}gGr(E);c[Q>>2]=0;break L64254}}while(0);while(1){if((G|0)>=1024){break L64254}R=9638528+(G<<2)|0;if((c[R>>2]|0)==(E|0)){break}else{G=G+1|0}}gGr(E);c[R>>2]=0}}while(0);R=a+1|0;G=z+100|0;c[G>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,R)|0;z=c[G>>2]|0;L64279:do{if((z|0)!=0){G=0;while(1){if((G|0)>=1024){break L64279}S=9638528+(G<<2)|0;if((c[S>>2]|0)==0){break}else{G=G+1|0}}G=gGq(z)|0;c[S>>2]=G;if((G|0)==0){break}gGz(G|0,0,z|0);do{if((c[3542200]|0)==0){T=0}else{E=r+108|0;c[E>>2]=0;Q=r+100|0;c[Q>>2]=0;P=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[P&16383](r,R)|0;if((c[E>>2]|0)==0){U=D;V=G;W=0}else{E=c[Q>>2]|0;c[s>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](s,R,0)|0;if((E|0)<1){T=0;break}if((gzL(G,0,R)|0)==0){U=D;V=G;W=0}else{T=0;break}}while(1){E=W+1|0;Q=U;c[Q>>2]=c[Q>>2]|c[9620648+((d[V]|0)<<2)>>2]<<1;if((E|0)<262144){U=U+8|0;V=V+1|0;W=E}else{break}}E=D+4|0;Q=G+262144|0;P=0;while(1){M=P+1|0;L=E;c[L>>2]=c[L>>2]|c[9620648+((d[Q]|0)<<2)>>2]<<1;if((M|0)<262144){E=E+8|0;Q=Q+1|0;P=M}else{X=0;break}}while(1){if((X|0)>=1024){break L64279}Y=9638528+(X<<2)|0;if((c[Y>>2]|0)==(G|0)){break}else{X=X+1|0}}gGr(G);c[Y>>2]=0;break L64279}}while(0);while(1){if((T|0)>=1024){break L64279}Z=9638528+(T<<2)|0;if((c[Z>>2]|0)==(G|0)){break}else{T=T+1|0}}gGr(G);c[Z>>2]=0}}while(0);Z=a+2|0;T=y+100|0;c[T>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](y,Z)|0;y=c[T>>2]|0;L64304:do{if((y|0)!=0){T=0;while(1){if((T|0)>=1024){break L64304}_=9638528+(T<<2)|0;if((c[_>>2]|0)==0){break}else{T=T+1|0}}T=gGq(y)|0;c[_>>2]=T;if((T|0)==0){break}gGz(T|0,0,y|0);do{if((c[3542200]|0)==0){$=0}else{G=p+108|0;c[G>>2]=0;Y=p+100|0;c[Y>>2]=0;X=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[X&16383](p,Z)|0;if((c[G>>2]|0)==0){aa=D;ab=T;ac=0}else{G=c[Y>>2]|0;c[q>>2]=9534384;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Y&16383](q,Z,0)|0;if((G|0)<1){$=0;break}if((gzL(T,0,Z)|0)==0){aa=D;ab=T;ac=0}else{$=0;break}}while(1){G=ac+1|0;Y=aa;c[Y>>2]=c[Y>>2]|c[9620648+((d[ab]|0)<<2)>>2]<<2;if((G|0)<262144){aa=aa+8|0;ab=ab+1|0;ac=G}else{break}}G=D+4|0;Y=T+262144|0;X=0;while(1){W=X+1|0;V=G;c[V>>2]=c[V>>2]|c[9620648+((d[Y]|0)<<2)>>2]<<2;if((W|0)<262144){G=G+8|0;Y=Y+1|0;X=W}else{ad=0;break}}while(1){if((ad|0)>=1024){break L64304}ae=9638528+(ad<<2)|0;if((c[ae>>2]|0)==(T|0)){break}else{ad=ad+1|0}}gGr(T);c[ae>>2]=0;break L64304}}while(0);while(1){if(($|0)>=1024){break L64304}af=9638528+($<<2)|0;if((c[af>>2]|0)==(T|0)){break}else{$=$+1|0}}gGr(T);c[af>>2]=0}}while(0);af=a+3|0;$=C+100|0;c[$>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](C,af)|0;C=c[$>>2]|0;L64329:do{if((C|0)!=0){$=0;while(1){if(($|0)>=1024){break L64329}ag=9638528+($<<2)|0;if((c[ag>>2]|0)==0){break}else{$=$+1|0}}$=gGq(C)|0;c[ag>>2]=$;if(($|0)==0){break}gGz($|0,0,C|0);do{if((c[3542200]|0)==0){ah=0}else{T=n+108|0;c[T>>2]=0;ae=n+100|0;c[ae>>2]=0;ad=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ad&16383](n,af)|0;if((c[T>>2]|0)==0){ai=D;aj=$;ak=0}else{T=c[ae>>2]|0;c[o>>2]=9534384;ae=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ae&16383](o,af,0)|0;if((T|0)<1){ah=0;break}if((gzL($,0,af)|0)==0){ai=D;aj=$;ak=0}else{ah=0;break}}while(1){T=ak+1|0;ae=ai;c[ae>>2]=c[ae>>2]|c[9620648+((d[aj]|0)<<2)>>2]<<3;if((T|0)<262144){ai=ai+8|0;aj=aj+1|0;ak=T}else{break}}T=D+4|0;ae=$+262144|0;ad=0;while(1){ac=ad+1|0;ab=T;c[ab>>2]=c[ab>>2]|c[9620648+((d[ae]|0)<<2)>>2]<<3;if((ac|0)<262144){T=T+8|0;ae=ae+1|0;ad=ac}else{al=0;break}}while(1){if((al|0)>=1024){break L64329}am=9638528+(al<<2)|0;if((c[am>>2]|0)==($|0)){break}else{al=al+1|0}}gGr($);c[am>>2]=0;break L64329}}while(0);while(1){if((ah|0)>=1024){break L64329}an=9638528+(ah<<2)|0;if((c[an>>2]|0)==($|0)){break}else{ah=ah+1|0}}gGr($);c[an>>2]=0}}while(0);an=c[3542028]|0;ah=an+2097152|0;am=a+4|0;al=x+100|0;c[al>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,am)|0;x=c[al>>2]|0;L64354:do{if((x|0)!=0){al=0;while(1){if((al|0)>=1024){break L64354}ao=9638528+(al<<2)|0;if((c[ao>>2]|0)==0){break}else{al=al+1|0}}al=gGq(x)|0;c[ao>>2]=al;if((al|0)==0){break}gGz(al|0,0,x|0);do{if((c[3542200]|0)==0){ap=0}else{$=l+108|0;c[$>>2]=0;D=l+100|0;c[D>>2]=0;ak=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ak&16383](l,am)|0;if((c[$>>2]|0)==0){aq=ah;ar=al;as=0}else{$=c[D>>2]|0;c[m>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](m,am,0)|0;if(($|0)<1){ap=0;break}if((gzL(al,0,am)|0)==0){aq=ah;ar=al;as=0}else{ap=0;break}}while(1){$=as+1|0;D=aq;c[D>>2]=c[D>>2]|c[9620648+((d[ar]|0)<<2)>>2];if(($|0)<262144){aq=aq+8|0;ar=ar+1|0;as=$}else{break}}$=an+2097156|0;D=al+262144|0;ak=0;while(1){aj=ak+1|0;ai=$;c[ai>>2]=c[ai>>2]|c[9620648+((d[D]|0)<<2)>>2];if((aj|0)<262144){$=$+8|0;D=D+1|0;ak=aj}else{at=0;break}}while(1){if((at|0)>=1024){break L64354}au=9638528+(at<<2)|0;if((c[au>>2]|0)==(al|0)){break}else{at=at+1|0}}gGr(al);c[au>>2]=0;break L64354}}while(0);while(1){if((ap|0)>=1024){break L64354}av=9638528+(ap<<2)|0;if((c[av>>2]|0)==(al|0)){break}else{ap=ap+1|0}}gGr(al);c[av>>2]=0}}while(0);av=a+5|0;ap=w+100|0;c[ap>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](w,av)|0;w=c[ap>>2]|0;L64379:do{if((w|0)!=0){ap=0;while(1){if((ap|0)>=1024){break L64379}aw=9638528+(ap<<2)|0;if((c[aw>>2]|0)==0){break}else{ap=ap+1|0}}ap=gGq(w)|0;c[aw>>2]=ap;if((ap|0)==0){break}gGz(ap|0,0,w|0);do{if((c[3542200]|0)==0){ax=0}else{al=j+108|0;c[al>>2]=0;au=j+100|0;c[au>>2]=0;at=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[at&16383](j,av)|0;if((c[al>>2]|0)==0){ay=ah;az=ap;aA=0}else{al=c[au>>2]|0;c[k>>2]=9534384;au=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[au&16383](k,av,0)|0;if((al|0)<1){ax=0;break}if((gzL(ap,0,av)|0)==0){ay=ah;az=ap;aA=0}else{ax=0;break}}while(1){al=aA+1|0;au=ay;c[au>>2]=c[au>>2]|c[9620648+((d[az]|0)<<2)>>2]<<1;if((al|0)<262144){ay=ay+8|0;az=az+1|0;aA=al}else{break}}al=an+2097156|0;au=ap+262144|0;at=0;while(1){as=at+1|0;ar=al;c[ar>>2]=c[ar>>2]|c[9620648+((d[au]|0)<<2)>>2]<<1;if((as|0)<262144){al=al+8|0;au=au+1|0;at=as}else{aB=0;break}}while(1){if((aB|0)>=1024){break L64379}aC=9638528+(aB<<2)|0;if((c[aC>>2]|0)==(ap|0)){break}else{aB=aB+1|0}}gGr(ap);c[aC>>2]=0;break L64379}}while(0);while(1){if((ax|0)>=1024){break L64379}aD=9638528+(ax<<2)|0;if((c[aD>>2]|0)==(ap|0)){break}else{ax=ax+1|0}}gGr(ap);c[aD>>2]=0}}while(0);aD=a+6|0;ax=v+100|0;c[ax>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,aD)|0;v=c[ax>>2]|0;L64404:do{if((v|0)!=0){ax=0;while(1){if((ax|0)>=1024){break L64404}aE=9638528+(ax<<2)|0;if((c[aE>>2]|0)==0){break}else{ax=ax+1|0}}ax=gGq(v)|0;c[aE>>2]=ax;if((ax|0)==0){break}gGz(ax|0,0,v|0);do{if((c[3542200]|0)==0){aF=0}else{ap=g+108|0;c[ap>>2]=0;aC=g+100|0;c[aC>>2]=0;aB=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aB&16383](g,aD)|0;if((c[ap>>2]|0)==0){aG=ah;aH=ax;aI=0}else{ap=c[aC>>2]|0;c[h>>2]=9534384;aC=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aC&16383](h,aD,0)|0;if((ap|0)<1){aF=0;break}if((gzL(ax,0,aD)|0)==0){aG=ah;aH=ax;aI=0}else{aF=0;break}}while(1){ap=aI+1|0;aC=aG;c[aC>>2]=c[aC>>2]|c[9620648+((d[aH]|0)<<2)>>2]<<2;if((ap|0)<262144){aG=aG+8|0;aH=aH+1|0;aI=ap}else{break}}ap=an+2097156|0;aC=ax+262144|0;aB=0;while(1){aA=aB+1|0;az=ap;c[az>>2]=c[az>>2]|c[9620648+((d[aC]|0)<<2)>>2]<<2;if((aA|0)<262144){ap=ap+8|0;aC=aC+1|0;aB=aA}else{aJ=0;break}}while(1){if((aJ|0)>=1024){break L64404}aK=9638528+(aJ<<2)|0;if((c[aK>>2]|0)==(ax|0)){break}else{aJ=aJ+1|0}}gGr(ax);c[aK>>2]=0;break L64404}}while(0);while(1){if((aF|0)>=1024){break L64404}aL=9638528+(aF<<2)|0;if((c[aL>>2]|0)==(ax|0)){break}else{aF=aF+1|0}}gGr(ax);c[aL>>2]=0}}while(0);aL=a+7|0;a=B+100|0;c[a>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](B,aL)|0;B=c[a>>2]|0;if((B|0)==0){i=b;return 0}else{aM=0}while(1){if((aM|0)>=1024){aN=49626;break}aO=9638528+(aM<<2)|0;if((c[aO>>2]|0)==0){break}else{aM=aM+1|0}}if((aN|0)==49626){i=b;return 0}aM=gGq(B)|0;c[aO>>2]=aM;if((aM|0)==0){i=b;return 0}gGz(aM|0,0,B|0);do{if((c[3542200]|0)==0){aP=0}else{B=e+108|0;c[B>>2]=0;aO=e+100|0;c[aO>>2]=0;a=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[a&16383](e,aL)|0;if((c[B>>2]|0)==0){aQ=ah;aR=aM;aS=0}else{B=c[aO>>2]|0;c[f>>2]=9534384;aO=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aO&16383](f,aL,0)|0;if((B|0)<1){aP=0;break}if((gzL(aM,0,aL)|0)==0){aQ=ah;aR=aM;aS=0}else{aP=0;break}}while(1){B=aS+1|0;aO=aQ;c[aO>>2]=c[aO>>2]|c[9620648+((d[aR]|0)<<2)>>2]<<3;if((B|0)<262144){aQ=aQ+8|0;aR=aR+1|0;aS=B}else{break}}ax=an+2097156|0;B=aM+262144|0;aO=0;while(1){a=aO+1|0;aF=ax;c[aF>>2]=c[aF>>2]|c[9620648+((d[B]|0)<<2)>>2]<<3;if((a|0)<262144){ax=ax+8|0;B=B+1|0;aO=a}else{aT=0;break}}while(1){if((aT|0)>=1024){aN=49629;break}aU=9638528+(aT<<2)|0;if((c[aU>>2]|0)==(aM|0)){break}else{aT=aT+1|0}}if((aN|0)==49629){i=b;return 0}gGr(aM);c[aU>>2]=0;i=b;return 0}}while(0);while(1){if((aP|0)>=1024){aN=49628;break}aV=9638528+(aP<<2)|0;if((c[aV>>2]|0)==(aM|0)){break}else{aP=aP+1|0}}if((aN|0)==49628){i=b;return 0}gGr(aM);c[aV>>2]=0;i=b;return 0}function Wf(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0;b=i;i=i+2784|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;l=b+360|0;m=b+472|0;n=b+480|0;o=b+592|0;p=b+600|0;q=b+712|0;r=b+720|0;s=b+832|0;t=b+840|0;u=b+952|0;v=b+960|0;w=b+1072|0;x=b+1080|0;y=b+1192|0;z=b+1200|0;A=b+1312|0;B=b+1320|0;C=b+1432|0;D=b+1440|0;E=b+1552|0;F=b+1664|0;G=b+1776|0;H=b+1888|0;I=b+2e3|0;J=b+2112|0;K=b+2224|0;L=b+2336|0;M=b+2448|0;N=b+2560|0;O=b+2672|0;P=c[3542028]|0;Q=L+100|0;c[Q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](L,a)|0;L=c[Q>>2]|0;L64465:do{if((L|0)!=0){Q=0;while(1){if((Q|0)>=1024){break L64465}R=9638528+(Q<<2)|0;if((c[R>>2]|0)==0){break}else{Q=Q+1|0}}Q=gGq(L)|0;c[R>>2]=Q;if((Q|0)==0){break}gGz(Q|0,0,L|0);do{if((c[3542200]|0)==0){S=0}else{T=B+108|0;c[T>>2]=0;U=B+100|0;c[U>>2]=0;V=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[V&16383](B,a)|0;if((c[T>>2]|0)==0){W=P;X=Q;Y=0}else{T=c[U>>2]|0;c[C>>2]=9534384;U=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[U&16383](C,a,0)|0;if((T|0)<1){S=0;break}if((gzL(Q,0,a)|0)==0){W=P;X=Q;Y=0}else{S=0;break}}while(1){T=Y+1|0;U=W;c[U>>2]=c[U>>2]|c[9620648+((d[X]|0)<<2)>>2];if((T|0)<262144){W=W+8|0;X=X+1|0;Y=T}else{break}}T=P+4|0;U=Q+262144|0;V=0;while(1){Z=V+1|0;_=T;c[_>>2]=c[_>>2]|c[9620648+((d[U]|0)<<2)>>2];if((Z|0)<262144){T=T+8|0;U=U+1|0;V=Z}else{$=0;break}}while(1){if(($|0)>=1024){break L64465}aa=9638528+($<<2)|0;if((c[aa>>2]|0)==(Q|0)){break}else{$=$+1|0}}gGr(Q);c[aa>>2]=0;break L64465}}while(0);while(1){if((S|0)>=1024){break L64465}ab=9638528+(S<<2)|0;if((c[ab>>2]|0)==(Q|0)){break}else{S=S+1|0}}gGr(Q);c[ab>>2]=0}}while(0);ab=a+1|0;S=K+100|0;c[S>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](K,ab)|0;K=c[S>>2]|0;L64490:do{if((K|0)!=0){S=0;while(1){if((S|0)>=1024){break L64490}ac=9638528+(S<<2)|0;if((c[ac>>2]|0)==0){break}else{S=S+1|0}}S=gGq(K)|0;c[ac>>2]=S;if((S|0)==0){break}gGz(S|0,0,K|0);do{if((c[3542200]|0)==0){ad=0}else{Q=z+108|0;c[Q>>2]=0;aa=z+100|0;c[aa>>2]=0;$=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[$&16383](z,ab)|0;if((c[Q>>2]|0)==0){ae=P;af=S;ag=0}else{Q=c[aa>>2]|0;c[A>>2]=9534384;aa=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aa&16383](A,ab,0)|0;if((Q|0)<1){ad=0;break}if((gzL(S,0,ab)|0)==0){ae=P;af=S;ag=0}else{ad=0;break}}while(1){Q=ag+1|0;aa=ae;c[aa>>2]=c[aa>>2]|c[9620648+((d[af]|0)<<2)>>2]<<1;if((Q|0)<262144){ae=ae+8|0;af=af+1|0;ag=Q}else{break}}Q=P+4|0;aa=S+262144|0;$=0;while(1){Y=$+1|0;X=Q;c[X>>2]=c[X>>2]|c[9620648+((d[aa]|0)<<2)>>2]<<1;if((Y|0)<262144){Q=Q+8|0;aa=aa+1|0;$=Y}else{ah=0;break}}while(1){if((ah|0)>=1024){break L64490}ai=9638528+(ah<<2)|0;if((c[ai>>2]|0)==(S|0)){break}else{ah=ah+1|0}}gGr(S);c[ai>>2]=0;break L64490}}while(0);while(1){if((ad|0)>=1024){break L64490}aj=9638528+(ad<<2)|0;if((c[aj>>2]|0)==(S|0)){break}else{ad=ad+1|0}}gGr(S);c[aj>>2]=0}}while(0);aj=a+2|0;ad=J+100|0;c[ad>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](J,aj)|0;J=c[ad>>2]|0;L64515:do{if((J|0)!=0){ad=0;while(1){if((ad|0)>=1024){break L64515}ak=9638528+(ad<<2)|0;if((c[ak>>2]|0)==0){break}else{ad=ad+1|0}}ad=gGq(J)|0;c[ak>>2]=ad;if((ad|0)==0){break}gGz(ad|0,0,J|0);do{if((c[3542200]|0)==0){al=0}else{S=x+108|0;c[S>>2]=0;ai=x+100|0;c[ai>>2]=0;ah=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ah&16383](x,aj)|0;if((c[S>>2]|0)==0){am=P;an=ad;ao=0}else{S=c[ai>>2]|0;c[y>>2]=9534384;ai=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ai&16383](y,aj,0)|0;if((S|0)<1){al=0;break}if((gzL(ad,0,aj)|0)==0){am=P;an=ad;ao=0}else{al=0;break}}while(1){S=ao+1|0;ai=am;c[ai>>2]=c[ai>>2]|c[9620648+((d[an]|0)<<2)>>2]<<2;if((S|0)<262144){am=am+8|0;an=an+1|0;ao=S}else{break}}S=P+4|0;ai=ad+262144|0;ah=0;while(1){ag=ah+1|0;af=S;c[af>>2]=c[af>>2]|c[9620648+((d[ai]|0)<<2)>>2]<<2;if((ag|0)<262144){S=S+8|0;ai=ai+1|0;ah=ag}else{ap=0;break}}while(1){if((ap|0)>=1024){break L64515}aq=9638528+(ap<<2)|0;if((c[aq>>2]|0)==(ad|0)){break}else{ap=ap+1|0}}gGr(ad);c[aq>>2]=0;break L64515}}while(0);while(1){if((al|0)>=1024){break L64515}ar=9638528+(al<<2)|0;if((c[ar>>2]|0)==(ad|0)){break}else{al=al+1|0}}gGr(ad);c[ar>>2]=0}}while(0);ar=a+3|0;al=O+100|0;c[al>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](O,ar)|0;O=c[al>>2]|0;L64540:do{if((O|0)!=0){al=0;while(1){if((al|0)>=1024){break L64540}as=9638528+(al<<2)|0;if((c[as>>2]|0)==0){break}else{al=al+1|0}}al=gGq(O)|0;c[as>>2]=al;if((al|0)==0){break}gGz(al|0,0,O|0);do{if((c[3542200]|0)==0){at=0}else{ad=v+108|0;c[ad>>2]=0;aq=v+100|0;c[aq>>2]=0;ap=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ap&16383](v,ar)|0;if((c[ad>>2]|0)==0){au=P;av=al;aw=0}else{ad=c[aq>>2]|0;c[w>>2]=9534384;aq=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aq&16383](w,ar,0)|0;if((ad|0)<1){at=0;break}if((gzL(al,0,ar)|0)==0){au=P;av=al;aw=0}else{at=0;break}}while(1){ad=aw+1|0;aq=au;c[aq>>2]=c[aq>>2]|c[9620648+((d[av]|0)<<2)>>2]<<3;if((ad|0)<262144){au=au+8|0;av=av+1|0;aw=ad}else{break}}ad=P+4|0;aq=al+262144|0;ap=0;while(1){ao=ap+1|0;an=ad;c[an>>2]=c[an>>2]|c[9620648+((d[aq]|0)<<2)>>2]<<3;if((ao|0)<262144){ad=ad+8|0;aq=aq+1|0;ap=ao}else{ax=0;break}}while(1){if((ax|0)>=1024){break L64540}ay=9638528+(ax<<2)|0;if((c[ay>>2]|0)==(al|0)){break}else{ax=ax+1|0}}gGr(al);c[ay>>2]=0;break L64540}}while(0);while(1){if((at|0)>=1024){break L64540}az=9638528+(at<<2)|0;if((c[az>>2]|0)==(al|0)){break}else{at=at+1|0}}gGr(al);c[az>>2]=0}}while(0);az=c[3542028]|0;at=az+2097152|0;ay=a+4|0;ax=I+100|0;c[ax>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](I,ay)|0;I=c[ax>>2]|0;L64565:do{if((I|0)!=0){ax=0;while(1){if((ax|0)>=1024){break L64565}aA=9638528+(ax<<2)|0;if((c[aA>>2]|0)==0){break}else{ax=ax+1|0}}ax=gGq(I)|0;c[aA>>2]=ax;if((ax|0)==0){break}gGz(ax|0,0,I|0);do{if((c[3542200]|0)==0){aB=0}else{al=t+108|0;c[al>>2]=0;P=t+100|0;c[P>>2]=0;aw=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aw&16383](t,ay)|0;if((c[al>>2]|0)==0){aC=at;aD=ax;aE=0}else{al=c[P>>2]|0;c[u>>2]=9534384;P=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[P&16383](u,ay,0)|0;if((al|0)<1){aB=0;break}if((gzL(ax,0,ay)|0)==0){aC=at;aD=ax;aE=0}else{aB=0;break}}while(1){al=aE+1|0;P=aC;c[P>>2]=c[P>>2]|c[9620648+((d[aD]|0)<<2)>>2];if((al|0)<262144){aC=aC+8|0;aD=aD+1|0;aE=al}else{break}}al=az+2097156|0;P=ax+262144|0;aw=0;while(1){av=aw+1|0;au=al;c[au>>2]=c[au>>2]|c[9620648+((d[P]|0)<<2)>>2];if((av|0)<262144){al=al+8|0;P=P+1|0;aw=av}else{aF=0;break}}while(1){if((aF|0)>=1024){break L64565}aG=9638528+(aF<<2)|0;if((c[aG>>2]|0)==(ax|0)){break}else{aF=aF+1|0}}gGr(ax);c[aG>>2]=0;break L64565}}while(0);while(1){if((aB|0)>=1024){break L64565}aH=9638528+(aB<<2)|0;if((c[aH>>2]|0)==(ax|0)){break}else{aB=aB+1|0}}gGr(ax);c[aH>>2]=0}}while(0);aH=a+5|0;aB=H+100|0;c[aB>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](H,aH)|0;H=c[aB>>2]|0;L64590:do{if((H|0)!=0){aB=0;while(1){if((aB|0)>=1024){break L64590}aI=9638528+(aB<<2)|0;if((c[aI>>2]|0)==0){break}else{aB=aB+1|0}}aB=gGq(H)|0;c[aI>>2]=aB;if((aB|0)==0){break}gGz(aB|0,0,H|0);do{if((c[3542200]|0)==0){aJ=0}else{ax=r+108|0;c[ax>>2]=0;aG=r+100|0;c[aG>>2]=0;aF=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aF&16383](r,aH)|0;if((c[ax>>2]|0)==0){aK=at;aL=aB;aM=0}else{ax=c[aG>>2]|0;c[s>>2]=9534384;aG=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aG&16383](s,aH,0)|0;if((ax|0)<1){aJ=0;break}if((gzL(aB,0,aH)|0)==0){aK=at;aL=aB;aM=0}else{aJ=0;break}}while(1){ax=aM+1|0;aG=aK;c[aG>>2]=c[aG>>2]|c[9620648+((d[aL]|0)<<2)>>2]<<1;if((ax|0)<262144){aK=aK+8|0;aL=aL+1|0;aM=ax}else{break}}ax=az+2097156|0;aG=aB+262144|0;aF=0;while(1){aE=aF+1|0;aD=ax;c[aD>>2]=c[aD>>2]|c[9620648+((d[aG]|0)<<2)>>2]<<1;if((aE|0)<262144){ax=ax+8|0;aG=aG+1|0;aF=aE}else{aN=0;break}}while(1){if((aN|0)>=1024){break L64590}aO=9638528+(aN<<2)|0;if((c[aO>>2]|0)==(aB|0)){break}else{aN=aN+1|0}}gGr(aB);c[aO>>2]=0;break L64590}}while(0);while(1){if((aJ|0)>=1024){break L64590}aP=9638528+(aJ<<2)|0;if((c[aP>>2]|0)==(aB|0)){break}else{aJ=aJ+1|0}}gGr(aB);c[aP>>2]=0}}while(0);aP=a+6|0;aJ=G+100|0;c[aJ>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](G,aP)|0;G=c[aJ>>2]|0;L64615:do{if((G|0)!=0){aJ=0;while(1){if((aJ|0)>=1024){break L64615}aQ=9638528+(aJ<<2)|0;if((c[aQ>>2]|0)==0){break}else{aJ=aJ+1|0}}aJ=gGq(G)|0;c[aQ>>2]=aJ;if((aJ|0)==0){break}gGz(aJ|0,0,G|0);do{if((c[3542200]|0)==0){aR=0}else{aB=p+108|0;c[aB>>2]=0;aO=p+100|0;c[aO>>2]=0;aN=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aN&16383](p,aP)|0;if((c[aB>>2]|0)==0){aS=at;aT=aJ;aU=0}else{aB=c[aO>>2]|0;c[q>>2]=9534384;aO=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aO&16383](q,aP,0)|0;if((aB|0)<1){aR=0;break}if((gzL(aJ,0,aP)|0)==0){aS=at;aT=aJ;aU=0}else{aR=0;break}}while(1){aB=aU+1|0;aO=aS;c[aO>>2]=c[aO>>2]|c[9620648+((d[aT]|0)<<2)>>2]<<2;if((aB|0)<262144){aS=aS+8|0;aT=aT+1|0;aU=aB}else{break}}aB=az+2097156|0;aO=aJ+262144|0;aN=0;while(1){aM=aN+1|0;aL=aB;c[aL>>2]=c[aL>>2]|c[9620648+((d[aO]|0)<<2)>>2]<<2;if((aM|0)<262144){aB=aB+8|0;aO=aO+1|0;aN=aM}else{aV=0;break}}while(1){if((aV|0)>=1024){break L64615}aW=9638528+(aV<<2)|0;if((c[aW>>2]|0)==(aJ|0)){break}else{aV=aV+1|0}}gGr(aJ);c[aW>>2]=0;break L64615}}while(0);while(1){if((aR|0)>=1024){break L64615}aX=9638528+(aR<<2)|0;if((c[aX>>2]|0)==(aJ|0)){break}else{aR=aR+1|0}}gGr(aJ);c[aX>>2]=0}}while(0);aX=a+7|0;aR=N+100|0;c[aR>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](N,aX)|0;N=c[aR>>2]|0;L64640:do{if((N|0)!=0){aR=0;while(1){if((aR|0)>=1024){break L64640}aY=9638528+(aR<<2)|0;if((c[aY>>2]|0)==0){break}else{aR=aR+1|0}}aR=gGq(N)|0;c[aY>>2]=aR;if((aR|0)==0){break}gGz(aR|0,0,N|0);do{if((c[3542200]|0)==0){aZ=0}else{aJ=n+108|0;c[aJ>>2]=0;aW=n+100|0;c[aW>>2]=0;aV=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aV&16383](n,aX)|0;if((c[aJ>>2]|0)==0){a_=at;a$=aR;a0=0}else{aJ=c[aW>>2]|0;c[o>>2]=9534384;aW=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[aW&16383](o,aX,0)|0;if((aJ|0)<1){aZ=0;break}if((gzL(aR,0,aX)|0)==0){a_=at;a$=aR;a0=0}else{aZ=0;break}}while(1){aJ=a0+1|0;aW=a_;c[aW>>2]=c[aW>>2]|c[9620648+((d[a$]|0)<<2)>>2]<<3;if((aJ|0)<262144){a_=a_+8|0;a$=a$+1|0;a0=aJ}else{break}}aJ=az+2097156|0;aW=aR+262144|0;aV=0;while(1){aU=aV+1|0;aT=aJ;c[aT>>2]=c[aT>>2]|c[9620648+((d[aW]|0)<<2)>>2]<<3;if((aU|0)<262144){aJ=aJ+8|0;aW=aW+1|0;aV=aU}else{a1=0;break}}while(1){if((a1|0)>=1024){break L64640}a2=9638528+(a1<<2)|0;if((c[a2>>2]|0)==(aR|0)){break}else{a1=a1+1|0}}gGr(aR);c[a2>>2]=0;break L64640}}while(0);while(1){if((aZ|0)>=1024){break L64640}a3=9638528+(aZ<<2)|0;if((c[a3>>2]|0)==(aR|0)){break}else{aZ=aZ+1|0}}gGr(aR);c[a3>>2]=0}}while(0);a3=c[3542028]|0;aZ=a3+4194304|0;a2=a+8|0;a1=F+100|0;c[a1>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](F,a2)|0;F=c[a1>>2]|0;L64665:do{if((F|0)!=0){a1=0;while(1){if((a1|0)>=1024){break L64665}a4=9638528+(a1<<2)|0;if((c[a4>>2]|0)==0){break}else{a1=a1+1|0}}a1=gGq(F)|0;c[a4>>2]=a1;if((a1|0)==0){break}gGz(a1|0,0,F|0);do{if((c[3542200]|0)==0){a5=0}else{aR=l+108|0;c[aR>>2]=0;az=l+100|0;c[az>>2]=0;a0=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[a0&16383](l,a2)|0;if((c[aR>>2]|0)==0){a6=aZ;a7=a1;a8=0}else{aR=c[az>>2]|0;c[m>>2]=9534384;az=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[az&16383](m,a2,0)|0;if((aR|0)<1){a5=0;break}if((gzL(a1,0,a2)|0)==0){a6=aZ;a7=a1;a8=0}else{a5=0;break}}while(1){aR=a8+1|0;az=a6;c[az>>2]=c[az>>2]|c[9620648+((d[a7]|0)<<2)>>2];if((aR|0)<262144){a6=a6+8|0;a7=a7+1|0;a8=aR}else{break}}aR=a3+4194308|0;az=a1+262144|0;a0=0;while(1){a$=a0+1|0;a_=aR;c[a_>>2]=c[a_>>2]|c[9620648+((d[az]|0)<<2)>>2];if((a$|0)<262144){aR=aR+8|0;az=az+1|0;a0=a$}else{a9=0;break}}while(1){if((a9|0)>=1024){break L64665}ba=9638528+(a9<<2)|0;if((c[ba>>2]|0)==(a1|0)){break}else{a9=a9+1|0}}gGr(a1);c[ba>>2]=0;break L64665}}while(0);while(1){if((a5|0)>=1024){break L64665}bb=9638528+(a5<<2)|0;if((c[bb>>2]|0)==(a1|0)){break}else{a5=a5+1|0}}gGr(a1);c[bb>>2]=0}}while(0);bb=a+9|0;a5=E+100|0;c[a5>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](E,bb)|0;E=c[a5>>2]|0;L64690:do{if((E|0)!=0){a5=0;while(1){if((a5|0)>=1024){break L64690}bc=9638528+(a5<<2)|0;if((c[bc>>2]|0)==0){break}else{a5=a5+1|0}}a5=gGq(E)|0;c[bc>>2]=a5;if((a5|0)==0){break}gGz(a5|0,0,E|0);do{if((c[3542200]|0)==0){bd=0}else{a1=j+108|0;c[a1>>2]=0;ba=j+100|0;c[ba>>2]=0;a9=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[a9&16383](j,bb)|0;if((c[a1>>2]|0)==0){be=aZ;bf=a5;bg=0}else{a1=c[ba>>2]|0;c[k>>2]=9534384;ba=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ba&16383](k,bb,0)|0;if((a1|0)<1){bd=0;break}if((gzL(a5,0,bb)|0)==0){be=aZ;bf=a5;bg=0}else{bd=0;break}}while(1){a1=bg+1|0;ba=be;c[ba>>2]=c[ba>>2]|c[9620648+((d[bf]|0)<<2)>>2]<<1;if((a1|0)<262144){be=be+8|0;bf=bf+1|0;bg=a1}else{break}}a1=a3+4194308|0;ba=a5+262144|0;a9=0;while(1){a8=a9+1|0;a7=a1;c[a7>>2]=c[a7>>2]|c[9620648+((d[ba]|0)<<2)>>2]<<1;if((a8|0)<262144){a1=a1+8|0;ba=ba+1|0;a9=a8}else{bh=0;break}}while(1){if((bh|0)>=1024){break L64690}bi=9638528+(bh<<2)|0;if((c[bi>>2]|0)==(a5|0)){break}else{bh=bh+1|0}}gGr(a5);c[bi>>2]=0;break L64690}}while(0);while(1){if((bd|0)>=1024){break L64690}bj=9638528+(bd<<2)|0;if((c[bj>>2]|0)==(a5|0)){break}else{bd=bd+1|0}}gGr(a5);c[bj>>2]=0}}while(0);bj=a+10|0;bd=D+100|0;c[bd>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](D,bj)|0;D=c[bd>>2]|0;L64715:do{if((D|0)!=0){bd=0;while(1){if((bd|0)>=1024){break L64715}bk=9638528+(bd<<2)|0;if((c[bk>>2]|0)==0){break}else{bd=bd+1|0}}bd=gGq(D)|0;c[bk>>2]=bd;if((bd|0)==0){break}gGz(bd|0,0,D|0);do{if((c[3542200]|0)==0){bl=0}else{a5=g+108|0;c[a5>>2]=0;bi=g+100|0;c[bi>>2]=0;bh=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[bh&16383](g,bj)|0;if((c[a5>>2]|0)==0){bm=aZ;bn=bd;bo=0}else{a5=c[bi>>2]|0;c[h>>2]=9534384;bi=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[bi&16383](h,bj,0)|0;if((a5|0)<1){bl=0;break}if((gzL(bd,0,bj)|0)==0){bm=aZ;bn=bd;bo=0}else{bl=0;break}}while(1){a5=bo+1|0;bi=bm;c[bi>>2]=c[bi>>2]|c[9620648+((d[bn]|0)<<2)>>2]<<2;if((a5|0)<262144){bm=bm+8|0;bn=bn+1|0;bo=a5}else{break}}a5=a3+4194308|0;bi=bd+262144|0;bh=0;while(1){bg=bh+1|0;bf=a5;c[bf>>2]=c[bf>>2]|c[9620648+((d[bi]|0)<<2)>>2]<<2;if((bg|0)<262144){a5=a5+8|0;bi=bi+1|0;bh=bg}else{bp=0;break}}while(1){if((bp|0)>=1024){break L64715}bq=9638528+(bp<<2)|0;if((c[bq>>2]|0)==(bd|0)){break}else{bp=bp+1|0}}gGr(bd);c[bq>>2]=0;break L64715}}while(0);while(1){if((bl|0)>=1024){break L64715}br=9638528+(bl<<2)|0;if((c[br>>2]|0)==(bd|0)){break}else{bl=bl+1|0}}gGr(bd);c[br>>2]=0}}while(0);br=a+11|0;a=M+100|0;c[a>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](M,br)|0;M=c[a>>2]|0;if((M|0)==0){i=b;return 0}else{bs=0}while(1){if((bs|0)>=1024){bt=49837;break}bu=9638528+(bs<<2)|0;if((c[bu>>2]|0)==0){break}else{bs=bs+1|0}}if((bt|0)==49837){i=b;return 0}bs=gGq(M)|0;c[bu>>2]=bs;if((bs|0)==0){i=b;return 0}gGz(bs|0,0,M|0);do{if((c[3542200]|0)==0){bv=0}else{M=e+108|0;c[M>>2]=0;bu=e+100|0;c[bu>>2]=0;a=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[a&16383](e,br)|0;if((c[M>>2]|0)==0){bw=aZ;bx=bs;by=0}else{M=c[bu>>2]|0;c[f>>2]=9534384;bu=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[bu&16383](f,br,0)|0;if((M|0)<1){bv=0;break}if((gzL(bs,0,br)|0)==0){bw=aZ;bx=bs;by=0}else{bv=0;break}}while(1){M=by+1|0;bu=bw;c[bu>>2]=c[bu>>2]|c[9620648+((d[bx]|0)<<2)>>2]<<3;if((M|0)<262144){bw=bw+8|0;bx=bx+1|0;by=M}else{break}}bd=a3+4194308|0;M=bs+262144|0;bu=0;while(1){a=bu+1|0;bl=bd;c[bl>>2]=c[bl>>2]|c[9620648+((d[M]|0)<<2)>>2]<<3;if((a|0)<262144){bd=bd+8|0;M=M+1|0;bu=a}else{bz=0;break}}while(1){if((bz|0)>=1024){bt=49841;break}bA=9638528+(bz<<2)|0;if((c[bA>>2]|0)==(bs|0)){break}else{bz=bz+1|0}}if((bt|0)==49841){i=b;return 0}gGr(bs);c[bA>>2]=0;i=b;return 0}}while(0);while(1){if((bv|0)>=1024){bt=49838;break}bB=9638528+(bv<<2)|0;if((c[bB>>2]|0)==(bs|0)){break}else{bv=bv+1|0}}if((bt|0)==49838){i=b;return 0}gGr(bs);c[bB>>2]=0;i=b;return 0}function Wg(a){a=a|0;VX(c[3542028]|0,a);return 0}function Wh(a){a=a|0;Wi(c[3542028]|0,a,0);Wi(c[3542028]|0,a+1|0,2);Wi((c[3542028]|0)+4|0,a+2|0,0);Wi((c[3542028]|0)+4|0,a+3|0,2);Wi(c[3542028]|0,a+4|0,1);Wi(c[3542028]|0,a+5|0,3);Wi((c[3542028]|0)+4|0,a+6|0,1);Wi((c[3542028]|0)+4|0,a+7|0,3);return 0}function Wi(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=i;i=i+232|0;g=f|0;h=f+112|0;j=f+120|0;k=j+100|0;c[k>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,b)|0;j=c[k>>2]|0;if((j|0)==0){i=f;return}else{l=0}while(1){if((l|0)>=1024){m=49866;break}n=9638528+(l<<2)|0;if((c[n>>2]|0)==0){break}else{l=l+1|0}}if((m|0)==49866){i=f;return}l=gGq(j)|0;c[n>>2]=l;if((l|0)==0){i=f;return}gGz(l|0,0,j|0);do{if((c[3542200]|0)==0){o=0}else{j=g+108|0;c[j>>2]=0;n=g+100|0;c[n>>2]=0;p=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[p&16383](g,b)|0;if((c[j>>2]|0)!=0){j=c[n>>2]|0;c[h>>2]=9534384;n=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[n&16383](h,b,0)|0;if((j|0)<1){o=0;break}if((gzL(l,0,b)|0)!=0){o=0;break}}j=c[k>>2]>>1;if((j|0)>0){n=a;p=l;q=0;while(1){r=q+1|0;s=n;c[s>>2]=c[s>>2]|c[9620648+((d[p]|0)<<2)>>2]<<e;if((r|0)<(j|0)){n=n+8|0;p=p+1|0;q=r}else{break}}q=a+2097152|0;p=l+262144|0;n=0;while(1){r=n+1|0;s=q;c[s>>2]=c[s>>2]|c[9620648+((d[p]|0)<<2)>>2]<<e;if((r|0)<(j|0)){q=q+8|0;p=p+1|0;n=r}else{t=0;break}}}else{t=0}while(1){if((t|0)>=1024){m=49868;break}u=9638528+(t<<2)|0;if((c[u>>2]|0)==(l|0)){break}else{t=t+1|0}}if((m|0)==49868){i=f;return}gGr(l);c[u>>2]=0;i=f;return}}while(0);while(1){if((o|0)>=1024){m=49870;break}v=9638528+(o<<2)|0;if((c[v>>2]|0)==(l|0)){break}else{o=o+1|0}}if((m|0)==49870){i=f;return}gGr(l);c[v>>2]=0;i=f;return}function Wj(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0;b=i;i=i+1856|0;e=b|0;f=b+112|0;g=b+120|0;h=b+232|0;j=b+240|0;k=b+352|0;l=b+360|0;m=b+472|0;n=b+480|0;o=b+592|0;p=b+600|0;q=b+712|0;r=b+720|0;s=b+832|0;t=b+840|0;u=b+952|0;v=b+960|0;w=b+1072|0;x=b+1184|0;y=b+1296|0;z=b+1408|0;A=b+1520|0;B=b+1632|0;C=b+1744|0;D=c[3542028]|0;E=C+100|0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](C,a)|0;C=c[E>>2]|0;L64816:do{if((C|0)!=0){F=0;while(1){if((F|0)>=1024){break L64816}G=9638528+(F<<2)|0;if((c[G>>2]|0)==0){break}else{F=F+1|0}}F=gGq(C)|0;c[G>>2]=F;if((F|0)==0){break}gGz(F|0,0,C|0);do{if((c[3542200]|0)==0){H=0}else{I=t+108|0;c[I>>2]=0;J=t+100|0;c[J>>2]=0;K=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[K&16383](t,a)|0;if((c[I>>2]|0)!=0){I=c[J>>2]|0;c[u>>2]=9534384;J=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[J&16383](u,a,0)|0;if((I|0)<1){H=0;break}if((gzL(F,0,a)|0)!=0){H=0;break}}I=c[E>>2]&-2;if((I|0)>0){J=D;K=F;L=0;while(1){M=L+2|0;N=J;c[N>>2]=c[9620648+((d[K+1|0]|0)<<2)>>2]<<1|c[9620648+((d[K]|0)<<2)>>2]|c[N>>2];if((M|0)<(I|0)){J=J+8|0;K=K+2|0;L=M}else{O=0;break}}}else{O=0}while(1){if((O|0)>=1024){break L64816}P=9638528+(O<<2)|0;if((c[P>>2]|0)==(F|0)){break}else{O=O+1|0}}gGr(F);c[P>>2]=0;break L64816}}while(0);while(1){if((H|0)>=1024){break L64816}Q=9638528+(H<<2)|0;if((c[Q>>2]|0)==(F|0)){break}else{H=H+1|0}}gGr(F);c[Q>>2]=0}}while(0);Q=(c[3542028]|0)+2097152|0;H=a+1|0;P=B+100|0;c[P>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](B,H)|0;B=c[P>>2]|0;L64840:do{if((B|0)!=0){O=0;while(1){if((O|0)>=1024){break L64840}R=9638528+(O<<2)|0;if((c[R>>2]|0)==0){break}else{O=O+1|0}}O=gGq(B)|0;c[R>>2]=O;if((O|0)==0){break}gGz(O|0,0,B|0);do{if((c[3542200]|0)==0){S=0}else{F=r+108|0;c[F>>2]=0;D=r+100|0;c[D>>2]=0;E=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[E&16383](r,H)|0;if((c[F>>2]|0)!=0){F=c[D>>2]|0;c[s>>2]=9534384;D=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[D&16383](s,H,0)|0;if((F|0)<1){S=0;break}if((gzL(O,0,H)|0)!=0){S=0;break}}F=c[P>>2]&-2;if((F|0)>0){D=Q;E=O;u=0;while(1){t=u+2|0;C=D;c[C>>2]=c[9620648+((d[E+1|0]|0)<<2)>>2]<<1|c[9620648+((d[E]|0)<<2)>>2]|c[C>>2];if((t|0)<(F|0)){D=D+8|0;E=E+2|0;u=t}else{T=0;break}}}else{T=0}while(1){if((T|0)>=1024){break L64840}U=9638528+(T<<2)|0;if((c[U>>2]|0)==(O|0)){break}else{T=T+1|0}}gGr(O);c[U>>2]=0;break L64840}}while(0);while(1){if((S|0)>=1024){break L64840}V=9638528+(S<<2)|0;if((c[V>>2]|0)==(O|0)){break}else{S=S+1|0}}gGr(O);c[V>>2]=0}}while(0);V=(c[3542028]|0)+4|0;S=a+2|0;U=A+100|0;c[U>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](A,S)|0;A=c[U>>2]|0;L64864:do{if((A|0)!=0){T=0;while(1){if((T|0)>=1024){break L64864}W=9638528+(T<<2)|0;if((c[W>>2]|0)==0){break}else{T=T+1|0}}T=gGq(A)|0;c[W>>2]=T;if((T|0)==0){break}gGz(T|0,0,A|0);do{if((c[3542200]|0)==0){X=0}else{O=p+108|0;c[O>>2]=0;Q=p+100|0;c[Q>>2]=0;P=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[P&16383](p,S)|0;if((c[O>>2]|0)!=0){O=c[Q>>2]|0;c[q>>2]=9534384;Q=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[Q&16383](q,S,0)|0;if((O|0)<1){X=0;break}if((gzL(T,0,S)|0)!=0){X=0;break}}O=c[U>>2]&-2;if((O|0)>0){Q=V;P=T;H=0;while(1){s=H+2|0;r=Q;c[r>>2]=c[9620648+((d[P+1|0]|0)<<2)>>2]<<1|c[9620648+((d[P]|0)<<2)>>2]|c[r>>2];if((s|0)<(O|0)){Q=Q+8|0;P=P+2|0;H=s}else{Y=0;break}}}else{Y=0}while(1){if((Y|0)>=1024){break L64864}Z=9638528+(Y<<2)|0;if((c[Z>>2]|0)==(T|0)){break}else{Y=Y+1|0}}gGr(T);c[Z>>2]=0;break L64864}}while(0);while(1){if((X|0)>=1024){break L64864}_=9638528+(X<<2)|0;if((c[_>>2]|0)==(T|0)){break}else{X=X+1|0}}gGr(T);c[_>>2]=0}}while(0);_=(c[3542028]|0)+2097156|0;X=a+3|0;Z=z+100|0;c[Z>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](z,X)|0;z=c[Z>>2]|0;L64888:do{if((z|0)!=0){Y=0;while(1){if((Y|0)>=1024){break L64888}$=9638528+(Y<<2)|0;if((c[$>>2]|0)==0){break}else{Y=Y+1|0}}Y=gGq(z)|0;c[$>>2]=Y;if((Y|0)==0){break}gGz(Y|0,0,z|0);do{if((c[3542200]|0)==0){aa=0}else{T=n+108|0;c[T>>2]=0;V=n+100|0;c[V>>2]=0;U=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[U&16383](n,X)|0;if((c[T>>2]|0)!=0){T=c[V>>2]|0;c[o>>2]=9534384;V=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[V&16383](o,X,0)|0;if((T|0)<1){aa=0;break}if((gzL(Y,0,X)|0)!=0){aa=0;break}}T=c[Z>>2]&-2;if((T|0)>0){V=_;U=Y;S=0;while(1){q=S+2|0;p=V;c[p>>2]=c[9620648+((d[U+1|0]|0)<<2)>>2]<<1|c[9620648+((d[U]|0)<<2)>>2]|c[p>>2];if((q|0)<(T|0)){V=V+8|0;U=U+2|0;S=q}else{ab=0;break}}}else{ab=0}while(1){if((ab|0)>=1024){break L64888}ac=9638528+(ab<<2)|0;if((c[ac>>2]|0)==(Y|0)){break}else{ab=ab+1|0}}gGr(Y);c[ac>>2]=0;break L64888}}while(0);while(1){if((aa|0)>=1024){break L64888}ad=9638528+(aa<<2)|0;if((c[ad>>2]|0)==(Y|0)){break}else{aa=aa+1|0}}gGr(Y);c[ad>>2]=0}}while(0);ad=c[3542028]|0;aa=a+4|0;ac=y+100|0;c[ac>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](y,aa)|0;y=c[ac>>2]|0;L64912:do{if((y|0)!=0){ab=0;while(1){if((ab|0)>=1024){break L64912}ae=9638528+(ab<<2)|0;if((c[ae>>2]|0)==0){break}else{ab=ab+1|0}}ab=gGq(y)|0;c[ae>>2]=ab;if((ab|0)==0){break}gGz(ab|0,0,y|0);do{if((c[3542200]|0)==0){af=0}else{Y=l+108|0;c[Y>>2]=0;_=l+100|0;c[_>>2]=0;Z=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[Z&16383](l,aa)|0;if((c[Y>>2]|0)!=0){Y=c[_>>2]|0;c[m>>2]=9534384;_=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[_&16383](m,aa,0)|0;if((Y|0)<1){af=0;break}if((gzL(ab,0,aa)|0)!=0){af=0;break}}Y=c[ac>>2]&-2;if((Y|0)>0){_=ad;Z=ab;X=0;while(1){o=X+2|0;n=_;c[n>>2]=(c[9620648+((d[Z+1|0]|0)<<2)>>2]<<1|c[9620648+((d[Z]|0)<<2)>>2])<<2|c[n>>2];if((o|0)<(Y|0)){_=_+8|0;Z=Z+2|0;X=o}else{ag=0;break}}}else{ag=0}while(1){if((ag|0)>=1024){break L64912}ah=9638528+(ag<<2)|0;if((c[ah>>2]|0)==(ab|0)){break}else{ag=ag+1|0}}gGr(ab);c[ah>>2]=0;break L64912}}while(0);while(1){if((af|0)>=1024){break L64912}ai=9638528+(af<<2)|0;if((c[ai>>2]|0)==(ab|0)){break}else{af=af+1|0}}gGr(ab);c[ai>>2]=0}}while(0);ai=(c[3542028]|0)+2097152|0;af=a+5|0;ah=x+100|0;c[ah>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](x,af)|0;x=c[ah>>2]|0;L64936:do{if((x|0)!=0){ag=0;while(1){if((ag|0)>=1024){break L64936}aj=9638528+(ag<<2)|0;if((c[aj>>2]|0)==0){break}else{ag=ag+1|0}}ag=gGq(x)|0;c[aj>>2]=ag;if((ag|0)==0){break}gGz(ag|0,0,x|0);do{if((c[3542200]|0)==0){ak=0}else{ab=j+108|0;c[ab>>2]=0;ad=j+100|0;c[ad>>2]=0;ac=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ac&16383](j,af)|0;if((c[ab>>2]|0)!=0){ab=c[ad>>2]|0;c[k>>2]=9534384;ad=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ad&16383](k,af,0)|0;if((ab|0)<1){ak=0;break}if((gzL(ag,0,af)|0)!=0){ak=0;break}}ab=c[ah>>2]&-2;if((ab|0)>0){ad=ai;ac=ag;aa=0;while(1){m=aa+2|0;l=ad;c[l>>2]=(c[9620648+((d[ac+1|0]|0)<<2)>>2]<<1|c[9620648+((d[ac]|0)<<2)>>2])<<2|c[l>>2];if((m|0)<(ab|0)){ad=ad+8|0;ac=ac+2|0;aa=m}else{al=0;break}}}else{al=0}while(1){if((al|0)>=1024){break L64936}am=9638528+(al<<2)|0;if((c[am>>2]|0)==(ag|0)){break}else{al=al+1|0}}gGr(ag);c[am>>2]=0;break L64936}}while(0);while(1){if((ak|0)>=1024){break L64936}an=9638528+(ak<<2)|0;if((c[an>>2]|0)==(ag|0)){break}else{ak=ak+1|0}}gGr(ag);c[an>>2]=0}}while(0);an=(c[3542028]|0)+4|0;ak=a+6|0;am=w+100|0;c[am>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](w,ak)|0;w=c[am>>2]|0;L64960:do{if((w|0)!=0){al=0;while(1){if((al|0)>=1024){break L64960}ao=9638528+(al<<2)|0;if((c[ao>>2]|0)==0){break}else{al=al+1|0}}al=gGq(w)|0;c[ao>>2]=al;if((al|0)==0){break}gGz(al|0,0,w|0);do{if((c[3542200]|0)==0){ap=0}else{ag=g+108|0;c[ag>>2]=0;ai=g+100|0;c[ai>>2]=0;ah=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ah&16383](g,ak)|0;if((c[ag>>2]|0)!=0){ag=c[ai>>2]|0;c[h>>2]=9534384;ai=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[ai&16383](h,ak,0)|0;if((ag|0)<1){ap=0;break}if((gzL(al,0,ak)|0)!=0){ap=0;break}}ag=c[am>>2]&-2;if((ag|0)>0){ai=an;ah=al;af=0;while(1){k=af+2|0;j=ai;c[j>>2]=(c[9620648+((d[ah+1|0]|0)<<2)>>2]<<1|c[9620648+((d[ah]|0)<<2)>>2])<<2|c[j>>2];if((k|0)<(ag|0)){ai=ai+8|0;ah=ah+2|0;af=k}else{aq=0;break}}}else{aq=0}while(1){if((aq|0)>=1024){break L64960}ar=9638528+(aq<<2)|0;if((c[ar>>2]|0)==(al|0)){break}else{aq=aq+1|0}}gGr(al);c[ar>>2]=0;break L64960}}while(0);while(1){if((ap|0)>=1024){break L64960}as=9638528+(ap<<2)|0;if((c[as>>2]|0)==(al|0)){break}else{ap=ap+1|0}}gGr(al);c[as>>2]=0}}while(0);as=(c[3542028]|0)+2097156|0;ap=a+7|0;a=v+100|0;c[a>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](v,ap)|0;v=c[a>>2]|0;if((v|0)==0){i=b;return 0}else{at=0}while(1){if((at|0)>=1024){au=50001;break}av=9638528+(at<<2)|0;if((c[av>>2]|0)==0){break}else{at=at+1|0}}if((au|0)==50001){i=b;return 0}at=gGq(v)|0;c[av>>2]=at;if((at|0)==0){i=b;return 0}gGz(at|0,0,v|0);do{if((c[3542200]|0)==0){aw=0}else{v=e+108|0;c[v>>2]=0;av=e+100|0;c[av>>2]=0;ar=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[ar&16383](e,ap)|0;if((c[v>>2]|0)!=0){v=c[av>>2]|0;c[f>>2]=9534384;av=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[av&16383](f,ap,0)|0;if((v|0)<1){aw=0;break}if((gzL(at,0,ap)|0)!=0){aw=0;break}}v=c[a>>2]&-2;if((v|0)>0){av=as;ar=at;aq=0;while(1){an=aq+2|0;am=av;c[am>>2]=(c[9620648+((d[ar+1|0]|0)<<2)>>2]<<1|c[9620648+((d[ar]|0)<<2)>>2])<<2|c[am>>2];if((an|0)<(v|0)){av=av+8|0;ar=ar+2|0;aq=an}else{ax=0;break}}}else{ax=0}while(1){if((ax|0)>=1024){au=50005;break}ay=9638528+(ax<<2)|0;if((c[ay>>2]|0)==(at|0)){break}else{ax=ax+1|0}}if((au|0)==50005){i=b;return 0}gGr(at);c[ay>>2]=0;i=b;return 0}}while(0);while(1){if((aw|0)>=1024){au=50003;break}az=9638528+(aw<<2)|0;if((c[az>>2]|0)==(at|0)){break}else{aw=aw+1|0}}if((au|0)==50003){i=b;return 0}gGr(at);c[az>>2]=0;i=b;return 0}function Wk(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;e=i;i=i+352|0;f=e|0;g=e+112|0;h=e+120|0;j=e+232|0;k=e+240|0;l=k+100|0;c[l>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,d)|0;m=c[l>>2]|0;L65019:do{if((m|0)==0){n=0;o=50018}else{p=0;while(1){if((p|0)>=1024){n=0;o=50018;break L65019}q=9638528+(p<<2)|0;if((c[q>>2]|0)==0){break}else{p=p+1|0}}p=gGq(m)|0;c[q>>2]=p;if((p|0)==0){n=0;o=50018;break}gGz(p|0,0,m|0);do{if((c[3542200]|0)==0){r=0}else{s=h+108|0;c[s>>2]=0;t=h+100|0;c[t>>2]=0;u=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[u&16383](h,d)|0;if((c[s>>2]|0)==0){v=p;break L65019}s=c[t>>2]|0;c[j>>2]=9534384;t=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[t&16383](j,d,0)|0;if((s|0)<1){r=0;break}if((gzL(p,0,d)|0)==0){v=p;break L65019}else{r=0}}}while(0);while(1){if((r|0)>=1024){n=0;o=50018;break L65019}w=9638528+(r<<2)|0;if((c[w>>2]|0)==(p|0)){break}else{r=r+1|0}}gGr(p);c[w>>2]=0;n=0;o=50018}}while(0);L65033:do{if((o|0)==50018){while(1){o=0;if((n|0)>=1024){x=0;break}y=9638528+(n<<2)|0;if((c[y>>2]|0)==0){o=50020;break}else{n=n+1|0;o=50018}}if((o|0)==50020){gGr(0);c[y>>2]=0;x=0}while(1){if((x|0)>=1024){v=0;break L65033}z=9638528+(x<<2)|0;if((c[z>>2]|0)==0){break}else{x=x+1|0}}gGr(0);c[z>>2]=0;v=0}}while(0);z=d+2|0;c[l>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,z)|0;k=c[l>>2]|0;L65044:do{if((k|0)==0){A=0;o=50043}else{l=0;while(1){if((l|0)>=1024){A=0;o=50043;break L65044}B=9638528+(l<<2)|0;if((c[B>>2]|0)==0){break}else{l=l+1|0}}l=gGq(k)|0;c[B>>2]=l;if((l|0)==0){A=0;o=50043;break}gGz(l|0,0,k|0);do{if((c[3542200]|0)==0){C=0}else{d=f+108|0;c[d>>2]=0;x=f+100|0;c[x>>2]=0;y=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[y&16383](f,z)|0;if((c[d>>2]|0)==0){D=v;E=l;break L65044}d=c[x>>2]|0;c[g>>2]=9534384;x=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[x&16383](g,z,0)|0;if((d|0)<1){C=0;break}if((gzL(l,0,z)|0)==0){D=v;E=l;break L65044}else{C=0}}}while(0);while(1){if((C|0)>=1024){A=0;o=50043;break L65044}F=9638528+(C<<2)|0;if((c[F>>2]|0)==(l|0)){break}else{C=C+1|0}}gGr(l);c[F>>2]=0;A=0;o=50043}}while(0);L65058:do{if((o|0)==50043){while(1){o=0;if((A|0)>=1024){G=0;break}H=9638528+(A<<2)|0;if((c[H>>2]|0)==(v|0)){o=50045;break}else{A=A+1|0;o=50043}}if((o|0)==50045){gGr(v);c[H>>2]=0;G=0}while(1){if((G|0)>=1024){D=0;E=0;break L65058}I=9638528+(G<<2)|0;if((c[I>>2]|0)==0){break}else{G=G+1|0}}gGr(0);c[I>>2]=0;D=0;E=0}}while(0);I=0;while(1){G=I<<1;a[b+I|0]=a[D+G|0]|0;a[b+(I+4096)|0]=a[E+G|0]|0;G=I+1|0;if((G|0)<4096){I=G}else{J=0;break}}while(1){if((J|0)>=1024){K=0;break}L=9638528+(J<<2)|0;if((c[L>>2]|0)==(D|0)){o=50028;break}else{J=J+1|0}}if((o|0)==50028){gGr(D);c[L>>2]=0;K=0}while(1){if((K|0)>=1024){o=50050;break}M=9638528+(K<<2)|0;if((c[M>>2]|0)==(E|0)){break}else{K=K+1|0}}if((o|0)==50050){i=e;return}gGr(E);c[M>>2]=0;i=e;return}function Wl(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;d=i;i=i+352|0;e=d|0;f=d+112|0;g=d+120|0;h=d+232|0;j=d+240|0;k=j+100|0;c[k>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,15)|0;l=c[k>>2]|0;L65084:do{if((l|0)==0){m=0;n=50063}else{o=0;while(1){if((o|0)>=1024){m=0;n=50063;break L65084}p=9638528+(o<<2)|0;if((c[p>>2]|0)==0){break}else{o=o+1|0}}o=gGq(l)|0;c[p>>2]=o;if((o|0)==0){m=0;n=50063;break}gGz(o|0,0,l|0);do{if((c[3542200]|0)==0){q=0}else{r=g+108|0;c[r>>2]=0;s=g+100|0;c[s>>2]=0;t=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[t&16383](g,15)|0;if((c[r>>2]|0)==0){u=o;break L65084}r=c[s>>2]|0;c[h>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](h,15,0)|0;if((r|0)<1){q=0;break}if((gzL(o,0,15)|0)==0){u=o;break L65084}else{q=0}}}while(0);while(1){if((q|0)>=1024){m=0;n=50063;break L65084}v=9638528+(q<<2)|0;if((c[v>>2]|0)==(o|0)){break}else{q=q+1|0}}gGr(o);c[v>>2]=0;m=0;n=50063}}while(0);L65098:do{if((n|0)==50063){while(1){n=0;if((m|0)>=1024){w=0;break}x=9638528+(m<<2)|0;if((c[x>>2]|0)==0){n=50065;break}else{m=m+1|0;n=50063}}if((n|0)==50065){gGr(0);c[x>>2]=0;w=0}while(1){if((w|0)>=1024){u=0;break L65098}y=9638528+(w<<2)|0;if((c[y>>2]|0)==0){break}else{w=w+1|0}}gGr(0);c[y>>2]=0;u=0}}while(0);c[k>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](j,18)|0;j=c[k>>2]|0;L65109:do{if((j|0)==0){z=0;n=50088}else{k=0;while(1){if((k|0)>=1024){z=0;n=50088;break L65109}A=9638528+(k<<2)|0;if((c[A>>2]|0)==0){break}else{k=k+1|0}}k=gGq(j)|0;c[A>>2]=k;if((k|0)==0){z=0;n=50088;break}gGz(k|0,0,j|0);do{if((c[3542200]|0)==0){B=0}else{y=e+108|0;c[y>>2]=0;w=e+100|0;c[w>>2]=0;x=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[x&16383](e,18)|0;if((c[y>>2]|0)==0){C=u;D=k;break L65109}y=c[w>>2]|0;c[f>>2]=9534384;w=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[w&16383](f,18,0)|0;if((y|0)<1){B=0;break}if((gzL(k,0,18)|0)==0){C=u;D=k;break L65109}else{B=0}}}while(0);while(1){if((B|0)>=1024){z=0;n=50088;break L65109}E=9638528+(B<<2)|0;if((c[E>>2]|0)==(k|0)){break}else{B=B+1|0}}gGr(k);c[E>>2]=0;z=0;n=50088}}while(0);L65123:do{if((n|0)==50088){while(1){n=0;if((z|0)>=1024){F=0;break}G=9638528+(z<<2)|0;if((c[G>>2]|0)==(u|0)){n=50090;break}else{z=z+1|0;n=50088}}if((n|0)==50090){gGr(u);c[G>>2]=0;F=0}while(1){if((F|0)>=1024){C=0;D=0;break L65123}H=9638528+(F<<2)|0;if((c[H>>2]|0)==0){break}else{F=F+1|0}}gGr(0);c[H>>2]=0;C=0;D=0}}while(0);H=0;while(1){F=H<<1;a[b+H|0]=a[C+F|0]|0;a[b+(H+4096)|0]=a[D+F|0]|0;F=H+1|0;if((F|0)<4096){H=F}else{I=0;break}}while(1){if((I|0)>=1024){J=0;break}K=9638528+(I<<2)|0;if((c[K>>2]|0)==(C|0)){n=50073;break}else{I=I+1|0}}if((n|0)==50073){gGr(C);c[K>>2]=0;J=0}while(1){if((J|0)>=1024){n=50096;break}L=9638528+(J<<2)|0;if((c[L>>2]|0)==(D|0)){break}else{J=J+1|0}}if((n|0)==50096){i=d;return}gGr(D);c[L>>2]=0;i=d;return}function Wm(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;h=i;i=i+464|0;j=h|0;k=h+112|0;l=h+120|0;m=h+232|0;n=h+240|0;o=h+352|0;p=o+100|0;c[p>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](o,e)|0;o=c[p>>2]|0;if((o|0)==0){i=h;return}else{q=0}while(1){if((q|0)>=1024){r=50159;break}s=9638528+(q<<2)|0;if((c[s>>2]|0)==0){break}else{q=q+1|0}}if((r|0)==50159){i=h;return}q=gGq(o)|0;c[s>>2]=q;if((q|0)==0){i=h;return}gGz(q|0,0,o|0);do{if((c[3542200]|0)==0){t=0}else{o=l+108|0;c[o>>2]=0;s=l+100|0;c[s>>2]=0;u=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[u&16383](l,e)|0;if((c[o>>2]|0)!=0){o=c[s>>2]|0;c[m>>2]=9534384;s=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[s&16383](m,e,0)|0;if((o|0)<1){t=0;break}if((gzL(q,0,e)|0)!=0){t=0;break}}o=c[p>>2]|0;L65166:do{if((f|0)==0){s=e+1|0;u=n+100|0;c[u>>2]=0;v=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[v&16383](n,s)|0;v=c[u>>2]|0;if((v|0)==0){i=h;return}else{w=0}while(1){if((w|0)>=1024){r=50155;break}x=9638528+(w<<2)|0;if((c[x>>2]|0)==0){break}else{w=w+1|0}}if((r|0)==50155){i=h;return}y=gGq(v)|0;c[x>>2]=y;if((y|0)==0){i=h;return}gGz(y|0,0,v|0);do{if((c[3542200]|0)==0){z=0}else{A=j+108|0;c[A>>2]=0;B=j+100|0;c[B>>2]=0;C=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[C&16383](j,s)|0;if((c[A>>2]|0)!=0){A=c[B>>2]|0;c[k>>2]=9534384;B=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[B&16383](k,s,0)|0;if((A|0)<1){z=0;break}if((gzL(y,0,s)|0)!=0){z=0;break}}A=c[u>>2]|0;B=o<<1;C=0;while(1){if((C|0)>=1024){D=0;break}E=9638528+(C<<2)|0;if((c[E>>2]|0)==0){r=50123;break}else{C=C+1|0}}do{if((r|0)==50123){C=gGq(B)|0;c[E>>2]=C;if((C|0)==0){D=0;break}gGz(C|0,0,B|0);if((A|0)>0){F=0;while(1){G=F<<1;a[C+G|0]=a[q+F|0]|0;a[C+(G|1)|0]=a[y+F|0]|0;G=F+1|0;if((G|0)<(A|0)){F=G}else{H=0;break}}}else{H=0}while(1){if((H|0)>=1024){I=0;break}J=9638528+(H<<2)|0;if((c[J>>2]|0)==(y|0)){r=50134;break}else{H=H+1|0}}if((r|0)==50134){gGr(y);c[J>>2]=0;I=0}while(1){if((I|0)>=1024){K=B;L=C;break L65166}M=9638528+(I<<2)|0;if((c[M>>2]|0)==(q|0)){break}else{I=I+1|0}}gGr(q);c[M>>2]=0;K=B;L=C;break L65166}}while(0);while(1){if((D|0)>=1024){N=0;break}O=9638528+(D<<2)|0;if((c[O>>2]|0)==(y|0)){r=50127;break}else{D=D+1|0}}if((r|0)==50127){gGr(y);c[O>>2]=0;N=0}while(1){if((N|0)>=1024){r=50156;break}P=9638528+(N<<2)|0;if((c[P>>2]|0)==(q|0)){break}else{N=N+1|0}}if((r|0)==50156){i=h;return}gGr(q);c[P>>2]=0;i=h;return}}while(0);while(1){if((z|0)>=1024){r=50149;break}Q=9638528+(z<<2)|0;if((c[Q>>2]|0)==(y|0)){break}else{z=z+1|0}}if((r|0)==50149){i=h;return}gGr(y);c[Q>>2]=0;i=h;return}else{K=o;L=q}}while(0);o=K>>19;if((o|0)>0){u=b;s=L;v=0;while(1){B=u+1048576|0;A=u;F=s;while(1){G=A;c[G>>2]=(c[9620648+((d[F+1|0]|0)<<2)>>2]<<1|c[9620648+((d[F]|0)<<2)>>2])<<g|c[G>>2];G=A+8|0;if(G>>>0<B>>>0){A=G;F=F+4|0}else{break}}F=u+2097152|0;A=B;y=s+2|0;while(1){G=A;c[G>>2]=(c[9620648+((d[y+1|0]|0)<<2)>>2]<<1|c[9620648+((d[y]|0)<<2)>>2])<<g|c[G>>2];G=A+8|0;if(G>>>0<F>>>0){A=G;y=y+4|0}else{break}}y=v+1|0;if((y|0)<(o|0)){u=F;s=s+524288|0;v=y}else{R=0;break}}}else{R=0}while(1){if((R|0)>=1024){r=50161;break}S=9638528+(R<<2)|0;if((c[S>>2]|0)==(L|0)){break}else{R=R+1|0}}if((r|0)==50161){i=h;return}gGr(L);c[S>>2]=0;i=h;return}}while(0);while(1){if((t|0)>=1024){r=50150;break}T=9638528+(t<<2)|0;if((c[T>>2]|0)==(q|0)){break}else{t=t+1|0}}if((r|0)==50150){i=h;return}gGr(q);c[T>>2]=0;i=h;return}function Wn(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;g=i;i=i+264|0;h=g|0;j=g+112|0;k=g+120|0;l=g+232|0;m=k+100|0;c[m>>2]=0;if((f|0)>0){n=0}else{i=g;return}while(1){gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,n+b|0)|0;c[l+(n<<2)>>2]=c[m>>2];o=n+1|0;if((o|0)<(f|0)){n=o}else{p=0;q=0;break}}do{p=(c[l+(q<<2)>>2]|0)+p|0;q=q+1|0;}while((q|0)<(f|0));if((p|0)==0){i=g;return}else{r=0}while(1){if((r|0)>=1024){s=50190;break}t=9638528+(r<<2)|0;if((c[t>>2]|0)==0){break}else{r=r+1|0}}if((s|0)==50190){i=g;return}r=gGq(p)|0;c[t>>2]=r;if((r|0)==0){i=g;return}gGz(r|0,0,p|0);t=h+108|0;q=h+100|0;n=0;m=0;while(1){if((n|0)>0){u=(c[l+(n-1<<2)>>2]|0)+m|0}else{u=m}k=r+u|0;o=n+b|0;if((c[3542200]|0)==0){v=0;s=50177;break}c[t>>2]=0;c[q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](h,o)|0;if((c[t>>2]|0)!=0){w=c[q>>2]|0;c[j>>2]=9534384;x=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[x&16383](j,o,0)|0;if((w|0)<1){v=0;s=50177;break}if((gzL(k,0,o)|0)!=0){v=0;s=50177;break}}o=n+1|0;if((o|0)<(f|0)){n=o;m=u}else{break}}if((s|0)==50177){while(1){s=0;if((v|0)>=1024){s=50196;break}y=9638528+(v<<2)|0;if((c[y>>2]|0)==(r|0)){break}else{v=v+1|0;s=50177}}if((s|0)==50196){i=g;return}gGr(r);c[y>>2]=0;i=g;return}y=p>>19;if((y|0)>0){p=a;a=r;v=0;while(1){u=p+1048576|0;m=p;n=a;while(1){f=m;c[f>>2]=(c[9620648+((d[n+1|0]|0)<<2)>>2]<<1|c[9620648+((d[n]|0)<<2)>>2])<<e|c[f>>2];f=m+8|0;if(f>>>0<u>>>0){m=f;n=n+4|0}else{break}}n=p+2097152|0;m=u;f=a+2|0;while(1){j=m;c[j>>2]=(c[9620648+((d[f+1|0]|0)<<2)>>2]<<1|c[9620648+((d[f]|0)<<2)>>2])<<e|c[j>>2];j=m+8|0;if(j>>>0<n>>>0){m=j;f=f+4|0}else{break}}f=v+1|0;if((f|0)<(y|0)){p=n;a=a+524288|0;v=f}else{z=0;break}}}else{z=0}while(1){if((z|0)>=1024){s=50193;break}A=9638528+(z<<2)|0;if((c[A>>2]|0)==(r|0)){break}else{z=z+1|0}}if((s|0)==50193){i=g;return}gGr(r);c[A>>2]=0;i=g;return}function Wo(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[3542068]|0;if((b|0)==1){c[2424]=5961}else if((b|0)==2){c[2424]=5962}d=c[2113296]|0;do{if((d|0)==0){if((b&1|0)==0){c[2113296]=118e5;e=118e7;break}else{c[2113296]=1e7;e=1e9;break}}else{e=d*100|0}}while(0);c[2113296]=(e|0)/(c[2424]|0)|0;e=c[2113246]|0;d=(c[2113250]|0)+(c[2113268]|0)+(c[2113272]|0)+e+(c[2113252]|0)+(c[2113274]|0)|0;if(a[7462128]|0){f=d+(e<<1)|0}else{f=d}d=0;while(1){if((d|0)>=1024){break}g=9638528+(d<<2)|0;if((c[g>>2]|0)==0){h=50211;break}else{d=d+1|0}}do{if((h|0)==50211){d=gGq(f)|0;c[g>>2]=d;if((d|0)==0){break}gGz(d|0,0,f|0);c[3542028]=d;gGz(d|0,0,f|0);e=c[2113268]|0;c[3541922]=d+e;b=(c[2113250]|0)+e|0;c[3542034]=d+b;i=(c[2113272]|0)+b|0;b=d+i|0;if(a[7462128]|0){c[3542032]=b;j=c[2113246]|0;k=d+((j<<1)+i)|0;l=j}else{k=b;l=c[2113246]|0}c[3541874]=k;c[3541940]=k+l;c[3542044]=k+((c[2113252]|0)+l);b=0;while(1){m=1<<b;if((b|0)>=31){break}if((m|0)<(e|0)){b=b+1|0}else{break}}c[2113266]=m-1;b=c[3542068]<<23&8388608^8388608;c[2113260]=b;c[2113262]=b;c[2113264]=b;if(!(a[607976]|0)){b=0;do{e=255-b|0;j=e<<12&983040|e&15;e=j<<6&50332416|j&196611;c[9620648+(b<<2)>>2]=e<<3&269488144|e&16843009;b=b+1|0;}while((b|0)<256);a[607976]=1}a[14167696]=0;a[14168280]=0;a[14168288]=0;a[14168296]=0;c[3542042]=50;c[3542040]=0;c[3542038]=0;c[3541956]=64;c[3541957]=66;c[3541958]=68;c[3541959]=70;c[2113258]=102;c[3541186]=104;c[3541187]=106;c[3541188]=108;c[3541189]=110;c[2113254]=112;c[3541969]=2;c[3541970]=4;c[3541971]=8;n=0;return n|0}}while(0);c[3542028]=0;n=1;return n|0}function Wp(){var a=0;c[3542068]=2;if((Wq(0)|0)!=0){a=1;return a|0}Wo()|0;if((Wq(1)|0)!=0){a=1;return a|0}a=agT()|0;return a|0}function Wq(d){d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0;e=i;i=i+11248|0;f=e|0;g=e+16|0;h=e+5136|0;j=e+10256|0;k=e+10264|0;l=e+10280|0;m=e+10536|0;n=e+10648|0;o=e+10656|0;p=e+10768|0;q=e+10776|0;r=e+10888|0;s=e+10896|0;t=e+11008|0;u=e+11016|0;v=e+11128|0;w=e+11136|0;x=c[3542034]|0;y=c[3541922]|0;z=c[3542028]|0;A=c[3541874]|0;B=c[3541940]|0;do{if(d){if((x|0)==0|(y|0)==0|(z|0)==0|(A|0)==0|(B|0)==0){C=1}else{break}i=e;return C|0}else{c[2113252]=0;c[2113246]=0;c[2113268]=0;c[2113250]=0;c[2113272]=0;c[2443926]=0;if((c[(c[642608+(c[2436]<<2)>>2]|0)+60>>2]&2|0)==0){break}c[2443926]=-1}}while(0);D=w+100|0;E=w+108|0;F=u+108|0;G=u+100|0;H=s+108|0;I=s+100|0;J=q+108|0;K=q+100|0;L=o+108|0;M=o+100|0;N=m+108|0;O=m+100|0;P=0;Q=0;R=B;B=A;A=z;z=y;y=x;while(1){c[D>>2]=0;c[E>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](w,P)|0;x=c[E>>2]|0;if((x&15|0)==1){if(d){do{if((c[3542200]|0)!=0){c[F>>2]=0;c[G>>2]=0;S=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[S&16383](u,P)|0;if((c[F>>2]|0)==0){break}S=c[G>>2]|0;c[v>>2]=9534384;T=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[T&16383](v,P,0)|0;if((S|0)<1){break}gzL(z,0,P)|0}}while(0);U=z+(c[D>>2]|0)|0;V=c[E>>2]|0}else{c[2113250]=(c[2113250]|0)+(c[D>>2]|0);U=z;V=x}W=P+1|0;X=U;Y=V}else{W=P;X=z;Y=x}do{if((Y&15|0)==2){if(d){S=X+1|0;R6(S,W,2)|0;S=W+1|0;R6(X,S,2)|0;Z=W+2|0;_=X+(c[D>>2]<<1)|0;$=c[E>>2]|0;break}else{c[2113250]=(c[2113250]|0)+(c[D>>2]|0);Z=W+1|0;_=X;$=Y;break}}else{Z=W;_=X;$=Y}}while(0);if(($&15|0)==3){if(d){do{if((c[3542200]|0)!=0){c[H>>2]=0;c[I>>2]=0;x=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[x&16383](s,Z)|0;if((c[H>>2]|0)==0){break}x=c[I>>2]|0;c[t>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](t,Z,0)|0;if((x|0)<1){break}gzL(y,0,Z)|0}}while(0);aa=y+(c[D>>2]|0)|0;ab=c[E>>2]|0}else{c[2113272]=(c[2113272]|0)+(c[D>>2]|0);aa=y;ab=$}ac=Z+1|0;ad=aa;ae=ab}else{ac=Z;ad=y;ae=$}do{if((ae&15|0)==5){if(d){Wm(A,ac,1,0);Wm(A,ac+1|0,1,2);x=A+4|0;Wm(x,ac+2|0,1,0);Wm(x,ac+3|0,1,2);x=c[2443926]|0;af=ac+4|0;ah=Q;ai=A+(((x|0)==-1?c[D>>2]|0:x)<<2)|0;aj=c[E>>2]|0;break}x=c[D>>2]|0;S=c[2443926]|0;if(x>>>0>S>>>0){c[2443926]=x;ak=x}else{ak=S}if(x>>>0<ak>>>0){c[2443926]=-1}c[2113268]=(c[2113268]|0)+x;af=ac+1|0;ah=Q+1|0;ai=A;aj=ae}else{af=ac;ah=Q;ai=A;aj=ae}}while(0);do{if((aj&15|0)==6){if(d){Wm(ai,af,0,0);Wm(ai,af+2|0,0,2);x=ai+4|0;Wm(x,af+4|0,0,0);Wm(x,af+6|0,0,2);al=af+8|0;am=ai+(c[D>>2]<<3)|0;an=c[E>>2]|0;break}else{c[2113268]=(c[2113268]|0)+(c[D>>2]|0);al=af+1|0;am=ai;an=aj;break}}else{al=af;am=ai;an=aj}}while(0);do{if((an&15|0)==7){if(d){Wn(am,al,0,4);Wn(am,al+4|0,2,4);x=am+4|0;Wn(x,al+8|0,0,4);Wn(x,al+12|0,2,4);x=c[2443926]|0;ao=al+16|0;ap=ah;aq=am+(((x|0)==-1?c[D>>2]|0:x)<<4)|0;ar=c[E>>2]|0;break}x=c[D>>2]|0;S=c[2443926]|0;if(x>>>0>S>>>0){c[2443926]=x;as=x}else{as=S}if(x>>>0<as>>>0){c[2443926]=-1}c[2113268]=(c[2113268]|0)+x;ao=al+1|0;ap=ah+1|0;aq=am;ar=an}else{ao=al;ap=ah;aq=am;ar=an}}while(0);do{if((ar&15|0)==8){if(d){Wn(aq,ao,0,8);Wn(aq,ao+8|0,2,8);x=aq+4|0;Wn(x,ao+16|0,0,8);Wn(x,ao+24|0,2,8);x=c[2443926]|0;at=ao+32|0;au=ap;av=aq+(((x|0)==-1?c[D>>2]|0:x)<<5)|0;aw=c[E>>2]|0;break}x=c[D>>2]|0;S=c[2443926]|0;if(x>>>0>S>>>0){c[2443926]=x;ax=x}else{ax=S}if(x>>>0<ax>>>0){c[2443926]=-1}c[2113268]=(c[2113268]|0)+x;at=ao+1|0;au=ap+1|0;av=aq;aw=ar}else{at=ao;au=ap;av=aq;aw=ar}}while(0);if((aw&15|0)==10){if(d){do{if((c[3542200]|0)!=0){c[J>>2]=0;c[K>>2]=0;x=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[x&16383](q,at)|0;if((c[J>>2]|0)==0){break}x=c[K>>2]|0;c[r>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](r,at,0)|0;if((x|0)<1){break}gzL(B,0,at)|0}}while(0);ay=B+(c[D>>2]|0)|0;az=c[E>>2]|0}else{c[2113246]=(c[2113246]|0)+(c[D>>2]|0);ay=B;az=aw}aA=at+1|0;aB=ay;aC=az}else{aA=at;aB=B;aC=aw}if((aC&15|0)==12){if(d){do{if((c[3542200]|0)!=0){c[L>>2]=0;c[M>>2]=0;x=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[x&16383](o,aA)|0;if((c[L>>2]|0)==0){break}x=c[M>>2]|0;c[p>>2]=9534384;S=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[S&16383](p,aA,0)|0;if((x|0)<1){break}gzL(R,0,aA)|0}}while(0);x=c[D>>2]|0;S=x>>1;if((S|0)>0){T=0;aD=R;while(1){aE=a[aD]|0;aF=aD+1|0;a[aD]=a[aF]|0;a[aF]=aE;aE=T+1|0;if((aE|0)<(S|0)){T=aE;aD=aD+2|0}else{break}}aG=c[D>>2]|0}else{aG=x}aH=R+aG|0;aI=c[E>>2]|0}else{c[2113252]=(c[2113252]|0)+(c[D>>2]|0);aH=R;aI=aC}aJ=aA+1|0;aK=aH;aL=aI}else{aJ=aA;aK=R;aL=aC}if((aL&15|0)==13){if(d){do{if((c[3542200]|0)!=0){c[N>>2]=0;c[O>>2]=0;aD=c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]|0;gA[aD&16383](m,aJ)|0;if((c[N>>2]|0)==0){break}aD=c[O>>2]|0;c[n>>2]=9534384;T=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[T&16383](n,aJ,0)|0;if((aD|0)<1){break}gzL(aK,0,aJ)|0}}while(0);x=c[D>>2]|0;aD=x>>1;if((aD|0)>0){T=0;S=aK;while(1){aE=a[S]|0;aF=S+1|0;a[S]=a[aF]|0;a[aF]=aE;aE=T+1|0;if((aE|0)<(aD|0)){T=aE;S=S+2|0}else{break}}aM=c[D>>2]|0}else{aM=x}aN=aK+aM|0;aO=c[E>>2]|0}else{c[2113252]=(c[2113252]|0)+(c[D>>2]|0);aN=aK;aO=aL}aP=aJ+1|0;aQ=aN;aR=aO}else{aP=aJ;aQ=aK;aR=aL}do{if((aR&15|0)==14){if(d){S=aQ+1|0;R6(S,aP,2)|0;S=aP+1|0;R6(aQ,S,2)|0;aS=aP+2|0;break}else{c[2113252]=(c[2113252]|0)+(c[D>>2]|0);aS=aP+1|0;break}}else{aS=aP}}while(0);if((c[D>>2]|0)==0){break}else{P=aS;Q=au;R=aQ;B=aB;A=av;z=_;y=ad}}L65479:do{if(d){ad=c[c[642608+(c[2436]<<2)>>2]>>2]|0;y=7349960;while(1){_=c[y>>2]|0;if((_|0)==0){aT=50349;break}if((fa(_|0,ad|0)|0)==0){break}else{y=y+16|0}}if((aT|0)==50349){ad=c[3542034]|0;if((ad|0)==0){break}_=c[3541922]|0;z=ad;ad=c[2113272]|0;av=(ad|0)/2|0;if((ad|0)>1){aU=0}else{break}while(1){ad=z+(aU<<1)|0;b[ad>>1]=b[ad>>1]^b[_+(aU<<1)>>1];aU=aU+1|0;if((aU|0)>=(av|0)){break L65479}}}av=c[y+12>>2]|0;_=(av|0)==0?c[2113250]|0:av;c[2113272]=_;av=f;z=k;ad=l|0;A=c[3541922]|0;aB=0;while(1){if((aB|0)>=1024){aV=0;break}aW=9638528+(aB<<2)|0;if((c[aW>>2]|0)==0){aT=50333;break}else{aB=aB+1|0}}do{if((aT|0)==50333){aB=gGq(_)|0;c[aW>>2]=aB;if((aB|0)==0){aV=0;break}gGz(aB|0,0,_|0);aV=aB}}while(0);c[3542034]=aV;aB=g|0;Xa(aB,6578352);B=g+1280|0;Xa(B,6577968);aQ=g+2560|0;Xa(aQ,6577584);R=g+3840|0;Xa(R,6577200);Q=h|0;Xa(Q,6576816);aS=h+1280|0;Xa(aS,6576432);P=h+2560|0;Xa(P,6576048);D=h+3840|0;Xa(D,6575664);gGz(av|0,0,16);aP=0;do{aR=c[603360+(aP<<2)>>2]|0;aL=f+(((aP|0)/24|0)<<2)|0;c[aL>>2]=c[aL>>2]|((c[y+4+(((aR|0)/32|0)<<2)>>2]|0)>>>((aR&31)>>>0)&1)<<((aP|0)%24|0);aP=aP+1|0;}while((aP|0)<96);aP=y+4|0;av=A;aR=aV;aL=f|0;aK=c[aL>>2]|0;aJ=aK>>>1<<4&16^aK;aK=aJ>>>2<<5&32^aJ;aJ=aK>>>8<<11&2048^aK;c[aL>>2]=aJ;aL=f+4|0;aK=c[aL>>2]|0;aO=aK<<5&32^aK;aK=aO>>>8<<11&2048^aO;c[aL>>2]=aK;aL=f+8|0;aO=c[aL>>2]|0;aN=aO>>>1<<5&32^aO;aO=aN>>>8<<11&2048^aN;c[aL>>2]=aO;aL=c[f+12>>2]|0;aN=j|0;E=j+4|0;aM=y+8|0;n=k|0;O=k+4|0;N=k+8|0;m=k+12|0;aC=_>>>1;aA=0;do{if((aA&255|0)==0){aI=(aA*100|0)>>>16;cC(ad|0,65064,(aH=i,i=i+16|0,c[aH>>2]=aI,c[aH+8>>2]=454192,aH)|0)|0;i=aH}aH=Xb(aA&65535,7358168,7358136,aB,B,aQ,R,aJ,aK,aO,aL)|0;c[aN>>2]=0;c[E>>2]=0;aI=aH&65535;aH=0;do{aG=j+(((aH|0)/32|0)<<2)|0;c[aG>>2]=(aI>>>((c[606280+(aH<<2)>>2]|0)>>>0)&1)<<(aH&31)|c[aG>>2];aH=aH+1|0;}while((aH|0)<64);c[aN>>2]=c[aN>>2]^c[aP>>2];c[E>>2]=c[E>>2]^c[aM>>2];gGz(z|0,0,16);aH=0;do{aI=c[602976+(aH<<2)>>2]|0;aG=k+(((aH|0)/24|0)<<2)|0;c[aG>>2]=c[aG>>2]|((c[j+(((aI|0)/32|0)<<2)>>2]|0)>>>((aI&31)>>>0)&1)<<((aH|0)%24|0);aH=aH+1|0;}while((aH|0)<96);aH=c[n>>2]|0;aI=aH<<5&32^aH;aH=aI>>>6<<11&2048^aI;c[n>>2]=aH;aI=c[O>>2]|0;aG=aI<<5&32^aI;aI=aG>>>1<<4&16^aG;c[O>>2]=aI;aG=c[N>>2]|0;p=aG>>>2<<5&32^aG;aG=p>>>3<<4&16^p;p=aG>>>7<<11&2048^aG;c[N>>2]=p;aG=c[m>>2]|0;M=aG>>>1<<5&32^aG;c[m>>2]=M;if(aA>>>0<aC>>>0){aG=aA;while(1){b[aR+(aG<<1)>>1]=Xb(b[av+(aG<<1)>>1]|0,7358104,7358072,Q,aS,P,D,aH,aI,p,M)|0;L=aG+65536|0;if(L>>>0<aC>>>0){aG=L}else{aX=L;break}}}else{aX=aA}if(aX>>>0<aC>>>0){aG=aX;do{b[aR+(aG<<1)>>1]=b[av+(aG<<1)>>1]|0;aG=aG+65536|0;}while(aG>>>0<aC>>>0)}aA=aA+1|0;}while(aA>>>0<65536)}else{aA=c[2443926]|0;if((aA|0)==-1){aY=c[2113268]|0}else{aC=ag(aA,au)|0;c[2113268]=aC;aY=aC}if((c[2113250]|0)!=0&(aY|0)!=0&(c[2113246]|0)!=0&(c[2113252]|0)!=0){break}else{C=1}i=e;return C|0}}while(0);C=0;i=e;return C|0}function Wr(){var b=0,d=0,e=0,f=0,g=0;if((c[3542068]&1|0)==0){agV()}gGz(14167876,0,20);c[2113258]=0;c[2113260]=0;c[2113262]=0;c[2113264]=0;c[2113266]=0;a[7461688]=0;a[7461680]=0;c[2113274]=0;c[2113252]=0;c[2113246]=0;c[2113268]=0;c[2113250]=0;c[2113272]=0;c[3541880]=0;c[3542044]=0;c[3541874]=0;c[3541922]=0;c[3541940]=0;b=c[3542028]|0;d=0;while(1){if((d|0)>=1024){break}e=9638528+(d<<2)|0;if((c[e>>2]|0)==(b|0)){f=50366;break}else{d=d+1|0}}if((f|0)==50366){gGr(b);c[e>>2]=0}c[3542028]=0;e=c[3542034]|0;b=0;while(1){if((b|0)>=1024){f=50372;break}g=9638528+(b<<2)|0;if((c[g>>2]|0)==(e|0)){break}else{b=b+1|0}}if((f|0)==50372){c[3542034]=0;a[64288]=0;c[2113296]=0;c[3542068]=0;a[9640]=0;return}gGr(e);c[g>>2]=0;c[3542034]=0;a[64288]=0;c[2113296]=0;c[3542068]=0;a[9640]=0;return}function Ws(b){b=b|0;var d=0,e=0,f=0,g=0,h=0;if(!((a[b|0]|0)!=0&a[9608])){return}d=c[b+16>>2]|0;e=d>>12;f=c[b+4>>2]|0;a[b+48|0]=a[f+(e-4)|0]|0;a[b+49|0]=a[f+(e-3)|0]|0;a[b+50|0]=a[f+(e-2)|0]|0;g=a[f+(e-1)|0]|0;a[b+51|0]=g;e=c[b+20>>2]|0;if((e|0)==0){gGz(b+52|0,g|0,4);return}else{g=e>>12;h=d-e>>12;a[b+52|0]=a[f+h|0]|0;e=(g|0)>1;a[b+53|0]=a[f+((e&1)+h)|0]|0;d=e?2:1;e=(d|0)<(g|0)?d:0;a[b+54|0]=a[f+(e+h)|0]|0;d=e+1|0;a[b+55|0]=a[f+(((d|0)<(g|0)?d:0)+h)|0]|0;return}}function Wt(d){d=d|0;var e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0.0,K=0.0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;e=a[9688]|0?534:0;f=(e|0)<(d|0)?e:d;d=c[2420370]|0;e=f-d|0;if((e|0)<1){return}g=c[2424774]|0;if((c[170120]|0)<(e|0)){i=g;j=0;while(1){if((j|0)>=1024){break}k=9638528+(j<<2)|0;if((c[k>>2]|0)==(i|0)){l=50388;break}else{j=j+1|0}}if((l|0)==50388){gGr(i);c[k>>2]=0}c[2424774]=0;c[170120]=e;k=e<<3;i=0;while(1){if((i|0)>=1024){m=0;break}n=9638528+(i<<2)|0;if((c[n>>2]|0)==0){l=50392;break}else{i=i+1|0}}do{if((l|0)==50392){i=gGq(k)|0;c[n>>2]=i;if((i|0)==0){m=0;break}gGz(i|0,0,k|0);m=i}}while(0);c[2424774]=m;o=m;p=k}else{o=g;p=e<<3}gGz(o|0,0,p|0);p=(f|0)==(d|0);if(a[9608]|0){q=0}else{d=0;do{g=9673112+(d*56|0)|0;k=a[g]|0;L65577:do{if(k<<24>>24!=0){m=c[9673144+(d*56|0)>>2]|0;n=(ag(c[9673148+(d*56|0)>>2]|0,m)|0)>>8;i=(ag(c[9673152+(d*56|0)>>2]|0,m)|0)>>8;if((k&2)!=0){a[g]=k&-3;c[9673136+(d*56|0)>>2]=c[9673120+(d*56|0)>>2]}if(p){break}m=9673136+(d*56|0)|0;j=9673128+(d*56|0)|0;r=9673116+(d*56|0)|0;s=9673160+(d*56|0)|0;t=9673140+(d*56|0)|0;u=9673132+(d*56|0)|0;v=o;w=e;x=c[m>>2]|0;L65583:while(1){y=w-1|0;z=x>>>12&65535;A=c[j>>2]|0;do{if((x|0)<(A-4096|0)){B=c[r>>2]|0;C=a[B+(z+1)|0]|0;a[s]=C;D=z;E=B;F=x;G=C}else{C=c[u>>2]|0;B=(x|0)<(A|0);if((C|0)==0){if(!B){break L65583}H=c[r>>2]|0;I=a[H+z|0]|0;a[s]=I;D=z;E=H;F=x;G=I;break}I=A-C|0;if(B){B=c[r>>2]|0;C=a[B+(I>>12)|0]|0;a[s]=C;D=z;E=B;F=x;G=C;break}else{C=I+(x&4095)|0;c[m>>2]=C;D=C>>>12&65535;E=c[r>>2]|0;F=C;G=a[s]|0;break}}}while(0);z=a[E+D|0]|0;A=(z<<6)+((ag((G<<24>>24)-z|0,F&4095)|0)/64|0)|0;z=(ag(A,n)|0)>>3;c[v>>2]=z+(c[v>>2]|0);z=(ag(A,i)|0)>>3;A=v+4|0;c[A>>2]=z+(c[A>>2]|0);A=(c[m>>2]|0)+(c[t>>2]|0)|0;c[m>>2]=A;if((y|0)==0){break L65577}else{v=v+8|0;w=y;x=A}}a[g]=0}}while(0);d=d+1|0;}while((d|0)<16);d=c[2112964]|0;F=c[2420370]<<1;if((e|0)>0){G=a[6163584]|0;J=+h[80230];D=a[6163576]|0;K=+h[80229];E=0;do{if(G){L=~~(J*+(c[o+(E<<1<<2)>>2]>>8|0))}else{L=0}if(D){M=~~(K*+(c[o+((E<<1|1)<<2)>>2]>>8|0))}else{M=0}if((L|0)<-32768){N=-32768}else{N=(L|0)>32767?32767:L&65535}g=E<<1;b[d+(g+F<<1)>>1]=N;if((M|0)<-32768){O=-32768}else{O=(M|0)>32767?32767:M&65535}b[d+((g|1)+F<<1)>>1]=O;E=E+1|0;}while((E|0)<(e|0))}c[2420370]=f;return}do{E=9673112+(q*56|0)|0;O=a[E]|0;L65619:do{if(O<<24>>24!=0){F=c[9673144+(q*56|0)>>2]|0;d=(ag(c[9673148+(q*56|0)>>2]|0,F)|0)>>11;M=(ag(c[9673152+(q*56|0)>>2]|0,F)|0)>>11;if((O&2)==0){P=e;Q=o}else{F=9673136+(q*56|0)|0;N=c[F>>2]|0;if((N|0)>4095|p){R=o;S=e;T=N}else{L=9673120+(q*56|0)|0;D=9673116+(q*56|0)|0;G=9673140+(q*56|0)|0;g=o;k=e;x=N;while(1){N=c[L>>2]>>12;w=x<<2;v=c[D>>2]|0;m=ag(b[14130680+((w|1)<<1)>>1]|0,a[v+N|0]|0)|0;t=(ag(b[14130680+((w|2)<<1)>>1]|0,a[v+(N+1)|0]|0)|0)+m|0;m=(t+(ag(b[14130680+((w|3)<<1)>>1]|0,a[v+(N+2)|0]|0)|0)|0)/256|0;N=ag(m,d)|0;c[g>>2]=(c[g>>2]|0)+N;N=ag(m,M)|0;m=g+4|0;c[m>>2]=(c[m>>2]|0)+N;N=(c[F>>2]|0)+(c[G>>2]|0)|0;c[F>>2]=N;m=g+8|0;v=k-1|0;if((N|0)>4095|(v|0)==0){R=m;S=v;T=N;break}else{g=m;k=v;x=N}}}if((S|0)<=0){break}a[E]=a[E]&-3;c[F>>2]=(c[9673120+(q*56|0)>>2]|0)+(T&4095);P=S;Q=R}if((P|0)<=0){break}x=9673136+(q*56|0)|0;k=9673128+(q*56|0)|0;g=9673132+(q*56|0)|0;G=9673116+(q*56|0)|0;D=9673140+(q*56|0)|0;L=Q;N=P;v=c[x>>2]|0;L65631:while(1){U=c[k>>2]|0;m=U-12288|0;L65633:do{if((v|0)<(m|0)){V=v;l=50441}else{w=v;while(1){if((w|0)<(U|0)){break}t=c[g>>2]|0;if((t|0)==0){l=50440;break L65631}if((t|0)<4097){l=50439;break L65631}i=w-t|0;c[x>>2]=i;if((i|0)<(m|0)){V=i;l=50441;break L65633}else{w=i}}i=4-(U-w>>12)|0;t=w<<2&16380;n=ag(b[14130680+(t<<1)>>1]|0,a[9673160+(q*56|0)+i|0]|0)|0;s=(ag(b[14130680+((t|1)<<1)>>1]|0,a[i+1+(9673160+(q*56|0))|0]|0)|0)+n|0;n=s+(ag(b[14130680+((t|2)<<1)>>1]|0,a[i+2+(9673160+(q*56|0))|0]|0)|0)|0;W=n+(ag(b[14130680+((t|3)<<1)>>1]|0,a[i+3+(9673160+(q*56|0))|0]|0)|0)|0}}while(0);if((l|0)==50441){l=0;m=V>>>12&65535;y=c[G>>2]|0;i=V<<2&16380;t=ag(b[14130680+(i<<1)>>1]|0,a[y+m|0]|0)|0;n=(ag(b[14130680+((i|1)<<1)>>1]|0,a[y+(m+1)|0]|0)|0)+t|0;t=n+(ag(b[14130680+((i|2)<<1)>>1]|0,a[y+(m+2)|0]|0)|0)|0;W=t+(ag(b[14130680+((i|3)<<1)>>1]|0,a[y+(m+3)|0]|0)|0)|0}m=(W|0)/256|0;y=ag(m,d)|0;c[L>>2]=(c[L>>2]|0)+y;y=ag(m,M)|0;m=L+4|0;c[m>>2]=(c[m>>2]|0)+y;y=(c[x>>2]|0)+(c[D>>2]|0)|0;c[x>>2]=y;m=N-1|0;if((m|0)>0){L=L+8|0;N=m;v=y}else{break L65619}}if((l|0)==50439){l=0;c[x>>2]=U-4096;break}else if((l|0)==50440){l=0;a[E]=0;break}}}while(0);q=q+1|0;}while((q|0)<16);q=c[2112964]|0;l=c[2420370]<<1;if((e|0)>0){U=a[6163584]|0;K=+h[80230];W=a[6163576]|0;J=+h[80229];V=0;do{if(U){X=~~(K*+(c[o+(V<<1<<2)>>2]>>8|0))}else{X=0}if(W){Y=~~(J*+(c[o+((V<<1|1)<<2)>>2]>>8|0))}else{Y=0}if((X|0)<-32768){Z=-32768}else{Z=(X|0)>32767?32767:X&65535}P=V<<1;b[q+(P+l<<1)>>1]=Z;if((Y|0)<-32768){_=-32768}else{_=(Y|0)>32767?32767:Y&65535}b[q+((P|1)+l<<1)>>1]=_;V=V+1|0;}while((V|0)<(e|0))}c[2420370]=f;return}function Wu(b){b=b|0;if((b|0)==0){a[9706117]=0;return}a[9706117]=1;if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){b=gfc(2048)|0;c[2433530]=(c[2433530]|0)+b;return}else{c[2433530]=(c[2433530]|0)+2048;return}}function Wv(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=c[2385480]|0;if((d|0)<(b|0)){e=d;while(1){d=a[9688]|0?534:0;f=ag(d,e)|0;g=(f|0)/(c[2113248]|0)|0;f=c[2112964]|0;do{if((f|0)==0|a[64264]^1){h=e}else{i=c[2420372]|0;if((i|0)>=(g|0)){h=e;break}j=(d|0)<(g|0)?d:g;gg[c[3542124]&4095](f+(i<<1<<1)|0,j-i|0);i=c[2420372]|0;Uu(0,(c[2112964]|0)+(i<<1<<1)|0,j-i|0);c[2420372]=j;h=c[2385480]|0}}while(0);f=c[2433530]|0;g=h-f-(c[2426530]|0)+(c[2076596]|0)|0;do{if((g|0)<1){k=h;l=f}else{if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){d=gfc(g)|0;j=(c[2433530]|0)+d|0;c[2433530]=j;k=c[2385480]|0;l=j;break}else{j=g+f|0;c[2433530]=j;k=h;l=j;break}}}while(0);f=k+(c[2443848]|0)|0;c[2385480]=f;if((f|0)<(b|0)){e=f}else{m=l;break}}}else{m=c[2433530]|0}l=b-m-(c[2426530]|0)+(c[2076596]|0)|0;if((l|0)<1){n=0;c[2444124]=n;return}if((a[(c[9757320+(c[1836236]<<2)>>2]|0)+4188|0]|0)==0){b=gfc(l)|0;c[2433530]=(c[2433530]|0)+b;n=b;c[2444124]=n;return}else{c[2433530]=l+m;n=l;c[2444124]=n;return}}function Ww(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;if((b<<16>>16|0)==(-12288|0)){a[9647664]=e;return}else if((b<<16>>16|0)==(-12286|0)){f=e&255;g=a[9647656]|0;h=g&255;i=d[9647664]<<8|h;if((e&255)>143){return}if((c[2112964]|0)!=0){j=ag(a[9688]|0?534:0,(c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)|0;Wt((j|0)/(c[2113248]|0)|0)}if(e<<24>>24<0){j=f&15;k=h+48&63;l=k>>>0>32?32:k;c[9673148+(j*56|0)>>2]=c[9754360+(32-l<<2)>>2];c[9673152+(j*56|0)>>2]=c[9754360+(l<<2)>>2];return}l=f>>>3;j=l&15;k=9673112+(j*56|0)|0;switch(f&7|0){case 0:{f=l+1&15;a[9673113+(f*56|0)|0]=g;g=h<<16&8323072;c[9673116+(f*56|0)>>2]=(c[3541940]|0)+((g+65536|0)>>>0>(c[2113252]|0)>>>0?0:g);Ws(9673112+(f*56|0)|0);return};case 2:{c[9673156+(j*56|0)>>2]=i;f=c[2394736]|0;if((f|0)!=0){g=gGU(i,0,4e6,0)|0;h=gGV(g,K,166,0)|0;g=gGS(h,K,f,(f|0)<0|0?-1:0)|0;c[9673140+(j*56|0)>>2]=g}if((i|0)!=0){return}a[k|0]=0;return};case 4:{c[9673132+(j*56|0)>>2]=i<<12;Ws(k);return};case 6:{c[9673144+(j*56|0)>>2]=i;g=k|0;if((i|0)==0){a[g]=0;return}if((a[g]|0)!=0){return}c[9673120+(j*56|0)>>2]=c[9673124+(j*56|0)>>2];c[9673136+(j*56|0)>>2]=0;a[g]=3;Ws(k);return};case 1:{c[9673124+(j*56|0)>>2]=i<<12;return};case 5:{c[9673128+(j*56|0)>>2]=i<<12;Ws(k);return};default:{return}}}else if((b<<16>>16|0)==(-12287|0)){a[9647656]=e;return}else if((b<<16>>16|0)==(-12285|0)){b=e&15;if((c[3528524]|0)==(b|0)){return}c[3528524]=b;Wx();return}else{return}}function Wx(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=c[3528524]<<14;d=b+32768|0;e=a[7462128]|0;f=b+49152|0;b=c[2113246]|0;if(e){g=b>>>1;h=f>>>0>g>>>0?0:d;i=c[3541874]|0;j=i+(h-g)|0;k=h;l=i}else{i=f>>>0>b>>>0?0:d;d=c[3541874]|0;j=d+i|0;k=i;l=d}d=c[9757320+(c[1836236]<<2)>>2]|0;i=128;b=128;while(1){c[d+76+(b<<2)>>2]=j+((b<<8)-32768);f=i+1&65535;if((f&65535)>191){break}else{i=f;b=f&65535}}if(e){e=128;b=128;while(1){i=j+((b<<8)-32768)|0;c[d+76+(b+512<<2)>>2]=i;c[d+76+(b+768<<2)>>2]=i;i=e+1&65535;if((i&65535)>191){break}else{e=i;b=i&65535}}return}else{b=128;e=128;while(1){i=(e<<8)-32768|0;c[d+76+(e+512<<2)>>2]=j+i;c[d+76+(e+768<<2)>>2]=l+(i+k);i=b+1&65535;if((i&65535)>191){break}else{b=i;e=i&65535}}return}}function Wy(a){a=a|0;return(a<<16>>16==-12281?-128:0)|0}function Wz(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if((c[2113256]|0)==(a|0)){return}c[2113256]=a;b=c[3541934]|0;d=c[2112932]|0;e=d+28800|0;if((a|0)==0){c[e>>2]=b;c[d+94336>>2]=b;c[d+159872>>2]=b;a=b+1024|0;c[d+28804>>2]=a;c[d+94340>>2]=a;c[d+159876>>2]=a;f=b+2048|0;c[d+28808>>2]=f;c[d+94344>>2]=f;c[d+159880>>2]=f;g=b+3072|0;c[d+28812>>2]=g;c[d+94348>>2]=g;c[d+159884>>2]=g;h=b+4096|0;c[d+28816>>2]=h;c[d+94352>>2]=h;c[d+159888>>2]=h;i=b+5120|0;c[d+28820>>2]=i;c[d+94356>>2]=i;c[d+159892>>2]=i;j=b+6144|0;c[d+28824>>2]=j;c[d+94360>>2]=j;c[d+159896>>2]=j;k=b+7168|0;c[d+28828>>2]=k;c[d+94364>>2]=k;c[d+159900>>2]=k;c[d+28832>>2]=b;c[d+94368>>2]=b;c[d+159904>>2]=b;c[d+28836>>2]=a;c[d+94372>>2]=a;c[d+159908>>2]=a;c[d+28840>>2]=f;c[d+94376>>2]=f;c[d+159912>>2]=f;c[d+28844>>2]=g;c[d+94380>>2]=g;c[d+159916>>2]=g;c[d+28848>>2]=h;c[d+94384>>2]=h;c[d+159920>>2]=h;c[d+28852>>2]=i;c[d+94388>>2]=i;c[d+159924>>2]=i;c[d+28856>>2]=j;c[d+94392>>2]=j;c[d+159928>>2]=j;c[d+28860>>2]=k;c[d+94396>>2]=k;c[d+159932>>2]=k;c[d+28864>>2]=b;c[d+94400>>2]=b;c[d+159936>>2]=b;c[d+28868>>2]=a;c[d+94404>>2]=a;c[d+159940>>2]=a;c[d+28872>>2]=f;c[d+94408>>2]=f;c[d+159944>>2]=f;c[d+28876>>2]=g;c[d+94412>>2]=g;c[d+159948>>2]=g;c[d+28880>>2]=h;c[d+94416>>2]=h;c[d+159952>>2]=h;c[d+28884>>2]=i;c[d+94420>>2]=i;c[d+159956>>2]=i;c[d+28888>>2]=j;c[d+94424>>2]=j;c[d+159960>>2]=j;c[d+28892>>2]=k;c[d+94428>>2]=k;c[d+159964>>2]=k;c[d+28896>>2]=b;c[d+94432>>2]=b;c[d+159968>>2]=b;c[d+28900>>2]=a;c[d+94436>>2]=a;c[d+159972>>2]=a;c[d+28904>>2]=f;c[d+94440>>2]=f;c[d+159976>>2]=f;c[d+28908>>2]=g;c[d+94444>>2]=g;c[d+159980>>2]=g;c[d+28912>>2]=h;c[d+94448>>2]=h;c[d+159984>>2]=h;c[d+28916>>2]=i;c[d+94452>>2]=i;c[d+159988>>2]=i;c[d+28920>>2]=j;c[d+94456>>2]=j;c[d+159992>>2]=j;c[d+28924>>2]=k;c[d+94460>>2]=k;c[d+159996>>2]=k;return}else{k=b+32768|0;c[e>>2]=k;c[d+94336>>2]=k;c[d+159872>>2]=k;e=b+33792|0;c[d+28804>>2]=e;c[d+94340>>2]=e;c[d+159876>>2]=e;j=b+34816|0;c[d+28808>>2]=j;c[d+94344>>2]=j;c[d+159880>>2]=j;i=b+35840|0;c[d+28812>>2]=i;c[d+94348>>2]=i;c[d+159884>>2]=i;h=b+36864|0;c[d+28816>>2]=h;c[d+94352>>2]=h;c[d+159888>>2]=h;g=b+37888|0;c[d+28820>>2]=g;c[d+94356>>2]=g;c[d+159892>>2]=g;f=b+38912|0;c[d+28824>>2]=f;c[d+94360>>2]=f;c[d+159896>>2]=f;a=b+39936|0;c[d+28828>>2]=a;c[d+94364>>2]=a;c[d+159900>>2]=a;c[d+28832>>2]=k;c[d+94368>>2]=k;c[d+159904>>2]=k;c[d+28836>>2]=e;c[d+94372>>2]=e;c[d+159908>>2]=e;c[d+28840>>2]=j;c[d+94376>>2]=j;c[d+159912>>2]=j;c[d+28844>>2]=i;c[d+94380>>2]=i;c[d+159916>>2]=i;c[d+28848>>2]=h;c[d+94384>>2]=h;c[d+159920>>2]=h;c[d+28852>>2]=g;c[d+94388>>2]=g;c[d+159924>>2]=g;c[d+28856>>2]=f;c[d+94392>>2]=f;c[d+159928>>2]=f;c[d+28860>>2]=a;c[d+94396>>2]=a;c[d+159932>>2]=a;c[d+28864>>2]=k;c[d+94400>>2]=k;c[d+159936>>2]=k;c[d+28868>>2]=e;c[d+94404>>2]=e;c[d+159940>>2]=e;c[d+28872>>2]=j;c[d+94408>>2]=j;c[d+159944>>2]=j;c[d+28876>>2]=i;c[d+94412>>2]=i;c[d+159948>>2]=i;c[d+28880>>2]=h;c[d+94416>>2]=h;c[d+159952>>2]=h;c[d+28884>>2]=g;c[d+94420>>2]=g;c[d+159956>>2]=g;c[d+28888>>2]=f;c[d+94424>>2]=f;c[d+159960>>2]=f;c[d+28892>>2]=a;c[d+94428>>2]=a;c[d+159964>>2]=a;c[d+28896>>2]=k;c[d+94432>>2]=k;c[d+159968>>2]=k;c[d+28900>>2]=e;c[d+94436>>2]=e;c[d+159972>>2]=e;c[d+28904>>2]=j;c[d+94440>>2]=j;c[d+159976>>2]=j;c[d+28908>>2]=i;c[d+94444>>2]=i;c[d+159980>>2]=i;c[d+28912>>2]=h;c[d+94448>>2]=h;c[d+159984>>2]=h;c[d+28916>>2]=g;c[d+94452>>2]=g;c[d+159988>>2]=g;c[d+28920>>2]=f;c[d+94456>>2]=f;c[d+159992>>2]=f;c[d+28924>>2]=a;c[d+94460>>2]=a;c[d+159996>>2]=a;return}}function WA(){var b=0;b=c[3542068]|0;do{if((b&1|0)==0|a[7462160]){if(!((b|0)!=2|a[7462104])){break}return 0}}while(0);gGz(9706056,0,76);return 0}function WB(b){b=b|0;var d=0,e=0,f=0,g=0;if((b&1|0)==0){d=-1;return d|0}e=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;f=c[2113248]|0;g=gGU(e,(e|0)<0|0?-1:0,f,(f|0)<0|0?-1:0)|0;f=c[2113270]|0;e=gGS(g,K,f,(f|0)<0|0?-1:0)|0;f=e;if((f|0)>((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)){Sb(f)}d=a[(c[3541878]|0)+(b>>>1&4095)|0]|0;return d|0}function WC(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;if((b&1|0)==0){return}e=b&8191;do{if((e|0)==31){b=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;f=c[2113248]|0;g=gGU(b,(b|0)<0|0?-1:0,f,(f|0)<0|0?-1:0)|0;f=c[2113270]|0;b=gGS(g,K,f,(f|0)<0|0?-1:0)|0;f=b;if((f|0)<=((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)){break}Sb(f)}}while(0);a[(c[3541878]|0)+(e>>>1)|0]=d;return}function WD(b){b=b|0;var d=0,e=0,f=0,g=0;if((b&1|0)==0){d=-1;return d|0}e=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;f=c[2113248]|0;g=gGU(e,(e|0)<0|0?-1:0,f,(f|0)<0|0?-1:0)|0;f=c[2113270]|0;e=gGS(g,K,f,(f|0)<0|0?-1:0)|0;f=e;if((f|0)>((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)){Sb(f)}d=a[(c[3541876]|0)+(b>>>1&4095)|0]|0;return d|0}function WE(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;if((b&1|0)==0){return}e=b&8191;do{if((e|0)==31){b=(c[2113056]|0)+(c[2113054]|0)-(c[2276108]|0)|0;f=c[2113248]|0;g=gGU(b,(b|0)<0|0?-1:0,f,(f|0)<0|0?-1:0)|0;f=c[2113270]|0;b=gGS(g,K,f,(f|0)<0|0?-1:0)|0;f=b;if((f|0)<=((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)){break}Sb(f)}}while(0);a[(c[3541876]|0)+(e>>>1)|0]=d;return}function WF(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;g=i;i=i+272|0;h=g|0;j=g+16|0;k=g+32|0;l=g+48|0;m=g+64|0;n=g+80|0;o=g+96|0;p=g+112|0;q=g+128|0;r=g+144|0;s=g+160|0;t=g+176|0;u=g+192|0;v=g+208|0;w=g+224|0;x=g+240|0;y=g+256|0;if((c[2414530]|0)==0){z=1;i=g;return z|0}if((f|0)!=0){c[f>>2]=169249}do{if((e&4|0)!=0){gGz(y|0,0,12);A=y|0;c[A>>2]=c[3541922];B=y+4|0;c[B>>2]=c[2113250];C=y+12|0;c[C>>2]=79384;D=c[2076592]|0;gj[D&4095](y)|0;D=c[2113246]|0;if((D|0)==0){break}c[A>>2]=c[3541874];c[B>>2]=D;c[C>>2]=462744;C=c[2076592]|0;gj[C&4095](y)|0}}while(0);if((c[3542068]|0)==2|a[7462128]|a[7461720]|a[7462008]){Ts(e,f)}do{if((e&32|0)!=0){gGz(x|0,0,12);C=x|0;c[C>>2]=c[3541932];D=x+4|0;c[D>>2]=196608;B=x+12|0;c[B>>2]=167216;A=c[2076592]|0;gj[A&4095](x)|0;c[C>>2]=c[3541930];c[D>>2]=65536;c[B>>2]=134880;A=c[2076592]|0;gj[A&4095](x)|0;c[C>>2]=c[3541926];c[D>>2]=256;c[B>>2]=109264;A=c[2076592]|0;gj[A&4095](x)|0;A=c[3542068]|0;if((A|0)==2&(a[7462104]^1)|a[7462128]){c[C>>2]=c[3541878];c[D>>2]=4096;c[B>>2]=84240;E=c[2076592]|0;gj[E&4095](x)|0;c[C>>2]=c[3541876];c[D>>2]=4096;c[B>>2]=65752;E=c[2076592]|0;gj[E&4095](x)|0;F=c[3542068]|0}else{F=A}if((F|0)!=2){break}c[C>>2]=c[3541934];c[D>>2]=65536;c[B>>2]=574096;A=c[2076592]|0;gj[A&4095](x)|0;c[C>>2]=c[3542030];c[D>>2]=16;c[B>>2]=557424;B=c[2076592]|0;gj[B&4095](x)|0;if((c[3542068]|0)!=2){break}gGz(y|0,0,12);c[y>>2]=c[3541936];c[y+4>>2]=16384;c[y+12>>2]=356592;B=c[2076592]|0;gj[B&4095](y)|0}}while(0);y=(e&64|0)==0;do{if(!y){x=u|0;gGz(t|0,0,16);c[2394]=-1;if((c[2392]|0)>=0){F=u+9|0;B=s;D=s|0;C=s+4|0;A=s+12|0;E=t|0;G=t+4|0;H=t+12|0;I=0;do{gGC(x|0,614896,11)|0;a[F]=I+48&255;J=8452256+(I<<2)|0;gGz(B|0,0,12);c[D>>2]=J;c[C>>2]=4;c[A>>2]=164976;gj[c[2076592]&4095](s)|0;if((c[J>>2]|0)!=0){c[E>>2]=c[14130368+(I<<2)>>2];c[G>>2]=c[8452184+(I<<2)>>2];c[H>>2]=x;J=c[2076592]|0;gj[J&4095](t)|0}I=I+1|0;}while((I|0)<=(c[2392]|0))}if(a[7462144]|0){gGz(w|0,0,12);c[w>>2]=9648;c[w+4>>2]=16;c[w+12>>2]=277992;I=c[2076592]|0;gj[I&4095](w)|0;gGz(v|0,0,12);c[v>>2]=9664;c[v+4>>2]=12;c[v+12>>2]=213904;I=c[2076592]|0;gj[I&4095](v)|0}if((e&2|0)==0){break}a[14167712]=1}}while(0);v=c[3542068]|0;do{if((v|0)==2&(a[7462104]^1)|a[7462128]){if(y){break}fw$(e);gGz(m|0,0,12);c[m>>2]=14114096;c[m+4>>2]=4;c[m+12>>2]=83528;w=c[2076592]|0;gj[w&4095](m)|0;w=(e&2|0)==0;if(!w){t=c[2439330]|0;s=(t|0)==0;if(!s){u=t;gGC(9706056,u|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];u=c[3528484]|0;c[2076596]=u;I=c[2417276]|0;c[3541536]=I;c[1836236]=0;Wx();if(!s){s=t;gGC(s|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=u;c[2417276]=I;c[1836236]=-1}gGz(n|0,0,12);c[n>>2]=9673112;c[n+4>>2]=896;c[n+12>>2]=85688;I=c[2076592]|0;gj[I&4095](n)|0;if(w){break}w=c[2113252]|0;I=c[3541940]|0;u=c[2394736]|0;s=u;t=(u|0)<0|0?-1:0;if((u|0)==0){u=0;do{x=(d[9673113+(u*56|0)|0]|0)<<16&8323072;c[9673116+(u*56|0)>>2]=I+((x+65536|0)>>>0>w>>>0?0:x);u=u+1|0;}while((u|0)<16)}else{u=0;do{x=(d[9673113+(u*56|0)|0]|0)<<16&8323072;c[9673116+(u*56|0)>>2]=I+((x+65536|0)>>>0>w>>>0?0:x);x=c[9673156+(u*56|0)>>2]|0;H=gGU(x,(x|0)<0|0?-1:0,4e6,0)|0;x=gGS(H,K,166,0)|0;H=gGS(x,K,s,t)|0;c[9673140+(u*56|0)>>2]=H;u=u+1|0;}while((u|0)<16)}}else{if((v&1|0)==0|a[7462160]|y){break}gGz(r|0,0,12);c[r>>2]=9776496;c[r+4>>2]=4;c[r+12>>2]=212472;u=c[2076592]|0;gj[u&4095](r)|0;gGz(q|0,0,12);c[q>>2]=9541920;c[q+4>>2]=4;c[q+12>>2]=465960;u=c[2076592]|0;gj[u&4095](q)|0;u=l;fw$(e);Ut(0);gGz(j|0,0,12);c[j>>2]=8453216;c[j+4>>2]=4;c[j+12>>2]=107480;t=c[2076592]|0;gj[t&4095](j)|0;gGz(h|0,0,12);c[h>>2]=14168504;c[h+4>>2]=256;c[h+12>>2]=476464;t=c[2076592]|0;gj[t&4095](h)|0;if((e&2|0)!=0){t=0;do{mv(0,t,d[14168504+t|0]|0);t=t+1|0;}while((t|0)<256)}gGz(k|0,0,12);c[k>>2]=14114104;c[k+4>>2]=4;c[k+12>>2]=71440;t=c[2076592]|0;gj[t&4095](k)|0;gGz(u|0,0,12);c[l+12>>2]=498600;c[l>>2]=c[2405730];c[l+4>>2]=2048;t=c[2076592]|0;gj[t&4095](l)|0;gGz(p|0,0,12);c[p>>2]=14130592;c[p+4>>2]=1;c[p+12>>2]=358464;t=c[2076592]|0;gj[t&4095](p)|0;gGz(o|0,0,12);c[o>>2]=14130584;c[o+4>>2]=1;c[o+12>>2]=279800;t=c[2076592]|0;gj[t&4095](o)|0}}while(0);o=c[3541954]|0;if((o|0)==0){z=0;i=g;return z|0}gA[o&16383](e,f)|0;z=0;i=g;return z|0}function WG(b,d,f){b=b|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;g=(d>>>3)+1|0;h=(f>>3)+1|0;i=8-(d&7)|0;d=8-(f&7)|0;f=-1;j=-1;while(1){k=h+j|0;l=k<<2&124|k<<8&8192;k=(j<<3)+d|0;if(j>>>0>26){m=f;n=-1;while(1){o=n+g<<7&8064|l;p=(a[7461688]|0?20479:65535)&(e[b+o>>1]|0);q=c[2439494]|0;r=c[q>>2]|0;L65907:do{if((r|0)==0){s=m}else{t=q;u=r;L65908:while(1){do{if((p|0)>=(c[t+4>>2]|0)){if((p|0)>(c[t+8>>2]|0)){break}if((u&2|0)!=0){break L65908}}}while(0);v=t+16|0;w=c[v>>2]|0;if((w|0)==0){s=m;break L65907}else{t=v;u=w}}u=c[t+12>>2]|0;if((u|0)>0){w=0;v=0;while(1){x=(c[9773320+(v<<2)>>2]|0)+w|0;y=v+1|0;if((y|0)<(u|0)){w=x;v=y}else{z=x;break}}}else{z=0}v=((c[9773320+(u<<2)>>2]|0)+65535&p)+z|0;if((v|0)==-1){s=m;break}w=(c[2113264]|0)+(v<<6)|0;if((w|0)==(m|0)){s=m;break}v=e[b+(o|2)>>1]|0;c[3541654]=(c[3541942]|0)+((v<<4&496|512)<<2);c[2113234]=2;c[2113232]=(n<<3)+i;c[2113230]=k;c[2113236]=w;c[2113238]=v>>>5&3;t=a[9760]|0;if(t){c[3541652]=e[(c[3541886]|0)+(c[14164744+((v>>>7&3)<<2)>>2]|0)>>1]|0}v=(gD[c[7461952+((t&1)<<2)>>2]&8191]()|0)==0;s=v?m:w}}while(0);o=n+1|0;if((o|0)<48){m=s;n=o}else{A=s;break}}}else{n=f;m=-1;while(1){o=m+g<<7&8064|l;p=(a[7461688]|0?20479:65535)&(e[b+o>>1]|0);r=c[2439494]|0;q=c[r>>2]|0;L65887:do{if((q|0)==0){B=n}else{w=r;v=q;L65888:while(1){do{if((p|0)>=(c[w+4>>2]|0)){if((p|0)>(c[w+8>>2]|0)){break}if((v&2|0)!=0){break L65888}}}while(0);t=w+16|0;x=c[t>>2]|0;if((x|0)==0){B=n;break L65887}else{w=t;v=x}}v=c[w+12>>2]|0;if((v|0)>0){u=0;x=0;while(1){t=(c[9773320+(x<<2)>>2]|0)+u|0;y=x+1|0;if((y|0)<(v|0)){u=t;x=y}else{C=t;break}}}else{C=0}x=((c[9773320+(v<<2)>>2]|0)+65535&p)+C|0;if((x|0)==-1){B=n;break}u=(c[2113264]|0)+(x<<6)|0;if((u|0)==(n|0)){B=n;break}x=e[b+(o|2)>>1]|0;c[3541654]=(c[3541942]|0)+((x<<4&496|512)<<2);c[2113234]=m>>>0>46?2:0;c[2113232]=(m<<3)+i;c[2113230]=k;c[2113236]=u;c[2113238]=x>>>5&3;w=a[9760]|0;if(w){c[3541652]=e[(c[3541886]|0)+(c[14164744+((x>>>7&3)<<2)>>2]|0)>>1]|0}x=(gD[c[7461952+((w&1)<<2)>>2]&8191]()|0)==0;B=x?n:u}}while(0);o=m+1|0;if((o|0)<48){n=B;m=o}else{A=B;break}}}m=j+1|0;if((m|0)<28){f=A;j=m}else{break}}return 0}function WH(a,b,d){a=a|0;b=b|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=(b>>>3)+1|0;g=8-(b&7)|0;b=(d>>3)+1|0;h=d&7;d=c[2113214]|0;i=d+h>>3;j=c[2113038]|0;k=8-h|0;l=(j+h>>3)-1|0;if((l|0)<(i|0)){m=-1;n=l;o=j;p=d}else{return 0}while(1){d=n<<3;j=b+n|0;l=j<<2&124|j<<8&8192;j=d+k|0;if(((d+8|0)>=(p|0)|(d|0)<(o|0)|0)==0){d=m;h=-1;while(1){q=h+f<<7&8064|l;r=((e[a+q>>1]|0)<<6)+(c[2113264]|0)|0;if((r|0)==(d|0)){s=d}else{t=e[a+(q|2)>>1]|0;c[3541654]=(c[3541942]|0)+((t<<4&496|512)<<2);c[2113232]=(h<<3)+g;c[2113230]=j;c[2113236]=r;c[2113238]=t>>>5&3;c[2113234]=h>>>0<47?0:2;t=(W2()|0)==0;s=t?d:r}r=h+1|0;if((r|0)<48){d=s;h=r}else{u=s;break}}}else{h=m;d=-1;while(1){r=d+f<<7&8064|l;t=((e[a+r>>1]|0)<<6)+(c[2113264]|0)|0;if((t|0)==(h|0)){v=h}else{q=e[a+(r|2)>>1]|0;c[3541654]=(c[3541942]|0)+((q<<4&496|512)<<2);c[2113232]=(d<<3)+g;c[2113230]=j;c[2113236]=t;c[2113238]=q>>>5&3;c[2113234]=2;q=(W2()|0)==0;v=q?h:t}t=d+1|0;if((t|0)<48){h=v;d=t}else{u=v;break}}}d=n+1|0;if((d|0)>=(i|0)){break}m=u;n=d;o=c[2113038]|0;p=c[2113214]|0}return 0}function WI(b,d,f){b=b|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;g=(d>>>5)+1|0;h=(f>>5)+1|0;i=32-(d&31)|0;d=32-(f&31)|0;f=-1;j=-1;while(1){k=h+j|0;l=k<<2&28|k<<8&14336;k=(j<<5)+d|0;if(j>>>0>5){m=f;n=-1;while(1){o=n+g<<5&2016|l;p=c[2439494]|0;q=((a[7461680]|0?8191:65535)&(e[b+o>>1]|0))<<3;r=c[p>>2]|0;L65952:do{if((r|0)==0){s=m}else{t=p;u=r;L65953:while(1){do{if((q|0)>=(c[t+4>>2]|0)){if((q|0)>(c[t+8>>2]|0)){break}if((u&8|0)!=0){break L65953}}}while(0);v=t+16|0;w=c[v>>2]|0;if((w|0)==0){s=m;break L65952}else{t=v;u=w}}u=c[t+12>>2]|0;if((u|0)>0){w=0;v=0;while(1){x=(c[9773320+(v<<2)>>2]|0)+w|0;y=v+1|0;if((y|0)<(u|0)){w=x;v=y}else{z=x;break}}}else{z=0}v=((c[9773320+(u<<2)>>2]|0)+524287&q)+z>>3;if((v|0)==-1){s=m;break}w=(c[2113260]|0)+(v<<9)|0;if((w|0)==(m|0)){s=m;break}v=e[b+(o|2)>>1]|0;c[3541654]=(c[3541942]|0)+((v<<4&496|1536)<<2);c[2113234]=26;c[2113232]=(n<<5)+i;c[2113230]=k;c[2113236]=w;c[2113238]=v>>>5&3;t=a[9760]|0;if(t){c[3541652]=e[(c[3541886]|0)+(c[14164744+((v>>>7&3)<<2)>>2]|0)>>1]|0}v=(gD[c[7461952+((t&1)<<2)>>2]&8191]()|0)==0;s=v?m:w}}while(0);o=n+1|0;if((o|0)<12){m=s;n=o}else{A=s;break}}}else{n=f;m=-1;while(1){o=m+g<<5&2016|l;q=c[2439494]|0;r=((a[7461680]|0?8191:65535)&(e[b+o>>1]|0))<<3;p=c[q>>2]|0;L65972:do{if((p|0)==0){B=n}else{w=q;v=p;L65973:while(1){do{if((r|0)>=(c[w+4>>2]|0)){if((r|0)>(c[w+8>>2]|0)){break}if((v&8|0)!=0){break L65973}}}while(0);t=w+16|0;x=c[t>>2]|0;if((x|0)==0){B=n;break L65972}else{w=t;v=x}}v=c[w+12>>2]|0;if((v|0)>0){u=0;x=0;while(1){t=(c[9773320+(x<<2)>>2]|0)+u|0;y=x+1|0;if((y|0)<(v|0)){u=t;x=y}else{C=t;break}}}else{C=0}x=((c[9773320+(v<<2)>>2]|0)+524287&r)+C>>3;if((x|0)==-1){B=n;break}u=(c[2113260]|0)+(x<<9)|0;if((u|0)==(n|0)){B=n;break}x=e[b+(o|2)>>1]|0;c[3541654]=(c[3541942]|0)+((x<<4&496|1536)<<2);c[2113234]=m>>>0>10?26:24;c[2113232]=(m<<5)+i;c[2113230]=k;c[2113236]=u;c[2113238]=x>>>5&3;w=a[9760]|0;if(w){c[3541652]=e[(c[3541886]|0)+(c[14164744+((x>>>7&3)<<2)>>2]|0)>>1]|0}x=(gD[c[7461952+((w&1)<<2)>>2]&8191]()|0)==0;B=x?n:u}}while(0);o=m+1|0;if((o|0)<12){n=B;m=o}else{A=B;break}}}m=j+1|0;if((m|0)<7){f=A;j=m}else{break}}return 0}function WJ(d,f,g){d=d|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;h=(f>>>5)+1|0;i=32-(f&31)|0;f=(g>>5)+1|0;j=g&31;g=c[2113214]|0;k=g+j>>5;l=c[2113038]|0;m=32-j|0;n=(l+j>>5)-1|0;if((n|0)<(k|0)){o=-1;p=n;q=l;r=g}else{return 0}while(1){g=p<<5;l=f+p|0;n=l<<2&28|l<<8&14336;l=m+g|0;j=((g+32|0)>=(r|0)|(g|0)<(q|0)|0)==0;g=o;s=-1;while(1){t=n|h+s<<5&2016;u=b[d+t>>1]|0;v=u&65535;if(a[7460896]&(u&65535)>22527){w=v-16384|0}else{w=a[7461640]&(u&65535)<22016?v+16384|0:v}v=(w<<9)+(c[2113260]|0)|0;if((v|0)==(g|0)){x=g}else{u=e[d+(t|2)>>1]|0;c[3541654]=(c[3541942]|0)+((u<<4&496|1536)<<2);c[2113232]=i+(s<<5);c[2113230]=l;c[2113236]=v;c[2113238]=u>>>5&3;c[2113234]=s>>>0<11&j?24:26;u=(W2()|0)==0;x=u?g:v}v=s+1|0;if((v|0)<12){g=x;s=v}else{break}}s=p+1|0;if((s|0)>=(k|0)){break}o=x;p=s;q=c[2113038]|0;r=c[2113214]|0}return 0}function WK(b){b=b|0;var d=0,e=0,f=0.0,g=0.0,i=0;d=b&65535;if((d|0)==55296){b=c[3541518]|0;e=b+296|0;f=+h[e>>3];do{if(f!=0.0){g=+h[6675];if(f-(g+ +gC[c[2429842]&255]())<=0.0){h[e>>3]=0.0;break}i=a[b+307|0]|-128;return i|0}}while(0);i=a[b+307|0]|0;return i|0}else if((d|0)==58368){a[9706117]=0;i=c[2433432]&255;return i|0}else if((d|0)==56320){d=c[3541518]|0;b=d+19320|0;f=+h[b>>3];do{if(f!=0.0){g=+h[6675];if(f-(g+ +gC[c[2429842]&255]())<=0.0){h[b>>3]=0.0;break}i=a[d+19331|0]|-128;return i|0}}while(0);i=a[d+19331|0]|0;return i|0}else{i=0;return i|0}return 0}function WL(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,i=0,j=0,k=0,l=0;switch(b&65535|0){case 60416:{c[2429752]=d&255;return};case 56321:{lS(1,1,d);return};case 57344:{b=d&255;h[1207773]=(b&8|0)!=0?0.0:.25;c[2415548]=3;c[2415126]=9665376;h[1208176]=(b&16|0)!=0?0.0:.25;c[2416354]=3;e=b<<14&114688;c[2429514]=e;b=c[3541874]|0;f=c[9757320+(c[1836236]<<2)>>2]|0;g=e-32768|0;e=128;i=128;while(1){c[f+76+(i<<2)>>2]=b+(g+(i<<8));j=e+1&65535;if((j&65535)>191){break}else{e=j;i=j&65535}}i=(c[2429514]|0)-32768|0;e=128;g=128;while(1){j=b+(i+(g<<8))|0;c[f+76+(g+512<<2)>>2]=j;c[f+76+(g+768<<2)>>2]=j;j=e+1&65535;if((j&65535)>191){break}else{e=j;g=j&65535}}return};case 55297:{lS(0,1,d);return};case 55296:{g=c[3541518]|0;e=g+256|0;a[g+304|0]=d;f=d&255;if((d&255)<16){c[14168912+((c[2383582]|0)*252|0)>>2]=f&15}if((d-45&255)>=3){return}if((f|0)==0){a[g+312|0]=2;k=2}else if((f|0)==45){i=g+312|0;b=a[i]|2;a[i]=b;k=b}else if((f|0)==47){a[g+312|0]=0;k=0}else if((f|0)==46){f=g+312|0;b=a[f]|1;a[f]=b;k=b}else{k=a[g+312|0]|0}g=k&3;k=c[7461744+(g<<2)>>2]|0;lI(e,k,k,c[7461728+(g<<2)>>2]|0);return};case 59392:{c[2429754]=d&255;return};case 56320:{g=c[3541518]|0;k=g+19280|0;a[g+19328|0]=d;e=d&255;if((d&255)<16){c[14168912+(((c[2383582]|0)+1|0)*252|0)>>2]=e&15}if((d-45&255)>=3){return}if((e|0)==47){a[g+19336|0]=0;l=0}else if((e|0)==0){a[g+19336|0]=2;l=2}else if((e|0)==46){d=g+19336|0;b=a[d]|1;a[d]=b;l=b}else if((e|0)==45){e=g+19336|0;b=a[e]|2;a[e]=b;l=b}else{l=a[g+19336|0]|0}g=l&3;l=c[7461744+(g<<2)>>2]|0;lI(k,l,l,c[7461728+(g<<2)>>2]|0);return};default:{return}}}function WM(){var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=0;while(1){if((d|0)>=1024){e=0;break}f=9638528+(d<<2)|0;if((c[f>>2]|0)==0){g=50778;break}else{d=d+1|0}}do{if((g|0)==50778){d=gGq(2048)|0;c[f>>2]=d;if((d|0)==0){e=0;break}gGz(d|0,0,2048);e=d}}while(0);c[2443342]=e;fwR(0);e=c[2439330]|0;f=(e|0)==0;if(!f){g=e;gGC(9706056,g|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];g=c[3528484]|0;c[2076596]=g;d=c[2417276]|0;c[3541536]=d;c[1836236]=0;c[e+4180>>2]=3326;c[e+4184>>2]=1780;i=c[3541874]|0;j=0;k=0;while(1){c[e+76+(k<<2)>>2]=i+(k<<8);l=j+1&65535;if((l&65535)>127){m=0;n=0;break}else{j=l;k=l&65535}}while(1){k=i+(n<<8)|0;c[e+76+(n+512<<2)>>2]=k;c[e+76+(n+768<<2)>>2]=k;k=m+1&65535;if((k&65535)>127){o=128;p=128;break}else{m=k;n=k&65535}}while(1){c[e+76+(p<<2)>>2]=i+(p<<8);n=o+1&65535;if((n&65535)>191){q=128;r=128;break}else{o=n;p=n&65535}}while(1){p=i+(r<<8)|0;c[e+76+(r+512<<2)>>2]=p;c[e+76+(r+768<<2)>>2]=p;p=q+1&65535;if((p&65535)>191){break}else{q=p;r=p&65535}}r=c[2443342]|0;c[e+908>>2]=r;q=r+256|0;c[e+912>>2]=q;i=r+512|0;c[e+916>>2]=i;p=r+768|0;c[e+920>>2]=p;o=r+1024|0;c[e+924>>2]=o;n=r+1280|0;c[e+928>>2]=n;m=r+1536|0;c[e+932>>2]=m;k=r+1792|0;c[e+936>>2]=k;c[e+1932>>2]=r;c[e+1936>>2]=q;c[e+1940>>2]=i;c[e+1944>>2]=p;c[e+1948>>2]=o;c[e+1952>>2]=n;c[e+1956>>2]=m;c[e+1960>>2]=k;c[e+2956>>2]=r;c[e+3980>>2]=r;c[e+2960>>2]=q;c[e+3984>>2]=q;c[e+2964>>2]=i;c[e+3988>>2]=i;c[e+2968>>2]=p;c[e+3992>>2]=p;c[e+2972>>2]=o;c[e+3996>>2]=o;c[e+2976>>2]=n;c[e+4e3>>2]=n;c[e+2980>>2]=m;c[e+4004>>2]=m;c[e+2984>>2]=k;c[e+4008>>2]=k;if(!f){f=e;gGC(f|0,9706056,76)|0}c[2438118]=c[2433530];c[3528484]=g;c[2417276]=d;c[1836236]=-1;Vr(2,4e6,0,2792,66,0);c[2438228]=4e6;c[2433526]=3416;c[2406676]=1752;c[3528472]=9362;c[2443846]=511;h[745419]=.7;a[3203368]=1;h[745418]=.07;a[3203360]=1;h[745417]=.07;a[3203352]=1;h[745416]=.07;a[3203344]=1;h[745415]=.7;a[3203336]=1;h[745414]=.07;a[3203328]=1;h[745413]=.07;a[3203320]=1;h[745412]=.07;a[3203312]=1;UB(0,2792,375e3,5362,4);UB(1,2792,375e3,418,4);h[1207773]=.25;c[2415548]=3;c[2415126]=9665376;h[1208176]=.25;c[2416354]=3;c[2113248]=4e8/(c[2424]|0)|0;return 0}function WN(a){a=a|0;var b=0.0;b=+(a|0)*+((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)/4.0e6;+V(b)>=1.0?b>0.0?(al(+U(b/4294967296.0),4294967295.0)|0)>>>0:~~+af((b- +(~~b>>>0))/4294967296.0)>>>0:0;return~~b>>>0|0}function WO(){return+(+((c[2426530]|0)+(c[2433530]|0)-(c[2076596]|0)|0)/4.0e6)}function WP(){var b=0,d=0,e=0;b=c[2429754]|0;d=b&15;c[2415126]=9662152;if((c[2415542]|0)==4){e=d}else{e=d<<1&14}c[2415538]=e;c[2429754]=b>>4;b=c[2429750]|0;c[2429750]=b^1;if((b|0)!=1){return}if((a[9706115]|0)==0){a[9706116]=1}a[9706115]=1;gfc(0)|0;a[9706115]=0;gfc(0)|0;c[2433530]=(c[2433530]|0)+12;return}function WQ(){var a=0,b=0,d=0;a=c[2429752]|0;b=a&15;c[2415126]=9665376;if((c[2416348]|0)==4){d=b}else{d=b<<1&14}c[2416344]=d;c[2429752]=a>>4;c[2429748]=c[2429748]^1;return}function WR(){var a=0,b=0,d=0,e=0,f=0,g=0,i=0;a=c[2439330]|0;if((a|0)!=0){b=a;gGC(9706056,b|0,76)|0}c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;gGz(9706056,0,76);c[2443831]=1073676288;c[2443830]=1073676288;c[2443823]=1073676288;c[2443822]=1073676288;h[6675]=0.0;c[3528512]=0;if((c[2385508]|0)>0){b=0;do{lN(b);mB(b);b=b+1|0;}while((b|0)<(c[2385508]|0));b=c[1836236]|0;d=b;e=c[9757320+(b<<2)>>2]|0}else{d=0;e=a}UA();c[2429514]=32768;a=c[3541874]|0;b=128;f=128;while(1){c[e+76+(f<<2)>>2]=a+(f<<8);g=b+1&65535;if((g&65535)>191){break}else{b=g;f=g&65535}}f=(c[2429514]|0)-32768|0;b=128;g=128;while(1){i=a+(f+(g<<8))|0;c[e+76+(g+512<<2)>>2]=i;c[e+76+(g+768<<2)>>2]=i;i=b+1&65535;if((i&65535)>191){break}else{b=i;g=i&65535}}g=e;gGC(g|0,9706056,76)|0;c[9752472+(d<<2)>>2]=c[2433530];c[14113936+(d<<2)>>2]=c[2076596];c[9669104+(d<<2)>>2]=c[3541536];c[1836236]=-1;c[2433432]=0;c[2429754]=0;c[2429752]=0;c[2429750]=0;c[2429748]=0;return 0}function WS(){var b=0,d=0,e=0,f=0,g=0,h=0;fwZ();b=c[3541518]|0;if((b|0)!=0){gGr(b|0);c[3541518]=0}if((c[2385508]|0)>0){c[2113008]=0;c[2076598]=0;c[2383582]=0}c[2438228]=0;c[2433526]=0;c[2406676]=0;c[3528472]=0;b=c[2406680]|0;if((b|0)!=0){gGr(b);c[2406680]=0}c[2385508]=0;c[2432978]=0;a[64240]=0;c[2415126]=9662152;b=c[2408988]|0;if((b|0)!=0){gGz(9662152,0,3224);d=b;b=0;while(1){if((b|0)>=1024){break}e=9638528+(b<<2)|0;if((c[e>>2]|0)==(d|0)){f=50824;break}else{b=b+1|0}}if((f|0)==50824){gGr(d);c[e>>2]=0}c[2408988]=0}c[2415126]=9665376;e=c[2408989]|0;if((e|0)!=0){gGz(9665376,0,3224);d=e;e=0;while(1){if((e|0)>=1024){break}g=9638528+(e<<2)|0;if((c[g>>2]|0)==(d|0)){f=50830;break}else{e=e+1|0}}if((f|0)==50830){gGr(d);c[g>>2]=0}c[2408989]=0}g=c[2443342]|0;d=0;while(1){if((d|0)>=1024){f=50838;break}h=9638528+(d<<2)|0;if((c[h>>2]|0)==(g|0)){break}else{d=d+1|0}}if((f|0)==50838){c[2443342]=0;c[2429514]=0;c[2433432]=0;c[2427054]=0;c[2429754]=0;c[2429752]=0;c[2429750]=0;c[2429748]=0;c[2427084]=0;c[2113248]=0;return 0}gGr(g);c[h>>2]=0;c[2443342]=0;c[2429514]=0;c[2433432]=0;c[2427054]=0;c[2429754]=0;c[2429752]=0;c[2429750]=0;c[2429748]=0;c[2427084]=0;c[2113248]=0;return 0}function WT(){var a=0,d=0,e=0;c[2415126]=9662152;a=c[2415557]|0;d=a&3;if((d|0)==3){e=133}else{e=(4e6/(4e6/((c[2415554]|0)/(c[600992+((a>>>3&1)<<4)+(d<<2)>>2]|0)|0|0)|0|0)|0|0)/((c[2424]|0)/100|0|0)|0}c[2427054]=e;c[2438718]=0;d=c[2113248]|0;a=gGS(d,(d|0)<0|0?-1:0,e,(e|0)<0|0?-1:0)|0;c[2427084]=a;a=c[2385548]|0;if((a|0)>0){gGz(9752472,0,((a|0)>1?a<<2:4)|0)}c[2433530]=0;a=c[2439330]|0;if((a|0)!=0){e=a;gGC(9706056,e|0,76)|0}b[4853030]=c[2426515]&65535;c[2433530]=c[2438118];c[2076596]=c[3528484];c[3541536]=c[2417276];c[1836236]=0;return}function WU(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=c[2438718]|0;if((b|0)<(c[2427054]|0)){d=b;while(1){b=d+1|0;Sb(ag(c[2427084]|0,b)|0);UD();c[2438718]=d;if((b|0)<(c[2427054]|0)){d=b}else{break}}}d=c[2113248]|0;b=gGU(d,(d|0)<0|0?-1:0,2048e6,0)|0;e=c[2438228]|0;f=gGS(b,K,e,(e|0)<0|0?-1:0)|0;e=f;Sb(d);d=c[2443830]|0;if((d|0)<1073676288){c[2443830]=d-e}d=c[2443831]|0;if((d|0)<1073676288){c[2443831]=d-e}d=(c[3528512]|0)-e|0;c[3528512]=(d|0)<0?0:d;d=c[2112964]|0;if((d|0)!=0){gg[c[3542122]&4095](d,a[9688]|0?534:0);Uz(0,c[2112964]|0,a[9688]|0?534:0);Uz(1,c[2112964]|0,a[9688]|0?534:0)}d=c[1836236]|0;e=c[9757320+(d<<2)>>2]|0;if((e|0)==0){g=c[2433530]|0;h=9752472+(d<<2)|0;c[h>>2]=g;i=c[2076596]|0;j=14113936+(d<<2)|0;c[j>>2]=i;k=c[3541536]|0;l=9669104+(d<<2)|0;c[l>>2]=k;c[1836236]=-1;return}f=e;gGC(f|0,9706056,76)|0;g=c[2433530]|0;h=9752472+(d<<2)|0;c[h>>2]=g;i=c[2076596]|0;j=14113936+(d<<2)|0;c[j>>2]=i;k=c[3541536]|0;l=9669104+(d<<2)|0;c[l>>2]=k;c[1836236]=-1;return}function WV(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;i=i+128|0;e=d|0;f=d+16|0;g=d+32|0;h=d+48|0;j=d+64|0;k=d+80|0;l=d+96|0;m=d+112|0;if((a&32|0)!=0){gGz(m|0,0,12);c[m>>2]=c[2443342];c[m+4>>2]=2048;c[m+12>>2]=74448;n=c[2076592]|0;gj[n&4095](m)|0}if((a&64|0)==0){i=d;return 0}fw$(a);Vx(a,b);UE(a,b);gGz(l|0,0,12);c[l>>2]=9718056;c[l+4>>2]=4;c[l+12>>2]=459528;gj[c[2076592]&4095](l)|0;gGz(k|0,0,12);c[k>>2]=9733728;c[k+4>>2]=4;c[k+12>>2]=354528;gj[c[2076592]&4095](k)|0;gGz(j|0,0,12);c[j>>2]=9719016;c[j+4>>2]=4;c[j+12>>2]=276008;gj[c[2076592]&4095](j)|0;gGz(h|0,0,12);c[h>>2]=9719008;c[h+4>>2]=4;c[h+12>>2]=213112;gj[c[2076592]&4095](h)|0;gGz(g|0,0,12);c[g>>2]=9719e3;c[g+4>>2]=4;c[g+12>>2]=166408;gj[c[2076592]&4095](g)|0;gGz(f|0,0,12);c[f>>2]=9718992;c[f+4>>2]=4;c[f+12>>2]=134392;gj[c[2076592]&4095](f)|0;gGz(e|0,0,12);c[e>>2]=9754872;c[e+4>>2]=4;c[e+12>>2]=108816;gj[c[2076592]&4095](e)|0;i=d;return 0}function WW(b,c){b=b|0;c=c|0;a[9706117]=1;gfc(0)|0;a[9706117]=0;gfc(0)|0;return 0}function WX(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[2113248]|0;d=gGU(b,(b|0)<0|0?-1:0,2048e6,0)|0;e=c[2438228]|0;f=gGS(d,K,e,(e|0)<0|0?-1:0)|0;e=f;Sb(b);b=c[2443830]|0;if((b|0)<1073676288){c[2443830]=b-e}b=c[2443831]|0;if((b|0)<1073676288){c[2443831]=b-e}b=(c[3528512]|0)-e|0;c[3528512]=(b|0)<0?0:b;if((c[2112964]|0)!=0){Wt(a[9688]|0?534:0)}b=c[2433530]|0;e=c[2076596]|0;c[2432836]=(c[2426530]|0)+b-e-(c[2113248]|0);f=c[1836236]|0;d=c[9757320+(f<<2)>>2]|0;if((d|0)==0){g=9752472+(f<<2)|0;c[g>>2]=b;h=14113936+(f<<2)|0;c[h>>2]=e;i=c[3541536]|0;j=9669104+(f<<2)|0;c[j>>2]=i;c[1836236]=-1;return}k=d;gGC(k|0,9706056,76)|0;g=9752472+(f<<2)|0;c[g>>2]=b;h=14113936+(f<<2)|0;c[h>>2]=e;i=c[3541536]|0;j=9669104+(f<<2)|0;c[j>>2]=i;c[1836236]=-1;return}function WY(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=b&65535;if((e|0)==61441){b=c[2113304]|0;a[14168504+b|0]=d;mv(0,b,d&255);return}else if((e|0)==61442){Uv(0,d);return}else if((e|0)==61440){c[2113304]=d&255;return}else if((e|0)==61444){e=d&15;if((c[3528526]|0)==(e|0)){return}c[3528526]=e;d=e<<14;e=c[3541874]|0;b=c[9757320+(c[1836236]<<2)>>2]|0;f=(d+49152|0)>>>0>(c[2113246]|0)>>>0?-32768:d;d=128;g=128;while(1){c[b+76+(g<<2)>>2]=e+(f+(g<<8));h=d+1&65535;if((h&65535)>191){i=128;j=128;break}else{d=h;g=h&65535}}while(1){g=e+(f+(j<<8))|0;c[b+76+(j+512<<2)>>2]=g;c[b+76+(j+768<<2)>>2]=g;g=i+1&65535;if((g&65535)>191){break}else{i=g;j=g&65535}}return}else{return}}function WZ(b,d){b=b|0;d=d|0;var e=0;e=b&65535;if((e|0)==57345){b=c[2113304]|0;a[14168504+b|0]=d;mv(0,b,d&255);return}else if((e|0)==57344){c[2113304]=d&255;return}else if((e|0)==58368){Uv(0,d);return}else{return}}function W_(b){b=b|0;var d=0,e=0;d=b&65535;if((d|0)==61441){e=c[(c[3531464]|0)+4240>>2]&255}else if((d|0)==61442){e=c[2113156]&255}else if((d|0)==61448){e=a[14130592]|0}else if((d|0)==61450){e=a[14130584]|0}else{e=0}return e|0}function W$(b){b=b|0;var d=0,e=0;d=b&65535;if((d|0)==59392){e=a[14130592]|0}else if((d|0)==58368){e=c[2113156]&255}else if((d|0)==57345){e=c[(c[3531464]|0)+4240>>2]&255}else{e=0}return e|0}function W0(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0;a=c[2113234]|0;b=a&24;d=b+8|0;if((a&2|0)!=0){e=c[2113232]|0;do{if((a&4|0)==0){f=-8-b|0;if((e|0)<=(f|0)|(e|0)>383){g=0;return g|0}h=c[2113230]|0;if((h|0)<=(f|0)|(h|0)>223){g=0}else{i=h;break}return g|0}else{i=c[2113230]|0}}while(0);c[2113228]=(e*32767|0)+1073742207;c[2113226]=(i*32767|0)+1073742047}i=c[2113236]&c[2113266];c[2113236]=i;if(i>>>0>=(c[2113268]|0)>>>0){g=1;return g|0}e=c[3542028]|0;c[2112960]=e+i;b=c[2112968]|0;h=ag(c[2113300]|0,c[2113230]|0)|0;c[2112962]=b+((ag(c[2113308]|0,c[2113232]|0)|0)+h);h=(d|0)==32;c[2113224]=h?16:8;b=c[2113238]|0;do{if((b&2|0)!=0){if((d|0)==16){c[2113224]=-8;c[2112960]=e+(i+120);break}if(h){c[2113224]=-16;c[2112960]=e+(i+496);break}else{c[2113224]=-8;c[2112960]=e+(i+56);break}}}while(0);g=gD[c[14166472+((b&1|a&30)<<2)>>2]&8191]()|0;return g|0}function W1(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0;a=c[2113234]|0;b=a&24;d=b+8|0;if((a&2|0)!=0){e=c[2113232]|0;do{if((a&4|0)==0){f=-8-b|0;if((e|0)<=(f|0)|(e|0)>383){g=0;return g|0}h=c[2113230]|0;if((h|0)<=(f|0)|(h|0)>223){g=0}else{i=h;break}return g|0}else{i=c[2113230]|0}}while(0);c[2113228]=(e*32767|0)+1073742207;c[2113226]=(i*32767|0)+1073742047}i=c[2113236]&c[2113266];c[2113236]=i;if(i>>>0>=(c[2113268]|0)>>>0){g=1;return g|0}e=c[3542028]|0;c[2112960]=e+i;b=c[2112968]|0;h=ag(c[2113300]|0,c[2113230]|0)|0;c[2112962]=b+((ag(c[2113308]|0,c[2113232]|0)|0)+h);h=(d|0)==32;c[2113224]=h?16:8;b=c[2113238]|0;do{if((b&2|0)!=0){if((d|0)==16){c[2113224]=-8;c[2112960]=e+(i+120);break}if(h){c[2113224]=-16;c[2112960]=e+(i+496);break}else{c[2113224]=-8;c[2112960]=e+(i+56);break}}}while(0);g=gD[c[14166344+((b&1|a&30)<<2)>>2]&8191]()|0;return g|0}function W2(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[2113234]|0;b=a&24;d=b+8|0;if((a&2|0)!=0){e=c[2113232]|0;do{if((a&4|0)==0){f=-8-b|0;if((e|0)<=(f|0)|(e|0)>383){g=0;return g|0}h=c[2113230]|0;i=c[2113038]|0;j=c[2113214]|0;if((h|0)>(f-i|0)&(h|0)<(j|0)){k=j;l=i;m=h;break}else{g=0}return g|0}else{k=c[2113214]|0;l=c[2113038]|0;m=c[2113230]|0}}while(0);c[2113228]=(e*32767|0)+1073742207;c[2113226]=1073741823-l+k+((m-l|0)*32767|0)}l=c[2113236]&c[2113266];c[2113236]=l;if(l>>>0>=(c[2113268]|0)>>>0){g=0;return g|0}m=c[3542028]|0;c[2112960]=m+l;k=c[2112968]|0;e=ag(c[2113300]|0,c[2113230]|0)|0;c[2112962]=k+((ag(c[2113308]|0,c[2113232]|0)|0)+e);e=(d|0)==32;c[2113224]=e?16:8;k=c[2113238]|0;do{if((k&2|0)!=0){if((d|0)==16){c[2113224]=-8;c[2112960]=m+(l+120);break}if(e){c[2113224]=-16;c[2112960]=m+(l+496);break}else{c[2113224]=-8;c[2112960]=m+(l+56);break}}}while(0);g=gD[c[14166472+((k&1|a&30)<<2)>>2]&8191]()|0;return g|0}function W3(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a=c[2113234]|0;b=a&24;d=b+8|0;if((a&2|0)!=0){e=c[2113232]|0;do{if((a&4|0)==0){f=-8-b|0;if((e|0)<=(f|0)|(e|0)>383){g=0;return g|0}h=c[2113230]|0;if((h|0)<=(f|0)|(h|0)>223){g=0}else{i=h;break}return g|0}else{i=c[2113230]|0}}while(0);c[2113228]=(e*32767|0)+1073742207;c[2113226]=(i*32767|0)+1073742047}i=c[2113236]&c[2113266];c[2113236]=i;if(i>>>0>=(c[2113268]|0)>>>0){g=1;return g|0}e=c[3542028]|0;c[2112960]=e+i;b=c[2112968]|0;h=c[2113230]|0;f=ag(c[2113300]|0,h)|0;j=c[2113232]|0;c[2112962]=b+((ag(c[2113308]|0,j)|0)+f);c[2112924]=(c[3531284]|0)+(j+(h*384|0)<<1);h=(d|0)==32;c[2113224]=h?16:8;j=c[2113238]|0;do{if((j&2|0)!=0){if((d|0)==16){c[2113224]=-8;c[2112960]=e+(i+120);break}if(h){c[2113224]=-16;c[2112960]=e+(i+496);break}else{c[2113224]=-8;c[2112960]=e+(i+56);break}}}while(0);g=gD[c[14166216+((j&1|a&30)<<2)>>2]&8191]()|0;return g|0}function W4(b,c,e,f,g,h,i,j,k){b=b|0;c=c|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0;if((g|0)<=0){return}l=1<<(h&7);m=1<<(h>>>4&7);n=1<<(h>>>8&7);o=1<<(h>>>12&7);p=h>>16;h=1<<(p>>>12&7);q=1<<(p>>>8&7);r=1<<(p>>>4&7);s=1<<(p&7);p=1<<(i>>>12&7);t=1<<(i>>>8&7);u=1<<(i>>>4&7);v=1<<(i&7);w=i>>16;i=1<<(w&7);x=1<<(w>>>4&7);y=1<<(w>>>8&7);z=1<<(w>>>12&7);w=j+1|0;A=0;do{B=A+f|0;C=B+j|0;D=b+A|0;E=d[D]|0;F=C&255;if((F&l|0)==0){G=E}else{G=E<<1&2|E&252|E>>>1&1}if((F&m|0)==0){H=G}else{H=G<<1&8|G&243|G>>>1&4}if((F&n|0)==0){I=H}else{I=H<<1&32|H&207|H>>>1&16}if((F&o|0)==0){J=I}else{J=I<<1&128|I&63|I>>>1&64}E=J<<1;K=J>>>7;if((F&h|0)==0){L=E&254|K&1}else{L=E&252|J&1|K<<1&2}if((F&q|0)==0){M=L}else{M=L<<1&8|L&243|L>>>1&4}if((F&r|0)==0){N=M}else{N=M<<1&32|M&207|M>>>1&16}if((F&s|0)==0){O=N}else{O=N<<1&128|N&63|N>>>1&64}F=O^k;K=F<<1;E=F>>>7;P=C>>8;if((P&p|0)==0){Q=K&254|E&1}else{Q=K&252|F&1|E<<1&2}if((P&t|0)==0){R=Q}else{R=Q<<1&8|Q&243|Q>>>1&4}if((P&u|0)==0){S=R}else{S=R<<1&32|R&207|R>>>1&16}if((P&v|0)==0){T=S}else{T=S<<1&128|S&63|S>>>1&64}E=T<<1;F=T>>>7;if((P&i|0)==0){U=E&254|F&1}else{U=E&252|T&1|F<<1&2}if((P&x|0)==0){V=U}else{V=U<<1&8|U&243|U>>>1&4}if((P&y|0)==0){W=V}else{W=V<<1&32|V&207|V>>>1&16}if((P&z|0)==0){X=W&255}else{X=(W<<1&128|W&63|W>>>1&64)&255}a[c+A|0]=X;P=w+(B^8128)|0;B=d[D]|0;D=P&255;if((D&l|0)==0){Y=B}else{Y=B<<1&2|B&252|B>>>1&1}if((D&m|0)==0){Z=Y}else{Z=Y<<1&8|Y&243|Y>>>1&4}if((D&n|0)==0){_=Z}else{_=Z<<1&32|Z&207|Z>>>1&16}if((D&o|0)==0){$=_}else{$=_<<1&128|_&63|_>>>1&64}B=$<<1;F=$>>>7;if((D&h|0)==0){aa=B&254|F&1}else{aa=B&252|$&1|F<<1&2}if((D&q|0)==0){ab=aa}else{ab=aa<<1&8|aa&243|aa>>>1&4}if((D&r|0)==0){ac=ab}else{ac=ab<<1&32|ab&207|ab>>>1&16}if((D&s|0)==0){ad=ac}else{ad=ac<<1&128|ac&63|ac>>>1&64}D=ad^k;F=D<<1;B=D>>>7;E=P>>8;if((E&p|0)==0){ae=F&254|B&1}else{ae=F&252|D&1|B<<1&2}if((E&t|0)==0){af=ae}else{af=ae<<1&8|ae&243|ae>>>1&4}if((E&u|0)==0){ag=af}else{ag=af<<1&32|af&207|af>>>1&16}if((E&v|0)==0){ah=ag}else{ah=ag<<1&128|ag&63|ag>>>1&64}B=ah<<1;D=ah>>>7;if((E&i|0)==0){ai=B&254|D&1}else{ai=B&252|ah&1|D<<1&2}if((E&x|0)==0){aj=ai}else{aj=ai<<1&8|ai&243|ai>>>1&4}if((E&y|0)==0){ak=aj}else{ak=aj<<1&32|aj&207|aj>>>1&16}if((E&z|0)==0){al=ak&255}else{al=(ak<<1&128|ak&63|ak>>>1&64)&255}a[e+A|0]=al;A=A+1|0;}while((A|0)<(g|0));return}function W5(){var a=0,b=0;a=c[3541874]|0;b=a+((c[2113246]|0)>>>1)|0;c[3541874]=b;W4(a,b,a,0,32768,19088743,1410740338,20817,81);return}function W6(){var a=0,b=0;a=c[3541874]|0;b=a+((c[2113246]|0)>>>1)|0;c[3541874]=b;W4(a,b,a,0,32768,1985229328,610276183,17219,67);return}function W7(){var a=0,b=0;a=c[3541874]|0;b=a+((c[2113246]|0)>>>1)|0;c[3541874]=b;W4(a,b,a,0,32768,1732583683,1966170148,8738,34);return}function W8(){var a=0,b=0;a=c[3541874]|0;b=a+((c[2113246]|0)>>>1)|0;c[3541874]=b;W4(a,b,a,0,32768,1412567158,1698898183,12593,25);return}function W9(a){a=a|0;var b=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2388324]|0;gGC(b|0,a|0,6144)|0;a=d[(c[3541926]|0)+(c[2113254]|0)|0]|0;f=b;b=c[3541942]|0;g=0;h=f;while(1){if((1<<g&a|0)==0){i=(h|0)==(f|0)?h:h+1024|0}else{j=g<<9;k=0;l=h;while(1){m=e[l>>1]|0;n=(m>>>12<<1)+15|0;o=((ag((m>>>8&15)*17|0,n)|0)>>>0)/45|0;p=((ag((m>>>4&15)*17|0,n)|0)>>>0)/45|0;c[b+((k^15)+j<<2)>>2]=p<<3&2016|o<<8&63488|(((ag((m&15)*17|0,n)|0)>>>0)/45|0)>>>3&31;n=k+1|0;if((n|0)<512){k=n;l=l+2|0}else{break}}i=h+1024|0}l=g+1|0;if((l|0)<6){g=l;h=i}else{break}}return}function Xa(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=0;do{g=e+(f*96|0)+64|0;h=e+(f*96|0)+68|0;i=e+(f*96|0)+72|0;j=e+(f*96|0)+76|0;k=e+(f*96|0)+80|0;l=e+(f*96|0)+84|0;m=0;do{n=c[g>>2]|0;if((n|0)==-1){o=0}else{o=m>>>(n>>>0)&1}n=c[h>>2]|0;if((n|0)==-1){p=o}else{p=m>>>(n>>>0)<<1&2|o}n=c[i>>2]|0;if((n|0)==-1){q=p}else{q=m>>>(n>>>0)<<2&4|p}n=c[j>>2]|0;if((n|0)==-1){r=q}else{r=m>>>(n>>>0)<<3&8|q}n=c[k>>2]|0;if((n|0)==-1){s=r}else{s=m>>>(n>>>0)<<4&16|r}n=c[l>>2]|0;if((n|0)==-1){t=s&255}else{t=(m>>>(n>>>0)<<5&32|s)&255}a[b+(f*320|0)+m|0]=t;m=m+1|0;}while((m|0)<256);m=e+(f*96|0)+92|0;l=e+(f*96|0)+88|0;k=0;do{j=d[e+(f*96|0)+k|0]|0;i=b+(f*320|0)+256+k|0;a[i]=0;if((j&1|0)==0){u=0}else{h=1<<c[l>>2];a[i]=h&255;u=h&255}if((j&2|0)!=0){a[i]=(1<<c[m>>2]|u)&255}k=k+1|0;}while((k|0)<64);f=f+1|0;}while((f|0)<4);return}function Xb(b,e,f,g,h,i,j,k,l,m,n){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;o=b&65535;b=c[f+28>>2]|0;p=c[f+24>>2]|0;q=c[f+20>>2]|0;r=c[f+16>>2]|0;s=c[f+12>>2]|0;t=c[f+8>>2]|0;u=c[f+4>>2]|0;v=c[f>>2]|0;f=c[e+28>>2]|0;w=c[e+24>>2]|0;x=c[e+20>>2]|0;y=c[e+16>>2]|0;z=c[e+12>>2]|0;A=c[e+8>>2]|0;B=c[e+4>>2]|0;C=c[e>>2]|0;e=o>>>(w>>>0)<<6&64|o>>>(f>>>0)<<7&128|o>>>(x>>>0)<<5&32|o>>>(y>>>0)<<4&16|o>>>(z>>>0)<<3&8|o>>>(A>>>0)<<2&4|o>>>(B>>>0)<<1&2|o>>>(C>>>0)&1;D=(a[((d[g+320+e|0]|0)^k>>>6&63)+(g+576)|0]|a[((d[g+e|0]|0)^k&63)+(g+256)|0]|a[((d[g+640+e|0]|0)^k>>>12&63)+(g+896)|0]|a[((d[g+960+e|0]|0)^k>>>18&63)+(g+1216)|0])&255^(o>>>(p>>>0)<<6&64|o>>>(b>>>0)<<7&128|o>>>(q>>>0)<<5&32|o>>>(r>>>0)<<4&16|o>>>(s>>>0)<<3&8|o>>>(t>>>0)<<2&4|o>>>(u>>>0)<<1&2|o>>>(v>>>0)&1);o=D&255;g=(a[((d[h+320+o|0]|0)^l>>>6&63)+(h+576)|0]|a[((d[h+o|0]|0)^l&63)+(h+256)|0]|a[((d[h+640+o|0]|0)^l>>>12&63)+(h+896)|0]|a[((d[h+960+o|0]|0)^l>>>18&63)+(h+1216)|0])&255^e;e=(a[((d[i+320+g|0]|0)^m>>>6&63)+(i+576)|0]|a[((d[i+g|0]|0)^m&63)+(i+256)|0]|a[((d[i+640+g|0]|0)^m>>>12&63)+(i+896)|0]|a[((d[i+960+g|0]|0)^m>>>18&63)+(i+1216)|0])&255^D;D=e&255;i=(a[((d[j+320+D|0]|0)^n>>>6&63)+(j+576)|0]|a[((d[j+D|0]|0)^n&63)+(j+256)|0]|a[((d[j+640+D|0]|0)^n>>>12&63)+(j+896)|0]|a[((d[j+960+D|0]|0)^n>>>18&63)+(j+1216)|0])&255^g;return((e>>>1&1)<<B|(e&1)<<C|(e>>>2&1)<<A|(e>>>3&1)<<z|(e>>>4&1)<<y|(e>>>5&1)<<x|(e>>>6&1)<<w|(e>>>7&1)<<f|(i&1)<<v|i>>>7<<b|(i>>>1&1)<<u|(i>>>2&1)<<t|(i>>>3&1)<<s|(i>>>4&1)<<r|(i>>>5&1)<<q|(i>>>6&1)<<p)&65535|0}function Xc(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6204764+(b*112|0)>>2];c[a+104>>2]=c[6204768+(b*112|0)>>2];c[a+108>>2]=c[6204772+(b*112|0)>>2];d=0;return d|0}function Xd(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=6204664+(b*112|0);e=0;return e|0}function Xe(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3661656+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function Xf(){a[7461704]=0;a[7461640]=0;a[7461632]=0;a[7460896]=0;c[1865524]=39;a[7462112]=0;c[3541966]=0;c[3541964]=0;c[3541962]=0;a[7461984]=0;a[7461976]=0;a[7461968]=0;Wr();return 0}function Xg(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5218260+(b*112|0)>>2];c[a+104>>2]=c[5218264+(b*112|0)>>2];c[a+108>>2]=c[5218268+(b*112|0)>>2];d=0;return d|0}function Xh(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=5218160+(b*112|0);e=0;return e|0}function Xi(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5216468+(b*112|0)>>2];c[a+104>>2]=c[5216472+(b*112|0)>>2];c[a+108>>2]=c[5216476+(b*112|0)>>2];d=0;return d|0}function Xj(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=5216368+(b*112|0);e=0;return e|0}function Xk(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5212884+(b*112|0)>>2];c[a+104>>2]=c[5212888+(b*112|0)>>2];c[a+108>>2]=c[5212892+(b*112|0)>>2];d=0;return d|0}function Xl(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=5212784+(b*112|0);e=0;return e|0}function Xm(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5211092+(b*112|0)>>2];c[a+104>>2]=c[5211096+(b*112|0)>>2];c[a+108>>2]=c[5211100+(b*112|0)>>2];d=0;return d|0}function Xn(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=5210992+(b*112|0);e=0;return e|0}function Xo(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1801772+(b*112|0)>>2];c[a+104>>2]=c[1801776+(b*112|0)>>2];c[a+108>>2]=c[1801780+(b*112|0)>>2];d=0;return d|0}function Xp(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=1801672+(b*112|0);e=0;return e|0}function Xq(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6206556+(b*112|0)>>2];c[a+104>>2]=c[6206560+(b*112|0)>>2];c[a+108>>2]=c[6206564+(b*112|0)>>2];d=0;return d|0}function Xr(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=6206456+(b*112|0);e=0;return e|0}function Xs(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3661656+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function Xt(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5220052+(b*112|0)>>2];c[a+104>>2]=c[5220056+(b*112|0)>>2];c[a+108>>2]=c[5220060+(b*112|0)>>2];d=0;return d|0}function Xu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=5219952+(b*112|0);e=0;return e|0}function Xv(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6431356+(b*112|0)>>2];c[a+104>>2]=c[6431360+(b*112|0)>>2];c[a+108>>2]=c[6431364+(b*112|0)>>2];d=0;return d|0}function Xw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=6431256+(b*112|0);e=0;return e|0}function Xx(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>31){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4270616+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function Xy(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4268476+(b*112|0)>>2];c[a+104>>2]=c[4268480+(b*112|0)>>2];c[a+108>>2]=c[4268484+(b*112|0)>>2];d=0;return d|0}function Xz(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=4268376+(b*112|0);e=0;return e|0}function XA(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5603860+(b*112|0)>>2];c[a+104>>2]=c[5603864+(b*112|0)>>2];c[a+108>>2]=c[5603868+(b*112|0)>>2];d=0;return d|0}function XB(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=5603760+(b*112|0);e=0;return e|0}function XC(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5601620+(b*112|0)>>2];c[a+104>>2]=c[5601624+(b*112|0)>>2];c[a+108>>2]=c[5601628+(b*112|0)>>2];d=0;return d|0}function XD(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=5601520+(b*112|0);e=0;return e|0}function XE(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4266236+(b*112|0)>>2];c[a+104>>2]=c[4266240+(b*112|0)>>2];c[a+108>>2]=c[4266244+(b*112|0)>>2];d=0;return d|0}function XF(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=4266136+(b*112|0);e=0;return e|0}function XG(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6815412+(b*112|0)>>2];c[a+104>>2]=c[6815416+(b*112|0)>>2];c[a+108>>2]=c[6815420+(b*112|0)>>2];d=0;return d|0}function XH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=6815312+(b*112|0);e=0;return e|0}function XI(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5146036+(b*112|0)>>2];c[a+104>>2]=c[5146040+(b*112|0)>>2];c[a+108>>2]=c[5146044+(b*112|0)>>2];d=0;return d|0}function XJ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=5145936+(b*112|0);e=0;return e|0}function XK(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7319428+(b*112|0)>>2];c[a+104>>2]=c[7319432+(b*112|0)>>2];c[a+108>>2]=c[7319436+(b*112|0)>>2];d=0;return d|0}function XL(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=7319328+(b*112|0);e=0;return e|0}function XM(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>31){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=6423728+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function XN(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6976620+(b*112|0)>>2];c[a+104>>2]=c[6976624+(b*112|0)>>2];c[a+108>>2]=c[6976628+(b*112|0)>>2];d=0;return d|0}function XO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=6976520+(b*112|0);e=0;return e|0}function XP(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6973260+(b*112|0)>>2];c[a+104>>2]=c[6973264+(b*112|0)>>2];c[a+108>>2]=c[6973268+(b*112|0)>>2];d=0;return d|0}function XQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=6973160+(b*112|0);e=0;return e|0}function XR(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6971580+(b*112|0)>>2];c[a+104>>2]=c[6971584+(b*112|0)>>2];c[a+108>>2]=c[6971588+(b*112|0)>>2];d=0;return d|0}function XS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=6971480+(b*112|0);e=0;return e|0}function XT(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6969900+(b*112|0)>>2];c[a+104>>2]=c[6969904+(b*112|0)>>2];c[a+108>>2]=c[6969908+(b*112|0)>>2];d=0;return d|0}function XU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=6969800+(b*112|0);e=0;return e|0}function XV(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6420468+(b*112|0)>>2];c[a+104>>2]=c[6420472+(b*112|0)>>2];c[a+108>>2]=c[6420476+(b*112|0)>>2];d=0;return d|0}function XW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=6420368+(b*112|0);e=0;return e|0}function XX(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>36){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4250504+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function XY(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5582876+(b*112|0)>>2];c[a+104>>2]=c[5582880+(b*112|0)>>2];c[a+108>>2]=c[5582884+(b*112|0)>>2];d=0;return d|0}function XZ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=5582776+(b*112|0);e=0;return e|0}function X_(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5579516+(b*112|0)>>2];c[a+104>>2]=c[5579520+(b*112|0)>>2];c[a+108>>2]=c[5579524+(b*112|0)>>2];d=0;return d|0}function X$(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=5579416+(b*112|0);e=0;return e|0}function X0(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6962412+(b*112|0)>>2];c[a+104>>2]=c[6962416+(b*112|0)>>2];c[a+108>>2]=c[6962420+(b*112|0)>>2];d=0;return d|0}function X1(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=6962312+(b*112|0);e=0;return e|0}function X2(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5534192+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function X3(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>29){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6389772+(b*112|0)>>2];c[a+104>>2]=c[6389776+(b*112|0)>>2];c[a+108>>2]=c[6389780+(b*112|0)>>2];d=0;return d|0}function X4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<30&(d|0)==0)){e=1;return e|0}c[a>>2]=6389672+(b*112|0);e=0;return e|0}function X5(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4136232+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function X6(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5521988+(b*112|0)>>2];c[a+104>>2]=c[5521992+(b*112|0)>>2];c[a+108>>2]=c[5521996+(b*112|0)>>2];d=0;return d|0}function X7(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=5521888+(b*112|0);e=0;return e|0}function X8(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5520644+(b*112|0)>>2];c[a+104>>2]=c[5520648+(b*112|0)>>2];c[a+108>>2]=c[5520652+(b*112|0)>>2];d=0;return d|0}function X9(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=5520544+(b*112|0);e=0;return e|0}function Ya(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5519300+(b*112|0)>>2];c[a+104>>2]=c[5519304+(b*112|0)>>2];c[a+108>>2]=c[5519308+(b*112|0)>>2];d=0;return d|0}function Yb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=5519200+(b*112|0);e=0;return e|0}function Yc(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5517956+(b*112|0)>>2];c[a+104>>2]=c[5517960+(b*112|0)>>2];c[a+108>>2]=c[5517964+(b*112|0)>>2];d=0;return d|0}function Yd(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=5517856+(b*112|0);e=0;return e|0}function Ye(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>29){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4132972+(b*112|0)>>2];c[a+104>>2]=c[4132976+(b*112|0)>>2];c[a+108>>2]=c[4132980+(b*112|0)>>2];d=0;return d|0}function Yf(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<30&(d|0)==0)){e=1;return e|0}c[a>>2]=4132872+(b*112|0);e=0;return e|0}function Yg(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6383340+(b*112|0)>>2];c[a+104>>2]=c[6383344+(b*112|0)>>2];c[a+108>>2]=c[6383348+(b*112|0)>>2];d=0;return d|0}function Yh(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=6383240+(b*112|0);e=0;return e|0}function Yi(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>24){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4121416+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function Yj(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5509148+(b*112|0)>>2];c[a+104>>2]=c[5509152+(b*112|0)>>2];c[a+108>>2]=c[5509156+(b*112|0)>>2];d=0;return d|0}function Yk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=5509048+(b*112|0);e=0;return e|0}function Yl(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5506908+(b*112|0)>>2];c[a+104>>2]=c[5506912+(b*112|0)>>2];c[a+108>>2]=c[5506916+(b*112|0)>>2];d=0;return d|0}function Ym(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=5506808+(b*112|0);e=0;return e|0}function Yn(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6957596+(b*112|0)>>2];c[a+104>>2]=c[6957600+(b*112|0)>>2];c[a+108>>2]=c[6957604+(b*112|0)>>2];d=0;return d|0}function Yo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=6957496+(b*112|0);e=0;return e|0}function Yp(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>44){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5476840+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function Yq(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5474700+(b*112|0)>>2];c[a+104>>2]=c[5474704+(b*112|0)>>2];c[a+108>>2]=c[5474708+(b*112|0)>>2];d=0;return d|0}function Yr(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=5474600+(b*112|0);e=0;return e|0}function Ys(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5472460+(b*112|0)>>2];c[a+104>>2]=c[5472464+(b*112|0)>>2];c[a+108>>2]=c[5472468+(b*112|0)>>2];d=0;return d|0}function Yt(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=5472360+(b*112|0);e=0;return e|0}function Yu(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5470220+(b*112|0)>>2];c[a+104>>2]=c[5470224+(b*112|0)>>2];c[a+108>>2]=c[5470228+(b*112|0)>>2];d=0;return d|0}function Yv(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=5470120+(b*112|0);e=0;return e|0}function Yw(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6373060+(b*112|0)>>2];c[a+104>>2]=c[6373064+(b*112|0)>>2];c[a+108>>2]=c[6373068+(b*112|0)>>2];d=0;return d|0}function Yx(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=6372960+(b*112|0);e=0;return e|0}function Yy(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6370820+(b*112|0)>>2];c[a+104>>2]=c[6370824+(b*112|0)>>2];c[a+108>>2]=c[6370828+(b*112|0)>>2];d=0;return d|0}function Yz(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=6370720+(b*112|0);e=0;return e|0}function YA(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6368580+(b*112|0)>>2];c[a+104>>2]=c[6368584+(b*112|0)>>2];c[a+108>>2]=c[6368588+(b*112|0)>>2];d=0;return d|0}function YB(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=6368480+(b*112|0);e=0;return e|0}function YC(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6366340+(b*112|0)>>2];c[a+104>>2]=c[6366344+(b*112|0)>>2];c[a+108>>2]=c[6366348+(b*112|0)>>2];d=0;return d|0}function YD(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=6366240+(b*112|0);e=0;return e|0}function YE(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4091804+(b*112|0)>>2];c[a+104>>2]=c[4091808+(b*112|0)>>2];c[a+108>>2]=c[4091812+(b*112|0)>>2];d=0;return d|0}function YF(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=4091704+(b*112|0);e=0;return e|0}function YG(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6364100+(b*112|0)>>2];c[a+104>>2]=c[6364104+(b*112|0)>>2];c[a+108>>2]=c[6364108+(b*112|0)>>2];d=0;return d|0}function YH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=6364e3+(b*112|0);e=0;return e|0}function YI(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4089564+(b*112|0)>>2];c[a+104>>2]=c[4089568+(b*112|0)>>2];c[a+108>>2]=c[4089572+(b*112|0)>>2];d=0;return d|0}function YJ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=4089464+(b*112|0);e=0;return e|0}function YK(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6955804+(b*112|0)>>2];c[a+104>>2]=c[6955808+(b*112|0)>>2];c[a+108>>2]=c[6955812+(b*112|0)>>2];d=0;return d|0}function YL(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=6955704+(b*112|0);e=0;return e|0}function YM(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>44){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5467160+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function YN(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5465468+(b*112|0)>>2];c[a+104>>2]=c[5465472+(b*112|0)>>2];c[a+108>>2]=c[5465476+(b*112|0)>>2];d=0;return d|0}function YO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=5465368+(b*112|0);e=0;return e|0}function YP(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6362308+(b*112|0)>>2];c[a+104>>2]=c[6362312+(b*112|0)>>2];c[a+108>>2]=c[6362316+(b*112|0)>>2];d=0;return d|0}function YQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=6362208+(b*112|0);e=0;return e|0}function YR(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4087772+(b*112|0)>>2];c[a+104>>2]=c[4087776+(b*112|0)>>2];c[a+108>>2]=c[4087780+(b*112|0)>>2];d=0;return d|0}function YS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=4087672+(b*112|0);e=0;return e|0}function YT(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6358724+(b*112|0)>>2];c[a+104>>2]=c[6358728+(b*112|0)>>2];c[a+108>>2]=c[6358732+(b*112|0)>>2];d=0;return d|0}function YU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=6358624+(b*112|0);e=0;return e|0}function YV(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4085980+(b*112|0)>>2];c[a+104>>2]=c[4085984+(b*112|0)>>2];c[a+108>>2]=c[4085988+(b*112|0)>>2];d=0;return d|0}function YW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=4085880+(b*112|0);e=0;return e|0}function YX(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4084188+(b*112|0)>>2];c[a+104>>2]=c[4084192+(b*112|0)>>2];c[a+108>>2]=c[4084196+(b*112|0)>>2];d=0;return d|0}function YY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=4084088+(b*112|0);e=0;return e|0}function YZ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6356932+(b*112|0)>>2];c[a+104>>2]=c[6356936+(b*112|0)>>2];c[a+108>>2]=c[6356940+(b*112|0)>>2];d=0;return d|0}function Y_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=6356832+(b*112|0);e=0;return e|0}function Y$(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4082396+(b*112|0)>>2];c[a+104>>2]=c[4082400+(b*112|0)>>2];c[a+108>>2]=c[4082404+(b*112|0)>>2];d=0;return d|0}function Y0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=4082296+(b*112|0);e=0;return e|0}function Y1(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4080604+(b*112|0)>>2];c[a+104>>2]=c[4080608+(b*112|0)>>2];c[a+108>>2]=c[4080612+(b*112|0)>>2];d=0;return d|0}function Y2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=4080504+(b*112|0);e=0;return e|0}function Y3(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6355140+(b*112|0)>>2];c[a+104>>2]=c[6355144+(b*112|0)>>2];c[a+108>>2]=c[6355148+(b*112|0)>>2];d=0;return d|0}function Y4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=6355040+(b*112|0);e=0;return e|0}function Y5(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4078812+(b*112|0)>>2];c[a+104>>2]=c[4078816+(b*112|0)>>2];c[a+108>>2]=c[4078820+(b*112|0)>>2];d=0;return d|0}function Y6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=4078712+(b*112|0);e=0;return e|0}function Y7(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5459924+(b*112|0)>>2];c[a+104>>2]=c[5459928+(b*112|0)>>2];c[a+108>>2]=c[5459932+(b*112|0)>>2];d=0;return d|0}function Y8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=5459824+(b*112|0);e=0;return e|0}function Y9(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1957304+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function Za(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7208620+(b*112|0)>>2];c[a+104>>2]=c[7208624+(b*112|0)>>2];c[a+108>>2]=c[7208628+(b*112|0)>>2];d=0;return d|0}function Zb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=7208520+(b*112|0);e=0;return e|0}function Zc(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4065732+(b*112|0)>>2];c[a+104>>2]=c[4065736+(b*112|0)>>2];c[a+108>>2]=c[4065740+(b*112|0)>>2];d=0;return d|0}function Zd(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=4065632+(b*112|0);e=0;return e|0}function Ze(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6892628+(b*112|0)>>2];c[a+104>>2]=c[6892632+(b*112|0)>>2];c[a+108>>2]=c[6892636+(b*112|0)>>2];d=0;return d|0}function Zf(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=6892528+(b*112|0);e=0;return e|0}function Zg(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>28){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=704232+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function Zh(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6335828+(b*112|0)>>2];c[a+104>>2]=c[6335832+(b*112|0)>>2];c[a+108>>2]=c[6335836+(b*112|0)>>2];d=0;return d|0}function Zi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=6335728+(b*112|0);e=0;return e|0}function Zj(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6333588+(b*112|0)>>2];c[a+104>>2]=c[6333592+(b*112|0)>>2];c[a+108>>2]=c[6333596+(b*112|0)>>2];d=0;return d|0}function Zk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=6333488+(b*112|0);e=0;return e|0}function Zl(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6331348+(b*112|0)>>2];c[a+104>>2]=c[6331352+(b*112|0)>>2];c[a+108>>2]=c[6331356+(b*112|0)>>2];d=0;return d|0}function Zm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=6331248+(b*112|0);e=0;return e|0}function Zn(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4032884+(b*112|0)>>2];c[a+104>>2]=c[4032888+(b*112|0)>>2];c[a+108>>2]=c[4032892+(b*112|0)>>2];d=0;return d|0}function Zo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=4032784+(b*112|0);e=0;return e|0}function Zp(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6658124+(b*112|0)>>2];c[a+104>>2]=c[6658128+(b*112|0)>>2];c[a+108>>2]=c[6658132+(b*112|0)>>2];d=0;return d|0}function Zq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=6658024+(b*112|0);e=0;return e|0}function Zr(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6020196+(b*112|0)>>2];c[a+104>>2]=c[6020200+(b*112|0)>>2];c[a+108>>2]=c[6020204+(b*112|0)>>2];d=0;return d|0}function Zs(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=6020096+(b*112|0);e=0;return e|0}function Zt(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4899292+(b*112|0)>>2];c[a+104>>2]=c[4899296+(b*112|0)>>2];c[a+108>>2]=c[4899300+(b*112|0)>>2];d=0;return d|0}function Zu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=4899192+(b*112|0);e=0;return e|0}function Zv(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4021388+(b*112|0)>>2];c[a+104>>2]=c[4021392+(b*112|0)>>2];c[a+108>>2]=c[4021396+(b*112|0)>>2];d=0;return d|0}function Zw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=4021288+(b*112|0);e=0;return e|0}function Zx(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1275544+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function Zy(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1948156+(b*112|0)>>2];c[a+104>>2]=c[1948160+(b*112|0)>>2];c[a+108>>2]=c[1948164+(b*112|0)>>2];d=0;return d|0}function Zz(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=1948056+(b*112|0);e=0;return e|0}function ZA(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1944796+(b*112|0)>>2];c[a+104>>2]=c[1944800+(b*112|0)>>2];c[a+108>>2]=c[1944804+(b*112|0)>>2];d=0;return d|0}function ZB(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=1944696+(b*112|0);e=0;return e|0}function ZC(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1943116+(b*112|0)>>2];c[a+104>>2]=c[1943120+(b*112|0)>>2];c[a+108>>2]=c[1943124+(b*112|0)>>2];d=0;return d|0}function ZD(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=1943016+(b*112|0);e=0;return e|0}function ZE(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1273964+(b*112|0)>>2];c[a+104>>2]=c[1273968+(b*112|0)>>2];c[a+108>>2]=c[1273972+(b*112|0)>>2];d=0;return d|0}function ZF(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=1273864+(b*112|0);e=0;return e|0}function ZG(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3274100+(b*112|0)>>2];c[a+104>>2]=c[3274104+(b*112|0)>>2];c[a+108>>2]=c[3274108+(b*112|0)>>2];d=0;return d|0}function ZH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=3274e3+(b*112|0);e=0;return e|0}function ZI(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3907596+(b*112|0)>>2];c[a+104>>2]=c[3907600+(b*112|0)>>2];c[a+108>>2]=c[3907604+(b*112|0)>>2];d=0;return d|0}function ZJ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=3907496+(b*112|0);e=0;return e|0}function ZK(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=3661656+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function ZL(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1889388+(b*112|0)>>2];c[a+104>>2]=c[1889392+(b*112|0)>>2];c[a+108>>2]=c[1889396+(b*112|0)>>2];d=0;return d|0}function ZM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=1889288+(b*112|0);e=0;return e|0}function ZN(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1888268+(b*112|0)>>2];c[a+104>>2]=c[1888272+(b*112|0)>>2];c[a+108>>2]=c[1888276+(b*112|0)>>2];d=0;return d|0}function ZO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=1888168+(b*112|0);e=0;return e|0}function ZP(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1886028+(b*112|0)>>2];c[a+104>>2]=c[1886032+(b*112|0)>>2];c[a+108>>2]=c[1886036+(b*112|0)>>2];d=0;return d|0}function ZQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=1885928+(b*112|0);e=0;return e|0}function ZR(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1884908+(b*112|0)>>2];c[a+104>>2]=c[1884912+(b*112|0)>>2];c[a+108>>2]=c[1884916+(b*112|0)>>2];d=0;return d|0}function ZS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=1884808+(b*112|0);e=0;return e|0}function ZT(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7203076+(b*112|0)>>2];c[a+104>>2]=c[7203080+(b*112|0)>>2];c[a+108>>2]=c[7203084+(b*112|0)>>2];d=0;return d|0}function ZU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=7202976+(b*112|0);e=0;return e|0}function ZV(){var b=0;a[7461640]=1;c[3542068]=2;do{if((Wq(0)|0)==0){Wo()|0;if((Wq(1)|0)!=0){b=1;break}b=agT()|0}else{b=1}}while(0);c[2113260]=0;return b|0}function ZW(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6878164+(b*112|0)>>2];c[a+104>>2]=c[6878168+(b*112|0)>>2];c[a+108>>2]=c[6878172+(b*112|0)>>2];d=0;return d|0}function ZX(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=6878064+(b*112|0);e=0;return e|0}function ZY(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6874804+(b*112|0)>>2];c[a+104>>2]=c[6874808+(b*112|0)>>2];c[a+108>>2]=c[6874812+(b*112|0)>>2];d=0;return d|0}function ZZ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=6874704+(b*112|0);e=0;return e|0}function Z_(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3837796+(b*112|0)>>2];c[a+104>>2]=c[3837800+(b*112|0)>>2];c[a+108>>2]=c[3837804+(b*112|0)>>2];d=0;return d|0}function Z$(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=3837696+(b*112|0);e=0;return e|0}function Z0(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1237712+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function Z1(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3752436+(b*112|0)>>2];c[a+104>>2]=c[3752440+(b*112|0)>>2];c[a+108>>2]=c[3752444+(b*112|0)>>2];d=0;return d|0}function Z2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=3752336+(b*112|0);e=0;return e|0}function Z3(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1231736+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function Z4(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1832140+(b*112|0)>>2];c[a+104>>2]=c[1832144+(b*112|0)>>2];c[a+108>>2]=c[1832148+(b*112|0)>>2];d=0;return d|0}function Z5(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=1832040+(b*112|0);e=0;return e|0}function Z6(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1830908+(b*112|0)>>2];c[a+104>>2]=c[1830912+(b*112|0)>>2];c[a+108>>2]=c[1830916+(b*112|0)>>2];d=0;return d|0}function Z7(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=1830808+(b*112|0);e=0;return e|0}function Z8(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1749236+(b*112|0)>>2];c[a+104>>2]=c[1749240+(b*112|0)>>2];c[a+108>>2]=c[1749244+(b*112|0)>>2];d=0;return d|0}function Z9(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=1749136+(b*112|0);e=0;return e|0}function _a(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>27){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3725020+(b*112|0)>>2];c[a+104>>2]=c[3725024+(b*112|0)>>2];c[a+108>>2]=c[3725028+(b*112|0)>>2];d=0;return d|0}function _b(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<28&(d|0)==0)){e=1;return e|0}c[a>>2]=3724920+(b*112|0);e=0;return e|0}function _c(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1230136+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function _d(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>27){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3551908+(b*112|0)>>2];c[a+104>>2]=c[3551912+(b*112|0)>>2];c[a+108>>2]=c[3551916+(b*112|0)>>2];d=0;return d|0}function _e(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<28&(d|0)==0)){e=1;return e|0}c[a>>2]=3551808+(b*112|0);e=0;return e|0}function _f(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5268276+(b*112|0)>>2];c[a+104>>2]=c[5268280+(b*112|0)>>2];c[a+108>>2]=c[5268284+(b*112|0)>>2];d=0;return d|0}function _g(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=5268176+(b*112|0);e=0;return e|0}function _h(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1826344+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function _i(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3721884+(b*112|0)>>2];c[a+104>>2]=c[3721888+(b*112|0)>>2];c[a+108>>2]=c[3721892+(b*112|0)>>2];d=0;return d|0}function _j(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=3721784+(b*112|0);e=0;return e|0}function _k(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6849212+(b*112|0)>>2];c[a+104>>2]=c[6849216+(b*112|0)>>2];c[a+108>>2]=c[6849220+(b*112|0)>>2];d=0;return d|0}function _l(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=6849112+(b*112|0);e=0;return e|0}function _m(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=5260968+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function _n(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5259612+(b*112|0)>>2];c[a+104>>2]=c[5259616+(b*112|0)>>2];c[a+108>>2]=c[5259620+(b*112|0)>>2];d=0;return d|0}function _o(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=5259512+(b*112|0);e=0;return e|0}function _p(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6227164+(b*112|0)>>2];c[a+104>>2]=c[6227168+(b*112|0)>>2];c[a+108>>2]=c[6227172+(b*112|0)>>2];d=0;return d|0}function _q(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=6227064+(b*112|0);e=0;return e|0}function _r(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>12){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6228396+(b*112|0)>>2];c[a+104>>2]=c[6228400+(b*112|0)>>2];c[a+108>>2]=c[6228404+(b*112|0)>>2];d=0;return d|0}function _s(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<13&(d|0)==0)){e=1;return e|0}c[a>>2]=6228296+(b*112|0);e=0;return e|0}function _t(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7392700+(b*112|0)>>2];c[a+104>>2]=c[7392704+(b*112|0)>>2];c[a+108>>2]=c[7392708+(b*112|0)>>2];d=0;return d|0}function _u(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=7392600+(b*112|0);e=0;return e|0}function _v(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7185284+(b*112|0)>>2];c[a+104>>2]=c[7185288+(b*112|0)>>2];c[a+108>>2]=c[7185292+(b*112|0)>>2];d=0;return d|0}function _w(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=7185184+(b*112|0);e=0;return e|0}function _x(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7183044+(b*112|0)>>2];c[a+104>>2]=c[7183048+(b*112|0)>>2];c[a+108>>2]=c[7183052+(b*112|0)>>2];d=0;return d|0}function _y(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=7182944+(b*112|0);e=0;return e|0}function _z(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7180804+(b*112|0)>>2];c[a+104>>2]=c[7180808+(b*112|0)>>2];c[a+108>>2]=c[7180812+(b*112|0)>>2];d=0;return d|0}function _A(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=7180704+(b*112|0);e=0;return e|0}function _B(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7178564+(b*112|0)>>2];c[a+104>>2]=c[7178568+(b*112|0)>>2];c[a+108>>2]=c[7178572+(b*112|0)>>2];d=0;return d|0}function _C(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=7178464+(b*112|0);e=0;return e|0}function _D(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6224924+(b*112|0)>>2];c[a+104>>2]=c[6224928+(b*112|0)>>2];c[a+108>>2]=c[6224932+(b*112|0)>>2];d=0;return d|0}function _E(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=6224824+(b*112|0);e=0;return e|0}function _F(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7176324+(b*112|0)>>2];c[a+104>>2]=c[7176328+(b*112|0)>>2];c[a+108>>2]=c[7176332+(b*112|0)>>2];d=0;return d|0}function _G(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=7176224+(b*112|0);e=0;return e|0}function _H(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6222684+(b*112|0)>>2];c[a+104>>2]=c[6222688+(b*112|0)>>2];c[a+108>>2]=c[6222692+(b*112|0)>>2];d=0;return d|0}function _I(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=6222584+(b*112|0);e=0;return e|0}function _J(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5255748+(b*112|0)>>2];c[a+104>>2]=c[5255752+(b*112|0)>>2];c[a+108>>2]=c[5255756+(b*112|0)>>2];d=0;return d|0}function _K(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=5255648+(b*112|0);e=0;return e|0}function _L(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3691420+(b*112|0)>>2];c[a+104>>2]=c[3691424+(b*112|0)>>2];c[a+108>>2]=c[3691428+(b*112|0)>>2];d=0;return d|0}function _M(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=3691320+(b*112|0);e=0;return e|0}function _N(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5253508+(b*112|0)>>2];c[a+104>>2]=c[5253512+(b*112|0)>>2];c[a+108>>2]=c[5253516+(b*112|0)>>2];d=0;return d|0}function _O(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=5253408+(b*112|0);e=0;return e|0}function _P(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3689180+(b*112|0)>>2];c[a+104>>2]=c[3689184+(b*112|0)>>2];c[a+108>>2]=c[3689188+(b*112|0)>>2];d=0;return d|0}function _Q(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=3689080+(b*112|0);e=0;return e|0}function _R(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5251268+(b*112|0)>>2];c[a+104>>2]=c[5251272+(b*112|0)>>2];c[a+108>>2]=c[5251276+(b*112|0)>>2];d=0;return d|0}function _S(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=5251168+(b*112|0);e=0;return e|0}function _T(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5249028+(b*112|0)>>2];c[a+104>>2]=c[5249032+(b*112|0)>>2];c[a+108>>2]=c[5249036+(b*112|0)>>2];d=0;return d|0}function _U(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=5248928+(b*112|0);e=0;return e|0}function _V(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3686940+(b*112|0)>>2];c[a+104>>2]=c[3686944+(b*112|0)>>2];c[a+108>>2]=c[3686948+(b*112|0)>>2];d=0;return d|0}function _W(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=3686840+(b*112|0);e=0;return e|0}function _X(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3684700+(b*112|0)>>2];c[a+104>>2]=c[3684704+(b*112|0)>>2];c[a+108>>2]=c[3684708+(b*112|0)>>2];d=0;return d|0}function _Y(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=3684600+(b*112|0);e=0;return e|0}function _Z(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5246788+(b*112|0)>>2];c[a+104>>2]=c[5246792+(b*112|0)>>2];c[a+108>>2]=c[5246796+(b*112|0)>>2];d=0;return d|0}function __(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=5246688+(b*112|0);e=0;return e|0}function _$(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3682460+(b*112|0)>>2];c[a+104>>2]=c[3682464+(b*112|0)>>2];c[a+108>>2]=c[3682468+(b*112|0)>>2];d=0;return d|0}function _0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=3682360+(b*112|0);e=0;return e|0}function _1(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7171284+(b*112|0)>>2];c[a+104>>2]=c[7171288+(b*112|0)>>2];c[a+108>>2]=c[7171292+(b*112|0)>>2];d=0;return d|0}function _2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=7171184+(b*112|0);e=0;return e|0}function _3(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6214732+(b*112|0)>>2];c[a+104>>2]=c[6214736+(b*112|0)>>2];c[a+108>>2]=c[6214740+(b*112|0)>>2];d=0;return d|0}function _4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=6214632+(b*112|0);e=0;return e|0}function _5(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6844732+(b*112|0)>>2];c[a+104>>2]=c[6844736+(b*112|0)>>2];c[a+108>>2]=c[6844740+(b*112|0)>>2];d=0;return d|0}function _6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=6844632+(b*112|0);e=0;return e|0}function _7(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5237644+(b*112|0)>>2];c[a+104>>2]=c[5237648+(b*112|0)>>2];c[a+108>>2]=c[5237652+(b*112|0)>>2];d=0;return d|0}function _8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=5237544+(b*112|0);e=0;return e|0}function _9(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6842492+(b*112|0)>>2];c[a+104>>2]=c[6842496+(b*112|0)>>2];c[a+108>>2]=c[6842500+(b*112|0)>>2];d=0;return d|0}function $a(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=6842392+(b*112|0);e=0;return e|0}function $b(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6840252+(b*112|0)>>2];c[a+104>>2]=c[6840256+(b*112|0)>>2];c[a+108>>2]=c[6840260+(b*112|0)>>2];d=0;return d|0}function $c(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=6840152+(b*112|0);e=0;return e|0}function $d(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6838012+(b*112|0)>>2];c[a+104>>2]=c[6838016+(b*112|0)>>2];c[a+108>>2]=c[6838020+(b*112|0)>>2];d=0;return d|0}function $e(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=6837912+(b*112|0);e=0;return e|0}function $f(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5235404+(b*112|0)>>2];c[a+104>>2]=c[5235408+(b*112|0)>>2];c[a+108>>2]=c[5235412+(b*112|0)>>2];d=0;return d|0}function $g(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=5235304+(b*112|0);e=0;return e|0}function $h(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6835772+(b*112|0)>>2];c[a+104>>2]=c[6835776+(b*112|0)>>2];c[a+108>>2]=c[6835780+(b*112|0)>>2];d=0;return d|0}function $i(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=6835672+(b*112|0);e=0;return e|0}function $j(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5233164+(b*112|0)>>2];c[a+104>>2]=c[5233168+(b*112|0)>>2];c[a+108>>2]=c[5233172+(b*112|0)>>2];d=0;return d|0}function $k(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=5233064+(b*112|0);e=0;return e|0}function $l(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1813196+(b*112|0)>>2];c[a+104>>2]=c[1813200+(b*112|0)>>2];c[a+108>>2]=c[1813204+(b*112|0)>>2];d=0;return d|0}function $m(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=1813096+(b*112|0);e=0;return e|0}function $n(){var b=0;a[7462112]=1;c[3542068]=2;if((Wq(0)|0)!=0){b=1;return b|0}Wo()|0;if((Wq(1)|0)!=0){b=1;return b|0}b=agT()|0;return b|0}function $o(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6824588+(b*112|0)>>2];c[a+104>>2]=c[6824592+(b*112|0)>>2];c[a+108>>2]=c[6824596+(b*112|0)>>2];d=0;return d|0}function $p(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=6824488+(b*112|0);e=0;return e|0}function $q(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6196900+(b*112|0)>>2];c[a+104>>2]=c[6196904+(b*112|0)>>2];c[a+108>>2]=c[6196908+(b*112|0)>>2];d=0;return d|0}function $r(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=6196800+(b*112|0);e=0;return e|0}function $s(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6194660+(b*112|0)>>2];c[a+104>>2]=c[6194664+(b*112|0)>>2];c[a+108>>2]=c[6194668+(b*112|0)>>2];d=0;return d|0}function $t(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=6194560+(b*112|0);e=0;return e|0}function $u(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6192420+(b*112|0)>>2];c[a+104>>2]=c[6192424+(b*112|0)>>2];c[a+108>>2]=c[6192428+(b*112|0)>>2];d=0;return d|0}function $v(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=6192320+(b*112|0);e=0;return e|0}function $w(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6190180+(b*112|0)>>2];c[a+104>>2]=c[6190184+(b*112|0)>>2];c[a+108>>2]=c[6190188+(b*112|0)>>2];d=0;return d|0}function $x(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=6190080+(b*112|0);e=0;return e|0}function $y(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6009892+(b*112|0)>>2];c[a+104>>2]=c[6009896+(b*112|0)>>2];c[a+108>>2]=c[6009900+(b*112|0)>>2];d=0;return d|0}function $z(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=6009792+(b*112|0);e=0;return e|0}function $A(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1648508+(b*112|0)>>2];c[a+104>>2]=c[1648512+(b*112|0)>>2];c[a+108>>2]=c[1648516+(b*112|0)>>2];d=0;return d|0}function $B(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=1648408+(b*112|0);e=0;return e|0}function $C(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3265444+(b*112|0)>>2];c[a+104>>2]=c[3265448+(b*112|0)>>2];c[a+108>>2]=c[3265452+(b*112|0)>>2];d=0;return d|0}function $D(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=3265344+(b*112|0);e=0;return e|0}function $E(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3263204+(b*112|0)>>2];c[a+104>>2]=c[3263208+(b*112|0)>>2];c[a+108>>2]=c[3263212+(b*112|0)>>2];d=0;return d|0}function $F(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=3263104+(b*112|0);e=0;return e|0}function $G(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5141052+(b*112|0)>>2];c[a+104>>2]=c[5141056+(b*112|0)>>2];c[a+108>>2]=c[5141060+(b*112|0)>>2];d=0;return d|0}function $H(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=5140952+(b*112|0);e=0;return e|0}function $I(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1782904+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function $J(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3611636+(b*112|0)>>2];c[a+104>>2]=c[3611640+(b*112|0)>>2];c[a+108>>2]=c[3611644+(b*112|0)>>2];d=0;return d|0}function $K(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=3611536+(b*112|0);e=0;return e|0}function $L(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3609956+(b*112|0)>>2];c[a+104>>2]=c[3609960+(b*112|0)>>2];c[a+108>>2]=c[3609964+(b*112|0)>>2];d=0;return d|0}function $M(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=3609856+(b*112|0);e=0;return e|0}function $N(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5137420+(b*112|0)>>2];c[a+104>>2]=c[5137424+(b*112|0)>>2];c[a+108>>2]=c[5137428+(b*112|0)>>2];d=0;return d|0}function $O(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=5137320+(b*112|0);e=0;return e|0}function $P(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1765216+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function $Q(){var b=0;a[7461704]=1;c[3542068]=2;if((Wq(0)|0)!=0){b=1;return b|0}Wo()|0;if((Wq(1)|0)!=0){b=1;return b|0}b=agT()|0;return b|0}function $R(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3596692+(b*112|0)>>2];c[a+104>>2]=c[3596696+(b*112|0)>>2];c[a+108>>2]=c[3596700+(b*112|0)>>2];d=0;return d|0}function $S(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=3596592+(b*112|0);e=0;return e|0}function $T(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1208948+(b*112|0)>>2];c[a+104>>2]=c[1208952+(b*112|0)>>2];c[a+108>>2]=c[1208956+(b*112|0)>>2];d=0;return d|0}function $U(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=1208848+(b*112|0);e=0;return e|0}function $V(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5133780+(b*112|0)>>2];c[a+104>>2]=c[5133784+(b*112|0)>>2];c[a+108>>2]=c[5133788+(b*112|0)>>2];d=0;return d|0}function $W(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=5133680+(b*112|0);e=0;return e|0}function $X(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1764640+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function $Y(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3560748+(b*112|0)>>2];c[a+104>>2]=c[3560752+(b*112|0)>>2];c[a+108>>2]=c[3560756+(b*112|0)>>2];d=0;return d|0}function $Z(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<22&(d|0)==0)){e=1;return e|0}c[a>>2]=3560648+(b*112|0);e=0;return e|0}function $_(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>28){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1204920+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function $$(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6074956+(b*112|0)>>2];c[a+104>>2]=c[6074960+(b*112|0)>>2];c[a+108>>2]=c[6074964+(b*112|0)>>2];d=0;return d|0}function $0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<22&(d|0)==0)){e=1;return e|0}c[a>>2]=6074856+(b*112|0);e=0;return e|0}function $1(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3426012+(b*112|0)>>2];c[a+104>>2]=c[3426016+(b*112|0)>>2];c[a+108>>2]=c[3426020+(b*112|0)>>2];d=0;return d|0}function $2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<22&(d|0)==0)){e=1;return e|0}c[a>>2]=3425912+(b*112|0);e=0;return e|0}function $3(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1753268+(b*112|0)>>2];c[a+104>>2]=c[1753272+(b*112|0)>>2];c[a+108>>2]=c[1753276+(b*112|0)>>2];d=0;return d|0}function $4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<22&(d|0)==0)){e=1;return e|0}c[a>>2]=1753168+(b*112|0);e=0;return e|0}function $5(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7373004+(b*112|0)>>2];c[a+104>>2]=c[7373008+(b*112|0)>>2];c[a+108>>2]=c[7373012+(b*112|0)>>2];d=0;return d|0}function $6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=7372904+(b*112|0);e=0;return e|0}function $7(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6730268+(b*112|0)>>2];c[a+104>>2]=c[6730272+(b*112|0)>>2];c[a+108>>2]=c[6730276+(b*112|0)>>2];d=0;return d|0}function $8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=6730168+(b*112|0);e=0;return e|0}function $9(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6728924+(b*112|0)>>2];c[a+104>>2]=c[6728928+(b*112|0)>>2];c[a+108>>2]=c[6728932+(b*112|0)>>2];d=0;return d|0}function aaa(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=6728824+(b*112|0);e=0;return e|0}function aab(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6727580+(b*112|0)>>2];c[a+104>>2]=c[6727584+(b*112|0)>>2];c[a+108>>2]=c[6727588+(b*112|0)>>2];d=0;return d|0}function aac(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=6727480+(b*112|0);e=0;return e|0}function aad(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7133748+(b*112|0)>>2];c[a+104>>2]=c[7133752+(b*112|0)>>2];c[a+108>>2]=c[7133756+(b*112|0)>>2];d=0;return d|0}function aae(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=7133648+(b*112|0);e=0;return e|0}function aaf(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7131636+(b*112|0)>>2];c[a+104>>2]=c[7131640+(b*112|0)>>2];c[a+108>>2]=c[7131644+(b*112|0)>>2];d=0;return d|0}function aag(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=7131536+(b*112|0);e=0;return e|0}function aah(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6092620+(b*112|0)>>2];c[a+104>>2]=c[6092624+(b*112|0)>>2];c[a+108>>2]=c[6092628+(b*112|0)>>2];d=0;return d|0}function aai(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=6092520+(b*112|0);e=0;return e|0}function aaj(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7130292+(b*112|0)>>2];c[a+104>>2]=c[7130296+(b*112|0)>>2];c[a+108>>2]=c[7130300+(b*112|0)>>2];d=0;return d|0}function aak(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=7130192+(b*112|0);e=0;return e|0}function aal(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6091276+(b*112|0)>>2];c[a+104>>2]=c[6091280+(b*112|0)>>2];c[a+108>>2]=c[6091284+(b*112|0)>>2];d=0;return d|0}function aam(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=6091176+(b*112|0);e=0;return e|0}function aan(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7128948+(b*112|0)>>2];c[a+104>>2]=c[7128952+(b*112|0)>>2];c[a+108>>2]=c[7128956+(b*112|0)>>2];d=0;return d|0}function aao(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=7128848+(b*112|0);e=0;return e|0}function aap(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6089932+(b*112|0)>>2];c[a+104>>2]=c[6089936+(b*112|0)>>2];c[a+108>>2]=c[6089940+(b*112|0)>>2];d=0;return d|0}function aaq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=6089832+(b*112|0);e=0;return e|0}function aar(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7127604+(b*112|0)>>2];c[a+104>>2]=c[7127608+(b*112|0)>>2];c[a+108>>2]=c[7127612+(b*112|0)>>2];d=0;return d|0}function aas(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=7127504+(b*112|0);e=0;return e|0}function aat(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6088588+(b*112|0)>>2];c[a+104>>2]=c[6088592+(b*112|0)>>2];c[a+108>>2]=c[6088596+(b*112|0)>>2];d=0;return d|0}function aau(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=6088488+(b*112|0);e=0;return e|0}function aav(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6087244+(b*112|0)>>2];c[a+104>>2]=c[6087248+(b*112|0)>>2];c[a+108>>2]=c[6087252+(b*112|0)>>2];d=0;return d|0}function aaw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=6087144+(b*112|0);e=0;return e|0}function aax(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7138676+(b*112|0)>>2];c[a+104>>2]=c[7138680+(b*112|0)>>2];c[a+108>>2]=c[7138684+(b*112|0)>>2];d=0;return d|0}function aay(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=7138576+(b*112|0);e=0;return e|0}function aaz(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6738332+(b*112|0)>>2];c[a+104>>2]=c[6738336+(b*112|0)>>2];c[a+108>>2]=c[6738340+(b*112|0)>>2];d=0;return d|0}function aaA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=6738232+(b*112|0);e=0;return e|0}function aaB(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5025108+(b*112|0)>>2];c[a+104>>2]=c[5025112+(b*112|0)>>2];c[a+108>>2]=c[5025116+(b*112|0)>>2];d=0;return d|0}function aaC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=5025008+(b*112|0);e=0;return e|0}function aaD(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6723884+(b*112|0)>>2];c[a+104>>2]=c[6723888+(b*112|0)>>2];c[a+108>>2]=c[6723892+(b*112|0)>>2];d=0;return d|0}function aaE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=6723784+(b*112|0);e=0;return e|0}function aaF(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6721868+(b*112|0)>>2];c[a+104>>2]=c[6721872+(b*112|0)>>2];c[a+108>>2]=c[6721876+(b*112|0)>>2];d=0;return d|0}function aaG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=6721768+(b*112|0);e=0;return e|0}function aaH(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5010548+(b*112|0)>>2];c[a+104>>2]=c[5010552+(b*112|0)>>2];c[a+108>>2]=c[5010556+(b*112|0)>>2];d=0;return d|0}function aaI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=5010448+(b*112|0);e=0;return e|0}function aaJ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6719852+(b*112|0)>>2];c[a+104>>2]=c[6719856+(b*112|0)>>2];c[a+108>>2]=c[6719860+(b*112|0)>>2];d=0;return d|0}function aaK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=6719752+(b*112|0);e=0;return e|0}function aaL(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6717836+(b*112|0)>>2];c[a+104>>2]=c[6717840+(b*112|0)>>2];c[a+108>>2]=c[6717844+(b*112|0)>>2];d=0;return d|0}function aaM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=6717736+(b*112|0);e=0;return e|0}function aaN(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5008532+(b*112|0)>>2];c[a+104>>2]=c[5008536+(b*112|0)>>2];c[a+108>>2]=c[5008540+(b*112|0)>>2];d=0;return d|0}function aaO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=5008432+(b*112|0);e=0;return e|0}function aaP(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6715820+(b*112|0)>>2];c[a+104>>2]=c[6715824+(b*112|0)>>2];c[a+108>>2]=c[6715828+(b*112|0)>>2];d=0;return d|0}function aaQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=6715720+(b*112|0);e=0;return e|0}function aaR(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6095980+(b*112|0)>>2];c[a+104>>2]=c[6095984+(b*112|0)>>2];c[a+108>>2]=c[6095988+(b*112|0)>>2];d=0;return d|0}function aaS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=6095880+(b*112|0);e=0;return e|0}function aaT(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5018612+(b*112|0)>>2];c[a+104>>2]=c[5018616+(b*112|0)>>2];c[a+108>>2]=c[5018620+(b*112|0)>>2];d=0;return d|0}function aaU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=5018512+(b*112|0);e=0;return e|0}function aaV(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5014580+(b*112|0)>>2];c[a+104>>2]=c[5014584+(b*112|0)>>2];c[a+108>>2]=c[5014588+(b*112|0)>>2];d=0;return d|0}function aaW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=5014480+(b*112|0);e=0;return e|0}function aaX(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5012564+(b*112|0)>>2];c[a+104>>2]=c[5012568+(b*112|0)>>2];c[a+108>>2]=c[5012572+(b*112|0)>>2];d=0;return d|0}function aaY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=5012464+(b*112|0);e=0;return e|0}function aaZ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7136436+(b*112|0)>>2];c[a+104>>2]=c[7136440+(b*112|0)>>2];c[a+108>>2]=c[7136444+(b*112|0)>>2];d=0;return d|0}function aa_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=7136336+(b*112|0);e=0;return e|0}function aa$(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6736092+(b*112|0)>>2];c[a+104>>2]=c[6736096+(b*112|0)>>2];c[a+108>>2]=c[6736100+(b*112|0)>>2];d=0;return d|0}function aa0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=6735992+(b*112|0);e=0;return e|0}function aa1(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6733852+(b*112|0)>>2];c[a+104>>2]=c[6733856+(b*112|0)>>2];c[a+108>>2]=c[6733860+(b*112|0)>>2];d=0;return d|0}function aa2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=6733752+(b*112|0);e=0;return e|0}function aa3(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5022868+(b*112|0)>>2];c[a+104>>2]=c[5022872+(b*112|0)>>2];c[a+108>>2]=c[5022876+(b*112|0)>>2];d=0;return d|0}function aa4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=5022768+(b*112|0);e=0;return e|0}function aa5(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6731612+(b*112|0)>>2];c[a+104>>2]=c[6731616+(b*112|0)>>2];c[a+108>>2]=c[6731620+(b*112|0)>>2];d=0;return d|0}function aa6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=6731512+(b*112|0);e=0;return e|0}function aa7(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5020628+(b*112|0)>>2];c[a+104>>2]=c[5020632+(b*112|0)>>2];c[a+108>>2]=c[5020636+(b*112|0)>>2];d=0;return d|0}function aa8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=5020528+(b*112|0);e=0;return e|0}function aa9(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6713580+(b*112|0)>>2];c[a+104>>2]=c[6713584+(b*112|0)>>2];c[a+108>>2]=c[6713588+(b*112|0)>>2];d=0;return d|0}function aba(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=6713480+(b*112|0);e=0;return e|0}function abb(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5006292+(b*112|0)>>2];c[a+104>>2]=c[5006296+(b*112|0)>>2];c[a+108>>2]=c[5006300+(b*112|0)>>2];d=0;return d|0}function abc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=5006192+(b*112|0);e=0;return e|0}function abd(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6711340+(b*112|0)>>2];c[a+104>>2]=c[6711344+(b*112|0)>>2];c[a+108>>2]=c[6711348+(b*112|0)>>2];d=0;return d|0}function abe(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=6711240+(b*112|0);e=0;return e|0}function abf(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5004052+(b*112|0)>>2];c[a+104>>2]=c[5004056+(b*112|0)>>2];c[a+108>>2]=c[5004060+(b*112|0)>>2];d=0;return d|0}function abg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=5003952+(b*112|0);e=0;return e|0}function abh(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5001812+(b*112|0)>>2];c[a+104>>2]=c[5001816+(b*112|0)>>2];c[a+108>>2]=c[5001820+(b*112|0)>>2];d=0;return d|0}function abi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=5001712+(b*112|0);e=0;return e|0}function abj(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6706860+(b*112|0)>>2];c[a+104>>2]=c[6706864+(b*112|0)>>2];c[a+108>>2]=c[6706868+(b*112|0)>>2];d=0;return d|0}function abk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=6706760+(b*112|0);e=0;return e|0}function abl(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=1230136+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function abm(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6170108+(b*112|0)>>2];c[a+104>>2]=c[6170112+(b*112|0)>>2];c[a+108>>2]=c[6170116+(b*112|0)>>2];d=0;return d|0}function abn(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=6170008+(b*112|0);e=0;return e|0}function abo(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6085340+(b*112|0)>>2];c[a+104>>2]=c[6085344+(b*112|0)>>2];c[a+108>>2]=c[6085348+(b*112|0)>>2];d=0;return d|0}function abp(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=6085240+(b*112|0);e=0;return e|0}function abq(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6081532+(b*112|0)>>2];c[a+104>>2]=c[6081536+(b*112|0)>>2];c[a+108>>2]=c[6081540+(b*112|0)>>2];d=0;return d|0}function abr(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=6081432+(b*112|0);e=0;return e|0}function abs(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6688604+(b*112|0)>>2];c[a+104>>2]=c[6688608+(b*112|0)>>2];c[a+108>>2]=c[6688612+(b*112|0)>>2];d=0;return d|0}function abt(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=6688504+(b*112|0);e=0;return e|0}function abu(a,b){a=a|0;b=b|0;var d=0,e=0;if(b>>>0>20){d=1;return d|0}if((a|0)==0){d=0;return d|0}e=a;a=4971064+(b<<4)|0;c[e>>2]=c[a>>2];c[e+4>>2]=c[a+4>>2];c[e+8>>2]=c[a+8>>2];c[e+12>>2]=c[a+12>>2];d=0;return d|0}function abv(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6056796+(b*112|0)>>2];c[a+104>>2]=c[6056800+(b*112|0)>>2];c[a+108>>2]=c[6056804+(b*112|0)>>2];d=0;return d|0}function abw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=6056696+(b*112|0);e=0;return e|0}function abx(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6060156+(b*112|0)>>2];c[a+104>>2]=c[6060160+(b*112|0)>>2];c[a+108>>2]=c[6060164+(b*112|0)>>2];d=0;return d|0}function aby(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=6060056+(b*112|0);e=0;return e|0}function abz(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6057916+(b*112|0)>>2];c[a+104>>2]=c[6057920+(b*112|0)>>2];c[a+108>>2]=c[6057924+(b*112|0)>>2];d=0;return d|0}function abA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=6057816+(b*112|0);e=0;return e|0}function abB(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7120636+(b*112|0)>>2];c[a+104>>2]=c[7120640+(b*112|0)>>2];c[a+108>>2]=c[7120644+(b*112|0)>>2];d=0;return d|0}function abC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<22&(d|0)==0)){e=1;return e|0}c[a>>2]=7120536+(b*112|0);e=0;return e|0}function abD(){var a=0;c[3542068]=2;do{if((Wq(0)|0)==0){Wo()|0;if((Wq(1)|0)!=0){a=1;break}a=agT()|0}else{a=1}}while(0);c[2113260]=0;return a|0}function abE(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6685804+(b*112|0)>>2];c[a+104>>2]=c[6685808+(b*112|0)>>2];c[a+108>>2]=c[6685812+(b*112|0)>>2];d=0;return d|0}function abF(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<22&(d|0)==0)){e=1;return e|0}c[a>>2]=6685704+(b*112|0);e=0;return e|0}function abG(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4965916+(b*112|0)>>2];c[a+104>>2]=c[4965920+(b*112|0)>>2];c[a+108>>2]=c[4965924+(b*112|0)>>2];d=0;return d|0}function abH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<22&(d|0)==0)){e=1;return e|0}c[a>>2]=4965816+(b*112|0);e=0;return e|0}function abI(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6680876+(b*112|0)>>2];c[a+104>>2]=c[6680880+(b*112|0)>>2];c[a+108>>2]=c[6680884+(b*112|0)>>2];d=0;return d|0}function abJ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<22&(d|0)==0)){e=1;return e|0}c[a>>2]=6680776+(b*112|0);e=0;return e|0}function abK(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6678412+(b*112|0)>>2];c[a+104>>2]=c[6678416+(b*112|0)>>2];c[a+108>>2]=c[6678420+(b*112|0)>>2];d=0;return d|0}function abL(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<22&(d|0)==0)){e=1;return e|0}c[a>>2]=6678312+(b*112|0);e=0;return e|0}function abM(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4963452+(b*112|0)>>2];c[a+104>>2]=c[4963456+(b*112|0)>>2];c[a+108>>2]=c[4963460+(b*112|0)>>2];d=0;return d|0}function abN(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<22&(d|0)==0)){e=1;return e|0}c[a>>2]=4963352+(b*112|0);e=0;return e|0}function abO(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4960988+(b*112|0)>>2];c[a+104>>2]=c[4960992+(b*112|0)>>2];c[a+108>>2]=c[4960996+(b*112|0)>>2];d=0;return d|0}function abP(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<22&(d|0)==0)){e=1;return e|0}c[a>>2]=4960888+(b*112|0);e=0;return e|0}function abQ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6673372+(b*112|0)>>2];c[a+104>>2]=c[6673376+(b*112|0)>>2];c[a+108>>2]=c[6673380+(b*112|0)>>2];d=0;return d|0}function abR(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<22&(d|0)==0)){e=1;return e|0}c[a>>2]=6673272+(b*112|0);e=0;return e|0}function abS(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6051252+(b*112|0)>>2];c[a+104>>2]=c[6051256+(b*112|0)>>2];c[a+108>>2]=c[6051260+(b*112|0)>>2];d=0;return d|0}function abT(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<22&(d|0)==0)){e=1;return e|0}c[a>>2]=6051152+(b*112|0);e=0;return e|0}function abU(){var b=0;a[7461632]=1;c[3542068]=2;do{if((Wq(0)|0)==0){Wo()|0;if((Wq(1)|0)!=0){b=1;break}b=agT()|0}else{b=1}}while(0);c[2113260]=0;return b|0}function abV(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3374804+(b*112|0)>>2];c[a+104>>2]=c[3374808+(b*112|0)>>2];c[a+108>>2]=c[3374812+(b*112|0)>>2];d=0;return d|0}function abW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<22&(d|0)==0)){e=1;return e|0}c[a>>2]=3374704+(b*112|0);e=0;return e|0}function abX(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4951020+(b*112|0)>>2];c[a+104>>2]=c[4951024+(b*112|0)>>2];c[a+108>>2]=c[4951028+(b*112|0)>>2];d=0;return d|0}function abY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<22&(d|0)==0)){e=1;return e|0}c[a>>2]=4950920+(b*112|0);e=0;return e|0}function abZ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4953484+(b*112|0)>>2];c[a+104>>2]=c[4953488+(b*112|0)>>2];c[a+108>>2]=c[4953492+(b*112|0)>>2];d=0;return d|0}function ab_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<22&(d|0)==0)){e=1;return e|0}c[a>>2]=4953384+(b*112|0);e=0;return e|0}function ab$(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6675836+(b*112|0)>>2];c[a+104>>2]=c[6675840+(b*112|0)>>2];c[a+108>>2]=c[6675844+(b*112|0)>>2];d=0;return d|0}function ab0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=6675736+(b*112|0);e=0;return e|0}function ab1(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6053716+(b*112|0)>>2];c[a+104>>2]=c[6053720+(b*112|0)>>2];c[a+108>>2]=c[6053724+(b*112|0)>>2];d=0;return d|0}function ab2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=6053616+(b*112|0);e=0;return e|0}function ab3(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6046100+(b*112|0)>>2];c[a+104>>2]=c[6046104+(b*112|0)>>2];c[a+108>>2]=c[6046108+(b*112|0)>>2];d=0;return d|0}function ab4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=6046e3+(b*112|0);e=0;return e|0}function ab5(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3372228+(b*112|0)>>2];c[a+104>>2]=c[3372232+(b*112|0)>>2];c[a+108>>2]=c[3372236+(b*112|0)>>2];d=0;return d|0}function ab6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=3372128+(b*112|0);e=0;return e|0}function ab7(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6041060+(b*112|0)>>2];c[a+104>>2]=c[6041064+(b*112|0)>>2];c[a+108>>2]=c[6041068+(b*112|0)>>2];d=0;return d|0}function ab8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=6040960+(b*112|0);e=0;return e|0}function ab9(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>48){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4942956+(b*112|0)>>2];c[a+104>>2]=c[4942960+(b*112|0)>>2];c[a+108>>2]=c[4942964+(b*112|0)>>2];d=0;return d|0}function aca(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<49&(d|0)==0)){e=1;return e|0}c[a>>2]=4942856+(b*112|0);e=0;return e|0}function acb(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6012132+(b*112|0)>>2];c[a+104>>2]=c[6012136+(b*112|0)>>2];c[a+108>>2]=c[6012140+(b*112|0)>>2];d=0;return d|0}function acc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=6012032+(b*112|0);e=0;return e|0}function acd(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3267684+(b*112|0)>>2];c[a+104>>2]=c[3267688+(b*112|0)>>2];c[a+108>>2]=c[3267692+(b*112|0)>>2];d=0;return d|0}function ace(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=3267584+(b*112|0);e=0;return e|0}function acf(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7109188+(b*112|0)>>2];c[a+104>>2]=c[7109192+(b*112|0)>>2];c[a+108>>2]=c[7109196+(b*112|0)>>2];d=0;return d|0}function acg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=7109088+(b*112|0);e=0;return e|0}function ach(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6649588+(b*112|0)>>2];c[a+104>>2]=c[6649592+(b*112|0)>>2];c[a+108>>2]=c[6649596+(b*112|0)>>2];d=0;return d|0}function aci(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=6649488+(b*112|0);e=0;return e|0}function acj(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6645108+(b*112|0)>>2];c[a+104>>2]=c[6645112+(b*112|0)>>2];c[a+108>>2]=c[6645116+(b*112|0)>>2];d=0;return d|0}function ack(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=6645008+(b*112|0);e=0;return e|0}function acl(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6642868+(b*112|0)>>2];c[a+104>>2]=c[6642872+(b*112|0)>>2];c[a+108>>2]=c[6642876+(b*112|0)>>2];d=0;return d|0}function acm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=6642768+(b*112|0);e=0;return e|0}function acn(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6640628+(b*112|0)>>2];c[a+104>>2]=c[6640632+(b*112|0)>>2];c[a+108>>2]=c[6640636+(b*112|0)>>2];d=0;return d|0}function aco(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=6640528+(b*112|0);e=0;return e|0}function acp(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6651828+(b*112|0)>>2];c[a+104>>2]=c[6651832+(b*112|0)>>2];c[a+108>>2]=c[6651836+(b*112|0)>>2];d=0;return d|0}function acq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=6651728+(b*112|0);e=0;return e|0}function acr(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5974724+(b*112|0)>>2];c[a+104>>2]=c[5974728+(b*112|0)>>2];c[a+108>>2]=c[5974732+(b*112|0)>>2];d=0;return d|0}function acs(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=5974624+(b*112|0);e=0;return e|0}function act(){var b=0;a[7460896]=1;c[3542068]=2;if((Wq(0)|0)!=0){b=1;return b|0}Wo()|0;if((Wq(1)|0)!=0){b=1;return b|0}b=agT()|0;return b|0}function acu(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3217164+(b*112|0)>>2];c[a+104>>2]=c[3217168+(b*112|0)>>2];c[a+108>>2]=c[3217172+(b*112|0)>>2];d=0;return d|0}function acv(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=3217064+(b*112|0);e=0;return e|0}function acw(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4867268+(b*112|0)>>2];c[a+104>>2]=c[4867272+(b*112|0)>>2];c[a+108>>2]=c[4867276+(b*112|0)>>2];d=0;return d|0}function acx(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=4867168+(b*112|0);e=0;return e|0}function acy(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1637468+(b*112|0)>>2];c[a+104>>2]=c[1637472+(b*112|0)>>2];c[a+108>>2]=c[1637476+(b*112|0)>>2];d=0;return d|0}function acz(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=1637368+(b*112|0);e=0;return e|0}function acA(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4865028+(b*112|0)>>2];c[a+104>>2]=c[4865032+(b*112|0)>>2];c[a+108>>2]=c[4865036+(b*112|0)>>2];d=0;return d|0}function acB(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=4864928+(b*112|0);e=0;return e|0}function acC(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1635228+(b*112|0)>>2];c[a+104>>2]=c[1635232+(b*112|0)>>2];c[a+108>>2]=c[1635236+(b*112|0)>>2];d=0;return d|0}function acD(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=1635128+(b*112|0);e=0;return e|0}function acE(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4862788+(b*112|0)>>2];c[a+104>>2]=c[4862792+(b*112|0)>>2];c[a+108>>2]=c[4862796+(b*112|0)>>2];d=0;return d|0}function acF(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=4862688+(b*112|0);e=0;return e|0}function acG(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3226124+(b*112|0)>>2];c[a+104>>2]=c[3226128+(b*112|0)>>2];c[a+108>>2]=c[3226132+(b*112|0)>>2];d=0;return d|0}function acH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=3226024+(b*112|0);e=0;return e|0}function acI(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3223884+(b*112|0)>>2];c[a+104>>2]=c[3223888+(b*112|0)>>2];c[a+108>>2]=c[3223892+(b*112|0)>>2];d=0;return d|0}function acJ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=3223784+(b*112|0);e=0;return e|0}function acK(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3221644+(b*112|0)>>2];c[a+104>>2]=c[3221648+(b*112|0)>>2];c[a+108>>2]=c[3221652+(b*112|0)>>2];d=0;return d|0}function acL(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=3221544+(b*112|0);e=0;return e|0}function acM(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3219404+(b*112|0)>>2];c[a+104>>2]=c[3219408+(b*112|0)>>2];c[a+108>>2]=c[3219412+(b*112|0)>>2];d=0;return d|0}function acN(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=3219304+(b*112|0);e=0;return e|0}function acO(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4860548+(b*112|0)>>2];c[a+104>>2]=c[4860552+(b*112|0)>>2];c[a+108>>2]=c[4860556+(b*112|0)>>2];d=0;return d|0}function acP(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=4860448+(b*112|0);e=0;return e|0}function acQ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6610580+(b*112|0)>>2];c[a+104>>2]=c[6610584+(b*112|0)>>2];c[a+108>>2]=c[6610588+(b*112|0)>>2];d=0;return d|0}function acR(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=6610480+(b*112|0);e=0;return e|0}function acS(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4858420+(b*112|0)>>2];c[a+104>>2]=c[4858424+(b*112|0)>>2];c[a+108>>2]=c[4858428+(b*112|0)>>2];d=0;return d|0}function acT(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=4858320+(b*112|0);e=0;return e|0}function acU(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5971988+(b*112|0)>>2];c[a+104>>2]=c[5971992+(b*112|0)>>2];c[a+108>>2]=c[5971996+(b*112|0)>>2];d=0;return d|0}function acV(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=5971888+(b*112|0);e=0;return e|0}function acW(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3214372+(b*112|0)>>2];c[a+104>>2]=c[3214376+(b*112|0)>>2];c[a+108>>2]=c[3214380+(b*112|0)>>2];d=0;return d|0}function acX(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=3214272+(b*112|0);e=0;return e|0}function acY(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3212244+(b*112|0)>>2];c[a+104>>2]=c[3212248+(b*112|0)>>2];c[a+108>>2]=c[3212252+(b*112|0)>>2];d=0;return d|0}function acZ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=3212144+(b*112|0);e=0;return e|0}function ac_(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5969860+(b*112|0)>>2];c[a+104>>2]=c[5969864+(b*112|0)>>2];c[a+108>>2]=c[5969868+(b*112|0)>>2];d=0;return d|0}function ac$(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=5969760+(b*112|0);e=0;return e|0}function ac0(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5967732+(b*112|0)>>2];c[a+104>>2]=c[5967736+(b*112|0)>>2];c[a+108>>2]=c[5967740+(b*112|0)>>2];d=0;return d|0}function ac1(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=5967632+(b*112|0);e=0;return e|0}function ac2(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5965604+(b*112|0)>>2];c[a+104>>2]=c[5965608+(b*112|0)>>2];c[a+108>>2]=c[5965612+(b*112|0)>>2];d=0;return d|0}function ac3(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=5965504+(b*112|0);e=0;return e|0}function ac4(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3210116+(b*112|0)>>2];c[a+104>>2]=c[3210120+(b*112|0)>>2];c[a+108>>2]=c[3210124+(b*112|0)>>2];d=0;return d|0}function ac5(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=3210016+(b*112|0);e=0;return e|0}function ac6(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3207988+(b*112|0)>>2];c[a+104>>2]=c[3207992+(b*112|0)>>2];c[a+108>>2]=c[3207996+(b*112|0)>>2];d=0;return d|0}function ac7(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=3207888+(b*112|0);e=0;return e|0}function ac8(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5963476+(b*112|0)>>2];c[a+104>>2]=c[5963480+(b*112|0)>>2];c[a+108>>2]=c[5963484+(b*112|0)>>2];d=0;return d|0}function ac9(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=5963376+(b*112|0);e=0;return e|0}function ada(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3203732+(b*112|0)>>2];c[a+104>>2]=c[3203736+(b*112|0)>>2];c[a+108>>2]=c[3203740+(b*112|0)>>2];d=0;return d|0}function adb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=3203632+(b*112|0);e=0;return e|0}function adc(b,d){b=b|0;d=d|0;if((b-16777200|0)>>>0<12){a[(c[3542030]|0)+(b&15)|0]=d}a[(c[3541930]|0)+(b-16711680^1)|0]=d;return}function add(a,b){a=a|0;b=b|0;gg[c[(c[2112932]|0)+196660>>2]&4095](a,(b&65535)>>>8&255);gg[c[(c[2112932]|0)+196660>>2]&4095](a+1|0,b&255);return}function ade(b,d){b=b|0;d=d|0;var e=0;e=b-7340032^1;b=c[3541934]|0;a[b+e|0]=d;a[b+(e+32768)|0]=d;return}function adf(a,d){a=a|0;d=d|0;var e=0,f=0;e=c[3541934]|0;f=(a-7340032|0)>>>1;b[e+(f<<1)>>1]=d;b[e+(f+16384<<1)>>1]=d;return}function adg(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5214676+(b*112|0)>>2];c[a+104>>2]=c[5214680+(b*112|0)>>2];c[a+108>>2]=c[5214684+(b*112|0)>>2];d=0;return d|0}function adh(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=5214576+(b*112|0);e=0;return e|0}function adi(){var b=0,d=0,e=0,f=0,g=0,h=0;c[3542068]=2;do{if((Wq(0)|0)==0){Wo()|0;if((Wq(1)|0)!=0){b=1;break}b=agT()|0}else{b=1}}while(0);a[9640]=1;if((c[2394]|0)==0){d=c[2112932]|0}else{c[2394]=0;e=c[3532596]|0;c[2112932]=e;f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];d=e}e=d+65280|0;f=16711680;while(1){c[e+65536>>2]=3;g=f+1024|0;if(g>>>0>16777215){break}else{e=e+4|0;f=g}}c[d+196660>>2]=250;c[d+196740>>2]=1342;c[d+94208>>2]=4;c[d+94212>>2]=4;c[d+94216>>2]=4;c[d+94220>>2]=4;c[d+94224>>2]=4;c[d+94228>>2]=4;c[d+94232>>2]=4;c[d+94236>>2]=4;c[d+196664>>2]=2406;c[d+196744>>2]=474;d=c[3532592]|0;if((d|0)==0){h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return b|0}gGC(d|0,9104152,280)|0;h=c[2113054]|0;c[2113060]=h;c[2394]=-1;return b|0}function adj(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5221620+(b*112|0)>>2];c[a+104>>2]=c[5221624+(b*112|0)>>2];c[a+108>>2]=c[5221628+(b*112|0)>>2];d=0;return d|0}function adk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=5221520+(b*112|0);e=0;return e|0}function adl(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3662092+(b*112|0)>>2];c[a+104>>2]=c[3662096+(b*112|0)>>2];c[a+108>>2]=c[3662100+(b*112|0)>>2];d=0;return d|0}function adm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=3661992+(b*112|0);e=0;return e|0}function adn(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4271228+(b*112|0)>>2];c[a+104>>2]=c[4271232+(b*112|0)>>2];c[a+108>>2]=c[4271236+(b*112|0)>>2];d=0;return d|0}function ado(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=4271128+(b*112|0);e=0;return e|0}function adp(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6974940+(b*112|0)>>2];c[a+104>>2]=c[6974944+(b*112|0)>>2];c[a+108>>2]=c[6974948+(b*112|0)>>2];d=0;return d|0}function adq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=6974840+(b*112|0);e=0;return e|0}function adr(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5581196+(b*112|0)>>2];c[a+104>>2]=c[5581200+(b*112|0)>>2];c[a+108>>2]=c[5581204+(b*112|0)>>2];d=0;return d|0}function ads(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=5581096+(b*112|0);e=0;return e|0}function adt(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>29){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4136700+(b*112|0)>>2];c[a+104>>2]=c[4136704+(b*112|0)>>2];c[a+108>>2]=c[4136708+(b*112|0)>>2];d=0;return d|0}function adu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<30&(d|0)==0)){e=1;return e|0}c[a>>2]=4136600+(b*112|0);e=0;return e|0}function adv(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4117036+(b*112|0)>>2];c[a+104>>2]=c[4117040+(b*112|0)>>2];c[a+108>>2]=c[4117044+(b*112|0)>>2];d=0;return d|0}function adw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=4116936+(b*112|0);e=0;return e|0}function adx(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4119276+(b*112|0)>>2];c[a+104>>2]=c[4119280+(b*112|0)>>2];c[a+108>>2]=c[4119284+(b*112|0)>>2];d=0;return d|0}function ady(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=4119176+(b*112|0);e=0;return e|0}function adz(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5467980+(b*112|0)>>2];c[a+104>>2]=c[5467984+(b*112|0)>>2];c[a+108>>2]=c[5467988+(b*112|0)>>2];d=0;return d|0}function adA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=5467880+(b*112|0);e=0;return e|0}function adB(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>15){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6360516+(b*112|0)>>2];c[a+104>>2]=c[6360520+(b*112|0)>>2];c[a+108>>2]=c[6360524+(b*112|0)>>2];d=0;return d|0}function adC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<16&(d|0)==0)){e=1;return e|0}c[a>>2]=6360416+(b*112|0);e=0;return e|0}function adD(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4064388+(b*112|0)>>2];c[a+104>>2]=c[4064392+(b*112|0)>>2];c[a+108>>2]=c[4064396+(b*112|0)>>2];d=0;return d|0}function adE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=4064288+(b*112|0);e=0;return e|0}function adF(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4035124+(b*112|0)>>2];c[a+104>>2]=c[4035128+(b*112|0)>>2];c[a+108>>2]=c[4035132+(b*112|0)>>2];d=0;return d|0}function adG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=4035024+(b*112|0);e=0;return e|0}function adH(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1946476+(b*112|0)>>2];c[a+104>>2]=c[1946480+(b*112|0)>>2];c[a+108>>2]=c[1946484+(b*112|0)>>2];d=0;return d|0}function adI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=1946376+(b*112|0);e=0;return e|0}function adJ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1887148+(b*112|0)>>2];c[a+104>>2]=c[1887152+(b*112|0)>>2];c[a+108>>2]=c[1887156+(b*112|0)>>2];d=0;return d|0}function adK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=1887048+(b*112|0);e=0;return e|0}function adL(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1242084+(b*112|0)>>2];c[a+104>>2]=c[1242088+(b*112|0)>>2];c[a+108>>2]=c[1242092+(b*112|0)>>2];d=0;return d|0}function adM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=1241984+(b*112|0);e=0;return e|0}function adN(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6876484+(b*112|0)>>2];c[a+104>>2]=c[6876488+(b*112|0)>>2];c[a+108>>2]=c[6876492+(b*112|0)>>2];d=0;return d|0}function adO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=6876384+(b*112|0);e=0;return e|0}function adP(){var b=0,d=0,e=0,f=0,g=0,h=0;a[7461640]=1;c[3542068]=2;do{if((Wq(0)|0)==0){Wo()|0;if((Wq(1)|0)!=0){b=1;break}b=agT()|0}else{b=1}}while(0);a[9640]=1;if((c[2394]|0)==0){d=c[2112932]|0}else{c[2394]=0;e=c[3532596]|0;c[2112932]=e;f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];d=e}e=d+65280|0;f=16711680;while(1){c[e+65536>>2]=3;g=f+1024|0;if(g>>>0>16777215){break}else{e=e+4|0;f=g}}c[d+196660>>2]=250;c[d+196740>>2]=1342;c[d+94208>>2]=4;c[d+94212>>2]=4;c[d+94216>>2]=4;c[d+94220>>2]=4;c[d+94224>>2]=4;c[d+94228>>2]=4;c[d+94232>>2]=4;c[d+94236>>2]=4;c[d+196664>>2]=2406;c[d+196744>>2]=474;d=c[3532592]|0;if((d|0)==0){h=c[2113054]|0;c[2113060]=h;c[2394]=-1;c[2113260]=0;return b|0}gGC(d|0,9104152,280)|0;h=c[2113054]|0;c[2113060]=h;c[2394]=-1;c[2113260]=0;return b|0}function adQ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6273172+(b*112|0)>>2];c[a+104>>2]=c[6273176+(b*112|0)>>2];c[a+108>>2]=c[6273180+(b*112|0)>>2];d=0;return d|0}function adR(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=6273072+(b*112|0);e=0;return e|0}function adS(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>10){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3747620+(b*112|0)>>2];c[a+104>>2]=c[3747624+(b*112|0)>>2];c[a+108>>2]=c[3747628+(b*112|0)>>2];d=0;return d|0}function adT(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<11&(d|0)==0)){e=1;return e|0}c[a>>2]=3747520+(b*112|0);e=0;return e|0}function adU(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>13){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3723452+(b*112|0)>>2];c[a+104>>2]=c[3723456+(b*112|0)>>2];c[a+108>>2]=c[3723460+(b*112|0)>>2];d=0;return d|0}function adV(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<14&(d|0)==0)){e=1;return e|0}c[a>>2]=3723352+(b*112|0);e=0;return e|0}function adW(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6846972+(b*112|0)>>2];c[a+104>>2]=c[6846976+(b*112|0)>>2];c[a+108>>2]=c[6846980+(b*112|0)>>2];d=0;return d|0}function adX(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=6846872+(b*112|0);e=0;return e|0}function adY(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1814204+(b*112|0)>>2];c[a+104>>2]=c[1814208+(b*112|0)>>2];c[a+108>>2]=c[1814212+(b*112|0)>>2];d=0;return d|0}function adZ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=1814104+(b*112|0);e=0;return e|0}function ad_(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6212492+(b*112|0)>>2];c[a+104>>2]=c[6212496+(b*112|0)>>2];c[a+108>>2]=c[6212500+(b*112|0)>>2];d=0;return d|0}function ad$(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=6212392+(b*112|0);e=0;return e|0}function ad0(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5197460+(b*112|0)>>2];c[a+104>>2]=c[5197464+(b*112|0)>>2];c[a+108>>2]=c[5197468+(b*112|0)>>2];d=0;return d|0}function ad1(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=5197360+(b*112|0);e=0;return e|0}function ad2(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1779644+(b*112|0)>>2];c[a+104>>2]=c[1779648+(b*112|0)>>2];c[a+108>>2]=c[1779652+(b*112|0)>>2];d=0;return d|0}function ad3(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=1779544+(b*112|0);e=0;return e|0}function ad4(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>14){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1781324+(b*112|0)>>2];c[a+104>>2]=c[1781328+(b*112|0)>>2];c[a+108>>2]=c[1781332+(b*112|0)>>2];d=0;return d|0}function ad5(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<15&(d|0)==0)){e=1;return e|0}c[a>>2]=1781224+(b*112|0);e=0;return e|0}function ad6(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3558284+(b*112|0)>>2];c[a+104>>2]=c[3558288+(b*112|0)>>2];c[a+108>>2]=c[3558292+(b*112|0)>>2];d=0;return d|0}function ad7(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<22&(d|0)==0)){e=1;return e|0}c[a>>2]=3558184+(b*112|0);e=0;return e|0}function ad8(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[7135092+(b*112|0)>>2];c[a+104>>2]=c[7135096+(b*112|0)>>2];c[a+108>>2]=c[7135100+(b*112|0)>>2];d=0;return d|0}function ad9(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=7134992+(b*112|0);e=0;return e|0}function aea(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>11){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6726236+(b*112|0)>>2];c[a+104>>2]=c[6726240+(b*112|0)>>2];c[a+108>>2]=c[6726244+(b*112|0)>>2];d=0;return d|0}function aeb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<12&(d|0)==0)){e=1;return e|0}c[a>>2]=6726136+(b*112|0);e=0;return e|0}function aec(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6097996+(b*112|0)>>2];c[a+104>>2]=c[6098e3+(b*112|0)>>2];c[a+108>>2]=c[6098004+(b*112|0)>>2];d=0;return d|0}function aed(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=6097896+(b*112|0);e=0;return e|0}function aee(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6093964+(b*112|0)>>2];c[a+104>>2]=c[6093968+(b*112|0)>>2];c[a+108>>2]=c[6093972+(b*112|0)>>2];d=0;return d|0}function aef(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=6093864+(b*112|0);e=0;return e|0}function aeg(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>17){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[5016596+(b*112|0)>>2];c[a+104>>2]=c[5016600+(b*112|0)>>2];c[a+108>>2]=c[5016604+(b*112|0)>>2];d=0;return d|0}function aeh(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<18&(d|0)==0)){e=1;return e|0}c[a>>2]=5016496+(b*112|0);e=0;return e|0}function aei(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6100972+(b*112|0)>>2];c[a+104>>2]=c[6100976+(b*112|0)>>2];c[a+108>>2]=c[6100980+(b*112|0)>>2];d=0;return d|0}function aej(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=6100872+(b*112|0);e=0;return e|0}function aek(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3477092+(b*112|0)>>2];c[a+104>>2]=c[3477096+(b*112|0)>>2];c[a+108>>2]=c[3477100+(b*112|0)>>2];d=0;return d|0}function ael(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=3476992+(b*112|0);e=0;return e|0}function aem(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>16){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6083436+(b*112|0)>>2];c[a+104>>2]=c[6083440+(b*112|0)>>2];c[a+108>>2]=c[6083444+(b*112|0)>>2];d=0;return d|0}function aen(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<17&(d|0)==0)){e=1;return e|0}c[a>>2]=6083336+(b*112|0);e=0;return e|0}function aeo(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6059036+(b*112|0)>>2];c[a+104>>2]=c[6059040+(b*112|0)>>2];c[a+108>>2]=c[6059044+(b*112|0)>>2];d=0;return d|0}function aep(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=6058936+(b*112|0);e=0;return e|0}function aeq(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>9){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4970044+(b*112|0)>>2];c[a+104>>2]=c[4970048+(b*112|0)>>2];c[a+108>>2]=c[4970052+(b*112|0)>>2];d=0;return d|0}function aer(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<10&(d|0)==0)){e=1;return e|0}c[a>>2]=4969944+(b*112|0);e=0;return e|0}function aes(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6683340+(b*112|0)>>2];c[a+104>>2]=c[6683344+(b*112|0)>>2];c[a+108>>2]=c[6683348+(b*112|0)>>2];d=0;return d|0}function aet(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<22&(d|0)==0)){e=1;return e|0}c[a>>2]=6683240+(b*112|0);e=0;return e|0}function aeu(){var b=0,d=0,e=0,f=0,g=0,h=0;c[3542068]=2;do{if((Wq(0)|0)==0){Wo()|0;if((Wq(1)|0)!=0){b=1;break}b=agT()|0}else{b=1}}while(0);a[9640]=1;if((c[2394]|0)==0){d=c[2112932]|0}else{c[2394]=0;e=c[3532596]|0;c[2112932]=e;f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];d=e}e=d+65280|0;f=16711680;while(1){c[e+65536>>2]=3;g=f+1024|0;if(g>>>0>16777215){break}else{e=e+4|0;f=g}}c[d+196660>>2]=250;c[d+196740>>2]=1342;c[d+94208>>2]=4;c[d+94212>>2]=4;c[d+94216>>2]=4;c[d+94220>>2]=4;c[d+94224>>2]=4;c[d+94228>>2]=4;c[d+94232>>2]=4;c[d+94236>>2]=4;c[d+196664>>2]=2406;c[d+196744>>2]=474;d=c[3532592]|0;if((d|0)==0){h=c[2113054]|0;c[2113060]=h;c[2394]=-1;c[2113260]=0;return b|0}gGC(d|0,9104152,280)|0;h=c[2113054]|0;c[2113060]=h;c[2394]=-1;c[2113260]=0;return b|0}function aev(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6043636+(b*112|0)>>2];c[a+104>>2]=c[6043640+(b*112|0)>>2];c[a+108>>2]=c[6043644+(b*112|0)>>2];d=0;return d|0}function aew(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<22&(d|0)==0)){e=1;return e|0}c[a>>2]=6043536+(b*112|0);e=0;return e|0}function aex(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>21){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4955948+(b*112|0)>>2];c[a+104>>2]=c[4955952+(b*112|0)>>2];c[a+108>>2]=c[4955956+(b*112|0)>>2];d=0;return d|0}function aey(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<22&(d|0)==0)){e=1;return e|0}c[a>>2]=4955848+(b*112|0);e=0;return e|0}function aez(){var b=0,d=0,e=0,f=0,g=0,h=0;a[7461632]=1;c[3542068]=2;do{if((Wq(0)|0)==0){Wo()|0;if((Wq(1)|0)!=0){b=1;break}b=agT()|0}else{b=1}}while(0);a[9640]=1;if((c[2394]|0)==0){d=c[2112932]|0}else{c[2394]=0;e=c[3532596]|0;c[2112932]=e;f=c[3532592]|0;if((f|0)!=0){gGC(9104152,f|0,280)|0}c[2113054]=c[2113060];d=e}e=d+65280|0;f=16711680;while(1){c[e+65536>>2]=3;g=f+1024|0;if(g>>>0>16777215){break}else{e=e+4|0;f=g}}c[d+196660>>2]=250;c[d+196740>>2]=1342;c[d+94208>>2]=4;c[d+94212>>2]=4;c[d+94216>>2]=4;c[d+94220>>2]=4;c[d+94224>>2]=4;c[d+94228>>2]=4;c[d+94232>>2]=4;c[d+94236>>2]=4;c[d+196664>>2]=2406;c[d+196744>>2]=474;d=c[3532592]|0;if((d|0)==0){h=c[2113054]|0;c[2113060]=h;c[2394]=-1;c[2113260]=0;return b|0}gGC(d|0,9104152,280)|0;h=c[2113054]|0;c[2113060]=h;c[2394]=-1;c[2113260]=0;return b|0}function aeA(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6048676+(b*112|0)>>2];c[a+104>>2]=c[6048680+(b*112|0)>>2];c[a+108>>2]=c[6048684+(b*112|0)>>2];d=0;return d|0}function aeB(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=6048576+(b*112|0);e=0;return e|0}function aeC(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4958412+(b*112|0)>>2];c[a+104>>2]=c[4958416+(b*112|0)>>2];c[a+108>>2]=c[4958420+(b*112|0)>>2];d=0;return d|0}function aeD(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=4958312+(b*112|0);e=0;return e|0}function aeE(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>22){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4948444+(b*112|0)>>2];c[a+104>>2]=c[4948448+(b*112|0)>>2];c[a+108>>2]=c[4948452+(b*112|0)>>2];d=0;return d|0}function aeF(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<23&(d|0)==0)){e=1;return e|0}c[a>>2]=4948344+(b*112|0);e=0;return e|0}function aeG(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6647348+(b*112|0)>>2];c[a+104>>2]=c[6647352+(b*112|0)>>2];c[a+108>>2]=c[6647356+(b*112|0)>>2];d=0;return d|0}function aeH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=6647248+(b*112|0);e=0;return e|0}function aeI(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[4893796+(b*112|0)>>2];c[a+104>>2]=c[4893800+(b*112|0)>>2];c[a+108>>2]=c[4893804+(b*112|0)>>2];d=0;return d|0}function aeJ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=4893696+(b*112|0);e=0;return e|0}function aeK(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[6007036+(b*112|0)>>2];c[a+104>>2]=c[6007040+(b*112|0)>>2];c[a+108>>2]=c[6007044+(b*112|0)>>2];d=0;return d|0}function aeL(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=6006936+(b*112|0);e=0;return e|0}function aeM(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>19){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1632988+(b*112|0)>>2];c[a+104>>2]=c[1632992+(b*112|0)>>2];c[a+108>>2]=c[1632996+(b*112|0)>>2];d=0;return d|0}function aeN(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<20&(d|0)==0)){e=1;return e|0}c[a>>2]=1632888+(b*112|0);e=0;return e|0}function aeO(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>18){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3205860+(b*112|0)>>2];c[a+104>>2]=c[3205864+(b*112|0)>>2];c[a+108>>2]=c[3205868+(b*112|0)>>2];d=0;return d|0}function aeP(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<19&(d|0)==0)){e=1;return e|0}c[a>>2]=3205760+(b*112|0);e=0;return e|0}function aeQ(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>8){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[1214212+(b*112|0)>>2];c[a+104>>2]=c[1214216+(b*112|0)>>2];c[a+108>>2]=c[1214220+(b*112|0)>>2];d=0;return d|0}function aeR(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<9&(d|0)==0)){e=1;return e|0}c[a>>2]=1214112+(b*112|0);e=0;return e|0}function aeS(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>4){d=1;return d|0}if((a|0)==0){d=0;return d|0}c[a+100>>2]=c[3910468+(b*112|0)>>2];c[a+104>>2]=c[3910472+(b*112|0)>>2];c[a+108>>2]=c[3910476+(b*112|0)>>2];d=0;return d|0}function aeT(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(!(b>>>0<5&(d|0)==0)){e=1;return e|0}c[a>>2]=3910368+(b*112|0);e=0;return e|0}function aeU(){var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;e=i;i=i+480|0;f=e|0;g=e+112|0;h=e+120|0;j=e+232|0;k=e+240|0;l=e+352|0;m=e+360|0;n=e+472|0;c[3542068]=2;a[7462104]=1;c[3541966]=-9;c[3541964]=-9;c[3541962]=-9;c[2113268]=8388608;c[2113250]=1572864;c[2113272]=1572864;c[2113246]=0;c[2113252]=0;c[2113274]=8388608;o=0;while(1){if((o|0)>=1024){p=0;break}q=9638528+(o<<2)|0;if((c[q>>2]|0)==0){r=54853;break}else{o=o+1|0}}do{if((r|0)==54853){o=gGq(131072)|0;c[q>>2]=o;if((o|0)==0){p=0;break}gGz(o|0,0,131072);p=o}}while(0);c[2429512]=p;Wo()|0;p=0;while(1){if((p|0)>=1024){s=1;r=54962;break}t=9638528+(p<<2)|0;if((c[t>>2]|0)==0){break}else{p=p+1|0}}if((r|0)==54962){i=e;return s|0}p=gGq(4194304)|0;c[t>>2]=p;if((p|0)==0){s=1;i=e;return s|0}gGz(p|0,0,4194304);if((c[3542200]|0)==0){s=1;i=e;return s|0}t=m+108|0;c[t>>2]=0;q=m+100|0;c[q>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](m,0)|0;do{if((c[t>>2]|0)!=0){m=c[q>>2]|0;c[n>>2]=9534384;o=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[o&16383](n,0,0)|0;if((m|0)<1){s=1;i=e;return s|0}if((gzL(p,0,0)|0)==0){break}else{s=1}i=e;return s|0}}while(0);n=c[3541922]|0;gGC(n|0,p|0,1572864)|0;n=c[3542034]|0;q=p+2097152|0;gGC(n|0,q|0,1572864)|0;q=0;while(1){if((q|0)>=1024){u=0;break}v=9638528+(q<<2)|0;if((c[v>>2]|0)==(p|0)){r=54866;break}else{q=q+1|0}}if((r|0)==54866){gGr(p);c[v>>2]=0;u=0}while(1){if((u|0)>=1024){s=1;r=54967;break}w=9638528+(u<<2)|0;if((c[w>>2]|0)==0){break}else{u=u+1|0}}if((r|0)==54967){i=e;return s|0}u=gGq(12582912)|0;c[w>>2]=u;if((u|0)==0){s=1;i=e;return s|0}gGz(u|0,0,12582912);if((c[3542200]|0)==0){s=1;i=e;return s|0}w=k+108|0;c[w>>2]=0;v=k+100|0;c[v>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](k,1)|0;do{if((c[w>>2]|0)!=0){k=c[v>>2]|0;c[l>>2]=9534384;p=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[p&16383](l,1,0)|0;if((k|0)<1){s=1;i=e;return s|0}if((gzL(u,0,1)|0)==0){break}else{s=1}i=e;return s|0}}while(0);l=u+4194304|0;if((c[3542200]|0)==0){s=1;i=e;return s|0}v=h+108|0;c[v>>2]=0;w=h+100|0;c[w>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](h,2)|0;do{if((c[v>>2]|0)!=0){h=c[w>>2]|0;c[j>>2]=9534384;k=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[k&16383](j,2,0)|0;if((h|0)<1){s=1;i=e;return s|0}if((gzL(l,0,2)|0)==0){break}else{s=1}i=e;return s|0}}while(0);j=c[3542028]|0;w=c[2113268]|0;gGC(j|0,u|0,w)|0;gGz(u|0,0,12582912);v=u;h=j;k=0;do{b[v+(k<<1)>>1]=b[h+((k>>2&-2|k<<18&1048576|k>>>1&1|k<<21&2097152)<<1)>>1]|0;k=k+1|0;}while((k|0)<4194304);gGC(j|0,u|0,w)|0;gGz(u|0,0,12582912);k=0;do{p=k<<2;b[v+(k<<1)>>1]=b[h+(p<<1)>>1]|0;b[v+(k+1048576<<1)>>1]=b[h+((p|1)<<1)>>1]|0;b[v+(k+2097152<<1)>>1]=b[h+((p|2)<<1)>>1]|0;b[v+(k+3145728<<1)>>1]=b[h+((p|3)<<1)>>1]|0;k=k+1|0;}while((k|0)<1048576);gGz(j|0,0,w|0);w=j+1048576|0;k=j;h=u;while(1){v=k;c[v>>2]=c[9620648+((d[h+1|0]|0)<<2)>>2]<<1|c[9620648+((d[h]|0)<<2)>>2]|c[v>>2];v=k+8|0;if(v>>>0<w>>>0){k=v;h=h+4|0}else{break}}h=j+2097152|0;k=w;v=u+2|0;while(1){p=k;c[p>>2]=c[9620648+((d[v+1|0]|0)<<2)>>2]<<1|c[9620648+((d[v]|0)<<2)>>2]|c[p>>2];p=k+8|0;if(p>>>0<h>>>0){k=p;v=v+4|0}else{break}}v=j+3145728|0;k=h;p=u+524288|0;while(1){q=k;c[q>>2]=c[9620648+((d[p+1|0]|0)<<2)>>2]<<1|c[9620648+((d[p]|0)<<2)>>2]|c[q>>2];q=k+8|0;if(q>>>0<v>>>0){k=q;p=p+4|0}else{break}}p=j+4194304|0;k=v;q=u+524290|0;while(1){n=k;c[n>>2]=c[9620648+((d[q+1|0]|0)<<2)>>2]<<1|c[9620648+((d[q]|0)<<2)>>2]|c[n>>2];n=k+8|0;if(n>>>0<p>>>0){k=n;q=q+4|0}else{break}}q=j+5242880|0;k=p;n=u+1048576|0;while(1){t=k;c[t>>2]=c[9620648+((d[n+1|0]|0)<<2)>>2]<<1|c[9620648+((d[n]|0)<<2)>>2]|c[t>>2];t=k+8|0;if(t>>>0<q>>>0){k=t;n=n+4|0}else{break}}n=j+6291456|0;k=q;t=u+1048578|0;while(1){m=k;c[m>>2]=c[9620648+((d[t+1|0]|0)<<2)>>2]<<1|c[9620648+((d[t]|0)<<2)>>2]|c[m>>2];m=k+8|0;if(m>>>0<n>>>0){k=m;t=t+4|0}else{break}}t=j+7340032|0;k=n;m=u+1572864|0;while(1){o=k;c[o>>2]=c[9620648+((d[m+1|0]|0)<<2)>>2]<<1|c[9620648+((d[m]|0)<<2)>>2]|c[o>>2];o=k+8|0;if(o>>>0<t>>>0){k=o;m=m+4|0}else{break}}m=j+8388608|0;k=t;o=u+1572866|0;while(1){x=k;c[x>>2]=c[9620648+((d[o+1|0]|0)<<2)>>2]<<1|c[9620648+((d[o]|0)<<2)>>2]|c[x>>2];x=k+8|0;if(x>>>0<m>>>0){k=x;o=o+4|0}else{break}}o=j;k=u+2097152|0;while(1){x=o;c[x>>2]=(c[9620648+((d[k+1|0]|0)<<2)>>2]<<1|c[9620648+((d[k]|0)<<2)>>2])<<2|c[x>>2];x=o+8|0;if(x>>>0<w>>>0){o=x;k=k+4|0}else{break}}k=w;w=u+2097154|0;while(1){o=k;c[o>>2]=(c[9620648+((d[w+1|0]|0)<<2)>>2]<<1|c[9620648+((d[w]|0)<<2)>>2])<<2|c[o>>2];o=k+8|0;if(o>>>0<h>>>0){k=o;w=w+4|0}else{break}}w=h;h=u+2621440|0;while(1){k=w;c[k>>2]=(c[9620648+((d[h+1|0]|0)<<2)>>2]<<1|c[9620648+((d[h]|0)<<2)>>2])<<2|c[k>>2];k=w+8|0;if(k>>>0<v>>>0){w=k;h=h+4|0}else{break}}h=v;v=u+2621442|0;while(1){w=h;c[w>>2]=(c[9620648+((d[v+1|0]|0)<<2)>>2]<<1|c[9620648+((d[v]|0)<<2)>>2])<<2|c[w>>2];w=h+8|0;if(w>>>0<p>>>0){h=w;v=v+4|0}else{break}}v=p;p=u+3145728|0;while(1){h=v;c[h>>2]=(c[9620648+((d[p+1|0]|0)<<2)>>2]<<1|c[9620648+((d[p]|0)<<2)>>2])<<2|c[h>>2];h=v+8|0;if(h>>>0<q>>>0){v=h;p=p+4|0}else{break}}p=q;q=u+3145730|0;while(1){v=p;c[v>>2]=(c[9620648+((d[q+1|0]|0)<<2)>>2]<<1|c[9620648+((d[q]|0)<<2)>>2])<<2|c[v>>2];v=p+8|0;if(v>>>0<n>>>0){p=v;q=q+4|0}else{break}}q=n;n=u+3670016|0;while(1){p=q;c[p>>2]=(c[9620648+((d[n+1|0]|0)<<2)>>2]<<1|c[9620648+((d[n]|0)<<2)>>2])<<2|c[p>>2];p=q+8|0;if(p>>>0<t>>>0){q=p;n=n+4|0}else{break}}n=t;t=u+3670018|0;while(1){q=n;c[q>>2]=(c[9620648+((d[t+1|0]|0)<<2)>>2]<<1|c[9620648+((d[t]|0)<<2)>>2])<<2|c[q>>2];q=n+8|0;if(q>>>0<m>>>0){n=q;t=t+4|0}else{break}}t=j+4|0;n=j+1048580|0;m=t;q=l;while(1){l=m;c[l>>2]=c[9620648+((d[q+1|0]|0)<<2)>>2]<<1|c[9620648+((d[q]|0)<<2)>>2]|c[l>>2];l=m+8|0;if(l>>>0<n>>>0){m=l;q=q+4|0}else{break}}q=j+2097156|0;m=n;l=u+4194306|0;while(1){p=m;c[p>>2]=c[9620648+((d[l+1|0]|0)<<2)>>2]<<1|c[9620648+((d[l]|0)<<2)>>2]|c[p>>2];p=m+8|0;if(p>>>0<q>>>0){m=p;l=l+4|0}else{break}}l=j+3145732|0;m=q;p=u+4718592|0;while(1){v=m;c[v>>2]=c[9620648+((d[p+1|0]|0)<<2)>>2]<<1|c[9620648+((d[p]|0)<<2)>>2]|c[v>>2];v=m+8|0;if(v>>>0<l>>>0){m=v;p=p+4|0}else{break}}p=j+4194308|0;m=l;v=u+4718594|0;while(1){h=m;c[h>>2]=c[9620648+((d[v+1|0]|0)<<2)>>2]<<1|c[9620648+((d[v]|0)<<2)>>2]|c[h>>2];h=m+8|0;if(h>>>0<p>>>0){m=h;v=v+4|0}else{break}}v=j+5242884|0;m=p;h=u+5242880|0;while(1){w=m;c[w>>2]=c[9620648+((d[h+1|0]|0)<<2)>>2]<<1|c[9620648+((d[h]|0)<<2)>>2]|c[w>>2];w=m+8|0;if(w>>>0<v>>>0){m=w;h=h+4|0}else{break}}h=j+6291460|0;m=v;w=u+5242882|0;while(1){k=m;c[k>>2]=c[9620648+((d[w+1|0]|0)<<2)>>2]<<1|c[9620648+((d[w]|0)<<2)>>2]|c[k>>2];k=m+8|0;if(k>>>0<h>>>0){m=k;w=w+4|0}else{break}}w=j+7340036|0;m=h;k=u+5767168|0;while(1){o=m;c[o>>2]=c[9620648+((d[k+1|0]|0)<<2)>>2]<<1|c[9620648+((d[k]|0)<<2)>>2]|c[o>>2];o=m+8|0;if(o>>>0<w>>>0){m=o;k=k+4|0}else{break}}k=j+8388612|0;j=w;m=u+5767170|0;while(1){o=j;c[o>>2]=c[9620648+((d[m+1|0]|0)<<2)>>2]<<1|c[9620648+((d[m]|0)<<2)>>2]|c[o>>2];o=j+8|0;if(o>>>0<k>>>0){j=o;m=m+4|0}else{break}}m=t;t=u+6291456|0;while(1){j=m;c[j>>2]=(c[9620648+((d[t+1|0]|0)<<2)>>2]<<1|c[9620648+((d[t]|0)<<2)>>2])<<2|c[j>>2];j=m+8|0;if(j>>>0<n>>>0){m=j;t=t+4|0}else{break}}t=n;n=u+6291458|0;while(1){m=t;c[m>>2]=(c[9620648+((d[n+1|0]|0)<<2)>>2]<<1|c[9620648+((d[n]|0)<<2)>>2])<<2|c[m>>2];m=t+8|0;if(m>>>0<q>>>0){t=m;n=n+4|0}else{break}}n=q;q=u+6815744|0;while(1){t=n;c[t>>2]=(c[9620648+((d[q+1|0]|0)<<2)>>2]<<1|c[9620648+((d[q]|0)<<2)>>2])<<2|c[t>>2];t=n+8|0;if(t>>>0<l>>>0){n=t;q=q+4|0}else{break}}q=l;l=u+6815746|0;while(1){n=q;c[n>>2]=(c[9620648+((d[l+1|0]|0)<<2)>>2]<<1|c[9620648+((d[l]|0)<<2)>>2])<<2|c[n>>2];n=q+8|0;if(n>>>0<p>>>0){q=n;l=l+4|0}else{break}}l=p;p=u+7340032|0;while(1){q=l;c[q>>2]=(c[9620648+((d[p+1|0]|0)<<2)>>2]<<1|c[9620648+((d[p]|0)<<2)>>2])<<2|c[q>>2];q=l+8|0;if(q>>>0<v>>>0){l=q;p=p+4|0}else{break}}p=v;v=u+7340034|0;while(1){l=p;c[l>>2]=(c[9620648+((d[v+1|0]|0)<<2)>>2]<<1|c[9620648+((d[v]|0)<<2)>>2])<<2|c[l>>2];l=p+8|0;if(l>>>0<h>>>0){p=l;v=v+4|0}else{break}}v=h;h=u+7864320|0;while(1){p=v;c[p>>2]=(c[9620648+((d[h+1|0]|0)<<2)>>2]<<1|c[9620648+((d[h]|0)<<2)>>2])<<2|c[p>>2];p=v+8|0;if(p>>>0<w>>>0){v=p;h=h+4|0}else{break}}h=w;w=u+7864322|0;while(1){v=h;c[v>>2]=(c[9620648+((d[w+1|0]|0)<<2)>>2]<<1|c[9620648+((d[w]|0)<<2)>>2])<<2|c[v>>2];v=h+8|0;if(v>>>0<k>>>0){h=v;w=w+4|0}else{y=0;break}}while(1){if((y|0)>=1024){break}z=9638528+(y<<2)|0;if((c[z>>2]|0)==(u|0)){r=54948;break}else{y=y+1|0}}if((r|0)==54948){gGr(u);c[z>>2]=0}z=c[3542044]|0;if((c[3542200]|0)==0){s=1;i=e;return s|0}u=f+108|0;c[u>>2]=0;r=f+100|0;c[r>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](f,3)|0;do{if((c[u>>2]|0)!=0){f=c[r>>2]|0;c[g>>2]=9534384;y=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[y&16383](g,3,0)|0;if((f|0)<1){s=1;i=e;return s|0}if((gzL(z,0,3)|0)==0){break}else{s=1}i=e;return s|0}}while(0);z=agT()|0;if((c[2394]|0)==0){A=c[2112932]|0;B=c[3532592]|0}else{c[2394]=0;g=c[3532596]|0;c[2112932]=g;r=c[3532592]|0;if((r|0)!=0){gGC(9104152,r|0,280)|0}c[2113054]=c[2113060];A=g;B=r}r=c[2429512]|0;c[A+24960>>2]=r;c[A+90496>>2]=r;c[A+156032>>2]=r;g=r+1024|0;c[A+24964>>2]=g;c[A+90500>>2]=g;c[A+156036>>2]=g;g=r+2048|0;c[A+24968>>2]=g;c[A+90504>>2]=g;c[A+156040>>2]=g;g=r+3072|0;c[A+24972>>2]=g;c[A+90508>>2]=g;c[A+156044>>2]=g;g=r+4096|0;c[A+24976>>2]=g;c[A+90512>>2]=g;c[A+156048>>2]=g;g=r+5120|0;c[A+24980>>2]=g;c[A+90516>>2]=g;c[A+156052>>2]=g;g=r+6144|0;c[A+24984>>2]=g;c[A+90520>>2]=g;c[A+156056>>2]=g;g=r+7168|0;c[A+24988>>2]=g;c[A+90524>>2]=g;c[A+156060>>2]=g;if((B|0)!=0){gGC(B|0,9104152,280)|0}c[2113060]=c[2113054];c[2394]=-1;s=z;i=e;return s|0}function aeV(){var b=0,d=0,e=0,f=0;b=c[2429512]|0;d=0;while(1){if((d|0)>=1024){break}e=9638528+(d<<2)|0;if((c[e>>2]|0)==(b|0)){f=54982;break}else{d=d+1|0}}if((f|0)==54982){gGr(b);c[e>>2]=0}c[2429512]=0;a[7461704]=0;a[7461640]=0;a[7461632]=0;a[7460896]=0;c[1865524]=39;a[7462112]=0;c[3541966]=0;c[3541964]=0;c[3541962]=0;a[7461984]=0;a[7461976]=0;a[7461968]=0;Wr();return 0}function aeW(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=i;i=i+16|0;e=d|0;if((a&32|0)==0){f=WF(a,b)|0;i=d;return f|0}gGz(e|0,0,12);c[e>>2]=c[2429512];c[e+4>>2]=131072;c[e+12>>2]=162104;gj[c[2076592]&4095](e)|0;f=WF(a,b)|0;i=d;return f|0}function aeX(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;if((c[3541872]|0)==0){a=1;return a|0}c[2113214]=224;c[3527210]=14;d=16-(c[2113240]&15)|0;c[2406710]=d;f=c[3541656]|0;g=(f|0)==0;h=c[2113242]|0;i=c[2113244]|0;j=-1;k=14166648;while(1){if(g){l=0;m=0}else{n=d+(j<<4)|0;o=n+16|0;p=((n|0)<0?0:n)+i|0;n=((o|0)>224?224:o)+i|0;o=b[f+((p&1023)<<1)>>1]&1023;if((p|0)<(n|0)){q=o;r=0;s=p;while(1){p=(512-q+(e[f+((s&1023)<<1)>>1]|0)&1023)-512|0;if((p|0)>-1){t=(p|0)<(r|0)?r:p;u=q}else{t=r-p|0;u=p+q&1023}p=s+1|0;if((p|0)<(n|0)){q=u;r=t;s=p}else{v=u;w=t;break}}}else{v=o;w=0}l=(w|0)>1024?1024:w;m=v}s=h+m&1023;c[k>>2]=s;c[k+4>>2]=l;c[k+8>>2]=s>>>4;c[k+12>>2]=l+399+s>>4;s=j+1|0;if((s|0)<14){j=s;k=k+56|0}else{break}}aeY();a=0;return a|0}function aeY(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;a=c[3527210]|0;if((a|0)<=-1){return}d=c[3541656]|0;f=(d|0)==0;g=c[2113242]|0;h=c[2113214]|0;i=c[2113244]|0;j=512-g|0;k=(c[2406710]|0)-16|0;l=14166648;m=-1;while(1){if(f){n=(c[l+8>>2]<<4)-g|0;o=n&65535;b[l+16>>1]=o;b[l+18>>1]=o;b[l+20>>1]=o;b[l+22>>1]=o;b[l+24>>1]=o;b[l+26>>1]=o;b[l+28>>1]=o;b[l+30>>1]=o;b[l+32>>1]=o;b[l+34>>1]=o;b[l+36>>1]=o;b[l+38>>1]=o;b[l+40>>1]=o;b[l+42>>1]=o;b[l+44>>1]=o;b[l+46>>1]=o;p=n;q=n;r=k}else{n=l+8|0;o=k;s=0;t=0;u=0;v=l+16|0;while(1){do{if((o|0)>-1&(o|0)<(h|0)){w=(j+(c[n>>2]<<4)-(e[d+((i+o&1023)<<1)>>1]|0)&1023)-512|0;b[v>>1]=w&65535;if((w|0)<(s|0)){x=t;y=w;break}x=(w|0)>(t|0)?w:t;y=s}else{b[v>>1]=0;x=t;y=s}}while(0);w=u+1|0;if((w|0)<16){o=o+1|0;s=y;t=x;u=w;v=v+2|0}else{break}}p=x;q=y;r=k+16|0}c[l+48>>2]=q;c[l+52>>2]=p;v=m+1|0;if((v|0)<(a|0)){k=r;l=l+56|0;m=v}else{break}}return}function aeZ(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;if((c[3541872]|0)==0){a=1;return a|0}d=c[2113214]|0;f=d+15>>4;c[3527210]=f;g=16-(c[2113240]&15)|0;c[2406710]=g;if((f|0)>-1){h=c[3541656]|0;i=(h|0)==0;j=c[2113242]|0;k=c[2113244]|0;l=-1;m=14166648;while(1){if(i){n=0;o=0}else{p=g+(l<<4)|0;q=p+16|0;r=((p|0)<0?0:p)+k|0;p=((q|0)>(d|0)?d:q)+k|0;q=b[h+((r&1023)<<1)>>1]&1023;if((r|0)<(p|0)){s=q;t=0;u=r;while(1){r=(512-s+(e[h+((u&1023)<<1)>>1]|0)&1023)-512|0;if((r|0)>-1){v=(r|0)<(t|0)?t:r;w=s}else{v=t-r|0;w=r+s&1023}r=u+1|0;if((r|0)<(p|0)){s=w;t=v;u=r}else{x=w;y=v;break}}}else{x=q;y=0}n=(y|0)>1024?1024:y;o=x}u=j+o&1023;c[m>>2]=u;c[m+4>>2]=n;c[m+8>>2]=u>>>4;c[m+12>>2]=n+399+u>>4;u=l+1|0;if((u|0)<(f|0)){l=u;m=m+56|0}else{break}}}aeY();a=0;return a|0}function ae_(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[3541654]|0;b=c[2113300]|0;d=c[2113224]|0;e=c[3541652]|0;f=0;g=0;h=c[2112962]|0;i=c[2112960]|0;do{j=c[i>>2]|0;g=j|g;k=j>>>28;do{if((k|0)!=0){if((e&1<<(k^15)|0)==0){break}c[h>>2]=c[a+(k<<2)>>2]}}while(0);k=h+4|0;l=j&15;m=j>>>24&15;do{if((m|0)!=0){if((e&1<<(m^15)|0)==0){break}c[k>>2]=c[a+(m<<2)>>2]}}while(0);m=h+8|0;k=j>>>20&15;do{if((k|0)!=0){if((e&1<<(k^15)|0)==0){break}c[m>>2]=c[a+(k<<2)>>2]}}while(0);k=h+12|0;m=j>>>16&15;do{if((m|0)!=0){if((e&1<<(m^15)|0)==0){break}c[k>>2]=c[a+(m<<2)>>2]}}while(0);m=h+16|0;k=j>>>12&15;do{if((k|0)!=0){if((e&1<<(k^15)|0)==0){break}c[m>>2]=c[a+(k<<2)>>2]}}while(0);k=h+20|0;m=j>>>8&15;do{if((m|0)!=0){if((e&1<<(m^15)|0)==0){break}c[k>>2]=c[a+(m<<2)>>2]}}while(0);m=h+24|0;k=j>>>4&15;do{if((k|0)!=0){if((e&1<<(k^15)|0)==0){break}c[m>>2]=c[a+(k<<2)>>2]}}while(0);k=h+28|0;do{if((l|0)!=0){if((e&1<<(l^15)|0)==0){break}c[k>>2]=c[a+(l<<2)>>2]}}while(0);f=f+1|0;h=h+b|0;i=i+d|0;}while((f|0)<8);c[2112962]=h;c[2112960]=i;return(g|0)==0|0}function ae$(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[3541654]|0;b=c[2113300]|0;d=c[2113224]|0;e=c[3541652]|0;f=0;g=0;h=c[2112962]|0;i=c[2112960]|0;do{j=c[i>>2]|0;g=j|g;k=j&15;do{if((k|0)!=0){if((e&1<<(k^15)|0)==0){break}c[h>>2]=c[a+(k<<2)>>2]}}while(0);k=h+4|0;l=j>>>4&15;do{if((l|0)!=0){if((e&1<<(l^15)|0)==0){break}c[k>>2]=c[a+(l<<2)>>2]}}while(0);l=h+8|0;k=j>>>8&15;do{if((k|0)!=0){if((e&1<<(k^15)|0)==0){break}c[l>>2]=c[a+(k<<2)>>2]}}while(0);k=h+12|0;l=j>>>12&15;do{if((l|0)!=0){if((e&1<<(l^15)|0)==0){break}c[k>>2]=c[a+(l<<2)>>2]}}while(0);l=h+16|0;k=j>>>16&15;do{if((k|0)!=0){if((e&1<<(k^15)|0)==0){break}c[l>>2]=c[a+(k<<2)>>2]}}while(0);k=h+20|0;l=j>>>20&15;do{if((l|0)!=0){if((e&1<<(l^15)|0)==0){break}c[k>>2]=c[a+(l<<2)>>2]}}while(0);l=h+24|0;k=j>>>24&15;do{if((k|0)!=0){if((e&1<<(k^15)|0)==0){break}c[l>>2]=c[a+(k<<2)>>2]}}while(0);k=h+28|0;l=j>>>28;do{if((l|0)!=0){if((e&1<<(l^15)|0)==0){break}c[k>>2]=c[a+(l<<2)>>2]}}while(0);f=f+1|0;h=h+b|0;i=i+d|0;}while((f|0)<8);c[2112962]=h;c[2112960]=i;return(g|0)==0|0}function ae0(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;a=c[3541654]|0;b=c[2113228]|0;d=(b&536887296|0)==0;e=c[3541652]|0;f=(b+32767&536887296|0)==0;g=(b+65534&536887296|0)==0;h=(b+98301&536887296|0)==0;i=(b+131068&536887296|0)==0;j=(b+163835&536887296|0)==0;k=(b+196602&536887296|0)==0;l=(b+229369&536887296|0)==0;b=c[2113300]|0;m=c[2113224]|0;n=1;o=0;p=c[2113226]|0;q=c[2112962]|0;r=c[2112960]|0;while(1){s=p+32767|0;do{if((p&536887296|0)==0){t=c[r>>2]|0;u=t|o;do{if(d){v=t>>>28;if((v|0)==0){break}if((e&1<<(v^15)|0)==0){break}c[q>>2]=c[a+(v<<2)>>2]}}while(0);v=q+4|0;do{if(f){w=t>>>24&15;if((w|0)==0){break}if((e&1<<(w^15)|0)==0){break}c[v>>2]=c[a+(w<<2)>>2]}}while(0);v=q+8|0;do{if(g){w=t>>>20&15;if((w|0)==0){break}if((e&1<<(w^15)|0)==0){break}c[v>>2]=c[a+(w<<2)>>2]}}while(0);v=q+12|0;do{if(h){w=t>>>16&15;if((w|0)==0){break}if((e&1<<(w^15)|0)==0){break}c[v>>2]=c[a+(w<<2)>>2]}}while(0);v=q+16|0;do{if(i){w=t>>>12&15;if((w|0)==0){break}if((e&1<<(w^15)|0)==0){break}c[v>>2]=c[a+(w<<2)>>2]}}while(0);v=q+20|0;do{if(j){w=t>>>8&15;if((w|0)==0){break}if((e&1<<(w^15)|0)==0){break}c[v>>2]=c[a+(w<<2)>>2]}}while(0);v=q+24|0;do{if(k){w=t>>>4&15;if((w|0)==0){break}if((e&1<<(w^15)|0)==0){break}c[v>>2]=c[a+(w<<2)>>2]}}while(0);if(!l){x=u;break}v=t&15;if((v|0)==0){x=u;break}if((e&1<<(v^15)|0)==0){x=u;break}c[q+28>>2]=c[a+(v<<2)>>2];x=u}else{x=o}}while(0);y=q+b|0;z=r+m|0;if((n|0)>=8){break}n=n+1|0;o=x;p=s;q=y;r=z}c[2113226]=s;c[2112962]=y;c[2112960]=z;return(x|0)==0|0}function ae1(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;a=c[3541654]|0;b=c[2113228]|0;d=(b&536887296|0)==0;e=c[3541652]|0;f=(b+32767&536887296|0)==0;g=(b+65534&536887296|0)==0;h=(b+98301&536887296|0)==0;i=(b+131068&536887296|0)==0;j=(b+163835&536887296|0)==0;k=(b+196602&536887296|0)==0;l=(b+229369&536887296|0)==0;b=c[2113300]|0;m=c[2113224]|0;n=1;o=0;p=c[2113226]|0;q=c[2112962]|0;r=c[2112960]|0;while(1){s=p+32767|0;do{if((p&536887296|0)==0){t=c[r>>2]|0;u=t|o;do{if(d){v=t&15;if((v|0)==0){break}if((e&1<<(v^15)|0)==0){break}c[q>>2]=c[a+(v<<2)>>2]}}while(0);v=q+4|0;do{if(f){w=t>>>4&15;if((w|0)==0){break}if((e&1<<(w^15)|0)==0){break}c[v>>2]=c[a+(w<<2)>>2]}}while(0);v=q+8|0;do{if(g){w=t>>>8&15;if((w|0)==0){break}if((e&1<<(w^15)|0)==0){break}c[v>>2]=c[a+(w<<2)>>2]}}while(0);v=q+12|0;do{if(h){w=t>>>12&15;if((w|0)==0){break}if((e&1<<(w^15)|0)==0){break}c[v>>2]=c[a+(w<<2)>>2]}}while(0);v=q+16|0;do{if(i){w=t>>>16&15;if((w|0)==0){break}if((e&1<<(w^15)|0)==0){break}c[v>>2]=c[a+(w<<2)>>2]}}while(0);v=q+20|0;do{if(j){w=t>>>20&15;if((w|0)==0){break}if((e&1<<(w^15)|0)==0){break}c[v>>2]=c[a+(w<<2)>>2]}}while(0);v=q+24|0;do{if(k){w=t>>>24&15;if((w|0)==0){break}if((e&1<<(w^15)|0)==0){break}c[v>>2]=c[a+(w<<2)>>2]}}while(0);if(!l){x=u;break}v=t>>>28;if((v|0)==0){x=u;break}if((e&1<<(v^15)|0)==0){x=u;break}c[q+28>>2]=c[a+(v<<2)>>2];x=u}else{x=o}}while(0);y=q+b|0;z=r+m|0;if((n|0)>=8){break}n=n+1|0;o=x;p=s;q=y;r=z}c[2113226]=s;c[2112962]=y;c[2112960]=z;return(x|0)==0|0}function ae2(){return 0}function ae3(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[3541654]|0;b=c[2113300]|0;d=c[2113224]|0;e=c[3541652]|0;f=0;g=0;h=c[2112960]|0;i=c[2112962]|0;do{j=c[h>>2]|0;k=j|g;l=j>>>28;do{if((l|0)!=0){if((e&1<<(l^15)|0)==0){break}c[i>>2]=c[a+(l<<2)>>2]}}while(0);l=i+4|0;m=j&15;n=j>>>24&15;do{if((n|0)!=0){if((e&1<<(n^15)|0)==0){break}c[l>>2]=c[a+(n<<2)>>2]}}while(0);n=i+8|0;l=j>>>20&15;do{if((l|0)!=0){if((e&1<<(l^15)|0)==0){break}c[n>>2]=c[a+(l<<2)>>2]}}while(0);l=i+12|0;n=j>>>16&15;do{if((n|0)!=0){if((e&1<<(n^15)|0)==0){break}c[l>>2]=c[a+(n<<2)>>2]}}while(0);n=i+16|0;l=j>>>12&15;do{if((l|0)!=0){if((e&1<<(l^15)|0)==0){break}c[n>>2]=c[a+(l<<2)>>2]}}while(0);l=i+20|0;n=j>>>8&15;do{if((n|0)!=0){if((e&1<<(n^15)|0)==0){break}c[l>>2]=c[a+(n<<2)>>2]}}while(0);n=i+24|0;l=j>>>4&15;do{if((l|0)!=0){if((e&1<<(l^15)|0)==0){break}c[n>>2]=c[a+(l<<2)>>2]}}while(0);l=i+28|0;do{if((m|0)!=0){if((e&1<<(m^15)|0)==0){break}c[l>>2]=c[a+(m<<2)>>2]}}while(0);m=i+32|0;l=c[h+4>>2]|0;g=k|l;n=l>>>28;do{if((n|0)!=0){if((e&1<<(n^15)|0)==0){break}c[m>>2]=c[a+(n<<2)>>2]}}while(0);n=i+36|0;m=l&15;k=l>>>24&15;do{if((k|0)!=0){if((e&1<<(k^15)|0)==0){break}c[n>>2]=c[a+(k<<2)>>2]}}while(0);k=i+40|0;n=l>>>20&15;do{if((n|0)!=0){if((e&1<<(n^15)|0)==0){break}c[k>>2]=c[a+(n<<2)>>2]}}while(0);n=i+44|0;k=l>>>16&15;do{if((k|0)!=0){if((e&1<<(k^15)|0)==0){break}c[n>>2]=c[a+(k<<2)>>2]}}while(0);k=i+48|0;n=l>>>12&15;do{if((n|0)!=0){if((e&1<<(n^15)|0)==0){break}c[k>>2]=c[a+(n<<2)>>2]}}while(0);n=i+52|0;k=l>>>8&15;do{if((k|0)!=0){if((e&1<<(k^15)|0)==0){break}c[n>>2]=c[a+(k<<2)>>2]}}while(0);k=i+56|0;n=l>>>4&15;do{if((n|0)!=0){if((e&1<<(n^15)|0)==0){break}c[k>>2]=c[a+(n<<2)>>2]}}while(0);n=i+60|0;do{if((m|0)!=0){if((e&1<<(m^15)|0)==0){break}c[n>>2]=c[a+(m<<2)>>2]}}while(0);f=f+1|0;i=i+b|0;h=h+d|0;}while((f|0)<16);c[2112960]=h;c[2112962]=i;return(g|0)==0|0}function ae4(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[3541654]|0;b=c[2113300]|0;d=c[2113224]|0;e=c[3541652]|0;f=0;g=0;h=c[2112960]|0;i=c[2112962]|0;do{j=c[h+4>>2]|0;k=j|g;l=j&15;do{if((l|0)!=0){if((e&1<<(l^15)|0)==0){break}c[i>>2]=c[a+(l<<2)>>2]}}while(0);l=i+4|0;m=j>>>4&15;do{if((m|0)!=0){if((e&1<<(m^15)|0)==0){break}c[l>>2]=c[a+(m<<2)>>2]}}while(0);m=i+8|0;l=j>>>8&15;do{if((l|0)!=0){if((e&1<<(l^15)|0)==0){break}c[m>>2]=c[a+(l<<2)>>2]}}while(0);l=i+12|0;m=j>>>12&15;do{if((m|0)!=0){if((e&1<<(m^15)|0)==0){break}c[l>>2]=c[a+(m<<2)>>2]}}while(0);m=i+16|0;l=j>>>16&15;do{if((l|0)!=0){if((e&1<<(l^15)|0)==0){break}c[m>>2]=c[a+(l<<2)>>2]}}while(0);l=i+20|0;m=j>>>20&15;do{if((m|0)!=0){if((e&1<<(m^15)|0)==0){break}c[l>>2]=c[a+(m<<2)>>2]}}while(0);m=i+24|0;l=j>>>24&15;do{if((l|0)!=0){if((e&1<<(l^15)|0)==0){break}c[m>>2]=c[a+(l<<2)>>2]}}while(0);l=i+28|0;m=j>>>28;do{if((m|0)!=0){if((e&1<<(m^15)|0)==0){break}c[l>>2]=c[a+(m<<2)>>2]}}while(0);m=i+32|0;l=c[h>>2]|0;g=k|l;j=l&15;do{if((j|0)!=0){if((e&1<<(j^15)|0)==0){break}c[m>>2]=c[a+(j<<2)>>2]}}while(0);j=i+36|0;m=l>>>4&15;do{if((m|0)!=0){if((e&1<<(m^15)|0)==0){break}c[j>>2]=c[a+(m<<2)>>2]}}while(0);m=i+40|0;j=l>>>8&15;do{if((j|0)!=0){if((e&1<<(j^15)|0)==0){break}c[m>>2]=c[a+(j<<2)>>2]}}while(0);j=i+44|0;m=l>>>12&15;do{if((m|0)!=0){if((e&1<<(m^15)|0)==0){break}c[j>>2]=c[a+(m<<2)>>2]}}while(0);m=i+48|0;j=l>>>16&15;do{if((j|0)!=0){if((e&1<<(j^15)|0)==0){break}c[m>>2]=c[a+(j<<2)>>2]}}while(0);j=i+52|0;m=l>>>20&15;do{if((m|0)!=0){if((e&1<<(m^15)|0)==0){break}c[j>>2]=c[a+(m<<2)>>2]}}while(0);m=i+56|0;j=l>>>24&15;do{if((j|0)!=0){if((e&1<<(j^15)|0)==0){break}c[m>>2]=c[a+(j<<2)>>2]}}while(0);j=i+60|0;m=l>>>28;do{if((m|0)!=0){if((e&1<<(m^15)|0)==0){break}c[j>>2]=c[a+(m<<2)>>2]}}while(0);f=f+1|0;i=i+b|0;h=h+d|0;}while((f|0)<16);c[2112960]=h;c[2112962]=i;return(g|0)==0|0}function ae5(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;a=c[3541654]|0;b=c[2113228]|0;d=(b&536887296|0)==0;e=c[3541652]|0;f=(b+32767&536887296|0)==0;g=(b+65534&536887296|0)==0;h=(b+98301&536887296|0)==0;i=(b+131068&536887296|0)==0;j=(b+163835&536887296|0)==0;k=(b+196602&536887296|0)==0;l=(b+229369&536887296|0)==0;m=(b+262136&536887296|0)==0;n=(b+294903&536887296|0)==0;o=(b+327670&536887296|0)==0;p=(b+360437&536887296|0)==0;q=(b+393204&536887296|0)==0;r=(b+425971&536887296|0)==0;s=(b+458738&536887296|0)==0;t=(b+491505&536887296|0)==0;b=c[2113300]|0;u=c[2113224]|0;v=1;w=0;x=c[2113226]|0;y=c[2112962]|0;z=c[2112960]|0;while(1){A=x+32767|0;do{if((x&536887296|0)==0){B=c[z>>2]|0;C=B|w;do{if(d){D=B>>>28;if((D|0)==0){break}if((e&1<<(D^15)|0)==0){break}c[y>>2]=c[a+(D<<2)>>2]}}while(0);D=y+4|0;do{if(f){E=B>>>24&15;if((E|0)==0){break}if((e&1<<(E^15)|0)==0){break}c[D>>2]=c[a+(E<<2)>>2]}}while(0);D=y+8|0;do{if(g){E=B>>>20&15;if((E|0)==0){break}if((e&1<<(E^15)|0)==0){break}c[D>>2]=c[a+(E<<2)>>2]}}while(0);D=y+12|0;do{if(h){E=B>>>16&15;if((E|0)==0){break}if((e&1<<(E^15)|0)==0){break}c[D>>2]=c[a+(E<<2)>>2]}}while(0);D=y+16|0;do{if(i){E=B>>>12&15;if((E|0)==0){break}if((e&1<<(E^15)|0)==0){break}c[D>>2]=c[a+(E<<2)>>2]}}while(0);D=y+20|0;do{if(j){E=B>>>8&15;if((E|0)==0){break}if((e&1<<(E^15)|0)==0){break}c[D>>2]=c[a+(E<<2)>>2]}}while(0);D=y+24|0;do{if(k){E=B>>>4&15;if((E|0)==0){break}if((e&1<<(E^15)|0)==0){break}c[D>>2]=c[a+(E<<2)>>2]}}while(0);D=y+28|0;do{if(l){E=B&15;if((E|0)==0){break}if((e&1<<(E^15)|0)==0){break}c[D>>2]=c[a+(E<<2)>>2]}}while(0);D=y+32|0;B=c[z+4>>2]|0;E=C|B;do{if(m){F=B>>>28;if((F|0)==0){break}if((e&1<<(F^15)|0)==0){break}c[D>>2]=c[a+(F<<2)>>2]}}while(0);D=y+36|0;do{if(n){C=B>>>24&15;if((C|0)==0){break}if((e&1<<(C^15)|0)==0){break}c[D>>2]=c[a+(C<<2)>>2]}}while(0);D=y+40|0;do{if(o){C=B>>>20&15;if((C|0)==0){break}if((e&1<<(C^15)|0)==0){break}c[D>>2]=c[a+(C<<2)>>2]}}while(0);D=y+44|0;do{if(p){C=B>>>16&15;if((C|0)==0){break}if((e&1<<(C^15)|0)==0){break}c[D>>2]=c[a+(C<<2)>>2]}}while(0);D=y+48|0;do{if(q){C=B>>>12&15;if((C|0)==0){break}if((e&1<<(C^15)|0)==0){break}c[D>>2]=c[a+(C<<2)>>2]}}while(0);D=y+52|0;do{if(r){C=B>>>8&15;if((C|0)==0){break}if((e&1<<(C^15)|0)==0){break}c[D>>2]=c[a+(C<<2)>>2]}}while(0);D=y+56|0;do{if(s){C=B>>>4&15;if((C|0)==0){break}if((e&1<<(C^15)|0)==0){break}c[D>>2]=c[a+(C<<2)>>2]}}while(0);if(!t){G=E;break}D=B&15;if((D|0)==0){G=E;break}if((e&1<<(D^15)|0)==0){G=E;break}c[y+60>>2]=c[a+(D<<2)>>2];G=E}else{G=w}}while(0);H=y+b|0;I=z+u|0;if((v|0)>=16){break}v=v+1|0;w=G;x=A;y=H;z=I}c[2113226]=A;c[2112962]=H;c[2112960]=I;return(G|0)==0|0}function ae6(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;a=c[3541654]|0;b=c[2113228]|0;d=(b&536887296|0)==0;e=c[3541652]|0;f=(b+32767&536887296|0)==0;g=(b+65534&536887296|0)==0;h=(b+98301&536887296|0)==0;i=(b+131068&536887296|0)==0;j=(b+163835&536887296|0)==0;k=(b+196602&536887296|0)==0;l=(b+229369&536887296|0)==0;m=(b+262136&536887296|0)==0;n=(b+294903&536887296|0)==0;o=(b+327670&536887296|0)==0;p=(b+360437&536887296|0)==0;q=(b+393204&536887296|0)==0;r=(b+425971&536887296|0)==0;s=(b+458738&536887296|0)==0;t=(b+491505&536887296|0)==0;b=c[2113300]|0;u=c[2113224]|0;v=1;w=0;x=c[2113226]|0;y=c[2112962]|0;z=c[2112960]|0;while(1){A=x+32767|0;do{if((x&536887296|0)==0){B=c[z+4>>2]|0;C=B|w;do{if(d){D=B&15;if((D|0)==0){break}if((e&1<<(D^15)|0)==0){break}c[y>>2]=c[a+(D<<2)>>2]}}while(0);D=y+4|0;do{if(f){E=B>>>4&15;if((E|0)==0){break}if((e&1<<(E^15)|0)==0){break}c[D>>2]=c[a+(E<<2)>>2]}}while(0);D=y+8|0;do{if(g){E=B>>>8&15;if((E|0)==0){break}if((e&1<<(E^15)|0)==0){break}c[D>>2]=c[a+(E<<2)>>2]}}while(0);D=y+12|0;do{if(h){E=B>>>12&15;if((E|0)==0){break}if((e&1<<(E^15)|0)==0){break}c[D>>2]=c[a+(E<<2)>>2]}}while(0);D=y+16|0;do{if(i){E=B>>>16&15;if((E|0)==0){break}if((e&1<<(E^15)|0)==0){break}c[D>>2]=c[a+(E<<2)>>2]}}while(0);D=y+20|0;do{if(j){E=B>>>20&15;if((E|0)==0){break}if((e&1<<(E^15)|0)==0){break}c[D>>2]=c[a+(E<<2)>>2]}}while(0);D=y+24|0;do{if(k){E=B>>>24&15;if((E|0)==0){break}if((e&1<<(E^15)|0)==0){break}c[D>>2]=c[a+(E<<2)>>2]}}while(0);D=y+28|0;do{if(l){E=B>>>28;if((E|0)==0){break}if((e&1<<(E^15)|0)==0){break}c[D>>2]=c[a+(E<<2)>>2]}}while(0);D=y+32|0;B=c[z>>2]|0;E=C|B;do{if(m){F=B&15;if((F|0)==0){break}if((e&1<<(F^15)|0)==0){break}c[D>>2]=c[a+(F<<2)>>2]}}while(0);D=y+36|0;do{if(n){C=B>>>4&15;if((C|0)==0){break}if((e&1<<(C^15)|0)==0){break}c[D>>2]=c[a+(C<<2)>>2]}}while(0);D=y+40|0;do{if(o){C=B>>>8&15;if((C|0)==0){break}if((e&1<<(C^15)|0)==0){break}c[D>>2]=c[a+(C<<2)>>2]}}while(0);D=y+44|0;do{if(p){C=B>>>12&15;if((C|0)==0){break}if((e&1<<(C^15)|0)==0){break}c[D>>2]=c[a+(C<<2)>>2]}}while(0);D=y+48|0;do{if(q){C=B>>>16&15;if((C|0)==0){break}if((e&1<<(C^15)|0)==0){break}c[D>>2]=c[a+(C<<2)>>2]}}while(0);D=y+52|0;do{if(r){C=B>>>20&15;if((C|0)==0){break}if((e&1<<(C^15)|0)==0){break}c[D>>2]=c[a+(C<<2)>>2]}}while(0);D=y+56|0;do{if(s){C=B>>>24&15;if((C|0)==0){break}if((e&1<<(C^15)|0)==0){break}c[D>>2]=c[a+(C<<2)>>2]}}while(0);if(!t){G=E;break}D=B>>>28;if((D|0)==0){G=E;break}if((e&1<<(D^15)|0)==0){G=E;break}c[y+60>>2]=c[a+(D<<2)>>2];G=E}else{G=w}}while(0);H=y+b|0;I=z+u|0;if((v|0)>=16){break}v=v+1|0;w=G;x=A;y=H;z=I}c[2113226]=A;c[2112962]=H;c[2112960]=I;return(G|0)==0|0}function ae7(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[3541654]|0;b=c[2113300]|0;d=c[2113224]|0;e=c[3541652]|0;f=0;g=0;h=c[2112960]|0;i=c[2112962]|0;do{j=c[h>>2]|0;k=j|g;l=j>>>28;do{if((l|0)!=0){if((e&1<<(l^15)|0)==0){break}c[i>>2]=c[a+(l<<2)>>2]}}while(0);l=i+4|0;m=j&15;n=j>>>24&15;do{if((n|0)!=0){if((e&1<<(n^15)|0)==0){break}c[l>>2]=c[a+(n<<2)>>2]}}while(0);n=i+8|0;l=j>>>20&15;do{if((l|0)!=0){if((e&1<<(l^15)|0)==0){break}c[n>>2]=c[a+(l<<2)>>2]}}while(0);l=i+12|0;n=j>>>16&15;do{if((n|0)!=0){if((e&1<<(n^15)|0)==0){break}c[l>>2]=c[a+(n<<2)>>2]}}while(0);n=i+16|0;l=j>>>12&15;do{if((l|0)!=0){if((e&1<<(l^15)|0)==0){break}c[n>>2]=c[a+(l<<2)>>2]}}while(0);l=i+20|0;n=j>>>8&15;do{if((n|0)!=0){if((e&1<<(n^15)|0)==0){break}c[l>>2]=c[a+(n<<2)>>2]}}while(0);n=i+24|0;l=j>>>4&15;do{if((l|0)!=0){if((e&1<<(l^15)|0)==0){break}c[n>>2]=c[a+(l<<2)>>2]}}while(0);l=i+28|0;do{if((m|0)!=0){if((e&1<<(m^15)|0)==0){break}c[l>>2]=c[a+(m<<2)>>2]}}while(0);m=i+32|0;l=c[h+4>>2]|0;n=k|l;j=l>>>28;do{if((j|0)!=0){if((e&1<<(j^15)|0)==0){break}c[m>>2]=c[a+(j<<2)>>2]}}while(0);j=i+36|0;m=l&15;k=l>>>24&15;do{if((k|0)!=0){if((e&1<<(k^15)|0)==0){break}c[j>>2]=c[a+(k<<2)>>2]}}while(0);k=i+40|0;j=l>>>20&15;do{if((j|0)!=0){if((e&1<<(j^15)|0)==0){break}c[k>>2]=c[a+(j<<2)>>2]}}while(0);j=i+44|0;k=l>>>16&15;do{if((k|0)!=0){if((e&1<<(k^15)|0)==0){break}c[j>>2]=c[a+(k<<2)>>2]}}while(0);k=i+48|0;j=l>>>12&15;do{if((j|0)!=0){if((e&1<<(j^15)|0)==0){break}c[k>>2]=c[a+(j<<2)>>2]}}while(0);j=i+52|0;k=l>>>8&15;do{if((k|0)!=0){if((e&1<<(k^15)|0)==0){break}c[j>>2]=c[a+(k<<2)>>2]}}while(0);k=i+56|0;j=l>>>4&15;do{if((j|0)!=0){if((e&1<<(j^15)|0)==0){break}c[k>>2]=c[a+(j<<2)>>2]}}while(0);j=i+60|0;do{if((m|0)!=0){if((e&1<<(m^15)|0)==0){break}c[j>>2]=c[a+(m<<2)>>2]}}while(0);m=i+64|0;j=c[h+8>>2]|0;k=n|j;l=j>>>28;do{if((l|0)!=0){if((e&1<<(l^15)|0)==0){break}c[m>>2]=c[a+(l<<2)>>2]}}while(0);l=i+68|0;m=j&15;n=j>>>24&15;do{if((n|0)!=0){if((e&1<<(n^15)|0)==0){break}c[l>>2]=c[a+(n<<2)>>2]}}while(0);n=i+72|0;l=j>>>20&15;do{if((l|0)!=0){if((e&1<<(l^15)|0)==0){break}c[n>>2]=c[a+(l<<2)>>2]}}while(0);l=i+76|0;n=j>>>16&15;do{if((n|0)!=0){if((e&1<<(n^15)|0)==0){break}c[l>>2]=c[a+(n<<2)>>2]}}while(0);n=i+80|0;l=j>>>12&15;do{if((l|0)!=0){if((e&1<<(l^15)|0)==0){break}c[n>>2]=c[a+(l<<2)>>2]}}while(0);l=i+84|0;n=j>>>8&15;do{if((n|0)!=0){if((e&1<<(n^15)|0)==0){break}c[l>>2]=c[a+(n<<2)>>2]}}while(0);n=i+88|0;l=j>>>4&15;do{if((l|0)!=0){if((e&1<<(l^15)|0)==0){break}c[n>>2]=c[a+(l<<2)>>2]}}while(0);l=i+92|0;do{if((m|0)!=0){if((e&1<<(m^15)|0)==0){break}c[l>>2]=c[a+(m<<2)>>2]}}while(0);m=i+96|0;l=c[h+12>>2]|0;g=k|l;n=l>>>28;do{if((n|0)!=0){if((e&1<<(n^15)|0)==0){break}c[m>>2]=c[a+(n<<2)>>2]}}while(0);n=i+100|0;m=l&15;k=l>>>24&15;do{if((k|0)!=0){if((e&1<<(k^15)|0)==0){break}c[n>>2]=c[a+(k<<2)>>2]}}while(0);k=i+104|0;n=l>>>20&15;do{if((n|0)!=0){if((e&1<<(n^15)|0)==0){break}c[k>>2]=c[a+(n<<2)>>2]}}while(0);n=i+108|0;k=l>>>16&15;do{if((k|0)!=0){if((e&1<<(k^15)|0)==0){break}c[n>>2]=c[a+(k<<2)>>2]}}while(0);k=i+112|0;n=l>>>12&15;do{if((n|0)!=0){if((e&1<<(n^15)|0)==0){break}c[k>>2]=c[a+(n<<2)>>2]}}while(0);n=i+116|0;k=l>>>8&15;do{if((k|0)!=0){if((e&1<<(k^15)|0)==0){break}c[n>>2]=c[a+(k<<2)>>2]}}while(0);k=i+120|0;n=l>>>4&15;do{if((n|0)!=0){if((e&1<<(n^15)|0)==0){break}c[k>>2]=c[a+(n<<2)>>2]}}while(0);n=i+124|0;do{if((m|0)!=0){if((e&1<<(m^15)|0)==0){break}c[n>>2]=c[a+(m<<2)>>2]}}while(0);f=f+1|0;i=i+b|0;h=h+d|0;}while((f|0)<32);c[2112960]=h;c[2112962]=i;return(g|0)==0|0}function ae8(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[3541654]|0;b=c[2113300]|0;d=c[2113224]|0;e=c[3541652]|0;f=0;g=0;h=c[2112960]|0;i=c[2112962]|0;do{j=c[h+12>>2]|0;k=j|g;l=j&15;do{if((l|0)!=0){if((e&1<<(l^15)|0)==0){break}c[i>>2]=c[a+(l<<2)>>2]}}while(0);l=i+4|0;m=j>>>4&15;do{if((m|0)!=0){if((e&1<<(m^15)|0)==0){break}c[l>>2]=c[a+(m<<2)>>2]}}while(0);m=i+8|0;l=j>>>8&15;do{if((l|0)!=0){if((e&1<<(l^15)|0)==0){break}c[m>>2]=c[a+(l<<2)>>2]}}while(0);l=i+12|0;m=j>>>12&15;do{if((m|0)!=0){if((e&1<<(m^15)|0)==0){break}c[l>>2]=c[a+(m<<2)>>2]}}while(0);m=i+16|0;l=j>>>16&15;do{if((l|0)!=0){if((e&1<<(l^15)|0)==0){break}c[m>>2]=c[a+(l<<2)>>2]}}while(0);l=i+20|0;m=j>>>20&15;do{if((m|0)!=0){if((e&1<<(m^15)|0)==0){break}c[l>>2]=c[a+(m<<2)>>2]}}while(0);m=i+24|0;l=j>>>24&15;do{if((l|0)!=0){if((e&1<<(l^15)|0)==0){break}c[m>>2]=c[a+(l<<2)>>2]}}while(0);l=i+28|0;m=j>>>28;do{if((m|0)!=0){if((e&1<<(m^15)|0)==0){break}c[l>>2]=c[a+(m<<2)>>2]}}while(0);m=i+32|0;l=c[h+8>>2]|0;j=k|l;n=l&15;do{if((n|0)!=0){if((e&1<<(n^15)|0)==0){break}c[m>>2]=c[a+(n<<2)>>2]}}while(0);n=i+36|0;m=l>>>4&15;do{if((m|0)!=0){if((e&1<<(m^15)|0)==0){break}c[n>>2]=c[a+(m<<2)>>2]}}while(0);m=i+40|0;n=l>>>8&15;do{if((n|0)!=0){if((e&1<<(n^15)|0)==0){break}c[m>>2]=c[a+(n<<2)>>2]}}while(0);n=i+44|0;m=l>>>12&15;do{if((m|0)!=0){if((e&1<<(m^15)|0)==0){break}c[n>>2]=c[a+(m<<2)>>2]}}while(0);m=i+48|0;n=l>>>16&15;do{if((n|0)!=0){if((e&1<<(n^15)|0)==0){break}c[m>>2]=c[a+(n<<2)>>2]}}while(0);n=i+52|0;m=l>>>20&15;do{if((m|0)!=0){if((e&1<<(m^15)|0)==0){break}c[n>>2]=c[a+(m<<2)>>2]}}while(0);m=i+56|0;n=l>>>24&15;do{if((n|0)!=0){if((e&1<<(n^15)|0)==0){break}c[m>>2]=c[a+(n<<2)>>2]}}while(0);n=i+60|0;m=l>>>28;do{if((m|0)!=0){if((e&1<<(m^15)|0)==0){break}c[n>>2]=c[a+(m<<2)>>2]}}while(0);m=i+64|0;n=c[h+4>>2]|0;l=j|n;k=n&15;do{if((k|0)!=0){if((e&1<<(k^15)|0)==0){break}c[m>>2]=c[a+(k<<2)>>2]}}while(0);k=i+68|0;m=n>>>4&15;do{if((m|0)!=0){if((e&1<<(m^15)|0)==0){break}c[k>>2]=c[a+(m<<2)>>2]}}while(0);m=i+72|0;k=n>>>8&15;do{if((k|0)!=0){if((e&1<<(k^15)|0)==0){break}c[m>>2]=c[a+(k<<2)>>2]}}while(0);k=i+76|0;m=n>>>12&15;do{if((m|0)!=0){if((e&1<<(m^15)|0)==0){break}c[k>>2]=c[a+(m<<2)>>2]}}while(0);m=i+80|0;k=n>>>16&15;do{if((k|0)!=0){if((e&1<<(k^15)|0)==0){break}c[m>>2]=c[a+(k<<2)>>2]}}while(0);k=i+84|0;m=n>>>20&15;do{if((m|0)!=0){if((e&1<<(m^15)|0)==0){break}c[k>>2]=c[a+(m<<2)>>2]}}while(0);m=i+88|0;k=n>>>24&15;do{if((k|0)!=0){if((e&1<<(k^15)|0)==0){break}c[m>>2]=c[a+(k<<2)>>2]}}while(0);k=i+92|0;m=n>>>28;do{if((m|0)!=0){if((e&1<<(m^15)|0)==0){break}c[k>>2]=c[a+(m<<2)>>2]}}while(0);m=i+96|0;k=c[h>>2]|0;g=l|k;n=k&15;do{if((n|0)!=0){if((e&1<<(n^15)|0)==0){break}c[m>>2]=c[a+(n<<2)>>2]}}while(0);n=i+100|0;m=k>>>4&15;do{if((m|0)!=0){if((e&1<<(m^15)|0)==0){break}c[n>>2]=c[a+(m<<2)>>2]}}while(0);m=i+104|0;n=k>>>8&15;do{if((n|0)!=0){if((e&1<<(n^15)|0)==0){break}c[m>>2]=c[a+(n<<2)>>2]}}while(0);n=i+108|0;m=k>>>12&15;do{if((m|0)!=0){if((e&1<<(m^15)|0)==0){break}c[n>>2]=c[a+(m<<2)>>2]}}while(0);m=i+112|0;n=k>>>16&15;do{if((n|0)!=0){if((e&1<<(n^15)|0)==0){break}c[m>>2]=c[a+(n<<2)>>2]}}while(0);n=i+116|0;m=k>>>20&15;do{if((m|0)!=0){if((e&1<<(m^15)|0)==0){break}c[n>>2]=c[a+(m<<2)>>2]}}while(0);m=i+120|0;n=k>>>24&15;do{if((n|0)!=0){if((e&1<<(n^15)|0)==0){break}c[m>>2]=c[a+(n<<2)>>2]}}while(0);n=i+124|0;m=k>>>28;do{if((m|0)!=0){if((e&1<<(m^15)|0)==0){break}c[n>>2]=c[a+(m<<2)>>2]}}while(0);f=f+1|0;i=i+b|0;h=h+d|0;}while((f|0)<32);c[2112960]=h;c[2112962]=i;return(g|0)==0|0}function ae9(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;a=c[3541654]|0;b=c[2113228]|0;d=(b&536887296|0)==0;e=c[3541652]|0;f=(b+32767&536887296|0)==0;g=(b+65534&536887296|0)==0;h=(b+98301&536887296|0)==0;i=(b+131068&536887296|0)==0;j=(b+163835&536887296|0)==0;k=(b+196602&536887296|0)==0;l=(b+229369&536887296|0)==0;m=(b+262136&536887296|0)==0;n=(b+294903&536887296|0)==0;o=(b+327670&536887296|0)==0;p=(b+360437&536887296|0)==0;q=(b+393204&536887296|0)==0;r=(b+425971&536887296|0)==0;s=(b+458738&536887296|0)==0;t=(b+491505&536887296|0)==0;u=(b+524272&536887296|0)==0;v=(b+557039&536887296|0)==0;w=(b+589806&536887296|0)==0;x=(b+622573&536887296|0)==0;y=(b+655340&536887296|0)==0;z=(b+688107&536887296|0)==0;A=(b+720874&536887296|0)==0;B=(b+753641&536887296|0)==0;C=(b+786408&536887296|0)==0;D=(b+819175&536887296|0)==0;E=(b+851942&536887296|0)==0;F=(b+884709&536887296|0)==0;G=(b+917476&536887296|0)==0;H=(b+950243&536887296|0)==0;I=(b+983010&536887296|0)==0;J=(b+1015777&536887296|0)==0;b=c[2113300]|0;K=c[2113224]|0;L=1;M=0;N=c[2113226]|0;O=c[2112962]|0;P=c[2112960]|0;while(1){Q=N+32767|0;do{if((N&536887296|0)==0){R=c[P>>2]|0;S=R|M;do{if(d){T=R>>>28;if((T|0)==0){break}if((e&1<<(T^15)|0)==0){break}c[O>>2]=c[a+(T<<2)>>2]}}while(0);T=O+4|0;do{if(f){U=R>>>24&15;if((U|0)==0){break}if((e&1<<(U^15)|0)==0){break}c[T>>2]=c[a+(U<<2)>>2]}}while(0);T=O+8|0;do{if(g){U=R>>>20&15;if((U|0)==0){break}if((e&1<<(U^15)|0)==0){break}c[T>>2]=c[a+(U<<2)>>2]}}while(0);T=O+12|0;do{if(h){U=R>>>16&15;if((U|0)==0){break}if((e&1<<(U^15)|0)==0){break}c[T>>2]=c[a+(U<<2)>>2]}}while(0);T=O+16|0;do{if(i){U=R>>>12&15;if((U|0)==0){break}if((e&1<<(U^15)|0)==0){break}c[T>>2]=c[a+(U<<2)>>2]}}while(0);T=O+20|0;do{if(j){U=R>>>8&15;if((U|0)==0){break}if((e&1<<(U^15)|0)==0){break}c[T>>2]=c[a+(U<<2)>>2]}}while(0);T=O+24|0;do{if(k){U=R>>>4&15;if((U|0)==0){break}if((e&1<<(U^15)|0)==0){break}c[T>>2]=c[a+(U<<2)>>2]}}while(0);T=O+28|0;do{if(l){U=R&15;if((U|0)==0){break}if((e&1<<(U^15)|0)==0){break}c[T>>2]=c[a+(U<<2)>>2]}}while(0);T=O+32|0;R=c[P+4>>2]|0;U=S|R;do{if(m){V=R>>>28;if((V|0)==0){break}if((e&1<<(V^15)|0)==0){break}c[T>>2]=c[a+(V<<2)>>2]}}while(0);T=O+36|0;do{if(n){S=R>>>24&15;if((S|0)==0){break}if((e&1<<(S^15)|0)==0){break}c[T>>2]=c[a+(S<<2)>>2]}}while(0);T=O+40|0;do{if(o){S=R>>>20&15;if((S|0)==0){break}if((e&1<<(S^15)|0)==0){break}c[T>>2]=c[a+(S<<2)>>2]}}while(0);T=O+44|0;do{if(p){S=R>>>16&15;if((S|0)==0){break}if((e&1<<(S^15)|0)==0){break}c[T>>2]=c[a+(S<<2)>>2]}}while(0);T=O+48|0;do{if(q){S=R>>>12&15;if((S|0)==0){break}if((e&1<<(S^15)|0)==0){break}c[T>>2]=c[a+(S<<2)>>2]}}while(0);T=O+52|0;do{if(r){S=R>>>8&15;if((S|0)==0){break}if((e&1<<(S^15)|0)==0){break}c[T>>2]=c[a+(S<<2)>>2]}}while(0);T=O+56|0;do{if(s){S=R>>>4&15;if((S|0)==0){break}if((e&1<<(S^15)|0)==0){break}c[T>>2]=c[a+(S<<2)>>2]}}while(0);T=O+60|0;do{if(t){S=R&15;if((S|0)==0){break}if((e&1<<(S^15)|0)==0){break}c[T>>2]=c[a+(S<<2)>>2]}}while(0);T=O+64|0;R=c[P+8>>2]|0;S=U|R;do{if(u){V=R>>>28;if((V|0)==0){break}if((e&1<<(V^15)|0)==0){break}c[T>>2]=c[a+(V<<2)>>2]}}while(0);T=O+68|0;do{if(v){U=R>>>24&15;if((U|0)==0){break}if((e&1<<(U^15)|0)==0){break}c[T>>2]=c[a+(U<<2)>>2]}}while(0);T=O+72|0;do{if(w){U=R>>>20&15;if((U|0)==0){break}if((e&1<<(U^15)|0)==0){break}c[T>>2]=c[a+(U<<2)>>2]}}while(0);T=O+76|0;do{if(x){U=R>>>16&15;if((U|0)==0){break}if((e&1<<(U^15)|0)==0){break}c[T>>2]=c[a+(U<<2)>>2]}}while(0);T=O+80|0;do{if(y){U=R>>>12&15;if((U|0)==0){break}if((e&1<<(U^15)|0)==0){break}c[T>>2]=c[a+(U<<2)>>2]}}while(0);T=O+84|0;do{if(z){U=R>>>8&15;if((U|0)==0){break}if((e&1<<(U^15)|0)==0){break}c[T>>2]=c[a+(U<<2)>>2]}}while(0);T=O+88|0;do{if(A){U=R>>>4&15;if((U|0)==0){break}if((e&1<<(U^15)|0)==0){break}c[T>>2]=c[a+(U<<2)>>2]}}while(0);T=O+92|0;do{if(B){U=R&15;if((U|0)==0){break}if((e&1<<(U^15)|0)==0){break}c[T>>2]=c[a+(U<<2)>>2]}}while(0);T=O+96|0;R=c[P+12>>2]|0;U=S|R;do{if(C){V=R>>>28;if((V|0)==0){break}if((e&1<<(V^15)|0)==0){break}c[T>>2]=c[a+(V<<2)>>2]}}while(0);T=O+100|0;do{if(D){S=R>>>24&15;if((S|0)==0){break}if((e&1<<(S^15)|0)==0){break}c[T>>2]=c[a+(S<<2)>>2]}}while(0);T=O+104|0;do{if(E){S=R>>>20&15;if((S|0)==0){break}if((e&1<<(S^15)|0)==0){break}c[T>>2]=c[a+(S<<2)>>2]}}while(0);T=O+108|0;do{if(F){S=R>>>16&15;if((S|0)==0){break}if((e&1<<(S^15)|0)==0){break}c[T>>2]=c[a+(S<<2)>>2]}}while(0);T=O+112|0;do{if(G){S=R>>>12&15;if((S|0)==0){break}if((e&1<<(S^15)|0)==0){break}c[T>>2]=c[a+(S<<2)>>2]}}while(0);T=O+116|0;do{if(H){S=R>>>8&15;if((S|0)==0){break}if((e&1<<(S^15)|0)==0){break}c[T>>2]=c[a+(S<<2)>>2]}}while(0);T=O+120|0;do{if(I){S=R>>>4&15;if((S|0)==0){break}if((e&1<<(S^15)|0)==0){break}c[T>>2]=c[a+(S<<2)>>2]}}while(0);if(!J){W=U;break}T=R&15;if((T|0)==0){W=U;break}if((e&1<<(T^15)|0)==0){W=U;break}c[O+124>>2]=c[a+(T<<2)>>2];W=U}else{W=M}}while(0);X=O+b|0;Y=P+K|0;if((L|0)>=32){break}L=L+1|0;M=W;N=Q;O=X;P=Y}c[2113226]=Q;c[2112962]=X;c[2112960]=Y;return(W|0)==0|0}function afa(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;a=c[3541654]|0;b=c[2113228]|0;d=(b&536887296|0)==0;e=c[3541652]|0;f=(b+32767&536887296|0)==0;g=(b+65534&536887296|0)==0;h=(b+98301&536887296|0)==0;i=(b+131068&536887296|0)==0;j=(b+163835&536887296|0)==0;k=(b+196602&536887296|0)==0;l=(b+229369&536887296|0)==0;m=(b+262136&536887296|0)==0;n=(b+294903&536887296|0)==0;o=(b+327670&536887296|0)==0;p=(b+360437&536887296|0)==0;q=(b+393204&536887296|0)==0;r=(b+425971&536887296|0)==0;s=(b+458738&536887296|0)==0;t=(b+491505&536887296|0)==0;u=(b+524272&536887296|0)==0;v=(b+557039&536887296|0)==0;w=(b+589806&536887296|0)==0;x=(b+622573&536887296|0)==0;y=(b+655340&536887296|0)==0;z=(b+688107&536887296|0)==0;A=(b+720874&536887296|0)==0;B=(b+753641&536887296|0)==0;C=(b+786408&536887296|0)==0;D=(b+819175&536887296|0)==0;E=(b+851942&536887296|0)==0;F=(b+884709&536887296|0)==0;G=(b+917476&536887296|0)==0;H=(b+950243&536887296|0)==0;I=(b+983010&536887296|0)==0;J=(b+1015777&536887296|0)==0;b=c[2113300]|0;K=c[2113224]|0;L=1;M=0;N=c[2113226]|0;O=c[2112962]|0;P=c[2112960]|0;while(1){Q=N+32767|0;do{if((N&536887296|0)==0){R=c[P+12>>2]|0;S=R|M;do{if(d){T=R&15;if((T|0)==0){break}if((e&1<<(T^15)|0)==0){break}c[O>>2]=c[a+(T<<2)>>2]}}while(0);T=O+4|0;do{if(f){U=R>>>4&15;if((U|0)==0){break}if((e&1<<(U^15)|0)==0){break}c[T>>2]=c[a+(U<<2)>>2]}}while(0);T=O+8|0;do{if(g){U=R>>>8&15;if((U|0)==0){break}if((e&1<<(U^15)|0)==0){break}c[T>>2]=c[a+(U<<2)>>2]}}while(0);T=O+12|0;do{if(h){U=R>>>12&15;if((U|0)==0){break}if((e&1<<(U^15)|0)==0){break}c[T>>2]=c[a+(U<<2)>>2]}}while(0);T=O+16|0;do{if(i){U=R>>>16&15;if((U|0)==0){break}if((e&1<<(U^15)|0)==0){break}c[T>>2]=c[a+(U<<2)>>2]}}while(0);T=O+20|0;do{if(j){U=R>>>20&15;if((U|0)==0){break}if((e&1<<(U^15)|0)==0){break}c[T>>2]=c[a+(U<<2)>>2]}}while(0);T=O+24|0;do{if(k){U=R>>>24&15;if((U|0)==0){break}if((e&1<<(U^15)|0)==0){break}c[T>>2]=c[a+(U<<2)>>2]}}while(0);T=O+28|0;do{if(l){U=R>>>28;if((U|0)==0){break}if((e&1<<(U^15)|0)==0){break}c[T>>2]=c[a+(U<<2)>>2]}}while(0);T=O+32|0;R=c[P+8>>2]|0;U=S|R;do{if(m){V=R&15;if((V|0)==0){break}if((e&1<<(V^15)|0)==0){break}c[T>>2]=c[a+(V<<2)>>2]}}while(0);T=O+36|0;do{if(n){S=R>>>4&15;if((S|0)==0){break}if((e&1<<(S^15)|0)==0){break}c[T>>2]=c[a+(S<<2)>>2]}}while(0);T=O+40|0;do{if(o){S=R>>>8&15;if((S|0)==0){break}if((e&1<<(S^15)|0)==0){break}c[T>>2]=c[a+(S<<2)>>2]}}while(0);T=O+44|0;do{if(p){S=R>>>12&15;if((S|0)==0){break}if((e&1<<(S^15)|0)==0){break}c[T>>2]=c[a+(S<<2)>>2]}}while(0);T=O+48|0;do{if(q){S=R>>>16&15;if((S|0)==0){break}if((e&1<<(S^15)|0)==0){break}c[T>>2]=c[a+(S<<2)>>2]}}while(0);T=O+52|0;do{if(r){S=R>>>20&15;if((S|0)==0){break}if((e&1<<(S^15)|0)==0){break}c[T>>2]=c[a+(S<<2)>>2]}}while(0);T=O+56|0;do{if(s){S=R>>>24&15;if((S|0)==0){break}if((e&1<<(S^15)|0)==0){break}c[T>>2]=c[a+(S<<2)>>2]}}while(0);T=O+60|0;do{if(t){S=R>>>28;if((S|0)==0){break}if((e&1<<(S^15)|0)==0){break}c[T>>2]=c[a+(S<<2)>>2]}}while(0);T=O+64|0;R=c[P+4>>2]|0;S=U|R;do{if(u){V=R&15;if((V|0)==0){break}if((e&1<<(V^15)|0)==0){break}c[T>>2]=c[a+(V<<2)>>2]}}while(0);T=O+68|0;do{if(v){U=R>>>4&15;if((U|0)==0){break}if((e&1<<(U^15)|0)==0){break}c[T>>2]=c[a+(U<<2)>>2]}}while(0);T=O+72|0;do{if(w){U=R>>>8&15;if((U|0)==0){break}if((e&1<<(U^15)|0)==0){break}c[T>>2]=c[a+(U<<2)>>2]}}while(0);T=O+76|0;do{if(x){U=R>>>12&15;if((U|0)==0){break}if((e&1<<(U^15)|0)==0){break}c[T>>2]=c[a+(U<<2)>>2]}}while(0);T=O+80|0;do{if(y){U=R>>>16&15;if((U|0)==0){break}if((e&1<<(U^15)|0)==0){break}c[T>>2]=c[a+(U<<2)>>2]}}while(0);T=O+84|0;do{if(z){U=R>>>20&15;if((U|0)==0){break}if((e&1<<(U^15)|0)==0){break}c[T>>2]=c[a+(U<<2)>>2]}}while(0);T=O+88|0;do{if(A){U=R>>>24&15;if((U|0)==0){break}if((e&1<<(U^15)|0)==0){break}c[T>>2]=c[a+(U<<2)>>2]}}while(0);T=O+92|0;do{if(B){U=R>>>28;if((U|0)==0){break}if((e&1<<(U^15)|0)==0){break}c[T>>2]=c[a+(U<<2)>>2]}}while(0);T=O+96|0;R=c[P>>2]|0;U=S|R;do{if(C){V=R&15;if((V|0)==0){break}if((e&1<<(V^15)|0)==0){break}c[T>>2]=c[a+(V<<2)>>2]}}while(0);T=O+100|0;do{if(D){S=R>>>4&15;if((S|0)==0){break}if((e&1<<(S^15)|0)==0){break}c[T>>2]=c[a+(S<<2)>>2]}}while(0);T=O+104|0;do{if(E){S=R>>>8&15;if((S|0)==0){break}if((e&1<<(S^15)|0)==0){break}c[T>>2]=c[a+(S<<2)>>2]}}while(0);T=O+108|0;do{if(F){S=R>>>12&15;if((S|0)==0){break}if((e&1<<(S^15)|0)==0){break}c[T>>2]=c[a+(S<<2)>>2]}}while(0);T=O+112|0;do{if(G){S=R>>>16&15;if((S|0)==0){break}if((e&1<<(S^15)|0)==0){break}c[T>>2]=c[a+(S<<2)>>2]}}while(0);T=O+116|0;do{if(H){S=R>>>20&15;if((S|0)==0){break}if((e&1<<(S^15)|0)==0){break}c[T>>2]=c[a+(S<<2)>>2]}}while(0);T=O+120|0;do{if(I){S=R>>>24&15;if((S|0)==0){break}if((e&1<<(S^15)|0)==0){break}c[T>>2]=c[a+(S<<2)>>2]}}while(0);if(!J){W=U;break}T=R>>>28;if((T|0)==0){W=U;break}if((e&1<<(T^15)|0)==0){W=U;break}c[O+124>>2]=c[a+(T<<2)>>2];W=U}else{W=M}}while(0);X=O+b|0;Y=P+K|0;if((L|0)>=32){break}L=L+1|0;M=W;N=Q;O=X;P=Y}c[2113226]=Q;c[2112962]=X;c[2112960]=Y;return(W|0)==0|0}function afb(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;a=c[3541654]|0;d=b[3726284]|0;f=c[2113300]|0;g=c[2113224]|0;h=0;i=0;j=c[2112962]|0;k=c[2112960]|0;l=c[2112924]|0;do{m=c[k>>2]|0;i=m|i;do{if(m>>>0>268435455){if((e[l>>1]|0)>=(d&65535)){break}c[j>>2]=c[a+(m>>>28<<2)>>2];b[l>>1]=d}}while(0);n=j+4|0;o=l+2|0;do{if(m<<4>>>0>268435455){if((e[o>>1]|0)>=(d&65535)){break}c[n>>2]=c[a+((m>>>24&15)<<2)>>2];b[o>>1]=d}}while(0);o=j+8|0;n=l+4|0;do{if(m<<8>>>0>268435455){if((e[n>>1]|0)>=(d&65535)){break}c[o>>2]=c[a+((m>>>20&15)<<2)>>2];b[n>>1]=d}}while(0);n=j+12|0;o=l+6|0;do{if(m<<12>>>0>268435455){if((e[o>>1]|0)>=(d&65535)){break}c[n>>2]=c[a+((m>>>16&15)<<2)>>2];b[o>>1]=d}}while(0);o=j+16|0;n=l+8|0;do{if(m<<16>>>0>268435455){if((e[n>>1]|0)>=(d&65535)){break}c[o>>2]=c[a+((m>>>12&15)<<2)>>2];b[n>>1]=d}}while(0);n=j+20|0;o=l+10|0;do{if(m<<20>>>0>268435455){if((e[o>>1]|0)>=(d&65535)){break}c[n>>2]=c[a+((m>>>8&15)<<2)>>2];b[o>>1]=d}}while(0);o=j+24|0;n=l+12|0;do{if(m<<24>>>0>268435455){if((e[n>>1]|0)>=(d&65535)){break}c[o>>2]=c[a+((m>>>4&15)<<2)>>2];b[n>>1]=d}}while(0);n=j+28|0;o=l+14|0;p=m&15;do{if((p|0)!=0){if((e[o>>1]|0)>=(d&65535)){break}c[n>>2]=c[a+(p<<2)>>2];b[o>>1]=d}}while(0);h=h+1|0;j=j+f|0;k=k+g|0;l=l+768|0;}while((h|0)<8);c[2112962]=j;c[2112960]=k;c[2112924]=l;return(i|0)==0|0}function afc(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;a=c[3541654]|0;d=c[2113300]|0;f=c[2113224]|0;g=b[3726284]|0;h=0;i=0;j=c[2112962]|0;k=c[2112960]|0;l=c[2112924]|0;do{m=c[k>>2]|0;i=m|i;n=m&15;do{if((n|0)!=0){if((e[l>>1]|0)>=(g&65535)){break}c[j>>2]=c[a+(n<<2)>>2];b[l>>1]=g}}while(0);n=j+4|0;o=l+2|0;p=m>>>4&15;do{if((p|0)!=0){if((e[o>>1]|0)>=(g&65535)){break}c[n>>2]=c[a+(p<<2)>>2];b[o>>1]=g}}while(0);o=j+8|0;p=l+4|0;n=m>>>8&15;do{if((n|0)!=0){if((e[p>>1]|0)>=(g&65535)){break}c[o>>2]=c[a+(n<<2)>>2];b[p>>1]=g}}while(0);p=j+12|0;n=l+6|0;o=m>>>12&15;do{if((o|0)!=0){if((e[n>>1]|0)>=(g&65535)){break}c[p>>2]=c[a+(o<<2)>>2];b[n>>1]=g}}while(0);n=j+16|0;o=l+8|0;p=m>>>16&15;do{if((p|0)!=0){if((e[o>>1]|0)>=(g&65535)){break}c[n>>2]=c[a+(p<<2)>>2];b[o>>1]=g}}while(0);o=j+20|0;p=l+10|0;n=m>>>20&15;do{if((n|0)!=0){if((e[p>>1]|0)>=(g&65535)){break}c[o>>2]=c[a+(n<<2)>>2];b[p>>1]=g}}while(0);p=j+24|0;n=l+12|0;o=m>>>24&15;do{if((o|0)!=0){if((e[n>>1]|0)>=(g&65535)){break}c[p>>2]=c[a+(o<<2)>>2];b[n>>1]=g}}while(0);n=j+28|0;o=l+14|0;p=m>>>28;do{if((p|0)!=0){if((e[o>>1]|0)>=(g&65535)){break}c[n>>2]=c[a+(p<<2)>>2];b[o>>1]=g}}while(0);h=h+1|0;j=j+d|0;k=k+f|0;l=l+768|0;}while((h|0)<8);c[2112962]=j;c[2112960]=k;c[2112924]=l;return(i|0)==0|0}function afd(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;a=c[3541654]|0;d=c[2113228]|0;f=(d&536887296|0)==0;g=b[3726284]|0;h=(d+32767&536887296|0)==0;i=(d+65534&536887296|0)==0;j=(d+98301&536887296|0)==0;k=(d+131068&536887296|0)==0;l=(d+163835&536887296|0)==0;m=(d+196602&536887296|0)==0;n=(d+229369&536887296|0)==0;d=c[2113300]|0;o=c[2113224]|0;p=1;q=0;r=c[2113226]|0;s=c[2112962]|0;t=c[2112924]|0;u=c[2112960]|0;while(1){v=r+32767|0;do{if((r&536887296|0)==0){w=c[u>>2]|0;x=w|q;do{if(f&w>>>0>268435455){if((e[t>>1]|0)>=(g&65535)){break}c[s>>2]=c[a+(w>>>28<<2)>>2];b[t>>1]=g}}while(0);y=s+4|0;z=t+2|0;do{if(h){if(w<<4>>>0<=268435455){break}if((e[z>>1]|0)>=(g&65535)){break}c[y>>2]=c[a+((w>>>24&15)<<2)>>2];b[z>>1]=g}}while(0);z=s+8|0;y=t+4|0;do{if(i){if(w<<8>>>0<=268435455){break}if((e[y>>1]|0)>=(g&65535)){break}c[z>>2]=c[a+((w>>>20&15)<<2)>>2];b[y>>1]=g}}while(0);y=s+12|0;z=t+6|0;do{if(j){if(w<<12>>>0<=268435455){break}if((e[z>>1]|0)>=(g&65535)){break}c[y>>2]=c[a+((w>>>16&15)<<2)>>2];b[z>>1]=g}}while(0);z=s+16|0;y=t+8|0;do{if(k){if(w<<16>>>0<=268435455){break}if((e[y>>1]|0)>=(g&65535)){break}c[z>>2]=c[a+((w>>>12&15)<<2)>>2];b[y>>1]=g}}while(0);y=s+20|0;z=t+10|0;do{if(l){if(w<<20>>>0<=268435455){break}if((e[z>>1]|0)>=(g&65535)){break}c[y>>2]=c[a+((w>>>8&15)<<2)>>2];b[z>>1]=g}}while(0);z=s+24|0;y=t+12|0;do{if(m){if(w<<24>>>0<=268435455){break}if((e[y>>1]|0)>=(g&65535)){break}c[z>>2]=c[a+((w>>>4&15)<<2)>>2];b[y>>1]=g}}while(0);y=t+14|0;if(!n){A=x;break}z=w&15;if((z|0)==0){A=x;break}if((e[y>>1]|0)>=(g&65535)){A=x;break}c[s+28>>2]=c[a+(z<<2)>>2];b[y>>1]=g;A=x}else{A=q}}while(0);B=s+d|0;C=u+o|0;D=t+768|0;if((p|0)>=8){break}p=p+1|0;q=A;r=v;s=B;t=D;u=C}c[2113226]=v;c[2112962]=B;c[2112924]=D;c[2112960]=C;return(A|0)==0|0}function afe(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;a=c[3541654]|0;d=c[2113228]|0;f=(d&536887296|0)==0;g=b[3726284]|0;h=(d+32767&536887296|0)==0;i=(d+65534&536887296|0)==0;j=(d+98301&536887296|0)==0;k=(d+131068&536887296|0)==0;l=(d+163835&536887296|0)==0;m=(d+196602&536887296|0)==0;n=(d+229369&536887296|0)==0;d=c[2113300]|0;o=c[2113224]|0;p=1;q=0;r=c[2113226]|0;s=c[2112962]|0;t=c[2112924]|0;u=c[2112960]|0;while(1){v=r+32767|0;do{if((r&536887296|0)==0){w=c[u>>2]|0;x=w|q;do{if(f){y=w&15;if((y|0)==0){break}if((e[t>>1]|0)>=(g&65535)){break}c[s>>2]=c[a+(y<<2)>>2];b[t>>1]=g}}while(0);y=s+4|0;z=t+2|0;do{if(h){A=w>>>4&15;if((A|0)==0){break}if((e[z>>1]|0)>=(g&65535)){break}c[y>>2]=c[a+(A<<2)>>2];b[z>>1]=g}}while(0);z=s+8|0;y=t+4|0;do{if(i){A=w>>>8&15;if((A|0)==0){break}if((e[y>>1]|0)>=(g&65535)){break}c[z>>2]=c[a+(A<<2)>>2];b[y>>1]=g}}while(0);y=s+12|0;z=t+6|0;do{if(j){A=w>>>12&15;if((A|0)==0){break}if((e[z>>1]|0)>=(g&65535)){break}c[y>>2]=c[a+(A<<2)>>2];b[z>>1]=g}}while(0);z=s+16|0;y=t+8|0;do{if(k){A=w>>>16&15;if((A|0)==0){break}if((e[y>>1]|0)>=(g&65535)){break}c[z>>2]=c[a+(A<<2)>>2];b[y>>1]=g}}while(0);y=s+20|0;z=t+10|0;do{if(l){A=w>>>20&15;if((A|0)==0){break}if((e[z>>1]|0)>=(g&65535)){break}c[y>>2]=c[a+(A<<2)>>2];b[z>>1]=g}}while(0);z=s+24|0;y=t+12|0;do{if(m){A=w>>>24&15;if((A|0)==0){break}if((e[y>>1]|0)>=(g&65535)){break}c[z>>2]=c[a+(A<<2)>>2];b[y>>1]=g}}while(0);y=t+14|0;if(!n){B=x;break}z=w>>>28;if((z|0)==0){B=x;break}if((e[y>>1]|0)>=(g&65535)){B=x;break}c[s+28>>2]=c[a+(z<<2)>>2];b[y>>1]=g;B=x}else{B=q}}while(0);C=s+d|0;D=u+o|0;E=t+768|0;if((p|0)>=8){break}p=p+1|0;q=B;r=v;s=C;t=E;u=D}c[2113226]=v;c[2112962]=C;c[2112924]=E;c[2112960]=D;return(B|0)==0|0}function aff(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;a=c[3541654]|0;d=b[3726284]|0;f=c[2113300]|0;g=c[2113224]|0;h=0;i=0;j=c[2112960]|0;k=c[2112962]|0;l=c[2112924]|0;do{m=c[j>>2]|0;n=m|i;do{if(m>>>0>268435455){if((e[l>>1]|0)>=(d&65535)){break}c[k>>2]=c[a+(m>>>28<<2)>>2];b[l>>1]=d}}while(0);o=k+4|0;p=l+2|0;do{if(m<<4>>>0>268435455){if((e[p>>1]|0)>=(d&65535)){break}c[o>>2]=c[a+((m>>>24&15)<<2)>>2];b[p>>1]=d}}while(0);p=k+8|0;o=l+4|0;do{if(m<<8>>>0>268435455){if((e[o>>1]|0)>=(d&65535)){break}c[p>>2]=c[a+((m>>>20&15)<<2)>>2];b[o>>1]=d}}while(0);o=k+12|0;p=l+6|0;do{if(m<<12>>>0>268435455){if((e[p>>1]|0)>=(d&65535)){break}c[o>>2]=c[a+((m>>>16&15)<<2)>>2];b[p>>1]=d}}while(0);p=k+16|0;o=l+8|0;do{if(m<<16>>>0>268435455){if((e[o>>1]|0)>=(d&65535)){break}c[p>>2]=c[a+((m>>>12&15)<<2)>>2];b[o>>1]=d}}while(0);o=k+20|0;p=l+10|0;do{if(m<<20>>>0>268435455){if((e[p>>1]|0)>=(d&65535)){break}c[o>>2]=c[a+((m>>>8&15)<<2)>>2];b[p>>1]=d}}while(0);p=k+24|0;o=l+12|0;do{if(m<<24>>>0>268435455){if((e[o>>1]|0)>=(d&65535)){break}c[p>>2]=c[a+((m>>>4&15)<<2)>>2];b[o>>1]=d}}while(0);o=k+28|0;p=l+14|0;q=m&15;do{if((q|0)!=0){if((e[p>>1]|0)>=(d&65535)){break}c[o>>2]=c[a+(q<<2)>>2];b[p>>1]=d}}while(0);p=k+32|0;q=l+16|0;o=c[j+4>>2]|0;i=n|o;do{if(o>>>0>268435455){if((e[q>>1]|0)>=(d&65535)){break}c[p>>2]=c[a+(o>>>28<<2)>>2];b[q>>1]=d}}while(0);q=k+36|0;p=l+18|0;do{if(o<<4>>>0>268435455){if((e[p>>1]|0)>=(d&65535)){break}c[q>>2]=c[a+((o>>>24&15)<<2)>>2];b[p>>1]=d}}while(0);p=k+40|0;q=l+20|0;do{if(o<<8>>>0>268435455){if((e[q>>1]|0)>=(d&65535)){break}c[p>>2]=c[a+((o>>>20&15)<<2)>>2];b[q>>1]=d}}while(0);q=k+44|0;p=l+22|0;do{if(o<<12>>>0>268435455){if((e[p>>1]|0)>=(d&65535)){break}c[q>>2]=c[a+((o>>>16&15)<<2)>>2];b[p>>1]=d}}while(0);p=k+48|0;q=l+24|0;do{if(o<<16>>>0>268435455){if((e[q>>1]|0)>=(d&65535)){break}c[p>>2]=c[a+((o>>>12&15)<<2)>>2];b[q>>1]=d}}while(0);q=k+52|0;p=l+26|0;do{if(o<<20>>>0>268435455){if((e[p>>1]|0)>=(d&65535)){break}c[q>>2]=c[a+((o>>>8&15)<<2)>>2];b[p>>1]=d}}while(0);p=k+56|0;q=l+28|0;do{if(o<<24>>>0>268435455){if((e[q>>1]|0)>=(d&65535)){break}c[p>>2]=c[a+((o>>>4&15)<<2)>>2];b[q>>1]=d}}while(0);q=k+60|0;p=l+30|0;n=o&15;do{if((n|0)!=0){if((e[p>>1]|0)>=(d&65535)){break}c[q>>2]=c[a+(n<<2)>>2];b[p>>1]=d}}while(0);h=h+1|0;k=k+f|0;j=j+g|0;l=l+768|0;}while((h|0)<16);c[2112960]=j;c[2112962]=k;c[2112924]=l;return(i|0)==0|0}function afg(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;a=c[3541654]|0;d=c[2113300]|0;f=c[2113224]|0;g=b[3726284]|0;h=0;i=0;j=c[2112960]|0;k=c[2112962]|0;l=c[2112924]|0;do{m=c[j+4>>2]|0;n=m|i;o=m&15;do{if((o|0)!=0){if((e[l>>1]|0)>=(g&65535)){break}c[k>>2]=c[a+(o<<2)>>2];b[l>>1]=g}}while(0);o=k+4|0;p=l+2|0;q=m>>>4&15;do{if((q|0)!=0){if((e[p>>1]|0)>=(g&65535)){break}c[o>>2]=c[a+(q<<2)>>2];b[p>>1]=g}}while(0);p=k+8|0;q=l+4|0;o=m>>>8&15;do{if((o|0)!=0){if((e[q>>1]|0)>=(g&65535)){break}c[p>>2]=c[a+(o<<2)>>2];b[q>>1]=g}}while(0);q=k+12|0;o=l+6|0;p=m>>>12&15;do{if((p|0)!=0){if((e[o>>1]|0)>=(g&65535)){break}c[q>>2]=c[a+(p<<2)>>2];b[o>>1]=g}}while(0);o=k+16|0;p=l+8|0;q=m>>>16&15;do{if((q|0)!=0){if((e[p>>1]|0)>=(g&65535)){break}c[o>>2]=c[a+(q<<2)>>2];b[p>>1]=g}}while(0);p=k+20|0;q=l+10|0;o=m>>>20&15;do{if((o|0)!=0){if((e[q>>1]|0)>=(g&65535)){break}c[p>>2]=c[a+(o<<2)>>2];b[q>>1]=g}}while(0);q=k+24|0;o=l+12|0;p=m>>>24&15;do{if((p|0)!=0){if((e[o>>1]|0)>=(g&65535)){break}c[q>>2]=c[a+(p<<2)>>2];b[o>>1]=g}}while(0);o=k+28|0;p=l+14|0;q=m>>>28;do{if((q|0)!=0){if((e[p>>1]|0)>=(g&65535)){break}c[o>>2]=c[a+(q<<2)>>2];b[p>>1]=g}}while(0);p=k+32|0;q=l+16|0;o=c[j>>2]|0;i=n|o;m=o&15;do{if((m|0)!=0){if((e[q>>1]|0)>=(g&65535)){break}c[p>>2]=c[a+(m<<2)>>2];b[q>>1]=g}}while(0);q=k+36|0;m=l+18|0;p=o>>>4&15;do{if((p|0)!=0){if((e[m>>1]|0)>=(g&65535)){break}c[q>>2]=c[a+(p<<2)>>2];b[m>>1]=g}}while(0);m=k+40|0;p=l+20|0;q=o>>>8&15;do{if((q|0)!=0){if((e[p>>1]|0)>=(g&65535)){break}c[m>>2]=c[a+(q<<2)>>2];b[p>>1]=g}}while(0);p=k+44|0;q=l+22|0;m=o>>>12&15;do{if((m|0)!=0){if((e[q>>1]|0)>=(g&65535)){break}c[p>>2]=c[a+(m<<2)>>2];b[q>>1]=g}}while(0);q=k+48|0;m=l+24|0;p=o>>>16&15;do{if((p|0)!=0){if((e[m>>1]|0)>=(g&65535)){break}c[q>>2]=c[a+(p<<2)>>2];b[m>>1]=g}}while(0);m=k+52|0;p=l+26|0;q=o>>>20&15;do{if((q|0)!=0){if((e[p>>1]|0)>=(g&65535)){break}c[m>>2]=c[a+(q<<2)>>2];b[p>>1]=g}}while(0);p=k+56|0;q=l+28|0;m=o>>>24&15;do{if((m|0)!=0){if((e[q>>1]|0)>=(g&65535)){break}c[p>>2]=c[a+(m<<2)>>2];b[q>>1]=g}}while(0);q=k+60|0;m=l+30|0;p=o>>>28;do{if((p|0)!=0){if((e[m>>1]|0)>=(g&65535)){break}c[q>>2]=c[a+(p<<2)>>2];b[m>>1]=g}}while(0);h=h+1|0;k=k+d|0;j=j+f|0;l=l+768|0;}while((h|0)<16);c[2112960]=j;c[2112962]=k;c[2112924]=l;return(i|0)==0|0}function afh(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;a=c[3541654]|0;d=c[2113228]|0;f=(d&536887296|0)==0;g=b[3726284]|0;h=(d+32767&536887296|0)==0;i=(d+65534&536887296|0)==0;j=(d+98301&536887296|0)==0;k=(d+131068&536887296|0)==0;l=(d+163835&536887296|0)==0;m=(d+196602&536887296|0)==0;n=(d+229369&536887296|0)==0;o=(d+262136&536887296|0)==0;p=(d+294903&536887296|0)==0;q=(d+327670&536887296|0)==0;r=(d+360437&536887296|0)==0;s=(d+393204&536887296|0)==0;t=(d+425971&536887296|0)==0;u=(d+458738&536887296|0)==0;v=(d+491505&536887296|0)==0;d=c[2113300]|0;w=c[2113224]|0;x=1;y=0;z=c[2113226]|0;A=c[2112962]|0;B=c[2112924]|0;C=c[2112960]|0;while(1){D=z+32767|0;do{if((z&536887296|0)==0){E=c[C>>2]|0;F=E|y;do{if(f&E>>>0>268435455){if((e[B>>1]|0)>=(g&65535)){break}c[A>>2]=c[a+(E>>>28<<2)>>2];b[B>>1]=g}}while(0);G=A+4|0;H=B+2|0;do{if(h){if(E<<4>>>0<=268435455){break}if((e[H>>1]|0)>=(g&65535)){break}c[G>>2]=c[a+((E>>>24&15)<<2)>>2];b[H>>1]=g}}while(0);H=A+8|0;G=B+4|0;do{if(i){if(E<<8>>>0<=268435455){break}if((e[G>>1]|0)>=(g&65535)){break}c[H>>2]=c[a+((E>>>20&15)<<2)>>2];b[G>>1]=g}}while(0);G=A+12|0;H=B+6|0;do{if(j){if(E<<12>>>0<=268435455){break}if((e[H>>1]|0)>=(g&65535)){break}c[G>>2]=c[a+((E>>>16&15)<<2)>>2];b[H>>1]=g}}while(0);H=A+16|0;G=B+8|0;do{if(k){if(E<<16>>>0<=268435455){break}if((e[G>>1]|0)>=(g&65535)){break}c[H>>2]=c[a+((E>>>12&15)<<2)>>2];b[G>>1]=g}}while(0);G=A+20|0;H=B+10|0;do{if(l){if(E<<20>>>0<=268435455){break}if((e[H>>1]|0)>=(g&65535)){break}c[G>>2]=c[a+((E>>>8&15)<<2)>>2];b[H>>1]=g}}while(0);H=A+24|0;G=B+12|0;do{if(m){if(E<<24>>>0<=268435455){break}if((e[G>>1]|0)>=(g&65535)){break}c[H>>2]=c[a+((E>>>4&15)<<2)>>2];b[G>>1]=g}}while(0);G=A+28|0;H=B+14|0;do{if(n){I=E&15;if((I|0)==0){break}if((e[H>>1]|0)>=(g&65535)){break}c[G>>2]=c[a+(I<<2)>>2];b[H>>1]=g}}while(0);H=A+32|0;G=B+16|0;E=c[C+4>>2]|0;I=F|E;do{if(o&E>>>0>268435455){if((e[G>>1]|0)>=(g&65535)){break}c[H>>2]=c[a+(E>>>28<<2)>>2];b[G>>1]=g}}while(0);G=A+36|0;H=B+18|0;do{if(p){if(E<<4>>>0<=268435455){break}if((e[H>>1]|0)>=(g&65535)){break}c[G>>2]=c[a+((E>>>24&15)<<2)>>2];b[H>>1]=g}}while(0);H=A+40|0;G=B+20|0;do{if(q){if(E<<8>>>0<=268435455){break}if((e[G>>1]|0)>=(g&65535)){break}c[H>>2]=c[a+((E>>>20&15)<<2)>>2];b[G>>1]=g}}while(0);G=A+44|0;H=B+22|0;do{if(r){if(E<<12>>>0<=268435455){break}if((e[H>>1]|0)>=(g&65535)){break}c[G>>2]=c[a+((E>>>16&15)<<2)>>2];b[H>>1]=g}}while(0);H=A+48|0;G=B+24|0;do{if(s){if(E<<16>>>0<=268435455){break}if((e[G>>1]|0)>=(g&65535)){break}c[H>>2]=c[a+((E>>>12&15)<<2)>>2];b[G>>1]=g}}while(0);G=A+52|0;H=B+26|0;do{if(t){if(E<<20>>>0<=268435455){break}if((e[H>>1]|0)>=(g&65535)){break}c[G>>2]=c[a+((E>>>8&15)<<2)>>2];b[H>>1]=g}}while(0);H=A+56|0;G=B+28|0;do{if(u){if(E<<24>>>0<=268435455){break}if((e[G>>1]|0)>=(g&65535)){break}c[H>>2]=c[a+((E>>>4&15)<<2)>>2];b[G>>1]=g}}while(0);G=B+30|0;if(!v){J=I;break}H=E&15;if((H|0)==0){J=I;break}if((e[G>>1]|0)>=(g&65535)){J=I;break}c[A+60>>2]=c[a+(H<<2)>>2];b[G>>1]=g;J=I}else{J=y}}while(0);K=A+d|0;L=C+w|0;M=B+768|0;if((x|0)>=16){break}x=x+1|0;y=J;z=D;A=K;B=M;C=L}c[2113226]=D;c[2112962]=K;c[2112924]=M;c[2112960]=L;return(J|0)==0|0}function afi(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;a=c[3541654]|0;d=c[2113228]|0;f=(d&536887296|0)==0;g=b[3726284]|0;h=(d+32767&536887296|0)==0;i=(d+65534&536887296|0)==0;j=(d+98301&536887296|0)==0;k=(d+131068&536887296|0)==0;l=(d+163835&536887296|0)==0;m=(d+196602&536887296|0)==0;n=(d+229369&536887296|0)==0;o=(d+262136&536887296|0)==0;p=(d+294903&536887296|0)==0;q=(d+327670&536887296|0)==0;r=(d+360437&536887296|0)==0;s=(d+393204&536887296|0)==0;t=(d+425971&536887296|0)==0;u=(d+458738&536887296|0)==0;v=(d+491505&536887296|0)==0;d=c[2113300]|0;w=c[2113224]|0;x=1;y=0;z=c[2113226]|0;A=c[2112962]|0;B=c[2112924]|0;C=c[2112960]|0;while(1){D=z+32767|0;do{if((z&536887296|0)==0){E=c[C+4>>2]|0;F=E|y;do{if(f){G=E&15;if((G|0)==0){break}if((e[B>>1]|0)>=(g&65535)){break}c[A>>2]=c[a+(G<<2)>>2];b[B>>1]=g}}while(0);G=A+4|0;H=B+2|0;do{if(h){I=E>>>4&15;if((I|0)==0){break}if((e[H>>1]|0)>=(g&65535)){break}c[G>>2]=c[a+(I<<2)>>2];b[H>>1]=g}}while(0);H=A+8|0;G=B+4|0;do{if(i){I=E>>>8&15;if((I|0)==0){break}if((e[G>>1]|0)>=(g&65535)){break}c[H>>2]=c[a+(I<<2)>>2];b[G>>1]=g}}while(0);G=A+12|0;H=B+6|0;do{if(j){I=E>>>12&15;if((I|0)==0){break}if((e[H>>1]|0)>=(g&65535)){break}c[G>>2]=c[a+(I<<2)>>2];b[H>>1]=g}}while(0);H=A+16|0;G=B+8|0;do{if(k){I=E>>>16&15;if((I|0)==0){break}if((e[G>>1]|0)>=(g&65535)){break}c[H>>2]=c[a+(I<<2)>>2];b[G>>1]=g}}while(0);G=A+20|0;H=B+10|0;do{if(l){I=E>>>20&15;if((I|0)==0){break}if((e[H>>1]|0)>=(g&65535)){break}c[G>>2]=c[a+(I<<2)>>2];b[H>>1]=g}}while(0);H=A+24|0;G=B+12|0;do{if(m){I=E>>>24&15;if((I|0)==0){break}if((e[G>>1]|0)>=(g&65535)){break}c[H>>2]=c[a+(I<<2)>>2];b[G>>1]=g}}while(0);G=A+28|0;H=B+14|0;do{if(n){I=E>>>28;if((I|0)==0){break}if((e[H>>1]|0)>=(g&65535)){break}c[G>>2]=c[a+(I<<2)>>2];b[H>>1]=g}}while(0);H=A+32|0;G=B+16|0;E=c[C>>2]|0;I=F|E;do{if(o){J=E&15;if((J|0)==0){break}if((e[G>>1]|0)>=(g&65535)){break}c[H>>2]=c[a+(J<<2)>>2];b[G>>1]=g}}while(0);G=A+36|0;H=B+18|0;do{if(p){F=E>>>4&15;if((F|0)==0){break}if((e[H>>1]|0)>=(g&65535)){break}c[G>>2]=c[a+(F<<2)>>2];b[H>>1]=g}}while(0);H=A+40|0;G=B+20|0;do{if(q){F=E>>>8&15;if((F|0)==0){break}if((e[G>>1]|0)>=(g&65535)){break}c[H>>2]=c[a+(F<<2)>>2];b[G>>1]=g}}while(0);G=A+44|0;H=B+22|0;do{if(r){F=E>>>12&15;if((F|0)==0){break}if((e[H>>1]|0)>=(g&65535)){break}c[G>>2]=c[a+(F<<2)>>2];b[H>>1]=g}}while(0);H=A+48|0;G=B+24|0;do{if(s){F=E>>>16&15;if((F|0)==0){break}if((e[G>>1]|0)>=(g&65535)){break}c[H>>2]=c[a+(F<<2)>>2];b[G>>1]=g}}while(0);G=A+52|0;H=B+26|0;do{if(t){F=E>>>20&15;if((F|0)==0){break}if((e[H>>1]|0)>=(g&65535)){break}c[G>>2]=c[a+(F<<2)>>2];b[H>>1]=g}}while(0);H=A+56|0;G=B+28|0;do{if(u){F=E>>>24&15;if((F|0)==0){break}if((e[G>>1]|0)>=(g&65535)){break}c[H>>2]=c[a+(F<<2)>>2];b[G>>1]=g}}while(0);G=B+30|0;if(!v){K=I;break}H=E>>>28;if((H|0)==0){K=I;break}if((e[G>>1]|0)>=(g&65535)){K=I;break}c[A+60>>2]=c[a+(H<<2)>>2];b[G>>1]=g;K=I}else{K=y}}while(0);L=A+d|0;M=C+w|0;N=B+768|0;if((x|0)>=16){break}x=x+1|0;y=K;z=D;A=L;B=N;C=M}c[2113226]=D;c[2112962]=L;c[2112924]=N;c[2112960]=M;return(K|0)==0|0}function afj(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;a=c[3541654]|0;d=b[3726284]|0;f=c[2113300]|0;g=c[2113224]|0;h=0;i=0;j=c[2112960]|0;k=c[2112962]|0;l=c[2112924]|0;do{m=c[j>>2]|0;n=m|i;do{if(m>>>0>268435455){if((e[l>>1]|0)>=(d&65535)){break}c[k>>2]=c[a+(m>>>28<<2)>>2];b[l>>1]=d}}while(0);o=k+4|0;p=l+2|0;do{if(m<<4>>>0>268435455){if((e[p>>1]|0)>=(d&65535)){break}c[o>>2]=c[a+((m>>>24&15)<<2)>>2];b[p>>1]=d}}while(0);p=k+8|0;o=l+4|0;do{if(m<<8>>>0>268435455){if((e[o>>1]|0)>=(d&65535)){break}c[p>>2]=c[a+((m>>>20&15)<<2)>>2];b[o>>1]=d}}while(0);o=k+12|0;p=l+6|0;do{if(m<<12>>>0>268435455){if((e[p>>1]|0)>=(d&65535)){break}c[o>>2]=c[a+((m>>>16&15)<<2)>>2];b[p>>1]=d}}while(0);p=k+16|0;o=l+8|0;do{if(m<<16>>>0>268435455){if((e[o>>1]|0)>=(d&65535)){break}c[p>>2]=c[a+((m>>>12&15)<<2)>>2];b[o>>1]=d}}while(0);o=k+20|0;p=l+10|0;do{if(m<<20>>>0>268435455){if((e[p>>1]|0)>=(d&65535)){break}c[o>>2]=c[a+((m>>>8&15)<<2)>>2];b[p>>1]=d}}while(0);p=k+24|0;o=l+12|0;do{if(m<<24>>>0>268435455){if((e[o>>1]|0)>=(d&65535)){break}c[p>>2]=c[a+((m>>>4&15)<<2)>>2];b[o>>1]=d}}while(0);o=k+28|0;p=l+14|0;q=m&15;do{if((q|0)!=0){if((e[p>>1]|0)>=(d&65535)){break}c[o>>2]=c[a+(q<<2)>>2];b[p>>1]=d}}while(0);p=k+32|0;q=l+16|0;o=c[j+4>>2]|0;m=n|o;do{if(o>>>0>268435455){if((e[q>>1]|0)>=(d&65535)){break}c[p>>2]=c[a+(o>>>28<<2)>>2];b[q>>1]=d}}while(0);q=k+36|0;p=l+18|0;do{if(o<<4>>>0>268435455){if((e[p>>1]|0)>=(d&65535)){break}c[q>>2]=c[a+((o>>>24&15)<<2)>>2];b[p>>1]=d}}while(0);p=k+40|0;q=l+20|0;do{if(o<<8>>>0>268435455){if((e[q>>1]|0)>=(d&65535)){break}c[p>>2]=c[a+((o>>>20&15)<<2)>>2];b[q>>1]=d}}while(0);q=k+44|0;p=l+22|0;do{if(o<<12>>>0>268435455){if((e[p>>1]|0)>=(d&65535)){break}c[q>>2]=c[a+((o>>>16&15)<<2)>>2];b[p>>1]=d}}while(0);p=k+48|0;q=l+24|0;do{if(o<<16>>>0>268435455){if((e[q>>1]|0)>=(d&65535)){break}c[p>>2]=c[a+((o>>>12&15)<<2)>>2];b[q>>1]=d}}while(0);q=k+52|0;p=l+26|0;do{if(o<<20>>>0>268435455){if((e[p>>1]|0)>=(d&65535)){break}c[q>>2]=c[a+((o>>>8&15)<<2)>>2];b[p>>1]=d}}while(0);p=k+56|0;q=l+28|0;do{if(o<<24>>>0>268435455){if((e[q>>1]|0)>=(d&65535)){break}c[p>>2]=c[a+((o>>>4&15)<<2)>>2];b[q>>1]=d}}while(0);q=k+60|0;p=l+30|0;n=o&15;do{if((n|0)!=0){if((e[p>>1]|0)>=(d&65535)){break}c[q>>2]=c[a+(n<<2)>>2];b[p>>1]=d}}while(0);p=k+64|0;n=l+32|0;q=c[j+8>>2]|0;o=m|q;do{if(q>>>0>268435455){if((e[n>>1]|0)>=(d&65535)){break}c[p>>2]=c[a+(q>>>28<<2)>>2];b[n>>1]=d}}while(0);n=k+68|0;p=l+34|0;do{if(q<<4>>>0>268435455){if((e[p>>1]|0)>=(d&65535)){break}c[n>>2]=c[a+((q>>>24&15)<<2)>>2];b[p>>1]=d}}while(0);p=k+72|0;n=l+36|0;do{if(q<<8>>>0>268435455){if((e[n>>1]|0)>=(d&65535)){break}c[p>>2]=c[a+((q>>>20&15)<<2)>>2];b[n>>1]=d}}while(0);n=k+76|0;p=l+38|0;do{if(q<<12>>>0>268435455){if((e[p>>1]|0)>=(d&65535)){break}c[n>>2]=c[a+((q>>>16&15)<<2)>>2];b[p>>1]=d}}while(0);p=k+80|0;n=l+40|0;do{if(q<<16>>>0>268435455){if((e[n>>1]|0)>=(d&65535)){break}c[p>>2]=c[a+((q>>>12&15)<<2)>>2];b[n>>1]=d}}while(0);n=k+84|0;p=l+42|0;do{if(q<<20>>>0>268435455){if((e[p>>1]|0)>=(d&65535)){break}c[n>>2]=c[a+((q>>>8&15)<<2)>>2];b[p>>1]=d}}while(0);p=k+88|0;n=l+44|0;do{if(q<<24>>>0>268435455){if((e[n>>1]|0)>=(d&65535)){break}c[p>>2]=c[a+((q>>>4&15)<<2)>>2];b[n>>1]=d}}while(0);n=k+92|0;p=l+46|0;m=q&15;do{if((m|0)!=0){if((e[p>>1]|0)>=(d&65535)){break}c[n>>2]=c[a+(m<<2)>>2];b[p>>1]=d}}while(0);p=k+96|0;m=l+48|0;n=c[j+12>>2]|0;i=o|n;do{if(n>>>0>268435455){if((e[m>>1]|0)>=(d&65535)){break}c[p>>2]=c[a+(n>>>28<<2)>>2];b[m>>1]=d}}while(0);m=k+100|0;p=l+50|0;do{if(n<<4>>>0>268435455){if((e[p>>1]|0)>=(d&65535)){break}c[m>>2]=c[a+((n>>>24&15)<<2)>>2];b[p>>1]=d}}while(0);p=k+104|0;m=l+52|0;do{if(n<<8>>>0>268435455){if((e[m>>1]|0)>=(d&65535)){break}c[p>>2]=c[a+((n>>>20&15)<<2)>>2];b[m>>1]=d}}while(0);m=k+108|0;p=l+54|0;do{if(n<<12>>>0>268435455){if((e[p>>1]|0)>=(d&65535)){break}c[m>>2]=c[a+((n>>>16&15)<<2)>>2];b[p>>1]=d}}while(0);p=k+112|0;m=l+56|0;do{if(n<<16>>>0>268435455){if((e[m>>1]|0)>=(d&65535)){break}c[p>>2]=c[a+((n>>>12&15)<<2)>>2];b[m>>1]=d}}while(0);m=k+116|0;p=l+58|0;do{if(n<<20>>>0>268435455){if((e[p>>1]|0)>=(d&65535)){break}c[m>>2]=c[a+((n>>>8&15)<<2)>>2];b[p>>1]=d}}while(0);p=k+120|0;m=l+60|0;do{if(n<<24>>>0>268435455){if((e[m>>1]|0)>=(d&65535)){break}c[p>>2]=c[a+((n>>>4&15)<<2)>>2];b[m>>1]=d}}while(0);m=k+124|0;p=l+62|0;o=n&15;do{if((o|0)!=0){if((e[p>>1]|0)>=(d&65535)){break}c[m>>2]=c[a+(o<<2)>>2];b[p>>1]=d}}while(0);h=h+1|0;k=k+f|0;j=j+g|0;l=l+768|0;}while((h|0)<32);c[2112960]=j;c[2112962]=k;c[2112924]=l;return(i|0)==0|0}function afk(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;a=c[3541654]|0;d=c[2113300]|0;f=c[2113224]|0;g=b[3726284]|0;h=0;i=0;j=c[2112960]|0;k=c[2112962]|0;l=c[2112924]|0;do{m=c[j+12>>2]|0;n=m|i;o=m&15;do{if((o|0)!=0){if((e[l>>1]|0)>=(g&65535)){break}c[k>>2]=c[a+(o<<2)>>2];b[l>>1]=g}}while(0);o=k+4|0;p=l+2|0;q=m>>>4&15;do{if((q|0)!=0){if((e[p>>1]|0)>=(g&65535)){break}c[o>>2]=c[a+(q<<2)>>2];b[p>>1]=g}}while(0);p=k+8|0;q=l+4|0;o=m>>>8&15;do{if((o|0)!=0){if((e[q>>1]|0)>=(g&65535)){break}c[p>>2]=c[a+(o<<2)>>2];b[q>>1]=g}}while(0);q=k+12|0;o=l+6|0;p=m>>>12&15;do{if((p|0)!=0){if((e[o>>1]|0)>=(g&65535)){break}c[q>>2]=c[a+(p<<2)>>2];b[o>>1]=g}}while(0);o=k+16|0;p=l+8|0;q=m>>>16&15;do{if((q|0)!=0){if((e[p>>1]|0)>=(g&65535)){break}c[o>>2]=c[a+(q<<2)>>2];b[p>>1]=g}}while(0);p=k+20|0;q=l+10|0;o=m>>>20&15;do{if((o|0)!=0){if((e[q>>1]|0)>=(g&65535)){break}c[p>>2]=c[a+(o<<2)>>2];b[q>>1]=g}}while(0);q=k+24|0;o=l+12|0;p=m>>>24&15;do{if((p|0)!=0){if((e[o>>1]|0)>=(g&65535)){break}c[q>>2]=c[a+(p<<2)>>2];b[o>>1]=g}}while(0);o=k+28|0;p=l+14|0;q=m>>>28;do{if((q|0)!=0){if((e[p>>1]|0)>=(g&65535)){break}c[o>>2]=c[a+(q<<2)>>2];b[p>>1]=g}}while(0);p=k+32|0;q=l+16|0;o=c[j+8>>2]|0;m=n|o;r=o&15;do{if((r|0)!=0){if((e[q>>1]|0)>=(g&65535)){break}c[p>>2]=c[a+(r<<2)>>2];b[q>>1]=g}}while(0);q=k+36|0;r=l+18|0;p=o>>>4&15;do{if((p|0)!=0){if((e[r>>1]|0)>=(g&65535)){break}c[q>>2]=c[a+(p<<2)>>2];b[r>>1]=g}}while(0);r=k+40|0;p=l+20|0;q=o>>>8&15;do{if((q|0)!=0){if((e[p>>1]|0)>=(g&65535)){break}c[r>>2]=c[a+(q<<2)>>2];b[p>>1]=g}}while(0);p=k+44|0;q=l+22|0;r=o>>>12&15;do{if((r|0)!=0){if((e[q>>1]|0)>=(g&65535)){break}c[p>>2]=c[a+(r<<2)>>2];b[q>>1]=g}}while(0);q=k+48|0;r=l+24|0;p=o>>>16&15;do{if((p|0)!=0){if((e[r>>1]|0)>=(g&65535)){break}c[q>>2]=c[a+(p<<2)>>2];b[r>>1]=g}}while(0);r=k+52|0;p=l+26|0;q=o>>>20&15;do{if((q|0)!=0){if((e[p>>1]|0)>=(g&65535)){break}c[r>>2]=c[a+(q<<2)>>2];b[p>>1]=g}}while(0);p=k+56|0;q=l+28|0;r=o>>>24&15;do{if((r|0)!=0){if((e[q>>1]|0)>=(g&65535)){break}c[p>>2]=c[a+(r<<2)>>2];b[q>>1]=g}}while(0);q=k+60|0;r=l+30|0;p=o>>>28;do{if((p|0)!=0){if((e[r>>1]|0)>=(g&65535)){break}c[q>>2]=c[a+(p<<2)>>2];b[r>>1]=g}}while(0);r=k+64|0;p=l+32|0;q=c[j+4>>2]|0;o=m|q;n=q&15;do{if((n|0)!=0){if((e[p>>1]|0)>=(g&65535)){break}c[r>>2]=c[a+(n<<2)>>2];b[p>>1]=g}}while(0);p=k+68|0;n=l+34|0;r=q>>>4&15;do{if((r|0)!=0){if((e[n>>1]|0)>=(g&65535)){break}c[p>>2]=c[a+(r<<2)>>2];b[n>>1]=g}}while(0);n=k+72|0;r=l+36|0;p=q>>>8&15;do{if((p|0)!=0){if((e[r>>1]|0)>=(g&65535)){break}c[n>>2]=c[a+(p<<2)>>2];b[r>>1]=g}}while(0);r=k+76|0;p=l+38|0;n=q>>>12&15;do{if((n|0)!=0){if((e[p>>1]|0)>=(g&65535)){break}c[r>>2]=c[a+(n<<2)>>2];b[p>>1]=g}}while(0);p=k+80|0;n=l+40|0;r=q>>>16&15;do{if((r|0)!=0){if((e[n>>1]|0)>=(g&65535)){break}c[p>>2]=c[a+(r<<2)>>2];b[n>>1]=g}}while(0);n=k+84|0;r=l+42|0;p=q>>>20&15;do{if((p|0)!=0){if((e[r>>1]|0)>=(g&65535)){break}c[n>>2]=c[a+(p<<2)>>2];b[r>>1]=g}}while(0);r=k+88|0;p=l+44|0;n=q>>>24&15;do{if((n|0)!=0){if((e[p>>1]|0)>=(g&65535)){break}c[r>>2]=c[a+(n<<2)>>2];b[p>>1]=g}}while(0);p=k+92|0;n=l+46|0;r=q>>>28;do{if((r|0)!=0){if((e[n>>1]|0)>=(g&65535)){break}c[p>>2]=c[a+(r<<2)>>2];b[n>>1]=g}}while(0);n=k+96|0;r=l+48|0;p=c[j>>2]|0;i=o|p;q=p&15;do{if((q|0)!=0){if((e[r>>1]|0)>=(g&65535)){break}c[n>>2]=c[a+(q<<2)>>2];b[r>>1]=g}}while(0);r=k+100|0;q=l+50|0;n=p>>>4&15;do{if((n|0)!=0){if((e[q>>1]|0)>=(g&65535)){break}c[r>>2]=c[a+(n<<2)>>2];b[q>>1]=g}}while(0);q=k+104|0;n=l+52|0;r=p>>>8&15;do{if((r|0)!=0){if((e[n>>1]|0)>=(g&65535)){break}c[q>>2]=c[a+(r<<2)>>2];b[n>>1]=g}}while(0);n=k+108|0;r=l+54|0;q=p>>>12&15;do{if((q|0)!=0){if((e[r>>1]|0)>=(g&65535)){break}c[n>>2]=c[a+(q<<2)>>2];b[r>>1]=g}}while(0);r=k+112|0;q=l+56|0;n=p>>>16&15;do{if((n|0)!=0){if((e[q>>1]|0)>=(g&65535)){break}c[r>>2]=c[a+(n<<2)>>2];b[q>>1]=g}}while(0);q=k+116|0;n=l+58|0;r=p>>>20&15;do{if((r|0)!=0){if((e[n>>1]|0)>=(g&65535)){break}c[q>>2]=c[a+(r<<2)>>2];b[n>>1]=g}}while(0);n=k+120|0;r=l+60|0;q=p>>>24&15;do{if((q|0)!=0){if((e[r>>1]|0)>=(g&65535)){break}c[n>>2]=c[a+(q<<2)>>2];b[r>>1]=g}}while(0);r=k+124|0;q=l+62|0;n=p>>>28;do{if((n|0)!=0){if((e[q>>1]|0)>=(g&65535)){break}c[r>>2]=c[a+(n<<2)>>2];b[q>>1]=g}}while(0);h=h+1|0;k=k+d|0;j=j+f|0;l=l+768|0;}while((h|0)<32);c[2112960]=j;c[2112962]=k;c[2112924]=l;return(i|0)==0|0}function afl(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0;a=c[3541654]|0;d=c[2113228]|0;f=(d&536887296|0)==0;g=b[3726284]|0;h=(d+32767&536887296|0)==0;i=(d+65534&536887296|0)==0;j=(d+98301&536887296|0)==0;k=(d+131068&536887296|0)==0;l=(d+163835&536887296|0)==0;m=(d+196602&536887296|0)==0;n=(d+229369&536887296|0)==0;o=(d+262136&536887296|0)==0;p=(d+294903&536887296|0)==0;q=(d+327670&536887296|0)==0;r=(d+360437&536887296|0)==0;s=(d+393204&536887296|0)==0;t=(d+425971&536887296|0)==0;u=(d+458738&536887296|0)==0;v=(d+491505&536887296|0)==0;w=(d+524272&536887296|0)==0;x=(d+557039&536887296|0)==0;y=(d+589806&536887296|0)==0;z=(d+622573&536887296|0)==0;A=(d+655340&536887296|0)==0;B=(d+688107&536887296|0)==0;C=(d+720874&536887296|0)==0;D=(d+753641&536887296|0)==0;E=(d+786408&536887296|0)==0;F=(d+819175&536887296|0)==0;G=(d+851942&536887296|0)==0;H=(d+884709&536887296|0)==0;I=(d+917476&536887296|0)==0;J=(d+950243&536887296|0)==0;K=(d+983010&536887296|0)==0;L=(d+1015777&536887296|0)==0;d=c[2113300]|0;M=c[2113224]|0;N=1;O=0;P=c[2113226]|0;Q=c[2112962]|0;R=c[2112924]|0;S=c[2112960]|0;while(1){T=P+32767|0;do{if((P&536887296|0)==0){U=c[S>>2]|0;V=U|O;do{if(f&U>>>0>268435455){if((e[R>>1]|0)>=(g&65535)){break}c[Q>>2]=c[a+(U>>>28<<2)>>2];b[R>>1]=g}}while(0);W=Q+4|0;X=R+2|0;do{if(h){if(U<<4>>>0<=268435455){break}if((e[X>>1]|0)>=(g&65535)){break}c[W>>2]=c[a+((U>>>24&15)<<2)>>2];b[X>>1]=g}}while(0);X=Q+8|0;W=R+4|0;do{if(i){if(U<<8>>>0<=268435455){break}if((e[W>>1]|0)>=(g&65535)){break}c[X>>2]=c[a+((U>>>20&15)<<2)>>2];b[W>>1]=g}}while(0);W=Q+12|0;X=R+6|0;do{if(j){if(U<<12>>>0<=268435455){break}if((e[X>>1]|0)>=(g&65535)){break}c[W>>2]=c[a+((U>>>16&15)<<2)>>2];b[X>>1]=g}}while(0);X=Q+16|0;W=R+8|0;do{if(k){if(U<<16>>>0<=268435455){break}if((e[W>>1]|0)>=(g&65535)){break}c[X>>2]=c[a+((U>>>12&15)<<2)>>2];b[W>>1]=g}}while(0);W=Q+20|0;X=R+10|0;do{if(l){if(U<<20>>>0<=268435455){break}if((e[X>>1]|0)>=(g&65535)){break}c[W>>2]=c[a+((U>>>8&15)<<2)>>2];b[X>>1]=g}}while(0);X=Q+24|0;W=R+12|0;do{if(m){if(U<<24>>>0<=268435455){break}if((e[W>>1]|0)>=(g&65535)){break}c[X>>2]=c[a+((U>>>4&15)<<2)>>2];b[W>>1]=g}}while(0);W=Q+28|0;X=R+14|0;do{if(n){Y=U&15;if((Y|0)==0){break}if((e[X>>1]|0)>=(g&65535)){break}c[W>>2]=c[a+(Y<<2)>>2];b[X>>1]=g}}while(0);X=Q+32|0;W=R+16|0;U=c[S+4>>2]|0;Y=V|U;do{if(o&U>>>0>268435455){if((e[W>>1]|0)>=(g&65535)){break}c[X>>2]=c[a+(U>>>28<<2)>>2];b[W>>1]=g}}while(0);W=Q+36|0;X=R+18|0;do{if(p){if(U<<4>>>0<=268435455){break}if((e[X>>1]|0)>=(g&65535)){break}c[W>>2]=c[a+((U>>>24&15)<<2)>>2];b[X>>1]=g}}while(0);X=Q+40|0;W=R+20|0;do{if(q){if(U<<8>>>0<=268435455){break}if((e[W>>1]|0)>=(g&65535)){break}c[X>>2]=c[a+((U>>>20&15)<<2)>>2];b[W>>1]=g}}while(0);W=Q+44|0;X=R+22|0;do{if(r){if(U<<12>>>0<=268435455){break}if((e[X>>1]|0)>=(g&65535)){break}c[W>>2]=c[a+((U>>>16&15)<<2)>>2];b[X>>1]=g}}while(0);X=Q+48|0;W=R+24|0;do{if(s){if(U<<16>>>0<=268435455){break}if((e[W>>1]|0)>=(g&65535)){break}c[X>>2]=c[a+((U>>>12&15)<<2)>>2];b[W>>1]=g}}while(0);W=Q+52|0;X=R+26|0;do{if(t){if(U<<20>>>0<=268435455){break}if((e[X>>1]|0)>=(g&65535)){break}c[W>>2]=c[a+((U>>>8&15)<<2)>>2];b[X>>1]=g}}while(0);X=Q+56|0;W=R+28|0;do{if(u){if(U<<24>>>0<=268435455){break}if((e[W>>1]|0)>=(g&65535)){break}c[X>>2]=c[a+((U>>>4&15)<<2)>>2];b[W>>1]=g}}while(0);W=Q+60|0;X=R+30|0;do{if(v){V=U&15;if((V|0)==0){break}if((e[X>>1]|0)>=(g&65535)){break}c[W>>2]=c[a+(V<<2)>>2];b[X>>1]=g}}while(0);X=Q+64|0;W=R+32|0;U=c[S+8>>2]|0;V=Y|U;do{if(w&U>>>0>268435455){if((e[W>>1]|0)>=(g&65535)){break}c[X>>2]=c[a+(U>>>28<<2)>>2];b[W>>1]=g}}while(0);W=Q+68|0;X=R+34|0;do{if(x){if(U<<4>>>0<=268435455){break}if((e[X>>1]|0)>=(g&65535)){break}c[W>>2]=c[a+((U>>>24&15)<<2)>>2];b[X>>1]=g}}while(0);X=Q+72|0;W=R+36|0;do{if(y){if(U<<8>>>0<=268435455){break}if((e[W>>1]|0)>=(g&65535)){break}c[X>>2]=c[a+((U>>>20&15)<<2)>>2];b[W>>1]=g}}while(0);W=Q+76|0;X=R+38|0;do{if(z){if(U<<12>>>0<=268435455){break}if((e[X>>1]|0)>=(g&65535)){break}c[W>>2]=c[a+((U>>>16&15)<<2)>>2];b[X>>1]=g}}while(0);X=Q+80|0;W=R+40|0;do{if(A){if(U<<16>>>0<=268435455){break}if((e[W>>1]|0)>=(g&65535)){break}c[X>>2]=c[a+((U>>>12&15)<<2)>>2];b[W>>1]=g}}while(0);W=Q+84|0;X=R+42|0;do{if(B){if(U<<20>>>0<=268435455){break}if((e[X>>1]|0)>=(g&65535)){break}c[W>>2]=c[a+((U>>>8&15)<<2)>>2];b[X>>1]=g}}while(0);X=Q+88|0;W=R+44|0;do{if(C){if(U<<24>>>0<=268435455){break}if((e[W>>1]|0)>=(g&65535)){break}c[X>>2]=c[a+((U>>>4&15)<<2)>>2];b[W>>1]=g}}while(0);W=Q+92|0;X=R+46|0;do{if(D){Y=U&15;if((Y|0)==0){break}if((e[X>>1]|0)>=(g&65535)){break}c[W>>2]=c[a+(Y<<2)>>2];b[X>>1]=g}}while(0);X=Q+96|0;W=R+48|0;U=c[S+12>>2]|0;Y=V|U;do{if(E&U>>>0>268435455){if((e[W>>1]|0)>=(g&65535)){break}c[X>>2]=c[a+(U>>>28<<2)>>2];b[W>>1]=g}}while(0);W=Q+100|0;X=R+50|0;do{if(F){if(U<<4>>>0<=268435455){break}if((e[X>>1]|0)>=(g&65535)){break}c[W>>2]=c[a+((U>>>24&15)<<2)>>2];b[X>>1]=g}}while(0);X=Q+104|0;W=R+52|0;do{if(G){if(U<<8>>>0<=268435455){break}if((e[W>>1]|0)>=(g&65535)){break}c[X>>2]=c[a+((U>>>20&15)<<2)>>2];b[W>>1]=g}}while(0);W=Q+108|0;X=R+54|0;do{if(H){if(U<<12>>>0<=268435455){break}if((e[X>>1]|0)>=(g&65535)){break}c[W>>2]=c[a+((U>>>16&15)<<2)>>2];b[X>>1]=g}}while(0);X=Q+112|0;W=R+56|0;do{if(I){if(U<<16>>>0<=268435455){break}if((e[W>>1]|0)>=(g&65535)){break}c[X>>2]=c[a+((U>>>12&15)<<2)>>2];b[W>>1]=g}}while(0);W=Q+116|0;X=R+58|0;do{if(J){if(U<<20>>>0<=268435455){break}if((e[X>>1]|0)>=(g&65535)){break}c[W>>2]=c[a+((U>>>8&15)<<2)>>2];b[X>>1]=g}}while(0);X=Q+120|0;W=R+60|0;do{if(K){if(U<<24>>>0<=268435455){break}if((e[W>>1]|0)>=(g&65535)){break}c[X>>2]=c[a+((U>>>4&15)<<2)>>2];b[W>>1]=g}}while(0);W=R+62|0;if(!L){Z=Y;break}X=U&15;if((X|0)==0){Z=Y;break}if((e[W>>1]|0)>=(g&65535)){Z=Y;break}c[Q+124>>2]=c[a+(X<<2)>>2];b[W>>1]=g;Z=Y}else{Z=O}}while(0);_=Q+d|0;$=S+M|0;aa=R+768|0;if((N|0)>=32){break}N=N+1|0;O=Z;P=T;Q=_;R=aa;S=$}c[2113226]=T;c[2112962]=_;c[2112924]=aa;c[2112960]=$;return(Z|0)==0|0}function afm(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0;a=c[3541654]|0;d=c[2113228]|0;f=(d&536887296|0)==0;g=b[3726284]|0;h=(d+32767&536887296|0)==0;i=(d+65534&536887296|0)==0;j=(d+98301&536887296|0)==0;k=(d+131068&536887296|0)==0;l=(d+163835&536887296|0)==0;m=(d+196602&536887296|0)==0;n=(d+229369&536887296|0)==0;o=(d+262136&536887296|0)==0;p=(d+294903&536887296|0)==0;q=(d+327670&536887296|0)==0;r=(d+360437&536887296|0)==0;s=(d+393204&536887296|0)==0;t=(d+425971&536887296|0)==0;u=(d+458738&536887296|0)==0;v=(d+491505&536887296|0)==0;w=(d+524272&536887296|0)==0;x=(d+557039&536887296|0)==0;y=(d+589806&536887296|0)==0;z=(d+622573&536887296|0)==0;A=(d+655340&536887296|0)==0;B=(d+688107&536887296|0)==0;C=(d+720874&536887296|0)==0;D=(d+753641&536887296|0)==0;E=(d+786408&536887296|0)==0;F=(d+819175&536887296|0)==0;G=(d+851942&536887296|0)==0;H=(d+884709&536887296|0)==0;I=(d+917476&536887296|0)==0;J=(d+950243&536887296|0)==0;K=(d+983010&536887296|0)==0;L=(d+1015777&536887296|0)==0;d=c[2113300]|0;M=c[2113224]|0;N=1;O=0;P=c[2113226]|0;Q=c[2112962]|0;R=c[2112924]|0;S=c[2112960]|0;while(1){T=P+32767|0;do{if((P&536887296|0)==0){U=c[S+12>>2]|0;V=U|O;do{if(f){W=U&15;if((W|0)==0){break}if((e[R>>1]|0)>=(g&65535)){break}c[Q>>2]=c[a+(W<<2)>>2];b[R>>1]=g}}while(0);W=Q+4|0;X=R+2|0;do{if(h){Y=U>>>4&15;if((Y|0)==0){break}if((e[X>>1]|0)>=(g&65535)){break}c[W>>2]=c[a+(Y<<2)>>2];b[X>>1]=g}}while(0);X=Q+8|0;W=R+4|0;do{if(i){Y=U>>>8&15;if((Y|0)==0){break}if((e[W>>1]|0)>=(g&65535)){break}c[X>>2]=c[a+(Y<<2)>>2];b[W>>1]=g}}while(0);W=Q+12|0;X=R+6|0;do{if(j){Y=U>>>12&15;if((Y|0)==0){break}if((e[X>>1]|0)>=(g&65535)){break}c[W>>2]=c[a+(Y<<2)>>2];b[X>>1]=g}}while(0);X=Q+16|0;W=R+8|0;do{if(k){Y=U>>>16&15;if((Y|0)==0){break}if((e[W>>1]|0)>=(g&65535)){break}c[X>>2]=c[a+(Y<<2)>>2];b[W>>1]=g}}while(0);W=Q+20|0;X=R+10|0;do{if(l){Y=U>>>20&15;if((Y|0)==0){break}if((e[X>>1]|0)>=(g&65535)){break}c[W>>2]=c[a+(Y<<2)>>2];b[X>>1]=g}}while(0);X=Q+24|0;W=R+12|0;do{if(m){Y=U>>>24&15;if((Y|0)==0){break}if((e[W>>1]|0)>=(g&65535)){break}c[X>>2]=c[a+(Y<<2)>>2];b[W>>1]=g}}while(0);W=Q+28|0;X=R+14|0;do{if(n){Y=U>>>28;if((Y|0)==0){break}if((e[X>>1]|0)>=(g&65535)){break}c[W>>2]=c[a+(Y<<2)>>2];b[X>>1]=g}}while(0);X=Q+32|0;W=R+16|0;U=c[S+8>>2]|0;Y=V|U;do{if(o){Z=U&15;if((Z|0)==0){break}if((e[W>>1]|0)>=(g&65535)){break}c[X>>2]=c[a+(Z<<2)>>2];b[W>>1]=g}}while(0);W=Q+36|0;X=R+18|0;do{if(p){V=U>>>4&15;if((V|0)==0){break}if((e[X>>1]|0)>=(g&65535)){break}c[W>>2]=c[a+(V<<2)>>2];b[X>>1]=g}}while(0);X=Q+40|0;W=R+20|0;do{if(q){V=U>>>8&15;if((V|0)==0){break}if((e[W>>1]|0)>=(g&65535)){break}c[X>>2]=c[a+(V<<2)>>2];b[W>>1]=g}}while(0);W=Q+44|0;X=R+22|0;do{if(r){V=U>>>12&15;if((V|0)==0){break}if((e[X>>1]|0)>=(g&65535)){break}c[W>>2]=c[a+(V<<2)>>2];b[X>>1]=g}}while(0);X=Q+48|0;W=R+24|0;do{if(s){V=U>>>16&15;if((V|0)==0){break}if((e[W>>1]|0)>=(g&65535)){break}c[X>>2]=c[a+(V<<2)>>2];b[W>>1]=g}}while(0);W=Q+52|0;X=R+26|0;do{if(t){V=U>>>20&15;if((V|0)==0){break}if((e[X>>1]|0)>=(g&65535)){break}c[W>>2]=c[a+(V<<2)>>2];b[X>>1]=g}}while(0);X=Q+56|0;W=R+28|0;do{if(u){V=U>>>24&15;if((V|0)==0){break}if((e[W>>1]|0)>=(g&65535)){break}c[X>>2]=c[a+(V<<2)>>2];b[W>>1]=g}}while(0);W=Q+60|0;X=R+30|0;do{if(v){V=U>>>28;if((V|0)==0){break}if((e[X>>1]|0)>=(g&65535)){break}c[W>>2]=c[a+(V<<2)>>2];b[X>>1]=g}}while(0);X=Q+64|0;W=R+32|0;U=c[S+4>>2]|0;V=Y|U;do{if(w){Z=U&15;if((Z|0)==0){break}if((e[W>>1]|0)>=(g&65535)){break}c[X>>2]=c[a+(Z<<2)>>2];b[W>>1]=g}}while(0);W=Q+68|0;X=R+34|0;do{if(x){Y=U>>>4&15;if((Y|0)==0){break}if((e[X>>1]|0)>=(g&65535)){break}c[W>>2]=c[a+(Y<<2)>>2];b[X>>1]=g}}while(0);X=Q+72|0;W=R+36|0;do{if(y){Y=U>>>8&15;if((Y|0)==0){break}if((e[W>>1]|0)>=(g&65535)){break}c[X>>2]=c[a+(Y<<2)>>2];b[W>>1]=g}}while(0);W=Q+76|0;X=R+38|0;do{if(z){Y=U>>>12&15;if((Y|0)==0){break}if((e[X>>1]|0)>=(g&65535)){break}c[W>>2]=c[a+(Y<<2)>>2];b[X>>1]=g}}while(0);X=Q+80|0;W=R+40|0;do{if(A){Y=U>>>16&15;if((Y|0)==0){break}if((e[W>>1]|0)>=(g&65535)){break}c[X>>2]=c[a+(Y<<2)>>2];b[W>>1]=g}}while(0);W=Q+84|0;X=R+42|0;do{if(B){Y=U>>>20&15;if((Y|0)==0){break}if((e[X>>1]|0)>=(g&65535)){break}c[W>>2]=c[a+(Y<<2)>>2];b[X>>1]=g}}while(0);X=Q+88|0;W=R+44|0;do{if(C){Y=U>>>24&15;if((Y|0)==0){break}if((e[W>>1]|0)>=(g&65535)){break}c[X>>2]=c[a+(Y<<2)>>2];b[W>>1]=g}}while(0);W=Q+92|0;X=R+46|0;do{if(D){Y=U>>>28;if((Y|0)==0){break}if((e[X>>1]|0)>=(g&65535)){break}c[W>>2]=c[a+(Y<<2)>>2];b[X>>1]=g}}while(0);X=Q+96|0;W=R+48|0;U=c[S>>2]|0;Y=V|U;do{if(E){Z=U&15;if((Z|0)==0){break}if((e[W>>1]|0)>=(g&65535)){break}c[X>>2]=c[a+(Z<<2)>>2];b[W>>1]=g}}while(0);W=Q+100|0;X=R+50|0;do{if(F){V=U>>>4&15;if((V|0)==0){break}if((e[X>>1]|0)>=(g&65535)){break}c[W>>2]=c[a+(V<<2)>>2];b[X>>1]=g}}while(0);X=Q+104|0;W=R+52|0;do{if(G){V=U>>>8&15;if((V|0)==0){break}if((e[W>>1]|0)>=(g&65535)){break}c[X>>2]=c[a+(V<<2)>>2];b[W>>1]=g}}while(0);W=Q+108|0;X=R+54|0;do{if(H){V=U>>>12&15;if((V|0)==0){break}if((e[X>>1]|0)>=(g&65535)){break}c[W>>2]=c[a+(V<<2)>>2];b[X>>1]=g}}while(0);X=Q+112|0;W=R+56|0;do{if(I){V=U>>>16&15;if((V|0)==0){break}if((e[W>>1]|0)>=(g&65535)){break}c[X>>2]=c[a+(V<<2)>>2];b[W>>1]=g}}while(0);W=Q+116|0;X=R+58|0;do{if(J){V=U>>>20&15;if((V|0)==0){break}if((e[X>>1]|0)>=(g&65535)){break}c[W>>2]=c[a+(V<<2)>>2];b[X>>1]=g}}while(0);X=Q+120|0;W=R+60|0;do{if(K){V=U>>>24&15;if((V|0)==0){break}if((e[W>>1]|0)>=(g&65535)){break}c[X>>2]=c[a+(V<<2)>>2];b[W>>1]=g}}while(0);W=R+62|0;if(!L){_=Y;break}X=U>>>28;if((X|0)==0){_=Y;break}if((e[W>>1]|0)>=(g&65535)){_=Y;break}c[Q+124>>2]=c[a+(X<<2)>>2];b[W>>1]=g;_=Y}else{_=O}}while(0);$=Q+d|0;aa=S+M|0;ab=R+768|0;if((N|0)>=32){break}N=N+1|0;O=_;P=T;Q=$;R=ab;S=aa}c[2113226]=T;c[2112962]=$;c[2112924]=ab;c[2112960]=aa;return(_|0)==0|0}function afn(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a=c[3541654]|0;b=c[2113300]|0;d=c[2113224]|0;e=0;f=0;g=c[2112962]|0;h=c[2112960]|0;do{i=c[h>>2]|0;f=i|f;if(i>>>0>268435455){c[g>>2]=c[a+(i>>>28<<2)>>2]}if(i<<4>>>0>268435455){c[g+4>>2]=c[a+((i>>>24&15)<<2)>>2]}if(i<<8>>>0>268435455){c[g+8>>2]=c[a+((i>>>20&15)<<2)>>2]}if(i<<12>>>0>268435455){c[g+12>>2]=c[a+((i>>>16&15)<<2)>>2]}if(i<<16>>>0>268435455){c[g+16>>2]=c[a+((i>>>12&15)<<2)>>2]}if(i<<20>>>0>268435455){c[g+20>>2]=c[a+((i>>>8&15)<<2)>>2]}if(i<<24>>>0>268435455){c[g+24>>2]=c[a+((i>>>4&15)<<2)>>2]}j=i&15;if((j|0)!=0){c[g+28>>2]=c[a+(j<<2)>>2]}e=e+1|0;g=g+b|0;h=h+d|0;}while((e|0)<8);c[2112962]=g;c[2112960]=h;return(f|0)==0|0}function afo(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a=c[3541654]|0;b=c[2113300]|0;d=c[2113224]|0;e=0;f=0;g=c[2112962]|0;h=c[2112960]|0;do{i=c[h>>2]|0;f=i|f;j=i&15;if((j|0)!=0){c[g>>2]=c[a+(j<<2)>>2]}j=i>>>4&15;if((j|0)!=0){c[g+4>>2]=c[a+(j<<2)>>2]}j=i>>>8&15;if((j|0)!=0){c[g+8>>2]=c[a+(j<<2)>>2]}j=i>>>12&15;if((j|0)!=0){c[g+12>>2]=c[a+(j<<2)>>2]}j=i>>>16&15;if((j|0)!=0){c[g+16>>2]=c[a+(j<<2)>>2]}j=i>>>20&15;if((j|0)!=0){c[g+20>>2]=c[a+(j<<2)>>2]}j=i>>>24&15;if((j|0)!=0){c[g+24>>2]=c[a+(j<<2)>>2]}j=i>>>28;if((j|0)!=0){c[g+28>>2]=c[a+(j<<2)>>2]}e=e+1|0;g=g+b|0;h=h+d|0;}while((e|0)<8);c[2112962]=g;c[2112960]=h;return(f|0)==0|0}function afp(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;a=c[3541654]|0;b=c[2113228]|0;d=(b&536887296|0)==0;e=(b+32767&536887296|0)==0;f=(b+65534&536887296|0)==0;g=(b+98301&536887296|0)==0;h=(b+131068&536887296|0)==0;i=(b+163835&536887296|0)==0;j=(b+196602&536887296|0)==0;k=(b+229369&536887296|0)==0;b=c[2113300]|0;l=c[2113224]|0;m=1;n=0;o=c[2113226]|0;p=c[2112962]|0;q=c[2112960]|0;while(1){r=o+32767|0;do{if((o&536887296|0)==0){s=c[q>>2]|0;t=s|n;if(d&s>>>0>268435455){c[p>>2]=c[a+(s>>>28<<2)>>2]}u=p+4|0;do{if(e){if(s<<4>>>0<=268435455){break}c[u>>2]=c[a+((s>>>24&15)<<2)>>2]}}while(0);u=p+8|0;do{if(f){if(s<<8>>>0<=268435455){break}c[u>>2]=c[a+((s>>>20&15)<<2)>>2]}}while(0);u=p+12|0;do{if(g){if(s<<12>>>0<=268435455){break}c[u>>2]=c[a+((s>>>16&15)<<2)>>2]}}while(0);u=p+16|0;do{if(h){if(s<<16>>>0<=268435455){break}c[u>>2]=c[a+((s>>>12&15)<<2)>>2]}}while(0);u=p+20|0;do{if(i){if(s<<20>>>0<=268435455){break}c[u>>2]=c[a+((s>>>8&15)<<2)>>2]}}while(0);u=p+24|0;do{if(j){if(s<<24>>>0<=268435455){break}c[u>>2]=c[a+((s>>>4&15)<<2)>>2]}}while(0);if(!k){v=t;break}u=s&15;if((u|0)==0){v=t;break}c[p+28>>2]=c[a+(u<<2)>>2];v=t}else{v=n}}while(0);w=p+b|0;x=q+l|0;if((m|0)>=8){break}m=m+1|0;n=v;o=r;p=w;q=x}c[2113226]=r;c[2112962]=w;c[2112960]=x;return(v|0)==0|0}function afq(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;a=c[3541654]|0;b=c[2113228]|0;d=(b&536887296|0)==0;e=(b+32767&536887296|0)==0;f=(b+65534&536887296|0)==0;g=(b+98301&536887296|0)==0;h=(b+131068&536887296|0)==0;i=(b+163835&536887296|0)==0;j=(b+196602&536887296|0)==0;k=(b+229369&536887296|0)==0;b=c[2113300]|0;l=c[2113224]|0;m=1;n=0;o=c[2113226]|0;p=c[2112962]|0;q=c[2112960]|0;while(1){r=o+32767|0;do{if((o&536887296|0)==0){s=c[q>>2]|0;t=s|n;do{if(d){u=s&15;if((u|0)==0){break}c[p>>2]=c[a+(u<<2)>>2]}}while(0);u=p+4|0;do{if(e){v=s>>>4&15;if((v|0)==0){break}c[u>>2]=c[a+(v<<2)>>2]}}while(0);u=p+8|0;do{if(f){v=s>>>8&15;if((v|0)==0){break}c[u>>2]=c[a+(v<<2)>>2]}}while(0);u=p+12|0;do{if(g){v=s>>>12&15;if((v|0)==0){break}c[u>>2]=c[a+(v<<2)>>2]}}while(0);u=p+16|0;do{if(h){v=s>>>16&15;if((v|0)==0){break}c[u>>2]=c[a+(v<<2)>>2]}}while(0);u=p+20|0;do{if(i){v=s>>>20&15;if((v|0)==0){break}c[u>>2]=c[a+(v<<2)>>2]}}while(0);u=p+24|0;do{if(j){v=s>>>24&15;if((v|0)==0){break}c[u>>2]=c[a+(v<<2)>>2]}}while(0);if(!k){w=t;break}u=s>>>28;if((u|0)==0){w=t;break}c[p+28>>2]=c[a+(u<<2)>>2];w=t}else{w=n}}while(0);x=p+b|0;y=q+l|0;if((m|0)>=8){break}m=m+1|0;n=w;o=r;p=x;q=y}c[2113226]=r;c[2112962]=x;c[2112960]=y;return(w|0)==0|0}function afr(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a=c[3541654]|0;b=c[2113300]|0;d=c[2113224]|0;e=0;f=0;g=c[2112960]|0;h=c[2112962]|0;do{i=c[g>>2]|0;if(i>>>0>268435455){c[h>>2]=c[a+(i>>>28<<2)>>2]}if(i<<4>>>0>268435455){c[h+4>>2]=c[a+((i>>>24&15)<<2)>>2]}if(i<<8>>>0>268435455){c[h+8>>2]=c[a+((i>>>20&15)<<2)>>2]}if(i<<12>>>0>268435455){c[h+12>>2]=c[a+((i>>>16&15)<<2)>>2]}if(i<<16>>>0>268435455){c[h+16>>2]=c[a+((i>>>12&15)<<2)>>2]}if(i<<20>>>0>268435455){c[h+20>>2]=c[a+((i>>>8&15)<<2)>>2]}if(i<<24>>>0>268435455){c[h+24>>2]=c[a+((i>>>4&15)<<2)>>2]}j=i&15;if((j|0)!=0){c[h+28>>2]=c[a+(j<<2)>>2]}j=c[g+4>>2]|0;f=i|f|j;if(j>>>0>268435455){c[h+32>>2]=c[a+(j>>>28<<2)>>2]}if(j<<4>>>0>268435455){c[h+36>>2]=c[a+((j>>>24&15)<<2)>>2]}if(j<<8>>>0>268435455){c[h+40>>2]=c[a+((j>>>20&15)<<2)>>2]}if(j<<12>>>0>268435455){c[h+44>>2]=c[a+((j>>>16&15)<<2)>>2]}if(j<<16>>>0>268435455){c[h+48>>2]=c[a+((j>>>12&15)<<2)>>2]}if(j<<20>>>0>268435455){c[h+52>>2]=c[a+((j>>>8&15)<<2)>>2]}if(j<<24>>>0>268435455){c[h+56>>2]=c[a+((j>>>4&15)<<2)>>2]}i=j&15;if((i|0)!=0){c[h+60>>2]=c[a+(i<<2)>>2]}e=e+1|0;h=h+b|0;g=g+d|0;}while((e|0)<16);c[2112960]=g;c[2112962]=h;return(f|0)==0|0}function afs(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a=c[3541654]|0;b=c[2113300]|0;d=c[2113224]|0;e=0;f=0;g=c[2112960]|0;h=c[2112962]|0;do{i=c[g+4>>2]|0;j=i&15;if((j|0)!=0){c[h>>2]=c[a+(j<<2)>>2]}j=i>>>4&15;if((j|0)!=0){c[h+4>>2]=c[a+(j<<2)>>2]}j=i>>>8&15;if((j|0)!=0){c[h+8>>2]=c[a+(j<<2)>>2]}j=i>>>12&15;if((j|0)!=0){c[h+12>>2]=c[a+(j<<2)>>2]}j=i>>>16&15;if((j|0)!=0){c[h+16>>2]=c[a+(j<<2)>>2]}j=i>>>20&15;if((j|0)!=0){c[h+20>>2]=c[a+(j<<2)>>2]}j=i>>>24&15;if((j|0)!=0){c[h+24>>2]=c[a+(j<<2)>>2]}j=i>>>28;if((j|0)!=0){c[h+28>>2]=c[a+(j<<2)>>2]}j=c[g>>2]|0;f=i|f|j;i=j&15;if((i|0)!=0){c[h+32>>2]=c[a+(i<<2)>>2]}i=j>>>4&15;if((i|0)!=0){c[h+36>>2]=c[a+(i<<2)>>2]}i=j>>>8&15;if((i|0)!=0){c[h+40>>2]=c[a+(i<<2)>>2]}i=j>>>12&15;if((i|0)!=0){c[h+44>>2]=c[a+(i<<2)>>2]}i=j>>>16&15;if((i|0)!=0){c[h+48>>2]=c[a+(i<<2)>>2]}i=j>>>20&15;if((i|0)!=0){c[h+52>>2]=c[a+(i<<2)>>2]}i=j>>>24&15;if((i|0)!=0){c[h+56>>2]=c[a+(i<<2)>>2]}i=j>>>28;if((i|0)!=0){c[h+60>>2]=c[a+(i<<2)>>2]}e=e+1|0;h=h+b|0;g=g+d|0;}while((e|0)<16);c[2112960]=g;c[2112962]=h;return(f|0)==0|0}function aft(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;a=c[3541654]|0;b=c[2113228]|0;d=(b&536887296|0)==0;e=(b+32767&536887296|0)==0;f=(b+65534&536887296|0)==0;g=(b+98301&536887296|0)==0;h=(b+131068&536887296|0)==0;i=(b+163835&536887296|0)==0;j=(b+196602&536887296|0)==0;k=(b+229369&536887296|0)==0;l=(b+262136&536887296|0)==0;m=(b+294903&536887296|0)==0;n=(b+327670&536887296|0)==0;o=(b+360437&536887296|0)==0;p=(b+393204&536887296|0)==0;q=(b+425971&536887296|0)==0;r=(b+458738&536887296|0)==0;s=(b+491505&536887296|0)==0;b=c[2113300]|0;t=c[2113224]|0;u=1;v=0;w=c[2113226]|0;x=c[2112962]|0;y=c[2112960]|0;while(1){z=w+32767|0;do{if((w&536887296|0)==0){A=c[y>>2]|0;B=A|v;if(d&A>>>0>268435455){c[x>>2]=c[a+(A>>>28<<2)>>2]}C=x+4|0;do{if(e){if(A<<4>>>0<=268435455){break}c[C>>2]=c[a+((A>>>24&15)<<2)>>2]}}while(0);C=x+8|0;do{if(f){if(A<<8>>>0<=268435455){break}c[C>>2]=c[a+((A>>>20&15)<<2)>>2]}}while(0);C=x+12|0;do{if(g){if(A<<12>>>0<=268435455){break}c[C>>2]=c[a+((A>>>16&15)<<2)>>2]}}while(0);C=x+16|0;do{if(h){if(A<<16>>>0<=268435455){break}c[C>>2]=c[a+((A>>>12&15)<<2)>>2]}}while(0);C=x+20|0;do{if(i){if(A<<20>>>0<=268435455){break}c[C>>2]=c[a+((A>>>8&15)<<2)>>2]}}while(0);C=x+24|0;do{if(j){if(A<<24>>>0<=268435455){break}c[C>>2]=c[a+((A>>>4&15)<<2)>>2]}}while(0);C=x+28|0;do{if(k){D=A&15;if((D|0)==0){break}c[C>>2]=c[a+(D<<2)>>2]}}while(0);C=c[y+4>>2]|0;A=B|C;if(l&C>>>0>268435455){c[x+32>>2]=c[a+(C>>>28<<2)>>2]}D=x+36|0;do{if(m){if(C<<4>>>0<=268435455){break}c[D>>2]=c[a+((C>>>24&15)<<2)>>2]}}while(0);D=x+40|0;do{if(n){if(C<<8>>>0<=268435455){break}c[D>>2]=c[a+((C>>>20&15)<<2)>>2]}}while(0);D=x+44|0;do{if(o){if(C<<12>>>0<=268435455){break}c[D>>2]=c[a+((C>>>16&15)<<2)>>2]}}while(0);D=x+48|0;do{if(p){if(C<<16>>>0<=268435455){break}c[D>>2]=c[a+((C>>>12&15)<<2)>>2]}}while(0);D=x+52|0;do{if(q){if(C<<20>>>0<=268435455){break}c[D>>2]=c[a+((C>>>8&15)<<2)>>2]}}while(0);D=x+56|0;do{if(r){if(C<<24>>>0<=268435455){break}c[D>>2]=c[a+((C>>>4&15)<<2)>>2]}}while(0);if(!s){E=A;break}D=C&15;if((D|0)==0){E=A;break}c[x+60>>2]=c[a+(D<<2)>>2];E=A}else{E=v}}while(0);F=x+b|0;G=y+t|0;if((u|0)>=16){break}u=u+1|0;v=E;w=z;x=F;y=G}c[2113226]=z;c[2112962]=F;c[2112960]=G;return(E|0)==0|0}function afu(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;a=c[3541654]|0;b=c[2113228]|0;d=(b&536887296|0)==0;e=(b+32767&536887296|0)==0;f=(b+65534&536887296|0)==0;g=(b+98301&536887296|0)==0;h=(b+131068&536887296|0)==0;i=(b+163835&536887296|0)==0;j=(b+196602&536887296|0)==0;k=(b+229369&536887296|0)==0;l=(b+262136&536887296|0)==0;m=(b+294903&536887296|0)==0;n=(b+327670&536887296|0)==0;o=(b+360437&536887296|0)==0;p=(b+393204&536887296|0)==0;q=(b+425971&536887296|0)==0;r=(b+458738&536887296|0)==0;s=(b+491505&536887296|0)==0;b=c[2113300]|0;t=c[2113224]|0;u=1;v=0;w=c[2113226]|0;x=c[2112962]|0;y=c[2112960]|0;while(1){z=w+32767|0;do{if((w&536887296|0)==0){A=c[y+4>>2]|0;B=A|v;do{if(d){C=A&15;if((C|0)==0){break}c[x>>2]=c[a+(C<<2)>>2]}}while(0);C=x+4|0;do{if(e){D=A>>>4&15;if((D|0)==0){break}c[C>>2]=c[a+(D<<2)>>2]}}while(0);C=x+8|0;do{if(f){D=A>>>8&15;if((D|0)==0){break}c[C>>2]=c[a+(D<<2)>>2]}}while(0);C=x+12|0;do{if(g){D=A>>>12&15;if((D|0)==0){break}c[C>>2]=c[a+(D<<2)>>2]}}while(0);C=x+16|0;do{if(h){D=A>>>16&15;if((D|0)==0){break}c[C>>2]=c[a+(D<<2)>>2]}}while(0);C=x+20|0;do{if(i){D=A>>>20&15;if((D|0)==0){break}c[C>>2]=c[a+(D<<2)>>2]}}while(0);C=x+24|0;do{if(j){D=A>>>24&15;if((D|0)==0){break}c[C>>2]=c[a+(D<<2)>>2]}}while(0);C=x+28|0;do{if(k){D=A>>>28;if((D|0)==0){break}c[C>>2]=c[a+(D<<2)>>2]}}while(0);C=x+32|0;A=c[y>>2]|0;D=B|A;do{if(l){E=A&15;if((E|0)==0){break}c[C>>2]=c[a+(E<<2)>>2]}}while(0);C=x+36|0;do{if(m){B=A>>>4&15;if((B|0)==0){break}c[C>>2]=c[a+(B<<2)>>2]}}while(0);C=x+40|0;do{if(n){B=A>>>8&15;if((B|0)==0){break}c[C>>2]=c[a+(B<<2)>>2]}}while(0);C=x+44|0;do{if(o){B=A>>>12&15;if((B|0)==0){break}c[C>>2]=c[a+(B<<2)>>2]}}while(0);C=x+48|0;do{if(p){B=A>>>16&15;if((B|0)==0){break}c[C>>2]=c[a+(B<<2)>>2]}}while(0);C=x+52|0;do{if(q){B=A>>>20&15;if((B|0)==0){break}c[C>>2]=c[a+(B<<2)>>2]}}while(0);C=x+56|0;do{if(r){B=A>>>24&15;if((B|0)==0){break}c[C>>2]=c[a+(B<<2)>>2]}}while(0);if(!s){F=D;break}C=A>>>28;if((C|0)==0){F=D;break}c[x+60>>2]=c[a+(C<<2)>>2];F=D}else{F=v}}while(0);G=x+b|0;H=y+t|0;if((u|0)>=16){break}u=u+1|0;v=F;w=z;x=G;y=H}c[2113226]=z;c[2112962]=G;c[2112960]=H;return(F|0)==0|0}function afv(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;a=c[3541654]|0;d=c[2113308]|0;e=c[2113300]|0;f=c[2113224]|0;g=1;h=0;i=c[3541650]|0;j=c[2112960]|0;k=c[2112962]|0;while(1){l=ag(b[i>>1]|0,d)|0;m=c[j>>2]|0;if(m>>>0>268435455){c[k+l>>2]=c[a+(m>>>28<<2)>>2]}if(m<<4>>>0>268435455){c[k+(l+4)>>2]=c[a+((m>>>24&15)<<2)>>2]}if(m<<8>>>0>268435455){c[k+(l+8)>>2]=c[a+((m>>>20&15)<<2)>>2]}if(m<<12>>>0>268435455){c[k+(l+12)>>2]=c[a+((m>>>16&15)<<2)>>2]}if(m<<16>>>0>268435455){c[k+(l+16)>>2]=c[a+((m>>>12&15)<<2)>>2]}if(m<<20>>>0>268435455){c[k+(l+20)>>2]=c[a+((m>>>8&15)<<2)>>2]}if(m<<24>>>0>268435455){c[k+(l+24)>>2]=c[a+((m>>>4&15)<<2)>>2]}n=m&15;if((n|0)!=0){c[k+(l+28)>>2]=c[a+(n<<2)>>2]}n=c[j+4>>2]|0;o=m|h|n;if(n>>>0>268435455){c[k+(l+32)>>2]=c[a+(n>>>28<<2)>>2]}if(n<<4>>>0>268435455){c[k+(l+36)>>2]=c[a+((n>>>24&15)<<2)>>2]}if(n<<8>>>0>268435455){c[k+(l+40)>>2]=c[a+((n>>>20&15)<<2)>>2]}if(n<<12>>>0>268435455){c[k+(l+44)>>2]=c[a+((n>>>16&15)<<2)>>2]}if(n<<16>>>0>268435455){c[k+(l+48)>>2]=c[a+((n>>>12&15)<<2)>>2]}if(n<<20>>>0>268435455){c[k+(l+52)>>2]=c[a+((n>>>8&15)<<2)>>2]}if(n<<24>>>0>268435455){c[k+(l+56)>>2]=c[a+((n>>>4&15)<<2)>>2]}m=n&15;if((m|0)!=0){c[k+(l+60)>>2]=c[a+(m<<2)>>2]}p=k+e|0;q=j+f|0;if((g|0)>=16){break}g=g+1|0;h=o;i=i+2|0;j=q;k=p}c[2112960]=q;c[2112962]=p;return(o|0)==0|0}function afw(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;a=c[3541654]|0;d=c[2113308]|0;e=c[2113300]|0;f=c[2113224]|0;g=1;h=0;i=c[3541650]|0;j=c[2112960]|0;k=c[2112962]|0;while(1){l=ag(b[i>>1]|0,d)|0;m=c[j+4>>2]|0;n=m&15;if((n|0)!=0){c[k+l>>2]=c[a+(n<<2)>>2]}n=m>>>4&15;if((n|0)!=0){c[k+(l+4)>>2]=c[a+(n<<2)>>2]}n=m>>>8&15;if((n|0)!=0){c[k+(l+8)>>2]=c[a+(n<<2)>>2]}n=m>>>12&15;if((n|0)!=0){c[k+(l+12)>>2]=c[a+(n<<2)>>2]}n=m>>>16&15;if((n|0)!=0){c[k+(l+16)>>2]=c[a+(n<<2)>>2]}n=m>>>20&15;if((n|0)!=0){c[k+(l+20)>>2]=c[a+(n<<2)>>2]}n=m>>>24&15;if((n|0)!=0){c[k+(l+24)>>2]=c[a+(n<<2)>>2]}n=m>>>28;if((n|0)!=0){c[k+(l+28)>>2]=c[a+(n<<2)>>2]}n=c[j>>2]|0;o=m|h|n;m=n&15;if((m|0)!=0){c[k+(l+32)>>2]=c[a+(m<<2)>>2]}m=n>>>4&15;if((m|0)!=0){c[k+(l+36)>>2]=c[a+(m<<2)>>2]}m=n>>>8&15;if((m|0)!=0){c[k+(l+40)>>2]=c[a+(m<<2)>>2]}m=n>>>12&15;if((m|0)!=0){c[k+(l+44)>>2]=c[a+(m<<2)>>2]}m=n>>>16&15;if((m|0)!=0){c[k+(l+48)>>2]=c[a+(m<<2)>>2]}m=n>>>20&15;if((m|0)!=0){c[k+(l+52)>>2]=c[a+(m<<2)>>2]}m=n>>>24&15;if((m|0)!=0){c[k+(l+56)>>2]=c[a+(m<<2)>>2]}m=n>>>28;if((m|0)!=0){c[k+(l+60)>>2]=c[a+(m<<2)>>2]}p=k+e|0;q=j+f|0;if((g|0)>=16){break}g=g+1|0;h=o;i=i+2|0;j=q;k=p}c[2112960]=q;c[2112962]=p;return(o|0)==0|0}function afx(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;a=c[3541654]|0;d=c[2113228]|0;e=c[2113308]|0;f=c[2113300]|0;g=c[2113224]|0;h=1;i=0;j=c[3541650]|0;k=c[2113226]|0;l=c[2112962]|0;m=c[2112960]|0;while(1){n=k+32767|0;do{if((k&536887296|0)==0){o=b[j>>1]|0;p=ag(o,e)|0;q=(o*32767|0)+d|0;o=c[m>>2]|0;r=o|i;if((q&536887296|0)==0&o>>>0>268435455){c[l+p>>2]=c[a+(o>>>28<<2)>>2]}s=l+(p+4)|0;do{if((q+32767&536887296|0)==0){if(o<<4>>>0<=268435455){break}c[s>>2]=c[a+((o>>>24&15)<<2)>>2]}}while(0);s=l+(p+8)|0;do{if((q+65534&536887296|0)==0){if(o<<8>>>0<=268435455){break}c[s>>2]=c[a+((o>>>20&15)<<2)>>2]}}while(0);s=l+(p+12)|0;do{if((q+98301&536887296|0)==0){if(o<<12>>>0<=268435455){break}c[s>>2]=c[a+((o>>>16&15)<<2)>>2]}}while(0);s=l+(p+16)|0;do{if((q+131068&536887296|0)==0){if(o<<16>>>0<=268435455){break}c[s>>2]=c[a+((o>>>12&15)<<2)>>2]}}while(0);s=l+(p+20)|0;do{if((q+163835&536887296|0)==0){if(o<<20>>>0<=268435455){break}c[s>>2]=c[a+((o>>>8&15)<<2)>>2]}}while(0);s=l+(p+24)|0;do{if((q+196602&536887296|0)==0){if(o<<24>>>0<=268435455){break}c[s>>2]=c[a+((o>>>4&15)<<2)>>2]}}while(0);s=l+(p+28)|0;do{if((q+229369&536887296|0)==0){t=o&15;if((t|0)==0){break}c[s>>2]=c[a+(t<<2)>>2]}}while(0);s=c[m+4>>2]|0;o=r|s;if((q+262136&536887296|0)==0&s>>>0>268435455){c[l+(p+32)>>2]=c[a+(s>>>28<<2)>>2]}t=l+(p+36)|0;do{if((q+294903&536887296|0)==0){if(s<<4>>>0<=268435455){break}c[t>>2]=c[a+((s>>>24&15)<<2)>>2]}}while(0);t=l+(p+40)|0;do{if((q+327670&536887296|0)==0){if(s<<8>>>0<=268435455){break}c[t>>2]=c[a+((s>>>20&15)<<2)>>2]}}while(0);t=l+(p+44)|0;do{if((q+360437&536887296|0)==0){if(s<<12>>>0<=268435455){break}c[t>>2]=c[a+((s>>>16&15)<<2)>>2]}}while(0);t=l+(p+48)|0;do{if((q+393204&536887296|0)==0){if(s<<16>>>0<=268435455){break}c[t>>2]=c[a+((s>>>12&15)<<2)>>2]}}while(0);t=l+(p+52)|0;do{if((q+425971&536887296|0)==0){if(s<<20>>>0<=268435455){break}c[t>>2]=c[a+((s>>>8&15)<<2)>>2]}}while(0);t=l+(p+56)|0;do{if((q+458738&536887296|0)==0){if(s<<24>>>0<=268435455){break}c[t>>2]=c[a+((s>>>4&15)<<2)>>2]}}while(0);if((q+491505&536887296|0)!=0){u=o;break}t=s&15;if((t|0)==0){u=o;break}c[l+(p+60)>>2]=c[a+(t<<2)>>2];u=o}else{u=i}}while(0);v=l+f|0;w=m+g|0;if((h|0)>=16){break}h=h+1|0;i=u;j=j+2|0;k=n;l=v;m=w}c[2113226]=n;c[2112962]=v;c[2112960]=w;return(u|0)==0|0}function afy(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;a=c[3541654]|0;d=c[2113228]|0;e=c[2113308]|0;f=c[2113300]|0;g=c[2113224]|0;h=1;i=0;j=c[3541650]|0;k=c[2113226]|0;l=c[2112962]|0;m=c[2112960]|0;while(1){n=k+32767|0;do{if((k&536887296|0)==0){o=b[j>>1]|0;p=ag(o,e)|0;q=l+p|0;r=(o*32767|0)+d|0;o=c[m+4>>2]|0;s=o|i;do{if((r&536887296|0)==0){t=o&15;if((t|0)==0){break}c[q>>2]=c[a+(t<<2)>>2]}}while(0);q=l+(p+4)|0;do{if((r+32767&536887296|0)==0){t=o>>>4&15;if((t|0)==0){break}c[q>>2]=c[a+(t<<2)>>2]}}while(0);q=l+(p+8)|0;do{if((r+65534&536887296|0)==0){t=o>>>8&15;if((t|0)==0){break}c[q>>2]=c[a+(t<<2)>>2]}}while(0);q=l+(p+12)|0;do{if((r+98301&536887296|0)==0){t=o>>>12&15;if((t|0)==0){break}c[q>>2]=c[a+(t<<2)>>2]}}while(0);q=l+(p+16)|0;do{if((r+131068&536887296|0)==0){t=o>>>16&15;if((t|0)==0){break}c[q>>2]=c[a+(t<<2)>>2]}}while(0);q=l+(p+20)|0;do{if((r+163835&536887296|0)==0){t=o>>>20&15;if((t|0)==0){break}c[q>>2]=c[a+(t<<2)>>2]}}while(0);q=l+(p+24)|0;do{if((r+196602&536887296|0)==0){t=o>>>24&15;if((t|0)==0){break}c[q>>2]=c[a+(t<<2)>>2]}}while(0);q=l+(p+28)|0;do{if((r+229369&536887296|0)==0){t=o>>>28;if((t|0)==0){break}c[q>>2]=c[a+(t<<2)>>2]}}while(0);q=l+(p+32)|0;o=c[m>>2]|0;t=s|o;do{if((r+262136&536887296|0)==0){u=o&15;if((u|0)==0){break}c[q>>2]=c[a+(u<<2)>>2]}}while(0);q=l+(p+36)|0;do{if((r+294903&536887296|0)==0){s=o>>>4&15;if((s|0)==0){break}c[q>>2]=c[a+(s<<2)>>2]}}while(0);q=l+(p+40)|0;do{if((r+327670&536887296|0)==0){s=o>>>8&15;if((s|0)==0){break}c[q>>2]=c[a+(s<<2)>>2]}}while(0);q=l+(p+44)|0;do{if((r+360437&536887296|0)==0){s=o>>>12&15;if((s|0)==0){break}c[q>>2]=c[a+(s<<2)>>2]}}while(0);q=l+(p+48)|0;do{if((r+393204&536887296|0)==0){s=o>>>16&15;if((s|0)==0){break}c[q>>2]=c[a+(s<<2)>>2]}}while(0);q=l+(p+52)|0;do{if((r+425971&536887296|0)==0){s=o>>>20&15;if((s|0)==0){break}c[q>>2]=c[a+(s<<2)>>2]}}while(0);q=l+(p+56)|0;do{if((r+458738&536887296|0)==0){s=o>>>24&15;if((s|0)==0){break}c[q>>2]=c[a+(s<<2)>>2]}}while(0);if((r+491505&536887296|0)!=0){v=t;break}q=o>>>28;if((q|0)==0){v=t;break}c[l+(p+60)>>2]=c[a+(q<<2)>>2];v=t}else{v=i}}while(0);w=l+f|0;x=m+g|0;if((h|0)>=16){break}h=h+1|0;i=v;j=j+2|0;k=n;l=w;m=x}c[2113226]=n;c[2112962]=w;c[2112960]=x;return(v|0)==0|0}function afz(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[3541654]|0;b=c[2113300]|0;d=c[2113224]|0;e=0;f=0;g=c[2112960]|0;h=c[2112962]|0;do{i=c[g>>2]|0;if(i>>>0>268435455){c[h>>2]=c[a+(i>>>28<<2)>>2]}if(i<<4>>>0>268435455){c[h+4>>2]=c[a+((i>>>24&15)<<2)>>2]}if(i<<8>>>0>268435455){c[h+8>>2]=c[a+((i>>>20&15)<<2)>>2]}if(i<<12>>>0>268435455){c[h+12>>2]=c[a+((i>>>16&15)<<2)>>2]}if(i<<16>>>0>268435455){c[h+16>>2]=c[a+((i>>>12&15)<<2)>>2]}if(i<<20>>>0>268435455){c[h+20>>2]=c[a+((i>>>8&15)<<2)>>2]}if(i<<24>>>0>268435455){c[h+24>>2]=c[a+((i>>>4&15)<<2)>>2]}j=i&15;if((j|0)!=0){c[h+28>>2]=c[a+(j<<2)>>2]}j=c[g+4>>2]|0;if(j>>>0>268435455){c[h+32>>2]=c[a+(j>>>28<<2)>>2]}if(j<<4>>>0>268435455){c[h+36>>2]=c[a+((j>>>24&15)<<2)>>2]}if(j<<8>>>0>268435455){c[h+40>>2]=c[a+((j>>>20&15)<<2)>>2]}if(j<<12>>>0>268435455){c[h+44>>2]=c[a+((j>>>16&15)<<2)>>2]}if(j<<16>>>0>268435455){c[h+48>>2]=c[a+((j>>>12&15)<<2)>>2]}if(j<<20>>>0>268435455){c[h+52>>2]=c[a+((j>>>8&15)<<2)>>2]}if(j<<24>>>0>268435455){c[h+56>>2]=c[a+((j>>>4&15)<<2)>>2]}k=j&15;if((k|0)!=0){c[h+60>>2]=c[a+(k<<2)>>2]}k=c[g+8>>2]|0;if(k>>>0>268435455){c[h+64>>2]=c[a+(k>>>28<<2)>>2]}if(k<<4>>>0>268435455){c[h+68>>2]=c[a+((k>>>24&15)<<2)>>2]}if(k<<8>>>0>268435455){c[h+72>>2]=c[a+((k>>>20&15)<<2)>>2]}if(k<<12>>>0>268435455){c[h+76>>2]=c[a+((k>>>16&15)<<2)>>2]}if(k<<16>>>0>268435455){c[h+80>>2]=c[a+((k>>>12&15)<<2)>>2]}if(k<<20>>>0>268435455){c[h+84>>2]=c[a+((k>>>8&15)<<2)>>2]}if(k<<24>>>0>268435455){c[h+88>>2]=c[a+((k>>>4&15)<<2)>>2]}l=k&15;if((l|0)!=0){c[h+92>>2]=c[a+(l<<2)>>2]}l=c[g+12>>2]|0;f=i|f|j|k|l;if(l>>>0>268435455){c[h+96>>2]=c[a+(l>>>28<<2)>>2]}if(l<<4>>>0>268435455){c[h+100>>2]=c[a+((l>>>24&15)<<2)>>2]}if(l<<8>>>0>268435455){c[h+104>>2]=c[a+((l>>>20&15)<<2)>>2]}if(l<<12>>>0>268435455){c[h+108>>2]=c[a+((l>>>16&15)<<2)>>2]}if(l<<16>>>0>268435455){c[h+112>>2]=c[a+((l>>>12&15)<<2)>>2]}if(l<<20>>>0>268435455){c[h+116>>2]=c[a+((l>>>8&15)<<2)>>2]}if(l<<24>>>0>268435455){c[h+120>>2]=c[a+((l>>>4&15)<<2)>>2]}k=l&15;if((k|0)!=0){c[h+124>>2]=c[a+(k<<2)>>2]}e=e+1|0;h=h+b|0;g=g+d|0;}while((e|0)<32);c[2112960]=g;c[2112962]=h;return(f|0)==0|0}function afA(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[3541654]|0;b=c[2113300]|0;d=c[2113224]|0;e=0;f=0;g=c[2112960]|0;h=c[2112962]|0;do{i=c[g+12>>2]|0;j=i&15;if((j|0)!=0){c[h>>2]=c[a+(j<<2)>>2]}j=i>>>4&15;if((j|0)!=0){c[h+4>>2]=c[a+(j<<2)>>2]}j=i>>>8&15;if((j|0)!=0){c[h+8>>2]=c[a+(j<<2)>>2]}j=i>>>12&15;if((j|0)!=0){c[h+12>>2]=c[a+(j<<2)>>2]}j=i>>>16&15;if((j|0)!=0){c[h+16>>2]=c[a+(j<<2)>>2]}j=i>>>20&15;if((j|0)!=0){c[h+20>>2]=c[a+(j<<2)>>2]}j=i>>>24&15;if((j|0)!=0){c[h+24>>2]=c[a+(j<<2)>>2]}j=i>>>28;if((j|0)!=0){c[h+28>>2]=c[a+(j<<2)>>2]}j=c[g+8>>2]|0;k=j&15;if((k|0)!=0){c[h+32>>2]=c[a+(k<<2)>>2]}k=j>>>4&15;if((k|0)!=0){c[h+36>>2]=c[a+(k<<2)>>2]}k=j>>>8&15;if((k|0)!=0){c[h+40>>2]=c[a+(k<<2)>>2]}k=j>>>12&15;if((k|0)!=0){c[h+44>>2]=c[a+(k<<2)>>2]}k=j>>>16&15;if((k|0)!=0){c[h+48>>2]=c[a+(k<<2)>>2]}k=j>>>20&15;if((k|0)!=0){c[h+52>>2]=c[a+(k<<2)>>2]}k=j>>>24&15;if((k|0)!=0){c[h+56>>2]=c[a+(k<<2)>>2]}k=j>>>28;if((k|0)!=0){c[h+60>>2]=c[a+(k<<2)>>2]}k=c[g+4>>2]|0;l=k&15;if((l|0)!=0){c[h+64>>2]=c[a+(l<<2)>>2]}l=k>>>4&15;if((l|0)!=0){c[h+68>>2]=c[a+(l<<2)>>2]}l=k>>>8&15;if((l|0)!=0){c[h+72>>2]=c[a+(l<<2)>>2]}l=k>>>12&15;if((l|0)!=0){c[h+76>>2]=c[a+(l<<2)>>2]}l=k>>>16&15;if((l|0)!=0){c[h+80>>2]=c[a+(l<<2)>>2]}l=k>>>20&15;if((l|0)!=0){c[h+84>>2]=c[a+(l<<2)>>2]}l=k>>>24&15;if((l|0)!=0){c[h+88>>2]=c[a+(l<<2)>>2]}l=k>>>28;if((l|0)!=0){c[h+92>>2]=c[a+(l<<2)>>2]}l=c[g>>2]|0;f=i|f|j|k|l;k=l&15;if((k|0)!=0){c[h+96>>2]=c[a+(k<<2)>>2]}k=l>>>4&15;if((k|0)!=0){c[h+100>>2]=c[a+(k<<2)>>2]}k=l>>>8&15;if((k|0)!=0){c[h+104>>2]=c[a+(k<<2)>>2]}k=l>>>12&15;if((k|0)!=0){c[h+108>>2]=c[a+(k<<2)>>2]}k=l>>>16&15;if((k|0)!=0){c[h+112>>2]=c[a+(k<<2)>>2]}k=l>>>20&15;if((k|0)!=0){c[h+116>>2]=c[a+(k<<2)>>2]}k=l>>>24&15;if((k|0)!=0){c[h+120>>2]=c[a+(k<<2)>>2]}k=l>>>28;if((k|0)!=0){c[h+124>>2]=c[a+(k<<2)>>2]}e=e+1|0;h=h+b|0;g=g+d|0;}while((e|0)<32);c[2112960]=g;c[2112962]=h;return(f|0)==0|0}function afB(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;a=c[3541654]|0;b=c[2113228]|0;d=(b&536887296|0)==0;e=(b+32767&536887296|0)==0;f=(b+65534&536887296|0)==0;g=(b+98301&536887296|0)==0;h=(b+131068&536887296|0)==0;i=(b+163835&536887296|0)==0;j=(b+196602&536887296|0)==0;k=(b+229369&536887296|0)==0;l=(b+262136&536887296|0)==0;m=(b+294903&536887296|0)==0;n=(b+327670&536887296|0)==0;o=(b+360437&536887296|0)==0;p=(b+393204&536887296|0)==0;q=(b+425971&536887296|0)==0;r=(b+458738&536887296|0)==0;s=(b+491505&536887296|0)==0;t=(b+524272&536887296|0)==0;u=(b+557039&536887296|0)==0;v=(b+589806&536887296|0)==0;w=(b+622573&536887296|0)==0;x=(b+655340&536887296|0)==0;y=(b+688107&536887296|0)==0;z=(b+720874&536887296|0)==0;A=(b+753641&536887296|0)==0;B=(b+786408&536887296|0)==0;C=(b+819175&536887296|0)==0;D=(b+851942&536887296|0)==0;E=(b+884709&536887296|0)==0;F=(b+917476&536887296|0)==0;G=(b+950243&536887296|0)==0;H=(b+983010&536887296|0)==0;I=(b+1015777&536887296|0)==0;b=c[2113300]|0;J=c[2113224]|0;K=1;L=0;M=c[2113226]|0;N=c[2112962]|0;O=c[2112960]|0;while(1){P=M+32767|0;do{if((M&536887296|0)==0){Q=c[O>>2]|0;R=Q|L;if(d&Q>>>0>268435455){c[N>>2]=c[a+(Q>>>28<<2)>>2]}S=N+4|0;do{if(e){if(Q<<4>>>0<=268435455){break}c[S>>2]=c[a+((Q>>>24&15)<<2)>>2]}}while(0);S=N+8|0;do{if(f){if(Q<<8>>>0<=268435455){break}c[S>>2]=c[a+((Q>>>20&15)<<2)>>2]}}while(0);S=N+12|0;do{if(g){if(Q<<12>>>0<=268435455){break}c[S>>2]=c[a+((Q>>>16&15)<<2)>>2]}}while(0);S=N+16|0;do{if(h){if(Q<<16>>>0<=268435455){break}c[S>>2]=c[a+((Q>>>12&15)<<2)>>2]}}while(0);S=N+20|0;do{if(i){if(Q<<20>>>0<=268435455){break}c[S>>2]=c[a+((Q>>>8&15)<<2)>>2]}}while(0);S=N+24|0;do{if(j){if(Q<<24>>>0<=268435455){break}c[S>>2]=c[a+((Q>>>4&15)<<2)>>2]}}while(0);S=N+28|0;do{if(k){T=Q&15;if((T|0)==0){break}c[S>>2]=c[a+(T<<2)>>2]}}while(0);S=c[O+4>>2]|0;Q=R|S;if(l&S>>>0>268435455){c[N+32>>2]=c[a+(S>>>28<<2)>>2]}T=N+36|0;do{if(m){if(S<<4>>>0<=268435455){break}c[T>>2]=c[a+((S>>>24&15)<<2)>>2]}}while(0);T=N+40|0;do{if(n){if(S<<8>>>0<=268435455){break}c[T>>2]=c[a+((S>>>20&15)<<2)>>2]}}while(0);T=N+44|0;do{if(o){if(S<<12>>>0<=268435455){break}c[T>>2]=c[a+((S>>>16&15)<<2)>>2]}}while(0);T=N+48|0;do{if(p){if(S<<16>>>0<=268435455){break}c[T>>2]=c[a+((S>>>12&15)<<2)>>2]}}while(0);T=N+52|0;do{if(q){if(S<<20>>>0<=268435455){break}c[T>>2]=c[a+((S>>>8&15)<<2)>>2]}}while(0);T=N+56|0;do{if(r){if(S<<24>>>0<=268435455){break}c[T>>2]=c[a+((S>>>4&15)<<2)>>2]}}while(0);T=N+60|0;do{if(s){R=S&15;if((R|0)==0){break}c[T>>2]=c[a+(R<<2)>>2]}}while(0);T=c[O+8>>2]|0;S=Q|T;if(t&T>>>0>268435455){c[N+64>>2]=c[a+(T>>>28<<2)>>2]}R=N+68|0;do{if(u){if(T<<4>>>0<=268435455){break}c[R>>2]=c[a+((T>>>24&15)<<2)>>2]}}while(0);R=N+72|0;do{if(v){if(T<<8>>>0<=268435455){break}c[R>>2]=c[a+((T>>>20&15)<<2)>>2]}}while(0);R=N+76|0;do{if(w){if(T<<12>>>0<=268435455){break}c[R>>2]=c[a+((T>>>16&15)<<2)>>2]}}while(0);R=N+80|0;do{if(x){if(T<<16>>>0<=268435455){break}c[R>>2]=c[a+((T>>>12&15)<<2)>>2]}}while(0);R=N+84|0;do{if(y){if(T<<20>>>0<=268435455){break}c[R>>2]=c[a+((T>>>8&15)<<2)>>2]}}while(0);R=N+88|0;do{if(z){if(T<<24>>>0<=268435455){break}c[R>>2]=c[a+((T>>>4&15)<<2)>>2]}}while(0);R=N+92|0;do{if(A){Q=T&15;if((Q|0)==0){break}c[R>>2]=c[a+(Q<<2)>>2]}}while(0);R=c[O+12>>2]|0;T=S|R;if(B&R>>>0>268435455){c[N+96>>2]=c[a+(R>>>28<<2)>>2]}Q=N+100|0;do{if(C){if(R<<4>>>0<=268435455){break}c[Q>>2]=c[a+((R>>>24&15)<<2)>>2]}}while(0);Q=N+104|0;do{if(D){if(R<<8>>>0<=268435455){break}c[Q>>2]=c[a+((R>>>20&15)<<2)>>2]}}while(0);Q=N+108|0;do{if(E){if(R<<12>>>0<=268435455){break}c[Q>>2]=c[a+((R>>>16&15)<<2)>>2]}}while(0);Q=N+112|0;do{if(F){if(R<<16>>>0<=268435455){break}c[Q>>2]=c[a+((R>>>12&15)<<2)>>2]}}while(0);Q=N+116|0;do{if(G){if(R<<20>>>0<=268435455){break}c[Q>>2]=c[a+((R>>>8&15)<<2)>>2]}}while(0);Q=N+120|0;do{if(H){if(R<<24>>>0<=268435455){break}c[Q>>2]=c[a+((R>>>4&15)<<2)>>2]}}while(0);if(!I){U=T;break}Q=R&15;if((Q|0)==0){U=T;break}c[N+124>>2]=c[a+(Q<<2)>>2];U=T}else{U=L}}while(0);V=N+b|0;W=O+J|0;if((K|0)>=32){break}K=K+1|0;L=U;M=P;N=V;O=W}c[2113226]=P;c[2112962]=V;c[2112960]=W;return(U|0)==0|0}function afC(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0;a=c[3541654]|0;b=c[2113228]|0;d=(b&536887296|0)==0;e=(b+32767&536887296|0)==0;f=(b+65534&536887296|0)==0;g=(b+98301&536887296|0)==0;h=(b+131068&536887296|0)==0;i=(b+163835&536887296|0)==0;j=(b+196602&536887296|0)==0;k=(b+229369&536887296|0)==0;l=(b+262136&536887296|0)==0;m=(b+294903&536887296|0)==0;n=(b+327670&536887296|0)==0;o=(b+360437&536887296|0)==0;p=(b+393204&536887296|0)==0;q=(b+425971&536887296|0)==0;r=(b+458738&536887296|0)==0;s=(b+491505&536887296|0)==0;t=(b+524272&536887296|0)==0;u=(b+557039&536887296|0)==0;v=(b+589806&536887296|0)==0;w=(b+622573&536887296|0)==0;x=(b+655340&536887296|0)==0;y=(b+688107&536887296|0)==0;z=(b+720874&536887296|0)==0;A=(b+753641&536887296|0)==0;B=(b+786408&536887296|0)==0;C=(b+819175&536887296|0)==0;D=(b+851942&536887296|0)==0;E=(b+884709&536887296|0)==0;F=(b+917476&536887296|0)==0;G=(b+950243&536887296|0)==0;H=(b+983010&536887296|0)==0;I=(b+1015777&536887296|0)==0;b=c[2113300]|0;J=c[2113224]|0;K=1;L=0;M=c[2113226]|0;N=c[2112962]|0;O=c[2112960]|0;while(1){P=M+32767|0;do{if((M&536887296|0)==0){Q=c[O+12>>2]|0;R=Q|L;do{if(d){S=Q&15;if((S|0)==0){break}c[N>>2]=c[a+(S<<2)>>2]}}while(0);S=N+4|0;do{if(e){T=Q>>>4&15;if((T|0)==0){break}c[S>>2]=c[a+(T<<2)>>2]}}while(0);S=N+8|0;do{if(f){T=Q>>>8&15;if((T|0)==0){break}c[S>>2]=c[a+(T<<2)>>2]}}while(0);S=N+12|0;do{if(g){T=Q>>>12&15;if((T|0)==0){break}c[S>>2]=c[a+(T<<2)>>2]}}while(0);S=N+16|0;do{if(h){T=Q>>>16&15;if((T|0)==0){break}c[S>>2]=c[a+(T<<2)>>2]}}while(0);S=N+20|0;do{if(i){T=Q>>>20&15;if((T|0)==0){break}c[S>>2]=c[a+(T<<2)>>2]}}while(0);S=N+24|0;do{if(j){T=Q>>>24&15;if((T|0)==0){break}c[S>>2]=c[a+(T<<2)>>2]}}while(0);S=N+28|0;do{if(k){T=Q>>>28;if((T|0)==0){break}c[S>>2]=c[a+(T<<2)>>2]}}while(0);S=N+32|0;Q=c[O+8>>2]|0;T=R|Q;do{if(l){U=Q&15;if((U|0)==0){break}c[S>>2]=c[a+(U<<2)>>2]}}while(0);S=N+36|0;do{if(m){R=Q>>>4&15;if((R|0)==0){break}c[S>>2]=c[a+(R<<2)>>2]}}while(0);S=N+40|0;do{if(n){R=Q>>>8&15;if((R|0)==0){break}c[S>>2]=c[a+(R<<2)>>2]}}while(0);S=N+44|0;do{if(o){R=Q>>>12&15;if((R|0)==0){break}c[S>>2]=c[a+(R<<2)>>2]}}while(0);S=N+48|0;do{if(p){R=Q>>>16&15;if((R|0)==0){break}c[S>>2]=c[a+(R<<2)>>2]}}while(0);S=N+52|0;do{if(q){R=Q>>>20&15;if((R|0)==0){break}c[S>>2]=c[a+(R<<2)>>2]}}while(0);S=N+56|0;do{if(r){R=Q>>>24&15;if((R|0)==0){break}c[S>>2]=c[a+(R<<2)>>2]}}while(0);S=N+60|0;do{if(s){R=Q>>>28;if((R|0)==0){break}c[S>>2]=c[a+(R<<2)>>2]}}while(0);S=N+64|0;Q=c[O+4>>2]|0;R=T|Q;do{if(t){U=Q&15;if((U|0)==0){break}c[S>>2]=c[a+(U<<2)>>2]}}while(0);S=N+68|0;do{if(u){T=Q>>>4&15;if((T|0)==0){break}c[S>>2]=c[a+(T<<2)>>2]}}while(0);S=N+72|0;do{if(v){T=Q>>>8&15;if((T|0)==0){break}c[S>>2]=c[a+(T<<2)>>2]}}while(0);S=N+76|0;do{if(w){T=Q>>>12&15;if((T|0)==0){break}c[S>>2]=c[a+(T<<2)>>2]}}while(0);S=N+80|0;do{if(x){T=Q>>>16&15;if((T|0)==0){break}c[S>>2]=c[a+(T<<2)>>2]}}while(0);S=N+84|0;do{if(y){T=Q>>>20&15;if((T|0)==0){break}c[S>>2]=c[a+(T<<2)>>2]}}while(0);S=N+88|0;do{if(z){T=Q>>>24&15;if((T|0)==0){break}c[S>>2]=c[a+(T<<2)>>2]}}while(0);S=N+92|0;do{if(A){T=Q>>>28;if((T|0)==0){break}c[S>>2]=c[a+(T<<2)>>2]}}while(0);S=N+96|0;Q=c[O>>2]|0;T=R|Q;do{if(B){U=Q&15;if((U|0)==0){break}c[S>>2]=c[a+(U<<2)>>2]}}while(0);S=N+100|0;do{if(C){R=Q>>>4&15;if((R|0)==0){break}c[S>>2]=c[a+(R<<2)>>2]}}while(0);S=N+104|0;do{if(D){R=Q>>>8&15;if((R|0)==0){break}c[S>>2]=c[a+(R<<2)>>2]}}while(0);S=N+108|0;do{if(E){R=Q>>>12&15;if((R|0)==0){break}c[S>>2]=c[a+(R<<2)>>2]}}while(0);S=N+112|0;do{if(F){R=Q>>>16&15;if((R|0)==0){break}c[S>>2]=c[a+(R<<2)>>2]}}while(0);S=N+116|0;do{if(G){R=Q>>>20&15;if((R|0)==0){break}c[S>>2]=c[a+(R<<2)>>2]}}while(0);S=N+120|0;do{if(H){R=Q>>>24&15;if((R|0)==0){break}c[S>>2]=c[a+(R<<2)>>2]}}while(0);if(!I){V=T;break}S=Q>>>28;if((S|0)==0){V=T;break}c[N+124>>2]=c[a+(S<<2)>>2];V=T}else{V=L}}while(0);W=N+b|0;X=O+J|0;if((K|0)>=32){break}K=K+1|0;L=V;M=P;N=W;O=X}c[2113226]=P;c[2112962]=W;c[2112960]=X;return(V|0)==0|0}function afD(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=c[3541654]|0;d=c[2113300]|0;e=c[2113224]|0;f=c[3541652]|0;g=0;h=0;i=c[2112962]|0;j=c[2112960]|0;do{k=c[j>>2]|0;h=k|h;l=k>>>28;do{if((l|0)!=0){if((f&1<<(l^15)|0)==0){break}m=c[b+(l<<2)>>2]|0;a[i]=m&255;a[i+1|0]=m>>>8&255;a[i+2|0]=m>>>16&255}}while(0);l=i+3|0;m=k&15;n=k>>>24&15;do{if((n|0)!=0){if((f&1<<(n^15)|0)==0){break}o=c[b+(n<<2)>>2]|0;a[l]=o&255;a[i+4|0]=o>>>8&255;a[i+5|0]=o>>>16&255}}while(0);l=i+6|0;n=k>>>20&15;do{if((n|0)!=0){if((f&1<<(n^15)|0)==0){break}o=c[b+(n<<2)>>2]|0;a[l]=o&255;a[i+7|0]=o>>>8&255;a[i+8|0]=o>>>16&255}}while(0);l=i+9|0;n=k>>>16&15;do{if((n|0)!=0){if((f&1<<(n^15)|0)==0){break}o=c[b+(n<<2)>>2]|0;a[l]=o&255;a[i+10|0]=o>>>8&255;a[i+11|0]=o>>>16&255}}while(0);l=i+12|0;n=k>>>12&15;do{if((n|0)!=0){if((f&1<<(n^15)|0)==0){break}o=c[b+(n<<2)>>2]|0;a[l]=o&255;a[i+13|0]=o>>>8&255;a[i+14|0]=o>>>16&255}}while(0);l=i+15|0;n=k>>>8&15;do{if((n|0)!=0){if((f&1<<(n^15)|0)==0){break}o=c[b+(n<<2)>>2]|0;a[l]=o&255;a[i+16|0]=o>>>8&255;a[i+17|0]=o>>>16&255}}while(0);l=i+18|0;n=k>>>4&15;do{if((n|0)!=0){if((f&1<<(n^15)|0)==0){break}o=c[b+(n<<2)>>2]|0;a[l]=o&255;a[i+19|0]=o>>>8&255;a[i+20|0]=o>>>16&255}}while(0);l=i+21|0;do{if((m|0)!=0){if((f&1<<(m^15)|0)==0){break}n=c[b+(m<<2)>>2]|0;a[l]=n&255;a[i+22|0]=n>>>8&255;a[i+23|0]=n>>>16&255}}while(0);g=g+1|0;i=i+d|0;j=j+e|0;}while((g|0)<8);c[2112962]=i;c[2112960]=j;return(h|0)==0|0}function afE(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[3541654]|0;d=c[2113300]|0;e=c[2113224]|0;f=c[3541652]|0;g=0;h=0;i=c[2112962]|0;j=c[2112960]|0;do{k=c[j>>2]|0;h=k|h;l=k&15;do{if((l|0)!=0){if((f&1<<(l^15)|0)==0){break}m=c[b+(l<<2)>>2]|0;a[i]=m&255;a[i+1|0]=m>>>8&255;a[i+2|0]=m>>>16&255}}while(0);l=i+3|0;m=k>>>4&15;do{if((m|0)!=0){if((f&1<<(m^15)|0)==0){break}n=c[b+(m<<2)>>2]|0;a[l]=n&255;a[i+4|0]=n>>>8&255;a[i+5|0]=n>>>16&255}}while(0);l=i+6|0;m=k>>>8&15;do{if((m|0)!=0){if((f&1<<(m^15)|0)==0){break}n=c[b+(m<<2)>>2]|0;a[l]=n&255;a[i+7|0]=n>>>8&255;a[i+8|0]=n>>>16&255}}while(0);l=i+9|0;m=k>>>12&15;do{if((m|0)!=0){if((f&1<<(m^15)|0)==0){break}n=c[b+(m<<2)>>2]|0;a[l]=n&255;a[i+10|0]=n>>>8&255;a[i+11|0]=n>>>16&255}}while(0);l=i+12|0;m=k>>>16&15;do{if((m|0)!=0){if((f&1<<(m^15)|0)==0){break}n=c[b+(m<<2)>>2]|0;a[l]=n&255;a[i+13|0]=n>>>8&255;a[i+14|0]=n>>>16&255}}while(0);l=i+15|0;m=k>>>20&15;do{if((m|0)!=0){if((f&1<<(m^15)|0)==0){break}n=c[b+(m<<2)>>2]|0;a[l]=n&255;a[i+16|0]=n>>>8&255;a[i+17|0]=n>>>16&255}}while(0);l=i+18|0;m=k>>>24&15;do{if((m|0)!=0){if((f&1<<(m^15)|0)==0){break}n=c[b+(m<<2)>>2]|0;a[l]=n&255;a[i+19|0]=n>>>8&255;a[i+20|0]=n>>>16&255}}while(0);l=i+21|0;m=k>>>28;do{if((m|0)!=0){if((f&1<<(m^15)|0)==0){break}n=c[b+(m<<2)>>2]|0;a[l]=n&255;a[i+22|0]=n>>>8&255;a[i+23|0]=n>>>16&255}}while(0);g=g+1|0;i=i+d|0;j=j+e|0;}while((g|0)<8);c[2112962]=i;c[2112960]=j;return(h|0)==0|0}function afF(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;b=c[3541654]|0;d=c[2113228]|0;e=(d&536887296|0)==0;f=c[3541652]|0;g=(d+32767&536887296|0)==0;h=(d+65534&536887296|0)==0;i=(d+98301&536887296|0)==0;j=(d+131068&536887296|0)==0;k=(d+163835&536887296|0)==0;l=(d+196602&536887296|0)==0;m=(d+229369&536887296|0)==0;d=c[2113300]|0;n=c[2113224]|0;o=1;p=0;q=c[2113226]|0;r=c[2112962]|0;s=c[2112960]|0;while(1){t=q+32767|0;do{if((q&536887296|0)==0){u=c[s>>2]|0;v=u|p;do{if(e){w=u>>>28;if((w|0)==0){break}if((f&1<<(w^15)|0)==0){break}x=c[b+(w<<2)>>2]|0;a[r]=x&255;a[r+1|0]=x>>>8&255;a[r+2|0]=x>>>16&255}}while(0);x=r+3|0;do{if(g){w=u>>>24&15;if((w|0)==0){break}if((f&1<<(w^15)|0)==0){break}y=c[b+(w<<2)>>2]|0;a[x]=y&255;a[r+4|0]=y>>>8&255;a[r+5|0]=y>>>16&255}}while(0);x=r+6|0;do{if(h){y=u>>>20&15;if((y|0)==0){break}if((f&1<<(y^15)|0)==0){break}w=c[b+(y<<2)>>2]|0;a[x]=w&255;a[r+7|0]=w>>>8&255;a[r+8|0]=w>>>16&255}}while(0);x=r+9|0;do{if(i){w=u>>>16&15;if((w|0)==0){break}if((f&1<<(w^15)|0)==0){break}y=c[b+(w<<2)>>2]|0;a[x]=y&255;a[r+10|0]=y>>>8&255;a[r+11|0]=y>>>16&255}}while(0);x=r+12|0;do{if(j){y=u>>>12&15;if((y|0)==0){break}if((f&1<<(y^15)|0)==0){break}w=c[b+(y<<2)>>2]|0;a[x]=w&255;a[r+13|0]=w>>>8&255;a[r+14|0]=w>>>16&255}}while(0);x=r+15|0;do{if(k){w=u>>>8&15;if((w|0)==0){break}if((f&1<<(w^15)|0)==0){break}y=c[b+(w<<2)>>2]|0;a[x]=y&255;a[r+16|0]=y>>>8&255;a[r+17|0]=y>>>16&255}}while(0);x=r+18|0;do{if(l){y=u>>>4&15;if((y|0)==0){break}if((f&1<<(y^15)|0)==0){break}w=c[b+(y<<2)>>2]|0;a[x]=w&255;a[r+19|0]=w>>>8&255;a[r+20|0]=w>>>16&255}}while(0);if(!m){z=v;break}x=u&15;if((x|0)==0){z=v;break}if((f&1<<(x^15)|0)==0){z=v;break}w=c[b+(x<<2)>>2]|0;a[r+21|0]=w&255;a[r+22|0]=w>>>8&255;a[r+23|0]=w>>>16&255;z=v}else{z=p}}while(0);A=r+d|0;B=s+n|0;if((o|0)>=8){break}o=o+1|0;p=z;q=t;r=A;s=B}c[2113226]=t;c[2112962]=A;c[2112960]=B;return(z|0)==0|0}function afG(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;b=c[3541654]|0;d=c[2113228]|0;e=(d&536887296|0)==0;f=c[3541652]|0;g=(d+32767&536887296|0)==0;h=(d+65534&536887296|0)==0;i=(d+98301&536887296|0)==0;j=(d+131068&536887296|0)==0;k=(d+163835&536887296|0)==0;l=(d+196602&536887296|0)==0;m=(d+229369&536887296|0)==0;d=c[2113300]|0;n=c[2113224]|0;o=1;p=0;q=c[2113226]|0;r=c[2112962]|0;s=c[2112960]|0;while(1){t=q+32767|0;do{if((q&536887296|0)==0){u=c[s>>2]|0;v=u|p;do{if(e){w=u&15;if((w|0)==0){break}if((f&1<<(w^15)|0)==0){break}x=c[b+(w<<2)>>2]|0;a[r]=x&255;a[r+1|0]=x>>>8&255;a[r+2|0]=x>>>16&255}}while(0);x=r+3|0;do{if(g){w=u>>>4&15;if((w|0)==0){break}if((f&1<<(w^15)|0)==0){break}y=c[b+(w<<2)>>2]|0;a[x]=y&255;a[r+4|0]=y>>>8&255;a[r+5|0]=y>>>16&255}}while(0);x=r+6|0;do{if(h){y=u>>>8&15;if((y|0)==0){break}if((f&1<<(y^15)|0)==0){break}w=c[b+(y<<2)>>2]|0;a[x]=w&255;a[r+7|0]=w>>>8&255;a[r+8|0]=w>>>16&255}}while(0);x=r+9|0;do{if(i){w=u>>>12&15;if((w|0)==0){break}if((f&1<<(w^15)|0)==0){break}y=c[b+(w<<2)>>2]|0;a[x]=y&255;a[r+10|0]=y>>>8&255;a[r+11|0]=y>>>16&255}}while(0);x=r+12|0;do{if(j){y=u>>>16&15;if((y|0)==0){break}if((f&1<<(y^15)|0)==0){break}w=c[b+(y<<2)>>2]|0;a[x]=w&255;a[r+13|0]=w>>>8&255;a[r+14|0]=w>>>16&255}}while(0);x=r+15|0;do{if(k){w=u>>>20&15;if((w|0)==0){break}if((f&1<<(w^15)|0)==0){break}y=c[b+(w<<2)>>2]|0;a[x]=y&255;a[r+16|0]=y>>>8&255;a[r+17|0]=y>>>16&255}}while(0);x=r+18|0;do{if(l){y=u>>>24&15;if((y|0)==0){break}if((f&1<<(y^15)|0)==0){break}w=c[b+(y<<2)>>2]|0;a[x]=w&255;a[r+19|0]=w>>>8&255;a[r+20|0]=w>>>16&255}}while(0);if(!m){z=v;break}x=u>>>28;if((x|0)==0){z=v;break}if((f&1<<(x^15)|0)==0){z=v;break}w=c[b+(x<<2)>>2]|0;a[r+21|0]=w&255;a[r+22|0]=w>>>8&255;a[r+23|0]=w>>>16&255;z=v}else{z=p}}while(0);A=r+d|0;B=s+n|0;if((o|0)>=8){break}o=o+1|0;p=z;q=t;r=A;s=B}c[2113226]=t;c[2112962]=A;c[2112960]=B;return(z|0)==0|0}function afH(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[3541654]|0;d=c[2113300]|0;e=c[2113224]|0;f=c[3541652]|0;g=0;h=0;i=c[2112960]|0;j=c[2112962]|0;do{k=c[i>>2]|0;l=k|h;m=k>>>28;do{if((m|0)!=0){if((f&1<<(m^15)|0)==0){break}n=c[b+(m<<2)>>2]|0;a[j]=n&255;a[j+1|0]=n>>>8&255;a[j+2|0]=n>>>16&255}}while(0);m=j+3|0;n=k&15;o=k>>>24&15;do{if((o|0)!=0){if((f&1<<(o^15)|0)==0){break}p=c[b+(o<<2)>>2]|0;a[m]=p&255;a[j+4|0]=p>>>8&255;a[j+5|0]=p>>>16&255}}while(0);m=j+6|0;o=k>>>20&15;do{if((o|0)!=0){if((f&1<<(o^15)|0)==0){break}p=c[b+(o<<2)>>2]|0;a[m]=p&255;a[j+7|0]=p>>>8&255;a[j+8|0]=p>>>16&255}}while(0);m=j+9|0;o=k>>>16&15;do{if((o|0)!=0){if((f&1<<(o^15)|0)==0){break}p=c[b+(o<<2)>>2]|0;a[m]=p&255;a[j+10|0]=p>>>8&255;a[j+11|0]=p>>>16&255}}while(0);m=j+12|0;o=k>>>12&15;do{if((o|0)!=0){if((f&1<<(o^15)|0)==0){break}p=c[b+(o<<2)>>2]|0;a[m]=p&255;a[j+13|0]=p>>>8&255;a[j+14|0]=p>>>16&255}}while(0);m=j+15|0;o=k>>>8&15;do{if((o|0)!=0){if((f&1<<(o^15)|0)==0){break}p=c[b+(o<<2)>>2]|0;a[m]=p&255;a[j+16|0]=p>>>8&255;a[j+17|0]=p>>>16&255}}while(0);m=j+18|0;o=k>>>4&15;do{if((o|0)!=0){if((f&1<<(o^15)|0)==0){break}p=c[b+(o<<2)>>2]|0;a[m]=p&255;a[j+19|0]=p>>>8&255;a[j+20|0]=p>>>16&255}}while(0);m=j+21|0;do{if((n|0)!=0){if((f&1<<(n^15)|0)==0){break}o=c[b+(n<<2)>>2]|0;a[m]=o&255;a[j+22|0]=o>>>8&255;a[j+23|0]=o>>>16&255}}while(0);m=j+24|0;n=c[i+4>>2]|0;h=l|n;o=n>>>28;do{if((o|0)!=0){if((f&1<<(o^15)|0)==0){break}k=c[b+(o<<2)>>2]|0;a[m]=k&255;a[j+25|0]=k>>>8&255;a[j+26|0]=k>>>16&255}}while(0);m=j+27|0;o=n&15;l=n>>>24&15;do{if((l|0)!=0){if((f&1<<(l^15)|0)==0){break}k=c[b+(l<<2)>>2]|0;a[m]=k&255;a[j+28|0]=k>>>8&255;a[j+29|0]=k>>>16&255}}while(0);m=j+30|0;l=n>>>20&15;do{if((l|0)!=0){if((f&1<<(l^15)|0)==0){break}k=c[b+(l<<2)>>2]|0;a[m]=k&255;a[j+31|0]=k>>>8&255;a[j+32|0]=k>>>16&255}}while(0);m=j+33|0;l=n>>>16&15;do{if((l|0)!=0){if((f&1<<(l^15)|0)==0){break}k=c[b+(l<<2)>>2]|0;a[m]=k&255;a[j+34|0]=k>>>8&255;a[j+35|0]=k>>>16&255}}while(0);m=j+36|0;l=n>>>12&15;do{if((l|0)!=0){if((f&1<<(l^15)|0)==0){break}k=c[b+(l<<2)>>2]|0;a[m]=k&255;a[j+37|0]=k>>>8&255;a[j+38|0]=k>>>16&255}}while(0);m=j+39|0;l=n>>>8&15;do{if((l|0)!=0){if((f&1<<(l^15)|0)==0){break}k=c[b+(l<<2)>>2]|0;a[m]=k&255;a[j+40|0]=k>>>8&255;a[j+41|0]=k>>>16&255}}while(0);m=j+42|0;l=n>>>4&15;do{if((l|0)!=0){if((f&1<<(l^15)|0)==0){break}k=c[b+(l<<2)>>2]|0;a[m]=k&255;a[j+43|0]=k>>>8&255;a[j+44|0]=k>>>16&255}}while(0);m=j+45|0;do{if((o|0)!=0){if((f&1<<(o^15)|0)==0){break}l=c[b+(o<<2)>>2]|0;a[m]=l&255;a[j+46|0]=l>>>8&255;a[j+47|0]=l>>>16&255}}while(0);g=g+1|0;j=j+d|0;i=i+e|0;}while((g|0)<16);c[2112960]=i;c[2112962]=j;return(h|0)==0|0}function afI(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=c[3541654]|0;d=c[2113300]|0;e=c[2113224]|0;f=c[3541652]|0;g=0;h=0;i=c[2112960]|0;j=c[2112962]|0;do{k=c[i+4>>2]|0;l=k|h;m=k&15;do{if((m|0)!=0){if((f&1<<(m^15)|0)==0){break}n=c[b+(m<<2)>>2]|0;a[j]=n&255;a[j+1|0]=n>>>8&255;a[j+2|0]=n>>>16&255}}while(0);m=j+3|0;n=k>>>4&15;do{if((n|0)!=0){if((f&1<<(n^15)|0)==0){break}o=c[b+(n<<2)>>2]|0;a[m]=o&255;a[j+4|0]=o>>>8&255;a[j+5|0]=o>>>16&255}}while(0);m=j+6|0;n=k>>>8&15;do{if((n|0)!=0){if((f&1<<(n^15)|0)==0){break}o=c[b+(n<<2)>>2]|0;a[m]=o&255;a[j+7|0]=o>>>8&255;a[j+8|0]=o>>>16&255}}while(0);m=j+9|0;n=k>>>12&15;do{if((n|0)!=0){if((f&1<<(n^15)|0)==0){break}o=c[b+(n<<2)>>2]|0;a[m]=o&255;a[j+10|0]=o>>>8&255;a[j+11|0]=o>>>16&255}}while(0);m=j+12|0;n=k>>>16&15;do{if((n|0)!=0){if((f&1<<(n^15)|0)==0){break}o=c[b+(n<<2)>>2]|0;a[m]=o&255;a[j+13|0]=o>>>8&255;a[j+14|0]=o>>>16&255}}while(0);m=j+15|0;n=k>>>20&15;do{if((n|0)!=0){if((f&1<<(n^15)|0)==0){break}o=c[b+(n<<2)>>2]|0;a[m]=o&255;a[j+16|0]=o>>>8&255;a[j+17|0]=o>>>16&255}}while(0);m=j+18|0;n=k>>>24&15;do{if((n|0)!=0){if((f&1<<(n^15)|0)==0){break}o=c[b+(n<<2)>>2]|0;a[m]=o&255;a[j+19|0]=o>>>8&255;a[j+20|0]=o>>>16&255}}while(0);m=j+21|0;n=k>>>28;do{if((n|0)!=0){if((f&1<<(n^15)|0)==0){break}o=c[b+(n<<2)>>2]|0;a[m]=o&255;a[j+22|0]=o>>>8&255;a[j+23|0]=o>>>16&255}}while(0);m=j+24|0;n=c[i>>2]|0;h=l|n;k=n&15;do{if((k|0)!=0){if((f&1<<(k^15)|0)==0){break}o=c[b+(k<<2)>>2]|0;a[m]=o&255;a[j+25|0]=o>>>8&255;a[j+26|0]=o>>>16&255}}while(0);m=j+27|0;k=n>>>4&15;do{if((k|0)!=0){if((f&1<<(k^15)|0)==0){break}l=c[b+(k<<2)>>2]|0;a[m]=l&255;a[j+28|0]=l>>>8&255;a[j+29|0]=l>>>16&255}}while(0);m=j+30|0;k=n>>>8&15;do{if((k|0)!=0){if((f&1<<(k^15)|0)==0){break}l=c[b+(k<<2)>>2]|0;a[m]=l&255;a[j+31|0]=l>>>8&255;a[j+32|0]=l>>>16&255}}while(0);m=j+33|0;k=n>>>12&15;do{if((k|0)!=0){if((f&1<<(k^15)|0)==0){break}l=c[b+(k<<2)>>2]|0;a[m]=l&255;a[j+34|0]=l>>>8&255;a[j+35|0]=l>>>16&255}}while(0);m=j+36|0;k=n>>>16&15;do{if((k|0)!=0){if((f&1<<(k^15)|0)==0){break}l=c[b+(k<<2)>>2]|0;a[m]=l&255;a[j+37|0]=l>>>8&255;a[j+38|0]=l>>>16&255}}while(0);m=j+39|0;k=n>>>20&15;do{if((k|0)!=0){if((f&1<<(k^15)|0)==0){break}l=c[b+(k<<2)>>2]|0;a[m]=l&255;a[j+40|0]=l>>>8&255;a[j+41|0]=l>>>16&255}}while(0);m=j+42|0;k=n>>>24&15;do{if((k|0)!=0){if((f&1<<(k^15)|0)==0){break}l=c[b+(k<<2)>>2]|0;a[m]=l&255;a[j+43|0]=l>>>8&255;a[j+44|0]=l>>>16&255}}while(0);m=j+45|0;k=n>>>28;do{if((k|0)!=0){if((f&1<<(k^15)|0)==0){break}l=c[b+(k<<2)>>2]|0;a[m]=l&255;a[j+46|0]=l>>>8&255;a[j+47|0]=l>>>16&255}}while(0);g=g+1|0;j=j+d|0;i=i+e|0;}while((g|0)<16);c[2112960]=i;c[2112962]=j;return(h|0)==0|0}function afJ(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;b=c[3541654]|0;d=c[2113228]|0;e=(d&536887296|0)==0;f=c[3541652]|0;g=(d+32767&536887296|0)==0;h=(d+65534&536887296|0)==0;i=(d+98301&536887296|0)==0;j=(d+131068&536887296|0)==0;k=(d+163835&536887296|0)==0;l=(d+196602&536887296|0)==0;m=(d+229369&536887296|0)==0;n=(d+262136&536887296|0)==0;o=(d+294903&536887296|0)==0;p=(d+327670&536887296|0)==0;q=(d+360437&536887296|0)==0;r=(d+393204&536887296|0)==0;s=(d+425971&536887296|0)==0;t=(d+458738&536887296|0)==0;u=(d+491505&536887296|0)==0;d=c[2113300]|0;v=c[2113224]|0;w=1;x=0;y=c[2113226]|0;z=c[2112962]|0;A=c[2112960]|0;while(1){B=y+32767|0;do{if((y&536887296|0)==0){C=c[A>>2]|0;D=C|x;do{if(e){E=C>>>28;if((E|0)==0){break}if((f&1<<(E^15)|0)==0){break}F=c[b+(E<<2)>>2]|0;a[z]=F&255;a[z+1|0]=F>>>8&255;a[z+2|0]=F>>>16&255}}while(0);F=z+3|0;do{if(g){E=C>>>24&15;if((E|0)==0){break}if((f&1<<(E^15)|0)==0){break}G=c[b+(E<<2)>>2]|0;a[F]=G&255;a[z+4|0]=G>>>8&255;a[z+5|0]=G>>>16&255}}while(0);F=z+6|0;do{if(h){G=C>>>20&15;if((G|0)==0){break}if((f&1<<(G^15)|0)==0){break}E=c[b+(G<<2)>>2]|0;a[F]=E&255;a[z+7|0]=E>>>8&255;a[z+8|0]=E>>>16&255}}while(0);F=z+9|0;do{if(i){E=C>>>16&15;if((E|0)==0){break}if((f&1<<(E^15)|0)==0){break}G=c[b+(E<<2)>>2]|0;a[F]=G&255;a[z+10|0]=G>>>8&255;a[z+11|0]=G>>>16&255}}while(0);F=z+12|0;do{if(j){G=C>>>12&15;if((G|0)==0){break}if((f&1<<(G^15)|0)==0){break}E=c[b+(G<<2)>>2]|0;a[F]=E&255;a[z+13|0]=E>>>8&255;a[z+14|0]=E>>>16&255}}while(0);F=z+15|0;do{if(k){E=C>>>8&15;if((E|0)==0){break}if((f&1<<(E^15)|0)==0){break}G=c[b+(E<<2)>>2]|0;a[F]=G&255;a[z+16|0]=G>>>8&255;a[z+17|0]=G>>>16&255}}while(0);F=z+18|0;do{if(l){G=C>>>4&15;if((G|0)==0){break}if((f&1<<(G^15)|0)==0){break}E=c[b+(G<<2)>>2]|0;a[F]=E&255;a[z+19|0]=E>>>8&255;a[z+20|0]=E>>>16&255}}while(0);F=z+21|0;do{if(m){E=C&15;if((E|0)==0){break}if((f&1<<(E^15)|0)==0){break}G=c[b+(E<<2)>>2]|0;a[F]=G&255;a[z+22|0]=G>>>8&255;a[z+23|0]=G>>>16&255}}while(0);F=z+24|0;C=c[A+4>>2]|0;G=D|C;do{if(n){E=C>>>28;if((E|0)==0){break}if((f&1<<(E^15)|0)==0){break}H=c[b+(E<<2)>>2]|0;a[F]=H&255;a[z+25|0]=H>>>8&255;a[z+26|0]=H>>>16&255}}while(0);F=z+27|0;do{if(o){D=C>>>24&15;if((D|0)==0){break}if((f&1<<(D^15)|0)==0){break}H=c[b+(D<<2)>>2]|0;a[F]=H&255;a[z+28|0]=H>>>8&255;a[z+29|0]=H>>>16&255}}while(0);F=z+30|0;do{if(p){H=C>>>20&15;if((H|0)==0){break}if((f&1<<(H^15)|0)==0){break}D=c[b+(H<<2)>>2]|0;a[F]=D&255;a[z+31|0]=D>>>8&255;a[z+32|0]=D>>>16&255}}while(0);F=z+33|0;do{if(q){D=C>>>16&15;if((D|0)==0){break}if((f&1<<(D^15)|0)==0){break}H=c[b+(D<<2)>>2]|0;a[F]=H&255;a[z+34|0]=H>>>8&255;a[z+35|0]=H>>>16&255}}while(0);F=z+36|0;do{if(r){H=C>>>12&15;if((H|0)==0){break}if((f&1<<(H^15)|0)==0){break}D=c[b+(H<<2)>>2]|0;a[F]=D&255;a[z+37|0]=D>>>8&255;a[z+38|0]=D>>>16&255}}while(0);F=z+39|0;do{if(s){D=C>>>8&15;if((D|0)==0){break}if((f&1<<(D^15)|0)==0){break}H=c[b+(D<<2)>>2]|0;a[F]=H&255;a[z+40|0]=H>>>8&255;a[z+41|0]=H>>>16&255}}while(0);F=z+42|0;do{if(t){H=C>>>4&15;if((H|0)==0){break}if((f&1<<(H^15)|0)==0){break}D=c[b+(H<<2)>>2]|0;a[F]=D&255;a[z+43|0]=D>>>8&255;a[z+44|0]=D>>>16&255}}while(0);if(!u){I=G;break}F=C&15;if((F|0)==0){I=G;break}if((f&1<<(F^15)|0)==0){I=G;break}D=c[b+(F<<2)>>2]|0;a[z+45|0]=D&255;a[z+46|0]=D>>>8&255;a[z+47|0]=D>>>16&255;I=G}else{I=x}}while(0);J=z+d|0;K=A+v|0;if((w|0)>=16){break}w=w+1|0;x=I;y=B;z=J;A=K}c[2113226]=B;c[2112962]=J;c[2112960]=K;return(I|0)==0|0}function afK(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;b=c[3541654]|0;d=c[2113228]|0;e=(d&536887296|0)==0;f=c[3541652]|0;g=(d+32767&536887296|0)==0;h=(d+65534&536887296|0)==0;i=(d+98301&536887296|0)==0;j=(d+131068&536887296|0)==0;k=(d+163835&536887296|0)==0;l=(d+196602&536887296|0)==0;m=(d+229369&536887296|0)==0;n=(d+262136&536887296|0)==0;o=(d+294903&536887296|0)==0;p=(d+327670&536887296|0)==0;q=(d+360437&536887296|0)==0;r=(d+393204&536887296|0)==0;s=(d+425971&536887296|0)==0;t=(d+458738&536887296|0)==0;u=(d+491505&536887296|0)==0;d=c[2113300]|0;v=c[2113224]|0;w=1;x=0;y=c[2113226]|0;z=c[2112962]|0;A=c[2112960]|0;while(1){B=y+32767|0;do{if((y&536887296|0)==0){C=c[A+4>>2]|0;D=C|x;do{if(e){E=C&15;if((E|0)==0){break}if((f&1<<(E^15)|0)==0){break}F=c[b+(E<<2)>>2]|0;a[z]=F&255;a[z+1|0]=F>>>8&255;a[z+2|0]=F>>>16&255}}while(0);F=z+3|0;do{if(g){E=C>>>4&15;if((E|0)==0){break}if((f&1<<(E^15)|0)==0){break}G=c[b+(E<<2)>>2]|0;a[F]=G&255;a[z+4|0]=G>>>8&255;a[z+5|0]=G>>>16&255}}while(0);F=z+6|0;do{if(h){G=C>>>8&15;if((G|0)==0){break}if((f&1<<(G^15)|0)==0){break}E=c[b+(G<<2)>>2]|0;a[F]=E&255;a[z+7|0]=E>>>8&255;a[z+8|0]=E>>>16&255}}while(0);F=z+9|0;do{if(i){E=C>>>12&15;if((E|0)==0){break}if((f&1<<(E^15)|0)==0){break}G=c[b+(E<<2)>>2]|0;a[F]=G&255;a[z+10|0]=G>>>8&255;a[z+11|0]=G>>>16&255}}while(0);F=z+12|0;do{if(j){G=C>>>16&15;if((G|0)==0){break}if((f&1<<(G^15)|0)==0){break}E=c[b+(G<<2)>>2]|0;a[F]=E&255;a[z+13|0]=E>>>8&255;a[z+14|0]=E>>>16&255}}while(0);F=z+15|0;do{if(k){E=C>>>20&15;if((E|0)==0){break}if((f&1<<(E^15)|0)==0){break}G=c[b+(E<<2)>>2]|0;a[F]=G&255;a[z+16|0]=G>>>8&255;a[z+17|0]=G>>>16&255}}while(0);F=z+18|0;do{if(l){G=C>>>24&15;if((G|0)==0){break}if((f&1<<(G^15)|0)==0){break}E=c[b+(G<<2)>>2]|0;a[F]=E&255;a[z+19|0]=E>>>8&255;a[z+20|0]=E>>>16&255}}while(0);F=z+21|0;do{if(m){E=C>>>28;if((E|0)==0){break}if((f&1<<(E^15)|0)==0){break}G=c[b+(E<<2)>>2]|0;a[F]=G&255;a[z+22|0]=G>>>8&255;a[z+23|0]=G>>>16&255}}while(0);F=z+24|0;C=c[A>>2]|0;G=D|C;do{if(n){E=C&15;if((E|0)==0){break}if((f&1<<(E^15)|0)==0){break}H=c[b+(E<<2)>>2]|0;a[F]=H&255;a[z+25|0]=H>>>8&255;a[z+26|0]=H>>>16&255}}while(0);F=z+27|0;do{if(o){D=C>>>4&15;if((D|0)==0){break}if((f&1<<(D^15)|0)==0){break}H=c[b+(D<<2)>>2]|0;a[F]=H&255;a[z+28|0]=H>>>8&255;a[z+29|0]=H>>>16&255}}while(0);F=z+30|0;do{if(p){H=C>>>8&15;if((H|0)==0){break}if((f&1<<(H^15)|0)==0){break}D=c[b+(H<<2)>>2]|0;a[F]=D&255;a[z+31|0]=D>>>8&255;a[z+32|0]=D>>>16&255}}while(0);F=z+33|0;do{if(q){D=C>>>12&15;if((D|0)==0){break}if((f&1<<(D^15)|0)==0){break}H=c[b+(D<<2)>>2]|0;a[F]=H&255;a[z+34|0]=H>>>8&255;a[z+35|0]=H>>>16&255}}while(0);F=z+36|0;do{if(r){H=C>>>16&15;if((H|0)==0){break}if((f&1<<(H^15)|0)==0){break}D=c[b+(H<<2)>>2]|0;a[F]=D&255;a[z+37|0]=D>>>8&255;a[z+38|0]=D>>>16&255}}while(0);F=z+39|0;do{if(s){D=C>>>20&15;if((D|0)==0){break}if((f&1<<(D^15)|0)==0){break}H=c[b+(D<<2)>>2]|0;a[F]=H&255;a[z+40|0]=H>>>8&255;a[z+41|0]=H>>>16&255}}while(0);F=z+42|0;do{if(t){H=C>>>24&15;if((H|0)==0){break}if((f&1<<(H^15)|0)==0){break}D=c[b+(H<<2)>>2]|0;a[F]=D&255;a[z+43|0]=D>>>8&255;a[z+44|0]=D>>>16&255}}while(0);if(!u){I=G;break}F=C>>>28;if((F|0)==0){I=G;break}if((f&1<<(F^15)|0)==0){I=G;break}D=c[b+(F<<2)>>2]|0;a[z+45|0]=D&255;a[z+46|0]=D>>>8&255;a[z+47|0]=D>>>16&255;I=G}else{I=x}}while(0);J=z+d|0;K=A+v|0;if((w|0)>=16){break}w=w+1|0;x=I;y=B;z=J;A=K}c[2113226]=B;c[2112962]=J;c[2112960]=K;return(I|0)==0|0}function afL(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[3541654]|0;d=c[2113300]|0;e=c[2113224]|0;f=c[3541652]|0;g=0;h=0;i=c[2112960]|0;j=c[2112962]|0;do{k=c[i>>2]|0;l=k|h;m=k>>>28;do{if((m|0)!=0){if((f&1<<(m^15)|0)==0){break}n=c[b+(m<<2)>>2]|0;a[j]=n&255;a[j+1|0]=n>>>8&255;a[j+2|0]=n>>>16&255}}while(0);m=j+3|0;n=k&15;o=k>>>24&15;do{if((o|0)!=0){if((f&1<<(o^15)|0)==0){break}p=c[b+(o<<2)>>2]|0;a[m]=p&255;a[j+4|0]=p>>>8&255;a[j+5|0]=p>>>16&255}}while(0);m=j+6|0;o=k>>>20&15;do{if((o|0)!=0){if((f&1<<(o^15)|0)==0){break}p=c[b+(o<<2)>>2]|0;a[m]=p&255;a[j+7|0]=p>>>8&255;a[j+8|0]=p>>>16&255}}while(0);m=j+9|0;o=k>>>16&15;do{if((o|0)!=0){if((f&1<<(o^15)|0)==0){break}p=c[b+(o<<2)>>2]|0;a[m]=p&255;a[j+10|0]=p>>>8&255;a[j+11|0]=p>>>16&255}}while(0);m=j+12|0;o=k>>>12&15;do{if((o|0)!=0){if((f&1<<(o^15)|0)==0){break}p=c[b+(o<<2)>>2]|0;a[m]=p&255;a[j+13|0]=p>>>8&255;a[j+14|0]=p>>>16&255}}while(0);m=j+15|0;o=k>>>8&15;do{if((o|0)!=0){if((f&1<<(o^15)|0)==0){break}p=c[b+(o<<2)>>2]|0;a[m]=p&255;a[j+16|0]=p>>>8&255;a[j+17|0]=p>>>16&255}}while(0);m=j+18|0;o=k>>>4&15;do{if((o|0)!=0){if((f&1<<(o^15)|0)==0){break}p=c[b+(o<<2)>>2]|0;a[m]=p&255;a[j+19|0]=p>>>8&255;a[j+20|0]=p>>>16&255}}while(0);m=j+21|0;do{if((n|0)!=0){if((f&1<<(n^15)|0)==0){break}o=c[b+(n<<2)>>2]|0;a[m]=o&255;a[j+22|0]=o>>>8&255;a[j+23|0]=o>>>16&255}}while(0);m=j+24|0;n=c[i+4>>2]|0;o=l|n;k=n>>>28;do{if((k|0)!=0){if((f&1<<(k^15)|0)==0){break}p=c[b+(k<<2)>>2]|0;a[m]=p&255;a[j+25|0]=p>>>8&255;a[j+26|0]=p>>>16&255}}while(0);m=j+27|0;k=n&15;l=n>>>24&15;do{if((l|0)!=0){if((f&1<<(l^15)|0)==0){break}p=c[b+(l<<2)>>2]|0;a[m]=p&255;a[j+28|0]=p>>>8&255;a[j+29|0]=p>>>16&255}}while(0);m=j+30|0;l=n>>>20&15;do{if((l|0)!=0){if((f&1<<(l^15)|0)==0){break}p=c[b+(l<<2)>>2]|0;a[m]=p&255;a[j+31|0]=p>>>8&255;a[j+32|0]=p>>>16&255}}while(0);m=j+33|0;l=n>>>16&15;do{if((l|0)!=0){if((f&1<<(l^15)|0)==0){break}p=c[b+(l<<2)>>2]|0;a[m]=p&255;a[j+34|0]=p>>>8&255;a[j+35|0]=p>>>16&255}}while(0);m=j+36|0;l=n>>>12&15;do{if((l|0)!=0){if((f&1<<(l^15)|0)==0){break}p=c[b+(l<<2)>>2]|0;a[m]=p&255;a[j+37|0]=p>>>8&255;a[j+38|0]=p>>>16&255}}while(0);m=j+39|0;l=n>>>8&15;do{if((l|0)!=0){if((f&1<<(l^15)|0)==0){break}p=c[b+(l<<2)>>2]|0;a[m]=p&255;a[j+40|0]=p>>>8&255;a[j+41|0]=p>>>16&255}}while(0);m=j+42|0;l=n>>>4&15;do{if((l|0)!=0){if((f&1<<(l^15)|0)==0){break}p=c[b+(l<<2)>>2]|0;a[m]=p&255;a[j+43|0]=p>>>8&255;a[j+44|0]=p>>>16&255}}while(0);m=j+45|0;do{if((k|0)!=0){if((f&1<<(k^15)|0)==0){break}l=c[b+(k<<2)>>2]|0;a[m]=l&255;a[j+46|0]=l>>>8&255;a[j+47|0]=l>>>16&255}}while(0);m=j+48|0;k=c[i+8>>2]|0;l=o|k;n=k>>>28;do{if((n|0)!=0){if((f&1<<(n^15)|0)==0){break}p=c[b+(n<<2)>>2]|0;a[m]=p&255;a[j+49|0]=p>>>8&255;a[j+50|0]=p>>>16&255}}while(0);m=j+51|0;n=k&15;o=k>>>24&15;do{if((o|0)!=0){if((f&1<<(o^15)|0)==0){break}p=c[b+(o<<2)>>2]|0;a[m]=p&255;a[j+52|0]=p>>>8&255;a[j+53|0]=p>>>16&255}}while(0);m=j+54|0;o=k>>>20&15;do{if((o|0)!=0){if((f&1<<(o^15)|0)==0){break}p=c[b+(o<<2)>>2]|0;a[m]=p&255;a[j+55|0]=p>>>8&255;a[j+56|0]=p>>>16&255}}while(0);m=j+57|0;o=k>>>16&15;do{if((o|0)!=0){if((f&1<<(o^15)|0)==0){break}p=c[b+(o<<2)>>2]|0;a[m]=p&255;a[j+58|0]=p>>>8&255;a[j+59|0]=p>>>16&255}}while(0);m=j+60|0;o=k>>>12&15;do{if((o|0)!=0){if((f&1<<(o^15)|0)==0){break}p=c[b+(o<<2)>>2]|0;a[m]=p&255;a[j+61|0]=p>>>8&255;a[j+62|0]=p>>>16&255}}while(0);m=j+63|0;o=k>>>8&15;do{if((o|0)!=0){if((f&1<<(o^15)|0)==0){break}p=c[b+(o<<2)>>2]|0;a[m]=p&255;a[j+64|0]=p>>>8&255;a[j+65|0]=p>>>16&255}}while(0);m=j+66|0;o=k>>>4&15;do{if((o|0)!=0){if((f&1<<(o^15)|0)==0){break}p=c[b+(o<<2)>>2]|0;a[m]=p&255;a[j+67|0]=p>>>8&255;a[j+68|0]=p>>>16&255}}while(0);m=j+69|0;do{if((n|0)!=0){if((f&1<<(n^15)|0)==0){break}o=c[b+(n<<2)>>2]|0;a[m]=o&255;a[j+70|0]=o>>>8&255;a[j+71|0]=o>>>16&255}}while(0);m=j+72|0;n=c[i+12>>2]|0;h=l|n;o=n>>>28;do{if((o|0)!=0){if((f&1<<(o^15)|0)==0){break}k=c[b+(o<<2)>>2]|0;a[m]=k&255;a[j+73|0]=k>>>8&255;a[j+74|0]=k>>>16&255}}while(0);m=j+75|0;o=n&15;l=n>>>24&15;do{if((l|0)!=0){if((f&1<<(l^15)|0)==0){break}k=c[b+(l<<2)>>2]|0;a[m]=k&255;a[j+76|0]=k>>>8&255;a[j+77|0]=k>>>16&255}}while(0);m=j+78|0;l=n>>>20&15;do{if((l|0)!=0){if((f&1<<(l^15)|0)==0){break}k=c[b+(l<<2)>>2]|0;a[m]=k&255;a[j+79|0]=k>>>8&255;a[j+80|0]=k>>>16&255}}while(0);m=j+81|0;l=n>>>16&15;do{if((l|0)!=0){if((f&1<<(l^15)|0)==0){break}k=c[b+(l<<2)>>2]|0;a[m]=k&255;a[j+82|0]=k>>>8&255;a[j+83|0]=k>>>16&255}}while(0);m=j+84|0;l=n>>>12&15;do{if((l|0)!=0){if((f&1<<(l^15)|0)==0){break}k=c[b+(l<<2)>>2]|0;a[m]=k&255;a[j+85|0]=k>>>8&255;a[j+86|0]=k>>>16&255}}while(0);m=j+87|0;l=n>>>8&15;do{if((l|0)!=0){if((f&1<<(l^15)|0)==0){break}k=c[b+(l<<2)>>2]|0;a[m]=k&255;a[j+88|0]=k>>>8&255;a[j+89|0]=k>>>16&255}}while(0);m=j+90|0;l=n>>>4&15;do{if((l|0)!=0){if((f&1<<(l^15)|0)==0){break}k=c[b+(l<<2)>>2]|0;a[m]=k&255;a[j+91|0]=k>>>8&255;a[j+92|0]=k>>>16&255}}while(0);m=j+93|0;do{if((o|0)!=0){if((f&1<<(o^15)|0)==0){break}l=c[b+(o<<2)>>2]|0;a[m]=l&255;a[j+94|0]=l>>>8&255;a[j+95|0]=l>>>16&255}}while(0);g=g+1|0;j=j+d|0;i=i+e|0;}while((g|0)<32);c[2112960]=i;c[2112962]=j;return(h|0)==0|0}function afM(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[3541654]|0;d=c[2113300]|0;e=c[2113224]|0;f=c[3541652]|0;g=0;h=0;i=c[2112960]|0;j=c[2112962]|0;do{k=c[i+12>>2]|0;l=k|h;m=k&15;do{if((m|0)!=0){if((f&1<<(m^15)|0)==0){break}n=c[b+(m<<2)>>2]|0;a[j]=n&255;a[j+1|0]=n>>>8&255;a[j+2|0]=n>>>16&255}}while(0);m=j+3|0;n=k>>>4&15;do{if((n|0)!=0){if((f&1<<(n^15)|0)==0){break}o=c[b+(n<<2)>>2]|0;a[m]=o&255;a[j+4|0]=o>>>8&255;a[j+5|0]=o>>>16&255}}while(0);m=j+6|0;n=k>>>8&15;do{if((n|0)!=0){if((f&1<<(n^15)|0)==0){break}o=c[b+(n<<2)>>2]|0;a[m]=o&255;a[j+7|0]=o>>>8&255;a[j+8|0]=o>>>16&255}}while(0);m=j+9|0;n=k>>>12&15;do{if((n|0)!=0){if((f&1<<(n^15)|0)==0){break}o=c[b+(n<<2)>>2]|0;a[m]=o&255;a[j+10|0]=o>>>8&255;a[j+11|0]=o>>>16&255}}while(0);m=j+12|0;n=k>>>16&15;do{if((n|0)!=0){if((f&1<<(n^15)|0)==0){break}o=c[b+(n<<2)>>2]|0;a[m]=o&255;a[j+13|0]=o>>>8&255;a[j+14|0]=o>>>16&255}}while(0);m=j+15|0;n=k>>>20&15;do{if((n|0)!=0){if((f&1<<(n^15)|0)==0){break}o=c[b+(n<<2)>>2]|0;a[m]=o&255;a[j+16|0]=o>>>8&255;a[j+17|0]=o>>>16&255}}while(0);m=j+18|0;n=k>>>24&15;do{if((n|0)!=0){if((f&1<<(n^15)|0)==0){break}o=c[b+(n<<2)>>2]|0;a[m]=o&255;a[j+19|0]=o>>>8&255;a[j+20|0]=o>>>16&255}}while(0);m=j+21|0;n=k>>>28;do{if((n|0)!=0){if((f&1<<(n^15)|0)==0){break}o=c[b+(n<<2)>>2]|0;a[m]=o&255;a[j+22|0]=o>>>8&255;a[j+23|0]=o>>>16&255}}while(0);m=j+24|0;n=c[i+8>>2]|0;k=l|n;o=n&15;do{if((o|0)!=0){if((f&1<<(o^15)|0)==0){break}p=c[b+(o<<2)>>2]|0;a[m]=p&255;a[j+25|0]=p>>>8&255;a[j+26|0]=p>>>16&255}}while(0);m=j+27|0;o=n>>>4&15;do{if((o|0)!=0){if((f&1<<(o^15)|0)==0){break}l=c[b+(o<<2)>>2]|0;a[m]=l&255;a[j+28|0]=l>>>8&255;a[j+29|0]=l>>>16&255}}while(0);m=j+30|0;o=n>>>8&15;do{if((o|0)!=0){if((f&1<<(o^15)|0)==0){break}l=c[b+(o<<2)>>2]|0;a[m]=l&255;a[j+31|0]=l>>>8&255;a[j+32|0]=l>>>16&255}}while(0);m=j+33|0;o=n>>>12&15;do{if((o|0)!=0){if((f&1<<(o^15)|0)==0){break}l=c[b+(o<<2)>>2]|0;a[m]=l&255;a[j+34|0]=l>>>8&255;a[j+35|0]=l>>>16&255}}while(0);m=j+36|0;o=n>>>16&15;do{if((o|0)!=0){if((f&1<<(o^15)|0)==0){break}l=c[b+(o<<2)>>2]|0;a[m]=l&255;a[j+37|0]=l>>>8&255;a[j+38|0]=l>>>16&255}}while(0);m=j+39|0;o=n>>>20&15;do{if((o|0)!=0){if((f&1<<(o^15)|0)==0){break}l=c[b+(o<<2)>>2]|0;a[m]=l&255;a[j+40|0]=l>>>8&255;a[j+41|0]=l>>>16&255}}while(0);m=j+42|0;o=n>>>24&15;do{if((o|0)!=0){if((f&1<<(o^15)|0)==0){break}l=c[b+(o<<2)>>2]|0;a[m]=l&255;a[j+43|0]=l>>>8&255;a[j+44|0]=l>>>16&255}}while(0);m=j+45|0;o=n>>>28;do{if((o|0)!=0){if((f&1<<(o^15)|0)==0){break}l=c[b+(o<<2)>>2]|0;a[m]=l&255;a[j+46|0]=l>>>8&255;a[j+47|0]=l>>>16&255}}while(0);m=j+48|0;o=c[i+4>>2]|0;n=k|o;l=o&15;do{if((l|0)!=0){if((f&1<<(l^15)|0)==0){break}p=c[b+(l<<2)>>2]|0;a[m]=p&255;a[j+49|0]=p>>>8&255;a[j+50|0]=p>>>16&255}}while(0);m=j+51|0;l=o>>>4&15;do{if((l|0)!=0){if((f&1<<(l^15)|0)==0){break}k=c[b+(l<<2)>>2]|0;a[m]=k&255;a[j+52|0]=k>>>8&255;a[j+53|0]=k>>>16&255}}while(0);m=j+54|0;l=o>>>8&15;do{if((l|0)!=0){if((f&1<<(l^15)|0)==0){break}k=c[b+(l<<2)>>2]|0;a[m]=k&255;a[j+55|0]=k>>>8&255;a[j+56|0]=k>>>16&255}}while(0);m=j+57|0;l=o>>>12&15;do{if((l|0)!=0){if((f&1<<(l^15)|0)==0){break}k=c[b+(l<<2)>>2]|0;a[m]=k&255;a[j+58|0]=k>>>8&255;a[j+59|0]=k>>>16&255}}while(0);m=j+60|0;l=o>>>16&15;do{if((l|0)!=0){if((f&1<<(l^15)|0)==0){break}k=c[b+(l<<2)>>2]|0;a[m]=k&255;a[j+61|0]=k>>>8&255;a[j+62|0]=k>>>16&255}}while(0);m=j+63|0;l=o>>>20&15;do{if((l|0)!=0){if((f&1<<(l^15)|0)==0){break}k=c[b+(l<<2)>>2]|0;a[m]=k&255;a[j+64|0]=k>>>8&255;a[j+65|0]=k>>>16&255}}while(0);m=j+66|0;l=o>>>24&15;do{if((l|0)!=0){if((f&1<<(l^15)|0)==0){break}k=c[b+(l<<2)>>2]|0;a[m]=k&255;a[j+67|0]=k>>>8&255;a[j+68|0]=k>>>16&255}}while(0);m=j+69|0;l=o>>>28;do{if((l|0)!=0){if((f&1<<(l^15)|0)==0){break}k=c[b+(l<<2)>>2]|0;a[m]=k&255;a[j+70|0]=k>>>8&255;a[j+71|0]=k>>>16&255}}while(0);m=j+72|0;l=c[i>>2]|0;h=n|l;o=l&15;do{if((o|0)!=0){if((f&1<<(o^15)|0)==0){break}k=c[b+(o<<2)>>2]|0;a[m]=k&255;a[j+73|0]=k>>>8&255;a[j+74|0]=k>>>16&255}}while(0);m=j+75|0;o=l>>>4&15;do{if((o|0)!=0){if((f&1<<(o^15)|0)==0){break}n=c[b+(o<<2)>>2]|0;a[m]=n&255;a[j+76|0]=n>>>8&255;a[j+77|0]=n>>>16&255}}while(0);m=j+78|0;o=l>>>8&15;do{if((o|0)!=0){if((f&1<<(o^15)|0)==0){break}n=c[b+(o<<2)>>2]|0;a[m]=n&255;a[j+79|0]=n>>>8&255;a[j+80|0]=n>>>16&255}}while(0);m=j+81|0;o=l>>>12&15;do{if((o|0)!=0){if((f&1<<(o^15)|0)==0){break}n=c[b+(o<<2)>>2]|0;a[m]=n&255;a[j+82|0]=n>>>8&255;a[j+83|0]=n>>>16&255}}while(0);m=j+84|0;o=l>>>16&15;do{if((o|0)!=0){if((f&1<<(o^15)|0)==0){break}n=c[b+(o<<2)>>2]|0;a[m]=n&255;a[j+85|0]=n>>>8&255;a[j+86|0]=n>>>16&255}}while(0);m=j+87|0;o=l>>>20&15;do{if((o|0)!=0){if((f&1<<(o^15)|0)==0){break}n=c[b+(o<<2)>>2]|0;a[m]=n&255;a[j+88|0]=n>>>8&255;a[j+89|0]=n>>>16&255}}while(0);m=j+90|0;o=l>>>24&15;do{if((o|0)!=0){if((f&1<<(o^15)|0)==0){break}n=c[b+(o<<2)>>2]|0;a[m]=n&255;a[j+91|0]=n>>>8&255;a[j+92|0]=n>>>16&255}}while(0);m=j+93|0;o=l>>>28;do{if((o|0)!=0){if((f&1<<(o^15)|0)==0){break}n=c[b+(o<<2)>>2]|0;a[m]=n&255;a[j+94|0]=n>>>8&255;a[j+95|0]=n>>>16&255}}while(0);g=g+1|0;j=j+d|0;i=i+e|0;}while((g|0)<32);c[2112960]=i;c[2112962]=j;return(h|0)==0|0}function afN(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;b=c[3541654]|0;d=c[2113228]|0;e=(d&536887296|0)==0;f=c[3541652]|0;g=(d+32767&536887296|0)==0;h=(d+65534&536887296|0)==0;i=(d+98301&536887296|0)==0;j=(d+131068&536887296|0)==0;k=(d+163835&536887296|0)==0;l=(d+196602&536887296|0)==0;m=(d+229369&536887296|0)==0;n=(d+262136&536887296|0)==0;o=(d+294903&536887296|0)==0;p=(d+327670&536887296|0)==0;q=(d+360437&536887296|0)==0;r=(d+393204&536887296|0)==0;s=(d+425971&536887296|0)==0;t=(d+458738&536887296|0)==0;u=(d+491505&536887296|0)==0;v=(d+524272&536887296|0)==0;w=(d+557039&536887296|0)==0;x=(d+589806&536887296|0)==0;y=(d+622573&536887296|0)==0;z=(d+655340&536887296|0)==0;A=(d+688107&536887296|0)==0;B=(d+720874&536887296|0)==0;C=(d+753641&536887296|0)==0;D=(d+786408&536887296|0)==0;E=(d+819175&536887296|0)==0;F=(d+851942&536887296|0)==0;G=(d+884709&536887296|0)==0;H=(d+917476&536887296|0)==0;I=(d+950243&536887296|0)==0;J=(d+983010&536887296|0)==0;K=(d+1015777&536887296|0)==0;d=c[2113300]|0;L=c[2113224]|0;M=1;N=0;O=c[2113226]|0;P=c[2112962]|0;Q=c[2112960]|0;while(1){R=O+32767|0;do{if((O&536887296|0)==0){S=c[Q>>2]|0;T=S|N;do{if(e){U=S>>>28;if((U|0)==0){break}if((f&1<<(U^15)|0)==0){break}V=c[b+(U<<2)>>2]|0;a[P]=V&255;a[P+1|0]=V>>>8&255;a[P+2|0]=V>>>16&255}}while(0);V=P+3|0;do{if(g){U=S>>>24&15;if((U|0)==0){break}if((f&1<<(U^15)|0)==0){break}W=c[b+(U<<2)>>2]|0;a[V]=W&255;a[P+4|0]=W>>>8&255;a[P+5|0]=W>>>16&255}}while(0);V=P+6|0;do{if(h){W=S>>>20&15;if((W|0)==0){break}if((f&1<<(W^15)|0)==0){break}U=c[b+(W<<2)>>2]|0;a[V]=U&255;a[P+7|0]=U>>>8&255;a[P+8|0]=U>>>16&255}}while(0);V=P+9|0;do{if(i){U=S>>>16&15;if((U|0)==0){break}if((f&1<<(U^15)|0)==0){break}W=c[b+(U<<2)>>2]|0;a[V]=W&255;a[P+10|0]=W>>>8&255;a[P+11|0]=W>>>16&255}}while(0);V=P+12|0;do{if(j){W=S>>>12&15;if((W|0)==0){break}if((f&1<<(W^15)|0)==0){break}U=c[b+(W<<2)>>2]|0;a[V]=U&255;a[P+13|0]=U>>>8&255;a[P+14|0]=U>>>16&255}}while(0);V=P+15|0;do{if(k){U=S>>>8&15;if((U|0)==0){break}if((f&1<<(U^15)|0)==0){break}W=c[b+(U<<2)>>2]|0;a[V]=W&255;a[P+16|0]=W>>>8&255;a[P+17|0]=W>>>16&255}}while(0);V=P+18|0;do{if(l){W=S>>>4&15;if((W|0)==0){break}if((f&1<<(W^15)|0)==0){break}U=c[b+(W<<2)>>2]|0;a[V]=U&255;a[P+19|0]=U>>>8&255;a[P+20|0]=U>>>16&255}}while(0);V=P+21|0;do{if(m){U=S&15;if((U|0)==0){break}if((f&1<<(U^15)|0)==0){break}W=c[b+(U<<2)>>2]|0;a[V]=W&255;a[P+22|0]=W>>>8&255;a[P+23|0]=W>>>16&255}}while(0);V=P+24|0;S=c[Q+4>>2]|0;W=T|S;do{if(n){U=S>>>28;if((U|0)==0){break}if((f&1<<(U^15)|0)==0){break}X=c[b+(U<<2)>>2]|0;a[V]=X&255;a[P+25|0]=X>>>8&255;a[P+26|0]=X>>>16&255}}while(0);V=P+27|0;do{if(o){T=S>>>24&15;if((T|0)==0){break}if((f&1<<(T^15)|0)==0){break}X=c[b+(T<<2)>>2]|0;a[V]=X&255;a[P+28|0]=X>>>8&255;a[P+29|0]=X>>>16&255}}while(0);V=P+30|0;do{if(p){X=S>>>20&15;if((X|0)==0){break}if((f&1<<(X^15)|0)==0){break}T=c[b+(X<<2)>>2]|0;a[V]=T&255;a[P+31|0]=T>>>8&255;a[P+32|0]=T>>>16&255}}while(0);V=P+33|0;do{if(q){T=S>>>16&15;if((T|0)==0){break}if((f&1<<(T^15)|0)==0){break}X=c[b+(T<<2)>>2]|0;a[V]=X&255;a[P+34|0]=X>>>8&255;a[P+35|0]=X>>>16&255}}while(0);V=P+36|0;do{if(r){X=S>>>12&15;if((X|0)==0){break}if((f&1<<(X^15)|0)==0){break}T=c[b+(X<<2)>>2]|0;a[V]=T&255;a[P+37|0]=T>>>8&255;a[P+38|0]=T>>>16&255}}while(0);V=P+39|0;do{if(s){T=S>>>8&15;if((T|0)==0){break}if((f&1<<(T^15)|0)==0){break}X=c[b+(T<<2)>>2]|0;a[V]=X&255;a[P+40|0]=X>>>8&255;a[P+41|0]=X>>>16&255}}while(0);V=P+42|0;do{if(t){X=S>>>4&15;if((X|0)==0){break}if((f&1<<(X^15)|0)==0){break}T=c[b+(X<<2)>>2]|0;a[V]=T&255;a[P+43|0]=T>>>8&255;a[P+44|0]=T>>>16&255}}while(0);V=P+45|0;do{if(u){T=S&15;if((T|0)==0){break}if((f&1<<(T^15)|0)==0){break}X=c[b+(T<<2)>>2]|0;a[V]=X&255;a[P+46|0]=X>>>8&255;a[P+47|0]=X>>>16&255}}while(0);V=P+48|0;S=c[Q+8>>2]|0;X=W|S;do{if(v){T=S>>>28;if((T|0)==0){break}if((f&1<<(T^15)|0)==0){break}U=c[b+(T<<2)>>2]|0;a[V]=U&255;a[P+49|0]=U>>>8&255;a[P+50|0]=U>>>16&255}}while(0);V=P+51|0;do{if(w){W=S>>>24&15;if((W|0)==0){break}if((f&1<<(W^15)|0)==0){break}U=c[b+(W<<2)>>2]|0;a[V]=U&255;a[P+52|0]=U>>>8&255;a[P+53|0]=U>>>16&255}}while(0);V=P+54|0;do{if(x){U=S>>>20&15;if((U|0)==0){break}if((f&1<<(U^15)|0)==0){break}W=c[b+(U<<2)>>2]|0;a[V]=W&255;a[P+55|0]=W>>>8&255;a[P+56|0]=W>>>16&255}}while(0);V=P+57|0;do{if(y){W=S>>>16&15;if((W|0)==0){break}if((f&1<<(W^15)|0)==0){break}U=c[b+(W<<2)>>2]|0;a[V]=U&255;a[P+58|0]=U>>>8&255;a[P+59|0]=U>>>16&255}}while(0);V=P+60|0;do{if(z){U=S>>>12&15;if((U|0)==0){break}if((f&1<<(U^15)|0)==0){break}W=c[b+(U<<2)>>2]|0;a[V]=W&255;a[P+61|0]=W>>>8&255;a[P+62|0]=W>>>16&255}}while(0);V=P+63|0;do{if(A){W=S>>>8&15;if((W|0)==0){break}if((f&1<<(W^15)|0)==0){break}U=c[b+(W<<2)>>2]|0;a[V]=U&255;a[P+64|0]=U>>>8&255;a[P+65|0]=U>>>16&255}}while(0);V=P+66|0;do{if(B){U=S>>>4&15;if((U|0)==0){break}if((f&1<<(U^15)|0)==0){break}W=c[b+(U<<2)>>2]|0;a[V]=W&255;a[P+67|0]=W>>>8&255;a[P+68|0]=W>>>16&255}}while(0);V=P+69|0;do{if(C){W=S&15;if((W|0)==0){break}if((f&1<<(W^15)|0)==0){break}U=c[b+(W<<2)>>2]|0;a[V]=U&255;a[P+70|0]=U>>>8&255;a[P+71|0]=U>>>16&255}}while(0);V=P+72|0;S=c[Q+12>>2]|0;U=X|S;do{if(D){W=S>>>28;if((W|0)==0){break}if((f&1<<(W^15)|0)==0){break}T=c[b+(W<<2)>>2]|0;a[V]=T&255;a[P+73|0]=T>>>8&255;a[P+74|0]=T>>>16&255}}while(0);V=P+75|0;do{if(E){X=S>>>24&15;if((X|0)==0){break}if((f&1<<(X^15)|0)==0){break}T=c[b+(X<<2)>>2]|0;a[V]=T&255;a[P+76|0]=T>>>8&255;a[P+77|0]=T>>>16&255}}while(0);V=P+78|0;do{if(F){T=S>>>20&15;if((T|0)==0){break}if((f&1<<(T^15)|0)==0){break}X=c[b+(T<<2)>>2]|0;a[V]=X&255;a[P+79|0]=X>>>8&255;a[P+80|0]=X>>>16&255}}while(0);V=P+81|0;do{if(G){X=S>>>16&15;if((X|0)==0){break}if((f&1<<(X^15)|0)==0){break}T=c[b+(X<<2)>>2]|0;a[V]=T&255;a[P+82|0]=T>>>8&255;a[P+83|0]=T>>>16&255}}while(0);V=P+84|0;do{if(H){T=S>>>12&15;if((T|0)==0){break}if((f&1<<(T^15)|0)==0){break}X=c[b+(T<<2)>>2]|0;a[V]=X&255;a[P+85|0]=X>>>8&255;a[P+86|0]=X>>>16&255}}while(0);V=P+87|0;do{if(I){X=S>>>8&15;if((X|0)==0){break}if((f&1<<(X^15)|0)==0){break}T=c[b+(X<<2)>>2]|0;a[V]=T&255;a[P+88|0]=T>>>8&255;a[P+89|0]=T>>>16&255}}while(0);V=P+90|0;do{if(J){T=S>>>4&15;if((T|0)==0){break}if((f&1<<(T^15)|0)==0){break}X=c[b+(T<<2)>>2]|0;a[V]=X&255;a[P+91|0]=X>>>8&255;a[P+92|0]=X>>>16&255}}while(0);if(!K){Y=U;break}V=S&15;if((V|0)==0){Y=U;break}if((f&1<<(V^15)|0)==0){Y=U;break}X=c[b+(V<<2)>>2]|0;a[P+93|0]=X&255;a[P+94|0]=X>>>8&255;a[P+95|0]=X>>>16&255;Y=U}else{Y=N}}while(0);Z=P+d|0;_=Q+L|0;if((M|0)>=32){break}M=M+1|0;N=Y;O=R;P=Z;Q=_}c[2113226]=R;c[2112962]=Z;c[2112960]=_;return(Y|0)==0|0}function afO(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;b=c[3541654]|0;d=c[2113228]|0;e=(d&536887296|0)==0;f=c[3541652]|0;g=(d+32767&536887296|0)==0;h=(d+65534&536887296|0)==0;i=(d+98301&536887296|0)==0;j=(d+131068&536887296|0)==0;k=(d+163835&536887296|0)==0;l=(d+196602&536887296|0)==0;m=(d+229369&536887296|0)==0;n=(d+262136&536887296|0)==0;o=(d+294903&536887296|0)==0;p=(d+327670&536887296|0)==0;q=(d+360437&536887296|0)==0;r=(d+393204&536887296|0)==0;s=(d+425971&536887296|0)==0;t=(d+458738&536887296|0)==0;u=(d+491505&536887296|0)==0;v=(d+524272&536887296|0)==0;w=(d+557039&536887296|0)==0;x=(d+589806&536887296|0)==0;y=(d+622573&536887296|0)==0;z=(d+655340&536887296|0)==0;A=(d+688107&536887296|0)==0;B=(d+720874&536887296|0)==0;C=(d+753641&536887296|0)==0;D=(d+786408&536887296|0)==0;E=(d+819175&536887296|0)==0;F=(d+851942&536887296|0)==0;G=(d+884709&536887296|0)==0;H=(d+917476&536887296|0)==0;I=(d+950243&536887296|0)==0;J=(d+983010&536887296|0)==0;K=(d+1015777&536887296|0)==0;d=c[2113300]|0;L=c[2113224]|0;M=1;N=0;O=c[2113226]|0;P=c[2112962]|0;Q=c[2112960]|0;while(1){R=O+32767|0;do{if((O&536887296|0)==0){S=c[Q+12>>2]|0;T=S|N;do{if(e){U=S&15;if((U|0)==0){break}if((f&1<<(U^15)|0)==0){break}V=c[b+(U<<2)>>2]|0;a[P]=V&255;a[P+1|0]=V>>>8&255;a[P+2|0]=V>>>16&255}}while(0);V=P+3|0;do{if(g){U=S>>>4&15;if((U|0)==0){break}if((f&1<<(U^15)|0)==0){break}W=c[b+(U<<2)>>2]|0;a[V]=W&255;a[P+4|0]=W>>>8&255;a[P+5|0]=W>>>16&255}}while(0);V=P+6|0;do{if(h){W=S>>>8&15;if((W|0)==0){break}if((f&1<<(W^15)|0)==0){break}U=c[b+(W<<2)>>2]|0;a[V]=U&255;a[P+7|0]=U>>>8&255;a[P+8|0]=U>>>16&255}}while(0);V=P+9|0;do{if(i){U=S>>>12&15;if((U|0)==0){break}if((f&1<<(U^15)|0)==0){break}W=c[b+(U<<2)>>2]|0;a[V]=W&255;a[P+10|0]=W>>>8&255;a[P+11|0]=W>>>16&255}}while(0);V=P+12|0;do{if(j){W=S>>>16&15;if((W|0)==0){break}if((f&1<<(W^15)|0)==0){break}U=c[b+(W<<2)>>2]|0;a[V]=U&255;a[P+13|0]=U>>>8&255;a[P+14|0]=U>>>16&255}}while(0);V=P+15|0;do{if(k){U=S>>>20&15;if((U|0)==0){break}if((f&1<<(U^15)|0)==0){break}W=c[b+(U<<2)>>2]|0;a[V]=W&255;a[P+16|0]=W>>>8&255;a[P+17|0]=W>>>16&255}}while(0);V=P+18|0;do{if(l){W=S>>>24&15;if((W|0)==0){break}if((f&1<<(W^15)|0)==0){break}U=c[b+(W<<2)>>2]|0;a[V]=U&255;a[P+19|0]=U>>>8&255;a[P+20|0]=U>>>16&255}}while(0);V=P+21|0;do{if(m){U=S>>>28;if((U|0)==0){break}if((f&1<<(U^15)|0)==0){break}W=c[b+(U<<2)>>2]|0;a[V]=W&255;a[P+22|0]=W>>>8&255;a[P+23|0]=W>>>16&255}}while(0);V=P+24|0;S=c[Q+8>>2]|0;W=T|S;do{if(n){U=S&15;if((U|0)==0){break}if((f&1<<(U^15)|0)==0){break}X=c[b+(U<<2)>>2]|0;a[V]=X&255;a[P+25|0]=X>>>8&255;a[P+26|0]=X>>>16&255}}while(0);V=P+27|0;do{if(o){T=S>>>4&15;if((T|0)==0){break}if((f&1<<(T^15)|0)==0){break}X=c[b+(T<<2)>>2]|0;a[V]=X&255;a[P+28|0]=X>>>8&255;a[P+29|0]=X>>>16&255}}while(0);V=P+30|0;do{if(p){X=S>>>8&15;if((X|0)==0){break}if((f&1<<(X^15)|0)==0){break}T=c[b+(X<<2)>>2]|0;a[V]=T&255;a[P+31|0]=T>>>8&255;a[P+32|0]=T>>>16&255}}while(0);V=P+33|0;do{if(q){T=S>>>12&15;if((T|0)==0){break}if((f&1<<(T^15)|0)==0){break}X=c[b+(T<<2)>>2]|0;a[V]=X&255;a[P+34|0]=X>>>8&255;a[P+35|0]=X>>>16&255}}while(0);V=P+36|0;do{if(r){X=S>>>16&15;if((X|0)==0){break}if((f&1<<(X^15)|0)==0){break}T=c[b+(X<<2)>>2]|0;a[V]=T&255;a[P+37|0]=T>>>8&255;a[P+38|0]=T>>>16&255}}while(0);V=P+39|0;do{if(s){T=S>>>20&15;if((T|0)==0){break}if((f&1<<(T^15)|0)==0){break}X=c[b+(T<<2)>>2]|0;a[V]=X&255;a[P+40|0]=X>>>8&255;a[P+41|0]=X>>>16&255}}while(0);V=P+42|0;do{if(t){X=S>>>24&15;if((X|0)==0){break}if((f&1<<(X^15)|0)==0){break}T=c[b+(X<<2)>>2]|0;a[V]=T&255;a[P+43|0]=T>>>8&255;a[P+44|0]=T>>>16&255}}while(0);V=P+45|0;do{if(u){T=S>>>28;if((T|0)==0){break}if((f&1<<(T^15)|0)==0){break}X=c[b+(T<<2)>>2]|0;a[V]=X&255;a[P+46|0]=X>>>8&255;a[P+47|0]=X>>>16&255}}while(0);V=P+48|0;S=c[Q+4>>2]|0;X=W|S;do{if(v){T=S&15;if((T|0)==0){break}if((f&1<<(T^15)|0)==0){break}U=c[b+(T<<2)>>2]|0;a[V]=U&255;a[P+49|0]=U>>>8&255;a[P+50|0]=U>>>16&255}}while(0);V=P+51|0;do{if(w){W=S>>>4&15;if((W|0)==0){break}if((f&1<<(W^15)|0)==0){break}U=c[b+(W<<2)>>2]|0;a[V]=U&255;a[P+52|0]=U>>>8&255;a[P+53|0]=U>>>16&255}}while(0);V=P+54|0;do{if(x){U=S>>>8&15;if((U|0)==0){break}if((f&1<<(U^15)|0)==0){break}W=c[b+(U<<2)>>2]|0;a[V]=W&255;a[P+55|0]=W>>>8&255;a[P+56|0]=W>>>16&255}}while(0);V=P+57|0;do{if(y){W=S>>>12&15;if((W|0)==0){break}if((f&1<<(W^15)|0)==0){break}U=c[b+(W<<2)>>2]|0;a[V]=U&255;a[P+58|0]=U>>>8&255;a[P+59|0]=U>>>16&255}}while(0);V=P+60|0;do{if(z){U=S>>>16&15;if((U|0)==0){break}if((f&1<<(U^15)|0)==0){break}W=c[b+(U<<2)>>2]|0;a[V]=W&255;a[P+61|0]=W>>>8&255;a[P+62|0]=W>>>16&255}}while(0);V=P+63|0;do{if(A){W=S>>>20&15;if((W|0)==0){break}if((f&1<<(W^15)|0)==0){break}U=c[b+(W<<2)>>2]|0;a[V]=U&255;a[P+64|0]=U>>>8&255;a[P+65|0]=U>>>16&255}}while(0);V=P+66|0;do{if(B){U=S>>>24&15;if((U|0)==0){break}if((f&1<<(U^15)|0)==0){break}W=c[b+(U<<2)>>2]|0;a[V]=W&255;a[P+67|0]=W>>>8&255;a[P+68|0]=W>>>16&255}}while(0);V=P+69|0;do{if(C){W=S>>>28;if((W|0)==0){break}if((f&1<<(W^15)|0)==0){break}U=c[b+(W<<2)>>2]|0;a[V]=U&255;a[P+70|0]=U>>>8&255;a[P+71|0]=U>>>16&255}}while(0);V=P+72|0;S=c[Q>>2]|0;U=X|S;do{if(D){W=S&15;if((W|0)==0){break}if((f&1<<(W^15)|0)==0){break}T=c[b+(W<<2)>>2]|0;a[V]=T&255;a[P+73|0]=T>>>8&255;a[P+74|0]=T>>>16&255}}while(0);V=P+75|0;do{if(E){X=S>>>4&15;if((X|0)==0){break}if((f&1<<(X^15)|0)==0){break}T=c[b+(X<<2)>>2]|0;a[V]=T&255;a[P+76|0]=T>>>8&255;a[P+77|0]=T>>>16&255}}while(0);V=P+78|0;do{if(F){T=S>>>8&15;if((T|0)==0){break}if((f&1<<(T^15)|0)==0){break}X=c[b+(T<<2)>>2]|0;a[V]=X&255;a[P+79|0]=X>>>8&255;a[P+80|0]=X>>>16&255}}while(0);V=P+81|0;do{if(G){X=S>>>12&15;if((X|0)==0){break}if((f&1<<(X^15)|0)==0){break}T=c[b+(X<<2)>>2]|0;a[V]=T&255;a[P+82|0]=T>>>8&255;a[P+83|0]=T>>>16&255}}while(0);V=P+84|0;do{if(H){T=S>>>16&15;if((T|0)==0){break}if((f&1<<(T^15)|0)==0){break}X=c[b+(T<<2)>>2]|0;a[V]=X&255;a[P+85|0]=X>>>8&255;a[P+86|0]=X>>>16&255}}while(0);V=P+87|0;do{if(I){X=S>>>20&15;if((X|0)==0){break}if((f&1<<(X^15)|0)==0){break}T=c[b+(X<<2)>>2]|0;a[V]=T&255;a[P+88|0]=T>>>8&255;a[P+89|0]=T>>>16&255}}while(0);V=P+90|0;do{if(J){T=S>>>24&15;if((T|0)==0){break}if((f&1<<(T^15)|0)==0){break}X=c[b+(T<<2)>>2]|0;a[V]=X&255;a[P+91|0]=X>>>8&255;a[P+92|0]=X>>>16&255}}while(0);if(!K){Y=U;break}V=S>>>28;if((V|0)==0){Y=U;break}if((f&1<<(V^15)|0)==0){Y=U;break}X=c[b+(V<<2)>>2]|0;a[P+93|0]=X&255;a[P+94|0]=X>>>8&255;a[P+95|0]=X>>>16&255;Y=U}else{Y=N}}while(0);Z=P+d|0;_=Q+L|0;if((M|0)>=32){break}M=M+1|0;N=Y;O=R;P=Z;Q=_}c[2113226]=R;c[2112962]=Z;c[2112960]=_;return(Y|0)==0|0}function afP(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=c[3541654]|0;f=b[3726284]|0;g=c[2113300]|0;h=c[2113224]|0;i=0;j=0;k=c[2112962]|0;l=c[2112960]|0;m=c[2112924]|0;do{n=c[l>>2]|0;j=n|j;do{if(n>>>0>268435455){o=c[d+(n>>>28<<2)>>2]|0;if((e[m>>1]|0)>=(f&65535)){break}a[k]=o&255;a[k+1|0]=o>>>8&255;a[k+2|0]=o>>>16&255}}while(0);o=k+3|0;do{if(n<<4>>>0>268435455){p=c[d+((n>>>24&15)<<2)>>2]|0;if((e[m+2>>1]|0)>=(f&65535)){break}a[o]=p&255;a[k+4|0]=p>>>8&255;a[k+5|0]=p>>>16&255}}while(0);o=k+6|0;do{if(n<<8>>>0>268435455){p=c[d+((n>>>20&15)<<2)>>2]|0;if((e[m+4>>1]|0)>=(f&65535)){break}a[o]=p&255;a[k+7|0]=p>>>8&255;a[k+8|0]=p>>>16&255}}while(0);o=k+9|0;do{if(n<<12>>>0>268435455){p=c[d+((n>>>16&15)<<2)>>2]|0;if((e[m+6>>1]|0)>=(f&65535)){break}a[o]=p&255;a[k+10|0]=p>>>8&255;a[k+11|0]=p>>>16&255}}while(0);o=k+12|0;do{if(n<<16>>>0>268435455){p=c[d+((n>>>12&15)<<2)>>2]|0;if((e[m+8>>1]|0)>=(f&65535)){break}a[o]=p&255;a[k+13|0]=p>>>8&255;a[k+14|0]=p>>>16&255}}while(0);o=k+15|0;do{if(n<<20>>>0>268435455){p=c[d+((n>>>8&15)<<2)>>2]|0;if((e[m+10>>1]|0)>=(f&65535)){break}a[o]=p&255;a[k+16|0]=p>>>8&255;a[k+17|0]=p>>>16&255}}while(0);o=k+18|0;do{if(n<<24>>>0>268435455){p=c[d+((n>>>4&15)<<2)>>2]|0;if((e[m+12>>1]|0)>=(f&65535)){break}a[o]=p&255;a[k+19|0]=p>>>8&255;a[k+20|0]=p>>>16&255}}while(0);o=k+21|0;p=n&15;do{if((p|0)!=0){q=c[d+(p<<2)>>2]|0;if((e[m+14>>1]|0)>=(f&65535)){break}a[o]=q&255;a[k+22|0]=q>>>8&255;a[k+23|0]=q>>>16&255}}while(0);i=i+1|0;k=k+g|0;l=l+h|0;m=m+768|0;}while((i|0)<8);c[2112962]=k;c[2112960]=l;c[2112924]=m;return(j|0)==0|0}function afQ(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=c[3541654]|0;f=c[2113300]|0;g=c[2113224]|0;h=b[3726284]|0;i=0;j=0;k=c[2112962]|0;l=c[2112960]|0;m=c[2112924]|0;do{n=c[l>>2]|0;j=n|j;o=n&15;do{if((o|0)!=0){p=c[d+(o<<2)>>2]|0;if((e[m>>1]|0)>=(h&65535)){break}a[k]=p&255;a[k+1|0]=p>>>8&255;a[k+2|0]=p>>>16&255}}while(0);o=k+3|0;p=n>>>4&15;do{if((p|0)!=0){q=c[d+(p<<2)>>2]|0;if((e[m+2>>1]|0)>=(h&65535)){break}a[o]=q&255;a[k+4|0]=q>>>8&255;a[k+5|0]=q>>>16&255}}while(0);o=k+6|0;p=n>>>8&15;do{if((p|0)!=0){q=c[d+(p<<2)>>2]|0;if((e[m+4>>1]|0)>=(h&65535)){break}a[o]=q&255;a[k+7|0]=q>>>8&255;a[k+8|0]=q>>>16&255}}while(0);o=k+9|0;p=n>>>12&15;do{if((p|0)!=0){q=c[d+(p<<2)>>2]|0;if((e[m+6>>1]|0)>=(h&65535)){break}a[o]=q&255;a[k+10|0]=q>>>8&255;a[k+11|0]=q>>>16&255}}while(0);o=k+12|0;p=n>>>16&15;do{if((p|0)!=0){q=c[d+(p<<2)>>2]|0;if((e[m+8>>1]|0)>=(h&65535)){break}a[o]=q&255;a[k+13|0]=q>>>8&255;a[k+14|0]=q>>>16&255}}while(0);o=k+15|0;p=n>>>20&15;do{if((p|0)!=0){q=c[d+(p<<2)>>2]|0;if((e[m+10>>1]|0)>=(h&65535)){break}a[o]=q&255;a[k+16|0]=q>>>8&255;a[k+17|0]=q>>>16&255}}while(0);o=k+18|0;p=n>>>24&15;do{if((p|0)!=0){q=c[d+(p<<2)>>2]|0;if((e[m+12>>1]|0)>=(h&65535)){break}a[o]=q&255;a[k+19|0]=q>>>8&255;a[k+20|0]=q>>>16&255}}while(0);o=k+21|0;p=n>>>28;do{if((p|0)!=0){q=c[d+(p<<2)>>2]|0;if((e[m+14>>1]|0)>=(h&65535)){break}a[o]=q&255;a[k+22|0]=q>>>8&255;a[k+23|0]=q>>>16&255}}while(0);i=i+1|0;k=k+f|0;l=l+g|0;m=m+768|0;}while((i|0)<8);c[2112962]=k;c[2112960]=l;c[2112924]=m;return(j|0)==0|0}function afR(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;d=c[3541654]|0;f=c[2113228]|0;g=(f&536887296|0)==0;h=b[3726284]|0;i=(f+32767&536887296|0)==0;j=(f+65534&536887296|0)==0;k=(f+98301&536887296|0)==0;l=(f+131068&536887296|0)==0;m=(f+163835&536887296|0)==0;n=(f+196602&536887296|0)==0;o=(f+229369&536887296|0)==0;f=c[2113300]|0;p=c[2113224]|0;q=1;r=0;s=c[2113226]|0;t=c[2112962]|0;u=c[2112924]|0;v=c[2112960]|0;while(1){w=s+32767|0;do{if((s&536887296|0)==0){x=c[v>>2]|0;y=x|r;do{if(g&x>>>0>268435455){z=c[d+(x>>>28<<2)>>2]|0;if((e[u>>1]|0)>=(h&65535)){break}a[t]=z&255;a[t+1|0]=z>>>8&255;a[t+2|0]=z>>>16&255}}while(0);z=t+3|0;A=u+2|0;do{if(i){if(x<<4>>>0<=268435455){break}B=c[d+((x>>>24&15)<<2)>>2]|0;if((e[A>>1]|0)>=(h&65535)){break}a[z]=B&255;a[t+4|0]=B>>>8&255;a[t+5|0]=B>>>16&255}}while(0);z=t+6|0;A=u+4|0;do{if(j){if(x<<8>>>0<=268435455){break}B=c[d+((x>>>20&15)<<2)>>2]|0;if((e[A>>1]|0)>=(h&65535)){break}a[z]=B&255;a[t+7|0]=B>>>8&255;a[t+8|0]=B>>>16&255}}while(0);z=t+9|0;A=u+6|0;do{if(k){if(x<<12>>>0<=268435455){break}B=c[d+((x>>>16&15)<<2)>>2]|0;if((e[A>>1]|0)>=(h&65535)){break}a[z]=B&255;a[t+10|0]=B>>>8&255;a[t+11|0]=B>>>16&255}}while(0);z=t+12|0;A=u+8|0;do{if(l){if(x<<16>>>0<=268435455){break}B=c[d+((x>>>12&15)<<2)>>2]|0;if((e[A>>1]|0)>=(h&65535)){break}a[z]=B&255;a[t+13|0]=B>>>8&255;a[t+14|0]=B>>>16&255}}while(0);z=t+15|0;A=u+10|0;do{if(m){if(x<<20>>>0<=268435455){break}B=c[d+((x>>>8&15)<<2)>>2]|0;if((e[A>>1]|0)>=(h&65535)){break}a[z]=B&255;a[t+16|0]=B>>>8&255;a[t+17|0]=B>>>16&255}}while(0);z=t+18|0;A=u+12|0;do{if(n){if(x<<24>>>0<=268435455){break}B=c[d+((x>>>4&15)<<2)>>2]|0;if((e[A>>1]|0)>=(h&65535)){break}a[z]=B&255;a[t+19|0]=B>>>8&255;a[t+20|0]=B>>>16&255}}while(0);if(!o){C=y;break}z=x&15;if((z|0)==0){C=y;break}A=c[d+(z<<2)>>2]|0;if((e[u+14>>1]|0)>=(h&65535)){C=y;break}a[t+21|0]=A&255;a[t+22|0]=A>>>8&255;a[t+23|0]=A>>>16&255;C=y}else{C=r}}while(0);D=t+f|0;E=v+p|0;F=u+768|0;if((q|0)>=8){break}q=q+1|0;r=C;s=w;t=D;u=F;v=E}c[2113226]=w;c[2112962]=D;c[2112924]=F;c[2112960]=E;return(C|0)==0|0}function afS(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;d=c[3541654]|0;f=c[2113228]|0;g=(f&536887296|0)==0;h=b[3726284]|0;i=(f+32767&536887296|0)==0;j=(f+65534&536887296|0)==0;k=(f+98301&536887296|0)==0;l=(f+131068&536887296|0)==0;m=(f+163835&536887296|0)==0;n=(f+196602&536887296|0)==0;o=(f+229369&536887296|0)==0;f=c[2113300]|0;p=c[2113224]|0;q=1;r=0;s=c[2113226]|0;t=c[2112962]|0;u=c[2112924]|0;v=c[2112960]|0;while(1){w=s+32767|0;do{if((s&536887296|0)==0){x=c[v>>2]|0;y=x|r;do{if(g){z=x&15;if((z|0)==0){break}A=c[d+(z<<2)>>2]|0;if((e[u>>1]|0)>=(h&65535)){break}a[t]=A&255;a[t+1|0]=A>>>8&255;a[t+2|0]=A>>>16&255}}while(0);A=t+3|0;z=u+2|0;do{if(i){B=x>>>4&15;if((B|0)==0){break}C=c[d+(B<<2)>>2]|0;if((e[z>>1]|0)>=(h&65535)){break}a[A]=C&255;a[t+4|0]=C>>>8&255;a[t+5|0]=C>>>16&255}}while(0);A=t+6|0;z=u+4|0;do{if(j){C=x>>>8&15;if((C|0)==0){break}B=c[d+(C<<2)>>2]|0;if((e[z>>1]|0)>=(h&65535)){break}a[A]=B&255;a[t+7|0]=B>>>8&255;a[t+8|0]=B>>>16&255}}while(0);A=t+9|0;z=u+6|0;do{if(k){B=x>>>12&15;if((B|0)==0){break}C=c[d+(B<<2)>>2]|0;if((e[z>>1]|0)>=(h&65535)){break}a[A]=C&255;a[t+10|0]=C>>>8&255;a[t+11|0]=C>>>16&255}}while(0);A=t+12|0;z=u+8|0;do{if(l){C=x>>>16&15;if((C|0)==0){break}B=c[d+(C<<2)>>2]|0;if((e[z>>1]|0)>=(h&65535)){break}a[A]=B&255;a[t+13|0]=B>>>8&255;a[t+14|0]=B>>>16&255}}while(0);A=t+15|0;z=u+10|0;do{if(m){B=x>>>20&15;if((B|0)==0){break}C=c[d+(B<<2)>>2]|0;if((e[z>>1]|0)>=(h&65535)){break}a[A]=C&255;a[t+16|0]=C>>>8&255;a[t+17|0]=C>>>16&255}}while(0);A=t+18|0;z=u+12|0;do{if(n){C=x>>>24&15;if((C|0)==0){break}B=c[d+(C<<2)>>2]|0;if((e[z>>1]|0)>=(h&65535)){break}a[A]=B&255;a[t+19|0]=B>>>8&255;a[t+20|0]=B>>>16&255}}while(0);if(!o){D=y;break}A=x>>>28;if((A|0)==0){D=y;break}z=c[d+(A<<2)>>2]|0;if((e[u+14>>1]|0)>=(h&65535)){D=y;break}a[t+21|0]=z&255;a[t+22|0]=z>>>8&255;a[t+23|0]=z>>>16&255;D=y}else{D=r}}while(0);E=t+f|0;F=v+p|0;G=u+768|0;if((q|0)>=8){break}q=q+1|0;r=D;s=w;t=E;u=G;v=F}c[2113226]=w;c[2112962]=E;c[2112924]=G;c[2112960]=F;return(D|0)==0|0}function afT(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=c[3541654]|0;f=b[3726284]|0;g=c[2113300]|0;h=c[2113224]|0;i=0;j=0;k=c[2112960]|0;l=c[2112962]|0;m=c[2112924]|0;do{n=c[k>>2]|0;o=n|j;do{if(n>>>0>268435455){p=c[d+(n>>>28<<2)>>2]|0;if((e[m>>1]|0)>=(f&65535)){break}a[l]=p&255;a[l+1|0]=p>>>8&255;a[l+2|0]=p>>>16&255}}while(0);p=l+3|0;do{if(n<<4>>>0>268435455){q=c[d+((n>>>24&15)<<2)>>2]|0;if((e[m+2>>1]|0)>=(f&65535)){break}a[p]=q&255;a[l+4|0]=q>>>8&255;a[l+5|0]=q>>>16&255}}while(0);p=l+6|0;do{if(n<<8>>>0>268435455){q=c[d+((n>>>20&15)<<2)>>2]|0;if((e[m+4>>1]|0)>=(f&65535)){break}a[p]=q&255;a[l+7|0]=q>>>8&255;a[l+8|0]=q>>>16&255}}while(0);p=l+9|0;do{if(n<<12>>>0>268435455){q=c[d+((n>>>16&15)<<2)>>2]|0;if((e[m+6>>1]|0)>=(f&65535)){break}a[p]=q&255;a[l+10|0]=q>>>8&255;a[l+11|0]=q>>>16&255}}while(0);p=l+12|0;do{if(n<<16>>>0>268435455){q=c[d+((n>>>12&15)<<2)>>2]|0;if((e[m+8>>1]|0)>=(f&65535)){break}a[p]=q&255;a[l+13|0]=q>>>8&255;a[l+14|0]=q>>>16&255}}while(0);p=l+15|0;do{if(n<<20>>>0>268435455){q=c[d+((n>>>8&15)<<2)>>2]|0;if((e[m+10>>1]|0)>=(f&65535)){break}a[p]=q&255;a[l+16|0]=q>>>8&255;a[l+17|0]=q>>>16&255}}while(0);p=l+18|0;do{if(n<<24>>>0>268435455){q=c[d+((n>>>4&15)<<2)>>2]|0;if((e[m+12>>1]|0)>=(f&65535)){break}a[p]=q&255;a[l+19|0]=q>>>8&255;a[l+20|0]=q>>>16&255}}while(0);p=l+21|0;q=n&15;do{if((q|0)!=0){r=c[d+(q<<2)>>2]|0;if((e[m+14>>1]|0)>=(f&65535)){break}a[p]=r&255;a[l+22|0]=r>>>8&255;a[l+23|0]=r>>>16&255}}while(0);p=l+24|0;q=c[k+4>>2]|0;j=o|q;do{if(q>>>0>268435455){n=c[d+(q>>>28<<2)>>2]|0;if((e[m+16>>1]|0)>=(f&65535)){break}a[p]=n&255;a[l+25|0]=n>>>8&255;a[l+26|0]=n>>>16&255}}while(0);p=l+27|0;do{if(q<<4>>>0>268435455){o=c[d+((q>>>24&15)<<2)>>2]|0;if((e[m+18>>1]|0)>=(f&65535)){break}a[p]=o&255;a[l+28|0]=o>>>8&255;a[l+29|0]=o>>>16&255}}while(0);p=l+30|0;do{if(q<<8>>>0>268435455){o=c[d+((q>>>20&15)<<2)>>2]|0;if((e[m+20>>1]|0)>=(f&65535)){break}a[p]=o&255;a[l+31|0]=o>>>8&255;a[l+32|0]=o>>>16&255}}while(0);p=l+33|0;do{if(q<<12>>>0>268435455){o=c[d+((q>>>16&15)<<2)>>2]|0;if((e[m+22>>1]|0)>=(f&65535)){break}a[p]=o&255;a[l+34|0]=o>>>8&255;a[l+35|0]=o>>>16&255}}while(0);p=l+36|0;do{if(q<<16>>>0>268435455){o=c[d+((q>>>12&15)<<2)>>2]|0;if((e[m+24>>1]|0)>=(f&65535)){break}a[p]=o&255;a[l+37|0]=o>>>8&255;a[l+38|0]=o>>>16&255}}while(0);p=l+39|0;do{if(q<<20>>>0>268435455){o=c[d+((q>>>8&15)<<2)>>2]|0;if((e[m+26>>1]|0)>=(f&65535)){break}a[p]=o&255;a[l+40|0]=o>>>8&255;a[l+41|0]=o>>>16&255}}while(0);p=l+42|0;do{if(q<<24>>>0>268435455){o=c[d+((q>>>4&15)<<2)>>2]|0;if((e[m+28>>1]|0)>=(f&65535)){break}a[p]=o&255;a[l+43|0]=o>>>8&255;a[l+44|0]=o>>>16&255}}while(0);p=l+45|0;o=q&15;do{if((o|0)!=0){n=c[d+(o<<2)>>2]|0;if((e[m+30>>1]|0)>=(f&65535)){break}a[p]=n&255;a[l+46|0]=n>>>8&255;a[l+47|0]=n>>>16&255}}while(0);i=i+1|0;l=l+g|0;k=k+h|0;m=m+768|0;}while((i|0)<16);c[2112960]=k;c[2112962]=l;c[2112924]=m;return(j|0)==0|0}function afU(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=c[3541654]|0;f=c[2113300]|0;g=c[2113224]|0;h=b[3726284]|0;i=0;j=0;k=c[2112960]|0;l=c[2112962]|0;m=c[2112924]|0;do{n=c[k+4>>2]|0;o=n|j;p=n&15;do{if((p|0)!=0){q=c[d+(p<<2)>>2]|0;if((e[m>>1]|0)>=(h&65535)){break}a[l]=q&255;a[l+1|0]=q>>>8&255;a[l+2|0]=q>>>16&255}}while(0);p=l+3|0;q=n>>>4&15;do{if((q|0)!=0){r=c[d+(q<<2)>>2]|0;if((e[m+2>>1]|0)>=(h&65535)){break}a[p]=r&255;a[l+4|0]=r>>>8&255;a[l+5|0]=r>>>16&255}}while(0);p=l+6|0;q=n>>>8&15;do{if((q|0)!=0){r=c[d+(q<<2)>>2]|0;if((e[m+4>>1]|0)>=(h&65535)){break}a[p]=r&255;a[l+7|0]=r>>>8&255;a[l+8|0]=r>>>16&255}}while(0);p=l+9|0;q=n>>>12&15;do{if((q|0)!=0){r=c[d+(q<<2)>>2]|0;if((e[m+6>>1]|0)>=(h&65535)){break}a[p]=r&255;a[l+10|0]=r>>>8&255;a[l+11|0]=r>>>16&255}}while(0);p=l+12|0;q=n>>>16&15;do{if((q|0)!=0){r=c[d+(q<<2)>>2]|0;if((e[m+8>>1]|0)>=(h&65535)){break}a[p]=r&255;a[l+13|0]=r>>>8&255;a[l+14|0]=r>>>16&255}}while(0);p=l+15|0;q=n>>>20&15;do{if((q|0)!=0){r=c[d+(q<<2)>>2]|0;if((e[m+10>>1]|0)>=(h&65535)){break}a[p]=r&255;a[l+16|0]=r>>>8&255;a[l+17|0]=r>>>16&255}}while(0);p=l+18|0;q=n>>>24&15;do{if((q|0)!=0){r=c[d+(q<<2)>>2]|0;if((e[m+12>>1]|0)>=(h&65535)){break}a[p]=r&255;a[l+19|0]=r>>>8&255;a[l+20|0]=r>>>16&255}}while(0);p=l+21|0;q=n>>>28;do{if((q|0)!=0){r=c[d+(q<<2)>>2]|0;if((e[m+14>>1]|0)>=(h&65535)){break}a[p]=r&255;a[l+22|0]=r>>>8&255;a[l+23|0]=r>>>16&255}}while(0);p=l+24|0;q=c[k>>2]|0;j=o|q;n=q&15;do{if((n|0)!=0){r=c[d+(n<<2)>>2]|0;if((e[m+16>>1]|0)>=(h&65535)){break}a[p]=r&255;a[l+25|0]=r>>>8&255;a[l+26|0]=r>>>16&255}}while(0);p=l+27|0;n=q>>>4&15;do{if((n|0)!=0){o=c[d+(n<<2)>>2]|0;if((e[m+18>>1]|0)>=(h&65535)){break}a[p]=o&255;a[l+28|0]=o>>>8&255;a[l+29|0]=o>>>16&255}}while(0);p=l+30|0;n=q>>>8&15;do{if((n|0)!=0){o=c[d+(n<<2)>>2]|0;if((e[m+20>>1]|0)>=(h&65535)){break}a[p]=o&255;a[l+31|0]=o>>>8&255;a[l+32|0]=o>>>16&255}}while(0);p=l+33|0;n=q>>>12&15;do{if((n|0)!=0){o=c[d+(n<<2)>>2]|0;if((e[m+22>>1]|0)>=(h&65535)){break}a[p]=o&255;a[l+34|0]=o>>>8&255;a[l+35|0]=o>>>16&255}}while(0);p=l+36|0;n=q>>>16&15;do{if((n|0)!=0){o=c[d+(n<<2)>>2]|0;if((e[m+24>>1]|0)>=(h&65535)){break}a[p]=o&255;a[l+37|0]=o>>>8&255;a[l+38|0]=o>>>16&255}}while(0);p=l+39|0;n=q>>>20&15;do{if((n|0)!=0){o=c[d+(n<<2)>>2]|0;if((e[m+26>>1]|0)>=(h&65535)){break}a[p]=o&255;a[l+40|0]=o>>>8&255;a[l+41|0]=o>>>16&255}}while(0);p=l+42|0;n=q>>>24&15;do{if((n|0)!=0){o=c[d+(n<<2)>>2]|0;if((e[m+28>>1]|0)>=(h&65535)){break}a[p]=o&255;a[l+43|0]=o>>>8&255;a[l+44|0]=o>>>16&255}}while(0);p=l+45|0;n=q>>>28;do{if((n|0)!=0){o=c[d+(n<<2)>>2]|0;if((e[m+30>>1]|0)>=(h&65535)){break}a[p]=o&255;a[l+46|0]=o>>>8&255;a[l+47|0]=o>>>16&255}}while(0);i=i+1|0;l=l+f|0;k=k+g|0;m=m+768|0;}while((i|0)<16);c[2112960]=k;c[2112962]=l;c[2112924]=m;return(j|0)==0|0}function afV(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;d=c[3541654]|0;f=c[2113228]|0;g=(f&536887296|0)==0;h=b[3726284]|0;i=(f+32767&536887296|0)==0;j=(f+65534&536887296|0)==0;k=(f+98301&536887296|0)==0;l=(f+131068&536887296|0)==0;m=(f+163835&536887296|0)==0;n=(f+196602&536887296|0)==0;o=(f+229369&536887296|0)==0;p=(f+262136&536887296|0)==0;q=(f+294903&536887296|0)==0;r=(f+327670&536887296|0)==0;s=(f+360437&536887296|0)==0;t=(f+393204&536887296|0)==0;u=(f+425971&536887296|0)==0;v=(f+458738&536887296|0)==0;w=(f+491505&536887296|0)==0;f=c[2113300]|0;x=c[2113224]|0;y=1;z=0;A=c[2113226]|0;B=c[2112962]|0;C=c[2112924]|0;D=c[2112960]|0;while(1){E=A+32767|0;do{if((A&536887296|0)==0){F=c[D>>2]|0;G=F|z;do{if(g&F>>>0>268435455){H=c[d+(F>>>28<<2)>>2]|0;if((e[C>>1]|0)>=(h&65535)){break}a[B]=H&255;a[B+1|0]=H>>>8&255;a[B+2|0]=H>>>16&255}}while(0);H=B+3|0;I=C+2|0;do{if(i){if(F<<4>>>0<=268435455){break}J=c[d+((F>>>24&15)<<2)>>2]|0;if((e[I>>1]|0)>=(h&65535)){break}a[H]=J&255;a[B+4|0]=J>>>8&255;a[B+5|0]=J>>>16&255}}while(0);H=B+6|0;I=C+4|0;do{if(j){if(F<<8>>>0<=268435455){break}J=c[d+((F>>>20&15)<<2)>>2]|0;if((e[I>>1]|0)>=(h&65535)){break}a[H]=J&255;a[B+7|0]=J>>>8&255;a[B+8|0]=J>>>16&255}}while(0);H=B+9|0;I=C+6|0;do{if(k){if(F<<12>>>0<=268435455){break}J=c[d+((F>>>16&15)<<2)>>2]|0;if((e[I>>1]|0)>=(h&65535)){break}a[H]=J&255;a[B+10|0]=J>>>8&255;a[B+11|0]=J>>>16&255}}while(0);H=B+12|0;I=C+8|0;do{if(l){if(F<<16>>>0<=268435455){break}J=c[d+((F>>>12&15)<<2)>>2]|0;if((e[I>>1]|0)>=(h&65535)){break}a[H]=J&255;a[B+13|0]=J>>>8&255;a[B+14|0]=J>>>16&255}}while(0);H=B+15|0;I=C+10|0;do{if(m){if(F<<20>>>0<=268435455){break}J=c[d+((F>>>8&15)<<2)>>2]|0;if((e[I>>1]|0)>=(h&65535)){break}a[H]=J&255;a[B+16|0]=J>>>8&255;a[B+17|0]=J>>>16&255}}while(0);H=B+18|0;I=C+12|0;do{if(n){if(F<<24>>>0<=268435455){break}J=c[d+((F>>>4&15)<<2)>>2]|0;if((e[I>>1]|0)>=(h&65535)){break}a[H]=J&255;a[B+19|0]=J>>>8&255;a[B+20|0]=J>>>16&255}}while(0);H=B+21|0;I=C+14|0;do{if(o){J=F&15;if((J|0)==0){break}K=c[d+(J<<2)>>2]|0;if((e[I>>1]|0)>=(h&65535)){break}a[H]=K&255;a[B+22|0]=K>>>8&255;a[B+23|0]=K>>>16&255}}while(0);H=B+24|0;I=c[D+4>>2]|0;F=G|I;do{if(p&I>>>0>268435455){K=c[d+(I>>>28<<2)>>2]|0;if((e[C+16>>1]|0)>=(h&65535)){break}a[H]=K&255;a[B+25|0]=K>>>8&255;a[B+26|0]=K>>>16&255}}while(0);H=B+27|0;G=C+18|0;do{if(q){if(I<<4>>>0<=268435455){break}K=c[d+((I>>>24&15)<<2)>>2]|0;if((e[G>>1]|0)>=(h&65535)){break}a[H]=K&255;a[B+28|0]=K>>>8&255;a[B+29|0]=K>>>16&255}}while(0);H=B+30|0;G=C+20|0;do{if(r){if(I<<8>>>0<=268435455){break}K=c[d+((I>>>20&15)<<2)>>2]|0;if((e[G>>1]|0)>=(h&65535)){break}a[H]=K&255;a[B+31|0]=K>>>8&255;a[B+32|0]=K>>>16&255}}while(0);H=B+33|0;G=C+22|0;do{if(s){if(I<<12>>>0<=268435455){break}K=c[d+((I>>>16&15)<<2)>>2]|0;if((e[G>>1]|0)>=(h&65535)){break}a[H]=K&255;a[B+34|0]=K>>>8&255;a[B+35|0]=K>>>16&255}}while(0);H=B+36|0;G=C+24|0;do{if(t){if(I<<16>>>0<=268435455){break}K=c[d+((I>>>12&15)<<2)>>2]|0;if((e[G>>1]|0)>=(h&65535)){break}a[H]=K&255;a[B+37|0]=K>>>8&255;a[B+38|0]=K>>>16&255}}while(0);H=B+39|0;G=C+26|0;do{if(u){if(I<<20>>>0<=268435455){break}K=c[d+((I>>>8&15)<<2)>>2]|0;if((e[G>>1]|0)>=(h&65535)){break}a[H]=K&255;a[B+40|0]=K>>>8&255;a[B+41|0]=K>>>16&255}}while(0);H=B+42|0;G=C+28|0;do{if(v){if(I<<24>>>0<=268435455){break}K=c[d+((I>>>4&15)<<2)>>2]|0;if((e[G>>1]|0)>=(h&65535)){break}a[H]=K&255;a[B+43|0]=K>>>8&255;a[B+44|0]=K>>>16&255}}while(0);if(!w){L=F;break}H=I&15;if((H|0)==0){L=F;break}G=c[d+(H<<2)>>2]|0;if((e[C+30>>1]|0)>=(h&65535)){L=F;break}a[B+45|0]=G&255;a[B+46|0]=G>>>8&255;a[B+47|0]=G>>>16&255;L=F}else{L=z}}while(0);M=B+f|0;N=D+x|0;O=C+768|0;if((y|0)>=16){break}y=y+1|0;z=L;A=E;B=M;C=O;D=N}c[2113226]=E;c[2112962]=M;c[2112924]=O;c[2112960]=N;return(L|0)==0|0}function afW(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;d=c[3541654]|0;f=c[2113228]|0;g=(f&536887296|0)==0;h=b[3726284]|0;i=(f+32767&536887296|0)==0;j=(f+65534&536887296|0)==0;k=(f+98301&536887296|0)==0;l=(f+131068&536887296|0)==0;m=(f+163835&536887296|0)==0;n=(f+196602&536887296|0)==0;o=(f+229369&536887296|0)==0;p=(f+262136&536887296|0)==0;q=(f+294903&536887296|0)==0;r=(f+327670&536887296|0)==0;s=(f+360437&536887296|0)==0;t=(f+393204&536887296|0)==0;u=(f+425971&536887296|0)==0;v=(f+458738&536887296|0)==0;w=(f+491505&536887296|0)==0;f=c[2113300]|0;x=c[2113224]|0;y=1;z=0;A=c[2113226]|0;B=c[2112962]|0;C=c[2112924]|0;D=c[2112960]|0;while(1){E=A+32767|0;do{if((A&536887296|0)==0){F=c[D+4>>2]|0;G=F|z;do{if(g){H=F&15;if((H|0)==0){break}I=c[d+(H<<2)>>2]|0;if((e[C>>1]|0)>=(h&65535)){break}a[B]=I&255;a[B+1|0]=I>>>8&255;a[B+2|0]=I>>>16&255}}while(0);I=B+3|0;H=C+2|0;do{if(i){J=F>>>4&15;if((J|0)==0){break}K=c[d+(J<<2)>>2]|0;if((e[H>>1]|0)>=(h&65535)){break}a[I]=K&255;a[B+4|0]=K>>>8&255;a[B+5|0]=K>>>16&255}}while(0);I=B+6|0;H=C+4|0;do{if(j){K=F>>>8&15;if((K|0)==0){break}J=c[d+(K<<2)>>2]|0;if((e[H>>1]|0)>=(h&65535)){break}a[I]=J&255;a[B+7|0]=J>>>8&255;a[B+8|0]=J>>>16&255}}while(0);I=B+9|0;H=C+6|0;do{if(k){J=F>>>12&15;if((J|0)==0){break}K=c[d+(J<<2)>>2]|0;if((e[H>>1]|0)>=(h&65535)){break}a[I]=K&255;a[B+10|0]=K>>>8&255;a[B+11|0]=K>>>16&255}}while(0);I=B+12|0;H=C+8|0;do{if(l){K=F>>>16&15;if((K|0)==0){break}J=c[d+(K<<2)>>2]|0;if((e[H>>1]|0)>=(h&65535)){break}a[I]=J&255;a[B+13|0]=J>>>8&255;a[B+14|0]=J>>>16&255}}while(0);I=B+15|0;H=C+10|0;do{if(m){J=F>>>20&15;if((J|0)==0){break}K=c[d+(J<<2)>>2]|0;if((e[H>>1]|0)>=(h&65535)){break}a[I]=K&255;a[B+16|0]=K>>>8&255;a[B+17|0]=K>>>16&255}}while(0);I=B+18|0;H=C+12|0;do{if(n){K=F>>>24&15;if((K|0)==0){break}J=c[d+(K<<2)>>2]|0;if((e[H>>1]|0)>=(h&65535)){break}a[I]=J&255;a[B+19|0]=J>>>8&255;a[B+20|0]=J>>>16&255}}while(0);I=B+21|0;H=C+14|0;do{if(o){J=F>>>28;if((J|0)==0){break}K=c[d+(J<<2)>>2]|0;if((e[H>>1]|0)>=(h&65535)){break}a[I]=K&255;a[B+22|0]=K>>>8&255;a[B+23|0]=K>>>16&255}}while(0);I=B+24|0;H=C+16|0;F=c[D>>2]|0;K=G|F;do{if(p){J=F&15;if((J|0)==0){break}L=c[d+(J<<2)>>2]|0;if((e[H>>1]|0)>=(h&65535)){break}a[I]=L&255;a[B+25|0]=L>>>8&255;a[B+26|0]=L>>>16&255}}while(0);I=B+27|0;H=C+18|0;do{if(q){G=F>>>4&15;if((G|0)==0){break}L=c[d+(G<<2)>>2]|0;if((e[H>>1]|0)>=(h&65535)){break}a[I]=L&255;a[B+28|0]=L>>>8&255;a[B+29|0]=L>>>16&255}}while(0);I=B+30|0;H=C+20|0;do{if(r){L=F>>>8&15;if((L|0)==0){break}G=c[d+(L<<2)>>2]|0;if((e[H>>1]|0)>=(h&65535)){break}a[I]=G&255;a[B+31|0]=G>>>8&255;a[B+32|0]=G>>>16&255}}while(0);I=B+33|0;H=C+22|0;do{if(s){G=F>>>12&15;if((G|0)==0){break}L=c[d+(G<<2)>>2]|0;if((e[H>>1]|0)>=(h&65535)){break}a[I]=L&255;a[B+34|0]=L>>>8&255;a[B+35|0]=L>>>16&255}}while(0);I=B+36|0;H=C+24|0;do{if(t){L=F>>>16&15;if((L|0)==0){break}G=c[d+(L<<2)>>2]|0;if((e[H>>1]|0)>=(h&65535)){break}a[I]=G&255;a[B+37|0]=G>>>8&255;a[B+38|0]=G>>>16&255}}while(0);I=B+39|0;H=C+26|0;do{if(u){G=F>>>20&15;if((G|0)==0){break}L=c[d+(G<<2)>>2]|0;if((e[H>>1]|0)>=(h&65535)){break}a[I]=L&255;a[B+40|0]=L>>>8&255;a[B+41|0]=L>>>16&255}}while(0);I=B+42|0;H=C+28|0;do{if(v){L=F>>>24&15;if((L|0)==0){break}G=c[d+(L<<2)>>2]|0;if((e[H>>1]|0)>=(h&65535)){break}a[I]=G&255;a[B+43|0]=G>>>8&255;a[B+44|0]=G>>>16&255}}while(0);if(!w){M=K;break}I=F>>>28;if((I|0)==0){M=K;break}H=c[d+(I<<2)>>2]|0;if((e[C+30>>1]|0)>=(h&65535)){M=K;break}a[B+45|0]=H&255;a[B+46|0]=H>>>8&255;a[B+47|0]=H>>>16&255;M=K}else{M=z}}while(0);N=B+f|0;O=D+x|0;P=C+768|0;if((y|0)>=16){break}y=y+1|0;z=M;A=E;B=N;C=P;D=O}c[2113226]=E;c[2112962]=N;c[2112924]=P;c[2112960]=O;return(M|0)==0|0}function afX(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=c[3541654]|0;f=b[3726284]|0;g=c[2113300]|0;h=c[2113224]|0;i=0;j=0;k=c[2112960]|0;l=c[2112962]|0;m=c[2112924]|0;do{n=c[k>>2]|0;o=n|j;do{if(n>>>0>268435455){p=c[d+(n>>>28<<2)>>2]|0;if((e[m>>1]|0)>=(f&65535)){break}a[l]=p&255;a[l+1|0]=p>>>8&255;a[l+2|0]=p>>>16&255}}while(0);p=l+3|0;do{if(n<<4>>>0>268435455){q=c[d+((n>>>24&15)<<2)>>2]|0;if((e[m+2>>1]|0)>=(f&65535)){break}a[p]=q&255;a[l+4|0]=q>>>8&255;a[l+5|0]=q>>>16&255}}while(0);p=l+6|0;do{if(n<<8>>>0>268435455){q=c[d+((n>>>20&15)<<2)>>2]|0;if((e[m+4>>1]|0)>=(f&65535)){break}a[p]=q&255;a[l+7|0]=q>>>8&255;a[l+8|0]=q>>>16&255}}while(0);p=l+9|0;do{if(n<<12>>>0>268435455){q=c[d+((n>>>16&15)<<2)>>2]|0;if((e[m+6>>1]|0)>=(f&65535)){break}a[p]=q&255;a[l+10|0]=q>>>8&255;a[l+11|0]=q>>>16&255}}while(0);p=l+12|0;do{if(n<<16>>>0>268435455){q=c[d+((n>>>12&15)<<2)>>2]|0;if((e[m+8>>1]|0)>=(f&65535)){break}a[p]=q&255;a[l+13|0]=q>>>8&255;a[l+14|0]=q>>>16&255}}while(0);p=l+15|0;do{if(n<<20>>>0>268435455){q=c[d+((n>>>8&15)<<2)>>2]|0;if((e[m+10>>1]|0)>=(f&65535)){break}a[p]=q&255;a[l+16|0]=q>>>8&255;a[l+17|0]=q>>>16&255}}while(0);p=l+18|0;do{if(n<<24>>>0>268435455){q=c[d+((n>>>4&15)<<2)>>2]|0;if((e[m+12>>1]|0)>=(f&65535)){break}a[p]=q&255;a[l+19|0]=q>>>8&255;a[l+20|0]=q>>>16&255}}while(0);p=l+21|0;q=n&15;do{if((q|0)!=0){r=c[d+(q<<2)>>2]|0;if((e[m+14>>1]|0)>=(f&65535)){break}a[p]=r&255;a[l+22|0]=r>>>8&255;a[l+23|0]=r>>>16&255}}while(0);p=l+24|0;q=c[k+4>>2]|0;n=o|q;do{if(q>>>0>268435455){r=c[d+(q>>>28<<2)>>2]|0;if((e[m+16>>1]|0)>=(f&65535)){break}a[p]=r&255;a[l+25|0]=r>>>8&255;a[l+26|0]=r>>>16&255}}while(0);p=l+27|0;do{if(q<<4>>>0>268435455){o=c[d+((q>>>24&15)<<2)>>2]|0;if((e[m+18>>1]|0)>=(f&65535)){break}a[p]=o&255;a[l+28|0]=o>>>8&255;a[l+29|0]=o>>>16&255}}while(0);p=l+30|0;do{if(q<<8>>>0>268435455){o=c[d+((q>>>20&15)<<2)>>2]|0;if((e[m+20>>1]|0)>=(f&65535)){break}a[p]=o&255;a[l+31|0]=o>>>8&255;a[l+32|0]=o>>>16&255}}while(0);p=l+33|0;do{if(q<<12>>>0>268435455){o=c[d+((q>>>16&15)<<2)>>2]|0;if((e[m+22>>1]|0)>=(f&65535)){break}a[p]=o&255;a[l+34|0]=o>>>8&255;a[l+35|0]=o>>>16&255}}while(0);p=l+36|0;do{if(q<<16>>>0>268435455){o=c[d+((q>>>12&15)<<2)>>2]|0;if((e[m+24>>1]|0)>=(f&65535)){break}a[p]=o&255;a[l+37|0]=o>>>8&255;a[l+38|0]=o>>>16&255}}while(0);p=l+39|0;do{if(q<<20>>>0>268435455){o=c[d+((q>>>8&15)<<2)>>2]|0;if((e[m+26>>1]|0)>=(f&65535)){break}a[p]=o&255;a[l+40|0]=o>>>8&255;a[l+41|0]=o>>>16&255}}while(0);p=l+42|0;do{if(q<<24>>>0>268435455){o=c[d+((q>>>4&15)<<2)>>2]|0;if((e[m+28>>1]|0)>=(f&65535)){break}a[p]=o&255;a[l+43|0]=o>>>8&255;a[l+44|0]=o>>>16&255}}while(0);p=l+45|0;o=q&15;do{if((o|0)!=0){r=c[d+(o<<2)>>2]|0;if((e[m+30>>1]|0)>=(f&65535)){break}a[p]=r&255;a[l+46|0]=r>>>8&255;a[l+47|0]=r>>>16&255}}while(0);p=l+48|0;o=c[k+8>>2]|0;q=n|o;do{if(o>>>0>268435455){r=c[d+(o>>>28<<2)>>2]|0;if((e[m+32>>1]|0)>=(f&65535)){break}a[p]=r&255;a[l+49|0]=r>>>8&255;a[l+50|0]=r>>>16&255}}while(0);p=l+51|0;do{if(o<<4>>>0>268435455){n=c[d+((o>>>24&15)<<2)>>2]|0;if((e[m+34>>1]|0)>=(f&65535)){break}a[p]=n&255;a[l+52|0]=n>>>8&255;a[l+53|0]=n>>>16&255}}while(0);p=l+54|0;do{if(o<<8>>>0>268435455){n=c[d+((o>>>20&15)<<2)>>2]|0;if((e[m+36>>1]|0)>=(f&65535)){break}a[p]=n&255;a[l+55|0]=n>>>8&255;a[l+56|0]=n>>>16&255}}while(0);p=l+57|0;do{if(o<<12>>>0>268435455){n=c[d+((o>>>16&15)<<2)>>2]|0;if((e[m+38>>1]|0)>=(f&65535)){break}a[p]=n&255;a[l+58|0]=n>>>8&255;a[l+59|0]=n>>>16&255}}while(0);p=l+60|0;do{if(o<<16>>>0>268435455){n=c[d+((o>>>12&15)<<2)>>2]|0;if((e[m+40>>1]|0)>=(f&65535)){break}a[p]=n&255;a[l+61|0]=n>>>8&255;a[l+62|0]=n>>>16&255}}while(0);p=l+63|0;do{if(o<<20>>>0>268435455){n=c[d+((o>>>8&15)<<2)>>2]|0;if((e[m+42>>1]|0)>=(f&65535)){break}a[p]=n&255;a[l+64|0]=n>>>8&255;a[l+65|0]=n>>>16&255}}while(0);p=l+66|0;do{if(o<<24>>>0>268435455){n=c[d+((o>>>4&15)<<2)>>2]|0;if((e[m+44>>1]|0)>=(f&65535)){break}a[p]=n&255;a[l+67|0]=n>>>8&255;a[l+68|0]=n>>>16&255}}while(0);p=l+69|0;n=o&15;do{if((n|0)!=0){r=c[d+(n<<2)>>2]|0;if((e[m+46>>1]|0)>=(f&65535)){break}a[p]=r&255;a[l+70|0]=r>>>8&255;a[l+71|0]=r>>>16&255}}while(0);p=l+72|0;n=c[k+12>>2]|0;j=q|n;do{if(n>>>0>268435455){o=c[d+(n>>>28<<2)>>2]|0;if((e[m+48>>1]|0)>=(f&65535)){break}a[p]=o&255;a[l+73|0]=o>>>8&255;a[l+74|0]=o>>>16&255}}while(0);p=l+75|0;do{if(n<<4>>>0>268435455){q=c[d+((n>>>24&15)<<2)>>2]|0;if((e[m+50>>1]|0)>=(f&65535)){break}a[p]=q&255;a[l+76|0]=q>>>8&255;a[l+77|0]=q>>>16&255}}while(0);p=l+78|0;do{if(n<<8>>>0>268435455){q=c[d+((n>>>20&15)<<2)>>2]|0;if((e[m+52>>1]|0)>=(f&65535)){break}a[p]=q&255;a[l+79|0]=q>>>8&255;a[l+80|0]=q>>>16&255}}while(0);p=l+81|0;do{if(n<<12>>>0>268435455){q=c[d+((n>>>16&15)<<2)>>2]|0;if((e[m+54>>1]|0)>=(f&65535)){break}a[p]=q&255;a[l+82|0]=q>>>8&255;a[l+83|0]=q>>>16&255}}while(0);p=l+84|0;do{if(n<<16>>>0>268435455){q=c[d+((n>>>12&15)<<2)>>2]|0;if((e[m+56>>1]|0)>=(f&65535)){break}a[p]=q&255;a[l+85|0]=q>>>8&255;a[l+86|0]=q>>>16&255}}while(0);p=l+87|0;do{if(n<<20>>>0>268435455){q=c[d+((n>>>8&15)<<2)>>2]|0;if((e[m+58>>1]|0)>=(f&65535)){break}a[p]=q&255;a[l+88|0]=q>>>8&255;a[l+89|0]=q>>>16&255}}while(0);p=l+90|0;do{if(n<<24>>>0>268435455){q=c[d+((n>>>4&15)<<2)>>2]|0;if((e[m+60>>1]|0)>=(f&65535)){break}a[p]=q&255;a[l+91|0]=q>>>8&255;a[l+92|0]=q>>>16&255}}while(0);p=l+93|0;q=n&15;do{if((q|0)!=0){o=c[d+(q<<2)>>2]|0;if((e[m+62>>1]|0)>=(f&65535)){break}a[p]=o&255;a[l+94|0]=o>>>8&255;a[l+95|0]=o>>>16&255}}while(0);i=i+1|0;l=l+g|0;k=k+h|0;m=m+768|0;}while((i|0)<32);c[2112960]=k;c[2112962]=l;c[2112924]=m;return(j|0)==0|0}function afY(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=c[3541654]|0;f=c[2113300]|0;g=c[2113224]|0;h=b[3726284]|0;i=0;j=0;k=c[2112960]|0;l=c[2112962]|0;m=c[2112924]|0;do{n=c[k+12>>2]|0;o=n|j;p=n&15;do{if((p|0)!=0){q=c[d+(p<<2)>>2]|0;if((e[m>>1]|0)>=(h&65535)){break}a[l]=q&255;a[l+1|0]=q>>>8&255;a[l+2|0]=q>>>16&255}}while(0);p=l+3|0;q=n>>>4&15;do{if((q|0)!=0){r=c[d+(q<<2)>>2]|0;if((e[m+2>>1]|0)>=(h&65535)){break}a[p]=r&255;a[l+4|0]=r>>>8&255;a[l+5|0]=r>>>16&255}}while(0);p=l+6|0;q=n>>>8&15;do{if((q|0)!=0){r=c[d+(q<<2)>>2]|0;if((e[m+4>>1]|0)>=(h&65535)){break}a[p]=r&255;a[l+7|0]=r>>>8&255;a[l+8|0]=r>>>16&255}}while(0);p=l+9|0;q=n>>>12&15;do{if((q|0)!=0){r=c[d+(q<<2)>>2]|0;if((e[m+6>>1]|0)>=(h&65535)){break}a[p]=r&255;a[l+10|0]=r>>>8&255;a[l+11|0]=r>>>16&255}}while(0);p=l+12|0;q=n>>>16&15;do{if((q|0)!=0){r=c[d+(q<<2)>>2]|0;if((e[m+8>>1]|0)>=(h&65535)){break}a[p]=r&255;a[l+13|0]=r>>>8&255;a[l+14|0]=r>>>16&255}}while(0);p=l+15|0;q=n>>>20&15;do{if((q|0)!=0){r=c[d+(q<<2)>>2]|0;if((e[m+10>>1]|0)>=(h&65535)){break}a[p]=r&255;a[l+16|0]=r>>>8&255;a[l+17|0]=r>>>16&255}}while(0);p=l+18|0;q=n>>>24&15;do{if((q|0)!=0){r=c[d+(q<<2)>>2]|0;if((e[m+12>>1]|0)>=(h&65535)){break}a[p]=r&255;a[l+19|0]=r>>>8&255;a[l+20|0]=r>>>16&255}}while(0);p=l+21|0;q=n>>>28;do{if((q|0)!=0){r=c[d+(q<<2)>>2]|0;if((e[m+14>>1]|0)>=(h&65535)){break}a[p]=r&255;a[l+22|0]=r>>>8&255;a[l+23|0]=r>>>16&255}}while(0);p=l+24|0;q=c[k+8>>2]|0;n=o|q;r=q&15;do{if((r|0)!=0){s=c[d+(r<<2)>>2]|0;if((e[m+16>>1]|0)>=(h&65535)){break}a[p]=s&255;a[l+25|0]=s>>>8&255;a[l+26|0]=s>>>16&255}}while(0);p=l+27|0;r=q>>>4&15;do{if((r|0)!=0){o=c[d+(r<<2)>>2]|0;if((e[m+18>>1]|0)>=(h&65535)){break}a[p]=o&255;a[l+28|0]=o>>>8&255;a[l+29|0]=o>>>16&255}}while(0);p=l+30|0;r=q>>>8&15;do{if((r|0)!=0){o=c[d+(r<<2)>>2]|0;if((e[m+20>>1]|0)>=(h&65535)){break}a[p]=o&255;a[l+31|0]=o>>>8&255;a[l+32|0]=o>>>16&255}}while(0);p=l+33|0;r=q>>>12&15;do{if((r|0)!=0){o=c[d+(r<<2)>>2]|0;if((e[m+22>>1]|0)>=(h&65535)){break}a[p]=o&255;a[l+34|0]=o>>>8&255;a[l+35|0]=o>>>16&255}}while(0);p=l+36|0;r=q>>>16&15;do{if((r|0)!=0){o=c[d+(r<<2)>>2]|0;if((e[m+24>>1]|0)>=(h&65535)){break}a[p]=o&255;a[l+37|0]=o>>>8&255;a[l+38|0]=o>>>16&255}}while(0);p=l+39|0;r=q>>>20&15;do{if((r|0)!=0){o=c[d+(r<<2)>>2]|0;if((e[m+26>>1]|0)>=(h&65535)){break}a[p]=o&255;a[l+40|0]=o>>>8&255;a[l+41|0]=o>>>16&255}}while(0);p=l+42|0;r=q>>>24&15;do{if((r|0)!=0){o=c[d+(r<<2)>>2]|0;if((e[m+28>>1]|0)>=(h&65535)){break}a[p]=o&255;a[l+43|0]=o>>>8&255;a[l+44|0]=o>>>16&255}}while(0);p=l+45|0;r=q>>>28;do{if((r|0)!=0){o=c[d+(r<<2)>>2]|0;if((e[m+30>>1]|0)>=(h&65535)){break}a[p]=o&255;a[l+46|0]=o>>>8&255;a[l+47|0]=o>>>16&255}}while(0);p=l+48|0;r=c[k+4>>2]|0;q=n|r;o=r&15;do{if((o|0)!=0){s=c[d+(o<<2)>>2]|0;if((e[m+32>>1]|0)>=(h&65535)){break}a[p]=s&255;a[l+49|0]=s>>>8&255;a[l+50|0]=s>>>16&255}}while(0);p=l+51|0;o=r>>>4&15;do{if((o|0)!=0){n=c[d+(o<<2)>>2]|0;if((e[m+34>>1]|0)>=(h&65535)){break}a[p]=n&255;a[l+52|0]=n>>>8&255;a[l+53|0]=n>>>16&255}}while(0);p=l+54|0;o=r>>>8&15;do{if((o|0)!=0){n=c[d+(o<<2)>>2]|0;if((e[m+36>>1]|0)>=(h&65535)){break}a[p]=n&255;a[l+55|0]=n>>>8&255;a[l+56|0]=n>>>16&255}}while(0);p=l+57|0;o=r>>>12&15;do{if((o|0)!=0){n=c[d+(o<<2)>>2]|0;if((e[m+38>>1]|0)>=(h&65535)){break}a[p]=n&255;a[l+58|0]=n>>>8&255;a[l+59|0]=n>>>16&255}}while(0);p=l+60|0;o=r>>>16&15;do{if((o|0)!=0){n=c[d+(o<<2)>>2]|0;if((e[m+40>>1]|0)>=(h&65535)){break}a[p]=n&255;a[l+61|0]=n>>>8&255;a[l+62|0]=n>>>16&255}}while(0);p=l+63|0;o=r>>>20&15;do{if((o|0)!=0){n=c[d+(o<<2)>>2]|0;if((e[m+42>>1]|0)>=(h&65535)){break}a[p]=n&255;a[l+64|0]=n>>>8&255;a[l+65|0]=n>>>16&255}}while(0);p=l+66|0;o=r>>>24&15;do{if((o|0)!=0){n=c[d+(o<<2)>>2]|0;if((e[m+44>>1]|0)>=(h&65535)){break}a[p]=n&255;a[l+67|0]=n>>>8&255;a[l+68|0]=n>>>16&255}}while(0);p=l+69|0;o=r>>>28;do{if((o|0)!=0){n=c[d+(o<<2)>>2]|0;if((e[m+46>>1]|0)>=(h&65535)){break}a[p]=n&255;a[l+70|0]=n>>>8&255;a[l+71|0]=n>>>16&255}}while(0);p=l+72|0;o=c[k>>2]|0;j=q|o;r=o&15;do{if((r|0)!=0){n=c[d+(r<<2)>>2]|0;if((e[m+48>>1]|0)>=(h&65535)){break}a[p]=n&255;a[l+73|0]=n>>>8&255;a[l+74|0]=n>>>16&255}}while(0);p=l+75|0;r=o>>>4&15;do{if((r|0)!=0){q=c[d+(r<<2)>>2]|0;if((e[m+50>>1]|0)>=(h&65535)){break}a[p]=q&255;a[l+76|0]=q>>>8&255;a[l+77|0]=q>>>16&255}}while(0);p=l+78|0;r=o>>>8&15;do{if((r|0)!=0){q=c[d+(r<<2)>>2]|0;if((e[m+52>>1]|0)>=(h&65535)){break}a[p]=q&255;a[l+79|0]=q>>>8&255;a[l+80|0]=q>>>16&255}}while(0);p=l+81|0;r=o>>>12&15;do{if((r|0)!=0){q=c[d+(r<<2)>>2]|0;if((e[m+54>>1]|0)>=(h&65535)){break}a[p]=q&255;a[l+82|0]=q>>>8&255;a[l+83|0]=q>>>16&255}}while(0);p=l+84|0;r=o>>>16&15;do{if((r|0)!=0){q=c[d+(r<<2)>>2]|0;if((e[m+56>>1]|0)>=(h&65535)){break}a[p]=q&255;a[l+85|0]=q>>>8&255;a[l+86|0]=q>>>16&255}}while(0);p=l+87|0;r=o>>>20&15;do{if((r|0)!=0){q=c[d+(r<<2)>>2]|0;if((e[m+58>>1]|0)>=(h&65535)){break}a[p]=q&255;a[l+88|0]=q>>>8&255;a[l+89|0]=q>>>16&255}}while(0);p=l+90|0;r=o>>>24&15;do{if((r|0)!=0){q=c[d+(r<<2)>>2]|0;if((e[m+60>>1]|0)>=(h&65535)){break}a[p]=q&255;a[l+91|0]=q>>>8&255;a[l+92|0]=q>>>16&255}}while(0);p=l+93|0;r=o>>>28;do{if((r|0)!=0){q=c[d+(r<<2)>>2]|0;if((e[m+62>>1]|0)>=(h&65535)){break}a[p]=q&255;a[l+94|0]=q>>>8&255;a[l+95|0]=q>>>16&255}}while(0);i=i+1|0;l=l+f|0;k=k+g|0;m=m+768|0;}while((i|0)<32);c[2112960]=k;c[2112962]=l;c[2112924]=m;return(j|0)==0|0}function afZ(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0;d=c[3541654]|0;f=c[2113228]|0;g=(f&536887296|0)==0;h=b[3726284]|0;i=(f+32767&536887296|0)==0;j=(f+65534&536887296|0)==0;k=(f+98301&536887296|0)==0;l=(f+131068&536887296|0)==0;m=(f+163835&536887296|0)==0;n=(f+196602&536887296|0)==0;o=(f+229369&536887296|0)==0;p=(f+262136&536887296|0)==0;q=(f+294903&536887296|0)==0;r=(f+327670&536887296|0)==0;s=(f+360437&536887296|0)==0;t=(f+393204&536887296|0)==0;u=(f+425971&536887296|0)==0;v=(f+458738&536887296|0)==0;w=(f+491505&536887296|0)==0;x=(f+524272&536887296|0)==0;y=(f+557039&536887296|0)==0;z=(f+589806&536887296|0)==0;A=(f+622573&536887296|0)==0;B=(f+655340&536887296|0)==0;C=(f+688107&536887296|0)==0;D=(f+720874&536887296|0)==0;E=(f+753641&536887296|0)==0;F=(f+786408&536887296|0)==0;G=(f+819175&536887296|0)==0;H=(f+851942&536887296|0)==0;I=(f+884709&536887296|0)==0;J=(f+917476&536887296|0)==0;K=(f+950243&536887296|0)==0;L=(f+983010&536887296|0)==0;M=(f+1015777&536887296|0)==0;f=c[2113300]|0;N=c[2113224]|0;O=1;P=0;Q=c[2113226]|0;R=c[2112962]|0;S=c[2112924]|0;T=c[2112960]|0;while(1){U=Q+32767|0;do{if((Q&536887296|0)==0){V=c[T>>2]|0;W=V|P;do{if(g&V>>>0>268435455){X=c[d+(V>>>28<<2)>>2]|0;if((e[S>>1]|0)>=(h&65535)){break}a[R]=X&255;a[R+1|0]=X>>>8&255;a[R+2|0]=X>>>16&255}}while(0);X=R+3|0;Y=S+2|0;do{if(i){if(V<<4>>>0<=268435455){break}Z=c[d+((V>>>24&15)<<2)>>2]|0;if((e[Y>>1]|0)>=(h&65535)){break}a[X]=Z&255;a[R+4|0]=Z>>>8&255;a[R+5|0]=Z>>>16&255}}while(0);X=R+6|0;Y=S+4|0;do{if(j){if(V<<8>>>0<=268435455){break}Z=c[d+((V>>>20&15)<<2)>>2]|0;if((e[Y>>1]|0)>=(h&65535)){break}a[X]=Z&255;a[R+7|0]=Z>>>8&255;a[R+8|0]=Z>>>16&255}}while(0);X=R+9|0;Y=S+6|0;do{if(k){if(V<<12>>>0<=268435455){break}Z=c[d+((V>>>16&15)<<2)>>2]|0;if((e[Y>>1]|0)>=(h&65535)){break}a[X]=Z&255;a[R+10|0]=Z>>>8&255;a[R+11|0]=Z>>>16&255}}while(0);X=R+12|0;Y=S+8|0;do{if(l){if(V<<16>>>0<=268435455){break}Z=c[d+((V>>>12&15)<<2)>>2]|0;if((e[Y>>1]|0)>=(h&65535)){break}a[X]=Z&255;a[R+13|0]=Z>>>8&255;a[R+14|0]=Z>>>16&255}}while(0);X=R+15|0;Y=S+10|0;do{if(m){if(V<<20>>>0<=268435455){break}Z=c[d+((V>>>8&15)<<2)>>2]|0;if((e[Y>>1]|0)>=(h&65535)){break}a[X]=Z&255;a[R+16|0]=Z>>>8&255;a[R+17|0]=Z>>>16&255}}while(0);X=R+18|0;Y=S+12|0;do{if(n){if(V<<24>>>0<=268435455){break}Z=c[d+((V>>>4&15)<<2)>>2]|0;if((e[Y>>1]|0)>=(h&65535)){break}a[X]=Z&255;a[R+19|0]=Z>>>8&255;a[R+20|0]=Z>>>16&255}}while(0);X=R+21|0;Y=S+14|0;do{if(o){Z=V&15;if((Z|0)==0){break}_=c[d+(Z<<2)>>2]|0;if((e[Y>>1]|0)>=(h&65535)){break}a[X]=_&255;a[R+22|0]=_>>>8&255;a[R+23|0]=_>>>16&255}}while(0);X=R+24|0;Y=c[T+4>>2]|0;V=W|Y;do{if(p&Y>>>0>268435455){_=c[d+(Y>>>28<<2)>>2]|0;if((e[S+16>>1]|0)>=(h&65535)){break}a[X]=_&255;a[R+25|0]=_>>>8&255;a[R+26|0]=_>>>16&255}}while(0);X=R+27|0;W=S+18|0;do{if(q){if(Y<<4>>>0<=268435455){break}_=c[d+((Y>>>24&15)<<2)>>2]|0;if((e[W>>1]|0)>=(h&65535)){break}a[X]=_&255;a[R+28|0]=_>>>8&255;a[R+29|0]=_>>>16&255}}while(0);X=R+30|0;W=S+20|0;do{if(r){if(Y<<8>>>0<=268435455){break}_=c[d+((Y>>>20&15)<<2)>>2]|0;if((e[W>>1]|0)>=(h&65535)){break}a[X]=_&255;a[R+31|0]=_>>>8&255;a[R+32|0]=_>>>16&255}}while(0);X=R+33|0;W=S+22|0;do{if(s){if(Y<<12>>>0<=268435455){break}_=c[d+((Y>>>16&15)<<2)>>2]|0;if((e[W>>1]|0)>=(h&65535)){break}a[X]=_&255;a[R+34|0]=_>>>8&255;a[R+35|0]=_>>>16&255}}while(0);X=R+36|0;W=S+24|0;do{if(t){if(Y<<16>>>0<=268435455){break}_=c[d+((Y>>>12&15)<<2)>>2]|0;if((e[W>>1]|0)>=(h&65535)){break}a[X]=_&255;a[R+37|0]=_>>>8&255;a[R+38|0]=_>>>16&255}}while(0);X=R+39|0;W=S+26|0;do{if(u){if(Y<<20>>>0<=268435455){break}_=c[d+((Y>>>8&15)<<2)>>2]|0;if((e[W>>1]|0)>=(h&65535)){break}a[X]=_&255;a[R+40|0]=_>>>8&255;a[R+41|0]=_>>>16&255}}while(0);X=R+42|0;W=S+28|0;do{if(v){if(Y<<24>>>0<=268435455){break}_=c[d+((Y>>>4&15)<<2)>>2]|0;if((e[W>>1]|0)>=(h&65535)){break}a[X]=_&255;a[R+43|0]=_>>>8&255;a[R+44|0]=_>>>16&255}}while(0);X=R+45|0;W=S+30|0;do{if(w){_=Y&15;if((_|0)==0){break}Z=c[d+(_<<2)>>2]|0;if((e[W>>1]|0)>=(h&65535)){break}a[X]=Z&255;a[R+46|0]=Z>>>8&255;a[R+47|0]=Z>>>16&255}}while(0);X=R+48|0;W=c[T+8>>2]|0;Y=V|W;do{if(x&W>>>0>268435455){Z=c[d+(W>>>28<<2)>>2]|0;if((e[S+32>>1]|0)>=(h&65535)){break}a[X]=Z&255;a[R+49|0]=Z>>>8&255;a[R+50|0]=Z>>>16&255}}while(0);X=R+51|0;V=S+34|0;do{if(y){if(W<<4>>>0<=268435455){break}Z=c[d+((W>>>24&15)<<2)>>2]|0;if((e[V>>1]|0)>=(h&65535)){break}a[X]=Z&255;a[R+52|0]=Z>>>8&255;a[R+53|0]=Z>>>16&255}}while(0);X=R+54|0;V=S+36|0;do{if(z){if(W<<8>>>0<=268435455){break}Z=c[d+((W>>>20&15)<<2)>>2]|0;if((e[V>>1]|0)>=(h&65535)){break}a[X]=Z&255;a[R+55|0]=Z>>>8&255;a[R+56|0]=Z>>>16&255}}while(0);X=R+57|0;V=S+38|0;do{if(A){if(W<<12>>>0<=268435455){break}Z=c[d+((W>>>16&15)<<2)>>2]|0;if((e[V>>1]|0)>=(h&65535)){break}a[X]=Z&255;a[R+58|0]=Z>>>8&255;a[R+59|0]=Z>>>16&255}}while(0);X=R+60|0;V=S+40|0;do{if(B){if(W<<16>>>0<=268435455){break}Z=c[d+((W>>>12&15)<<2)>>2]|0;if((e[V>>1]|0)>=(h&65535)){break}a[X]=Z&255;a[R+61|0]=Z>>>8&255;a[R+62|0]=Z>>>16&255}}while(0);X=R+63|0;V=S+42|0;do{if(C){if(W<<20>>>0<=268435455){break}Z=c[d+((W>>>8&15)<<2)>>2]|0;if((e[V>>1]|0)>=(h&65535)){break}a[X]=Z&255;a[R+64|0]=Z>>>8&255;a[R+65|0]=Z>>>16&255}}while(0);X=R+66|0;V=S+44|0;do{if(D){if(W<<24>>>0<=268435455){break}Z=c[d+((W>>>4&15)<<2)>>2]|0;if((e[V>>1]|0)>=(h&65535)){break}a[X]=Z&255;a[R+67|0]=Z>>>8&255;a[R+68|0]=Z>>>16&255}}while(0);X=R+69|0;V=S+46|0;do{if(E){Z=W&15;if((Z|0)==0){break}_=c[d+(Z<<2)>>2]|0;if((e[V>>1]|0)>=(h&65535)){break}a[X]=_&255;a[R+70|0]=_>>>8&255;a[R+71|0]=_>>>16&255}}while(0);X=R+72|0;V=c[T+12>>2]|0;W=Y|V;do{if(F&V>>>0>268435455){_=c[d+(V>>>28<<2)>>2]|0;if((e[S+48>>1]|0)>=(h&65535)){break}a[X]=_&255;a[R+73|0]=_>>>8&255;a[R+74|0]=_>>>16&255}}while(0);X=R+75|0;Y=S+50|0;do{if(G){if(V<<4>>>0<=268435455){break}_=c[d+((V>>>24&15)<<2)>>2]|0;if((e[Y>>1]|0)>=(h&65535)){break}a[X]=_&255;a[R+76|0]=_>>>8&255;a[R+77|0]=_>>>16&255}}while(0);X=R+78|0;Y=S+52|0;do{if(H){if(V<<8>>>0<=268435455){break}_=c[d+((V>>>20&15)<<2)>>2]|0;if((e[Y>>1]|0)>=(h&65535)){break}a[X]=_&255;a[R+79|0]=_>>>8&255;a[R+80|0]=_>>>16&255}}while(0);X=R+81|0;Y=S+54|0;do{if(I){if(V<<12>>>0<=268435455){break}_=c[d+((V>>>16&15)<<2)>>2]|0;if((e[Y>>1]|0)>=(h&65535)){break}a[X]=_&255;a[R+82|0]=_>>>8&255;a[R+83|0]=_>>>16&255}}while(0);X=R+84|0;Y=S+56|0;do{if(J){if(V<<16>>>0<=268435455){break}_=c[d+((V>>>12&15)<<2)>>2]|0;if((e[Y>>1]|0)>=(h&65535)){break}a[X]=_&255;a[R+85|0]=_>>>8&255;a[R+86|0]=_>>>16&255}}while(0);X=R+87|0;Y=S+58|0;do{if(K){if(V<<20>>>0<=268435455){break}_=c[d+((V>>>8&15)<<2)>>2]|0;if((e[Y>>1]|0)>=(h&65535)){break}a[X]=_&255;a[R+88|0]=_>>>8&255;a[R+89|0]=_>>>16&255}}while(0);X=R+90|0;Y=S+60|0;do{if(L){if(V<<24>>>0<=268435455){break}_=c[d+((V>>>4&15)<<2)>>2]|0;if((e[Y>>1]|0)>=(h&65535)){break}a[X]=_&255;a[R+91|0]=_>>>8&255;a[R+92|0]=_>>>16&255}}while(0);if(!M){$=W;break}X=V&15;if((X|0)==0){$=W;break}Y=c[d+(X<<2)>>2]|0;if((e[S+62>>1]|0)>=(h&65535)){$=W;break}a[R+93|0]=Y&255;a[R+94|0]=Y>>>8&255;a[R+95|0]=Y>>>16&255;$=W}else{$=P}}while(0);aa=R+f|0;ab=T+N|0;ac=S+768|0;if((O|0)>=32){break}O=O+1|0;P=$;Q=U;R=aa;S=ac;T=ab}c[2113226]=U;c[2112962]=aa;c[2112924]=ac;c[2112960]=ab;return($|0)==0|0}function af_(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0;d=c[3541654]|0;f=c[2113228]|0;g=(f&536887296|0)==0;h=b[3726284]|0;i=(f+32767&536887296|0)==0;j=(f+65534&536887296|0)==0;k=(f+98301&536887296|0)==0;l=(f+131068&536887296|0)==0;m=(f+163835&536887296|0)==0;n=(f+196602&536887296|0)==0;o=(f+229369&536887296|0)==0;p=(f+262136&536887296|0)==0;q=(f+294903&536887296|0)==0;r=(f+327670&536887296|0)==0;s=(f+360437&536887296|0)==0;t=(f+393204&536887296|0)==0;u=(f+425971&536887296|0)==0;v=(f+458738&536887296|0)==0;w=(f+491505&536887296|0)==0;x=(f+524272&536887296|0)==0;y=(f+557039&536887296|0)==0;z=(f+589806&536887296|0)==0;A=(f+622573&536887296|0)==0;B=(f+655340&536887296|0)==0;C=(f+688107&536887296|0)==0;D=(f+720874&536887296|0)==0;E=(f+753641&536887296|0)==0;F=(f+786408&536887296|0)==0;G=(f+819175&536887296|0)==0;H=(f+851942&536887296|0)==0;I=(f+884709&536887296|0)==0;J=(f+917476&536887296|0)==0;K=(f+950243&536887296|0)==0;L=(f+983010&536887296|0)==0;M=(f+1015777&536887296|0)==0;f=c[2113300]|0;N=c[2113224]|0;O=1;P=0;Q=c[2113226]|0;R=c[2112962]|0;S=c[2112924]|0;T=c[2112960]|0;while(1){U=Q+32767|0;do{if((Q&536887296|0)==0){V=c[T+12>>2]|0;W=V|P;do{if(g){X=V&15;if((X|0)==0){break}Y=c[d+(X<<2)>>2]|0;if((e[S>>1]|0)>=(h&65535)){break}a[R]=Y&255;a[R+1|0]=Y>>>8&255;a[R+2|0]=Y>>>16&255}}while(0);Y=R+3|0;X=S+2|0;do{if(i){Z=V>>>4&15;if((Z|0)==0){break}_=c[d+(Z<<2)>>2]|0;if((e[X>>1]|0)>=(h&65535)){break}a[Y]=_&255;a[R+4|0]=_>>>8&255;a[R+5|0]=_>>>16&255}}while(0);Y=R+6|0;X=S+4|0;do{if(j){_=V>>>8&15;if((_|0)==0){break}Z=c[d+(_<<2)>>2]|0;if((e[X>>1]|0)>=(h&65535)){break}a[Y]=Z&255;a[R+7|0]=Z>>>8&255;a[R+8|0]=Z>>>16&255}}while(0);Y=R+9|0;X=S+6|0;do{if(k){Z=V>>>12&15;if((Z|0)==0){break}_=c[d+(Z<<2)>>2]|0;if((e[X>>1]|0)>=(h&65535)){break}a[Y]=_&255;a[R+10|0]=_>>>8&255;a[R+11|0]=_>>>16&255}}while(0);Y=R+12|0;X=S+8|0;do{if(l){_=V>>>16&15;if((_|0)==0){break}Z=c[d+(_<<2)>>2]|0;if((e[X>>1]|0)>=(h&65535)){break}a[Y]=Z&255;a[R+13|0]=Z>>>8&255;a[R+14|0]=Z>>>16&255}}while(0);Y=R+15|0;X=S+10|0;do{if(m){Z=V>>>20&15;if((Z|0)==0){break}_=c[d+(Z<<2)>>2]|0;if((e[X>>1]|0)>=(h&65535)){break}a[Y]=_&255;a[R+16|0]=_>>>8&255;a[R+17|0]=_>>>16&255}}while(0);Y=R+18|0;X=S+12|0;do{if(n){_=V>>>24&15;if((_|0)==0){break}Z=c[d+(_<<2)>>2]|0;if((e[X>>1]|0)>=(h&65535)){break}a[Y]=Z&255;a[R+19|0]=Z>>>8&255;a[R+20|0]=Z>>>16&255}}while(0);Y=R+21|0;X=S+14|0;do{if(o){Z=V>>>28;if((Z|0)==0){break}_=c[d+(Z<<2)>>2]|0;if((e[X>>1]|0)>=(h&65535)){break}a[Y]=_&255;a[R+22|0]=_>>>8&255;a[R+23|0]=_>>>16&255}}while(0);Y=R+24|0;X=S+16|0;V=c[T+8>>2]|0;_=W|V;do{if(p){Z=V&15;if((Z|0)==0){break}$=c[d+(Z<<2)>>2]|0;if((e[X>>1]|0)>=(h&65535)){break}a[Y]=$&255;a[R+25|0]=$>>>8&255;a[R+26|0]=$>>>16&255}}while(0);Y=R+27|0;X=S+18|0;do{if(q){W=V>>>4&15;if((W|0)==0){break}$=c[d+(W<<2)>>2]|0;if((e[X>>1]|0)>=(h&65535)){break}a[Y]=$&255;a[R+28|0]=$>>>8&255;a[R+29|0]=$>>>16&255}}while(0);Y=R+30|0;X=S+20|0;do{if(r){$=V>>>8&15;if(($|0)==0){break}W=c[d+($<<2)>>2]|0;if((e[X>>1]|0)>=(h&65535)){break}a[Y]=W&255;a[R+31|0]=W>>>8&255;a[R+32|0]=W>>>16&255}}while(0);Y=R+33|0;X=S+22|0;do{if(s){W=V>>>12&15;if((W|0)==0){break}$=c[d+(W<<2)>>2]|0;if((e[X>>1]|0)>=(h&65535)){break}a[Y]=$&255;a[R+34|0]=$>>>8&255;a[R+35|0]=$>>>16&255}}while(0);Y=R+36|0;X=S+24|0;do{if(t){$=V>>>16&15;if(($|0)==0){break}W=c[d+($<<2)>>2]|0;if((e[X>>1]|0)>=(h&65535)){break}a[Y]=W&255;a[R+37|0]=W>>>8&255;a[R+38|0]=W>>>16&255}}while(0);Y=R+39|0;X=S+26|0;do{if(u){W=V>>>20&15;if((W|0)==0){break}$=c[d+(W<<2)>>2]|0;if((e[X>>1]|0)>=(h&65535)){break}a[Y]=$&255;a[R+40|0]=$>>>8&255;a[R+41|0]=$>>>16&255}}while(0);Y=R+42|0;X=S+28|0;do{if(v){$=V>>>24&15;if(($|0)==0){break}W=c[d+($<<2)>>2]|0;if((e[X>>1]|0)>=(h&65535)){break}a[Y]=W&255;a[R+43|0]=W>>>8&255;a[R+44|0]=W>>>16&255}}while(0);Y=R+45|0;X=S+30|0;do{if(w){W=V>>>28;if((W|0)==0){break}$=c[d+(W<<2)>>2]|0;if((e[X>>1]|0)>=(h&65535)){break}a[Y]=$&255;a[R+46|0]=$>>>8&255;a[R+47|0]=$>>>16&255}}while(0);Y=R+48|0;X=S+32|0;V=c[T+4>>2]|0;$=_|V;do{if(x){W=V&15;if((W|0)==0){break}Z=c[d+(W<<2)>>2]|0;if((e[X>>1]|0)>=(h&65535)){break}a[Y]=Z&255;a[R+49|0]=Z>>>8&255;a[R+50|0]=Z>>>16&255}}while(0);Y=R+51|0;X=S+34|0;do{if(y){_=V>>>4&15;if((_|0)==0){break}Z=c[d+(_<<2)>>2]|0;if((e[X>>1]|0)>=(h&65535)){break}a[Y]=Z&255;a[R+52|0]=Z>>>8&255;a[R+53|0]=Z>>>16&255}}while(0);Y=R+54|0;X=S+36|0;do{if(z){Z=V>>>8&15;if((Z|0)==0){break}_=c[d+(Z<<2)>>2]|0;if((e[X>>1]|0)>=(h&65535)){break}a[Y]=_&255;a[R+55|0]=_>>>8&255;a[R+56|0]=_>>>16&255}}while(0);Y=R+57|0;X=S+38|0;do{if(A){_=V>>>12&15;if((_|0)==0){break}Z=c[d+(_<<2)>>2]|0;if((e[X>>1]|0)>=(h&65535)){break}a[Y]=Z&255;a[R+58|0]=Z>>>8&255;a[R+59|0]=Z>>>16&255}}while(0);Y=R+60|0;X=S+40|0;do{if(B){Z=V>>>16&15;if((Z|0)==0){break}_=c[d+(Z<<2)>>2]|0;if((e[X>>1]|0)>=(h&65535)){break}a[Y]=_&255;a[R+61|0]=_>>>8&255;a[R+62|0]=_>>>16&255}}while(0);Y=R+63|0;X=S+42|0;do{if(C){_=V>>>20&15;if((_|0)==0){break}Z=c[d+(_<<2)>>2]|0;if((e[X>>1]|0)>=(h&65535)){break}a[Y]=Z&255;a[R+64|0]=Z>>>8&255;a[R+65|0]=Z>>>16&255}}while(0);Y=R+66|0;X=S+44|0;do{if(D){Z=V>>>24&15;if((Z|0)==0){break}_=c[d+(Z<<2)>>2]|0;if((e[X>>1]|0)>=(h&65535)){break}a[Y]=_&255;a[R+67|0]=_>>>8&255;a[R+68|0]=_>>>16&255}}while(0);Y=R+69|0;X=S+46|0;do{if(E){_=V>>>28;if((_|0)==0){break}Z=c[d+(_<<2)>>2]|0;if((e[X>>1]|0)>=(h&65535)){break}a[Y]=Z&255;a[R+70|0]=Z>>>8&255;a[R+71|0]=Z>>>16&255}}while(0);Y=R+72|0;X=S+48|0;V=c[T>>2]|0;Z=$|V;do{if(F){_=V&15;if((_|0)==0){break}W=c[d+(_<<2)>>2]|0;if((e[X>>1]|0)>=(h&65535)){break}a[Y]=W&255;a[R+73|0]=W>>>8&255;a[R+74|0]=W>>>16&255}}while(0);Y=R+75|0;X=S+50|0;do{if(G){$=V>>>4&15;if(($|0)==0){break}W=c[d+($<<2)>>2]|0;if((e[X>>1]|0)>=(h&65535)){break}a[Y]=W&255;a[R+76|0]=W>>>8&255;a[R+77|0]=W>>>16&255}}while(0);Y=R+78|0;X=S+52|0;do{if(H){W=V>>>8&15;if((W|0)==0){break}$=c[d+(W<<2)>>2]|0;if((e[X>>1]|0)>=(h&65535)){break}a[Y]=$&255;a[R+79|0]=$>>>8&255;a[R+80|0]=$>>>16&255}}while(0);Y=R+81|0;X=S+54|0;do{if(I){$=V>>>12&15;if(($|0)==0){break}W=c[d+($<<2)>>2]|0;if((e[X>>1]|0)>=(h&65535)){break}a[Y]=W&255;a[R+82|0]=W>>>8&255;a[R+83|0]=W>>>16&255}}while(0);Y=R+84|0;X=S+56|0;do{if(J){W=V>>>16&15;if((W|0)==0){break}$=c[d+(W<<2)>>2]|0;if((e[X>>1]|0)>=(h&65535)){break}a[Y]=$&255;a[R+85|0]=$>>>8&255;a[R+86|0]=$>>>16&255}}while(0);Y=R+87|0;X=S+58|0;do{if(K){$=V>>>20&15;if(($|0)==0){break}W=c[d+($<<2)>>2]|0;if((e[X>>1]|0)>=(h&65535)){break}a[Y]=W&255;a[R+88|0]=W>>>8&255;a[R+89|0]=W>>>16&255}}while(0);Y=R+90|0;X=S+60|0;do{if(L){W=V>>>24&15;if((W|0)==0){break}$=c[d+(W<<2)>>2]|0;if((e[X>>1]|0)>=(h&65535)){break}a[Y]=$&255;a[R+91|0]=$>>>8&255;a[R+92|0]=$>>>16&255}}while(0);if(!M){aa=Z;break}Y=V>>>28;if((Y|0)==0){aa=Z;break}X=c[d+(Y<<2)>>2]|0;if((e[S+62>>1]|0)>=(h&65535)){aa=Z;break}a[R+93|0]=X&255;a[R+94|0]=X>>>8&255;a[R+95|0]=X>>>16&255;aa=Z}else{aa=P}}while(0);ab=R+f|0;ac=T+N|0;ad=S+768|0;if((O|0)>=32){break}O=O+1|0;P=aa;Q=U;R=ab;S=ad;T=ac}c[2113226]=U;c[2112962]=ab;c[2112924]=ad;c[2112960]=ac;return(aa|0)==0|0}function af$(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[3541654]|0;d=c[2113300]|0;e=c[2113224]|0;f=0;g=0;h=c[2112962]|0;i=c[2112960]|0;do{j=c[i>>2]|0;g=j|g;if(j>>>0>268435455){k=c[b+(j>>>28<<2)>>2]|0;a[h]=k&255;a[h+1|0]=k>>>8&255;a[h+2|0]=k>>>16&255}if(j<<4>>>0>268435455){k=c[b+((j>>>24&15)<<2)>>2]|0;a[h+3|0]=k&255;a[h+4|0]=k>>>8&255;a[h+5|0]=k>>>16&255}if(j<<8>>>0>268435455){k=c[b+((j>>>20&15)<<2)>>2]|0;a[h+6|0]=k&255;a[h+7|0]=k>>>8&255;a[h+8|0]=k>>>16&255}if(j<<12>>>0>268435455){k=c[b+((j>>>16&15)<<2)>>2]|0;a[h+9|0]=k&255;a[h+10|0]=k>>>8&255;a[h+11|0]=k>>>16&255}if(j<<16>>>0>268435455){k=c[b+((j>>>12&15)<<2)>>2]|0;a[h+12|0]=k&255;a[h+13|0]=k>>>8&255;a[h+14|0]=k>>>16&255}if(j<<20>>>0>268435455){k=c[b+((j>>>8&15)<<2)>>2]|0;a[h+15|0]=k&255;a[h+16|0]=k>>>8&255;a[h+17|0]=k>>>16&255}if(j<<24>>>0>268435455){k=c[b+((j>>>4&15)<<2)>>2]|0;a[h+18|0]=k&255;a[h+19|0]=k>>>8&255;a[h+20|0]=k>>>16&255}k=j&15;if((k|0)!=0){j=c[b+(k<<2)>>2]|0;a[h+21|0]=j&255;a[h+22|0]=j>>>8&255;a[h+23|0]=j>>>16&255}f=f+1|0;h=h+d|0;i=i+e|0;}while((f|0)<8);c[2112962]=h;c[2112960]=i;return(g|0)==0|0}function af0(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=c[3541654]|0;d=c[2113300]|0;e=c[2113224]|0;f=0;g=0;h=c[2112962]|0;i=c[2112960]|0;do{j=c[i>>2]|0;g=j|g;k=j&15;if((k|0)!=0){l=c[b+(k<<2)>>2]|0;a[h]=l&255;a[h+1|0]=l>>>8&255;a[h+2|0]=l>>>16&255}l=j>>>4&15;if((l|0)!=0){k=c[b+(l<<2)>>2]|0;a[h+3|0]=k&255;a[h+4|0]=k>>>8&255;a[h+5|0]=k>>>16&255}k=j>>>8&15;if((k|0)!=0){l=c[b+(k<<2)>>2]|0;a[h+6|0]=l&255;a[h+7|0]=l>>>8&255;a[h+8|0]=l>>>16&255}l=j>>>12&15;if((l|0)!=0){k=c[b+(l<<2)>>2]|0;a[h+9|0]=k&255;a[h+10|0]=k>>>8&255;a[h+11|0]=k>>>16&255}k=j>>>16&15;if((k|0)!=0){l=c[b+(k<<2)>>2]|0;a[h+12|0]=l&255;a[h+13|0]=l>>>8&255;a[h+14|0]=l>>>16&255}l=j>>>20&15;if((l|0)!=0){k=c[b+(l<<2)>>2]|0;a[h+15|0]=k&255;a[h+16|0]=k>>>8&255;a[h+17|0]=k>>>16&255}k=j>>>24&15;if((k|0)!=0){l=c[b+(k<<2)>>2]|0;a[h+18|0]=l&255;a[h+19|0]=l>>>8&255;a[h+20|0]=l>>>16&255}l=j>>>28;if((l|0)!=0){j=c[b+(l<<2)>>2]|0;a[h+21|0]=j&255;a[h+22|0]=j>>>8&255;a[h+23|0]=j>>>16&255}f=f+1|0;h=h+d|0;i=i+e|0;}while((f|0)<8);c[2112962]=h;c[2112960]=i;return(g|0)==0|0}function af1(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;b=c[3541654]|0;d=c[2113228]|0;e=(d&536887296|0)==0;f=(d+32767&536887296|0)==0;g=(d+65534&536887296|0)==0;h=(d+98301&536887296|0)==0;i=(d+131068&536887296|0)==0;j=(d+163835&536887296|0)==0;k=(d+196602&536887296|0)==0;l=(d+229369&536887296|0)==0;d=c[2113300]|0;m=c[2113224]|0;n=1;o=0;p=c[2113226]|0;q=c[2112962]|0;r=c[2112960]|0;while(1){s=p+32767|0;do{if((p&536887296|0)==0){t=c[r>>2]|0;u=t|o;if(e&t>>>0>268435455){v=c[b+(t>>>28<<2)>>2]|0;a[q]=v&255;a[q+1|0]=v>>>8&255;a[q+2|0]=v>>>16&255}v=q+3|0;do{if(f){if(t<<4>>>0<=268435455){break}w=c[b+((t>>>24&15)<<2)>>2]|0;a[v]=w&255;a[q+4|0]=w>>>8&255;a[q+5|0]=w>>>16&255}}while(0);v=q+6|0;do{if(g){if(t<<8>>>0<=268435455){break}w=c[b+((t>>>20&15)<<2)>>2]|0;a[v]=w&255;a[q+7|0]=w>>>8&255;a[q+8|0]=w>>>16&255}}while(0);v=q+9|0;do{if(h){if(t<<12>>>0<=268435455){break}w=c[b+((t>>>16&15)<<2)>>2]|0;a[v]=w&255;a[q+10|0]=w>>>8&255;a[q+11|0]=w>>>16&255}}while(0);v=q+12|0;do{if(i){if(t<<16>>>0<=268435455){break}w=c[b+((t>>>12&15)<<2)>>2]|0;a[v]=w&255;a[q+13|0]=w>>>8&255;a[q+14|0]=w>>>16&255}}while(0);v=q+15|0;do{if(j){if(t<<20>>>0<=268435455){break}w=c[b+((t>>>8&15)<<2)>>2]|0;a[v]=w&255;a[q+16|0]=w>>>8&255;a[q+17|0]=w>>>16&255}}while(0);v=q+18|0;do{if(k){if(t<<24>>>0<=268435455){break}w=c[b+((t>>>4&15)<<2)>>2]|0;a[v]=w&255;a[q+19|0]=w>>>8&255;a[q+20|0]=w>>>16&255}}while(0);if(!l){x=u;break}v=t&15;if((v|0)==0){x=u;break}w=c[b+(v<<2)>>2]|0;a[q+21|0]=w&255;a[q+22|0]=w>>>8&255;a[q+23|0]=w>>>16&255;x=u}else{x=o}}while(0);y=q+d|0;z=r+m|0;if((n|0)>=8){break}n=n+1|0;o=x;p=s;q=y;r=z}c[2113226]=s;c[2112962]=y;c[2112960]=z;return(x|0)==0|0}function af2(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;b=c[3541654]|0;d=c[2113228]|0;e=(d&536887296|0)==0;f=(d+32767&536887296|0)==0;g=(d+65534&536887296|0)==0;h=(d+98301&536887296|0)==0;i=(d+131068&536887296|0)==0;j=(d+163835&536887296|0)==0;k=(d+196602&536887296|0)==0;l=(d+229369&536887296|0)==0;d=c[2113300]|0;m=c[2113224]|0;n=1;o=0;p=c[2113226]|0;q=c[2112962]|0;r=c[2112960]|0;while(1){s=p+32767|0;do{if((p&536887296|0)==0){t=c[r>>2]|0;u=t|o;do{if(e){v=t&15;if((v|0)==0){break}w=c[b+(v<<2)>>2]|0;a[q]=w&255;a[q+1|0]=w>>>8&255;a[q+2|0]=w>>>16&255}}while(0);w=q+3|0;do{if(f){v=t>>>4&15;if((v|0)==0){break}x=c[b+(v<<2)>>2]|0;a[w]=x&255;a[q+4|0]=x>>>8&255;a[q+5|0]=x>>>16&255}}while(0);w=q+6|0;do{if(g){x=t>>>8&15;if((x|0)==0){break}v=c[b+(x<<2)>>2]|0;a[w]=v&255;a[q+7|0]=v>>>8&255;a[q+8|0]=v>>>16&255}}while(0);w=q+9|0;do{if(h){v=t>>>12&15;if((v|0)==0){break}x=c[b+(v<<2)>>2]|0;a[w]=x&255;a[q+10|0]=x>>>8&255;a[q+11|0]=x>>>16&255}}while(0);w=q+12|0;do{if(i){x=t>>>16&15;if((x|0)==0){break}v=c[b+(x<<2)>>2]|0;a[w]=v&255;a[q+13|0]=v>>>8&255;a[q+14|0]=v>>>16&255}}while(0);w=q+15|0;do{if(j){v=t>>>20&15;if((v|0)==0){break}x=c[b+(v<<2)>>2]|0;a[w]=x&255;a[q+16|0]=x>>>8&255;a[q+17|0]=x>>>16&255}}while(0);w=q+18|0;do{if(k){x=t>>>24&15;if((x|0)==0){break}v=c[b+(x<<2)>>2]|0;a[w]=v&255;a[q+19|0]=v>>>8&255;a[q+20|0]=v>>>16&255}}while(0);if(!l){y=u;break}w=t>>>28;if((w|0)==0){y=u;break}v=c[b+(w<<2)>>2]|0;a[q+21|0]=v&255;a[q+22|0]=v>>>8&255;a[q+23|0]=v>>>16&255;y=u}else{y=o}}while(0);z=q+d|0;A=r+m|0;if((n|0)>=8){break}n=n+1|0;o=y;p=s;q=z;r=A}c[2113226]=s;c[2112962]=z;c[2112960]=A;return(y|0)==0|0}function af3(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=c[3541654]|0;d=c[2113300]|0;e=c[2113224]|0;f=0;g=0;h=c[2112960]|0;i=c[2112962]|0;do{j=c[h>>2]|0;if(j>>>0>268435455){k=c[b+(j>>>28<<2)>>2]|0;a[i]=k&255;a[i+1|0]=k>>>8&255;a[i+2|0]=k>>>16&255}if(j<<4>>>0>268435455){k=c[b+((j>>>24&15)<<2)>>2]|0;a[i+3|0]=k&255;a[i+4|0]=k>>>8&255;a[i+5|0]=k>>>16&255}if(j<<8>>>0>268435455){k=c[b+((j>>>20&15)<<2)>>2]|0;a[i+6|0]=k&255;a[i+7|0]=k>>>8&255;a[i+8|0]=k>>>16&255}if(j<<12>>>0>268435455){k=c[b+((j>>>16&15)<<2)>>2]|0;a[i+9|0]=k&255;a[i+10|0]=k>>>8&255;a[i+11|0]=k>>>16&255}if(j<<16>>>0>268435455){k=c[b+((j>>>12&15)<<2)>>2]|0;a[i+12|0]=k&255;a[i+13|0]=k>>>8&255;a[i+14|0]=k>>>16&255}if(j<<20>>>0>268435455){k=c[b+((j>>>8&15)<<2)>>2]|0;a[i+15|0]=k&255;a[i+16|0]=k>>>8&255;a[i+17|0]=k>>>16&255}if(j<<24>>>0>268435455){k=c[b+((j>>>4&15)<<2)>>2]|0;a[i+18|0]=k&255;a[i+19|0]=k>>>8&255;a[i+20|0]=k>>>16&255}k=j&15;if((k|0)!=0){l=c[b+(k<<2)>>2]|0;a[i+21|0]=l&255;a[i+22|0]=l>>>8&255;a[i+23|0]=l>>>16&255}l=c[h+4>>2]|0;g=j|g|l;if(l>>>0>268435455){j=c[b+(l>>>28<<2)>>2]|0;a[i+24|0]=j&255;a[i+25|0]=j>>>8&255;a[i+26|0]=j>>>16&255}if(l<<4>>>0>268435455){j=c[b+((l>>>24&15)<<2)>>2]|0;a[i+27|0]=j&255;a[i+28|0]=j>>>8&255;a[i+29|0]=j>>>16&255}if(l<<8>>>0>268435455){j=c[b+((l>>>20&15)<<2)>>2]|0;a[i+30|0]=j&255;a[i+31|0]=j>>>8&255;a[i+32|0]=j>>>16&255}if(l<<12>>>0>268435455){j=c[b+((l>>>16&15)<<2)>>2]|0;a[i+33|0]=j&255;a[i+34|0]=j>>>8&255;a[i+35|0]=j>>>16&255}if(l<<16>>>0>268435455){j=c[b+((l>>>12&15)<<2)>>2]|0;a[i+36|0]=j&255;a[i+37|0]=j>>>8&255;a[i+38|0]=j>>>16&255}if(l<<20>>>0>268435455){j=c[b+((l>>>8&15)<<2)>>2]|0;a[i+39|0]=j&255;a[i+40|0]=j>>>8&255;a[i+41|0]=j>>>16&255}if(l<<24>>>0>268435455){j=c[b+((l>>>4&15)<<2)>>2]|0;a[i+42|0]=j&255;a[i+43|0]=j>>>8&255;a[i+44|0]=j>>>16&255}j=l&15;if((j|0)!=0){l=c[b+(j<<2)>>2]|0;a[i+45|0]=l&255;a[i+46|0]=l>>>8&255;a[i+47|0]=l>>>16&255}f=f+1|0;i=i+d|0;h=h+e|0;}while((f|0)<16);c[2112960]=h;c[2112962]=i;return(g|0)==0|0}function af4(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=c[3541654]|0;d=c[2113300]|0;e=c[2113224]|0;f=0;g=0;h=c[2112960]|0;i=c[2112962]|0;do{j=c[h+4>>2]|0;k=j&15;if((k|0)!=0){l=c[b+(k<<2)>>2]|0;a[i]=l&255;a[i+1|0]=l>>>8&255;a[i+2|0]=l>>>16&255}l=j>>>4&15;if((l|0)!=0){k=c[b+(l<<2)>>2]|0;a[i+3|0]=k&255;a[i+4|0]=k>>>8&255;a[i+5|0]=k>>>16&255}k=j>>>8&15;if((k|0)!=0){l=c[b+(k<<2)>>2]|0;a[i+6|0]=l&255;a[i+7|0]=l>>>8&255;a[i+8|0]=l>>>16&255}l=j>>>12&15;if((l|0)!=0){k=c[b+(l<<2)>>2]|0;a[i+9|0]=k&255;a[i+10|0]=k>>>8&255;a[i+11|0]=k>>>16&255}k=j>>>16&15;if((k|0)!=0){l=c[b+(k<<2)>>2]|0;a[i+12|0]=l&255;a[i+13|0]=l>>>8&255;a[i+14|0]=l>>>16&255}l=j>>>20&15;if((l|0)!=0){k=c[b+(l<<2)>>2]|0;a[i+15|0]=k&255;a[i+16|0]=k>>>8&255;a[i+17|0]=k>>>16&255}k=j>>>24&15;if((k|0)!=0){l=c[b+(k<<2)>>2]|0;a[i+18|0]=l&255;a[i+19|0]=l>>>8&255;a[i+20|0]=l>>>16&255}l=j>>>28;if((l|0)!=0){k=c[b+(l<<2)>>2]|0;a[i+21|0]=k&255;a[i+22|0]=k>>>8&255;a[i+23|0]=k>>>16&255}k=c[h>>2]|0;g=j|g|k;j=k&15;if((j|0)!=0){l=c[b+(j<<2)>>2]|0;a[i+24|0]=l&255;a[i+25|0]=l>>>8&255;a[i+26|0]=l>>>16&255}l=k>>>4&15;if((l|0)!=0){j=c[b+(l<<2)>>2]|0;a[i+27|0]=j&255;a[i+28|0]=j>>>8&255;a[i+29|0]=j>>>16&255}j=k>>>8&15;if((j|0)!=0){l=c[b+(j<<2)>>2]|0;a[i+30|0]=l&255;a[i+31|0]=l>>>8&255;a[i+32|0]=l>>>16&255}l=k>>>12&15;if((l|0)!=0){j=c[b+(l<<2)>>2]|0;a[i+33|0]=j&255;a[i+34|0]=j>>>8&255;a[i+35|0]=j>>>16&255}j=k>>>16&15;if((j|0)!=0){l=c[b+(j<<2)>>2]|0;a[i+36|0]=l&255;a[i+37|0]=l>>>8&255;a[i+38|0]=l>>>16&255}l=k>>>20&15;if((l|0)!=0){j=c[b+(l<<2)>>2]|0;a[i+39|0]=j&255;a[i+40|0]=j>>>8&255;a[i+41|0]=j>>>16&255}j=k>>>24&15;if((j|0)!=0){l=c[b+(j<<2)>>2]|0;a[i+42|0]=l&255;a[i+43|0]=l>>>8&255;a[i+44|0]=l>>>16&255}l=k>>>28;if((l|0)!=0){k=c[b+(l<<2)>>2]|0;a[i+45|0]=k&255;a[i+46|0]=k>>>8&255;a[i+47|0]=k>>>16&255}f=f+1|0;i=i+d|0;h=h+e|0;}while((f|0)<16);c[2112960]=h;c[2112962]=i;return(g|0)==0|0}function af5(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;b=c[3541654]|0;d=c[2113228]|0;e=(d&536887296|0)==0;f=(d+32767&536887296|0)==0;g=(d+65534&536887296|0)==0;h=(d+98301&536887296|0)==0;i=(d+131068&536887296|0)==0;j=(d+163835&536887296|0)==0;k=(d+196602&536887296|0)==0;l=(d+229369&536887296|0)==0;m=(d+262136&536887296|0)==0;n=(d+294903&536887296|0)==0;o=(d+327670&536887296|0)==0;p=(d+360437&536887296|0)==0;q=(d+393204&536887296|0)==0;r=(d+425971&536887296|0)==0;s=(d+458738&536887296|0)==0;t=(d+491505&536887296|0)==0;d=c[2113300]|0;u=c[2113224]|0;v=1;w=0;x=c[2113226]|0;y=c[2112962]|0;z=c[2112960]|0;while(1){A=x+32767|0;do{if((x&536887296|0)==0){B=c[z>>2]|0;C=B|w;if(e&B>>>0>268435455){D=c[b+(B>>>28<<2)>>2]|0;a[y]=D&255;a[y+1|0]=D>>>8&255;a[y+2|0]=D>>>16&255}D=y+3|0;do{if(f){if(B<<4>>>0<=268435455){break}E=c[b+((B>>>24&15)<<2)>>2]|0;a[D]=E&255;a[y+4|0]=E>>>8&255;a[y+5|0]=E>>>16&255}}while(0);D=y+6|0;do{if(g){if(B<<8>>>0<=268435455){break}E=c[b+((B>>>20&15)<<2)>>2]|0;a[D]=E&255;a[y+7|0]=E>>>8&255;a[y+8|0]=E>>>16&255}}while(0);D=y+9|0;do{if(h){if(B<<12>>>0<=268435455){break}E=c[b+((B>>>16&15)<<2)>>2]|0;a[D]=E&255;a[y+10|0]=E>>>8&255;a[y+11|0]=E>>>16&255}}while(0);D=y+12|0;do{if(i){if(B<<16>>>0<=268435455){break}E=c[b+((B>>>12&15)<<2)>>2]|0;a[D]=E&255;a[y+13|0]=E>>>8&255;a[y+14|0]=E>>>16&255}}while(0);D=y+15|0;do{if(j){if(B<<20>>>0<=268435455){break}E=c[b+((B>>>8&15)<<2)>>2]|0;a[D]=E&255;a[y+16|0]=E>>>8&255;a[y+17|0]=E>>>16&255}}while(0);D=y+18|0;do{if(k){if(B<<24>>>0<=268435455){break}E=c[b+((B>>>4&15)<<2)>>2]|0;a[D]=E&255;a[y+19|0]=E>>>8&255;a[y+20|0]=E>>>16&255}}while(0);D=y+21|0;do{if(l){E=B&15;if((E|0)==0){break}F=c[b+(E<<2)>>2]|0;a[D]=F&255;a[y+22|0]=F>>>8&255;a[y+23|0]=F>>>16&255}}while(0);D=c[z+4>>2]|0;B=C|D;if(m&D>>>0>268435455){F=c[b+(D>>>28<<2)>>2]|0;a[y+24|0]=F&255;a[y+25|0]=F>>>8&255;a[y+26|0]=F>>>16&255}F=y+27|0;do{if(n){if(D<<4>>>0<=268435455){break}E=c[b+((D>>>24&15)<<2)>>2]|0;a[F]=E&255;a[y+28|0]=E>>>8&255;a[y+29|0]=E>>>16&255}}while(0);F=y+30|0;do{if(o){if(D<<8>>>0<=268435455){break}C=c[b+((D>>>20&15)<<2)>>2]|0;a[F]=C&255;a[y+31|0]=C>>>8&255;a[y+32|0]=C>>>16&255}}while(0);F=y+33|0;do{if(p){if(D<<12>>>0<=268435455){break}C=c[b+((D>>>16&15)<<2)>>2]|0;a[F]=C&255;a[y+34|0]=C>>>8&255;a[y+35|0]=C>>>16&255}}while(0);F=y+36|0;do{if(q){if(D<<16>>>0<=268435455){break}C=c[b+((D>>>12&15)<<2)>>2]|0;a[F]=C&255;a[y+37|0]=C>>>8&255;a[y+38|0]=C>>>16&255}}while(0);F=y+39|0;do{if(r){if(D<<20>>>0<=268435455){break}C=c[b+((D>>>8&15)<<2)>>2]|0;a[F]=C&255;a[y+40|0]=C>>>8&255;a[y+41|0]=C>>>16&255}}while(0);F=y+42|0;do{if(s){if(D<<24>>>0<=268435455){break}C=c[b+((D>>>4&15)<<2)>>2]|0;a[F]=C&255;a[y+43|0]=C>>>8&255;a[y+44|0]=C>>>16&255}}while(0);if(!t){G=B;break}F=D&15;if((F|0)==0){G=B;break}C=c[b+(F<<2)>>2]|0;a[y+45|0]=C&255;a[y+46|0]=C>>>8&255;a[y+47|0]=C>>>16&255;G=B}else{G=w}}while(0);H=y+d|0;I=z+u|0;if((v|0)>=16){break}v=v+1|0;w=G;x=A;y=H;z=I}c[2113226]=A;c[2112962]=H;c[2112960]=I;return(G|0)==0|0}function af6(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;b=c[3541654]|0;d=c[2113228]|0;e=(d&536887296|0)==0;f=(d+32767&536887296|0)==0;g=(d+65534&536887296|0)==0;h=(d+98301&536887296|0)==0;i=(d+131068&536887296|0)==0;j=(d+163835&536887296|0)==0;k=(d+196602&536887296|0)==0;l=(d+229369&536887296|0)==0;m=(d+262136&536887296|0)==0;n=(d+294903&536887296|0)==0;o=(d+327670&536887296|0)==0;p=(d+360437&536887296|0)==0;q=(d+393204&536887296|0)==0;r=(d+425971&536887296|0)==0;s=(d+458738&536887296|0)==0;t=(d+491505&536887296|0)==0;d=c[2113300]|0;u=c[2113224]|0;v=1;w=0;x=c[2113226]|0;y=c[2112962]|0;z=c[2112960]|0;while(1){A=x+32767|0;do{if((x&536887296|0)==0){B=c[z+4>>2]|0;C=B|w;do{if(e){D=B&15;if((D|0)==0){break}E=c[b+(D<<2)>>2]|0;a[y]=E&255;a[y+1|0]=E>>>8&255;a[y+2|0]=E>>>16&255}}while(0);E=y+3|0;do{if(f){D=B>>>4&15;if((D|0)==0){break}F=c[b+(D<<2)>>2]|0;a[E]=F&255;a[y+4|0]=F>>>8&255;a[y+5|0]=F>>>16&255}}while(0);E=y+6|0;do{if(g){F=B>>>8&15;if((F|0)==0){break}D=c[b+(F<<2)>>2]|0;a[E]=D&255;a[y+7|0]=D>>>8&255;a[y+8|0]=D>>>16&255}}while(0);E=y+9|0;do{if(h){D=B>>>12&15;if((D|0)==0){break}F=c[b+(D<<2)>>2]|0;a[E]=F&255;a[y+10|0]=F>>>8&255;a[y+11|0]=F>>>16&255}}while(0);E=y+12|0;do{if(i){F=B>>>16&15;if((F|0)==0){break}D=c[b+(F<<2)>>2]|0;a[E]=D&255;a[y+13|0]=D>>>8&255;a[y+14|0]=D>>>16&255}}while(0);E=y+15|0;do{if(j){D=B>>>20&15;if((D|0)==0){break}F=c[b+(D<<2)>>2]|0;a[E]=F&255;a[y+16|0]=F>>>8&255;a[y+17|0]=F>>>16&255}}while(0);E=y+18|0;do{if(k){F=B>>>24&15;if((F|0)==0){break}D=c[b+(F<<2)>>2]|0;a[E]=D&255;a[y+19|0]=D>>>8&255;a[y+20|0]=D>>>16&255}}while(0);E=y+21|0;do{if(l){D=B>>>28;if((D|0)==0){break}F=c[b+(D<<2)>>2]|0;a[E]=F&255;a[y+22|0]=F>>>8&255;a[y+23|0]=F>>>16&255}}while(0);E=y+24|0;B=c[z>>2]|0;F=C|B;do{if(m){D=B&15;if((D|0)==0){break}G=c[b+(D<<2)>>2]|0;a[E]=G&255;a[y+25|0]=G>>>8&255;a[y+26|0]=G>>>16&255}}while(0);E=y+27|0;do{if(n){C=B>>>4&15;if((C|0)==0){break}G=c[b+(C<<2)>>2]|0;a[E]=G&255;a[y+28|0]=G>>>8&255;a[y+29|0]=G>>>16&255}}while(0);E=y+30|0;do{if(o){G=B>>>8&15;if((G|0)==0){break}C=c[b+(G<<2)>>2]|0;a[E]=C&255;a[y+31|0]=C>>>8&255;a[y+32|0]=C>>>16&255}}while(0);E=y+33|0;do{if(p){C=B>>>12&15;if((C|0)==0){break}G=c[b+(C<<2)>>2]|0;a[E]=G&255;a[y+34|0]=G>>>8&255;a[y+35|0]=G>>>16&255}}while(0);E=y+36|0;do{if(q){G=B>>>16&15;if((G|0)==0){break}C=c[b+(G<<2)>>2]|0;a[E]=C&255;a[y+37|0]=C>>>8&255;a[y+38|0]=C>>>16&255}}while(0);E=y+39|0;do{if(r){C=B>>>20&15;if((C|0)==0){break}G=c[b+(C<<2)>>2]|0;a[E]=G&255;a[y+40|0]=G>>>8&255;a[y+41|0]=G>>>16&255}}while(0);E=y+42|0;do{if(s){G=B>>>24&15;if((G|0)==0){break}C=c[b+(G<<2)>>2]|0;a[E]=C&255;a[y+43|0]=C>>>8&255;a[y+44|0]=C>>>16&255}}while(0);if(!t){H=F;break}E=B>>>28;if((E|0)==0){H=F;break}C=c[b+(E<<2)>>2]|0;a[y+45|0]=C&255;a[y+46|0]=C>>>8&255;a[y+47|0]=C>>>16&255;H=F}else{H=w}}while(0);I=y+d|0;J=z+u|0;if((v|0)>=16){break}v=v+1|0;w=H;x=A;y=I;z=J}c[2113226]=A;c[2112962]=I;c[2112960]=J;return(H|0)==0|0}function af7(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=c[3541654]|0;e=c[2113308]|0;f=c[2113300]|0;g=c[2113224]|0;h=1;i=0;j=c[3541650]|0;k=c[2112960]|0;l=c[2112962]|0;while(1){m=ag(b[j>>1]|0,e)|0;n=c[k>>2]|0;if(n>>>0>268435455){o=c[d+(n>>>28<<2)>>2]|0;a[l+m|0]=o&255;a[l+(m+1)|0]=o>>>8&255;a[l+(m+2)|0]=o>>>16&255}if(n<<4>>>0>268435455){o=c[d+((n>>>24&15)<<2)>>2]|0;a[l+(m+3)|0]=o&255;a[l+(m+4)|0]=o>>>8&255;a[l+(m+5)|0]=o>>>16&255}if(n<<8>>>0>268435455){o=c[d+((n>>>20&15)<<2)>>2]|0;a[l+(m+6)|0]=o&255;a[l+(m+7)|0]=o>>>8&255;a[l+(m+8)|0]=o>>>16&255}if(n<<12>>>0>268435455){o=c[d+((n>>>16&15)<<2)>>2]|0;a[l+(m+9)|0]=o&255;a[l+(m+10)|0]=o>>>8&255;a[l+(m+11)|0]=o>>>16&255}if(n<<16>>>0>268435455){o=c[d+((n>>>12&15)<<2)>>2]|0;a[l+(m+12)|0]=o&255;a[l+(m+13)|0]=o>>>8&255;a[l+(m+14)|0]=o>>>16&255}if(n<<20>>>0>268435455){o=c[d+((n>>>8&15)<<2)>>2]|0;a[l+(m+15)|0]=o&255;a[l+(m+16)|0]=o>>>8&255;a[l+(m+17)|0]=o>>>16&255}if(n<<24>>>0>268435455){o=c[d+((n>>>4&15)<<2)>>2]|0;a[l+(m+18)|0]=o&255;a[l+(m+19)|0]=o>>>8&255;a[l+(m+20)|0]=o>>>16&255}o=n&15;if((o|0)!=0){p=c[d+(o<<2)>>2]|0;a[l+(m+21)|0]=p&255;a[l+(m+22)|0]=p>>>8&255;a[l+(m+23)|0]=p>>>16&255}p=c[k+4>>2]|0;q=n|i|p;if(p>>>0>268435455){n=c[d+(p>>>28<<2)>>2]|0;a[l+(m+24)|0]=n&255;a[l+(m+25)|0]=n>>>8&255;a[l+(m+26)|0]=n>>>16&255}if(p<<4>>>0>268435455){n=c[d+((p>>>24&15)<<2)>>2]|0;a[l+(m+27)|0]=n&255;a[l+(m+28)|0]=n>>>8&255;a[l+(m+29)|0]=n>>>16&255}if(p<<8>>>0>268435455){n=c[d+((p>>>20&15)<<2)>>2]|0;a[l+(m+30)|0]=n&255;a[l+(m+31)|0]=n>>>8&255;a[l+(m+32)|0]=n>>>16&255}if(p<<12>>>0>268435455){n=c[d+((p>>>16&15)<<2)>>2]|0;a[l+(m+33)|0]=n&255;a[l+(m+34)|0]=n>>>8&255;a[l+(m+35)|0]=n>>>16&255}if(p<<16>>>0>268435455){n=c[d+((p>>>12&15)<<2)>>2]|0;a[l+(m+36)|0]=n&255;a[l+(m+37)|0]=n>>>8&255;a[l+(m+38)|0]=n>>>16&255}if(p<<20>>>0>268435455){n=c[d+((p>>>8&15)<<2)>>2]|0;a[l+(m+39)|0]=n&255;a[l+(m+40)|0]=n>>>8&255;a[l+(m+41)|0]=n>>>16&255}if(p<<24>>>0>268435455){n=c[d+((p>>>4&15)<<2)>>2]|0;a[l+(m+42)|0]=n&255;a[l+(m+43)|0]=n>>>8&255;a[l+(m+44)|0]=n>>>16&255}n=p&15;if((n|0)!=0){p=c[d+(n<<2)>>2]|0;a[l+(m+45)|0]=p&255;a[l+(m+46)|0]=p>>>8&255;a[l+(m+47)|0]=p>>>16&255}r=l+f|0;s=k+g|0;if((h|0)>=16){break}h=h+1|0;i=q;j=j+2|0;k=s;l=r}c[2112960]=s;c[2112962]=r;return(q|0)==0|0}
function f45(f){f=f|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0,cf=0,cg=0,ch=0,ci=0,cj=0,ck=0,cl=0,cm=0,cn=0,co=0,cp=0,cq=0,cr=0,cs=0,ct=0,cu=0,cv=0,cw=0,cx=0,cy=0,cz=0,cA=0,cB=0,cC=0,cD=0,cE=0,cF=0,cG=0,cH=0,cI=0,cJ=0,cK=0,cL=0,cM=0,cN=0,cO=0,cP=0,cQ=0,cR=0,cS=0,cT=0,cU=0,cV=0,cW=0,cX=0,cY=0,cZ=0,c_=0,c$=0,c0=0,c1=0,c2=0,c3=0,c4=0,c5=0,c6=0,c7=0,c8=0,c9=0,da=0,db=0,dc=0,dd=0,de=0,df=0,dg=0,dh=0,di=0,dj=0,dk=0,dl=0,dm=0,dn=0,dp=0,dq=0,dr=0,ds=0,dt=0,du=0,dv=0,dw=0,dx=0,dy=0,dz=0,dA=0,dB=0,dC=0,dD=0,dE=0,dF=0,dG=0,dH=0,dI=0,dJ=0,dK=0,dL=0,dM=0,dN=0,dO=0,dP=0,dQ=0,dR=0,dS=0,dT=0,dU=0,dV=0,dW=0,dX=0,dY=0;h=i;i=i+51872|0;c[2440592]=f-(c[2415197]|0);c[2415197]=0;if((a[9660796]&24)!=0){c[2440592]=0;j=0;k=f-j|0;i=h;return k|0}do{l=c[2415188]|0;c[2415189]=l;m=c[3528554]|0;n=c[2433592]|0;o=c[n+(m*3148|0)+48+((l>>>8&255|512)<<2)>>2]|0;do{if((o|0)==0){p=c[n+(m*3148|0)+3128>>2]|0;if((p|0)==0){q=0;r=l&65535;break}s=gj[p&4095](l&65535)|0;q=s;r=b[4830376]|0}else{q=a[o+(l&255)|0]|0;r=l&65535}}while(0);a[9660785]=q;l=r+1&65535;b[4830376]=l;L48643:do{o=1;m=q&255|0;if(o){o=0;switch(m|0){case 9:{c[2426864]=c[2415191];n=c[2415188]|0;s=c[3528554]|0;p=c[2433592]|0;t=c[p+(s*3148|0)+48+((n>>>8&255)<<2)>>2]|0;do{if((t|0)==0){u=c[p+(s*3148|0)+3132>>2]|0;if((u|0)==0){v=0;w=n&65535;x=s;y=p;break}z=gj[u&4095](n&65535)|0;v=z;w=b[4830376]|0;x=c[3528554]|0;y=c[2433592]|0}else{v=a[t+(n&255)|0]|0;w=n&65535;x=s;y=p}}while(0);a[9707456]=v;b[4830376]=w+1&65535;p=c[2426864]|0;s=c[y+(x*3148|0)+48+((p>>>8&255)<<2)>>2]|0;do{if((s|0)==0){n=c[y+(x*3148|0)+3120>>2]|0;if((n|0)==0){A=0;C=p;D=x;E=y;break}t=gj[n&4095](p&65535)|0;A=t;C=c[2426864]|0;D=c[3528554]|0;E=c[2433592]|0}else{A=a[s+(p&255)|0]|0;C=p;D=x;E=y}}while(0);p=a[9660784]|0;s=A&255;t=p&-16|(A&255)>>>3&8;a[9660784]=((s<<1^s)>>>6&2|s>>>7|(((p&1|s<<1)&255)<<24>>24==0?t|4:t)&255)&255;t=C&65535;n=c[E+(D*3148|0)+48+((C>>>8&255|256)<<2)>>2]|0;do{if((n|0)==0){z=c[E+(D*3148|0)+3124>>2]|0;if((z|0)==0){break}gg[z&4095](t,(p&1|s<<1)&255)}else{a[n+(C&255)|0]=(p&1|s<<1)&255}}while(0);s=(c[2440592]|0)-6|0;c[2440592]=s;F=s;break};case 17:{s=c[2415188]|0;p=c[3528554]|0;n=c[2433592]|0;t=c[n+(p*3148|0)+48+((s>>>8&255|512)<<2)>>2]|0;do{if((t|0)==0){z=c[n+(p*3148|0)+3128>>2]|0;if((z|0)==0){G=0;H=s&65535;break}u=gj[z&4095](s&65535)|0;G=u;H=b[4830376]|0}else{G=a[t+(s&255)|0]|0;H=s&65535}}while(0);s=H+1&65535;b[4830376]=s;switch(G&255|0){case 63:{a[9660784]=a[9660784]|-128;b[4830386]=(b[4830386]|0)-1&65535;t=c[2415193]|0;p=c[3528554]|0;n=c[2433592]|0;u=c[n+(p*3148|0)+48+((t>>>8&255|256)<<2)>>2]|0;do{if((u|0)==0){z=c[n+(p*3148|0)+3124>>2]|0;if((z|0)==0){K=p;L=n;break}gg[z&4095](t&65535,s&255);K=c[3528554]|0;L=c[2433592]|0}else{a[u+(t&255)|0]=s&255;K=p;L=n}}while(0);b[4830386]=(b[4830386]|0)-1&65535;n=c[2415193]|0;p=a[9660753]|0;s=c[L+(K*3148|0)+48+((n>>>8&255|256)<<2)>>2]|0;do{if((s|0)==0){t=c[L+(K*3148|0)+3124>>2]|0;if((t|0)==0){M=K;N=L;break}gg[t&4095](n&65535,p);M=c[3528554]|0;N=c[2433592]|0}else{a[s+(n&255)|0]=p;M=K;N=L}}while(0);b[4830386]=(b[4830386]|0)-1&65535;p=c[2415193]|0;n=a[9660768]|0;s=c[N+(M*3148|0)+48+((p>>>8&255|256)<<2)>>2]|0;do{if((s|0)==0){t=c[N+(M*3148|0)+3124>>2]|0;if((t|0)==0){O=M;P=N;break}gg[t&4095](p&65535,n);O=c[3528554]|0;P=c[2433592]|0}else{a[s+(p&255)|0]=n;O=M;P=N}}while(0);b[4830386]=(b[4830386]|0)-1&65535;n=c[2415193]|0;p=a[9660769]|0;s=c[P+(O*3148|0)+48+((n>>>8&255|256)<<2)>>2]|0;do{if((s|0)==0){t=c[P+(O*3148|0)+3124>>2]|0;if((t|0)==0){Q=O;R=P;break}gg[t&4095](n&65535,p);Q=c[3528554]|0;R=c[2433592]|0}else{a[s+(n&255)|0]=p;Q=O;R=P}}while(0);b[4830386]=(b[4830386]|0)-1&65535;p=c[2415193]|0;n=a[9660780]|0;s=c[R+(Q*3148|0)+48+((p>>>8&255|256)<<2)>>2]|0;do{if((s|0)==0){t=c[R+(Q*3148|0)+3124>>2]|0;if((t|0)==0){S=Q;T=R;break}gg[t&4095](p&65535,n);S=c[3528554]|0;T=c[2433592]|0}else{a[s+(p&255)|0]=n;S=Q;T=R}}while(0);b[4830386]=(b[4830386]|0)-1&65535;n=c[2415193]|0;p=a[9660781]|0;s=c[T+(S*3148|0)+48+((n>>>8&255|256)<<2)>>2]|0;do{if((s|0)==0){t=c[T+(S*3148|0)+3124>>2]|0;if((t|0)==0){U=S;V=T;break}gg[t&4095](n&65535,p);U=c[3528554]|0;V=c[2433592]|0}else{a[s+(n&255)|0]=p;U=S;V=T}}while(0);b[4830386]=(b[4830386]|0)-1&65535;p=c[2415193]|0;n=a[9660776]|0;s=c[V+(U*3148|0)+48+((p>>>8&255|256)<<2)>>2]|0;do{if((s|0)==0){t=c[V+(U*3148|0)+3124>>2]|0;if((t|0)==0){W=U;X=V;break}gg[t&4095](p&65535,n);W=c[3528554]|0;X=c[2433592]|0}else{a[s+(p&255)|0]=n;W=U;X=V}}while(0);b[4830386]=(b[4830386]|0)-1&65535;n=c[2415193]|0;p=a[9660777]|0;s=c[X+(W*3148|0)+48+((n>>>8&255|256)<<2)>>2]|0;do{if((s|0)==0){t=c[X+(W*3148|0)+3124>>2]|0;if((t|0)==0){Y=W;Z=X;break}gg[t&4095](n&65535,p);Y=c[3528554]|0;Z=c[2433592]|0}else{a[s+(n&255)|0]=p;Y=W;Z=X}}while(0);b[4830386]=(b[4830386]|0)-1&65535;p=c[2415193]|0;n=a[9660765]|0;s=c[Z+(Y*3148|0)+48+((p>>>8&255|256)<<2)>>2]|0;do{if((s|0)==0){t=c[Z+(Y*3148|0)+3124>>2]|0;if((t|0)==0){_=Y;$=Z;break}gg[t&4095](p&65535,n);_=c[3528554]|0;$=c[2433592]|0}else{a[s+(p&255)|0]=n;_=Y;$=Z}}while(0);b[4830386]=(b[4830386]|0)-1&65535;n=c[2415193]|0;p=a[9660760]|0;s=c[$+(_*3148|0)+48+((n>>>8&255|256)<<2)>>2]|0;do{if((s|0)==0){t=c[$+(_*3148|0)+3124>>2]|0;if((t|0)==0){aa=_;ab=$;break}gg[t&4095](n&65535,p);aa=c[3528554]|0;ab=c[2433592]|0}else{a[s+(n&255)|0]=p;aa=_;ab=$}}while(0);b[4830386]=(b[4830386]|0)-1&65535;p=c[2415193]|0;n=a[9660761]|0;s=c[ab+(aa*3148|0)+48+((p>>>8&255|256)<<2)>>2]|0;do{if((s|0)==0){t=c[ab+(aa*3148|0)+3124>>2]|0;if((t|0)==0){ac=aa;ad=ab;break}gg[t&4095](p&65535,n);ac=c[3528554]|0;ad=c[2433592]|0}else{a[s+(p&255)|0]=n;ac=aa;ad=ab}}while(0);b[4830386]=(b[4830386]|0)-1&65535;n=c[2415193]|0;p=a[9660784]|0;s=c[ad+(ac*3148|0)+48+((n>>>8&255|256)<<2)>>2]|0;do{if((s|0)==0){t=c[ad+(ac*3148|0)+3124>>2]|0;if((t|0)==0){ae=ac;af=ad;break}gg[t&4095](n&65535,p);ae=c[3528554]|0;af=c[2433592]|0}else{a[s+(n&255)|0]=p;ae=ac;af=ad}}while(0);p=c[af+(ae*3148|0)+1068>>2]|0;do{if((p|0)==0){n=c[af+(ae*3148|0)+3120>>2]|0;if((n|0)==0){ag=0;ah=0;break}s=gj[n&4095](-14)|0;n=c[3528554]|0;t=c[2433592]|0;u=c[t+(n*3148|0)+1068>>2]|0;if((u|0)!=0){ai=u;aj=(s&255)<<8;ak=40485;break}u=c[t+(n*3148|0)+3120>>2]|0;if((u|0)==0){ag=0;ah=(s&255)<<8;break}ag=gj[u&4095](-13)|0;ah=(s&255)<<8}else{ai=p;aj=(d[p+242|0]|0)<<8;ak=40485}}while(0);if((ak|0)==40485){ak=0;ag=a[ai+243|0]|0;ah=aj}p=ag&255|ah;c[2415188]=p;b[4830376]=p&65535;p=(c[2440592]|0)-20|0;c[2440592]=p;F=p;break L48643;break};case 131:{p=c[2415188]|0;s=c[3528554]|0;u=c[2433592]|0;n=c[u+(s*3148|0)+48+((p>>>8&255)<<2)>>2]|0;do{if((n|0)==0){t=c[u+(s*3148|0)+3132>>2]|0;if((t|0)==0){al=0;am=p;an=s;ao=u;ap=p&65535;break}z=gj[t&4095](p&65535)|0;t=c[2415188]|0;al=z;am=t;an=c[3528554]|0;ao=c[2433592]|0;ap=t&65535}else{al=a[n+(p&255)|0]|0;am=p;an=s;ao=u;ap=p&65535}}while(0);p=(al&255)<<8;u=am+1|0;s=c[ao+(an*3148|0)+48+((u>>>8&255)<<2)>>2]|0;do{if((s|0)==0){n=c[ao+(an*3148|0)+3132>>2]|0;if((n|0)==0){aq=0;ar=ap;break}t=gj[n&4095](u&65535)|0;aq=t;ar=b[4830376]|0}else{aq=a[s+(u&255)|0]|0;ar=ap}}while(0);b[4830376]=ar+2&65535;u=e[4830384]|0;s=u-(aq&255|p)|0;t=(s>>>12&8|a[9660784]&-16&255)&255;a[9660784]=((u^p^s^s>>>1)>>>14&2|s>>>16&1|((s&65535)<<16>>16==0?t|4:t)&255)&255;t=(c[2440592]|0)-5|0;c[2440592]=t;F=t;break L48643;break};case 140:{t=c[2415188]|0;s=c[3528554]|0;u=c[2433592]|0;n=c[u+(s*3148|0)+48+((t>>>8&255)<<2)>>2]|0;do{if((n|0)==0){z=c[u+(s*3148|0)+3132>>2]|0;if((z|0)==0){as=0;at=t;au=s;av=u;aw=t&65535;break}ax=gj[z&4095](t&65535)|0;z=c[2415188]|0;as=ax;at=z;au=c[3528554]|0;av=c[2433592]|0;aw=z&65535}else{as=a[n+(t&255)|0]|0;at=t;au=s;av=u;aw=t&65535}}while(0);t=(as&255)<<8;u=at+1|0;s=c[av+(au*3148|0)+48+((u>>>8&255)<<2)>>2]|0;do{if((s|0)==0){n=c[av+(au*3148|0)+3132>>2]|0;if((n|0)==0){ay=0;az=aw;break}p=gj[n&4095](u&65535)|0;ay=p;az=b[4830376]|0}else{ay=a[s+(u&255)|0]|0;az=aw}}while(0);b[4830376]=az+2&65535;u=e[4830386]|0;s=u-(ay&255|t)|0;p=(s>>>12&8|a[9660784]&-16&255)&255;a[9660784]=((u^t^s^s>>>1)>>>14&2|s>>>16&1|((s&65535)<<16>>16==0?p|4:p)&255)&255;p=(c[2440592]|0)-5|0;c[2440592]=p;F=p;break L48643;break};case 147:{c[2426864]=c[2415191];p=c[2415188]|0;s=c[3528554]|0;u=c[2433592]|0;n=c[u+(s*3148|0)+48+((p>>>8&255)<<2)>>2]|0;do{if((n|0)==0){z=c[u+(s*3148|0)+3132>>2]|0;if((z|0)==0){aA=0;aB=p&65535;aC=s;aD=u;break}ax=gj[z&4095](p&65535)|0;aA=ax;aB=b[4830376]|0;aC=c[3528554]|0;aD=c[2433592]|0}else{aA=a[n+(p&255)|0]|0;aB=p&65535;aC=s;aD=u}}while(0);a[9707456]=aA;b[4830376]=aB+1&65535;u=c[2426864]|0;s=c[aD+(aC*3148|0)+48+((u>>>8&255)<<2)>>2]|0;do{if((s|0)==0){p=c[aD+(aC*3148|0)+3120>>2]|0;if((p|0)==0){aE=0;aF=aC;aG=aD;break}n=gj[p&4095](u&65535)|0;aE=n;aF=c[3528554]|0;aG=c[2433592]|0}else{aE=a[s+(u&255)|0]|0;aF=aC;aG=aD}}while(0);s=(aE&255)<<8;n=c[aG+(aF*3148|0)+48+(((u+1|0)>>>8&255)<<2)>>2]|0;do{if((n|0)==0){p=c[aG+(aF*3148|0)+3120>>2]|0;if((p|0)==0){aH=0;break}aH=gj[p&4095]((u+1|0)&65535)|0}else{aH=a[n+((u+1|0)&255)|0]|0}}while(0);u=e[4830384]|0;n=u-(aH&255|s)|0;p=(n>>>12&8|a[9660784]&-16&255)&255;a[9660784]=((u^s^n^n>>>1)>>>14&2|n>>>16&1|((n&65535)<<16>>16==0?p|4:p)&255)&255;p=(c[2440592]|0)-7|0;c[2440592]=p;F=p;break L48643;break};case 156:{c[2426864]=c[2415191];p=c[2415188]|0;n=c[3528554]|0;u=c[2433592]|0;t=c[u+(n*3148|0)+48+((p>>>8&255)<<2)>>2]|0;do{if((t|0)==0){ax=c[u+(n*3148|0)+3132>>2]|0;if((ax|0)==0){aI=0;aJ=p&65535;aK=n;aL=u;break}z=gj[ax&4095](p&65535)|0;aI=z;aJ=b[4830376]|0;aK=c[3528554]|0;aL=c[2433592]|0}else{aI=a[t+(p&255)|0]|0;aJ=p&65535;aK=n;aL=u}}while(0);a[9707456]=aI;b[4830376]=aJ+1&65535;u=c[2426864]|0;n=c[aL+(aK*3148|0)+48+((u>>>8&255)<<2)>>2]|0;do{if((n|0)==0){p=c[aL+(aK*3148|0)+3120>>2]|0;if((p|0)==0){aM=0;aN=aK;aO=aL;break}t=gj[p&4095](u&65535)|0;aM=t;aN=c[3528554]|0;aO=c[2433592]|0}else{aM=a[n+(u&255)|0]|0;aN=aK;aO=aL}}while(0);n=(aM&255)<<8;t=c[aO+(aN*3148|0)+48+(((u+1|0)>>>8&255)<<2)>>2]|0;do{if((t|0)==0){p=c[aO+(aN*3148|0)+3120>>2]|0;if((p|0)==0){aP=0;break}aP=gj[p&4095]((u+1|0)&65535)|0}else{aP=a[t+((u+1|0)&255)|0]|0}}while(0);u=e[4830386]|0;t=u-(aP&255|n)|0;p=(t>>>12&8|a[9660784]&-16&255)&255;a[9660784]=((u^n^t^t>>>1)>>>14&2|t>>>16&1|((t&65535)<<16>>16==0?p|4:p)&255)&255;p=(c[2440592]|0)-7|0;c[2440592]=p;F=p;break L48643;break};case 163:{f46();p=c[2426864]|0;t=c[3528554]|0;u=c[2433592]|0;s=c[u+(t*3148|0)+48+((p>>>8&255)<<2)>>2]|0;do{if((s|0)==0){z=c[u+(t*3148|0)+3120>>2]|0;if((z|0)==0){aQ=0;aR=t;aS=u;break}ax=gj[z&4095](p&65535)|0;aQ=ax;aR=c[3528554]|0;aS=c[2433592]|0}else{aQ=a[s+(p&255)|0]|0;aR=t;aS=u}}while(0);u=(aQ&255)<<8;t=c[aS+(aR*3148|0)+48+(((p+1|0)>>>8&255)<<2)>>2]|0;do{if((t|0)==0){s=c[aS+(aR*3148|0)+3120>>2]|0;if((s|0)==0){aT=0;break}aT=gj[s&4095]((p+1|0)&65535)|0}else{aT=a[t+((p+1|0)&255)|0]|0}}while(0);p=e[4830384]|0;t=p-(aT&255|u)|0;s=(t>>>12&8|a[9660784]&-16&255)&255;a[9660784]=((p^u^t^t>>>1)>>>14&2|t>>>16&1|((t&65535)<<16>>16==0?s|4:s)&255)&255;s=(c[2440592]|0)-7|0;c[2440592]=s;F=s;break L48643;break};case 172:{f46();s=c[2426864]|0;t=c[3528554]|0;p=c[2433592]|0;n=c[p+(t*3148|0)+48+((s>>>8&255)<<2)>>2]|0;do{if((n|0)==0){ax=c[p+(t*3148|0)+3120>>2]|0;if((ax|0)==0){aU=0;aV=t;aW=p;break}z=gj[ax&4095](s&65535)|0;aU=z;aV=c[3528554]|0;aW=c[2433592]|0}else{aU=a[n+(s&255)|0]|0;aV=t;aW=p}}while(0);p=(aU&255)<<8;t=c[aW+(aV*3148|0)+48+(((s+1|0)>>>8&255)<<2)>>2]|0;do{if((t|0)==0){n=c[aW+(aV*3148|0)+3120>>2]|0;if((n|0)==0){aX=0;break}aX=gj[n&4095]((s+1|0)&65535)|0}else{aX=a[t+((s+1|0)&255)|0]|0}}while(0);s=e[4830386]|0;t=s-(aX&255|p)|0;n=(t>>>12&8|a[9660784]&-16&255)&255;a[9660784]=((s^p^t^t>>>1)>>>14&2|t>>>16&1|((t&65535)<<16>>16==0?n|4:n)&255)&255;n=(c[2440592]|0)-7|0;c[2440592]=n;F=n;break L48643;break};case 179:{n=c[2415188]|0;t=c[3528554]|0;s=c[2433592]|0;u=c[s+(t*3148|0)+48+((n>>>8&255)<<2)>>2]|0;do{if((u|0)==0){z=c[s+(t*3148|0)+3132>>2]|0;if((z|0)==0){aY=0;aZ=n;a_=t;a$=s;a0=n&65535;break}ax=gj[z&4095](n&65535)|0;z=c[2415188]|0;aY=ax;aZ=z;a_=c[3528554]|0;a$=c[2433592]|0;a0=z&65535}else{aY=a[u+(n&255)|0]|0;aZ=n;a_=t;a$=s;a0=n&65535}}while(0);n=aY&255;s=aZ+1|0;t=c[a$+(a_*3148|0)+48+((s>>>8&255)<<2)>>2]|0;do{if((t|0)==0){u=c[a$+(a_*3148|0)+3132>>2]|0;if((u|0)==0){a1=0;a2=a0;a3=a_;a4=a$;break}p=gj[u&4095](s&65535)|0;a1=p;a2=b[4830376]|0;a3=c[3528554]|0;a4=c[2433592]|0}else{a1=a[t+(s&255)|0]|0;a2=a0;a3=a_;a4=a$}}while(0);s=a1&255;c[2426864]=s|n<<8;b[4830376]=a2+2&65535;t=c[a4+(a3*3148|0)+48+(n<<2)>>2]|0;do{if((t|0)==0){p=c[a4+(a3*3148|0)+3120>>2]|0;if((p|0)==0){a5=0;a6=a3;a7=a4;break}u=gj[p&4095]((s|n<<8)&65535)|0;a5=u;a6=c[3528554]|0;a7=c[2433592]|0}else{a5=a[t+s|0]|0;a6=a3;a7=a4}}while(0);t=(a5&255)<<8;u=c[a7+(a6*3148|0)+48+((((s|n<<8)+1|0)>>>8&255)<<2)>>2]|0;do{if((u|0)==0){p=c[a7+(a6*3148|0)+3120>>2]|0;if((p|0)==0){a8=0;break}a8=gj[p&4095](((s|n<<8)+1|0)&65535)|0}else{a8=a[u+(((s|n<<8)+1|0)&255)|0]|0}}while(0);n=e[4830384]|0;s=n-(a8&255|t)|0;u=(s>>>12&8|a[9660784]&-16&255)&255;a[9660784]=((n^t^s^s>>>1)>>>14&2|s>>>16&1|((s&65535)<<16>>16==0?u|4:u)&255)&255;u=(c[2440592]|0)-8|0;c[2440592]=u;F=u;break L48643;break};case 188:{u=c[2415188]|0;s=c[3528554]|0;n=c[2433592]|0;p=c[n+(s*3148|0)+48+((u>>>8&255)<<2)>>2]|0;do{if((p|0)==0){z=c[n+(s*3148|0)+3132>>2]|0;if((z|0)==0){a9=0;ba=u;bb=s;bc=n;bd=u&65535;break}ax=gj[z&4095](u&65535)|0;z=c[2415188]|0;a9=ax;ba=z;bb=c[3528554]|0;bc=c[2433592]|0;bd=z&65535}else{a9=a[p+(u&255)|0]|0;ba=u;bb=s;bc=n;bd=u&65535}}while(0);u=a9&255;n=ba+1|0;s=c[bc+(bb*3148|0)+48+((n>>>8&255)<<2)>>2]|0;do{if((s|0)==0){p=c[bc+(bb*3148|0)+3132>>2]|0;if((p|0)==0){be=0;bf=bd;bg=bb;bh=bc;break}t=gj[p&4095](n&65535)|0;be=t;bf=b[4830376]|0;bg=c[3528554]|0;bh=c[2433592]|0}else{be=a[s+(n&255)|0]|0;bf=bd;bg=bb;bh=bc}}while(0);n=be&255;c[2426864]=n|u<<8;b[4830376]=bf+2&65535;s=c[bh+(bg*3148|0)+48+(u<<2)>>2]|0;do{if((s|0)==0){t=c[bh+(bg*3148|0)+3120>>2]|0;if((t|0)==0){bi=0;bj=bg;bk=bh;break}p=gj[t&4095]((n|u<<8)&65535)|0;bi=p;bj=c[3528554]|0;bk=c[2433592]|0}else{bi=a[s+n|0]|0;bj=bg;bk=bh}}while(0);s=(bi&255)<<8;p=c[bk+(bj*3148|0)+48+((((n|u<<8)+1|0)>>>8&255)<<2)>>2]|0;do{if((p|0)==0){t=c[bk+(bj*3148|0)+3120>>2]|0;if((t|0)==0){bl=0;break}bl=gj[t&4095](((n|u<<8)+1|0)&65535)|0}else{bl=a[p+(((n|u<<8)+1|0)&255)|0]|0}}while(0);u=e[4830386]|0;n=u-(bl&255|s)|0;p=(n>>>12&8|a[9660784]&-16&255)&255;a[9660784]=((u^s^n^n>>>1)>>>14&2|n>>>16&1|((n&65535)<<16>>16==0?p|4:p)&255)&255;p=(c[2440592]|0)-8|0;c[2440592]=p;F=p;break L48643;break};default:{ak=43386;break L48643}}break};case 18:{p=(c[2440592]|0)-2|0;c[2440592]=p;F=p;break};case 19:{p=a[9660796]|0;a[9660796]=p|16;n=a[9660786]|0;u=a[9660787]|0;if((u|n)<<24>>24==0){bm=p|16}else{a[9660796]=p&-17;bm=p&-17}do{if(u<<24>>24==0){ak=40613}else{p=a[9660784]|0;if((p&64)!=0){ak=40613;break}if((bm&8)==0){a[9660784]=p&127;b[4830386]=(b[4830386]|0)-1&65535;t=c[2415193]|0;z=c[3528554]|0;ax=c[2433592]|0;bn=c[ax+(z*3148|0)+48+((t>>>8&255|256)<<2)>>2]|0;do{if((bn|0)==0){bo=c[ax+(z*3148|0)+3124>>2]|0;if((bo|0)==0){bp=z;bq=ax;break}gg[bo&4095](t&65535,l&255);bp=c[3528554]|0;bq=c[2433592]|0}else{a[bn+(t&255)|0]=l&255;bp=z;bq=ax}}while(0);b[4830386]=(b[4830386]|0)-1&65535;ax=c[2415193]|0;z=a[9660753]|0;t=c[bq+(bp*3148|0)+48+((ax>>>8&255|256)<<2)>>2]|0;do{if((t|0)==0){bn=c[bq+(bp*3148|0)+3124>>2]|0;if((bn|0)==0){br=bp;bs=bq;break}gg[bn&4095](ax&65535,z);br=c[3528554]|0;bs=c[2433592]|0}else{a[t+(ax&255)|0]=z;br=bp;bs=bq}}while(0);b[4830386]=(b[4830386]|0)-1&65535;z=c[2415193]|0;ax=a[9660784]|0;t=c[bs+(br*3148|0)+48+((z>>>8&255|256)<<2)>>2]|0;do{if((t|0)==0){bn=c[bs+(br*3148|0)+3124>>2]|0;if((bn|0)==0){break}gg[bn&4095](z&65535,ax)}else{a[t+(z&255)|0]=ax}}while(0);bt=(c[2415197]|0)+10|0;bu=a[9660784]|0}else{a[9660796]=bm&-9;bt=(c[2415197]|0)+7|0;bu=p}c[2415197]=bt;a[9660784]=bu|80;ax=c[3528554]|0;z=c[2433592]|0;t=c[z+(ax*3148|0)+1068>>2]|0;do{if((t|0)==0){bn=c[z+(ax*3148|0)+3120>>2]|0;if((bn|0)==0){bv=0;bw=0;break}bo=gj[bn&4095](-10)|0;bn=c[3528554]|0;bx=c[2433592]|0;by=c[bx+(bn*3148|0)+1068>>2]|0;if((by|0)!=0){bz=by;bA=(bo&255)<<8;ak=40609;break}by=c[bx+(bn*3148|0)+3120>>2]|0;if((by|0)==0){bv=0;bw=(bo&255)<<8;break}bv=gj[by&4095](-9)|0;bw=(bo&255)<<8}else{bz=t;bA=(d[t+246|0]|0)<<8;ak=40609}}while(0);if((ak|0)==40609){ak=0;bv=a[bz+247|0]|0;bw=bA}t=bv&255|bw;c[2415188]=t;b[4830376]=t&65535}}while(0);do{if((ak|0)==40613){ak=0;if(n<<24>>24==0){break}u=a[9660784]|0;if((u&16)!=0){break}if((bm&8)==0){a[9660784]=u|-128;b[4830386]=(b[4830386]|0)-1&65535;s=c[2415193]|0;t=c[3528554]|0;ax=c[2433592]|0;z=c[ax+(t*3148|0)+48+((s>>>8&255|256)<<2)>>2]|0;do{if((z|0)==0){p=c[ax+(t*3148|0)+3124>>2]|0;if((p|0)==0){bB=t;bC=ax;break}gg[p&4095](s&65535,l&255);bB=c[3528554]|0;bC=c[2433592]|0}else{a[z+(s&255)|0]=l&255;bB=t;bC=ax}}while(0);b[4830386]=(b[4830386]|0)-1&65535;ax=c[2415193]|0;t=a[9660753]|0;s=c[bC+(bB*3148|0)+48+((ax>>>8&255|256)<<2)>>2]|0;do{if((s|0)==0){z=c[bC+(bB*3148|0)+3124>>2]|0;if((z|0)==0){bD=bB;bE=bC;break}gg[z&4095](ax&65535,t);bD=c[3528554]|0;bE=c[2433592]|0}else{a[s+(ax&255)|0]=t;bD=bB;bE=bC}}while(0);b[4830386]=(b[4830386]|0)-1&65535;t=c[2415193]|0;ax=a[9660768]|0;s=c[bE+(bD*3148|0)+48+((t>>>8&255|256)<<2)>>2]|0;do{if((s|0)==0){z=c[bE+(bD*3148|0)+3124>>2]|0;if((z|0)==0){bF=bD;bG=bE;break}gg[z&4095](t&65535,ax);bF=c[3528554]|0;bG=c[2433592]|0}else{a[s+(t&255)|0]=ax;bF=bD;bG=bE}}while(0);b[4830386]=(b[4830386]|0)-1&65535;ax=c[2415193]|0;t=a[9660769]|0;s=c[bG+(bF*3148|0)+48+((ax>>>8&255|256)<<2)>>2]|0;do{if((s|0)==0){z=c[bG+(bF*3148|0)+3124>>2]|0;if((z|0)==0){bH=bF;bI=bG;break}gg[z&4095](ax&65535,t);bH=c[3528554]|0;bI=c[2433592]|0}else{a[s+(ax&255)|0]=t;bH=bF;bI=bG}}while(0);b[4830386]=(b[4830386]|0)-1&65535;t=c[2415193]|0;ax=a[9660780]|0;s=c[bI+(bH*3148|0)+48+((t>>>8&255|256)<<2)>>2]|0;do{if((s|0)==0){z=c[bI+(bH*3148|0)+3124>>2]|0;if((z|0)==0){bJ=bH;bK=bI;break}gg[z&4095](t&65535,ax);bJ=c[3528554]|0;bK=c[2433592]|0}else{a[s+(t&255)|0]=ax;bJ=bH;bK=bI}}while(0);b[4830386]=(b[4830386]|0)-1&65535;ax=c[2415193]|0;t=a[9660781]|0;s=c[bK+(bJ*3148|0)+48+((ax>>>8&255|256)<<2)>>2]|0;do{if((s|0)==0){z=c[bK+(bJ*3148|0)+3124>>2]|0;if((z|0)==0){bL=bJ;bM=bK;break}gg[z&4095](ax&65535,t);bL=c[3528554]|0;bM=c[2433592]|0}else{a[s+(ax&255)|0]=t;bL=bJ;bM=bK}}while(0);b[4830386]=(b[4830386]|0)-1&65535;t=c[2415193]|0;ax=a[9660776]|0;s=c[bM+(bL*3148|0)+48+((t>>>8&255|256)<<2)>>2]|0;do{if((s|0)==0){z=c[bM+(bL*3148|0)+3124>>2]|0;if((z|0)==0){bN=bL;bO=bM;break}gg[z&4095](t&65535,ax);bN=c[3528554]|0;bO=c[2433592]|0}else{a[s+(t&255)|0]=ax;bN=bL;bO=bM}}while(0);b[4830386]=(b[4830386]|0)-1&65535;ax=c[2415193]|0;t=a[9660777]|0;s=c[bO+(bN*3148|0)+48+((ax>>>8&255|256)<<2)>>2]|0;do{if((s|0)==0){z=c[bO+(bN*3148|0)+3124>>2]|0;if((z|0)==0){bP=bN;bQ=bO;break}gg[z&4095](ax&65535,t);bP=c[3528554]|0;bQ=c[2433592]|0}else{a[s+(ax&255)|0]=t;bP=bN;bQ=bO}}while(0);b[4830386]=(b[4830386]|0)-1&65535;t=c[2415193]|0;ax=a[9660765]|0;s=c[bQ+(bP*3148|0)+48+((t>>>8&255|256)<<2)>>2]|0;do{if((s|0)==0){z=c[bQ+(bP*3148|0)+3124>>2]|0;if((z|0)==0){bR=bP;bS=bQ;break}gg[z&4095](t&65535,ax);bR=c[3528554]|0;bS=c[2433592]|0}else{a[s+(t&255)|0]=ax;bR=bP;bS=bQ}}while(0);b[4830386]=(b[4830386]|0)-1&65535;ax=c[2415193]|0;t=a[9660760]|0;s=c[bS+(bR*3148|0)+48+((ax>>>8&255|256)<<2)>>2]|0;do{if((s|0)==0){z=c[bS+(bR*3148|0)+3124>>2]|0;if((z|0)==0){bT=bR;bU=bS;break}gg[z&4095](ax&65535,t);bT=c[3528554]|0;bU=c[2433592]|0}else{a[s+(ax&255)|0]=t;bT=bR;bU=bS}}while(0);b[4830386]=(b[4830386]|0)-1&65535;t=c[2415193]|0;ax=a[9660761]|0;s=c[bU+(bT*3148|0)+48+((t>>>8&255|256)<<2)>>2]|0;do{if((s|0)==0){z=c[bU+(bT*3148|0)+3124>>2]|0;if((z|0)==0){bV=bT;bW=bU;break}gg[z&4095](t&65535,ax);bV=c[3528554]|0;bW=c[2433592]|0}else{a[s+(t&255)|0]=ax;bV=bT;bW=bU}}while(0);b[4830386]=(b[4830386]|0)-1&65535;ax=c[2415193]|0;t=a[9660784]|0;s=c[bW+(bV*3148|0)+48+((ax>>>8&255|256)<<2)>>2]|0;do{if((s|0)==0){z=c[bW+(bV*3148|0)+3124>>2]|0;if((z|0)==0){break}gg[z&4095](ax&65535,t)}else{a[s+(ax&255)|0]=t}}while(0);bX=(c[2415197]|0)+19|0;bY=a[9660784]|0}else{a[9660796]=bm&-9;bX=(c[2415197]|0)+7|0;bY=u}c[2415197]=bX;a[9660784]=bY|16;t=c[3528554]|0;ax=c[2433592]|0;s=c[ax+(t*3148|0)+1068>>2]|0;do{if((s|0)==0){z=c[ax+(t*3148|0)+3120>>2]|0;if((z|0)==0){bZ=0;b_=0;break}p=gj[z&4095](-8)|0;z=c[3528554]|0;bo=c[2433592]|0;by=c[bo+(z*3148|0)+1068>>2]|0;if((by|0)!=0){b$=by;b0=(p&255)<<8;ak=40670;break}by=c[bo+(z*3148|0)+3120>>2]|0;if((by|0)==0){bZ=0;b_=(p&255)<<8;break}bZ=gj[by&4095](-7)|0;b_=(p&255)<<8}else{b$=s;b0=(d[s+248|0]|0)<<8;ak=40670}}while(0);if((ak|0)==40670){ak=0;bZ=a[b$+249|0]|0;b_=b0}s=bZ&255|b_;c[2415188]=s;b[4830376]=s&65535}}while(0);n=c[2440592]|0;if((a[9660796]&16)!=0&(n|0)>0){c[2440592]=0;b1=0}else{b1=n}n=b1-4|0;c[2440592]=n;F=n;break};case 20:{n=(c[2440592]|0)-2|0;c[2440592]=n;F=n;break};default:{o=1}}}if(o){o=0;switch(m|0){case 21:{n=(c[2440592]|0)-2|0;c[2440592]=n;F=n;break};case 22:{n=c[2415188]|0;s=c[3528554]|0;t=c[2433592]|0;ax=c[t+(s*3148|0)+48+((n>>>8&255)<<2)>>2]|0;do{if((ax|0)==0){u=c[t+(s*3148|0)+3132>>2]|0;if((u|0)==0){b2=0;b3=n;b4=s;b5=t;b6=n&65535;break}p=gj[u&4095](n&65535)|0;u=c[2415188]|0;b2=p;b3=u;b4=c[3528554]|0;b5=c[2433592]|0;b6=u&65535}else{b2=a[ax+(n&255)|0]|0;b3=n;b4=s;b5=t;b6=n&65535}}while(0);n=(b2&255)<<8;t=b3+1|0;s=c[b5+(b4*3148|0)+48+((t>>>8&255)<<2)>>2]|0;do{if((s|0)==0){ax=c[b5+(b4*3148|0)+3132>>2]|0;if((ax|0)==0){b7=0;b8=b6;break}u=gj[ax&4095](t&65535)|0;b7=u;b8=b[4830376]|0}else{b7=a[s+(t&255)|0]|0;b8=b6}}while(0);t=b7&255|n;c[2426864]=t;b[4830376]=(b8+2&65535)+(t&65535)&65535;b[4830376]=c[2415188]&65535;s=c[2440592]|0;if((t&65535)<<16>>16==-3&(s|0)>0){c[2440592]=0;b9=0}else{b9=s}s=b9-5|0;c[2440592]=s;F=s;break};case 23:{s=c[2415188]|0;t=c[3528554]|0;u=c[2433592]|0;ax=c[u+(t*3148|0)+48+((s>>>8&255)<<2)>>2]|0;do{if((ax|0)==0){p=c[u+(t*3148|0)+3132>>2]|0;if((p|0)==0){ca=0;cb=s;cc=t;cd=u;ce=s&65535;break}by=gj[p&4095](s&65535)|0;p=c[2415188]|0;ca=by;cb=p;cc=c[3528554]|0;cd=c[2433592]|0;ce=p&65535}else{ca=a[ax+(s&255)|0]|0;cb=s;cc=t;cd=u;ce=s&65535}}while(0);s=(ca&255)<<8;u=cb+1|0;t=c[cd+(cc*3148|0)+48+((u>>>8&255)<<2)>>2]|0;do{if((t|0)==0){ax=c[cd+(cc*3148|0)+3132>>2]|0;if((ax|0)==0){cf=0;cg=ce;ch=cc;ci=cd;break}n=gj[ax&4095](u&65535)|0;cf=n;cg=b[4830376]|0;ch=c[3528554]|0;ci=c[2433592]|0}else{cf=a[t+(u&255)|0]|0;cg=ce;ch=cc;ci=cd}}while(0);c[2426864]=cf&255|s;u=cg+2&65535;b[4830376]=u;b[4830386]=(b[4830386]|0)-1&65535;t=c[2415193]|0;n=c[ci+(ch*3148|0)+48+((t>>>8&255|256)<<2)>>2]|0;do{if((n|0)==0){ax=c[ci+(ch*3148|0)+3124>>2]|0;if((ax|0)==0){cj=ch;ck=ci;break}gg[ax&4095](t&65535,u&255);cj=c[3528554]|0;ck=c[2433592]|0}else{a[n+(t&255)|0]=u&255;cj=ch;ck=ci}}while(0);b[4830386]=(b[4830386]|0)-1&65535;u=c[2415193]|0;t=a[9660753]|0;n=c[ck+(cj*3148|0)+48+((u>>>8&255|256)<<2)>>2]|0;do{if((n|0)==0){s=c[ck+(cj*3148|0)+3124>>2]|0;if((s|0)==0){break}gg[s&4095](u&65535,t)}else{a[n+(u&255)|0]=t}}while(0);b[4830376]=(b[4830376]|0)+(b[4853728]|0)&65535;b[4830376]=c[2415188]&65535;t=(c[2440592]|0)-9|0;c[2440592]=t;F=t;break};case 24:{t=(c[2440592]|0)-2|0;c[2440592]=t;F=t;break};case 25:{t=a[9660761]|0;if((t&14)>9){ak=40710}else{if((a[9660784]&32)==0){cl=0}else{ak=40710}}if((ak|0)==40710){ak=0;cl=6}do{if((t&-16&255)>128){u=(t&14)>9?cl|96:cl;if((t&-16&255)<=144){cm=u;ak=40714;break}cn=u;co=a[9660784]|0;ak=40715}else{cm=cl;ak=40714}}while(0);if((ak|0)==40714){ak=0;u=a[9660784]|0;if((u&1)==0){cp=cm;cq=u}else{cn=cm;co=u;ak=40715}}if((ak|0)==40715){ak=0;cp=cn|96;cq=co}u=cp+(t&255)&65535;n=((u&65535)>>>4&8|cq&-15&255)&255;a[9660784]=(((u&255)<<24>>24==0?n|4:n)&255|(u&65535)>>>8&1)&255;a[9660761]=u&255;u=(c[2440592]|0)-2|0;c[2440592]=u;F=u;break};case 26:{u=c[2415188]|0;n=c[3528554]|0;s=c[2433592]|0;ax=c[s+(n*3148|0)+48+((u>>>8&255)<<2)>>2]|0;do{if((ax|0)==0){p=c[s+(n*3148|0)+3132>>2]|0;if((p|0)==0){cr=0;cs=u&65535;break}by=gj[p&4095](u&65535)|0;cr=by;cs=b[4830376]|0}else{cr=a[ax+(u&255)|0]|0;cs=u&65535}}while(0);u=cs+1&65535;b[4830376]=u;ax=a[9660784]|cr;a[9660784]=ax;n=a[9660786]|0;s=a[9660787]|0;if((s|n)<<24>>24!=0){a[9660796]=a[9660796]&-17}do{if(s<<24>>24==0){ak=40748}else{if((ax&64)!=0){ak=40748;break}t=a[9660796]|0;if((t&8)==0){a[9660784]=ax&127;b[4830386]=(b[4830386]|0)-1&65535;by=c[2415193]|0;p=c[3528554]|0;z=c[2433592]|0;bo=c[z+(p*3148|0)+48+((by>>>8&255|256)<<2)>>2]|0;do{if((bo|0)==0){bn=c[z+(p*3148|0)+3124>>2]|0;if((bn|0)==0){ct=p;cu=z;break}gg[bn&4095](by&65535,u&255);ct=c[3528554]|0;cu=c[2433592]|0}else{a[bo+(by&255)|0]=u&255;ct=p;cu=z}}while(0);b[4830386]=(b[4830386]|0)-1&65535;z=c[2415193]|0;p=a[9660753]|0;by=c[cu+(ct*3148|0)+48+((z>>>8&255|256)<<2)>>2]|0;do{if((by|0)==0){bo=c[cu+(ct*3148|0)+3124>>2]|0;if((bo|0)==0){cv=ct;cw=cu;break}gg[bo&4095](z&65535,p);cv=c[3528554]|0;cw=c[2433592]|0}else{a[by+(z&255)|0]=p;cv=ct;cw=cu}}while(0);b[4830386]=(b[4830386]|0)-1&65535;p=c[2415193]|0;z=a[9660784]|0;by=c[cw+(cv*3148|0)+48+((p>>>8&255|256)<<2)>>2]|0;do{if((by|0)==0){bo=c[cw+(cv*3148|0)+3124>>2]|0;if((bo|0)==0){break}gg[bo&4095](p&65535,z)}else{a[by+(p&255)|0]=z}}while(0);cx=(c[2415197]|0)+10|0;cy=a[9660784]|0}else{a[9660796]=t&-9;cx=(c[2415197]|0)+7|0;cy=ax}c[2415197]=cx;a[9660784]=cy|80;z=c[3528554]|0;p=c[2433592]|0;by=c[p+(z*3148|0)+1068>>2]|0;do{if((by|0)==0){bo=c[p+(z*3148|0)+3120>>2]|0;if((bo|0)==0){cz=0;cA=0;break}bn=gj[bo&4095](-10)|0;bo=c[3528554]|0;bx=c[2433592]|0;cB=c[bx+(bo*3148|0)+1068>>2]|0;if((cB|0)!=0){cC=cB;cD=(bn&255)<<8;ak=40744;break}cB=c[bx+(bo*3148|0)+3120>>2]|0;if((cB|0)==0){cz=0;cA=(bn&255)<<8;break}cz=gj[cB&4095](-9)|0;cA=(bn&255)<<8}else{cC=by;cD=(d[by+246|0]|0)<<8;ak=40744}}while(0);if((ak|0)==40744){ak=0;cz=a[cC+247|0]|0;cA=cD}by=cz&255|cA;c[2415188]=by;b[4830376]=by&65535}}while(0);do{if((ak|0)==40748){ak=0;if(n<<24>>24==0){break}if((ax&16)!=0){break}s=a[9660796]|0;if((s&8)==0){a[9660784]=ax|-128;b[4830386]=(b[4830386]|0)-1&65535;by=c[2415193]|0;z=c[3528554]|0;p=c[2433592]|0;t=c[p+(z*3148|0)+48+((by>>>8&255|256)<<2)>>2]|0;do{if((t|0)==0){bn=c[p+(z*3148|0)+3124>>2]|0;if((bn|0)==0){cE=z;cF=p;break}gg[bn&4095](by&65535,u&255);cE=c[3528554]|0;cF=c[2433592]|0}else{a[t+(by&255)|0]=u&255;cE=z;cF=p}}while(0);b[4830386]=(b[4830386]|0)-1&65535;p=c[2415193]|0;z=a[9660753]|0;by=c[cF+(cE*3148|0)+48+((p>>>8&255|256)<<2)>>2]|0;do{if((by|0)==0){t=c[cF+(cE*3148|0)+3124>>2]|0;if((t|0)==0){cG=cE;cH=cF;break}gg[t&4095](p&65535,z);cG=c[3528554]|0;cH=c[2433592]|0}else{a[by+(p&255)|0]=z;cG=cE;cH=cF}}while(0);b[4830386]=(b[4830386]|0)-1&65535;z=c[2415193]|0;p=a[9660768]|0;by=c[cH+(cG*3148|0)+48+((z>>>8&255|256)<<2)>>2]|0;do{if((by|0)==0){t=c[cH+(cG*3148|0)+3124>>2]|0;if((t|0)==0){cI=cG;cJ=cH;break}gg[t&4095](z&65535,p);cI=c[3528554]|0;cJ=c[2433592]|0}else{a[by+(z&255)|0]=p;cI=cG;cJ=cH}}while(0);b[4830386]=(b[4830386]|0)-1&65535;p=c[2415193]|0;z=a[9660769]|0;by=c[cJ+(cI*3148|0)+48+((p>>>8&255|256)<<2)>>2]|0;do{if((by|0)==0){t=c[cJ+(cI*3148|0)+3124>>2]|0;if((t|0)==0){cK=cI;cL=cJ;break}gg[t&4095](p&65535,z);cK=c[3528554]|0;cL=c[2433592]|0}else{a[by+(p&255)|0]=z;cK=cI;cL=cJ}}while(0);b[4830386]=(b[4830386]|0)-1&65535;z=c[2415193]|0;p=a[9660780]|0;by=c[cL+(cK*3148|0)+48+((z>>>8&255|256)<<2)>>2]|0;do{if((by|0)==0){t=c[cL+(cK*3148|0)+3124>>2]|0;if((t|0)==0){cM=cK;cN=cL;break}gg[t&4095](z&65535,p);cM=c[3528554]|0;cN=c[2433592]|0}else{a[by+(z&255)|0]=p;cM=cK;cN=cL}}while(0);b[4830386]=(b[4830386]|0)-1&65535;p=c[2415193]|0;z=a[9660781]|0;by=c[cN+(cM*3148|0)+48+((p>>>8&255|256)<<2)>>2]|0;do{if((by|0)==0){t=c[cN+(cM*3148|0)+3124>>2]|0;if((t|0)==0){cO=cM;cP=cN;break}gg[t&4095](p&65535,z);cO=c[3528554]|0;cP=c[2433592]|0}else{a[by+(p&255)|0]=z;cO=cM;cP=cN}}while(0);b[4830386]=(b[4830386]|0)-1&65535;z=c[2415193]|0;p=a[9660776]|0;by=c[cP+(cO*3148|0)+48+((z>>>8&255|256)<<2)>>2]|0;do{if((by|0)==0){t=c[cP+(cO*3148|0)+3124>>2]|0;if((t|0)==0){cQ=cO;cR=cP;break}gg[t&4095](z&65535,p);cQ=c[3528554]|0;cR=c[2433592]|0}else{a[by+(z&255)|0]=p;cQ=cO;cR=cP}}while(0);b[4830386]=(b[4830386]|0)-1&65535;p=c[2415193]|0;z=a[9660777]|0;by=c[cR+(cQ*3148|0)+48+((p>>>8&255|256)<<2)>>2]|0;do{if((by|0)==0){t=c[cR+(cQ*3148|0)+3124>>2]|0;if((t|0)==0){cS=cQ;cT=cR;break}gg[t&4095](p&65535,z);cS=c[3528554]|0;cT=c[2433592]|0}else{a[by+(p&255)|0]=z;cS=cQ;cT=cR}}while(0);b[4830386]=(b[4830386]|0)-1&65535;z=c[2415193]|0;p=a[9660765]|0;by=c[cT+(cS*3148|0)+48+((z>>>8&255|256)<<2)>>2]|0;do{if((by|0)==0){t=c[cT+(cS*3148|0)+3124>>2]|0;if((t|0)==0){cU=cS;cV=cT;break}gg[t&4095](z&65535,p);cU=c[3528554]|0;cV=c[2433592]|0}else{a[by+(z&255)|0]=p;cU=cS;cV=cT}}while(0);b[4830386]=(b[4830386]|0)-1&65535;p=c[2415193]|0;z=a[9660760]|0;by=c[cV+(cU*3148|0)+48+((p>>>8&255|256)<<2)>>2]|0;do{if((by|0)==0){t=c[cV+(cU*3148|0)+3124>>2]|0;if((t|0)==0){cW=cU;cX=cV;break}gg[t&4095](p&65535,z);cW=c[3528554]|0;cX=c[2433592]|0}else{a[by+(p&255)|0]=z;cW=cU;cX=cV}}while(0);b[4830386]=(b[4830386]|0)-1&65535;z=c[2415193]|0;p=a[9660761]|0;by=c[cX+(cW*3148|0)+48+((z>>>8&255|256)<<2)>>2]|0;do{if((by|0)==0){t=c[cX+(cW*3148|0)+3124>>2]|0;if((t|0)==0){cY=cW;cZ=cX;break}gg[t&4095](z&65535,p);cY=c[3528554]|0;cZ=c[2433592]|0}else{a[by+(z&255)|0]=p;cY=cW;cZ=cX}}while(0);b[4830386]=(b[4830386]|0)-1&65535;p=c[2415193]|0;z=a[9660784]|0;by=c[cZ+(cY*3148|0)+48+((p>>>8&255|256)<<2)>>2]|0;do{if((by|0)==0){t=c[cZ+(cY*3148|0)+3124>>2]|0;if((t|0)==0){break}gg[t&4095](p&65535,z)}else{a[by+(p&255)|0]=z}}while(0);c_=(c[2415197]|0)+19|0;c$=a[9660784]|0}else{a[9660796]=s&-9;c_=(c[2415197]|0)+7|0;c$=ax}c[2415197]=c_;a[9660784]=c$|16;z=c[3528554]|0;p=c[2433592]|0;by=c[p+(z*3148|0)+1068>>2]|0;do{if((by|0)==0){t=c[p+(z*3148|0)+3120>>2]|0;if((t|0)==0){c0=0;c1=0;break}bn=gj[t&4095](-8)|0;t=c[3528554]|0;cB=c[2433592]|0;bo=c[cB+(t*3148|0)+1068>>2]|0;if((bo|0)!=0){c2=bo;c3=(bn&255)<<8;ak=40805;break}bo=c[cB+(t*3148|0)+3120>>2]|0;if((bo|0)==0){c0=0;c1=(bn&255)<<8;break}c0=gj[bo&4095](-7)|0;c1=(bn&255)<<8}else{c2=by;c3=(d[by+248|0]|0)<<8;ak=40805}}while(0);if((ak|0)==40805){ak=0;c0=a[c2+249|0]|0;c1=c3}by=c0&255|c1;c[2415188]=by;b[4830376]=by&65535}}while(0);ax=(c[2440592]|0)-3|0;c[2440592]=ax;F=ax;break};case 10:{c[2426864]=c[2415191];ax=c[2415188]|0;u=c[3528554]|0;n=c[2433592]|0;by=c[n+(u*3148|0)+48+((ax>>>8&255)<<2)>>2]|0;do{if((by|0)==0){z=c[n+(u*3148|0)+3132>>2]|0;if((z|0)==0){c4=0;c5=ax&65535;c6=u;c7=n;break}p=gj[z&4095](ax&65535)|0;c4=p;c5=b[4830376]|0;c6=c[3528554]|0;c7=c[2433592]|0}else{c4=a[by+(ax&255)|0]|0;c5=ax&65535;c6=u;c7=n}}while(0);a[9707456]=c4;b[4830376]=c5+1&65535;n=c[2426864]|0;u=c[c7+(c6*3148|0)+48+((n>>>8&255)<<2)>>2]|0;do{if((u|0)==0){ax=c[c7+(c6*3148|0)+3120>>2]|0;if((ax|0)==0){c8=0;c9=n;da=c6;db=c7;break}by=gj[ax&4095](n&65535)|0;c8=by;c9=c[2426864]|0;da=c[3528554]|0;db=c[2433592]|0}else{c8=a[u+(n&255)|0]|0;c9=n;da=c6;db=c7}}while(0);n=c8-1&255;a[9660784]=a[9660784]&-15|a[669184+(n&255)|0];u=c9&65535;by=c[db+(da*3148|0)+48+((c9>>>8&255|256)<<2)>>2]|0;do{if((by|0)==0){ax=c[db+(da*3148|0)+3124>>2]|0;if((ax|0)==0){break}gg[ax&4095](u,n)}else{a[by+(c9&255)|0]=n}}while(0);n=(c[2440592]|0)-6|0;c[2440592]=n;F=n;break};case 1:{c[2426864]=c[2415191];n=c[2415188]|0;by=c[3528554]|0;u=c[2433592]|0;ax=c[u+(by*3148|0)+48+((n>>>8&255)<<2)>>2]|0;do{if((ax|0)==0){p=c[u+(by*3148|0)+3132>>2]|0;if((p|0)==0){dc=0;dd=n&65535;de=by;df=u;break}z=gj[p&4095](n&65535)|0;dc=z;dd=b[4830376]|0;de=c[3528554]|0;df=c[2433592]|0}else{dc=a[ax+(n&255)|0]|0;dd=n&65535;de=by;df=u}}while(0);a[9707456]=dc;b[4830376]=dd+1&65535;u=c[2426864]|0;by=c[df+(de*3148|0)+48+((u>>>8&255)<<2)>>2]|0;do{if((by|0)==0){n=c[df+(de*3148|0)+3120>>2]|0;if((n|0)==0){dg=0;dh=u;di=de;dj=df;break}ax=gj[n&4095](u&65535)|0;dg=ax;dh=c[2426864]|0;di=c[3528554]|0;dj=c[2433592]|0}else{dg=a[by+(u&255)|0]|0;dh=u;di=de;dj=df}}while(0);u=dg&255;by=(a[9660784]&-16&255|(-u|0)>>>4&8)&255;a[9660784]=((u^(-u|0)^(-u|0)>>>1)>>>6&2|(-u|0)>>>8&1|(((-u|0)&255)<<24>>24==0?by|4:by)&255)&255;by=dh&65535;ax=c[dj+(di*3148|0)+48+((dh>>>8&255|256)<<2)>>2]|0;do{if((ax|0)==0){n=c[dj+(di*3148|0)+3124>>2]|0;if((n|0)==0){break}gg[n&4095](by,(-u|0)&255)}else{a[ax+(dh&255)|0]=(-u|0)&255}}while(0);u=(c[2440592]|0)-6|0;c[2440592]=u;F=u;break};case 2:{u=(c[2440592]|0)-2|0;c[2440592]=u;F=u;break};case 3:{c[2426864]=c[2415191];u=c[2415188]|0;ax=c[3528554]|0;by=c[2433592]|0;n=c[by+(ax*3148|0)+48+((u>>>8&255)<<2)>>2]|0;do{if((n|0)==0){z=c[by+(ax*3148|0)+3132>>2]|0;if((z|0)==0){dk=0;dl=u&65535;dm=ax;dn=by;break}p=gj[z&4095](u&65535)|0;dk=p;dl=b[4830376]|0;dm=c[3528554]|0;dn=c[2433592]|0}else{dk=a[n+(u&255)|0]|0;dl=u&65535;dm=ax;dn=by}}while(0);a[9707456]=dk;b[4830376]=dl+1&65535;by=c[2426864]|0;ax=c[dn+(dm*3148|0)+48+((by>>>8&255)<<2)>>2]|0;do{if((ax|0)==0){u=c[dn+(dm*3148|0)+3120>>2]|0;if((u|0)==0){dp=0;dq=by;dr=dm;ds=dn;break}n=gj[u&4095](by&65535)|0;dp=n;dq=c[2426864]|0;dr=c[3528554]|0;ds=c[2433592]|0}else{dp=a[ax+(by&255)|0]|0;dq=by;dr=dm;ds=dn}}while(0);by=~dp;ax=a[9660784]&-15|(by&255)>>>4&8;a[9660784]=(dp<<24>>24==-1?ax|4:ax)|1;ax=dq&65535;n=c[ds+(dr*3148|0)+48+((dq>>>8&255|256)<<2)>>2]|0;do{if((n|0)==0){u=c[ds+(dr*3148|0)+3124>>2]|0;if((u|0)==0){break}gg[u&4095](ax,by)}else{a[n+(dq&255)|0]=by}}while(0);by=(c[2440592]|0)-6|0;c[2440592]=by;F=by;break};case 8:{c[2426864]=c[2415191];by=c[2415188]|0;n=c[3528554]|0;ax=c[2433592]|0;u=c[ax+(n*3148|0)+48+((by>>>8&255)<<2)>>2]|0;do{if((u|0)==0){p=c[ax+(n*3148|0)+3132>>2]|0;if((p|0)==0){dt=0;du=by&65535;dv=n;dw=ax;break}z=gj[p&4095](by&65535)|0;dt=z;du=b[4830376]|0;dv=c[3528554]|0;dw=c[2433592]|0}else{dt=a[u+(by&255)|0]|0;du=by&65535;dv=n;dw=ax}}while(0);a[9707456]=dt;b[4830376]=du+1&65535;ax=c[2426864]|0;n=c[dw+(dv*3148|0)+48+((ax>>>8&255)<<2)>>2]|0;do{if((n|0)==0){by=c[dw+(dv*3148|0)+3120>>2]|0;if((by|0)==0){dx=0;dy=ax;dz=dv;dA=dw;break}u=gj[by&4095](ax&65535)|0;dx=u;dy=c[2426864]|0;dz=c[3528554]|0;dA=c[2433592]|0}else{dx=a[n+(ax&255)|0]|0;dy=ax;dz=dv;dA=dw}}while(0);ax=(dx&255)<<1;n=((ax&65535)>>>4&8|a[9660784]&-16&255)&255;a[9660784]=(((ax&65535)>>>1^ax&65535)>>>6&2|(ax&65535)>>>8|((ax&255)<<24>>24==0?n|4:n)&255)&255;n=dy&65535;u=c[dA+(dz*3148|0)+48+((dy>>>8&255|256)<<2)>>2]|0;do{if((u|0)==0){by=c[dA+(dz*3148|0)+3124>>2]|0;if((by|0)==0){break}gg[by&4095](n,ax&255)}else{a[u+(dy&255)|0]=ax&255}}while(0);ax=(c[2440592]|0)-6|0;c[2440592]=ax;F=ax;break};case 5:{ax=(c[2440592]|0)-2|0;c[2440592]=ax;F=ax;break};case 6:{c[2426864]=c[2415191];ax=c[2415188]|0;u=c[3528554]|0;n=c[2433592]|0;by=c[n+(u*3148|0)+48+((ax>>>8&255)<<2)>>2]|0;do{if((by|0)==0){z=c[n+(u*3148|0)+3132>>2]|0;if((z|0)==0){dB=0;dC=ax&65535;dD=u;dE=n;break}p=gj[z&4095](ax&65535)|0;dB=p;dC=b[4830376]|0;dD=c[3528554]|0;dE=c[2433592]|0}else{dB=a[by+(ax&255)|0]|0;dC=ax&65535;dD=u;dE=n}}while(0);a[9707456]=dB;b[4830376]=dC+1&65535;n=c[2426864]|0;u=c[dE+(dD*3148|0)+48+((n>>>8&255)<<2)>>2]|0;do{if((u|0)==0){ax=c[dE+(dD*3148|0)+3120>>2]|0;if((ax|0)==0){dF=0;dG=n;dH=dD;dI=dE;break}by=gj[ax&4095](n&65535)|0;dF=by;dG=c[2426864]|0;dH=c[3528554]|0;dI=c[2433592]|0}else{dF=a[u+(n&255)|0]|0;dG=n;dH=dD;dI=dE}}while(0);n=a[9660784]|0;u=n<<7|(dF&255)>>>1;by=n&-14|dF&1|n<<3&8;a[9660784]=u<<24>>24==0?by|4:by;by=dG&65535;n=c[dI+(dH*3148|0)+48+((dG>>>8&255|256)<<2)>>2]|0;do{if((n|0)==0){ax=c[dI+(dH*3148|0)+3124>>2]|0;if((ax|0)==0){break}gg[ax&4095](by,u)}else{a[n+(dG&255)|0]=u}}while(0);u=(c[2440592]|0)-6|0;c[2440592]=u;F=u;break};case 4:{c[2426864]=c[2415191];u=c[2415188]|0;n=c[3528554]|0;by=c[2433592]|0;ax=c[by+(n*3148|0)+48+((u>>>8&255)<<2)>>2]|0;do{if((ax|0)==0){p=c[by+(n*3148|0)+3132>>2]|0;if((p|0)==0){dJ=0;dK=u&65535;dL=n;dM=by;break}z=gj[p&4095](u&65535)|0;dJ=z;dK=b[4830376]|0;dL=c[3528554]|0;dM=c[2433592]|0}else{dJ=a[ax+(u&255)|0]|0;dK=u&65535;dL=n;dM=by}}while(0);a[9707456]=dJ;b[4830376]=dK+1&65535;by=c[2426864]|0;n=c[dM+(dL*3148|0)+48+((by>>>8&255)<<2)>>2]|0;do{if((n|0)==0){u=c[dM+(dL*3148|0)+3120>>2]|0;if((u|0)==0){dN=0;dO=by;dP=dL;dQ=dM;break}ax=gj[u&4095](by&65535)|0;dN=ax;dO=c[2426864]|0;dP=c[3528554]|0;dQ=c[2433592]|0}else{dN=a[n+(by&255)|0]|0;dO=by;dP=dL;dQ=dM}}while(0);by=a[9660784]&-14|dN&1;n=(dN&255)>>>1;a[9660784]=n<<24>>24==0?by|4:by;by=dO&65535;ax=c[dQ+(dP*3148|0)+48+((dO>>>8&255|256)<<2)>>2]|0;do{if((ax|0)==0){u=c[dQ+(dP*3148|0)+3124>>2]|0;if((u|0)==0){break}gg[u&4095](by,n)}else{a[ax+(dO&255)|0]=n}}while(0);n=(c[2440592]|0)-6|0;c[2440592]=n;F=n;break};case 7:{c[2426864]=c[2415191];n=c[2415188]|0;ax=c[3528554]|0;by=c[2433592]|0;u=c[by+(ax*3148|0)+48+((n>>>8&255)<<2)>>2]|0;do{if((u|0)==0){z=c[by+(ax*3148|0)+3132>>2]|0;if((z|0)==0){dR=0;dS=n&65535;dT=ax;dU=by;break}p=gj[z&4095](n&65535)|0;dR=p;dS=b[4830376]|0;dT=c[3528554]|0;dU=c[2433592]|0}else{dR=a[u+(n&255)|0]|0;dS=n&65535;dT=ax;dU=by}}while(0);a[9707456]=dR;b[4830376]=dS+1&65535;by=c[2426864]|0;ax=c[dU+(dT*3148|0)+48+((by>>>8&255)<<2)>>2]|0;do{if((ax|0)==0){n=c[dU+(dT*3148|0)+3120>>2]|0;if((n|0)==0){dV=0;dW=by;dX=dT;dY=dU;break}u=gj[n&4095](by&65535)|0;dV=u;dW=c[2426864]|0;dX=c[3528554]|0;dY=c[2433592]|0}else{dV=a[ax+(by&255)|0]|0;dW=by;dX=dT;dY=dU}}while(0);by=dV&-128|(dV&255)>>>1;ax=a[9660784]&-14|dV&1|(dV&255)>>>4&8;a[9660784]=by<<24>>24==0?ax|4:ax;ax=dW&65535;u=c[dY+(dX*3148|0)+48+((dW>>>8&255|256)<<2)>>2]|0;do{if((u|0)==0){n=c[dY+(dX*3148|0)+3124>>2]|0;if((n|0)==0){break}gg[n&4095](ax,by)}else{a[u+(dW&255)|0]=by}}while(0);by=(c[2440592]|0)-6|0;c[2440592]=by;F=by;break};default:{o=1}}}c[h+51624>>2]=F;c[h+51656>>2]=ak;c[h+51664>>2]=o;c[h+51672>>2]=m;c[h+51712>>2]=0;c[h+51716>>2]=0;__Z13m6809_executei$2(h);F=c[h+51624>>2]|0;ak=c[h+51656>>2]|0;o=c[h+51664>>2]|0;I=c[h+51712>>2]|0;B=c[h+51716>>2]|0;J=+g[h+51716>>2];c[h+51712>>2]=0;c[h+51716>>2]=0;if((I|0)==1){break}if((I|0)==2){switch(B|0){case 45:{break L48643}}}c[h+80>>2]=l;c[h+51624>>2]=F;c[h+51656>>2]=ak;c[h+51664>>2]=o;c[h+51672>>2]=m;c[h+51704>>2]=0;c[h+51708>>2]=0;__Z13m6809_executei$1(h);F=c[h+51624>>2]|0;ak=c[h+51656>>2]|0;o=c[h+51664>>2]|0;c[h+51624>>2]=F;c[h+51656>>2]=ak;c[h+51664>>2]=o;c[h+51672>>2]=m;c[h+51696>>2]=0;c[h+51700>>2]=0;__Z13m6809_executei$0(h);F=c[h+51624>>2]|0;ak=c[h+51656>>2]|0;o=c[h+51664>>2]|0}while(0);if((ak|0)==43386){ak=0;F=c[2440592]|0}}while((F|0)>0);ak=F-(c[2415197]|0)|0;c[2440592]=ak;c[2415197]=0;j=ak;k=f-j|0;i=h;return k|0}function f46(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0,cf=0,cg=0,ch=0,ci=0,cj=0,ck=0,cl=0,cm=0,cn=0,co=0,cp=0,cq=0,cr=0,cs=0,ct=0,cu=0,cv=0,cw=0,cx=0,cy=0,cz=0,cA=0,cB=0,cC=0,cD=0,cE=0,cF=0,cG=0,cH=0,cI=0,cJ=0,cK=0,cL=0,cM=0,cN=0,cO=0,cP=0,cQ=0,cR=0,cS=0,cT=0,cU=0,cV=0,cW=0,cX=0,cY=0,cZ=0,c_=0,c$=0,c0=0,c1=0,c2=0,c3=0,c4=0,c5=0,c6=0,c7=0,c8=0,c9=0,da=0,db=0,dc=0,dd=0,de=0,df=0,dg=0,dh=0,di=0,dj=0,dk=0,dl=0,dm=0,dn=0,dp=0,dq=0,dr=0,ds=0,dt=0,du=0,dv=0,dw=0,dx=0,dy=0,dz=0,dA=0,dB=0,dC=0,dD=0,dE=0,dF=0,dG=0,dH=0,dI=0,dJ=0,dK=0,dL=0,dM=0,dN=0,dO=0,dP=0,dQ=0,dR=0,dS=0,dT=0,dU=0,dV=0,dW=0,dX=0,dY=0,dZ=0,d_=0,d$=0,d0=0,d1=0,d2=0,d3=0,d4=0,d5=0,d6=0,d7=0,d8=0,d9=0,ea=0,eb=0,ec=0,ed=0,ee=0,ef=0,eg=0,eh=0,ei=0,ej=0,ek=0,el=0,em=0,en=0,eo=0,ep=0,eq=0,er=0,es=0,et=0,eu=0,ev=0,ew=0,ex=0,ey=0,ez=0,eA=0,eB=0,eC=0,eD=0,eE=0,eF=0,eG=0,eH=0,eI=0,eJ=0,eK=0,eL=0,eM=0,eN=0,eO=0,eP=0,eQ=0,eR=0,eS=0,eT=0,eU=0,eV=0,eW=0,eX=0,eY=0,eZ=0,e_=0,e$=0,e0=0,e1=0,e2=0,e3=0,e4=0,e5=0,e6=0,e7=0,e8=0,e9=0,fa=0,fb=0,fc=0,fd=0,fe=0,ff=0,fg=0,fh=0,fi=0,fj=0,fk=0,fl=0,fm=0,fn=0,fo=0,fp=0,fq=0,fr=0,fs=0,ft=0,fu=0,fv=0,fw=0,fx=0,fy=0,fz=0,fA=0,fB=0,fC=0,fD=0,fE=0,fF=0,fG=0,fH=0,fI=0,fJ=0,fK=0,fL=0,fM=0,fN=0,fO=0,fP=0,fQ=0,fR=0,fS=0,fT=0,fU=0,fV=0,fW=0,fX=0,fY=0,fZ=0,f_=0,f$=0,f0=0,f1=0,f2=0,f3=0,f4=0,f5=0,f6=0,f7=0,f8=0,f9=0,ga=0,gb=0,gc=0,gd=0,ge=0,gf=0,gg=0,gh=0,gi=0,gk=0,gl=0,gm=0,gn=0,go=0,gp=0,gq=0,gr=0,gs=0,gt=0,gu=0,gv=0,gw=0,gx=0,gy=0,gz=0;f=c[2415188]|0;g=f&65535;h=c[3528554]|0;i=c[2433592]|0;j=c[i+(h*3148|0)+48+((f>>>8&255)<<2)>>2]|0;do{if((j|0)==0){k=c[i+(h*3148|0)+3132>>2]|0;if((k|0)==0){l=0;m=g;break}n=gj[k&4095](g)|0;l=n;m=b[4830376]|0}else{l=a[j+(f&255)|0]|0;m=g}}while(0);b[4830376]=m+1&65535;switch(l&255|0){case 3:{b[4853728]=(b[4830388]|0)+3&65535;c[2440592]=(c[2440592]|0)-1;return};case 11:{b[4853728]=(b[4830388]|0)+11&65535;c[2440592]=(c[2440592]|0)-1;return};case 4:{b[4853728]=(b[4830388]|0)+4&65535;c[2440592]=(c[2440592]|0)-1;return};case 2:{b[4853728]=(b[4830388]|0)+2&65535;c[2440592]=(c[2440592]|0)-1;return};case 5:{b[4853728]=(b[4830388]|0)+5&65535;c[2440592]=(c[2440592]|0)-1;return};case 7:{b[4853728]=(b[4830388]|0)+7&65535;c[2440592]=(c[2440592]|0)-1;return};case 8:{b[4853728]=(b[4830388]|0)+8&65535;c[2440592]=(c[2440592]|0)-1;return};case 1:{b[4853728]=(b[4830388]|0)+1&65535;c[2440592]=(c[2440592]|0)-1;return};case 53:{b[4853728]=(b[4830390]|0)-11&65535;c[2440592]=(c[2440592]|0)-1;return};case 54:{b[4853728]=(b[4830390]|0)-10&65535;c[2440592]=(c[2440592]|0)-1;return};case 55:{b[4853728]=(b[4830390]|0)-9&65535;c[2440592]=(c[2440592]|0)-1;return};case 56:{b[4853728]=(b[4830390]|0)-8&65535;c[2440592]=(c[2440592]|0)-1;return};case 57:{b[4853728]=(b[4830390]|0)-7&65535;c[2440592]=(c[2440592]|0)-1;return};case 58:{b[4853728]=(b[4830390]|0)-6&65535;c[2440592]=(c[2440592]|0)-1;return};case 59:{b[4853728]=(b[4830390]|0)-5&65535;c[2440592]=(c[2440592]|0)-1;return};case 60:{b[4853728]=(b[4830390]|0)-4&65535;c[2440592]=(c[2440592]|0)-1;return};case 61:{b[4853728]=(b[4830390]|0)-3&65535;c[2440592]=(c[2440592]|0)-1;return};case 62:{b[4853728]=(b[4830390]|0)-2&65535;c[2440592]=(c[2440592]|0)-1;return};case 63:{b[4853728]=(b[4830390]|0)-1&65535;c[2440592]=(c[2440592]|0)-1;return};case 64:{b[4853728]=b[4830384]|0;c[2440592]=(c[2440592]|0)-1;return};case 9:{b[4853728]=(b[4830388]|0)+9&65535;c[2440592]=(c[2440592]|0)-1;return};case 0:{b[4853728]=b[4830388]|0;c[2440592]=(c[2440592]|0)-1;return};case 24:{b[4853728]=(b[4830388]|0)-8&65535;c[2440592]=(c[2440592]|0)-1;return};case 25:{b[4853728]=(b[4830388]|0)-7&65535;c[2440592]=(c[2440592]|0)-1;return};case 26:{b[4853728]=(b[4830388]|0)-6&65535;c[2440592]=(c[2440592]|0)-1;return};case 220:{l=c[2415188]|0;m=l&65535;g=c[3528554]|0;f=c[2433592]|0;j=c[f+(g*3148|0)+48+((l>>>8&255)<<2)>>2]|0;do{if((j|0)==0){h=c[f+(g*3148|0)+3132>>2]|0;if((h|0)==0){o=0;p=m;q=g;r=f;break}i=gj[h&4095](m)|0;o=i;p=b[4830376]|0;q=c[3528554]|0;r=c[2433592]|0}else{o=a[j+(l&255)|0]|0;p=m;q=g;r=f}}while(0);f=o&255;o=p+1&65535;b[4830376]=o;b[4853728]=((f&128)!=0?f|-256:f)+o&65535;o=c[2426864]|0;f=o&65535;p=c[r+(q*3148|0)+48+((o>>>8&255)<<2)>>2]|0;do{if((p|0)==0){g=c[r+(q*3148|0)+3120>>2]|0;if((g|0)==0){s=0;t=q;u=r;break}m=gj[g&4095](f)|0;s=m;t=c[3528554]|0;u=c[2433592]|0}else{s=a[p+(o&255)|0]|0;t=q;u=r}}while(0);r=(s&255)<<8;s=o+1|0;o=s&65535;q=c[u+(t*3148|0)+48+((s>>>8&255)<<2)>>2]|0;do{if((q|0)==0){p=c[u+(t*3148|0)+3120>>2]|0;if((p|0)==0){v=0;break}v=gj[p&4095](o)|0}else{v=a[q+(s&255)|0]|0}}while(0);c[2426864]=v&255|r;c[2440592]=(c[2440592]|0)-4;return};case 221:{r=c[2415188]|0;v=r&65535;s=c[3528554]|0;q=c[2433592]|0;o=c[q+(s*3148|0)+48+((r>>>8&255)<<2)>>2]|0;do{if((o|0)==0){t=c[q+(s*3148|0)+3132>>2]|0;if((t|0)==0){w=0;x=r;y=s;z=q;A=v;break}u=gj[t&4095](v)|0;t=c[2415188]|0;w=u;x=t;y=c[3528554]|0;z=c[2433592]|0;A=t&65535}else{w=a[o+(r&255)|0]|0;x=r;y=s;z=q;A=v}}while(0);v=(w&255)<<8;w=x+1|0;x=w&65535;q=c[z+(y*3148|0)+48+((w>>>8&255)<<2)>>2]|0;do{if((q|0)==0){s=c[z+(y*3148|0)+3132>>2]|0;if((s|0)==0){B=0;C=A;D=y;E=z;break}r=gj[s&4095](x)|0;B=r;C=b[4830376]|0;D=c[3528554]|0;E=c[2433592]|0}else{B=a[q+(w&255)|0]|0;C=A;D=y;E=z}}while(0);z=B&255|v;c[2426864]=z;v=C+2&65535;b[4830376]=v;b[4853728]=(z&65535)+v&65535;v=c[2426864]|0;z=v&65535;C=c[E+(D*3148|0)+48+((v>>>8&255)<<2)>>2]|0;do{if((C|0)==0){B=c[E+(D*3148|0)+3120>>2]|0;if((B|0)==0){F=0;G=D;H=E;break}y=gj[B&4095](z)|0;F=y;G=c[3528554]|0;H=c[2433592]|0}else{F=a[C+(v&255)|0]|0;G=D;H=E}}while(0);E=(F&255)<<8;F=v+1|0;v=F&65535;D=c[H+(G*3148|0)+48+((F>>>8&255)<<2)>>2]|0;do{if((D|0)==0){C=c[H+(G*3148|0)+3120>>2]|0;if((C|0)==0){I=0;break}I=gj[C&4095](v)|0}else{I=a[D+(F&255)|0]|0}}while(0);c[2426864]=I&255|E;c[2440592]=(c[2440592]|0)-8;return};case 222:{b[4853728]=0;return};case 223:{E=c[2415188]|0;I=E&65535;F=c[3528554]|0;D=c[2433592]|0;v=c[D+(F*3148|0)+48+((E>>>8&255)<<2)>>2]|0;do{if((v|0)==0){G=c[D+(F*3148|0)+3132>>2]|0;if((G|0)==0){J=0;K=E;L=F;M=D;N=I;break}H=gj[G&4095](I)|0;G=c[2415188]|0;J=H;K=G;L=c[3528554]|0;M=c[2433592]|0;N=G&65535}else{J=a[v+(E&255)|0]|0;K=E;L=F;M=D;N=I}}while(0);I=J&255;J=I<<8;D=K+1|0;K=D&65535;F=c[M+(L*3148|0)+48+((D>>>8&255)<<2)>>2]|0;do{if((F|0)==0){E=c[M+(L*3148|0)+3132>>2]|0;if((E|0)==0){O=0;P=N;Q=L;R=M;break}v=gj[E&4095](K)|0;O=v;P=b[4830376]|0;Q=c[3528554]|0;R=c[2433592]|0}else{O=a[F+(D&255)|0]|0;P=N;Q=L;R=M}}while(0);M=O&255;O=M|J;c[2426864]=O;b[4830376]=P+2&65535;P=O&65535;J=c[R+(Q*3148|0)+48+(I<<2)>>2]|0;do{if((J|0)==0){I=c[R+(Q*3148|0)+3120>>2]|0;if((I|0)==0){S=0;T=Q;U=R;break}L=gj[I&4095](P)|0;S=L;T=c[3528554]|0;U=c[2433592]|0}else{S=a[J+M|0]|0;T=Q;U=R}}while(0);R=(S&255)<<8;S=O+1|0;O=S&65535;Q=c[U+(T*3148|0)+48+((S>>>8&255)<<2)>>2]|0;do{if((Q|0)==0){M=c[U+(T*3148|0)+3120>>2]|0;if((M|0)==0){V=0;break}V=gj[M&4095](O)|0}else{V=a[Q+(S&255)|0]|0}}while(0);c[2426864]=V&255|R;c[2440592]=(c[2440592]|0)-8;return};case 224:{R=b[4830386]|0;b[4853728]=R;b[4830386]=R+1&65535;c[2440592]=(c[2440592]|0)-2;return};case 225:{R=b[4830386]|0;b[4853728]=R;b[4830386]=R+2&65535;c[2440592]=(c[2440592]|0)-3;return};case 226:{R=(b[4830386]|0)-1&65535;b[4830386]=R;b[4853728]=R;c[2440592]=(c[2440592]|0)-2;return};case 227:{R=(b[4830386]|0)-2&65535;b[4830386]=R;b[4853728]=R;c[2440592]=(c[2440592]|0)-3;return};case 228:{b[4853728]=b[4830386]|0;return};case 229:{R=d[9660760]|0;b[4853728]=((R&128|0)!=0?R|65280:R)+(e[4830386]|0)&65535;c[2440592]=(c[2440592]|0)-1;return};case 230:{R=d[9660761]|0;b[4853728]=((R&128|0)!=0?R|65280:R)+(e[4830386]|0)&65535;c[2440592]=(c[2440592]|0)-1;return};case 231:{b[4853728]=0;return};case 232:{R=c[2415188]|0;V=R&65535;S=c[3528554]|0;Q=c[2433592]|0;O=c[Q+(S*3148|0)+48+((R>>>8&255)<<2)>>2]|0;do{if((O|0)==0){T=c[Q+(S*3148|0)+3132>>2]|0;if((T|0)==0){W=0;X=V;break}U=gj[T&4095](V)|0;W=U;X=b[4830376]|0}else{W=a[O+(R&255)|0]|0;X=V}}while(0);V=W&255;b[4830376]=X+1&65535;b[4853728]=((V&128)!=0?V|-256:V)+(b[4830386]|0)&65535;c[2440592]=(c[2440592]|0)-1;return};case 233:{V=c[2415188]|0;X=V&65535;W=c[3528554]|0;R=c[2433592]|0;O=c[R+(W*3148|0)+48+((V>>>8&255)<<2)>>2]|0;do{if((O|0)==0){S=c[R+(W*3148|0)+3132>>2]|0;if((S|0)==0){Y=0;Z=V;_=W;$=R;aa=X;break}Q=gj[S&4095](X)|0;S=c[2415188]|0;Y=Q;Z=S;_=c[3528554]|0;$=c[2433592]|0;aa=S&65535}else{Y=a[O+(V&255)|0]|0;Z=V;_=W;$=R;aa=X}}while(0);X=(Y&255)<<8;Y=Z+1|0;Z=Y&65535;R=c[$+(_*3148|0)+48+((Y>>>8&255)<<2)>>2]|0;do{if((R|0)==0){W=c[$+(_*3148|0)+3132>>2]|0;if((W|0)==0){ab=0;ac=aa;break}V=gj[W&4095](Z)|0;ab=V;ac=b[4830376]|0}else{ab=a[R+(Y&255)|0]|0;ac=aa}}while(0);aa=ab&255|X;c[2426864]=aa;b[4830376]=ac+2&65535;b[4853728]=(aa&65535)+(b[4830386]|0)&65535;c[2440592]=(c[2440592]|0)-4;return};case 234:{b[4853728]=0;return};case 235:{b[4853728]=(b[4830380]|0)+(b[4830386]|0)&65535;c[2440592]=(c[2440592]|0)-4;return};case 236:{aa=c[2415188]|0;ac=aa&65535;X=c[3528554]|0;ab=c[2433592]|0;Y=c[ab+(X*3148|0)+48+((aa>>>8&255)<<2)>>2]|0;do{if((Y|0)==0){R=c[ab+(X*3148|0)+3132>>2]|0;if((R|0)==0){ad=0;ae=ac;break}Z=gj[R&4095](ac)|0;ad=Z;ae=b[4830376]|0}else{ad=a[Y+(aa&255)|0]|0;ae=ac}}while(0);ac=ad&255;ad=ae+1&65535;b[4830376]=ad;b[4853728]=((ac&128)!=0?ac|-256:ac)+ad&65535;c[2440592]=(c[2440592]|0)-1;return};case 237:{ad=c[2415188]|0;ac=ad&65535;ae=c[3528554]|0;aa=c[2433592]|0;Y=c[aa+(ae*3148|0)+48+((ad>>>8&255)<<2)>>2]|0;do{if((Y|0)==0){X=c[aa+(ae*3148|0)+3132>>2]|0;if((X|0)==0){af=0;ag=ad;ah=ae;ai=aa;aj=ac;break}ab=gj[X&4095](ac)|0;X=c[2415188]|0;af=ab;ag=X;ah=c[3528554]|0;ai=c[2433592]|0;aj=X&65535}else{af=a[Y+(ad&255)|0]|0;ag=ad;ah=ae;ai=aa;aj=ac}}while(0);ac=(af&255)<<8;af=ag+1|0;ag=af&65535;aa=c[ai+(ah*3148|0)+48+((af>>>8&255)<<2)>>2]|0;do{if((aa|0)==0){ae=c[ai+(ah*3148|0)+3132>>2]|0;if((ae|0)==0){ak=0;al=aj;break}ad=gj[ae&4095](ag)|0;ak=ad;al=b[4830376]|0}else{ak=a[aa+(af&255)|0]|0;al=aj}}while(0);aj=ak&255|ac;c[2426864]=aj;ac=al+2&65535;b[4830376]=ac;b[4853728]=(aj&65535)+ac&65535;c[2440592]=(c[2440592]|0)-5;return};case 238:{b[4853728]=0;return};case 239:{ac=c[2415188]|0;aj=ac&65535;al=c[3528554]|0;ak=c[2433592]|0;af=c[ak+(al*3148|0)+48+((ac>>>8&255)<<2)>>2]|0;do{if((af|0)==0){aa=c[ak+(al*3148|0)+3132>>2]|0;if((aa|0)==0){am=0;an=ac;ao=al;ap=ak;aq=aj;break}ag=gj[aa&4095](aj)|0;aa=c[2415188]|0;am=ag;an=aa;ao=c[3528554]|0;ap=c[2433592]|0;aq=aa&65535}else{am=a[af+(ac&255)|0]|0;an=ac;ao=al;ap=ak;aq=aj}}while(0);aj=(am&255)<<8;am=an+1|0;an=am&65535;ak=c[ap+(ao*3148|0)+48+((am>>>8&255)<<2)>>2]|0;do{if((ak|0)==0){al=c[ap+(ao*3148|0)+3132>>2]|0;if((al|0)==0){ar=0;as=aq;break}ac=gj[al&4095](an)|0;ar=ac;as=b[4830376]|0}else{ar=a[ak+(am&255)|0]|0;as=aq}}while(0);c[2426864]=ar&255|aj;b[4830376]=as+2&65535;c[2440592]=(c[2440592]|0)-5;return};case 240:{as=b[4830386]|0;b[4853728]=as;b[4830386]=as+1&65535;as=c[2426864]|0;aj=as&65535;ar=c[3528554]|0;aq=c[2433592]|0;am=c[aq+(ar*3148|0)+48+((as>>>8&255)<<2)>>2]|0;do{if((am|0)==0){ak=c[aq+(ar*3148|0)+3120>>2]|0;if((ak|0)==0){at=0;au=ar;av=aq;break}an=gj[ak&4095](aj)|0;at=an;au=c[3528554]|0;av=c[2433592]|0}else{at=a[am+(as&255)|0]|0;au=ar;av=aq}}while(0);aq=(at&255)<<8;at=as+1|0;as=at&65535;ar=c[av+(au*3148|0)+48+((at>>>8&255)<<2)>>2]|0;do{if((ar|0)==0){am=c[av+(au*3148|0)+3120>>2]|0;if((am|0)==0){aw=0;break}aw=gj[am&4095](as)|0}else{aw=a[ar+(at&255)|0]|0}}while(0);c[2426864]=aw&255|aq;c[2440592]=(c[2440592]|0)-5;return};case 241:{aq=b[4830386]|0;b[4853728]=aq;b[4830386]=aq+2&65535;aq=c[2426864]|0;aw=aq&65535;at=c[3528554]|0;ar=c[2433592]|0;as=c[ar+(at*3148|0)+48+((aq>>>8&255)<<2)>>2]|0;do{if((as|0)==0){au=c[ar+(at*3148|0)+3120>>2]|0;if((au|0)==0){ax=0;ay=at;az=ar;break}av=gj[au&4095](aw)|0;ax=av;ay=c[3528554]|0;az=c[2433592]|0}else{ax=a[as+(aq&255)|0]|0;ay=at;az=ar}}while(0);ar=(ax&255)<<8;ax=aq+1|0;aq=ax&65535;at=c[az+(ay*3148|0)+48+((ax>>>8&255)<<2)>>2]|0;do{if((at|0)==0){as=c[az+(ay*3148|0)+3120>>2]|0;if((as|0)==0){aA=0;break}aA=gj[as&4095](aq)|0}else{aA=a[at+(ax&255)|0]|0}}while(0);c[2426864]=aA&255|ar;c[2440592]=(c[2440592]|0)-6;return};case 242:{ar=(b[4830386]|0)-1&65535;b[4830386]=ar;b[4853728]=ar;ar=c[2426864]|0;aA=ar&65535;ax=c[3528554]|0;at=c[2433592]|0;aq=c[at+(ax*3148|0)+48+((ar>>>8&255)<<2)>>2]|0;do{if((aq|0)==0){ay=c[at+(ax*3148|0)+3120>>2]|0;if((ay|0)==0){aB=0;aC=ax;aD=at;break}az=gj[ay&4095](aA)|0;aB=az;aC=c[3528554]|0;aD=c[2433592]|0}else{aB=a[aq+(ar&255)|0]|0;aC=ax;aD=at}}while(0);at=(aB&255)<<8;aB=ar+1|0;ar=aB&65535;ax=c[aD+(aC*3148|0)+48+((aB>>>8&255)<<2)>>2]|0;do{if((ax|0)==0){aq=c[aD+(aC*3148|0)+3120>>2]|0;if((aq|0)==0){aE=0;break}aE=gj[aq&4095](ar)|0}else{aE=a[ax+(aB&255)|0]|0}}while(0);c[2426864]=aE&255|at;c[2440592]=(c[2440592]|0)-5;return};case 243:{at=(b[4830386]|0)-2&65535;b[4830386]=at;b[4853728]=at;at=c[2426864]|0;aE=at&65535;aB=c[3528554]|0;ax=c[2433592]|0;ar=c[ax+(aB*3148|0)+48+((at>>>8&255)<<2)>>2]|0;do{if((ar|0)==0){aC=c[ax+(aB*3148|0)+3120>>2]|0;if((aC|0)==0){aF=0;aG=aB;aH=ax;break}aD=gj[aC&4095](aE)|0;aF=aD;aG=c[3528554]|0;aH=c[2433592]|0}else{aF=a[ar+(at&255)|0]|0;aG=aB;aH=ax}}while(0);ax=(aF&255)<<8;aF=at+1|0;at=aF&65535;aB=c[aH+(aG*3148|0)+48+((aF>>>8&255)<<2)>>2]|0;do{if((aB|0)==0){ar=c[aH+(aG*3148|0)+3120>>2]|0;if((ar|0)==0){aI=0;break}aI=gj[ar&4095](at)|0}else{aI=a[aB+(aF&255)|0]|0}}while(0);c[2426864]=aI&255|ax;c[2440592]=(c[2440592]|0)-6;return};case 244:{b[4853728]=b[4830386]|0;ax=c[2426864]|0;aI=ax&65535;aF=c[3528554]|0;aB=c[2433592]|0;at=c[aB+(aF*3148|0)+48+((ax>>>8&255)<<2)>>2]|0;do{if((at|0)==0){aG=c[aB+(aF*3148|0)+3120>>2]|0;if((aG|0)==0){aJ=0;aK=aF;aL=aB;break}aH=gj[aG&4095](aI)|0;aJ=aH;aK=c[3528554]|0;aL=c[2433592]|0}else{aJ=a[at+(ax&255)|0]|0;aK=aF;aL=aB}}while(0);aB=(aJ&255)<<8;aJ=ax+1|0;ax=aJ&65535;aF=c[aL+(aK*3148|0)+48+((aJ>>>8&255)<<2)>>2]|0;do{if((aF|0)==0){at=c[aL+(aK*3148|0)+3120>>2]|0;if((at|0)==0){aM=0;break}aM=gj[at&4095](ax)|0}else{aM=a[aF+(aJ&255)|0]|0}}while(0);c[2426864]=aM&255|aB;c[2440592]=(c[2440592]|0)-3;return};case 245:{aB=d[9660760]|0;b[4853728]=((aB&128|0)!=0?aB|65280:aB)+(e[4830386]|0)&65535;aB=c[2426864]|0;aM=aB&65535;aJ=c[3528554]|0;aF=c[2433592]|0;ax=c[aF+(aJ*3148|0)+48+((aB>>>8&255)<<2)>>2]|0;do{if((ax|0)==0){aK=c[aF+(aJ*3148|0)+3120>>2]|0;if((aK|0)==0){aN=0;aO=aJ;aP=aF;break}aL=gj[aK&4095](aM)|0;aN=aL;aO=c[3528554]|0;aP=c[2433592]|0}else{aN=a[ax+(aB&255)|0]|0;aO=aJ;aP=aF}}while(0);aF=(aN&255)<<8;aN=aB+1|0;aB=aN&65535;aJ=c[aP+(aO*3148|0)+48+((aN>>>8&255)<<2)>>2]|0;do{if((aJ|0)==0){ax=c[aP+(aO*3148|0)+3120>>2]|0;if((ax|0)==0){aQ=0;break}aQ=gj[ax&4095](aB)|0}else{aQ=a[aJ+(aN&255)|0]|0}}while(0);c[2426864]=aQ&255|aF;c[2440592]=(c[2440592]|0)-4;return};case 246:{aF=d[9660761]|0;b[4853728]=((aF&128|0)!=0?aF|65280:aF)+(e[4830386]|0)&65535;aF=c[2426864]|0;aQ=aF&65535;aN=c[3528554]|0;aJ=c[2433592]|0;aB=c[aJ+(aN*3148|0)+48+((aF>>>8&255)<<2)>>2]|0;do{if((aB|0)==0){aO=c[aJ+(aN*3148|0)+3120>>2]|0;if((aO|0)==0){aR=0;aS=aN;aT=aJ;break}aP=gj[aO&4095](aQ)|0;aR=aP;aS=c[3528554]|0;aT=c[2433592]|0}else{aR=a[aB+(aF&255)|0]|0;aS=aN;aT=aJ}}while(0);aJ=(aR&255)<<8;aR=aF+1|0;aF=aR&65535;aN=c[aT+(aS*3148|0)+48+((aR>>>8&255)<<2)>>2]|0;do{if((aN|0)==0){aB=c[aT+(aS*3148|0)+3120>>2]|0;if((aB|0)==0){aU=0;break}aU=gj[aB&4095](aF)|0}else{aU=a[aN+(aR&255)|0]|0}}while(0);c[2426864]=aU&255|aJ;c[2440592]=(c[2440592]|0)-4;return};case 247:{b[4853728]=0;return};case 248:{aJ=c[2415188]|0;aU=aJ&65535;aR=c[3528554]|0;aN=c[2433592]|0;aF=c[aN+(aR*3148|0)+48+((aJ>>>8&255)<<2)>>2]|0;do{if((aF|0)==0){aS=c[aN+(aR*3148|0)+3132>>2]|0;if((aS|0)==0){aV=0;aW=aU;aX=aR;aY=aN;break}aT=gj[aS&4095](aU)|0;aV=aT;aW=b[4830376]|0;aX=c[3528554]|0;aY=c[2433592]|0}else{aV=a[aF+(aJ&255)|0]|0;aW=aU;aX=aR;aY=aN}}while(0);aN=aV&255;b[4830376]=aW+1&65535;b[4853728]=((aN&128)!=0?aN|-256:aN)+(b[4830386]|0)&65535;aN=c[2426864]|0;aW=aN&65535;aV=c[aY+(aX*3148|0)+48+((aN>>>8&255)<<2)>>2]|0;do{if((aV|0)==0){aR=c[aY+(aX*3148|0)+3120>>2]|0;if((aR|0)==0){aZ=0;a_=aX;a$=aY;break}aU=gj[aR&4095](aW)|0;aZ=aU;a_=c[3528554]|0;a$=c[2433592]|0}else{aZ=a[aV+(aN&255)|0]|0;a_=aX;a$=aY}}while(0);aY=(aZ&255)<<8;aZ=aN+1|0;aN=aZ&65535;aX=c[a$+(a_*3148|0)+48+((aZ>>>8&255)<<2)>>2]|0;do{if((aX|0)==0){aV=c[a$+(a_*3148|0)+3120>>2]|0;if((aV|0)==0){a0=0;break}a0=gj[aV&4095](aN)|0}else{a0=a[aX+(aZ&255)|0]|0}}while(0);c[2426864]=a0&255|aY;c[2440592]=(c[2440592]|0)-4;return};case 249:{aY=c[2415188]|0;a0=aY&65535;aZ=c[3528554]|0;aX=c[2433592]|0;aN=c[aX+(aZ*3148|0)+48+((aY>>>8&255)<<2)>>2]|0;do{if((aN|0)==0){a_=c[aX+(aZ*3148|0)+3132>>2]|0;if((a_|0)==0){a1=0;a2=aY;a3=aZ;a4=aX;a5=a0;break}a$=gj[a_&4095](a0)|0;a_=c[2415188]|0;a1=a$;a2=a_;a3=c[3528554]|0;a4=c[2433592]|0;a5=a_&65535}else{a1=a[aN+(aY&255)|0]|0;a2=aY;a3=aZ;a4=aX;a5=a0}}while(0);a0=(a1&255)<<8;a1=a2+1|0;a2=a1&65535;aX=c[a4+(a3*3148|0)+48+((a1>>>8&255)<<2)>>2]|0;do{if((aX|0)==0){aZ=c[a4+(a3*3148|0)+3132>>2]|0;if((aZ|0)==0){a6=0;a7=a5;a8=a3;a9=a4;break}aY=gj[aZ&4095](a2)|0;a6=aY;a7=b[4830376]|0;a8=c[3528554]|0;a9=c[2433592]|0}else{a6=a[aX+(a1&255)|0]|0;a7=a5;a8=a3;a9=a4}}while(0);a4=a6&255|a0;c[2426864]=a4;b[4830376]=a7+2&65535;b[4853728]=(a4&65535)+(b[4830386]|0)&65535;a4=c[2426864]|0;a7=a4&65535;a0=c[a9+(a8*3148|0)+48+((a4>>>8&255)<<2)>>2]|0;do{if((a0|0)==0){a6=c[a9+(a8*3148|0)+3120>>2]|0;if((a6|0)==0){ba=0;bb=a8;bc=a9;break}a3=gj[a6&4095](a7)|0;ba=a3;bb=c[3528554]|0;bc=c[2433592]|0}else{ba=a[a0+(a4&255)|0]|0;bb=a8;bc=a9}}while(0);a9=(ba&255)<<8;ba=a4+1|0;a4=ba&65535;a8=c[bc+(bb*3148|0)+48+((ba>>>8&255)<<2)>>2]|0;do{if((a8|0)==0){a0=c[bc+(bb*3148|0)+3120>>2]|0;if((a0|0)==0){bd=0;break}bd=gj[a0&4095](a4)|0}else{bd=a[a8+(ba&255)|0]|0}}while(0);c[2426864]=bd&255|a9;c[2440592]=(c[2440592]|0)-7;return};case 250:{b[4853728]=0;return};case 251:{b[4853728]=(b[4830380]|0)+(b[4830386]|0)&65535;a9=c[2426864]|0;bd=a9&65535;ba=c[3528554]|0;a8=c[2433592]|0;a4=c[a8+(ba*3148|0)+48+((a9>>>8&255)<<2)>>2]|0;do{if((a4|0)==0){bb=c[a8+(ba*3148|0)+3120>>2]|0;if((bb|0)==0){be=0;bf=ba;bg=a8;break}bc=gj[bb&4095](bd)|0;be=bc;bf=c[3528554]|0;bg=c[2433592]|0}else{be=a[a4+(a9&255)|0]|0;bf=ba;bg=a8}}while(0);a8=(be&255)<<8;be=a9+1|0;a9=be&65535;ba=c[bg+(bf*3148|0)+48+((be>>>8&255)<<2)>>2]|0;do{if((ba|0)==0){a4=c[bg+(bf*3148|0)+3120>>2]|0;if((a4|0)==0){bh=0;break}bh=gj[a4&4095](a9)|0}else{bh=a[ba+(be&255)|0]|0}}while(0);c[2426864]=bh&255|a8;c[2440592]=(c[2440592]|0)-7;return};case 252:{a8=c[2415188]|0;bh=a8&65535;be=c[3528554]|0;ba=c[2433592]|0;a9=c[ba+(be*3148|0)+48+((a8>>>8&255)<<2)>>2]|0;do{if((a9|0)==0){bf=c[ba+(be*3148|0)+3132>>2]|0;if((bf|0)==0){bi=0;bj=bh;bk=be;bl=ba;break}bg=gj[bf&4095](bh)|0;bi=bg;bj=b[4830376]|0;bk=c[3528554]|0;bl=c[2433592]|0}else{bi=a[a9+(a8&255)|0]|0;bj=bh;bk=be;bl=ba}}while(0);ba=bi&255;bi=bj+1&65535;b[4830376]=bi;b[4853728]=((ba&128)!=0?ba|-256:ba)+bi&65535;bi=c[2426864]|0;ba=bi&65535;bj=c[bl+(bk*3148|0)+48+((bi>>>8&255)<<2)>>2]|0;do{if((bj|0)==0){be=c[bl+(bk*3148|0)+3120>>2]|0;if((be|0)==0){bm=0;bn=bk;bo=bl;break}bh=gj[be&4095](ba)|0;bm=bh;bn=c[3528554]|0;bo=c[2433592]|0}else{bm=a[bj+(bi&255)|0]|0;bn=bk;bo=bl}}while(0);bl=(bm&255)<<8;bm=bi+1|0;bi=bm&65535;bk=c[bo+(bn*3148|0)+48+((bm>>>8&255)<<2)>>2]|0;do{if((bk|0)==0){bj=c[bo+(bn*3148|0)+3120>>2]|0;if((bj|0)==0){bp=0;break}bp=gj[bj&4095](bi)|0}else{bp=a[bk+(bm&255)|0]|0}}while(0);c[2426864]=bp&255|bl;c[2440592]=(c[2440592]|0)-4;return};case 253:{bl=c[2415188]|0;bp=bl&65535;bm=c[3528554]|0;bk=c[2433592]|0;bi=c[bk+(bm*3148|0)+48+((bl>>>8&255)<<2)>>2]|0;do{if((bi|0)==0){bn=c[bk+(bm*3148|0)+3132>>2]|0;if((bn|0)==0){bq=0;br=bl;bs=bm;bt=bk;bu=bp;break}bo=gj[bn&4095](bp)|0;bn=c[2415188]|0;bq=bo;br=bn;bs=c[3528554]|0;bt=c[2433592]|0;bu=bn&65535}else{bq=a[bi+(bl&255)|0]|0;br=bl;bs=bm;bt=bk;bu=bp}}while(0);bp=(bq&255)<<8;bq=br+1|0;br=bq&65535;bk=c[bt+(bs*3148|0)+48+((bq>>>8&255)<<2)>>2]|0;do{if((bk|0)==0){bm=c[bt+(bs*3148|0)+3132>>2]|0;if((bm|0)==0){bv=0;bw=bu;bx=bs;by=bt;break}bl=gj[bm&4095](br)|0;bv=bl;bw=b[4830376]|0;bx=c[3528554]|0;by=c[2433592]|0}else{bv=a[bk+(bq&255)|0]|0;bw=bu;bx=bs;by=bt}}while(0);bt=bv&255|bp;c[2426864]=bt;bp=bw+2&65535;b[4830376]=bp;b[4853728]=(bt&65535)+bp&65535;bp=c[2426864]|0;bt=bp&65535;bw=c[by+(bx*3148|0)+48+((bp>>>8&255)<<2)>>2]|0;do{if((bw|0)==0){bv=c[by+(bx*3148|0)+3120>>2]|0;if((bv|0)==0){bz=0;bA=bx;bB=by;break}bs=gj[bv&4095](bt)|0;bz=bs;bA=c[3528554]|0;bB=c[2433592]|0}else{bz=a[bw+(bp&255)|0]|0;bA=bx;bB=by}}while(0);by=(bz&255)<<8;bz=bp+1|0;bp=bz&65535;bx=c[bB+(bA*3148|0)+48+((bz>>>8&255)<<2)>>2]|0;do{if((bx|0)==0){bw=c[bB+(bA*3148|0)+3120>>2]|0;if((bw|0)==0){bC=0;break}bC=gj[bw&4095](bp)|0}else{bC=a[bx+(bz&255)|0]|0}}while(0);c[2426864]=bC&255|by;c[2440592]=(c[2440592]|0)-8;return};case 254:{b[4853728]=0;return};case 255:{by=c[2415188]|0;bC=by&65535;bz=c[3528554]|0;bx=c[2433592]|0;bp=c[bx+(bz*3148|0)+48+((by>>>8&255)<<2)>>2]|0;do{if((bp|0)==0){bA=c[bx+(bz*3148|0)+3132>>2]|0;if((bA|0)==0){bD=0;bE=by;bF=bz;bG=bx;bH=bC;break}bB=gj[bA&4095](bC)|0;bA=c[2415188]|0;bD=bB;bE=bA;bF=c[3528554]|0;bG=c[2433592]|0;bH=bA&65535}else{bD=a[bp+(by&255)|0]|0;bE=by;bF=bz;bG=bx;bH=bC}}while(0);bC=bD&255;bD=bC<<8;bx=bE+1|0;bE=bx&65535;bz=c[bG+(bF*3148|0)+48+((bx>>>8&255)<<2)>>2]|0;do{if((bz|0)==0){by=c[bG+(bF*3148|0)+3132>>2]|0;if((by|0)==0){bI=0;bJ=bH;bK=bF;bL=bG;break}bp=gj[by&4095](bE)|0;bI=bp;bJ=b[4830376]|0;bK=c[3528554]|0;bL=c[2433592]|0}else{bI=a[bz+(bx&255)|0]|0;bJ=bH;bK=bF;bL=bG}}while(0);bG=bI&255;bI=bG|bD;c[2426864]=bI;b[4830376]=bJ+2&65535;bJ=bI&65535;bD=c[bL+(bK*3148|0)+48+(bC<<2)>>2]|0;do{if((bD|0)==0){bC=c[bL+(bK*3148|0)+3120>>2]|0;if((bC|0)==0){bM=0;bN=bK;bO=bL;break}bF=gj[bC&4095](bJ)|0;bM=bF;bN=c[3528554]|0;bO=c[2433592]|0}else{bM=a[bD+bG|0]|0;bN=bK;bO=bL}}while(0);bL=(bM&255)<<8;bM=bI+1|0;bI=bM&65535;bK=c[bO+(bN*3148|0)+48+((bM>>>8&255)<<2)>>2]|0;do{if((bK|0)==0){bG=c[bO+(bN*3148|0)+3120>>2]|0;if((bG|0)==0){bP=0;break}bP=gj[bG&4095](bI)|0}else{bP=a[bK+(bM&255)|0]|0}}while(0);c[2426864]=bP&255|bL;c[2440592]=(c[2440592]|0)-8;return};case 84:{b[4853728]=(b[4830384]|0)-12&65535;c[2440592]=(c[2440592]|0)-1;return};case 85:{b[4853728]=(b[4830384]|0)-11&65535;c[2440592]=(c[2440592]|0)-1;return};case 86:{b[4853728]=(b[4830384]|0)-10&65535;c[2440592]=(c[2440592]|0)-1;return};case 87:{b[4853728]=(b[4830384]|0)-9&65535;c[2440592]=(c[2440592]|0)-1;return};case 88:{b[4853728]=(b[4830384]|0)-8&65535;c[2440592]=(c[2440592]|0)-1;return};case 89:{b[4853728]=(b[4830384]|0)-7&65535;c[2440592]=(c[2440592]|0)-1;return};case 90:{b[4853728]=(b[4830384]|0)-6&65535;c[2440592]=(c[2440592]|0)-1;return};case 91:{b[4853728]=(b[4830384]|0)-5&65535;c[2440592]=(c[2440592]|0)-1;return};case 92:{b[4853728]=(b[4830384]|0)-4&65535;c[2440592]=(c[2440592]|0)-1;return};case 93:{b[4853728]=(b[4830384]|0)-3&65535;c[2440592]=(c[2440592]|0)-1;return};case 94:{b[4853728]=(b[4830384]|0)-2&65535;c[2440592]=(c[2440592]|0)-1;return};case 95:{b[4853728]=(b[4830384]|0)-1&65535;c[2440592]=(c[2440592]|0)-1;return};case 96:{b[4853728]=b[4830386]|0;c[2440592]=(c[2440592]|0)-1;return};case 97:{b[4853728]=(b[4830386]|0)+1&65535;c[2440592]=(c[2440592]|0)-1;return};case 98:{b[4853728]=(b[4830386]|0)+2&65535;c[2440592]=(c[2440592]|0)-1;return};case 99:{b[4853728]=(b[4830386]|0)+3&65535;c[2440592]=(c[2440592]|0)-1;return};case 100:{b[4853728]=(b[4830386]|0)+4&65535;c[2440592]=(c[2440592]|0)-1;return};case 101:{b[4853728]=(b[4830386]|0)+5&65535;c[2440592]=(c[2440592]|0)-1;return};case 102:{b[4853728]=(b[4830386]|0)+6&65535;c[2440592]=(c[2440592]|0)-1;return};case 66:{b[4853728]=(b[4830384]|0)+2&65535;c[2440592]=(c[2440592]|0)-1;return};case 67:{b[4853728]=(b[4830384]|0)+3&65535;c[2440592]=(c[2440592]|0)-1;return};case 68:{b[4853728]=(b[4830384]|0)+4&65535;c[2440592]=(c[2440592]|0)-1;return};case 69:{b[4853728]=(b[4830384]|0)+5&65535;c[2440592]=(c[2440592]|0)-1;return};case 70:{b[4853728]=(b[4830384]|0)+6&65535;c[2440592]=(c[2440592]|0)-1;return};case 71:{b[4853728]=(b[4830384]|0)+7&65535;c[2440592]=(c[2440592]|0)-1;return};case 72:{b[4853728]=(b[4830384]|0)+8&65535;c[2440592]=(c[2440592]|0)-1;return};case 73:{b[4853728]=(b[4830384]|0)+9&65535;c[2440592]=(c[2440592]|0)-1;return};case 74:{b[4853728]=(b[4830384]|0)+10&65535;c[2440592]=(c[2440592]|0)-1;return};case 75:{b[4853728]=(b[4830384]|0)+11&65535;c[2440592]=(c[2440592]|0)-1;return};case 76:{b[4853728]=(b[4830384]|0)+12&65535;c[2440592]=(c[2440592]|0)-1;return};case 77:{b[4853728]=(b[4830384]|0)+13&65535;c[2440592]=(c[2440592]|0)-1;return};case 78:{b[4853728]=(b[4830384]|0)+14&65535;c[2440592]=(c[2440592]|0)-1;return};case 79:{b[4853728]=(b[4830384]|0)+15&65535;c[2440592]=(c[2440592]|0)-1;return};case 80:{b[4853728]=(b[4830384]|0)-16&65535;c[2440592]=(c[2440592]|0)-1;return};case 81:{b[4853728]=(b[4830384]|0)-15&65535;c[2440592]=(c[2440592]|0)-1;return};case 82:{b[4853728]=(b[4830384]|0)-14&65535;c[2440592]=(c[2440592]|0)-1;return};case 83:{b[4853728]=(b[4830384]|0)-13&65535;c[2440592]=(c[2440592]|0)-1;return};case 17:{b[4853728]=(b[4830388]|0)-15&65535;c[2440592]=(c[2440592]|0)-1;return};case 18:{b[4853728]=(b[4830388]|0)-14&65535;c[2440592]=(c[2440592]|0)-1;return};case 21:{b[4853728]=(b[4830388]|0)-11&65535;c[2440592]=(c[2440592]|0)-1;return};case 20:{b[4853728]=(b[4830388]|0)-12&65535;c[2440592]=(c[2440592]|0)-1;return};case 22:{b[4853728]=(b[4830388]|0)-10&65535;c[2440592]=(c[2440592]|0)-1;return};case 19:{b[4853728]=(b[4830388]|0)-13&65535;c[2440592]=(c[2440592]|0)-1;return};case 35:{b[4853728]=(b[4830390]|0)+3&65535;c[2440592]=(c[2440592]|0)-1;return};case 36:{b[4853728]=(b[4830390]|0)+4&65535;c[2440592]=(c[2440592]|0)-1;return};case 37:{b[4853728]=(b[4830390]|0)+5&65535;c[2440592]=(c[2440592]|0)-1;return};case 38:{b[4853728]=(b[4830390]|0)+6&65535;c[2440592]=(c[2440592]|0)-1;return};case 39:{b[4853728]=(b[4830390]|0)+7&65535;c[2440592]=(c[2440592]|0)-1;return};case 40:{b[4853728]=(b[4830390]|0)+8&65535;c[2440592]=(c[2440592]|0)-1;return};case 41:{b[4853728]=(b[4830390]|0)+9&65535;c[2440592]=(c[2440592]|0)-1;return};case 42:{b[4853728]=(b[4830390]|0)+10&65535;c[2440592]=(c[2440592]|0)-1;return};case 129:{bL=b[4830388]|0;b[4853728]=bL;b[4830388]=bL+2&65535;c[2440592]=(c[2440592]|0)-3;return};case 130:{bL=(b[4830388]|0)-1&65535;b[4830388]=bL;b[4853728]=bL;c[2440592]=(c[2440592]|0)-2;return};case 131:{bL=(b[4830388]|0)-2&65535;b[4830388]=bL;b[4853728]=bL;c[2440592]=(c[2440592]|0)-3;return};case 132:{b[4853728]=b[4830388]|0;return};case 133:{bL=d[9660760]|0;b[4853728]=((bL&128|0)!=0?bL|65280:bL)+(e[4830388]|0)&65535;c[2440592]=(c[2440592]|0)-1;return};case 134:{bL=d[9660761]|0;b[4853728]=((bL&128|0)!=0?bL|65280:bL)+(e[4830388]|0)&65535;c[2440592]=(c[2440592]|0)-1;return};case 135:{b[4853728]=0;return};case 136:{bL=c[2415188]|0;bP=bL&65535;bM=c[3528554]|0;bK=c[2433592]|0;bI=c[bK+(bM*3148|0)+48+((bL>>>8&255)<<2)>>2]|0;do{if((bI|0)==0){bN=c[bK+(bM*3148|0)+3132>>2]|0;if((bN|0)==0){bQ=0;bR=bP;break}bO=gj[bN&4095](bP)|0;bQ=bO;bR=b[4830376]|0}else{bQ=a[bI+(bL&255)|0]|0;bR=bP}}while(0);bP=bQ&255;b[4830376]=bR+1&65535;b[4853728]=((bP&128)!=0?bP|-256:bP)+(b[4830388]|0)&65535;c[2440592]=(c[2440592]|0)-1;return};case 137:{bP=c[2415188]|0;bR=bP&65535;bQ=c[3528554]|0;bL=c[2433592]|0;bI=c[bL+(bQ*3148|0)+48+((bP>>>8&255)<<2)>>2]|0;do{if((bI|0)==0){bM=c[bL+(bQ*3148|0)+3132>>2]|0;if((bM|0)==0){bS=0;bT=bP;bU=bQ;bV=bL;bW=bR;break}bK=gj[bM&4095](bR)|0;bM=c[2415188]|0;bS=bK;bT=bM;bU=c[3528554]|0;bV=c[2433592]|0;bW=bM&65535}else{bS=a[bI+(bP&255)|0]|0;bT=bP;bU=bQ;bV=bL;bW=bR}}while(0);bR=(bS&255)<<8;bS=bT+1|0;bT=bS&65535;bL=c[bV+(bU*3148|0)+48+((bS>>>8&255)<<2)>>2]|0;do{if((bL|0)==0){bQ=c[bV+(bU*3148|0)+3132>>2]|0;if((bQ|0)==0){bX=0;bY=bW;break}bP=gj[bQ&4095](bT)|0;bX=bP;bY=b[4830376]|0}else{bX=a[bL+(bS&255)|0]|0;bY=bW}}while(0);bW=bX&255|bR;c[2426864]=bW;b[4830376]=bY+2&65535;b[4853728]=(bW&65535)+(b[4830388]|0)&65535;c[2440592]=(c[2440592]|0)-4;return};case 138:{b[4853728]=0;return};case 139:{b[4853728]=(b[4830380]|0)+(b[4830388]|0)&65535;c[2440592]=(c[2440592]|0)-4;return};case 140:{bW=c[2415188]|0;bY=bW&65535;bR=c[3528554]|0;bX=c[2433592]|0;bS=c[bX+(bR*3148|0)+48+((bW>>>8&255)<<2)>>2]|0;do{if((bS|0)==0){bL=c[bX+(bR*3148|0)+3132>>2]|0;if((bL|0)==0){bZ=0;b_=bY;break}bT=gj[bL&4095](bY)|0;bZ=bT;b_=b[4830376]|0}else{bZ=a[bS+(bW&255)|0]|0;b_=bY}}while(0);bY=bZ&255;bZ=b_+1&65535;b[4830376]=bZ;b[4853728]=((bY&128)!=0?bY|-256:bY)+bZ&65535;c[2440592]=(c[2440592]|0)-1;return};case 141:{bZ=c[2415188]|0;bY=bZ&65535;b_=c[3528554]|0;bW=c[2433592]|0;bS=c[bW+(b_*3148|0)+48+((bZ>>>8&255)<<2)>>2]|0;do{if((bS|0)==0){bR=c[bW+(b_*3148|0)+3132>>2]|0;if((bR|0)==0){b$=0;b0=bZ;b1=b_;b2=bW;b3=bY;break}bX=gj[bR&4095](bY)|0;bR=c[2415188]|0;b$=bX;b0=bR;b1=c[3528554]|0;b2=c[2433592]|0;b3=bR&65535}else{b$=a[bS+(bZ&255)|0]|0;b0=bZ;b1=b_;b2=bW;b3=bY}}while(0);bY=(b$&255)<<8;b$=b0+1|0;b0=b$&65535;bW=c[b2+(b1*3148|0)+48+((b$>>>8&255)<<2)>>2]|0;do{if((bW|0)==0){b_=c[b2+(b1*3148|0)+3132>>2]|0;if((b_|0)==0){b4=0;b5=b3;break}bZ=gj[b_&4095](b0)|0;b4=bZ;b5=b[4830376]|0}else{b4=a[bW+(b$&255)|0]|0;b5=b3}}while(0);b3=b4&255|bY;c[2426864]=b3;bY=b5+2&65535;b[4830376]=bY;b[4853728]=(b3&65535)+bY&65535;c[2440592]=(c[2440592]|0)-5;return};case 13:{b[4853728]=(b[4830388]|0)+13&65535;c[2440592]=(c[2440592]|0)-1;return};case 23:{b[4853728]=(b[4830388]|0)-9&65535;c[2440592]=(c[2440592]|0)-1;return};case 65:{b[4853728]=(b[4830384]|0)+1&65535;c[2440592]=(c[2440592]|0)-1;return};case 10:{b[4853728]=(b[4830388]|0)+10&65535;c[2440592]=(c[2440592]|0)-1;return};case 6:{b[4853728]=(b[4830388]|0)+6&65535;c[2440592]=(c[2440592]|0)-1;return};case 16:{b[4853728]=(b[4830388]|0)-16&65535;c[2440592]=(c[2440592]|0)-1;return};case 27:{b[4853728]=(b[4830388]|0)-5&65535;c[2440592]=(c[2440592]|0)-1;return};case 28:{b[4853728]=(b[4830388]|0)-4&65535;c[2440592]=(c[2440592]|0)-1;return};case 12:{b[4853728]=(b[4830388]|0)+12&65535;c[2440592]=(c[2440592]|0)-1;return};case 15:{b[4853728]=(b[4830388]|0)+15&65535;c[2440592]=(c[2440592]|0)-1;return};case 14:{b[4853728]=(b[4830388]|0)+14&65535;c[2440592]=(c[2440592]|0)-1;return};case 29:{b[4853728]=(b[4830388]|0)-3&65535;c[2440592]=(c[2440592]|0)-1;return};case 30:{b[4853728]=(b[4830388]|0)-2&65535;c[2440592]=(c[2440592]|0)-1;return};case 31:{b[4853728]=(b[4830388]|0)-1&65535;c[2440592]=(c[2440592]|0)-1;return};case 32:{b[4853728]=b[4830390]|0;c[2440592]=(c[2440592]|0)-1;return};case 33:{b[4853728]=(b[4830390]|0)+1&65535;c[2440592]=(c[2440592]|0)-1;return};case 34:{b[4853728]=(b[4830390]|0)+2&65535;c[2440592]=(c[2440592]|0)-1;return};case 174:{b[4853728]=0;return};case 175:{bY=c[2415188]|0;b3=bY&65535;b5=c[3528554]|0;b4=c[2433592]|0;b$=c[b4+(b5*3148|0)+48+((bY>>>8&255)<<2)>>2]|0;do{if((b$|0)==0){bW=c[b4+(b5*3148|0)+3132>>2]|0;if((bW|0)==0){b6=0;b7=bY;b8=b5;b9=b4;ca=b3;break}b0=gj[bW&4095](b3)|0;bW=c[2415188]|0;b6=b0;b7=bW;b8=c[3528554]|0;b9=c[2433592]|0;ca=bW&65535}else{b6=a[b$+(bY&255)|0]|0;b7=bY;b8=b5;b9=b4;ca=b3}}while(0);b3=(b6&255)<<8;b6=b7+1|0;b7=b6&65535;b4=c[b9+(b8*3148|0)+48+((b6>>>8&255)<<2)>>2]|0;do{if((b4|0)==0){b5=c[b9+(b8*3148|0)+3132>>2]|0;if((b5|0)==0){cb=0;cc=ca;break}bY=gj[b5&4095](b7)|0;cb=bY;cc=b[4830376]|0}else{cb=a[b4+(b6&255)|0]|0;cc=ca}}while(0);c[2426864]=cb&255|b3;b[4830376]=cc+2&65535;c[2440592]=(c[2440592]|0)-5;return};case 176:{cc=b[4830390]|0;b[4853728]=cc;b[4830390]=cc+1&65535;cc=c[2426864]|0;b3=cc&65535;cb=c[3528554]|0;ca=c[2433592]|0;b6=c[ca+(cb*3148|0)+48+((cc>>>8&255)<<2)>>2]|0;do{if((b6|0)==0){b4=c[ca+(cb*3148|0)+3120>>2]|0;if((b4|0)==0){cd=0;ce=cb;cf=ca;break}b7=gj[b4&4095](b3)|0;cd=b7;ce=c[3528554]|0;cf=c[2433592]|0}else{cd=a[b6+(cc&255)|0]|0;ce=cb;cf=ca}}while(0);ca=(cd&255)<<8;cd=cc+1|0;cc=cd&65535;cb=c[cf+(ce*3148|0)+48+((cd>>>8&255)<<2)>>2]|0;do{if((cb|0)==0){b6=c[cf+(ce*3148|0)+3120>>2]|0;if((b6|0)==0){cg=0;break}cg=gj[b6&4095](cc)|0}else{cg=a[cb+(cd&255)|0]|0}}while(0);c[2426864]=cg&255|ca;c[2440592]=(c[2440592]|0)-5;return};case 177:{ca=b[4830390]|0;b[4853728]=ca;b[4830390]=ca+2&65535;ca=c[2426864]|0;cg=ca&65535;cd=c[3528554]|0;cb=c[2433592]|0;cc=c[cb+(cd*3148|0)+48+((ca>>>8&255)<<2)>>2]|0;do{if((cc|0)==0){ce=c[cb+(cd*3148|0)+3120>>2]|0;if((ce|0)==0){ch=0;ci=cd;cj=cb;break}cf=gj[ce&4095](cg)|0;ch=cf;ci=c[3528554]|0;cj=c[2433592]|0}else{ch=a[cc+(ca&255)|0]|0;ci=cd;cj=cb}}while(0);cb=(ch&255)<<8;ch=ca+1|0;ca=ch&65535;cd=c[cj+(ci*3148|0)+48+((ch>>>8&255)<<2)>>2]|0;do{if((cd|0)==0){cc=c[cj+(ci*3148|0)+3120>>2]|0;if((cc|0)==0){ck=0;break}ck=gj[cc&4095](ca)|0}else{ck=a[cd+(ch&255)|0]|0}}while(0);c[2426864]=ck&255|cb;c[2440592]=(c[2440592]|0)-6;return};case 178:{cb=(b[4830390]|0)-1&65535;b[4830390]=cb;b[4853728]=cb;cb=c[2426864]|0;ck=cb&65535;ch=c[3528554]|0;cd=c[2433592]|0;ca=c[cd+(ch*3148|0)+48+((cb>>>8&255)<<2)>>2]|0;do{if((ca|0)==0){ci=c[cd+(ch*3148|0)+3120>>2]|0;if((ci|0)==0){cl=0;cm=ch;cn=cd;break}cj=gj[ci&4095](ck)|0;cl=cj;cm=c[3528554]|0;cn=c[2433592]|0}else{cl=a[ca+(cb&255)|0]|0;cm=ch;cn=cd}}while(0);cd=(cl&255)<<8;cl=cb+1|0;cb=cl&65535;ch=c[cn+(cm*3148|0)+48+((cl>>>8&255)<<2)>>2]|0;do{if((ch|0)==0){ca=c[cn+(cm*3148|0)+3120>>2]|0;if((ca|0)==0){co=0;break}co=gj[ca&4095](cb)|0}else{co=a[ch+(cl&255)|0]|0}}while(0);c[2426864]=co&255|cd;c[2440592]=(c[2440592]|0)-5;return};case 179:{cd=(b[4830390]|0)-2&65535;b[4830390]=cd;b[4853728]=cd;cd=c[2426864]|0;co=cd&65535;cl=c[3528554]|0;ch=c[2433592]|0;cb=c[ch+(cl*3148|0)+48+((cd>>>8&255)<<2)>>2]|0;do{if((cb|0)==0){cm=c[ch+(cl*3148|0)+3120>>2]|0;if((cm|0)==0){cp=0;cq=cl;cr=ch;break}cn=gj[cm&4095](co)|0;cp=cn;cq=c[3528554]|0;cr=c[2433592]|0}else{cp=a[cb+(cd&255)|0]|0;cq=cl;cr=ch}}while(0);ch=(cp&255)<<8;cp=cd+1|0;cd=cp&65535;cl=c[cr+(cq*3148|0)+48+((cp>>>8&255)<<2)>>2]|0;do{if((cl|0)==0){cb=c[cr+(cq*3148|0)+3120>>2]|0;if((cb|0)==0){cs=0;break}cs=gj[cb&4095](cd)|0}else{cs=a[cl+(cp&255)|0]|0}}while(0);c[2426864]=cs&255|ch;c[2440592]=(c[2440592]|0)-6;return};case 180:{b[4853728]=b[4830390]|0;ch=c[2426864]|0;cs=ch&65535;cp=c[3528554]|0;cl=c[2433592]|0;cd=c[cl+(cp*3148|0)+48+((ch>>>8&255)<<2)>>2]|0;do{if((cd|0)==0){cq=c[cl+(cp*3148|0)+3120>>2]|0;if((cq|0)==0){ct=0;cu=cp;cv=cl;break}cr=gj[cq&4095](cs)|0;ct=cr;cu=c[3528554]|0;cv=c[2433592]|0}else{ct=a[cd+(ch&255)|0]|0;cu=cp;cv=cl}}while(0);cl=(ct&255)<<8;ct=ch+1|0;ch=ct&65535;cp=c[cv+(cu*3148|0)+48+((ct>>>8&255)<<2)>>2]|0;do{if((cp|0)==0){cd=c[cv+(cu*3148|0)+3120>>2]|0;if((cd|0)==0){cw=0;break}cw=gj[cd&4095](ch)|0}else{cw=a[cp+(ct&255)|0]|0}}while(0);c[2426864]=cw&255|cl;c[2440592]=(c[2440592]|0)-3;return};case 181:{cl=d[9660760]|0;b[4853728]=((cl&128|0)!=0?cl|65280:cl)+(e[4830390]|0)&65535;cl=c[2426864]|0;cw=cl&65535;ct=c[3528554]|0;cp=c[2433592]|0;ch=c[cp+(ct*3148|0)+48+((cl>>>8&255)<<2)>>2]|0;do{if((ch|0)==0){cu=c[cp+(ct*3148|0)+3120>>2]|0;if((cu|0)==0){cx=0;cy=ct;cz=cp;break}cv=gj[cu&4095](cw)|0;cx=cv;cy=c[3528554]|0;cz=c[2433592]|0}else{cx=a[ch+(cl&255)|0]|0;cy=ct;cz=cp}}while(0);cp=(cx&255)<<8;cx=cl+1|0;cl=cx&65535;ct=c[cz+(cy*3148|0)+48+((cx>>>8&255)<<2)>>2]|0;do{if((ct|0)==0){ch=c[cz+(cy*3148|0)+3120>>2]|0;if((ch|0)==0){cA=0;break}cA=gj[ch&4095](cl)|0}else{cA=a[ct+(cx&255)|0]|0}}while(0);c[2426864]=cA&255|cp;c[2440592]=(c[2440592]|0)-4;return};case 182:{cp=d[9660761]|0;b[4853728]=((cp&128|0)!=0?cp|65280:cp)+(e[4830390]|0)&65535;cp=c[2426864]|0;cA=cp&65535;cx=c[3528554]|0;ct=c[2433592]|0;cl=c[ct+(cx*3148|0)+48+((cp>>>8&255)<<2)>>2]|0;do{if((cl|0)==0){cy=c[ct+(cx*3148|0)+3120>>2]|0;if((cy|0)==0){cB=0;cC=cx;cD=ct;break}cz=gj[cy&4095](cA)|0;cB=cz;cC=c[3528554]|0;cD=c[2433592]|0}else{cB=a[cl+(cp&255)|0]|0;cC=cx;cD=ct}}while(0);ct=(cB&255)<<8;cB=cp+1|0;cp=cB&65535;cx=c[cD+(cC*3148|0)+48+((cB>>>8&255)<<2)>>2]|0;do{if((cx|0)==0){cl=c[cD+(cC*3148|0)+3120>>2]|0;if((cl|0)==0){cE=0;break}cE=gj[cl&4095](cp)|0}else{cE=a[cx+(cB&255)|0]|0}}while(0);c[2426864]=cE&255|ct;c[2440592]=(c[2440592]|0)-4;return};case 183:{b[4853728]=0;return};case 184:{ct=c[2415188]|0;cE=ct&65535;cB=c[3528554]|0;cx=c[2433592]|0;cp=c[cx+(cB*3148|0)+48+((ct>>>8&255)<<2)>>2]|0;do{if((cp|0)==0){cC=c[cx+(cB*3148|0)+3132>>2]|0;if((cC|0)==0){cF=0;cG=cE;cH=cB;cI=cx;break}cD=gj[cC&4095](cE)|0;cF=cD;cG=b[4830376]|0;cH=c[3528554]|0;cI=c[2433592]|0}else{cF=a[cp+(ct&255)|0]|0;cG=cE;cH=cB;cI=cx}}while(0);cx=cF&255;b[4830376]=cG+1&65535;b[4853728]=((cx&128)!=0?cx|-256:cx)+(b[4830390]|0)&65535;cx=c[2426864]|0;cG=cx&65535;cF=c[cI+(cH*3148|0)+48+((cx>>>8&255)<<2)>>2]|0;do{if((cF|0)==0){cB=c[cI+(cH*3148|0)+3120>>2]|0;if((cB|0)==0){cJ=0;cK=cH;cL=cI;break}cE=gj[cB&4095](cG)|0;cJ=cE;cK=c[3528554]|0;cL=c[2433592]|0}else{cJ=a[cF+(cx&255)|0]|0;cK=cH;cL=cI}}while(0);cI=(cJ&255)<<8;cJ=cx+1|0;cx=cJ&65535;cH=c[cL+(cK*3148|0)+48+((cJ>>>8&255)<<2)>>2]|0;do{if((cH|0)==0){cF=c[cL+(cK*3148|0)+3120>>2]|0;if((cF|0)==0){cM=0;break}cM=gj[cF&4095](cx)|0}else{cM=a[cH+(cJ&255)|0]|0}}while(0);c[2426864]=cM&255|cI;c[2440592]=(c[2440592]|0)-4;return};case 185:{cI=c[2415188]|0;cM=cI&65535;cJ=c[3528554]|0;cH=c[2433592]|0;cx=c[cH+(cJ*3148|0)+48+((cI>>>8&255)<<2)>>2]|0;do{if((cx|0)==0){cK=c[cH+(cJ*3148|0)+3132>>2]|0;if((cK|0)==0){cN=0;cO=cI;cP=cJ;cQ=cH;cR=cM;break}cL=gj[cK&4095](cM)|0;cK=c[2415188]|0;cN=cL;cO=cK;cP=c[3528554]|0;cQ=c[2433592]|0;cR=cK&65535}else{cN=a[cx+(cI&255)|0]|0;cO=cI;cP=cJ;cQ=cH;cR=cM}}while(0);cM=(cN&255)<<8;cN=cO+1|0;cO=cN&65535;cH=c[cQ+(cP*3148|0)+48+((cN>>>8&255)<<2)>>2]|0;do{if((cH|0)==0){cJ=c[cQ+(cP*3148|0)+3132>>2]|0;if((cJ|0)==0){cS=0;cT=cR;cU=cP;cV=cQ;break}cI=gj[cJ&4095](cO)|0;cS=cI;cT=b[4830376]|0;cU=c[3528554]|0;cV=c[2433592]|0}else{cS=a[cH+(cN&255)|0]|0;cT=cR;cU=cP;cV=cQ}}while(0);cQ=cS&255|cM;c[2426864]=cQ;b[4830376]=cT+2&65535;b[4853728]=(cQ&65535)+(b[4830390]|0)&65535;cQ=c[2426864]|0;cT=cQ&65535;cM=c[cV+(cU*3148|0)+48+((cQ>>>8&255)<<2)>>2]|0;do{if((cM|0)==0){cS=c[cV+(cU*3148|0)+3120>>2]|0;if((cS|0)==0){cW=0;cX=cU;cY=cV;break}cP=gj[cS&4095](cT)|0;cW=cP;cX=c[3528554]|0;cY=c[2433592]|0}else{cW=a[cM+(cQ&255)|0]|0;cX=cU;cY=cV}}while(0);cV=(cW&255)<<8;cW=cQ+1|0;cQ=cW&65535;cU=c[cY+(cX*3148|0)+48+((cW>>>8&255)<<2)>>2]|0;do{if((cU|0)==0){cM=c[cY+(cX*3148|0)+3120>>2]|0;if((cM|0)==0){cZ=0;break}cZ=gj[cM&4095](cQ)|0}else{cZ=a[cU+(cW&255)|0]|0}}while(0);c[2426864]=cZ&255|cV;c[2440592]=(c[2440592]|0)-7;return};case 186:{b[4853728]=0;return};case 187:{b[4853728]=(b[4830380]|0)+(b[4830390]|0)&65535;cV=c[2426864]|0;cZ=cV&65535;cW=c[3528554]|0;cU=c[2433592]|0;cQ=c[cU+(cW*3148|0)+48+((cV>>>8&255)<<2)>>2]|0;do{if((cQ|0)==0){cX=c[cU+(cW*3148|0)+3120>>2]|0;if((cX|0)==0){c_=0;c$=cW;c0=cU;break}cY=gj[cX&4095](cZ)|0;c_=cY;c$=c[3528554]|0;c0=c[2433592]|0}else{c_=a[cQ+(cV&255)|0]|0;c$=cW;c0=cU}}while(0);cU=(c_&255)<<8;c_=cV+1|0;cV=c_&65535;cW=c[c0+(c$*3148|0)+48+((c_>>>8&255)<<2)>>2]|0;do{if((cW|0)==0){cQ=c[c0+(c$*3148|0)+3120>>2]|0;if((cQ|0)==0){c1=0;break}c1=gj[cQ&4095](cV)|0}else{c1=a[cW+(c_&255)|0]|0}}while(0);c[2426864]=c1&255|cU;c[2440592]=(c[2440592]|0)-7;return};case 188:{cU=c[2415188]|0;c1=cU&65535;c_=c[3528554]|0;cW=c[2433592]|0;cV=c[cW+(c_*3148|0)+48+((cU>>>8&255)<<2)>>2]|0;do{if((cV|0)==0){c$=c[cW+(c_*3148|0)+3132>>2]|0;if((c$|0)==0){c2=0;c3=c1;c4=c_;c5=cW;break}c0=gj[c$&4095](c1)|0;c2=c0;c3=b[4830376]|0;c4=c[3528554]|0;c5=c[2433592]|0}else{c2=a[cV+(cU&255)|0]|0;c3=c1;c4=c_;c5=cW}}while(0);cW=c2&255;c2=c3+1&65535;b[4830376]=c2;b[4853728]=((cW&128)!=0?cW|-256:cW)+c2&65535;c2=c[2426864]|0;cW=c2&65535;c3=c[c5+(c4*3148|0)+48+((c2>>>8&255)<<2)>>2]|0;do{if((c3|0)==0){c_=c[c5+(c4*3148|0)+3120>>2]|0;if((c_|0)==0){c6=0;c7=c4;c8=c5;break}c1=gj[c_&4095](cW)|0;c6=c1;c7=c[3528554]|0;c8=c[2433592]|0}else{c6=a[c3+(c2&255)|0]|0;c7=c4;c8=c5}}while(0);c5=(c6&255)<<8;c6=c2+1|0;c2=c6&65535;c4=c[c8+(c7*3148|0)+48+((c6>>>8&255)<<2)>>2]|0;do{if((c4|0)==0){c3=c[c8+(c7*3148|0)+3120>>2]|0;if((c3|0)==0){c9=0;break}c9=gj[c3&4095](c2)|0}else{c9=a[c4+(c6&255)|0]|0}}while(0);c[2426864]=c9&255|c5;c[2440592]=(c[2440592]|0)-4;return};case 189:{c5=c[2415188]|0;c9=c5&65535;c6=c[3528554]|0;c4=c[2433592]|0;c2=c[c4+(c6*3148|0)+48+((c5>>>8&255)<<2)>>2]|0;do{if((c2|0)==0){c7=c[c4+(c6*3148|0)+3132>>2]|0;if((c7|0)==0){da=0;db=c5;dc=c6;dd=c4;de=c9;break}c8=gj[c7&4095](c9)|0;c7=c[2415188]|0;da=c8;db=c7;dc=c[3528554]|0;dd=c[2433592]|0;de=c7&65535}else{da=a[c2+(c5&255)|0]|0;db=c5;dc=c6;dd=c4;de=c9}}while(0);c9=(da&255)<<8;da=db+1|0;db=da&65535;c4=c[dd+(dc*3148|0)+48+((da>>>8&255)<<2)>>2]|0;do{if((c4|0)==0){c6=c[dd+(dc*3148|0)+3132>>2]|0;if((c6|0)==0){df=0;dg=de;dh=dc;di=dd;break}c5=gj[c6&4095](db)|0;df=c5;dg=b[4830376]|0;dh=c[3528554]|0;di=c[2433592]|0}else{df=a[c4+(da&255)|0]|0;dg=de;dh=dc;di=dd}}while(0);dd=df&255|c9;c[2426864]=dd;c9=dg+2&65535;b[4830376]=c9;b[4853728]=(dd&65535)+c9&65535;c9=c[2426864]|0;dd=c9&65535;dg=c[di+(dh*3148|0)+48+((c9>>>8&255)<<2)>>2]|0;do{if((dg|0)==0){df=c[di+(dh*3148|0)+3120>>2]|0;if((df|0)==0){dj=0;dk=dh;dl=di;break}dc=gj[df&4095](dd)|0;dj=dc;dk=c[3528554]|0;dl=c[2433592]|0}else{dj=a[dg+(c9&255)|0]|0;dk=dh;dl=di}}while(0);di=(dj&255)<<8;dj=c9+1|0;c9=dj&65535;dh=c[dl+(dk*3148|0)+48+((dj>>>8&255)<<2)>>2]|0;do{if((dh|0)==0){dg=c[dl+(dk*3148|0)+3120>>2]|0;if((dg|0)==0){dm=0;break}dm=gj[dg&4095](c9)|0}else{dm=a[dh+(dj&255)|0]|0}}while(0);c[2426864]=dm&255|di;c[2440592]=(c[2440592]|0)-8;return};case 190:{b[4853728]=0;return};case 191:{di=c[2415188]|0;dm=di&65535;dj=c[3528554]|0;dh=c[2433592]|0;c9=c[dh+(dj*3148|0)+48+((di>>>8&255)<<2)>>2]|0;do{if((c9|0)==0){dk=c[dh+(dj*3148|0)+3132>>2]|0;if((dk|0)==0){dn=0;dp=di;dq=dj;dr=dh;ds=dm;break}dl=gj[dk&4095](dm)|0;dk=c[2415188]|0;dn=dl;dp=dk;dq=c[3528554]|0;dr=c[2433592]|0;ds=dk&65535}else{dn=a[c9+(di&255)|0]|0;dp=di;dq=dj;dr=dh;ds=dm}}while(0);dm=dn&255;dn=dm<<8;dh=dp+1|0;dp=dh&65535;dj=c[dr+(dq*3148|0)+48+((dh>>>8&255)<<2)>>2]|0;do{if((dj|0)==0){di=c[dr+(dq*3148|0)+3132>>2]|0;if((di|0)==0){dt=0;du=ds;dv=dq;dw=dr;break}c9=gj[di&4095](dp)|0;dt=c9;du=b[4830376]|0;dv=c[3528554]|0;dw=c[2433592]|0}else{dt=a[dj+(dh&255)|0]|0;du=ds;dv=dq;dw=dr}}while(0);dr=dt&255;dt=dr|dn;c[2426864]=dt;b[4830376]=du+2&65535;du=dt&65535;dn=c[dw+(dv*3148|0)+48+(dm<<2)>>2]|0;do{if((dn|0)==0){dm=c[dw+(dv*3148|0)+3120>>2]|0;if((dm|0)==0){dx=0;dy=dv;dz=dw;break}dq=gj[dm&4095](du)|0;dx=dq;dy=c[3528554]|0;dz=c[2433592]|0}else{dx=a[dn+dr|0]|0;dy=dv;dz=dw}}while(0);dw=(dx&255)<<8;dx=dt+1|0;dt=dx&65535;dv=c[dz+(dy*3148|0)+48+((dx>>>8&255)<<2)>>2]|0;do{if((dv|0)==0){dr=c[dz+(dy*3148|0)+3120>>2]|0;if((dr|0)==0){dA=0;break}dA=gj[dr&4095](dt)|0}else{dA=a[dv+(dx&255)|0]|0}}while(0);c[2426864]=dA&255|dw;c[2440592]=(c[2440592]|0)-8;return};case 192:{dw=b[4830384]|0;b[4853728]=dw;b[4830384]=dw+1&65535;c[2440592]=(c[2440592]|0)-2;return};case 193:{dw=b[4830384]|0;b[4853728]=dw;b[4830384]=dw+2&65535;c[2440592]=(c[2440592]|0)-3;return};case 194:{dw=(b[4830384]|0)-1&65535;b[4830384]=dw;b[4853728]=dw;c[2440592]=(c[2440592]|0)-2;return};case 195:{dw=(b[4830384]|0)-2&65535;b[4830384]=dw;b[4853728]=dw;c[2440592]=(c[2440592]|0)-3;return};case 196:{b[4853728]=b[4830384]|0;return};case 197:{dw=d[9660760]|0;b[4853728]=((dw&128|0)!=0?dw|65280:dw)+(e[4830384]|0)&65535;c[2440592]=(c[2440592]|0)-1;return};case 198:{dw=d[9660761]|0;b[4853728]=((dw&128|0)!=0?dw|65280:dw)+(e[4830384]|0)&65535;c[2440592]=(c[2440592]|0)-1;return};case 199:{b[4853728]=0;return};case 200:{dw=c[2415188]|0;dA=dw&65535;dx=c[3528554]|0;dv=c[2433592]|0;dt=c[dv+(dx*3148|0)+48+((dw>>>8&255)<<2)>>2]|0;do{if((dt|0)==0){dy=c[dv+(dx*3148|0)+3132>>2]|0;if((dy|0)==0){dB=0;dC=dA;break}dz=gj[dy&4095](dA)|0;dB=dz;dC=b[4830376]|0}else{dB=a[dt+(dw&255)|0]|0;dC=dA}}while(0);dA=dB&255;b[4830376]=dC+1&65535;b[4853728]=((dA&128)!=0?dA|-256:dA)+(b[4830384]|0)&65535;c[2440592]=(c[2440592]|0)-1;return};case 201:{dA=c[2415188]|0;dC=dA&65535;dB=c[3528554]|0;dw=c[2433592]|0;dt=c[dw+(dB*3148|0)+48+((dA>>>8&255)<<2)>>2]|0;do{if((dt|0)==0){dx=c[dw+(dB*3148|0)+3132>>2]|0;if((dx|0)==0){dD=0;dE=dA;dF=dB;dG=dw;dH=dC;break}dv=gj[dx&4095](dC)|0;dx=c[2415188]|0;dD=dv;dE=dx;dF=c[3528554]|0;dG=c[2433592]|0;dH=dx&65535}else{dD=a[dt+(dA&255)|0]|0;dE=dA;dF=dB;dG=dw;dH=dC}}while(0);dC=(dD&255)<<8;dD=dE+1|0;dE=dD&65535;dw=c[dG+(dF*3148|0)+48+((dD>>>8&255)<<2)>>2]|0;do{if((dw|0)==0){dB=c[dG+(dF*3148|0)+3132>>2]|0;if((dB|0)==0){dI=0;dJ=dH;break}dA=gj[dB&4095](dE)|0;dI=dA;dJ=b[4830376]|0}else{dI=a[dw+(dD&255)|0]|0;dJ=dH}}while(0);dH=dI&255|dC;c[2426864]=dH;b[4830376]=dJ+2&65535;b[4853728]=(dH&65535)+(b[4830384]|0)&65535;c[2440592]=(c[2440592]|0)-4;return};case 202:{b[4853728]=0;return};case 203:{b[4853728]=(b[4830380]|0)+(b[4830384]|0)&65535;c[2440592]=(c[2440592]|0)-4;return};case 204:{dH=c[2415188]|0;dJ=dH&65535;dC=c[3528554]|0;dI=c[2433592]|0;dD=c[dI+(dC*3148|0)+48+((dH>>>8&255)<<2)>>2]|0;do{if((dD|0)==0){dw=c[dI+(dC*3148|0)+3132>>2]|0;if((dw|0)==0){dK=0;dL=dJ;break}dE=gj[dw&4095](dJ)|0;dK=dE;dL=b[4830376]|0}else{dK=a[dD+(dH&255)|0]|0;dL=dJ}}while(0);dJ=dK&255;dK=dL+1&65535;b[4830376]=dK;b[4853728]=((dJ&128)!=0?dJ|-256:dJ)+dK&65535;c[2440592]=(c[2440592]|0)-1;return};case 205:{dK=c[2415188]|0;dJ=dK&65535;dL=c[3528554]|0;dH=c[2433592]|0;dD=c[dH+(dL*3148|0)+48+((dK>>>8&255)<<2)>>2]|0;do{if((dD|0)==0){dC=c[dH+(dL*3148|0)+3132>>2]|0;if((dC|0)==0){dM=0;dN=dK;dO=dL;dP=dH;dQ=dJ;break}dI=gj[dC&4095](dJ)|0;dC=c[2415188]|0;dM=dI;dN=dC;dO=c[3528554]|0;dP=c[2433592]|0;dQ=dC&65535}else{dM=a[dD+(dK&255)|0]|0;dN=dK;dO=dL;dP=dH;dQ=dJ}}while(0);dJ=(dM&255)<<8;dM=dN+1|0;dN=dM&65535;dH=c[dP+(dO*3148|0)+48+((dM>>>8&255)<<2)>>2]|0;do{if((dH|0)==0){dL=c[dP+(dO*3148|0)+3132>>2]|0;if((dL|0)==0){dR=0;dS=dQ;break}dK=gj[dL&4095](dN)|0;dR=dK;dS=b[4830376]|0}else{dR=a[dH+(dM&255)|0]|0;dS=dQ}}while(0);dQ=dR&255|dJ;c[2426864]=dQ;dJ=dS+2&65535;b[4830376]=dJ;b[4853728]=(dQ&65535)+dJ&65535;c[2440592]=(c[2440592]|0)-5;return};case 206:{b[4853728]=0;return};case 207:{dJ=c[2415188]|0;dQ=dJ&65535;dS=c[3528554]|0;dR=c[2433592]|0;dM=c[dR+(dS*3148|0)+48+((dJ>>>8&255)<<2)>>2]|0;do{if((dM|0)==0){dH=c[dR+(dS*3148|0)+3132>>2]|0;if((dH|0)==0){dT=0;dU=dJ;dV=dS;dW=dR;dX=dQ;break}dN=gj[dH&4095](dQ)|0;dH=c[2415188]|0;dT=dN;dU=dH;dV=c[3528554]|0;dW=c[2433592]|0;dX=dH&65535}else{dT=a[dM+(dJ&255)|0]|0;dU=dJ;dV=dS;dW=dR;dX=dQ}}while(0);dQ=(dT&255)<<8;dT=dU+1|0;dU=dT&65535;dR=c[dW+(dV*3148|0)+48+((dT>>>8&255)<<2)>>2]|0;do{if((dR|0)==0){dS=c[dW+(dV*3148|0)+3132>>2]|0;if((dS|0)==0){dY=0;dZ=dX;break}dJ=gj[dS&4095](dU)|0;dY=dJ;dZ=b[4830376]|0}else{dY=a[dR+(dT&255)|0]|0;dZ=dX}}while(0);c[2426864]=dY&255|dQ;b[4830376]=dZ+2&65535;c[2440592]=(c[2440592]|0)-5;return};case 208:{dZ=b[4830384]|0;b[4853728]=dZ;b[4830384]=dZ+1&65535;dZ=c[2426864]|0;dQ=dZ&65535;dY=c[3528554]|0;dX=c[2433592]|0;dT=c[dX+(dY*3148|0)+48+((dZ>>>8&255)<<2)>>2]|0;do{if((dT|0)==0){dR=c[dX+(dY*3148|0)+3120>>2]|0;if((dR|0)==0){d_=0;d$=dY;d0=dX;break}dU=gj[dR&4095](dQ)|0;d_=dU;d$=c[3528554]|0;d0=c[2433592]|0}else{d_=a[dT+(dZ&255)|0]|0;d$=dY;d0=dX}}while(0);dX=(d_&255)<<8;d_=dZ+1|0;dZ=d_&65535;dY=c[d0+(d$*3148|0)+48+((d_>>>8&255)<<2)>>2]|0;do{if((dY|0)==0){dT=c[d0+(d$*3148|0)+3120>>2]|0;if((dT|0)==0){d1=0;break}d1=gj[dT&4095](dZ)|0}else{d1=a[dY+(d_&255)|0]|0}}while(0);c[2426864]=d1&255|dX;c[2440592]=(c[2440592]|0)-5;return};case 209:{dX=b[4830384]|0;b[4853728]=dX;b[4830384]=dX+2&65535;dX=c[2426864]|0;d1=dX&65535;d_=c[3528554]|0;dY=c[2433592]|0;dZ=c[dY+(d_*3148|0)+48+((dX>>>8&255)<<2)>>2]|0;do{if((dZ|0)==0){d$=c[dY+(d_*3148|0)+3120>>2]|0;if((d$|0)==0){d2=0;d3=d_;d4=dY;break}d0=gj[d$&4095](d1)|0;d2=d0;d3=c[3528554]|0;d4=c[2433592]|0}else{d2=a[dZ+(dX&255)|0]|0;d3=d_;d4=dY}}while(0);dY=(d2&255)<<8;d2=dX+1|0;dX=d2&65535;d_=c[d4+(d3*3148|0)+48+((d2>>>8&255)<<2)>>2]|0;do{if((d_|0)==0){dZ=c[d4+(d3*3148|0)+3120>>2]|0;if((dZ|0)==0){d5=0;break}d5=gj[dZ&4095](dX)|0}else{d5=a[d_+(d2&255)|0]|0}}while(0);c[2426864]=d5&255|dY;c[2440592]=(c[2440592]|0)-6;return};case 210:{dY=(b[4830384]|0)-1&65535;b[4830384]=dY;b[4853728]=dY;dY=c[2426864]|0;d5=dY&65535;d2=c[3528554]|0;d_=c[2433592]|0;dX=c[d_+(d2*3148|0)+48+((dY>>>8&255)<<2)>>2]|0;do{if((dX|0)==0){d3=c[d_+(d2*3148|0)+3120>>2]|0;if((d3|0)==0){d6=0;d7=d2;d8=d_;break}d4=gj[d3&4095](d5)|0;d6=d4;d7=c[3528554]|0;d8=c[2433592]|0}else{d6=a[dX+(dY&255)|0]|0;d7=d2;d8=d_}}while(0);d_=(d6&255)<<8;d6=dY+1|0;dY=d6&65535;d2=c[d8+(d7*3148|0)+48+((d6>>>8&255)<<2)>>2]|0;do{if((d2|0)==0){dX=c[d8+(d7*3148|0)+3120>>2]|0;if((dX|0)==0){d9=0;break}d9=gj[dX&4095](dY)|0}else{d9=a[d2+(d6&255)|0]|0}}while(0);c[2426864]=d9&255|d_;c[2440592]=(c[2440592]|0)-5;return};case 211:{d_=(b[4830384]|0)-2&65535;b[4830384]=d_;b[4853728]=d_;d_=c[2426864]|0;d9=d_&65535;d6=c[3528554]|0;d2=c[2433592]|0;dY=c[d2+(d6*3148|0)+48+((d_>>>8&255)<<2)>>2]|0;do{if((dY|0)==0){d7=c[d2+(d6*3148|0)+3120>>2]|0;if((d7|0)==0){ea=0;eb=d6;ec=d2;break}d8=gj[d7&4095](d9)|0;ea=d8;eb=c[3528554]|0;ec=c[2433592]|0}else{ea=a[dY+(d_&255)|0]|0;eb=d6;ec=d2}}while(0);d2=(ea&255)<<8;ea=d_+1|0;d_=ea&65535;d6=c[ec+(eb*3148|0)+48+((ea>>>8&255)<<2)>>2]|0;do{if((d6|0)==0){dY=c[ec+(eb*3148|0)+3120>>2]|0;if((dY|0)==0){ed=0;break}ed=gj[dY&4095](d_)|0}else{ed=a[d6+(ea&255)|0]|0}}while(0);c[2426864]=ed&255|d2;c[2440592]=(c[2440592]|0)-6;return};case 212:{b[4853728]=b[4830384]|0;d2=c[2426864]|0;ed=d2&65535;ea=c[3528554]|0;d6=c[2433592]|0;d_=c[d6+(ea*3148|0)+48+((d2>>>8&255)<<2)>>2]|0;do{if((d_|0)==0){eb=c[d6+(ea*3148|0)+3120>>2]|0;if((eb|0)==0){ee=0;ef=ea;eg=d6;break}ec=gj[eb&4095](ed)|0;ee=ec;ef=c[3528554]|0;eg=c[2433592]|0}else{ee=a[d_+(d2&255)|0]|0;ef=ea;eg=d6}}while(0);d6=(ee&255)<<8;ee=d2+1|0;d2=ee&65535;ea=c[eg+(ef*3148|0)+48+((ee>>>8&255)<<2)>>2]|0;do{if((ea|0)==0){d_=c[eg+(ef*3148|0)+3120>>2]|0;if((d_|0)==0){eh=0;break}eh=gj[d_&4095](d2)|0}else{eh=a[ea+(ee&255)|0]|0}}while(0);c[2426864]=eh&255|d6;c[2440592]=(c[2440592]|0)-3;return};case 213:{d6=d[9660760]|0;b[4853728]=((d6&128|0)!=0?d6|65280:d6)+(e[4830384]|0)&65535;d6=c[2426864]|0;eh=d6&65535;ee=c[3528554]|0;ea=c[2433592]|0;d2=c[ea+(ee*3148|0)+48+((d6>>>8&255)<<2)>>2]|0;do{if((d2|0)==0){ef=c[ea+(ee*3148|0)+3120>>2]|0;if((ef|0)==0){ei=0;ej=ee;ek=ea;break}eg=gj[ef&4095](eh)|0;ei=eg;ej=c[3528554]|0;ek=c[2433592]|0}else{ei=a[d2+(d6&255)|0]|0;ej=ee;ek=ea}}while(0);ea=(ei&255)<<8;ei=d6+1|0;d6=ei&65535;ee=c[ek+(ej*3148|0)+48+((ei>>>8&255)<<2)>>2]|0;do{if((ee|0)==0){d2=c[ek+(ej*3148|0)+3120>>2]|0;if((d2|0)==0){el=0;break}el=gj[d2&4095](d6)|0}else{el=a[ee+(ei&255)|0]|0}}while(0);c[2426864]=el&255|ea;c[2440592]=(c[2440592]|0)-4;return};case 214:{ea=d[9660761]|0;b[4853728]=((ea&128|0)!=0?ea|65280:ea)+(e[4830384]|0)&65535;ea=c[2426864]|0;el=ea&65535;ei=c[3528554]|0;ee=c[2433592]|0;d6=c[ee+(ei*3148|0)+48+((ea>>>8&255)<<2)>>2]|0;do{if((d6|0)==0){ej=c[ee+(ei*3148|0)+3120>>2]|0;if((ej|0)==0){em=0;en=ei;eo=ee;break}ek=gj[ej&4095](el)|0;em=ek;en=c[3528554]|0;eo=c[2433592]|0}else{em=a[d6+(ea&255)|0]|0;en=ei;eo=ee}}while(0);ee=(em&255)<<8;em=ea+1|0;ea=em&65535;ei=c[eo+(en*3148|0)+48+((em>>>8&255)<<2)>>2]|0;do{if((ei|0)==0){d6=c[eo+(en*3148|0)+3120>>2]|0;if((d6|0)==0){ep=0;break}ep=gj[d6&4095](ea)|0}else{ep=a[ei+(em&255)|0]|0}}while(0);c[2426864]=ep&255|ee;c[2440592]=(c[2440592]|0)-4;return};case 215:{b[4853728]=0;return};case 216:{ee=c[2415188]|0;ep=ee&65535;em=c[3528554]|0;ei=c[2433592]|0;ea=c[ei+(em*3148|0)+48+((ee>>>8&255)<<2)>>2]|0;do{if((ea|0)==0){en=c[ei+(em*3148|0)+3132>>2]|0;if((en|0)==0){eq=0;er=ep;es=em;et=ei;break}eo=gj[en&4095](ep)|0;eq=eo;er=b[4830376]|0;es=c[3528554]|0;et=c[2433592]|0}else{eq=a[ea+(ee&255)|0]|0;er=ep;es=em;et=ei}}while(0);ei=eq&255;b[4830376]=er+1&65535;b[4853728]=((ei&128)!=0?ei|-256:ei)+(b[4830384]|0)&65535;ei=c[2426864]|0;er=ei&65535;eq=c[et+(es*3148|0)+48+((ei>>>8&255)<<2)>>2]|0;do{if((eq|0)==0){em=c[et+(es*3148|0)+3120>>2]|0;if((em|0)==0){eu=0;ev=es;ew=et;break}ep=gj[em&4095](er)|0;eu=ep;ev=c[3528554]|0;ew=c[2433592]|0}else{eu=a[eq+(ei&255)|0]|0;ev=es;ew=et}}while(0);et=(eu&255)<<8;eu=ei+1|0;ei=eu&65535;es=c[ew+(ev*3148|0)+48+((eu>>>8&255)<<2)>>2]|0;do{if((es|0)==0){eq=c[ew+(ev*3148|0)+3120>>2]|0;if((eq|0)==0){ex=0;break}ex=gj[eq&4095](ei)|0}else{ex=a[es+(eu&255)|0]|0}}while(0);c[2426864]=ex&255|et;c[2440592]=(c[2440592]|0)-4;return};case 217:{et=c[2415188]|0;ex=et&65535;eu=c[3528554]|0;es=c[2433592]|0;ei=c[es+(eu*3148|0)+48+((et>>>8&255)<<2)>>2]|0;do{if((ei|0)==0){ev=c[es+(eu*3148|0)+3132>>2]|0;if((ev|0)==0){ey=0;ez=et;eA=eu;eB=es;eC=ex;break}ew=gj[ev&4095](ex)|0;ev=c[2415188]|0;ey=ew;ez=ev;eA=c[3528554]|0;eB=c[2433592]|0;eC=ev&65535}else{ey=a[ei+(et&255)|0]|0;ez=et;eA=eu;eB=es;eC=ex}}while(0);ex=(ey&255)<<8;ey=ez+1|0;ez=ey&65535;es=c[eB+(eA*3148|0)+48+((ey>>>8&255)<<2)>>2]|0;do{if((es|0)==0){eu=c[eB+(eA*3148|0)+3132>>2]|0;if((eu|0)==0){eD=0;eE=eC;eF=eA;eG=eB;break}et=gj[eu&4095](ez)|0;eD=et;eE=b[4830376]|0;eF=c[3528554]|0;eG=c[2433592]|0}else{eD=a[es+(ey&255)|0]|0;eE=eC;eF=eA;eG=eB}}while(0);eB=eD&255|ex;c[2426864]=eB;b[4830376]=eE+2&65535;b[4853728]=(eB&65535)+(b[4830384]|0)&65535;eB=c[2426864]|0;eE=eB&65535;ex=c[eG+(eF*3148|0)+48+((eB>>>8&255)<<2)>>2]|0;do{if((ex|0)==0){eD=c[eG+(eF*3148|0)+3120>>2]|0;if((eD|0)==0){eH=0;eI=eF;eJ=eG;break}eA=gj[eD&4095](eE)|0;eH=eA;eI=c[3528554]|0;eJ=c[2433592]|0}else{eH=a[ex+(eB&255)|0]|0;eI=eF;eJ=eG}}while(0);eG=(eH&255)<<8;eH=eB+1|0;eB=eH&65535;eF=c[eJ+(eI*3148|0)+48+((eH>>>8&255)<<2)>>2]|0;do{if((eF|0)==0){ex=c[eJ+(eI*3148|0)+3120>>2]|0;if((ex|0)==0){eK=0;break}eK=gj[ex&4095](eB)|0}else{eK=a[eF+(eH&255)|0]|0}}while(0);c[2426864]=eK&255|eG;c[2440592]=(c[2440592]|0)-7;return};case 218:{b[4853728]=0;return};case 219:{b[4853728]=(b[4830380]|0)+(b[4830384]|0)&65535;eG=c[2426864]|0;eK=eG&65535;eH=c[3528554]|0;eF=c[2433592]|0;eB=c[eF+(eH*3148|0)+48+((eG>>>8&255)<<2)>>2]|0;do{if((eB|0)==0){eI=c[eF+(eH*3148|0)+3120>>2]|0;if((eI|0)==0){eL=0;eM=eH;eN=eF;break}eJ=gj[eI&4095](eK)|0;eL=eJ;eM=c[3528554]|0;eN=c[2433592]|0}else{eL=a[eB+(eG&255)|0]|0;eM=eH;eN=eF}}while(0);eF=(eL&255)<<8;eL=eG+1|0;eG=eL&65535;eH=c[eN+(eM*3148|0)+48+((eL>>>8&255)<<2)>>2]|0;do{if((eH|0)==0){eB=c[eN+(eM*3148|0)+3120>>2]|0;if((eB|0)==0){eO=0;break}eO=gj[eB&4095](eG)|0}else{eO=a[eH+(eL&255)|0]|0}}while(0);c[2426864]=eO&255|eF;c[2440592]=(c[2440592]|0)-7;return};case 154:{b[4853728]=0;return};case 155:{b[4853728]=(b[4830380]|0)+(b[4830388]|0)&65535;eF=c[2426864]|0;eO=eF&65535;eL=c[3528554]|0;eH=c[2433592]|0;eG=c[eH+(eL*3148|0)+48+((eF>>>8&255)<<2)>>2]|0;do{if((eG|0)==0){eM=c[eH+(eL*3148|0)+3120>>2]|0;if((eM|0)==0){eP=0;eQ=eL;eR=eH;break}eN=gj[eM&4095](eO)|0;eP=eN;eQ=c[3528554]|0;eR=c[2433592]|0}else{eP=a[eG+(eF&255)|0]|0;eQ=eL;eR=eH}}while(0);eH=(eP&255)<<8;eP=eF+1|0;eF=eP&65535;eL=c[eR+(eQ*3148|0)+48+((eP>>>8&255)<<2)>>2]|0;do{if((eL|0)==0){eG=c[eR+(eQ*3148|0)+3120>>2]|0;if((eG|0)==0){eS=0;break}eS=gj[eG&4095](eF)|0}else{eS=a[eL+(eP&255)|0]|0}}while(0);c[2426864]=eS&255|eH;c[2440592]=(c[2440592]|0)-7;return};case 156:{eH=c[2415188]|0;eS=eH&65535;eP=c[3528554]|0;eL=c[2433592]|0;eF=c[eL+(eP*3148|0)+48+((eH>>>8&255)<<2)>>2]|0;do{if((eF|0)==0){eQ=c[eL+(eP*3148|0)+3132>>2]|0;if((eQ|0)==0){eT=0;eU=eS;eV=eP;eW=eL;break}eR=gj[eQ&4095](eS)|0;eT=eR;eU=b[4830376]|0;eV=c[3528554]|0;eW=c[2433592]|0}else{eT=a[eF+(eH&255)|0]|0;eU=eS;eV=eP;eW=eL}}while(0);eL=eT&255;eT=eU+1&65535;b[4830376]=eT;b[4853728]=((eL&128)!=0?eL|-256:eL)+eT&65535;eT=c[2426864]|0;eL=eT&65535;eU=c[eW+(eV*3148|0)+48+((eT>>>8&255)<<2)>>2]|0;do{if((eU|0)==0){eP=c[eW+(eV*3148|0)+3120>>2]|0;if((eP|0)==0){eX=0;eY=eV;eZ=eW;break}eS=gj[eP&4095](eL)|0;eX=eS;eY=c[3528554]|0;eZ=c[2433592]|0}else{eX=a[eU+(eT&255)|0]|0;eY=eV;eZ=eW}}while(0);eW=(eX&255)<<8;eX=eT+1|0;eT=eX&65535;eV=c[eZ+(eY*3148|0)+48+((eX>>>8&255)<<2)>>2]|0;do{if((eV|0)==0){eU=c[eZ+(eY*3148|0)+3120>>2]|0;if((eU|0)==0){e_=0;break}e_=gj[eU&4095](eT)|0}else{e_=a[eV+(eX&255)|0]|0}}while(0);c[2426864]=e_&255|eW;c[2440592]=(c[2440592]|0)-4;return};case 157:{eW=c[2415188]|0;e_=eW&65535;eX=c[3528554]|0;eV=c[2433592]|0;eT=c[eV+(eX*3148|0)+48+((eW>>>8&255)<<2)>>2]|0;do{if((eT|0)==0){eY=c[eV+(eX*3148|0)+3132>>2]|0;if((eY|0)==0){e$=0;e0=eW;e1=eX;e2=eV;e3=e_;break}eZ=gj[eY&4095](e_)|0;eY=c[2415188]|0;e$=eZ;e0=eY;e1=c[3528554]|0;e2=c[2433592]|0;e3=eY&65535}else{e$=a[eT+(eW&255)|0]|0;e0=eW;e1=eX;e2=eV;e3=e_}}while(0);e_=(e$&255)<<8;e$=e0+1|0;e0=e$&65535;eV=c[e2+(e1*3148|0)+48+((e$>>>8&255)<<2)>>2]|0;do{if((eV|0)==0){eX=c[e2+(e1*3148|0)+3132>>2]|0;if((eX|0)==0){e4=0;e5=e3;e6=e1;e7=e2;break}eW=gj[eX&4095](e0)|0;e4=eW;e5=b[4830376]|0;e6=c[3528554]|0;e7=c[2433592]|0}else{e4=a[eV+(e$&255)|0]|0;e5=e3;e6=e1;e7=e2}}while(0);e2=e4&255|e_;c[2426864]=e2;e_=e5+2&65535;b[4830376]=e_;b[4853728]=(e2&65535)+e_&65535;e_=c[2426864]|0;e2=e_&65535;e5=c[e7+(e6*3148|0)+48+((e_>>>8&255)<<2)>>2]|0;do{if((e5|0)==0){e4=c[e7+(e6*3148|0)+3120>>2]|0;if((e4|0)==0){e8=0;e9=e6;fa=e7;break}e1=gj[e4&4095](e2)|0;e8=e1;e9=c[3528554]|0;fa=c[2433592]|0}else{e8=a[e5+(e_&255)|0]|0;e9=e6;fa=e7}}while(0);e7=(e8&255)<<8;e8=e_+1|0;e_=e8&65535;e6=c[fa+(e9*3148|0)+48+((e8>>>8&255)<<2)>>2]|0;do{if((e6|0)==0){e5=c[fa+(e9*3148|0)+3120>>2]|0;if((e5|0)==0){fb=0;break}fb=gj[e5&4095](e_)|0}else{fb=a[e6+(e8&255)|0]|0}}while(0);c[2426864]=fb&255|e7;c[2440592]=(c[2440592]|0)-8;return};case 158:{b[4853728]=0;return};case 159:{e7=c[2415188]|0;fb=e7&65535;e8=c[3528554]|0;e6=c[2433592]|0;e_=c[e6+(e8*3148|0)+48+((e7>>>8&255)<<2)>>2]|0;do{if((e_|0)==0){e9=c[e6+(e8*3148|0)+3132>>2]|0;if((e9|0)==0){fc=0;fd=e7;fe=e8;ff=e6;fg=fb;break}fa=gj[e9&4095](fb)|0;e9=c[2415188]|0;fc=fa;fd=e9;fe=c[3528554]|0;ff=c[2433592]|0;fg=e9&65535}else{fc=a[e_+(e7&255)|0]|0;fd=e7;fe=e8;ff=e6;fg=fb}}while(0);fb=fc&255;fc=fb<<8;e6=fd+1|0;fd=e6&65535;e8=c[ff+(fe*3148|0)+48+((e6>>>8&255)<<2)>>2]|0;do{if((e8|0)==0){e7=c[ff+(fe*3148|0)+3132>>2]|0;if((e7|0)==0){fh=0;fi=fg;fj=fe;fk=ff;break}e_=gj[e7&4095](fd)|0;fh=e_;fi=b[4830376]|0;fj=c[3528554]|0;fk=c[2433592]|0}else{fh=a[e8+(e6&255)|0]|0;fi=fg;fj=fe;fk=ff}}while(0);ff=fh&255;fh=ff|fc;c[2426864]=fh;b[4830376]=fi+2&65535;fi=fh&65535;fc=c[fk+(fj*3148|0)+48+(fb<<2)>>2]|0;do{if((fc|0)==0){fb=c[fk+(fj*3148|0)+3120>>2]|0;if((fb|0)==0){fl=0;fm=fj;fn=fk;break}fe=gj[fb&4095](fi)|0;fl=fe;fm=c[3528554]|0;fn=c[2433592]|0}else{fl=a[fc+ff|0]|0;fm=fj;fn=fk}}while(0);fk=(fl&255)<<8;fl=fh+1|0;fh=fl&65535;fj=c[fn+(fm*3148|0)+48+((fl>>>8&255)<<2)>>2]|0;do{if((fj|0)==0){ff=c[fn+(fm*3148|0)+3120>>2]|0;if((ff|0)==0){fo=0;break}fo=gj[ff&4095](fh)|0}else{fo=a[fj+(fl&255)|0]|0}}while(0);c[2426864]=fo&255|fk;c[2440592]=(c[2440592]|0)-8;return};case 160:{fk=b[4830390]|0;b[4853728]=fk;b[4830390]=fk+1&65535;c[2440592]=(c[2440592]|0)-2;return};case 161:{fk=b[4830390]|0;b[4853728]=fk;b[4830390]=fk+2&65535;c[2440592]=(c[2440592]|0)-3;return};case 162:{fk=(b[4830390]|0)-1&65535;b[4830390]=fk;b[4853728]=fk;c[2440592]=(c[2440592]|0)-2;return};case 163:{fk=(b[4830390]|0)-2&65535;b[4830390]=fk;b[4853728]=fk;c[2440592]=(c[2440592]|0)-3;return};case 164:{b[4853728]=b[4830390]|0;return};case 165:{fk=d[9660760]|0;b[4853728]=((fk&128|0)!=0?fk|65280:fk)+(e[4830390]|0)&65535;c[2440592]=(c[2440592]|0)-1;return};case 166:{fk=d[9660761]|0;b[4853728]=((fk&128|0)!=0?fk|65280:fk)+(e[4830390]|0)&65535;c[2440592]=(c[2440592]|0)-1;return};case 167:{b[4853728]=0;return};case 168:{fk=c[2415188]|0;fo=fk&65535;fl=c[3528554]|0;fj=c[2433592]|0;fh=c[fj+(fl*3148|0)+48+((fk>>>8&255)<<2)>>2]|0;do{if((fh|0)==0){fm=c[fj+(fl*3148|0)+3132>>2]|0;if((fm|0)==0){fp=0;fq=fo;break}fn=gj[fm&4095](fo)|0;fp=fn;fq=b[4830376]|0}else{fp=a[fh+(fk&255)|0]|0;fq=fo}}while(0);fo=fp&255;b[4830376]=fq+1&65535;b[4853728]=((fo&128)!=0?fo|-256:fo)+(b[4830390]|0)&65535;c[2440592]=(c[2440592]|0)-1;return};case 169:{fo=c[2415188]|0;fq=fo&65535;fp=c[3528554]|0;fk=c[2433592]|0;fh=c[fk+(fp*3148|0)+48+((fo>>>8&255)<<2)>>2]|0;do{if((fh|0)==0){fl=c[fk+(fp*3148|0)+3132>>2]|0;if((fl|0)==0){fr=0;fs=fo;ft=fp;fu=fk;fv=fq;break}fj=gj[fl&4095](fq)|0;fl=c[2415188]|0;fr=fj;fs=fl;ft=c[3528554]|0;fu=c[2433592]|0;fv=fl&65535}else{fr=a[fh+(fo&255)|0]|0;fs=fo;ft=fp;fu=fk;fv=fq}}while(0);fq=(fr&255)<<8;fr=fs+1|0;fs=fr&65535;fk=c[fu+(ft*3148|0)+48+((fr>>>8&255)<<2)>>2]|0;do{if((fk|0)==0){fp=c[fu+(ft*3148|0)+3132>>2]|0;if((fp|0)==0){fw=0;fx=fv;break}fo=gj[fp&4095](fs)|0;fw=fo;fx=b[4830376]|0}else{fw=a[fk+(fr&255)|0]|0;fx=fv}}while(0);fv=fw&255|fq;c[2426864]=fv;b[4830376]=fx+2&65535;b[4853728]=(fv&65535)+(b[4830390]|0)&65535;c[2440592]=(c[2440592]|0)-4;return};case 170:{b[4853728]=0;return};case 171:{b[4853728]=(b[4830380]|0)+(b[4830390]|0)&65535;c[2440592]=(c[2440592]|0)-4;return};case 172:{fv=c[2415188]|0;fx=fv&65535;fq=c[3528554]|0;fw=c[2433592]|0;fr=c[fw+(fq*3148|0)+48+((fv>>>8&255)<<2)>>2]|0;do{if((fr|0)==0){fk=c[fw+(fq*3148|0)+3132>>2]|0;if((fk|0)==0){fy=0;fz=fx;break}fs=gj[fk&4095](fx)|0;fy=fs;fz=b[4830376]|0}else{fy=a[fr+(fv&255)|0]|0;fz=fx}}while(0);fx=fy&255;fy=fz+1&65535;b[4830376]=fy;b[4853728]=((fx&128)!=0?fx|-256:fx)+fy&65535;c[2440592]=(c[2440592]|0)-1;return};case 173:{fy=c[2415188]|0;fx=fy&65535;fz=c[3528554]|0;fv=c[2433592]|0;fr=c[fv+(fz*3148|0)+48+((fy>>>8&255)<<2)>>2]|0;do{if((fr|0)==0){fq=c[fv+(fz*3148|0)+3132>>2]|0;if((fq|0)==0){fA=0;fB=fy;fC=fz;fD=fv;fE=fx;break}fw=gj[fq&4095](fx)|0;fq=c[2415188]|0;fA=fw;fB=fq;fC=c[3528554]|0;fD=c[2433592]|0;fE=fq&65535}else{fA=a[fr+(fy&255)|0]|0;fB=fy;fC=fz;fD=fv;fE=fx}}while(0);fx=(fA&255)<<8;fA=fB+1|0;fB=fA&65535;fv=c[fD+(fC*3148|0)+48+((fA>>>8&255)<<2)>>2]|0;do{if((fv|0)==0){fz=c[fD+(fC*3148|0)+3132>>2]|0;if((fz|0)==0){fF=0;fG=fE;break}fy=gj[fz&4095](fB)|0;fF=fy;fG=b[4830376]|0}else{fF=a[fv+(fA&255)|0]|0;fG=fE}}while(0);fE=fF&255|fx;c[2426864]=fE;fx=fG+2&65535;b[4830376]=fx;b[4853728]=(fE&65535)+fx&65535;c[2440592]=(c[2440592]|0)-5;return};case 43:{b[4853728]=(b[4830390]|0)+11&65535;c[2440592]=(c[2440592]|0)-1;return};case 44:{b[4853728]=(b[4830390]|0)+12&65535;c[2440592]=(c[2440592]|0)-1;return};case 45:{b[4853728]=(b[4830390]|0)+13&65535;c[2440592]=(c[2440592]|0)-1;return};case 46:{b[4853728]=(b[4830390]|0)+14&65535;c[2440592]=(c[2440592]|0)-1;return};case 47:{b[4853728]=(b[4830390]|0)+15&65535;c[2440592]=(c[2440592]|0)-1;return};case 48:{b[4853728]=(b[4830390]|0)-16&65535;c[2440592]=(c[2440592]|0)-1;return};case 49:{b[4853728]=(b[4830390]|0)-15&65535;c[2440592]=(c[2440592]|0)-1;return};case 50:{b[4853728]=(b[4830390]|0)-14&65535;c[2440592]=(c[2440592]|0)-1;return};case 51:{b[4853728]=(b[4830390]|0)-13&65535;c[2440592]=(c[2440592]|0)-1;return};case 52:{b[4853728]=(b[4830390]|0)-12&65535;c[2440592]=(c[2440592]|0)-1;return};case 103:{b[4853728]=(b[4830386]|0)+7&65535;c[2440592]=(c[2440592]|0)-1;return};case 104:{b[4853728]=(b[4830386]|0)+8&65535;c[2440592]=(c[2440592]|0)-1;return};case 105:{b[4853728]=(b[4830386]|0)+9&65535;c[2440592]=(c[2440592]|0)-1;return};case 106:{b[4853728]=(b[4830386]|0)+10&65535;c[2440592]=(c[2440592]|0)-1;return};case 107:{b[4853728]=(b[4830386]|0)+11&65535;c[2440592]=(c[2440592]|0)-1;return};case 108:{b[4853728]=(b[4830386]|0)+12&65535;c[2440592]=(c[2440592]|0)-1;return};case 109:{b[4853728]=(b[4830386]|0)+13&65535;c[2440592]=(c[2440592]|0)-1;return};case 110:{b[4853728]=(b[4830386]|0)+14&65535;c[2440592]=(c[2440592]|0)-1;return};case 111:{b[4853728]=(b[4830386]|0)+15&65535;c[2440592]=(c[2440592]|0)-1;return};case 112:{b[4853728]=(b[4830386]|0)-16&65535;c[2440592]=(c[2440592]|0)-1;return};case 113:{b[4853728]=(b[4830386]|0)-15&65535;c[2440592]=(c[2440592]|0)-1;return};case 114:{b[4853728]=(b[4830386]|0)-14&65535;c[2440592]=(c[2440592]|0)-1;return};case 115:{b[4853728]=(b[4830386]|0)-13&65535;c[2440592]=(c[2440592]|0)-1;return};case 116:{b[4853728]=(b[4830386]|0)-12&65535;c[2440592]=(c[2440592]|0)-1;return};case 117:{b[4853728]=(b[4830386]|0)-11&65535;c[2440592]=(c[2440592]|0)-1;return};case 118:{b[4853728]=(b[4830386]|0)-10&65535;c[2440592]=(c[2440592]|0)-1;return};case 119:{b[4853728]=(b[4830386]|0)-9&65535;c[2440592]=(c[2440592]|0)-1;return};case 120:{b[4853728]=(b[4830386]|0)-8&65535;c[2440592]=(c[2440592]|0)-1;return};case 121:{b[4853728]=(b[4830386]|0)-7&65535;c[2440592]=(c[2440592]|0)-1;return};case 122:{b[4853728]=(b[4830386]|0)-6&65535;c[2440592]=(c[2440592]|0)-1;return};case 123:{b[4853728]=(b[4830386]|0)-5&65535;c[2440592]=(c[2440592]|0)-1;return};case 124:{b[4853728]=(b[4830386]|0)-4&65535;c[2440592]=(c[2440592]|0)-1;return};case 125:{b[4853728]=(b[4830386]|0)-3&65535;c[2440592]=(c[2440592]|0)-1;return};case 126:{b[4853728]=(b[4830386]|0)-2&65535;c[2440592]=(c[2440592]|0)-1;return};case 127:{b[4853728]=(b[4830386]|0)-1&65535;c[2440592]=(c[2440592]|0)-1;return};case 128:{fx=b[4830388]|0;b[4853728]=fx;b[4830388]=fx+1&65535;c[2440592]=(c[2440592]|0)-2;return};case 142:{b[4853728]=0;return};case 143:{fx=c[2415188]|0;fE=fx&65535;fG=c[3528554]|0;fF=c[2433592]|0;fA=c[fF+(fG*3148|0)+48+((fx>>>8&255)<<2)>>2]|0;do{if((fA|0)==0){fv=c[fF+(fG*3148|0)+3132>>2]|0;if((fv|0)==0){fH=0;fI=fx;fJ=fG;fK=fF;fL=fE;break}fB=gj[fv&4095](fE)|0;fv=c[2415188]|0;fH=fB;fI=fv;fJ=c[3528554]|0;fK=c[2433592]|0;fL=fv&65535}else{fH=a[fA+(fx&255)|0]|0;fI=fx;fJ=fG;fK=fF;fL=fE}}while(0);fE=(fH&255)<<8;fH=fI+1|0;fI=fH&65535;fF=c[fK+(fJ*3148|0)+48+((fH>>>8&255)<<2)>>2]|0;do{if((fF|0)==0){fG=c[fK+(fJ*3148|0)+3132>>2]|0;if((fG|0)==0){fM=0;fN=fL;break}fx=gj[fG&4095](fI)|0;fM=fx;fN=b[4830376]|0}else{fM=a[fF+(fH&255)|0]|0;fN=fL}}while(0);c[2426864]=fM&255|fE;b[4830376]=fN+2&65535;c[2440592]=(c[2440592]|0)-5;return};case 144:{fN=b[4830388]|0;b[4853728]=fN;b[4830388]=fN+1&65535;fN=c[2426864]|0;fE=fN&65535;fM=c[3528554]|0;fL=c[2433592]|0;fH=c[fL+(fM*3148|0)+48+((fN>>>8&255)<<2)>>2]|0;do{if((fH|0)==0){fF=c[fL+(fM*3148|0)+3120>>2]|0;if((fF|0)==0){fO=0;fP=fM;fQ=fL;break}fI=gj[fF&4095](fE)|0;fO=fI;fP=c[3528554]|0;fQ=c[2433592]|0}else{fO=a[fH+(fN&255)|0]|0;fP=fM;fQ=fL}}while(0);fL=(fO&255)<<8;fO=fN+1|0;fN=fO&65535;fM=c[fQ+(fP*3148|0)+48+((fO>>>8&255)<<2)>>2]|0;do{if((fM|0)==0){fH=c[fQ+(fP*3148|0)+3120>>2]|0;if((fH|0)==0){fR=0;break}fR=gj[fH&4095](fN)|0}else{fR=a[fM+(fO&255)|0]|0}}while(0);c[2426864]=fR&255|fL;c[2440592]=(c[2440592]|0)-5;return};case 145:{fL=b[4830388]|0;b[4853728]=fL;b[4830388]=fL+2&65535;fL=c[2426864]|0;fR=fL&65535;fO=c[3528554]|0;fM=c[2433592]|0;fN=c[fM+(fO*3148|0)+48+((fL>>>8&255)<<2)>>2]|0;do{if((fN|0)==0){fP=c[fM+(fO*3148|0)+3120>>2]|0;if((fP|0)==0){fS=0;fT=fO;fU=fM;break}fQ=gj[fP&4095](fR)|0;fS=fQ;fT=c[3528554]|0;fU=c[2433592]|0}else{fS=a[fN+(fL&255)|0]|0;fT=fO;fU=fM}}while(0);fM=(fS&255)<<8;fS=fL+1|0;fL=fS&65535;fO=c[fU+(fT*3148|0)+48+((fS>>>8&255)<<2)>>2]|0;do{if((fO|0)==0){fN=c[fU+(fT*3148|0)+3120>>2]|0;if((fN|0)==0){fV=0;break}fV=gj[fN&4095](fL)|0}else{fV=a[fO+(fS&255)|0]|0}}while(0);c[2426864]=fV&255|fM;c[2440592]=(c[2440592]|0)-6;return};case 146:{fM=(b[4830388]|0)-1&65535;b[4830388]=fM;b[4853728]=fM;fM=c[2426864]|0;fV=fM&65535;fS=c[3528554]|0;fO=c[2433592]|0;fL=c[fO+(fS*3148|0)+48+((fM>>>8&255)<<2)>>2]|0;do{if((fL|0)==0){fT=c[fO+(fS*3148|0)+3120>>2]|0;if((fT|0)==0){fW=0;fX=fS;fY=fO;break}fU=gj[fT&4095](fV)|0;fW=fU;fX=c[3528554]|0;fY=c[2433592]|0}else{fW=a[fL+(fM&255)|0]|0;fX=fS;fY=fO}}while(0);fO=(fW&255)<<8;fW=fM+1|0;fM=fW&65535;fS=c[fY+(fX*3148|0)+48+((fW>>>8&255)<<2)>>2]|0;do{if((fS|0)==0){fL=c[fY+(fX*3148|0)+3120>>2]|0;if((fL|0)==0){fZ=0;break}fZ=gj[fL&4095](fM)|0}else{fZ=a[fS+(fW&255)|0]|0}}while(0);c[2426864]=fZ&255|fO;c[2440592]=(c[2440592]|0)-5;return};case 147:{fO=(b[4830388]|0)-2&65535;b[4830388]=fO;b[4853728]=fO;fO=c[2426864]|0;fZ=fO&65535;fW=c[3528554]|0;fS=c[2433592]|0;fM=c[fS+(fW*3148|0)+48+((fO>>>8&255)<<2)>>2]|0;do{if((fM|0)==0){fX=c[fS+(fW*3148|0)+3120>>2]|0;if((fX|0)==0){f_=0;f$=fW;f0=fS;break}fY=gj[fX&4095](fZ)|0;f_=fY;f$=c[3528554]|0;f0=c[2433592]|0}else{f_=a[fM+(fO&255)|0]|0;f$=fW;f0=fS}}while(0);fS=(f_&255)<<8;f_=fO+1|0;fO=f_&65535;fW=c[f0+(f$*3148|0)+48+((f_>>>8&255)<<2)>>2]|0;do{if((fW|0)==0){fM=c[f0+(f$*3148|0)+3120>>2]|0;if((fM|0)==0){f1=0;break}f1=gj[fM&4095](fO)|0}else{f1=a[fW+(f_&255)|0]|0}}while(0);c[2426864]=f1&255|fS;c[2440592]=(c[2440592]|0)-6;return};case 148:{b[4853728]=b[4830388]|0;fS=c[2426864]|0;f1=fS&65535;f_=c[3528554]|0;fW=c[2433592]|0;fO=c[fW+(f_*3148|0)+48+((fS>>>8&255)<<2)>>2]|0;do{if((fO|0)==0){f$=c[fW+(f_*3148|0)+3120>>2]|0;if((f$|0)==0){f2=0;f3=f_;f4=fW;break}f0=gj[f$&4095](f1)|0;f2=f0;f3=c[3528554]|0;f4=c[2433592]|0}else{f2=a[fO+(fS&255)|0]|0;f3=f_;f4=fW}}while(0);fW=(f2&255)<<8;f2=fS+1|0;fS=f2&65535;f_=c[f4+(f3*3148|0)+48+((f2>>>8&255)<<2)>>2]|0;do{if((f_|0)==0){fO=c[f4+(f3*3148|0)+3120>>2]|0;if((fO|0)==0){f5=0;break}f5=gj[fO&4095](fS)|0}else{f5=a[f_+(f2&255)|0]|0}}while(0);c[2426864]=f5&255|fW;c[2440592]=(c[2440592]|0)-3;return};case 149:{fW=d[9660760]|0;b[4853728]=((fW&128|0)!=0?fW|65280:fW)+(e[4830388]|0)&65535;fW=c[2426864]|0;f5=fW&65535;f2=c[3528554]|0;f_=c[2433592]|0;fS=c[f_+(f2*3148|0)+48+((fW>>>8&255)<<2)>>2]|0;do{if((fS|0)==0){f3=c[f_+(f2*3148|0)+3120>>2]|0;if((f3|0)==0){f6=0;f7=f2;f8=f_;break}f4=gj[f3&4095](f5)|0;f6=f4;f7=c[3528554]|0;f8=c[2433592]|0}else{f6=a[fS+(fW&255)|0]|0;f7=f2;f8=f_}}while(0);f_=(f6&255)<<8;f6=fW+1|0;fW=f6&65535;f2=c[f8+(f7*3148|0)+48+((f6>>>8&255)<<2)>>2]|0;do{if((f2|0)==0){fS=c[f8+(f7*3148|0)+3120>>2]|0;if((fS|0)==0){f9=0;break}f9=gj[fS&4095](fW)|0}else{f9=a[f2+(f6&255)|0]|0}}while(0);c[2426864]=f9&255|f_;c[2440592]=(c[2440592]|0)-4;return};case 150:{f_=d[9660761]|0;b[4853728]=((f_&128|0)!=0?f_|65280:f_)+(e[4830388]|0)&65535;f_=c[2426864]|0;f9=f_&65535;f6=c[3528554]|0;f2=c[2433592]|0;fW=c[f2+(f6*3148|0)+48+((f_>>>8&255)<<2)>>2]|0;do{if((fW|0)==0){f7=c[f2+(f6*3148|0)+3120>>2]|0;if((f7|0)==0){ga=0;gb=f6;gc=f2;break}f8=gj[f7&4095](f9)|0;ga=f8;gb=c[3528554]|0;gc=c[2433592]|0}else{ga=a[fW+(f_&255)|0]|0;gb=f6;gc=f2}}while(0);f2=(ga&255)<<8;ga=f_+1|0;f_=ga&65535;f6=c[gc+(gb*3148|0)+48+((ga>>>8&255)<<2)>>2]|0;do{if((f6|0)==0){fW=c[gc+(gb*3148|0)+3120>>2]|0;if((fW|0)==0){gd=0;break}gd=gj[fW&4095](f_)|0}else{gd=a[f6+(ga&255)|0]|0}}while(0);c[2426864]=gd&255|f2;c[2440592]=(c[2440592]|0)-4;return};case 151:{b[4853728]=0;return};case 152:{f2=c[2415188]|0;gd=f2&65535;ga=c[3528554]|0;f6=c[2433592]|0;f_=c[f6+(ga*3148|0)+48+((f2>>>8&255)<<2)>>2]|0;do{if((f_|0)==0){gb=c[f6+(ga*3148|0)+3132>>2]|0;if((gb|0)==0){ge=0;gf=gd;gg=ga;gh=f6;break}gc=gj[gb&4095](gd)|0;ge=gc;gf=b[4830376]|0;gg=c[3528554]|0;gh=c[2433592]|0}else{ge=a[f_+(f2&255)|0]|0;gf=gd;gg=ga;gh=f6}}while(0);f6=ge&255;b[4830376]=gf+1&65535;b[4853728]=((f6&128)!=0?f6|-256:f6)+(b[4830388]|0)&65535;f6=c[2426864]|0;gf=f6&65535;ge=c[gh+(gg*3148|0)+48+((f6>>>8&255)<<2)>>2]|0;do{if((ge|0)==0){ga=c[gh+(gg*3148|0)+3120>>2]|0;if((ga|0)==0){gi=0;gk=gg;gl=gh;break}gd=gj[ga&4095](gf)|0;gi=gd;gk=c[3528554]|0;gl=c[2433592]|0}else{gi=a[ge+(f6&255)|0]|0;gk=gg;gl=gh}}while(0);gh=(gi&255)<<8;gi=f6+1|0;f6=gi&65535;gg=c[gl+(gk*3148|0)+48+((gi>>>8&255)<<2)>>2]|0;do{if((gg|0)==0){ge=c[gl+(gk*3148|0)+3120>>2]|0;if((ge|0)==0){gm=0;break}gm=gj[ge&4095](f6)|0}else{gm=a[gg+(gi&255)|0]|0}}while(0);c[2426864]=gm&255|gh;c[2440592]=(c[2440592]|0)-4;return};case 153:{gh=c[2415188]|0;gm=gh&65535;gi=c[3528554]|0;gg=c[2433592]|0;f6=c[gg+(gi*3148|0)+48+((gh>>>8&255)<<2)>>2]|0;do{if((f6|0)==0){gk=c[gg+(gi*3148|0)+3132>>2]|0;if((gk|0)==0){gn=0;go=gh;gp=gi;gq=gg;gr=gm;break}gl=gj[gk&4095](gm)|0;gk=c[2415188]|0;gn=gl;go=gk;gp=c[3528554]|0;gq=c[2433592]|0;gr=gk&65535}else{gn=a[f6+(gh&255)|0]|0;go=gh;gp=gi;gq=gg;gr=gm}}while(0);gm=(gn&255)<<8;gn=go+1|0;go=gn&65535;gg=c[gq+(gp*3148|0)+48+((gn>>>8&255)<<2)>>2]|0;do{if((gg|0)==0){gi=c[gq+(gp*3148|0)+3132>>2]|0;if((gi|0)==0){gs=0;gt=gr;gu=gp;gv=gq;break}gh=gj[gi&4095](go)|0;gs=gh;gt=b[4830376]|0;gu=c[3528554]|0;gv=c[2433592]|0}else{gs=a[gg+(gn&255)|0]|0;gt=gr;gu=gp;gv=gq}}while(0);gq=gs&255|gm;c[2426864]=gq;b[4830376]=gt+2&65535;b[4853728]=(gq&65535)+(b[4830388]|0)&65535;gq=c[2426864]|0;gt=gq&65535;gm=c[gv+(gu*3148|0)+48+((gq>>>8&255)<<2)>>2]|0;do{if((gm|0)==0){gs=c[gv+(gu*3148|0)+3120>>2]|0;if((gs|0)==0){gw=0;gx=gu;gy=gv;break}gp=gj[gs&4095](gt)|0;gw=gp;gx=c[3528554]|0;gy=c[2433592]|0}else{gw=a[gm+(gq&255)|0]|0;gx=gu;gy=gv}}while(0);gv=(gw&255)<<8;gw=gq+1|0;gq=gw&65535;gu=c[gy+(gx*3148|0)+48+((gw>>>8&255)<<2)>>2]|0;do{if((gu|0)==0){gm=c[gy+(gx*3148|0)+3120>>2]|0;if((gm|0)==0){gz=0;break}gz=gj[gm&4095](gq)|0}else{gz=a[gu+(gw&255)|0]|0}}while(0);c[2426864]=gz&255|gv;c[2440592]=(c[2440592]|0)-7;return};default:{return}}}function f47(){var d=0;d=c[2385310]|0;gGz(d|0,0,16);b[d+28>>1]=0;a[d+56|0]=0;a[d+57|0]=0;a[d+58|0]=0;a[d+59|0]=1;c[d+32>>2]=0;c[d+36>>2]=0;c[d+40>>2]=0;c[d+44>>2]=1;c[d+48>>2]=0;c[d+52>>2]=1;c[d+64>>2]=0;c[d+68>>2]=0;c[d+72>>2]=0;c[d+76>>2]=1;a[d+81|0]=0;c[d+104>>2]=0;c[d+108>>2]=0;c[d+60>>2]=255;b[d+22>>1]=-1;b[d+24>>1]=0;b[d+26>>1]=0;b[d+20>>1]=0;a[d+91|0]=1;return 0}function f48(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0;f=c[2385310]|0;if((b|0)==20){c[f+60>>2]=d;c[f+76>>2]=e;return}else if((b|0)==32){g=f+68|0;if((c[g>>2]|0)==(e|0)){return}c[g>>2]=e;if((e|0)==0){return}c[f+60>>2]=d;g=f+64|0;c[g>>2]=c[g>>2]|2;a[f+81|0]=0;return}else if((b|0)==0){c[f+72>>2]=e;if((e|0)==0){e=f+64|0;c[e>>2]=c[e>>2]&-2;return}else{c[f+60>>2]=d;d=f+64|0;c[d>>2]=c[d>>2]|1;a[f+81|0]=0;return}}else{return}}function f49(a){a=a|0;c[2385310]=9637928+(a*116|0);return}function f5a(){c[2385310]=0;return}function f5b(){var a=0;a=c[2385310]|0;return(c[a+108>>2]|0)+(c[a+104>>2]|0)-(c[a+84>>2]|0)|0}function f5c(){a[(c[2385310]|0)+112|0]=1;return}function f5d(a){a=a|0;var b=0;b=(c[2385310]|0)+84|0;c[b>>2]=(c[b>>2]|0)-a;return}function f5e(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;g=c[2385310]|0;h=g+84|0;c[h>>2]=f;i=g+108|0;c[i>>2]=f;if((a[g+81|0]|0)!=0){c[h>>2]=0;j=f;return j|0}k=g+112|0;L54595:do{if((f|0)>0){l=g+64|0;m=g+80|0;n=g+90|0;o=g+22|0;p=g+28|0;q=g+16|0;r=g+89|0;s=g+91|0;t=g+88|0;u=g+57|0;v=g+72|0;w=f;while(1){if((a[k]|0)!=0){x=w;break L54595}y=c[l>>2]|0;do{if((y|0)==0){z=44616}else{A=a[m]|0;if(A<<24>>24!=0){B=A;z=44617;break}if((y&2|0)!=0){f9v(g,2,2);c[l>>2]=c[l>>2]&-3;z=44616;break}if((a[u]|0)==0){z=44616;break}f9v(g,-1,1);c[v>>2]=0;c[l>>2]=c[l>>2]&-2;z=44616}}while(0);if((z|0)==44616){z=0;y=a[m]|0;if(y<<24>>24!=0){B=y;z=44617}}if((z|0)==44617){z=0;a[m]=B-1&255}y=c[h>>2]|0;a[n]=(a[n]|0)-1&255;A=e[o>>1]<<4;C=b[p>>1]|0;b[p>>1]=C+1&65535;D=(A+(C&65535)^c[q>>2])&1048575;C=c[3531864]|0;A=c[C+4140+(D>>>11<<2)>>2]|0;if((A|0)==0){E=gj[c[C+8236>>2]&4095](D)|0}else{E=a[A+D|0]|0}gf[c[2520528+((E&255)<<2)>>2]&2047](g);D=c[h>>2]|0;A=y-D|0;y=a[n]|0;L54616:do{if(y<<24>>24<0){C=d[r]|0;F=A;G=y;while(1){H=G+1&255;if((F|0)<=(C|0)){break}a[n]=H;I=F-C|0;if(H<<24>>24<0){F=I;G=H}else{J=I;K=H;L=D;break L54616}}I=H<<24>>24>0?H:0;M=(ag(C,~(I+~G&255))|0)+D|0;c[h>>2]=M;a[n]=I;J=F;K=I;L=M}else{J=A;K=y;L=D}}while(0);L54623:do{if((a[s]|0)==0){D=d[r]|0;if((J|0)<(D|0)){break}y=d[t]|0;A=J;M=K;do{if((M<<24>>24|0)>=(y|0)){break L54623}A=A-D|0;M=M+1&255;a[n]=M;}while((A|0)>=(D|0))}else{a[n]=0;a[s]=0}}while(0);if((L|0)>0){w=L}else{x=L;break}}}else{x=f}}while(0);L=f-x|0;x=g+104|0;c[x>>2]=L+(c[x>>2]|0);c[i>>2]=0;a[k]=0;j=L;return j|0}function f5f(a){a=a|0;var b=0,d=0;if((a|0)==-1){b=c[2385310]|0;d=((e[b+22>>1]|0)<<4)+(e[b+28>>1]|0)|0;return d|0}else{d=((e[9637950+(a*116|0)>>1]|0)<<4)+(e[9637956+(a*116|0)>>1]|0)|0;return d|0}return 0}function f5g(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;e=i;i=i+24|0;f=e|0;g=e+16|0;if((d&64|0)==0){i=e;return}d=g|0;a[d]=a[614872]|0;a[d+1|0]=a[614873]|0;a[d+2|0]=a[614874]|0;a[d+3|0]=a[614875]|0;a[d+4|0]=a[614876]|0;a[d+5|0]=a[614877]|0;a[d+6|0]=a[614878]|0;a[g+5|0]=b+49&255;gGz(f|0,0,12);c[f>>2]=9637928+(b*116|0);c[f+4>>2]=116;c[f+12>>2]=d;gj[c[2076592]&4095](f)|0;i=e;return}function f5h(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=(e[d+22>>1]|0)<<4;g=(c[2385310]|0)+28|0;h=b[g>>1]|0;b[g>>1]=h+1&65535;g=(h&65535)+f&1048575;f=c[3531864]|0;h=c[f+6188+(g>>>11<<2)>>2]|0;if((h|0)==0){i=gj[c[f+8236>>2]&4095](g)|0}else{i=a[h+g|0]|0}g=i&255;h=d;f=a[h+(c[9652832+(g<<2)>>2]|0)|0]|0;j=f&255;k=(i&255)>191;do{if(k){l=a[h+(c[9648736+(g<<2)>>2]|0)|0]|0}else{i=(gj[c[679712+(g<<2)>>2]&4095](d)|0)&1048575;m=c[3531864]|0;n=c[m+44+(i>>>11<<2)>>2]|0;if((n|0)==0){l=gj[c[m+8236>>2]&4095](i)|0;break}else{l=a[n+i|0]|0;break}}}while(0);i=l&255;n=i+j|0;c[d+48>>2]=n&256;c[d+40>>2]=(n^i)&128&(n^j);c[d+36>>2]=(n^(l^f)&255)&16;f=n<<24>>24;c[d+52>>2]=f;c[d+44>>2]=f;c[d+32>>2]=f;do{if(k){a[h+(c[9648736+(g<<2)>>2]|0)|0]=n&255}else{f=n&255;l=c[2426956]&1048575;j=c[3531864]|0;i=c[j+2092+(l>>>11<<2)>>2]|0;if((i|0)==0){gg[c[j+8240>>2]&4095](l,f);break}else{a[i+l|0]=f;break}}}while(0);n=d+84|0;c[n>>2]=(c[n>>2]|0)-((k?131586:1052679)>>>((c[d+92>>2]|0)>>>0)&127);return}function f5i(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=(e[d+22>>1]|0)<<4;g=(c[2385310]|0)+28|0;h=b[g>>1]|0;b[g>>1]=h+1&65535;g=(h&65535)+f&1048575;f=c[3531864]|0;h=c[f+6188+(g>>>11<<2)>>2]|0;if((h|0)==0){i=gj[c[f+8236>>2]&4095](g)|0}else{i=a[h+g|0]|0}g=i&255;h=e[d+(c[9654880+(g<<2)>>2]<<1)>>1]|0;f=(i&255)>191;if(f){j=e[d+(c[9650784+(g<<2)>>2]<<1)>>1]|0}else{i=c[679712+(g<<2)>>2]|0;gj[i&4095](d)|0;i=c[2426956]|0;k=i&1048575;l=c[3531864]|0;m=c[l+44+(k>>>11<<2)>>2]|0;if((m|0)==0){n=gj[c[l+8236>>2]&4095](k)|0;o=n;p=c[2426956]|0;q=c[3531864]|0}else{o=a[m+k|0]|0;p=i;q=l}l=p+1&1048575;p=c[q+44+(l>>>11<<2)>>2]|0;if((p|0)==0){r=gj[c[q+8236>>2]&4095](l)|0}else{r=a[p+l|0]|0}j=(r&255)<<8|o&255}o=j+h|0;c[d+48>>2]=o&65536;c[d+40>>2]=(o^j)&32768&(o^h);c[d+36>>2]=(j^h^o)&16;h=o<<16>>16;c[d+52>>2]=h;c[d+44>>2]=h;c[d+32>>2]=h;if(f){b[d+(c[9650784+(g<<2)>>2]<<1)>>1]=o&65535;g=d+84|0;c[g>>2]=(c[g>>2]|0)-2;return}g=c[2426956]|0;f=o&255;h=g&1048575;j=c[3531864]|0;r=c[j+2092+(h>>>11<<2)>>2]|0;if((r|0)==0){gg[c[j+8240>>2]&4095](h,f);s=c[3531864]|0}else{a[r+h|0]=f;s=j}j=(o&65535)>>>8&255;o=g+1&1048575;g=c[s+2092+(o>>>11<<2)>>2]|0;if((g|0)==0){gg[c[s+8240>>2]&4095](o,j)}else{a[g+o|0]=j}j=d+84|0;c[j>>2]=(c[j>>2]|0)-(((c[2426956]&1|0)!=0?1579019:1576967)>>>((c[d+92>>2]|0)>>>0)&127);return}function f5j(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=(e[d+22>>1]|0)<<4;g=(c[2385310]|0)+28|0;h=b[g>>1]|0;b[g>>1]=h+1&65535;g=(h&65535)+f&1048575;f=c[3531864]|0;h=c[f+6188+(g>>>11<<2)>>2]|0;if((h|0)==0){i=gj[c[f+8236>>2]&4095](g)|0}else{i=a[h+g|0]|0}g=i&255;h=9652832+(g<<2)|0;f=d;j=a[f+(c[h>>2]|0)|0]|0;k=j&255;l=(i&255)>191;do{if(l){m=a[f+(c[9648736+(g<<2)>>2]|0)|0]|0}else{i=(gj[c[679712+(g<<2)>>2]&4095](d)|0)&1048575;n=c[3531864]|0;o=c[n+44+(i>>>11<<2)>>2]|0;if((o|0)==0){m=gj[c[n+8236>>2]&4095](i)|0;break}else{m=a[o+i|0]|0;break}}}while(0);g=m&255;i=g+k|0;c[d+48>>2]=i&256;c[d+40>>2]=(i^k)&128&(i^g);c[d+36>>2]=(i^(m^j)&255)&16;j=i&255;i=j<<24>>24;c[d+52>>2]=i;c[d+44>>2]=i;c[d+32>>2]=i;a[f+(c[h>>2]|0)|0]=j;j=d+84|0;c[j>>2]=(c[j>>2]|0)-((l?131586:723718)>>>((c[d+92>>2]|0)>>>0)&127);return}function f5k(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=(e[d+22>>1]|0)<<4;g=(c[2385310]|0)+28|0;h=b[g>>1]|0;b[g>>1]=h+1&65535;g=(h&65535)+f&1048575;f=c[3531864]|0;h=c[f+6188+(g>>>11<<2)>>2]|0;if((h|0)==0){i=gj[c[f+8236>>2]&4095](g)|0}else{i=a[h+g|0]|0}g=i&255;h=9654880+(g<<2)|0;f=c[h>>2]|0;j=e[d+(f<<1)>>1]|0;k=(i&255)>191;if(k){l=e[d+(c[9650784+(g<<2)>>2]<<1)>>1]|0;m=f}else{f=c[679712+(g<<2)>>2]|0;gj[f&4095](d)|0;f=c[2426956]|0;g=f&1048575;i=c[3531864]|0;n=c[i+44+(g>>>11<<2)>>2]|0;if((n|0)==0){o=gj[c[i+8236>>2]&4095](g)|0;p=o;q=c[2426956]|0;r=c[3531864]|0}else{p=a[n+g|0]|0;q=f;r=i}i=q+1&1048575;q=c[r+44+(i>>>11<<2)>>2]|0;if((q|0)==0){s=gj[c[r+8236>>2]&4095](i)|0}else{s=a[q+i|0]|0}l=(s&255)<<8|p&255;m=c[h>>2]|0}h=l+j|0;c[d+48>>2]=h&65536;c[d+40>>2]=(h^j)&32768&(h^l);c[d+36>>2]=(l^j^h)&16;j=h&65535;h=j<<16>>16;c[d+52>>2]=h;c[d+44>>2]=h;c[d+32>>2]=h;b[d+(m<<1)>>1]=j;if(k){k=d+84|0;c[k>>2]=(c[k>>2]|0)-2;return}else{k=d+84|0;c[k>>2]=(c[k>>2]|0)-(((c[2426956]&1|0)!=0?986888:985862)>>>((c[d+92>>2]|0)>>>0)&127);return}}function f5l(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=(e[d+22>>1]|0)<<4;g=(c[2385310]|0)+28|0;h=b[g>>1]|0;b[g>>1]=h+1&65535;g=(h&65535)+f&1048575;f=c[3531864]|0;h=c[f+6188+(g>>>11<<2)>>2]|0;if((h|0)==0){i=gj[c[f+8236>>2]&4095](g)|0}else{i=a[h+g|0]|0}g=i&255;h=d;f=a[h]|0;j=f&255;k=j+g|0;c[d+48>>2]=k&256;c[d+40>>2]=(k^j)&128&(k^g);c[d+36>>2]=(k^(f^i)&255)&16;i=k&255;k=i<<24>>24;c[d+52>>2]=k;c[d+44>>2]=k;c[d+32>>2]=k;a[h]=i;i=d+84|0;c[i>>2]=(c[i>>2]|0)-(263170>>>((c[d+92>>2]|0)>>>0)&127);return}function f5m(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=d+22|0;g=(e[f>>1]|0)<<4;h=c[2385310]|0;i=h+28|0;j=b[i>>1]|0;k=j+1&65535;b[i>>1]=k;i=(j&65535)+g&1048575;g=c[3531864]|0;j=c[g+6188+(i>>>11<<2)>>2]|0;if((j|0)==0){l=gj[c[g+8236>>2]&4095](i)|0;m=c[2385310]|0;n=l;o=m;p=b[m+28>>1]|0;q=c[3531864]|0}else{n=a[j+i|0]|0;o=h;p=k;q=g}g=n&255;n=d|0;k=e[n>>1]|0;h=(e[f>>1]|0)<<4;b[o+28>>1]=p+1&65535;o=(p&65535)+h&1048575;h=c[q+6188+(o>>>11<<2)>>2]|0;if((h|0)==0){r=gj[c[q+8236>>2]&4095](o)|0}else{r=a[h+o|0]|0}o=(r&255)<<8;r=(o|g)+k|0;c[d+48>>2]=r&65536;c[d+40>>2]=(r^k)&32768&(r^o);c[d+36>>2]=(k^g^r)&16;g=r&65535;r=g<<16>>16;c[d+52>>2]=r;c[d+44>>2]=r;c[d+32>>2]=r;b[n>>1]=g;g=d+84|0;c[g>>2]=(c[g>>2]|0)-(263170>>>((c[d+92>>2]|0)>>>0)&127);return}function f5n(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=d+8|0;g=(b[f>>1]|0)-2&65535;b[f>>1]=g;f=((e[d+24>>1]|0)<<4)+(g&65535)|0;g=b[d+20>>1]|0;h=g&255;i=f&1048575;j=c[3531864]|0;k=c[j+2092+(i>>>11<<2)>>2]|0;if((k|0)==0){gg[c[j+8240>>2]&4095](i,h);l=c[3531864]|0}else{a[k+i|0]=h;l=j}j=(g&65535)>>>8&255;g=f+1&1048575;f=c[l+2092+(g>>>11<<2)>>2]|0;if((f|0)==0){gg[c[l+8240>>2]&4095](g,j);m=d+92|0;n=c[m>>2]|0;o=788483>>>(n>>>0);p=o&127;q=d+84|0;r=c[q>>2]|0;s=r-p|0;c[q>>2]=s;return}else{a[f+g|0]=j;m=d+92|0;n=c[m>>2]|0;o=788483>>>(n>>>0);p=o&127;q=d+84|0;r=c[q>>2]|0;s=r-p|0;c[q>>2]=s;return}}function f5o(d){d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=d+8|0;f=(b[e>>1]|0)+2&65535;b[e>>1]=f;g=d+24|0;h=b[g>>1]|0;i=((f&65535)+65534&65535)+((h&65535)<<4)&1048575;j=c[3531864]|0;k=c[j+44+(i>>>11<<2)>>2]|0;if((k|0)==0){l=gj[c[j+8236>>2]&4095](i)|0;m=l;n=b[g>>1]|0;o=b[e>>1]|0;p=c[3531864]|0}else{m=a[k+i|0]|0;n=h;o=f;p=j}j=((o&65535)+65534&65535)+((n&65535)<<4|1)&1048575;n=c[p+44+(j>>>11<<2)>>2]|0;if((n|0)==0){q=gj[c[p+8236>>2]&4095](j)|0}else{q=a[n+j|0]|0}b[d+20>>1]=(q&255)<<8|m&255;m=d+84|0;c[m>>2]=(c[m>>2]|0)-(788485>>>((c[d+92>>2]|0)>>>0)&127);return}function f5p(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=(e[d+22>>1]|0)<<4;g=(c[2385310]|0)+28|0;h=b[g>>1]|0;b[g>>1]=h+1&65535;g=(h&65535)+f&1048575;f=c[3531864]|0;h=c[f+6188+(g>>>11<<2)>>2]|0;if((h|0)==0){i=gj[c[f+8236>>2]&4095](g)|0}else{i=a[h+g|0]|0}g=i&255;h=d;f=a[h+(c[9652832+(g<<2)>>2]|0)|0]|0;j=(i&255)>191;do{if(j){k=a[h+(c[9648736+(g<<2)>>2]|0)|0]|0}else{i=(gj[c[679712+(g<<2)>>2]&4095](d)|0)&1048575;l=c[3531864]|0;m=c[l+44+(i>>>11<<2)>>2]|0;if((m|0)==0){k=gj[c[l+8236>>2]&4095](i)|0;break}else{k=a[m+i|0]|0;break}}}while(0);i=k|f;c[d+36>>2]=0;c[d+40>>2]=0;c[d+48>>2]=0;f=i<<24>>24;c[d+52>>2]=f;c[d+44>>2]=f;c[d+32>>2]=f;do{if(j){a[h+(c[9648736+(g<<2)>>2]|0)|0]=i}else{f=c[2426956]&1048575;k=c[3531864]|0;m=c[k+2092+(f>>>11<<2)>>2]|0;if((m|0)==0){gg[c[k+8240>>2]&4095](f,i);break}else{a[m+f|0]=i;break}}}while(0);i=d+84|0;c[i>>2]=(c[i>>2]|0)-((j?131586:1052679)>>>((c[d+92>>2]|0)>>>0)&127);return}function f5q(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=(e[d+22>>1]|0)<<4;g=(c[2385310]|0)+28|0;h=b[g>>1]|0;b[g>>1]=h+1&65535;g=(h&65535)+f&1048575;f=c[3531864]|0;h=c[f+6188+(g>>>11<<2)>>2]|0;if((h|0)==0){i=gj[c[f+8236>>2]&4095](g)|0}else{i=a[h+g|0]|0}g=i&255;h=b[d+(c[9654880+(g<<2)>>2]<<1)>>1]|0;f=(i&255)>191;if(f){j=b[d+(c[9650784+(g<<2)>>2]<<1)>>1]|0}else{i=c[679712+(g<<2)>>2]|0;gj[i&4095](d)|0;i=c[2426956]|0;k=i&1048575;l=c[3531864]|0;m=c[l+44+(k>>>11<<2)>>2]|0;if((m|0)==0){n=gj[c[l+8236>>2]&4095](k)|0;o=n;p=c[2426956]|0;q=c[3531864]|0}else{o=a[m+k|0]|0;p=i;q=l}l=p+1&1048575;p=c[q+44+(l>>>11<<2)>>2]|0;if((p|0)==0){r=gj[c[q+8236>>2]&4095](l)|0}else{r=a[p+l|0]|0}j=(r&255)<<8|o&255}o=j|h;c[d+36>>2]=0;c[d+40>>2]=0;c[d+48>>2]=0;h=o<<16>>16;c[d+52>>2]=h;c[d+44>>2]=h;c[d+32>>2]=h;if(f){b[d+(c[9650784+(g<<2)>>2]<<1)>>1]=o;g=d+84|0;c[g>>2]=(c[g>>2]|0)-2;return}g=c[2426956]|0;f=o&255;h=g&1048575;j=c[3531864]|0;r=c[j+2092+(h>>>11<<2)>>2]|0;if((r|0)==0){gg[c[j+8240>>2]&4095](h,f);s=c[3531864]|0}else{a[r+h|0]=f;s=j}j=(o&65535)>>>8&255;o=g+1&1048575;g=c[s+2092+(o>>>11<<2)>>2]|0;if((g|0)==0){gg[c[s+8240>>2]&4095](o,j)}else{a[g+o|0]=j}j=d+84|0;c[j>>2]=(c[j>>2]|0)-(((c[2426956]&1|0)!=0?1579019:1576967)>>>((c[d+92>>2]|0)>>>0)&127);return}function f5r(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=(e[d+22>>1]|0)<<4;g=(c[2385310]|0)+28|0;h=b[g>>1]|0;b[g>>1]=h+1&65535;g=(h&65535)+f&1048575;f=c[3531864]|0;h=c[f+6188+(g>>>11<<2)>>2]|0;if((h|0)==0){i=gj[c[f+8236>>2]&4095](g)|0}else{i=a[h+g|0]|0}g=i&255;h=9652832+(g<<2)|0;f=d;j=a[f+(c[h>>2]|0)|0]|0;k=(i&255)>191;do{if(k){l=a[f+(c[9648736+(g<<2)>>2]|0)|0]|0}else{i=(gj[c[679712+(g<<2)>>2]&4095](d)|0)&1048575;m=c[3531864]|0;n=c[m+44+(i>>>11<<2)>>2]|0;if((n|0)==0){l=gj[c[m+8236>>2]&4095](i)|0;break}else{l=a[n+i|0]|0;break}}}while(0);g=l|j;c[d+36>>2]=0;c[d+40>>2]=0;c[d+48>>2]=0;j=g<<24>>24;c[d+52>>2]=j;c[d+44>>2]=j;c[d+32>>2]=j;a[f+(c[h>>2]|0)|0]=g;g=d+84|0;c[g>>2]=(c[g>>2]|0)-((k?131586:723718)>>>((c[d+92>>2]|0)>>>0)&127);return}function f5s(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=(e[d+22>>1]|0)<<4;g=(c[2385310]|0)+28|0;h=b[g>>1]|0;b[g>>1]=h+1&65535;g=(h&65535)+f&1048575;f=c[3531864]|0;h=c[f+6188+(g>>>11<<2)>>2]|0;if((h|0)==0){i=gj[c[f+8236>>2]&4095](g)|0}else{i=a[h+g|0]|0}g=i&255;h=9654880+(g<<2)|0;f=c[h>>2]|0;j=b[d+(f<<1)>>1]|0;k=(i&255)>191;if(k){l=b[d+(c[9650784+(g<<2)>>2]<<1)>>1]|0;m=f}else{f=c[679712+(g<<2)>>2]|0;gj[f&4095](d)|0;f=c[2426956]|0;g=f&1048575;i=c[3531864]|0;n=c[i+44+(g>>>11<<2)>>2]|0;if((n|0)==0){o=gj[c[i+8236>>2]&4095](g)|0;p=o;q=c[2426956]|0;r=c[3531864]|0}else{p=a[n+g|0]|0;q=f;r=i}i=q+1&1048575;q=c[r+44+(i>>>11<<2)>>2]|0;if((q|0)==0){s=gj[c[r+8236>>2]&4095](i)|0}else{s=a[q+i|0]|0}l=(s&255)<<8|p&255;m=c[h>>2]|0}h=l|j;c[d+36>>2]=0;c[d+40>>2]=0;c[d+48>>2]=0;j=h<<16>>16;c[d+52>>2]=j;c[d+44>>2]=j;c[d+32>>2]=j;b[d+(m<<1)>>1]=h;if(k){k=d+84|0;c[k>>2]=(c[k>>2]|0)-2;return}else{k=d+84|0;c[k>>2]=(c[k>>2]|0)-(((c[2426956]&1|0)!=0?986888:985862)>>>((c[d+92>>2]|0)>>>0)&127);return}}function f5t(d){d=d|0;var f=0,g=0,h=0,i=0;f=(e[d+22>>1]|0)<<4;g=(c[2385310]|0)+28|0;h=b[g>>1]|0;b[g>>1]=h+1&65535;g=(h&65535)+f&1048575;f=c[3531864]|0;h=c[f+6188+(g>>>11<<2)>>2]|0;if((h|0)==0){i=gj[c[f+8236>>2]&4095](g)|0}else{i=a[h+g|0]|0}g=d;h=a[g]|i;c[d+36>>2]=0;c[d+40>>2]=0;c[d+48>>2]=0;i=h<<24>>24;c[d+52>>2]=i;c[d+44>>2]=i;c[d+32>>2]=i;a[g]=h;h=d+84|0;c[h>>2]=(c[h>>2]|0)-(263170>>>((c[d+92>>2]|0)>>>0)&127);return}function f5u(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=d+22|0;g=(e[f>>1]|0)<<4;h=c[2385310]|0;i=h+28|0;j=b[i>>1]|0;k=j+1&65535;b[i>>1]=k;i=(j&65535)+g&1048575;g=c[3531864]|0;j=c[g+6188+(i>>>11<<2)>>2]|0;if((j|0)==0){l=gj[c[g+8236>>2]&4095](i)|0;m=c[2385310]|0;n=l;o=m;p=b[m+28>>1]|0;q=c[3531864]|0}else{n=a[j+i|0]|0;o=h;p=k;q=g}g=d|0;k=b[g>>1]|0;h=(e[f>>1]|0)<<4;b[o+28>>1]=p+1&65535;o=(p&65535)+h&1048575;h=c[q+6188+(o>>>11<<2)>>2]|0;if((h|0)==0){r=gj[c[q+8236>>2]&4095](o)|0}else{r=a[h+o|0]|0}o=k|n&255|(r&255)<<8;c[d+36>>2]=0;c[d+40>>2]=0;c[d+48>>2]=0;r=o<<16>>16;c[d+52>>2]=r;c[d+44>>2]=r;c[d+32>>2]=r;b[g>>1]=o;o=d+84|0;c[o>>2]=(c[o>>2]|0)-(263170>>>((c[d+92>>2]|0)>>>0)&127);return}function f5v(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=d+8|0;g=(b[f>>1]|0)-2&65535;b[f>>1]=g;f=((e[d+24>>1]|0)<<4)+(g&65535)|0;g=b[d+22>>1]|0;h=g&255;i=f&1048575;j=c[3531864]|0;k=c[j+2092+(i>>>11<<2)>>2]|0;if((k|0)==0){gg[c[j+8240>>2]&4095](i,h);l=c[3531864]|0}else{a[k+i|0]=h;l=j}j=(g&65535)>>>8&255;g=f+1&1048575;f=c[l+2092+(g>>>11<<2)>>2]|0;if((f|0)==0){gg[c[l+8240>>2]&4095](g,j);m=d+92|0;n=c[m>>2]|0;o=788483>>>(n>>>0);p=o&127;q=d+84|0;r=c[q>>2]|0;s=r-p|0;c[q>>2]=s;return}else{a[f+g|0]=j;m=d+92|0;n=c[m>>2]|0;o=788483>>>(n>>>0);p=o&127;q=d+84|0;r=c[q>>2]|0;s=r-p|0;c[q>>2]=s;return}}function f5w(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0;g=f+20|0;h=f+22|0;i=e[h>>1]<<4;j=(c[2385310]|0)+28|0;k=b[j>>1]|0;b[j>>1]=k+1&65535;j=(k&65535)+i&1048575;i=c[3531864]|0;k=c[i+6188+(j>>>11<<2)>>2]|0;if((k|0)==0){l=gj[c[i+8236>>2]&4095](j)|0}else{l=a[k+j|0]|0}switch(l&255|0){case 17:{l=e[h>>1]<<4;j=(c[2385310]|0)+28|0;k=b[j>>1]|0;b[j>>1]=k+1&65535;j=(k&65535)+l&1048575;l=c[3531864]|0;k=c[l+6188+(j>>>11<<2)>>2]|0;if((k|0)==0){m=gj[c[l+8236>>2]&4095](j)|0}else{m=a[k+j|0]|0}j=m&255;if((m&255)>191){n=e[f+(c[9650784+(j<<2)>>2]<<1)>>1]|0}else{m=c[679712+(j<<2)>>2]|0;gj[m&4095](f)|0;m=c[2426956]|0;j=m&1048575;k=c[3531864]|0;l=c[k+44+(j>>>11<<2)>>2]|0;if((l|0)==0){i=gj[c[k+8236>>2]&4095](j)|0;o=i;p=c[2426956]|0;q=c[3531864]|0}else{o=a[l+j|0]|0;p=m;q=k}k=p+1&1048575;p=c[q+44+(k>>>11<<2)>>2]|0;if((p|0)==0){r=gj[c[q+8236>>2]&4095](k)|0}else{r=a[p+k|0]|0}n=(r&255)<<8|o&255}o=f+84|0;c[o>>2]=(c[o>>2]|0)-(197380>>>((c[f+92>>2]|0)>>>0)&127);c[f+44>>2]=(1<<(a[f+2|0]&15)&n|0)!=0;c[f+40>>2]=0;c[f+48>>2]=0;return};case 18:{n=e[h>>1]<<4;o=(c[2385310]|0)+28|0;r=b[o>>1]|0;b[o>>1]=r+1&65535;o=(r&65535)+n&1048575;n=c[3531864]|0;r=c[n+6188+(o>>>11<<2)>>2]|0;if((r|0)==0){s=gj[c[n+8236>>2]&4095](o)|0}else{s=a[r+o|0]|0}o=s&255;r=(s&255)>191;do{if(r){t=a[f+(c[9648736+(o<<2)>>2]|0)|0]|0}else{s=c[679712+(o<<2)>>2]|0;gj[s&4095](f)|0;s=c[2426956]&1048575;n=c[3531864]|0;k=c[n+44+(s>>>11<<2)>>2]|0;if((k|0)==0){t=gj[c[n+8236>>2]&4095](s)|0;break}else{t=a[k+s|0]|0;break}}}while(0);s=f+84|0;c[s>>2]=(c[s>>2]|0)-(328964>>>((c[f+92>>2]|0)>>>0)&127);s=t&255&~(1<<(a[f+2|0]&7));if(r){a[f+(c[9648736+(o<<2)>>2]|0)|0]=s&255;return}o=s&255;s=c[2426956]&1048575;r=c[3531864]|0;t=c[r+2092+(s>>>11<<2)>>2]|0;if((t|0)==0){gg[c[r+8240>>2]&4095](s,o);return}else{a[t+s|0]=o;return}break};case 19:{o=e[h>>1]<<4;s=(c[2385310]|0)+28|0;t=b[s>>1]|0;b[s>>1]=t+1&65535;s=(t&65535)+o&1048575;o=c[3531864]|0;t=c[o+6188+(s>>>11<<2)>>2]|0;if((t|0)==0){u=gj[c[o+8236>>2]&4095](s)|0}else{u=a[t+s|0]|0}s=u&255;t=(u&255)>191;if(t){v=e[f+(c[9650784+(s<<2)>>2]<<1)>>1]|0}else{u=c[679712+(s<<2)>>2]|0;gj[u&4095](f)|0;u=c[2426956]|0;o=u&1048575;r=c[3531864]|0;k=c[r+44+(o>>>11<<2)>>2]|0;if((k|0)==0){n=gj[c[r+8236>>2]&4095](o)|0;w=n;x=c[2426956]|0;y=c[3531864]|0}else{w=a[k+o|0]|0;x=u;y=r}r=x+1&1048575;x=c[y+44+(r>>>11<<2)>>2]|0;if((x|0)==0){z=gj[c[y+8236>>2]&4095](r)|0}else{z=a[x+r|0]|0}v=(z&255)<<8|w&255}w=f+84|0;c[w>>2]=(c[w>>2]|0)-(328964>>>((c[f+92>>2]|0)>>>0)&127);w=v&~(1<<(a[f+2|0]&15));if(t){b[f+(c[9650784+(s<<2)>>2]<<1)>>1]=w&65535;return}s=c[2426956]|0;t=w&255;v=s&1048575;z=c[3531864]|0;r=c[z+2092+(v>>>11<<2)>>2]|0;if((r|0)==0){gg[c[z+8240>>2]&4095](v,t);A=c[3531864]|0}else{a[r+v|0]=t;A=z}z=(w&65535)>>>8&255;w=s+1&1048575;s=c[A+2092+(w>>>11<<2)>>2]|0;if((s|0)==0){gg[c[A+8240>>2]&4095](w,z);return}else{a[s+w|0]=z;return}break};case 20:{z=e[h>>1]<<4;w=(c[2385310]|0)+28|0;s=b[w>>1]|0;b[w>>1]=s+1&65535;w=(s&65535)+z&1048575;z=c[3531864]|0;s=c[z+6188+(w>>>11<<2)>>2]|0;if((s|0)==0){B=gj[c[z+8236>>2]&4095](w)|0}else{B=a[s+w|0]|0}w=B&255;s=(B&255)>191;do{if(s){C=a[f+(c[9648736+(w<<2)>>2]|0)|0]|0}else{B=c[679712+(w<<2)>>2]|0;gj[B&4095](f)|0;B=c[2426956]&1048575;z=c[3531864]|0;A=c[z+44+(B>>>11<<2)>>2]|0;if((A|0)==0){C=gj[c[z+8236>>2]&4095](B)|0;break}else{C=a[A+B|0]|0;break}}}while(0);B=f+84|0;c[B>>2]=(c[B>>2]|0)-(263172>>>((c[f+92>>2]|0)>>>0)&127);B=1<<(a[f+2|0]&7)|C&255;if(s){a[f+(c[9648736+(w<<2)>>2]|0)|0]=B&255;return}w=B&255;B=c[2426956]&1048575;s=c[3531864]|0;C=c[s+2092+(B>>>11<<2)>>2]|0;if((C|0)==0){gg[c[s+8240>>2]&4095](B,w);return}else{a[C+B|0]=w;return}break};case 21:{w=e[h>>1]<<4;B=(c[2385310]|0)+28|0;C=b[B>>1]|0;b[B>>1]=C+1&65535;B=(C&65535)+w&1048575;w=c[3531864]|0;C=c[w+6188+(B>>>11<<2)>>2]|0;if((C|0)==0){D=gj[c[w+8236>>2]&4095](B)|0}else{D=a[C+B|0]|0}B=D&255;C=(D&255)>191;if(C){E=e[f+(c[9650784+(B<<2)>>2]<<1)>>1]|0}else{D=c[679712+(B<<2)>>2]|0;gj[D&4095](f)|0;D=c[2426956]|0;w=D&1048575;s=c[3531864]|0;A=c[s+44+(w>>>11<<2)>>2]|0;if((A|0)==0){z=gj[c[s+8236>>2]&4095](w)|0;F=z;G=c[2426956]|0;H=c[3531864]|0}else{F=a[A+w|0]|0;G=D;H=s}s=G+1&1048575;G=c[H+44+(s>>>11<<2)>>2]|0;if((G|0)==0){I=gj[c[H+8236>>2]&4095](s)|0}else{I=a[G+s|0]|0}E=(I&255)<<8|F&255}F=f+84|0;c[F>>2]=(c[F>>2]|0)-(263172>>>((c[f+92>>2]|0)>>>0)&127);F=1<<(a[f+2|0]&15)|E;if(C){b[f+(c[9650784+(B<<2)>>2]<<1)>>1]=F&65535;return}B=c[2426956]|0;C=F&255;E=B&1048575;I=c[3531864]|0;s=c[I+2092+(E>>>11<<2)>>2]|0;if((s|0)==0){gg[c[I+8240>>2]&4095](E,C);J=c[3531864]|0}else{a[s+E|0]=C;J=I}I=(F&65535)>>>8&255;F=B+1&1048575;B=c[J+2092+(F>>>11<<2)>>2]|0;if((B|0)==0){gg[c[J+8240>>2]&4095](F,I);return}else{a[B+F|0]=I;return}break};case 22:{I=e[h>>1]<<4;F=(c[2385310]|0)+28|0;B=b[F>>1]|0;b[F>>1]=B+1&65535;F=(B&65535)+I&1048575;I=c[3531864]|0;B=c[I+6188+(F>>>11<<2)>>2]|0;if((B|0)==0){K=gj[c[I+8236>>2]&4095](F)|0}else{K=a[B+F|0]|0}F=K&255;B=(K&255)>191;if(B){K=f;L=a[K+(c[9648736+(F<<2)>>2]|0)|0]|0;M=K}else{K=c[679712+(F<<2)>>2]|0;gj[K&4095](f)|0;K=c[2426956]&1048575;I=c[3531864]|0;J=c[I+44+(K>>>11<<2)>>2]|0;if((J|0)==0){N=gj[c[I+8236>>2]&4095](K)|0}else{N=a[J+K|0]|0}L=N;M=f}N=L&255;L=f+84|0;c[L>>2]=(c[L>>2]|0)-(263172>>>((c[f+92>>2]|0)>>>0)&127);L=1<<(a[f+2|0]&7);if((L&N|0)==0){O=L|N}else{O=(L^255)&N}N=O&255;if(B){a[M+(c[9648736+(F<<2)>>2]|0)|0]=N;return}F=c[2426956]&1048575;M=c[3531864]|0;B=c[M+2092+(F>>>11<<2)>>2]|0;if((B|0)==0){gg[c[M+8240>>2]&4095](F,N);return}else{a[B+F|0]=N;return}break};case 23:{N=e[h>>1]<<4;F=(c[2385310]|0)+28|0;B=b[F>>1]|0;b[F>>1]=B+1&65535;F=(B&65535)+N&1048575;N=c[3531864]|0;B=c[N+6188+(F>>>11<<2)>>2]|0;if((B|0)==0){P=gj[c[N+8236>>2]&4095](F)|0}else{P=a[B+F|0]|0}F=P&255;B=(P&255)>191;if(B){Q=e[f+(c[9650784+(F<<2)>>2]<<1)>>1]|0}else{P=c[679712+(F<<2)>>2]|0;gj[P&4095](f)|0;P=c[2426956]|0;N=P&1048575;M=c[3531864]|0;O=c[M+44+(N>>>11<<2)>>2]|0;if((O|0)==0){L=gj[c[M+8236>>2]&4095](N)|0;R=L;S=c[2426956]|0;T=c[3531864]|0}else{R=a[O+N|0]|0;S=P;T=M}M=S+1&1048575;S=c[T+44+(M>>>11<<2)>>2]|0;if((S|0)==0){U=gj[c[T+8236>>2]&4095](M)|0}else{U=a[S+M|0]|0}Q=(U&255)<<8|R&255}R=f+84|0;c[R>>2]=(c[R>>2]|0)-(263172>>>((c[f+92>>2]|0)>>>0)&127);R=1<<(a[f+2|0]&15);if((R&Q|0)==0){V=R|Q}else{V=(R^65535)&Q}Q=V&65535;if(B){b[f+(c[9650784+(F<<2)>>2]<<1)>>1]=Q;return}F=c[2426956]|0;B=Q&255;V=F&1048575;R=c[3531864]|0;U=c[R+2092+(V>>>11<<2)>>2]|0;if((U|0)==0){gg[c[R+8240>>2]&4095](V,B);W=c[3531864]|0}else{a[U+V|0]=B;W=R}R=(Q&65535)>>>8&255;Q=F+1&1048575;F=c[W+2092+(Q>>>11<<2)>>2]|0;if((F|0)==0){gg[c[W+8240>>2]&4095](Q,R);return}else{a[F+Q|0]=R;return}break};case 24:{R=e[h>>1]<<4;Q=(c[2385310]|0)+28|0;F=b[Q>>1]|0;b[Q>>1]=F+1&65535;Q=(F&65535)+R&1048575;R=c[3531864]|0;F=c[R+6188+(Q>>>11<<2)>>2]|0;if((F|0)==0){X=gj[c[R+8236>>2]&4095](Q)|0}else{X=a[F+Q|0]|0}Q=X&255;do{if((X&255)>191){Y=a[f+(c[9648736+(Q<<2)>>2]|0)|0]|0}else{F=c[679712+(Q<<2)>>2]|0;gj[F&4095](f)|0;F=c[2426956]&1048575;R=c[3531864]|0;W=c[R+44+(F>>>11<<2)>>2]|0;if((W|0)==0){Y=gj[c[R+8236>>2]&4095](F)|0;break}else{Y=a[W+F|0]|0;break}}}while(0);Q=f+84|0;c[Q>>2]=(c[Q>>2]|0)-(263172>>>((c[f+92>>2]|0)>>>0)&127);Q=e[h>>1]<<4;X=(c[2385310]|0)+28|0;F=b[X>>1]|0;b[X>>1]=F+1&65535;X=(F&65535)+Q&1048575;Q=c[3531864]|0;F=c[Q+6188+(X>>>11<<2)>>2]|0;if((F|0)==0){Z=gj[c[Q+8236>>2]&4095](X)|0}else{Z=a[F+X|0]|0}c[f+44>>2]=(1<<(Z&7)&(Y&255)|0)!=0;c[f+40>>2]=0;c[f+48>>2]=0;return};case 25:{Y=e[h>>1]<<4;Z=(c[2385310]|0)+28|0;X=b[Z>>1]|0;b[Z>>1]=X+1&65535;Z=(X&65535)+Y&1048575;Y=c[3531864]|0;X=c[Y+6188+(Z>>>11<<2)>>2]|0;if((X|0)==0){_=gj[c[Y+8236>>2]&4095](Z)|0}else{_=a[X+Z|0]|0}Z=_&255;if((_&255)>191){$=e[f+(c[9650784+(Z<<2)>>2]<<1)>>1]|0}else{_=c[679712+(Z<<2)>>2]|0;gj[_&4095](f)|0;_=c[2426956]|0;Z=_&1048575;X=c[3531864]|0;Y=c[X+44+(Z>>>11<<2)>>2]|0;if((Y|0)==0){F=gj[c[X+8236>>2]&4095](Z)|0;aa=F;ab=c[2426956]|0;ac=c[3531864]|0}else{aa=a[Y+Z|0]|0;ab=_;ac=X}X=ab+1&1048575;ab=c[ac+44+(X>>>11<<2)>>2]|0;if((ab|0)==0){ad=gj[c[ac+8236>>2]&4095](X)|0}else{ad=a[ab+X|0]|0}$=(ad&255)<<8|aa&255}aa=f+84|0;c[aa>>2]=(c[aa>>2]|0)-(263172>>>((c[f+92>>2]|0)>>>0)&127);aa=e[h>>1]<<4;ad=(c[2385310]|0)+28|0;X=b[ad>>1]|0;b[ad>>1]=X+1&65535;ad=(X&65535)+aa&1048575;aa=c[3531864]|0;X=c[aa+6188+(ad>>>11<<2)>>2]|0;if((X|0)==0){ae=gj[c[aa+8236>>2]&4095](ad)|0}else{ae=a[X+ad|0]|0}c[f+44>>2]=(1<<(ae&15)&$|0)!=0;c[f+40>>2]=0;c[f+48>>2]=0;return};case 26:{$=e[h>>1]<<4;ae=(c[2385310]|0)+28|0;ad=b[ae>>1]|0;b[ae>>1]=ad+1&65535;ae=(ad&65535)+$&1048575;$=c[3531864]|0;ad=c[$+6188+(ae>>>11<<2)>>2]|0;if((ad|0)==0){af=gj[c[$+8236>>2]&4095](ae)|0}else{af=a[ad+ae|0]|0}ae=af&255;ad=(af&255)>191;do{if(ad){ag=a[f+(c[9648736+(ae<<2)>>2]|0)|0]|0}else{af=c[679712+(ae<<2)>>2]|0;gj[af&4095](f)|0;af=c[2426956]&1048575;$=c[3531864]|0;X=c[$+44+(af>>>11<<2)>>2]|0;if((X|0)==0){ag=gj[c[$+8236>>2]&4095](af)|0;break}else{ag=a[X+af|0]|0;break}}}while(0);af=f+84|0;c[af>>2]=(c[af>>2]|0)-(394756>>>((c[f+92>>2]|0)>>>0)&127);af=e[h>>1]<<4;X=(c[2385310]|0)+28|0;$=b[X>>1]|0;b[X>>1]=$+1&65535;X=($&65535)+af&1048575;af=c[3531864]|0;$=c[af+6188+(X>>>11<<2)>>2]|0;if(($|0)==0){ah=gj[c[af+8236>>2]&4095](X)|0}else{ah=a[$+X|0]|0}X=ag&255&~(1<<(ah&7));if(ad){a[f+(c[9648736+(ae<<2)>>2]|0)|0]=X&255;return}ae=X&255;X=c[2426956]&1048575;ad=c[3531864]|0;ah=c[ad+2092+(X>>>11<<2)>>2]|0;if((ah|0)==0){gg[c[ad+8240>>2]&4095](X,ae);return}else{a[ah+X|0]=ae;return}break};case 27:{ae=e[h>>1]<<4;X=(c[2385310]|0)+28|0;ah=b[X>>1]|0;b[X>>1]=ah+1&65535;X=(ah&65535)+ae&1048575;ae=c[3531864]|0;ah=c[ae+6188+(X>>>11<<2)>>2]|0;if((ah|0)==0){ai=gj[c[ae+8236>>2]&4095](X)|0}else{ai=a[ah+X|0]|0}X=ai&255;ah=(ai&255)>191;if(ah){aj=e[f+(c[9650784+(X<<2)>>2]<<1)>>1]|0}else{ai=c[679712+(X<<2)>>2]|0;gj[ai&4095](f)|0;ai=c[2426956]|0;ae=ai&1048575;ad=c[3531864]|0;ag=c[ad+44+(ae>>>11<<2)>>2]|0;if((ag|0)==0){$=gj[c[ad+8236>>2]&4095](ae)|0;ak=$;al=c[2426956]|0;am=c[3531864]|0}else{ak=a[ag+ae|0]|0;al=ai;am=ad}ad=al+1&1048575;al=c[am+44+(ad>>>11<<2)>>2]|0;if((al|0)==0){an=gj[c[am+8236>>2]&4095](ad)|0}else{an=a[al+ad|0]|0}aj=(an&255)<<8|ak&255}ak=f+84|0;c[ak>>2]=(c[ak>>2]|0)-(394756>>>((c[f+92>>2]|0)>>>0)&127);ak=e[h>>1]<<4;an=(c[2385310]|0)+28|0;ad=b[an>>1]|0;b[an>>1]=ad+1&65535;an=(ad&65535)+ak&1048575;ak=c[3531864]|0;ad=c[ak+6188+(an>>>11<<2)>>2]|0;if((ad|0)==0){ao=gj[c[ak+8236>>2]&4095](an)|0}else{ao=a[ad+an|0]|0}an=aj&~(1<<(ao&15));if(ah){b[f+(c[9650784+(X<<2)>>2]<<1)>>1]=an&65535;return}X=c[2426956]|0;ah=an&255;ao=X&1048575;aj=c[3531864]|0;ad=c[aj+2092+(ao>>>11<<2)>>2]|0;if((ad|0)==0){gg[c[aj+8240>>2]&4095](ao,ah);ap=c[3531864]|0}else{a[ad+ao|0]=ah;ap=aj}aj=(an&65535)>>>8&255;an=X+1&1048575;X=c[ap+2092+(an>>>11<<2)>>2]|0;if((X|0)==0){gg[c[ap+8240>>2]&4095](an,aj);return}else{a[X+an|0]=aj;return}break};case 28:{aj=e[h>>1]<<4;an=(c[2385310]|0)+28|0;X=b[an>>1]|0;b[an>>1]=X+1&65535;an=(X&65535)+aj&1048575;aj=c[3531864]|0;X=c[aj+6188+(an>>>11<<2)>>2]|0;if((X|0)==0){aq=gj[c[aj+8236>>2]&4095](an)|0}else{aq=a[X+an|0]|0}an=aq&255;X=(aq&255)>191;do{if(X){ar=a[f+(c[9648736+(an<<2)>>2]|0)|0]|0}else{aq=c[679712+(an<<2)>>2]|0;gj[aq&4095](f)|0;aq=c[2426956]&1048575;aj=c[3531864]|0;ap=c[aj+44+(aq>>>11<<2)>>2]|0;if((ap|0)==0){ar=gj[c[aj+8236>>2]&4095](aq)|0;break}else{ar=a[ap+aq|0]|0;break}}}while(0);aq=f+84|0;c[aq>>2]=(c[aq>>2]|0)-(328964>>>((c[f+92>>2]|0)>>>0)&127);aq=e[h>>1]<<4;ap=(c[2385310]|0)+28|0;aj=b[ap>>1]|0;b[ap>>1]=aj+1&65535;ap=(aj&65535)+aq&1048575;aq=c[3531864]|0;aj=c[aq+6188+(ap>>>11<<2)>>2]|0;if((aj|0)==0){as=gj[c[aq+8236>>2]&4095](ap)|0}else{as=a[aj+ap|0]|0}ap=1<<(as&7)|ar&255;if(X){a[f+(c[9648736+(an<<2)>>2]|0)|0]=ap&255;return}an=ap&255;ap=c[2426956]&1048575;X=c[3531864]|0;ar=c[X+2092+(ap>>>11<<2)>>2]|0;if((ar|0)==0){gg[c[X+8240>>2]&4095](ap,an);return}else{a[ar+ap|0]=an;return}break};case 29:{an=e[h>>1]<<4;ap=(c[2385310]|0)+28|0;ar=b[ap>>1]|0;b[ap>>1]=ar+1&65535;ap=(ar&65535)+an&1048575;an=c[3531864]|0;ar=c[an+6188+(ap>>>11<<2)>>2]|0;if((ar|0)==0){at=gj[c[an+8236>>2]&4095](ap)|0}else{at=a[ar+ap|0]|0}ap=at&255;ar=(at&255)>191;if(ar){au=e[f+(c[9650784+(ap<<2)>>2]<<1)>>1]|0}else{at=c[679712+(ap<<2)>>2]|0;gj[at&4095](f)|0;at=c[2426956]|0;an=at&1048575;X=c[3531864]|0;as=c[X+44+(an>>>11<<2)>>2]|0;if((as|0)==0){aj=gj[c[X+8236>>2]&4095](an)|0;av=aj;aw=c[2426956]|0;ax=c[3531864]|0}else{av=a[as+an|0]|0;aw=at;ax=X}X=aw+1&1048575;aw=c[ax+44+(X>>>11<<2)>>2]|0;if((aw|0)==0){ay=gj[c[ax+8236>>2]&4095](X)|0}else{ay=a[aw+X|0]|0}au=(ay&255)<<8|av&255}av=f+84|0;c[av>>2]=(c[av>>2]|0)-(328964>>>((c[f+92>>2]|0)>>>0)&127);av=e[h>>1]<<4;ay=(c[2385310]|0)+28|0;X=b[ay>>1]|0;b[ay>>1]=X+1&65535;ay=(X&65535)+av&1048575;av=c[3531864]|0;X=c[av+6188+(ay>>>11<<2)>>2]|0;if((X|0)==0){az=gj[c[av+8236>>2]&4095](ay)|0}else{az=a[X+ay|0]|0}ay=1<<(az&15)|au;if(ar){b[f+(c[9650784+(ap<<2)>>2]<<1)>>1]=ay&65535;return}ap=c[2426956]|0;ar=ay&255;au=ap&1048575;az=c[3531864]|0;X=c[az+2092+(au>>>11<<2)>>2]|0;if((X|0)==0){gg[c[az+8240>>2]&4095](au,ar);aA=c[3531864]|0}else{a[X+au|0]=ar;aA=az}az=(ay&65535)>>>8&255;ay=ap+1&1048575;ap=c[aA+2092+(ay>>>11<<2)>>2]|0;if((ap|0)==0){gg[c[aA+8240>>2]&4095](ay,az);return}else{a[ap+ay|0]=az;return}break};case 30:{az=e[h>>1]<<4;ay=(c[2385310]|0)+28|0;ap=b[ay>>1]|0;b[ay>>1]=ap+1&65535;ay=(ap&65535)+az&1048575;az=c[3531864]|0;ap=c[az+6188+(ay>>>11<<2)>>2]|0;if((ap|0)==0){aB=gj[c[az+8236>>2]&4095](ay)|0}else{aB=a[ap+ay|0]|0}ay=aB&255;ap=(aB&255)>191;do{if(ap){aC=a[f+(c[9648736+(ay<<2)>>2]|0)|0]|0}else{aB=c[679712+(ay<<2)>>2]|0;gj[aB&4095](f)|0;aB=c[2426956]&1048575;az=c[3531864]|0;aA=c[az+44+(aB>>>11<<2)>>2]|0;if((aA|0)==0){aC=gj[c[az+8236>>2]&4095](aB)|0;break}else{aC=a[aA+aB|0]|0;break}}}while(0);aB=aC&255;aC=f+84|0;c[aC>>2]=(c[aC>>2]|0)-(328964>>>((c[f+92>>2]|0)>>>0)&127);aC=e[h>>1]<<4;aA=(c[2385310]|0)+28|0;az=b[aA>>1]|0;b[aA>>1]=az+1&65535;aA=(az&65535)+aC&1048575;aC=c[3531864]|0;az=c[aC+6188+(aA>>>11<<2)>>2]|0;if((az|0)==0){aD=gj[c[aC+8236>>2]&4095](aA)|0}else{aD=a[az+aA|0]|0}aA=1<<(aD&7);if((aA&aB|0)==0){aE=aA|aB}else{aE=(aA^255)&aB}aB=aE&255;if(ap){a[f+(c[9648736+(ay<<2)>>2]|0)|0]=aB;return}ay=c[2426956]&1048575;ap=c[3531864]|0;aE=c[ap+2092+(ay>>>11<<2)>>2]|0;if((aE|0)==0){gg[c[ap+8240>>2]&4095](ay,aB);return}else{a[aE+ay|0]=aB;return}break};case 31:{aB=e[h>>1]<<4;ay=(c[2385310]|0)+28|0;aE=b[ay>>1]|0;b[ay>>1]=aE+1&65535;ay=(aE&65535)+aB&1048575;aB=c[3531864]|0;aE=c[aB+6188+(ay>>>11<<2)>>2]|0;if((aE|0)==0){aF=gj[c[aB+8236>>2]&4095](ay)|0}else{aF=a[aE+ay|0]|0}ay=aF&255;aE=(aF&255)>191;if(aE){aG=e[f+(c[9650784+(ay<<2)>>2]<<1)>>1]|0}else{aF=c[679712+(ay<<2)>>2]|0;gj[aF&4095](f)|0;aF=c[2426956]|0;aB=aF&1048575;ap=c[3531864]|0;aA=c[ap+44+(aB>>>11<<2)>>2]|0;if((aA|0)==0){aD=gj[c[ap+8236>>2]&4095](aB)|0;aH=aD;aI=c[2426956]|0;aJ=c[3531864]|0}else{aH=a[aA+aB|0]|0;aI=aF;aJ=ap}ap=aI+1&1048575;aI=c[aJ+44+(ap>>>11<<2)>>2]|0;if((aI|0)==0){aK=gj[c[aJ+8236>>2]&4095](ap)|0}else{aK=a[aI+ap|0]|0}aG=(aK&255)<<8|aH&255}aH=f+84|0;c[aH>>2]=(c[aH>>2]|0)-(328964>>>((c[f+92>>2]|0)>>>0)&127);aH=e[h>>1]<<4;aK=(c[2385310]|0)+28|0;ap=b[aK>>1]|0;b[aK>>1]=ap+1&65535;aK=(ap&65535)+aH&1048575;aH=c[3531864]|0;ap=c[aH+6188+(aK>>>11<<2)>>2]|0;if((ap|0)==0){aL=gj[c[aH+8236>>2]&4095](aK)|0}else{aL=a[ap+aK|0]|0}aK=1<<(aL&15);if((aK&aG|0)==0){aM=aK|aG}else{aM=(aK^65535)&aG}aG=aM&65535;if(aE){b[f+(c[9650784+(ay<<2)>>2]<<1)>>1]=aG;return}ay=c[2426956]|0;aE=aG&255;aM=ay&1048575;aK=c[3531864]|0;aL=c[aK+2092+(aM>>>11<<2)>>2]|0;if((aL|0)==0){gg[c[aK+8240>>2]&4095](aM,aE);aN=c[3531864]|0}else{a[aL+aM|0]=aE;aN=aK}aK=(aG&65535)>>>8&255;aG=ay+1&1048575;ay=c[aN+2092+(aG>>>11<<2)>>2]|0;if((ay|0)==0){gg[c[aN+8240>>2]&4095](aG,aK);return}else{a[ay+aG|0]=aK;return}break};case 32:{aK=((d[f+2|0]|0)+1|0)>>>1;aG=b[f+14>>1]|0;ay=b[f+12>>1]|0;aN=f+48|0;c[aN>>2]=0;aE=f+44|0;c[aE>>2]=0;aM=f+92|0;aL=c[aM>>2]|0;if((aK|0)==0){aO=aL;aP=f+84|0}else{ap=f+84|0;aH=f+100|0;aI=f+26|0;aJ=g|0;aF=f+96|0;aB=ay&65535;ay=aG&65535;aG=0;aA=aL;while(1){c[ap>>2]=(c[ap>>2]|0)-(d[591216+(aA>>>3)|0]|0);if((a[aH]|0)==0){aQ=e[aI>>1]<<4}else{aQ=c[aF>>2]|0}aL=aQ+aB&1048575;aD=c[3531864]|0;az=c[aD+44+(aL>>>11<<2)>>2]|0;if((az|0)==0){aC=gj[c[aD+8236>>2]&4095](aL)|0;aR=aC;aS=c[3531864]|0}else{aR=a[az+aL|0]|0;aS=aD}aD=aR&255;aL=b[aJ>>1]|0;az=((aL&65535)<<4)+ay&1048575;aC=c[aS+44+(az>>>11<<2)>>2]|0;if((aC|0)==0){ar=gj[c[aS+8236>>2]&4095](az)|0;aT=ar;aU=b[aJ>>1]|0;aV=c[3531864]|0}else{aT=a[aC+az|0]|0;aU=aL;aV=aS}aL=aT&255;az=(c[aN>>2]|0)+(aD&15)+(aL&15)+(((aL>>>4)+(aD>>>4)|0)*10|0)|0;c[aN>>2]=(az|0)>99;aD=(az|0)%100|0;az=((aD|0)/10|0)<<4|((aD|0)%10|0);aD=az&255;aL=((aU&65535)<<4)+ay&1048575;aC=c[aV+2092+(aL>>>11<<2)>>2]|0;if((aC|0)==0){gg[c[aV+8240>>2]&4095](aL,aD)}else{a[aC+aL|0]=aD}if((az|0)!=0){c[aE>>2]=1}az=aG+1|0;aD=c[aM>>2]|0;if((az|0)<(aK|0)){aB=aB+1|0;ay=ay+1|0;aG=az;aA=aD}else{aO=aD;aP=ap;break}}}c[aP>>2]=(c[aP>>2]|0)-(460546>>>(aO>>>0)&127);return};case 34:{aO=((d[f+2|0]|0)+1|0)>>>1;aP=b[f+14>>1]|0;ap=b[f+12>>1]|0;aA=f+48|0;c[aA>>2]=0;aG=f+44|0;c[aG>>2]=0;ay=f+92|0;aB=c[ay>>2]|0;L55305:do{if((aO|0)==0){aW=aB;aX=f+84|0}else{aK=f+84|0;aM=f+100|0;aE=g|0;aV=f+26|0;aU=f+96|0;aN=aP&65535;aT=ap&65535;aS=1;aJ=aB;while(1){c[aK>>2]=(c[aK>>2]|0)-(d[591216+(aJ>>>3)|0]|0);aR=(e[aE>>1]<<4)+aN&1048575;aQ=c[3531864]|0;aF=c[aQ+44+(aR>>>11<<2)>>2]|0;if((aF|0)==0){aY=gj[c[aQ+8236>>2]&4095](aR)|0}else{aY=a[aF+aR|0]|0}aR=aY&255;if((a[aM]|0)==0){aZ=e[aV>>1]<<4}else{aZ=c[aU>>2]|0}aF=aZ+aT&1048575;aQ=c[3531864]|0;aI=c[aQ+44+(aF>>>11<<2)>>2]|0;if((aI|0)==0){aH=gj[c[aQ+8236>>2]&4095](aF)|0;a_=aH;a$=c[3531864]|0}else{a_=a[aI+aF|0]|0;a$=aQ}aQ=a_&255;aF=((aR>>>4)*10|0)+(aR&15)|0;aR=(aQ&15)+(c[aA>>2]|0)+((aQ>>>4)*10|0)|0;aQ=aF>>>0<aR>>>0;aI=(aQ?aF+100|0:aF)-aR|0;c[aA>>2]=aQ&1;aQ=((aI>>>0)/10|0)<<4|((aI>>>0)%10|0);aI=aQ&255;aR=(e[aE>>1]<<4)+aN&1048575;aF=c[a$+2092+(aR>>>11<<2)>>2]|0;if((aF|0)==0){gg[c[a$+8240>>2]&4095](aR,aI)}else{a[aF+aR|0]=aI}if((aQ|0)!=0){c[aG>>2]=1}aQ=c[ay>>2]|0;if((aS|0)>=(aO|0)){aW=aQ;aX=aK;break L55305}aN=aN+1|0;aT=aT+1|0;aS=aS+1|0;aJ=aQ}}}while(0);c[aX>>2]=(c[aX>>2]|0)-(460546>>>(aW>>>0)&127);return};case 38:{aW=((d[f+2|0]|0)+1|0)>>>1;aX=b[f+14>>1]|0;aO=b[f+12>>1]|0;ay=f+48|0;c[ay>>2]=0;aG=f+44|0;c[aG>>2]=0;a$=f+92|0;aA=c[a$>>2]|0;L55333:do{if((aW|0)==0){a0=aA;a1=f+84|0}else{a_=f+84|0;aZ=f+100|0;aY=g|0;aB=f+26|0;ap=f+96|0;aP=1;aJ=aX&65535;aS=aO&65535;aT=aA;while(1){c[a_>>2]=(c[a_>>2]|0)-(d[591208+(aT>>>3)|0]|0);aN=(e[aY>>1]<<4)+aJ&1048575;aK=c[3531864]|0;aE=c[aK+44+(aN>>>11<<2)>>2]|0;if((aE|0)==0){a2=gj[c[aK+8236>>2]&4095](aN)|0}else{a2=a[aE+aN|0]|0}aN=a2&255;if((a[aZ]|0)==0){a3=e[aB>>1]<<4}else{a3=c[ap>>2]|0}aE=a3+aS&1048575;aK=c[3531864]|0;aU=c[aK+44+(aE>>>11<<2)>>2]|0;if((aU|0)==0){a4=gj[c[aK+8236>>2]&4095](aE)|0}else{a4=a[aU+aE|0]|0}aE=a4&255;aU=((aN>>>4)*10|0)+(aN&15)|0;aN=(aE&15)+(c[ay>>2]|0)+((aE>>>4)*10|0)|0;aE=aU>>>0<aN>>>0;aK=(aE?aU+100|0:aU)-aN|0;c[ay>>2]=aE&1;if((((aK>>>0)/10|0)<<4|((aK>>>0)%10|0)|0)!=0){c[aG>>2]=1}aK=c[a$>>2]|0;if((aP|0)>=(aW|0)){a0=aK;a1=a_;break L55333}aP=aP+1|0;aJ=aJ+1|0;aS=aS+1|0;aT=aK}}}while(0);c[a1>>2]=(c[a1>>2]|0)-(460546>>>(a0>>>0)&127);return};case 40:{a0=e[h>>1]<<4;a1=(c[2385310]|0)+28|0;aW=b[a1>>1]|0;b[a1>>1]=aW+1&65535;a1=(aW&65535)+a0&1048575;a0=c[3531864]|0;aW=c[a0+6188+(a1>>>11<<2)>>2]|0;if((aW|0)==0){a5=gj[c[a0+8236>>2]&4095](a1)|0}else{a5=a[aW+a1|0]|0}a1=a5&255;aW=(a5&255)>191;do{if(aW){a6=a[f+(c[9648736+(a1<<2)>>2]|0)|0]|0}else{a5=(gj[c[679712+(a1<<2)>>2]&4095](f)|0)&1048575;a0=c[3531864]|0;a$=c[a0+44+(a5>>>11<<2)>>2]|0;if((a$|0)==0){a6=gj[c[a0+8236>>2]&4095](a5)|0;break}else{a6=a[a$+a5|0]|0;break}}}while(0);a5=f;a$=a[a5]|0;a[a5]=a$&-16|(a6&255)>>>4;a5=(a6&255)<<4&240|a$&15;do{if(aW){a[f+(c[9648736+(a1<<2)>>2]|0)|0]=a5&255}else{a$=a5&255;a6=c[2426956]&1048575;a0=c[3531864]|0;aG=c[a0+2092+(a6>>>11<<2)>>2]|0;if((aG|0)==0){gg[c[a0+8240>>2]&4095](a6,a$);break}else{a[aG+a6|0]=a$;break}}}while(0);a5=f+84|0;c[a5>>2]=(c[a5>>2]|0)-((aW?855305:1842191)>>>((c[f+92>>2]|0)>>>0)&127);return};case 42:{aW=e[h>>1]<<4;a5=(c[2385310]|0)+28|0;a1=b[a5>>1]|0;b[a5>>1]=a1+1&65535;a5=(a1&65535)+aW&1048575;aW=c[3531864]|0;a1=c[aW+6188+(a5>>>11<<2)>>2]|0;if((a1|0)==0){a7=gj[c[aW+8236>>2]&4095](a5)|0}else{a7=a[a1+a5|0]|0}a5=a7&255;a1=(a7&255)>191;do{if(a1){a8=a[f+(c[9648736+(a5<<2)>>2]|0)|0]|0}else{a7=(gj[c[679712+(a5<<2)>>2]&4095](f)|0)&1048575;aW=c[3531864]|0;a$=c[aW+44+(a7>>>11<<2)>>2]|0;if((a$|0)==0){a8=gj[c[aW+8236>>2]&4095](a7)|0;break}else{a8=a[a$+a7|0]|0;break}}}while(0);a7=f;a$=a[a7]|0;a[a7]=a$&-16|a8&15;a7=(a$&255)<<4&240|(a8&255)>>>4;do{if(a1){a[f+(c[9648736+(a5<<2)>>2]|0)|0]=a7&255}else{a8=a7&255;a$=c[2426956]&1048575;aW=c[3531864]|0;a6=c[aW+2092+(a$>>>11<<2)>>2]|0;if((a6|0)==0){gg[c[aW+8240>>2]&4095](a$,a8);break}else{a[a6+a$|0]=a8;break}}}while(0);a7=f+84|0;c[a7>>2]=(c[a7>>2]|0)-((a1?1118477:2105363)>>>((c[f+92>>2]|0)>>>0)&127);return};case 49:{a1=e[h>>1]<<4;a7=(c[2385310]|0)+28|0;a5=b[a7>>1]|0;b[a7>>1]=a5+1&65535;a7=(a5&65535)+a1&1048575;a1=c[3531864]|0;if((c[a1+6188+(a7>>>11<<2)>>2]|0)!=0){return}gj[c[a1+8236>>2]&4095](a7)|0;return};case 51:{a7=e[h>>1]<<4;a1=(c[2385310]|0)+28|0;a5=b[a1>>1]|0;b[a1>>1]=a5+1&65535;a1=(a5&65535)+a7&1048575;a7=c[3531864]|0;if((c[a7+6188+(a1>>>11<<2)>>2]|0)!=0){return}gj[c[a7+8236>>2]&4095](a1)|0;return};case 224:{a1=e[h>>1]<<4;a7=(c[2385310]|0)+28|0;a5=b[a7>>1]|0;b[a7>>1]=a5+1&65535;a7=(a5&65535)+a1&1048575;a1=c[3531864]|0;if((c[a1+6188+(a7>>>11<<2)>>2]|0)!=0){return}gj[c[a1+8236>>2]&4095](a7)|0;return};case 240:{a7=e[h>>1]<<4;a1=(c[2385310]|0)+28|0;a5=b[a1>>1]|0;b[a1>>1]=a5+1&65535;a1=(a5&65535)+a7&1048575;a7=c[3531864]|0;if((c[a7+6188+(a1>>>11<<2)>>2]|0)!=0){return}gj[c[a7+8236>>2]&4095](a1)|0;return};case 255:{a1=e[h>>1]<<4;a7=(c[2385310]|0)+28|0;a5=b[a7>>1]|0;b[a7>>1]=a5+1&65535;a7=(a5&65535)+a1&1048575;a1=c[3531864]|0;if((c[a1+6188+(a7>>>11<<2)>>2]|0)!=0){return}gj[c[a1+8236>>2]&4095](a7)|0;return};case 16:{a7=e[h>>1]<<4;h=(c[2385310]|0)+28|0;a1=b[h>>1]|0;b[h>>1]=a1+1&65535;h=(a1&65535)+a7&1048575;a7=c[3531864]|0;a1=c[a7+6188+(h>>>11<<2)>>2]|0;if((a1|0)==0){a9=gj[c[a7+8236>>2]&4095](h)|0}else{a9=a[a1+h|0]|0}h=a9&255;do{if((a9&255)>191){ba=a[f+(c[9648736+(h<<2)>>2]|0)|0]|0}else{a1=c[679712+(h<<2)>>2]|0;gj[a1&4095](f)|0;a1=c[2426956]&1048575;a7=c[3531864]|0;a5=c[a7+44+(a1>>>11<<2)>>2]|0;if((a5|0)==0){ba=gj[c[a7+8236>>2]&4095](a1)|0;break}else{ba=a[a5+a1|0]|0;break}}}while(0);h=f+84|0;c[h>>2]=(c[h>>2]|0)-(197380>>>((c[f+92>>2]|0)>>>0)&127);c[f+44>>2]=(1<<(a[f+2|0]&7)&(ba&255)|0)!=0;c[f+40>>2]=0;c[f+48>>2]=0;return};default:{return}}}function f5x(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=(e[f+22>>1]|0)<<4;h=(c[2385310]|0)+28|0;i=b[h>>1]|0;b[h>>1]=i+1&65535;h=(i&65535)+g&1048575;g=c[3531864]|0;i=c[g+6188+(h>>>11<<2)>>2]|0;if((i|0)==0){j=gj[c[g+8236>>2]&4095](h)|0}else{j=a[i+h|0]|0}h=j&255;i=f;g=d[i+(c[9652832+(h<<2)>>2]|0)|0]|0;k=(j&255)>191;do{if(k){l=a[i+(c[9648736+(h<<2)>>2]|0)|0]|0}else{j=(gj[c[679712+(h<<2)>>2]&4095](f)|0)&1048575;m=c[3531864]|0;n=c[m+44+(j>>>11<<2)>>2]|0;if((n|0)==0){l=gj[c[m+8236>>2]&4095](j)|0;break}else{l=a[n+j|0]|0;break}}}while(0);j=l&255;l=f+48|0;n=((c[l>>2]|0)!=0)+g|0;g=n+j|0;c[l>>2]=g&256;c[f+40>>2]=(g^j)&128&(g^n);c[f+36>>2]=(n^j^g)&16;j=g<<24>>24;c[f+52>>2]=j;c[f+44>>2]=j;c[f+32>>2]=j;if(k){a[i+(c[9648736+(h<<2)>>2]|0)|0]=g&255;o=f+92|0;p=c[o>>2]|0;q=k?131586:1052679;r=q>>>(p>>>0);s=r&127;t=f+84|0;u=c[t>>2]|0;v=u-s|0;c[t>>2]=v;return}h=g&255;g=c[2426956]&1048575;i=c[3531864]|0;j=c[i+2092+(g>>>11<<2)>>2]|0;if((j|0)==0){gg[c[i+8240>>2]&4095](g,h);o=f+92|0;p=c[o>>2]|0;q=k?131586:1052679;r=q>>>(p>>>0);s=r&127;t=f+84|0;u=c[t>>2]|0;v=u-s|0;c[t>>2]=v;return}else{a[j+g|0]=h;o=f+92|0;p=c[o>>2]|0;q=k?131586:1052679;r=q>>>(p>>>0);s=r&127;t=f+84|0;u=c[t>>2]|0;v=u-s|0;c[t>>2]=v;return}}function f5y(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=(e[d+22>>1]|0)<<4;g=(c[2385310]|0)+28|0;h=b[g>>1]|0;b[g>>1]=h+1&65535;g=(h&65535)+f&1048575;f=c[3531864]|0;h=c[f+6188+(g>>>11<<2)>>2]|0;if((h|0)==0){i=gj[c[f+8236>>2]&4095](g)|0}else{i=a[h+g|0]|0}g=i&255;h=e[d+(c[9654880+(g<<2)>>2]<<1)>>1]|0;f=(i&255)>191;if(f){j=e[d+(c[9650784+(g<<2)>>2]<<1)>>1]|0}else{i=c[679712+(g<<2)>>2]|0;gj[i&4095](d)|0;i=c[2426956]|0;k=i&1048575;l=c[3531864]|0;m=c[l+44+(k>>>11<<2)>>2]|0;if((m|0)==0){n=gj[c[l+8236>>2]&4095](k)|0;o=n;p=c[2426956]|0;q=c[3531864]|0}else{o=a[m+k|0]|0;p=i;q=l}l=p+1&1048575;p=c[q+44+(l>>>11<<2)>>2]|0;if((p|0)==0){r=gj[c[q+8236>>2]&4095](l)|0}else{r=a[p+l|0]|0}j=(r&255)<<8|o&255}o=d+48|0;r=((c[o>>2]|0)!=0)+h|0;h=r+j|0;c[o>>2]=h&65536;c[d+40>>2]=(h^j)&32768&(h^r);c[d+36>>2]=(r^j^h)&16;j=h<<16>>16;c[d+52>>2]=j;c[d+44>>2]=j;c[d+32>>2]=j;if(f){b[d+(c[9650784+(g<<2)>>2]<<1)>>1]=h&65535;g=d+84|0;c[g>>2]=(c[g>>2]|0)-2;return}g=c[2426956]|0;f=h&255;j=g&1048575;r=c[3531864]|0;o=c[r+2092+(j>>>11<<2)>>2]|0;if((o|0)==0){gg[c[r+8240>>2]&4095](j,f);s=c[3531864]|0}else{a[o+j|0]=f;s=r}r=(h&65535)>>>8&255;h=g+1&1048575;g=c[s+2092+(h>>>11<<2)>>2]|0;if((g|0)==0){gg[c[s+8240>>2]&4095](h,r)}else{a[g+h|0]=r}r=d+84|0;c[r>>2]=(c[r>>2]|0)-(((c[2426956]&1|0)!=0?1579019:1576967)>>>((c[d+92>>2]|0)>>>0)&127);return}function f5z(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=(e[f+22>>1]|0)<<4;h=(c[2385310]|0)+28|0;i=b[h>>1]|0;b[h>>1]=i+1&65535;h=(i&65535)+g&1048575;g=c[3531864]|0;i=c[g+6188+(h>>>11<<2)>>2]|0;if((i|0)==0){j=gj[c[g+8236>>2]&4095](h)|0}else{j=a[i+h|0]|0}h=j&255;i=9652832+(h<<2)|0;g=f;k=d[g+(c[i>>2]|0)|0]|0;l=(j&255)>191;do{if(l){m=a[g+(c[9648736+(h<<2)>>2]|0)|0]|0}else{j=(gj[c[679712+(h<<2)>>2]&4095](f)|0)&1048575;n=c[3531864]|0;o=c[n+44+(j>>>11<<2)>>2]|0;if((o|0)==0){m=gj[c[n+8236>>2]&4095](j)|0;break}else{m=a[o+j|0]|0;break}}}while(0);h=f+48|0;j=((c[h>>2]|0)!=0)+(m&255)|0;m=j+k|0;c[h>>2]=m&256;c[f+40>>2]=(m^k)&128&(m^j);c[f+36>>2]=(j^k^m)&16;k=m&255;m=k<<24>>24;c[f+52>>2]=m;c[f+44>>2]=m;c[f+32>>2]=m;a[g+(c[i>>2]|0)|0]=k;k=f+84|0;c[k>>2]=(c[k>>2]|0)-((l?131586:723718)>>>((c[f+92>>2]|0)>>>0)&127);return}function f5A(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=(e[d+22>>1]|0)<<4;g=(c[2385310]|0)+28|0;h=b[g>>1]|0;b[g>>1]=h+1&65535;g=(h&65535)+f&1048575;f=c[3531864]|0;h=c[f+6188+(g>>>11<<2)>>2]|0;if((h|0)==0){i=gj[c[f+8236>>2]&4095](g)|0}else{i=a[h+g|0]|0}g=i&255;h=9654880+(g<<2)|0;f=c[h>>2]|0;j=e[d+(f<<1)>>1]|0;k=(i&255)>191;if(k){l=e[d+(c[9650784+(g<<2)>>2]<<1)>>1]|0;m=f}else{f=c[679712+(g<<2)>>2]|0;gj[f&4095](d)|0;f=c[2426956]|0;g=f&1048575;i=c[3531864]|0;n=c[i+44+(g>>>11<<2)>>2]|0;if((n|0)==0){o=gj[c[i+8236>>2]&4095](g)|0;p=o;q=c[2426956]|0;r=c[3531864]|0}else{p=a[n+g|0]|0;q=f;r=i}i=q+1&1048575;q=c[r+44+(i>>>11<<2)>>2]|0;if((q|0)==0){s=gj[c[r+8236>>2]&4095](i)|0}else{s=a[q+i|0]|0}l=(s&255)<<8|p&255;m=c[h>>2]|0}h=d+48|0;p=((c[h>>2]|0)!=0)+l|0;l=p+j|0;c[h>>2]=l&65536;c[d+40>>2]=(l^j)&32768&(l^p);c[d+36>>2]=(p^j^l)&16;j=l&65535;l=j<<16>>16;c[d+52>>2]=l;c[d+44>>2]=l;c[d+32>>2]=l;b[d+(m<<1)>>1]=j;if(k){k=d+84|0;c[k>>2]=(c[k>>2]|0)-2;return}else{k=d+84|0;c[k>>2]=(c[k>>2]|0)-(((c[2426956]&1|0)!=0?986888:985862)>>>((c[d+92>>2]|0)>>>0)&127);return}}function f5B(f){f=f|0;var g=0,h=0,i=0,j=0,k=0;g=(e[f+22>>1]|0)<<4;h=(c[2385310]|0)+28|0;i=b[h>>1]|0;b[h>>1]=i+1&65535;h=(i&65535)+g&1048575;g=c[3531864]|0;i=c[g+6188+(h>>>11<<2)>>2]|0;if((i|0)==0){j=gj[c[g+8236>>2]&4095](h)|0}else{j=a[i+h|0]|0}h=f;i=d[h]|0;g=f+48|0;k=((c[g>>2]|0)!=0)+(j&255)|0;j=k+i|0;c[g>>2]=j&256;c[f+40>>2]=(j^i)&128&(j^k);c[f+36>>2]=(k^i^j)&16;i=j&255;j=i<<24>>24;c[f+52>>2]=j;c[f+44>>2]=j;c[f+32>>2]=j;a[h]=i;i=f+84|0;c[i>>2]=(c[i>>2]|0)-(263170>>>((c[f+92>>2]|0)>>>0)&127);return}function f5C(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=d+22|0;g=(e[f>>1]|0)<<4;h=c[2385310]|0;i=h+28|0;j=b[i>>1]|0;k=j+1&65535;b[i>>1]=k;i=(j&65535)+g&1048575;g=c[3531864]|0;j=c[g+6188+(i>>>11<<2)>>2]|0;if((j|0)==0){l=gj[c[g+8236>>2]&4095](i)|0;m=c[2385310]|0;n=l;o=m;p=b[m+28>>1]|0;q=c[3531864]|0}else{n=a[j+i|0]|0;o=h;p=k;q=g}g=d|0;k=e[g>>1]|0;h=(e[f>>1]|0)<<4;b[o+28>>1]=p+1&65535;o=(p&65535)+h&1048575;h=c[q+6188+(o>>>11<<2)>>2]|0;if((h|0)==0){r=gj[c[q+8236>>2]&4095](o)|0}else{r=a[h+o|0]|0}o=d+48|0;h=((r&255)<<8|n&255)+((c[o>>2]|0)!=0)|0;n=h+k|0;c[o>>2]=n&65536;c[d+40>>2]=(n^k)&32768&(n^h);c[d+36>>2]=(h^k^n)&16;k=n&65535;n=k<<16>>16;c[d+52>>2]=n;c[d+44>>2]=n;c[d+32>>2]=n;b[g>>1]=k;k=d+84|0;c[k>>2]=(c[k>>2]|0)-(263170>>>((c[d+92>>2]|0)>>>0)&127);return}function f5D(d){d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=d+8|0;f=(b[e>>1]|0)-2&65535;b[e>>1]=f;e=b[d+24>>1]|0;g=((e&65535)<<4)+(f&65535)|0;f=e&255;h=g&1048575;i=c[3531864]|0;j=c[i+2092+(h>>>11<<2)>>2]|0;if((j|0)==0){gg[c[i+8240>>2]&4095](h,f);k=c[3531864]|0}else{a[j+h|0]=f;k=i}i=(e&65535)>>>8&255;e=g+1&1048575;g=c[k+2092+(e>>>11<<2)>>2]|0;if((g|0)==0){gg[c[k+8240>>2]&4095](e,i);l=d+92|0;m=c[l>>2]|0;n=788483>>>(m>>>0);o=n&127;p=d+84|0;q=c[p>>2]|0;r=q-o|0;c[p>>2]=r;return}else{a[g+e|0]=i;l=d+92|0;m=c[l>>2]|0;n=788483>>>(m>>>0);o=n&127;p=d+84|0;q=c[p>>2]|0;r=q-o|0;c[p>>2]=r;return}}function f5E(d){d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=d+8|0;f=(b[e>>1]|0)+2&65535;b[e>>1]=f;g=d+24|0;h=b[g>>1]|0;i=((f&65535)+65534&65535)+((h&65535)<<4)&1048575;j=c[3531864]|0;k=c[j+44+(i>>>11<<2)>>2]|0;if((k|0)==0){l=gj[c[j+8236>>2]&4095](i)|0;m=l;n=b[g>>1]|0;o=b[e>>1]|0;p=c[3531864]|0}else{m=a[k+i|0]|0;n=h;o=f;p=j}j=((o&65535)+65534&65535)+((n&65535)<<4|1)&1048575;n=c[p+44+(j>>>11<<2)>>2]|0;if((n|0)==0){q=gj[c[p+8236>>2]&4095](j)|0}else{q=a[n+j|0]|0}b[g>>1]=(q&255)<<8|m&255;m=d+84|0;c[m>>2]=(c[m>>2]|0)-(788485>>>((c[d+92>>2]|0)>>>0)&127);a[d+80|0]=1;return}function f5F(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=(e[f+22>>1]|0)<<4;h=(c[2385310]|0)+28|0;i=b[h>>1]|0;b[h>>1]=i+1&65535;h=(i&65535)+g&1048575;g=c[3531864]|0;i=c[g+6188+(h>>>11<<2)>>2]|0;if((i|0)==0){j=gj[c[g+8236>>2]&4095](h)|0}else{j=a[i+h|0]|0}h=j&255;i=f;g=d[i+(c[9652832+(h<<2)>>2]|0)|0]|0;k=(j&255)>191;do{if(k){l=a[i+(c[9648736+(h<<2)>>2]|0)|0]|0}else{j=(gj[c[679712+(h<<2)>>2]&4095](f)|0)&1048575;m=c[3531864]|0;n=c[m+44+(j>>>11<<2)>>2]|0;if((n|0)==0){l=gj[c[m+8236>>2]&4095](j)|0;break}else{l=a[n+j|0]|0;break}}}while(0);j=l&255;l=f+48|0;n=((c[l>>2]|0)!=0)+g|0;g=j-n|0;c[l>>2]=g&256;l=n^j;c[f+40>>2]=l&128&(g^j);c[f+36>>2]=(g^l)&16;l=g<<24>>24;c[f+52>>2]=l;c[f+44>>2]=l;c[f+32>>2]=l;if(k){a[i+(c[9648736+(h<<2)>>2]|0)|0]=g&255;o=f+92|0;p=c[o>>2]|0;q=k?131586:1052679;r=q>>>(p>>>0);s=r&127;t=f+84|0;u=c[t>>2]|0;v=u-s|0;c[t>>2]=v;return}h=g&255;g=c[2426956]&1048575;i=c[3531864]|0;l=c[i+2092+(g>>>11<<2)>>2]|0;if((l|0)==0){gg[c[i+8240>>2]&4095](g,h);o=f+92|0;p=c[o>>2]|0;q=k?131586:1052679;r=q>>>(p>>>0);s=r&127;t=f+84|0;u=c[t>>2]|0;v=u-s|0;c[t>>2]=v;return}else{a[l+g|0]=h;o=f+92|0;p=c[o>>2]|0;q=k?131586:1052679;r=q>>>(p>>>0);s=r&127;t=f+84|0;u=c[t>>2]|0;v=u-s|0;c[t>>2]=v;return}}function f5G(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=(e[d+22>>1]|0)<<4;g=(c[2385310]|0)+28|0;h=b[g>>1]|0;b[g>>1]=h+1&65535;g=(h&65535)+f&1048575;f=c[3531864]|0;h=c[f+6188+(g>>>11<<2)>>2]|0;if((h|0)==0){i=gj[c[f+8236>>2]&4095](g)|0}else{i=a[h+g|0]|0}g=i&255;h=e[d+(c[9654880+(g<<2)>>2]<<1)>>1]|0;f=(i&255)>191;if(f){j=e[d+(c[9650784+(g<<2)>>2]<<1)>>1]|0}else{i=c[679712+(g<<2)>>2]|0;gj[i&4095](d)|0;i=c[2426956]|0;k=i&1048575;l=c[3531864]|0;m=c[l+44+(k>>>11<<2)>>2]|0;if((m|0)==0){n=gj[c[l+8236>>2]&4095](k)|0;o=n;p=c[2426956]|0;q=c[3531864]|0}else{o=a[m+k|0]|0;p=i;q=l}l=p+1&1048575;p=c[q+44+(l>>>11<<2)>>2]|0;if((p|0)==0){r=gj[c[q+8236>>2]&4095](l)|0}else{r=a[p+l|0]|0}j=(r&255)<<8|o&255}o=d+48|0;r=((c[o>>2]|0)!=0)+h|0;h=j-r|0;c[o>>2]=h&65536;o=r^j;c[d+40>>2]=o&32768&(h^j);c[d+36>>2]=(h^o)&16;o=h<<16>>16;c[d+52>>2]=o;c[d+44>>2]=o;c[d+32>>2]=o;if(f){b[d+(c[9650784+(g<<2)>>2]<<1)>>1]=h&65535;g=d+84|0;c[g>>2]=(c[g>>2]|0)-2;return}g=c[2426956]|0;f=h&255;o=g&1048575;j=c[3531864]|0;r=c[j+2092+(o>>>11<<2)>>2]|0;if((r|0)==0){gg[c[j+8240>>2]&4095](o,f);s=c[3531864]|0}else{a[r+o|0]=f;s=j}j=(h&65535)>>>8&255;h=g+1&1048575;g=c[s+2092+(h>>>11<<2)>>2]|0;if((g|0)==0){gg[c[s+8240>>2]&4095](h,j)}else{a[g+h|0]=j}j=d+84|0;c[j>>2]=(c[j>>2]|0)-(((c[2426956]&1|0)!=0?1579019:1576967)>>>((c[d+92>>2]|0)>>>0)&127);return}function f5H(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=(e[f+22>>1]|0)<<4;h=(c[2385310]|0)+28|0;i=b[h>>1]|0;b[h>>1]=i+1&65535;h=(i&65535)+g&1048575;g=c[3531864]|0;i=c[g+6188+(h>>>11<<2)>>2]|0;if((i|0)==0){j=gj[c[g+8236>>2]&4095](h)|0}else{j=a[i+h|0]|0}h=j&255;i=9652832+(h<<2)|0;g=f;k=d[g+(c[i>>2]|0)|0]|0;l=(j&255)>191;do{if(l){m=a[g+(c[9648736+(h<<2)>>2]|0)|0]|0}else{j=(gj[c[679712+(h<<2)>>2]&4095](f)|0)&1048575;n=c[3531864]|0;o=c[n+44+(j>>>11<<2)>>2]|0;if((o|0)==0){m=gj[c[n+8236>>2]&4095](j)|0;break}else{m=a[o+j|0]|0;break}}}while(0);h=f+48|0;j=((c[h>>2]|0)!=0)+(m&255)|0;m=k-j|0;c[h>>2]=m&256;h=j^k;c[f+40>>2]=h&128&(m^k);c[f+36>>2]=(m^h)&16;h=m&255;m=h<<24>>24;c[f+52>>2]=m;c[f+44>>2]=m;c[f+32>>2]=m;a[g+(c[i>>2]|0)|0]=h;h=f+84|0;c[h>>2]=(c[h>>2]|0)-((l?131586:723718)>>>((c[f+92>>2]|0)>>>0)&127);return}function f5I(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=(e[d+22>>1]|0)<<4;g=(c[2385310]|0)+28|0;h=b[g>>1]|0;b[g>>1]=h+1&65535;g=(h&65535)+f&1048575;f=c[3531864]|0;h=c[f+6188+(g>>>11<<2)>>2]|0;if((h|0)==0){i=gj[c[f+8236>>2]&4095](g)|0}else{i=a[h+g|0]|0}g=i&255;h=9654880+(g<<2)|0;f=c[h>>2]|0;j=e[d+(f<<1)>>1]|0;k=(i&255)>191;if(k){l=e[d+(c[9650784+(g<<2)>>2]<<1)>>1]|0;m=f}else{f=c[679712+(g<<2)>>2]|0;gj[f&4095](d)|0;f=c[2426956]|0;g=f&1048575;i=c[3531864]|0;n=c[i+44+(g>>>11<<2)>>2]|0;if((n|0)==0){o=gj[c[i+8236>>2]&4095](g)|0;p=o;q=c[2426956]|0;r=c[3531864]|0}else{p=a[n+g|0]|0;q=f;r=i}i=q+1&1048575;q=c[r+44+(i>>>11<<2)>>2]|0;if((q|0)==0){s=gj[c[r+8236>>2]&4095](i)|0}else{s=a[q+i|0]|0}l=(s&255)<<8|p&255;m=c[h>>2]|0}h=d+48|0;p=((c[h>>2]|0)!=0)+l|0;l=j-p|0;c[h>>2]=l&65536;h=p^j;c[d+40>>2]=h&32768&(l^j);c[d+36>>2]=(l^h)&16;h=l&65535;l=h<<16>>16;c[d+52>>2]=l;c[d+44>>2]=l;c[d+32>>2]=l;b[d+(m<<1)>>1]=h;if(k){k=d+84|0;c[k>>2]=(c[k>>2]|0)-2;return}else{k=d+84|0;c[k>>2]=(c[k>>2]|0)-(((c[2426956]&1|0)!=0?986888:985862)>>>((c[d+92>>2]|0)>>>0)&127);return}}function f5J(f){f=f|0;var g=0,h=0,i=0,j=0,k=0;g=(e[f+22>>1]|0)<<4;h=(c[2385310]|0)+28|0;i=b[h>>1]|0;b[h>>1]=i+1&65535;h=(i&65535)+g&1048575;g=c[3531864]|0;i=c[g+6188+(h>>>11<<2)>>2]|0;if((i|0)==0){j=gj[c[g+8236>>2]&4095](h)|0}else{j=a[i+h|0]|0}h=f;i=d[h]|0;g=f+48|0;k=((c[g>>2]|0)!=0)+(j&255)|0;j=i-k|0;c[g>>2]=j&256;g=k^i;c[f+40>>2]=g&128&(j^i);c[f+36>>2]=(j^g)&16;g=j&255;j=g<<24>>24;c[f+52>>2]=j;c[f+44>>2]=j;c[f+32>>2]=j;a[h]=g;g=f+84|0;c[g>>2]=(c[g>>2]|0)-(263170>>>((c[f+92>>2]|0)>>>0)&127);return}function f5K(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=d+22|0;g=(e[f>>1]|0)<<4;h=c[2385310]|0;i=h+28|0;j=b[i>>1]|0;k=j+1&65535;b[i>>1]=k;i=(j&65535)+g&1048575;g=c[3531864]|0;j=c[g+6188+(i>>>11<<2)>>2]|0;if((j|0)==0){l=gj[c[g+8236>>2]&4095](i)|0;m=c[2385310]|0;n=l;o=m;p=b[m+28>>1]|0;q=c[3531864]|0}else{n=a[j+i|0]|0;o=h;p=k;q=g}g=d|0;k=e[g>>1]|0;h=(e[f>>1]|0)<<4;b[o+28>>1]=p+1&65535;o=(p&65535)+h&1048575;h=c[q+6188+(o>>>11<<2)>>2]|0;if((h|0)==0){r=gj[c[q+8236>>2]&4095](o)|0}else{r=a[h+o|0]|0}o=d+48|0;h=((r&255)<<8|n&255)+((c[o>>2]|0)!=0)|0;n=k-h|0;c[o>>2]=n&65536;o=h^k;c[d+40>>2]=o&32768&(n^k);c[d+36>>2]=(n^o)&16;o=n&65535;n=o<<16>>16;c[d+52>>2]=n;c[d+44>>2]=n;c[d+32>>2]=n;b[g>>1]=o;o=d+84|0;c[o>>2]=(c[o>>2]|0)-(263170>>>((c[d+92>>2]|0)>>>0)&127);return}function f5L(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=d+8|0;g=(b[f>>1]|0)-2&65535;b[f>>1]=g;f=((e[d+24>>1]|0)<<4)+(g&65535)|0;g=b[d+26>>1]|0;h=g&255;i=f&1048575;j=c[3531864]|0;k=c[j+2092+(i>>>11<<2)>>2]|0;if((k|0)==0){gg[c[j+8240>>2]&4095](i,h);l=c[3531864]|0}else{a[k+i|0]=h;l=j}j=(g&65535)>>>8&255;g=f+1&1048575;f=c[l+2092+(g>>>11<<2)>>2]|0;if((f|0)==0){gg[c[l+8240>>2]&4095](g,j);m=d+92|0;n=c[m>>2]|0;o=788483>>>(n>>>0);p=o&127;q=d+84|0;r=c[q>>2]|0;s=r-p|0;c[q>>2]=s;return}else{a[f+g|0]=j;m=d+92|0;n=c[m>>2]|0;o=788483>>>(n>>>0);p=o&127;q=d+84|0;r=c[q>>2]|0;s=r-p|0;c[q>>2]=s;return}}function f5M(d){d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=d+8|0;f=(b[e>>1]|0)+2&65535;b[e>>1]=f;g=d+24|0;h=b[g>>1]|0;i=((f&65535)+65534&65535)+((h&65535)<<4)&1048575;j=c[3531864]|0;k=c[j+44+(i>>>11<<2)>>2]|0;if((k|0)==0){l=gj[c[j+8236>>2]&4095](i)|0;m=l;n=b[g>>1]|0;o=b[e>>1]|0;p=c[3531864]|0}else{m=a[k+i|0]|0;n=h;o=f;p=j}j=((o&65535)+65534&65535)+((n&65535)<<4|1)&1048575;n=c[p+44+(j>>>11<<2)>>2]|0;if((n|0)==0){q=gj[c[p+8236>>2]&4095](j)|0}else{q=a[n+j|0]|0}b[d+26>>1]=(q&255)<<8|m&255;m=d+84|0;c[m>>2]=(c[m>>2]|0)-(788485>>>((c[d+92>>2]|0)>>>0)&127);return}function f5N(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=(e[d+22>>1]|0)<<4;g=(c[2385310]|0)+28|0;h=b[g>>1]|0;b[g>>1]=h+1&65535;g=(h&65535)+f&1048575;f=c[3531864]|0;h=c[f+6188+(g>>>11<<2)>>2]|0;if((h|0)==0){i=gj[c[f+8236>>2]&4095](g)|0}else{i=a[h+g|0]|0}g=i&255;h=d;f=a[h+(c[9652832+(g<<2)>>2]|0)|0]|0;j=(i&255)>191;do{if(j){k=a[h+(c[9648736+(g<<2)>>2]|0)|0]|0}else{i=(gj[c[679712+(g<<2)>>2]&4095](d)|0)&1048575;l=c[3531864]|0;m=c[l+44+(i>>>11<<2)>>2]|0;if((m|0)==0){k=gj[c[l+8236>>2]&4095](i)|0;break}else{k=a[m+i|0]|0;break}}}while(0);i=k&f;c[d+36>>2]=0;c[d+40>>2]=0;c[d+48>>2]=0;f=i<<24>>24;c[d+52>>2]=f;c[d+44>>2]=f;c[d+32>>2]=f;do{if(j){a[h+(c[9648736+(g<<2)>>2]|0)|0]=i}else{f=c[2426956]&1048575;k=c[3531864]|0;m=c[k+2092+(f>>>11<<2)>>2]|0;if((m|0)==0){gg[c[k+8240>>2]&4095](f,i);break}else{a[m+f|0]=i;break}}}while(0);i=d+84|0;c[i>>2]=(c[i>>2]|0)-((j?131586:1052679)>>>((c[d+92>>2]|0)>>>0)&127);return}function f5O(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=(e[d+22>>1]|0)<<4;g=(c[2385310]|0)+28|0;h=b[g>>1]|0;b[g>>1]=h+1&65535;g=(h&65535)+f&1048575;f=c[3531864]|0;h=c[f+6188+(g>>>11<<2)>>2]|0;if((h|0)==0){i=gj[c[f+8236>>2]&4095](g)|0}else{i=a[h+g|0]|0}g=i&255;h=b[d+(c[9654880+(g<<2)>>2]<<1)>>1]|0;f=(i&255)>191;if(f){j=b[d+(c[9650784+(g<<2)>>2]<<1)>>1]|0}else{i=c[679712+(g<<2)>>2]|0;gj[i&4095](d)|0;i=c[2426956]|0;k=i&1048575;l=c[3531864]|0;m=c[l+44+(k>>>11<<2)>>2]|0;if((m|0)==0){n=gj[c[l+8236>>2]&4095](k)|0;o=n;p=c[2426956]|0;q=c[3531864]|0}else{o=a[m+k|0]|0;p=i;q=l}l=p+1&1048575;p=c[q+44+(l>>>11<<2)>>2]|0;if((p|0)==0){r=gj[c[q+8236>>2]&4095](l)|0}else{r=a[p+l|0]|0}j=(r&255)<<8|o&255}o=j&h;c[d+36>>2]=0;c[d+40>>2]=0;c[d+48>>2]=0;h=o<<16>>16;c[d+52>>2]=h;c[d+44>>2]=h;c[d+32>>2]=h;if(f){b[d+(c[9650784+(g<<2)>>2]<<1)>>1]=o;g=d+84|0;c[g>>2]=(c[g>>2]|0)-2;return}g=c[2426956]|0;f=o&255;h=g&1048575;j=c[3531864]|0;r=c[j+2092+(h>>>11<<2)>>2]|0;if((r|0)==0){gg[c[j+8240>>2]&4095](h,f);s=c[3531864]|0}else{a[r+h|0]=f;s=j}j=(o&65535)>>>8&255;o=g+1&1048575;g=c[s+2092+(o>>>11<<2)>>2]|0;if((g|0)==0){gg[c[s+8240>>2]&4095](o,j)}else{a[g+o|0]=j}j=d+84|0;c[j>>2]=(c[j>>2]|0)-(((c[2426956]&1|0)!=0?1579019:1576967)>>>((c[d+92>>2]|0)>>>0)&127);return}function f5P(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=(e[d+22>>1]|0)<<4;g=(c[2385310]|0)+28|0;h=b[g>>1]|0;b[g>>1]=h+1&65535;g=(h&65535)+f&1048575;f=c[3531864]|0;h=c[f+6188+(g>>>11<<2)>>2]|0;if((h|0)==0){i=gj[c[f+8236>>2]&4095](g)|0}else{i=a[h+g|0]|0}g=i&255;h=9652832+(g<<2)|0;f=d;j=a[f+(c[h>>2]|0)|0]|0;k=(i&255)>191;do{if(k){l=a[f+(c[9648736+(g<<2)>>2]|0)|0]|0}else{i=(gj[c[679712+(g<<2)>>2]&4095](d)|0)&1048575;m=c[3531864]|0;n=c[m+44+(i>>>11<<2)>>2]|0;if((n|0)==0){l=gj[c[m+8236>>2]&4095](i)|0;break}else{l=a[n+i|0]|0;break}}}while(0);g=l&j;c[d+36>>2]=0;c[d+40>>2]=0;c[d+48>>2]=0;j=g<<24>>24;c[d+52>>2]=j;c[d+44>>2]=j;c[d+32>>2]=j;a[f+(c[h>>2]|0)|0]=g;g=d+84|0;c[g>>2]=(c[g>>2]|0)-((k?131586:723718)>>>((c[d+92>>2]|0)>>>0)&127);return}function f5Q(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=(e[d+22>>1]|0)<<4;g=(c[2385310]|0)+28|0;h=b[g>>1]|0;b[g>>1]=h+1&65535;g=(h&65535)+f&1048575;f=c[3531864]|0;h=c[f+6188+(g>>>11<<2)>>2]|0;if((h|0)==0){i=gj[c[f+8236>>2]&4095](g)|0}else{i=a[h+g|0]|0}g=i&255;h=9654880+(g<<2)|0;f=c[h>>2]|0;j=b[d+(f<<1)>>1]|0;k=(i&255)>191;if(k){l=b[d+(c[9650784+(g<<2)>>2]<<1)>>1]|0;m=f}else{f=c[679712+(g<<2)>>2]|0;gj[f&4095](d)|0;f=c[2426956]|0;g=f&1048575;i=c[3531864]|0;n=c[i+44+(g>>>11<<2)>>2]|0;if((n|0)==0){o=gj[c[i+8236>>2]&4095](g)|0;p=o;q=c[2426956]|0;r=c[3531864]|0}else{p=a[n+g|0]|0;q=f;r=i}i=q+1&1048575;q=c[r+44+(i>>>11<<2)>>2]|0;if((q|0)==0){s=gj[c[r+8236>>2]&4095](i)|0}else{s=a[q+i|0]|0}l=(s&255)<<8|p&255;m=c[h>>2]|0}h=l&j;c[d+36>>2]=0;c[d+40>>2]=0;c[d+48>>2]=0;j=h<<16>>16;c[d+52>>2]=j;c[d+44>>2]=j;c[d+32>>2]=j;b[d+(m<<1)>>1]=h;if(k){k=d+84|0;c[k>>2]=(c[k>>2]|0)-2;return}else{k=d+84|0;c[k>>2]=(c[k>>2]|0)-(((c[2426956]&1|0)!=0?986888:985862)>>>((c[d+92>>2]|0)>>>0)&127);return}}function f5R(d){d=d|0;var f=0,g=0,h=0,i=0;f=(e[d+22>>1]|0)<<4;g=(c[2385310]|0)+28|0;h=b[g>>1]|0;b[g>>1]=h+1&65535;g=(h&65535)+f&1048575;f=c[3531864]|0;h=c[f+6188+(g>>>11<<2)>>2]|0;if((h|0)==0){i=gj[c[f+8236>>2]&4095](g)|0}else{i=a[h+g|0]|0}g=d;h=a[g]&i;c[d+36>>2]=0;c[d+40>>2]=0;c[d+48>>2]=0;i=h<<24>>24;c[d+52>>2]=i;c[d+44>>2]=i;c[d+32>>2]=i;a[g]=h;h=d+84|0;c[h>>2]=(c[h>>2]|0)-(263170>>>((c[d+92>>2]|0)>>>0)&127);return}function f5S(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=d+22|0;g=(e[f>>1]|0)<<4;h=c[2385310]|0;i=h+28|0;j=b[i>>1]|0;k=j+1&65535;b[i>>1]=k;i=(j&65535)+g&1048575;g=c[3531864]|0;j=c[g+6188+(i>>>11<<2)>>2]|0;if((j|0)==0){l=gj[c[g+8236>>2]&4095](i)|0;m=c[2385310]|0;n=l;o=m;p=b[m+28>>1]|0;q=c[3531864]|0}else{n=a[j+i|0]|0;o=h;p=k;q=g}g=d|0;k=b[g>>1]|0;h=(e[f>>1]|0)<<4;b[o+28>>1]=p+1&65535;o=(p&65535)+h&1048575;h=c[q+6188+(o>>>11<<2)>>2]|0;if((h|0)==0){r=gj[c[q+8236>>2]&4095](o)|0}else{r=a[h+o|0]|0}o=((r&255)<<8|n&255)&k;c[d+36>>2]=0;c[d+40>>2]=0;c[d+48>>2]=0;k=o<<16>>16;c[d+52>>2]=k;c[d+44>>2]=k;c[d+32>>2]=k;b[g>>1]=o;o=d+84|0;c[o>>2]=(c[o>>2]|0)-(263170>>>((c[d+92>>2]|0)>>>0)&127);return}function f5T(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=d+100|0;a[f]=1;c[d+96>>2]=(e[d+20>>1]|0)<<4;g=d+84|0;c[g>>2]=(c[g>>2]|0)-2;g=d+90|0;a[g]=(a[g]|0)-1&255;g=(e[d+22>>1]|0)<<4;h=d+28|0;i=b[h>>1]|0;b[h>>1]=i+1&65535;h=(g+(i&65535)^c[d+16>>2])&1048575;i=c[3531864]|0;g=c[i+4140+(h>>>11<<2)>>2]|0;if((g|0)==0){j=gj[c[i+8236>>2]&4095](h)|0;k=j&255;l=2520528+(k<<2)|0;m=c[l>>2]|0;gf[m&2047](d);a[f]=0;return}else{j=a[g+h|0]|0;k=j&255;l=2520528+(k<<2)|0;m=c[l>>2]|0;gf[m&2047](d);a[f]=0;return}}function f5U(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=b+36|0;e=b;f=a[e]|0;do{if((c[d>>2]|0)==0){if((f&14)>>>0>9){g=45534;break}h=f;i=c[b+48>>2]|0}else{g=45534}}while(0);if((g|0)==45534){g=(f&255)+6&65535;f=g&255;a[e]=f;c[d>>2]=1;d=b+48|0;j=c[d>>2]|g&256;c[d>>2]=j;h=f;i=j}if((i|0)!=0|(h&255)>159){i=h+96&255;a[e]=i;c[b+48>>2]=1;k=i}else{k=h}h=k<<24>>24;c[b+52>>2]=h;c[b+44>>2]=h;c[b+32>>2]=h;h=b+84|0;c[h>>2]=(c[h>>2]|0)-(197378>>>((c[b+92>>2]|0)>>>0)&127);return}function f5V(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=(e[d+22>>1]|0)<<4;g=(c[2385310]|0)+28|0;h=b[g>>1]|0;b[g>>1]=h+1&65535;g=(h&65535)+f&1048575;f=c[3531864]|0;h=c[f+6188+(g>>>11<<2)>>2]|0;if((h|0)==0){i=gj[c[f+8236>>2]&4095](g)|0}else{i=a[h+g|0]|0}g=i&255;h=d;f=a[h+(c[9652832+(g<<2)>>2]|0)|0]|0;j=f&255;k=(i&255)>191;do{if(k){l=a[h+(c[9648736+(g<<2)>>2]|0)|0]|0}else{i=(gj[c[679712+(g<<2)>>2]&4095](d)|0)&1048575;m=c[3531864]|0;n=c[m+44+(i>>>11<<2)>>2]|0;if((n|0)==0){l=gj[c[m+8236>>2]&4095](i)|0;break}else{l=a[n+i|0]|0;break}}}while(0);i=l&255;n=i-j|0;c[d+48>>2]=n&256;j=(l^f)&255;c[d+40>>2]=j&128&(n^i);c[d+36>>2]=(n^j)&16;j=n<<24>>24;c[d+52>>2]=j;c[d+44>>2]=j;c[d+32>>2]=j;do{if(k){a[h+(c[9648736+(g<<2)>>2]|0)|0]=n&255}else{j=n&255;i=c[2426956]&1048575;f=c[3531864]|0;l=c[f+2092+(i>>>11<<2)>>2]|0;if((l|0)==0){gg[c[f+8240>>2]&4095](i,j);break}else{a[l+i|0]=j;break}}}while(0);n=d+84|0;c[n>>2]=(c[n>>2]|0)-((k?131586:1052679)>>>((c[d+92>>2]|0)>>>0)&127);return}function f5W(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=(e[d+22>>1]|0)<<4;g=(c[2385310]|0)+28|0;h=b[g>>1]|0;b[g>>1]=h+1&65535;g=(h&65535)+f&1048575;f=c[3531864]|0;h=c[f+6188+(g>>>11<<2)>>2]|0;if((h|0)==0){i=gj[c[f+8236>>2]&4095](g)|0}else{i=a[h+g|0]|0}g=i&255;h=e[d+(c[9654880+(g<<2)>>2]<<1)>>1]|0;f=(i&255)>191;if(f){j=e[d+(c[9650784+(g<<2)>>2]<<1)>>1]|0}else{i=c[679712+(g<<2)>>2]|0;gj[i&4095](d)|0;i=c[2426956]|0;k=i&1048575;l=c[3531864]|0;m=c[l+44+(k>>>11<<2)>>2]|0;if((m|0)==0){n=gj[c[l+8236>>2]&4095](k)|0;o=n;p=c[2426956]|0;q=c[3531864]|0}else{o=a[m+k|0]|0;p=i;q=l}l=p+1&1048575;p=c[q+44+(l>>>11<<2)>>2]|0;if((p|0)==0){r=gj[c[q+8236>>2]&4095](l)|0}else{r=a[p+l|0]|0}j=(r&255)<<8|o&255}o=j-h|0;c[d+48>>2]=o&65536;r=j^h;c[d+40>>2]=r&32768&(o^j);c[d+36>>2]=(o^r)&16;r=o<<16>>16;c[d+52>>2]=r;c[d+44>>2]=r;c[d+32>>2]=r;if(f){b[d+(c[9650784+(g<<2)>>2]<<1)>>1]=o&65535;g=d+84|0;c[g>>2]=(c[g>>2]|0)-2;return}g=c[2426956]|0;f=o&255;r=g&1048575;j=c[3531864]|0;h=c[j+2092+(r>>>11<<2)>>2]|0;if((h|0)==0){gg[c[j+8240>>2]&4095](r,f);s=c[3531864]|0}else{a[h+r|0]=f;s=j}j=(o&65535)>>>8&255;o=g+1&1048575;g=c[s+2092+(o>>>11<<2)>>2]|0;if((g|0)==0){gg[c[s+8240>>2]&4095](o,j)}else{a[g+o|0]=j}j=d+84|0;c[j>>2]=(c[j>>2]|0)-(((c[2426956]&1|0)!=0?1579019:1576967)>>>((c[d+92>>2]|0)>>>0)&127);return}function f5X(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=(e[d+22>>1]|0)<<4;g=(c[2385310]|0)+28|0;h=b[g>>1]|0;b[g>>1]=h+1&65535;g=(h&65535)+f&1048575;f=c[3531864]|0;h=c[f+6188+(g>>>11<<2)>>2]|0;if((h|0)==0){i=gj[c[f+8236>>2]&4095](g)|0}else{i=a[h+g|0]|0}g=i&255;h=9652832+(g<<2)|0;f=d;j=a[f+(c[h>>2]|0)|0]|0;k=j&255;l=(i&255)>191;do{if(l){m=a[f+(c[9648736+(g<<2)>>2]|0)|0]|0}else{i=(gj[c[679712+(g<<2)>>2]&4095](d)|0)&1048575;n=c[3531864]|0;o=c[n+44+(i>>>11<<2)>>2]|0;if((o|0)==0){m=gj[c[n+8236>>2]&4095](i)|0;break}else{m=a[o+i|0]|0;break}}}while(0);g=k-(m&255)|0;c[d+48>>2]=g&256;i=(m^j)&255;c[d+40>>2]=i&128&(g^k);c[d+36>>2]=(g^i)&16;i=g&255;g=i<<24>>24;c[d+52>>2]=g;c[d+44>>2]=g;c[d+32>>2]=g;a[f+(c[h>>2]|0)|0]=i;i=d+84|0;c[i>>2]=(c[i>>2]|0)-((l?131586:723718)>>>((c[d+92>>2]|0)>>>0)&127);return}function f5Y(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=(e[d+22>>1]|0)<<4;g=(c[2385310]|0)+28|0;h=b[g>>1]|0;b[g>>1]=h+1&65535;g=(h&65535)+f&1048575;f=c[3531864]|0;h=c[f+6188+(g>>>11<<2)>>2]|0;if((h|0)==0){i=gj[c[f+8236>>2]&4095](g)|0}else{i=a[h+g|0]|0}g=i&255;h=9654880+(g<<2)|0;f=c[h>>2]|0;j=e[d+(f<<1)>>1]|0;k=(i&255)>191;if(k){l=e[d+(c[9650784+(g<<2)>>2]<<1)>>1]|0;m=f}else{f=c[679712+(g<<2)>>2]|0;gj[f&4095](d)|0;f=c[2426956]|0;g=f&1048575;i=c[3531864]|0;n=c[i+44+(g>>>11<<2)>>2]|0;if((n|0)==0){o=gj[c[i+8236>>2]&4095](g)|0;p=o;q=c[2426956]|0;r=c[3531864]|0}else{p=a[n+g|0]|0;q=f;r=i}i=q+1&1048575;q=c[r+44+(i>>>11<<2)>>2]|0;if((q|0)==0){s=gj[c[r+8236>>2]&4095](i)|0}else{s=a[q+i|0]|0}l=(s&255)<<8|p&255;m=c[h>>2]|0}h=j-l|0;c[d+48>>2]=h&65536;p=l^j;c[d+40>>2]=p&32768&(h^j);c[d+36>>2]=(h^p)&16;p=h&65535;h=p<<16>>16;c[d+52>>2]=h;c[d+44>>2]=h;c[d+32>>2]=h;b[d+(m<<1)>>1]=p;if(k){k=d+84|0;c[k>>2]=(c[k>>2]|0)-2;return}else{k=d+84|0;c[k>>2]=(c[k>>2]|0)-(((c[2426956]&1|0)!=0?986888:985862)>>>((c[d+92>>2]|0)>>>0)&127);return}}function f5Z(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=(e[d+22>>1]|0)<<4;g=(c[2385310]|0)+28|0;h=b[g>>1]|0;b[g>>1]=h+1&65535;g=(h&65535)+f&1048575;f=c[3531864]|0;h=c[f+6188+(g>>>11<<2)>>2]|0;if((h|0)==0){i=gj[c[f+8236>>2]&4095](g)|0}else{i=a[h+g|0]|0}g=d;h=a[g]|0;f=h&255;j=f-(i&255)|0;c[d+48>>2]=j&256;k=(h^i)&255;c[d+40>>2]=k&128&(j^f);c[d+36>>2]=(j^k)&16;k=j&255;j=k<<24>>24;c[d+52>>2]=j;c[d+44>>2]=j;c[d+32>>2]=j;a[g]=k;k=d+84|0;c[k>>2]=(c[k>>2]|0)-(263170>>>((c[d+92>>2]|0)>>>0)&127);return}function f5_(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=d+22|0;g=(e[f>>1]|0)<<4;h=c[2385310]|0;i=h+28|0;j=b[i>>1]|0;k=j+1&65535;b[i>>1]=k;i=(j&65535)+g&1048575;g=c[3531864]|0;j=c[g+6188+(i>>>11<<2)>>2]|0;if((j|0)==0){l=gj[c[g+8236>>2]&4095](i)|0;m=c[2385310]|0;n=l;o=m;p=b[m+28>>1]|0;q=c[3531864]|0}else{n=a[j+i|0]|0;o=h;p=k;q=g}g=d|0;k=e[g>>1]|0;h=(e[f>>1]|0)<<4;b[o+28>>1]=p+1&65535;o=(p&65535)+h&1048575;h=c[q+6188+(o>>>11<<2)>>2]|0;if((h|0)==0){r=gj[c[q+8236>>2]&4095](o)|0}else{r=a[h+o|0]|0}o=(r&255)<<8|n&255;n=k-o|0;c[d+48>>2]=n&65536;r=o^k;c[d+40>>2]=r&32768&(n^k);c[d+36>>2]=(n^r)&16;r=n&65535;n=r<<16>>16;c[d+52>>2]=n;c[d+44>>2]=n;c[d+32>>2]=n;b[g>>1]=r;r=d+84|0;c[r>>2]=(c[r>>2]|0)-(263170>>>((c[d+92>>2]|0)>>>0)&127);return}function f5$(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=d+100|0;a[f]=1;g=(e[d+22>>1]|0)<<4;c[d+96>>2]=g;h=d+84|0;c[h>>2]=(c[h>>2]|0)-2;h=d+90|0;a[h]=(a[h]|0)-1&255;h=d+28|0;i=b[h>>1]|0;b[h>>1]=i+1&65535;h=((i&65535)+g^c[d+16>>2])&1048575;g=c[3531864]|0;i=c[g+4140+(h>>>11<<2)>>2]|0;if((i|0)==0){j=gj[c[g+8236>>2]&4095](h)|0;k=j&255;l=2520528+(k<<2)|0;m=c[l>>2]|0;gf[m&2047](d);a[f]=0;return}else{j=a[i+h|0]|0;k=j&255;l=2520528+(k<<2)|0;m=c[l>>2]|0;gf[m&2047](d);a[f]=0;return}}function f50(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=b+36|0;e=b;f=a[e]|0;do{if((c[d>>2]|0)==0){if((f&14)>>>0>9){g=45623;break}h=f;i=c[b+48>>2]|0}else{g=45623}}while(0);if((g|0)==45623){g=(f&255)-6&65535;f=g&255;a[e]=f;c[d>>2]=1;d=b+48|0;j=c[d>>2]|g&256;c[d>>2]=j;h=f;i=j}if((i|0)!=0|(h&255)>159){i=h-96&255;a[e]=i;c[b+48>>2]=1;k=i}else{k=h}h=k<<24>>24;c[b+52>>2]=h;c[b+44>>2]=h;c[b+32>>2]=h;h=b+84|0;c[h>>2]=(c[h>>2]|0)-(197378>>>((c[b+92>>2]|0)>>>0)&127);return}function f51(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=(e[d+22>>1]|0)<<4;g=(c[2385310]|0)+28|0;h=b[g>>1]|0;b[g>>1]=h+1&65535;g=(h&65535)+f&1048575;f=c[3531864]|0;h=c[f+6188+(g>>>11<<2)>>2]|0;if((h|0)==0){i=gj[c[f+8236>>2]&4095](g)|0}else{i=a[h+g|0]|0}g=i&255;h=d;f=a[h+(c[9652832+(g<<2)>>2]|0)|0]|0;j=(i&255)>191;do{if(j){k=a[h+(c[9648736+(g<<2)>>2]|0)|0]|0}else{i=(gj[c[679712+(g<<2)>>2]&4095](d)|0)&1048575;l=c[3531864]|0;m=c[l+44+(i>>>11<<2)>>2]|0;if((m|0)==0){k=gj[c[l+8236>>2]&4095](i)|0;break}else{k=a[m+i|0]|0;break}}}while(0);i=k^f;c[d+36>>2]=0;c[d+40>>2]=0;c[d+48>>2]=0;f=i<<24>>24;c[d+52>>2]=f;c[d+44>>2]=f;c[d+32>>2]=f;do{if(j){a[h+(c[9648736+(g<<2)>>2]|0)|0]=i}else{f=c[2426956]&1048575;k=c[3531864]|0;m=c[k+2092+(f>>>11<<2)>>2]|0;if((m|0)==0){gg[c[k+8240>>2]&4095](f,i);break}else{a[m+f|0]=i;break}}}while(0);i=d+84|0;c[i>>2]=(c[i>>2]|0)-((j?131586:1052679)>>>((c[d+92>>2]|0)>>>0)&127);return}function f52(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=(e[d+22>>1]|0)<<4;g=(c[2385310]|0)+28|0;h=b[g>>1]|0;b[g>>1]=h+1&65535;g=(h&65535)+f&1048575;f=c[3531864]|0;h=c[f+6188+(g>>>11<<2)>>2]|0;if((h|0)==0){i=gj[c[f+8236>>2]&4095](g)|0}else{i=a[h+g|0]|0}g=i&255;h=b[d+(c[9654880+(g<<2)>>2]<<1)>>1]|0;f=(i&255)>191;if(f){j=b[d+(c[9650784+(g<<2)>>2]<<1)>>1]|0}else{i=c[679712+(g<<2)>>2]|0;gj[i&4095](d)|0;i=c[2426956]|0;k=i&1048575;l=c[3531864]|0;m=c[l+44+(k>>>11<<2)>>2]|0;if((m|0)==0){n=gj[c[l+8236>>2]&4095](k)|0;o=n;p=c[2426956]|0;q=c[3531864]|0}else{o=a[m+k|0]|0;p=i;q=l}l=p+1&1048575;p=c[q+44+(l>>>11<<2)>>2]|0;if((p|0)==0){r=gj[c[q+8236>>2]&4095](l)|0}else{r=a[p+l|0]|0}j=(r&255)<<8|o&255}o=j^h;c[d+36>>2]=0;c[d+40>>2]=0;c[d+48>>2]=0;h=o<<16>>16;c[d+52>>2]=h;c[d+44>>2]=h;c[d+32>>2]=h;if(f){b[d+(c[9650784+(g<<2)>>2]<<1)>>1]=o;g=d+84|0;c[g>>2]=(c[g>>2]|0)-2;return}g=c[2426956]|0;f=o&255;h=g&1048575;j=c[3531864]|0;r=c[j+2092+(h>>>11<<2)>>2]|0;if((r|0)==0){gg[c[j+8240>>2]&4095](h,f);s=c[3531864]|0}else{a[r+h|0]=f;s=j}j=(o&65535)>>>8&255;o=g+1&1048575;g=c[s+2092+(o>>>11<<2)>>2]|0;if((g|0)==0){gg[c[s+8240>>2]&4095](o,j)}else{a[g+o|0]=j}j=d+84|0;c[j>>2]=(c[j>>2]|0)-(((c[2426956]&1|0)!=0?1579019:1576967)>>>((c[d+92>>2]|0)>>>0)&127);return}function f53(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=(e[d+22>>1]|0)<<4;g=(c[2385310]|0)+28|0;h=b[g>>1]|0;b[g>>1]=h+1&65535;g=(h&65535)+f&1048575;f=c[3531864]|0;h=c[f+6188+(g>>>11<<2)>>2]|0;if((h|0)==0){i=gj[c[f+8236>>2]&4095](g)|0}else{i=a[h+g|0]|0}g=i&255;h=9652832+(g<<2)|0;f=d;j=a[f+(c[h>>2]|0)|0]|0;k=(i&255)>191;do{if(k){l=a[f+(c[9648736+(g<<2)>>2]|0)|0]|0}else{i=(gj[c[679712+(g<<2)>>2]&4095](d)|0)&1048575;m=c[3531864]|0;n=c[m+44+(i>>>11<<2)>>2]|0;if((n|0)==0){l=gj[c[m+8236>>2]&4095](i)|0;break}else{l=a[n+i|0]|0;break}}}while(0);g=l^j;c[d+36>>2]=0;c[d+40>>2]=0;c[d+48>>2]=0;j=g<<24>>24;c[d+52>>2]=j;c[d+44>>2]=j;c[d+32>>2]=j;a[f+(c[h>>2]|0)|0]=g;g=d+84|0;c[g>>2]=(c[g>>2]|0)-((k?131586:723718)>>>((c[d+92>>2]|0)>>>0)&127);return}function f54(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=(e[d+22>>1]|0)<<4;g=(c[2385310]|0)+28|0;h=b[g>>1]|0;b[g>>1]=h+1&65535;g=(h&65535)+f&1048575;f=c[3531864]|0;h=c[f+6188+(g>>>11<<2)>>2]|0;if((h|0)==0){i=gj[c[f+8236>>2]&4095](g)|0}else{i=a[h+g|0]|0}g=i&255;h=9654880+(g<<2)|0;f=c[h>>2]|0;j=b[d+(f<<1)>>1]|0;k=(i&255)>191;if(k){l=b[d+(c[9650784+(g<<2)>>2]<<1)>>1]|0;m=f}else{f=c[679712+(g<<2)>>2]|0;gj[f&4095](d)|0;f=c[2426956]|0;g=f&1048575;i=c[3531864]|0;n=c[i+44+(g>>>11<<2)>>2]|0;if((n|0)==0){o=gj[c[i+8236>>2]&4095](g)|0;p=o;q=c[2426956]|0;r=c[3531864]|0}else{p=a[n+g|0]|0;q=f;r=i}i=q+1&1048575;q=c[r+44+(i>>>11<<2)>>2]|0;if((q|0)==0){s=gj[c[r+8236>>2]&4095](i)|0}else{s=a[q+i|0]|0}l=(s&255)<<8|p&255;m=c[h>>2]|0}h=l^j;c[d+36>>2]=0;c[d+40>>2]=0;c[d+48>>2]=0;j=h<<16>>16;c[d+52>>2]=j;c[d+44>>2]=j;c[d+32>>2]=j;b[d+(m<<1)>>1]=h;if(k){k=d+84|0;c[k>>2]=(c[k>>2]|0)-2;return}else{k=d+84|0;c[k>>2]=(c[k>>2]|0)-(((c[2426956]&1|0)!=0?986888:985862)>>>((c[d+92>>2]|0)>>>0)&127);return}}function f55(d){d=d|0;var f=0,g=0,h=0,i=0;f=(e[d+22>>1]|0)<<4;g=(c[2385310]|0)+28|0;h=b[g>>1]|0;b[g>>1]=h+1&65535;g=(h&65535)+f&1048575;f=c[3531864]|0;h=c[f+6188+(g>>>11<<2)>>2]|0;if((h|0)==0){i=gj[c[f+8236>>2]&4095](g)|0}else{i=a[h+g|0]|0}g=d;h=a[g]^i;c[d+36>>2]=0;c[d+40>>2]=0;c[d+48>>2]=0;i=h<<24>>24;c[d+52>>2]=i;c[d+44>>2]=i;c[d+32>>2]=i;a[g]=h;h=d+84|0;c[h>>2]=(c[h>>2]|0)-(263170>>>((c[d+92>>2]|0)>>>0)&127);return}function f56(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=d+22|0;g=(e[f>>1]|0)<<4;h=c[2385310]|0;i=h+28|0;j=b[i>>1]|0;k=j+1&65535;b[i>>1]=k;i=(j&65535)+g&1048575;g=c[3531864]|0;j=c[g+6188+(i>>>11<<2)>>2]|0;if((j|0)==0){l=gj[c[g+8236>>2]&4095](i)|0;m=c[2385310]|0;n=l;o=m;p=b[m+28>>1]|0;q=c[3531864]|0}else{n=a[j+i|0]|0;o=h;p=k;q=g}g=d|0;k=b[g>>1]|0;h=(e[f>>1]|0)<<4;b[o+28>>1]=p+1&65535;o=(p&65535)+h&1048575;h=c[q+6188+(o>>>11<<2)>>2]|0;if((h|0)==0){r=gj[c[q+8236>>2]&4095](o)|0}else{r=a[h+o|0]|0}o=((r&255)<<8|n&255)^k;c[d+36>>2]=0;c[d+40>>2]=0;c[d+48>>2]=0;k=o<<16>>16;c[d+52>>2]=k;c[d+44>>2]=k;c[d+32>>2]=k;b[g>>1]=o;o=d+84|0;c[o>>2]=(c[o>>2]|0)-(263170>>>((c[d+92>>2]|0)>>>0)&127);return}function f57(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=d+100|0;a[f]=1;c[d+96>>2]=(e[d+24>>1]|0)<<4;g=d+84|0;c[g>>2]=(c[g>>2]|0)-2;g=d+90|0;a[g]=(a[g]|0)-1&255;g=(e[d+22>>1]|0)<<4;h=d+28|0;i=b[h>>1]|0;b[h>>1]=i+1&65535;h=(g+(i&65535)^c[d+16>>2])&1048575;i=c[3531864]|0;g=c[i+4140+(h>>>11<<2)>>2]|0;if((g|0)==0){j=gj[c[i+8236>>2]&4095](h)|0;k=j&255;l=2520528+(k<<2)|0;m=c[l>>2]|0;gf[m&2047](d);a[f]=0;return}else{j=a[g+h|0]|0;k=j&255;l=2520528+(k<<2)|0;m=c[l>>2]|0;gf[m&2047](d);a[f]=0;return}}function f58(b){b=b|0;var d=0,e=0,f=0,g=0,h=0;d=b+36|0;e=b;f=a[e]|0;do{if((c[d>>2]|0)==0){if((f&14)>>>0>9){g=45711;break}c[d>>2]=0;c[b+48>>2]=0;h=f}else{g=45711}}while(0);if((g|0)==45711){g=f+6&255;a[e]=g;f=b+1|0;a[f]=(a[f]|0)+((g&255)>249?2:1)&255;c[d>>2]=1;c[b+48>>2]=1;h=g}a[e]=h&15;h=b+84|0;c[h>>2]=(c[h>>2]|0)-(460548>>>((c[b+92>>2]|0)>>>0)&127);return}function f59(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=(e[d+22>>1]|0)<<4;g=(c[2385310]|0)+28|0;h=b[g>>1]|0;b[g>>1]=h+1&65535;g=(h&65535)+f&1048575;f=c[3531864]|0;h=c[f+6188+(g>>>11<<2)>>2]|0;if((h|0)==0){i=gj[c[f+8236>>2]&4095](g)|0}else{i=a[h+g|0]|0}g=i&255;h=d;f=a[h+(c[9652832+(g<<2)>>2]|0)|0]|0;j=f&255;k=(i&255)>191;do{if(k){l=a[h+(c[9648736+(g<<2)>>2]|0)|0]|0}else{i=(gj[c[679712+(g<<2)>>2]&4095](d)|0)&1048575;m=c[3531864]|0;n=c[m+44+(i>>>11<<2)>>2]|0;if((n|0)==0){l=gj[c[m+8236>>2]&4095](i)|0;break}else{l=a[n+i|0]|0;break}}}while(0);g=l&255;h=g-j|0;c[d+48>>2]=h&256;j=(l^f)&255;c[d+40>>2]=j&128&(h^g);c[d+36>>2]=(h^j)&16;j=h<<24>>24;c[d+52>>2]=j;c[d+44>>2]=j;c[d+32>>2]=j;j=d+84|0;c[j>>2]=(c[j>>2]|0)-((k?131586:723718)>>>((c[d+92>>2]|0)>>>0)&127);return}function f6a(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=(e[d+22>>1]|0)<<4;g=(c[2385310]|0)+28|0;h=b[g>>1]|0;b[g>>1]=h+1&65535;g=(h&65535)+f&1048575;f=c[3531864]|0;h=c[f+6188+(g>>>11<<2)>>2]|0;if((h|0)==0){i=gj[c[f+8236>>2]&4095](g)|0}else{i=a[h+g|0]|0}g=i&255;h=e[d+(c[9654880+(g<<2)>>2]<<1)>>1]|0;f=(i&255)>191;if(f){j=e[d+(c[9650784+(g<<2)>>2]<<1)>>1]|0}else{i=c[679712+(g<<2)>>2]|0;gj[i&4095](d)|0;i=c[2426956]|0;g=i&1048575;k=c[3531864]|0;l=c[k+44+(g>>>11<<2)>>2]|0;if((l|0)==0){m=gj[c[k+8236>>2]&4095](g)|0;n=m;o=c[2426956]|0;p=c[3531864]|0}else{n=a[l+g|0]|0;o=i;p=k}k=o+1&1048575;o=c[p+44+(k>>>11<<2)>>2]|0;if((o|0)==0){q=gj[c[p+8236>>2]&4095](k)|0}else{q=a[o+k|0]|0}j=(q&255)<<8|n&255}n=j-h|0;c[d+48>>2]=n&65536;q=j^h;c[d+40>>2]=q&32768&(n^j);c[d+36>>2]=(n^q)&16;q=n<<16>>16;c[d+52>>2]=q;c[d+44>>2]=q;c[d+32>>2]=q;if(f){f=d+84|0;c[f>>2]=(c[f>>2]|0)-2;return}else{f=d+84|0;c[f>>2]=(c[f>>2]|0)-(((c[2426956]&1|0)!=0?986888:985862)>>>((c[d+92>>2]|0)>>>0)&127);return}}function f6b(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=(e[d+22>>1]|0)<<4;g=(c[2385310]|0)+28|0;h=b[g>>1]|0;b[g>>1]=h+1&65535;g=(h&65535)+f&1048575;f=c[3531864]|0;h=c[f+6188+(g>>>11<<2)>>2]|0;if((h|0)==0){i=gj[c[f+8236>>2]&4095](g)|0}else{i=a[h+g|0]|0}g=i&255;h=d;f=a[h+(c[9652832+(g<<2)>>2]|0)|0]|0;j=f&255;k=(i&255)>191;do{if(k){l=a[h+(c[9648736+(g<<2)>>2]|0)|0]|0}else{i=(gj[c[679712+(g<<2)>>2]&4095](d)|0)&1048575;m=c[3531864]|0;n=c[m+44+(i>>>11<<2)>>2]|0;if((n|0)==0){l=gj[c[m+8236>>2]&4095](i)|0;break}else{l=a[n+i|0]|0;break}}}while(0);g=j-(l&255)|0;c[d+48>>2]=g&256;h=(l^f)&255;c[d+40>>2]=h&128&(g^j);c[d+36>>2]=(g^h)&16;h=g<<24>>24;c[d+52>>2]=h;c[d+44>>2]=h;c[d+32>>2]=h;h=d+84|0;c[h>>2]=(c[h>>2]|0)-((k?131586:723718)>>>((c[d+92>>2]|0)>>>0)&127);return}function f6c(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=(e[d+22>>1]|0)<<4;g=(c[2385310]|0)+28|0;h=b[g>>1]|0;b[g>>1]=h+1&65535;g=(h&65535)+f&1048575;f=c[3531864]|0;h=c[f+6188+(g>>>11<<2)>>2]|0;if((h|0)==0){i=gj[c[f+8236>>2]&4095](g)|0}else{i=a[h+g|0]|0}g=i&255;h=e[d+(c[9654880+(g<<2)>>2]<<1)>>1]|0;f=(i&255)>191;if(f){j=e[d+(c[9650784+(g<<2)>>2]<<1)>>1]|0}else{i=c[679712+(g<<2)>>2]|0;gj[i&4095](d)|0;i=c[2426956]|0;g=i&1048575;k=c[3531864]|0;l=c[k+44+(g>>>11<<2)>>2]|0;if((l|0)==0){m=gj[c[k+8236>>2]&4095](g)|0;n=m;o=c[2426956]|0;p=c[3531864]|0}else{n=a[l+g|0]|0;o=i;p=k}k=o+1&1048575;o=c[p+44+(k>>>11<<2)>>2]|0;if((o|0)==0){q=gj[c[p+8236>>2]&4095](k)|0}else{q=a[o+k|0]|0}j=(q&255)<<8|n&255}n=h-j|0;c[d+48>>2]=n&65536;q=j^h;c[d+40>>2]=q&32768&(n^h);c[d+36>>2]=(n^q)&16;q=n<<16>>16;c[d+52>>2]=q;c[d+44>>2]=q;c[d+32>>2]=q;if(f){f=d+84|0;c[f>>2]=(c[f>>2]|0)-2;return}else{f=d+84|0;c[f>>2]=(c[f>>2]|0)-(((c[2426956]&1|0)!=0?986888:985862)>>>((c[d+92>>2]|0)>>>0)&127);return}}function f6d(d){d=d|0;var f=0,g=0,h=0,i=0,j=0;f=(e[d+22>>1]|0)<<4;g=(c[2385310]|0)+28|0;h=b[g>>1]|0;b[g>>1]=h+1&65535;g=(h&65535)+f&1048575;f=c[3531864]|0;h=c[f+6188+(g>>>11<<2)>>2]|0;if((h|0)==0){i=gj[c[f+8236>>2]&4095](g)|0}else{i=a[h+g|0]|0}g=a[d]|0;h=g&255;f=h-(i&255)|0;c[d+48>>2]=f&256;j=(g^i)&255;c[d+40>>2]=j&128&(f^h);c[d+36>>2]=(f^j)&16;j=f<<24>>24;c[d+52>>2]=j;c[d+44>>2]=j;c[d+32>>2]=j;j=d+84|0;c[j>>2]=(c[j>>2]|0)-(263170>>>((c[d+92>>2]|0)>>>0)&127);return}function f6e(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=d+22|0;g=(e[f>>1]|0)<<4;h=c[2385310]|0;i=h+28|0;j=b[i>>1]|0;k=j+1&65535;b[i>>1]=k;i=(j&65535)+g&1048575;g=c[3531864]|0;j=c[g+6188+(i>>>11<<2)>>2]|0;if((j|0)==0){l=gj[c[g+8236>>2]&4095](i)|0;m=c[2385310]|0;n=l;o=m;p=b[m+28>>1]|0;q=c[3531864]|0}else{n=a[j+i|0]|0;o=h;p=k;q=g}g=e[d>>1]|0;k=(e[f>>1]|0)<<4;b[o+28>>1]=p+1&65535;o=(p&65535)+k&1048575;k=c[q+6188+(o>>>11<<2)>>2]|0;if((k|0)==0){r=gj[c[q+8236>>2]&4095](o)|0}else{r=a[k+o|0]|0}o=(r&255)<<8|n&255;n=g-o|0;c[d+48>>2]=n&65536;r=o^g;c[d+40>>2]=r&32768&(n^g);c[d+36>>2]=(n^r)&16;r=n<<16>>16;c[d+52>>2]=r;c[d+44>>2]=r;c[d+32>>2]=r;r=d+84|0;c[r>>2]=(c[r>>2]|0)-(263170>>>((c[d+92>>2]|0)>>>0)&127);return}function f6f(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=d+100|0;a[f]=1;c[d+96>>2]=(e[d+26>>1]|0)<<4;g=d+84|0;c[g>>2]=(c[g>>2]|0)-2;g=d+90|0;a[g]=(a[g]|0)-1&255;g=(e[d+22>>1]|0)<<4;h=d+28|0;i=b[h>>1]|0;b[h>>1]=i+1&65535;h=(g+(i&65535)^c[d+16>>2])&1048575;i=c[3531864]|0;g=c[i+4140+(h>>>11<<2)>>2]|0;if((g|0)==0){j=gj[c[i+8236>>2]&4095](h)|0;k=j&255;l=2520528+(k<<2)|0;m=c[l>>2]|0;gf[m&2047](d);a[f]=0;return}else{j=a[g+h|0]|0;k=j&255;l=2520528+(k<<2)|0;m=c[l>>2]|0;gf[m&2047](d);a[f]=0;return}}function f6g(b){b=b|0;var d=0,e=0,f=0,g=0,h=0;d=b+36|0;e=b;f=a[e]|0;do{if((c[d>>2]|0)==0){if((f&14)>>>0>9){g=45787;break}c[d>>2]=0;c[b+48>>2]=0;h=f}else{g=45787}}while(0);if((g|0)==45787){g=f-6&255;a[e]=g;f=b+1|0;a[f]=(a[f]|0)+((g&255)<6?-2:-1)&255;c[d>>2]=1;c[b+48>>2]=1;h=g}a[e]=h&15;h=b+84|0;c[h>>2]=(c[h>>2]|0)-(460548>>>((c[b+92>>2]|0)>>>0)&127);return}function f6h(a){a=a|0;var d=0,e=0,f=0,g=0;d=a|0;e=b[d>>1]|0;f=e&65535;g=f+1|0;c[a+40>>2]=e<<16>>16==32767;c[a+36>>2]=(g^f)&16;f=g&65535;g=f<<16>>16;c[a+52>>2]=g;c[a+44>>2]=g;c[a+32>>2]=g;b[d>>1]=f;f=a+84|0;c[f>>2]=(c[f>>2]|0)-2;return}function f6i(a){a=a|0;var d=0,e=0,f=0,g=0;d=a+2|0;e=b[d>>1]|0;f=e&65535;g=f+1|0;c[a+40>>2]=e<<16>>16==32767;c[a+36>>2]=(g^f)&16;f=g&65535;g=f<<16>>16;c[a+52>>2]=g;c[a+44>>2]=g;c[a+32>>2]=g;b[d>>1]=f;f=a+84|0;c[f>>2]=(c[f>>2]|0)-2;return}function f6j(a){a=a|0;var d=0,e=0,f=0,g=0;d=a+4|0;e=b[d>>1]|0;f=e&65535;g=f+1|0;c[a+40>>2]=e<<16>>16==32767;c[a+36>>2]=(g^f)&16;f=g&65535;g=f<<16>>16;c[a+52>>2]=g;c[a+44>>2]=g;c[a+32>>2]=g;b[d>>1]=f;f=a+84|0;c[f>>2]=(c[f>>2]|0)-2;return}function f6k(a){a=a|0;var d=0,e=0,f=0,g=0;d=a+6|0;e=b[d>>1]|0;f=e&65535;g=f+1|0;c[a+40>>2]=e<<16>>16==32767;c[a+36>>2]=(g^f)&16;f=g&65535;g=f<<16>>16;c[a+52>>2]=g;c[a+44>>2]=g;c[a+32>>2]=g;b[d>>1]=f;f=a+84|0;c[f>>2]=(c[f>>2]|0)-2;return}function f6l(a){a=a|0;var d=0,e=0,f=0,g=0;d=a+8|0;e=b[d>>1]|0;f=e&65535;g=f+1|0;c[a+40>>2]=e<<16>>16==32767;c[a+36>>2]=(g^f)&16;f=g&65535;g=f<<16>>16;c[a+52>>2]=g;c[a+44>>2]=g;c[a+32>>2]=g;b[d>>1]=f;f=a+84|0;c[f>>2]=(c[f>>2]|0)-2;return}function f6m(a){a=a|0;var d=0,e=0,f=0,g=0;d=a+10|0;e=b[d>>1]|0;f=e&65535;g=f+1|0;c[a+40>>2]=e<<16>>16==32767;c[a+36>>2]=(g^f)&16;f=g&65535;g=f<<16>>16;c[a+52>>2]=g;c[a+44>>2]=g;c[a+32>>2]=g;b[d>>1]=f;f=a+84|0;c[f>>2]=(c[f>>2]|0)-2;return}function f6n(a){a=a|0;var d=0,e=0,f=0,g=0;d=a+12|0;e=b[d>>1]|0;f=e&65535;g=f+1|0;c[a+40>>2]=e<<16>>16==32767;c[a+36>>2]=(g^f)&16;f=g&65535;g=f<<16>>16;c[a+52>>2]=g;c[a+44>>2]=g;c[a+32>>2]=g;b[d>>1]=f;f=a+84|0;c[f>>2]=(c[f>>2]|0)-2;return}function f6o(a){a=a|0;var d=0,e=0,f=0,g=0;d=a+14|0;e=b[d>>1]|0;f=e&65535;g=f+1|0;c[a+40>>2]=e<<16>>16==32767;c[a+36>>2]=(g^f)&16;f=g&65535;g=f<<16>>16;c[a+52>>2]=g;c[a+44>>2]=g;c[a+32>>2]=g;b[d>>1]=f;f=a+84|0;c[f>>2]=(c[f>>2]|0)-2;return}function f6p(a){a=a|0;var d=0,e=0,f=0,g=0;d=a|0;e=b[d>>1]|0;f=e&65535;g=f-1|0;c[a+40>>2]=e<<16>>16==-32768;c[a+36>>2]=(g^f)&16;f=g&65535;g=f<<16>>16;c[a+52>>2]=g;c[a+44>>2]=g;c[a+32>>2]=g;b[d>>1]=f;f=a+84|0;c[f>>2]=(c[f>>2]|0)-2;return}function f6q(a){a=a|0;var d=0,e=0,f=0,g=0;d=a+2|0;e=b[d>>1]|0;f=e&65535;g=f-1|0;c[a+40>>2]=e<<16>>16==-32768;c[a+36>>2]=(g^f)&16;f=g&65535;g=f<<16>>16;c[a+52>>2]=g;c[a+44>>2]=g;c[a+32>>2]=g;b[d>>1]=f;f=a+84|0;c[f>>2]=(c[f>>2]|0)-2;return}function f6r(a){a=a|0;var d=0,e=0,f=0,g=0;d=a+4|0;e=b[d>>1]|0;f=e&65535;g=f-1|0;c[a+40>>2]=e<<16>>16==-32768;c[a+36>>2]=(g^f)&16;f=g&65535;g=f<<16>>16;c[a+52>>2]=g;c[a+44>>2]=g;c[a+32>>2]=g;b[d>>1]=f;f=a+84|0;c[f>>2]=(c[f>>2]|0)-2;return}function f6s(a){a=a|0;var d=0,e=0,f=0,g=0;d=a+6|0;e=b[d>>1]|0;f=e&65535;g=f-1|0;c[a+40>>2]=e<<16>>16==-32768;c[a+36>>2]=(g^f)&16;f=g&65535;g=f<<16>>16;c[a+52>>2]=g;c[a+44>>2]=g;c[a+32>>2]=g;b[d>>1]=f;f=a+84|0;c[f>>2]=(c[f>>2]|0)-2;return}function f6t(a){a=a|0;var d=0,e=0,f=0,g=0;d=a+8|0;e=b[d>>1]|0;f=e&65535;g=f-1|0;c[a+40>>2]=e<<16>>16==-32768;c[a+36>>2]=(g^f)&16;f=g&65535;g=f<<16>>16;c[a+52>>2]=g;c[a+44>>2]=g;c[a+32>>2]=g;b[d>>1]=f;f=a+84|0;c[f>>2]=(c[f>>2]|0)-2;return}function f6u(a){a=a|0;var d=0,e=0,f=0,g=0;d=a+10|0;e=b[d>>1]|0;f=e&65535;g=f-1|0;c[a+40>>2]=e<<16>>16==-32768;c[a+36>>2]=(g^f)&16;f=g&65535;g=f<<16>>16;c[a+52>>2]=g;c[a+44>>2]=g;c[a+32>>2]=g;b[d>>1]=f;f=a+84|0;c[f>>2]=(c[f>>2]|0)-2;return}function f6v(a){a=a|0;var d=0,e=0,f=0,g=0;d=a+12|0;e=b[d>>1]|0;f=e&65535;g=f-1|0;c[a+40>>2]=e<<16>>16==-32768;c[a+36>>2]=(g^f)&16;f=g&65535;g=f<<16>>16;c[a+52>>2]=g;c[a+44>>2]=g;c[a+32>>2]=g;b[d>>1]=f;f=a+84|0;c[f>>2]=(c[f>>2]|0)-2;return}function f6w(a){a=a|0;var d=0,e=0,f=0,g=0;d=a+14|0;e=b[d>>1]|0;f=e&65535;g=f-1|0;c[a+40>>2]=e<<16>>16==-32768;c[a+36>>2]=(g^f)&16;f=g&65535;g=f<<16>>16;c[a+52>>2]=g;c[a+44>>2]=g;c[a+32>>2]=g;b[d>>1]=f;f=a+84|0;c[f>>2]=(c[f>>2]|0)-2;return}function f6x(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=d+8|0;g=(b[f>>1]|0)-2&65535;b[f>>1]=g;f=((e[d+24>>1]|0)<<4)+(g&65535)|0;g=b[d>>1]|0;h=g&255;i=f&1048575;j=c[3531864]|0;k=c[j+2092+(i>>>11<<2)>>2]|0;if((k|0)==0){gg[c[j+8240>>2]&4095](i,h);l=c[3531864]|0}else{a[k+i|0]=h;l=j}j=(g&65535)>>>8&255;g=f+1&1048575;f=c[l+2092+(g>>>11<<2)>>2]|0;if((f|0)==0){gg[c[l+8240>>2]&4095](g,j);m=d+92|0;n=c[m>>2]|0;o=788483>>>(n>>>0);p=o&127;q=d+84|0;r=c[q>>2]|0;s=r-p|0;c[q>>2]=s;return}else{a[f+g|0]=j;m=d+92|0;n=c[m>>2]|0;o=788483>>>(n>>>0);p=o&127;q=d+84|0;r=c[q>>2]|0;s=r-p|0;c[q>>2]=s;return}}function f6y(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=d+8|0;g=(b[f>>1]|0)-2&65535;b[f>>1]=g;f=((e[d+24>>1]|0)<<4)+(g&65535)|0;g=b[d+2>>1]|0;h=g&255;i=f&1048575;j=c[3531864]|0;k=c[j+2092+(i>>>11<<2)>>2]|0;if((k|0)==0){gg[c[j+8240>>2]&4095](i,h);l=c[3531864]|0}else{a[k+i|0]=h;l=j}j=(g&65535)>>>8&255;g=f+1&1048575;f=c[l+2092+(g>>>11<<2)>>2]|0;if((f|0)==0){gg[c[l+8240>>2]&4095](g,j);m=d+92|0;n=c[m>>2]|0;o=788483>>>(n>>>0);p=o&127;q=d+84|0;r=c[q>>2]|0;s=r-p|0;c[q>>2]=s;return}else{a[f+g|0]=j;m=d+92|0;n=c[m>>2]|0;o=788483>>>(n>>>0);p=o&127;q=d+84|0;r=c[q>>2]|0;s=r-p|0;c[q>>2]=s;return}}function f6z(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=d+8|0;g=(b[f>>1]|0)-2&65535;b[f>>1]=g;f=((e[d+24>>1]|0)<<4)+(g&65535)|0;g=b[d+4>>1]|0;h=g&255;i=f&1048575;j=c[3531864]|0;k=c[j+2092+(i>>>11<<2)>>2]|0;if((k|0)==0){gg[c[j+8240>>2]&4095](i,h);l=c[3531864]|0}else{a[k+i|0]=h;l=j}j=(g&65535)>>>8&255;g=f+1&1048575;f=c[l+2092+(g>>>11<<2)>>2]|0;if((f|0)==0){gg[c[l+8240>>2]&4095](g,j);m=d+92|0;n=c[m>>2]|0;o=788483>>>(n>>>0);p=o&127;q=d+84|0;r=c[q>>2]|0;s=r-p|0;c[q>>2]=s;return}else{a[f+g|0]=j;m=d+92|0;n=c[m>>2]|0;o=788483>>>(n>>>0);p=o&127;q=d+84|0;r=c[q>>2]|0;s=r-p|0;c[q>>2]=s;return}}function f6A(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=d+8|0;g=(b[f>>1]|0)-2&65535;b[f>>1]=g;f=((e[d+24>>1]|0)<<4)+(g&65535)|0;g=b[d+6>>1]|0;h=g&255;i=f&1048575;j=c[3531864]|0;k=c[j+2092+(i>>>11<<2)>>2]|0;if((k|0)==0){gg[c[j+8240>>2]&4095](i,h);l=c[3531864]|0}else{a[k+i|0]=h;l=j}j=(g&65535)>>>8&255;g=f+1&1048575;f=c[l+2092+(g>>>11<<2)>>2]|0;if((f|0)==0){gg[c[l+8240>>2]&4095](g,j);m=d+92|0;n=c[m>>2]|0;o=788483>>>(n>>>0);p=o&127;q=d+84|0;r=c[q>>2]|0;s=r-p|0;c[q>>2]=s;return}else{a[f+g|0]=j;m=d+92|0;n=c[m>>2]|0;o=788483>>>(n>>>0);p=o&127;q=d+84|0;r=c[q>>2]|0;s=r-p|0;c[q>>2]=s;return}}function f6B(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=d+8|0;g=(b[f>>1]|0)-2&65535;b[f>>1]=g;f=((e[d+24>>1]|0)<<4)+(g&65535)|0;h=g&255;i=f&1048575;j=c[3531864]|0;k=c[j+2092+(i>>>11<<2)>>2]|0;if((k|0)==0){gg[c[j+8240>>2]&4095](i,h);l=c[3531864]|0}else{a[k+i|0]=h;l=j}j=(g&65535)>>>8&255;g=f+1&1048575;f=c[l+2092+(g>>>11<<2)>>2]|0;if((f|0)==0){gg[c[l+8240>>2]&4095](g,j);m=d+92|0;n=c[m>>2]|0;o=788483>>>(n>>>0);p=o&127;q=d+84|0;r=c[q>>2]|0;s=r-p|0;c[q>>2]=s;return}else{a[f+g|0]=j;m=d+92|0;n=c[m>>2]|0;o=788483>>>(n>>>0);p=o&127;q=d+84|0;r=c[q>>2]|0;s=r-p|0;c[q>>2]=s;return}}function f6C(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=d+8|0;g=(b[f>>1]|0)-2&65535;b[f>>1]=g;f=((e[d+24>>1]|0)<<4)+(g&65535)|0;g=b[d+10>>1]|0;h=g&255;i=f&1048575;j=c[3531864]|0;k=c[j+2092+(i>>>11<<2)>>2]|0;if((k|0)==0){gg[c[j+8240>>2]&4095](i,h);l=c[3531864]|0}else{a[k+i|0]=h;l=j}j=(g&65535)>>>8&255;g=f+1&1048575;f=c[l+2092+(g>>>11<<2)>>2]|0;if((f|0)==0){gg[c[l+8240>>2]&4095](g,j);m=d+92|0;n=c[m>>2]|0;o=788483>>>(n>>>0);p=o&127;q=d+84|0;r=c[q>>2]|0;s=r-p|0;c[q>>2]=s;return}else{a[f+g|0]=j;m=d+92|0;n=c[m>>2]|0;o=788483>>>(n>>>0);p=o&127;q=d+84|0;r=c[q>>2]|0;s=r-p|0;c[q>>2]=s;return}}function f6D(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=d+8|0;g=(b[f>>1]|0)-2&65535;b[f>>1]=g;f=((e[d+24>>1]|0)<<4)+(g&65535)|0;g=b[d+12>>1]|0;h=g&255;i=f&1048575;j=c[3531864]|0;k=c[j+2092+(i>>>11<<2)>>2]|0;if((k|0)==0){gg[c[j+8240>>2]&4095](i,h);l=c[3531864]|0}else{a[k+i|0]=h;l=j}j=(g&65535)>>>8&255;g=f+1&1048575;f=c[l+2092+(g>>>11<<2)>>2]|0;if((f|0)==0){gg[c[l+8240>>2]&4095](g,j);m=d+92|0;n=c[m>>2]|0;o=788483>>>(n>>>0);p=o&127;q=d+84|0;r=c[q>>2]|0;s=r-p|0;c[q>>2]=s;return}else{a[f+g|0]=j;m=d+92|0;n=c[m>>2]|0;o=788483>>>(n>>>0);p=o&127;q=d+84|0;r=c[q>>2]|0;s=r-p|0;c[q>>2]=s;return}}function f6E(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=d+8|0;g=(b[f>>1]|0)-2&65535;b[f>>1]=g;f=((e[d+24>>1]|0)<<4)+(g&65535)|0;g=b[d+14>>1]|0;h=g&255;i=f&1048575;j=c[3531864]|0;k=c[j+2092+(i>>>11<<2)>>2]|0;if((k|0)==0){gg[c[j+8240>>2]&4095](i,h);l=c[3531864]|0}else{a[k+i|0]=h;l=j}j=(g&65535)>>>8&255;g=f+1&1048575;f=c[l+2092+(g>>>11<<2)>>2]|0;if((f|0)==0){gg[c[l+8240>>2]&4095](g,j);m=d+92|0;n=c[m>>2]|0;o=788483>>>(n>>>0);p=o&127;q=d+84|0;r=c[q>>2]|0;s=r-p|0;c[q>>2]=s;return}else{a[f+g|0]=j;m=d+92|0;n=c[m>>2]|0;o=788483>>>(n>>>0);p=o&127;q=d+84|0;r=c[q>>2]|0;s=r-p|0;c[q>>2]=s;return}}function f6F(d){d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=d+8|0;f=(b[e>>1]|0)+2&65535;b[e>>1]=f;g=d+24|0;h=b[g>>1]|0;i=((f&65535)+65534&65535)+((h&65535)<<4)&1048575;j=c[3531864]|0;k=c[j+44+(i>>>11<<2)>>2]|0;if((k|0)==0){l=gj[c[j+8236>>2]&4095](i)|0;m=l;n=b[g>>1]|0;o=b[e>>1]|0;p=c[3531864]|0}else{m=a[k+i|0]|0;n=h;o=f;p=j}j=((o&65535)+65534&65535)+((n&65535)<<4|1)&1048575;n=c[p+44+(j>>>11<<2)>>2]|0;if((n|0)==0){q=gj[c[p+8236>>2]&4095](j)|0}else{q=a[n+j|0]|0}b[d>>1]=(q&255)<<8|m&255;m=d+84|0;c[m>>2]=(c[m>>2]|0)-(788485>>>((c[d+92>>2]|0)>>>0)&127);return}function f6G(d){d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=d+8|0;f=(b[e>>1]|0)+2&65535;b[e>>1]=f;g=d+24|0;h=b[g>>1]|0;i=((f&65535)+65534&65535)+((h&65535)<<4)&1048575;j=c[3531864]|0;k=c[j+44+(i>>>11<<2)>>2]|0;if((k|0)==0){l=gj[c[j+8236>>2]&4095](i)|0;m=l;n=b[g>>1]|0;o=b[e>>1]|0;p=c[3531864]|0}else{m=a[k+i|0]|0;n=h;o=f;p=j}j=((o&65535)+65534&65535)+((n&65535)<<4|1)&1048575;n=c[p+44+(j>>>11<<2)>>2]|0;if((n|0)==0){q=gj[c[p+8236>>2]&4095](j)|0}else{q=a[n+j|0]|0}b[d+2>>1]=(q&255)<<8|m&255;m=d+84|0;c[m>>2]=(c[m>>2]|0)-(788485>>>((c[d+92>>2]|0)>>>0)&127);return}function f6H(d){d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=d+8|0;f=(b[e>>1]|0)+2&65535;b[e>>1]=f;g=d+24|0;h=b[g>>1]|0;i=((f&65535)+65534&65535)+((h&65535)<<4)&1048575;j=c[3531864]|0;k=c[j+44+(i>>>11<<2)>>2]|0;if((k|0)==0){l=gj[c[j+8236>>2]&4095](i)|0;m=l;n=b[g>>1]|0;o=b[e>>1]|0;p=c[3531864]|0}else{m=a[k+i|0]|0;n=h;o=f;p=j}j=((o&65535)+65534&65535)+((n&65535)<<4|1)&1048575;n=c[p+44+(j>>>11<<2)>>2]|0;if((n|0)==0){q=gj[c[p+8236>>2]&4095](j)|0}else{q=a[n+j|0]|0}b[d+4>>1]=(q&255)<<8|m&255;m=d+84|0;c[m>>2]=(c[m>>2]|0)-(788485>>>((c[d+92>>2]|0)>>>0)&127);return}function f6I(d){d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=d+8|0;f=(b[e>>1]|0)+2&65535;b[e>>1]=f;g=d+24|0;h=b[g>>1]|0;i=((f&65535)+65534&65535)+((h&65535)<<4)&1048575;j=c[3531864]|0;k=c[j+44+(i>>>11<<2)>>2]|0;if((k|0)==0){l=gj[c[j+8236>>2]&4095](i)|0;m=l;n=b[g>>1]|0;o=b[e>>1]|0;p=c[3531864]|0}else{m=a[k+i|0]|0;n=h;o=f;p=j}j=((o&65535)+65534&65535)+((n&65535)<<4|1)&1048575;n=c[p+44+(j>>>11<<2)>>2]|0;if((n|0)==0){q=gj[c[p+8236>>2]&4095](j)|0}else{q=a[n+j|0]|0}b[d+6>>1]=(q&255)<<8|m&255;m=d+84|0;c[m>>2]=(c[m>>2]|0)-(788485>>>((c[d+92>>2]|0)>>>0)&127);return}function f6J(d){d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=d+8|0;f=(b[e>>1]|0)+2&65535;b[e>>1]=f;g=d+24|0;h=b[g>>1]|0;i=((f&65535)+65534&65535)+((h&65535)<<4)&1048575;j=c[3531864]|0;k=c[j+44+(i>>>11<<2)>>2]|0;if((k|0)==0){l=gj[c[j+8236>>2]&4095](i)|0;m=l;n=b[g>>1]|0;o=b[e>>1]|0;p=c[3531864]|0}else{m=a[k+i|0]|0;n=h;o=f;p=j}j=((o&65535)+65534&65535)+((n&65535)<<4|1)&1048575;n=c[p+44+(j>>>11<<2)>>2]|0;if((n|0)==0){q=gj[c[p+8236>>2]&4095](j)|0}else{q=a[n+j|0]|0}b[e>>1]=(q&255)<<8|m&255;m=d+84|0;c[m>>2]=(c[m>>2]|0)-(788485>>>((c[d+92>>2]|0)>>>0)&127);return}function f6K(d){d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=d+8|0;f=(b[e>>1]|0)+2&65535;b[e>>1]=f;g=d+24|0;h=b[g>>1]|0;i=((f&65535)+65534&65535)+((h&65535)<<4)&1048575;j=c[3531864]|0;k=c[j+44+(i>>>11<<2)>>2]|0;if((k|0)==0){l=gj[c[j+8236>>2]&4095](i)|0;m=l;n=b[g>>1]|0;o=b[e>>1]|0;p=c[3531864]|0}else{m=a[k+i|0]|0;n=h;o=f;p=j}j=((o&65535)+65534&65535)+((n&65535)<<4|1)&1048575;n=c[p+44+(j>>>11<<2)>>2]|0;if((n|0)==0){q=gj[c[p+8236>>2]&4095](j)|0}else{q=a[n+j|0]|0}b[d+10>>1]=(q&255)<<8|m&255;m=d+84|0;c[m>>2]=(c[m>>2]|0)-(788485>>>((c[d+92>>2]|0)>>>0)&127);return}function f6L(d){d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=d+8|0;f=(b[e>>1]|0)+2&65535;b[e>>1]=f;g=d+24|0;h=b[g>>1]|0;i=((f&65535)+65534&65535)+((h&65535)<<4)&1048575;j=c[3531864]|0;k=c[j+44+(i>>>11<<2)>>2]|0;if((k|0)==0){l=gj[c[j+8236>>2]&4095](i)|0;m=l;n=b[g>>1]|0;o=b[e>>1]|0;p=c[3531864]|0}else{m=a[k+i|0]|0;n=h;o=f;p=j}j=((o&65535)+65534&65535)+((n&65535)<<4|1)&1048575;n=c[p+44+(j>>>11<<2)>>2]|0;if((n|0)==0){q=gj[c[p+8236>>2]&4095](j)|0}else{q=a[n+j|0]|0}b[d+12>>1]=(q&255)<<8|m&255;m=d+84|0;c[m>>2]=(c[m>>2]|0)-(788485>>>((c[d+92>>2]|0)>>>0)&127);return}function f6M(d){d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=d+8|0;f=(b[e>>1]|0)+2&65535;b[e>>1]=f;g=d+24|0;h=b[g>>1]|0;i=((f&65535)+65534&65535)+((h&65535)<<4)&1048575;j=c[3531864]|0;k=c[j+44+(i>>>11<<2)>>2]|0;if((k|0)==0){l=gj[c[j+8236>>2]&4095](i)|0;m=l;n=b[g>>1]|0;o=b[e>>1]|0;p=c[3531864]|0}else{m=a[k+i|0]|0;n=h;o=f;p=j}j=((o&65535)+65534&65535)+((n&65535)<<4|1)&1048575;n=c[p+44+(j>>>11<<2)>>2]|0;if((n|0)==0){q=gj[c[p+8236>>2]&4095](j)|0}else{q=a[n+j|0]|0}b[d+14>>1]=(q&255)<<8|m&255;m=d+84|0;c[m>>2]=(c[m>>2]|0)-(788485>>>((c[d+92>>2]|0)>>>0)&127);return}function f6N(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;f=d+8|0;g=b[f>>1]|0;h=g-2&65535;b[f>>1]=h;i=d+24|0;j=((e[i>>1]|0)<<4)+(h&65535)|0;h=b[d>>1]|0;k=h&255;l=j&1048575;m=c[3531864]|0;n=c[m+2092+(l>>>11<<2)>>2]|0;if((n|0)==0){gg[c[m+8240>>2]&4095](l,k);o=c[3531864]|0}else{a[n+l|0]=k;o=m}m=(h&65535)>>>8&255;h=j+1&1048575;j=c[o+2092+(h>>>11<<2)>>2]|0;if((j|0)==0){gg[c[o+8240>>2]&4095](h,m);p=c[3531864]|0}else{a[j+h|0]=m;p=o}o=(b[f>>1]|0)-2&65535;b[f>>1]=o;m=((e[i>>1]|0)<<4)+(o&65535)|0;o=b[d+2>>1]|0;h=o&255;j=m&1048575;k=c[p+2092+(j>>>11<<2)>>2]|0;if((k|0)==0){gg[c[p+8240>>2]&4095](j,h);q=c[3531864]|0}else{a[k+j|0]=h;q=p}p=(o&65535)>>>8&255;o=m+1&1048575;m=c[q+2092+(o>>>11<<2)>>2]|0;if((m|0)==0){gg[c[q+8240>>2]&4095](o,p);r=c[3531864]|0}else{a[m+o|0]=p;r=q}q=(b[f>>1]|0)-2&65535;b[f>>1]=q;p=((e[i>>1]|0)<<4)+(q&65535)|0;q=b[d+4>>1]|0;o=q&255;m=p&1048575;h=c[r+2092+(m>>>11<<2)>>2]|0;if((h|0)==0){gg[c[r+8240>>2]&4095](m,o);s=c[3531864]|0}else{a[h+m|0]=o;s=r}r=(q&65535)>>>8&255;q=p+1&1048575;p=c[s+2092+(q>>>11<<2)>>2]|0;if((p|0)==0){gg[c[s+8240>>2]&4095](q,r);t=c[3531864]|0}else{a[p+q|0]=r;t=s}s=(b[f>>1]|0)-2&65535;b[f>>1]=s;r=((e[i>>1]|0)<<4)+(s&65535)|0;s=b[d+6>>1]|0;q=s&255;p=r&1048575;o=c[t+2092+(p>>>11<<2)>>2]|0;if((o|0)==0){gg[c[t+8240>>2]&4095](p,q);u=c[3531864]|0}else{a[o+p|0]=q;u=t}t=(s&65535)>>>8&255;s=r+1&1048575;r=c[u+2092+(s>>>11<<2)>>2]|0;if((r|0)==0){gg[c[u+8240>>2]&4095](s,t);v=c[3531864]|0}else{a[r+s|0]=t;v=u}u=(b[f>>1]|0)-2&65535;b[f>>1]=u;t=((e[i>>1]|0)<<4)+(u&65535)|0;u=g&255;s=t&1048575;r=c[v+2092+(s>>>11<<2)>>2]|0;if((r|0)==0){gg[c[v+8240>>2]&4095](s,u);w=c[3531864]|0}else{a[r+s|0]=u;w=v}v=(g&65535)>>>8&255;g=t+1&1048575;t=c[w+2092+(g>>>11<<2)>>2]|0;if((t|0)==0){gg[c[w+8240>>2]&4095](g,v);x=c[3531864]|0}else{a[t+g|0]=v;x=w}w=(b[f>>1]|0)-2&65535;b[f>>1]=w;v=((e[i>>1]|0)<<4)+(w&65535)|0;w=b[d+10>>1]|0;g=w&255;t=v&1048575;u=c[x+2092+(t>>>11<<2)>>2]|0;if((u|0)==0){gg[c[x+8240>>2]&4095](t,g);y=c[3531864]|0}else{a[u+t|0]=g;y=x}x=(w&65535)>>>8&255;w=v+1&1048575;v=c[y+2092+(w>>>11<<2)>>2]|0;if((v|0)==0){gg[c[y+8240>>2]&4095](w,x);z=c[3531864]|0}else{a[v+w|0]=x;z=y}y=(b[f>>1]|0)-2&65535;b[f>>1]=y;x=((e[i>>1]|0)<<4)+(y&65535)|0;y=b[d+12>>1]|0;w=y&255;v=x&1048575;g=c[z+2092+(v>>>11<<2)>>2]|0;if((g|0)==0){gg[c[z+8240>>2]&4095](v,w);A=c[3531864]|0}else{a[g+v|0]=w;A=z}z=(y&65535)>>>8&255;y=x+1&1048575;x=c[A+2092+(y>>>11<<2)>>2]|0;if((x|0)==0){gg[c[A+8240>>2]&4095](y,z);B=c[3531864]|0}else{a[x+y|0]=z;B=A}A=(b[f>>1]|0)-2&65535;b[f>>1]=A;f=((e[i>>1]|0)<<4)+(A&65535)|0;A=b[d+14>>1]|0;i=A&255;z=f&1048575;y=c[B+2092+(z>>>11<<2)>>2]|0;if((y|0)==0){gg[c[B+8240>>2]&4095](z,i);C=c[3531864]|0}else{a[y+z|0]=i;C=B}B=(A&65535)>>>8&255;A=f+1&1048575;f=c[C+2092+(A>>>11<<2)>>2]|0;if((f|0)==0){gg[c[C+8240>>2]&4095](A,B);D=d+92|0;E=c[D>>2]|0;F=4399892>>>(E>>>0);G=F&127;H=d+84|0;I=c[H>>2]|0;J=I-G|0;c[H>>2]=J;return}else{a[f+A|0]=B;D=d+92|0;E=c[D>>2]|0;F=4399892>>>(E>>>0);G=F&127;H=d+84|0;I=c[H>>2]|0;J=I-G|0;c[H>>2]=J;return}}function f6O(d){d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0;e=d+8|0;f=(b[e>>1]|0)+2&65535;b[e>>1]=f;g=d+24|0;h=b[g>>1]|0;i=((f&65535)+65534&65535)+((h&65535)<<4)&1048575;j=c[3531864]|0;k=c[j+44+(i>>>11<<2)>>2]|0;if((k|0)==0){l=gj[c[j+8236>>2]&4095](i)|0;m=l;n=b[g>>1]|0;o=b[e>>1]|0;p=c[3531864]|0}else{m=a[k+i|0]|0;n=h;o=f;p=j}j=((o&65535)+65534&65535)+((n&65535)<<4|1)&1048575;f=c[p+44+(j>>>11<<2)>>2]|0;if((f|0)==0){h=gj[c[p+8236>>2]&4095](j)|0;q=h;r=b[e>>1]|0;s=b[g>>1]|0;t=c[3531864]|0}else{q=a[f+j|0]|0;r=o;s=n;t=p}b[d+14>>1]=(q&255)<<8|m&255;m=r+2&65535;b[e>>1]=m;r=((m&65535)+65534&65535)+((s&65535)<<4)&1048575;q=c[t+44+(r>>>11<<2)>>2]|0;if((q|0)==0){p=gj[c[t+8236>>2]&4095](r)|0;u=p;v=b[g>>1]|0;w=b[e>>1]|0;x=c[3531864]|0}else{u=a[q+r|0]|0;v=s;w=m;x=t}t=((w&65535)+65534&65535)+((v&65535)<<4|1)&1048575;m=c[x+44+(t>>>11<<2)>>2]|0;if((m|0)==0){s=gj[c[x+8236>>2]&4095](t)|0;y=s;z=b[e>>1]|0;A=b[g>>1]|0;B=c[3531864]|0}else{y=a[m+t|0]|0;z=w;A=v;B=x}b[d+12>>1]=(y&255)<<8|u&255;u=z+2&65535;b[e>>1]=u;z=((u&65535)+65534&65535)+((A&65535)<<4)&1048575;y=c[B+44+(z>>>11<<2)>>2]|0;if((y|0)==0){x=gj[c[B+8236>>2]&4095](z)|0;C=x;D=b[g>>1]|0;E=b[e>>1]|0;F=c[3531864]|0}else{C=a[y+z|0]|0;D=A;E=u;F=B}B=((E&65535)+65534&65535)+((D&65535)<<4|1)&1048575;u=c[F+44+(B>>>11<<2)>>2]|0;if((u|0)==0){A=gj[c[F+8236>>2]&4095](B)|0;G=A;H=b[e>>1]|0;I=b[g>>1]|0;J=c[3531864]|0}else{G=a[u+B|0]|0;H=E;I=D;J=F}b[d+10>>1]=(G&255)<<8|C&255;C=H+2&65535;b[e>>1]=C;H=((C&65535)+65534&65535)+((I&65535)<<4)&1048575;if((c[J+44+(H>>>11<<2)>>2]|0)==0){G=c[J+8236>>2]|0;gj[G&4095](H)|0;K=b[g>>1]|0;L=b[e>>1]|0;M=c[3531864]|0}else{K=I;L=C;M=J}J=((L&65535)+65534&65535)+((K&65535)<<4|1)&1048575;if((c[M+44+(J>>>11<<2)>>2]|0)==0){C=c[M+8236>>2]|0;gj[C&4095](J)|0;N=b[e>>1]|0;O=b[g>>1]|0;P=c[3531864]|0}else{N=L;O=K;P=M}M=N+2&65535;b[e>>1]=M;N=((M&65535)+65534&65535)+((O&65535)<<4)&1048575;K=c[P+44+(N>>>11<<2)>>2]|0;if((K|0)==0){L=gj[c[P+8236>>2]&4095](N)|0;Q=L;R=b[g>>1]|0;S=b[e>>1]|0;T=c[3531864]|0}else{Q=a[K+N|0]|0;R=O;S=M;T=P}P=((S&65535)+65534&65535)+((R&65535)<<4|1)&1048575;M=c[T+44+(P>>>11<<2)>>2]|0;if((M|0)==0){O=gj[c[T+8236>>2]&4095](P)|0;U=O;V=b[e>>1]|0;W=b[g>>1]|0;X=c[3531864]|0}else{U=a[M+P|0]|0;V=S;W=R;X=T}b[d+6>>1]=(U&255)<<8|Q&255;Q=V+2&65535;b[e>>1]=Q;V=((Q&65535)+65534&65535)+((W&65535)<<4)&1048575;U=c[X+44+(V>>>11<<2)>>2]|0;if((U|0)==0){T=gj[c[X+8236>>2]&4095](V)|0;Y=T;Z=b[g>>1]|0;_=b[e>>1]|0;$=c[3531864]|0}else{Y=a[U+V|0]|0;Z=W;_=Q;$=X}X=((_&65535)+65534&65535)+((Z&65535)<<4|1)&1048575;Q=c[$+44+(X>>>11<<2)>>2]|0;if((Q|0)==0){W=gj[c[$+8236>>2]&4095](X)|0;aa=W;ab=b[e>>1]|0;ac=b[g>>1]|0;ad=c[3531864]|0}else{aa=a[Q+X|0]|0;ab=_;ac=Z;ad=$}b[d+4>>1]=(aa&255)<<8|Y&255;Y=ab+2&65535;b[e>>1]=Y;ab=((Y&65535)+65534&65535)+((ac&65535)<<4)&1048575;aa=c[ad+44+(ab>>>11<<2)>>2]|0;if((aa|0)==0){$=gj[c[ad+8236>>2]&4095](ab)|0;ae=$;af=b[g>>1]|0;ag=b[e>>1]|0;ah=c[3531864]|0}else{ae=a[aa+ab|0]|0;af=ac;ag=Y;ah=ad}ad=((ag&65535)+65534&65535)+((af&65535)<<4|1)&1048575;Y=c[ah+44+(ad>>>11<<2)>>2]|0;if((Y|0)==0){ac=gj[c[ah+8236>>2]&4095](ad)|0;ai=ac;aj=b[e>>1]|0;ak=b[g>>1]|0;al=c[3531864]|0}else{ai=a[Y+ad|0]|0;aj=ag;ak=af;al=ah}b[d+2>>1]=(ai&255)<<8|ae&255;ae=aj+2&65535;b[e>>1]=ae;aj=((ae&65535)+65534&65535)+((ak&65535)<<4)&1048575;ai=c[al+44+(aj>>>11<<2)>>2]|0;if((ai|0)==0){ah=gj[c[al+8236>>2]&4095](aj)|0;am=ah;an=b[g>>1]|0;ao=b[e>>1]|0;ap=c[3531864]|0}else{am=a[ai+aj|0]|0;an=ak;ao=ae;ap=al}al=am&255;am=((ao&65535)+65534&65535)+((an&65535)<<4|1)&1048575;an=c[ap+44+(am>>>11<<2)>>2]|0;if((an|0)==0){aq=gj[c[ap+8236>>2]&4095](am)|0;ar=aq&255;as=ar<<8;at=as|al;au=d|0;b[au>>1]=at;av=d+92|0;aw=c[av>>2]|0;ax=4926230>>>(aw>>>0);ay=ax&127;az=d+84|0;aA=c[az>>2]|0;aB=aA-ay|0;c[az>>2]=aB;return}else{aq=a[an+am|0]|0;ar=aq&255;as=ar<<8;at=as|al;au=d|0;b[au>>1]=at;av=d+92|0;aw=c[av>>2]|0;ax=4926230>>>(aw>>>0);ay=ax&127;az=d+84|0;aA=c[az>>2]|0;aB=aA-ay|0;c[az>>2]=aB;return}}function f6P(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=(e[d+22>>1]|0)<<4;g=(c[2385310]|0)+28|0;h=b[g>>1]|0;b[g>>1]=h+1&65535;g=(h&65535)+f&1048575;f=c[3531864]|0;h=c[f+6188+(g>>>11<<2)>>2]|0;if((h|0)==0){i=gj[c[f+8236>>2]&4095](g)|0}else{i=a[h+g|0]|0}g=i&255;if((i&255)>191){j=e[d+(c[9650784+(g<<2)>>2]<<1)>>1]|0}else{i=c[679712+(g<<2)>>2]|0;gj[i&4095](d)|0;i=c[2426956]|0;h=i&1048575;f=c[3531864]|0;k=c[f+44+(h>>>11<<2)>>2]|0;if((k|0)==0){l=gj[c[f+8236>>2]&4095](h)|0;m=l;n=c[2426956]|0;o=c[3531864]|0}else{m=a[k+h|0]|0;n=i;o=f}f=n+1&1048575;n=c[o+44+(f>>>11<<2)>>2]|0;if((n|0)==0){p=gj[c[o+8236>>2]&4095](f)|0}else{p=a[n+f|0]|0}j=(p&255)<<8|m&255}m=c[2426956]|0;p=m+2&65535|m&983040;f=c[3531864]|0;n=c[f+44+(p>>>11<<2)>>2]|0;if((n|0)==0){o=gj[c[f+8236>>2]&4095](p)|0;q=o;r=c[2426956]|0;s=c[3531864]|0}else{q=a[n+p|0]|0;r=m;s=f}f=(r+2&65535|r&983040)+1&1048575;r=c[s+44+(f>>>11<<2)>>2]|0;if((r|0)==0){t=gj[c[s+8236>>2]&4095](f)|0}else{t=a[r+f|0]|0}f=e[d+(c[9654880+(g<<2)>>2]<<1)>>1]|0;do{if(f>>>0>=j>>>0){if(f>>>0>((t&255)<<8|q&255)>>>0){break}u=d+84|0;v=c[u>>2]|0;w=v-20|0;c[u>>2]=w;return}}while(0);f9v(d,5,0);u=d+84|0;v=c[u>>2]|0;w=v-20|0;c[u>>2]=w;return}function f6Q(a){a=a|0;var b=0;b=a+84|0;c[b>>2]=(c[b>>2]|0)-10;return}function f6R(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0;g=f+90|0;a[g]=(a[g]|0)-1&255;h=f+22|0;i=e[h>>1]<<4;j=f+28|0;k=b[j>>1]|0;b[j>>1]=k+1&65535;l=f+16|0;m=(i+(k&65535)^c[l>>2])&1048575;k=c[3531864]|0;i=c[k+4140+(m>>>11<<2)>>2]|0;if((i|0)==0){n=gj[c[k+8236>>2]&4095](m)|0}else{n=a[i+m|0]|0}m=n&255;n=f+2|0;i=b[n>>1]|0;if((m|0)==54){a[f+100|0]=1;c[f+96>>2]=e[f+24>>1]<<4;a[g]=(a[g]|0)-1&255;k=e[h>>1]<<4;o=b[j>>1]|0;b[j>>1]=o+1&65535;p=(k+(o&65535)^c[l>>2])&1048575;o=c[3531864]|0;k=c[o+4140+(p>>>11<<2)>>2]|0;if((k|0)==0){q=gj[c[o+8236>>2]&4095](p)|0}else{q=a[k+p|0]|0}p=f+84|0;c[p>>2]=(c[p>>2]|0)-2;r=q&255}else if((m|0)==46){a[f+100|0]=1;q=e[h>>1]<<4;c[f+96>>2]=q;a[g]=(a[g]|0)-1&255;p=b[j>>1]|0;b[j>>1]=p+1&65535;k=((p&65535)+q^c[l>>2])&1048575;q=c[3531864]|0;p=c[q+4140+(k>>>11<<2)>>2]|0;if((p|0)==0){s=gj[c[q+8236>>2]&4095](k)|0}else{s=a[p+k|0]|0}k=f+84|0;c[k>>2]=(c[k>>2]|0)-2;r=s&255}else if((m|0)==62){a[f+100|0]=1;c[f+96>>2]=e[f+26>>1]<<4;a[g]=(a[g]|0)-1&255;s=e[h>>1]<<4;k=b[j>>1]|0;b[j>>1]=k+1&65535;p=(s+(k&65535)^c[l>>2])&1048575;k=c[3531864]|0;s=c[k+4140+(p>>>11<<2)>>2]|0;if((s|0)==0){t=gj[c[k+8236>>2]&4095](p)|0}else{t=a[s+p|0]|0}p=f+84|0;c[p>>2]=(c[p>>2]|0)-2;r=t&255}else if((m|0)==38){a[f+100|0]=1;c[f+96>>2]=e[f+20>>1]<<4;a[g]=(a[g]|0)-1&255;g=e[h>>1]<<4;h=b[j>>1]|0;b[j>>1]=h+1&65535;j=(g+(h&65535)^c[l>>2])&1048575;l=c[3531864]|0;h=c[l+4140+(j>>>11<<2)>>2]|0;if((h|0)==0){u=gj[c[l+8236>>2]&4095](j)|0}else{u=a[h+j|0]|0}j=f+84|0;c[j>>2]=(c[j>>2]|0)-2;r=u&255}else{r=m}switch(r|0){case 108:{m=f+84|0;c[m>>2]=(c[m>>2]|0)-2;L56460:do{if(i<<16>>16==0){v=0}else{u=f+48|0;j=f+20|0;h=f+14|0;l=f+4|0;g=f+58|0;t=i;p=b[h>>1]|0;while(1){s=(e[j>>1]<<4)+(p&65535)|0;k=gj[c[(c[3531864]|0)+8244>>2]&4095](b[l>>1]&255)|0;q=s&1048575;s=c[3531864]|0;o=c[s+2092+(q>>>11<<2)>>2]|0;if((o|0)==0){gg[c[s+8240>>2]&4095](q,k)}else{a[o+q|0]=k}k=((d[g]|0)*-2&65535|1)+(b[h>>1]|0)&65535;b[h>>1]=k;c[m>>2]=(c[m>>2]|0)-8;q=t-1&65535;if(q<<16>>16==0){v=0;break L56460}if((c[u>>2]|0)==0){t=q;p=k}else{v=q;break}}}}while(0);b[n>>1]=v;w=f+100|0;a[w]=0;return};case 109:{v=f+84|0;c[v>>2]=(c[v>>2]|0)-2;L56472:do{if(i<<16>>16==0){x=0}else{m=f+48|0;p=f+20|0;t=f+14|0;u=f+4|0;h=f+58|0;g=f+92|0;l=i;j=b[t>>1]|0;while(1){q=(e[p>>1]<<4)+(j&65535)|0;k=gj[c[(c[3531864]|0)+8244>>2]&4095](b[u>>1]&255)|0;o=gj[c[(c[3531864]|0)+8244>>2]&4095]((e[u>>1]|0)+1&65791)|0;s=q&1048575;y=c[3531864]|0;z=c[y+2092+(s>>>11<<2)>>2]|0;if((z|0)==0){gg[c[y+8240>>2]&4095](s,k);A=c[3531864]|0}else{a[z+s|0]=k;A=y}y=q+1&1048575;q=c[A+2092+(y>>>11<<2)>>2]|0;if((q|0)==0){gg[c[A+8240>>2]&4095](y,o)}else{a[q+y|0]=o}o=((d[h]|0)*-4&65535|2)+(b[t>>1]|0)&65535;b[t>>1]=o;c[v>>2]=(c[v>>2]|0)-(1182216>>>((c[g>>2]|0)>>>0)&127);y=l-1&65535;if(y<<16>>16==0){x=0;break L56472}if((c[m>>2]|0)==0){l=y;j=o}else{x=y;break}}}}while(0);b[n>>1]=x;w=f+100|0;a[w]=0;return};case 110:{x=f+84|0;c[x>>2]=(c[x>>2]|0)-2;L56488:do{if(i<<16>>16==0){B=0}else{v=f+48|0;A=f+4|0;j=f+100|0;l=f+26|0;m=f+12|0;g=f+58|0;t=f+96|0;h=i;while(1){u=e[A>>1]|0;if((a[j]|0)==0){C=e[l>>1]<<4}else{C=c[t>>2]|0}p=(e[m>>1]|0)+C&1048575;y=c[3531864]|0;o=c[y+44+(p>>>11<<2)>>2]|0;if((o|0)==0){q=gj[c[y+8236>>2]&4095](p)|0;D=q;E=c[3531864]|0}else{D=a[o+p|0]|0;E=y}gg[c[E+8248>>2]&4095](u,D);b[m>>1]=((d[g]|0)*-2&65535|1)+(b[m>>1]|0)&65535;c[x>>2]=(c[x>>2]|0)-8;u=h-1&65535;if(u<<16>>16==0){B=0;break L56488}if((c[v>>2]|0)==0){h=u}else{B=u;break}}}}while(0);b[n>>1]=B;w=f+100|0;a[w]=0;return};case 111:{B=f+84|0;c[B>>2]=(c[B>>2]|0)-2;L56504:do{if(i<<16>>16==0){F=0}else{B=f+48|0;x=i;while(1){f6_(f);D=x-1&65535;if(D<<16>>16==0){F=0;break L56504}if((c[B>>2]|0)==0){x=D}else{F=D;break}}}}while(0);b[n>>1]=F;w=f+100|0;a[w]=0;return};case 164:{F=f+84|0;c[F>>2]=(c[F>>2]|0)-2;L56512:do{if(i<<16>>16==0){G=0}else{x=f+48|0;B=f+100|0;D=f+26|0;E=f+12|0;C=f+20|0;h=f+14|0;v=f+58|0;m=f+92|0;g=f+96|0;t=i;while(1){if((a[B]|0)==0){H=e[D>>1]<<4}else{H=c[g>>2]|0}l=(e[E>>1]|0)+H&1048575;j=c[3531864]|0;A=c[j+44+(l>>>11<<2)>>2]|0;if((A|0)==0){u=gj[c[j+8236>>2]&4095](l)|0;I=u;J=c[3531864]|0}else{I=a[A+l|0]|0;J=j}j=(e[C>>1]<<4)+(e[h>>1]|0)&1048575;l=c[J+2092+(j>>>11<<2)>>2]|0;if((l|0)==0){gg[c[J+8240>>2]&4095](j,I)}else{a[l+j|0]=I}j=(d[v]|0)*-2&65535|1;b[h>>1]=j+(b[h>>1]|0)&65535;b[E>>1]=j+(b[E>>1]|0)&65535;c[F>>2]=(c[F>>2]|0)-(526342>>>((c[m>>2]|0)>>>0)&127);j=t-1&65535;if(j<<16>>16==0){G=0;break L56512}if((c[x>>2]|0)==0){t=j}else{G=j;break}}}}while(0);b[n>>1]=G;w=f+100|0;a[w]=0;return};case 165:{G=f+84|0;c[G>>2]=(c[G>>2]|0)-2;L56532:do{if(i<<16>>16==0){K=0}else{G=f+48|0;F=i;while(1){f7Q(f);I=F-1&65535;if(I<<16>>16==0){K=0;break L56532}if((c[G>>2]|0)==0){F=I}else{K=I;break}}}}while(0);b[n>>1]=K;w=f+100|0;a[w]=0;return};case 166:{K=f+84|0;c[K>>2]=(c[K>>2]|0)-2;L56540:do{if(i<<16>>16==0){L=0}else{K=f+48|0;F=i;while(1){f7R(f);G=F-1&65535;if(G<<16>>16==0){L=0;break L56540}if((c[K>>2]|0)==0){F=G}else{L=G;break}}}}while(0);b[n>>1]=L;w=f+100|0;a[w]=0;return};case 167:{L=f+84|0;c[L>>2]=(c[L>>2]|0)-2;L56548:do{if(i<<16>>16==0){M=0}else{L=f+48|0;F=i;while(1){f7S(f);K=F-1&65535;if(K<<16>>16==0){M=0;break L56548}if((c[L>>2]|0)==0){F=K}else{M=K;break}}}}while(0);b[n>>1]=M;w=f+100|0;a[w]=0;return};case 170:{M=f+84|0;c[M>>2]=(c[M>>2]|0)-2;L56556:do{if(i<<16>>16==0){N=0}else{F=f+48|0;L=f+20|0;K=f+14|0;G=f;I=f+58|0;J=f+92|0;H=i;t=b[K>>1]|0;while(1){x=a[G]|0;m=(e[L>>1]<<4)+(t&65535)&1048575;E=c[3531864]|0;h=c[E+2092+(m>>>11<<2)>>2]|0;if((h|0)==0){gg[c[E+8240>>2]&4095](m,x)}else{a[h+m|0]=x}x=((d[I]|0)*-2&65535|1)+(b[K>>1]|0)&65535;b[K>>1]=x;c[M>>2]=(c[M>>2]|0)-(263171>>>((c[J>>2]|0)>>>0)&127);m=H-1&65535;if(m<<16>>16==0){N=0;break L56556}if((c[F>>2]|0)==0){H=m;t=x}else{N=m;break}}}}while(0);b[n>>1]=N;w=f+100|0;a[w]=0;return};case 171:{N=f+84|0;c[N>>2]=(c[N>>2]|0)-2;L56568:do{if(i<<16>>16==0){O=0}else{M=f+48|0;t=f+20|0;H=f+14|0;F=f|0;J=f+58|0;K=f+92|0;I=i;L=b[H>>1]|0;while(1){G=(e[t>>1]<<4)+(L&65535)|0;m=b[F>>1]|0;x=m&255;h=G&1048575;E=c[3531864]|0;v=c[E+2092+(h>>>11<<2)>>2]|0;if((v|0)==0){gg[c[E+8240>>2]&4095](h,x);P=c[3531864]|0}else{a[v+h|0]=x;P=E}E=(m&65535)>>>8&255;m=G+1&1048575;G=c[P+2092+(m>>>11<<2)>>2]|0;if((G|0)==0){gg[c[P+8240>>2]&4095](m,E)}else{a[G+m|0]=E}E=(d[J]|0)*-4&65535;m=b[H>>1]|0;G=(E|2)+m&65535;b[H>>1]=G;c[N>>2]=(c[N>>2]|0)-(((E+m&1)!=0?526341:525315)>>>((c[K>>2]|0)>>>0)&127);m=I-1&65535;if(m<<16>>16==0){O=0;break L56568}if((c[M>>2]|0)==0){I=m;L=G}else{O=m;break}}}}while(0);b[n>>1]=O;w=f+100|0;a[w]=0;return};case 172:{O=f+84|0;N=(c[O>>2]|0)-2|0;c[O>>2]=N;L56584:do{if(i<<16>>16==0){Q=0}else{P=f+48|0;L=f+100|0;I=f+26|0;M=f+12|0;K=f;H=f+58|0;J=f+92|0;F=f+96|0;t=i;m=N;while(1){if((a[L]|0)==0){R=e[I>>1]<<4}else{R=c[F>>2]|0}G=b[M>>1]|0;E=(G&65535)+R&1048575;x=c[3531864]|0;h=c[x+44+(E>>>11<<2)>>2]|0;if((h|0)==0){v=gj[c[x+8236>>2]&4095](E)|0;S=v;T=b[M>>1]|0;U=c[O>>2]|0}else{S=a[h+E|0]|0;T=G;U=m}a[K]=S;b[M>>1]=((d[H]|0)*-2&65535|1)+T&65535;G=U-(263171>>>((c[J>>2]|0)>>>0)&127)|0;c[O>>2]=G;E=t-1&65535;if(E<<16>>16==0){Q=0;break L56584}if((c[P>>2]|0)==0){t=E;m=G}else{Q=E;break}}}}while(0);b[n>>1]=Q;w=f+100|0;a[w]=0;return};case 173:{Q=f+84|0;c[Q>>2]=(c[Q>>2]|0)-2;L56600:do{if(i<<16>>16==0){V=0}else{Q=f+48|0;O=i;while(1){f7Y(f);U=O-1&65535;if(U<<16>>16==0){V=0;break L56600}if((c[Q>>2]|0)==0){O=U}else{V=U;break}}}}while(0);b[n>>1]=V;w=f+100|0;a[w]=0;return};case 174:{V=f+84|0;O=(c[V>>2]|0)-2|0;c[V>>2]=O;L56608:do{if(i<<16>>16==0){W=0}else{Q=f+20|0;U=f+14|0;T=f;S=f+48|0;R=f+40|0;N=f+36|0;m=f+52|0;t=f+44|0;P=f+32|0;J=f+58|0;H=f+92|0;M=i;K=b[U>>1]|0;F=O;while(1){I=(e[Q>>1]<<4)+(K&65535)&1048575;L=c[3531864]|0;E=c[L+44+(I>>>11<<2)>>2]|0;if((E|0)==0){G=gj[c[L+8236>>2]&4095](I)|0;X=G;Y=b[U>>1]|0;Z=c[V>>2]|0}else{X=a[E+I|0]|0;Y=K;Z=F}I=a[T]|0;E=I&255;G=E-(X&255)|0;L=G&256;c[S>>2]=L;h=(I^X)&255;c[R>>2]=h&128&(G^E);c[N>>2]=(G^h)&16;h=G<<24>>24;c[m>>2]=h;c[t>>2]=h;c[P>>2]=h;h=((d[J]|0)*-2&65535|1)+Y&65535;b[U>>1]=h;G=Z-(263171>>>((c[H>>2]|0)>>>0)&127)|0;c[V>>2]=G;E=M-1&65535;if(E<<16>>16==0){W=0;break L56608}if((L|0)==0){M=E;K=h;F=G}else{W=E;break}}}}while(0);b[n>>1]=W;w=f+100|0;a[w]=0;return};case 175:{W=f+84|0;c[W>>2]=(c[W>>2]|0)-2;L56620:do{if(i<<16>>16==0){_=0}else{V=f+20|0;Z=f+14|0;Y=f|0;X=f+48|0;O=f+40|0;F=f+36|0;K=f+52|0;M=f+44|0;H=f+32|0;U=f+58|0;J=f+92|0;P=i;t=b[Z>>1]|0;while(1){m=b[V>>1]|0;N=((m&65535)<<4)+(t&65535)&1048575;R=c[3531864]|0;S=c[R+44+(N>>>11<<2)>>2]|0;if((S|0)==0){T=gj[c[R+8236>>2]&4095](N)|0;$=T;aa=b[V>>1]|0;ab=b[Z>>1]|0;ac=c[3531864]|0}else{$=a[S+N|0]|0;aa=m;ab=t;ac=R}R=(ab&65535)+1+((aa&65535)<<4)&1048575;m=c[ac+44+(R>>>11<<2)>>2]|0;if((m|0)==0){N=gj[c[ac+8236>>2]&4095](R)|0;ad=N;ae=b[Z>>1]|0}else{ad=a[m+R|0]|0;ae=ab}R=(ad&255)<<8|$&255;m=e[Y>>1]|0;N=m-R|0;S=N&65536;c[X>>2]=S;T=R^m;c[O>>2]=T&32768&(N^m);c[F>>2]=(N^T)&16;T=N<<16>>16;c[K>>2]=T;c[M>>2]=T;c[H>>2]=T;T=(d[U]|0)*-4&65535;N=(T|2)+ae&65535;b[Z>>1]=N;c[W>>2]=(c[W>>2]|0)-(((T+ae&1)!=0?526341:525315)>>>((c[J>>2]|0)>>>0)&127);T=P-1&65535;if(T<<16>>16==0){_=0;break L56620}if((S|0)==0){P=T;t=N}else{_=T;break}}}}while(0);b[n>>1]=_;w=f+100|0;a[w]=0;return};default:{gf[c[2520528+(r<<2)>>2]&2047](f);w=f+100|0;a[w]=0;return}}}function f6S(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0;g=f+90|0;a[g]=(a[g]|0)-1&255;h=f+22|0;i=e[h>>1]<<4;j=f+28|0;k=b[j>>1]|0;b[j>>1]=k+1&65535;l=f+16|0;m=(i+(k&65535)^c[l>>2])&1048575;k=c[3531864]|0;i=c[k+4140+(m>>>11<<2)>>2]|0;if((i|0)==0){n=gj[c[k+8236>>2]&4095](m)|0}else{n=a[i+m|0]|0}m=n&255;n=f+2|0;i=b[n>>1]|0;if((m|0)==54){a[f+100|0]=1;c[f+96>>2]=e[f+24>>1]<<4;a[g]=(a[g]|0)-1&255;k=e[h>>1]<<4;o=b[j>>1]|0;b[j>>1]=o+1&65535;p=(k+(o&65535)^c[l>>2])&1048575;o=c[3531864]|0;k=c[o+4140+(p>>>11<<2)>>2]|0;if((k|0)==0){q=gj[c[o+8236>>2]&4095](p)|0}else{q=a[k+p|0]|0}p=f+84|0;c[p>>2]=(c[p>>2]|0)-2;r=q&255}else if((m|0)==46){a[f+100|0]=1;q=e[h>>1]<<4;c[f+96>>2]=q;a[g]=(a[g]|0)-1&255;p=b[j>>1]|0;b[j>>1]=p+1&65535;k=((p&65535)+q^c[l>>2])&1048575;q=c[3531864]|0;p=c[q+4140+(k>>>11<<2)>>2]|0;if((p|0)==0){s=gj[c[q+8236>>2]&4095](k)|0}else{s=a[p+k|0]|0}k=f+84|0;c[k>>2]=(c[k>>2]|0)-2;r=s&255}else if((m|0)==62){a[f+100|0]=1;c[f+96>>2]=e[f+26>>1]<<4;a[g]=(a[g]|0)-1&255;s=e[h>>1]<<4;k=b[j>>1]|0;b[j>>1]=k+1&65535;p=(s+(k&65535)^c[l>>2])&1048575;k=c[3531864]|0;s=c[k+4140+(p>>>11<<2)>>2]|0;if((s|0)==0){t=gj[c[k+8236>>2]&4095](p)|0}else{t=a[s+p|0]|0}p=f+84|0;c[p>>2]=(c[p>>2]|0)-2;r=t&255}else if((m|0)==38){a[f+100|0]=1;c[f+96>>2]=e[f+20>>1]<<4;a[g]=(a[g]|0)-1&255;g=e[h>>1]<<4;h=b[j>>1]|0;b[j>>1]=h+1&65535;j=(g+(h&65535)^c[l>>2])&1048575;l=c[3531864]|0;h=c[l+4140+(j>>>11<<2)>>2]|0;if((h|0)==0){u=gj[c[l+8236>>2]&4095](j)|0}else{u=a[h+j|0]|0}j=f+84|0;c[j>>2]=(c[j>>2]|0)-2;r=u&255}else{r=m}switch(r|0){case 108:{m=f+84|0;c[m>>2]=(c[m>>2]|0)-2;L56666:do{if(i<<16>>16==0){v=0}else{u=f+48|0;j=f+20|0;h=f+14|0;l=f+4|0;g=f+58|0;t=i;p=b[h>>1]|0;while(1){s=(e[j>>1]<<4)+(p&65535)|0;k=gj[c[(c[3531864]|0)+8244>>2]&4095](b[l>>1]&255)|0;q=s&1048575;s=c[3531864]|0;o=c[s+2092+(q>>>11<<2)>>2]|0;if((o|0)==0){gg[c[s+8240>>2]&4095](q,k)}else{a[o+q|0]=k}k=((d[g]|0)*-2&65535|1)+(b[h>>1]|0)&65535;b[h>>1]=k;c[m>>2]=(c[m>>2]|0)-8;q=t-1&65535;if(q<<16>>16==0){v=0;break L56666}if((c[u>>2]|0)==0){v=q;break}else{t=q;p=k}}}}while(0);b[n>>1]=v;w=f+100|0;a[w]=0;return};case 109:{v=f+84|0;c[v>>2]=(c[v>>2]|0)-2;L56678:do{if(i<<16>>16==0){x=0}else{m=f+48|0;p=f+20|0;t=f+14|0;u=f+4|0;h=f+58|0;g=f+92|0;l=i;j=b[t>>1]|0;while(1){k=(e[p>>1]<<4)+(j&65535)|0;q=gj[c[(c[3531864]|0)+8244>>2]&4095](b[u>>1]&255)|0;o=gj[c[(c[3531864]|0)+8244>>2]&4095]((e[u>>1]|0)+1&65791)|0;s=k&1048575;y=c[3531864]|0;z=c[y+2092+(s>>>11<<2)>>2]|0;if((z|0)==0){gg[c[y+8240>>2]&4095](s,q);A=c[3531864]|0}else{a[z+s|0]=q;A=y}y=k+1&1048575;k=c[A+2092+(y>>>11<<2)>>2]|0;if((k|0)==0){gg[c[A+8240>>2]&4095](y,o)}else{a[k+y|0]=o}o=((d[h]|0)*-4&65535|2)+(b[t>>1]|0)&65535;b[t>>1]=o;c[v>>2]=(c[v>>2]|0)-(1182216>>>((c[g>>2]|0)>>>0)&127);y=l-1&65535;if(y<<16>>16==0){x=0;break L56678}if((c[m>>2]|0)==0){x=y;break}else{l=y;j=o}}}}while(0);b[n>>1]=x;w=f+100|0;a[w]=0;return};case 110:{x=f+84|0;c[x>>2]=(c[x>>2]|0)-2;L56694:do{if(i<<16>>16==0){B=0}else{v=f+48|0;A=f+4|0;j=f+100|0;l=f+26|0;m=f+12|0;g=f+58|0;t=f+96|0;h=i;while(1){u=e[A>>1]|0;if((a[j]|0)==0){C=e[l>>1]<<4}else{C=c[t>>2]|0}p=(e[m>>1]|0)+C&1048575;o=c[3531864]|0;y=c[o+44+(p>>>11<<2)>>2]|0;if((y|0)==0){k=gj[c[o+8236>>2]&4095](p)|0;D=k;E=c[3531864]|0}else{D=a[y+p|0]|0;E=o}gg[c[E+8248>>2]&4095](u,D);b[m>>1]=((d[g]|0)*-2&65535|1)+(b[m>>1]|0)&65535;c[x>>2]=(c[x>>2]|0)-8;u=h-1&65535;if(u<<16>>16==0){B=0;break L56694}if((c[v>>2]|0)==0){B=u;break}else{h=u}}}}while(0);b[n>>1]=B;w=f+100|0;a[w]=0;return};case 111:{B=f+84|0;c[B>>2]=(c[B>>2]|0)-2;L56710:do{if(i<<16>>16==0){F=0}else{B=f+48|0;x=i;while(1){f6_(f);D=x-1&65535;if(D<<16>>16==0){F=0;break L56710}if((c[B>>2]|0)==0){F=D;break}else{x=D}}}}while(0);b[n>>1]=F;w=f+100|0;a[w]=0;return};case 164:{F=f+84|0;c[F>>2]=(c[F>>2]|0)-2;L56718:do{if(i<<16>>16==0){G=0}else{x=f+48|0;B=f+100|0;D=f+26|0;E=f+12|0;C=f+20|0;h=f+14|0;v=f+58|0;m=f+92|0;g=f+96|0;t=i;while(1){if((a[B]|0)==0){H=e[D>>1]<<4}else{H=c[g>>2]|0}l=(e[E>>1]|0)+H&1048575;j=c[3531864]|0;A=c[j+44+(l>>>11<<2)>>2]|0;if((A|0)==0){u=gj[c[j+8236>>2]&4095](l)|0;I=u;J=c[3531864]|0}else{I=a[A+l|0]|0;J=j}j=(e[C>>1]<<4)+(e[h>>1]|0)&1048575;l=c[J+2092+(j>>>11<<2)>>2]|0;if((l|0)==0){gg[c[J+8240>>2]&4095](j,I)}else{a[l+j|0]=I}j=(d[v]|0)*-2&65535|1;b[h>>1]=j+(b[h>>1]|0)&65535;b[E>>1]=j+(b[E>>1]|0)&65535;c[F>>2]=(c[F>>2]|0)-(526342>>>((c[m>>2]|0)>>>0)&127);j=t-1&65535;if(j<<16>>16==0){G=0;break L56718}if((c[x>>2]|0)==0){G=j;break}else{t=j}}}}while(0);b[n>>1]=G;w=f+100|0;a[w]=0;return};case 165:{G=f+84|0;c[G>>2]=(c[G>>2]|0)-2;L56738:do{if(i<<16>>16==0){K=0}else{G=f+48|0;F=i;while(1){f7Q(f);I=F-1&65535;if(I<<16>>16==0){K=0;break L56738}if((c[G>>2]|0)==0){K=I;break}else{F=I}}}}while(0);b[n>>1]=K;w=f+100|0;a[w]=0;return};case 166:{K=f+84|0;c[K>>2]=(c[K>>2]|0)-2;L56746:do{if(i<<16>>16==0){L=0}else{K=f+48|0;F=i;while(1){f7R(f);G=F-1&65535;if(G<<16>>16==0){L=0;break L56746}if((c[K>>2]|0)==0){L=G;break}else{F=G}}}}while(0);b[n>>1]=L;w=f+100|0;a[w]=0;return};case 167:{L=f+84|0;c[L>>2]=(c[L>>2]|0)-2;L56754:do{if(i<<16>>16==0){M=0}else{L=f+48|0;F=i;while(1){f7S(f);K=F-1&65535;if(K<<16>>16==0){M=0;break L56754}if((c[L>>2]|0)==0){M=K;break}else{F=K}}}}while(0);b[n>>1]=M;w=f+100|0;a[w]=0;return};case 170:{M=f+84|0;c[M>>2]=(c[M>>2]|0)-2;L56762:do{if(i<<16>>16==0){N=0}else{F=f+48|0;L=f+20|0;K=f+14|0;G=f;I=f+58|0;J=f+92|0;H=i;t=b[K>>1]|0;while(1){x=a[G]|0;m=(e[L>>1]<<4)+(t&65535)&1048575;E=c[3531864]|0;h=c[E+2092+(m>>>11<<2)>>2]|0;if((h|0)==0){gg[c[E+8240>>2]&4095](m,x)}else{a[h+m|0]=x}x=((d[I]|0)*-2&65535|1)+(b[K>>1]|0)&65535;b[K>>1]=x;c[M>>2]=(c[M>>2]|0)-(263171>>>((c[J>>2]|0)>>>0)&127);m=H-1&65535;if(m<<16>>16==0){N=0;break L56762}if((c[F>>2]|0)==0){N=m;break}else{H=m;t=x}}}}while(0);b[n>>1]=N;w=f+100|0;a[w]=0;return};case 171:{N=f+84|0;c[N>>2]=(c[N>>2]|0)-2;L56774:do{if(i<<16>>16==0){O=0}else{M=f+48|0;t=f+20|0;H=f+14|0;F=f|0;J=f+58|0;K=f+92|0;I=i;L=b[H>>1]|0;while(1){G=(e[t>>1]<<4)+(L&65535)|0;x=b[F>>1]|0;m=x&255;h=G&1048575;E=c[3531864]|0;v=c[E+2092+(h>>>11<<2)>>2]|0;if((v|0)==0){gg[c[E+8240>>2]&4095](h,m);P=c[3531864]|0}else{a[v+h|0]=m;P=E}E=(x&65535)>>>8&255;x=G+1&1048575;G=c[P+2092+(x>>>11<<2)>>2]|0;if((G|0)==0){gg[c[P+8240>>2]&4095](x,E)}else{a[G+x|0]=E}E=(d[J]|0)*-4&65535;x=b[H>>1]|0;G=(E|2)+x&65535;b[H>>1]=G;c[N>>2]=(c[N>>2]|0)-(((E+x&1)!=0?526341:525315)>>>((c[K>>2]|0)>>>0)&127);x=I-1&65535;if(x<<16>>16==0){O=0;break L56774}if((c[M>>2]|0)==0){O=x;break}else{I=x;L=G}}}}while(0);b[n>>1]=O;w=f+100|0;a[w]=0;return};case 172:{O=f+84|0;N=(c[O>>2]|0)-2|0;c[O>>2]=N;L56790:do{if(i<<16>>16==0){Q=0}else{P=f+48|0;L=f+100|0;I=f+26|0;M=f+12|0;K=f;H=f+58|0;J=f+92|0;F=f+96|0;t=i;G=N;while(1){if((a[L]|0)==0){R=e[I>>1]<<4}else{R=c[F>>2]|0}x=b[M>>1]|0;E=(x&65535)+R&1048575;m=c[3531864]|0;h=c[m+44+(E>>>11<<2)>>2]|0;if((h|0)==0){v=gj[c[m+8236>>2]&4095](E)|0;S=v;T=b[M>>1]|0;U=c[O>>2]|0}else{S=a[h+E|0]|0;T=x;U=G}a[K]=S;b[M>>1]=((d[H]|0)*-2&65535|1)+T&65535;x=U-(263171>>>((c[J>>2]|0)>>>0)&127)|0;c[O>>2]=x;E=t-1&65535;if(E<<16>>16==0){Q=0;break L56790}if((c[P>>2]|0)==0){Q=E;break}else{t=E;G=x}}}}while(0);b[n>>1]=Q;w=f+100|0;a[w]=0;return};case 173:{Q=f+84|0;c[Q>>2]=(c[Q>>2]|0)-2;L56806:do{if(i<<16>>16==0){V=0}else{Q=f+48|0;O=i;while(1){f7Y(f);U=O-1&65535;if(U<<16>>16==0){V=0;break L56806}if((c[Q>>2]|0)==0){V=U;break}else{O=U}}}}while(0);b[n>>1]=V;w=f+100|0;a[w]=0;return};case 174:{V=f+84|0;O=(c[V>>2]|0)-2|0;c[V>>2]=O;L56814:do{if(i<<16>>16==0){W=0}else{Q=f+20|0;U=f+14|0;T=f;S=f+48|0;R=f+40|0;N=f+36|0;G=f+52|0;t=f+44|0;P=f+32|0;J=f+58|0;H=f+92|0;M=i;K=b[U>>1]|0;F=O;while(1){I=(e[Q>>1]<<4)+(K&65535)&1048575;L=c[3531864]|0;x=c[L+44+(I>>>11<<2)>>2]|0;if((x|0)==0){E=gj[c[L+8236>>2]&4095](I)|0;X=E;Y=b[U>>1]|0;Z=c[V>>2]|0}else{X=a[x+I|0]|0;Y=K;Z=F}I=a[T]|0;x=I&255;E=x-(X&255)|0;L=E&256;c[S>>2]=L;h=(I^X)&255;c[R>>2]=h&128&(E^x);c[N>>2]=(E^h)&16;h=E<<24>>24;c[G>>2]=h;c[t>>2]=h;c[P>>2]=h;h=((d[J]|0)*-2&65535|1)+Y&65535;b[U>>1]=h;E=Z-(263171>>>((c[H>>2]|0)>>>0)&127)|0;c[V>>2]=E;x=M-1&65535;if(x<<16>>16==0){W=0;break L56814}if((L|0)==0){W=x;break}else{M=x;K=h;F=E}}}}while(0);b[n>>1]=W;w=f+100|0;a[w]=0;return};case 175:{W=f+84|0;c[W>>2]=(c[W>>2]|0)-2;L56826:do{if(i<<16>>16==0){_=0}else{V=f+20|0;Z=f+14|0;Y=f|0;X=f+48|0;O=f+40|0;F=f+36|0;K=f+52|0;M=f+44|0;H=f+32|0;U=f+58|0;J=f+92|0;P=i;t=b[Z>>1]|0;while(1){G=b[V>>1]|0;N=((G&65535)<<4)+(t&65535)&1048575;R=c[3531864]|0;S=c[R+44+(N>>>11<<2)>>2]|0;if((S|0)==0){T=gj[c[R+8236>>2]&4095](N)|0;$=T;aa=b[V>>1]|0;ab=b[Z>>1]|0;ac=c[3531864]|0}else{$=a[S+N|0]|0;aa=G;ab=t;ac=R}R=(ab&65535)+1+((aa&65535)<<4)&1048575;G=c[ac+44+(R>>>11<<2)>>2]|0;if((G|0)==0){N=gj[c[ac+8236>>2]&4095](R)|0;ad=N;ae=b[Z>>1]|0}else{ad=a[G+R|0]|0;ae=ab}R=(ad&255)<<8|$&255;G=e[Y>>1]|0;N=G-R|0;S=N&65536;c[X>>2]=S;T=R^G;c[O>>2]=T&32768&(N^G);c[F>>2]=(N^T)&16;T=N<<16>>16;c[K>>2]=T;c[M>>2]=T;c[H>>2]=T;T=(d[U]|0)*-4&65535;N=(T|2)+ae&65535;b[Z>>1]=N;c[W>>2]=(c[W>>2]|0)-(((T+ae&1)!=0?526341:525315)>>>((c[J>>2]|0)>>>0)&127);T=P-1&65535;if(T<<16>>16==0){_=0;break L56826}if((S|0)==0){_=T;break}else{P=T;t=N}}}}while(0);b[n>>1]=_;w=f+100|0;a[w]=0;return};default:{gf[c[2520528+(r<<2)>>2]&2047](f);w=f+100|0;a[w]=0;return}}}function f6T(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;f=d+22|0;g=(e[f>>1]|0)<<4;h=c[2385310]|0;i=h+28|0;j=b[i>>1]|0;k=j+1&65535;b[i>>1]=k;i=(j&65535)+g&1048575;g=c[3531864]|0;j=c[g+6188+(i>>>11<<2)>>2]|0;if((j|0)==0){l=gj[c[g+8236>>2]&4095](i)|0;m=c[2385310]|0;n=l;o=m;p=b[m+28>>1]|0;q=c[3531864]|0}else{n=a[j+i|0]|0;o=h;p=k;q=g}g=(e[f>>1]|0)<<4;b[o+28>>1]=p+1&65535;o=(p&65535)+g&1048575;g=c[q+6188+(o>>>11<<2)>>2]|0;if((g|0)==0){p=gj[c[q+8236>>2]&4095](o)|0;r=p;s=c[3531864]|0}else{r=a[g+o|0]|0;s=q}q=d+8|0;o=(b[q>>1]|0)-2&65535;b[q>>1]=o;g=((e[d+24>>1]|0)<<4)+(o&65535)|0;o=g&1048575;p=c[s+2092+(o>>>11<<2)>>2]|0;if((p|0)==0){gg[c[s+8240>>2]&4095](o,n);t=c[3531864]|0}else{a[p+o|0]=n;t=s}s=g+1&1048575;g=c[t+2092+(s>>>11<<2)>>2]|0;if((g|0)==0){gg[c[t+8240>>2]&4095](s,r);u=b[q>>1]|0;v=u&1;w=v<<16>>16!=0;x=d+92|0;y=c[x>>2]|0;z=w?789509:788485;A=z>>>(y>>>0);B=A&127;C=d+84|0;D=c[C>>2]|0;E=D-B|0;c[C>>2]=E;return}else{a[g+s|0]=r;u=b[q>>1]|0;v=u&1;w=v<<16>>16!=0;x=d+92|0;y=c[x>>2]|0;z=w?789509:788485;A=z>>>(y>>>0);B=A&127;C=d+84|0;D=c[C>>2]|0;E=D-B|0;c[C>>2]=E;return}}function f6U(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;f=d+22|0;g=(e[f>>1]|0)<<4;h=(c[2385310]|0)+28|0;i=b[h>>1]|0;b[h>>1]=i+1&65535;h=(i&65535)+g&1048575;g=c[3531864]|0;i=c[g+6188+(h>>>11<<2)>>2]|0;if((i|0)==0){j=gj[c[g+8236>>2]&4095](h)|0}else{j=a[i+h|0]|0}h=j&255;i=9654880+(h<<2)|0;g=(j&255)>191;if(g){k=b[d+(c[9650784+(h<<2)>>2]<<1)>>1]|0}else{j=c[679712+(h<<2)>>2]|0;gj[j&4095](d)|0;j=c[2426956]|0;h=j&1048575;l=c[3531864]|0;m=c[l+44+(h>>>11<<2)>>2]|0;if((m|0)==0){n=gj[c[l+8236>>2]&4095](h)|0;o=n;p=c[2426956]|0;q=c[3531864]|0}else{o=a[m+h|0]|0;p=j;q=l}l=p+1&1048575;p=c[q+44+(l>>>11<<2)>>2]|0;if((p|0)==0){r=gj[c[q+8236>>2]&4095](l)|0}else{r=a[p+l|0]|0}k=(r&255)<<8|o&255}o=(e[f>>1]|0)<<4;r=c[2385310]|0;l=r+28|0;p=b[l>>1]|0;q=p+1&65535;b[l>>1]=q;l=(p&65535)+o&1048575;o=c[3531864]|0;p=c[o+6188+(l>>>11<<2)>>2]|0;if((p|0)==0){j=gj[c[o+8236>>2]&4095](l)|0;h=c[2385310]|0;s=j;t=h;u=b[h+28>>1]|0;v=c[3531864]|0}else{s=a[p+l|0]|0;t=r;u=q;v=o}o=(e[f>>1]|0)<<4;b[t+28>>1]=u+1&65535;t=(u&65535)+o&1048575;o=c[v+6188+(t>>>11<<2)>>2]|0;if((o|0)==0){w=gj[c[v+8236>>2]&4095](t)|0}else{w=a[o+t|0]|0}t=ag(((w&255)<<8|s&255)<<16>>16,k<<16>>16)|0;k=t>>15;if((k|0)==0){x=0;y=d+40|0;c[y>>2]=x;z=d+48|0;c[z>>2]=x;A=t&65535;B=c[i>>2]|0;C=d+(B<<1)|0;b[C>>1]=A;D=g?38:47;E=d+84|0;F=c[E>>2]|0;G=F-D|0;c[E>>2]=G;return}x=(k|0)!=-1|0;y=d+40|0;c[y>>2]=x;z=d+48|0;c[z>>2]=x;A=t&65535;B=c[i>>2]|0;C=d+(B<<1)|0;b[C>>1]=A;D=g?38:47;E=d+84|0;F=c[E>>2]|0;G=F-D|0;c[E>>2]=G;return}function f6V(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=(e[d+22>>1]|0)<<4;g=(c[2385310]|0)+28|0;h=b[g>>1]|0;b[g>>1]=h+1&65535;g=(h&65535)+f&1048575;f=c[3531864]|0;h=c[f+6188+(g>>>11<<2)>>2]|0;if((h|0)==0){i=gj[c[f+8236>>2]&4095](g)|0;j=i;k=c[3531864]|0}else{j=a[h+g|0]|0;k=f}f=d+8|0;g=(b[f>>1]|0)-2&65535;b[f>>1]=g;h=((e[d+24>>1]|0)<<4)+(g&65535)|0;g=h&1048575;i=c[k+2092+(g>>>11<<2)>>2]|0;if((i|0)==0){gg[c[k+8240>>2]&4095](g,j);l=c[3531864]|0}else{a[i+g|0]=j;l=k}k=(j<<24>>24&65535)>>>8&255;j=h+1&1048575;h=c[l+2092+(j>>>11<<2)>>2]|0;if((h|0)==0){gg[c[l+8240>>2]&4095](j,k);m=b[f>>1]|0;n=m&1;o=n<<16>>16!=0;p=d+92|0;q=c[p>>2]|0;r=o?723717:722691;s=r>>>(q>>>0);t=s&127;u=d+84|0;v=c[u>>2]|0;w=v-t|0;c[u>>2]=w;return}else{a[h+j|0]=k;m=b[f>>1]|0;n=m&1;o=n<<16>>16!=0;p=d+92|0;q=c[p>>2]|0;r=o?723717:722691;s=r>>>(q>>>0);t=s&127;u=d+84|0;v=c[u>>2]|0;w=v-t|0;c[u>>2]=w;return}}function f6W(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;f=d+22|0;g=(e[f>>1]|0)<<4;h=(c[2385310]|0)+28|0;i=b[h>>1]|0;b[h>>1]=i+1&65535;h=(i&65535)+g&1048575;g=c[3531864]|0;i=c[g+6188+(h>>>11<<2)>>2]|0;if((i|0)==0){j=gj[c[g+8236>>2]&4095](h)|0}else{j=a[i+h|0]|0}h=j&255;i=9654880+(h<<2)|0;g=(j&255)>191;if(g){k=b[d+(c[9650784+(h<<2)>>2]<<1)>>1]|0}else{j=c[679712+(h<<2)>>2]|0;gj[j&4095](d)|0;j=c[2426956]|0;h=j&1048575;l=c[3531864]|0;m=c[l+44+(h>>>11<<2)>>2]|0;if((m|0)==0){n=gj[c[l+8236>>2]&4095](h)|0;o=n;p=c[2426956]|0;q=c[3531864]|0}else{o=a[m+h|0]|0;p=j;q=l}l=p+1&1048575;p=c[q+44+(l>>>11<<2)>>2]|0;if((p|0)==0){r=gj[c[q+8236>>2]&4095](l)|0}else{r=a[p+l|0]|0}k=(r&255)<<8|o&255}o=(e[f>>1]|0)<<4;f=(c[2385310]|0)+28|0;r=b[f>>1]|0;b[f>>1]=r+1&65535;f=(r&65535)+o&1048575;o=c[3531864]|0;r=c[o+6188+(f>>>11<<2)>>2]|0;if((r|0)==0){s=gj[c[o+8236>>2]&4095](f)|0}else{s=a[r+f|0]|0}f=ag(s<<24>>24,k<<16>>16)|0;k=f>>15;if((k|0)==0){t=0;u=d+40|0;c[u>>2]=t;v=d+48|0;c[v>>2]=t;w=f&65535;x=c[i>>2]|0;y=d+(x<<1)|0;b[y>>1]=w;z=g?31:39;A=d+84|0;B=c[A>>2]|0;C=B-z|0;c[A>>2]=C;return}t=(k|0)!=-1|0;u=d+40|0;c[u>>2]=t;v=d+48|0;c[v>>2]=t;w=f&65535;x=c[i>>2]|0;y=d+(x<<1)|0;b[y>>1]=w;z=g?31:39;A=d+84|0;B=c[A>>2]|0;C=B-z|0;c[A>>2]=C;return}function f6X(f){f=f|0;var g=0,h=0,i=0,j=0,k=0;g=f+14|0;h=((e[f+20>>1]|0)<<4)+(e[g>>1]|0)|0;i=gj[c[(c[3531864]|0)+8244>>2]&4095](b[f+4>>1]&255)|0;j=h&1048575;h=c[3531864]|0;k=c[h+2092+(j>>>11<<2)>>2]|0;if((k|0)==0){gg[c[h+8240>>2]&4095](j,i)}else{a[k+j|0]=i}b[g>>1]=((d[f+58|0]|0)*-2&65535|1)+(b[g>>1]|0)&65535;g=f+84|0;c[g>>2]=(c[g>>2]|0)-8;return}function f6Y(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=f+14|0;h=((e[f+20>>1]|0)<<4)+(e[g>>1]|0)|0;i=f+4|0;j=gj[c[(c[3531864]|0)+8244>>2]&4095](b[i>>1]&255)|0;k=gj[c[(c[3531864]|0)+8244>>2]&4095]((e[i>>1]|0)+1&65791)|0;i=h&1048575;l=c[3531864]|0;m=c[l+2092+(i>>>11<<2)>>2]|0;if((m|0)==0){gg[c[l+8240>>2]&4095](i,j);n=c[3531864]|0}else{a[m+i|0]=j;n=l}l=h+1&1048575;h=c[n+2092+(l>>>11<<2)>>2]|0;if((h|0)==0){gg[c[n+8240>>2]&4095](l,k)}else{a[h+l|0]=k}b[g>>1]=((d[f+58|0]|0)*-4&65535|2)+(b[g>>1]|0)&65535;g=f+84|0;c[g>>2]=(c[g>>2]|0)-(1182216>>>((c[f+92>>2]|0)>>>0)&127);return}function f6Z(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=e[f+4>>1]|0;if((a[f+100|0]|0)==0){h=e[f+26>>1]<<4}else{h=c[f+96>>2]|0}i=f+12|0;j=(e[i>>1]|0)+h&1048575;h=c[3531864]|0;k=c[h+44+(j>>>11<<2)>>2]|0;if((k|0)==0){l=gj[c[h+8236>>2]&4095](j)|0;m=l;n=c[3531864]|0}else{m=a[k+j|0]|0;n=h}gg[c[n+8248>>2]&4095](g,m);b[i>>1]=((d[f+58|0]|0)*-2&65535|1)+(b[i>>1]|0)&65535;i=f+84|0;c[i>>2]=(c[i>>2]|0)-8;return}function f6_(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=e[f+4>>1]|0;h=f+100|0;i=a[h]|0;if(i<<24>>24==0){j=(e[f+26>>1]|0)<<4}else{j=c[f+96>>2]|0}k=f+12|0;l=(e[k>>1]|0)+j&1048575;j=c[3531864]|0;m=c[j+44+(l>>>11<<2)>>2]|0;if((m|0)==0){n=gj[c[j+8236>>2]&4095](l)|0;o=n;p=a[h]|0}else{o=a[m+l|0]|0;p=i}if(p<<24>>24==0){q=(e[f+26>>1]|0)<<4}else{q=c[f+96>>2]|0}p=q+1+(e[k>>1]|0)&1048575;q=c[3531864]|0;i=c[q+44+(p>>>11<<2)>>2]|0;if((i|0)==0){l=gj[c[q+8236>>2]&4095](p)|0;r=l;s=c[3531864]|0}else{r=a[i+p|0]|0;s=q}gg[c[s+8248>>2]&4095](g,o);gg[c[(c[3531864]|0)+8248>>2]&4095](g+1|0,r);b[k>>1]=((d[f+58|0]|0)*-4&65535|2)+(b[k>>1]|0)&65535;k=f+84|0;c[k>>2]=(c[k>>2]|0)-(1182216>>>((c[f+92>>2]|0)>>>0)&127);return}function f6$(f){f=f|0;var g=0,h=0,i=0,j=0,k=0;g=f+91|0;a[g]=1;h=(e[f+22>>1]|0)<<4;i=(c[2385310]|0)+28|0;j=b[i>>1]|0;b[i>>1]=j+1&65535;i=(j&65535)+h&1048575;h=c[3531864]|0;j=c[h+6188+(i>>>11<<2)>>2]|0;if((j|0)==0){k=gj[c[h+8236>>2]&4095](i)|0}else{k=a[j+i|0]|0}if((c[f+40>>2]|0)==0){i=f+84|0;c[i>>2]=(c[i>>2]|0)-(263171>>>((c[f+92>>2]|0)>>>0)&127);return}else{i=f+28|0;b[i>>1]=(b[i>>1]|0)+(k<<24>>24)&65535;k=f+84|0;c[k>>2]=(c[k>>2]|0)-(d[591976+((c[f+92>>2]|0)>>>3)|0]|0);a[g]=1;return}}function f60(f){f=f|0;var g=0,h=0,i=0,j=0,k=0;g=f+91|0;a[g]=1;h=(e[f+22>>1]|0)<<4;i=(c[2385310]|0)+28|0;j=b[i>>1]|0;b[i>>1]=j+1&65535;i=(j&65535)+h&1048575;h=c[3531864]|0;j=c[h+6188+(i>>>11<<2)>>2]|0;if((j|0)==0){k=gj[c[h+8236>>2]&4095](i)|0}else{k=a[j+i|0]|0}if((c[f+40>>2]|0)==0){i=f+28|0;b[i>>1]=(b[i>>1]|0)+(k<<24>>24)&65535;k=f+84|0;c[k>>2]=(c[k>>2]|0)-(d[591976+((c[f+92>>2]|0)>>>3)|0]|0);a[g]=1;return}else{g=f+84|0;c[g>>2]=(c[g>>2]|0)-(263171>>>((c[f+92>>2]|0)>>>0)&127);return}}function f61(f){f=f|0;var g=0,h=0,i=0,j=0,k=0;g=f+91|0;a[g]=1;h=(e[f+22>>1]|0)<<4;i=(c[2385310]|0)+28|0;j=b[i>>1]|0;b[i>>1]=j+1&65535;i=(j&65535)+h&1048575;h=c[3531864]|0;j=c[h+6188+(i>>>11<<2)>>2]|0;if((j|0)==0){k=gj[c[h+8236>>2]&4095](i)|0}else{k=a[j+i|0]|0}if((c[f+48>>2]|0)==0){i=f+84|0;c[i>>2]=(c[i>>2]|0)-(263171>>>((c[f+92>>2]|0)>>>0)&127);return}else{i=f+28|0;b[i>>1]=(b[i>>1]|0)+(k<<24>>24)&65535;k=f+84|0;c[k>>2]=(c[k>>2]|0)-(d[591976+((c[f+92>>2]|0)>>>3)|0]|0);a[g]=1;return}}function f62(f){f=f|0;var g=0,h=0,i=0,j=0,k=0;g=f+91|0;a[g]=1;h=(e[f+22>>1]|0)<<4;i=(c[2385310]|0)+28|0;j=b[i>>1]|0;b[i>>1]=j+1&65535;i=(j&65535)+h&1048575;h=c[3531864]|0;j=c[h+6188+(i>>>11<<2)>>2]|0;if((j|0)==0){k=gj[c[h+8236>>2]&4095](i)|0}else{k=a[j+i|0]|0}if((c[f+48>>2]|0)==0){i=f+28|0;b[i>>1]=(b[i>>1]|0)+(k<<24>>24)&65535;k=f+84|0;c[k>>2]=(c[k>>2]|0)-(d[591976+((c[f+92>>2]|0)>>>3)|0]|0);a[g]=1;return}else{g=f+84|0;c[g>>2]=(c[g>>2]|0)-(263171>>>((c[f+92>>2]|0)>>>0)&127);return}}function f63(f){f=f|0;var g=0,h=0,i=0,j=0,k=0;g=f+91|0;a[g]=1;h=(e[f+22>>1]|0)<<4;i=(c[2385310]|0)+28|0;j=b[i>>1]|0;b[i>>1]=j+1&65535;i=(j&65535)+h&1048575;h=c[3531864]|0;j=c[h+6188+(i>>>11<<2)>>2]|0;if((j|0)==0){k=gj[c[h+8236>>2]&4095](i)|0}else{k=a[j+i|0]|0}if((c[f+44>>2]|0)==0){i=f+28|0;b[i>>1]=(b[i>>1]|0)+(k<<24>>24)&65535;k=f+84|0;c[k>>2]=(c[k>>2]|0)-(d[591976+((c[f+92>>2]|0)>>>3)|0]|0);a[g]=1;return}else{g=f+84|0;c[g>>2]=(c[g>>2]|0)-(263171>>>((c[f+92>>2]|0)>>>0)&127);return}}function f64(f){f=f|0;var g=0,h=0,i=0,j=0,k=0;g=f+91|0;a[g]=1;h=(e[f+22>>1]|0)<<4;i=(c[2385310]|0)+28|0;j=b[i>>1]|0;b[i>>1]=j+1&65535;i=(j&65535)+h&1048575;h=c[3531864]|0;j=c[h+6188+(i>>>11<<2)>>2]|0;if((j|0)==0){k=gj[c[h+8236>>2]&4095](i)|0}else{k=a[j+i|0]|0}if((c[f+44>>2]|0)==0){i=f+84|0;c[i>>2]=(c[i>>2]|0)-(263171>>>((c[f+92>>2]|0)>>>0)&127);return}else{i=f+28|0;b[i>>1]=(b[i>>1]|0)+(k<<24>>24)&65535;k=f+84|0;c[k>>2]=(c[k>>2]|0)-(d[591976+((c[f+92>>2]|0)>>>3)|0]|0);a[g]=1;return}}function f65(f){f=f|0;var g=0,h=0,i=0,j=0,k=0;g=f+91|0;a[g]=1;h=(e[f+22>>1]|0)<<4;i=(c[2385310]|0)+28|0;j=b[i>>1]|0;b[i>>1]=j+1&65535;i=(j&65535)+h&1048575;h=c[3531864]|0;j=c[h+6188+(i>>>11<<2)>>2]|0;if((j|0)==0){k=gj[c[h+8236>>2]&4095](i)|0}else{k=a[j+i|0]|0}i=k<<24>>24;do{if((c[f+48>>2]|0)==0){if((c[f+44>>2]|0)==0){break}k=f+84|0;c[k>>2]=(c[k>>2]|0)-(263171>>>((c[f+92>>2]|0)>>>0)&127);return}}while(0);k=f+28|0;b[k>>1]=(b[k>>1]|0)+i&65535;i=f+84|0;c[i>>2]=(c[i>>2]|0)-(d[591976+((c[f+92>>2]|0)>>>3)|0]|0);a[g]=1;return}function f66(f){f=f|0;var g=0,h=0,i=0,j=0,k=0;g=f+91|0;a[g]=1;h=(e[f+22>>1]|0)<<4;i=(c[2385310]|0)+28|0;j=b[i>>1]|0;b[i>>1]=j+1&65535;i=(j&65535)+h&1048575;h=c[3531864]|0;j=c[h+6188+(i>>>11<<2)>>2]|0;if((j|0)==0){k=gj[c[h+8236>>2]&4095](i)|0}else{k=a[j+i|0]|0}i=k<<24>>24;do{if((c[f+48>>2]|0)==0){if((c[f+44>>2]|0)==0){break}k=f+28|0;b[k>>1]=(b[k>>1]|0)+i&65535;k=f+84|0;c[k>>2]=(c[k>>2]|0)-(d[591976+((c[f+92>>2]|0)>>>3)|0]|0);a[g]=1;return}}while(0);g=f+84|0;c[g>>2]=(c[g>>2]|0)-(263171>>>((c[f+92>>2]|0)>>>0)&127);return}function f67(f){f=f|0;var g=0,h=0,i=0,j=0,k=0;g=f+91|0;a[g]=1;h=(e[f+22>>1]|0)<<4;i=(c[2385310]|0)+28|0;j=b[i>>1]|0;b[i>>1]=j+1&65535;i=(j&65535)+h&1048575;h=c[3531864]|0;j=c[h+6188+(i>>>11<<2)>>2]|0;if((j|0)==0){k=gj[c[h+8236>>2]&4095](i)|0}else{k=a[j+i|0]|0}if((c[f+32>>2]|0)<0){i=f+28|0;b[i>>1]=(b[i>>1]|0)+(k<<24>>24)&65535;k=f+84|0;c[k>>2]=(c[k>>2]|0)-(d[591976+((c[f+92>>2]|0)>>>3)|0]|0);a[g]=1;return}else{g=f+84|0;c[g>>2]=(c[g>>2]|0)-(263171>>>((c[f+92>>2]|0)>>>0)&127);return}}function f68(f){f=f|0;var g=0,h=0,i=0,j=0,k=0;g=f+91|0;a[g]=1;h=(e[f+22>>1]|0)<<4;i=(c[2385310]|0)+28|0;j=b[i>>1]|0;b[i>>1]=j+1&65535;i=(j&65535)+h&1048575;h=c[3531864]|0;j=c[h+6188+(i>>>11<<2)>>2]|0;if((j|0)==0){k=gj[c[h+8236>>2]&4095](i)|0}else{k=a[j+i|0]|0}if((c[f+32>>2]|0)<0){i=f+84|0;c[i>>2]=(c[i>>2]|0)-(263171>>>((c[f+92>>2]|0)>>>0)&127);return}else{i=f+28|0;b[i>>1]=(b[i>>1]|0)+(k<<24>>24)&65535;k=f+84|0;c[k>>2]=(c[k>>2]|0)-(d[591976+((c[f+92>>2]|0)>>>3)|0]|0);a[g]=1;return}}function f69(f){f=f|0;var g=0,h=0,i=0,j=0,k=0;g=f+91|0;a[g]=1;h=e[f+22>>1]<<4;i=(c[2385310]|0)+28|0;j=b[i>>1]|0;b[i>>1]=j+1&65535;i=(j&65535)+h&1048575;h=c[3531864]|0;j=c[h+6188+(i>>>11<<2)>>2]|0;if((j|0)==0){k=gj[c[h+8236>>2]&4095](i)|0}else{k=a[j+i|0]|0}if((a[9761200+(c[f+52>>2]&255)|0]|0)==0){i=f+84|0;c[i>>2]=(c[i>>2]|0)-(263171>>>((c[f+92>>2]|0)>>>0)&127);return}else{i=f+28|0;b[i>>1]=(b[i>>1]|0)+(k<<24>>24)&65535;k=f+84|0;c[k>>2]=(c[k>>2]|0)-(d[591976+((c[f+92>>2]|0)>>>3)|0]|0);a[g]=1;return}}function f7a(f){f=f|0;var g=0,h=0,i=0,j=0,k=0;g=f+91|0;a[g]=1;h=e[f+22>>1]<<4;i=(c[2385310]|0)+28|0;j=b[i>>1]|0;b[i>>1]=j+1&65535;i=(j&65535)+h&1048575;h=c[3531864]|0;j=c[h+6188+(i>>>11<<2)>>2]|0;if((j|0)==0){k=gj[c[h+8236>>2]&4095](i)|0}else{k=a[j+i|0]|0}if((a[9761200+(c[f+52>>2]&255)|0]|0)==0){i=f+28|0;b[i>>1]=(b[i>>1]|0)+(k<<24>>24)&65535;k=f+84|0;c[k>>2]=(c[k>>2]|0)-(d[591976+((c[f+92>>2]|0)>>>3)|0]|0);a[g]=1;return}else{g=f+84|0;c[g>>2]=(c[g>>2]|0)-(263171>>>((c[f+92>>2]|0)>>>0)&127);return}}function f7b(f){f=f|0;var g=0,h=0,i=0,j=0,k=0;g=f+91|0;a[g]=1;h=(e[f+22>>1]|0)<<4;i=(c[2385310]|0)+28|0;j=b[i>>1]|0;b[i>>1]=j+1&65535;i=(j&65535)+h&1048575;h=c[3531864]|0;j=c[h+6188+(i>>>11<<2)>>2]|0;if((j|0)==0){k=gj[c[h+8236>>2]&4095](i)|0}else{k=a[j+i|0]|0}i=k<<24>>24;do{if(((c[f+32>>2]|0)>>>31|0)!=((c[f+40>>2]|0)!=0|0)){if((c[f+44>>2]|0)==0){break}k=f+28|0;b[k>>1]=(b[k>>1]|0)+i&65535;k=f+84|0;c[k>>2]=(c[k>>2]|0)-(d[591976+((c[f+92>>2]|0)>>>3)|0]|0);a[g]=1;return}}while(0);g=f+84|0;c[g>>2]=(c[g>>2]|0)-(263171>>>((c[f+92>>2]|0)>>>0)&127);return}function f7c(f){f=f|0;var g=0,h=0,i=0,j=0,k=0;g=f+91|0;a[g]=1;h=(e[f+22>>1]|0)<<4;i=(c[2385310]|0)+28|0;j=b[i>>1]|0;b[i>>1]=j+1&65535;i=(j&65535)+h&1048575;h=c[3531864]|0;j=c[h+6188+(i>>>11<<2)>>2]|0;if((j|0)==0){k=gj[c[h+8236>>2]&4095](i)|0}else{k=a[j+i|0]|0}i=k<<24>>24;do{if((c[f+44>>2]|0)!=0){if(((c[f+32>>2]|0)>>>31|0)==((c[f+40>>2]|0)!=0|0)){break}k=f+84|0;c[k>>2]=(c[k>>2]|0)-(263171>>>((c[f+92>>2]|0)>>>0)&127);return}}while(0);k=f+28|0;b[k>>1]=(b[k>>1]|0)+i&65535;i=f+84|0;c[i>>2]=(c[i>>2]|0)-(d[591976+((c[f+92>>2]|0)>>>3)|0]|0);a[g]=1;return}function f7d(f){f=f|0;var g=0,h=0,i=0,j=0,k=0;g=f+91|0;a[g]=1;h=(e[f+22>>1]|0)<<4;i=(c[2385310]|0)+28|0;j=b[i>>1]|0;b[i>>1]=j+1&65535;i=(j&65535)+h&1048575;h=c[3531864]|0;j=c[h+6188+(i>>>11<<2)>>2]|0;if((j|0)==0){k=gj[c[h+8236>>2]&4095](i)|0}else{k=a[j+i|0]|0}i=k<<24>>24;do{if((c[f+44>>2]|0)!=0){if(((c[f+32>>2]|0)>>>31|0)!=((c[f+40>>2]|0)!=0|0)){break}k=f+84|0;c[k>>2]=(c[k>>2]|0)-(263171>>>((c[f+92>>2]|0)>>>0)&127);return}}while(0);k=f+28|0;b[k>>1]=(b[k>>1]|0)+i&65535;i=f+84|0;c[i>>2]=(c[i>>2]|0)-(d[591976+((c[f+92>>2]|0)>>>3)|0]|0);a[g]=1;return}function f7e(f){f=f|0;var g=0,h=0,i=0,j=0,k=0;g=f+91|0;a[g]=1;h=(e[f+22>>1]|0)<<4;i=(c[2385310]|0)+28|0;j=b[i>>1]|0;b[i>>1]=j+1&65535;i=(j&65535)+h&1048575;h=c[3531864]|0;j=c[h+6188+(i>>>11<<2)>>2]|0;if((j|0)==0){k=gj[c[h+8236>>2]&4095](i)|0}else{k=a[j+i|0]|0}i=k<<24>>24;do{if(((c[f+32>>2]|0)>>>31|0)==((c[f+40>>2]|0)!=0|0)){if((c[f+44>>2]|0)==0){break}k=f+28|0;b[k>>1]=(b[k>>1]|0)+i&65535;k=f+84|0;c[k>>2]=(c[k>>2]|0)-(d[591976+((c[f+92>>2]|0)>>>3)|0]|0);a[g]=1;return}}while(0);g=f+84|0;c[g>>2]=(c[g>>2]|0)-(263171>>>((c[f+92>>2]|0)>>>0)&127);return}function f7f(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=d+22|0;g=(e[f>>1]|0)<<4;h=(c[2385310]|0)+28|0;i=b[h>>1]|0;b[h>>1]=i+1&65535;h=(i&65535)+g&1048575;g=c[3531864]|0;i=c[g+6188+(h>>>11<<2)>>2]|0;if((i|0)==0){j=gj[c[g+8236>>2]&4095](h)|0}else{j=a[i+h|0]|0}h=j&255;i=(j&255)>191;do{if(i){k=a[d+(c[9648736+(h<<2)>>2]|0)|0]|0}else{j=(gj[c[679712+(h<<2)>>2]&4095](d)|0)&1048575;g=c[3531864]|0;l=c[g+44+(j>>>11<<2)>>2]|0;if((l|0)==0){k=gj[c[g+8236>>2]&4095](j)|0;break}else{k=a[l+j|0]|0;break}}}while(0);j=k&255;l=(e[f>>1]|0)<<4;f=(c[2385310]|0)+28|0;g=b[f>>1]|0;b[f>>1]=g+1&65535;f=(g&65535)+l&1048575;l=c[3531864]|0;g=c[l+6188+(f>>>11<<2)>>2]|0;if((g|0)==0){m=gj[c[l+8236>>2]&4095](f)|0}else{m=a[g+f|0]|0}f=m&255;do{if(i){g=d+84|0;c[g>>2]=(c[g>>2]|0)-(263170>>>((c[d+92>>2]|0)>>>0)&127);n=h&56;o=46638}else{g=h&56;l=c[d+92>>2]|0;if((g|0)==56){p=d+84|0;c[p>>2]=(c[p>>2]|0)-(855302>>>(l>>>0)&127);break}else{p=d+84|0;c[p>>2]=(c[p>>2]|0)-(1184263>>>(l>>>0)&127);n=g;o=46638;break}}}while(0);L57157:do{if((o|0)==46638){switch(n|0){case 0:{g=f+j|0;c[d+48>>2]=g&256;c[d+40>>2]=(g^j)&128&(g^f);c[d+36>>2]=(g^(m^k)&255)&16;l=g<<24>>24;c[d+52>>2]=l;c[d+44>>2]=l;c[d+32>>2]=l;if(i){a[d+(c[9648736+(h<<2)>>2]|0)|0]=g&255;return}l=g&255;g=c[2426956]&1048575;p=c[3531864]|0;q=c[p+2092+(g>>>11<<2)>>2]|0;if((q|0)==0){gg[c[p+8240>>2]&4095](g,l);return}else{a[q+g|0]=l;return}break};case 8:{l=m|k;c[d+36>>2]=0;c[d+40>>2]=0;c[d+48>>2]=0;g=l<<24>>24;c[d+52>>2]=g;c[d+44>>2]=g;c[d+32>>2]=g;if(i){a[d+(c[9648736+(h<<2)>>2]|0)|0]=l;return}g=c[2426956]&1048575;q=c[3531864]|0;p=c[q+2092+(g>>>11<<2)>>2]|0;if((p|0)==0){gg[c[q+8240>>2]&4095](g,l);return}else{a[p+g|0]=l;return}break};case 16:{l=d+48|0;g=((c[l>>2]|0)!=0)+f|0;p=g+j|0;c[l>>2]=p&256;c[d+40>>2]=(p^j)&128&(p^g);c[d+36>>2]=(g^j^p)&16;g=p<<24>>24;c[d+52>>2]=g;c[d+44>>2]=g;c[d+32>>2]=g;if(i){a[d+(c[9648736+(h<<2)>>2]|0)|0]=p&255;return}g=p&255;p=c[2426956]&1048575;l=c[3531864]|0;q=c[l+2092+(p>>>11<<2)>>2]|0;if((q|0)==0){gg[c[l+8240>>2]&4095](p,g);return}else{a[q+p|0]=g;return}break};case 24:{g=d+48|0;p=((c[g>>2]|0)!=0)+f|0;q=j-p|0;c[g>>2]=q&256;g=p^j;c[d+40>>2]=g&128&(q^j);c[d+36>>2]=(q^g)&16;g=q<<24>>24;c[d+52>>2]=g;c[d+44>>2]=g;c[d+32>>2]=g;if(i){a[d+(c[9648736+(h<<2)>>2]|0)|0]=q&255;return}g=q&255;q=c[2426956]&1048575;p=c[3531864]|0;l=c[p+2092+(q>>>11<<2)>>2]|0;if((l|0)==0){gg[c[p+8240>>2]&4095](q,g);return}else{a[l+q|0]=g;return}break};case 32:{g=m&k;c[d+36>>2]=0;c[d+40>>2]=0;c[d+48>>2]=0;q=g<<24>>24;c[d+52>>2]=q;c[d+44>>2]=q;c[d+32>>2]=q;if(i){a[d+(c[9648736+(h<<2)>>2]|0)|0]=g;return}q=c[2426956]&1048575;l=c[3531864]|0;p=c[l+2092+(q>>>11<<2)>>2]|0;if((p|0)==0){gg[c[l+8240>>2]&4095](q,g);return}else{a[p+q|0]=g;return}break};case 40:{g=j-f|0;c[d+48>>2]=g&256;q=(m^k)&255;c[d+40>>2]=q&128&(g^j);c[d+36>>2]=(g^q)&16;q=g<<24>>24;c[d+52>>2]=q;c[d+44>>2]=q;c[d+32>>2]=q;if(i){a[d+(c[9648736+(h<<2)>>2]|0)|0]=g&255;return}q=g&255;g=c[2426956]&1048575;p=c[3531864]|0;l=c[p+2092+(g>>>11<<2)>>2]|0;if((l|0)==0){gg[c[p+8240>>2]&4095](g,q);return}else{a[l+g|0]=q;return}break};case 48:{q=m^k;c[d+36>>2]=0;c[d+40>>2]=0;c[d+48>>2]=0;g=q<<24>>24;c[d+52>>2]=g;c[d+44>>2]=g;c[d+32>>2]=g;if(i){a[d+(c[9648736+(h<<2)>>2]|0)|0]=q;return}g=c[2426956]&1048575;l=c[3531864]|0;p=c[l+2092+(g>>>11<<2)>>2]|0;if((p|0)==0){gg[c[l+8240>>2]&4095](g,q);return}else{a[p+g|0]=q;return}break};case 56:{break L57157;break};default:{return}}}}while(0);h=j-f|0;c[d+48>>2]=h&256;f=(m^k)&255;c[d+40>>2]=f&128&(h^j);c[d+36>>2]=(h^f)&16;f=h<<24>>24;c[d+52>>2]=f;c[d+44>>2]=f;c[d+32>>2]=f;return}function f7g(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;f=d+22|0;g=(e[f>>1]|0)<<4;h=(c[2385310]|0)+28|0;i=b[h>>1]|0;b[h>>1]=i+1&65535;h=(i&65535)+g&1048575;g=c[3531864]|0;i=c[g+6188+(h>>>11<<2)>>2]|0;if((i|0)==0){j=gj[c[g+8236>>2]&4095](h)|0}else{j=a[i+h|0]|0}h=j&255;i=(j&255)>191;if(i){k=e[d+(c[9650784+(h<<2)>>2]<<1)>>1]|0}else{j=c[679712+(h<<2)>>2]|0;gj[j&4095](d)|0;j=c[2426956]|0;g=j&1048575;l=c[3531864]|0;m=c[l+44+(g>>>11<<2)>>2]|0;if((m|0)==0){n=gj[c[l+8236>>2]&4095](g)|0;o=n;p=c[2426956]|0;q=c[3531864]|0}else{o=a[m+g|0]|0;p=j;q=l}l=p+1&1048575;p=c[q+44+(l>>>11<<2)>>2]|0;if((p|0)==0){r=gj[c[q+8236>>2]&4095](l)|0}else{r=a[p+l|0]|0}k=(r&255)<<8|o&255}o=(e[f>>1]|0)<<4;r=c[2385310]|0;l=r+28|0;p=b[l>>1]|0;q=p+1&65535;b[l>>1]=q;l=(p&65535)+o&1048575;o=c[3531864]|0;p=c[o+6188+(l>>>11<<2)>>2]|0;if((p|0)==0){j=gj[c[o+8236>>2]&4095](l)|0;g=c[2385310]|0;s=j;t=g;u=b[g+28>>1]|0;v=c[3531864]|0}else{s=a[p+l|0]|0;t=r;u=q;v=o}o=s&255;s=(e[f>>1]|0)<<4;b[t+28>>1]=u+1&65535;t=(u&65535)+s&1048575;s=c[v+6188+(t>>>11<<2)>>2]|0;if((s|0)==0){w=gj[c[v+8236>>2]&4095](t)|0}else{w=a[s+t|0]|0}t=(w&255)<<8;w=t|o;do{if(i){s=d+84|0;c[s>>2]=(c[s>>2]|0)-(263170>>>((c[d+92>>2]|0)>>>0)&127);x=h&56;y=46722}else{s=h&56;v=(c[2426956]&1|0)!=0;u=c[d+92>>2]|0;if((s|0)==56){f=d+84|0;c[f>>2]=(c[f>>2]|0)-((v?1118472:1117446)>>>(u>>>0)&127);break}else{f=d+84|0;c[f>>2]=(c[f>>2]|0)-((v?1710603:1708551)>>>(u>>>0)&127);x=s;y=46722;break}}}while(0);L57264:do{if((y|0)==46722){switch(x|0){case 0:{s=w+k|0;c[d+48>>2]=s&65536;c[d+40>>2]=(s^k)&32768&(s^t);c[d+36>>2]=(o^k^s)&16;u=s<<16>>16;c[d+52>>2]=u;c[d+44>>2]=u;c[d+32>>2]=u;if(i){b[d+(c[9650784+(h<<2)>>2]<<1)>>1]=s&65535;return}u=c[2426956]|0;v=s&255;f=u&1048575;q=c[3531864]|0;r=c[q+2092+(f>>>11<<2)>>2]|0;if((r|0)==0){gg[c[q+8240>>2]&4095](f,v);z=c[3531864]|0}else{a[r+f|0]=v;z=q}q=(s&65535)>>>8&255;s=u+1&1048575;u=c[z+2092+(s>>>11<<2)>>2]|0;if((u|0)==0){gg[c[z+8240>>2]&4095](s,q);return}else{a[u+s|0]=q;return}break};case 8:{q=w|k;c[d+36>>2]=0;c[d+40>>2]=0;c[d+48>>2]=0;s=q&65535;u=s<<16>>16;c[d+52>>2]=u;c[d+44>>2]=u;c[d+32>>2]=u;if(i){b[d+(c[9650784+(h<<2)>>2]<<1)>>1]=s;return}u=c[2426956]|0;v=q&255;q=u&1048575;f=c[3531864]|0;r=c[f+2092+(q>>>11<<2)>>2]|0;if((r|0)==0){gg[c[f+8240>>2]&4095](q,v);A=c[3531864]|0}else{a[r+q|0]=v;A=f}f=(s&65535)>>>8&255;s=u+1&1048575;u=c[A+2092+(s>>>11<<2)>>2]|0;if((u|0)==0){gg[c[A+8240>>2]&4095](s,f);return}else{a[u+s|0]=f;return}break};case 16:{f=d+48|0;s=((c[f>>2]|0)!=0)+w|0;u=s+k|0;c[f>>2]=u&65536;c[d+40>>2]=(u^k)&32768&(u^s);c[d+36>>2]=(s^k^u)&16;s=u<<16>>16;c[d+52>>2]=s;c[d+44>>2]=s;c[d+32>>2]=s;if(i){b[d+(c[9650784+(h<<2)>>2]<<1)>>1]=u&65535;return}s=c[2426956]|0;f=u&255;v=s&1048575;q=c[3531864]|0;r=c[q+2092+(v>>>11<<2)>>2]|0;if((r|0)==0){gg[c[q+8240>>2]&4095](v,f);B=c[3531864]|0}else{a[r+v|0]=f;B=q}q=(u&65535)>>>8&255;u=s+1&1048575;s=c[B+2092+(u>>>11<<2)>>2]|0;if((s|0)==0){gg[c[B+8240>>2]&4095](u,q);return}else{a[s+u|0]=q;return}break};case 24:{q=d+48|0;u=((c[q>>2]|0)!=0)+w|0;s=k-u|0;c[q>>2]=s&65536;q=u^k;c[d+40>>2]=q&32768&(s^k);c[d+36>>2]=(s^q)&16;q=s<<16>>16;c[d+52>>2]=q;c[d+44>>2]=q;c[d+32>>2]=q;if(i){b[d+(c[9650784+(h<<2)>>2]<<1)>>1]=s&65535;return}q=c[2426956]|0;u=s&255;f=q&1048575;v=c[3531864]|0;r=c[v+2092+(f>>>11<<2)>>2]|0;if((r|0)==0){gg[c[v+8240>>2]&4095](f,u);C=c[3531864]|0}else{a[r+f|0]=u;C=v}v=(s&65535)>>>8&255;s=q+1&1048575;q=c[C+2092+(s>>>11<<2)>>2]|0;if((q|0)==0){gg[c[C+8240>>2]&4095](s,v);return}else{a[q+s|0]=v;return}break};case 32:{v=w&k;c[d+36>>2]=0;c[d+40>>2]=0;c[d+48>>2]=0;s=v&65535;q=s<<16>>16;c[d+52>>2]=q;c[d+44>>2]=q;c[d+32>>2]=q;if(i){b[d+(c[9650784+(h<<2)>>2]<<1)>>1]=s;return}q=c[2426956]|0;u=v&255;v=q&1048575;f=c[3531864]|0;r=c[f+2092+(v>>>11<<2)>>2]|0;if((r|0)==0){gg[c[f+8240>>2]&4095](v,u);D=c[3531864]|0}else{a[r+v|0]=u;D=f}f=(s&65535)>>>8&255;s=q+1&1048575;q=c[D+2092+(s>>>11<<2)>>2]|0;if((q|0)==0){gg[c[D+8240>>2]&4095](s,f);return}else{a[q+s|0]=f;return}break};case 40:{f=k-w|0;c[d+48>>2]=f&65536;s=w^k;c[d+40>>2]=s&32768&(f^k);c[d+36>>2]=(f^s)&16;s=f<<16>>16;c[d+52>>2]=s;c[d+44>>2]=s;c[d+32>>2]=s;if(i){b[d+(c[9650784+(h<<2)>>2]<<1)>>1]=f&65535;return}s=c[2426956]|0;q=f&255;u=s&1048575;v=c[3531864]|0;r=c[v+2092+(u>>>11<<2)>>2]|0;if((r|0)==0){gg[c[v+8240>>2]&4095](u,q);E=c[3531864]|0}else{a[r+u|0]=q;E=v}v=(f&65535)>>>8&255;f=s+1&1048575;s=c[E+2092+(f>>>11<<2)>>2]|0;if((s|0)==0){gg[c[E+8240>>2]&4095](f,v);return}else{a[s+f|0]=v;return}break};case 48:{v=w^k;c[d+36>>2]=0;c[d+40>>2]=0;c[d+48>>2]=0;f=v&65535;s=f<<16>>16;c[d+52>>2]=s;c[d+44>>2]=s;c[d+32>>2]=s;if(i){b[d+(c[9650784+(h<<2)>>2]<<1)>>1]=f;return}s=c[2426956]|0;q=v&255;v=s&1048575;u=c[3531864]|0;r=c[u+2092+(v>>>11<<2)>>2]|0;if((r|0)==0){gg[c[u+8240>>2]&4095](v,q);F=c[3531864]|0}else{a[r+v|0]=q;F=u}u=(f&65535)>>>8&255;f=s+1&1048575;s=c[F+2092+(f>>>11<<2)>>2]|0;if((s|0)==0){gg[c[F+8240>>2]&4095](f,u);return}else{a[s+f|0]=u;return}break};case 56:{break L57264;break};default:{return}}}}while(0);F=k-w|0;c[d+48>>2]=F&65536;h=w^k;c[d+40>>2]=h&32768&(F^k);c[d+36>>2]=(F^h)&16;h=F<<16>>16;c[d+52>>2]=h;c[d+44>>2]=h;c[d+32>>2]=h;return}function f7h(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=d+22|0;g=(e[f>>1]|0)<<4;h=(c[2385310]|0)+28|0;i=b[h>>1]|0;b[h>>1]=i+1&65535;h=(i&65535)+g&1048575;g=c[3531864]|0;i=c[g+6188+(h>>>11<<2)>>2]|0;if((i|0)==0){j=gj[c[g+8236>>2]&4095](h)|0}else{j=a[i+h|0]|0}h=j&255;i=(j&255)>191;do{if(i){k=a[d+(c[9648736+(h<<2)>>2]|0)|0]|0}else{j=(gj[c[679712+(h<<2)>>2]&4095](d)|0)&1048575;g=c[3531864]|0;l=c[g+44+(j>>>11<<2)>>2]|0;if((l|0)==0){k=gj[c[g+8236>>2]&4095](j)|0;break}else{k=a[l+j|0]|0;break}}}while(0);j=k&255;l=(e[f>>1]|0)<<4;f=(c[2385310]|0)+28|0;g=b[f>>1]|0;b[f>>1]=g+1&65535;f=(g&65535)+l&1048575;l=c[3531864]|0;g=c[l+6188+(f>>>11<<2)>>2]|0;if((g|0)==0){m=gj[c[l+8236>>2]&4095](f)|0}else{m=a[g+f|0]|0}f=m&255;do{if(i){g=d+84|0;c[g>>2]=(c[g>>2]|0)-(263170>>>((c[d+92>>2]|0)>>>0)&127);n=h&56;o=46820}else{g=h&56;l=c[d+92>>2]|0;if((g|0)==56){p=d+84|0;c[p>>2]=(c[p>>2]|0)-(855302>>>(l>>>0)&127);break}else{p=d+84|0;c[p>>2]=(c[p>>2]|0)-(1184263>>>(l>>>0)&127);n=g;o=46820;break}}}while(0);L57390:do{if((o|0)==46820){switch(n|0){case 0:{g=f+j|0;c[d+48>>2]=g&256;c[d+40>>2]=(g^j)&128&(g^f);c[d+36>>2]=(g^(m^k)&255)&16;l=g<<24>>24;c[d+52>>2]=l;c[d+44>>2]=l;c[d+32>>2]=l;if(i){a[d+(c[9648736+(h<<2)>>2]|0)|0]=g&255;return}l=g&255;g=c[2426956]&1048575;p=c[3531864]|0;q=c[p+2092+(g>>>11<<2)>>2]|0;if((q|0)==0){gg[c[p+8240>>2]&4095](g,l);return}else{a[q+g|0]=l;return}break};case 8:{l=m|k;c[d+36>>2]=0;c[d+40>>2]=0;c[d+48>>2]=0;g=l<<24>>24;c[d+52>>2]=g;c[d+44>>2]=g;c[d+32>>2]=g;if(i){a[d+(c[9648736+(h<<2)>>2]|0)|0]=l;return}g=c[2426956]&1048575;q=c[3531864]|0;p=c[q+2092+(g>>>11<<2)>>2]|0;if((p|0)==0){gg[c[q+8240>>2]&4095](g,l);return}else{a[p+g|0]=l;return}break};case 16:{l=d+48|0;g=((c[l>>2]|0)!=0)+f|0;p=g+j|0;c[l>>2]=p&256;c[d+40>>2]=(p^j)&128&(p^g);c[d+36>>2]=(g^j^p)&16;g=p<<24>>24;c[d+52>>2]=g;c[d+44>>2]=g;c[d+32>>2]=g;if(i){a[d+(c[9648736+(h<<2)>>2]|0)|0]=p&255;return}g=p&255;p=c[2426956]&1048575;l=c[3531864]|0;q=c[l+2092+(p>>>11<<2)>>2]|0;if((q|0)==0){gg[c[l+8240>>2]&4095](p,g);return}else{a[q+p|0]=g;return}break};case 24:{g=d+48|0;p=((c[g>>2]|0)!=0)+f|0;q=j-p|0;c[g>>2]=q&256;g=p^j;c[d+40>>2]=g&128&(q^j);c[d+36>>2]=(q^g)&16;g=q<<24>>24;c[d+52>>2]=g;c[d+44>>2]=g;c[d+32>>2]=g;if(i){a[d+(c[9648736+(h<<2)>>2]|0)|0]=q&255;return}g=q&255;q=c[2426956]&1048575;p=c[3531864]|0;l=c[p+2092+(q>>>11<<2)>>2]|0;if((l|0)==0){gg[c[p+8240>>2]&4095](q,g);return}else{a[l+q|0]=g;return}break};case 32:{g=m&k;c[d+36>>2]=0;c[d+40>>2]=0;c[d+48>>2]=0;q=g<<24>>24;c[d+52>>2]=q;c[d+44>>2]=q;c[d+32>>2]=q;if(i){a[d+(c[9648736+(h<<2)>>2]|0)|0]=g;return}q=c[2426956]&1048575;l=c[3531864]|0;p=c[l+2092+(q>>>11<<2)>>2]|0;if((p|0)==0){gg[c[l+8240>>2]&4095](q,g);return}else{a[p+q|0]=g;return}break};case 40:{g=j-f|0;c[d+48>>2]=g&256;q=(m^k)&255;c[d+40>>2]=q&128&(g^j);c[d+36>>2]=(g^q)&16;q=g<<24>>24;c[d+52>>2]=q;c[d+44>>2]=q;c[d+32>>2]=q;if(i){a[d+(c[9648736+(h<<2)>>2]|0)|0]=g&255;return}q=g&255;g=c[2426956]&1048575;p=c[3531864]|0;l=c[p+2092+(g>>>11<<2)>>2]|0;if((l|0)==0){gg[c[p+8240>>2]&4095](g,q);return}else{a[l+g|0]=q;return}break};case 48:{q=m^k;c[d+36>>2]=0;c[d+40>>2]=0;c[d+48>>2]=0;g=q<<24>>24;c[d+52>>2]=g;c[d+44>>2]=g;c[d+32>>2]=g;if(i){a[d+(c[9648736+(h<<2)>>2]|0)|0]=q;return}g=c[2426956]&1048575;l=c[3531864]|0;p=c[l+2092+(g>>>11<<2)>>2]|0;if((p|0)==0){gg[c[l+8240>>2]&4095](g,q);return}else{a[p+g|0]=q;return}break};case 56:{break L57390;break};default:{return}}}}while(0);h=j-f|0;c[d+48>>2]=h&256;f=(m^k)&255;c[d+40>>2]=f&128&(h^j);c[d+36>>2]=(h^f)&16;f=h<<24>>24;c[d+52>>2]=f;c[d+44>>2]=f;c[d+32>>2]=f;return}function f7i(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;f=d+22|0;g=(e[f>>1]|0)<<4;h=(c[2385310]|0)+28|0;i=b[h>>1]|0;b[h>>1]=i+1&65535;h=(i&65535)+g&1048575;g=c[3531864]|0;i=c[g+6188+(h>>>11<<2)>>2]|0;if((i|0)==0){j=gj[c[g+8236>>2]&4095](h)|0}else{j=a[i+h|0]|0}h=j&255;i=(j&255)>191;if(i){k=e[d+(c[9650784+(h<<2)>>2]<<1)>>1]|0}else{j=c[679712+(h<<2)>>2]|0;gj[j&4095](d)|0;j=c[2426956]|0;g=j&1048575;l=c[3531864]|0;m=c[l+44+(g>>>11<<2)>>2]|0;if((m|0)==0){n=gj[c[l+8236>>2]&4095](g)|0;o=n;p=c[2426956]|0;q=c[3531864]|0}else{o=a[m+g|0]|0;p=j;q=l}l=p+1&1048575;p=c[q+44+(l>>>11<<2)>>2]|0;if((p|0)==0){r=gj[c[q+8236>>2]&4095](l)|0}else{r=a[p+l|0]|0}k=(r&255)<<8|o&255}o=(e[f>>1]|0)<<4;f=(c[2385310]|0)+28|0;r=b[f>>1]|0;b[f>>1]=r+1&65535;f=(r&65535)+o&1048575;o=c[3531864]|0;r=c[o+6188+(f>>>11<<2)>>2]|0;if((r|0)==0){s=gj[c[o+8236>>2]&4095](f)|0}else{s=a[r+f|0]|0}f=s<<24>>24&65535;do{if(i){s=d+84|0;c[s>>2]=(c[s>>2]|0)-(263170>>>((c[d+92>>2]|0)>>>0)&127);t=h&56;u=46901}else{s=h&56;r=(c[2426956]&1|0)!=0;o=c[d+92>>2]|0;if((s|0)==56){l=d+84|0;c[l>>2]=(c[l>>2]|0)-((r?1118472:1117446)>>>(o>>>0)&127);break}else{l=d+84|0;c[l>>2]=(c[l>>2]|0)-((r?1710603:1708551)>>>(o>>>0)&127);t=s;u=46901;break}}}while(0);L57493:do{if((u|0)==46901){switch(t|0){case 0:{s=f+k|0;c[d+48>>2]=s&65536;c[d+40>>2]=(s^k)&32768&(s^f);c[d+36>>2]=(f^k^s)&16;o=s<<16>>16;c[d+52>>2]=o;c[d+44>>2]=o;c[d+32>>2]=o;if(i){b[d+(c[9650784+(h<<2)>>2]<<1)>>1]=s&65535;return}o=c[2426956]|0;r=s&255;l=o&1048575;p=c[3531864]|0;q=c[p+2092+(l>>>11<<2)>>2]|0;if((q|0)==0){gg[c[p+8240>>2]&4095](l,r);v=c[3531864]|0}else{a[q+l|0]=r;v=p}p=(s&65535)>>>8&255;s=o+1&1048575;o=c[v+2092+(s>>>11<<2)>>2]|0;if((o|0)==0){gg[c[v+8240>>2]&4095](s,p);return}else{a[o+s|0]=p;return}break};case 8:{p=f|k;c[d+36>>2]=0;c[d+40>>2]=0;c[d+48>>2]=0;s=p&65535;o=s<<16>>16;c[d+52>>2]=o;c[d+44>>2]=o;c[d+32>>2]=o;if(i){b[d+(c[9650784+(h<<2)>>2]<<1)>>1]=s;return}o=c[2426956]|0;r=p&255;p=o&1048575;l=c[3531864]|0;q=c[l+2092+(p>>>11<<2)>>2]|0;if((q|0)==0){gg[c[l+8240>>2]&4095](p,r);w=c[3531864]|0}else{a[q+p|0]=r;w=l}l=(s&65535)>>>8&255;s=o+1&1048575;o=c[w+2092+(s>>>11<<2)>>2]|0;if((o|0)==0){gg[c[w+8240>>2]&4095](s,l);return}else{a[o+s|0]=l;return}break};case 16:{l=d+48|0;s=((c[l>>2]|0)!=0)+f|0;o=s+k|0;c[l>>2]=o&65536;c[d+40>>2]=(o^k)&32768&(o^s);c[d+36>>2]=(s^k^o)&16;s=o<<16>>16;c[d+52>>2]=s;c[d+44>>2]=s;c[d+32>>2]=s;if(i){b[d+(c[9650784+(h<<2)>>2]<<1)>>1]=o&65535;return}s=c[2426956]|0;l=o&255;r=s&1048575;p=c[3531864]|0;q=c[p+2092+(r>>>11<<2)>>2]|0;if((q|0)==0){gg[c[p+8240>>2]&4095](r,l);x=c[3531864]|0}else{a[q+r|0]=l;x=p}p=(o&65535)>>>8&255;o=s+1&1048575;s=c[x+2092+(o>>>11<<2)>>2]|0;if((s|0)==0){gg[c[x+8240>>2]&4095](o,p);return}else{a[s+o|0]=p;return}break};case 24:{p=d+48|0;o=((c[p>>2]|0)!=0)+f|0;s=k-o|0;c[p>>2]=s&65536;p=o^k;c[d+40>>2]=p&32768&(s^k);c[d+36>>2]=(s^p)&16;p=s<<16>>16;c[d+52>>2]=p;c[d+44>>2]=p;c[d+32>>2]=p;if(i){b[d+(c[9650784+(h<<2)>>2]<<1)>>1]=s&65535;return}p=c[2426956]|0;o=s&255;l=p&1048575;r=c[3531864]|0;q=c[r+2092+(l>>>11<<2)>>2]|0;if((q|0)==0){gg[c[r+8240>>2]&4095](l,o);y=c[3531864]|0}else{a[q+l|0]=o;y=r}r=(s&65535)>>>8&255;s=p+1&1048575;p=c[y+2092+(s>>>11<<2)>>2]|0;if((p|0)==0){gg[c[y+8240>>2]&4095](s,r);return}else{a[p+s|0]=r;return}break};case 32:{r=f&k;c[d+36>>2]=0;c[d+40>>2]=0;c[d+48>>2]=0;s=r&65535;p=s<<16>>16;c[d+52>>2]=p;c[d+44>>2]=p;c[d+32>>2]=p;if(i){b[d+(c[9650784+(h<<2)>>2]<<1)>>1]=s;return}p=c[2426956]|0;o=r&255;r=p&1048575;l=c[3531864]|0;q=c[l+2092+(r>>>11<<2)>>2]|0;if((q|0)==0){gg[c[l+8240>>2]&4095](r,o);z=c[3531864]|0}else{a[q+r|0]=o;z=l}l=(s&65535)>>>8&255;s=p+1&1048575;p=c[z+2092+(s>>>11<<2)>>2]|0;if((p|0)==0){gg[c[z+8240>>2]&4095](s,l);return}else{a[p+s|0]=l;return}break};case 40:{l=k-f|0;c[d+48>>2]=l&65536;s=f^k;c[d+40>>2]=s&32768&(l^k);c[d+36>>2]=(l^s)&16;s=l<<16>>16;c[d+52>>2]=s;c[d+44>>2]=s;c[d+32>>2]=s;if(i){b[d+(c[9650784+(h<<2)>>2]<<1)>>1]=l&65535;return}s=c[2426956]|0;p=l&255;o=s&1048575;r=c[3531864]|0;q=c[r+2092+(o>>>11<<2)>>2]|0;if((q|0)==0){gg[c[r+8240>>2]&4095](o,p);A=c[3531864]|0}else{a[q+o|0]=p;A=r}r=(l&65535)>>>8&255;l=s+1&1048575;s=c[A+2092+(l>>>11<<2)>>2]|0;if((s|0)==0){gg[c[A+8240>>2]&4095](l,r);return}else{a[s+l|0]=r;return}break};case 48:{r=f^k;c[d+36>>2]=0;c[d+40>>2]=0;c[d+48>>2]=0;l=r&65535;s=l<<16>>16;c[d+52>>2]=s;c[d+44>>2]=s;c[d+32>>2]=s;if(i){b[d+(c[9650784+(h<<2)>>2]<<1)>>1]=l;return}s=c[2426956]|0;p=r&255;r=s&1048575;o=c[3531864]|0;q=c[o+2092+(r>>>11<<2)>>2]|0;if((q|0)==0){gg[c[o+8240>>2]&4095](r,p);B=c[3531864]|0}else{a[q+r|0]=p;B=o}o=(l&65535)>>>8&255;l=s+1&1048575;s=c[B+2092+(l>>>11<<2)>>2]|0;if((s|0)==0){gg[c[B+8240>>2]&4095](l,o);return}else{a[s+l|0]=o;return}break};case 56:{break L57493;break};default:{return}}}}while(0);B=k-f|0;c[d+48>>2]=B&65536;h=f^k;c[d+40>>2]=h&32768&(B^k);c[d+36>>2]=(B^h)&16;h=B<<16>>16;c[d+52>>2]=h;c[d+44>>2]=h;c[d+32>>2]=h;return}function f7j(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=(e[d+22>>1]|0)<<4;g=(c[2385310]|0)+28|0;h=b[g>>1]|0;b[g>>1]=h+1&65535;g=(h&65535)+f&1048575;f=c[3531864]|0;h=c[f+6188+(g>>>11<<2)>>2]|0;if((h|0)==0){i=gj[c[f+8236>>2]&4095](g)|0}else{i=a[h+g|0]|0}g=i&255;h=d;f=a[h+(c[9652832+(g<<2)>>2]|0)|0]|0;j=(i&255)>191;do{if(j){k=a[h+(c[9648736+(g<<2)>>2]|0)|0]|0}else{i=(gj[c[679712+(g<<2)>>2]&4095](d)|0)&1048575;l=c[3531864]|0;m=c[l+44+(i>>>11<<2)>>2]|0;if((m|0)==0){k=gj[c[l+8236>>2]&4095](i)|0;break}else{k=a[m+i|0]|0;break}}}while(0);c[d+36>>2]=0;c[d+40>>2]=0;c[d+48>>2]=0;g=(k&f)<<24>>24;c[d+52>>2]=g;c[d+44>>2]=g;c[d+32>>2]=g;g=d+84|0;c[g>>2]=(c[g>>2]|0)-((j?131586:657926)>>>((c[d+92>>2]|0)>>>0)&127);return}function f7k(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=(e[d+22>>1]|0)<<4;g=(c[2385310]|0)+28|0;h=b[g>>1]|0;b[g>>1]=h+1&65535;g=(h&65535)+f&1048575;f=c[3531864]|0;h=c[f+6188+(g>>>11<<2)>>2]|0;if((h|0)==0){i=gj[c[f+8236>>2]&4095](g)|0}else{i=a[h+g|0]|0}g=i&255;h=b[d+(c[9654880+(g<<2)>>2]<<1)>>1]|0;f=(i&255)>191;if(f){j=b[d+(c[9650784+(g<<2)>>2]<<1)>>1]|0}else{i=c[679712+(g<<2)>>2]|0;gj[i&4095](d)|0;i=c[2426956]|0;g=i&1048575;k=c[3531864]|0;l=c[k+44+(g>>>11<<2)>>2]|0;if((l|0)==0){m=gj[c[k+8236>>2]&4095](g)|0;n=m;o=c[2426956]|0;p=c[3531864]|0}else{n=a[l+g|0]|0;o=i;p=k}k=o+1&1048575;o=c[p+44+(k>>>11<<2)>>2]|0;if((o|0)==0){q=gj[c[p+8236>>2]&4095](k)|0}else{q=a[o+k|0]|0}j=(q&255)<<8|n&255}c[d+36>>2]=0;c[d+40>>2]=0;c[d+48>>2]=0;n=(j&h)<<16>>16;c[d+52>>2]=n;c[d+44>>2]=n;c[d+32>>2]=n;if(f){f=d+84|0;c[f>>2]=(c[f>>2]|0)-2;return}else{f=d+84|0;c[f>>2]=(c[f>>2]|0)-(((c[2426956]&1|0)!=0?921096:920070)>>>((c[d+92>>2]|0)>>>0)&127);return}}function f7l(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=(e[d+22>>1]|0)<<4;g=(c[2385310]|0)+28|0;h=b[g>>1]|0;b[g>>1]=h+1&65535;g=(h&65535)+f&1048575;f=c[3531864]|0;h=c[f+6188+(g>>>11<<2)>>2]|0;if((h|0)==0){i=gj[c[f+8236>>2]&4095](g)|0}else{i=a[h+g|0]|0}g=i&255;h=9652832+(g<<2)|0;f=d;j=f+(c[h>>2]|0)|0;k=a[j]|0;l=(i&255)>191;do{if(l){i=f+(c[9648736+(g<<2)>>2]|0)|0;a[j]=a[i]|0;a[i]=k}else{i=(gj[c[679712+(g<<2)>>2]&4095](d)|0)&1048575;m=c[3531864]|0;n=c[m+44+(i>>>11<<2)>>2]|0;if((n|0)==0){o=gj[c[m+8236>>2]&4095](i)|0;p=o;q=c[3531864]|0}else{p=a[n+i|0]|0;q=m}a[f+(c[h>>2]|0)|0]=p;m=c[2426956]&1048575;i=c[q+2092+(m>>>11<<2)>>2]|0;if((i|0)==0){gg[c[q+8240>>2]&4095](m,k);break}else{a[i+m|0]=k;break}}}while(0);k=d+84|0;c[k>>2]=(c[k>>2]|0)-((l?197379:1053192)>>>((c[d+92>>2]|0)>>>0)&127);return}function f7m(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=(e[d+22>>1]|0)<<4;g=(c[2385310]|0)+28|0;h=b[g>>1]|0;b[g>>1]=h+1&65535;g=(h&65535)+f&1048575;f=c[3531864]|0;h=c[f+6188+(g>>>11<<2)>>2]|0;if((h|0)==0){i=gj[c[f+8236>>2]&4095](g)|0}else{i=a[h+g|0]|0}g=i&255;h=9654880+(g<<2)|0;f=d+(c[h>>2]<<1)|0;j=b[f>>1]|0;if((i&255)>191){i=d+(c[9650784+(g<<2)>>2]<<1)|0;b[f>>1]=b[i>>1]|0;b[i>>1]=j;i=d+84|0;c[i>>2]=(c[i>>2]|0)-3;return}gj[c[679712+(g<<2)>>2]&4095](d)|0;g=c[2426956]|0;i=g&1048575;f=c[3531864]|0;k=c[f+44+(i>>>11<<2)>>2]|0;if((k|0)==0){l=gj[c[f+8236>>2]&4095](i)|0;m=l;n=c[2426956]|0;o=c[3531864]|0}else{m=a[k+i|0]|0;n=g;o=f}f=n+1&1048575;g=c[o+44+(f>>>11<<2)>>2]|0;if((g|0)==0){i=gj[c[o+8236>>2]&4095](f)|0;p=i;q=c[2426956]|0;r=c[3531864]|0}else{p=a[g+f|0]|0;q=n;r=o}b[d+(c[h>>2]<<1)>>1]=(p&255)<<8|m&255;m=j&255;p=q&1048575;h=c[r+2092+(p>>>11<<2)>>2]|0;if((h|0)==0){gg[c[r+8240>>2]&4095](p,m);s=c[3531864]|0}else{a[h+p|0]=m;s=r}r=(j&65535)>>>8&255;j=q+1&1048575;q=c[s+2092+(j>>>11<<2)>>2]|0;if((q|0)==0){gg[c[s+8240>>2]&4095](j,r)}else{a[q+j|0]=r}r=d+84|0;c[r>>2]=(c[r>>2]|0)-(((c[2426956]&1|0)!=0?1579020:1576968)>>>((c[d+92>>2]|0)>>>0)&127);return}function f7n(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=(e[d+22>>1]|0)<<4;g=(c[2385310]|0)+28|0;h=b[g>>1]|0;b[g>>1]=h+1&65535;g=(h&65535)+f&1048575;f=c[3531864]|0;h=c[f+6188+(g>>>11<<2)>>2]|0;if((h|0)==0){i=gj[c[f+8236>>2]&4095](g)|0}else{i=a[h+g|0]|0}g=i&255;h=d;f=a[h+(c[9652832+(g<<2)>>2]|0)|0]|0;j=(i&255)>191;do{if(j){a[h+(c[9648736+(g<<2)>>2]|0)|0]=f}else{i=(gj[c[679712+(g<<2)>>2]&4095](d)|0)&1048575;k=c[3531864]|0;l=c[k+2092+(i>>>11<<2)>>2]|0;if((l|0)==0){gg[c[k+8240>>2]&4095](i,f);break}else{a[l+i|0]=f;break}}}while(0);f=d+84|0;c[f>>2]=(c[f>>2]|0)-((j?131586:592131)>>>((c[d+92>>2]|0)>>>0)&127);return}function f7o(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=(e[d+22>>1]|0)<<4;g=(c[2385310]|0)+28|0;h=b[g>>1]|0;b[g>>1]=h+1&65535;g=(h&65535)+f&1048575;f=c[3531864]|0;h=c[f+6188+(g>>>11<<2)>>2]|0;if((h|0)==0){i=gj[c[f+8236>>2]&4095](g)|0}else{i=a[h+g|0]|0}g=i&255;h=b[d+(c[9654880+(g<<2)>>2]<<1)>>1]|0;if((i&255)>191){b[d+(c[9650784+(g<<2)>>2]<<1)>>1]=h;i=d+84|0;c[i>>2]=(c[i>>2]|0)-2;return}gj[c[679712+(g<<2)>>2]&4095](d)|0;g=c[2426956]|0;i=h&255;f=g&1048575;j=c[3531864]|0;k=c[j+2092+(f>>>11<<2)>>2]|0;if((k|0)==0){gg[c[j+8240>>2]&4095](f,i);l=c[3531864]|0}else{a[k+f|0]=i;l=j}j=(h&65535)>>>8&255;h=g+1&1048575;g=c[l+2092+(h>>>11<<2)>>2]|0;if((g|0)==0){gg[c[l+8240>>2]&4095](h,j)}else{a[g+h|0]=j}j=d+84|0;c[j>>2]=(c[j>>2]|0)-(((c[2426956]&1|0)!=0?855301:854275)>>>((c[d+92>>2]|0)>>>0)&127);return}function f7p(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=(e[d+22>>1]|0)<<4;g=(c[2385310]|0)+28|0;h=b[g>>1]|0;b[g>>1]=h+1&65535;g=(h&65535)+f&1048575;f=c[3531864]|0;h=c[f+6188+(g>>>11<<2)>>2]|0;if((h|0)==0){i=gj[c[f+8236>>2]&4095](g)|0}else{i=a[h+g|0]|0}g=i&255;h=(i&255)>191;if(h){i=d;j=a[i+(c[9648736+(g<<2)>>2]|0)|0]|0;k=i}else{i=(gj[c[679712+(g<<2)>>2]&4095](d)|0)&1048575;f=c[3531864]|0;l=c[f+44+(i>>>11<<2)>>2]|0;if((l|0)==0){m=gj[c[f+8236>>2]&4095](i)|0}else{m=a[l+i|0]|0}j=m;k=d}a[k+(c[9652832+(g<<2)>>2]|0)|0]=j;j=d+84|0;c[j>>2]=(c[j>>2]|0)-((h?131586:723717)>>>((c[d+92>>2]|0)>>>0)&127);return}function f7q(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=(e[d+22>>1]|0)<<4;g=(c[2385310]|0)+28|0;h=b[g>>1]|0;b[g>>1]=h+1&65535;g=(h&65535)+f&1048575;f=c[3531864]|0;h=c[f+6188+(g>>>11<<2)>>2]|0;if((h|0)==0){i=gj[c[f+8236>>2]&4095](g)|0}else{i=a[h+g|0]|0}g=i&255;if((i&255)>191){b[d+(c[9654880+(g<<2)>>2]<<1)>>1]=b[d+(c[9650784+(g<<2)>>2]<<1)>>1]|0;i=d+84|0;c[i>>2]=(c[i>>2]|0)-2;return}gj[c[679712+(g<<2)>>2]&4095](d)|0;i=c[2426956]|0;h=i&1048575;f=c[3531864]|0;j=c[f+44+(h>>>11<<2)>>2]|0;if((j|0)==0){k=gj[c[f+8236>>2]&4095](h)|0;l=k;m=c[2426956]|0;n=c[3531864]|0}else{l=a[j+h|0]|0;m=i;n=f}f=m+1&1048575;i=c[n+44+(f>>>11<<2)>>2]|0;if((i|0)==0){h=gj[c[n+8236>>2]&4095](f)|0;o=h;p=c[2426956]|0}else{o=a[i+f|0]|0;p=m}b[d+(c[9654880+(g<<2)>>2]<<1)>>1]=(o&255)<<8|l&255;l=d+84|0;c[l>>2]=(c[l>>2]|0)-(((p&1|0)!=0?986887:985861)>>>((c[d+92>>2]|0)>>>0)&127);return}function f7r(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=d+20|0;g=d+22|0;h=(e[g>>1]|0)<<4;i=(c[2385310]|0)+28|0;j=b[i>>1]|0;b[i>>1]=j+1&65535;i=(j&65535)+h&1048575;h=c[3531864]|0;j=c[h+6188+(i>>>11<<2)>>2]|0;if((j|0)==0){k=gj[c[h+8236>>2]&4095](i)|0}else{k=a[j+i|0]|0}i=k&255;j=i&56;if((j|0)==8){if((k&255)>191){b[d+(c[9650784+(i<<2)>>2]<<1)>>1]=b[g>>1]|0;h=d+84|0;c[h>>2]=(c[h>>2]|0)-2;return}h=c[679712+(i<<2)>>2]|0;gj[h&4095](d)|0;h=c[2426956]|0;l=b[g>>1]|0;g=l&255;m=h&1048575;n=c[3531864]|0;o=c[n+2092+(m>>>11<<2)>>2]|0;if((o|0)==0){gg[c[n+8240>>2]&4095](m,g);p=c[3531864]|0}else{a[o+m|0]=g;p=n}n=(l&65535)>>>8&255;l=h+1&1048575;h=c[p+2092+(l>>>11<<2)>>2]|0;if((h|0)==0){gg[c[p+8240>>2]&4095](l,n)}else{a[h+l|0]=n}n=d+84|0;c[n>>2]=(c[n>>2]|0)-(((c[2426956]&1|0)!=0?921093:920067)>>>((c[d+92>>2]|0)>>>0)&127);return}else if((j|0)==0){if((k&255)>191){b[d+(c[9650784+(i<<2)>>2]<<1)>>1]=b[f>>1]|0;n=d+84|0;c[n>>2]=(c[n>>2]|0)-2;return}gj[c[679712+(i<<2)>>2]&4095](d)|0;n=c[2426956]|0;l=b[f>>1]|0;f=l&255;h=n&1048575;p=c[3531864]|0;g=c[p+2092+(h>>>11<<2)>>2]|0;if((g|0)==0){gg[c[p+8240>>2]&4095](h,f);q=c[3531864]|0}else{a[g+h|0]=f;q=p}p=(l&65535)>>>8&255;l=n+1&1048575;n=c[q+2092+(l>>>11<<2)>>2]|0;if((n|0)==0){gg[c[q+8240>>2]&4095](l,p)}else{a[n+l|0]=p}p=d+84|0;c[p>>2]=(c[p>>2]|0)-(((c[2426956]&1|0)!=0?921093:920067)>>>((c[d+92>>2]|0)>>>0)&127);return}else if((j|0)==16){if((k&255)>191){b[d+(c[9650784+(i<<2)>>2]<<1)>>1]=b[d+24>>1]|0;p=d+84|0;c[p>>2]=(c[p>>2]|0)-2;return}gj[c[679712+(i<<2)>>2]&4095](d)|0;p=c[2426956]|0;l=b[d+24>>1]|0;n=l&255;q=p&1048575;f=c[3531864]|0;h=c[f+2092+(q>>>11<<2)>>2]|0;if((h|0)==0){gg[c[f+8240>>2]&4095](q,n);r=c[3531864]|0}else{a[h+q|0]=n;r=f}f=(l&65535)>>>8&255;l=p+1&1048575;p=c[r+2092+(l>>>11<<2)>>2]|0;if((p|0)==0){gg[c[r+8240>>2]&4095](l,f)}else{a[p+l|0]=f}f=d+84|0;c[f>>2]=(c[f>>2]|0)-(((c[2426956]&1|0)!=0?921093:920067)>>>((c[d+92>>2]|0)>>>0)&127);return}else if((j|0)==24){if((k&255)>191){b[d+(c[9650784+(i<<2)>>2]<<1)>>1]=b[d+26>>1]|0;k=d+84|0;c[k>>2]=(c[k>>2]|0)-2;return}gj[c[679712+(i<<2)>>2]&4095](d)|0;i=c[2426956]|0;k=b[d+26>>1]|0;j=k&255;f=i&1048575;l=c[3531864]|0;p=c[l+2092+(f>>>11<<2)>>2]|0;if((p|0)==0){gg[c[l+8240>>2]&4095](f,j);s=c[3531864]|0}else{a[p+f|0]=j;s=l}l=(k&65535)>>>8&255;k=i+1&1048575;i=c[s+2092+(k>>>11<<2)>>2]|0;if((i|0)==0){gg[c[s+8240>>2]&4095](k,l)}else{a[i+k|0]=l}l=d+84|0;c[l>>2]=(c[l>>2]|0)-(((c[2426956]&1|0)!=0?921093:920067)>>>((c[d+92>>2]|0)>>>0)&127);return}else{return}}function f7s(d){d=d|0;var f=0,g=0,h=0,i=0;f=(e[d+22>>1]|0)<<4;g=(c[2385310]|0)+28|0;h=b[g>>1]|0;b[g>>1]=h+1&65535;g=(h&65535)+f&1048575;f=c[3531864]|0;h=c[f+6188+(g>>>11<<2)>>2]|0;if((h|0)==0){i=gj[c[f+8236>>2]&4095](g)|0}else{i=a[h+g|0]|0}g=i&255;gj[c[679712+(g<<2)>>2]&4095](d)|0;b[d+(c[9654880+(g<<2)>>2]<<1)>>1]=b[4853904]|0;g=d+84|0;c[g>>2]=(c[g>>2]|0)-(263170>>>((c[d+92>>2]|0)>>>0)&127);return}function f7t(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=d+22|0;g=(e[f>>1]|0)<<4;h=(c[2385310]|0)+28|0;i=b[h>>1]|0;b[h>>1]=i+1&65535;h=(i&65535)+g&1048575;g=c[3531864]|0;i=c[g+6188+(h>>>11<<2)>>2]|0;if((i|0)==0){j=gj[c[g+8236>>2]&4095](h)|0}else{j=a[i+h|0]|0}h=j&255;if((j&255)>191){j=b[d+(c[9650784+(h<<2)>>2]<<1)>>1]|0;i=d+84|0;c[i>>2]=(c[i>>2]|0)-2;k=j}else{j=c[679712+(h<<2)>>2]|0;gj[j&4095](d)|0;j=c[2426956]|0;i=j&1048575;g=c[3531864]|0;l=c[g+44+(i>>>11<<2)>>2]|0;if((l|0)==0){m=gj[c[g+8236>>2]&4095](i)|0;n=m;o=c[2426956]|0;p=c[3531864]|0}else{n=a[l+i|0]|0;o=j;p=g}g=o+1&1048575;j=c[p+44+(g>>>11<<2)>>2]|0;if((j|0)==0){i=gj[c[p+8236>>2]&4095](g)|0;q=i;r=c[2426956]|0}else{q=a[j+g|0]|0;r=o}o=d+84|0;c[o>>2]=(c[o>>2]|0)-(((r&1|0)!=0?986887:985861)>>>((c[d+92>>2]|0)>>>0)&127);k=(q&255)<<8|n&255}n=h&56;if((n|0)==16){b[d+24>>1]=k;s=d+80|0;a[s]=1;return}else if((n|0)==24){b[d+26>>1]=k;s=d+80|0;a[s]=1;return}else if((n|0)==0){b[d+20>>1]=k;s=d+80|0;a[s]=1;return}else if((n|0)==8){b[f>>1]=k;s=d+80|0;a[s]=1;return}else{s=d+80|0;a[s]=1;return}}function f7u(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;f=(e[d+22>>1]|0)<<4;g=(c[2385310]|0)+28|0;h=b[g>>1]|0;b[g>>1]=h+1&65535;g=(h&65535)+f&1048575;f=c[3531864]|0;h=c[f+6188+(g>>>11<<2)>>2]|0;if((h|0)==0){i=gj[c[f+8236>>2]&4095](g)|0;j=i;k=c[3531864]|0}else{j=a[h+g|0]|0;k=f}f=j&255;g=d+8|0;h=(b[g>>1]|0)+2&65535;b[g>>1]=h;i=d+24|0;l=b[i>>1]|0;m=((h&65535)+65534&65535)+((l&65535)<<4)&1048575;n=c[k+44+(m>>>11<<2)>>2]|0;if((n|0)==0){o=gj[c[k+8236>>2]&4095](m)|0;p=o;q=b[i>>1]|0;r=b[g>>1]|0;s=c[3531864]|0}else{p=a[n+m|0]|0;q=l;r=h;s=k}k=((r&65535)+65534&65535)+((q&65535)<<4|1)&1048575;q=c[s+44+(k>>>11<<2)>>2]|0;if((q|0)==0){t=gj[c[s+8236>>2]&4095](k)|0}else{t=a[q+k|0]|0}if((j&255)>191){b[d+(c[9650784+(f<<2)>>2]<<1)>>1]=(t&255)<<8|p&255;u=d+84|0;v=c[u>>2]|0;w=v-21|0;c[u>>2]=w;return}gj[c[679712+(f<<2)>>2]&4095](d)|0;f=c[2426956]|0;j=f&1048575;k=c[3531864]|0;q=c[k+2092+(j>>>11<<2)>>2]|0;if((q|0)==0){gg[c[k+8240>>2]&4095](j,p);x=c[3531864]|0}else{a[q+j|0]=p;x=k}k=f+1&1048575;f=c[x+2092+(k>>>11<<2)>>2]|0;if((f|0)==0){gg[c[x+8240>>2]&4095](k,t);u=d+84|0;v=c[u>>2]|0;w=v-21|0;c[u>>2]=w;return}else{a[f+k|0]=t;u=d+84|0;v=c[u>>2]|0;w=v-21|0;c[u>>2]=w;return}}function f7v(a){a=a|0;var b=0;b=a+84|0;c[b>>2]=(c[b>>2]|0)-3;return}function f7w(a){a=a|0;var d=0,e=0,f=0;d=a+2|0;e=b[d>>1]|0;f=a|0;b[d>>1]=b[f>>1]|0;b[f>>1]=e;e=a+84|0;c[e>>2]=(c[e>>2]|0)-3;return}function f7x(a){a=a|0;var d=0,e=0,f=0;d=a+4|0;e=b[d>>1]|0;f=a|0;b[d>>1]=b[f>>1]|0;b[f>>1]=e;e=a+84|0;c[e>>2]=(c[e>>2]|0)-3;return}function f7y(a){a=a|0;var d=0,e=0,f=0;d=a+6|0;e=b[d>>1]|0;f=a|0;b[d>>1]=b[f>>1]|0;b[f>>1]=e;e=a+84|0;c[e>>2]=(c[e>>2]|0)-3;return}function f7z(a){a=a|0;var d=0,e=0,f=0;d=a+8|0;e=b[d>>1]|0;f=a|0;b[d>>1]=b[f>>1]|0;b[f>>1]=e;e=a+84|0;c[e>>2]=(c[e>>2]|0)-3;return}function f7A(a){a=a|0;var d=0,e=0,f=0;d=a+10|0;e=b[d>>1]|0;f=a|0;b[d>>1]=b[f>>1]|0;b[f>>1]=e;e=a+84|0;c[e>>2]=(c[e>>2]|0)-3;return}function f7B(a){a=a|0;var d=0,e=0,f=0;d=a+12|0;e=b[d>>1]|0;f=a|0;b[d>>1]=b[f>>1]|0;b[f>>1]=e;e=a+84|0;c[e>>2]=(c[e>>2]|0)-3;return}function f7C(a){a=a|0;var d=0,e=0,f=0;d=a+14|0;e=b[d>>1]|0;f=a|0;b[d>>1]=b[f>>1]|0;b[f>>1]=e;e=a+84|0;c[e>>2]=(c[e>>2]|0)-3;return}function f7D(b){b=b|0;var d=0;a[b+1|0]=a[b]>>7;d=b+84|0;c[d>>2]=(c[d>>2]|0)-2;return}function f7E(d){d=d|0;var e=0;b[d+4>>1]=a[d+1|0]>>7<<24>>24;e=d+84|0;c[e>>2]=(c[e>>2]|0)-4;return}function f7F(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;f=d+22|0;g=(e[f>>1]|0)<<4;h=c[2385310]|0;i=h+28|0;j=b[i>>1]|0;k=j+1&65535;b[i>>1]=k;i=(j&65535)+g&1048575;g=c[3531864]|0;j=c[g+6188+(i>>>11<<2)>>2]|0;if((j|0)==0){l=gj[c[g+8236>>2]&4095](i)|0;m=c[2385310]|0;n=l;o=m;p=b[m+28>>1]|0;q=c[3531864]|0}else{n=a[j+i|0]|0;o=h;p=k;q=g}g=(e[f>>1]|0)<<4;k=p+1&65535;b[o+28>>1]=k;h=(p&65535)+g&1048575;g=c[q+6188+(h>>>11<<2)>>2]|0;if((g|0)==0){p=gj[c[q+8236>>2]&4095](h)|0;i=c[2385310]|0;r=p;s=i;t=b[i+28>>1]|0;u=c[3531864]|0}else{r=a[g+h|0]|0;s=o;t=k;u=q}q=(r&255)<<8|n&255;n=(e[f>>1]|0)<<4;r=t+1&65535;b[s+28>>1]=r;k=(t&65535)+n&1048575;n=c[u+6188+(k>>>11<<2)>>2]|0;if((n|0)==0){t=gj[c[u+8236>>2]&4095](k)|0;o=c[2385310]|0;v=t;w=o;x=b[o+28>>1]|0;y=c[3531864]|0}else{v=a[n+k|0]|0;w=s;x=r;y=u}u=(e[f>>1]|0)<<4;b[w+28>>1]=x+1&65535;w=(x&65535)+u&1048575;u=c[y+6188+(w>>>11<<2)>>2]|0;if((u|0)==0){x=gj[c[y+8236>>2]&4095](w)|0;z=x;A=c[3531864]|0}else{z=a[u+w|0]|0;A=y}y=(z&255)<<8|v&255;v=d+8|0;z=(b[v>>1]|0)-2&65535;b[v>>1]=z;w=d+24|0;u=((e[w>>1]|0)<<4)+(z&65535)|0;z=b[f>>1]|0;x=z&255;r=u&1048575;s=c[A+2092+(r>>>11<<2)>>2]|0;if((s|0)==0){gg[c[A+8240>>2]&4095](r,x);B=c[3531864]|0}else{a[s+r|0]=x;B=A}A=(z&65535)>>>8&255;z=u+1&1048575;u=c[B+2092+(z>>>11<<2)>>2]|0;if((u|0)==0){gg[c[B+8240>>2]&4095](z,A);C=c[3531864]|0}else{a[u+z|0]=A;C=B}B=(b[v>>1]|0)-2&65535;b[v>>1]=B;A=((e[w>>1]|0)<<4)+(B&65535)|0;B=d+28|0;w=b[B>>1]|0;z=w&255;u=A&1048575;x=c[C+2092+(u>>>11<<2)>>2]|0;if((x|0)==0){gg[c[C+8240>>2]&4095](u,z);D=c[3531864]|0}else{a[x+u|0]=z;D=C}C=(w&65535)>>>8&255;w=A+1&1048575;A=c[D+2092+(w>>>11<<2)>>2]|0;if((A|0)==0){gg[c[D+8240>>2]&4095](w,C);b[B>>1]=q;b[f>>1]=y;E=d+91|0;a[E]=1;F=b[v>>1]|0;G=F&1;H=G<<16>>16!=0;I=d+92|0;J=c[I>>2]|0;K=H?1907981:1905929;L=K>>>(J>>>0);M=L&127;N=d+84|0;O=c[N>>2]|0;P=O-M|0;c[N>>2]=P;return}else{a[A+w|0]=C;b[B>>1]=q;b[f>>1]=y;E=d+91|0;a[E]=1;F=b[v>>1]|0;G=F&1;H=G<<16>>16!=0;I=d+92|0;J=c[I>>2]|0;K=H?1907981:1905929;L=K>>>(J>>>0);M=L&127;N=d+84|0;O=c[N>>2]|0;P=O-M|0;c[N>>2]=P;return}}function f7G(a){a=a|0;var d=0;if((c[a+76>>2]|0)==0){d=a+28|0;b[d>>1]=(b[d>>1]|0)-1&65535}d=a+84|0;c[d>>2]=(c[d>>2]|0)-5;return}function f7H(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=(c[f+48>>2]|0)!=0|(d[9761200+(c[f+52>>2]&255)|0]|0)<<2|((c[f+36>>2]|0)!=0)<<4|((c[f+44>>2]|0)==0)<<6|(c[f+32>>2]|0)>>>31<<7|(d[f+56|0]|0)<<8|(d[f+57|0]|0)<<9|(d[f+58|0]|0)<<10|((c[f+40>>2]|0)!=0)<<11|(d[f+59|0]|0)<<15|28674;h=f+8|0;i=(b[h>>1]|0)-2&65535;b[h>>1]=i;h=((e[f+24>>1]|0)<<4)+(i&65535)|0;i=g&255;j=h&1048575;k=c[3531864]|0;l=c[k+2092+(j>>>11<<2)>>2]|0;if((l|0)==0){gg[c[k+8240>>2]&4095](j,i);m=c[3531864]|0}else{a[l+j|0]=i;m=k}k=(g&65535)>>>8&255;g=h+1&1048575;h=c[m+2092+(g>>>11<<2)>>2]|0;if((h|0)==0){gg[c[m+8240>>2]&4095](g,k);n=f+92|0;o=c[n>>2]|0;p=788483>>>(o>>>0);q=p&127;r=f+84|0;s=c[r>>2]|0;t=s-q|0;c[r>>2]=t;return}else{a[h+g|0]=k;n=f+92|0;o=c[n>>2]|0;p=788483>>>(o>>>0);q=p&127;r=f+84|0;s=c[r>>2]|0;t=s-q|0;c[r>>2]=t;return}}function f7I(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=d+8|0;g=(b[f>>1]|0)+2&65535;b[f>>1]=g;h=d+24|0;i=b[h>>1]|0;j=((g&65535)+65534&65535)+((i&65535)<<4)&1048575;k=c[3531864]|0;l=c[k+44+(j>>>11<<2)>>2]|0;if((l|0)==0){m=gj[c[k+8236>>2]&4095](j)|0;n=m;o=b[h>>1]|0;p=b[f>>1]|0;q=c[3531864]|0}else{n=a[l+j|0]|0;o=i;p=g;q=k}k=n&255;n=((p&65535)+65534&65535)+((o&65535)<<4|1)&1048575;o=c[q+44+(n>>>11<<2)>>2]|0;if((o|0)==0){r=gj[c[q+8236>>2]&4095](n)|0}else{r=a[o+n|0]|0}c[d+48>>2]=k&1;c[d+52>>2]=k>>>2&1^1;c[d+36>>2]=k&16;c[d+44>>2]=k>>>6&1^1;c[d+32>>2]=k<<24>>31;k=r&1;a[d+56|0]=k;a[d+57|0]=(r&255)>>>1&1;a[d+58|0]=(r&255)>>>2&1;c[d+40>>2]=(r&255)<<8&2048;a[d+59|0]=(r&255)>>>7;r=d+84|0;c[r>>2]=(c[r>>2]|0)-(788485>>>((c[d+92>>2]|0)>>>0)&127);if(k<<24>>24==0){return}k=d+90|0;a[k]=(a[k]|0)-1&255;k=(e[d+22>>1]|0)<<4;r=d+28|0;n=b[r>>1]|0;b[r>>1]=n+1&65535;r=(k+(n&65535)^c[d+16>>2])&1048575;n=c[3531864]|0;k=c[n+4140+(r>>>11<<2)>>2]|0;if((k|0)==0){s=gj[c[n+8236>>2]&4095](r)|0}else{s=a[k+r|0]|0}gf[c[2520528+((s&255)<<2)>>2]&2047](d);f9v(d,1,0);return}function f7J(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=b+48|0;f=b+52|0;g=b+36|0;h=b+44|0;i=b+32|0;j=b+56|0;k=(d[9761200+(c[f>>2]&255)|0]|0)<<2|(c[e>>2]|0)!=0|((c[g>>2]|0)!=0)<<4|((c[h>>2]|0)==0)<<6|(c[i>>2]|0)>>>31<<7|(d[j]|0)<<8;l=b+57|0;m=k|(d[l]|0)<<9;n=b+58|0;o=m|(d[n]|0)<<10;p=b+40|0;q=((c[p>>2]|0)!=0)<<11;r=b+59|0;s=o|(d[r]|0)<<15;t=d[b+1|0]|0;c[e>>2]=t&1;c[f>>2]=t>>>2&1^1;c[g>>2]=t&16;c[h>>2]=t>>>6&1^1;c[i>>2]=t<<24>>31;a[j]=k>>>8&1;a[l]=m>>>9&1;a[n]=o>>>10&1;c[p>>2]=o&2048|q;a[r]=s>>>15&1;s=b+84|0;c[s>>2]=(c[s>>2]|0)-(197378>>>((c[b+92>>2]|0)>>>0)&127);return}function f7K(b){b=b|0;var e=0;a[b+1|0]=((c[b+48>>2]|0)!=0|(d[9761200+(c[b+52>>2]&255)|0]|0)<<2|((c[b+36>>2]|0)!=0)<<4|((c[b+44>>2]|0)==0)<<6|(c[b+32>>2]|0)>>>31<<7|2)&255;e=b+84|0;c[e>>2]=(c[e>>2]|0)-(197378>>>((c[b+92>>2]|0)>>>0)&127);return}function f7L(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;f=d+22|0;g=e[f>>1]<<4;h=c[2385310]|0;i=h+28|0;j=b[i>>1]|0;k=j+1&65535;b[i>>1]=k;i=(j&65535)+g&1048575;g=c[3531864]|0;j=c[g+6188+(i>>>11<<2)>>2]|0;if((j|0)==0){l=gj[c[g+8236>>2]&4095](i)|0;m=c[2385310]|0;n=l;o=m;p=b[m+28>>1]|0;q=c[3531864]|0}else{n=a[j+i|0]|0;o=h;p=k;q=g}g=e[f>>1]<<4;b[o+28>>1]=p+1&65535;o=(p&65535)+g&1048575;g=c[q+6188+(o>>>11<<2)>>2]|0;if((g|0)==0){r=gj[c[q+8236>>2]&4095](o)|0}else{r=a[g+o|0]|0}if((a[d+100|0]|0)==0){s=e[d+26>>1]<<4}else{s=c[d+96>>2]|0}o=s+((r&255)<<8|n&255)&1048575;n=c[3531864]|0;r=c[n+44+(o>>>11<<2)>>2]|0;if((r|0)==0){t=gj[c[n+8236>>2]&4095](o)|0;u=d;a[u]=t;v=d+92|0;w=c[v>>2]|0;x=657925>>>(w>>>0);y=x&127;z=d+84|0;A=c[z>>2]|0;B=A-y|0;c[z>>2]=B;return}else{t=a[r+o|0]|0;u=d;a[u]=t;v=d+92|0;w=c[v>>2]|0;x=657925>>>(w>>>0);y=x&127;z=d+84|0;A=c[z>>2]|0;B=A-y|0;c[z>>2]=B;return}}function f7M(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;f=d+22|0;g=(e[f>>1]|0)<<4;h=c[2385310]|0;i=h+28|0;j=b[i>>1]|0;k=j+1&65535;b[i>>1]=k;i=(j&65535)+g&1048575;g=c[3531864]|0;j=c[g+6188+(i>>>11<<2)>>2]|0;if((j|0)==0){l=gj[c[g+8236>>2]&4095](i)|0;m=c[2385310]|0;n=l;o=m;p=b[m+28>>1]|0;q=c[3531864]|0}else{n=a[j+i|0]|0;o=h;p=k;q=g}g=n&255;n=(e[f>>1]|0)<<4;b[o+28>>1]=p+1&65535;o=(p&65535)+n&1048575;n=c[q+6188+(o>>>11<<2)>>2]|0;if((n|0)==0){r=gj[c[q+8236>>2]&4095](o)|0}else{r=a[n+o|0]|0}o=(r&255)<<8|g;r=d+100|0;n=a[r]|0;if(n<<24>>24==0){s=(e[d+26>>1]|0)<<4}else{s=c[d+96>>2]|0}q=s+o&1048575;s=c[3531864]|0;p=c[s+44+(q>>>11<<2)>>2]|0;if((p|0)==0){f=gj[c[s+8236>>2]&4095](q)|0;t=f;u=a[r]|0}else{t=a[p+q|0]|0;u=n}n=t&255;if(u<<24>>24==0){v=(e[d+26>>1]|0)<<4}else{v=c[d+96>>2]|0}u=o+1+v&1048575;v=c[3531864]|0;o=c[v+44+(u>>>11<<2)>>2]|0;if((o|0)==0){w=gj[c[v+8236>>2]&4095](u)|0;x=w&255;y=x<<8;z=y|n;A=d|0;b[A>>1]=z;B=g&1;C=(B|0)!=0;D=d+92|0;E=c[D>>2]|0;F=C?921095:920069;G=F>>>(E>>>0);H=G&127;I=d+84|0;J=c[I>>2]|0;K=J-H|0;c[I>>2]=K;return}else{w=a[o+u|0]|0;x=w&255;y=x<<8;z=y|n;A=d|0;b[A>>1]=z;B=g&1;C=(B|0)!=0;D=d+92|0;E=c[D>>2]|0;F=C?921095:920069;G=F>>>(E>>>0);H=G&127;I=d+84|0;J=c[I>>2]|0;K=J-H|0;c[I>>2]=K;return}}function f7N(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;f=d+22|0;g=e[f>>1]<<4;h=c[2385310]|0;i=h+28|0;j=b[i>>1]|0;k=j+1&65535;b[i>>1]=k;i=(j&65535)+g&1048575;g=c[3531864]|0;j=c[g+6188+(i>>>11<<2)>>2]|0;if((j|0)==0){l=gj[c[g+8236>>2]&4095](i)|0;m=c[2385310]|0;n=l;o=m;p=b[m+28>>1]|0;q=c[3531864]|0}else{n=a[j+i|0]|0;o=h;p=k;q=g}g=e[f>>1]<<4;b[o+28>>1]=p+1&65535;o=(p&65535)+g&1048575;g=c[q+6188+(o>>>11<<2)>>2]|0;if((g|0)==0){r=gj[c[q+8236>>2]&4095](o)|0}else{r=a[g+o|0]|0}if((a[d+100|0]|0)==0){s=e[d+26>>1]<<4}else{s=c[d+96>>2]|0}o=a[d]|0;g=s+((r&255)<<8|n&255)&1048575;n=c[3531864]|0;r=c[n+2092+(g>>>11<<2)>>2]|0;if((r|0)==0){gg[c[n+8240>>2]&4095](g,o);t=d+92|0;u=c[t>>2]|0;v=592131>>>(u>>>0);w=v&127;x=d+84|0;y=c[x>>2]|0;z=y-w|0;c[x>>2]=z;return}else{a[r+g|0]=o;t=d+92|0;u=c[t>>2]|0;v=592131>>>(u>>>0);w=v&127;x=d+84|0;y=c[x>>2]|0;z=y-w|0;c[x>>2]=z;return}}function f7O(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;f=d+22|0;g=e[f>>1]<<4;h=c[2385310]|0;i=h+28|0;j=b[i>>1]|0;k=j+1&65535;b[i>>1]=k;i=(j&65535)+g&1048575;g=c[3531864]|0;j=c[g+6188+(i>>>11<<2)>>2]|0;if((j|0)==0){l=gj[c[g+8236>>2]&4095](i)|0;m=c[2385310]|0;n=l;o=m;p=b[m+28>>1]|0;q=c[3531864]|0}else{n=a[j+i|0]|0;o=h;p=k;q=g}g=n&255;n=e[f>>1]<<4;b[o+28>>1]=p+1&65535;o=(p&65535)+n&1048575;n=c[q+6188+(o>>>11<<2)>>2]|0;if((n|0)==0){r=gj[c[q+8236>>2]&4095](o)|0}else{r=a[n+o|0]|0}if((a[d+100|0]|0)==0){s=e[d+26>>1]<<4}else{s=c[d+96>>2]|0}o=s+((r&255)<<8|g)|0;r=b[d>>1]|0;s=r&255;n=o&1048575;q=c[3531864]|0;p=c[q+2092+(n>>>11<<2)>>2]|0;if((p|0)==0){gg[c[q+8240>>2]&4095](n,s);t=c[3531864]|0}else{a[p+n|0]=s;t=q}q=(r&65535)>>>8&255;r=o+1&1048575;o=c[t+2092+(r>>>11<<2)>>2]|0;if((o|0)==0){gg[c[t+8240>>2]&4095](r,q);u=g&1;v=(u|0)!=0;w=d+92|0;x=c[w>>2]|0;y=v?855301:854275;z=y>>>(x>>>0);A=z&127;B=d+84|0;C=c[B>>2]|0;D=C-A|0;c[B>>2]=D;return}else{a[o+r|0]=q;u=g&1;v=(u|0)!=0;w=d+92|0;x=c[w>>2]|0;y=v?855301:854275;z=y>>>(x>>>0);A=z&127;B=d+84|0;C=c[B>>2]|0;D=C-A|0;c[B>>2]=D;return}}function f7P(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((a[f+100|0]|0)==0){g=e[f+26>>1]<<4}else{g=c[f+96>>2]|0}h=f+12|0;i=(e[h>>1]|0)+g&1048575;g=c[3531864]|0;j=c[g+44+(i>>>11<<2)>>2]|0;if((j|0)==0){k=gj[c[g+8236>>2]&4095](i)|0;l=k;m=c[3531864]|0}else{l=a[j+i|0]|0;m=g}g=f+14|0;i=(e[f+20>>1]<<4)+(e[g>>1]|0)&1048575;j=c[m+2092+(i>>>11<<2)>>2]|0;if((j|0)==0){gg[c[m+8240>>2]&4095](i,l)}else{a[j+i|0]=l}l=(d[f+58|0]|0)*-2&65535|1;b[g>>1]=l+(b[g>>1]|0)&65535;b[h>>1]=l+(b[h>>1]|0)&65535;h=f+84|0;c[h>>2]=(c[h>>2]|0)-(526342>>>((c[f+92>>2]|0)>>>0)&127);return}function f7Q(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;f=d+100|0;g=a[f]|0;if(g<<24>>24==0){h=(e[d+26>>1]|0)<<4}else{h=c[d+96>>2]|0}i=d+12|0;j=(e[i>>1]|0)+h&1048575;h=c[3531864]|0;k=c[h+44+(j>>>11<<2)>>2]|0;if((k|0)==0){l=gj[c[h+8236>>2]&4095](j)|0;m=l;n=a[f]|0}else{m=a[k+j|0]|0;n=g}if(n<<24>>24==0){o=(e[d+26>>1]|0)<<4}else{o=c[d+96>>2]|0}n=o+1+(e[i>>1]|0)&1048575;o=c[3531864]|0;g=c[o+44+(n>>>11<<2)>>2]|0;if((g|0)==0){j=gj[c[o+8236>>2]&4095](n)|0;p=j;q=c[3531864]|0}else{p=a[g+n|0]|0;q=o}o=d+14|0;n=((e[d+20>>1]|0)<<4)+(e[o>>1]|0)|0;g=n&1048575;j=c[q+2092+(g>>>11<<2)>>2]|0;if((j|0)==0){gg[c[q+8240>>2]&4095](g,m);r=c[3531864]|0}else{a[j+g|0]=m;r=q}q=n+1&1048575;n=c[r+2092+(q>>>11<<2)>>2]|0;if((n|0)==0){gg[c[r+8240>>2]&4095](q,p);s=d+58|0;t=a[s]|0;u=t&255;v=u*-4&65535;w=v|2;x=b[o>>1]|0;y=w+x&65535;b[o>>1]=y;z=b[i>>1]|0;A=w+z&65535;b[i>>1]=A;B=d+92|0;C=c[B>>2]|0;D=1052682>>>(C>>>0);E=D&127;F=d+84|0;G=c[F>>2]|0;H=G-E|0;c[F>>2]=H;return}else{a[n+q|0]=p;s=d+58|0;t=a[s]|0;u=t&255;v=u*-4&65535;w=v|2;x=b[o>>1]|0;y=w+x&65535;b[o>>1]=y;z=b[i>>1]|0;A=w+z&65535;b[i>>1]=A;B=d+92|0;C=c[B>>2]|0;D=1052682>>>(C>>>0);E=D&127;F=d+84|0;G=c[F>>2]|0;H=G-E|0;c[F>>2]=H;return}}function f7R(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=f+14|0;h=(e[f+20>>1]<<4)+(e[g>>1]|0)&1048575;i=c[3531864]|0;j=c[i+44+(h>>>11<<2)>>2]|0;if((j|0)==0){k=gj[c[i+8236>>2]&4095](h)|0}else{k=a[j+h|0]|0}if((a[f+100|0]|0)==0){l=e[f+26>>1]<<4}else{l=c[f+96>>2]|0}h=f+12|0;j=b[h>>1]|0;i=(j&65535)+l&1048575;l=c[3531864]|0;m=c[l+44+(i>>>11<<2)>>2]|0;if((m|0)==0){n=gj[c[l+8236>>2]&4095](i)|0;o=n;p=b[h>>1]|0}else{o=a[m+i|0]|0;p=j}j=o&255;i=j-(k&255)|0;c[f+48>>2]=i&256;m=(o^k)&255;c[f+40>>2]=m&128&(i^j);c[f+36>>2]=(i^m)&16;m=i<<24>>24;c[f+52>>2]=m;c[f+44>>2]=m;c[f+32>>2]=m;m=(d[f+58|0]|0)*-2&65535|1;b[g>>1]=m+(b[g>>1]|0)&65535;b[h>>1]=m+p&65535;p=f+84|0;c[p>>2]=(c[p>>2]|0)-(921102>>>((c[f+92>>2]|0)>>>0)&127);return}function f7S(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;g=f+100|0;h=f+20|0;i=b[h>>1]|0;j=f+14|0;k=b[j>>1]|0;l=((i&65535)<<4)+(k&65535)&1048575;m=c[3531864]|0;n=c[m+44+(l>>>11<<2)>>2]|0;if((n|0)==0){o=gj[c[m+8236>>2]&4095](l)|0;p=o;q=b[h>>1]|0;r=b[j>>1]|0;s=c[3531864]|0}else{p=a[n+l|0]|0;q=i;r=k;s=m}m=(r&65535)+1+((q&65535)<<4)&1048575;q=c[s+44+(m>>>11<<2)>>2]|0;if((q|0)==0){t=gj[c[s+8236>>2]&4095](m)|0}else{t=a[q+m|0]|0}m=(t&255)<<8|p&255;p=a[g]|0;if(p<<24>>24==0){u=(e[f+26>>1]|0)<<4}else{u=c[f+96>>2]|0}t=f+12|0;q=(e[t>>1]|0)+u&1048575;u=c[3531864]|0;s=c[u+44+(q>>>11<<2)>>2]|0;if((s|0)==0){r=gj[c[u+8236>>2]&4095](q)|0;v=r;w=a[g]|0}else{v=a[s+q|0]|0;w=p}if(w<<24>>24==0){x=(e[f+26>>1]|0)<<4}else{x=c[f+96>>2]|0}w=b[t>>1]|0;p=x+1+(w&65535)&1048575;x=c[3531864]|0;q=c[x+44+(p>>>11<<2)>>2]|0;if((q|0)==0){s=gj[c[x+8236>>2]&4095](p)|0;y=s;z=b[t>>1]|0}else{y=a[q+p|0]|0;z=w}w=(y&255)<<8;y=w|v&255;v=y-m|0;c[f+48>>2]=v&65536;p=y^m;c[f+40>>2]=p&32768&(v^w);c[f+36>>2]=(v^p)&16;p=v<<16>>16;c[f+52>>2]=p;c[f+44>>2]=p;c[f+32>>2]=p;p=(d[f+58|0]|0)*-4&65535|2;b[j>>1]=p+(b[j>>1]|0)&65535;b[t>>1]=p+z&65535;z=f+84|0;c[z>>2]=(c[z>>2]|0)-(921102>>>((c[f+92>>2]|0)>>>0)&127);return}function f7T(d){d=d|0;var f=0,g=0,h=0,i=0;f=(e[d+22>>1]|0)<<4;g=(c[2385310]|0)+28|0;h=b[g>>1]|0;b[g>>1]=h+1&65535;g=(h&65535)+f&1048575;f=c[3531864]|0;h=c[f+6188+(g>>>11<<2)>>2]|0;if((h|0)==0){i=gj[c[f+8236>>2]&4095](g)|0}else{i=a[h+g|0]|0}g=a[d]&i;c[d+36>>2]=0;c[d+40>>2]=0;c[d+48>>2]=0;i=g<<24>>24;c[d+52>>2]=i;c[d+44>>2]=i;c[d+32>>2]=i;i=d+84|0;c[i>>2]=(c[i>>2]|0)-(263170>>>((c[d+92>>2]|0)>>>0)&127);return}function f7U(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=d+22|0;g=(e[f>>1]|0)<<4;h=c[2385310]|0;i=h+28|0;j=b[i>>1]|0;k=j+1&65535;b[i>>1]=k;i=(j&65535)+g&1048575;g=c[3531864]|0;j=c[g+6188+(i>>>11<<2)>>2]|0;if((j|0)==0){l=gj[c[g+8236>>2]&4095](i)|0;m=c[2385310]|0;n=l;o=m;p=b[m+28>>1]|0;q=c[3531864]|0}else{n=a[j+i|0]|0;o=h;p=k;q=g}g=b[d>>1]|0;k=(e[f>>1]|0)<<4;b[o+28>>1]=p+1&65535;o=(p&65535)+k&1048575;k=c[q+6188+(o>>>11<<2)>>2]|0;if((k|0)==0){r=gj[c[q+8236>>2]&4095](o)|0}else{r=a[k+o|0]|0}c[d+36>>2]=0;c[d+40>>2]=0;c[d+48>>2]=0;o=(((r&255)<<8|n&255)&g)<<16>>16;c[d+52>>2]=o;c[d+44>>2]=o;c[d+32>>2]=o;o=d+84|0;c[o>>2]=(c[o>>2]|0)-(263170>>>((c[d+92>>2]|0)>>>0)&127);return}function f7V(f){f=f|0;var g=0,h=0,i=0,j=0,k=0;g=f+14|0;h=a[f]|0;i=((e[f+20>>1]|0)<<4)+(e[g>>1]|0)&1048575;j=c[3531864]|0;k=c[j+2092+(i>>>11<<2)>>2]|0;if((k|0)==0){gg[c[j+8240>>2]&4095](i,h)}else{a[k+i|0]=h}b[g>>1]=((d[f+58|0]|0)*-2&65535|1)+(b[g>>1]|0)&65535;g=f+84|0;c[g>>2]=(c[g>>2]|0)-(263171>>>((c[f+92>>2]|0)>>>0)&127);return}function f7W(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=f+14|0;h=((e[f+20>>1]|0)<<4)+(e[g>>1]|0)|0;i=b[f>>1]|0;j=i&255;k=h&1048575;l=c[3531864]|0;m=c[l+2092+(k>>>11<<2)>>2]|0;if((m|0)==0){gg[c[l+8240>>2]&4095](k,j);n=c[3531864]|0}else{a[m+k|0]=j;n=l}l=(i&65535)>>>8&255;i=h+1&1048575;h=c[n+2092+(i>>>11<<2)>>2]|0;if((h|0)==0){gg[c[n+8240>>2]&4095](i,l)}else{a[h+i|0]=l}l=(d[f+58|0]|0)*-4&65535;i=b[g>>1]|0;b[g>>1]=(l|2)+i&65535;g=f+84|0;c[g>>2]=(c[g>>2]|0)-(((l+i&1)!=0?526341:525315)>>>((c[f+92>>2]|0)>>>0)&127);return}function f7X(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((a[f+100|0]|0)==0){g=e[f+26>>1]<<4}else{g=c[f+96>>2]|0}h=f+12|0;i=b[h>>1]|0;j=(i&65535)+g&1048575;g=c[3531864]|0;k=c[g+44+(j>>>11<<2)>>2]|0;if((k|0)==0){l=gj[c[g+8236>>2]&4095](j)|0;m=l;n=b[h>>1]|0}else{m=a[k+j|0]|0;n=i}a[f]=m;b[h>>1]=((d[f+58|0]|0)*-2&65535|1)+n&65535;n=f+84|0;c[n>>2]=(c[n>>2]|0)-(263171>>>((c[f+92>>2]|0)>>>0)&127);return}function f7Y(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=f+100|0;h=a[g]|0;if(h<<24>>24==0){i=(e[f+26>>1]|0)<<4}else{i=c[f+96>>2]|0}j=f+12|0;k=(e[j>>1]|0)+i&1048575;i=c[3531864]|0;l=c[i+44+(k>>>11<<2)>>2]|0;if((l|0)==0){m=gj[c[i+8236>>2]&4095](k)|0;n=m;o=a[g]|0}else{n=a[l+k|0]|0;o=h}if(o<<24>>24==0){p=(e[f+26>>1]|0)<<4}else{p=c[f+96>>2]|0}o=b[j>>1]|0;h=p+1+(o&65535)&1048575;p=c[3531864]|0;k=c[p+44+(h>>>11<<2)>>2]|0;if((k|0)==0){l=gj[c[p+8236>>2]&4095](h)|0;q=l;r=b[j>>1]|0}else{q=a[k+h|0]|0;r=o}b[f>>1]=(q&255)<<8|n&255;n=(d[f+58|0]|0)*-4&65535;b[j>>1]=(n|2)+r&65535;j=f+84|0;c[j>>2]=(c[j>>2]|0)-(((n+r&1)!=0?526341:525315)>>>((c[f+92>>2]|0)>>>0)&127);return}function f7Z(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=f+14|0;h=b[g>>1]|0;i=((e[f+20>>1]|0)<<4)+(h&65535)&1048575;j=c[3531864]|0;k=c[j+44+(i>>>11<<2)>>2]|0;if((k|0)==0){l=gj[c[j+8236>>2]&4095](i)|0;m=l;n=b[g>>1]|0}else{m=a[k+i|0]|0;n=h}h=a[f]|0;i=h&255;k=i-(m&255)|0;c[f+48>>2]=k&256;l=(h^m)&255;c[f+40>>2]=l&128&(k^i);c[f+36>>2]=(k^l)&16;l=k<<24>>24;c[f+52>>2]=l;c[f+44>>2]=l;c[f+32>>2]=l;b[g>>1]=((d[f+58|0]|0)*-2&65535|1)+n&65535;n=f+84|0;c[n>>2]=(c[n>>2]|0)-(263171>>>((c[f+92>>2]|0)>>>0)&127);return}function f7_(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=f+20|0;h=b[g>>1]|0;i=f+14|0;j=b[i>>1]|0;k=((h&65535)<<4)+(j&65535)&1048575;l=c[3531864]|0;m=c[l+44+(k>>>11<<2)>>2]|0;if((m|0)==0){n=gj[c[l+8236>>2]&4095](k)|0;o=n;p=b[g>>1]|0;q=b[i>>1]|0;r=c[3531864]|0}else{o=a[m+k|0]|0;p=h;q=j;r=l}l=(q&65535)+1+((p&65535)<<4)&1048575;p=c[r+44+(l>>>11<<2)>>2]|0;if((p|0)==0){j=gj[c[r+8236>>2]&4095](l)|0;s=j;t=b[i>>1]|0}else{s=a[p+l|0]|0;t=q}q=(s&255)<<8|o&255;o=e[f>>1]|0;s=o-q|0;c[f+48>>2]=s&65536;l=q^o;c[f+40>>2]=l&32768&(s^o);c[f+36>>2]=(s^l)&16;l=s<<16>>16;c[f+52>>2]=l;c[f+44>>2]=l;c[f+32>>2]=l;l=(d[f+58|0]|0)*-4&65535;b[i>>1]=(l|2)+t&65535;i=f+84|0;c[i>>2]=(c[i>>2]|0)-(((l+t&1)!=0?526341:525315)>>>((c[f+92>>2]|0)>>>0)&127);return}function f7$(d){d=d|0;var f=0,g=0,h=0,i=0;f=(e[d+22>>1]|0)<<4;g=(c[2385310]|0)+28|0;h=b[g>>1]|0;b[g>>1]=h+1&65535;g=(h&65535)+f&1048575;f=c[3531864]|0;h=c[f+6188+(g>>>11<<2)>>2]|0;if((h|0)==0){i=gj[c[f+8236>>2]&4095](g)|0}else{i=a[h+g|0]|0}a[d]=i;i=d+84|0;c[i>>2]=(c[i>>2]|0)-(263170>>>((c[d+92>>2]|0)>>>0)&127);return}function f70(d){d=d|0;var f=0,g=0,h=0,i=0;f=(e[d+22>>1]|0)<<4;g=(c[2385310]|0)+28|0;h=b[g>>1]|0;b[g>>1]=h+1&65535;g=(h&65535)+f&1048575;f=c[3531864]|0;h=c[f+6188+(g>>>11<<2)>>2]|0;if((h|0)==0){i=gj[c[f+8236>>2]&4095](g)|0}else{i=a[h+g|0]|0}a[d+2|0]=i;i=d+84|0;c[i>>2]=(c[i>>2]|0)-(263170>>>((c[d+92>>2]|0)>>>0)&127);return}function f71(d){d=d|0;var f=0,g=0,h=0,i=0;f=(e[d+22>>1]|0)<<4;g=(c[2385310]|0)+28|0;h=b[g>>1]|0;b[g>>1]=h+1&65535;g=(h&65535)+f&1048575;f=c[3531864]|0;h=c[f+6188+(g>>>11<<2)>>2]|0;if((h|0)==0){i=gj[c[f+8236>>2]&4095](g)|0}else{i=a[h+g|0]|0}a[d+4|0]=i;i=d+84|0;c[i>>2]=(c[i>>2]|0)-(263170>>>((c[d+92>>2]|0)>>>0)&127);return}function f72(d){d=d|0;var f=0,g=0,h=0,i=0;f=(e[d+22>>1]|0)<<4;g=(c[2385310]|0)+28|0;h=b[g>>1]|0;b[g>>1]=h+1&65535;g=(h&65535)+f&1048575;f=c[3531864]|0;h=c[f+6188+(g>>>11<<2)>>2]|0;if((h|0)==0){i=gj[c[f+8236>>2]&4095](g)|0}else{i=a[h+g|0]|0}a[d+6|0]=i;i=d+84|0;c[i>>2]=(c[i>>2]|0)-(263170>>>((c[d+92>>2]|0)>>>0)&127);return}function f73(d){d=d|0;var f=0,g=0,h=0,i=0;f=(e[d+22>>1]|0)<<4;g=(c[2385310]|0)+28|0;h=b[g>>1]|0;b[g>>1]=h+1&65535;g=(h&65535)+f&1048575;f=c[3531864]|0;h=c[f+6188+(g>>>11<<2)>>2]|0;if((h|0)==0){i=gj[c[f+8236>>2]&4095](g)|0}else{i=a[h+g|0]|0}a[d+1|0]=i;i=d+84|0;c[i>>2]=(c[i>>2]|0)-(263170>>>((c[d+92>>2]|0)>>>0)&127);return}function f74(d){d=d|0;var f=0,g=0,h=0,i=0;f=(e[d+22>>1]|0)<<4;g=(c[2385310]|0)+28|0;h=b[g>>1]|0;b[g>>1]=h+1&65535;g=(h&65535)+f&1048575;f=c[3531864]|0;h=c[f+6188+(g>>>11<<2)>>2]|0;if((h|0)==0){i=gj[c[f+8236>>2]&4095](g)|0}else{i=a[h+g|0]|0}a[d+3|0]=i;i=d+84|0;c[i>>2]=(c[i>>2]|0)-(263170>>>((c[d+92>>2]|0)>>>0)&127);return}function f75(d){d=d|0;var f=0,g=0,h=0,i=0;f=(e[d+22>>1]|0)<<4;g=(c[2385310]|0)+28|0;h=b[g>>1]|0;b[g>>1]=h+1&65535;g=(h&65535)+f&1048575;f=c[3531864]|0;h=c[f+6188+(g>>>11<<2)>>2]|0;if((h|0)==0){i=gj[c[f+8236>>2]&4095](g)|0}else{i=a[h+g|0]|0}a[d+5|0]=i;i=d+84|0;c[i>>2]=(c[i>>2]|0)-(263170>>>((c[d+92>>2]|0)>>>0)&127);return}function f76(d){d=d|0;var f=0,g=0,h=0,i=0;f=(e[d+22>>1]|0)<<4;g=(c[2385310]|0)+28|0;h=b[g>>1]|0;b[g>>1]=h+1&65535;g=(h&65535)+f&1048575;f=c[3531864]|0;h=c[f+6188+(g>>>11<<2)>>2]|0;if((h|0)==0){i=gj[c[f+8236>>2]&4095](g)|0}else{i=a[h+g|0]|0}a[d+7|0]=i;i=d+84|0;c[i>>2]=(c[i>>2]|0)-(263170>>>((c[d+92>>2]|0)>>>0)&127);return}function f77(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=d+22|0;g=(e[f>>1]|0)<<4;h=c[2385310]|0;i=h+28|0;j=b[i>>1]|0;b[i>>1]=j+1&65535;i=(j&65535)+g&1048575;g=c[3531864]|0;j=c[g+6188+(i>>>11<<2)>>2]|0;if((j|0)==0){k=gj[c[g+8236>>2]&4095](i)|0;l=k;m=c[2385310]|0;n=c[3531864]|0}else{l=a[j+i|0]|0;m=h;n=g}g=d;a[d]=l;l=(e[f>>1]|0)<<4;f=m+28|0;m=b[f>>1]|0;b[f>>1]=m+1&65535;f=(m&65535)+l&1048575;l=c[n+6188+(f>>>11<<2)>>2]|0;if((l|0)==0){o=gj[c[n+8236>>2]&4095](f)|0;p=g+1|0;a[p]=o;q=d+92|0;r=c[q>>2]|0;s=263170>>>(r>>>0);t=s&127;u=d+84|0;v=c[u>>2]|0;w=v-t|0;c[u>>2]=w;return}else{o=a[l+f|0]|0;p=g+1|0;a[p]=o;q=d+92|0;r=c[q>>2]|0;s=263170>>>(r>>>0);t=s&127;u=d+84|0;v=c[u>>2]|0;w=v-t|0;c[u>>2]=w;return}}function f78(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=d+22|0;g=(e[f>>1]|0)<<4;h=c[2385310]|0;i=h+28|0;j=b[i>>1]|0;b[i>>1]=j+1&65535;i=(j&65535)+g&1048575;g=c[3531864]|0;j=c[g+6188+(i>>>11<<2)>>2]|0;if((j|0)==0){k=gj[c[g+8236>>2]&4095](i)|0;l=k;m=c[2385310]|0;n=c[3531864]|0}else{l=a[j+i|0]|0;m=h;n=g}g=d;a[d+2|0]=l;l=(e[f>>1]|0)<<4;f=m+28|0;m=b[f>>1]|0;b[f>>1]=m+1&65535;f=(m&65535)+l&1048575;l=c[n+6188+(f>>>11<<2)>>2]|0;if((l|0)==0){o=gj[c[n+8236>>2]&4095](f)|0;p=g+3|0;a[p]=o;q=d+92|0;r=c[q>>2]|0;s=263170>>>(r>>>0);t=s&127;u=d+84|0;v=c[u>>2]|0;w=v-t|0;c[u>>2]=w;return}else{o=a[l+f|0]|0;p=g+3|0;a[p]=o;q=d+92|0;r=c[q>>2]|0;s=263170>>>(r>>>0);t=s&127;u=d+84|0;v=c[u>>2]|0;w=v-t|0;c[u>>2]=w;return}}function f79(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=d+22|0;g=(e[f>>1]|0)<<4;h=c[2385310]|0;i=h+28|0;j=b[i>>1]|0;b[i>>1]=j+1&65535;i=(j&65535)+g&1048575;g=c[3531864]|0;j=c[g+6188+(i>>>11<<2)>>2]|0;if((j|0)==0){k=gj[c[g+8236>>2]&4095](i)|0;l=k;m=c[2385310]|0;n=c[3531864]|0}else{l=a[j+i|0]|0;m=h;n=g}g=d;a[d+4|0]=l;l=(e[f>>1]|0)<<4;f=m+28|0;m=b[f>>1]|0;b[f>>1]=m+1&65535;f=(m&65535)+l&1048575;l=c[n+6188+(f>>>11<<2)>>2]|0;if((l|0)==0){o=gj[c[n+8236>>2]&4095](f)|0;p=g+5|0;a[p]=o;q=d+92|0;r=c[q>>2]|0;s=263170>>>(r>>>0);t=s&127;u=d+84|0;v=c[u>>2]|0;w=v-t|0;c[u>>2]=w;return}else{o=a[l+f|0]|0;p=g+5|0;a[p]=o;q=d+92|0;r=c[q>>2]|0;s=263170>>>(r>>>0);t=s&127;u=d+84|0;v=c[u>>2]|0;w=v-t|0;c[u>>2]=w;return}}function f8a(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=d+22|0;g=(e[f>>1]|0)<<4;h=c[2385310]|0;i=h+28|0;j=b[i>>1]|0;b[i>>1]=j+1&65535;i=(j&65535)+g&1048575;g=c[3531864]|0;j=c[g+6188+(i>>>11<<2)>>2]|0;if((j|0)==0){k=gj[c[g+8236>>2]&4095](i)|0;l=k;m=c[2385310]|0;n=c[3531864]|0}else{l=a[j+i|0]|0;m=h;n=g}g=d;a[d+6|0]=l;l=(e[f>>1]|0)<<4;f=m+28|0;m=b[f>>1]|0;b[f>>1]=m+1&65535;f=(m&65535)+l&1048575;l=c[n+6188+(f>>>11<<2)>>2]|0;if((l|0)==0){o=gj[c[n+8236>>2]&4095](f)|0;p=g+7|0;a[p]=o;q=d+92|0;r=c[q>>2]|0;s=263170>>>(r>>>0);t=s&127;u=d+84|0;v=c[u>>2]|0;w=v-t|0;c[u>>2]=w;return}else{o=a[l+f|0]|0;p=g+7|0;a[p]=o;q=d+92|0;r=c[q>>2]|0;s=263170>>>(r>>>0);t=s&127;u=d+84|0;v=c[u>>2]|0;w=v-t|0;c[u>>2]=w;return}}function f8b(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=d+22|0;g=(e[f>>1]|0)<<4;h=c[2385310]|0;i=h+28|0;j=b[i>>1]|0;k=j+1&65535;b[i>>1]=k;i=(j&65535)+g&1048575;g=c[3531864]|0;j=c[g+6188+(i>>>11<<2)>>2]|0;if((j|0)==0){l=gj[c[g+8236>>2]&4095](i)|0;m=c[2385310]|0;n=l;o=m;p=b[m+28>>1]|0;q=c[3531864]|0}else{n=a[j+i|0]|0;o=h;p=k;q=g}g=(e[f>>1]|0)<<4;b[o+28>>1]=p+1&65535;o=(p&65535)+g&1048575;g=c[q+6188+(o>>>11<<2)>>2]|0;if((g|0)==0){r=gj[c[q+8236>>2]&4095](o)|0}else{r=a[g+o|0]|0}b[d+8>>1]=(r&255)<<8|n&255;n=d+84|0;c[n>>2]=(c[n>>2]|0)-(263170>>>((c[d+92>>2]|0)>>>0)&127);return}function f8c(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=d+22|0;g=(e[f>>1]|0)<<4;h=c[2385310]|0;i=h+28|0;j=b[i>>1]|0;k=j+1&65535;b[i>>1]=k;i=(j&65535)+g&1048575;g=c[3531864]|0;j=c[g+6188+(i>>>11<<2)>>2]|0;if((j|0)==0){l=gj[c[g+8236>>2]&4095](i)|0;m=c[2385310]|0;n=l;o=m;p=b[m+28>>1]|0;q=c[3531864]|0}else{n=a[j+i|0]|0;o=h;p=k;q=g}g=(e[f>>1]|0)<<4;b[o+28>>1]=p+1&65535;o=(p&65535)+g&1048575;g=c[q+6188+(o>>>11<<2)>>2]|0;if((g|0)==0){r=gj[c[q+8236>>2]&4095](o)|0}else{r=a[g+o|0]|0}b[d+10>>1]=(r&255)<<8|n&255;n=d+84|0;c[n>>2]=(c[n>>2]|0)-(263170>>>((c[d+92>>2]|0)>>>0)&127);return}function f8d(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=d+22|0;g=(e[f>>1]|0)<<4;h=c[2385310]|0;i=h+28|0;j=b[i>>1]|0;k=j+1&65535;b[i>>1]=k;i=(j&65535)+g&1048575;g=c[3531864]|0;j=c[g+6188+(i>>>11<<2)>>2]|0;if((j|0)==0){l=gj[c[g+8236>>2]&4095](i)|0;m=c[2385310]|0;n=l;o=m;p=b[m+28>>1]|0;q=c[3531864]|0}else{n=a[j+i|0]|0;o=h;p=k;q=g}g=(e[f>>1]|0)<<4;b[o+28>>1]=p+1&65535;o=(p&65535)+g&1048575;g=c[q+6188+(o>>>11<<2)>>2]|0;if((g|0)==0){r=gj[c[q+8236>>2]&4095](o)|0}else{r=a[g+o|0]|0}b[d+12>>1]=(r&255)<<8|n&255;n=d+84|0;c[n>>2]=(c[n>>2]|0)-(263170>>>((c[d+92>>2]|0)>>>0)&127);return}function f8e(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=d+22|0;g=(e[f>>1]|0)<<4;h=c[2385310]|0;i=h+28|0;j=b[i>>1]|0;k=j+1&65535;b[i>>1]=k;i=(j&65535)+g&1048575;g=c[3531864]|0;j=c[g+6188+(i>>>11<<2)>>2]|0;if((j|0)==0){l=gj[c[g+8236>>2]&4095](i)|0;m=c[2385310]|0;n=l;o=m;p=b[m+28>>1]|0;q=c[3531864]|0}else{n=a[j+i|0]|0;o=h;p=k;q=g}g=(e[f>>1]|0)<<4;b[o+28>>1]=p+1&65535;o=(p&65535)+g&1048575;g=c[q+6188+(o>>>11<<2)>>2]|0;if((g|0)==0){r=gj[c[q+8236>>2]&4095](o)|0}else{r=a[g+o|0]|0}b[d+14>>1]=(r&255)<<8|n&255;n=d+84|0;c[n>>2]=(c[n>>2]|0)-(263170>>>((c[d+92>>2]|0)>>>0)&127);return}function f8f(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=d+22|0;g=(e[f>>1]|0)<<4;h=(c[2385310]|0)+28|0;i=b[h>>1]|0;b[h>>1]=i+1&65535;h=(i&65535)+g&1048575;g=c[3531864]|0;i=c[g+6188+(h>>>11<<2)>>2]|0;if((i|0)==0){j=gj[c[g+8236>>2]&4095](h)|0}else{j=a[i+h|0]|0}h=j&255;i=(j&255)>191;do{if(i){k=a[d+(c[9648736+(h<<2)>>2]|0)|0]|0}else{j=(gj[c[679712+(h<<2)>>2]&4095](d)|0)&1048575;g=c[3531864]|0;l=c[g+44+(j>>>11<<2)>>2]|0;if((l|0)==0){k=gj[c[g+8236>>2]&4095](j)|0;break}else{k=a[l+j|0]|0;break}}}while(0);j=k&255;l=(e[f>>1]|0)<<4;f=(c[2385310]|0)+28|0;g=b[f>>1]|0;b[f>>1]=g+1&65535;f=(g&65535)+l&1048575;l=c[3531864]|0;g=c[l+6188+(f>>>11<<2)>>2]|0;if((g|0)==0){m=gj[c[l+8236>>2]&4095](f)|0}else{m=a[g+f|0]|0}f=d+84|0;g=(c[f>>2]|0)-((i?460546:1250054)>>>((c[d+92>>2]|0)>>>0)&127)|0;c[f>>2]=g;if(m<<24>>24==0){return}switch(h&56|0){case 16:{l=d+48|0;n=m-1&255;o=j;p=m;q=c[l>>2]|0;do{r=o<<1;o=r|(q|0)!=0;q=r&256;p=p-1&255;}while(p<<24>>24!=0);c[l>>2]=q;c[f>>2]=g+~(n&255);if(i){a[d+(c[9648736+(h<<2)>>2]|0)|0]=o&255;return}n=o&255;o=c[2426956]&1048575;q=c[3531864]|0;l=c[q+2092+(o>>>11<<2)>>2]|0;if((l|0)==0){gg[c[q+8240>>2]&4095](o,n);return}else{a[l+o|0]=n;return}break};case 24:{n=d+48|0;o=m-1&255;l=j;q=m;p=c[n>>2]|0;do{r=(((p|0)!=0)<<8)+l|0;p=r&1;l=r>>>1;q=q-1&255;}while(q<<24>>24!=0);c[n>>2]=p;c[f>>2]=g+~(o&255);if(i){a[d+(c[9648736+(h<<2)>>2]|0)|0]=l&255;return}o=l&255;l=c[2426956]&1048575;p=c[3531864]|0;n=c[p+2092+(l>>>11<<2)>>2]|0;if((n|0)==0){gg[c[p+8240>>2]&4095](l,o);return}else{a[n+l|0]=o;return}break};case 0:{o=m-1&255;l=j;n=m;do{s=l&128;l=s>>>7|l<<1;n=n-1&255;}while(n<<24>>24!=0);c[d+48>>2]=s;c[f>>2]=g+~(o&255);if(i){a[d+(c[9648736+(h<<2)>>2]|0)|0]=l&255;return}o=l&255;l=c[2426956]&1048575;s=c[3531864]|0;n=c[s+2092+(l>>>11<<2)>>2]|0;if((n|0)==0){gg[c[s+8240>>2]&4095](l,o);return}else{a[n+l|0]=o;return}break};case 8:{o=m-1&255;l=j;n=m;do{t=l&1;l=(t<<7)+(l>>>1)|0;n=n-1&255;}while(n<<24>>24!=0);c[d+48>>2]=t;c[f>>2]=g+~(o&255);if(i){a[d+(c[9648736+(h<<2)>>2]|0)|0]=l&255;return}o=l&255;l=c[2426956]&1048575;t=c[3531864]|0;n=c[t+2092+(l>>>11<<2)>>2]|0;if((n|0)==0){gg[c[t+8240>>2]&4095](l,o);return}else{a[n+l|0]=o;return}break};case 32:{o=m&255;c[f>>2]=g-o;l=j<<o;c[d+48>>2]=l&256;o=l&255;l=o<<24>>24;c[d+52>>2]=l;c[d+44>>2]=l;c[d+32>>2]=l;if(i){a[d+(c[9648736+(h<<2)>>2]|0)|0]=o;return}l=c[2426956]&1048575;n=c[3531864]|0;t=c[n+2092+(l>>>11<<2)>>2]|0;if((t|0)==0){gg[c[n+8240>>2]&4095](l,o);return}else{a[t+l|0]=o;return}break};case 40:{o=m&255;c[f>>2]=g-o;l=j>>>((o-1|0)>>>0);c[d+48>>2]=l&1;o=l>>>1&255;l=o<<24>>24;c[d+52>>2]=l;c[d+44>>2]=l;c[d+32>>2]=l;if(i){a[d+(c[9648736+(h<<2)>>2]|0)|0]=o;return}l=c[2426956]&1048575;j=c[3531864]|0;t=c[j+2092+(l>>>11<<2)>>2]|0;if((t|0)==0){gg[c[j+8240>>2]&4095](l,o);return}else{a[t+l|0]=o;return}break};case 56:{o=m&255;c[f>>2]=g-o;g=k<<24>>24>>o-1;c[d+48>>2]=g&1;o=g>>>1&255;g=o<<24>>24;c[d+52>>2]=g;c[d+44>>2]=g;c[d+32>>2]=g;if(i){a[d+(c[9648736+(h<<2)>>2]|0)|0]=o;return}h=c[2426956]&1048575;d=c[3531864]|0;i=c[d+2092+(h>>>11<<2)>>2]|0;if((i|0)==0){gg[c[d+8240>>2]&4095](h,o);return}else{a[i+h|0]=o;return}break};default:{return}}}function f8g(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;f=d+22|0;g=(e[f>>1]|0)<<4;h=(c[2385310]|0)+28|0;i=b[h>>1]|0;b[h>>1]=i+1&65535;h=(i&65535)+g&1048575;g=c[3531864]|0;i=c[g+6188+(h>>>11<<2)>>2]|0;if((i|0)==0){j=gj[c[g+8236>>2]&4095](h)|0}else{j=a[i+h|0]|0}h=j&255;i=(j&255)>191;if(i){k=e[d+(c[9650784+(h<<2)>>2]<<1)>>1]|0}else{j=c[679712+(h<<2)>>2]|0;gj[j&4095](d)|0;j=c[2426956]|0;g=j&1048575;l=c[3531864]|0;m=c[l+44+(g>>>11<<2)>>2]|0;if((m|0)==0){n=gj[c[l+8236>>2]&4095](g)|0;o=n;p=c[2426956]|0;q=c[3531864]|0}else{o=a[m+g|0]|0;p=j;q=l}l=p+1&1048575;p=c[q+44+(l>>>11<<2)>>2]|0;if((p|0)==0){r=gj[c[q+8236>>2]&4095](l)|0}else{r=a[p+l|0]|0}k=(r&255)<<8|o&255}o=(e[f>>1]|0)<<4;f=(c[2385310]|0)+28|0;r=b[f>>1]|0;b[f>>1]=r+1&65535;f=(r&65535)+o&1048575;o=c[3531864]|0;r=c[o+6188+(f>>>11<<2)>>2]|0;if((r|0)==0){s=gj[c[o+8236>>2]&4095](f)|0}else{s=a[r+f|0]|0}f=d+84|0;r=(c[f>>2]|0)-((i?460546:1774342)>>>((c[d+92>>2]|0)>>>0)&127)|0;c[f>>2]=r;if(s<<24>>24==0){return}switch(h&56|0){case 24:{o=d+48|0;l=s-1&255;p=k;q=s;j=c[o>>2]|0;do{t=(((j|0)!=0)<<16)+p|0;j=t&1;p=t>>>1;q=q-1&255;}while(q<<24>>24!=0);c[o>>2]=j;c[f>>2]=r+~(l&255);if(i){b[d+(c[9650784+(h<<2)>>2]<<1)>>1]=p&65535;return}l=c[2426956]|0;j=p&255;p=l&1048575;o=c[3531864]|0;q=c[o+2092+(p>>>11<<2)>>2]|0;if((q|0)==0){gg[c[o+8240>>2]&4095](p,j);u=c[3531864]|0}else{a[q+p|0]=j;u=o}o=t>>>9&255;t=l+1&1048575;l=c[u+2092+(t>>>11<<2)>>2]|0;if((l|0)==0){gg[c[u+8240>>2]&4095](t,o);return}else{a[l+t|0]=o;return}break};case 16:{o=d+48|0;t=s-1&255;l=k;u=s;j=c[o>>2]|0;while(1){p=l<<1;v=p|(j|0)!=0;w=p&65536;p=u-1&255;if(p<<24>>24==0){break}else{l=v;u=p;j=w}}c[o>>2]=w;c[f>>2]=r+~(t&255);if(i){b[d+(c[9650784+(h<<2)>>2]<<1)>>1]=v&65535;return}t=c[2426956]|0;w=v&255;v=t&1048575;o=c[3531864]|0;j=c[o+2092+(v>>>11<<2)>>2]|0;if((j|0)==0){gg[c[o+8240>>2]&4095](v,w);x=c[3531864]|0}else{a[j+v|0]=w;x=o}o=l>>>7&255;l=t+1&1048575;t=c[x+2092+(l>>>11<<2)>>2]|0;if((t|0)==0){gg[c[x+8240>>2]&4095](l,o);return}else{a[t+l|0]=o;return}break};case 0:{o=s-1&255;l=k;t=s;while(1){y=l&32768;z=y>>>15|l<<1;x=t-1&255;if(x<<24>>24==0){break}else{l=z;t=x}}c[d+48>>2]=y;c[f>>2]=r+~(o&255);if(i){b[d+(c[9650784+(h<<2)>>2]<<1)>>1]=z&65535;return}o=c[2426956]|0;y=z&255;z=o&1048575;t=c[3531864]|0;x=c[t+2092+(z>>>11<<2)>>2]|0;if((x|0)==0){gg[c[t+8240>>2]&4095](z,y);A=c[3531864]|0}else{a[x+z|0]=y;A=t}t=l>>>7&255;l=o+1&1048575;o=c[A+2092+(l>>>11<<2)>>2]|0;if((o|0)==0){gg[c[A+8240>>2]&4095](l,t);return}else{a[o+l|0]=t;return}break};case 8:{t=s-1&255;l=k;o=s;do{B=l&1;l=(B<<15)+(l>>>1)|0;o=o-1&255;}while(o<<24>>24!=0);c[d+48>>2]=B;c[f>>2]=r+~(t&255);if(i){b[d+(c[9650784+(h<<2)>>2]<<1)>>1]=l&65535;return}t=c[2426956]|0;B=l&255;o=t&1048575;A=c[3531864]|0;y=c[A+2092+(o>>>11<<2)>>2]|0;if((y|0)==0){gg[c[A+8240>>2]&4095](o,B);C=c[3531864]|0}else{a[y+o|0]=B;C=A}A=(l&65535)>>>8&255;l=t+1&1048575;t=c[C+2092+(l>>>11<<2)>>2]|0;if((t|0)==0){gg[c[C+8240>>2]&4095](l,A);return}else{a[t+l|0]=A;return}break};case 32:{A=s&255;c[f>>2]=r-A;l=k<<A;c[d+48>>2]=l&65536;A=l&65535;t=A<<16>>16;c[d+52>>2]=t;c[d+44>>2]=t;c[d+32>>2]=t;if(i){b[d+(c[9650784+(h<<2)>>2]<<1)>>1]=A;return}t=c[2426956]|0;C=l&255;l=t&1048575;B=c[3531864]|0;o=c[B+2092+(l>>>11<<2)>>2]|0;if((o|0)==0){gg[c[B+8240>>2]&4095](l,C);D=c[3531864]|0}else{a[o+l|0]=C;D=B}B=(A&65535)>>>8&255;A=t+1&1048575;t=c[D+2092+(A>>>11<<2)>>2]|0;if((t|0)==0){gg[c[D+8240>>2]&4095](A,B);return}else{a[t+A|0]=B;return}break};case 40:{B=s&255;c[f>>2]=r-B;A=k>>>((B-1|0)>>>0);c[d+48>>2]=A&1;B=A>>>1;t=B&65535;D=t<<16>>16;c[d+52>>2]=D;c[d+44>>2]=D;c[d+32>>2]=D;if(i){b[d+(c[9650784+(h<<2)>>2]<<1)>>1]=t;return}t=c[2426956]|0;D=B&255;B=t&1048575;C=c[3531864]|0;l=c[C+2092+(B>>>11<<2)>>2]|0;if((l|0)==0){gg[c[C+8240>>2]&4095](B,D);E=c[3531864]|0}else{a[l+B|0]=D;E=C}C=A>>>9&255;A=t+1&1048575;t=c[E+2092+(A>>>11<<2)>>2]|0;if((t|0)==0){gg[c[E+8240>>2]&4095](A,C);return}else{a[t+A|0]=C;return}break};case 56:{C=s&255;c[f>>2]=r-C;r=k<<16>>16>>C-1;c[d+48>>2]=r&1;C=r>>>1;k=C&65535;f=k<<16>>16;c[d+52>>2]=f;c[d+44>>2]=f;c[d+32>>2]=f;if(i){b[d+(c[9650784+(h<<2)>>2]<<1)>>1]=k;return}k=c[2426956]|0;h=C&255;C=k&1048575;d=c[3531864]|0;i=c[d+2092+(C>>>11<<2)>>2]|0;if((i|0)==0){gg[c[d+8240>>2]&4095](C,h);F=c[3531864]|0}else{a[i+C|0]=h;F=d}d=r>>>9&255;r=k+1&1048575;k=c[F+2092+(r>>>11<<2)>>2]|0;if((k|0)==0){gg[c[F+8240>>2]&4095](r,d);return}else{a[k+r|0]=d;return}break};default:{return}}}function f8h(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;f=d+22|0;g=(e[f>>1]|0)<<4;h=c[2385310]|0;i=h+28|0;j=b[i>>1]|0;k=j+1&65535;b[i>>1]=k;i=(j&65535)+g&1048575;g=c[3531864]|0;j=c[g+6188+(i>>>11<<2)>>2]|0;if((j|0)==0){l=gj[c[g+8236>>2]&4095](i)|0;m=c[2385310]|0;n=l;o=m;p=b[m+28>>1]|0;q=c[3531864]|0}else{n=a[j+i|0]|0;o=h;p=k;q=g}g=(e[f>>1]|0)<<4;b[o+28>>1]=p+1&65535;o=(p&65535)+g&1048575;g=c[q+6188+(o>>>11<<2)>>2]|0;if((g|0)==0){p=gj[c[q+8236>>2]&4095](o)|0;r=p;s=c[3531864]|0}else{r=a[g+o|0]|0;s=q}q=(r&255)<<8|n&255;n=d+8|0;r=(b[n>>1]|0)+2&65535;b[n>>1]=r;o=d+24|0;g=b[o>>1]|0;p=((r&65535)+65534&65535)+((g&65535)<<4)&1048575;f=c[s+44+(p>>>11<<2)>>2]|0;if((f|0)==0){k=gj[c[s+8236>>2]&4095](p)|0;t=k;u=b[o>>1]|0;v=b[n>>1]|0;w=c[3531864]|0}else{t=a[f+p|0]|0;u=g;v=r;w=s}s=t&255;t=((v&65535)+65534&65535)+((u&65535)<<4|1)&1048575;u=c[w+44+(t>>>11<<2)>>2]|0;if((u|0)==0){r=gj[c[w+8236>>2]&4095](t)|0;x=r;y=b[n>>1]|0;z=x&255;A=z<<8;B=A|s;C=d+28|0;b[C>>1]=B;D=y+q&65535;b[n>>1]=D;E=d+91|0;a[E]=1;F=d+92|0;G=c[F>>2]|0;H=1579018>>>(G>>>0);I=H&127;J=d+84|0;K=c[J>>2]|0;L=K-I|0;c[J>>2]=L;return}else{x=a[u+t|0]|0;y=v;z=x&255;A=z<<8;B=A|s;C=d+28|0;b[C>>1]=B;D=y+q&65535;b[n>>1]=D;E=d+91|0;a[E]=1;F=d+92|0;G=c[F>>2]|0;H=1579018>>>(G>>>0);I=H&127;J=d+84|0;K=c[J>>2]|0;L=K-I|0;c[J>>2]=L;return}}function f8i(d){d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=d+8|0;f=(b[e>>1]|0)+2&65535;b[e>>1]=f;g=d+24|0;h=b[g>>1]|0;i=((f&65535)+65534&65535)+((h&65535)<<4)&1048575;j=c[3531864]|0;k=c[j+44+(i>>>11<<2)>>2]|0;if((k|0)==0){l=gj[c[j+8236>>2]&4095](i)|0;m=l;n=b[g>>1]|0;o=b[e>>1]|0;p=c[3531864]|0}else{m=a[k+i|0]|0;n=h;o=f;p=j}j=((o&65535)+65534&65535)+((n&65535)<<4|1)&1048575;n=c[p+44+(j>>>11<<2)>>2]|0;if((n|0)==0){q=gj[c[p+8236>>2]&4095](j)|0}else{q=a[n+j|0]|0}b[d+28>>1]=(q&255)<<8|m&255;a[d+91|0]=1;m=d+84|0;c[m>>2]=(c[m>>2]|0)-(1250058>>>((c[d+92>>2]|0)>>>0)&127);return}function f8j(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;f=(e[d+22>>1]|0)<<4;g=(c[2385310]|0)+28|0;h=b[g>>1]|0;b[g>>1]=h+1&65535;g=(h&65535)+f&1048575;f=c[3531864]|0;h=c[f+6188+(g>>>11<<2)>>2]|0;if((h|0)==0){i=gj[c[f+8236>>2]&4095](g)|0}else{i=a[h+g|0]|0}g=i&255;if((i&255)>191){j=b[d+(c[9650784+(g<<2)>>2]<<1)>>1]|0}else{i=c[679712+(g<<2)>>2]|0;gj[i&4095](d)|0;i=c[2426956]|0;h=i&1048575;f=c[3531864]|0;k=c[f+44+(h>>>11<<2)>>2]|0;if((k|0)==0){l=gj[c[f+8236>>2]&4095](h)|0;m=l;n=c[2426956]|0;o=c[3531864]|0}else{m=a[k+h|0]|0;n=i;o=f}f=n+1&1048575;n=c[o+44+(f>>>11<<2)>>2]|0;if((n|0)==0){p=gj[c[o+8236>>2]&4095](f)|0}else{p=a[n+f|0]|0}j=(p&255)<<8|m&255}b[d+(c[9654880+(g<<2)>>2]<<1)>>1]=j;j=c[2426956]|0;g=j+2&65535|j&983040;m=c[3531864]|0;p=c[m+44+(g>>>11<<2)>>2]|0;if((p|0)==0){f=gj[c[m+8236>>2]&4095](g)|0;q=f;r=c[2426956]|0;s=c[3531864]|0}else{q=a[p+g|0]|0;r=j;s=m}m=q&255;q=(r+2&65535|r&983040)+1&1048575;j=c[s+44+(q>>>11<<2)>>2]|0;if((j|0)==0){g=gj[c[s+8236>>2]&4095](q)|0;t=g;u=c[2426956]|0;v=t&255;w=v<<8;x=w|m;y=d+20|0;b[y>>1]=x;z=u&1;A=(z|0)!=0;B=d+92|0;C=c[B>>2]|0;D=A?1710606:1708554;E=D>>>(C>>>0);F=E&127;G=d+84|0;H=c[G>>2]|0;I=H-F|0;c[G>>2]=I;return}else{t=a[j+q|0]|0;u=r;v=t&255;w=v<<8;x=w|m;y=d+20|0;b[y>>1]=x;z=u&1;A=(z|0)!=0;B=d+92|0;C=c[B>>2]|0;D=A?1710606:1708554;E=D>>>(C>>>0);F=E&127;G=d+84|0;H=c[G>>2]|0;I=H-F|0;c[G>>2]=I;return}}function f8k(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;f=(e[d+22>>1]|0)<<4;g=(c[2385310]|0)+28|0;h=b[g>>1]|0;b[g>>1]=h+1&65535;g=(h&65535)+f&1048575;f=c[3531864]|0;h=c[f+6188+(g>>>11<<2)>>2]|0;if((h|0)==0){i=gj[c[f+8236>>2]&4095](g)|0}else{i=a[h+g|0]|0}g=i&255;if((i&255)>191){j=b[d+(c[9650784+(g<<2)>>2]<<1)>>1]|0}else{i=c[679712+(g<<2)>>2]|0;gj[i&4095](d)|0;i=c[2426956]|0;h=i&1048575;f=c[3531864]|0;k=c[f+44+(h>>>11<<2)>>2]|0;if((k|0)==0){l=gj[c[f+8236>>2]&4095](h)|0;m=l;n=c[2426956]|0;o=c[3531864]|0}else{m=a[k+h|0]|0;n=i;o=f}f=n+1&1048575;n=c[o+44+(f>>>11<<2)>>2]|0;if((n|0)==0){p=gj[c[o+8236>>2]&4095](f)|0}else{p=a[n+f|0]|0}j=(p&255)<<8|m&255}b[d+(c[9654880+(g<<2)>>2]<<1)>>1]=j;j=c[2426956]|0;g=j+2&65535|j&983040;m=c[3531864]|0;p=c[m+44+(g>>>11<<2)>>2]|0;if((p|0)==0){f=gj[c[m+8236>>2]&4095](g)|0;q=f;r=c[2426956]|0;s=c[3531864]|0}else{q=a[p+g|0]|0;r=j;s=m}m=q&255;q=(r+2&65535|r&983040)+1&1048575;j=c[s+44+(q>>>11<<2)>>2]|0;if((j|0)==0){g=gj[c[s+8236>>2]&4095](q)|0;t=g;u=c[2426956]|0;v=t&255;w=v<<8;x=w|m;y=d+26|0;b[y>>1]=x;z=u&1;A=(z|0)!=0;B=d+92|0;C=c[B>>2]|0;D=A?1710606:1708554;E=D>>>(C>>>0);F=E&127;G=d+84|0;H=c[G>>2]|0;I=H-F|0;c[G>>2]=I;return}else{t=a[j+q|0]|0;u=r;v=t&255;w=v<<8;x=w|m;y=d+26|0;b[y>>1]=x;z=u&1;A=(z|0)!=0;B=d+92|0;C=c[B>>2]|0;D=A?1710606:1708554;E=D>>>(C>>>0);F=E&127;G=d+84|0;H=c[G>>2]|0;I=H-F|0;c[G>>2]=I;return}}function f8l(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=d+22|0;g=(e[f>>1]|0)<<4;h=(c[2385310]|0)+28|0;i=b[h>>1]|0;b[h>>1]=i+1&65535;h=(i&65535)+g&1048575;g=c[3531864]|0;i=c[g+6188+(h>>>11<<2)>>2]|0;if((i|0)==0){j=gj[c[g+8236>>2]&4095](h)|0}else{j=a[i+h|0]|0}h=j&255;i=(j&255)>191;if(i){j=(e[f>>1]|0)<<4;g=(c[2385310]|0)+28|0;k=b[g>>1]|0;b[g>>1]=k+1&65535;g=(k&65535)+j&1048575;j=c[3531864]|0;k=c[j+6188+(g>>>11<<2)>>2]|0;if((k|0)==0){l=gj[c[j+8236>>2]&4095](g)|0}else{l=a[k+g|0]|0}a[d+(c[9648736+(h<<2)>>2]|0)|0]=l;m=i?4:11;n=d+84|0;o=c[n>>2]|0;p=o-m|0;c[n>>2]=p;return}gj[c[679712+(h<<2)>>2]&4095](d)|0;h=c[2426956]|0;l=(e[f>>1]|0)<<4;f=(c[2385310]|0)+28|0;g=b[f>>1]|0;b[f>>1]=g+1&65535;f=(g&65535)+l&1048575;l=c[3531864]|0;g=c[l+6188+(f>>>11<<2)>>2]|0;if((g|0)==0){k=gj[c[l+8236>>2]&4095](f)|0;q=k;r=c[3531864]|0}else{q=a[g+f|0]|0;r=l}l=h&1048575;h=c[r+2092+(l>>>11<<2)>>2]|0;if((h|0)==0){gg[c[r+8240>>2]&4095](l,q);m=i?4:11;n=d+84|0;o=c[n>>2]|0;p=o-m|0;c[n>>2]=p;return}else{a[h+l|0]=q;m=i?4:11;n=d+84|0;o=c[n>>2]|0;p=o-m|0;c[n>>2]=p;return}}function f8m(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;f=d+22|0;g=(e[f>>1]|0)<<4;h=(c[2385310]|0)+28|0;i=b[h>>1]|0;b[h>>1]=i+1&65535;h=(i&65535)+g&1048575;g=c[3531864]|0;i=c[g+6188+(h>>>11<<2)>>2]|0;if((i|0)==0){j=gj[c[g+8236>>2]&4095](h)|0}else{j=a[i+h|0]|0}h=j&255;i=(j&255)>191;if(i){j=(e[f>>1]|0)<<4;g=c[2385310]|0;k=g+28|0;l=b[k>>1]|0;m=l+1&65535;b[k>>1]=m;k=(l&65535)+j&1048575;j=c[3531864]|0;l=c[j+6188+(k>>>11<<2)>>2]|0;if((l|0)==0){n=gj[c[j+8236>>2]&4095](k)|0;o=c[2385310]|0;p=n;q=o;r=b[o+28>>1]|0;s=c[3531864]|0}else{p=a[l+k|0]|0;q=g;r=m;s=j}j=(e[f>>1]|0)<<4;b[q+28>>1]=r+1&65535;q=(r&65535)+j&1048575;j=c[s+6188+(q>>>11<<2)>>2]|0;if((j|0)==0){t=gj[c[s+8236>>2]&4095](q)|0}else{t=a[j+q|0]|0}b[d+(c[9650784+(h<<2)>>2]<<1)>>1]=(t&255)<<8|p&255;u=i?4:15;v=d+84|0;w=c[v>>2]|0;x=w-u|0;c[v>>2]=x;return}gj[c[679712+(h<<2)>>2]&4095](d)|0;h=(e[f>>1]|0)<<4;p=c[2385310]|0;t=p+28|0;q=b[t>>1]|0;j=q+1&65535;b[t>>1]=j;t=(q&65535)+h&1048575;h=c[3531864]|0;q=c[h+6188+(t>>>11<<2)>>2]|0;if((q|0)==0){s=gj[c[h+8236>>2]&4095](t)|0;r=c[2385310]|0;y=s;z=r;A=b[r+28>>1]|0;B=c[3531864]|0}else{y=a[q+t|0]|0;z=p;A=j;B=h}h=(e[f>>1]|0)<<4;b[z+28>>1]=A+1&65535;z=(A&65535)+h&1048575;h=c[B+6188+(z>>>11<<2)>>2]|0;if((h|0)==0){A=gj[c[B+8236>>2]&4095](z)|0;C=A;D=c[3531864]|0}else{C=a[h+z|0]|0;D=B}B=c[2426956]|0;z=B&1048575;h=c[D+2092+(z>>>11<<2)>>2]|0;if((h|0)==0){gg[c[D+8240>>2]&4095](z,y);E=c[3531864]|0}else{a[h+z|0]=y;E=D}D=B+1&1048575;B=c[E+2092+(D>>>11<<2)>>2]|0;if((B|0)==0){gg[c[E+8240>>2]&4095](D,C);u=i?4:15;v=d+84|0;w=c[v>>2]|0;x=w-u|0;c[v>>2]=x;return}else{a[B+D|0]=C;u=i?4:15;v=d+84|0;w=c[v>>2]|0;x=w-u|0;c[v>>2]=x;return}}function f8n(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;f=d+22|0;g=(e[f>>1]|0)<<4;h=c[2385310]|0;i=h+28|0;j=b[i>>1]|0;b[i>>1]=j+1&65535;i=(j&65535)+g&1048575;g=c[3531864]|0;j=c[g+6188+(i>>>11<<2)>>2]|0;if((j|0)==0){k=gj[c[g+8236>>2]&4095](i)|0;l=k;m=c[2385310]|0;n=c[3531864]|0}else{l=a[j+i|0]|0;m=h;n=g}g=d+84|0;c[g>>2]=(c[g>>2]|0)-23;h=(e[f>>1]|0)<<4;i=m+28|0;j=b[i>>1]|0;k=j+1&65535;b[i>>1]=k;i=(j&65535)+h&1048575;h=c[n+6188+(i>>>11<<2)>>2]|0;if((h|0)==0){j=gj[c[n+8236>>2]&4095](i)|0;o=c[2385310]|0;p=j;q=o;r=b[o+28>>1]|0;s=c[3531864]|0}else{p=a[h+i|0]|0;q=m;r=k;s=n}n=(e[f>>1]|0)<<4;b[q+28>>1]=r+1&65535;q=(r&65535)+n&1048575;n=c[s+6188+(q>>>11<<2)>>2]|0;if((n|0)==0){r=gj[c[s+8236>>2]&4095](q)|0;t=r;u=c[3531864]|0}else{t=a[n+q|0]|0;u=s}s=t&255;q=d+8|0;n=(b[q>>1]|0)-2&65535;b[q>>1]=n;r=d+24|0;f=((e[r>>1]|0)<<4)+(n&65535)|0;n=d+10|0;k=b[n>>1]|0;m=k&255;i=f&1048575;h=c[u+2092+(i>>>11<<2)>>2]|0;if((h|0)==0){gg[c[u+8240>>2]&4095](i,m);v=c[3531864]|0}else{a[h+i|0]=m;v=u}u=(k&65535)>>>8&255;k=f+1&1048575;f=c[v+2092+(k>>>11<<2)>>2]|0;if((f|0)==0){gg[c[v+8240>>2]&4095](k,u)}else{a[f+k|0]=u}u=b[q>>1]|0;b[n>>1]=u;k=u-((p&255)<<8|l&255)&65535;b[q>>1]=k;L58672:do{if((t&255)>1){l=d+100|0;p=d+96|0;u=1;f=k;while(1){v=f-2&65535;b[q>>1]=v;m=(e[r>>1]|0)<<4;i=m+(v&65535)|0;v=a[l]|0;if(v<<24>>24==0){w=m}else{w=c[p>>2]|0}m=u<<1;h=w-m+(e[n>>1]|0)&1048575;o=c[3531864]|0;j=c[o+44+(h>>>11<<2)>>2]|0;if((j|0)==0){x=gj[c[o+8236>>2]&4095](h)|0;y=x;z=a[l]|0}else{y=a[j+h|0]|0;z=v}if(z<<24>>24==0){A=(e[r>>1]|0)<<4}else{A=c[p>>2]|0}v=A+(-m|1)+(e[n>>1]|0)&1048575;m=c[3531864]|0;h=c[m+44+(v>>>11<<2)>>2]|0;if((h|0)==0){j=gj[c[m+8236>>2]&4095](v)|0;B=j;C=c[3531864]|0}else{B=a[h+v|0]|0;C=m}m=i&1048575;v=c[C+2092+(m>>>11<<2)>>2]|0;if((v|0)==0){gg[c[C+8240>>2]&4095](m,y);D=c[3531864]|0}else{a[v+m|0]=y;D=C}m=i+1&1048575;i=c[D+2092+(m>>>11<<2)>>2]|0;if((i|0)==0){gg[c[D+8240>>2]&4095](m,B)}else{a[i+m|0]=B}c[g>>2]=(c[g>>2]|0)-16;m=u+1|0;if(m>>>0>=s>>>0){break L58672}u=m;f=b[q>>1]|0}}}while(0);if(t<<24>>24==0){return}t=(b[q>>1]|0)-2&65535;b[q>>1]=t;q=((e[r>>1]|0)<<4)+(t&65535)|0;t=b[n>>1]|0;n=t&255;r=q&1048575;s=c[3531864]|0;g=c[s+2092+(r>>>11<<2)>>2]|0;if((g|0)==0){gg[c[s+8240>>2]&4095](r,n);E=c[3531864]|0}else{a[g+r|0]=n;E=s}s=(t&65535)>>>8&255;t=q+1&1048575;q=c[E+2092+(t>>>11<<2)>>2]|0;if((q|0)==0){gg[c[E+8240>>2]&4095](t,s);return}else{a[q+t|0]=s;return}}function f8o(d){d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;e=d+10|0;f=d+8|0;g=(b[e>>1]|0)+2&65535;b[f>>1]=g;h=d+24|0;i=b[h>>1]|0;j=((g&65535)+65534&65535)+((i&65535)<<4)&1048575;k=c[3531864]|0;l=c[k+44+(j>>>11<<2)>>2]|0;if((l|0)==0){m=gj[c[k+8236>>2]&4095](j)|0;n=m;o=b[h>>1]|0;p=b[f>>1]|0;q=c[3531864]|0}else{n=a[l+j|0]|0;o=i;p=g;q=k}k=n&255;n=((p&65535)+65534&65535)+((o&65535)<<4|1)&1048575;o=c[q+44+(n>>>11<<2)>>2]|0;if((o|0)==0){r=gj[c[q+8236>>2]&4095](n)|0;s=r&255;t=s<<8;u=t|k;b[e>>1]=u;v=d+84|0;w=c[v>>2]|0;x=w-8|0;c[v>>2]=x;return}else{r=a[o+n|0]|0;s=r&255;t=s<<8;u=t|k;b[e>>1]=u;v=d+84|0;w=c[v>>2]|0;x=w-8|0;c[v>>2]=x;return}}function f8p(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;f=d+22|0;g=(e[f>>1]|0)<<4;h=c[2385310]|0;i=h+28|0;j=b[i>>1]|0;k=j+1&65535;b[i>>1]=k;i=(j&65535)+g&1048575;g=c[3531864]|0;j=c[g+6188+(i>>>11<<2)>>2]|0;if((j|0)==0){l=gj[c[g+8236>>2]&4095](i)|0;m=c[2385310]|0;n=l;o=m;p=b[m+28>>1]|0;q=c[3531864]|0}else{n=a[j+i|0]|0;o=h;p=k;q=g}g=(e[f>>1]|0)<<4;b[o+28>>1]=p+1&65535;o=(p&65535)+g&1048575;g=c[q+6188+(o>>>11<<2)>>2]|0;if((g|0)==0){p=gj[c[q+8236>>2]&4095](o)|0;r=p;s=c[3531864]|0}else{r=a[g+o|0]|0;s=q}q=(r&255)<<8|n&255;n=d+8|0;r=(b[n>>1]|0)+2&65535;b[n>>1]=r;o=d+24|0;g=b[o>>1]|0;p=((r&65535)+65534&65535)+((g&65535)<<4)&1048575;k=c[s+44+(p>>>11<<2)>>2]|0;if((k|0)==0){h=gj[c[s+8236>>2]&4095](p)|0;t=h;u=b[o>>1]|0;v=b[n>>1]|0;w=c[3531864]|0}else{t=a[k+p|0]|0;u=g;v=r;w=s}s=((v&65535)+65534&65535)+((u&65535)<<4|1)&1048575;r=c[w+44+(s>>>11<<2)>>2]|0;if((r|0)==0){g=gj[c[w+8236>>2]&4095](s)|0;x=g;y=b[n>>1]|0;z=b[o>>1]|0;A=c[3531864]|0}else{x=a[r+s|0]|0;y=v;z=u;A=w}b[d+28>>1]=(x&255)<<8|t&255;t=y+2&65535;b[n>>1]=t;y=((t&65535)+65534&65535)+((z&65535)<<4)&1048575;x=c[A+44+(y>>>11<<2)>>2]|0;if((x|0)==0){w=gj[c[A+8236>>2]&4095](y)|0;B=w;C=b[o>>1]|0;D=b[n>>1]|0;E=c[3531864]|0}else{B=a[x+y|0]|0;C=z;D=t;E=A}A=B&255;B=((D&65535)+65534&65535)+((C&65535)<<4|1)&1048575;C=c[E+44+(B>>>11<<2)>>2]|0;if((C|0)==0){t=gj[c[E+8236>>2]&4095](B)|0;F=t;G=b[n>>1]|0;H=F&255;I=H<<8;J=I|A;b[f>>1]=J;K=G+q&65535;b[n>>1]=K;L=d+91|0;a[L]=1;M=d+92|0;N=c[M>>2]|0;O=2105360>>>(N>>>0);P=O&127;Q=d+84|0;R=c[Q>>2]|0;S=R-P|0;c[Q>>2]=S;return}else{F=a[C+B|0]|0;G=D;H=F&255;I=H<<8;J=I|A;b[f>>1]=J;K=G+q&65535;b[n>>1]=K;L=d+91|0;a[L]=1;M=d+92|0;N=c[M>>2]|0;O=2105360>>>(N>>>0);P=O&127;Q=d+84|0;R=c[Q>>2]|0;S=R-P|0;c[Q>>2]=S;return}}function f8q(d){d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;e=d+8|0;f=(b[e>>1]|0)+2&65535;b[e>>1]=f;g=d+24|0;h=b[g>>1]|0;i=((f&65535)+65534&65535)+((h&65535)<<4)&1048575;j=c[3531864]|0;k=c[j+44+(i>>>11<<2)>>2]|0;if((k|0)==0){l=gj[c[j+8236>>2]&4095](i)|0;m=l;n=b[g>>1]|0;o=b[e>>1]|0;p=c[3531864]|0}else{m=a[k+i|0]|0;n=h;o=f;p=j}j=((o&65535)+65534&65535)+((n&65535)<<4|1)&1048575;f=c[p+44+(j>>>11<<2)>>2]|0;if((f|0)==0){h=gj[c[p+8236>>2]&4095](j)|0;q=h;r=b[e>>1]|0;s=b[g>>1]|0;t=c[3531864]|0}else{q=a[f+j|0]|0;r=o;s=n;t=p}b[d+28>>1]=(q&255)<<8|m&255;m=r+2&65535;b[e>>1]=m;r=((m&65535)+65534&65535)+((s&65535)<<4)&1048575;q=c[t+44+(r>>>11<<2)>>2]|0;if((q|0)==0){p=gj[c[t+8236>>2]&4095](r)|0;u=p;v=b[g>>1]|0;w=b[e>>1]|0;x=c[3531864]|0}else{u=a[q+r|0]|0;v=s;w=m;x=t}t=u&255;u=((w&65535)+65534&65535)+((v&65535)<<4|1)&1048575;v=c[x+44+(u>>>11<<2)>>2]|0;if((v|0)==0){y=gj[c[x+8236>>2]&4095](u)|0;z=y&255;A=z<<8;B=A|t;C=d+22|0;b[C>>1]=B;D=d+91|0;a[D]=1;E=d+92|0;F=c[E>>2]|0;G=1907984>>>(F>>>0);H=G&127;I=d+84|0;J=c[I>>2]|0;K=J-H|0;c[I>>2]=K;return}else{y=a[v+u|0]|0;z=y&255;A=z<<8;B=A|t;C=d+22|0;b[C>>1]=B;D=d+91|0;a[D]=1;E=d+92|0;F=c[E>>2]|0;G=1907984>>>(F>>>0);H=G&127;I=d+84|0;J=c[I>>2]|0;K=J-H|0;c[I>>2]=K;return}}function f8r(a){a=a|0;var b=0;f9v(a,3,0);b=a+84|0;c[b>>2]=(c[b>>2]|0)-(3289624>>>((c[a+92>>2]|0)>>>0)&127);return}function f8s(d){d=d|0;var f=0,g=0,h=0,i=0;f=(e[d+22>>1]|0)<<4;g=(c[2385310]|0)+28|0;h=b[g>>1]|0;b[g>>1]=h+1&65535;g=(h&65535)+f&1048575;f=c[3531864]|0;h=c[f+6188+(g>>>11<<2)>>2]|0;if((h|0)==0){i=gj[c[f+8236>>2]&4095](g)|0}else{i=a[h+g|0]|0}f9v(d,i&255,0);i=d+84|0;c[i>>2]=(c[i>>2]|0)-(3289624>>>((c[d+92>>2]|0)>>>0)&127);return}function f8t(a){a=a|0;var b=0;if((c[a+40>>2]|0)==0){b=a+84|0;c[b>>2]=(c[b>>2]|0)-3;return}else{f9v(a,4,0);b=a+84|0;c[b>>2]=(c[b>>2]|0)-(3421210>>>((c[a+92>>2]|0)>>>0)&127);return}}function f8u(d){d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;e=d+8|0;f=(b[e>>1]|0)+2&65535;b[e>>1]=f;g=d+24|0;h=b[g>>1]|0;i=((f&65535)+65534&65535)+((h&65535)<<4)&1048575;j=c[3531864]|0;k=c[j+44+(i>>>11<<2)>>2]|0;if((k|0)==0){l=gj[c[j+8236>>2]&4095](i)|0;m=l;n=b[g>>1]|0;o=b[e>>1]|0;p=c[3531864]|0}else{m=a[k+i|0]|0;n=h;o=f;p=j}j=((o&65535)+65534&65535)+((n&65535)<<4|1)&1048575;f=c[p+44+(j>>>11<<2)>>2]|0;if((f|0)==0){h=gj[c[p+8236>>2]&4095](j)|0;q=h;r=b[e>>1]|0;s=b[g>>1]|0;t=c[3531864]|0}else{q=a[f+j|0]|0;r=o;s=n;t=p}b[d+28>>1]=(q&255)<<8|m&255;m=r+2&65535;b[e>>1]=m;r=((m&65535)+65534&65535)+((s&65535)<<4)&1048575;q=c[t+44+(r>>>11<<2)>>2]|0;if((q|0)==0){p=gj[c[t+8236>>2]&4095](r)|0;u=p;v=b[g>>1]|0;w=b[e>>1]|0;x=c[3531864]|0}else{u=a[q+r|0]|0;v=s;w=m;x=t}t=u&255;u=((w&65535)+65534&65535)+((v&65535)<<4|1)&1048575;v=c[x+44+(u>>>11<<2)>>2]|0;if((v|0)==0){y=gj[c[x+8236>>2]&4095](u)|0;z=y&255;A=z<<8;B=A|t;C=d+22|0;b[C>>1]=B;f7I(d);D=d+91|0;a[D]=1;E=d+92|0;F=c[E>>2]|0;G=2565907>>>(F>>>0);H=G&127;I=d+84|0;J=c[I>>2]|0;K=J-H|0;c[I>>2]=K;return}else{y=a[v+u|0]|0;z=y&255;A=z<<8;B=A|t;C=d+22|0;b[C>>1]=B;f7I(d);D=d+91|0;a[D]=1;E=d+92|0;F=c[E>>2]|0;G=2565907>>>(F>>>0);H=G&127;I=d+84|0;J=c[I>>2]|0;K=J-H|0;c[I>>2]=K;return}}function f8v(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=(e[d+22>>1]|0)<<4;g=(c[2385310]|0)+28|0;h=b[g>>1]|0;b[g>>1]=h+1&65535;g=(h&65535)+f&1048575;f=c[3531864]|0;h=c[f+6188+(g>>>11<<2)>>2]|0;if((h|0)==0){i=gj[c[f+8236>>2]&4095](g)|0}else{i=a[h+g|0]|0}g=i&255;h=(i&255)>191;do{if(h){j=a[d+(c[9648736+(g<<2)>>2]|0)|0]|0}else{i=(gj[c[679712+(g<<2)>>2]&4095](d)|0)&1048575;f=c[3531864]|0;k=c[f+44+(i>>>11<<2)>>2]|0;if((k|0)==0){j=gj[c[f+8236>>2]&4095](i)|0;break}else{j=a[k+i|0]|0;break}}}while(0);i=j&255;k=d+84|0;f=(c[k>>2]|0)-((h?394754:1052679)>>>((c[d+92>>2]|0)>>>0)&127)|0;c[k>>2]=f;switch(g&56|0){case 8:{l=i&1;c[d+48>>2]=l;m=l<<7;l=m|i>>>1;do{if(h){a[d+(c[9648736+(g<<2)>>2]|0)|0]=l&255}else{n=l&255;o=c[2426956]&1048575;p=c[3531864]|0;q=c[p+2092+(o>>>11<<2)>>2]|0;if((q|0)==0){gg[c[p+8240>>2]&4095](o,n);break}else{a[q+o|0]=n;break}}}while(0);c[d+40>>2]=m^i&128;return};case 0:{c[d+48>>2]=i&128;m=i<<1;l=m|i>>>7;do{if(h){a[d+(c[9648736+(g<<2)>>2]|0)|0]=l&255}else{n=l&255;o=c[2426956]&1048575;q=c[3531864]|0;p=c[q+2092+(o>>>11<<2)>>2]|0;if((p|0)==0){gg[c[q+8240>>2]&4095](o,n);break}else{a[p+o|0]=n;break}}}while(0);c[d+40>>2]=(m^i)&128;return};case 16:{m=i<<1;l=d+48|0;n=(c[l>>2]|0)!=0|m;c[l>>2]=m&256;do{if(h){a[d+(c[9648736+(g<<2)>>2]|0)|0]=n&255}else{l=n&255;o=c[2426956]&1048575;p=c[3531864]|0;q=c[p+2092+(o>>>11<<2)>>2]|0;if((q|0)==0){gg[c[p+8240>>2]&4095](o,l);break}else{a[q+o|0]=l;break}}}while(0);c[d+40>>2]=(m^i)&128;return};case 24:{m=d+48|0;n=((c[m>>2]|0)!=0)<<8|i;c[m>>2]=i&1;m=n>>>1;do{if(h){a[d+(c[9648736+(g<<2)>>2]|0)|0]=m&255}else{n=m&255;l=c[2426956]&1048575;o=c[3531864]|0;q=c[o+2092+(l>>>11<<2)>>2]|0;if((q|0)==0){gg[c[o+8240>>2]&4095](l,n);break}else{a[q+l|0]=n;break}}}while(0);c[d+40>>2]=(m^i)&128;return};case 32:{c[k>>2]=f-1;m=i<<1;c[d+48>>2]=m&256;n=m&255;l=n<<24>>24;c[d+52>>2]=l;c[d+44>>2]=l;c[d+32>>2]=l;do{if(h){a[d+(c[9648736+(g<<2)>>2]|0)|0]=n}else{l=c[2426956]&1048575;q=c[3531864]|0;o=c[q+2092+(l>>>11<<2)>>2]|0;if((o|0)==0){gg[c[q+8240>>2]&4095](l,n);break}else{a[o+l|0]=n;break}}}while(0);c[d+40>>2]=(m^i)&128;return};case 40:{c[k>>2]=f-1;c[d+48>>2]=i&1;m=i>>>1;n=m&255;c[d+52>>2]=m;c[d+44>>2]=m;c[d+32>>2]=m;do{if(h){a[d+(c[9648736+(g<<2)>>2]|0)|0]=n}else{m=c[2426956]&1048575;l=c[3531864]|0;o=c[l+2092+(m>>>11<<2)>>2]|0;if((o|0)==0){gg[c[l+8240>>2]&4095](m,n);break}else{a[o+m|0]=n;break}}}while(0);c[d+40>>2]=i&128;return};case 56:{c[k>>2]=f-1;c[d+48>>2]=i&1;i=j<<24>>24>>>1&255;j=i<<24>>24;c[d+52>>2]=j;c[d+44>>2]=j;c[d+32>>2]=j;do{if(h){a[d+(c[9648736+(g<<2)>>2]|0)|0]=i}else{j=c[2426956]&1048575;f=c[3531864]|0;k=c[f+2092+(j>>>11<<2)>>2]|0;if((k|0)==0){gg[c[f+8240>>2]&4095](j,i);break}else{a[k+j|0]=i;break}}}while(0);c[d+40>>2]=0;return};default:{return}}}function f8w(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;f=(e[d+22>>1]|0)<<4;g=(c[2385310]|0)+28|0;h=b[g>>1]|0;b[g>>1]=h+1&65535;g=(h&65535)+f&1048575;f=c[3531864]|0;h=c[f+6188+(g>>>11<<2)>>2]|0;if((h|0)==0){i=gj[c[f+8236>>2]&4095](g)|0}else{i=a[h+g|0]|0}g=i&255;h=(i&255)>191;if(h){j=e[d+(c[9650784+(g<<2)>>2]<<1)>>1]|0}else{i=c[679712+(g<<2)>>2]|0;gj[i&4095](d)|0;i=c[2426956]|0;f=i&1048575;k=c[3531864]|0;l=c[k+44+(f>>>11<<2)>>2]|0;if((l|0)==0){m=gj[c[k+8236>>2]&4095](f)|0;n=m;o=c[2426956]|0;p=c[3531864]|0}else{n=a[l+f|0]|0;o=i;p=k}k=o+1&1048575;o=c[p+44+(k>>>11<<2)>>2]|0;if((o|0)==0){q=gj[c[p+8236>>2]&4095](k)|0}else{q=a[o+k|0]|0}j=(q&255)<<8|n&255}n=d+84|0;q=(c[n>>2]|0)-((h?394754:1576967)>>>((c[d+92>>2]|0)>>>0)&127)|0;c[n>>2]=q;switch(g&56|0){case 0:{k=j&32768;c[d+48>>2]=k;o=j<<1;p=k>>>15|o;do{if(h){b[d+(c[9650784+(g<<2)>>2]<<1)>>1]=p&65535}else{k=c[2426956]|0;i=p&255;f=k&1048575;l=c[3531864]|0;m=c[l+2092+(f>>>11<<2)>>2]|0;if((m|0)==0){gg[c[l+8240>>2]&4095](f,i);r=c[3531864]|0}else{a[m+f|0]=i;r=l}l=j>>>7&255;i=k+1&1048575;k=c[r+2092+(i>>>11<<2)>>2]|0;if((k|0)==0){gg[c[r+8240>>2]&4095](i,l);break}else{a[k+i|0]=l;break}}}while(0);c[d+40>>2]=(o^j)&32768;return};case 8:{o=j&1;c[d+48>>2]=o;r=(o<<15)+(j>>>1)|0;do{if(h){b[d+(c[9650784+(g<<2)>>2]<<1)>>1]=r&65535}else{o=c[2426956]|0;p=r&255;l=o&1048575;i=c[3531864]|0;k=c[i+2092+(l>>>11<<2)>>2]|0;if((k|0)==0){gg[c[i+8240>>2]&4095](l,p);s=c[3531864]|0}else{a[k+l|0]=p;s=i}i=(r&65535)>>>8&255;p=o+1&1048575;o=c[s+2092+(p>>>11<<2)>>2]|0;if((o|0)==0){gg[c[s+8240>>2]&4095](p,i);break}else{a[o+p|0]=i;break}}}while(0);c[d+40>>2]=(r^j)&32768;return};case 16:{r=j<<1;s=d+48|0;i=(c[s>>2]|0)!=0|r;c[s>>2]=r&65536;do{if(h){b[d+(c[9650784+(g<<2)>>2]<<1)>>1]=i&65535}else{s=c[2426956]|0;p=i&255;o=s&1048575;l=c[3531864]|0;k=c[l+2092+(o>>>11<<2)>>2]|0;if((k|0)==0){gg[c[l+8240>>2]&4095](o,p);t=c[3531864]|0}else{a[k+o|0]=p;t=l}l=j>>>7&255;p=s+1&1048575;s=c[t+2092+(p>>>11<<2)>>2]|0;if((s|0)==0){gg[c[t+8240>>2]&4095](p,l);break}else{a[s+p|0]=l;break}}}while(0);c[d+40>>2]=(r^j)&32768;return};case 24:{r=d+48|0;t=(((c[r>>2]|0)!=0)<<16)+j|0;c[r>>2]=t&1;r=t>>>1;do{if(h){b[d+(c[9650784+(g<<2)>>2]<<1)>>1]=r&65535}else{i=c[2426956]|0;l=r&255;p=i&1048575;s=c[3531864]|0;o=c[s+2092+(p>>>11<<2)>>2]|0;if((o|0)==0){gg[c[s+8240>>2]&4095](p,l);u=c[3531864]|0}else{a[o+p|0]=l;u=s}s=t>>>9&255;l=i+1&1048575;i=c[u+2092+(l>>>11<<2)>>2]|0;if((i|0)==0){gg[c[u+8240>>2]&4095](l,s);break}else{a[i+l|0]=s;break}}}while(0);c[d+40>>2]=(r^j)&32768;return};case 32:{c[n>>2]=q-1;r=j<<1;c[d+48>>2]=r&65536;u=r&65535;t=u<<16>>16;c[d+52>>2]=t;c[d+44>>2]=t;c[d+32>>2]=t;do{if(h){b[d+(c[9650784+(g<<2)>>2]<<1)>>1]=u}else{t=c[2426956]|0;s=r&255;l=t&1048575;i=c[3531864]|0;p=c[i+2092+(l>>>11<<2)>>2]|0;if((p|0)==0){gg[c[i+8240>>2]&4095](l,s);v=c[3531864]|0}else{a[p+l|0]=s;v=i}i=j>>>7&255;s=t+1&1048575;t=c[v+2092+(s>>>11<<2)>>2]|0;if((t|0)==0){gg[c[v+8240>>2]&4095](s,i);break}else{a[t+s|0]=i;break}}}while(0);c[d+40>>2]=(r^j)&32768;return};case 40:{c[n>>2]=q-1;c[d+48>>2]=j&1;r=j>>>1;v=r&65535;u=v<<16>>16;c[d+52>>2]=u;c[d+44>>2]=u;c[d+32>>2]=u;do{if(h){b[d+(c[9650784+(g<<2)>>2]<<1)>>1]=v}else{u=c[2426956]|0;i=r&255;s=u&1048575;t=c[3531864]|0;l=c[t+2092+(s>>>11<<2)>>2]|0;if((l|0)==0){gg[c[t+8240>>2]&4095](s,i);w=c[3531864]|0}else{a[l+s|0]=i;w=t}t=j>>>9&255;i=u+1&1048575;u=c[w+2092+(i>>>11<<2)>>2]|0;if((u|0)==0){gg[c[w+8240>>2]&4095](i,t);break}else{a[u+i|0]=t;break}}}while(0);c[d+40>>2]=(r^j)&32768;return};case 56:{c[n>>2]=q-1;c[d+48>>2]=j&1;q=j<<16>>17;j=q&65535;n=j<<16>>16;c[d+52>>2]=n;c[d+44>>2]=n;c[d+32>>2]=n;do{if(h){b[d+(c[9650784+(g<<2)>>2]<<1)>>1]=j}else{n=c[2426956]|0;r=q&255;w=n&1048575;v=c[3531864]|0;t=c[v+2092+(w>>>11<<2)>>2]|0;if((t|0)==0){gg[c[v+8240>>2]&4095](w,r);x=c[3531864]|0}else{a[t+w|0]=r;x=v}v=q>>>8&255;r=n+1&1048575;n=c[x+2092+(r>>>11<<2)>>2]|0;if((n|0)==0){gg[c[x+8240>>2]&4095](r,v);break}else{a[n+r|0]=v;break}}}while(0);c[d+40>>2]=0;return};default:{return}}}function f8x(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=(e[d+22>>1]|0)<<4;g=(c[2385310]|0)+28|0;h=b[g>>1]|0;b[g>>1]=h+1&65535;g=(h&65535)+f&1048575;f=c[3531864]|0;h=c[f+6188+(g>>>11<<2)>>2]|0;if((h|0)==0){i=gj[c[f+8236>>2]&4095](g)|0}else{i=a[h+g|0]|0}g=i&255;h=(i&255)>191;if(h){i=d;j=a[i+(c[9648736+(g<<2)>>2]|0)|0]|0;k=i}else{i=(gj[c[679712+(g<<2)>>2]&4095](d)|0)&1048575;f=c[3531864]|0;l=c[f+44+(i>>>11<<2)>>2]|0;if((l|0)==0){m=gj[c[f+8236>>2]&4095](i)|0}else{m=a[l+i|0]|0}j=m;k=d}m=j&255;i=a[d+2|0]|0;l=d+84|0;f=(c[l>>2]|0)-((h?460546:1250054)>>>((c[d+92>>2]|0)>>>0)&127)|0;c[l>>2]=f;if(i<<24>>24==0){return}switch(g&56|0){case 8:{n=i-1&255;o=m;p=i;do{q=o&1;o=(q<<7)+(o>>>1)|0;p=p-1&255;}while(p<<24>>24!=0);c[d+48>>2]=q;c[l>>2]=f+~(n&255);if(h){a[k+(c[9648736+(g<<2)>>2]|0)|0]=o&255;return}n=o&255;o=c[2426956]&1048575;q=c[3531864]|0;p=c[q+2092+(o>>>11<<2)>>2]|0;if((p|0)==0){gg[c[q+8240>>2]&4095](o,n);return}else{a[p+o|0]=n;return}break};case 0:{n=i-1&255;o=m;p=i;do{r=o&128;o=r>>>7|o<<1;p=p-1&255;}while(p<<24>>24!=0);c[d+48>>2]=r;c[l>>2]=f+~(n&255);if(h){a[k+(c[9648736+(g<<2)>>2]|0)|0]=o&255;return}n=o&255;o=c[2426956]&1048575;r=c[3531864]|0;p=c[r+2092+(o>>>11<<2)>>2]|0;if((p|0)==0){gg[c[r+8240>>2]&4095](o,n);return}else{a[p+o|0]=n;return}break};case 16:{n=d+48|0;o=i-1&255;p=m;r=i;q=c[n>>2]|0;do{s=p<<1;p=s|(q|0)!=0;q=s&256;r=r-1&255;}while(r<<24>>24!=0);c[n>>2]=q;c[l>>2]=f+~(o&255);if(h){a[k+(c[9648736+(g<<2)>>2]|0)|0]=p&255;return}o=p&255;p=c[2426956]&1048575;q=c[3531864]|0;n=c[q+2092+(p>>>11<<2)>>2]|0;if((n|0)==0){gg[c[q+8240>>2]&4095](p,o);return}else{a[n+p|0]=o;return}break};case 24:{o=d+48|0;p=i-1&255;n=m;q=i;r=c[o>>2]|0;do{s=(((r|0)!=0)<<8)+n|0;r=s&1;n=s>>>1;q=q-1&255;}while(q<<24>>24!=0);c[o>>2]=r;c[l>>2]=f+~(p&255);if(h){a[k+(c[9648736+(g<<2)>>2]|0)|0]=n&255;return}p=n&255;n=c[2426956]&1048575;r=c[3531864]|0;o=c[r+2092+(n>>>11<<2)>>2]|0;if((o|0)==0){gg[c[r+8240>>2]&4095](n,p);return}else{a[o+n|0]=p;return}break};case 32:{p=i&255;c[l>>2]=f-p;n=m<<p;c[d+48>>2]=n&256;p=n&255;n=p<<24>>24;c[d+52>>2]=n;c[d+44>>2]=n;c[d+32>>2]=n;if(h){a[k+(c[9648736+(g<<2)>>2]|0)|0]=p;return}n=c[2426956]&1048575;o=c[3531864]|0;r=c[o+2092+(n>>>11<<2)>>2]|0;if((r|0)==0){gg[c[o+8240>>2]&4095](n,p);return}else{a[r+n|0]=p;return}break};case 40:{p=i&255;c[l>>2]=f-p;n=m>>>((p-1|0)>>>0);c[d+48>>2]=n&1;p=n>>>1&255;n=p<<24>>24;c[d+52>>2]=n;c[d+44>>2]=n;c[d+32>>2]=n;if(h){a[k+(c[9648736+(g<<2)>>2]|0)|0]=p;return}n=c[2426956]&1048575;m=c[3531864]|0;r=c[m+2092+(n>>>11<<2)>>2]|0;if((r|0)==0){gg[c[m+8240>>2]&4095](n,p);return}else{a[r+n|0]=p;return}break};case 56:{p=i&255;c[l>>2]=f-p;f=j<<24>>24>>p-1;c[d+48>>2]=f&1;p=f>>>1&255;f=p<<24>>24;c[d+52>>2]=f;c[d+44>>2]=f;c[d+32>>2]=f;if(h){a[k+(c[9648736+(g<<2)>>2]|0)|0]=p;return}g=c[2426956]&1048575;k=c[3531864]|0;h=c[k+2092+(g>>>11<<2)>>2]|0;if((h|0)==0){gg[c[k+8240>>2]&4095](g,p);return}else{a[h+g|0]=p;return}break};default:{return}}}function f8y(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;f=(e[d+22>>1]|0)<<4;g=(c[2385310]|0)+28|0;h=b[g>>1]|0;b[g>>1]=h+1&65535;g=(h&65535)+f&1048575;f=c[3531864]|0;h=c[f+6188+(g>>>11<<2)>>2]|0;if((h|0)==0){i=gj[c[f+8236>>2]&4095](g)|0}else{i=a[h+g|0]|0}g=i&255;h=(i&255)>191;if(h){j=e[d+(c[9650784+(g<<2)>>2]<<1)>>1]|0}else{i=c[679712+(g<<2)>>2]|0;gj[i&4095](d)|0;i=c[2426956]|0;f=i&1048575;k=c[3531864]|0;l=c[k+44+(f>>>11<<2)>>2]|0;if((l|0)==0){m=gj[c[k+8236>>2]&4095](f)|0;n=m;o=c[2426956]|0;p=c[3531864]|0}else{n=a[l+f|0]|0;o=i;p=k}k=o+1&1048575;o=c[p+44+(k>>>11<<2)>>2]|0;if((o|0)==0){q=gj[c[p+8236>>2]&4095](k)|0}else{q=a[o+k|0]|0}j=(q&255)<<8|n&255}n=a[d+2|0]|0;q=d+84|0;k=(c[q>>2]|0)-((h?460546:1774342)>>>((c[d+92>>2]|0)>>>0)&127)|0;c[q>>2]=k;if(n<<24>>24==0){return}switch(g&56|0){case 16:{o=d+48|0;p=n-1&255;i=j;f=n;l=c[o>>2]|0;while(1){m=i<<1;r=m|(l|0)!=0;s=m&65536;m=f-1&255;if(m<<24>>24==0){break}else{i=r;f=m;l=s}}c[o>>2]=s;c[q>>2]=k+~(p&255);if(h){b[d+(c[9650784+(g<<2)>>2]<<1)>>1]=r&65535;return}p=c[2426956]|0;s=r&255;r=p&1048575;o=c[3531864]|0;l=c[o+2092+(r>>>11<<2)>>2]|0;if((l|0)==0){gg[c[o+8240>>2]&4095](r,s);t=c[3531864]|0}else{a[l+r|0]=s;t=o}o=i>>>7&255;i=p+1&1048575;p=c[t+2092+(i>>>11<<2)>>2]|0;if((p|0)==0){gg[c[t+8240>>2]&4095](i,o);return}else{a[p+i|0]=o;return}break};case 0:{o=n-1&255;i=j;p=n;while(1){u=i&32768;v=u>>>15|i<<1;t=p-1&255;if(t<<24>>24==0){break}else{i=v;p=t}}c[d+48>>2]=u;c[q>>2]=k+~(o&255);if(h){b[d+(c[9650784+(g<<2)>>2]<<1)>>1]=v&65535;return}o=c[2426956]|0;u=v&255;v=o&1048575;p=c[3531864]|0;t=c[p+2092+(v>>>11<<2)>>2]|0;if((t|0)==0){gg[c[p+8240>>2]&4095](v,u);w=c[3531864]|0}else{a[t+v|0]=u;w=p}p=i>>>7&255;i=o+1&1048575;o=c[w+2092+(i>>>11<<2)>>2]|0;if((o|0)==0){gg[c[w+8240>>2]&4095](i,p);return}else{a[o+i|0]=p;return}break};case 8:{p=n-1&255;i=j;o=n;do{x=i&1;i=(x<<15)+(i>>>1)|0;o=o-1&255;}while(o<<24>>24!=0);c[d+48>>2]=x;c[q>>2]=k+~(p&255);if(h){b[d+(c[9650784+(g<<2)>>2]<<1)>>1]=i&65535;return}p=c[2426956]|0;x=i&255;o=p&1048575;w=c[3531864]|0;u=c[w+2092+(o>>>11<<2)>>2]|0;if((u|0)==0){gg[c[w+8240>>2]&4095](o,x);y=c[3531864]|0}else{a[u+o|0]=x;y=w}w=(i&65535)>>>8&255;i=p+1&1048575;p=c[y+2092+(i>>>11<<2)>>2]|0;if((p|0)==0){gg[c[y+8240>>2]&4095](i,w);return}else{a[p+i|0]=w;return}break};case 32:{w=n&255;c[q>>2]=k-w;i=j<<w;c[d+48>>2]=i&65536;w=i&65535;p=w<<16>>16;c[d+52>>2]=p;c[d+44>>2]=p;c[d+32>>2]=p;if(h){b[d+(c[9650784+(g<<2)>>2]<<1)>>1]=w;return}p=c[2426956]|0;y=i&255;i=p&1048575;x=c[3531864]|0;o=c[x+2092+(i>>>11<<2)>>2]|0;if((o|0)==0){gg[c[x+8240>>2]&4095](i,y);z=c[3531864]|0}else{a[o+i|0]=y;z=x}x=(w&65535)>>>8&255;w=p+1&1048575;p=c[z+2092+(w>>>11<<2)>>2]|0;if((p|0)==0){gg[c[z+8240>>2]&4095](w,x);return}else{a[p+w|0]=x;return}break};case 40:{x=n&255;c[q>>2]=k-x;w=j>>>((x-1|0)>>>0);c[d+48>>2]=w&1;x=w>>>1;p=x&65535;z=p<<16>>16;c[d+52>>2]=z;c[d+44>>2]=z;c[d+32>>2]=z;if(h){b[d+(c[9650784+(g<<2)>>2]<<1)>>1]=p;return}p=c[2426956]|0;z=x&255;x=p&1048575;y=c[3531864]|0;i=c[y+2092+(x>>>11<<2)>>2]|0;if((i|0)==0){gg[c[y+8240>>2]&4095](x,z);A=c[3531864]|0}else{a[i+x|0]=z;A=y}y=w>>>9&255;w=p+1&1048575;p=c[A+2092+(w>>>11<<2)>>2]|0;if((p|0)==0){gg[c[A+8240>>2]&4095](w,y);return}else{a[p+w|0]=y;return}break};case 56:{y=n&255;c[q>>2]=k-y;w=j<<16>>16>>y-1;c[d+48>>2]=w&1;y=w>>>1;p=y&65535;A=p<<16>>16;c[d+52>>2]=A;c[d+44>>2]=A;c[d+32>>2]=A;if(h){b[d+(c[9650784+(g<<2)>>2]<<1)>>1]=p;return}p=c[2426956]|0;A=y&255;y=p&1048575;z=c[3531864]|0;x=c[z+2092+(y>>>11<<2)>>2]|0;if((x|0)==0){gg[c[z+8240>>2]&4095](y,A);B=c[3531864]|0}else{a[x+y|0]=A;B=z}z=w>>>9&255;w=p+1&1048575;p=c[B+2092+(w>>>11<<2)>>2]|0;if((p|0)==0){gg[c[B+8240>>2]&4095](w,z);return}else{a[p+w|0]=z;return}break};case 24:{z=d+48|0;w=n-1&255;p=j;j=n;n=c[z>>2]|0;do{C=(((n|0)!=0)<<16)+p|0;n=C&1;p=C>>>1;j=j-1&255;}while(j<<24>>24!=0);c[z>>2]=n;c[q>>2]=k+~(w&255);if(h){b[d+(c[9650784+(g<<2)>>2]<<1)>>1]=p&65535;return}g=c[2426956]|0;d=p&255;p=g&1048575;h=c[3531864]|0;w=c[h+2092+(p>>>11<<2)>>2]|0;if((w|0)==0){gg[c[h+8240>>2]&4095](p,d);D=c[3531864]|0}else{a[w+p|0]=d;D=h}h=C>>>9&255;C=g+1&1048575;g=c[D+2092+(C>>>11<<2)>>2]|0;if((g|0)==0){gg[c[D+8240>>2]&4095](C,h);return}else{a[g+C|0]=h;return}break};default:{return}}}function f8z(d){d=d|0;var f=0,g=0,h=0;f=e[d+22>>1]<<4;g=(c[2385310]|0)+28|0;h=b[g>>1]|0;b[g>>1]=h+1&65535;g=(h&65535)+f&1048575;f=c[3531864]|0;if((c[f+6188+(g>>>11<<2)>>2]|0)==0){h=c[f+8236>>2]|0;gj[h&4095](g)|0}g=d;h=a[g]|0;a[d+1|0]=(h&255)/10|0;a[g]=(h&255)%10|0;h=b[d>>1]|0;c[d+52>>2]=h;c[d+44>>2]=h;c[d+32>>2]=h;h=d+84|0;c[h>>2]=(c[h>>2]|0)-(986892>>>((c[d+92>>2]|0)>>>0)&127);return}function f8A(d){d=d|0;var f=0,g=0,h=0;f=(e[d+22>>1]|0)<<4;g=(c[2385310]|0)+28|0;h=b[g>>1]|0;b[g>>1]=h+1&65535;g=(h&65535)+f&1048575;f=c[3531864]|0;if((c[f+6188+(g>>>11<<2)>>2]|0)==0){h=c[f+8236>>2]|0;gj[h&4095](g)|0}g=d+1|0;h=d;f=((a[g]|0)*10&255)+(a[h]|0)&255;a[h]=f;a[g]=0;g=f<<24>>24;c[d+52>>2]=g;c[d+44>>2]=g;c[d+32>>2]=g;g=d+84|0;c[g>>2]=(c[g>>2]|0)-(460552>>>((c[d+92>>2]|0)>>>0)&127);return}function f8B(b){b=b|0;var d=0;a[b]=((c[b+48>>2]|0)!=0)<<31>>31;d=b+84|0;c[d>>2]=(c[d>>2]|0)-3;return}function f8C(b){b=b|0;var f=0,g=0,h=0,i=0,j=0;f=b;if((a[b+100|0]|0)==0){g=e[b+26>>1]<<4}else{g=c[b+96>>2]|0}h=g+((d[f]|0)+(e[b+6>>1]|0)&65535)&1048575;g=c[3531864]|0;i=c[g+44+(h>>>11<<2)>>2]|0;if((i|0)==0){j=gj[c[g+8236>>2]&4095](h)|0}else{j=a[i+h|0]|0}a[f]=j;j=b+84|0;c[j>>2]=(c[j>>2]|0)-(592133>>>((c[b+92>>2]|0)>>>0)&127);return}function f8D(a){a=a|0;var d=0,f=0,g=0,h=0,i=0,j=0;d=(e[a+22>>1]|0)<<4;f=(c[2385310]|0)+28|0;g=b[f>>1]|0;b[f>>1]=g+1&65535;f=(g&65535)+d&1048575;d=c[3531864]|0;if((c[d+6188+(f>>>11<<2)>>2]|0)!=0){h=a+84|0;i=c[h>>2]|0;j=i-2|0;c[h>>2]=j;return}gj[c[d+8236>>2]&4095](f)|0;h=a+84|0;i=c[h>>2]|0;j=i-2|0;c[h>>2]=j;return}function f8E(d){d=d|0;var f=0,g=0,h=0,i=0;f=(e[d+22>>1]|0)<<4;g=(c[2385310]|0)+28|0;h=b[g>>1]|0;b[g>>1]=h+1&65535;g=(h&65535)+f&1048575;f=c[3531864]|0;h=c[f+6188+(g>>>11<<2)>>2]|0;if((h|0)==0){i=gj[c[f+8236>>2]&4095](g)|0}else{i=a[h+g|0]|0}g=d+2|0;h=(b[g>>1]|0)-1&65535;b[g>>1]=h;if((c[d+44>>2]|0)==0|h<<16>>16==0){h=d+84|0;c[h>>2]=(c[h>>2]|0)-(328963>>>((c[d+92>>2]|0)>>>0)&127);return}else{h=d+28|0;b[h>>1]=(b[h>>1]|0)+(i<<24>>24)&65535;i=d+84|0;c[i>>2]=(c[i>>2]|0)-(921094>>>((c[d+92>>2]|0)>>>0)&127);return}}function f8F(d){d=d|0;var f=0,g=0,h=0,i=0;f=(e[d+22>>1]|0)<<4;g=(c[2385310]|0)+28|0;h=b[g>>1]|0;b[g>>1]=h+1&65535;g=(h&65535)+f&1048575;f=c[3531864]|0;h=c[f+6188+(g>>>11<<2)>>2]|0;if((h|0)==0){i=gj[c[f+8236>>2]&4095](g)|0}else{i=a[h+g|0]|0}g=d+2|0;h=(b[g>>1]|0)-1&65535;b[g>>1]=h;if((c[d+44>>2]|0)!=0|h<<16>>16==0){h=d+84|0;c[h>>2]=(c[h>>2]|0)-(328963>>>((c[d+92>>2]|0)>>>0)&127);return}else{h=d+28|0;b[h>>1]=(b[h>>1]|0)+(i<<24>>24)&65535;i=d+84|0;c[i>>2]=(c[i>>2]|0)-(921094>>>((c[d+92>>2]|0)>>>0)&127);return}}function f8G(d){d=d|0;var f=0,g=0,h=0,i=0;f=(e[d+22>>1]|0)<<4;g=(c[2385310]|0)+28|0;h=b[g>>1]|0;b[g>>1]=h+1&65535;g=(h&65535)+f&1048575;f=c[3531864]|0;h=c[f+6188+(g>>>11<<2)>>2]|0;if((h|0)==0){i=gj[c[f+8236>>2]&4095](g)|0}else{i=a[h+g|0]|0}g=d+2|0;h=(b[g>>1]|0)-1&65535;b[g>>1]=h;if(h<<16>>16==0){h=d+84|0;c[h>>2]=(c[h>>2]|0)-(328963>>>((c[d+92>>2]|0)>>>0)&127);return}else{h=d+28|0;b[h>>1]=(b[h>>1]|0)+(i<<24>>24)&65535;i=d+84|0;c[i>>2]=(c[i>>2]|0)-(855302>>>((c[d+92>>2]|0)>>>0)&127);return}}function f8H(d){d=d|0;var f=0,g=0,h=0,i=0;f=e[d+22>>1]<<4;g=(c[2385310]|0)+28|0;h=b[g>>1]|0;b[g>>1]=h+1&65535;g=(h&65535)+f&1048575;f=c[3531864]|0;h=c[f+6188+(g>>>11<<2)>>2]|0;if((h|0)==0){i=gj[c[f+8236>>2]&4095](g)|0}else{i=a[h+g|0]|0}if((b[d+2>>1]|0)==0){g=d+28|0;b[g>>1]=(b[g>>1]|0)+(i<<24>>24)&65535;i=d+84|0;c[i>>2]=(c[i>>2]|0)-(855302>>>((c[d+92>>2]|0)>>>0)&127);return}else{i=d+84|0;c[i>>2]=(c[i>>2]|0)-(328963>>>((c[d+92>>2]|0)>>>0)&127);return}}function f8I(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=(e[d+22>>1]|0)<<4;g=(c[2385310]|0)+28|0;h=b[g>>1]|0;b[g>>1]=h+1&65535;g=(h&65535)+f&1048575;f=c[3531864]|0;h=c[f+6188+(g>>>11<<2)>>2]|0;if((h|0)==0){i=gj[c[f+8236>>2]&4095](g)|0;j=i;k=c[3531864]|0}else{j=a[h+g|0]|0;k=f}a[d]=gj[c[k+8244>>2]&4095](j&255)|0;j=d+84|0;c[j>>2]=(c[j>>2]|0)-(592133>>>((c[d+92>>2]|0)>>>0)&127);return}function f8J(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=(e[d+22>>1]|0)<<4;g=(c[2385310]|0)+28|0;h=b[g>>1]|0;b[g>>1]=h+1&65535;g=(h&65535)+f&1048575;f=c[3531864]|0;h=c[f+6188+(g>>>11<<2)>>2]|0;if((h|0)==0){i=gj[c[f+8236>>2]&4095](g)|0;j=i;k=c[3531864]|0}else{j=a[h+g|0]|0;k=f}f=j&255;j=(gj[c[k+8244>>2]&4095](f)|0)&255;b[d>>1]=((gj[c[(c[3531864]|0)+8244>>2]&4095](f+1&255)|0)&255)<<8|j;j=d+84|0;c[j>>2]=(c[j>>2]|0)-(((f&1|0)!=0?855303:854277)>>>((c[d+92>>2]|0)>>>0)&127);return}function f8K(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=(e[d+22>>1]|0)<<4;g=(c[2385310]|0)+28|0;h=b[g>>1]|0;b[g>>1]=h+1&65535;g=(h&65535)+f&1048575;f=c[3531864]|0;h=c[f+6188+(g>>>11<<2)>>2]|0;if((h|0)==0){i=gj[c[f+8236>>2]&4095](g)|0;j=i;k=c[3531864]|0}else{j=a[h+g|0]|0;k=f}gg[c[k+8248>>2]&4095](j&255,a[d]|0);j=d+84|0;c[j>>2]=(c[j>>2]|0)-(526339>>>((c[d+92>>2]|0)>>>0)&127);return}function f8L(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=(e[d+22>>1]|0)<<4;g=(c[2385310]|0)+28|0;h=b[g>>1]|0;b[g>>1]=h+1&65535;g=(h&65535)+f&1048575;f=c[3531864]|0;h=c[f+6188+(g>>>11<<2)>>2]|0;if((h|0)==0){i=gj[c[f+8236>>2]&4095](g)|0;j=i;k=c[3531864]|0}else{j=a[h+g|0]|0;k=f}f=j&255;j=b[d>>1]|0;gg[c[k+8248>>2]&4095](f,j&255);gg[c[(c[3531864]|0)+8248>>2]&4095](f+1|0,(j&65535)>>>8&255);j=d+84|0;c[j>>2]=(c[j>>2]|0)-(((f&1|0)!=0?789509:788483)>>>((c[d+92>>2]|0)>>>0)&127);return}function f8M(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;f=d+22|0;g=(e[f>>1]|0)<<4;h=c[2385310]|0;i=h+28|0;j=b[i>>1]|0;k=j+1&65535;b[i>>1]=k;i=(j&65535)+g&1048575;g=c[3531864]|0;j=c[g+6188+(i>>>11<<2)>>2]|0;if((j|0)==0){l=gj[c[g+8236>>2]&4095](i)|0;m=c[2385310]|0;n=l;o=m;p=b[m+28>>1]|0;q=c[3531864]|0}else{n=a[j+i|0]|0;o=h;p=k;q=g}g=(e[f>>1]|0)<<4;b[o+28>>1]=p+1&65535;o=(p&65535)+g&1048575;g=c[q+6188+(o>>>11<<2)>>2]|0;if((g|0)==0){p=gj[c[q+8236>>2]&4095](o)|0;r=p;s=c[3531864]|0}else{r=a[g+o|0]|0;s=q}q=(r&255)<<8|n&255;n=d+8|0;r=(b[n>>1]|0)-2&65535;b[n>>1]=r;n=((e[d+24>>1]|0)<<4)+(r&65535)|0;r=d+28|0;o=b[r>>1]|0;g=o&255;p=n&1048575;f=c[s+2092+(p>>>11<<2)>>2]|0;if((f|0)==0){gg[c[s+8240>>2]&4095](p,g);t=c[3531864]|0}else{a[f+p|0]=g;t=s}s=(o&65535)>>>8&255;o=n+1&1048575;n=c[t+2092+(o>>>11<<2)>>2]|0;if((n|0)==0){gg[c[t+8240>>2]&4095](o,s);u=b[r>>1]|0;v=u+q&65535;b[r>>1]=v;w=d+91|0;a[w]=1;x=d+84|0;y=c[x>>2]|0;z=y-24|0;c[x>>2]=z;return}else{a[n+o|0]=s;u=b[r>>1]|0;v=u+q&65535;b[r>>1]=v;w=d+91|0;a[w]=1;x=d+84|0;y=c[x>>2]|0;z=y-24|0;c[x>>2]=z;return}}function f8N(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=d+22|0;g=(e[f>>1]|0)<<4;h=c[2385310]|0;i=h+28|0;j=b[i>>1]|0;k=j+1&65535;b[i>>1]=k;i=(j&65535)+g&1048575;g=c[3531864]|0;j=c[g+6188+(i>>>11<<2)>>2]|0;if((j|0)==0){l=gj[c[g+8236>>2]&4095](i)|0;m=c[2385310]|0;n=l;o=m;p=b[m+28>>1]|0;q=c[3531864]|0}else{n=a[j+i|0]|0;o=h;p=k;q=g}g=(e[f>>1]|0)<<4;b[o+28>>1]=p+1&65535;o=(p&65535)+g&1048575;g=c[q+6188+(o>>>11<<2)>>2]|0;if((g|0)==0){r=gj[c[q+8236>>2]&4095](o)|0}else{r=a[g+o|0]|0}o=d+28|0;b[o>>1]=((r&255)<<8|n&255)+(b[o>>1]|0)&65535;a[d+91|0]=1;o=d+84|0;c[o>>2]=(c[o>>2]|0)-15;return}function f8O(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;f=d+22|0;g=(e[f>>1]|0)<<4;h=c[2385310]|0;i=h+28|0;j=b[i>>1]|0;k=j+1&65535;b[i>>1]=k;i=(j&65535)+g&1048575;g=c[3531864]|0;j=c[g+6188+(i>>>11<<2)>>2]|0;if((j|0)==0){l=gj[c[g+8236>>2]&4095](i)|0;m=c[2385310]|0;n=l;o=m;p=b[m+28>>1]|0;q=c[3531864]|0}else{n=a[j+i|0]|0;o=h;p=k;q=g}g=(e[f>>1]|0)<<4;k=p+1&65535;b[o+28>>1]=k;h=(p&65535)+g&1048575;g=c[q+6188+(h>>>11<<2)>>2]|0;if((g|0)==0){p=gj[c[q+8236>>2]&4095](h)|0;i=c[2385310]|0;r=p;s=i;t=b[i+28>>1]|0;u=c[3531864]|0}else{r=a[g+h|0]|0;s=o;t=k;u=q}q=(r&255)<<8|n&255;n=(e[f>>1]|0)<<4;r=t+1&65535;b[s+28>>1]=r;k=(t&65535)+n&1048575;n=c[u+6188+(k>>>11<<2)>>2]|0;if((n|0)==0){t=gj[c[u+8236>>2]&4095](k)|0;o=c[2385310]|0;v=t;w=o;x=b[o+28>>1]|0;y=c[3531864]|0}else{v=a[n+k|0]|0;w=s;x=r;y=u}u=v&255;v=(e[f>>1]|0)<<4;b[w+28>>1]=x+1&65535;w=(x&65535)+v&1048575;v=c[y+6188+(w>>>11<<2)>>2]|0;if((v|0)==0){z=gj[c[y+8236>>2]&4095](w)|0;A=z&255;B=A<<8;C=B|u;b[f>>1]=C;D=d+28|0;b[D>>1]=q;E=d+91|0;a[E]=1;F=d+84|0;G=c[F>>2]|0;H=G-27|0;c[F>>2]=H;return}else{z=a[v+w|0]|0;A=z&255;B=A<<8;C=B|u;b[f>>1]=C;D=d+28|0;b[D>>1]=q;E=d+91|0;a[E]=1;F=d+84|0;G=c[F>>2]|0;H=G-27|0;c[F>>2]=H;return}}function f8P(d){d=d|0;var f=0,g=0,h=0,i=0;f=(e[d+22>>1]|0)<<4;g=(c[2385310]|0)+28|0;h=b[g>>1]|0;b[g>>1]=h+1&65535;g=(h&65535)+f&1048575;f=c[3531864]|0;h=c[f+6188+(g>>>11<<2)>>2]|0;if((h|0)==0){i=gj[c[f+8236>>2]&4095](g)|0}else{i=a[h+g|0]|0}g=d+84|0;c[g>>2]=(c[g>>2]|0)-12;g=d+28|0;b[g>>1]=(b[g>>1]|0)+(i<<24>>24)&65535;return}function f8Q(d){d=d|0;var e=0;a[d]=gj[c[(c[3531864]|0)+8244>>2]&4095](b[d+4>>1]&255)|0;e=d+84|0;c[e>>2]=(c[e>>2]|0)-(526341>>>((c[d+92>>2]|0)>>>0)&127);return}function f8R(a){a=a|0;var d=0,f=0;d=a+4|0;f=(gj[c[(c[3531864]|0)+8244>>2]&4095](b[d>>1]&255)|0)&255;b[a>>1]=((gj[c[(c[3531864]|0)+8244>>2]&4095]((e[d>>1]|0)+1&65791)|0)&255)<<8|f;f=a+84|0;c[f>>2]=(c[f>>2]|0)-(((b[d>>1]&1)!=0?789511:788485)>>>((c[a+92>>2]|0)>>>0)&127);return}function f8S(b){b=b|0;var d=0;gg[c[(c[3531864]|0)+8248>>2]&4095](e[b+4>>1]|0,a[b]|0);d=b+84|0;c[d>>2]=(c[d>>2]|0)-(526339>>>((c[b+92>>2]|0)>>>0)&127);return}function f8T(a){a=a|0;var d=0,f=0,g=0;d=a+4|0;f=e[d>>1]|0;g=b[a>>1]|0;gg[c[(c[3531864]|0)+8248>>2]&4095](f,g&255);gg[c[(c[3531864]|0)+8248>>2]&4095](f+1|0,(g&65535)>>>8&255);g=a+84|0;c[g>>2]=(c[g>>2]|0)-(((b[d>>1]&1)!=0?789509:788483)>>>((c[a+92>>2]|0)>>>0)&127);return}function f8U(b){b=b|0;var d=0;a[b+80|0]=1;d=b+84|0;c[d>>2]=(c[d>>2]|0)-2;return}function f8V(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;g=f+90|0;a[g]=(a[g]|0)-1&255;h=f+22|0;i=e[h>>1]<<4;j=f+28|0;k=b[j>>1]|0;b[j>>1]=k+1&65535;l=f+16|0;m=(i+(k&65535)^c[l>>2])&1048575;k=c[3531864]|0;i=c[k+4140+(m>>>11<<2)>>2]|0;if((i|0)==0){n=gj[c[k+8236>>2]&4095](m)|0}else{n=a[i+m|0]|0}m=n&255;n=f+2|0;i=b[n>>1]|0;if((m|0)==46){a[f+100|0]=1;k=e[h>>1]<<4;c[f+96>>2]=k;a[g]=(a[g]|0)-1&255;o=b[j>>1]|0;b[j>>1]=o+1&65535;p=((o&65535)+k^c[l>>2])&1048575;k=c[3531864]|0;o=c[k+4140+(p>>>11<<2)>>2]|0;if((o|0)==0){q=gj[c[k+8236>>2]&4095](p)|0}else{q=a[o+p|0]|0}p=f+84|0;c[p>>2]=(c[p>>2]|0)-2;r=q&255}else if((m|0)==62){a[f+100|0]=1;c[f+96>>2]=e[f+26>>1]<<4;a[g]=(a[g]|0)-1&255;q=e[h>>1]<<4;p=b[j>>1]|0;b[j>>1]=p+1&65535;o=(q+(p&65535)^c[l>>2])&1048575;p=c[3531864]|0;q=c[p+4140+(o>>>11<<2)>>2]|0;if((q|0)==0){s=gj[c[p+8236>>2]&4095](o)|0}else{s=a[q+o|0]|0}o=f+84|0;c[o>>2]=(c[o>>2]|0)-2;r=s&255}else if((m|0)==54){a[f+100|0]=1;c[f+96>>2]=e[f+24>>1]<<4;a[g]=(a[g]|0)-1&255;s=e[h>>1]<<4;o=b[j>>1]|0;b[j>>1]=o+1&65535;q=(s+(o&65535)^c[l>>2])&1048575;o=c[3531864]|0;s=c[o+4140+(q>>>11<<2)>>2]|0;if((s|0)==0){t=gj[c[o+8236>>2]&4095](q)|0}else{t=a[s+q|0]|0}q=f+84|0;c[q>>2]=(c[q>>2]|0)-2;r=t&255}else if((m|0)==38){a[f+100|0]=1;c[f+96>>2]=e[f+20>>1]<<4;a[g]=(a[g]|0)-1&255;g=e[h>>1]<<4;h=b[j>>1]|0;b[j>>1]=h+1&65535;j=(g+(h&65535)^c[l>>2])&1048575;l=c[3531864]|0;h=c[l+4140+(j>>>11<<2)>>2]|0;if((h|0)==0){u=gj[c[l+8236>>2]&4095](j)|0}else{u=a[h+j|0]|0}j=f+84|0;c[j>>2]=(c[j>>2]|0)-2;r=u&255}else{r=m}switch(r|0){case 108:{m=f+84|0;c[m>>2]=(c[m>>2]|0)-2;if(i<<16>>16!=0){u=f+20|0;j=f+14|0;h=f+4|0;l=f+58|0;g=i;t=b[j>>1]|0;do{q=(e[u>>1]<<4)+(t&65535)|0;s=gj[c[(c[3531864]|0)+8244>>2]&4095](b[h>>1]&255)|0;o=q&1048575;q=c[3531864]|0;p=c[q+2092+(o>>>11<<2)>>2]|0;if((p|0)==0){gg[c[q+8240>>2]&4095](o,s)}else{a[p+o|0]=s}t=((d[l]|0)*-2&65535|1)+(b[j>>1]|0)&65535;b[j>>1]=t;c[m>>2]=(c[m>>2]|0)-8;g=g-1&65535;}while(g<<16>>16!=0)}b[n>>1]=0;v=f+100|0;a[v]=0;return};case 109:{g=f+84|0;c[g>>2]=(c[g>>2]|0)-2;if(i<<16>>16!=0){m=f+20|0;t=f+14|0;j=f+4|0;l=f+58|0;h=f+92|0;u=i;s=b[t>>1]|0;do{o=(e[m>>1]<<4)+(s&65535)|0;p=gj[c[(c[3531864]|0)+8244>>2]&4095](b[j>>1]&255)|0;q=gj[c[(c[3531864]|0)+8244>>2]&4095]((e[j>>1]|0)+1&65791)|0;k=o&1048575;w=c[3531864]|0;x=c[w+2092+(k>>>11<<2)>>2]|0;if((x|0)==0){gg[c[w+8240>>2]&4095](k,p);y=c[3531864]|0}else{a[x+k|0]=p;y=w}w=o+1&1048575;o=c[y+2092+(w>>>11<<2)>>2]|0;if((o|0)==0){gg[c[y+8240>>2]&4095](w,q)}else{a[o+w|0]=q}s=((d[l]|0)*-4&65535|2)+(b[t>>1]|0)&65535;b[t>>1]=s;c[g>>2]=(c[g>>2]|0)-(1182216>>>((c[h>>2]|0)>>>0)&127);u=u-1&65535;}while(u<<16>>16!=0)}b[n>>1]=0;v=f+100|0;a[v]=0;return};case 110:{u=f+84|0;c[u>>2]=(c[u>>2]|0)-2;if(i<<16>>16!=0){h=f+4|0;g=f+100|0;s=f+26|0;t=f+12|0;l=f+58|0;y=f+96|0;j=i;do{m=e[h>>1]|0;if((a[g]|0)==0){z=e[s>>1]<<4}else{z=c[y>>2]|0}q=(e[t>>1]|0)+z&1048575;w=c[3531864]|0;o=c[w+44+(q>>>11<<2)>>2]|0;if((o|0)==0){p=gj[c[w+8236>>2]&4095](q)|0;A=p;B=c[3531864]|0}else{A=a[o+q|0]|0;B=w}gg[c[B+8248>>2]&4095](m,A);b[t>>1]=((d[l]|0)*-2&65535|1)+(b[t>>1]|0)&65535;c[u>>2]=(c[u>>2]|0)-8;j=j-1&65535;}while(j<<16>>16!=0)}b[n>>1]=0;v=f+100|0;a[v]=0;return};case 111:{j=f+84|0;c[j>>2]=(c[j>>2]|0)-2;if(i<<16>>16!=0){j=i;do{f6_(f);j=j-1&65535;}while(j<<16>>16!=0)}b[n>>1]=0;v=f+100|0;a[v]=0;return};case 164:{j=f+84|0;c[j>>2]=(c[j>>2]|0)-2;if(i<<16>>16!=0){u=f+100|0;t=f+26|0;l=f+12|0;A=f+20|0;B=f+14|0;z=f+58|0;y=f+92|0;s=f+96|0;g=i;do{if((a[u]|0)==0){C=e[t>>1]<<4}else{C=c[s>>2]|0}h=(e[l>>1]|0)+C&1048575;m=c[3531864]|0;w=c[m+44+(h>>>11<<2)>>2]|0;if((w|0)==0){q=gj[c[m+8236>>2]&4095](h)|0;D=q;E=c[3531864]|0}else{D=a[w+h|0]|0;E=m}m=(e[A>>1]<<4)+(e[B>>1]|0)&1048575;h=c[E+2092+(m>>>11<<2)>>2]|0;if((h|0)==0){gg[c[E+8240>>2]&4095](m,D)}else{a[h+m|0]=D}m=(d[z]|0)*-2&65535|1;b[B>>1]=m+(b[B>>1]|0)&65535;b[l>>1]=m+(b[l>>1]|0)&65535;c[j>>2]=(c[j>>2]|0)-(526342>>>((c[y>>2]|0)>>>0)&127);g=g-1&65535;}while(g<<16>>16!=0)}b[n>>1]=0;v=f+100|0;a[v]=0;return};case 165:{g=f+84|0;c[g>>2]=(c[g>>2]|0)-2;if(i<<16>>16!=0){g=i;do{f7Q(f);g=g-1&65535;}while(g<<16>>16!=0)}b[n>>1]=0;v=f+100|0;a[v]=0;return};case 166:{g=f+84|0;c[g>>2]=(c[g>>2]|0)-2;L59455:do{if(i<<16>>16==0){F=0}else{g=f+44|0;y=i;while(1){f7R(f);j=y-1&65535;if(j<<16>>16==0){F=0;break L59455}if((c[g>>2]|0)==0){F=j;break}else{y=j}}}}while(0);b[n>>1]=F;v=f+100|0;a[v]=0;return};case 167:{F=f+84|0;c[F>>2]=(c[F>>2]|0)-2;L59463:do{if(i<<16>>16==0){G=0}else{F=f+44|0;y=i;while(1){f7S(f);g=y-1&65535;if(g<<16>>16==0){G=0;break L59463}if((c[F>>2]|0)==0){G=g;break}else{y=g}}}}while(0);b[n>>1]=G;v=f+100|0;a[v]=0;return};case 170:{G=f+84|0;c[G>>2]=(c[G>>2]|0)-2;if(i<<16>>16!=0){y=f+20|0;F=f+14|0;g=f;j=f+58|0;l=f+92|0;B=i;z=b[F>>1]|0;do{D=a[g]|0;E=(e[y>>1]<<4)+(z&65535)&1048575;A=c[3531864]|0;C=c[A+2092+(E>>>11<<2)>>2]|0;if((C|0)==0){gg[c[A+8240>>2]&4095](E,D)}else{a[C+E|0]=D}z=((d[j]|0)*-2&65535|1)+(b[F>>1]|0)&65535;b[F>>1]=z;c[G>>2]=(c[G>>2]|0)-(263171>>>((c[l>>2]|0)>>>0)&127);B=B-1&65535;}while(B<<16>>16!=0)}b[n>>1]=0;v=f+100|0;a[v]=0;return};case 171:{B=f+84|0;c[B>>2]=(c[B>>2]|0)-2;if(i<<16>>16!=0){l=f+20|0;G=f+14|0;z=f|0;F=f+58|0;j=f+92|0;y=i;g=b[G>>1]|0;do{D=(e[l>>1]<<4)+(g&65535)|0;E=b[z>>1]|0;C=E&255;A=D&1048575;s=c[3531864]|0;t=c[s+2092+(A>>>11<<2)>>2]|0;if((t|0)==0){gg[c[s+8240>>2]&4095](A,C);H=c[3531864]|0}else{a[t+A|0]=C;H=s}s=(E&65535)>>>8&255;E=D+1&1048575;D=c[H+2092+(E>>>11<<2)>>2]|0;if((D|0)==0){gg[c[H+8240>>2]&4095](E,s)}else{a[D+E|0]=s}s=(d[F]|0)*-4&65535;E=b[G>>1]|0;g=(s|2)+E&65535;b[G>>1]=g;c[B>>2]=(c[B>>2]|0)-(((s+E&1)!=0?526341:525315)>>>((c[j>>2]|0)>>>0)&127);y=y-1&65535;}while(y<<16>>16!=0)}b[n>>1]=0;v=f+100|0;a[v]=0;return};case 172:{y=f+84|0;j=(c[y>>2]|0)-2|0;c[y>>2]=j;if(i<<16>>16!=0){B=f+100|0;g=f+26|0;G=f+12|0;F=f;H=f+58|0;z=f+92|0;l=f+96|0;E=i;s=j;do{if((a[B]|0)==0){I=e[g>>1]<<4}else{I=c[l>>2]|0}j=b[G>>1]|0;D=(j&65535)+I&1048575;C=c[3531864]|0;A=c[C+44+(D>>>11<<2)>>2]|0;if((A|0)==0){t=gj[c[C+8236>>2]&4095](D)|0;J=t;K=b[G>>1]|0;L=c[y>>2]|0}else{J=a[A+D|0]|0;K=j;L=s}a[F]=J;b[G>>1]=((d[H]|0)*-2&65535|1)+K&65535;s=L-(263171>>>((c[z>>2]|0)>>>0)&127)|0;c[y>>2]=s;E=E-1&65535;}while(E<<16>>16!=0)}b[n>>1]=0;v=f+100|0;a[v]=0;return};case 173:{E=f+84|0;c[E>>2]=(c[E>>2]|0)-2;if(i<<16>>16!=0){E=i;do{f7Y(f);E=E-1&65535;}while(E<<16>>16!=0)}b[n>>1]=0;v=f+100|0;a[v]=0;return};case 174:{E=f+84|0;s=(c[E>>2]|0)-2|0;c[E>>2]=s;L59518:do{if(i<<16>>16==0){M=0}else{y=f+20|0;z=f+14|0;L=f;K=f+48|0;H=f+40|0;G=f+36|0;J=f+52|0;F=f+44|0;I=f+32|0;l=f+58|0;g=f+92|0;B=i;j=b[z>>1]|0;D=s;while(1){A=(e[y>>1]<<4)+(j&65535)&1048575;t=c[3531864]|0;C=c[t+44+(A>>>11<<2)>>2]|0;if((C|0)==0){u=gj[c[t+8236>>2]&4095](A)|0;N=u;O=b[z>>1]|0;P=c[E>>2]|0}else{N=a[C+A|0]|0;O=j;P=D}A=a[L]|0;C=A&255;u=C-(N&255)|0;c[K>>2]=u&256;t=(A^N)&255;c[H>>2]=t&128&(u^C);c[G>>2]=(u^t)&16;t=u<<24>>24;c[J>>2]=t;c[F>>2]=t;c[I>>2]=t;u=((d[l]|0)*-2&65535|1)+O&65535;b[z>>1]=u;C=P-(263171>>>((c[g>>2]|0)>>>0)&127)|0;c[E>>2]=C;A=B-1&65535;if(A<<16>>16==0){M=0;break L59518}if((t|0)==0){M=A;break}else{B=A;j=u;D=C}}}}while(0);b[n>>1]=M;v=f+100|0;a[v]=0;return};case 175:{M=f+84|0;c[M>>2]=(c[M>>2]|0)-2;L59530:do{if(i<<16>>16==0){Q=0}else{E=f+20|0;P=f+14|0;O=f|0;N=f+48|0;s=f+40|0;D=f+36|0;j=f+52|0;B=f+44|0;g=f+32|0;z=f+58|0;l=f+92|0;I=i;F=b[P>>1]|0;while(1){J=b[E>>1]|0;G=((J&65535)<<4)+(F&65535)&1048575;H=c[3531864]|0;K=c[H+44+(G>>>11<<2)>>2]|0;if((K|0)==0){L=gj[c[H+8236>>2]&4095](G)|0;R=L;S=b[E>>1]|0;T=b[P>>1]|0;U=c[3531864]|0}else{R=a[K+G|0]|0;S=J;T=F;U=H}H=(T&65535)+1+((S&65535)<<4)&1048575;J=c[U+44+(H>>>11<<2)>>2]|0;if((J|0)==0){G=gj[c[U+8236>>2]&4095](H)|0;V=G;W=b[P>>1]|0}else{V=a[J+H|0]|0;W=T}H=(V&255)<<8|R&255;J=e[O>>1]|0;G=J-H|0;c[N>>2]=G&65536;K=H^J;c[s>>2]=K&32768&(G^J);c[D>>2]=(G^K)&16;K=G<<16>>16;c[j>>2]=K;c[B>>2]=K;c[g>>2]=K;G=(d[z]|0)*-4&65535;J=(G|2)+W&65535;b[P>>1]=J;c[M>>2]=(c[M>>2]|0)-(((G+W&1)!=0?526341:525315)>>>((c[l>>2]|0)>>>0)&127);G=I-1&65535;if(G<<16>>16==0){Q=0;break L59530}if((K|0)==0){Q=G;break}else{I=G;F=J}}}}while(0);b[n>>1]=Q;v=f+100|0;a[v]=0;return};default:{gf[c[2520528+(r<<2)>>2]&2047](f);v=f+100|0;a[v]=0;return}}}function f8W(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;g=f+90|0;a[g]=(a[g]|0)-1&255;h=f+22|0;i=e[h>>1]<<4;j=f+28|0;k=b[j>>1]|0;b[j>>1]=k+1&65535;l=f+16|0;m=(i+(k&65535)^c[l>>2])&1048575;k=c[3531864]|0;i=c[k+4140+(m>>>11<<2)>>2]|0;if((i|0)==0){n=gj[c[k+8236>>2]&4095](m)|0}else{n=a[i+m|0]|0}m=n&255;n=f+2|0;i=b[n>>1]|0;if((m|0)==54){a[f+100|0]=1;c[f+96>>2]=e[f+24>>1]<<4;a[g]=(a[g]|0)-1&255;k=e[h>>1]<<4;o=b[j>>1]|0;b[j>>1]=o+1&65535;p=(k+(o&65535)^c[l>>2])&1048575;o=c[3531864]|0;k=c[o+4140+(p>>>11<<2)>>2]|0;if((k|0)==0){q=gj[c[o+8236>>2]&4095](p)|0}else{q=a[k+p|0]|0}p=f+84|0;c[p>>2]=(c[p>>2]|0)-2;r=q&255}else if((m|0)==46){a[f+100|0]=1;q=e[h>>1]<<4;c[f+96>>2]=q;a[g]=(a[g]|0)-1&255;p=b[j>>1]|0;b[j>>1]=p+1&65535;k=((p&65535)+q^c[l>>2])&1048575;q=c[3531864]|0;p=c[q+4140+(k>>>11<<2)>>2]|0;if((p|0)==0){s=gj[c[q+8236>>2]&4095](k)|0}else{s=a[p+k|0]|0}k=f+84|0;c[k>>2]=(c[k>>2]|0)-2;r=s&255}else if((m|0)==62){a[f+100|0]=1;c[f+96>>2]=e[f+26>>1]<<4;a[g]=(a[g]|0)-1&255;s=e[h>>1]<<4;k=b[j>>1]|0;b[j>>1]=k+1&65535;p=(s+(k&65535)^c[l>>2])&1048575;k=c[3531864]|0;s=c[k+4140+(p>>>11<<2)>>2]|0;if((s|0)==0){t=gj[c[k+8236>>2]&4095](p)|0}else{t=a[s+p|0]|0}p=f+84|0;c[p>>2]=(c[p>>2]|0)-2;r=t&255}else if((m|0)==38){a[f+100|0]=1;c[f+96>>2]=e[f+20>>1]<<4;a[g]=(a[g]|0)-1&255;g=e[h>>1]<<4;h=b[j>>1]|0;b[j>>1]=h+1&65535;j=(g+(h&65535)^c[l>>2])&1048575;l=c[3531864]|0;h=c[l+4140+(j>>>11<<2)>>2]|0;if((h|0)==0){u=gj[c[l+8236>>2]&4095](j)|0}else{u=a[h+j|0]|0}j=f+84|0;c[j>>2]=(c[j>>2]|0)-2;r=u&255}else{r=m}switch(r|0){case 108:{m=f+84|0;c[m>>2]=(c[m>>2]|0)-2;if(i<<16>>16!=0){u=f+20|0;j=f+14|0;h=f+4|0;l=f+58|0;g=i;t=b[j>>1]|0;do{p=(e[u>>1]<<4)+(t&65535)|0;s=gj[c[(c[3531864]|0)+8244>>2]&4095](b[h>>1]&255)|0;k=p&1048575;p=c[3531864]|0;q=c[p+2092+(k>>>11<<2)>>2]|0;if((q|0)==0){gg[c[p+8240>>2]&4095](k,s)}else{a[q+k|0]=s}t=((d[l]|0)*-2&65535|1)+(b[j>>1]|0)&65535;b[j>>1]=t;c[m>>2]=(c[m>>2]|0)-8;g=g-1&65535;}while(g<<16>>16!=0)}b[n>>1]=0;v=f+100|0;a[v]=0;return};case 109:{g=f+84|0;c[g>>2]=(c[g>>2]|0)-2;if(i<<16>>16!=0){m=f+20|0;t=f+14|0;j=f+4|0;l=f+58|0;h=f+92|0;u=i;s=b[t>>1]|0;do{k=(e[m>>1]<<4)+(s&65535)|0;q=gj[c[(c[3531864]|0)+8244>>2]&4095](b[j>>1]&255)|0;p=gj[c[(c[3531864]|0)+8244>>2]&4095]((e[j>>1]|0)+1&65791)|0;o=k&1048575;w=c[3531864]|0;x=c[w+2092+(o>>>11<<2)>>2]|0;if((x|0)==0){gg[c[w+8240>>2]&4095](o,q);y=c[3531864]|0}else{a[x+o|0]=q;y=w}w=k+1&1048575;k=c[y+2092+(w>>>11<<2)>>2]|0;if((k|0)==0){gg[c[y+8240>>2]&4095](w,p)}else{a[k+w|0]=p}s=((d[l]|0)*-4&65535|2)+(b[t>>1]|0)&65535;b[t>>1]=s;c[g>>2]=(c[g>>2]|0)-(1182216>>>((c[h>>2]|0)>>>0)&127);u=u-1&65535;}while(u<<16>>16!=0)}b[n>>1]=0;v=f+100|0;a[v]=0;return};case 110:{u=f+84|0;c[u>>2]=(c[u>>2]|0)-2;if(i<<16>>16!=0){h=f+4|0;g=f+100|0;s=f+26|0;t=f+12|0;l=f+58|0;y=f+96|0;j=i;do{m=e[h>>1]|0;if((a[g]|0)==0){z=e[s>>1]<<4}else{z=c[y>>2]|0}p=(e[t>>1]|0)+z&1048575;w=c[3531864]|0;k=c[w+44+(p>>>11<<2)>>2]|0;if((k|0)==0){q=gj[c[w+8236>>2]&4095](p)|0;A=q;B=c[3531864]|0}else{A=a[k+p|0]|0;B=w}gg[c[B+8248>>2]&4095](m,A);b[t>>1]=((d[l]|0)*-2&65535|1)+(b[t>>1]|0)&65535;c[u>>2]=(c[u>>2]|0)-8;j=j-1&65535;}while(j<<16>>16!=0)}b[n>>1]=0;v=f+100|0;a[v]=0;return};case 111:{j=f+84|0;c[j>>2]=(c[j>>2]|0)-2;if(i<<16>>16!=0){j=i;do{f6_(f);j=j-1&65535;}while(j<<16>>16!=0)}b[n>>1]=0;v=f+100|0;a[v]=0;return};case 164:{j=f+84|0;c[j>>2]=(c[j>>2]|0)-2;if(i<<16>>16!=0){u=f+100|0;t=f+26|0;l=f+12|0;A=f+20|0;B=f+14|0;z=f+58|0;y=f+92|0;s=f+96|0;g=i;do{if((a[u]|0)==0){C=e[t>>1]<<4}else{C=c[s>>2]|0}h=(e[l>>1]|0)+C&1048575;m=c[3531864]|0;w=c[m+44+(h>>>11<<2)>>2]|0;if((w|0)==0){p=gj[c[m+8236>>2]&4095](h)|0;D=p;E=c[3531864]|0}else{D=a[w+h|0]|0;E=m}m=(e[A>>1]<<4)+(e[B>>1]|0)&1048575;h=c[E+2092+(m>>>11<<2)>>2]|0;if((h|0)==0){gg[c[E+8240>>2]&4095](m,D)}else{a[h+m|0]=D}m=(d[z]|0)*-2&65535|1;b[B>>1]=m+(b[B>>1]|0)&65535;b[l>>1]=m+(b[l>>1]|0)&65535;c[j>>2]=(c[j>>2]|0)-(526342>>>((c[y>>2]|0)>>>0)&127);g=g-1&65535;}while(g<<16>>16!=0)}b[n>>1]=0;v=f+100|0;a[v]=0;return};case 165:{g=f+84|0;c[g>>2]=(c[g>>2]|0)-2;if(i<<16>>16!=0){g=i;do{f7Q(f);g=g-1&65535;}while(g<<16>>16!=0)}b[n>>1]=0;v=f+100|0;a[v]=0;return};case 166:{g=f+84|0;c[g>>2]=(c[g>>2]|0)-2;L59648:do{if(i<<16>>16==0){F=0}else{g=f+44|0;y=i;while(1){f7R(f);j=y-1&65535;if(j<<16>>16==0){F=0;break L59648}if((c[g>>2]|0)==0){y=j}else{F=j;break}}}}while(0);b[n>>1]=F;v=f+100|0;a[v]=0;return};case 167:{F=f+84|0;c[F>>2]=(c[F>>2]|0)-2;L59656:do{if(i<<16>>16==0){G=0}else{F=f+44|0;y=i;while(1){f7S(f);g=y-1&65535;if(g<<16>>16==0){G=0;break L59656}if((c[F>>2]|0)==0){y=g}else{G=g;break}}}}while(0);b[n>>1]=G;v=f+100|0;a[v]=0;return};case 170:{G=f+84|0;c[G>>2]=(c[G>>2]|0)-2;if(i<<16>>16!=0){y=f+20|0;F=f+14|0;g=f;j=f+58|0;l=f+92|0;B=i;z=b[F>>1]|0;do{D=a[g]|0;E=(e[y>>1]<<4)+(z&65535)&1048575;A=c[3531864]|0;C=c[A+2092+(E>>>11<<2)>>2]|0;if((C|0)==0){gg[c[A+8240>>2]&4095](E,D)}else{a[C+E|0]=D}z=((d[j]|0)*-2&65535|1)+(b[F>>1]|0)&65535;b[F>>1]=z;c[G>>2]=(c[G>>2]|0)-(263171>>>((c[l>>2]|0)>>>0)&127);B=B-1&65535;}while(B<<16>>16!=0)}b[n>>1]=0;v=f+100|0;a[v]=0;return};case 171:{B=f+84|0;c[B>>2]=(c[B>>2]|0)-2;if(i<<16>>16!=0){l=f+20|0;G=f+14|0;z=f|0;F=f+58|0;j=f+92|0;y=i;g=b[G>>1]|0;do{D=(e[l>>1]<<4)+(g&65535)|0;E=b[z>>1]|0;C=E&255;A=D&1048575;s=c[3531864]|0;t=c[s+2092+(A>>>11<<2)>>2]|0;if((t|0)==0){gg[c[s+8240>>2]&4095](A,C);H=c[3531864]|0}else{a[t+A|0]=C;H=s}s=(E&65535)>>>8&255;E=D+1&1048575;D=c[H+2092+(E>>>11<<2)>>2]|0;if((D|0)==0){gg[c[H+8240>>2]&4095](E,s)}else{a[D+E|0]=s}s=(d[F]|0)*-4&65535;E=b[G>>1]|0;g=(s|2)+E&65535;b[G>>1]=g;c[B>>2]=(c[B>>2]|0)-(((s+E&1)!=0?526341:525315)>>>((c[j>>2]|0)>>>0)&127);y=y-1&65535;}while(y<<16>>16!=0)}b[n>>1]=0;v=f+100|0;a[v]=0;return};case 172:{y=f+84|0;j=(c[y>>2]|0)-2|0;c[y>>2]=j;if(i<<16>>16!=0){B=f+100|0;g=f+26|0;G=f+12|0;F=f;H=f+58|0;z=f+92|0;l=f+96|0;E=i;s=j;do{if((a[B]|0)==0){I=e[g>>1]<<4}else{I=c[l>>2]|0}j=b[G>>1]|0;D=(j&65535)+I&1048575;C=c[3531864]|0;A=c[C+44+(D>>>11<<2)>>2]|0;if((A|0)==0){t=gj[c[C+8236>>2]&4095](D)|0;J=t;K=b[G>>1]|0;L=c[y>>2]|0}else{J=a[A+D|0]|0;K=j;L=s}a[F]=J;b[G>>1]=((d[H]|0)*-2&65535|1)+K&65535;s=L-(263171>>>((c[z>>2]|0)>>>0)&127)|0;c[y>>2]=s;E=E-1&65535;}while(E<<16>>16!=0)}b[n>>1]=0;v=f+100|0;a[v]=0;return};case 173:{E=f+84|0;c[E>>2]=(c[E>>2]|0)-2;if(i<<16>>16!=0){E=i;do{f7Y(f);E=E-1&65535;}while(E<<16>>16!=0)}b[n>>1]=0;v=f+100|0;a[v]=0;return};case 174:{E=f+84|0;s=(c[E>>2]|0)-2|0;c[E>>2]=s;L59711:do{if(i<<16>>16==0){M=0}else{y=f+20|0;z=f+14|0;L=f;K=f+48|0;H=f+40|0;G=f+36|0;J=f+52|0;F=f+44|0;I=f+32|0;l=f+58|0;g=f+92|0;B=i;j=b[z>>1]|0;D=s;while(1){A=(e[y>>1]<<4)+(j&65535)&1048575;t=c[3531864]|0;C=c[t+44+(A>>>11<<2)>>2]|0;if((C|0)==0){u=gj[c[t+8236>>2]&4095](A)|0;N=u;O=b[z>>1]|0;P=c[E>>2]|0}else{N=a[C+A|0]|0;O=j;P=D}A=a[L]|0;C=A&255;u=C-(N&255)|0;c[K>>2]=u&256;t=(A^N)&255;c[H>>2]=t&128&(u^C);c[G>>2]=(u^t)&16;t=u<<24>>24;c[J>>2]=t;c[F>>2]=t;c[I>>2]=t;u=((d[l]|0)*-2&65535|1)+O&65535;b[z>>1]=u;C=P-(263171>>>((c[g>>2]|0)>>>0)&127)|0;c[E>>2]=C;A=B-1&65535;if(A<<16>>16==0){M=0;break L59711}if((t|0)==0){B=A;j=u;D=C}else{M=A;break}}}}while(0);b[n>>1]=M;v=f+100|0;a[v]=0;return};case 175:{M=f+84|0;c[M>>2]=(c[M>>2]|0)-2;L59723:do{if(i<<16>>16==0){Q=0}else{E=f+20|0;P=f+14|0;O=f|0;N=f+48|0;s=f+40|0;D=f+36|0;j=f+52|0;B=f+44|0;g=f+32|0;z=f+58|0;l=f+92|0;I=i;F=b[P>>1]|0;while(1){J=b[E>>1]|0;G=((J&65535)<<4)+(F&65535)&1048575;H=c[3531864]|0;K=c[H+44+(G>>>11<<2)>>2]|0;if((K|0)==0){L=gj[c[H+8236>>2]&4095](G)|0;R=L;S=b[E>>1]|0;T=b[P>>1]|0;U=c[3531864]|0}else{R=a[K+G|0]|0;S=J;T=F;U=H}H=(T&65535)+1+((S&65535)<<4)&1048575;J=c[U+44+(H>>>11<<2)>>2]|0;if((J|0)==0){G=gj[c[U+8236>>2]&4095](H)|0;V=G;W=b[P>>1]|0}else{V=a[J+H|0]|0;W=T}H=(V&255)<<8|R&255;J=e[O>>1]|0;G=J-H|0;c[N>>2]=G&65536;K=H^J;c[s>>2]=K&32768&(G^J);c[D>>2]=(G^K)&16;K=G<<16>>16;c[j>>2]=K;c[B>>2]=K;c[g>>2]=K;G=(d[z]|0)*-4&65535;J=(G|2)+W&65535;b[P>>1]=J;c[M>>2]=(c[M>>2]|0)-(((G+W&1)!=0?526341:525315)>>>((c[l>>2]|0)>>>0)&127);G=I-1&65535;if(G<<16>>16==0){Q=0;break L59723}if((K|0)==0){I=G;F=J}else{Q=G;break}}}}while(0);b[n>>1]=Q;v=f+100|0;a[v]=0;return};default:{gf[c[2520528+(r<<2)>>2]&2047](f);v=f+100|0;a[v]=0;return}}}function f8X(b){b=b|0;a[b+81|0]=1;c[b+84>>2]=0;return}function f8Y(a){a=a|0;var b=0;b=a+48|0;c[b>>2]=(c[b>>2]|0)==0;b=a+84|0;c[b>>2]=(c[b>>2]|0)-2;return}function f8Z(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=f+22|0;h=e[g>>1]<<4;i=(c[2385310]|0)+28|0;j=b[i>>1]|0;b[i>>1]=j+1&65535;i=(j&65535)+h&1048575;h=c[3531864]|0;j=c[h+6188+(i>>>11<<2)>>2]|0;if((j|0)==0){k=gj[c[h+8236>>2]&4095](i)|0}else{k=a[j+i|0]|0}i=k&255;j=(k&255)>191;do{if(j){l=a[f+(c[9648736+(i<<2)>>2]|0)|0]|0}else{k=(gj[c[679712+(i<<2)>>2]&4095](f)|0)&1048575;h=c[3531864]|0;m=c[h+44+(k>>>11<<2)>>2]|0;if((m|0)==0){l=gj[c[h+8236>>2]&4095](k)|0;break}else{l=a[m+k|0]|0;break}}}while(0);k=l&255;switch(i&56|0){case 0:{m=e[g>>1]<<4;g=(c[2385310]|0)+28|0;h=b[g>>1]|0;b[g>>1]=h+1&65535;g=(h&65535)+m&1048575;m=c[3531864]|0;h=c[m+6188+(g>>>11<<2)>>2]|0;if((h|0)==0){n=gj[c[m+8236>>2]&4095](g)|0}else{n=a[h+g|0]|0}c[f+40>>2]=0;c[f+48>>2]=0;g=(n&l)<<24>>24;c[f+52>>2]=g;c[f+44>>2]=g;c[f+32>>2]=g;g=f+84|0;c[g>>2]=(c[g>>2]|0)-(j?4:11);return};case 16:{do{if(j){a[f+(c[9648736+(i<<2)>>2]|0)|0]=~l}else{g=~l;n=c[2426956]&1048575;h=c[3531864]|0;m=c[h+2092+(n>>>11<<2)>>2]|0;if((m|0)==0){gg[c[h+8240>>2]&4095](n,g);break}else{a[m+n|0]=g;break}}}while(0);g=f+84|0;c[g>>2]=(c[g>>2]|0)-(j?2:16);return};case 24:{c[f+48>>2]=l<<24>>24!=0;g=-k|0;n=g<<24>>24;c[f+52>>2]=n;c[f+44>>2]=n;c[f+32>>2]=n;do{if(j){a[f+(c[9648736+(i<<2)>>2]|0)|0]=g&255}else{n=g&255;m=c[2426956]&1048575;h=c[3531864]|0;o=c[h+2092+(m>>>11<<2)>>2]|0;if((o|0)==0){gg[c[h+8240>>2]&4095](m,n);break}else{a[o+m|0]=n;break}}}while(0);g=f+84|0;c[g>>2]=(c[g>>2]|0)-(j?2:16);return};case 32:{g=(ag(d[f]|0,k)|0)&65535;b[f>>1]=g;i=(g&65535)>255|0;c[f+40>>2]=i;c[f+48>>2]=i;i=f+84|0;c[i>>2]=(c[i>>2]|0)-(j?30:36);return};case 40:{i=ag(a[f]|0,l<<24>>24)|0;b[f>>1]=i;g=(i&65535)>255|0;c[f+40>>2]=g;c[f+48>>2]=g;g=f+84|0;c[g>>2]=(c[g>>2]|0)-(j?30:36);return};case 48:{do{if(l<<24>>24==0){f9v(f,0,0)}else{g=e[f>>1]|0;i=(g>>>0)/(k>>>0)|0;if(i>>>0<=255){a[f]=i&255;a[f+1|0]=((g>>>0)%(k>>>0)|0)&255;break}f9v(f,0,0);return}}while(0);k=f+84|0;c[k>>2]=(c[k>>2]|0)-(j?43:53);return};case 56:{do{if(l<<24>>24==0){f9v(f,0,0)}else{k=b[f>>1]|0;g=l<<24>>24;i=(k|0)/(g|0)|0;if((i|0)<=255){a[f]=i&255;a[f+1|0]=((k|0)%(g|0)|0)&255;break}f9v(f,0,0);return}}while(0);l=f+84|0;c[l>>2]=(c[l>>2]|0)-(j?43:53);return};default:{return}}}function f8_(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;f=d+22|0;g=e[f>>1]<<4;h=(c[2385310]|0)+28|0;i=b[h>>1]|0;b[h>>1]=i+1&65535;h=(i&65535)+g&1048575;g=c[3531864]|0;i=c[g+6188+(h>>>11<<2)>>2]|0;if((i|0)==0){j=gj[c[g+8236>>2]&4095](h)|0}else{j=a[i+h|0]|0}h=j&255;i=(j&255)>191;if(i){k=e[d+(c[9650784+(h<<2)>>2]<<1)>>1]|0}else{j=c[679712+(h<<2)>>2]|0;gj[j&4095](d)|0;j=c[2426956]|0;g=j&1048575;l=c[3531864]|0;m=c[l+44+(g>>>11<<2)>>2]|0;if((m|0)==0){n=gj[c[l+8236>>2]&4095](g)|0;o=n;p=c[2426956]|0;q=c[3531864]|0}else{o=a[m+g|0]|0;p=j;q=l}l=p+1&1048575;p=c[q+44+(l>>>11<<2)>>2]|0;if((p|0)==0){r=gj[c[q+8236>>2]&4095](l)|0}else{r=a[p+l|0]|0}k=(r&255)<<8|o&255}switch(h&56|0){case 0:{o=e[f>>1]<<4;r=c[2385310]|0;l=r+28|0;p=b[l>>1]|0;q=p+1&65535;b[l>>1]=q;l=(p&65535)+o&1048575;o=c[3531864]|0;p=c[o+6188+(l>>>11<<2)>>2]|0;if((p|0)==0){j=gj[c[o+8236>>2]&4095](l)|0;g=c[2385310]|0;s=j;t=g;u=b[g+28>>1]|0;v=c[3531864]|0}else{s=a[p+l|0]|0;t=r;u=q;v=o}o=e[f>>1]<<4;b[t+28>>1]=u+1&65535;t=(u&65535)+o&1048575;o=c[v+6188+(t>>>11<<2)>>2]|0;if((o|0)==0){w=gj[c[v+8236>>2]&4095](t)|0}else{w=a[o+t|0]|0}c[d+40>>2]=0;c[d+48>>2]=0;t=(((w&255)<<8|s&255)&k)<<16>>16;c[d+52>>2]=t;c[d+44>>2]=t;c[d+32>>2]=t;t=d+84|0;c[t>>2]=(c[t>>2]|0)-(i?4:11);return};case 16:{do{if(i){b[d+(c[9650784+(h<<2)>>2]<<1)>>1]=(k^65535)&65535}else{t=c[2426956]|0;s=k^65535;w=s&255;o=t&1048575;v=c[3531864]|0;u=c[v+2092+(o>>>11<<2)>>2]|0;if((u|0)==0){gg[c[v+8240>>2]&4095](o,w);x=c[3531864]|0}else{a[u+o|0]=w;x=v}v=(s&65535)>>>8&255;s=t+1&1048575;t=c[x+2092+(s>>>11<<2)>>2]|0;if((t|0)==0){gg[c[x+8240>>2]&4095](s,v);break}else{a[t+s|0]=v;break}}}while(0);x=d+84|0;c[x>>2]=(c[x>>2]|0)-(i?2:16);return};case 24:{c[d+48>>2]=(k|0)!=0;x=-k|0;v=x<<16>>16;c[d+52>>2]=v;c[d+44>>2]=v;c[d+32>>2]=v;do{if(i){b[d+(c[9650784+(h<<2)>>2]<<1)>>1]=x&65535}else{v=c[2426956]|0;s=x&255;t=v&1048575;w=c[3531864]|0;o=c[w+2092+(t>>>11<<2)>>2]|0;if((o|0)==0){gg[c[w+8240>>2]&4095](t,s);y=c[3531864]|0}else{a[o+t|0]=s;y=w}w=(x&65535)>>>8&255;s=v+1&1048575;v=c[y+2092+(s>>>11<<2)>>2]|0;if((v|0)==0){gg[c[y+8240>>2]&4095](s,w);break}else{a[v+s|0]=w;break}}}while(0);y=d+84|0;c[y>>2]=(c[y>>2]|0)-(i?2:16);return};case 32:{y=d|0;x=ag(e[y>>1]|0,k)|0;b[y>>1]=x&65535;y=x>>>16;b[d+4>>1]=y&65535;x=(y|0)!=0|0;c[d+40>>2]=x;c[d+48>>2]=x;x=d+84|0;c[x>>2]=(c[x>>2]|0)-(i?30:36);return};case 40:{x=d|0;y=ag(b[x>>1]|0,k<<16>>16)|0;b[x>>1]=y&65535;x=y>>>16;b[d+4>>1]=x&65535;y=(x|0)!=0|0;c[d+40>>2]=y;c[d+48>>2]=y;y=d+84|0;c[y>>2]=(c[y>>2]|0)-(i?30:36);return};case 48:{do{if((k|0)==0){f9v(d,0,0)}else{y=d+4|0;x=d|0;h=e[y>>1]<<16|e[x>>1];w=(h>>>0)/(k>>>0)|0;if(w>>>0<=65535){b[x>>1]=w&65535;b[y>>1]=((h>>>0)%(k>>>0)|0)&65535;break}f9v(d,0,0);return}}while(0);h=d+84|0;c[h>>2]=(c[h>>2]|0)-(i?43:53);return};case 56:{do{if((k|0)==0){f9v(d,0,0)}else{h=d+4|0;y=d|0;w=e[h>>1]<<16|e[y>>1];x=k<<16>>16;s=(w|0)/(x|0)|0;if((s|0)<=65535){b[y>>1]=s&65535;b[h>>1]=((w|0)%(x|0)|0)&65535;break}f9v(d,0,0);return}}while(0);k=d+84|0;c[k>>2]=(c[k>>2]|0)-(i?43:53);return};default:{return}}}function f8$(a){a=a|0;var b=0;c[a+48>>2]=0;b=a+84|0;c[b>>2]=(c[b>>2]|0)-2;return}function f80(a){a=a|0;var b=0;c[a+48>>2]=1;b=a+84|0;c[b>>2]=(c[b>>2]|0)-2;return}function f81(b){b=b|0;var d=0;a[b+57|0]=0;d=b+84|0;c[d>>2]=(c[d>>2]|0)-2;return}function f82(b){b=b|0;var d=0;a[b+57|0]=1;d=b+84|0;c[d>>2]=(c[d>>2]|0)-2;return}function f83(b){b=b|0;var d=0;a[b+58|0]=0;d=b+84|0;c[d>>2]=(c[d>>2]|0)-2;return}function f84(b){b=b|0;var d=0;a[b+58|0]=1;d=b+84|0;c[d>>2]=(c[d>>2]|0)-2;return}function f85(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=(e[d+22>>1]|0)<<4;g=(c[2385310]|0)+28|0;h=b[g>>1]|0;b[g>>1]=h+1&65535;g=(h&65535)+f&1048575;f=c[3531864]|0;h=c[f+6188+(g>>>11<<2)>>2]|0;if((h|0)==0){i=gj[c[f+8236>>2]&4095](g)|0}else{i=a[h+g|0]|0}g=i&255;h=(i&255)>191;do{if(h){j=a[d+(c[9648736+(g<<2)>>2]|0)|0]|0}else{i=(gj[c[679712+(g<<2)>>2]&4095](d)|0)&1048575;f=c[3531864]|0;k=c[f+44+(i>>>11<<2)>>2]|0;if((k|0)==0){j=gj[c[f+8236>>2]&4095](i)|0;break}else{j=a[k+i|0]|0;break}}}while(0);i=j&255;k=g&56;if((k|0)==0){f=i+1|0;c[d+40>>2]=j<<24>>24==127;c[d+36>>2]=(f^i)&16;l=f&255;f=l<<24>>24;c[d+52>>2]=f;c[d+44>>2]=f;c[d+32>>2]=f;do{if(h){a[d+(c[9648736+(g<<2)>>2]|0)|0]=l}else{f=c[2426956]&1048575;m=c[3531864]|0;n=c[m+2092+(f>>>11<<2)>>2]|0;if((n|0)==0){gg[c[m+8240>>2]&4095](f,l);break}else{a[n+f|0]=l;break}}}while(0);l=d+84|0;c[l>>2]=(c[l>>2]|0)-((h?131586:1052679)>>>((c[d+92>>2]|0)>>>0)&127);return}else if((k|0)==8){k=i-1|0;c[d+40>>2]=j<<24>>24==-128;c[d+36>>2]=(k^i)&16;i=k&255;k=i<<24>>24;c[d+52>>2]=k;c[d+44>>2]=k;c[d+32>>2]=k;do{if(h){a[d+(c[9648736+(g<<2)>>2]|0)|0]=i}else{k=c[2426956]&1048575;j=c[3531864]|0;l=c[j+2092+(k>>>11<<2)>>2]|0;if((l|0)==0){gg[c[j+8240>>2]&4095](k,i);break}else{a[l+k|0]=i;break}}}while(0);i=d+84|0;c[i>>2]=(c[i>>2]|0)-((h?131586:1052679)>>>((c[d+92>>2]|0)>>>0)&127);return}else{return}}function f86(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;f=d+22|0;g=(e[f>>1]|0)<<4;h=(c[2385310]|0)+28|0;i=b[h>>1]|0;b[h>>1]=i+1&65535;h=(i&65535)+g&1048575;g=c[3531864]|0;i=c[g+6188+(h>>>11<<2)>>2]|0;if((i|0)==0){j=gj[c[g+8236>>2]&4095](h)|0}else{j=a[i+h|0]|0}h=j&255;i=(j&255)>191;if(i){k=e[d+(c[9650784+(h<<2)>>2]<<1)>>1]|0}else{j=c[679712+(h<<2)>>2]|0;gj[j&4095](d)|0;j=c[2426956]|0;g=j&1048575;l=c[3531864]|0;m=c[l+44+(g>>>11<<2)>>2]|0;if((m|0)==0){n=gj[c[l+8236>>2]&4095](g)|0;o=n;p=c[2426956]|0;q=c[3531864]|0}else{o=a[m+g|0]|0;p=j;q=l}l=p+1&1048575;p=c[q+44+(l>>>11<<2)>>2]|0;if((p|0)==0){r=gj[c[q+8236>>2]&4095](l)|0}else{r=a[p+l|0]|0}k=(r&255)<<8|o&255}switch(h&56|0){case 0:{o=k+1|0;c[d+40>>2]=(k|0)==32767;c[d+36>>2]=(o^k)&16;r=o&65535;l=r<<16>>16;c[d+52>>2]=l;c[d+44>>2]=l;c[d+32>>2]=l;do{if(i){b[d+(c[9650784+(h<<2)>>2]<<1)>>1]=r}else{l=c[2426956]|0;p=o&255;q=l&1048575;j=c[3531864]|0;g=c[j+2092+(q>>>11<<2)>>2]|0;if((g|0)==0){gg[c[j+8240>>2]&4095](q,p);s=c[3531864]|0}else{a[g+q|0]=p;s=j}j=(r&65535)>>>8&255;p=l+1&1048575;l=c[s+2092+(p>>>11<<2)>>2]|0;if((l|0)==0){gg[c[s+8240>>2]&4095](p,j);break}else{a[l+p|0]=j;break}}}while(0);s=d+84|0;c[s>>2]=(c[s>>2]|0)-((i?131586:1576967)>>>((c[d+92>>2]|0)>>>0)&127);return};case 8:{s=k-1|0;c[d+40>>2]=(k|0)==32768;c[d+36>>2]=(s^k)&16;r=s&65535;o=r<<16>>16;c[d+52>>2]=o;c[d+44>>2]=o;c[d+32>>2]=o;do{if(i){b[d+(c[9650784+(h<<2)>>2]<<1)>>1]=r}else{o=c[2426956]|0;j=s&255;p=o&1048575;l=c[3531864]|0;q=c[l+2092+(p>>>11<<2)>>2]|0;if((q|0)==0){gg[c[l+8240>>2]&4095](p,j);t=c[3531864]|0}else{a[q+p|0]=j;t=l}l=(r&65535)>>>8&255;j=o+1&1048575;o=c[t+2092+(j>>>11<<2)>>2]|0;if((o|0)==0){gg[c[t+8240>>2]&4095](j,l);break}else{a[o+j|0]=l;break}}}while(0);t=d+84|0;c[t>>2]=(c[t>>2]|0)-((i?131586:1576967)>>>((c[d+92>>2]|0)>>>0)&127);return};case 16:{t=d+8|0;r=(b[t>>1]|0)-2&65535;b[t>>1]=r;t=((e[d+24>>1]|0)<<4)+(r&65535)|0;r=d+28|0;s=b[r>>1]|0;h=s&255;l=t&1048575;j=c[3531864]|0;o=c[j+2092+(l>>>11<<2)>>2]|0;if((o|0)==0){gg[c[j+8240>>2]&4095](l,h);u=c[3531864]|0}else{a[o+l|0]=h;u=j}j=(s&65535)>>>8&255;s=t+1&1048575;t=c[u+2092+(s>>>11<<2)>>2]|0;if((t|0)==0){gg[c[u+8240>>2]&4095](s,j)}else{a[t+s|0]=j}b[r>>1]=k&65535;a[d+91|0]=1;r=d+84|0;c[r>>2]=(c[r>>2]|0)-(i?16:20);return};case 24:{r=b[f>>1]|0;j=c[2426956]|0;s=j+2&65535|j&983040;t=c[3531864]|0;u=c[t+44+(s>>>11<<2)>>2]|0;if((u|0)==0){h=gj[c[t+8236>>2]&4095](s)|0;v=h;w=c[2426956]|0;x=c[3531864]|0}else{v=a[u+s|0]|0;w=j;x=t}t=(w+2&65535|w&983040)+1&1048575;w=c[x+44+(t>>>11<<2)>>2]|0;if((w|0)==0){j=gj[c[x+8236>>2]&4095](t)|0;y=j;z=c[3531864]|0}else{y=a[w+t|0]|0;z=x}b[f>>1]=(y&255)<<8|v&255;v=d+8|0;y=(b[v>>1]|0)-2&65535;b[v>>1]=y;x=d+24|0;t=((e[x>>1]|0)<<4)+(y&65535)|0;y=r&255;w=t&1048575;j=c[z+2092+(w>>>11<<2)>>2]|0;if((j|0)==0){gg[c[z+8240>>2]&4095](w,y);A=c[3531864]|0}else{a[j+w|0]=y;A=z}z=(r&65535)>>>8&255;r=t+1&1048575;t=c[A+2092+(r>>>11<<2)>>2]|0;if((t|0)==0){gg[c[A+8240>>2]&4095](r,z);B=c[3531864]|0}else{a[t+r|0]=z;B=A}A=(b[v>>1]|0)-2&65535;b[v>>1]=A;v=((e[x>>1]|0)<<4)+(A&65535)|0;A=d+28|0;x=b[A>>1]|0;z=x&255;r=v&1048575;t=c[B+2092+(r>>>11<<2)>>2]|0;if((t|0)==0){gg[c[B+8240>>2]&4095](r,z);C=c[3531864]|0}else{a[t+r|0]=z;C=B}B=(x&65535)>>>8&255;x=v+1&1048575;v=c[C+2092+(x>>>11<<2)>>2]|0;if((v|0)==0){gg[c[C+8240>>2]&4095](x,B)}else{a[v+x|0]=B}b[A>>1]=k&65535;a[d+91|0]=1;A=d+84|0;c[A>>2]=(c[A>>2]|0)-(i?16:26);return};case 32:{b[d+28>>1]=k&65535;a[d+91|0]=1;i=d+84|0;c[i>>2]=(c[i>>2]|0)-13;return};case 40:{b[d+28>>1]=k&65535;i=c[2426956]|0;A=i+2&65535|i&983040;B=c[3531864]|0;x=c[B+44+(A>>>11<<2)>>2]|0;if((x|0)==0){v=gj[c[B+8236>>2]&4095](A)|0;D=v;E=c[2426956]|0;F=c[3531864]|0}else{D=a[x+A|0]|0;E=i;F=B}B=(E+2&65535|E&983040)+1&1048575;E=c[F+44+(B>>>11<<2)>>2]|0;if((E|0)==0){G=gj[c[F+8236>>2]&4095](B)|0}else{G=a[E+B|0]|0}b[f>>1]=(G&255)<<8|D&255;a[d+91|0]=1;D=d+84|0;c[D>>2]=(c[D>>2]|0)-15;return};case 48:{D=d+8|0;G=(b[D>>1]|0)-2&65535;b[D>>1]=G;D=((e[d+24>>1]|0)<<4)+(G&65535)|0;G=k&255;f=D&1048575;B=c[3531864]|0;E=c[B+2092+(f>>>11<<2)>>2]|0;if((E|0)==0){gg[c[B+8240>>2]&4095](f,G);H=c[3531864]|0}else{a[E+f|0]=G;H=B}B=(k&65535)>>>8&255;k=D+1&1048575;D=c[H+2092+(k>>>11<<2)>>2]|0;if((D|0)==0){gg[c[H+8240>>2]&4095](k,B)}else{a[D+k|0]=B}B=d+84|0;c[B>>2]=(c[B>>2]|0)-4;return};default:{return}}}function f87(d){d=d|0;var f=0,g=0,h=0,i=0;f=(b[d+12>>1]|0)+(b[d+6>>1]|0)&65535;b[4853904]=f;if((a[d+100|0]|0)==0){g=e[d+26>>1]<<4;h=f&65535;i=g+h|0;c[2426956]=i;return i|0}else{g=c[d+96>>2]|0;h=f&65535;i=g+h|0;c[2426956]=i;return i|0}return 0}function f88(d){d=d|0;var f=0,g=0,h=0,i=0;f=(b[d+14>>1]|0)+(b[d+6>>1]|0)&65535;b[4853904]=f;if((a[d+100|0]|0)==0){g=e[d+26>>1]<<4;h=f&65535;i=g+h|0;c[2426956]=i;return i|0}else{g=c[d+96>>2]|0;h=f&65535;i=g+h|0;c[2426956]=i;return i|0}return 0}function f89(d){d=d|0;var f=0,g=0,h=0,i=0;f=(b[d+12>>1]|0)+(b[d+10>>1]|0)&65535;b[4853904]=f;if((a[d+100|0]|0)==0){g=e[d+24>>1]<<4;h=f&65535;i=g+h|0;c[2426956]=i;return i|0}else{g=c[d+96>>2]|0;h=f&65535;i=g+h|0;c[2426956]=i;return i|0}return 0}function f9a(d){d=d|0;var f=0,g=0,h=0,i=0;f=(b[d+14>>1]|0)+(b[d+10>>1]|0)&65535;b[4853904]=f;if((a[d+100|0]|0)==0){g=e[d+24>>1]<<4;h=f&65535;i=g+h|0;c[2426956]=i;return i|0}else{g=c[d+96>>2]|0;h=f&65535;i=g+h|0;c[2426956]=i;return i|0}return 0}function f9b(d){d=d|0;var f=0,g=0;f=b[d+12>>1]|0;b[4853904]=f;if((a[d+100|0]|0)==0){g=e[d+26>>1]<<4}else{g=c[d+96>>2]|0}d=g+(f&65535)|0;c[2426956]=d;return d|0}function f9c(d){d=d|0;var f=0,g=0;f=b[d+14>>1]|0;b[4853904]=f;if((a[d+100|0]|0)==0){g=e[d+26>>1]<<4}else{g=c[d+96>>2]|0}d=g+(f&65535)|0;c[2426956]=d;return d|0}function f9d(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=d+22|0;g=e[f>>1]<<4;h=c[2385310]|0;i=h+28|0;j=b[i>>1]|0;k=j+1&65535;b[i>>1]=k;i=(j&65535)+g&1048575;g=c[3531864]|0;j=c[g+6188+(i>>>11<<2)>>2]|0;if((j|0)==0){l=gj[c[g+8236>>2]&4095](i)|0;m=c[2385310]|0;n=l;o=m;p=b[m+28>>1]|0;q=c[3531864]|0}else{n=a[j+i|0]|0;o=h;p=k;q=g}g=n&255;b[4853904]=g;n=e[f>>1]<<4;b[o+28>>1]=p+1&65535;o=(p&65535)+n&1048575;n=c[q+6188+(o>>>11<<2)>>2]|0;if((n|0)==0){p=gj[c[q+8236>>2]&4095](o)|0;r=p;s=b[4853904]|0}else{r=a[n+o|0]|0;s=g}g=((r&255)<<8)+s&65535;b[4853904]=g;if((a[d+100|0]|0)==0){t=e[d+26>>1]<<4;u=g&65535;v=t+u|0;c[2426956]=v;return v|0}else{t=c[d+96>>2]|0;u=g&65535;v=t+u|0;c[2426956]=v;return v|0}return 0}function f9e(d){d=d|0;var f=0,g=0;f=b[d+6>>1]|0;b[4853904]=f;if((a[d+100|0]|0)==0){g=e[d+26>>1]<<4}else{g=c[d+96>>2]|0}d=g+(f&65535)|0;c[2426956]=d;return d|0}function f9f(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=(b[d+12>>1]|0)+(b[d+6>>1]|0)&65535;g=e[d+22>>1]<<4;h=(c[2385310]|0)+28|0;i=b[h>>1]|0;b[h>>1]=i+1&65535;h=(i&65535)+g&1048575;g=c[3531864]|0;i=c[g+6188+(h>>>11<<2)>>2]|0;if((i|0)==0){j=gj[c[g+8236>>2]&4095](h)|0}else{j=a[i+h|0]|0}h=f+(j<<24>>24)&65535;b[4853904]=h;if((a[d+100|0]|0)==0){k=e[d+26>>1]<<4;l=h&65535;m=k+l|0;c[2426956]=m;return m|0}else{k=c[d+96>>2]|0;l=h&65535;m=k+l|0;c[2426956]=m;return m|0}return 0}function f9g(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=(b[d+14>>1]|0)+(b[d+6>>1]|0)&65535;g=e[d+22>>1]<<4;h=(c[2385310]|0)+28|0;i=b[h>>1]|0;b[h>>1]=i+1&65535;h=(i&65535)+g&1048575;g=c[3531864]|0;i=c[g+6188+(h>>>11<<2)>>2]|0;if((i|0)==0){j=gj[c[g+8236>>2]&4095](h)|0}else{j=a[i+h|0]|0}h=f+(j<<24>>24)&65535;b[4853904]=h;if((a[d+100|0]|0)==0){k=e[d+26>>1]<<4;l=h&65535;m=k+l|0;c[2426956]=m;return m|0}else{k=c[d+96>>2]|0;l=h&65535;m=k+l|0;c[2426956]=m;return m|0}return 0}function f9h(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=(b[d+12>>1]|0)+(b[d+10>>1]|0)&65535;g=e[d+22>>1]<<4;h=(c[2385310]|0)+28|0;i=b[h>>1]|0;b[h>>1]=i+1&65535;h=(i&65535)+g&1048575;g=c[3531864]|0;i=c[g+6188+(h>>>11<<2)>>2]|0;if((i|0)==0){j=gj[c[g+8236>>2]&4095](h)|0}else{j=a[i+h|0]|0}h=f+(j<<24>>24)&65535;b[4853904]=h;if((a[d+100|0]|0)==0){k=e[d+24>>1]<<4;l=h&65535;m=k+l|0;c[2426956]=m;return m|0}else{k=c[d+96>>2]|0;l=h&65535;m=k+l|0;c[2426956]=m;return m|0}return 0}function f9i(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=(b[d+14>>1]|0)+(b[d+10>>1]|0)&65535;g=e[d+22>>1]<<4;h=(c[2385310]|0)+28|0;i=b[h>>1]|0;b[h>>1]=i+1&65535;h=(i&65535)+g&1048575;g=c[3531864]|0;i=c[g+6188+(h>>>11<<2)>>2]|0;if((i|0)==0){j=gj[c[g+8236>>2]&4095](h)|0}else{j=a[i+h|0]|0}h=f+(j<<24>>24)&65535;b[4853904]=h;if((a[d+100|0]|0)==0){k=e[d+24>>1]<<4;l=h&65535;m=k+l|0;c[2426956]=m;return m|0}else{k=c[d+96>>2]|0;l=h&65535;m=k+l|0;c[2426956]=m;return m|0}return 0}function f9j(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=b[d+12>>1]|0;g=e[d+22>>1]<<4;h=(c[2385310]|0)+28|0;i=b[h>>1]|0;b[h>>1]=i+1&65535;h=(i&65535)+g&1048575;g=c[3531864]|0;i=c[g+6188+(h>>>11<<2)>>2]|0;if((i|0)==0){j=gj[c[g+8236>>2]&4095](h)|0}else{j=a[i+h|0]|0}h=(j<<24>>24)+f&65535;b[4853904]=h;if((a[d+100|0]|0)==0){k=e[d+26>>1]<<4;l=h&65535;m=k+l|0;c[2426956]=m;return m|0}else{k=c[d+96>>2]|0;l=h&65535;m=k+l|0;c[2426956]=m;return m|0}return 0}function f9k(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=b[d+14>>1]|0;g=e[d+22>>1]<<4;h=(c[2385310]|0)+28|0;i=b[h>>1]|0;b[h>>1]=i+1&65535;h=(i&65535)+g&1048575;g=c[3531864]|0;i=c[g+6188+(h>>>11<<2)>>2]|0;if((i|0)==0){j=gj[c[g+8236>>2]&4095](h)|0}else{j=a[i+h|0]|0}h=(j<<24>>24)+f&65535;b[4853904]=h;if((a[d+100|0]|0)==0){k=e[d+26>>1]<<4;l=h&65535;m=k+l|0;c[2426956]=m;return m|0}else{k=c[d+96>>2]|0;l=h&65535;m=k+l|0;c[2426956]=m;return m|0}return 0}function f9l(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=b[d+10>>1]|0;g=e[d+22>>1]<<4;h=(c[2385310]|0)+28|0;i=b[h>>1]|0;b[h>>1]=i+1&65535;h=(i&65535)+g&1048575;g=c[3531864]|0;i=c[g+6188+(h>>>11<<2)>>2]|0;if((i|0)==0){j=gj[c[g+8236>>2]&4095](h)|0}else{j=a[i+h|0]|0}h=(j<<24>>24)+f&65535;b[4853904]=h;if((a[d+100|0]|0)==0){k=e[d+24>>1]<<4;l=h&65535;m=k+l|0;c[2426956]=m;return m|0}else{k=c[d+96>>2]|0;l=h&65535;m=k+l|0;c[2426956]=m;return m|0}return 0}function f9m(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=b[d+6>>1]|0;g=e[d+22>>1]<<4;h=(c[2385310]|0)+28|0;i=b[h>>1]|0;b[h>>1]=i+1&65535;h=(i&65535)+g&1048575;g=c[3531864]|0;i=c[g+6188+(h>>>11<<2)>>2]|0;if((i|0)==0){j=gj[c[g+8236>>2]&4095](h)|0}else{j=a[i+h|0]|0}h=(j<<24>>24)+f&65535;b[4853904]=h;if((a[d+100|0]|0)==0){k=e[d+26>>1]<<4;l=h&65535;m=k+l|0;c[2426956]=m;return m|0}else{k=c[d+96>>2]|0;l=h&65535;m=k+l|0;c[2426956]=m;return m|0}return 0}function f9n(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=d+22|0;g=e[f>>1]<<4;h=c[2385310]|0;i=h+28|0;j=b[i>>1]|0;k=j+1&65535;b[i>>1]=k;i=(j&65535)+g&1048575;g=c[3531864]|0;j=c[g+6188+(i>>>11<<2)>>2]|0;if((j|0)==0){l=gj[c[g+8236>>2]&4095](i)|0;m=c[2385310]|0;n=l;o=m;p=b[m+28>>1]|0;q=c[3531864]|0}else{n=a[j+i|0]|0;o=h;p=k;q=g}g=n&255;b[4853680]=g;n=e[f>>1]<<4;b[o+28>>1]=p+1&65535;o=(p&65535)+n&1048575;n=c[q+6188+(o>>>11<<2)>>2]|0;if((n|0)==0){p=gj[c[q+8236>>2]&4095](o)|0;r=p;s=b[4853680]|0}else{r=a[n+o|0]|0;s=g}g=((r&255)<<8)+s&65535;b[4853680]=g;s=((b[d+12>>1]|0)+(b[d+6>>1]|0)&65535)+g&65535;b[4853904]=s;if((a[d+100|0]|0)==0){t=e[d+26>>1]<<4;u=s&65535;v=t+u|0;c[2426956]=v;return v|0}else{t=c[d+96>>2]|0;u=s&65535;v=t+u|0;c[2426956]=v;return v|0}return 0}function f9o(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=d+22|0;g=e[f>>1]<<4;h=c[2385310]|0;i=h+28|0;j=b[i>>1]|0;k=j+1&65535;b[i>>1]=k;i=(j&65535)+g&1048575;g=c[3531864]|0;j=c[g+6188+(i>>>11<<2)>>2]|0;if((j|0)==0){l=gj[c[g+8236>>2]&4095](i)|0;m=c[2385310]|0;n=l;o=m;p=b[m+28>>1]|0;q=c[3531864]|0}else{n=a[j+i|0]|0;o=h;p=k;q=g}g=n&255;b[4853680]=g;n=e[f>>1]<<4;b[o+28>>1]=p+1&65535;o=(p&65535)+n&1048575;n=c[q+6188+(o>>>11<<2)>>2]|0;if((n|0)==0){p=gj[c[q+8236>>2]&4095](o)|0;r=p;s=b[4853680]|0}else{r=a[n+o|0]|0;s=g}g=((r&255)<<8)+s&65535;b[4853680]=g;s=((b[d+14>>1]|0)+(b[d+6>>1]|0)&65535)+g&65535;b[4853904]=s;if((a[d+100|0]|0)==0){t=e[d+26>>1]<<4;u=s&65535;v=t+u|0;c[2426956]=v;return v|0}else{t=c[d+96>>2]|0;u=s&65535;v=t+u|0;c[2426956]=v;return v|0}return 0}function f9p(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=d+22|0;g=e[f>>1]<<4;h=c[2385310]|0;i=h+28|0;j=b[i>>1]|0;k=j+1&65535;b[i>>1]=k;i=(j&65535)+g&1048575;g=c[3531864]|0;j=c[g+6188+(i>>>11<<2)>>2]|0;if((j|0)==0){l=gj[c[g+8236>>2]&4095](i)|0;m=c[2385310]|0;n=l;o=m;p=b[m+28>>1]|0;q=c[3531864]|0}else{n=a[j+i|0]|0;o=h;p=k;q=g}g=n&255;b[4853680]=g;n=e[f>>1]<<4;b[o+28>>1]=p+1&65535;o=(p&65535)+n&1048575;n=c[q+6188+(o>>>11<<2)>>2]|0;if((n|0)==0){p=gj[c[q+8236>>2]&4095](o)|0;r=p;s=b[4853680]|0}else{r=a[n+o|0]|0;s=g}g=((r&255)<<8)+s&65535;b[4853680]=g;s=((b[d+12>>1]|0)+(b[d+10>>1]|0)&65535)+g&65535;b[4853904]=s;if((a[d+100|0]|0)==0){t=e[d+24>>1]<<4;u=s&65535;v=t+u|0;c[2426956]=v;return v|0}else{t=c[d+96>>2]|0;u=s&65535;v=t+u|0;c[2426956]=v;return v|0}return 0}function f9q(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=d+22|0;g=e[f>>1]<<4;h=c[2385310]|0;i=h+28|0;j=b[i>>1]|0;k=j+1&65535;b[i>>1]=k;i=(j&65535)+g&1048575;g=c[3531864]|0;j=c[g+6188+(i>>>11<<2)>>2]|0;if((j|0)==0){l=gj[c[g+8236>>2]&4095](i)|0;m=c[2385310]|0;n=l;o=m;p=b[m+28>>1]|0;q=c[3531864]|0}else{n=a[j+i|0]|0;o=h;p=k;q=g}g=n&255;b[4853680]=g;n=e[f>>1]<<4;b[o+28>>1]=p+1&65535;o=(p&65535)+n&1048575;n=c[q+6188+(o>>>11<<2)>>2]|0;if((n|0)==0){p=gj[c[q+8236>>2]&4095](o)|0;r=p;s=b[4853680]|0}else{r=a[n+o|0]|0;s=g}g=((r&255)<<8)+s&65535;b[4853680]=g;s=((b[d+14>>1]|0)+(b[d+10>>1]|0)&65535)+g&65535;b[4853904]=s;if((a[d+100|0]|0)==0){t=e[d+24>>1]<<4;u=s&65535;v=t+u|0;c[2426956]=v;return v|0}else{t=c[d+96>>2]|0;u=s&65535;v=t+u|0;c[2426956]=v;return v|0}return 0}function f9r(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=d+22|0;g=e[f>>1]<<4;h=c[2385310]|0;i=h+28|0;j=b[i>>1]|0;k=j+1&65535;b[i>>1]=k;i=(j&65535)+g&1048575;g=c[3531864]|0;j=c[g+6188+(i>>>11<<2)>>2]|0;if((j|0)==0){l=gj[c[g+8236>>2]&4095](i)|0;m=c[2385310]|0;n=l;o=m;p=b[m+28>>1]|0;q=c[3531864]|0}else{n=a[j+i|0]|0;o=h;p=k;q=g}g=n&255;b[4853680]=g;n=e[f>>1]<<4;b[o+28>>1]=p+1&65535;o=(p&65535)+n&1048575;n=c[q+6188+(o>>>11<<2)>>2]|0;if((n|0)==0){p=gj[c[q+8236>>2]&4095](o)|0;r=p;s=b[4853680]|0}else{r=a[n+o|0]|0;s=g}g=((r&255)<<8)+s&65535;b[4853680]=g;s=g+(b[d+12>>1]|0)&65535;b[4853904]=s;if((a[d+100|0]|0)==0){t=e[d+26>>1]<<4;u=s&65535;v=t+u|0;c[2426956]=v;return v|0}else{t=c[d+96>>2]|0;u=s&65535;v=t+u|0;c[2426956]=v;return v|0}return 0}function f9s(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=d+22|0;g=e[f>>1]<<4;h=c[2385310]|0;i=h+28|0;j=b[i>>1]|0;k=j+1&65535;b[i>>1]=k;i=(j&65535)+g&1048575;g=c[3531864]|0;j=c[g+6188+(i>>>11<<2)>>2]|0;if((j|0)==0){l=gj[c[g+8236>>2]&4095](i)|0;m=c[2385310]|0;n=l;o=m;p=b[m+28>>1]|0;q=c[3531864]|0}else{n=a[j+i|0]|0;o=h;p=k;q=g}g=n&255;b[4853680]=g;n=e[f>>1]<<4;b[o+28>>1]=p+1&65535;o=(p&65535)+n&1048575;n=c[q+6188+(o>>>11<<2)>>2]|0;if((n|0)==0){p=gj[c[q+8236>>2]&4095](o)|0;r=p;s=b[4853680]|0}else{r=a[n+o|0]|0;s=g}g=((r&255)<<8)+s&65535;b[4853680]=g;s=g+(b[d+14>>1]|0)&65535;b[4853904]=s;if((a[d+100|0]|0)==0){t=e[d+26>>1]<<4;u=s&65535;v=t+u|0;c[2426956]=v;return v|0}else{t=c[d+96>>2]|0;u=s&65535;v=t+u|0;c[2426956]=v;return v|0}return 0}function f9t(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=d+22|0;g=e[f>>1]<<4;h=c[2385310]|0;i=h+28|0;j=b[i>>1]|0;k=j+1&65535;b[i>>1]=k;i=(j&65535)+g&1048575;g=c[3531864]|0;j=c[g+6188+(i>>>11<<2)>>2]|0;if((j|0)==0){l=gj[c[g+8236>>2]&4095](i)|0;m=c[2385310]|0;n=l;o=m;p=b[m+28>>1]|0;q=c[3531864]|0}else{n=a[j+i|0]|0;o=h;p=k;q=g}g=n&255;b[4853680]=g;n=e[f>>1]<<4;b[o+28>>1]=p+1&65535;o=(p&65535)+n&1048575;n=c[q+6188+(o>>>11<<2)>>2]|0;if((n|0)==0){p=gj[c[q+8236>>2]&4095](o)|0;r=p;s=b[4853680]|0}else{r=a[n+o|0]|0;s=g}g=((r&255)<<8)+s&65535;b[4853680]=g;s=g+(b[d+10>>1]|0)&65535;b[4853904]=s;if((a[d+100|0]|0)==0){t=e[d+24>>1]<<4;u=s&65535;v=t+u|0;c[2426956]=v;return v|0}else{t=c[d+96>>2]|0;u=s&65535;v=t+u|0;c[2426956]=v;return v|0}return 0}function f9u(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=d+22|0;g=e[f>>1]<<4;h=c[2385310]|0;i=h+28|0;j=b[i>>1]|0;k=j+1&65535;b[i>>1]=k;i=(j&65535)+g&1048575;g=c[3531864]|0;j=c[g+6188+(i>>>11<<2)>>2]|0;if((j|0)==0){l=gj[c[g+8236>>2]&4095](i)|0;m=c[2385310]|0;n=l;o=m;p=b[m+28>>1]|0;q=c[3531864]|0}else{n=a[j+i|0]|0;o=h;p=k;q=g}g=n&255;b[4853680]=g;n=e[f>>1]<<4;b[o+28>>1]=p+1&65535;o=(p&65535)+n&1048575;n=c[q+6188+(o>>>11<<2)>>2]|0;if((n|0)==0){p=gj[c[q+8236>>2]&4095](o)|0;r=p;s=b[4853680]|0}else{r=a[n+o|0]|0;s=g}g=((r&255)<<8)+s&65535;b[4853680]=g;s=g+(b[d+6>>1]|0)&65535;b[4853904]=s;if((a[d+100|0]|0)==0){t=e[d+26>>1]<<4;u=s&65535;v=t+u|0;c[2426956]=v;return v|0}else{t=c[d+96>>2]|0;u=s&65535;v=t+u|0;c[2426956]=v;return v|0}return 0}function f9v(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;i=f+56|0;j=f+57|0;k=(c[f+48>>2]|0)!=0|(d[9761200+(c[f+52>>2]&255)|0]|0)<<2|((c[f+36>>2]|0)!=0)<<4|((c[f+44>>2]|0)==0)<<6|(c[f+32>>2]|0)>>>31<<7|(d[i]|0)<<8|(d[j]|0)<<9|(d[f+58|0]|0)<<10|((c[f+40>>2]|0)!=0)<<11|(d[f+59|0]|0)<<15|28674;l=f+8|0;m=(b[l>>1]|0)-2&65535;b[l>>1]=m;n=f+24|0;o=((e[n>>1]|0)<<4)+(m&65535)|0;m=k&255;p=o&1048575;q=c[3531864]|0;r=c[q+2092+(p>>>11<<2)>>2]|0;if((r|0)==0){gg[c[q+8240>>2]&4095](p,m);s=c[3531864]|0}else{a[r+p|0]=m;s=q}q=(k&65535)>>>8&255;k=o+1&1048575;o=c[s+2092+(k>>>11<<2)>>2]|0;if((o|0)==0){gg[c[s+8240>>2]&4095](k,q)}else{a[o+k|0]=q}q=f+84|0;c[q>>2]=(c[q>>2]|0)-(788483>>>((c[f+92>>2]|0)>>>0)&127);a[j]=0;a[i]=0;if((h|0)==1){t=c[f+60>>2]|0}else{t=g}g=t<<2&1048572;t=g>>>11;h=c[3531864]|0;i=c[h+44+(t<<2)>>2]|0;do{if((i|0)==0){j=gj[c[h+8236>>2]&4095](g)|0;q=c[3531864]|0;k=c[q+44+(t<<2)>>2]|0;o=j&255;j=g|1;if((k|0)!=0){u=k;v=q;w=o;x=j;y=49127;break}k=gj[c[q+8236>>2]&4095](j)|0;j=c[3531864]|0;z=k;A=j;B=c[j+44+(t<<2)>>2]|0;C=o}else{u=i;v=h;w=d[i+g|0]|0;x=g|1;y=49127}}while(0);if((y|0)==49127){z=a[u+x|0]|0;A=v;B=u;C=w}w=(z&255)<<8|C;C=g|2;do{if((B|0)==0){z=gj[c[A+8236>>2]&4095](C)|0;u=c[3531864]|0;v=c[u+44+(t<<2)>>2]|0;x=z&255;z=g|3;if((v|0)!=0){D=v;E=x;F=z;G=u;y=49132;break}v=gj[c[u+8236>>2]&4095](z)|0;H=v;I=x;J=c[3531864]|0}else{D=B;E=d[B+C|0]|0;F=g|3;G=A;y=49132}}while(0);if((y|0)==49132){H=a[D+F|0]|0;I=E;J=G}G=(H&255)<<8|I;I=(b[l>>1]|0)-2&65535;b[l>>1]=I;H=((e[n>>1]|0)<<4)+(I&65535)|0;I=f+22|0;E=b[I>>1]|0;F=E&255;D=H&1048575;y=c[J+2092+(D>>>11<<2)>>2]|0;if((y|0)==0){gg[c[J+8240>>2]&4095](D,F);K=c[3531864]|0}else{a[y+D|0]=F;K=J}J=(E&65535)>>>8&255;E=H+1&1048575;H=c[K+2092+(E>>>11<<2)>>2]|0;if((H|0)==0){gg[c[K+8240>>2]&4095](E,J);L=c[3531864]|0}else{a[H+E|0]=J;L=K}K=(b[l>>1]|0)-2&65535;b[l>>1]=K;l=((e[n>>1]|0)<<4)+(K&65535)|0;K=f+28|0;n=b[K>>1]|0;J=n&255;E=l&1048575;H=c[L+2092+(E>>>11<<2)>>2]|0;if((H|0)==0){gg[c[L+8240>>2]&4095](E,J);M=c[3531864]|0}else{a[H+E|0]=J;M=L}L=(n&65535)>>>8&255;n=l+1&1048575;l=c[M+2092+(n>>>11<<2)>>2]|0;if((l|0)==0){gg[c[M+8240>>2]&4095](n,L);b[K>>1]=w;b[I>>1]=G;N=f+91|0;a[N]=1;return}else{a[l+n|0]=L;b[K>>1]=w;b[I>>1]=G;N=f+91|0;a[N]=1;return}}function f9w(b,e){b=b|0;e=e|0;var f=0,g=0,h=0;switch(e|0){case 157:{f=((c[b+308>>2]&8|0)!=0?7:71)|((c[b+304>>2]&8|0)!=0?-128:0)|((c[b+312>>2]&8|0)!=0?16:0);return f|0};case 0:{f=gj[c[(c[3531864]|0)+8244>>2]&4095](65536)|0;return f|0};case 16:{f=gj[c[(c[3531864]|0)+8244>>2]&4095](65540)|0;return f|0};case 235:{e=(a[b+424|0]|0)!=0?64:0;g=d[b+425|0]|0;if((g|0)==13){h=e|4}else if((g|0)==16){h=e|8}else if((g|0)==20){h=e|12}else{h=e}e=d[b+426|0]|0;if((e|0)==8){f=h|2;return f|0}else if((e|0)==4){f=h|1;return f|0}else{f=h;return f|0}break};case 77:{f=((c[b+308>>2]&256|0)!=0?7:71)|((c[b+304>>2]&256|0)!=0?-128:0)|((c[b+312>>2]&256|0)!=0?16:0);return f|0};case 78:{f=((c[b+308>>2]&512|0)!=0?7:71)|((c[b+304>>2]&512|0)!=0?-128:0)|((c[b+312>>2]&512|0)!=0?16:0);return f|0};case 56:{f=gj[c[(c[3531864]|0)+8244>>2]&4095](65542)|0;return f|0};case 76:{f=((c[b+304>>2]&128|0)!=0?-128:0)|a[b+318|0]|((c[b+308>>2]&128|0)!=0?0:64)|((c[b+312>>2]&128|0)!=0?16:0);return f|0};case 236:{f=((c[b+308>>2]&65536|0)!=0?7:71)|((c[b+304>>2]&65536|0)!=0?-128:0)|((c[b+312>>2]&65536|0)!=0?16:0);return f|0};case 234:{f=a[b+290|0]<<5|a[b+289|0]<<3;return f|0};case 156:{f=((c[b+304>>2]&4|0)!=0?-128:0)|a[b+316|0]|((c[b+308>>2]&4|0)!=0?0:64)|((c[b+312>>2]&4|0)!=0?16:0);return f|0};case 252:{f=a[b+322|0]|0;return f|0};case 239:{f=a[b+321|0]|0;return f|0};case 8:{f=(gj[c[(c[3531864]|0)+8244>>2]&4095](65538)|0)&-16|(c[b+324>>2]|0)==0|((c[b+340>>2]|0)!=0?0:2)|((c[b+344>>2]|0)!=0?0:4)|((c[b+348>>2]|0)!=0?0:8);return f|0};case 255:{f=(c[b+428>>2]|0)>>>12&255;return f|0};case 158:{f=((c[b+308>>2]&16|0)!=0?7:71)|((c[b+304>>2]&16|0)!=0?-128:0)|((c[b+312>>2]&16|0)!=0?16:0);return f|0};default:{f=0;return f|0}}return 0}function f9x(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=d+428|0;g=(e&1048064|0)==(c[f>>2]|0);if((e&1|0)!=0){do{if(g|(e|0)==1048575){h=e&511;if((a[d+424|0]|0)!=0&h>>>0<256){i=a[d+h|0]|0;break}if(h>>>0<=255){j=49198;break}i=f9w(d,h-256|0)|0}else{j=49198}}while(0);do{if((j|0)==49198){h=e&1048575;k=c[3531864]|0;l=c[k+44+(h>>>11<<2)>>2]|0;if((l|0)==0){i=gj[c[k+8236>>2]&4095](h)|0;break}else{i=a[l+h|0]|0;break}}}while(0);h=i&255;i=e+1|0;do{if((i&1048064|0)==(c[f>>2]|0)|(i|0)==1048575){l=i&511;if((a[d+424|0]|0)!=0&l>>>0<256){m=a[d+l|0]|0;break}if(l>>>0<=255){j=49206;break}m=f9w(d,l-256|0)|0}else{j=49206}}while(0);do{if((j|0)==49206){l=i&1048575;k=c[3531864]|0;n=c[k+44+(l>>>11<<2)>>2]|0;if((n|0)==0){m=gj[c[k+8236>>2]&4095](l)|0;break}else{m=a[n+l|0]|0;break}}}while(0);o=(m&255)<<8|h;return o|0}do{if(g){h=e&511;if((a[d+424|0]|0)!=0&h>>>0<256){o=b[d+(h>>>1<<1)>>1]|0;return o|0}if(h>>>0<=255){break}if((h|0)==386){o=b[d+356>>1]|0;return o|0}else if((h|0)==384){o=b[d+354>>1]|0;return o|0}else if((h|0)==392){o=b[d+358>>1]|0;return o|0}else if((h|0)==394){o=b[d+360>>1]|0;return o|0}else{m=(f9w(d,h-256|0)|0)&255;o=((f9w(d,h-255|0)|0)&255)<<8|m;return o|0}}}while(0);d=e&1048575;g=c[3531864]|0;m=c[g+44+(d>>>11<<2)>>2]|0;if((m|0)==0){p=gj[c[g+8236>>2]&4095](d)|0}else{p=a[m+d|0]|0}d=p&255;if((e|0)==1048574){o=((c[f>>2]|0)>>>12<<8|d)&65535;return o|0}f=e+1&1048575;e=c[3531864]|0;p=c[e+44+(f>>>11<<2)>>2]|0;if((p|0)==0){q=gj[c[e+8236>>2]&4095](f)|0}else{q=a[p+f|0]|0}o=((q&255)<<8|d)&65535;return o|0}function f9y(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0.0,m=0;switch(g|0){case 0:{gg[c[(c[3531864]|0)+8248>>2]&4095](65536,h);return};case 16:{gg[c[(c[3531864]|0)+8248>>2]&4095](65540,h);return};case 76:{g=h&255;i=f+304|0;j=c[i>>2]|0;c[i>>2]=(g&128|0)==0?j&-129:j|128;j=f+308|0;i=c[j>>2]|0;c[j>>2]=(g&64|0)==0?i|128:i&-129;i=f+312|0;j=c[i>>2]|0;c[i>>2]=(g&16|0)==0?j&-129:j|128;a[f+318|0]=h&7;return};case 77:{j=h&255;g=f+304|0;i=c[g>>2]|0;c[g>>2]=(j&128|0)==0?i&-257:i|256;i=f+308|0;g=c[i>>2]|0;c[i>>2]=(j&64|0)==0?g|256:g&-257;g=f+312|0;i=c[g>>2]|0;if((j&16|0)==0){c[g>>2]=i&-257;return}else{c[g>>2]=i|256;return}break};case 156:{i=h&255;g=f+304|0;j=c[g>>2]|0;c[g>>2]=(i&128|0)==0?j&-5:j|4;j=f+308|0;g=c[j>>2]|0;c[j>>2]=(i&64|0)==0?g|4:g&-5;g=f+312|0;j=c[g>>2]|0;c[g>>2]=(i&16|0)==0?j&-5:j|4;a[f+316|0]=h&7;return};case 144:{a[f+362|0]=h;j=h&255;i=(j&128|0)!=0;if((j&1|0)==0){if(i){g=b[f+356>>1]|0;k=d[f+426|0]|0;l=+(ag(ag(g&65535,(j&64|0)!=0?128:6)|0,k)|0);k=c[f+420>>2]|0;c[f+364>>2]=4;a[f+412|0]=1;a[f+416|0]=1;m=~~(+(k>>>1>>>0>>>0)*1.0/+(k>>>0>>>0)*l);c[f+380>>2]=m;c[f+396>>2]=m;a[f+413|0]=0;b[f+354>>1]=g;return}else{a[f+412|0]=0;a[f+413|0]=0;return}}if(i){i=d[f+426|0]|0;l=+(ag(ag(e[f+354>>1]|0,(j&64|0)!=0?128:12)|0,i)|0);i=c[f+420>>2]|0;c[f+364>>2]=4;a[f+412|0]=1;a[f+416|0]=0;g=~~(+(i>>>1>>>0>>>0)*1.0/+(i>>>0>>>0)*l);c[f+380>>2]=g;c[f+396>>2]=g}else{a[f+412|0]=0}if((j&32|0)==0){a[f+413|0]=0;return}else{g=d[f+426|0]|0;l=+(ag(ag(e[f+356>>1]|0,(j&16|0)!=0?128:12)|0,g)|0);g=c[f+420>>2]|0;c[f+368>>2]=8;a[f+413|0]=1;a[f+417|0]=0;j=~~(+(g>>>1>>>0>>>0)*1.0/+(g>>>0>>>0)*l);c[f+384>>2]=j;c[f+400>>2]=j;return}break};case 78:{j=h&255;g=f+304|0;i=c[g>>2]|0;c[g>>2]=(j&128|0)==0?i&-513:i|512;i=f+308|0;g=c[i>>2]|0;c[i>>2]=(j&64|0)==0?g|512:g&-513;g=f+312|0;i=c[g>>2]|0;if((j&16|0)==0){c[g>>2]=i&-513;return}else{c[g>>2]=i|512;return}break};case 158:{i=h&255;g=f+304|0;j=c[g>>2]|0;c[g>>2]=(i&128|0)==0?j&-17:j|16;j=f+308|0;g=c[j>>2]|0;c[j>>2]=(i&64|0)==0?g|16:g&-17;g=f+312|0;j=c[g>>2]|0;if((i&16|0)==0){c[g>>2]=j&-17;return}else{c[g>>2]=j|16;return}break};case 157:{j=h&255;g=f+304|0;i=c[g>>2]|0;c[g>>2]=(j&128|0)==0?i&-9:i|8;i=f+308|0;g=c[i>>2]|0;c[i>>2]=(j&64|0)==0?g|8:g&-9;g=f+312|0;i=c[g>>2]|0;if((j&16|0)==0){c[g>>2]=i&-9;return}else{c[g>>2]=i|8;return}break};case 8:{gg[c[(c[3531864]|0)+8248>>2]&4095](65538,h&-16);return};case 234:{a[f+289|0]=(h&255)>>>3&1;a[f+290|0]=(h&255)>>>5&1;return};case 235:{i=h&255;a[f+424|0]=(h&255)>>>6&1;g=c[591160+((i>>>2&3)<<2)>>2]|0;a[f+425|0]=g&255;j=i&3;i=(j|0)==3?8:c[591176+(j<<2)>>2]&255;a[f+426|0]=i;j=c[f+420>>2]|0;c[f+376>>2]=65536;a[f+415|0]=1;a[f+419|0]=1;m=~~(+(j>>>1>>>0>>>0)*1.0/+(j>>>0>>>0)*+((i&255)<<(g&255)|0));c[f+392>>2]=m;c[f+408>>2]=m;return};case 255:{c[f+428>>2]=(h&255)<<12|3584;return};case 236:{m=h&-64&255;g=f+304|0;i=c[g>>2]|0;c[g>>2]=(m&128|0)==0?i&-65537:i|65536;i=f+308|0;g=c[i>>2]|0;c[i>>2]=(m&64|0)==0?g|65536:g&-65537;g=f+312|0;c[g>>2]=c[g>>2]&-65537;return};case 145:{g=h&255;a[f+363|0]=h&-64;if((g&128|0)==0){a[f+414|0]=0;return}else{h=b[f+360>>1]|0;m=d[f+426|0]|0;l=+(ag(ag(h&65535,(g&64|0)!=0?128:6)|0,m)|0);m=c[f+420>>2]|0;c[f+372>>2]=16;a[f+414|0]=1;a[f+418|0]=1;g=~~(+(m>>>1>>>0>>>0)*1.0/+(m>>>0>>>0)*l);c[f+388>>2]=g;c[f+404>>2]=g;b[f+358>>1]=h;return}break};default:{return}}}function f9z(d,e,f){d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;if((e&1|0)!=0){g=f&255;h=d+428|0;do{if((e&1048064|0)==(c[h>>2]|0)|(e|0)==1048575){i=e&511;if((a[d+424|0]|0)!=0&i>>>0<256){a[d+i|0]=g;break}if(i>>>0<=255){j=49305;break}f9y(d,i-256|0,g)}else{j=49305}}while(0);do{if((j|0)==49305){i=e&1048575;k=c[3531864]|0;l=c[k+2092+(i>>>11<<2)>>2]|0;if((l|0)==0){gg[c[k+8240>>2]&4095](i,g);break}else{a[l+i|0]=g;break}}}while(0);g=e+1|0;j=(f&65535)>>>8&255;do{if((g&1048064|0)==(c[h>>2]|0)|(g|0)==1048575){i=g&511;if((a[d+424|0]|0)!=0&i>>>0<256){a[d+i|0]=j;return}if(i>>>0<=255){break}f9y(d,i-256|0,j);return}}while(0);h=g&1048575;g=c[3531864]|0;i=c[g+2092+(h>>>11<<2)>>2]|0;if((i|0)==0){gg[c[g+8240>>2]&4095](h,j);return}else{a[i+h|0]=j;return}}j=d+428|0;do{if((e&1048064|0)==(c[j>>2]|0)){h=e&511;if((a[d+424|0]|0)!=0&h>>>0<256){b[d+(h>>>1<<1)>>1]=f;return}if(h>>>0<=255){break}if((h|0)==392){b[d+358>>1]=f;return}else if((h|0)==394){b[d+360>>1]=f;return}else if((h|0)==384){b[d+354>>1]=f;return}else if((h|0)==386){b[d+356>>1]=f;return}else{f9y(d,h-256|0,f&255);f9y(d,h-255|0,(f&65535)>>>8&255);return}}}while(0);d=f&255;h=e&1048575;i=c[3531864]|0;g=c[i+2092+(h>>>11<<2)>>2]|0;if((g|0)==0){gg[c[i+8240>>2]&4095](h,d)}else{a[g+h|0]=d}if((e|0)==1048574){c[j>>2]=((f&65535)>>>8&65535)<<12|3584;return}j=(f&65535)>>>8&255;f=e+1&1048575;e=c[3531864]|0;d=c[e+2092+(f>>>11<<2)>>2]|0;if((d|0)==0){gg[c[e+8240>>2]&4095](f,j);return}else{a[d+f|0]=j;return}}function f9A(a){a=a|0;c[2385308]=9636056+(a*468|0);return}function f9B(){c[2385308]=0;return}function f9C(){var d=0,e=0,f=0;d=c[2385308]|0;b[d+260>>1]=0;a[d+288|0]=1;c[d+264>>2]=0;c[d+268>>2]=0;c[d+272>>2]=0;gGz(d+289|0,0,5);c[d+276>>2]=1;c[d+280>>2]=0;c[d+284>>2]=1;c[d+304>>2]=0;c[d+308>>2]=3;c[d+312>>2]=0;gGz(d+316|0,7,5);a[d+322|0]=0;a[d+321|0]=0;c[d+324>>2]=0;c[d+328>>2]=0;c[d+332>>2]=1;c[d+340>>2]=0;c[d+344>>2]=0;c[d+348>>2]=0;a[d+353|0]=0;c[d+300>>2]=255;c[d+456>>2]=0;gGz(d+354|0,0,10);a[d+424|0]=1;a[d+425|0]=20;a[d+426|0]=8;c[d+428>>2]=1048064;e=d+412|0;C=0;a[e]=C&255;C=C>>8;a[e+1|0]=C&255;C=C>>8;a[e+2|0]=C&255;C=C>>8;a[e+3|0]=C&255;e=c[d+420>>2]|0;c[d+376>>2]=65536;a[d+415|0]=1;a[d+419|0]=1;f=~~(+(e>>>1>>>0>>>0)*1.0/+(e>>>0>>>0)*8388608.0);c[d+392>>2]=f;c[d+408>>2]=f;a[d+295|0]=112;a[d+296|0]=-32;b[d+236>>1]=-1;b[d+234>>1]=0;b[d+232>>1]=0;b[d+238>>1]=0;a[d+443|0]=1;return 0}function f9D(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0;f=c[2385308]|0;switch(b|0){case 10:case 11:case 12:{c[f+300>>2]=d;g=b-10|0;b=f+340+(g<<2)|0;if((c[b>>2]|0)==(e|0)){return}c[b>>2]=e;if((e|0)==0){return}b=f+304|0;c[b>>2]=c[b>>2]|128<<g;return};case 32:{c[f+300>>2]=d;g=f+324|0;if((c[g>>2]|0)==(e|0)){return}c[g>>2]=e;if((e|0)==0){return}g=f+304|0;c[g>>2]=c[g>>2]|2;a[f+353|0]=0;return};case 0:{c[f+300>>2]=d;c[f+328>>2]=e;g=f+304|0;b=c[g>>2]|0;if((e|0)==0){c[g>>2]=b&-2;return}else{c[g>>2]=b|1;a[f+353|0]=0;return}break};case 20:{c[f+300>>2]=d;c[f+332>>2]=e;return};default:{return}}}function f9E(b){b=b|0;var d=0,e=0;d=c[2385308]|0;c[d+436>>2]=b;e=(b|0)==0;a[d+294|0]=e&1;c[d+336>>2]=e&1;return}function f9F(){var a=0;a=c[2385308]|0;return(c[a+460>>2]|0)+(c[a+456>>2]|0)-(c[a+432>>2]|0)|0}function f9G(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0;g=c[2385308]|0;h=g+304|0;i=g+308|0;j=c[i>>2]&c[h>>2];k=g+353|0;l=a[k]|0;L60582:do{if(l<<24>>24==0|(j|0)==0){m=l}else{n=d[g+322|0]|0;o=g+316|0;p=(j&28|0)==0;q=g+317|0;r=(j&96|0)==0;s=g+318|0;t=(j&896|0)==0;u=g+319|0;v=(j&7168|0)==0;w=g+320|0;x=(j&57344|0)==0;y=(j&65536|0)==0;z=0;A=l;while(1){if((1<<z&n|0)!=0){m=A;break L60582}if((d[o]|0)!=(z|0)|p){B=A}else{a[k]=0;B=0}if((d[q]|0)!=(z|0)|r){C=B}else{a[k]=0;C=0}if((d[s]|0)!=(z|0)|t){D=C}else{a[k]=0;D=0}if((d[u]|0)!=(z|0)|v){E=D}else{a[k]=0;E=0}if((d[w]|0)!=(z|0)|x){F=E}else{a[k]=0;F=0}if((z|0)==7){if(y){m=F;break L60582}a[k]=0;G=0}else{G=F}H=z+1|0;if((H|0)<8){z=H;A=G}else{m=G;break}}}}while(0);G=g+432|0;if(m<<24>>24!=0){c[G>>2]=0;I=0;return I|0}c[G>>2]=f;c[g+460>>2]=f;m=g+464|0;L60611:do{if((f|0)>0){F=g+352|0;k=g+292|0;E=g+442|0;D=g+295|0;C=g+260|0;B=g+256|0;l=g+294|0;j=g+436|0;A=g+441|0;z=g+443|0;y=g+440|0;x=g+412|0;w=g+413|0;v=g+414|0;u=g+415|0;t=g+408|0;s=g+419|0;r=g+376|0;q=g+392|0;p=g+404|0;o=g+418|0;n=g+372|0;H=g+388|0;J=g+400|0;K=g+417|0;L=g+368|0;M=g+384|0;N=g+396|0;O=g+416|0;P=g+364|0;Q=g+380|0;R=f;while(1){if((a[m]|0)!=0){S=R;break L60611}T=a[F]|0;if(T<<24>>24==0){U=c[h>>2]|0;do{if((c[i>>2]&U|0)!=0){if((U&2|0)!=0){f9H(g);break}if((a[k]|0)==0){break}f9H(g)}}while(0);U=a[F]|0;if(U<<24>>24!=0){V=U;W=49404}}else{V=T;W=49404}if((W|0)==49404){W=0;a[F]=V-1&255}U=c[G>>2]|0;a[E]=(a[E]|0)-1&255;X=e[g+((d[D]|0)+6<<1)>>1]<<4;Y=b[C>>1]|0;b[C>>1]=Y+1&65535;Z=(X+(Y&65535)^c[B>>2])&1048575;Y=c[3531864]|0;X=c[Y+4140+(Z>>>11<<2)>>2]|0;if((X|0)==0){_=gj[c[Y+8236>>2]&4095](Z)|0}else{_=a[X+Z|0]|0}do{if((a[l]|0)==0){Z=c[j>>2]|0;if((Z|0)==0){$=_;break}$=a[Z+(_&255)|0]|0}else{$=_}}while(0);gf[c[2519504+(($&255)<<2)>>2]&2047](g);T=c[G>>2]|0;Z=U-T|0;X=a[E]|0;L60636:do{if(X<<24>>24<0){Y=d[A]|0;aa=Z;ab=X;while(1){ac=ab+1&255;if((aa|0)<=(Y|0)){break}a[E]=ac;ad=aa-Y|0;if(ac<<24>>24<0){aa=ad;ab=ac}else{ae=ad;af=ac;ah=T;break L60636}}ad=ac<<24>>24>0?ac:0;ai=(ag(Y,~(ad+~ab&255))|0)+T|0;c[G>>2]=ai;a[E]=ad;ae=aa;af=ad;ah=ai}else{ae=Z;af=X;ah=T}}while(0);L60643:do{if((a[z]|0)==0){T=d[A]|0;if((ae|0)<(T|0)){break}X=d[y]|0;Z=ae;ai=af;do{if((ai<<24>>24|0)>=(X|0)){break L60643}Z=Z-T|0;ai=ai+1&255;a[E]=ai;}while((Z|0)>=(T|0))}else{a[E]=0;a[z]=0}}while(0);do{if((a[x]|0)!=0){T=(c[N>>2]|0)+(ah-U)|0;c[N>>2]=T;if((T|0)>=1){break}if((a[O]|0)==0){a[x]=0}else{c[N>>2]=c[Q>>2]}T=(c[2385308]|0)+304|0;c[T>>2]=c[T>>2]|c[P>>2]}}while(0);do{if((a[w]|0)!=0){T=(c[J>>2]|0)+((c[G>>2]|0)-U)|0;c[J>>2]=T;if((T|0)>=1){break}if((a[K]|0)==0){a[w]=0}else{c[J>>2]=c[M>>2]}T=(c[2385308]|0)+304|0;c[T>>2]=c[T>>2]|c[L>>2]}}while(0);do{if((a[v]|0)!=0){T=(c[p>>2]|0)+((c[G>>2]|0)-U)|0;c[p>>2]=T;if((T|0)>=1){break}if((a[o]|0)==0){a[v]=0}else{c[p>>2]=c[H>>2]}T=(c[2385308]|0)+304|0;c[T>>2]=c[T>>2]|c[n>>2]}}while(0);do{if((a[u]|0)!=0){T=(c[t>>2]|0)+((c[G>>2]|0)-U)|0;c[t>>2]=T;if((T|0)>=1){break}if((a[s]|0)==0){a[u]=0}else{c[t>>2]=c[q>>2]}T=(c[2385308]|0)+304|0;c[T>>2]=c[T>>2]|c[r>>2]}}while(0);U=c[G>>2]|0;if((U|0)>0){R=U}else{S=U;break}}}else{S=f}}while(0);a[m]=0;m=f-S|0;S=g+456|0;c[S>>2]=m+(c[S>>2]|0);I=m;return I|0}function f9H(e){e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0;f=e+304|0;g=c[f>>2]|0;h=c[e+308>>2]&g;if((h&2|0)!=0){gd0(e,2,2);c[f>>2]=c[f>>2]&-3;return}if((h&131068|0)==0){if((h&1|0)==0){return}gd0(e,-1,1);c[e+328>>2]=0;c[f>>2]=c[f>>2]&-2;return}i=e+322|0;j=a[i]|0;k=j&255;l=e+316|0;m=(h&8|0)==0;n=(h&16|0)==0;o=e+317|0;p=(h&32|0)==0;q=(h&64|0)==0;r=e+318|0;s=(h&128|0)==0;t=(h&256|0)==0;u=(h&512|0)==0;v=e+319|0;w=(h&1024|0)==0;x=(h&2048|0)==0;y=(h&4096|0)==0;z=e+320|0;A=(h&8192|0)==0;B=(h&16384|0)==0;C=(h&32768|0)==0;D=(h&65536|0)==0;L60697:do{if((h&4|0)==0){E=0;while(1){F=1<<E;if((F&k|0)!=0){G=49566;break}if((d[l]|0|0)==(E|0)){if(!m){G=49503;break}if(!n){G=49506;break}}if((d[o]|0|0)==(E|0)){if(!p){H=E;I=F;G=49511;break L60697}if(!q){J=E;K=F;G=49515;break L60697}}if((d[r]|0|0)==(E|0)){if(!s){L=E;M=F;G=49520;break L60697}if(!t){N=E;O=F;G=49524;break L60697}if(!u){P=E;Q=F;G=49528;break L60697}}if((d[v]|0|0)==(E|0)){if(!w){R=E;S=F;G=49533;break L60697}if(!x){T=E;U=F;G=49537;break L60697}if(!y){V=E;W=F;G=49541;break L60697}}if((d[z]|0|0)==(E|0)){if(!A){X=E;Y=F;G=49546;break L60697}if(!B){Z=E;_=F;G=49550;break L60697}if(!C){$=E;aa=F;G=49554;break L60697}}if((E|0)==7){G=49476;break}ab=E+1|0;if((ab|0)<8){E=ab}else{G=49601;break}}if((G|0)==49476){if(!D){G=49559;break}return}else if((G|0)==49566){return}else if((G|0)==49503){a[e+321|0]=29;a[i]=(F|k)&255;c[f>>2]=g&-9;if((c[e+312>>2]&8|0)==0){gd0(e,29,8);return}else{gd1(e,E);return}}else if((G|0)==49601){return}else if((G|0)==49506){a[e+321|0]=30;a[i]=(F|k)&255;c[f>>2]=g&-17;if((c[e+312>>2]&16|0)==0){gd0(e,30,16);return}else{gd1(e,E);return}}}else{L60743:do{if(m){ab=0;while(1){ac=1<<ab;if((ac&k|0)!=0){G=49583;break}if((d[l]|0|0)==(ab|0)){ad=ab;ae=ac;break L60743}if((d[o]|0|0)==(ab|0)){if(!p){H=ab;I=ac;G=49511;break L60697}if(!q){J=ab;K=ac;G=49515;break L60697}}if((d[r]|0|0)==(ab|0)){if(!s){L=ab;M=ac;G=49520;break L60697}if(!t){N=ab;O=ac;G=49524;break L60697}if(!u){P=ab;Q=ac;G=49528;break L60697}}if((d[v]|0|0)==(ab|0)){if(!w){R=ab;S=ac;G=49533;break L60697}if(!x){T=ab;U=ac;G=49537;break L60697}if(!y){V=ab;W=ac;G=49541;break L60697}}if((d[z]|0|0)==(ab|0)){if(!A){X=ab;Y=ac;G=49546;break L60697}if(!B){Z=ab;_=ac;G=49550;break L60697}if(!C){$=ab;aa=ac;G=49554;break L60697}}if((ab|0)==7){G=49496;break}ac=ab+1|0;if((ac|0)<8){ab=ac}else{G=49591;break}}if((G|0)==49496){if(!D){G=49559;break L60697}return}else if((G|0)==49591){return}else if((G|0)==49583){return}}else{ab=0;while(1){ac=1<<ab;if((ac&k|0)!=0){G=49571;break}if((d[l]|0|0)==(ab|0)){ad=ab;ae=ac;break L60743}if((d[o]|0|0)==(ab|0)){if(!p){H=ab;I=ac;G=49511;break L60697}if(!q){J=ab;K=ac;G=49515;break L60697}}if((d[r]|0|0)==(ab|0)){if(!s){L=ab;M=ac;G=49520;break L60697}if(!t){N=ab;O=ac;G=49524;break L60697}if(!u){P=ab;Q=ac;G=49528;break L60697}}if((d[v]|0|0)==(ab|0)){if(!w){R=ab;S=ac;G=49533;break L60697}if(!x){T=ab;U=ac;G=49537;break L60697}if(!y){V=ab;W=ac;G=49541;break L60697}}if((d[z]|0|0)==(ab|0)){if(!A){X=ab;Y=ac;G=49546;break L60697}if(!B){Z=ab;_=ac;G=49550;break L60697}if(!C){$=ab;aa=ac;G=49554;break L60697}}if((ab|0)==7){G=49558;break}ac=ab+1|0;if((ac|0)<8){ab=ac}else{G=49607;break}}if((G|0)==49607){return}else if((G|0)==49558){if(!D){G=49559;break L60697}return}else if((G|0)==49571){return}}}while(0);a[e+321|0]=28;a[i]=(ae|k)&255;c[f>>2]=g&-5;if((c[e+312>>2]&4|0)==0){gd0(e,28,4);return}else{gd1(e,ad);return}}}while(0);if((G|0)==49541){a[e+321|0]=14;a[i]=(W|k)&255;c[f>>2]=g&-4097;if((c[e+312>>2]&4096|0)==0){gd0(e,14,4096);return}else{gd1(e,V);return}}else if((G|0)==49546){a[e+321|0]=16;a[i]=(Y|k)&255;c[f>>2]=g&-8193;if((c[e+312>>2]&8192|0)==0){gd0(e,16,8192);return}else{gd1(e,X);return}}else if((G|0)==49550){a[e+321|0]=17;a[i]=(_|k)&255;c[f>>2]=g&-16385;if((c[e+312>>2]&16384|0)==0){gd0(e,17,16384);return}else{gd1(e,Z);return}}else if((G|0)==49520){a[e+321|0]=24;a[i]=(M|k)&255;c[f>>2]=g&-129;if((c[e+312>>2]&128|0)==0){gd0(e,24,128);return}else{gd1(e,L);return}}else if((G|0)==49511){a[e+321|0]=20;a[i]=(I|k)&255;c[f>>2]=g&-33;if((c[e+312>>2]&32|0)==0){gd0(e,20,32);return}else{gd1(e,H);return}}else if((G|0)==49515){a[e+321|0]=21;a[i]=(K|k)&255;c[f>>2]=g&-65;if((c[e+312>>2]&64|0)==0){gd0(e,21,64);return}else{gd1(e,J);return}}else if((G|0)==49533){a[e+321|0]=12;a[i]=(S|k)&255;c[f>>2]=g&-1025;if((c[e+312>>2]&1024|0)==0){gd0(e,12,1024);return}else{gd1(e,R);return}}else if((G|0)==49537){a[e+321|0]=13;a[i]=(U|k)&255;c[f>>2]=g&-2049;if((c[e+312>>2]&2048|0)==0){gd0(e,13,2048);return}else{gd1(e,T);return}}else if((G|0)==49524){a[e+321|0]=25;a[i]=(O|k)&255;c[f>>2]=g&-257;if((c[e+312>>2]&256|0)==0){gd0(e,25,256);return}else{gd1(e,N);return}}else if((G|0)==49528){a[e+321|0]=26;a[i]=(Q|k)&255;c[f>>2]=g&-513;if((c[e+312>>2]&512|0)==0){gd0(e,26,512);return}else{gd1(e,P);return}}else if((G|0)==49554){a[e+321|0]=18;a[i]=(aa|k)&255;c[f>>2]=g&-32769;if((c[e+312>>2]&32768|0)==0){gd0(e,18,32768);return}else{gd1(e,$);return}}else if((G|0)==49559){a[e+321|0]=31;a[i]=j|-128;c[f>>2]=g&-65537;if((c[e+312>>2]&65536|0)==0){gd0(e,31,65536);return}else{g=e+291|0;f=e+292|0;j=e+295|0;i=e+294|0;G=((d[e+288|0]|0)<<1|(c[e+280>>2]|0)!=0|(d[9760944+(c[e+284>>2]&255)|0]|0)<<2|(d[e+289|0]|0)<<3|((c[e+268>>2]|0)!=0)<<4|(d[e+290|0]|0)<<5|((c[e+276>>2]|0)==0)<<6|(c[e+264>>2]|0)>>>31<<7|(d[g]|0)<<8|(d[f]|0)<<9|(d[e+293|0]|0)<<10|((c[e+272>>2]|0)!=0)<<11|(d[j]|0)>>>4<<12|(d[i]|0)<<15)&65535;a[f]=0;a[g]=0;a[i]=c[e+336>>2]&255;a[j]=112;a[e+296|0]=-32;b[e+228>>1]=G;G=e+260|0;b[e+230>>1]=b[G>>1]|0;b[G>>1]=b[e+226>>1]|0;a[e+443|0]=1;return}}}function f9I(){a[(c[2385308]|0)+464|0]=1;return}function f9J(a){a=a|0;var b=0;b=(c[2385308]|0)+432|0;c[b>>2]=(c[b>>2]|0)-a;return}function f9K(a){a=a|0;var b=0,f=0;if((a|0)==-1){b=c[2385308]|0;f=((e[b+((d[b+295|0]|0)+6<<1)>>1]|0)<<4)+(e[b+260>>1]|0)|0;return f|0}else{f=((e[9636056+(a*468|0)+((d[9636351+(a*468|0)|0]|0)+6<<1)>>1]|0)<<4)+(e[9636316+(a*468|0)>>1]|0)|0;return f|0}return 0}function f9L(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;e=i;i=i+24|0;f=e|0;g=e+16|0;if((d&64|0)==0){i=e;return}d=g|0;a[d]=a[614864]|0;a[d+1|0]=a[614865]|0;a[d+2|0]=a[614866]|0;a[d+3|0]=a[614867]|0;a[d+4|0]=a[614868]|0;a[d+5|0]=a[614869]|0;a[d+6|0]=a[614870]|0;a[g+5|0]=b+49&255;gGz(f|0,0,12);c[f>>2]=9636056+(b*468|0);c[f+4>>2]=468;c[f+12>>2]=d;gj[c[2076592]&4095](f)|0;i=e;return}function f9M(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=f+442|0;a[g]=(a[g]|0)-1&255;g=e[f+((d[f+295|0]|0)+6<<1)>>1]<<4;h=f+260|0;i=b[h>>1]|0;b[h>>1]=i+1&65535;h=(g+(i&65535)^c[f+256>>2])&1048575;i=c[3531864]|0;g=c[i+6188+(h>>>11<<2)>>2]|0;if((g|0)==0){j=gj[c[i+8236>>2]&4095](h)|0}else{j=a[g+h|0]|0}h=j&255;g=f+296|0;i=d[g]|0;k=f;l=a[k+(i+(c[9651808+(h<<2)>>2]|0))|0]|0;m=l&255;n=(j&255)>191;L60899:do{if(n){o=a[k+((c[9647712+(h<<2)>>2]|0)+i)|0]|0}else{j=gj[c[678944+(h<<2)>>2]&4095](f)|0;do{if((j&1048064|0)==(c[f+428>>2]|0)|(j|0)==1048575){p=j&511;if((a[f+424|0]|0)!=0&p>>>0<256){o=a[k+p|0]|0;break L60899}if(p>>>0<=255){break}o=f9w(f,p-256|0)|0;break L60899}}while(0);p=j&1048575;q=c[3531864]|0;r=c[q+44+(p>>>11<<2)>>2]|0;if((r|0)==0){o=gj[c[q+8236>>2]&4095](p)|0;break}else{o=a[r+p|0]|0;break}}}while(0);i=o&255;p=i+m|0;c[f+280>>2]=p&256;c[f+272>>2]=(p^i)&128&(p^m);c[f+268>>2]=(p^(o^l)&255)&16;l=p<<24>>24;c[f+284>>2]=l;c[f+276>>2]=l;c[f+264>>2]=l;L60913:do{if(n){a[k+((d[g]|0)+(c[9647712+(h<<2)>>2]|0))|0]=p&255}else{l=c[2426954]|0;o=p&255;do{if((l&1048064|0)==(c[f+428>>2]|0)|(l|0)==1048575){m=l&511;if((a[f+424|0]|0)!=0&m>>>0<256){a[k+m|0]=o;break L60913}if(m>>>0<=255){break}f9y(f,m-256|0,o);break L60913}}while(0);j=l&1048575;m=c[3531864]|0;i=c[m+2092+(j>>>11<<2)>>2]|0;if((i|0)==0){gg[c[m+8240>>2]&4095](j,o);break}else{a[i+j|0]=o;break}}}while(0);k=f+432|0;c[k>>2]=(c[k>>2]|0)-((n?131586:1052679)>>>((c[f+444>>2]|0)>>>0)&127);return}function f9N(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=f+442|0;a[g]=(a[g]|0)-1&255;g=f+295|0;h=a[g]|0;i=(e[f+((h&255)+6<<1)>>1]|0)<<4;j=f+260|0;k=b[j>>1]|0;b[j>>1]=k+1&65535;j=(i+(k&65535)^c[f+256>>2])&1048575;k=c[3531864]|0;i=c[k+6188+(j>>>11<<2)>>2]|0;if((i|0)==0){l=gj[c[k+8236>>2]&4095](j)|0;m=l;n=a[g]|0}else{m=a[i+j|0]|0;n=h}h=m&255;j=n&255;n=b[f+(j+(c[9653856+(h<<2)>>2]|0)<<1)>>1]|0;i=n&65535;l=(m&255)>191;if(l){o=b[f+((c[9649760+(h<<2)>>2]|0)+j<<1)>>1]|0}else{j=c[678944+(h<<2)>>2]|0;gj[j&4095](f)|0;o=f9x(f,c[2426954]|0)|0}j=o&65535;m=j+i|0;c[f+280>>2]=m&65536;c[f+272>>2]=(m^j)&32768&(m^i);c[f+268>>2]=(m^(o^n)&65535)&16;n=m<<16>>16;c[f+284>>2]=n;c[f+276>>2]=n;c[f+264>>2]=n;if(l){b[f+((d[g]|0)+(c[9649760+(h<<2)>>2]|0)<<1)>>1]=m&65535;h=f+432|0;c[h>>2]=(c[h>>2]|0)-2;return}else{f9z(f,c[2426954]|0,m&65535);m=f+432|0;c[m>>2]=(c[m>>2]|0)-(((c[2426954]&1|0)!=0?1579019:1576967)>>>((c[f+444>>2]|0)>>>0)&127);return}}function f9O(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=f+442|0;a[g]=(a[g]|0)-1&255;g=e[f+((d[f+295|0]|0)+6<<1)>>1]<<4;h=f+260|0;i=b[h>>1]|0;b[h>>1]=i+1&65535;h=(g+(i&65535)^c[f+256>>2])&1048575;i=c[3531864]|0;g=c[i+6188+(h>>>11<<2)>>2]|0;if((g|0)==0){j=gj[c[i+8236>>2]&4095](h)|0}else{j=a[g+h|0]|0}h=j&255;g=f+296|0;i=d[g]|0;k=9651808+(h<<2)|0;l=f;m=a[l+(i+(c[k>>2]|0))|0]|0;n=m&255;o=(j&255)>191;L60946:do{if(o){p=a[l+((c[9647712+(h<<2)>>2]|0)+i)|0]|0}else{j=gj[c[678944+(h<<2)>>2]&4095](f)|0;do{if((j&1048064|0)==(c[f+428>>2]|0)|(j|0)==1048575){q=j&511;if((a[f+424|0]|0)!=0&q>>>0<256){p=a[l+q|0]|0;break L60946}if(q>>>0<=255){break}p=f9w(f,q-256|0)|0;break L60946}}while(0);q=j&1048575;r=c[3531864]|0;s=c[r+44+(q>>>11<<2)>>2]|0;if((s|0)==0){p=gj[c[r+8236>>2]&4095](q)|0;break}else{p=a[s+q|0]|0;break}}}while(0);h=p&255;i=h+n|0;c[f+280>>2]=i&256;c[f+272>>2]=(i^n)&128&(i^h);c[f+268>>2]=(i^(p^m)&255)&16;m=i&255;i=m<<24>>24;c[f+284>>2]=i;c[f+276>>2]=i;c[f+264>>2]=i;a[l+((d[g]|0)+(c[k>>2]|0))|0]=m;m=f+432|0;c[m>>2]=(c[m>>2]|0)-((o?131586:723718)>>>((c[f+444>>2]|0)>>>0)&127);return}function f9P(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=d+442|0;a[f]=(a[f]|0)-1&255;f=d+295|0;g=a[f]|0;h=(e[d+((g&255)+6<<1)>>1]|0)<<4;i=d+260|0;j=b[i>>1]|0;b[i>>1]=j+1&65535;i=(h+(j&65535)^c[d+256>>2])&1048575;j=c[3531864]|0;h=c[j+6188+(i>>>11<<2)>>2]|0;if((h|0)==0){k=gj[c[j+8236>>2]&4095](i)|0;l=k;m=a[f]|0}else{l=a[h+i|0]|0;m=g}g=l&255;i=m&255;h=9653856+(g<<2)|0;k=c[h>>2]|0;j=b[d+(i+k<<1)>>1]|0;n=j&65535;o=(l&255)>191;if(o){p=b[d+((c[9649760+(g<<2)>>2]|0)+i<<1)>>1]|0;q=m;r=k}else{k=c[678944+(g<<2)>>2]|0;gj[k&4095](d)|0;k=f9x(d,c[2426954]|0)|0;p=k;q=a[f]|0;r=c[h>>2]|0}h=p&65535;f=h+n|0;c[d+280>>2]=f&65536;c[d+272>>2]=(f^n)&32768&(f^h);c[d+268>>2]=(f^(p^j)&65535)&16;j=f&65535;f=j<<16>>16;c[d+284>>2]=f;c[d+276>>2]=f;c[d+264>>2]=f;b[d+(r+(q&255)<<1)>>1]=j;if(o){o=d+432|0;c[o>>2]=(c[o>>2]|0)-2;return}else{o=d+432|0;c[o>>2]=(c[o>>2]|0)-(((c[2426954]&1|0)!=0?986888:985862)>>>((c[d+444>>2]|0)>>>0)&127);return}}function f9Q(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;g=f+442|0;a[g]=(a[g]|0)-1&255;g=(e[f+((d[f+295|0]|0)+6<<1)>>1]|0)<<4;h=f+260|0;i=b[h>>1]|0;b[h>>1]=i+1&65535;h=(g+(i&65535)^c[f+256>>2])&1048575;i=c[3531864]|0;g=c[i+6188+(h>>>11<<2)>>2]|0;if((g|0)==0){j=gj[c[i+8236>>2]&4095](h)|0}else{j=a[g+h|0]|0}h=j&255;g=f+((d[f+296|0]|0)+30)|0;i=a[g]|0;k=i&255;l=k+h|0;c[f+280>>2]=l&256;c[f+272>>2]=(l^k)&128&(l^h);c[f+268>>2]=(l^(i^j)&255)&16;j=l&255;l=j<<24>>24;c[f+284>>2]=l;c[f+276>>2]=l;c[f+264>>2]=l;a[g]=j;j=f+432|0;c[j>>2]=(c[j>>2]|0)-(263170>>>((c[f+444>>2]|0)>>>0)&127);return}function f9R(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;f=d+442|0;g=(a[f]|0)-1&255;a[f]=g;h=d+295|0;i=a[h]|0;j=(e[d+((i&255)+6<<1)>>1]|0)<<4;k=d+260|0;l=b[k>>1]|0;m=l+1&65535;b[k>>1]=m;n=d+256|0;o=c[n>>2]|0;p=(j+(l&65535)^o)&1048575;l=c[3531864]|0;j=c[l+6188+(p>>>11<<2)>>2]|0;if((j|0)==0){q=gj[c[l+8236>>2]&4095](p)|0;r=q;s=a[h]|0;t=a[f]|0;u=b[k>>1]|0;v=c[n>>2]|0;w=c[3531864]|0}else{r=a[j+p|0]|0;s=i;t=g;u=m;v=o;w=l}l=r&255;r=s&255;o=e[d+(r+15<<1)>>1]|0;a[f]=t-1&255;t=(e[d+(r+6<<1)>>1]|0)<<4;b[k>>1]=u+1&65535;k=(t+(u&65535)^v)&1048575;v=c[w+6188+(k>>>11<<2)>>2]|0;if((v|0)==0){u=gj[c[w+8236>>2]&4095](k)|0;x=u;y=a[h]|0}else{x=a[v+k|0]|0;y=s}s=(x&255)<<8;x=(s|l)+o|0;c[d+280>>2]=x&65536;c[d+272>>2]=(x^o)&32768&(x^s);c[d+268>>2]=(o^l^x)&16;l=x&65535;x=l<<16>>16;c[d+284>>2]=x;c[d+276>>2]=x;c[d+264>>2]=x;b[d+((y&255)+15<<1)>>1]=l;l=d+432|0;c[l>>2]=(c[l>>2]|0)-(263170>>>((c[d+444>>2]|0)>>>0)&127);return}function f9S(a){a=a|0;var f=0,g=0;f=a+295|0;g=a+((d[f]|0)+11<<1)|0;b[g>>1]=(b[g>>1]|0)-2&65535;g=d[f]|0;f9z(a,((e[a+(g+5<<1)>>1]|0)<<4)+(e[a+(g+11<<1)>>1]|0)|0,b[a+(g+7<<1)>>1]|0);g=a+432|0;c[g>>2]=(c[g>>2]|0)-(788483>>>((c[a+444>>2]|0)>>>0)&127);return}function f9T(a){a=a|0;var f=0,g=0,h=0;f=a+295|0;g=a+((d[f]|0)+11<<1)|0;b[g>>1]=(b[g>>1]|0)+2&65535;g=d[f]|0;h=f9x(a,((e[a+(g+11<<1)>>1]|0)+65534&65535)+((e[a+(g+5<<1)>>1]|0)<<4)|0)|0;b[a+((d[f]|0)+7<<1)>>1]=h;h=a+432|0;c[h>>2]=(c[h>>2]|0)-(788485>>>((c[a+444>>2]|0)>>>0)&127);return}function f9U(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=f+442|0;a[g]=(a[g]|0)-1&255;g=e[f+((d[f+295|0]|0)+6<<1)>>1]<<4;h=f+260|0;i=b[h>>1]|0;b[h>>1]=i+1&65535;h=(g+(i&65535)^c[f+256>>2])&1048575;i=c[3531864]|0;g=c[i+6188+(h>>>11<<2)>>2]|0;if((g|0)==0){j=gj[c[i+8236>>2]&4095](h)|0}else{j=a[g+h|0]|0}h=j&255;g=f+296|0;i=d[g]|0;k=f;l=a[k+(i+(c[9651808+(h<<2)>>2]|0))|0]|0;m=(j&255)>191;L60995:do{if(m){n=a[k+((c[9647712+(h<<2)>>2]|0)+i)|0]|0}else{j=gj[c[678944+(h<<2)>>2]&4095](f)|0;do{if((j&1048064|0)==(c[f+428>>2]|0)|(j|0)==1048575){o=j&511;if((a[f+424|0]|0)!=0&o>>>0<256){n=a[k+o|0]|0;break L60995}if(o>>>0<=255){break}n=f9w(f,o-256|0)|0;break L60995}}while(0);o=j&1048575;p=c[3531864]|0;q=c[p+44+(o>>>11<<2)>>2]|0;if((q|0)==0){n=gj[c[p+8236>>2]&4095](o)|0;break}else{n=a[q+o|0]|0;break}}}while(0);i=n|l;c[f+268>>2]=0;c[f+272>>2]=0;c[f+280>>2]=0;l=i<<24>>24;c[f+284>>2]=l;c[f+276>>2]=l;c[f+264>>2]=l;L61009:do{if(m){a[k+((d[g]|0)+(c[9647712+(h<<2)>>2]|0))|0]=i}else{l=c[2426954]|0;do{if((l&1048064|0)==(c[f+428>>2]|0)|(l|0)==1048575){n=l&511;if((a[f+424|0]|0)!=0&n>>>0<256){a[k+n|0]=i;break L61009}if(n>>>0<=255){break}f9y(f,n-256|0,i);break L61009}}while(0);j=l&1048575;n=c[3531864]|0;o=c[n+2092+(j>>>11<<2)>>2]|0;if((o|0)==0){gg[c[n+8240>>2]&4095](j,i);break}else{a[o+j|0]=i;break}}}while(0);i=f+432|0;c[i>>2]=(c[i>>2]|0)-((m?131586:1052679)>>>((c[f+444>>2]|0)>>>0)&127);return}function f9V(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=f+442|0;a[g]=(a[g]|0)-1&255;g=f+295|0;h=a[g]|0;i=(e[f+((h&255)+6<<1)>>1]|0)<<4;j=f+260|0;k=b[j>>1]|0;b[j>>1]=k+1&65535;j=(i+(k&65535)^c[f+256>>2])&1048575;k=c[3531864]|0;i=c[k+6188+(j>>>11<<2)>>2]|0;if((i|0)==0){l=gj[c[k+8236>>2]&4095](j)|0;m=l;n=a[g]|0}else{m=a[i+j|0]|0;n=h}h=m&255;j=n&255;n=b[f+(j+(c[9653856+(h<<2)>>2]|0)<<1)>>1]|0;i=(m&255)>191;if(i){o=b[f+((c[9649760+(h<<2)>>2]|0)+j<<1)>>1]|0}else{j=c[678944+(h<<2)>>2]|0;gj[j&4095](f)|0;o=f9x(f,c[2426954]|0)|0}j=o|n;c[f+268>>2]=0;c[f+272>>2]=0;c[f+280>>2]=0;n=j<<16>>16;c[f+284>>2]=n;c[f+276>>2]=n;c[f+264>>2]=n;if(i){b[f+((d[g]|0)+(c[9649760+(h<<2)>>2]|0)<<1)>>1]=j;h=f+432|0;c[h>>2]=(c[h>>2]|0)-2;return}else{f9z(f,c[2426954]|0,j);j=f+432|0;c[j>>2]=(c[j>>2]|0)-(((c[2426954]&1|0)!=0?1579019:1576967)>>>((c[f+444>>2]|0)>>>0)&127);return}}function f9W(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=f+442|0;a[g]=(a[g]|0)-1&255;g=e[f+((d[f+295|0]|0)+6<<1)>>1]<<4;h=f+260|0;i=b[h>>1]|0;b[h>>1]=i+1&65535;h=(g+(i&65535)^c[f+256>>2])&1048575;i=c[3531864]|0;g=c[i+6188+(h>>>11<<2)>>2]|0;if((g|0)==0){j=gj[c[i+8236>>2]&4095](h)|0}else{j=a[g+h|0]|0}h=j&255;g=f+296|0;i=d[g]|0;k=9651808+(h<<2)|0;l=f;m=a[l+(i+(c[k>>2]|0))|0]|0;n=(j&255)>191;L61042:do{if(n){o=a[l+((c[9647712+(h<<2)>>2]|0)+i)|0]|0}else{j=gj[c[678944+(h<<2)>>2]&4095](f)|0;do{if((j&1048064|0)==(c[f+428>>2]|0)|(j|0)==1048575){p=j&511;if((a[f+424|0]|0)!=0&p>>>0<256){o=a[l+p|0]|0;break L61042}if(p>>>0<=255){break}o=f9w(f,p-256|0)|0;break L61042}}while(0);p=j&1048575;q=c[3531864]|0;r=c[q+44+(p>>>11<<2)>>2]|0;if((r|0)==0){o=gj[c[q+8236>>2]&4095](p)|0;break}else{o=a[r+p|0]|0;break}}}while(0);h=o|m;c[f+268>>2]=0;c[f+272>>2]=0;c[f+280>>2]=0;m=h<<24>>24;c[f+284>>2]=m;c[f+276>>2]=m;c[f+264>>2]=m;a[l+((d[g]|0)+(c[k>>2]|0))|0]=h;h=f+432|0;c[h>>2]=(c[h>>2]|0)-((n?131586:723718)>>>((c[f+444>>2]|0)>>>0)&127);return}function f9X(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=d+442|0;a[f]=(a[f]|0)-1&255;f=d+295|0;g=a[f]|0;h=(e[d+((g&255)+6<<1)>>1]|0)<<4;i=d+260|0;j=b[i>>1]|0;b[i>>1]=j+1&65535;i=(h+(j&65535)^c[d+256>>2])&1048575;j=c[3531864]|0;h=c[j+6188+(i>>>11<<2)>>2]|0;if((h|0)==0){k=gj[c[j+8236>>2]&4095](i)|0;l=k;m=a[f]|0}else{l=a[h+i|0]|0;m=g}g=l&255;i=m&255;h=9653856+(g<<2)|0;k=c[h>>2]|0;j=b[d+(i+k<<1)>>1]|0;n=(l&255)>191;if(n){o=b[d+((c[9649760+(g<<2)>>2]|0)+i<<1)>>1]|0;p=m;q=k}else{k=c[678944+(g<<2)>>2]|0;gj[k&4095](d)|0;k=f9x(d,c[2426954]|0)|0;o=k;p=a[f]|0;q=c[h>>2]|0}h=o|j;c[d+268>>2]=0;c[d+272>>2]=0;c[d+280>>2]=0;j=h<<16>>16;c[d+284>>2]=j;c[d+276>>2]=j;c[d+264>>2]=j;b[d+(q+(p&255)<<1)>>1]=h;if(n){n=d+432|0;c[n>>2]=(c[n>>2]|0)-2;return}else{n=d+432|0;c[n>>2]=(c[n>>2]|0)-(((c[2426954]&1|0)!=0?986888:985862)>>>((c[d+444>>2]|0)>>>0)&127);return}}function f9Y(f){f=f|0;var g=0,h=0,i=0,j=0;g=f+442|0;a[g]=(a[g]|0)-1&255;g=(e[f+((d[f+295|0]|0)+6<<1)>>1]|0)<<4;h=f+260|0;i=b[h>>1]|0;b[h>>1]=i+1&65535;h=(g+(i&65535)^c[f+256>>2])&1048575;i=c[3531864]|0;g=c[i+6188+(h>>>11<<2)>>2]|0;if((g|0)==0){j=gj[c[i+8236>>2]&4095](h)|0}else{j=a[g+h|0]|0}h=f+((d[f+296|0]|0)+30)|0;g=a[h]|j;c[f+268>>2]=0;c[f+272>>2]=0;c[f+280>>2]=0;j=g<<24>>24;c[f+284>>2]=j;c[f+276>>2]=j;c[f+264>>2]=j;a[h]=g;g=f+432|0;c[g>>2]=(c[g>>2]|0)-(263170>>>((c[f+444>>2]|0)>>>0)&127);return}function f9Z(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;f=d+442|0;g=(a[f]|0)-1&255;a[f]=g;h=d+295|0;i=a[h]|0;j=(e[d+((i&255)+6<<1)>>1]|0)<<4;k=d+260|0;l=b[k>>1]|0;m=l+1&65535;b[k>>1]=m;n=d+256|0;o=c[n>>2]|0;p=(j+(l&65535)^o)&1048575;l=c[3531864]|0;j=c[l+6188+(p>>>11<<2)>>2]|0;if((j|0)==0){q=gj[c[l+8236>>2]&4095](p)|0;r=q;s=a[h]|0;t=a[f]|0;u=b[k>>1]|0;v=c[n>>2]|0;w=c[3531864]|0}else{r=a[j+p|0]|0;s=i;t=g;u=m;v=o;w=l}l=s&255;o=b[d+(l+15<<1)>>1]|0;a[f]=t-1&255;t=(e[d+(l+6<<1)>>1]|0)<<4;b[k>>1]=u+1&65535;k=(t+(u&65535)^v)&1048575;v=c[w+6188+(k>>>11<<2)>>2]|0;if((v|0)==0){u=gj[c[w+8236>>2]&4095](k)|0;x=u;y=a[h]|0}else{x=a[v+k|0]|0;y=s}s=o|r&255|(x&255)<<8;c[d+268>>2]=0;c[d+272>>2]=0;c[d+280>>2]=0;x=s<<16>>16;c[d+284>>2]=x;c[d+276>>2]=x;c[d+264>>2]=x;b[d+((y&255)+15<<1)>>1]=s;s=d+432|0;c[s>>2]=(c[s>>2]|0)-(263170>>>((c[d+444>>2]|0)>>>0)&127);return}function f9_(a){a=a|0;var f=0,g=0;f=a+295|0;g=a+((d[f]|0)+11<<1)|0;b[g>>1]=(b[g>>1]|0)-2&65535;g=d[f]|0;f9z(a,((e[a+(g+5<<1)>>1]|0)<<4)+(e[a+(g+11<<1)>>1]|0)|0,b[a+(g+6<<1)>>1]|0);g=a+432|0;c[g>>2]=(c[g>>2]|0)-(788483>>>((c[a+444>>2]|0)>>>0)&127);return}function f9$(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0;g=f+442|0;a[g]=(a[g]|0)-1&255;h=f+295|0;i=e[f+((d[h]|0)+6<<1)>>1]<<4;j=f+260|0;k=b[j>>1]|0;b[j>>1]=k+1&65535;l=f+256|0;m=(i+(k&65535)^c[l>>2])&1048575;k=c[3531864]|0;i=c[k+6188+(m>>>11<<2)>>2]|0;if((i|0)==0){n=gj[c[k+8236>>2]&4095](m)|0}else{n=a[i+m|0]|0}switch(n&255|0){case 17:{a[g]=(a[g]|0)-1&255;n=e[f+((d[h]|0)+6<<1)>>1]<<4;m=b[j>>1]|0;b[j>>1]=m+1&65535;i=(n+(m&65535)^c[l>>2])&1048575;m=c[3531864]|0;n=c[m+6188+(i>>>11<<2)>>2]|0;if((n|0)==0){o=gj[c[m+8236>>2]&4095](i)|0}else{o=a[n+i|0]|0}i=o&255;if((o&255)>191){p=b[f+((d[h]|0)+(c[9649760+(i<<2)>>2]|0)<<1)>>1]|0}else{o=c[678944+(i<<2)>>2]|0;gj[o&4095](f)|0;p=f9x(f,c[2426954]|0)|0}o=f+432|0;c[o>>2]=(c[o>>2]|0)-(197380>>>((c[f+444>>2]|0)>>>0)&127);c[f+276>>2]=(1<<(a[f+((d[f+296|0]|0)+28)|0]&15)&(p&65535)|0)!=0;c[f+272>>2]=0;c[f+280>>2]=0;return};case 16:{a[g]=(a[g]|0)-1&255;p=e[f+((d[h]|0)+6<<1)>>1]<<4;o=b[j>>1]|0;b[j>>1]=o+1&65535;i=(p+(o&65535)^c[l>>2])&1048575;o=c[3531864]|0;p=c[o+6188+(i>>>11<<2)>>2]|0;if((p|0)==0){q=gj[c[o+8236>>2]&4095](i)|0}else{q=a[p+i|0]|0}i=q&255;L61106:do{if((q&255)>191){r=a[f+((d[f+296|0]|0)+(c[9647712+(i<<2)>>2]|0))|0]|0}else{p=c[678944+(i<<2)>>2]|0;gj[p&4095](f)|0;p=c[2426954]|0;do{if((p&1048064|0)==(c[f+428>>2]|0)|(p|0)==1048575){o=p&511;if((a[f+424|0]|0)!=0&o>>>0<256){r=a[f+o|0]|0;break L61106}if(o>>>0<=255){break}r=f9w(f,o-256|0)|0;break L61106}}while(0);o=p&1048575;n=c[3531864]|0;m=c[n+44+(o>>>11<<2)>>2]|0;if((m|0)==0){r=gj[c[n+8236>>2]&4095](o)|0;break}else{r=a[m+o|0]|0;break}}}while(0);i=f+432|0;c[i>>2]=(c[i>>2]|0)-(197380>>>((c[f+444>>2]|0)>>>0)&127);c[f+276>>2]=(1<<(a[f+((d[f+296|0]|0)+28)|0]&7)&(r&255)|0)!=0;c[f+272>>2]=0;c[f+280>>2]=0;return};case 146:{r=f+322|0;i=1;while(1){if(i>>>0>=256){break}s=d[r]|0;if((s&i|0)==0){i=i<<1}else{t=50203;break}}if((t|0)==50203){a[r]=s&(i^255)&255}i=f+432|0;c[i>>2]=(c[i>>2]|0)-2;a[f+352|0]=1;return};case 26:{a[g]=(a[g]|0)-1&255;i=e[f+((d[h]|0)+6<<1)>>1]<<4;s=b[j>>1]|0;b[j>>1]=s+1&65535;r=(i+(s&65535)^c[l>>2])&1048575;s=c[3531864]|0;i=c[s+6188+(r>>>11<<2)>>2]|0;if((i|0)==0){u=gj[c[s+8236>>2]&4095](r)|0}else{u=a[i+r|0]|0}r=u&255;i=(u&255)>191;L61134:do{if(i){v=a[f+((d[f+296|0]|0)+(c[9647712+(r<<2)>>2]|0))|0]|0}else{u=c[678944+(r<<2)>>2]|0;gj[u&4095](f)|0;u=c[2426954]|0;do{if((u&1048064|0)==(c[f+428>>2]|0)|(u|0)==1048575){s=u&511;if((a[f+424|0]|0)!=0&s>>>0<256){v=a[f+s|0]|0;break L61134}if(s>>>0<=255){break}v=f9w(f,s-256|0)|0;break L61134}}while(0);p=u&1048575;s=c[3531864]|0;q=c[s+44+(p>>>11<<2)>>2]|0;if((q|0)==0){v=gj[c[s+8236>>2]&4095](p)|0;break}else{v=a[q+p|0]|0;break}}}while(0);p=f+432|0;c[p>>2]=(c[p>>2]|0)-(394756>>>((c[f+444>>2]|0)>>>0)&127);a[g]=(a[g]|0)-1&255;p=e[f+((d[h]|0)+6<<1)>>1]<<4;q=b[j>>1]|0;b[j>>1]=q+1&65535;s=(p+(q&65535)^c[l>>2])&1048575;q=c[3531864]|0;p=c[q+6188+(s>>>11<<2)>>2]|0;if((p|0)==0){w=gj[c[q+8236>>2]&4095](s)|0}else{w=a[p+s|0]|0}s=v&255&~(1<<(w&7));if(i){a[f+((d[f+296|0]|0)+(c[9647712+(r<<2)>>2]|0))|0]=s&255;return}r=c[2426954]|0;i=s&255;do{if((r&1048064|0)==(c[f+428>>2]|0)|(r|0)==1048575){s=r&511;if((a[f+424|0]|0)!=0&s>>>0<256){a[f+s|0]=i;return}if(s>>>0<=255){break}f9y(f,s-256|0,i);return}}while(0);s=r&1048575;r=c[3531864]|0;w=c[r+2092+(s>>>11<<2)>>2]|0;if((w|0)==0){gg[c[r+8240>>2]&4095](s,i);return}else{a[w+s|0]=i;return}break};case 158:{c[f+432>>2]=0;return};case 149:{a[g]=(a[g]|0)-1&255;i=e[f+((d[h]|0)+6<<1)>>1]<<4;s=b[j>>1]|0;b[j>>1]=s+1&65535;w=(i+(s&65535)^c[l>>2])&1048575;s=c[3531864]|0;i=c[s+6188+(w>>>11<<2)>>2]|0;if((i|0)==0){x=gj[c[s+8236>>2]&4095](w)|0}else{x=a[i+w|0]|0}if((x&255)>191){w=a[h]|0;y=e[f+((w&255)+(c[9649760+((x&255)<<2)>>2]|0)<<1)>>1]<<4&112;z=w}else{y=0;z=a[h]|0}b[f+((y|5)<<1)>>1]=b[f+((z&255)+5<<1)>>1]|0;b[f+((y|11)<<1)>>1]=b[f+((d[h]|0)+11<<1)>>1]|0;y=f+432|0;c[y>>2]=(c[y>>2]|0)-11;return};case 18:{a[g]=(a[g]|0)-1&255;y=e[f+((d[h]|0)+6<<1)>>1]<<4;z=b[j>>1]|0;b[j>>1]=z+1&65535;w=(y+(z&65535)^c[l>>2])&1048575;z=c[3531864]|0;y=c[z+6188+(w>>>11<<2)>>2]|0;if((y|0)==0){A=gj[c[z+8236>>2]&4095](w)|0}else{A=a[y+w|0]|0}w=A&255;y=(A&255)>191;L61187:do{if(y){B=a[f+((d[f+296|0]|0)+(c[9647712+(w<<2)>>2]|0))|0]|0}else{A=c[678944+(w<<2)>>2]|0;gj[A&4095](f)|0;A=c[2426954]|0;do{if((A&1048064|0)==(c[f+428>>2]|0)|(A|0)==1048575){z=A&511;if((a[f+424|0]|0)!=0&z>>>0<256){B=a[f+z|0]|0;break L61187}if(z>>>0<=255){break}B=f9w(f,z-256|0)|0;break L61187}}while(0);u=A&1048575;z=c[3531864]|0;x=c[z+44+(u>>>11<<2)>>2]|0;if((x|0)==0){B=gj[c[z+8236>>2]&4095](u)|0;break}else{B=a[x+u|0]|0;break}}}while(0);u=f+432|0;c[u>>2]=(c[u>>2]|0)-(328964>>>((c[f+444>>2]|0)>>>0)&127);u=d[f+296|0]|0;x=f;z=B&255&~(1<<(a[x+(u+28)|0]&7));if(y){a[x+((c[9647712+(w<<2)>>2]|0)+u)|0]=z&255;return}u=c[2426954]|0;w=z&255;do{if((u&1048064|0)==(c[f+428>>2]|0)|(u|0)==1048575){z=u&511;if((a[f+424|0]|0)!=0&z>>>0<256){a[x+z|0]=w;return}if(z>>>0<=255){break}f9y(f,z-256|0,w);return}}while(0);x=u&1048575;u=c[3531864]|0;z=c[u+2092+(x>>>11<<2)>>2]|0;if((z|0)==0){gg[c[u+8240>>2]&4095](x,w);return}else{a[z+x|0]=w;return}break};case 30:{a[g]=(a[g]|0)-1&255;w=e[f+((d[h]|0)+6<<1)>>1]<<4;x=b[j>>1]|0;b[j>>1]=x+1&65535;z=(w+(x&65535)^c[l>>2])&1048575;x=c[3531864]|0;w=c[x+6188+(z>>>11<<2)>>2]|0;if((w|0)==0){C=gj[c[x+8236>>2]&4095](z)|0}else{C=a[w+z|0]|0}z=C&255;w=(C&255)>191;L61224:do{if(w){D=a[f+((d[f+296|0]|0)+(c[9647712+(z<<2)>>2]|0))|0]|0}else{C=c[678944+(z<<2)>>2]|0;gj[C&4095](f)|0;C=c[2426954]|0;do{if((C&1048064|0)==(c[f+428>>2]|0)|(C|0)==1048575){x=C&511;if((a[f+424|0]|0)!=0&x>>>0<256){D=a[f+x|0]|0;break L61224}if(x>>>0<=255){break}D=f9w(f,x-256|0)|0;break L61224}}while(0);A=C&1048575;x=c[3531864]|0;u=c[x+44+(A>>>11<<2)>>2]|0;if((u|0)==0){D=gj[c[x+8236>>2]&4095](A)|0;break}else{D=a[u+A|0]|0;break}}}while(0);A=D&255;D=f+432|0;c[D>>2]=(c[D>>2]|0)-(328964>>>((c[f+444>>2]|0)>>>0)&127);a[g]=(a[g]|0)-1&255;D=e[f+((d[h]|0)+6<<1)>>1]<<4;u=b[j>>1]|0;b[j>>1]=u+1&65535;x=(D+(u&65535)^c[l>>2])&1048575;u=c[3531864]|0;D=c[u+6188+(x>>>11<<2)>>2]|0;if((D|0)==0){E=gj[c[u+8236>>2]&4095](x)|0}else{E=a[D+x|0]|0}x=1<<(E&7);if((x&A|0)==0){F=x|A}else{F=(x^255)&A}A=F&255;if(w){a[f+((d[f+296|0]|0)+(c[9647712+(z<<2)>>2]|0))|0]=A;return}z=c[2426954]|0;do{if((z&1048064|0)==(c[f+428>>2]|0)|(z|0)==1048575){w=z&511;if((a[f+424|0]|0)!=0&w>>>0<256){a[f+w|0]=A;return}if(w>>>0<=255){break}f9y(f,w-256|0,A);return}}while(0);w=z&1048575;z=c[3531864]|0;F=c[z+2092+(w>>>11<<2)>>2]|0;if((F|0)==0){gg[c[z+8240>>2]&4095](w,A);return}else{a[F+w|0]=A;return}break};case 40:{a[g]=(a[g]|0)-1&255;A=e[f+((d[h]|0)+6<<1)>>1]<<4;w=b[j>>1]|0;b[j>>1]=w+1&65535;F=(A+(w&65535)^c[l>>2])&1048575;w=c[3531864]|0;A=c[w+6188+(F>>>11<<2)>>2]|0;if((A|0)==0){G=gj[c[w+8236>>2]&4095](F)|0}else{G=a[A+F|0]|0}F=G&255;A=(G&255)>191;L61269:do{if(A){H=a[f+((d[f+296|0]|0)+(c[9647712+(F<<2)>>2]|0))|0]|0}else{G=gj[c[678944+(F<<2)>>2]&4095](f)|0;do{if((G&1048064|0)==(c[f+428>>2]|0)|(G|0)==1048575){w=G&511;if((a[f+424|0]|0)!=0&w>>>0<256){H=a[f+w|0]|0;break L61269}if(w>>>0<=255){break}H=f9w(f,w-256|0)|0;break L61269}}while(0);C=G&1048575;w=c[3531864]|0;z=c[w+44+(C>>>11<<2)>>2]|0;if((z|0)==0){H=gj[c[w+8236>>2]&4095](C)|0;break}else{H=a[z+C|0]|0;break}}}while(0);C=f+296|0;z=f;w=z+((d[C]|0)+30)|0;x=a[w]|0;a[w]=x&-16|(H&255)>>>4;w=x&15|(H&255)<<4&240;L61283:do{if(A){a[z+((d[C]|0)+(c[9647712+(F<<2)>>2]|0))|0]=w&255}else{H=c[2426954]|0;x=w&255;do{if((H&1048064|0)==(c[f+428>>2]|0)|(H|0)==1048575){E=H&511;if((a[f+424|0]|0)!=0&E>>>0<256){a[z+E|0]=x;break L61283}if(E>>>0<=255){break}f9y(f,E-256|0,x);break L61283}}while(0);G=H&1048575;E=c[3531864]|0;D=c[E+2092+(G>>>11<<2)>>2]|0;if((D|0)==0){gg[c[E+8240>>2]&4095](G,x);break}else{a[D+G|0]=x;break}}}while(0);z=f+432|0;c[z>>2]=(c[z>>2]|0)-((A?855305:1842191)>>>((c[f+444>>2]|0)>>>0)&127);return};case 37:{A=d[h]|0;z=(e[f+(A+2<<1)>>1]|0)>>>8&112;b[f+(A+5<<1)>>1]=b[f+((z|5)<<1)>>1]|0;b[f+((d[h]|0)+11<<1)>>1]=b[f+((z|11)<<1)>>1]|0;z=f+432|0;c[z>>2]=(c[z>>2]|0)-16;return};case 38:{z=f;A=((d[z+((d[f+296|0]|0)+28)|0]|0)+1|0)>>>1;w=a[h]|0;F=w&255;C=b[f+(F+8<<1)>>1]|0;G=b[f+(F+9<<1)>>1]|0;F=f+280|0;c[F>>2]=0;D=f+276|0;c[D>>2]=0;E=f+444|0;u=c[E>>2]|0;L61301:do{if((A|0)==0){I=u;J=f+432|0}else{y=f+432|0;B=f+452|0;i=f+428|0;s=f+424|0;r=f+448|0;v=1;p=C&65535;q=G&65535;o=u;m=w;while(1){c[y>>2]=(c[y>>2]|0)-(d[591208+(o>>>3)|0]|0);n=(e[f+((m&255)+7<<1)>>1]<<4)+p|0;do{if((n&1048064|0)==(c[i>>2]|0)|(n|0)==1048575){k=n&511;if((a[s]|0)!=0&k>>>0<256){K=a[z+k|0]|0;break}if(k>>>0<=255){t=50123;break}K=f9w(f,k-256|0)|0}else{t=50123}}while(0);do{if((t|0)==50123){t=0;k=n&1048575;L=c[3531864]|0;M=c[L+44+(k>>>11<<2)>>2]|0;if((M|0)==0){K=gj[c[L+8236>>2]&4095](k)|0;break}else{K=a[M+k|0]|0;break}}}while(0);n=K&255;if((a[B]|0)==0){N=e[f+((d[h]|0)+4<<1)>>1]<<4}else{N=c[r>>2]|0}k=N+q|0;do{if((k&1048064|0)==(c[i>>2]|0)|(k|0)==1048575){M=k&511;if((a[s]|0)!=0&M>>>0<256){O=a[z+M|0]|0;break}if(M>>>0<=255){t=50134;break}O=f9w(f,M-256|0)|0}else{t=50134}}while(0);do{if((t|0)==50134){t=0;M=k&1048575;L=c[3531864]|0;P=c[L+44+(M>>>11<<2)>>2]|0;if((P|0)==0){O=gj[c[L+8236>>2]&4095](M)|0;break}else{O=a[P+M|0]|0;break}}}while(0);k=O&255;M=((n>>>4)*10|0)+(n&15)|0;P=(k&15)+(c[F>>2]|0)+((k>>>4)*10|0)|0;k=M>>>0<P>>>0;L=(k?M+100|0:M)-P|0;c[F>>2]=k&1;if((((L>>>0)/10|0)<<4|((L>>>0)%10|0)|0)!=0){c[D>>2]=1}L=c[E>>2]|0;if((v|0)>=(A|0)){I=L;J=y;break L61301}v=v+1|0;p=p+1|0;q=q+1|0;o=L;m=a[h]|0}}}while(0);c[J>>2]=(c[J>>2]|0)-(460546>>>(I>>>0)&127);return};case 148:{a[g]=(a[g]|0)-1&255;I=e[f+((d[h]|0)+6<<1)>>1]<<4;J=b[j>>1]|0;b[j>>1]=J+1&65535;A=(I+(J&65535)^c[l>>2])&1048575;J=c[3531864]|0;I=c[J+6188+(A>>>11<<2)>>2]|0;if((I|0)==0){Q=gj[c[J+8236>>2]&4095](A)|0}else{Q=a[I+A|0]|0}if((Q&255)>191){A=a[h]|0;R=b[f+((A&255)+(c[9649760+((Q&255)<<2)>>2]|0)<<1)>>1]&7;S=A}else{R=0;S=a[h]|0}A=f+280|0;Q=f+288|0;I=f+284|0;J=f+289|0;E=f+268|0;D=f+290|0;F=f+276|0;O=f+264|0;z=f+291|0;N=f+292|0;K=f+293|0;w=f+272|0;u=S&255;S=f+294|0;b[f+(u+2<<1)>>1]=((c[A>>2]|0)!=0|u>>>4<<12|d[Q]<<1|d[9760944+(c[I>>2]&255)|0]<<2|d[J]<<3|((c[E>>2]|0)!=0)<<4|d[D]<<5|((c[F>>2]|0)==0)<<6|(c[O>>2]|0)>>>31<<7|d[z]<<8|d[N]<<9|d[K]<<10|((c[w>>2]|0)!=0)<<11|d[S]<<15)&65535;b[f+((d[h]|0)+3<<1)>>1]=b[j>>1]|0;u=R<<4;a[h]=u&255;a[f+296|0]=R<<5&255;b[j>>1]=b[f+((u|3)<<1)>>1]|0;R=f+((u|2)<<1)|0;u=b[R>>1]|0;G=u&65535;c[A>>2]=G&1;a[Q]=(u&65535)>>>1&1;c[I>>2]=((u&65535)>>>2&1^1)&65535;a[J]=(u&65535)>>>3&1;c[E>>2]=G&16;a[D]=(u&65535)>>>5&1;c[F>>2]=((u&65535)>>>6&1^1)&65535;c[O>>2]=u<<8<<16>>16>>15<<16>>16;a[z]=(u&65535)>>>8&1;a[N]=(u&65535)>>>9&1;a[K]=(e[R>>1]|0)>>>10&1;K=b[R>>1]|0;c[w>>2]=K&2048;a[S]=(K&65535)>>>15&255;a[f+443|0]=1;K=f+432|0;c[K>>2]=(c[K>>2]|0)-20;return};case 42:{a[g]=(a[g]|0)-1&255;K=e[f+((d[h]|0)+6<<1)>>1]<<4;S=b[j>>1]|0;b[j>>1]=S+1&65535;w=(K+(S&65535)^c[l>>2])&1048575;S=c[3531864]|0;K=c[S+6188+(w>>>11<<2)>>2]|0;if((K|0)==0){T=gj[c[S+8236>>2]&4095](w)|0}else{T=a[K+w|0]|0}w=T&255;K=(T&255)>191;L61355:do{if(K){U=a[f+((d[f+296|0]|0)+(c[9647712+(w<<2)>>2]|0))|0]|0}else{T=gj[c[678944+(w<<2)>>2]&4095](f)|0;do{if((T&1048064|0)==(c[f+428>>2]|0)|(T|0)==1048575){S=T&511;if((a[f+424|0]|0)!=0&S>>>0<256){U=a[f+S|0]|0;break L61355}if(S>>>0<=255){break}U=f9w(f,S-256|0)|0;break L61355}}while(0);S=T&1048575;R=c[3531864]|0;u=c[R+44+(S>>>11<<2)>>2]|0;if((u|0)==0){U=gj[c[R+8236>>2]&4095](S)|0;break}else{U=a[u+S|0]|0;break}}}while(0);S=f+296|0;u=f;R=u+((d[S]|0)+30)|0;N=a[R]|0;a[R]=N&-16|U&15;R=(N&255)<<4&240|(U&255)>>>4;L61369:do{if(K){a[u+((d[S]|0)+(c[9647712+(w<<2)>>2]|0))|0]=R&255}else{U=c[2426954]|0;N=R&255;do{if((U&1048064|0)==(c[f+428>>2]|0)|(U|0)==1048575){z=U&511;if((a[f+424|0]|0)!=0&z>>>0<256){a[u+z|0]=N;break L61369}if(z>>>0<=255){break}f9y(f,z-256|0,N);break L61369}}while(0);T=U&1048575;z=c[3531864]|0;O=c[z+2092+(T>>>11<<2)>>2]|0;if((O|0)==0){gg[c[z+8240>>2]&4095](T,N);break}else{a[O+T|0]=N;break}}}while(0);u=f+432|0;c[u>>2]=(c[u>>2]|0)-((K?1118477:2105363)>>>((c[f+444>>2]|0)>>>0)&127);return};case 145:{K=d[h]|0;u=f+(K+2<<1)|0;R=(e[u>>1]|0)>>>12;b[j>>1]=b[f+(K+3<<1)>>1]|0;c[f+280>>2]=b[u>>1]&1;a[f+288|0]=(e[u>>1]|0)>>>1&1;c[f+284>>2]=((e[u>>1]|0)>>>2&1^1)&65535;a[f+289|0]=(e[u>>1]|0)>>>3&1;c[f+268>>2]=b[u>>1]&16;a[f+290|0]=(e[u>>1]|0)>>>5&1;c[f+276>>2]=((e[u>>1]|0)>>>6&1^1)&65535;c[f+264>>2]=b[u>>1]<<8<<16>>16>>15<<16>>16;a[f+291|0]=(e[u>>1]|0)>>>8&1;a[f+292|0]=(e[u>>1]|0)>>>9&1;a[f+293|0]=(e[u>>1]|0)>>>10&1;c[f+272>>2]=b[u>>1]&2048;a[f+294|0]=(e[u>>1]|0)>>>15&255;a[h]=R<<4&112;a[f+296|0]=R<<5&255;a[f+443|0]=1;R=f+432|0;c[R>>2]=(c[R>>2]|0)-12;return};case 49:{a[g]=(a[g]|0)-1&255;R=e[f+((d[h]|0)+6<<1)>>1]<<4;u=b[j>>1]|0;b[j>>1]=u+1&65535;K=(R+(u&65535)^c[l>>2])&1048575;u=c[3531864]|0;if((c[u+6188+(K>>>11<<2)>>2]|0)!=0){return}gj[c[u+8236>>2]&4095](K)|0;return};case 51:{a[g]=(a[g]|0)-1&255;K=e[f+((d[h]|0)+6<<1)>>1]<<4;u=b[j>>1]|0;b[j>>1]=u+1&65535;R=(K+(u&65535)^c[l>>2])&1048575;u=c[3531864]|0;if((c[u+6188+(R>>>11<<2)>>2]|0)!=0){return}gj[c[u+8236>>2]&4095](R)|0;return};case 45:{a[g]=(a[g]|0)-1&255;R=e[f+((d[h]|0)+6<<1)>>1]<<4;u=b[j>>1]|0;b[j>>1]=u+1&65535;K=(R+(u&65535)^c[l>>2])&1048575;u=c[3531864]|0;R=c[u+6188+(K>>>11<<2)>>2]|0;if((R|0)==0){V=gj[c[u+8236>>2]&4095](K)|0}else{V=a[R+K|0]|0}if((V&255)>191){W=b[f+((d[h]|0)+(c[9649760+((V&255)<<2)>>2]|0)<<1)>>1]&7}else{W=0}gd1(f,W);W=f+432|0;c[W>>2]=(c[W>>2]|0)-15;return};case 23:{a[g]=(a[g]|0)-1&255;W=e[f+((d[h]|0)+6<<1)>>1]<<4;V=b[j>>1]|0;b[j>>1]=V+1&65535;K=(W+(V&65535)^c[l>>2])&1048575;V=c[3531864]|0;W=c[V+6188+(K>>>11<<2)>>2]|0;if((W|0)==0){X=gj[c[V+8236>>2]&4095](K)|0}else{X=a[W+K|0]|0}K=X&255;W=(X&255)>191;if(W){Y=b[f+((d[h]|0)+(c[9649760+(K<<2)>>2]|0)<<1)>>1]|0}else{X=c[678944+(K<<2)>>2]|0;gj[X&4095](f)|0;Y=f9x(f,c[2426954]|0)|0}X=Y&65535;Y=f+432|0;c[Y>>2]=(c[Y>>2]|0)-(263172>>>((c[f+444>>2]|0)>>>0)&127);Y=1<<(a[f+((d[f+296|0]|0)+28)|0]&15);if((Y&X|0)==0){Z=Y|X}else{Z=(Y^65535)&X}X=Z&65535;if(W){b[f+((d[h]|0)+(c[9649760+(K<<2)>>2]|0)<<1)>>1]=X;return}else{f9z(f,c[2426954]|0,X);return}break};case 32:{X=f;K=((d[X+((d[f+296|0]|0)+28)|0]|0)+1|0)>>>1;W=d[h]|0;Z=b[f+(W+8<<1)>>1]|0;Y=b[f+(W+9<<1)>>1]|0;W=f+280|0;c[W>>2]=0;V=f+276|0;c[V>>2]=0;R=f+444|0;u=c[R>>2]|0;if((K|0)==0){_=u;$=f+432|0}else{w=f+432|0;S=f+452|0;T=f+428|0;O=f+424|0;z=f+448|0;F=Y&65535;Y=Z&65535;Z=0;D=u;while(1){c[w>>2]=(c[w>>2]|0)-(d[591216+(D>>>3)|0]|0);if((a[S]|0)==0){aa=e[f+((d[h]|0)+4<<1)>>1]<<4}else{aa=c[z>>2]|0}u=aa+F|0;do{if((u&1048064|0)==(c[T>>2]|0)|(u|0)==1048575){G=u&511;if((a[O]|0)!=0&G>>>0<256){ab=a[X+G|0]|0;break}if(G>>>0<=255){t=50056;break}ab=f9w(f,G-256|0)|0}else{t=50056}}while(0);do{if((t|0)==50056){t=0;N=u&1048575;U=c[3531864]|0;G=c[U+44+(N>>>11<<2)>>2]|0;if((G|0)==0){ab=gj[c[U+8236>>2]&4095](N)|0;break}else{ab=a[G+N|0]|0;break}}}while(0);u=ab&255;N=(e[f+((d[h]|0)+7<<1)>>1]<<4)+Y|0;do{if((N&1048064|0)==(c[T>>2]|0)|(N|0)==1048575){G=N&511;if((a[O]|0)!=0&G>>>0<256){ac=a[X+G|0]|0;break}if(G>>>0<=255){t=50064;break}ac=f9w(f,G-256|0)|0}else{t=50064}}while(0);do{if((t|0)==50064){t=0;G=N&1048575;U=c[3531864]|0;E=c[U+44+(G>>>11<<2)>>2]|0;if((E|0)==0){ac=gj[c[U+8236>>2]&4095](G)|0;break}else{ac=a[E+G|0]|0;break}}}while(0);N=ac&255;G=(c[W>>2]|0)+(u&15)+(N&15)+(((N>>>4)+(u>>>4)|0)*10|0)|0;c[W>>2]=(G|0)>99;N=(G|0)%100|0;G=((N|0)/10|0)<<4|((N|0)%10|0);N=(e[f+((d[h]|0)+7<<1)>>1]<<4)+Y|0;E=G&255;do{if((N&1048064|0)==(c[T>>2]|0)|(N|0)==1048575){U=N&511;if((a[O]|0)!=0&U>>>0<256){a[X+U|0]=E;break}if(U>>>0<=255){t=50072;break}f9y(f,U-256|0,E)}else{t=50072}}while(0);do{if((t|0)==50072){t=0;u=N&1048575;U=c[3531864]|0;J=c[U+2092+(u>>>11<<2)>>2]|0;if((J|0)==0){gg[c[U+8240>>2]&4095](u,E);break}else{a[J+u|0]=E;break}}}while(0);if((G|0)!=0){c[V>>2]=1}E=Z+1|0;N=c[R>>2]|0;if((E|0)<(K|0)){F=F+1|0;Y=Y+1|0;Z=E;D=N}else{_=N;$=w;break}}}c[$>>2]=(c[$>>2]|0)-(460546>>>(_>>>0)&127);return};case 22:{a[g]=(a[g]|0)-1&255;_=e[f+((d[h]|0)+6<<1)>>1]<<4;$=b[j>>1]|0;b[j>>1]=$+1&65535;w=(_+($&65535)^c[l>>2])&1048575;$=c[3531864]|0;_=c[$+6188+(w>>>11<<2)>>2]|0;if((_|0)==0){ad=gj[c[$+8236>>2]&4095](w)|0}else{ad=a[_+w|0]|0}w=ad&255;_=(ad&255)>191;L61480:do{if(_){ae=a[f+((d[f+296|0]|0)+(c[9647712+(w<<2)>>2]|0))|0]|0}else{ad=c[678944+(w<<2)>>2]|0;gj[ad&4095](f)|0;ad=c[2426954]|0;do{if((ad&1048064|0)==(c[f+428>>2]|0)|(ad|0)==1048575){$=ad&511;if((a[f+424|0]|0)!=0&$>>>0<256){ae=a[f+$|0]|0;break L61480}if($>>>0<=255){break}ae=f9w(f,$-256|0)|0;break L61480}}while(0);G=ad&1048575;$=c[3531864]|0;D=c[$+44+(G>>>11<<2)>>2]|0;if((D|0)==0){ae=gj[c[$+8236>>2]&4095](G)|0;break}else{ae=a[D+G|0]|0;break}}}while(0);G=ae&255;ae=f+432|0;c[ae>>2]=(c[ae>>2]|0)-(263172>>>((c[f+444>>2]|0)>>>0)&127);ae=d[f+296|0]|0;D=f;$=1<<(a[D+(ae+28)|0]&7);if(($&G|0)==0){af=$|G}else{af=($^255)&G}G=af&255;if(_){a[D+((c[9647712+(w<<2)>>2]|0)+ae)|0]=G;return}ae=c[2426954]|0;do{if((ae&1048064|0)==(c[f+428>>2]|0)|(ae|0)==1048575){w=ae&511;if((a[f+424|0]|0)!=0&w>>>0<256){a[D+w|0]=G;return}if(w>>>0<=255){break}f9y(f,w-256|0,G);return}}while(0);D=ae&1048575;ae=c[3531864]|0;w=c[ae+2092+(D>>>11<<2)>>2]|0;if((w|0)==0){gg[c[ae+8240>>2]&4095](D,G);return}else{a[w+D|0]=G;return}break};case 21:{a[g]=(a[g]|0)-1&255;G=e[f+((d[h]|0)+6<<1)>>1]<<4;D=b[j>>1]|0;b[j>>1]=D+1&65535;w=(G+(D&65535)^c[l>>2])&1048575;D=c[3531864]|0;G=c[D+6188+(w>>>11<<2)>>2]|0;if((G|0)==0){ag=gj[c[D+8236>>2]&4095](w)|0}else{ag=a[G+w|0]|0}w=ag&255;G=(ag&255)>191;if(G){ah=b[f+((d[h]|0)+(c[9649760+(w<<2)>>2]|0)<<1)>>1]|0}else{ag=c[678944+(w<<2)>>2]|0;gj[ag&4095](f)|0;ah=f9x(f,c[2426954]|0)|0}ag=f+432|0;c[ag>>2]=(c[ag>>2]|0)-(263172>>>((c[f+444>>2]|0)>>>0)&127);ag=1<<(a[f+((d[f+296|0]|0)+28)|0]&15)|ah&65535;if(G){b[f+((d[h]|0)+(c[9649760+(w<<2)>>2]|0)<<1)>>1]=ag&65535;return}else{f9z(f,c[2426954]|0,ag&65535);return}break};case 27:{a[g]=(a[g]|0)-1&255;ag=e[f+((d[h]|0)+6<<1)>>1]<<4;w=b[j>>1]|0;b[j>>1]=w+1&65535;G=(ag+(w&65535)^c[l>>2])&1048575;w=c[3531864]|0;ag=c[w+6188+(G>>>11<<2)>>2]|0;if((ag|0)==0){ai=gj[c[w+8236>>2]&4095](G)|0}else{ai=a[ag+G|0]|0}G=ai&255;ag=(ai&255)>191;if(ag){ai=a[h]|0;aj=b[f+((ai&255)+(c[9649760+(G<<2)>>2]|0)<<1)>>1]|0;ak=ai}else{ai=c[678944+(G<<2)>>2]|0;gj[ai&4095](f)|0;ai=f9x(f,c[2426954]|0)|0;aj=ai;ak=a[h]|0}ai=f+432|0;c[ai>>2]=(c[ai>>2]|0)-(394756>>>((c[f+444>>2]|0)>>>0)&127);a[g]=(a[g]|0)-1&255;ai=e[f+((ak&255)+6<<1)>>1]<<4;ak=b[j>>1]|0;b[j>>1]=ak+1&65535;w=(ai+(ak&65535)^c[l>>2])&1048575;ak=c[3531864]|0;ai=c[ak+6188+(w>>>11<<2)>>2]|0;if((ai|0)==0){al=gj[c[ak+8236>>2]&4095](w)|0}else{al=a[ai+w|0]|0}w=aj&65535&~(1<<(al&15));if(ag){b[f+((d[h]|0)+(c[9649760+(G<<2)>>2]|0)<<1)>>1]=w&65535;return}else{f9z(f,c[2426954]|0,w&65535);return}break};case 20:{a[g]=(a[g]|0)-1&255;w=e[f+((d[h]|0)+6<<1)>>1]<<4;G=b[j>>1]|0;b[j>>1]=G+1&65535;ag=(w+(G&65535)^c[l>>2])&1048575;G=c[3531864]|0;w=c[G+6188+(ag>>>11<<2)>>2]|0;if((w|0)==0){am=gj[c[G+8236>>2]&4095](ag)|0}else{am=a[w+ag|0]|0}ag=am&255;w=(am&255)>191;L61553:do{if(w){an=a[f+((d[f+296|0]|0)+(c[9647712+(ag<<2)>>2]|0))|0]|0}else{am=c[678944+(ag<<2)>>2]|0;gj[am&4095](f)|0;am=c[2426954]|0;do{if((am&1048064|0)==(c[f+428>>2]|0)|(am|0)==1048575){G=am&511;if((a[f+424|0]|0)!=0&G>>>0<256){an=a[f+G|0]|0;break L61553}if(G>>>0<=255){break}an=f9w(f,G-256|0)|0;break L61553}}while(0);ad=am&1048575;G=c[3531864]|0;al=c[G+44+(ad>>>11<<2)>>2]|0;if((al|0)==0){an=gj[c[G+8236>>2]&4095](ad)|0;break}else{an=a[al+ad|0]|0;break}}}while(0);ad=f+432|0;c[ad>>2]=(c[ad>>2]|0)-(263172>>>((c[f+444>>2]|0)>>>0)&127);ad=d[f+296|0]|0;al=f;G=1<<(a[al+(ad+28)|0]&7)|an&255;if(w){a[al+((c[9647712+(ag<<2)>>2]|0)+ad)|0]=G&255;return}ad=c[2426954]|0;ag=G&255;do{if((ad&1048064|0)==(c[f+428>>2]|0)|(ad|0)==1048575){G=ad&511;if((a[f+424|0]|0)!=0&G>>>0<256){a[al+G|0]=ag;return}if(G>>>0<=255){break}f9y(f,G-256|0,ag);return}}while(0);al=ad&1048575;ad=c[3531864]|0;G=c[ad+2092+(al>>>11<<2)>>2]|0;if((G|0)==0){gg[c[ad+8240>>2]&4095](al,ag);return}else{a[G+al|0]=ag;return}break};case 19:{a[g]=(a[g]|0)-1&255;ag=e[f+((d[h]|0)+6<<1)>>1]<<4;al=b[j>>1]|0;b[j>>1]=al+1&65535;G=(ag+(al&65535)^c[l>>2])&1048575;al=c[3531864]|0;ag=c[al+6188+(G>>>11<<2)>>2]|0;if((ag|0)==0){ao=gj[c[al+8236>>2]&4095](G)|0}else{ao=a[ag+G|0]|0}G=ao&255;ag=(ao&255)>191;if(ag){ap=b[f+((d[h]|0)+(c[9649760+(G<<2)>>2]|0)<<1)>>1]|0}else{ao=c[678944+(G<<2)>>2]|0;gj[ao&4095](f)|0;ap=f9x(f,c[2426954]|0)|0}ao=f+432|0;c[ao>>2]=(c[ao>>2]|0)-(328964>>>((c[f+444>>2]|0)>>>0)&127);ao=ap&65535&~(1<<(a[f+((d[f+296|0]|0)+28)|0]&15));if(ag){b[f+((d[h]|0)+(c[9649760+(G<<2)>>2]|0)<<1)>>1]=ao&65535;return}else{f9z(f,c[2426954]|0,ao&65535);return}break};case 25:{a[g]=(a[g]|0)-1&255;ao=e[f+((d[h]|0)+6<<1)>>1]<<4;G=b[j>>1]|0;b[j>>1]=G+1&65535;ag=(ao+(G&65535)^c[l>>2])&1048575;G=c[3531864]|0;ao=c[G+6188+(ag>>>11<<2)>>2]|0;if((ao|0)==0){aq=gj[c[G+8236>>2]&4095](ag)|0}else{aq=a[ao+ag|0]|0}ag=aq&255;if((aq&255)>191){aq=a[h]|0;ar=b[f+((aq&255)+(c[9649760+(ag<<2)>>2]|0)<<1)>>1]|0;as=aq}else{aq=c[678944+(ag<<2)>>2]|0;gj[aq&4095](f)|0;aq=f9x(f,c[2426954]|0)|0;ar=aq;as=a[h]|0}aq=f+432|0;c[aq>>2]=(c[aq>>2]|0)-(263172>>>((c[f+444>>2]|0)>>>0)&127);a[g]=(a[g]|0)-1&255;aq=e[f+((as&255)+6<<1)>>1]<<4;as=b[j>>1]|0;b[j>>1]=as+1&65535;ag=(aq+(as&65535)^c[l>>2])&1048575;as=c[3531864]|0;aq=c[as+6188+(ag>>>11<<2)>>2]|0;if((aq|0)==0){at=gj[c[as+8236>>2]&4095](ag)|0}else{at=a[aq+ag|0]|0}c[f+276>>2]=(1<<(at&15)&(ar&65535)|0)!=0;c[f+272>>2]=0;c[f+280>>2]=0;return};case 28:{a[g]=(a[g]|0)-1&255;ar=e[f+((d[h]|0)+6<<1)>>1]<<4;at=b[j>>1]|0;b[j>>1]=at+1&65535;ag=(ar+(at&65535)^c[l>>2])&1048575;at=c[3531864]|0;ar=c[at+6188+(ag>>>11<<2)>>2]|0;if((ar|0)==0){au=gj[c[at+8236>>2]&4095](ag)|0}else{au=a[ar+ag|0]|0}ag=au&255;ar=(au&255)>191;L61618:do{if(ar){av=a[f+((d[f+296|0]|0)+(c[9647712+(ag<<2)>>2]|0))|0]|0}else{au=c[678944+(ag<<2)>>2]|0;gj[au&4095](f)|0;au=c[2426954]|0;do{if((au&1048064|0)==(c[f+428>>2]|0)|(au|0)==1048575){at=au&511;if((a[f+424|0]|0)!=0&at>>>0<256){av=a[f+at|0]|0;break L61618}if(at>>>0<=255){break}av=f9w(f,at-256|0)|0;break L61618}}while(0);am=au&1048575;at=c[3531864]|0;aq=c[at+44+(am>>>11<<2)>>2]|0;if((aq|0)==0){av=gj[c[at+8236>>2]&4095](am)|0;break}else{av=a[aq+am|0]|0;break}}}while(0);am=f+432|0;c[am>>2]=(c[am>>2]|0)-(328964>>>((c[f+444>>2]|0)>>>0)&127);a[g]=(a[g]|0)-1&255;am=e[f+((d[h]|0)+6<<1)>>1]<<4;aq=b[j>>1]|0;b[j>>1]=aq+1&65535;at=(am+(aq&65535)^c[l>>2])&1048575;aq=c[3531864]|0;am=c[aq+6188+(at>>>11<<2)>>2]|0;if((am|0)==0){aw=gj[c[aq+8236>>2]&4095](at)|0}else{aw=a[am+at|0]|0}at=1<<(aw&7)|av&255;if(ar){a[f+((d[f+296|0]|0)+(c[9647712+(ag<<2)>>2]|0))|0]=at&255;return}ag=c[2426954]|0;ar=at&255;do{if((ag&1048064|0)==(c[f+428>>2]|0)|(ag|0)==1048575){at=ag&511;if((a[f+424|0]|0)!=0&at>>>0<256){a[f+at|0]=ar;return}if(at>>>0<=255){break}f9y(f,at-256|0,ar);return}}while(0);at=ag&1048575;ag=c[3531864]|0;av=c[ag+2092+(at>>>11<<2)>>2]|0;if((av|0)==0){gg[c[ag+8240>>2]&4095](at,ar);return}else{a[av+at|0]=ar;return}break};case 34:{ar=f;at=((d[ar+((d[f+296|0]|0)+28)|0]|0)+1|0)>>>1;av=a[h]|0;ag=av&255;aw=b[f+(ag+8<<1)>>1]|0;am=b[f+(ag+9<<1)>>1]|0;ag=f+280|0;c[ag>>2]=0;aq=f+276|0;c[aq>>2]=0;as=f+444|0;ao=c[as>>2]|0;L61655:do{if((at|0)==0){ax=ao;ay=f+432|0}else{G=f+432|0;ap=f+452|0;al=f+428|0;ad=f+424|0;w=f+448|0;an=aw&65535;aj=am&65535;ai=1;ak=ao;ah=av;while(1){c[G>>2]=(c[G>>2]|0)-(d[591216+(ak>>>3)|0]|0);D=(e[f+((ah&255)+7<<1)>>1]<<4)+an|0;do{if((D&1048064|0)==(c[al>>2]|0)|(D|0)==1048575){ae=D&511;if((a[ad]|0)!=0&ae>>>0<256){az=a[ar+ae|0]|0;break}if(ae>>>0<=255){t=50087;break}az=f9w(f,ae-256|0)|0}else{t=50087}}while(0);do{if((t|0)==50087){t=0;n=D&1048575;ae=c[3531864]|0;_=c[ae+44+(n>>>11<<2)>>2]|0;if((_|0)==0){az=gj[c[ae+8236>>2]&4095](n)|0;break}else{az=a[_+n|0]|0;break}}}while(0);D=az&255;if((a[ap]|0)==0){aA=e[f+((d[h]|0)+4<<1)>>1]<<4}else{aA=c[w>>2]|0}n=aA+aj|0;do{if((n&1048064|0)==(c[al>>2]|0)|(n|0)==1048575){_=n&511;if((a[ad]|0)!=0&_>>>0<256){aB=a[ar+_|0]|0;break}if(_>>>0<=255){t=50098;break}aB=f9w(f,_-256|0)|0}else{t=50098}}while(0);do{if((t|0)==50098){t=0;_=n&1048575;ae=c[3531864]|0;af=c[ae+44+(_>>>11<<2)>>2]|0;if((af|0)==0){aB=gj[c[ae+8236>>2]&4095](_)|0;break}else{aB=a[af+_|0]|0;break}}}while(0);n=aB&255;_=((D>>>4)*10|0)+(D&15)|0;af=(n&15)+(c[ag>>2]|0)+((n>>>4)*10|0)|0;n=_>>>0<af>>>0;ae=(n?_+100|0:_)-af|0;c[ag>>2]=n&1;n=((ae>>>0)/10|0)<<4|((ae>>>0)%10|0);ae=(e[f+((d[h]|0)+7<<1)>>1]<<4)+an|0;af=n&255;do{if((ae&1048064|0)==(c[al>>2]|0)|(ae|0)==1048575){_=ae&511;if((a[ad]|0)!=0&_>>>0<256){a[ar+_|0]=af;break}if(_>>>0<=255){t=50106;break}f9y(f,_-256|0,af)}else{t=50106}}while(0);do{if((t|0)==50106){t=0;D=ae&1048575;_=c[3531864]|0;$=c[_+2092+(D>>>11<<2)>>2]|0;if(($|0)==0){gg[c[_+8240>>2]&4095](D,af);break}else{a[$+D|0]=af;break}}}while(0);if((n|0)!=0){c[aq>>2]=1}af=c[as>>2]|0;if((ai|0)>=(at|0)){ax=af;ay=G;break L61655}an=an+1|0;aj=aj+1|0;ai=ai+1|0;ak=af;ah=a[h]|0}}}while(0);c[ay>>2]=(c[ay>>2]|0)-(460546>>>(ax>>>0)&127);return};case 29:{a[g]=(a[g]|0)-1&255;ax=e[f+((d[h]|0)+6<<1)>>1]<<4;ay=b[j>>1]|0;b[j>>1]=ay+1&65535;at=(ax+(ay&65535)^c[l>>2])&1048575;ay=c[3531864]|0;ax=c[ay+6188+(at>>>11<<2)>>2]|0;if((ax|0)==0){aC=gj[c[ay+8236>>2]&4095](at)|0}else{aC=a[ax+at|0]|0}at=aC&255;ax=(aC&255)>191;if(ax){aC=a[h]|0;aD=b[f+((aC&255)+(c[9649760+(at<<2)>>2]|0)<<1)>>1]|0;aE=aC}else{aC=c[678944+(at<<2)>>2]|0;gj[aC&4095](f)|0;aC=f9x(f,c[2426954]|0)|0;aD=aC;aE=a[h]|0}aC=f+432|0;c[aC>>2]=(c[aC>>2]|0)-(328964>>>((c[f+444>>2]|0)>>>0)&127);a[g]=(a[g]|0)-1&255;aC=e[f+((aE&255)+6<<1)>>1]<<4;aE=b[j>>1]|0;b[j>>1]=aE+1&65535;ay=(aC+(aE&65535)^c[l>>2])&1048575;aE=c[3531864]|0;aC=c[aE+6188+(ay>>>11<<2)>>2]|0;if((aC|0)==0){aF=gj[c[aE+8236>>2]&4095](ay)|0}else{aF=a[aC+ay|0]|0}ay=1<<(aF&15)|aD&65535;if(ax){b[f+((d[h]|0)+(c[9649760+(at<<2)>>2]|0)<<1)>>1]=ay&65535;return}else{f9z(f,c[2426954]|0,ay&65535);return}break};case 24:{a[g]=(a[g]|0)-1&255;ay=e[f+((d[h]|0)+6<<1)>>1]<<4;at=b[j>>1]|0;b[j>>1]=at+1&65535;ax=(ay+(at&65535)^c[l>>2])&1048575;at=c[3531864]|0;ay=c[at+6188+(ax>>>11<<2)>>2]|0;if((ay|0)==0){aG=gj[c[at+8236>>2]&4095](ax)|0}else{aG=a[ay+ax|0]|0}ax=aG&255;L61729:do{if((aG&255)>191){aH=a[f+((d[f+296|0]|0)+(c[9647712+(ax<<2)>>2]|0))|0]|0}else{ay=c[678944+(ax<<2)>>2]|0;gj[ay&4095](f)|0;ay=c[2426954]|0;do{if((ay&1048064|0)==(c[f+428>>2]|0)|(ay|0)==1048575){at=ay&511;if((a[f+424|0]|0)!=0&at>>>0<256){aH=a[f+at|0]|0;break L61729}if(at>>>0<=255){break}aH=f9w(f,at-256|0)|0;break L61729}}while(0);at=ay&1048575;aD=c[3531864]|0;aF=c[aD+44+(at>>>11<<2)>>2]|0;if((aF|0)==0){aH=gj[c[aD+8236>>2]&4095](at)|0;break}else{aH=a[aF+at|0]|0;break}}}while(0);ax=f+432|0;c[ax>>2]=(c[ax>>2]|0)-(263172>>>((c[f+444>>2]|0)>>>0)&127);a[g]=(a[g]|0)-1&255;ax=e[f+((d[h]|0)+6<<1)>>1]<<4;aG=b[j>>1]|0;b[j>>1]=aG+1&65535;at=(ax+(aG&65535)^c[l>>2])&1048575;aG=c[3531864]|0;ax=c[aG+6188+(at>>>11<<2)>>2]|0;if((ax|0)==0){aI=gj[c[aG+8236>>2]&4095](at)|0}else{aI=a[ax+at|0]|0}c[f+276>>2]=(1<<(aI&7)&(aH&255)|0)!=0;c[f+272>>2]=0;c[f+280>>2]=0;return};case 31:{a[g]=(a[g]|0)-1&255;aH=e[f+((d[h]|0)+6<<1)>>1]<<4;aI=b[j>>1]|0;b[j>>1]=aI+1&65535;at=(aH+(aI&65535)^c[l>>2])&1048575;aI=c[3531864]|0;aH=c[aI+6188+(at>>>11<<2)>>2]|0;if((aH|0)==0){aJ=gj[c[aI+8236>>2]&4095](at)|0}else{aJ=a[aH+at|0]|0}at=aJ&255;aH=(aJ&255)>191;if(aH){aJ=a[h]|0;aK=b[f+((aJ&255)+(c[9649760+(at<<2)>>2]|0)<<1)>>1]|0;aL=aJ}else{aJ=c[678944+(at<<2)>>2]|0;gj[aJ&4095](f)|0;aJ=f9x(f,c[2426954]|0)|0;aK=aJ;aL=a[h]|0}aJ=aK&65535;aK=f+432|0;c[aK>>2]=(c[aK>>2]|0)-(328964>>>((c[f+444>>2]|0)>>>0)&127);a[g]=(a[g]|0)-1&255;g=e[f+((aL&255)+6<<1)>>1]<<4;aL=b[j>>1]|0;b[j>>1]=aL+1&65535;j=(g+(aL&65535)^c[l>>2])&1048575;l=c[3531864]|0;aL=c[l+6188+(j>>>11<<2)>>2]|0;if((aL|0)==0){aM=gj[c[l+8236>>2]&4095](j)|0}else{aM=a[aL+j|0]|0}j=1<<(aM&15);if((j&aJ|0)==0){aN=j|aJ}else{aN=(j^65535)&aJ}aJ=aN&65535;if(aH){b[f+((d[h]|0)+(c[9649760+(at<<2)>>2]|0)<<1)>>1]=aJ;return}else{f9z(f,c[2426954]|0,aJ);return}break};default:{return}}}function f90(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=f+442|0;a[g]=(a[g]|0)-1&255;g=e[f+((d[f+295|0]|0)+6<<1)>>1]<<4;h=f+260|0;i=b[h>>1]|0;b[h>>1]=i+1&65535;h=(g+(i&65535)^c[f+256>>2])&1048575;i=c[3531864]|0;g=c[i+6188+(h>>>11<<2)>>2]|0;if((g|0)==0){j=gj[c[i+8236>>2]&4095](h)|0}else{j=a[g+h|0]|0}h=j&255;g=f+296|0;i=d[g]|0;k=f;l=d[k+(i+(c[9651808+(h<<2)>>2]|0))|0]|0;m=(j&255)>191;L61775:do{if(m){n=a[k+((c[9647712+(h<<2)>>2]|0)+i)|0]|0}else{j=gj[c[678944+(h<<2)>>2]&4095](f)|0;do{if((j&1048064|0)==(c[f+428>>2]|0)|(j|0)==1048575){o=j&511;if((a[f+424|0]|0)!=0&o>>>0<256){n=a[k+o|0]|0;break L61775}if(o>>>0<=255){break}n=f9w(f,o-256|0)|0;break L61775}}while(0);o=j&1048575;p=c[3531864]|0;q=c[p+44+(o>>>11<<2)>>2]|0;if((q|0)==0){n=gj[c[p+8236>>2]&4095](o)|0;break}else{n=a[q+o|0]|0;break}}}while(0);i=n&255;n=f+280|0;o=((c[n>>2]|0)!=0)+l|0;l=o+i|0;c[n>>2]=l&256;c[f+272>>2]=(l^i)&128&(l^o);c[f+268>>2]=(o^i^l)&16;i=l<<24>>24;c[f+284>>2]=i;c[f+276>>2]=i;c[f+264>>2]=i;L61789:do{if(m){a[k+((d[g]|0)+(c[9647712+(h<<2)>>2]|0))|0]=l&255}else{i=c[2426954]|0;o=l&255;do{if((i&1048064|0)==(c[f+428>>2]|0)|(i|0)==1048575){n=i&511;if((a[f+424|0]|0)!=0&n>>>0<256){a[k+n|0]=o;break L61789}if(n>>>0<=255){break}f9y(f,n-256|0,o);break L61789}}while(0);j=i&1048575;n=c[3531864]|0;q=c[n+2092+(j>>>11<<2)>>2]|0;if((q|0)==0){gg[c[n+8240>>2]&4095](j,o);break}else{a[q+j|0]=o;break}}}while(0);k=f+432|0;c[k>>2]=(c[k>>2]|0)-((m?131586:1052679)>>>((c[f+444>>2]|0)>>>0)&127);return}function f91(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=f+442|0;a[g]=(a[g]|0)-1&255;g=f+295|0;h=a[g]|0;i=(e[f+((h&255)+6<<1)>>1]|0)<<4;j=f+260|0;k=b[j>>1]|0;b[j>>1]=k+1&65535;j=(i+(k&65535)^c[f+256>>2])&1048575;k=c[3531864]|0;i=c[k+6188+(j>>>11<<2)>>2]|0;if((i|0)==0){l=gj[c[k+8236>>2]&4095](j)|0;m=l;n=a[g]|0}else{m=a[i+j|0]|0;n=h}h=m&255;j=n&255;n=e[f+(j+(c[9653856+(h<<2)>>2]|0)<<1)>>1]|0;i=(m&255)>191;if(i){o=b[f+((c[9649760+(h<<2)>>2]|0)+j<<1)>>1]|0}else{j=c[678944+(h<<2)>>2]|0;gj[j&4095](f)|0;o=f9x(f,c[2426954]|0)|0}j=o&65535;o=f+280|0;m=((c[o>>2]|0)!=0)+n|0;n=m+j|0;c[o>>2]=n&65536;c[f+272>>2]=(n^j)&32768&(n^m);c[f+268>>2]=(m^j^n)&16;j=n<<16>>16;c[f+284>>2]=j;c[f+276>>2]=j;c[f+264>>2]=j;if(i){b[f+((d[g]|0)+(c[9649760+(h<<2)>>2]|0)<<1)>>1]=n&65535;h=f+432|0;c[h>>2]=(c[h>>2]|0)-2;return}else{f9z(f,c[2426954]|0,n&65535);n=f+432|0;c[n>>2]=(c[n>>2]|0)-(((c[2426954]&1|0)!=0?1579019:1576967)>>>((c[f+444>>2]|0)>>>0)&127);return}}function f92(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=f+442|0;a[g]=(a[g]|0)-1&255;g=e[f+((d[f+295|0]|0)+6<<1)>>1]<<4;h=f+260|0;i=b[h>>1]|0;b[h>>1]=i+1&65535;h=(g+(i&65535)^c[f+256>>2])&1048575;i=c[3531864]|0;g=c[i+6188+(h>>>11<<2)>>2]|0;if((g|0)==0){j=gj[c[i+8236>>2]&4095](h)|0}else{j=a[g+h|0]|0}h=j&255;g=f+296|0;i=d[g]|0;k=9651808+(h<<2)|0;l=f;m=d[l+(i+(c[k>>2]|0))|0]|0;n=(j&255)>191;L61822:do{if(n){o=a[l+((c[9647712+(h<<2)>>2]|0)+i)|0]|0}else{j=gj[c[678944+(h<<2)>>2]&4095](f)|0;do{if((j&1048064|0)==(c[f+428>>2]|0)|(j|0)==1048575){p=j&511;if((a[f+424|0]|0)!=0&p>>>0<256){o=a[l+p|0]|0;break L61822}if(p>>>0<=255){break}o=f9w(f,p-256|0)|0;break L61822}}while(0);p=j&1048575;q=c[3531864]|0;r=c[q+44+(p>>>11<<2)>>2]|0;if((r|0)==0){o=gj[c[q+8236>>2]&4095](p)|0;break}else{o=a[r+p|0]|0;break}}}while(0);h=f+280|0;i=((c[h>>2]|0)!=0)+(o&255)|0;o=i+m|0;c[h>>2]=o&256;c[f+272>>2]=(o^m)&128&(o^i);c[f+268>>2]=(i^m^o)&16;m=o&255;o=m<<24>>24;c[f+284>>2]=o;c[f+276>>2]=o;c[f+264>>2]=o;a[l+((d[g]|0)+(c[k>>2]|0))|0]=m;m=f+432|0;c[m>>2]=(c[m>>2]|0)-((n?131586:723718)>>>((c[f+444>>2]|0)>>>0)&127);return}function f93(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=d+442|0;a[f]=(a[f]|0)-1&255;f=d+295|0;g=a[f]|0;h=(e[d+((g&255)+6<<1)>>1]|0)<<4;i=d+260|0;j=b[i>>1]|0;b[i>>1]=j+1&65535;i=(h+(j&65535)^c[d+256>>2])&1048575;j=c[3531864]|0;h=c[j+6188+(i>>>11<<2)>>2]|0;if((h|0)==0){k=gj[c[j+8236>>2]&4095](i)|0;l=k;m=a[f]|0}else{l=a[h+i|0]|0;m=g}g=l&255;i=m&255;h=9653856+(g<<2)|0;k=c[h>>2]|0;j=e[d+(i+k<<1)>>1]|0;n=(l&255)>191;if(n){o=b[d+((c[9649760+(g<<2)>>2]|0)+i<<1)>>1]|0;p=m;q=k}else{k=c[678944+(g<<2)>>2]|0;gj[k&4095](d)|0;k=f9x(d,c[2426954]|0)|0;o=k;p=a[f]|0;q=c[h>>2]|0}h=d+280|0;f=((c[h>>2]|0)!=0)+(o&65535)|0;o=f+j|0;c[h>>2]=o&65536;c[d+272>>2]=(o^j)&32768&(o^f);c[d+268>>2]=(f^j^o)&16;j=o&65535;o=j<<16>>16;c[d+284>>2]=o;c[d+276>>2]=o;c[d+264>>2]=o;b[d+(q+(p&255)<<1)>>1]=j;if(n){n=d+432|0;c[n>>2]=(c[n>>2]|0)-2;return}else{n=d+432|0;c[n>>2]=(c[n>>2]|0)-(((c[2426954]&1|0)!=0?986888:985862)>>>((c[d+444>>2]|0)>>>0)&127);return}}function f94(f){f=f|0;var g=0,h=0,i=0,j=0,k=0;g=f+442|0;a[g]=(a[g]|0)-1&255;g=(e[f+((d[f+295|0]|0)+6<<1)>>1]|0)<<4;h=f+260|0;i=b[h>>1]|0;b[h>>1]=i+1&65535;h=(g+(i&65535)^c[f+256>>2])&1048575;i=c[3531864]|0;g=c[i+6188+(h>>>11<<2)>>2]|0;if((g|0)==0){j=gj[c[i+8236>>2]&4095](h)|0}else{j=a[g+h|0]|0}h=f+((d[f+296|0]|0)+30)|0;g=d[h]|0;i=f+280|0;k=((c[i>>2]|0)!=0)+(j&255)|0;j=k+g|0;c[i>>2]=j&256;c[f+272>>2]=(j^g)&128&(j^k);c[f+268>>2]=(k^g^j)&16;g=j&255;j=g<<24>>24;c[f+284>>2]=j;c[f+276>>2]=j;c[f+264>>2]=j;a[h]=g;g=f+432|0;c[g>>2]=(c[g>>2]|0)-(263170>>>((c[f+444>>2]|0)>>>0)&127);return}function f95(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;f=d+442|0;g=(a[f]|0)-1&255;a[f]=g;h=d+295|0;i=a[h]|0;j=(e[d+((i&255)+6<<1)>>1]|0)<<4;k=d+260|0;l=b[k>>1]|0;m=l+1&65535;b[k>>1]=m;n=d+256|0;o=c[n>>2]|0;p=(j+(l&65535)^o)&1048575;l=c[3531864]|0;j=c[l+6188+(p>>>11<<2)>>2]|0;if((j|0)==0){q=gj[c[l+8236>>2]&4095](p)|0;r=q;s=a[h]|0;t=a[f]|0;u=b[k>>1]|0;v=c[n>>2]|0;w=c[3531864]|0}else{r=a[j+p|0]|0;s=i;t=g;u=m;v=o;w=l}l=s&255;o=e[d+(l+15<<1)>>1]|0;a[f]=t-1&255;t=(e[d+(l+6<<1)>>1]|0)<<4;b[k>>1]=u+1&65535;k=(t+(u&65535)^v)&1048575;v=c[w+6188+(k>>>11<<2)>>2]|0;if((v|0)==0){u=gj[c[w+8236>>2]&4095](k)|0;x=u;y=a[h]|0}else{x=a[v+k|0]|0;y=s}s=d+280|0;k=((x&255)<<8|r&255)+((c[s>>2]|0)!=0)|0;r=k+o|0;c[s>>2]=r&65536;c[d+272>>2]=(r^o)&32768&(r^k);c[d+268>>2]=(k^o^r)&16;o=r&65535;r=o<<16>>16;c[d+284>>2]=r;c[d+276>>2]=r;c[d+264>>2]=r;b[d+((y&255)+15<<1)>>1]=o;o=d+432|0;c[o>>2]=(c[o>>2]|0)-(263170>>>((c[d+444>>2]|0)>>>0)&127);return}function f96(a){a=a|0;var f=0,g=0;f=a+295|0;g=a+((d[f]|0)+11<<1)|0;b[g>>1]=(b[g>>1]|0)-2&65535;g=d[f]|0;f=b[a+(g+5<<1)>>1]|0;f9z(a,((f&65535)<<4)+(e[a+(g+11<<1)>>1]|0)|0,f);f=a+432|0;c[f>>2]=(c[f>>2]|0)-(788483>>>((c[a+444>>2]|0)>>>0)&127);return}function f97(f){f=f|0;var g=0,h=0,i=0;g=f+295|0;h=f+((d[g]|0)+11<<1)|0;b[h>>1]=(b[h>>1]|0)+2&65535;h=d[g]|0;i=f9x(f,((e[f+(h+11<<1)>>1]|0)+65534&65535)+((e[f+(h+5<<1)>>1]|0)<<4)|0)|0;b[f+((d[g]|0)+5<<1)>>1]=i;i=f+432|0;c[i>>2]=(c[i>>2]|0)-(788485>>>((c[f+444>>2]|0)>>>0)&127);a[f+352|0]=1;return}function f98(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=f+442|0;a[g]=(a[g]|0)-1&255;g=e[f+((d[f+295|0]|0)+6<<1)>>1]<<4;h=f+260|0;i=b[h>>1]|0;b[h>>1]=i+1&65535;h=(g+(i&65535)^c[f+256>>2])&1048575;i=c[3531864]|0;g=c[i+6188+(h>>>11<<2)>>2]|0;if((g|0)==0){j=gj[c[i+8236>>2]&4095](h)|0}else{j=a[g+h|0]|0}h=j&255;g=f+296|0;i=d[g]|0;k=f;l=d[k+(i+(c[9651808+(h<<2)>>2]|0))|0]|0;m=(j&255)>191;L61871:do{if(m){n=a[k+((c[9647712+(h<<2)>>2]|0)+i)|0]|0}else{j=gj[c[678944+(h<<2)>>2]&4095](f)|0;do{if((j&1048064|0)==(c[f+428>>2]|0)|(j|0)==1048575){o=j&511;if((a[f+424|0]|0)!=0&o>>>0<256){n=a[k+o|0]|0;break L61871}if(o>>>0<=255){break}n=f9w(f,o-256|0)|0;break L61871}}while(0);o=j&1048575;p=c[3531864]|0;q=c[p+44+(o>>>11<<2)>>2]|0;if((q|0)==0){n=gj[c[p+8236>>2]&4095](o)|0;break}else{n=a[q+o|0]|0;break}}}while(0);i=n&255;n=f+280|0;o=((c[n>>2]|0)!=0)+l|0;l=i-o|0;c[n>>2]=l&256;n=o^i;c[f+272>>2]=n&128&(l^i);c[f+268>>2]=(l^n)&16;n=l<<24>>24;c[f+284>>2]=n;c[f+276>>2]=n;c[f+264>>2]=n;L61885:do{if(m){a[k+((d[g]|0)+(c[9647712+(h<<2)>>2]|0))|0]=l&255}else{n=c[2426954]|0;i=l&255;do{if((n&1048064|0)==(c[f+428>>2]|0)|(n|0)==1048575){o=n&511;if((a[f+424|0]|0)!=0&o>>>0<256){a[k+o|0]=i;break L61885}if(o>>>0<=255){break}f9y(f,o-256|0,i);break L61885}}while(0);j=n&1048575;o=c[3531864]|0;q=c[o+2092+(j>>>11<<2)>>2]|0;if((q|0)==0){gg[c[o+8240>>2]&4095](j,i);break}else{a[q+j|0]=i;break}}}while(0);k=f+432|0;c[k>>2]=(c[k>>2]|0)-((m?131586:1052679)>>>((c[f+444>>2]|0)>>>0)&127);return}function f99(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=f+442|0;a[g]=(a[g]|0)-1&255;g=f+295|0;h=a[g]|0;i=(e[f+((h&255)+6<<1)>>1]|0)<<4;j=f+260|0;k=b[j>>1]|0;b[j>>1]=k+1&65535;j=(i+(k&65535)^c[f+256>>2])&1048575;k=c[3531864]|0;i=c[k+6188+(j>>>11<<2)>>2]|0;if((i|0)==0){l=gj[c[k+8236>>2]&4095](j)|0;m=l;n=a[g]|0}else{m=a[i+j|0]|0;n=h}h=m&255;j=n&255;n=e[f+(j+(c[9653856+(h<<2)>>2]|0)<<1)>>1]|0;i=(m&255)>191;if(i){o=b[f+((c[9649760+(h<<2)>>2]|0)+j<<1)>>1]|0}else{j=c[678944+(h<<2)>>2]|0;gj[j&4095](f)|0;o=f9x(f,c[2426954]|0)|0}j=o&65535;o=f+280|0;m=((c[o>>2]|0)!=0)+n|0;n=j-m|0;c[o>>2]=n&65536;o=m^j;c[f+272>>2]=o&32768&(n^j);c[f+268>>2]=(n^o)&16;o=n<<16>>16;c[f+284>>2]=o;c[f+276>>2]=o;c[f+264>>2]=o;if(i){b[f+((d[g]|0)+(c[9649760+(h<<2)>>2]|0)<<1)>>1]=n&65535;h=f+432|0;c[h>>2]=(c[h>>2]|0)-2;return}else{f9z(f,c[2426954]|0,n&65535);n=f+432|0;c[n>>2]=(c[n>>2]|0)-(((c[2426954]&1|0)!=0?1579019:1576967)>>>((c[f+444>>2]|0)>>>0)&127);return}}function gaa(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=f+442|0;a[g]=(a[g]|0)-1&255;g=e[f+((d[f+295|0]|0)+6<<1)>>1]<<4;h=f+260|0;i=b[h>>1]|0;b[h>>1]=i+1&65535;h=(g+(i&65535)^c[f+256>>2])&1048575;i=c[3531864]|0;g=c[i+6188+(h>>>11<<2)>>2]|0;if((g|0)==0){j=gj[c[i+8236>>2]&4095](h)|0}else{j=a[g+h|0]|0}h=j&255;g=f+296|0;i=d[g]|0;k=9651808+(h<<2)|0;l=f;m=d[l+(i+(c[k>>2]|0))|0]|0;n=(j&255)>191;L61918:do{if(n){o=a[l+((c[9647712+(h<<2)>>2]|0)+i)|0]|0}else{j=gj[c[678944+(h<<2)>>2]&4095](f)|0;do{if((j&1048064|0)==(c[f+428>>2]|0)|(j|0)==1048575){p=j&511;if((a[f+424|0]|0)!=0&p>>>0<256){o=a[l+p|0]|0;break L61918}if(p>>>0<=255){break}o=f9w(f,p-256|0)|0;break L61918}}while(0);p=j&1048575;q=c[3531864]|0;r=c[q+44+(p>>>11<<2)>>2]|0;if((r|0)==0){o=gj[c[q+8236>>2]&4095](p)|0;break}else{o=a[r+p|0]|0;break}}}while(0);h=f+280|0;i=((c[h>>2]|0)!=0)+(o&255)|0;o=m-i|0;c[h>>2]=o&256;h=i^m;c[f+272>>2]=h&128&(o^m);c[f+268>>2]=(o^h)&16;h=o&255;o=h<<24>>24;c[f+284>>2]=o;c[f+276>>2]=o;c[f+264>>2]=o;a[l+((d[g]|0)+(c[k>>2]|0))|0]=h;h=f+432|0;c[h>>2]=(c[h>>2]|0)-((n?131586:723718)>>>((c[f+444>>2]|0)>>>0)&127);return}function gab(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=d+442|0;a[f]=(a[f]|0)-1&255;f=d+295|0;g=a[f]|0;h=(e[d+((g&255)+6<<1)>>1]|0)<<4;i=d+260|0;j=b[i>>1]|0;b[i>>1]=j+1&65535;i=(h+(j&65535)^c[d+256>>2])&1048575;j=c[3531864]|0;h=c[j+6188+(i>>>11<<2)>>2]|0;if((h|0)==0){k=gj[c[j+8236>>2]&4095](i)|0;l=k;m=a[f]|0}else{l=a[h+i|0]|0;m=g}g=l&255;i=m&255;h=9653856+(g<<2)|0;k=c[h>>2]|0;j=e[d+(i+k<<1)>>1]|0;n=(l&255)>191;if(n){o=b[d+((c[9649760+(g<<2)>>2]|0)+i<<1)>>1]|0;p=m;q=k}else{k=c[678944+(g<<2)>>2]|0;gj[k&4095](d)|0;k=f9x(d,c[2426954]|0)|0;o=k;p=a[f]|0;q=c[h>>2]|0}h=d+280|0;f=((c[h>>2]|0)!=0)+(o&65535)|0;o=j-f|0;c[h>>2]=o&65536;h=f^j;c[d+272>>2]=h&32768&(o^j);c[d+268>>2]=(o^h)&16;h=o&65535;o=h<<16>>16;c[d+284>>2]=o;c[d+276>>2]=o;c[d+264>>2]=o;b[d+(q+(p&255)<<1)>>1]=h;if(n){n=d+432|0;c[n>>2]=(c[n>>2]|0)-2;return}else{n=d+432|0;c[n>>2]=(c[n>>2]|0)-(((c[2426954]&1|0)!=0?986888:985862)>>>((c[d+444>>2]|0)>>>0)&127);return}}function gac(f){f=f|0;var g=0,h=0,i=0,j=0,k=0;g=f+442|0;a[g]=(a[g]|0)-1&255;g=(e[f+((d[f+295|0]|0)+6<<1)>>1]|0)<<4;h=f+260|0;i=b[h>>1]|0;b[h>>1]=i+1&65535;h=(g+(i&65535)^c[f+256>>2])&1048575;i=c[3531864]|0;g=c[i+6188+(h>>>11<<2)>>2]|0;if((g|0)==0){j=gj[c[i+8236>>2]&4095](h)|0}else{j=a[g+h|0]|0}h=f+((d[f+296|0]|0)+30)|0;g=d[h]|0;i=f+280|0;k=((c[i>>2]|0)!=0)+(j&255)|0;j=g-k|0;c[i>>2]=j&256;i=k^g;c[f+272>>2]=i&128&(j^g);c[f+268>>2]=(j^i)&16;i=j&255;j=i<<24>>24;c[f+284>>2]=j;c[f+276>>2]=j;c[f+264>>2]=j;a[h]=i;i=f+432|0;c[i>>2]=(c[i>>2]|0)-(263170>>>((c[f+444>>2]|0)>>>0)&127);return}function gad(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;f=d+442|0;g=(a[f]|0)-1&255;a[f]=g;h=d+295|0;i=a[h]|0;j=(e[d+((i&255)+6<<1)>>1]|0)<<4;k=d+260|0;l=b[k>>1]|0;m=l+1&65535;b[k>>1]=m;n=d+256|0;o=c[n>>2]|0;p=(j+(l&65535)^o)&1048575;l=c[3531864]|0;j=c[l+6188+(p>>>11<<2)>>2]|0;if((j|0)==0){q=gj[c[l+8236>>2]&4095](p)|0;r=q;s=a[h]|0;t=a[f]|0;u=b[k>>1]|0;v=c[n>>2]|0;w=c[3531864]|0}else{r=a[j+p|0]|0;s=i;t=g;u=m;v=o;w=l}l=s&255;o=e[d+(l+15<<1)>>1]|0;a[f]=t-1&255;t=(e[d+(l+6<<1)>>1]|0)<<4;b[k>>1]=u+1&65535;k=(t+(u&65535)^v)&1048575;v=c[w+6188+(k>>>11<<2)>>2]|0;if((v|0)==0){u=gj[c[w+8236>>2]&4095](k)|0;x=u;y=a[h]|0}else{x=a[v+k|0]|0;y=s}s=d+280|0;k=((x&255)<<8|r&255)+((c[s>>2]|0)!=0)|0;r=o-k|0;c[s>>2]=r&65536;s=k^o;c[d+272>>2]=s&32768&(r^o);c[d+268>>2]=(r^s)&16;s=r&65535;r=s<<16>>16;c[d+284>>2]=r;c[d+276>>2]=r;c[d+264>>2]=r;b[d+((y&255)+15<<1)>>1]=s;s=d+432|0;c[s>>2]=(c[s>>2]|0)-(263170>>>((c[d+444>>2]|0)>>>0)&127);return}function gae(a){a=a|0;var f=0,g=0;f=a+295|0;g=a+((d[f]|0)+11<<1)|0;b[g>>1]=(b[g>>1]|0)-2&65535;g=d[f]|0;f9z(a,((e[a+(g+5<<1)>>1]|0)<<4)+(e[a+(g+11<<1)>>1]|0)|0,b[a+(g+4<<1)>>1]|0);g=a+432|0;c[g>>2]=(c[g>>2]|0)-(788483>>>((c[a+444>>2]|0)>>>0)&127);return}function gaf(a){a=a|0;var f=0,g=0,h=0;f=a+295|0;g=a+((d[f]|0)+11<<1)|0;b[g>>1]=(b[g>>1]|0)+2&65535;g=d[f]|0;h=f9x(a,((e[a+(g+11<<1)>>1]|0)+65534&65535)+((e[a+(g+5<<1)>>1]|0)<<4)|0)|0;b[a+((d[f]|0)+4<<1)>>1]=h;h=a+432|0;c[h>>2]=(c[h>>2]|0)-(788485>>>((c[a+444>>2]|0)>>>0)&127);return}function gag(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=f+442|0;a[g]=(a[g]|0)-1&255;g=e[f+((d[f+295|0]|0)+6<<1)>>1]<<4;h=f+260|0;i=b[h>>1]|0;b[h>>1]=i+1&65535;h=(g+(i&65535)^c[f+256>>2])&1048575;i=c[3531864]|0;g=c[i+6188+(h>>>11<<2)>>2]|0;if((g|0)==0){j=gj[c[i+8236>>2]&4095](h)|0}else{j=a[g+h|0]|0}h=j&255;g=f+296|0;i=d[g]|0;k=f;l=a[k+(i+(c[9651808+(h<<2)>>2]|0))|0]|0;m=(j&255)>191;L61967:do{if(m){n=a[k+((c[9647712+(h<<2)>>2]|0)+i)|0]|0}else{j=gj[c[678944+(h<<2)>>2]&4095](f)|0;do{if((j&1048064|0)==(c[f+428>>2]|0)|(j|0)==1048575){o=j&511;if((a[f+424|0]|0)!=0&o>>>0<256){n=a[k+o|0]|0;break L61967}if(o>>>0<=255){break}n=f9w(f,o-256|0)|0;break L61967}}while(0);o=j&1048575;p=c[3531864]|0;q=c[p+44+(o>>>11<<2)>>2]|0;if((q|0)==0){n=gj[c[p+8236>>2]&4095](o)|0;break}else{n=a[q+o|0]|0;break}}}while(0);i=n&l;c[f+268>>2]=0;c[f+272>>2]=0;c[f+280>>2]=0;l=i<<24>>24;c[f+284>>2]=l;c[f+276>>2]=l;c[f+264>>2]=l;L61981:do{if(m){a[k+((d[g]|0)+(c[9647712+(h<<2)>>2]|0))|0]=i}else{l=c[2426954]|0;do{if((l&1048064|0)==(c[f+428>>2]|0)|(l|0)==1048575){n=l&511;if((a[f+424|0]|0)!=0&n>>>0<256){a[k+n|0]=i;break L61981}if(n>>>0<=255){break}f9y(f,n-256|0,i);break L61981}}while(0);j=l&1048575;n=c[3531864]|0;o=c[n+2092+(j>>>11<<2)>>2]|0;if((o|0)==0){gg[c[n+8240>>2]&4095](j,i);break}else{a[o+j|0]=i;break}}}while(0);i=f+432|0;c[i>>2]=(c[i>>2]|0)-((m?131586:1052679)>>>((c[f+444>>2]|0)>>>0)&127);return}function gah(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=f+442|0;a[g]=(a[g]|0)-1&255;g=f+295|0;h=a[g]|0;i=(e[f+((h&255)+6<<1)>>1]|0)<<4;j=f+260|0;k=b[j>>1]|0;b[j>>1]=k+1&65535;j=(i+(k&65535)^c[f+256>>2])&1048575;k=c[3531864]|0;i=c[k+6188+(j>>>11<<2)>>2]|0;if((i|0)==0){l=gj[c[k+8236>>2]&4095](j)|0;m=l;n=a[g]|0}else{m=a[i+j|0]|0;n=h}h=m&255;j=n&255;n=b[f+(j+(c[9653856+(h<<2)>>2]|0)<<1)>>1]|0;i=(m&255)>191;if(i){o=b[f+((c[9649760+(h<<2)>>2]|0)+j<<1)>>1]|0}else{j=c[678944+(h<<2)>>2]|0;gj[j&4095](f)|0;o=f9x(f,c[2426954]|0)|0}j=o&n;c[f+268>>2]=0;c[f+272>>2]=0;c[f+280>>2]=0;n=j<<16>>16;c[f+284>>2]=n;c[f+276>>2]=n;c[f+264>>2]=n;if(i){b[f+((d[g]|0)+(c[9649760+(h<<2)>>2]|0)<<1)>>1]=j;h=f+432|0;c[h>>2]=(c[h>>2]|0)-2;return}else{f9z(f,c[2426954]|0,j);j=f+432|0;c[j>>2]=(c[j>>2]|0)-(((c[2426954]&1|0)!=0?1579019:1576967)>>>((c[f+444>>2]|0)>>>0)&127);return}}function gai(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=f+442|0;a[g]=(a[g]|0)-1&255;g=e[f+((d[f+295|0]|0)+6<<1)>>1]<<4;h=f+260|0;i=b[h>>1]|0;b[h>>1]=i+1&65535;h=(g+(i&65535)^c[f+256>>2])&1048575;i=c[3531864]|0;g=c[i+6188+(h>>>11<<2)>>2]|0;if((g|0)==0){j=gj[c[i+8236>>2]&4095](h)|0}else{j=a[g+h|0]|0}h=j&255;g=f+296|0;i=d[g]|0;k=9651808+(h<<2)|0;l=f;m=a[l+(i+(c[k>>2]|0))|0]|0;n=(j&255)>191;L62014:do{if(n){o=a[l+((c[9647712+(h<<2)>>2]|0)+i)|0]|0}else{j=gj[c[678944+(h<<2)>>2]&4095](f)|0;do{if((j&1048064|0)==(c[f+428>>2]|0)|(j|0)==1048575){p=j&511;if((a[f+424|0]|0)!=0&p>>>0<256){o=a[l+p|0]|0;break L62014}if(p>>>0<=255){break}o=f9w(f,p-256|0)|0;break L62014}}while(0);p=j&1048575;q=c[3531864]|0;r=c[q+44+(p>>>11<<2)>>2]|0;if((r|0)==0){o=gj[c[q+8236>>2]&4095](p)|0;break}else{o=a[r+p|0]|0;break}}}while(0);h=o&m;c[f+268>>2]=0;c[f+272>>2]=0;c[f+280>>2]=0;m=h<<24>>24;c[f+284>>2]=m;c[f+276>>2]=m;c[f+264>>2]=m;a[l+((d[g]|0)+(c[k>>2]|0))|0]=h;h=f+432|0;c[h>>2]=(c[h>>2]|0)-((n?131586:723718)>>>((c[f+444>>2]|0)>>>0)&127);return}function gaj(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=d+442|0;a[f]=(a[f]|0)-1&255;f=d+295|0;g=a[f]|0;h=(e[d+((g&255)+6<<1)>>1]|0)<<4;i=d+260|0;j=b[i>>1]|0;b[i>>1]=j+1&65535;i=(h+(j&65535)^c[d+256>>2])&1048575;j=c[3531864]|0;h=c[j+6188+(i>>>11<<2)>>2]|0;if((h|0)==0){k=gj[c[j+8236>>2]&4095](i)|0;l=k;m=a[f]|0}else{l=a[h+i|0]|0;m=g}g=l&255;i=m&255;h=9653856+(g<<2)|0;k=c[h>>2]|0;j=b[d+(i+k<<1)>>1]|0;n=(l&255)>191;if(n){o=b[d+((c[9649760+(g<<2)>>2]|0)+i<<1)>>1]|0;p=m;q=k}else{k=c[678944+(g<<2)>>2]|0;gj[k&4095](d)|0;k=f9x(d,c[2426954]|0)|0;o=k;p=a[f]|0;q=c[h>>2]|0}h=o&j;c[d+268>>2]=0;c[d+272>>2]=0;c[d+280>>2]=0;j=h<<16>>16;c[d+284>>2]=j;c[d+276>>2]=j;c[d+264>>2]=j;b[d+(q+(p&255)<<1)>>1]=h;if(n){n=d+432|0;c[n>>2]=(c[n>>2]|0)-2;return}else{n=d+432|0;c[n>>2]=(c[n>>2]|0)-(((c[2426954]&1|0)!=0?986888:985862)>>>((c[d+444>>2]|0)>>>0)&127);return}}function gak(f){f=f|0;var g=0,h=0,i=0,j=0;g=f+442|0;a[g]=(a[g]|0)-1&255;g=(e[f+((d[f+295|0]|0)+6<<1)>>1]|0)<<4;h=f+260|0;i=b[h>>1]|0;b[h>>1]=i+1&65535;h=(g+(i&65535)^c[f+256>>2])&1048575;i=c[3531864]|0;g=c[i+6188+(h>>>11<<2)>>2]|0;if((g|0)==0){j=gj[c[i+8236>>2]&4095](h)|0}else{j=a[g+h|0]|0}h=f+((d[f+296|0]|0)+30)|0;g=a[h]&j;c[f+268>>2]=0;c[f+272>>2]=0;c[f+280>>2]=0;j=g<<24>>24;c[f+284>>2]=j;c[f+276>>2]=j;c[f+264>>2]=j;a[h]=g;g=f+432|0;c[g>>2]=(c[g>>2]|0)-(263170>>>((c[f+444>>2]|0)>>>0)&127);return}function gal(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;f=d+442|0;g=(a[f]|0)-1&255;a[f]=g;h=d+295|0;i=a[h]|0;j=(e[d+((i&255)+6<<1)>>1]|0)<<4;k=d+260|0;l=b[k>>1]|0;m=l+1&65535;b[k>>1]=m;n=d+256|0;o=c[n>>2]|0;p=(j+(l&65535)^o)&1048575;l=c[3531864]|0;j=c[l+6188+(p>>>11<<2)>>2]|0;if((j|0)==0){q=gj[c[l+8236>>2]&4095](p)|0;r=q;s=a[h]|0;t=a[f]|0;u=b[k>>1]|0;v=c[n>>2]|0;w=c[3531864]|0}else{r=a[j+p|0]|0;s=i;t=g;u=m;v=o;w=l}l=s&255;o=b[d+(l+15<<1)>>1]|0;a[f]=t-1&255;t=(e[d+(l+6<<1)>>1]|0)<<4;b[k>>1]=u+1&65535;k=(t+(u&65535)^v)&1048575;v=c[w+6188+(k>>>11<<2)>>2]|0;if((v|0)==0){u=gj[c[w+8236>>2]&4095](k)|0;x=u;y=a[h]|0}else{x=a[v+k|0]|0;y=s}s=((x&255)<<8|r&255)&o;c[d+268>>2]=0;c[d+272>>2]=0;c[d+280>>2]=0;o=s<<16>>16;c[d+284>>2]=o;c[d+276>>2]=o;c[d+264>>2]=o;b[d+((y&255)+15<<1)>>1]=s;s=d+432|0;c[s>>2]=(c[s>>2]|0)-(263170>>>((c[d+444>>2]|0)>>>0)&127);return}function gam(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;g=f+452|0;a[g]=1;h=d[f+295|0]|0;c[f+448>>2]=e[f+(h+7<<1)>>1]<<4;i=f+432|0;c[i>>2]=(c[i>>2]|0)-2;i=f+442|0;a[i]=(a[i]|0)-1&255;i=e[f+(h+6<<1)>>1]<<4;h=f+260|0;j=b[h>>1]|0;b[h>>1]=j+1&65535;h=(i+(j&65535)^c[f+256>>2])&1048575;j=c[3531864]|0;i=c[j+4140+(h>>>11<<2)>>2]|0;if((i|0)==0){k=gj[c[j+8236>>2]&4095](h)|0}else{k=a[i+h|0]|0}do{if((a[f+294|0]|0)==0){h=c[f+436>>2]|0;if((h|0)==0){l=k;break}l=a[h+(k&255)|0]|0}else{l=k}}while(0);gf[c[2519504+((l&255)<<2)>>2]&2047](f);a[g]=0;return}function gan(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=b+268|0;e=b+296|0;f=a[e]|0;do{if((c[d>>2]|0)==0){g=(f&255)+30|0;h=b;i=a[h+g|0]|0;if((i&14)>>>0>9){j=h;k=g;l=i;m=50518;break}n=c[b+280>>2]|0;o=f}else{i=b;g=(f&255)+30|0;j=i;k=g;l=a[i+g|0]|0;m=50518}}while(0);if((m|0)==50518){f=(l&255)+6&65535;a[j+k|0]=f&255;c[d>>2]=1;d=b+280|0;k=f&256|c[d>>2];c[d>>2]=k;n=k;o=a[e]|0}k=b+280|0;if((n|0)==0){n=(o&255)+30|0;d=b;f=a[d+n|0]|0;if((f&255)>159){p=d;q=n;r=f;m=50522}else{s=o;t=d}}else{d=b;f=(o&255)+30|0;p=d;q=f;r=a[d+f|0]|0;m=50522}if((m|0)==50522){a[p+q|0]=r+96&255;c[k>>2]=1;s=a[e]|0;t=b}e=a[t+((s&255)+30)|0]|0;c[b+284>>2]=e;c[b+276>>2]=e;c[b+264>>2]=e;e=b+432|0;c[e>>2]=(c[e>>2]|0)-(197378>>>((c[b+444>>2]|0)>>>0)&127);return}function gao(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=f+442|0;a[g]=(a[g]|0)-1&255;g=e[f+((d[f+295|0]|0)+6<<1)>>1]<<4;h=f+260|0;i=b[h>>1]|0;b[h>>1]=i+1&65535;h=(g+(i&65535)^c[f+256>>2])&1048575;i=c[3531864]|0;g=c[i+6188+(h>>>11<<2)>>2]|0;if((g|0)==0){j=gj[c[i+8236>>2]&4095](h)|0}else{j=a[g+h|0]|0}h=j&255;g=f+296|0;i=d[g]|0;k=f;l=a[k+(i+(c[9651808+(h<<2)>>2]|0))|0]|0;m=l&255;n=(j&255)>191;L62084:do{if(n){o=a[k+((c[9647712+(h<<2)>>2]|0)+i)|0]|0}else{j=gj[c[678944+(h<<2)>>2]&4095](f)|0;do{if((j&1048064|0)==(c[f+428>>2]|0)|(j|0)==1048575){p=j&511;if((a[f+424|0]|0)!=0&p>>>0<256){o=a[k+p|0]|0;break L62084}if(p>>>0<=255){break}o=f9w(f,p-256|0)|0;break L62084}}while(0);p=j&1048575;q=c[3531864]|0;r=c[q+44+(p>>>11<<2)>>2]|0;if((r|0)==0){o=gj[c[q+8236>>2]&4095](p)|0;break}else{o=a[r+p|0]|0;break}}}while(0);i=o&255;p=i-m|0;c[f+280>>2]=p&256;m=(o^l)&255;c[f+272>>2]=m&128&(p^i);c[f+268>>2]=(p^m)&16;m=p<<24>>24;c[f+284>>2]=m;c[f+276>>2]=m;c[f+264>>2]=m;L62098:do{if(n){a[k+((d[g]|0)+(c[9647712+(h<<2)>>2]|0))|0]=p&255}else{m=c[2426954]|0;i=p&255;do{if((m&1048064|0)==(c[f+428>>2]|0)|(m|0)==1048575){l=m&511;if((a[f+424|0]|0)!=0&l>>>0<256){a[k+l|0]=i;break L62098}if(l>>>0<=255){break}f9y(f,l-256|0,i);break L62098}}while(0);j=m&1048575;l=c[3531864]|0;o=c[l+2092+(j>>>11<<2)>>2]|0;if((o|0)==0){gg[c[l+8240>>2]&4095](j,i);break}else{a[o+j|0]=i;break}}}while(0);k=f+432|0;c[k>>2]=(c[k>>2]|0)-((n?131586:1052679)>>>((c[f+444>>2]|0)>>>0)&127);return}function gap(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=f+442|0;a[g]=(a[g]|0)-1&255;g=f+295|0;h=a[g]|0;i=(e[f+((h&255)+6<<1)>>1]|0)<<4;j=f+260|0;k=b[j>>1]|0;b[j>>1]=k+1&65535;j=(i+(k&65535)^c[f+256>>2])&1048575;k=c[3531864]|0;i=c[k+6188+(j>>>11<<2)>>2]|0;if((i|0)==0){l=gj[c[k+8236>>2]&4095](j)|0;m=l;n=a[g]|0}else{m=a[i+j|0]|0;n=h}h=m&255;j=n&255;n=b[f+(j+(c[9653856+(h<<2)>>2]|0)<<1)>>1]|0;i=(m&255)>191;if(i){o=b[f+((c[9649760+(h<<2)>>2]|0)+j<<1)>>1]|0}else{j=c[678944+(h<<2)>>2]|0;gj[j&4095](f)|0;o=f9x(f,c[2426954]|0)|0}j=o&65535;m=j-(n&65535)|0;c[f+280>>2]=m&65536;l=(o^n)&65535;c[f+272>>2]=l&32768&(m^j);c[f+268>>2]=(m^l)&16;l=m<<16>>16;c[f+284>>2]=l;c[f+276>>2]=l;c[f+264>>2]=l;if(i){b[f+((d[g]|0)+(c[9649760+(h<<2)>>2]|0)<<1)>>1]=m&65535;h=f+432|0;c[h>>2]=(c[h>>2]|0)-2;return}else{f9z(f,c[2426954]|0,m&65535);m=f+432|0;c[m>>2]=(c[m>>2]|0)-(((c[2426954]&1|0)!=0?1579019:1576967)>>>((c[f+444>>2]|0)>>>0)&127);return}}function gaq(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=f+442|0;a[g]=(a[g]|0)-1&255;g=e[f+((d[f+295|0]|0)+6<<1)>>1]<<4;h=f+260|0;i=b[h>>1]|0;b[h>>1]=i+1&65535;h=(g+(i&65535)^c[f+256>>2])&1048575;i=c[3531864]|0;g=c[i+6188+(h>>>11<<2)>>2]|0;if((g|0)==0){j=gj[c[i+8236>>2]&4095](h)|0}else{j=a[g+h|0]|0}h=j&255;g=f+296|0;i=d[g]|0;k=9651808+(h<<2)|0;l=f;m=a[l+(i+(c[k>>2]|0))|0]|0;n=m&255;o=(j&255)>191;L62131:do{if(o){p=a[l+((c[9647712+(h<<2)>>2]|0)+i)|0]|0}else{j=gj[c[678944+(h<<2)>>2]&4095](f)|0;do{if((j&1048064|0)==(c[f+428>>2]|0)|(j|0)==1048575){q=j&511;if((a[f+424|0]|0)!=0&q>>>0<256){p=a[l+q|0]|0;break L62131}if(q>>>0<=255){break}p=f9w(f,q-256|0)|0;break L62131}}while(0);q=j&1048575;r=c[3531864]|0;s=c[r+44+(q>>>11<<2)>>2]|0;if((s|0)==0){p=gj[c[r+8236>>2]&4095](q)|0;break}else{p=a[s+q|0]|0;break}}}while(0);h=n-(p&255)|0;c[f+280>>2]=h&256;i=(p^m)&255;c[f+272>>2]=i&128&(h^n);c[f+268>>2]=(h^i)&16;i=h&255;h=i<<24>>24;c[f+284>>2]=h;c[f+276>>2]=h;c[f+264>>2]=h;a[l+((d[g]|0)+(c[k>>2]|0))|0]=i;i=f+432|0;c[i>>2]=(c[i>>2]|0)-((o?131586:723718)>>>((c[f+444>>2]|0)>>>0)&127);return}function gar(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=d+442|0;a[f]=(a[f]|0)-1&255;f=d+295|0;g=a[f]|0;h=(e[d+((g&255)+6<<1)>>1]|0)<<4;i=d+260|0;j=b[i>>1]|0;b[i>>1]=j+1&65535;i=(h+(j&65535)^c[d+256>>2])&1048575;j=c[3531864]|0;h=c[j+6188+(i>>>11<<2)>>2]|0;if((h|0)==0){k=gj[c[j+8236>>2]&4095](i)|0;l=k;m=a[f]|0}else{l=a[h+i|0]|0;m=g}g=l&255;i=m&255;h=9653856+(g<<2)|0;k=c[h>>2]|0;j=b[d+(i+k<<1)>>1]|0;n=j&65535;o=(l&255)>191;if(o){p=b[d+((c[9649760+(g<<2)>>2]|0)+i<<1)>>1]|0;q=m;r=k}else{k=c[678944+(g<<2)>>2]|0;gj[k&4095](d)|0;k=f9x(d,c[2426954]|0)|0;p=k;q=a[f]|0;r=c[h>>2]|0}h=n-(p&65535)|0;c[d+280>>2]=h&65536;f=(p^j)&65535;c[d+272>>2]=f&32768&(h^n);c[d+268>>2]=(h^f)&16;f=h&65535;h=f<<16>>16;c[d+284>>2]=h;c[d+276>>2]=h;c[d+264>>2]=h;b[d+(r+(q&255)<<1)>>1]=f;if(o){o=d+432|0;c[o>>2]=(c[o>>2]|0)-2;return}else{o=d+432|0;c[o>>2]=(c[o>>2]|0)-(((c[2426954]&1|0)!=0?986888:985862)>>>((c[d+444>>2]|0)>>>0)&127);return}}function gas(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;g=f+442|0;a[g]=(a[g]|0)-1&255;g=(e[f+((d[f+295|0]|0)+6<<1)>>1]|0)<<4;h=f+260|0;i=b[h>>1]|0;b[h>>1]=i+1&65535;h=(g+(i&65535)^c[f+256>>2])&1048575;i=c[3531864]|0;g=c[i+6188+(h>>>11<<2)>>2]|0;if((g|0)==0){j=gj[c[i+8236>>2]&4095](h)|0}else{j=a[g+h|0]|0}h=f+((d[f+296|0]|0)+30)|0;g=a[h]|0;i=g&255;k=i-(j&255)|0;c[f+280>>2]=k&256;l=(g^j)&255;c[f+272>>2]=l&128&(k^i);c[f+268>>2]=(k^l)&16;l=k&255;k=l<<24>>24;c[f+284>>2]=k;c[f+276>>2]=k;c[f+264>>2]=k;a[h]=l;l=f+432|0;c[l>>2]=(c[l>>2]|0)-(263170>>>((c[f+444>>2]|0)>>>0)&127);return}function gat(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;f=d+442|0;g=(a[f]|0)-1&255;a[f]=g;h=d+295|0;i=a[h]|0;j=(e[d+((i&255)+6<<1)>>1]|0)<<4;k=d+260|0;l=b[k>>1]|0;m=l+1&65535;b[k>>1]=m;n=d+256|0;o=c[n>>2]|0;p=(j+(l&65535)^o)&1048575;l=c[3531864]|0;j=c[l+6188+(p>>>11<<2)>>2]|0;if((j|0)==0){q=gj[c[l+8236>>2]&4095](p)|0;r=q;s=a[h]|0;t=a[f]|0;u=b[k>>1]|0;v=c[n>>2]|0;w=c[3531864]|0}else{r=a[j+p|0]|0;s=i;t=g;u=m;v=o;w=l}l=s&255;o=e[d+(l+15<<1)>>1]|0;a[f]=t-1&255;t=(e[d+(l+6<<1)>>1]|0)<<4;b[k>>1]=u+1&65535;k=(t+(u&65535)^v)&1048575;v=c[w+6188+(k>>>11<<2)>>2]|0;if((v|0)==0){u=gj[c[w+8236>>2]&4095](k)|0;x=u;y=a[h]|0}else{x=a[v+k|0]|0;y=s}s=(x&255)<<8|r&255;r=o-s|0;c[d+280>>2]=r&65536;x=s^o;c[d+272>>2]=x&32768&(r^o);c[d+268>>2]=(r^x)&16;x=r&65535;r=x<<16>>16;c[d+284>>2]=r;c[d+276>>2]=r;c[d+264>>2]=r;b[d+((y&255)+15<<1)>>1]=x;x=d+432|0;c[x>>2]=(c[x>>2]|0)-(263170>>>((c[d+444>>2]|0)>>>0)&127);return}function gau(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;g=f+452|0;a[g]=1;h=f+((d[f+295|0]|0)+6<<1)|0;c[f+448>>2]=e[h>>1]<<4;i=f+432|0;c[i>>2]=(c[i>>2]|0)-2;i=f+442|0;a[i]=(a[i]|0)-1&255;i=e[h>>1]<<4;h=f+260|0;j=b[h>>1]|0;b[h>>1]=j+1&65535;h=(i+(j&65535)^c[f+256>>2])&1048575;j=c[3531864]|0;i=c[j+4140+(h>>>11<<2)>>2]|0;if((i|0)==0){k=gj[c[j+8236>>2]&4095](h)|0}else{k=a[i+h|0]|0}do{if((a[f+294|0]|0)==0){h=c[f+436>>2]|0;if((h|0)==0){l=k;break}l=a[h+(k&255)|0]|0}else{l=k}}while(0);gf[c[2519504+((l&255)<<2)>>2]&2047](f);a[g]=0;return}function gav(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=b+268|0;e=b+296|0;f=a[e]|0;do{if((c[d>>2]|0)==0){g=(f&255)+30|0;h=b;i=a[h+g|0]|0;if((i&14)>>>0>9){j=h;k=g;l=i;m=50608;break}n=c[b+280>>2]|0;o=f}else{i=b;g=(f&255)+30|0;j=i;k=g;l=a[i+g|0]|0;m=50608}}while(0);if((m|0)==50608){f=(l&255)-6&65535;a[j+k|0]=f&255;c[d>>2]=1;d=b+280|0;k=f&256|c[d>>2];c[d>>2]=k;n=k;o=a[e]|0}k=b+280|0;if((n|0)==0){n=(o&255)+30|0;d=b;f=a[d+n|0]|0;if((f&255)>159){p=d;q=n;r=f;m=50612}else{s=o;t=d}}else{d=b;f=(o&255)+30|0;p=d;q=f;r=a[d+f|0]|0;m=50612}if((m|0)==50612){a[p+q|0]=r-96&255;c[k>>2]=1;s=a[e]|0;t=b}e=a[t+((s&255)+30)|0]|0;c[b+284>>2]=e;c[b+276>>2]=e;c[b+264>>2]=e;e=b+432|0;c[e>>2]=(c[e>>2]|0)-(197378>>>((c[b+444>>2]|0)>>>0)&127);return}function gaw(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=f+442|0;a[g]=(a[g]|0)-1&255;g=e[f+((d[f+295|0]|0)+6<<1)>>1]<<4;h=f+260|0;i=b[h>>1]|0;b[h>>1]=i+1&65535;h=(g+(i&65535)^c[f+256>>2])&1048575;i=c[3531864]|0;g=c[i+6188+(h>>>11<<2)>>2]|0;if((g|0)==0){j=gj[c[i+8236>>2]&4095](h)|0}else{j=a[g+h|0]|0}h=j&255;g=f+296|0;i=d[g]|0;k=f;l=a[k+(i+(c[9651808+(h<<2)>>2]|0))|0]|0;m=(j&255)>191;L62201:do{if(m){n=a[k+((c[9647712+(h<<2)>>2]|0)+i)|0]|0}else{j=gj[c[678944+(h<<2)>>2]&4095](f)|0;do{if((j&1048064|0)==(c[f+428>>2]|0)|(j|0)==1048575){o=j&511;if((a[f+424|0]|0)!=0&o>>>0<256){n=a[k+o|0]|0;break L62201}if(o>>>0<=255){break}n=f9w(f,o-256|0)|0;break L62201}}while(0);o=j&1048575;p=c[3531864]|0;q=c[p+44+(o>>>11<<2)>>2]|0;if((q|0)==0){n=gj[c[p+8236>>2]&4095](o)|0;break}else{n=a[q+o|0]|0;break}}}while(0);i=n^l;c[f+268>>2]=0;c[f+272>>2]=0;c[f+280>>2]=0;l=i<<24>>24;c[f+284>>2]=l;c[f+276>>2]=l;c[f+264>>2]=l;L62215:do{if(m){a[k+((d[g]|0)+(c[9647712+(h<<2)>>2]|0))|0]=i}else{l=c[2426954]|0;do{if((l&1048064|0)==(c[f+428>>2]|0)|(l|0)==1048575){n=l&511;if((a[f+424|0]|0)!=0&n>>>0<256){a[k+n|0]=i;break L62215}if(n>>>0<=255){break}f9y(f,n-256|0,i);break L62215}}while(0);j=l&1048575;n=c[3531864]|0;o=c[n+2092+(j>>>11<<2)>>2]|0;if((o|0)==0){gg[c[n+8240>>2]&4095](j,i);break}else{a[o+j|0]=i;break}}}while(0);i=f+432|0;c[i>>2]=(c[i>>2]|0)-((m?131586:1052679)>>>((c[f+444>>2]|0)>>>0)&127);return}function gax(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=f+442|0;a[g]=(a[g]|0)-1&255;g=f+295|0;h=a[g]|0;i=(e[f+((h&255)+6<<1)>>1]|0)<<4;j=f+260|0;k=b[j>>1]|0;b[j>>1]=k+1&65535;j=(i+(k&65535)^c[f+256>>2])&1048575;k=c[3531864]|0;i=c[k+6188+(j>>>11<<2)>>2]|0;if((i|0)==0){l=gj[c[k+8236>>2]&4095](j)|0;m=l;n=a[g]|0}else{m=a[i+j|0]|0;n=h}h=m&255;j=n&255;n=b[f+(j+(c[9653856+(h<<2)>>2]|0)<<1)>>1]|0;i=(m&255)>191;if(i){o=b[f+((c[9649760+(h<<2)>>2]|0)+j<<1)>>1]|0}else{j=c[678944+(h<<2)>>2]|0;gj[j&4095](f)|0;o=f9x(f,c[2426954]|0)|0}j=o^n;c[f+268>>2]=0;c[f+272>>2]=0;c[f+280>>2]=0;n=j<<16>>16;c[f+284>>2]=n;c[f+276>>2]=n;c[f+264>>2]=n;if(i){b[f+((d[g]|0)+(c[9649760+(h<<2)>>2]|0)<<1)>>1]=j;h=f+432|0;c[h>>2]=(c[h>>2]|0)-2;return}else{f9z(f,c[2426954]|0,j);j=f+432|0;c[j>>2]=(c[j>>2]|0)-(((c[2426954]&1|0)!=0?1579019:1576967)>>>((c[f+444>>2]|0)>>>0)&127);return}}function gay(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=f+442|0;a[g]=(a[g]|0)-1&255;g=e[f+((d[f+295|0]|0)+6<<1)>>1]<<4;h=f+260|0;i=b[h>>1]|0;b[h>>1]=i+1&65535;h=(g+(i&65535)^c[f+256>>2])&1048575;i=c[3531864]|0;g=c[i+6188+(h>>>11<<2)>>2]|0;if((g|0)==0){j=gj[c[i+8236>>2]&4095](h)|0}else{j=a[g+h|0]|0}h=j&255;g=f+296|0;i=d[g]|0;k=9651808+(h<<2)|0;l=f;m=a[l+(i+(c[k>>2]|0))|0]|0;n=(j&255)>191;L62248:do{if(n){o=a[l+((c[9647712+(h<<2)>>2]|0)+i)|0]|0}else{j=gj[c[678944+(h<<2)>>2]&4095](f)|0;do{if((j&1048064|0)==(c[f+428>>2]|0)|(j|0)==1048575){p=j&511;if((a[f+424|0]|0)!=0&p>>>0<256){o=a[l+p|0]|0;break L62248}if(p>>>0<=255){break}o=f9w(f,p-256|0)|0;break L62248}}while(0);p=j&1048575;q=c[3531864]|0;r=c[q+44+(p>>>11<<2)>>2]|0;if((r|0)==0){o=gj[c[q+8236>>2]&4095](p)|0;break}else{o=a[r+p|0]|0;break}}}while(0);h=o^m;c[f+268>>2]=0;c[f+272>>2]=0;c[f+280>>2]=0;m=h<<24>>24;c[f+284>>2]=m;c[f+276>>2]=m;c[f+264>>2]=m;a[l+((d[g]|0)+(c[k>>2]|0))|0]=h;h=f+432|0;c[h>>2]=(c[h>>2]|0)-((n?131586:723718)>>>((c[f+444>>2]|0)>>>0)&127);return}function gaz(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=d+442|0;a[f]=(a[f]|0)-1&255;f=d+295|0;g=a[f]|0;h=(e[d+((g&255)+6<<1)>>1]|0)<<4;i=d+260|0;j=b[i>>1]|0;b[i>>1]=j+1&65535;i=(h+(j&65535)^c[d+256>>2])&1048575;j=c[3531864]|0;h=c[j+6188+(i>>>11<<2)>>2]|0;if((h|0)==0){k=gj[c[j+8236>>2]&4095](i)|0;l=k;m=a[f]|0}else{l=a[h+i|0]|0;m=g}g=l&255;i=m&255;h=9653856+(g<<2)|0;k=c[h>>2]|0;j=b[d+(i+k<<1)>>1]|0;n=(l&255)>191;if(n){o=b[d+((c[9649760+(g<<2)>>2]|0)+i<<1)>>1]|0;p=m;q=k}else{k=c[678944+(g<<2)>>2]|0;gj[k&4095](d)|0;k=f9x(d,c[2426954]|0)|0;o=k;p=a[f]|0;q=c[h>>2]|0}h=o^j;c[d+268>>2]=0;c[d+272>>2]=0;c[d+280>>2]=0;j=h<<16>>16;c[d+284>>2]=j;c[d+276>>2]=j;c[d+264>>2]=j;b[d+(q+(p&255)<<1)>>1]=h;if(n){n=d+432|0;c[n>>2]=(c[n>>2]|0)-2;return}else{n=d+432|0;c[n>>2]=(c[n>>2]|0)-(((c[2426954]&1|0)!=0?986888:985862)>>>((c[d+444>>2]|0)>>>0)&127);return}}function gaA(f){f=f|0;var g=0,h=0,i=0,j=0;g=f+442|0;a[g]=(a[g]|0)-1&255;g=(e[f+((d[f+295|0]|0)+6<<1)>>1]|0)<<4;h=f+260|0;i=b[h>>1]|0;b[h>>1]=i+1&65535;h=(g+(i&65535)^c[f+256>>2])&1048575;i=c[3531864]|0;g=c[i+6188+(h>>>11<<2)>>2]|0;if((g|0)==0){j=gj[c[i+8236>>2]&4095](h)|0}else{j=a[g+h|0]|0}h=f+((d[f+296|0]|0)+30)|0;g=a[h]^j;c[f+268>>2]=0;c[f+272>>2]=0;c[f+280>>2]=0;j=g<<24>>24;c[f+284>>2]=j;c[f+276>>2]=j;c[f+264>>2]=j;a[h]=g;g=f+432|0;c[g>>2]=(c[g>>2]|0)-(263170>>>((c[f+444>>2]|0)>>>0)&127);return}function gaB(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;f=d+442|0;g=(a[f]|0)-1&255;a[f]=g;h=d+295|0;i=a[h]|0;j=(e[d+((i&255)+6<<1)>>1]|0)<<4;k=d+260|0;l=b[k>>1]|0;m=l+1&65535;b[k>>1]=m;n=d+256|0;o=c[n>>2]|0;p=(j+(l&65535)^o)&1048575;l=c[3531864]|0;j=c[l+6188+(p>>>11<<2)>>2]|0;if((j|0)==0){q=gj[c[l+8236>>2]&4095](p)|0;r=q;s=a[h]|0;t=a[f]|0;u=b[k>>1]|0;v=c[n>>2]|0;w=c[3531864]|0}else{r=a[j+p|0]|0;s=i;t=g;u=m;v=o;w=l}l=s&255;o=b[d+(l+15<<1)>>1]|0;a[f]=t-1&255;t=(e[d+(l+6<<1)>>1]|0)<<4;b[k>>1]=u+1&65535;k=(t+(u&65535)^v)&1048575;v=c[w+6188+(k>>>11<<2)>>2]|0;if((v|0)==0){u=gj[c[w+8236>>2]&4095](k)|0;x=u;y=a[h]|0}else{x=a[v+k|0]|0;y=s}s=((x&255)<<8|r&255)^o;c[d+268>>2]=0;c[d+272>>2]=0;c[d+280>>2]=0;o=s<<16>>16;c[d+284>>2]=o;c[d+276>>2]=o;c[d+264>>2]=o;b[d+((y&255)+15<<1)>>1]=s;s=d+432|0;c[s>>2]=(c[s>>2]|0)-(263170>>>((c[d+444>>2]|0)>>>0)&127);return}function gaC(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;g=f+452|0;a[g]=1;h=d[f+295|0]|0;c[f+448>>2]=e[f+(h+5<<1)>>1]<<4;i=f+432|0;c[i>>2]=(c[i>>2]|0)-2;i=f+442|0;a[i]=(a[i]|0)-1&255;i=e[f+(h+6<<1)>>1]<<4;h=f+260|0;j=b[h>>1]|0;b[h>>1]=j+1&65535;h=(i+(j&65535)^c[f+256>>2])&1048575;j=c[3531864]|0;i=c[j+4140+(h>>>11<<2)>>2]|0;if((i|0)==0){k=gj[c[j+8236>>2]&4095](h)|0}else{k=a[i+h|0]|0}do{if((a[f+294|0]|0)==0){h=c[f+436>>2]|0;if((h|0)==0){l=k;break}l=a[h+(k&255)|0]|0}else{l=k}}while(0);gf[c[2519504+((l&255)<<2)>>2]&2047](f);a[g]=0;return}function gaD(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=b+268|0;f=b+296|0;g=a[f]|0;do{if((c[e>>2]|0)==0){h=(g&255)+30|0;i=b;j=a[i+h|0]|0;if((j&14)>>>0>9){k=i;l=h;m=j;n=50697;break}c[e>>2]=0;c[b+280>>2]=0;o=g;p=i}else{i=b;j=(g&255)+30|0;k=i;l=j;m=a[i+j|0]|0;n=50697}}while(0);if((n|0)==50697){a[k+l|0]=m+6&255;m=d[f]|0;l=k+(m+31)|0;a[l]=((d[k+(m+30)|0]|0)>249?2:1)+(a[l]|0)&255;c[e>>2]=1;c[b+280>>2]=1;o=a[f]|0;p=b}f=p+((o&255)+30)|0;a[f]=a[f]&15;f=b+432|0;c[f>>2]=(c[f>>2]|0)-(460548>>>((c[b+444>>2]|0)>>>0)&127);return}function gaE(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=f+442|0;a[g]=(a[g]|0)-1&255;g=e[f+((d[f+295|0]|0)+6<<1)>>1]<<4;h=f+260|0;i=b[h>>1]|0;b[h>>1]=i+1&65535;h=(g+(i&65535)^c[f+256>>2])&1048575;i=c[3531864]|0;g=c[i+6188+(h>>>11<<2)>>2]|0;if((g|0)==0){j=gj[c[i+8236>>2]&4095](h)|0}else{j=a[g+h|0]|0}h=j&255;g=d[f+296|0]|0;i=f;k=a[i+(g+(c[9651808+(h<<2)>>2]|0))|0]|0;l=k&255;m=(j&255)>191;L62312:do{if(m){n=a[i+((c[9647712+(h<<2)>>2]|0)+g)|0]|0}else{j=gj[c[678944+(h<<2)>>2]&4095](f)|0;do{if((j&1048064|0)==(c[f+428>>2]|0)|(j|0)==1048575){o=j&511;if((a[f+424|0]|0)!=0&o>>>0<256){n=a[i+o|0]|0;break L62312}if(o>>>0<=255){break}n=f9w(f,o-256|0)|0;break L62312}}while(0);o=j&1048575;p=c[3531864]|0;q=c[p+44+(o>>>11<<2)>>2]|0;if((q|0)==0){n=gj[c[p+8236>>2]&4095](o)|0;break}else{n=a[q+o|0]|0;break}}}while(0);i=n&255;h=i-l|0;c[f+280>>2]=h&256;l=(n^k)&255;c[f+272>>2]=l&128&(h^i);c[f+268>>2]=(h^l)&16;l=h<<24>>24;c[f+284>>2]=l;c[f+276>>2]=l;c[f+264>>2]=l;l=f+432|0;c[l>>2]=(c[l>>2]|0)-((m?131586:723718)>>>((c[f+444>>2]|0)>>>0)&127);return}function gaF(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=d+442|0;a[f]=(a[f]|0)-1&255;f=d+295|0;g=a[f]|0;h=(e[d+((g&255)+6<<1)>>1]|0)<<4;i=d+260|0;j=b[i>>1]|0;b[i>>1]=j+1&65535;i=(h+(j&65535)^c[d+256>>2])&1048575;j=c[3531864]|0;h=c[j+6188+(i>>>11<<2)>>2]|0;if((h|0)==0){k=gj[c[j+8236>>2]&4095](i)|0;l=k;m=a[f]|0}else{l=a[h+i|0]|0;m=g}g=l&255;i=m&255;m=b[d+(i+(c[9653856+(g<<2)>>2]|0)<<1)>>1]|0;h=(l&255)>191;if(h){n=b[d+((c[9649760+(g<<2)>>2]|0)+i<<1)>>1]|0}else{i=c[678944+(g<<2)>>2]|0;gj[i&4095](d)|0;n=f9x(d,c[2426954]|0)|0}i=n&65535;g=i-(m&65535)|0;c[d+280>>2]=g&65536;l=(n^m)&65535;c[d+272>>2]=l&32768&(g^i);c[d+268>>2]=(g^l)&16;l=g<<16>>16;c[d+284>>2]=l;c[d+276>>2]=l;c[d+264>>2]=l;if(h){h=d+432|0;c[h>>2]=(c[h>>2]|0)-2;return}else{h=d+432|0;c[h>>2]=(c[h>>2]|0)-(((c[2426954]&1|0)!=0?986888:985862)>>>((c[d+444>>2]|0)>>>0)&127);return}}function gaG(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=f+442|0;a[g]=(a[g]|0)-1&255;g=e[f+((d[f+295|0]|0)+6<<1)>>1]<<4;h=f+260|0;i=b[h>>1]|0;b[h>>1]=i+1&65535;h=(g+(i&65535)^c[f+256>>2])&1048575;i=c[3531864]|0;g=c[i+6188+(h>>>11<<2)>>2]|0;if((g|0)==0){j=gj[c[i+8236>>2]&4095](h)|0}else{j=a[g+h|0]|0}h=j&255;g=d[f+296|0]|0;i=f;k=a[i+(g+(c[9651808+(h<<2)>>2]|0))|0]|0;l=k&255;m=(j&255)>191;L62345:do{if(m){n=a[i+((c[9647712+(h<<2)>>2]|0)+g)|0]|0}else{j=gj[c[678944+(h<<2)>>2]&4095](f)|0;do{if((j&1048064|0)==(c[f+428>>2]|0)|(j|0)==1048575){o=j&511;if((a[f+424|0]|0)!=0&o>>>0<256){n=a[i+o|0]|0;break L62345}if(o>>>0<=255){break}n=f9w(f,o-256|0)|0;break L62345}}while(0);o=j&1048575;p=c[3531864]|0;q=c[p+44+(o>>>11<<2)>>2]|0;if((q|0)==0){n=gj[c[p+8236>>2]&4095](o)|0;break}else{n=a[q+o|0]|0;break}}}while(0);i=l-(n&255)|0;c[f+280>>2]=i&256;h=(n^k)&255;c[f+272>>2]=h&128&(i^l);c[f+268>>2]=(i^h)&16;h=i<<24>>24;c[f+284>>2]=h;c[f+276>>2]=h;c[f+264>>2]=h;h=f+432|0;c[h>>2]=(c[h>>2]|0)-((m?131586:723718)>>>((c[f+444>>2]|0)>>>0)&127);return}function gaH(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=d+442|0;a[f]=(a[f]|0)-1&255;f=d+295|0;g=a[f]|0;h=(e[d+((g&255)+6<<1)>>1]|0)<<4;i=d+260|0;j=b[i>>1]|0;b[i>>1]=j+1&65535;i=(h+(j&65535)^c[d+256>>2])&1048575;j=c[3531864]|0;h=c[j+6188+(i>>>11<<2)>>2]|0;if((h|0)==0){k=gj[c[j+8236>>2]&4095](i)|0;l=k;m=a[f]|0}else{l=a[h+i|0]|0;m=g}g=l&255;i=m&255;m=b[d+(i+(c[9653856+(g<<2)>>2]|0)<<1)>>1]|0;h=m&65535;f=(l&255)>191;if(f){n=b[d+((c[9649760+(g<<2)>>2]|0)+i<<1)>>1]|0}else{i=c[678944+(g<<2)>>2]|0;gj[i&4095](d)|0;n=f9x(d,c[2426954]|0)|0}i=h-(n&65535)|0;c[d+280>>2]=i&65536;g=(n^m)&65535;c[d+272>>2]=g&32768&(i^h);c[d+268>>2]=(i^g)&16;g=i<<16>>16;c[d+284>>2]=g;c[d+276>>2]=g;c[d+264>>2]=g;if(f){f=d+432|0;c[f>>2]=(c[f>>2]|0)-2;return}else{f=d+432|0;c[f>>2]=(c[f>>2]|0)-(((c[2426954]&1|0)!=0?986888:985862)>>>((c[d+444>>2]|0)>>>0)&127);return}}function gaI(f){f=f|0;var g=0,h=0,i=0,j=0,k=0;g=f+442|0;a[g]=(a[g]|0)-1&255;g=(e[f+((d[f+295|0]|0)+6<<1)>>1]|0)<<4;h=f+260|0;i=b[h>>1]|0;b[h>>1]=i+1&65535;h=(g+(i&65535)^c[f+256>>2])&1048575;i=c[3531864]|0;g=c[i+6188+(h>>>11<<2)>>2]|0;if((g|0)==0){j=gj[c[i+8236>>2]&4095](h)|0}else{j=a[g+h|0]|0}h=a[f+((d[f+296|0]|0)+30)|0]|0;g=h&255;i=g-(j&255)|0;c[f+280>>2]=i&256;k=(h^j)&255;c[f+272>>2]=k&128&(i^g);c[f+268>>2]=(i^k)&16;k=i<<24>>24;c[f+284>>2]=k;c[f+276>>2]=k;c[f+264>>2]=k;k=f+432|0;c[k>>2]=(c[k>>2]|0)-(263170>>>((c[f+444>>2]|0)>>>0)&127);return}function gaJ(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;f=d+442|0;g=(a[f]|0)-1&255;a[f]=g;h=d+295|0;i=a[h]|0;j=(e[d+((i&255)+6<<1)>>1]|0)<<4;k=d+260|0;l=b[k>>1]|0;m=l+1&65535;b[k>>1]=m;n=d+256|0;o=c[n>>2]|0;p=(j+(l&65535)^o)&1048575;l=c[3531864]|0;j=c[l+6188+(p>>>11<<2)>>2]|0;if((j|0)==0){q=gj[c[l+8236>>2]&4095](p)|0;r=q;s=a[h]|0;t=a[f]|0;u=b[k>>1]|0;v=c[n>>2]|0;w=c[3531864]|0}else{r=a[j+p|0]|0;s=i;t=g;u=m;v=o;w=l}l=s&255;s=e[d+(l+15<<1)>>1]|0;a[f]=t-1&255;t=(e[d+(l+6<<1)>>1]|0)<<4;b[k>>1]=u+1&65535;k=(t+(u&65535)^v)&1048575;v=c[w+6188+(k>>>11<<2)>>2]|0;if((v|0)==0){x=gj[c[w+8236>>2]&4095](k)|0}else{x=a[v+k|0]|0}k=(x&255)<<8|r&255;r=s-k|0;c[d+280>>2]=r&65536;x=k^s;c[d+272>>2]=x&32768&(r^s);c[d+268>>2]=(r^x)&16;x=r<<16>>16;c[d+284>>2]=x;c[d+276>>2]=x;c[d+264>>2]=x;x=d+432|0;c[x>>2]=(c[x>>2]|0)-(263170>>>((c[d+444>>2]|0)>>>0)&127);return}function gaK(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;g=f+452|0;a[g]=1;h=d[f+295|0]|0;c[f+448>>2]=e[f+(h+4<<1)>>1]<<4;i=f+432|0;c[i>>2]=(c[i>>2]|0)-2;i=f+442|0;a[i]=(a[i]|0)-1&255;i=e[f+(h+6<<1)>>1]<<4;h=f+260|0;j=b[h>>1]|0;b[h>>1]=j+1&65535;h=(i+(j&65535)^c[f+256>>2])&1048575;j=c[3531864]|0;i=c[j+4140+(h>>>11<<2)>>2]|0;if((i|0)==0){k=gj[c[j+8236>>2]&4095](h)|0}else{k=a[i+h|0]|0}do{if((a[f+294|0]|0)==0){h=c[f+436>>2]|0;if((h|0)==0){l=k;break}l=a[h+(k&255)|0]|0}else{l=k}}while(0);gf[c[2519504+((l&255)<<2)>>2]&2047](f);a[g]=0;return}function gaL(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=b+268|0;f=b+296|0;g=a[f]|0;do{if((c[e>>2]|0)==0){h=(g&255)+30|0;i=b;j=a[i+h|0]|0;if((j&14)>>>0>9){k=i;l=h;m=j;n=50773;break}c[e>>2]=0;c[b+280>>2]=0;o=g;p=i}else{i=b;j=(g&255)+30|0;k=i;l=j;m=a[i+j|0]|0;n=50773}}while(0);if((n|0)==50773){a[k+l|0]=m-6&255;m=d[f]|0;l=k+(m+31)|0;a[l]=((d[k+(m+30)|0]|0)<6?-2:-1)+(a[l]|0)&255;c[e>>2]=1;c[b+280>>2]=1;o=a[f]|0;p=b}f=p+((o&255)+30)|0;a[f]=a[f]&15;f=b+432|0;c[f>>2]=(c[f>>2]|0)-(460548>>>((c[b+444>>2]|0)>>>0)&127);return}function gaM(a){a=a|0;var e=0,f=0,g=0,h=0;e=a+((d[a+295|0]|0)+15<<1)|0;f=b[e>>1]|0;g=f&65535;h=g+1|0;c[a+272>>2]=f<<16>>16==32767;c[a+268>>2]=(h^g)&16;g=h&65535;h=g<<16>>16;c[a+284>>2]=h;c[a+276>>2]=h;c[a+264>>2]=h;b[e>>1]=g;g=a+432|0;c[g>>2]=(c[g>>2]|0)-2;return}function gaN(a){a=a|0;var e=0,f=0,g=0,h=0;e=a+((d[a+295|0]|0)+14<<1)|0;f=b[e>>1]|0;g=f&65535;h=g+1|0;c[a+272>>2]=f<<16>>16==32767;c[a+268>>2]=(h^g)&16;g=h&65535;h=g<<16>>16;c[a+284>>2]=h;c[a+276>>2]=h;c[a+264>>2]=h;b[e>>1]=g;g=a+432|0;c[g>>2]=(c[g>>2]|0)-2;return}function gaO(a){a=a|0;var e=0,f=0,g=0,h=0;e=a+((d[a+295|0]|0)+13<<1)|0;f=b[e>>1]|0;g=f&65535;h=g+1|0;c[a+272>>2]=f<<16>>16==32767;c[a+268>>2]=(h^g)&16;g=h&65535;h=g<<16>>16;c[a+284>>2]=h;c[a+276>>2]=h;c[a+264>>2]=h;b[e>>1]=g;g=a+432|0;c[g>>2]=(c[g>>2]|0)-2;return}function gaP(a){a=a|0;var e=0,f=0,g=0,h=0;e=a+((d[a+295|0]|0)+12<<1)|0;f=b[e>>1]|0;g=f&65535;h=g+1|0;c[a+272>>2]=f<<16>>16==32767;c[a+268>>2]=(h^g)&16;g=h&65535;h=g<<16>>16;c[a+284>>2]=h;c[a+276>>2]=h;c[a+264>>2]=h;b[e>>1]=g;g=a+432|0;c[g>>2]=(c[g>>2]|0)-2;return}function gaQ(a){a=a|0;var e=0,f=0,g=0,h=0;e=a+((d[a+295|0]|0)+11<<1)|0;f=b[e>>1]|0;g=f&65535;h=g+1|0;c[a+272>>2]=f<<16>>16==32767;c[a+268>>2]=(h^g)&16;g=h&65535;h=g<<16>>16;c[a+284>>2]=h;c[a+276>>2]=h;c[a+264>>2]=h;b[e>>1]=g;g=a+432|0;c[g>>2]=(c[g>>2]|0)-2;return}function gaR(a){a=a|0;var e=0,f=0,g=0,h=0;e=a+((d[a+295|0]|0)+10<<1)|0;f=b[e>>1]|0;g=f&65535;h=g+1|0;c[a+272>>2]=f<<16>>16==32767;c[a+268>>2]=(h^g)&16;g=h&65535;h=g<<16>>16;c[a+284>>2]=h;c[a+276>>2]=h;c[a+264>>2]=h;b[e>>1]=g;g=a+432|0;c[g>>2]=(c[g>>2]|0)-2;return}function gaS(a){a=a|0;var e=0,f=0,g=0,h=0;e=a+((d[a+295|0]|0)+9<<1)|0;f=b[e>>1]|0;g=f&65535;h=g+1|0;c[a+272>>2]=f<<16>>16==32767;c[a+268>>2]=(h^g)&16;g=h&65535;h=g<<16>>16;c[a+284>>2]=h;c[a+276>>2]=h;c[a+264>>2]=h;b[e>>1]=g;g=a+432|0;c[g>>2]=(c[g>>2]|0)-2;return}function gaT(a){a=a|0;var e=0,f=0,g=0,h=0;e=a+((d[a+295|0]|0)+8<<1)|0;f=b[e>>1]|0;g=f&65535;h=g+1|0;c[a+272>>2]=f<<16>>16==32767;c[a+268>>2]=(h^g)&16;g=h&65535;h=g<<16>>16;c[a+284>>2]=h;c[a+276>>2]=h;c[a+264>>2]=h;b[e>>1]=g;g=a+432|0;c[g>>2]=(c[g>>2]|0)-2;return}function gaU(a){a=a|0;var e=0,f=0,g=0,h=0;e=a+((d[a+295|0]|0)+15<<1)|0;f=b[e>>1]|0;g=f&65535;h=g-1|0;c[a+272>>2]=f<<16>>16==-32768;c[a+268>>2]=(h^g)&16;g=h&65535;h=g<<16>>16;c[a+284>>2]=h;c[a+276>>2]=h;c[a+264>>2]=h;b[e>>1]=g;g=a+432|0;c[g>>2]=(c[g>>2]|0)-2;return}function gaV(a){a=a|0;var e=0,f=0,g=0,h=0;e=a+((d[a+295|0]|0)+14<<1)|0;f=b[e>>1]|0;g=f&65535;h=g-1|0;c[a+272>>2]=f<<16>>16==-32768;c[a+268>>2]=(h^g)&16;g=h&65535;h=g<<16>>16;c[a+284>>2]=h;c[a+276>>2]=h;c[a+264>>2]=h;b[e>>1]=g;g=a+432|0;c[g>>2]=(c[g>>2]|0)-2;return}function gaW(a){a=a|0;var e=0,f=0,g=0,h=0;e=a+((d[a+295|0]|0)+13<<1)|0;f=b[e>>1]|0;g=f&65535;h=g-1|0;c[a+272>>2]=f<<16>>16==-32768;c[a+268>>2]=(h^g)&16;g=h&65535;h=g<<16>>16;c[a+284>>2]=h;c[a+276>>2]=h;c[a+264>>2]=h;b[e>>1]=g;g=a+432|0;c[g>>2]=(c[g>>2]|0)-2;return}function gaX(a){a=a|0;var e=0,f=0,g=0,h=0;e=a+((d[a+295|0]|0)+12<<1)|0;f=b[e>>1]|0;g=f&65535;h=g-1|0;c[a+272>>2]=f<<16>>16==-32768;c[a+268>>2]=(h^g)&16;g=h&65535;h=g<<16>>16;c[a+284>>2]=h;c[a+276>>2]=h;c[a+264>>2]=h;b[e>>1]=g;g=a+432|0;c[g>>2]=(c[g>>2]|0)-2;return}function gaY(a){a=a|0;var e=0,f=0,g=0,h=0;e=a+((d[a+295|0]|0)+11<<1)|0;f=b[e>>1]|0;g=f&65535;h=g-1|0;c[a+272>>2]=f<<16>>16==-32768;c[a+268>>2]=(h^g)&16;g=h&65535;h=g<<16>>16;c[a+284>>2]=h;c[a+276>>2]=h;c[a+264>>2]=h;b[e>>1]=g;g=a+432|0;c[g>>2]=(c[g>>2]|0)-2;return}function gaZ(a){a=a|0;var e=0,f=0,g=0,h=0;e=a+((d[a+295|0]|0)+10<<1)|0;f=b[e>>1]|0;g=f&65535;h=g-1|0;c[a+272>>2]=f<<16>>16==-32768;c[a+268>>2]=(h^g)&16;g=h&65535;h=g<<16>>16;c[a+284>>2]=h;c[a+276>>2]=h;c[a+264>>2]=h;b[e>>1]=g;g=a+432|0;c[g>>2]=(c[g>>2]|0)-2;return}function ga_(a){a=a|0;var e=0,f=0,g=0,h=0;e=a+((d[a+295|0]|0)+9<<1)|0;f=b[e>>1]|0;g=f&65535;h=g-1|0;c[a+272>>2]=f<<16>>16==-32768;c[a+268>>2]=(h^g)&16;g=h&65535;h=g<<16>>16;c[a+284>>2]=h;c[a+276>>2]=h;c[a+264>>2]=h;b[e>>1]=g;g=a+432|0;c[g>>2]=(c[g>>2]|0)-2;return}function ga$(a){a=a|0;var e=0,f=0,g=0,h=0;e=a+((d[a+295|0]|0)+8<<1)|0;f=b[e>>1]|0;g=f&65535;h=g-1|0;c[a+272>>2]=f<<16>>16==-32768;c[a+268>>2]=(h^g)&16;g=h&65535;h=g<<16>>16;c[a+284>>2]=h;c[a+276>>2]=h;c[a+264>>2]=h;b[e>>1]=g;g=a+432|0;c[g>>2]=(c[g>>2]|0)-2;return}function ga0(a){a=a|0;var f=0,g=0;f=a+295|0;g=a+((d[f]|0)+11<<1)|0;b[g>>1]=(b[g>>1]|0)-2&65535;g=d[f]|0;f9z(a,((e[a+(g+5<<1)>>1]|0)<<4)+(e[a+(g+11<<1)>>1]|0)|0,b[a+(g+15<<1)>>1]|0);g=a+432|0;c[g>>2]=(c[g>>2]|0)-(788483>>>((c[a+444>>2]|0)>>>0)&127);return}function ga1(a){a=a|0;var f=0,g=0;f=a+295|0;g=a+((d[f]|0)+11<<1)|0;b[g>>1]=(b[g>>1]|0)-2&65535;g=d[f]|0;f9z(a,((e[a+(g+5<<1)>>1]|0)<<4)+(e[a+(g+11<<1)>>1]|0)|0,b[a+(g+14<<1)>>1]|0);g=a+432|0;c[g>>2]=(c[g>>2]|0)-(788483>>>((c[a+444>>2]|0)>>>0)&127);return}function ga2(a){a=a|0;var f=0,g=0;f=a+295|0;g=a+((d[f]|0)+11<<1)|0;b[g>>1]=(b[g>>1]|0)-2&65535;g=d[f]|0;f9z(a,((e[a+(g+5<<1)>>1]|0)<<4)+(e[a+(g+11<<1)>>1]|0)|0,b[a+(g+13<<1)>>1]|0);g=a+432|0;c[g>>2]=(c[g>>2]|0)-(788483>>>((c[a+444>>2]|0)>>>0)&127);return}function ga3(a){a=a|0;var f=0,g=0;f=a+295|0;g=a+((d[f]|0)+11<<1)|0;b[g>>1]=(b[g>>1]|0)-2&65535;g=d[f]|0;f9z(a,((e[a+(g+5<<1)>>1]|0)<<4)+(e[a+(g+11<<1)>>1]|0)|0,b[a+(g+12<<1)>>1]|0);g=a+432|0;c[g>>2]=(c[g>>2]|0)-(788483>>>((c[a+444>>2]|0)>>>0)&127);return}function ga4(a){a=a|0;var f=0,g=0;f=a+295|0;g=a+((d[f]|0)+11<<1)|0;b[g>>1]=(b[g>>1]|0)-2&65535;g=d[f]|0;f=b[a+(g+11<<1)>>1]|0;f9z(a,((e[a+(g+5<<1)>>1]|0)<<4)+(f&65535)|0,f);f=a+432|0;c[f>>2]=(c[f>>2]|0)-(788483>>>((c[a+444>>2]|0)>>>0)&127);return}function ga5(a){a=a|0;var f=0,g=0;f=a+295|0;g=a+((d[f]|0)+11<<1)|0;b[g>>1]=(b[g>>1]|0)-2&65535;g=d[f]|0;f9z(a,((e[a+(g+5<<1)>>1]|0)<<4)+(e[a+(g+11<<1)>>1]|0)|0,b[a+(g+10<<1)>>1]|0);g=a+432|0;c[g>>2]=(c[g>>2]|0)-(788483>>>((c[a+444>>2]|0)>>>0)&127);return}function ga6(a){a=a|0;var f=0,g=0;f=a+295|0;g=a+((d[f]|0)+11<<1)|0;b[g>>1]=(b[g>>1]|0)-2&65535;g=d[f]|0;f9z(a,((e[a+(g+5<<1)>>1]|0)<<4)+(e[a+(g+11<<1)>>1]|0)|0,b[a+(g+9<<1)>>1]|0);g=a+432|0;c[g>>2]=(c[g>>2]|0)-(788483>>>((c[a+444>>2]|0)>>>0)&127);return}function ga7(a){a=a|0;var f=0,g=0;f=a+295|0;g=a+((d[f]|0)+11<<1)|0;b[g>>1]=(b[g>>1]|0)-2&65535;g=d[f]|0;f9z(a,((e[a+(g+5<<1)>>1]|0)<<4)+(e[a+(g+11<<1)>>1]|0)|0,b[a+(g+8<<1)>>1]|0);g=a+432|0;c[g>>2]=(c[g>>2]|0)-(788483>>>((c[a+444>>2]|0)>>>0)&127);return}function ga8(a){a=a|0;var f=0,g=0,h=0;f=a+295|0;g=a+((d[f]|0)+11<<1)|0;b[g>>1]=(b[g>>1]|0)+2&65535;g=d[f]|0;h=f9x(a,((e[a+(g+11<<1)>>1]|0)+65534&65535)+((e[a+(g+5<<1)>>1]|0)<<4)|0)|0;b[a+((d[f]|0)+15<<1)>>1]=h;h=a+432|0;c[h>>2]=(c[h>>2]|0)-(788485>>>((c[a+444>>2]|0)>>>0)&127);return}function ga9(a){a=a|0;var f=0,g=0,h=0;f=a+295|0;g=a+((d[f]|0)+11<<1)|0;b[g>>1]=(b[g>>1]|0)+2&65535;g=d[f]|0;h=f9x(a,((e[a+(g+11<<1)>>1]|0)+65534&65535)+((e[a+(g+5<<1)>>1]|0)<<4)|0)|0;b[a+((d[f]|0)+14<<1)>>1]=h;h=a+432|0;c[h>>2]=(c[h>>2]|0)-(788485>>>((c[a+444>>2]|0)>>>0)&127);return}function gba(a){a=a|0;var f=0,g=0,h=0;f=a+295|0;g=a+((d[f]|0)+11<<1)|0;b[g>>1]=(b[g>>1]|0)+2&65535;g=d[f]|0;h=f9x(a,((e[a+(g+11<<1)>>1]|0)+65534&65535)+((e[a+(g+5<<1)>>1]|0)<<4)|0)|0;b[a+((d[f]|0)+13<<1)>>1]=h;h=a+432|0;c[h>>2]=(c[h>>2]|0)-(788485>>>((c[a+444>>2]|0)>>>0)&127);return}function gbb(a){a=a|0;var f=0,g=0,h=0;f=a+295|0;g=a+((d[f]|0)+11<<1)|0;b[g>>1]=(b[g>>1]|0)+2&65535;g=d[f]|0;h=f9x(a,((e[a+(g+11<<1)>>1]|0)+65534&65535)+((e[a+(g+5<<1)>>1]|0)<<4)|0)|0;b[a+((d[f]|0)+12<<1)>>1]=h;h=a+432|0;c[h>>2]=(c[h>>2]|0)-(788485>>>((c[a+444>>2]|0)>>>0)&127);return}function gbc(a){a=a|0;var f=0,g=0,h=0;f=a+295|0;g=a+((d[f]|0)+11<<1)|0;b[g>>1]=(b[g>>1]|0)+2&65535;g=d[f]|0;h=f9x(a,((e[a+(g+11<<1)>>1]|0)+65534&65535)+((e[a+(g+5<<1)>>1]|0)<<4)|0)|0;b[a+((d[f]|0)+11<<1)>>1]=h;h=a+432|0;c[h>>2]=(c[h>>2]|0)-(788485>>>((c[a+444>>2]|0)>>>0)&127);return}function gbd(a){a=a|0;var f=0,g=0,h=0;f=a+295|0;g=a+((d[f]|0)+11<<1)|0;b[g>>1]=(b[g>>1]|0)+2&65535;g=d[f]|0;h=f9x(a,((e[a+(g+11<<1)>>1]|0)+65534&65535)+((e[a+(g+5<<1)>>1]|0)<<4)|0)|0;b[a+((d[f]|0)+10<<1)>>1]=h;h=a+432|0;c[h>>2]=(c[h>>2]|0)-(788485>>>((c[a+444>>2]|0)>>>0)&127);return}function gbe(a){a=a|0;var f=0,g=0,h=0;f=a+295|0;g=a+((d[f]|0)+11<<1)|0;b[g>>1]=(b[g>>1]|0)+2&65535;g=d[f]|0;h=f9x(a,((e[a+(g+11<<1)>>1]|0)+65534&65535)+((e[a+(g+5<<1)>>1]|0)<<4)|0)|0;b[a+((d[f]|0)+9<<1)>>1]=h;h=a+432|0;c[h>>2]=(c[h>>2]|0)-(788485>>>((c[a+444>>2]|0)>>>0)&127);return}function gbf(a){a=a|0;var f=0,g=0,h=0;f=a+295|0;g=a+((d[f]|0)+11<<1)|0;b[g>>1]=(b[g>>1]|0)+2&65535;g=d[f]|0;h=f9x(a,((e[a+(g+11<<1)>>1]|0)+65534&65535)+((e[a+(g+5<<1)>>1]|0)<<4)|0)|0;b[a+((d[f]|0)+8<<1)>>1]=h;h=a+432|0;c[h>>2]=(c[h>>2]|0)-(788485>>>((c[a+444>>2]|0)>>>0)&127);return}function gbg(a){a=a|0;var f=0,g=0,h=0;f=a+295|0;g=a+((d[f]|0)+11<<1)|0;h=b[g>>1]|0;b[g>>1]=h-2&65535;g=d[f]|0;f9z(a,((e[a+(g+5<<1)>>1]|0)<<4)+(e[a+(g+11<<1)>>1]|0)|0,b[a+(g+15<<1)>>1]|0);g=a+((d[f]|0)+11<<1)|0;b[g>>1]=(b[g>>1]|0)-2&65535;g=d[f]|0;f9z(a,((e[a+(g+5<<1)>>1]|0)<<4)+(e[a+(g+11<<1)>>1]|0)|0,b[a+(g+14<<1)>>1]|0);g=a+((d[f]|0)+11<<1)|0;b[g>>1]=(b[g>>1]|0)-2&65535;g=d[f]|0;f9z(a,((e[a+(g+5<<1)>>1]|0)<<4)+(e[a+(g+11<<1)>>1]|0)|0,b[a+(g+13<<1)>>1]|0);g=a+((d[f]|0)+11<<1)|0;b[g>>1]=(b[g>>1]|0)-2&65535;g=d[f]|0;f9z(a,((e[a+(g+5<<1)>>1]|0)<<4)+(e[a+(g+11<<1)>>1]|0)|0,b[a+(g+12<<1)>>1]|0);g=a+((d[f]|0)+11<<1)|0;b[g>>1]=(b[g>>1]|0)-2&65535;g=d[f]|0;f9z(a,((e[a+(g+5<<1)>>1]|0)<<4)+(e[a+(g+11<<1)>>1]|0)|0,h);h=a+((d[f]|0)+11<<1)|0;b[h>>1]=(b[h>>1]|0)-2&65535;h=d[f]|0;f9z(a,((e[a+(h+5<<1)>>1]|0)<<4)+(e[a+(h+11<<1)>>1]|0)|0,b[a+(h+10<<1)>>1]|0);h=a+((d[f]|0)+11<<1)|0;b[h>>1]=(b[h>>1]|0)-2&65535;h=d[f]|0;f9z(a,((e[a+(h+5<<1)>>1]|0)<<4)+(e[a+(h+11<<1)>>1]|0)|0,b[a+(h+9<<1)>>1]|0);h=a+((d[f]|0)+11<<1)|0;b[h>>1]=(b[h>>1]|0)-2&65535;h=d[f]|0;f9z(a,((e[a+(h+5<<1)>>1]|0)<<4)+(e[a+(h+11<<1)>>1]|0)|0,b[a+(h+8<<1)>>1]|0);h=a+432|0;c[h>>2]=(c[h>>2]|0)-(4399892>>>((c[a+444>>2]|0)>>>0)&127);return}function gbh(a){a=a|0;var f=0,g=0,h=0;f=a+295|0;g=a+((d[f]|0)+11<<1)|0;b[g>>1]=(b[g>>1]|0)+2&65535;g=d[f]|0;h=f9x(a,((e[a+(g+11<<1)>>1]|0)+65534&65535)+((e[a+(g+5<<1)>>1]|0)<<4)|0)|0;b[a+((d[f]|0)+8<<1)>>1]=h;h=a+((d[f]|0)+11<<1)|0;b[h>>1]=(b[h>>1]|0)+2&65535;h=d[f]|0;g=f9x(a,((e[a+(h+11<<1)>>1]|0)+65534&65535)+((e[a+(h+5<<1)>>1]|0)<<4)|0)|0;b[a+((d[f]|0)+9<<1)>>1]=g;g=a+((d[f]|0)+11<<1)|0;b[g>>1]=(b[g>>1]|0)+2&65535;g=d[f]|0;h=f9x(a,((e[a+(g+11<<1)>>1]|0)+65534&65535)+((e[a+(g+5<<1)>>1]|0)<<4)|0)|0;b[a+((d[f]|0)+10<<1)>>1]=h;h=a+((d[f]|0)+11<<1)|0;b[h>>1]=(b[h>>1]|0)+2&65535;h=d[f]|0;f9x(a,((e[a+(h+11<<1)>>1]|0)+65534&65535)+((e[a+(h+5<<1)>>1]|0)<<4)|0)|0;h=a+((d[f]|0)+11<<1)|0;b[h>>1]=(b[h>>1]|0)+2&65535;h=d[f]|0;g=f9x(a,((e[a+(h+11<<1)>>1]|0)+65534&65535)+((e[a+(h+5<<1)>>1]|0)<<4)|0)|0;b[a+((d[f]|0)+12<<1)>>1]=g;g=a+((d[f]|0)+11<<1)|0;b[g>>1]=(b[g>>1]|0)+2&65535;g=d[f]|0;h=f9x(a,((e[a+(g+11<<1)>>1]|0)+65534&65535)+((e[a+(g+5<<1)>>1]|0)<<4)|0)|0;b[a+((d[f]|0)+13<<1)>>1]=h;h=a+((d[f]|0)+11<<1)|0;b[h>>1]=(b[h>>1]|0)+2&65535;h=d[f]|0;g=f9x(a,((e[a+(h+11<<1)>>1]|0)+65534&65535)+((e[a+(h+5<<1)>>1]|0)<<4)|0)|0;b[a+((d[f]|0)+14<<1)>>1]=g;g=a+((d[f]|0)+11<<1)|0;b[g>>1]=(b[g>>1]|0)+2&65535;g=d[f]|0;h=f9x(a,((e[a+(g+11<<1)>>1]|0)+65534&65535)+((e[a+(g+5<<1)>>1]|0)<<4)|0)|0;b[a+((d[f]|0)+15<<1)>>1]=h;h=a+432|0;c[h>>2]=(c[h>>2]|0)-(4926230>>>((c[a+444>>2]|0)>>>0)&127);return}function gbi(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=f+442|0;a[g]=(a[g]|0)-1&255;g=f+295|0;h=(e[f+((d[g]|0)+6<<1)>>1]|0)<<4;i=f+260|0;j=b[i>>1]|0;b[i>>1]=j+1&65535;i=(h+(j&65535)^c[f+256>>2])&1048575;j=c[3531864]|0;h=c[j+6188+(i>>>11<<2)>>2]|0;if((h|0)==0){k=gj[c[j+8236>>2]&4095](i)|0}else{k=a[h+i|0]|0}i=k&255;if((k&255)>191){l=b[f+((d[g]|0)+(c[9649760+(i<<2)>>2]|0)<<1)>>1]|0}else{k=c[678944+(i<<2)>>2]|0;gj[k&4095](f)|0;l=f9x(f,c[2426954]|0)|0}k=c[2426954]|0;h=f9x(f,k+2&65535|k&983040)|0;k=b[f+((d[g]|0)+(c[9653856+(i<<2)>>2]|0)<<1)>>1]|0;if(!((k&65535)<(l&65535)|(k&65535)>(h&65535))){m=f+432|0;n=c[m>>2]|0;o=n-20|0;c[m>>2]=o;return}gd0(f,5,0);m=f+432|0;n=c[m>>2]|0;o=n-20|0;c[m>>2]=o;return}function gbj(f){f=f|0;var g=0,h=0,i=0,j=0;g=f+442|0;a[g]=(a[g]|0)-1&255;g=(e[f+((d[f+295|0]|0)+6<<1)>>1]|0)<<4;h=f+260|0;i=b[h>>1]|0;b[h>>1]=i+1&65535;h=(g+(i&65535)^c[f+256>>2])&1048575;i=c[3531864]|0;g=c[i+6188+(h>>>11<<2)>>2]|0;if((g|0)==0){j=gj[c[i+8236>>2]&4095](h)|0}else{j=a[g+h|0]|0}gd0(f,j&255,131072);j=f+432|0;c[j>>2]=(c[j>>2]|0)-(3289624>>>((c[f+444>>2]|0)>>>0)&127);return}function gbk(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;g=f+442|0;a[g]=(a[g]|0)-1&255;h=f+295|0;i=(e[f+((d[h]|0)+6<<1)>>1]|0)<<4;j=f+260|0;k=b[j>>1]|0;b[j>>1]=k+1&65535;l=f+256|0;m=(i+(k&65535)^c[l>>2])&1048575;k=c[3531864]|0;i=c[k+4140+(m>>>11<<2)>>2]|0;if((i|0)==0){n=gj[c[k+8236>>2]&4095](m)|0}else{n=a[i+m|0]|0}m=f+294|0;i=a[m]|0;do{if(i<<24>>24==0){k=c[f+436>>2]|0;if((k|0)==0){o=n;break}o=a[k+(n&255)|0]|0}else{o=n}}while(0);n=o&255;o=d[h]|0;k=b[f+(o+14<<1)>>1]|0;if((n|0)==46){a[f+452|0]=1;p=f+(o+6<<1)|0;c[f+448>>2]=(e[p>>1]|0)<<4;a[g]=(a[g]|0)-1&255;q=(e[p>>1]|0)<<4;p=b[j>>1]|0;b[j>>1]=p+1&65535;r=(q+(p&65535)^c[l>>2])&1048575;p=c[3531864]|0;q=c[p+4140+(r>>>11<<2)>>2]|0;if((q|0)==0){s=gj[c[p+8236>>2]&4095](r)|0;t=s;u=a[m]|0}else{t=a[q+r|0]|0;u=i}do{if(u<<24>>24==0){r=c[f+436>>2]|0;if((r|0)==0){v=t;break}v=a[r+(t&255)|0]|0}else{v=t}}while(0);t=f+432|0;c[t>>2]=(c[t>>2]|0)-2;w=v&255}else if((n|0)==38){a[f+452|0]=1;c[f+448>>2]=(e[f+(o+7<<1)>>1]|0)<<4;a[g]=(a[g]|0)-1&255;v=(e[f+(o+6<<1)>>1]|0)<<4;t=b[j>>1]|0;b[j>>1]=t+1&65535;u=(v+(t&65535)^c[l>>2])&1048575;t=c[3531864]|0;v=c[t+4140+(u>>>11<<2)>>2]|0;if((v|0)==0){r=gj[c[t+8236>>2]&4095](u)|0;x=r;y=a[m]|0}else{x=a[v+u|0]|0;y=i}do{if(y<<24>>24==0){u=c[f+436>>2]|0;if((u|0)==0){z=x;break}z=a[u+(x&255)|0]|0}else{z=x}}while(0);x=f+432|0;c[x>>2]=(c[x>>2]|0)-2;w=z&255}else if((n|0)==54){a[f+452|0]=1;c[f+448>>2]=(e[f+(o+5<<1)>>1]|0)<<4;a[g]=(a[g]|0)-1&255;z=(e[f+(o+6<<1)>>1]|0)<<4;x=b[j>>1]|0;b[j>>1]=x+1&65535;y=(z+(x&65535)^c[l>>2])&1048575;x=c[3531864]|0;z=c[x+4140+(y>>>11<<2)>>2]|0;if((z|0)==0){u=gj[c[x+8236>>2]&4095](y)|0;A=u;B=a[m]|0}else{A=a[z+y|0]|0;B=i}do{if(B<<24>>24==0){y=c[f+436>>2]|0;if((y|0)==0){C=A;break}C=a[y+(A&255)|0]|0}else{C=A}}while(0);A=f+432|0;c[A>>2]=(c[A>>2]|0)-2;w=C&255}else if((n|0)==62){a[f+452|0]=1;c[f+448>>2]=(e[f+(o+4<<1)>>1]|0)<<4;a[g]=(a[g]|0)-1&255;g=(e[f+(o+6<<1)>>1]|0)<<4;o=b[j>>1]|0;b[j>>1]=o+1&65535;j=(g+(o&65535)^c[l>>2])&1048575;l=c[3531864]|0;o=c[l+4140+(j>>>11<<2)>>2]|0;if((o|0)==0){g=gj[c[l+8236>>2]&4095](j)|0;D=g;E=a[m]|0}else{D=a[o+j|0]|0;E=i}do{if(E<<24>>24==0){i=c[f+436>>2]|0;if((i|0)==0){F=D;break}F=a[i+(D&255)|0]|0}else{F=D}}while(0);D=f+432|0;c[D>>2]=(c[D>>2]|0)-2;w=F&255}else{w=n}switch(w|0){case 166:{n=f+432|0;c[n>>2]=(c[n>>2]|0)-2;L62505:do{if(k<<16>>16==0){G=0}else{n=f+280|0;F=k;while(1){gcl(f);D=F-1&65535;if(D<<16>>16==0){G=0;break L62505}if((c[n>>2]|0)==0){F=D}else{G=D;break}}}}while(0);b[f+((d[h]|0)+14<<1)>>1]=G;H=f+452|0;a[H]=0;return};case 164:{G=f+432|0;c[G>>2]=(c[G>>2]|0)-2;L62513:do{if(k<<16>>16==0){I=0}else{G=f+280|0;F=k;while(1){gcj(f);n=F-1&65535;if(n<<16>>16==0){I=0;break L62513}if((c[G>>2]|0)==0){F=n}else{I=n;break}}}}while(0);b[f+((d[h]|0)+14<<1)>>1]=I;H=f+452|0;a[H]=0;return};case 173:{I=f+432|0;c[I>>2]=(c[I>>2]|0)-2;L62521:do{if(k<<16>>16==0){J=0}else{I=f+280|0;F=k;while(1){gcs(f);G=F-1&65535;if(G<<16>>16==0){J=0;break L62521}if((c[I>>2]|0)==0){F=G}else{J=G;break}}}}while(0);b[f+((d[h]|0)+14<<1)>>1]=J;H=f+452|0;a[H]=0;return};case 174:{J=f+432|0;c[J>>2]=(c[J>>2]|0)-2;L62531:do{if(k<<16>>16==0){K=0}else{J=f+280|0;F=k;while(1){gct(f);I=F-1&65535;if(I<<16>>16==0){K=0;break L62531}if((c[J>>2]|0)==0){F=I}else{K=I;break}}}}while(0);b[f+((d[h]|0)+14<<1)>>1]=K;H=f+452|0;a[H]=0;return};case 172:{K=f+432|0;c[K>>2]=(c[K>>2]|0)-2;L62539:do{if(k<<16>>16==0){L=0}else{K=f+280|0;F=k;while(1){gcr(f);J=F-1&65535;if(J<<16>>16==0){L=0;break L62539}if((c[K>>2]|0)==0){F=J}else{L=J;break}}}}while(0);b[f+((d[h]|0)+14<<1)>>1]=L;H=f+452|0;a[H]=0;return};case 108:{L=f+432|0;c[L>>2]=(c[L>>2]|0)-2;L62547:do{if(k<<16>>16==0){M=0}else{L=f+280|0;F=k;while(1){gbr(f);K=F-1&65535;if(K<<16>>16==0){M=0;break L62547}if((c[L>>2]|0)==0){F=K}else{M=K;break}}}}while(0);b[f+((d[h]|0)+14<<1)>>1]=M;H=f+452|0;a[H]=0;return};case 111:{M=f+432|0;c[M>>2]=(c[M>>2]|0)-2;L62555:do{if(k<<16>>16==0){N=0}else{M=f+280|0;F=k;while(1){gbu(f);L=F-1&65535;if(L<<16>>16==0){N=0;break L62555}if((c[M>>2]|0)==0){F=L}else{N=L;break}}}}while(0);b[f+((d[h]|0)+14<<1)>>1]=N;H=f+452|0;a[H]=0;return};case 170:{N=f+432|0;c[N>>2]=(c[N>>2]|0)-2;L62563:do{if(k<<16>>16==0){O=0}else{N=f+280|0;F=k;while(1){gcp(f);M=F-1&65535;if(M<<16>>16==0){O=0;break L62563}if((c[N>>2]|0)==0){F=M}else{O=M;break}}}}while(0);b[f+((d[h]|0)+14<<1)>>1]=O;H=f+452|0;a[H]=0;return};case 175:{O=f+432|0;c[O>>2]=(c[O>>2]|0)-2;L62571:do{if(k<<16>>16==0){P=0;Q=a[h]|0}else{F=f+280|0;N=f+272|0;M=f+268|0;L=f+284|0;K=f+276|0;J=f+264|0;I=f+293|0;G=f+444|0;n=k;D=a[h]|0;while(1){E=D&255;i=f9x(f,((e[f+(E+7<<1)>>1]|0)<<4)+(e[f+(E+8<<1)>>1]|0)|0)|0;E=d[h]|0;j=b[f+(E+15<<1)>>1]|0;o=j&65535;m=o-(i&65535)|0;c[F>>2]=m&65536;g=(j^i)&65535;c[N>>2]=g&32768&(m^o);c[M>>2]=(m^g)&16;g=m<<16>>16;c[L>>2]=g;c[K>>2]=g;c[J>>2]=g;g=f+(E+8<<1)|0;b[g>>1]=((d[I]|0)*-4&65535|2)+(b[g>>1]|0)&65535;g=a[h]|0;c[O>>2]=(c[O>>2]|0)-(((b[f+((g&255)+8<<1)>>1]&1)!=0?526341:525315)>>>((c[G>>2]|0)>>>0)&127);E=n-1&65535;if(E<<16>>16==0){P=0;Q=g;break L62571}if((c[F>>2]|0)==0){n=E;D=g}else{P=E;Q=g;break}}}}while(0);b[f+((Q&255)+14<<1)>>1]=P;H=f+452|0;a[H]=0;return};case 165:{P=f+432|0;c[P>>2]=(c[P>>2]|0)-2;L62580:do{if(k<<16>>16==0){R=0}else{P=f+280|0;Q=k;while(1){gck(f);O=Q-1&65535;if(O<<16>>16==0){R=0;break L62580}if((c[P>>2]|0)==0){Q=O}else{R=O;break}}}}while(0);b[f+((d[h]|0)+14<<1)>>1]=R;H=f+452|0;a[H]=0;return};case 167:{R=f+432|0;c[R>>2]=(c[R>>2]|0)-2;L62588:do{if(k<<16>>16==0){S=0}else{R=f+280|0;Q=k;while(1){gcm(f);P=Q-1&65535;if(P<<16>>16==0){S=0;break L62588}if((c[R>>2]|0)==0){Q=P}else{S=P;break}}}}while(0);b[f+((d[h]|0)+14<<1)>>1]=S;H=f+452|0;a[H]=0;return};case 109:{S=f+432|0;c[S>>2]=(c[S>>2]|0)-2;L62596:do{if(k<<16>>16==0){T=0}else{Q=f+280|0;R=f+293|0;P=f+444|0;O=k;while(1){D=d[h]|0;n=((e[f+(D+7<<1)>>1]|0)<<4)+(e[f+(D+8<<1)>>1]|0)|0;F=(gj[c[(c[3531864]|0)+8244>>2]&4095](b[f+(D+13<<1)>>1]&255)|0)&255;f9z(f,n,((gj[c[(c[3531864]|0)+8244>>2]&4095]((e[f+((d[h]|0)+13<<1)>>1]|0)+1&65791)|0)&255)<<8|F);F=f+((d[h]|0)+8<<1)|0;b[F>>1]=((d[R]|0)*-4&65535|2)+(b[F>>1]|0)&65535;c[S>>2]=(c[S>>2]|0)-(1182216>>>((c[P>>2]|0)>>>0)&127);F=O-1&65535;if(F<<16>>16==0){T=0;break L62596}if((c[Q>>2]|0)==0){O=F}else{T=F;break}}}}while(0);b[f+((d[h]|0)+14<<1)>>1]=T;H=f+452|0;a[H]=0;return};case 171:{T=f+432|0;c[T>>2]=(c[T>>2]|0)-2;L62604:do{if(k<<16>>16==0){U=0;V=a[h]|0}else{S=f+280|0;O=f+293|0;Q=f+444|0;P=k;R=a[h]|0;while(1){F=R&255;f9z(f,((e[f+(F+7<<1)>>1]|0)<<4)+(e[f+(F+8<<1)>>1]|0)|0,b[f+(F+15<<1)>>1]|0);F=f+((d[h]|0)+8<<1)|0;b[F>>1]=((d[O]|0)*-4&65535|2)+(b[F>>1]|0)&65535;F=a[h]|0;c[T>>2]=(c[T>>2]|0)-(((b[f+((F&255)+8<<1)>>1]&1)!=0?526341:525315)>>>((c[Q>>2]|0)>>>0)&127);n=P-1&65535;if(n<<16>>16==0){U=0;V=F;break L62604}if((c[S>>2]|0)==0){P=n;R=F}else{U=n;V=F;break}}}}while(0);b[f+((V&255)+14<<1)>>1]=U;H=f+452|0;a[H]=0;return};case 110:{U=f+432|0;c[U>>2]=(c[U>>2]|0)-2;L62613:do{if(k<<16>>16==0){W=0}else{U=f+280|0;V=k;while(1){gbt(f);T=V-1&65535;if(T<<16>>16==0){W=0;break L62613}if((c[U>>2]|0)==0){V=T}else{W=T;break}}}}while(0);b[f+((d[h]|0)+14<<1)>>1]=W;H=f+452|0;a[H]=0;return};default:{gf[c[2519504+(w<<2)>>2]&2047](f);H=f+452|0;a[H]=0;return}}}function gbl(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;g=f+442|0;a[g]=(a[g]|0)-1&255;h=f+295|0;i=(e[f+((d[h]|0)+6<<1)>>1]|0)<<4;j=f+260|0;k=b[j>>1]|0;b[j>>1]=k+1&65535;l=f+256|0;m=(i+(k&65535)^c[l>>2])&1048575;k=c[3531864]|0;i=c[k+4140+(m>>>11<<2)>>2]|0;if((i|0)==0){n=gj[c[k+8236>>2]&4095](m)|0}else{n=a[i+m|0]|0}m=f+294|0;i=a[m]|0;do{if(i<<24>>24==0){k=c[f+436>>2]|0;if((k|0)==0){o=n;break}o=a[k+(n&255)|0]|0}else{o=n}}while(0);n=o&255;o=d[h]|0;k=b[f+(o+14<<1)>>1]|0;if((n|0)==38){a[f+452|0]=1;c[f+448>>2]=(e[f+(o+7<<1)>>1]|0)<<4;a[g]=(a[g]|0)-1&255;p=(e[f+(o+6<<1)>>1]|0)<<4;q=b[j>>1]|0;b[j>>1]=q+1&65535;r=(p+(q&65535)^c[l>>2])&1048575;q=c[3531864]|0;p=c[q+4140+(r>>>11<<2)>>2]|0;if((p|0)==0){s=gj[c[q+8236>>2]&4095](r)|0;t=s;u=a[m]|0}else{t=a[p+r|0]|0;u=i}do{if(u<<24>>24==0){r=c[f+436>>2]|0;if((r|0)==0){v=t;break}v=a[r+(t&255)|0]|0}else{v=t}}while(0);t=f+432|0;c[t>>2]=(c[t>>2]|0)-2;w=v&255}else if((n|0)==46){a[f+452|0]=1;v=f+(o+6<<1)|0;c[f+448>>2]=(e[v>>1]|0)<<4;a[g]=(a[g]|0)-1&255;t=(e[v>>1]|0)<<4;v=b[j>>1]|0;b[j>>1]=v+1&65535;u=(t+(v&65535)^c[l>>2])&1048575;v=c[3531864]|0;t=c[v+4140+(u>>>11<<2)>>2]|0;if((t|0)==0){r=gj[c[v+8236>>2]&4095](u)|0;x=r;y=a[m]|0}else{x=a[t+u|0]|0;y=i}do{if(y<<24>>24==0){u=c[f+436>>2]|0;if((u|0)==0){z=x;break}z=a[u+(x&255)|0]|0}else{z=x}}while(0);x=f+432|0;c[x>>2]=(c[x>>2]|0)-2;w=z&255}else if((n|0)==54){a[f+452|0]=1;c[f+448>>2]=(e[f+(o+5<<1)>>1]|0)<<4;a[g]=(a[g]|0)-1&255;z=(e[f+(o+6<<1)>>1]|0)<<4;x=b[j>>1]|0;b[j>>1]=x+1&65535;y=(z+(x&65535)^c[l>>2])&1048575;x=c[3531864]|0;z=c[x+4140+(y>>>11<<2)>>2]|0;if((z|0)==0){u=gj[c[x+8236>>2]&4095](y)|0;A=u;B=a[m]|0}else{A=a[z+y|0]|0;B=i}do{if(B<<24>>24==0){y=c[f+436>>2]|0;if((y|0)==0){C=A;break}C=a[y+(A&255)|0]|0}else{C=A}}while(0);A=f+432|0;c[A>>2]=(c[A>>2]|0)-2;w=C&255}else if((n|0)==62){a[f+452|0]=1;c[f+448>>2]=(e[f+(o+4<<1)>>1]|0)<<4;a[g]=(a[g]|0)-1&255;g=(e[f+(o+6<<1)>>1]|0)<<4;o=b[j>>1]|0;b[j>>1]=o+1&65535;j=(g+(o&65535)^c[l>>2])&1048575;l=c[3531864]|0;o=c[l+4140+(j>>>11<<2)>>2]|0;if((o|0)==0){g=gj[c[l+8236>>2]&4095](j)|0;D=g;E=a[m]|0}else{D=a[o+j|0]|0;E=i}do{if(E<<24>>24==0){i=c[f+436>>2]|0;if((i|0)==0){F=D;break}F=a[i+(D&255)|0]|0}else{F=D}}while(0);D=f+432|0;c[D>>2]=(c[D>>2]|0)-2;w=F&255}else{w=n}switch(w|0){case 175:{n=f+432|0;c[n>>2]=(c[n>>2]|0)-2;L62669:do{if(k<<16>>16==0){G=0;H=a[h]|0}else{F=f+280|0;D=f+272|0;E=f+268|0;i=f+284|0;j=f+276|0;o=f+264|0;m=f+293|0;g=f+444|0;l=k;C=a[h]|0;while(1){A=C&255;B=f9x(f,((e[f+(A+7<<1)>>1]|0)<<4)+(e[f+(A+8<<1)>>1]|0)|0)|0;A=d[h]|0;y=b[f+(A+15<<1)>>1]|0;z=y&65535;u=z-(B&65535)|0;c[F>>2]=u&65536;x=(y^B)&65535;c[D>>2]=x&32768&(u^z);c[E>>2]=(u^x)&16;x=u<<16>>16;c[i>>2]=x;c[j>>2]=x;c[o>>2]=x;x=f+(A+8<<1)|0;b[x>>1]=((d[m]|0)*-4&65535|2)+(b[x>>1]|0)&65535;x=a[h]|0;c[n>>2]=(c[n>>2]|0)-(((b[f+((x&255)+8<<1)>>1]&1)!=0?526341:525315)>>>((c[g>>2]|0)>>>0)&127);A=l-1&65535;if(A<<16>>16==0){G=0;H=x;break L62669}if((c[F>>2]|0)==0){G=A;H=x;break}else{l=A;C=x}}}}while(0);b[f+((H&255)+14<<1)>>1]=G;I=f+452|0;a[I]=0;return};case 174:{G=f+432|0;c[G>>2]=(c[G>>2]|0)-2;L62678:do{if(k<<16>>16==0){J=0}else{G=f+280|0;H=k;while(1){gct(f);n=H-1&65535;if(n<<16>>16==0){J=0;break L62678}if((c[G>>2]|0)==0){J=n;break}else{H=n}}}}while(0);b[f+((d[h]|0)+14<<1)>>1]=J;I=f+452|0;a[I]=0;return};case 109:{J=f+432|0;c[J>>2]=(c[J>>2]|0)-2;L62688:do{if(k<<16>>16==0){K=0}else{H=f+280|0;G=f+293|0;n=f+444|0;C=k;while(1){l=d[h]|0;F=((e[f+(l+7<<1)>>1]|0)<<4)+(e[f+(l+8<<1)>>1]|0)|0;g=(gj[c[(c[3531864]|0)+8244>>2]&4095](b[f+(l+13<<1)>>1]&255)|0)&255;f9z(f,F,((gj[c[(c[3531864]|0)+8244>>2]&4095]((e[f+((d[h]|0)+13<<1)>>1]|0)+1&65791)|0)&255)<<8|g);g=f+((d[h]|0)+8<<1)|0;b[g>>1]=((d[G]|0)*-4&65535|2)+(b[g>>1]|0)&65535;c[J>>2]=(c[J>>2]|0)-(1182216>>>((c[n>>2]|0)>>>0)&127);g=C-1&65535;if(g<<16>>16==0){K=0;break L62688}if((c[H>>2]|0)==0){K=g;break}else{C=g}}}}while(0);b[f+((d[h]|0)+14<<1)>>1]=K;I=f+452|0;a[I]=0;return};case 108:{K=f+432|0;c[K>>2]=(c[K>>2]|0)-2;L62696:do{if(k<<16>>16==0){L=0}else{K=f+280|0;J=k;while(1){gbr(f);C=J-1&65535;if(C<<16>>16==0){L=0;break L62696}if((c[K>>2]|0)==0){L=C;break}else{J=C}}}}while(0);b[f+((d[h]|0)+14<<1)>>1]=L;I=f+452|0;a[I]=0;return};case 173:{L=f+432|0;c[L>>2]=(c[L>>2]|0)-2;L62704:do{if(k<<16>>16==0){M=0}else{L=f+280|0;J=k;while(1){gcs(f);K=J-1&65535;if(K<<16>>16==0){M=0;break L62704}if((c[L>>2]|0)==0){M=K;break}else{J=K}}}}while(0);b[f+((d[h]|0)+14<<1)>>1]=M;I=f+452|0;a[I]=0;return};case 170:{M=f+432|0;c[M>>2]=(c[M>>2]|0)-2;L62712:do{if(k<<16>>16==0){N=0}else{M=f+280|0;J=k;while(1){gcp(f);L=J-1&65535;if(L<<16>>16==0){N=0;break L62712}if((c[M>>2]|0)==0){N=L;break}else{J=L}}}}while(0);b[f+((d[h]|0)+14<<1)>>1]=N;I=f+452|0;a[I]=0;return};case 166:{N=f+432|0;c[N>>2]=(c[N>>2]|0)-2;L62720:do{if(k<<16>>16==0){O=0}else{N=f+280|0;J=k;while(1){gcl(f);M=J-1&65535;if(M<<16>>16==0){O=0;break L62720}if((c[N>>2]|0)==0){O=M;break}else{J=M}}}}while(0);b[f+((d[h]|0)+14<<1)>>1]=O;I=f+452|0;a[I]=0;return};case 111:{O=f+432|0;c[O>>2]=(c[O>>2]|0)-2;L62728:do{if(k<<16>>16==0){P=0}else{O=f+280|0;J=k;while(1){gbu(f);N=J-1&65535;if(N<<16>>16==0){P=0;break L62728}if((c[O>>2]|0)==0){P=N;break}else{J=N}}}}while(0);b[f+((d[h]|0)+14<<1)>>1]=P;I=f+452|0;a[I]=0;return};case 171:{P=f+432|0;c[P>>2]=(c[P>>2]|0)-2;L62736:do{if(k<<16>>16==0){Q=0;R=a[h]|0}else{J=f+280|0;O=f+293|0;N=f+444|0;M=k;L=a[h]|0;while(1){K=L&255;f9z(f,((e[f+(K+7<<1)>>1]|0)<<4)+(e[f+(K+8<<1)>>1]|0)|0,b[f+(K+15<<1)>>1]|0);K=f+((d[h]|0)+8<<1)|0;b[K>>1]=((d[O]|0)*-4&65535|2)+(b[K>>1]|0)&65535;K=a[h]|0;c[P>>2]=(c[P>>2]|0)-(((b[f+((K&255)+8<<1)>>1]&1)!=0?526341:525315)>>>((c[N>>2]|0)>>>0)&127);C=M-1&65535;if(C<<16>>16==0){Q=0;R=K;break L62736}if((c[J>>2]|0)==0){Q=C;R=K;break}else{M=C;L=K}}}}while(0);b[f+((R&255)+14<<1)>>1]=Q;I=f+452|0;a[I]=0;return};case 165:{Q=f+432|0;c[Q>>2]=(c[Q>>2]|0)-2;L62745:do{if(k<<16>>16==0){S=0}else{Q=f+280|0;R=k;while(1){gck(f);P=R-1&65535;if(P<<16>>16==0){S=0;break L62745}if((c[Q>>2]|0)==0){S=P;break}else{R=P}}}}while(0);b[f+((d[h]|0)+14<<1)>>1]=S;I=f+452|0;a[I]=0;return};case 172:{S=f+432|0;c[S>>2]=(c[S>>2]|0)-2;L62753:do{if(k<<16>>16==0){T=0}else{S=f+280|0;R=k;while(1){gcr(f);Q=R-1&65535;if(Q<<16>>16==0){T=0;break L62753}if((c[S>>2]|0)==0){T=Q;break}else{R=Q}}}}while(0);b[f+((d[h]|0)+14<<1)>>1]=T;I=f+452|0;a[I]=0;return};case 110:{T=f+432|0;c[T>>2]=(c[T>>2]|0)-2;L62761:do{if(k<<16>>16==0){U=0}else{T=f+280|0;R=k;while(1){gbt(f);S=R-1&65535;if(S<<16>>16==0){U=0;break L62761}if((c[T>>2]|0)==0){U=S;break}else{R=S}}}}while(0);b[f+((d[h]|0)+14<<1)>>1]=U;I=f+452|0;a[I]=0;return};case 167:{U=f+432|0;c[U>>2]=(c[U>>2]|0)-2;L62769:do{if(k<<16>>16==0){V=0}else{U=f+280|0;R=k;while(1){gcm(f);T=R-1&65535;if(T<<16>>16==0){V=0;break L62769}if((c[U>>2]|0)==0){V=T;break}else{R=T}}}}while(0);b[f+((d[h]|0)+14<<1)>>1]=V;I=f+452|0;a[I]=0;return};case 164:{V=f+432|0;c[V>>2]=(c[V>>2]|0)-2;L62777:do{if(k<<16>>16==0){W=0}else{V=f+280|0;R=k;while(1){gcj(f);U=R-1&65535;if(U<<16>>16==0){W=0;break L62777}if((c[V>>2]|0)==0){W=U;break}else{R=U}}}}while(0);b[f+((d[h]|0)+14<<1)>>1]=W;I=f+452|0;a[I]=0;return};default:{gf[c[2519504+(w<<2)>>2]&2047](f);I=f+452|0;a[I]=0;return}}}function gbm(a){a=a|0;var b=0;b=a+432|0;c[b>>2]=(c[b>>2]|0)-10;return}function gbn(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;g=f+442|0;h=(a[g]|0)-1&255;a[g]=h;i=f+295|0;j=a[i]|0;k=(e[f+((j&255)+6<<1)>>1]|0)<<4;l=f+260|0;m=b[l>>1]|0;n=m+1&65535;b[l>>1]=n;o=f+256|0;p=c[o>>2]|0;q=(k+(m&65535)^p)&1048575;m=c[3531864]|0;k=c[m+6188+(q>>>11<<2)>>2]|0;if((k|0)==0){r=gj[c[m+8236>>2]&4095](q)|0;s=r;t=a[g]|0;u=a[i]|0;v=b[l>>1]|0;w=c[o>>2]|0;x=c[3531864]|0}else{s=a[k+q|0]|0;t=h;u=j;v=n;w=p;x=m}a[g]=t-1&255;t=(e[f+((u&255)+6<<1)>>1]|0)<<4;b[l>>1]=v+1&65535;l=(t+(v&65535)^w)&1048575;w=c[x+6188+(l>>>11<<2)>>2]|0;if((w|0)==0){v=gj[c[x+8236>>2]&4095](l)|0;y=v;z=a[i]|0}else{y=a[w+l|0]|0;z=u}u=f+((z&255)+11<<1)|0;b[u>>1]=(b[u>>1]|0)-2&65535;u=d[i]|0;f9z(f,((e[f+(u+5<<1)>>1]|0)<<4)+(e[f+(u+11<<1)>>1]|0)|0,(y&255)<<8|s&255);s=f+432|0;c[s>>2]=(c[s>>2]|0)-(((b[f+((d[i]|0)+11<<1)>>1]&1)!=0?789509:788485)>>>((c[f+444>>2]|0)>>>0)&127);return}function gbo(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;g=f+442|0;a[g]=(a[g]|0)-1&255;h=f+295|0;i=(e[f+((d[h]|0)+6<<1)>>1]|0)<<4;j=f+260|0;k=b[j>>1]|0;b[j>>1]=k+1&65535;l=f+256|0;m=(i+(k&65535)^c[l>>2])&1048575;k=c[3531864]|0;i=c[k+6188+(m>>>11<<2)>>2]|0;if((i|0)==0){n=gj[c[k+8236>>2]&4095](m)|0}else{n=a[i+m|0]|0}m=n&255;i=9653856+(m<<2)|0;k=(n&255)>191;if(k){n=a[h]|0;o=b[f+((n&255)+(c[9649760+(m<<2)>>2]|0)<<1)>>1]|0;p=n}else{n=c[678944+(m<<2)>>2]|0;gj[n&4095](f)|0;n=f9x(f,c[2426954]|0)|0;o=n;p=a[h]|0}n=(a[g]|0)-1&255;a[g]=n;m=(e[f+((p&255)+6<<1)>>1]|0)<<4;q=b[j>>1]|0;r=q+1&65535;b[j>>1]=r;s=c[l>>2]|0;t=(m+(q&65535)^s)&1048575;q=c[3531864]|0;m=c[q+6188+(t>>>11<<2)>>2]|0;if((m|0)==0){u=gj[c[q+8236>>2]&4095](t)|0;v=u;w=a[g]|0;x=a[h]|0;y=b[j>>1]|0;z=c[l>>2]|0;A=c[3531864]|0}else{v=a[m+t|0]|0;w=n;x=p;y=r;z=s;A=q}a[g]=w-1&255;w=(e[f+((x&255)+6<<1)>>1]|0)<<4;b[j>>1]=y+1&65535;j=(w+(y&65535)^z)&1048575;z=c[A+6188+(j>>>11<<2)>>2]|0;if((z|0)==0){B=gj[c[A+8236>>2]&4095](j)|0}else{B=a[z+j|0]|0}j=ag(((B&255)<<8|v&255)<<16>>16,o<<16>>16)|0;o=j>>15;if((o|0)==0){C=0;D=f+272|0;c[D>>2]=C;E=f+280|0;c[E>>2]=C;F=j&65535;G=a[h]|0;H=G&255;I=c[i>>2]|0;J=H+I|0;K=f+(J<<1)|0;b[K>>1]=F;L=k?38:47;M=f+432|0;N=c[M>>2]|0;O=N-L|0;c[M>>2]=O;return}C=(o|0)!=-1|0;D=f+272|0;c[D>>2]=C;E=f+280|0;c[E>>2]=C;F=j&65535;G=a[h]|0;H=G&255;I=c[i>>2]|0;J=H+I|0;K=f+(J<<1)|0;b[K>>1]=F;L=k?38:47;M=f+432|0;N=c[M>>2]|0;O=N-L|0;c[M>>2]=O;return}function gbp(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=f+442|0;a[g]=(a[g]|0)-1&255;g=f+295|0;h=a[g]|0;i=(e[f+((h&255)+6<<1)>>1]|0)<<4;j=f+260|0;k=b[j>>1]|0;b[j>>1]=k+1&65535;j=(i+(k&65535)^c[f+256>>2])&1048575;k=c[3531864]|0;i=c[k+6188+(j>>>11<<2)>>2]|0;if((i|0)==0){l=gj[c[k+8236>>2]&4095](j)|0;m=l;n=a[g]|0}else{m=a[i+j|0]|0;n=h}h=f+((n&255)+11<<1)|0;b[h>>1]=(b[h>>1]|0)-2&65535;h=d[g]|0;f9z(f,((e[f+(h+5<<1)>>1]|0)<<4)+(e[f+(h+11<<1)>>1]|0)|0,m<<24>>24);m=f+432|0;c[m>>2]=(c[m>>2]|0)-(((b[f+((d[g]|0)+11<<1)>>1]&1)!=0?723717:722691)>>>((c[f+444>>2]|0)>>>0)&127);return}function gbq(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;g=f+442|0;a[g]=(a[g]|0)-1&255;h=f+295|0;i=(e[f+((d[h]|0)+6<<1)>>1]|0)<<4;j=f+260|0;k=b[j>>1]|0;b[j>>1]=k+1&65535;l=f+256|0;m=(i+(k&65535)^c[l>>2])&1048575;k=c[3531864]|0;i=c[k+6188+(m>>>11<<2)>>2]|0;if((i|0)==0){n=gj[c[k+8236>>2]&4095](m)|0}else{n=a[i+m|0]|0}m=n&255;i=9653856+(m<<2)|0;k=(n&255)>191;if(k){n=a[h]|0;o=b[f+((n&255)+(c[9649760+(m<<2)>>2]|0)<<1)>>1]|0;p=n}else{n=c[678944+(m<<2)>>2]|0;gj[n&4095](f)|0;n=f9x(f,c[2426954]|0)|0;o=n;p=a[h]|0}a[g]=(a[g]|0)-1&255;g=(e[f+((p&255)+6<<1)>>1]|0)<<4;p=b[j>>1]|0;b[j>>1]=p+1&65535;j=(g+(p&65535)^c[l>>2])&1048575;l=c[3531864]|0;p=c[l+6188+(j>>>11<<2)>>2]|0;if((p|0)==0){q=gj[c[l+8236>>2]&4095](j)|0}else{q=a[p+j|0]|0}j=ag(q<<24>>24,o<<16>>16)|0;o=j>>15;if((o|0)==0){r=0;s=f+272|0;c[s>>2]=r;t=f+280|0;c[t>>2]=r;u=j&65535;v=a[h]|0;w=v&255;x=c[i>>2]|0;y=w+x|0;z=f+(y<<1)|0;b[z>>1]=u;A=k?31:39;B=f+432|0;C=c[B>>2]|0;D=C-A|0;c[B>>2]=D;return}r=(o|0)!=-1|0;s=f+272|0;c[s>>2]=r;t=f+280|0;c[t>>2]=r;u=j&65535;v=a[h]|0;w=v&255;x=c[i>>2]|0;y=w+x|0;z=f+(y<<1)|0;b[z>>1]=u;A=k?31:39;B=f+432|0;C=c[B>>2]|0;D=C-A|0;c[B>>2]=D;return}function gbr(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=f+295|0;h=d[g]|0;i=(e[f+(h+7<<1)>>1]<<4)+(e[f+(h+8<<1)>>1]|0)|0;j=gj[c[(c[3531864]|0)+8244>>2]&4095](b[f+(h+13<<1)>>1]&255)|0;do{if((i&1048064|0)==(c[f+428>>2]|0)|(i|0)==1048575){h=i&511;if((a[f+424|0]|0)!=0&h>>>0<256){a[f+h|0]=j;break}if(h>>>0<=255){k=51123;break}f9y(f,h-256|0,j)}else{k=51123}}while(0);do{if((k|0)==51123){h=i&1048575;l=c[3531864]|0;m=c[l+2092+(h>>>11<<2)>>2]|0;if((m|0)==0){gg[c[l+8240>>2]&4095](h,j);break}else{a[m+h|0]=j;break}}}while(0);j=f+((d[g]|0)+8<<1)|0;b[j>>1]=((d[f+293|0]|0)*-2&65535|1)+(b[j>>1]|0)&65535;j=f+432|0;c[j>>2]=(c[j>>2]|0)-8;return}function gbs(a){a=a|0;var f=0,g=0,h=0,i=0;f=a+295|0;g=d[f]|0;h=((e[a+(g+7<<1)>>1]|0)<<4)+(e[a+(g+8<<1)>>1]|0)|0;i=(gj[c[(c[3531864]|0)+8244>>2]&4095](b[a+(g+13<<1)>>1]&255)|0)&255;f9z(a,h,((gj[c[(c[3531864]|0)+8244>>2]&4095]((e[a+((d[f]|0)+13<<1)>>1]|0)+1&65791)|0)&255)<<8|i);i=a+((d[f]|0)+8<<1)|0;b[i>>1]=((d[a+293|0]|0)*-4&65535|2)+(b[i>>1]|0)&65535;i=a+432|0;c[i>>2]=(c[i>>2]|0)-(1182216>>>((c[a+444>>2]|0)>>>0)&127);return}function gbt(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=f+295|0;h=d[g]|0;i=e[f+(h+13<<1)>>1]|0;if((a[f+452|0]|0)==0){j=e[f+(h+4<<1)>>1]<<4}else{j=c[f+448>>2]|0}k=(e[f+(h+9<<1)>>1]|0)+j|0;do{if((k&1048064|0)==(c[f+428>>2]|0)|(k|0)==1048575){j=k&511;if((a[f+424|0]|0)!=0&j>>>0<256){l=a[f+j|0]|0;break}if(j>>>0<=255){m=51136;break}l=f9w(f,j-256|0)|0}else{m=51136}}while(0);do{if((m|0)==51136){j=k&1048575;h=c[3531864]|0;n=c[h+44+(j>>>11<<2)>>2]|0;if((n|0)==0){l=gj[c[h+8236>>2]&4095](j)|0;break}else{l=a[n+j|0]|0;break}}}while(0);gg[c[(c[3531864]|0)+8248>>2]&4095](i,l);l=f+((d[g]|0)+9<<1)|0;b[l>>1]=((d[f+293|0]|0)*-2&65535|1)+(b[l>>1]|0)&65535;l=f+432|0;c[l>>2]=(c[l>>2]|0)-8;return}function gbu(f){f=f|0;var g=0,h=0,i=0,j=0,k=0;g=f+295|0;h=d[g]|0;i=e[f+(h+13<<1)>>1]|0;if((a[f+452|0]|0)==0){j=e[f+(h+4<<1)>>1]<<4}else{j=c[f+448>>2]|0}k=f9x(f,(e[f+(h+9<<1)>>1]|0)+j|0)|0;gg[c[(c[3531864]|0)+8248>>2]&4095](i,k&255);gg[c[(c[3531864]|0)+8248>>2]&4095](i+1|0,(k&65535)>>>8&255);k=f+((d[g]|0)+9<<1)|0;b[k>>1]=((d[f+293|0]|0)*-4&65535|2)+(b[k>>1]|0)&65535;k=f+432|0;c[k>>2]=(c[k>>2]|0)-(1182216>>>((c[f+444>>2]|0)>>>0)&127);return}function gbv(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;g=f+443|0;a[g]=1;h=f+442|0;a[h]=(a[h]|0)-1&255;h=(e[f+((d[f+295|0]|0)+6<<1)>>1]|0)<<4;i=f+260|0;j=b[i>>1]|0;b[i>>1]=j+1&65535;k=(h+(j&65535)^c[f+256>>2])&1048575;j=c[3531864]|0;h=c[j+6188+(k>>>11<<2)>>2]|0;if((h|0)==0){l=gj[c[j+8236>>2]&4095](k)|0}else{l=a[h+k|0]|0}if((c[f+272>>2]|0)==0){k=f+432|0;c[k>>2]=(c[k>>2]|0)-(263171>>>((c[f+444>>2]|0)>>>0)&127);return}else{b[i>>1]=(b[i>>1]|0)+(l<<24>>24)&65535;l=f+432|0;c[l>>2]=(c[l>>2]|0)-(d[591976+((c[f+444>>2]|0)>>>3)|0]|0);a[g]=1;return}}function gbw(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;g=f+443|0;a[g]=1;h=f+442|0;a[h]=(a[h]|0)-1&255;h=(e[f+((d[f+295|0]|0)+6<<1)>>1]|0)<<4;i=f+260|0;j=b[i>>1]|0;b[i>>1]=j+1&65535;k=(h+(j&65535)^c[f+256>>2])&1048575;j=c[3531864]|0;h=c[j+6188+(k>>>11<<2)>>2]|0;if((h|0)==0){l=gj[c[j+8236>>2]&4095](k)|0}else{l=a[h+k|0]|0}if((c[f+272>>2]|0)==0){b[i>>1]=(b[i>>1]|0)+(l<<24>>24)&65535;l=f+432|0;c[l>>2]=(c[l>>2]|0)-(d[591976+((c[f+444>>2]|0)>>>3)|0]|0);a[g]=1;return}else{g=f+432|0;c[g>>2]=(c[g>>2]|0)-(263171>>>((c[f+444>>2]|0)>>>0)&127);return}}function gbx(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;g=f+443|0;a[g]=1;h=f+442|0;a[h]=(a[h]|0)-1&255;h=(e[f+((d[f+295|0]|0)+6<<1)>>1]|0)<<4;i=f+260|0;j=b[i>>1]|0;b[i>>1]=j+1&65535;k=(h+(j&65535)^c[f+256>>2])&1048575;j=c[3531864]|0;h=c[j+6188+(k>>>11<<2)>>2]|0;if((h|0)==0){l=gj[c[j+8236>>2]&4095](k)|0}else{l=a[h+k|0]|0}if((c[f+280>>2]|0)==0){k=f+432|0;c[k>>2]=(c[k>>2]|0)-(263171>>>((c[f+444>>2]|0)>>>0)&127);return}else{b[i>>1]=(b[i>>1]|0)+(l<<24>>24)&65535;l=f+432|0;c[l>>2]=(c[l>>2]|0)-(d[591976+((c[f+444>>2]|0)>>>3)|0]|0);a[g]=1;return}}function gby(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;g=f+443|0;a[g]=1;h=f+442|0;a[h]=(a[h]|0)-1&255;h=(e[f+((d[f+295|0]|0)+6<<1)>>1]|0)<<4;i=f+260|0;j=b[i>>1]|0;b[i>>1]=j+1&65535;k=(h+(j&65535)^c[f+256>>2])&1048575;j=c[3531864]|0;h=c[j+6188+(k>>>11<<2)>>2]|0;if((h|0)==0){l=gj[c[j+8236>>2]&4095](k)|0}else{l=a[h+k|0]|0}if((c[f+280>>2]|0)==0){b[i>>1]=(b[i>>1]|0)+(l<<24>>24)&65535;l=f+432|0;c[l>>2]=(c[l>>2]|0)-(d[591976+((c[f+444>>2]|0)>>>3)|0]|0);a[g]=1;return}else{g=f+432|0;c[g>>2]=(c[g>>2]|0)-(263171>>>((c[f+444>>2]|0)>>>0)&127);return}}function gbz(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;g=f+443|0;a[g]=1;h=f+442|0;a[h]=(a[h]|0)-1&255;h=(e[f+((d[f+295|0]|0)+6<<1)>>1]|0)<<4;i=f+260|0;j=b[i>>1]|0;b[i>>1]=j+1&65535;k=(h+(j&65535)^c[f+256>>2])&1048575;j=c[3531864]|0;h=c[j+6188+(k>>>11<<2)>>2]|0;if((h|0)==0){l=gj[c[j+8236>>2]&4095](k)|0}else{l=a[h+k|0]|0}if((c[f+276>>2]|0)==0){b[i>>1]=(b[i>>1]|0)+(l<<24>>24)&65535;l=f+432|0;c[l>>2]=(c[l>>2]|0)-(d[591976+((c[f+444>>2]|0)>>>3)|0]|0);a[g]=1;return}else{g=f+432|0;c[g>>2]=(c[g>>2]|0)-(263171>>>((c[f+444>>2]|0)>>>0)&127);return}}function gbA(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;g=f+443|0;a[g]=1;h=f+442|0;a[h]=(a[h]|0)-1&255;h=(e[f+((d[f+295|0]|0)+6<<1)>>1]|0)<<4;i=f+260|0;j=b[i>>1]|0;b[i>>1]=j+1&65535;k=(h+(j&65535)^c[f+256>>2])&1048575;j=c[3531864]|0;h=c[j+6188+(k>>>11<<2)>>2]|0;if((h|0)==0){l=gj[c[j+8236>>2]&4095](k)|0}else{l=a[h+k|0]|0}if((c[f+276>>2]|0)==0){k=f+432|0;c[k>>2]=(c[k>>2]|0)-(263171>>>((c[f+444>>2]|0)>>>0)&127);return}else{b[i>>1]=(b[i>>1]|0)+(l<<24>>24)&65535;l=f+432|0;c[l>>2]=(c[l>>2]|0)-(d[591976+((c[f+444>>2]|0)>>>3)|0]|0);a[g]=1;return}}function gbB(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;g=f+443|0;a[g]=1;h=f+442|0;a[h]=(a[h]|0)-1&255;h=(e[f+((d[f+295|0]|0)+6<<1)>>1]|0)<<4;i=f+260|0;j=b[i>>1]|0;b[i>>1]=j+1&65535;k=(h+(j&65535)^c[f+256>>2])&1048575;j=c[3531864]|0;h=c[j+6188+(k>>>11<<2)>>2]|0;if((h|0)==0){l=gj[c[j+8236>>2]&4095](k)|0}else{l=a[h+k|0]|0}k=l<<24>>24;do{if((c[f+280>>2]|0)==0){if((c[f+276>>2]|0)==0){break}l=f+432|0;c[l>>2]=(c[l>>2]|0)-(263171>>>((c[f+444>>2]|0)>>>0)&127);return}}while(0);b[i>>1]=(b[i>>1]|0)+k&65535;k=f+432|0;c[k>>2]=(c[k>>2]|0)-(d[591976+((c[f+444>>2]|0)>>>3)|0]|0);a[g]=1;return}function gbC(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;g=f+443|0;a[g]=1;h=f+442|0;a[h]=(a[h]|0)-1&255;h=(e[f+((d[f+295|0]|0)+6<<1)>>1]|0)<<4;i=f+260|0;j=b[i>>1]|0;b[i>>1]=j+1&65535;k=(h+(j&65535)^c[f+256>>2])&1048575;j=c[3531864]|0;h=c[j+6188+(k>>>11<<2)>>2]|0;if((h|0)==0){l=gj[c[j+8236>>2]&4095](k)|0}else{l=a[h+k|0]|0}k=l<<24>>24;do{if((c[f+280>>2]|0)==0){if((c[f+276>>2]|0)==0){break}b[i>>1]=(b[i>>1]|0)+k&65535;l=f+432|0;c[l>>2]=(c[l>>2]|0)-(d[591976+((c[f+444>>2]|0)>>>3)|0]|0);a[g]=1;return}}while(0);g=f+432|0;c[g>>2]=(c[g>>2]|0)-(263171>>>((c[f+444>>2]|0)>>>0)&127);return}function gbD(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;g=f+443|0;a[g]=1;h=f+442|0;a[h]=(a[h]|0)-1&255;h=(e[f+((d[f+295|0]|0)+6<<1)>>1]|0)<<4;i=f+260|0;j=b[i>>1]|0;b[i>>1]=j+1&65535;k=(h+(j&65535)^c[f+256>>2])&1048575;j=c[3531864]|0;h=c[j+6188+(k>>>11<<2)>>2]|0;if((h|0)==0){l=gj[c[j+8236>>2]&4095](k)|0}else{l=a[h+k|0]|0}if((c[f+264>>2]|0)<0){b[i>>1]=(b[i>>1]|0)+(l<<24>>24)&65535;l=f+432|0;c[l>>2]=(c[l>>2]|0)-(d[591976+((c[f+444>>2]|0)>>>3)|0]|0);a[g]=1;return}else{g=f+432|0;c[g>>2]=(c[g>>2]|0)-(263171>>>((c[f+444>>2]|0)>>>0)&127);return}}function gbE(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;g=f+443|0;a[g]=1;h=f+442|0;a[h]=(a[h]|0)-1&255;h=(e[f+((d[f+295|0]|0)+6<<1)>>1]|0)<<4;i=f+260|0;j=b[i>>1]|0;b[i>>1]=j+1&65535;k=(h+(j&65535)^c[f+256>>2])&1048575;j=c[3531864]|0;h=c[j+6188+(k>>>11<<2)>>2]|0;if((h|0)==0){l=gj[c[j+8236>>2]&4095](k)|0}else{l=a[h+k|0]|0}if((c[f+264>>2]|0)<0){k=f+432|0;c[k>>2]=(c[k>>2]|0)-(263171>>>((c[f+444>>2]|0)>>>0)&127);return}else{b[i>>1]=(b[i>>1]|0)+(l<<24>>24)&65535;l=f+432|0;c[l>>2]=(c[l>>2]|0)-(d[591976+((c[f+444>>2]|0)>>>3)|0]|0);a[g]=1;return}}function gbF(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;g=f+443|0;a[g]=1;h=f+442|0;a[h]=(a[h]|0)-1&255;h=e[f+((d[f+295|0]|0)+6<<1)>>1]<<4;i=f+260|0;j=b[i>>1]|0;b[i>>1]=j+1&65535;k=(h+(j&65535)^c[f+256>>2])&1048575;j=c[3531864]|0;h=c[j+6188+(k>>>11<<2)>>2]|0;if((h|0)==0){l=gj[c[j+8236>>2]&4095](k)|0}else{l=a[h+k|0]|0}if((a[9760944+(c[f+284>>2]&255)|0]|0)==0){k=f+432|0;c[k>>2]=(c[k>>2]|0)-(263171>>>((c[f+444>>2]|0)>>>0)&127);return}else{b[i>>1]=(b[i>>1]|0)+(l<<24>>24)&65535;l=f+432|0;c[l>>2]=(c[l>>2]|0)-(d[591976+((c[f+444>>2]|0)>>>3)|0]|0);a[g]=1;return}}function gbG(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;g=f+443|0;a[g]=1;h=f+442|0;a[h]=(a[h]|0)-1&255;h=e[f+((d[f+295|0]|0)+6<<1)>>1]<<4;i=f+260|0;j=b[i>>1]|0;b[i>>1]=j+1&65535;k=(h+(j&65535)^c[f+256>>2])&1048575;j=c[3531864]|0;h=c[j+6188+(k>>>11<<2)>>2]|0;if((h|0)==0){l=gj[c[j+8236>>2]&4095](k)|0}else{l=a[h+k|0]|0}if((a[9760944+(c[f+284>>2]&255)|0]|0)==0){b[i>>1]=(b[i>>1]|0)+(l<<24>>24)&65535;l=f+432|0;c[l>>2]=(c[l>>2]|0)-(d[591976+((c[f+444>>2]|0)>>>3)|0]|0);a[g]=1;return}else{g=f+432|0;c[g>>2]=(c[g>>2]|0)-(263171>>>((c[f+444>>2]|0)>>>0)&127);return}}function gbH(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;g=f+443|0;a[g]=1;h=f+442|0;a[h]=(a[h]|0)-1&255;h=(e[f+((d[f+295|0]|0)+6<<1)>>1]|0)<<4;i=f+260|0;j=b[i>>1]|0;b[i>>1]=j+1&65535;k=(h+(j&65535)^c[f+256>>2])&1048575;j=c[3531864]|0;h=c[j+6188+(k>>>11<<2)>>2]|0;if((h|0)==0){l=gj[c[j+8236>>2]&4095](k)|0}else{l=a[h+k|0]|0}k=l<<24>>24;do{if(((c[f+264>>2]|0)>>>31|0)!=((c[f+272>>2]|0)!=0|0)){if((c[f+276>>2]|0)==0){break}b[i>>1]=(b[i>>1]|0)+k&65535;l=f+432|0;c[l>>2]=(c[l>>2]|0)-(d[591976+((c[f+444>>2]|0)>>>3)|0]|0);a[g]=1;return}}while(0);g=f+432|0;c[g>>2]=(c[g>>2]|0)-(263171>>>((c[f+444>>2]|0)>>>0)&127);return}function gbI(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;g=f+443|0;a[g]=1;h=f+442|0;a[h]=(a[h]|0)-1&255;h=(e[f+((d[f+295|0]|0)+6<<1)>>1]|0)<<4;i=f+260|0;j=b[i>>1]|0;b[i>>1]=j+1&65535;k=(h+(j&65535)^c[f+256>>2])&1048575;j=c[3531864]|0;h=c[j+6188+(k>>>11<<2)>>2]|0;if((h|0)==0){l=gj[c[j+8236>>2]&4095](k)|0}else{l=a[h+k|0]|0}k=l<<24>>24;do{if((c[f+276>>2]|0)!=0){if(((c[f+264>>2]|0)>>>31|0)==((c[f+272>>2]|0)!=0|0)){break}l=f+432|0;c[l>>2]=(c[l>>2]|0)-(263171>>>((c[f+444>>2]|0)>>>0)&127);return}}while(0);b[i>>1]=(b[i>>1]|0)+k&65535;k=f+432|0;c[k>>2]=(c[k>>2]|0)-(d[591976+((c[f+444>>2]|0)>>>3)|0]|0);a[g]=1;return}function gbJ(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;g=f+443|0;a[g]=1;h=f+442|0;a[h]=(a[h]|0)-1&255;h=(e[f+((d[f+295|0]|0)+6<<1)>>1]|0)<<4;i=f+260|0;j=b[i>>1]|0;b[i>>1]=j+1&65535;k=(h+(j&65535)^c[f+256>>2])&1048575;j=c[3531864]|0;h=c[j+6188+(k>>>11<<2)>>2]|0;if((h|0)==0){l=gj[c[j+8236>>2]&4095](k)|0}else{l=a[h+k|0]|0}k=l<<24>>24;do{if((c[f+276>>2]|0)!=0){if(((c[f+264>>2]|0)>>>31|0)!=((c[f+272>>2]|0)!=0|0)){break}l=f+432|0;c[l>>2]=(c[l>>2]|0)-(263171>>>((c[f+444>>2]|0)>>>0)&127);return}}while(0);b[i>>1]=(b[i>>1]|0)+k&65535;k=f+432|0;c[k>>2]=(c[k>>2]|0)-(d[591976+((c[f+444>>2]|0)>>>3)|0]|0);a[g]=1;return}function gbK(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;g=f+443|0;a[g]=1;h=f+442|0;a[h]=(a[h]|0)-1&255;h=(e[f+((d[f+295|0]|0)+6<<1)>>1]|0)<<4;i=f+260|0;j=b[i>>1]|0;b[i>>1]=j+1&65535;k=(h+(j&65535)^c[f+256>>2])&1048575;j=c[3531864]|0;h=c[j+6188+(k>>>11<<2)>>2]|0;if((h|0)==0){l=gj[c[j+8236>>2]&4095](k)|0}else{l=a[h+k|0]|0}k=l<<24>>24;do{if(((c[f+264>>2]|0)>>>31|0)==((c[f+272>>2]|0)!=0|0)){if((c[f+276>>2]|0)==0){break}b[i>>1]=(b[i>>1]|0)+k&65535;l=f+432|0;c[l>>2]=(c[l>>2]|0)-(d[591976+((c[f+444>>2]|0)>>>3)|0]|0);a[g]=1;return}}while(0);g=f+432|0;c[g>>2]=(c[g>>2]|0)-(263171>>>((c[f+444>>2]|0)>>>0)&127);return}function gbL(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=f+442|0;a[g]=(a[g]|0)-1&255;h=f+295|0;i=e[f+((d[h]|0)+6<<1)>>1]<<4;j=f+260|0;k=b[j>>1]|0;b[j>>1]=k+1&65535;l=f+256|0;m=(i+(k&65535)^c[l>>2])&1048575;k=c[3531864]|0;i=c[k+6188+(m>>>11<<2)>>2]|0;if((i|0)==0){n=gj[c[k+8236>>2]&4095](m)|0}else{n=a[i+m|0]|0}m=n&255;i=(n&255)>191;L63044:do{if(i){o=a[f+((d[f+296|0]|0)+(c[9647712+(m<<2)>>2]|0))|0]|0}else{n=gj[c[678944+(m<<2)>>2]&4095](f)|0;do{if((n&1048064|0)==(c[f+428>>2]|0)|(n|0)==1048575){k=n&511;if((a[f+424|0]|0)!=0&k>>>0<256){o=a[f+k|0]|0;break L63044}if(k>>>0<=255){break}o=f9w(f,k-256|0)|0;break L63044}}while(0);k=n&1048575;p=c[3531864]|0;q=c[p+44+(k>>>11<<2)>>2]|0;if((q|0)==0){o=gj[c[p+8236>>2]&4095](k)|0;break}else{o=a[q+k|0]|0;break}}}while(0);k=o&255;a[g]=(a[g]|0)-1&255;g=e[f+((d[h]|0)+6<<1)>>1]<<4;h=b[j>>1]|0;b[j>>1]=h+1&65535;j=(g+(h&65535)^c[l>>2])&1048575;l=c[3531864]|0;h=c[l+6188+(j>>>11<<2)>>2]|0;if((h|0)==0){r=gj[c[l+8236>>2]&4095](j)|0}else{r=a[h+j|0]|0}j=r&255;do{if(i){h=f+432|0;c[h>>2]=(c[h>>2]|0)-(263170>>>((c[f+444>>2]|0)>>>0)&127);s=m&56;t=51315}else{h=m&56;l=c[f+444>>2]|0;if((h|0)==56){g=f+432|0;c[g>>2]=(c[g>>2]|0)-(855302>>>(l>>>0)&127);break}else{g=f+432|0;c[g>>2]=(c[g>>2]|0)-(1184263>>>(l>>>0)&127);s=h;t=51315;break}}}while(0);L63068:do{if((t|0)==51315){switch(s|0){case 0:{h=j+k|0;c[f+280>>2]=h&256;c[f+272>>2]=(h^k)&128&(h^j);c[f+268>>2]=(h^(r^o)&255)&16;l=h<<24>>24;c[f+284>>2]=l;c[f+276>>2]=l;c[f+264>>2]=l;if(i){a[f+((d[f+296|0]|0)+(c[9647712+(m<<2)>>2]|0))|0]=h&255;return}l=c[2426954]|0;g=h&255;do{if((l&1048064|0)==(c[f+428>>2]|0)|(l|0)==1048575){h=l&511;if((a[f+424|0]|0)!=0&h>>>0<256){a[f+h|0]=g;return}if(h>>>0<=255){break}f9y(f,h-256|0,g);return}}while(0);n=l&1048575;h=c[3531864]|0;q=c[h+2092+(n>>>11<<2)>>2]|0;if((q|0)==0){gg[c[h+8240>>2]&4095](n,g);return}else{a[q+n|0]=g;return}break};case 16:{n=f+280|0;q=((c[n>>2]|0)!=0)+j|0;h=q+k|0;c[n>>2]=h&256;c[f+272>>2]=(h^k)&128&(h^q);c[f+268>>2]=(q^k^h)&16;q=h<<24>>24;c[f+284>>2]=q;c[f+276>>2]=q;c[f+264>>2]=q;if(i){a[f+((d[f+296|0]|0)+(c[9647712+(m<<2)>>2]|0))|0]=h&255;return}q=c[2426954]|0;n=h&255;do{if((q&1048064|0)==(c[f+428>>2]|0)|(q|0)==1048575){h=q&511;if((a[f+424|0]|0)!=0&h>>>0<256){a[f+h|0]=n;return}if(h>>>0<=255){break}f9y(f,h-256|0,n);return}}while(0);g=q&1048575;l=c[3531864]|0;h=c[l+2092+(g>>>11<<2)>>2]|0;if((h|0)==0){gg[c[l+8240>>2]&4095](g,n);return}else{a[h+g|0]=n;return}break};case 8:{g=r|o;c[f+268>>2]=0;c[f+272>>2]=0;c[f+280>>2]=0;h=g<<24>>24;c[f+284>>2]=h;c[f+276>>2]=h;c[f+264>>2]=h;if(i){a[f+((d[f+296|0]|0)+(c[9647712+(m<<2)>>2]|0))|0]=g;return}h=c[2426954]|0;do{if((h&1048064|0)==(c[f+428>>2]|0)|(h|0)==1048575){l=h&511;if((a[f+424|0]|0)!=0&l>>>0<256){a[f+l|0]=g;return}if(l>>>0<=255){break}f9y(f,l-256|0,g);return}}while(0);n=h&1048575;q=c[3531864]|0;l=c[q+2092+(n>>>11<<2)>>2]|0;if((l|0)==0){gg[c[q+8240>>2]&4095](n,g);return}else{a[l+n|0]=g;return}break};case 56:{break L63068;break};case 40:{n=k-j|0;c[f+280>>2]=n&256;l=(r^o)&255;c[f+272>>2]=l&128&(n^k);c[f+268>>2]=(n^l)&16;l=n<<24>>24;c[f+284>>2]=l;c[f+276>>2]=l;c[f+264>>2]=l;if(i){a[f+((d[f+296|0]|0)+(c[9647712+(m<<2)>>2]|0))|0]=n&255;return}l=c[2426954]|0;q=n&255;do{if((l&1048064|0)==(c[f+428>>2]|0)|(l|0)==1048575){n=l&511;if((a[f+424|0]|0)!=0&n>>>0<256){a[f+n|0]=q;return}if(n>>>0<=255){break}f9y(f,n-256|0,q);return}}while(0);g=l&1048575;h=c[3531864]|0;n=c[h+2092+(g>>>11<<2)>>2]|0;if((n|0)==0){gg[c[h+8240>>2]&4095](g,q);return}else{a[n+g|0]=q;return}break};case 48:{g=r^o;c[f+268>>2]=0;c[f+272>>2]=0;c[f+280>>2]=0;n=g<<24>>24;c[f+284>>2]=n;c[f+276>>2]=n;c[f+264>>2]=n;if(i){a[f+((d[f+296|0]|0)+(c[9647712+(m<<2)>>2]|0))|0]=g;return}n=c[2426954]|0;do{if((n&1048064|0)==(c[f+428>>2]|0)|(n|0)==1048575){h=n&511;if((a[f+424|0]|0)!=0&h>>>0<256){a[f+h|0]=g;return}if(h>>>0<=255){break}f9y(f,h-256|0,g);return}}while(0);q=n&1048575;l=c[3531864]|0;h=c[l+2092+(q>>>11<<2)>>2]|0;if((h|0)==0){gg[c[l+8240>>2]&4095](q,g);return}else{a[h+q|0]=g;return}break};case 32:{q=r&o;c[f+268>>2]=0;c[f+272>>2]=0;c[f+280>>2]=0;h=q<<24>>24;c[f+284>>2]=h;c[f+276>>2]=h;c[f+264>>2]=h;if(i){a[f+((d[f+296|0]|0)+(c[9647712+(m<<2)>>2]|0))|0]=q;return}h=c[2426954]|0;do{if((h&1048064|0)==(c[f+428>>2]|0)|(h|0)==1048575){l=h&511;if((a[f+424|0]|0)!=0&l>>>0<256){a[f+l|0]=q;return}if(l>>>0<=255){break}f9y(f,l-256|0,q);return}}while(0);g=h&1048575;n=c[3531864]|0;l=c[n+2092+(g>>>11<<2)>>2]|0;if((l|0)==0){gg[c[n+8240>>2]&4095](g,q);return}else{a[l+g|0]=q;return}break};case 24:{g=f+280|0;l=((c[g>>2]|0)!=0)+j|0;n=k-l|0;c[g>>2]=n&256;g=l^k;c[f+272>>2]=g&128&(n^k);c[f+268>>2]=(n^g)&16;g=n<<24>>24;c[f+284>>2]=g;c[f+276>>2]=g;c[f+264>>2]=g;if(i){a[f+((d[f+296|0]|0)+(c[9647712+(m<<2)>>2]|0))|0]=n&255;return}g=c[2426954]|0;l=n&255;do{if((g&1048064|0)==(c[f+428>>2]|0)|(g|0)==1048575){n=g&511;if((a[f+424|0]|0)!=0&n>>>0<256){a[f+n|0]=l;return}if(n>>>0<=255){break}f9y(f,n-256|0,l);return}}while(0);q=g&1048575;h=c[3531864]|0;n=c[h+2092+(q>>>11<<2)>>2]|0;if((n|0)==0){gg[c[h+8240>>2]&4095](q,l);return}else{a[n+q|0]=l;return}break};default:{return}}}}while(0);m=k-j|0;c[f+280>>2]=m&256;j=(r^o)&255;c[f+272>>2]=j&128&(m^k);c[f+268>>2]=(m^j)&16;j=m<<24>>24;c[f+284>>2]=j;c[f+276>>2]=j;c[f+264>>2]=j;return}function gbM(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;g=f+442|0;a[g]=(a[g]|0)-1&255;h=f+295|0;i=(e[f+((d[h]|0)+6<<1)>>1]|0)<<4;j=f+260|0;k=b[j>>1]|0;b[j>>1]=k+1&65535;l=f+256|0;m=(i+(k&65535)^c[l>>2])&1048575;k=c[3531864]|0;i=c[k+6188+(m>>>11<<2)>>2]|0;if((i|0)==0){n=gj[c[k+8236>>2]&4095](m)|0}else{n=a[i+m|0]|0}m=n&255;i=(n&255)>191;if(i){n=a[h]|0;o=b[f+((n&255)+(c[9649760+(m<<2)>>2]|0)<<1)>>1]|0;p=n}else{n=c[678944+(m<<2)>>2]|0;gj[n&4095](f)|0;n=f9x(f,c[2426954]|0)|0;o=n;p=a[h]|0}n=o&65535;o=(a[g]|0)-1&255;a[g]=o;k=(e[f+((p&255)+6<<1)>>1]|0)<<4;q=b[j>>1]|0;r=q+1&65535;b[j>>1]=r;s=c[l>>2]|0;t=(k+(q&65535)^s)&1048575;q=c[3531864]|0;k=c[q+6188+(t>>>11<<2)>>2]|0;if((k|0)==0){u=gj[c[q+8236>>2]&4095](t)|0;v=u;w=a[g]|0;x=a[h]|0;y=b[j>>1]|0;z=c[l>>2]|0;A=c[3531864]|0}else{v=a[k+t|0]|0;w=o;x=p;y=r;z=s;A=q}q=v&255;a[g]=w-1&255;w=(e[f+((x&255)+6<<1)>>1]|0)<<4;b[j>>1]=y+1&65535;j=(w+(y&65535)^z)&1048575;z=c[A+6188+(j>>>11<<2)>>2]|0;if((z|0)==0){B=gj[c[A+8236>>2]&4095](j)|0}else{B=a[z+j|0]|0}j=(B&255)<<8;B=j|q;do{if(i){z=f+432|0;c[z>>2]=(c[z>>2]|0)-(263170>>>((c[f+444>>2]|0)>>>0)&127);C=m&56;D=51442}else{z=m&56;A=(c[2426954]&1|0)!=0;y=c[f+444>>2]|0;if((z|0)==56){w=f+432|0;c[w>>2]=(c[w>>2]|0)-((A?1118472:1117446)>>>(y>>>0)&127);break}else{w=f+432|0;c[w>>2]=(c[w>>2]|0)-((A?1710603:1708551)>>>(y>>>0)&127);C=z;D=51442;break}}}while(0);L63230:do{if((D|0)==51442){switch(C|0){case 0:{z=B+n|0;c[f+280>>2]=z&65536;c[f+272>>2]=(z^n)&32768&(z^j);c[f+268>>2]=(q^n^z)&16;y=z<<16>>16;c[f+284>>2]=y;c[f+276>>2]=y;c[f+264>>2]=y;if(i){b[f+((d[h]|0)+(c[9649760+(m<<2)>>2]|0)<<1)>>1]=z&65535;return}else{f9z(f,c[2426954]|0,z&65535);return}break};case 8:{c[f+268>>2]=0;c[f+272>>2]=0;c[f+280>>2]=0;z=(B|n)&65535;y=z<<16>>16;c[f+284>>2]=y;c[f+276>>2]=y;c[f+264>>2]=y;if(i){b[f+((d[h]|0)+(c[9649760+(m<<2)>>2]|0)<<1)>>1]=z;return}else{f9z(f,c[2426954]|0,z);return}break};case 56:{break L63230;break};case 24:{z=f+280|0;y=((c[z>>2]|0)!=0)+B|0;A=n-y|0;c[z>>2]=A&65536;z=y^n;c[f+272>>2]=z&32768&(A^n);c[f+268>>2]=(A^z)&16;z=A<<16>>16;c[f+284>>2]=z;c[f+276>>2]=z;c[f+264>>2]=z;if(i){b[f+((d[h]|0)+(c[9649760+(m<<2)>>2]|0)<<1)>>1]=A&65535;return}else{f9z(f,c[2426954]|0,A&65535);return}break};case 32:{c[f+268>>2]=0;c[f+272>>2]=0;c[f+280>>2]=0;A=B&n&65535;z=A<<16>>16;c[f+284>>2]=z;c[f+276>>2]=z;c[f+264>>2]=z;if(i){b[f+((d[h]|0)+(c[9649760+(m<<2)>>2]|0)<<1)>>1]=A;return}else{f9z(f,c[2426954]|0,A);return}break};case 40:{A=n-B|0;c[f+280>>2]=A&65536;z=B^n;c[f+272>>2]=z&32768&(A^n);c[f+268>>2]=(A^z)&16;z=A<<16>>16;c[f+284>>2]=z;c[f+276>>2]=z;c[f+264>>2]=z;if(i){b[f+((d[h]|0)+(c[9649760+(m<<2)>>2]|0)<<1)>>1]=A&65535;return}else{f9z(f,c[2426954]|0,A&65535);return}break};case 16:{A=f+280|0;z=((c[A>>2]|0)!=0)+B|0;y=z+n|0;c[A>>2]=y&65536;c[f+272>>2]=(y^n)&32768&(y^z);c[f+268>>2]=(z^n^y)&16;z=y<<16>>16;c[f+284>>2]=z;c[f+276>>2]=z;c[f+264>>2]=z;if(i){b[f+((d[h]|0)+(c[9649760+(m<<2)>>2]|0)<<1)>>1]=y&65535;return}else{f9z(f,c[2426954]|0,y&65535);return}break};case 48:{c[f+268>>2]=0;c[f+272>>2]=0;c[f+280>>2]=0;y=(B^n)&65535;z=y<<16>>16;c[f+284>>2]=z;c[f+276>>2]=z;c[f+264>>2]=z;if(i){b[f+((d[h]|0)+(c[9649760+(m<<2)>>2]|0)<<1)>>1]=y;return}else{f9z(f,c[2426954]|0,y);return}break};default:{return}}}}while(0);m=n-B|0;c[f+280>>2]=m&65536;h=B^n;c[f+272>>2]=h&32768&(m^n);c[f+268>>2]=(m^h)&16;h=m<<16>>16;c[f+284>>2]=h;c[f+276>>2]=h;c[f+264>>2]=h;return}function gbN(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=f+442|0;a[g]=(a[g]|0)-1&255;h=f+295|0;i=e[f+((d[h]|0)+6<<1)>>1]<<4;j=f+260|0;k=b[j>>1]|0;b[j>>1]=k+1&65535;l=f+256|0;m=(i+(k&65535)^c[l>>2])&1048575;k=c[3531864]|0;i=c[k+6188+(m>>>11<<2)>>2]|0;if((i|0)==0){n=gj[c[k+8236>>2]&4095](m)|0}else{n=a[i+m|0]|0}m=n&255;i=(n&255)>191;L63283:do{if(i){o=a[f+((d[f+296|0]|0)+(c[9647712+(m<<2)>>2]|0))|0]|0}else{n=gj[c[678944+(m<<2)>>2]&4095](f)|0;do{if((n&1048064|0)==(c[f+428>>2]|0)|(n|0)==1048575){k=n&511;if((a[f+424|0]|0)!=0&k>>>0<256){o=a[f+k|0]|0;break L63283}if(k>>>0<=255){break}o=f9w(f,k-256|0)|0;break L63283}}while(0);k=n&1048575;p=c[3531864]|0;q=c[p+44+(k>>>11<<2)>>2]|0;if((q|0)==0){o=gj[c[p+8236>>2]&4095](k)|0;break}else{o=a[q+k|0]|0;break}}}while(0);k=o&255;a[g]=(a[g]|0)-1&255;g=e[f+((d[h]|0)+6<<1)>>1]<<4;h=b[j>>1]|0;b[j>>1]=h+1&65535;j=(g+(h&65535)^c[l>>2])&1048575;l=c[3531864]|0;h=c[l+6188+(j>>>11<<2)>>2]|0;if((h|0)==0){r=gj[c[l+8236>>2]&4095](j)|0}else{r=a[h+j|0]|0}j=r&255;do{if(i){h=f+432|0;c[h>>2]=(c[h>>2]|0)-(263170>>>((c[f+444>>2]|0)>>>0)&127);s=m&56;t=51503}else{h=m&56;l=c[f+444>>2]|0;if((h|0)==56){g=f+432|0;c[g>>2]=(c[g>>2]|0)-(855302>>>(l>>>0)&127);break}else{g=f+432|0;c[g>>2]=(c[g>>2]|0)-(1184263>>>(l>>>0)&127);s=h;t=51503;break}}}while(0);L63307:do{if((t|0)==51503){switch(s|0){case 8:{h=r|o;c[f+268>>2]=0;c[f+272>>2]=0;c[f+280>>2]=0;l=h<<24>>24;c[f+284>>2]=l;c[f+276>>2]=l;c[f+264>>2]=l;if(i){a[f+((d[f+296|0]|0)+(c[9647712+(m<<2)>>2]|0))|0]=h;return}l=c[2426954]|0;do{if((l&1048064|0)==(c[f+428>>2]|0)|(l|0)==1048575){g=l&511;if((a[f+424|0]|0)!=0&g>>>0<256){a[f+g|0]=h;return}if(g>>>0<=255){break}f9y(f,g-256|0,h);return}}while(0);n=l&1048575;g=c[3531864]|0;q=c[g+2092+(n>>>11<<2)>>2]|0;if((q|0)==0){gg[c[g+8240>>2]&4095](n,h);return}else{a[q+n|0]=h;return}break};case 16:{n=f+280|0;q=((c[n>>2]|0)!=0)+j|0;g=q+k|0;c[n>>2]=g&256;c[f+272>>2]=(g^k)&128&(g^q);c[f+268>>2]=(q^k^g)&16;q=g<<24>>24;c[f+284>>2]=q;c[f+276>>2]=q;c[f+264>>2]=q;if(i){a[f+((d[f+296|0]|0)+(c[9647712+(m<<2)>>2]|0))|0]=g&255;return}q=c[2426954]|0;n=g&255;do{if((q&1048064|0)==(c[f+428>>2]|0)|(q|0)==1048575){g=q&511;if((a[f+424|0]|0)!=0&g>>>0<256){a[f+g|0]=n;return}if(g>>>0<=255){break}f9y(f,g-256|0,n);return}}while(0);h=q&1048575;l=c[3531864]|0;g=c[l+2092+(h>>>11<<2)>>2]|0;if((g|0)==0){gg[c[l+8240>>2]&4095](h,n);return}else{a[g+h|0]=n;return}break};case 0:{h=j+k|0;c[f+280>>2]=h&256;c[f+272>>2]=(h^k)&128&(h^j);c[f+268>>2]=(h^(r^o)&255)&16;g=h<<24>>24;c[f+284>>2]=g;c[f+276>>2]=g;c[f+264>>2]=g;if(i){a[f+((d[f+296|0]|0)+(c[9647712+(m<<2)>>2]|0))|0]=h&255;return}g=c[2426954]|0;l=h&255;do{if((g&1048064|0)==(c[f+428>>2]|0)|(g|0)==1048575){h=g&511;if((a[f+424|0]|0)!=0&h>>>0<256){a[f+h|0]=l;return}if(h>>>0<=255){break}f9y(f,h-256|0,l);return}}while(0);n=g&1048575;q=c[3531864]|0;h=c[q+2092+(n>>>11<<2)>>2]|0;if((h|0)==0){gg[c[q+8240>>2]&4095](n,l);return}else{a[h+n|0]=l;return}break};case 48:{n=r^o;c[f+268>>2]=0;c[f+272>>2]=0;c[f+280>>2]=0;h=n<<24>>24;c[f+284>>2]=h;c[f+276>>2]=h;c[f+264>>2]=h;if(i){a[f+((d[f+296|0]|0)+(c[9647712+(m<<2)>>2]|0))|0]=n;return}h=c[2426954]|0;do{if((h&1048064|0)==(c[f+428>>2]|0)|(h|0)==1048575){q=h&511;if((a[f+424|0]|0)!=0&q>>>0<256){a[f+q|0]=n;return}if(q>>>0<=255){break}f9y(f,q-256|0,n);return}}while(0);l=h&1048575;g=c[3531864]|0;q=c[g+2092+(l>>>11<<2)>>2]|0;if((q|0)==0){gg[c[g+8240>>2]&4095](l,n);return}else{a[q+l|0]=n;return}break};case 32:{l=r&o;c[f+268>>2]=0;c[f+272>>2]=0;c[f+280>>2]=0;q=l<<24>>24;c[f+284>>2]=q;c[f+276>>2]=q;c[f+264>>2]=q;if(i){a[f+((d[f+296|0]|0)+(c[9647712+(m<<2)>>2]|0))|0]=l;return}q=c[2426954]|0;do{if((q&1048064|0)==(c[f+428>>2]|0)|(q|0)==1048575){g=q&511;if((a[f+424|0]|0)!=0&g>>>0<256){a[f+g|0]=l;return}if(g>>>0<=255){break}f9y(f,g-256|0,l);return}}while(0);n=q&1048575;h=c[3531864]|0;g=c[h+2092+(n>>>11<<2)>>2]|0;if((g|0)==0){gg[c[h+8240>>2]&4095](n,l);return}else{a[g+n|0]=l;return}break};case 24:{n=f+280|0;g=((c[n>>2]|0)!=0)+j|0;h=k-g|0;c[n>>2]=h&256;n=g^k;c[f+272>>2]=n&128&(h^k);c[f+268>>2]=(h^n)&16;n=h<<24>>24;c[f+284>>2]=n;c[f+276>>2]=n;c[f+264>>2]=n;if(i){a[f+((d[f+296|0]|0)+(c[9647712+(m<<2)>>2]|0))|0]=h&255;return}n=c[2426954]|0;g=h&255;do{if((n&1048064|0)==(c[f+428>>2]|0)|(n|0)==1048575){h=n&511;if((a[f+424|0]|0)!=0&h>>>0<256){a[f+h|0]=g;return}if(h>>>0<=255){break}f9y(f,h-256|0,g);return}}while(0);l=n&1048575;q=c[3531864]|0;h=c[q+2092+(l>>>11<<2)>>2]|0;if((h|0)==0){gg[c[q+8240>>2]&4095](l,g);return}else{a[h+l|0]=g;return}break};case 56:{break L63307;break};case 40:{l=k-j|0;c[f+280>>2]=l&256;h=(r^o)&255;c[f+272>>2]=h&128&(l^k);c[f+268>>2]=(l^h)&16;h=l<<24>>24;c[f+284>>2]=h;c[f+276>>2]=h;c[f+264>>2]=h;if(i){a[f+((d[f+296|0]|0)+(c[9647712+(m<<2)>>2]|0))|0]=l&255;return}h=c[2426954]|0;q=l&255;do{if((h&1048064|0)==(c[f+428>>2]|0)|(h|0)==1048575){l=h&511;if((a[f+424|0]|0)!=0&l>>>0<256){a[f+l|0]=q;return}if(l>>>0<=255){break}f9y(f,l-256|0,q);return}}while(0);g=h&1048575;n=c[3531864]|0;l=c[n+2092+(g>>>11<<2)>>2]|0;if((l|0)==0){gg[c[n+8240>>2]&4095](g,q);return}else{a[l+g|0]=q;return}break};default:{return}}}}while(0);m=k-j|0;c[f+280>>2]=m&256;j=(r^o)&255;c[f+272>>2]=j&128&(m^k);c[f+268>>2]=(m^j)&16;j=m<<24>>24;c[f+284>>2]=j;c[f+276>>2]=j;c[f+264>>2]=j;return}function gbO(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=f+442|0;a[g]=(a[g]|0)-1&255;h=f+295|0;i=(e[f+((d[h]|0)+6<<1)>>1]|0)<<4;j=f+260|0;k=b[j>>1]|0;b[j>>1]=k+1&65535;l=f+256|0;m=(i+(k&65535)^c[l>>2])&1048575;k=c[3531864]|0;i=c[k+6188+(m>>>11<<2)>>2]|0;if((i|0)==0){n=gj[c[k+8236>>2]&4095](m)|0}else{n=a[i+m|0]|0}m=n&255;i=(n&255)>191;if(i){n=a[h]|0;o=b[f+((n&255)+(c[9649760+(m<<2)>>2]|0)<<1)>>1]|0;p=n}else{n=c[678944+(m<<2)>>2]|0;gj[n&4095](f)|0;n=f9x(f,c[2426954]|0)|0;o=n;p=a[h]|0}n=o&65535;a[g]=(a[g]|0)-1&255;g=(e[f+((p&255)+6<<1)>>1]|0)<<4;p=b[j>>1]|0;b[j>>1]=p+1&65535;j=(g+(p&65535)^c[l>>2])&1048575;l=c[3531864]|0;p=c[l+6188+(j>>>11<<2)>>2]|0;if((p|0)==0){q=gj[c[l+8236>>2]&4095](j)|0}else{q=a[p+j|0]|0}j=q<<24>>24;q=j&65535;do{if(i){p=f+432|0;c[p>>2]=(c[p>>2]|0)-(263170>>>((c[f+444>>2]|0)>>>0)&127);r=m&56;s=51627}else{p=m&56;l=(c[2426954]&1|0)!=0;g=c[f+444>>2]|0;if((p|0)==56){k=f+432|0;c[k>>2]=(c[k>>2]|0)-((l?1118472:1117446)>>>(g>>>0)&127);break}else{k=f+432|0;c[k>>2]=(c[k>>2]|0)-((l?1710603:1708551)>>>(g>>>0)&127);r=p;s=51627;break}}}while(0);L63465:do{if((s|0)==51627){switch(r|0){case 16:{p=f+280|0;g=((c[p>>2]|0)!=0)+q|0;l=g+n|0;c[p>>2]=l&65536;c[f+272>>2]=(l^n)&32768&(l^g);c[f+268>>2]=(g^n^l)&16;g=l<<16>>16;c[f+284>>2]=g;c[f+276>>2]=g;c[f+264>>2]=g;if(i){b[f+((d[h]|0)+(c[9649760+(m<<2)>>2]|0)<<1)>>1]=l&65535;return}else{f9z(f,c[2426954]|0,l&65535);return}break};case 24:{l=f+280|0;g=((c[l>>2]|0)!=0)+q|0;p=n-g|0;c[l>>2]=p&65536;l=g^n;c[f+272>>2]=l&32768&(p^n);c[f+268>>2]=(p^l)&16;l=p<<16>>16;c[f+284>>2]=l;c[f+276>>2]=l;c[f+264>>2]=l;if(i){b[f+((d[h]|0)+(c[9649760+(m<<2)>>2]|0)<<1)>>1]=p&65535;return}else{f9z(f,c[2426954]|0,p&65535);return}break};case 32:{p=j&o;c[f+268>>2]=0;c[f+272>>2]=0;c[f+280>>2]=0;l=p<<16>>16;c[f+284>>2]=l;c[f+276>>2]=l;c[f+264>>2]=l;if(i){b[f+((d[h]|0)+(c[9649760+(m<<2)>>2]|0)<<1)>>1]=p;return}else{f9z(f,c[2426954]|0,p);return}break};case 0:{p=q+n|0;c[f+280>>2]=p&65536;c[f+272>>2]=(p^n)&32768&(p^q);c[f+268>>2]=(p^(j^o)&65535)&16;l=p<<16>>16;c[f+284>>2]=l;c[f+276>>2]=l;c[f+264>>2]=l;if(i){b[f+((d[h]|0)+(c[9649760+(m<<2)>>2]|0)<<1)>>1]=p&65535;return}else{f9z(f,c[2426954]|0,p&65535);return}break};case 56:{break L63465;break};case 40:{p=n-q|0;c[f+280>>2]=p&65536;l=(j^o)&65535;c[f+272>>2]=l&32768&(p^n);c[f+268>>2]=(p^l)&16;l=p<<16>>16;c[f+284>>2]=l;c[f+276>>2]=l;c[f+264>>2]=l;if(i){b[f+((d[h]|0)+(c[9649760+(m<<2)>>2]|0)<<1)>>1]=p&65535;return}else{f9z(f,c[2426954]|0,p&65535);return}break};case 48:{p=j^o;c[f+268>>2]=0;c[f+272>>2]=0;c[f+280>>2]=0;l=p<<16>>16;c[f+284>>2]=l;c[f+276>>2]=l;c[f+264>>2]=l;if(i){b[f+((d[h]|0)+(c[9649760+(m<<2)>>2]|0)<<1)>>1]=p;return}else{f9z(f,c[2426954]|0,p);return}break};case 8:{p=j|o;c[f+268>>2]=0;c[f+272>>2]=0;c[f+280>>2]=0;l=p<<16>>16;c[f+284>>2]=l;c[f+276>>2]=l;c[f+264>>2]=l;if(i){b[f+((d[h]|0)+(c[9649760+(m<<2)>>2]|0)<<1)>>1]=p;return}else{f9z(f,c[2426954]|0,p);return}break};default:{return}}}}while(0);m=n-q|0;c[f+280>>2]=m&65536;q=(j^o)&65535;c[f+272>>2]=q&32768&(m^n);c[f+268>>2]=(m^q)&16;q=m<<16>>16;c[f+284>>2]=q;c[f+276>>2]=q;c[f+264>>2]=q;return}function gbP(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=f+442|0;a[g]=(a[g]|0)-1&255;g=e[f+((d[f+295|0]|0)+6<<1)>>1]<<4;h=f+260|0;i=b[h>>1]|0;b[h>>1]=i+1&65535;h=(g+(i&65535)^c[f+256>>2])&1048575;i=c[3531864]|0;g=c[i+6188+(h>>>11<<2)>>2]|0;if((g|0)==0){j=gj[c[i+8236>>2]&4095](h)|0}else{j=a[g+h|0]|0}h=j&255;g=d[f+296|0]|0;i=f;k=a[i+(g+(c[9651808+(h<<2)>>2]|0))|0]|0;l=(j&255)>191;L63518:do{if(l){m=a[i+((c[9647712+(h<<2)>>2]|0)+g)|0]|0}else{j=gj[c[678944+(h<<2)>>2]&4095](f)|0;do{if((j&1048064|0)==(c[f+428>>2]|0)|(j|0)==1048575){n=j&511;if((a[f+424|0]|0)!=0&n>>>0<256){m=a[i+n|0]|0;break L63518}if(n>>>0<=255){break}m=f9w(f,n-256|0)|0;break L63518}}while(0);n=j&1048575;o=c[3531864]|0;p=c[o+44+(n>>>11<<2)>>2]|0;if((p|0)==0){m=gj[c[o+8236>>2]&4095](n)|0;break}else{m=a[p+n|0]|0;break}}}while(0);c[f+268>>2]=0;c[f+272>>2]=0;c[f+280>>2]=0;i=(m&k)<<24>>24;c[f+284>>2]=i;c[f+276>>2]=i;c[f+264>>2]=i;i=f+432|0;c[i>>2]=(c[i>>2]|0)-((l?131586:657926)>>>((c[f+444>>2]|0)>>>0)&127);return}function gbQ(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=d+442|0;a[f]=(a[f]|0)-1&255;f=d+295|0;g=a[f]|0;h=(e[d+((g&255)+6<<1)>>1]|0)<<4;i=d+260|0;j=b[i>>1]|0;b[i>>1]=j+1&65535;i=(h+(j&65535)^c[d+256>>2])&1048575;j=c[3531864]|0;h=c[j+6188+(i>>>11<<2)>>2]|0;if((h|0)==0){k=gj[c[j+8236>>2]&4095](i)|0;l=k;m=a[f]|0}else{l=a[h+i|0]|0;m=g}g=l&255;i=m&255;m=b[d+(i+(c[9653856+(g<<2)>>2]|0)<<1)>>1]|0;h=(l&255)>191;if(h){n=b[d+((c[9649760+(g<<2)>>2]|0)+i<<1)>>1]|0}else{i=c[678944+(g<<2)>>2]|0;gj[i&4095](d)|0;n=f9x(d,c[2426954]|0)|0}c[d+268>>2]=0;c[d+272>>2]=0;c[d+280>>2]=0;i=(n&m)<<16>>16;c[d+284>>2]=i;c[d+276>>2]=i;c[d+264>>2]=i;if(h){h=d+432|0;c[h>>2]=(c[h>>2]|0)-2;return}else{h=d+432|0;c[h>>2]=(c[h>>2]|0)-(((c[2426954]&1|0)!=0?921096:920070)>>>((c[d+444>>2]|0)>>>0)&127);return}}function gbR(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=f+442|0;a[g]=(a[g]|0)-1&255;g=e[f+((d[f+295|0]|0)+6<<1)>>1]<<4;h=f+260|0;i=b[h>>1]|0;b[h>>1]=i+1&65535;h=(g+(i&65535)^c[f+256>>2])&1048575;i=c[3531864]|0;g=c[i+6188+(h>>>11<<2)>>2]|0;if((g|0)==0){j=gj[c[i+8236>>2]&4095](h)|0}else{j=a[g+h|0]|0}h=j&255;g=f+296|0;i=d[g]|0;k=9651808+(h<<2)|0;l=f;m=l+(i+(c[k>>2]|0))|0;n=a[m]|0;o=(j&255)>191;L63551:do{if(o){j=c[9647712+(h<<2)>>2]|0;a[m]=a[l+(j+i)|0]|0;a[l+((d[g]|0)+j)|0]=n}else{j=gj[c[678944+(h<<2)>>2]&4095](f)|0;p=f+428|0;do{if((j&1048064|0)==(c[p>>2]|0)|(j|0)==1048575){q=j&511;if((a[f+424|0]|0)!=0&q>>>0<256){a[l+((d[g]|0)+(c[k>>2]|0))|0]=a[l+q|0]|0;break}if(q>>>0<=255){r=51702;break}s=f9w(f,q-256|0)|0;r=51705}else{r=51702}}while(0);do{if((r|0)==51702){q=j&1048575;t=c[3531864]|0;u=c[t+44+(q>>>11<<2)>>2]|0;if((u|0)==0){s=gj[c[t+8236>>2]&4095](q)|0;r=51705;break}else{s=a[u+q|0]|0;r=51705;break}}}while(0);if((r|0)==51705){a[l+((d[g]|0)+(c[k>>2]|0))|0]=s}j=c[2426954]|0;do{if((j&1048064|0)==(c[p>>2]|0)|(j|0)==1048575){q=j&511;if((a[f+424|0]|0)!=0&q>>>0<256){a[l+q|0]=n;break L63551}if(q>>>0<=255){break}f9y(f,q-256|0,n);break L63551}}while(0);p=j&1048575;q=c[3531864]|0;u=c[q+2092+(p>>>11<<2)>>2]|0;if((u|0)==0){gg[c[q+8240>>2]&4095](p,n);break}else{a[u+p|0]=n;break}}}while(0);n=f+432|0;c[n>>2]=(c[n>>2]|0)-((o?197379:1053192)>>>((c[f+444>>2]|0)>>>0)&127);return}function gbS(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=f+442|0;a[g]=(a[g]|0)-1&255;g=f+295|0;h=a[g]|0;i=(e[f+((h&255)+6<<1)>>1]|0)<<4;j=f+260|0;k=b[j>>1]|0;b[j>>1]=k+1&65535;j=(i+(k&65535)^c[f+256>>2])&1048575;k=c[3531864]|0;i=c[k+6188+(j>>>11<<2)>>2]|0;if((i|0)==0){l=gj[c[k+8236>>2]&4095](j)|0;m=l;n=a[g]|0}else{m=a[i+j|0]|0;n=h}h=m&255;j=n&255;n=9653856+(h<<2)|0;i=f+(j+(c[n>>2]|0)<<1)|0;l=b[i>>1]|0;if((m&255)>191){m=c[9649760+(h<<2)>>2]|0;b[i>>1]=b[f+(m+j<<1)>>1]|0;b[f+((d[g]|0)+m<<1)>>1]=l;m=f+432|0;c[m>>2]=(c[m>>2]|0)-3;return}else{m=c[678944+(h<<2)>>2]|0;gj[m&4095](f)|0;m=f9x(f,c[2426954]|0)|0;b[f+((d[g]|0)+(c[n>>2]|0)<<1)>>1]=m;f9z(f,c[2426954]|0,l);l=f+432|0;c[l>>2]=(c[l>>2]|0)-(((c[2426954]&1|0)!=0?1579020:1576968)>>>((c[f+444>>2]|0)>>>0)&127);return}}function gbT(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=f+442|0;a[g]=(a[g]|0)-1&255;g=e[f+((d[f+295|0]|0)+6<<1)>>1]<<4;h=f+260|0;i=b[h>>1]|0;b[h>>1]=i+1&65535;h=(g+(i&65535)^c[f+256>>2])&1048575;i=c[3531864]|0;g=c[i+6188+(h>>>11<<2)>>2]|0;if((g|0)==0){j=gj[c[i+8236>>2]&4095](h)|0}else{j=a[g+h|0]|0}h=j&255;g=d[f+296|0]|0;i=f;k=a[i+(g+(c[9651808+(h<<2)>>2]|0))|0]|0;l=(j&255)>191;L63594:do{if(l){a[i+((c[9647712+(h<<2)>>2]|0)+g)|0]=k}else{j=gj[c[678944+(h<<2)>>2]&4095](f)|0;do{if((j&1048064|0)==(c[f+428>>2]|0)|(j|0)==1048575){m=j&511;if((a[f+424|0]|0)!=0&m>>>0<256){a[i+m|0]=k;break L63594}if(m>>>0<=255){break}f9y(f,m-256|0,k);break L63594}}while(0);m=j&1048575;n=c[3531864]|0;o=c[n+2092+(m>>>11<<2)>>2]|0;if((o|0)==0){gg[c[n+8240>>2]&4095](m,k);break}else{a[o+m|0]=k;break}}}while(0);k=f+432|0;c[k>>2]=(c[k>>2]|0)-((l?131586:592131)>>>((c[f+444>>2]|0)>>>0)&127);return}function gbU(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=d+442|0;a[f]=(a[f]|0)-1&255;f=d+295|0;g=a[f]|0;h=(e[d+((g&255)+6<<1)>>1]|0)<<4;i=d+260|0;j=b[i>>1]|0;b[i>>1]=j+1&65535;i=(h+(j&65535)^c[d+256>>2])&1048575;j=c[3531864]|0;h=c[j+6188+(i>>>11<<2)>>2]|0;if((h|0)==0){k=gj[c[j+8236>>2]&4095](i)|0;l=k;m=a[f]|0}else{l=a[h+i|0]|0;m=g}g=l&255;i=m&255;m=b[d+(i+(c[9653856+(g<<2)>>2]|0)<<1)>>1]|0;if((l&255)>191){b[d+((c[9649760+(g<<2)>>2]|0)+i<<1)>>1]=m;i=d+432|0;c[i>>2]=(c[i>>2]|0)-2;return}else{i=c[678944+(g<<2)>>2]|0;gj[i&4095](d)|0;f9z(d,c[2426954]|0,m);m=d+432|0;c[m>>2]=(c[m>>2]|0)-(((c[2426954]&1|0)!=0?855301:854275)>>>((c[d+444>>2]|0)>>>0)&127);return}}function gbV(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=f+442|0;a[g]=(a[g]|0)-1&255;g=e[f+((d[f+295|0]|0)+6<<1)>>1]<<4;h=f+260|0;i=b[h>>1]|0;b[h>>1]=i+1&65535;h=(g+(i&65535)^c[f+256>>2])&1048575;i=c[3531864]|0;g=c[i+6188+(h>>>11<<2)>>2]|0;if((g|0)==0){j=gj[c[i+8236>>2]&4095](h)|0}else{j=a[g+h|0]|0}h=j&255;g=(j&255)>191;L63623:do{if(g){k=a[f+((d[f+296|0]|0)+(c[9647712+(h<<2)>>2]|0))|0]|0}else{j=gj[c[678944+(h<<2)>>2]&4095](f)|0;do{if((j&1048064|0)==(c[f+428>>2]|0)|(j|0)==1048575){i=j&511;if((a[f+424|0]|0)!=0&i>>>0<256){k=a[f+i|0]|0;break L63623}if(i>>>0<=255){break}k=f9w(f,i-256|0)|0;break L63623}}while(0);i=j&1048575;l=c[3531864]|0;m=c[l+44+(i>>>11<<2)>>2]|0;if((m|0)==0){k=gj[c[l+8236>>2]&4095](i)|0;break}else{k=a[m+i|0]|0;break}}}while(0);a[f+((d[f+296|0]|0)+(c[9651808+(h<<2)>>2]|0))|0]=k;k=f+432|0;c[k>>2]=(c[k>>2]|0)-((g?131586:723717)>>>((c[f+444>>2]|0)>>>0)&127);return}function gbW(f){f=f|0;var g=0,h=0,i=0,j=0,k=0;g=f+442|0;a[g]=(a[g]|0)-1&255;g=f+295|0;h=(e[f+((d[g]|0)+6<<1)>>1]|0)<<4;i=f+260|0;j=b[i>>1]|0;b[i>>1]=j+1&65535;i=(h+(j&65535)^c[f+256>>2])&1048575;j=c[3531864]|0;h=c[j+6188+(i>>>11<<2)>>2]|0;if((h|0)==0){k=gj[c[j+8236>>2]&4095](i)|0}else{k=a[h+i|0]|0}i=k&255;if((k&255)>191){k=d[g]|0;b[f+((c[9653856+(i<<2)>>2]|0)+k<<1)>>1]=b[f+(k+(c[9649760+(i<<2)>>2]|0)<<1)>>1]|0;k=f+432|0;c[k>>2]=(c[k>>2]|0)-2;return}else{k=c[678944+(i<<2)>>2]|0;gj[k&4095](f)|0;k=f9x(f,c[2426954]|0)|0;b[f+((d[g]|0)+(c[9653856+(i<<2)>>2]|0)<<1)>>1]=k;k=f+432|0;c[k>>2]=(c[k>>2]|0)-(((c[2426954]&1|0)!=0?986887:985861)>>>((c[f+444>>2]|0)>>>0)&127);return}}function gbX(f){f=f|0;var g=0,h=0,i=0,j=0,k=0;g=f+442|0;a[g]=(a[g]|0)-1&255;g=f+295|0;h=(e[f+((d[g]|0)+6<<1)>>1]|0)<<4;i=f+260|0;j=b[i>>1]|0;b[i>>1]=j+1&65535;i=(h+(j&65535)^c[f+256>>2])&1048575;j=c[3531864]|0;h=c[j+6188+(i>>>11<<2)>>2]|0;if((h|0)==0){k=gj[c[j+8236>>2]&4095](i)|0}else{k=a[h+i|0]|0}i=k&255;h=i&56;if((h|0)==8){if((k&255)>191){j=d[g]|0;b[f+((c[9649760+(i<<2)>>2]|0)+j<<1)>>1]=b[f+(j+6<<1)>>1]|0;j=f+432|0;c[j>>2]=(c[j>>2]|0)-2;return}else{j=c[678944+(i<<2)>>2]|0;gj[j&4095](f)|0;f9z(f,c[2426954]|0,b[f+((d[g]|0)+6<<1)>>1]|0);j=f+432|0;c[j>>2]=(c[j>>2]|0)-(((c[2426954]&1|0)!=0?921093:920067)>>>((c[f+444>>2]|0)>>>0)&127);return}}else if((h|0)==0){if((k&255)>191){j=d[g]|0;b[f+((c[9649760+(i<<2)>>2]|0)+j<<1)>>1]=b[f+(j+7<<1)>>1]|0;j=f+432|0;c[j>>2]=(c[j>>2]|0)-2;return}else{j=c[678944+(i<<2)>>2]|0;gj[j&4095](f)|0;f9z(f,c[2426954]|0,b[f+((d[g]|0)+7<<1)>>1]|0);j=f+432|0;c[j>>2]=(c[j>>2]|0)-(((c[2426954]&1|0)!=0?921093:920067)>>>((c[f+444>>2]|0)>>>0)&127);return}}else if((h|0)==24){if((k&255)>191){j=d[g]|0;b[f+((c[9649760+(i<<2)>>2]|0)+j<<1)>>1]=b[f+(j+4<<1)>>1]|0;j=f+432|0;c[j>>2]=(c[j>>2]|0)-2;return}else{j=c[678944+(i<<2)>>2]|0;gj[j&4095](f)|0;f9z(f,c[2426954]|0,b[f+((d[g]|0)+4<<1)>>1]|0);j=f+432|0;c[j>>2]=(c[j>>2]|0)-(((c[2426954]&1|0)!=0?921093:920067)>>>((c[f+444>>2]|0)>>>0)&127);return}}else if((h|0)==16){if((k&255)>191){k=d[g]|0;b[f+((c[9649760+(i<<2)>>2]|0)+k<<1)>>1]=b[f+(k+5<<1)>>1]|0;k=f+432|0;c[k>>2]=(c[k>>2]|0)-2;return}else{k=c[678944+(i<<2)>>2]|0;gj[k&4095](f)|0;f9z(f,c[2426954]|0,b[f+((d[g]|0)+5<<1)>>1]|0);g=f+432|0;c[g>>2]=(c[g>>2]|0)-(((c[2426954]&1|0)!=0?921093:920067)>>>((c[f+444>>2]|0)>>>0)&127);return}}else{return}}function gbY(f){f=f|0;var g=0,h=0,i=0,j=0,k=0;g=f+442|0;a[g]=(a[g]|0)-1&255;g=f+295|0;h=(e[f+((d[g]|0)+6<<1)>>1]|0)<<4;i=f+260|0;j=b[i>>1]|0;b[i>>1]=j+1&65535;i=(h+(j&65535)^c[f+256>>2])&1048575;j=c[3531864]|0;h=c[j+6188+(i>>>11<<2)>>2]|0;if((h|0)==0){k=gj[c[j+8236>>2]&4095](i)|0}else{k=a[h+i|0]|0}i=k&255;gj[c[678944+(i<<2)>>2]&4095](f)|0;b[f+((d[g]|0)+(c[9653856+(i<<2)>>2]|0)<<1)>>1]=b[4853900]|0;i=f+432|0;c[i>>2]=(c[i>>2]|0)-(263170>>>((c[f+444>>2]|0)>>>0)&127);return}function gbZ(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=f+442|0;a[g]=(a[g]|0)-1&255;g=f+295|0;h=(e[f+((d[g]|0)+6<<1)>>1]|0)<<4;i=f+260|0;j=b[i>>1]|0;b[i>>1]=j+1&65535;i=(h+(j&65535)^c[f+256>>2])&1048575;j=c[3531864]|0;h=c[j+6188+(i>>>11<<2)>>2]|0;if((h|0)==0){k=gj[c[j+8236>>2]&4095](i)|0}else{k=a[h+i|0]|0}i=k&255;if((k&255)>191){k=b[f+((d[g]|0)+(c[9649760+(i<<2)>>2]|0)<<1)>>1]|0;h=f+432|0;c[h>>2]=(c[h>>2]|0)-2;l=k}else{k=c[678944+(i<<2)>>2]|0;gj[k&4095](f)|0;k=f9x(f,c[2426954]|0)|0;h=f+432|0;c[h>>2]=(c[h>>2]|0)-(((c[2426954]&1|0)!=0?986887:985861)>>>((c[f+444>>2]|0)>>>0)&127);l=k}k=i&56;if((k|0)==24){b[f+((d[g]|0)+4<<1)>>1]=l;m=f+352|0;a[m]=1;return}else if((k|0)==0){b[f+((d[g]|0)+7<<1)>>1]=l;m=f+352|0;a[m]=1;return}else if((k|0)==8){b[f+((d[g]|0)+6<<1)>>1]=l;m=f+352|0;a[m]=1;return}else if((k|0)==16){b[f+((d[g]|0)+5<<1)>>1]=l;m=f+352|0;a[m]=1;return}else{m=f+352|0;a[m]=1;return}}function gb_(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=f+442|0;a[g]=(a[g]|0)-1&255;g=f+295|0;h=a[g]|0;i=(e[f+((h&255)+6<<1)>>1]|0)<<4;j=f+260|0;k=b[j>>1]|0;b[j>>1]=k+1&65535;j=(i+(k&65535)^c[f+256>>2])&1048575;k=c[3531864]|0;i=c[k+6188+(j>>>11<<2)>>2]|0;if((i|0)==0){l=gj[c[k+8236>>2]&4095](j)|0;m=l;n=a[g]|0}else{m=a[i+j|0]|0;n=h}h=m&255;j=f+((n&255)+11<<1)|0;b[j>>1]=(b[j>>1]|0)+2&65535;j=d[g]|0;n=f9x(f,((e[f+(j+11<<1)>>1]|0)+65534&65535)+((e[f+(j+5<<1)>>1]|0)<<4)|0)|0;if((m&255)>191){b[f+((d[g]|0)+(c[9649760+(h<<2)>>2]|0)<<1)>>1]=n;o=f+432|0;p=c[o>>2]|0;q=p-21|0;c[o>>2]=q;return}else{g=c[678944+(h<<2)>>2]|0;gj[g&4095](f)|0;f9z(f,c[2426954]|0,n);o=f+432|0;p=c[o>>2]|0;q=p-21|0;c[o>>2]=q;return}}function gb$(a){a=a|0;var b=0;b=a+432|0;c[b>>2]=(c[b>>2]|0)-3;return}function gb0(a){a=a|0;var e=0,f=0,g=0,h=0;e=a+295|0;f=d[e]|0;g=a+(f+14<<1)|0;h=b[g>>1]|0;b[g>>1]=b[a+(f+15<<1)>>1]|0;b[a+((d[e]|0)+15<<1)>>1]=h;h=a+432|0;c[h>>2]=(c[h>>2]|0)-3;return}function gb1(a){a=a|0;var e=0,f=0,g=0,h=0;e=a+295|0;f=d[e]|0;g=a+(f+13<<1)|0;h=b[g>>1]|0;b[g>>1]=b[a+(f+15<<1)>>1]|0;b[a+((d[e]|0)+15<<1)>>1]=h;h=a+432|0;c[h>>2]=(c[h>>2]|0)-3;return}function gb2(a){a=a|0;var e=0,f=0,g=0,h=0;e=a+295|0;f=d[e]|0;g=a+(f+12<<1)|0;h=b[g>>1]|0;b[g>>1]=b[a+(f+15<<1)>>1]|0;b[a+((d[e]|0)+15<<1)>>1]=h;h=a+432|0;c[h>>2]=(c[h>>2]|0)-3;return}function gb3(a){a=a|0;var e=0,f=0,g=0,h=0;e=a+295|0;f=d[e]|0;g=a+(f+11<<1)|0;h=b[g>>1]|0;b[g>>1]=b[a+(f+15<<1)>>1]|0;b[a+((d[e]|0)+15<<1)>>1]=h;h=a+432|0;c[h>>2]=(c[h>>2]|0)-3;return}function gb4(a){a=a|0;var e=0,f=0,g=0,h=0;e=a+295|0;f=d[e]|0;g=a+(f+10<<1)|0;h=b[g>>1]|0;b[g>>1]=b[a+(f+15<<1)>>1]|0;b[a+((d[e]|0)+15<<1)>>1]=h;h=a+432|0;c[h>>2]=(c[h>>2]|0)-3;return}function gb5(a){a=a|0;var e=0,f=0,g=0,h=0;e=a+295|0;f=d[e]|0;g=a+(f+9<<1)|0;h=b[g>>1]|0;b[g>>1]=b[a+(f+15<<1)>>1]|0;b[a+((d[e]|0)+15<<1)>>1]=h;h=a+432|0;c[h>>2]=(c[h>>2]|0)-3;return}function gb6(a){a=a|0;var e=0,f=0,g=0,h=0;e=a+295|0;f=d[e]|0;g=a+(f+8<<1)|0;h=b[g>>1]|0;b[g>>1]=b[a+(f+15<<1)>>1]|0;b[a+((d[e]|0)+15<<1)>>1]=h;h=a+432|0;c[h>>2]=(c[h>>2]|0)-3;return}function gb7(b){b=b|0;var e=0,f=0;e=d[b+296|0]|0;f=b;a[f+(e+31)|0]=a[f+(e+30)|0]>>7;e=b+432|0;c[e>>2]=(c[e>>2]|0)-2;return}function gb8(e){e=e|0;var f=0;b[e+((d[e+295|0]|0)+13<<1)>>1]=a[e+((d[e+296|0]|0)+31)|0]>>7<<24>>24;f=e+432|0;c[f>>2]=(c[f>>2]|0)-4;return}function gb9(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;g=f+442|0;h=(a[g]|0)-1&255;a[g]=h;i=f+295|0;j=a[i]|0;k=(e[f+((j&255)+6<<1)>>1]|0)<<4;l=f+260|0;m=b[l>>1]|0;n=m+1&65535;b[l>>1]=n;o=f+256|0;p=c[o>>2]|0;q=(k+(m&65535)^p)&1048575;m=c[3531864]|0;k=c[m+6188+(q>>>11<<2)>>2]|0;if((k|0)==0){r=gj[c[m+8236>>2]&4095](q)|0;s=r;t=a[g]|0;u=a[i]|0;v=b[l>>1]|0;w=c[o>>2]|0;x=c[3531864]|0}else{s=a[k+q|0]|0;t=h;u=j;v=n;w=p;x=m}m=t-1&255;a[g]=m;t=(e[f+((u&255)+6<<1)>>1]|0)<<4;p=v+1&65535;b[l>>1]=p;n=(t+(v&65535)^w)&1048575;v=c[x+6188+(n>>>11<<2)>>2]|0;if((v|0)==0){t=gj[c[x+8236>>2]&4095](n)|0;y=t;z=a[g]|0;A=a[i]|0;B=b[l>>1]|0;C=c[o>>2]|0;D=c[3531864]|0}else{y=a[v+n|0]|0;z=m;A=u;B=p;C=w;D=x}x=z-1&255;a[g]=x;z=(e[f+((A&255)+6<<1)>>1]|0)<<4;w=B+1&65535;b[l>>1]=w;p=(z+(B&65535)^C)&1048575;B=c[D+6188+(p>>>11<<2)>>2]|0;if((B|0)==0){z=gj[c[D+8236>>2]&4095](p)|0;E=z;F=a[g]|0;G=a[i]|0;H=b[l>>1]|0;I=c[o>>2]|0;J=c[3531864]|0}else{E=a[B+p|0]|0;F=x;G=A;H=w;I=C;J=D}a[g]=F-1&255;F=(e[f+((G&255)+6<<1)>>1]|0)<<4;b[l>>1]=H+1&65535;g=(F+(H&65535)^I)&1048575;I=c[J+6188+(g>>>11<<2)>>2]|0;if((I|0)==0){H=gj[c[J+8236>>2]&4095](g)|0;K=H;L=a[i]|0}else{K=a[I+g|0]|0;L=G}G=f+((L&255)+11<<1)|0;b[G>>1]=(b[G>>1]|0)-2&65535;G=d[i]|0;f9z(f,((e[f+(G+5<<1)>>1]|0)<<4)+(e[f+(G+11<<1)>>1]|0)|0,b[f+(G+6<<1)>>1]|0);G=f+((d[i]|0)+11<<1)|0;b[G>>1]=(b[G>>1]|0)-2&65535;G=d[i]|0;f9z(f,((e[f+(G+5<<1)>>1]|0)<<4)+(e[f+(G+11<<1)>>1]|0)|0,b[l>>1]|0);b[l>>1]=(y&255)<<8|s&255;b[f+((d[i]|0)+6<<1)>>1]=(K&255)<<8|E&255;a[f+443|0]=1;E=f+432|0;c[E>>2]=(c[E>>2]|0)-(((b[f+((d[i]|0)+11<<1)>>1]&1)!=0?1907981:1905929)>>>((c[f+444>>2]|0)>>>0)&127);return}function gca(a){a=a|0;var d=0;if((c[a+332>>2]|0)==0){d=a+260|0;b[d>>1]=(b[d>>1]|0)-1&65535}d=a+432|0;c[d>>2]=(c[d>>2]|0)-5;return}function gcb(a){a=a|0;var f=0,g=0,h=0,i=0;f=a+295|0;g=d[f]|0;h=((d[a+288|0]|0)<<1|(c[a+280>>2]|0)!=0|(d[9760944+(c[a+284>>2]&255)|0]|0)<<2|(d[a+289|0]|0)<<3|((c[a+268>>2]|0)!=0)<<4|(d[a+290|0]|0)<<5|((c[a+276>>2]|0)==0)<<6|(c[a+264>>2]|0)>>>31<<7|(d[a+291|0]|0)<<8|(d[a+292|0]|0)<<9|(d[a+293|0]|0)<<10|((c[a+272>>2]|0)!=0)<<11|g>>>4<<12|(d[a+294|0]|0)<<15)&65535;i=a+(g+11<<1)|0;b[i>>1]=(b[i>>1]|0)-2&65535;i=d[f]|0;f9z(a,((e[a+(i+5<<1)>>1]|0)<<4)+(e[a+(i+11<<1)>>1]|0)|0,h);h=a+432|0;c[h>>2]=(c[h>>2]|0)-(788483>>>((c[a+444>>2]|0)>>>0)&127);return}function gcc(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=f+295|0;h=f+((d[g]|0)+11<<1)|0;b[h>>1]=(b[h>>1]|0)+2&65535;h=d[g]|0;i=f9x(f,((e[f+(h+11<<1)>>1]|0)+65534&65535)+((e[f+(h+5<<1)>>1]|0)<<4)|0)|0;h=i&65535;c[f+280>>2]=h&1;a[f+288|0]=(i&65535)>>>1&1;c[f+284>>2]=h>>>2&1^1;a[f+289|0]=(i&65535)>>>3&1;c[f+268>>2]=h&16;a[f+290|0]=(i&65535)>>>5&1;c[f+276>>2]=h>>>6&1^1;c[f+264>>2]=h<<24>>31;j=(i&65535)>>>8&1;a[f+291|0]=j;a[f+292|0]=(i&65535)>>>9&1;a[f+293|0]=(i&65535)>>>10&1;c[f+272>>2]=h&2048;h=(i&65535)>>>15&255;i=f+294|0;a[i]=h;k=f+432|0;c[k>>2]=(c[k>>2]|0)-(788485>>>((c[f+444>>2]|0)>>>0)&127);if(j<<24>>24==0){return}j=f+442|0;a[j]=(a[j]|0)-1&255;j=(e[f+((d[g]|0)+6<<1)>>1]|0)<<4;g=f+260|0;k=b[g>>1]|0;b[g>>1]=k+1&65535;g=(j+(k&65535)^c[f+256>>2])&1048575;k=c[3531864]|0;j=c[k+4140+(g>>>11<<2)>>2]|0;if((j|0)==0){l=gj[c[k+8236>>2]&4095](g)|0;m=l;n=a[i]|0}else{m=a[j+g|0]|0;n=h}do{if(n<<24>>24==0){h=c[f+436>>2]|0;if((h|0)==0){o=m;break}o=a[h+(m&255)|0]|0}else{o=m}}while(0);gf[c[2519504+((o&255)<<2)>>2]&2047](f);gd0(f,1,0);return}function gcd(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;e=b+280|0;f=b+288|0;g=b+284|0;h=b+289|0;i=b+268|0;j=b+290|0;k=b+276|0;l=b+264|0;m=b+291|0;n=(d[f]|0)<<1|(c[e>>2]|0)!=0|(d[9760944+(c[g>>2]&255)|0]|0)<<2|(d[h]|0)<<3|((c[i>>2]|0)!=0)<<4|(d[j]|0)<<5|((c[k>>2]|0)==0)<<6|(c[l>>2]|0)>>>31<<7|(d[m]|0)<<8;o=b+292|0;p=n|(d[o]|0)<<9;q=b+293|0;r=p|(d[q]|0)<<10;s=b+272|0;t=((c[s>>2]|0)!=0)<<11;u=b+294|0;v=(d[b+295|0]|0)>>>4<<12|r|(d[u]|0)<<15;w=d[b+((d[b+296|0]|0)+31)|0]|0;c[e>>2]=w&1;a[f]=0;c[g>>2]=w>>>2&1^1;a[h]=0;c[i>>2]=w&16;a[j]=0;c[k>>2]=w>>>6&1^1;c[l>>2]=w<<24>>31;a[m]=n>>>8&1;a[o]=p>>>9&1;a[q]=r>>>10&1;c[s>>2]=r&2048|t;a[u]=v>>>15&1;v=b+432|0;c[v>>2]=(c[v>>2]|0)-(197378>>>((c[b+444>>2]|0)>>>0)&127);return}function gce(b){b=b|0;var e=0;a[b+((d[b+296|0]|0)+31)|0]=((d[b+288|0]|0)<<1|(c[b+280>>2]|0)!=0|(d[9760944+(c[b+284>>2]&255)|0]|0)<<2|(d[b+289|0]|0)<<3|((c[b+268>>2]|0)!=0)<<4|(d[b+290|0]|0)<<5|((c[b+276>>2]|0)==0)<<6|(c[b+264>>2]|0)>>>31<<7)&255;e=b+432|0;c[e>>2]=(c[e>>2]|0)-(197378>>>((c[b+444>>2]|0)>>>0)&127);return}function gcf(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;g=f+442|0;h=(a[g]|0)-1&255;a[g]=h;i=f+295|0;j=a[i]|0;k=e[f+((j&255)+6<<1)>>1]<<4;l=f+260|0;m=b[l>>1]|0;n=m+1&65535;b[l>>1]=n;o=f+256|0;p=c[o>>2]|0;q=(k+(m&65535)^p)&1048575;m=c[3531864]|0;k=c[m+6188+(q>>>11<<2)>>2]|0;if((k|0)==0){r=gj[c[m+8236>>2]&4095](q)|0;s=r;t=a[g]|0;u=a[i]|0;v=b[l>>1]|0;w=c[o>>2]|0;x=c[3531864]|0}else{s=a[k+q|0]|0;t=h;u=j;v=n;w=p;x=m}a[g]=t-1&255;t=e[f+((u&255)+6<<1)>>1]<<4;b[l>>1]=v+1&65535;l=(t+(v&65535)^w)&1048575;w=c[x+6188+(l>>>11<<2)>>2]|0;if((w|0)==0){y=gj[c[x+8236>>2]&4095](l)|0}else{y=a[w+l|0]|0}if((a[f+452|0]|0)==0){z=e[f+((d[i]|0)+4<<1)>>1]<<4}else{z=c[f+448>>2]|0}i=z+(((y&255)<<8|s&255)&65535)|0;do{if((i&1048064|0)==(c[f+428>>2]|0)|(i|0)==1048575){s=i&511;if((a[f+424|0]|0)!=0&s>>>0<256){A=a[f+s|0]|0;break}if(s>>>0<=255){B=51881;break}A=f9w(f,s-256|0)|0}else{B=51881}}while(0);do{if((B|0)==51881){s=i&1048575;y=c[3531864]|0;z=c[y+44+(s>>>11<<2)>>2]|0;if((z|0)==0){A=gj[c[y+8236>>2]&4095](s)|0;break}else{A=a[z+s|0]|0;break}}}while(0);a[f+((d[f+296|0]|0)+30)|0]=A;A=f+432|0;c[A>>2]=(c[A>>2]|0)-(657925>>>((c[f+444>>2]|0)>>>0)&127);return}function gcg(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;g=f+442|0;h=(a[g]|0)-1&255;a[g]=h;i=f+295|0;j=a[i]|0;k=e[f+((j&255)+6<<1)>>1]<<4;l=f+260|0;m=b[l>>1]|0;n=m+1&65535;b[l>>1]=n;o=f+256|0;p=c[o>>2]|0;q=(k+(m&65535)^p)&1048575;m=c[3531864]|0;k=c[m+6188+(q>>>11<<2)>>2]|0;if((k|0)==0){r=gj[c[m+8236>>2]&4095](q)|0;s=r;t=a[g]|0;u=a[i]|0;v=b[l>>1]|0;w=c[o>>2]|0;x=c[3531864]|0}else{s=a[k+q|0]|0;t=h;u=j;v=n;w=p;x=m}a[g]=t-1&255;t=e[f+((u&255)+6<<1)>>1]<<4;b[l>>1]=v+1&65535;l=(t+(v&65535)^w)&1048575;w=c[x+6188+(l>>>11<<2)>>2]|0;if((w|0)==0){y=gj[c[x+8236>>2]&4095](l)|0}else{y=a[w+l|0]|0}l=((y&255)<<8|s&255)&65535;if((a[f+452|0]|0)==0){z=e[f+((d[i]|0)+4<<1)>>1]<<4}else{z=c[f+448>>2]|0}s=f9x(f,z+l|0)|0;b[f+((d[i]|0)+15<<1)>>1]=s;s=f+432|0;c[s>>2]=(c[s>>2]|0)-(((l&1|0)!=0?921095:920069)>>>((c[f+444>>2]|0)>>>0)&127);return}function gch(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;g=f+442|0;h=(a[g]|0)-1&255;a[g]=h;i=f+295|0;j=a[i]|0;k=e[f+((j&255)+6<<1)>>1]<<4;l=f+260|0;m=b[l>>1]|0;n=m+1&65535;b[l>>1]=n;o=f+256|0;p=c[o>>2]|0;q=(k+(m&65535)^p)&1048575;m=c[3531864]|0;k=c[m+6188+(q>>>11<<2)>>2]|0;if((k|0)==0){r=gj[c[m+8236>>2]&4095](q)|0;s=r;t=a[g]|0;u=a[i]|0;v=b[l>>1]|0;w=c[o>>2]|0;x=c[3531864]|0}else{s=a[k+q|0]|0;t=h;u=j;v=n;w=p;x=m}a[g]=t-1&255;t=e[f+((u&255)+6<<1)>>1]<<4;b[l>>1]=v+1&65535;l=(t+(v&65535)^w)&1048575;w=c[x+6188+(l>>>11<<2)>>2]|0;if((w|0)==0){y=gj[c[x+8236>>2]&4095](l)|0}else{y=a[w+l|0]|0}if((a[f+452|0]|0)==0){z=e[f+((d[i]|0)+4<<1)>>1]<<4}else{z=c[f+448>>2]|0}i=z+(((y&255)<<8|s&255)&65535)|0;s=f;y=a[s+((d[f+296|0]|0)+30)|0]|0;do{if((i&1048064|0)==(c[f+428>>2]|0)|(i|0)==1048575){z=i&511;if((a[f+424|0]|0)!=0&z>>>0<256){a[s+z|0]=y;break}if(z>>>0<=255){A=51909;break}f9y(f,z-256|0,y)}else{A=51909}}while(0);do{if((A|0)==51909){s=i&1048575;z=c[3531864]|0;l=c[z+2092+(s>>>11<<2)>>2]|0;if((l|0)==0){gg[c[z+8240>>2]&4095](s,y);break}else{a[l+s|0]=y;break}}}while(0);y=f+432|0;c[y>>2]=(c[y>>2]|0)-(592131>>>((c[f+444>>2]|0)>>>0)&127);return}function gci(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;f=d+442|0;g=(a[f]|0)-1&255;a[f]=g;h=d+295|0;i=a[h]|0;j=e[d+((i&255)+6<<1)>>1]<<4;k=d+260|0;l=b[k>>1]|0;m=l+1&65535;b[k>>1]=m;n=d+256|0;o=c[n>>2]|0;p=(j+(l&65535)^o)&1048575;l=c[3531864]|0;j=c[l+6188+(p>>>11<<2)>>2]|0;if((j|0)==0){q=gj[c[l+8236>>2]&4095](p)|0;r=q;s=a[f]|0;t=a[h]|0;u=b[k>>1]|0;v=c[n>>2]|0;w=c[3531864]|0}else{r=a[j+p|0]|0;s=g;t=i;u=m;v=o;w=l}a[f]=s-1&255;s=e[d+((t&255)+6<<1)>>1]<<4;b[k>>1]=u+1&65535;k=(s+(u&65535)^v)&1048575;v=c[w+6188+(k>>>11<<2)>>2]|0;if((v|0)==0){x=gj[c[w+8236>>2]&4095](k)|0}else{x=a[v+k|0]|0}k=((x&255)<<8|r&255)&65535;if((a[d+452|0]|0)==0){r=a[h]|0;y=e[d+((r&255)+4<<1)>>1]<<4;z=r;A=y+k|0;B=z&255;C=B+15|0;D=d+(C<<1)|0;E=b[D>>1]|0;f9z(d,A,E);F=k&1;G=(F|0)!=0;H=d+444|0;I=c[H>>2]|0;J=G?855301:854275;K=J>>>(I>>>0);L=K&127;M=d+432|0;N=c[M>>2]|0;O=N-L|0;c[M>>2]=O;return}else{y=c[d+448>>2]|0;z=a[h]|0;A=y+k|0;B=z&255;C=B+15|0;D=d+(C<<1)|0;E=b[D>>1]|0;f9z(d,A,E);F=k&1;G=(F|0)!=0;H=d+444|0;I=c[H>>2]|0;J=G?855301:854275;K=J>>>(I>>>0);L=K&127;M=d+432|0;N=c[M>>2]|0;O=N-L|0;c[M>>2]=O;return}}function gcj(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((a[f+452|0]|0)==0){g=a[f+295|0]|0;h=e[f+((g&255)+4<<1)>>1]<<4;i=g}else{h=c[f+448>>2]|0;i=a[f+295|0]|0}g=f+295|0;j=(e[f+((i&255)+9<<1)>>1]|0)+h|0;h=f+428|0;do{if((j&1048064|0)==(c[h>>2]|0)|(j|0)==1048575){i=j&511;if((a[f+424|0]|0)!=0&i>>>0<256){k=a[f+i|0]|0;break}if(i>>>0<=255){l=51933;break}k=f9w(f,i-256|0)|0}else{l=51933}}while(0);do{if((l|0)==51933){i=j&1048575;m=c[3531864]|0;n=c[m+44+(i>>>11<<2)>>2]|0;if((n|0)==0){k=gj[c[m+8236>>2]&4095](i)|0;break}else{k=a[n+i|0]|0;break}}}while(0);j=d[g]|0;i=(e[f+(j+7<<1)>>1]<<4)+(e[f+(j+8<<1)>>1]|0)|0;do{if((i&1048064|0)==(c[h>>2]|0)|(i|0)==1048575){j=i&511;if((a[f+424|0]|0)!=0&j>>>0<256){a[f+j|0]=k;break}if(j>>>0<=255){l=51941;break}f9y(f,j-256|0,k)}else{l=51941}}while(0);do{if((l|0)==51941){h=i&1048575;j=c[3531864]|0;n=c[j+2092+(h>>>11<<2)>>2]|0;if((n|0)==0){gg[c[j+8240>>2]&4095](h,k);break}else{a[n+h|0]=k;break}}}while(0);k=f+293|0;i=f+((d[g]|0)+8<<1)|0;b[i>>1]=((d[k]|0)*-2&65535|1)+(b[i>>1]|0)&65535;i=f+((d[g]|0)+9<<1)|0;b[i>>1]=((d[k]|0)*-2&65535|1)+(b[i>>1]|0)&65535;i=f+432|0;c[i>>2]=(c[i>>2]|0)-(526342>>>((c[f+444>>2]|0)>>>0)&127);return}function gck(f){f=f|0;var g=0,h=0,i=0,j=0;if((a[f+452|0]|0)==0){g=a[f+295|0]|0;h=e[f+((g&255)+4<<1)>>1]<<4;i=g}else{h=c[f+448>>2]|0;i=a[f+295|0]|0}g=f+295|0;j=f9x(f,(e[f+((i&255)+9<<1)>>1]|0)+h|0)|0;h=d[g]|0;f9z(f,(e[f+(h+7<<1)>>1]<<4)+(e[f+(h+8<<1)>>1]|0)|0,j);j=f+293|0;h=f+((d[g]|0)+8<<1)|0;b[h>>1]=((d[j]|0)*-4&65535|2)+(b[h>>1]|0)&65535;h=f+((d[g]|0)+9<<1)|0;b[h>>1]=((d[j]|0)*-4&65535|2)+(b[h>>1]|0)&65535;h=f+432|0;c[h>>2]=(c[h>>2]|0)-(1052682>>>((c[f+444>>2]|0)>>>0)&127);return}function gcl(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=f+452|0;h=f+295|0;i=d[h]|0;j=(e[f+(i+7<<1)>>1]<<4)+(e[f+(i+8<<1)>>1]|0)|0;i=f+428|0;do{if((j&1048064|0)==(c[i>>2]|0)|(j|0)==1048575){k=j&511;if((a[f+424|0]|0)!=0&k>>>0<256){l=a[f+k|0]|0;break}if(k>>>0<=255){m=51954;break}l=f9w(f,k-256|0)|0}else{m=51954}}while(0);do{if((m|0)==51954){k=j&1048575;n=c[3531864]|0;o=c[n+44+(k>>>11<<2)>>2]|0;if((o|0)==0){l=gj[c[n+8236>>2]&4095](k)|0;break}else{l=a[o+k|0]|0;break}}}while(0);j=l&255;if((a[g]|0)==0){g=a[h]|0;p=e[f+((g&255)+4<<1)>>1]<<4;q=g}else{p=c[f+448>>2]|0;q=a[h]|0}g=(e[f+((q&255)+9<<1)>>1]|0)+p|0;do{if((g&1048064|0)==(c[i>>2]|0)|(g|0)==1048575){p=g&511;if((a[f+424|0]|0)!=0&p>>>0<256){r=a[f+p|0]|0;break}if(p>>>0<=255){m=51965;break}r=f9w(f,p-256|0)|0}else{m=51965}}while(0);do{if((m|0)==51965){i=g&1048575;p=c[3531864]|0;q=c[p+44+(i>>>11<<2)>>2]|0;if((q|0)==0){r=gj[c[p+8236>>2]&4095](i)|0;break}else{r=a[q+i|0]|0;break}}}while(0);g=r&255;m=g-j|0;c[f+280>>2]=m&256;j=(r^l)&255;c[f+272>>2]=j&128&(m^g);c[f+268>>2]=(m^j)&16;j=m<<24>>24;c[f+284>>2]=j;c[f+276>>2]=j;c[f+264>>2]=j;j=f+293|0;m=f+((d[h]|0)+8<<1)|0;b[m>>1]=((d[j]|0)*-2&65535|1)+(b[m>>1]|0)&65535;m=f+((d[h]|0)+9<<1)|0;b[m>>1]=((d[j]|0)*-2&65535|1)+(b[m>>1]|0)&65535;m=f+432|0;c[m>>2]=(c[m>>2]|0)-(921102>>>((c[f+444>>2]|0)>>>0)&127);return}function gcm(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;g=f+295|0;h=d[g]|0;i=f9x(f,(e[f+(h+7<<1)>>1]<<4)+(e[f+(h+8<<1)>>1]|0)|0)|0;if((a[f+452|0]|0)==0){h=a[g]|0;j=e[f+((h&255)+4<<1)>>1]<<4;k=h}else{j=c[f+448>>2]|0;k=a[g]|0}h=f9x(f,(e[f+((k&255)+9<<1)>>1]|0)+j|0)|0;j=h&65535;k=j-(i&65535)|0;c[f+280>>2]=k&65536;l=(h^i)&65535;c[f+272>>2]=l&32768&(k^j);c[f+268>>2]=(k^l)&16;l=k<<16>>16;c[f+284>>2]=l;c[f+276>>2]=l;c[f+264>>2]=l;l=f+293|0;k=f+((d[g]|0)+8<<1)|0;b[k>>1]=((d[l]|0)*-4&65535|2)+(b[k>>1]|0)&65535;k=f+((d[g]|0)+9<<1)|0;b[k>>1]=((d[l]|0)*-4&65535|2)+(b[k>>1]|0)&65535;k=f+432|0;c[k>>2]=(c[k>>2]|0)-(921102>>>((c[f+444>>2]|0)>>>0)&127);return}function gcn(f){f=f|0;var g=0,h=0,i=0,j=0;g=f+442|0;a[g]=(a[g]|0)-1&255;g=(e[f+((d[f+295|0]|0)+6<<1)>>1]|0)<<4;h=f+260|0;i=b[h>>1]|0;b[h>>1]=i+1&65535;h=(g+(i&65535)^c[f+256>>2])&1048575;i=c[3531864]|0;g=c[i+6188+(h>>>11<<2)>>2]|0;if((g|0)==0){j=gj[c[i+8236>>2]&4095](h)|0}else{j=a[g+h|0]|0}h=a[f+((d[f+296|0]|0)+30)|0]&j;c[f+268>>2]=0;c[f+272>>2]=0;c[f+280>>2]=0;j=h<<24>>24;c[f+284>>2]=j;c[f+276>>2]=j;c[f+264>>2]=j;j=f+432|0;c[j>>2]=(c[j>>2]|0)-(263170>>>((c[f+444>>2]|0)>>>0)&127);return}function gco(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;f=d+442|0;g=(a[f]|0)-1&255;a[f]=g;h=d+295|0;i=a[h]|0;j=(e[d+((i&255)+6<<1)>>1]|0)<<4;k=d+260|0;l=b[k>>1]|0;m=l+1&65535;b[k>>1]=m;n=d+256|0;o=c[n>>2]|0;p=(j+(l&65535)^o)&1048575;l=c[3531864]|0;j=c[l+6188+(p>>>11<<2)>>2]|0;if((j|0)==0){q=gj[c[l+8236>>2]&4095](p)|0;r=q;s=a[h]|0;t=a[f]|0;u=b[k>>1]|0;v=c[n>>2]|0;w=c[3531864]|0}else{r=a[j+p|0]|0;s=i;t=g;u=m;v=o;w=l}l=s&255;s=b[d+(l+15<<1)>>1]|0;a[f]=t-1&255;t=(e[d+(l+6<<1)>>1]|0)<<4;b[k>>1]=u+1&65535;k=(t+(u&65535)^v)&1048575;v=c[w+6188+(k>>>11<<2)>>2]|0;if((v|0)==0){x=gj[c[w+8236>>2]&4095](k)|0}else{x=a[v+k|0]|0}c[d+268>>2]=0;c[d+272>>2]=0;c[d+280>>2]=0;k=(((x&255)<<8|r&255)&s)<<16>>16;c[d+284>>2]=k;c[d+276>>2]=k;c[d+264>>2]=k;k=d+432|0;c[k>>2]=(c[k>>2]|0)-(263170>>>((c[d+444>>2]|0)>>>0)&127);return}function gcp(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=f+295|0;h=d[g]|0;i=(e[f+(h+7<<1)>>1]<<4)+(e[f+(h+8<<1)>>1]|0)|0;h=f;j=a[h+((d[f+296|0]|0)+30)|0]|0;do{if((i&1048064|0)==(c[f+428>>2]|0)|(i|0)==1048575){k=i&511;if((a[f+424|0]|0)!=0&k>>>0<256){a[h+k|0]=j;break}if(k>>>0<=255){l=51989;break}f9y(f,k-256|0,j)}else{l=51989}}while(0);do{if((l|0)==51989){h=i&1048575;k=c[3531864]|0;m=c[k+2092+(h>>>11<<2)>>2]|0;if((m|0)==0){gg[c[k+8240>>2]&4095](h,j);break}else{a[m+h|0]=j;break}}}while(0);j=f+((d[g]|0)+8<<1)|0;b[j>>1]=((d[f+293|0]|0)*-2&65535|1)+(b[j>>1]|0)&65535;j=f+432|0;c[j>>2]=(c[j>>2]|0)-(263171>>>((c[f+444>>2]|0)>>>0)&127);return}function gcq(a){a=a|0;var f=0,g=0;f=a+295|0;g=d[f]|0;f9z(a,((e[a+(g+7<<1)>>1]|0)<<4)+(e[a+(g+8<<1)>>1]|0)|0,b[a+(g+15<<1)>>1]|0);g=a+((d[f]|0)+8<<1)|0;b[g>>1]=((d[a+293|0]|0)*-4&65535|2)+(b[g>>1]|0)&65535;g=a+432|0;c[g>>2]=(c[g>>2]|0)-(((b[a+((d[f]|0)+8<<1)>>1]&1)!=0?526341:525315)>>>((c[a+444>>2]|0)>>>0)&127);return}function gcr(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((a[f+452|0]|0)==0){g=a[f+295|0]|0;h=e[f+((g&255)+4<<1)>>1]<<4;i=g}else{h=c[f+448>>2]|0;i=a[f+295|0]|0}g=f+295|0;j=(e[f+((i&255)+9<<1)>>1]|0)+h|0;do{if((j&1048064|0)==(c[f+428>>2]|0)|(j|0)==1048575){h=j&511;if((a[f+424|0]|0)!=0&h>>>0<256){k=a[f+h|0]|0;break}if(h>>>0<=255){l=52002;break}k=f9w(f,h-256|0)|0}else{l=52002}}while(0);do{if((l|0)==52002){h=j&1048575;i=c[3531864]|0;m=c[i+44+(h>>>11<<2)>>2]|0;if((m|0)==0){k=gj[c[i+8236>>2]&4095](h)|0;break}else{k=a[m+h|0]|0;break}}}while(0);a[f+((d[f+296|0]|0)+30)|0]=k;k=f+((d[g]|0)+9<<1)|0;b[k>>1]=((d[f+293|0]|0)*-2&65535|1)+(b[k>>1]|0)&65535;k=f+432|0;c[k>>2]=(c[k>>2]|0)-(263171>>>((c[f+444>>2]|0)>>>0)&127);return}function gcs(f){f=f|0;var g=0,h=0,i=0,j=0;if((a[f+452|0]|0)==0){g=a[f+295|0]|0;h=e[f+((g&255)+4<<1)>>1]<<4;i=g}else{h=c[f+448>>2]|0;i=a[f+295|0]|0}g=f+295|0;j=f9x(f,(e[f+((i&255)+9<<1)>>1]|0)+h|0)|0;b[f+((d[g]|0)+15<<1)>>1]=j;j=f+((d[g]|0)+9<<1)|0;b[j>>1]=((d[f+293|0]|0)*-4&65535|2)+(b[j>>1]|0)&65535;j=f+432|0;c[j>>2]=(c[j>>2]|0)-(((b[f+((d[g]|0)+9<<1)>>1]&1)!=0?526341:525315)>>>((c[f+444>>2]|0)>>>0)&127);return}function gct(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=f+295|0;h=d[g]|0;i=(e[f+(h+7<<1)>>1]<<4)+(e[f+(h+8<<1)>>1]|0)|0;do{if((i&1048064|0)==(c[f+428>>2]|0)|(i|0)==1048575){h=i&511;if((a[f+424|0]|0)!=0&h>>>0<256){j=a[f+h|0]|0;break}if(h>>>0<=255){k=52015;break}j=f9w(f,h-256|0)|0}else{k=52015}}while(0);do{if((k|0)==52015){h=i&1048575;l=c[3531864]|0;m=c[l+44+(h>>>11<<2)>>2]|0;if((m|0)==0){j=gj[c[l+8236>>2]&4095](h)|0;break}else{j=a[m+h|0]|0;break}}}while(0);i=a[f+((d[f+296|0]|0)+30)|0]|0;k=i&255;h=k-(j&255)|0;c[f+280>>2]=h&256;m=(i^j)&255;c[f+272>>2]=m&128&(h^k);c[f+268>>2]=(h^m)&16;m=h<<24>>24;c[f+284>>2]=m;c[f+276>>2]=m;c[f+264>>2]=m;m=f+((d[g]|0)+8<<1)|0;b[m>>1]=((d[f+293|0]|0)*-2&65535|1)+(b[m>>1]|0)&65535;m=f+432|0;c[m>>2]=(c[m>>2]|0)-(263171>>>((c[f+444>>2]|0)>>>0)&127);return}function gcu(a){a=a|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=a+295|0;g=d[f]|0;h=f9x(a,((e[a+(g+7<<1)>>1]|0)<<4)+(e[a+(g+8<<1)>>1]|0)|0)|0;g=d[f]|0;i=b[a+(g+15<<1)>>1]|0;j=i&65535;k=j-(h&65535)|0;c[a+280>>2]=k&65536;l=(i^h)&65535;c[a+272>>2]=l&32768&(k^j);c[a+268>>2]=(k^l)&16;l=k<<16>>16;c[a+284>>2]=l;c[a+276>>2]=l;c[a+264>>2]=l;l=a+(g+8<<1)|0;b[l>>1]=((d[a+293|0]|0)*-4&65535|2)+(b[l>>1]|0)&65535;l=a+432|0;c[l>>2]=(c[l>>2]|0)-(((b[a+((d[f]|0)+8<<1)>>1]&1)!=0?526341:525315)>>>((c[a+444>>2]|0)>>>0)&127);return}function gcv(f){f=f|0;var g=0,h=0,i=0,j=0;g=f+442|0;a[g]=(a[g]|0)-1&255;g=(e[f+((d[f+295|0]|0)+6<<1)>>1]|0)<<4;h=f+260|0;i=b[h>>1]|0;b[h>>1]=i+1&65535;h=(g+(i&65535)^c[f+256>>2])&1048575;i=c[3531864]|0;g=c[i+6188+(h>>>11<<2)>>2]|0;if((g|0)==0){j=gj[c[i+8236>>2]&4095](h)|0}else{j=a[g+h|0]|0}a[f+((d[f+296|0]|0)+30)|0]=j;j=f+432|0;c[j>>2]=(c[j>>2]|0)-(263170>>>((c[f+444>>2]|0)>>>0)&127);return}function gcw(f){f=f|0;var g=0,h=0,i=0,j=0;g=f+442|0;a[g]=(a[g]|0)-1&255;g=(e[f+((d[f+295|0]|0)+6<<1)>>1]|0)<<4;h=f+260|0;i=b[h>>1]|0;b[h>>1]=i+1&65535;h=(g+(i&65535)^c[f+256>>2])&1048575;i=c[3531864]|0;g=c[i+6188+(h>>>11<<2)>>2]|0;if((g|0)==0){j=gj[c[i+8236>>2]&4095](h)|0}else{j=a[g+h|0]|0}a[f+((d[f+296|0]|0)+28)|0]=j;j=f+432|0;c[j>>2]=(c[j>>2]|0)-(263170>>>((c[f+444>>2]|0)>>>0)&127);return}function gcx(f){f=f|0;var g=0,h=0,i=0,j=0;g=f+442|0;a[g]=(a[g]|0)-1&255;g=(e[f+((d[f+295|0]|0)+6<<1)>>1]|0)<<4;h=f+260|0;i=b[h>>1]|0;b[h>>1]=i+1&65535;h=(g+(i&65535)^c[f+256>>2])&1048575;i=c[3531864]|0;g=c[i+6188+(h>>>11<<2)>>2]|0;if((g|0)==0){j=gj[c[i+8236>>2]&4095](h)|0}else{j=a[g+h|0]|0}a[f+((d[f+296|0]|0)+26)|0]=j;j=f+432|0;c[j>>2]=(c[j>>2]|0)-(263170>>>((c[f+444>>2]|0)>>>0)&127);return}function gcy(f){f=f|0;var g=0,h=0,i=0,j=0;g=f+442|0;a[g]=(a[g]|0)-1&255;g=(e[f+((d[f+295|0]|0)+6<<1)>>1]|0)<<4;h=f+260|0;i=b[h>>1]|0;b[h>>1]=i+1&65535;h=(g+(i&65535)^c[f+256>>2])&1048575;i=c[3531864]|0;g=c[i+6188+(h>>>11<<2)>>2]|0;if((g|0)==0){j=gj[c[i+8236>>2]&4095](h)|0}else{j=a[g+h|0]|0}a[f+((d[f+296|0]|0)+24)|0]=j;j=f+432|0;c[j>>2]=(c[j>>2]|0)-(263170>>>((c[f+444>>2]|0)>>>0)&127);return}function gcz(f){f=f|0;var g=0,h=0,i=0,j=0;g=f+442|0;a[g]=(a[g]|0)-1&255;g=(e[f+((d[f+295|0]|0)+6<<1)>>1]|0)<<4;h=f+260|0;i=b[h>>1]|0;b[h>>1]=i+1&65535;h=(g+(i&65535)^c[f+256>>2])&1048575;i=c[3531864]|0;g=c[i+6188+(h>>>11<<2)>>2]|0;if((g|0)==0){j=gj[c[i+8236>>2]&4095](h)|0}else{j=a[g+h|0]|0}a[f+((d[f+296|0]|0)+31)|0]=j;j=f+432|0;c[j>>2]=(c[j>>2]|0)-(263170>>>((c[f+444>>2]|0)>>>0)&127);return}function gcA(f){f=f|0;var g=0,h=0,i=0,j=0;g=f+442|0;a[g]=(a[g]|0)-1&255;g=(e[f+((d[f+295|0]|0)+6<<1)>>1]|0)<<4;h=f+260|0;i=b[h>>1]|0;b[h>>1]=i+1&65535;h=(g+(i&65535)^c[f+256>>2])&1048575;i=c[3531864]|0;g=c[i+6188+(h>>>11<<2)>>2]|0;if((g|0)==0){j=gj[c[i+8236>>2]&4095](h)|0}else{j=a[g+h|0]|0}a[f+((d[f+296|0]|0)+29)|0]=j;j=f+432|0;c[j>>2]=(c[j>>2]|0)-(263170>>>((c[f+444>>2]|0)>>>0)&127);return}function gcB(f){f=f|0;var g=0,h=0,i=0,j=0;g=f+442|0;a[g]=(a[g]|0)-1&255;g=(e[f+((d[f+295|0]|0)+6<<1)>>1]|0)<<4;h=f+260|0;i=b[h>>1]|0;b[h>>1]=i+1&65535;h=(g+(i&65535)^c[f+256>>2])&1048575;i=c[3531864]|0;g=c[i+6188+(h>>>11<<2)>>2]|0;if((g|0)==0){j=gj[c[i+8236>>2]&4095](h)|0}else{j=a[g+h|0]|0}a[f+((d[f+296|0]|0)+27)|0]=j;j=f+432|0;c[j>>2]=(c[j>>2]|0)-(263170>>>((c[f+444>>2]|0)>>>0)&127);return}function gcC(f){f=f|0;var g=0,h=0,i=0,j=0;g=f+442|0;a[g]=(a[g]|0)-1&255;g=(e[f+((d[f+295|0]|0)+6<<1)>>1]|0)<<4;h=f+260|0;i=b[h>>1]|0;b[h>>1]=i+1&65535;h=(g+(i&65535)^c[f+256>>2])&1048575;i=c[3531864]|0;g=c[i+6188+(h>>>11<<2)>>2]|0;if((g|0)==0){j=gj[c[i+8236>>2]&4095](h)|0}else{j=a[g+h|0]|0}a[f+((d[f+296|0]|0)+25)|0]=j;j=f+432|0;c[j>>2]=(c[j>>2]|0)-(263170>>>((c[f+444>>2]|0)>>>0)&127);return}function gcD(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;g=f+442|0;a[g]=(a[g]|0)-1&255;h=f+295|0;i=(e[f+((d[h]|0)+6<<1)>>1]|0)<<4;j=f+260|0;k=b[j>>1]|0;b[j>>1]=k+1&65535;l=f+256|0;m=(i+(k&65535)^c[l>>2])&1048575;k=c[3531864]|0;i=c[k+6188+(m>>>11<<2)>>2]|0;if((i|0)==0){n=gj[c[k+8236>>2]&4095](m)|0;o=n;p=c[3531864]|0}else{o=a[i+m|0]|0;p=k}k=f+296|0;m=f;a[m+((d[k]|0)+30)|0]=o;a[g]=(a[g]|0)-1&255;g=(e[f+((d[h]|0)+6<<1)>>1]|0)<<4;h=b[j>>1]|0;b[j>>1]=h+1&65535;j=(g+(h&65535)^c[l>>2])&1048575;l=c[p+6188+(j>>>11<<2)>>2]|0;if((l|0)==0){q=gj[c[p+8236>>2]&4095](j)|0;r=a[k]|0;s=r&255;t=s+31|0;u=m+t|0;a[u]=q;v=f+444|0;w=c[v>>2]|0;x=263170>>>(w>>>0);y=x&127;z=f+432|0;A=c[z>>2]|0;B=A-y|0;c[z>>2]=B;return}else{q=a[l+j|0]|0;r=a[k]|0;s=r&255;t=s+31|0;u=m+t|0;a[u]=q;v=f+444|0;w=c[v>>2]|0;x=263170>>>(w>>>0);y=x&127;z=f+432|0;A=c[z>>2]|0;B=A-y|0;c[z>>2]=B;return}}function gcE(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;g=f+442|0;a[g]=(a[g]|0)-1&255;h=f+295|0;i=(e[f+((d[h]|0)+6<<1)>>1]|0)<<4;j=f+260|0;k=b[j>>1]|0;b[j>>1]=k+1&65535;l=f+256|0;m=(i+(k&65535)^c[l>>2])&1048575;k=c[3531864]|0;i=c[k+6188+(m>>>11<<2)>>2]|0;if((i|0)==0){n=gj[c[k+8236>>2]&4095](m)|0;o=n;p=c[3531864]|0}else{o=a[i+m|0]|0;p=k}k=f+296|0;m=f;a[m+((d[k]|0)+28)|0]=o;a[g]=(a[g]|0)-1&255;g=(e[f+((d[h]|0)+6<<1)>>1]|0)<<4;h=b[j>>1]|0;b[j>>1]=h+1&65535;j=(g+(h&65535)^c[l>>2])&1048575;l=c[p+6188+(j>>>11<<2)>>2]|0;if((l|0)==0){q=gj[c[p+8236>>2]&4095](j)|0;r=a[k]|0;s=r&255;t=s+29|0;u=m+t|0;a[u]=q;v=f+444|0;w=c[v>>2]|0;x=263170>>>(w>>>0);y=x&127;z=f+432|0;A=c[z>>2]|0;B=A-y|0;c[z>>2]=B;return}else{q=a[l+j|0]|0;r=a[k]|0;s=r&255;t=s+29|0;u=m+t|0;a[u]=q;v=f+444|0;w=c[v>>2]|0;x=263170>>>(w>>>0);y=x&127;z=f+432|0;A=c[z>>2]|0;B=A-y|0;c[z>>2]=B;return}}function gcF(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;g=f+442|0;a[g]=(a[g]|0)-1&255;h=f+295|0;i=(e[f+((d[h]|0)+6<<1)>>1]|0)<<4;j=f+260|0;k=b[j>>1]|0;b[j>>1]=k+1&65535;l=f+256|0;m=(i+(k&65535)^c[l>>2])&1048575;k=c[3531864]|0;i=c[k+6188+(m>>>11<<2)>>2]|0;if((i|0)==0){n=gj[c[k+8236>>2]&4095](m)|0;o=n;p=c[3531864]|0}else{o=a[i+m|0]|0;p=k}k=f+296|0;m=f;a[m+((d[k]|0)+26)|0]=o;a[g]=(a[g]|0)-1&255;g=(e[f+((d[h]|0)+6<<1)>>1]|0)<<4;h=b[j>>1]|0;b[j>>1]=h+1&65535;j=(g+(h&65535)^c[l>>2])&1048575;l=c[p+6188+(j>>>11<<2)>>2]|0;if((l|0)==0){q=gj[c[p+8236>>2]&4095](j)|0;r=a[k]|0;s=r&255;t=s+27|0;u=m+t|0;a[u]=q;v=f+444|0;w=c[v>>2]|0;x=263170>>>(w>>>0);y=x&127;z=f+432|0;A=c[z>>2]|0;B=A-y|0;c[z>>2]=B;return}else{q=a[l+j|0]|0;r=a[k]|0;s=r&255;t=s+27|0;u=m+t|0;a[u]=q;v=f+444|0;w=c[v>>2]|0;x=263170>>>(w>>>0);y=x&127;z=f+432|0;A=c[z>>2]|0;B=A-y|0;c[z>>2]=B;return}}function gcG(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;g=f+442|0;a[g]=(a[g]|0)-1&255;h=f+295|0;i=(e[f+((d[h]|0)+6<<1)>>1]|0)<<4;j=f+260|0;k=b[j>>1]|0;b[j>>1]=k+1&65535;l=f+256|0;m=(i+(k&65535)^c[l>>2])&1048575;k=c[3531864]|0;i=c[k+6188+(m>>>11<<2)>>2]|0;if((i|0)==0){n=gj[c[k+8236>>2]&4095](m)|0;o=n;p=c[3531864]|0}else{o=a[i+m|0]|0;p=k}k=f+296|0;m=f;a[m+((d[k]|0)+24)|0]=o;a[g]=(a[g]|0)-1&255;g=(e[f+((d[h]|0)+6<<1)>>1]|0)<<4;h=b[j>>1]|0;b[j>>1]=h+1&65535;j=(g+(h&65535)^c[l>>2])&1048575;l=c[p+6188+(j>>>11<<2)>>2]|0;if((l|0)==0){q=gj[c[p+8236>>2]&4095](j)|0;r=a[k]|0;s=r&255;t=s+25|0;u=m+t|0;a[u]=q;v=f+444|0;w=c[v>>2]|0;x=263170>>>(w>>>0);y=x&127;z=f+432|0;A=c[z>>2]|0;B=A-y|0;c[z>>2]=B;return}else{q=a[l+j|0]|0;r=a[k]|0;s=r&255;t=s+25|0;u=m+t|0;a[u]=q;v=f+444|0;w=c[v>>2]|0;x=263170>>>(w>>>0);y=x&127;z=f+432|0;A=c[z>>2]|0;B=A-y|0;c[z>>2]=B;return}}function gcH(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;f=d+442|0;g=(a[f]|0)-1&255;a[f]=g;h=d+295|0;i=a[h]|0;j=(e[d+((i&255)+6<<1)>>1]|0)<<4;k=d+260|0;l=b[k>>1]|0;m=l+1&65535;b[k>>1]=m;n=d+256|0;o=c[n>>2]|0;p=(j+(l&65535)^o)&1048575;l=c[3531864]|0;j=c[l+6188+(p>>>11<<2)>>2]|0;if((j|0)==0){q=gj[c[l+8236>>2]&4095](p)|0;r=q;s=a[f]|0;t=a[h]|0;u=b[k>>1]|0;v=c[n>>2]|0;w=c[3531864]|0}else{r=a[j+p|0]|0;s=g;t=i;u=m;v=o;w=l}a[f]=s-1&255;s=(e[d+((t&255)+6<<1)>>1]|0)<<4;b[k>>1]=u+1&65535;k=(s+(u&65535)^v)&1048575;v=c[w+6188+(k>>>11<<2)>>2]|0;if((v|0)==0){u=gj[c[w+8236>>2]&4095](k)|0;x=u;y=a[h]|0;z=x&255;A=z<<8;B=r&255;C=A|B;D=y&255;E=D+11|0;F=d+(E<<1)|0;b[F>>1]=C;G=d+444|0;H=c[G>>2]|0;I=263170>>>(H>>>0);J=I&127;K=d+432|0;L=c[K>>2]|0;M=L-J|0;c[K>>2]=M;return}else{x=a[v+k|0]|0;y=t;z=x&255;A=z<<8;B=r&255;C=A|B;D=y&255;E=D+11|0;F=d+(E<<1)|0;b[F>>1]=C;G=d+444|0;H=c[G>>2]|0;I=263170>>>(H>>>0);J=I&127;K=d+432|0;L=c[K>>2]|0;M=L-J|0;c[K>>2]=M;return}}function gcI(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;f=d+442|0;g=(a[f]|0)-1&255;a[f]=g;h=d+295|0;i=a[h]|0;j=(e[d+((i&255)+6<<1)>>1]|0)<<4;k=d+260|0;l=b[k>>1]|0;m=l+1&65535;b[k>>1]=m;n=d+256|0;o=c[n>>2]|0;p=(j+(l&65535)^o)&1048575;l=c[3531864]|0;j=c[l+6188+(p>>>11<<2)>>2]|0;if((j|0)==0){q=gj[c[l+8236>>2]&4095](p)|0;r=q;s=a[f]|0;t=a[h]|0;u=b[k>>1]|0;v=c[n>>2]|0;w=c[3531864]|0}else{r=a[j+p|0]|0;s=g;t=i;u=m;v=o;w=l}a[f]=s-1&255;s=(e[d+((t&255)+6<<1)>>1]|0)<<4;b[k>>1]=u+1&65535;k=(s+(u&65535)^v)&1048575;v=c[w+6188+(k>>>11<<2)>>2]|0;if((v|0)==0){u=gj[c[w+8236>>2]&4095](k)|0;x=u;y=a[h]|0;z=x&255;A=z<<8;B=r&255;C=A|B;D=y&255;E=D+10|0;F=d+(E<<1)|0;b[F>>1]=C;G=d+444|0;H=c[G>>2]|0;I=263170>>>(H>>>0);J=I&127;K=d+432|0;L=c[K>>2]|0;M=L-J|0;c[K>>2]=M;return}else{x=a[v+k|0]|0;y=t;z=x&255;A=z<<8;B=r&255;C=A|B;D=y&255;E=D+10|0;F=d+(E<<1)|0;b[F>>1]=C;G=d+444|0;H=c[G>>2]|0;I=263170>>>(H>>>0);J=I&127;K=d+432|0;L=c[K>>2]|0;M=L-J|0;c[K>>2]=M;return}}function gcJ(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;f=d+442|0;g=(a[f]|0)-1&255;a[f]=g;h=d+295|0;i=a[h]|0;j=(e[d+((i&255)+6<<1)>>1]|0)<<4;k=d+260|0;l=b[k>>1]|0;m=l+1&65535;b[k>>1]=m;n=d+256|0;o=c[n>>2]|0;p=(j+(l&65535)^o)&1048575;l=c[3531864]|0;j=c[l+6188+(p>>>11<<2)>>2]|0;if((j|0)==0){q=gj[c[l+8236>>2]&4095](p)|0;r=q;s=a[f]|0;t=a[h]|0;u=b[k>>1]|0;v=c[n>>2]|0;w=c[3531864]|0}else{r=a[j+p|0]|0;s=g;t=i;u=m;v=o;w=l}a[f]=s-1&255;s=(e[d+((t&255)+6<<1)>>1]|0)<<4;b[k>>1]=u+1&65535;k=(s+(u&65535)^v)&1048575;v=c[w+6188+(k>>>11<<2)>>2]|0;if((v|0)==0){u=gj[c[w+8236>>2]&4095](k)|0;x=u;y=a[h]|0;z=x&255;A=z<<8;B=r&255;C=A|B;D=y&255;E=D+9|0;F=d+(E<<1)|0;b[F>>1]=C;G=d+444|0;H=c[G>>2]|0;I=263170>>>(H>>>0);J=I&127;K=d+432|0;L=c[K>>2]|0;M=L-J|0;c[K>>2]=M;return}else{x=a[v+k|0]|0;y=t;z=x&255;A=z<<8;B=r&255;C=A|B;D=y&255;E=D+9|0;F=d+(E<<1)|0;b[F>>1]=C;G=d+444|0;H=c[G>>2]|0;I=263170>>>(H>>>0);J=I&127;K=d+432|0;L=c[K>>2]|0;M=L-J|0;c[K>>2]=M;return}}function gcK(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;f=d+442|0;g=(a[f]|0)-1&255;a[f]=g;h=d+295|0;i=a[h]|0;j=(e[d+((i&255)+6<<1)>>1]|0)<<4;k=d+260|0;l=b[k>>1]|0;m=l+1&65535;b[k>>1]=m;n=d+256|0;o=c[n>>2]|0;p=(j+(l&65535)^o)&1048575;l=c[3531864]|0;j=c[l+6188+(p>>>11<<2)>>2]|0;if((j|0)==0){q=gj[c[l+8236>>2]&4095](p)|0;r=q;s=a[f]|0;t=a[h]|0;u=b[k>>1]|0;v=c[n>>2]|0;w=c[3531864]|0}else{r=a[j+p|0]|0;s=g;t=i;u=m;v=o;w=l}a[f]=s-1&255;s=(e[d+((t&255)+6<<1)>>1]|0)<<4;b[k>>1]=u+1&65535;k=(s+(u&65535)^v)&1048575;v=c[w+6188+(k>>>11<<2)>>2]|0;if((v|0)==0){u=gj[c[w+8236>>2]&4095](k)|0;x=u;y=a[h]|0;z=x&255;A=z<<8;B=r&255;C=A|B;D=y&255;E=D+8|0;F=d+(E<<1)|0;b[F>>1]=C;G=d+444|0;H=c[G>>2]|0;I=263170>>>(H>>>0);J=I&127;K=d+432|0;L=c[K>>2]|0;M=L-J|0;c[K>>2]=M;return}else{x=a[v+k|0]|0;y=t;z=x&255;A=z<<8;B=r&255;C=A|B;D=y&255;E=D+8|0;F=d+(E<<1)|0;b[F>>1]=C;G=d+444|0;H=c[G>>2]|0;I=263170>>>(H>>>0);J=I&127;K=d+432|0;L=c[K>>2]|0;M=L-J|0;c[K>>2]=M;return}}function gcL(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=f+442|0;a[g]=(a[g]|0)-1&255;h=f+295|0;i=e[f+((d[h]|0)+6<<1)>>1]<<4;j=f+260|0;k=b[j>>1]|0;b[j>>1]=k+1&65535;l=f+256|0;m=(i+(k&65535)^c[l>>2])&1048575;k=c[3531864]|0;i=c[k+6188+(m>>>11<<2)>>2]|0;if((i|0)==0){n=gj[c[k+8236>>2]&4095](m)|0}else{n=a[i+m|0]|0}m=n&255;i=(n&255)>191;L64093:do{if(i){o=a[f+((d[f+296|0]|0)+(c[9647712+(m<<2)>>2]|0))|0]|0}else{n=gj[c[678944+(m<<2)>>2]&4095](f)|0;do{if((n&1048064|0)==(c[f+428>>2]|0)|(n|0)==1048575){k=n&511;if((a[f+424|0]|0)!=0&k>>>0<256){o=a[f+k|0]|0;break L64093}if(k>>>0<=255){break}o=f9w(f,k-256|0)|0;break L64093}}while(0);k=n&1048575;p=c[3531864]|0;q=c[p+44+(k>>>11<<2)>>2]|0;if((q|0)==0){o=gj[c[p+8236>>2]&4095](k)|0;break}else{o=a[q+k|0]|0;break}}}while(0);k=o&255;a[g]=(a[g]|0)-1&255;g=e[f+((d[h]|0)+6<<1)>>1]<<4;h=b[j>>1]|0;b[j>>1]=h+1&65535;j=(g+(h&65535)^c[l>>2])&1048575;l=c[3531864]|0;h=c[l+6188+(j>>>11<<2)>>2]|0;if((h|0)==0){r=gj[c[l+8236>>2]&4095](j)|0}else{r=a[h+j|0]|0}j=f+432|0;h=(c[j>>2]|0)-((i?460546:1250054)>>>((c[f+444>>2]|0)>>>0)&127)|0;c[j>>2]=h;if(r<<24>>24==0){return}switch(m&56|0){case 24:{l=f+280|0;g=r-1&255;q=k;p=r;s=c[l>>2]|0;do{t=(((s|0)!=0)<<8)+q|0;s=t&1;q=t>>>1;p=p-1&255;}while(p<<24>>24!=0);c[l>>2]=s;c[j>>2]=h+~(g&255);if(i){a[f+((d[f+296|0]|0)+(c[9647712+(m<<2)>>2]|0))|0]=q&255;return}g=c[2426954]|0;s=q&255;do{if((g&1048064|0)==(c[f+428>>2]|0)|(g|0)==1048575){q=g&511;if((a[f+424|0]|0)!=0&q>>>0<256){a[f+q|0]=s;return}if(q>>>0<=255){break}f9y(f,q-256|0,s);return}}while(0);q=g&1048575;g=c[3531864]|0;l=c[g+2092+(q>>>11<<2)>>2]|0;if((l|0)==0){gg[c[g+8240>>2]&4095](q,s);return}else{a[l+q|0]=s;return}break};case 8:{s=r-1&255;q=k;l=r;do{u=q&1;q=(u<<7)+(q>>>1)|0;l=l-1&255;}while(l<<24>>24!=0);c[f+280>>2]=u;c[j>>2]=h+~(s&255);if(i){a[f+((d[f+296|0]|0)+(c[9647712+(m<<2)>>2]|0))|0]=q&255;return}s=c[2426954]|0;u=q&255;do{if((s&1048064|0)==(c[f+428>>2]|0)|(s|0)==1048575){q=s&511;if((a[f+424|0]|0)!=0&q>>>0<256){a[f+q|0]=u;return}if(q>>>0<=255){break}f9y(f,q-256|0,u);return}}while(0);q=s&1048575;s=c[3531864]|0;l=c[s+2092+(q>>>11<<2)>>2]|0;if((l|0)==0){gg[c[s+8240>>2]&4095](q,u);return}else{a[l+q|0]=u;return}break};case 56:{u=r&255;c[j>>2]=h-u;q=o<<24>>24>>u-1;c[f+280>>2]=q&1;u=q>>>1&255;q=u<<24>>24;c[f+284>>2]=q;c[f+276>>2]=q;c[f+264>>2]=q;if(i){a[f+((d[f+296|0]|0)+(c[9647712+(m<<2)>>2]|0))|0]=u;return}q=c[2426954]|0;do{if((q&1048064|0)==(c[f+428>>2]|0)|(q|0)==1048575){o=q&511;if((a[f+424|0]|0)!=0&o>>>0<256){a[f+o|0]=u;return}if(o>>>0<=255){break}f9y(f,o-256|0,u);return}}while(0);o=q&1048575;q=c[3531864]|0;l=c[q+2092+(o>>>11<<2)>>2]|0;if((l|0)==0){gg[c[q+8240>>2]&4095](o,u);return}else{a[l+o|0]=u;return}break};case 0:{u=r-1&255;o=k;l=r;do{v=o&128;o=v>>>7|o<<1;l=l-1&255;}while(l<<24>>24!=0);c[f+280>>2]=v;c[j>>2]=h+~(u&255);if(i){a[f+((d[f+296|0]|0)+(c[9647712+(m<<2)>>2]|0))|0]=o&255;return}u=c[2426954]|0;v=o&255;do{if((u&1048064|0)==(c[f+428>>2]|0)|(u|0)==1048575){o=u&511;if((a[f+424|0]|0)!=0&o>>>0<256){a[f+o|0]=v;return}if(o>>>0<=255){break}f9y(f,o-256|0,v);return}}while(0);o=u&1048575;u=c[3531864]|0;l=c[u+2092+(o>>>11<<2)>>2]|0;if((l|0)==0){gg[c[u+8240>>2]&4095](o,v);return}else{a[l+o|0]=v;return}break};case 32:{v=r&255;c[j>>2]=h-v;o=k<<v;c[f+280>>2]=o&256;v=o&255;o=v<<24>>24;c[f+284>>2]=o;c[f+276>>2]=o;c[f+264>>2]=o;if(i){a[f+((d[f+296|0]|0)+(c[9647712+(m<<2)>>2]|0))|0]=v;return}o=c[2426954]|0;do{if((o&1048064|0)==(c[f+428>>2]|0)|(o|0)==1048575){l=o&511;if((a[f+424|0]|0)!=0&l>>>0<256){a[f+l|0]=v;return}if(l>>>0<=255){break}f9y(f,l-256|0,v);return}}while(0);l=o&1048575;o=c[3531864]|0;u=c[o+2092+(l>>>11<<2)>>2]|0;if((u|0)==0){gg[c[o+8240>>2]&4095](l,v);return}else{a[u+l|0]=v;return}break};case 16:{v=f+280|0;l=r-1&255;u=k;o=r;q=c[v>>2]|0;do{s=u<<1;u=s|(q|0)!=0;q=s&256;o=o-1&255;}while(o<<24>>24!=0);c[v>>2]=q;c[j>>2]=h+~(l&255);if(i){a[f+((d[f+296|0]|0)+(c[9647712+(m<<2)>>2]|0))|0]=u&255;return}l=c[2426954]|0;q=u&255;do{if((l&1048064|0)==(c[f+428>>2]|0)|(l|0)==1048575){u=l&511;if((a[f+424|0]|0)!=0&u>>>0<256){a[f+u|0]=q;return}if(u>>>0<=255){break}f9y(f,u-256|0,q);return}}while(0);u=l&1048575;l=c[3531864]|0;v=c[l+2092+(u>>>11<<2)>>2]|0;if((v|0)==0){gg[c[l+8240>>2]&4095](u,q);return}else{a[v+u|0]=q;return}break};case 40:{q=r&255;c[j>>2]=h-q;h=k>>>((q-1|0)>>>0);c[f+280>>2]=h&1;q=h>>>1&255;h=q<<24>>24;c[f+284>>2]=h;c[f+276>>2]=h;c[f+264>>2]=h;if(i){a[f+((d[f+296|0]|0)+(c[9647712+(m<<2)>>2]|0))|0]=q;return}m=c[2426954]|0;do{if((m&1048064|0)==(c[f+428>>2]|0)|(m|0)==1048575){i=m&511;if((a[f+424|0]|0)!=0&i>>>0<256){a[f+i|0]=q;return}if(i>>>0<=255){break}f9y(f,i-256|0,q);return}}while(0);f=m&1048575;m=c[3531864]|0;i=c[m+2092+(f>>>11<<2)>>2]|0;if((i|0)==0){gg[c[m+8240>>2]&4095](f,q);return}else{a[i+f|0]=q;return}break};default:{return}}}function gcM(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=f+442|0;a[g]=(a[g]|0)-1&255;h=f+295|0;i=(e[f+((d[h]|0)+6<<1)>>1]|0)<<4;j=f+260|0;k=b[j>>1]|0;b[j>>1]=k+1&65535;l=f+256|0;m=(i+(k&65535)^c[l>>2])&1048575;k=c[3531864]|0;i=c[k+6188+(m>>>11<<2)>>2]|0;if((i|0)==0){n=gj[c[k+8236>>2]&4095](m)|0}else{n=a[i+m|0]|0}m=n&255;i=(n&255)>191;if(i){n=a[h]|0;o=b[f+((n&255)+(c[9649760+(m<<2)>>2]|0)<<1)>>1]|0;p=n}else{n=c[678944+(m<<2)>>2]|0;gj[n&4095](f)|0;n=f9x(f,c[2426954]|0)|0;o=n;p=a[h]|0}n=o&65535;a[g]=(a[g]|0)-1&255;g=(e[f+((p&255)+6<<1)>>1]|0)<<4;p=b[j>>1]|0;b[j>>1]=p+1&65535;j=(g+(p&65535)^c[l>>2])&1048575;l=c[3531864]|0;p=c[l+6188+(j>>>11<<2)>>2]|0;if((p|0)==0){q=gj[c[l+8236>>2]&4095](j)|0}else{q=a[p+j|0]|0}j=f+432|0;p=(c[j>>2]|0)-((i?460546:1774342)>>>((c[f+444>>2]|0)>>>0)&127)|0;c[j>>2]=p;if(q<<24>>24==0){return}switch(m&56|0){case 0:{l=q-1&255;g=n;k=q;do{r=g&32768;g=r>>>15|g<<1;k=k-1&255;}while(k<<24>>24!=0);c[f+280>>2]=r;c[j>>2]=p+~(l&255);if(i){b[f+((d[h]|0)+(c[9649760+(m<<2)>>2]|0)<<1)>>1]=g&65535;return}else{f9z(f,c[2426954]|0,g&65535);return}break};case 8:{g=q-1&255;l=n;r=q;do{s=l&1;l=(s<<15)+(l>>>1)|0;r=r-1&255;}while(r<<24>>24!=0);c[f+280>>2]=s;c[j>>2]=p+~(g&255);if(i){b[f+((d[h]|0)+(c[9649760+(m<<2)>>2]|0)<<1)>>1]=l&65535;return}else{f9z(f,c[2426954]|0,l&65535);return}break};case 32:{l=q&255;c[j>>2]=p-l;g=n<<l;c[f+280>>2]=g&65536;l=g&65535;g=l<<16>>16;c[f+284>>2]=g;c[f+276>>2]=g;c[f+264>>2]=g;if(i){b[f+((d[h]|0)+(c[9649760+(m<<2)>>2]|0)<<1)>>1]=l;return}else{f9z(f,c[2426954]|0,l);return}break};case 24:{l=f+280|0;g=q-1&255;s=n;r=q;k=c[l>>2]|0;do{t=(((k|0)!=0)<<16)+s|0;k=t&1;s=t>>>1;r=r-1&255;}while(r<<24>>24!=0);c[l>>2]=k;c[j>>2]=p+~(g&255);if(i){b[f+((d[h]|0)+(c[9649760+(m<<2)>>2]|0)<<1)>>1]=s&65535;return}else{f9z(f,c[2426954]|0,s&65535);return}break};case 56:{s=q&255;c[j>>2]=p-s;g=o<<16>>16>>s-1;c[f+280>>2]=g&1;s=g>>>1&65535;g=s<<16>>16;c[f+284>>2]=g;c[f+276>>2]=g;c[f+264>>2]=g;if(i){b[f+((d[h]|0)+(c[9649760+(m<<2)>>2]|0)<<1)>>1]=s;return}else{f9z(f,c[2426954]|0,s);return}break};case 40:{s=q&255;c[j>>2]=p-s;g=n>>>((s-1|0)>>>0);c[f+280>>2]=g&1;s=g>>>1&65535;g=s<<16>>16;c[f+284>>2]=g;c[f+276>>2]=g;c[f+264>>2]=g;if(i){b[f+((d[h]|0)+(c[9649760+(m<<2)>>2]|0)<<1)>>1]=s;return}else{f9z(f,c[2426954]|0,s);return}break};case 16:{s=f+280|0;g=q-1&255;o=n;n=q;q=c[s>>2]|0;do{k=o<<1;o=k|(q|0)!=0;q=k&65536;n=n-1&255;}while(n<<24>>24!=0);c[s>>2]=q;c[j>>2]=p+~(g&255);if(i){b[f+((d[h]|0)+(c[9649760+(m<<2)>>2]|0)<<1)>>1]=o&65535;return}else{f9z(f,c[2426954]|0,o&65535);return}break};default:{return}}}function gcN(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;g=f+442|0;h=(a[g]|0)-1&255;a[g]=h;i=f+295|0;j=a[i]|0;k=(e[f+((j&255)+6<<1)>>1]|0)<<4;l=f+260|0;m=b[l>>1]|0;n=m+1&65535;b[l>>1]=n;o=f+256|0;p=c[o>>2]|0;q=(k+(m&65535)^p)&1048575;m=c[3531864]|0;k=c[m+6188+(q>>>11<<2)>>2]|0;if((k|0)==0){r=gj[c[m+8236>>2]&4095](q)|0;s=r;t=a[g]|0;u=a[i]|0;v=b[l>>1]|0;w=c[o>>2]|0;x=c[3531864]|0}else{s=a[k+q|0]|0;t=h;u=j;v=n;w=p;x=m}a[g]=t-1&255;t=(e[f+((u&255)+6<<1)>>1]|0)<<4;b[l>>1]=v+1&65535;g=(t+(v&65535)^w)&1048575;w=c[x+6188+(g>>>11<<2)>>2]|0;if((w|0)==0){v=gj[c[x+8236>>2]&4095](g)|0;y=v;z=a[i]|0}else{y=a[w+g|0]|0;z=u}u=f+((z&255)+11<<1)|0;b[u>>1]=(b[u>>1]|0)+2&65535;u=d[i]|0;b[l>>1]=f9x(f,((e[f+(u+11<<1)>>1]|0)+65534&65535)+((e[f+(u+5<<1)>>1]|0)<<4)|0)|0;u=f+((d[i]|0)+11<<1)|0;b[u>>1]=(b[u>>1]|0)+((y&255)<<8|s&255)&65535;a[f+443|0]=1;s=f+432|0;c[s>>2]=(c[s>>2]|0)-(1579018>>>((c[f+444>>2]|0)>>>0)&127);return}function gcO(f){f=f|0;var g=0,h=0;g=f+295|0;h=f+((d[g]|0)+11<<1)|0;b[h>>1]=(b[h>>1]|0)+2&65535;h=d[g]|0;b[f+260>>1]=f9x(f,((e[f+(h+11<<1)>>1]|0)+65534&65535)+((e[f+(h+5<<1)>>1]|0)<<4)|0)|0;a[f+443|0]=1;h=f+432|0;c[h>>2]=(c[h>>2]|0)-(1250058>>>((c[f+444>>2]|0)>>>0)&127);return}function gcP(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=f+442|0;a[g]=(a[g]|0)-1&255;g=f+295|0;h=(e[f+((d[g]|0)+6<<1)>>1]|0)<<4;i=f+260|0;j=b[i>>1]|0;b[i>>1]=j+1&65535;i=(h+(j&65535)^c[f+256>>2])&1048575;j=c[3531864]|0;h=c[j+6188+(i>>>11<<2)>>2]|0;if((h|0)==0){k=gj[c[j+8236>>2]&4095](i)|0}else{k=a[h+i|0]|0}i=k&255;if((k&255)>191){k=a[g]|0;l=b[f+((k&255)+(c[9649760+(i<<2)>>2]|0)<<1)>>1]|0;m=k}else{k=c[678944+(i<<2)>>2]|0;gj[k&4095](f)|0;k=f9x(f,c[2426954]|0)|0;l=k;m=a[g]|0}b[f+((c[9653856+(i<<2)>>2]|0)+(m&255)<<1)>>1]=l;l=c[2426954]|0;m=f9x(f,l+2&65535|l&983040)|0;b[f+((d[g]|0)+7<<1)>>1]=m;m=f+432|0;c[m>>2]=(c[m>>2]|0)-(((c[2426954]&1|0)!=0?1710606:1708554)>>>((c[f+444>>2]|0)>>>0)&127);return}function gcQ(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=f+442|0;a[g]=(a[g]|0)-1&255;g=f+295|0;h=(e[f+((d[g]|0)+6<<1)>>1]|0)<<4;i=f+260|0;j=b[i>>1]|0;b[i>>1]=j+1&65535;i=(h+(j&65535)^c[f+256>>2])&1048575;j=c[3531864]|0;h=c[j+6188+(i>>>11<<2)>>2]|0;if((h|0)==0){k=gj[c[j+8236>>2]&4095](i)|0}else{k=a[h+i|0]|0}i=k&255;if((k&255)>191){k=a[g]|0;l=b[f+((k&255)+(c[9649760+(i<<2)>>2]|0)<<1)>>1]|0;m=k}else{k=c[678944+(i<<2)>>2]|0;gj[k&4095](f)|0;k=f9x(f,c[2426954]|0)|0;l=k;m=a[g]|0}b[f+((c[9653856+(i<<2)>>2]|0)+(m&255)<<1)>>1]=l;l=c[2426954]|0;m=f9x(f,l+2&65535|l&983040)|0;b[f+((d[g]|0)+4<<1)>>1]=m;m=f+432|0;c[m>>2]=(c[m>>2]|0)-(((c[2426954]&1|0)!=0?1710606:1708554)>>>((c[f+444>>2]|0)>>>0)&127);return}function gcR(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=f+442|0;a[g]=(a[g]|0)-1&255;h=f+295|0;i=e[f+((d[h]|0)+6<<1)>>1]<<4;j=f+260|0;k=b[j>>1]|0;b[j>>1]=k+1&65535;l=f+256|0;m=(i+(k&65535)^c[l>>2])&1048575;k=c[3531864]|0;i=c[k+6188+(m>>>11<<2)>>2]|0;if((i|0)==0){n=gj[c[k+8236>>2]&4095](m)|0}else{n=a[i+m|0]|0}m=n&255;i=(n&255)>191;if(i){a[g]=(a[g]|0)-1&255;n=e[f+((d[h]|0)+6<<1)>>1]<<4;k=b[j>>1]|0;b[j>>1]=k+1&65535;o=(n+(k&65535)^c[l>>2])&1048575;k=c[3531864]|0;n=c[k+6188+(o>>>11<<2)>>2]|0;if((n|0)==0){p=gj[c[k+8236>>2]&4095](o)|0}else{p=a[n+o|0]|0}a[f+((d[f+296|0]|0)+(c[9647712+(m<<2)>>2]|0))|0]=p;q=i?4:11;r=f+432|0;s=c[r>>2]|0;t=s-q|0;c[r>>2]=t;return}gj[c[678944+(m<<2)>>2]&4095](f)|0;m=c[2426954]|0;a[g]=(a[g]|0)-1&255;g=e[f+((d[h]|0)+6<<1)>>1]<<4;h=b[j>>1]|0;b[j>>1]=h+1&65535;j=(g+(h&65535)^c[l>>2])&1048575;l=c[3531864]|0;h=c[l+6188+(j>>>11<<2)>>2]|0;if((h|0)==0){u=gj[c[l+8236>>2]&4095](j)|0}else{u=a[h+j|0]|0}do{if((m&1048064|0)==(c[f+428>>2]|0)|(m|0)==1048575){j=m&511;if((a[f+424|0]|0)!=0&j>>>0<256){a[f+j|0]=u;q=i?4:11;r=f+432|0;s=c[r>>2]|0;t=s-q|0;c[r>>2]=t;return}if(j>>>0<=255){break}f9y(f,j-256|0,u);q=i?4:11;r=f+432|0;s=c[r>>2]|0;t=s-q|0;c[r>>2]=t;return}}while(0);j=m&1048575;m=c[3531864]|0;h=c[m+2092+(j>>>11<<2)>>2]|0;if((h|0)==0){gg[c[m+8240>>2]&4095](j,u);q=i?4:11;r=f+432|0;s=c[r>>2]|0;t=s-q|0;c[r>>2]=t;return}else{a[h+j|0]=u;q=i?4:11;r=f+432|0;s=c[r>>2]|0;t=s-q|0;c[r>>2]=t;return}}function gcS(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;g=f+442|0;a[g]=(a[g]|0)-1&255;h=f+295|0;i=(e[f+((d[h]|0)+6<<1)>>1]|0)<<4;j=f+260|0;k=b[j>>1]|0;b[j>>1]=k+1&65535;l=f+256|0;m=(i+(k&65535)^c[l>>2])&1048575;k=c[3531864]|0;i=c[k+6188+(m>>>11<<2)>>2]|0;if((i|0)==0){n=gj[c[k+8236>>2]&4095](m)|0}else{n=a[i+m|0]|0}m=n&255;i=(n&255)>191;if(i){n=(a[g]|0)-1&255;a[g]=n;k=a[h]|0;o=(e[f+((k&255)+6<<1)>>1]|0)<<4;p=b[j>>1]|0;q=p+1&65535;b[j>>1]=q;r=c[l>>2]|0;s=(o+(p&65535)^r)&1048575;p=c[3531864]|0;o=c[p+6188+(s>>>11<<2)>>2]|0;if((o|0)==0){t=gj[c[p+8236>>2]&4095](s)|0;u=t;v=a[g]|0;w=a[h]|0;x=b[j>>1]|0;y=c[l>>2]|0;z=c[3531864]|0}else{u=a[o+s|0]|0;v=n;w=k;x=q;y=r;z=p}a[g]=v-1&255;v=(e[f+((w&255)+6<<1)>>1]|0)<<4;b[j>>1]=x+1&65535;p=(v+(x&65535)^y)&1048575;y=c[z+6188+(p>>>11<<2)>>2]|0;if((y|0)==0){x=gj[c[z+8236>>2]&4095](p)|0;A=x;B=a[h]|0}else{A=a[y+p|0]|0;B=w}b[f+((B&255)+(c[9649760+(m<<2)>>2]|0)<<1)>>1]=(A&255)<<8|u&255;C=i?4:15;D=f+432|0;E=c[D>>2]|0;F=E-C|0;c[D>>2]=F;return}else{u=c[678944+(m<<2)>>2]|0;gj[u&4095](f)|0;u=(a[g]|0)-1&255;a[g]=u;m=a[h]|0;A=(e[f+((m&255)+6<<1)>>1]|0)<<4;B=b[j>>1]|0;w=B+1&65535;b[j>>1]=w;p=c[l>>2]|0;y=(A+(B&65535)^p)&1048575;B=c[3531864]|0;A=c[B+6188+(y>>>11<<2)>>2]|0;if((A|0)==0){x=gj[c[B+8236>>2]&4095](y)|0;G=x;H=a[g]|0;I=a[h]|0;J=b[j>>1]|0;K=c[l>>2]|0;L=c[3531864]|0}else{G=a[A+y|0]|0;H=u;I=m;J=w;K=p;L=B}a[g]=H-1&255;H=(e[f+((I&255)+6<<1)>>1]|0)<<4;b[j>>1]=J+1&65535;j=(H+(J&65535)^K)&1048575;K=c[L+6188+(j>>>11<<2)>>2]|0;if((K|0)==0){M=gj[c[L+8236>>2]&4095](j)|0}else{M=a[K+j|0]|0}f9z(f,c[2426954]|0,(M&255)<<8|G&255);C=i?4:15;D=f+432|0;E=c[D>>2]|0;F=E-C|0;c[D>>2]=F;return}}function gcT(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;g=f+442|0;h=(a[g]|0)-1&255;a[g]=h;i=f+295|0;j=a[i]|0;k=e[f+((j&255)+6<<1)>>1]<<4;l=f+260|0;m=b[l>>1]|0;n=m+1&65535;b[l>>1]=n;o=f+256|0;p=c[o>>2]|0;q=(k+(m&65535)^p)&1048575;m=c[3531864]|0;k=c[m+6188+(q>>>11<<2)>>2]|0;if((k|0)==0){r=gj[c[m+8236>>2]&4095](q)|0;s=r;t=a[g]|0;u=a[i]|0;v=b[l>>1]|0;w=c[o>>2]|0;x=c[3531864]|0}else{s=a[k+q|0]|0;t=h;u=j;v=n;w=p;x=m}m=f+432|0;c[m>>2]=(c[m>>2]|0)-23;p=t-1&255;a[g]=p;t=e[f+((u&255)+6<<1)>>1]<<4;n=v+1&65535;b[l>>1]=n;j=(t+(v&65535)^w)&1048575;v=c[x+6188+(j>>>11<<2)>>2]|0;if((v|0)==0){t=gj[c[x+8236>>2]&4095](j)|0;y=t;z=a[g]|0;A=a[i]|0;B=b[l>>1]|0;C=c[o>>2]|0;D=c[3531864]|0}else{y=a[v+j|0]|0;z=p;A=u;B=n;C=w;D=x}a[g]=z-1&255;z=e[f+((A&255)+6<<1)>>1]<<4;b[l>>1]=B+1&65535;l=(z+(B&65535)^C)&1048575;C=c[D+6188+(l>>>11<<2)>>2]|0;if((C|0)==0){B=gj[c[D+8236>>2]&4095](l)|0;E=B;F=a[i]|0}else{E=a[C+l|0]|0;F=A}A=E&255;l=f+((F&255)+11<<1)|0;b[l>>1]=(b[l>>1]|0)-2&65535;l=d[i]|0;f9z(f,(e[f+(l+5<<1)>>1]<<4)+(e[f+(l+11<<1)>>1]|0)|0,b[f+(l+10<<1)>>1]|0);l=d[i]|0;b[f+(l+10<<1)>>1]=b[f+(l+11<<1)>>1]|0;l=f+((d[i]|0)+11<<1)|0;b[l>>1]=(b[l>>1]|0)-((y&255)<<8|s&255)&65535;if((E&255)>1){s=f+452|0;y=f+448|0;l=1;do{F=f+((d[i]|0)+11<<1)|0;b[F>>1]=(b[F>>1]|0)-2&65535;F=d[i]|0;C=e[f+(F+5<<1)>>1]<<4;B=C+(e[f+(F+11<<1)>>1]|0)|0;if((a[s]|0)==0){G=C}else{G=c[y>>2]|0}f9z(f,B,f9x(f,G-(l<<1)+(e[f+(F+10<<1)>>1]|0)|0)|0);c[m>>2]=(c[m>>2]|0)-16;l=l+1|0;}while(l>>>0<A>>>0)}if(E<<24>>24==0){return}E=f+((d[i]|0)+11<<1)|0;b[E>>1]=(b[E>>1]|0)-2&65535;E=d[i]|0;f9z(f,(e[f+(E+5<<1)>>1]<<4)+(e[f+(E+11<<1)>>1]|0)|0,b[f+(E+10<<1)>>1]|0);return}function gcU(a){a=a|0;var f=0,g=0,h=0;f=a+295|0;g=d[f]|0;b[a+(g+11<<1)>>1]=b[a+(g+10<<1)>>1]|0;g=a+((d[f]|0)+11<<1)|0;b[g>>1]=(b[g>>1]|0)+2&65535;g=d[f]|0;h=f9x(a,((e[a+(g+11<<1)>>1]|0)+65534&65535)+((e[a+(g+5<<1)>>1]|0)<<4)|0)|0;b[a+((d[f]|0)+10<<1)>>1]=h;h=a+432|0;c[h>>2]=(c[h>>2]|0)-8;return}function gcV(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;g=f+442|0;h=(a[g]|0)-1&255;a[g]=h;i=f+295|0;j=a[i]|0;k=(e[f+((j&255)+6<<1)>>1]|0)<<4;l=f+260|0;m=b[l>>1]|0;n=m+1&65535;b[l>>1]=n;o=f+256|0;p=c[o>>2]|0;q=(k+(m&65535)^p)&1048575;m=c[3531864]|0;k=c[m+6188+(q>>>11<<2)>>2]|0;if((k|0)==0){r=gj[c[m+8236>>2]&4095](q)|0;s=r;t=a[g]|0;u=a[i]|0;v=b[l>>1]|0;w=c[o>>2]|0;x=c[3531864]|0}else{s=a[k+q|0]|0;t=h;u=j;v=n;w=p;x=m}a[g]=t-1&255;t=(e[f+((u&255)+6<<1)>>1]|0)<<4;b[l>>1]=v+1&65535;g=(t+(v&65535)^w)&1048575;w=c[x+6188+(g>>>11<<2)>>2]|0;if((w|0)==0){v=gj[c[x+8236>>2]&4095](g)|0;y=v;z=a[i]|0}else{y=a[w+g|0]|0;z=u}u=f+((z&255)+11<<1)|0;b[u>>1]=(b[u>>1]|0)+2&65535;u=d[i]|0;b[l>>1]=f9x(f,((e[f+(u+11<<1)>>1]|0)+65534&65535)+((e[f+(u+5<<1)>>1]|0)<<4)|0)|0;u=f+((d[i]|0)+11<<1)|0;b[u>>1]=(b[u>>1]|0)+2&65535;u=d[i]|0;l=f9x(f,((e[f+(u+11<<1)>>1]|0)+65534&65535)+((e[f+(u+5<<1)>>1]|0)<<4)|0)|0;b[f+((d[i]|0)+6<<1)>>1]=l;l=f+((d[i]|0)+11<<1)|0;b[l>>1]=(b[l>>1]|0)+((y&255)<<8|s&255)&65535;a[f+443|0]=1;s=f+432|0;c[s>>2]=(c[s>>2]|0)-(2105360>>>((c[f+444>>2]|0)>>>0)&127);return}function gcW(f){f=f|0;var g=0,h=0,i=0;g=f+295|0;h=f+((d[g]|0)+11<<1)|0;b[h>>1]=(b[h>>1]|0)+2&65535;h=d[g]|0;b[f+260>>1]=f9x(f,((e[f+(h+11<<1)>>1]|0)+65534&65535)+((e[f+(h+5<<1)>>1]|0)<<4)|0)|0;h=f+((d[g]|0)+11<<1)|0;b[h>>1]=(b[h>>1]|0)+2&65535;h=d[g]|0;i=f9x(f,((e[f+(h+11<<1)>>1]|0)+65534&65535)+((e[f+(h+5<<1)>>1]|0)<<4)|0)|0;b[f+((d[g]|0)+6<<1)>>1]=i;a[f+443|0]=1;i=f+432|0;c[i>>2]=(c[i>>2]|0)-(1907984>>>((c[f+444>>2]|0)>>>0)&127);return}function gcX(a){a=a|0;var b=0;gd0(a,3,0);b=a+432|0;c[b>>2]=(c[b>>2]|0)-(3289624>>>((c[a+444>>2]|0)>>>0)&127);return}function gcY(f){f=f|0;var g=0,h=0,i=0,j=0;g=f+442|0;a[g]=(a[g]|0)-1&255;g=(e[f+((d[f+295|0]|0)+6<<1)>>1]|0)<<4;h=f+260|0;i=b[h>>1]|0;b[h>>1]=i+1&65535;h=(g+(i&65535)^c[f+256>>2])&1048575;i=c[3531864]|0;g=c[i+6188+(h>>>11<<2)>>2]|0;if((g|0)==0){j=gj[c[i+8236>>2]&4095](h)|0}else{j=a[g+h|0]|0}gd0(f,j&255,0);j=f+432|0;c[j>>2]=(c[j>>2]|0)-(3289624>>>((c[f+444>>2]|0)>>>0)&127);return}function gcZ(a){a=a|0;var b=0;if((c[a+272>>2]|0)==0){b=a+432|0;c[b>>2]=(c[b>>2]|0)-3;return}else{gd0(a,4,0);b=a+432|0;c[b>>2]=(c[b>>2]|0)-(3421210>>>((c[a+444>>2]|0)>>>0)&127);return}}function gc_(f){f=f|0;var g=0,h=0,i=0;g=f+295|0;h=f+((d[g]|0)+11<<1)|0;b[h>>1]=(b[h>>1]|0)+2&65535;h=d[g]|0;b[f+260>>1]=f9x(f,((e[f+(h+11<<1)>>1]|0)+65534&65535)+((e[f+(h+5<<1)>>1]|0)<<4)|0)|0;h=f+((d[g]|0)+11<<1)|0;b[h>>1]=(b[h>>1]|0)+2&65535;h=d[g]|0;i=f9x(f,((e[f+(h+11<<1)>>1]|0)+65534&65535)+((e[f+(h+5<<1)>>1]|0)<<4)|0)|0;b[f+((d[g]|0)+6<<1)>>1]=i;gcc(f);a[f+443|0]=1;i=f+432|0;c[i>>2]=(c[i>>2]|0)-(2565907>>>((c[f+444>>2]|0)>>>0)&127);return}function gc$(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=f+442|0;a[g]=(a[g]|0)-1&255;g=e[f+((d[f+295|0]|0)+6<<1)>>1]<<4;h=f+260|0;i=b[h>>1]|0;b[h>>1]=i+1&65535;h=(g+(i&65535)^c[f+256>>2])&1048575;i=c[3531864]|0;g=c[i+6188+(h>>>11<<2)>>2]|0;if((g|0)==0){j=gj[c[i+8236>>2]&4095](h)|0}else{j=a[g+h|0]|0}h=j&255;g=(j&255)>191;L64472:do{if(g){k=a[f+((d[f+296|0]|0)+(c[9647712+(h<<2)>>2]|0))|0]|0}else{j=gj[c[678944+(h<<2)>>2]&4095](f)|0;do{if((j&1048064|0)==(c[f+428>>2]|0)|(j|0)==1048575){i=j&511;if((a[f+424|0]|0)!=0&i>>>0<256){k=a[f+i|0]|0;break L64472}if(i>>>0<=255){break}k=f9w(f,i-256|0)|0;break L64472}}while(0);i=j&1048575;l=c[3531864]|0;m=c[l+44+(i>>>11<<2)>>2]|0;if((m|0)==0){k=gj[c[l+8236>>2]&4095](i)|0;break}else{k=a[m+i|0]|0;break}}}while(0);i=k&255;m=f+432|0;l=(c[m>>2]|0)-((g?394754:1052679)>>>((c[f+444>>2]|0)>>>0)&127)|0;c[m>>2]=l;switch(h&56|0){case 8:{n=i&1;c[f+280>>2]=n;o=n<<7;n=o|i>>>1;L64488:do{if(g){a[f+((d[f+296|0]|0)+(c[9647712+(h<<2)>>2]|0))|0]=n&255}else{p=c[2426954]|0;q=n&255;do{if((p&1048064|0)==(c[f+428>>2]|0)|(p|0)==1048575){r=p&511;if((a[f+424|0]|0)!=0&r>>>0<256){a[f+r|0]=q;break L64488}if(r>>>0<=255){break}f9y(f,r-256|0,q);break L64488}}while(0);j=p&1048575;r=c[3531864]|0;s=c[r+2092+(j>>>11<<2)>>2]|0;if((s|0)==0){gg[c[r+8240>>2]&4095](j,q);break}else{a[s+j|0]=q;break}}}while(0);c[f+272>>2]=o^i&128;return};case 0:{c[f+280>>2]=i&128;o=i<<1;n=o|i>>>7;L64504:do{if(g){a[f+((d[f+296|0]|0)+(c[9647712+(h<<2)>>2]|0))|0]=n&255}else{j=c[2426954]|0;s=n&255;do{if((j&1048064|0)==(c[f+428>>2]|0)|(j|0)==1048575){r=j&511;if((a[f+424|0]|0)!=0&r>>>0<256){a[f+r|0]=s;break L64504}if(r>>>0<=255){break}f9y(f,r-256|0,s);break L64504}}while(0);q=j&1048575;p=c[3531864]|0;r=c[p+2092+(q>>>11<<2)>>2]|0;if((r|0)==0){gg[c[p+8240>>2]&4095](q,s);break}else{a[r+q|0]=s;break}}}while(0);c[f+272>>2]=(o^i)&128;return};case 24:{o=f+280|0;n=((c[o>>2]|0)!=0)<<8|i;c[o>>2]=i&1;o=n>>>1;L64520:do{if(g){a[f+((d[f+296|0]|0)+(c[9647712+(h<<2)>>2]|0))|0]=o&255}else{n=c[2426954]|0;q=o&255;do{if((n&1048064|0)==(c[f+428>>2]|0)|(n|0)==1048575){r=n&511;if((a[f+424|0]|0)!=0&r>>>0<256){a[f+r|0]=q;break L64520}if(r>>>0<=255){break}f9y(f,r-256|0,q);break L64520}}while(0);s=n&1048575;j=c[3531864]|0;r=c[j+2092+(s>>>11<<2)>>2]|0;if((r|0)==0){gg[c[j+8240>>2]&4095](s,q);break}else{a[r+s|0]=q;break}}}while(0);c[f+272>>2]=(o^i)&128;return};case 56:{c[m>>2]=l-1;c[f+280>>2]=i&1;o=k<<24>>24>>>1&255;k=o<<24>>24;c[f+284>>2]=k;c[f+276>>2]=k;c[f+264>>2]=k;L64536:do{if(g){a[f+((d[f+296|0]|0)+(c[9647712+(h<<2)>>2]|0))|0]=o}else{k=c[2426954]|0;do{if((k&1048064|0)==(c[f+428>>2]|0)|(k|0)==1048575){s=k&511;if((a[f+424|0]|0)!=0&s>>>0<256){a[f+s|0]=o;break L64536}if(s>>>0<=255){break}f9y(f,s-256|0,o);break L64536}}while(0);q=k&1048575;n=c[3531864]|0;s=c[n+2092+(q>>>11<<2)>>2]|0;if((s|0)==0){gg[c[n+8240>>2]&4095](q,o);break}else{a[s+q|0]=o;break}}}while(0);c[f+272>>2]=0;return};case 32:{c[m>>2]=l-1;o=i<<1;c[f+280>>2]=o&256;q=o&255;s=q<<24>>24;c[f+284>>2]=s;c[f+276>>2]=s;c[f+264>>2]=s;L64552:do{if(g){a[f+((d[f+296|0]|0)+(c[9647712+(h<<2)>>2]|0))|0]=q}else{s=c[2426954]|0;do{if((s&1048064|0)==(c[f+428>>2]|0)|(s|0)==1048575){n=s&511;if((a[f+424|0]|0)!=0&n>>>0<256){a[f+n|0]=q;break L64552}if(n>>>0<=255){break}f9y(f,n-256|0,q);break L64552}}while(0);k=s&1048575;n=c[3531864]|0;r=c[n+2092+(k>>>11<<2)>>2]|0;if((r|0)==0){gg[c[n+8240>>2]&4095](k,q);break}else{a[r+k|0]=q;break}}}while(0);c[f+272>>2]=(o^i)&128;return};case 40:{c[m>>2]=l-1;c[f+280>>2]=i&1;l=i>>>1;m=l&255;c[f+284>>2]=l;c[f+276>>2]=l;c[f+264>>2]=l;L64569:do{if(g){a[f+((d[f+296|0]|0)+(c[9647712+(h<<2)>>2]|0))|0]=m}else{l=c[2426954]|0;do{if((l&1048064|0)==(c[f+428>>2]|0)|(l|0)==1048575){o=l&511;if((a[f+424|0]|0)!=0&o>>>0<256){a[f+o|0]=m;break L64569}if(o>>>0<=255){break}f9y(f,o-256|0,m);break L64569}}while(0);s=l&1048575;o=c[3531864]|0;q=c[o+2092+(s>>>11<<2)>>2]|0;if((q|0)==0){gg[c[o+8240>>2]&4095](s,m);break}else{a[q+s|0]=m;break}}}while(0);c[f+272>>2]=i&128;return};case 16:{m=i<<1;s=f+280|0;q=(c[s>>2]|0)!=0|m;c[s>>2]=m&256;L64585:do{if(g){a[f+((d[f+296|0]|0)+(c[9647712+(h<<2)>>2]|0))|0]=q&255}else{s=c[2426954]|0;o=q&255;do{if((s&1048064|0)==(c[f+428>>2]|0)|(s|0)==1048575){k=s&511;if((a[f+424|0]|0)!=0&k>>>0<256){a[f+k|0]=o;break L64585}if(k>>>0<=255){break}f9y(f,k-256|0,o);break L64585}}while(0);l=s&1048575;k=c[3531864]|0;r=c[k+2092+(l>>>11<<2)>>2]|0;if((r|0)==0){gg[c[k+8240>>2]&4095](l,o);break}else{a[r+l|0]=o;break}}}while(0);c[f+272>>2]=(m^i)&128;return};default:{return}}}function gc0(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=f+442|0;a[g]=(a[g]|0)-1&255;g=f+295|0;h=(e[f+((d[g]|0)+6<<1)>>1]|0)<<4;i=f+260|0;j=b[i>>1]|0;b[i>>1]=j+1&65535;i=(h+(j&65535)^c[f+256>>2])&1048575;j=c[3531864]|0;h=c[j+6188+(i>>>11<<2)>>2]|0;if((h|0)==0){k=gj[c[j+8236>>2]&4095](i)|0}else{k=a[h+i|0]|0}i=k&255;h=(k&255)>191;if(h){l=b[f+((d[g]|0)+(c[9649760+(i<<2)>>2]|0)<<1)>>1]|0}else{k=c[678944+(i<<2)>>2]|0;gj[k&4095](f)|0;l=f9x(f,c[2426954]|0)|0}k=l&65535;j=f+432|0;m=(c[j>>2]|0)-((h?394754:1576967)>>>((c[f+444>>2]|0)>>>0)&127)|0;c[j>>2]=m;switch(i&56|0){case 0:{c[f+280>>2]=k&32768;n=k<<1;o=n|k>>>15;if(h){b[f+((d[g]|0)+(c[9649760+(i<<2)>>2]|0)<<1)>>1]=o&65535}else{f9z(f,c[2426954]|0,o&65535)}c[f+272>>2]=(n^k)&32768;return};case 16:{n=k<<1;o=f+280|0;p=(c[o>>2]|0)!=0|n;c[o>>2]=n&65536;if(h){b[f+((d[g]|0)+(c[9649760+(i<<2)>>2]|0)<<1)>>1]=p&65535}else{f9z(f,c[2426954]|0,p&65535)}c[f+272>>2]=(n^k)&32768;return};case 56:{c[j>>2]=m-1;c[f+280>>2]=k&1;n=l<<16>>16>>>1&65535;l=n<<16>>16;c[f+284>>2]=l;c[f+276>>2]=l;c[f+264>>2]=l;if(h){b[f+((d[g]|0)+(c[9649760+(i<<2)>>2]|0)<<1)>>1]=n}else{f9z(f,c[2426954]|0,n)}c[f+272>>2]=0;return};case 24:{n=f+280|0;l=((c[n>>2]|0)!=0)<<16|k;c[n>>2]=k&1;n=l>>>1;if(h){b[f+((d[g]|0)+(c[9649760+(i<<2)>>2]|0)<<1)>>1]=n&65535}else{f9z(f,c[2426954]|0,n&65535)}c[f+272>>2]=(n^k)&32768;return};case 8:{n=k&1;c[f+280>>2]=n;l=n<<15;n=l|k>>>1;if(h){b[f+((d[g]|0)+(c[9649760+(i<<2)>>2]|0)<<1)>>1]=n&65535}else{f9z(f,c[2426954]|0,n&65535)}c[f+272>>2]=l^k&32768;return};case 32:{c[j>>2]=m-1;l=k<<1;c[f+280>>2]=l&65536;n=l&65535;p=n<<16>>16;c[f+284>>2]=p;c[f+276>>2]=p;c[f+264>>2]=p;if(h){b[f+((d[g]|0)+(c[9649760+(i<<2)>>2]|0)<<1)>>1]=n}else{f9z(f,c[2426954]|0,n)}c[f+272>>2]=(l^k)&32768;return};case 40:{c[j>>2]=m-1;c[f+280>>2]=k&1;m=k>>>1;j=m&65535;c[f+284>>2]=m;c[f+276>>2]=m;c[f+264>>2]=m;if(h){b[f+((d[g]|0)+(c[9649760+(i<<2)>>2]|0)<<1)>>1]=j}else{f9z(f,c[2426954]|0,j)}c[f+272>>2]=k&32768;return};default:{return}}}function gc1(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=f+442|0;a[g]=(a[g]|0)-1&255;g=e[f+((d[f+295|0]|0)+6<<1)>>1]<<4;h=f+260|0;i=b[h>>1]|0;b[h>>1]=i+1&65535;h=(g+(i&65535)^c[f+256>>2])&1048575;i=c[3531864]|0;g=c[i+6188+(h>>>11<<2)>>2]|0;if((g|0)==0){j=gj[c[i+8236>>2]&4095](h)|0}else{j=a[g+h|0]|0}h=j&255;g=(j&255)>191;L64658:do{if(g){k=a[f+((d[f+296|0]|0)+(c[9647712+(h<<2)>>2]|0))|0]|0}else{j=gj[c[678944+(h<<2)>>2]&4095](f)|0;do{if((j&1048064|0)==(c[f+428>>2]|0)|(j|0)==1048575){i=j&511;if((a[f+424|0]|0)!=0&i>>>0<256){k=a[f+i|0]|0;break L64658}if(i>>>0<=255){break}k=f9w(f,i-256|0)|0;break L64658}}while(0);i=j&1048575;l=c[3531864]|0;m=c[l+44+(i>>>11<<2)>>2]|0;if((m|0)==0){k=gj[c[l+8236>>2]&4095](i)|0;break}else{k=a[m+i|0]|0;break}}}while(0);i=k&255;m=d[f+296|0]|0;l=f;n=a[l+(m+28)|0]|0;o=f+432|0;p=(c[o>>2]|0)-((g?460546:1250054)>>>((c[f+444>>2]|0)>>>0)&127)|0;c[o>>2]=p;if(n<<24>>24==0){return}switch(h&56|0){case 8:{q=n-1&255;r=i;s=n;do{t=r&1;r=(t<<7)+(r>>>1)|0;s=s-1&255;}while(s<<24>>24!=0);c[f+280>>2]=t;c[o>>2]=p+~(q&255);if(g){a[l+((c[9647712+(h<<2)>>2]|0)+m)|0]=r&255;return}q=c[2426954]|0;t=r&255;do{if((q&1048064|0)==(c[f+428>>2]|0)|(q|0)==1048575){r=q&511;if((a[f+424|0]|0)!=0&r>>>0<256){a[l+r|0]=t;return}if(r>>>0<=255){break}f9y(f,r-256|0,t);return}}while(0);r=q&1048575;q=c[3531864]|0;s=c[q+2092+(r>>>11<<2)>>2]|0;if((s|0)==0){gg[c[q+8240>>2]&4095](r,t);return}else{a[s+r|0]=t;return}break};case 0:{t=n-1&255;r=i;s=n;do{u=r&128;r=u>>>7|r<<1;s=s-1&255;}while(s<<24>>24!=0);c[f+280>>2]=u;c[o>>2]=p+~(t&255);if(g){a[l+((c[9647712+(h<<2)>>2]|0)+m)|0]=r&255;return}t=c[2426954]|0;u=r&255;do{if((t&1048064|0)==(c[f+428>>2]|0)|(t|0)==1048575){r=t&511;if((a[f+424|0]|0)!=0&r>>>0<256){a[l+r|0]=u;return}if(r>>>0<=255){break}f9y(f,r-256|0,u);return}}while(0);r=t&1048575;t=c[3531864]|0;s=c[t+2092+(r>>>11<<2)>>2]|0;if((s|0)==0){gg[c[t+8240>>2]&4095](r,u);return}else{a[s+r|0]=u;return}break};case 16:{u=f+280|0;r=n-1&255;s=i;t=n;q=c[u>>2]|0;do{v=s<<1;s=v|(q|0)!=0;q=v&256;t=t-1&255;}while(t<<24>>24!=0);c[u>>2]=q;c[o>>2]=p+~(r&255);if(g){a[l+((c[9647712+(h<<2)>>2]|0)+m)|0]=s&255;return}r=c[2426954]|0;q=s&255;do{if((r&1048064|0)==(c[f+428>>2]|0)|(r|0)==1048575){s=r&511;if((a[f+424|0]|0)!=0&s>>>0<256){a[l+s|0]=q;return}if(s>>>0<=255){break}f9y(f,s-256|0,q);return}}while(0);s=r&1048575;r=c[3531864]|0;u=c[r+2092+(s>>>11<<2)>>2]|0;if((u|0)==0){gg[c[r+8240>>2]&4095](s,q);return}else{a[u+s|0]=q;return}break};case 32:{q=n&255;c[o>>2]=p-q;s=i<<q;c[f+280>>2]=s&256;q=s&255;s=q<<24>>24;c[f+284>>2]=s;c[f+276>>2]=s;c[f+264>>2]=s;if(g){a[l+((c[9647712+(h<<2)>>2]|0)+m)|0]=q;return}s=c[2426954]|0;do{if((s&1048064|0)==(c[f+428>>2]|0)|(s|0)==1048575){u=s&511;if((a[f+424|0]|0)!=0&u>>>0<256){a[l+u|0]=q;return}if(u>>>0<=255){break}f9y(f,u-256|0,q);return}}while(0);u=s&1048575;s=c[3531864]|0;r=c[s+2092+(u>>>11<<2)>>2]|0;if((r|0)==0){gg[c[s+8240>>2]&4095](u,q);return}else{a[r+u|0]=q;return}break};case 40:{q=n&255;c[o>>2]=p-q;u=i>>>((q-1|0)>>>0);c[f+280>>2]=u&1;q=u>>>1&255;u=q<<24>>24;c[f+284>>2]=u;c[f+276>>2]=u;c[f+264>>2]=u;if(g){a[l+((c[9647712+(h<<2)>>2]|0)+m)|0]=q;return}u=c[2426954]|0;do{if((u&1048064|0)==(c[f+428>>2]|0)|(u|0)==1048575){r=u&511;if((a[f+424|0]|0)!=0&r>>>0<256){a[l+r|0]=q;return}if(r>>>0<=255){break}f9y(f,r-256|0,q);return}}while(0);r=u&1048575;u=c[3531864]|0;s=c[u+2092+(r>>>11<<2)>>2]|0;if((s|0)==0){gg[c[u+8240>>2]&4095](r,q);return}else{a[s+r|0]=q;return}break};case 56:{q=n&255;c[o>>2]=p-q;r=k<<24>>24>>q-1;c[f+280>>2]=r&1;q=r>>>1&255;r=q<<24>>24;c[f+284>>2]=r;c[f+276>>2]=r;c[f+264>>2]=r;if(g){a[l+((c[9647712+(h<<2)>>2]|0)+m)|0]=q;return}r=c[2426954]|0;do{if((r&1048064|0)==(c[f+428>>2]|0)|(r|0)==1048575){k=r&511;if((a[f+424|0]|0)!=0&k>>>0<256){a[l+k|0]=q;return}if(k>>>0<=255){break}f9y(f,k-256|0,q);return}}while(0);k=r&1048575;r=c[3531864]|0;s=c[r+2092+(k>>>11<<2)>>2]|0;if((s|0)==0){gg[c[r+8240>>2]&4095](k,q);return}else{a[s+k|0]=q;return}break};case 24:{q=f+280|0;k=n-1&255;s=i;i=n;n=c[q>>2]|0;do{r=(((n|0)!=0)<<8)+s|0;n=r&1;s=r>>>1;i=i-1&255;}while(i<<24>>24!=0);c[q>>2]=n;c[o>>2]=p+~(k&255);if(g){a[l+((c[9647712+(h<<2)>>2]|0)+m)|0]=s&255;return}m=c[2426954]|0;h=s&255;do{if((m&1048064|0)==(c[f+428>>2]|0)|(m|0)==1048575){s=m&511;if((a[f+424|0]|0)!=0&s>>>0<256){a[l+s|0]=h;return}if(s>>>0<=255){break}f9y(f,s-256|0,h);return}}while(0);f=m&1048575;m=c[3531864]|0;l=c[m+2092+(f>>>11<<2)>>2]|0;if((l|0)==0){gg[c[m+8240>>2]&4095](f,h);return}else{a[l+f|0]=h;return}break};default:{return}}}function gc2(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=f+442|0;a[g]=(a[g]|0)-1&255;g=f+295|0;h=(e[f+((d[g]|0)+6<<1)>>1]|0)<<4;i=f+260|0;j=b[i>>1]|0;b[i>>1]=j+1&65535;i=(h+(j&65535)^c[f+256>>2])&1048575;j=c[3531864]|0;h=c[j+6188+(i>>>11<<2)>>2]|0;if((h|0)==0){k=gj[c[j+8236>>2]&4095](i)|0}else{k=a[h+i|0]|0}i=k&255;h=(k&255)>191;if(h){l=b[f+((d[g]|0)+(c[9649760+(i<<2)>>2]|0)<<1)>>1]|0}else{k=c[678944+(i<<2)>>2]|0;gj[k&4095](f)|0;l=f9x(f,c[2426954]|0)|0}k=l&65535;j=a[f+((d[f+296|0]|0)+28)|0]|0;m=f+432|0;n=(c[m>>2]|0)-((h?460546:1774342)>>>((c[f+444>>2]|0)>>>0)&127)|0;c[m>>2]=n;if(j<<24>>24==0){return}switch(i&56|0){case 24:{o=f+280|0;p=j-1&255;q=k;r=j;s=c[o>>2]|0;do{t=(((s|0)!=0)<<16)+q|0;s=t&1;q=t>>>1;r=r-1&255;}while(r<<24>>24!=0);c[o>>2]=s;c[m>>2]=n+~(p&255);if(h){b[f+((d[g]|0)+(c[9649760+(i<<2)>>2]|0)<<1)>>1]=q&65535;return}else{f9z(f,c[2426954]|0,q&65535);return}break};case 8:{q=j-1&255;p=k;s=j;do{u=p&1;p=(u<<15)+(p>>>1)|0;s=s-1&255;}while(s<<24>>24!=0);c[f+280>>2]=u;c[m>>2]=n+~(q&255);if(h){b[f+((d[g]|0)+(c[9649760+(i<<2)>>2]|0)<<1)>>1]=p&65535;return}else{f9z(f,c[2426954]|0,p&65535);return}break};case 40:{p=j&255;c[m>>2]=n-p;q=k>>>((p-1|0)>>>0);c[f+280>>2]=q&1;p=q>>>1&65535;q=p<<16>>16;c[f+284>>2]=q;c[f+276>>2]=q;c[f+264>>2]=q;if(h){b[f+((d[g]|0)+(c[9649760+(i<<2)>>2]|0)<<1)>>1]=p;return}else{f9z(f,c[2426954]|0,p);return}break};case 0:{p=j-1&255;q=k;u=j;do{v=q&32768;q=v>>>15|q<<1;u=u-1&255;}while(u<<24>>24!=0);c[f+280>>2]=v;c[m>>2]=n+~(p&255);if(h){b[f+((d[g]|0)+(c[9649760+(i<<2)>>2]|0)<<1)>>1]=q&65535;return}else{f9z(f,c[2426954]|0,q&65535);return}break};case 56:{q=j&255;c[m>>2]=n-q;p=l<<16>>16>>q-1;c[f+280>>2]=p&1;q=p>>>1&65535;p=q<<16>>16;c[f+284>>2]=p;c[f+276>>2]=p;c[f+264>>2]=p;if(h){b[f+((d[g]|0)+(c[9649760+(i<<2)>>2]|0)<<1)>>1]=q;return}else{f9z(f,c[2426954]|0,q);return}break};case 32:{q=j&255;c[m>>2]=n-q;p=k<<q;c[f+280>>2]=p&65536;q=p&65535;p=q<<16>>16;c[f+284>>2]=p;c[f+276>>2]=p;c[f+264>>2]=p;if(h){b[f+((d[g]|0)+(c[9649760+(i<<2)>>2]|0)<<1)>>1]=q;return}else{f9z(f,c[2426954]|0,q);return}break};case 16:{q=f+280|0;p=j-1&255;l=k;k=j;j=c[q>>2]|0;do{v=l<<1;l=v|(j|0)!=0;j=v&65536;k=k-1&255;}while(k<<24>>24!=0);c[q>>2]=j;c[m>>2]=n+~(p&255);if(h){b[f+((d[g]|0)+(c[9649760+(i<<2)>>2]|0)<<1)>>1]=l&65535;return}else{f9z(f,c[2426954]|0,l&65535);return}break};default:{return}}}function gc3(f){f=f|0;var g=0,h=0,i=0,j=0;g=f+442|0;a[g]=(a[g]|0)-1&255;g=f+295|0;h=e[f+((d[g]|0)+6<<1)>>1]<<4;i=f+260|0;j=b[i>>1]|0;b[i>>1]=j+1&65535;i=(h+(j&65535)^c[f+256>>2])&1048575;j=c[3531864]|0;if((c[j+6188+(i>>>11<<2)>>2]|0)==0){h=c[j+8236>>2]|0;gj[h&4095](i)|0}i=f+296|0;h=d[i]|0;j=f;a[j+(h+31)|0]=(d[j+(h+30)|0]|0)/10|0;h=j+((d[i]|0)+30)|0;a[h]=(d[h]|0)%10|0;h=b[f+((d[g]|0)+15<<1)>>1]|0;c[f+284>>2]=h;c[f+276>>2]=h;c[f+264>>2]=h;h=f+432|0;c[h>>2]=(c[h>>2]|0)-(986892>>>((c[f+444>>2]|0)>>>0)&127);return}function gc4(f){f=f|0;var g=0,h=0,i=0,j=0;g=f+442|0;a[g]=(a[g]|0)-1&255;g=e[f+((d[f+295|0]|0)+6<<1)>>1]<<4;h=f+260|0;i=b[h>>1]|0;b[h>>1]=i+1&65535;h=(g+(i&65535)^c[f+256>>2])&1048575;i=c[3531864]|0;if((c[i+6188+(h>>>11<<2)>>2]|0)==0){g=c[i+8236>>2]|0;gj[g&4095](h)|0}h=f+296|0;g=d[h]|0;i=f;j=i+(g+30)|0;a[j]=((a[i+(g+31)|0]|0)*10&255)+(a[j]|0)&255;a[i+((d[h]|0)+31)|0]=0;j=a[i+((d[h]|0)+30)|0]|0;c[f+284>>2]=j;c[f+276>>2]=j;c[f+264>>2]=j;j=f+432|0;c[j>>2]=(c[j>>2]|0)-(460552>>>((c[f+444>>2]|0)>>>0)&127);return}function gc5(b){b=b|0;var e=0;a[b+((d[b+296|0]|0)+30)|0]=((c[b+280>>2]|0)!=0)<<31>>31;e=b+432|0;c[e>>2]=(c[e>>2]|0)-3;return}function gc6(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=d[b+295|0]|0;g=b+296|0;h=b;i=(d[h+((d[g]|0)+30)|0]|0)+(e[b+(f+12<<1)>>1]|0)|0;if((a[b+452|0]|0)==0){j=e[b+(f+4<<1)>>1]<<4}else{j=c[b+448>>2]|0}f=j+(i&65535)|0;do{if((f&1048064|0)==(c[b+428>>2]|0)|(f|0)==1048575){k=j+i&511;if((a[b+424|0]|0)!=0&k>>>0<256){l=a[h+k|0]|0;break}if(k>>>0<=255){m=52767;break}l=f9w(b,k-256|0)|0}else{m=52767}}while(0);do{if((m|0)==52767){i=f&1048575;j=c[3531864]|0;k=c[j+44+(i>>>11<<2)>>2]|0;if((k|0)==0){l=gj[c[j+8236>>2]&4095](i)|0;break}else{l=a[k+i|0]|0;break}}}while(0);a[h+((d[g]|0)+30)|0]=l;l=b+432|0;c[l>>2]=(c[l>>2]|0)-(592133>>>((c[b+444>>2]|0)>>>0)&127);return}function gc7(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;g=f+442|0;a[g]=(a[g]|0)-1&255;g=(e[f+((d[f+295|0]|0)+6<<1)>>1]|0)<<4;h=f+260|0;i=b[h>>1]|0;b[h>>1]=i+1&65535;h=(g+(i&65535)^c[f+256>>2])&1048575;i=c[3531864]|0;if((c[i+6188+(h>>>11<<2)>>2]|0)!=0){j=f+432|0;k=c[j>>2]|0;l=k-2|0;c[j>>2]=l;return}gj[c[i+8236>>2]&4095](h)|0;j=f+432|0;k=c[j>>2]|0;l=k-2|0;c[j>>2]=l;return}function gc8(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=f+442|0;a[g]=(a[g]|0)-1&255;g=f+295|0;h=a[g]|0;i=e[f+((h&255)+6<<1)>>1]<<4;j=f+260|0;k=b[j>>1]|0;b[j>>1]=k+1&65535;l=(i+(k&65535)^c[f+256>>2])&1048575;k=c[3531864]|0;i=c[k+6188+(l>>>11<<2)>>2]|0;if((i|0)==0){m=gj[c[k+8236>>2]&4095](l)|0;n=m;o=a[g]|0}else{n=a[i+l|0]|0;o=h}h=f+((o&255)+14<<1)|0;b[h>>1]=(b[h>>1]|0)-1&65535;do{if((c[f+276>>2]|0)!=0){if((b[f+((d[g]|0)+14<<1)>>1]|0)==0){break}b[j>>1]=(b[j>>1]|0)+(n<<24>>24)&65535;h=f+432|0;c[h>>2]=(c[h>>2]|0)-(921094>>>((c[f+444>>2]|0)>>>0)&127);return}}while(0);n=f+432|0;c[n>>2]=(c[n>>2]|0)-(328963>>>((c[f+444>>2]|0)>>>0)&127);return}function gc9(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=f+442|0;a[g]=(a[g]|0)-1&255;g=f+295|0;h=a[g]|0;i=e[f+((h&255)+6<<1)>>1]<<4;j=f+260|0;k=b[j>>1]|0;b[j>>1]=k+1&65535;l=(i+(k&65535)^c[f+256>>2])&1048575;k=c[3531864]|0;i=c[k+6188+(l>>>11<<2)>>2]|0;if((i|0)==0){m=gj[c[k+8236>>2]&4095](l)|0;n=m;o=a[g]|0}else{n=a[i+l|0]|0;o=h}h=f+((o&255)+14<<1)|0;b[h>>1]=(b[h>>1]|0)-1&65535;do{if((c[f+276>>2]|0)==0){if((b[f+((d[g]|0)+14<<1)>>1]|0)==0){break}b[j>>1]=(b[j>>1]|0)+(n<<24>>24)&65535;h=f+432|0;c[h>>2]=(c[h>>2]|0)-(921094>>>((c[f+444>>2]|0)>>>0)&127);return}}while(0);n=f+432|0;c[n>>2]=(c[n>>2]|0)-(328963>>>((c[f+444>>2]|0)>>>0)&127);return}function gda(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=f+442|0;a[g]=(a[g]|0)-1&255;g=f+295|0;h=a[g]|0;i=e[f+((h&255)+6<<1)>>1]<<4;j=f+260|0;k=b[j>>1]|0;b[j>>1]=k+1&65535;l=(i+(k&65535)^c[f+256>>2])&1048575;k=c[3531864]|0;i=c[k+6188+(l>>>11<<2)>>2]|0;if((i|0)==0){m=gj[c[k+8236>>2]&4095](l)|0;n=m;o=a[g]|0}else{n=a[i+l|0]|0;o=h}h=f+((o&255)+14<<1)|0;b[h>>1]=(b[h>>1]|0)-1&65535;if((b[f+((d[g]|0)+14<<1)>>1]|0)==0){g=f+432|0;c[g>>2]=(c[g>>2]|0)-(328963>>>((c[f+444>>2]|0)>>>0)&127);return}else{b[j>>1]=(b[j>>1]|0)+(n<<24>>24)&65535;n=f+432|0;c[n>>2]=(c[n>>2]|0)-(855302>>>((c[f+444>>2]|0)>>>0)&127);return}}function gdb(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=d+442|0;a[f]=(a[f]|0)-1&255;f=d+295|0;g=a[f]|0;h=e[d+((g&255)+6<<1)>>1]<<4;i=d+260|0;j=b[i>>1]|0;b[i>>1]=j+1&65535;k=(h+(j&65535)^c[d+256>>2])&1048575;j=c[3531864]|0;h=c[j+6188+(k>>>11<<2)>>2]|0;if((h|0)==0){l=gj[c[j+8236>>2]&4095](k)|0;m=l;n=a[f]|0}else{m=a[h+k|0]|0;n=g}if((b[d+((n&255)+14<<1)>>1]|0)==0){b[i>>1]=(b[i>>1]|0)+(m<<24>>24)&65535;m=d+432|0;c[m>>2]=(c[m>>2]|0)-(855302>>>((c[d+444>>2]|0)>>>0)&127);return}else{m=d+432|0;c[m>>2]=(c[m>>2]|0)-(328963>>>((c[d+444>>2]|0)>>>0)&127);return}}function gdc(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;g=f+442|0;a[g]=(a[g]|0)-1&255;g=(e[f+((d[f+295|0]|0)+6<<1)>>1]|0)<<4;h=f+260|0;i=b[h>>1]|0;b[h>>1]=i+1&65535;h=(g+(i&65535)^c[f+256>>2])&1048575;i=c[3531864]|0;g=c[i+6188+(h>>>11<<2)>>2]|0;if((g|0)==0){j=gj[c[i+8236>>2]&4095](h)|0;k=j;l=c[3531864]|0}else{k=a[g+h|0]|0;l=i}i=gj[c[l+8244>>2]&4095](k&255)|0;a[f+((d[f+296|0]|0)+30)|0]=i;i=f+432|0;c[i>>2]=(c[i>>2]|0)-(592133>>>((c[f+444>>2]|0)>>>0)&127);return}function gdd(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=f+442|0;a[g]=(a[g]|0)-1&255;g=f+295|0;h=(e[f+((d[g]|0)+6<<1)>>1]|0)<<4;i=f+260|0;j=b[i>>1]|0;b[i>>1]=j+1&65535;i=(h+(j&65535)^c[f+256>>2])&1048575;j=c[3531864]|0;h=c[j+6188+(i>>>11<<2)>>2]|0;if((h|0)==0){k=gj[c[j+8236>>2]&4095](i)|0;l=k;m=c[3531864]|0}else{l=a[h+i|0]|0;m=j}j=l&255;l=(gj[c[m+8244>>2]&4095](j)|0)&255;m=((gj[c[(c[3531864]|0)+8244>>2]&4095](j+1&255)|0)&255)<<8|l;b[f+((d[g]|0)+15<<1)>>1]=m;m=f+432|0;c[m>>2]=(c[m>>2]|0)-(((j&1|0)!=0?855303:854277)>>>((c[f+444>>2]|0)>>>0)&127);return}function gde(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;g=f+442|0;a[g]=(a[g]|0)-1&255;g=(e[f+((d[f+295|0]|0)+6<<1)>>1]|0)<<4;h=f+260|0;i=b[h>>1]|0;b[h>>1]=i+1&65535;h=(g+(i&65535)^c[f+256>>2])&1048575;i=c[3531864]|0;g=c[i+6188+(h>>>11<<2)>>2]|0;if((g|0)==0){j=gj[c[i+8236>>2]&4095](h)|0;k=j;l=c[3531864]|0}else{k=a[g+h|0]|0;l=i}gg[c[l+8248>>2]&4095](k&255,a[f+((d[f+296|0]|0)+30)|0]|0);k=f+432|0;c[k>>2]=(c[k>>2]|0)-(526339>>>((c[f+444>>2]|0)>>>0)&127);return}function gdf(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=d+442|0;a[f]=(a[f]|0)-1&255;f=d+295|0;g=a[f]|0;h=(e[d+((g&255)+6<<1)>>1]|0)<<4;i=d+260|0;j=b[i>>1]|0;b[i>>1]=j+1&65535;i=(h+(j&65535)^c[d+256>>2])&1048575;j=c[3531864]|0;h=c[j+6188+(i>>>11<<2)>>2]|0;if((h|0)==0){k=gj[c[j+8236>>2]&4095](i)|0;l=k;m=a[f]|0;n=c[3531864]|0}else{l=a[h+i|0]|0;m=g;n=j}j=l&255;l=b[d+((m&255)+15<<1)>>1]|0;gg[c[n+8248>>2]&4095](j,l&255);gg[c[(c[3531864]|0)+8248>>2]&4095](j+1|0,(l&65535)>>>8&255);l=d+432|0;c[l>>2]=(c[l>>2]|0)-(((j&1|0)!=0?789509:788483)>>>((c[d+444>>2]|0)>>>0)&127);return}function gdg(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;g=f+442|0;h=(a[g]|0)-1&255;a[g]=h;i=f+295|0;j=a[i]|0;k=(e[f+((j&255)+6<<1)>>1]|0)<<4;l=f+260|0;m=b[l>>1]|0;n=m+1&65535;b[l>>1]=n;o=f+256|0;p=c[o>>2]|0;q=(k+(m&65535)^p)&1048575;m=c[3531864]|0;k=c[m+6188+(q>>>11<<2)>>2]|0;if((k|0)==0){r=gj[c[m+8236>>2]&4095](q)|0;s=r;t=a[g]|0;u=a[i]|0;v=b[l>>1]|0;w=c[o>>2]|0;x=c[3531864]|0}else{s=a[k+q|0]|0;t=h;u=j;v=n;w=p;x=m}a[g]=t-1&255;t=(e[f+((u&255)+6<<1)>>1]|0)<<4;b[l>>1]=v+1&65535;g=(t+(v&65535)^w)&1048575;w=c[x+6188+(g>>>11<<2)>>2]|0;if((w|0)==0){v=gj[c[x+8236>>2]&4095](g)|0;y=v;z=a[i]|0}else{y=a[w+g|0]|0;z=u}u=f+((z&255)+11<<1)|0;b[u>>1]=(b[u>>1]|0)-2&65535;u=d[i]|0;f9z(f,((e[f+(u+5<<1)>>1]|0)<<4)+(e[f+(u+11<<1)>>1]|0)|0,b[l>>1]|0);b[l>>1]=(b[l>>1]|0)+((y&255)<<8|s&255)&65535;a[f+443|0]=1;s=f+432|0;c[s>>2]=(c[s>>2]|0)-24;return}function gdh(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;f=d+442|0;g=(a[f]|0)-1&255;a[f]=g;h=d+295|0;i=a[h]|0;j=(e[d+((i&255)+6<<1)>>1]|0)<<4;k=d+260|0;l=b[k>>1]|0;m=l+1&65535;b[k>>1]=m;n=d+256|0;o=c[n>>2]|0;p=(j+(l&65535)^o)&1048575;l=c[3531864]|0;j=c[l+6188+(p>>>11<<2)>>2]|0;if((j|0)==0){q=gj[c[l+8236>>2]&4095](p)|0;r=q;s=a[f]|0;t=a[h]|0;u=b[k>>1]|0;v=c[n>>2]|0;w=c[3531864]|0}else{r=a[j+p|0]|0;s=g;t=i;u=m;v=o;w=l}a[f]=s-1&255;s=(e[d+((t&255)+6<<1)>>1]|0)<<4;t=u+1&65535;b[k>>1]=t;f=(s+(u&65535)^v)&1048575;v=c[w+6188+(f>>>11<<2)>>2]|0;if((v|0)==0){u=gj[c[w+8236>>2]&4095](f)|0;x=u;y=b[k>>1]|0;z=x&255;A=z<<8;B=r&255;C=A|B;D=C+y&65535;b[k>>1]=D;E=d+443|0;a[E]=1;F=d+432|0;G=c[F>>2]|0;H=G-15|0;c[F>>2]=H;return}else{x=a[v+f|0]|0;y=t;z=x&255;A=z<<8;B=r&255;C=A|B;D=C+y&65535;b[k>>1]=D;E=d+443|0;a[E]=1;F=d+432|0;G=c[F>>2]|0;H=G-15|0;c[F>>2]=H;return}}function gdi(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;f=d+442|0;g=(a[f]|0)-1&255;a[f]=g;h=d+295|0;i=a[h]|0;j=(e[d+((i&255)+6<<1)>>1]|0)<<4;k=d+260|0;l=b[k>>1]|0;m=l+1&65535;b[k>>1]=m;n=d+256|0;o=c[n>>2]|0;p=(j+(l&65535)^o)&1048575;l=c[3531864]|0;j=c[l+6188+(p>>>11<<2)>>2]|0;if((j|0)==0){q=gj[c[l+8236>>2]&4095](p)|0;r=q;s=a[f]|0;t=a[h]|0;u=b[k>>1]|0;v=c[n>>2]|0;w=c[3531864]|0}else{r=a[j+p|0]|0;s=g;t=i;u=m;v=o;w=l}l=s-1&255;a[f]=l;s=(e[d+((t&255)+6<<1)>>1]|0)<<4;o=u+1&65535;b[k>>1]=o;m=(s+(u&65535)^v)&1048575;u=c[w+6188+(m>>>11<<2)>>2]|0;if((u|0)==0){s=gj[c[w+8236>>2]&4095](m)|0;x=s;y=a[f]|0;z=a[h]|0;A=b[k>>1]|0;B=c[n>>2]|0;C=c[3531864]|0}else{x=a[u+m|0]|0;y=l;z=t;A=o;B=v;C=w}w=(x&255)<<8|r&255;r=y-1&255;a[f]=r;y=(e[d+((z&255)+6<<1)>>1]|0)<<4;x=A+1&65535;b[k>>1]=x;v=(y+(A&65535)^B)&1048575;A=c[C+6188+(v>>>11<<2)>>2]|0;if((A|0)==0){y=gj[c[C+8236>>2]&4095](v)|0;D=y;E=a[f]|0;F=a[h]|0;G=b[k>>1]|0;H=c[n>>2]|0;I=c[3531864]|0}else{D=a[A+v|0]|0;E=r;F=z;G=x;H=B;I=C}a[f]=E-1&255;E=(e[d+((F&255)+6<<1)>>1]|0)<<4;b[k>>1]=G+1&65535;f=(E+(G&65535)^H)&1048575;H=c[I+6188+(f>>>11<<2)>>2]|0;if((H|0)==0){G=gj[c[I+8236>>2]&4095](f)|0;J=G;K=a[h]|0;L=J&255;M=L<<8;N=D&255;O=M|N;P=K&255;Q=P+6|0;R=d+(Q<<1)|0;b[R>>1]=O;b[k>>1]=w;S=d+443|0;a[S]=1;T=d+432|0;U=c[T>>2]|0;V=U-27|0;c[T>>2]=V;return}else{J=a[H+f|0]|0;K=F;L=J&255;M=L<<8;N=D&255;O=M|N;P=K&255;Q=P+6|0;R=d+(Q<<1)|0;b[R>>1]=O;b[k>>1]=w;S=d+443|0;a[S]=1;T=d+432|0;U=c[T>>2]|0;V=U-27|0;c[T>>2]=V;return}}function gdj(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=f+442|0;a[g]=(a[g]|0)-1&255;g=(e[f+((d[f+295|0]|0)+6<<1)>>1]|0)<<4;h=f+260|0;i=b[h>>1]|0;j=i+1&65535;b[h>>1]=j;k=(g+(i&65535)^c[f+256>>2])&1048575;i=c[3531864]|0;g=c[i+6188+(k>>>11<<2)>>2]|0;if((g|0)==0){l=gj[c[i+8236>>2]&4095](k)|0;m=l;n=b[h>>1]|0;o=m<<24>>24;p=f+432|0;q=c[p>>2]|0;r=q-12|0;c[p>>2]=r;s=n+o&65535;b[h>>1]=s;return}else{m=a[g+k|0]|0;n=j;o=m<<24>>24;p=f+432|0;q=c[p>>2]|0;r=q-12|0;c[p>>2]=r;s=n+o&65535;b[h>>1]=s;return}}function gdk(e){e=e|0;var f=0;f=gj[c[(c[3531864]|0)+8244>>2]&4095](b[e+((d[e+295|0]|0)+13<<1)>>1]&255)|0;a[e+((d[e+296|0]|0)+30)|0]=f;f=e+432|0;c[f>>2]=(c[f>>2]|0)-(526341>>>((c[e+444>>2]|0)>>>0)&127);return}function gdl(a){a=a|0;var f=0,g=0,h=0;f=a+295|0;g=(gj[c[(c[3531864]|0)+8244>>2]&4095](b[a+((d[f]|0)+13<<1)>>1]&255)|0)&255;h=((gj[c[(c[3531864]|0)+8244>>2]&4095]((e[a+((d[f]|0)+13<<1)>>1]|0)+1&65791)|0)&255)<<8|g;b[a+((d[f]|0)+15<<1)>>1]=h;h=a+432|0;c[h>>2]=(c[h>>2]|0)-(((b[a+((d[f]|0)+13<<1)>>1]&1)!=0?789511:788485)>>>((c[a+444>>2]|0)>>>0)&127);return}function gdm(b){b=b|0;var f=0;gg[c[(c[3531864]|0)+8248>>2]&4095](e[b+((d[b+295|0]|0)+13<<1)>>1]|0,a[b+((d[b+296|0]|0)+30)|0]|0);f=b+432|0;c[f>>2]=(c[f>>2]|0)-(526339>>>((c[b+444>>2]|0)>>>0)&127);return}function gdn(a){a=a|0;var f=0,g=0,h=0,i=0;f=a+295|0;g=d[f]|0;h=e[a+(g+13<<1)>>1]|0;i=b[a+(g+15<<1)>>1]|0;gg[c[(c[3531864]|0)+8248>>2]&4095](h,i&255);gg[c[(c[3531864]|0)+8248>>2]&4095](h+1|0,(i&65535)>>>8&255);i=a+432|0;c[i>>2]=(c[i>>2]|0)-(((b[a+((d[f]|0)+13<<1)>>1]&1)!=0?789509:788483)>>>((c[a+444>>2]|0)>>>0)&127);return}function gdo(b){b=b|0;var d=0;a[b+352|0]=1;d=b+432|0;c[d>>2]=(c[d>>2]|0)-2;return}function gdp(f){f=f|0;var g=0,h=0,i=0,j=0;g=f+442|0;a[g]=(a[g]|0)-1&255;g=(e[f+((d[f+295|0]|0)+6<<1)>>1]|0)<<4;h=f+260|0;i=b[h>>1]|0;b[h>>1]=i+1&65535;h=(g+(i&65535)^c[f+256>>2])&1048575;i=c[3531864]|0;g=c[i+6188+(h>>>11<<2)>>2]|0;if((g|0)==0){j=gj[c[i+8236>>2]&4095](h)|0}else{j=a[g+h|0]|0}gd0(f,j&255,262144);j=f+432|0;c[j>>2]=(c[j>>2]|0)-(3289624>>>((c[f+444>>2]|0)>>>0)&127);return}function gdq(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;g=f+442|0;a[g]=(a[g]|0)-1&255;h=f+295|0;i=(e[f+((d[h]|0)+6<<1)>>1]|0)<<4;j=f+260|0;k=b[j>>1]|0;b[j>>1]=k+1&65535;l=f+256|0;m=(i+(k&65535)^c[l>>2])&1048575;k=c[3531864]|0;i=c[k+4140+(m>>>11<<2)>>2]|0;if((i|0)==0){n=gj[c[k+8236>>2]&4095](m)|0}else{n=a[i+m|0]|0}m=f+294|0;i=a[m]|0;do{if(i<<24>>24==0){k=c[f+436>>2]|0;if((k|0)==0){o=n;break}o=a[k+(n&255)|0]|0}else{o=n}}while(0);n=o&255;o=d[h]|0;k=b[f+(o+14<<1)>>1]|0;if((n|0)==46){a[f+452|0]=1;p=f+(o+6<<1)|0;c[f+448>>2]=(e[p>>1]|0)<<4;a[g]=(a[g]|0)-1&255;q=(e[p>>1]|0)<<4;p=b[j>>1]|0;b[j>>1]=p+1&65535;r=(q+(p&65535)^c[l>>2])&1048575;p=c[3531864]|0;q=c[p+4140+(r>>>11<<2)>>2]|0;if((q|0)==0){s=gj[c[p+8236>>2]&4095](r)|0;t=s;u=a[m]|0}else{t=a[q+r|0]|0;u=i}do{if(u<<24>>24==0){r=c[f+436>>2]|0;if((r|0)==0){v=t;break}v=a[r+(t&255)|0]|0}else{v=t}}while(0);t=f+432|0;c[t>>2]=(c[t>>2]|0)-2;w=v&255}else if((n|0)==38){a[f+452|0]=1;c[f+448>>2]=(e[f+(o+7<<1)>>1]|0)<<4;a[g]=(a[g]|0)-1&255;v=(e[f+(o+6<<1)>>1]|0)<<4;t=b[j>>1]|0;b[j>>1]=t+1&65535;u=(v+(t&65535)^c[l>>2])&1048575;t=c[3531864]|0;v=c[t+4140+(u>>>11<<2)>>2]|0;if((v|0)==0){r=gj[c[t+8236>>2]&4095](u)|0;x=r;y=a[m]|0}else{x=a[v+u|0]|0;y=i}do{if(y<<24>>24==0){u=c[f+436>>2]|0;if((u|0)==0){z=x;break}z=a[u+(x&255)|0]|0}else{z=x}}while(0);x=f+432|0;c[x>>2]=(c[x>>2]|0)-2;w=z&255}else if((n|0)==62){a[f+452|0]=1;c[f+448>>2]=(e[f+(o+4<<1)>>1]|0)<<4;a[g]=(a[g]|0)-1&255;z=(e[f+(o+6<<1)>>1]|0)<<4;x=b[j>>1]|0;b[j>>1]=x+1&65535;y=(z+(x&65535)^c[l>>2])&1048575;x=c[3531864]|0;z=c[x+4140+(y>>>11<<2)>>2]|0;if((z|0)==0){u=gj[c[x+8236>>2]&4095](y)|0;A=u;B=a[m]|0}else{A=a[z+y|0]|0;B=i}do{if(B<<24>>24==0){y=c[f+436>>2]|0;if((y|0)==0){C=A;break}C=a[y+(A&255)|0]|0}else{C=A}}while(0);A=f+432|0;c[A>>2]=(c[A>>2]|0)-2;w=C&255}else if((n|0)==54){a[f+452|0]=1;c[f+448>>2]=(e[f+(o+5<<1)>>1]|0)<<4;a[g]=(a[g]|0)-1&255;g=(e[f+(o+6<<1)>>1]|0)<<4;o=b[j>>1]|0;b[j>>1]=o+1&65535;j=(g+(o&65535)^c[l>>2])&1048575;l=c[3531864]|0;o=c[l+4140+(j>>>11<<2)>>2]|0;if((o|0)==0){g=gj[c[l+8236>>2]&4095](j)|0;D=g;E=a[m]|0}else{D=a[o+j|0]|0;E=i}do{if(E<<24>>24==0){i=c[f+436>>2]|0;if((i|0)==0){F=D;break}F=a[i+(D&255)|0]|0}else{F=D}}while(0);D=f+432|0;c[D>>2]=(c[D>>2]|0)-2;w=F&255}else{w=n}switch(w|0){case 111:{n=f+432|0;c[n>>2]=(c[n>>2]|0)-2;if(k<<16>>16!=0){n=k;do{gbu(f);n=n-1&65535;}while(n<<16>>16!=0)}b[f+((d[h]|0)+14<<1)>>1]=0;G=f+452|0;a[G]=0;return};case 167:{n=f+432|0;c[n>>2]=(c[n>>2]|0)-2;L65091:do{if(k<<16>>16==0){H=0}else{n=f+276|0;F=k;while(1){gcm(f);D=F-1&65535;if(D<<16>>16==0){H=0;break L65091}if((c[n>>2]|0)==0){H=D;break}else{F=D}}}}while(0);b[f+((d[h]|0)+14<<1)>>1]=H;G=f+452|0;a[G]=0;return};case 172:{H=f+432|0;c[H>>2]=(c[H>>2]|0)-2;if(k<<16>>16!=0){H=k;do{gcr(f);H=H-1&65535;}while(H<<16>>16!=0)}b[f+((d[h]|0)+14<<1)>>1]=0;G=f+452|0;a[G]=0;return};case 110:{H=f+432|0;c[H>>2]=(c[H>>2]|0)-2;if(k<<16>>16!=0){H=k;do{gbt(f);H=H-1&65535;}while(H<<16>>16!=0)}b[f+((d[h]|0)+14<<1)>>1]=0;G=f+452|0;a[G]=0;return};case 174:{H=f+432|0;c[H>>2]=(c[H>>2]|0)-2;L65111:do{if(k<<16>>16==0){I=0}else{H=f+276|0;F=k;while(1){gct(f);n=F-1&65535;if(n<<16>>16==0){I=0;break L65111}if((c[H>>2]|0)==0){I=n;break}else{F=n}}}}while(0);b[f+((d[h]|0)+14<<1)>>1]=I;G=f+452|0;a[G]=0;return};case 164:{I=f+432|0;c[I>>2]=(c[I>>2]|0)-2;if(k<<16>>16!=0){I=k;do{gcj(f);I=I-1&65535;}while(I<<16>>16!=0)}b[f+((d[h]|0)+14<<1)>>1]=0;G=f+452|0;a[G]=0;return};case 173:{I=f+432|0;c[I>>2]=(c[I>>2]|0)-2;if(k<<16>>16!=0){I=k;do{gcs(f);I=I-1&65535;}while(I<<16>>16!=0)}b[f+((d[h]|0)+14<<1)>>1]=0;G=f+452|0;a[G]=0;return};case 171:{I=f+432|0;c[I>>2]=(c[I>>2]|0)-2;if(k<<16>>16==0){J=a[h]|0}else{F=f+293|0;H=f+444|0;n=k;D=a[h]|0;while(1){E=D&255;f9z(f,((e[f+(E+7<<1)>>1]|0)<<4)+(e[f+(E+8<<1)>>1]|0)|0,b[f+(E+15<<1)>>1]|0);E=f+((d[h]|0)+8<<1)|0;b[E>>1]=((d[F]|0)*-4&65535|2)+(b[E>>1]|0)&65535;E=a[h]|0;c[I>>2]=(c[I>>2]|0)-(((b[f+((E&255)+8<<1)>>1]&1)!=0?526341:525315)>>>((c[H>>2]|0)>>>0)&127);i=n-1&65535;if(i<<16>>16==0){J=E;break}else{n=i;D=E}}}b[f+((J&255)+14<<1)>>1]=0;G=f+452|0;a[G]=0;return};case 166:{J=f+432|0;c[J>>2]=(c[J>>2]|0)-2;L65141:do{if(k<<16>>16==0){K=0}else{J=f+276|0;D=k;while(1){gcl(f);n=D-1&65535;if(n<<16>>16==0){K=0;break L65141}if((c[J>>2]|0)==0){K=n;break}else{D=n}}}}while(0);b[f+((d[h]|0)+14<<1)>>1]=K;G=f+452|0;a[G]=0;return};case 165:{K=f+432|0;c[K>>2]=(c[K>>2]|0)-2;if(k<<16>>16!=0){K=k;do{gck(f);K=K-1&65535;}while(K<<16>>16!=0)}b[f+((d[h]|0)+14<<1)>>1]=0;G=f+452|0;a[G]=0;return};case 170:{K=f+432|0;c[K>>2]=(c[K>>2]|0)-2;if(k<<16>>16!=0){K=k;do{gcp(f);K=K-1&65535;}while(K<<16>>16!=0)}b[f+((d[h]|0)+14<<1)>>1]=0;G=f+452|0;a[G]=0;return};case 175:{K=f+432|0;c[K>>2]=(c[K>>2]|0)-2;L65161:do{if(k<<16>>16==0){L=0;M=a[h]|0}else{D=f+280|0;J=f+272|0;n=f+268|0;H=f+284|0;I=f+276|0;F=f+264|0;E=f+293|0;i=f+444|0;j=k;o=a[h]|0;while(1){m=o&255;g=f9x(f,((e[f+(m+7<<1)>>1]|0)<<4)+(e[f+(m+8<<1)>>1]|0)|0)|0;m=d[h]|0;l=b[f+(m+15<<1)>>1]|0;C=l&65535;A=C-(g&65535)|0;c[D>>2]=A&65536;B=(l^g)&65535;c[J>>2]=B&32768&(A^C);c[n>>2]=(A^B)&16;B=A<<16>>16;c[H>>2]=B;c[I>>2]=B;c[F>>2]=B;B=f+(m+8<<1)|0;b[B>>1]=((d[E]|0)*-4&65535|2)+(b[B>>1]|0)&65535;B=a[h]|0;c[K>>2]=(c[K>>2]|0)-(((b[f+((B&255)+8<<1)>>1]&1)!=0?526341:525315)>>>((c[i>>2]|0)>>>0)&127);m=j-1&65535;if(m<<16>>16==0){L=0;M=B;break L65161}if((c[I>>2]|0)==0){L=m;M=B;break}else{j=m;o=B}}}}while(0);b[f+((M&255)+14<<1)>>1]=L;G=f+452|0;a[G]=0;return};case 109:{L=f+432|0;c[L>>2]=(c[L>>2]|0)-2;if(k<<16>>16!=0){M=f+293|0;K=f+444|0;o=k;do{j=d[h]|0;I=((e[f+(j+7<<1)>>1]|0)<<4)+(e[f+(j+8<<1)>>1]|0)|0;i=(gj[c[(c[3531864]|0)+8244>>2]&4095](b[f+(j+13<<1)>>1]&255)|0)&255;f9z(f,I,((gj[c[(c[3531864]|0)+8244>>2]&4095]((e[f+((d[h]|0)+13<<1)>>1]|0)+1&65791)|0)&255)<<8|i);i=f+((d[h]|0)+8<<1)|0;b[i>>1]=((d[M]|0)*-4&65535|2)+(b[i>>1]|0)&65535;c[L>>2]=(c[L>>2]|0)-(1182216>>>((c[K>>2]|0)>>>0)&127);o=o-1&65535;}while(o<<16>>16!=0)}b[f+((d[h]|0)+14<<1)>>1]=0;G=f+452|0;a[G]=0;return};case 108:{o=f+432|0;c[o>>2]=(c[o>>2]|0)-2;if(k<<16>>16!=0){o=k;do{gbr(f);o=o-1&65535;}while(o<<16>>16!=0)}b[f+((d[h]|0)+14<<1)>>1]=0;G=f+452|0;a[G]=0;return};default:{gf[c[2519504+(w<<2)>>2]&2047](f);G=f+452|0;a[G]=0;return}}}function gdr(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;g=f+442|0;a[g]=(a[g]|0)-1&255;h=f+295|0;i=(e[f+((d[h]|0)+6<<1)>>1]|0)<<4;j=f+260|0;k=b[j>>1]|0;b[j>>1]=k+1&65535;l=f+256|0;m=(i+(k&65535)^c[l>>2])&1048575;k=c[3531864]|0;i=c[k+4140+(m>>>11<<2)>>2]|0;if((i|0)==0){n=gj[c[k+8236>>2]&4095](m)|0}else{n=a[i+m|0]|0}m=f+294|0;i=a[m]|0;do{if(i<<24>>24==0){k=c[f+436>>2]|0;if((k|0)==0){o=n;break}o=a[k+(n&255)|0]|0}else{o=n}}while(0);n=o&255;o=d[h]|0;k=b[f+(o+14<<1)>>1]|0;if((n|0)==38){a[f+452|0]=1;c[f+448>>2]=(e[f+(o+7<<1)>>1]|0)<<4;a[g]=(a[g]|0)-1&255;p=(e[f+(o+6<<1)>>1]|0)<<4;q=b[j>>1]|0;b[j>>1]=q+1&65535;r=(p+(q&65535)^c[l>>2])&1048575;q=c[3531864]|0;p=c[q+4140+(r>>>11<<2)>>2]|0;if((p|0)==0){s=gj[c[q+8236>>2]&4095](r)|0;t=s;u=a[m]|0}else{t=a[p+r|0]|0;u=i}do{if(u<<24>>24==0){r=c[f+436>>2]|0;if((r|0)==0){v=t;break}v=a[r+(t&255)|0]|0}else{v=t}}while(0);t=f+432|0;c[t>>2]=(c[t>>2]|0)-2;w=v&255}else if((n|0)==54){a[f+452|0]=1;c[f+448>>2]=(e[f+(o+5<<1)>>1]|0)<<4;a[g]=(a[g]|0)-1&255;v=(e[f+(o+6<<1)>>1]|0)<<4;t=b[j>>1]|0;b[j>>1]=t+1&65535;u=(v+(t&65535)^c[l>>2])&1048575;t=c[3531864]|0;v=c[t+4140+(u>>>11<<2)>>2]|0;if((v|0)==0){r=gj[c[t+8236>>2]&4095](u)|0;x=r;y=a[m]|0}else{x=a[v+u|0]|0;y=i}do{if(y<<24>>24==0){u=c[f+436>>2]|0;if((u|0)==0){z=x;break}z=a[u+(x&255)|0]|0}else{z=x}}while(0);x=f+432|0;c[x>>2]=(c[x>>2]|0)-2;w=z&255}else if((n|0)==62){a[f+452|0]=1;c[f+448>>2]=(e[f+(o+4<<1)>>1]|0)<<4;a[g]=(a[g]|0)-1&255;z=(e[f+(o+6<<1)>>1]|0)<<4;x=b[j>>1]|0;b[j>>1]=x+1&65535;y=(z+(x&65535)^c[l>>2])&1048575;x=c[3531864]|0;z=c[x+4140+(y>>>11<<2)>>2]|0;if((z|0)==0){u=gj[c[x+8236>>2]&4095](y)|0;A=u;B=a[m]|0}else{A=a[z+y|0]|0;B=i}do{if(B<<24>>24==0){y=c[f+436>>2]|0;if((y|0)==0){C=A;break}C=a[y+(A&255)|0]|0}else{C=A}}while(0);A=f+432|0;c[A>>2]=(c[A>>2]|0)-2;w=C&255}else if((n|0)==46){a[f+452|0]=1;C=f+(o+6<<1)|0;c[f+448>>2]=(e[C>>1]|0)<<4;a[g]=(a[g]|0)-1&255;g=(e[C>>1]|0)<<4;C=b[j>>1]|0;b[j>>1]=C+1&65535;j=(g+(C&65535)^c[l>>2])&1048575;l=c[3531864]|0;C=c[l+4140+(j>>>11<<2)>>2]|0;if((C|0)==0){g=gj[c[l+8236>>2]&4095](j)|0;D=g;E=a[m]|0}else{D=a[C+j|0]|0;E=i}do{if(E<<24>>24==0){i=c[f+436>>2]|0;if((i|0)==0){F=D;break}F=a[i+(D&255)|0]|0}else{F=D}}while(0);D=f+432|0;c[D>>2]=(c[D>>2]|0)-2;w=F&255}else{w=n}switch(w|0){case 172:{n=f+432|0;c[n>>2]=(c[n>>2]|0)-2;if(k<<16>>16!=0){n=k;do{gcr(f);n=n-1&65535;}while(n<<16>>16!=0)}b[f+((d[h]|0)+14<<1)>>1]=0;G=f+452|0;a[G]=0;return};case 164:{n=f+432|0;c[n>>2]=(c[n>>2]|0)-2;if(k<<16>>16!=0){n=k;do{gcj(f);n=n-1&65535;}while(n<<16>>16!=0)}b[f+((d[h]|0)+14<<1)>>1]=0;G=f+452|0;a[G]=0;return};case 166:{n=f+432|0;c[n>>2]=(c[n>>2]|0)-2;L65245:do{if(k<<16>>16==0){H=0}else{n=f+276|0;F=k;while(1){gcl(f);D=F-1&65535;if(D<<16>>16==0){H=0;break L65245}if((c[n>>2]|0)==0){F=D}else{H=D;break}}}}while(0);b[f+((d[h]|0)+14<<1)>>1]=H;G=f+452|0;a[G]=0;return};case 175:{H=f+432|0;c[H>>2]=(c[H>>2]|0)-2;L65253:do{if(k<<16>>16==0){I=0;J=a[h]|0}else{F=f+280|0;n=f+272|0;D=f+268|0;E=f+284|0;i=f+276|0;j=f+264|0;C=f+293|0;m=f+444|0;g=k;l=a[h]|0;while(1){o=l&255;A=f9x(f,((e[f+(o+7<<1)>>1]|0)<<4)+(e[f+(o+8<<1)>>1]|0)|0)|0;o=d[h]|0;B=b[f+(o+15<<1)>>1]|0;y=B&65535;z=y-(A&65535)|0;c[F>>2]=z&65536;u=(B^A)&65535;c[n>>2]=u&32768&(z^y);c[D>>2]=(z^u)&16;u=z<<16>>16;c[E>>2]=u;c[i>>2]=u;c[j>>2]=u;u=f+(o+8<<1)|0;b[u>>1]=((d[C]|0)*-4&65535|2)+(b[u>>1]|0)&65535;u=a[h]|0;c[H>>2]=(c[H>>2]|0)-(((b[f+((u&255)+8<<1)>>1]&1)!=0?526341:525315)>>>((c[m>>2]|0)>>>0)&127);o=g-1&65535;if(o<<16>>16==0){I=0;J=u;break L65253}if((c[i>>2]|0)==0){g=o;l=u}else{I=o;J=u;break}}}}while(0);b[f+((J&255)+14<<1)>>1]=I;G=f+452|0;a[G]=0;return};case 171:{I=f+432|0;c[I>>2]=(c[I>>2]|0)-2;if(k<<16>>16==0){K=a[h]|0}else{J=f+293|0;H=f+444|0;l=k;g=a[h]|0;while(1){i=g&255;f9z(f,((e[f+(i+7<<1)>>1]|0)<<4)+(e[f+(i+8<<1)>>1]|0)|0,b[f+(i+15<<1)>>1]|0);i=f+((d[h]|0)+8<<1)|0;b[i>>1]=((d[J]|0)*-4&65535|2)+(b[i>>1]|0)&65535;i=a[h]|0;c[I>>2]=(c[I>>2]|0)-(((b[f+((i&255)+8<<1)>>1]&1)!=0?526341:525315)>>>((c[H>>2]|0)>>>0)&127);m=l-1&65535;if(m<<16>>16==0){K=i;break}else{l=m;g=i}}}b[f+((K&255)+14<<1)>>1]=0;G=f+452|0;a[G]=0;return};case 108:{K=f+432|0;c[K>>2]=(c[K>>2]|0)-2;if(k<<16>>16!=0){K=k;do{gbr(f);K=K-1&65535;}while(K<<16>>16!=0)}b[f+((d[h]|0)+14<<1)>>1]=0;G=f+452|0;a[G]=0;return};case 109:{K=f+432|0;c[K>>2]=(c[K>>2]|0)-2;if(k<<16>>16!=0){g=f+293|0;l=f+444|0;H=k;do{I=d[h]|0;J=((e[f+(I+7<<1)>>1]|0)<<4)+(e[f+(I+8<<1)>>1]|0)|0;i=(gj[c[(c[3531864]|0)+8244>>2]&4095](b[f+(I+13<<1)>>1]&255)|0)&255;f9z(f,J,((gj[c[(c[3531864]|0)+8244>>2]&4095]((e[f+((d[h]|0)+13<<1)>>1]|0)+1&65791)|0)&255)<<8|i);i=f+((d[h]|0)+8<<1)|0;b[i>>1]=((d[g]|0)*-4&65535|2)+(b[i>>1]|0)&65535;c[K>>2]=(c[K>>2]|0)-(1182216>>>((c[l>>2]|0)>>>0)&127);H=H-1&65535;}while(H<<16>>16!=0)}b[f+((d[h]|0)+14<<1)>>1]=0;G=f+452|0;a[G]=0;return};case 170:{H=f+432|0;c[H>>2]=(c[H>>2]|0)-2;if(k<<16>>16!=0){H=k;do{gcp(f);H=H-1&65535;}while(H<<16>>16!=0)}b[f+((d[h]|0)+14<<1)>>1]=0;G=f+452|0;a[G]=0;return};case 173:{H=f+432|0;c[H>>2]=(c[H>>2]|0)-2;if(k<<16>>16!=0){H=k;do{gcs(f);H=H-1&65535;}while(H<<16>>16!=0)}b[f+((d[h]|0)+14<<1)>>1]=0;G=f+452|0;a[G]=0;return};case 174:{H=f+432|0;c[H>>2]=(c[H>>2]|0)-2;L65295:do{if(k<<16>>16==0){L=0}else{H=f+276|0;l=k;while(1){gct(f);K=l-1&65535;if(K<<16>>16==0){L=0;break L65295}if((c[H>>2]|0)==0){l=K}else{L=K;break}}}}while(0);b[f+((d[h]|0)+14<<1)>>1]=L;G=f+452|0;a[G]=0;return};case 167:{L=f+432|0;c[L>>2]=(c[L>>2]|0)-2;L65303:do{if(k<<16>>16==0){M=0}else{L=f+276|0;l=k;while(1){gcm(f);H=l-1&65535;if(H<<16>>16==0){M=0;break L65303}if((c[L>>2]|0)==0){l=H}else{M=H;break}}}}while(0);b[f+((d[h]|0)+14<<1)>>1]=M;G=f+452|0;a[G]=0;return};case 110:{M=f+432|0;c[M>>2]=(c[M>>2]|0)-2;if(k<<16>>16!=0){M=k;do{gbt(f);M=M-1&65535;}while(M<<16>>16!=0)}b[f+((d[h]|0)+14<<1)>>1]=0;G=f+452|0;a[G]=0;return};case 165:{M=f+432|0;c[M>>2]=(c[M>>2]|0)-2;if(k<<16>>16!=0){M=k;do{gck(f);M=M-1&65535;}while(M<<16>>16!=0)}b[f+((d[h]|0)+14<<1)>>1]=0;G=f+452|0;a[G]=0;return};case 111:{M=f+432|0;c[M>>2]=(c[M>>2]|0)-2;if(k<<16>>16!=0){M=k;do{gbu(f);M=M-1&65535;}while(M<<16>>16!=0)}b[f+((d[h]|0)+14<<1)>>1]=0;G=f+452|0;a[G]=0;return};default:{gf[c[2519504+(w<<2)>>2]&2047](f);G=f+452|0;a[G]=0;return}}}function gds(b){b=b|0;a[b+353|0]=1;c[b+432>>2]=0;return}function gdt(a){a=a|0;var b=0;b=a+280|0;c[b>>2]=(c[b>>2]|0)==0;b=a+432|0;c[b>>2]=(c[b>>2]|0)-2;return}function gdu(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=f+442|0;a[g]=(a[g]|0)-1&255;h=f+295|0;i=e[f+((d[h]|0)+6<<1)>>1]<<4;j=f+260|0;k=b[j>>1]|0;b[j>>1]=k+1&65535;l=f+256|0;m=(i+(k&65535)^c[l>>2])&1048575;k=c[3531864]|0;i=c[k+6188+(m>>>11<<2)>>2]|0;if((i|0)==0){n=gj[c[k+8236>>2]&4095](m)|0}else{n=a[i+m|0]|0}m=n&255;i=(n&255)>191;L65335:do{if(i){o=a[f+((d[f+296|0]|0)+(c[9647712+(m<<2)>>2]|0))|0]|0}else{n=gj[c[678944+(m<<2)>>2]&4095](f)|0;do{if((n&1048064|0)==(c[f+428>>2]|0)|(n|0)==1048575){k=n&511;if((a[f+424|0]|0)!=0&k>>>0<256){o=a[f+k|0]|0;break L65335}if(k>>>0<=255){break}o=f9w(f,k-256|0)|0;break L65335}}while(0);k=n&1048575;p=c[3531864]|0;q=c[p+44+(k>>>11<<2)>>2]|0;if((q|0)==0){o=gj[c[p+8236>>2]&4095](k)|0;break}else{o=a[q+k|0]|0;break}}}while(0);k=o&255;switch(m&56|0){case 16:{L65351:do{if(i){a[f+((d[f+296|0]|0)+(c[9647712+(m<<2)>>2]|0))|0]=~o}else{q=c[2426954]|0;p=~o;do{if((q&1048064|0)==(c[f+428>>2]|0)|(q|0)==1048575){r=q&511;if((a[f+424|0]|0)!=0&r>>>0<256){a[f+r|0]=p;break L65351}if(r>>>0<=255){break}f9y(f,r-256|0,p);break L65351}}while(0);n=q&1048575;r=c[3531864]|0;s=c[r+2092+(n>>>11<<2)>>2]|0;if((s|0)==0){gg[c[r+8240>>2]&4095](n,p);break}else{a[s+n|0]=p;break}}}while(0);n=f+432|0;c[n>>2]=(c[n>>2]|0)-(i?2:16);return};case 24:{c[f+280>>2]=o<<24>>24!=0;n=-k|0;s=n<<24>>24;c[f+284>>2]=s;c[f+276>>2]=s;c[f+264>>2]=s;L65367:do{if(i){a[f+((d[f+296|0]|0)+(c[9647712+(m<<2)>>2]|0))|0]=n&255}else{s=c[2426954]|0;r=n&255;do{if((s&1048064|0)==(c[f+428>>2]|0)|(s|0)==1048575){t=s&511;if((a[f+424|0]|0)!=0&t>>>0<256){a[f+t|0]=r;break L65367}if(t>>>0<=255){break}f9y(f,t-256|0,r);break L65367}}while(0);p=s&1048575;q=c[3531864]|0;t=c[q+2092+(p>>>11<<2)>>2]|0;if((t|0)==0){gg[c[q+8240>>2]&4095](p,r);break}else{a[t+p|0]=r;break}}}while(0);n=f+432|0;c[n>>2]=(c[n>>2]|0)-(i?2:16);return};case 0:{a[g]=(a[g]|0)-1&255;g=e[f+((d[h]|0)+6<<1)>>1]<<4;n=b[j>>1]|0;b[j>>1]=n+1&65535;j=(g+(n&65535)^c[l>>2])&1048575;l=c[3531864]|0;n=c[l+6188+(j>>>11<<2)>>2]|0;if((n|0)==0){u=gj[c[l+8236>>2]&4095](j)|0}else{u=a[n+j|0]|0}c[f+272>>2]=0;c[f+280>>2]=0;j=(u&o)<<24>>24;c[f+284>>2]=j;c[f+276>>2]=j;c[f+264>>2]=j;j=f+432|0;c[j>>2]=(c[j>>2]|0)-(i?4:11);return};case 40:{j=f+296|0;u=f;n=ag(a[u+((d[j]|0)+30)|0]|0,o<<24>>24)|0;b[f+((d[h]|0)+15<<1)>>1]=n;n=(a[u+((d[j]|0)+31)|0]|0)!=0|0;c[f+272>>2]=n;c[f+280>>2]=n;n=f+432|0;c[n>>2]=(c[n>>2]|0)-(i?30:36);return};case 32:{n=f+296|0;j=f;u=(ag(d[j+((d[n]|0)+30)|0]|0,k)|0)&65535;b[f+((d[h]|0)+15<<1)>>1]=u;u=(a[j+((d[n]|0)+31)|0]|0)!=0|0;c[f+272>>2]=u;c[f+280>>2]=u;u=f+432|0;c[u>>2]=(c[u>>2]|0)-(i?30:36);return};case 48:{do{if(o<<24>>24==0){gd0(f,0,0)}else{u=e[f+((d[h]|0)+15<<1)>>1]|0;n=(u>>>0)/(k>>>0)|0;if(n>>>0<=255){j=f+296|0;l=f;a[l+((d[j]|0)+30)|0]=n&255;a[l+((d[j]|0)+31)|0]=((u>>>0)%(k>>>0)|0)&255;break}gd0(f,0,0);return}}while(0);k=f+432|0;c[k>>2]=(c[k>>2]|0)-(i?43:53);return};case 56:{do{if(o<<24>>24==0){gd0(f,0,0)}else{k=b[f+((d[h]|0)+15<<1)>>1]|0;u=o<<24>>24;j=(k|0)/(u|0)|0;if((j|0)<=255){l=f+296|0;n=f;a[n+((d[l]|0)+30)|0]=j&255;a[n+((d[l]|0)+31)|0]=((k|0)%(u|0)|0)&255;break}gd0(f,0,0);return}}while(0);o=f+432|0;c[o>>2]=(c[o>>2]|0)-(i?43:53);return};default:{return}}}function gdv(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;g=f+442|0;a[g]=(a[g]|0)-1&255;h=f+295|0;i=e[f+((d[h]|0)+6<<1)>>1]<<4;j=f+260|0;k=b[j>>1]|0;b[j>>1]=k+1&65535;l=f+256|0;m=(i+(k&65535)^c[l>>2])&1048575;k=c[3531864]|0;i=c[k+6188+(m>>>11<<2)>>2]|0;if((i|0)==0){n=gj[c[k+8236>>2]&4095](m)|0}else{n=a[i+m|0]|0}m=n&255;i=(n&255)>191;if(i){o=b[f+((d[h]|0)+(c[9649760+(m<<2)>>2]|0)<<1)>>1]|0}else{n=c[678944+(m<<2)>>2]|0;gj[n&4095](f)|0;o=f9x(f,c[2426954]|0)|0}n=o&65535;switch(m&56|0){case 40:{k=f+((d[h]|0)+15<<1)|0;p=ag(b[k>>1]|0,o<<16>>16)|0;b[k>>1]=p&65535;b[f+((d[h]|0)+13<<1)>>1]=p>>>16&65535;p=(b[f+((d[h]|0)+13<<1)>>1]|0)!=0|0;c[f+272>>2]=p;c[f+280>>2]=p;p=f+432|0;c[p>>2]=(c[p>>2]|0)-(i?30:36);return};case 0:{p=(a[g]|0)-1&255;a[g]=p;k=a[h]|0;q=e[f+((k&255)+6<<1)>>1]<<4;r=b[j>>1]|0;s=r+1&65535;b[j>>1]=s;t=c[l>>2]|0;u=(q+(r&65535)^t)&1048575;r=c[3531864]|0;q=c[r+6188+(u>>>11<<2)>>2]|0;if((q|0)==0){v=gj[c[r+8236>>2]&4095](u)|0;w=v;x=a[g]|0;y=a[h]|0;z=b[j>>1]|0;A=c[l>>2]|0;B=c[3531864]|0}else{w=a[q+u|0]|0;x=p;y=k;z=s;A=t;B=r}a[g]=x-1&255;x=e[f+((y&255)+6<<1)>>1]<<4;b[j>>1]=z+1&65535;j=(x+(z&65535)^A)&1048575;A=c[B+6188+(j>>>11<<2)>>2]|0;if((A|0)==0){C=gj[c[B+8236>>2]&4095](j)|0}else{C=a[A+j|0]|0}c[f+272>>2]=0;c[f+280>>2]=0;j=(((C&255)<<8|w&255)&o)<<16>>16;c[f+284>>2]=j;c[f+276>>2]=j;c[f+264>>2]=j;j=f+432|0;c[j>>2]=(c[j>>2]|0)-(i?4:11);return};case 32:{j=f+((d[h]|0)+15<<1)|0;w=ag(e[j>>1]|0,n)|0;b[j>>1]=w&65535;b[f+((d[h]|0)+13<<1)>>1]=w>>>16&65535;w=(b[f+((d[h]|0)+13<<1)>>1]|0)!=0|0;c[f+272>>2]=w;c[f+280>>2]=w;w=f+432|0;c[w>>2]=(c[w>>2]|0)-(i?30:36);return};case 24:{c[f+280>>2]=o<<16>>16!=0;w=-n|0;j=w<<16>>16;c[f+284>>2]=j;c[f+276>>2]=j;c[f+264>>2]=j;if(i){b[f+((d[h]|0)+(c[9649760+(m<<2)>>2]|0)<<1)>>1]=w&65535}else{f9z(f,c[2426954]|0,w&65535)}w=f+432|0;c[w>>2]=(c[w>>2]|0)-(i?2:16);return};case 48:{do{if(o<<16>>16==0){gd0(f,0,0)}else{w=d[h]|0;j=f+(w+15<<1)|0;C=e[f+(w+13<<1)>>1]<<16|e[j>>1];w=(C>>>0)/(n>>>0)|0;if(w>>>0<=65535){b[j>>1]=w&65535;b[f+((d[h]|0)+13<<1)>>1]=((C>>>0)%(n>>>0)|0)&65535;break}gd0(f,0,0);return}}while(0);n=f+432|0;c[n>>2]=(c[n>>2]|0)-(i?43:53);return};case 56:{do{if(o<<16>>16==0){gd0(f,0,0)}else{n=d[h]|0;C=f+(n+15<<1)|0;w=e[f+(n+13<<1)>>1]<<16|e[C>>1];n=o<<16>>16;j=(w|0)/(n|0)|0;if((j|0)<=65535){b[C>>1]=j&65535;b[f+((d[h]|0)+13<<1)>>1]=((w|0)%(n|0)|0)&65535;break}gd0(f,0,0);return}}while(0);n=f+432|0;c[n>>2]=(c[n>>2]|0)-(i?43:53);return};case 16:{if(i){b[f+((d[h]|0)+(c[9649760+(m<<2)>>2]|0)<<1)>>1]=~o}else{f9z(f,c[2426954]|0,~o)}o=f+432|0;c[o>>2]=(c[o>>2]|0)-(i?2:16);return};default:{return}}}function gdw(a){a=a|0;var b=0;c[a+280>>2]=0;b=a+432|0;c[b>>2]=(c[b>>2]|0)-2;return}function gdx(a){a=a|0;var b=0;c[a+280>>2]=1;b=a+432|0;c[b>>2]=(c[b>>2]|0)-2;return}function gdy(b){b=b|0;var d=0;a[b+292|0]=0;d=b+432|0;c[d>>2]=(c[d>>2]|0)-2;return}function gdz(b){b=b|0;var d=0;a[b+292|0]=1;d=b+432|0;c[d>>2]=(c[d>>2]|0)-2;return}function gdA(b){b=b|0;var d=0;a[b+293|0]=0;d=b+432|0;c[d>>2]=(c[d>>2]|0)-2;return}function gdB(b){b=b|0;var d=0;a[b+293|0]=1;d=b+432|0;c[d>>2]=(c[d>>2]|0)-2;return}function gdC(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=f+442|0;a[g]=(a[g]|0)-1&255;g=e[f+((d[f+295|0]|0)+6<<1)>>1]<<4;h=f+260|0;i=b[h>>1]|0;b[h>>1]=i+1&65535;h=(g+(i&65535)^c[f+256>>2])&1048575;i=c[3531864]|0;g=c[i+6188+(h>>>11<<2)>>2]|0;if((g|0)==0){j=gj[c[i+8236>>2]&4095](h)|0}else{j=a[g+h|0]|0}h=j&255;g=(j&255)>191;L65481:do{if(g){k=a[f+((d[f+296|0]|0)+(c[9647712+(h<<2)>>2]|0))|0]|0}else{j=gj[c[678944+(h<<2)>>2]&4095](f)|0;do{if((j&1048064|0)==(c[f+428>>2]|0)|(j|0)==1048575){i=j&511;if((a[f+424|0]|0)!=0&i>>>0<256){k=a[f+i|0]|0;break L65481}if(i>>>0<=255){break}k=f9w(f,i-256|0)|0;break L65481}}while(0);i=j&1048575;l=c[3531864]|0;m=c[l+44+(i>>>11<<2)>>2]|0;if((m|0)==0){k=gj[c[l+8236>>2]&4095](i)|0;break}else{k=a[m+i|0]|0;break}}}while(0);i=k&255;m=h&56;if((m|0)==0){l=i+1|0;c[f+272>>2]=k<<24>>24==127;c[f+268>>2]=(l^i)&16;n=l&255;l=n<<24>>24;c[f+284>>2]=l;c[f+276>>2]=l;c[f+264>>2]=l;L65497:do{if(g){a[f+((d[f+296|0]|0)+(c[9647712+(h<<2)>>2]|0))|0]=n}else{l=c[2426954]|0;do{if((l&1048064|0)==(c[f+428>>2]|0)|(l|0)==1048575){o=l&511;if((a[f+424|0]|0)!=0&o>>>0<256){a[f+o|0]=n;break L65497}if(o>>>0<=255){break}f9y(f,o-256|0,n);break L65497}}while(0);j=l&1048575;o=c[3531864]|0;p=c[o+2092+(j>>>11<<2)>>2]|0;if((p|0)==0){gg[c[o+8240>>2]&4095](j,n);break}else{a[p+j|0]=n;break}}}while(0);n=f+432|0;c[n>>2]=(c[n>>2]|0)-((g?131586:1052679)>>>((c[f+444>>2]|0)>>>0)&127);return}else if((m|0)==8){m=i-1|0;c[f+272>>2]=k<<24>>24==-128;c[f+268>>2]=(m^i)&16;i=m&255;m=i<<24>>24;c[f+284>>2]=m;c[f+276>>2]=m;c[f+264>>2]=m;L65513:do{if(g){a[f+((d[f+296|0]|0)+(c[9647712+(h<<2)>>2]|0))|0]=i}else{m=c[2426954]|0;do{if((m&1048064|0)==(c[f+428>>2]|0)|(m|0)==1048575){k=m&511;if((a[f+424|0]|0)!=0&k>>>0<256){a[f+k|0]=i;break L65513}if(k>>>0<=255){break}f9y(f,k-256|0,i);break L65513}}while(0);l=m&1048575;k=c[3531864]|0;n=c[k+2092+(l>>>11<<2)>>2]|0;if((n|0)==0){gg[c[k+8240>>2]&4095](l,i);break}else{a[n+l|0]=i;break}}}while(0);i=f+432|0;c[i>>2]=(c[i>>2]|0)-((g?131586:1052679)>>>((c[f+444>>2]|0)>>>0)&127);return}else{return}}function gdD(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=f+442|0;a[g]=(a[g]|0)-1&255;g=f+295|0;h=(e[f+((d[g]|0)+6<<1)>>1]|0)<<4;i=f+260|0;j=b[i>>1]|0;b[i>>1]=j+1&65535;k=(h+(j&65535)^c[f+256>>2])&1048575;j=c[3531864]|0;h=c[j+6188+(k>>>11<<2)>>2]|0;if((h|0)==0){l=gj[c[j+8236>>2]&4095](k)|0}else{l=a[h+k|0]|0}k=l&255;h=(l&255)>191;if(h){m=b[f+((d[g]|0)+(c[9649760+(k<<2)>>2]|0)<<1)>>1]|0}else{l=c[678944+(k<<2)>>2]|0;gj[l&4095](f)|0;m=f9x(f,c[2426954]|0)|0}l=m&65535;switch(k&56|0){case 32:{b[i>>1]=m;a[f+443|0]=1;j=f+432|0;c[j>>2]=(c[j>>2]|0)-13;return};case 0:{j=l+1|0;c[f+272>>2]=m<<16>>16==32767;c[f+268>>2]=(j^l)&16;n=j&65535;j=n<<16>>16;c[f+284>>2]=j;c[f+276>>2]=j;c[f+264>>2]=j;if(h){b[f+((d[g]|0)+(c[9649760+(k<<2)>>2]|0)<<1)>>1]=n}else{f9z(f,c[2426954]|0,n)}n=f+432|0;c[n>>2]=(c[n>>2]|0)-((h?131586:1576967)>>>((c[f+444>>2]|0)>>>0)&127);return};case 8:{n=l-1|0;c[f+272>>2]=m<<16>>16==-32768;c[f+268>>2]=(n^l)&16;l=n&65535;n=l<<16>>16;c[f+284>>2]=n;c[f+276>>2]=n;c[f+264>>2]=n;if(h){b[f+((d[g]|0)+(c[9649760+(k<<2)>>2]|0)<<1)>>1]=l}else{f9z(f,c[2426954]|0,l)}l=f+432|0;c[l>>2]=(c[l>>2]|0)-((h?131586:1576967)>>>((c[f+444>>2]|0)>>>0)&127);return};case 40:{b[i>>1]=m;l=c[2426954]|0;k=f9x(f,l+2&65535|l&983040)|0;b[f+((d[g]|0)+6<<1)>>1]=k;a[f+443|0]=1;k=f+432|0;c[k>>2]=(c[k>>2]|0)-15;return};case 16:{k=f+((d[g]|0)+11<<1)|0;b[k>>1]=(b[k>>1]|0)-2&65535;k=d[g]|0;f9z(f,((e[f+(k+5<<1)>>1]|0)<<4)+(e[f+(k+11<<1)>>1]|0)|0,b[i>>1]|0);b[i>>1]=m;a[f+443|0]=1;k=f+432|0;c[k>>2]=(c[k>>2]|0)-(h?16:20);return};case 24:{k=b[f+((d[g]|0)+6<<1)>>1]|0;l=c[2426954]|0;n=f9x(f,l+2&65535|l&983040)|0;b[f+((d[g]|0)+6<<1)>>1]=n;n=f+((d[g]|0)+11<<1)|0;b[n>>1]=(b[n>>1]|0)-2&65535;n=d[g]|0;f9z(f,((e[f+(n+5<<1)>>1]|0)<<4)+(e[f+(n+11<<1)>>1]|0)|0,k);k=f+((d[g]|0)+11<<1)|0;b[k>>1]=(b[k>>1]|0)-2&65535;k=d[g]|0;f9z(f,((e[f+(k+5<<1)>>1]|0)<<4)+(e[f+(k+11<<1)>>1]|0)|0,b[i>>1]|0);b[i>>1]=m;a[f+443|0]=1;i=f+432|0;c[i>>2]=(c[i>>2]|0)-(h?16:26);return};case 48:{h=f+((d[g]|0)+11<<1)|0;b[h>>1]=(b[h>>1]|0)-2&65535;h=d[g]|0;f9z(f,((e[f+(h+5<<1)>>1]|0)<<4)+(e[f+(h+11<<1)>>1]|0)|0,m);m=f+432|0;c[m>>2]=(c[m>>2]|0)-4;return};default:{return}}}function gdE(f){f=f|0;var g=0,h=0,i=0,j=0,k=0;g=d[f+295|0]|0;h=(b[f+(g+9<<1)>>1]|0)+(b[f+(g+12<<1)>>1]|0)&65535;b[4853900]=h;if((a[f+452|0]|0)==0){i=e[f+(g+4<<1)>>1]<<4;j=h&65535;k=i+j|0;c[2426954]=k;return k|0}else{i=c[f+448>>2]|0;j=h&65535;k=i+j|0;c[2426954]=k;return k|0}return 0}function gdF(f){f=f|0;var g=0,h=0,i=0,j=0,k=0;g=d[f+295|0]|0;h=(b[f+(g+8<<1)>>1]|0)+(b[f+(g+12<<1)>>1]|0)&65535;b[4853900]=h;if((a[f+452|0]|0)==0){i=e[f+(g+4<<1)>>1]<<4;j=h&65535;k=i+j|0;c[2426954]=k;return k|0}else{i=c[f+448>>2]|0;j=h&65535;k=i+j|0;c[2426954]=k;return k|0}return 0}function gdG(f){f=f|0;var g=0,h=0,i=0,j=0,k=0;g=d[f+295|0]|0;h=(b[f+(g+9<<1)>>1]|0)+(b[f+(g+10<<1)>>1]|0)&65535;b[4853900]=h;if((a[f+452|0]|0)==0){i=e[f+(g+5<<1)>>1]<<4;j=h&65535;k=i+j|0;c[2426954]=k;return k|0}else{i=c[f+448>>2]|0;j=h&65535;k=i+j|0;c[2426954]=k;return k|0}return 0}function gdH(f){f=f|0;var g=0,h=0,i=0,j=0,k=0;g=d[f+295|0]|0;h=(b[f+(g+8<<1)>>1]|0)+(b[f+(g+10<<1)>>1]|0)&65535;b[4853900]=h;if((a[f+452|0]|0)==0){i=e[f+(g+5<<1)>>1]<<4;j=h&65535;k=i+j|0;c[2426954]=k;return k|0}else{i=c[f+448>>2]|0;j=h&65535;k=i+j|0;c[2426954]=k;return k|0}return 0}function gdI(f){f=f|0;var g=0,h=0,i=0,j=0,k=0;g=d[f+295|0]|0;h=b[f+(g+9<<1)>>1]|0;b[4853900]=h;if((a[f+452|0]|0)==0){i=e[f+(g+4<<1)>>1]<<4;j=h&65535;k=i+j|0;c[2426954]=k;return k|0}else{i=c[f+448>>2]|0;j=h&65535;k=i+j|0;c[2426954]=k;return k|0}return 0}function gdJ(f){f=f|0;var g=0,h=0,i=0,j=0,k=0;g=d[f+295|0]|0;h=b[f+(g+8<<1)>>1]|0;b[4853900]=h;if((a[f+452|0]|0)==0){i=e[f+(g+4<<1)>>1]<<4;j=h&65535;k=i+j|0;c[2426954]=k;return k|0}else{i=c[f+448>>2]|0;j=h&65535;k=i+j|0;c[2426954]=k;return k|0}return 0}function gdK(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;g=f+442|0;h=(a[g]|0)-1&255;a[g]=h;i=f+295|0;j=a[i]|0;k=e[f+((j&255)+6<<1)>>1]<<4;l=f+260|0;m=b[l>>1]|0;n=m+1&65535;b[l>>1]=n;o=f+256|0;p=c[o>>2]|0;q=(k+(m&65535)^p)&1048575;m=c[3531864]|0;k=c[m+6188+(q>>>11<<2)>>2]|0;if((k|0)==0){r=gj[c[m+8236>>2]&4095](q)|0;s=r;t=c[o>>2]|0;u=a[g]|0;v=a[i]|0;w=b[l>>1]|0;x=c[3531864]|0}else{s=a[k+q|0]|0;t=p;u=h;v=j;w=n;x=m}m=s&255;b[4853900]=m;a[g]=u-1&255;u=e[f+((v&255)+6<<1)>>1]<<4;b[l>>1]=w+1&65535;l=(u+(w&65535)^t)&1048575;t=c[x+6188+(l>>>11<<2)>>2]|0;if((t|0)==0){w=gj[c[x+8236>>2]&4095](l)|0;y=w;z=b[4853900]|0}else{y=a[t+l|0]|0;z=m}m=((y&255)<<8)+z&65535;b[4853900]=m;if((a[f+452|0]|0)==0){A=e[f+((d[i]|0)+4<<1)>>1]<<4;B=m&65535;C=A+B|0;c[2426954]=C;return C|0}else{A=c[f+448>>2]|0;B=m&65535;C=A+B|0;c[2426954]=C;return C|0}return 0}function gdL(f){f=f|0;var g=0,h=0,i=0,j=0,k=0;g=d[f+295|0]|0;h=b[f+(g+12<<1)>>1]|0;b[4853900]=h;if((a[f+452|0]|0)==0){i=e[f+(g+4<<1)>>1]<<4;j=h&65535;k=i+j|0;c[2426954]=k;return k|0}else{i=c[f+448>>2]|0;j=h&65535;k=i+j|0;c[2426954]=k;return k|0}return 0}function gdM(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=f+295|0;h=d[g]|0;i=(b[f+(h+9<<1)>>1]|0)+(b[f+(h+12<<1)>>1]|0)&65535;j=f+442|0;a[j]=(a[j]|0)-1&255;j=e[f+(h+6<<1)>>1]<<4;h=f+260|0;k=b[h>>1]|0;b[h>>1]=k+1&65535;h=(j+(k&65535)^c[f+256>>2])&1048575;k=c[3531864]|0;j=c[k+6188+(h>>>11<<2)>>2]|0;if((j|0)==0){l=gj[c[k+8236>>2]&4095](h)|0}else{l=a[j+h|0]|0}h=i+(l<<24>>24)&65535;b[4853900]=h;if((a[f+452|0]|0)==0){m=e[f+((d[g]|0)+4<<1)>>1]<<4;n=h&65535;o=m+n|0;c[2426954]=o;return o|0}else{m=c[f+448>>2]|0;n=h&65535;o=m+n|0;c[2426954]=o;return o|0}return 0}function gdN(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=f+295|0;h=d[g]|0;i=(b[f+(h+8<<1)>>1]|0)+(b[f+(h+12<<1)>>1]|0)&65535;j=f+442|0;a[j]=(a[j]|0)-1&255;j=e[f+(h+6<<1)>>1]<<4;h=f+260|0;k=b[h>>1]|0;b[h>>1]=k+1&65535;h=(j+(k&65535)^c[f+256>>2])&1048575;k=c[3531864]|0;j=c[k+6188+(h>>>11<<2)>>2]|0;if((j|0)==0){l=gj[c[k+8236>>2]&4095](h)|0}else{l=a[j+h|0]|0}h=i+(l<<24>>24)&65535;b[4853900]=h;if((a[f+452|0]|0)==0){m=e[f+((d[g]|0)+4<<1)>>1]<<4;n=h&65535;o=m+n|0;c[2426954]=o;return o|0}else{m=c[f+448>>2]|0;n=h&65535;o=m+n|0;c[2426954]=o;return o|0}return 0}function gdO(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=f+295|0;h=d[g]|0;i=(b[f+(h+9<<1)>>1]|0)+(b[f+(h+10<<1)>>1]|0)&65535;j=f+442|0;a[j]=(a[j]|0)-1&255;j=e[f+(h+6<<1)>>1]<<4;h=f+260|0;k=b[h>>1]|0;b[h>>1]=k+1&65535;h=(j+(k&65535)^c[f+256>>2])&1048575;k=c[3531864]|0;j=c[k+6188+(h>>>11<<2)>>2]|0;if((j|0)==0){l=gj[c[k+8236>>2]&4095](h)|0}else{l=a[j+h|0]|0}h=i+(l<<24>>24)&65535;b[4853900]=h;if((a[f+452|0]|0)==0){m=e[f+((d[g]|0)+5<<1)>>1]<<4;n=h&65535;o=m+n|0;c[2426954]=o;return o|0}else{m=c[f+448>>2]|0;n=h&65535;o=m+n|0;c[2426954]=o;return o|0}return 0}function gdP(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=f+295|0;h=d[g]|0;i=(b[f+(h+8<<1)>>1]|0)+(b[f+(h+10<<1)>>1]|0)&65535;j=f+442|0;a[j]=(a[j]|0)-1&255;j=e[f+(h+6<<1)>>1]<<4;h=f+260|0;k=b[h>>1]|0;b[h>>1]=k+1&65535;h=(j+(k&65535)^c[f+256>>2])&1048575;k=c[3531864]|0;j=c[k+6188+(h>>>11<<2)>>2]|0;if((j|0)==0){l=gj[c[k+8236>>2]&4095](h)|0}else{l=a[j+h|0]|0}h=i+(l<<24>>24)&65535;b[4853900]=h;if((a[f+452|0]|0)==0){m=e[f+((d[g]|0)+5<<1)>>1]<<4;n=h&65535;o=m+n|0;c[2426954]=o;return o|0}else{m=c[f+448>>2]|0;n=h&65535;o=m+n|0;c[2426954]=o;return o|0}return 0}function gdQ(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=f+295|0;h=d[g]|0;i=b[f+(h+9<<1)>>1]|0;j=f+442|0;a[j]=(a[j]|0)-1&255;j=e[f+(h+6<<1)>>1]<<4;h=f+260|0;k=b[h>>1]|0;b[h>>1]=k+1&65535;h=(j+(k&65535)^c[f+256>>2])&1048575;k=c[3531864]|0;j=c[k+6188+(h>>>11<<2)>>2]|0;if((j|0)==0){l=gj[c[k+8236>>2]&4095](h)|0}else{l=a[j+h|0]|0}h=(l<<24>>24)+i&65535;b[4853900]=h;if((a[f+452|0]|0)==0){m=e[f+((d[g]|0)+4<<1)>>1]<<4;n=h&65535;o=m+n|0;c[2426954]=o;return o|0}else{m=c[f+448>>2]|0;n=h&65535;o=m+n|0;c[2426954]=o;return o|0}return 0}function gdR(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=f+295|0;h=d[g]|0;i=b[f+(h+8<<1)>>1]|0;j=f+442|0;a[j]=(a[j]|0)-1&255;j=e[f+(h+6<<1)>>1]<<4;h=f+260|0;k=b[h>>1]|0;b[h>>1]=k+1&65535;h=(j+(k&65535)^c[f+256>>2])&1048575;k=c[3531864]|0;j=c[k+6188+(h>>>11<<2)>>2]|0;if((j|0)==0){l=gj[c[k+8236>>2]&4095](h)|0}else{l=a[j+h|0]|0}h=(l<<24>>24)+i&65535;b[4853900]=h;if((a[f+452|0]|0)==0){m=e[f+((d[g]|0)+4<<1)>>1]<<4;n=h&65535;o=m+n|0;c[2426954]=o;return o|0}else{m=c[f+448>>2]|0;n=h&65535;o=m+n|0;c[2426954]=o;return o|0}return 0}function gdS(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=f+295|0;h=d[g]|0;i=b[f+(h+10<<1)>>1]|0;j=f+442|0;a[j]=(a[j]|0)-1&255;j=e[f+(h+6<<1)>>1]<<4;h=f+260|0;k=b[h>>1]|0;b[h>>1]=k+1&65535;h=(j+(k&65535)^c[f+256>>2])&1048575;k=c[3531864]|0;j=c[k+6188+(h>>>11<<2)>>2]|0;if((j|0)==0){l=gj[c[k+8236>>2]&4095](h)|0}else{l=a[j+h|0]|0}h=(l<<24>>24)+i&65535;b[4853900]=h;if((a[f+452|0]|0)==0){m=e[f+((d[g]|0)+5<<1)>>1]<<4;n=h&65535;o=m+n|0;c[2426954]=o;return o|0}else{m=c[f+448>>2]|0;n=h&65535;o=m+n|0;c[2426954]=o;return o|0}return 0}function gdT(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=f+295|0;h=d[g]|0;i=b[f+(h+12<<1)>>1]|0;j=f+442|0;a[j]=(a[j]|0)-1&255;j=e[f+(h+6<<1)>>1]<<4;h=f+260|0;k=b[h>>1]|0;b[h>>1]=k+1&65535;h=(j+(k&65535)^c[f+256>>2])&1048575;k=c[3531864]|0;j=c[k+6188+(h>>>11<<2)>>2]|0;if((j|0)==0){l=gj[c[k+8236>>2]&4095](h)|0}else{l=a[j+h|0]|0}h=(l<<24>>24)+i&65535;b[4853900]=h;if((a[f+452|0]|0)==0){m=e[f+((d[g]|0)+4<<1)>>1]<<4;n=h&65535;o=m+n|0;c[2426954]=o;return o|0}else{m=c[f+448>>2]|0;n=h&65535;o=m+n|0;c[2426954]=o;return o|0}return 0}function gdU(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;f=d+442|0;g=(a[f]|0)-1&255;a[f]=g;h=d+295|0;i=a[h]|0;j=e[d+((i&255)+6<<1)>>1]<<4;k=d+260|0;l=b[k>>1]|0;m=l+1&65535;b[k>>1]=m;n=d+256|0;o=c[n>>2]|0;p=(j+(l&65535)^o)&1048575;l=c[3531864]|0;j=c[l+6188+(p>>>11<<2)>>2]|0;if((j|0)==0){q=gj[c[l+8236>>2]&4095](p)|0;r=q;s=c[n>>2]|0;t=a[f]|0;u=a[h]|0;v=b[k>>1]|0;w=c[3531864]|0}else{r=a[j+p|0]|0;s=o;t=g;u=i;v=m;w=l}l=r&255;b[4853676]=l;a[f]=t-1&255;t=e[d+((u&255)+6<<1)>>1]<<4;b[k>>1]=v+1&65535;k=(t+(v&65535)^s)&1048575;s=c[w+6188+(k>>>11<<2)>>2]|0;if((s|0)==0){v=gj[c[w+8236>>2]&4095](k)|0;x=v;y=b[4853676]|0;z=a[h]|0}else{x=a[s+k|0]|0;y=l;z=u}u=((x&255)<<8)+y&65535;b[4853676]=u;y=z&255;z=(u+(b[d+(y+12<<1)>>1]|0)&65535)+(b[d+(y+9<<1)>>1]|0)&65535;b[4853900]=z;if((a[d+452|0]|0)==0){A=e[d+(y+4<<1)>>1]<<4;B=z&65535;C=A+B|0;c[2426954]=C;return C|0}else{A=c[d+448>>2]|0;B=z&65535;C=A+B|0;c[2426954]=C;return C|0}return 0}function gdV(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;f=d+442|0;g=(a[f]|0)-1&255;a[f]=g;h=d+295|0;i=a[h]|0;j=e[d+((i&255)+6<<1)>>1]<<4;k=d+260|0;l=b[k>>1]|0;m=l+1&65535;b[k>>1]=m;n=d+256|0;o=c[n>>2]|0;p=(j+(l&65535)^o)&1048575;l=c[3531864]|0;j=c[l+6188+(p>>>11<<2)>>2]|0;if((j|0)==0){q=gj[c[l+8236>>2]&4095](p)|0;r=q;s=c[n>>2]|0;t=a[f]|0;u=a[h]|0;v=b[k>>1]|0;w=c[3531864]|0}else{r=a[j+p|0]|0;s=o;t=g;u=i;v=m;w=l}l=r&255;b[4853676]=l;a[f]=t-1&255;t=e[d+((u&255)+6<<1)>>1]<<4;b[k>>1]=v+1&65535;k=(t+(v&65535)^s)&1048575;s=c[w+6188+(k>>>11<<2)>>2]|0;if((s|0)==0){v=gj[c[w+8236>>2]&4095](k)|0;x=v;y=b[4853676]|0;z=a[h]|0}else{x=a[s+k|0]|0;y=l;z=u}u=((x&255)<<8)+y&65535;b[4853676]=u;y=z&255;z=(u+(b[d+(y+12<<1)>>1]|0)&65535)+(b[d+(y+8<<1)>>1]|0)&65535;b[4853900]=z;if((a[d+452|0]|0)==0){A=e[d+(y+4<<1)>>1]<<4;B=z&65535;C=A+B|0;c[2426954]=C;return C|0}else{A=c[d+448>>2]|0;B=z&65535;C=A+B|0;c[2426954]=C;return C|0}return 0}function gdW(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;f=d+442|0;g=(a[f]|0)-1&255;a[f]=g;h=d+295|0;i=a[h]|0;j=e[d+((i&255)+6<<1)>>1]<<4;k=d+260|0;l=b[k>>1]|0;m=l+1&65535;b[k>>1]=m;n=d+256|0;o=c[n>>2]|0;p=(j+(l&65535)^o)&1048575;l=c[3531864]|0;j=c[l+6188+(p>>>11<<2)>>2]|0;if((j|0)==0){q=gj[c[l+8236>>2]&4095](p)|0;r=q;s=c[n>>2]|0;t=a[f]|0;u=a[h]|0;v=b[k>>1]|0;w=c[3531864]|0}else{r=a[j+p|0]|0;s=o;t=g;u=i;v=m;w=l}l=r&255;b[4853676]=l;a[f]=t-1&255;t=e[d+((u&255)+6<<1)>>1]<<4;b[k>>1]=v+1&65535;k=(t+(v&65535)^s)&1048575;s=c[w+6188+(k>>>11<<2)>>2]|0;if((s|0)==0){v=gj[c[w+8236>>2]&4095](k)|0;x=v;y=b[4853676]|0;z=a[h]|0}else{x=a[s+k|0]|0;y=l;z=u}u=((x&255)<<8)+y&65535;b[4853676]=u;y=z&255;z=(u+(b[d+(y+10<<1)>>1]|0)&65535)+(b[d+(y+9<<1)>>1]|0)&65535;b[4853900]=z;if((a[d+452|0]|0)==0){A=e[d+(y+5<<1)>>1]<<4;B=z&65535;C=A+B|0;c[2426954]=C;return C|0}else{A=c[d+448>>2]|0;B=z&65535;C=A+B|0;c[2426954]=C;return C|0}return 0}function gdX(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;f=d+442|0;g=(a[f]|0)-1&255;a[f]=g;h=d+295|0;i=a[h]|0;j=e[d+((i&255)+6<<1)>>1]<<4;k=d+260|0;l=b[k>>1]|0;m=l+1&65535;b[k>>1]=m;n=d+256|0;o=c[n>>2]|0;p=(j+(l&65535)^o)&1048575;l=c[3531864]|0;j=c[l+6188+(p>>>11<<2)>>2]|0;if((j|0)==0){q=gj[c[l+8236>>2]&4095](p)|0;r=q;s=c[n>>2]|0;t=a[f]|0;u=a[h]|0;v=b[k>>1]|0;w=c[3531864]|0}else{r=a[j+p|0]|0;s=o;t=g;u=i;v=m;w=l}l=r&255;b[4853676]=l;a[f]=t-1&255;t=e[d+((u&255)+6<<1)>>1]<<4;b[k>>1]=v+1&65535;k=(t+(v&65535)^s)&1048575;s=c[w+6188+(k>>>11<<2)>>2]|0;if((s|0)==0){v=gj[c[w+8236>>2]&4095](k)|0;x=v;y=b[4853676]|0;z=a[h]|0}else{x=a[s+k|0]|0;y=l;z=u}u=((x&255)<<8)+y&65535;b[4853676]=u;y=z&255;z=(u+(b[d+(y+10<<1)>>1]|0)&65535)+(b[d+(y+8<<1)>>1]|0)&65535;b[4853900]=z;if((a[d+452|0]|0)==0){A=e[d+(y+5<<1)>>1]<<4;B=z&65535;C=A+B|0;c[2426954]=C;return C|0}else{A=c[d+448>>2]|0;B=z&65535;C=A+B|0;c[2426954]=C;return C|0}return 0}function gdY(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;f=d+442|0;g=(a[f]|0)-1&255;a[f]=g;h=d+295|0;i=a[h]|0;j=e[d+((i&255)+6<<1)>>1]<<4;k=d+260|0;l=b[k>>1]|0;m=l+1&65535;b[k>>1]=m;n=d+256|0;o=c[n>>2]|0;p=(j+(l&65535)^o)&1048575;l=c[3531864]|0;j=c[l+6188+(p>>>11<<2)>>2]|0;if((j|0)==0){q=gj[c[l+8236>>2]&4095](p)|0;r=q;s=c[n>>2]|0;t=a[f]|0;u=a[h]|0;v=b[k>>1]|0;w=c[3531864]|0}else{r=a[j+p|0]|0;s=o;t=g;u=i;v=m;w=l}l=r&255;b[4853676]=l;a[f]=t-1&255;t=e[d+((u&255)+6<<1)>>1]<<4;b[k>>1]=v+1&65535;k=(t+(v&65535)^s)&1048575;s=c[w+6188+(k>>>11<<2)>>2]|0;if((s|0)==0){v=gj[c[w+8236>>2]&4095](k)|0;x=v;y=b[4853676]|0;z=a[h]|0}else{x=a[s+k|0]|0;y=l;z=u}u=((x&255)<<8)+y&65535;b[4853676]=u;y=z&255;z=(b[d+(y+9<<1)>>1]|0)+u&65535;b[4853900]=z;if((a[d+452|0]|0)==0){A=e[d+(y+4<<1)>>1]<<4;B=z&65535;C=A+B|0;c[2426954]=C;return C|0}else{A=c[d+448>>2]|0;B=z&65535;C=A+B|0;c[2426954]=C;return C|0}return 0}function gdZ(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;f=d+442|0;g=(a[f]|0)-1&255;a[f]=g;h=d+295|0;i=a[h]|0;j=e[d+((i&255)+6<<1)>>1]<<4;k=d+260|0;l=b[k>>1]|0;m=l+1&65535;b[k>>1]=m;n=d+256|0;o=c[n>>2]|0;p=(j+(l&65535)^o)&1048575;l=c[3531864]|0;j=c[l+6188+(p>>>11<<2)>>2]|0;if((j|0)==0){q=gj[c[l+8236>>2]&4095](p)|0;r=q;s=c[n>>2]|0;t=a[f]|0;u=a[h]|0;v=b[k>>1]|0;w=c[3531864]|0}else{r=a[j+p|0]|0;s=o;t=g;u=i;v=m;w=l}l=r&255;b[4853676]=l;a[f]=t-1&255;t=e[d+((u&255)+6<<1)>>1]<<4;b[k>>1]=v+1&65535;k=(t+(v&65535)^s)&1048575;s=c[w+6188+(k>>>11<<2)>>2]|0;if((s|0)==0){v=gj[c[w+8236>>2]&4095](k)|0;x=v;y=b[4853676]|0;z=a[h]|0}else{x=a[s+k|0]|0;y=l;z=u}u=((x&255)<<8)+y&65535;b[4853676]=u;y=z&255;z=(b[d+(y+8<<1)>>1]|0)+u&65535;b[4853900]=z;if((a[d+452|0]|0)==0){A=e[d+(y+4<<1)>>1]<<4;B=z&65535;C=A+B|0;c[2426954]=C;return C|0}else{A=c[d+448>>2]|0;B=z&65535;C=A+B|0;c[2426954]=C;return C|0}return 0}function gd_(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;f=d+442|0;g=(a[f]|0)-1&255;a[f]=g;h=d+295|0;i=a[h]|0;j=e[d+((i&255)+6<<1)>>1]<<4;k=d+260|0;l=b[k>>1]|0;m=l+1&65535;b[k>>1]=m;n=d+256|0;o=c[n>>2]|0;p=(j+(l&65535)^o)&1048575;l=c[3531864]|0;j=c[l+6188+(p>>>11<<2)>>2]|0;if((j|0)==0){q=gj[c[l+8236>>2]&4095](p)|0;r=q;s=c[n>>2]|0;t=a[f]|0;u=a[h]|0;v=b[k>>1]|0;w=c[3531864]|0}else{r=a[j+p|0]|0;s=o;t=g;u=i;v=m;w=l}l=r&255;b[4853676]=l;a[f]=t-1&255;t=e[d+((u&255)+6<<1)>>1]<<4;b[k>>1]=v+1&65535;k=(t+(v&65535)^s)&1048575;s=c[w+6188+(k>>>11<<2)>>2]|0;if((s|0)==0){v=gj[c[w+8236>>2]&4095](k)|0;x=v;y=b[4853676]|0;z=a[h]|0}else{x=a[s+k|0]|0;y=l;z=u}u=((x&255)<<8)+y&65535;b[4853676]=u;y=z&255;z=(b[d+(y+10<<1)>>1]|0)+u&65535;b[4853900]=z;if((a[d+452|0]|0)==0){A=e[d+(y+5<<1)>>1]<<4;B=z&65535;C=A+B|0;c[2426954]=C;return C|0}else{A=c[d+448>>2]|0;B=z&65535;C=A+B|0;c[2426954]=C;return C|0}return 0}function gd$(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;f=d+442|0;g=(a[f]|0)-1&255;a[f]=g;h=d+295|0;i=a[h]|0;j=e[d+((i&255)+6<<1)>>1]<<4;k=d+260|0;l=b[k>>1]|0;m=l+1&65535;b[k>>1]=m;n=d+256|0;o=c[n>>2]|0;p=(j+(l&65535)^o)&1048575;l=c[3531864]|0;j=c[l+6188+(p>>>11<<2)>>2]|0;if((j|0)==0){q=gj[c[l+8236>>2]&4095](p)|0;r=q;s=c[n>>2]|0;t=a[f]|0;u=a[h]|0;v=b[k>>1]|0;w=c[3531864]|0}else{r=a[j+p|0]|0;s=o;t=g;u=i;v=m;w=l}l=r&255;b[4853676]=l;a[f]=t-1&255;t=e[d+((u&255)+6<<1)>>1]<<4;b[k>>1]=v+1&65535;k=(t+(v&65535)^s)&1048575;s=c[w+6188+(k>>>11<<2)>>2]|0;if((s|0)==0){v=gj[c[w+8236>>2]&4095](k)|0;x=v;y=b[4853676]|0;z=a[h]|0}else{x=a[s+k|0]|0;y=l;z=u}u=((x&255)<<8)+y&65535;b[4853676]=u;y=z&255;z=(b[d+(y+12<<1)>>1]|0)+u&65535;b[4853900]=z;if((a[d+452|0]|0)==0){A=e[d+(y+4<<1)>>1]<<4;B=z&65535;C=A+B|0;c[2426954]=C;return C|0}else{A=c[d+448>>2]|0;B=z&65535;C=A+B|0;c[2426954]=C;return C|0}return 0}function gd0(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0;gcb(f);a[f+292|0]=0;a[f+291|0]=0;i=f+294|0;a[i]=c[f+336>>2]&255;do{if((h|0)==1){j=c[f+300>>2]|0}else if((h|0)==131072){a[i]=1;j=g}else if((h|0)==262144){if((c[f+436>>2]|0)==0){j=g;break}a[i]=0;j=g}else{j=g}}while(0);g=j<<2;j=f9x(f,g)|0;i=f9x(f,g|2)|0;g=f+295|0;h=f+((d[g]|0)+11<<1)|0;b[h>>1]=(b[h>>1]|0)-2&65535;h=d[g]|0;f9z(f,((e[f+(h+5<<1)>>1]|0)<<4)+(e[f+(h+11<<1)>>1]|0)|0,b[f+(h+6<<1)>>1]|0);h=f+((d[g]|0)+11<<1)|0;b[h>>1]=(b[h>>1]|0)-2&65535;h=d[g]|0;k=f+260|0;f9z(f,((e[f+(h+5<<1)>>1]|0)<<4)+(e[f+(h+11<<1)>>1]|0)|0,b[k>>1]|0);b[k>>1]=j;b[f+((d[g]|0)+6<<1)>>1]=i;a[f+443|0]=1;return}function gd1(e,f){e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;g=e+291|0;h=e+292|0;i=e+295|0;j=e+294|0;k=((d[e+288|0]|0)<<1|(c[e+280>>2]|0)!=0|(d[9760944+(c[e+284>>2]&255)|0]|0)<<2|(d[e+289|0]|0)<<3|((c[e+268>>2]|0)!=0)<<4|(d[e+290|0]|0)<<5|((c[e+276>>2]|0)==0)<<6|(c[e+264>>2]|0)>>>31<<7|(d[g]|0)<<8|(d[h]|0)<<9|(d[e+293|0]|0)<<10|((c[e+272>>2]|0)!=0)<<11|(d[i]|0)>>>4<<12|(d[j]|0)<<15)&65535;a[h]=0;a[g]=0;a[j]=c[e+336>>2]&255;j=f<<4;a[i]=j&255;a[e+296|0]=f<<5&255;b[e+((j&240|2)<<1)>>1]=k;k=e+260|0;b[e+((d[i]|0)+3<<1)>>1]=b[k>>1]|0;b[k>>1]=b[e+((d[i]|0)+1<<1)>>1]|0;a[e+443|0]=1;return}function gd2(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;if((b|0)==0){d=a[14113648]&a[9718208]&255}else{d=b}b=c[2394714]|0;if((b-93271|0)>>>0<2){e=a[9718208]&96|d}else{e=d}d=e&15;f=(e&16|0)==0?d:e;switch(f|0){case 5:{e=c[2112948]|0;if((e|0)==0){g=0}else{g=gj[e&4095](0)|0}e=a[9718188]|0;h=(a[9718209]&(e^15)|e&g)&15;return h|0};case 7:{if(!((b|0)==93271|(b|0)==93269)){h=a[9718211]|0;return h|0}b=c[2112948]|0;if((b|0)==0){i=0}else{i=gj[b&4095](2)|0}b=a[9718190]|0;h=a[9718211]&~b|b&i;return h|0};case 4:{h=a[9718208]|~a[14113648];return h|0};case 0:{h=0;return h|0};case 6:{i=c[2112948]|0;if((i|0)==0){j=0}else{j=gj[i&4095](1)|0}i=a[9718189]|0;h=a[9718210]&~i|i&j;return h|0};default:{if(f>>>0<8){h=a[9718204+f|0]|0;return h|0}else{j=f&(a[1428184]|0?31:127);h=a[(c[2440232]|0)+(((c[2396]|0)-93271|0)>>>0<2&j>>>0>95&j>>>0<112?d:j)|0]|0;return h|0}}}return 0}function gd3(e,f){e=e|0;f=f|0;var g=0,h=0,i=0,j=0;if((e|0)==0){g=a[14113648]&a[9718208]&255}else{g=e}e=c[2394714]|0;if((e-93271|0)>>>0<2){h=a[9718208]&96|g}else{h=g}g=h&15;i=(h&16|0)==0?g:h;switch(i|0){case 2:{a[9718206]=f;b[4859088]=(d[9718207]|0)<<4&3584|f&255;return};case 4:{a[9718208]=~a[14113648]|f;return};case 5:{h=f&15;j=c[2112946]|0;if((j|0)!=0){gg[j&4095](0,h&~a[9718188])}a[9718209]=h;return};case 1:{c[3526934]=2;if((a[9718181]&8)==0){b[4859098]=0}a[9718205]=f;return};case 7:{if(!((e|0)==93271|(e|0)==93269)){a[9718211]=f;return}e=c[2112946]|0;if((e|0)!=0){gg[e&4095](2,~a[9718190]&f)}a[9718211]=f;return};case 0:{return};case 6:{e=c[2112946]|0;if((e|0)!=0){gg[e&4095](1,~a[9718189]&f)}a[9718210]=f;return};case 3:{a[9718207]=a[9718207]&31|f&-32;return};default:{e=i&(a[1428184]|0?31:127);i=c[2440232]|0;if(((c[2396]|0)-93271|0)>>>0<2&e>>>0>95&e>>>0<112){a[i+g|0]=f;return}else{a[i+e|0]=f;return}}}}function gd4(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c[2433504]=f;do{do{if((a[9718207]&8)==0){c[2444184]=1;if((b[4859091]&4)==0){break}gd5(1)}else{g=b[4859088]|0;b[4859089]=g;h=e[(c[2440230]|0)+((c[355e3]&(g&65535))<<1)>>1]|0;c[2429550]=h;b[4859088]=g+1&65535;a[9718206]=(a[9718206]|0)+1&255;if((h&4080|0)==0){g=h&31;c[2444184]=c[1588200+(g<<2)>>2];gu[c[1449040+(g<<2)>>2]&16383]()}else{g=h>>>4&255;c[2444184]=c[7065600+(g<<2)>>2];gu[c[7014656+(g<<2)>>2]&16383]()}g=a[9718181]|0;do{if((g&32)==0){h=c[3526934]|0;if((h|0)!=0){c[3526934]=h-1;break}h=c[2444184]|0;if((g&8)!=0){a[9718205]=(d[9718205]|0)+h&255;break}i=(e[4859098]|0)+h|0;b[4859098]=i&65535;h=i&65535;i=g&7;j=2<<i;if((h|0)<(j|0)){break}a[9718205]=(d[9718205]|0)+(h>>>((i+1|0)>>>0))&255;b[4859098]=((h|0)%(j|0)|0)&65535}else{j=c[2112948]|0;if((j|0)==0){k=0;l=g}else{h=(gj[j&4095](16)|0)<<24>>24!=0;k=h;l=a[9718181]|0}h=k&1;j=(k&1)-(d[9638440]|0)|0;do{if((l&16)==0){if((j|0)<=0){break}if((l&8)!=0){a[9718205]=(a[9718205]|0)+1&255;break}i=(e[4859098]|0)+1|0;b[4859098]=i&65535;m=i&65535;i=l&7;n=2<<i;if((m|0)<(n|0)){break}a[9718205]=(d[9718205]|0)+(m>>>((i+1|0)>>>0))&255;b[4859098]=((m|0)%(n|0)|0)&65535}else{if((j|0)>=0){break}if((l&8)!=0){a[9718205]=(a[9718205]|0)+1&255;break}n=(e[4859098]|0)+1|0;b[4859098]=n&65535;m=n&65535;n=l&7;i=2<<n;if((m|0)<(i|0)){break}a[9718205]=(d[9718205]|0)+(m>>>((n+1|0)>>>0))&255;b[4859098]=((m|0)%(i|0)|0)&65535}}while(0);a[9638440]=h}}while(0);if((b[4859091]&4)==0){break}gd5(c[2444184]|0)}}while(0);o=(c[2433504]|0)-(c[2444184]|0)|0;c[2433504]=o;}while((o|0)>0);return f-o|0}function gd5(d){d=d|0;var e=0,f=0,g=0;if(((b[4859100]|0)-3&65535)<2){return}e=b[4859093]|0;f=(e&65535)-d|0;if((f&65520)>>>0>17999){g=17999-(f^65535)&65535}else{g=f&65535}b[4859093]=g;if(!(e<<16>>16!=0&(e&65535)<(g&65535)|g<<16>>16==0)){return}g=a[9718181]|0;if((g&8)==0){a[9718207]=a[9718207]|31;b[4859088]=c[2427090]&65535;b[4859091]=b[4887388]|0;a[9718188]=-1;a[9718189]=-1;a[9718190]=-1;a[9718181]=63;a[9718206]=-1;a[9718208]=a[9718208]|~a[14113648];a[9718209]=a[9718209]&15;b[4859098]=0;c[3526934]=0;a[9638440]=0;c[2444184]=0;return}e=(b[4859098]|0)+1&65535;b[4859098]=e;if((e&65535|0)<(1<<(g&7)|0)){return}a[9718207]=a[9718207]|31;b[4859088]=c[2427090]&65535;b[4859091]=b[4887388]|0;a[9718188]=-1;a[9718189]=-1;a[9718190]=-1;a[9718181]=63;a[9718206]=-1;a[9718208]=a[9718208]|~a[14113648];a[9718209]=a[9718209]&15;b[4859098]=0;c[3526934]=0;a[9638440]=0;c[2444184]=0;return}function gd6(d){d=d|0;switch(d|0){case 93272:{c[2394714]=93272;a[14113648]=127;c[2427090]=2047;b[4859088]=2047;b[4859091]=b[4887388]|0;a[9718188]=-1;a[9718189]=-1;a[9718190]=-1;a[9718181]=63;a[9718206]=-1;a[9718208]=a[9718208]|-128;a[9718209]=a[9718209]&15;b[4859098]=0;c[3526934]=0;a[9638440]=0;c[2444184]=0;a[9718207]=a[9718207]&7|24;c[355e3]=2047;a[1428184]=0;return};case 93270:{c[2394714]=93270;a[14113648]=31;c[2427090]=1023;b[4859088]=1023;b[4859091]=b[4887388]|0;a[9718188]=-1;a[9718189]=-1;a[9718190]=-1;a[9718181]=63;a[9718206]=-1;a[9718208]=a[9718208]|-32;a[9718209]=a[9718209]&15;b[4859098]=0;c[3526934]=0;a[9638440]=0;c[2444184]=0;a[9718207]=a[9718207]&7|24;c[355e3]=1023;a[1428184]=1;return};case 93268:{c[2394714]=93268;a[14113648]=31;c[2427090]=511;b[4859088]=511;b[4859091]=b[4887388]|0;a[9718188]=-1;a[9718189]=-1;a[9718190]=-1;a[9718181]=63;a[9718206]=-1;a[9718208]=a[9718208]|-32;a[9718209]=a[9718209]&15;b[4859098]=0;c[3526934]=0;a[9638440]=0;c[2444184]=0;a[9718207]=a[9718207]&7|24;c[355e3]=511;a[1428184]=1;return};case 93269:{c[2394714]=93269;a[14113648]=31;c[2427090]=511;b[4859088]=511;b[4859091]=b[4887388]|0;a[9718188]=-1;a[9718189]=-1;a[9718190]=-1;a[9718181]=63;a[9718206]=-1;a[9718208]=a[9718208]|-32;a[9718209]=a[9718209]&15;b[4859098]=0;c[3526934]=0;a[9638440]=0;c[2444184]=0;a[9718207]=a[9718207]&7|24;c[355e3]=1023;a[1428184]=1;return};case 93271:{c[2394714]=93271;a[14113648]=127;c[2427090]=2047;b[4859088]=2047;b[4859091]=b[4887388]|0;a[9718188]=-1;a[9718189]=-1;a[9718190]=-1;a[9718181]=63;a[9718206]=-1;a[9718208]=a[9718208]|-128;a[9718209]=a[9718209]&15;b[4859098]=0;c[3526934]=0;a[9638440]=0;c[2444184]=0;a[9718207]=a[9718207]&7|24;c[355e3]=2047;a[1428184]=0;return};default:{return}}}function gd7(){return}function gd8(){return}function gd9(){a[9718181]=a[9718180]&63;return}function gea(){if((b[4859091]&4)!=0){b[4859093]=0}if((a[9718181]&8)!=0){b[4859098]=0}a[9718207]=a[9718207]&-25|16;return}function geb(){b[4859093]=0;if((a[9718181]&8)!=0){b[4859098]=0}a[9718207]=a[9718207]|24;return}function gec(){var b=0,d=0,e=0;b=a[9718200]&7;if((b|0)==5){d=a[9718180]|0;if((a[9718188]|0)==d<<24>>24){return}a[9718188]=d|-16;e=c[2112946]|0;if((e|0)==0){return}gg[e&4095](0,a[9718209]&(d&15^15));return}else if((b|0)==7){d=c[2394714]|0;if(!((d|0)==93271|(d|0)==93269)){return}d=a[9718180]|0;if((a[9718190]|0)==d<<24>>24){return}a[9718190]=d;e=c[2112946]|0;if((e|0)==0){return}gg[e&4095](2,a[9718211]&~d);return}else if((b|0)==6){b=a[9718180]|0;if((a[9718189]|0)==b<<24>>24){return}a[9718189]=b;d=c[2112946]|0;if((d|0)==0){return}gg[d&4095](1,a[9718210]&~b);return}else{return}}function ged(){gd3(a[9718200]&31,a[9718180]|0);return}function gee(){a[9718180]=0;a[9718207]=a[9718207]|4;return}function gef(){gd3(a[9718200]&31,0);a[9718207]=a[9718207]|4;return}function geg(){var b=0,c=0,d=0,e=0,f=0;b=gd2(a[9718200]&31)|0;a[9578888]=b;c=b-(a[9718180]|0)&255;a[9718184]=c;d=a[9718200]|0;if((d&32)==0){a[9718180]=c;e=c;f=b}else{gd3(d&31,c);e=a[9718184]|0;f=a[9578888]|0}c=a[9718207]|0;d=e<<24>>24==0?c|4:c&-5;c=(f&255)<(e&255)?d&-2:d|1;a[9718207]=(f&15)>>>0<(e&15)>>>0?c&-3:c|2;return}function geh(){var b=0,c=0,d=0;b=(gd2(a[9718200]&31)|0)-1&255;a[9718184]=b;c=a[9718200]|0;if((c&32)==0){a[9718180]=b;d=b}else{gd3(c&31,b);d=a[9718184]|0}b=a[9718207]|0;a[9718207]=d<<24>>24==0?b|4:b&-5;return}function gei(){var b=0,c=0,d=0;b=gd2(a[9718200]&31)|0;c=a[9718180]|b;a[9718184]=c;b=a[9718200]|0;if((b&32)==0){a[9718180]=c;d=c}else{gd3(b&31,c);d=a[9718184]|0}c=a[9718207]|0;a[9718207]=d<<24>>24==0?c|4:c&-5;return}function gej(){var b=0,c=0,d=0;b=gd2(a[9718200]&31)|0;c=a[9718180]&b;a[9718184]=c;b=a[9718200]|0;if((b&32)==0){a[9718180]=c;d=c}else{gd3(b&31,c);d=a[9718184]|0}c=a[9718207]|0;a[9718207]=d<<24>>24==0?c|4:c&-5;return}function gek(){var b=0,c=0,d=0;b=gd2(a[9718200]&31)|0;c=a[9718180]^b;a[9718184]=c;b=a[9718200]|0;if((b&32)==0){a[9718180]=c;d=c}else{gd3(b&31,c);d=a[9718184]|0}c=a[9718207]|0;a[9718207]=d<<24>>24==0?c|4:c&-5;return}function gel(){var b=0,c=0,d=0,e=0,f=0;b=gd2(a[9718200]&31)|0;a[9578888]=b;c=(a[9718180]|0)+b&255;a[9718184]=c;d=a[9718200]|0;if((d&32)==0){a[9718180]=c;e=c;f=b}else{gd3(d&31,c);e=a[9718184]|0;f=a[9578888]|0}c=a[9718207]|0;d=e<<24>>24==0?c|4:c&-5;c=(f&255)>(e&255)?d|1:d&-2;a[9718207]=(f&15)>>>0>(e&15)>>>0?c|2:c&-3;return}function gem(){var b=0,c=0,d=0;b=gd2(a[9718200]&31)|0;a[9718184]=b;c=a[9718200]|0;if((c&32)==0){a[9718180]=b;d=b}else{gd3(c&31,b);d=a[9718184]|0}b=a[9718207]|0;a[9718207]=d<<24>>24==0?b|4:b&-5;return}function gen(){var b=0,c=0,d=0;b=~(gd2(a[9718200]&31)|0);a[9718184]=b;c=a[9718200]|0;if((c&32)==0){a[9718180]=b;d=b}else{gd3(c&31,b);d=a[9718184]|0}b=a[9718207]|0;a[9718207]=d<<24>>24==0?b|4:b&-5;return}function geo(){var b=0,c=0,d=0;b=(gd2(a[9718200]&31)|0)+1&255;a[9718184]=b;c=a[9718200]|0;if((c&32)==0){a[9718180]=b;d=b}else{gd3(c&31,b);d=a[9718184]|0}b=a[9718207]|0;a[9718207]=d<<24>>24==0?b|4:b&-5;return}function gep(){var d=0,e=0,f=0;d=(gd2(a[9718200]&31)|0)-1&255;a[9718184]=d;e=a[9718200]|0;if((e&32)==0){a[9718180]=d;f=d}else{gd3(e&31,d);f=a[9718184]|0}if(f<<24>>24!=0){return}f=(b[4859088]|0)+1&65535;b[4859088]=f;a[9718206]=f&255;c[2444184]=(c[2444184]|0)+1;return}function geq(){var b=0,c=0;b=((gd2(a[9718200]&31)|0)&255)>>>1;a[9718184]=b;if((a[9718207]&1)!=0){a[9718184]=b|-128}b=((gd2(a[9718200]&31)|0)&1)==0;c=a[9718207]|0;a[9718207]=b?c&-2:c|1;c=a[9718200]|0;b=a[9718184]|0;if((c&32)==0){a[9718180]=b;return}else{gd3(c&31,b);return}}function ger(){var b=0,c=0;b=(gd2(a[9718200]&31)|0)<<1;a[9718184]=b;if((a[9718207]&1)!=0){a[9718184]=b|1}b=(gd2(a[9718200]&31)|0)<<24>>24<0;c=a[9718207]|0;a[9718207]=b?c|1:c&-2;c=a[9718200]|0;b=a[9718184]|0;if((c&32)==0){a[9718180]=b;return}else{gd3(c&31,b);return}}function ges(){var b=0,c=0;a[9718184]=(gd2(a[9718200]&31)|0)<<4;b=((gd2(a[9718200]&31)|0)&255)>>>4;c=a[9718184]|b;a[9718184]=c;b=a[9718200]|0;if((b&32)==0){a[9718180]=c;return}else{gd3(b&31,c);return}}function get(){var d=0,e=0,f=0;d=(gd2(a[9718200]&31)|0)+1&255;a[9718184]=d;e=a[9718200]|0;if((e&32)==0){a[9718180]=d;f=d}else{gd3(e&31,d);f=a[9718184]|0}if(f<<24>>24!=0){return}f=(b[4859088]|0)+1&65535;b[4859088]=f;a[9718206]=f&255;c[2444184]=(c[2444184]|0)+1;return}function geu(){var b=0,e=0,f=0;b=gd2(a[9718200]&31)|0;e=d[9718200]|0;f=c[670512+(e>>>5<<2)>>2]&(b&255)&255;a[9718184]=f;gd3(e&31,f);return}function gev(){var b=0,e=0,f=0;b=gd2(a[9718200]&31)|0;e=d[9718200]|0;f=(c[670480+(e>>>5<<2)>>2]|b&255)&255;a[9718184]=f;gd3(e&31,f);return}function gew(){var e=0;e=(gd2(a[9718200]&31)|0)&255;if((c[670480+((d[9718200]|0)>>>5<<2)>>2]&e|0)!=0){return}e=(b[4859088]|0)+1&65535;b[4859088]=e;a[9718206]=e&255;c[2444184]=(c[2444184]|0)+1;return}function gex(){var e=0,f=0;e=(gd2(a[9718200]&31)|0)&255;f=c[670480+((d[9718200]|0)>>>5<<2)>>2]|0;if((f&e|0)!=(f|0)){return}f=(b[4859088]|0)+1&65535;b[4859088]=f;a[9718206]=f&255;c[2444184]=(c[2444184]|0)+1;return}function gey(){var c=0;a[9718180]=a[9718200]|0;c=b[4859097]|0;b[4859097]=b[4859096]|0;b[4859088]=c&2047;a[9718206]=c&255;return}function gez(){var c=0;c=b[4859088]|0;b[4859096]=b[4859097]|0;b[4859097]=c&2047;c=a[9718200]|0;b[4859088]=(d[9718207]|0)<<4&1536|c&255;a[9718206]=c;return}function geA(){var c=0;c=b[4859100]|0;b[4859088]=(d[9718207]|0)<<4&1536|c&511;a[9718206]=c&255;return}function geB(){a[9718180]=a[9718200]|0;return}function geC(){var b=0,c=0;b=a[9718180]|a[9718200];a[9718184]=b;a[9718180]=b;c=a[9718207]|0;a[9718207]=b<<24>>24==0?c|4:c&-5;return}function geD(){var b=0,c=0;b=a[9718180]&a[9718200];a[9718184]=b;a[9718180]=b;c=a[9718207]|0;a[9718207]=b<<24>>24==0?c|4:c&-5;return}function geE(){var b=0,c=0,d=0;b=a[9718180]|0;c=a[9718200]|0;d=c^b;a[9718184]=d;a[9718180]=d;d=a[9718207]|0;a[9718207]=c<<24>>24==b<<24>>24?d|4:d&-5;return}function geF(){gGz(9718136|0,0|0,38|0);a[9718144]=10;a[9718145]=0;return}function geG(d){d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if((d|0)==1){a[9718145]=a[9718145]|-128;return}a[9718172]=1;if((a[9718145]&32)!=0){return}if((a[9718154]|0)!=0){a[9718154]=0;b[4859070]=(b[4859070]|0)+1&8191}d=c[8449976+(c[2444]<<2)>>2]|0;if((d|0)==0){e=0}else{e=(gj[d&4095](0)|0)&255}d=c[5093528+(e<<2)>>2]&8191;b[4859071]=d;if((e&128|0)!=0){e=d&65535;c[2440218]=(c[2440218]|0)-6;f=c[2110940]|0;g=c[f+16+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[2110940]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);f=(i&255)<<8;b[4859071]=f;i=e+1|0;e=((i&8191|0)==0?d+24577&65535:i&65535)&32767;i=e&65535;d=c[j+16+(i>>>8<<2)>>2]|0;do{if((d|0)==0){g=c[j>>2]|0;if((g|0)==0){l=0;break}l=gj[g&4095](e)|0}else{l=a[d+(i&255)|0]|0}}while(0);b[4859071]=l&255|f&32512}f=a[9718145]|0;l=f+1&255;a[9718145]=f&-40|l&7|32;b[9718156+((l&7)<<1)>>1]=(b[4859070]|0)+(b[4859069]|0)&65535;l=b[4859071]|0;b[4859069]=l&24576;b[4859070]=l&8191;return}function geH(e){e=e|0;var f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0,cf=0,cg=0,ch=0,ci=0,cj=0,ck=0,cl=0,cm=0,cn=0,co=0,cp=0,cq=0,cr=0,cs=0,ct=0,cu=0,cv=0,cw=0,cx=0,cy=0,cz=0,cA=0,cB=0,cC=0,cD=0,cE=0,cF=0,cG=0,cH=0,cI=0,cJ=0,cK=0,cL=0,cM=0,cN=0,cO=0,cP=0,cQ=0,cR=0,cS=0,cT=0,cU=0,cV=0,cW=0,cX=0,cY=0,cZ=0,c_=0,c$=0,c0=0,c1=0,c2=0,c3=0,c4=0,c5=0,c6=0,c7=0,c8=0,c9=0,da=0,db=0;f=i;i=i+14024|0;c[2440218]=e;L66155:while(1){h=b[4859070]|0;j=h+(b[4859069]|0)&65535;b[4859068]=j;k=c[2110940]|0;l=c[k+1040+((j&32767&65535)>>>8<<2)>>2]|0;do{if((l|0)==0){m=c[k+16+((j&32767&65535)>>>8<<2)>>2]|0;if((m|0)!=0){n=a[m+(j&32767&65535&255)|0]|0;o=h;break}m=c[k>>2]|0;if((m|0)==0){n=0;o=h;break}p=gj[m&4095](j&32767)|0;n=p;o=b[4859070]|0}else{n=a[l+(j&32767&65535&255)|0]|0;o=h}}while(0);h=o+1&8191;b[4859070]=h;a[9718155]=n;j=n&3;a[9718146]=j;L66165:do{l=1;k=n&255|0;if(l){l=0;switch(k|0){case 4:case 5:case 6:case 7:{c[2440218]=(c[2440218]|0)-6;p=(b[4859069]|0)+h&32767;m=c[2110940]|0;q=c[m+1040+((p&65535)>>>8<<2)>>2]|0;do{if((q|0)==0){r=c[m+16+((p&65535)>>>8<<2)>>2]|0;if((r|0)!=0){s=a[r+(p&65535&255)|0]|0;t=h;u=j;break}r=c[m>>2]|0;if((r|0)==0){s=0;t=h;u=j;break}v=gj[r&4095](p)|0;s=v;t=b[4859070]|0;u=a[9718146]|0}else{s=a[q+(p&65535&255)|0]|0;t=h;u=j}}while(0);b[4859070]=t+1&8191;a[9718147+(u&255)|0]=s;a[9718144]=a[680792+(d[9718147+(d[9718146]|0)|0]|0)|0]|a[9718144]&63;w=55018;break};case 8:case 9:case 10:case 11:{c[2440218]=(c[2440218]|0)-9;p=b[4859069]|0;q=c[2110940]|0;m=c[q+1040+((p+h&32767&65535)>>>8<<2)>>2]|0;do{if((m|0)==0){v=c[q+16+((p+h&32767&65535)>>>8<<2)>>2]|0;if((v|0)!=0){x=a[v+(p+h&32767&65535&255)|0]|0;y=h;z=p;break}v=c[q>>2]|0;if((v|0)==0){x=0;y=h;z=p;break}r=gj[v&4095](p+h&32767)|0;x=r;y=b[4859070]|0;z=b[4859069]|0}else{x=a[m+(p+h&32767&65535&255)|0]|0;y=h;z=p}}while(0);p=y+1&65535;b[4859070]=p&8191;m=x&255;q=((p&65535)+(c[5093528+(m<<2)>>2]|0)&8191)+(z&65535)|0;b[4859071]=q&65535;if((m&128|0)==0){A=q&65535}else{c[2440218]=(c[2440218]|0)-6;m=c[2110940]|0;p=c[m+16+((q&65535&32767&65535)>>>8<<2)>>2]|0;do{if((p|0)==0){r=c[m>>2]|0;if((r|0)==0){C=0;D=m;break}v=gj[r&4095](q&65535&32767)|0;C=v;D=c[2110940]|0}else{C=a[p+(q&65535&32767&65535&255)|0]|0;D=m}}while(0);m=(C&255)<<8;b[4859071]=m;p=(((q+1|0)&8191|0)==0?q+24577|0:q+1|0)&32767;v=c[D+16+((p&65535)>>>8<<2)>>2]|0;do{if((v|0)==0){r=c[D>>2]|0;if((r|0)==0){E=0;break}E=gj[r&4095](p)|0}else{E=a[v+(p&65535&255)|0]|0}}while(0);p=E&255|m&32512;b[4859071]=p;A=p}p=A&32767;v=c[2110940]|0;q=c[v+16+((p&65535)>>>8<<2)>>2]|0;do{if((q|0)==0){r=c[v>>2]|0;if((r|0)==0){F=0;break}F=gj[r&4095](p)|0}else{F=a[q+(p&65535&255)|0]|0}}while(0);a[9718147+(d[9718146]|0)|0]=F;a[9718144]=a[680792+(d[9718147+(d[9718146]|0)|0]|0)|0]|a[9718144]&63;w=55018;break};case 40:case 41:case 42:case 43:{c[2440218]=(c[2440218]|0)-9;p=b[4859069]|0;q=c[2110940]|0;v=c[q+1040+((p+h&32767&65535)>>>8<<2)>>2]|0;do{if((v|0)==0){m=c[q+16+((p+h&32767&65535)>>>8<<2)>>2]|0;if((m|0)!=0){G=a[m+(p+h&32767&65535&255)|0]|0;H=h;K=p;break}m=c[q>>2]|0;if((m|0)==0){G=0;H=h;K=p;break}r=gj[m&4095](p+h&32767)|0;G=r;H=b[4859070]|0;K=b[4859069]|0}else{G=a[v+(p+h&32767&65535&255)|0]|0;H=h;K=p}}while(0);p=H+1&65535;b[4859070]=p&8191;v=G&255;q=((p&65535)+(c[5093528+(v<<2)>>2]|0)&8191)+(K&65535)|0;b[4859071]=q&65535;if((v&128|0)==0){L=q&65535}else{c[2440218]=(c[2440218]|0)-6;v=c[2110940]|0;p=c[v+16+((q&65535&32767&65535)>>>8<<2)>>2]|0;do{if((p|0)==0){r=c[v>>2]|0;if((r|0)==0){M=0;N=v;break}m=gj[r&4095](q&65535&32767)|0;M=m;N=c[2110940]|0}else{M=a[p+(q&65535&32767&65535&255)|0]|0;N=v}}while(0);v=(M&255)<<8;b[4859071]=v;p=(((q+1|0)&8191|0)==0?q+24577|0:q+1|0)&32767;m=c[N+16+((p&65535)>>>8<<2)>>2]|0;do{if((m|0)==0){r=c[N>>2]|0;if((r|0)==0){O=0;break}O=gj[r&4095](p)|0}else{O=a[m+(p&65535&255)|0]|0}}while(0);p=O&255|v&32512;b[4859071]=p;L=p}p=L&32767;m=c[2110940]|0;q=c[m+16+((p&65535)>>>8<<2)>>2]|0;do{if((q|0)==0){r=c[m>>2]|0;if((r|0)==0){P=0;break}P=gj[r&4095](p)|0}else{P=a[q+(p&65535&255)|0]|0}}while(0);p=9718147+(d[9718146]|0)|0;a[p]=a[p]^P;a[9718144]=a[680792+(d[9718147+(d[9718146]|0)|0]|0)|0]|a[9718144]&63;w=55018;break};case 31:{c[2440218]=(c[2440218]|0)-9;p=b[4859069]|0;q=c[2110940]|0;m=c[q+1040+((p+h&32767&65535)>>>8<<2)>>2]|0;do{if((m|0)==0){v=c[q+16+((p+h&32767&65535)>>>8<<2)>>2]|0;if((v|0)!=0){Q=a[v+(p+h&32767&65535&255)|0]|0;R=h;S=p;T=q;break}v=c[q>>2]|0;if((v|0)==0){Q=0;R=h;S=p;T=q;break}r=gj[v&4095](p+h&32767)|0;Q=r;R=b[4859070]|0;S=b[4859069]|0;T=c[2110940]|0}else{Q=a[m+(p+h&32767&65535&255)|0]|0;R=h;S=p;T=q}}while(0);q=R+1&8191;b[4859070]=q;p=q+S&32767;m=c[T+1040+((p&65535)>>>8<<2)>>2]|0;do{if((m|0)==0){r=c[T+16+((p&65535)>>>8<<2)>>2]|0;if((r|0)!=0){U=a[r+(p&65535&255)|0]|0;V=q;break}r=c[T>>2]|0;if((r|0)==0){U=0;V=q;break}v=gj[r&4095](p)|0;U=v;V=b[4859070]|0}else{U=a[m+(p&65535&255)|0]|0;V=q}}while(0);b[4859070]=V+1&8191;q=Q&255;p=U&255;b[4859071]=(p|q<<8&32512)&65535;if((q&128|0)==0){W=(p|q<<8&32512)&65535}else{c[2440218]=(c[2440218]|0)-6;m=c[2110940]|0;v=c[m+16+((q<<8&32512)>>>8<<2)>>2]|0;do{if((v|0)==0){r=c[m>>2]|0;if((r|0)==0){X=0;Y=m;break}Z=gj[r&4095]((p|q<<8&32512)&65535)|0;X=Z;Y=c[2110940]|0}else{X=a[v+p|0]|0;Y=m}}while(0);m=(X&255)<<8;b[4859071]=m;v=((((p|q<<8&32512)+1|0)&8191|0)==0?(p|q<<8&32512)+24577|0:(p|q<<8&32512)+1|0)&32767;Z=c[Y+16+((v&65535)>>>8<<2)>>2]|0;do{if((Z|0)==0){r=c[Y>>2]|0;if((r|0)==0){_=0;break}_=gj[r&4095](v)|0}else{_=a[Z+(v&65535&255)|0]|0}}while(0);v=_&255|m&32512;b[4859071]=v;W=v}b[4859069]=W&24576;b[4859070]=W&8191;w=55018;break};case 19:{c[2440218]=(c[2440218]|0)-6;v=a[9718144]|0;a[9718147]=v;a[9718144]=v&63|a[680792+(v&255)|0];w=55018;break};case 63:{c[2440218]=(c[2440218]|0)-9;v=b[4859069]|0;Z=c[2110940]|0;q=c[Z+1040+((v+h&32767&65535)>>>8<<2)>>2]|0;do{if((q|0)==0){p=c[Z+16+((v+h&32767&65535)>>>8<<2)>>2]|0;if((p|0)!=0){$=a[p+(v+h&32767&65535&255)|0]|0;aa=h;ab=v;ac=Z;break}p=c[Z>>2]|0;if((p|0)==0){$=0;aa=h;ab=v;ac=Z;break}r=gj[p&4095](v+h&32767)|0;$=r;aa=b[4859070]|0;ab=b[4859069]|0;ac=c[2110940]|0}else{$=a[q+(v+h&32767&65535&255)|0]|0;aa=h;ab=v;ac=Z}}while(0);Z=aa+1&8191;b[4859070]=Z;v=Z+ab&32767;q=c[ac+1040+((v&65535)>>>8<<2)>>2]|0;do{if((q|0)==0){m=c[ac+16+((v&65535)>>>8<<2)>>2]|0;if((m|0)!=0){ad=a[m+(v&65535&255)|0]|0;ae=Z;break}m=c[ac>>2]|0;if((m|0)==0){ad=0;ae=Z;break}r=gj[m&4095](v)|0;ad=r;ae=b[4859070]|0}else{ad=a[q+(v&65535&255)|0]|0;ae=Z}}while(0);Z=ae+1&8191;b[4859070]=Z;v=$&255;q=ad&255;b[4859071]=(q|v<<8&32512)&65535;if((v&128|0)==0){af=Z}else{c[2440218]=(c[2440218]|0)-6;Z=c[2110940]|0;r=c[Z+16+((v<<8&32512)>>>8<<2)>>2]|0;do{if((r|0)==0){m=c[Z>>2]|0;if((m|0)==0){ag=0;ah=Z;break}p=gj[m&4095]((q|v<<8&32512)&65535)|0;ag=p;ah=c[2110940]|0}else{ag=a[r+q|0]|0;ah=Z}}while(0);Z=(ag&255)<<8;b[4859071]=Z;r=((((q|v<<8&32512)+1|0)&8191|0)==0?(q|v<<8&32512)+24577|0:(q|v<<8&32512)+1|0)&32767;p=c[ah+16+((r&65535)>>>8<<2)>>2]|0;do{if((p|0)==0){m=c[ah>>2]|0;if((m|0)==0){ai=0;break}ai=gj[m&4095](r)|0}else{ai=a[p+(r&65535&255)|0]|0}}while(0);b[4859071]=ai&255|Z&32512;af=b[4859070]|0}r=a[9718145]|0;a[9718145]=r+1&255&7|r&-8;b[9718156+((r+1&255&7)<<1)>>1]=(b[4859069]|0)+af&65535;r=b[4859071]|0;b[4859069]=r&24576;b[4859070]=r&8191;w=55018;break};case 104:case 105:case 106:case 107:{c[2440218]=(c[2440218]|0)-9;r=b[4859069]|0;p=c[2110940]|0;v=c[p+1040+((r+h&32767&65535)>>>8<<2)>>2]|0;do{if((v|0)==0){q=c[p+16+((r+h&32767&65535)>>>8<<2)>>2]|0;if((q|0)!=0){aj=a[q+(r+h&32767&65535&255)|0]|0;ak=h;al=r;break}q=c[p>>2]|0;if((q|0)==0){aj=0;ak=h;al=r;break}m=gj[q&4095](r+h&32767)|0;aj=m;ak=b[4859070]|0;al=b[4859069]|0}else{aj=a[v+(r+h&32767&65535&255)|0]|0;ak=h;al=r}}while(0);r=ak+1&65535;b[4859070]=r&8191;v=aj&255;p=((r&65535)+(c[5093528+(v<<2)>>2]|0)&8191)+(al&65535)|0;b[4859071]=p&65535;if((v&128|0)==0){am=p&65535}else{c[2440218]=(c[2440218]|0)-6;v=c[2110940]|0;r=c[v+16+((p&65535&32767&65535)>>>8<<2)>>2]|0;do{if((r|0)==0){Z=c[v>>2]|0;if((Z|0)==0){an=0;ao=v;break}m=gj[Z&4095](p&65535&32767)|0;an=m;ao=c[2110940]|0}else{an=a[r+(p&65535&32767&65535&255)|0]|0;ao=v}}while(0);v=(an&255)<<8;b[4859071]=v;r=(((p+1|0)&8191|0)==0?p+24577|0:p+1|0)&32767;m=c[ao+16+((r&65535)>>>8<<2)>>2]|0;do{if((m|0)==0){Z=c[ao>>2]|0;if((Z|0)==0){ap=0;break}ap=gj[Z&4095](r)|0}else{ap=a[m+(r&65535&255)|0]|0}}while(0);r=ap&255|v&32512;b[4859071]=r;am=r}r=am&32767;m=c[2110940]|0;p=c[m+16+((r&65535)>>>8<<2)>>2]|0;do{if((p|0)==0){Z=c[m>>2]|0;if((Z|0)==0){aq=0;break}aq=gj[Z&4095](r)|0}else{aq=a[p+(r&65535&255)|0]|0}}while(0);r=9718147+(d[9718146]|0)|0;a[r]=a[r]|aq;a[9718144]=a[680792+(d[9718147+(d[9718146]|0)|0]|0)|0]|a[9718144]&63;w=55018;break};case 80:case 81:case 82:case 83:{c[2440218]=(c[2440218]|0)-6;r=a[9718147+(j&255)|0]|0;p=a[9718144]|0;if((p&8)==0){a[9718147+(j&255)|0]=(r&255)>>>1|r<<7;ar=a[9718144]|0;as=a[9718146]|0}else{a[9718144]=p&-34;a[9718147+(j&255)|0]=p<<7|(r&255)>>>1;p=a[9718146]|0;m=a[9718147+(p&255)|0]&32|r&1|a[9718144];a[9718144]=m;ar=m;as=p}p=9718147+(as&255)|0;m=a[680792+(d[p]|0)|0]|ar&63;a[9718144]=m;a[9718144]=((a[p]^r)&255)>>>5&4|m&-5;w=55018;break};case 188:case 189:case 190:{c[2440218]=(c[2440218]|0)-9;if(((d[9718144]|0)>>>6|0)==(j&255|0)){b[4859070]=o+3&8191;w=55018;break L66165}m=b[4859069]|0;r=c[2110940]|0;p=c[r+1040+((m+h&32767&65535)>>>8<<2)>>2]|0;do{if((p|0)==0){v=c[r+16+((m+h&32767&65535)>>>8<<2)>>2]|0;if((v|0)!=0){at=a[v+(m+h&32767&65535&255)|0]|0;au=h;av=m;aw=r;break}v=c[r>>2]|0;if((v|0)==0){at=0;au=h;av=m;aw=r;break}Z=gj[v&4095](m+h&32767)|0;at=Z;au=b[4859070]|0;av=b[4859069]|0;aw=c[2110940]|0}else{at=a[p+(m+h&32767&65535&255)|0]|0;au=h;av=m;aw=r}}while(0);r=au+1&8191;b[4859070]=r;m=r+av&32767;p=c[aw+1040+((m&65535)>>>8<<2)>>2]|0;do{if((p|0)==0){Z=c[aw+16+((m&65535)>>>8<<2)>>2]|0;if((Z|0)!=0){ax=a[Z+(m&65535&255)|0]|0;ay=r;break}Z=c[aw>>2]|0;if((Z|0)==0){ax=0;ay=r;break}v=gj[Z&4095](m)|0;ax=v;ay=b[4859070]|0}else{ax=a[p+(m&65535&255)|0]|0;ay=r}}while(0);r=ay+1&8191;b[4859070]=r;m=at&255;p=ax&255;b[4859071]=(p|m<<8&32512)&65535;if((m&128|0)==0){az=r}else{c[2440218]=(c[2440218]|0)-6;r=c[2110940]|0;v=c[r+16+((m<<8&32512)>>>8<<2)>>2]|0;do{if((v|0)==0){Z=c[r>>2]|0;if((Z|0)==0){aA=0;aB=r;break}q=gj[Z&4095]((p|m<<8&32512)&65535)|0;aA=q;aB=c[2110940]|0}else{aA=a[v+p|0]|0;aB=r}}while(0);r=(aA&255)<<8;b[4859071]=r;v=((((p|m<<8&32512)+1|0)&8191|0)==0?(p|m<<8&32512)+24577|0:(p|m<<8&32512)+1|0)&32767;q=c[aB+16+((v&65535)>>>8<<2)>>2]|0;do{if((q|0)==0){Z=c[aB>>2]|0;if((Z|0)==0){aC=0;break}aC=gj[Z&4095](v)|0}else{aC=a[q+(v&65535&255)|0]|0}}while(0);b[4859071]=aC&255|r&32512;az=b[4859070]|0}v=a[9718145]|0;a[9718145]=v+1&255&7|v&-8;b[9718156+((v+1&255&7)<<1)>>1]=(b[4859069]|0)+az&65535;v=b[4859071]|0;b[4859069]=v&24576;b[4859070]=v&8191;w=55018;break};case 187:{c[2440218]=(c[2440218]|0)-9;v=(b[4859069]|0)+h&32767;q=c[2110940]|0;m=c[q+1040+((v&65535)>>>8<<2)>>2]|0;do{if((m|0)==0){p=c[q+16+((v&65535)>>>8<<2)>>2]|0;if((p|0)!=0){aD=a[p+(v&65535&255)|0]|0;aE=h;break}p=c[q>>2]|0;if((p|0)==0){aD=0;aE=h;break}Z=gj[p&4095](v)|0;aD=Z;aE=b[4859070]|0}else{aD=a[m+(v&65535&255)|0]|0;aE=h}}while(0);v=aE+1&8191;b[4859070]=v;m=aD&255;q=c[5093528+(m<<2)>>2]&8191;b[4859071]=q;if((m&128|0)==0){aF=v}else{c[2440218]=(c[2440218]|0)-6;v=c[2110940]|0;m=c[v+16+((q&65535)>>>8<<2)>>2]|0;do{if((m|0)==0){r=c[v>>2]|0;if((r|0)==0){aG=0;aH=v;break}Z=gj[r&4095](q)|0;aG=Z;aH=c[2110940]|0}else{aG=a[m+(q&65535&255)|0]|0;aH=v}}while(0);v=(aG&255)<<8;b[4859071]=v;m=((((q&65535)+1|0)&8191|0)==0?q+24577&65535:((q&65535)+1|0)&65535)&32767;Z=c[aH+16+((m&65535)>>>8<<2)>>2]|0;do{if((Z|0)==0){r=c[aH>>2]|0;if((r|0)==0){aI=0;break}aI=gj[r&4095](m)|0}else{aI=a[Z+(m&65535&255)|0]|0}}while(0);b[4859071]=aI&255|v&32512;aF=b[4859070]|0}m=a[9718145]|0;a[9718145]=m+1&255&7|m&-8;b[9718156+((m+1&255&7)<<1)>>1]=(b[4859069]|0)+aF&65535;m=b[4859071]|0;b[4859069]=m&24576;b[4859070]=m&8191;w=55018;break};case 140:case 141:case 142:case 143:{c[2440218]=(c[2440218]|0)-12;m=b[4859069]|0;Z=c[2110940]|0;q=c[Z+1040+((m+h&32767&65535)>>>8<<2)>>2]|0;do{if((q|0)==0){r=c[Z+16+((m+h&32767&65535)>>>8<<2)>>2]|0;if((r|0)!=0){aJ=a[r+(m+h&32767&65535&255)|0]|0;aK=h;aL=m;aM=Z;break}r=c[Z>>2]|0;if((r|0)==0){aJ=0;aK=h;aL=m;aM=Z;break}p=gj[r&4095](m+h&32767)|0;aJ=p;aK=b[4859070]|0;aL=b[4859069]|0;aM=c[2110940]|0}else{aJ=a[q+(m+h&32767&65535&255)|0]|0;aK=h;aL=m;aM=Z}}while(0);Z=aK+1&8191;b[4859070]=Z;m=Z+aL&32767;q=c[aM+1040+((m&65535)>>>8<<2)>>2]|0;do{if((q|0)==0){v=c[aM+16+((m&65535)>>>8<<2)>>2]|0;if((v|0)!=0){aN=a[v+(m&65535&255)|0]|0;aO=Z;aP=aL;break}v=c[aM>>2]|0;if((v|0)==0){aN=0;aO=Z;aP=aL;break}p=gj[v&4095](m)|0;aN=p;aO=b[4859070]|0;aP=b[4859069]|0}else{aN=a[q+(m&65535&255)|0]|0;aO=Z;aP=aL}}while(0);b[4859070]=aO+1&8191;Z=aJ&255;m=(aP&65535)+(aN&255|Z<<8&7936)|0;b[4859071]=m&65535;if((Z&128|0)==0){aQ=m&65535}else{c[2440218]=(c[2440218]|0)-6;q=c[2110940]|0;p=c[q+16+((m&65535&32767&65535)>>>8<<2)>>2]|0;do{if((p|0)==0){v=c[q>>2]|0;if((v|0)==0){aR=0;aS=q;break}r=gj[v&4095](m&65535&32767)|0;aR=r;aS=c[2110940]|0}else{aR=a[p+(m&65535&32767&65535&255)|0]|0;aS=q}}while(0);q=(aR&255)<<8;b[4859071]=q;p=(((m+1|0)&8191|0)==0?m+24577|0:m+1|0)&32767;r=c[aS+16+((p&65535)>>>8<<2)>>2]|0;do{if((r|0)==0){v=c[aS>>2]|0;if((v|0)==0){aT=0;break}aT=gj[v&4095](p)|0}else{aT=a[r+(p&65535&255)|0]|0}}while(0);p=aT&255|q&32512;b[4859071]=p;aQ=p}if((Z&96|0)==32){p=9718147+(d[9718146]|0)|0;a[p]=(a[p]|0)+1&255;p=b[4859071]|0;r=(d[9718147+(d[9718146]|0)|0]|0)+p&8191|p&24576;b[4859071]=r;a[9718146]=0;aU=r}else if((Z&96|0)==64){r=9718147+(d[9718146]|0)|0;a[r]=(a[r]|0)-1&255;r=b[4859071]|0;p=(d[9718147+(d[9718146]|0)|0]|0)+r&8191|r&24576;b[4859071]=p;a[9718146]=0;aU=p}else if((Z&96|0)==96){p=(d[9718147+(d[9718146]|0)|0]|0)+aQ&8191|aQ&24576;b[4859071]=p;a[9718146]=0;aU=p}else{aU=aQ}p=aU&32767;r=c[2110940]|0;m=c[r+16+((p&65535)>>>8<<2)>>2]|0;do{if((m|0)==0){v=c[r>>2]|0;if((v|0)==0){aV=0;break}aV=gj[v&4095](p)|0}else{aV=a[m+(p&65535&255)|0]|0}}while(0);p=9718147+(d[9718146]|0)|0;m=a[p]|0;r=a[9718144]|0;Z=(m&255)+(aV&255)+(r&255&1&(r&255)>>>3)|0;a[9718144]=Z>>>8&1|r&-38;a[p]=Z&255;Z=9718147+(d[9718146]|0)|0;p=a[Z]|0;r=a[9718144]|0;if((p&15)>>>0<(m&255&15)>>>0){a[9718144]=r|32;aW=a[Z]|0;aX=r|32}else{aW=p;aX=r}a[9718144]=a[680792+(((aW^m)&255&((m^aV)&255^128))<<1&256|aW&255)|0]|aX&59;w=55018;break};case 252:case 253:case 254:case 255:{c[2440218]=(c[2440218]|0)-9;m=(a[9718147+(j&255)|0]|0)-1&255;a[9718147+(j&255)|0]=m;if(m<<24>>24==0){b[4859070]=(b[4859070]|0)+2&8191;w=55018;break L66165}m=b[4859069]|0;r=b[4859070]|0;p=c[2110940]|0;Z=c[p+1040+((r+m&32767&65535)>>>8<<2)>>2]|0;do{if((Z|0)==0){q=c[p+16+((r+m&32767&65535)>>>8<<2)>>2]|0;if((q|0)!=0){aY=a[q+(r+m&32767&65535&255)|0]|0;aZ=r;a_=m;a$=p;break}q=c[p>>2]|0;if((q|0)==0){aY=0;aZ=r;a_=m;a$=p;break}v=gj[q&4095](r+m&32767)|0;aY=v;aZ=b[4859070]|0;a_=b[4859069]|0;a$=c[2110940]|0}else{aY=a[Z+(r+m&32767&65535&255)|0]|0;aZ=r;a_=m;a$=p}}while(0);p=aZ+1&8191;b[4859070]=p;m=p+a_&32767;r=c[a$+1040+((m&65535)>>>8<<2)>>2]|0;do{if((r|0)==0){Z=c[a$+16+((m&65535)>>>8<<2)>>2]|0;if((Z|0)!=0){a0=a[Z+(m&65535&255)|0]|0;a1=p;break}Z=c[a$>>2]|0;if((Z|0)==0){a0=0;a1=p;break}v=gj[Z&4095](m)|0;a0=v;a1=b[4859070]|0}else{a0=a[r+(m&65535&255)|0]|0;a1=p}}while(0);b[4859070]=a1+1&8191;p=aY&255;m=a0&255;b[4859071]=(m|p<<8&32512)&65535;if((p&128|0)==0){a2=(m|p<<8&32512)&65535}else{c[2440218]=(c[2440218]|0)-6;r=c[2110940]|0;v=c[r+16+((p<<8&32512)>>>8<<2)>>2]|0;do{if((v|0)==0){Z=c[r>>2]|0;if((Z|0)==0){a3=0;a4=r;break}q=gj[Z&4095]((m|p<<8&32512)&65535)|0;a3=q;a4=c[2110940]|0}else{a3=a[v+m|0]|0;a4=r}}while(0);r=(a3&255)<<8;b[4859071]=r;v=((((m|p<<8&32512)+1|0)&8191|0)==0?(m|p<<8&32512)+24577|0:(m|p<<8&32512)+1|0)&32767;q=c[a4+16+((v&65535)>>>8<<2)>>2]|0;do{if((q|0)==0){Z=c[a4>>2]|0;if((Z|0)==0){a5=0;break}a5=gj[Z&4095](v)|0}else{a5=a[q+(v&65535&255)|0]|0}}while(0);v=a5&255|r&32512;b[4859071]=v;a2=v}b[4859069]=a2&24576;b[4859070]=a2&8191;w=55018;break};case 24:case 25:case 26:{c[2440218]=(c[2440218]|0)-9;if(((d[9718144]|0)>>>6|0)!=(j&255|0)){b[4859070]=o+2&8191;w=55018;break L66165}v=b[4859069]|0;q=c[2110940]|0;p=c[q+1040+((v+h&32767&65535)>>>8<<2)>>2]|0;do{if((p|0)==0){m=c[q+16+((v+h&32767&65535)>>>8<<2)>>2]|0;if((m|0)!=0){a6=a[m+(v+h&32767&65535&255)|0]|0;a7=h;a8=v;break}m=c[q>>2]|0;if((m|0)==0){a6=0;a7=h;a8=v;break}Z=gj[m&4095](v+h&32767)|0;a6=Z;a7=b[4859070]|0;a8=b[4859069]|0}else{a6=a[p+(v+h&32767&65535&255)|0]|0;a7=h;a8=v}}while(0);v=a7+1&65535;b[4859070]=v&8191;p=a6&255;q=((v&65535)+(c[5093528+(p<<2)>>2]|0)&8191)+(a8&65535)|0;b[4859071]=q&65535;if((p&128|0)==0){a9=q&65535}else{c[2440218]=(c[2440218]|0)-6;p=c[2110940]|0;v=c[p+16+((q&65535&32767&65535)>>>8<<2)>>2]|0;do{if((v|0)==0){r=c[p>>2]|0;if((r|0)==0){ba=0;bb=p;break}Z=gj[r&4095](q&65535&32767)|0;ba=Z;bb=c[2110940]|0}else{ba=a[v+(q&65535&32767&65535&255)|0]|0;bb=p}}while(0);p=(ba&255)<<8;b[4859071]=p;v=(((q+1|0)&8191|0)==0?q+24577|0:q+1|0)&32767;Z=c[bb+16+((v&65535)>>>8<<2)>>2]|0;do{if((Z|0)==0){r=c[bb>>2]|0;if((r|0)==0){bc=0;break}bc=gj[r&4095](v)|0}else{bc=a[Z+(v&65535&255)|0]|0}}while(0);v=bc&255|p&32512;b[4859071]=v;a9=v}b[4859069]=a9&24576;b[4859070]=a9&8191;w=55018;break};case 52:case 53:case 54:{c[2440218]=(c[2440218]|0)-9;if(((d[9718144]|0)>>>6|0)!=(j&255|0)){w=55018;break L66165}v=a[9718145]|0;Z=b[9718156+((v&7)<<1)>>1]|0;b[4859071]=Z;b[4859069]=Z&24576;b[4859070]=Z&8191;a[9718145]=v+7&7|v&-40;if((a[9718172]|0)==0){w=55018;break L66165}if((a[9718154]|0)!=0){a[9718154]=0;b[4859070]=Z+1&8191}Z=c[8449976+(c[2444]<<2)>>2]|0;if((Z|0)==0){bd=0}else{bd=(gj[Z&4095](0)|0)&255}Z=c[5093528+(bd<<2)>>2]&8191;b[4859071]=Z;if((bd&128|0)!=0){c[2440218]=(c[2440218]|0)-6;v=c[2110940]|0;q=c[v+16+((Z&65535)>>>8<<2)>>2]|0;do{if((q|0)==0){r=c[v>>2]|0;if((r|0)==0){be=0;bf=v;break}m=gj[r&4095](Z)|0;be=m;bf=c[2110940]|0}else{be=a[q+(Z&65535&255)|0]|0;bf=v}}while(0);v=(be&255)<<8;b[4859071]=v;q=((((Z&65535)+1|0)&8191|0)==0?Z+24577&65535:((Z&65535)+1|0)&65535)&32767;p=c[bf+16+((q&65535)>>>8<<2)>>2]|0;do{if((p|0)==0){m=c[bf>>2]|0;if((m|0)==0){bg=0;break}bg=gj[m&4095](q)|0}else{bg=a[p+(q&65535&255)|0]|0}}while(0);b[4859071]=bg&255|v&32512}q=a[9718145]|0;a[9718145]=q&-40|q+1&255&7|32;b[9718156+((q+1&255&7)<<1)>>1]=(b[4859070]|0)+(b[4859069]|0)&65535;q=b[4859071]|0;b[4859069]=q&24576;b[4859070]=q&8191;w=55018;break};case 152:case 153:case 154:{c[2440218]=(c[2440218]|0)-9;if(((d[9718144]|0)>>>6|0)==(j&255|0)){b[4859070]=o+2&8191;w=55018;break L66165}q=b[4859069]|0;p=c[2110940]|0;Z=c[p+1040+((q+h&32767&65535)>>>8<<2)>>2]|0;do{if((Z|0)==0){m=c[p+16+((q+h&32767&65535)>>>8<<2)>>2]|0;if((m|0)!=0){bh=a[m+(q+h&32767&65535&255)|0]|0;bi=h;bj=q;break}m=c[p>>2]|0;if((m|0)==0){bh=0;bi=h;bj=q;break}r=gj[m&4095](q+h&32767)|0;bh=r;bi=b[4859070]|0;bj=b[4859069]|0}else{bh=a[Z+(q+h&32767&65535&255)|0]|0;bi=h;bj=q}}while(0);q=bi+1&65535;b[4859070]=q&8191;Z=bh&255;p=((q&65535)+(c[5093528+(Z<<2)>>2]|0)&8191)+(bj&65535)|0;b[4859071]=p&65535;if((Z&128|0)==0){bk=p&65535}else{c[2440218]=(c[2440218]|0)-6;Z=c[2110940]|0;q=c[Z+16+((p&65535&32767&65535)>>>8<<2)>>2]|0;do{if((q|0)==0){v=c[Z>>2]|0;if((v|0)==0){bl=0;bm=Z;break}r=gj[v&4095](p&65535&32767)|0;bl=r;bm=c[2110940]|0}else{bl=a[q+(p&65535&32767&65535&255)|0]|0;bm=Z}}while(0);Z=(bl&255)<<8;b[4859071]=Z;q=(((p+1|0)&8191|0)==0?p+24577|0:p+1|0)&32767;r=c[bm+16+((q&65535)>>>8<<2)>>2]|0;do{if((r|0)==0){v=c[bm>>2]|0;if((v|0)==0){bn=0;break}bn=gj[v&4095](q)|0}else{bn=a[r+(q&65535&255)|0]|0}}while(0);q=bn&255|Z&32512;b[4859071]=q;bk=q}b[4859069]=bk&24576;b[4859070]=bk&8191;w=55018;break};case 147:{c[2440218]=(c[2440218]|0)-6;q=a[9718147]|0;if(((q^a[9718144])&16)!=0){r=a[9718148]|0;a[9718148]=a[9718151]|0;a[9718151]=r;r=a[9718149]|0;a[9718149]=a[9718152]|0;a[9718152]=r;r=a[9718150]|0;a[9718150]=a[9718153]|0;a[9718153]=r}a[9718144]=q;w=55018;break};case 148:case 149:case 150:case 151:{c[2440218]=(c[2440218]|0)-9;q=a[9718144]|0;if((q&1)==0){a[9718147+(j&255)|0]=(a[9718147+(j&255)|0]|0)-96&255;bo=a[9718144]|0}else{bo=q}if((bo&32)!=0){w=55018;break L66165}q=9718147+(d[9718146]|0)|0;r=a[q]|0;a[q]=r+10&15|r&-16;w=55018;break};case 112:case 113:case 114:case 115:{c[2440218]=(c[2440218]|0)-6;r=c[(c[2110940]|0)+8>>2]|0;if((r|0)==0){bp=0;bq=j}else{q=gj[r&4095](257)|0;bp=q;bq=a[9718146]|0}a[9718147+(bq&255)|0]=bp;a[9718144]=a[680792+(d[9718147+(d[9718146]|0)|0]|0)|0]|a[9718144]&63;w=55018;break};default:{l=1}}}if(l){l=0;switch(k|0){case 88:case 89:case 90:case 91:{c[2440218]=(c[2440218]|0)-9;if((a[9718147+(j&255)|0]|0)==0){b[4859070]=o+2&8191;w=55018;break L66165}q=b[4859069]|0;r=c[2110940]|0;p=c[r+1040+((q+h&32767&65535)>>>8<<2)>>2]|0;do{if((p|0)==0){v=c[r+16+((q+h&32767&65535)>>>8<<2)>>2]|0;if((v|0)!=0){br=a[v+(q+h&32767&65535&255)|0]|0;bs=h;bt=q;break}v=c[r>>2]|0;if((v|0)==0){br=0;bs=h;bt=q;break}m=gj[v&4095](q+h&32767)|0;br=m;bs=b[4859070]|0;bt=b[4859069]|0}else{br=a[p+(q+h&32767&65535&255)|0]|0;bs=h;bt=q}}while(0);q=bs+1&65535;b[4859070]=q&8191;p=br&255;r=((q&65535)+(c[5093528+(p<<2)>>2]|0)&8191)+(bt&65535)|0;b[4859071]=r&65535;if((p&128|0)==0){bu=r&65535}else{c[2440218]=(c[2440218]|0)-6;p=c[2110940]|0;q=c[p+16+((r&65535&32767&65535)>>>8<<2)>>2]|0;do{if((q|0)==0){Z=c[p>>2]|0;if((Z|0)==0){bv=0;bw=p;break}m=gj[Z&4095](r&65535&32767)|0;bv=m;bw=c[2110940]|0}else{bv=a[q+(r&65535&32767&65535&255)|0]|0;bw=p}}while(0);p=(bv&255)<<8;b[4859071]=p;q=(((r+1|0)&8191|0)==0?r+24577|0:r+1|0)&32767;m=c[bw+16+((q&65535)>>>8<<2)>>2]|0;do{if((m|0)==0){Z=c[bw>>2]|0;if((Z|0)==0){bx=0;break}bx=gj[Z&4095](q)|0}else{bx=a[m+(q&65535&255)|0]|0}}while(0);q=bx&255|p&32512;b[4859071]=q;bu=q}b[4859069]=bu&24576;b[4859070]=bu&8191;w=55018;break};case 84:case 85:case 86:case 87:{c[2440218]=(c[2440218]|0)-9;q=(b[4859069]|0)+h&32767;m=c[2110940]|0;r=c[m+1040+((q&65535)>>>8<<2)>>2]|0;do{if((r|0)==0){Z=c[m+16+((q&65535)>>>8<<2)>>2]|0;if((Z|0)!=0){by=a[Z+(q&65535&255)|0]|0;bz=h;bA=m;break}Z=c[m>>2]|0;if((Z|0)==0){by=0;bz=h;bA=m;break}v=gj[Z&4095](q)|0;by=v;bz=b[4859070]|0;bA=c[2110940]|0}else{by=a[r+(q&65535&255)|0]|0;bz=h;bA=m}}while(0);b[4859070]=bz+1&8191;m=c[bA+8>>2]|0;if((m|0)==0){bB=0}else{bB=gj[m&4095](by&255)|0}a[9718147+(d[9718146]|0)|0]=bB;a[9718144]=a[680792+(d[9718147+(d[9718146]|0)|0]|0)|0]|a[9718144]&63;w=55018;break};case 32:case 33:case 34:case 35:{c[2440218]=(c[2440218]|0)-6;m=a[9718147]^a[9718147+(j&255)|0];a[9718147]=m;a[9718144]=a[9718144]&63|a[680792+(m&255)|0];w=55018;break};case 36:case 37:case 38:case 39:{c[2440218]=(c[2440218]|0)-6;m=(b[4859069]|0)+h&32767;q=c[2110940]|0;r=c[q+1040+((m&65535)>>>8<<2)>>2]|0;do{if((r|0)==0){p=c[q+16+((m&65535)>>>8<<2)>>2]|0;if((p|0)!=0){bC=a[p+(m&65535&255)|0]|0;bD=h;bE=j;break}p=c[q>>2]|0;if((p|0)==0){bC=0;bD=h;bE=j;break}v=gj[p&4095](m)|0;bC=v;bD=b[4859070]|0;bE=a[9718146]|0}else{bC=a[r+(m&65535&255)|0]|0;bD=h;bE=j}}while(0);b[4859070]=bD+1&8191;m=9718147+(bE&255)|0;a[m]=a[m]^bC;a[9718144]=a[680792+(d[9718147+(d[9718146]|0)|0]|0)|0]|a[9718144]&63;w=55018;break};case 48:case 49:case 50:case 51:{c[2440218]=(c[2440218]|0)-6;m=c[(c[2110940]|0)+8>>2]|0;if((m|0)==0){bF=0;bG=j}else{r=gj[m&4095](256)|0;bF=r;bG=a[9718146]|0}a[9718147+(bG&255)|0]=bF;a[9718144]=a[680792+(d[9718147+(d[9718146]|0)|0]|0)|0]|a[9718144]&63;w=55018;break};case 108:case 109:case 110:case 111:{c[2440218]=(c[2440218]|0)-12;r=b[4859069]|0;m=c[2110940]|0;q=c[m+1040+((r+h&32767&65535)>>>8<<2)>>2]|0;do{if((q|0)==0){v=c[m+16+((r+h&32767&65535)>>>8<<2)>>2]|0;if((v|0)!=0){bH=a[v+(r+h&32767&65535&255)|0]|0;bI=h;bJ=r;bK=m;break}v=c[m>>2]|0;if((v|0)==0){bH=0;bI=h;bJ=r;bK=m;break}p=gj[v&4095](r+h&32767)|0;bH=p;bI=b[4859070]|0;bJ=b[4859069]|0;bK=c[2110940]|0}else{bH=a[q+(r+h&32767&65535&255)|0]|0;bI=h;bJ=r;bK=m}}while(0);m=bI+1&8191;b[4859070]=m;r=m+bJ&32767;q=c[bK+1040+((r&65535)>>>8<<2)>>2]|0;do{if((q|0)==0){p=c[bK+16+((r&65535)>>>8<<2)>>2]|0;if((p|0)!=0){bL=a[p+(r&65535&255)|0]|0;bM=m;bN=bJ;break}p=c[bK>>2]|0;if((p|0)==0){bL=0;bM=m;bN=bJ;break}v=gj[p&4095](r)|0;bL=v;bM=b[4859070]|0;bN=b[4859069]|0}else{bL=a[q+(r&65535&255)|0]|0;bM=m;bN=bJ}}while(0);b[4859070]=bM+1&8191;m=bH&255;r=(bN&65535)+(bL&255|m<<8&7936)|0;b[4859071]=r&65535;if((m&128|0)==0){bO=r&65535}else{c[2440218]=(c[2440218]|0)-6;q=c[2110940]|0;v=c[q+16+((r&65535&32767&65535)>>>8<<2)>>2]|0;do{if((v|0)==0){p=c[q>>2]|0;if((p|0)==0){bP=0;bQ=q;break}Z=gj[p&4095](r&65535&32767)|0;bP=Z;bQ=c[2110940]|0}else{bP=a[v+(r&65535&32767&65535&255)|0]|0;bQ=q}}while(0);q=(bP&255)<<8;b[4859071]=q;v=(((r+1|0)&8191|0)==0?r+24577|0:r+1|0)&32767;Z=c[bQ+16+((v&65535)>>>8<<2)>>2]|0;do{if((Z|0)==0){p=c[bQ>>2]|0;if((p|0)==0){bR=0;break}bR=gj[p&4095](v)|0}else{bR=a[Z+(v&65535&255)|0]|0}}while(0);v=bR&255|q&32512;b[4859071]=v;bO=v}if((m&96|0)==32){v=9718147+(d[9718146]|0)|0;a[v]=(a[v]|0)+1&255;v=b[4859071]|0;Z=(d[9718147+(d[9718146]|0)|0]|0)+v&8191|v&24576;b[4859071]=Z;a[9718146]=0;bS=Z}else if((m&96|0)==64){Z=9718147+(d[9718146]|0)|0;a[Z]=(a[Z]|0)-1&255;Z=b[4859071]|0;v=(d[9718147+(d[9718146]|0)|0]|0)+Z&8191|Z&24576;b[4859071]=v;a[9718146]=0;bS=v}else if((m&96|0)==96){v=(d[9718147+(d[9718146]|0)|0]|0)+bO&8191|bO&24576;b[4859071]=v;a[9718146]=0;bS=v}else{bS=bO}v=bS&32767;Z=c[2110940]|0;r=c[Z+16+((v&65535)>>>8<<2)>>2]|0;do{if((r|0)==0){p=c[Z>>2]|0;if((p|0)==0){bT=0;break}bT=gj[p&4095](v)|0}else{bT=a[r+(v&65535&255)|0]|0}}while(0);v=9718147+(d[9718146]|0)|0;a[v]=a[v]|bT;a[9718144]=a[680792+(d[9718147+(d[9718146]|0)|0]|0)|0]|a[9718144]&63;w=55018;break};case 155:{c[2440218]=(c[2440218]|0)-9;v=(b[4859069]|0)+h&32767;r=c[2110940]|0;Z=c[r+1040+((v&65535)>>>8<<2)>>2]|0;do{if((Z|0)==0){m=c[r+16+((v&65535)>>>8<<2)>>2]|0;if((m|0)!=0){bU=a[m+(v&65535&255)|0]|0;bV=h;break}m=c[r>>2]|0;if((m|0)==0){bU=0;bV=h;break}q=gj[m&4095](v)|0;bU=q;bV=b[4859070]|0}else{bU=a[Z+(v&65535&255)|0]|0;bV=h}}while(0);b[4859070]=bV+1&8191;v=bU&255;Z=c[5093528+(v<<2)>>2]&8191;b[4859071]=Z;if((v&128|0)==0){bW=Z}else{c[2440218]=(c[2440218]|0)-6;v=c[2110940]|0;r=c[v+16+((Z&65535)>>>8<<2)>>2]|0;do{if((r|0)==0){q=c[v>>2]|0;if((q|0)==0){bX=0;bY=v;break}m=gj[q&4095](Z)|0;bX=m;bY=c[2110940]|0}else{bX=a[r+(Z&65535&255)|0]|0;bY=v}}while(0);v=(bX&255)<<8;b[4859071]=v;r=((((Z&65535)+1|0)&8191|0)==0?Z+24577&65535:((Z&65535)+1|0)&65535)&32767;m=c[bY+16+((r&65535)>>>8<<2)>>2]|0;do{if((m|0)==0){q=c[bY>>2]|0;if((q|0)==0){bZ=0;break}bZ=gj[q&4095](r)|0}else{bZ=a[m+(r&65535&255)|0]|0}}while(0);r=bZ&255|v&32512;b[4859071]=r;bW=r}b[4859069]=bW&24576;b[4859070]=bW&8191;w=55018;break};case 159:{c[2440218]=(c[2440218]|0)-9;r=b[4859069]|0;m=c[2110940]|0;Z=c[m+1040+((r+h&32767&65535)>>>8<<2)>>2]|0;do{if((Z|0)==0){q=c[m+16+((r+h&32767&65535)>>>8<<2)>>2]|0;if((q|0)!=0){b_=a[q+(r+h&32767&65535&255)|0]|0;b$=h;b0=r;b1=m;break}q=c[m>>2]|0;if((q|0)==0){b_=0;b$=h;b0=r;b1=m;break}p=gj[q&4095](r+h&32767)|0;b_=p;b$=b[4859070]|0;b0=b[4859069]|0;b1=c[2110940]|0}else{b_=a[Z+(r+h&32767&65535&255)|0]|0;b$=h;b0=r;b1=m}}while(0);m=b$+1&8191;b[4859070]=m;r=m+b0&32767;Z=c[b1+1040+((r&65535)>>>8<<2)>>2]|0;do{if((Z|0)==0){v=c[b1+16+((r&65535)>>>8<<2)>>2]|0;if((v|0)!=0){b2=a[v+(r&65535&255)|0]|0;b3=m;break}v=c[b1>>2]|0;if((v|0)==0){b2=0;b3=m;break}p=gj[v&4095](r)|0;b2=p;b3=b[4859070]|0}else{b2=a[Z+(r&65535&255)|0]|0;b3=m}}while(0);b[4859070]=b3+1&8191;m=b_&255;r=b2&255;b[4859071]=(r|m<<8&32512)&65535;if((m&128|0)==0){b4=(r|m<<8&32512)&65535}else{c[2440218]=(c[2440218]|0)-6;Z=c[2110940]|0;p=c[Z+16+((m<<8&32512)>>>8<<2)>>2]|0;do{if((p|0)==0){v=c[Z>>2]|0;if((v|0)==0){b5=0;b6=Z;break}q=gj[v&4095]((r|m<<8&32512)&65535)|0;b5=q;b6=c[2110940]|0}else{b5=a[p+r|0]|0;b6=Z}}while(0);Z=(b5&255)<<8;b[4859071]=Z;p=((((r|m<<8&32512)+1|0)&8191|0)==0?(r|m<<8&32512)+24577|0:(r|m<<8&32512)+1|0)&32767;q=c[b6+16+((p&65535)>>>8<<2)>>2]|0;do{if((q|0)==0){v=c[b6>>2]|0;if((v|0)==0){b7=0;break}b7=gj[v&4095](p)|0}else{b7=a[q+(p&65535&255)|0]|0}}while(0);p=b7&255|Z&32512;b[4859071]=p;b4=p}p=(d[9718150]|0)+b4&65535;b[4859071]=p&32767;b[4859069]=p&24576;b[4859070]=p&8191;w=55018;break};case 96:case 97:case 98:case 99:{c[2440218]=(c[2440218]|0)-6;p=a[9718147]|a[9718147+(j&255)|0];a[9718147]=p;a[9718144]=a[9718144]&63|a[680792+(p&255)|0];w=55018;break};case 100:case 101:case 102:case 103:{c[2440218]=(c[2440218]|0)-6;p=(b[4859069]|0)+h&32767;q=c[2110940]|0;m=c[q+1040+((p&65535)>>>8<<2)>>2]|0;do{if((m|0)==0){r=c[q+16+((p&65535)>>>8<<2)>>2]|0;if((r|0)!=0){b8=a[r+(p&65535&255)|0]|0;b9=h;ca=j;break}r=c[q>>2]|0;if((r|0)==0){b8=0;b9=h;ca=j;break}v=gj[r&4095](p)|0;b8=v;b9=b[4859070]|0;ca=a[9718146]|0}else{b8=a[m+(p&65535&255)|0]|0;b9=h;ca=j}}while(0);b[4859070]=b9+1&8191;p=9718147+(ca&255)|0;a[p]=a[p]|b8;a[9718144]=a[680792+(d[9718147+(d[9718146]|0)|0]|0)|0]|a[9718144]&63;w=55018;break};case 92:case 93:case 94:case 95:{c[2440218]=(c[2440218]|0)-9;if((a[9718147+(j&255)|0]|0)==0){b[4859070]=o+3&8191;w=55018;break L66165}p=b[4859069]|0;m=c[2110940]|0;q=c[m+1040+((p+h&32767&65535)>>>8<<2)>>2]|0;do{if((q|0)==0){Z=c[m+16+((p+h&32767&65535)>>>8<<2)>>2]|0;if((Z|0)!=0){cb=a[Z+(p+h&32767&65535&255)|0]|0;cc=h;cd=p;ce=m;break}Z=c[m>>2]|0;if((Z|0)==0){cb=0;cc=h;cd=p;ce=m;break}v=gj[Z&4095](p+h&32767)|0;cb=v;cc=b[4859070]|0;cd=b[4859069]|0;ce=c[2110940]|0}else{cb=a[q+(p+h&32767&65535&255)|0]|0;cc=h;cd=p;ce=m}}while(0);m=cc+1&8191;b[4859070]=m;p=m+cd&32767;q=c[ce+1040+((p&65535)>>>8<<2)>>2]|0;do{if((q|0)==0){v=c[ce+16+((p&65535)>>>8<<2)>>2]|0;if((v|0)!=0){cf=a[v+(p&65535&255)|0]|0;cg=m;break}v=c[ce>>2]|0;if((v|0)==0){cf=0;cg=m;break}Z=gj[v&4095](p)|0;cf=Z;cg=b[4859070]|0}else{cf=a[q+(p&65535&255)|0]|0;cg=m}}while(0);b[4859070]=cg+1&8191;m=cb&255;p=cf&255;b[4859071]=(p|m<<8&32512)&65535;if((m&128|0)==0){ch=(p|m<<8&32512)&65535}else{c[2440218]=(c[2440218]|0)-6;q=c[2110940]|0;Z=c[q+16+((m<<8&32512)>>>8<<2)>>2]|0;do{if((Z|0)==0){v=c[q>>2]|0;if((v|0)==0){ci=0;cj=q;break}r=gj[v&4095]((p|m<<8&32512)&65535)|0;ci=r;cj=c[2110940]|0}else{ci=a[Z+p|0]|0;cj=q}}while(0);q=(ci&255)<<8;b[4859071]=q;Z=((((p|m<<8&32512)+1|0)&8191|0)==0?(p|m<<8&32512)+24577|0:(p|m<<8&32512)+1|0)&32767;r=c[cj+16+((Z&65535)>>>8<<2)>>2]|0;do{if((r|0)==0){v=c[cj>>2]|0;if((v|0)==0){ck=0;break}ck=gj[v&4095](Z)|0}else{ck=a[r+(Z&65535&255)|0]|0}}while(0);Z=ck&255|q&32512;b[4859071]=Z;ch=Z}b[4859069]=ch&24576;b[4859070]=ch&8191;w=55018;break};case 124:case 125:case 126:case 127:{c[2440218]=(c[2440218]|0)-9;if((a[9718147+(j&255)|0]|0)==0){b[4859070]=o+3&8191;w=55018;break L66165}Z=b[4859069]|0;r=c[2110940]|0;m=c[r+1040+((Z+h&32767&65535)>>>8<<2)>>2]|0;do{if((m|0)==0){p=c[r+16+((Z+h&32767&65535)>>>8<<2)>>2]|0;if((p|0)!=0){cl=a[p+(Z+h&32767&65535&255)|0]|0;cm=h;cn=Z;co=r;break}p=c[r>>2]|0;if((p|0)==0){cl=0;cm=h;cn=Z;co=r;break}v=gj[p&4095](Z+h&32767)|0;cl=v;cm=b[4859070]|0;cn=b[4859069]|0;co=c[2110940]|0}else{cl=a[m+(Z+h&32767&65535&255)|0]|0;cm=h;cn=Z;co=r}}while(0);r=cm+1&8191;b[4859070]=r;Z=r+cn&32767;m=c[co+1040+((Z&65535)>>>8<<2)>>2]|0;do{if((m|0)==0){q=c[co+16+((Z&65535)>>>8<<2)>>2]|0;if((q|0)!=0){cp=a[q+(Z&65535&255)|0]|0;cq=r;break}q=c[co>>2]|0;if((q|0)==0){cp=0;cq=r;break}v=gj[q&4095](Z)|0;cp=v;cq=b[4859070]|0}else{cp=a[m+(Z&65535&255)|0]|0;cq=r}}while(0);r=cq+1&8191;b[4859070]=r;Z=cl&255;m=cp&255;b[4859071]=(m|Z<<8&32512)&65535;if((Z&128|0)==0){cr=r}else{c[2440218]=(c[2440218]|0)-6;r=c[2110940]|0;v=c[r+16+((Z<<8&32512)>>>8<<2)>>2]|0;do{if((v|0)==0){q=c[r>>2]|0;if((q|0)==0){cs=0;ct=r;break}p=gj[q&4095]((m|Z<<8&32512)&65535)|0;cs=p;ct=c[2110940]|0}else{cs=a[v+m|0]|0;ct=r}}while(0);r=(cs&255)<<8;b[4859071]=r;v=((((m|Z<<8&32512)+1|0)&8191|0)==0?(m|Z<<8&32512)+24577|0:(m|Z<<8&32512)+1|0)&32767;p=c[ct+16+((v&65535)>>>8<<2)>>2]|0;do{if((p|0)==0){q=c[ct>>2]|0;if((q|0)==0){cu=0;break}cu=gj[q&4095](v)|0}else{cu=a[p+(v&65535&255)|0]|0}}while(0);b[4859071]=cu&255|r&32512;cr=b[4859070]|0}v=a[9718145]|0;a[9718145]=v+1&255&7|v&-8;b[9718156+((v+1&255&7)<<1)>>1]=(b[4859069]|0)+cr&65535;v=b[4859071]|0;b[4859069]=v&24576;b[4859070]=v&8191;w=55018;break};case 160:case 161:case 162:case 163:{c[2440218]=(c[2440218]|0)-6;v=a[9718147+(j&255)|0]|0;p=a[9718147]|0;Z=a[9718144]|0;m=(p&255)-(v&255)-((Z&255&1^1)&(Z&255)>>>3)|0;a[9718144]=(m>>>8&1^1)&255|Z&-38;a[9718147]=m&255;if((m&15)>>>0>(p&255&15)>>>0){cv=(m>>>8&1^1)&255|Z&-38}else{q=(m>>>8&1^1)&255|Z&-38|32;a[9718144]=q;cv=q}a[9718144]=a[680792+(((m&255^p)&255&((p^v)&255^128))<<1&256|m&255)|0]|cv&59;w=55018;break};case 156:case 157:case 158:{c[2440218]=(c[2440218]|0)-9;if(((d[9718144]|0)>>>6|0)==(j&255|0)){b[4859070]=o+3&8191;w=55018;break L66165}m=b[4859069]|0;v=c[2110940]|0;p=c[v+1040+((m+h&32767&65535)>>>8<<2)>>2]|0;do{if((p|0)==0){q=c[v+16+((m+h&32767&65535)>>>8<<2)>>2]|0;if((q|0)!=0){cw=a[q+(m+h&32767&65535&255)|0]|0;cx=h;cy=m;cz=v;break}q=c[v>>2]|0;if((q|0)==0){cw=0;cx=h;cy=m;cz=v;break}Z=gj[q&4095](m+h&32767)|0;cw=Z;cx=b[4859070]|0;cy=b[4859069]|0;cz=c[2110940]|0}else{cw=a[p+(m+h&32767&65535&255)|0]|0;cx=h;cy=m;cz=v}}while(0);v=cx+1&8191;b[4859070]=v;m=v+cy&32767;p=c[cz+1040+((m&65535)>>>8<<2)>>2]|0;do{if((p|0)==0){r=c[cz+16+((m&65535)>>>8<<2)>>2]|0;if((r|0)!=0){cA=a[r+(m&65535&255)|0]|0;cB=v;break}r=c[cz>>2]|0;if((r|0)==0){cA=0;cB=v;break}Z=gj[r&4095](m)|0;cA=Z;cB=b[4859070]|0}else{cA=a[p+(m&65535&255)|0]|0;cB=v}}while(0);b[4859070]=cB+1&8191;v=cw&255;m=cA&255;b[4859071]=(m|v<<8&32512)&65535;if((v&128|0)==0){cC=(m|v<<8&32512)&65535}else{c[2440218]=(c[2440218]|0)-6;p=c[2110940]|0;Z=c[p+16+((v<<8&32512)>>>8<<2)>>2]|0;do{if((Z|0)==0){r=c[p>>2]|0;if((r|0)==0){cD=0;cE=p;break}q=gj[r&4095]((m|v<<8&32512)&65535)|0;cD=q;cE=c[2110940]|0}else{cD=a[Z+m|0]|0;cE=p}}while(0);p=(cD&255)<<8;b[4859071]=p;Z=((((m|v<<8&32512)+1|0)&8191|0)==0?(m|v<<8&32512)+24577|0:(m|v<<8&32512)+1|0)&32767;q=c[cE+16+((Z&65535)>>>8<<2)>>2]|0;do{if((q|0)==0){r=c[cE>>2]|0;if((r|0)==0){cF=0;break}cF=gj[r&4095](Z)|0}else{cF=a[q+(Z&65535&255)|0]|0}}while(0);Z=cF&255|p&32512;b[4859071]=Z;cC=Z}b[4859069]=cC&24576;b[4859070]=cC&8191;w=55018;break};case 164:case 165:case 166:case 167:{c[2440218]=(c[2440218]|0)-6;Z=(b[4859069]|0)+h&32767;q=c[2110940]|0;v=c[q+1040+((Z&65535)>>>8<<2)>>2]|0;do{if((v|0)==0){m=c[q+16+((Z&65535)>>>8<<2)>>2]|0;if((m|0)!=0){cG=a[m+(Z&65535&255)|0]|0;cH=h;cI=j;break}m=c[q>>2]|0;if((m|0)==0){cG=0;cH=h;cI=j;break}r=gj[m&4095](Z)|0;cG=r;cH=b[4859070]|0;cI=a[9718146]|0}else{cG=a[v+(Z&65535&255)|0]|0;cH=h;cI=j}}while(0);b[4859070]=cH+1&8191;Z=9718147+(cI&255)|0;v=a[Z]|0;q=a[9718144]|0;p=(v&255)-(cG&255)-((q&255&1^1)&(q&255)>>>3)|0;a[9718144]=(p>>>8&1^1)&255|q&-38;a[Z]=p&255;p=9718147+(d[9718146]|0)|0;Z=a[p]|0;q=a[9718144]|0;if((Z&15)>>>0>(v&255&15)>>>0){cJ=Z;cK=q}else{a[9718144]=q|32;cJ=a[p]|0;cK=q|32}a[9718144]=a[680792+(((cJ^v)&255&((v^cG)&255^128))<<1&256|cJ&255)|0]|cK&59;w=55018;break};case 168:case 169:case 170:case 171:{c[2440218]=(c[2440218]|0)-9;v=b[4859069]|0;q=c[2110940]|0;p=c[q+1040+((v+h&32767&65535)>>>8<<2)>>2]|0;do{if((p|0)==0){Z=c[q+16+((v+h&32767&65535)>>>8<<2)>>2]|0;if((Z|0)!=0){cL=a[Z+(v+h&32767&65535&255)|0]|0;cM=h;cN=v;break}Z=c[q>>2]|0;if((Z|0)==0){cL=0;cM=h;cN=v;break}r=gj[Z&4095](v+h&32767)|0;cL=r;cM=b[4859070]|0;cN=b[4859069]|0}else{cL=a[p+(v+h&32767&65535&255)|0]|0;cM=h;cN=v}}while(0);v=cM+1&65535;b[4859070]=v&8191;p=cL&255;q=((v&65535)+(c[5093528+(p<<2)>>2]|0)&8191)+(cN&65535)|0;b[4859071]=q&65535;if((p&128|0)==0){cO=q&65535}else{c[2440218]=(c[2440218]|0)-6;p=c[2110940]|0;v=c[p+16+((q&65535&32767&65535)>>>8<<2)>>2]|0;do{if((v|0)==0){r=c[p>>2]|0;if((r|0)==0){cP=0;cQ=p;break}Z=gj[r&4095](q&65535&32767)|0;cP=Z;cQ=c[2110940]|0}else{cP=a[v+(q&65535&32767&65535&255)|0]|0;cQ=p}}while(0);p=(cP&255)<<8;b[4859071]=p;v=(((q+1|0)&8191|0)==0?q+24577|0:q+1|0)&32767;Z=c[cQ+16+((v&65535)>>>8<<2)>>2]|0;do{if((Z|0)==0){r=c[cQ>>2]|0;if((r|0)==0){cR=0;break}cR=gj[r&4095](v)|0}else{cR=a[Z+(v&65535&255)|0]|0}}while(0);v=cR&255|p&32512;b[4859071]=v;cO=v}v=cO&32767;Z=c[2110940]|0;q=c[Z+16+((v&65535)>>>8<<2)>>2]|0;do{if((q|0)==0){r=c[Z>>2]|0;if((r|0)==0){cS=0;break}cS=gj[r&4095](v)|0}else{cS=a[q+(v&65535&255)|0]|0}}while(0);v=9718147+(d[9718146]|0)|0;q=a[v]|0;Z=a[9718144]|0;p=(q&255)-(cS&255)-((Z&255&1^1)&(Z&255)>>>3)|0;a[9718144]=(p>>>8&1^1)&255|Z&-38;a[v]=p&255;p=9718147+(d[9718146]|0)|0;v=a[p]|0;Z=a[9718144]|0;if((v&15)>>>0>(q&255&15)>>>0){cT=v;cU=Z}else{a[9718144]=Z|32;cT=a[p]|0;cU=Z|32}a[9718144]=a[680792+(((cT^q)&255&((q^cS)&255^128))<<1&256|cT&255)|0]|cU&59;w=55018;break};case 28:case 29:case 30:{c[2440218]=(c[2440218]|0)-9;if(((d[9718144]|0)>>>6|0)!=(j&255|0)){b[4859070]=o+3&8191;w=55018;break L66165}q=b[4859069]|0;Z=c[2110940]|0;p=c[Z+1040+((q+h&32767&65535)>>>8<<2)>>2]|0;do{if((p|0)==0){v=c[Z+16+((q+h&32767&65535)>>>8<<2)>>2]|0;if((v|0)!=0){cV=a[v+(q+h&32767&65535&255)|0]|0;cW=h;cX=q;cY=Z;break}v=c[Z>>2]|0;if((v|0)==0){cV=0;cW=h;cX=q;cY=Z;break}r=gj[v&4095](q+h&32767)|0;cV=r;cW=b[4859070]|0;cX=b[4859069]|0;cY=c[2110940]|0}else{cV=a[p+(q+h&32767&65535&255)|0]|0;cW=h;cX=q;cY=Z}}while(0);Z=cW+1&8191;b[4859070]=Z;q=Z+cX&32767;p=c[cY+1040+((q&65535)>>>8<<2)>>2]|0;do{if((p|0)==0){r=c[cY+16+((q&65535)>>>8<<2)>>2]|0;if((r|0)!=0){cZ=a[r+(q&65535&255)|0]|0;c_=Z;break}r=c[cY>>2]|0;if((r|0)==0){cZ=0;c_=Z;break}v=gj[r&4095](q)|0;cZ=v;c_=b[4859070]|0}else{cZ=a[p+(q&65535&255)|0]|0;c_=Z}}while(0);b[4859070]=c_+1&8191;Z=cV&255;q=cZ&255;b[4859071]=(q|Z<<8&32512)&65535;if((Z&128|0)==0){c$=(q|Z<<8&32512)&65535}else{c[2440218]=(c[2440218]|0)-6;p=c[2110940]|0;v=c[p+16+((Z<<8&32512)>>>8<<2)>>2]|0;do{if((v|0)==0){r=c[p>>2]|0;if((r|0)==0){c0=0;c1=p;break}m=gj[r&4095]((q|Z<<8&32512)&65535)|0;c0=m;c1=c[2110940]|0}else{c0=a[v+q|0]|0;c1=p}}while(0);p=(c0&255)<<8;b[4859071]=p;v=((((q|Z<<8&32512)+1|0)&8191|0)==0?(q|Z<<8&32512)+24577|0:(q|Z<<8&32512)+1|0)&32767;m=c[c1+16+((v&65535)>>>8<<2)>>2]|0;do{if((m|0)==0){r=c[c1>>2]|0;if((r|0)==0){c2=0;break}c2=gj[r&4095](v)|0}else{c2=a[m+(v&65535&255)|0]|0}}while(0);v=c2&255|p&32512;b[4859071]=v;c$=v}b[4859069]=c$&24576;b[4859070]=c$&8191;w=55018;break};case 0:case 1:case 2:case 3:{c[2440218]=(c[2440218]|0)-6;v=a[9718147+(j&255)|0]|0;a[9718147]=v;a[9718144]=a[9718144]&63|a[680792+(v&255)|0];w=55018;break};case 128:case 129:case 130:case 131:{c[2440218]=(c[2440218]|0)-6;v=a[9718147+(j&255)|0]|0;m=a[9718147]|0;Z=a[9718144]|0;q=(m&255)+(v&255)+(Z&255&1&(Z&255)>>>3)|0;a[9718144]=q>>>8&1|Z&-38;a[9718147]=q&255;if((q&15)>>>0<(m&255&15)>>>0){a[9718144]=q>>>8&1|Z&-38|32;c3=q>>>8&1|Z&-38|32}else{c3=q>>>8&1|Z&-38}a[9718144]=a[680792+(((q&255^m)&255&((m^v)&255^128))<<1&256|q&255)|0]|c3&59;w=55018;break};case 132:case 133:case 134:case 135:{c[2440218]=(c[2440218]|0)-6;q=(b[4859069]|0)+h&32767;v=c[2110940]|0;m=c[v+1040+((q&65535)>>>8<<2)>>2]|0;do{if((m|0)==0){Z=c[v+16+((q&65535)>>>8<<2)>>2]|0;if((Z|0)!=0){c4=a[Z+(q&65535&255)|0]|0;c5=h;c6=j;break}Z=c[v>>2]|0;if((Z|0)==0){c4=0;c5=h;c6=j;break}r=gj[Z&4095](q)|0;c4=r;c5=b[4859070]|0;c6=a[9718146]|0}else{c4=a[m+(q&65535&255)|0]|0;c5=h;c6=j}}while(0);b[4859070]=c5+1&8191;q=9718147+(c6&255)|0;m=a[q]|0;v=a[9718144]|0;p=(m&255)+(c4&255)+(v&255&1&(v&255)>>>3)|0;a[9718144]=p>>>8&1|v&-38;a[q]=p&255;p=9718147+(d[9718146]|0)|0;q=a[p]|0;v=a[9718144]|0;if((q&15)>>>0<(m&255&15)>>>0){a[9718144]=v|32;c7=a[p]|0;c8=v|32}else{c7=q;c8=v}a[9718144]=a[680792+(((c7^m)&255&((m^c4)&255^128))<<1&256|c7&255)|0]|c8&59;w=55018;break};default:{l=1}}}c[f+72>>2]=o;c[f+88>>2]=h;c[f+96>>2]=j;c[f+13928>>2]=c9;c[f+13952>>2]=w;c[f+13960>>2]=l;c[f+13968>>2]=k;c[f+13976>>2]=0;c[f+13980>>2]=0;__Z8s2650Runi$0(f);c9=c[f+13928>>2]|0;w=c[f+13952>>2]|0;l=c[f+13960>>2]|0;I=c[f+13976>>2]|0;B=c[f+13980>>2]|0;J=+g[f+13980>>2];c[f+13976>>2]=0;c[f+13980>>2]=0;if((I|0)==1){break}if((I|0)==2){switch(B|0){case 33:{break L66165};case 23:{break L66155}}}}while(0);if((w|0)==55018){w=0;c9=c[2440218]|0}if((c9|0)<=0){da=c9;w=55021;break}}if((w|0)==55021){db=e-da|0;i=f;return db|0}w=(c[2440218]|0)-6|0;c[2440218]=w;b[4859070]=o&8191;a[9718154]=1;if((w|0)<=0){da=w;db=e-da|0;i=f;return db|0}c[2440218]=0;da=0;db=e-da|0;i=f;return db|0}function geI(a){a=a|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=a>>>2&127;L67765:do{switch(d|0){case 70:{f=c[(c[2424904]|0)+552>>2]|0;break};case 56:{f=c[(c[2424904]|0)+504>>2]|-2147483648;break};case 4:{g=c[2424904]|0;h=(c[g+300>>2]|0)>>>8&3;i=(c[g+2396>>2]|0)+(c[g+2392>>2]|0)-(c[g+2400>>2]|0)|0;if((h|0)==3){j=b[g+2330>>1]|0;k=g+2340|0}else{l=g+2340|0;m=g+2330|0;n=(e[m>>1]|0)+((i-(c[l>>2]|0)|0)>>>((c[669696+(h<<2)>>2]|0)>>>0))&65535;b[m>>1]=n;j=n;k=l}c[k>>2]=i;f=j&65535|c[g+296>>2]&-65536;break};case 5:{g=c[2424904]|0;i=c[g+300>>2]|0;if((i&16|0)==0){f=(e[g+2332>>1]|0)<<16|i&65535;break L67765}else{f=(e[g+2334>>1]|0)<<16|i&65535;break L67765}break};case 65:case 71:{f=c[(c[2424904]|0)+556>>2]|0;break};case 120:{f=0;break};case 6:{f=(e[(c[2424904]|0)+2336>>1]|0)<<16;break};default:{f=c[(c[2424904]|0)+280+(d<<2)>>2]|0}}}while(0);return f>>>((a<<3&24^24)>>>0)&255|0}function geJ(a){a=a|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=a>>>2&127;L67782:do{switch(d|0){case 70:{f=c[(c[2424904]|0)+552>>2]|0;break};case 4:{g=c[2424904]|0;h=(c[g+300>>2]|0)>>>8&3;i=(c[g+2396>>2]|0)+(c[g+2392>>2]|0)-(c[g+2400>>2]|0)|0;if((h|0)==3){j=b[g+2330>>1]|0;k=g+2340|0}else{l=g+2340|0;m=g+2330|0;n=(e[m>>1]|0)+((i-(c[l>>2]|0)|0)>>>((c[669696+(h<<2)>>2]|0)>>>0))&65535;b[m>>1]=n;j=n;k=l}c[k>>2]=i;f=j&65535|c[g+296>>2]&-65536;break};case 6:{f=(e[(c[2424904]|0)+2336>>1]|0)<<16;break};case 120:{f=0;break};case 56:{f=c[(c[2424904]|0)+504>>2]|-2147483648;break};case 5:{g=c[2424904]|0;i=c[g+300>>2]|0;if((i&16|0)==0){f=(e[g+2332>>1]|0)<<16|i&65535;break L67782}else{f=(e[g+2334>>1]|0)<<16|i&65535;break L67782}break};case 65:case 71:{f=c[(c[2424904]|0)+556>>2]|0;break};default:{f=c[(c[2424904]|0)+280+(d<<2)>>2]|0}}}while(0);return f>>>((a<<3&16^16)>>>0)&65535|0}function geK(a){a=a|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=a>>>2&127;switch(d|0){case 120:{f=0;return f|0};case 65:case 71:{f=c[(c[2424904]|0)+556>>2]|0;return f|0};case 5:{a=c[2424904]|0;g=c[a+300>>2]|0;if((g&16|0)==0){f=(e[a+2332>>1]|0)<<16|g&65535;return f|0}else{f=(e[a+2334>>1]|0)<<16|g&65535;return f|0}break};case 70:{f=c[(c[2424904]|0)+552>>2]|0;return f|0};case 56:{f=c[(c[2424904]|0)+504>>2]|-2147483648;return f|0};case 4:{g=c[2424904]|0;a=(c[g+300>>2]|0)>>>8&3;h=(c[g+2396>>2]|0)+(c[g+2392>>2]|0)-(c[g+2400>>2]|0)|0;if((a|0)==3){i=b[g+2330>>1]|0;j=g+2340|0}else{k=g+2340|0;l=g+2330|0;m=(e[l>>1]|0)+((h-(c[k>>2]|0)|0)>>>((c[669696+(a<<2)>>2]|0)>>>0))&65535;b[l>>1]=m;i=m;j=k}c[j>>2]=h;f=i&65535|c[g+296>>2]&-65536;return f|0};case 6:{f=(e[(c[2424904]|0)+2336>>1]|0)<<16;return f|0};default:{f=c[(c[2424904]|0)+280+(d<<2)>>2]|0;return f|0}}return 0}function geL(a,b){a=a|0;b=b|0;var c=0;c=a<<3&24^24;geM(a>>>2&127,(b&255)<<c,~(255<<c));return}function geM(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=c[2424904]|0;h=g+280+(a<<2)|0;i=c[h>>2]|0;j=~f&d;c[h>>2]=i&f|j;switch(a|0){case 5:{a=c[g+300>>2]|0;h=a>>>8&3;d=(c[g+2396>>2]|0)+(c[g+2392>>2]|0)-(c[g+2400>>2]|0)|0;if((h|0)==3){k=g+2340|0}else{l=g+2340|0;m=g+2330|0;b[m>>1]=(e[m>>1]|0)+((d-(c[l>>2]|0)|0)>>>((c[669696+(h<<2)>>2]|0)>>>0))&65535;k=l}c[k>>2]=d;if((a&16|0)==0){a=g+2332|0;b[a>>1]=((e[a>>1]|0)&f>>>16|j>>>16)&65535}else{a=g+2334|0;b[a>>1]=((e[a>>1]|0)&f>>>16|j>>>16)&65535}ge6();return};case 106:case 104:{ge5();return};case 108:{a=g+712|0;c[a>>2]=c[a>>2]&(i|-7);ge9(0);ge9(1);return};case 67:{ge5();return};case 24:case 25:case 26:{ge5();return};case 4:{a=(f&16777215|0)!=16777215;if(a){d=(c[g+300>>2]|0)>>>8&3;k=(c[g+2396>>2]|0)+(c[g+2392>>2]|0)-(c[g+2400>>2]|0)|0;if((d|0)==3){n=g+2340|0}else{l=g+2340|0;h=g+2330|0;b[h>>1]=(e[h>>1]|0)+((k-(c[l>>2]|0)|0)>>>((c[669696+(d<<2)>>2]|0)>>>0))&65535;n=l}c[n>>2]=k}k=g+296|0;c[k>>2]=c[k>>2]&(i|-9306113);k=g+2330|0;b[k>>1]=((e[k>>1]|0)&f|j)&65535;if(a){ge6()}ge5();return};case 98:{a=g+672|0;c[a>>2]=c[a>>2]&16777215;return};case 102:{a=g+688|0;c[a>>2]=c[a>>2]&16777215;return};case 66:{a=g+544|0;c[a>>2]=c[a>>2]&-4097;ge5();return};case 99:{a=g+676|0;c[a>>2]=c[a>>2]&(i|-3);ge9(0);return};case 103:{a=g+692|0;c[a>>2]=c[a>>2]&(i|-3);ge9(1);return};case 65:{i=c[g+540>>2]|0;a=c[g+536>>2]|0;if((a|0)==0){j=g+544|0;c[j>>2]=c[j>>2]|65536;c[g+556>>2]=2147483647;c[g+552>>2]=2147483647;ge5();return}else{c[g+556>>2]=(i|0)/(a|0)|0;c[g+552>>2]=(i|0)%(a|0)|0;return}break};case 69:{a=g+556|0;i=g+552|0;j=c[a>>2]|0;f=c[i>>2]|0;k=c[g+536>>2]|0;n=k;l=(k|0)<0|0?-1:0;if((k|0)==0){k=g+544|0;c[k>>2]=c[k>>2]|65536;c[a>>2]=2147483647;c[i>>2]=2147483647;ge5();return}k=gGS(j,f,n,l)|0;d=k;if((k|0)==(d|0)&(K|0)==(((d|0)<0|0?-1:0)|0)){c[a>>2]=d;d=gGT(j,f,n,l)|0;c[i>>2]=d;return}else{d=g+544|0;c[d>>2]=c[d>>2]|65536;c[a>>2]=2147483647;c[i>>2]=2147483647;ge5();return}break};default:{return}}}function geN(a,b){a=a|0;b=b|0;var c=0;c=a<<3&16^16;geM(a>>>2&127,(b&65535)<<c,~(65535<<c));return}function geO(a,b){a=a|0;b=b|0;geM(a>>>2&127,b,0);return}function geP(a){a=a|0;return-91|0}function geQ(a){a=a|0;return-23131|0}function geR(a){a=a|0;return-1515870811|0}function geS(a,b){a=a|0;b=b|0;return}function geT(a,b){a=a|0;b=b|0;return}function geU(a,b){a=a|0;b=b|0;return}function geV(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0;a=gGq(789044)|0;b=a;c[2411230]=b;if((a|0)==0){c[2406668]=0;return}gGz(a|0,0,789044);c[2406668]=b;b=a+231788|0;d=0;e=-536870912;while(1){c[b>>2]=7;c[b+262144>>2]=7;c[b+524288>>2]=7;f=gGK(e,d,65536,0)|0;g=K;h=0;if(g>>>0>h>>>0|g>>>0==h>>>0&f>>>0>-1>>>0){break}else{b=b+4|0;d=g;e=f}}e=a+67948|0;d=0;b=1073741824;while(1){c[e>>2]=6;c[e+262144>>2]=6;c[e+524288>>2]=6;f=gGK(b,d,65536,0)|0;g=K;h=0;if(g>>>0>h>>>0|g>>>0==h>>>0&f>>>0>-1073741825>>>0){break}else{e=e+4|0;d=g;b=f}}c[a+788872>>2]=2722;c[a+788936>>2]=1500;c[a+789e3>>2]=1384;c[a+788904>>2]=2466;c[a+788968>>2]=2224;c[a+789032>>2]=2520;c[a+788868>>2]=1076;c[a+788932>>2]=2548;c[a+788996>>2]=818;c[a+788900>>2]=1208;c[a+788964>>2]=2860;c[a+789028>>2]=2134;a=c[2427044]|0;c[9681616+(a<<3)>>2]=1196632;c[9681620+(a<<3)>>2]=0;c[2427044]=a+1;return}function geW(a){a=a|0;var b=0;b=(c[2411230]|0)+(a*789044|0)|0;c[2406668]=b;c[2424904]=b;return}function geX(){return}function geY(){return 0}function geZ(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0;f=c[2424904]|0;c[f+2400>>2]=d;c[f+2396>>2]=d;g=f;while(1){f=c[2406668]|0;if((c[f+789040>>2]|0)!=0){break}h=c[g+100>>2]|0;i=f+789036|0;j=c[i>>2]|0;if((h|0)==0){k=g+4|0;l=c[k>>2]|0;m=b[j+(l&-939524097^2)>>1]|0;n=l+2|0;c[k>>2]=n;o=m;p=g;q=n}else{n=b[j+(h&-939524097^2)>>1]|0;h=g+4|0;c[h>>2]=c[h>>2]&-939524097;h=g+4|0;j=c[f+2412+(((c[h>>2]|0)>>>16|131072)<<2)>>2]|0;c[i>>2]=j;c[i>>2]=j+(-(c[h>>2]&-65536)|0);c[g+100>>2]=0;o=n;p=g;q=c[h>>2]|0}c[p>>2]=q;h=o&65535;n=h&61440;L67914:do{if((n|0)==4096){j=(c[g+32+((h>>>8&15)<<2)>>2]|0)+(h<<2&60)|0;c[g+96>>2]=j;m=c[g+32+((h>>>4&15)<<2)>>2]|0;k=c[f+2412+((j>>>16|65536)<<2)>>2]|0;if(k>>>0>7){c[k+(j&65535)>>2]=m;break}else{gg[c[f+789004+(k<<2)>>2]&4095](j,m);break}}else if((n|0)==8192){switch(h&15|0){case 0:{m=c[g+32+((h>>>8&15)<<2)>>2]|0;c[g+96>>2]=m;j=c[g+32+((h>>>4&15)<<2)>>2]&255;k=c[f+2412+((m>>>16|65536)<<2)>>2]|0;if(k>>>0>7){a[k+(m&65535^3)|0]=j;break L67914}else{gg[c[f+788876+(k<<2)>>2]&4095](m,j);break L67914}break};case 1:{j=c[g+32+((h>>>8&15)<<2)>>2]|0;c[g+96>>2]=j;m=c[g+32+((h>>>4&15)<<2)>>2]&65535;k=c[f+2412+((j>>>16|65536)<<2)>>2]|0;if(k>>>0>7){b[k+(j&65535^2)>>1]=m;break L67914}else{gg[c[f+788940+(k<<2)>>2]&4095](j,m);break L67914}break};case 2:{m=c[g+32+((h>>>8&15)<<2)>>2]|0;c[g+96>>2]=m;j=c[g+32+((h>>>4&15)<<2)>>2]|0;k=c[f+2412+((m>>>16|65536)<<2)>>2]|0;if(k>>>0>7){c[k+(m&65535)>>2]=j;break L67914}else{gg[c[f+789004+(k<<2)>>2]&4095](m,j);break L67914}break};case 4:{j=c[g+32+((h>>>4&15)<<2)>>2]|0;m=g+32+((h>>>8&15)<<2)|0;k=(c[m>>2]|0)-1|0;c[m>>2]=k;m=j&255;j=c[f+2412+((k>>>16|65536)<<2)>>2]|0;if(j>>>0>7){a[j+(k&65535^3)|0]=m;break L67914}else{gg[c[f+788876+(j<<2)>>2]&4095](k,m);break L67914}break};case 5:{m=c[g+32+((h>>>4&15)<<2)>>2]|0;k=g+32+((h>>>8&15)<<2)|0;j=(c[k>>2]|0)-2|0;c[k>>2]=j;k=m&65535;m=c[f+2412+((j>>>16|65536)<<2)>>2]|0;if(m>>>0>7){b[m+(j&65535^2)>>1]=k;break L67914}else{gg[c[f+788940+(m<<2)>>2]&4095](j,k);break L67914}break};case 6:{k=c[g+32+((h>>>4&15)<<2)>>2]|0;j=g+32+((h>>>8&15)<<2)|0;m=(c[j>>2]|0)-4|0;c[j>>2]=m;j=c[f+2412+((m>>>16|65536)<<2)>>2]|0;if(j>>>0>7){c[j+(m&65535)>>2]=k;break L67914}else{gg[c[f+789004+(j<<2)>>2]&4095](m,k);break L67914}break};case 7:{k=g+32+((h>>>8&15)<<2)|0;m=g+12|0;j=c[m>>2]|0;l=(c[k>>2]|0)>-1?j&-257:j|256;c[m>>2]=l;j=g+32+((h>>>4&15)<<2)|0;r=(c[j>>2]|0)>-1?l&-513:l|512;c[m>>2]=r;c[m>>2]=(c[k>>2]^c[j>>2]|0)<0?r|1:r&-2;break L67914;break};case 8:{r=g+12|0;j=c[r>>2]|0;c[r>>2]=(c[g+32+((h>>>4&15)<<2)>>2]&c[g+32+((h>>>8&15)<<2)>>2]|0)==0?j|1:j&-2;break L67914;break};case 9:{j=g+32+((h>>>8&15)<<2)|0;c[j>>2]=c[j>>2]&c[g+32+((h>>>4&15)<<2)>>2];break L67914;break};case 10:{j=g+32+((h>>>8&15)<<2)|0;c[j>>2]=c[j>>2]^c[g+32+((h>>>4&15)<<2)>>2];break L67914;break};case 11:{j=g+32+((h>>>8&15)<<2)|0;c[j>>2]=c[j>>2]|c[g+32+((h>>>4&15)<<2)>>2];break L67914;break};case 12:{j=c[g+32+((h>>>4&15)<<2)>>2]^c[g+32+((h>>>8&15)<<2)>>2];r=g+12|0;k=c[r>>2]|0;c[r>>2]=j>>>0<16777216|(j&16711680|0)==0|(j&65280|0)==0|(j&255|0)==0?k|1:k&-2;break L67914;break};case 13:{k=g+32+((h>>>8&15)<<2)|0;c[k>>2]=(c[k>>2]|0)>>>16|c[g+32+((h>>>4&15)<<2)>>2]<<16;break L67914;break};case 14:{c[g+28>>2]=ag(c[g+32+((h>>>4&15)<<2)>>2]&65535,c[g+32+((h>>>8&15)<<2)>>2]&65535)|0;break L67914;break};case 15:{c[g+28>>2]=ag(c[g+32+((h>>>4&15)<<2)>>2]<<16>>16,c[g+32+((h>>>8&15)<<2)>>2]<<16>>16)|0;break L67914;break};default:{break L67914}}}else if((n|0)==12288){switch(h&15|0){case 0:{k=g+12|0;j=c[k>>2]|0;c[k>>2]=(c[g+32+((h>>>8&15)<<2)>>2]|0)==(c[g+32+((h>>>4&15)<<2)>>2]|0)?j|1:j&-2;break L67914;break};case 2:{j=g+12|0;k=c[j>>2]|0;c[j>>2]=(c[g+32+((h>>>8&15)<<2)>>2]|0)>>>0<(c[g+32+((h>>>4&15)<<2)>>2]|0)>>>0?k&-2:k|1;break L67914;break};case 3:{k=g+12|0;j=c[k>>2]|0;c[k>>2]=(c[g+32+((h>>>8&15)<<2)>>2]|0)<(c[g+32+((h>>>4&15)<<2)>>2]|0)?j&-2:j|1;break L67914;break};case 4:{j=g+12|0;k=c[j>>2]|0;r=g+32+((h>>>8&15)<<2)|0;m=(c[r>>2]|0)<0?k|256:k&-257;c[j>>2]=m;l=m&1|c[r>>2]<<1;c[r>>2]=l;m=(c[j>>2]&512|0)!=0;s=c[g+32+((h>>>4&15)<<2)>>2]|0;do{if((k&256|0)==0){if(m){t=cJ(s|0,l|0)|0;c[r>>2]=t;t=c[j>>2]|0;u=K;if((t&256|0)==0){if(u){v=t&-257;c[j>>2]=v;w=v;break}else{v=t|256;c[j>>2]=v;w=v;break}}else{if(u){u=t|256;c[j>>2]=u;w=u;break}else{u=t&-257;c[j>>2]=u;w=u;break}}}else{u=l-s|0;c[r>>2]=u;t=c[j>>2]|0;v=u>>>0>l>>>0;if((t&256|0)==0){if(v){u=t|256;c[j>>2]=u;w=u;break}else{u=t&-257;c[j>>2]=u;w=u;break}}else{if(v){v=t&-257;c[j>>2]=v;w=v;break}else{v=t|256;c[j>>2]=v;w=v;break}}}}else{if(m){v=l-s|0;c[r>>2]=v;t=c[j>>2]|0;u=v>>>0>l>>>0;if((t&256|0)==0){if(u){v=t&-257;c[j>>2]=v;w=v;break}else{v=t|256;c[j>>2]=v;w=v;break}}else{if(u){u=t|256;c[j>>2]=u;w=u;break}else{u=t&-257;c[j>>2]=u;w=u;break}}}else{u=cJ(s|0,l|0)|0;c[r>>2]=u;u=c[j>>2]|0;t=K;if((u&256|0)==0){if(t){v=u|256;c[j>>2]=v;w=v;break}else{v=u&-257;c[j>>2]=v;w=v;break}}else{if(t){t=u&-257;c[j>>2]=t;w=t;break}else{t=u|256;c[j>>2]=t;w=t;break}}}}}while(0);r=w&768;if((r|0)==768|(r|0)==0){x=w|1}else{x=w&-2}c[j>>2]=x;break L67914;break};case 5:{r=c[g+32+((h>>>8&15)<<2)>>2]|0;l=r&65535;s=r>>>16;r=c[g+32+((h>>>4&15)<<2)>>2]|0;m=r&65535;k=r>>>16;r=ag(m,l)|0;t=ag(k,l)|0;l=ag(m,s)|0;m=ag(k,s)|0;s=cJ(t|0,l|0)|0;l=K?65536:0;t=cJ(r|0,s<<16|0)|0;c[g+24>>2]=(s>>>16)+m+(K&1|l);c[g+28>>2]=t;t=g+2400|0;c[t>>2]=(c[t>>2]|0)-1;break L67914;break};case 6:{t=g+12|0;l=c[t>>2]|0;c[t>>2]=(c[g+32+((h>>>8&15)<<2)>>2]|0)>>>0>(c[g+32+((h>>>4&15)<<2)>>2]|0)>>>0?l|1:l&-2;break L67914;break};case 7:{l=g+12|0;t=c[l>>2]|0;c[l>>2]=(c[g+32+((h>>>8&15)<<2)>>2]|0)>(c[g+32+((h>>>4&15)<<2)>>2]|0)?t|1:t&-2;break L67914;break};case 8:{t=g+32+((h>>>8&15)<<2)|0;c[t>>2]=(c[t>>2]|0)-(c[g+32+((h>>>4&15)<<2)>>2]|0);break L67914;break};case 10:{t=g+32+((h>>>8&15)<<2)|0;l=c[t>>2]|0;m=l-(c[g+32+((h>>>4&15)<<2)>>2]|0)|0;s=g+12|0;c[t>>2]=m-(c[s>>2]&1);r=c[s>>2]|0;k=l>>>0<m>>>0?r|1:r&-2;c[s>>2]=k;if(m>>>0>=(c[t>>2]|0)>>>0){break L67914}c[s>>2]=k|1;break L67914;break};case 11:{k=g+32+((h>>>8&15)<<2)|0;s=c[k>>2]|0;t=s>>>31;m=c[g+32+((h>>>4&15)<<2)>>2]|0;r=s-m|0;c[k>>2]=r;if(((m>>>31)+t|0)!=1){m=g+12|0;c[m>>2]=c[m>>2]&-2;break L67914}m=g+12|0;k=c[m>>2]|0;if(((r>>>31)+t|0)==1){c[m>>2]=k|1;break L67914}else{c[m>>2]=k&-2;break L67914}break};case 12:{k=g+32+((h>>>8&15)<<2)|0;c[k>>2]=(c[k>>2]|0)+(c[g+32+((h>>>4&15)<<2)>>2]|0);break L67914;break};case 13:{k=c[g+32+((h>>>8&15)<<2)>>2]|0;m=c[g+32+((h>>>4&15)<<2)>>2]|0;t=(k|0)<0?-k|0:k;r=(m|0)<0?-m|0:m;s=t&65535;l=t>>>16;t=r&65535;u=r>>>16;r=ag(t,s)|0;v=ag(u,s)|0;s=ag(t,l)|0;t=ag(u,l)|0;l=cJ(v|0,s|0)|0;s=K?65536:0;v=cJ(r|0,l<<16|0)|0;r=t+(l>>>16)+(K&1|s)|0;do{if((m^k|0)<0){if((v|0)==0){y=0;z=-r|0;break}else{y=-v|0;z=~r;break}}else{y=v;z=r}}while(0);c[g+24>>2]=z;c[g+28>>2]=y;r=g+2400|0;c[r>>2]=(c[r>>2]|0)-1;break L67914;break};case 14:{r=g+32+((h>>>8&15)<<2)|0;v=cJ(c[r>>2]|0,c[g+32+((h>>>4&15)<<2)>>2]|0)|0;k=g+12|0;c[r>>2]=(c[k>>2]&1)+v;m=c[k>>2]|0;j=K?m|1:m&-2;c[k>>2]=j;if(v>>>0<=(c[r>>2]|0)>>>0){break L67914}c[k>>2]=j|1;break L67914;break};case 15:{j=g+32+((h>>>8&15)<<2)|0;k=c[j>>2]|0;r=k>>>31;v=c[g+32+((h>>>4&15)<<2)>>2]|0;m=(v>>>31)+r|0;s=v+k|0;c[j>>2]=s;if(!((m|0)==2|(m|0)==0)){m=g+12|0;c[m>>2]=c[m>>2]&-2;break L67914}m=g+12|0;j=c[m>>2]|0;if(((s>>>31)+r|0)==1){c[m>>2]=j|1;break L67914}else{c[m>>2]=j&-2;break L67914}break};default:{break L67914}}}else if((n|0)==16384){switch(h&63|0){case 14:{c[g+12>>2]=c[g+32+((h>>>8&15)<<2)>>2]&1011;c[g+128>>2]=1;break L67914;break};case 0:{j=g+12|0;m=g+32+((h>>>8&15)<<2)|0;c[j>>2]=(c[m>>2]|0)>>>31|c[j>>2]&-2;c[m>>2]=c[m>>2]<<1;break L67914;break};case 1:{m=g+12|0;j=g+32+((h>>>8&15)<<2)|0;c[m>>2]=c[j>>2]&1|c[m>>2]&-2;c[j>>2]=(c[j>>2]|0)>>>1;break L67914;break};case 2:{j=g+32+((h>>>8&15)<<2)|0;m=(c[j>>2]|0)-4|0;c[j>>2]=m;c[g+96>>2]=m;j=c[g+24>>2]|0;r=c[f+2412+((m>>>16|65536)<<2)>>2]|0;if(r>>>0>7){c[r+(m&65535)>>2]=j;break L67914}else{gg[c[f+789004+(r<<2)>>2]&4095](m,j);break L67914}break};case 3:{j=g+32+((h>>>8&15)<<2)|0;m=(c[j>>2]|0)-4|0;c[j>>2]=m;c[g+96>>2]=m;j=c[g+12>>2]|0;r=c[f+2412+((m>>>16|65536)<<2)>>2]|0;if(r>>>0>7){c[r+(m&65535)>>2]=j;A=g}else{gg[c[f+789004+(r<<2)>>2]&4095](m,j);A=c[2424904]|0}j=A+2400|0;c[j>>2]=(c[j>>2]|0)-1;break L67914;break};case 4:{j=g+12|0;m=g+32+((h>>>8&15)<<2)|0;c[j>>2]=(c[m>>2]|0)>>>31|c[j>>2]&-2;j=c[m>>2]|0;c[m>>2]=j<<1|j>>>31;break L67914;break};case 5:{j=g+12|0;m=g+32+((h>>>8&15)<<2)|0;c[j>>2]=c[m>>2]&1|c[j>>2]&-2;j=c[m>>2]|0;c[m>>2]=j>>>1|j<<31;break L67914;break};case 6:{j=h>>>8&15;m=c[g+32+(j<<2)>>2]|0;c[g+96>>2]=m;r=c[f+2412+(m>>>16<<2)>>2]|0;if(r>>>0>7){B=c[r+(m&65535)>>2]|0;C=g}else{s=gj[c[f+788972+(r<<2)>>2]&4095](m)|0;B=s;C=c[2424904]|0}c[C+24>>2]=B;s=C+32+(j<<2)|0;c[s>>2]=(c[s>>2]|0)+4;break L67914;break};case 7:{s=h>>>8&15;j=c[g+32+(s<<2)>>2]|0;c[g+96>>2]=j;m=c[f+2412+(j>>>16<<2)>>2]|0;if(m>>>0>7){D=c[m+(j&65535)>>2]|0;E=g}else{r=gj[c[f+788972+(m<<2)>>2]&4095](j)|0;D=r;E=c[2424904]|0}c[E+12>>2]=D&1011;r=E+32+(s<<2)|0;c[r>>2]=(c[r>>2]|0)+4;r=E+2400|0;c[r>>2]=(c[r>>2]|0)-2;c[E+128>>2]=1;break L67914;break};case 8:{r=g+32+((h>>>8&15)<<2)|0;c[r>>2]=c[r>>2]<<2;break L67914;break};case 9:{r=g+32+((h>>>8&15)<<2)|0;c[r>>2]=(c[r>>2]|0)>>>2;break L67914;break};case 10:{c[g+24>>2]=c[g+32+((h>>>8&15)<<2)>>2];break L67914;break};case 11:{r=g+4|0;s=c[r>>2]|0;c[g+100>>2]=s;c[g+8>>2]=s+2;s=c[g+32+((h>>>8&15)<<2)>>2]|0;c[g+96>>2]=s;c[r>>2]=s;s=g+2400|0;c[s>>2]=(c[s>>2]|0)-1;break L67914;break};case 15:{ge7(h>>>4&15,h>>>8&15);break L67914;break};case 16:{s=h>>>8&15;r=g+32+(s<<2)|0;j=(c[r>>2]|0)-1|0;c[r>>2]=j;r=g+12|0;m=c[r>>2]|0;c[r>>2]=(j|0)==0?m|1:m&-2;m=c[g>>2]|0;j=m&-939524097;r=c[f+2412+(j>>>16<<2)>>2]|0;if(r>>>0>7){F=b[r+(m&65535^2)>>1]|0}else{F=gj[c[f+788908+(r<<2)>>2]&4095](j)|0}if(F<<16>>16!=-29699){break L67914}j=c[2424904]|0;r=j+32+(s<<2)|0;s=c[r>>2]|0;if(s>>>0<=1){break L67914}m=j+2400|0;k=j+2404|0;j=s;s=c[m>>2]|0;do{if((s|0)<=4){break L67914}c[r>>2]=j-1;s=(c[m>>2]|0)-4|0;c[m>>2]=s;c[k>>2]=(c[k>>2]|0)+4;j=c[r>>2]|0;}while(j>>>0>1);break};case 17:{j=g+12|0;r=c[j>>2]|0;c[j>>2]=(c[g+32+((h>>>8&15)<<2)>>2]|0)>-1?r|1:r&-2;break L67914;break};case 18:{r=g+32+((h>>>8&15)<<2)|0;j=(c[r>>2]|0)-4|0;c[r>>2]=j;c[g+96>>2]=j;r=c[g+28>>2]|0;k=c[f+2412+((j>>>16|65536)<<2)>>2]|0;if(k>>>0>7){c[k+(j&65535)>>2]=r;break L67914}else{gg[c[f+789004+(k<<2)>>2]&4095](j,r);break L67914}break};case 19:{r=g+32+((h>>>8&15)<<2)|0;j=(c[r>>2]|0)-4|0;c[r>>2]=j;c[g+96>>2]=j;r=c[g+16>>2]|0;k=c[f+2412+((j>>>16|65536)<<2)>>2]|0;if(k>>>0>7){c[k+(j&65535)>>2]=r;G=g}else{gg[c[f+789004+(k<<2)>>2]&4095](j,r);G=c[2424904]|0}r=G+2400|0;c[r>>2]=(c[r>>2]|0)-1;break L67914;break};case 21:{r=g+12|0;j=c[r>>2]|0;c[r>>2]=(c[g+32+((h>>>8&15)<<2)>>2]|0)>0?j|1:j&-2;break L67914;break};case 22:{j=h>>>8&15;r=c[g+32+(j<<2)>>2]|0;c[g+96>>2]=r;k=c[f+2412+(r>>>16<<2)>>2]|0;if(k>>>0>7){H=c[k+(r&65535)>>2]|0;I=g}else{s=gj[c[f+788972+(k<<2)>>2]&4095](r)|0;H=s;I=c[2424904]|0}c[I+28>>2]=H;s=I+32+(j<<2)|0;c[s>>2]=(c[s>>2]|0)+4;break L67914;break};case 23:{s=h>>>8&15;j=c[g+32+(s<<2)>>2]|0;c[g+96>>2]=j;r=c[f+2412+(j>>>16<<2)>>2]|0;if(r>>>0>7){J=c[r+(j&65535)>>2]|0;L=g}else{k=gj[c[f+788972+(r<<2)>>2]&4095](j)|0;J=k;L=c[2424904]|0}c[L+16>>2]=J;k=L+32+(s<<2)|0;c[k>>2]=(c[k>>2]|0)+4;k=L+2400|0;c[k>>2]=(c[k>>2]|0)-2;break L67914;break};case 24:{k=g+32+((h>>>8&15)<<2)|0;c[k>>2]=c[k>>2]<<8;break L67914;break};case 25:{k=g+32+((h>>>8&15)<<2)|0;c[k>>2]=(c[k>>2]|0)>>>8;break L67914;break};case 26:{c[g+28>>2]=c[g+32+((h>>>8&15)<<2)>>2];break L67914;break};case 27:{k=c[g+32+((h>>>8&15)<<2)>>2]|0;c[g+96>>2]=k;s=c[f+2412+(k>>>16<<2)>>2]|0;if(s>>>0>7){M=a[s+(k&65535^3)|0]|0;N=g;O=k;P=f}else{j=gj[c[f+788844+(s<<2)>>2]&4095](k)|0;k=c[2424904]|0;M=j;N=k;O=c[k+96>>2]|0;P=c[2406668]|0}k=N+12|0;j=c[k>>2]|0;c[k>>2]=M<<24>>24==0?j|1:j&-2;j=M|-128;k=c[P+2412+((O>>>16|65536)<<2)>>2]|0;if(k>>>0>7){a[k+(O&65535^3)|0]=j;Q=N}else{gg[c[P+788876+(k<<2)>>2]&4095](O,j);Q=c[2424904]|0}j=Q+2400|0;c[j>>2]=(c[j>>2]|0)-3;break L67914;break};case 30:{c[g+16>>2]=c[g+32+((h>>>8&15)<<2)>>2];break L67914;break};case 31:{ge7(h>>>4&15,h>>>8&15);break L67914;break};case 32:{j=g+12|0;k=g+32+((h>>>8&15)<<2)|0;c[j>>2]=(c[k>>2]|0)>>>31|c[j>>2]&-2;c[k>>2]=c[k>>2]<<1;break L67914;break};case 33:{k=g+12|0;j=g+32+((h>>>8&15)<<2)|0;c[k>>2]=c[j>>2]&1|c[k>>2]&-2;c[j>>2]=c[j>>2]>>1;break L67914;break};case 34:{j=g+32+((h>>>8&15)<<2)|0;k=(c[j>>2]|0)-4|0;c[j>>2]=k;c[g+96>>2]=k;j=c[g+8>>2]|0;s=c[f+2412+((k>>>16|65536)<<2)>>2]|0;if(s>>>0>7){c[s+(k&65535)>>2]=j;break L67914}else{gg[c[f+789004+(s<<2)>>2]&4095](k,j);break L67914}break};case 35:{j=g+32+((h>>>8&15)<<2)|0;k=(c[j>>2]|0)-4|0;c[j>>2]=k;c[g+96>>2]=k;j=c[g+20>>2]|0;s=c[f+2412+((k>>>16|65536)<<2)>>2]|0;if(s>>>0>7){c[s+(k&65535)>>2]=j;R=g}else{gg[c[f+789004+(s<<2)>>2]&4095](k,j);R=c[2424904]|0}j=R+2400|0;c[j>>2]=(c[j>>2]|0)-1;break L67914;break};case 36:{j=g+32+((h>>>8&15)<<2)|0;k=c[j>>2]|0;s=g+12|0;c[j>>2]=c[s>>2]&1|k<<1;c[s>>2]=c[s>>2]&-2|k>>>31;break L67914;break};case 37:{k=g+12|0;s=c[k>>2]|0;j=g+32+((h>>>8&15)<<2)|0;c[k>>2]=(c[j>>2]&1|0)==0?s&-2:s|1;c[j>>2]=(c[j>>2]|0)>>>1|s<<31;break L67914;break};case 38:{s=h>>>8&15;j=c[g+32+(s<<2)>>2]|0;c[g+96>>2]=j;k=c[f+2412+(j>>>16<<2)>>2]|0;if(k>>>0>7){S=c[k+(j&65535)>>2]|0;T=g}else{r=gj[c[f+788972+(k<<2)>>2]&4095](j)|0;S=r;T=c[2424904]|0}c[T+8>>2]=S;r=T+32+(s<<2)|0;c[r>>2]=(c[r>>2]|0)+4;break L67914;break};case 39:{r=h>>>8&15;s=c[g+32+(r<<2)>>2]|0;c[g+96>>2]=s;j=c[f+2412+(s>>>16<<2)>>2]|0;if(j>>>0>7){U=c[j+(s&65535)>>2]|0;V=g}else{k=gj[c[f+788972+(j<<2)>>2]&4095](s)|0;U=k;V=c[2424904]|0}c[V+20>>2]=U;k=V+32+(r<<2)|0;c[k>>2]=(c[k>>2]|0)+4;k=V+2400|0;c[k>>2]=(c[k>>2]|0)-2;break L67914;break};case 40:{k=g+32+((h>>>8&15)<<2)|0;c[k>>2]=c[k>>2]<<16;break L67914;break};case 41:{k=g+32+((h>>>8&15)<<2)|0;c[k>>2]=(c[k>>2]|0)>>>16;break L67914;break};case 42:{c[g+8>>2]=c[g+32+((h>>>8&15)<<2)>>2];break L67914;break};case 43:{k=g+4|0;c[g+100>>2]=c[k>>2];r=c[g+32+((h>>>8&15)<<2)>>2]|0;c[g+96>>2]=r;c[k>>2]=r;break L67914;break};case 46:{c[g+20>>2]=c[g+32+((h>>>8&15)<<2)>>2];break L67914;break};case 47:{ge7(h>>>4&15,h>>>8&15);break L67914;break};case 63:{ge7(h>>>4&15,h>>>8&15);break L67914;break};default:{break L67914}}}else if((n|0)==20480){r=(c[g+32+((h>>>4&15)<<2)>>2]|0)+(h<<2&60)|0;c[g+96>>2]=r;k=c[f+2412+(r>>>16<<2)>>2]|0;if(k>>>0>7){W=c[k+(r&65535)>>2]|0;X=g}else{s=gj[c[f+788972+(k<<2)>>2]&4095](r)|0;W=s;X=c[2424904]|0}c[X+32+((h>>>8&15)<<2)>>2]=W}else if((n|0)==24576){switch(h&15|0){case 0:{s=c[g+32+((h>>>4&15)<<2)>>2]|0;c[g+96>>2]=s;r=c[f+2412+(s>>>16<<2)>>2]|0;if(r>>>0>7){Y=a[r+(s&65535^3)|0]|0;Z=g}else{k=gj[c[f+788844+(r<<2)>>2]&4095](s)|0;Y=k;Z=c[2424904]|0}c[Z+32+((h>>>8&15)<<2)>>2]=Y<<24>>24;break L67914;break};case 1:{k=c[g+32+((h>>>4&15)<<2)>>2]|0;c[g+96>>2]=k;s=c[f+2412+(k>>>16<<2)>>2]|0;if(s>>>0>7){_=b[s+(k&65535^2)>>1]|0;$=g}else{r=gj[c[f+788908+(s<<2)>>2]&4095](k)|0;_=r;$=c[2424904]|0}c[$+32+((h>>>8&15)<<2)>>2]=_<<16>>16;break L67914;break};case 2:{r=c[g+32+((h>>>4&15)<<2)>>2]|0;c[g+96>>2]=r;k=c[f+2412+(r>>>16<<2)>>2]|0;if(k>>>0>7){aa=c[k+(r&65535)>>2]|0;ab=g}else{s=gj[c[f+788972+(k<<2)>>2]&4095](r)|0;aa=s;ab=c[2424904]|0}c[ab+32+((h>>>8&15)<<2)>>2]=aa;break L67914;break};case 3:{c[g+32+((h>>>8&15)<<2)>>2]=c[g+32+((h>>>4&15)<<2)>>2];break L67914;break};case 4:{s=h>>>4&15;r=h>>>8&15;k=c[g+32+(s<<2)>>2]|0;j=c[f+2412+(k>>>16<<2)>>2]|0;if(j>>>0>7){ac=a[j+(k&65535^3)|0]|0;ad=g}else{m=gj[c[f+788844+(j<<2)>>2]&4095](k)|0;ac=m;ad=c[2424904]|0}c[ad+32+(r<<2)>>2]=ac<<24>>24;if((r|0)==(s|0)){break L67914}r=ad+32+(s<<2)|0;c[r>>2]=(c[r>>2]|0)+1;break L67914;break};case 5:{r=h>>>4&15;s=h>>>8&15;m=c[g+32+(r<<2)>>2]|0;k=c[f+2412+(m>>>16<<2)>>2]|0;if(k>>>0>7){ae=b[k+(m&65535^2)>>1]|0;af=g}else{j=gj[c[f+788908+(k<<2)>>2]&4095](m)|0;ae=j;af=c[2424904]|0}c[af+32+(s<<2)>>2]=ae<<16>>16;if((s|0)==(r|0)){break L67914}s=af+32+(r<<2)|0;c[s>>2]=(c[s>>2]|0)+2;break L67914;break};case 6:{s=h>>>4&15;r=h>>>8&15;j=c[g+32+(s<<2)>>2]|0;m=c[f+2412+(j>>>16<<2)>>2]|0;if(m>>>0>7){ah=c[m+(j&65535)>>2]|0;ai=g}else{k=gj[c[f+788972+(m<<2)>>2]&4095](j)|0;ah=k;ai=c[2424904]|0}c[ai+32+(r<<2)>>2]=ah;if((r|0)==(s|0)){break L67914}r=ai+32+(s<<2)|0;c[r>>2]=(c[r>>2]|0)+4;break L67914;break};case 7:{c[g+32+((h>>>8&15)<<2)>>2]=~c[g+32+((h>>>4&15)<<2)>>2];break L67914;break};case 8:{r=c[g+32+((h>>>4&15)<<2)>>2]|0;c[g+32+((h>>>8&15)<<2)>>2]=r<<8&65280|r&-65536|r>>>8&255;break L67914;break};case 9:{r=c[g+32+((h>>>4&15)<<2)>>2]|0;c[g+32+((h>>>8&15)<<2)>>2]=r<<16|r>>>16;break L67914;break};case 10:{r=c[g+32+((h>>>4&15)<<2)>>2]|0;s=g+12|0;c[g+32+((h>>>8&15)<<2)>>2]=-((c[s>>2]&1)+r|0);k=c[s>>2]|0;do{if((r|0)==0){if((k&1|0)!=0){break}c[s>>2]=k&-2;break L67914}}while(0);c[s>>2]=k|1;break L67914;break};case 11:{c[g+32+((h>>>8&15)<<2)>>2]=-(c[g+32+((h>>>4&15)<<2)>>2]|0);break L67914;break};case 12:{c[g+32+((h>>>8&15)<<2)>>2]=c[g+32+((h>>>4&15)<<2)>>2]&255;break L67914;break};case 13:{c[g+32+((h>>>8&15)<<2)>>2]=c[g+32+((h>>>4&15)<<2)>>2]&65535;break L67914;break};case 14:{c[g+32+((h>>>8&15)<<2)>>2]=c[g+32+((h>>>4&15)<<2)>>2]<<24>>24;break L67914;break};case 15:{c[g+32+((h>>>8&15)<<2)>>2]=c[g+32+((h>>>4&15)<<2)>>2]<<16>>16;break L67914;break};default:{break L67914}}}else if((n|0)==28672){r=g+32+((h>>>8&15)<<2)|0;c[r>>2]=(c[r>>2]|0)+(h<<24>>24)}else if((n|0)==32768){switch(h&3840|0){case 0:{r=(c[g+32+((h>>>4&15)<<2)>>2]|0)+(h&15)|0;c[g+96>>2]=r;j=c[g+32>>2]&255;m=c[f+2412+((r>>>16|65536)<<2)>>2]|0;if(m>>>0>7){a[m+(r&65535^3)|0]=j;break L67914}else{gg[c[f+788876+(m<<2)>>2]&4095](r,j);break L67914}break};case 256:{j=(c[g+32+((h>>>4&15)<<2)>>2]|0)+(h<<1&30)|0;c[g+96>>2]=j;r=c[g+32>>2]&65535;m=c[f+2412+((j>>>16|65536)<<2)>>2]|0;if(m>>>0>7){b[m+(j&65535^2)>>1]=r;break L67914}else{gg[c[f+788940+(m<<2)>>2]&4095](j,r);break L67914}break};case 1024:{r=(c[g+32+((h>>>4&15)<<2)>>2]|0)+(h&15)|0;c[g+96>>2]=r;j=c[f+2412+(r>>>16<<2)>>2]|0;if(j>>>0>7){aj=a[j+(r&65535^3)|0]|0;ak=g}else{m=gj[c[f+788844+(j<<2)>>2]&4095](r)|0;aj=m;ak=c[2424904]|0}c[ak+32>>2]=aj<<24>>24;break L67914;break};case 1280:{m=(c[g+32+((h>>>4&15)<<2)>>2]|0)+(h<<1&30)|0;c[g+96>>2]=m;r=c[f+2412+(m>>>16<<2)>>2]|0;if(r>>>0>7){al=b[r+(m&65535^2)>>1]|0;am=g}else{j=gj[c[f+788908+(r<<2)>>2]&4095](m)|0;al=j;am=c[2424904]|0}c[am+32>>2]=al<<16>>16;break L67914;break};case 2048:{j=g+12|0;m=c[j>>2]|0;c[j>>2]=(c[g+32>>2]|0)==(h<<24>>24|0)?m|1:m&-2;break L67914;break};case 2304:{if((c[g+12>>2]&1|0)==0){break L67914}m=g+4|0;j=(h<<24>>23)+2+(c[m>>2]|0)|0;c[g+96>>2]=j;r=j&-939524097;c[m>>2]=r;j=c[f+2412+((r>>>16|131072)<<2)>>2]|0;c[i>>2]=j;c[i>>2]=j+(-(c[m>>2]&-65536)|0);m=g+2400|0;c[m>>2]=(c[m>>2]|0)-2;break L67914;break};case 2816:{if((c[g+12>>2]&1|0)!=0){break L67914}m=g+4|0;j=(h<<24>>23)+2+(c[m>>2]|0)|0;c[g+96>>2]=j;r=j&-939524097;c[m>>2]=r;j=c[f+2412+((r>>>16|131072)<<2)>>2]|0;c[i>>2]=j;c[i>>2]=j+(-(c[m>>2]&-65536)|0);m=g+2400|0;c[m>>2]=(c[m>>2]|0)-2;break L67914;break};case 3328:{if((c[g+12>>2]&1|0)==0){break L67914}m=g+4|0;j=c[m>>2]|0;c[g+100>>2]=j;r=(h<<24>>23)+2+j|0;c[g+96>>2]=r;c[m>>2]=r;r=g+2400|0;c[r>>2]=(c[r>>2]|0)-1;break L67914;break};case 3840:{if((c[g+12>>2]&1|0)!=0){break L67914}r=g+4|0;m=c[r>>2]|0;c[g+100>>2]=m;j=(h<<24>>23)+2+m|0;c[g+96>>2]=j;c[r>>2]=j;j=g+2400|0;c[j>>2]=(c[j>>2]|0)-1;break L67914;break};default:{break L67914}}}else if((n|0)==36864){j=(h<<1&510)+2+(c[g+4>>2]|0)|0;c[g+96>>2]=j;r=c[f+2412+(j>>>16<<2)>>2]|0;if(r>>>0>7){an=b[r+(j&65535^2)>>1]|0;ao=g}else{m=gj[c[f+788908+(r<<2)>>2]&4095](j)|0;an=m;ao=c[2424904]|0}c[ao+32+((h>>>8&15)<<2)>>2]=an<<16>>16}else if((n|0)==40960){m=h<<20;do{if((m|0)==-2097152){j=c[g>>2]|0;r=j&-939524097;v=c[f+2412+(r>>>16<<2)>>2]|0;if(v>>>0>7){ap=b[v+(j&65535^2)>>1]|0}else{ap=gj[c[f+788908+(v<<2)>>2]&4095](r)|0}r=c[2424904]|0;if(ap<<16>>16!=9){aq=r;break}v=r+2400|0;j=c[v>>2]|0;l=r+2404|0;t=(c[l>>2]|0)+j|0;u=(j|0)%3|0;c[v>>2]=u;c[l>>2]=t-u;aq=r}else{aq=g}}while(0);k=aq+4|0;s=c[k>>2]|0;c[aq+100>>2]=s;r=(m>>19)+2+s|0;c[aq+96>>2]=r;c[k>>2]=r;r=aq+2400|0;c[r>>2]=(c[r>>2]|0)-1}else if((n|0)==45056){r=g+4|0;k=c[r>>2]|0;c[g+8>>2]=k+2;c[g+100>>2]=k;s=(h<<20>>19)+2+k|0;c[g+96>>2]=s;c[r>>2]=s;s=g+2400|0;c[s>>2]=(c[s>>2]|0)-1}else if((n|0)==49152){switch(h&3840|0){case 0:{s=(c[g+16>>2]|0)+(h&255)|0;c[g+96>>2]=s;r=c[g+32>>2]&255;k=c[f+2412+((s>>>16|65536)<<2)>>2]|0;if(k>>>0>7){a[k+(s&65535^3)|0]=r;break L67914}else{gg[c[f+788876+(k<<2)>>2]&4095](s,r);break L67914}break};case 256:{r=(c[g+16>>2]|0)+(h<<1&510)|0;c[g+96>>2]=r;s=c[g+32>>2]&65535;k=c[f+2412+((r>>>16|65536)<<2)>>2]|0;if(k>>>0>7){b[k+(r&65535^2)>>1]=s;break L67914}else{gg[c[f+788940+(k<<2)>>2]&4095](r,s);break L67914}break};case 512:{s=(c[g+16>>2]|0)+(h<<2&1020)|0;c[g+96>>2]=s;r=c[g+32>>2]|0;k=c[f+2412+((s>>>16|65536)<<2)>>2]|0;if(k>>>0>7){c[k+(s&65535)>>2]=r;break L67914}else{gg[c[f+789004+(k<<2)>>2]&4095](s,r);break L67914}break};case 768:{c[g+96>>2]=(c[g+20>>2]|0)+(h<<2&1020);r=g+92|0;s=(c[r>>2]|0)-4|0;c[r>>2]=s;r=c[g+12>>2]|0;k=c[f+2412+((s>>>16|65536)<<2)>>2]|0;if(k>>>0>7){c[k+(s&65535)>>2]=r;ar=g;as=f}else{gg[c[f+789004+(k<<2)>>2]&4095](s,r);ar=c[2424904]|0;as=c[2406668]|0}r=ar+92|0;s=(c[r>>2]|0)-4|0;c[r>>2]=s;r=c[ar+4>>2]|0;k=c[as+2412+((s>>>16|65536)<<2)>>2]|0;if(k>>>0>7){c[k+(s&65535)>>2]=r;at=ar;au=as}else{gg[c[as+789004+(k<<2)>>2]&4095](s,r);at=c[2424904]|0;au=c[2406668]|0}r=c[at+96>>2]|0;s=c[au+2412+(r>>>16<<2)>>2]|0;if(s>>>0>7){av=c[s+(r&65535)>>2]|0;aw=at;ax=au}else{k=gj[c[au+788972+(s<<2)>>2]&4095](r)|0;av=k;aw=c[2424904]|0;ax=c[2406668]|0}k=aw+4|0;r=av&-939524097;c[k>>2]=r;s=c[ax+2412+((r>>>16|131072)<<2)>>2]|0;r=ax+789036|0;c[r>>2]=s;c[r>>2]=s+(-(c[k>>2]&-65536)|0);k=aw+2400|0;c[k>>2]=(c[k>>2]|0)-7;break L67914;break};case 1024:{k=(c[g+16>>2]|0)+(h&255)|0;c[g+96>>2]=k;s=c[f+2412+(k>>>16<<2)>>2]|0;if(s>>>0>7){ay=a[s+(k&65535^3)|0]|0;az=g}else{r=gj[c[f+788844+(s<<2)>>2]&4095](k)|0;ay=r;az=c[2424904]|0}c[az+32>>2]=ay<<24>>24;break L67914;break};case 1280:{r=(c[g+16>>2]|0)+(h<<1&510)|0;c[g+96>>2]=r;k=c[f+2412+(r>>>16<<2)>>2]|0;if(k>>>0>7){aA=b[k+(r&65535^2)>>1]|0;aB=g}else{s=gj[c[f+788908+(k<<2)>>2]&4095](r)|0;aA=s;aB=c[2424904]|0}c[aB+32>>2]=aA<<16>>16;break L67914;break};case 1536:{s=(c[g+16>>2]|0)+(h<<2&1020)|0;c[g+96>>2]=s;r=c[f+2412+(s>>>16<<2)>>2]|0;if(r>>>0>7){aC=c[r+(s&65535)>>2]|0;aD=g}else{k=gj[c[f+788972+(r<<2)>>2]&4095](s)|0;aC=k;aD=c[2424904]|0}c[aD+32>>2]=aC;break L67914;break};case 1792:{k=((c[g+4>>2]|0)+2&-4)+(h<<2&1020)|0;c[g+96>>2]=k;c[g+32>>2]=k;break L67914;break};case 2048:{k=g+12|0;s=c[k>>2]|0;c[k>>2]=(h&255&c[g+32>>2]|0)==0?s|1:s&-2;break L67914;break};case 2304:{s=g+32|0;c[s>>2]=h&255&c[s>>2];break L67914;break};case 2560:{s=g+32|0;c[s>>2]=c[s>>2]^h&255;break L67914;break};case 2816:{s=g+32|0;c[s>>2]=c[s>>2]|h&255;s=g+2400|0;c[s>>2]=(c[s>>2]|0)-2;break L67914;break};case 3072:{s=(c[g+32>>2]|0)+(c[g+16>>2]|0)|0;c[g+96>>2]=s;k=c[f+2412+(s>>>16<<2)>>2]|0;if(k>>>0>7){aE=a[k+(s&65535^3)|0]|0;aF=g}else{r=gj[c[f+788844+(k<<2)>>2]&4095](s)|0;aE=r;aF=c[2424904]|0}r=aF+12|0;s=c[r>>2]|0;c[r>>2]=(aE&255&h|0)==0?s|1:s&-2;s=aF+2400|0;c[s>>2]=(c[s>>2]|0)-2;break L67914;break};case 3328:{s=(c[g+32>>2]|0)+(c[g+16>>2]|0)|0;c[g+96>>2]=s;r=c[f+2412+(s>>>16<<2)>>2]|0;if(r>>>0>7){aG=a[r+(s&65535^3)|0]|0;aH=s;aI=f;aJ=g}else{k=gj[c[f+788844+(r<<2)>>2]&4095](s)|0;s=c[2424904]|0;aG=k;aH=c[s+96>>2]|0;aI=c[2406668]|0;aJ=s}s=aG&255&h&255;k=c[aI+2412+((aH>>>16|65536)<<2)>>2]|0;if(k>>>0>7){a[k+(aH&65535^3)|0]=s;aK=aJ}else{gg[c[aI+788876+(k<<2)>>2]&4095](aH,s);aK=c[2424904]|0}s=aK+2400|0;c[s>>2]=(c[s>>2]|0)-2;break L67914;break};case 3584:{s=(c[g+32>>2]|0)+(c[g+16>>2]|0)|0;c[g+96>>2]=s;k=c[f+2412+(s>>>16<<2)>>2]|0;if(k>>>0>7){aL=a[k+(s&65535^3)|0]|0;aM=s;aN=f;aO=g}else{r=gj[c[f+788844+(k<<2)>>2]&4095](s)|0;s=c[2424904]|0;aL=r;aM=c[s+96>>2]|0;aN=c[2406668]|0;aO=s}s=(aL&255^h)&255;r=c[aN+2412+((aM>>>16|65536)<<2)>>2]|0;if(r>>>0>7){a[r+(aM&65535^3)|0]=s;aP=aO}else{gg[c[aN+788876+(r<<2)>>2]&4095](aM,s);aP=c[2424904]|0}s=aP+2400|0;c[s>>2]=(c[s>>2]|0)-2;break L67914;break};case 3840:{s=(c[g+32>>2]|0)+(c[g+16>>2]|0)|0;c[g+96>>2]=s;r=c[f+2412+(s>>>16<<2)>>2]|0;if(r>>>0>7){aQ=a[r+(s&65535^3)|0]|0;aR=s;aS=f}else{k=gj[c[f+788844+(r<<2)>>2]&4095](s)|0;aQ=k;aR=c[(c[2424904]|0)+96>>2]|0;aS=c[2406668]|0}k=(aQ&255|h)&255;s=c[aS+2412+((aR>>>16|65536)<<2)>>2]|0;if(s>>>0>7){a[s+(aR&65535^3)|0]=k;break L67914}else{gg[c[aS+788876+(s<<2)>>2]&4095](aR,k);break L67914}break};default:{break L67914}}}else if((n|0)==53248){k=((c[g+4>>2]|0)+2&-4)+(h<<2&1020)|0;c[g+96>>2]=k;s=c[f+2412+(k>>>16<<2)>>2]|0;if(s>>>0>7){aT=c[s+(k&65532)>>2]|0;aU=g}else{r=gj[c[f+788972+(s<<2)>>2]&4095](k)|0;aT=r;aU=c[2424904]|0}c[aU+32+((h>>>8&15)<<2)>>2]=aT}else if((n|0)==57344){c[g+32+((h>>>8&15)<<2)>>2]=h<<24>>24}else if((n|0)==0){switch(h&63|0){case 6:{r=(c[g+32>>2]|0)+(c[g+32+((h>>>8&15)<<2)>>2]|0)|0;c[g+96>>2]=r;k=c[g+32+((h>>>4&15)<<2)>>2]|0;s=c[f+2412+((r>>>16|65536)<<2)>>2]|0;if(s>>>0>7){c[s+(r&65535)>>2]=k;break L67914}else{gg[c[f+789004+(s<<2)>>2]&4095](r,k);break L67914}break};case 8:{k=g+12|0;c[k>>2]=c[k>>2]&-2;break L67914;break};case 10:{c[g+32+((h>>>8&15)<<2)>>2]=c[g+24>>2];break L67914;break};case 5:{k=(c[g+32>>2]|0)+(c[g+32+((h>>>8&15)<<2)>>2]|0)|0;c[g+96>>2]=k;r=c[g+32+((h>>>4&15)<<2)>>2]&65535;s=c[f+2412+((k>>>16|65536)<<2)>>2]|0;if(s>>>0>7){b[s+(k&65535^2)>>1]=r;break L67914}else{gg[c[f+788940+(s<<2)>>2]&4095](k,r);break L67914}break};case 12:{r=(c[g+32>>2]|0)+(c[g+32+((h>>>4&15)<<2)>>2]|0)|0;c[g+96>>2]=r;k=c[f+2412+(r>>>16<<2)>>2]|0;if(k>>>0>7){aV=a[k+(r&65535^3)|0]|0;aW=g}else{s=gj[c[f+788844+(k<<2)>>2]&4095](r)|0;aV=s;aW=c[2424904]|0}c[aW+32+((h>>>8&15)<<2)>>2]=aV<<24>>24;break L67914;break};case 14:{s=(c[g+32>>2]|0)+(c[g+32+((h>>>4&15)<<2)>>2]|0)|0;c[g+96>>2]=s;r=c[f+2412+(s>>>16<<2)>>2]|0;if(r>>>0>7){aX=c[r+(s&65535)>>2]|0;aY=g}else{k=gj[c[f+788972+(r<<2)>>2]&4095](s)|0;aX=k;aY=c[2424904]|0}c[aY+32+((h>>>8&15)<<2)>>2]=aX;break L67914;break};case 15:{ge8(h>>>4&15,h>>>8&15);break L67914;break};case 18:{c[g+32+((h>>>8&15)<<2)>>2]=c[g+16>>2];break L67914;break};case 20:{k=(c[g+32>>2]|0)+(c[g+32+((h>>>8&15)<<2)>>2]|0)|0;c[g+96>>2]=k;s=c[g+32+((h>>>4&15)<<2)>>2]&255;r=c[f+2412+((k>>>16|65536)<<2)>>2]|0;if(r>>>0>7){a[r+(k&65535^3)|0]=s;break L67914}else{gg[c[f+788876+(r<<2)>>2]&4095](k,s);break L67914}break};case 21:{s=(c[g+32>>2]|0)+(c[g+32+((h>>>8&15)<<2)>>2]|0)|0;c[g+96>>2]=s;k=c[g+32+((h>>>4&15)<<2)>>2]&65535;r=c[f+2412+((s>>>16|65536)<<2)>>2]|0;if(r>>>0>7){b[r+(s&65535^2)>>1]=k;break L67914}else{gg[c[f+788940+(r<<2)>>2]&4095](s,k);break L67914}break};case 22:{k=(c[g+32>>2]|0)+(c[g+32+((h>>>8&15)<<2)>>2]|0)|0;c[g+96>>2]=k;s=c[g+32+((h>>>4&15)<<2)>>2]|0;r=c[f+2412+((k>>>16|65536)<<2)>>2]|0;if(r>>>0>7){c[r+(k&65535)>>2]=s;break L67914}else{gg[c[f+789004+(r<<2)>>2]&4095](k,s);break L67914}break};case 23:{c[g+28>>2]=ag(c[g+32+((h>>>4&15)<<2)>>2]|0,c[g+32+((h>>>8&15)<<2)>>2]|0)|0;s=g+2400|0;c[s>>2]=(c[s>>2]|0)-1;break L67914;break};case 24:{s=g+12|0;c[s>>2]=c[s>>2]|1;break L67914;break};case 25:{s=g+12|0;c[s>>2]=c[s>>2]&-770;break L67914;break};case 26:{c[g+32+((h>>>8&15)<<2)>>2]=c[g+28>>2];break L67914;break};case 27:{s=g+4|0;c[s>>2]=(c[s>>2]|0)-2;s=g+2400|0;c[s>>2]=(c[s>>2]|0)-2;break L67914;break};case 28:{s=(c[g+32>>2]|0)+(c[g+32+((h>>>4&15)<<2)>>2]|0)|0;c[g+96>>2]=s;k=c[f+2412+(s>>>16<<2)>>2]|0;if(k>>>0>7){aZ=a[k+(s&65535^3)|0]|0;a_=g}else{r=gj[c[f+788844+(k<<2)>>2]&4095](s)|0;aZ=r;a_=c[2424904]|0}c[a_+32+((h>>>8&15)<<2)>>2]=aZ<<24>>24;break L67914;break};case 29:{r=(c[g+32>>2]|0)+(c[g+32+((h>>>4&15)<<2)>>2]|0)|0;c[g+96>>2]=r;s=c[f+2412+(r>>>16<<2)>>2]|0;if(s>>>0>7){a$=b[s+(r&65535^2)>>1]|0;a0=g}else{k=gj[c[f+788908+(s<<2)>>2]&4095](r)|0;a$=k;a0=c[2424904]|0}c[a0+32+((h>>>8&15)<<2)>>2]=a$<<16>>16;break L67914;break};case 30:{k=(c[g+32>>2]|0)+(c[g+32+((h>>>4&15)<<2)>>2]|0)|0;c[g+96>>2]=k;r=c[f+2412+(k>>>16<<2)>>2]|0;if(r>>>0>7){a1=c[r+(k&65535)>>2]|0;a2=g}else{s=gj[c[f+788972+(r<<2)>>2]&4095](k)|0;a1=s;a2=c[2424904]|0}c[a2+32+((h>>>8&15)<<2)>>2]=a1;break L67914;break};case 31:{ge8(h>>>4&15,h>>>8&15);break L67914;break};case 34:{c[g+32+((h>>>8&15)<<2)>>2]=c[g+20>>2];break L67914;break};case 35:{s=g+4|0;k=c[s>>2]|0;c[g+100>>2]=k;c[s>>2]=(c[g+32+((h>>>8&15)<<2)>>2]|0)+2+k;k=g+2400|0;c[k>>2]=(c[k>>2]|0)-1;break L67914;break};case 36:{k=(c[g+32>>2]|0)+(c[g+32+((h>>>8&15)<<2)>>2]|0)|0;c[g+96>>2]=k;s=c[g+32+((h>>>4&15)<<2)>>2]&255;r=c[f+2412+((k>>>16|65536)<<2)>>2]|0;if(r>>>0>7){a[r+(k&65535^3)|0]=s;break L67914}else{gg[c[f+788876+(r<<2)>>2]&4095](k,s);break L67914}break};case 37:{s=(c[g+32>>2]|0)+(c[g+32+((h>>>8&15)<<2)>>2]|0)|0;c[g+96>>2]=s;k=c[g+32+((h>>>4&15)<<2)>>2]&65535;r=c[f+2412+((s>>>16|65536)<<2)>>2]|0;if(r>>>0>7){b[r+(s&65535^2)>>1]=k;break L67914}else{gg[c[f+788940+(r<<2)>>2]&4095](s,k);break L67914}break};case 38:{k=(c[g+32>>2]|0)+(c[g+32+((h>>>8&15)<<2)>>2]|0)|0;c[g+96>>2]=k;s=c[g+32+((h>>>4&15)<<2)>>2]|0;r=c[f+2412+((k>>>16|65536)<<2)>>2]|0;if(r>>>0>7){c[r+(k&65535)>>2]=s;break L67914}else{gg[c[f+789004+(r<<2)>>2]&4095](k,s);break L67914}break};case 39:{c[g+28>>2]=ag(c[g+32+((h>>>4&15)<<2)>>2]|0,c[g+32+((h>>>8&15)<<2)>>2]|0)|0;s=g+2400|0;c[s>>2]=(c[s>>2]|0)-1;break L67914;break};case 40:{c[g+24>>2]=0;c[g+28>>2]=0;break L67914;break};case 41:{c[g+32+((h>>>8&15)<<2)>>2]=c[g+12>>2]&1;break L67914;break};case 42:{c[g+32+((h>>>8&15)<<2)>>2]=c[g+8>>2];break L67914;break};case 43:{s=c[g+92>>2]|0;c[g+96>>2]=s;c[g+100>>2]=c[g+4>>2];k=c[f+2412+(s>>>16<<2)>>2]|0;if(k>>>0>7){a3=c[k+(s&65535)>>2]|0;a4=g;a5=s;a6=f}else{r=gj[c[f+788972+(k<<2)>>2]&4095](s)|0;s=c[2424904]|0;a3=r;a4=s;a5=c[s+92>>2]|0;a6=c[2406668]|0}c[a4+4>>2]=a3;s=a5+4|0;c[a4+92>>2]=s;c[a4+96>>2]=s;r=c[a6+2412+(s>>>16<<2)>>2]|0;if(r>>>0>7){a7=c[r+(s&65535)>>2]|0;a8=a4;a9=s}else{k=gj[c[a6+788972+(r<<2)>>2]&4095](s)|0;s=c[2424904]|0;a7=k;a8=s;a9=c[s+92>>2]|0}c[a8+12>>2]=a7&1011;c[a8+92>>2]=a9+4;s=a8+2400|0;c[s>>2]=(c[s>>2]|0)-3;c[a8+128>>2]=1;break L67914;break};case 44:{s=(c[g+32>>2]|0)+(c[g+32+((h>>>4&15)<<2)>>2]|0)|0;c[g+96>>2]=s;k=c[f+2412+(s>>>16<<2)>>2]|0;if(k>>>0>7){ba=a[k+(s&65535^3)|0]|0;bb=g}else{r=gj[c[f+788844+(k<<2)>>2]&4095](s)|0;ba=r;bb=c[2424904]|0}c[bb+32+((h>>>8&15)<<2)>>2]=ba<<24>>24;break L67914;break};case 45:{r=(c[g+32>>2]|0)+(c[g+32+((h>>>4&15)<<2)>>2]|0)|0;c[g+96>>2]=r;s=c[f+2412+(r>>>16<<2)>>2]|0;if(s>>>0>7){bc=b[s+(r&65535^2)>>1]|0;bd=g}else{k=gj[c[f+788908+(s<<2)>>2]&4095](r)|0;bc=k;bd=c[2424904]|0}c[bd+32+((h>>>8&15)<<2)>>2]=bc<<16>>16;break L67914;break};case 46:{k=(c[g+32>>2]|0)+(c[g+32+((h>>>4&15)<<2)>>2]|0)|0;c[g+96>>2]=k;r=c[f+2412+(k>>>16<<2)>>2]|0;if(r>>>0>7){be=c[r+(k&65535)>>2]|0;bf=g}else{s=gj[c[f+788972+(r<<2)>>2]&4095](k)|0;be=s;bf=c[2424904]|0}c[bf+32+((h>>>8&15)<<2)>>2]=be;break L67914;break};case 47:{ge8(h>>>4&15,h>>>8&15);break L67914;break};case 52:{s=(c[g+32>>2]|0)+(c[g+32+((h>>>8&15)<<2)>>2]|0)|0;c[g+96>>2]=s;k=c[g+32+((h>>>4&15)<<2)>>2]&255;r=c[f+2412+((s>>>16|65536)<<2)>>2]|0;if(r>>>0>7){a[r+(s&65535^3)|0]=k;break L67914}else{gg[c[f+788876+(r<<2)>>2]&4095](s,k);break L67914}break};case 53:{k=(c[g+32>>2]|0)+(c[g+32+((h>>>8&15)<<2)>>2]|0)|0;c[g+96>>2]=k;s=c[g+32+((h>>>4&15)<<2)>>2]&65535;r=c[f+2412+((k>>>16|65536)<<2)>>2]|0;if(r>>>0>7){b[r+(k&65535^2)>>1]=s;break L67914}else{gg[c[f+788940+(r<<2)>>2]&4095](k,s);break L67914}break};case 54:{s=(c[g+32>>2]|0)+(c[g+32+((h>>>8&15)<<2)>>2]|0)|0;c[g+96>>2]=s;k=c[g+32+((h>>>4&15)<<2)>>2]|0;r=c[f+2412+((s>>>16|65536)<<2)>>2]|0;if(r>>>0>7){c[r+(s&65535)>>2]=k;break L67914}else{gg[c[f+789004+(r<<2)>>2]&4095](s,k);break L67914}break};case 55:{c[g+28>>2]=ag(c[g+32+((h>>>4&15)<<2)>>2]|0,c[g+32+((h>>>8&15)<<2)>>2]|0)|0;k=g+2400|0;c[k>>2]=(c[k>>2]|0)-1;break L67914;break};case 60:{k=(c[g+32>>2]|0)+(c[g+32+((h>>>4&15)<<2)>>2]|0)|0;c[g+96>>2]=k;s=c[f+2412+(k>>>16<<2)>>2]|0;if(s>>>0>7){bg=a[s+(k&65535^3)|0]|0;bh=g}else{r=gj[c[f+788844+(s<<2)>>2]&4095](k)|0;bg=r;bh=c[2424904]|0}c[bh+32+((h>>>8&15)<<2)>>2]=bg<<24>>24;break L67914;break};case 61:{r=(c[g+32>>2]|0)+(c[g+32+((h>>>4&15)<<2)>>2]|0)|0;c[g+96>>2]=r;k=c[f+2412+(r>>>16<<2)>>2]|0;if(k>>>0>7){bi=b[k+(r&65535^2)>>1]|0;bj=g}else{s=gj[c[f+788908+(k<<2)>>2]&4095](r)|0;bi=s;bj=c[2424904]|0}c[bj+32+((h>>>8&15)<<2)>>2]=bi<<16>>16;break L67914;break};case 62:{s=(c[g+32>>2]|0)+(c[g+32+((h>>>4&15)<<2)>>2]|0)|0;c[g+96>>2]=s;r=c[f+2412+(s>>>16<<2)>>2]|0;if(r>>>0>7){bk=c[r+(s&65535)>>2]|0;bl=g}else{k=gj[c[f+788972+(r<<2)>>2]&4095](s)|0;bk=k;bl=c[2424904]|0}c[bl+32+((h>>>8&15)<<2)>>2]=bk;break L67914;break};case 63:{ge8(h>>>4&15,h>>>8&15);break L67914;break};case 4:{k=(c[g+32>>2]|0)+(c[g+32+((h>>>8&15)<<2)>>2]|0)|0;c[g+96>>2]=k;s=c[g+32+((h>>>4&15)<<2)>>2]&255;r=c[f+2412+((k>>>16|65536)<<2)>>2]|0;if(r>>>0>7){a[r+(k&65535^3)|0]=s;break L67914}else{gg[c[f+788876+(r<<2)>>2]&4095](k,s);break L67914}break};case 2:{c[g+32+((h>>>8&15)<<2)>>2]=c[g+12>>2];break L67914;break};case 11:{s=g+4|0;c[g+100>>2]=c[s>>2];k=c[g+8>>2]|0;c[g+96>>2]=k;c[s>>2]=k;k=g+2400|0;c[k>>2]=(c[k>>2]|0)-1;break L67914;break};case 13:{k=(c[g+32>>2]|0)+(c[g+32+((h>>>4&15)<<2)>>2]|0)|0;c[g+96>>2]=k;s=c[f+2412+(k>>>16<<2)>>2]|0;if(s>>>0>7){bm=b[s+(k&65535^2)>>1]|0;bn=g}else{r=gj[c[f+788908+(s<<2)>>2]&4095](k)|0;bm=r;bn=c[2424904]|0}c[bn+32+((h>>>8&15)<<2)>>2]=bm<<16>>16;break L67914;break};case 3:{r=g+4|0;k=c[r>>2]|0;c[g+8>>2]=k+2;c[g+100>>2]=k;c[r>>2]=(c[g+32+((h>>>8&15)<<2)>>2]|0)+2+k;k=g+2400|0;c[k>>2]=(c[k>>2]|0)-1;break L67914;break};case 7:{c[g+28>>2]=ag(c[g+32+((h>>>4&15)<<2)>>2]|0,c[g+32+((h>>>8&15)<<2)>>2]|0)|0;k=g+2400|0;c[k>>2]=(c[k>>2]|0)-1;break L67914;break};default:{break L67914}}}}while(0);h=c[2424904]|0;do{if((c[h+128>>2]|0)==0){bo=h}else{if((c[h+100>>2]|0)!=0){bo=h;break}f=c[h+124>>2]|0;n=(f&32768|0)==0?(f&16384|0)==0?(f&8192|0)==0?(f&4096|0)==0?(f&2048|0)==0?(f&1024|0)==0?(f&512|0)==0?(f&256|0)==0?(f&128|0)==0?(f&64|0)==0?(f&32|0)==0?(f&16|0)==0?(f&8|0)==0?(f&4|0)==0?(f&2|0)==0?(f&1)-1|0:1:2:3:4:5:6:7:8:9:10:11:12:13:14:15;f=c[h+2348>>2]|0;i=(f|0)!=-1&(f|0)>(n|0)?f:n;if((i|0)>-1){ge_(i);bp=c[2424904]|0}else{bp=h}c[bp+128>>2]=0;bo=bp}}while(0);h=bo+2404|0;c[h>>2]=(c[h>>2]|0)+1;h=bo+2400|0;i=(c[h>>2]|0)-1|0;c[h>>2]=i;n=bo+2392|0;f=bo+2396|0;k=(c[f>>2]|0)+(c[n>>2]|0)-i|0;i=bo+2384|0;do{if((c[i>>2]|0)!=0){if((k-(c[bo+2376>>2]|0)|0)>>>0<(c[bo+2368>>2]|0)>>>0){break}r=bo+676|0;c[r>>2]=c[r>>2]|2;c[i>>2]=0;ge5()}}while(0);i=bo+2388|0;do{if((c[i>>2]|0)!=0){if((k-(c[bo+2380>>2]|0)|0)>>>0<(c[bo+2372>>2]|0)>>>0){break}r=bo+692|0;c[r>>2]=c[r>>2]|2;c[i>>2]=0;ge5()}}while(0);do{if((c[bo+2364>>2]|0)!=0){if((k-(c[bo+2360>>2]|0)|0)>>>0<(c[bo+2356>>2]|0)>>>0){break}i=(c[bo+300>>2]|0)>>>8&3;r=(c[f>>2]|0)+(c[n>>2]|0)-(c[h>>2]|0)|0;if((i|0)==3){bq=b[bo+2330>>1]|0;br=bo+2340|0}else{s=bo+2340|0;u=bo+2330|0;t=(e[u>>1]|0)+((r-(c[s>>2]|0)|0)>>>((c[669696+(i<<2)>>2]|0)>>>0))&65535;b[u>>1]=t;bq=t;br=s}c[br>>2]=r;r=bo+2330|0;if(bq<<16>>16==(b[bo+2334>>1]|0)){s=bo+296|0;c[s>>2]=c[s>>2]|262144}if(bq<<16>>16==0){s=bo+296|0;c[s>>2]=c[s>>2]|131072}do{if(bq<<16>>16==(b[bo+2332>>1]|0)){s=bo+296|0;t=c[s>>2]|0;c[s>>2]=t|524288;if((t&65536|0)==0){break}b[r>>1]=0}}while(0);ge5();ge6()}}while(0);n=c[h>>2]|0;if((n|0)>0){g=bo}else{bs=n;bt=bo;bu=55628;break}}if((bu|0)==55628){bv=d-bs|0;bw=bt+2392|0;bx=c[bw>>2]|0;by=bv+bx|0;c[bw>>2]=by;bz=bt+2400|0;bA=c[bz>>2]|0;bB=bt+2396|0;c[bB>>2]=bA;bC=d-bA|0;return bC|0}bu=g+2404|0;c[bu>>2]=(c[bu>>2]|0)+d;c[g+2400>>2]=0;bs=0;bt=g;bv=d-bs|0;bw=bt+2392|0;bx=c[bw>>2]|0;by=bv+bx|0;c[bw>>2]=by;bz=bt+2400|0;bA=c[bz>>2]|0;bB=bt+2396|0;c[bB>>2]=bA;bC=d-bA|0;return bC|0}function ge_(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=c[2424904]|0;d=c[b+12>>2]|0;do{if((a|0)==16){e=11;f=d}else{if((d>>>4&15|0)>=(a|0)){return}if((c[b+2348>>2]|0)==(a|0)){e=c[b+2352>>2]|0;f=d;break}else{e=((a|0)/2|0)+64|0;f=d;break}}}while(0);d=b+92|0;g=(c[d>>2]|0)-4|0;c[d>>2]=g;d=c[2406668]|0;h=c[d+2412+((g>>>16|65536)<<2)>>2]|0;if(h>>>0>7){c[h+(g&65535)>>2]=f;i=b;j=d}else{gg[c[d+789004+(h<<2)>>2]&4095](g,f);i=c[2424904]|0;j=c[2406668]|0}f=i+92|0;g=(c[f>>2]|0)-4|0;c[f>>2]=g;f=c[i+4>>2]|0;h=c[j+2412+((g>>>16|65536)<<2)>>2]|0;if(h>>>0>7){c[h+(g&65535)>>2]=f;k=i}else{gg[c[j+789004+(h<<2)>>2]&4095](g,f);k=c[2424904]|0}f=k+12|0;g=c[f>>2]|0;if((a|0)>15){l=g|240}else{l=g&-241|a<<4}c[f>>2]=l;l=(c[k+20>>2]|0)+(e<<2)|0;e=c[2406668]|0;f=c[e+2412+(l>>>16<<2)>>2]|0;if(f>>>0>7){m=c[f+(l&65535)>>2]|0;n=k;o=e}else{k=gj[c[e+788972+(f<<2)>>2]&4095](l)|0;m=k;n=c[2424904]|0;o=c[2406668]|0}k=n+4|0;n=m&-939524097;c[k>>2]=n;m=c[o+2412+((n>>>16|131072)<<2)>>2]|0;n=o+789036|0;c[n>>2]=m;c[n>>2]=m+(-(c[k>>2]&-65536)|0);return}function ge$(b){b=b|0;var d=0,e=0,f=0,g=0;d=c[2424904]|0;e=d+260+b|0;if((a[e]|0)==1){return}a[e]=1;e=d+124|0;f=c[e>>2]|1<<b;c[e>>2]=f;do{if((c[d+100>>2]|0)==0){e=(f&32768|0)==0?(f&16384|0)==0?(f&8192|0)==0?(f&4096|0)==0?(f&2048|0)==0?(f&1024|0)==0?(f&512|0)==0?(f&256|0)==0?(f&128|0)==0?(f&64|0)==0?(f&32|0)==0?(f&16|0)==0?(f&8|0)==0?(f&4|0)==0?(f&2|0)==0?(f&1)-1|0:1:2:3:4:5:6:7:8:9:10:11:12:13:14:15;b=c[d+2348>>2]|0;g=(b|0)!=-1&(b|0)>(e|0)?b:e;if((g|0)<=-1){break}ge_(g)}else{c[d+128>>2]=1}}while(0);c[(c[2406668]|0)+789040>>2]=0;return}function ge0(){var a=0,b=0,d=0;a=c[2424904]|0;b=a+2400|0;d=a+2404|0;c[d>>2]=(c[d>>2]|0)+(c[b>>2]|0);c[b>>2]=0;c[a+2396>>2]=0;return}function ge1(){return c[(c[2424904]|0)+2404>>2]|0}function ge2(){c[(c[2424904]|0)+2404>>2]=0;return}function ge3(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0;a=c[2406668]|0;b=c[a+2412>>2]|0;if(b>>>0>7){d=c[b>>2]|0;e=a;f=b}else{g=gj[c[a+788972+(b<<2)>>2]&4095](0)|0;b=c[2406668]|0;d=g;e=b;f=c[b+2412>>2]|0}if(f>>>0>7){h=c[f+4>>2]|0;i=e}else{b=gj[c[e+788972+(f<<2)>>2]&4095](4)|0;h=b;i=c[2406668]|0}b=c[2424904]|0;gGz(b|0,0,2408);f=b+4|0;c[b+92>>2]=h;c[b+12>>2]=240;h=d&-939524097;c[f>>2]=h;d=c[i+2412+((h>>>16|131072)<<2)>>2]|0;h=i+789036|0;c[h>>2]=d;c[h>>2]=d+(-(c[f>>2]&-65536)|0);c[b+2348>>2]=-1;return}function ge4(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0;d=i;i=i+56|0;e=d|0;f=d+16|0;g=d+32|0;h=d+48|0;if((b&64|0)==0){i=d;return}j=h|0;a[j]=a[614888]|0;a[j+1|0]=a[614889]|0;a[j+2|0]=a[614890]|0;a[j+3|0]=a[614891]|0;a[j+4|0]=a[614892]|0;a[j+5|0]=a[614893]|0;a[j+6|0]=a[614894]|0;a[h+5|0]=49;h=c[2411230]|0;gGz(g|0,0,12);c[g>>2]=h;c[g+4>>2]=2408;c[g+12>>2]=j;gj[c[2076592]&4095](g)|0;g=(c[2411230]|0)+789040|0;gGz(f|0,0,12);c[f>>2]=g;c[f+4>>2]=4;c[f+12>>2]=162128;gj[c[2076592]&4095](f)|0;f=(c[2411230]|0)+789036|0;gGz(e|0,0,12);c[e>>2]=f;c[e+4>>2]=4;c[e+12>>2]=500520;gj[c[2076592]&4095](e)|0;if((b&2|0)==0){i=d;return}b=(c[2424904]|0)+4|0;e=c[b>>2]&-939524097;c[b>>2]=e;f=c[2406668]|0;g=c[f+2412+((e>>>16|131072)<<2)>>2]|0;e=f+789036|0;c[e>>2]=g;c[e>>2]=g+(-(c[b>>2]&-65536)|0);i=d;return}function ge5(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a=c[2424904]|0;b=c[a+296>>2]|0;d=b>>>8&b;do{if((d&9306112|0)==0){e=0;f=-1}else{b=(c[a+376>>2]|0)>>>24&15;if((b|0)==0){e=0;f=-1;break}if((d&8388608|0)!=0){e=b;f=(c[a+380>>2]|0)>>>8&127;break}if((d&786432|0)==0){e=b;f=(c[a+384>>2]|0)>>>24&127;break}else{e=b;f=c[a+380>>2]&127;break}}}while(0);do{if((c[a+676>>2]&6|0)==6){d=(c[a+504>>2]|0)>>>8&15;if(d>>>0<=e>>>0){g=e;h=f;break}g=d;h=(c[a+696>>2]|0)>>>24&127}else{g=e;h=f}}while(0);do{if((c[a+692>>2]&6|0)==6){f=(c[a+504>>2]|0)>>>8&15;if((f|0)<=(g|0)){i=g;j=h;break}i=f;j=(c[a+704>>2]|0)>>>24&127}else{i=g;j=h}}while(0);c[a+2348>>2]=i;c[a+2352>>2]=j;c[a+128>>2]=1;return}function ge6(){var a=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[2424904]|0;d=a+2364|0;c[d>>2]=0;f=b[a+2330>>1]|0;g=c[a+296>>2]|0;if((g&524288|0)==0){h=(b[a+2332>>1]|0)-f&65535}else{h=1048575}do{if((g&262144|0)==0){i=b[a+2334>>1]|0;if((e[a+2332>>1]|0)>(i&65535)){if((g&65536|0)!=0){j=h;break}}k=i-f&65535;j=k>>>0<h>>>0?k:h}else{j=h}}while(0);if((g&196608|0)==0){g=65536-(f&65535)|0;l=(g|0)<(j|0)?g:j}else{l=j}if((l|0)==1048575){return}j=(c[a+300>>2]|0)>>>8&3;if((j|0)==3){return}g=l<<c[669696+(j<<2)>>2];j=(c[a+2396>>2]|0)+(c[a+2392>>2]|0)-(c[a+2400>>2]|0)|0;c[a+2340>>2]=j;c[d>>2]=1;c[a+2356>>2]=g;c[a+2360>>2]=j;return}function ge7(a,d){a=a|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=c[2424904]|0;f=c[e+32+(d<<2)>>2]|0;g=c[2406668]|0;h=c[g+2412+(f>>>16<<2)>>2]|0;if(h>>>0>7){i=b[h+(f&65535^2)>>1]|0;j=e;k=f;l=g}else{e=gj[c[g+788908+(h<<2)>>2]&4095](f)|0;f=c[2424904]|0;i=e;j=f;k=c[f+32+(d<<2)>>2]|0;l=c[2406668]|0}c[j+32+(d<<2)>>2]=k+2;k=c[j+32+(a<<2)>>2]|0;d=c[l+2412+(k>>>16<<2)>>2]|0;if(d>>>0>7){m=b[d+(k&65535^2)>>1]|0;n=j;o=k}else{j=gj[c[l+788908+(d<<2)>>2]&4095](k)|0;k=c[2424904]|0;m=j;n=k;o=c[k+32+(a<<2)>>2]|0}c[n+32+(a<<2)>>2]=o+2;o=n+28|0;a=c[o>>2]|0;k=ag(m<<16>>16,i<<16>>16)|0;i=a>>>31;m=i+(k>>>31)|0;j=cJ(a|0,k|0)|0;a=j;c[o>>2]=a;do{if((c[n+12>>2]&2|0)==0){j=n+24|0;d=(c[j>>2]|0)+(k>>31)|0;c[j>>2]=d;if(!K){break}c[j>>2]=d+1}else{if(((a>>>31)+i|0)!=1){break}if((m|0)==2){c[o>>2]=-2147483648;break}else if((m|0)==0){c[o>>2]=2147483647;break}else{break}}}while(0);o=n+2400|0;c[o>>2]=(c[o>>2]|0)-2;return}function ge8(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;d=c[2424904]|0;e=c[d+32+(b<<2)>>2]|0;f=c[2406668]|0;g=c[f+2412+(e>>>16<<2)>>2]|0;if(g>>>0>7){h=c[g+(e&65535)>>2]|0;i=d;j=e;k=f}else{d=gj[c[f+788972+(g<<2)>>2]&4095](e)|0;e=c[2424904]|0;h=d;i=e;j=c[e+32+(b<<2)>>2]|0;k=c[2406668]|0}c[i+32+(b<<2)>>2]=j+4;j=c[i+32+(a<<2)>>2]|0;b=c[k+2412+(j>>>16<<2)>>2]|0;if(b>>>0>7){l=c[b+(j&65535)>>2]|0;m=i;n=j}else{i=gj[c[k+788972+(b<<2)>>2]&4095](j)|0;j=c[2424904]|0;l=i;m=j;n=c[j+32+(a<<2)>>2]|0}c[m+32+(a<<2)>>2]=n+4;n=(h|0)<0?-h|0:h;a=(l|0)<0?-l|0:l;j=n&65535;i=n>>>16;n=a&65535;b=a>>>16;a=ag(n,j)|0;k=ag(b,j)|0;j=ag(n,i)|0;n=ag(b,i)|0;i=cJ(k|0,j|0)|0;j=i;i=K?65536:0;k=cJ(a|0,j<<16|0)|0;a=k;k=n+(j>>>16)+(K&1|i)|0;do{if((l^h|0)<0){if((a|0)==0){o=0;p=-k|0;break}else{o=-a|0;p=~k;break}}else{o=a;p=k}}while(0);k=(c[m+12>>2]&2|0)==0;a=m+28|0;h=cJ(c[a>>2]|0,o|0)|0;o=h;h=(K&1)+p|0;p=m+24|0;l=c[p>>2]|0;if(k){q=o;r=h+l|0;c[p>>2]=r;c[a>>2]=q;s=m+2400|0;t=c[s>>2]|0;u=t-2|0;c[s>>2]=u;return}k=h+(l&65535)|0;if((k|0)<0&k>>>0<4294934528){q=0;r=32768;c[p>>2]=r;c[a>>2]=q;s=m+2400|0;t=c[s>>2]|0;u=t-2|0;c[s>>2]=u;return}l=(k|0)>0&k>>>0>32767;q=l?-1:o;r=l?32767:k;c[p>>2]=r;c[a>>2]=q;s=m+2400|0;t=c[s>>2]|0;u=t-2|0;c[s>>2]=u;return}function ge9(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=a<<2;d=c[2424904]|0;e=c[d+280+(b+99<<2)>>2]|0;f=d+2384+(a<<2)|0;g=(c[f>>2]|0)!=0;if((e&1&c[d+712>>2]|0)==0){if(!g){return}c[f>>2]=0;return}if(g){return}if((e&2|0)!=0){return}g=e>>>14&3;h=e>>>12&3;if((g|0)==3|(h|0)==3){return}i=e>>>10&3;e=c[d+280+(b+96<<2)>>2]|0;j=c[d+280+(b+97<<2)>>2]|0;k=c[d+280+(b+98<<2)>>2]|0;b=(k|0)==0?16777216:k;c[f>>2]=1;c[d+2368+(a<<2)>>2]=b<<1|1;c[d+2376+(a<<2)>>2]=(c[d+2396>>2]|0)+(c[d+2392>>2]|0)-(c[d+2400>>2]|0);if((i|0)==2){d=(h|0)==2;a=(g|0)==2;f=(h|0)==1;h=(g|0)==1;g=e&-939524100;e=j&-939524100;j=b;while(1){k=d?g-4|0:g;l=a?e-4|0:e;m=c[2406668]|0;n=c[m+2412+(k>>>16<<2)>>2]|0;if(n>>>0>7){o=c[n+(k&65535)>>2]|0;p=m}else{q=gj[c[m+788972+(n<<2)>>2]&4095](k)|0;o=q;p=c[2406668]|0}q=c[p+2412+((l>>>16|65536)<<2)>>2]|0;if(q>>>0>7){c[q+(l&65535)>>2]=o}else{gg[c[p+789004+(q<<2)>>2]&4095](l,o)}q=j-1|0;if((q|0)==0){break}g=f?k+4|0:k;e=h?l+4|0:l;j=q}return}else if((i|0)==3){i=b&-4;if((i|0)==0){return}else{r=i}do{r=r-4|0;}while((r|0)!=0);return}else{return}}function gfa(b){b=b|0;var d=0,e=0,f=0;d=c[2406668]|0;e=c[d+2412+(b>>>16<<2)>>2]|0;if(e>>>0>7){f=a[e+(b&65535^3)|0]|0;return f|0}else{f=gj[c[d+788844+(e<<2)>>2]&4095](b)|0;return f|0}return 0}function gfb(b,d){b=b|0;d=d|0;var e=0,f=0;e=c[2406668]|0;f=c[e+2412+((b>>>16|65536)<<2)>>2]|0;if(f>>>0>7){a[f+(b&65535^3)|0]=d;return}else{gg[c[e+788876+(f<<2)>>2]&4095](b,d);return}}function gfc(e){e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0,cf=0,cg=0,ch=0,ci=0,cj=0,ck=0,cl=0,cm=0,cn=0,co=0,cp=0,cq=0,cr=0,cs=0,ct=0,cu=0,cv=0,cw=0,cx=0,cy=0,cz=0,cA=0,cB=0,cC=0,cD=0,cE=0,cF=0,cG=0,cH=0,cI=0,cJ=0,cK=0,cL=0,cM=0,cN=0,cO=0,cP=0,cQ=0,cR=0,cS=0,cT=0,cU=0,cV=0,cW=0,cX=0,cY=0,cZ=0,c_=0,c$=0,c0=0,c1=0,c2=0,c3=0,c4=0,c5=0,c6=0,c7=0,c8=0,c9=0,da=0,db=0,dc=0,dd=0,de=0,df=0,dg=0,dh=0,di=0,dj=0,dk=0,dl=0,dm=0,dn=0,dp=0,dq=0,dr=0,ds=0,dt=0,du=0,dv=0,dw=0,dx=0,dy=0,dz=0,dA=0,dB=0,dC=0,dD=0,dE=0,dF=0,dG=0;c[2076596]=e;c[2426530]=e;if((a[9706116]|0)==0){f=e}else{c[2426514]=-1;if((a[9706112]|0)==0){g=a[9706060]|0}else{a[9706112]=0;h=(b[4853030]|0)+1&65535;b[4853030]=h;g=h&255}a[9706110]=0;b[4853032]=(b[4853032]|0)-2&65535;h=c[2426516]|0;i=c[9757320+(c[1836236]<<2)>>2]|0;j=c[i+76+((h>>>8|256)<<2)>>2]|0;do{if((j|0)==0){k=c[i+4184>>2]|0;if((k|0)==0){l=i;break}gg[k&4095](h&65535,g);l=c[9757320+(c[1836236]<<2)>>2]|0}else{a[j+(h&255)|0]=g;l=i}}while(0);i=h+1|0;h=a[9706061]|0;g=c[l+76+((i>>>8&255|256)<<2)>>2]|0;do{if((g|0)==0){j=c[l+4184>>2]|0;if((j|0)==0){break}gg[j&4095](i&65535,h)}else{a[g+(i&255)|0]=h}}while(0);c[2426515]=102;b[4853030]=102;h=(c[2076596]|0)-11|0;c[2076596]=h;a[9706116]=0;f=h}L68713:while(1){if((a[9706110]|0)==0|(a[9706117]|0)==0|(a[9706118]|0)!=0){m=f}else{h=d[14125144]|0;a[14125144]=0;c[2426514]=-1;if((a[9706112]|0)!=0){a[9706112]=0;b[4853030]=(b[4853030]|0)+1&65535}a[9706111]=0;a[9706110]=0;i=a[9706113]|0;if((i<<24>>24|0)==2){g=d[9706114]|0;l=g<<8|h;b[4853032]=(b[4853032]|0)-2&65535;j=c[2426516]|0;k=a[9706060]|0;n=c[9757320+(c[1836236]<<2)>>2]|0;o=c[n+76+((j>>>8|256)<<2)>>2]|0;do{if((o|0)==0){p=c[n+4184>>2]|0;if((p|0)==0){q=n;break}gg[p&4095](j&65535,k);q=c[9757320+(c[1836236]<<2)>>2]|0}else{a[o+(j&255)|0]=k;q=n}}while(0);n=j+1|0;k=a[9706061]|0;o=c[q+76+((n>>>8&255|256)<<2)>>2]|0;do{if((o|0)==0){p=c[q+4184>>2]|0;if((p|0)==0){r=q;break}gg[p&4095](n&65535,k);r=c[9757320+(c[1836236]<<2)>>2]|0}else{a[o+(n&255)|0]=k;r=q}}while(0);k=c[r+76+(g<<2)>>2]|0;do{if((k|0)==0){n=c[r+4180>>2]|0;if((n|0)==0){s=0;t=r;break}o=gj[n&4095](l&65535)|0;s=o;t=c[9757320+(c[1836236]<<2)>>2]|0}else{s=a[k+h|0]|0;t=r}}while(0);a[9706060]=s;k=l+1|0;g=c[t+76+((k>>>8&255)<<2)>>2]|0;do{if((g|0)==0){o=c[t+4180>>2]|0;if((o|0)==0){u=0;break}u=gj[o&4095](k&65535)|0}else{u=a[g+(k&255)|0]|0}}while(0);a[9706061]=u;k=(c[2076596]|0)-17|0;c[2076596]=k;v=c[2426515]&65535;w=k}else if((i<<24>>24|0)==1){b[4853032]=(b[4853032]|0)-2&65535;k=c[2426516]|0;g=a[9706060]|0;l=c[9757320+(c[1836236]<<2)>>2]|0;o=c[l+76+((k>>>8|256)<<2)>>2]|0;do{if((o|0)==0){n=c[l+4184>>2]|0;if((n|0)==0){x=l;break}gg[n&4095](k&65535,g);x=c[9757320+(c[1836236]<<2)>>2]|0}else{a[o+(k&255)|0]=g;x=l}}while(0);l=k+1|0;g=a[9706061]|0;o=c[x+76+((l>>>8&255|256)<<2)>>2]|0;do{if((o|0)==0){i=c[x+4184>>2]|0;if((i|0)==0){break}gg[i&4095](l&65535,g)}else{a[o+(l&255)|0]=g}}while(0);c[2426515]=56;g=(c[2076596]|0)-13|0;c[2076596]=g;v=56;w=g}else{b[4853032]=(b[4853032]|0)-2&65535;g=c[2426516]|0;l=a[9706060]|0;o=c[9757320+(c[1836236]<<2)>>2]|0;k=c[o+76+((g>>>8|256)<<2)>>2]|0;do{if((k|0)==0){i=c[o+4184>>2]|0;if((i|0)==0){y=o;break}gg[i&4095](g&65535,l);y=c[9757320+(c[1836236]<<2)>>2]|0}else{a[k+(g&255)|0]=l;y=o}}while(0);o=g+1|0;l=a[9706061]|0;k=c[y+76+((o>>>8&255|256)<<2)>>2]|0;do{if((k|0)==0){i=c[y+4184>>2]|0;if((i|0)==0){break}gg[i&4095](o&65535,l)}else{a[k+(o&255)|0]=l}}while(0);l=h&56;c[2426515]=l;o=(c[2076596]|0)-((d[(c[2426874]|0)+l|0]|0)+(d[(c[2426884]|0)+l|0]|0))|0;c[2076596]=o;v=l&65535;w=o}b[4853030]=v;m=w}a[9706118]=0;o=c[2426515]|0;c[2426514]=o;a[9706108]=(a[9706108]|0)+1&255;l=o&65535;b[4853030]=l+1&65535;k=c[9757320+(c[1836236]<<2)>>2]|0;g=c[k+76+((o>>>8|512)<<2)>>2]|0;do{if((g|0)==0){i=c[k+4180>>2]|0;if((i|0)==0){z=0;A=m;break}n=gj[i&4095](l)|0;z=n;A=c[2076596]|0}else{z=a[g+(o&255)|0]|0;A=m}}while(0);o=z&255;g=A-(d[(c[2426884]|0)+o|0]|0)|0;c[2076596]=g;L68771:do{switch(o|0){case 229:{b[4853032]=(b[4853032]|0)-2&65535;l=c[2426516]|0;k=a[9706080]|0;h=c[9757320+(c[1836236]<<2)>>2]|0;n=c[h+76+((l>>>8|256)<<2)>>2]|0;do{if((n|0)==0){i=c[h+4184>>2]|0;if((i|0)==0){B=h;break}gg[i&4095](l&65535,k);B=c[9757320+(c[1836236]<<2)>>2]|0}else{a[n+(l&255)|0]=k;B=h}}while(0);h=l+1|0;k=a[9706081]|0;n=c[B+76+((h>>>8&255|256)<<2)>>2]|0;if((n|0)!=0){a[n+(h&255)|0]=k;C=56882;break L68771}n=c[B+4184>>2]|0;if((n|0)==0){C=56882;break L68771}gg[n&4095](h&65535,k);C=56882;break};case 230:{k=c[2426515]|0;h=k&65535;b[4853030]=h+1&65535;n=c[9757320+(c[1836236]<<2)>>2]|0;i=c[n+76+((k>>>8|768)<<2)>>2]|0;do{if((i|0)==0){j=c[n+4180>>2]|0;if((j|0)==0){D=0;break}D=gj[j&4095](h)|0}else{D=a[i+(k&255)|0]|0}}while(0);k=a[9706069]&D;a[9706069]=k;a[9706068]=a[9706144+(k&255)|0]|16;C=56882;break};case 203:{a[9706108]=(a[9706108]|0)+1&255;k=c[2426515]|0;i=k&65535;b[4853030]=i+1&65535;h=c[9757320+(c[1836236]<<2)>>2]|0;n=c[h+76+((k>>>8|512)<<2)>>2]|0;do{if((n|0)==0){l=c[h+4180>>2]|0;if((l|0)==0){E=0;F=g;break}j=gj[l&4095](i)|0;E=j;F=c[2076596]|0}else{E=a[n+(k&255)|0]|0;F=g}}while(0);k=E&255;c[2076596]=F-(d[(c[2426882]|0)+k|0]|0);gu[c[677920+(k<<2)>>2]&16383]();C=56882;break};case 33:{k=c[2426515]|0;n=k&65535;b[4853030]=n+2&65535;i=c[9757320+(c[1836236]<<2)>>2]|0;h=c[i+76+((k>>>8|768)<<2)>>2]|0;do{if((h|0)==0){j=c[i+4180>>2]|0;if((j|0)==0){G=0;H=i;break}l=gj[j&4095](n)|0;G=l;H=c[9757320+(c[1836236]<<2)>>2]|0}else{G=a[h+(k&255)|0]|0;H=i}}while(0);i=G&255;h=k+1|0;n=c[H+76+((h>>>8&255|768)<<2)>>2]|0;do{if((n|0)==0){l=c[H+4180>>2]|0;if((l|0)==0){I=0;break}I=gj[l&4095](h&65535)|0}else{I=a[n+(h&255)|0]|0}}while(0);b[4853040]=(I&255)<<8|i;C=56882;break};case 30:{h=c[2426515]|0;n=h&65535;b[4853030]=n+1&65535;k=c[9757320+(c[1836236]<<2)>>2]|0;l=c[k+76+((h>>>8|768)<<2)>>2]|0;do{if((l|0)==0){j=c[k+4180>>2]|0;if((j|0)==0){J=0;break}J=gj[j&4095](n)|0}else{J=a[l+(h&255)|0]|0}}while(0);a[9706076]=J;C=56882;break};case 99:{a[9706081]=a[9706076]|0;C=56882;break};case 101:{a[9706081]=a[9706080]|0;C=56882;break};case 102:{h=b[4853040]|0;l=h&65535;n=c[9757320+(c[1836236]<<2)>>2]|0;k=c[n+76+(l>>>8<<2)>>2]|0;do{if((k|0)==0){i=c[n+4180>>2]|0;if((i|0)==0){K=0;break}K=gj[i&4095](h)|0}else{K=a[k+(l&255)|0]|0}}while(0);a[9706081]=K;C=56882;break};case 32:{if((a[9706068]&64)==0){l=c[2426515]|0;k=l&65535;h=k+1&65535;b[4853030]=h;n=c[9757320+(c[1836236]<<2)>>2]|0;i=c[n+76+((l>>>8|768)<<2)>>2]|0;do{if((i|0)==0){j=c[n+4180>>2]|0;if((j|0)==0){L=0;M=h;N=g;break}p=gj[j&4095](k)|0;L=p;M=b[4853030]|0;N=c[2076596]|0}else{L=a[i+(l&255)|0]|0;M=h;N=g}}while(0);b[4853030]=M+(L<<24>>24)&65535;c[2076596]=N-5;O=c[2426515]&65535}else{O=(b[4853030]|0)+1&65535}b[4853030]=O;C=56882;break};case 4:{h=(a[9706073]|0)+1&255;a[9706068]=a[9706068]&1|a[9621712+(h&255)|0];a[9706073]=h;C=56882;break};case 79:{a[9706072]=a[9706069]|0;C=56882;break};case 80:{a[9706077]=a[9706073]|0;C=56882;break};case 81:{a[9706077]=a[9706072]|0;C=56882;break};case 83:{a[9706077]=a[9706076]|0;C=56882;break};case 84:{a[9706077]=a[9706081]|0;C=56882;break};case 85:{a[9706077]=a[9706080]|0;C=56882;break};case 111:{a[9706080]=a[9706069]|0;C=56882;break};case 112:{h=b[4853040]|0;l=h&65535;i=a[9706073]|0;k=c[9757320+(c[1836236]<<2)>>2]|0;n=c[k+76+((l>>>8|256)<<2)>>2]|0;if((n|0)!=0){a[n+(l&255)|0]=i;C=56882;break L68771}l=c[k+4184>>2]|0;if((l|0)==0){C=56882;break L68771}gg[l&4095](h,i);C=56882;break};case 115:{i=b[4853040]|0;h=i&65535;l=a[9706076]|0;k=c[9757320+(c[1836236]<<2)>>2]|0;n=c[k+76+((h>>>8|256)<<2)>>2]|0;if((n|0)!=0){a[n+(h&255)|0]=l;C=56882;break L68771}h=c[k+4184>>2]|0;if((h|0)==0){C=56882;break L68771}gg[h&4095](i,l);C=56882;break};case 158:{l=c[2426517]|0;i=l&65280;h=l&1;l=i>>>8;k=b[4853040]|0;n=k&65535;p=c[9757320+(c[1836236]<<2)>>2]|0;j=c[p+76+(n>>>8<<2)>>2]|0;do{if((j|0)==0){P=c[p+4180>>2]|0;if((P|0)==0){Q=0;break}Q=gj[P&4095](k)|0}else{Q=a[j+(n&255)|0]|0}}while(0);n=l-(Q&255)-h|0;a[9706068]=a[(c[2385738]|0)+(h<<16|i|n&255)|0]|0;a[9706069]=n&255;C=56882;break};case 166:{n=b[4853040]|0;j=n&65535;k=c[9757320+(c[1836236]<<2)>>2]|0;p=c[k+76+(j>>>8<<2)>>2]|0;do{if((p|0)==0){P=c[k+4180>>2]|0;if((P|0)==0){R=0;break}R=gj[P&4095](n)|0}else{R=a[p+(j&255)|0]|0}}while(0);j=a[9706069]&R;a[9706069]=j;a[9706068]=a[9706144+(j&255)|0]|16;C=56882;break};case 156:{j=c[2426517]|0;p=j&65280;n=j&1;j=(p>>>8)-(d[9706081]|0)-n|0;a[9706068]=a[(c[2385738]|0)+(n<<16|p|j&255)|0]|0;a[9706069]=j&255;C=56882;break};case 216:{if((a[9706068]&1)==0){C=56882;break L68771}j=c[2426516]|0;p=c[9757320+(c[1836236]<<2)>>2]|0;n=c[p+76+(j>>>8<<2)>>2]|0;do{if((n|0)==0){k=c[p+4180>>2]|0;if((k|0)==0){S=0;T=p;break}i=gj[k&4095](j&65535)|0;S=i;T=c[9757320+(c[1836236]<<2)>>2]|0}else{S=a[n+(j&255)|0]|0;T=p}}while(0);a[9706060]=S;p=j+1|0;n=c[T+76+((p>>>8&255)<<2)>>2]|0;do{if((n|0)==0){i=c[T+4180>>2]|0;if((i|0)==0){U=0;break}U=gj[i&4095](p&65535)|0}else{U=a[n+(p&255)|0]|0}}while(0);a[9706061]=U;b[4853032]=(b[4853032]|0)+2&65535;b[4853030]=c[2426515]&65535;p=(c[2076596]|0)-6|0;c[2076596]=p;V=p;break};case 37:{p=(a[9706081]|0)-1&255;a[9706068]=a[9706068]&1|a[9621968+(p&255)|0];a[9706081]=p;C=56882;break};case 38:{p=c[2426515]|0;n=p&65535;b[4853030]=n+1&65535;j=c[9757320+(c[1836236]<<2)>>2]|0;i=c[j+76+((p>>>8|768)<<2)>>2]|0;do{if((i|0)==0){k=c[j+4180>>2]|0;if((k|0)==0){W=0;break}W=gj[k&4095](n)|0}else{W=a[i+(p&255)|0]|0}}while(0);a[9706081]=W;C=56882;break};case 240:{if((a[9706068]|0)<0){C=56882;break L68771}p=c[2426516]|0;i=c[9757320+(c[1836236]<<2)>>2]|0;n=c[i+76+(p>>>8<<2)>>2]|0;do{if((n|0)==0){j=c[i+4180>>2]|0;if((j|0)==0){X=0;Y=i;break}k=gj[j&4095](p&65535)|0;X=k;Y=c[9757320+(c[1836236]<<2)>>2]|0}else{X=a[n+(p&255)|0]|0;Y=i}}while(0);a[9706060]=X;i=p+1|0;n=c[Y+76+((i>>>8&255)<<2)>>2]|0;do{if((n|0)==0){k=c[Y+4180>>2]|0;if((k|0)==0){Z=0;break}Z=gj[k&4095](i&65535)|0}else{Z=a[n+(i&255)|0]|0}}while(0);a[9706061]=Z;b[4853032]=(b[4853032]|0)+2&65535;b[4853030]=c[2426515]&65535;i=(c[2076596]|0)-6|0;c[2076596]=i;V=i;break};case 241:{i=c[2426516]|0;n=c[9757320+(c[1836236]<<2)>>2]|0;p=c[n+76+(i>>>8<<2)>>2]|0;do{if((p|0)==0){k=c[n+4180>>2]|0;if((k|0)==0){_=0;$=n;break}j=gj[k&4095](i&65535)|0;_=j;$=c[9757320+(c[1836236]<<2)>>2]|0}else{_=a[p+(i&255)|0]|0;$=n}}while(0);a[9706068]=_;n=i+1|0;p=c[$+76+((n>>>8&255)<<2)>>2]|0;do{if((p|0)==0){j=c[$+4180>>2]|0;if((j|0)==0){aa=0;break}aa=gj[j&4095](n&65535)|0}else{aa=a[p+(n&255)|0]|0}}while(0);a[9706069]=aa;b[4853032]=(b[4853032]|0)+2&65535;C=56882;break};case 242:{if((a[9706068]|0)<0){ab=(b[4853030]|0)+2&65535}else{n=c[2426515]|0;p=n&65535;b[4853030]=p+2&65535;i=c[9757320+(c[1836236]<<2)>>2]|0;j=c[i+76+((n>>>8|768)<<2)>>2]|0;do{if((j|0)==0){k=c[i+4180>>2]|0;if((k|0)==0){ac=0;ad=i;break}h=gj[k&4095](p)|0;ac=h;ad=c[9757320+(c[1836236]<<2)>>2]|0}else{ac=a[j+(n&255)|0]|0;ad=i}}while(0);i=ac&255;j=n+1|0;p=c[ad+76+((j>>>8&255|768)<<2)>>2]|0;do{if((p|0)==0){h=c[ad+4180>>2]|0;if((h|0)==0){ae=0;break}ae=gj[h&4095](j&65535)|0}else{ae=a[p+(j&255)|0]|0}}while(0);j=(ae&255)<<8|i;c[2426515]=j;ab=j&65535}b[4853030]=ab;C=56882;break};case 237:{a[9706108]=(a[9706108]|0)+1&255;j=c[2426515]|0;p=j&65535;b[4853030]=p+1&65535;n=c[9757320+(c[1836236]<<2)>>2]|0;h=c[n+76+((j>>>8|512)<<2)>>2]|0;do{if((h|0)==0){k=c[n+4180>>2]|0;if((k|0)==0){af=0;ag=g;break}l=gj[k&4095](p)|0;af=l;ag=c[2076596]|0}else{af=a[h+(j&255)|0]|0;ag=g}}while(0);j=af&255;c[2076596]=ag-(d[(c[2426880]|0)+j|0]|0);gu[c[675872+(j<<2)>>2]&16383]();C=56882;break};case 238:{j=c[2426515]|0;h=j&65535;b[4853030]=h+1&65535;p=c[9757320+(c[1836236]<<2)>>2]|0;n=c[p+76+((j>>>8|768)<<2)>>2]|0;do{if((n|0)==0){i=c[p+4180>>2]|0;if((i|0)==0){ah=0;break}ah=gj[i&4095](h)|0}else{ah=a[n+(j&255)|0]|0}}while(0);j=a[9706069]^ah;a[9706069]=j;a[9706068]=a[9706144+(j&255)|0]|0;C=56882;break};case 239:{b[4853032]=(b[4853032]|0)-2&65535;j=c[2426516]|0;n=a[9706060]|0;h=c[9757320+(c[1836236]<<2)>>2]|0;p=c[h+76+((j>>>8|256)<<2)>>2]|0;do{if((p|0)==0){i=c[h+4184>>2]|0;if((i|0)==0){ai=h;break}gg[i&4095](j&65535,n);ai=c[9757320+(c[1836236]<<2)>>2]|0}else{a[p+(j&255)|0]=n;ai=h}}while(0);h=j+1|0;n=a[9706061]|0;p=c[ai+76+((h>>>8&255|256)<<2)>>2]|0;do{if((p|0)==0){i=c[ai+4184>>2]|0;if((i|0)==0){break}gg[i&4095](h&65535,n)}else{a[p+(h&255)|0]=n}}while(0);c[2426515]=40;b[4853030]=40;C=56882;break};case 212:{if((a[9706068]&1)==0){n=c[2426515]|0;h=n&65535;b[4853030]=h+2&65535;p=c[9757320+(c[1836236]<<2)>>2]|0;j=c[p+76+((n>>>8|768)<<2)>>2]|0;do{if((j|0)==0){i=c[p+4180>>2]|0;if((i|0)==0){aj=0;ak=p;break}l=gj[i&4095](h)|0;aj=l;ak=c[9757320+(c[1836236]<<2)>>2]|0}else{aj=a[j+(n&255)|0]|0;ak=p}}while(0);p=aj&255;j=n+1|0;h=c[ak+76+((j>>>8&255|768)<<2)>>2]|0;do{if((h|0)==0){l=c[ak+4180>>2]|0;if((l|0)==0){al=0;am=ak;break}i=gj[l&4095](j&65535)|0;al=i;am=c[9757320+(c[1836236]<<2)>>2]|0}else{al=a[h+(j&255)|0]|0;am=ak}}while(0);c[3541536]=(al&255)<<8|p;b[4853032]=(b[4853032]|0)-2&65535;j=c[2426516]|0;h=a[9706060]|0;n=c[am+76+((j>>>8|256)<<2)>>2]|0;do{if((n|0)==0){i=c[am+4184>>2]|0;if((i|0)==0){an=am;break}gg[i&4095](j&65535,h);an=c[9757320+(c[1836236]<<2)>>2]|0}else{a[n+(j&255)|0]=h;an=am}}while(0);h=j+1|0;n=a[9706061]|0;p=c[an+76+((h>>>8&255|256)<<2)>>2]|0;do{if((p|0)==0){i=c[an+4184>>2]|0;if((i|0)==0){break}gg[i&4095](h&65535,n)}else{a[p+(h&255)|0]=n}}while(0);n=c[3541536]|0;c[2426515]=n;c[2076596]=(c[2076596]|0)-7;ao=n&65535}else{ao=(b[4853030]|0)+2&65535}b[4853030]=ao;C=56882;break};case 19:{b[4853038]=(b[4853038]|0)+1&65535;C=56882;break};case 2:{n=b[4853036]|0;h=n&65535;p=a[9706069]|0;j=c[9757320+(c[1836236]<<2)>>2]|0;i=c[j+76+((h>>>8|256)<<2)>>2]|0;if((i|0)!=0){a[i+(h&255)|0]=p;C=56882;break L68771}h=c[j+4184>>2]|0;if((h|0)==0){C=56882;break L68771}gg[h&4095](n,p);C=56882;break};case 50:{p=c[2426515]|0;n=p&65535;b[4853030]=n+2&65535;h=c[9757320+(c[1836236]<<2)>>2]|0;j=c[h+76+((p>>>8|768)<<2)>>2]|0;do{if((j|0)==0){i=c[h+4180>>2]|0;if((i|0)==0){ap=0;aq=h;break}l=gj[i&4095](n)|0;ap=l;aq=c[9757320+(c[1836236]<<2)>>2]|0}else{ap=a[j+(p&255)|0]|0;aq=h}}while(0);h=ap&255;j=p+1|0;n=c[aq+76+((j>>>8&255|768)<<2)>>2]|0;do{if((n|0)==0){l=c[aq+4180>>2]|0;if((l|0)==0){ar=0;as=aq;break}i=gj[l&4095](j&65535)|0;ar=i;as=c[9757320+(c[1836236]<<2)>>2]|0}else{ar=a[n+(j&255)|0]|0;as=aq}}while(0);j=ar&255;n=j<<8|h;c[3541536]=n;p=a[9706069]|0;i=c[as+76+((j|256)<<2)>>2]|0;if((i|0)!=0){a[i+h|0]=p;C=56882;break L68771}i=c[as+4184>>2]|0;if((i|0)==0){C=56882;break L68771}gg[i&4095](n&65535,p);C=56882;break};case 20:{p=(a[9706077]|0)+1&255;a[9706068]=a[9706068]&1|a[9621712+(p&255)|0];a[9706077]=p;C=56882;break};case 21:{p=(a[9706077]|0)-1&255;a[9706068]=a[9706068]&1|a[9621968+(p&255)|0];a[9706077]=p;C=56882;break};case 217:{p=c[2426518]|0;c[2426518]=c[2426524];c[2426524]=p;p=c[2426519]|0;c[2426519]=c[2426525];c[2426525]=p;p=c[2426520]|0;c[2426520]=c[2426526];c[2426526]=p;C=56882;break};case 218:{if((a[9706068]&1)==0){at=(b[4853030]|0)+2&65535}else{p=c[2426515]|0;n=p&65535;b[4853030]=n+2&65535;i=c[9757320+(c[1836236]<<2)>>2]|0;j=c[i+76+((p>>>8|768)<<2)>>2]|0;do{if((j|0)==0){l=c[i+4180>>2]|0;if((l|0)==0){au=0;av=i;break}k=gj[l&4095](n)|0;au=k;av=c[9757320+(c[1836236]<<2)>>2]|0}else{au=a[j+(p&255)|0]|0;av=i}}while(0);i=au&255;j=p+1|0;n=c[av+76+((j>>>8&255|768)<<2)>>2]|0;do{if((n|0)==0){h=c[av+4180>>2]|0;if((h|0)==0){aw=0;break}aw=gj[h&4095](j&65535)|0}else{aw=a[n+(j&255)|0]|0}}while(0);j=(aw&255)<<8|i;c[2426515]=j;at=j&65535}b[4853030]=at;C=56882;break};case 219:{j=c[2426515]|0;n=j&65535;b[4853030]=n+1&65535;p=c[9757320+(c[1836236]<<2)>>2]|0;h=c[p+76+((j>>>8|768)<<2)>>2]|0;do{if((h|0)==0){k=c[p+4180>>2]|0;if((k|0)==0){ax=0;ay=p;break}l=gj[k&4095](n)|0;ax=l;ay=c[9757320+(c[1836236]<<2)>>2]|0}else{ax=a[h+(j&255)|0]|0;ay=p}}while(0);a[9706069]=gj[c[ay+4172>>2]&4095](d[9706069]<<8|ax&255)|0;C=56882;break};case 87:{a[9706077]=a[9706069]|0;C=56882;break};case 88:{a[9706076]=a[9706073]|0;C=56882;break};case 89:{a[9706076]=a[9706072]|0;C=56882;break};case 90:{a[9706076]=a[9706077]|0;C=56882;break};case 92:{a[9706076]=a[9706081]|0;C=56882;break};case 163:{p=a[9706069]&a[9706076];a[9706069]=p;a[9706068]=a[9706144+(p&255)|0]|16;C=56882;break};case 164:{p=a[9706069]&a[9706081];a[9706069]=p;a[9706068]=a[9706144+(p&255)|0]|16;C=56882;break};case 165:{p=a[9706069]&a[9706080];a[9706069]=p;a[9706068]=a[9706144+(p&255)|0]|16;C=56882;break};case 151:{p=c[2426517]&65280;j=(p>>>8)-(d[9706069]|0)|0;a[9706068]=a[(c[2385738]|0)+(j&255|p)|0]|0;a[9706069]=j&255;C=56882;break};case 152:{j=c[2426517]|0;p=j&65280;h=j&1;j=(p>>>8)-(d[9706073]|0)-h|0;a[9706068]=a[(c[2385738]|0)+(h<<16|p|j&255)|0]|0;a[9706069]=j&255;C=56882;break};case 153:{j=c[2426517]|0;p=j&65280;h=j&1;j=(p>>>8)-(d[9706072]|0)-h|0;a[9706068]=a[(c[2385738]|0)+(h<<16|p|j&255)|0]|0;a[9706069]=j&255;C=56882;break};case 154:{j=c[2426517]|0;p=j&65280;h=j&1;j=(p>>>8)-(d[9706077]|0)-h|0;a[9706068]=a[(c[2385738]|0)+(h<<16|p|j&255)|0]|0;a[9706069]=j&255;C=56882;break};case 155:{j=c[2426517]|0;p=j&65280;h=j&1;j=(p>>>8)-(d[9706076]|0)-h|0;a[9706068]=a[(c[2385738]|0)+(h<<16|p|j&255)|0]|0;a[9706069]=j&255;C=56882;break};case 175:{a[9706069]=0;a[9706068]=a[9706144]|0;C=56882;break};case 176:{j=a[9706069]|a[9706073];a[9706069]=j;a[9706068]=a[9706144+(j&255)|0]|0;C=56882;break};case 177:{j=a[9706069]|a[9706072];a[9706069]=j;a[9706068]=a[9706144+(j&255)|0]|0;C=56882;break};case 167:{a[9706068]=a[9706144+(d[9706069]|0)|0]|16;C=56882;break};case 168:{j=a[9706069]^a[9706073];a[9706069]=j;a[9706068]=a[9706144+(j&255)|0]|0;C=56882;break};case 169:{j=a[9706069]^a[9706072];a[9706069]=j;a[9706068]=a[9706144+(j&255)|0]|0;C=56882;break};case 146:{j=c[2426517]&65280;p=(j>>>8)-(d[9706077]|0)|0;a[9706068]=a[(c[2385738]|0)+(p&255|j)|0]|0;a[9706069]=p&255;C=56882;break};case 147:{p=c[2426517]&65280;j=(p>>>8)-(d[9706076]|0)|0;a[9706068]=a[(c[2385738]|0)+(j&255|p)|0]|0;a[9706069]=j&255;C=56882;break};case 148:{j=c[2426517]&65280;p=(j>>>8)-(d[9706081]|0)|0;a[9706068]=a[(c[2385738]|0)+(p&255|j)|0]|0;a[9706069]=p&255;C=56882;break};case 181:{p=a[9706069]|a[9706080];a[9706069]=p;a[9706068]=a[9706144+(p&255)|0]|0;C=56882;break};case 182:{p=b[4853040]|0;j=p&65535;h=c[9757320+(c[1836236]<<2)>>2]|0;n=c[h+76+(j>>>8<<2)>>2]|0;do{if((n|0)==0){i=c[h+4180>>2]|0;if((i|0)==0){az=0;break}az=gj[i&4095](p)|0}else{az=a[n+(j&255)|0]|0}}while(0);j=a[9706069]|az;a[9706069]=j;a[9706068]=a[9706144+(j&255)|0]|0;C=56882;break};case 173:{j=a[9706069]^a[9706080];a[9706069]=j;a[9706068]=a[9706144+(j&255)|0]|0;C=56882;break};case 174:{j=b[4853040]|0;n=j&65535;p=c[9757320+(c[1836236]<<2)>>2]|0;h=c[p+76+(n>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[p+4180>>2]|0;if((i|0)==0){aA=0;break}aA=gj[i&4095](j)|0}else{aA=a[h+(n&255)|0]|0}}while(0);n=a[9706069]^aA;a[9706069]=n;a[9706068]=a[9706144+(n&255)|0]|0;C=56882;break};case 225:{n=c[2426516]|0;h=c[9757320+(c[1836236]<<2)>>2]|0;j=c[h+76+(n>>>8<<2)>>2]|0;do{if((j|0)==0){p=c[h+4180>>2]|0;if((p|0)==0){aB=0;aC=h;break}i=gj[p&4095](n&65535)|0;aB=i;aC=c[9757320+(c[1836236]<<2)>>2]|0}else{aB=a[j+(n&255)|0]|0;aC=h}}while(0);a[9706080]=aB;h=n+1|0;j=c[aC+76+((h>>>8&255)<<2)>>2]|0;do{if((j|0)==0){i=c[aC+4180>>2]|0;if((i|0)==0){aD=0;break}aD=gj[i&4095](h&65535)|0}else{aD=a[j+(h&255)|0]|0}}while(0);a[9706081]=aD;b[4853032]=(b[4853032]|0)+2&65535;C=56882;break};case 170:{h=a[9706069]^a[9706077];a[9706069]=h;a[9706068]=a[9706144+(h&255)|0]|0;C=56882;break};case 171:{h=a[9706069]^a[9706076];a[9706069]=h;a[9706068]=a[9706144+(h&255)|0]|0;C=56882;break};case 172:{h=a[9706069]^a[9706081];a[9706069]=h;a[9706068]=a[9706144+(h&255)|0]|0;C=56882;break};case 34:{h=c[2426515]|0;j=h&65535;b[4853030]=j+2&65535;n=c[9757320+(c[1836236]<<2)>>2]|0;i=c[n+76+((h>>>8|768)<<2)>>2]|0;do{if((i|0)==0){p=c[n+4180>>2]|0;if((p|0)==0){aE=0;aF=n;break}l=gj[p&4095](j)|0;aE=l;aF=c[9757320+(c[1836236]<<2)>>2]|0}else{aE=a[i+(h&255)|0]|0;aF=n}}while(0);n=aE&255;i=h+1|0;j=c[aF+76+((i>>>8&255|768)<<2)>>2]|0;do{if((j|0)==0){l=c[aF+4180>>2]|0;if((l|0)==0){aG=0;aH=aF;break}p=gj[l&4095](i&65535)|0;aG=p;aH=c[9757320+(c[1836236]<<2)>>2]|0}else{aG=a[j+(i&255)|0]|0;aH=aF}}while(0);i=aG&255;j=i<<8|n;c[3541536]=j;h=a[9706080]|0;p=c[aH+76+((i|256)<<2)>>2]|0;do{if((p|0)==0){i=c[aH+4184>>2]|0;if((i|0)==0){aI=aH;break}gg[i&4095](j&65535,h);aI=c[9757320+(c[1836236]<<2)>>2]|0}else{a[p+n|0]=h;aI=aH}}while(0);h=j+1|0;n=a[9706081]|0;p=c[aI+76+((h>>>8&255|256)<<2)>>2]|0;if((p|0)!=0){a[p+(h&255)|0]=n;C=56882;break L68771}p=c[aI+4184>>2]|0;if((p|0)==0){C=56882;break L68771}gg[p&4095](h&65535,n);C=56882;break};case 93:{a[9706076]=a[9706080]|0;C=56882;break};case 94:{n=b[4853040]|0;h=n&65535;p=c[9757320+(c[1836236]<<2)>>2]|0;i=c[p+76+(h>>>8<<2)>>2]|0;do{if((i|0)==0){l=c[p+4180>>2]|0;if((l|0)==0){aJ=0;break}aJ=gj[l&4095](n)|0}else{aJ=a[i+(h&255)|0]|0}}while(0);a[9706076]=aJ;C=56882;break};case 114:{h=b[4853040]|0;i=h&65535;n=a[9706077]|0;p=c[9757320+(c[1836236]<<2)>>2]|0;j=c[p+76+((i>>>8|256)<<2)>>2]|0;if((j|0)!=0){a[j+(i&255)|0]=n;C=56882;break L68771}i=c[p+4184>>2]|0;if((i|0)==0){C=56882;break L68771}gg[i&4095](h,n);C=56882;break};case 143:{n=c[2426517]|0;h=n&65280;i=n&1;n=(d[9706069]|0)+i+(h>>>8)|0;a[9706068]=a[(c[2385740]|0)+(i<<16|h|n&255)|0]|0;a[9706069]=n&255;C=56882;break};case 144:{n=c[2426517]&65280;h=(n>>>8)-(d[9706073]|0)|0;a[9706068]=a[(c[2385738]|0)+(h&255|n)|0]|0;a[9706069]=h&255;C=56882;break};case 145:{h=c[2426517]&65280;n=(h>>>8)-(d[9706072]|0)|0;a[9706068]=a[(c[2385738]|0)+(n&255|h)|0]|0;a[9706069]=n&255;C=56882;break};case 159:{n=c[2426517]|0;h=n&65280;i=n&1;n=(h>>>8)-(d[9706069]|0)-i|0;a[9706068]=a[(c[2385738]|0)+(i<<16|h|n&255)|0]|0;a[9706069]=n&255;C=56882;break};case 160:{n=a[9706069]&a[9706073];a[9706069]=n;a[9706068]=a[9706144+(n&255)|0]|16;C=56882;break};case 162:{n=a[9706069]&a[9706077];a[9706069]=n;a[9706068]=a[9706144+(n&255)|0]|16;C=56882;break};case 161:{n=a[9706069]&a[9706072];a[9706069]=n;a[9706068]=a[9706144+(n&255)|0]|16;C=56882;break};case 149:{n=c[2426517]&65280;h=(n>>>8)-(d[9706080]|0)|0;a[9706068]=a[(c[2385738]|0)+(h&255|n)|0]|0;a[9706069]=h&255;C=56882;break};case 150:{h=c[2426517]&65280;n=h>>>8;i=b[4853040]|0;p=i&65535;j=c[9757320+(c[1836236]<<2)>>2]|0;l=c[j+76+(p>>>8<<2)>>2]|0;do{if((l|0)==0){k=c[j+4180>>2]|0;if((k|0)==0){aK=0;break}aK=gj[k&4095](i)|0}else{aK=a[l+(p&255)|0]|0}}while(0);p=n-(aK&255)|0;a[9706068]=a[(c[2385738]|0)+(p&255|h)|0]|0;a[9706069]=p&255;C=56882;break};case 157:{p=c[2426517]|0;l=p&65280;i=p&1;p=(l>>>8)-(d[9706080]|0)-i|0;a[9706068]=a[(c[2385738]|0)+(i<<16|l|p&255)|0]|0;a[9706069]=p&255;C=56882;break};case 197:{b[4853032]=(b[4853032]|0)-2&65535;p=c[2426516]|0;l=a[9706072]|0;i=c[9757320+(c[1836236]<<2)>>2]|0;j=c[i+76+((p>>>8|256)<<2)>>2]|0;do{if((j|0)==0){k=c[i+4184>>2]|0;if((k|0)==0){aL=i;break}gg[k&4095](p&65535,l);aL=c[9757320+(c[1836236]<<2)>>2]|0}else{a[j+(p&255)|0]=l;aL=i}}while(0);i=p+1|0;l=a[9706073]|0;j=c[aL+76+((i>>>8&255|256)<<2)>>2]|0;if((j|0)!=0){a[j+(i&255)|0]=l;C=56882;break L68771}j=c[aL+4184>>2]|0;if((j|0)==0){C=56882;break L68771}gg[j&4095](i&65535,l);C=56882;break};case 223:{b[4853032]=(b[4853032]|0)-2&65535;l=c[2426516]|0;i=a[9706060]|0;j=c[9757320+(c[1836236]<<2)>>2]|0;h=c[j+76+((l>>>8|256)<<2)>>2]|0;do{if((h|0)==0){n=c[j+4184>>2]|0;if((n|0)==0){aM=j;break}gg[n&4095](l&65535,i);aM=c[9757320+(c[1836236]<<2)>>2]|0}else{a[h+(l&255)|0]=i;aM=j}}while(0);j=l+1|0;i=a[9706061]|0;h=c[aM+76+((j>>>8&255|256)<<2)>>2]|0;do{if((h|0)==0){p=c[aM+4184>>2]|0;if((p|0)==0){break}gg[p&4095](j&65535,i)}else{a[h+(j&255)|0]=i}}while(0);c[2426515]=24;b[4853030]=24;C=56882;break};case 207:{b[4853032]=(b[4853032]|0)-2&65535;i=c[2426516]|0;j=a[9706060]|0;h=c[9757320+(c[1836236]<<2)>>2]|0;l=c[h+76+((i>>>8|256)<<2)>>2]|0;do{if((l|0)==0){p=c[h+4184>>2]|0;if((p|0)==0){aN=h;break}gg[p&4095](i&65535,j);aN=c[9757320+(c[1836236]<<2)>>2]|0}else{a[l+(i&255)|0]=j;aN=h}}while(0);h=i+1|0;j=a[9706061]|0;l=c[aN+76+((h>>>8&255|256)<<2)>>2]|0;do{if((l|0)==0){p=c[aN+4184>>2]|0;if((p|0)==0){break}gg[p&4095](h&65535,j)}else{a[l+(h&255)|0]=j}}while(0);c[2426515]=8;b[4853030]=8;C=56882;break};case 224:{if((a[9706068]&4)!=0){C=56882;break L68771}j=c[2426516]|0;h=c[9757320+(c[1836236]<<2)>>2]|0;l=c[h+76+(j>>>8<<2)>>2]|0;do{if((l|0)==0){i=c[h+4180>>2]|0;if((i|0)==0){aO=0;aP=h;break}p=gj[i&4095](j&65535)|0;aO=p;aP=c[9757320+(c[1836236]<<2)>>2]|0}else{aO=a[l+(j&255)|0]|0;aP=h}}while(0);a[9706060]=aO;h=j+1|0;l=c[aP+76+((h>>>8&255)<<2)>>2]|0;do{if((l|0)==0){p=c[aP+4180>>2]|0;if((p|0)==0){aQ=0;break}aQ=gj[p&4095](h&65535)|0}else{aQ=a[l+(h&255)|0]|0}}while(0);a[9706061]=aQ;b[4853032]=(b[4853032]|0)+2&65535;b[4853030]=c[2426515]&65535;h=(c[2076596]|0)-6|0;c[2076596]=h;V=h;break};case 226:{if((a[9706068]&4)==0){h=c[2426515]|0;l=h&65535;b[4853030]=l+2&65535;j=c[9757320+(c[1836236]<<2)>>2]|0;p=c[j+76+((h>>>8|768)<<2)>>2]|0;do{if((p|0)==0){i=c[j+4180>>2]|0;if((i|0)==0){aR=0;aS=j;break}n=gj[i&4095](l)|0;aR=n;aS=c[9757320+(c[1836236]<<2)>>2]|0}else{aR=a[p+(h&255)|0]|0;aS=j}}while(0);j=aR&255;p=h+1|0;l=c[aS+76+((p>>>8&255|768)<<2)>>2]|0;do{if((l|0)==0){n=c[aS+4180>>2]|0;if((n|0)==0){aT=0;break}aT=gj[n&4095](p&65535)|0}else{aT=a[l+(p&255)|0]|0}}while(0);p=(aT&255)<<8|j;c[2426515]=p;aU=p&65535}else{aU=(b[4853030]|0)+2&65535}b[4853030]=aU;C=56882;break};case 195:{gff();C=56882;break};case 196:{if((a[9706068]&64)==0){p=c[2426515]|0;l=p&65535;b[4853030]=l+2&65535;h=c[9757320+(c[1836236]<<2)>>2]|0;n=c[h+76+((p>>>8|768)<<2)>>2]|0;do{if((n|0)==0){i=c[h+4180>>2]|0;if((i|0)==0){aV=0;aW=h;break}k=gj[i&4095](l)|0;aV=k;aW=c[9757320+(c[1836236]<<2)>>2]|0}else{aV=a[n+(p&255)|0]|0;aW=h}}while(0);h=aV&255;n=p+1|0;l=c[aW+76+((n>>>8&255|768)<<2)>>2]|0;do{if((l|0)==0){j=c[aW+4180>>2]|0;if((j|0)==0){aX=0;aY=aW;break}k=gj[j&4095](n&65535)|0;aX=k;aY=c[9757320+(c[1836236]<<2)>>2]|0}else{aX=a[l+(n&255)|0]|0;aY=aW}}while(0);c[3541536]=(aX&255)<<8|h;b[4853032]=(b[4853032]|0)-2&65535;n=c[2426516]|0;l=a[9706060]|0;p=c[aY+76+((n>>>8|256)<<2)>>2]|0;do{if((p|0)==0){k=c[aY+4184>>2]|0;if((k|0)==0){aZ=aY;break}gg[k&4095](n&65535,l);aZ=c[9757320+(c[1836236]<<2)>>2]|0}else{a[p+(n&255)|0]=l;aZ=aY}}while(0);l=n+1|0;p=a[9706061]|0;h=c[aZ+76+((l>>>8&255|256)<<2)>>2]|0;do{if((h|0)==0){k=c[aZ+4184>>2]|0;if((k|0)==0){break}gg[k&4095](l&65535,p)}else{a[h+(l&255)|0]=p}}while(0);p=c[3541536]|0;c[2426515]=p;c[2076596]=(c[2076596]|0)-7;a_=p&65535}else{a_=(b[4853030]|0)+2&65535}b[4853030]=a_;C=56882;break};case 71:{a[9706073]=a[9706069]|0;C=56882;break};case 72:{a[9706072]=a[9706073]|0;C=56882;break};case 74:{a[9706072]=a[9706077]|0;C=56882;break};case 75:{a[9706072]=a[9706076]|0;C=56882;break};case 76:{a[9706072]=a[9706081]|0;C=56882;break};case 77:{a[9706072]=a[9706080]|0;C=56882;break};case 56:{if((a[9706068]&1)==0){a$=(b[4853030]|0)+1&65535}else{p=c[2426515]|0;l=p&65535;h=l+1&65535;b[4853030]=h;n=c[9757320+(c[1836236]<<2)>>2]|0;k=c[n+76+((p>>>8|768)<<2)>>2]|0;do{if((k|0)==0){j=c[n+4180>>2]|0;if((j|0)==0){a0=0;a1=h;a2=g;break}i=gj[j&4095](l)|0;a0=i;a1=b[4853030]|0;a2=c[2076596]|0}else{a0=a[k+(p&255)|0]|0;a1=h;a2=g}}while(0);b[4853030]=a1+(a0<<24>>24)&65535;c[2076596]=a2-5;a$=c[2426515]&65535}b[4853030]=a$;C=56882;break};case 178:{h=a[9706069]|a[9706077];a[9706069]=h;a[9706068]=a[9706144+(h&255)|0]|0;C=56882;break};case 179:{h=a[9706069]|a[9706076];a[9706069]=h;a[9706068]=a[9706144+(h&255)|0]|0;C=56882;break};case 180:{h=a[9706069]|a[9706081];a[9706069]=h;a[9706068]=a[9706144+(h&255)|0]|0;C=56882;break};case 183:{a[9706068]=a[9706144+(d[9706069]|0)|0]|0;C=56882;break};case 184:{h=a[9706073]|0;p=c[2426517]&65280;a[9706068]=a[(c[2385738]|0)+((p>>>8)-(h&255)&255|p)|0]&-41|h&40;C=56882;break};case 185:{h=a[9706072]|0;p=c[2426517]&65280;a[9706068]=a[(c[2385738]|0)+((p>>>8)-(h&255)&255|p)|0]&-41|h&40;C=56882;break};case 186:{h=a[9706077]|0;p=c[2426517]&65280;a[9706068]=a[(c[2385738]|0)+((p>>>8)-(h&255)&255|p)|0]&-41|h&40;C=56882;break};case 187:{h=a[9706076]|0;p=c[2426517]&65280;a[9706068]=a[(c[2385738]|0)+((p>>>8)-(h&255)&255|p)|0]&-41|h&40;C=56882;break};case 188:{h=a[9706081]|0;p=c[2426517]&65280;a[9706068]=a[(c[2385738]|0)+((p>>>8)-(h&255)&255|p)|0]&-41|h&40;C=56882;break};case 191:{h=a[9706069]|0;p=c[2426517]&65280;a[9706068]=a[(c[2385738]|0)+((p>>>8)-(h&255)&255|p)|0]&-41|h&40;C=56882;break};case 192:{if((a[9706068]&64)!=0){C=56882;break L68771}h=c[2426516]|0;p=c[9757320+(c[1836236]<<2)>>2]|0;k=c[p+76+(h>>>8<<2)>>2]|0;do{if((k|0)==0){l=c[p+4180>>2]|0;if((l|0)==0){a3=0;a4=p;break}n=gj[l&4095](h&65535)|0;a3=n;a4=c[9757320+(c[1836236]<<2)>>2]|0}else{a3=a[k+(h&255)|0]|0;a4=p}}while(0);a[9706060]=a3;p=h+1|0;k=c[a4+76+((p>>>8&255)<<2)>>2]|0;do{if((k|0)==0){n=c[a4+4180>>2]|0;if((n|0)==0){a5=0;break}a5=gj[n&4095](p&65535)|0}else{a5=a[k+(p&255)|0]|0}}while(0);a[9706061]=a5;b[4853032]=(b[4853032]|0)+2&65535;b[4853030]=c[2426515]&65535;p=(c[2076596]|0)-6|0;c[2076596]=p;V=p;break};case 189:{p=a[9706080]|0;k=c[2426517]&65280;a[9706068]=a[(c[2385738]|0)+((k>>>8)-(p&255)&255|k)|0]&-41|p&40;C=56882;break};case 190:{p=b[4853040]|0;k=p&65535;h=c[9757320+(c[1836236]<<2)>>2]|0;n=c[h+76+(k>>>8<<2)>>2]|0;do{if((n|0)==0){l=c[h+4180>>2]|0;if((l|0)==0){a6=0;break}a6=gj[l&4095](p)|0}else{a6=a[n+(k&255)|0]|0}}while(0);k=c[2426517]&65280;a[9706068]=a[(c[2385738]|0)+((k>>>8)-(a6&255)&255|k)|0]&-41|a6&40;C=56882;break};case 205:{k=c[2426515]|0;n=k&65535;b[4853030]=n+2&65535;p=c[9757320+(c[1836236]<<2)>>2]|0;h=c[p+76+((k>>>8|768)<<2)>>2]|0;do{if((h|0)==0){l=c[p+4180>>2]|0;if((l|0)==0){a7=0;a8=p;break}i=gj[l&4095](n)|0;a7=i;a8=c[9757320+(c[1836236]<<2)>>2]|0}else{a7=a[h+(k&255)|0]|0;a8=p}}while(0);p=a7&255;h=k+1|0;n=c[a8+76+((h>>>8&255|768)<<2)>>2]|0;do{if((n|0)==0){i=c[a8+4180>>2]|0;if((i|0)==0){a9=0;ba=a8;break}l=gj[i&4095](h&65535)|0;a9=l;ba=c[9757320+(c[1836236]<<2)>>2]|0}else{a9=a[n+(h&255)|0]|0;ba=a8}}while(0);c[3541536]=(a9&255)<<8|p;b[4853032]=(b[4853032]|0)-2&65535;h=c[2426516]|0;n=a[9706060]|0;k=c[ba+76+((h>>>8|256)<<2)>>2]|0;do{if((k|0)==0){l=c[ba+4184>>2]|0;if((l|0)==0){bb=ba;break}gg[l&4095](h&65535,n);bb=c[9757320+(c[1836236]<<2)>>2]|0}else{a[k+(h&255)|0]=n;bb=ba}}while(0);n=h+1|0;k=a[9706061]|0;p=c[bb+76+((n>>>8&255|256)<<2)>>2]|0;do{if((p|0)==0){l=c[bb+4184>>2]|0;if((l|0)==0){break}gg[l&4095](n&65535,k)}else{a[p+(n&255)|0]=k}}while(0);k=c[3541536]|0;c[2426515]=k;b[4853030]=k&65535;C=56882;break};case 220:{if((a[9706068]&1)==0){bc=(b[4853030]|0)+2&65535}else{k=c[2426515]|0;n=k&65535;b[4853030]=n+2&65535;p=c[9757320+(c[1836236]<<2)>>2]|0;h=c[p+76+((k>>>8|768)<<2)>>2]|0;do{if((h|0)==0){l=c[p+4180>>2]|0;if((l|0)==0){bd=0;be=p;break}i=gj[l&4095](n)|0;bd=i;be=c[9757320+(c[1836236]<<2)>>2]|0}else{bd=a[h+(k&255)|0]|0;be=p}}while(0);p=bd&255;h=k+1|0;n=c[be+76+((h>>>8&255|768)<<2)>>2]|0;do{if((n|0)==0){i=c[be+4180>>2]|0;if((i|0)==0){bf=0;bg=be;break}l=gj[i&4095](h&65535)|0;bf=l;bg=c[9757320+(c[1836236]<<2)>>2]|0}else{bf=a[n+(h&255)|0]|0;bg=be}}while(0);c[3541536]=(bf&255)<<8|p;b[4853032]=(b[4853032]|0)-2&65535;h=c[2426516]|0;n=a[9706060]|0;k=c[bg+76+((h>>>8|256)<<2)>>2]|0;do{if((k|0)==0){l=c[bg+4184>>2]|0;if((l|0)==0){bh=bg;break}gg[l&4095](h&65535,n);bh=c[9757320+(c[1836236]<<2)>>2]|0}else{a[k+(h&255)|0]=n;bh=bg}}while(0);n=h+1|0;k=a[9706061]|0;p=c[bh+76+((n>>>8&255|256)<<2)>>2]|0;do{if((p|0)==0){l=c[bh+4184>>2]|0;if((l|0)==0){break}gg[l&4095](n&65535,k)}else{a[p+(n&255)|0]=k}}while(0);k=c[3541536]|0;c[2426515]=k;c[2076596]=(c[2076596]|0)-7;bc=k&65535}b[4853030]=bc;C=56882;break};case 206:{k=c[2426517]|0;n=k&65280;p=k&1;k=n>>>8;h=c[2426515]|0;l=h&65535;b[4853030]=l+1&65535;i=c[9757320+(c[1836236]<<2)>>2]|0;j=c[i+76+((h>>>8|768)<<2)>>2]|0;do{if((j|0)==0){P=c[i+4180>>2]|0;if((P|0)==0){bi=0;break}bi=gj[P&4095](l)|0}else{bi=a[j+(h&255)|0]|0}}while(0);h=k+p+(bi&255)|0;a[9706068]=a[(c[2385740]|0)+(p<<16|n|h&255)|0]|0;a[9706069]=h&255;C=56882;break};case 227:{h=c[2426516]|0;j=c[9757320+(c[1836236]<<2)>>2]|0;l=c[j+76+(h>>>8<<2)>>2]|0;do{if((l|0)==0){i=c[j+4180>>2]|0;if((i|0)==0){bj=0;bk=j;break}P=gj[i&4095](h&65535)|0;bj=P;bk=c[9757320+(c[1836236]<<2)>>2]|0}else{bj=a[l+(h&255)|0]|0;bk=j}}while(0);j=h+1|0;l=c[bk+76+((j>>>8&255)<<2)>>2]|0;do{if((l|0)==0){n=c[bk+4180>>2]|0;if((n|0)==0){bl=0;bm=bk;break}p=gj[n&4095](j&65535)|0;bl=p;bm=c[9757320+(c[1836236]<<2)>>2]|0}else{bl=a[l+(j&255)|0]|0;bm=bk}}while(0);j=c[2426516]|0;l=a[9706080]|0;h=c[bm+76+((j>>>8|256)<<2)>>2]|0;do{if((h|0)==0){p=c[bm+4184>>2]|0;if((p|0)==0){bn=bm;break}gg[p&4095](j&65535,l);bn=c[9757320+(c[1836236]<<2)>>2]|0}else{a[h+(j&255)|0]=l;bn=bm}}while(0);l=j+1|0;h=a[9706081]|0;p=c[bn+76+((l>>>8&255|256)<<2)>>2]|0;do{if((p|0)==0){n=c[bn+4184>>2]|0;if((n|0)==0){break}gg[n&4095](l&65535,h)}else{a[p+(l&255)|0]=h}}while(0);c[2426520]=(bl&255)<<8|bj&255;C=56882;break};case 221:{a[9706108]=(a[9706108]|0)+1&255;h=c[2426515]|0;l=h&65535;b[4853030]=l+1&65535;p=c[9757320+(c[1836236]<<2)>>2]|0;j=c[p+76+((h>>>8|512)<<2)>>2]|0;do{if((j|0)==0){n=c[p+4180>>2]|0;if((n|0)==0){bo=0;bp=g;break}k=gj[n&4095](l)|0;bo=k;bp=c[2076596]|0}else{bo=a[j+(h&255)|0]|0;bp=g}}while(0);h=bo&255;c[2076596]=bp-(d[(c[2426878]|0)+h|0]|0);gu[c[676896+(h<<2)>>2]&16383]();C=56882;break};case 222:{h=c[2426517]|0;j=h&65280;l=h&1;h=j>>>8;p=c[2426515]|0;k=p&65535;b[4853030]=k+1&65535;n=c[9757320+(c[1836236]<<2)>>2]|0;P=c[n+76+((p>>>8|768)<<2)>>2]|0;do{if((P|0)==0){i=c[n+4180>>2]|0;if((i|0)==0){bq=0;break}bq=gj[i&4095](k)|0}else{bq=a[P+(p&255)|0]|0}}while(0);p=h-(bq&255)-l|0;a[9706068]=a[(c[2385738]|0)+(l<<16|j|p&255)|0]|0;a[9706069]=p&255;C=56882;break};case 134:{p=c[2426517]&65280;P=p>>>8;k=b[4853040]|0;n=k&65535;i=c[9757320+(c[1836236]<<2)>>2]|0;br=c[i+76+(n>>>8<<2)>>2]|0;do{if((br|0)==0){bs=c[i+4180>>2]|0;if((bs|0)==0){bt=0;break}bt=gj[bs&4095](k)|0}else{bt=a[br+(n&255)|0]|0}}while(0);n=(bt&255)+P|0;a[9706068]=a[(c[2385740]|0)+(n&255|p)|0]|0;a[9706069]=n&255;C=56882;break};case 198:{n=c[2426517]&65280;br=n>>>8;k=c[2426515]|0;i=k&65535;b[4853030]=i+1&65535;j=c[9757320+(c[1836236]<<2)>>2]|0;l=c[j+76+((k>>>8|768)<<2)>>2]|0;do{if((l|0)==0){h=c[j+4180>>2]|0;if((h|0)==0){bu=0;break}bu=gj[h&4095](i)|0}else{bu=a[l+(k&255)|0]|0}}while(0);k=(bu&255)+br|0;a[9706068]=a[(c[2385740]|0)+(k&255|n)|0]|0;a[9706069]=k&255;C=56882;break};case 199:{b[4853032]=(b[4853032]|0)-2&65535;k=c[2426516]|0;l=a[9706060]|0;i=c[9757320+(c[1836236]<<2)>>2]|0;j=c[i+76+((k>>>8|256)<<2)>>2]|0;do{if((j|0)==0){p=c[i+4184>>2]|0;if((p|0)==0){bv=i;break}gg[p&4095](k&65535,l);bv=c[9757320+(c[1836236]<<2)>>2]|0}else{a[j+(k&255)|0]=l;bv=i}}while(0);i=k+1|0;l=a[9706061]|0;j=c[bv+76+((i>>>8&255|256)<<2)>>2]|0;do{if((j|0)==0){n=c[bv+4184>>2]|0;if((n|0)==0){break}gg[n&4095](i&65535,l)}else{a[j+(i&255)|0]=l}}while(0);c[2426515]=0;b[4853030]=0;C=56882;break};case 208:{if((a[9706068]&1)!=0){C=56882;break L68771}l=c[2426516]|0;i=c[9757320+(c[1836236]<<2)>>2]|0;j=c[i+76+(l>>>8<<2)>>2]|0;do{if((j|0)==0){k=c[i+4180>>2]|0;if((k|0)==0){bw=0;bx=i;break}n=gj[k&4095](l&65535)|0;bw=n;bx=c[9757320+(c[1836236]<<2)>>2]|0}else{bw=a[j+(l&255)|0]|0;bx=i}}while(0);a[9706060]=bw;i=l+1|0;j=c[bx+76+((i>>>8&255)<<2)>>2]|0;do{if((j|0)==0){n=c[bx+4180>>2]|0;if((n|0)==0){by=0;break}by=gj[n&4095](i&65535)|0}else{by=a[j+(i&255)|0]|0}}while(0);a[9706061]=by;b[4853032]=(b[4853032]|0)+2&65535;b[4853030]=c[2426515]&65535;i=(c[2076596]|0)-6|0;c[2076596]=i;V=i;break};case 204:{if((a[9706068]&64)==0){bz=(b[4853030]|0)+2&65535}else{i=c[2426515]|0;j=i&65535;b[4853030]=j+2&65535;l=c[9757320+(c[1836236]<<2)>>2]|0;n=c[l+76+((i>>>8|768)<<2)>>2]|0;do{if((n|0)==0){k=c[l+4180>>2]|0;if((k|0)==0){bA=0;bB=l;break}br=gj[k&4095](j)|0;bA=br;bB=c[9757320+(c[1836236]<<2)>>2]|0}else{bA=a[n+(i&255)|0]|0;bB=l}}while(0);l=bA&255;n=i+1|0;j=c[bB+76+((n>>>8&255|768)<<2)>>2]|0;do{if((j|0)==0){br=c[bB+4180>>2]|0;if((br|0)==0){bC=0;bD=bB;break}k=gj[br&4095](n&65535)|0;bC=k;bD=c[9757320+(c[1836236]<<2)>>2]|0}else{bC=a[j+(n&255)|0]|0;bD=bB}}while(0);c[3541536]=(bC&255)<<8|l;b[4853032]=(b[4853032]|0)-2&65535;n=c[2426516]|0;j=a[9706060]|0;i=c[bD+76+((n>>>8|256)<<2)>>2]|0;do{if((i|0)==0){k=c[bD+4184>>2]|0;if((k|0)==0){bE=bD;break}gg[k&4095](n&65535,j);bE=c[9757320+(c[1836236]<<2)>>2]|0}else{a[i+(n&255)|0]=j;bE=bD}}while(0);j=n+1|0;i=a[9706061]|0;l=c[bE+76+((j>>>8&255|256)<<2)>>2]|0;do{if((l|0)==0){k=c[bE+4184>>2]|0;if((k|0)==0){break}gg[k&4095](j&65535,i)}else{a[l+(j&255)|0]=i}}while(0);i=c[3541536]|0;c[2426515]=i;c[2076596]=(c[2076596]|0)-7;bz=i&65535}b[4853030]=bz;C=56882;break};case 209:{i=c[2426516]|0;j=c[9757320+(c[1836236]<<2)>>2]|0;l=c[j+76+(i>>>8<<2)>>2]|0;do{if((l|0)==0){n=c[j+4180>>2]|0;if((n|0)==0){bF=0;bG=j;break}k=gj[n&4095](i&65535)|0;bF=k;bG=c[9757320+(c[1836236]<<2)>>2]|0}else{bF=a[l+(i&255)|0]|0;bG=j}}while(0);a[9706076]=bF;j=i+1|0;l=c[bG+76+((j>>>8&255)<<2)>>2]|0;do{if((l|0)==0){k=c[bG+4180>>2]|0;if((k|0)==0){bH=0;break}bH=gj[k&4095](j&65535)|0}else{bH=a[l+(j&255)|0]|0}}while(0);a[9706077]=bH;b[4853032]=(b[4853032]|0)+2&65535;C=56882;break};case 210:{if((a[9706068]&1)==0){j=c[2426515]|0;l=j&65535;b[4853030]=l+2&65535;i=c[9757320+(c[1836236]<<2)>>2]|0;k=c[i+76+((j>>>8|768)<<2)>>2]|0;do{if((k|0)==0){n=c[i+4180>>2]|0;if((n|0)==0){bI=0;bJ=i;break}br=gj[n&4095](l)|0;bI=br;bJ=c[9757320+(c[1836236]<<2)>>2]|0}else{bI=a[k+(j&255)|0]|0;bJ=i}}while(0);i=bI&255;k=j+1|0;l=c[bJ+76+((k>>>8&255|768)<<2)>>2]|0;do{if((l|0)==0){br=c[bJ+4180>>2]|0;if((br|0)==0){bK=0;break}bK=gj[br&4095](k&65535)|0}else{bK=a[l+(k&255)|0]|0}}while(0);k=(bK&255)<<8|i;c[2426515]=k;bL=k&65535}else{bL=(b[4853030]|0)+2&65535}b[4853030]=bL;C=56882;break};case 17:{k=c[2426515]|0;l=k&65535;b[4853030]=l+2&65535;j=c[9757320+(c[1836236]<<2)>>2]|0;br=c[j+76+((k>>>8|768)<<2)>>2]|0;do{if((br|0)==0){n=c[j+4180>>2]|0;if((n|0)==0){bM=0;bN=j;break}p=gj[n&4095](l)|0;bM=p;bN=c[9757320+(c[1836236]<<2)>>2]|0}else{bM=a[br+(k&255)|0]|0;bN=j}}while(0);j=bM&255;br=k+1|0;l=c[bN+76+((br>>>8&255|768)<<2)>>2]|0;do{if((l|0)==0){i=c[bN+4180>>2]|0;if((i|0)==0){bO=0;break}bO=gj[i&4095](br&65535)|0}else{bO=a[l+(br&255)|0]|0}}while(0);b[4853038]=(bO&255)<<8|j;C=56882;break};case 213:{b[4853032]=(b[4853032]|0)-2&65535;br=c[2426516]|0;l=a[9706076]|0;k=c[9757320+(c[1836236]<<2)>>2]|0;i=c[k+76+((br>>>8|256)<<2)>>2]|0;do{if((i|0)==0){p=c[k+4184>>2]|0;if((p|0)==0){bP=k;break}gg[p&4095](br&65535,l);bP=c[9757320+(c[1836236]<<2)>>2]|0}else{a[i+(br&255)|0]=l;bP=k}}while(0);k=br+1|0;l=a[9706077]|0;i=c[bP+76+((k>>>8&255|256)<<2)>>2]|0;if((i|0)!=0){a[i+(k&255)|0]=l;C=56882;break L68771}i=c[bP+4184>>2]|0;if((i|0)==0){C=56882;break L68771}gg[i&4095](k&65535,l);C=56882;break};case 214:{l=c[2426517]&65280;k=l>>>8;i=c[2426515]|0;j=i&65535;b[4853030]=j+1&65535;p=c[9757320+(c[1836236]<<2)>>2]|0;n=c[p+76+((i>>>8|768)<<2)>>2]|0;do{if((n|0)==0){P=c[p+4180>>2]|0;if((P|0)==0){bQ=0;break}bQ=gj[P&4095](j)|0}else{bQ=a[n+(i&255)|0]|0}}while(0);i=k-(bQ&255)|0;a[9706068]=a[(c[2385738]|0)+(i&255|l)|0]|0;a[9706069]=i&255;C=56882;break};case 215:{b[4853032]=(b[4853032]|0)-2&65535;i=c[2426516]|0;n=a[9706060]|0;j=c[9757320+(c[1836236]<<2)>>2]|0;p=c[j+76+((i>>>8|256)<<2)>>2]|0;do{if((p|0)==0){br=c[j+4184>>2]|0;if((br|0)==0){bR=j;break}gg[br&4095](i&65535,n);bR=c[9757320+(c[1836236]<<2)>>2]|0}else{a[p+(i&255)|0]=n;bR=j}}while(0);j=i+1|0;n=a[9706061]|0;p=c[bR+76+((j>>>8&255|256)<<2)>>2]|0;do{if((p|0)==0){l=c[bR+4184>>2]|0;if((l|0)==0){break}gg[l&4095](j&65535,n)}else{a[p+(j&255)|0]=n}}while(0);c[2426515]=16;b[4853030]=16;C=56882;break};case 194:{if((a[9706068]&64)==0){n=c[2426515]|0;j=n&65535;b[4853030]=j+2&65535;p=c[9757320+(c[1836236]<<2)>>2]|0;i=c[p+76+((n>>>8|768)<<2)>>2]|0;do{if((i|0)==0){l=c[p+4180>>2]|0;if((l|0)==0){bS=0;bT=p;break}k=gj[l&4095](j)|0;bS=k;bT=c[9757320+(c[1836236]<<2)>>2]|0}else{bS=a[i+(n&255)|0]|0;bT=p}}while(0);p=bS&255;i=n+1|0;j=c[bT+76+((i>>>8&255|768)<<2)>>2]|0;do{if((j|0)==0){k=c[bT+4180>>2]|0;if((k|0)==0){bU=0;break}bU=gj[k&4095](i&65535)|0}else{bU=a[j+(i&255)|0]|0}}while(0);i=(bU&255)<<8|p;c[2426515]=i;bV=i&65535}else{bV=(b[4853030]|0)+2&65535}b[4853030]=bV;C=56882;break};case 200:{if((a[9706068]&64)==0){C=56882;break L68771}i=c[2426516]|0;j=c[9757320+(c[1836236]<<2)>>2]|0;n=c[j+76+(i>>>8<<2)>>2]|0;do{if((n|0)==0){k=c[j+4180>>2]|0;if((k|0)==0){bW=0;bX=j;break}l=gj[k&4095](i&65535)|0;bW=l;bX=c[9757320+(c[1836236]<<2)>>2]|0}else{bW=a[n+(i&255)|0]|0;bX=j}}while(0);a[9706060]=bW;j=i+1|0;n=c[bX+76+((j>>>8&255)<<2)>>2]|0;do{if((n|0)==0){p=c[bX+4180>>2]|0;if((p|0)==0){bY=0;break}bY=gj[p&4095](j&65535)|0}else{bY=a[n+(j&255)|0]|0}}while(0);a[9706061]=bY;b[4853032]=(b[4853032]|0)+2&65535;b[4853030]=c[2426515]&65535;j=(c[2076596]|0)-6|0;c[2076596]=j;V=j;break};case 86:{j=b[4853040]|0;n=j&65535;i=c[9757320+(c[1836236]<<2)>>2]|0;p=c[i+76+(n>>>8<<2)>>2]|0;do{if((p|0)==0){l=c[i+4180>>2]|0;if((l|0)==0){bZ=0;break}bZ=gj[l&4095](j)|0}else{bZ=a[p+(n&255)|0]|0}}while(0);a[9706077]=bZ;C=56882;break};case 15:{n=a[9706069]|0;p=n&1|a[9706068]&-60;j=(n&255)>>>1;a[9706069]=j|n<<7;a[9706068]=p|j&40;C=56882;break};case 45:{j=(a[9706080]|0)-1&255;a[9706068]=a[9706068]&1|a[9621968+(j&255)|0];a[9706080]=j;C=56882;break};case 47:{j=~a[9706069];a[9706069]=j;a[9706068]=j&40|a[9706068]&-59|18;C=56882;break};case 202:{if((a[9706068]&64)==0){b_=(b[4853030]|0)+2&65535}else{j=c[2426515]|0;p=j&65535;b[4853030]=p+2&65535;n=c[9757320+(c[1836236]<<2)>>2]|0;i=c[n+76+((j>>>8|768)<<2)>>2]|0;do{if((i|0)==0){l=c[n+4180>>2]|0;if((l|0)==0){b$=0;b0=n;break}k=gj[l&4095](p)|0;b$=k;b0=c[9757320+(c[1836236]<<2)>>2]|0}else{b$=a[i+(j&255)|0]|0;b0=n}}while(0);n=b$&255;i=j+1|0;p=c[b0+76+((i>>>8&255|768)<<2)>>2]|0;do{if((p|0)==0){k=c[b0+4180>>2]|0;if((k|0)==0){b1=0;break}b1=gj[k&4095](i&65535)|0}else{b1=a[p+(i&255)|0]|0}}while(0);i=(b1&255)<<8|n;c[2426515]=i;b_=i&65535}b[4853030]=b_;C=56882;break};case 41:{i=c[2426520]|0;p=i>>>7;a[9706068]=(i>>>15&1|p&16|p&40|a[9706068]&196)&255;b[4853040]=i<<1&65535;C=56882;break};case 106:{a[9706080]=a[9706077]|0;C=56882;break};case 107:{a[9706080]=a[9706076]|0;C=56882;break};case 108:{a[9706080]=a[9706081]|0;C=56882;break};case 110:{i=b[4853040]|0;p=i&65535;j=c[9757320+(c[1836236]<<2)>>2]|0;k=c[j+76+(p>>>8<<2)>>2]|0;do{if((k|0)==0){l=c[j+4180>>2]|0;if((l|0)==0){b2=0;break}b2=gj[l&4095](i)|0}else{b2=a[k+(p&255)|0]|0}}while(0);a[9706080]=b2;C=56882;break};case 78:{p=b[4853040]|0;k=p&65535;i=c[9757320+(c[1836236]<<2)>>2]|0;j=c[i+76+(k>>>8<<2)>>2]|0;do{if((j|0)==0){n=c[i+4180>>2]|0;if((n|0)==0){b3=0;break}b3=gj[n&4095](p)|0}else{b3=a[j+(k&255)|0]|0}}while(0);a[9706072]=b3;C=56882;break};case 128:{k=c[2426517]&65280;j=(k>>>8)+(d[9706073]|0)|0;a[9706068]=a[(c[2385740]|0)+(j&255|k)|0]|0;a[9706069]=j&255;C=56882;break};case 129:{j=c[2426517]&65280;k=(j>>>8)+(d[9706072]|0)|0;a[9706068]=a[(c[2385740]|0)+(k&255|j)|0]|0;a[9706069]=k&255;C=56882;break};case 130:{k=c[2426517]&65280;j=(k>>>8)+(d[9706077]|0)|0;a[9706068]=a[(c[2385740]|0)+(j&255|k)|0]|0;a[9706069]=j&255;C=56882;break};case 54:{j=b[4853040]|0;k=j&65535;p=c[2426515]|0;i=p&65535;b[4853030]=i+1&65535;n=c[9757320+(c[1836236]<<2)>>2]|0;l=c[n+76+((p>>>8|768)<<2)>>2]|0;do{if((l|0)==0){br=c[n+4180>>2]|0;if((br|0)==0){b4=0;b5=n;break}P=gj[br&4095](i)|0;b4=P;b5=c[9757320+(c[1836236]<<2)>>2]|0}else{b4=a[l+(p&255)|0]|0;b5=n}}while(0);n=c[b5+76+((k>>>8|256)<<2)>>2]|0;if((n|0)!=0){a[n+(k&255)|0]=b4;C=56882;break L68771}n=c[b5+4184>>2]|0;if((n|0)==0){C=56882;break L68771}gg[n&4095](j,b4);C=56882;break};case 113:{n=b[4853040]|0;p=n&65535;l=a[9706072]|0;i=c[9757320+(c[1836236]<<2)>>2]|0;P=c[i+76+((p>>>8|256)<<2)>>2]|0;if((P|0)!=0){a[P+(p&255)|0]=l;C=56882;break L68771}p=c[i+4184>>2]|0;if((p|0)==0){C=56882;break L68771}gg[p&4095](n,l);C=56882;break};case 43:{b[4853040]=(b[4853040]|0)-1&65535;C=56882;break};case 44:{l=(a[9706080]|0)+1&255;a[9706068]=a[9706068]&1|a[9621712+(l&255)|0];a[9706080]=l;C=56882;break};case 35:{b[4853040]=(b[4853040]|0)+1&65535;C=56882;break};case 36:{l=(a[9706081]|0)+1&255;a[9706068]=a[9706068]&1|a[9621712+(l&255)|0];a[9706081]=l;C=56882;break};case 103:{a[9706081]=a[9706069]|0;C=56882;break};case 104:{a[9706080]=a[9706073]|0;C=56882;break};case 105:{a[9706080]=a[9706072]|0;C=56882;break};case 42:{l=c[2426515]|0;n=l&65535;b[4853030]=n+2&65535;p=c[9757320+(c[1836236]<<2)>>2]|0;i=c[p+76+((l>>>8|768)<<2)>>2]|0;do{if((i|0)==0){P=c[p+4180>>2]|0;if((P|0)==0){b6=0;b7=p;break}br=gj[P&4095](n)|0;b6=br;b7=c[9757320+(c[1836236]<<2)>>2]|0}else{b6=a[i+(l&255)|0]|0;b7=p}}while(0);p=b6&255;i=l+1|0;n=c[b7+76+((i>>>8&255|768)<<2)>>2]|0;do{if((n|0)==0){j=c[b7+4180>>2]|0;if((j|0)==0){b8=0;b9=b7;break}k=gj[j&4095](i&65535)|0;b8=k;b9=c[9757320+(c[1836236]<<2)>>2]|0}else{b8=a[n+(i&255)|0]|0;b9=b7}}while(0);i=b8&255;n=i<<8|p;c[3541536]=n;l=c[b9+76+(i<<2)>>2]|0;do{if((l|0)==0){i=c[b9+4180>>2]|0;if((i|0)==0){ca=0;cb=b9;break}k=gj[i&4095](n&65535)|0;ca=k;cb=c[9757320+(c[1836236]<<2)>>2]|0}else{ca=a[l+p|0]|0;cb=b9}}while(0);a[9706080]=ca;p=n+1|0;l=c[cb+76+((p>>>8&255)<<2)>>2]|0;do{if((l|0)==0){k=c[cb+4180>>2]|0;if((k|0)==0){cc=0;break}cc=gj[k&4095](p&65535)|0}else{cc=a[l+(p&255)|0]|0}}while(0);a[9706081]=cc;C=56882;break};case 126:{p=b[4853040]|0;l=p&65535;n=c[9757320+(c[1836236]<<2)>>2]|0;k=c[n+76+(l>>>8<<2)>>2]|0;do{if((k|0)==0){i=c[n+4180>>2]|0;if((i|0)==0){cd=0;break}cd=gj[i&4095](p)|0}else{cd=a[k+(l&255)|0]|0}}while(0);a[9706069]=cd;C=56882;break};case 193:{l=c[2426516]|0;k=c[9757320+(c[1836236]<<2)>>2]|0;p=c[k+76+(l>>>8<<2)>>2]|0;do{if((p|0)==0){n=c[k+4180>>2]|0;if((n|0)==0){ce=0;cf=k;break}i=gj[n&4095](l&65535)|0;ce=i;cf=c[9757320+(c[1836236]<<2)>>2]|0}else{ce=a[p+(l&255)|0]|0;cf=k}}while(0);a[9706072]=ce;k=l+1|0;p=c[cf+76+((k>>>8&255)<<2)>>2]|0;do{if((p|0)==0){i=c[cf+4180>>2]|0;if((i|0)==0){cg=0;break}cg=gj[i&4095](k&65535)|0}else{cg=a[p+(k&255)|0]|0}}while(0);a[9706073]=cg;b[4853032]=(b[4853032]|0)+2&65535;C=56882;break};case 9:{k=c[2426520]|0;p=c[2426518]|0;l=p+k|0;a[9706068]=(l>>>16&1|a[9706068]&196|l>>>8&40|(p^k^l)>>>8&16)&255;b[4853040]=l&65535;C=56882;break};case 10:{l=b[4853036]|0;k=l&65535;p=c[9757320+(c[1836236]<<2)>>2]|0;i=c[p+76+(k>>>8<<2)>>2]|0;do{if((i|0)==0){n=c[p+4180>>2]|0;if((n|0)==0){ch=0;break}ch=gj[n&4095](l)|0}else{ch=a[i+(k&255)|0]|0}}while(0);a[9706069]=ch;C=56882;break};case 243:{a[9706111]=0;a[9706110]=0;C=56882;break};case 244:{if((a[9706068]|0)<0){ci=(b[4853030]|0)+2&65535}else{k=c[2426515]|0;i=k&65535;b[4853030]=i+2&65535;l=c[9757320+(c[1836236]<<2)>>2]|0;p=c[l+76+((k>>>8|768)<<2)>>2]|0;do{if((p|0)==0){n=c[l+4180>>2]|0;if((n|0)==0){cj=0;ck=l;break}j=gj[n&4095](i)|0;cj=j;ck=c[9757320+(c[1836236]<<2)>>2]|0}else{cj=a[p+(k&255)|0]|0;ck=l}}while(0);l=cj&255;p=k+1|0;i=c[ck+76+((p>>>8&255|768)<<2)>>2]|0;do{if((i|0)==0){j=c[ck+4180>>2]|0;if((j|0)==0){cl=0;cm=ck;break}n=gj[j&4095](p&65535)|0;cl=n;cm=c[9757320+(c[1836236]<<2)>>2]|0}else{cl=a[i+(p&255)|0]|0;cm=ck}}while(0);c[3541536]=(cl&255)<<8|l;b[4853032]=(b[4853032]|0)-2&65535;p=c[2426516]|0;i=a[9706060]|0;k=c[cm+76+((p>>>8|256)<<2)>>2]|0;do{if((k|0)==0){n=c[cm+4184>>2]|0;if((n|0)==0){cn=cm;break}gg[n&4095](p&65535,i);cn=c[9757320+(c[1836236]<<2)>>2]|0}else{a[k+(p&255)|0]=i;cn=cm}}while(0);i=p+1|0;k=a[9706061]|0;l=c[cn+76+((i>>>8&255|256)<<2)>>2]|0;do{if((l|0)==0){n=c[cn+4184>>2]|0;if((n|0)==0){break}gg[n&4095](i&65535,k)}else{a[l+(i&255)|0]=k}}while(0);k=c[3541536]|0;c[2426515]=k;c[2076596]=(c[2076596]|0)-7;ci=k&65535}b[4853030]=ci;C=56882;break};case 8:{k=c[2426517]|0;c[2426517]=c[2426523];c[2426523]=k;C=56882;break};case 23:{k=a[9706069]|0;i=k<<1;l=a[9706068]|0;a[9706068]=l&-60|(k&255)>>>7|i&40;a[9706069]=l&1|i;C=56882;break};case 26:{i=b[4853038]|0;l=i&65535;k=c[9757320+(c[1836236]<<2)>>2]|0;p=c[k+76+(l>>>8<<2)>>2]|0;do{if((p|0)==0){n=c[k+4180>>2]|0;if((n|0)==0){co=0;break}co=gj[n&4095](i)|0}else{co=a[p+(l&255)|0]|0}}while(0);a[9706069]=co;C=56882;break};case 228:{if((a[9706068]&4)==0){l=c[2426515]|0;p=l&65535;b[4853030]=p+2&65535;i=c[9757320+(c[1836236]<<2)>>2]|0;k=c[i+76+((l>>>8|768)<<2)>>2]|0;do{if((k|0)==0){n=c[i+4180>>2]|0;if((n|0)==0){cp=0;cq=i;break}j=gj[n&4095](p)|0;cp=j;cq=c[9757320+(c[1836236]<<2)>>2]|0}else{cp=a[k+(l&255)|0]|0;cq=i}}while(0);i=cp&255;k=l+1|0;p=c[cq+76+((k>>>8&255|768)<<2)>>2]|0;do{if((p|0)==0){j=c[cq+4180>>2]|0;if((j|0)==0){cr=0;cs=cq;break}n=gj[j&4095](k&65535)|0;cr=n;cs=c[9757320+(c[1836236]<<2)>>2]|0}else{cr=a[p+(k&255)|0]|0;cs=cq}}while(0);c[3541536]=(cr&255)<<8|i;b[4853032]=(b[4853032]|0)-2&65535;k=c[2426516]|0;p=a[9706060]|0;l=c[cs+76+((k>>>8|256)<<2)>>2]|0;do{if((l|0)==0){n=c[cs+4184>>2]|0;if((n|0)==0){ct=cs;break}gg[n&4095](k&65535,p);ct=c[9757320+(c[1836236]<<2)>>2]|0}else{a[l+(k&255)|0]=p;ct=cs}}while(0);p=k+1|0;l=a[9706061]|0;i=c[ct+76+((p>>>8&255|256)<<2)>>2]|0;do{if((i|0)==0){n=c[ct+4184>>2]|0;if((n|0)==0){break}gg[n&4095](p&65535,l)}else{a[i+(p&255)|0]=l}}while(0);l=c[3541536]|0;c[2426515]=l;c[2076596]=(c[2076596]|0)-7;cu=l&65535}else{cu=(b[4853030]|0)+2&65535}b[4853030]=cu;C=56882;break};case 29:{l=(a[9706076]|0)-1&255;a[9706068]=a[9706068]&1|a[9621968+(l&255)|0];a[9706076]=l;C=56882;break};case 253:{a[9706108]=(a[9706108]|0)+1&255;l=c[2426515]|0;p=l&65535;b[4853030]=p+1&65535;i=c[9757320+(c[1836236]<<2)>>2]|0;k=c[i+76+((l>>>8|512)<<2)>>2]|0;do{if((k|0)==0){n=c[i+4180>>2]|0;if((n|0)==0){cv=0;cw=g;break}j=gj[n&4095](p)|0;cv=j;cw=c[2076596]|0}else{cv=a[k+(l&255)|0]|0;cw=g}}while(0);l=cv&255;c[2076596]=cw-(d[(c[2426878]|0)+l|0]|0);gu[c[674848+(l<<2)>>2]&16383]();C=56882;break};case 254:{l=c[2426515]|0;k=l&65535;b[4853030]=k+1&65535;p=c[9757320+(c[1836236]<<2)>>2]|0;i=c[p+76+((l>>>8|768)<<2)>>2]|0;do{if((i|0)==0){j=c[p+4180>>2]|0;if((j|0)==0){cx=0;break}cx=gj[j&4095](k)|0}else{cx=a[i+(l&255)|0]|0}}while(0);l=c[2426517]&65280;a[9706068]=a[(c[2385738]|0)+((l>>>8)-(cx&255)&255|l)|0]&-41|cx&40;C=56882;break};case 3:{b[4853036]=(b[4853036]|0)+1&65535;C=56882;break};case 53:{l=b[4853040]|0;i=l&65535;k=i>>>8;p=c[9757320+(c[1836236]<<2)>>2]|0;j=c[p+76+(k<<2)>>2]|0;do{if((j|0)==0){n=c[p+4180>>2]|0;if((n|0)==0){cy=0;cz=p;break}br=gj[n&4095](l)|0;cy=br;cz=c[9757320+(c[1836236]<<2)>>2]|0}else{cy=a[j+(i&255)|0]|0;cz=p}}while(0);p=cy-1&255;a[9706068]=a[9706068]&1|a[9621968+(p&255)|0];j=c[cz+76+((k|256)<<2)>>2]|0;if((j|0)!=0){a[j+(i&255)|0]=p;C=56882;break L68771}j=c[cz+4184>>2]|0;if((j|0)==0){C=56882;break L68771}gg[j&4095](l,p);C=56882;break};case 14:{p=c[2426515]|0;j=p&65535;b[4853030]=j+1&65535;br=c[9757320+(c[1836236]<<2)>>2]|0;n=c[br+76+((p>>>8|768)<<2)>>2]|0;do{if((n|0)==0){P=c[br+4180>>2]|0;if((P|0)==0){cA=0;break}cA=gj[P&4095](j)|0}else{cA=a[n+(p&255)|0]|0}}while(0);a[9706072]=cA;C=56882;break};case 16:{p=(a[9706073]|0)-1&255;a[9706073]=p;if(p<<24>>24==0){cB=(b[4853030]|0)+1&65535}else{p=c[2426515]|0;n=p&65535;j=n+1&65535;b[4853030]=j;br=c[9757320+(c[1836236]<<2)>>2]|0;l=c[br+76+((p>>>8|768)<<2)>>2]|0;do{if((l|0)==0){i=c[br+4180>>2]|0;if((i|0)==0){cC=0;cD=j;cE=g;break}k=gj[i&4095](n)|0;cC=k;cD=b[4853030]|0;cE=c[2076596]|0}else{cC=a[l+(p&255)|0]|0;cD=j;cE=g}}while(0);b[4853030]=cD+(cC<<24>>24)&65535;c[2076596]=cE-5;cB=c[2426515]&65535}b[4853030]=cB;C=56882;break};case 138:{j=c[2426517]|0;p=j&65280;l=j&1;j=(d[9706077]|0)+l+(p>>>8)|0;a[9706068]=a[(c[2385740]|0)+(l<<16|p|j&255)|0]|0;a[9706069]=j&255;C=56882;break};case 236:{if((a[9706068]&4)==0){cF=(b[4853030]|0)+2&65535}else{j=c[2426515]|0;p=j&65535;b[4853030]=p+2&65535;l=c[9757320+(c[1836236]<<2)>>2]|0;n=c[l+76+((j>>>8|768)<<2)>>2]|0;do{if((n|0)==0){br=c[l+4180>>2]|0;if((br|0)==0){cG=0;cH=l;break}k=gj[br&4095](p)|0;cG=k;cH=c[9757320+(c[1836236]<<2)>>2]|0}else{cG=a[n+(j&255)|0]|0;cH=l}}while(0);l=cG&255;n=j+1|0;p=c[cH+76+((n>>>8&255|768)<<2)>>2]|0;do{if((p|0)==0){k=c[cH+4180>>2]|0;if((k|0)==0){cI=0;cJ=cH;break}br=gj[k&4095](n&65535)|0;cI=br;cJ=c[9757320+(c[1836236]<<2)>>2]|0}else{cI=a[p+(n&255)|0]|0;cJ=cH}}while(0);c[3541536]=(cI&255)<<8|l;b[4853032]=(b[4853032]|0)-2&65535;n=c[2426516]|0;p=a[9706060]|0;j=c[cJ+76+((n>>>8|256)<<2)>>2]|0;do{if((j|0)==0){br=c[cJ+4184>>2]|0;if((br|0)==0){cK=cJ;break}gg[br&4095](n&65535,p);cK=c[9757320+(c[1836236]<<2)>>2]|0}else{a[j+(n&255)|0]=p;cK=cJ}}while(0);p=n+1|0;j=a[9706061]|0;l=c[cK+76+((p>>>8&255|256)<<2)>>2]|0;do{if((l|0)==0){br=c[cK+4184>>2]|0;if((br|0)==0){break}gg[br&4095](p&65535,j)}else{a[l+(p&255)|0]=j}}while(0);j=c[3541536]|0;c[2426515]=j;c[2076596]=(c[2076596]|0)-7;cF=j&65535}b[4853030]=cF;C=56882;break};case 245:{b[4853032]=(b[4853032]|0)-2&65535;j=c[2426516]|0;p=a[9706068]|0;l=c[9757320+(c[1836236]<<2)>>2]|0;n=c[l+76+((j>>>8|256)<<2)>>2]|0;do{if((n|0)==0){br=c[l+4184>>2]|0;if((br|0)==0){cL=l;break}gg[br&4095](j&65535,p);cL=c[9757320+(c[1836236]<<2)>>2]|0}else{a[n+(j&255)|0]=p;cL=l}}while(0);l=j+1|0;p=a[9706069]|0;n=c[cL+76+((l>>>8&255|256)<<2)>>2]|0;if((n|0)!=0){a[n+(l&255)|0]=p;C=56882;break L68771}n=c[cL+4184>>2]|0;if((n|0)==0){C=56882;break L68771}gg[n&4095](l&65535,p);C=56882;break};case 246:{p=c[2426515]|0;l=p&65535;b[4853030]=l+1&65535;n=c[9757320+(c[1836236]<<2)>>2]|0;br=c[n+76+((p>>>8|768)<<2)>>2]|0;do{if((br|0)==0){k=c[n+4180>>2]|0;if((k|0)==0){cM=0;break}cM=gj[k&4095](l)|0}else{cM=a[br+(p&255)|0]|0}}while(0);p=a[9706069]|cM;a[9706069]=p;a[9706068]=a[9706144+(p&255)|0]|0;C=56882;break};case 247:{b[4853032]=(b[4853032]|0)-2&65535;p=c[2426516]|0;br=a[9706060]|0;l=c[9757320+(c[1836236]<<2)>>2]|0;n=c[l+76+((p>>>8|256)<<2)>>2]|0;do{if((n|0)==0){j=c[l+4184>>2]|0;if((j|0)==0){cN=l;break}gg[j&4095](p&65535,br);cN=c[9757320+(c[1836236]<<2)>>2]|0}else{a[n+(p&255)|0]=br;cN=l}}while(0);l=p+1|0;br=a[9706061]|0;n=c[cN+76+((l>>>8&255|256)<<2)>>2]|0;do{if((n|0)==0){j=c[cN+4184>>2]|0;if((j|0)==0){break}gg[j&4095](l&65535,br)}else{a[n+(l&255)|0]=br}}while(0);c[2426515]=48;b[4853030]=48;C=56882;break};case 22:{br=c[2426515]|0;l=br&65535;b[4853030]=l+1&65535;n=c[9757320+(c[1836236]<<2)>>2]|0;p=c[n+76+((br>>>8|768)<<2)>>2]|0;do{if((p|0)==0){j=c[n+4180>>2]|0;if((j|0)==0){cO=0;break}cO=gj[j&4095](l)|0}else{cO=a[p+(br&255)|0]|0}}while(0);a[9706077]=cO;C=56882;break};case 57:{br=c[2426520]|0;p=c[2426516]|0;l=p+br|0;a[9706068]=(l>>>16&1|a[9706068]&196|l>>>8&40|(p^br^l)>>>8&16)&255;b[4853040]=l&65535;C=56882;break};case 58:{l=c[2426515]|0;br=l&65535;b[4853030]=br+2&65535;p=c[9757320+(c[1836236]<<2)>>2]|0;n=c[p+76+((l>>>8|768)<<2)>>2]|0;do{if((n|0)==0){j=c[p+4180>>2]|0;if((j|0)==0){cP=0;cQ=p;break}k=gj[j&4095](br)|0;cP=k;cQ=c[9757320+(c[1836236]<<2)>>2]|0}else{cP=a[n+(l&255)|0]|0;cQ=p}}while(0);p=cP&255;n=l+1|0;br=c[cQ+76+((n>>>8&255|768)<<2)>>2]|0;do{if((br|0)==0){k=c[cQ+4180>>2]|0;if((k|0)==0){cR=0;cS=cQ;break}j=gj[k&4095](n&65535)|0;cR=j;cS=c[9757320+(c[1836236]<<2)>>2]|0}else{cR=a[br+(n&255)|0]|0;cS=cQ}}while(0);n=cR&255;br=n<<8|p;c[3541536]=br;l=c[cS+76+(n<<2)>>2]|0;do{if((l|0)==0){n=c[cS+4180>>2]|0;if((n|0)==0){cT=0;break}cT=gj[n&4095](br&65535)|0}else{cT=a[l+p|0]|0}}while(0);a[9706069]=cT;C=56882;break};case 60:{p=(a[9706069]|0)+1&255;a[9706068]=a[9706068]&1|a[9621712+(p&255)|0];a[9706069]=p;C=56882;break};case 61:{p=(a[9706069]|0)-1&255;a[9706068]=a[9706068]&1|a[9621968+(p&255)|0];a[9706069]=p;C=56882;break};case 62:{p=c[2426515]|0;l=p&65535;b[4853030]=l+1&65535;br=c[9757320+(c[1836236]<<2)>>2]|0;n=c[br+76+((p>>>8|768)<<2)>>2]|0;do{if((n|0)==0){j=c[br+4180>>2]|0;if((j|0)==0){cU=0;break}cU=gj[j&4095](l)|0}else{cU=a[n+(p&255)|0]|0}}while(0);a[9706069]=cU;C=56882;break};case 68:{a[9706073]=a[9706081]|0;C=56882;break};case 69:{a[9706073]=a[9706080]|0;C=56882;break};case 70:{p=b[4853040]|0;n=p&65535;l=c[9757320+(c[1836236]<<2)>>2]|0;br=c[l+76+(n>>>8<<2)>>2]|0;do{if((br|0)==0){j=c[l+4180>>2]|0;if((j|0)==0){cV=0;break}cV=gj[j&4095](p)|0}else{cV=a[br+(n&255)|0]|0}}while(0);a[9706073]=cV;C=56882;break};case 248:{if((a[9706068]|0)>=0){C=56882;break L68771}n=c[2426516]|0;br=c[9757320+(c[1836236]<<2)>>2]|0;p=c[br+76+(n>>>8<<2)>>2]|0;do{if((p|0)==0){l=c[br+4180>>2]|0;if((l|0)==0){cW=0;cX=br;break}j=gj[l&4095](n&65535)|0;cW=j;cX=c[9757320+(c[1836236]<<2)>>2]|0}else{cW=a[p+(n&255)|0]|0;cX=br}}while(0);a[9706060]=cW;br=n+1|0;p=c[cX+76+((br>>>8&255)<<2)>>2]|0;do{if((p|0)==0){j=c[cX+4180>>2]|0;if((j|0)==0){cY=0;break}cY=gj[j&4095](br&65535)|0}else{cY=a[p+(br&255)|0]|0}}while(0);a[9706061]=cY;b[4853032]=(b[4853032]|0)+2&65535;b[4853030]=c[2426515]&65535;br=(c[2076596]|0)-6|0;c[2076596]=br;V=br;break};case 249:{b[4853032]=b[4853040]|0;C=56882;break};case 250:{if((a[9706068]|0)<0){br=c[2426515]|0;p=br&65535;b[4853030]=p+2&65535;n=c[9757320+(c[1836236]<<2)>>2]|0;j=c[n+76+((br>>>8|768)<<2)>>2]|0;do{if((j|0)==0){l=c[n+4180>>2]|0;if((l|0)==0){cZ=0;c_=n;break}k=gj[l&4095](p)|0;cZ=k;c_=c[9757320+(c[1836236]<<2)>>2]|0}else{cZ=a[j+(br&255)|0]|0;c_=n}}while(0);n=cZ&255;j=br+1|0;p=c[c_+76+((j>>>8&255|768)<<2)>>2]|0;do{if((p|0)==0){k=c[c_+4180>>2]|0;if((k|0)==0){c$=0;break}c$=gj[k&4095](j&65535)|0}else{c$=a[p+(j&255)|0]|0}}while(0);j=(c$&255)<<8|n;c[2426515]=j;c0=j&65535}else{c0=(b[4853030]|0)+2&65535}b[4853030]=c0;C=56882;break};case 251:{a[9706111]=1;a[9706110]=1;a[9706118]=1;C=56882;break};case 252:{if((a[9706068]|0)<0){j=c[2426515]|0;p=j&65535;b[4853030]=p+2&65535;br=c[9757320+(c[1836236]<<2)>>2]|0;k=c[br+76+((j>>>8|768)<<2)>>2]|0;do{if((k|0)==0){l=c[br+4180>>2]|0;if((l|0)==0){c1=0;c2=br;break}i=gj[l&4095](p)|0;c1=i;c2=c[9757320+(c[1836236]<<2)>>2]|0}else{c1=a[k+(j&255)|0]|0;c2=br}}while(0);br=c1&255;k=j+1|0;p=c[c2+76+((k>>>8&255|768)<<2)>>2]|0;do{if((p|0)==0){n=c[c2+4180>>2]|0;if((n|0)==0){c3=0;c4=c2;break}i=gj[n&4095](k&65535)|0;c3=i;c4=c[9757320+(c[1836236]<<2)>>2]|0}else{c3=a[p+(k&255)|0]|0;c4=c2}}while(0);c[3541536]=(c3&255)<<8|br;b[4853032]=(b[4853032]|0)-2&65535;k=c[2426516]|0;p=a[9706060]|0;j=c[c4+76+((k>>>8|256)<<2)>>2]|0;do{if((j|0)==0){i=c[c4+4184>>2]|0;if((i|0)==0){c5=c4;break}gg[i&4095](k&65535,p);c5=c[9757320+(c[1836236]<<2)>>2]|0}else{a[j+(k&255)|0]=p;c5=c4}}while(0);p=k+1|0;j=a[9706061]|0;br=c[c5+76+((p>>>8&255|256)<<2)>>2]|0;do{if((br|0)==0){i=c[c5+4184>>2]|0;if((i|0)==0){break}gg[i&4095](p&65535,j)}else{a[br+(p&255)|0]=j}}while(0);j=c[3541536]|0;c[2426515]=j;c[2076596]=(c[2076596]|0)-7;c6=j&65535}else{c6=(b[4853030]|0)+2&65535}b[4853030]=c6;C=56882;break};case 31:{j=a[9706069]|0;p=(j&255)>>>1;br=a[9706068]|0;a[9706068]=br&-60|j&1|p&40;a[9706069]=br<<7|p;C=56882;break};case 11:{b[4853036]=(b[4853036]|0)-1&65535;C=56882;break};case 12:{p=(a[9706072]|0)+1&255;a[9706068]=a[9706068]&1|a[9621712+(p&255)|0];a[9706072]=p;C=56882;break};case 7:{p=a[9706069]|0;br=p<<1|(p&255)>>>7;a[9706069]=br;a[9706068]=br&41|a[9706068]&-60;C=56882;break};case 55:{a[9706068]=a[9706068]&-60|a[9706069]&40|1;C=56882;break};case 5:{br=(a[9706073]|0)-1&255;a[9706068]=a[9706068]&1|a[9621968+(br&255)|0];a[9706073]=br;C=56882;break};case 6:{br=c[2426515]|0;p=br&65535;b[4853030]=p+1&65535;j=c[9757320+(c[1836236]<<2)>>2]|0;k=c[j+76+((br>>>8|768)<<2)>>2]|0;do{if((k|0)==0){i=c[j+4180>>2]|0;if((i|0)==0){c7=0;break}c7=gj[i&4095](p)|0}else{c7=a[k+(br&255)|0]|0}}while(0);a[9706073]=c7;C=56882;break};case 13:{br=(a[9706072]|0)-1&255;a[9706068]=a[9706068]&1|a[9621968+(br&255)|0];a[9706072]=br;C=56882;break};case 116:{br=b[4853040]|0;k=br&65535;p=a[9706081]|0;j=c[9757320+(c[1836236]<<2)>>2]|0;i=c[j+76+((k>>>8|256)<<2)>>2]|0;if((i|0)!=0){a[i+(k&255)|0]=p;C=56882;break L68771}k=c[j+4184>>2]|0;if((k|0)==0){C=56882;break L68771}gg[k&4095](br,p);C=56882;break};case 139:{p=c[2426517]|0;br=p&65280;k=p&1;p=(d[9706076]|0)+k+(br>>>8)|0;a[9706068]=a[(c[2385740]|0)+(k<<16|br|p&255)|0]|0;a[9706069]=p&255;C=56882;break};case 140:{p=c[2426517]|0;br=p&65280;k=p&1;p=(d[9706081]|0)+k+(br>>>8)|0;a[9706068]=a[(c[2385740]|0)+(k<<16|br|p&255)|0]|0;a[9706069]=p&255;C=56882;break};case 141:{p=c[2426517]|0;br=p&65280;k=p&1;p=(d[9706080]|0)+k+(br>>>8)|0;a[9706068]=a[(c[2385740]|0)+(k<<16|br|p&255)|0]|0;a[9706069]=p&255;C=56882;break};case 142:{p=c[2426517]|0;br=p&65280;k=p&1;p=br>>>8;j=b[4853040]|0;i=j&65535;n=c[9757320+(c[1836236]<<2)>>2]|0;l=c[n+76+(i>>>8<<2)>>2]|0;do{if((l|0)==0){P=c[n+4180>>2]|0;if((P|0)==0){c8=0;break}c8=gj[P&4095](j)|0}else{c8=a[l+(i&255)|0]|0}}while(0);i=p+k+(c8&255)|0;a[9706068]=a[(c[2385740]|0)+(k<<16|br|i&255)|0]|0;a[9706069]=i&255;C=56882;break};case 27:{b[4853038]=(b[4853038]|0)-1&65535;C=56882;break};case 28:{i=(a[9706076]|0)+1&255;a[9706068]=a[9706068]&1|a[9621712+(i&255)|0];a[9706076]=i;C=56882;break};case 1:{i=c[2426515]|0;l=i&65535;b[4853030]=l+2&65535;j=c[9757320+(c[1836236]<<2)>>2]|0;n=c[j+76+((i>>>8|768)<<2)>>2]|0;do{if((n|0)==0){P=c[j+4180>>2]|0;if((P|0)==0){c9=0;da=j;break}h=gj[P&4095](l)|0;c9=h;da=c[9757320+(c[1836236]<<2)>>2]|0}else{c9=a[n+(i&255)|0]|0;da=j}}while(0);j=c9&255;n=i+1|0;l=c[da+76+((n>>>8&255|768)<<2)>>2]|0;do{if((l|0)==0){br=c[da+4180>>2]|0;if((br|0)==0){db=0;break}db=gj[br&4095](n&65535)|0}else{db=a[l+(n&255)|0]|0}}while(0);b[4853036]=(db&255)<<8|j;C=56882;break};case 131:{n=c[2426517]&65280;l=(n>>>8)+(d[9706076]|0)|0;a[9706068]=a[(c[2385740]|0)+(l&255|n)|0]|0;a[9706069]=l&255;C=56882;break};case 132:{l=c[2426517]&65280;n=(l>>>8)+(d[9706081]|0)|0;a[9706068]=a[(c[2385740]|0)+(n&255|l)|0]|0;a[9706069]=n&255;C=56882;break};case 133:{n=c[2426517]&65280;l=(n>>>8)+(d[9706080]|0)|0;a[9706068]=a[(c[2385740]|0)+(l&255|n)|0]|0;a[9706069]=l&255;C=56882;break};case 49:{l=c[2426515]|0;n=l&65535;b[4853030]=n+2&65535;i=c[9757320+(c[1836236]<<2)>>2]|0;br=c[i+76+((l>>>8|768)<<2)>>2]|0;do{if((br|0)==0){k=c[i+4180>>2]|0;if((k|0)==0){dc=0;dd=i;break}p=gj[k&4095](n)|0;dc=p;dd=c[9757320+(c[1836236]<<2)>>2]|0}else{dc=a[br+(l&255)|0]|0;dd=i}}while(0);i=dc&255;br=l+1|0;n=c[dd+76+((br>>>8&255|768)<<2)>>2]|0;do{if((n|0)==0){j=c[dd+4180>>2]|0;if((j|0)==0){de=0;break}de=gj[j&4095](br&65535)|0}else{de=a[n+(br&255)|0]|0}}while(0);b[4853032]=(de&255)<<8|i;C=56882;break};case 117:{br=b[4853040]|0;n=br&65535;l=br&255;j=c[9757320+(c[1836236]<<2)>>2]|0;p=c[j+76+((n>>>8|256)<<2)>>2]|0;if((p|0)!=0){a[p+(n&255)|0]=l;C=56882;break L68771}n=c[j+4184>>2]|0;if((n|0)==0){C=56882;break L68771}gg[n&4095](br,l);C=56882;break};case 118:{b[4853030]=(b[4853030]|0)-1&65535;a[9706112]=1;if((a[9706117]|0)!=0){C=56882;break L68771}if((g|0)<=0){df=g;C=56885;break L68713}l=(g+3|0)/4|0;a[9706108]=(d[9706108]|0)+l&255;br=g-(l<<2)|0;c[2076596]=br;V=br;break};case 119:{br=b[4853040]|0;l=br&65535;n=a[9706069]|0;j=c[9757320+(c[1836236]<<2)>>2]|0;p=c[j+76+((l>>>8|256)<<2)>>2]|0;if((p|0)!=0){a[p+(l&255)|0]=n;C=56882;break L68771}l=c[j+4184>>2]|0;if((l|0)==0){C=56882;break L68771}gg[l&4095](br,n);C=56882;break};case 135:{n=c[2426517]&65280;br=(n>>>8)+(d[9706069]|0)|0;a[9706068]=a[(c[2385740]|0)+(br&255|n)|0]|0;a[9706069]=br&255;C=56882;break};case 136:{br=c[2426517]|0;n=br&65280;l=br&1;br=(d[9706073]|0)+l+(n>>>8)|0;a[9706068]=a[(c[2385740]|0)+(l<<16|n|br&255)|0]|0;a[9706069]=br&255;C=56882;break};case 137:{br=c[2426517]|0;n=br&65280;l=br&1;br=(d[9706072]|0)+l+(n>>>8)|0;a[9706068]=a[(c[2385740]|0)+(l<<16|n|br&255)|0]|0;a[9706069]=br&255;C=56882;break};case 39:{gfe();C=56882;break};case 40:{if((a[9706068]&64)==0){dg=(b[4853030]|0)+1&65535}else{br=c[2426515]|0;n=br&65535;l=n+1&65535;b[4853030]=l;j=c[9757320+(c[1836236]<<2)>>2]|0;p=c[j+76+((br>>>8|768)<<2)>>2]|0;do{if((p|0)==0){k=c[j+4180>>2]|0;if((k|0)==0){dh=0;di=l;dj=g;break}h=gj[k&4095](n)|0;dh=h;di=b[4853030]|0;dj=c[2076596]|0}else{dh=a[p+(br&255)|0]|0;di=l;dj=g}}while(0);b[4853030]=di+(dh<<24>>24)&65535;c[2076596]=dj-5;dg=c[2426515]&65535}b[4853030]=dg;C=56882;break};case 120:{a[9706069]=a[9706073]|0;C=56882;break};case 121:{a[9706069]=a[9706072]|0;C=56882;break};case 122:{a[9706069]=a[9706077]|0;C=56882;break};case 123:{a[9706069]=a[9706076]|0;C=56882;break};case 124:{a[9706069]=a[9706081]|0;C=56882;break};case 125:{a[9706069]=a[9706080]|0;C=56882;break};case 95:{a[9706076]=a[9706069]|0;C=56882;break};case 96:{a[9706081]=a[9706073]|0;C=56882;break};case 97:{a[9706081]=a[9706072]|0;C=56882;break};case 98:{a[9706081]=a[9706077]|0;C=56882;break};case 18:{l=b[4853038]|0;br=l&65535;p=a[9706069]|0;n=c[9757320+(c[1836236]<<2)>>2]|0;j=c[n+76+((br>>>8|256)<<2)>>2]|0;if((j|0)!=0){a[j+(br&255)|0]=p;C=56882;break L68771}br=c[n+4184>>2]|0;if((br|0)==0){C=56882;break L68771}gg[br&4095](l,p);C=56882;break};case 201:{p=c[2426516]|0;l=c[9757320+(c[1836236]<<2)>>2]|0;br=c[l+76+(p>>>8<<2)>>2]|0;do{if((br|0)==0){n=c[l+4180>>2]|0;if((n|0)==0){dk=0;dl=l;break}j=gj[n&4095](p&65535)|0;dk=j;dl=c[9757320+(c[1836236]<<2)>>2]|0}else{dk=a[br+(p&255)|0]|0;dl=l}}while(0);a[9706060]=dk;l=p+1|0;br=c[dl+76+((l>>>8&255)<<2)>>2]|0;do{if((br|0)==0){j=c[dl+4180>>2]|0;if((j|0)==0){dm=0;break}dm=gj[j&4095](l&65535)|0}else{dm=a[br+(l&255)|0]|0}}while(0);a[9706061]=dm;b[4853032]=(b[4853032]|0)+2&65535;b[4853030]=c[2426515]&65535;C=56882;break};case 231:{b[4853032]=(b[4853032]|0)-2&65535;l=c[2426516]|0;br=a[9706060]|0;p=c[9757320+(c[1836236]<<2)>>2]|0;j=c[p+76+((l>>>8|256)<<2)>>2]|0;do{if((j|0)==0){n=c[p+4184>>2]|0;if((n|0)==0){dn=p;break}gg[n&4095](l&65535,br);dn=c[9757320+(c[1836236]<<2)>>2]|0}else{a[j+(l&255)|0]=br;dn=p}}while(0);p=l+1|0;br=a[9706061]|0;j=c[dn+76+((p>>>8&255|256)<<2)>>2]|0;do{if((j|0)==0){n=c[dn+4184>>2]|0;if((n|0)==0){break}gg[n&4095](p&65535,br)}else{a[j+(p&255)|0]=br}}while(0);c[2426515]=32;b[4853030]=32;C=56882;break};case 232:{if((a[9706068]&4)==0){C=56882;break L68771}br=c[2426516]|0;p=c[9757320+(c[1836236]<<2)>>2]|0;j=c[p+76+(br>>>8<<2)>>2]|0;do{if((j|0)==0){l=c[p+4180>>2]|0;if((l|0)==0){dp=0;dq=p;break}n=gj[l&4095](br&65535)|0;dp=n;dq=c[9757320+(c[1836236]<<2)>>2]|0}else{dp=a[j+(br&255)|0]|0;dq=p}}while(0);a[9706060]=dp;p=br+1|0;j=c[dq+76+((p>>>8&255)<<2)>>2]|0;do{if((j|0)==0){n=c[dq+4180>>2]|0;if((n|0)==0){dr=0;break}dr=gj[n&4095](p&65535)|0}else{dr=a[j+(p&255)|0]|0}}while(0);a[9706061]=dr;b[4853032]=(b[4853032]|0)+2&65535;b[4853030]=c[2426515]&65535;p=(c[2076596]|0)-6|0;c[2076596]=p;V=p;break};case 235:{p=c[2426519]|0;c[2426519]=c[2426520];c[2426520]=p;C=56882;break};case 24:{gfd();C=56882;break};case 25:{p=c[2426520]|0;j=c[2426519]|0;br=j+p|0;a[9706068]=(br>>>16&1|a[9706068]&196|br>>>8&40|(j^p^br)>>>8&16)&255;b[4853040]=br&65535;C=56882;break};case 233:{b[4853030]=b[4853040]|0;b[4853030]=c[2426515]&65535;C=56882;break};case 234:{if((a[9706068]&4)==0){ds=(b[4853030]|0)+2&65535}else{br=c[2426515]|0;p=br&65535;b[4853030]=p+2&65535;j=c[9757320+(c[1836236]<<2)>>2]|0;n=c[j+76+((br>>>8|768)<<2)>>2]|0;do{if((n|0)==0){l=c[j+4180>>2]|0;if((l|0)==0){dt=0;du=j;break}i=gj[l&4095](p)|0;dt=i;du=c[9757320+(c[1836236]<<2)>>2]|0}else{dt=a[n+(br&255)|0]|0;du=j}}while(0);j=dt&255;n=br+1|0;p=c[du+76+((n>>>8&255|768)<<2)>>2]|0;do{if((p|0)==0){i=c[du+4180>>2]|0;if((i|0)==0){dv=0;break}dv=gj[i&4095](n&65535)|0}else{dv=a[p+(n&255)|0]|0}}while(0);n=(dv&255)<<8|j;c[2426515]=n;ds=n&65535}b[4853030]=ds;C=56882;break};case 63:{n=a[9706068]|0;a[9706068]=(n<<4&16|n&-59|a[9706069]&40)^1;C=56882;break};case 65:{a[9706073]=a[9706072]|0;C=56882;break};case 66:{a[9706073]=a[9706077]|0;C=56882;break};case 67:{a[9706073]=a[9706076]|0;C=56882;break};case 59:{b[4853032]=(b[4853032]|0)-1&65535;C=56882;break};case 48:{if((a[9706068]&1)==0){n=c[2426515]|0;p=n&65535;br=p+1&65535;b[4853030]=br;i=c[9757320+(c[1836236]<<2)>>2]|0;l=c[i+76+((n>>>8|768)<<2)>>2]|0;do{if((l|0)==0){h=c[i+4180>>2]|0;if((h|0)==0){dw=0;dx=br;dy=g;break}k=gj[h&4095](p)|0;dw=k;dx=b[4853030]|0;dy=c[2076596]|0}else{dw=a[l+(n&255)|0]|0;dx=br;dy=g}}while(0);b[4853030]=dx+(dw<<24>>24)&65535;c[2076596]=dy-5;dz=c[2426515]&65535}else{dz=(b[4853030]|0)+1&65535}b[4853030]=dz;C=56882;break};case 46:{br=c[2426515]|0;n=br&65535;b[4853030]=n+1&65535;l=c[9757320+(c[1836236]<<2)>>2]|0;p=c[l+76+((br>>>8|768)<<2)>>2]|0;do{if((p|0)==0){i=c[l+4180>>2]|0;if((i|0)==0){dA=0;break}dA=gj[i&4095](n)|0}else{dA=a[p+(br&255)|0]|0}}while(0);a[9706080]=dA;C=56882;break};case 211:{br=c[2426515]|0;p=br&65535;b[4853030]=p+1&65535;n=c[9757320+(c[1836236]<<2)>>2]|0;l=c[n+76+((br>>>8|768)<<2)>>2]|0;do{if((l|0)==0){i=c[n+4180>>2]|0;if((i|0)==0){dB=0;dC=n;break}j=gj[i&4095](p)|0;dB=j;dC=c[9757320+(c[1836236]<<2)>>2]|0}else{dB=a[l+(br&255)|0]|0;dC=n}}while(0);n=a[9706069]|0;gg[c[dC+4176>>2]&4095]((n&255)<<8|dB&255,n);C=56882;break};case 51:{b[4853032]=(b[4853032]|0)+1&65535;C=56882;break};case 52:{n=b[4853040]|0;br=n&65535;l=br>>>8;p=c[9757320+(c[1836236]<<2)>>2]|0;j=c[p+76+(l<<2)>>2]|0;do{if((j|0)==0){i=c[p+4180>>2]|0;if((i|0)==0){dD=0;dE=p;break}k=gj[i&4095](n)|0;dD=k;dE=c[9757320+(c[1836236]<<2)>>2]|0}else{dD=a[j+(br&255)|0]|0;dE=p}}while(0);p=dD+1&255;a[9706068]=a[9706068]&1|a[9621712+(p&255)|0];j=c[dE+76+((l|256)<<2)>>2]|0;if((j|0)!=0){a[j+(br&255)|0]=p;C=56882;break L68771}j=c[dE+4184>>2]|0;if((j|0)==0){C=56882;break L68771}gg[j&4095](n,p);C=56882;break};case 255:{b[4853032]=(b[4853032]|0)-2&65535;p=c[2426516]|0;j=a[9706060]|0;k=c[9757320+(c[1836236]<<2)>>2]|0;i=c[k+76+((p>>>8|256)<<2)>>2]|0;do{if((i|0)==0){h=c[k+4184>>2]|0;if((h|0)==0){dF=k;break}gg[h&4095](p&65535,j);dF=c[9757320+(c[1836236]<<2)>>2]|0}else{a[i+(p&255)|0]=j;dF=k}}while(0);k=p+1|0;j=a[9706061]|0;i=c[dF+76+((k>>>8&255|256)<<2)>>2]|0;do{if((i|0)==0){n=c[dF+4184>>2]|0;if((n|0)==0){break}gg[n&4095](k&65535,j)}else{a[i+(k&255)|0]=j}}while(0);c[2426515]=56;b[4853030]=56;C=56882;break};default:{V=g}}}while(0);if((C|0)==56882){C=0;V=c[2076596]|0}if((V|0)>0){f=V}else{df=V;C=56886;break}}if((C|0)==56885){c[2426530]=0;dG=e-df|0;return dG|0}else if((C|0)==56886){c[2426530]=0;dG=e-df|0;return dG|0}return 0}function gfd(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=c[2426515]|0;f=e-1|0;g=e&65535;h=g+1&65535;b[4853030]=h;i=c[9757320+(c[1836236]<<2)>>2]|0;j=c[i+76+((e>>>8|768)<<2)>>2]|0;do{if((j|0)==0){k=c[i+4180>>2]|0;if((k|0)==0){l=0;m=h;break}n=gj[k&4095](g)|0;l=n;m=b[4853030]|0}else{l=a[j+(e&255)|0]|0;m=h}}while(0);b[4853030]=m+(l<<24>>24)&65535;b[4853030]=c[2426515]&65535;l=c[2426515]|0;if((l|0)==(f|0)){if((a[9706117]|0)!=0){return}f=c[2076596]|0;if((f|0)<=0){return}m=(f|0)/12|0;a[9706108]=(d[9706108]|0)+m&255;c[2076596]=(m*-12|0)+f;return}f=c[9757320+(c[1836236]<<2)>>2]|0;m=c[f+76+((l>>>8|512)<<2)>>2]|0;do{if((m|0)==0){h=c[f+4180>>2]|0;if((h|0)==0){o=0;p=l;break}j=gj[h&4095](l&65535)|0;o=j;p=c[2426515]|0}else{o=a[m+(l&255)|0]|0;p=l}}while(0);if((p|0)!=(e-2|0)){if(!((p|0)==(e-4|0)&o<<24>>24==49&(a[9706117]|0)==0)){return}e=c[2076596]|0;p=e-10|0;if((p|0)<=0){return}l=(p|0)/22|0;a[9706108]=(d[9706108]|0)+(l<<1)&255;c[2076596]=(l*-22|0)+e;return}if(!((o<<24>>24|0)==0|(o<<24>>24|0)==(-5|0))){return}if((a[9706117]|0)!=0){return}o=c[2076596]|0;e=o-4|0;if((e|0)<=0){return}l=(e|0)/16|0;a[9706108]=(d[9706108]|0)+(l<<1)&255;c[2076596]=o-(l<<4);return}function gfe(){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=a[9706068]|0;c=b&2;d=b&16;e=a[9706069]|0;f=e&15;g=(b&1)!=0;do{if(g){if((f&255)>=10){h=102;break}h=d<<24>>24!=0?102:96}else{if((f&255)>9){h=(e&255)<144?6:102;break}b=d<<24>>24!=0;if((e&255)>159){h=b?102:96;break}else{h=b?6:0;break}}}while(0);b=c<<24>>24!=0;i=(b?-h&255:h)+e&255;a[9706069]=i;h=a[9706144+(i&255)|0]|c;a[9706068]=h;do{if(g){j=56930}else{if((f&255)<10){if((e&255)>159){j=56930;break}else{k=h;break}}else{if((e&255)>143){j=56930;break}else{k=h;break}}}}while(0);if((j|0)==56930){j=h|1;a[9706068]=j;k=j}do{if(b){if(d<<24>>24!=0&(f&255)<6){break}return}else{if((f&255)>9){break}return}}while(0);a[9706068]=k|16;return}function gff(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=c[2426515]|0;f=e-1|0;g=e&65535;b[4853030]=g+2&65535;h=c[9757320+(c[1836236]<<2)>>2]|0;i=c[h+76+((e>>>8|768)<<2)>>2]|0;do{if((i|0)==0){j=c[h+4180>>2]|0;if((j|0)==0){k=0;l=h;break}m=gj[j&4095](g)|0;k=m;l=c[9757320+(c[1836236]<<2)>>2]|0}else{k=a[i+(e&255)|0]|0;l=h}}while(0);h=k&255;k=e+1|0;i=c[l+76+((k>>>8&255|768)<<2)>>2]|0;do{if((i|0)==0){g=c[l+4180>>2]|0;if((g|0)==0){n=0;break}n=gj[g&4095](k&65535)|0}else{n=a[i+(k&255)|0]|0}}while(0);k=(n&255)<<8|h;c[2426515]=k;b[4853030]=k&65535;k=c[2426515]|0;if((k|0)==(f|0)){if((a[9706117]|0)!=0){return}f=c[2076596]|0;if((f|0)<=0){return}h=(f|0)/10|0;a[9706108]=(d[9706108]|0)+h&255;c[2076596]=(h*-10|0)+f;return}f=c[9757320+(c[1836236]<<2)>>2]|0;h=c[f+76+((k>>>8|512)<<2)>>2]|0;do{if((h|0)==0){n=c[f+4180>>2]|0;if((n|0)==0){o=0;p=k;break}i=gj[n&4095](k&65535)|0;o=i;p=c[2426515]|0}else{o=a[h+(k&255)|0]|0;p=k}}while(0);if((p|0)!=(e-2|0)){if(!((p|0)==(e-4|0)&o<<24>>24==49&(a[9706117]|0)==0)){return}e=c[2076596]|0;p=e-10|0;if((p|0)<=0){return}k=(p|0)/20|0;a[9706108]=(d[9706108]|0)+(k<<1)&255;c[2076596]=(k*-20|0)+e;return}if(!((o<<24>>24|0)==0|(o<<24>>24|0)==(-5|0))){return}if((a[9706117]|0)!=0){return}o=c[2076596]|0;e=o-4|0;if((e|0)<=0){return}k=(e|0)/14|0;a[9706108]=(d[9706108]|0)+(k<<1)&255;c[2076596]=(k*-14|0)+o;return}function gfg(){return}function gfh(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=c[2426515]|0;e=d&65535;b[4853030]=e+2&65535;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+((d>>>8|768)<<2)>>2]|0;do{if((g|0)==0){h=c[f+4180>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](e)|0;i=k;j=c[9757320+(c[1836236]<<2)>>2]|0}else{i=a[g+(d&255)|0]|0;j=f}}while(0);f=i&255;i=d+1|0;d=c[j+76+((i>>>8&255|768)<<2)>>2]|0;if((d|0)!=0){l=a[d+(i&255)|0]|0;m=l&255;n=m<<8;o=n|f;b[4853036]=o;return}d=c[j+4180>>2]|0;if((d|0)==0){l=0;m=l&255;n=m<<8;o=n|f;b[4853036]=o;return}l=gj[d&4095](i&65535)|0;m=l&255;n=m<<8;o=n|f;b[4853036]=o;return}function gfi(){var d=0,e=0,f=0,g=0,h=0;d=b[4853036]|0;e=d&65535;f=a[9706069]|0;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|256)<<2)>>2]|0;if((h|0)!=0){a[h+(e&255)|0]=f;return}e=c[g+4184>>2]|0;if((e|0)==0){return}gg[e&4095](d,f);return}function gfj(){b[4853036]=(b[4853036]|0)+1&65535;return}function gfk(){var b=0;b=(a[9706073]|0)+1&255;a[9706068]=a[9706068]&1|a[9621712+(b&255)|0];a[9706073]=b;return}function gfl(){var b=0;b=(a[9706073]|0)-1&255;a[9706068]=a[9706068]&1|a[9621968+(b&255)|0];a[9706073]=b;return}function gfm(){var d=0,e=0,f=0,g=0,h=0;d=c[2426515]|0;e=d&65535;b[4853030]=e+1&65535;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+((d>>>8|768)<<2)>>2]|0;if((g|0)!=0){h=a[g+(d&255)|0]|0;a[9706073]=h;return}d=c[f+4180>>2]|0;if((d|0)==0){h=0;a[9706073]=h;return}h=gj[d&4095](e)|0;a[9706073]=h;return}function gfn(){var b=0,c=0;b=a[9706069]|0;c=b<<1|(b&255)>>>7;a[9706069]=c;a[9706068]=c&41|a[9706068]&-60;return}function gfo(){var a=0;a=c[2426517]|0;c[2426517]=c[2426523];c[2426523]=a;return}function gfp(){var d=0,e=0,f=0;d=c[2426522]|0;e=c[2426518]|0;f=e+d|0;a[9706068]=(f>>>16&1|a[9706068]&196|f>>>8&40|(e^d^f)>>>8&16)&255;b[4853044]=f&65535;return}function gfq(){var d=0,e=0,f=0,g=0,h=0;d=b[4853036]|0;e=d&65535;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+(e>>>8<<2)>>2]|0;if((g|0)!=0){h=a[g+(e&255)|0]|0;a[9706069]=h;return}e=c[f+4180>>2]|0;if((e|0)==0){h=0;a[9706069]=h;return}h=gj[e&4095](d)|0;a[9706069]=h;return}function gfr(){b[4853036]=(b[4853036]|0)-1&65535;return}function gfs(){var b=0;b=(a[9706072]|0)+1&255;a[9706068]=a[9706068]&1|a[9621712+(b&255)|0];a[9706072]=b;return}function gft(){var b=0;b=(a[9706072]|0)-1&255;a[9706068]=a[9706068]&1|a[9621968+(b&255)|0];a[9706072]=b;return}function gfu(){var d=0,e=0,f=0,g=0,h=0;d=c[2426515]|0;e=d&65535;b[4853030]=e+1&65535;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+((d>>>8|768)<<2)>>2]|0;if((g|0)!=0){h=a[g+(d&255)|0]|0;a[9706072]=h;return}d=c[f+4180>>2]|0;if((d|0)==0){h=0;a[9706072]=h;return}h=gj[d&4095](e)|0;a[9706072]=h;return}function gfv(){var b=0,c=0,d=0;b=a[9706069]|0;c=b&1|a[9706068]&-60;d=(b&255)>>>1;a[9706069]=d|b<<7;a[9706068]=c|d&40;return}function gfw(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=(a[9706073]|0)-1&255;a[9706073]=d;if(d<<24>>24==0){e=(b[4853030]|0)+1&65535;b[4853030]=e;return}d=c[2426515]|0;f=d&65535;g=f+1&65535;b[4853030]=g;h=c[9757320+(c[1836236]<<2)>>2]|0;i=c[h+76+((d>>>8|768)<<2)>>2]|0;do{if((i|0)==0){j=c[h+4180>>2]|0;if((j|0)==0){k=0;l=g;break}m=gj[j&4095](f)|0;k=m;l=b[4853030]|0}else{k=a[i+(d&255)|0]|0;l=g}}while(0);b[4853030]=l+(k<<24>>24)&65535;c[2076596]=(c[2076596]|0)-5;e=c[2426515]&65535;b[4853030]=e;return}function gfx(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=c[2426515]|0;e=d&65535;b[4853030]=e+2&65535;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+((d>>>8|768)<<2)>>2]|0;do{if((g|0)==0){h=c[f+4180>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](e)|0;i=k;j=c[9757320+(c[1836236]<<2)>>2]|0}else{i=a[g+(d&255)|0]|0;j=f}}while(0);f=i&255;i=d+1|0;d=c[j+76+((i>>>8&255|768)<<2)>>2]|0;if((d|0)!=0){l=a[d+(i&255)|0]|0;m=l&255;n=m<<8;o=n|f;b[4853038]=o;return}d=c[j+4180>>2]|0;if((d|0)==0){l=0;m=l&255;n=m<<8;o=n|f;b[4853038]=o;return}l=gj[d&4095](i&65535)|0;m=l&255;n=m<<8;o=n|f;b[4853038]=o;return}function gfy(){var d=0,e=0,f=0,g=0,h=0;d=b[4853038]|0;e=d&65535;f=a[9706069]|0;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|256)<<2)>>2]|0;if((h|0)!=0){a[h+(e&255)|0]=f;return}e=c[g+4184>>2]|0;if((e|0)==0){return}gg[e&4095](d,f);return}function gfz(){b[4853038]=(b[4853038]|0)+1&65535;return}function gfA(){var b=0;b=(a[9706077]|0)+1&255;a[9706068]=a[9706068]&1|a[9621712+(b&255)|0];a[9706077]=b;return}function gfB(){var b=0;b=(a[9706077]|0)-1&255;a[9706068]=a[9706068]&1|a[9621968+(b&255)|0];a[9706077]=b;return}function gfC(){var d=0,e=0,f=0,g=0,h=0;d=c[2426515]|0;e=d&65535;b[4853030]=e+1&65535;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+((d>>>8|768)<<2)>>2]|0;if((g|0)!=0){h=a[g+(d&255)|0]|0;a[9706077]=h;return}d=c[f+4180>>2]|0;if((d|0)==0){h=0;a[9706077]=h;return}h=gj[d&4095](e)|0;a[9706077]=h;return}function gfD(){var b=0,c=0,d=0;b=a[9706069]|0;c=b<<1;d=a[9706068]|0;a[9706068]=d&-60|(b&255)>>>7|c&40;a[9706069]=d&1|c;return}function gfE(){gfd();return}function gfF(){var d=0,e=0,f=0;d=c[2426522]|0;e=c[2426519]|0;f=e+d|0;a[9706068]=(f>>>16&1|a[9706068]&196|f>>>8&40|(e^d^f)>>>8&16)&255;b[4853044]=f&65535;return}function gfG(){var d=0,e=0,f=0,g=0,h=0;d=b[4853038]|0;e=d&65535;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+(e>>>8<<2)>>2]|0;if((g|0)!=0){h=a[g+(e&255)|0]|0;a[9706069]=h;return}e=c[f+4180>>2]|0;if((e|0)==0){h=0;a[9706069]=h;return}h=gj[e&4095](d)|0;a[9706069]=h;return}function gfH(){b[4853038]=(b[4853038]|0)-1&65535;return}function gfI(){var b=0;b=(a[9706076]|0)+1&255;a[9706068]=a[9706068]&1|a[9621712+(b&255)|0];a[9706076]=b;return}function gfJ(){var b=0;b=(a[9706076]|0)-1&255;a[9706068]=a[9706068]&1|a[9621968+(b&255)|0];a[9706076]=b;return}function gfK(){var d=0,e=0,f=0,g=0,h=0;d=c[2426515]|0;e=d&65535;b[4853030]=e+1&65535;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+((d>>>8|768)<<2)>>2]|0;if((g|0)!=0){h=a[g+(d&255)|0]|0;a[9706076]=h;return}d=c[f+4180>>2]|0;if((d|0)==0){h=0;a[9706076]=h;return}h=gj[d&4095](e)|0;a[9706076]=h;return}function gfL(){var b=0,c=0,d=0;b=a[9706069]|0;c=(b&255)>>>1;d=a[9706068]|0;a[9706068]=d&-60|b&1|c&40;a[9706069]=d<<7|c;return}function gfM(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((a[9706068]&64)!=0){d=(b[4853030]|0)+1&65535;b[4853030]=d;return}e=c[2426515]|0;f=e&65535;g=f+1&65535;b[4853030]=g;h=c[9757320+(c[1836236]<<2)>>2]|0;i=c[h+76+((e>>>8|768)<<2)>>2]|0;do{if((i|0)==0){j=c[h+4180>>2]|0;if((j|0)==0){k=0;l=g;break}m=gj[j&4095](f)|0;k=m;l=b[4853030]|0}else{k=a[i+(e&255)|0]|0;l=g}}while(0);b[4853030]=l+(k<<24>>24)&65535;c[2076596]=(c[2076596]|0)-5;d=c[2426515]&65535;b[4853030]=d;return}function gfN(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=c[2426515]|0;e=d&65535;b[4853030]=e+2&65535;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+((d>>>8|768)<<2)>>2]|0;do{if((g|0)==0){h=c[f+4180>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](e)|0;i=k;j=c[9757320+(c[1836236]<<2)>>2]|0}else{i=a[g+(d&255)|0]|0;j=f}}while(0);f=i&255;i=d+1|0;d=c[j+76+((i>>>8&255|768)<<2)>>2]|0;if((d|0)!=0){l=a[d+(i&255)|0]|0;m=l&255;n=m<<8;o=n|f;b[4853044]=o;return}d=c[j+4180>>2]|0;if((d|0)==0){l=0;m=l&255;n=m<<8;o=n|f;b[4853044]=o;return}l=gj[d&4095](i&65535)|0;m=l&255;n=m<<8;o=n|f;b[4853044]=o;return}function gfO(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=c[2426515]|0;e=d&65535;b[4853030]=e+2&65535;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+((d>>>8|768)<<2)>>2]|0;do{if((g|0)==0){h=c[f+4180>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](e)|0;i=k;j=c[9757320+(c[1836236]<<2)>>2]|0}else{i=a[g+(d&255)|0]|0;j=f}}while(0);f=i&255;i=d+1|0;d=c[j+76+((i>>>8&255|768)<<2)>>2]|0;do{if((d|0)==0){g=c[j+4180>>2]|0;if((g|0)==0){l=0;m=j;break}e=gj[g&4095](i&65535)|0;l=e;m=c[9757320+(c[1836236]<<2)>>2]|0}else{l=a[d+(i&255)|0]|0;m=j}}while(0);j=l&255;l=j<<8|f;c[3541536]=l;i=a[9706088]|0;d=c[m+76+((j|256)<<2)>>2]|0;do{if((d|0)==0){j=c[m+4184>>2]|0;if((j|0)==0){n=m;break}gg[j&4095](l&65535,i);n=c[9757320+(c[1836236]<<2)>>2]|0}else{a[d+f|0]=i;n=m}}while(0);m=l+1|0;l=a[9706089]|0;i=c[n+76+((m>>>8&255|256)<<2)>>2]|0;if((i|0)!=0){a[i+(m&255)|0]=l;return}i=c[n+4184>>2]|0;if((i|0)==0){return}gg[i&4095](m&65535,l);return}function gfP(){b[4853044]=(b[4853044]|0)+1&65535;return}function gfQ(){var b=0;b=(a[9706089]|0)+1&255;a[9706068]=a[9706068]&1|a[9621712+(b&255)|0];a[9706089]=b;return}function gfR(){var b=0;b=(a[9706089]|0)-1&255;a[9706068]=a[9706068]&1|a[9621968+(b&255)|0];a[9706089]=b;return}function gfS(){var d=0,e=0,f=0,g=0,h=0;d=c[2426515]|0;e=d&65535;b[4853030]=e+1&65535;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+((d>>>8|768)<<2)>>2]|0;if((g|0)!=0){h=a[g+(d&255)|0]|0;a[9706089]=h;return}d=c[f+4180>>2]|0;if((d|0)==0){h=0;a[9706089]=h;return}h=gj[d&4095](e)|0;a[9706089]=h;return}function gfT(){gfe();return}function gfU(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((a[9706068]&64)==0){d=(b[4853030]|0)+1&65535;b[4853030]=d;return}e=c[2426515]|0;f=e&65535;g=f+1&65535;b[4853030]=g;h=c[9757320+(c[1836236]<<2)>>2]|0;i=c[h+76+((e>>>8|768)<<2)>>2]|0;do{if((i|0)==0){j=c[h+4180>>2]|0;if((j|0)==0){k=0;l=g;break}m=gj[j&4095](f)|0;k=m;l=b[4853030]|0}else{k=a[i+(e&255)|0]|0;l=g}}while(0);b[4853030]=l+(k<<24>>24)&65535;c[2076596]=(c[2076596]|0)-5;d=c[2426515]&65535;b[4853030]=d;return}function gfV(){var d=0,e=0;d=c[2426522]|0;e=d>>>7;a[9706068]=(d>>>15&1|e&16|e&40|a[9706068]&196)&255;b[4853044]=d<<1&65535;return}function gfW(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=c[2426515]|0;e=d&65535;b[4853030]=e+2&65535;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+((d>>>8|768)<<2)>>2]|0;do{if((g|0)==0){h=c[f+4180>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](e)|0;i=k;j=c[9757320+(c[1836236]<<2)>>2]|0}else{i=a[g+(d&255)|0]|0;j=f}}while(0);f=i&255;i=d+1|0;d=c[j+76+((i>>>8&255|768)<<2)>>2]|0;do{if((d|0)==0){g=c[j+4180>>2]|0;if((g|0)==0){l=0;m=j;break}e=gj[g&4095](i&65535)|0;l=e;m=c[9757320+(c[1836236]<<2)>>2]|0}else{l=a[d+(i&255)|0]|0;m=j}}while(0);j=l&255;l=j<<8|f;c[3541536]=l;i=c[m+76+(j<<2)>>2]|0;do{if((i|0)==0){j=c[m+4180>>2]|0;if((j|0)==0){n=0;o=m;break}d=gj[j&4095](l&65535)|0;n=d;o=c[9757320+(c[1836236]<<2)>>2]|0}else{n=a[i+f|0]|0;o=m}}while(0);a[9706088]=n;n=l+1|0;l=c[o+76+((n>>>8&255)<<2)>>2]|0;if((l|0)!=0){p=a[l+(n&255)|0]|0;a[9706089]=p;return}l=c[o+4180>>2]|0;if((l|0)==0){p=0;a[9706089]=p;return}p=gj[l&4095](n&65535)|0;a[9706089]=p;return}function gfX(){b[4853044]=(b[4853044]|0)-1&65535;return}function gfY(){var b=0;b=(a[9706088]|0)+1&255;a[9706068]=a[9706068]&1|a[9621712+(b&255)|0];a[9706088]=b;return}function gfZ(){var b=0;b=(a[9706088]|0)-1&255;a[9706068]=a[9706068]&1|a[9621968+(b&255)|0];a[9706088]=b;return}function gf_(){var d=0,e=0,f=0,g=0,h=0;d=c[2426515]|0;e=d&65535;b[4853030]=e+1&65535;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+((d>>>8|768)<<2)>>2]|0;if((g|0)!=0){h=a[g+(d&255)|0]|0;a[9706088]=h;return}d=c[f+4180>>2]|0;if((d|0)==0){h=0;a[9706088]=h;return}h=gj[d&4095](e)|0;a[9706088]=h;return}function gf$(){var b=0;b=~a[9706069];a[9706069]=b;a[9706068]=b&40|a[9706068]&-59|18;return}function gf0(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((a[9706068]&1)!=0){d=(b[4853030]|0)+1&65535;b[4853030]=d;return}e=c[2426515]|0;f=e&65535;g=f+1&65535;b[4853030]=g;h=c[9757320+(c[1836236]<<2)>>2]|0;i=c[h+76+((e>>>8|768)<<2)>>2]|0;do{if((i|0)==0){j=c[h+4180>>2]|0;if((j|0)==0){k=0;l=g;break}m=gj[j&4095](f)|0;k=m;l=b[4853030]|0}else{k=a[i+(e&255)|0]|0;l=g}}while(0);b[4853030]=l+(k<<24>>24)&65535;c[2076596]=(c[2076596]|0)-5;d=c[2426515]&65535;b[4853030]=d;return}function gf1(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=c[2426515]|0;e=d&65535;b[4853030]=e+2&65535;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+((d>>>8|768)<<2)>>2]|0;do{if((g|0)==0){h=c[f+4180>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](e)|0;i=k;j=c[9757320+(c[1836236]<<2)>>2]|0}else{i=a[g+(d&255)|0]|0;j=f}}while(0);f=i&255;i=d+1|0;d=c[j+76+((i>>>8&255|768)<<2)>>2]|0;if((d|0)!=0){l=a[d+(i&255)|0]|0;m=l&255;n=m<<8;o=n|f;b[4853032]=o;return}d=c[j+4180>>2]|0;if((d|0)==0){l=0;m=l&255;n=m<<8;o=n|f;b[4853032]=o;return}l=gj[d&4095](i&65535)|0;m=l&255;n=m<<8;o=n|f;b[4853032]=o;return}function gf2(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=c[2426515]|0;e=d&65535;b[4853030]=e+2&65535;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+((d>>>8|768)<<2)>>2]|0;do{if((g|0)==0){h=c[f+4180>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](e)|0;i=k;j=c[9757320+(c[1836236]<<2)>>2]|0}else{i=a[g+(d&255)|0]|0;j=f}}while(0);f=i&255;i=d+1|0;d=c[j+76+((i>>>8&255|768)<<2)>>2]|0;do{if((d|0)==0){g=c[j+4180>>2]|0;if((g|0)==0){l=0;m=j;break}e=gj[g&4095](i&65535)|0;l=e;m=c[9757320+(c[1836236]<<2)>>2]|0}else{l=a[d+(i&255)|0]|0;m=j}}while(0);j=l&255;l=j<<8|f;c[3541536]=l;i=a[9706069]|0;d=c[m+76+((j|256)<<2)>>2]|0;if((d|0)!=0){a[d+f|0]=i;return}f=c[m+4184>>2]|0;if((f|0)==0){return}gg[f&4095](l&65535,i);return}function gf3(){b[4853032]=(b[4853032]|0)+1&65535;return}function gf4(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=b[4853044]|0;e=c[2426515]|0;f=e&65535;b[4853030]=f+1&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=(j<<24>>24)+d&65535;d=g&65535;c[3541536]=d;j=d>>>8;e=c[k+76+(j<<2)>>2]|0;do{if((e|0)==0){h=c[k+4180>>2]|0;if((h|0)==0){m=0;n=k;break}f=gj[h&4095](g)|0;m=f;n=c[9757320+(c[1836236]<<2)>>2]|0}else{m=a[e+(d&255)|0]|0;n=k}}while(0);k=m+1&255;a[9706068]=a[9706068]&1|a[9621712+(k&255)|0];m=c[n+76+((j|256)<<2)>>2]|0;if((m|0)!=0){a[m+(d&255)|0]=k;return}d=c[n+4184>>2]|0;if((d|0)==0){return}gg[d&4095](g,k);return}function gf5(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=b[4853044]|0;e=c[2426515]|0;f=e&65535;b[4853030]=f+1&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=(j<<24>>24)+d&65535;d=g&65535;c[3541536]=d;j=d>>>8;e=c[k+76+(j<<2)>>2]|0;do{if((e|0)==0){h=c[k+4180>>2]|0;if((h|0)==0){m=0;n=k;break}f=gj[h&4095](g)|0;m=f;n=c[9757320+(c[1836236]<<2)>>2]|0}else{m=a[e+(d&255)|0]|0;n=k}}while(0);k=m-1&255;a[9706068]=a[9706068]&1|a[9621968+(k&255)|0];m=c[n+76+((j|256)<<2)>>2]|0;if((m|0)!=0){a[m+(d&255)|0]=k;return}d=c[n+4184>>2]|0;if((d|0)==0){return}gg[d&4095](g,k);return}function gf6(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=b[4853044]|0;e=c[2426515]|0;f=e&65535;b[4853030]=f+1&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=(j<<24>>24)+d&65535;d=g&65535;c[3541536]=d;j=c[2426515]|0;e=j&65535;b[4853030]=e+1&65535;h=c[k+76+((j>>>8|768)<<2)>>2]|0;do{if((h|0)==0){f=c[k+4180>>2]|0;if((f|0)==0){m=0;n=k;break}l=gj[f&4095](e)|0;m=l;n=c[9757320+(c[1836236]<<2)>>2]|0}else{m=a[h+(j&255)|0]|0;n=k}}while(0);k=c[n+76+((d>>>8|256)<<2)>>2]|0;if((k|0)!=0){a[k+(d&255)|0]=m;return}d=c[n+4184>>2]|0;if((d|0)==0){return}gg[d&4095](g,m);return}function gf7(){a[9706068]=a[9706068]&-60|a[9706069]&40|1;return}function gf8(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((a[9706068]&1)==0){d=(b[4853030]|0)+1&65535;b[4853030]=d;return}e=c[2426515]|0;f=e&65535;g=f+1&65535;b[4853030]=g;h=c[9757320+(c[1836236]<<2)>>2]|0;i=c[h+76+((e>>>8|768)<<2)>>2]|0;do{if((i|0)==0){j=c[h+4180>>2]|0;if((j|0)==0){k=0;l=g;break}m=gj[j&4095](f)|0;k=m;l=b[4853030]|0}else{k=a[i+(e&255)|0]|0;l=g}}while(0);b[4853030]=l+(k<<24>>24)&65535;c[2076596]=(c[2076596]|0)-5;d=c[2426515]&65535;b[4853030]=d;return}function gf9(){var d=0,e=0,f=0;d=c[2426522]|0;e=c[2426516]|0;f=e+d|0;a[9706068]=(f>>>16&1|a[9706068]&196|f>>>8&40|(e^d^f)>>>8&16)&255;b[4853044]=f&65535;return}function gga(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=c[2426515]|0;e=d&65535;b[4853030]=e+2&65535;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+((d>>>8|768)<<2)>>2]|0;do{if((g|0)==0){h=c[f+4180>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](e)|0;i=k;j=c[9757320+(c[1836236]<<2)>>2]|0}else{i=a[g+(d&255)|0]|0;j=f}}while(0);f=i&255;i=d+1|0;d=c[j+76+((i>>>8&255|768)<<2)>>2]|0;do{if((d|0)==0){g=c[j+4180>>2]|0;if((g|0)==0){l=0;m=j;break}e=gj[g&4095](i&65535)|0;l=e;m=c[9757320+(c[1836236]<<2)>>2]|0}else{l=a[d+(i&255)|0]|0;m=j}}while(0);j=l&255;l=j<<8|f;c[3541536]=l;i=c[m+76+(j<<2)>>2]|0;if((i|0)!=0){n=a[i+f|0]|0;a[9706069]=n;return}f=c[m+4180>>2]|0;if((f|0)==0){n=0;a[9706069]=n;return}n=gj[f&4095](l&65535)|0;a[9706069]=n;return}function ggb(){b[4853032]=(b[4853032]|0)-1&65535;return}function ggc(){var b=0;b=(a[9706069]|0)+1&255;a[9706068]=a[9706068]&1|a[9621712+(b&255)|0];a[9706069]=b;return}function ggd(){var b=0;b=(a[9706069]|0)-1&255;a[9706068]=a[9706068]&1|a[9621968+(b&255)|0];a[9706069]=b;return}function gge(){var d=0,e=0,f=0,g=0,h=0;d=c[2426515]|0;e=d&65535;b[4853030]=e+1&65535;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+((d>>>8|768)<<2)>>2]|0;if((g|0)!=0){h=a[g+(d&255)|0]|0;a[9706069]=h;return}d=c[f+4180>>2]|0;if((d|0)==0){h=0;a[9706069]=h;return}h=gj[d&4095](e)|0;a[9706069]=h;return}function ggf(){var b=0;b=a[9706068]|0;a[9706068]=(b<<4&16|b&-59|a[9706069]&40)^1;return}function ggg(){return}function ggh(){a[9706073]=a[9706072]|0;return}function ggi(){a[9706073]=a[9706077]|0;return}function ggj(){a[9706073]=a[9706076]|0;return}function ggk(){a[9706073]=a[9706089]|0;return}function ggl(){a[9706073]=a[9706088]|0;return}function ggm(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b[4853044]|0;e=c[2426515]|0;f=e&65535;b[4853030]=f+1&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=(j<<24>>24)+d&65535;d=g&65535;c[3541536]=d;j=c[k+76+(d>>>8<<2)>>2]|0;if((j|0)!=0){m=a[j+(d&255)|0]|0;a[9706073]=m;return}d=c[k+4180>>2]|0;if((d|0)==0){m=0;a[9706073]=m;return}m=gj[d&4095](g)|0;a[9706073]=m;return}function ggn(){a[9706073]=a[9706069]|0;return}function ggo(){a[9706072]=a[9706073]|0;return}function ggp(){return}function ggq(){a[9706072]=a[9706077]|0;return}function ggr(){a[9706072]=a[9706076]|0;return}function ggs(){a[9706072]=a[9706089]|0;return}function ggt(){a[9706072]=a[9706088]|0;return}function ggu(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b[4853044]|0;e=c[2426515]|0;f=e&65535;b[4853030]=f+1&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=(j<<24>>24)+d&65535;d=g&65535;c[3541536]=d;j=c[k+76+(d>>>8<<2)>>2]|0;if((j|0)!=0){m=a[j+(d&255)|0]|0;a[9706072]=m;return}d=c[k+4180>>2]|0;if((d|0)==0){m=0;a[9706072]=m;return}m=gj[d&4095](g)|0;a[9706072]=m;return}function ggv(){a[9706072]=a[9706069]|0;return}function ggw(){a[9706077]=a[9706073]|0;return}function ggx(){a[9706077]=a[9706072]|0;return}function ggy(){return}function ggz(){a[9706077]=a[9706076]|0;return}function ggA(){a[9706077]=a[9706089]|0;return}function ggB(){a[9706077]=a[9706088]|0;return}function ggC(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b[4853044]|0;e=c[2426515]|0;f=e&65535;b[4853030]=f+1&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=(j<<24>>24)+d&65535;d=g&65535;c[3541536]=d;j=c[k+76+(d>>>8<<2)>>2]|0;if((j|0)!=0){m=a[j+(d&255)|0]|0;a[9706077]=m;return}d=c[k+4180>>2]|0;if((d|0)==0){m=0;a[9706077]=m;return}m=gj[d&4095](g)|0;a[9706077]=m;return}function ggD(){a[9706077]=a[9706069]|0;return}function ggE(){a[9706076]=a[9706073]|0;return}function ggF(){a[9706076]=a[9706072]|0;return}function ggG(){a[9706076]=a[9706077]|0;return}function ggH(){return}function ggI(){a[9706076]=a[9706089]|0;return}function ggJ(){a[9706076]=a[9706088]|0;return}function ggK(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b[4853044]|0;e=c[2426515]|0;f=e&65535;b[4853030]=f+1&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=(j<<24>>24)+d&65535;d=g&65535;c[3541536]=d;j=c[k+76+(d>>>8<<2)>>2]|0;if((j|0)!=0){m=a[j+(d&255)|0]|0;a[9706076]=m;return}d=c[k+4180>>2]|0;if((d|0)==0){m=0;a[9706076]=m;return}m=gj[d&4095](g)|0;a[9706076]=m;return}function ggL(){a[9706076]=a[9706069]|0;return}function ggM(){a[9706089]=a[9706073]|0;return}function ggN(){a[9706089]=a[9706072]|0;return}function ggO(){a[9706089]=a[9706077]|0;return}function ggP(){a[9706089]=a[9706076]|0;return}function ggQ(){return}function ggR(){a[9706089]=a[9706088]|0;return}function ggS(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b[4853044]|0;e=c[2426515]|0;f=e&65535;b[4853030]=f+1&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=(j<<24>>24)+d&65535;d=g&65535;c[3541536]=d;j=c[k+76+(d>>>8<<2)>>2]|0;if((j|0)!=0){m=a[j+(d&255)|0]|0;a[9706081]=m;return}d=c[k+4180>>2]|0;if((d|0)==0){m=0;a[9706081]=m;return}m=gj[d&4095](g)|0;a[9706081]=m;return}function ggT(){a[9706089]=a[9706069]|0;return}function ggU(){a[9706088]=a[9706073]|0;return}function ggV(){a[9706088]=a[9706072]|0;return}function ggW(){a[9706088]=a[9706077]|0;return}function ggX(){a[9706088]=a[9706076]|0;return}function ggY(){a[9706088]=a[9706089]|0;return}function ggZ(){return}function gg_(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b[4853044]|0;e=c[2426515]|0;f=e&65535;b[4853030]=f+1&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=(j<<24>>24)+d&65535;d=g&65535;c[3541536]=d;j=c[k+76+(d>>>8<<2)>>2]|0;if((j|0)!=0){m=a[j+(d&255)|0]|0;a[9706080]=m;return}d=c[k+4180>>2]|0;if((d|0)==0){m=0;a[9706080]=m;return}m=gj[d&4095](g)|0;a[9706080]=m;return}function gg$(){a[9706088]=a[9706069]|0;return}function gg0(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[4853044]|0;e=c[2426515]|0;f=e&65535;b[4853030]=f+1&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=(j<<24>>24)+d&65535;d=g&65535;c[3541536]=d;j=a[9706073]|0;e=c[k+76+((d>>>8|256)<<2)>>2]|0;if((e|0)!=0){a[e+(d&255)|0]=j;return}d=c[k+4184>>2]|0;if((d|0)==0){return}gg[d&4095](g,j);return}function gg1(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[4853044]|0;e=c[2426515]|0;f=e&65535;b[4853030]=f+1&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=(j<<24>>24)+d&65535;d=g&65535;c[3541536]=d;j=a[9706072]|0;e=c[k+76+((d>>>8|256)<<2)>>2]|0;if((e|0)!=0){a[e+(d&255)|0]=j;return}d=c[k+4184>>2]|0;if((d|0)==0){return}gg[d&4095](g,j);return}function gg2(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[4853044]|0;e=c[2426515]|0;f=e&65535;b[4853030]=f+1&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=(j<<24>>24)+d&65535;d=g&65535;c[3541536]=d;j=a[9706077]|0;e=c[k+76+((d>>>8|256)<<2)>>2]|0;if((e|0)!=0){a[e+(d&255)|0]=j;return}d=c[k+4184>>2]|0;if((d|0)==0){return}gg[d&4095](g,j);return}function gg3(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[4853044]|0;e=c[2426515]|0;f=e&65535;b[4853030]=f+1&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=(j<<24>>24)+d&65535;d=g&65535;c[3541536]=d;j=a[9706076]|0;e=c[k+76+((d>>>8|256)<<2)>>2]|0;if((e|0)!=0){a[e+(d&255)|0]=j;return}d=c[k+4184>>2]|0;if((d|0)==0){return}gg[d&4095](g,j);return}function gg4(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[4853044]|0;e=c[2426515]|0;f=e&65535;b[4853030]=f+1&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=(j<<24>>24)+d&65535;d=g&65535;c[3541536]=d;j=a[9706081]|0;e=c[k+76+((d>>>8|256)<<2)>>2]|0;if((e|0)!=0){a[e+(d&255)|0]=j;return}d=c[k+4184>>2]|0;if((d|0)==0){return}gg[d&4095](g,j);return}function gg5(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[4853044]|0;e=c[2426515]|0;f=e&65535;b[4853030]=f+1&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=(j<<24>>24)+d&65535;d=g&65535;c[3541536]=d;j=a[9706080]|0;e=c[k+76+((d>>>8|256)<<2)>>2]|0;if((e|0)!=0){a[e+(d&255)|0]=j;return}d=c[k+4184>>2]|0;if((d|0)==0){return}gg[d&4095](g,j);return}function gg6(){var e=0,f=0;b[4853030]=(b[4853030]|0)-1&65535;a[9706112]=1;if((a[9706117]|0)!=0){return}e=c[2076596]|0;if((e|0)<=0){return}f=(e+3|0)/4|0;a[9706108]=(d[9706108]|0)+f&255;c[2076596]=e-(f<<2);return}function gg7(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[4853044]|0;e=c[2426515]|0;f=e&65535;b[4853030]=f+1&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=(j<<24>>24)+d&65535;d=g&65535;c[3541536]=d;j=a[9706069]|0;e=c[k+76+((d>>>8|256)<<2)>>2]|0;if((e|0)!=0){a[e+(d&255)|0]=j;return}d=c[k+4184>>2]|0;if((d|0)==0){return}gg[d&4095](g,j);return}function gg8(){a[9706069]=a[9706073]|0;return}function gg9(){a[9706069]=a[9706072]|0;return}function gha(){a[9706069]=a[9706077]|0;return}function ghb(){a[9706069]=a[9706076]|0;return}function ghc(){a[9706069]=a[9706089]|0;return}function ghd(){a[9706069]=a[9706088]|0;return}function ghe(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b[4853044]|0;e=c[2426515]|0;f=e&65535;b[4853030]=f+1&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=(j<<24>>24)+d&65535;d=g&65535;c[3541536]=d;j=c[k+76+(d>>>8<<2)>>2]|0;if((j|0)!=0){m=a[j+(d&255)|0]|0;a[9706069]=m;return}d=c[k+4180>>2]|0;if((d|0)==0){m=0;a[9706069]=m;return}m=gj[d&4095](g)|0;a[9706069]=m;return}function ghf(){return}function ghg(){var b=0,e=0;b=c[2426517]&65280;e=(b>>>8)+(d[9706073]|0)|0;a[9706068]=a[(c[2385740]|0)+(e&255|b)|0]|0;a[9706069]=e&255;return}function ghh(){var b=0,e=0;b=c[2426517]&65280;e=(b>>>8)+(d[9706072]|0)|0;a[9706068]=a[(c[2385740]|0)+(e&255|b)|0]|0;a[9706069]=e&255;return}function ghi(){var b=0,e=0;b=c[2426517]&65280;e=(b>>>8)+(d[9706077]|0)|0;a[9706068]=a[(c[2385740]|0)+(e&255|b)|0]|0;a[9706069]=e&255;return}function ghj(){var b=0,e=0;b=c[2426517]&65280;e=(b>>>8)+(d[9706076]|0)|0;a[9706068]=a[(c[2385740]|0)+(e&255|b)|0]|0;a[9706069]=e&255;return}function ghk(){var b=0,e=0;b=c[2426517]&65280;e=(b>>>8)+(d[9706089]|0)|0;a[9706068]=a[(c[2385740]|0)+(e&255|b)|0]|0;a[9706069]=e&255;return}function ghl(){var b=0,e=0;b=c[2426517]&65280;e=(b>>>8)+(d[9706088]|0)|0;a[9706068]=a[(c[2385740]|0)+(e&255|b)|0]|0;a[9706069]=e&255;return}function ghm(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b[4853044]|0;e=c[2426515]|0;f=e&65535;b[4853030]=f+1&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=(j<<24>>24)+d&65535;d=g&65535;c[3541536]=d;j=c[2426517]&65280;e=j>>>8;h=c[k+76+(d>>>8<<2)>>2]|0;do{if((h|0)==0){f=c[k+4180>>2]|0;if((f|0)==0){m=0;break}m=gj[f&4095](g)|0}else{m=a[h+(d&255)|0]|0}}while(0);d=(m&255)+e|0;a[9706068]=a[(c[2385740]|0)+(d&255|j)|0]|0;a[9706069]=d&255;return}function ghn(){var b=0,e=0;b=c[2426517]&65280;e=(b>>>8)+(d[9706069]|0)|0;a[9706068]=a[(c[2385740]|0)+(e&255|b)|0]|0;a[9706069]=e&255;return}function gho(){var b=0,e=0,f=0;b=c[2426517]|0;e=b&65280;f=b&1;b=(d[9706073]|0)+f+(e>>>8)|0;a[9706068]=a[(c[2385740]|0)+(f<<16|e|b&255)|0]|0;a[9706069]=b&255;return}function ghp(){var b=0,e=0,f=0;b=c[2426517]|0;e=b&65280;f=b&1;b=(d[9706072]|0)+f+(e>>>8)|0;a[9706068]=a[(c[2385740]|0)+(f<<16|e|b&255)|0]|0;a[9706069]=b&255;return}function ghq(){var b=0,e=0,f=0;b=c[2426517]|0;e=b&65280;f=b&1;b=(d[9706077]|0)+f+(e>>>8)|0;a[9706068]=a[(c[2385740]|0)+(f<<16|e|b&255)|0]|0;a[9706069]=b&255;return}function ghr(){var b=0,e=0,f=0;b=c[2426517]|0;e=b&65280;f=b&1;b=(d[9706076]|0)+f+(e>>>8)|0;a[9706068]=a[(c[2385740]|0)+(f<<16|e|b&255)|0]|0;a[9706069]=b&255;return}function ghs(){var b=0,e=0,f=0;b=c[2426517]|0;e=b&65280;f=b&1;b=(d[9706089]|0)+f+(e>>>8)|0;a[9706068]=a[(c[2385740]|0)+(f<<16|e|b&255)|0]|0;a[9706069]=b&255;return}function ght(){var b=0,e=0,f=0;b=c[2426517]|0;e=b&65280;f=b&1;b=(d[9706088]|0)+f+(e>>>8)|0;a[9706068]=a[(c[2385740]|0)+(f<<16|e|b&255)|0]|0;a[9706069]=b&255;return}function ghu(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b[4853044]|0;e=c[2426515]|0;f=e&65535;b[4853030]=f+1&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=(j<<24>>24)+d&65535;d=g&65535;c[3541536]=d;j=c[2426517]|0;e=j&65280;h=j&1;j=e>>>8;f=c[k+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){l=c[k+4180>>2]|0;if((l|0)==0){m=0;break}m=gj[l&4095](g)|0}else{m=a[f+(d&255)|0]|0}}while(0);d=j+h+(m&255)|0;a[9706068]=a[(c[2385740]|0)+(h<<16|e|d&255)|0]|0;a[9706069]=d&255;return}function ghv(){var b=0,e=0,f=0;b=c[2426517]|0;e=b&65280;f=b&1;b=(d[9706069]|0)+f+(e>>>8)|0;a[9706068]=a[(c[2385740]|0)+(f<<16|e|b&255)|0]|0;a[9706069]=b&255;return}function ghw(){var b=0,e=0;b=c[2426517]&65280;e=(b>>>8)-(d[9706073]|0)|0;a[9706068]=a[(c[2385738]|0)+(e&255|b)|0]|0;a[9706069]=e&255;return}function ghx(){var b=0,e=0;b=c[2426517]&65280;e=(b>>>8)-(d[9706072]|0)|0;a[9706068]=a[(c[2385738]|0)+(e&255|b)|0]|0;a[9706069]=e&255;return}function ghy(){var b=0,e=0;b=c[2426517]&65280;e=(b>>>8)-(d[9706077]|0)|0;a[9706068]=a[(c[2385738]|0)+(e&255|b)|0]|0;a[9706069]=e&255;return}function ghz(){var b=0,e=0;b=c[2426517]&65280;e=(b>>>8)-(d[9706076]|0)|0;a[9706068]=a[(c[2385738]|0)+(e&255|b)|0]|0;a[9706069]=e&255;return}function ghA(){var b=0,e=0;b=c[2426517]&65280;e=(b>>>8)-(d[9706089]|0)|0;a[9706068]=a[(c[2385738]|0)+(e&255|b)|0]|0;a[9706069]=e&255;return}function ghB(){var b=0,e=0;b=c[2426517]&65280;e=(b>>>8)-(d[9706088]|0)|0;a[9706068]=a[(c[2385738]|0)+(e&255|b)|0]|0;a[9706069]=e&255;return}function ghC(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b[4853044]|0;e=c[2426515]|0;f=e&65535;b[4853030]=f+1&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=(j<<24>>24)+d&65535;d=g&65535;c[3541536]=d;j=c[2426517]&65280;e=j>>>8;h=c[k+76+(d>>>8<<2)>>2]|0;do{if((h|0)==0){f=c[k+4180>>2]|0;if((f|0)==0){m=0;break}m=gj[f&4095](g)|0}else{m=a[h+(d&255)|0]|0}}while(0);d=e-(m&255)|0;a[9706068]=a[(c[2385738]|0)+(d&255|j)|0]|0;a[9706069]=d&255;return}function ghD(){var b=0,e=0;b=c[2426517]&65280;e=(b>>>8)-(d[9706069]|0)|0;a[9706068]=a[(c[2385738]|0)+(e&255|b)|0]|0;a[9706069]=e&255;return}function ghE(){var b=0,e=0,f=0;b=c[2426517]|0;e=b&65280;f=b&1;b=(e>>>8)-(d[9706073]|0)-f|0;a[9706068]=a[(c[2385738]|0)+(f<<16|e|b&255)|0]|0;a[9706069]=b&255;return}function ghF(){var b=0,e=0,f=0;b=c[2426517]|0;e=b&65280;f=b&1;b=(e>>>8)-(d[9706072]|0)-f|0;a[9706068]=a[(c[2385738]|0)+(f<<16|e|b&255)|0]|0;a[9706069]=b&255;return}function ghG(){var b=0,e=0,f=0;b=c[2426517]|0;e=b&65280;f=b&1;b=(e>>>8)-(d[9706077]|0)-f|0;a[9706068]=a[(c[2385738]|0)+(f<<16|e|b&255)|0]|0;a[9706069]=b&255;return}function ghH(){var b=0,e=0,f=0;b=c[2426517]|0;e=b&65280;f=b&1;b=(e>>>8)-(d[9706076]|0)-f|0;a[9706068]=a[(c[2385738]|0)+(f<<16|e|b&255)|0]|0;a[9706069]=b&255;return}function ghI(){var b=0,e=0,f=0;b=c[2426517]|0;e=b&65280;f=b&1;b=(e>>>8)-(d[9706089]|0)-f|0;a[9706068]=a[(c[2385738]|0)+(f<<16|e|b&255)|0]|0;a[9706069]=b&255;return}function ghJ(){var b=0,e=0,f=0;b=c[2426517]|0;e=b&65280;f=b&1;b=(e>>>8)-(d[9706088]|0)-f|0;a[9706068]=a[(c[2385738]|0)+(f<<16|e|b&255)|0]|0;a[9706069]=b&255;return}function ghK(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b[4853044]|0;e=c[2426515]|0;f=e&65535;b[4853030]=f+1&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=(j<<24>>24)+d&65535;d=g&65535;c[3541536]=d;j=c[2426517]|0;e=j&65280;h=j&1;j=e>>>8;f=c[k+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){l=c[k+4180>>2]|0;if((l|0)==0){m=0;break}m=gj[l&4095](g)|0}else{m=a[f+(d&255)|0]|0}}while(0);d=j-(m&255)-h|0;a[9706068]=a[(c[2385738]|0)+(h<<16|e|d&255)|0]|0;a[9706069]=d&255;return}function ghL(){var b=0,e=0,f=0;b=c[2426517]|0;e=b&65280;f=b&1;b=(e>>>8)-(d[9706069]|0)-f|0;a[9706068]=a[(c[2385738]|0)+(f<<16|e|b&255)|0]|0;a[9706069]=b&255;return}function ghM(){var b=0;b=a[9706069]&a[9706073];a[9706069]=b;a[9706068]=a[9706144+(b&255)|0]|16;return}function ghN(){var b=0;b=a[9706069]&a[9706072];a[9706069]=b;a[9706068]=a[9706144+(b&255)|0]|16;return}function ghO(){var b=0;b=a[9706069]&a[9706077];a[9706069]=b;a[9706068]=a[9706144+(b&255)|0]|16;return}function ghP(){var b=0;b=a[9706069]&a[9706076];a[9706069]=b;a[9706068]=a[9706144+(b&255)|0]|16;return}function ghQ(){var b=0;b=a[9706069]&a[9706089];a[9706069]=b;a[9706068]=a[9706144+(b&255)|0]|16;return}function ghR(){var b=0;b=a[9706069]&a[9706088];a[9706069]=b;a[9706068]=a[9706144+(b&255)|0]|16;return}function ghS(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b[4853044]|0;e=c[2426515]|0;f=e&65535;b[4853030]=f+1&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=(j<<24>>24)+d&65535;d=g&65535;c[3541536]=d;j=c[k+76+(d>>>8<<2)>>2]|0;do{if((j|0)==0){e=c[k+4180>>2]|0;if((e|0)==0){m=0;break}m=gj[e&4095](g)|0}else{m=a[j+(d&255)|0]|0}}while(0);d=a[9706069]&m;a[9706069]=d;a[9706068]=a[9706144+(d&255)|0]|16;return}function ghT(){a[9706068]=a[9706144+(d[9706069]|0)|0]|16;return}function ghU(){var b=0;b=a[9706069]^a[9706073];a[9706069]=b;a[9706068]=a[9706144+(b&255)|0]|0;return}function ghV(){var b=0;b=a[9706069]^a[9706072];a[9706069]=b;a[9706068]=a[9706144+(b&255)|0]|0;return}function ghW(){var b=0;b=a[9706069]^a[9706077];a[9706069]=b;a[9706068]=a[9706144+(b&255)|0]|0;return}function ghX(){var b=0;b=a[9706069]^a[9706076];a[9706069]=b;a[9706068]=a[9706144+(b&255)|0]|0;return}function ghY(){var b=0;b=a[9706069]^a[9706089];a[9706069]=b;a[9706068]=a[9706144+(b&255)|0]|0;return}function ghZ(){var b=0;b=a[9706069]^a[9706088];a[9706069]=b;a[9706068]=a[9706144+(b&255)|0]|0;return}function gh_(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b[4853044]|0;e=c[2426515]|0;f=e&65535;b[4853030]=f+1&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=(j<<24>>24)+d&65535;d=g&65535;c[3541536]=d;j=c[k+76+(d>>>8<<2)>>2]|0;do{if((j|0)==0){e=c[k+4180>>2]|0;if((e|0)==0){m=0;break}m=gj[e&4095](g)|0}else{m=a[j+(d&255)|0]|0}}while(0);d=a[9706069]^m;a[9706069]=d;a[9706068]=a[9706144+(d&255)|0]|0;return}function gh$(){a[9706069]=0;a[9706068]=a[9706144]|0;return}function gh0(){var b=0;b=a[9706069]|a[9706073];a[9706069]=b;a[9706068]=a[9706144+(b&255)|0]|0;return}function gh1(){var b=0;b=a[9706069]|a[9706072];a[9706069]=b;a[9706068]=a[9706144+(b&255)|0]|0;return}function gh2(){var b=0;b=a[9706069]|a[9706077];a[9706069]=b;a[9706068]=a[9706144+(b&255)|0]|0;return}function gh3(){var b=0;b=a[9706069]|a[9706076];a[9706069]=b;a[9706068]=a[9706144+(b&255)|0]|0;return}function gh4(){var b=0;b=a[9706069]|a[9706089];a[9706069]=b;a[9706068]=a[9706144+(b&255)|0]|0;return}function gh5(){var b=0;b=a[9706069]|a[9706088];a[9706069]=b;a[9706068]=a[9706144+(b&255)|0]|0;return}function gh6(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b[4853044]|0;e=c[2426515]|0;f=e&65535;b[4853030]=f+1&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=(j<<24>>24)+d&65535;d=g&65535;c[3541536]=d;j=c[k+76+(d>>>8<<2)>>2]|0;do{if((j|0)==0){e=c[k+4180>>2]|0;if((e|0)==0){m=0;break}m=gj[e&4095](g)|0}else{m=a[j+(d&255)|0]|0}}while(0);d=a[9706069]|m;a[9706069]=d;a[9706068]=a[9706144+(d&255)|0]|0;return}function gh7(){a[9706068]=a[9706144+(d[9706069]|0)|0]|0;return}function gh8(){var b=0,d=0;b=a[9706073]|0;d=c[2426517]&65280;a[9706068]=a[(c[2385738]|0)+((d>>>8)-(b&255)&255|d)|0]&-41|b&40;return}function gh9(){var b=0,d=0;b=a[9706072]|0;d=c[2426517]&65280;a[9706068]=a[(c[2385738]|0)+((d>>>8)-(b&255)&255|d)|0]&-41|b&40;return}function gia(){var b=0,d=0;b=a[9706077]|0;d=c[2426517]&65280;a[9706068]=a[(c[2385738]|0)+((d>>>8)-(b&255)&255|d)|0]&-41|b&40;return}function gib(){var b=0,d=0;b=a[9706076]|0;d=c[2426517]&65280;a[9706068]=a[(c[2385738]|0)+((d>>>8)-(b&255)&255|d)|0]&-41|b&40;return}function gic(){var b=0,d=0;b=a[9706089]|0;d=c[2426517]&65280;a[9706068]=a[(c[2385738]|0)+((d>>>8)-(b&255)&255|d)|0]&-41|b&40;return}function gid(){var b=0,d=0;b=a[9706088]|0;d=c[2426517]&65280;a[9706068]=a[(c[2385738]|0)+((d>>>8)-(b&255)&255|d)|0]&-41|b&40;return}function gie(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b[4853044]|0;e=c[2426515]|0;f=e&65535;b[4853030]=f+1&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=(j<<24>>24)+d&65535;d=g&65535;c[3541536]=d;j=c[k+76+(d>>>8<<2)>>2]|0;do{if((j|0)==0){e=c[k+4180>>2]|0;if((e|0)==0){m=0;break}m=gj[e&4095](g)|0}else{m=a[j+(d&255)|0]|0}}while(0);d=c[2426517]&65280;a[9706068]=a[(c[2385738]|0)+((d>>>8)-(m&255)&255|d)|0]&-41|m&40;return}function gif(){var b=0,d=0;b=a[9706069]|0;d=c[2426517]&65280;a[9706068]=a[(c[2385738]|0)+((d>>>8)-(b&255)&255|d)|0]&-41|b&40;return}function gig(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if((a[9706068]&64)!=0){return}d=c[2426516]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](d&65535)|0;h=j;i=c[9757320+(c[1836236]<<2)>>2]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9706060]=h;h=d+1|0;d=c[i+76+((h>>>8&255)<<2)>>2]|0;do{if((d|0)==0){e=c[i+4180>>2]|0;if((e|0)==0){k=0;break}k=gj[e&4095](h&65535)|0}else{k=a[d+(h&255)|0]|0}}while(0);a[9706061]=k;b[4853032]=(b[4853032]|0)+2&65535;b[4853030]=c[2426515]&65535;c[2076596]=(c[2076596]|0)-6;return}function gih(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[2426516]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](d&65535)|0;h=j;i=c[9757320+(c[1836236]<<2)>>2]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9706072]=h;h=d+1|0;d=c[i+76+((h>>>8&255)<<2)>>2]|0;do{if((d|0)==0){e=c[i+4180>>2]|0;if((e|0)==0){k=0;break}k=gj[e&4095](h&65535)|0}else{k=a[d+(h&255)|0]|0}}while(0);a[9706073]=k;b[4853032]=(b[4853032]|0)+2&65535;return}function gii(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((a[9706068]&64)!=0){d=(b[4853030]|0)+2&65535;b[4853030]=d;return}e=c[2426515]|0;f=e&65535;b[4853030]=f+2&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=j&255;j=e+1|0;e=c[k+76+((j>>>8&255|768)<<2)>>2]|0;do{if((e|0)==0){h=c[k+4180>>2]|0;if((h|0)==0){m=0;break}m=gj[h&4095](j&65535)|0}else{m=a[e+(j&255)|0]|0}}while(0);j=(m&255)<<8|g;c[2426515]=j;d=j&65535;b[4853030]=d;return}function gij(){gff();return}function gik(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((a[9706068]&64)!=0){d=(b[4853030]|0)+2&65535;b[4853030]=d;return}e=c[2426515]|0;f=e&65535;b[4853030]=f+2&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=j&255;j=e+1|0;e=c[k+76+((j>>>8&255|768)<<2)>>2]|0;do{if((e|0)==0){h=c[k+4180>>2]|0;if((h|0)==0){m=0;n=k;break}f=gj[h&4095](j&65535)|0;m=f;n=c[9757320+(c[1836236]<<2)>>2]|0}else{m=a[e+(j&255)|0]|0;n=k}}while(0);c[3541536]=(m&255)<<8|g;b[4853032]=(b[4853032]|0)-2&65535;g=c[2426516]|0;m=a[9706060]|0;k=c[n+76+((g>>>8|256)<<2)>>2]|0;do{if((k|0)==0){j=c[n+4184>>2]|0;if((j|0)==0){o=n;break}gg[j&4095](g&65535,m);o=c[9757320+(c[1836236]<<2)>>2]|0}else{a[k+(g&255)|0]=m;o=n}}while(0);n=g+1|0;g=a[9706061]|0;m=c[o+76+((n>>>8&255|256)<<2)>>2]|0;do{if((m|0)==0){k=c[o+4184>>2]|0;if((k|0)==0){break}gg[k&4095](n&65535,g)}else{a[m+(n&255)|0]=g}}while(0);g=c[3541536]|0;c[2426515]=g;c[2076596]=(c[2076596]|0)-7;d=g&65535;b[4853030]=d;return}function gil(){var d=0,e=0,f=0,g=0,h=0,i=0;b[4853032]=(b[4853032]|0)-2&65535;d=c[2426516]|0;e=a[9706072]|0;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+((d>>>8|256)<<2)>>2]|0;do{if((g|0)==0){h=c[f+4184>>2]|0;if((h|0)==0){i=f;break}gg[h&4095](d&65535,e);i=c[9757320+(c[1836236]<<2)>>2]|0}else{a[g+(d&255)|0]=e;i=f}}while(0);f=d+1|0;d=a[9706073]|0;e=c[i+76+((f>>>8&255|256)<<2)>>2]|0;if((e|0)!=0){a[e+(f&255)|0]=d;return}e=c[i+4184>>2]|0;if((e|0)==0){return}gg[e&4095](f&65535,d);return}function gim(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[2426517]&65280;e=d>>>8;f=c[2426515]|0;g=f&65535;b[4853030]=g+1&65535;h=c[9757320+(c[1836236]<<2)>>2]|0;i=c[h+76+((f>>>8|768)<<2)>>2]|0;do{if((i|0)==0){j=c[h+4180>>2]|0;if((j|0)==0){k=0;break}k=gj[j&4095](g)|0}else{k=a[i+(f&255)|0]|0}}while(0);f=(k&255)+e|0;a[9706068]=a[(c[2385740]|0)+(f&255|d)|0]|0;a[9706069]=f&255;return}function gin(){var d=0,e=0,f=0,g=0,h=0,i=0;b[4853032]=(b[4853032]|0)-2&65535;d=c[2426516]|0;e=a[9706060]|0;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+((d>>>8|256)<<2)>>2]|0;do{if((g|0)==0){h=c[f+4184>>2]|0;if((h|0)==0){i=f;break}gg[h&4095](d&65535,e);i=c[9757320+(c[1836236]<<2)>>2]|0}else{a[g+(d&255)|0]=e;i=f}}while(0);f=d+1|0;d=a[9706061]|0;e=c[i+76+((f>>>8&255|256)<<2)>>2]|0;if((e|0)!=0){a[e+(f&255)|0]=d;c[2426515]=0;b[4853030]=0;return}e=c[i+4184>>2]|0;if((e|0)==0){c[2426515]=0;b[4853030]=0;return}gg[e&4095](f&65535,d);c[2426515]=0;b[4853030]=0;return}function gio(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if((a[9706068]&64)==0){return}d=c[2426516]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](d&65535)|0;h=j;i=c[9757320+(c[1836236]<<2)>>2]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9706060]=h;h=d+1|0;d=c[i+76+((h>>>8&255)<<2)>>2]|0;do{if((d|0)==0){e=c[i+4180>>2]|0;if((e|0)==0){k=0;break}k=gj[e&4095](h&65535)|0}else{k=a[d+(h&255)|0]|0}}while(0);a[9706061]=k;b[4853032]=(b[4853032]|0)+2&65535;b[4853030]=c[2426515]&65535;c[2076596]=(c[2076596]|0)-6;return}function gip(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[2426516]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](d&65535)|0;h=j;i=c[9757320+(c[1836236]<<2)>>2]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9706060]=h;h=d+1|0;d=c[i+76+((h>>>8&255)<<2)>>2]|0;do{if((d|0)==0){e=c[i+4180>>2]|0;if((e|0)==0){k=0;break}k=gj[e&4095](h&65535)|0}else{k=a[d+(h&255)|0]|0}}while(0);a[9706061]=k;b[4853032]=(b[4853032]|0)+2&65535;b[4853030]=c[2426515]&65535;return}function giq(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((a[9706068]&64)==0){d=(b[4853030]|0)+2&65535;b[4853030]=d;return}e=c[2426515]|0;f=e&65535;b[4853030]=f+2&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=j&255;j=e+1|0;e=c[k+76+((j>>>8&255|768)<<2)>>2]|0;do{if((e|0)==0){h=c[k+4180>>2]|0;if((h|0)==0){m=0;break}m=gj[h&4095](j&65535)|0}else{m=a[e+(j&255)|0]|0}}while(0);j=(m&255)<<8|g;c[2426515]=j;d=j&65535;b[4853030]=d;return}function gir(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=b[4853044]|0;f=c[2426515]|0;g=f&65535;b[4853030]=g+1&65535;h=c[9757320+(c[1836236]<<2)>>2]|0;i=c[h+76+((f>>>8|768)<<2)>>2]|0;do{if((i|0)==0){j=c[h+4180>>2]|0;if((j|0)==0){k=0;l=h;break}m=gj[j&4095](g)|0;k=m;l=c[9757320+(c[1836236]<<2)>>2]|0}else{k=a[i+(f&255)|0]|0;l=h}}while(0);c[3541536]=(k<<24>>24)+e&65535;e=c[2426515]|0;k=e&65535;b[4853030]=k+1&65535;h=c[l+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){f=c[l+4180>>2]|0;if((f|0)==0){n=0;break}n=gj[f&4095](k)|0}else{n=a[h+(e&255)|0]|0}}while(0);e=n&255;c[2076596]=(c[2076596]|0)-(d[(c[2426876]|0)+e|0]|0);gu[c[670648+(e<<2)>>2]&16383]();return}function gis(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((a[9706068]&64)==0){d=(b[4853030]|0)+2&65535;b[4853030]=d;return}e=c[2426515]|0;f=e&65535;b[4853030]=f+2&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=j&255;j=e+1|0;e=c[k+76+((j>>>8&255|768)<<2)>>2]|0;do{if((e|0)==0){h=c[k+4180>>2]|0;if((h|0)==0){m=0;n=k;break}f=gj[h&4095](j&65535)|0;m=f;n=c[9757320+(c[1836236]<<2)>>2]|0}else{m=a[e+(j&255)|0]|0;n=k}}while(0);c[3541536]=(m&255)<<8|g;b[4853032]=(b[4853032]|0)-2&65535;g=c[2426516]|0;m=a[9706060]|0;k=c[n+76+((g>>>8|256)<<2)>>2]|0;do{if((k|0)==0){j=c[n+4184>>2]|0;if((j|0)==0){o=n;break}gg[j&4095](g&65535,m);o=c[9757320+(c[1836236]<<2)>>2]|0}else{a[k+(g&255)|0]=m;o=n}}while(0);n=g+1|0;g=a[9706061]|0;m=c[o+76+((n>>>8&255|256)<<2)>>2]|0;do{if((m|0)==0){k=c[o+4184>>2]|0;if((k|0)==0){break}gg[k&4095](n&65535,g)}else{a[m+(n&255)|0]=g}}while(0);g=c[3541536]|0;c[2426515]=g;c[2076596]=(c[2076596]|0)-7;d=g&65535;b[4853030]=d;return}function git(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=c[2426515]|0;e=d&65535;b[4853030]=e+2&65535;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+((d>>>8|768)<<2)>>2]|0;do{if((g|0)==0){h=c[f+4180>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](e)|0;i=k;j=c[9757320+(c[1836236]<<2)>>2]|0}else{i=a[g+(d&255)|0]|0;j=f}}while(0);f=i&255;i=d+1|0;d=c[j+76+((i>>>8&255|768)<<2)>>2]|0;do{if((d|0)==0){g=c[j+4180>>2]|0;if((g|0)==0){l=0;m=j;break}e=gj[g&4095](i&65535)|0;l=e;m=c[9757320+(c[1836236]<<2)>>2]|0}else{l=a[d+(i&255)|0]|0;m=j}}while(0);c[3541536]=(l&255)<<8|f;b[4853032]=(b[4853032]|0)-2&65535;f=c[2426516]|0;l=a[9706060]|0;j=c[m+76+((f>>>8|256)<<2)>>2]|0;do{if((j|0)==0){i=c[m+4184>>2]|0;if((i|0)==0){n=m;break}gg[i&4095](f&65535,l);n=c[9757320+(c[1836236]<<2)>>2]|0}else{a[j+(f&255)|0]=l;n=m}}while(0);m=f+1|0;f=a[9706061]|0;l=c[n+76+((m>>>8&255|256)<<2)>>2]|0;if((l|0)!=0){a[l+(m&255)|0]=f;o=c[3541536]|0;c[2426515]=o;p=o&65535;b[4853030]=p;return}l=c[n+4184>>2]|0;if((l|0)==0){o=c[3541536]|0;c[2426515]=o;p=o&65535;b[4853030]=p;return}gg[l&4095](m&65535,f);o=c[3541536]|0;c[2426515]=o;p=o&65535;b[4853030]=p;return}function giu(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[2426517]|0;e=d&65280;f=d&1;d=e>>>8;g=c[2426515]|0;h=g&65535;b[4853030]=h+1&65535;i=c[9757320+(c[1836236]<<2)>>2]|0;j=c[i+76+((g>>>8|768)<<2)>>2]|0;do{if((j|0)==0){k=c[i+4180>>2]|0;if((k|0)==0){l=0;break}l=gj[k&4095](h)|0}else{l=a[j+(g&255)|0]|0}}while(0);g=d+f+(l&255)|0;a[9706068]=a[(c[2385740]|0)+(f<<16|e|g&255)|0]|0;a[9706069]=g&255;return}function giv(){var d=0,e=0,f=0,g=0,h=0,i=0;b[4853032]=(b[4853032]|0)-2&65535;d=c[2426516]|0;e=a[9706060]|0;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+((d>>>8|256)<<2)>>2]|0;do{if((g|0)==0){h=c[f+4184>>2]|0;if((h|0)==0){i=f;break}gg[h&4095](d&65535,e);i=c[9757320+(c[1836236]<<2)>>2]|0}else{a[g+(d&255)|0]=e;i=f}}while(0);f=d+1|0;d=a[9706061]|0;e=c[i+76+((f>>>8&255|256)<<2)>>2]|0;if((e|0)!=0){a[e+(f&255)|0]=d;c[2426515]=8;b[4853030]=8;return}e=c[i+4184>>2]|0;if((e|0)==0){c[2426515]=8;b[4853030]=8;return}gg[e&4095](f&65535,d);c[2426515]=8;b[4853030]=8;return}function giw(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if((a[9706068]&1)!=0){return}d=c[2426516]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](d&65535)|0;h=j;i=c[9757320+(c[1836236]<<2)>>2]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9706060]=h;h=d+1|0;d=c[i+76+((h>>>8&255)<<2)>>2]|0;do{if((d|0)==0){e=c[i+4180>>2]|0;if((e|0)==0){k=0;break}k=gj[e&4095](h&65535)|0}else{k=a[d+(h&255)|0]|0}}while(0);a[9706061]=k;b[4853032]=(b[4853032]|0)+2&65535;b[4853030]=c[2426515]&65535;c[2076596]=(c[2076596]|0)-6;return}function gix(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[2426516]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](d&65535)|0;h=j;i=c[9757320+(c[1836236]<<2)>>2]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9706076]=h;h=d+1|0;d=c[i+76+((h>>>8&255)<<2)>>2]|0;do{if((d|0)==0){e=c[i+4180>>2]|0;if((e|0)==0){k=0;break}k=gj[e&4095](h&65535)|0}else{k=a[d+(h&255)|0]|0}}while(0);a[9706077]=k;b[4853032]=(b[4853032]|0)+2&65535;return}function giy(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((a[9706068]&1)!=0){d=(b[4853030]|0)+2&65535;b[4853030]=d;return}e=c[2426515]|0;f=e&65535;b[4853030]=f+2&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=j&255;j=e+1|0;e=c[k+76+((j>>>8&255|768)<<2)>>2]|0;do{if((e|0)==0){h=c[k+4180>>2]|0;if((h|0)==0){m=0;break}m=gj[h&4095](j&65535)|0}else{m=a[e+(j&255)|0]|0}}while(0);j=(m&255)<<8|g;c[2426515]=j;d=j&65535;b[4853030]=d;return}function giz(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[2426515]|0;e=d&65535;b[4853030]=e+1&65535;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+((d>>>8|768)<<2)>>2]|0;do{if((g|0)==0){h=c[f+4180>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](e)|0;i=k;j=c[9757320+(c[1836236]<<2)>>2]|0}else{i=a[g+(d&255)|0]|0;j=f}}while(0);f=a[9706069]|0;gg[c[j+4176>>2]&4095]((f&255)<<8|i&255,f);return}function giA(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((a[9706068]&1)!=0){d=(b[4853030]|0)+2&65535;b[4853030]=d;return}e=c[2426515]|0;f=e&65535;b[4853030]=f+2&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=j&255;j=e+1|0;e=c[k+76+((j>>>8&255|768)<<2)>>2]|0;do{if((e|0)==0){h=c[k+4180>>2]|0;if((h|0)==0){m=0;n=k;break}f=gj[h&4095](j&65535)|0;m=f;n=c[9757320+(c[1836236]<<2)>>2]|0}else{m=a[e+(j&255)|0]|0;n=k}}while(0);c[3541536]=(m&255)<<8|g;b[4853032]=(b[4853032]|0)-2&65535;g=c[2426516]|0;m=a[9706060]|0;k=c[n+76+((g>>>8|256)<<2)>>2]|0;do{if((k|0)==0){j=c[n+4184>>2]|0;if((j|0)==0){o=n;break}gg[j&4095](g&65535,m);o=c[9757320+(c[1836236]<<2)>>2]|0}else{a[k+(g&255)|0]=m;o=n}}while(0);n=g+1|0;g=a[9706061]|0;m=c[o+76+((n>>>8&255|256)<<2)>>2]|0;do{if((m|0)==0){k=c[o+4184>>2]|0;if((k|0)==0){break}gg[k&4095](n&65535,g)}else{a[m+(n&255)|0]=g}}while(0);g=c[3541536]|0;c[2426515]=g;c[2076596]=(c[2076596]|0)-7;d=g&65535;b[4853030]=d;return}function giB(){var d=0,e=0,f=0,g=0,h=0,i=0;b[4853032]=(b[4853032]|0)-2&65535;d=c[2426516]|0;e=a[9706076]|0;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+((d>>>8|256)<<2)>>2]|0;do{if((g|0)==0){h=c[f+4184>>2]|0;if((h|0)==0){i=f;break}gg[h&4095](d&65535,e);i=c[9757320+(c[1836236]<<2)>>2]|0}else{a[g+(d&255)|0]=e;i=f}}while(0);f=d+1|0;d=a[9706077]|0;e=c[i+76+((f>>>8&255|256)<<2)>>2]|0;if((e|0)!=0){a[e+(f&255)|0]=d;return}e=c[i+4184>>2]|0;if((e|0)==0){return}gg[e&4095](f&65535,d);return}function giC(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[2426517]&65280;e=d>>>8;f=c[2426515]|0;g=f&65535;b[4853030]=g+1&65535;h=c[9757320+(c[1836236]<<2)>>2]|0;i=c[h+76+((f>>>8|768)<<2)>>2]|0;do{if((i|0)==0){j=c[h+4180>>2]|0;if((j|0)==0){k=0;break}k=gj[j&4095](g)|0}else{k=a[i+(f&255)|0]|0}}while(0);f=e-(k&255)|0;a[9706068]=a[(c[2385738]|0)+(f&255|d)|0]|0;a[9706069]=f&255;return}function giD(){var d=0,e=0,f=0,g=0,h=0,i=0;b[4853032]=(b[4853032]|0)-2&65535;d=c[2426516]|0;e=a[9706060]|0;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+((d>>>8|256)<<2)>>2]|0;do{if((g|0)==0){h=c[f+4184>>2]|0;if((h|0)==0){i=f;break}gg[h&4095](d&65535,e);i=c[9757320+(c[1836236]<<2)>>2]|0}else{a[g+(d&255)|0]=e;i=f}}while(0);f=d+1|0;d=a[9706061]|0;e=c[i+76+((f>>>8&255|256)<<2)>>2]|0;if((e|0)!=0){a[e+(f&255)|0]=d;c[2426515]=16;b[4853030]=16;return}e=c[i+4184>>2]|0;if((e|0)==0){c[2426515]=16;b[4853030]=16;return}gg[e&4095](f&65535,d);c[2426515]=16;b[4853030]=16;return}function giE(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if((a[9706068]&1)==0){return}d=c[2426516]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](d&65535)|0;h=j;i=c[9757320+(c[1836236]<<2)>>2]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9706060]=h;h=d+1|0;d=c[i+76+((h>>>8&255)<<2)>>2]|0;do{if((d|0)==0){e=c[i+4180>>2]|0;if((e|0)==0){k=0;break}k=gj[e&4095](h&65535)|0}else{k=a[d+(h&255)|0]|0}}while(0);a[9706061]=k;b[4853032]=(b[4853032]|0)+2&65535;b[4853030]=c[2426515]&65535;c[2076596]=(c[2076596]|0)-6;return}function giF(){var a=0;a=c[2426518]|0;c[2426518]=c[2426524];c[2426524]=a;a=c[2426519]|0;c[2426519]=c[2426525];c[2426525]=a;a=c[2426520]|0;c[2426520]=c[2426526];c[2426526]=a;return}function giG(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((a[9706068]&1)==0){d=(b[4853030]|0)+2&65535;b[4853030]=d;return}e=c[2426515]|0;f=e&65535;b[4853030]=f+2&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=j&255;j=e+1|0;e=c[k+76+((j>>>8&255|768)<<2)>>2]|0;do{if((e|0)==0){h=c[k+4180>>2]|0;if((h|0)==0){m=0;break}m=gj[h&4095](j&65535)|0}else{m=a[e+(j&255)|0]|0}}while(0);j=(m&255)<<8|g;c[2426515]=j;d=j&65535;b[4853030]=d;return}function giH(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=c[2426515]|0;f=e&65535;b[4853030]=f+1&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);a[9706069]=gj[c[k+4172>>2]&4095]((d[9706069]|0)<<8|j&255)|0;return}function giI(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((a[9706068]&1)==0){d=(b[4853030]|0)+2&65535;b[4853030]=d;return}e=c[2426515]|0;f=e&65535;b[4853030]=f+2&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=j&255;j=e+1|0;e=c[k+76+((j>>>8&255|768)<<2)>>2]|0;do{if((e|0)==0){h=c[k+4180>>2]|0;if((h|0)==0){m=0;n=k;break}f=gj[h&4095](j&65535)|0;m=f;n=c[9757320+(c[1836236]<<2)>>2]|0}else{m=a[e+(j&255)|0]|0;n=k}}while(0);c[3541536]=(m&255)<<8|g;b[4853032]=(b[4853032]|0)-2&65535;g=c[2426516]|0;m=a[9706060]|0;k=c[n+76+((g>>>8|256)<<2)>>2]|0;do{if((k|0)==0){j=c[n+4184>>2]|0;if((j|0)==0){o=n;break}gg[j&4095](g&65535,m);o=c[9757320+(c[1836236]<<2)>>2]|0}else{a[k+(g&255)|0]=m;o=n}}while(0);n=g+1|0;g=a[9706061]|0;m=c[o+76+((n>>>8&255|256)<<2)>>2]|0;do{if((m|0)==0){k=c[o+4184>>2]|0;if((k|0)==0){break}gg[k&4095](n&65535,g)}else{a[m+(n&255)|0]=g}}while(0);g=c[3541536]|0;c[2426515]=g;c[2076596]=(c[2076596]|0)-7;d=g&65535;b[4853030]=d;return}function giJ(){var e=0,f=0,g=0,h=0,i=0,j=0;a[9706108]=(a[9706108]|0)+1&255;e=c[2426515]|0;f=e&65535;b[4853030]=f+1&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;break}j=gj[i&4095](f)|0}else{j=a[h+(e&255)|0]|0}}while(0);e=j&255;c[2076596]=(c[2076596]|0)-(d[(c[2426878]|0)+e|0]|0);gu[c[676896+(e<<2)>>2]&16383]();return}function giK(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[2426517]|0;e=d&65280;f=d&1;d=e>>>8;g=c[2426515]|0;h=g&65535;b[4853030]=h+1&65535;i=c[9757320+(c[1836236]<<2)>>2]|0;j=c[i+76+((g>>>8|768)<<2)>>2]|0;do{if((j|0)==0){k=c[i+4180>>2]|0;if((k|0)==0){l=0;break}l=gj[k&4095](h)|0}else{l=a[j+(g&255)|0]|0}}while(0);g=d-(l&255)-f|0;a[9706068]=a[(c[2385738]|0)+(f<<16|e|g&255)|0]|0;a[9706069]=g&255;return}function giL(){var d=0,e=0,f=0,g=0,h=0,i=0;b[4853032]=(b[4853032]|0)-2&65535;d=c[2426516]|0;e=a[9706060]|0;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+((d>>>8|256)<<2)>>2]|0;do{if((g|0)==0){h=c[f+4184>>2]|0;if((h|0)==0){i=f;break}gg[h&4095](d&65535,e);i=c[9757320+(c[1836236]<<2)>>2]|0}else{a[g+(d&255)|0]=e;i=f}}while(0);f=d+1|0;d=a[9706061]|0;e=c[i+76+((f>>>8&255|256)<<2)>>2]|0;if((e|0)!=0){a[e+(f&255)|0]=d;c[2426515]=24;b[4853030]=24;return}e=c[i+4184>>2]|0;if((e|0)==0){c[2426515]=24;b[4853030]=24;return}gg[e&4095](f&65535,d);c[2426515]=24;b[4853030]=24;return}function giM(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if((a[9706068]&4)!=0){return}d=c[2426516]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](d&65535)|0;h=j;i=c[9757320+(c[1836236]<<2)>>2]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9706060]=h;h=d+1|0;d=c[i+76+((h>>>8&255)<<2)>>2]|0;do{if((d|0)==0){e=c[i+4180>>2]|0;if((e|0)==0){k=0;break}k=gj[e&4095](h&65535)|0}else{k=a[d+(h&255)|0]|0}}while(0);a[9706061]=k;b[4853032]=(b[4853032]|0)+2&65535;b[4853030]=c[2426515]&65535;c[2076596]=(c[2076596]|0)-6;return}function giN(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[2426516]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](d&65535)|0;h=j;i=c[9757320+(c[1836236]<<2)>>2]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9706088]=h;h=d+1|0;d=c[i+76+((h>>>8&255)<<2)>>2]|0;do{if((d|0)==0){e=c[i+4180>>2]|0;if((e|0)==0){k=0;break}k=gj[e&4095](h&65535)|0}else{k=a[d+(h&255)|0]|0}}while(0);a[9706089]=k;b[4853032]=(b[4853032]|0)+2&65535;return}function giO(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((a[9706068]&4)!=0){d=(b[4853030]|0)+2&65535;b[4853030]=d;return}e=c[2426515]|0;f=e&65535;b[4853030]=f+2&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=j&255;j=e+1|0;e=c[k+76+((j>>>8&255|768)<<2)>>2]|0;do{if((e|0)==0){h=c[k+4180>>2]|0;if((h|0)==0){m=0;break}m=gj[h&4095](j&65535)|0}else{m=a[e+(j&255)|0]|0}}while(0);j=(m&255)<<8|g;c[2426515]=j;d=j&65535;b[4853030]=d;return}function giP(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=c[2426516]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=d;break}i=gj[f&4095](b&65535)|0;g=i;h=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=d}}while(0);d=b+1|0;b=c[h+76+((d>>>8&255)<<2)>>2]|0;do{if((b|0)==0){e=c[h+4180>>2]|0;if((e|0)==0){j=0;k=h;break}i=gj[e&4095](d&65535)|0;j=i;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[b+(d&255)|0]|0;k=h}}while(0);h=c[2426516]|0;d=a[9706088]|0;b=c[k+76+((h>>>8|256)<<2)>>2]|0;do{if((b|0)==0){i=c[k+4184>>2]|0;if((i|0)==0){l=k;break}gg[i&4095](h&65535,d);l=c[9757320+(c[1836236]<<2)>>2]|0}else{a[b+(h&255)|0]=d;l=k}}while(0);k=h+1|0;h=a[9706089]|0;d=c[l+76+((k>>>8&255|256)<<2)>>2]|0;do{if((d|0)==0){b=c[l+4184>>2]|0;if((b|0)==0){break}gg[b&4095](k&65535,h)}else{a[d+(k&255)|0]=h}}while(0);c[2426522]=(j&255)<<8|g&255;return}function giQ(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((a[9706068]&4)!=0){d=(b[4853030]|0)+2&65535;b[4853030]=d;return}e=c[2426515]|0;f=e&65535;b[4853030]=f+2&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=j&255;j=e+1|0;e=c[k+76+((j>>>8&255|768)<<2)>>2]|0;do{if((e|0)==0){h=c[k+4180>>2]|0;if((h|0)==0){m=0;n=k;break}f=gj[h&4095](j&65535)|0;m=f;n=c[9757320+(c[1836236]<<2)>>2]|0}else{m=a[e+(j&255)|0]|0;n=k}}while(0);c[3541536]=(m&255)<<8|g;b[4853032]=(b[4853032]|0)-2&65535;g=c[2426516]|0;m=a[9706060]|0;k=c[n+76+((g>>>8|256)<<2)>>2]|0;do{if((k|0)==0){j=c[n+4184>>2]|0;if((j|0)==0){o=n;break}gg[j&4095](g&65535,m);o=c[9757320+(c[1836236]<<2)>>2]|0}else{a[k+(g&255)|0]=m;o=n}}while(0);n=g+1|0;g=a[9706061]|0;m=c[o+76+((n>>>8&255|256)<<2)>>2]|0;do{if((m|0)==0){k=c[o+4184>>2]|0;if((k|0)==0){break}gg[k&4095](n&65535,g)}else{a[m+(n&255)|0]=g}}while(0);g=c[3541536]|0;c[2426515]=g;c[2076596]=(c[2076596]|0)-7;d=g&65535;b[4853030]=d;return}function giR(){var d=0,e=0,f=0,g=0,h=0,i=0;b[4853032]=(b[4853032]|0)-2&65535;d=c[2426516]|0;e=a[9706088]|0;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+((d>>>8|256)<<2)>>2]|0;do{if((g|0)==0){h=c[f+4184>>2]|0;if((h|0)==0){i=f;break}gg[h&4095](d&65535,e);i=c[9757320+(c[1836236]<<2)>>2]|0}else{a[g+(d&255)|0]=e;i=f}}while(0);f=d+1|0;d=a[9706089]|0;e=c[i+76+((f>>>8&255|256)<<2)>>2]|0;if((e|0)!=0){a[e+(f&255)|0]=d;return}e=c[i+4184>>2]|0;if((e|0)==0){return}gg[e&4095](f&65535,d);return}function giS(){var d=0,e=0,f=0,g=0,h=0,i=0;d=c[2426515]|0;e=d&65535;b[4853030]=e+1&65535;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+((d>>>8|768)<<2)>>2]|0;do{if((g|0)==0){h=c[f+4180>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](e)|0}else{i=a[g+(d&255)|0]|0}}while(0);d=a[9706069]&i;a[9706069]=d;a[9706068]=a[9706144+(d&255)|0]|16;return}function giT(){var d=0,e=0,f=0,g=0,h=0,i=0;b[4853032]=(b[4853032]|0)-2&65535;d=c[2426516]|0;e=a[9706060]|0;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+((d>>>8|256)<<2)>>2]|0;do{if((g|0)==0){h=c[f+4184>>2]|0;if((h|0)==0){i=f;break}gg[h&4095](d&65535,e);i=c[9757320+(c[1836236]<<2)>>2]|0}else{a[g+(d&255)|0]=e;i=f}}while(0);f=d+1|0;d=a[9706061]|0;e=c[i+76+((f>>>8&255|256)<<2)>>2]|0;if((e|0)!=0){a[e+(f&255)|0]=d;c[2426515]=32;b[4853030]=32;return}e=c[i+4184>>2]|0;if((e|0)==0){c[2426515]=32;b[4853030]=32;return}gg[e&4095](f&65535,d);c[2426515]=32;b[4853030]=32;return}function giU(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if((a[9706068]&4)==0){return}d=c[2426516]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](d&65535)|0;h=j;i=c[9757320+(c[1836236]<<2)>>2]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9706060]=h;h=d+1|0;d=c[i+76+((h>>>8&255)<<2)>>2]|0;do{if((d|0)==0){e=c[i+4180>>2]|0;if((e|0)==0){k=0;break}k=gj[e&4095](h&65535)|0}else{k=a[d+(h&255)|0]|0}}while(0);a[9706061]=k;b[4853032]=(b[4853032]|0)+2&65535;b[4853030]=c[2426515]&65535;c[2076596]=(c[2076596]|0)-6;return}function giV(){b[4853030]=b[4853044]|0;b[4853030]=c[2426515]&65535;return}function giW(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((a[9706068]&4)==0){d=(b[4853030]|0)+2&65535;b[4853030]=d;return}e=c[2426515]|0;f=e&65535;b[4853030]=f+2&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=j&255;j=e+1|0;e=c[k+76+((j>>>8&255|768)<<2)>>2]|0;do{if((e|0)==0){h=c[k+4180>>2]|0;if((h|0)==0){m=0;break}m=gj[h&4095](j&65535)|0}else{m=a[e+(j&255)|0]|0}}while(0);j=(m&255)<<8|g;c[2426515]=j;d=j&65535;b[4853030]=d;return}function giX(){var a=0;a=c[2426519]|0;c[2426519]=c[2426520];c[2426520]=a;return}function giY(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((a[9706068]&4)==0){d=(b[4853030]|0)+2&65535;b[4853030]=d;return}e=c[2426515]|0;f=e&65535;b[4853030]=f+2&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=j&255;j=e+1|0;e=c[k+76+((j>>>8&255|768)<<2)>>2]|0;do{if((e|0)==0){h=c[k+4180>>2]|0;if((h|0)==0){m=0;n=k;break}f=gj[h&4095](j&65535)|0;m=f;n=c[9757320+(c[1836236]<<2)>>2]|0}else{m=a[e+(j&255)|0]|0;n=k}}while(0);c[3541536]=(m&255)<<8|g;b[4853032]=(b[4853032]|0)-2&65535;g=c[2426516]|0;m=a[9706060]|0;k=c[n+76+((g>>>8|256)<<2)>>2]|0;do{if((k|0)==0){j=c[n+4184>>2]|0;if((j|0)==0){o=n;break}gg[j&4095](g&65535,m);o=c[9757320+(c[1836236]<<2)>>2]|0}else{a[k+(g&255)|0]=m;o=n}}while(0);n=g+1|0;g=a[9706061]|0;m=c[o+76+((n>>>8&255|256)<<2)>>2]|0;do{if((m|0)==0){k=c[o+4184>>2]|0;if((k|0)==0){break}gg[k&4095](n&65535,g)}else{a[m+(n&255)|0]=g}}while(0);g=c[3541536]|0;c[2426515]=g;c[2076596]=(c[2076596]|0)-7;d=g&65535;b[4853030]=d;return}function giZ(){var e=0,f=0,g=0,h=0,i=0,j=0;a[9706108]=(a[9706108]|0)+1&255;e=c[2426515]|0;f=e&65535;b[4853030]=f+1&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;break}j=gj[i&4095](f)|0}else{j=a[h+(e&255)|0]|0}}while(0);e=j&255;c[2076596]=(c[2076596]|0)-(d[(c[2426880]|0)+e|0]|0);gu[c[675872+(e<<2)>>2]&16383]();return}function gi_(){var d=0,e=0,f=0,g=0,h=0,i=0;d=c[2426515]|0;e=d&65535;b[4853030]=e+1&65535;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+((d>>>8|768)<<2)>>2]|0;do{if((g|0)==0){h=c[f+4180>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](e)|0}else{i=a[g+(d&255)|0]|0}}while(0);d=a[9706069]^i;a[9706069]=d;a[9706068]=a[9706144+(d&255)|0]|0;return}function gi$(){var d=0,e=0,f=0,g=0,h=0,i=0;b[4853032]=(b[4853032]|0)-2&65535;d=c[2426516]|0;e=a[9706060]|0;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+((d>>>8|256)<<2)>>2]|0;do{if((g|0)==0){h=c[f+4184>>2]|0;if((h|0)==0){i=f;break}gg[h&4095](d&65535,e);i=c[9757320+(c[1836236]<<2)>>2]|0}else{a[g+(d&255)|0]=e;i=f}}while(0);f=d+1|0;d=a[9706061]|0;e=c[i+76+((f>>>8&255|256)<<2)>>2]|0;if((e|0)!=0){a[e+(f&255)|0]=d;c[2426515]=40;b[4853030]=40;return}e=c[i+4184>>2]|0;if((e|0)==0){c[2426515]=40;b[4853030]=40;return}gg[e&4095](f&65535,d);c[2426515]=40;b[4853030]=40;return}function gi0(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if((a[9706068]|0)<0){return}d=c[2426516]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](d&65535)|0;h=j;i=c[9757320+(c[1836236]<<2)>>2]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9706060]=h;h=d+1|0;d=c[i+76+((h>>>8&255)<<2)>>2]|0;do{if((d|0)==0){e=c[i+4180>>2]|0;if((e|0)==0){k=0;break}k=gj[e&4095](h&65535)|0}else{k=a[d+(h&255)|0]|0}}while(0);a[9706061]=k;b[4853032]=(b[4853032]|0)+2&65535;b[4853030]=c[2426515]&65535;c[2076596]=(c[2076596]|0)-6;return}function gi1(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[2426516]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](d&65535)|0;h=j;i=c[9757320+(c[1836236]<<2)>>2]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9706068]=h;h=d+1|0;d=c[i+76+((h>>>8&255)<<2)>>2]|0;do{if((d|0)==0){e=c[i+4180>>2]|0;if((e|0)==0){k=0;break}k=gj[e&4095](h&65535)|0}else{k=a[d+(h&255)|0]|0}}while(0);a[9706069]=k;b[4853032]=(b[4853032]|0)+2&65535;return}function gi2(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((a[9706068]|0)<0){d=(b[4853030]|0)+2&65535;b[4853030]=d;return}e=c[2426515]|0;f=e&65535;b[4853030]=f+2&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=j&255;j=e+1|0;e=c[k+76+((j>>>8&255|768)<<2)>>2]|0;do{if((e|0)==0){h=c[k+4180>>2]|0;if((h|0)==0){m=0;break}m=gj[h&4095](j&65535)|0}else{m=a[e+(j&255)|0]|0}}while(0);j=(m&255)<<8|g;c[2426515]=j;d=j&65535;b[4853030]=d;return}function gi3(){a[9706111]=0;a[9706110]=0;return}function gi4(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((a[9706068]|0)<0){d=(b[4853030]|0)+2&65535;b[4853030]=d;return}e=c[2426515]|0;f=e&65535;b[4853030]=f+2&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=j&255;j=e+1|0;e=c[k+76+((j>>>8&255|768)<<2)>>2]|0;do{if((e|0)==0){h=c[k+4180>>2]|0;if((h|0)==0){m=0;n=k;break}f=gj[h&4095](j&65535)|0;m=f;n=c[9757320+(c[1836236]<<2)>>2]|0}else{m=a[e+(j&255)|0]|0;n=k}}while(0);c[3541536]=(m&255)<<8|g;b[4853032]=(b[4853032]|0)-2&65535;g=c[2426516]|0;m=a[9706060]|0;k=c[n+76+((g>>>8|256)<<2)>>2]|0;do{if((k|0)==0){j=c[n+4184>>2]|0;if((j|0)==0){o=n;break}gg[j&4095](g&65535,m);o=c[9757320+(c[1836236]<<2)>>2]|0}else{a[k+(g&255)|0]=m;o=n}}while(0);n=g+1|0;g=a[9706061]|0;m=c[o+76+((n>>>8&255|256)<<2)>>2]|0;do{if((m|0)==0){k=c[o+4184>>2]|0;if((k|0)==0){break}gg[k&4095](n&65535,g)}else{a[m+(n&255)|0]=g}}while(0);g=c[3541536]|0;c[2426515]=g;c[2076596]=(c[2076596]|0)-7;d=g&65535;b[4853030]=d;return}function gi5(){var d=0,e=0,f=0,g=0,h=0,i=0;b[4853032]=(b[4853032]|0)-2&65535;d=c[2426516]|0;e=a[9706068]|0;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+((d>>>8|256)<<2)>>2]|0;do{if((g|0)==0){h=c[f+4184>>2]|0;if((h|0)==0){i=f;break}gg[h&4095](d&65535,e);i=c[9757320+(c[1836236]<<2)>>2]|0}else{a[g+(d&255)|0]=e;i=f}}while(0);f=d+1|0;d=a[9706069]|0;e=c[i+76+((f>>>8&255|256)<<2)>>2]|0;if((e|0)!=0){a[e+(f&255)|0]=d;return}e=c[i+4184>>2]|0;if((e|0)==0){return}gg[e&4095](f&65535,d);return}function gi6(){var d=0,e=0,f=0,g=0,h=0,i=0;d=c[2426515]|0;e=d&65535;b[4853030]=e+1&65535;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+((d>>>8|768)<<2)>>2]|0;do{if((g|0)==0){h=c[f+4180>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](e)|0}else{i=a[g+(d&255)|0]|0}}while(0);d=a[9706069]|i;a[9706069]=d;a[9706068]=a[9706144+(d&255)|0]|0;return}function gi7(){var d=0,e=0,f=0,g=0,h=0,i=0;b[4853032]=(b[4853032]|0)-2&65535;d=c[2426516]|0;e=a[9706060]|0;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+((d>>>8|256)<<2)>>2]|0;do{if((g|0)==0){h=c[f+4184>>2]|0;if((h|0)==0){i=f;break}gg[h&4095](d&65535,e);i=c[9757320+(c[1836236]<<2)>>2]|0}else{a[g+(d&255)|0]=e;i=f}}while(0);f=d+1|0;d=a[9706061]|0;e=c[i+76+((f>>>8&255|256)<<2)>>2]|0;if((e|0)!=0){a[e+(f&255)|0]=d;c[2426515]=48;b[4853030]=48;return}e=c[i+4184>>2]|0;if((e|0)==0){c[2426515]=48;b[4853030]=48;return}gg[e&4095](f&65535,d);c[2426515]=48;b[4853030]=48;return}function gi8(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if((a[9706068]|0)>=0){return}d=c[2426516]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](d&65535)|0;h=j;i=c[9757320+(c[1836236]<<2)>>2]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9706060]=h;h=d+1|0;d=c[i+76+((h>>>8&255)<<2)>>2]|0;do{if((d|0)==0){e=c[i+4180>>2]|0;if((e|0)==0){k=0;break}k=gj[e&4095](h&65535)|0}else{k=a[d+(h&255)|0]|0}}while(0);a[9706061]=k;b[4853032]=(b[4853032]|0)+2&65535;b[4853030]=c[2426515]&65535;c[2076596]=(c[2076596]|0)-6;return}function gi9(){b[4853032]=b[4853044]|0;return}function gja(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((a[9706068]|0)>=0){d=(b[4853030]|0)+2&65535;b[4853030]=d;return}e=c[2426515]|0;f=e&65535;b[4853030]=f+2&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=j&255;j=e+1|0;e=c[k+76+((j>>>8&255|768)<<2)>>2]|0;do{if((e|0)==0){h=c[k+4180>>2]|0;if((h|0)==0){m=0;break}m=gj[h&4095](j&65535)|0}else{m=a[e+(j&255)|0]|0}}while(0);j=(m&255)<<8|g;c[2426515]=j;d=j&65535;b[4853030]=d;return}function gjb(){a[9706111]=1;a[9706110]=1;a[9706118]=1;return}function gjc(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((a[9706068]|0)>=0){d=(b[4853030]|0)+2&65535;b[4853030]=d;return}e=c[2426515]|0;f=e&65535;b[4853030]=f+2&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=j&255;j=e+1|0;e=c[k+76+((j>>>8&255|768)<<2)>>2]|0;do{if((e|0)==0){h=c[k+4180>>2]|0;if((h|0)==0){m=0;n=k;break}f=gj[h&4095](j&65535)|0;m=f;n=c[9757320+(c[1836236]<<2)>>2]|0}else{m=a[e+(j&255)|0]|0;n=k}}while(0);c[3541536]=(m&255)<<8|g;b[4853032]=(b[4853032]|0)-2&65535;g=c[2426516]|0;m=a[9706060]|0;k=c[n+76+((g>>>8|256)<<2)>>2]|0;do{if((k|0)==0){j=c[n+4184>>2]|0;if((j|0)==0){o=n;break}gg[j&4095](g&65535,m);o=c[9757320+(c[1836236]<<2)>>2]|0}else{a[k+(g&255)|0]=m;o=n}}while(0);n=g+1|0;g=a[9706061]|0;m=c[o+76+((n>>>8&255|256)<<2)>>2]|0;do{if((m|0)==0){k=c[o+4184>>2]|0;if((k|0)==0){break}gg[k&4095](n&65535,g)}else{a[m+(n&255)|0]=g}}while(0);g=c[3541536]|0;c[2426515]=g;c[2076596]=(c[2076596]|0)-7;d=g&65535;b[4853030]=d;return}function gjd(){var e=0,f=0,g=0,h=0,i=0,j=0;a[9706108]=(a[9706108]|0)+1&255;e=c[2426515]|0;f=e&65535;b[4853030]=f+1&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;break}j=gj[i&4095](f)|0}else{j=a[h+(e&255)|0]|0}}while(0);e=j&255;c[2076596]=(c[2076596]|0)-(d[(c[2426878]|0)+e|0]|0);gu[c[674848+(e<<2)>>2]&16383]();return}function gje(){var d=0,e=0,f=0,g=0,h=0,i=0;d=c[2426515]|0;e=d&65535;b[4853030]=e+1&65535;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+((d>>>8|768)<<2)>>2]|0;do{if((g|0)==0){h=c[f+4180>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](e)|0}else{i=a[g+(d&255)|0]|0}}while(0);d=c[2426517]&65280;a[9706068]=a[(c[2385738]|0)+((d>>>8)-(i&255)&255|d)|0]&-41|i&40;return}function gjf(){var d=0,e=0,f=0,g=0,h=0,i=0;b[4853032]=(b[4853032]|0)-2&65535;d=c[2426516]|0;e=a[9706060]|0;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+((d>>>8|256)<<2)>>2]|0;do{if((g|0)==0){h=c[f+4184>>2]|0;if((h|0)==0){i=f;break}gg[h&4095](d&65535,e);i=c[9757320+(c[1836236]<<2)>>2]|0}else{a[g+(d&255)|0]=e;i=f}}while(0);f=d+1|0;d=a[9706061]|0;e=c[i+76+((f>>>8&255|256)<<2)>>2]|0;if((e|0)!=0){a[e+(f&255)|0]=d;c[2426515]=56;b[4853030]=56;return}e=c[i+4184>>2]|0;if((e|0)==0){c[2426515]=56;b[4853030]=56;return}gg[e&4095](f&65535,d);c[2426515]=56;b[4853030]=56;return}function gjg(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g&255;b=d<<1&254|d>>>7;a[9706068]=a[9706144+b|0]|(g&255)>>>7;g=b&255;a[9706073]=g;b=c[i+76+((h>>>8|256)<<2)>>2]|0;if((b|0)!=0){a[b+(h&255)|0]=g;return}b=c[i+4184>>2]|0;if((b|0)==0){return}gg[b&4095](h&65535,g);return}function gjh(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g&255;b=d<<1&254|d>>>7;a[9706068]=a[9706144+b|0]|(g&255)>>>7;g=b&255;a[9706072]=g;b=c[i+76+((h>>>8|256)<<2)>>2]|0;if((b|0)!=0){a[b+(h&255)|0]=g;return}b=c[i+4184>>2]|0;if((b|0)==0){return}gg[b&4095](h&65535,g);return}function gji(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g&255;b=d<<1&254|d>>>7;a[9706068]=a[9706144+b|0]|(g&255)>>>7;g=b&255;a[9706077]=g;b=c[i+76+((h>>>8|256)<<2)>>2]|0;if((b|0)!=0){a[b+(h&255)|0]=g;return}b=c[i+4184>>2]|0;if((b|0)==0){return}gg[b&4095](h&65535,g);return}function gjj(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g&255;b=d<<1&254|d>>>7;a[9706068]=a[9706144+b|0]|(g&255)>>>7;g=b&255;a[9706076]=g;b=c[i+76+((h>>>8|256)<<2)>>2]|0;if((b|0)!=0){a[b+(h&255)|0]=g;return}b=c[i+4184>>2]|0;if((b|0)==0){return}gg[b&4095](h&65535,g);return}function gjk(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g&255;b=d<<1&254|d>>>7;a[9706068]=a[9706144+b|0]|(g&255)>>>7;g=b&255;a[9706081]=g;b=c[i+76+((h>>>8|256)<<2)>>2]|0;if((b|0)!=0){a[b+(h&255)|0]=g;return}b=c[i+4184>>2]|0;if((b|0)==0){return}gg[b&4095](h&65535,g);return}function gjl(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g&255;b=d<<1&254|d>>>7;a[9706068]=a[9706144+b|0]|(g&255)>>>7;g=b&255;a[9706080]=g;b=c[i+76+((h>>>8|256)<<2)>>2]|0;if((b|0)!=0){a[b+(h&255)|0]=g;return}b=c[i+4184>>2]|0;if((b|0)==0){return}gg[b&4095](h&65535,g);return}function gjm(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=b>>>8;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](b&65535)|0;h=j;i=c[9757320+(c[1836236]<<2)>>2]|0}else{h=a[f+(b&255)|0]|0;i=e}}while(0);e=h&255;f=e<<1&254|e>>>7;a[9706068]=a[9706144+f|0]|(h&255)>>>7;h=f&255;f=c[i+76+((d|256)<<2)>>2]|0;if((f|0)!=0){a[f+(b&255)|0]=h;return}f=c[i+4184>>2]|0;if((f|0)==0){return}gg[f&4095](b&65535,h);return}function gjn(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g&255;b=d<<1&254|d>>>7;a[9706068]=a[9706144+b|0]|(g&255)>>>7;g=b&255;a[9706069]=g;b=c[i+76+((h>>>8|256)<<2)>>2]|0;if((b|0)!=0){a[b+(h&255)|0]=g;return}b=c[i+4184>>2]|0;if((b|0)==0){return}gg[b&4095](h&65535,g);return}function gjo(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g&255;b=d<<7&128|d>>>1;a[9706068]=a[9706144+b|0]|g&1;g=b&255;a[9706073]=g;b=c[i+76+((h>>>8|256)<<2)>>2]|0;if((b|0)!=0){a[b+(h&255)|0]=g;return}b=c[i+4184>>2]|0;if((b|0)==0){return}gg[b&4095](h&65535,g);return}function gjp(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g&255;b=d<<7&128|d>>>1;a[9706068]=a[9706144+b|0]|g&1;g=b&255;a[9706072]=g;b=c[i+76+((h>>>8|256)<<2)>>2]|0;if((b|0)!=0){a[b+(h&255)|0]=g;return}b=c[i+4184>>2]|0;if((b|0)==0){return}gg[b&4095](h&65535,g);return}function gjq(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g&255;b=d<<7&128|d>>>1;a[9706068]=a[9706144+b|0]|g&1;g=b&255;a[9706077]=g;b=c[i+76+((h>>>8|256)<<2)>>2]|0;if((b|0)!=0){a[b+(h&255)|0]=g;return}b=c[i+4184>>2]|0;if((b|0)==0){return}gg[b&4095](h&65535,g);return}function gjr(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g&255;b=d<<7&128|d>>>1;a[9706068]=a[9706144+b|0]|g&1;g=b&255;a[9706076]=g;b=c[i+76+((h>>>8|256)<<2)>>2]|0;if((b|0)!=0){a[b+(h&255)|0]=g;return}b=c[i+4184>>2]|0;if((b|0)==0){return}gg[b&4095](h&65535,g);return}function gjs(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g&255;b=d<<7&128|d>>>1;a[9706068]=a[9706144+b|0]|g&1;g=b&255;a[9706081]=g;b=c[i+76+((h>>>8|256)<<2)>>2]|0;if((b|0)!=0){a[b+(h&255)|0]=g;return}b=c[i+4184>>2]|0;if((b|0)==0){return}gg[b&4095](h&65535,g);return}function gjt(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g&255;b=d<<7&128|d>>>1;a[9706068]=a[9706144+b|0]|g&1;g=b&255;a[9706080]=g;b=c[i+76+((h>>>8|256)<<2)>>2]|0;if((b|0)!=0){a[b+(h&255)|0]=g;return}b=c[i+4184>>2]|0;if((b|0)==0){return}gg[b&4095](h&65535,g);return}function gju(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=b>>>8;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](b&65535)|0;h=j;i=c[9757320+(c[1836236]<<2)>>2]|0}else{h=a[f+(b&255)|0]|0;i=e}}while(0);e=h&255;f=e<<7&128|e>>>1;a[9706068]=a[9706144+f|0]|h&1;h=f&255;f=c[i+76+((d|256)<<2)>>2]|0;if((f|0)!=0){a[f+(b&255)|0]=h;return}f=c[i+4184>>2]|0;if((f|0)==0){return}gg[f&4095](b&65535,h);return}function gjv(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g&255;b=d<<7&128|d>>>1;a[9706068]=a[9706144+b|0]|g&1;g=b&255;a[9706069]=g;b=c[i+76+((h>>>8|256)<<2)>>2]|0;if((b|0)!=0){a[b+(h&255)|0]=g;return}b=c[i+4184>>2]|0;if((b|0)==0){return}gg[b&4095](h&65535,g);return}function gjw(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=a[9706068]&1|(g&255)<<1&254;a[9706068]=a[9706144+d|0]|(g&255)>>>7;g=d&255;a[9706073]=g;d=c[i+76+((h>>>8|256)<<2)>>2]|0;if((d|0)!=0){a[d+(h&255)|0]=g;return}d=c[i+4184>>2]|0;if((d|0)==0){return}gg[d&4095](h&65535,g);return}function gjx(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=a[9706068]&1|(g&255)<<1&254;a[9706068]=a[9706144+d|0]|(g&255)>>>7;g=d&255;a[9706072]=g;d=c[i+76+((h>>>8|256)<<2)>>2]|0;if((d|0)!=0){a[d+(h&255)|0]=g;return}d=c[i+4184>>2]|0;if((d|0)==0){return}gg[d&4095](h&65535,g);return}function gjy(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=a[9706068]&1|(g&255)<<1&254;a[9706068]=a[9706144+d|0]|(g&255)>>>7;g=d&255;a[9706077]=g;d=c[i+76+((h>>>8|256)<<2)>>2]|0;if((d|0)!=0){a[d+(h&255)|0]=g;return}d=c[i+4184>>2]|0;if((d|0)==0){return}gg[d&4095](h&65535,g);return}function gjz(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=a[9706068]&1|(g&255)<<1&254;a[9706068]=a[9706144+d|0]|(g&255)>>>7;g=d&255;a[9706076]=g;d=c[i+76+((h>>>8|256)<<2)>>2]|0;if((d|0)!=0){a[d+(h&255)|0]=g;return}d=c[i+4184>>2]|0;if((d|0)==0){return}gg[d&4095](h&65535,g);return}function gjA(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=a[9706068]&1|(g&255)<<1&254;a[9706068]=a[9706144+d|0]|(g&255)>>>7;g=d&255;a[9706081]=g;d=c[i+76+((h>>>8|256)<<2)>>2]|0;if((d|0)!=0){a[d+(h&255)|0]=g;return}d=c[i+4184>>2]|0;if((d|0)==0){return}gg[d&4095](h&65535,g);return}function gjB(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=a[9706068]&1|(g&255)<<1&254;a[9706068]=a[9706144+d|0]|(g&255)>>>7;g=d&255;a[9706080]=g;d=c[i+76+((h>>>8|256)<<2)>>2]|0;if((d|0)!=0){a[d+(h&255)|0]=g;return}d=c[i+4184>>2]|0;if((d|0)==0){return}gg[d&4095](h&65535,g);return}function gjC(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=b>>>8;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](b&65535)|0;h=j;i=c[9757320+(c[1836236]<<2)>>2]|0}else{h=a[f+(b&255)|0]|0;i=e}}while(0);e=a[9706068]&1|(h&255)<<1&254;a[9706068]=a[9706144+e|0]|(h&255)>>>7;h=e&255;e=c[i+76+((d|256)<<2)>>2]|0;if((e|0)!=0){a[e+(b&255)|0]=h;return}e=c[i+4184>>2]|0;if((e|0)==0){return}gg[e&4095](b&65535,h);return}function gjD(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=a[9706068]&1|(g&255)<<1&254;a[9706068]=a[9706144+d|0]|(g&255)>>>7;g=d&255;a[9706069]=g;d=c[i+76+((h>>>8|256)<<2)>>2]|0;if((d|0)!=0){a[d+(h&255)|0]=g;return}d=c[i+4184>>2]|0;if((d|0)==0){return}gg[d&4095](h&65535,g);return}function gjE(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[3541536]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(b>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=b;j=e;break}k=gj[g&4095](b&65535)|0;h=k;i=c[3541536]|0;j=c[9757320+(c[1836236]<<2)>>2]|0}else{h=a[f+(b&255)|0]|0;i=b;j=e}}while(0);e=(d[9706068]|0)<<7&128|(h&255)>>>1;a[9706068]=a[9706144+e|0]|h&1;h=e&255;a[9706073]=h;e=c[j+76+((i>>>8|256)<<2)>>2]|0;if((e|0)!=0){a[e+(i&255)|0]=h;return}e=c[j+4184>>2]|0;if((e|0)==0){return}gg[e&4095](i&65535,h);return}function gjF(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[3541536]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(b>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=b;j=e;break}k=gj[g&4095](b&65535)|0;h=k;i=c[3541536]|0;j=c[9757320+(c[1836236]<<2)>>2]|0}else{h=a[f+(b&255)|0]|0;i=b;j=e}}while(0);e=(d[9706068]|0)<<7&128|(h&255)>>>1;a[9706068]=a[9706144+e|0]|h&1;h=e&255;a[9706072]=h;e=c[j+76+((i>>>8|256)<<2)>>2]|0;if((e|0)!=0){a[e+(i&255)|0]=h;return}e=c[j+4184>>2]|0;if((e|0)==0){return}gg[e&4095](i&65535,h);return}function gjG(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[3541536]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(b>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=b;j=e;break}k=gj[g&4095](b&65535)|0;h=k;i=c[3541536]|0;j=c[9757320+(c[1836236]<<2)>>2]|0}else{h=a[f+(b&255)|0]|0;i=b;j=e}}while(0);e=(d[9706068]|0)<<7&128|(h&255)>>>1;a[9706068]=a[9706144+e|0]|h&1;h=e&255;a[9706077]=h;e=c[j+76+((i>>>8|256)<<2)>>2]|0;if((e|0)!=0){a[e+(i&255)|0]=h;return}e=c[j+4184>>2]|0;if((e|0)==0){return}gg[e&4095](i&65535,h);return}function gjH(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[3541536]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(b>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=b;j=e;break}k=gj[g&4095](b&65535)|0;h=k;i=c[3541536]|0;j=c[9757320+(c[1836236]<<2)>>2]|0}else{h=a[f+(b&255)|0]|0;i=b;j=e}}while(0);e=(d[9706068]|0)<<7&128|(h&255)>>>1;a[9706068]=a[9706144+e|0]|h&1;h=e&255;a[9706076]=h;e=c[j+76+((i>>>8|256)<<2)>>2]|0;if((e|0)!=0){a[e+(i&255)|0]=h;return}e=c[j+4184>>2]|0;if((e|0)==0){return}gg[e&4095](i&65535,h);return}function gjI(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[3541536]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(b>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=b;j=e;break}k=gj[g&4095](b&65535)|0;h=k;i=c[3541536]|0;j=c[9757320+(c[1836236]<<2)>>2]|0}else{h=a[f+(b&255)|0]|0;i=b;j=e}}while(0);e=(d[9706068]|0)<<7&128|(h&255)>>>1;a[9706068]=a[9706144+e|0]|h&1;h=e&255;a[9706081]=h;e=c[j+76+((i>>>8|256)<<2)>>2]|0;if((e|0)!=0){a[e+(i&255)|0]=h;return}e=c[j+4184>>2]|0;if((e|0)==0){return}gg[e&4095](i&65535,h);return}function gjJ(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[3541536]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(b>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=b;j=e;break}k=gj[g&4095](b&65535)|0;h=k;i=c[3541536]|0;j=c[9757320+(c[1836236]<<2)>>2]|0}else{h=a[f+(b&255)|0]|0;i=b;j=e}}while(0);e=(d[9706068]|0)<<7&128|(h&255)>>>1;a[9706068]=a[9706144+e|0]|h&1;h=e&255;a[9706080]=h;e=c[j+76+((i>>>8|256)<<2)>>2]|0;if((e|0)!=0){a[e+(i&255)|0]=h;return}e=c[j+4184>>2]|0;if((e|0)==0){return}gg[e&4095](i&65535,h);return}function gjK(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[3541536]|0;e=b>>>8;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+(e<<2)>>2]|0;do{if((g|0)==0){h=c[f+4180>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](b&65535)|0;i=k;j=c[9757320+(c[1836236]<<2)>>2]|0}else{i=a[g+(b&255)|0]|0;j=f}}while(0);f=(d[9706068]|0)<<7&128|(i&255)>>>1;a[9706068]=a[9706144+f|0]|i&1;i=f&255;f=c[j+76+((e|256)<<2)>>2]|0;if((f|0)!=0){a[f+(b&255)|0]=i;return}f=c[j+4184>>2]|0;if((f|0)==0){return}gg[f&4095](b&65535,i);return}function gjL(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[3541536]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(b>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=b;j=e;break}k=gj[g&4095](b&65535)|0;h=k;i=c[3541536]|0;j=c[9757320+(c[1836236]<<2)>>2]|0}else{h=a[f+(b&255)|0]|0;i=b;j=e}}while(0);e=(d[9706068]|0)<<7&128|(h&255)>>>1;a[9706068]=a[9706144+e|0]|h&1;h=e&255;a[9706069]=h;e=c[j+76+((i>>>8|256)<<2)>>2]|0;if((e|0)!=0){a[e+(i&255)|0]=h;return}e=c[j+4184>>2]|0;if((e|0)==0){return}gg[e&4095](i&65535,h);return}function gjM(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=(g&255)<<1;a[9706068]=a[9706144+(d&254)|0]|(g&255)>>>7;g=d&255;a[9706073]=g;d=c[i+76+((h>>>8|256)<<2)>>2]|0;if((d|0)!=0){a[d+(h&255)|0]=g;return}d=c[i+4184>>2]|0;if((d|0)==0){return}gg[d&4095](h&65535,g);return}function gjN(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=(g&255)<<1;a[9706068]=a[9706144+(d&254)|0]|(g&255)>>>7;g=d&255;a[9706072]=g;d=c[i+76+((h>>>8|256)<<2)>>2]|0;if((d|0)!=0){a[d+(h&255)|0]=g;return}d=c[i+4184>>2]|0;if((d|0)==0){return}gg[d&4095](h&65535,g);return}function gjO(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=(g&255)<<1;a[9706068]=a[9706144+(d&254)|0]|(g&255)>>>7;g=d&255;a[9706077]=g;d=c[i+76+((h>>>8|256)<<2)>>2]|0;if((d|0)!=0){a[d+(h&255)|0]=g;return}d=c[i+4184>>2]|0;if((d|0)==0){return}gg[d&4095](h&65535,g);return}function gjP(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=(g&255)<<1;a[9706068]=a[9706144+(d&254)|0]|(g&255)>>>7;g=d&255;a[9706076]=g;d=c[i+76+((h>>>8|256)<<2)>>2]|0;if((d|0)!=0){a[d+(h&255)|0]=g;return}d=c[i+4184>>2]|0;if((d|0)==0){return}gg[d&4095](h&65535,g);return}function gjQ(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=(g&255)<<1;a[9706068]=a[9706144+(d&254)|0]|(g&255)>>>7;g=d&255;a[9706081]=g;d=c[i+76+((h>>>8|256)<<2)>>2]|0;if((d|0)!=0){a[d+(h&255)|0]=g;return}d=c[i+4184>>2]|0;if((d|0)==0){return}gg[d&4095](h&65535,g);return}function gjR(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=(g&255)<<1;a[9706068]=a[9706144+(d&254)|0]|(g&255)>>>7;g=d&255;a[9706080]=g;d=c[i+76+((h>>>8|256)<<2)>>2]|0;if((d|0)!=0){a[d+(h&255)|0]=g;return}d=c[i+4184>>2]|0;if((d|0)==0){return}gg[d&4095](h&65535,g);return}function gjS(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=b>>>8;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](b&65535)|0;h=j;i=c[9757320+(c[1836236]<<2)>>2]|0}else{h=a[f+(b&255)|0]|0;i=e}}while(0);e=(h&255)<<1;a[9706068]=a[9706144+(e&254)|0]|(h&255)>>>7;h=e&255;e=c[i+76+((d|256)<<2)>>2]|0;if((e|0)!=0){a[e+(b&255)|0]=h;return}e=c[i+4184>>2]|0;if((e|0)==0){return}gg[e&4095](b&65535,h);return}function gjT(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=(g&255)<<1;a[9706068]=a[9706144+(d&254)|0]|(g&255)>>>7;g=d&255;a[9706069]=g;d=c[i+76+((h>>>8|256)<<2)>>2]|0;if((d|0)!=0){a[d+(h&255)|0]=g;return}d=c[i+4184>>2]|0;if((d|0)==0){return}gg[d&4095](h&65535,g);return}function gjU(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g&255;b=d>>>1|d&128;a[9706068]=a[9706144+b|0]|g&1;g=b&255;a[9706073]=g;b=c[i+76+((h>>>8|256)<<2)>>2]|0;if((b|0)!=0){a[b+(h&255)|0]=g;return}b=c[i+4184>>2]|0;if((b|0)==0){return}gg[b&4095](h&65535,g);return}function gjV(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g&255;b=d>>>1|d&128;a[9706068]=a[9706144+b|0]|g&1;g=b&255;a[9706072]=g;b=c[i+76+((h>>>8|256)<<2)>>2]|0;if((b|0)!=0){a[b+(h&255)|0]=g;return}b=c[i+4184>>2]|0;if((b|0)==0){return}gg[b&4095](h&65535,g);return}function gjW(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g&255;b=d>>>1|d&128;a[9706068]=a[9706144+b|0]|g&1;g=b&255;a[9706077]=g;b=c[i+76+((h>>>8|256)<<2)>>2]|0;if((b|0)!=0){a[b+(h&255)|0]=g;return}b=c[i+4184>>2]|0;if((b|0)==0){return}gg[b&4095](h&65535,g);return}function gjX(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g&255;b=d>>>1|d&128;a[9706068]=a[9706144+b|0]|g&1;g=b&255;a[9706076]=g;b=c[i+76+((h>>>8|256)<<2)>>2]|0;if((b|0)!=0){a[b+(h&255)|0]=g;return}b=c[i+4184>>2]|0;if((b|0)==0){return}gg[b&4095](h&65535,g);return}function gjY(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g&255;b=d>>>1|d&128;a[9706068]=a[9706144+b|0]|g&1;g=b&255;a[9706081]=g;b=c[i+76+((h>>>8|256)<<2)>>2]|0;if((b|0)!=0){a[b+(h&255)|0]=g;return}b=c[i+4184>>2]|0;if((b|0)==0){return}gg[b&4095](h&65535,g);return}function gjZ(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g&255;b=d>>>1|d&128;a[9706068]=a[9706144+b|0]|g&1;g=b&255;a[9706080]=g;b=c[i+76+((h>>>8|256)<<2)>>2]|0;if((b|0)!=0){a[b+(h&255)|0]=g;return}b=c[i+4184>>2]|0;if((b|0)==0){return}gg[b&4095](h&65535,g);return}function gj_(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=b>>>8;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](b&65535)|0;h=j;i=c[9757320+(c[1836236]<<2)>>2]|0}else{h=a[f+(b&255)|0]|0;i=e}}while(0);e=h&255;f=e>>>1|e&128;a[9706068]=a[9706144+f|0]|h&1;h=f&255;f=c[i+76+((d|256)<<2)>>2]|0;if((f|0)!=0){a[f+(b&255)|0]=h;return}f=c[i+4184>>2]|0;if((f|0)==0){return}gg[f&4095](b&65535,h);return}function gj$(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g&255;b=d>>>1|d&128;a[9706068]=a[9706144+b|0]|g&1;g=b&255;a[9706069]=g;b=c[i+76+((h>>>8|256)<<2)>>2]|0;if((b|0)!=0){a[b+(h&255)|0]=g;return}b=c[i+4184>>2]|0;if((b|0)==0){return}gg[b&4095](h&65535,g);return}function gj0(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=(g&255)<<1&254|1;a[9706068]=a[9706144+d|0]|(g&255)>>>7;g=d&255;a[9706073]=g;d=c[i+76+((h>>>8|256)<<2)>>2]|0;if((d|0)!=0){a[d+(h&255)|0]=g;return}d=c[i+4184>>2]|0;if((d|0)==0){return}gg[d&4095](h&65535,g);return}function gj1(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=(g&255)<<1&254|1;a[9706068]=a[9706144+d|0]|(g&255)>>>7;g=d&255;a[9706072]=g;d=c[i+76+((h>>>8|256)<<2)>>2]|0;if((d|0)!=0){a[d+(h&255)|0]=g;return}d=c[i+4184>>2]|0;if((d|0)==0){return}gg[d&4095](h&65535,g);return}function gj2(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=(g&255)<<1&254|1;a[9706068]=a[9706144+d|0]|(g&255)>>>7;g=d&255;a[9706077]=g;d=c[i+76+((h>>>8|256)<<2)>>2]|0;if((d|0)!=0){a[d+(h&255)|0]=g;return}d=c[i+4184>>2]|0;if((d|0)==0){return}gg[d&4095](h&65535,g);return}function gj3(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=(g&255)<<1&254|1;a[9706068]=a[9706144+d|0]|(g&255)>>>7;g=d&255;a[9706076]=g;d=c[i+76+((h>>>8|256)<<2)>>2]|0;if((d|0)!=0){a[d+(h&255)|0]=g;return}d=c[i+4184>>2]|0;if((d|0)==0){return}gg[d&4095](h&65535,g);return}function gj4(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=(g&255)<<1&254|1;a[9706068]=a[9706144+d|0]|(g&255)>>>7;g=d&255;a[9706081]=g;d=c[i+76+((h>>>8|256)<<2)>>2]|0;if((d|0)!=0){a[d+(h&255)|0]=g;return}d=c[i+4184>>2]|0;if((d|0)==0){return}gg[d&4095](h&65535,g);return}function gj5(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=(g&255)<<1&254|1;a[9706068]=a[9706144+d|0]|(g&255)>>>7;g=d&255;a[9706080]=g;d=c[i+76+((h>>>8|256)<<2)>>2]|0;if((d|0)!=0){a[d+(h&255)|0]=g;return}d=c[i+4184>>2]|0;if((d|0)==0){return}gg[d&4095](h&65535,g);return}function gj6(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=b>>>8;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](b&65535)|0;h=j;i=c[9757320+(c[1836236]<<2)>>2]|0}else{h=a[f+(b&255)|0]|0;i=e}}while(0);e=(h&255)<<1&254|1;a[9706068]=a[9706144+e|0]|(h&255)>>>7;h=e&255;e=c[i+76+((d|256)<<2)>>2]|0;if((e|0)!=0){a[e+(b&255)|0]=h;return}e=c[i+4184>>2]|0;if((e|0)==0){return}gg[e&4095](b&65535,h);return}function gj7(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=(g&255)<<1&254|1;a[9706068]=a[9706144+d|0]|(g&255)>>>7;g=d&255;a[9706069]=g;d=c[i+76+((h>>>8|256)<<2)>>2]|0;if((d|0)!=0){a[d+(h&255)|0]=g;return}d=c[i+4184>>2]|0;if((d|0)==0){return}gg[d&4095](h&65535,g);return}function gj8(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=(g&255)>>>1;a[9706068]=a[9706144+d|0]|g&1;g=d&255;a[9706073]=g;d=c[i+76+((h>>>8|256)<<2)>>2]|0;if((d|0)!=0){a[d+(h&255)|0]=g;return}d=c[i+4184>>2]|0;if((d|0)==0){return}gg[d&4095](h&65535,g);return}function gj9(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=(g&255)>>>1;a[9706068]=a[9706144+d|0]|g&1;g=d&255;a[9706072]=g;d=c[i+76+((h>>>8|256)<<2)>>2]|0;if((d|0)!=0){a[d+(h&255)|0]=g;return}d=c[i+4184>>2]|0;if((d|0)==0){return}gg[d&4095](h&65535,g);return}function gka(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=(g&255)>>>1;a[9706068]=a[9706144+d|0]|g&1;g=d&255;a[9706077]=g;d=c[i+76+((h>>>8|256)<<2)>>2]|0;if((d|0)!=0){a[d+(h&255)|0]=g;return}d=c[i+4184>>2]|0;if((d|0)==0){return}gg[d&4095](h&65535,g);return}function gkb(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=(g&255)>>>1;a[9706068]=a[9706144+d|0]|g&1;g=d&255;a[9706076]=g;d=c[i+76+((h>>>8|256)<<2)>>2]|0;if((d|0)!=0){a[d+(h&255)|0]=g;return}d=c[i+4184>>2]|0;if((d|0)==0){return}gg[d&4095](h&65535,g);return}function gkc(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=(g&255)>>>1;a[9706068]=a[9706144+d|0]|g&1;g=d&255;a[9706081]=g;d=c[i+76+((h>>>8|256)<<2)>>2]|0;if((d|0)!=0){a[d+(h&255)|0]=g;return}d=c[i+4184>>2]|0;if((d|0)==0){return}gg[d&4095](h&65535,g);return}function gkd(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=(g&255)>>>1;a[9706068]=a[9706144+d|0]|g&1;g=d&255;a[9706080]=g;d=c[i+76+((h>>>8|256)<<2)>>2]|0;if((d|0)!=0){a[d+(h&255)|0]=g;return}d=c[i+4184>>2]|0;if((d|0)==0){return}gg[d&4095](h&65535,g);return}function gke(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=b>>>8;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](b&65535)|0;h=j;i=c[9757320+(c[1836236]<<2)>>2]|0}else{h=a[f+(b&255)|0]|0;i=e}}while(0);e=(h&255)>>>1;a[9706068]=a[9706144+e|0]|h&1;h=e&255;e=c[i+76+((d|256)<<2)>>2]|0;if((e|0)!=0){a[e+(b&255)|0]=h;return}e=c[i+4184>>2]|0;if((e|0)==0){return}gg[e&4095](b&65535,h);return}function gkf(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=(g&255)>>>1;a[9706068]=a[9706144+d|0]|g&1;g=d&255;a[9706069]=g;d=c[i+76+((h>>>8|256)<<2)>>2]|0;if((d|0)!=0){a[d+(h&255)|0]=g;return}d=c[i+4184>>2]|0;if((d|0)==0){return}gg[d&4095](h&65535,g);return}function gkg(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a[9706068]&1;d=c[3541536]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=d;break}j=gj[g&4095](d&65535)|0;h=j;i=c[3541536]|0}else{h=a[f+(d&255)|0]|0;i=d}}while(0);a[9706068]=(b|a[9644928+(h&1)|0]&199|i>>>8&40|16)&255;return}function gkh(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a[9706068]&1;d=c[3541536]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=d;break}j=gj[g&4095](d&65535)|0;h=j;i=c[3541536]|0}else{h=a[f+(d&255)|0]|0;i=d}}while(0);a[9706068]=(b|a[9644928+(h&1)|0]&199|i>>>8&40|16)&255;return}function gki(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a[9706068]&1;d=c[3541536]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=d;break}j=gj[g&4095](d&65535)|0;h=j;i=c[3541536]|0}else{h=a[f+(d&255)|0]|0;i=d}}while(0);a[9706068]=(b|a[9644928+(h&1)|0]&199|i>>>8&40|16)&255;return}function gkj(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a[9706068]&1;d=c[3541536]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=d;break}j=gj[g&4095](d&65535)|0;h=j;i=c[3541536]|0}else{h=a[f+(d&255)|0]|0;i=d}}while(0);a[9706068]=(b|a[9644928+(h&1)|0]&199|i>>>8&40|16)&255;return}function gkk(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a[9706068]&1;d=c[3541536]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=d;break}j=gj[g&4095](d&65535)|0;h=j;i=c[3541536]|0}else{h=a[f+(d&255)|0]|0;i=d}}while(0);a[9706068]=(b|a[9644928+(h&1)|0]&199|i>>>8&40|16)&255;return}function gkl(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a[9706068]&1;d=c[3541536]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=d;break}j=gj[g&4095](d&65535)|0;h=j;i=c[3541536]|0}else{h=a[f+(d&255)|0]|0;i=d}}while(0);a[9706068]=(b|a[9644928+(h&1)|0]&199|i>>>8&40|16)&255;return}function gkm(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a[9706068]&1;d=c[3541536]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=d;break}j=gj[g&4095](d&65535)|0;h=j;i=c[3541536]|0}else{h=a[f+(d&255)|0]|0;i=d}}while(0);a[9706068]=(b|a[9644928+(h&1)|0]&199|i>>>8&40|16)&255;return}function gkn(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a[9706068]&1;d=c[3541536]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=d;break}j=gj[g&4095](d&65535)|0;h=j;i=c[3541536]|0}else{h=a[f+(d&255)|0]|0;i=d}}while(0);a[9706068]=(b|a[9644928+(h&1)|0]&199|i>>>8&40|16)&255;return}function gko(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a[9706068]&1;d=c[3541536]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=d;break}j=gj[g&4095](d&65535)|0;h=j;i=c[3541536]|0}else{h=a[f+(d&255)|0]|0;i=d}}while(0);a[9706068]=(b|a[9644928+(h&2)|0]&199|i>>>8&40|16)&255;return}function gkp(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a[9706068]&1;d=c[3541536]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=d;break}j=gj[g&4095](d&65535)|0;h=j;i=c[3541536]|0}else{h=a[f+(d&255)|0]|0;i=d}}while(0);a[9706068]=(b|a[9644928+(h&2)|0]&199|i>>>8&40|16)&255;return}function gkq(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a[9706068]&1;d=c[3541536]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=d;break}j=gj[g&4095](d&65535)|0;h=j;i=c[3541536]|0}else{h=a[f+(d&255)|0]|0;i=d}}while(0);a[9706068]=(b|a[9644928+(h&2)|0]&199|i>>>8&40|16)&255;return}function gkr(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a[9706068]&1;d=c[3541536]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=d;break}j=gj[g&4095](d&65535)|0;h=j;i=c[3541536]|0}else{h=a[f+(d&255)|0]|0;i=d}}while(0);a[9706068]=(b|a[9644928+(h&2)|0]&199|i>>>8&40|16)&255;return}function gks(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a[9706068]&1;d=c[3541536]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=d;break}j=gj[g&4095](d&65535)|0;h=j;i=c[3541536]|0}else{h=a[f+(d&255)|0]|0;i=d}}while(0);a[9706068]=(b|a[9644928+(h&2)|0]&199|i>>>8&40|16)&255;return}function gkt(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a[9706068]&1;d=c[3541536]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=d;break}j=gj[g&4095](d&65535)|0;h=j;i=c[3541536]|0}else{h=a[f+(d&255)|0]|0;i=d}}while(0);a[9706068]=(b|a[9644928+(h&2)|0]&199|i>>>8&40|16)&255;return}function gku(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a[9706068]&1;d=c[3541536]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=d;break}j=gj[g&4095](d&65535)|0;h=j;i=c[3541536]|0}else{h=a[f+(d&255)|0]|0;i=d}}while(0);a[9706068]=(b|a[9644928+(h&2)|0]&199|i>>>8&40|16)&255;return}function gkv(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a[9706068]&1;d=c[3541536]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=d;break}j=gj[g&4095](d&65535)|0;h=j;i=c[3541536]|0}else{h=a[f+(d&255)|0]|0;i=d}}while(0);a[9706068]=(b|a[9644928+(h&2)|0]&199|i>>>8&40|16)&255;return}function gkw(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a[9706068]&1;d=c[3541536]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=d;break}j=gj[g&4095](d&65535)|0;h=j;i=c[3541536]|0}else{h=a[f+(d&255)|0]|0;i=d}}while(0);a[9706068]=(b|a[9644928+(h&4)|0]&199|i>>>8&40|16)&255;return}function gkx(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a[9706068]&1;d=c[3541536]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=d;break}j=gj[g&4095](d&65535)|0;h=j;i=c[3541536]|0}else{h=a[f+(d&255)|0]|0;i=d}}while(0);a[9706068]=(b|a[9644928+(h&4)|0]&199|i>>>8&40|16)&255;return}function gky(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a[9706068]&1;d=c[3541536]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=d;break}j=gj[g&4095](d&65535)|0;h=j;i=c[3541536]|0}else{h=a[f+(d&255)|0]|0;i=d}}while(0);a[9706068]=(b|a[9644928+(h&4)|0]&199|i>>>8&40|16)&255;return}function gkz(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a[9706068]&1;d=c[3541536]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=d;break}j=gj[g&4095](d&65535)|0;h=j;i=c[3541536]|0}else{h=a[f+(d&255)|0]|0;i=d}}while(0);a[9706068]=(b|a[9644928+(h&4)|0]&199|i>>>8&40|16)&255;return}function gkA(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a[9706068]&1;d=c[3541536]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=d;break}j=gj[g&4095](d&65535)|0;h=j;i=c[3541536]|0}else{h=a[f+(d&255)|0]|0;i=d}}while(0);a[9706068]=(b|a[9644928+(h&4)|0]&199|i>>>8&40|16)&255;return}function gkB(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a[9706068]&1;d=c[3541536]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=d;break}j=gj[g&4095](d&65535)|0;h=j;i=c[3541536]|0}else{h=a[f+(d&255)|0]|0;i=d}}while(0);a[9706068]=(b|a[9644928+(h&4)|0]&199|i>>>8&40|16)&255;return}function gkC(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a[9706068]&1;d=c[3541536]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=d;break}j=gj[g&4095](d&65535)|0;h=j;i=c[3541536]|0}else{h=a[f+(d&255)|0]|0;i=d}}while(0);a[9706068]=(b|a[9644928+(h&4)|0]&199|i>>>8&40|16)&255;return}function gkD(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a[9706068]&1;d=c[3541536]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=d;break}j=gj[g&4095](d&65535)|0;h=j;i=c[3541536]|0}else{h=a[f+(d&255)|0]|0;i=d}}while(0);a[9706068]=(b|a[9644928+(h&4)|0]&199|i>>>8&40|16)&255;return}function gkE(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a[9706068]&1;d=c[3541536]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=d;break}j=gj[g&4095](d&65535)|0;h=j;i=c[3541536]|0}else{h=a[f+(d&255)|0]|0;i=d}}while(0);a[9706068]=(b|a[9644928+(h&8)|0]&199|i>>>8&40|16)&255;return}function gkF(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a[9706068]&1;d=c[3541536]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=d;break}j=gj[g&4095](d&65535)|0;h=j;i=c[3541536]|0}else{h=a[f+(d&255)|0]|0;i=d}}while(0);a[9706068]=(b|a[9644928+(h&8)|0]&199|i>>>8&40|16)&255;return}function gkG(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a[9706068]&1;d=c[3541536]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=d;break}j=gj[g&4095](d&65535)|0;h=j;i=c[3541536]|0}else{h=a[f+(d&255)|0]|0;i=d}}while(0);a[9706068]=(b|a[9644928+(h&8)|0]&199|i>>>8&40|16)&255;return}function gkH(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a[9706068]&1;d=c[3541536]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=d;break}j=gj[g&4095](d&65535)|0;h=j;i=c[3541536]|0}else{h=a[f+(d&255)|0]|0;i=d}}while(0);a[9706068]=(b|a[9644928+(h&8)|0]&199|i>>>8&40|16)&255;return}function gkI(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a[9706068]&1;d=c[3541536]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=d;break}j=gj[g&4095](d&65535)|0;h=j;i=c[3541536]|0}else{h=a[f+(d&255)|0]|0;i=d}}while(0);a[9706068]=(b|a[9644928+(h&8)|0]&199|i>>>8&40|16)&255;return}function gkJ(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a[9706068]&1;d=c[3541536]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=d;break}j=gj[g&4095](d&65535)|0;h=j;i=c[3541536]|0}else{h=a[f+(d&255)|0]|0;i=d}}while(0);a[9706068]=(b|a[9644928+(h&8)|0]&199|i>>>8&40|16)&255;return}function gkK(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a[9706068]&1;d=c[3541536]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=d;break}j=gj[g&4095](d&65535)|0;h=j;i=c[3541536]|0}else{h=a[f+(d&255)|0]|0;i=d}}while(0);a[9706068]=(b|a[9644928+(h&8)|0]&199|i>>>8&40|16)&255;return}function gkL(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a[9706068]&1;d=c[3541536]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=d;break}j=gj[g&4095](d&65535)|0;h=j;i=c[3541536]|0}else{h=a[f+(d&255)|0]|0;i=d}}while(0);a[9706068]=(b|a[9644928+(h&8)|0]&199|i>>>8&40|16)&255;return}function gkM(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a[9706068]&1;d=c[3541536]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=d;break}j=gj[g&4095](d&65535)|0;h=j;i=c[3541536]|0}else{h=a[f+(d&255)|0]|0;i=d}}while(0);a[9706068]=(b|a[9644928+(h&16)|0]&199|i>>>8&40|16)&255;return}function gkN(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a[9706068]&1;d=c[3541536]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=d;break}j=gj[g&4095](d&65535)|0;h=j;i=c[3541536]|0}else{h=a[f+(d&255)|0]|0;i=d}}while(0);a[9706068]=(b|a[9644928+(h&16)|0]&199|i>>>8&40|16)&255;return}function gkO(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a[9706068]&1;d=c[3541536]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=d;break}j=gj[g&4095](d&65535)|0;h=j;i=c[3541536]|0}else{h=a[f+(d&255)|0]|0;i=d}}while(0);a[9706068]=(b|a[9644928+(h&16)|0]&199|i>>>8&40|16)&255;return}function gkP(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a[9706068]&1;d=c[3541536]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=d;break}j=gj[g&4095](d&65535)|0;h=j;i=c[3541536]|0}else{h=a[f+(d&255)|0]|0;i=d}}while(0);a[9706068]=(b|a[9644928+(h&16)|0]&199|i>>>8&40|16)&255;return}function gkQ(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a[9706068]&1;d=c[3541536]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=d;break}j=gj[g&4095](d&65535)|0;h=j;i=c[3541536]|0}else{h=a[f+(d&255)|0]|0;i=d}}while(0);a[9706068]=(b|a[9644928+(h&16)|0]&199|i>>>8&40|16)&255;return}function gkR(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a[9706068]&1;d=c[3541536]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=d;break}j=gj[g&4095](d&65535)|0;h=j;i=c[3541536]|0}else{h=a[f+(d&255)|0]|0;i=d}}while(0);a[9706068]=(b|a[9644928+(h&16)|0]&199|i>>>8&40|16)&255;return}function gkS(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a[9706068]&1;d=c[3541536]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=d;break}j=gj[g&4095](d&65535)|0;h=j;i=c[3541536]|0}else{h=a[f+(d&255)|0]|0;i=d}}while(0);a[9706068]=(b|a[9644928+(h&16)|0]&199|i>>>8&40|16)&255;return}function gkT(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a[9706068]&1;d=c[3541536]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=d;break}j=gj[g&4095](d&65535)|0;h=j;i=c[3541536]|0}else{h=a[f+(d&255)|0]|0;i=d}}while(0);a[9706068]=(b|a[9644928+(h&16)|0]&199|i>>>8&40|16)&255;return}function gkU(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a[9706068]&1;d=c[3541536]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=d;break}j=gj[g&4095](d&65535)|0;h=j;i=c[3541536]|0}else{h=a[f+(d&255)|0]|0;i=d}}while(0);a[9706068]=(b|a[9644928+(h&32)|0]&199|i>>>8&40|16)&255;return}function gkV(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a[9706068]&1;d=c[3541536]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=d;break}j=gj[g&4095](d&65535)|0;h=j;i=c[3541536]|0}else{h=a[f+(d&255)|0]|0;i=d}}while(0);a[9706068]=(b|a[9644928+(h&32)|0]&199|i>>>8&40|16)&255;return}function gkW(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a[9706068]&1;d=c[3541536]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=d;break}j=gj[g&4095](d&65535)|0;h=j;i=c[3541536]|0}else{h=a[f+(d&255)|0]|0;i=d}}while(0);a[9706068]=(b|a[9644928+(h&32)|0]&199|i>>>8&40|16)&255;return}function gkX(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a[9706068]&1;d=c[3541536]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=d;break}j=gj[g&4095](d&65535)|0;h=j;i=c[3541536]|0}else{h=a[f+(d&255)|0]|0;i=d}}while(0);a[9706068]=(b|a[9644928+(h&32)|0]&199|i>>>8&40|16)&255;return}function gkY(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a[9706068]&1;d=c[3541536]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=d;break}j=gj[g&4095](d&65535)|0;h=j;i=c[3541536]|0}else{h=a[f+(d&255)|0]|0;i=d}}while(0);a[9706068]=(b|a[9644928+(h&32)|0]&199|i>>>8&40|16)&255;return}function gkZ(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a[9706068]&1;d=c[3541536]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=d;break}j=gj[g&4095](d&65535)|0;h=j;i=c[3541536]|0}else{h=a[f+(d&255)|0]|0;i=d}}while(0);a[9706068]=(b|a[9644928+(h&32)|0]&199|i>>>8&40|16)&255;return}function gk_(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a[9706068]&1;d=c[3541536]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=d;break}j=gj[g&4095](d&65535)|0;h=j;i=c[3541536]|0}else{h=a[f+(d&255)|0]|0;i=d}}while(0);a[9706068]=(b|a[9644928+(h&32)|0]&199|i>>>8&40|16)&255;return}function gk$(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a[9706068]&1;d=c[3541536]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=d;break}j=gj[g&4095](d&65535)|0;h=j;i=c[3541536]|0}else{h=a[f+(d&255)|0]|0;i=d}}while(0);a[9706068]=(b|a[9644928+(h&32)|0]&199|i>>>8&40|16)&255;return}function gk0(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a[9706068]&1;d=c[3541536]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=d;break}j=gj[g&4095](d&65535)|0;h=j;i=c[3541536]|0}else{h=a[f+(d&255)|0]|0;i=d}}while(0);a[9706068]=(b|a[9644928+(h&16)|0]&199|i>>>8&40|16)&255;return}function gk1(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a[9706068]&1;d=c[3541536]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=d;break}j=gj[g&4095](d&65535)|0;h=j;i=c[3541536]|0}else{h=a[f+(d&255)|0]|0;i=d}}while(0);a[9706068]=(b|a[9644928+(h&16)|0]&199|i>>>8&40|16)&255;return}function gk2(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a[9706068]&1;d=c[3541536]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=d;break}j=gj[g&4095](d&65535)|0;h=j;i=c[3541536]|0}else{h=a[f+(d&255)|0]|0;i=d}}while(0);a[9706068]=(b|a[9644928+(h&16)|0]&199|i>>>8&40|16)&255;return}function gk3(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a[9706068]&1;d=c[3541536]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=d;break}j=gj[g&4095](d&65535)|0;h=j;i=c[3541536]|0}else{h=a[f+(d&255)|0]|0;i=d}}while(0);a[9706068]=(b|a[9644928+(h&16)|0]&199|i>>>8&40|16)&255;return}function gk4(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a[9706068]&1;d=c[3541536]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=d;break}j=gj[g&4095](d&65535)|0;h=j;i=c[3541536]|0}else{h=a[f+(d&255)|0]|0;i=d}}while(0);a[9706068]=(b|a[9644928+(h&16)|0]&199|i>>>8&40|16)&255;return}function gk5(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a[9706068]&1;d=c[3541536]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=d;break}j=gj[g&4095](d&65535)|0;h=j;i=c[3541536]|0}else{h=a[f+(d&255)|0]|0;i=d}}while(0);a[9706068]=(b|a[9644928+(h&16)|0]&199|i>>>8&40|16)&255;return}function gk6(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a[9706068]&1;d=c[3541536]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=d;break}j=gj[g&4095](d&65535)|0;h=j;i=c[3541536]|0}else{h=a[f+(d&255)|0]|0;i=d}}while(0);a[9706068]=(b|a[9644928+(h&64)|0]&199|i>>>8&40|16)&255;return}function gk7(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a[9706068]&1;d=c[3541536]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=d;break}j=gj[g&4095](d&65535)|0;h=j;i=c[3541536]|0}else{h=a[f+(d&255)|0]|0;i=d}}while(0);a[9706068]=(b|a[9644928+(h&16)|0]&199|i>>>8&40|16)&255;return}function gk8(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a[9706068]&1;d=c[3541536]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=d;break}j=gj[g&4095](d&65535)|0;h=j;i=c[3541536]|0}else{h=a[f+(d&255)|0]|0;i=d}}while(0);a[9706068]=(b|a[9644928+(h&128)|0]&199|i>>>8&40|16)&255;return}function gk9(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a[9706068]&1;d=c[3541536]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=d;break}j=gj[g&4095](d&65535)|0;h=j;i=c[3541536]|0}else{h=a[f+(d&255)|0]|0;i=d}}while(0);a[9706068]=(b|a[9644928+(h&128)|0]&199|i>>>8&40|16)&255;return}function gla(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a[9706068]&1;d=c[3541536]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=d;break}j=gj[g&4095](d&65535)|0;h=j;i=c[3541536]|0}else{h=a[f+(d&255)|0]|0;i=d}}while(0);a[9706068]=(b|a[9644928+(h&128)|0]&199|i>>>8&40|16)&255;return}function glb(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a[9706068]&1;d=c[3541536]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=d;break}j=gj[g&4095](d&65535)|0;h=j;i=c[3541536]|0}else{h=a[f+(d&255)|0]|0;i=d}}while(0);a[9706068]=(b|a[9644928+(h&128)|0]&199|i>>>8&40|16)&255;return}function glc(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a[9706068]&1;d=c[3541536]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=d;break}j=gj[g&4095](d&65535)|0;h=j;i=c[3541536]|0}else{h=a[f+(d&255)|0]|0;i=d}}while(0);a[9706068]=(b|a[9644928+(h&128)|0]&199|i>>>8&40|16)&255;return}function gld(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a[9706068]&1;d=c[3541536]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=d;break}j=gj[g&4095](d&65535)|0;h=j;i=c[3541536]|0}else{h=a[f+(d&255)|0]|0;i=d}}while(0);a[9706068]=(b|a[9644928+(h&128)|0]&199|i>>>8&40|16)&255;return}function gle(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a[9706068]&1;d=c[3541536]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=d;break}j=gj[g&4095](d&65535)|0;h=j;i=c[3541536]|0}else{h=a[f+(d&255)|0]|0;i=d}}while(0);a[9706068]=(b|a[9644928+(h&128)|0]&199|i>>>8&40|16)&255;return}function glf(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a[9706068]&1;d=c[3541536]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=d;break}j=gj[g&4095](d&65535)|0;h=j;i=c[3541536]|0}else{h=a[f+(d&255)|0]|0;i=d}}while(0);a[9706068]=(b|a[9644928+(h&128)|0]&199|i>>>8&40|16)&255;return}function glg(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g&-2;a[9706073]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function glh(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g&-2;a[9706072]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function gli(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g&-2;a[9706077]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function glj(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g&-2;a[9706076]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function glk(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g&-2;a[9706081]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function gll(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g&-2;a[9706080]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function glm(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=b>>>8;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](b&65535)|0;h=j;i=c[9757320+(c[1836236]<<2)>>2]|0}else{h=a[f+(b&255)|0]|0;i=e}}while(0);e=h&-2;h=c[i+76+((d|256)<<2)>>2]|0;if((h|0)!=0){a[h+(b&255)|0]=e;return}h=c[i+4184>>2]|0;if((h|0)==0){return}gg[h&4095](b&65535,e);return}function gln(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g&-2;a[9706069]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function glo(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g&-3;a[9706073]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function glp(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g&-3;a[9706072]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function glq(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g&-3;a[9706077]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function glr(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g&-3;a[9706076]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function gls(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g&-3;a[9706081]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function glt(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g&-3;a[9706080]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function glu(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=b>>>8;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](b&65535)|0;h=j;i=c[9757320+(c[1836236]<<2)>>2]|0}else{h=a[f+(b&255)|0]|0;i=e}}while(0);e=h&-3;h=c[i+76+((d|256)<<2)>>2]|0;if((h|0)!=0){a[h+(b&255)|0]=e;return}h=c[i+4184>>2]|0;if((h|0)==0){return}gg[h&4095](b&65535,e);return}function glv(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g&-3;a[9706069]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function glw(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g&-5;a[9706073]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function glx(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g&-5;a[9706072]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function gly(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g&-5;a[9706077]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function glz(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g&-5;a[9706076]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function glA(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g&-5;a[9706081]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function glB(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g&-5;a[9706080]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function glC(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=b>>>8;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](b&65535)|0;h=j;i=c[9757320+(c[1836236]<<2)>>2]|0}else{h=a[f+(b&255)|0]|0;i=e}}while(0);e=h&-5;h=c[i+76+((d|256)<<2)>>2]|0;if((h|0)!=0){a[h+(b&255)|0]=e;return}h=c[i+4184>>2]|0;if((h|0)==0){return}gg[h&4095](b&65535,e);return}function glD(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g&-5;a[9706069]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function glE(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g&-9;a[9706073]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function glF(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g&-9;a[9706072]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function glG(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g&-9;a[9706077]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function glH(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g&-9;a[9706076]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function glI(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g&-9;a[9706081]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function glJ(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g&-9;a[9706080]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function glK(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=b>>>8;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](b&65535)|0;h=j;i=c[9757320+(c[1836236]<<2)>>2]|0}else{h=a[f+(b&255)|0]|0;i=e}}while(0);e=h&-9;h=c[i+76+((d|256)<<2)>>2]|0;if((h|0)!=0){a[h+(b&255)|0]=e;return}h=c[i+4184>>2]|0;if((h|0)==0){return}gg[h&4095](b&65535,e);return}function glL(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g&-9;a[9706069]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function glM(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g&-17;a[9706073]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function glN(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g&-17;a[9706072]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function glO(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g&-17;a[9706077]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function glP(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g&-17;a[9706076]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function glQ(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g&-17;a[9706081]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function glR(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g&-17;a[9706080]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function glS(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=b>>>8;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](b&65535)|0;h=j;i=c[9757320+(c[1836236]<<2)>>2]|0}else{h=a[f+(b&255)|0]|0;i=e}}while(0);e=h&-17;h=c[i+76+((d|256)<<2)>>2]|0;if((h|0)!=0){a[h+(b&255)|0]=e;return}h=c[i+4184>>2]|0;if((h|0)==0){return}gg[h&4095](b&65535,e);return}function glT(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g&-17;a[9706069]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function glU(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g&-33;a[9706073]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function glV(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g&-33;a[9706072]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function glW(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g&-33;a[9706077]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function glX(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g&-33;a[9706076]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function glY(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g&-33;a[9706081]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function glZ(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g&-33;a[9706080]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function gl_(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=b>>>8;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](b&65535)|0;h=j;i=c[9757320+(c[1836236]<<2)>>2]|0}else{h=a[f+(b&255)|0]|0;i=e}}while(0);e=h&-33;h=c[i+76+((d|256)<<2)>>2]|0;if((h|0)!=0){a[h+(b&255)|0]=e;return}h=c[i+4184>>2]|0;if((h|0)==0){return}gg[h&4095](b&65535,e);return}function gl$(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g&-33;a[9706069]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function gl0(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g&-65;a[9706073]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function gl1(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g&-65;a[9706072]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function gl2(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g&-65;a[9706077]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function gl3(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g&-65;a[9706076]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function gl4(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g&-65;a[9706081]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function gl5(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g&-65;a[9706080]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function gl6(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=b>>>8;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](b&65535)|0;h=j;i=c[9757320+(c[1836236]<<2)>>2]|0}else{h=a[f+(b&255)|0]|0;i=e}}while(0);e=h&-65;h=c[i+76+((d|256)<<2)>>2]|0;if((h|0)!=0){a[h+(b&255)|0]=e;return}h=c[i+4184>>2]|0;if((h|0)==0){return}gg[h&4095](b&65535,e);return}function gl7(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g&-65;a[9706069]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function gl8(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g&127;a[9706073]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function gl9(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g&127;a[9706072]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function gma(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g&127;a[9706077]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function gmb(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g&127;a[9706076]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function gmc(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g&127;a[9706081]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function gmd(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g&127;a[9706080]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function gme(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=b>>>8;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](b&65535)|0;h=j;i=c[9757320+(c[1836236]<<2)>>2]|0}else{h=a[f+(b&255)|0]|0;i=e}}while(0);e=h&127;h=c[i+76+((d|256)<<2)>>2]|0;if((h|0)!=0){a[h+(b&255)|0]=e;return}h=c[i+4184>>2]|0;if((h|0)==0){return}gg[h&4095](b&65535,e);return}function gmf(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g&127;a[9706069]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function gmg(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g|1;a[9706073]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function gmh(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g|1;a[9706072]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function gmi(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g|1;a[9706077]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function gmj(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g|1;a[9706076]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function gmk(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g|1;a[9706081]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function gml(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g|1;a[9706080]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function gmm(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=b>>>8;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](b&65535)|0;h=j;i=c[9757320+(c[1836236]<<2)>>2]|0}else{h=a[f+(b&255)|0]|0;i=e}}while(0);e=h|1;h=c[i+76+((d|256)<<2)>>2]|0;if((h|0)!=0){a[h+(b&255)|0]=e;return}h=c[i+4184>>2]|0;if((h|0)==0){return}gg[h&4095](b&65535,e);return}function gmn(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g|1;a[9706069]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function gmo(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g|2;a[9706073]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function gmp(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g|2;a[9706072]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function gmq(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g|2;a[9706077]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function gmr(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g|2;a[9706076]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function gms(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g|2;a[9706081]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function gmt(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g|2;a[9706080]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function gmu(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=b>>>8;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](b&65535)|0;h=j;i=c[9757320+(c[1836236]<<2)>>2]|0}else{h=a[f+(b&255)|0]|0;i=e}}while(0);e=h|2;h=c[i+76+((d|256)<<2)>>2]|0;if((h|0)!=0){a[h+(b&255)|0]=e;return}h=c[i+4184>>2]|0;if((h|0)==0){return}gg[h&4095](b&65535,e);return}function gmv(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g|2;a[9706069]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function gmw(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g|4;a[9706073]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function gmx(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g|4;a[9706072]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function gmy(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g|4;a[9706077]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function gmz(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g|4;a[9706076]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function gmA(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g|4;a[9706081]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function gmB(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g|4;a[9706080]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function gmC(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=b>>>8;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](b&65535)|0;h=j;i=c[9757320+(c[1836236]<<2)>>2]|0}else{h=a[f+(b&255)|0]|0;i=e}}while(0);e=h|4;h=c[i+76+((d|256)<<2)>>2]|0;if((h|0)!=0){a[h+(b&255)|0]=e;return}h=c[i+4184>>2]|0;if((h|0)==0){return}gg[h&4095](b&65535,e);return}function gmD(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g|4;a[9706069]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function gmE(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g|8;a[9706073]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function gmF(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g|8;a[9706072]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function gmG(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g|8;a[9706077]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function gmH(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g|8;a[9706076]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function gmI(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g|8;a[9706081]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function gmJ(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g|8;a[9706080]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function gmK(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=b>>>8;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](b&65535)|0;h=j;i=c[9757320+(c[1836236]<<2)>>2]|0}else{h=a[f+(b&255)|0]|0;i=e}}while(0);e=h|8;h=c[i+76+((d|256)<<2)>>2]|0;if((h|0)!=0){a[h+(b&255)|0]=e;return}h=c[i+4184>>2]|0;if((h|0)==0){return}gg[h&4095](b&65535,e);return}function gmL(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g|8;a[9706069]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function gmM(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g|16;a[9706073]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function gmN(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g|16;a[9706072]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function gmO(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g|16;a[9706077]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function gmP(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g|16;a[9706076]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function gmQ(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g|16;a[9706081]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function gmR(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g|16;a[9706080]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function gmS(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=b>>>8;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](b&65535)|0;h=j;i=c[9757320+(c[1836236]<<2)>>2]|0}else{h=a[f+(b&255)|0]|0;i=e}}while(0);e=h|16;h=c[i+76+((d|256)<<2)>>2]|0;if((h|0)!=0){a[h+(b&255)|0]=e;return}h=c[i+4184>>2]|0;if((h|0)==0){return}gg[h&4095](b&65535,e);return}function gmT(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g|16;a[9706069]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function gmU(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g|32;a[9706073]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function gmV(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g|32;a[9706072]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function gmW(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g|32;a[9706077]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function gmX(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g|32;a[9706076]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function gmY(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g|32;a[9706081]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function gmZ(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g|32;a[9706080]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function gm_(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=b>>>8;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](b&65535)|0;h=j;i=c[9757320+(c[1836236]<<2)>>2]|0}else{h=a[f+(b&255)|0]|0;i=e}}while(0);e=h|32;h=c[i+76+((d|256)<<2)>>2]|0;if((h|0)!=0){a[h+(b&255)|0]=e;return}h=c[i+4184>>2]|0;if((h|0)==0){return}gg[h&4095](b&65535,e);return}function gm$(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g|32;a[9706069]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function gm0(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g|64;a[9706073]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function gm1(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g|64;a[9706072]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function gm2(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g|64;a[9706077]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function gm3(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g|64;a[9706076]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function gm4(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g|64;a[9706081]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function gm5(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g|64;a[9706080]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function gm6(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=b>>>8;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](b&65535)|0;h=j;i=c[9757320+(c[1836236]<<2)>>2]|0}else{h=a[f+(b&255)|0]|0;i=e}}while(0);e=h|64;h=c[i+76+((d|256)<<2)>>2]|0;if((h|0)!=0){a[h+(b&255)|0]=e;return}h=c[i+4184>>2]|0;if((h|0)==0){return}gg[h&4095](b&65535,e);return}function gm7(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g|64;a[9706069]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function gm8(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g|-128;a[9706073]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function gm9(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g|-128;a[9706072]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function gna(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g|-128;a[9706077]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function gnb(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g|-128;a[9706076]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function gnc(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g|-128;a[9706081]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function gnd(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g|-128;a[9706080]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function gne(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=b>>>8;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](b&65535)|0;h=j;i=c[9757320+(c[1836236]<<2)>>2]|0}else{h=a[f+(b&255)|0]|0;i=e}}while(0);e=h|-128;h=c[i+76+((d|256)<<2)>>2]|0;if((h|0)!=0){a[h+(b&255)|0]=e;return}h=c[i+4184>>2]|0;if((h|0)==0){return}gg[h&4095](b&65535,e);return}function gnf(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3541536]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=b;i=d;break}j=gj[f&4095](b&65535)|0;g=j;h=c[3541536]|0;i=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=b;i=d}}while(0);d=g|-128;a[9706069]=d;g=c[i+76+((h>>>8|256)<<2)>>2]|0;if((g|0)!=0){a[g+(h&255)|0]=d;return}g=c[i+4184>>2]|0;if((g|0)==0){return}gg[g&4095](h&65535,d);return}function gng(){return}function gnh(){return}function gni(){return}function gnj(){return}function gnk(){return}function gnl(){return}function gnm(){return}function gnn(){return}function gno(){return}function gnp(){return}function gnq(){return}function gnr(){return}function gns(){return}function gnt(){return}function gnu(){return}function gnv(){return}function gnw(){return}function gnx(){return}function gny(){return}function gnz(){return}function gnA(){return}function gnB(){return}function gnC(){return}function gnD(){return}function gnE(){return}function gnF(){return}function gnG(){return}function gnH(){return}function gnI(){return}function gnJ(){return}function gnK(){return}function gnL(){return}function gnM(){return}function gnN(){return}function gnO(){return}function gnP(){return}function gnQ(){return}function gnR(){return}function gnS(){return}function gnT(){return}function gnU(){return}function gnV(){return}function gnW(){return}function gnX(){return}function gnY(){return}function gnZ(){return}function gn_(){return}function gn$(){return}function gn0(){return}function gn1(){return}function gn2(){return}function gn3(){return}function gn4(){return}function gn5(){return}function gn6(){return}function gn7(){return}function gn8(){return}function gn9(){return}function goa(){return}function gob(){return}function goc(){return}function god(){return}function goe(){return}function gof(){return}function gog(){var d=0;d=gj[c[(c[9757320+(c[1836236]<<2)>>2]|0)+4172>>2]&4095](b[4853036]|0)|0;a[9706073]=d;a[9706068]=a[9706068]&1|a[9706144+(d&255)|0];return}function goh(){gg[c[(c[9757320+(c[1836236]<<2)>>2]|0)+4176>>2]&4095](b[4853036]|0,a[9706073]|0);return}function goi(){var d=0,e=0,f=0,g=0;d=c[2426520]|0;e=c[2426518]|0;f=d-e-(a[9706068]&1)|0;g=f^d;a[9706068]=(f>>>8&168|f>>>16&1|((f&65535|0)!=0?0:64)|(g^e)>>>8&16|(g&(e^d))>>>13&4|2)&255;b[4853040]=f&65535;return}function goj(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=c[2426515]|0;e=d&65535;b[4853030]=e+2&65535;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+((d>>>8|768)<<2)>>2]|0;do{if((g|0)==0){h=c[f+4180>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](e)|0;i=k;j=c[9757320+(c[1836236]<<2)>>2]|0}else{i=a[g+(d&255)|0]|0;j=f}}while(0);f=i&255;i=d+1|0;d=c[j+76+((i>>>8&255|768)<<2)>>2]|0;do{if((d|0)==0){g=c[j+4180>>2]|0;if((g|0)==0){l=0;m=j;break}e=gj[g&4095](i&65535)|0;l=e;m=c[9757320+(c[1836236]<<2)>>2]|0}else{l=a[d+(i&255)|0]|0;m=j}}while(0);j=l&255;l=j<<8|f;c[3541536]=l;i=a[9706072]|0;d=c[m+76+((j|256)<<2)>>2]|0;do{if((d|0)==0){j=c[m+4184>>2]|0;if((j|0)==0){n=m;break}gg[j&4095](l&65535,i);n=c[9757320+(c[1836236]<<2)>>2]|0}else{a[d+f|0]=i;n=m}}while(0);m=l+1|0;l=a[9706073]|0;i=c[n+76+((m>>>8&255|256)<<2)>>2]|0;if((i|0)!=0){a[i+(m&255)|0]=l;return}i=c[n+4184>>2]|0;if((i|0)==0){return}gg[i&4095](m&65535,l);return}function gok(){var b=0,d=0,e=0;b=a[9706069]|0;a[9706069]=0;d=c[2426517]&65280;e=(d>>>8)-(b&255)|0;a[9706068]=a[(c[2385738]|0)+(e&255|d)|0]|0;a[9706069]=e&255;return}function gol(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[2426516]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](d&65535)|0;h=j;i=c[9757320+(c[1836236]<<2)>>2]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9706060]=h;h=d+1|0;d=c[i+76+((h>>>8&255)<<2)>>2]|0;do{if((d|0)==0){e=c[i+4180>>2]|0;if((e|0)==0){k=0;break}k=gj[e&4095](h&65535)|0}else{k=a[d+(h&255)|0]|0}}while(0);a[9706061]=k;b[4853032]=(b[4853032]|0)+2&65535;b[4853030]=c[2426515]&65535;a[9706110]=a[9706111]|0;return}function gom(){a[9706113]=0;return}function gon(){a[9706114]=a[9706069]|0;return}function goo(){var d=0;d=gj[c[(c[9757320+(c[1836236]<<2)>>2]|0)+4172>>2]&4095](b[4853036]|0)|0;a[9706072]=d;a[9706068]=a[9706068]&1|a[9706144+(d&255)|0];return}function gop(){var a=0;a=b[4853036]|0;gg[c[(c[9757320+(c[1836236]<<2)>>2]|0)+4176>>2]&4095](a,a&255);return}function goq(){var d=0,e=0,f=0;d=c[2426520]|0;e=c[2426518]|0;f=e+d+(a[9706068]&1)|0;a[9706068]=(f>>>8&168|f>>>16&1|(e^d^f)>>>8&16|((f&65535|0)!=0?0:64)|((f^e)&(d^32768^e))>>>13&4)&255;b[4853040]=f&65535;return}function gor(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=c[2426515]|0;e=d&65535;b[4853030]=e+2&65535;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+((d>>>8|768)<<2)>>2]|0;do{if((g|0)==0){h=c[f+4180>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](e)|0;i=k;j=c[9757320+(c[1836236]<<2)>>2]|0}else{i=a[g+(d&255)|0]|0;j=f}}while(0);f=i&255;i=d+1|0;d=c[j+76+((i>>>8&255|768)<<2)>>2]|0;do{if((d|0)==0){g=c[j+4180>>2]|0;if((g|0)==0){l=0;m=j;break}e=gj[g&4095](i&65535)|0;l=e;m=c[9757320+(c[1836236]<<2)>>2]|0}else{l=a[d+(i&255)|0]|0;m=j}}while(0);j=l&255;l=j<<8|f;c[3541536]=l;i=c[m+76+(j<<2)>>2]|0;do{if((i|0)==0){j=c[m+4180>>2]|0;if((j|0)==0){n=0;o=m;break}d=gj[j&4095](l&65535)|0;n=d;o=c[9757320+(c[1836236]<<2)>>2]|0}else{n=a[i+f|0]|0;o=m}}while(0);a[9706072]=n;n=l+1|0;l=c[o+76+((n>>>8&255)<<2)>>2]|0;if((l|0)!=0){p=a[l+(n&255)|0]|0;a[9706073]=p;return}l=c[o+4180>>2]|0;if((l|0)==0){p=0;a[9706073]=p;return}p=gj[l&4095](n&65535)|0;a[9706073]=p;return}function gos(){var b=0,d=0,e=0;b=a[9706069]|0;a[9706069]=0;d=c[2426517]&65280;e=(d>>>8)-(b&255)|0;a[9706068]=a[(c[2385738]|0)+(e&255|d)|0]|0;a[9706069]=e&255;return}function got(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=c[2426516]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](d&65535)|0;h=j;i=c[9757320+(c[1836236]<<2)>>2]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9706060]=h;h=d+1|0;d=c[i+76+((h>>>8&255)<<2)>>2]|0;do{if((d|0)==0){e=c[i+4180>>2]|0;if((e|0)==0){k=0;break}k=gj[e&4095](h&65535)|0}else{k=a[d+(h&255)|0]|0}}while(0);a[9706061]=k;b[4853032]=(b[4853032]|0)+2&65535;b[4853030]=c[2426515]&65535;a[9706110]=a[9706111]|0;k=c[2426531]|0;if((k|0)==0){return}else{l=k}while(1){m=l+16|0;k=c[m>>2]|0;if((k|0)==-1){n=2306;break}if(((gj[c[l+4>>2]&4095](k)|0)&2|0)==0){l=l+20|0}else{break}}if((n|0)==2306){return}gf[c[l+12>>2]&2047](c[m>>2]|0);return}function gou(){a[9706113]=0;return}function gov(){var b=0;b=a[9706069]|0;a[9706108]=b;a[9706109]=b&-128;return}function gow(){var d=0;d=gj[c[(c[9757320+(c[1836236]<<2)>>2]|0)+4172>>2]&4095](b[4853036]|0)|0;a[9706077]=d;a[9706068]=a[9706068]&1|a[9706144+(d&255)|0];return}function gox(){gg[c[(c[9757320+(c[1836236]<<2)>>2]|0)+4176>>2]&4095](b[4853036]|0,a[9706077]|0);return}function goy(){var d=0,e=0,f=0,g=0;d=c[2426520]|0;e=c[2426519]|0;f=d-e-(a[9706068]&1)|0;g=f^d;a[9706068]=(f>>>8&168|f>>>16&1|((f&65535|0)!=0?0:64)|(g^e)>>>8&16|(g&(e^d))>>>13&4|2)&255;b[4853040]=f&65535;return}function goz(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=c[2426515]|0;e=d&65535;b[4853030]=e+2&65535;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+((d>>>8|768)<<2)>>2]|0;do{if((g|0)==0){h=c[f+4180>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](e)|0;i=k;j=c[9757320+(c[1836236]<<2)>>2]|0}else{i=a[g+(d&255)|0]|0;j=f}}while(0);f=i&255;i=d+1|0;d=c[j+76+((i>>>8&255|768)<<2)>>2]|0;do{if((d|0)==0){g=c[j+4180>>2]|0;if((g|0)==0){l=0;m=j;break}e=gj[g&4095](i&65535)|0;l=e;m=c[9757320+(c[1836236]<<2)>>2]|0}else{l=a[d+(i&255)|0]|0;m=j}}while(0);j=l&255;l=j<<8|f;c[3541536]=l;i=a[9706076]|0;d=c[m+76+((j|256)<<2)>>2]|0;do{if((d|0)==0){j=c[m+4184>>2]|0;if((j|0)==0){n=m;break}gg[j&4095](l&65535,i);n=c[9757320+(c[1836236]<<2)>>2]|0}else{a[d+f|0]=i;n=m}}while(0);m=l+1|0;l=a[9706077]|0;i=c[n+76+((m>>>8&255|256)<<2)>>2]|0;if((i|0)!=0){a[i+(m&255)|0]=l;return}i=c[n+4184>>2]|0;if((i|0)==0){return}gg[i&4095](m&65535,l);return}function goA(){var b=0,d=0,e=0;b=a[9706069]|0;a[9706069]=0;d=c[2426517]&65280;e=(d>>>8)-(b&255)|0;a[9706068]=a[(c[2385738]|0)+(e&255|d)|0]|0;a[9706069]=e&255;return}function goB(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[2426516]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](d&65535)|0;h=j;i=c[9757320+(c[1836236]<<2)>>2]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9706060]=h;h=d+1|0;d=c[i+76+((h>>>8&255)<<2)>>2]|0;do{if((d|0)==0){e=c[i+4180>>2]|0;if((e|0)==0){k=0;break}k=gj[e&4095](h&65535)|0}else{k=a[d+(h&255)|0]|0}}while(0);a[9706061]=k;b[4853032]=(b[4853032]|0)+2&65535;b[4853030]=c[2426515]&65535;a[9706110]=a[9706111]|0;return}function goC(){a[9706113]=1;return}function goD(){var b=0;b=a[9706114]|0;a[9706069]=b;a[9706068]=a[9706068]&1|a[9707544+(b&255)|0]|a[9706111]<<2;return}function goE(){var d=0;d=gj[c[(c[9757320+(c[1836236]<<2)>>2]|0)+4172>>2]&4095](b[4853036]|0)|0;a[9706076]=d;a[9706068]=a[9706068]&1|a[9706144+(d&255)|0];return}function goF(){gg[c[(c[9757320+(c[1836236]<<2)>>2]|0)+4176>>2]&4095](b[4853036]|0,a[9706076]|0);return}function goG(){var d=0,e=0,f=0;d=c[2426520]|0;e=c[2426519]|0;f=e+d+(a[9706068]&1)|0;a[9706068]=(f>>>8&168|f>>>16&1|(e^d^f)>>>8&16|((f&65535|0)!=0?0:64)|((f^e)&(d^32768^e))>>>13&4)&255;b[4853040]=f&65535;return}function goH(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=c[2426515]|0;e=d&65535;b[4853030]=e+2&65535;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+((d>>>8|768)<<2)>>2]|0;do{if((g|0)==0){h=c[f+4180>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](e)|0;i=k;j=c[9757320+(c[1836236]<<2)>>2]|0}else{i=a[g+(d&255)|0]|0;j=f}}while(0);f=i&255;i=d+1|0;d=c[j+76+((i>>>8&255|768)<<2)>>2]|0;do{if((d|0)==0){g=c[j+4180>>2]|0;if((g|0)==0){l=0;m=j;break}e=gj[g&4095](i&65535)|0;l=e;m=c[9757320+(c[1836236]<<2)>>2]|0}else{l=a[d+(i&255)|0]|0;m=j}}while(0);j=l&255;l=j<<8|f;c[3541536]=l;i=c[m+76+(j<<2)>>2]|0;do{if((i|0)==0){j=c[m+4180>>2]|0;if((j|0)==0){n=0;o=m;break}d=gj[j&4095](l&65535)|0;n=d;o=c[9757320+(c[1836236]<<2)>>2]|0}else{n=a[i+f|0]|0;o=m}}while(0);a[9706076]=n;n=l+1|0;l=c[o+76+((n>>>8&255)<<2)>>2]|0;if((l|0)!=0){p=a[l+(n&255)|0]|0;a[9706077]=p;return}l=c[o+4180>>2]|0;if((l|0)==0){p=0;a[9706077]=p;return}p=gj[l&4095](n&65535)|0;a[9706077]=p;return}function goI(){var b=0,d=0,e=0;b=a[9706069]|0;a[9706069]=0;d=c[2426517]&65280;e=(d>>>8)-(b&255)|0;a[9706068]=a[(c[2385738]|0)+(e&255|d)|0]|0;a[9706069]=e&255;return}function goJ(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=c[2426516]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](d&65535)|0;h=j;i=c[9757320+(c[1836236]<<2)>>2]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9706060]=h;h=d+1|0;d=c[i+76+((h>>>8&255)<<2)>>2]|0;do{if((d|0)==0){e=c[i+4180>>2]|0;if((e|0)==0){k=0;break}k=gj[e&4095](h&65535)|0}else{k=a[d+(h&255)|0]|0}}while(0);a[9706061]=k;b[4853032]=(b[4853032]|0)+2&65535;b[4853030]=c[2426515]&65535;a[9706110]=a[9706111]|0;k=c[2426531]|0;if((k|0)==0){return}else{l=k}while(1){m=l+16|0;k=c[m>>2]|0;if((k|0)==-1){n=2382;break}if(((gj[c[l+4>>2]&4095](k)|0)&2|0)==0){l=l+20|0}else{break}}if((n|0)==2382){return}gf[c[l+12>>2]&2047](c[m>>2]|0);return}function goK(){a[9706113]=2;return}function goL(){var b=0;b=a[9706108]&127|a[9706109];a[9706069]=b;a[9706068]=a[9706068]&1|a[9707544+(b&255)|0]|a[9706111]<<2;return}function goM(){var d=0;d=gj[c[(c[9757320+(c[1836236]<<2)>>2]|0)+4172>>2]&4095](b[4853036]|0)|0;a[9706081]=d;a[9706068]=a[9706068]&1|a[9706144+(d&255)|0];return}function goN(){gg[c[(c[9757320+(c[1836236]<<2)>>2]|0)+4176>>2]&4095](b[4853036]|0,a[9706081]|0);return}function goO(){var c=0,d=0;c=-(a[9706068]&1)|0;d=c>>>8;a[9706068]=(d&16|c>>>16&1|d&168|((c&65535|0)!=0?0:64)|2)&255;b[4853040]=c&65535;return}function goP(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=c[2426515]|0;e=d&65535;b[4853030]=e+2&65535;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+((d>>>8|768)<<2)>>2]|0;do{if((g|0)==0){h=c[f+4180>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](e)|0;i=k;j=c[9757320+(c[1836236]<<2)>>2]|0}else{i=a[g+(d&255)|0]|0;j=f}}while(0);f=i&255;i=d+1|0;d=c[j+76+((i>>>8&255|768)<<2)>>2]|0;do{if((d|0)==0){g=c[j+4180>>2]|0;if((g|0)==0){l=0;m=j;break}e=gj[g&4095](i&65535)|0;l=e;m=c[9757320+(c[1836236]<<2)>>2]|0}else{l=a[d+(i&255)|0]|0;m=j}}while(0);j=l&255;l=j<<8|f;c[3541536]=l;i=a[9706080]|0;d=c[m+76+((j|256)<<2)>>2]|0;do{if((d|0)==0){j=c[m+4184>>2]|0;if((j|0)==0){n=m;break}gg[j&4095](l&65535,i);n=c[9757320+(c[1836236]<<2)>>2]|0}else{a[d+f|0]=i;n=m}}while(0);m=l+1|0;l=a[9706081]|0;i=c[n+76+((m>>>8&255|256)<<2)>>2]|0;if((i|0)!=0){a[i+(m&255)|0]=l;return}i=c[n+4184>>2]|0;if((i|0)==0){return}gg[i&4095](m&65535,l);return}function goQ(){var b=0,d=0,e=0;b=a[9706069]|0;a[9706069]=0;d=c[2426517]&65280;e=(d>>>8)-(b&255)|0;a[9706068]=a[(c[2385738]|0)+(e&255|d)|0]|0;a[9706069]=e&255;return}function goR(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[2426516]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](d&65535)|0;h=j;i=c[9757320+(c[1836236]<<2)>>2]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9706060]=h;h=d+1|0;d=c[i+76+((h>>>8&255)<<2)>>2]|0;do{if((d|0)==0){e=c[i+4180>>2]|0;if((e|0)==0){k=0;break}k=gj[e&4095](h&65535)|0}else{k=a[d+(h&255)|0]|0}}while(0);a[9706061]=k;b[4853032]=(b[4853032]|0)+2&65535;b[4853030]=c[2426515]&65535;a[9706110]=a[9706111]|0;return}function goS(){a[9706113]=0;return}function goT(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[4853040]|0;e=d&65535;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+4180>>2]|0;if((h|0)==0){i=0;j=d;k=f;break}l=gj[h&4095](d)|0;i=l;j=b[4853040]|0;k=c[9757320+(c[1836236]<<2)>>2]|0}else{i=a[g+(e&255)|0]|0;j=d;k=f}}while(0);f=j&65535;d=a[9706069]<<4|(i&255)>>>4;e=c[k+76+((f>>>8|256)<<2)>>2]|0;do{if((e|0)==0){g=c[k+4184>>2]|0;if((g|0)==0){break}gg[g&4095](j,d)}else{a[e+(f&255)|0]=d}}while(0);d=a[9706069]&-16|i&15;a[9706069]=d;a[9706068]=a[9706068]&1|a[9706144+(d&255)|0];return}function goU(){var d=0;d=gj[c[(c[9757320+(c[1836236]<<2)>>2]|0)+4172>>2]&4095](b[4853036]|0)|0;a[9706080]=d;a[9706068]=a[9706068]&1|a[9706144+(d&255)|0];return}function goV(){gg[c[(c[9757320+(c[1836236]<<2)>>2]|0)+4176>>2]&4095](b[4853036]|0,a[9706080]|0);return}function goW(){var d=0,e=0,f=0,g=0;d=c[2426520]|0;e=d<<1;f=a[9706068]&1|e;g=d>>>7;a[9706068]=(g&16|d>>>15&1|g&168|(e^d)>>>13&4|((f&65535|0)!=0?0:64))&255;b[4853040]=f&65535;return}function goX(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=c[2426515]|0;e=d&65535;b[4853030]=e+2&65535;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+((d>>>8|768)<<2)>>2]|0;do{if((g|0)==0){h=c[f+4180>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](e)|0;i=k;j=c[9757320+(c[1836236]<<2)>>2]|0}else{i=a[g+(d&255)|0]|0;j=f}}while(0);f=i&255;i=d+1|0;d=c[j+76+((i>>>8&255|768)<<2)>>2]|0;do{if((d|0)==0){g=c[j+4180>>2]|0;if((g|0)==0){l=0;m=j;break}e=gj[g&4095](i&65535)|0;l=e;m=c[9757320+(c[1836236]<<2)>>2]|0}else{l=a[d+(i&255)|0]|0;m=j}}while(0);j=l&255;l=j<<8|f;c[3541536]=l;i=c[m+76+(j<<2)>>2]|0;do{if((i|0)==0){j=c[m+4180>>2]|0;if((j|0)==0){n=0;o=m;break}d=gj[j&4095](l&65535)|0;n=d;o=c[9757320+(c[1836236]<<2)>>2]|0}else{n=a[i+f|0]|0;o=m}}while(0);a[9706080]=n;n=l+1|0;l=c[o+76+((n>>>8&255)<<2)>>2]|0;if((l|0)!=0){p=a[l+(n&255)|0]|0;a[9706081]=p;return}l=c[o+4180>>2]|0;if((l|0)==0){p=0;a[9706081]=p;return}p=gj[l&4095](n&65535)|0;a[9706081]=p;return}function goY(){var b=0,d=0,e=0;b=a[9706069]|0;a[9706069]=0;d=c[2426517]&65280;e=(d>>>8)-(b&255)|0;a[9706068]=a[(c[2385738]|0)+(e&255|d)|0]|0;a[9706069]=e&255;return}function goZ(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=c[2426516]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](d&65535)|0;h=j;i=c[9757320+(c[1836236]<<2)>>2]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9706060]=h;h=d+1|0;d=c[i+76+((h>>>8&255)<<2)>>2]|0;do{if((d|0)==0){e=c[i+4180>>2]|0;if((e|0)==0){k=0;break}k=gj[e&4095](h&65535)|0}else{k=a[d+(h&255)|0]|0}}while(0);a[9706061]=k;b[4853032]=(b[4853032]|0)+2&65535;b[4853030]=c[2426515]&65535;a[9706110]=a[9706111]|0;k=c[2426531]|0;if((k|0)==0){return}else{l=k}while(1){m=l+16|0;k=c[m>>2]|0;if((k|0)==-1){n=2467;break}if(((gj[c[l+4>>2]&4095](k)|0)&2|0)==0){l=l+20|0}else{break}}if((n|0)==2467){return}gf[c[l+12>>2]&2047](c[m>>2]|0);return}function go_(){a[9706113]=0;return}function go$(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[4853040]|0;e=d&65535;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+4180>>2]|0;if((h|0)==0){i=0;j=d;k=f;break}l=gj[h&4095](d)|0;i=l;j=b[4853040]|0;k=c[9757320+(c[1836236]<<2)>>2]|0}else{i=a[g+(e&255)|0]|0;j=d;k=f}}while(0);f=j&65535;d=a[9706069]&15|i<<4;e=c[k+76+((f>>>8|256)<<2)>>2]|0;do{if((e|0)==0){g=c[k+4184>>2]|0;if((g|0)==0){break}gg[g&4095](j,d)}else{a[e+(f&255)|0]=d}}while(0);d=a[9706069]&-16|(i&255)>>>4;a[9706069]=d;a[9706068]=a[9706068]&1|a[9706144+(d&255)|0];return}function go0(){var d=0;d=gj[c[(c[9757320+(c[1836236]<<2)>>2]|0)+4172>>2]&4095](b[4853036]|0)|0;a[9706068]=a[9706068]&1|a[9706144+(d&255)|0];return}function go1(){gg[c[(c[9757320+(c[1836236]<<2)>>2]|0)+4176>>2]&4095](b[4853036]|0,0);return}function go2(){var d=0,e=0,f=0,g=0;d=c[2426520]|0;e=c[2426516]|0;f=d-e-(a[9706068]&1)|0;g=f^d;a[9706068]=(f>>>8&168|f>>>16&1|((f&65535|0)!=0?0:64)|(g^e)>>>8&16|(g&(e^d))>>>13&4|2)&255;b[4853040]=f&65535;return}function go3(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=c[2426515]|0;e=d&65535;b[4853030]=e+2&65535;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+((d>>>8|768)<<2)>>2]|0;do{if((g|0)==0){h=c[f+4180>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](e)|0;i=k;j=c[9757320+(c[1836236]<<2)>>2]|0}else{i=a[g+(d&255)|0]|0;j=f}}while(0);f=i&255;i=d+1|0;d=c[j+76+((i>>>8&255|768)<<2)>>2]|0;do{if((d|0)==0){g=c[j+4180>>2]|0;if((g|0)==0){l=0;m=j;break}e=gj[g&4095](i&65535)|0;l=e;m=c[9757320+(c[1836236]<<2)>>2]|0}else{l=a[d+(i&255)|0]|0;m=j}}while(0);j=l&255;l=j<<8|f;c[3541536]=l;i=a[9706064]|0;d=c[m+76+((j|256)<<2)>>2]|0;do{if((d|0)==0){j=c[m+4184>>2]|0;if((j|0)==0){n=m;break}gg[j&4095](l&65535,i);n=c[9757320+(c[1836236]<<2)>>2]|0}else{a[d+f|0]=i;n=m}}while(0);m=l+1|0;l=a[9706065]|0;i=c[n+76+((m>>>8&255|256)<<2)>>2]|0;if((i|0)!=0){a[i+(m&255)|0]=l;return}i=c[n+4184>>2]|0;if((i|0)==0){return}gg[i&4095](m&65535,l);return}function go4(){var b=0,d=0,e=0;b=a[9706069]|0;a[9706069]=0;d=c[2426517]&65280;e=(d>>>8)-(b&255)|0;a[9706068]=a[(c[2385738]|0)+(e&255|d)|0]|0;a[9706069]=e&255;return}function go5(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[2426516]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](d&65535)|0;h=j;i=c[9757320+(c[1836236]<<2)>>2]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9706060]=h;h=d+1|0;d=c[i+76+((h>>>8&255)<<2)>>2]|0;do{if((d|0)==0){e=c[i+4180>>2]|0;if((e|0)==0){k=0;break}k=gj[e&4095](h&65535)|0}else{k=a[d+(h&255)|0]|0}}while(0);a[9706061]=k;b[4853032]=(b[4853032]|0)+2&65535;b[4853030]=c[2426515]&65535;a[9706110]=a[9706111]|0;return}function go6(){a[9706113]=1;return}function go7(){return}function go8(){var d=0;d=gj[c[(c[9757320+(c[1836236]<<2)>>2]|0)+4172>>2]&4095](b[4853036]|0)|0;a[9706069]=d;a[9706068]=a[9706068]&1|a[9706144+(d&255)|0];return}function go9(){gg[c[(c[9757320+(c[1836236]<<2)>>2]|0)+4176>>2]&4095](b[4853036]|0,a[9706069]|0);return}function gpa(){var d=0,e=0,f=0;d=c[2426520]|0;e=c[2426516]|0;f=e+d+(a[9706068]&1)|0;a[9706068]=(f>>>8&168|f>>>16&1|(e^d^f)>>>8&16|((f&65535|0)!=0?0:64)|((f^e)&(d^32768^e))>>>13&4)&255;b[4853040]=f&65535;return}function gpb(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=c[2426515]|0;e=d&65535;b[4853030]=e+2&65535;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+((d>>>8|768)<<2)>>2]|0;do{if((g|0)==0){h=c[f+4180>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](e)|0;i=k;j=c[9757320+(c[1836236]<<2)>>2]|0}else{i=a[g+(d&255)|0]|0;j=f}}while(0);f=i&255;i=d+1|0;d=c[j+76+((i>>>8&255|768)<<2)>>2]|0;do{if((d|0)==0){g=c[j+4180>>2]|0;if((g|0)==0){l=0;m=j;break}e=gj[g&4095](i&65535)|0;l=e;m=c[9757320+(c[1836236]<<2)>>2]|0}else{l=a[d+(i&255)|0]|0;m=j}}while(0);j=l&255;l=j<<8|f;c[3541536]=l;i=c[m+76+(j<<2)>>2]|0;do{if((i|0)==0){j=c[m+4180>>2]|0;if((j|0)==0){n=0;o=m;break}d=gj[j&4095](l&65535)|0;n=d;o=c[9757320+(c[1836236]<<2)>>2]|0}else{n=a[i+f|0]|0;o=m}}while(0);a[9706064]=n;n=l+1|0;l=c[o+76+((n>>>8&255)<<2)>>2]|0;if((l|0)!=0){p=a[l+(n&255)|0]|0;a[9706065]=p;return}l=c[o+4180>>2]|0;if((l|0)==0){p=0;a[9706065]=p;return}p=gj[l&4095](n&65535)|0;a[9706065]=p;return}function gpc(){var b=0,d=0,e=0;b=a[9706069]|0;a[9706069]=0;d=c[2426517]&65280;e=(d>>>8)-(b&255)|0;a[9706068]=a[(c[2385738]|0)+(e&255|d)|0]|0;a[9706069]=e&255;return}function gpd(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=c[2426516]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](d&65535)|0;h=j;i=c[9757320+(c[1836236]<<2)>>2]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9706060]=h;h=d+1|0;d=c[i+76+((h>>>8&255)<<2)>>2]|0;do{if((d|0)==0){e=c[i+4180>>2]|0;if((e|0)==0){k=0;break}k=gj[e&4095](h&65535)|0}else{k=a[d+(h&255)|0]|0}}while(0);a[9706061]=k;b[4853032]=(b[4853032]|0)+2&65535;b[4853030]=c[2426515]&65535;a[9706110]=a[9706111]|0;k=c[2426531]|0;if((k|0)==0){return}else{l=k}while(1){m=l+16|0;k=c[m>>2]|0;if((k|0)==-1){n=2552;break}if(((gj[c[l+4>>2]&4095](k)|0)&2|0)==0){l=l+20|0}else{break}}if((n|0)==2552){return}gf[c[l+12>>2]&2047](c[m>>2]|0);return}function gpe(){a[9706113]=2;return}function gpf(){return}function gpg(){return}function gph(){return}function gpi(){return}function gpj(){return}function gpk(){return}function gpl(){return}function gpm(){return}function gpn(){return}function gpo(){return}function gpp(){return}function gpq(){return}function gpr(){return}function gps(){return}function gpt(){return}function gpu(){return}function gpv(){return}function gpw(){return}function gpx(){return}function gpy(){return}function gpz(){return}function gpA(){return}function gpB(){return}function gpC(){return}function gpD(){return}function gpE(){return}function gpF(){return}function gpG(){return}function gpH(){return}function gpI(){return}function gpJ(){return}function gpK(){return}function gpL(){return}function gpM(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=b[4853040]|0;f=e&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](e)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(f&255)|0]|0;k=g}}while(0);g=b[4853038]|0;f=g&65535;h=c[k+76+((f>>>8|256)<<2)>>2]|0;do{if((h|0)==0){e=c[k+4184>>2]|0;if((e|0)==0){break}gg[e&4095](g,j)}else{a[h+(f&255)|0]=j}}while(0);f=a[9706068]&-63;a[9706068]=f;h=(d[9706069]|0)+(j&255)|0;if((h&2|0)==0){m=f}else{j=f|32;a[9706068]=j;m=j}if((h&8|0)==0){n=m}else{h=m|8;a[9706068]=h;n=h}b[4853040]=(b[4853040]|0)+1&65535;b[4853038]=(b[4853038]|0)+1&65535;h=(b[4853036]|0)-1&65535;b[4853036]=h;if(h<<16>>16==0){return}a[9706068]=n|4;return}function gpN(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=b[4853040]|0;e=d&65535;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+4180>>2]|0;if((h|0)==0){i=0;j=d;break}k=gj[h&4095](d)|0;i=k;j=b[4853040]|0}else{i=a[g+(e&255)|0]|0;j=d}}while(0);d=a[9706069]|0;e=d-i&255;b[4853040]=j+1&65535;j=(b[4853036]|0)-1&65535;b[4853036]=j;g=a[9706068]&1|(d^i^e)&16|a[9707544+(e&255)|0]&-43;i=(g<<3<<24>>24>>7)+e&255;e=((i&2|0)==0?2:34)|g;g=(i&8|0)==0?e:e|8;a[9706068]=j<<16>>16==0?g:g|4;return}function gpO(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=gj[c[(c[9757320+(c[1836236]<<2)>>2]|0)+4172>>2]&4095](b[4853036]|0)|0;a[9706073]=(a[9706073]|0)-1&255;f=b[4853040]|0;g=f&65535;h=c[9757320+(c[1836236]<<2)>>2]|0;i=c[h+76+((g>>>8|256)<<2)>>2]|0;do{if((i|0)==0){j=c[h+4184>>2]|0;if((j|0)==0){break}gg[j&4095](f,e)}else{a[i+(g&255)|0]=e}}while(0);b[4853040]=(b[4853040]|0)+1&65535;g=d[9706073]|0;i=a[9707544+g|0]|0;a[9706068]=i;f=(d[9706072]|0)+1|0;h=e&255;if((h&128|0)==0){k=i}else{e=i|2;a[9706068]=e;k=e}if(((f&255)+h&256|0)==0){l=k;m=f+h|0;n=m&7;o=n^g;p=9706144+o|0;q=a[p]|0;r=q&4;s=r|l;a[9706068]=s;return}e=k|17;a[9706068]=e;l=e;m=f+h|0;n=m&7;o=n^g;p=9706144+o|0;q=a[p]|0;r=q&4;s=r|l;a[9706068]=s;return}function gpP(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=b[4853040]|0;f=e&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](e)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(f&255)|0]|0;k=g}}while(0);a[9706073]=(a[9706073]|0)-1&255;gg[c[k+4176>>2]&4095](b[4853036]|0,j);k=(b[4853040]|0)+1&65535;b[4853040]=k;g=d[9706073]|0;f=a[9707544+g|0]|0;h=j&255;j=(k&255)+h|0;k=(h&128|0)==0?f:f|2;a[9706068]=((j&256|0)==0?k:k|17)|a[9706144+(j&7^g)|0]&4;return}function gpQ(){return}function gpR(){return}function gpS(){return}function gpT(){return}function gpU(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=b[4853040]|0;f=e&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](e)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(f&255)|0]|0;k=g}}while(0);g=b[4853038]|0;f=g&65535;h=c[k+76+((f>>>8|256)<<2)>>2]|0;do{if((h|0)==0){e=c[k+4184>>2]|0;if((e|0)==0){break}gg[e&4095](g,j)}else{a[h+(f&255)|0]=j}}while(0);f=a[9706068]&-63;a[9706068]=f;h=(d[9706069]|0)+(j&255)|0;if((h&2|0)==0){m=f}else{j=f|32;a[9706068]=j;m=j}if((h&8|0)==0){n=m}else{h=m|8;a[9706068]=h;n=h}b[4853040]=(b[4853040]|0)-1&65535;b[4853038]=(b[4853038]|0)-1&65535;h=(b[4853036]|0)-1&65535;b[4853036]=h;if(h<<16>>16==0){return}a[9706068]=n|4;return}function gpV(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=b[4853040]|0;e=d&65535;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+4180>>2]|0;if((h|0)==0){i=0;j=d;break}k=gj[h&4095](d)|0;i=k;j=b[4853040]|0}else{i=a[g+(e&255)|0]|0;j=d}}while(0);d=a[9706069]|0;e=d-i&255;b[4853040]=j-1&65535;j=(b[4853036]|0)-1&65535;b[4853036]=j;g=a[9706068]&1|(d^i^e)&16|a[9707544+(e&255)|0]&-43;i=(g<<3<<24>>24>>7)+e&255;e=((i&2|0)==0?2:34)|g;g=(i&8|0)==0?e:e|8;a[9706068]=j<<16>>16==0?g:g|4;return}function gpW(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=gj[c[(c[9757320+(c[1836236]<<2)>>2]|0)+4172>>2]&4095](b[4853036]|0)|0;a[9706073]=(a[9706073]|0)-1&255;f=b[4853040]|0;g=f&65535;h=c[9757320+(c[1836236]<<2)>>2]|0;i=c[h+76+((g>>>8|256)<<2)>>2]|0;do{if((i|0)==0){j=c[h+4184>>2]|0;if((j|0)==0){break}gg[j&4095](f,e)}else{a[i+(g&255)|0]=e}}while(0);b[4853040]=(b[4853040]|0)-1&65535;g=d[9706073]|0;i=a[9707544+g|0]|0;a[9706068]=i;f=(d[9706072]|0)+255|0;h=e&255;if((h&128|0)==0){k=i}else{e=i|2;a[9706068]=e;k=e}if(((f&255)+h&256|0)==0){l=k;m=f+h|0;n=m&7;o=n^g;p=9706144+o|0;q=a[p]|0;r=q&4;s=r|l;a[9706068]=s;return}e=k|17;a[9706068]=e;l=e;m=f+h|0;n=m&7;o=n^g;p=9706144+o|0;q=a[p]|0;r=q&4;s=r|l;a[9706068]=s;return}function gpX(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=b[4853040]|0;f=e&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](e)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(f&255)|0]|0;k=g}}while(0);a[9706073]=(a[9706073]|0)-1&255;gg[c[k+4176>>2]&4095](b[4853036]|0,j);k=(b[4853040]|0)-1&65535;b[4853040]=k;g=d[9706073]|0;f=a[9707544+g|0]|0;h=j&255;j=(k&255)+h|0;k=(h&128|0)==0?f:f|2;a[9706068]=((j&256|0)==0?k:k|17)|a[9706144+(j&7^g)|0]&4;return}function gpY(){return}function gpZ(){return}function gp_(){return}function gp$(){return}function gp0(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=b[4853040]|0;f=e&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](e)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(f&255)|0]|0;k=g}}while(0);g=b[4853038]|0;f=g&65535;h=c[k+76+((f>>>8|256)<<2)>>2]|0;do{if((h|0)==0){e=c[k+4184>>2]|0;if((e|0)==0){break}gg[e&4095](g,j)}else{a[h+(f&255)|0]=j}}while(0);f=a[9706068]&-63;a[9706068]=f;h=(d[9706069]|0)+(j&255)|0;if((h&2|0)==0){m=f}else{j=f|32;a[9706068]=j;m=j}if((h&8|0)==0){n=m}else{h=m|8;a[9706068]=h;n=h}b[4853040]=(b[4853040]|0)+1&65535;b[4853038]=(b[4853038]|0)+1&65535;h=(b[4853036]|0)-1&65535;b[4853036]=h;if(h<<16>>16==0){return}a[9706068]=n|4;b[4853030]=(b[4853030]|0)-2&65535;c[2076596]=(c[2076596]|0)-5;return}function gp1(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=b[4853040]|0;e=d&65535;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+4180>>2]|0;if((h|0)==0){i=0;j=d;break}k=gj[h&4095](d)|0;i=k;j=b[4853040]|0}else{i=a[g+(e&255)|0]|0;j=d}}while(0);d=a[9706069]|0;e=d-i&255;b[4853040]=j+1&65535;j=(b[4853036]|0)-1&65535;b[4853036]=j;g=a[9706068]&1|(d^i^e)&16|a[9707544+(e&255)|0]&-43;i=(g<<3<<24>>24>>7)+e&255;e=((i&2|0)==0?2:34)|g;g=(i&8|0)==0?e:e|8;a[9706068]=g;if(j<<16>>16==0){return}a[9706068]=g|4;if((g&64)!=0){return}b[4853030]=(b[4853030]|0)-2&65535;c[2076596]=(c[2076596]|0)-5;return}function gp2(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=gj[c[(c[9757320+(c[1836236]<<2)>>2]|0)+4172>>2]&4095](b[4853036]|0)|0;a[9706073]=(a[9706073]|0)-1&255;f=b[4853040]|0;g=f&65535;h=c[9757320+(c[1836236]<<2)>>2]|0;i=c[h+76+((g>>>8|256)<<2)>>2]|0;do{if((i|0)==0){j=c[h+4184>>2]|0;if((j|0)==0){break}gg[j&4095](f,e)}else{a[i+(g&255)|0]=e}}while(0);b[4853040]=(b[4853040]|0)+1&65535;g=a[9706073]|0;i=g&255;f=a[9707544+i|0]|0;a[9706068]=f;h=(d[9706072]|0)+1|0;j=e&255;if((j&128|0)==0){k=f}else{e=f|2;a[9706068]=e;k=e}if(((h&255)+j&256|0)==0){l=k}else{e=k|17;a[9706068]=e;l=e}a[9706068]=a[9706144+(h+j&7^i)|0]&4|l;if(g<<24>>24==0){return}b[4853030]=(b[4853030]|0)-2&65535;c[2076596]=(c[2076596]|0)-5;return}function gp3(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=b[4853040]|0;e=d&65535;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+4180>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[9757320+(c[1836236]<<2)>>2]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9706073]=(a[9706073]|0)-1&255;gg[c[j+4176>>2]&4095](b[4853036]|0,i);j=(b[4853040]|0)+1&65535;b[4853040]=j;f=a[9706073]|0;e=f&255;g=a[9707544+e|0]|0;d=i&255;i=(j&255)+d|0;j=(d&128|0)==0?g:g|2;a[9706068]=((i&256|0)==0?j:j|17)|a[9706144+(i&7^e)|0]&4;if(f<<24>>24==0){return}b[4853030]=(b[4853030]|0)-2&65535;c[2076596]=(c[2076596]|0)-5;return}function gp4(){return}function gp5(){return}function gp6(){return}function gp7(){return}function gp8(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=b[4853040]|0;f=e&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](e)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(f&255)|0]|0;k=g}}while(0);g=b[4853038]|0;f=g&65535;h=c[k+76+((f>>>8|256)<<2)>>2]|0;do{if((h|0)==0){e=c[k+4184>>2]|0;if((e|0)==0){break}gg[e&4095](g,j)}else{a[h+(f&255)|0]=j}}while(0);f=a[9706068]&-63;a[9706068]=f;h=(d[9706069]|0)+(j&255)|0;if((h&2|0)==0){m=f}else{j=f|32;a[9706068]=j;m=j}if((h&8|0)==0){n=m}else{h=m|8;a[9706068]=h;n=h}b[4853040]=(b[4853040]|0)-1&65535;b[4853038]=(b[4853038]|0)-1&65535;h=(b[4853036]|0)-1&65535;b[4853036]=h;if(h<<16>>16==0){return}a[9706068]=n|4;b[4853030]=(b[4853030]|0)-2&65535;c[2076596]=(c[2076596]|0)-5;return}function gp9(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=b[4853040]|0;e=d&65535;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+4180>>2]|0;if((h|0)==0){i=0;j=d;break}k=gj[h&4095](d)|0;i=k;j=b[4853040]|0}else{i=a[g+(e&255)|0]|0;j=d}}while(0);d=a[9706069]|0;e=d-i&255;b[4853040]=j-1&65535;j=(b[4853036]|0)-1&65535;b[4853036]=j;g=a[9706068]&1|(d^i^e)&16|a[9707544+(e&255)|0]&-43;i=(g<<3<<24>>24>>7)+e&255;e=((i&2|0)==0?2:34)|g;g=(i&8|0)==0?e:e|8;a[9706068]=g;if(j<<16>>16==0){return}a[9706068]=g|4;if((g&64)!=0){return}b[4853030]=(b[4853030]|0)-2&65535;c[2076596]=(c[2076596]|0)-5;return}function gqa(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=gj[c[(c[9757320+(c[1836236]<<2)>>2]|0)+4172>>2]&4095](b[4853036]|0)|0;a[9706073]=(a[9706073]|0)-1&255;f=b[4853040]|0;g=f&65535;h=c[9757320+(c[1836236]<<2)>>2]|0;i=c[h+76+((g>>>8|256)<<2)>>2]|0;do{if((i|0)==0){j=c[h+4184>>2]|0;if((j|0)==0){break}gg[j&4095](f,e)}else{a[i+(g&255)|0]=e}}while(0);b[4853040]=(b[4853040]|0)-1&65535;g=a[9706073]|0;i=g&255;f=a[9707544+i|0]|0;a[9706068]=f;h=(d[9706072]|0)+255|0;j=e&255;if((j&128|0)==0){k=f}else{e=f|2;a[9706068]=e;k=e}if(((h&255)+j&256|0)==0){l=k}else{e=k|17;a[9706068]=e;l=e}a[9706068]=a[9706144+(h+j&7^i)|0]&4|l;if(g<<24>>24==0){return}b[4853030]=(b[4853030]|0)-2&65535;c[2076596]=(c[2076596]|0)-5;return}function gqb(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=b[4853040]|0;e=d&65535;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+(e>>>8<<2)>>2]|0;do{if((g|0)==0){h=c[f+4180>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](d)|0;i=k;j=c[9757320+(c[1836236]<<2)>>2]|0}else{i=a[g+(e&255)|0]|0;j=f}}while(0);a[9706073]=(a[9706073]|0)-1&255;gg[c[j+4176>>2]&4095](b[4853036]|0,i);j=(b[4853040]|0)-1&65535;b[4853040]=j;f=a[9706073]|0;e=f&255;g=a[9707544+e|0]|0;d=i&255;i=(j&255)+d|0;j=(d&128|0)==0?g:g|2;a[9706068]=((i&256|0)==0?j:j|17)|a[9706144+(i&7^e)|0]&4;if(f<<24>>24==0){return}b[4853030]=(b[4853030]|0)-2&65535;c[2076596]=(c[2076596]|0)-5;return}function gqc(){return}function gqd(){return}function gqe(){return}function gqf(){return}function gqg(){return}function gqh(){return}function gqi(){return}function gqj(){return}function gqk(){return}function gql(){return}function gqm(){return}function gqn(){return}function gqo(){return}function gqp(){return}function gqq(){return}function gqr(){return}function gqs(){return}function gqt(){return}function gqu(){return}function gqv(){return}function gqw(){return}function gqx(){return}function gqy(){return}function gqz(){return}function gqA(){return}function gqB(){return}function gqC(){return}function gqD(){return}function gqE(){return}function gqF(){return}function gqG(){return}function gqH(){return}function gqI(){return}function gqJ(){return}function gqK(){return}function gqL(){return}function gqM(){return}function gqN(){return}function gqO(){return}function gqP(){return}function gqQ(){return}function gqR(){return}function gqS(){return}function gqT(){return}function gqU(){return}function gqV(){return}function gqW(){return}function gqX(){return}function gqY(){return}function gqZ(){return}function gq_(){return}function gq$(){return}function gq0(){return}function gq1(){return}function gq2(){return}function gq3(){return}function gq4(){return}function gq5(){return}function gq6(){return}function gq7(){return}function gq8(){return}function gq9(){return}function gra(){return}function grb(){return}function grc(){return}function grd(){return}function gre(){return}function grf(){return}function grg(){return}function grh(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=c[2426515]|0;e=d&65535;b[4853030]=e+2&65535;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+((d>>>8|768)<<2)>>2]|0;do{if((g|0)==0){h=c[f+4180>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](e)|0;i=k;j=c[9757320+(c[1836236]<<2)>>2]|0}else{i=a[g+(d&255)|0]|0;j=f}}while(0);f=i&255;i=d+1|0;d=c[j+76+((i>>>8&255|768)<<2)>>2]|0;if((d|0)!=0){l=a[d+(i&255)|0]|0;m=l&255;n=m<<8;o=n|f;b[4853036]=o;return}d=c[j+4180>>2]|0;if((d|0)==0){l=0;m=l&255;n=m<<8;o=n|f;b[4853036]=o;return}l=gj[d&4095](i&65535)|0;m=l&255;n=m<<8;o=n|f;b[4853036]=o;return}function gri(){var d=0,e=0,f=0,g=0,h=0;d=b[4853036]|0;e=d&65535;f=a[9706069]|0;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|256)<<2)>>2]|0;if((h|0)!=0){a[h+(e&255)|0]=f;return}e=c[g+4184>>2]|0;if((e|0)==0){return}gg[e&4095](d,f);return}function grj(){b[4853036]=(b[4853036]|0)+1&65535;return}function grk(){var b=0;b=(a[9706073]|0)+1&255;a[9706068]=a[9706068]&1|a[9621712+(b&255)|0];a[9706073]=b;return}function grl(){var b=0;b=(a[9706073]|0)-1&255;a[9706068]=a[9706068]&1|a[9621968+(b&255)|0];a[9706073]=b;return}function grm(){var d=0,e=0,f=0,g=0,h=0;d=c[2426515]|0;e=d&65535;b[4853030]=e+1&65535;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+((d>>>8|768)<<2)>>2]|0;if((g|0)!=0){h=a[g+(d&255)|0]|0;a[9706073]=h;return}d=c[f+4180>>2]|0;if((d|0)==0){h=0;a[9706073]=h;return}h=gj[d&4095](e)|0;a[9706073]=h;return}function grn(){var b=0,c=0;b=a[9706069]|0;c=b<<1|(b&255)>>>7;a[9706069]=c;a[9706068]=c&41|a[9706068]&-60;return}function gro(){var a=0;a=c[2426517]|0;c[2426517]=c[2426523];c[2426523]=a;return}function grp(){var d=0,e=0,f=0;d=c[2426521]|0;e=c[2426518]|0;f=e+d|0;a[9706068]=(f>>>16&1|a[9706068]&196|f>>>8&40|(e^d^f)>>>8&16)&255;b[4853042]=f&65535;return}function grq(){var d=0,e=0,f=0,g=0,h=0;d=b[4853036]|0;e=d&65535;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+(e>>>8<<2)>>2]|0;if((g|0)!=0){h=a[g+(e&255)|0]|0;a[9706069]=h;return}e=c[f+4180>>2]|0;if((e|0)==0){h=0;a[9706069]=h;return}h=gj[e&4095](d)|0;a[9706069]=h;return}function grr(){b[4853036]=(b[4853036]|0)-1&65535;return}function grs(){var b=0;b=(a[9706072]|0)+1&255;a[9706068]=a[9706068]&1|a[9621712+(b&255)|0];a[9706072]=b;return}function grt(){var b=0;b=(a[9706072]|0)-1&255;a[9706068]=a[9706068]&1|a[9621968+(b&255)|0];a[9706072]=b;return}function gru(){var d=0,e=0,f=0,g=0,h=0;d=c[2426515]|0;e=d&65535;b[4853030]=e+1&65535;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+((d>>>8|768)<<2)>>2]|0;if((g|0)!=0){h=a[g+(d&255)|0]|0;a[9706072]=h;return}d=c[f+4180>>2]|0;if((d|0)==0){h=0;a[9706072]=h;return}h=gj[d&4095](e)|0;a[9706072]=h;return}function grv(){var b=0,c=0,d=0;b=a[9706069]|0;c=b&1|a[9706068]&-60;d=(b&255)>>>1;a[9706069]=d|b<<7;a[9706068]=c|d&40;return}function grw(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=(a[9706073]|0)-1&255;a[9706073]=d;if(d<<24>>24==0){e=(b[4853030]|0)+1&65535;b[4853030]=e;return}d=c[2426515]|0;f=d&65535;g=f+1&65535;b[4853030]=g;h=c[9757320+(c[1836236]<<2)>>2]|0;i=c[h+76+((d>>>8|768)<<2)>>2]|0;do{if((i|0)==0){j=c[h+4180>>2]|0;if((j|0)==0){k=0;l=g;break}m=gj[j&4095](f)|0;k=m;l=b[4853030]|0}else{k=a[i+(d&255)|0]|0;l=g}}while(0);b[4853030]=l+(k<<24>>24)&65535;c[2076596]=(c[2076596]|0)-5;e=c[2426515]&65535;b[4853030]=e;return}function grx(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=c[2426515]|0;e=d&65535;b[4853030]=e+2&65535;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+((d>>>8|768)<<2)>>2]|0;do{if((g|0)==0){h=c[f+4180>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](e)|0;i=k;j=c[9757320+(c[1836236]<<2)>>2]|0}else{i=a[g+(d&255)|0]|0;j=f}}while(0);f=i&255;i=d+1|0;d=c[j+76+((i>>>8&255|768)<<2)>>2]|0;if((d|0)!=0){l=a[d+(i&255)|0]|0;m=l&255;n=m<<8;o=n|f;b[4853038]=o;return}d=c[j+4180>>2]|0;if((d|0)==0){l=0;m=l&255;n=m<<8;o=n|f;b[4853038]=o;return}l=gj[d&4095](i&65535)|0;m=l&255;n=m<<8;o=n|f;b[4853038]=o;return}function gry(){var d=0,e=0,f=0,g=0,h=0;d=b[4853038]|0;e=d&65535;f=a[9706069]|0;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|256)<<2)>>2]|0;if((h|0)!=0){a[h+(e&255)|0]=f;return}e=c[g+4184>>2]|0;if((e|0)==0){return}gg[e&4095](d,f);return}function grz(){b[4853038]=(b[4853038]|0)+1&65535;return}function grA(){var b=0;b=(a[9706077]|0)+1&255;a[9706068]=a[9706068]&1|a[9621712+(b&255)|0];a[9706077]=b;return}function grB(){var b=0;b=(a[9706077]|0)-1&255;a[9706068]=a[9706068]&1|a[9621968+(b&255)|0];a[9706077]=b;return}function grC(){var d=0,e=0,f=0,g=0,h=0;d=c[2426515]|0;e=d&65535;b[4853030]=e+1&65535;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+((d>>>8|768)<<2)>>2]|0;if((g|0)!=0){h=a[g+(d&255)|0]|0;a[9706077]=h;return}d=c[f+4180>>2]|0;if((d|0)==0){h=0;a[9706077]=h;return}h=gj[d&4095](e)|0;a[9706077]=h;return}function grD(){var b=0,c=0,d=0;b=a[9706069]|0;c=b<<1;d=a[9706068]|0;a[9706068]=d&-60|(b&255)>>>7|c&40;a[9706069]=d&1|c;return}function grE(){gfd();return}function grF(){var d=0,e=0,f=0;d=c[2426521]|0;e=c[2426519]|0;f=e+d|0;a[9706068]=(f>>>16&1|a[9706068]&196|f>>>8&40|(e^d^f)>>>8&16)&255;b[4853042]=f&65535;return}function grG(){var d=0,e=0,f=0,g=0,h=0;d=b[4853038]|0;e=d&65535;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+(e>>>8<<2)>>2]|0;if((g|0)!=0){h=a[g+(e&255)|0]|0;a[9706069]=h;return}e=c[f+4180>>2]|0;if((e|0)==0){h=0;a[9706069]=h;return}h=gj[e&4095](d)|0;a[9706069]=h;return}function grH(){b[4853038]=(b[4853038]|0)-1&65535;return}function grI(){var b=0;b=(a[9706076]|0)+1&255;a[9706068]=a[9706068]&1|a[9621712+(b&255)|0];a[9706076]=b;return}function grJ(){var b=0;b=(a[9706076]|0)-1&255;a[9706068]=a[9706068]&1|a[9621968+(b&255)|0];a[9706076]=b;return}function grK(){var d=0,e=0,f=0,g=0,h=0;d=c[2426515]|0;e=d&65535;b[4853030]=e+1&65535;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+((d>>>8|768)<<2)>>2]|0;if((g|0)!=0){h=a[g+(d&255)|0]|0;a[9706076]=h;return}d=c[f+4180>>2]|0;if((d|0)==0){h=0;a[9706076]=h;return}h=gj[d&4095](e)|0;a[9706076]=h;return}function grL(){var b=0,c=0,d=0;b=a[9706069]|0;c=(b&255)>>>1;d=a[9706068]|0;a[9706068]=d&-60|b&1|c&40;a[9706069]=d<<7|c;return}function grM(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((a[9706068]&64)!=0){d=(b[4853030]|0)+1&65535;b[4853030]=d;return}e=c[2426515]|0;f=e&65535;g=f+1&65535;b[4853030]=g;h=c[9757320+(c[1836236]<<2)>>2]|0;i=c[h+76+((e>>>8|768)<<2)>>2]|0;do{if((i|0)==0){j=c[h+4180>>2]|0;if((j|0)==0){k=0;l=g;break}m=gj[j&4095](f)|0;k=m;l=b[4853030]|0}else{k=a[i+(e&255)|0]|0;l=g}}while(0);b[4853030]=l+(k<<24>>24)&65535;c[2076596]=(c[2076596]|0)-5;d=c[2426515]&65535;b[4853030]=d;return}function grN(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=c[2426515]|0;e=d&65535;b[4853030]=e+2&65535;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+((d>>>8|768)<<2)>>2]|0;do{if((g|0)==0){h=c[f+4180>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](e)|0;i=k;j=c[9757320+(c[1836236]<<2)>>2]|0}else{i=a[g+(d&255)|0]|0;j=f}}while(0);f=i&255;i=d+1|0;d=c[j+76+((i>>>8&255|768)<<2)>>2]|0;if((d|0)!=0){l=a[d+(i&255)|0]|0;m=l&255;n=m<<8;o=n|f;b[4853042]=o;return}d=c[j+4180>>2]|0;if((d|0)==0){l=0;m=l&255;n=m<<8;o=n|f;b[4853042]=o;return}l=gj[d&4095](i&65535)|0;m=l&255;n=m<<8;o=n|f;b[4853042]=o;return}function grO(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=c[2426515]|0;e=d&65535;b[4853030]=e+2&65535;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+((d>>>8|768)<<2)>>2]|0;do{if((g|0)==0){h=c[f+4180>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](e)|0;i=k;j=c[9757320+(c[1836236]<<2)>>2]|0}else{i=a[g+(d&255)|0]|0;j=f}}while(0);f=i&255;i=d+1|0;d=c[j+76+((i>>>8&255|768)<<2)>>2]|0;do{if((d|0)==0){g=c[j+4180>>2]|0;if((g|0)==0){l=0;m=j;break}e=gj[g&4095](i&65535)|0;l=e;m=c[9757320+(c[1836236]<<2)>>2]|0}else{l=a[d+(i&255)|0]|0;m=j}}while(0);j=l&255;l=j<<8|f;c[3541536]=l;i=a[9706084]|0;d=c[m+76+((j|256)<<2)>>2]|0;do{if((d|0)==0){j=c[m+4184>>2]|0;if((j|0)==0){n=m;break}gg[j&4095](l&65535,i);n=c[9757320+(c[1836236]<<2)>>2]|0}else{a[d+f|0]=i;n=m}}while(0);m=l+1|0;l=a[9706085]|0;i=c[n+76+((m>>>8&255|256)<<2)>>2]|0;if((i|0)!=0){a[i+(m&255)|0]=l;return}i=c[n+4184>>2]|0;if((i|0)==0){return}gg[i&4095](m&65535,l);return}function grP(){b[4853042]=(b[4853042]|0)+1&65535;return}function grQ(){var b=0;b=(a[9706085]|0)+1&255;a[9706068]=a[9706068]&1|a[9621712+(b&255)|0];a[9706085]=b;return}function grR(){var b=0;b=(a[9706085]|0)-1&255;a[9706068]=a[9706068]&1|a[9621968+(b&255)|0];a[9706085]=b;return}function grS(){var d=0,e=0,f=0,g=0,h=0;d=c[2426515]|0;e=d&65535;b[4853030]=e+1&65535;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+((d>>>8|768)<<2)>>2]|0;if((g|0)!=0){h=a[g+(d&255)|0]|0;a[9706085]=h;return}d=c[f+4180>>2]|0;if((d|0)==0){h=0;a[9706085]=h;return}h=gj[d&4095](e)|0;a[9706085]=h;return}function grT(){gfe();return}function grU(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((a[9706068]&64)==0){d=(b[4853030]|0)+1&65535;b[4853030]=d;return}e=c[2426515]|0;f=e&65535;g=f+1&65535;b[4853030]=g;h=c[9757320+(c[1836236]<<2)>>2]|0;i=c[h+76+((e>>>8|768)<<2)>>2]|0;do{if((i|0)==0){j=c[h+4180>>2]|0;if((j|0)==0){k=0;l=g;break}m=gj[j&4095](f)|0;k=m;l=b[4853030]|0}else{k=a[i+(e&255)|0]|0;l=g}}while(0);b[4853030]=l+(k<<24>>24)&65535;c[2076596]=(c[2076596]|0)-5;d=c[2426515]&65535;b[4853030]=d;return}function grV(){var d=0,e=0;d=c[2426521]|0;e=d>>>7;a[9706068]=(d>>>15&1|e&16|e&40|a[9706068]&196)&255;b[4853042]=d<<1&65535;return}function grW(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=c[2426515]|0;e=d&65535;b[4853030]=e+2&65535;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+((d>>>8|768)<<2)>>2]|0;do{if((g|0)==0){h=c[f+4180>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](e)|0;i=k;j=c[9757320+(c[1836236]<<2)>>2]|0}else{i=a[g+(d&255)|0]|0;j=f}}while(0);f=i&255;i=d+1|0;d=c[j+76+((i>>>8&255|768)<<2)>>2]|0;do{if((d|0)==0){g=c[j+4180>>2]|0;if((g|0)==0){l=0;m=j;break}e=gj[g&4095](i&65535)|0;l=e;m=c[9757320+(c[1836236]<<2)>>2]|0}else{l=a[d+(i&255)|0]|0;m=j}}while(0);j=l&255;l=j<<8|f;c[3541536]=l;i=c[m+76+(j<<2)>>2]|0;do{if((i|0)==0){j=c[m+4180>>2]|0;if((j|0)==0){n=0;o=m;break}d=gj[j&4095](l&65535)|0;n=d;o=c[9757320+(c[1836236]<<2)>>2]|0}else{n=a[i+f|0]|0;o=m}}while(0);a[9706084]=n;n=l+1|0;l=c[o+76+((n>>>8&255)<<2)>>2]|0;if((l|0)!=0){p=a[l+(n&255)|0]|0;a[9706085]=p;return}l=c[o+4180>>2]|0;if((l|0)==0){p=0;a[9706085]=p;return}p=gj[l&4095](n&65535)|0;a[9706085]=p;return}function grX(){b[4853042]=(b[4853042]|0)-1&65535;return}function grY(){var b=0;b=(a[9706084]|0)+1&255;a[9706068]=a[9706068]&1|a[9621712+(b&255)|0];a[9706084]=b;return}function grZ(){var b=0;b=(a[9706084]|0)-1&255;a[9706068]=a[9706068]&1|a[9621968+(b&255)|0];a[9706084]=b;return}function gr_(){var d=0,e=0,f=0,g=0,h=0;d=c[2426515]|0;e=d&65535;b[4853030]=e+1&65535;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+((d>>>8|768)<<2)>>2]|0;if((g|0)!=0){h=a[g+(d&255)|0]|0;a[9706084]=h;return}d=c[f+4180>>2]|0;if((d|0)==0){h=0;a[9706084]=h;return}h=gj[d&4095](e)|0;a[9706084]=h;return}function gr$(){var b=0;b=~a[9706069];a[9706069]=b;a[9706068]=b&40|a[9706068]&-59|18;return}function gr0(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((a[9706068]&1)!=0){d=(b[4853030]|0)+1&65535;b[4853030]=d;return}e=c[2426515]|0;f=e&65535;g=f+1&65535;b[4853030]=g;h=c[9757320+(c[1836236]<<2)>>2]|0;i=c[h+76+((e>>>8|768)<<2)>>2]|0;do{if((i|0)==0){j=c[h+4180>>2]|0;if((j|0)==0){k=0;l=g;break}m=gj[j&4095](f)|0;k=m;l=b[4853030]|0}else{k=a[i+(e&255)|0]|0;l=g}}while(0);b[4853030]=l+(k<<24>>24)&65535;c[2076596]=(c[2076596]|0)-5;d=c[2426515]&65535;b[4853030]=d;return}function gr1(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=c[2426515]|0;e=d&65535;b[4853030]=e+2&65535;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+((d>>>8|768)<<2)>>2]|0;do{if((g|0)==0){h=c[f+4180>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](e)|0;i=k;j=c[9757320+(c[1836236]<<2)>>2]|0}else{i=a[g+(d&255)|0]|0;j=f}}while(0);f=i&255;i=d+1|0;d=c[j+76+((i>>>8&255|768)<<2)>>2]|0;if((d|0)!=0){l=a[d+(i&255)|0]|0;m=l&255;n=m<<8;o=n|f;b[4853032]=o;return}d=c[j+4180>>2]|0;if((d|0)==0){l=0;m=l&255;n=m<<8;o=n|f;b[4853032]=o;return}l=gj[d&4095](i&65535)|0;m=l&255;n=m<<8;o=n|f;b[4853032]=o;return}function gr2(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=c[2426515]|0;e=d&65535;b[4853030]=e+2&65535;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+((d>>>8|768)<<2)>>2]|0;do{if((g|0)==0){h=c[f+4180>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](e)|0;i=k;j=c[9757320+(c[1836236]<<2)>>2]|0}else{i=a[g+(d&255)|0]|0;j=f}}while(0);f=i&255;i=d+1|0;d=c[j+76+((i>>>8&255|768)<<2)>>2]|0;do{if((d|0)==0){g=c[j+4180>>2]|0;if((g|0)==0){l=0;m=j;break}e=gj[g&4095](i&65535)|0;l=e;m=c[9757320+(c[1836236]<<2)>>2]|0}else{l=a[d+(i&255)|0]|0;m=j}}while(0);j=l&255;l=j<<8|f;c[3541536]=l;i=a[9706069]|0;d=c[m+76+((j|256)<<2)>>2]|0;if((d|0)!=0){a[d+f|0]=i;return}f=c[m+4184>>2]|0;if((f|0)==0){return}gg[f&4095](l&65535,i);return}function gr3(){b[4853032]=(b[4853032]|0)+1&65535;return}function gr4(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=b[4853042]|0;e=c[2426515]|0;f=e&65535;b[4853030]=f+1&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=(j<<24>>24)+d&65535;d=g&65535;c[3541536]=d;j=d>>>8;e=c[k+76+(j<<2)>>2]|0;do{if((e|0)==0){h=c[k+4180>>2]|0;if((h|0)==0){m=0;n=k;break}f=gj[h&4095](g)|0;m=f;n=c[9757320+(c[1836236]<<2)>>2]|0}else{m=a[e+(d&255)|0]|0;n=k}}while(0);k=m+1&255;a[9706068]=a[9706068]&1|a[9621712+(k&255)|0];m=c[n+76+((j|256)<<2)>>2]|0;if((m|0)!=0){a[m+(d&255)|0]=k;return}d=c[n+4184>>2]|0;if((d|0)==0){return}gg[d&4095](g,k);return}function gr5(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=b[4853042]|0;e=c[2426515]|0;f=e&65535;b[4853030]=f+1&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=(j<<24>>24)+d&65535;d=g&65535;c[3541536]=d;j=d>>>8;e=c[k+76+(j<<2)>>2]|0;do{if((e|0)==0){h=c[k+4180>>2]|0;if((h|0)==0){m=0;n=k;break}f=gj[h&4095](g)|0;m=f;n=c[9757320+(c[1836236]<<2)>>2]|0}else{m=a[e+(d&255)|0]|0;n=k}}while(0);k=m-1&255;a[9706068]=a[9706068]&1|a[9621968+(k&255)|0];m=c[n+76+((j|256)<<2)>>2]|0;if((m|0)!=0){a[m+(d&255)|0]=k;return}d=c[n+4184>>2]|0;if((d|0)==0){return}gg[d&4095](g,k);return}function gr6(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=b[4853042]|0;e=c[2426515]|0;f=e&65535;b[4853030]=f+1&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=(j<<24>>24)+d&65535;d=g&65535;c[3541536]=d;j=c[2426515]|0;e=j&65535;b[4853030]=e+1&65535;h=c[k+76+((j>>>8|768)<<2)>>2]|0;do{if((h|0)==0){f=c[k+4180>>2]|0;if((f|0)==0){m=0;n=k;break}l=gj[f&4095](e)|0;m=l;n=c[9757320+(c[1836236]<<2)>>2]|0}else{m=a[h+(j&255)|0]|0;n=k}}while(0);k=c[n+76+((d>>>8|256)<<2)>>2]|0;if((k|0)!=0){a[k+(d&255)|0]=m;return}d=c[n+4184>>2]|0;if((d|0)==0){return}gg[d&4095](g,m);return}function gr7(){a[9706068]=a[9706068]&-60|a[9706069]&40|1;return}function gr8(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((a[9706068]&1)==0){d=(b[4853030]|0)+1&65535;b[4853030]=d;return}e=c[2426515]|0;f=e&65535;g=f+1&65535;b[4853030]=g;h=c[9757320+(c[1836236]<<2)>>2]|0;i=c[h+76+((e>>>8|768)<<2)>>2]|0;do{if((i|0)==0){j=c[h+4180>>2]|0;if((j|0)==0){k=0;l=g;break}m=gj[j&4095](f)|0;k=m;l=b[4853030]|0}else{k=a[i+(e&255)|0]|0;l=g}}while(0);b[4853030]=l+(k<<24>>24)&65535;c[2076596]=(c[2076596]|0)-5;d=c[2426515]&65535;b[4853030]=d;return}function gr9(){var d=0,e=0,f=0;d=c[2426521]|0;e=c[2426516]|0;f=e+d|0;a[9706068]=(f>>>16&1|a[9706068]&196|f>>>8&40|(e^d^f)>>>8&16)&255;b[4853042]=f&65535;return}function gsa(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=c[2426515]|0;e=d&65535;b[4853030]=e+2&65535;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+((d>>>8|768)<<2)>>2]|0;do{if((g|0)==0){h=c[f+4180>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](e)|0;i=k;j=c[9757320+(c[1836236]<<2)>>2]|0}else{i=a[g+(d&255)|0]|0;j=f}}while(0);f=i&255;i=d+1|0;d=c[j+76+((i>>>8&255|768)<<2)>>2]|0;do{if((d|0)==0){g=c[j+4180>>2]|0;if((g|0)==0){l=0;m=j;break}e=gj[g&4095](i&65535)|0;l=e;m=c[9757320+(c[1836236]<<2)>>2]|0}else{l=a[d+(i&255)|0]|0;m=j}}while(0);j=l&255;l=j<<8|f;c[3541536]=l;i=c[m+76+(j<<2)>>2]|0;if((i|0)!=0){n=a[i+f|0]|0;a[9706069]=n;return}f=c[m+4180>>2]|0;if((f|0)==0){n=0;a[9706069]=n;return}n=gj[f&4095](l&65535)|0;a[9706069]=n;return}function gsb(){b[4853032]=(b[4853032]|0)-1&65535;return}function gsc(){var b=0;b=(a[9706069]|0)+1&255;a[9706068]=a[9706068]&1|a[9621712+(b&255)|0];a[9706069]=b;return}function gsd(){var b=0;b=(a[9706069]|0)-1&255;a[9706068]=a[9706068]&1|a[9621968+(b&255)|0];a[9706069]=b;return}function gse(){var d=0,e=0,f=0,g=0,h=0;d=c[2426515]|0;e=d&65535;b[4853030]=e+1&65535;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+((d>>>8|768)<<2)>>2]|0;if((g|0)!=0){h=a[g+(d&255)|0]|0;a[9706069]=h;return}d=c[f+4180>>2]|0;if((d|0)==0){h=0;a[9706069]=h;return}h=gj[d&4095](e)|0;a[9706069]=h;return}function gsf(){var b=0;b=a[9706068]|0;a[9706068]=(b<<4&16|b&-59|a[9706069]&40)^1;return}function gsg(){return}function gsh(){a[9706073]=a[9706072]|0;return}function gsi(){a[9706073]=a[9706077]|0;return}function gsj(){a[9706073]=a[9706076]|0;return}function gsk(){a[9706073]=a[9706085]|0;return}function gsl(){a[9706073]=a[9706084]|0;return}function gsm(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b[4853042]|0;e=c[2426515]|0;f=e&65535;b[4853030]=f+1&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=(j<<24>>24)+d&65535;d=g&65535;c[3541536]=d;j=c[k+76+(d>>>8<<2)>>2]|0;if((j|0)!=0){m=a[j+(d&255)|0]|0;a[9706073]=m;return}d=c[k+4180>>2]|0;if((d|0)==0){m=0;a[9706073]=m;return}m=gj[d&4095](g)|0;a[9706073]=m;return}function gsn(){a[9706073]=a[9706069]|0;return}function gso(){a[9706072]=a[9706073]|0;return}function gsp(){return}function gsq(){a[9706072]=a[9706077]|0;return}function gsr(){a[9706072]=a[9706076]|0;return}function gss(){a[9706072]=a[9706085]|0;return}function gst(){a[9706072]=a[9706084]|0;return}function gsu(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b[4853042]|0;e=c[2426515]|0;f=e&65535;b[4853030]=f+1&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=(j<<24>>24)+d&65535;d=g&65535;c[3541536]=d;j=c[k+76+(d>>>8<<2)>>2]|0;if((j|0)!=0){m=a[j+(d&255)|0]|0;a[9706072]=m;return}d=c[k+4180>>2]|0;if((d|0)==0){m=0;a[9706072]=m;return}m=gj[d&4095](g)|0;a[9706072]=m;return}function gsv(){a[9706072]=a[9706069]|0;return}function gsw(){a[9706077]=a[9706073]|0;return}function gsx(){a[9706077]=a[9706072]|0;return}function gsy(){return}function gsz(){a[9706077]=a[9706076]|0;return}function gsA(){a[9706077]=a[9706085]|0;return}function gsB(){a[9706077]=a[9706084]|0;return}function gsC(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b[4853042]|0;e=c[2426515]|0;f=e&65535;b[4853030]=f+1&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=(j<<24>>24)+d&65535;d=g&65535;c[3541536]=d;j=c[k+76+(d>>>8<<2)>>2]|0;if((j|0)!=0){m=a[j+(d&255)|0]|0;a[9706077]=m;return}d=c[k+4180>>2]|0;if((d|0)==0){m=0;a[9706077]=m;return}m=gj[d&4095](g)|0;a[9706077]=m;return}function gsD(){a[9706077]=a[9706069]|0;return}function gsE(){a[9706076]=a[9706073]|0;return}function gsF(){a[9706076]=a[9706072]|0;return}function gsG(){a[9706076]=a[9706077]|0;return}function gsH(){return}function gsI(){a[9706076]=a[9706085]|0;return}function gsJ(){a[9706076]=a[9706084]|0;return}function gsK(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b[4853042]|0;e=c[2426515]|0;f=e&65535;b[4853030]=f+1&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=(j<<24>>24)+d&65535;d=g&65535;c[3541536]=d;j=c[k+76+(d>>>8<<2)>>2]|0;if((j|0)!=0){m=a[j+(d&255)|0]|0;a[9706076]=m;return}d=c[k+4180>>2]|0;if((d|0)==0){m=0;a[9706076]=m;return}m=gj[d&4095](g)|0;a[9706076]=m;return}function gsL(){a[9706076]=a[9706069]|0;return}function gsM(){a[9706085]=a[9706073]|0;return}function gsN(){a[9706085]=a[9706072]|0;return}function gsO(){a[9706085]=a[9706077]|0;return}function gsP(){a[9706085]=a[9706076]|0;return}function gsQ(){return}function gsR(){a[9706085]=a[9706084]|0;return}function gsS(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b[4853042]|0;e=c[2426515]|0;f=e&65535;b[4853030]=f+1&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=(j<<24>>24)+d&65535;d=g&65535;c[3541536]=d;j=c[k+76+(d>>>8<<2)>>2]|0;if((j|0)!=0){m=a[j+(d&255)|0]|0;a[9706081]=m;return}d=c[k+4180>>2]|0;if((d|0)==0){m=0;a[9706081]=m;return}m=gj[d&4095](g)|0;a[9706081]=m;return}function gsT(){a[9706085]=a[9706069]|0;return}function gsU(){a[9706084]=a[9706073]|0;return}function gsV(){a[9706084]=a[9706072]|0;return}function gsW(){a[9706084]=a[9706077]|0;return}function gsX(){a[9706084]=a[9706076]|0;return}function gsY(){a[9706084]=a[9706085]|0;return}function gsZ(){return}function gs_(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b[4853042]|0;e=c[2426515]|0;f=e&65535;b[4853030]=f+1&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=(j<<24>>24)+d&65535;d=g&65535;c[3541536]=d;j=c[k+76+(d>>>8<<2)>>2]|0;if((j|0)!=0){m=a[j+(d&255)|0]|0;a[9706080]=m;return}d=c[k+4180>>2]|0;if((d|0)==0){m=0;a[9706080]=m;return}m=gj[d&4095](g)|0;a[9706080]=m;return}function gs$(){a[9706084]=a[9706069]|0;return}function gs0(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[4853042]|0;e=c[2426515]|0;f=e&65535;b[4853030]=f+1&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=(j<<24>>24)+d&65535;d=g&65535;c[3541536]=d;j=a[9706073]|0;e=c[k+76+((d>>>8|256)<<2)>>2]|0;if((e|0)!=0){a[e+(d&255)|0]=j;return}d=c[k+4184>>2]|0;if((d|0)==0){return}gg[d&4095](g,j);return}function gs1(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[4853042]|0;e=c[2426515]|0;f=e&65535;b[4853030]=f+1&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=(j<<24>>24)+d&65535;d=g&65535;c[3541536]=d;j=a[9706072]|0;e=c[k+76+((d>>>8|256)<<2)>>2]|0;if((e|0)!=0){a[e+(d&255)|0]=j;return}d=c[k+4184>>2]|0;if((d|0)==0){return}gg[d&4095](g,j);return}function gs2(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[4853042]|0;e=c[2426515]|0;f=e&65535;b[4853030]=f+1&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=(j<<24>>24)+d&65535;d=g&65535;c[3541536]=d;j=a[9706077]|0;e=c[k+76+((d>>>8|256)<<2)>>2]|0;if((e|0)!=0){a[e+(d&255)|0]=j;return}d=c[k+4184>>2]|0;if((d|0)==0){return}gg[d&4095](g,j);return}function gs3(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[4853042]|0;e=c[2426515]|0;f=e&65535;b[4853030]=f+1&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=(j<<24>>24)+d&65535;d=g&65535;c[3541536]=d;j=a[9706076]|0;e=c[k+76+((d>>>8|256)<<2)>>2]|0;if((e|0)!=0){a[e+(d&255)|0]=j;return}d=c[k+4184>>2]|0;if((d|0)==0){return}gg[d&4095](g,j);return}function gs4(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[4853042]|0;e=c[2426515]|0;f=e&65535;b[4853030]=f+1&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=(j<<24>>24)+d&65535;d=g&65535;c[3541536]=d;j=a[9706081]|0;e=c[k+76+((d>>>8|256)<<2)>>2]|0;if((e|0)!=0){a[e+(d&255)|0]=j;return}d=c[k+4184>>2]|0;if((d|0)==0){return}gg[d&4095](g,j);return}function gs5(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[4853042]|0;e=c[2426515]|0;f=e&65535;b[4853030]=f+1&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=(j<<24>>24)+d&65535;d=g&65535;c[3541536]=d;j=a[9706080]|0;e=c[k+76+((d>>>8|256)<<2)>>2]|0;if((e|0)!=0){a[e+(d&255)|0]=j;return}d=c[k+4184>>2]|0;if((d|0)==0){return}gg[d&4095](g,j);return}function gs6(){var e=0,f=0;b[4853030]=(b[4853030]|0)-1&65535;a[9706112]=1;if((a[9706117]|0)!=0){return}e=c[2076596]|0;if((e|0)<=0){return}f=(e+3|0)/4|0;a[9706108]=(d[9706108]|0)+f&255;c[2076596]=e-(f<<2);return}function gs7(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[4853042]|0;e=c[2426515]|0;f=e&65535;b[4853030]=f+1&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=(j<<24>>24)+d&65535;d=g&65535;c[3541536]=d;j=a[9706069]|0;e=c[k+76+((d>>>8|256)<<2)>>2]|0;if((e|0)!=0){a[e+(d&255)|0]=j;return}d=c[k+4184>>2]|0;if((d|0)==0){return}gg[d&4095](g,j);return}function gs8(){a[9706069]=a[9706073]|0;return}function gs9(){a[9706069]=a[9706072]|0;return}function gta(){a[9706069]=a[9706077]|0;return}function gtb(){a[9706069]=a[9706076]|0;return}function gtc(){a[9706069]=a[9706085]|0;return}function gtd(){a[9706069]=a[9706084]|0;return}function gte(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b[4853042]|0;e=c[2426515]|0;f=e&65535;b[4853030]=f+1&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=(j<<24>>24)+d&65535;d=g&65535;c[3541536]=d;j=c[k+76+(d>>>8<<2)>>2]|0;if((j|0)!=0){m=a[j+(d&255)|0]|0;a[9706069]=m;return}d=c[k+4180>>2]|0;if((d|0)==0){m=0;a[9706069]=m;return}m=gj[d&4095](g)|0;a[9706069]=m;return}function gtf(){return}function gtg(){var b=0,e=0;b=c[2426517]&65280;e=(b>>>8)+(d[9706073]|0)|0;a[9706068]=a[(c[2385740]|0)+(e&255|b)|0]|0;a[9706069]=e&255;return}function gth(){var b=0,e=0;b=c[2426517]&65280;e=(b>>>8)+(d[9706072]|0)|0;a[9706068]=a[(c[2385740]|0)+(e&255|b)|0]|0;a[9706069]=e&255;return}function gti(){var b=0,e=0;b=c[2426517]&65280;e=(b>>>8)+(d[9706077]|0)|0;a[9706068]=a[(c[2385740]|0)+(e&255|b)|0]|0;a[9706069]=e&255;return}function gtj(){var b=0,e=0;b=c[2426517]&65280;e=(b>>>8)+(d[9706076]|0)|0;a[9706068]=a[(c[2385740]|0)+(e&255|b)|0]|0;a[9706069]=e&255;return}function gtk(){var b=0,e=0;b=c[2426517]&65280;e=(b>>>8)+(d[9706085]|0)|0;a[9706068]=a[(c[2385740]|0)+(e&255|b)|0]|0;a[9706069]=e&255;return}function gtl(){var b=0,e=0;b=c[2426517]&65280;e=(b>>>8)+(d[9706084]|0)|0;a[9706068]=a[(c[2385740]|0)+(e&255|b)|0]|0;a[9706069]=e&255;return}function gtm(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b[4853042]|0;e=c[2426515]|0;f=e&65535;b[4853030]=f+1&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=(j<<24>>24)+d&65535;d=g&65535;c[3541536]=d;j=c[2426517]&65280;e=j>>>8;h=c[k+76+(d>>>8<<2)>>2]|0;do{if((h|0)==0){f=c[k+4180>>2]|0;if((f|0)==0){m=0;break}m=gj[f&4095](g)|0}else{m=a[h+(d&255)|0]|0}}while(0);d=(m&255)+e|0;a[9706068]=a[(c[2385740]|0)+(d&255|j)|0]|0;a[9706069]=d&255;return}function gtn(){var b=0,e=0;b=c[2426517]&65280;e=(b>>>8)+(d[9706069]|0)|0;a[9706068]=a[(c[2385740]|0)+(e&255|b)|0]|0;a[9706069]=e&255;return}function gto(){var b=0,e=0,f=0;b=c[2426517]|0;e=b&65280;f=b&1;b=(d[9706073]|0)+f+(e>>>8)|0;a[9706068]=a[(c[2385740]|0)+(f<<16|e|b&255)|0]|0;a[9706069]=b&255;return}function gtp(){var b=0,e=0,f=0;b=c[2426517]|0;e=b&65280;f=b&1;b=(d[9706072]|0)+f+(e>>>8)|0;a[9706068]=a[(c[2385740]|0)+(f<<16|e|b&255)|0]|0;a[9706069]=b&255;return}function gtq(){var b=0,e=0,f=0;b=c[2426517]|0;e=b&65280;f=b&1;b=(d[9706077]|0)+f+(e>>>8)|0;a[9706068]=a[(c[2385740]|0)+(f<<16|e|b&255)|0]|0;a[9706069]=b&255;return}function gtr(){var b=0,e=0,f=0;b=c[2426517]|0;e=b&65280;f=b&1;b=(d[9706076]|0)+f+(e>>>8)|0;a[9706068]=a[(c[2385740]|0)+(f<<16|e|b&255)|0]|0;a[9706069]=b&255;return}function gts(){var b=0,e=0,f=0;b=c[2426517]|0;e=b&65280;f=b&1;b=(d[9706085]|0)+f+(e>>>8)|0;a[9706068]=a[(c[2385740]|0)+(f<<16|e|b&255)|0]|0;a[9706069]=b&255;return}function gtt(){var b=0,e=0,f=0;b=c[2426517]|0;e=b&65280;f=b&1;b=(d[9706084]|0)+f+(e>>>8)|0;a[9706068]=a[(c[2385740]|0)+(f<<16|e|b&255)|0]|0;a[9706069]=b&255;return}function gtu(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b[4853042]|0;e=c[2426515]|0;f=e&65535;b[4853030]=f+1&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=(j<<24>>24)+d&65535;d=g&65535;c[3541536]=d;j=c[2426517]|0;e=j&65280;h=j&1;j=e>>>8;f=c[k+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){l=c[k+4180>>2]|0;if((l|0)==0){m=0;break}m=gj[l&4095](g)|0}else{m=a[f+(d&255)|0]|0}}while(0);d=j+h+(m&255)|0;a[9706068]=a[(c[2385740]|0)+(h<<16|e|d&255)|0]|0;a[9706069]=d&255;return}function gtv(){var b=0,e=0,f=0;b=c[2426517]|0;e=b&65280;f=b&1;b=(d[9706069]|0)+f+(e>>>8)|0;a[9706068]=a[(c[2385740]|0)+(f<<16|e|b&255)|0]|0;a[9706069]=b&255;return}function gtw(){var b=0,e=0;b=c[2426517]&65280;e=(b>>>8)-(d[9706073]|0)|0;a[9706068]=a[(c[2385738]|0)+(e&255|b)|0]|0;a[9706069]=e&255;return}function gtx(){var b=0,e=0;b=c[2426517]&65280;e=(b>>>8)-(d[9706072]|0)|0;a[9706068]=a[(c[2385738]|0)+(e&255|b)|0]|0;a[9706069]=e&255;return}function gty(){var b=0,e=0;b=c[2426517]&65280;e=(b>>>8)-(d[9706077]|0)|0;a[9706068]=a[(c[2385738]|0)+(e&255|b)|0]|0;a[9706069]=e&255;return}function gtz(){var b=0,e=0;b=c[2426517]&65280;e=(b>>>8)-(d[9706076]|0)|0;a[9706068]=a[(c[2385738]|0)+(e&255|b)|0]|0;a[9706069]=e&255;return}function gtA(){var b=0,e=0;b=c[2426517]&65280;e=(b>>>8)-(d[9706085]|0)|0;a[9706068]=a[(c[2385738]|0)+(e&255|b)|0]|0;a[9706069]=e&255;return}function gtB(){var b=0,e=0;b=c[2426517]&65280;e=(b>>>8)-(d[9706084]|0)|0;a[9706068]=a[(c[2385738]|0)+(e&255|b)|0]|0;a[9706069]=e&255;return}function gtC(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b[4853042]|0;e=c[2426515]|0;f=e&65535;b[4853030]=f+1&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=(j<<24>>24)+d&65535;d=g&65535;c[3541536]=d;j=c[2426517]&65280;e=j>>>8;h=c[k+76+(d>>>8<<2)>>2]|0;do{if((h|0)==0){f=c[k+4180>>2]|0;if((f|0)==0){m=0;break}m=gj[f&4095](g)|0}else{m=a[h+(d&255)|0]|0}}while(0);d=e-(m&255)|0;a[9706068]=a[(c[2385738]|0)+(d&255|j)|0]|0;a[9706069]=d&255;return}function gtD(){var b=0,e=0;b=c[2426517]&65280;e=(b>>>8)-(d[9706069]|0)|0;a[9706068]=a[(c[2385738]|0)+(e&255|b)|0]|0;a[9706069]=e&255;return}function gtE(){var b=0,e=0,f=0;b=c[2426517]|0;e=b&65280;f=b&1;b=(e>>>8)-(d[9706073]|0)-f|0;a[9706068]=a[(c[2385738]|0)+(f<<16|e|b&255)|0]|0;a[9706069]=b&255;return}function gtF(){var b=0,e=0,f=0;b=c[2426517]|0;e=b&65280;f=b&1;b=(e>>>8)-(d[9706072]|0)-f|0;a[9706068]=a[(c[2385738]|0)+(f<<16|e|b&255)|0]|0;a[9706069]=b&255;return}function gtG(){var b=0,e=0,f=0;b=c[2426517]|0;e=b&65280;f=b&1;b=(e>>>8)-(d[9706077]|0)-f|0;a[9706068]=a[(c[2385738]|0)+(f<<16|e|b&255)|0]|0;a[9706069]=b&255;return}function gtH(){var b=0,e=0,f=0;b=c[2426517]|0;e=b&65280;f=b&1;b=(e>>>8)-(d[9706076]|0)-f|0;a[9706068]=a[(c[2385738]|0)+(f<<16|e|b&255)|0]|0;a[9706069]=b&255;return}function gtI(){var b=0,e=0,f=0;b=c[2426517]|0;e=b&65280;f=b&1;b=(e>>>8)-(d[9706085]|0)-f|0;a[9706068]=a[(c[2385738]|0)+(f<<16|e|b&255)|0]|0;a[9706069]=b&255;return}function gtJ(){var b=0,e=0,f=0;b=c[2426517]|0;e=b&65280;f=b&1;b=(e>>>8)-(d[9706084]|0)-f|0;a[9706068]=a[(c[2385738]|0)+(f<<16|e|b&255)|0]|0;a[9706069]=b&255;return}function gtK(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b[4853042]|0;e=c[2426515]|0;f=e&65535;b[4853030]=f+1&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=(j<<24>>24)+d&65535;d=g&65535;c[3541536]=d;j=c[2426517]|0;e=j&65280;h=j&1;j=e>>>8;f=c[k+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){l=c[k+4180>>2]|0;if((l|0)==0){m=0;break}m=gj[l&4095](g)|0}else{m=a[f+(d&255)|0]|0}}while(0);d=j-(m&255)-h|0;a[9706068]=a[(c[2385738]|0)+(h<<16|e|d&255)|0]|0;a[9706069]=d&255;return}function gtL(){var b=0,e=0,f=0;b=c[2426517]|0;e=b&65280;f=b&1;b=(e>>>8)-(d[9706069]|0)-f|0;a[9706068]=a[(c[2385738]|0)+(f<<16|e|b&255)|0]|0;a[9706069]=b&255;return}function gtM(){var b=0;b=a[9706069]&a[9706073];a[9706069]=b;a[9706068]=a[9706144+(b&255)|0]|16;return}function gtN(){var b=0;b=a[9706069]&a[9706072];a[9706069]=b;a[9706068]=a[9706144+(b&255)|0]|16;return}function gtO(){var b=0;b=a[9706069]&a[9706077];a[9706069]=b;a[9706068]=a[9706144+(b&255)|0]|16;return}function gtP(){var b=0;b=a[9706069]&a[9706076];a[9706069]=b;a[9706068]=a[9706144+(b&255)|0]|16;return}function gtQ(){var b=0;b=a[9706069]&a[9706085];a[9706069]=b;a[9706068]=a[9706144+(b&255)|0]|16;return}function gtR(){var b=0;b=a[9706069]&a[9706084];a[9706069]=b;a[9706068]=a[9706144+(b&255)|0]|16;return}function gtS(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b[4853042]|0;e=c[2426515]|0;f=e&65535;b[4853030]=f+1&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=(j<<24>>24)+d&65535;d=g&65535;c[3541536]=d;j=c[k+76+(d>>>8<<2)>>2]|0;do{if((j|0)==0){e=c[k+4180>>2]|0;if((e|0)==0){m=0;break}m=gj[e&4095](g)|0}else{m=a[j+(d&255)|0]|0}}while(0);d=a[9706069]&m;a[9706069]=d;a[9706068]=a[9706144+(d&255)|0]|16;return}function gtT(){a[9706068]=a[9706144+(d[9706069]|0)|0]|16;return}function gtU(){var b=0;b=a[9706069]^a[9706073];a[9706069]=b;a[9706068]=a[9706144+(b&255)|0]|0;return}function gtV(){var b=0;b=a[9706069]^a[9706072];a[9706069]=b;a[9706068]=a[9706144+(b&255)|0]|0;return}function gtW(){var b=0;b=a[9706069]^a[9706077];a[9706069]=b;a[9706068]=a[9706144+(b&255)|0]|0;return}function gtX(){var b=0;b=a[9706069]^a[9706076];a[9706069]=b;a[9706068]=a[9706144+(b&255)|0]|0;return}function gtY(){var b=0;b=a[9706069]^a[9706085];a[9706069]=b;a[9706068]=a[9706144+(b&255)|0]|0;return}function gtZ(){var b=0;b=a[9706069]^a[9706084];a[9706069]=b;a[9706068]=a[9706144+(b&255)|0]|0;return}function gt_(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b[4853042]|0;e=c[2426515]|0;f=e&65535;b[4853030]=f+1&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=(j<<24>>24)+d&65535;d=g&65535;c[3541536]=d;j=c[k+76+(d>>>8<<2)>>2]|0;do{if((j|0)==0){e=c[k+4180>>2]|0;if((e|0)==0){m=0;break}m=gj[e&4095](g)|0}else{m=a[j+(d&255)|0]|0}}while(0);d=a[9706069]^m;a[9706069]=d;a[9706068]=a[9706144+(d&255)|0]|0;return}function gt$(){a[9706069]=0;a[9706068]=a[9706144]|0;return}function gt0(){var b=0;b=a[9706069]|a[9706073];a[9706069]=b;a[9706068]=a[9706144+(b&255)|0]|0;return}function gt1(){var b=0;b=a[9706069]|a[9706072];a[9706069]=b;a[9706068]=a[9706144+(b&255)|0]|0;return}function gt2(){var b=0;b=a[9706069]|a[9706077];a[9706069]=b;a[9706068]=a[9706144+(b&255)|0]|0;return}function gt3(){var b=0;b=a[9706069]|a[9706076];a[9706069]=b;a[9706068]=a[9706144+(b&255)|0]|0;return}function gt4(){var b=0;b=a[9706069]|a[9706085];a[9706069]=b;a[9706068]=a[9706144+(b&255)|0]|0;return}function gt5(){var b=0;b=a[9706069]|a[9706084];a[9706069]=b;a[9706068]=a[9706144+(b&255)|0]|0;return}function gt6(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b[4853042]|0;e=c[2426515]|0;f=e&65535;b[4853030]=f+1&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=(j<<24>>24)+d&65535;d=g&65535;c[3541536]=d;j=c[k+76+(d>>>8<<2)>>2]|0;do{if((j|0)==0){e=c[k+4180>>2]|0;if((e|0)==0){m=0;break}m=gj[e&4095](g)|0}else{m=a[j+(d&255)|0]|0}}while(0);d=a[9706069]|m;a[9706069]=d;a[9706068]=a[9706144+(d&255)|0]|0;return}function gt7(){a[9706068]=a[9706144+(d[9706069]|0)|0]|0;return}function gt8(){var b=0,d=0;b=a[9706073]|0;d=c[2426517]&65280;a[9706068]=a[(c[2385738]|0)+((d>>>8)-(b&255)&255|d)|0]&-41|b&40;return}function gt9(){var b=0,d=0;b=a[9706072]|0;d=c[2426517]&65280;a[9706068]=a[(c[2385738]|0)+((d>>>8)-(b&255)&255|d)|0]&-41|b&40;return}function gua(){var b=0,d=0;b=a[9706077]|0;d=c[2426517]&65280;a[9706068]=a[(c[2385738]|0)+((d>>>8)-(b&255)&255|d)|0]&-41|b&40;return}function gub(){var b=0,d=0;b=a[9706076]|0;d=c[2426517]&65280;a[9706068]=a[(c[2385738]|0)+((d>>>8)-(b&255)&255|d)|0]&-41|b&40;return}function guc(){var b=0,d=0;b=a[9706085]|0;d=c[2426517]&65280;a[9706068]=a[(c[2385738]|0)+((d>>>8)-(b&255)&255|d)|0]&-41|b&40;return}function gud(){var b=0,d=0;b=a[9706084]|0;d=c[2426517]&65280;a[9706068]=a[(c[2385738]|0)+((d>>>8)-(b&255)&255|d)|0]&-41|b&40;return}function gue(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b[4853042]|0;e=c[2426515]|0;f=e&65535;b[4853030]=f+1&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=(j<<24>>24)+d&65535;d=g&65535;c[3541536]=d;j=c[k+76+(d>>>8<<2)>>2]|0;do{if((j|0)==0){e=c[k+4180>>2]|0;if((e|0)==0){m=0;break}m=gj[e&4095](g)|0}else{m=a[j+(d&255)|0]|0}}while(0);d=c[2426517]&65280;a[9706068]=a[(c[2385738]|0)+((d>>>8)-(m&255)&255|d)|0]&-41|m&40;return}function guf(){var b=0,d=0;b=a[9706069]|0;d=c[2426517]&65280;a[9706068]=a[(c[2385738]|0)+((d>>>8)-(b&255)&255|d)|0]&-41|b&40;return}function gug(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if((a[9706068]&64)!=0){return}d=c[2426516]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](d&65535)|0;h=j;i=c[9757320+(c[1836236]<<2)>>2]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9706060]=h;h=d+1|0;d=c[i+76+((h>>>8&255)<<2)>>2]|0;do{if((d|0)==0){e=c[i+4180>>2]|0;if((e|0)==0){k=0;break}k=gj[e&4095](h&65535)|0}else{k=a[d+(h&255)|0]|0}}while(0);a[9706061]=k;b[4853032]=(b[4853032]|0)+2&65535;b[4853030]=c[2426515]&65535;c[2076596]=(c[2076596]|0)-6;return}function guh(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[2426516]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](d&65535)|0;h=j;i=c[9757320+(c[1836236]<<2)>>2]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9706072]=h;h=d+1|0;d=c[i+76+((h>>>8&255)<<2)>>2]|0;do{if((d|0)==0){e=c[i+4180>>2]|0;if((e|0)==0){k=0;break}k=gj[e&4095](h&65535)|0}else{k=a[d+(h&255)|0]|0}}while(0);a[9706073]=k;b[4853032]=(b[4853032]|0)+2&65535;return}function gui(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((a[9706068]&64)!=0){d=(b[4853030]|0)+2&65535;b[4853030]=d;return}e=c[2426515]|0;f=e&65535;b[4853030]=f+2&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=j&255;j=e+1|0;e=c[k+76+((j>>>8&255|768)<<2)>>2]|0;do{if((e|0)==0){h=c[k+4180>>2]|0;if((h|0)==0){m=0;break}m=gj[h&4095](j&65535)|0}else{m=a[e+(j&255)|0]|0}}while(0);j=(m&255)<<8|g;c[2426515]=j;d=j&65535;b[4853030]=d;return}function guj(){gff();return}function guk(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((a[9706068]&64)!=0){d=(b[4853030]|0)+2&65535;b[4853030]=d;return}e=c[2426515]|0;f=e&65535;b[4853030]=f+2&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=j&255;j=e+1|0;e=c[k+76+((j>>>8&255|768)<<2)>>2]|0;do{if((e|0)==0){h=c[k+4180>>2]|0;if((h|0)==0){m=0;n=k;break}f=gj[h&4095](j&65535)|0;m=f;n=c[9757320+(c[1836236]<<2)>>2]|0}else{m=a[e+(j&255)|0]|0;n=k}}while(0);c[3541536]=(m&255)<<8|g;b[4853032]=(b[4853032]|0)-2&65535;g=c[2426516]|0;m=a[9706060]|0;k=c[n+76+((g>>>8|256)<<2)>>2]|0;do{if((k|0)==0){j=c[n+4184>>2]|0;if((j|0)==0){o=n;break}gg[j&4095](g&65535,m);o=c[9757320+(c[1836236]<<2)>>2]|0}else{a[k+(g&255)|0]=m;o=n}}while(0);n=g+1|0;g=a[9706061]|0;m=c[o+76+((n>>>8&255|256)<<2)>>2]|0;do{if((m|0)==0){k=c[o+4184>>2]|0;if((k|0)==0){break}gg[k&4095](n&65535,g)}else{a[m+(n&255)|0]=g}}while(0);g=c[3541536]|0;c[2426515]=g;c[2076596]=(c[2076596]|0)-7;d=g&65535;b[4853030]=d;return}function gul(){var d=0,e=0,f=0,g=0,h=0,i=0;b[4853032]=(b[4853032]|0)-2&65535;d=c[2426516]|0;e=a[9706072]|0;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+((d>>>8|256)<<2)>>2]|0;do{if((g|0)==0){h=c[f+4184>>2]|0;if((h|0)==0){i=f;break}gg[h&4095](d&65535,e);i=c[9757320+(c[1836236]<<2)>>2]|0}else{a[g+(d&255)|0]=e;i=f}}while(0);f=d+1|0;d=a[9706073]|0;e=c[i+76+((f>>>8&255|256)<<2)>>2]|0;if((e|0)!=0){a[e+(f&255)|0]=d;return}e=c[i+4184>>2]|0;if((e|0)==0){return}gg[e&4095](f&65535,d);return}function gum(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[2426517]&65280;e=d>>>8;f=c[2426515]|0;g=f&65535;b[4853030]=g+1&65535;h=c[9757320+(c[1836236]<<2)>>2]|0;i=c[h+76+((f>>>8|768)<<2)>>2]|0;do{if((i|0)==0){j=c[h+4180>>2]|0;if((j|0)==0){k=0;break}k=gj[j&4095](g)|0}else{k=a[i+(f&255)|0]|0}}while(0);f=(k&255)+e|0;a[9706068]=a[(c[2385740]|0)+(f&255|d)|0]|0;a[9706069]=f&255;return}function gun(){var d=0,e=0,f=0,g=0,h=0,i=0;b[4853032]=(b[4853032]|0)-2&65535;d=c[2426516]|0;e=a[9706060]|0;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+((d>>>8|256)<<2)>>2]|0;do{if((g|0)==0){h=c[f+4184>>2]|0;if((h|0)==0){i=f;break}gg[h&4095](d&65535,e);i=c[9757320+(c[1836236]<<2)>>2]|0}else{a[g+(d&255)|0]=e;i=f}}while(0);f=d+1|0;d=a[9706061]|0;e=c[i+76+((f>>>8&255|256)<<2)>>2]|0;if((e|0)!=0){a[e+(f&255)|0]=d;c[2426515]=0;b[4853030]=0;return}e=c[i+4184>>2]|0;if((e|0)==0){c[2426515]=0;b[4853030]=0;return}gg[e&4095](f&65535,d);c[2426515]=0;b[4853030]=0;return}function guo(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if((a[9706068]&64)==0){return}d=c[2426516]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](d&65535)|0;h=j;i=c[9757320+(c[1836236]<<2)>>2]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9706060]=h;h=d+1|0;d=c[i+76+((h>>>8&255)<<2)>>2]|0;do{if((d|0)==0){e=c[i+4180>>2]|0;if((e|0)==0){k=0;break}k=gj[e&4095](h&65535)|0}else{k=a[d+(h&255)|0]|0}}while(0);a[9706061]=k;b[4853032]=(b[4853032]|0)+2&65535;b[4853030]=c[2426515]&65535;c[2076596]=(c[2076596]|0)-6;return}function gup(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[2426516]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](d&65535)|0;h=j;i=c[9757320+(c[1836236]<<2)>>2]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9706060]=h;h=d+1|0;d=c[i+76+((h>>>8&255)<<2)>>2]|0;do{if((d|0)==0){e=c[i+4180>>2]|0;if((e|0)==0){k=0;break}k=gj[e&4095](h&65535)|0}else{k=a[d+(h&255)|0]|0}}while(0);a[9706061]=k;b[4853032]=(b[4853032]|0)+2&65535;b[4853030]=c[2426515]&65535;return}function guq(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((a[9706068]&64)==0){d=(b[4853030]|0)+2&65535;b[4853030]=d;return}e=c[2426515]|0;f=e&65535;b[4853030]=f+2&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=j&255;j=e+1|0;e=c[k+76+((j>>>8&255|768)<<2)>>2]|0;do{if((e|0)==0){h=c[k+4180>>2]|0;if((h|0)==0){m=0;break}m=gj[h&4095](j&65535)|0}else{m=a[e+(j&255)|0]|0}}while(0);j=(m&255)<<8|g;c[2426515]=j;d=j&65535;b[4853030]=d;return}function gur(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=b[4853042]|0;f=c[2426515]|0;g=f&65535;b[4853030]=g+1&65535;h=c[9757320+(c[1836236]<<2)>>2]|0;i=c[h+76+((f>>>8|768)<<2)>>2]|0;do{if((i|0)==0){j=c[h+4180>>2]|0;if((j|0)==0){k=0;l=h;break}m=gj[j&4095](g)|0;k=m;l=c[9757320+(c[1836236]<<2)>>2]|0}else{k=a[i+(f&255)|0]|0;l=h}}while(0);c[3541536]=(k<<24>>24)+e&65535;e=c[2426515]|0;k=e&65535;b[4853030]=k+1&65535;h=c[l+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){f=c[l+4180>>2]|0;if((f|0)==0){n=0;break}n=gj[f&4095](k)|0}else{n=a[h+(e&255)|0]|0}}while(0);e=n&255;c[2076596]=(c[2076596]|0)-(d[(c[2426876]|0)+e|0]|0);gu[c[670648+(e<<2)>>2]&16383]();return}function gus(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((a[9706068]&64)==0){d=(b[4853030]|0)+2&65535;b[4853030]=d;return}e=c[2426515]|0;f=e&65535;b[4853030]=f+2&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=j&255;j=e+1|0;e=c[k+76+((j>>>8&255|768)<<2)>>2]|0;do{if((e|0)==0){h=c[k+4180>>2]|0;if((h|0)==0){m=0;n=k;break}f=gj[h&4095](j&65535)|0;m=f;n=c[9757320+(c[1836236]<<2)>>2]|0}else{m=a[e+(j&255)|0]|0;n=k}}while(0);c[3541536]=(m&255)<<8|g;b[4853032]=(b[4853032]|0)-2&65535;g=c[2426516]|0;m=a[9706060]|0;k=c[n+76+((g>>>8|256)<<2)>>2]|0;do{if((k|0)==0){j=c[n+4184>>2]|0;if((j|0)==0){o=n;break}gg[j&4095](g&65535,m);o=c[9757320+(c[1836236]<<2)>>2]|0}else{a[k+(g&255)|0]=m;o=n}}while(0);n=g+1|0;g=a[9706061]|0;m=c[o+76+((n>>>8&255|256)<<2)>>2]|0;do{if((m|0)==0){k=c[o+4184>>2]|0;if((k|0)==0){break}gg[k&4095](n&65535,g)}else{a[m+(n&255)|0]=g}}while(0);g=c[3541536]|0;c[2426515]=g;c[2076596]=(c[2076596]|0)-7;d=g&65535;b[4853030]=d;return}function gut(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=c[2426515]|0;e=d&65535;b[4853030]=e+2&65535;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+((d>>>8|768)<<2)>>2]|0;do{if((g|0)==0){h=c[f+4180>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](e)|0;i=k;j=c[9757320+(c[1836236]<<2)>>2]|0}else{i=a[g+(d&255)|0]|0;j=f}}while(0);f=i&255;i=d+1|0;d=c[j+76+((i>>>8&255|768)<<2)>>2]|0;do{if((d|0)==0){g=c[j+4180>>2]|0;if((g|0)==0){l=0;m=j;break}e=gj[g&4095](i&65535)|0;l=e;m=c[9757320+(c[1836236]<<2)>>2]|0}else{l=a[d+(i&255)|0]|0;m=j}}while(0);c[3541536]=(l&255)<<8|f;b[4853032]=(b[4853032]|0)-2&65535;f=c[2426516]|0;l=a[9706060]|0;j=c[m+76+((f>>>8|256)<<2)>>2]|0;do{if((j|0)==0){i=c[m+4184>>2]|0;if((i|0)==0){n=m;break}gg[i&4095](f&65535,l);n=c[9757320+(c[1836236]<<2)>>2]|0}else{a[j+(f&255)|0]=l;n=m}}while(0);m=f+1|0;f=a[9706061]|0;l=c[n+76+((m>>>8&255|256)<<2)>>2]|0;if((l|0)!=0){a[l+(m&255)|0]=f;o=c[3541536]|0;c[2426515]=o;p=o&65535;b[4853030]=p;return}l=c[n+4184>>2]|0;if((l|0)==0){o=c[3541536]|0;c[2426515]=o;p=o&65535;b[4853030]=p;return}gg[l&4095](m&65535,f);o=c[3541536]|0;c[2426515]=o;p=o&65535;b[4853030]=p;return}function guu(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[2426517]|0;e=d&65280;f=d&1;d=e>>>8;g=c[2426515]|0;h=g&65535;b[4853030]=h+1&65535;i=c[9757320+(c[1836236]<<2)>>2]|0;j=c[i+76+((g>>>8|768)<<2)>>2]|0;do{if((j|0)==0){k=c[i+4180>>2]|0;if((k|0)==0){l=0;break}l=gj[k&4095](h)|0}else{l=a[j+(g&255)|0]|0}}while(0);g=d+f+(l&255)|0;a[9706068]=a[(c[2385740]|0)+(f<<16|e|g&255)|0]|0;a[9706069]=g&255;return}function guv(){var d=0,e=0,f=0,g=0,h=0,i=0;b[4853032]=(b[4853032]|0)-2&65535;d=c[2426516]|0;e=a[9706060]|0;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+((d>>>8|256)<<2)>>2]|0;do{if((g|0)==0){h=c[f+4184>>2]|0;if((h|0)==0){i=f;break}gg[h&4095](d&65535,e);i=c[9757320+(c[1836236]<<2)>>2]|0}else{a[g+(d&255)|0]=e;i=f}}while(0);f=d+1|0;d=a[9706061]|0;e=c[i+76+((f>>>8&255|256)<<2)>>2]|0;if((e|0)!=0){a[e+(f&255)|0]=d;c[2426515]=8;b[4853030]=8;return}e=c[i+4184>>2]|0;if((e|0)==0){c[2426515]=8;b[4853030]=8;return}gg[e&4095](f&65535,d);c[2426515]=8;b[4853030]=8;return}function guw(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if((a[9706068]&1)!=0){return}d=c[2426516]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](d&65535)|0;h=j;i=c[9757320+(c[1836236]<<2)>>2]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9706060]=h;h=d+1|0;d=c[i+76+((h>>>8&255)<<2)>>2]|0;do{if((d|0)==0){e=c[i+4180>>2]|0;if((e|0)==0){k=0;break}k=gj[e&4095](h&65535)|0}else{k=a[d+(h&255)|0]|0}}while(0);a[9706061]=k;b[4853032]=(b[4853032]|0)+2&65535;b[4853030]=c[2426515]&65535;c[2076596]=(c[2076596]|0)-6;return}function gux(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[2426516]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](d&65535)|0;h=j;i=c[9757320+(c[1836236]<<2)>>2]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9706076]=h;h=d+1|0;d=c[i+76+((h>>>8&255)<<2)>>2]|0;do{if((d|0)==0){e=c[i+4180>>2]|0;if((e|0)==0){k=0;break}k=gj[e&4095](h&65535)|0}else{k=a[d+(h&255)|0]|0}}while(0);a[9706077]=k;b[4853032]=(b[4853032]|0)+2&65535;return}function guy(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((a[9706068]&1)!=0){d=(b[4853030]|0)+2&65535;b[4853030]=d;return}e=c[2426515]|0;f=e&65535;b[4853030]=f+2&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=j&255;j=e+1|0;e=c[k+76+((j>>>8&255|768)<<2)>>2]|0;do{if((e|0)==0){h=c[k+4180>>2]|0;if((h|0)==0){m=0;break}m=gj[h&4095](j&65535)|0}else{m=a[e+(j&255)|0]|0}}while(0);j=(m&255)<<8|g;c[2426515]=j;d=j&65535;b[4853030]=d;return}function guz(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[2426515]|0;e=d&65535;b[4853030]=e+1&65535;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+((d>>>8|768)<<2)>>2]|0;do{if((g|0)==0){h=c[f+4180>>2]|0;if((h|0)==0){i=0;j=f;break}k=gj[h&4095](e)|0;i=k;j=c[9757320+(c[1836236]<<2)>>2]|0}else{i=a[g+(d&255)|0]|0;j=f}}while(0);f=a[9706069]|0;gg[c[j+4176>>2]&4095]((f&255)<<8|i&255,f);return}function guA(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((a[9706068]&1)!=0){d=(b[4853030]|0)+2&65535;b[4853030]=d;return}e=c[2426515]|0;f=e&65535;b[4853030]=f+2&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=j&255;j=e+1|0;e=c[k+76+((j>>>8&255|768)<<2)>>2]|0;do{if((e|0)==0){h=c[k+4180>>2]|0;if((h|0)==0){m=0;n=k;break}f=gj[h&4095](j&65535)|0;m=f;n=c[9757320+(c[1836236]<<2)>>2]|0}else{m=a[e+(j&255)|0]|0;n=k}}while(0);c[3541536]=(m&255)<<8|g;b[4853032]=(b[4853032]|0)-2&65535;g=c[2426516]|0;m=a[9706060]|0;k=c[n+76+((g>>>8|256)<<2)>>2]|0;do{if((k|0)==0){j=c[n+4184>>2]|0;if((j|0)==0){o=n;break}gg[j&4095](g&65535,m);o=c[9757320+(c[1836236]<<2)>>2]|0}else{a[k+(g&255)|0]=m;o=n}}while(0);n=g+1|0;g=a[9706061]|0;m=c[o+76+((n>>>8&255|256)<<2)>>2]|0;do{if((m|0)==0){k=c[o+4184>>2]|0;if((k|0)==0){break}gg[k&4095](n&65535,g)}else{a[m+(n&255)|0]=g}}while(0);g=c[3541536]|0;c[2426515]=g;c[2076596]=(c[2076596]|0)-7;d=g&65535;b[4853030]=d;return}function guB(){var d=0,e=0,f=0,g=0,h=0,i=0;b[4853032]=(b[4853032]|0)-2&65535;d=c[2426516]|0;e=a[9706076]|0;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+((d>>>8|256)<<2)>>2]|0;do{if((g|0)==0){h=c[f+4184>>2]|0;if((h|0)==0){i=f;break}gg[h&4095](d&65535,e);i=c[9757320+(c[1836236]<<2)>>2]|0}else{a[g+(d&255)|0]=e;i=f}}while(0);f=d+1|0;d=a[9706077]|0;e=c[i+76+((f>>>8&255|256)<<2)>>2]|0;if((e|0)!=0){a[e+(f&255)|0]=d;return}e=c[i+4184>>2]|0;if((e|0)==0){return}gg[e&4095](f&65535,d);return}function guC(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[2426517]&65280;e=d>>>8;f=c[2426515]|0;g=f&65535;b[4853030]=g+1&65535;h=c[9757320+(c[1836236]<<2)>>2]|0;i=c[h+76+((f>>>8|768)<<2)>>2]|0;do{if((i|0)==0){j=c[h+4180>>2]|0;if((j|0)==0){k=0;break}k=gj[j&4095](g)|0}else{k=a[i+(f&255)|0]|0}}while(0);f=e-(k&255)|0;a[9706068]=a[(c[2385738]|0)+(f&255|d)|0]|0;a[9706069]=f&255;return}function guD(){var d=0,e=0,f=0,g=0,h=0,i=0;b[4853032]=(b[4853032]|0)-2&65535;d=c[2426516]|0;e=a[9706060]|0;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+((d>>>8|256)<<2)>>2]|0;do{if((g|0)==0){h=c[f+4184>>2]|0;if((h|0)==0){i=f;break}gg[h&4095](d&65535,e);i=c[9757320+(c[1836236]<<2)>>2]|0}else{a[g+(d&255)|0]=e;i=f}}while(0);f=d+1|0;d=a[9706061]|0;e=c[i+76+((f>>>8&255|256)<<2)>>2]|0;if((e|0)!=0){a[e+(f&255)|0]=d;c[2426515]=16;b[4853030]=16;return}e=c[i+4184>>2]|0;if((e|0)==0){c[2426515]=16;b[4853030]=16;return}gg[e&4095](f&65535,d);c[2426515]=16;b[4853030]=16;return}function guE(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if((a[9706068]&1)==0){return}d=c[2426516]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](d&65535)|0;h=j;i=c[9757320+(c[1836236]<<2)>>2]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9706060]=h;h=d+1|0;d=c[i+76+((h>>>8&255)<<2)>>2]|0;do{if((d|0)==0){e=c[i+4180>>2]|0;if((e|0)==0){k=0;break}k=gj[e&4095](h&65535)|0}else{k=a[d+(h&255)|0]|0}}while(0);a[9706061]=k;b[4853032]=(b[4853032]|0)+2&65535;b[4853030]=c[2426515]&65535;c[2076596]=(c[2076596]|0)-6;return}function guF(){var a=0;a=c[2426518]|0;c[2426518]=c[2426524];c[2426524]=a;a=c[2426519]|0;c[2426519]=c[2426525];c[2426525]=a;a=c[2426520]|0;c[2426520]=c[2426526];c[2426526]=a;return}function guG(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((a[9706068]&1)==0){d=(b[4853030]|0)+2&65535;b[4853030]=d;return}e=c[2426515]|0;f=e&65535;b[4853030]=f+2&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=j&255;j=e+1|0;e=c[k+76+((j>>>8&255|768)<<2)>>2]|0;do{if((e|0)==0){h=c[k+4180>>2]|0;if((h|0)==0){m=0;break}m=gj[h&4095](j&65535)|0}else{m=a[e+(j&255)|0]|0}}while(0);j=(m&255)<<8|g;c[2426515]=j;d=j&65535;b[4853030]=d;return}function guH(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=c[2426515]|0;f=e&65535;b[4853030]=f+1&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);a[9706069]=gj[c[k+4172>>2]&4095]((d[9706069]|0)<<8|j&255)|0;return}function guI(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((a[9706068]&1)==0){d=(b[4853030]|0)+2&65535;b[4853030]=d;return}e=c[2426515]|0;f=e&65535;b[4853030]=f+2&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=j&255;j=e+1|0;e=c[k+76+((j>>>8&255|768)<<2)>>2]|0;do{if((e|0)==0){h=c[k+4180>>2]|0;if((h|0)==0){m=0;n=k;break}f=gj[h&4095](j&65535)|0;m=f;n=c[9757320+(c[1836236]<<2)>>2]|0}else{m=a[e+(j&255)|0]|0;n=k}}while(0);c[3541536]=(m&255)<<8|g;b[4853032]=(b[4853032]|0)-2&65535;g=c[2426516]|0;m=a[9706060]|0;k=c[n+76+((g>>>8|256)<<2)>>2]|0;do{if((k|0)==0){j=c[n+4184>>2]|0;if((j|0)==0){o=n;break}gg[j&4095](g&65535,m);o=c[9757320+(c[1836236]<<2)>>2]|0}else{a[k+(g&255)|0]=m;o=n}}while(0);n=g+1|0;g=a[9706061]|0;m=c[o+76+((n>>>8&255|256)<<2)>>2]|0;do{if((m|0)==0){k=c[o+4184>>2]|0;if((k|0)==0){break}gg[k&4095](n&65535,g)}else{a[m+(n&255)|0]=g}}while(0);g=c[3541536]|0;c[2426515]=g;c[2076596]=(c[2076596]|0)-7;d=g&65535;b[4853030]=d;return}function guJ(){var e=0,f=0,g=0,h=0,i=0,j=0;a[9706108]=(a[9706108]|0)+1&255;e=c[2426515]|0;f=e&65535;b[4853030]=f+1&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;break}j=gj[i&4095](f)|0}else{j=a[h+(e&255)|0]|0}}while(0);e=j&255;c[2076596]=(c[2076596]|0)-(d[(c[2426878]|0)+e|0]|0);gu[c[676896+(e<<2)>>2]&16383]();return}function guK(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[2426517]|0;e=d&65280;f=d&1;d=e>>>8;g=c[2426515]|0;h=g&65535;b[4853030]=h+1&65535;i=c[9757320+(c[1836236]<<2)>>2]|0;j=c[i+76+((g>>>8|768)<<2)>>2]|0;do{if((j|0)==0){k=c[i+4180>>2]|0;if((k|0)==0){l=0;break}l=gj[k&4095](h)|0}else{l=a[j+(g&255)|0]|0}}while(0);g=d-(l&255)-f|0;a[9706068]=a[(c[2385738]|0)+(f<<16|e|g&255)|0]|0;a[9706069]=g&255;return}function guL(){var d=0,e=0,f=0,g=0,h=0,i=0;b[4853032]=(b[4853032]|0)-2&65535;d=c[2426516]|0;e=a[9706060]|0;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+((d>>>8|256)<<2)>>2]|0;do{if((g|0)==0){h=c[f+4184>>2]|0;if((h|0)==0){i=f;break}gg[h&4095](d&65535,e);i=c[9757320+(c[1836236]<<2)>>2]|0}else{a[g+(d&255)|0]=e;i=f}}while(0);f=d+1|0;d=a[9706061]|0;e=c[i+76+((f>>>8&255|256)<<2)>>2]|0;if((e|0)!=0){a[e+(f&255)|0]=d;c[2426515]=24;b[4853030]=24;return}e=c[i+4184>>2]|0;if((e|0)==0){c[2426515]=24;b[4853030]=24;return}gg[e&4095](f&65535,d);c[2426515]=24;b[4853030]=24;return}function guM(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if((a[9706068]&4)!=0){return}d=c[2426516]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](d&65535)|0;h=j;i=c[9757320+(c[1836236]<<2)>>2]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9706060]=h;h=d+1|0;d=c[i+76+((h>>>8&255)<<2)>>2]|0;do{if((d|0)==0){e=c[i+4180>>2]|0;if((e|0)==0){k=0;break}k=gj[e&4095](h&65535)|0}else{k=a[d+(h&255)|0]|0}}while(0);a[9706061]=k;b[4853032]=(b[4853032]|0)+2&65535;b[4853030]=c[2426515]&65535;c[2076596]=(c[2076596]|0)-6;return}function guN(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[2426516]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](d&65535)|0;h=j;i=c[9757320+(c[1836236]<<2)>>2]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9706084]=h;h=d+1|0;d=c[i+76+((h>>>8&255)<<2)>>2]|0;do{if((d|0)==0){e=c[i+4180>>2]|0;if((e|0)==0){k=0;break}k=gj[e&4095](h&65535)|0}else{k=a[d+(h&255)|0]|0}}while(0);a[9706085]=k;b[4853032]=(b[4853032]|0)+2&65535;return}function guO(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((a[9706068]&4)!=0){d=(b[4853030]|0)+2&65535;b[4853030]=d;return}e=c[2426515]|0;f=e&65535;b[4853030]=f+2&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=j&255;j=e+1|0;e=c[k+76+((j>>>8&255|768)<<2)>>2]|0;do{if((e|0)==0){h=c[k+4180>>2]|0;if((h|0)==0){m=0;break}m=gj[h&4095](j&65535)|0}else{m=a[e+(j&255)|0]|0}}while(0);j=(m&255)<<8|g;c[2426515]=j;d=j&65535;b[4853030]=d;return}function guP(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=c[2426516]|0;d=c[9757320+(c[1836236]<<2)>>2]|0;e=c[d+76+(b>>>8<<2)>>2]|0;do{if((e|0)==0){f=c[d+4180>>2]|0;if((f|0)==0){g=0;h=d;break}i=gj[f&4095](b&65535)|0;g=i;h=c[9757320+(c[1836236]<<2)>>2]|0}else{g=a[e+(b&255)|0]|0;h=d}}while(0);d=b+1|0;b=c[h+76+((d>>>8&255)<<2)>>2]|0;do{if((b|0)==0){e=c[h+4180>>2]|0;if((e|0)==0){j=0;k=h;break}i=gj[e&4095](d&65535)|0;j=i;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[b+(d&255)|0]|0;k=h}}while(0);h=c[2426516]|0;d=a[9706084]|0;b=c[k+76+((h>>>8|256)<<2)>>2]|0;do{if((b|0)==0){i=c[k+4184>>2]|0;if((i|0)==0){l=k;break}gg[i&4095](h&65535,d);l=c[9757320+(c[1836236]<<2)>>2]|0}else{a[b+(h&255)|0]=d;l=k}}while(0);k=h+1|0;h=a[9706085]|0;d=c[l+76+((k>>>8&255|256)<<2)>>2]|0;do{if((d|0)==0){b=c[l+4184>>2]|0;if((b|0)==0){break}gg[b&4095](k&65535,h)}else{a[d+(k&255)|0]=h}}while(0);c[2426521]=(j&255)<<8|g&255;return}function guQ(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((a[9706068]&4)!=0){d=(b[4853030]|0)+2&65535;b[4853030]=d;return}e=c[2426515]|0;f=e&65535;b[4853030]=f+2&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=j&255;j=e+1|0;e=c[k+76+((j>>>8&255|768)<<2)>>2]|0;do{if((e|0)==0){h=c[k+4180>>2]|0;if((h|0)==0){m=0;n=k;break}f=gj[h&4095](j&65535)|0;m=f;n=c[9757320+(c[1836236]<<2)>>2]|0}else{m=a[e+(j&255)|0]|0;n=k}}while(0);c[3541536]=(m&255)<<8|g;b[4853032]=(b[4853032]|0)-2&65535;g=c[2426516]|0;m=a[9706060]|0;k=c[n+76+((g>>>8|256)<<2)>>2]|0;do{if((k|0)==0){j=c[n+4184>>2]|0;if((j|0)==0){o=n;break}gg[j&4095](g&65535,m);o=c[9757320+(c[1836236]<<2)>>2]|0}else{a[k+(g&255)|0]=m;o=n}}while(0);n=g+1|0;g=a[9706061]|0;m=c[o+76+((n>>>8&255|256)<<2)>>2]|0;do{if((m|0)==0){k=c[o+4184>>2]|0;if((k|0)==0){break}gg[k&4095](n&65535,g)}else{a[m+(n&255)|0]=g}}while(0);g=c[3541536]|0;c[2426515]=g;c[2076596]=(c[2076596]|0)-7;d=g&65535;b[4853030]=d;return}function guR(){var d=0,e=0,f=0,g=0,h=0,i=0;b[4853032]=(b[4853032]|0)-2&65535;d=c[2426516]|0;e=a[9706084]|0;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+((d>>>8|256)<<2)>>2]|0;do{if((g|0)==0){h=c[f+4184>>2]|0;if((h|0)==0){i=f;break}gg[h&4095](d&65535,e);i=c[9757320+(c[1836236]<<2)>>2]|0}else{a[g+(d&255)|0]=e;i=f}}while(0);f=d+1|0;d=a[9706085]|0;e=c[i+76+((f>>>8&255|256)<<2)>>2]|0;if((e|0)!=0){a[e+(f&255)|0]=d;return}e=c[i+4184>>2]|0;if((e|0)==0){return}gg[e&4095](f&65535,d);return}function guS(){var d=0,e=0,f=0,g=0,h=0,i=0;d=c[2426515]|0;e=d&65535;b[4853030]=e+1&65535;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+((d>>>8|768)<<2)>>2]|0;do{if((g|0)==0){h=c[f+4180>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](e)|0}else{i=a[g+(d&255)|0]|0}}while(0);d=a[9706069]&i;a[9706069]=d;a[9706068]=a[9706144+(d&255)|0]|16;return}function guT(){var d=0,e=0,f=0,g=0,h=0,i=0;b[4853032]=(b[4853032]|0)-2&65535;d=c[2426516]|0;e=a[9706060]|0;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+((d>>>8|256)<<2)>>2]|0;do{if((g|0)==0){h=c[f+4184>>2]|0;if((h|0)==0){i=f;break}gg[h&4095](d&65535,e);i=c[9757320+(c[1836236]<<2)>>2]|0}else{a[g+(d&255)|0]=e;i=f}}while(0);f=d+1|0;d=a[9706061]|0;e=c[i+76+((f>>>8&255|256)<<2)>>2]|0;if((e|0)!=0){a[e+(f&255)|0]=d;c[2426515]=32;b[4853030]=32;return}e=c[i+4184>>2]|0;if((e|0)==0){c[2426515]=32;b[4853030]=32;return}gg[e&4095](f&65535,d);c[2426515]=32;b[4853030]=32;return}function guU(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if((a[9706068]&4)==0){return}d=c[2426516]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](d&65535)|0;h=j;i=c[9757320+(c[1836236]<<2)>>2]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9706060]=h;h=d+1|0;d=c[i+76+((h>>>8&255)<<2)>>2]|0;do{if((d|0)==0){e=c[i+4180>>2]|0;if((e|0)==0){k=0;break}k=gj[e&4095](h&65535)|0}else{k=a[d+(h&255)|0]|0}}while(0);a[9706061]=k;b[4853032]=(b[4853032]|0)+2&65535;b[4853030]=c[2426515]&65535;c[2076596]=(c[2076596]|0)-6;return}function guV(){b[4853030]=b[4853042]|0;b[4853030]=c[2426515]&65535;return}function guW(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((a[9706068]&4)==0){d=(b[4853030]|0)+2&65535;b[4853030]=d;return}e=c[2426515]|0;f=e&65535;b[4853030]=f+2&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=j&255;j=e+1|0;e=c[k+76+((j>>>8&255|768)<<2)>>2]|0;do{if((e|0)==0){h=c[k+4180>>2]|0;if((h|0)==0){m=0;break}m=gj[h&4095](j&65535)|0}else{m=a[e+(j&255)|0]|0}}while(0);j=(m&255)<<8|g;c[2426515]=j;d=j&65535;b[4853030]=d;return}function guX(){var a=0;a=c[2426519]|0;c[2426519]=c[2426520];c[2426520]=a;return}function guY(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((a[9706068]&4)==0){d=(b[4853030]|0)+2&65535;b[4853030]=d;return}e=c[2426515]|0;f=e&65535;b[4853030]=f+2&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=j&255;j=e+1|0;e=c[k+76+((j>>>8&255|768)<<2)>>2]|0;do{if((e|0)==0){h=c[k+4180>>2]|0;if((h|0)==0){m=0;n=k;break}f=gj[h&4095](j&65535)|0;m=f;n=c[9757320+(c[1836236]<<2)>>2]|0}else{m=a[e+(j&255)|0]|0;n=k}}while(0);c[3541536]=(m&255)<<8|g;b[4853032]=(b[4853032]|0)-2&65535;g=c[2426516]|0;m=a[9706060]|0;k=c[n+76+((g>>>8|256)<<2)>>2]|0;do{if((k|0)==0){j=c[n+4184>>2]|0;if((j|0)==0){o=n;break}gg[j&4095](g&65535,m);o=c[9757320+(c[1836236]<<2)>>2]|0}else{a[k+(g&255)|0]=m;o=n}}while(0);n=g+1|0;g=a[9706061]|0;m=c[o+76+((n>>>8&255|256)<<2)>>2]|0;do{if((m|0)==0){k=c[o+4184>>2]|0;if((k|0)==0){break}gg[k&4095](n&65535,g)}else{a[m+(n&255)|0]=g}}while(0);g=c[3541536]|0;c[2426515]=g;c[2076596]=(c[2076596]|0)-7;d=g&65535;b[4853030]=d;return}function guZ(){var e=0,f=0,g=0,h=0,i=0,j=0;a[9706108]=(a[9706108]|0)+1&255;e=c[2426515]|0;f=e&65535;b[4853030]=f+1&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;break}j=gj[i&4095](f)|0}else{j=a[h+(e&255)|0]|0}}while(0);e=j&255;c[2076596]=(c[2076596]|0)-(d[(c[2426880]|0)+e|0]|0);gu[c[675872+(e<<2)>>2]&16383]();return}function gu_(){var d=0,e=0,f=0,g=0,h=0,i=0;d=c[2426515]|0;e=d&65535;b[4853030]=e+1&65535;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+((d>>>8|768)<<2)>>2]|0;do{if((g|0)==0){h=c[f+4180>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](e)|0}else{i=a[g+(d&255)|0]|0}}while(0);d=a[9706069]^i;a[9706069]=d;a[9706068]=a[9706144+(d&255)|0]|0;return}function gu$(){var d=0,e=0,f=0,g=0,h=0,i=0;b[4853032]=(b[4853032]|0)-2&65535;d=c[2426516]|0;e=a[9706060]|0;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+((d>>>8|256)<<2)>>2]|0;do{if((g|0)==0){h=c[f+4184>>2]|0;if((h|0)==0){i=f;break}gg[h&4095](d&65535,e);i=c[9757320+(c[1836236]<<2)>>2]|0}else{a[g+(d&255)|0]=e;i=f}}while(0);f=d+1|0;d=a[9706061]|0;e=c[i+76+((f>>>8&255|256)<<2)>>2]|0;if((e|0)!=0){a[e+(f&255)|0]=d;c[2426515]=40;b[4853030]=40;return}e=c[i+4184>>2]|0;if((e|0)==0){c[2426515]=40;b[4853030]=40;return}gg[e&4095](f&65535,d);c[2426515]=40;b[4853030]=40;return}function gu0(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if((a[9706068]|0)<0){return}d=c[2426516]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](d&65535)|0;h=j;i=c[9757320+(c[1836236]<<2)>>2]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9706060]=h;h=d+1|0;d=c[i+76+((h>>>8&255)<<2)>>2]|0;do{if((d|0)==0){e=c[i+4180>>2]|0;if((e|0)==0){k=0;break}k=gj[e&4095](h&65535)|0}else{k=a[d+(h&255)|0]|0}}while(0);a[9706061]=k;b[4853032]=(b[4853032]|0)+2&65535;b[4853030]=c[2426515]&65535;c[2076596]=(c[2076596]|0)-6;return}function gu1(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[2426516]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](d&65535)|0;h=j;i=c[9757320+(c[1836236]<<2)>>2]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9706068]=h;h=d+1|0;d=c[i+76+((h>>>8&255)<<2)>>2]|0;do{if((d|0)==0){e=c[i+4180>>2]|0;if((e|0)==0){k=0;break}k=gj[e&4095](h&65535)|0}else{k=a[d+(h&255)|0]|0}}while(0);a[9706069]=k;b[4853032]=(b[4853032]|0)+2&65535;return}function gu2(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((a[9706068]|0)<0){d=(b[4853030]|0)+2&65535;b[4853030]=d;return}e=c[2426515]|0;f=e&65535;b[4853030]=f+2&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=j&255;j=e+1|0;e=c[k+76+((j>>>8&255|768)<<2)>>2]|0;do{if((e|0)==0){h=c[k+4180>>2]|0;if((h|0)==0){m=0;break}m=gj[h&4095](j&65535)|0}else{m=a[e+(j&255)|0]|0}}while(0);j=(m&255)<<8|g;c[2426515]=j;d=j&65535;b[4853030]=d;return}function gu3(){a[9706111]=0;a[9706110]=0;return}function gu4(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((a[9706068]|0)<0){d=(b[4853030]|0)+2&65535;b[4853030]=d;return}e=c[2426515]|0;f=e&65535;b[4853030]=f+2&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=j&255;j=e+1|0;e=c[k+76+((j>>>8&255|768)<<2)>>2]|0;do{if((e|0)==0){h=c[k+4180>>2]|0;if((h|0)==0){m=0;n=k;break}f=gj[h&4095](j&65535)|0;m=f;n=c[9757320+(c[1836236]<<2)>>2]|0}else{m=a[e+(j&255)|0]|0;n=k}}while(0);c[3541536]=(m&255)<<8|g;b[4853032]=(b[4853032]|0)-2&65535;g=c[2426516]|0;m=a[9706060]|0;k=c[n+76+((g>>>8|256)<<2)>>2]|0;do{if((k|0)==0){j=c[n+4184>>2]|0;if((j|0)==0){o=n;break}gg[j&4095](g&65535,m);o=c[9757320+(c[1836236]<<2)>>2]|0}else{a[k+(g&255)|0]=m;o=n}}while(0);n=g+1|0;g=a[9706061]|0;m=c[o+76+((n>>>8&255|256)<<2)>>2]|0;do{if((m|0)==0){k=c[o+4184>>2]|0;if((k|0)==0){break}gg[k&4095](n&65535,g)}else{a[m+(n&255)|0]=g}}while(0);g=c[3541536]|0;c[2426515]=g;c[2076596]=(c[2076596]|0)-7;d=g&65535;b[4853030]=d;return}function gu5(){var d=0,e=0,f=0,g=0,h=0,i=0;b[4853032]=(b[4853032]|0)-2&65535;d=c[2426516]|0;e=a[9706068]|0;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+((d>>>8|256)<<2)>>2]|0;do{if((g|0)==0){h=c[f+4184>>2]|0;if((h|0)==0){i=f;break}gg[h&4095](d&65535,e);i=c[9757320+(c[1836236]<<2)>>2]|0}else{a[g+(d&255)|0]=e;i=f}}while(0);f=d+1|0;d=a[9706069]|0;e=c[i+76+((f>>>8&255|256)<<2)>>2]|0;if((e|0)!=0){a[e+(f&255)|0]=d;return}e=c[i+4184>>2]|0;if((e|0)==0){return}gg[e&4095](f&65535,d);return}function gu6(){var d=0,e=0,f=0,g=0,h=0,i=0;d=c[2426515]|0;e=d&65535;b[4853030]=e+1&65535;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+((d>>>8|768)<<2)>>2]|0;do{if((g|0)==0){h=c[f+4180>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](e)|0}else{i=a[g+(d&255)|0]|0}}while(0);d=a[9706069]|i;a[9706069]=d;a[9706068]=a[9706144+(d&255)|0]|0;return}function gu7(){var d=0,e=0,f=0,g=0,h=0,i=0;b[4853032]=(b[4853032]|0)-2&65535;d=c[2426516]|0;e=a[9706060]|0;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+((d>>>8|256)<<2)>>2]|0;do{if((g|0)==0){h=c[f+4184>>2]|0;if((h|0)==0){i=f;break}gg[h&4095](d&65535,e);i=c[9757320+(c[1836236]<<2)>>2]|0}else{a[g+(d&255)|0]=e;i=f}}while(0);f=d+1|0;d=a[9706061]|0;e=c[i+76+((f>>>8&255|256)<<2)>>2]|0;if((e|0)!=0){a[e+(f&255)|0]=d;c[2426515]=48;b[4853030]=48;return}e=c[i+4184>>2]|0;if((e|0)==0){c[2426515]=48;b[4853030]=48;return}gg[e&4095](f&65535,d);c[2426515]=48;b[4853030]=48;return}function gu8(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if((a[9706068]|0)>=0){return}d=c[2426516]|0;e=c[9757320+(c[1836236]<<2)>>2]|0;f=c[e+76+(d>>>8<<2)>>2]|0;do{if((f|0)==0){g=c[e+4180>>2]|0;if((g|0)==0){h=0;i=e;break}j=gj[g&4095](d&65535)|0;h=j;i=c[9757320+(c[1836236]<<2)>>2]|0}else{h=a[f+(d&255)|0]|0;i=e}}while(0);a[9706060]=h;h=d+1|0;d=c[i+76+((h>>>8&255)<<2)>>2]|0;do{if((d|0)==0){e=c[i+4180>>2]|0;if((e|0)==0){k=0;break}k=gj[e&4095](h&65535)|0}else{k=a[d+(h&255)|0]|0}}while(0);a[9706061]=k;b[4853032]=(b[4853032]|0)+2&65535;b[4853030]=c[2426515]&65535;c[2076596]=(c[2076596]|0)-6;return}function gu9(){b[4853032]=b[4853042]|0;return}function gva(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((a[9706068]|0)>=0){d=(b[4853030]|0)+2&65535;b[4853030]=d;return}e=c[2426515]|0;f=e&65535;b[4853030]=f+2&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=j&255;j=e+1|0;e=c[k+76+((j>>>8&255|768)<<2)>>2]|0;do{if((e|0)==0){h=c[k+4180>>2]|0;if((h|0)==0){m=0;break}m=gj[h&4095](j&65535)|0}else{m=a[e+(j&255)|0]|0}}while(0);j=(m&255)<<8|g;c[2426515]=j;d=j&65535;b[4853030]=d;return}function gvb(){a[9706111]=1;a[9706110]=1;a[9706118]=1;return}function gvc(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((a[9706068]|0)>=0){d=(b[4853030]|0)+2&65535;b[4853030]=d;return}e=c[2426515]|0;f=e&65535;b[4853030]=f+2&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|768)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](f)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=j&255;j=e+1|0;e=c[k+76+((j>>>8&255|768)<<2)>>2]|0;do{if((e|0)==0){h=c[k+4180>>2]|0;if((h|0)==0){m=0;n=k;break}f=gj[h&4095](j&65535)|0;m=f;n=c[9757320+(c[1836236]<<2)>>2]|0}else{m=a[e+(j&255)|0]|0;n=k}}while(0);c[3541536]=(m&255)<<8|g;b[4853032]=(b[4853032]|0)-2&65535;g=c[2426516]|0;m=a[9706060]|0;k=c[n+76+((g>>>8|256)<<2)>>2]|0;do{if((k|0)==0){j=c[n+4184>>2]|0;if((j|0)==0){o=n;break}gg[j&4095](g&65535,m);o=c[9757320+(c[1836236]<<2)>>2]|0}else{a[k+(g&255)|0]=m;o=n}}while(0);n=g+1|0;g=a[9706061]|0;m=c[o+76+((n>>>8&255|256)<<2)>>2]|0;do{if((m|0)==0){k=c[o+4184>>2]|0;if((k|0)==0){break}gg[k&4095](n&65535,g)}else{a[m+(n&255)|0]=g}}while(0);g=c[3541536]|0;c[2426515]=g;c[2076596]=(c[2076596]|0)-7;d=g&65535;b[4853030]=d;return}function gvd(){var e=0,f=0,g=0,h=0,i=0,j=0;a[9706108]=(a[9706108]|0)+1&255;e=c[2426515]|0;f=e&65535;b[4853030]=f+1&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+((e>>>8|512)<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;break}j=gj[i&4095](f)|0}else{j=a[h+(e&255)|0]|0}}while(0);e=j&255;c[2076596]=(c[2076596]|0)-(d[(c[2426878]|0)+e|0]|0);gu[c[674848+(e<<2)>>2]&16383]();return}function gve(){var d=0,e=0,f=0,g=0,h=0,i=0;d=c[2426515]|0;e=d&65535;b[4853030]=e+1&65535;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+((d>>>8|768)<<2)>>2]|0;do{if((g|0)==0){h=c[f+4180>>2]|0;if((h|0)==0){i=0;break}i=gj[h&4095](e)|0}else{i=a[g+(d&255)|0]|0}}while(0);d=c[2426517]&65280;a[9706068]=a[(c[2385738]|0)+((d>>>8)-(i&255)&255|d)|0]&-41|i&40;return}function gvf(){var d=0,e=0,f=0,g=0,h=0,i=0;b[4853032]=(b[4853032]|0)-2&65535;d=c[2426516]|0;e=a[9706060]|0;f=c[9757320+(c[1836236]<<2)>>2]|0;g=c[f+76+((d>>>8|256)<<2)>>2]|0;do{if((g|0)==0){h=c[f+4184>>2]|0;if((h|0)==0){i=f;break}gg[h&4095](d&65535,e);i=c[9757320+(c[1836236]<<2)>>2]|0}else{a[g+(d&255)|0]=e;i=f}}while(0);f=d+1|0;d=a[9706061]|0;e=c[i+76+((f>>>8&255|256)<<2)>>2]|0;if((e|0)!=0){a[e+(f&255)|0]=d;c[2426515]=56;b[4853030]=56;return}e=c[i+4184>>2]|0;if((e|0)==0){c[2426515]=56;b[4853030]=56;return}gg[e&4095](f&65535,d);c[2426515]=56;b[4853030]=56;return}function gvg(){var b=0,c=0,d=0;b=a[9706073]|0;c=b&255;d=c<<1&254|c>>>7;a[9706068]=a[9706144+d|0]|(b&255)>>>7;a[9706073]=d&255;return}function gvh(){var b=0,c=0,d=0;b=a[9706072]|0;c=b&255;d=c<<1&254|c>>>7;a[9706068]=a[9706144+d|0]|(b&255)>>>7;a[9706072]=d&255;return}function gvi(){var b=0,c=0,d=0;b=a[9706077]|0;c=b&255;d=c<<1&254|c>>>7;a[9706068]=a[9706144+d|0]|(b&255)>>>7;a[9706077]=d&255;return}function gvj(){var b=0,c=0,d=0;b=a[9706076]|0;c=b&255;d=c<<1&254|c>>>7;a[9706068]=a[9706144+d|0]|(b&255)>>>7;a[9706076]=d&255;return}function gvk(){var b=0,c=0,d=0;b=a[9706081]|0;c=b&255;d=c<<1&254|c>>>7;a[9706068]=a[9706144+d|0]|(b&255)>>>7;a[9706081]=d&255;return}function gvl(){var b=0,c=0,d=0;b=a[9706080]|0;c=b&255;d=c<<1&254|c>>>7;a[9706068]=a[9706144+d|0]|(b&255)>>>7;a[9706080]=d&255;return}function gvm(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[4853040]|0;e=d&65535;f=e>>>8;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+(f<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](d)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=j&255;h=g<<1&254|g>>>7;a[9706068]=a[9706144+h|0]|(j&255)>>>7;j=h&255;h=c[k+76+((f|256)<<2)>>2]|0;if((h|0)!=0){a[h+(e&255)|0]=j;return}e=c[k+4184>>2]|0;if((e|0)==0){return}gg[e&4095](d,j);return}function gvn(){var b=0,c=0,d=0;b=a[9706069]|0;c=b&255;d=c<<1&254|c>>>7;a[9706068]=a[9706144+d|0]|(b&255)>>>7;a[9706069]=d&255;return}function gvo(){var b=0,c=0,d=0;b=a[9706073]|0;c=b&255;d=c<<7&128|c>>>1;a[9706068]=a[9706144+d|0]|b&1;a[9706073]=d&255;return}function gvp(){var b=0,c=0,d=0;b=a[9706072]|0;c=b&255;d=c<<7&128|c>>>1;a[9706068]=a[9706144+d|0]|b&1;a[9706072]=d&255;return}function gvq(){var b=0,c=0,d=0;b=a[9706077]|0;c=b&255;d=c<<7&128|c>>>1;a[9706068]=a[9706144+d|0]|b&1;a[9706077]=d&255;return}function gvr(){var b=0,c=0,d=0;b=a[9706076]|0;c=b&255;d=c<<7&128|c>>>1;a[9706068]=a[9706144+d|0]|b&1;a[9706076]=d&255;return}function gvs(){var b=0,c=0,d=0;b=a[9706081]|0;c=b&255;d=c<<7&128|c>>>1;a[9706068]=a[9706144+d|0]|b&1;a[9706081]=d&255;return}function gvt(){var b=0,c=0,d=0;b=a[9706080]|0;c=b&255;d=c<<7&128|c>>>1;a[9706068]=a[9706144+d|0]|b&1;a[9706080]=d&255;return}function gvu(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[4853040]|0;e=d&65535;f=e>>>8;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+(f<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](d)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=j&255;h=g<<7&128|g>>>1;a[9706068]=a[9706144+h|0]|j&1;j=h&255;h=c[k+76+((f|256)<<2)>>2]|0;if((h|0)!=0){a[h+(e&255)|0]=j;return}e=c[k+4184>>2]|0;if((e|0)==0){return}gg[e&4095](d,j);return}function gvv(){var b=0,c=0,d=0;b=a[9706069]|0;c=b&255;d=c<<7&128|c>>>1;a[9706068]=a[9706144+d|0]|b&1;a[9706069]=d&255;return}function gvw(){var b=0,c=0;b=a[9706073]|0;c=a[9706068]&1|(b&255)<<1&254;a[9706068]=a[9706144+c|0]|(b&255)>>>7;a[9706073]=c&255;return}function gvx(){var b=0,c=0;b=a[9706072]|0;c=a[9706068]&1|(b&255)<<1&254;a[9706068]=a[9706144+c|0]|(b&255)>>>7;a[9706072]=c&255;return}function gvy(){var b=0,c=0;b=a[9706077]|0;c=a[9706068]&1|(b&255)<<1&254;a[9706068]=a[9706144+c|0]|(b&255)>>>7;a[9706077]=c&255;return}function gvz(){var b=0,c=0;b=a[9706076]|0;c=a[9706068]&1|(b&255)<<1&254;a[9706068]=a[9706144+c|0]|(b&255)>>>7;a[9706076]=c&255;return}function gvA(){var b=0,c=0;b=a[9706081]|0;c=a[9706068]&1|(b&255)<<1&254;a[9706068]=a[9706144+c|0]|(b&255)>>>7;a[9706081]=c&255;return}function gvB(){var b=0,c=0;b=a[9706080]|0;c=a[9706068]&1|(b&255)<<1&254;a[9706068]=a[9706144+c|0]|(b&255)>>>7;a[9706080]=c&255;return}function gvC(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[4853040]|0;e=d&65535;f=e>>>8;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+(f<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](d)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=a[9706068]&1|(j&255)<<1&254;a[9706068]=a[9706144+g|0]|(j&255)>>>7;j=g&255;g=c[k+76+((f|256)<<2)>>2]|0;if((g|0)!=0){a[g+(e&255)|0]=j;return}e=c[k+4184>>2]|0;if((e|0)==0){return}gg[e&4095](d,j);return}function gvD(){var b=0,c=0;b=a[9706069]|0;c=a[9706068]&1|(b&255)<<1&254;a[9706068]=a[9706144+c|0]|(b&255)>>>7;a[9706069]=c&255;return}function gvE(){var b=0,c=0;b=a[9706073]|0;c=(d[9706068]|0)<<7&128|(b&255)>>>1;a[9706068]=a[9706144+c|0]|b&1;a[9706073]=c&255;return}function gvF(){var b=0,c=0;b=a[9706072]|0;c=(d[9706068]|0)<<7&128|(b&255)>>>1;a[9706068]=a[9706144+c|0]|b&1;a[9706072]=c&255;return}function gvG(){var b=0,c=0;b=a[9706077]|0;c=(d[9706068]|0)<<7&128|(b&255)>>>1;a[9706068]=a[9706144+c|0]|b&1;a[9706077]=c&255;return}function gvH(){var b=0,c=0;b=a[9706076]|0;c=(d[9706068]|0)<<7&128|(b&255)>>>1;a[9706068]=a[9706144+c|0]|b&1;a[9706076]=c&255;return}function gvI(){var b=0,c=0;b=a[9706081]|0;c=(d[9706068]|0)<<7&128|(b&255)>>>1;a[9706068]=a[9706144+c|0]|b&1;a[9706081]=c&255;return}function gvJ(){var b=0,c=0;b=a[9706080]|0;c=(d[9706068]|0)<<7&128|(b&255)>>>1;a[9706068]=a[9706144+c|0]|b&1;a[9706080]=c&255;return}function gvK(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=b[4853040]|0;f=e&65535;g=f>>>8;h=c[9757320+(c[1836236]<<2)>>2]|0;i=c[h+76+(g<<2)>>2]|0;do{if((i|0)==0){j=c[h+4180>>2]|0;if((j|0)==0){k=0;l=h;break}m=gj[j&4095](e)|0;k=m;l=c[9757320+(c[1836236]<<2)>>2]|0}else{k=a[i+(f&255)|0]|0;l=h}}while(0);h=(d[9706068]|0)<<7&128|(k&255)>>>1;a[9706068]=a[9706144+h|0]|k&1;k=h&255;h=c[l+76+((g|256)<<2)>>2]|0;if((h|0)!=0){a[h+(f&255)|0]=k;return}f=c[l+4184>>2]|0;if((f|0)==0){return}gg[f&4095](e,k);return}function gvL(){var b=0,c=0;b=a[9706069]|0;c=(d[9706068]|0)<<7&128|(b&255)>>>1;a[9706068]=a[9706144+c|0]|b&1;a[9706069]=c&255;return}function gvM(){var b=0,c=0;b=a[9706073]|0;c=(b&255)<<1;a[9706068]=a[9706144+(c&254)|0]|(b&255)>>>7;a[9706073]=c&255;return}function gvN(){var b=0,c=0;b=a[9706072]|0;c=(b&255)<<1;a[9706068]=a[9706144+(c&254)|0]|(b&255)>>>7;a[9706072]=c&255;return}function gvO(){var b=0,c=0;b=a[9706077]|0;c=(b&255)<<1;a[9706068]=a[9706144+(c&254)|0]|(b&255)>>>7;a[9706077]=c&255;return}function gvP(){var b=0,c=0;b=a[9706076]|0;c=(b&255)<<1;a[9706068]=a[9706144+(c&254)|0]|(b&255)>>>7;a[9706076]=c&255;return}function gvQ(){var b=0,c=0;b=a[9706081]|0;c=(b&255)<<1;a[9706068]=a[9706144+(c&254)|0]|(b&255)>>>7;a[9706081]=c&255;return}function gvR(){var b=0,c=0;b=a[9706080]|0;c=(b&255)<<1;a[9706068]=a[9706144+(c&254)|0]|(b&255)>>>7;a[9706080]=c&255;return}function gvS(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[4853040]|0;e=d&65535;f=e>>>8;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+(f<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](d)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=(j&255)<<1;a[9706068]=a[9706144+(g&254)|0]|(j&255)>>>7;j=g&255;g=c[k+76+((f|256)<<2)>>2]|0;if((g|0)!=0){a[g+(e&255)|0]=j;return}e=c[k+4184>>2]|0;if((e|0)==0){return}gg[e&4095](d,j);return}function gvT(){var b=0,c=0;b=a[9706069]|0;c=(b&255)<<1;a[9706068]=a[9706144+(c&254)|0]|(b&255)>>>7;a[9706069]=c&255;return}function gvU(){var b=0,c=0,d=0;b=a[9706073]|0;c=b&255;d=c>>>1|c&128;a[9706068]=a[9706144+d|0]|b&1;a[9706073]=d&255;return}function gvV(){var b=0,c=0,d=0;b=a[9706072]|0;c=b&255;d=c>>>1|c&128;a[9706068]=a[9706144+d|0]|b&1;a[9706072]=d&255;return}function gvW(){var b=0,c=0,d=0;b=a[9706077]|0;c=b&255;d=c>>>1|c&128;a[9706068]=a[9706144+d|0]|b&1;a[9706077]=d&255;return}function gvX(){var b=0,c=0,d=0;b=a[9706076]|0;c=b&255;d=c>>>1|c&128;a[9706068]=a[9706144+d|0]|b&1;a[9706076]=d&255;return}function gvY(){var b=0,c=0,d=0;b=a[9706081]|0;c=b&255;d=c>>>1|c&128;a[9706068]=a[9706144+d|0]|b&1;a[9706081]=d&255;return}function gvZ(){var b=0,c=0,d=0;b=a[9706080]|0;c=b&255;d=c>>>1|c&128;a[9706068]=a[9706144+d|0]|b&1;a[9706080]=d&255;return}function gv_(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[4853040]|0;e=d&65535;f=e>>>8;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+(f<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](d)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=j&255;h=g>>>1|g&128;a[9706068]=a[9706144+h|0]|j&1;j=h&255;h=c[k+76+((f|256)<<2)>>2]|0;if((h|0)!=0){a[h+(e&255)|0]=j;return}e=c[k+4184>>2]|0;if((e|0)==0){return}gg[e&4095](d,j);return}function gv$(){var b=0,c=0,d=0;b=a[9706069]|0;c=b&255;d=c>>>1|c&128;a[9706068]=a[9706144+d|0]|b&1;a[9706069]=d&255;return}function gv0(){var b=0,c=0;b=a[9706073]|0;c=(b&255)<<1&254|1;a[9706068]=a[9706144+c|0]|(b&255)>>>7;a[9706073]=c&255;return}function gv1(){var b=0,c=0;b=a[9706072]|0;c=(b&255)<<1&254|1;a[9706068]=a[9706144+c|0]|(b&255)>>>7;a[9706072]=c&255;return}function gv2(){var b=0,c=0;b=a[9706077]|0;c=(b&255)<<1&254|1;a[9706068]=a[9706144+c|0]|(b&255)>>>7;a[9706077]=c&255;return}function gv3(){var b=0,c=0;b=a[9706076]|0;c=(b&255)<<1&254|1;a[9706068]=a[9706144+c|0]|(b&255)>>>7;a[9706076]=c&255;return}function gv4(){var b=0,c=0;b=a[9706081]|0;c=(b&255)<<1&254|1;a[9706068]=a[9706144+c|0]|(b&255)>>>7;a[9706081]=c&255;return}function gv5(){var b=0,c=0;b=a[9706080]|0;c=(b&255)<<1&254|1;a[9706068]=a[9706144+c|0]|(b&255)>>>7;a[9706080]=c&255;return}function gv6(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[4853040]|0;e=d&65535;f=e>>>8;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+(f<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](d)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=(j&255)<<1&254|1;a[9706068]=a[9706144+g|0]|(j&255)>>>7;j=g&255;g=c[k+76+((f|256)<<2)>>2]|0;if((g|0)!=0){a[g+(e&255)|0]=j;return}e=c[k+4184>>2]|0;if((e|0)==0){return}gg[e&4095](d,j);return}function gv7(){var b=0,c=0;b=a[9706069]|0;c=(b&255)<<1&254|1;a[9706068]=a[9706144+c|0]|(b&255)>>>7;a[9706069]=c&255;return}function gv8(){var b=0,c=0;b=a[9706073]|0;c=(b&255)>>>1;a[9706068]=a[9706144+c|0]|b&1;a[9706073]=c&255;return}function gv9(){var b=0,c=0;b=a[9706072]|0;c=(b&255)>>>1;a[9706068]=a[9706144+c|0]|b&1;a[9706072]=c&255;return}function gwa(){var b=0,c=0;b=a[9706077]|0;c=(b&255)>>>1;a[9706068]=a[9706144+c|0]|b&1;a[9706077]=c&255;return}function gwb(){var b=0,c=0;b=a[9706076]|0;c=(b&255)>>>1;a[9706068]=a[9706144+c|0]|b&1;a[9706076]=c&255;return}function gwc(){var b=0,c=0;b=a[9706081]|0;c=(b&255)>>>1;a[9706068]=a[9706144+c|0]|b&1;a[9706081]=c&255;return}function gwd(){var b=0,c=0;b=a[9706080]|0;c=(b&255)>>>1;a[9706068]=a[9706144+c|0]|b&1;a[9706080]=c&255;return}function gwe(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[4853040]|0;e=d&65535;f=e>>>8;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+(f<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](d)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=(j&255)>>>1;a[9706068]=a[9706144+g|0]|j&1;j=g&255;g=c[k+76+((f|256)<<2)>>2]|0;if((g|0)!=0){a[g+(e&255)|0]=j;return}e=c[k+4184>>2]|0;if((e|0)==0){return}gg[e&4095](d,j);return}function gwf(){var b=0,c=0;b=a[9706069]|0;c=(b&255)>>>1;a[9706068]=a[9706144+c|0]|b&1;a[9706069]=c&255;return}function gwg(){a[9706068]=a[9706068]&1|a[9644928+(a[9706073]&1)|0]|16;return}function gwh(){a[9706068]=a[9706068]&1|a[9644928+(a[9706072]&1)|0]|16;return}function gwi(){a[9706068]=a[9706068]&1|a[9644928+(a[9706077]&1)|0]|16;return}function gwj(){a[9706068]=a[9706068]&1|a[9644928+(a[9706076]&1)|0]|16;return}function gwk(){a[9706068]=a[9706068]&1|a[9644928+(a[9706081]&1)|0]|16;return}function gwl(){a[9706068]=a[9706068]&1|a[9644928+(a[9706080]&1)|0]|16;return}function gwm(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=a[9706068]&1;e=b[4853040]|0;f=e&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;break}j=gj[i&4095](e)|0}else{j=a[h+(f&255)|0]|0}}while(0);a[9706068]=d|a[9644928+(j&1)|0]|16;return}function gwn(){a[9706068]=a[9706068]&1|a[9644928+(a[9706069]&1)|0]|16;return}function gwo(){a[9706068]=a[9706068]&1|a[9644928+(a[9706073]&2)|0]|16;return}function gwp(){a[9706068]=a[9706068]&1|a[9644928+(a[9706072]&2)|0]|16;return}function gwq(){a[9706068]=a[9706068]&1|a[9644928+(a[9706077]&2)|0]|16;return}function gwr(){a[9706068]=a[9706068]&1|a[9644928+(a[9706076]&2)|0]|16;return}function gws(){a[9706068]=a[9706068]&1|a[9644928+(a[9706081]&2)|0]|16;return}function gwt(){a[9706068]=a[9706068]&1|a[9644928+(a[9706080]&2)|0]|16;return}function gwu(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=a[9706068]&1;e=b[4853040]|0;f=e&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;break}j=gj[i&4095](e)|0}else{j=a[h+(f&255)|0]|0}}while(0);a[9706068]=d|a[9644928+(j&2)|0]|16;return}function gwv(){a[9706068]=a[9706068]&1|a[9644928+(a[9706069]&2)|0]|16;return}function gww(){a[9706068]=a[9706068]&1|a[9644928+(a[9706073]&4)|0]|16;return}function gwx(){a[9706068]=a[9706068]&1|a[9644928+(a[9706072]&4)|0]|16;return}function gwy(){a[9706068]=a[9706068]&1|a[9644928+(a[9706077]&4)|0]|16;return}function gwz(){a[9706068]=a[9706068]&1|a[9644928+(a[9706076]&4)|0]|16;return}function gwA(){a[9706068]=a[9706068]&1|a[9644928+(a[9706081]&4)|0]|16;return}function gwB(){a[9706068]=a[9706068]&1|a[9644928+(a[9706080]&4)|0]|16;return}function gwC(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=a[9706068]&1;e=b[4853040]|0;f=e&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;break}j=gj[i&4095](e)|0}else{j=a[h+(f&255)|0]|0}}while(0);a[9706068]=d|a[9644928+(j&4)|0]|16;return}function gwD(){a[9706068]=a[9706068]&1|a[9644928+(a[9706069]&4)|0]|16;return}function gwE(){a[9706068]=a[9706068]&1|a[9644928+(a[9706073]&8)|0]|16;return}function gwF(){a[9706068]=a[9706068]&1|a[9644928+(a[9706072]&8)|0]|16;return}function gwG(){a[9706068]=a[9706068]&1|a[9644928+(a[9706077]&8)|0]|16;return}function gwH(){a[9706068]=a[9706068]&1|a[9644928+(a[9706076]&8)|0]|16;return}function gwI(){a[9706068]=a[9706068]&1|a[9644928+(a[9706081]&8)|0]|16;return}function gwJ(){a[9706068]=a[9706068]&1|a[9644928+(a[9706080]&8)|0]|16;return}function gwK(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=a[9706068]&1;e=b[4853040]|0;f=e&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;break}j=gj[i&4095](e)|0}else{j=a[h+(f&255)|0]|0}}while(0);a[9706068]=d|a[9644928+(j&8)|0]|16;return}function gwL(){a[9706068]=a[9706068]&1|a[9644928+(a[9706069]&8)|0]|16;return}function gwM(){a[9706068]=a[9706068]&1|a[9644928+(a[9706073]&16)|0]|16;return}function gwN(){a[9706068]=a[9706068]&1|a[9644928+(a[9706072]&16)|0]|16;return}function gwO(){a[9706068]=a[9706068]&1|a[9644928+(a[9706077]&16)|0]|16;return}function gwP(){a[9706068]=a[9706068]&1|a[9644928+(a[9706076]&16)|0]|16;return}function gwQ(){a[9706068]=a[9706068]&1|a[9644928+(a[9706081]&16)|0]|16;return}function gwR(){a[9706068]=a[9706068]&1|a[9644928+(a[9706080]&16)|0]|16;return}function gwS(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=a[9706068]&1;e=b[4853040]|0;f=e&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;break}j=gj[i&4095](e)|0}else{j=a[h+(f&255)|0]|0}}while(0);a[9706068]=d|a[9644928+(j&16)|0]|16;return}function gwT(){a[9706068]=a[9706068]&1|a[9644928+(a[9706069]&16)|0]|16;return}function gwU(){a[9706068]=a[9706068]&1|a[9644928+(a[9706073]&32)|0]|16;return}function gwV(){a[9706068]=a[9706068]&1|a[9644928+(a[9706072]&32)|0]|16;return}function gwW(){a[9706068]=a[9706068]&1|a[9644928+(a[9706077]&32)|0]|16;return}function gwX(){a[9706068]=a[9706068]&1|a[9644928+(a[9706076]&32)|0]|16;return}function gwY(){a[9706068]=a[9706068]&1|a[9644928+(a[9706081]&32)|0]|16;return}function gwZ(){a[9706068]=a[9706068]&1|a[9644928+(a[9706080]&32)|0]|16;return}function gw_(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=a[9706068]&1;e=b[4853040]|0;f=e&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;break}j=gj[i&4095](e)|0}else{j=a[h+(f&255)|0]|0}}while(0);a[9706068]=d|a[9644928+(j&32)|0]|16;return}function gw$(){a[9706068]=a[9706068]&1|a[9644928+(a[9706069]&32)|0]|16;return}function gw0(){a[9706068]=a[9706068]&1|a[9644928+(a[9706073]&64)|0]|16;return}function gw1(){a[9706068]=a[9706068]&1|a[9644928+(a[9706072]&64)|0]|16;return}function gw2(){a[9706068]=a[9706068]&1|a[9644928+(a[9706077]&64)|0]|16;return}function gw3(){a[9706068]=a[9706068]&1|a[9644928+(a[9706076]&64)|0]|16;return}function gw4(){a[9706068]=a[9706068]&1|a[9644928+(a[9706081]&64)|0]|16;return}function gw5(){a[9706068]=a[9706068]&1|a[9644928+(a[9706080]&64)|0]|16;return}function gw6(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=a[9706068]&1;e=b[4853040]|0;f=e&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;break}j=gj[i&4095](e)|0}else{j=a[h+(f&255)|0]|0}}while(0);a[9706068]=d|a[9644928+(j&64)|0]|16;return}function gw7(){a[9706068]=a[9706068]&1|a[9644928+(a[9706069]&64)|0]|16;return}function gw8(){a[9706068]=a[9706068]&1|a[9644928+(a[9706073]&128)|0]|16;return}function gw9(){a[9706068]=a[9706068]&1|a[9644928+(a[9706072]&128)|0]|16;return}function gxa(){a[9706068]=a[9706068]&1|a[9644928+(a[9706077]&128)|0]|16;return}function gxb(){a[9706068]=a[9706068]&1|a[9644928+(a[9706076]&128)|0]|16;return}function gxc(){a[9706068]=a[9706068]&1|a[9644928+(a[9706081]&128)|0]|16;return}function gxd(){a[9706068]=a[9706068]&1|a[9644928+(a[9706080]&128)|0]|16;return}function gxe(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=a[9706068]&1;e=b[4853040]|0;f=e&65535;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+(f>>>8<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;break}j=gj[i&4095](e)|0}else{j=a[h+(f&255)|0]|0}}while(0);a[9706068]=d|a[9644928+(j&128)|0]|16;return}function gxf(){a[9706068]=a[9706068]&1|a[9644928+(a[9706069]&128)|0]|16;return}function gxg(){a[9706073]=a[9706073]&-2;return}function gxh(){a[9706072]=a[9706072]&-2;return}function gxi(){a[9706077]=a[9706077]&-2;return}function gxj(){a[9706076]=a[9706076]&-2;return}function gxk(){a[9706081]=a[9706081]&-2;return}function gxl(){a[9706080]=a[9706080]&-2;return}function gxm(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[4853040]|0;e=d&65535;f=e>>>8;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+(f<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](d)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=j&-2;j=c[k+76+((f|256)<<2)>>2]|0;if((j|0)!=0){a[j+(e&255)|0]=g;return}e=c[k+4184>>2]|0;if((e|0)==0){return}gg[e&4095](d,g);return}function gxn(){a[9706069]=a[9706069]&-2;return}function gxo(){a[9706073]=a[9706073]&-3;return}function gxp(){a[9706072]=a[9706072]&-3;return}function gxq(){a[9706077]=a[9706077]&-3;return}function gxr(){a[9706076]=a[9706076]&-3;return}function gxs(){a[9706081]=a[9706081]&-3;return}function gxt(){a[9706080]=a[9706080]&-3;return}function gxu(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[4853040]|0;e=d&65535;f=e>>>8;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+(f<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](d)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=j&-3;j=c[k+76+((f|256)<<2)>>2]|0;if((j|0)!=0){a[j+(e&255)|0]=g;return}e=c[k+4184>>2]|0;if((e|0)==0){return}gg[e&4095](d,g);return}function gxv(){a[9706069]=a[9706069]&-3;return}function gxw(){a[9706073]=a[9706073]&-5;return}function gxx(){a[9706072]=a[9706072]&-5;return}function gxy(){a[9706077]=a[9706077]&-5;return}function gxz(){a[9706076]=a[9706076]&-5;return}function gxA(){a[9706081]=a[9706081]&-5;return}function gxB(){a[9706080]=a[9706080]&-5;return}function gxC(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[4853040]|0;e=d&65535;f=e>>>8;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+(f<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](d)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=j&-5;j=c[k+76+((f|256)<<2)>>2]|0;if((j|0)!=0){a[j+(e&255)|0]=g;return}e=c[k+4184>>2]|0;if((e|0)==0){return}gg[e&4095](d,g);return}function gxD(){a[9706069]=a[9706069]&-5;return}function gxE(){a[9706073]=a[9706073]&-9;return}function gxF(){a[9706072]=a[9706072]&-9;return}function gxG(){a[9706077]=a[9706077]&-9;return}function gxH(){a[9706076]=a[9706076]&-9;return}function gxI(){a[9706081]=a[9706081]&-9;return}function gxJ(){a[9706080]=a[9706080]&-9;return}function gxK(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[4853040]|0;e=d&65535;f=e>>>8;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+(f<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](d)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=j&-9;j=c[k+76+((f|256)<<2)>>2]|0;if((j|0)!=0){a[j+(e&255)|0]=g;return}e=c[k+4184>>2]|0;if((e|0)==0){return}gg[e&4095](d,g);return}function gxL(){a[9706069]=a[9706069]&-9;return}function gxM(){a[9706073]=a[9706073]&-17;return}function gxN(){a[9706072]=a[9706072]&-17;return}function gxO(){a[9706077]=a[9706077]&-17;return}function gxP(){a[9706076]=a[9706076]&-17;return}function gxQ(){a[9706081]=a[9706081]&-17;return}function gxR(){a[9706080]=a[9706080]&-17;return}function gxS(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[4853040]|0;e=d&65535;f=e>>>8;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+(f<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](d)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=j&-17;j=c[k+76+((f|256)<<2)>>2]|0;if((j|0)!=0){a[j+(e&255)|0]=g;return}e=c[k+4184>>2]|0;if((e|0)==0){return}gg[e&4095](d,g);return}function gxT(){a[9706069]=a[9706069]&-17;return}function gxU(){a[9706073]=a[9706073]&-33;return}function gxV(){a[9706072]=a[9706072]&-33;return}function gxW(){a[9706077]=a[9706077]&-33;return}function gxX(){a[9706076]=a[9706076]&-33;return}function gxY(){a[9706081]=a[9706081]&-33;return}function gxZ(){a[9706080]=a[9706080]&-33;return}function gx_(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[4853040]|0;e=d&65535;f=e>>>8;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+(f<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](d)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=j&-33;j=c[k+76+((f|256)<<2)>>2]|0;if((j|0)!=0){a[j+(e&255)|0]=g;return}e=c[k+4184>>2]|0;if((e|0)==0){return}gg[e&4095](d,g);return}function gx$(){a[9706069]=a[9706069]&-33;return}function gx0(){a[9706073]=a[9706073]&-65;return}function gx1(){a[9706072]=a[9706072]&-65;return}function gx2(){a[9706077]=a[9706077]&-65;return}function gx3(){a[9706076]=a[9706076]&-65;return}function gx4(){a[9706081]=a[9706081]&-65;return}function gx5(){a[9706080]=a[9706080]&-65;return}function gx6(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[4853040]|0;e=d&65535;f=e>>>8;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+(f<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](d)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=j&-65;j=c[k+76+((f|256)<<2)>>2]|0;if((j|0)!=0){a[j+(e&255)|0]=g;return}e=c[k+4184>>2]|0;if((e|0)==0){return}gg[e&4095](d,g);return}function gx7(){a[9706069]=a[9706069]&-65;return}function gx8(){a[9706073]=a[9706073]&127;return}function gx9(){a[9706072]=a[9706072]&127;return}function gya(){a[9706077]=a[9706077]&127;return}function gyb(){a[9706076]=a[9706076]&127;return}function gyc(){a[9706081]=a[9706081]&127;return}function gyd(){a[9706080]=a[9706080]&127;return}function gye(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[4853040]|0;e=d&65535;f=e>>>8;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+(f<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](d)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=j&127;j=c[k+76+((f|256)<<2)>>2]|0;if((j|0)!=0){a[j+(e&255)|0]=g;return}e=c[k+4184>>2]|0;if((e|0)==0){return}gg[e&4095](d,g);return}function gyf(){a[9706069]=a[9706069]&127;return}function gyg(){a[9706073]=a[9706073]|1;return}function gyh(){a[9706072]=a[9706072]|1;return}function gyi(){a[9706077]=a[9706077]|1;return}function gyj(){a[9706076]=a[9706076]|1;return}function gyk(){a[9706081]=a[9706081]|1;return}function gyl(){a[9706080]=a[9706080]|1;return}function gym(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[4853040]|0;e=d&65535;f=e>>>8;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+(f<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](d)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=j|1;j=c[k+76+((f|256)<<2)>>2]|0;if((j|0)!=0){a[j+(e&255)|0]=g;return}e=c[k+4184>>2]|0;if((e|0)==0){return}gg[e&4095](d,g);return}function gyn(){a[9706069]=a[9706069]|1;return}function gyo(){a[9706073]=a[9706073]|2;return}function gyp(){a[9706072]=a[9706072]|2;return}function gyq(){a[9706077]=a[9706077]|2;return}function gyr(){a[9706076]=a[9706076]|2;return}function gys(){a[9706081]=a[9706081]|2;return}function gyt(){a[9706080]=a[9706080]|2;return}function gyu(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[4853040]|0;e=d&65535;f=e>>>8;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+(f<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](d)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=j|2;j=c[k+76+((f|256)<<2)>>2]|0;if((j|0)!=0){a[j+(e&255)|0]=g;return}e=c[k+4184>>2]|0;if((e|0)==0){return}gg[e&4095](d,g);return}function gyv(){a[9706069]=a[9706069]|2;return}function gyw(){a[9706073]=a[9706073]|4;return}function gyx(){a[9706072]=a[9706072]|4;return}function gyy(){a[9706077]=a[9706077]|4;return}function gyz(){a[9706076]=a[9706076]|4;return}function gyA(){a[9706081]=a[9706081]|4;return}function gyB(){a[9706080]=a[9706080]|4;return}function gyC(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[4853040]|0;e=d&65535;f=e>>>8;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+(f<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](d)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=j|4;j=c[k+76+((f|256)<<2)>>2]|0;if((j|0)!=0){a[j+(e&255)|0]=g;return}e=c[k+4184>>2]|0;if((e|0)==0){return}gg[e&4095](d,g);return}function gyD(){a[9706069]=a[9706069]|4;return}function gyE(){a[9706073]=a[9706073]|8;return}function gyF(){a[9706072]=a[9706072]|8;return}function gyG(){a[9706077]=a[9706077]|8;return}function gyH(){a[9706076]=a[9706076]|8;return}function gyI(){a[9706081]=a[9706081]|8;return}function gyJ(){a[9706080]=a[9706080]|8;return}function gyK(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[4853040]|0;e=d&65535;f=e>>>8;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+(f<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](d)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=j|8;j=c[k+76+((f|256)<<2)>>2]|0;if((j|0)!=0){a[j+(e&255)|0]=g;return}e=c[k+4184>>2]|0;if((e|0)==0){return}gg[e&4095](d,g);return}function gyL(){a[9706069]=a[9706069]|8;return}function gyM(){a[9706073]=a[9706073]|16;return}function gyN(){a[9706072]=a[9706072]|16;return}function gyO(){a[9706077]=a[9706077]|16;return}function gyP(){a[9706076]=a[9706076]|16;return}function gyQ(){a[9706081]=a[9706081]|16;return}function gyR(){a[9706080]=a[9706080]|16;return}function gyS(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[4853040]|0;e=d&65535;f=e>>>8;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+(f<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](d)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=j|16;j=c[k+76+((f|256)<<2)>>2]|0;if((j|0)!=0){a[j+(e&255)|0]=g;return}e=c[k+4184>>2]|0;if((e|0)==0){return}gg[e&4095](d,g);return}function gyT(){a[9706069]=a[9706069]|16;return}function gyU(){a[9706073]=a[9706073]|32;return}function gyV(){a[9706072]=a[9706072]|32;return}function gyW(){a[9706077]=a[9706077]|32;return}function gyX(){a[9706076]=a[9706076]|32;return}function gyY(){a[9706081]=a[9706081]|32;return}function gyZ(){a[9706080]=a[9706080]|32;return}function gy_(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[4853040]|0;e=d&65535;f=e>>>8;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+(f<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](d)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=j|32;j=c[k+76+((f|256)<<2)>>2]|0;if((j|0)!=0){a[j+(e&255)|0]=g;return}e=c[k+4184>>2]|0;if((e|0)==0){return}gg[e&4095](d,g);return}function gy$(){a[9706069]=a[9706069]|32;return}function gy0(){a[9706073]=a[9706073]|64;return}function gy1(){a[9706072]=a[9706072]|64;return}function gy2(){a[9706077]=a[9706077]|64;return}function gy3(){a[9706076]=a[9706076]|64;return}function gy4(){a[9706081]=a[9706081]|64;return}function gy5(){a[9706080]=a[9706080]|64;return}function gy6(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[4853040]|0;e=d&65535;f=e>>>8;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+(f<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](d)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=j|64;j=c[k+76+((f|256)<<2)>>2]|0;if((j|0)!=0){a[j+(e&255)|0]=g;return}e=c[k+4184>>2]|0;if((e|0)==0){return}gg[e&4095](d,g);return}function gy7(){a[9706069]=a[9706069]|64;return}function gy8(){a[9706073]=a[9706073]|-128;return}function gy9(){a[9706072]=a[9706072]|-128;return}function gza(){a[9706077]=a[9706077]|-128;return}function gzb(){a[9706076]=a[9706076]|-128;return}function gzc(){a[9706081]=a[9706081]|-128;return}function gzd(){a[9706080]=a[9706080]|-128;return}function gze(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[4853040]|0;e=d&65535;f=e>>>8;g=c[9757320+(c[1836236]<<2)>>2]|0;h=c[g+76+(f<<2)>>2]|0;do{if((h|0)==0){i=c[g+4180>>2]|0;if((i|0)==0){j=0;k=g;break}l=gj[i&4095](d)|0;j=l;k=c[9757320+(c[1836236]<<2)>>2]|0}else{j=a[h+(e&255)|0]|0;k=g}}while(0);g=j|-128;j=c[k+76+((f|256)<<2)>>2]|0;if((j|0)!=0){a[j+(e&255)|0]=g;return}e=c[k+4184>>2]|0;if((e|0)==0){return}gg[e&4095](d,g);return}function gzf(){a[9706069]=a[9706069]|-128;return}function gzg(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=b|0;e=c[d>>2]|0;if((e|0)==0){return}f=b+4|0;b=c[f>>2]|0;do{if((e|0)==(b|0)){g=e}else{h=b;while(1){i=h-12|0;c[f>>2]=i;do{if((a[i]&1)==0){j=i}else{k=c[h-12+8>>2]|0;if((k|0)==0){j=i;break}gGr(k);j=c[f>>2]|0}}while(0);if((e|0)==(j|0)){break}else{h=j}}h=c[d>>2]|0;if((h|0)!=0){g=h;break}return}}while(0);gGr(g);return}function gzh(a){a=a|0;c[2388396]=a;return}function gzi(a){a=a|0;return}function gzj(a){a=a|0;c[2438342]=a;return}function gzk(a){a=a|0;c[2406660]=a;return}function gzl(a){a=a|0;c[2405094]=a;return}function gzm(a){a=a|0;c[3528788]=a;gA[a&16383](16,616208)|0;return}function gzn(b){b=b|0;c[b>>2]=143440;c[b+4>>2]=115184;a[b+12|0]=1;a[b+13|0]=1;c[b+8>>2]=90208;return}function gzo(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;i=i+32|0;d=b|0;e=b+16|0;c[3528546]=0;f=d+4|0;g=0;while(1){h=c[(c[642608+(c[2436]<<2)>>2]|0)+96>>2]|0;if((h|0)==0){break}if((gA[h&16383](d,g)|0)!=0){break}if((a[f]|0)==-16){j=4814;break}else{g=g+1|0}}if((j|0)==4814){g=c[d>>2]|0;c[3528546]=g;d=c[u>>2]|0;bU(d|0,360560,(d=i,i=i+8|0,c[d>>2]=g,d)|0)|0;i=d}d=c[(c[642608+(c[2436]<<2)>>2]|0)+96>>2]|0;if((d|0)==0){i=b;return}if((gA[d&16383](e,0)|0)!=0){i=b;return}d=e+4|0;g=e|0;f=e+5|0;h=e+6|0;k=0;while(1){do{if((a[d]|0)==-1){l=c[3541308]|0;m=(c[3528546]|0)+(c[g>>2]|0)|0;if((l+(m*68|0)|0)==0){break}n=l+(m*68|0)+12|0;m=a[f]|0;a[n]=a[h]&m|a[n]&~m}}while(0);m=k+1|0;n=c[(c[642608+(c[2436]<<2)>>2]|0)+96>>2]|0;if((n|0)==0){j=4827;break}if((gA[n&16383](e,m)|0)==0){k=m}else{j=4826;break}}if((j|0)==4826){i=b;return}else if((j|0)==4827){i=b;return}}function gzp(){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;a[9736]=1;c=0;do{d=c<<2;e=ag(d,d)|0;f=e>>>14;g=ag(f,d)|0;h=e>>>15;e=(g|0)/98304|0;b[14130680+(d<<1)>>1]=((d|0)/-3|0)-e+h&65535;i=(g|0)/32768|0;b[14130680+((d|1)<<1)>>1]=16384-f+((d|0)/-2|0)+i&65535;b[14130680+((d|2)<<1)>>1]=h+d-i&65535;b[14130680+((d|3)<<1)>>1]=((d|0)/-6|0)+e&65535;c=c+1|0;}while((c|0)<4096);return}function gzq(){var b=0,d=0,e=0;if(!(a[5904928]|0)){a[5904928]=0;a[9736]=0;return}b=9681616;c[b>>2]=0;c[b+4>>2]=0;c[2427044]=0;b=c[2430396]|0;if((b|0)!=0){d=b;while(1){b=c[d>>2]|0;if((d|0)!=0){gGr(d)}if((b|0)==0){break}else{d=b}}}c[2430396]=0;gGz(9774632,0,32);c[2438]=256;c[2112966]=0;gD[c[(c[642608+(c[2436]<<2)>>2]|0)+104>>2]&8191]()|0;d=0;do{b=9638528+(d<<2)|0;e=c[b>>2]|0;if((e|0)!=0){gGr(e);c[b>>2]=0}d=d+1|0;}while((d|0)<1024);a[5904928]=0;a[9736]=0;return}function gzr(){var d=0,e=0,f=0,g=0;d=c[2113198]|0;L5595:do{if((d|0)!=0){e=c[3541308]|0;f=0;while(1){if((b[e+12>>1]|0)==61){break}g=f+1|0;if(g>>>0<d>>>0){e=e+68|0;f=g}else{break L5595}}b[e+8>>1]=1;a[c[e+4>>2]|0]=1}}while(0);c[2112964]=14098152;a[9680]=1;c[2113222]=(c[2113222]|0)+1;gD[c[(c[642608+(c[2436]<<2)>>2]|0)+108>>2]&8191]()|0;return}function gzs(){var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;f=i;i=i+8|0;g=f|0;h=c[642608+(c[2436]<<2)>>2]|0;j=c[h+128>>2]|0;k=c[h+132>>2]|0;c[2112968]=9903848;gu[c[2406660]&16383]();L5603:do{if((c[2113198]|0)!=0){h=0;l=c[3541308]|0;while(1){m=a[l|0]|0;do{if((m&8)!=0){do{if(m<<24>>24==8){n=(gJ[c[2405094]&31](0,1,0,6)|0)<<16>>16==0;o=n?0:-256;if((gJ[c[2405094]&31](0,1,0,7)|0)<<16>>16==0){p=o;break}p=o+256|0}else{p=0}}while(0);o=(ag(b[l+16>>1]|0,p)|0)/256|0;n=b[l+18>>1]|0;q=l+20|0;r=c[q>>2]|0;if(n<<16>>16==0){s=r}else{t=n<<16>>16;n=((ag(r-32768|0,t-1|0)|0)/(t|0)|0)+32768|0;c[q>>2]=n;s=n}n=s+o|0;o=(n|0)<256?256:n;c[q>>2]=o;if((o|0)<=65280){break}c[q>>2]=65280}}while(0);m=h+1|0;u=c[2113198]|0;if(m>>>0<u>>>0){h=m;l=l+68|0}else{break}}if((u|0)==0){break}l=0;h=c[3541308]|0;while(1){L5622:do{switch(d[h|0]|0){case 1:{m=a[h+12|0]|0;b[h+8>>1]=m&255;a[c[h+4>>2]|0]=m;break};case 2:{m=h+4|0;q=e[h+12>>1]|0;o=(gJ[c[2405094]&31](d[9579393+(q<<1)|0]|0,1,0,d[9579392+(q<<1)|0]|0)|0)<<16>>16!=0;q=h+8|0;if((a[h+1|0]&4)==0){b[q>>1]=o&1;a[c[m>>2]|0]=o&1;break L5622}else{n=o?-1:1;b[q>>1]=n;b[c[m>>2]>>1]=n;break L5622}break};case 8:{n=c[h+20>>2]|0;if((a[h+1|0]|0)==4){v=(n+1015808|0)>>>4&65535}else{v=n&65535}b[h+8>>1]=v;b[c[h+4>>2]>>1]=v;break};case 16:{b[h+8>>1]=0;b[c[h+4>>2]>>1]=0;break};case 32:{n=h+4|0;m=h+12|0;q=d[m]|0;o=d[m+1|0]|0;if((o|0)==0){w=(gJ[c[2405094]&31](q,5,0,0)|0)<<16>>16}else if((o|0)==1){w=(gJ[c[2405094]&31](q,5,0,1)|0)<<16>>16}else if((o|0)==3){w=(gJ[c[2405094]&31](q,5,1,0)|0)<<16>>16}else if((o|0)==4){w=(gJ[c[2405094]&31](q,5,1,1)|0)<<16>>16}else{w=0}if((a[h+1|0]|0)==4){q=(ag(a[9768]|0?256:0,w)|0)>>13;o=(q|0)<-32768?-32768:q;x=(o|0)>32767?32767:o&65535}else{o=(w>>1)+32768|0;q=(o|0)<1?1:o;x=(q|0)>65535?-1:q&65535}b[h+8>>1]=x;b[c[n>>2]>>1]=x;break};case 33:{n=h+4|0;q=h+12|0;o=d[q]|0;m=d[q+1|0]|0;if((m|0)==0){y=gJ[c[2405094]&31](o,5,0,0)|0;z=4885}else if((m|0)==1){y=gJ[c[2405094]&31](o,5,0,1)|0;z=4885}else if((m|0)==3){y=gJ[c[2405094]&31](o,5,1,0)|0;z=4885}else if((m|0)==4){y=gJ[c[2405094]&31](o,5,1,1)|0;z=4885}else{A=0;z=4886}do{if((z|0)==4885){z=0;if(y<<16>>16!=32767){A=y<<16>>16;z=4886;break}b[h+8>>1]=0;B=0}}while(0);if((z|0)==4886){z=0;o=(A|0)>0?0:-A|0;m=(o|0)>65535?-1:o&65535;b[h+8>>1]=m;B=m}b[c[n>>2]>>1]=B;break};case 34:{m=h+4|0;o=h+12|0;q=d[o]|0;t=d[o+1|0]|0;if((t|0)==0){o=c[2405094]|0;gJ[o&31](q,5,0,0)|0}else if((t|0)==1){gJ[c[2405094]&31](q,5,0,1)|0}else if((t|0)==3){gJ[c[2405094]&31](q,5,1,0)|0}else if((t|0)==4){gJ[c[2405094]&31](q,5,1,1)|0}b[h+8>>1]=0;b[c[m>>2]>>1]=0;break};default:{}}}while(0);m=l+1|0;if(m>>>0<(c[2113198]|0)>>>0){l=m;h=h+68|0}else{break L5603}}}}while(0);c[2112964]=14098152;a[9680]=1;c[2113222]=(c[2113222]|0)+1;gD[c[(c[642608+(c[2436]<<2)>>2]|0)+108>>2]&8191]()|0;B=c[(c[642608+(c[2436]<<2)>>2]|0)+52>>2]&6;if((B|0)==4|(B|0)==6){C=j;D=k}else{C=k;D=j}j=ag((c[2113308]|0)==2?2:4,D)|0;c[2113300]=j;gL[c[2388396]&255](9903848,D,C,j);gA[c[2438342]&16383](14098152,a[9688]|0?534:0)|0;a[g]=0;if(!(gA[c[3528788]&16383](17,g)|0)){i=f;return}if((a[g]&1)==0){i=f;return}gzt();i=f;return}function gzt(){var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=i;i=i+8|0;e=d|0;f=e;g=e;c[e>>2]=0;c[e+4>>2]=0;h=e;c[h>>2]=161984;e=gA[c[3528788]&16383](15,g)|0;j=a[7358208]|0;do{if(e){if(!j){k=4917;break}l=c[f+4>>2]|0;if((fa(l|0,371680)|0)==0){m=0}else{m=(fa(l|0,393488)|0)==0}if((a[9537576]&1|0)==(m&1|0)){break}a[9537576]=m&1;l=c[2113198]|0;L5684:do{if((l|0)!=0){n=c[3541308]|0;o=0;while(1){if((b[n+12>>1]|0)==60){break}p=o+1|0;if(p>>>0<l>>>0){n=n+68|0;o=p}else{break L5684}}b[n+8>>1]=1;a[c[n+4>>2]|0]=1}}while(0);c[2112964]=14098152;a[9680]=1;c[2113222]=(c[2113222]|0)+1;l=c[(c[642608+(c[2436]<<2)>>2]|0)+108>>2]|0;gD[l&8191]()|0}else{if(!j){k=4917}}}while(0);if((k|0)==4917){a[7358208]=1}c[h>>2]=384888;do{if(gA[c[3528788]&16383](15,g)|0){k=c[f+4>>2]|0;if((fa(k|0,371680)|0)==0){a[1096920]=0}if((fa(k|0,393488)|0)!=0){break}a[1096920]=1}}while(0);c[h>>2]=228528;if(!(gA[c[3528788]&16383](15,g)|0)){i=d;return}g=c[f+4>>2]|0;if((fa(g|0,370512)|0)==0){c[2438]=256;i=d;return}if((fa(g|0,369024)|0)==0){c[2438]=272;i=d;return}if((fa(g|0,367912)|0)==0){c[2438]=288;i=d;return}if((fa(g|0,367328)|0)==0){c[2438]=304;i=d;return}if((fa(g|0,366688)|0)==0){c[2438]=320;i=d;return}if((fa(g|0,365688)|0)==0){c[2438]=336;i=d;return}if((fa(g|0,365288)|0)==0){c[2438]=352;i=d;return}if((fa(g|0,364384)|0)==0){c[2438]=368;i=d;return}if((fa(g|0,363648)|0)==0){c[2438]=384;i=d;return}if((fa(g|0,362464)|0)==0){c[2438]=400;i=d;return}if((fa(g|0,361528)|0)!=0){i=d;return}c[2438]=512;i=d;return}function gzu(){var a=0,b=0;a=c[3528198]|0;if((a|0)!=0){b=a;return b|0}c[2076592]=3140;c[3528198]=0;Sa();a=c[(c[642608+(c[2436]<<2)>>2]|0)+116>>2]|0;if((a|0)!=0){gA[a&16383](98,0)|0}b=c[3528198]|0;return b|0}function gzv(a){a=a|0;c[3528198]=(c[3528198]|0)+(c[a+4>>2]|0);return 0}function gzw(a,b){a=a|0;b=b|0;var d=0;if((c[3528198]|0)!=(b|0)){d=0;return d|0}c[2076592]=578;c[2433486]=a;Sa();a=c[(c[642608+(c[2436]<<2)>>2]|0)+116>>2]|0;if((a|0)==0){d=1;return d|0}gA[a&16383](98,0)|0;d=1;return d|0}function gzx(a){a=a|0;var b=0,d=0,e=0;b=c[2433486]|0;d=c[a>>2]|0;e=a+4|0;a=c[e>>2]|0;gGC(b|0,d|0,a)|0;c[2433486]=b+(c[e>>2]|0);return 0}function gzy(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;d=i;i=i+16|0;e=d|0;if((c[3528198]|0)!=(b|0)){f=0;i=d;return f|0}c[2076592]=1486;c[2438082]=a;a=c[2430396]|0;L5770:do{if((a|0)!=0){b=e|0;g=e+4|0;h=e+8|0;j=e+12|0;k=a;l=1486;while(1){c[b>>2]=c[k+264>>2];c[g>>2]=c[k+268>>2];c[h>>2]=0;c[j>>2]=k+8;gj[l&4095](e)|0;m=c[k>>2]|0;if((m|0)==0){break L5770}k=m;l=c[2076592]|0}}}while(0);e=c[(c[642608+(c[2436]<<2)>>2]|0)+116>>2]|0;if((e|0)==0){f=1;i=d;return f|0}gA[e&16383](97,0)|0;f=1;i=d;return f|0}function gzz(a){a=a|0;var b=0,d=0,e=0;b=c[a>>2]|0;d=c[2438082]|0;e=a+4|0;a=c[e>>2]|0;gGC(b|0,d|0,a)|0;c[2438082]=d+(c[e>>2]|0);return 0}function gzA(){return}function gzB(a,b,c){a=a|0;b=b|0;c=c|0;return}function gzC(a){a=a|0;var b=0,d=0,e=0,f=0.0;b=c[642608+(c[2436]<<2)>>2]|0;d=c[b+128>>2]|0;e=c[b+132>>2]|0;b=(d|0)>(e|0)?d:e;f=+(c[2424]|0)/100.0;c[a>>2]=d;c[a+4>>2]=e;c[a+8>>2]=b;c[a+12>>2]=b;g[a+16>>2]=0.0;h[a+24>>3]=f;h[a+32>>3]=f*534.0;return}function gzD(b){b=b|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,J=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0;f=i;i=i+5624|0;g=f|0;h=f+16|0;j=f+32|0;k=f+48|0;l=f+96|0;m=f+112|0;n=f+160|0;o=f+224|0;p=f+288|0;q=f+304|0;r=f+392|0;s=f+480|0;t=f+744|0;v=f+760|0;w=f+776|0;x=f+792|0;y=f+808|0;z=f+4408|0;A=f+4416|0;B=f+4424|0;C=f+5448|0;D=f+5464|0;E=f+5472|0;F=f+5480|0;G=f+5488|0;H=f+5496|0;J=H|0;L=b|0;b=c[L>>2]|0;M=cE(b|0,47)|0;if((M|0)==0){N=cE(b|0,92)|0}else{N=M}M=(N|0)==0?b:N;N=a[M]|0;if((N<<24>>24|0)==92|(N<<24>>24|0)==47){O=M+1|0}else{O=M}gGJ(J|0,O|0,127)|0;a[H+127|0]=0;H=cE(J|0,46)|0;if((H|0)!=0){a[H]=0}gGJ(9374064,c[L>>2]|0,1023)|0;a[9375087]=0;L=cE(9374064,47)|0;do{if((L|0)==0){H=cE(9374064,92)|0;if((H|0)!=0){P=H;Q=4999;break}a[9374064]=0}else{P=L;Q=4999}}while(0);if((Q|0)==4999){a[P]=0}P=a[9736]|0?5860:0;L=0;while(1){if(L>>>0>=P>>>0){Q=5495;break}c[2436]=L;H=c[c[642608+(L<<2)>>2]>>2]|0;if((H|0)==0){Q=5005}else{if((a[H]|0)==0){Q=5005}else{R=H}}if((Q|0)==5005){Q=0;R=0}if((fa(R|0,J|0)|0)==0){Q=5007;break}else{L=L+1|0}}do{if((Q|0)==5007){c[2112964]=14098152;a[9680]=1;a[9688]=1;R=E;P=F;H=G;c[2436]=L;O=B|0;M=C;gGz(9776872,0,126976);c[z>>2]=0;c[z+4>>2]=0;c[z>>2]=384888;do{if(gA[c[3528788]&16383](15,z)|0){if((fa(c[z+4>>2]|0,393488)|0)!=0){break}a[1096920]=1}}while(0);c[2444216]=0;if((gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](9776884,0)|0)==0){do{N=(c[2444216]|0)+1|0;c[2444216]=N;}while((gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](9776884+(N*124|0)|0,N)|0)==0)}N=c[2432952]|0;b=c[2432953]|0;if((N|0)!=(b|0)){S=b;while(1){b=S-12|0;c[2432953]=b;do{if((a[b]&1)==0){T=b}else{U=c[S-12+8>>2]|0;if((U|0)==0){T=b;break}gGr(U);T=c[2432953]|0}}while(0);if((N|0)==(T|0)){break}else{S=T}}}S=c[u>>2]|0;N=C+1|0;b=C+8|0;U=C+4|0;V=C|0;W=s|0;X=0;L5826:while(1){Y=c[2436]|0;Z=c[642608+(Y<<2)>>2]|0;_=c[Z+72>>2]|0;if((_|0)==0){if((X|0)==0){$=c[Z>>2]|0}else{aa=c[Z+8>>2]|0;ab=(aa|0)!=0|0;L5834:do{if((X|0)!=1|(aa|0)==0){if(ab>>>0>=X>>>0){ac=0;break}ad=c[Z+4>>2]|0;if((ad|0)==0){ac=0;break}ae=a[9736]|0?5860:0;af=ab;ah=ad;while(1){ad=0;while(1){c[2436]=ad;if(ad>>>0>=ae>>>0){ai=0;break}aj=c[c[642608+(ad<<2)>>2]>>2]|0;if((fa(ah|0,aj|0)|0)==0){ai=aj;break}else{ad=ad+1|0}}aj=af+1|0;if(aj>>>0>=X>>>0){ac=ai;break L5834}ak=c[(c[642608+(ad<<2)>>2]|0)+4>>2]|0;if((ak|0)==0){ac=0;break}else{af=aj;ah=ak}}}else{ac=aa}}while(0);c[2436]=Y;$=ac}if(($|0)==0){al=1;am=0}else{gGI(9538272,$|0)|0;al=0;am=9538272}c[A>>2]=am;an=al}else{an=gA[_&16383](A,X)|0}do{if((an|0)==0){aa=c[A>>2]|0;bU(S|0,391904,(ao=i,i=i+8|0,c[ao>>2]=aa,ao)|0)|0;i=ao;aa=c[A>>2]|0;be(O|0,1024,389848,(ao=i,i=i+16|0,c[ao>>2]=9374064,c[ao+8>>2]=aa,ao)|0)|0;i=ao;a[632384]=0;cC(W|0,328824,(ao=i,i=i+8|0,c[ao>>2]=O,ao)|0)|0;i=ao;aa=li(W)|0;c[2426512]=aa;if((aa|0)==0){Q=5039;break L5826}a[632384]=1;ab=aa+120|0;Z=c[ab+4>>2]|0;ah=aa+88|0;c[ah>>2]=c[ab>>2];c[ah+4>>2]=Z;Z=aa+80|0;c[Z>>2]=0;c[Z+4>>2]=0;Z=aa+96|0;c[Z>>2]=(ll(aa,aa+128|0,aa+216|0,0,0)|0)==0;c[Z+4>>2]=0;c[2385534]=0;Z=c[2426512]|0;if(a[632384]&(Z|0)!=0){lj(Z);c[2426512]=0}a[632384]=0;Z=gGy(O|0)|0;if(Z>>>0>4294967279){Q=5043;break L5826}if(Z>>>0<11){aa=Z<<1&255;a[M]=aa;ap=N;aq=aa}else{aa=Z+16&-16;ah=(aa|0)==0?1:aa;while(1){ar=gGq(ah)|0;if((ar|0)!=0){break}ab=(I=c[2439328]|0,c[2439328]=I+0,I);if((ab|0)==0){Q=5054;break L5826}gu[ab&16383]()}c[b>>2]=ar;ah=aa|1;c[V>>2]=ah;c[U>>2]=Z;ap=ar;aq=ah&255}gGC(ap|0,O|0,Z)|0;a[ap+Z|0]=0;ah=c[2432953]|0;if((ah|0)==(c[2432954]|0)){ab=c[2432952]|0;af=(ah-ab|0)/12|0;ae=af+1|0;if(ae>>>0>357913941){Q=5082;break L5826}if(af>>>0>178956969){as=357913941;Q=5086}else{ak=af<<1;aj=ak>>>0<ae>>>0?ae:ak;if((aj|0)==0){at=0;au=0}else{as=aj;Q=5086}}if((Q|0)==5086){Q=0;aj=as*12|0;ak=(aj|0)==0?1:aj;while(1){av=gGq(ak)|0;if((av|0)!=0){break}aj=(I=c[2439328]|0,c[2439328]=I+0,I);if((aj|0)==0){Q=5095;break L5826}gu[aj&16383]()}at=av;au=as}ak=at+(af*12|0)|0;Z=at+(au*12|0)|0;do{if((ak|0)==0){aw=ah}else{if((a[M]&1)==0){aa=ak;c[aa>>2]=c[M>>2];c[aa+4>>2]=c[M+4>>2];c[aa+8>>2]=c[M+8>>2];aw=ah;break}aa=c[b>>2]|0;aj=c[U>>2]|0;if(aj>>>0>4294967279){Q=5102;break L5826}if(aj>>>0<11){a[ak]=aj<<1&255;ax=ak+1|0}else{ay=aj+16&-16;az=(ay|0)==0?1:ay;while(1){aA=gGq(az)|0;if((aA|0)!=0){break}aB=(I=c[2439328]|0,c[2439328]=I+0,I);if((aB|0)==0){Q=5115;break L5826}gu[aB&16383]()}c[at+(af*12|0)+8>>2]=aA;c[ak>>2]=ay|1;c[at+(af*12|0)+4>>2]=aj;ax=aA}gGC(ax|0,aa|0,aj)|0;a[ax+aj|0]=0;aw=c[2432953]|0}}while(0);af=at+(ae*12|0)|0;do{if((aw|0)==(ab|0)){c[2432952]=ak;c[2432953]=af;c[2432954]=Z;aC=ab}else{az=aw;ad=ak;while(1){aD=ad-12|0;aB=az-12|0;do{if((aD|0)!=0){aE=aB;if((a[aE]&1)==0){aF=aD;c[aF>>2]=c[aE>>2];c[aF+4>>2]=c[aE+4>>2];c[aF+8>>2]=c[aE+8>>2];break}aE=c[az-12+8>>2]|0;aF=c[az-12+4>>2]|0;if(aF>>>0>4294967279){Q=5125;break L5826}if(aF>>>0<11){a[aD]=aF<<1&255;aG=aD+1|0}else{aH=aF+16&-16;aI=(aH|0)==0?1:aH;while(1){aJ=gGq(aI)|0;if((aJ|0)!=0){break}aK=(I=c[2439328]|0,c[2439328]=I+0,I);if((aK|0)==0){Q=5138;break L5826}gu[aK&16383]()}c[ad-12+8>>2]=aJ;c[aD>>2]=aH|1;c[ad-12+4>>2]=aF;aG=aJ}gGC(aG|0,aE|0,aF)|0;a[aG+aF|0]=0}}while(0);if((aB|0)==(ab|0)){break}else{az=aB;ad=aD}}ad=c[2432952]|0;az=c[2432953]|0;c[2432952]=aD;c[2432953]=af;c[2432954]=Z;if((ad|0)==(az|0)){aC=ad;break}else{aL=az}while(1){az=aL-12|0;do{if((a[az]&1)!=0){aj=c[aL-12+8>>2]|0;if((aj|0)==0){break}gGr(aj)}}while(0);if((ad|0)==(az|0)){aC=ad;break}else{aL=az}}}}while(0);if((aC|0)!=0){gGr(aC)}aM=a[M]|0}else{do{if((ah|0)!=0){if((aq&1)==0){Z=ah;c[Z>>2]=c[M>>2];c[Z+4>>2]=c[M+4>>2];c[Z+8>>2]=c[M+8>>2];break}Z=c[b>>2]|0;af=c[U>>2]|0;if(af>>>0>4294967279){Q=5063;break L5826}if(af>>>0<11){a[ah]=af<<1&255;aN=ah+1|0}else{ab=af+16&-16;ak=(ab|0)==0?1:ab;while(1){aO=gGq(ak)|0;if((aO|0)!=0){break}ae=(I=c[2439328]|0,c[2439328]=I+0,I);if((ae|0)==0){Q=5076;break L5826}gu[ae&16383]()}c[ah+8>>2]=aO;c[ah>>2]=ab|1;c[ah+4>>2]=af;aN=aO}gGC(aN|0,Z|0,af)|0;a[aN+af|0]=0}}while(0);c[2432953]=(c[2432953]|0)+12;aM=aq}if((aM&1)==0){break}ah=c[b>>2]|0;if((ah|0)==0){break}gGr(ah)}}while(0);_=X+1|0;if(_>>>0<32){X=_}else{Q=5018;break}}if((Q|0)==5018){X=c[2432952]|0;L5950:do{if((c[2432953]|0)!=(X|0)){b=r+40|0;U=q+20|0;M=q+32|0;V=0;N=X;_=0;while(1){Y=N+(V*12|0)|0;if((a[Y]&1)==0){aP=Y+1|0}else{aP=c[N+(V*12|0)+8>>2]|0}a[632384]=0;if((aP|0)==0){aQ=N;break}cC(W|0,328824,(ao=i,i=i+8|0,c[ao>>2]=aP,ao)|0)|0;i=ao;Y=li(W)|0;c[2426512]=Y;if((Y|0)==0){Q=5177;break}a[632384]=1;ah=Y+120|0;ak=c[ah+4>>2]|0;ae=Y+88|0;c[ae>>2]=c[ah>>2];c[ae+4>>2]=ak;ak=Y+80|0;c[ak>>2]=0;c[ak+4>>2]=0;ak=Y+96|0;c[ak>>2]=(ll(Y,Y+128|0,Y+216|0,0,0)|0)==0;c[ak+4>>2]=0;c[2385534]=0;ak=a[632384]|0;Y=c[2426512]|0;ae=(Y|0)==0;L5960:do{if(ak&ae|ak^1){aR=_;aS=0}else{if(ae){aT=0}else{aT=c[Y+56>>2]|0}ah=aT*12|0;ad=gGq(ah)|0;aB=ad;if((ad|0)==0){lj(c[2426512]|0);aR=_;aS=0;break}gGz(ad|0,0,ah|0);ah=c[2426512]|0;do{if((ah|0)==0){aU=0}else{ad=ah+120|0;aj=c[ad+4>>2]|0;aa=ah+88|0;c[aa>>2]=c[ad>>2];c[aa+4>>2]=aj;aj=ah+80|0;c[aj>>2]=0;c[aj+4>>2]=0;aj=(ll(ah,ah+128|0,ah+216|0,0,0)|0)==0;aa=ah+96|0;c[aa>>2]=aj&1;c[aa+4>>2]=0;if(!aj){aU=c[2426512]|0;break}c[2385534]=0;L5973:do{if((aT|0)>0){while(1){do{if((ll(c[2426512]|0,r,0,0,0)|0)==0){aj=(c[b>>2]|0)+1|0;aa=gGq(aj)|0;if((aa|0)==0){break}if((ll(c[2426512]|0,q,0,aa,aj)|0)!=0){break}aj=c[U>>2]|0;ad=c[M>>2]|0;ay=c[2385534]|0;c[aB+(ay*12|0)>>2]=aa;c[aB+(ay*12|0)+4>>2]=ad;c[aB+(ay*12|0)+8>>2]=aj}}while(0);c[2385534]=(c[2385534]|0)+1;aj=c[2426512]|0;if((aj|0)==0){break L5973}ay=aj+96|0;if((c[ay>>2]|0)==0&(c[ay+4>>2]|0)==0){Q=5200;break L5973}ad=aj+56|0;aa=c[ad>>2]|0;aI=c[ad+4>>2]|0;ad=aj+80|0;aK=gGK(c[ad>>2]|0,c[ad+4>>2]|0,1,0)|0;aV=K;if(((aa|0)!=65535|(aI|0)!=0)&((aK|0)==(aa|0)&(aV|0)==(aI|0))){Q=5200;break L5973}aI=aj+88|0;aa=gGK((c[aj+168>>2]|0)+46+(c[aj+172>>2]|0)+(c[aj+176>>2]|0)|0,0,c[aI>>2]|0,c[aI+4>>2]|0)|0;c[aI>>2]=aa;c[aI+4>>2]=K;c[ad>>2]=aK;c[ad+4>>2]=aV;aV=(ll(aj,aj+128|0,aj+216|0,0,0)|0)==0;c[ay>>2]=aV&1;c[ay+4>>2]=0;if(!((c[2385534]|0)<(aT|0)&aV)){Q=5200;break}}}else{Q=5200}}while(0);do{if((Q|0)==5200){Q=0;az=c[2426512]|0;if((az|0)==0){break}aF=az+120|0;aE=c[aF+4>>2]|0;aH=az+88|0;c[aH>>2]=c[aF>>2];c[aH+4>>2]=aE;aE=az+80|0;c[aE>>2]=0;c[aE+4>>2]=0;aE=az+96|0;c[aE>>2]=(ll(az,az+128|0,az+216|0,0,0)|0)==0;c[aE+4>>2]=0}}while(0);c[2385534]=0;aR=aT;aS=aB;break L5960}}while(0);lj(aU);aR=_;aS=0}}while(0);if((c[2444216]|0)!=0){Y=0;do{ae=9776872+(Y*124|0)|0;L5993:do{if((c[ae>>2]|0)!=1){do{if((c[9776992+(Y*124|0)>>2]|0)!=0){ak=9776984+(Y*124|0)|0;if((c[ak>>2]|0)==0){break}aB=9776988+(Y*124|0)|0;ah=c[aB>>2]|0;if((ah|0)==0){break}L5999:do{if(a[1096920]|0){c[D>>2]=0;af=c[(c[642608+(c[2436]<<2)>>2]|0)+80>>2]|0;gp[af&16383](D,Y,0)|0;if((fa(c[D>>2]|0,387056)|0)==0){aW=0}else{af=c[aB>>2]|0;Z=0;while(1){if(Z>>>0>=aR>>>0){break L5993}if((c[aS+(Z*12|0)+8>>2]|0)==(af|0)){aX=Z;Q=5285;break L5999}else{Z=Z+1|0}}}while(1){if(aW>>>0>=aR>>>0){aY=0;break}if((fa(c[aS+(aW*12|0)>>2]|0,386240)|0)==0){Q=5213;break}else{aW=aW+1|0}}if((Q|0)==5213){Q=0;if((aW|0)<0){aY=0}else{aZ=aW;break}}while(1){if(aY>>>0>=aR>>>0){a_=0;break}if((c[aS+(aY*12|0)+8>>2]|0)==-1451456087){Q=5216;break}else{aY=aY+1|0}}if((Q|0)==5216){Q=0;if((aY|0)<0){a_=0}else{aZ=aY;break}}while(1){if(a_>>>0>=aR>>>0){a$=0;break}if((fa(c[aS+(a_*12|0)>>2]|0,385032)|0)==0){Q=5219;break}else{a_=a_+1|0}}if((Q|0)==5219){Q=0;if((a_|0)<0){a$=0}else{aZ=a_;break}}while(1){if(a$>>>0>=aR>>>0){a0=0;break}if((c[aS+(a$*12|0)+8>>2]|0)==1612128430){Q=5222;break}else{a$=a$+1|0}}if((Q|0)==5222){Q=0;if((a$|0)<0){a0=0}else{aZ=a$;break}}while(1){if(a0>>>0>=aR>>>0){a1=0;break}if((fa(c[aS+(a0*12|0)>>2]|0,383960)|0)==0){Q=5225;break}else{a0=a0+1|0}}if((Q|0)==5225){Q=0;if((a0|0)<0){a1=0}else{aZ=a0;break}}while(1){if(a1>>>0>=aR>>>0){a2=0;break}if((c[aS+(a1*12|0)+8>>2]|0)==661016245){Q=5228;break}else{a1=a1+1|0}}if((Q|0)==5228){Q=0;if((a1|0)<0){a2=0}else{aZ=a1;break}}while(1){if(a2>>>0>=aR>>>0){a3=0;break}if((fa(c[aS+(a2*12|0)>>2]|0,383104)|0)==0){Q=5231;break}else{a2=a2+1|0}}if((Q|0)==5231){Q=0;if((a2|0)<0){a3=0}else{aZ=a2;break}}while(1){if(a3>>>0>=aR>>>0){a4=0;break}if((c[aS+(a3*12|0)+8>>2]|0)==760256874){Q=5234;break}else{a3=a3+1|0}}if((Q|0)==5234){Q=0;if((a3|0)<0){a4=0}else{aZ=a3;break}}while(1){if(a4>>>0>=aR>>>0){a5=0;break}if((fa(c[aS+(a4*12|0)>>2]|0,381848)|0)==0){Q=5237;break}else{a4=a4+1|0}}if((Q|0)==5237){Q=0;if((a4|0)<0){a5=0}else{aZ=a4;break}}while(1){if(a5>>>0>=aR>>>0){a6=0;break}if((c[aS+(a5*12|0)+8>>2]|0)==-1918109845){Q=5240;break}else{a5=a5+1|0}}if((Q|0)==5240){Q=0;if((a5|0)<0){a6=0}else{aZ=a5;break}}while(1){if(a6>>>0>=aR>>>0){a7=0;break}if((fa(c[aS+(a6*12|0)>>2]|0,380680)|0)==0){Q=5243;break}else{a6=a6+1|0}}if((Q|0)==5243){Q=0;if((a6|0)<0){a7=0}else{aZ=a6;break}}while(1){if(a7>>>0>=aR>>>0){a8=0;break}if((c[aS+(a7*12|0)+8>>2]|0)==202556077){Q=5246;break}else{a7=a7+1|0}}if((Q|0)==5246){Q=0;if((a7|0)<0){a8=0}else{aZ=a7;break}}while(1){if(a8>>>0>=aR>>>0){a9=0;break}if((fa(c[aS+(a8*12|0)>>2]|0,379584)|0)==0){Q=5249;break}else{a8=a8+1|0}}if((Q|0)==5249){Q=0;if((a8|0)<0){a9=0}else{aZ=a8;break}}while(1){if(a9>>>0>=aR>>>0){ba=0;break}if((c[aS+(a9*12|0)+8>>2]|0)==-1303690080){Q=5252;break}else{a9=a9+1|0}}if((Q|0)==5252){Q=0;if((a9|0)<0){ba=0}else{aZ=a9;break}}while(1){if(ba>>>0>=aR>>>0){bb=0;break}if((fa(c[aS+(ba*12|0)>>2]|0,378504)|0)==0){Q=5255;break}else{ba=ba+1|0}}if((Q|0)==5255){Q=0;if((ba|0)<0){bb=0}else{aZ=ba;break}}while(1){if(bb>>>0>=aR>>>0){bc=0;break}if((c[aS+(bb*12|0)+8>>2]|0)==-509788951){Q=5258;break}else{bb=bb+1|0}}if((Q|0)==5258){Q=0;if((bb|0)<0){bc=0}else{aZ=bb;break}}while(1){if(bc>>>0>=aR>>>0){bd=0;break}if((fa(c[aS+(bc*12|0)>>2]|0,377656)|0)==0){Q=5261;break}else{bc=bc+1|0}}if((Q|0)==5261){Q=0;if((bc|0)<0){bd=0}else{aZ=bc;break}}while(1){if(bd>>>0>=aR>>>0){bf=0;break}if((c[aS+(bd*12|0)+8>>2]|0)==1336318185){Q=5264;break}else{bd=bd+1|0}}if((Q|0)==5264){Q=0;if((bd|0)<0){bf=0}else{aZ=bd;break}}while(1){if(bf>>>0>=aR>>>0){bg=0;break}if((fa(c[aS+(bf*12|0)>>2]|0,376904)|0)==0){Q=5267;break}else{bf=bf+1|0}}if((Q|0)==5267){Q=0;if((bf|0)<0){bg=0}else{aZ=bf;break}}while(1){if(bg>>>0>=aR>>>0){bh=0;break}if((c[aS+(bg*12|0)+8>>2]|0)==1574571396){Q=5270;break}else{bg=bg+1|0}}if((Q|0)==5270){Q=0;if((bg|0)<0){bh=0}else{aZ=bg;break}}while(1){if(bh>>>0>=aR>>>0){bi=0;break}if((fa(c[aS+(bh*12|0)>>2]|0,376080)|0)==0){Q=5273;break}else{bh=bh+1|0}}if((Q|0)==5273){Q=0;if((bh|0)<0){bi=0}else{aZ=bh;break}}while(1){if(bi>>>0>=aR>>>0){break}if((c[aS+(bi*12|0)+8>>2]|0)==216290208){Q=5276;break}else{bi=bi+1|0}}if((Q|0)==5276){Q=0;if((bi|0)>=0){aZ=bi;break}}Z=c[aB>>2]|0;af=0;while(1){if(af>>>0>=aR>>>0){break L5993}if((c[aS+(af*12|0)+8>>2]|0)==(Z|0)){aX=af;Q=5285;break}else{af=af+1|0}}}else{af=0;while(1){if(af>>>0>=aR>>>0){break L5993}if((c[aS+(af*12|0)+8>>2]|0)==(ah|0)){aX=af;Q=5285;break}else{af=af+1|0}}}}while(0);if((Q|0)==5285){Q=0;if((aX|0)<0){break L5993}else{aZ=aX}}c[9776876+(Y*124|0)>>2]=V;c[9776880+(Y*124|0)>>2]=aZ;c[ae>>2]=1;ah=c[aS+(aZ*12|0)+4>>2]|0;aB=c[ak>>2]|0;if(ah>>>0<aB>>>0){c[ae>>2]=3;break L5993}if(ah>>>0<=aB>>>0){break L5993}c[ae>>2]=4;break L5993}}while(0);c[ae>>2]=1}}while(0);Y=Y+1|0;}while(Y>>>0<(c[2444216]|0)>>>0)}if((aS|0)!=0){if((aR|0)!=0){Y=0;do{gGr(c[aS+(Y*12|0)>>2]|0);Y=Y+1|0;}while(Y>>>0<aR>>>0)}gGr(aS)}Y=c[2426512]|0;if(a[632384]&(Y|0)!=0){lj(Y);c[2426512]=0}a[632384]=0;Y=V+1|0;ae=c[2432952]|0;if(Y>>>0<(((c[2432953]|0)-ae|0)/12|0)>>>0){V=Y;N=ae;_=aR}else{break L5950}}if((Q|0)==5177){aQ=c[2432952]|0}_=aQ+(V*12|0)|0;if((a[_]&1)==0){bj=_+1|0}else{bj=c[aQ+(V*12|0)+8>>2]|0}bU(S|0,387848,(ao=i,i=i+8|0,c[ao>>2]=bj,ao)|0)|0;i=ao;bk=0;i=f;return bk|0}}while(0);W=c[2444216]|0;L6152:do{if((W|0)!=0){X=0;_=W;while(1){if((c[9776872+(X*124|0)>>2]|0)==1){bl=_}else{N=c[9776988+(X*124|0)>>2]|0;bU(S|0,375096,(ao=i,i=i+16|0,c[ao>>2]=X,c[ao+8>>2]=N,ao)|0)|0;i=ao;if((c[9776992+(X*124|0)>>2]&134217728|0)==0){bk=0;break}bl=c[2444216]|0}N=X+1|0;if(N>>>0<bl>>>0){X=N;_=bl}else{break L6152}}i=f;return bk|0}}while(0);c[3542200]=8888;c[2113308]=2;a[9624]=1;a[9608]=1;W=c[2436]|0;if(W>>>0<(a[9736]|0?5860:0)>>>0){c[2424]=6e3;_=9681616;c[_>>2]=0;c[_+4>>2]=0;c[2427044]=0;_=c[2430396]|0;if((_|0)==0){bm=W}else{X=_;while(1){_=c[X>>2]|0;if((X|0)!=0){gGr(X)}if((_|0)==0){break}else{X=_}}bm=c[2436]|0}c[2430396]=0;gGz(9774632,0,32);gGz(9638528,0,4096);X=c[(c[642608+(bm<<2)>>2]|0)+100>>2]|0;gD[X&8191]()|0;X=c[642608+(c[2436]<<2)>>2]|0;c[2113150]=c[X+56>>2];bn=(c[2113308]|0)==2?2:4;bo=X}else{bn=2;bo=c[642608+(W<<2)>>2]|0}X=c[bo+52>>2]|0;c[2113300]=ag((X&4|0)==0?c[bo+128>>2]|0:c[bo+132>>2]|0,bn)|0;_=X&6;if((_|0)==4){c[E>>2]=1}else if((_|0)==2){c[E>>2]=2}else if((_|0)==6){c[E>>2]=3}else{c[E>>2]=0}do{if((fa(409096,J|0)|0)==0){Q=5328}else{if((fa(408384,J|0)|0)==0){Q=5328;break}if((fa(407696,J|0)|0)==0){Q=5328;break}if((fa(406816,J|0)|0)==0){Q=5328;break}if((fa(405632,J|0)|0)==0){Q=5328;break}if((fa(404304,J|0)|0)==0){Q=5328;break}if((fa(403192,J|0)|0)==0){Q=5328;break}if((fa(401832,J|0)|0)==0){Q=5328;break}if((fa(400936,J|0)|0)==0){Q=5328;break}if((fa(399944,J|0)|0)==0){Q=5328;break}if((fa(399200,J|0)|0)==0){Q=5328;break}if((fa(398208,J|0)|0)==0){Q=5328}}}while(0);if((Q|0)==5328){c[2113308]=4}bU(S|0,397488,(ao=i,i=i+8|0,c[ao>>2]=J,ao)|0)|0;i=ao;W=c[3528788]|0;gA[W&16383](1,R)|0;W=c[2436]|0;do{if(W>>>0<(a[9736]|0?5860:0)>>>0){_=c[(c[642608+(W<<2)>>2]|0)+120>>2]|0;if((_|0)==0){break}a[_]=1}}while(0);do{if((c[2113308]|0)==4){c[F>>2]=1;if(!(gA[c[3528788]&16383](10,P)|0)){break}cj(396328,63,1,S|0)|0}else{c[G>>2]=2;if(!(gA[c[3528788]&16383](10,H)|0)){break}cj(394704,62,1,S|0)|0}}while(0);a[5904928]=1;H=x;c[2113198]=0;c[2113154]=0;c[2113152]=(c[2113150]|0)*12|0;P=0;while(1){if(P>>>0>=4096){Q=5341;break}if((gA[c[(c[642608+(c[2436]<<2)>>2]|0)+92>>2]&16383](0,P)|0)==0){P=P+1|0}else{Q=5340;break}}if((Q|0)==5340){c[2113198]=P;bp=P}else if((Q|0)==5341){bp=c[2113198]|0}W=((c[2113152]|0)+bp|0)*68|0;R=gGq(W)|0;_=R;c[3541308]=_;if((R|0)==0){bq=c[2113150]|0}else{gGz(R|0,0,W|0);W=p;if((bp|0)==0){br=_}else{R=p+4|0;X=p+8|0;V=0;N=_;while(1){gGz(W|0,0,16);gA[c[(c[642608+(c[2436]<<2)>>2]|0)+92>>2]&16383](p,V)|0;_=N|0;gGz(_|0,0,68);a[N+1|0]=a[R]|0;c[N+4>>2]=c[X>>2];if((a[R]&8)!=0){a[_]=1;a[N+12|0]=a[c[X>>2]|0]|0}_=V+1|0;M=N+68|0;if(_>>>0<(c[2113198]|0)>>>0){V=_;N=M}else{br=M;break}}}N=c[2113154]|0;if((N|0)!=0){V=0;X=br;while(1){a[X+4|0]=0;R=X|0;if((a[R]|0)==-127){a[R]=0}R=V+1|0;if(R>>>0<N>>>0){V=R;X=X+68|0}else{break}}}gzo();gGz(j|0,0,16);gGz(l|0,0,16);a[64256]=0;c[2113154]=0;c[2113210]=0;if((c[2113198]|0)==0){bs=0}else{X=h|0;V=h+12|0;N=0;while(1){c[X>>2]=0;gA[c[(c[642608+(c[2436]<<2)>>2]|0)+92>>2]&16383](h,N)|0;R=c[X>>2]|0;if((R|0)==0){c[X>>2]=9534384;bt=9534384}else{bt=R}do{if((a[bt]|0)==80){R=a[bt+1|0]|0;if((R-49&255)>=4){break}W=(R<<24>>24)-49|0;do{if((W|0)==0){if((dW(457208,(c[V>>2]|0)+2|0,5)|0)!=0){break}c[2113210]=(c[2113210]|0)+1}}while(0);R=bt+2|0;if((gGF(456528,R|0)|0)==0){P=j+(W<<2)|0;c[P>>2]=c[P>>2]|1;c[k+(W*12|0)>>2]=N}if((gGF(455576,R|0)|0)==0){P=j+(W<<2)|0;c[P>>2]=c[P>>2]|2;c[k+(W*12|0)+4>>2]=N}if((gGF(454648,R|0)|0)==0){P=j+(W<<2)|0;c[P>>2]=c[P>>2]|4;c[k+(W*12|0)+8>>2]=N}if((gGF(453912,R|0)|0)==0){P=l+(W<<2)|0;c[P>>2]=c[P>>2]|1;c[m+(W*12|0)>>2]=N}if((gGF(453120,R|0)|0)==0){P=l+(W<<2)|0;c[P>>2]=c[P>>2]|2;c[m+(W*12|0)+4>>2]=N}if((gGF(451936,R|0)|0)==0){P=l+(W<<2)|0;c[P>>2]=c[P>>2]|4;c[m+(W*12|0)+8>>2]=N}P=c[(c[642608+(c[2436]<<2)>>2]|0)+60>>2]&-65536;if((P|0)==83951616){if((gGF(450744,R|0)|0)==0){c[n+(W<<4)>>2]=N}if((gGF(449312,R|0)|0)==0){c[n+(W<<4)+4>>2]=N}if((gGF(448160,R|0)|0)==0){c[n+(W<<4)+8>>2]=N}if((gGF(446904,R|0)|0)!=0){break}c[n+(W<<4)+12>>2]=N;break}else if((P|0)==134217728){if((gGF(446e3,R|0)|0)==0){c[o+(W<<4)>>2]=N}if((gGF(444992,R|0)|0)==0){c[o+(W<<4)+4>>2]=N}if((gGF(444320,R|0)|0)==0){c[o+(W<<4)+8>>2]=N}if((gGF(443392,R|0)|0)!=0){break}c[o+(W<<4)+12>>2]=N;break}else{break}}}while(0);R=N+1|0;P=c[2113198]|0;if(R>>>0<P>>>0){N=R}else{bs=P;break}}}N=c[2113150]|0;if((N|0)>0){V=h+8|0;X=(c[3541308]|0)+(bs*68|0)|0;P=0;while(1){if((c[j+(P<<2)>>2]|0)==7){a[X|0]=-128;a[X+1|0]=1;a[X+4|0]=0;R=X+34|0;M=P+1|0;cC(R|0,442160,(ao=i,i=i+8|0,c[ao>>2]=M,ao)|0)|0;i=ao;M=c[k+(P*12|0)>>2]|0;R=c[(c[642608+(c[2436]<<2)>>2]|0)+92>>2]|0;gA[R&16383](h,M)|0;c[X+8>>2]=c[V>>2];a[X+24|0]=1;M=c[k+(P*12|0)+4>>2]|0;R=c[(c[642608+(c[2436]<<2)>>2]|0)+92>>2]|0;gA[R&16383](h,M)|0;c[X+12>>2]=c[V>>2];a[X+25|0]=1;M=c[k+(P*12|0)+8>>2]|0;R=c[(c[642608+(c[2436]<<2)>>2]|0)+92>>2]|0;gA[R&16383](h,M)|0;c[X+16>>2]=c[V>>2];a[X+26|0]=1;c[2113154]=(c[2113154]|0)+1;bu=X+68|0}else{bu=X}if((c[l+(P<<2)>>2]|0)==7){a[bu|0]=-128;a[bu+1|0]=1;a[bu+4|0]=0;M=bu+34|0;R=P+1|0;cC(M|0,440736,(ao=i,i=i+8|0,c[ao>>2]=R,ao)|0)|0;i=ao;R=c[m+(P*12|0)>>2]|0;M=c[(c[642608+(c[2436]<<2)>>2]|0)+92>>2]|0;gA[M&16383](h,R)|0;c[bu+8>>2]=c[V>>2];a[bu+24|0]=1;R=c[m+(P*12|0)+4>>2]|0;M=c[(c[642608+(c[2436]<<2)>>2]|0)+92>>2]|0;gA[M&16383](h,R)|0;c[bu+12>>2]=c[V>>2];a[bu+25|0]=1;R=c[m+(P*12|0)+8>>2]|0;M=c[(c[642608+(c[2436]<<2)>>2]|0)+92>>2]|0;gA[M&16383](h,R)|0;c[bu+16>>2]=c[V>>2];a[bu+26|0]=1;c[2113154]=(c[2113154]|0)+1;bv=bu+68|0}else{bv=bu}do{if((c[2113210]|0)==4){R=c[(c[642608+(c[2436]<<2)>>2]|0)+60>>2]|0;if((R&-65536|0)==83951616){a[bv|0]=-128;a[bv+1|0]=1;a[bv+4|0]=0;M=bv+34|0;_=P+1|0;cC(M|0,439432,(ao=i,i=i+8|0,c[ao>>2]=_,ao)|0)|0;i=ao;M=n+(P<<4)|0;U=c[M>>2]|0;b=c[(c[642608+(c[2436]<<2)>>2]|0)+92>>2]|0;gA[b&16383](h,U)|0;c[bv+8>>2]=c[V>>2];a[bv+24|0]=1;U=n+(P<<4)+4|0;b=c[U>>2]|0;ae=c[(c[642608+(c[2436]<<2)>>2]|0)+92>>2]|0;gA[ae&16383](h,b)|0;c[bv+12>>2]=c[V>>2];a[bv+25|0]=1;c[2113154]=(c[2113154]|0)+1;a[bv+68|0]=-128;a[bv+69|0]=1;a[bv+72|0]=0;b=bv+102|0;cC(b|0,437976,(ao=i,i=i+8|0,c[ao>>2]=_,ao)|0)|0;i=ao;b=c[M>>2]|0;ae=c[(c[642608+(c[2436]<<2)>>2]|0)+92>>2]|0;gA[ae&16383](h,b)|0;c[bv+76>>2]=c[V>>2];a[bv+92|0]=1;b=n+(P<<4)+8|0;ae=c[b>>2]|0;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+92>>2]|0;gA[Y&16383](h,ae)|0;c[bv+80>>2]=c[V>>2];a[bv+93|0]=1;c[2113154]=(c[2113154]|0)+1;a[bv+136|0]=-128;a[bv+137|0]=1;a[bv+140|0]=0;ae=bv+170|0;cC(ae|0,436280,(ao=i,i=i+8|0,c[ao>>2]=_,ao)|0)|0;i=ao;ae=c[M>>2]|0;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+92>>2]|0;gA[Y&16383](h,ae)|0;c[bv+144>>2]=c[V>>2];a[bv+160|0]=1;ae=n+(P<<4)+12|0;Y=c[ae>>2]|0;aB=c[(c[642608+(c[2436]<<2)>>2]|0)+92>>2]|0;gA[aB&16383](h,Y)|0;c[bv+148>>2]=c[V>>2];a[bv+161|0]=1;c[2113154]=(c[2113154]|0)+1;a[bv+204|0]=-128;a[bv+205|0]=1;a[bv+208|0]=0;Y=bv+238|0;cC(Y|0,434816,(ao=i,i=i+8|0,c[ao>>2]=_,ao)|0)|0;i=ao;Y=c[U>>2]|0;aB=c[(c[642608+(c[2436]<<2)>>2]|0)+92>>2]|0;gA[aB&16383](h,Y)|0;c[bv+212>>2]=c[V>>2];a[bv+228|0]=1;Y=c[b>>2]|0;aB=c[(c[642608+(c[2436]<<2)>>2]|0)+92>>2]|0;gA[aB&16383](h,Y)|0;c[bv+216>>2]=c[V>>2];a[bv+229|0]=1;c[2113154]=(c[2113154]|0)+1;a[bv+272|0]=-128;a[bv+273|0]=1;a[bv+276|0]=0;Y=bv+306|0;cC(Y|0,433832,(ao=i,i=i+8|0,c[ao>>2]=_,ao)|0)|0;i=ao;Y=c[U>>2]|0;aB=c[(c[642608+(c[2436]<<2)>>2]|0)+92>>2]|0;gA[aB&16383](h,Y)|0;c[bv+280>>2]=c[V>>2];a[bv+296|0]=1;Y=c[ae>>2]|0;aB=c[(c[642608+(c[2436]<<2)>>2]|0)+92>>2]|0;gA[aB&16383](h,Y)|0;c[bv+284>>2]=c[V>>2];a[bv+297|0]=1;c[2113154]=(c[2113154]|0)+1;a[bv+340|0]=-128;a[bv+341|0]=1;a[bv+344|0]=0;Y=bv+374|0;cC(Y|0,433168,(ao=i,i=i+8|0,c[ao>>2]=_,ao)|0)|0;i=ao;Y=c[b>>2]|0;aB=c[(c[642608+(c[2436]<<2)>>2]|0)+92>>2]|0;gA[aB&16383](h,Y)|0;c[bv+348>>2]=c[V>>2];a[bv+364|0]=1;Y=c[ae>>2]|0;aB=c[(c[642608+(c[2436]<<2)>>2]|0)+92>>2]|0;gA[aB&16383](h,Y)|0;c[bv+352>>2]=c[V>>2];a[bv+365|0]=1;c[2113154]=(c[2113154]|0)+1;a[bv+408|0]=-128;a[bv+409|0]=1;a[bv+412|0]=0;Y=bv+442|0;cC(Y|0,432160,(ao=i,i=i+8|0,c[ao>>2]=_,ao)|0)|0;i=ao;Y=c[M>>2]|0;aB=c[(c[642608+(c[2436]<<2)>>2]|0)+92>>2]|0;gA[aB&16383](h,Y)|0;c[bv+416>>2]=c[V>>2];a[bv+432|0]=1;Y=c[U>>2]|0;aB=c[(c[642608+(c[2436]<<2)>>2]|0)+92>>2]|0;gA[aB&16383](h,Y)|0;c[bv+420>>2]=c[V>>2];a[bv+433|0]=1;Y=c[b>>2]|0;aB=c[(c[642608+(c[2436]<<2)>>2]|0)+92>>2]|0;gA[aB&16383](h,Y)|0;c[bv+424>>2]=c[V>>2];a[bv+434|0]=1;c[2113154]=(c[2113154]|0)+1;a[bv+476|0]=-128;a[bv+477|0]=1;a[bv+480|0]=0;Y=bv+510|0;cC(Y|0,431400,(ao=i,i=i+8|0,c[ao>>2]=_,ao)|0)|0;i=ao;Y=c[M>>2]|0;aB=c[(c[642608+(c[2436]<<2)>>2]|0)+92>>2]|0;gA[aB&16383](h,Y)|0;c[bv+484>>2]=c[V>>2];a[bv+500|0]=1;Y=c[U>>2]|0;aB=c[(c[642608+(c[2436]<<2)>>2]|0)+92>>2]|0;gA[aB&16383](h,Y)|0;c[bv+488>>2]=c[V>>2];a[bv+501|0]=1;Y=c[ae>>2]|0;aB=c[(c[642608+(c[2436]<<2)>>2]|0)+92>>2]|0;gA[aB&16383](h,Y)|0;c[bv+492>>2]=c[V>>2];a[bv+502|0]=1;c[2113154]=(c[2113154]|0)+1;a[bv+544|0]=-128;a[bv+545|0]=1;a[bv+548|0]=0;Y=bv+578|0;cC(Y|0,430400,(ao=i,i=i+8|0,c[ao>>2]=_,ao)|0)|0;i=ao;Y=c[M>>2]|0;aB=c[(c[642608+(c[2436]<<2)>>2]|0)+92>>2]|0;gA[aB&16383](h,Y)|0;c[bv+552>>2]=c[V>>2];a[bv+568|0]=1;Y=c[b>>2]|0;aB=c[(c[642608+(c[2436]<<2)>>2]|0)+92>>2]|0;gA[aB&16383](h,Y)|0;c[bv+556>>2]=c[V>>2];a[bv+569|0]=1;Y=c[ae>>2]|0;aB=c[(c[642608+(c[2436]<<2)>>2]|0)+92>>2]|0;gA[aB&16383](h,Y)|0;c[bv+560>>2]=c[V>>2];a[bv+570|0]=1;c[2113154]=(c[2113154]|0)+1;a[bv+612|0]=-128;a[bv+613|0]=1;a[bv+616|0]=0;Y=bv+646|0;cC(Y|0,429328,(ao=i,i=i+8|0,c[ao>>2]=_,ao)|0)|0;i=ao;Y=c[U>>2]|0;aB=c[(c[642608+(c[2436]<<2)>>2]|0)+92>>2]|0;gA[aB&16383](h,Y)|0;c[bv+620>>2]=c[V>>2];a[bv+636|0]=1;Y=c[b>>2]|0;aB=c[(c[642608+(c[2436]<<2)>>2]|0)+92>>2]|0;gA[aB&16383](h,Y)|0;c[bv+624>>2]=c[V>>2];a[bv+637|0]=1;Y=c[ae>>2]|0;aB=c[(c[642608+(c[2436]<<2)>>2]|0)+92>>2]|0;gA[aB&16383](h,Y)|0;c[bv+628>>2]=c[V>>2];a[bv+638|0]=1;c[2113154]=(c[2113154]|0)+1;a[bv+680|0]=-128;a[bv+681|0]=1;a[bv+684|0]=0;Y=bv+714|0;cC(Y|0,428296,(ao=i,i=i+8|0,c[ao>>2]=_,ao)|0)|0;i=ao;_=c[M>>2]|0;M=c[(c[642608+(c[2436]<<2)>>2]|0)+92>>2]|0;gA[M&16383](h,_)|0;c[bv+688>>2]=c[V>>2];a[bv+704|0]=1;_=c[U>>2]|0;U=c[(c[642608+(c[2436]<<2)>>2]|0)+92>>2]|0;gA[U&16383](h,_)|0;c[bv+692>>2]=c[V>>2];a[bv+705|0]=1;_=c[b>>2]|0;b=c[(c[642608+(c[2436]<<2)>>2]|0)+92>>2]|0;gA[b&16383](h,_)|0;c[bv+696>>2]=c[V>>2];a[bv+706|0]=1;_=c[ae>>2]|0;ae=c[(c[642608+(c[2436]<<2)>>2]|0)+92>>2]|0;gA[ae&16383](h,_)|0;c[bv+700>>2]=c[V>>2];a[bv+707|0]=1;c[2113154]=(c[2113154]|0)+1;_=bv+748|0;if((c[2113210]|0)!=4){bw=_;break}bx=_;by=c[(c[642608+(c[2436]<<2)>>2]|0)+60>>2]|0}else{bx=bv;by=R}if((by&-65536|0)!=134217728){bw=bx;break}a[bx|0]=-128;a[bx+1|0]=1;a[bx+4|0]=0;R=bx+34|0;_=P+1|0;cC(R|0,427088,(ao=i,i=i+8|0,c[ao>>2]=_,ao)|0)|0;i=ao;R=o+(P<<4)|0;ae=c[R>>2]|0;b=c[(c[642608+(c[2436]<<2)>>2]|0)+92>>2]|0;gA[b&16383](h,ae)|0;c[bx+8>>2]=c[V>>2];a[bx+24|0]=1;ae=o+(P<<4)+4|0;b=c[ae>>2]|0;U=c[(c[642608+(c[2436]<<2)>>2]|0)+92>>2]|0;gA[U&16383](h,b)|0;c[bx+12>>2]=c[V>>2];a[bx+25|0]=1;c[2113154]=(c[2113154]|0)+1;a[bx+68|0]=-128;a[bx+69|0]=1;a[bx+72|0]=0;b=bx+102|0;cC(b|0,425672,(ao=i,i=i+8|0,c[ao>>2]=_,ao)|0)|0;i=ao;b=c[R>>2]|0;U=c[(c[642608+(c[2436]<<2)>>2]|0)+92>>2]|0;gA[U&16383](h,b)|0;c[bx+76>>2]=c[V>>2];a[bx+92|0]=1;b=o+(P<<4)+8|0;U=c[b>>2]|0;M=c[(c[642608+(c[2436]<<2)>>2]|0)+92>>2]|0;gA[M&16383](h,U)|0;c[bx+80>>2]=c[V>>2];a[bx+93|0]=1;c[2113154]=(c[2113154]|0)+1;a[bx+136|0]=-128;a[bx+137|0]=1;a[bx+140|0]=0;U=bx+170|0;cC(U|0,424448,(ao=i,i=i+8|0,c[ao>>2]=_,ao)|0)|0;i=ao;U=c[R>>2]|0;M=c[(c[642608+(c[2436]<<2)>>2]|0)+92>>2]|0;gA[M&16383](h,U)|0;c[bx+144>>2]=c[V>>2];a[bx+160|0]=1;U=o+(P<<4)+12|0;M=c[U>>2]|0;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+92>>2]|0;gA[Y&16383](h,M)|0;c[bx+148>>2]=c[V>>2];a[bx+161|0]=1;c[2113154]=(c[2113154]|0)+1;a[bx+204|0]=-128;a[bx+205|0]=1;a[bx+208|0]=0;M=bx+238|0;cC(M|0,423496,(ao=i,i=i+8|0,c[ao>>2]=_,ao)|0)|0;i=ao;M=c[ae>>2]|0;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+92>>2]|0;gA[Y&16383](h,M)|0;c[bx+212>>2]=c[V>>2];a[bx+228|0]=1;M=c[b>>2]|0;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+92>>2]|0;gA[Y&16383](h,M)|0;c[bx+216>>2]=c[V>>2];a[bx+229|0]=1;c[2113154]=(c[2113154]|0)+1;a[bx+272|0]=-128;a[bx+273|0]=1;a[bx+276|0]=0;M=bx+306|0;cC(M|0,422368,(ao=i,i=i+8|0,c[ao>>2]=_,ao)|0)|0;i=ao;M=c[ae>>2]|0;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+92>>2]|0;gA[Y&16383](h,M)|0;c[bx+280>>2]=c[V>>2];a[bx+296|0]=1;M=c[U>>2]|0;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+92>>2]|0;gA[Y&16383](h,M)|0;c[bx+284>>2]=c[V>>2];a[bx+297|0]=1;c[2113154]=(c[2113154]|0)+1;a[bx+340|0]=-128;a[bx+341|0]=1;a[bx+344|0]=0;M=bx+374|0;cC(M|0,421752,(ao=i,i=i+8|0,c[ao>>2]=_,ao)|0)|0;i=ao;M=c[b>>2]|0;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+92>>2]|0;gA[Y&16383](h,M)|0;c[bx+348>>2]=c[V>>2];a[bx+364|0]=1;M=c[U>>2]|0;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+92>>2]|0;gA[Y&16383](h,M)|0;c[bx+352>>2]=c[V>>2];a[bx+365|0]=1;c[2113154]=(c[2113154]|0)+1;a[bx+408|0]=-128;a[bx+409|0]=1;a[bx+412|0]=0;M=bx+442|0;cC(M|0,420760,(ao=i,i=i+8|0,c[ao>>2]=_,ao)|0)|0;i=ao;M=c[R>>2]|0;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+92>>2]|0;gA[Y&16383](h,M)|0;c[bx+416>>2]=c[V>>2];a[bx+432|0]=1;M=c[ae>>2]|0;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+92>>2]|0;gA[Y&16383](h,M)|0;c[bx+420>>2]=c[V>>2];a[bx+433|0]=1;M=c[b>>2]|0;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+92>>2]|0;gA[Y&16383](h,M)|0;c[bx+424>>2]=c[V>>2];a[bx+434|0]=1;c[2113154]=(c[2113154]|0)+1;a[bx+476|0]=-128;a[bx+477|0]=1;a[bx+480|0]=0;M=bx+510|0;cC(M|0,419392,(ao=i,i=i+8|0,c[ao>>2]=_,ao)|0)|0;i=ao;M=c[R>>2]|0;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+92>>2]|0;gA[Y&16383](h,M)|0;c[bx+484>>2]=c[V>>2];a[bx+500|0]=1;M=c[ae>>2]|0;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+92>>2]|0;gA[Y&16383](h,M)|0;c[bx+488>>2]=c[V>>2];a[bx+501|0]=1;M=c[U>>2]|0;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+92>>2]|0;gA[Y&16383](h,M)|0;c[bx+492>>2]=c[V>>2];a[bx+502|0]=1;c[2113154]=(c[2113154]|0)+1;a[bx+544|0]=-128;a[bx+545|0]=1;a[bx+548|0]=0;M=bx+578|0;cC(M|0,418008,(ao=i,i=i+8|0,c[ao>>2]=_,ao)|0)|0;i=ao;M=c[R>>2]|0;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+92>>2]|0;gA[Y&16383](h,M)|0;c[bx+552>>2]=c[V>>2];a[bx+568|0]=1;M=c[b>>2]|0;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+92>>2]|0;gA[Y&16383](h,M)|0;c[bx+556>>2]=c[V>>2];a[bx+569|0]=1;M=c[U>>2]|0;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+92>>2]|0;gA[Y&16383](h,M)|0;c[bx+560>>2]=c[V>>2];a[bx+570|0]=1;c[2113154]=(c[2113154]|0)+1;a[bx+612|0]=-128;a[bx+613|0]=1;a[bx+616|0]=0;M=bx+646|0;cC(M|0,416424,(ao=i,i=i+8|0,c[ao>>2]=_,ao)|0)|0;i=ao;M=c[ae>>2]|0;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+92>>2]|0;gA[Y&16383](h,M)|0;c[bx+620>>2]=c[V>>2];a[bx+636|0]=1;M=c[b>>2]|0;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+92>>2]|0;gA[Y&16383](h,M)|0;c[bx+624>>2]=c[V>>2];a[bx+637|0]=1;M=c[U>>2]|0;Y=c[(c[642608+(c[2436]<<2)>>2]|0)+92>>2]|0;gA[Y&16383](h,M)|0;c[bx+628>>2]=c[V>>2];a[bx+638|0]=1;c[2113154]=(c[2113154]|0)+1;a[bx+680|0]=-128;a[bx+681|0]=1;a[bx+684|0]=0;M=bx+714|0;cC(M|0,414864,(ao=i,i=i+8|0,c[ao>>2]=_,ao)|0)|0;i=ao;_=c[R>>2]|0;R=c[(c[642608+(c[2436]<<2)>>2]|0)+92>>2]|0;gA[R&16383](h,_)|0;c[bx+688>>2]=c[V>>2];a[bx+704|0]=1;_=c[ae>>2]|0;ae=c[(c[642608+(c[2436]<<2)>>2]|0)+92>>2]|0;gA[ae&16383](h,_)|0;c[bx+692>>2]=c[V>>2];a[bx+705|0]=1;_=c[b>>2]|0;b=c[(c[642608+(c[2436]<<2)>>2]|0)+92>>2]|0;gA[b&16383](h,_)|0;c[bx+696>>2]=c[V>>2];a[bx+706|0]=1;_=c[U>>2]|0;U=c[(c[642608+(c[2436]<<2)>>2]|0)+92>>2]|0;gA[U&16383](h,_)|0;c[bx+700>>2]=c[V>>2];a[bx+707|0]=1;c[2113154]=(c[2113154]|0)+1;bw=bx+748|0}else{bw=bv}}while(0);_=P+1|0;U=c[2113150]|0;if((_|0)<(U|0)){X=bw;P=_}else{bz=U;break}}}else{bz=N}do{if((c[j>>2]|0)==7){if((c[l>>2]|0)!=7){break}a[64256]=1}}while(0);do{if((c[2113210]|0)>4){if((c[(c[642608+(c[2436]<<2)>>2]|0)+60>>2]&-65536|0)!=117506048){break}a[64256]=1}}while(0);a[9768]=1;bq=bz}if((bq|0)>0){N=0;do{N=N+1|0;}while((N|0)<(bq|0))}N=c[3541308]|0;if((c[2113198]|0)==0){bA=N;bB=0}else{P=g+12|0;X=g+8|0;V=g+4|0;U=N;N=0;while(1){_=U|0;do{if((a[_]|0)==0){c[P>>2]=0;b=c[(c[642608+(c[2436]<<2)>>2]|0)+92>>2]|0;gA[b&16383](g,N)|0;if((c[X>>2]|0)==0){break}b=c[P>>2]|0;if((b|0)==0){c[P>>2]=9534384;bC=9534384}else{bC=b}if((a[V]&8)==0){R$(U,bC);break}else{a[_]=1;break}}}while(0);_=N+1|0;b=U+68|0;ae=c[2113198]|0;if(_>>>0<ae>>>0){U=b;N=_}else{bA=b;bB=ae;break}}}N=c[2113154]|0;if((N|0)==0){bD=bB}else{U=bA;V=0;P=N;while(1){do{if((a[U|0]|0)==-128){if((a[U+4|0]|0)!=0){bE=P;break}R$(U,U+34|0);bE=c[2113154]|0}else{bE=P}}while(0);N=V+1|0;if(N>>>0<bE>>>0){U=U+68|0;V=N;P=bE}else{break}}bD=c[2113198]|0}L6342:do{if((bD|0)==0){bF=0}else{P=0;V=c[3541308]|0;while(1){if((a[V+1|0]|0)==4){bF=1;break L6342}U=P+1|0;if(U>>>0<bD>>>0){P=U;V=V+68|0}else{bF=0;break}}}}while(0);V=c[642608+(c[2436]<<2)>>2]|0;P=c[V+4>>2]|0;U=c[V+8>>2]|0;N=c[V>>2]|0;X=c[V+64>>2]|0;ae=c[V+60>>2]|0;bU(S|0,561936,(ao=i,i=i+8|0,c[ao>>2]=bF,ao)|0)|0;i=ao;V=(P|0)!=0;if(V){bU(S|0,545776,(ao=i,i=i+8|0,c[ao>>2]=P,ao)|0)|0;i=ao}b=(U|0)!=0;if(b){bU(S|0,532104,(ao=i,i=i+8|0,c[ao>>2]=U,ao)|0)|0;i=ao}if((N|0)!=0){bU(S|0,518456,(ao=i,i=i+8|0,c[ao>>2]=N,ao)|0)|0;i=ao}bU(S|0,505280,(ao=i,i=i+8|0,c[ao>>2]=X,ao)|0)|0;i=ao;bU(S|0,493256,(ao=i,i=i+8|0,c[ao>>2]=ae,ao)|0)|0;i=ao;gGz(H|0,0,16);ae=0;do{a[9579392+(ae<<1)|0]=-1;ae=ae+1|0;}while(ae>>>0<20480);ae=c[3541308]|0;c[y>>2]=480936;c[y+4>>2]=2;c[y+8>>2]=0;c[y+12>>2]=468504;c[y+16>>2]=3;c[y+20>>2]=0;c[y+24>>2]=457272;c[y+28>>2]=3;c[y+32>>2]=0;c[y+36>>2]=447032;c[y+40>>2]=4;c[y+44>>2]=0;c[y+48>>2]=434968;c[y+52>>2]=5;c[y+56>>2]=0;c[y+60>>2]=424600;c[y+64>>2]=6;c[y+68>>2]=0;c[y+72>>2]=411840;c[y+76>>2]=7;c[y+80>>2]=0;c[y+84>>2]=401304;c[y+88>>2]=1;c[y+92>>2]=0;c[y+96>>2]=389328;c[y+100>>2]=0;c[y+104>>2]=0;c[y+108>>2]=379168;c[y+112>>2]=1;c[y+116>>2]=0;c[y+120>>2]=368672;c[y+124>>2]=8;c[y+128>>2]=0;c[y+132>>2]=360232;c[y+136>>2]=8;c[y+140>>2]=0;c[y+144>>2]=352760;c[y+148>>2]=0;c[y+152>>2]=0;c[y+156>>2]=344952;c[y+160>>2]=8;c[y+164>>2]=0;c[y+168>>2]=337016;c[y+172>>2]=8;c[y+176>>2]=0;c[y+180>>2]=329368;c[y+184>>2]=9;c[y+188>>2]=0;c[y+192>>2]=320152;c[y+196>>2]=1;c[y+200>>2]=0;c[y+204>>2]=310952;c[y+208>>2]=9;c[y+212>>2]=0;c[y+216>>2]=302832;c[y+220>>2]=10;c[y+224>>2]=0;c[y+228>>2]=295048;c[y+232>>2]=0;c[y+236>>2]=0;c[y+240>>2]=288176;c[y+244>>2]=8;c[y+248>>2]=0;c[y+252>>2]=281480;c[y+256>>2]=11;c[y+260>>2]=0;c[y+264>>2]=274632;c[y+268>>2]=0;c[y+272>>2]=0;c[y+276>>2]=267576;c[y+280>>2]=8;c[y+284>>2]=0;c[y+288>>2]=259592;c[y+292>>2]=1;c[y+296>>2]=0;c[y+300>>2]=250920;c[y+304>>2]=0;c[y+308>>2]=0;c[y+312>>2]=243816;c[y+316>>2]=8;c[y+320>>2]=0;c[y+324>>2]=237288;c[y+328>>2]=0;c[y+332>>2]=0;c[y+336>>2]=230936;c[y+340>>2]=9;c[y+344>>2]=0;c[y+348>>2]=224968;c[y+352>>2]=1;c[y+356>>2]=0;c[y+360>>2]=219512;c[y+364>>2]=0;c[y+368>>2]=0;c[y+372>>2]=215672;c[y+376>>2]=8;c[y+380>>2]=0;c[y+384>>2]=212416;c[y+388>>2]=9;c[y+392>>2]=0;c[y+396>>2]=208104;c[y+400>>2]=8;c[y+404>>2]=0;c[y+408>>2]=201864;c[y+412>>2]=8;c[y+416>>2]=0;c[y+420>>2]=196504;c[y+424>>2]=1;c[y+428>>2]=0;c[y+432>>2]=190944;c[y+436>>2]=9;c[y+440>>2]=0;c[y+444>>2]=184864;c[y+448>>2]=0;c[y+452>>2]=0;c[y+456>>2]=180184;c[y+460>>2]=8;c[y+464>>2]=0;c[y+468>>2]=175888;c[y+472>>2]=0;c[y+476>>2]=0;c[y+480>>2]=175888;c[y+484>>2]=0;c[y+488>>2]=0;c[y+492>>2]=172120;c[y+496>>2]=8;c[y+500>>2]=0;c[y+504>>2]=168744;c[y+508>>2]=8;c[y+512>>2]=0;c[y+516>>2]=243816;c[y+520>>2]=8;c[y+524>>2]=0;c[y+528>>2]=165744;c[y+532>>2]=1;c[y+536>>2]=0;c[y+540>>2]=162608;c[y+544>>2]=1;c[y+548>>2]=0;c[y+552>>2]=158896;c[y+556>>2]=1;c[y+560>>2]=0;c[y+564>>2]=156288;c[y+568>>2]=0;c[y+572>>2]=0;c[y+576>>2]=152112;c[y+580>>2]=8;c[y+584>>2]=0;c[y+588>>2]=148832;c[y+592>>2]=0;c[y+596>>2]=0;c[y+600>>2]=145296;c[y+604>>2]=8;c[y+608>>2]=0;c[y+612>>2]=141496;c[y+616>>2]=2;c[y+620>>2]=0;c[y+624>>2]=138888;c[y+628>>2]=0;c[y+632>>2]=0;c[y+636>>2]=136160;c[y+640>>2]=8;c[y+644>>2]=0;c[y+648>>2]=133848;c[y+652>>2]=1;c[y+656>>2]=0;c[y+660>>2]=132088;c[y+664>>2]=9;c[y+668>>2]=0;c[y+672>>2]=128552;c[y+676>>2]=2;c[y+680>>2]=1;c[y+684>>2]=126096;c[y+688>>2]=3;c[y+692>>2]=1;c[y+696>>2]=122800;c[y+700>>2]=4;c[y+704>>2]=1;c[y+708>>2]=119232;c[y+712>>2]=5;c[y+716>>2]=1;c[y+720>>2]=116248;c[y+724>>2]=6;c[y+728>>2]=1;c[y+732>>2]=114040;c[y+736>>2]=7;c[y+740>>2]=1;c[y+744>>2]=112136;c[y+748>>2]=1;c[y+752>>2]=1;c[y+756>>2]=110248;c[y+760>>2]=8;c[y+764>>2]=1;c[y+768>>2]=108320;c[y+772>>2]=0;c[y+776>>2]=1;c[y+780>>2]=106520;c[y+784>>2]=8;c[y+788>>2]=1;c[y+792>>2]=103808;c[y+796>>2]=8;c[y+800>>2]=1;c[y+804>>2]=101512;c[y+808>>2]=9;c[y+812>>2]=1;c[y+816>>2]=97832;c[y+820>>2]=1;c[y+824>>2]=1;c[y+828>>2]=94208;c[y+832>>2]=9;c[y+836>>2]=1;c[y+840>>2]=91392;c[y+844>>2]=10;c[y+848>>2]=1;c[y+852>>2]=89080;c[y+856>>2]=0;c[y+860>>2]=1;c[y+864>>2]=87424;c[y+868>>2]=8;c[y+872>>2]=1;c[y+876>>2]=85240;c[y+880>>2]=11;c[y+884>>2]=1;c[y+888>>2]=83624;c[y+892>>2]=0;c[y+896>>2]=1;c[y+900>>2]=82192;c[y+904>>2]=8;c[y+908>>2]=1;c[y+912>>2]=80376;c[y+916>>2]=1;c[y+920>>2]=1;c[y+924>>2]=78376;c[y+928>>2]=0;c[y+932>>2]=1;c[y+936>>2]=76240;c[y+940>>2]=8;c[y+944>>2]=1;c[y+948>>2]=73928;c[y+952>>2]=0;c[y+956>>2]=1;c[y+960>>2]=71392;c[y+964>>2]=1;c[y+968>>2]=1;c[y+972>>2]=69280;c[y+976>>2]=0;c[y+980>>2]=1;c[y+984>>2]=68016;c[y+988>>2]=8;c[y+992>>2]=1;c[y+996>>2]=66504;c[y+1e3>>2]=9;c[y+1004>>2]=1;c[y+1008>>2]=65248;c[y+1012>>2]=8;c[y+1016>>2]=1;c[y+1020>>2]=588728;c[y+1024>>2]=9;c[y+1028>>2]=1;c[y+1032>>2]=586968;c[y+1036>>2]=8;c[y+1040>>2]=1;c[y+1044>>2]=585264;c[y+1048>>2]=1;c[y+1052>>2]=1;c[y+1056>>2]=583392;c[y+1060>>2]=9;c[y+1064>>2]=1;c[y+1068>>2]=581216;c[y+1072>>2]=0;c[y+1076>>2]=1;c[y+1080>>2]=579128;c[y+1084>>2]=8;c[y+1088>>2]=1;c[y+1092>>2]=577304;c[y+1096>>2]=0;c[y+1100>>2]=1;c[y+1104>>2]=576192;c[y+1108>>2]=8;c[y+1112>>2]=1;c[y+1116>>2]=574920;c[y+1120>>2]=8;c[y+1124>>2]=1;c[y+1128>>2]=76240;c[y+1132>>2]=8;c[y+1136>>2]=1;c[y+1140>>2]=573712;c[y+1144>>2]=1;c[y+1148>>2]=1;c[y+1152>>2]=572408;c[y+1156>>2]=1;c[y+1160>>2]=1;c[y+1164>>2]=570296;c[y+1168>>2]=0;c[y+1172>>2]=1;c[y+1176>>2]=568816;c[y+1180>>2]=8;c[y+1184>>2]=1;c[y+1188>>2]=566456;c[y+1192>>2]=2;c[y+1196>>2]=1;c[y+1200>>2]=564152;c[y+1204>>2]=0;c[y+1208>>2]=1;c[y+1212>>2]=562568;c[y+1216>>2]=8;c[y+1220>>2]=1;c[y+1224>>2]=560856;c[y+1228>>2]=1;c[y+1232>>2]=1;c[y+1236>>2]=559656;c[y+1240>>2]=9;c[y+1244>>2]=1;c[y+1248>>2]=558248;c[y+1252>>2]=2;c[y+1256>>2]=2;c[y+1260>>2]=556616;c[y+1264>>2]=3;c[y+1268>>2]=2;c[y+1272>>2]=555712;c[y+1276>>2]=4;c[y+1280>>2]=2;c[y+1284>>2]=554024;c[y+1288>>2]=5;c[y+1292>>2]=2;c[y+1296>>2]=552520;c[y+1300>>2]=6;c[y+1304>>2]=2;c[y+1308>>2]=550584;c[y+1312>>2]=7;c[y+1316>>2]=2;c[y+1320>>2]=548344;c[y+1324>>2]=1;c[y+1328>>2]=2;c[y+1332>>2]=546456;c[y+1336>>2]=0;c[y+1340>>2]=2;c[y+1344>>2]=544984;c[y+1348>>2]=8;c[y+1352>>2]=2;c[y+1356>>2]=543808;c[y+1360>>2]=8;c[y+1364>>2]=2;c[y+1368>>2]=542376;c[y+1372>>2]=9;c[y+1376>>2]=2;c[y+1380>>2]=541688;c[y+1384>>2]=1;c[y+1388>>2]=2;c[y+1392>>2]=540808;c[y+1396>>2]=0;c[y+1400>>2]=2;c[y+1404>>2]=539264;c[y+1408>>2]=8;c[y+1412>>2]=2;c[y+1416>>2]=538056;c[y+1420>>2]=9;c[y+1424>>2]=2;c[y+1428>>2]=536048;c[y+1432>>2]=1;c[y+1436>>2]=2;c[y+1440>>2]=534056;c[y+1444>>2]=0;c[y+1448>>2]=2;c[y+1452>>2]=532528;c[y+1456>>2]=8;c[y+1460>>2]=2;c[y+1464>>2]=531560;c[y+1468>>2]=2;c[y+1472>>2]=2;c[y+1476>>2]=530408;c[y+1480>>2]=2;c[y+1484>>2]=3;c[y+1488>>2]=529312;c[y+1492>>2]=3;c[y+1496>>2]=3;c[y+1500>>2]=528632;c[y+1504>>2]=4;c[y+1508>>2]=3;c[y+1512>>2]=527552;c[y+1516>>2]=5;c[y+1520>>2]=3;c[y+1524>>2]=525792;c[y+1528>>2]=6;c[y+1532>>2]=3;c[y+1536>>2]=524688;c[y+1540>>2]=7;c[y+1544>>2]=3;c[y+1548>>2]=522848;c[y+1552>>2]=1;c[y+1556>>2]=3;c[y+1560>>2]=520568;c[y+1564>>2]=0;c[y+1568>>2]=3;c[y+1572>>2]=519224;c[y+1576>>2]=8;c[y+1580>>2]=3;c[y+1584>>2]=517720;c[y+1588>>2]=8;c[y+1592>>2]=3;c[y+1596>>2]=516720;c[y+1600>>2]=9;c[y+1604>>2]=3;c[y+1608>>2]=515760;c[y+1612>>2]=1;c[y+1616>>2]=3;c[y+1620>>2]=514736;c[y+1624>>2]=0;c[y+1628>>2]=3;c[y+1632>>2]=513784;c[y+1636>>2]=8;c[y+1640>>2]=3;c[y+1644>>2]=512320;c[y+1648>>2]=9;c[y+1652>>2]=3;c[y+1656>>2]=511048;c[y+1660>>2]=1;c[y+1664>>2]=3;c[y+1668>>2]=509136;c[y+1672>>2]=0;c[y+1676>>2]=3;c[y+1680>>2]=507384;c[y+1684>>2]=8;c[y+1688>>2]=3;c[y+1692>>2]=505664;c[y+1696>>2]=2;c[y+1700>>2]=3;c[y+1704>>2]=504688;c[y+1708>>2]=8;c[y+1712>>2]=0;c[y+1716>>2]=503792;c[y+1720>>2]=0;c[y+1724>>2]=0;c[y+1728>>2]=502712;c[y+1732>>2]=1;c[y+1736>>2]=0;c[y+1740>>2]=501744;c[y+1744>>2]=4;c[y+1748>>2]=0;c[y+1752>>2]=500656;c[y+1756>>2]=5;c[y+1760>>2]=0;c[y+1764>>2]=499408;c[y+1768>>2]=6;c[y+1772>>2]=0;c[y+1776>>2]=498360;c[y+1780>>2]=7;c[y+1784>>2]=0;c[y+1788>>2]=496984;c[y+1792>>2]=3;c[y+1796>>2]=1;c[y+1800>>2]=495160;c[y+1804>>2]=1;c[y+1808>>2]=0;c[y+1812>>2]=493768;c[y+1816>>2]=9;c[y+1820>>2]=0;c[y+1824>>2]=492760;c[y+1828>>2]=0;c[y+1832>>2]=0;c[y+1836>>2]=491816;c[y+1840>>2]=8;c[y+1844>>2]=0;c[y+1848>>2]=491096;c[y+1852>>2]=1;c[y+1856>>2]=1;c[y+1860>>2]=490248;c[y+1864>>2]=9;c[y+1868>>2]=1;c[y+1872>>2]=489224;c[y+1876>>2]=0;c[y+1880>>2]=1;c[y+1884>>2]=487992;c[y+1888>>2]=8;c[y+1892>>2]=1;c[y+1896>>2]=486536;c[y+1900>>2]=9;c[y+1904>>2]=0;c[y+1908>>2]=485016;c[y+1912>>2]=11;c[y+1916>>2]=0;c[y+1920>>2]=483336;c[y+1924>>2]=4;c[y+1928>>2]=1;c[y+1932>>2]=481584;c[y+1936>>2]=5;c[y+1940>>2]=1;c[y+1944>>2]=480016;c[y+1948>>2]=6;c[y+1952>>2]=1;c[y+1956>>2]=479072;c[y+1960>>2]=7;c[y+1964>>2]=1;c[y+1968>>2]=478256;c[y+1972>>2]=1;c[y+1976>>2]=1;c[y+1980>>2]=477328;c[y+1984>>2]=0;c[y+1988>>2]=1;c[y+1992>>2]=476128;c[y+1996>>2]=8;c[y+2e3>>2]=1;c[y+2004>>2]=475032;c[y+2008>>2]=9;c[y+2012>>2]=1;c[y+2016>>2]=473784;c[y+2020>>2]=11;c[y+2024>>2]=1;c[y+2028>>2]=472112;c[y+2032>>2]=0;c[y+2036>>2]=0;c[y+2040>>2]=470792;c[y+2044>>2]=8;c[y+2048>>2]=0;c[y+2052>>2]=469112;c[y+2056>>2]=9;c[y+2060>>2]=0;c[y+2064>>2]=468032;c[y+2068>>2]=0;c[y+2072>>2]=1;c[y+2076>>2]=467368;c[y+2080>>2]=8;c[y+2084>>2]=1;c[y+2088>>2]=466272;c[y+2092>>2]=9;c[y+2096>>2]=1;c[y+2100>>2]=465616;c[y+2104>>2]=9;c[y+2108>>2]=0;c[y+2112>>2]=464888;c[y+2116>>2]=3;c[y+2120>>2]=2;c[y+2124>>2]=463664;c[y+2128>>2]=3;c[y+2132>>2]=3;c[y+2136>>2]=462320;c[y+2140>>2]=10;c[y+2144>>2]=0;c[y+2148>>2]=461064;c[y+2152>>2]=10;c[y+2156>>2]=1;c[y+2160>>2]=459328;c[y+2164>>2]=11;c[y+2168>>2]=0;c[y+2172>>2]=457720;c[y+2176>>2]=11;c[y+2180>>2]=1;c[y+2184>>2]=456824;c[y+2188>>2]=3;c[y+2192>>2]=0;c[y+2196>>2]=455984;c[y+2200>>2]=3;c[y+2204>>2]=1;c[y+2208>>2]=454872;c[y+2212>>2]=10;c[y+2216>>2]=0;c[y+2220>>2]=454344;c[y+2224>>2]=12;c[y+2228>>2]=0;c[y+2232>>2]=453520;c[y+2236>>2]=11;c[y+2240>>2]=0;c[y+2244>>2]=452472;c[y+2248>>2]=11;c[y+2252>>2]=0;c[y+2256>>2]=451336;c[y+2260>>2]=0;c[y+2264>>2]=0;c[y+2268>>2]=450184;c[y+2272>>2]=8;c[y+2276>>2]=0;c[y+2280>>2]=448888;c[y+2284>>2]=0;c[y+2288>>2]=1;c[y+2292>>2]=447536;c[y+2296>>2]=8;c[y+2300>>2]=1;c[y+2304>>2]=446408;c[y+2308>>2]=1;c[y+2312>>2]=0;c[y+2316>>2]=445480;c[y+2320>>2]=0;c[y+2324>>2]=0;c[y+2328>>2]=444656;c[y+2332>>2]=1;c[y+2336>>2]=1;c[y+2340>>2]=443816;c[y+2344>>2]=0;c[y+2348>>2]=1;c[y+2352>>2]=443e3;c[y+2356>>2]=10;c[y+2360>>2]=0;c[y+2364>>2]=441696;c[y+2368>>2]=11;c[y+2372>>2]=0;c[y+2376>>2]=440272;c[y+2380>>2]=10;c[y+2384>>2]=1;c[y+2388>>2]=438728;c[y+2392>>2]=11;c[y+2396>>2]=1;if((c[2113198]|0)==0){bG=1;break}H=x|0;X=c[u>>2]|0;_=ae;ae=0;while(1){gA[c[(c[642608+(c[2436]<<2)>>2]|0)+92>>2]&16383](x,ae)|0;R=c[H>>2]|0;L6363:do{if(b){M=0;while(1){if(M>>>0>=200){Q=5493;break L6363}if((fa(R|0,337016)|0)==0){if((fa(U|0,437320)|0)==0){Q=5458;break}}if((fa(R|0,237288)|0)==0){if(V){if((fa(P|0,435592)|0)==0){Q=5463;break L6363}}if((fa(N|0,435592)|0)==0){Q=5463;break L6363}}if((fa(R|0,103808)|0)==0){if((fa(U|0,437320)|0)==0){Q=5466;break}}if(V){if((fa(P|0,435592)|0)==0){Q=5470}else{Q=5469}}else{Q=5469}if((Q|0)==5469){Q=0;if((fa(N|0,435592)|0)==0){Q=5470}}if((Q|0)==5470){Q=0;if((fa(R|0,73928)|0)==0){Q=5471;break L6363}}if((fa(R|0,c[y+(M*12|0)>>2]|0)|0)==0){bH=M;Q=5475;break L6363}else{M=M+1|0}}if((Q|0)==5458){Q=0;M=e[_+12>>1]|0;a[9579392+(M<<1)|0]=2;a[9579393+(M<<1)|0]=0;bI=0}else if((Q|0)==5466){Q=0;M=e[_+12>>1]|0;a[9579392+(M<<1)|0]=2;a[9579393+(M<<1)|0]=1;bI=1}bJ=bI;bK=_+12|0;Q=5477}else{M=0;while(1){if(M>>>0>=200){Q=5493;break L6363}if((fa(R|0,237288)|0)==0){if(V){if((fa(P|0,435592)|0)==0){Q=5463;break L6363}}if((fa(N|0,435592)|0)==0){Q=5463;break L6363}}if(V){if((fa(P|0,435592)|0)==0){Q=5453}else{Q=5452}}else{Q=5452}if((Q|0)==5452){Q=0;if((fa(N|0,435592)|0)==0){Q=5453}}if((Q|0)==5453){Q=0;if((fa(R|0,73928)|0)==0){Q=5471;break L6363}}if((fa(R|0,c[y+(M*12|0)>>2]|0)|0)==0){bH=M;Q=5475;break}else{M=M+1|0}}}}while(0);L6406:do{if((Q|0)==5463){Q=0;M=e[_+12>>1]|0;a[9579392+(M<<1)|0]=8;a[9579393+(M<<1)|0]=0;bL=0;Q=5474}else if((Q|0)==5471){Q=0;M=e[_+12>>1]|0;a[9579392+(M<<1)|0]=8;a[9579393+(M<<1)|0]=1;bL=1;Q=5474}else if((Q|0)==5475){Q=0;M=c[y+(bH*12|0)+4>>2]|0;W=e[_+12>>1]|0;a[9579392+(W<<1)|0]=M&255;Y=c[y+(bH*12|0)+8>>2]|0;a[9579393+(W<<1)|0]=Y&255;W=Y&255;Y=_+12|0;switch(M&255|0){case 1:{bM=430992;bN=W;bO=Y;Q=5492;break L6406;break};case 2:{bJ=W;bK=Y;Q=5477;break L6406;break};case 3:{bM=428952;bN=W;bO=Y;Q=5492;break L6406;break};case 4:{bM=427800;bN=W;bO=Y;Q=5492;break L6406;break};case 5:{bM=426416;bN=W;bO=Y;Q=5492;break L6406;break};case 6:{bM=425200;bN=W;bO=Y;Q=5492;break L6406;break};case 7:{bM=423928;bN=W;bO=Y;Q=5492;break L6406;break};case 8:{bP=W;bQ=Y;Q=5483;break L6406;break};case 9:{bM=422144;bN=W;bO=Y;Q=5492;break L6406;break};case 10:{bM=421328;bN=W;bO=Y;Q=5492;break L6406;break};case 11:{bM=420016;bN=W;bO=Y;Q=5492;break L6406;break};case 12:{bM=418688;bN=W;bO=Y;Q=5492;break L6406;break};case 13:{bM=417624;bN=W;bO=Y;Q=5492;break L6406;break};case 14:{bM=416e3;bN=W;bO=Y;Q=5492;break L6406;break};case 15:{bM=414080;bN=W;bO=Y;Q=5492;break L6406;break};case 0:{bM=431792;bN=W;bO=Y;Q=5492;break L6406;break};default:{bM=412448;bN=W;bO=Y;Q=5492;break L6406}}}else if((Q|0)==5493){Q=0;bU(X|0,432624,(ao=i,i=i+8|0,c[ao>>2]=R,ao)|0)|0;i=ao;Y=e[_+12>>1]|0;bU(X|0,433608,(ao=i,i=i+16|0,c[ao>>2]=c[H>>2],c[ao+8>>2]=Y,ao)|0)|0;i=ao}}while(0);if((Q|0)==5474){Q=0;bP=bL;bQ=_+12|0;Q=5483}else if((Q|0)==5477){Q=0;bM=429904;bN=bJ;bO=bK;Q=5492}if((Q|0)==5483){Q=0;bM=422992;bN=bP;bO=bQ;Q=5492}if((Q|0)==5492){Q=0;bU(X|0,434424,(ao=i,i=i+24|0,c[ao>>2]=R,c[ao+8>>2]=bM,c[ao+16>>2]=bN,ao)|0)|0;i=ao;Y=c[H>>2]|0;W=e[bO>>1]|0;bU(X|0,433608,(ao=i,i=i+16|0,c[ao>>2]=Y,c[ao+8>>2]=W,ao)|0)|0;i=ao}W=ae+1|0;if(W>>>0<(c[2113198]|0)>>>0){_=_+68|0;ae=W}else{bG=1;break}}}else if((Q|0)==5082){gEo();return 0}else if((Q|0)==5039){bU(S|0,388864,(ao=i,i=i+8|0,c[ao>>2]=O,ao)|0)|0;i=ao;bk=0;i=f;return bk|0}else if((Q|0)==5043){gAq();return 0}else if((Q|0)==5054){ae=f_(4)|0;c[ae>>2]=619768;eh(ae|0,625520,1206);return 0}else if((Q|0)==5063){gAq();return 0}else if((Q|0)==5076){ae=f_(4)|0;c[ae>>2]=619768;eh(ae|0,625520,1206);return 0}else if((Q|0)==5095){ae=f_(4)|0;c[ae>>2]=619768;eh(ae|0,625520,1206);return 0}else if((Q|0)==5102){gAq();return 0}else if((Q|0)==5115){ae=f_(4)|0;c[ae>>2]=619768;eh(ae|0,625520,1206);return 0}else if((Q|0)==5125){gAq();return 0}else if((Q|0)==5138){ae=f_(4)|0;c[ae>>2]=619768;eh(ae|0,625520,1206);return 0}}else if((Q|0)==5495){cj(578232,26,1,c[u>>2]|0)|0;bG=0}}while(0);c[3528546]=0;bO=t+4|0;bN=0;while(1){bM=c[(c[642608+(c[2436]<<2)>>2]|0)+96>>2]|0;if((bM|0)==0){break}if((gA[bM&16383](t,bN)|0)!=0){break}if((a[bO]|0)==-16){Q=5500;break}else{bN=bN+1|0}}if((Q|0)==5500){Q=c[t>>2]|0;c[3528546]=Q;t=c[u>>2]|0;bU(t|0,360560,(ao=i,i=i+8|0,c[ao>>2]=Q,ao)|0)|0;i=ao}gzo();Q=c[(c[642608+(c[2436]<<2)>>2]|0)+96>>2]|0;L6464:do{if((Q|0)!=0){if((gA[Q&16383](v,0)|0)!=0){break}t=v+4|0;bN=c[u>>2]|0;bO=v+8|0;bM=v+6|0;bQ=w+5|0;bP=w+8|0;bK=0;do{L6469:do{if(((a[t]|0)+3&255)<2){bJ=c[bO>>2]|0;bU(bN|0,411072,(ao=i,i=i+8|0,c[ao>>2]=bJ,ao)|0)|0;i=ao;if((a[bM]|0)==0){break}bJ=bK+1|0;bL=0;bH=0;while(1){y=c[(c[642608+(c[2436]<<2)>>2]|0)+96>>2]|0;if((y|0)!=0){bI=bJ+bH|0;gA[y&16383](w,bI)|0}bI=a[bQ]|0;if((bI<<24>>24|0)==63|(bI<<24>>24|0)==48){bR=bL}else{bI=c[bP>>2]|0;bU(bN|0,409872,(ao=i,i=i+8|0,c[ao>>2]=bI,ao)|0)|0;i=ao;bR=bL+1|0}if((bR|0)>=(d[bM]|0)){break L6469}bL=bR;bH=bH+1|0}}}while(0);bK=bK+1|0;R=c[(c[642608+(c[2436]<<2)>>2]|0)+96>>2]|0;if((R|0)==0){break L6464}}while((gA[R&16383](v,bK)|0)==0)}}while(0);gzt();bk=bG;i=f;return bk|0}function gzE(a,b,c){a=a|0;b=b|0;c=c|0;return 0}function gzF(){return}function gzG(){return 0}function gzH(a){a=a|0;return 0}function gzI(a){a=a|0;return 0}function gzJ(){return 1}function gzK(a,b){a=a|0;b=b|0;return}function gzL(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=i;i=i+376|0;g=f+264|0;if(!((e|0)>-1&(c[2444216]|0)>>>0>e>>>0)){h=1;i=f;return h|0}j=c[9776876+(e*124|0)>>2]|0;k=c[2432952]|0;l=k+(j*12|0)|0;if((a[l]&1)==0){m=l+1|0}else{m=c[k+(j*12|0)+8>>2]|0}j=f|0;a[632384]=0;if((m|0)==0){h=1;i=f;return h|0}cC(j|0,328824,(k=i,i=i+8|0,c[k>>2]=m,k)|0)|0;i=k;k=li(j)|0;c[2426512]=k;if((k|0)==0){h=1;i=f;return h|0}a[632384]=1;j=k+120|0;m=c[j+4>>2]|0;l=k+88|0;c[l>>2]=c[j>>2];c[l+4>>2]=m;m=k+80|0;c[m>>2]=0;c[m+4>>2]=0;m=k+96|0;c[m>>2]=(ll(k,k+128|0,k+216|0,0,0)|0)==0;c[m+4>>2]=0;c[2385534]=0;gGz(g|0,0,112);gA[c[(c[642608+(c[2436]<<2)>>2]|0)+76>>2]&16383](g,e)|0;m=c[g+100>>2]|0;g=c[9776880+(e*124|0)>>2]|0;e=a[632384]|0;k=c[2426512]|0;l=(k|0)==0;L6506:do{if(e&l){n=1}else{do{if(e){j=c[2385534]|0;if((j|0)>(g|0)){if(l){n=1;break L6506}o=k+120|0;p=c[o+4>>2]|0;q=k+88|0;c[q>>2]=c[o>>2];c[q+4>>2]=p;p=k+80|0;c[p>>2]=0;c[p+4>>2]=0;p=(ll(k,k+128|0,k+216|0,0,0)|0)==0;q=k+96|0;c[q>>2]=p&1;c[q+4>>2]=0;if(!p){n=1;break L6506}c[2385534]=0;r=0;s=c[2426512]|0}else{r=j;s=k}if((r|0)<(g|0)){j=s;while(1){if((j|0)==0){n=1;break L6506}p=j+96|0;if((c[p>>2]|0)==0&(c[p+4>>2]|0)==0){n=1;break L6506}q=j+56|0;o=c[q>>2]|0;t=c[q+4>>2]|0;q=j+80|0;u=gGK(c[q>>2]|0,c[q+4>>2]|0,1,0)|0;v=K;if(((o|0)!=65535|(t|0)!=0)&((u|0)==(o|0)&(v|0)==(t|0))){n=1;break L6506}t=j+88|0;o=gGK((c[j+168>>2]|0)+46+(c[j+172>>2]|0)+(c[j+176>>2]|0)|0,0,c[t>>2]|0,c[t+4>>2]|0)|0;c[t>>2]=o;c[t+4>>2]=K;c[q>>2]=u;c[q+4>>2]=v;v=(ll(j,j+128|0,j+216|0,0,0)|0)==0;c[p>>2]=v&1;c[p+4>>2]=0;if(!v){n=1;break L6506}v=(c[2385534]|0)+1|0;c[2385534]=v;p=c[2426512]|0;if((v|0)<(g|0)){j=p}else{w=p;break}}}else{w=s}if((lm(w)|0)!=0){n=1;break L6506}j=ln(c[2426512]|0,b,m)|0;if(!((j|0)<0|(d|0)==0)){c[d>>2]=j}j=lk(c[2426512]|0)|0;if((j|0)==0){break}else if((j|0)==(-105|0)){n=2;break L6506}n=1;break L6506}}while(0);n=0}}while(0);d=c[2426512]|0;if(a[632384]&(d|0)!=0){lj(d);c[2426512]=0}a[632384]=0;h=(n|0)!=0|0;i=f;return h|0}function gzM(){c[2432952]=0;c[2432953]=0;c[2432954]=0;dZ(1508,9731808,t|0)|0;return}function gzN(a){a=a|0;gA8(9540336);gA8(9540424);gBd(9539968);gBd(9540056);return}function gzO(a){a=a|0;var b=0;c[a>>2]=621520;b=c[a+4>>2]|0;a=b+4|0;if(((I=c[a>>2]|0,c[a>>2]=I+ -1,I)|0)!=0){return}gf[c[(c[b>>2]|0)+8>>2]&2047](b|0);return}function gzP(a){a=a|0;var b=0,d=0,e=0;c[a>>2]=621520;b=c[a+4>>2]|0;d=b+4|0;if(((I=c[d>>2]|0,c[d>>2]=I+ -1,I)|0)!=0){e=a;gGr(e);return}gf[c[(c[b>>2]|0)+8>>2]&2047](b|0);e=a;gGr(e);return}function gzQ(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;i=i+16|0;f=e|0;gj[c[(c[b>>2]|0)+24>>2]&4095](b)|0;g=c[d>>2]|0;if((c[2384982]|0)!=-1){c[f>>2]=9539928;c[f+4>>2]=180;c[f+8>>2]=0;gAp(9539928,f)}f=(c[2384983]|0)-1|0;d=c[g+8>>2]|0;if((c[g+12>>2]|0)-d>>2>>>0<=f>>>0){h=f_(4)|0;j=h;c[j>>2]=619800;eh(h|0,625536,1e3)}g=c[d+(f<<2)>>2]|0;if((g|0)==0){h=f_(4)|0;j=h;c[j>>2]=619800;eh(h|0,625536,1e3)}else{h=g;c[b+36>>2]=h;a[b+44|0]=(gj[c[(c[g>>2]|0)+28>>2]&4095](h)|0)&1;i=e;return}}function gzR(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;i=i+16|0;d=b|0;e=b+8|0;f=a+36|0;g=a+40|0;h=d|0;j=d+8|0;k=d;d=a+32|0;while(1){a=c[f>>2]|0;l=gF[c[(c[a>>2]|0)+20>>2]&2047](a,c[g>>2]|0,h,j,e)|0;a=(c[e>>2]|0)-k|0;if((cj(h|0,1,a|0,c[d>>2]|0)|0)!=(a|0)){m=-1;n=5592;break}if((l|0)==2){m=-1;n=5591;break}else if((l|0)!=1){n=5588;break}}if((n|0)==5588){m=((eY(c[d>>2]|0)|0)!=0)<<31>>31;i=b;return m|0}else if((n|0)==5592){i=b;return m|0}else if((n|0)==5591){i=b;return m|0}return 0}function gzS(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;if((a[b+44|0]&1)!=0){f=cj(d|0,4,e|0,c[b+32>>2]|0)|0;return f|0}g=b;if((e|0)>0){h=d;i=0}else{f=0;return f|0}while(1){if((gA[c[(c[g>>2]|0)+52>>2]&16383](b,c[h>>2]|0)|0)==-1){f=i;j=5601;break}d=i+1|0;if((d|0)<(e|0)){h=h+4|0;i=d}else{f=d;j=5599;break}}if((j|0)==5601){return f|0}else if((j|0)==5599){return f|0}return 0}function gzT(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;e=i;i=i+32|0;f=e|0;g=e+8|0;h=e+16|0;j=e+24|0;k=(d|0)==-1;L6583:do{if(!k){c[g>>2]=d;if((a[b+44|0]&1)!=0){if((cj(g|0,4,1,c[b+32>>2]|0)|0)==1){break}else{l=-1}i=e;return l|0}m=f|0;c[h>>2]=m;n=g+4|0;o=b+36|0;p=b+40|0;q=f+8|0;r=f;s=b+32|0;t=g;while(1){u=c[o>>2]|0;v=gI[c[(c[u>>2]|0)+12>>2]&31](u,c[p>>2]|0,t,n,j,m,q,h)|0;if((c[j>>2]|0)==(t|0)){l=-1;w=5620;break}if((v|0)==3){w=5609;break}u=(v|0)==1;if(v>>>0>=2){l=-1;w=5615;break}v=(c[h>>2]|0)-r|0;if((cj(m|0,1,v|0,c[s>>2]|0)|0)!=(v|0)){l=-1;w=5617;break}if(u){t=u?c[j>>2]|0:t}else{break L6583}}if((w|0)==5609){if((cj(t|0,1,1,c[s>>2]|0)|0)==1){break}else{l=-1}i=e;return l|0}else if((w|0)==5615){i=e;return l|0}else if((w|0)==5617){i=e;return l|0}else if((w|0)==5620){i=e;return l|0}}}while(0);l=k?0:d;i=e;return l|0}function gzU(a){a=a|0;var b=0;c[a>>2]=621520;b=c[a+4>>2]|0;a=b+4|0;if(((I=c[a>>2]|0,c[a>>2]=I+ -1,I)|0)!=0){return}gf[c[(c[b>>2]|0)+8>>2]&2047](b|0);return}function gzV(a){a=a|0;var b=0,d=0,e=0;c[a>>2]=621520;b=c[a+4>>2]|0;d=b+4|0;if(((I=c[d>>2]|0,c[d>>2]=I+ -1,I)|0)!=0){e=a;gGr(e);return}gf[c[(c[b>>2]|0)+8>>2]&2047](b|0);e=a;gGr(e);return}function gzW(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;i=i+16|0;f=e|0;g=c[d>>2]|0;if((c[2384982]|0)!=-1){c[f>>2]=9539928;c[f+4>>2]=180;c[f+8>>2]=0;gAp(9539928,f)}f=(c[2384983]|0)-1|0;d=c[g+8>>2]|0;if((c[g+12>>2]|0)-d>>2>>>0<=f>>>0){h=f_(4)|0;j=h;c[j>>2]=619800;eh(h|0,625536,1e3)}g=c[d+(f<<2)>>2]|0;if((g|0)==0){h=f_(4)|0;j=h;c[j>>2]=619800;eh(h|0,625536,1e3)}h=g;j=b+36|0;c[j>>2]=h;f=b+44|0;c[f>>2]=gj[c[(c[g>>2]|0)+24>>2]&4095](h)|0;h=c[j>>2]|0;a[b+53|0]=(gj[c[(c[h>>2]|0)+28>>2]&4095](h)|0)&1;if((c[f>>2]|0)>8){gDU(73608)}else{i=e;return}}function gzX(a){a=a|0;return gz_(a,0)|0}function gzY(a){a=a|0;return gz_(a,1)|0}function gzZ(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=i;i=i+32|0;f=e|0;g=e+8|0;h=e+16|0;j=e+24|0;k=b+52|0;l=(a[k]&1)!=0;if((d|0)==-1){if(l){m=-1;i=e;return m|0}n=c[b+48>>2]|0;a[k]=(n|0)!=-1|0;m=n;i=e;return m|0}n=b+48|0;L6636:do{if(l){c[h>>2]=c[n>>2];o=c[b+36>>2]|0;p=f|0;q=gI[c[(c[o>>2]|0)+12>>2]&31](o,c[b+40>>2]|0,h,h+4|0,j,p,f+8|0,g)|0;if((q|0)==3){a[p]=c[n>>2]&255;c[g>>2]=f+1}else if((q|0)==2|(q|0)==1){m=-1;i=e;return m|0}q=b+32|0;while(1){o=c[g>>2]|0;if(o>>>0<=p>>>0){break L6636}r=o-1|0;c[g>>2]=r;if((fM(a[r]|0,c[q>>2]|0)|0)==-1){m=-1;break}}i=e;return m|0}}while(0);c[n>>2]=d;a[k]=1;m=d;i=e;return m|0}function gz_(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;e=i;i=i+32|0;f=e|0;g=e+8|0;h=e+16|0;j=e+24|0;k=b+52|0;if((a[k]&1)!=0){l=b+48|0;m=c[l>>2]|0;if(!d){n=m;i=e;return n|0}c[l>>2]=-1;a[k]=0;n=m;i=e;return n|0}m=c[b+44>>2]|0;k=(m|0)>1?m:1;L6656:do{if((k|0)>0){m=b+32|0;l=0;while(1){o=fc(c[m>>2]|0)|0;if((o|0)==-1){n=-1;break}a[f+l|0]=o&255;l=l+1|0;if((l|0)>=(k|0)){break L6656}}i=e;return n|0}}while(0);L6663:do{if((a[b+53|0]&1)==0){l=b+40|0;m=b+36|0;o=f|0;p=g+4|0;q=b+32|0;r=k;while(1){s=c[l>>2]|0;t=s;u=c[t>>2]|0;v=c[t+4>>2]|0;t=c[m>>2]|0;w=f+r|0;x=gI[c[(c[t>>2]|0)+16>>2]&31](t,s,o,w,h,g,p,j)|0;if((x|0)==3){y=5672;break}else if((x|0)==2){n=-1;y=5685;break}else if((x|0)!=1){z=r;break L6663}x=c[l>>2]|0;c[x>>2]=u;c[x+4>>2]=v;if((r|0)==8){n=-1;y=5684;break}v=fc(c[q>>2]|0)|0;if((v|0)==-1){n=-1;y=5683;break}a[w]=v&255;r=r+1|0}if((y|0)==5672){c[g>>2]=a[o]|0;z=r;break}else if((y|0)==5683){i=e;return n|0}else if((y|0)==5684){i=e;return n|0}else if((y|0)==5685){i=e;return n|0}}else{c[g>>2]=a[f|0]|0;z=k}}while(0);if(d){d=c[g>>2]|0;c[b+48>>2]=d;n=d;i=e;return n|0}d=b+32|0;b=z;while(1){if((b|0)<=0){break}z=b-1|0;if((fM(a[f+z|0]|0,c[d>>2]|0)|0)==-1){n=-1;y=5688;break}else{b=z}}if((y|0)==5688){i=e;return n|0}n=c[g>>2]|0;i=e;return n|0}function gz$(a){a=a|0;var b=0;c[a>>2]=621592;b=c[a+4>>2]|0;a=b+4|0;if(((I=c[a>>2]|0,c[a>>2]=I+ -1,I)|0)!=0){return}gf[c[(c[b>>2]|0)+8>>2]&2047](b|0);return}function gz0(a){a=a|0;var b=0,d=0,e=0;c[a>>2]=621592;b=c[a+4>>2]|0;d=b+4|0;if(((I=c[d>>2]|0,c[d>>2]=I+ -1,I)|0)!=0){e=a;gGr(e);return}gf[c[(c[b>>2]|0)+8>>2]&2047](b|0);e=a;gGr(e);return}function gz1(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;i=i+16|0;f=e|0;gj[c[(c[b>>2]|0)+24>>2]&4095](b)|0;g=c[d>>2]|0;if((c[2384984]|0)!=-1){c[f>>2]=9539936;c[f+4>>2]=180;c[f+8>>2]=0;gAp(9539936,f)}f=(c[2384985]|0)-1|0;d=c[g+8>>2]|0;if((c[g+12>>2]|0)-d>>2>>>0<=f>>>0){h=f_(4)|0;j=h;c[j>>2]=619800;eh(h|0,625536,1e3)}g=c[d+(f<<2)>>2]|0;if((g|0)==0){h=f_(4)|0;j=h;c[j>>2]=619800;eh(h|0,625536,1e3)}else{h=g;c[b+36>>2]=h;a[b+44|0]=(gj[c[(c[g>>2]|0)+28>>2]&4095](h)|0)&1;i=e;return}}function gz2(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;i=i+16|0;d=b|0;e=b+8|0;f=a+36|0;g=a+40|0;h=d|0;j=d+8|0;k=d;d=a+32|0;while(1){a=c[f>>2]|0;l=gF[c[(c[a>>2]|0)+20>>2]&2047](a,c[g>>2]|0,h,j,e)|0;a=(c[e>>2]|0)-k|0;if((cj(h|0,1,a|0,c[d>>2]|0)|0)!=(a|0)){m=-1;n=5713;break}if((l|0)==2){m=-1;n=5714;break}else if((l|0)!=1){n=5711;break}}if((n|0)==5714){i=b;return m|0}else if((n|0)==5713){i=b;return m|0}else if((n|0)==5711){m=((eY(c[d>>2]|0)|0)!=0)<<31>>31;i=b;return m|0}return 0}function gz3(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;if((a[b+44|0]&1)!=0){g=cj(e|0,1,f|0,c[b+32>>2]|0)|0;return g|0}h=b;if((f|0)>0){i=e;j=0}else{g=0;return g|0}while(1){if((gA[c[(c[h>>2]|0)+52>>2]&16383](b,d[i]|0)|0)==-1){g=j;k=5724;break}e=j+1|0;if((e|0)<(f|0)){i=i+1|0;j=e}else{g=e;k=5725;break}}if((k|0)==5724){return g|0}else if((k|0)==5725){return g|0}return 0}function gz4(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;e=i;i=i+32|0;f=e|0;g=e+8|0;h=e+16|0;j=e+24|0;k=(d|0)==-1;L6731:do{if(!k){a[g]=d&255;if((a[b+44|0]&1)!=0){if((cj(g|0,1,1,c[b+32>>2]|0)|0)==1){break}else{l=-1}i=e;return l|0}m=f|0;c[h>>2]=m;n=g+1|0;o=b+36|0;p=b+40|0;q=f+8|0;r=f;s=b+32|0;t=g;while(1){u=c[o>>2]|0;v=gI[c[(c[u>>2]|0)+12>>2]&31](u,c[p>>2]|0,t,n,j,m,q,h)|0;if((c[j>>2]|0)==(t|0)){l=-1;w=5743;break}if((v|0)==3){w=5732;break}u=(v|0)==1;if(v>>>0>=2){l=-1;w=5741;break}v=(c[h>>2]|0)-r|0;if((cj(m|0,1,v|0,c[s>>2]|0)|0)!=(v|0)){l=-1;w=5739;break}if(u){t=u?c[j>>2]|0:t}else{break L6731}}if((w|0)==5732){if((cj(t|0,1,1,c[s>>2]|0)|0)==1){break}else{l=-1}i=e;return l|0}else if((w|0)==5743){i=e;return l|0}else if((w|0)==5741){i=e;return l|0}else if((w|0)==5739){i=e;return l|0}}}while(0);l=k?0:d;i=e;return l|0}function gz5(a){a=a|0;var b=0;c[a>>2]=621592;b=c[a+4>>2]|0;a=b+4|0;if(((I=c[a>>2]|0,c[a>>2]=I+ -1,I)|0)!=0){return}gf[c[(c[b>>2]|0)+8>>2]&2047](b|0);return}function gz6(a){a=a|0;var b=0,d=0,e=0;c[a>>2]=621592;b=c[a+4>>2]|0;d=b+4|0;if(((I=c[d>>2]|0,c[d>>2]=I+ -1,I)|0)!=0){e=a;gGr(e);return}gf[c[(c[b>>2]|0)+8>>2]&2047](b|0);e=a;gGr(e);return}function gz7(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;i=i+16|0;f=e|0;g=c[d>>2]|0;if((c[2384984]|0)!=-1){c[f>>2]=9539936;c[f+4>>2]=180;c[f+8>>2]=0;gAp(9539936,f)}f=(c[2384985]|0)-1|0;d=c[g+8>>2]|0;if((c[g+12>>2]|0)-d>>2>>>0<=f>>>0){h=f_(4)|0;j=h;c[j>>2]=619800;eh(h|0,625536,1e3)}g=c[d+(f<<2)>>2]|0;if((g|0)==0){h=f_(4)|0;j=h;c[j>>2]=619800;eh(h|0,625536,1e3)}h=g;j=b+36|0;c[j>>2]=h;f=b+44|0;c[f>>2]=gj[c[(c[g>>2]|0)+24>>2]&4095](h)|0;h=c[j>>2]|0;a[b+53|0]=(gj[c[(c[h>>2]|0)+28>>2]&4095](h)|0)&1;if((c[f>>2]|0)>8){gDU(73608)}else{i=e;return}}function gz8(a){a=a|0;return gAb(a,0)|0}function gz9(a){a=a|0;return gAb(a,1)|0}function gAa(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=i;i=i+32|0;f=e|0;g=e+8|0;h=e+16|0;j=e+24|0;k=b+52|0;l=(a[k]&1)!=0;if((d|0)==-1){if(l){m=-1;i=e;return m|0}n=c[b+48>>2]|0;a[k]=(n|0)!=-1|0;m=n;i=e;return m|0}n=b+48|0;L6784:do{if(l){a[h]=c[n>>2]&255;o=c[b+36>>2]|0;p=f|0;q=gI[c[(c[o>>2]|0)+12>>2]&31](o,c[b+40>>2]|0,h,h+1|0,j,p,f+8|0,g)|0;if((q|0)==3){a[p]=c[n>>2]&255;c[g>>2]=f+1}else if((q|0)==2|(q|0)==1){m=-1;i=e;return m|0}q=b+32|0;while(1){o=c[g>>2]|0;if(o>>>0<=p>>>0){break L6784}r=o-1|0;c[g>>2]=r;if((fM(a[r]|0,c[q>>2]|0)|0)==-1){m=-1;break}}i=e;return m|0}}while(0);c[n>>2]=d;a[k]=1;m=d;i=e;return m|0}function gAb(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;f=i;i=i+32|0;g=f|0;h=f+8|0;j=f+16|0;k=f+24|0;l=b+52|0;if((a[l]&1)!=0){m=b+48|0;n=c[m>>2]|0;if(!e){o=n;i=f;return o|0}c[m>>2]=-1;a[l]=0;o=n;i=f;return o|0}n=c[b+44>>2]|0;l=(n|0)>1?n:1;L6804:do{if((l|0)>0){n=b+32|0;m=0;while(1){p=fc(c[n>>2]|0)|0;if((p|0)==-1){o=-1;break}a[g+m|0]=p&255;m=m+1|0;if((m|0)>=(l|0)){break L6804}}i=f;return o|0}}while(0);L6811:do{if((a[b+53|0]&1)==0){m=b+40|0;n=b+36|0;p=g|0;q=h+1|0;r=b+32|0;s=l;while(1){t=c[m>>2]|0;u=t;v=c[u>>2]|0;w=c[u+4>>2]|0;u=c[n>>2]|0;x=g+s|0;y=gI[c[(c[u>>2]|0)+16>>2]&31](u,t,p,x,j,h,q,k)|0;if((y|0)==3){z=5795;break}else if((y|0)==2){o=-1;z=5812;break}else if((y|0)!=1){A=s;break L6811}y=c[m>>2]|0;c[y>>2]=v;c[y+4>>2]=w;if((s|0)==8){o=-1;z=5806;break}w=fc(c[r>>2]|0)|0;if((w|0)==-1){o=-1;z=5807;break}a[x]=w&255;s=s+1|0}if((z|0)==5795){a[h]=a[p]|0;A=s;break}else if((z|0)==5806){i=f;return o|0}else if((z|0)==5807){i=f;return o|0}else if((z|0)==5812){i=f;return o|0}}else{a[h]=a[g|0]|0;A=l}}while(0);do{if(e){l=a[h]|0;c[b+48>>2]=l&255;B=l}else{l=b+32|0;k=A;while(1){if((k|0)<=0){z=5802;break}j=k-1|0;if((fM(d[g+j|0]|0|0,c[l>>2]|0)|0)==-1){o=-1;z=5811;break}else{k=j}}if((z|0)==5802){B=a[h]|0;break}else if((z|0)==5811){i=f;return o|0}}}while(0);o=B&255;i=f;return o|0}function gAc(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;b=i;i=i+96|0;d=b|0;e=b+16|0;f=b+32|0;g=b+48|0;h=b+64|0;j=b+80|0;k=c[p>>2]|0;c[2384902]=621592;l=c[(gEr()|0)>>2]|0;c[2384903]=l;m=l+4|0;I=c[m>>2]|0,c[m>>2]=I+1,I;gGz(9539616,0,24);c[2384902]=622360;c[2384910]=k;c[2384912]=9539736;c[2384914]=-1;a[9539660]=0;m=c[2384903]|0;l=m+4|0;I=c[l>>2]|0,c[l>>2]=I+1,I;if((c[2384984]|0)!=-1){c[e>>2]=9539936;c[e+4>>2]=180;c[e+8>>2]=0;gAp(9539936,e)}e=(c[2384985]|0)-1|0;n=c[m+8>>2]|0;do{if((c[m+12>>2]|0)-n>>2>>>0>e>>>0){o=c[n+(e<<2)>>2]|0;if((o|0)==0){break}q=o;c[2384911]=q;c[2384913]=gj[c[(c[o>>2]|0)+24>>2]&4095](q)|0;q=c[2384911]|0;a[9539661]=(gj[c[(c[q>>2]|0)+28>>2]&4095](q)|0)&1;if((c[2384913]|0)>8){q=f_(8)|0;c[q>>2]=619832;o=q+4|0;r=o;do{if((o|0)!=0){while(1){v=gGq(50)|0;if((v|0)!=0){w=5833;break}x=(I=c[2439328]|0,c[2439328]=I+0,I);if((x|0)==0){break}gu[x&16383]()}if((w|0)==5833){c[v+4>>2]=37;c[v>>2]=37;x=v+12|0;c[r>>2]=x;c[v+8>>2]=0;gGC(x|0,73608,38)|0;break}x=f_(4)|0;c[x>>2]=619768;eh(x|0,625520,1206)}}while(0);eh(q|0,625552,314)}if(((I=c[l>>2]|0,c[l>>2]=I+ -1,I)|0)==0){gf[c[(c[m>>2]|0)+8>>2]&2047](m|0)}c[2385150]=621812;c[2385152]=621832;c[2385151]=0;c[2385158]=9539608;c[2385156]=0;c[2385157]=0;c[2385153]=4098;c[2385155]=0;c[2385154]=6;gGz(9540640,0,40);r=c[(gEr()|0)>>2]|0;c[2385159]=r;o=r+4|0;I=c[o>>2]|0,c[o>>2]=I+1,I;c[2385170]=0;c[2385171]=-1;o=c[s>>2]|0;c[2384878]=621592;r=c[(gEr()|0)>>2]|0;c[2384879]=r;x=r+4|0;I=c[x>>2]|0,c[x>>2]=I+1,I;gGz(9539520,0,24);c[2384878]=621960;c[2384886]=o;x=c[2384879]|0;r=x+4|0;I=c[r>>2]|0,c[r>>2]=I+1,I;if((c[2384984]|0)!=-1){c[j>>2]=9539936;c[j+4>>2]=180;c[j+8>>2]=0;gAp(9539936,j)}y=(c[2384985]|0)-1|0;z=c[x+8>>2]|0;do{if((c[x+12>>2]|0)-z>>2>>>0>y>>>0){A=c[z+(y<<2)>>2]|0;if((A|0)==0){break}B=A;if(((I=c[r>>2]|0,c[r>>2]=I+ -1,I)|0)==0){gf[c[(c[x>>2]|0)+8>>2]&2047](x|0)}c[2384887]=B;c[2384888]=9539744;a[9539556]=(gj[c[(c[A>>2]|0)+28>>2]&4095](B)|0)&1;c[2385084]=621716;c[2385085]=621736;c[2385091]=9539512;c[2385089]=0;c[2385090]=0;c[2385086]=4098;c[2385088]=0;c[2385087]=6;gGz(9540372,0,40);B=c[(gEr()|0)>>2]|0;c[2385092]=B;A=B+4|0;I=c[A>>2]|0,c[A>>2]=I+1,I;c[2385103]=0;c[2385104]=-1;A=c[u>>2]|0;c[2384890]=621592;B=c[(gEr()|0)>>2]|0;c[2384891]=B;C=B+4|0;I=c[C>>2]|0,c[C>>2]=I+1,I;gGz(9539568,0,24);c[2384890]=621960;c[2384898]=A;C=c[2384891]|0;B=C+4|0;I=c[B>>2]|0,c[B>>2]=I+1,I;if((c[2384984]|0)!=-1){c[h>>2]=9539936;c[h+4>>2]=180;c[h+8>>2]=0;gAp(9539936,h)}D=(c[2384985]|0)-1|0;E=c[C+8>>2]|0;do{if((c[C+12>>2]|0)-E>>2>>>0>D>>>0){F=c[E+(D<<2)>>2]|0;if((F|0)==0){break}G=F;if(((I=c[B>>2]|0,c[B>>2]=I+ -1,I)|0)==0){gf[c[(c[C>>2]|0)+8>>2]&2047](C|0)}c[2384899]=G;c[2384900]=9539752;a[9539604]=(gj[c[(c[F>>2]|0)+28>>2]&4095](G)|0)&1;c[2385128]=621716;c[2385129]=621736;c[2385135]=9539560;c[2385133]=0;c[2385134]=0;c[2385130]=4098;c[2385132]=0;c[2385131]=6;gGz(9540548,0,40);G=c[(gEr()|0)>>2]|0;c[2385136]=G;F=G+4|0;I=c[F>>2]|0,c[F>>2]=I+1,I;c[2385147]=0;c[2385148]=-1;F=c[(c[(c[2385128]|0)-12>>2]|0)+9540536>>2]|0;c[2385106]=621716;c[2385107]=621736;c[2385113]=F;c[2385111]=(F|0)==0;c[2385112]=0;c[2385108]=4098;c[2385110]=0;c[2385109]=6;gGz(9540460,0,40);F=c[(gEr()|0)>>2]|0;c[2385114]=F;G=F+4|0;I=c[G>>2]|0,c[G>>2]=I+1,I;c[2385125]=0;c[2385126]=-1;c[(c[(c[2385150]|0)-12>>2]|0)+9540672>>2]=9540336;G=(c[(c[2385128]|0)-12>>2]|0)+9540516|0;c[G>>2]=c[G>>2]|8192;c[(c[(c[2385128]|0)-12>>2]|0)+9540584>>2]=9540336;c[2384864]=621520;G=c[(gEr()|0)>>2]|0;c[2384865]=G;F=G+4|0;I=c[F>>2]|0,c[F>>2]=I+1,I;gGz(9539464,0,24);c[2384864]=622288;c[2384872]=k;c[2384874]=9539760;c[2384876]=-1;a[9539508]=0;F=c[2384865]|0;G=F+4|0;I=c[G>>2]|0,c[G>>2]=I+1,I;if((c[2384982]|0)!=-1){c[d>>2]=9539928;c[d+4>>2]=180;c[d+8>>2]=0;gAp(9539928,d)}H=(c[2384983]|0)-1|0;J=c[F+8>>2]|0;do{if((c[F+12>>2]|0)-J>>2>>>0>H>>>0){K=c[J+(H<<2)>>2]|0;if((K|0)==0){break}L=K;c[2384873]=L;c[2384875]=gj[c[(c[K>>2]|0)+24>>2]&4095](L)|0;L=c[2384873]|0;a[9539509]=(gj[c[(c[L>>2]|0)+28>>2]&4095](L)|0)&1;if((c[2384875]|0)>8){L=f_(8)|0;c[L>>2]=619832;K=L+4|0;M=K;do{if((K|0)!=0){while(1){N=gGq(50)|0;if((N|0)!=0){w=5908;break}O=(I=c[2439328]|0,c[2439328]=I+0,I);if((O|0)==0){break}gu[O&16383]()}if((w|0)==5908){c[N+4>>2]=37;c[N>>2]=37;O=N+12|0;c[M>>2]=O;c[N+8>>2]=0;gGC(O|0,73608,38)|0;break}O=f_(4)|0;c[O>>2]=619768;eh(O|0,625520,1206)}}while(0);eh(L|0,625552,314)}if(((I=c[G>>2]|0,c[G>>2]=I+ -1,I)|0)==0){gf[c[(c[F>>2]|0)+8>>2]&2047](F|0)}c[2385062]=621764;c[2385064]=621784;c[2385063]=0;c[2385070]=9539456;c[2385068]=0;c[2385069]=0;c[2385065]=4098;c[2385067]=0;c[2385066]=6;gGz(9540288,0,40);M=c[(gEr()|0)>>2]|0;c[2385071]=M;K=M+4|0;I=c[K>>2]|0,c[K>>2]=I+1,I;c[2385082]=0;c[2385083]=-1;c[2384840]=621520;K=c[(gEr()|0)>>2]|0;c[2384841]=K;M=K+4|0;I=c[M>>2]|0,c[M>>2]=I+1,I;gGz(9539368,0,24);c[2384840]=621888;c[2384848]=o;M=c[2384841]|0;K=M+4|0;I=c[K>>2]|0,c[K>>2]=I+1,I;if((c[2384982]|0)!=-1){c[g>>2]=9539928;c[g+4>>2]=180;c[g+8>>2]=0;gAp(9539928,g)}O=(c[2384983]|0)-1|0;P=c[M+8>>2]|0;do{if((c[M+12>>2]|0)-P>>2>>>0>O>>>0){Q=c[P+(O<<2)>>2]|0;if((Q|0)==0){break}R=Q;if(((I=c[K>>2]|0,c[K>>2]=I+ -1,I)|0)==0){gf[c[(c[M>>2]|0)+8>>2]&2047](M|0)}c[2384849]=R;c[2384850]=9539768;a[9539404]=(gj[c[(c[Q>>2]|0)+28>>2]&4095](R)|0)&1;c[2384992]=621668;c[2384993]=621688;c[2384999]=9539360;c[2384997]=0;c[2384998]=0;c[2384994]=4098;c[2384996]=0;c[2384995]=6;gGz(9540004,0,40);R=c[(gEr()|0)>>2]|0;c[2385e3]=R;Q=R+4|0;I=c[Q>>2]|0,c[Q>>2]=I+1,I;c[2385011]=0;c[2385012]=-1;c[2384852]=621520;Q=c[(gEr()|0)>>2]|0;c[2384853]=Q;R=Q+4|0;I=c[R>>2]|0,c[R>>2]=I+1,I;gGz(9539416,0,24);c[2384852]=621888;c[2384860]=A;R=c[2384853]|0;Q=R+4|0;I=c[Q>>2]|0,c[Q>>2]=I+1,I;if((c[2384982]|0)!=-1){c[f>>2]=9539928;c[f+4>>2]=180;c[f+8>>2]=0;gAp(9539928,f)}S=(c[2384983]|0)-1|0;T=c[R+8>>2]|0;do{if((c[R+12>>2]|0)-T>>2>>>0>S>>>0){U=c[T+(S<<2)>>2]|0;if((U|0)==0){break}V=U;if(((I=c[Q>>2]|0,c[Q>>2]=I+ -1,I)|0)==0){gf[c[(c[R>>2]|0)+8>>2]&2047](R|0)}c[2384861]=V;c[2384862]=9539776;a[9539452]=(gj[c[(c[U>>2]|0)+28>>2]&4095](V)|0)&1;c[2385036]=621668;c[2385037]=621688;c[2385043]=9539408;c[2385041]=0;c[2385042]=0;c[2385038]=4098;c[2385040]=0;c[2385039]=6;gGz(9540180,0,40);V=c[(gEr()|0)>>2]|0;c[2385044]=V;U=V+4|0;I=c[U>>2]|0,c[U>>2]=I+1,I;c[2385055]=0;c[2385056]=-1;U=c[(c[(c[2385036]|0)-12>>2]|0)+9540168>>2]|0;c[2385014]=621668;c[2385015]=621688;c[2385021]=U;c[2385019]=(U|0)==0;c[2385020]=0;c[2385016]=4098;c[2385018]=0;c[2385017]=6;gGz(9540092,0,40);U=c[(gEr()|0)>>2]|0;c[2385022]=U;V=U+4|0;I=c[V>>2]|0,c[V>>2]=I+1,I;c[2385033]=0;c[2385034]=-1;c[(c[(c[2385062]|0)-12>>2]|0)+9540320>>2]=9539968;V=(c[(c[2385036]|0)-12>>2]|0)+9540148|0;c[V>>2]=c[V>>2]|8192;c[(c[(c[2385036]|0)-12>>2]|0)+9540216>>2]=9539968;dZ(402,9540688,t|0)|0;i=b;return}}while(0);R=f_(4)|0;c[R>>2]=619800;eh(R|0,625536,1e3)}}while(0);M=f_(4)|0;c[M>>2]=619800;eh(M|0,625536,1e3)}}while(0);F=f_(4)|0;c[F>>2]=619800;eh(F|0,625536,1e3)}}while(0);A=f_(4)|0;c[A>>2]=619800;eh(A|0,625536,1e3)}}while(0);o=f_(4)|0;c[o>>2]=619800;eh(o|0,625536,1e3)}}while(0);b=f_(4)|0;c[b>>2]=619800;eh(b|0,625536,1e3)}function gAd(a){a=a|0;var b=0,d=0,e=0;c[a>>2]=619896;b=a+4|0;d=(c[b>>2]|0)-4|0;do{if(((I=c[d>>2]|0,c[d>>2]=I+ -1,I)-1|0)<0){e=(c[b>>2]|0)-12|0;if((e|0)!=0){gGr(e)}if((a|0)!=0){break}return}}while(0);gGr(a);return}function gAe(a){a=a|0;var b=0;c[a>>2]=619896;b=a+4|0;a=(c[b>>2]|0)-4|0;if(((I=c[a>>2]|0,c[a>>2]=I+ -1,I)-1|0)>=0){return}a=(c[b>>2]|0)-12|0;if((a|0)==0){return}gGr(a);return}function gAf(a){a=a|0;return c[a+4>>2]|0}function gAg(a){a=a|0;var b=0,d=0,e=0;c[a>>2]=619832;b=a+4|0;d=(c[b>>2]|0)-4|0;do{if(((I=c[d>>2]|0,c[d>>2]=I+ -1,I)-1|0)<0){e=(c[b>>2]|0)-12|0;if((e|0)!=0){gGr(e)}if((a|0)!=0){break}return}}while(0);gGr(a);return}function gAh(a){a=a|0;var b=0;c[a>>2]=619832;b=a+4|0;a=(c[b>>2]|0)-4|0;if(((I=c[a>>2]|0,c[a>>2]=I+ -1,I)-1|0)>=0){return}a=(c[b>>2]|0)-12|0;if((a|0)==0){return}gGr(a);return}function gAi(a){a=a|0;return c[a+4>>2]|0}function gAj(a){a=a|0;var b=0,d=0,e=0;c[a>>2]=619896;b=a+4|0;d=(c[b>>2]|0)-4|0;do{if(((I=c[d>>2]|0,c[d>>2]=I+ -1,I)-1|0)<0){e=(c[b>>2]|0)-12|0;if((e|0)!=0){gGr(e)}if((a|0)!=0){break}return}}while(0);gGr(a);return}function gAk(a,b,d){a=a|0;b=b|0;d=d|0;c[a>>2]=d;c[a+4>>2]=b;return}function gAl(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=i;i=i+8|0;f=e|0;gG[c[(c[a>>2]|0)+12>>2]&255](f,a,b);if((c[f+4>>2]|0)!=(c[d+4>>2]|0)){g=0;i=e;return g|0}g=(c[f>>2]|0)==(c[d>>2]|0);i=e;return g|0}function gAm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((c[b+4>>2]|0)!=(a|0)){e=0;return e|0}e=(c[b>>2]|0)==(d|0);return e|0}function gAn(a){a=a|0;var b=0,d=0,e=0;c[a>>2]=619832;b=a+4|0;d=(c[b>>2]|0)-4|0;do{if(((I=c[d>>2]|0,c[d>>2]=I+ -1,I)-1|0)<0){e=(c[b>>2]|0)-12|0;if((e|0)!=0){gGr(e)}if((a|0)!=0){break}return}}while(0);gGr(a);return}function gAo(a){a=a|0;var b=0;c[a>>2]=619832;b=a+4|0;a=(c[b>>2]|0)-4|0;if(((I=c[a>>2]|0,c[a>>2]=I+ -1,I)-1|0)>=0){return}a=(c[b>>2]|0)-12|0;if((a|0)==0){return}gGr(a);return}function gAp(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;d;if((c[a>>2]|0)==1){do{dS(9539688,9539664)|0;}while((c[a>>2]|0)==1)}if((c[a>>2]|0)!=0){e;return}c[a>>2]=1;f;f=b+4|0;e=(c[b>>2]|0)+(c[f+4>>2]|0)|0;b=c[f>>2]|0;if((b&1|0)==0){g=b}else{g=c[(c[e>>2]|0)+(b-1)>>2]|0}gf[g&2047](e);h;c[a>>2]=-1;i;bK(9539688)|0;return}function gAq(){var a=0,b=0,d=0,e=0,f=0,g=0;a=f_(8)|0;c[a>>2]=619896;b=a+4|0;d=b;if((b|0)==0){e=a;c[e>>2]=619864;eh(a|0,625568,868)}while(1){f=gGq(25)|0;if((f|0)!=0){g=6068;break}b=(I=c[2439328]|0,c[2439328]=I+0,I);if((b|0)==0){g=6062;break}gu[b&16383]()}if((g|0)==6062){b=f_(4)|0;c[b>>2]=619768;eh(b|0,625520,1206)}else if((g|0)==6068){c[f+4>>2]=12;c[f>>2]=12;g=f+12|0;c[d>>2]=g;c[f+8>>2]=0;gGC(g|0,104616,13)|0;e=a;c[e>>2]=619864;eh(a|0,625568,868)}}function gAr(b){b=b|0;var d=0;if((a[b]&1)==0){return}d=c[b+8>>2]|0;if((d|0)==0){return}gGr(d);return}function gAs(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=gGy(d|0)|0;f=b;g=b;h=a[g]|0;if((h&1)==0){i=10;j=h}else{h=c[b>>2]|0;i=(h&-2)-1|0;j=h&255}if(i>>>0<e>>>0){h=j&255;if((h&1|0)==0){k=h>>>1}else{k=c[b+4>>2]|0}gAw(b,i,e-i|0,k,0,k,e,d);return}if((j&1)==0){l=f+1|0}else{l=c[b+8>>2]|0}gGG(l|0,d|0,e|0);a[l+e|0]=0;if((a[g]&1)==0){a[g]=e<<1&255;return}else{c[b+4>>2]=e;return}}function gAt(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;if((d|0)==0){return}e=b;f=a[e]|0;if((f&1)==0){g=10;h=f}else{f=c[b>>2]|0;g=(f&-2)-1|0;h=f&255}f=h&255;if((f&1|0)==0){i=f>>>1}else{i=c[b+4>>2]|0}if((g-i|0)>>>0<d>>>0){gAx(b,g,d-g+i|0,i,i,0);j=a[e]|0}else{j=h}if((j&1)==0){k=b+1|0}else{k=c[b+8>>2]|0}gGz(k+i|0,0,d|0);j=i+d|0;if((a[e]&1)==0){a[e]=j<<1&255}else{c[b+4>>2]=j}a[k+j|0]=0;return}function gAu(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;d=b;e=b;f=a[e]|0;if((f&1)==0){g=10;h=f}else{f=c[b>>2]|0;g=(f&-2)-1|0;h=f&255}f=h&255;i=(f&1|0)==0;if(i){j=f>>>1}else{j=c[b+4>>2]|0}if(j>>>0<11){k=11}else{k=j+16&-16}l=k-1|0;if((l|0)==(g|0)){return}if((l|0)==10){m=d+1|0;n=c[b+8>>2]|0;o=1;p=0}else{q=(k|0)==0?1:k;L7117:do{if(l>>>0>g>>>0){while(1){r=gGq(q)|0;if((r|0)!=0){s=r;break L7117}r=(I=c[2439328]|0,c[2439328]=I+0,I);if((r|0)==0){break}gu[r&16383]()}r=f_(4)|0;c[r>>2]=619768;eh(r|0,625520,1206)}else{while(1){r=gGq(q)|0;if((r|0)!=0){s=r;break L7117}r=(I=c[2439328]|0,c[2439328]=I+0,I);if((r|0)==0){break}gu[r&16383]()}r=f_(4)|0;c[r>>2]=619768;eh(r|0,625520,1206)}}while(0);q=h&1;if(q<<24>>24==0){t=d+1|0}else{t=c[b+8>>2]|0}m=s;n=t;o=q<<24>>24!=0;p=1}if(i){u=f>>>1}else{u=c[b+4>>2]|0}f=u+1|0;gGC(m|0,n|0,f)|0;if(!(o^1|(n|0)==0)){gGr(n)}if(p){c[b>>2]=k|1;c[b+4>>2]=j;c[b+8>>2]=m;return}else{a[e]=j<<1&255;return}}function gAv(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=b;g=a[f]|0;if((g&1)==0){h=10;i=g}else{g=c[b>>2]|0;h=(g&-2)-1|0;i=g&255}g=i&255;if((g&1|0)==0){j=g>>>1}else{j=c[b+4>>2]|0}if((h-j|0)>>>0<e>>>0){gAw(b,h,e-h+j|0,j,j,0,e,d);return}if((e|0)==0){return}if((i&1)==0){k=b+1|0}else{k=c[b+8>>2]|0}i=k+j|0;gGC(i|0,d|0,e)|0;d=j+e|0;if((a[f]&1)==0){a[f]=d<<1&255}else{c[b+4>>2]=d}a[k+d|0]=0;return}function gAw(b,d,e,f,g,h,i,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;if((-18-d|0)>>>0<e>>>0){gAq()}if((a[b]&1)==0){k=b+1|0}else{k=c[b+8>>2]|0}do{if(d>>>0<2147483623){l=e+d|0;m=d<<1;n=l>>>0<m>>>0?m:l;if(n>>>0<11){o=11;break}o=n+16&-16}else{o=-17}}while(0);e=(o|0)==0?1:o;while(1){p=gGq(e)|0;if((p|0)!=0){break}n=(I=c[2439328]|0,c[2439328]=I+0,I);if((n|0)==0){q=6200;break}gu[n&16383]()}if((q|0)==6200){q=f_(4)|0;c[q>>2]=619768;eh(q|0,625520,1206)}if((g|0)!=0){gGC(p|0,k|0,g)|0}if((i|0)!=0){q=p+g|0;gGC(q|0,j|0,i)|0}j=f-h|0;if((j|0)!=(g|0)){f=j-g|0;q=p+(i+g)|0;e=k+(h+g)|0;gGC(q|0,e|0,f)|0}if((d|0)==10|(k|0)==0){r=b+8|0;c[r>>2]=p;s=o|1;t=b|0;c[t>>2]=s;u=j+i|0;v=b+4|0;c[v>>2]=u;w=p+u|0;a[w]=0;return}gGr(k);r=b+8|0;c[r>>2]=p;s=o|1;t=b|0;c[t>>2]=s;u=j+i|0;v=b+4|0;c[v>>2]=u;w=p+u|0;a[w]=0;return}function gAx(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if((-17-d|0)>>>0<e>>>0){gAq()}if((a[b]&1)==0){i=b+1|0}else{i=c[b+8>>2]|0}do{if(d>>>0<2147483623){j=e+d|0;k=d<<1;l=j>>>0<k>>>0?k:j;if(l>>>0<11){m=11;break}m=l+16&-16}else{m=-17}}while(0);e=(m|0)==0?1:m;while(1){n=gGq(e)|0;if((n|0)!=0){break}l=(I=c[2439328]|0,c[2439328]=I+0,I);if((l|0)==0){o=6230;break}gu[l&16383]()}if((o|0)==6230){o=f_(4)|0;c[o>>2]=619768;eh(o|0,625520,1206)}if((g|0)!=0){gGC(n|0,i|0,g)|0}if((f|0)!=(g|0)){o=f-g|0;f=n+(h+g)|0;h=i+g|0;gGC(f|0,h|0,o)|0}if((d|0)==10|(i|0)==0){p=b+8|0;c[p>>2]=n;q=m|1;r=b|0;c[r>>2]=q;return}gGr(i);p=b+8|0;c[p>>2]=n;q=m|1;r=b|0;c[r>>2]=q;return}function gAy(b){b=b|0;var d=0;if((a[b]&1)==0){return}d=c[b+8>>2]|0;if((d|0)==0){return}gGr(d);return}function gAz(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=b;g=a[f]|0;if((g&1)==0){h=1;i=g}else{g=c[b>>2]|0;h=(g&-2)-1|0;i=g&255}if(h>>>0>=e>>>0){if((i&1)==0){j=b+4|0}else{j=c[b+8>>2]|0}g=(e|0)==0;do{if(j-d>>2>>>0<e>>>0){if(g){break}else{k=e}do{k=k-1|0;c[j+(k<<2)>>2]=c[d+(k<<2)>>2];}while((k|0)!=0)}else{if(g){break}else{l=d;m=e;n=j}while(1){o=m-1|0;c[n>>2]=c[l>>2];if((o|0)==0){break}else{l=l+4|0;m=o;n=n+4|0}}}}while(0);c[j+(e<<2)>>2]=0;if((a[f]&1)==0){a[f]=e<<1&255;return}else{c[b+4>>2]=e;return}}if((1073741806-h|0)>>>0<(e-h|0)>>>0){gAq()}if((i&1)==0){p=b+4|0}else{p=c[b+8>>2]|0}do{if(h>>>0<536870887){i=h<<1;f=i>>>0>e>>>0?i:e;if(f>>>0<2){q=2;break}q=f+4&-4}else{q=1073741807}}while(0);f=q<<2;i=(f|0)==0?1:f;while(1){r=gGq(i)|0;if((r|0)!=0){break}f=(I=c[2439328]|0,c[2439328]=I+0,I);if((f|0)==0){s=6279;break}gu[f&16383]()}if((s|0)==6279){s=f_(4)|0;c[s>>2]=619768;eh(s|0,625520,1206)}s=r;if((e|0)!=0){r=d;d=e;i=s;while(1){f=d-1|0;c[i>>2]=c[r>>2];if((f|0)==0){break}else{r=r+4|0;d=f;i=i+4|0}}}if(!((h|0)==1|(p|0)==0)){gGr(p)}c[b+8>>2]=s;c[b>>2]=q|1;c[b+4>>2]=e;c[s+(e<<2)>>2]=0;return}function gAA(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=b;e=a[d]|0;if((e&1)==0){f=1;g=e}else{e=c[b>>2]|0;f=(e&-2)-1|0;g=e&255}e=g&255;h=(e&1|0)==0;if(h){i=e>>>1}else{i=c[b+4>>2]|0}if(i>>>0<2){j=2}else{j=i+4&-4}k=j-1|0;if((k|0)==(f|0)){return}if((k|0)==1){l=b+4|0;m=c[b+8>>2]|0;n=1;o=0}else{p=j<<2;q=(p|0)==0?1:p;L7311:do{if(k>>>0>f>>>0){while(1){p=gGq(q)|0;if((p|0)!=0){r=p;break L7311}p=(I=c[2439328]|0,c[2439328]=I+0,I);if((p|0)==0){break}gu[p&16383]()}p=f_(4)|0;c[p>>2]=619768;eh(p|0,625520,1206)}else{while(1){p=gGq(q)|0;if((p|0)!=0){r=p;break L7311}p=(I=c[2439328]|0,c[2439328]=I+0,I);if((p|0)==0){break}gu[p&16383]()}p=f_(4)|0;c[p>>2]=619768;eh(p|0,625520,1206)}}while(0);q=g&1;if(q<<24>>24==0){s=b+4|0}else{s=c[b+8>>2]|0}l=r;m=s;n=q<<24>>24!=0;o=1}q=l;if(h){t=e>>>1}else{t=c[b+4>>2]|0}e=t+1|0;if((e|0)!=0){t=m;h=e;e=q;while(1){l=h-1|0;c[e>>2]=c[t>>2];if((l|0)==0){break}else{t=t+4|0;h=l;e=e+4|0}}}if(!(n^1|(m|0)==0)){gGr(m)}if(o){c[b>>2]=j|1;c[b+4>>2]=i;c[b+8>>2]=q;return}else{a[d]=i<<1&255;return}}function gAB(b,d,e,f,g,h,i){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;if((1073741807-d|0)>>>0<e>>>0){gAq()}if((a[b]&1)==0){j=b+4|0}else{j=c[b+8>>2]|0}do{if(d>>>0<536870887){k=e+d|0;l=d<<1;m=k>>>0<l>>>0?l:k;if(m>>>0<2){n=2;break}n=m+4&-4}else{n=1073741807}}while(0);e=n<<2;m=(e|0)==0?1:e;while(1){o=gGq(m)|0;if((o|0)!=0){break}e=(I=c[2439328]|0,c[2439328]=I+0,I);if((e|0)==0){p=6358;break}gu[e&16383]()}if((p|0)==6358){p=f_(4)|0;c[p>>2]=619768;eh(p|0,625520,1206)}p=o;if((g|0)!=0){o=j;m=g;e=p;while(1){k=m-1|0;c[e>>2]=c[o>>2];if((k|0)==0){break}else{o=o+4|0;m=k;e=e+4|0}}}e=f-h|0;if((e|0)!=(g|0)){f=j+(h+g<<2)|0;h=e-g|0;e=p+(i+g<<2)|0;while(1){g=h-1|0;c[e>>2]=c[f>>2];if((g|0)==0){break}else{f=f+4|0;h=g;e=e+4|0}}}if((d|0)==1|(j|0)==0){q=b+8|0;c[q>>2]=p;r=n|1;s=b|0;c[s>>2]=r;return}gGr(j);q=b+8|0;c[q>>2]=p;r=n|1;s=b|0;c[s>>2]=r;return}function gAC(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+48|0;g=f|0;h=f+16|0;j=f+32|0;k=(c[b+24>>2]|0)==0;if(k){c[b+16>>2]=e|1}else{c[b+16>>2]=e}if((c[b+20>>2]&(k&1|e)|0)==0){i=f;return}f=f_(16)|0;do{if((a[14125008]|0)==0){if((bp(14125008)|0)==0){break}c[2384152]=621360}}while(0);e=h;k=j;while(1){l=gGq(16)|0;if((l|0)!=0){break}b=(I=c[2439328]|0,c[2439328]=I+0,I);if((b|0)==0){m=6387;break}gu[b&16383]()}if((m|0)==6387){b=f_(4)|0;c[b>>2]=619768;eh(b|0,625520,1206)}b=j+8|0;c[b>>2]=l;c[j>>2]=17;n=j+4|0;c[n>>2]=15;gGC(l|0,438792,15)|0;a[l+15|0]=0;l=g;o=d[k]|0;if((((o&1|0)==0?o>>>1:c[n>>2]|0)|0)!=0){gAv(j,557040,2)}gG[c[(c[2384152]|0)+24>>2]&255](g,9536608,1);n=a[l]|0;if((n&1)==0){p=g+1|0}else{p=c[g+8>>2]|0}o=n&255;if((o&1|0)==0){q=o>>>1}else{q=c[g+4>>2]|0}gAv(j,p,q);do{if((a[l]&1)!=0){q=c[g+8>>2]|0;if((q|0)==0){break}gGr(q)}}while(0);c[e>>2]=c[k>>2];c[e+4>>2]=c[k+4>>2];c[e+8>>2]=c[k+8>>2];gGz(k|0,0,12);g=f;c[g>>2]=619832;l=f+4|0;q=l;p=a[e]&1;do{if((l|0)==0){r=p}else{if(p<<24>>24==0){s=h+1|0}else{s=c[h+8>>2]|0}e=gGy(s|0)|0;j=e+13|0;o=(j|0)==0?1:j;while(1){t=gGq(o)|0;if((t|0)!=0){m=6420;break}j=(I=c[2439328]|0,c[2439328]=I+0,I);if((j|0)==0){break}gu[j&16383]()}if((m|0)==6420){o=e+1|0;c[t+4>>2]=e;c[t>>2]=e;j=t+12|0;c[q>>2]=j;c[t+8>>2]=0;gGC(j|0,s|0,o)|0;r=p;break}o=f_(4)|0;c[o>>2]=619768;eh(o|0,625520,1206)}}while(0);do{if(r<<24>>24!=0){p=c[h+8>>2]|0;if((p|0)==0){break}gGr(p)}}while(0);do{if((a[k]&1)!=0){h=c[b>>2]|0;if((h|0)==0){break}gGr(h)}}while(0);c[g>>2]=621856;b=f+8|0;k=gGM(9536608,0,32)|0;c[b>>2]=k&0|1;c[b+4>>2]=K|0;c[g>>2]=620544;eh(f|0,626112,958)}function gAD(a){a=a|0;var b=0,d=0,e=0,f=0;c[a>>2]=620520;b=c[a+40>>2]|0;d=a+32|0;e=a+36|0;if((b|0)!=0){f=b;do{f=f-1|0;gG[c[(c[d>>2]|0)+(f<<2)>>2]&255](0,a,c[(c[e>>2]|0)+(f<<2)>>2]|0);}while((f|0)!=0)}f=c[a+28>>2]|0;b=f+4|0;if(((I=c[b>>2]|0,c[b>>2]=I+ -1,I)|0)==0){gf[c[(c[f>>2]|0)+8>>2]&2047](f)}gGr(c[d>>2]|0);gGr(c[e>>2]|0);gGr(c[a+48>>2]|0);gGr(c[a+60>>2]|0);return}function gAE(a){a=a|0;var b=0,d=0,e=0;c[a>>2]=621592;b=c[a+4>>2]|0;d=b+4|0;if(((I=c[d>>2]|0,c[d>>2]=I+ -1,I)|0)!=0){e=a;gGr(e);return}gf[c[(c[b>>2]|0)+8>>2]&2047](b|0);e=a;gGr(e);return}function gAF(a){a=a|0;var b=0;c[a>>2]=621592;b=c[a+4>>2]|0;a=b+4|0;if(((I=c[a>>2]|0,c[a>>2]=I+ -1,I)|0)!=0){return}gf[c[(c[b>>2]|0)+8>>2]&2047](b|0);return}function gAG(a,b){a=a|0;b=b|0;return}function gAH(a,b,c){a=a|0;b=b|0;c=c|0;return a|0}function gAI(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;g=a;c[g>>2]=0;c[g+4>>2]=0;g=a+8|0;c[g>>2]=-1;c[g+4>>2]=-1;return}function gAJ(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;e=i;b=d;d=i;i=i+16|0;c[d>>2]=c[b>>2];c[d+4>>2]=c[b+4>>2];c[d+8>>2]=c[b+8>>2];c[d+12>>2]=c[b+12>>2];b=a;c[b>>2]=0;c[b+4>>2]=0;b=a+8|0;c[b>>2]=-1;c[b+4>>2]=-1;i=e;return}function gAK(a){a=a|0;return 0}function gAL(a){a=a|0;return 0}function gAM(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=b;if((e|0)<=0){g=0;return g|0}h=b+12|0;i=b+16|0;j=d;d=0;while(1){k=c[h>>2]|0;if(k>>>0<(c[i>>2]|0)>>>0){c[h>>2]=k+1;l=a[k]|0}else{k=gj[c[(c[f>>2]|0)+40>>2]&4095](b)|0;if((k|0)==-1){g=d;m=6477;break}l=k&255}a[j]=l;k=d+1|0;if((k|0)<(e|0)){j=j+1|0;d=k}else{g=k;m=6478;break}}if((m|0)==6477){return g|0}else if((m|0)==6478){return g|0}return 0}function gAN(a){a=a|0;return-1|0}function gAO(a){a=a|0;var b=0,e=0;if((gj[c[(c[a>>2]|0)+36>>2]&4095](a)|0)==-1){b=-1;return b|0}e=a+12|0;a=c[e>>2]|0;c[e>>2]=a+1;b=d[a]|0;return b|0}function gAP(a,b){a=a|0;b=b|0;return-1|0}function gAQ(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=b;if((f|0)<=0){h=0;return h|0}i=b+24|0;j=b+28|0;k=0;l=e;while(1){e=c[i>>2]|0;if(e>>>0<(c[j>>2]|0)>>>0){m=a[l]|0;c[i>>2]=e+1;a[e]=m}else{if((gA[c[(c[g>>2]|0)+52>>2]&16383](b,d[l]|0)|0)==-1){h=k;n=6494;break}}m=k+1|0;if((m|0)<(f|0)){k=m;l=l+1|0}else{h=m;n=6493;break}}if((n|0)==6494){return h|0}else if((n|0)==6493){return h|0}return 0}function gAR(a,b){a=a|0;b=b|0;return-1|0}function gAS(a){a=a|0;var b=0,d=0,e=0;c[a>>2]=621520;b=c[a+4>>2]|0;d=b+4|0;if(((I=c[d>>2]|0,c[d>>2]=I+ -1,I)|0)!=0){e=a;gGr(e);return}gf[c[(c[b>>2]|0)+8>>2]&2047](b|0);e=a;gGr(e);return}function gAT(a){a=a|0;var b=0;c[a>>2]=621520;b=c[a+4>>2]|0;a=b+4|0;if(((I=c[a>>2]|0,c[a>>2]=I+ -1,I)|0)!=0){return}gf[c[(c[b>>2]|0)+8>>2]&2047](b|0);return}function gAU(a,b){a=a|0;b=b|0;return}function gAV(a,b,c){a=a|0;b=b|0;c=c|0;return a|0}function gAW(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;g=a;c[g>>2]=0;c[g+4>>2]=0;g=a+8|0;c[g>>2]=-1;c[g+4>>2]=-1;return}function gAX(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;e=i;b=d;d=i;i=i+16|0;c[d>>2]=c[b>>2];c[d+4>>2]=c[b+4>>2];c[d+8>>2]=c[b+8>>2];c[d+12>>2]=c[b+12>>2];b=a;c[b>>2]=0;c[b+4>>2]=0;b=a+8|0;c[b>>2]=-1;c[b+4>>2]=-1;i=e;return}function gAY(a){a=a|0;return 0}function gAZ(a){a=a|0;return 0}function gA_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=a;if((d|0)<=0){f=0;return f|0}g=a+12|0;h=a+16|0;i=b;b=0;while(1){j=c[g>>2]|0;if(j>>>0<(c[h>>2]|0)>>>0){c[g>>2]=j+4;k=c[j>>2]|0}else{j=gj[c[(c[e>>2]|0)+40>>2]&4095](a)|0;if((j|0)==-1){f=b;l=6520;break}else{k=j}}c[i>>2]=k;j=b+1|0;if((j|0)<(d|0)){i=i+4|0;b=j}else{f=j;l=6522;break}}if((l|0)==6520){return f|0}else if((l|0)==6522){return f|0}return 0}function gA$(a){a=a|0;return-1|0}function gA0(a){a=a|0;var b=0,d=0;if((gj[c[(c[a>>2]|0)+36>>2]&4095](a)|0)==-1){b=-1;return b|0}d=a+12|0;a=c[d>>2]|0;c[d>>2]=a+4;b=c[a>>2]|0;return b|0}function gA1(a,b){a=a|0;b=b|0;return-1|0}function gA2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=a;if((d|0)<=0){f=0;return f|0}g=a+24|0;h=a+28|0;i=0;j=b;while(1){b=c[g>>2]|0;if(b>>>0<(c[h>>2]|0)>>>0){k=c[j>>2]|0;c[g>>2]=b+4;c[b>>2]=k}else{if((gA[c[(c[e>>2]|0)+52>>2]&16383](a,c[j>>2]|0)|0)==-1){f=i;l=6538;break}}k=i+1|0;if((k|0)<(d|0)){i=k;j=j+4|0}else{f=k;l=6537;break}}if((l|0)==6538){return f|0}else if((l|0)==6537){return f|0}return 0}function gA3(a,b){a=a|0;b=b|0;return-1|0}function gA4(a){a=a|0;gAD(a+8|0);if((a|0)==0){return}gGr(a);return}function gA5(a){a=a|0;gAD(a+8|0);return}function gA6(a){a=a|0;var b=0,d=0;b=a;d=c[(c[a>>2]|0)-12>>2]|0;a=b+d|0;gAD(b+(d+8)|0);if((a|0)==0){return}gGr(a);return}function gA7(a){a=a|0;gAD(a+((c[(c[a>>2]|0)-12>>2]|0)+8)|0);return}function gA8(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;d=i;i=i+8|0;e=d|0;f=b;g=c[(c[f>>2]|0)-12>>2]|0;h=b;if((c[h+(g+24)>>2]|0)==0){i=d;return}j=e|0;a[j]=0;c[e+4>>2]=b;do{if((c[h+(g+16)>>2]|0)==0){b=c[h+(g+72)>>2]|0;if((b|0)==0){k=g}else{gA8(b);k=c[(c[f>>2]|0)-12>>2]|0}a[j]=1;b=c[h+(k+24)>>2]|0;if((gj[c[(c[b>>2]|0)+24>>2]&4095](b)|0)!=-1){break}b=c[(c[f>>2]|0)-12>>2]|0;gAC(h+b|0,c[h+(b+16)>>2]|1)}}while(0);gBi(e);i=d;return}function gA9(a){a=a|0;gAD(a+8|0);if((a|0)==0){return}gGr(a);return}function gBa(a){a=a|0;gAD(a+8|0);return}function gBb(a){a=a|0;var b=0,d=0;b=a;d=c[(c[a>>2]|0)-12>>2]|0;a=b+d|0;gAD(b+(d+8)|0);if((a|0)==0){return}gGr(a);return}function gBc(a){a=a|0;gAD(a+((c[(c[a>>2]|0)-12>>2]|0)+8)|0);return}function gBd(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;d=i;i=i+8|0;e=d|0;f=b;g=c[(c[f>>2]|0)-12>>2]|0;h=b;if((c[h+(g+24)>>2]|0)==0){i=d;return}j=e|0;a[j]=0;c[e+4>>2]=b;do{if((c[h+(g+16)>>2]|0)==0){b=c[h+(g+72)>>2]|0;if((b|0)==0){k=g}else{gBd(b);k=c[(c[f>>2]|0)-12>>2]|0}a[j]=1;b=c[h+(k+24)>>2]|0;if((gj[c[(c[b>>2]|0)+24>>2]&4095](b)|0)!=-1){break}b=c[(c[f>>2]|0)-12>>2]|0;gAC(h+b|0,c[h+(b+16)>>2]|1)}}while(0);gBn(e);i=d;return}function gBe(a){a=a|0;gAD(a+4|0);if((a|0)==0){return}gGr(a);return}function gBf(a){a=a|0;gAD(a+4|0);return}function gBg(a){a=a|0;var b=0,d=0;b=a;d=c[(c[a>>2]|0)-12>>2]|0;a=b+d|0;gAD(b+(d+4)|0);if((a|0)==0){return}gGr(a);return}function gBh(a){a=a|0;gAD(a+((c[(c[a>>2]|0)-12>>2]|0)+4)|0);return}function gBi(a){a=a|0;var b=0,d=0,e=0;b=a+4|0;a=c[b>>2]|0;d=c[(c[a>>2]|0)-12>>2]|0;e=a;if((c[e+(d+24)>>2]|0)==0){return}if((c[e+(d+16)>>2]|0)!=0){return}if((c[e+(d+4)>>2]&8192|0)==0){return}if(cO()|0){return}d=c[b>>2]|0;e=c[d+((c[(c[d>>2]|0)-12>>2]|0)+24)>>2]|0;if((gj[c[(c[e>>2]|0)+24>>2]&4095](e)|0)!=-1){return}e=c[b>>2]|0;b=c[(c[e>>2]|0)-12>>2]|0;d=e;gAC(d+b|0,c[d+(b+16)>>2]|1);return}function gBj(a){a=a|0;gAD(a+4|0);if((a|0)==0){return}gGr(a);return}function gBk(a){a=a|0;gAD(a+4|0);return}function gBl(a){a=a|0;var b=0,d=0;b=a;d=c[(c[a>>2]|0)-12>>2]|0;a=b+d|0;gAD(b+(d+4)|0);if((a|0)==0){return}gGr(a);return}function gBm(a){a=a|0;gAD(a+((c[(c[a>>2]|0)-12>>2]|0)+4)|0);return}function gBn(a){a=a|0;var b=0,d=0,e=0;b=a+4|0;a=c[b>>2]|0;d=c[(c[a>>2]|0)-12>>2]|0;e=a;if((c[e+(d+24)>>2]|0)==0){return}if((c[e+(d+16)>>2]|0)!=0){return}if((c[e+(d+4)>>2]&8192|0)==0){return}if(cO()|0){return}d=c[b>>2]|0;e=c[d+((c[(c[d>>2]|0)-12>>2]|0)+24)>>2]|0;if((gj[c[(c[e>>2]|0)+24>>2]&4095](e)|0)!=-1){return}e=c[b>>2]|0;b=c[(c[e>>2]|0)-12>>2]|0;d=e;gAC(d+b|0,c[d+(b+16)>>2]|1);return}function gBo(a){a=a|0;return 536432}function gBp(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;if((e|0)==1){while(1){f=gGq(48)|0;if((f|0)!=0){g=6692;break}d=(I=c[2439328]|0,c[2439328]=I+0,I);if((d|0)==0){g=6689;break}gu[d&16383]()}if((g|0)==6689){d=f_(4)|0;c[d>>2]=619768;eh(d|0,625520,1206)}else if((g|0)==6692){c[b+8>>2]=f;c[b>>2]=49;c[b+4>>2]=35;gGC(f|0,566912,35)|0;a[f+35|0]=0;return}}f=bP(e|0)|0;e=gGy(f|0)|0;if(e>>>0>4294967279){gAq()}do{if(e>>>0<11){a[b]=e<<1&255;h=b+1|0}else{d=e+16&-16;i=(d|0)==0?1:d;while(1){j=gGq(i)|0;if((j|0)!=0){g=6680;break}k=(I=c[2439328]|0,c[2439328]=I+0,I);if((k|0)==0){break}gu[k&16383]()}if((g|0)==6680){c[b+8>>2]=j;c[b>>2]=d|1;c[b+4>>2]=e;h=j;break}i=f_(4)|0;c[i>>2]=619768;eh(i|0,625520,1206)}}while(0);gGC(h|0,f|0,e)|0;a[h+e|0]=0;return}function gBq(a){a=a|0;return}function gBr(a){a=a|0;var b=0,d=0,e=0;c[a>>2]=619832;b=a+4|0;d=(c[b>>2]|0)-4|0;do{if(((I=c[d>>2]|0,c[d>>2]=I+ -1,I)-1|0)<0){e=(c[b>>2]|0)-12|0;if((e|0)!=0){gGr(e)}if((a|0)!=0){break}return}}while(0);gGr(a);return}function gBs(a){a=a|0;var b=0;c[a>>2]=619832;b=a+4|0;a=(c[b>>2]|0)-4|0;if(((I=c[a>>2]|0,c[a>>2]=I+ -1,I)-1|0)>=0){return}a=(c[b>>2]|0)-12|0;if((a|0)==0){return}gGr(a);return}function gBt(a){a=a|0;gAD(a);if((a|0)==0){return}gGr(a);return}function gBu(a){a=a|0;if((a|0)==0){return}gGr(a);return}function gBv(a){a=a|0;if((a|0)==0){return}gGr(a);return}function gBw(a){a=a|0;return}function gBx(a){a=a|0;return}function gBy(b,c,d,e,f){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;L7726:do{if((e|0)==(f|0)){g=c}else{b=c;h=e;while(1){if((b|0)==(d|0)){i=-1;j=6737;break}k=a[b]|0;l=a[h]|0;if(k<<24>>24<l<<24>>24){i=-1;j=6738;break}if(l<<24>>24<k<<24>>24){i=1;j=6739;break}k=b+1|0;l=h+1|0;if((l|0)==(f|0)){g=k;break L7726}else{b=k;h=l}}if((j|0)==6739){return i|0}else if((j|0)==6738){return i|0}else if((j|0)==6737){return i|0}}}while(0);i=(g|0)!=(d|0)|0;return i|0}function gBz(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=e;g=f-d|0;if(g>>>0>4294967279){gAq()}do{if(g>>>0<11){a[b]=g<<1&255;h=b+1|0}else{i=g+16&-16;j=(i|0)==0?1:i;while(1){k=gGq(j)|0;if((k|0)!=0){l=6755;break}m=(I=c[2439328]|0,c[2439328]=I+0,I);if((m|0)==0){break}gu[m&16383]()}if((l|0)==6755){c[b+8>>2]=k;c[b>>2]=i|1;c[b+4>>2]=g;h=k;break}j=f_(4)|0;c[j>>2]=619768;eh(j|0,625520,1206)}}while(0);if((e|0)==(f|0)){n=h;a[n]=0;return}k=-d|0;d=h;g=e;while(1){a[d]=a[g]|0;e=g+1|0;if((e|0)==(f|0)){break}else{d=d+1|0;g=e}}n=h+(f+k)|0;a[n]=0;return}function gBA(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;if((c|0)==(d|0)){e=0;return e|0}else{f=c;g=0}while(1){c=(a[f]|0)+(g<<4)|0;b=c&-268435456;h=(b>>>24|b)^c;c=f+1|0;if((c|0)==(d|0)){e=h;break}else{f=c;g=h}}return e|0}function gBB(a){a=a|0;if((a|0)==0){return}gGr(a);return}function gBC(a){a=a|0;return}function gBD(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;L7774:do{if((e|0)==(f|0)){g=b}else{a=b;h=e;while(1){if((a|0)==(d|0)){i=-1;j=6781;break}k=c[a>>2]|0;l=c[h>>2]|0;if((k|0)<(l|0)){i=-1;j=6783;break}if((l|0)<(k|0)){i=1;j=6784;break}k=a+4|0;l=h+4|0;if((l|0)==(f|0)){g=k;break L7774}else{a=k;h=l}}if((j|0)==6783){return i|0}else if((j|0)==6781){return i|0}else if((j|0)==6784){return i|0}}}while(0);i=(g|0)!=(d|0)|0;return i|0}function gBE(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=e;g=f-d|0;h=g>>2;if(h>>>0>1073741807){gAq()}do{if(h>>>0<2){a[b]=g>>>1&255;i=b+4|0}else{j=h+4&-4;k=j<<2;l=(k|0)==0?1:k;while(1){m=gGq(l)|0;if((m|0)!=0){n=6800;break}k=(I=c[2439328]|0,c[2439328]=I+0,I);if((k|0)==0){break}gu[k&16383]()}if((n|0)==6800){l=m;c[b+8>>2]=l;c[b>>2]=j|1;c[b+4>>2]=h;i=l;break}l=f_(4)|0;c[l>>2]=619768;eh(l|0,625520,1206)}}while(0);if((e|0)==(f|0)){o=i;c[o>>2]=0;return}h=f-4+(-d|0)|0;d=i;b=e;while(1){c[d>>2]=c[b>>2];e=b+4|0;if((e|0)==(f|0)){break}else{d=d+4|0;b=e}}o=i+((h>>>2)+1<<2)|0;c[o>>2]=0;return}function gBF(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;if((b|0)==(d|0)){e=0;return e|0}else{f=b;g=0}while(1){b=(c[f>>2]|0)+(g<<4)|0;a=b&-268435456;h=(a>>>24|a)^b;b=f+4|0;if((b|0)==(d|0)){e=h;break}else{f=b;g=h}}return e|0}function gBG(a){a=a|0;if((a|0)==0){return}gGr(a);return}function gBH(a){a=a|0;return}function gBI(b,d,e,f,g,h,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;k=i;i=i+88|0;l=e;e=i;i=i+4|0;i=i+7&-8;c[e>>2]=c[l>>2];l=f;f=i;i=i+4|0;i=i+7&-8;c[f>>2]=c[l>>2];l=k|0;m=k+16|0;n=k+32|0;o=k+40|0;p=k+48|0;q=k+56|0;r=k+64|0;if((c[g+4>>2]&1|0)==0){c[n>>2]=-1;s=c[(c[d>>2]|0)+16>>2]|0;t=e|0;c[p>>2]=c[t>>2];c[q>>2]=c[f>>2];gw[s&127](o,d,p,q,g,h,n);q=c[o>>2]|0;c[t>>2]=q;t=c[n>>2]|0;if((t|0)==0){a[j]=0}else if((t|0)==1){a[j]=1}else{a[j]=1;c[h>>2]=4}c[b>>2]=q;i=k;return}q=g+28|0;g=c[q>>2]|0;t=g+4|0;I=c[t>>2]|0,c[t>>2]=I+1,I;if((c[2385060]|0)!=-1){c[m>>2]=9540240;c[m+4>>2]=180;c[m+8>>2]=0;gAp(9540240,m)}m=(c[2385061]|0)-1|0;n=c[g+8>>2]|0;do{if((c[g+12>>2]|0)-n>>2>>>0>m>>>0){o=c[n+(m<<2)>>2]|0;if((o|0)==0){break}p=o;if(((I=c[t>>2]|0,c[t>>2]=I+ -1,I)|0)==0){gf[c[(c[g>>2]|0)+8>>2]&2047](g)}o=c[q>>2]|0;d=o+4|0;I=c[d>>2]|0,c[d>>2]=I+1,I;if((c[2384964]|0)!=-1){c[l>>2]=9539856;c[l+4>>2]=180;c[l+8>>2]=0;gAp(9539856,l)}s=(c[2384965]|0)-1|0;u=c[o+8>>2]|0;do{if((c[o+12>>2]|0)-u>>2>>>0>s>>>0){v=c[u+(s<<2)>>2]|0;if((v|0)==0){break}w=v;if(((I=c[d>>2]|0,c[d>>2]=I+ -1,I)|0)==0){gf[c[(c[o>>2]|0)+8>>2]&2047](o)}x=r|0;y=v;gg[c[(c[y>>2]|0)+24>>2]&4095](x,w);v=r+12|0;gg[c[(c[y>>2]|0)+28>>2]&4095](v,w);a[j]=(gBJ(e,c[f>>2]|0,x,r+24|0,p,h,1)|0)==(x|0)|0;c[b>>2]=c[e>>2];do{if((a[v]&1)!=0){x=c[r+20>>2]|0;if((x|0)==0){break}gGr(x)}}while(0);if((a[r]&1)==0){i=k;return}v=c[r+8>>2]|0;if((v|0)==0){i=k;return}gGr(v);i=k;return}}while(0);p=f_(4)|0;c[p>>2]=619800;eh(p|0,625536,1e3)}}while(0);k=f_(4)|0;c[k>>2]=619800;eh(k|0,625536,1e3)}function gBJ(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0;l=i;i=i+104|0;m=(g-f|0)/12|0;n=l|0;do{if(m>>>0>100){o=gGq(m)|0;if((o|0)!=0){p=o;q=o;break}o=f_(4)|0;c[o>>2]=619768;eh(o|0,625520,1206);return 0}else{p=n;q=0}}while(0);n=(f|0)==(g|0);if(n){r=m;s=0}else{o=m;m=0;t=p;u=f;while(1){v=d[u]|0;if((v&1|0)==0){w=v>>>1}else{w=c[u+4>>2]|0}if((w|0)==0){a[t]=2;x=m+1|0;y=o-1|0}else{a[t]=1;x=m;y=o}v=u+12|0;if((v|0)==(g|0)){r=y;s=x;break}else{o=y;m=x;t=t+1|0;u=v}}}u=b|0;b=h;t=0;x=s;s=r;r=e;L7885:while(1){e=(s|0)!=0;m=t;y=r;while(1){o=c[u>>2]|0;do{if((o|0)==0){z=0}else{if((c[o+12>>2]|0)!=(c[o+16>>2]|0)){z=o;break}if((gj[c[(c[o>>2]|0)+36>>2]&4095](o)|0)==-1){c[u>>2]=0;z=0;break}else{z=c[u>>2]|0;break}}}while(0);o=(z|0)==0;if((y|0)==0){A=z;B=0}else{if((c[y+12>>2]|0)==(c[y+16>>2]|0)){w=(gj[c[(c[y>>2]|0)+36>>2]&4095](y)|0)==-1;C=w?0:y}else{C=y}A=c[u>>2]|0;B=C}D=(B|0)==0;if(!((o^D)&e)){break L7885}o=c[A+12>>2]|0;if((o|0)==(c[A+16>>2]|0)){E=(gj[c[(c[A>>2]|0)+36>>2]&4095](A)|0)&255}else{E=a[o]|0}if(k){F=E}else{F=gA[c[(c[b>>2]|0)+12>>2]&16383](h,E)|0}G=m+1|0;if(n){m=G;y=B}else{break}}L7914:do{if(k){y=s;e=x;o=p;w=0;v=f;while(1){do{if((a[o]|0)==1){H=a[v]|0;if((H&1)==0){I=v+1|0}else{I=c[v+8>>2]|0}if(F<<24>>24!=(a[I+m|0]|0)){a[o]=0;J=w;K=e;L=y-1|0;break}M=H&255;if((M&1|0)==0){N=M>>>1}else{N=c[v+4>>2]|0}if((N|0)!=(G|0)){J=1;K=e;L=y;break}a[o]=2;J=1;K=e+1|0;L=y-1|0}else{J=w;K=e;L=y}}while(0);M=v+12|0;if((M|0)==(g|0)){O=L;P=K;Q=J;break L7914}y=L;e=K;o=o+1|0;w=J;v=M}}else{v=s;w=x;o=p;e=0;y=f;while(1){do{if((a[o]|0)==1){M=y;if((a[M]&1)==0){R=y+1|0}else{R=c[y+8>>2]|0}if(F<<24>>24!=(gA[c[(c[b>>2]|0)+12>>2]&16383](h,a[R+m|0]|0)|0)<<24>>24){a[o]=0;S=e;T=w;U=v-1|0;break}H=d[M]|0;if((H&1|0)==0){V=H>>>1}else{V=c[y+4>>2]|0}if((V|0)!=(G|0)){S=1;T=w;U=v;break}a[o]=2;S=1;T=w+1|0;U=v-1|0}else{S=e;T=w;U=v}}while(0);H=y+12|0;if((H|0)==(g|0)){O=U;P=T;Q=S;break L7914}v=U;w=T;o=o+1|0;e=S;y=H}}}while(0);if(!Q){t=G;x=P;s=O;r=B;continue}m=c[u>>2]|0;y=m+12|0;e=c[y>>2]|0;if((e|0)==(c[m+16>>2]|0)){o=c[(c[m>>2]|0)+40>>2]|0;gj[o&4095](m)|0}else{c[y>>2]=e+1}if((O+P|0)>>>0<2){t=G;x=P;s=O;r=B;continue}else{W=P;X=p;Y=f}while(1){do{if((a[X]|0)==2){e=d[Y]|0;if((e&1|0)==0){Z=e>>>1}else{Z=c[Y+4>>2]|0}if((Z|0)==(G|0)){_=W;break}a[X]=0;_=W-1|0}else{_=W}}while(0);e=Y+12|0;if((e|0)==(g|0)){t=G;x=_;s=O;r=B;continue L7885}else{W=_;X=X+1|0;Y=e}}}do{if((A|0)==0){$=0}else{if((c[A+12>>2]|0)!=(c[A+16>>2]|0)){$=A;break}if((gj[c[(c[A>>2]|0)+36>>2]&4095](A)|0)==-1){c[u>>2]=0;$=0;break}else{$=c[u>>2]|0;break}}}while(0);u=($|0)==0;do{if(D){aa=6963}else{if((c[B+12>>2]|0)!=(c[B+16>>2]|0)){if(u){break}else{aa=6965;break}}if((gj[c[(c[B>>2]|0)+36>>2]&4095](B)|0)==-1){aa=6963;break}if(!u){aa=6965}}}while(0);if((aa|0)==6963){if(u){aa=6965}}if((aa|0)==6965){c[j>>2]=c[j>>2]|2}L7989:do{if(n){aa=6970}else{u=f;B=p;while(1){if((a[B]|0)==2){ab=u;break L7989}D=u+12|0;if((D|0)==(g|0)){aa=6970;break L7989}u=D;B=B+1|0}}}while(0);if((aa|0)==6970){c[j>>2]=c[j>>2]|4;ab=g}if((q|0)==0){i=l;return ab|0}gGr(q);i=l;return ab|0}function gBK(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0;e=i;i=i+256|0;l=f;f=i;i=i+4|0;i=i+7&-8;c[f>>2]=c[l>>2];l=g;g=i;i=i+4|0;i=i+7&-8;c[g>>2]=c[l>>2];l=e+32|0;m=e+40|0;n=e+56|0;o=e+72|0;p=e+80|0;q=e+240|0;r=e+248|0;s=c[f>>2]|0;f=c[g>>2]|0;g=e|0;t=m;u=n;v=c[h+4>>2]&74;if((v|0)==0){w=0}else if((v|0)==64){w=8}else if((v|0)==8){w=16}else{w=10}gB9(m,c[h+28>>2]|0,g,l);gGz(u|0,0,12);h=n;gAt(n,10);if((a[u]&1)==0){v=h+1|0;x=v;y=v;z=n+8|0}else{v=n+8|0;x=c[v>>2]|0;y=h+1|0;z=v}c[o>>2]=x;v=p|0;c[q>>2]=v;c[r>>2]=0;A=n|0;B=n+4|0;C=a[l]|0;l=n+8|0;D=x;x=s;s=f;L8012:while(1){do{if((x|0)==0){E=0}else{if((c[x+12>>2]|0)!=(c[x+16>>2]|0)){E=x;break}f=(gj[c[(c[x>>2]|0)+36>>2]&4095](x)|0)==-1;E=f?0:x}}while(0);f=(E|0)==0;do{if((s|0)==0){F=6995}else{if((c[s+12>>2]|0)!=(c[s+16>>2]|0)){if(f){G=0;H=s;break}else{I=D;J=s;K=0;L=E;M=0;break L8012}}if((gj[c[(c[s>>2]|0)+36>>2]&4095](s)|0)==-1){F=6995;break}if(f){G=0;H=s}else{I=D;J=s;K=0;L=E;M=0;break L8012}}}while(0);if((F|0)==6995){F=0;if(f){I=D;J=0;K=1;L=0;M=1;break}else{G=1;H=0}}N=(c[o>>2]|0)-D|0;O=a[u]|0;P=O&255;if((N|0)==(((P&1|0)==0?P>>>1:c[B>>2]|0)|0)){P=N<<1;do{if(N>>>0<P>>>0){gAt(n,N)}else{if((O&1)==0){a[h+1+P|0]=0;a[u]=N<<2&255;break}else{a[(c[l>>2]|0)+P|0]=0;c[B>>2]=P;break}}}while(0);P=a[u]|0;if((P&1)==0){Q=10;R=P}else{P=c[A>>2]|0;Q=(P&-2)-1|0;R=P&255}P=R&255;O=(P&1|0)==0?P>>>1:c[B>>2]|0;do{if(O>>>0<Q>>>0){gAt(n,Q-O|0)}else{if((R&1)==0){a[h+1+Q|0]=0;a[u]=Q<<1&255;break}else{a[(c[l>>2]|0)+Q|0]=0;c[B>>2]=Q;break}}}while(0);if((a[u]&1)==0){S=y}else{S=c[z>>2]|0}c[o>>2]=S+N;T=S}else{T=D}O=E+12|0;P=c[O>>2]|0;U=E+16|0;if((P|0)==(c[U>>2]|0)){V=(gj[c[(c[E>>2]|0)+36>>2]&4095](E)|0)&255}else{V=a[P]|0}if((gBU(V,w,T,o,r,C,m,v,q,g)|0)!=0){I=T;J=H;K=G;L=E;M=f;break}P=c[O>>2]|0;if((P|0)==(c[U>>2]|0)){U=c[(c[E>>2]|0)+40>>2]|0;gj[U&4095](E)|0;D=T;x=E;s=H;continue}else{c[O>>2]=P+1;D=T;x=E;s=H;continue}}H=d[t]|0;if((H&1|0)==0){W=H>>>1}else{W=c[m+4>>2]|0}do{if((W|0)!=0){H=c[q>>2]|0;if((H-p|0)>=160){break}s=c[r>>2]|0;c[q>>2]=H+4;c[H>>2]=s}}while(0);c[k>>2]=gFY(I,c[o>>2]|0,j,w)|0;gDW(m,v,c[q>>2]|0,j);do{if(M){X=0}else{if((c[L+12>>2]|0)!=(c[L+16>>2]|0)){X=L;break}q=(gj[c[(c[L>>2]|0)+36>>2]&4095](L)|0)==-1;X=q?0:L}}while(0);L=(X|0)==0;do{if(K){F=7045}else{if((c[J+12>>2]|0)==(c[J+16>>2]|0)){if((gj[c[(c[J>>2]|0)+36>>2]&4095](J)|0)==-1){F=7045;break}}if(!(L^(J|0)==0)){F=7047}}}while(0);if((F|0)==7045){if(L){F=7047}}if((F|0)==7047){c[j>>2]=c[j>>2]|2}c[b>>2]=X;do{if((a[u]&1)!=0){X=c[l>>2]|0;if((X|0)==0){break}gGr(X)}}while(0);if((a[t]&1)==0){i=e;return}t=c[m+8>>2]|0;if((t|0)==0){i=e;return}gGr(t);i=e;return}function gBL(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;e=i;i=i+256|0;l=f;f=i;i=i+4|0;i=i+7&-8;c[f>>2]=c[l>>2];l=g;g=i;i=i+4|0;i=i+7&-8;c[g>>2]=c[l>>2];l=e+32|0;m=e+40|0;n=e+56|0;o=e+72|0;p=e+80|0;q=e+240|0;r=e+248|0;s=c[f>>2]|0;f=c[g>>2]|0;g=e|0;t=m;u=n;v=c[h+4>>2]&74;if((v|0)==0){w=0}else if((v|0)==8){w=16}else if((v|0)==64){w=8}else{w=10}gB9(m,c[h+28>>2]|0,g,l);gGz(u|0,0,12);h=n;gAt(n,10);if((a[u]&1)==0){v=h+1|0;x=v;y=v;z=n+8|0}else{v=n+8|0;x=c[v>>2]|0;y=h+1|0;z=v}c[o>>2]=x;v=p|0;c[q>>2]=v;c[r>>2]=0;A=n|0;B=n+4|0;C=a[l]|0;l=n+8|0;D=x;x=s;s=f;L8109:while(1){do{if((x|0)==0){E=0}else{if((c[x+12>>2]|0)!=(c[x+16>>2]|0)){E=x;break}f=(gj[c[(c[x>>2]|0)+36>>2]&4095](x)|0)==-1;E=f?0:x}}while(0);f=(E|0)==0;do{if((s|0)==0){F=7076}else{if((c[s+12>>2]|0)!=(c[s+16>>2]|0)){if(f){G=0;H=s;break}else{I=D;J=s;L=0;M=E;N=0;break L8109}}if((gj[c[(c[s>>2]|0)+36>>2]&4095](s)|0)==-1){F=7076;break}if(f){G=0;H=s}else{I=D;J=s;L=0;M=E;N=0;break L8109}}}while(0);if((F|0)==7076){F=0;if(f){I=D;J=0;L=1;M=0;N=1;break}else{G=1;H=0}}O=(c[o>>2]|0)-D|0;P=a[u]|0;Q=P&255;if((O|0)==(((Q&1|0)==0?Q>>>1:c[B>>2]|0)|0)){Q=O<<1;do{if(O>>>0<Q>>>0){gAt(n,O)}else{if((P&1)==0){a[h+1+Q|0]=0;a[u]=O<<2&255;break}else{a[(c[l>>2]|0)+Q|0]=0;c[B>>2]=Q;break}}}while(0);Q=a[u]|0;if((Q&1)==0){R=10;S=Q}else{Q=c[A>>2]|0;R=(Q&-2)-1|0;S=Q&255}Q=S&255;P=(Q&1|0)==0?Q>>>1:c[B>>2]|0;do{if(P>>>0<R>>>0){gAt(n,R-P|0)}else{if((S&1)==0){a[h+1+R|0]=0;a[u]=R<<1&255;break}else{a[(c[l>>2]|0)+R|0]=0;c[B>>2]=R;break}}}while(0);if((a[u]&1)==0){T=y}else{T=c[z>>2]|0}c[o>>2]=T+O;U=T}else{U=D}P=E+12|0;Q=c[P>>2]|0;V=E+16|0;if((Q|0)==(c[V>>2]|0)){W=(gj[c[(c[E>>2]|0)+36>>2]&4095](E)|0)&255}else{W=a[Q]|0}if((gBU(W,w,U,o,r,C,m,v,q,g)|0)!=0){I=U;J=H;L=G;M=E;N=f;break}Q=c[P>>2]|0;if((Q|0)==(c[V>>2]|0)){V=c[(c[E>>2]|0)+40>>2]|0;gj[V&4095](E)|0;D=U;x=E;s=H;continue}else{c[P>>2]=Q+1;D=U;x=E;s=H;continue}}H=d[t]|0;if((H&1|0)==0){X=H>>>1}else{X=c[m+4>>2]|0}do{if((X|0)!=0){H=c[q>>2]|0;if((H-p|0)>=160){break}s=c[r>>2]|0;c[q>>2]=H+4;c[H>>2]=s}}while(0);r=gFX(I,c[o>>2]|0,j,w)|0;c[k>>2]=r;c[k+4>>2]=K;gDW(m,v,c[q>>2]|0,j);do{if(N){Y=0}else{if((c[M+12>>2]|0)!=(c[M+16>>2]|0)){Y=M;break}q=(gj[c[(c[M>>2]|0)+36>>2]&4095](M)|0)==-1;Y=q?0:M}}while(0);M=(Y|0)==0;do{if(L){F=7126}else{if((c[J+12>>2]|0)==(c[J+16>>2]|0)){if((gj[c[(c[J>>2]|0)+36>>2]&4095](J)|0)==-1){F=7126;break}}if(!(M^(J|0)==0)){F=7128}}}while(0);if((F|0)==7126){if(M){F=7128}}if((F|0)==7128){c[j>>2]=c[j>>2]|2}c[b>>2]=Y;do{if((a[u]&1)!=0){Y=c[l>>2]|0;if((Y|0)==0){break}gGr(Y)}}while(0);if((a[t]&1)==0){i=e;return}t=c[m+8>>2]|0;if((t|0)==0){i=e;return}gGr(t);i=e;return}function gBM(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;f=i;i=i+256|0;m=g;g=i;i=i+4|0;i=i+7&-8;c[g>>2]=c[m>>2];m=h;h=i;i=i+4|0;i=i+7&-8;c[h>>2]=c[m>>2];m=f+32|0;n=f+40|0;o=f+56|0;p=f+72|0;q=f+80|0;r=f+240|0;s=f+248|0;t=c[g>>2]|0;g=c[h>>2]|0;h=f|0;u=n;v=o;w=c[j+4>>2]&74;if((w|0)==0){x=0}else if((w|0)==64){x=8}else if((w|0)==8){x=16}else{x=10}gB9(n,c[j+28>>2]|0,h,m);gGz(v|0,0,12);j=o;gAt(o,10);if((a[v]&1)==0){w=j+1|0;y=w;z=w;A=o+8|0}else{w=o+8|0;y=c[w>>2]|0;z=j+1|0;A=w}c[p>>2]=y;w=q|0;c[r>>2]=w;c[s>>2]=0;B=o|0;C=o+4|0;D=a[m]|0;m=o+8|0;E=y;y=t;t=g;L8206:while(1){do{if((y|0)==0){F=0}else{if((c[y+12>>2]|0)!=(c[y+16>>2]|0)){F=y;break}g=(gj[c[(c[y>>2]|0)+36>>2]&4095](y)|0)==-1;F=g?0:y}}while(0);g=(F|0)==0;do{if((t|0)==0){G=7157}else{if((c[t+12>>2]|0)!=(c[t+16>>2]|0)){if(g){H=0;I=t;break}else{J=E;K=t;L=0;M=F;N=0;break L8206}}if((gj[c[(c[t>>2]|0)+36>>2]&4095](t)|0)==-1){G=7157;break}if(g){H=0;I=t}else{J=E;K=t;L=0;M=F;N=0;break L8206}}}while(0);if((G|0)==7157){G=0;if(g){J=E;K=0;L=1;M=0;N=1;break}else{H=1;I=0}}O=(c[p>>2]|0)-E|0;P=a[v]|0;Q=P&255;if((O|0)==(((Q&1|0)==0?Q>>>1:c[C>>2]|0)|0)){Q=O<<1;do{if(O>>>0<Q>>>0){gAt(o,O)}else{if((P&1)==0){a[j+1+Q|0]=0;a[v]=O<<2&255;break}else{a[(c[m>>2]|0)+Q|0]=0;c[C>>2]=Q;break}}}while(0);Q=a[v]|0;if((Q&1)==0){R=10;S=Q}else{Q=c[B>>2]|0;R=(Q&-2)-1|0;S=Q&255}Q=S&255;P=(Q&1|0)==0?Q>>>1:c[C>>2]|0;do{if(P>>>0<R>>>0){gAt(o,R-P|0)}else{if((S&1)==0){a[j+1+R|0]=0;a[v]=R<<1&255;break}else{a[(c[m>>2]|0)+R|0]=0;c[C>>2]=R;break}}}while(0);if((a[v]&1)==0){T=z}else{T=c[A>>2]|0}c[p>>2]=T+O;U=T}else{U=E}P=F+12|0;Q=c[P>>2]|0;V=F+16|0;if((Q|0)==(c[V>>2]|0)){W=(gj[c[(c[F>>2]|0)+36>>2]&4095](F)|0)&255}else{W=a[Q]|0}if((gBU(W,x,U,p,s,D,n,w,r,h)|0)!=0){J=U;K=I;L=H;M=F;N=g;break}Q=c[P>>2]|0;if((Q|0)==(c[V>>2]|0)){V=c[(c[F>>2]|0)+40>>2]|0;gj[V&4095](F)|0;E=U;y=F;t=I;continue}else{c[P>>2]=Q+1;E=U;y=F;t=I;continue}}I=d[u]|0;if((I&1|0)==0){X=I>>>1}else{X=c[n+4>>2]|0}do{if((X|0)!=0){I=c[r>>2]|0;if((I-q|0)>=160){break}t=c[s>>2]|0;c[r>>2]=I+4;c[I>>2]=t}}while(0);b[l>>1]=gFW(J,c[p>>2]|0,k,x)|0;gDW(n,w,c[r>>2]|0,k);do{if(N){Y=0}else{if((c[M+12>>2]|0)!=(c[M+16>>2]|0)){Y=M;break}r=(gj[c[(c[M>>2]|0)+36>>2]&4095](M)|0)==-1;Y=r?0:M}}while(0);M=(Y|0)==0;do{if(L){G=7207}else{if((c[K+12>>2]|0)==(c[K+16>>2]|0)){if((gj[c[(c[K>>2]|0)+36>>2]&4095](K)|0)==-1){G=7207;break}}if(!(M^(K|0)==0)){G=7209}}}while(0);if((G|0)==7207){if(M){G=7209}}if((G|0)==7209){c[k>>2]=c[k>>2]|2}c[e>>2]=Y;do{if((a[v]&1)!=0){Y=c[m>>2]|0;if((Y|0)==0){break}gGr(Y)}}while(0);if((a[u]&1)==0){i=f;return}u=c[n+8>>2]|0;if((u|0)==0){i=f;return}gGr(u);i=f;return}function gBN(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0;e=i;i=i+256|0;l=f;f=i;i=i+4|0;i=i+7&-8;c[f>>2]=c[l>>2];l=g;g=i;i=i+4|0;i=i+7&-8;c[g>>2]=c[l>>2];l=e+32|0;m=e+40|0;n=e+56|0;o=e+72|0;p=e+80|0;q=e+240|0;r=e+248|0;s=c[f>>2]|0;f=c[g>>2]|0;g=e|0;t=m;u=n;v=c[h+4>>2]&74;if((v|0)==0){w=0}else if((v|0)==8){w=16}else if((v|0)==64){w=8}else{w=10}gB9(m,c[h+28>>2]|0,g,l);gGz(u|0,0,12);h=n;gAt(n,10);if((a[u]&1)==0){v=h+1|0;x=v;y=v;z=n+8|0}else{v=n+8|0;x=c[v>>2]|0;y=h+1|0;z=v}c[o>>2]=x;v=p|0;c[q>>2]=v;c[r>>2]=0;A=n|0;B=n+4|0;C=a[l]|0;l=n+8|0;D=x;x=s;s=f;L8303:while(1){do{if((x|0)==0){E=0}else{if((c[x+12>>2]|0)!=(c[x+16>>2]|0)){E=x;break}f=(gj[c[(c[x>>2]|0)+36>>2]&4095](x)|0)==-1;E=f?0:x}}while(0);f=(E|0)==0;do{if((s|0)==0){F=7238}else{if((c[s+12>>2]|0)!=(c[s+16>>2]|0)){if(f){G=0;H=s;break}else{I=D;J=s;K=0;L=E;M=0;break L8303}}if((gj[c[(c[s>>2]|0)+36>>2]&4095](s)|0)==-1){F=7238;break}if(f){G=0;H=s}else{I=D;J=s;K=0;L=E;M=0;break L8303}}}while(0);if((F|0)==7238){F=0;if(f){I=D;J=0;K=1;L=0;M=1;break}else{G=1;H=0}}N=(c[o>>2]|0)-D|0;O=a[u]|0;P=O&255;if((N|0)==(((P&1|0)==0?P>>>1:c[B>>2]|0)|0)){P=N<<1;do{if(N>>>0<P>>>0){gAt(n,N)}else{if((O&1)==0){a[h+1+P|0]=0;a[u]=N<<2&255;break}else{a[(c[l>>2]|0)+P|0]=0;c[B>>2]=P;break}}}while(0);P=a[u]|0;if((P&1)==0){Q=10;R=P}else{P=c[A>>2]|0;Q=(P&-2)-1|0;R=P&255}P=R&255;O=(P&1|0)==0?P>>>1:c[B>>2]|0;do{if(O>>>0<Q>>>0){gAt(n,Q-O|0)}else{if((R&1)==0){a[h+1+Q|0]=0;a[u]=Q<<1&255;break}else{a[(c[l>>2]|0)+Q|0]=0;c[B>>2]=Q;break}}}while(0);if((a[u]&1)==0){S=y}else{S=c[z>>2]|0}c[o>>2]=S+N;T=S}else{T=D}O=E+12|0;P=c[O>>2]|0;U=E+16|0;if((P|0)==(c[U>>2]|0)){V=(gj[c[(c[E>>2]|0)+36>>2]&4095](E)|0)&255}else{V=a[P]|0}if((gBU(V,w,T,o,r,C,m,v,q,g)|0)!=0){I=T;J=H;K=G;L=E;M=f;break}P=c[O>>2]|0;if((P|0)==(c[U>>2]|0)){U=c[(c[E>>2]|0)+40>>2]|0;gj[U&4095](E)|0;D=T;x=E;s=H;continue}else{c[O>>2]=P+1;D=T;x=E;s=H;continue}}H=d[t]|0;if((H&1|0)==0){W=H>>>1}else{W=c[m+4>>2]|0}do{if((W|0)!=0){H=c[q>>2]|0;if((H-p|0)>=160){break}s=c[r>>2]|0;c[q>>2]=H+4;c[H>>2]=s}}while(0);c[k>>2]=gFV(I,c[o>>2]|0,j,w)|0;gDW(m,v,c[q>>2]|0,j);do{if(M){X=0}else{if((c[L+12>>2]|0)!=(c[L+16>>2]|0)){X=L;break}q=(gj[c[(c[L>>2]|0)+36>>2]&4095](L)|0)==-1;X=q?0:L}}while(0);L=(X|0)==0;do{if(K){F=7288}else{if((c[J+12>>2]|0)==(c[J+16>>2]|0)){if((gj[c[(c[J>>2]|0)+36>>2]&4095](J)|0)==-1){F=7288;break}}if(!(L^(J|0)==0)){F=7290}}}while(0);if((F|0)==7288){if(L){F=7290}}if((F|0)==7290){c[j>>2]=c[j>>2]|2}c[b>>2]=X;do{if((a[u]&1)!=0){X=c[l>>2]|0;if((X|0)==0){break}gGr(X)}}while(0);if((a[t]&1)==0){i=e;return}t=c[m+8>>2]|0;if((t|0)==0){i=e;return}gGr(t);i=e;return}function gBO(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0;e=i;i=i+256|0;l=f;f=i;i=i+4|0;i=i+7&-8;c[f>>2]=c[l>>2];l=g;g=i;i=i+4|0;i=i+7&-8;c[g>>2]=c[l>>2];l=e+32|0;m=e+40|0;n=e+56|0;o=e+72|0;p=e+80|0;q=e+240|0;r=e+248|0;s=c[f>>2]|0;f=c[g>>2]|0;g=e|0;t=m;u=n;v=c[h+4>>2]&74;if((v|0)==0){w=0}else if((v|0)==64){w=8}else if((v|0)==8){w=16}else{w=10}gB9(m,c[h+28>>2]|0,g,l);gGz(u|0,0,12);h=n;gAt(n,10);if((a[u]&1)==0){v=h+1|0;x=v;y=v;z=n+8|0}else{v=n+8|0;x=c[v>>2]|0;y=h+1|0;z=v}c[o>>2]=x;v=p|0;c[q>>2]=v;c[r>>2]=0;A=n|0;B=n+4|0;C=a[l]|0;l=n+8|0;D=x;x=s;s=f;L8400:while(1){do{if((x|0)==0){E=0}else{if((c[x+12>>2]|0)!=(c[x+16>>2]|0)){E=x;break}f=(gj[c[(c[x>>2]|0)+36>>2]&4095](x)|0)==-1;E=f?0:x}}while(0);f=(E|0)==0;do{if((s|0)==0){F=7319}else{if((c[s+12>>2]|0)!=(c[s+16>>2]|0)){if(f){G=0;H=s;break}else{I=D;J=s;K=0;L=E;M=0;break L8400}}if((gj[c[(c[s>>2]|0)+36>>2]&4095](s)|0)==-1){F=7319;break}if(f){G=0;H=s}else{I=D;J=s;K=0;L=E;M=0;break L8400}}}while(0);if((F|0)==7319){F=0;if(f){I=D;J=0;K=1;L=0;M=1;break}else{G=1;H=0}}N=(c[o>>2]|0)-D|0;O=a[u]|0;P=O&255;if((N|0)==(((P&1|0)==0?P>>>1:c[B>>2]|0)|0)){P=N<<1;do{if(N>>>0<P>>>0){gAt(n,N)}else{if((O&1)==0){a[h+1+P|0]=0;a[u]=N<<2&255;break}else{a[(c[l>>2]|0)+P|0]=0;c[B>>2]=P;break}}}while(0);P=a[u]|0;if((P&1)==0){Q=10;R=P}else{P=c[A>>2]|0;Q=(P&-2)-1|0;R=P&255}P=R&255;O=(P&1|0)==0?P>>>1:c[B>>2]|0;do{if(O>>>0<Q>>>0){gAt(n,Q-O|0)}else{if((R&1)==0){a[h+1+Q|0]=0;a[u]=Q<<1&255;break}else{a[(c[l>>2]|0)+Q|0]=0;c[B>>2]=Q;break}}}while(0);if((a[u]&1)==0){S=y}else{S=c[z>>2]|0}c[o>>2]=S+N;T=S}else{T=D}O=E+12|0;P=c[O>>2]|0;U=E+16|0;if((P|0)==(c[U>>2]|0)){V=(gj[c[(c[E>>2]|0)+36>>2]&4095](E)|0)&255}else{V=a[P]|0}if((gBU(V,w,T,o,r,C,m,v,q,g)|0)!=0){I=T;J=H;K=G;L=E;M=f;break}P=c[O>>2]|0;if((P|0)==(c[U>>2]|0)){U=c[(c[E>>2]|0)+40>>2]|0;gj[U&4095](E)|0;D=T;x=E;s=H;continue}else{c[O>>2]=P+1;D=T;x=E;s=H;continue}}H=d[t]|0;if((H&1|0)==0){W=H>>>1}else{W=c[m+4>>2]|0}do{if((W|0)!=0){H=c[q>>2]|0;if((H-p|0)>=160){break}s=c[r>>2]|0;c[q>>2]=H+4;c[H>>2]=s}}while(0);c[k>>2]=gFU(I,c[o>>2]|0,j,w)|0;gDW(m,v,c[q>>2]|0,j);do{if(M){X=0}else{if((c[L+12>>2]|0)!=(c[L+16>>2]|0)){X=L;break}q=(gj[c[(c[L>>2]|0)+36>>2]&4095](L)|0)==-1;X=q?0:L}}while(0);L=(X|0)==0;do{if(K){F=7369}else{if((c[J+12>>2]|0)==(c[J+16>>2]|0)){if((gj[c[(c[J>>2]|0)+36>>2]&4095](J)|0)==-1){F=7369;break}}if(!(L^(J|0)==0)){F=7371}}}while(0);if((F|0)==7369){if(L){F=7371}}if((F|0)==7371){c[j>>2]=c[j>>2]|2}c[b>>2]=X;do{if((a[u]&1)!=0){X=c[l>>2]|0;if((X|0)==0){break}gGr(X)}}while(0);if((a[t]&1)==0){i=e;return}t=c[m+8>>2]|0;if((t|0)==0){i=e;return}gGr(t);i=e;return}function gBP(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;e=i;i=i+256|0;l=f;f=i;i=i+4|0;i=i+7&-8;c[f>>2]=c[l>>2];l=g;g=i;i=i+4|0;i=i+7&-8;c[g>>2]=c[l>>2];l=e+32|0;m=e+40|0;n=e+56|0;o=e+72|0;p=e+80|0;q=e+240|0;r=e+248|0;s=c[f>>2]|0;f=c[g>>2]|0;g=e|0;t=m;u=n;v=c[h+4>>2]&74;if((v|0)==0){w=0}else if((v|0)==8){w=16}else if((v|0)==64){w=8}else{w=10}gB9(m,c[h+28>>2]|0,g,l);gGz(u|0,0,12);h=n;gAt(n,10);if((a[u]&1)==0){v=h+1|0;x=v;y=v;z=n+8|0}else{v=n+8|0;x=c[v>>2]|0;y=h+1|0;z=v}c[o>>2]=x;v=p|0;c[q>>2]=v;c[r>>2]=0;A=n|0;B=n+4|0;C=a[l]|0;l=n+8|0;D=x;x=s;s=f;L8497:while(1){do{if((x|0)==0){E=0}else{if((c[x+12>>2]|0)!=(c[x+16>>2]|0)){E=x;break}f=(gj[c[(c[x>>2]|0)+36>>2]&4095](x)|0)==-1;E=f?0:x}}while(0);f=(E|0)==0;do{if((s|0)==0){F=7400}else{if((c[s+12>>2]|0)!=(c[s+16>>2]|0)){if(f){G=0;H=s;break}else{I=D;J=s;L=0;M=E;N=0;break L8497}}if((gj[c[(c[s>>2]|0)+36>>2]&4095](s)|0)==-1){F=7400;break}if(f){G=0;H=s}else{I=D;J=s;L=0;M=E;N=0;break L8497}}}while(0);if((F|0)==7400){F=0;if(f){I=D;J=0;L=1;M=0;N=1;break}else{G=1;H=0}}O=(c[o>>2]|0)-D|0;P=a[u]|0;Q=P&255;if((O|0)==(((Q&1|0)==0?Q>>>1:c[B>>2]|0)|0)){Q=O<<1;do{if(O>>>0<Q>>>0){gAt(n,O)}else{if((P&1)==0){a[h+1+Q|0]=0;a[u]=O<<2&255;break}else{a[(c[l>>2]|0)+Q|0]=0;c[B>>2]=Q;break}}}while(0);Q=a[u]|0;if((Q&1)==0){R=10;S=Q}else{Q=c[A>>2]|0;R=(Q&-2)-1|0;S=Q&255}Q=S&255;P=(Q&1|0)==0?Q>>>1:c[B>>2]|0;do{if(P>>>0<R>>>0){gAt(n,R-P|0)}else{if((S&1)==0){a[h+1+R|0]=0;a[u]=R<<1&255;break}else{a[(c[l>>2]|0)+R|0]=0;c[B>>2]=R;break}}}while(0);if((a[u]&1)==0){T=y}else{T=c[z>>2]|0}c[o>>2]=T+O;U=T}else{U=D}P=E+12|0;Q=c[P>>2]|0;V=E+16|0;if((Q|0)==(c[V>>2]|0)){W=(gj[c[(c[E>>2]|0)+36>>2]&4095](E)|0)&255}else{W=a[Q]|0}if((gBU(W,w,U,o,r,C,m,v,q,g)|0)!=0){I=U;J=H;L=G;M=E;N=f;break}Q=c[P>>2]|0;if((Q|0)==(c[V>>2]|0)){V=c[(c[E>>2]|0)+40>>2]|0;gj[V&4095](E)|0;D=U;x=E;s=H;continue}else{c[P>>2]=Q+1;D=U;x=E;s=H;continue}}H=d[t]|0;if((H&1|0)==0){X=H>>>1}else{X=c[m+4>>2]|0}do{if((X|0)!=0){H=c[q>>2]|0;if((H-p|0)>=160){break}s=c[r>>2]|0;c[q>>2]=H+4;c[H>>2]=s}}while(0);r=gFT(I,c[o>>2]|0,j,w)|0;c[k>>2]=r;c[k+4>>2]=K;gDW(m,v,c[q>>2]|0,j);do{if(N){Y=0}else{if((c[M+12>>2]|0)!=(c[M+16>>2]|0)){Y=M;break}q=(gj[c[(c[M>>2]|0)+36>>2]&4095](M)|0)==-1;Y=q?0:M}}while(0);M=(Y|0)==0;do{if(L){F=7450}else{if((c[J+12>>2]|0)==(c[J+16>>2]|0)){if((gj[c[(c[J>>2]|0)+36>>2]&4095](J)|0)==-1){F=7450;break}}if(!(M^(J|0)==0)){F=7452}}}while(0);if((F|0)==7450){if(M){F=7452}}if((F|0)==7452){c[j>>2]=c[j>>2]|2}c[b>>2]=Y;do{if((a[u]&1)!=0){Y=c[l>>2]|0;if((Y|0)==0){break}gGr(Y)}}while(0);if((a[t]&1)==0){i=e;return}t=c[m+8>>2]|0;if((t|0)==0){i=e;return}gGr(t);i=e;return}function gBQ(b,e,f,h,j,k,l){b=b|0;e=e|0;f=f|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;e=i;i=i+280|0;m=f;f=i;i=i+4|0;i=i+7&-8;c[f>>2]=c[m>>2];m=h;h=i;i=i+4|0;i=i+7&-8;c[h>>2]=c[m>>2];m=e+32|0;n=e+40|0;o=e+48|0;p=e+64|0;q=e+80|0;r=e+88|0;s=e+248|0;t=e+256|0;u=e+264|0;v=e+272|0;w=c[f>>2]|0;f=c[h>>2]|0;h=e|0;x=o;y=p;gCa(o,c[j+28>>2]|0,h,m,n);gGz(y|0,0,12);j=p;gAt(p,10);if((a[y]&1)==0){z=j+1|0;A=z;B=z;C=p+8|0}else{z=p+8|0;A=c[z>>2]|0;B=j+1|0;C=z}c[q>>2]=A;z=r|0;c[s>>2]=z;c[t>>2]=0;a[u]=1;a[v]=69;D=p|0;E=p+4|0;F=a[m]|0;m=a[n]|0;n=p+8|0;G=A;A=w;w=f;L8589:while(1){do{if((A|0)==0){H=0}else{if((c[A+12>>2]|0)!=(c[A+16>>2]|0)){H=A;break}f=(gj[c[(c[A>>2]|0)+36>>2]&4095](A)|0)==-1;H=f?0:A}}while(0);f=(H|0)==0;do{if((w|0)==0){I=7477}else{if((c[w+12>>2]|0)!=(c[w+16>>2]|0)){if(f){J=0;K=w;break}else{L=G;M=w;N=0;O=H;P=0;break L8589}}if((gj[c[(c[w>>2]|0)+36>>2]&4095](w)|0)==-1){I=7477;break}if(f){J=0;K=w}else{L=G;M=w;N=0;O=H;P=0;break L8589}}}while(0);if((I|0)==7477){I=0;if(f){L=G;M=0;N=1;O=0;P=1;break}else{J=1;K=0}}Q=(c[q>>2]|0)-G|0;R=a[y]|0;S=R&255;if((Q|0)==(((S&1|0)==0?S>>>1:c[E>>2]|0)|0)){S=Q<<1;do{if(Q>>>0<S>>>0){gAt(p,Q)}else{if((R&1)==0){a[j+1+S|0]=0;a[y]=Q<<2&255;break}else{a[(c[n>>2]|0)+S|0]=0;c[E>>2]=S;break}}}while(0);S=a[y]|0;if((S&1)==0){T=10;U=S}else{S=c[D>>2]|0;T=(S&-2)-1|0;U=S&255}S=U&255;R=(S&1|0)==0?S>>>1:c[E>>2]|0;do{if(R>>>0<T>>>0){gAt(p,T-R|0)}else{if((U&1)==0){a[j+1+T|0]=0;a[y]=T<<1&255;break}else{a[(c[n>>2]|0)+T|0]=0;c[E>>2]=T;break}}}while(0);if((a[y]&1)==0){V=B}else{V=c[C>>2]|0}c[q>>2]=V+Q;W=V}else{W=G}R=H+12|0;S=c[R>>2]|0;X=H+16|0;if((S|0)==(c[X>>2]|0)){Y=(gj[c[(c[H>>2]|0)+36>>2]&4095](H)|0)&255}else{Y=a[S]|0}if((gCb(Y,u,v,W,q,F,m,o,z,s,t,h)|0)!=0){L=W;M=K;N=J;O=H;P=f;break}S=c[R>>2]|0;if((S|0)==(c[X>>2]|0)){X=c[(c[H>>2]|0)+40>>2]|0;gj[X&4095](H)|0;G=W;A=H;w=K;continue}else{c[R>>2]=S+1;G=W;A=H;w=K;continue}}K=d[x]|0;if((K&1|0)==0){Z=K>>>1}else{Z=c[o+4>>2]|0}do{if((Z|0)!=0){if((a[u]&1)==0){break}K=c[s>>2]|0;if((K-r|0)>=160){break}w=c[t>>2]|0;c[s>>2]=K+4;c[K>>2]=w}}while(0);g[l>>2]=+gFS(L,c[q>>2]|0,k);gDW(o,z,c[s>>2]|0,k);do{if(P){_=0}else{if((c[O+12>>2]|0)!=(c[O+16>>2]|0)){_=O;break}s=(gj[c[(c[O>>2]|0)+36>>2]&4095](O)|0)==-1;_=s?0:O}}while(0);O=(_|0)==0;do{if(N){I=7528}else{if((c[M+12>>2]|0)==(c[M+16>>2]|0)){if((gj[c[(c[M>>2]|0)+36>>2]&4095](M)|0)==-1){I=7528;break}}if(!(O^(M|0)==0)){I=7530}}}while(0);if((I|0)==7528){if(O){I=7530}}if((I|0)==7530){c[k>>2]=c[k>>2]|2}c[b>>2]=_;do{if((a[y]&1)!=0){_=c[n>>2]|0;if((_|0)==0){break}gGr(_)}}while(0);if((a[x]&1)==0){i=e;return}x=c[o+8>>2]|0;if((x|0)==0){i=e;return}gGr(x);i=e;return}function gBR(b,e,f,g,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;e=i;i=i+280|0;m=f;f=i;i=i+4|0;i=i+7&-8;c[f>>2]=c[m>>2];m=g;g=i;i=i+4|0;i=i+7&-8;c[g>>2]=c[m>>2];m=e+32|0;n=e+40|0;o=e+48|0;p=e+64|0;q=e+80|0;r=e+88|0;s=e+248|0;t=e+256|0;u=e+264|0;v=e+272|0;w=c[f>>2]|0;f=c[g>>2]|0;g=e|0;x=o;y=p;gCa(o,c[j+28>>2]|0,g,m,n);gGz(y|0,0,12);j=p;gAt(p,10);if((a[y]&1)==0){z=j+1|0;A=z;B=z;C=p+8|0}else{z=p+8|0;A=c[z>>2]|0;B=j+1|0;C=z}c[q>>2]=A;z=r|0;c[s>>2]=z;c[t>>2]=0;a[u]=1;a[v]=69;D=p|0;E=p+4|0;F=a[m]|0;m=a[n]|0;n=p+8|0;G=A;A=w;w=f;L8682:while(1){do{if((A|0)==0){H=0}else{if((c[A+12>>2]|0)!=(c[A+16>>2]|0)){H=A;break}f=(gj[c[(c[A>>2]|0)+36>>2]&4095](A)|0)==-1;H=f?0:A}}while(0);f=(H|0)==0;do{if((w|0)==0){I=7555}else{if((c[w+12>>2]|0)!=(c[w+16>>2]|0)){if(f){J=0;K=w;break}else{L=G;M=w;N=0;O=H;P=0;break L8682}}if((gj[c[(c[w>>2]|0)+36>>2]&4095](w)|0)==-1){I=7555;break}if(f){J=0;K=w}else{L=G;M=w;N=0;O=H;P=0;break L8682}}}while(0);if((I|0)==7555){I=0;if(f){L=G;M=0;N=1;O=0;P=1;break}else{J=1;K=0}}Q=(c[q>>2]|0)-G|0;R=a[y]|0;S=R&255;if((Q|0)==(((S&1|0)==0?S>>>1:c[E>>2]|0)|0)){S=Q<<1;do{if(Q>>>0<S>>>0){gAt(p,Q)}else{if((R&1)==0){a[j+1+S|0]=0;a[y]=Q<<2&255;break}else{a[(c[n>>2]|0)+S|0]=0;c[E>>2]=S;break}}}while(0);S=a[y]|0;if((S&1)==0){T=10;U=S}else{S=c[D>>2]|0;T=(S&-2)-1|0;U=S&255}S=U&255;R=(S&1|0)==0?S>>>1:c[E>>2]|0;do{if(R>>>0<T>>>0){gAt(p,T-R|0)}else{if((U&1)==0){a[j+1+T|0]=0;a[y]=T<<1&255;break}else{a[(c[n>>2]|0)+T|0]=0;c[E>>2]=T;break}}}while(0);if((a[y]&1)==0){V=B}else{V=c[C>>2]|0}c[q>>2]=V+Q;W=V}else{W=G}R=H+12|0;S=c[R>>2]|0;X=H+16|0;if((S|0)==(c[X>>2]|0)){Y=(gj[c[(c[H>>2]|0)+36>>2]&4095](H)|0)&255}else{Y=a[S]|0}if((gCb(Y,u,v,W,q,F,m,o,z,s,t,g)|0)!=0){L=W;M=K;N=J;O=H;P=f;break}S=c[R>>2]|0;if((S|0)==(c[X>>2]|0)){X=c[(c[H>>2]|0)+40>>2]|0;gj[X&4095](H)|0;G=W;A=H;w=K;continue}else{c[R>>2]=S+1;G=W;A=H;w=K;continue}}K=d[x]|0;if((K&1|0)==0){Z=K>>>1}else{Z=c[o+4>>2]|0}do{if((Z|0)!=0){if((a[u]&1)==0){break}K=c[s>>2]|0;if((K-r|0)>=160){break}w=c[t>>2]|0;c[s>>2]=K+4;c[K>>2]=w}}while(0);h[l>>3]=+gFR(L,c[q>>2]|0,k);gDW(o,z,c[s>>2]|0,k);do{if(P){_=0}else{if((c[O+12>>2]|0)!=(c[O+16>>2]|0)){_=O;break}s=(gj[c[(c[O>>2]|0)+36>>2]&4095](O)|0)==-1;_=s?0:O}}while(0);O=(_|0)==0;do{if(N){I=7606}else{if((c[M+12>>2]|0)==(c[M+16>>2]|0)){if((gj[c[(c[M>>2]|0)+36>>2]&4095](M)|0)==-1){I=7606;break}}if(!(O^(M|0)==0)){I=7608}}}while(0);if((I|0)==7606){if(O){I=7608}}if((I|0)==7608){c[k>>2]=c[k>>2]|2}c[b>>2]=_;do{if((a[y]&1)!=0){_=c[n>>2]|0;if((_|0)==0){break}gGr(_)}}while(0);if((a[x]&1)==0){i=e;return}x=c[o+8>>2]|0;if((x|0)==0){i=e;return}gGr(x);i=e;return}function gBS(b,e,f,g,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;e=i;i=i+280|0;m=f;f=i;i=i+4|0;i=i+7&-8;c[f>>2]=c[m>>2];m=g;g=i;i=i+4|0;i=i+7&-8;c[g>>2]=c[m>>2];m=e+32|0;n=e+40|0;o=e+48|0;p=e+64|0;q=e+80|0;r=e+88|0;s=e+248|0;t=e+256|0;u=e+264|0;v=e+272|0;w=c[f>>2]|0;f=c[g>>2]|0;g=e|0;x=o;y=p;gCa(o,c[j+28>>2]|0,g,m,n);gGz(y|0,0,12);j=p;gAt(p,10);if((a[y]&1)==0){z=j+1|0;A=z;B=z;C=p+8|0}else{z=p+8|0;A=c[z>>2]|0;B=j+1|0;C=z}c[q>>2]=A;z=r|0;c[s>>2]=z;c[t>>2]=0;a[u]=1;a[v]=69;D=p|0;E=p+4|0;F=a[m]|0;m=a[n]|0;n=p+8|0;G=A;A=w;w=f;L8775:while(1){do{if((A|0)==0){H=0}else{if((c[A+12>>2]|0)!=(c[A+16>>2]|0)){H=A;break}f=(gj[c[(c[A>>2]|0)+36>>2]&4095](A)|0)==-1;H=f?0:A}}while(0);f=(H|0)==0;do{if((w|0)==0){I=7633}else{if((c[w+12>>2]|0)!=(c[w+16>>2]|0)){if(f){J=0;K=w;break}else{L=G;M=w;N=0;O=H;P=0;break L8775}}if((gj[c[(c[w>>2]|0)+36>>2]&4095](w)|0)==-1){I=7633;break}if(f){J=0;K=w}else{L=G;M=w;N=0;O=H;P=0;break L8775}}}while(0);if((I|0)==7633){I=0;if(f){L=G;M=0;N=1;O=0;P=1;break}else{J=1;K=0}}Q=(c[q>>2]|0)-G|0;R=a[y]|0;S=R&255;if((Q|0)==(((S&1|0)==0?S>>>1:c[E>>2]|0)|0)){S=Q<<1;do{if(Q>>>0<S>>>0){gAt(p,Q)}else{if((R&1)==0){a[j+1+S|0]=0;a[y]=Q<<2&255;break}else{a[(c[n>>2]|0)+S|0]=0;c[E>>2]=S;break}}}while(0);S=a[y]|0;if((S&1)==0){T=10;U=S}else{S=c[D>>2]|0;T=(S&-2)-1|0;U=S&255}S=U&255;R=(S&1|0)==0?S>>>1:c[E>>2]|0;do{if(R>>>0<T>>>0){gAt(p,T-R|0)}else{if((U&1)==0){a[j+1+T|0]=0;a[y]=T<<1&255;break}else{a[(c[n>>2]|0)+T|0]=0;c[E>>2]=T;break}}}while(0);if((a[y]&1)==0){V=B}else{V=c[C>>2]|0}c[q>>2]=V+Q;W=V}else{W=G}R=H+12|0;S=c[R>>2]|0;X=H+16|0;if((S|0)==(c[X>>2]|0)){Y=(gj[c[(c[H>>2]|0)+36>>2]&4095](H)|0)&255}else{Y=a[S]|0}if((gCb(Y,u,v,W,q,F,m,o,z,s,t,g)|0)!=0){L=W;M=K;N=J;O=H;P=f;break}S=c[R>>2]|0;if((S|0)==(c[X>>2]|0)){X=c[(c[H>>2]|0)+40>>2]|0;gj[X&4095](H)|0;G=W;A=H;w=K;continue}else{c[R>>2]=S+1;G=W;A=H;w=K;continue}}K=d[x]|0;if((K&1|0)==0){Z=K>>>1}else{Z=c[o+4>>2]|0}do{if((Z|0)!=0){if((a[u]&1)==0){break}K=c[s>>2]|0;if((K-r|0)>=160){break}w=c[t>>2]|0;c[s>>2]=K+4;c[K>>2]=w}}while(0);h[l>>3]=+gFQ(L,c[q>>2]|0,k);gDW(o,z,c[s>>2]|0,k);do{if(P){_=0}else{if((c[O+12>>2]|0)!=(c[O+16>>2]|0)){_=O;break}s=(gj[c[(c[O>>2]|0)+36>>2]&4095](O)|0)==-1;_=s?0:O}}while(0);O=(_|0)==0;do{if(N){I=7684}else{if((c[M+12>>2]|0)==(c[M+16>>2]|0)){if((gj[c[(c[M>>2]|0)+36>>2]&4095](M)|0)==-1){I=7684;break}}if(!(O^(M|0)==0)){I=7686}}}while(0);if((I|0)==7684){if(O){I=7686}}if((I|0)==7686){c[k>>2]=c[k>>2]|2}c[b>>2]=_;do{if((a[y]&1)!=0){_=c[n>>2]|0;if((_|0)==0){break}gGr(_)}}while(0);if((a[x]&1)==0){i=e;return}x=c[o+8>>2]|0;if((x|0)==0){i=e;return}gGr(x);i=e;return}function gBT(b,d,e,f,g,h,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;d=i;i=i+64|0;k=e;e=i;i=i+4|0;i=i+7&-8;c[e>>2]=c[k>>2];k=f;f=i;i=i+4|0;i=i+7&-8;c[f>>2]=c[k>>2];k=d|0;l=d+16|0;m=d+48|0;n=m;o=i;i=i+12|0;i=i+7&-8;p=i;i=i+4|0;i=i+7&-8;q=i;i=i+160|0;r=i;i=i+4|0;i=i+7&-8;s=i;i=i+4|0;i=i+7&-8;gGz(n|0,0,12);t=o;u=c[g+28>>2]|0;g=u+4|0;I=c[g>>2]|0,c[g>>2]=I+1,I;if((c[2385060]|0)!=-1){c[k>>2]=9540240;c[k+4>>2]=180;c[k+8>>2]=0;gAp(9540240,k)}k=(c[2385061]|0)-1|0;v=c[u+8>>2]|0;do{if((c[u+12>>2]|0)-v>>2>>>0>k>>>0){w=c[v+(k<<2)>>2]|0;if((w|0)==0){break}x=w;y=l|0;z=c[(c[w>>2]|0)+32>>2]|0;gJ[z&31](x,627080,627106,y)|0;if(((I=c[g>>2]|0,c[g>>2]=I+ -1,I)|0)==0){gf[c[(c[u>>2]|0)+8>>2]&2047](u)}gGz(t|0,0,12);x=o;gAt(o,10);if((a[t]&1)==0){z=x+1|0;A=z;B=z;C=o+8|0}else{z=o+8|0;A=c[z>>2]|0;B=x+1|0;C=z}c[p>>2]=A;z=q|0;c[r>>2]=z;c[s>>2]=0;w=e|0;D=f|0;E=o|0;F=o+4|0;G=o+8|0;H=A;J=c[w>>2]|0;L8878:while(1){do{if((J|0)==0){K=0}else{if((c[J+12>>2]|0)!=(c[J+16>>2]|0)){K=J;break}if((gj[c[(c[J>>2]|0)+36>>2]&4095](J)|0)!=-1){K=J;break}c[w>>2]=0;K=0}}while(0);L=(K|0)==0;M=c[D>>2]|0;do{if((M|0)==0){N=7722}else{if((c[M+12>>2]|0)!=(c[M+16>>2]|0)){if(L){break}else{O=H;break L8878}}if((gj[c[(c[M>>2]|0)+36>>2]&4095](M)|0)==-1){c[D>>2]=0;N=7722;break}else{if(L){break}else{O=H;break L8878}}}}while(0);if((N|0)==7722){N=0;if(L){O=H;break}}M=(c[p>>2]|0)-H|0;P=a[t]|0;Q=P&255;if((M|0)==(((Q&1|0)==0?Q>>>1:c[F>>2]|0)|0)){Q=M<<1;do{if(M>>>0<Q>>>0){gAt(o,M)}else{if((P&1)==0){a[x+1+Q|0]=0;a[t]=M<<2&255;break}else{a[(c[G>>2]|0)+Q|0]=0;c[F>>2]=Q;break}}}while(0);Q=a[t]|0;if((Q&1)==0){R=10;S=Q}else{Q=c[E>>2]|0;R=(Q&-2)-1|0;S=Q&255}Q=S&255;P=(Q&1|0)==0?Q>>>1:c[F>>2]|0;do{if(P>>>0<R>>>0){gAt(o,R-P|0)}else{if((S&1)==0){a[x+1+R|0]=0;a[t]=R<<1&255;break}else{a[(c[G>>2]|0)+R|0]=0;c[F>>2]=R;break}}}while(0);if((a[t]&1)==0){T=B}else{T=c[C>>2]|0}c[p>>2]=T+M;U=T}else{U=H}P=K+12|0;Q=c[P>>2]|0;L=K+16|0;if((Q|0)==(c[L>>2]|0)){V=(gj[c[(c[K>>2]|0)+36>>2]&4095](K)|0)&255}else{V=a[Q]|0}if((gBU(V,16,U,p,s,0,m,z,r,y)|0)!=0){O=U;break}Q=c[P>>2]|0;if((Q|0)==(c[L>>2]|0)){L=c[(c[K>>2]|0)+40>>2]|0;gj[L&4095](K)|0;H=U;J=K;continue}else{c[P>>2]=Q+1;H=U;J=K;continue}}a[O+3|0]=0;do{if((a[14125e3]|0)==0){if((bp(14125e3)|0)==0){break}c[2384150]=e6(2147483647,485280,0)|0}}while(0);J=gBV(O,c[2384150]|0,(H=i,i=i+8|0,c[H>>2]=j,H)|0)|0;i=H;if((J|0)!=1){c[h>>2]=4}J=c[w>>2]|0;do{if((J|0)==0){W=0}else{if((c[J+12>>2]|0)!=(c[J+16>>2]|0)){W=J;break}if((gj[c[(c[J>>2]|0)+36>>2]&4095](J)|0)!=-1){W=J;break}c[w>>2]=0;W=0}}while(0);w=(W|0)==0;J=c[D>>2]|0;do{if((J|0)==0){N=7774}else{if((c[J+12>>2]|0)!=(c[J+16>>2]|0)){if(w){break}else{N=7776;break}}if((gj[c[(c[J>>2]|0)+36>>2]&4095](J)|0)==-1){c[D>>2]=0;N=7774;break}else{if(w){break}else{N=7776;break}}}}while(0);if((N|0)==7774){if(w){N=7776}}if((N|0)==7776){c[h>>2]=c[h>>2]|2}c[b>>2]=W;do{if((a[t]&1)!=0){D=c[G>>2]|0;if((D|0)==0){break}gGr(D)}}while(0);if((a[n]&1)==0){i=d;return}G=c[m+8>>2]|0;if((G|0)==0){i=d;return}gGr(G);i=d;return}}while(0);d=f_(4)|0;c[d>>2]=619800;eh(d|0,625536,1e3)}function gBU(b,e,f,g,h,i,j,k,l,m){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0;n=c[g>>2]|0;o=(n|0)==(f|0);do{if(o){p=(a[m+24|0]|0)==b<<24>>24;if(!p){if((a[m+25|0]|0)!=b<<24>>24){break}}c[g>>2]=f+1;a[f]=p?43:45;c[h>>2]=0;q=0;return q|0}}while(0);p=d[j]|0;if((p&1|0)==0){r=p>>>1}else{r=c[j+4>>2]|0}if((r|0)!=0&b<<24>>24==i<<24>>24){i=c[l>>2]|0;if((i-k|0)>=160){q=0;return q|0}k=c[h>>2]|0;c[l>>2]=i+4;c[i>>2]=k;c[h>>2]=0;q=0;return q|0}k=m+26|0;i=m;while(1){if((i|0)==(k|0)){s=k;break}if((a[i]|0)==b<<24>>24){s=i;break}else{i=i+1|0}}i=s-m|0;if((i|0)>23){q=-1;return q|0}do{if((e|0)==8|(e|0)==10){if((i|0)<(e|0)){break}else{q=-1}return q|0}else if((e|0)==16){if((i|0)<22){break}if(o){q=-1;return q|0}if((n-f|0)>=3){q=-1;return q|0}if((a[n-1|0]|0)!=48){q=-1;return q|0}c[h>>2]=0;m=a[627080+i|0]|0;s=c[g>>2]|0;c[g>>2]=s+1;a[s]=m;q=0;return q|0}}while(0);f=a[627080+i|0]|0;c[g>>2]=n+1;a[n]=f;c[h>>2]=(c[h>>2]|0)+1;q=0;return q|0}function gBV(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=i;i=i+16|0;f=e|0;g=f;c[g>>2]=d;c[g+4>>2]=0;g=fN(b|0)|0;b=cv(a|0,368e3,f|0)|0;if((g|0)==0){i=e;return b|0}fN(g|0)|0;i=e;return b|0}function gBW(a){a=a|0;if((a|0)==0){return}gGr(a);return}function gBX(a){a=a|0;return}function gBY(b,d,e,f,g,h,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;k=i;i=i+88|0;l=e;e=i;i=i+4|0;i=i+7&-8;c[e>>2]=c[l>>2];l=f;f=i;i=i+4|0;i=i+7&-8;c[f>>2]=c[l>>2];l=k|0;m=k+16|0;n=k+32|0;o=k+40|0;p=k+48|0;q=k+56|0;r=k+64|0;if((c[g+4>>2]&1|0)==0){c[n>>2]=-1;s=c[(c[d>>2]|0)+16>>2]|0;t=e|0;c[p>>2]=c[t>>2];c[q>>2]=c[f>>2];gw[s&127](o,d,p,q,g,h,n);q=c[o>>2]|0;c[t>>2]=q;t=c[n>>2]|0;if((t|0)==0){a[j]=0}else if((t|0)==1){a[j]=1}else{a[j]=1;c[h>>2]=4}c[b>>2]=q;i=k;return}q=g+28|0;g=c[q>>2]|0;t=g+4|0;I=c[t>>2]|0,c[t>>2]=I+1,I;if((c[2385058]|0)!=-1){c[m>>2]=9540232;c[m+4>>2]=180;c[m+8>>2]=0;gAp(9540232,m)}m=(c[2385059]|0)-1|0;n=c[g+8>>2]|0;do{if((c[g+12>>2]|0)-n>>2>>>0>m>>>0){o=c[n+(m<<2)>>2]|0;if((o|0)==0){break}p=o;if(((I=c[t>>2]|0,c[t>>2]=I+ -1,I)|0)==0){gf[c[(c[g>>2]|0)+8>>2]&2047](g)}o=c[q>>2]|0;d=o+4|0;I=c[d>>2]|0,c[d>>2]=I+1,I;if((c[2384962]|0)!=-1){c[l>>2]=9539848;c[l+4>>2]=180;c[l+8>>2]=0;gAp(9539848,l)}s=(c[2384963]|0)-1|0;u=c[o+8>>2]|0;do{if((c[o+12>>2]|0)-u>>2>>>0>s>>>0){v=c[u+(s<<2)>>2]|0;if((v|0)==0){break}w=v;if(((I=c[d>>2]|0,c[d>>2]=I+ -1,I)|0)==0){gf[c[(c[o>>2]|0)+8>>2]&2047](o)}x=r|0;y=v;gg[c[(c[y>>2]|0)+24>>2]&4095](x,w);v=r+12|0;gg[c[(c[y>>2]|0)+28>>2]&4095](v,w);a[j]=(gBZ(e,c[f>>2]|0,x,r+24|0,p,h,1)|0)==(x|0)|0;c[b>>2]=c[e>>2];do{if((a[v]&1)!=0){x=c[r+20>>2]|0;if((x|0)==0){break}gGr(x)}}while(0);if((a[r]&1)==0){i=k;return}v=c[r+8>>2]|0;if((v|0)==0){i=k;return}gGr(v);i=k;return}}while(0);p=f_(4)|0;c[p>>2]=619800;eh(p|0,625536,1e3)}}while(0);k=f_(4)|0;c[k>>2]=619800;eh(k|0,625536,1e3)}function gBZ(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0;l=i;i=i+104|0;m=(g-f|0)/12|0;n=l|0;do{if(m>>>0>100){o=gGq(m)|0;if((o|0)!=0){p=o;q=o;break}o=f_(4)|0;c[o>>2]=619768;eh(o|0,625520,1206);return 0}else{p=n;q=0}}while(0);n=(f|0)==(g|0);if(n){r=m;s=0}else{o=m;m=0;t=p;u=f;while(1){v=d[u]|0;if((v&1|0)==0){w=v>>>1}else{w=c[u+4>>2]|0}if((w|0)==0){a[t]=2;x=m+1|0;y=o-1|0}else{a[t]=1;x=m;y=o}v=u+12|0;if((v|0)==(g|0)){r=y;s=x;break}else{o=y;m=x;t=t+1|0;u=v}}}u=b|0;b=h;t=0;x=s;s=r;r=e;L9091:while(1){e=(s|0)!=0;m=t;y=r;while(1){o=c[u>>2]|0;do{if((o|0)==0){z=0}else{w=c[o+12>>2]|0;if((w|0)==(c[o+16>>2]|0)){A=gj[c[(c[o>>2]|0)+36>>2]&4095](o)|0}else{A=c[w>>2]|0}if((A|0)==-1){c[u>>2]=0;z=0;break}else{z=c[u>>2]|0;break}}}while(0);o=(z|0)==0;if((y|0)==0){B=z;C=0}else{w=c[y+12>>2]|0;if((w|0)==(c[y+16>>2]|0)){D=gj[c[(c[y>>2]|0)+36>>2]&4095](y)|0}else{D=c[w>>2]|0}B=c[u>>2]|0;C=(D|0)==-1?0:y}E=(C|0)==0;if(!((o^E)&e)){break L9091}o=c[B+12>>2]|0;if((o|0)==(c[B+16>>2]|0)){F=gj[c[(c[B>>2]|0)+36>>2]&4095](B)|0}else{F=c[o>>2]|0}if(k){G=F}else{G=gA[c[(c[b>>2]|0)+28>>2]&16383](h,F)|0}H=m+1|0;if(n){m=H;y=C}else{break}}L9121:do{if(k){y=s;e=x;o=p;w=0;v=f;while(1){do{if((a[o]|0)==1){I=a[v]|0;if((I&1)==0){J=v+4|0}else{J=c[v+8>>2]|0}if((G|0)!=(c[J+(m<<2)>>2]|0)){a[o]=0;K=w;L=e;M=y-1|0;break}N=I&255;if((N&1|0)==0){O=N>>>1}else{O=c[v+4>>2]|0}if((O|0)!=(H|0)){K=1;L=e;M=y;break}a[o]=2;K=1;L=e+1|0;M=y-1|0}else{K=w;L=e;M=y}}while(0);N=v+12|0;if((N|0)==(g|0)){P=M;Q=L;R=K;break L9121}y=M;e=L;o=o+1|0;w=K;v=N}}else{v=s;w=x;o=p;e=0;y=f;while(1){do{if((a[o]|0)==1){N=y;if((a[N]&1)==0){S=y+4|0}else{S=c[y+8>>2]|0}if((G|0)!=(gA[c[(c[b>>2]|0)+28>>2]&16383](h,c[S+(m<<2)>>2]|0)|0)){a[o]=0;T=e;U=w;V=v-1|0;break}I=d[N]|0;if((I&1|0)==0){W=I>>>1}else{W=c[y+4>>2]|0}if((W|0)!=(H|0)){T=1;U=w;V=v;break}a[o]=2;T=1;U=w+1|0;V=v-1|0}else{T=e;U=w;V=v}}while(0);I=y+12|0;if((I|0)==(g|0)){P=V;Q=U;R=T;break L9121}v=V;w=U;o=o+1|0;e=T;y=I}}}while(0);if(!R){t=H;x=Q;s=P;r=C;continue}m=c[u>>2]|0;y=m+12|0;e=c[y>>2]|0;if((e|0)==(c[m+16>>2]|0)){o=c[(c[m>>2]|0)+40>>2]|0;gj[o&4095](m)|0}else{c[y>>2]=e+4}if((P+Q|0)>>>0<2){t=H;x=Q;s=P;r=C;continue}else{X=Q;Y=p;Z=f}while(1){do{if((a[Y]|0)==2){e=d[Z]|0;if((e&1|0)==0){_=e>>>1}else{_=c[Z+4>>2]|0}if((_|0)==(H|0)){$=X;break}a[Y]=0;$=X-1|0}else{$=X}}while(0);e=Z+12|0;if((e|0)==(g|0)){t=H;x=$;s=P;r=C;continue L9091}else{X=$;Y=Y+1|0;Z=e}}}do{if((B|0)==0){aa=1}else{Z=c[B+12>>2]|0;if((Z|0)==(c[B+16>>2]|0)){ab=gj[c[(c[B>>2]|0)+36>>2]&4095](B)|0}else{ab=c[Z>>2]|0}if((ab|0)==-1){c[u>>2]=0;aa=1;break}else{aa=(c[u>>2]|0)==0;break}}}while(0);do{if(E){ac=7981}else{u=c[C+12>>2]|0;if((u|0)==(c[C+16>>2]|0)){ad=gj[c[(c[C>>2]|0)+36>>2]&4095](C)|0}else{ad=c[u>>2]|0}if((ad|0)==-1){ac=7981;break}if(!aa){ac=7983}}}while(0);if((ac|0)==7981){if(aa){ac=7983}}if((ac|0)==7983){c[j>>2]=c[j>>2]|2}L9198:do{if(n){ac=7988}else{aa=f;ad=p;while(1){if((a[ad]|0)==2){ae=aa;break L9198}C=aa+12|0;if((C|0)==(g|0)){ac=7988;break L9198}aa=C;ad=ad+1|0}}}while(0);if((ac|0)==7988){c[j>>2]=c[j>>2]|4;ae=g}if((q|0)==0){i=l;return ae|0}gGr(q);i=l;return ae|0}function gB_(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0;e=i;i=i+328|0;l=f;f=i;i=i+4|0;i=i+7&-8;c[f>>2]=c[l>>2];l=g;g=i;i=i+4|0;i=i+7&-8;c[g>>2]=c[l>>2];l=e|0;m=e+104|0;n=e+112|0;o=e+128|0;p=e+144|0;q=e+152|0;r=e+312|0;s=e+320|0;t=c[f>>2]|0;f=c[g>>2]|0;g=n;u=o;v=c[h+4>>2]&74;if((v|0)==0){w=0}else if((v|0)==8){w=16}else if((v|0)==64){w=8}else{w=10}v=l|0;gCc(n,c[h+28>>2]|0,v,m);gGz(u|0,0,12);h=o;gAt(o,10);if((a[u]&1)==0){l=h+1|0;x=l;y=l;z=o+8|0}else{l=o+8|0;x=c[l>>2]|0;y=h+1|0;z=l}c[p>>2]=x;l=q|0;c[r>>2]=l;c[s>>2]=0;A=o|0;B=o+4|0;C=c[m>>2]|0;m=o+8|0;D=x;x=t;t=f;L9221:while(1){if((x|0)==0){E=0}else{f=c[x+12>>2]|0;if((f|0)==(c[x+16>>2]|0)){F=gj[c[(c[x>>2]|0)+36>>2]&4095](x)|0}else{F=c[f>>2]|0}E=(F|0)==-1?0:x}f=(E|0)==0;do{if((t|0)==0){G=8014}else{H=c[t+12>>2]|0;if((H|0)==(c[t+16>>2]|0)){I=gj[c[(c[t>>2]|0)+36>>2]&4095](t)|0}else{I=c[H>>2]|0}if((I|0)==-1){G=8014;break}if(f){J=0;K=t}else{L=D;M=t;N=0;O=E;P=0;break L9221}}}while(0);if((G|0)==8014){G=0;if(f){L=D;M=0;N=1;O=0;P=1;break}else{J=1;K=0}}H=(c[p>>2]|0)-D|0;Q=a[u]|0;R=Q&255;if((H|0)==(((R&1|0)==0?R>>>1:c[B>>2]|0)|0)){R=H<<1;do{if(H>>>0<R>>>0){gAt(o,H)}else{if((Q&1)==0){a[h+1+R|0]=0;a[u]=H<<2&255;break}else{a[(c[m>>2]|0)+R|0]=0;c[B>>2]=R;break}}}while(0);R=a[u]|0;if((R&1)==0){S=10;T=R}else{R=c[A>>2]|0;S=(R&-2)-1|0;T=R&255}R=T&255;Q=(R&1|0)==0?R>>>1:c[B>>2]|0;do{if(Q>>>0<S>>>0){gAt(o,S-Q|0)}else{if((T&1)==0){a[h+1+S|0]=0;a[u]=S<<1&255;break}else{a[(c[m>>2]|0)+S|0]=0;c[B>>2]=S;break}}}while(0);if((a[u]&1)==0){U=y}else{U=c[z>>2]|0}c[p>>2]=U+H;V=U}else{V=D}Q=E+12|0;R=c[Q>>2]|0;W=E+16|0;if((R|0)==(c[W>>2]|0)){X=gj[c[(c[E>>2]|0)+36>>2]&4095](E)|0}else{X=c[R>>2]|0}if((gB8(X,w,V,p,s,C,n,l,r,v)|0)!=0){L=V;M=K;N=J;O=E;P=f;break}R=c[Q>>2]|0;if((R|0)==(c[W>>2]|0)){W=c[(c[E>>2]|0)+40>>2]|0;gj[W&4095](E)|0;D=V;x=E;t=K;continue}else{c[Q>>2]=R+4;D=V;x=E;t=K;continue}}K=d[g]|0;if((K&1|0)==0){Y=K>>>1}else{Y=c[n+4>>2]|0}do{if((Y|0)!=0){K=c[r>>2]|0;if((K-q|0)>=160){break}t=c[s>>2]|0;c[r>>2]=K+4;c[K>>2]=t}}while(0);c[k>>2]=gFY(L,c[p>>2]|0,j,w)|0;gDW(n,l,c[r>>2]|0,j);if(P){Z=0}else{P=c[O+12>>2]|0;if((P|0)==(c[O+16>>2]|0)){_=gj[c[(c[O>>2]|0)+36>>2]&4095](O)|0}else{_=c[P>>2]|0}Z=(_|0)==-1?0:O}O=(Z|0)==0;do{if(N){G=8065}else{_=c[M+12>>2]|0;if((_|0)==(c[M+16>>2]|0)){$=gj[c[(c[M>>2]|0)+36>>2]&4095](M)|0}else{$=c[_>>2]|0}if(($|0)==-1){G=8065;break}if(!(O^(M|0)==0)){G=8067}}}while(0);if((G|0)==8065){if(O){G=8067}}if((G|0)==8067){c[j>>2]=c[j>>2]|2}c[b>>2]=Z;do{if((a[u]&1)!=0){Z=c[m>>2]|0;if((Z|0)==0){break}gGr(Z)}}while(0);if((a[g]&1)==0){i=e;return}g=c[n+8>>2]|0;if((g|0)==0){i=e;return}gGr(g);i=e;return}function gB$(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0;e=i;i=i+328|0;l=f;f=i;i=i+4|0;i=i+7&-8;c[f>>2]=c[l>>2];l=g;g=i;i=i+4|0;i=i+7&-8;c[g>>2]=c[l>>2];l=e|0;m=e+104|0;n=e+112|0;o=e+128|0;p=e+144|0;q=e+152|0;r=e+312|0;s=e+320|0;t=c[f>>2]|0;f=c[g>>2]|0;g=n;u=o;v=c[h+4>>2]&74;if((v|0)==8){w=16}else if((v|0)==0){w=0}else if((v|0)==64){w=8}else{w=10}v=l|0;gCc(n,c[h+28>>2]|0,v,m);gGz(u|0,0,12);h=o;gAt(o,10);if((a[u]&1)==0){l=h+1|0;x=l;y=l;z=o+8|0}else{l=o+8|0;x=c[l>>2]|0;y=h+1|0;z=l}c[p>>2]=x;l=q|0;c[r>>2]=l;c[s>>2]=0;A=o|0;B=o+4|0;C=c[m>>2]|0;m=o+8|0;D=x;x=t;t=f;L9322:while(1){if((x|0)==0){E=0}else{f=c[x+12>>2]|0;if((f|0)==(c[x+16>>2]|0)){F=gj[c[(c[x>>2]|0)+36>>2]&4095](x)|0}else{F=c[f>>2]|0}E=(F|0)==-1?0:x}f=(E|0)==0;do{if((t|0)==0){G=8097}else{H=c[t+12>>2]|0;if((H|0)==(c[t+16>>2]|0)){I=gj[c[(c[t>>2]|0)+36>>2]&4095](t)|0}else{I=c[H>>2]|0}if((I|0)==-1){G=8097;break}if(f){J=0;L=t}else{M=D;N=t;O=0;P=E;Q=0;break L9322}}}while(0);if((G|0)==8097){G=0;if(f){M=D;N=0;O=1;P=0;Q=1;break}else{J=1;L=0}}H=(c[p>>2]|0)-D|0;R=a[u]|0;S=R&255;if((H|0)==(((S&1|0)==0?S>>>1:c[B>>2]|0)|0)){S=H<<1;do{if(H>>>0<S>>>0){gAt(o,H)}else{if((R&1)==0){a[h+1+S|0]=0;a[u]=H<<2&255;break}else{a[(c[m>>2]|0)+S|0]=0;c[B>>2]=S;break}}}while(0);S=a[u]|0;if((S&1)==0){T=10;U=S}else{S=c[A>>2]|0;T=(S&-2)-1|0;U=S&255}S=U&255;R=(S&1|0)==0?S>>>1:c[B>>2]|0;do{if(R>>>0<T>>>0){gAt(o,T-R|0)}else{if((U&1)==0){a[h+1+T|0]=0;a[u]=T<<1&255;break}else{a[(c[m>>2]|0)+T|0]=0;c[B>>2]=T;break}}}while(0);if((a[u]&1)==0){V=y}else{V=c[z>>2]|0}c[p>>2]=V+H;W=V}else{W=D}R=E+12|0;S=c[R>>2]|0;X=E+16|0;if((S|0)==(c[X>>2]|0)){Y=gj[c[(c[E>>2]|0)+36>>2]&4095](E)|0}else{Y=c[S>>2]|0}if((gB8(Y,w,W,p,s,C,n,l,r,v)|0)!=0){M=W;N=L;O=J;P=E;Q=f;break}S=c[R>>2]|0;if((S|0)==(c[X>>2]|0)){X=c[(c[E>>2]|0)+40>>2]|0;gj[X&4095](E)|0;D=W;x=E;t=L;continue}else{c[R>>2]=S+4;D=W;x=E;t=L;continue}}L=d[g]|0;if((L&1|0)==0){Z=L>>>1}else{Z=c[n+4>>2]|0}do{if((Z|0)!=0){L=c[r>>2]|0;if((L-q|0)>=160){break}t=c[s>>2]|0;c[r>>2]=L+4;c[L>>2]=t}}while(0);s=gFX(M,c[p>>2]|0,j,w)|0;c[k>>2]=s;c[k+4>>2]=K;gDW(n,l,c[r>>2]|0,j);if(Q){_=0}else{Q=c[P+12>>2]|0;if((Q|0)==(c[P+16>>2]|0)){$=gj[c[(c[P>>2]|0)+36>>2]&4095](P)|0}else{$=c[Q>>2]|0}_=($|0)==-1?0:P}P=(_|0)==0;do{if(O){G=8148}else{$=c[N+12>>2]|0;if(($|0)==(c[N+16>>2]|0)){aa=gj[c[(c[N>>2]|0)+36>>2]&4095](N)|0}else{aa=c[$>>2]|0}if((aa|0)==-1){G=8148;break}if(!(P^(N|0)==0)){G=8150}}}while(0);if((G|0)==8148){if(P){G=8150}}if((G|0)==8150){c[j>>2]=c[j>>2]|2}c[b>>2]=_;do{if((a[u]&1)!=0){_=c[m>>2]|0;if((_|0)==0){break}gGr(_)}}while(0);if((a[g]&1)==0){i=e;return}g=c[n+8>>2]|0;if((g|0)==0){i=e;return}gGr(g);i=e;return}function gB0(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0;f=i;i=i+328|0;m=g;g=i;i=i+4|0;i=i+7&-8;c[g>>2]=c[m>>2];m=h;h=i;i=i+4|0;i=i+7&-8;c[h>>2]=c[m>>2];m=f|0;n=f+104|0;o=f+112|0;p=f+128|0;q=f+144|0;r=f+152|0;s=f+312|0;t=f+320|0;u=c[g>>2]|0;g=c[h>>2]|0;h=o;v=p;w=c[j+4>>2]&74;if((w|0)==0){x=0}else if((w|0)==8){x=16}else if((w|0)==64){x=8}else{x=10}w=m|0;gCc(o,c[j+28>>2]|0,w,n);gGz(v|0,0,12);j=p;gAt(p,10);if((a[v]&1)==0){m=j+1|0;y=m;z=m;A=p+8|0}else{m=p+8|0;y=c[m>>2]|0;z=j+1|0;A=m}c[q>>2]=y;m=r|0;c[s>>2]=m;c[t>>2]=0;B=p|0;C=p+4|0;D=c[n>>2]|0;n=p+8|0;E=y;y=u;u=g;L9423:while(1){if((y|0)==0){F=0}else{g=c[y+12>>2]|0;if((g|0)==(c[y+16>>2]|0)){G=gj[c[(c[y>>2]|0)+36>>2]&4095](y)|0}else{G=c[g>>2]|0}F=(G|0)==-1?0:y}g=(F|0)==0;do{if((u|0)==0){H=8180}else{I=c[u+12>>2]|0;if((I|0)==(c[u+16>>2]|0)){J=gj[c[(c[u>>2]|0)+36>>2]&4095](u)|0}else{J=c[I>>2]|0}if((J|0)==-1){H=8180;break}if(g){K=0;L=u}else{M=E;N=u;O=0;P=F;Q=0;break L9423}}}while(0);if((H|0)==8180){H=0;if(g){M=E;N=0;O=1;P=0;Q=1;break}else{K=1;L=0}}I=(c[q>>2]|0)-E|0;R=a[v]|0;S=R&255;if((I|0)==(((S&1|0)==0?S>>>1:c[C>>2]|0)|0)){S=I<<1;do{if(I>>>0<S>>>0){gAt(p,I)}else{if((R&1)==0){a[j+1+S|0]=0;a[v]=I<<2&255;break}else{a[(c[n>>2]|0)+S|0]=0;c[C>>2]=S;break}}}while(0);S=a[v]|0;if((S&1)==0){T=10;U=S}else{S=c[B>>2]|0;T=(S&-2)-1|0;U=S&255}S=U&255;R=(S&1|0)==0?S>>>1:c[C>>2]|0;do{if(R>>>0<T>>>0){gAt(p,T-R|0)}else{if((U&1)==0){a[j+1+T|0]=0;a[v]=T<<1&255;break}else{a[(c[n>>2]|0)+T|0]=0;c[C>>2]=T;break}}}while(0);if((a[v]&1)==0){V=z}else{V=c[A>>2]|0}c[q>>2]=V+I;W=V}else{W=E}R=F+12|0;S=c[R>>2]|0;X=F+16|0;if((S|0)==(c[X>>2]|0)){Y=gj[c[(c[F>>2]|0)+36>>2]&4095](F)|0}else{Y=c[S>>2]|0}if((gB8(Y,x,W,q,t,D,o,m,s,w)|0)!=0){M=W;N=L;O=K;P=F;Q=g;break}S=c[R>>2]|0;if((S|0)==(c[X>>2]|0)){X=c[(c[F>>2]|0)+40>>2]|0;gj[X&4095](F)|0;E=W;y=F;u=L;continue}else{c[R>>2]=S+4;E=W;y=F;u=L;continue}}L=d[h]|0;if((L&1|0)==0){Z=L>>>1}else{Z=c[o+4>>2]|0}do{if((Z|0)!=0){L=c[s>>2]|0;if((L-r|0)>=160){break}u=c[t>>2]|0;c[s>>2]=L+4;c[L>>2]=u}}while(0);b[l>>1]=gFW(M,c[q>>2]|0,k,x)|0;gDW(o,m,c[s>>2]|0,k);if(Q){_=0}else{Q=c[P+12>>2]|0;if((Q|0)==(c[P+16>>2]|0)){$=gj[c[(c[P>>2]|0)+36>>2]&4095](P)|0}else{$=c[Q>>2]|0}_=($|0)==-1?0:P}P=(_|0)==0;do{if(O){H=8231}else{$=c[N+12>>2]|0;if(($|0)==(c[N+16>>2]|0)){aa=gj[c[(c[N>>2]|0)+36>>2]&4095](N)|0}else{aa=c[$>>2]|0}if((aa|0)==-1){H=8231;break}if(!(P^(N|0)==0)){H=8233}}}while(0);if((H|0)==8231){if(P){H=8233}}if((H|0)==8233){c[k>>2]=c[k>>2]|2}c[e>>2]=_;do{if((a[v]&1)!=0){_=c[n>>2]|0;if((_|0)==0){break}gGr(_)}}while(0);if((a[h]&1)==0){i=f;return}h=c[o+8>>2]|0;if((h|0)==0){i=f;return}gGr(h);i=f;return}function gB1(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0;e=i;i=i+328|0;l=f;f=i;i=i+4|0;i=i+7&-8;c[f>>2]=c[l>>2];l=g;g=i;i=i+4|0;i=i+7&-8;c[g>>2]=c[l>>2];l=e|0;m=e+104|0;n=e+112|0;o=e+128|0;p=e+144|0;q=e+152|0;r=e+312|0;s=e+320|0;t=c[f>>2]|0;f=c[g>>2]|0;g=n;u=o;v=c[h+4>>2]&74;if((v|0)==8){w=16}else if((v|0)==0){w=0}else if((v|0)==64){w=8}else{w=10}v=l|0;gCc(n,c[h+28>>2]|0,v,m);gGz(u|0,0,12);h=o;gAt(o,10);if((a[u]&1)==0){l=h+1|0;x=l;y=l;z=o+8|0}else{l=o+8|0;x=c[l>>2]|0;y=h+1|0;z=l}c[p>>2]=x;l=q|0;c[r>>2]=l;c[s>>2]=0;A=o|0;B=o+4|0;C=c[m>>2]|0;m=o+8|0;D=x;x=t;t=f;L9524:while(1){if((x|0)==0){E=0}else{f=c[x+12>>2]|0;if((f|0)==(c[x+16>>2]|0)){F=gj[c[(c[x>>2]|0)+36>>2]&4095](x)|0}else{F=c[f>>2]|0}E=(F|0)==-1?0:x}f=(E|0)==0;do{if((t|0)==0){G=8263}else{H=c[t+12>>2]|0;if((H|0)==(c[t+16>>2]|0)){I=gj[c[(c[t>>2]|0)+36>>2]&4095](t)|0}else{I=c[H>>2]|0}if((I|0)==-1){G=8263;break}if(f){J=0;K=t}else{L=D;M=t;N=0;O=E;P=0;break L9524}}}while(0);if((G|0)==8263){G=0;if(f){L=D;M=0;N=1;O=0;P=1;break}else{J=1;K=0}}H=(c[p>>2]|0)-D|0;Q=a[u]|0;R=Q&255;if((H|0)==(((R&1|0)==0?R>>>1:c[B>>2]|0)|0)){R=H<<1;do{if(H>>>0<R>>>0){gAt(o,H)}else{if((Q&1)==0){a[h+1+R|0]=0;a[u]=H<<2&255;break}else{a[(c[m>>2]|0)+R|0]=0;c[B>>2]=R;break}}}while(0);R=a[u]|0;if((R&1)==0){S=10;T=R}else{R=c[A>>2]|0;S=(R&-2)-1|0;T=R&255}R=T&255;Q=(R&1|0)==0?R>>>1:c[B>>2]|0;do{if(Q>>>0<S>>>0){gAt(o,S-Q|0)}else{if((T&1)==0){a[h+1+S|0]=0;a[u]=S<<1&255;break}else{a[(c[m>>2]|0)+S|0]=0;c[B>>2]=S;break}}}while(0);if((a[u]&1)==0){U=y}else{U=c[z>>2]|0}c[p>>2]=U+H;V=U}else{V=D}Q=E+12|0;R=c[Q>>2]|0;W=E+16|0;if((R|0)==(c[W>>2]|0)){X=gj[c[(c[E>>2]|0)+36>>2]&4095](E)|0}else{X=c[R>>2]|0}if((gB8(X,w,V,p,s,C,n,l,r,v)|0)!=0){L=V;M=K;N=J;O=E;P=f;break}R=c[Q>>2]|0;if((R|0)==(c[W>>2]|0)){W=c[(c[E>>2]|0)+40>>2]|0;gj[W&4095](E)|0;D=V;x=E;t=K;continue}else{c[Q>>2]=R+4;D=V;x=E;t=K;continue}}K=d[g]|0;if((K&1|0)==0){Y=K>>>1}else{Y=c[n+4>>2]|0}do{if((Y|0)!=0){K=c[r>>2]|0;if((K-q|0)>=160){break}t=c[s>>2]|0;c[r>>2]=K+4;c[K>>2]=t}}while(0);c[k>>2]=gFV(L,c[p>>2]|0,j,w)|0;gDW(n,l,c[r>>2]|0,j);if(P){Z=0}else{P=c[O+12>>2]|0;if((P|0)==(c[O+16>>2]|0)){_=gj[c[(c[O>>2]|0)+36>>2]&4095](O)|0}else{_=c[P>>2]|0}Z=(_|0)==-1?0:O}O=(Z|0)==0;do{if(N){G=8314}else{_=c[M+12>>2]|0;if((_|0)==(c[M+16>>2]|0)){$=gj[c[(c[M>>2]|0)+36>>2]&4095](M)|0}else{$=c[_>>2]|0}if(($|0)==-1){G=8314;break}if(!(O^(M|0)==0)){G=8316}}}while(0);if((G|0)==8314){if(O){G=8316}}if((G|0)==8316){c[j>>2]=c[j>>2]|2}c[b>>2]=Z;do{if((a[u]&1)!=0){Z=c[m>>2]|0;if((Z|0)==0){break}gGr(Z)}}while(0);if((a[g]&1)==0){i=e;return}g=c[n+8>>2]|0;if((g|0)==0){i=e;return}gGr(g);i=e;return}function gB2(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0;e=i;i=i+328|0;l=f;f=i;i=i+4|0;i=i+7&-8;c[f>>2]=c[l>>2];l=g;g=i;i=i+4|0;i=i+7&-8;c[g>>2]=c[l>>2];l=e|0;m=e+104|0;n=e+112|0;o=e+128|0;p=e+144|0;q=e+152|0;r=e+312|0;s=e+320|0;t=c[f>>2]|0;f=c[g>>2]|0;g=n;u=o;v=c[h+4>>2]&74;if((v|0)==0){w=0}else if((v|0)==8){w=16}else if((v|0)==64){w=8}else{w=10}v=l|0;gCc(n,c[h+28>>2]|0,v,m);gGz(u|0,0,12);h=o;gAt(o,10);if((a[u]&1)==0){l=h+1|0;x=l;y=l;z=o+8|0}else{l=o+8|0;x=c[l>>2]|0;y=h+1|0;z=l}c[p>>2]=x;l=q|0;c[r>>2]=l;c[s>>2]=0;A=o|0;B=o+4|0;C=c[m>>2]|0;m=o+8|0;D=x;x=t;t=f;L9625:while(1){if((x|0)==0){E=0}else{f=c[x+12>>2]|0;if((f|0)==(c[x+16>>2]|0)){F=gj[c[(c[x>>2]|0)+36>>2]&4095](x)|0}else{F=c[f>>2]|0}E=(F|0)==-1?0:x}f=(E|0)==0;do{if((t|0)==0){G=8346}else{H=c[t+12>>2]|0;if((H|0)==(c[t+16>>2]|0)){I=gj[c[(c[t>>2]|0)+36>>2]&4095](t)|0}else{I=c[H>>2]|0}if((I|0)==-1){G=8346;break}if(f){J=0;K=t}else{L=D;M=t;N=0;O=E;P=0;break L9625}}}while(0);if((G|0)==8346){G=0;if(f){L=D;M=0;N=1;O=0;P=1;break}else{J=1;K=0}}H=(c[p>>2]|0)-D|0;Q=a[u]|0;R=Q&255;if((H|0)==(((R&1|0)==0?R>>>1:c[B>>2]|0)|0)){R=H<<1;do{if(H>>>0<R>>>0){gAt(o,H)}else{if((Q&1)==0){a[h+1+R|0]=0;a[u]=H<<2&255;break}else{a[(c[m>>2]|0)+R|0]=0;c[B>>2]=R;break}}}while(0);R=a[u]|0;if((R&1)==0){S=10;T=R}else{R=c[A>>2]|0;S=(R&-2)-1|0;T=R&255}R=T&255;Q=(R&1|0)==0?R>>>1:c[B>>2]|0;do{if(Q>>>0<S>>>0){gAt(o,S-Q|0)}else{if((T&1)==0){a[h+1+S|0]=0;a[u]=S<<1&255;break}else{a[(c[m>>2]|0)+S|0]=0;c[B>>2]=S;break}}}while(0);if((a[u]&1)==0){U=y}else{U=c[z>>2]|0}c[p>>2]=U+H;V=U}else{V=D}Q=E+12|0;R=c[Q>>2]|0;W=E+16|0;if((R|0)==(c[W>>2]|0)){X=gj[c[(c[E>>2]|0)+36>>2]&4095](E)|0}else{X=c[R>>2]|0}if((gB8(X,w,V,p,s,C,n,l,r,v)|0)!=0){L=V;M=K;N=J;O=E;P=f;break}R=c[Q>>2]|0;if((R|0)==(c[W>>2]|0)){W=c[(c[E>>2]|0)+40>>2]|0;gj[W&4095](E)|0;D=V;x=E;t=K;continue}else{c[Q>>2]=R+4;D=V;x=E;t=K;continue}}K=d[g]|0;if((K&1|0)==0){Y=K>>>1}else{Y=c[n+4>>2]|0}do{if((Y|0)!=0){K=c[r>>2]|0;if((K-q|0)>=160){break}t=c[s>>2]|0;c[r>>2]=K+4;c[K>>2]=t}}while(0);c[k>>2]=gFU(L,c[p>>2]|0,j,w)|0;gDW(n,l,c[r>>2]|0,j);if(P){Z=0}else{P=c[O+12>>2]|0;if((P|0)==(c[O+16>>2]|0)){_=gj[c[(c[O>>2]|0)+36>>2]&4095](O)|0}else{_=c[P>>2]|0}Z=(_|0)==-1?0:O}O=(Z|0)==0;do{if(N){G=8397}else{_=c[M+12>>2]|0;if((_|0)==(c[M+16>>2]|0)){$=gj[c[(c[M>>2]|0)+36>>2]&4095](M)|0}else{$=c[_>>2]|0}if(($|0)==-1){G=8397;break}if(!(O^(M|0)==0)){G=8399}}}while(0);if((G|0)==8397){if(O){G=8399}}if((G|0)==8399){c[j>>2]=c[j>>2]|2}c[b>>2]=Z;do{if((a[u]&1)!=0){Z=c[m>>2]|0;if((Z|0)==0){break}gGr(Z)}}while(0);if((a[g]&1)==0){i=e;return}g=c[n+8>>2]|0;if((g|0)==0){i=e;return}gGr(g);i=e;return}function gB3(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0;e=i;i=i+328|0;l=f;f=i;i=i+4|0;i=i+7&-8;c[f>>2]=c[l>>2];l=g;g=i;i=i+4|0;i=i+7&-8;c[g>>2]=c[l>>2];l=e|0;m=e+104|0;n=e+112|0;o=e+128|0;p=e+144|0;q=e+152|0;r=e+312|0;s=e+320|0;t=c[f>>2]|0;f=c[g>>2]|0;g=n;u=o;v=c[h+4>>2]&74;if((v|0)==8){w=16}else if((v|0)==0){w=0}else if((v|0)==64){w=8}else{w=10}v=l|0;gCc(n,c[h+28>>2]|0,v,m);gGz(u|0,0,12);h=o;gAt(o,10);if((a[u]&1)==0){l=h+1|0;x=l;y=l;z=o+8|0}else{l=o+8|0;x=c[l>>2]|0;y=h+1|0;z=l}c[p>>2]=x;l=q|0;c[r>>2]=l;c[s>>2]=0;A=o|0;B=o+4|0;C=c[m>>2]|0;m=o+8|0;D=x;x=t;t=f;L9726:while(1){if((x|0)==0){E=0}else{f=c[x+12>>2]|0;if((f|0)==(c[x+16>>2]|0)){F=gj[c[(c[x>>2]|0)+36>>2]&4095](x)|0}else{F=c[f>>2]|0}E=(F|0)==-1?0:x}f=(E|0)==0;do{if((t|0)==0){G=8429}else{H=c[t+12>>2]|0;if((H|0)==(c[t+16>>2]|0)){I=gj[c[(c[t>>2]|0)+36>>2]&4095](t)|0}else{I=c[H>>2]|0}if((I|0)==-1){G=8429;break}if(f){J=0;L=t}else{M=D;N=t;O=0;P=E;Q=0;break L9726}}}while(0);if((G|0)==8429){G=0;if(f){M=D;N=0;O=1;P=0;Q=1;break}else{J=1;L=0}}H=(c[p>>2]|0)-D|0;R=a[u]|0;S=R&255;if((H|0)==(((S&1|0)==0?S>>>1:c[B>>2]|0)|0)){S=H<<1;do{if(H>>>0<S>>>0){gAt(o,H)}else{if((R&1)==0){a[h+1+S|0]=0;a[u]=H<<2&255;break}else{a[(c[m>>2]|0)+S|0]=0;c[B>>2]=S;break}}}while(0);S=a[u]|0;if((S&1)==0){T=10;U=S}else{S=c[A>>2]|0;T=(S&-2)-1|0;U=S&255}S=U&255;R=(S&1|0)==0?S>>>1:c[B>>2]|0;do{if(R>>>0<T>>>0){gAt(o,T-R|0)}else{if((U&1)==0){a[h+1+T|0]=0;a[u]=T<<1&255;break}else{a[(c[m>>2]|0)+T|0]=0;c[B>>2]=T;break}}}while(0);if((a[u]&1)==0){V=y}else{V=c[z>>2]|0}c[p>>2]=V+H;W=V}else{W=D}R=E+12|0;S=c[R>>2]|0;X=E+16|0;if((S|0)==(c[X>>2]|0)){Y=gj[c[(c[E>>2]|0)+36>>2]&4095](E)|0}else{Y=c[S>>2]|0}if((gB8(Y,w,W,p,s,C,n,l,r,v)|0)!=0){M=W;N=L;O=J;P=E;Q=f;break}S=c[R>>2]|0;if((S|0)==(c[X>>2]|0)){X=c[(c[E>>2]|0)+40>>2]|0;gj[X&4095](E)|0;D=W;x=E;t=L;continue}else{c[R>>2]=S+4;D=W;x=E;t=L;continue}}L=d[g]|0;if((L&1|0)==0){Z=L>>>1}else{Z=c[n+4>>2]|0}do{if((Z|0)!=0){L=c[r>>2]|0;if((L-q|0)>=160){break}t=c[s>>2]|0;c[r>>2]=L+4;c[L>>2]=t}}while(0);s=gFT(M,c[p>>2]|0,j,w)|0;c[k>>2]=s;c[k+4>>2]=K;gDW(n,l,c[r>>2]|0,j);if(Q){_=0}else{Q=c[P+12>>2]|0;if((Q|0)==(c[P+16>>2]|0)){$=gj[c[(c[P>>2]|0)+36>>2]&4095](P)|0}else{$=c[Q>>2]|0}_=($|0)==-1?0:P}P=(_|0)==0;do{if(O){G=8480}else{$=c[N+12>>2]|0;if(($|0)==(c[N+16>>2]|0)){aa=gj[c[(c[N>>2]|0)+36>>2]&4095](N)|0}else{aa=c[$>>2]|0}if((aa|0)==-1){G=8480;break}if(!(P^(N|0)==0)){G=8482}}}while(0);if((G|0)==8480){if(P){G=8482}}if((G|0)==8482){c[j>>2]=c[j>>2]|2}c[b>>2]=_;do{if((a[u]&1)!=0){_=c[m>>2]|0;if((_|0)==0){break}gGr(_)}}while(0);if((a[g]&1)==0){i=e;return}g=c[n+8>>2]|0;if((g|0)==0){i=e;return}gGr(g);i=e;return}function gB4(b,e,f,h,j,k,l){b=b|0;e=e|0;f=f|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0;e=i;i=i+376|0;m=f;f=i;i=i+4|0;i=i+7&-8;c[f>>2]=c[m>>2];m=h;h=i;i=i+4|0;i=i+7&-8;c[h>>2]=c[m>>2];m=e+128|0;n=e+136|0;o=e+144|0;p=e+160|0;q=e+176|0;r=e+184|0;s=e+344|0;t=e+352|0;u=e+360|0;v=e+368|0;w=c[f>>2]|0;f=c[h>>2]|0;h=o;x=p;y=e|0;gCd(o,c[j+28>>2]|0,y,m,n);gGz(x|0,0,12);j=p;gAt(p,10);if((a[x]&1)==0){z=j+1|0;A=z;B=z;C=p+8|0}else{z=p+8|0;A=c[z>>2]|0;B=j+1|0;C=z}c[q>>2]=A;z=r|0;c[s>>2]=z;c[t>>2]=0;a[u]=1;a[v]=69;D=p|0;E=p+4|0;F=c[m>>2]|0;m=c[n>>2]|0;n=p+8|0;G=A;A=w;w=f;L9822:while(1){if((A|0)==0){H=0}else{f=c[A+12>>2]|0;if((f|0)==(c[A+16>>2]|0)){I=gj[c[(c[A>>2]|0)+36>>2]&4095](A)|0}else{I=c[f>>2]|0}H=(I|0)==-1?0:A}f=(H|0)==0;do{if((w|0)==0){J=8508}else{K=c[w+12>>2]|0;if((K|0)==(c[w+16>>2]|0)){L=gj[c[(c[w>>2]|0)+36>>2]&4095](w)|0}else{L=c[K>>2]|0}if((L|0)==-1){J=8508;break}if(f){M=0;N=w}else{O=G;P=w;Q=0;R=H;S=0;break L9822}}}while(0);if((J|0)==8508){J=0;if(f){O=G;P=0;Q=1;R=0;S=1;break}else{M=1;N=0}}K=(c[q>>2]|0)-G|0;T=a[x]|0;U=T&255;if((K|0)==(((U&1|0)==0?U>>>1:c[E>>2]|0)|0)){U=K<<1;do{if(K>>>0<U>>>0){gAt(p,K)}else{if((T&1)==0){a[j+1+U|0]=0;a[x]=K<<2&255;break}else{a[(c[n>>2]|0)+U|0]=0;c[E>>2]=U;break}}}while(0);U=a[x]|0;if((U&1)==0){V=10;W=U}else{U=c[D>>2]|0;V=(U&-2)-1|0;W=U&255}U=W&255;T=(U&1|0)==0?U>>>1:c[E>>2]|0;do{if(T>>>0<V>>>0){gAt(p,V-T|0)}else{if((W&1)==0){a[j+1+V|0]=0;a[x]=V<<1&255;break}else{a[(c[n>>2]|0)+V|0]=0;c[E>>2]=V;break}}}while(0);if((a[x]&1)==0){X=B}else{X=c[C>>2]|0}c[q>>2]=X+K;Y=X}else{Y=G}T=H+12|0;U=c[T>>2]|0;Z=H+16|0;if((U|0)==(c[Z>>2]|0)){_=gj[c[(c[H>>2]|0)+36>>2]&4095](H)|0}else{_=c[U>>2]|0}if((gCe(_,u,v,Y,q,F,m,o,z,s,t,y)|0)!=0){O=Y;P=N;Q=M;R=H;S=f;break}U=c[T>>2]|0;if((U|0)==(c[Z>>2]|0)){Z=c[(c[H>>2]|0)+40>>2]|0;gj[Z&4095](H)|0;G=Y;A=H;w=N;continue}else{c[T>>2]=U+4;G=Y;A=H;w=N;continue}}N=d[h]|0;if((N&1|0)==0){$=N>>>1}else{$=c[o+4>>2]|0}do{if(($|0)!=0){if((a[u]&1)==0){break}N=c[s>>2]|0;if((N-r|0)>=160){break}w=c[t>>2]|0;c[s>>2]=N+4;c[N>>2]=w}}while(0);g[l>>2]=+gFS(O,c[q>>2]|0,k);gDW(o,z,c[s>>2]|0,k);if(S){aa=0}else{S=c[R+12>>2]|0;if((S|0)==(c[R+16>>2]|0)){ab=gj[c[(c[R>>2]|0)+36>>2]&4095](R)|0}else{ab=c[S>>2]|0}aa=(ab|0)==-1?0:R}R=(aa|0)==0;do{if(Q){J=8560}else{ab=c[P+12>>2]|0;if((ab|0)==(c[P+16>>2]|0)){ac=gj[c[(c[P>>2]|0)+36>>2]&4095](P)|0}else{ac=c[ab>>2]|0}if((ac|0)==-1){J=8560;break}if(!(R^(P|0)==0)){J=8562}}}while(0);if((J|0)==8560){if(R){J=8562}}if((J|0)==8562){c[k>>2]=c[k>>2]|2}c[b>>2]=aa;do{if((a[x]&1)!=0){aa=c[n>>2]|0;if((aa|0)==0){break}gGr(aa)}}while(0);if((a[h]&1)==0){i=e;return}h=c[o+8>>2]|0;if((h|0)==0){i=e;return}gGr(h);i=e;return}function gB5(b,e,f,g,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0;e=i;i=i+376|0;m=f;f=i;i=i+4|0;i=i+7&-8;c[f>>2]=c[m>>2];m=g;g=i;i=i+4|0;i=i+7&-8;c[g>>2]=c[m>>2];m=e+128|0;n=e+136|0;o=e+144|0;p=e+160|0;q=e+176|0;r=e+184|0;s=e+344|0;t=e+352|0;u=e+360|0;v=e+368|0;w=c[f>>2]|0;f=c[g>>2]|0;g=o;x=p;y=e|0;gCd(o,c[j+28>>2]|0,y,m,n);gGz(x|0,0,12);j=p;gAt(p,10);if((a[x]&1)==0){z=j+1|0;A=z;B=z;C=p+8|0}else{z=p+8|0;A=c[z>>2]|0;B=j+1|0;C=z}c[q>>2]=A;z=r|0;c[s>>2]=z;c[t>>2]=0;a[u]=1;a[v]=69;D=p|0;E=p+4|0;F=c[m>>2]|0;m=c[n>>2]|0;n=p+8|0;G=A;A=w;w=f;L9919:while(1){if((A|0)==0){H=0}else{f=c[A+12>>2]|0;if((f|0)==(c[A+16>>2]|0)){I=gj[c[(c[A>>2]|0)+36>>2]&4095](A)|0}else{I=c[f>>2]|0}H=(I|0)==-1?0:A}f=(H|0)==0;do{if((w|0)==0){J=8588}else{K=c[w+12>>2]|0;if((K|0)==(c[w+16>>2]|0)){L=gj[c[(c[w>>2]|0)+36>>2]&4095](w)|0}else{L=c[K>>2]|0}if((L|0)==-1){J=8588;break}if(f){M=0;N=w}else{O=G;P=w;Q=0;R=H;S=0;break L9919}}}while(0);if((J|0)==8588){J=0;if(f){O=G;P=0;Q=1;R=0;S=1;break}else{M=1;N=0}}K=(c[q>>2]|0)-G|0;T=a[x]|0;U=T&255;if((K|0)==(((U&1|0)==0?U>>>1:c[E>>2]|0)|0)){U=K<<1;do{if(K>>>0<U>>>0){gAt(p,K)}else{if((T&1)==0){a[j+1+U|0]=0;a[x]=K<<2&255;break}else{a[(c[n>>2]|0)+U|0]=0;c[E>>2]=U;break}}}while(0);U=a[x]|0;if((U&1)==0){V=10;W=U}else{U=c[D>>2]|0;V=(U&-2)-1|0;W=U&255}U=W&255;T=(U&1|0)==0?U>>>1:c[E>>2]|0;do{if(T>>>0<V>>>0){gAt(p,V-T|0)}else{if((W&1)==0){a[j+1+V|0]=0;a[x]=V<<1&255;break}else{a[(c[n>>2]|0)+V|0]=0;c[E>>2]=V;break}}}while(0);if((a[x]&1)==0){X=B}else{X=c[C>>2]|0}c[q>>2]=X+K;Y=X}else{Y=G}T=H+12|0;U=c[T>>2]|0;Z=H+16|0;if((U|0)==(c[Z>>2]|0)){_=gj[c[(c[H>>2]|0)+36>>2]&4095](H)|0}else{_=c[U>>2]|0}if((gCe(_,u,v,Y,q,F,m,o,z,s,t,y)|0)!=0){O=Y;P=N;Q=M;R=H;S=f;break}U=c[T>>2]|0;if((U|0)==(c[Z>>2]|0)){Z=c[(c[H>>2]|0)+40>>2]|0;gj[Z&4095](H)|0;G=Y;A=H;w=N;continue}else{c[T>>2]=U+4;G=Y;A=H;w=N;continue}}N=d[g]|0;if((N&1|0)==0){$=N>>>1}else{$=c[o+4>>2]|0}do{if(($|0)!=0){if((a[u]&1)==0){break}N=c[s>>2]|0;if((N-r|0)>=160){break}w=c[t>>2]|0;c[s>>2]=N+4;c[N>>2]=w}}while(0);h[l>>3]=+gFR(O,c[q>>2]|0,k);gDW(o,z,c[s>>2]|0,k);if(S){aa=0}else{S=c[R+12>>2]|0;if((S|0)==(c[R+16>>2]|0)){ab=gj[c[(c[R>>2]|0)+36>>2]&4095](R)|0}else{ab=c[S>>2]|0}aa=(ab|0)==-1?0:R}R=(aa|0)==0;do{if(Q){J=8640}else{ab=c[P+12>>2]|0;if((ab|0)==(c[P+16>>2]|0)){ac=gj[c[(c[P>>2]|0)+36>>2]&4095](P)|0}else{ac=c[ab>>2]|0}if((ac|0)==-1){J=8640;break}if(!(R^(P|0)==0)){J=8642}}}while(0);if((J|0)==8640){if(R){J=8642}}if((J|0)==8642){c[k>>2]=c[k>>2]|2}c[b>>2]=aa;do{if((a[x]&1)!=0){aa=c[n>>2]|0;if((aa|0)==0){break}gGr(aa)}}while(0);if((a[g]&1)==0){i=e;return}g=c[o+8>>2]|0;if((g|0)==0){i=e;return}gGr(g);i=e;return}function gB6(b,e,f,g,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0;e=i;i=i+376|0;m=f;f=i;i=i+4|0;i=i+7&-8;c[f>>2]=c[m>>2];m=g;g=i;i=i+4|0;i=i+7&-8;c[g>>2]=c[m>>2];m=e+128|0;n=e+136|0;o=e+144|0;p=e+160|0;q=e+176|0;r=e+184|0;s=e+344|0;t=e+352|0;u=e+360|0;v=e+368|0;w=c[f>>2]|0;f=c[g>>2]|0;g=o;x=p;y=e|0;gCd(o,c[j+28>>2]|0,y,m,n);gGz(x|0,0,12);j=p;gAt(p,10);if((a[x]&1)==0){z=j+1|0;A=z;B=z;C=p+8|0}else{z=p+8|0;A=c[z>>2]|0;B=j+1|0;C=z}c[q>>2]=A;z=r|0;c[s>>2]=z;c[t>>2]=0;a[u]=1;a[v]=69;D=p|0;E=p+4|0;F=c[m>>2]|0;m=c[n>>2]|0;n=p+8|0;G=A;A=w;w=f;L10016:while(1){if((A|0)==0){H=0}else{f=c[A+12>>2]|0;if((f|0)==(c[A+16>>2]|0)){I=gj[c[(c[A>>2]|0)+36>>2]&4095](A)|0}else{I=c[f>>2]|0}H=(I|0)==-1?0:A}f=(H|0)==0;do{if((w|0)==0){J=8668}else{K=c[w+12>>2]|0;if((K|0)==(c[w+16>>2]|0)){L=gj[c[(c[w>>2]|0)+36>>2]&4095](w)|0}else{L=c[K>>2]|0}if((L|0)==-1){J=8668;break}if(f){M=0;N=w}else{O=G;P=w;Q=0;R=H;S=0;break L10016}}}while(0);if((J|0)==8668){J=0;if(f){O=G;P=0;Q=1;R=0;S=1;break}else{M=1;N=0}}K=(c[q>>2]|0)-G|0;T=a[x]|0;U=T&255;if((K|0)==(((U&1|0)==0?U>>>1:c[E>>2]|0)|0)){U=K<<1;do{if(K>>>0<U>>>0){gAt(p,K)}else{if((T&1)==0){a[j+1+U|0]=0;a[x]=K<<2&255;break}else{a[(c[n>>2]|0)+U|0]=0;c[E>>2]=U;break}}}while(0);U=a[x]|0;if((U&1)==0){V=10;W=U}else{U=c[D>>2]|0;V=(U&-2)-1|0;W=U&255}U=W&255;T=(U&1|0)==0?U>>>1:c[E>>2]|0;do{if(T>>>0<V>>>0){gAt(p,V-T|0)}else{if((W&1)==0){a[j+1+V|0]=0;a[x]=V<<1&255;break}else{a[(c[n>>2]|0)+V|0]=0;c[E>>2]=V;break}}}while(0);if((a[x]&1)==0){X=B}else{X=c[C>>2]|0}c[q>>2]=X+K;Y=X}else{Y=G}T=H+12|0;U=c[T>>2]|0;Z=H+16|0;if((U|0)==(c[Z>>2]|0)){_=gj[c[(c[H>>2]|0)+36>>2]&4095](H)|0}else{_=c[U>>2]|0}if((gCe(_,u,v,Y,q,F,m,o,z,s,t,y)|0)!=0){O=Y;P=N;Q=M;R=H;S=f;break}U=c[T>>2]|0;if((U|0)==(c[Z>>2]|0)){Z=c[(c[H>>2]|0)+40>>2]|0;gj[Z&4095](H)|0;G=Y;A=H;w=N;continue}else{c[T>>2]=U+4;G=Y;A=H;w=N;continue}}N=d[g]|0;if((N&1|0)==0){$=N>>>1}else{$=c[o+4>>2]|0}do{if(($|0)!=0){if((a[u]&1)==0){break}N=c[s>>2]|0;if((N-r|0)>=160){break}w=c[t>>2]|0;c[s>>2]=N+4;c[N>>2]=w}}while(0);h[l>>3]=+gFQ(O,c[q>>2]|0,k);gDW(o,z,c[s>>2]|0,k);if(S){aa=0}else{S=c[R+12>>2]|0;if((S|0)==(c[R+16>>2]|0)){ab=gj[c[(c[R>>2]|0)+36>>2]&4095](R)|0}else{ab=c[S>>2]|0}aa=(ab|0)==-1?0:R}R=(aa|0)==0;do{if(Q){J=8720}else{ab=c[P+12>>2]|0;if((ab|0)==(c[P+16>>2]|0)){ac=gj[c[(c[P>>2]|0)+36>>2]&4095](P)|0}else{ac=c[ab>>2]|0}if((ac|0)==-1){J=8720;break}if(!(R^(P|0)==0)){J=8722}}}while(0);if((J|0)==8720){if(R){J=8722}}if((J|0)==8722){c[k>>2]=c[k>>2]|2}c[b>>2]=aa;do{if((a[x]&1)!=0){aa=c[n>>2]|0;if((aa|0)==0){break}gGr(aa)}}while(0);if((a[g]&1)==0){i=e;return}g=c[o+8>>2]|0;if((g|0)==0){i=e;return}gGr(g);i=e;return}function gB7(b,d,e,f,g,h,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;d=i;i=i+136|0;k=e;e=i;i=i+4|0;i=i+7&-8;c[e>>2]=c[k>>2];k=f;f=i;i=i+4|0;i=i+7&-8;c[f>>2]=c[k>>2];k=d|0;l=d+16|0;m=d+120|0;n=m;o=i;i=i+12|0;i=i+7&-8;p=i;i=i+4|0;i=i+7&-8;q=i;i=i+160|0;r=i;i=i+4|0;i=i+7&-8;s=i;i=i+4|0;i=i+7&-8;gGz(n|0,0,12);t=o;u=c[g+28>>2]|0;g=u+4|0;I=c[g>>2]|0,c[g>>2]=I+1,I;if((c[2385058]|0)!=-1){c[k>>2]=9540232;c[k+4>>2]=180;c[k+8>>2]=0;gAp(9540232,k)}k=(c[2385059]|0)-1|0;v=c[u+8>>2]|0;do{if((c[u+12>>2]|0)-v>>2>>>0>k>>>0){w=c[v+(k<<2)>>2]|0;if((w|0)==0){break}x=w;y=l|0;z=c[(c[w>>2]|0)+48>>2]|0;gJ[z&31](x,627080,627106,y)|0;if(((I=c[g>>2]|0,c[g>>2]=I+ -1,I)|0)==0){gf[c[(c[u>>2]|0)+8>>2]&2047](u)}gGz(t|0,0,12);x=o;gAt(o,10);if((a[t]&1)==0){z=x+1|0;A=z;B=z;C=o+8|0}else{z=o+8|0;A=c[z>>2]|0;B=x+1|0;C=z}c[p>>2]=A;z=q|0;c[r>>2]=z;c[s>>2]=0;w=e|0;D=f|0;E=o|0;F=o+4|0;G=o+8|0;H=A;J=c[w>>2]|0;L10123:while(1){do{if((J|0)==0){K=0}else{L=c[J+12>>2]|0;if((L|0)==(c[J+16>>2]|0)){M=gj[c[(c[J>>2]|0)+36>>2]&4095](J)|0}else{M=c[L>>2]|0}if((M|0)!=-1){K=J;break}c[w>>2]=0;K=0}}while(0);L=(K|0)==0;N=c[D>>2]|0;do{if((N|0)==0){O=8759}else{P=c[N+12>>2]|0;if((P|0)==(c[N+16>>2]|0)){Q=gj[c[(c[N>>2]|0)+36>>2]&4095](N)|0}else{Q=c[P>>2]|0}if((Q|0)==-1){c[D>>2]=0;O=8759;break}else{if(L){break}else{R=H;break L10123}}}}while(0);if((O|0)==8759){O=0;if(L){R=H;break}}N=(c[p>>2]|0)-H|0;P=a[t]|0;S=P&255;if((N|0)==(((S&1|0)==0?S>>>1:c[F>>2]|0)|0)){S=N<<1;do{if(N>>>0<S>>>0){gAt(o,N)}else{if((P&1)==0){a[x+1+S|0]=0;a[t]=N<<2&255;break}else{a[(c[G>>2]|0)+S|0]=0;c[F>>2]=S;break}}}while(0);S=a[t]|0;if((S&1)==0){T=10;U=S}else{S=c[E>>2]|0;T=(S&-2)-1|0;U=S&255}S=U&255;P=(S&1|0)==0?S>>>1:c[F>>2]|0;do{if(P>>>0<T>>>0){gAt(o,T-P|0)}else{if((U&1)==0){a[x+1+T|0]=0;a[t]=T<<1&255;break}else{a[(c[G>>2]|0)+T|0]=0;c[F>>2]=T;break}}}while(0);if((a[t]&1)==0){V=B}else{V=c[C>>2]|0}c[p>>2]=V+N;W=V}else{W=H}P=K+12|0;S=c[P>>2]|0;L=K+16|0;if((S|0)==(c[L>>2]|0)){X=gj[c[(c[K>>2]|0)+36>>2]&4095](K)|0}else{X=c[S>>2]|0}if((gB8(X,16,W,p,s,0,m,z,r,y)|0)!=0){R=W;break}S=c[P>>2]|0;if((S|0)==(c[L>>2]|0)){L=c[(c[K>>2]|0)+40>>2]|0;gj[L&4095](K)|0;H=W;J=K;continue}else{c[P>>2]=S+4;H=W;J=K;continue}}a[R+3|0]=0;do{if((a[14125e3]|0)==0){if((bp(14125e3)|0)==0){break}c[2384150]=e6(2147483647,485280,0)|0}}while(0);J=gBV(R,c[2384150]|0,(H=i,i=i+8|0,c[H>>2]=j,H)|0)|0;i=H;if((J|0)!=1){c[h>>2]=4}J=c[w>>2]|0;do{if((J|0)==0){Y=0}else{H=c[J+12>>2]|0;if((H|0)==(c[J+16>>2]|0)){Z=gj[c[(c[J>>2]|0)+36>>2]&4095](J)|0}else{Z=c[H>>2]|0}if((Z|0)!=-1){Y=J;break}c[w>>2]=0;Y=0}}while(0);w=(Y|0)==0;J=c[D>>2]|0;do{if((J|0)==0){O=8811}else{H=c[J+12>>2]|0;if((H|0)==(c[J+16>>2]|0)){_=gj[c[(c[J>>2]|0)+36>>2]&4095](J)|0}else{_=c[H>>2]|0}if((_|0)==-1){c[D>>2]=0;O=8811;break}else{if(w){break}else{O=8813;break}}}}while(0);if((O|0)==8811){if(w){O=8813}}if((O|0)==8813){c[h>>2]=c[h>>2]|2}c[b>>2]=Y;do{if((a[t]&1)!=0){D=c[G>>2]|0;if((D|0)==0){break}gGr(D)}}while(0);if((a[n]&1)==0){i=d;return}G=c[m+8>>2]|0;if((G|0)==0){i=d;return}gGr(G);i=d;return}}while(0);d=f_(4)|0;c[d>>2]=619800;eh(d|0,625536,1e3)}function gB8(b,e,f,g,h,i,j,k,l,m){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0;n=c[g>>2]|0;o=(n|0)==(f|0);do{if(o){p=(c[m+96>>2]|0)==(b|0);if(!p){if((c[m+100>>2]|0)!=(b|0)){break}}c[g>>2]=f+1;a[f]=p?43:45;c[h>>2]=0;q=0;return q|0}}while(0);p=d[j]|0;if((p&1|0)==0){r=p>>>1}else{r=c[j+4>>2]|0}if((r|0)!=0&(b|0)==(i|0)){i=c[l>>2]|0;if((i-k|0)>=160){q=0;return q|0}k=c[h>>2]|0;c[l>>2]=i+4;c[i>>2]=k;c[h>>2]=0;q=0;return q|0}k=m+104|0;i=m;while(1){if((i|0)==(k|0)){s=k;break}if((c[i>>2]|0)==(b|0)){s=i;break}else{i=i+4|0}}i=s-m|0;m=i>>2;if((i|0)>92){q=-1;return q|0}do{if((e|0)==8|(e|0)==10){if((m|0)<(e|0)){break}else{q=-1}return q|0}else if((e|0)==16){if((i|0)<88){break}if(o){q=-1;return q|0}if((n-f|0)>=3){q=-1;return q|0}if((a[n-1|0]|0)!=48){q=-1;return q|0}c[h>>2]=0;s=a[627080+m|0]|0;b=c[g>>2]|0;c[g>>2]=b+1;a[b]=s;q=0;return q|0}}while(0);f=a[627080+m|0]|0;c[g>>2]=n+1;a[n]=f;c[h>>2]=(c[h>>2]|0)+1;q=0;return q|0}function gB9(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+32|0;h=g|0;j=g+16|0;k=d+4|0;I=c[k>>2]|0,c[k>>2]=I+1,I;if((c[2385060]|0)!=-1){c[j>>2]=9540240;c[j+4>>2]=180;c[j+8>>2]=0;gAp(9540240,j)}j=(c[2385061]|0)-1|0;l=d+12|0;m=d+8|0;n=c[m>>2]|0;do{if((c[l>>2]|0)-n>>2>>>0>j>>>0){o=c[n+(j<<2)>>2]|0;if((o|0)==0){break}p=o;q=c[(c[o>>2]|0)+32>>2]|0;gJ[q&31](p,627080,627106,e)|0;if((c[2384964]|0)!=-1){c[h>>2]=9539856;c[h+4>>2]=180;c[h+8>>2]=0;gAp(9539856,h)}p=(c[2384965]|0)-1|0;q=c[m>>2]|0;do{if((c[l>>2]|0)-q>>2>>>0>p>>>0){o=c[q+(p<<2)>>2]|0;if((o|0)==0){break}r=o;a[f]=gj[c[(c[o>>2]|0)+16>>2]&4095](r)|0;gg[c[(c[o>>2]|0)+20>>2]&4095](b,r);if(((I=c[k>>2]|0,c[k>>2]=I+ -1,I)|0)!=0){i=g;return}gf[c[(c[d>>2]|0)+8>>2]&2047](d);i=g;return}}while(0);p=f_(4)|0;c[p>>2]=619800;eh(p|0,625536,1e3)}}while(0);g=f_(4)|0;c[g>>2]=619800;eh(g|0,625536,1e3)}function gCa(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;h=i;i=i+32|0;j=h|0;k=h+16|0;l=d+4|0;I=c[l>>2]|0,c[l>>2]=I+1,I;if((c[2385060]|0)!=-1){c[k>>2]=9540240;c[k+4>>2]=180;c[k+8>>2]=0;gAp(9540240,k)}k=(c[2385061]|0)-1|0;m=d+12|0;n=d+8|0;o=c[n>>2]|0;do{if((c[m>>2]|0)-o>>2>>>0>k>>>0){p=c[o+(k<<2)>>2]|0;if((p|0)==0){break}q=p;r=c[(c[p>>2]|0)+32>>2]|0;gJ[r&31](q,627080,627112,e)|0;if((c[2384964]|0)!=-1){c[j>>2]=9539856;c[j+4>>2]=180;c[j+8>>2]=0;gAp(9539856,j)}q=(c[2384965]|0)-1|0;r=c[n>>2]|0;do{if((c[m>>2]|0)-r>>2>>>0>q>>>0){p=c[r+(q<<2)>>2]|0;if((p|0)==0){break}s=p;t=p;a[f]=gj[c[(c[t>>2]|0)+12>>2]&4095](s)|0;a[g]=gj[c[(c[t>>2]|0)+16>>2]&4095](s)|0;gg[c[(c[p>>2]|0)+20>>2]&4095](b,s);if(((I=c[l>>2]|0,c[l>>2]=I+ -1,I)|0)!=0){i=h;return}gf[c[(c[d>>2]|0)+8>>2]&2047](d);i=h;return}}while(0);q=f_(4)|0;c[q>>2]=619800;eh(q|0,625536,1e3)}}while(0);h=f_(4)|0;c[h>>2]=619800;eh(h|0,625536,1e3)}function gCb(b,e,f,g,h,i,j,k,l,m,n,o){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0;if(b<<24>>24==i<<24>>24){if((a[e]&1)==0){p=-1;return p|0}a[e]=0;i=c[h>>2]|0;c[h>>2]=i+1;a[i]=46;i=d[k]|0;if((i&1|0)==0){q=i>>>1}else{q=c[k+4>>2]|0}if((q|0)==0){p=0;return p|0}q=c[m>>2]|0;if((q-l|0)>=160){p=0;return p|0}i=c[n>>2]|0;c[m>>2]=q+4;c[q>>2]=i;p=0;return p|0}do{if(b<<24>>24==j<<24>>24){i=d[k]|0;if((i&1|0)==0){r=i>>>1}else{r=c[k+4>>2]|0}if((r|0)==0){break}if((a[e]&1)==0){p=-1;return p|0}i=c[m>>2]|0;if((i-l|0)>=160){p=0;return p|0}q=c[n>>2]|0;c[m>>2]=i+4;c[i>>2]=q;c[n>>2]=0;p=0;return p|0}}while(0);r=o+32|0;j=o;while(1){if((j|0)==(r|0)){s=r;break}if((a[j]|0)==b<<24>>24){s=j;break}else{j=j+1|0}}j=s-o|0;if((j|0)>31){p=-1;return p|0}o=a[627080+j|0]|0;if((j|0)==25|(j|0)==24){s=c[h>>2]|0;do{if((s|0)!=(g|0)){if((a[s-1|0]&95|0)==(a[f]&127|0)){break}else{p=-1}return p|0}}while(0);c[h>>2]=s+1;a[s]=o;p=0;return p|0}else if((j|0)==22|(j|0)==23){a[f]=80;s=c[h>>2]|0;c[h>>2]=s+1;a[s]=o;p=0;return p|0}else{s=a[f]|0;do{if((o&95|0)==(s<<24>>24|0)){a[f]=s|-128;if((a[e]&1)==0){break}a[e]=0;g=d[k]|0;if((g&1|0)==0){t=g>>>1}else{t=c[k+4>>2]|0}if((t|0)==0){break}g=c[m>>2]|0;if((g-l|0)>=160){break}b=c[n>>2]|0;c[m>>2]=g+4;c[g>>2]=b}}while(0);m=c[h>>2]|0;c[h>>2]=m+1;a[m]=o;if((j|0)>21){p=0;return p|0}c[n>>2]=(c[n>>2]|0)+1;p=0;return p|0}return 0}function gCc(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+32|0;g=f|0;h=f+16|0;j=b+4|0;I=c[j>>2]|0,c[j>>2]=I+1,I;if((c[2385058]|0)!=-1){c[h>>2]=9540232;c[h+4>>2]=180;c[h+8>>2]=0;gAp(9540232,h)}h=(c[2385059]|0)-1|0;k=b+12|0;l=b+8|0;m=c[l>>2]|0;do{if((c[k>>2]|0)-m>>2>>>0>h>>>0){n=c[m+(h<<2)>>2]|0;if((n|0)==0){break}o=n;p=c[(c[n>>2]|0)+48>>2]|0;gJ[p&31](o,627080,627106,d)|0;if((c[2384962]|0)!=-1){c[g>>2]=9539848;c[g+4>>2]=180;c[g+8>>2]=0;gAp(9539848,g)}o=(c[2384963]|0)-1|0;p=c[l>>2]|0;do{if((c[k>>2]|0)-p>>2>>>0>o>>>0){n=c[p+(o<<2)>>2]|0;if((n|0)==0){break}q=n;c[e>>2]=gj[c[(c[n>>2]|0)+16>>2]&4095](q)|0;gg[c[(c[n>>2]|0)+20>>2]&4095](a,q);if(((I=c[j>>2]|0,c[j>>2]=I+ -1,I)|0)!=0){i=f;return}gf[c[(c[b>>2]|0)+8>>2]&2047](b);i=f;return}}while(0);o=f_(4)|0;c[o>>2]=619800;eh(o|0,625536,1e3)}}while(0);f=f_(4)|0;c[f>>2]=619800;eh(f|0,625536,1e3)}function gCd(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=i;i=i+32|0;h=g|0;j=g+16|0;k=b+4|0;I=c[k>>2]|0,c[k>>2]=I+1,I;if((c[2385058]|0)!=-1){c[j>>2]=9540232;c[j+4>>2]=180;c[j+8>>2]=0;gAp(9540232,j)}j=(c[2385059]|0)-1|0;l=b+12|0;m=b+8|0;n=c[m>>2]|0;do{if((c[l>>2]|0)-n>>2>>>0>j>>>0){o=c[n+(j<<2)>>2]|0;if((o|0)==0){break}p=o;q=c[(c[o>>2]|0)+48>>2]|0;gJ[q&31](p,627080,627112,d)|0;if((c[2384962]|0)!=-1){c[h>>2]=9539848;c[h+4>>2]=180;c[h+8>>2]=0;gAp(9539848,h)}p=(c[2384963]|0)-1|0;q=c[m>>2]|0;do{if((c[l>>2]|0)-q>>2>>>0>p>>>0){o=c[q+(p<<2)>>2]|0;if((o|0)==0){break}r=o;s=o;c[e>>2]=gj[c[(c[s>>2]|0)+12>>2]&4095](r)|0;c[f>>2]=gj[c[(c[s>>2]|0)+16>>2]&4095](r)|0;gg[c[(c[o>>2]|0)+20>>2]&4095](a,r);if(((I=c[k>>2]|0,c[k>>2]=I+ -1,I)|0)!=0){i=g;return}gf[c[(c[b>>2]|0)+8>>2]&2047](b);i=g;return}}while(0);p=f_(4)|0;c[p>>2]=619800;eh(p|0,625536,1e3)}}while(0);g=f_(4)|0;c[g>>2]=619800;eh(g|0,625536,1e3)}function gCe(b,e,f,g,h,i,j,k,l,m,n,o){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0;if((b|0)==(i|0)){if((a[e]&1)==0){p=-1;return p|0}a[e]=0;i=c[h>>2]|0;c[h>>2]=i+1;a[i]=46;i=d[k]|0;if((i&1|0)==0){q=i>>>1}else{q=c[k+4>>2]|0}if((q|0)==0){p=0;return p|0}q=c[m>>2]|0;if((q-l|0)>=160){p=0;return p|0}i=c[n>>2]|0;c[m>>2]=q+4;c[q>>2]=i;p=0;return p|0}do{if((b|0)==(j|0)){i=d[k]|0;if((i&1|0)==0){r=i>>>1}else{r=c[k+4>>2]|0}if((r|0)==0){break}if((a[e]&1)==0){p=-1;return p|0}i=c[m>>2]|0;if((i-l|0)>=160){p=0;return p|0}q=c[n>>2]|0;c[m>>2]=i+4;c[i>>2]=q;c[n>>2]=0;p=0;return p|0}}while(0);r=o+128|0;j=o;while(1){if((j|0)==(r|0)){s=r;break}if((c[j>>2]|0)==(b|0)){s=j;break}else{j=j+4|0}}j=s-o|0;o=j>>2;if((j|0)>124){p=-1;return p|0}s=a[627080+o|0]|0;do{if((o|0)==25|(o|0)==24){b=c[h>>2]|0;do{if((b|0)!=(g|0)){if((a[b-1|0]&95|0)==(a[f]&127|0)){break}else{p=-1}return p|0}}while(0);c[h>>2]=b+1;a[b]=s;p=0;return p|0}else if((o|0)==22|(o|0)==23){a[f]=80}else{r=a[f]|0;if((s&95|0)!=(r<<24>>24|0)){break}a[f]=r|-128;if((a[e]&1)==0){break}a[e]=0;r=d[k]|0;if((r&1|0)==0){t=r>>>1}else{t=c[k+4>>2]|0}if((t|0)==0){break}r=c[m>>2]|0;if((r-l|0)>=160){break}q=c[n>>2]|0;c[m>>2]=r+4;c[r>>2]=q}}while(0);m=c[h>>2]|0;c[h>>2]=m+1;a[m]=s;if((j|0)>84){p=0;return p|0}c[n>>2]=(c[n>>2]|0)+1;p=0;return p|0}function gCf(a){a=a|0;if((a|0)==0){return}gGr(a);return}function gCg(a){a=a|0;return}function gCh(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;j=i;i=i+40|0;k=e;e=i;i=i+4|0;i=i+7&-8;c[e>>2]=c[k>>2];k=j|0;l=j+16|0;m=j+24|0;if((c[f+4>>2]&1|0)==0){n=c[(c[d>>2]|0)+24>>2]|0;c[l>>2]=c[e>>2];gB[n&127](b,d,l,f,g,h&1);i=j;return}g=c[f+28>>2]|0;f=g+4|0;I=c[f>>2]|0,c[f>>2]=I+1,I;if((c[2384964]|0)!=-1){c[k>>2]=9539856;c[k+4>>2]=180;c[k+8>>2]=0;gAp(9539856,k)}k=(c[2384965]|0)-1|0;l=c[g+8>>2]|0;do{if((c[g+12>>2]|0)-l>>2>>>0>k>>>0){d=c[l+(k<<2)>>2]|0;if((d|0)==0){break}n=d;if(((I=c[f>>2]|0,c[f>>2]=I+ -1,I)|0)==0){gf[c[(c[g>>2]|0)+8>>2]&2047](g)}o=c[d>>2]|0;if(h){gg[c[o+24>>2]&4095](m,n)}else{gg[c[o+28>>2]&4095](m,n)}n=m;o=m;d=a[o]|0;if((d&1)==0){p=n+1|0;q=p;r=p;s=m+8|0}else{p=m+8|0;q=c[p>>2]|0;r=n+1|0;s=p}p=e|0;n=m+4|0;t=q;u=d;while(1){v=(u&1)==0;if(v){w=r}else{w=c[s>>2]|0}d=u&255;if((t|0)==(w+((d&1|0)==0?d>>>1:c[n>>2]|0)|0)){break}d=a[t]|0;x=c[p>>2]|0;do{if((x|0)!=0){y=x+24|0;z=c[y>>2]|0;if((z|0)!=(c[x+28>>2]|0)){c[y>>2]=z+1;a[z]=d;break}if((gA[c[(c[x>>2]|0)+52>>2]&16383](x,d&255)|0)!=-1){break}c[p>>2]=0}}while(0);t=t+1|0;u=a[o]|0}c[b>>2]=c[p>>2];if(v){i=j;return}o=c[m+8>>2]|0;if((o|0)==0){i=j;return}gGr(o);i=j;return}}while(0);j=f_(4)|0;c[j>>2]=619800;eh(j|0,625536,1e3)}function gCi(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;d=i;i=i+72|0;j=e;e=i;i=i+4|0;i=i+7&-8;c[e>>2]=c[j>>2];j=d|0;k=d+8|0;l=d+24|0;m=d+48|0;n=d+56|0;o=d+64|0;p=j|0;a[p]=a[591144]|0;a[p+1|0]=a[591145]|0;a[p+2|0]=a[591146]|0;a[p+3|0]=a[591147]|0;a[p+4|0]=a[591148]|0;a[p+5|0]=a[591149]|0;q=j+1|0;r=f+4|0;s=c[r>>2]|0;if((s&2048|0)==0){t=q}else{a[q]=43;t=j+2|0}if((s&512|0)==0){u=t}else{a[t]=35;u=t+1|0}a[u]=108;t=u+1|0;u=s&74;do{if((u|0)==8){if((s&16384|0)==0){a[t]=120;break}else{a[t]=88;break}}else if((u|0)==64){a[t]=111}else{a[t]=100}}while(0);t=k|0;do{if((a[14125e3]|0)==0){if((bp(14125e3)|0)==0){break}c[2384150]=e6(2147483647,485280,0)|0}}while(0);u=gCj(t,12,c[2384150]|0,p,(p=i,i=i+8|0,c[p>>2]=h,p)|0)|0;i=p;p=k+u|0;h=c[r>>2]&176;do{if((h|0)==32){v=p}else if((h|0)==16){r=a[t]|0;if((r<<24>>24|0)==45|(r<<24>>24|0)==43){v=k+1|0;break}if(!((u|0)>1&r<<24>>24==48)){w=9120;break}r=a[k+1|0]|0;if(!((r<<24>>24|0)==120|(r<<24>>24|0)==88)){w=9120;break}v=k+2|0}else{w=9120}}while(0);if((w|0)==9120){v=t}w=l|0;l=o|0;k=c[f+28>>2]|0;c[l>>2]=k;u=k+4|0;I=c[u>>2]|0,c[u>>2]=I+1,I;gCk(t,v,p,w,m,n,o);o=c[l>>2]|0;l=o+4|0;if(((I=c[l>>2]|0,c[l>>2]=I+ -1,I)|0)!=0){x=e|0;y=c[x>>2]|0;z=c[m>>2]|0;A=c[n>>2]|0;gCl(b,y,w,z,A,f,g);i=d;return}gf[c[(c[o>>2]|0)+8>>2]&2047](o|0);x=e|0;y=c[x>>2]|0;z=c[m>>2]|0;A=c[n>>2]|0;gCl(b,y,w,z,A,f,g);i=d;return}function gCj(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0;g=i;i=i+16|0;h=g|0;j=h;c[j>>2]=f;c[j+4>>2]=0;j=fN(d|0)|0;d=db(a|0,b|0,e|0,h|0)|0;if((j|0)==0){i=g;return d|0}fN(j|0)|0;i=g;return d|0}function gCk(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;l=i;i=i+48|0;m=l|0;n=l+16|0;o=l+32|0;p=k|0;k=c[p>>2]|0;if((c[2385060]|0)!=-1){c[n>>2]=9540240;c[n+4>>2]=180;c[n+8>>2]=0;gAp(9540240,n)}n=(c[2385061]|0)-1|0;q=c[k+8>>2]|0;if((c[k+12>>2]|0)-q>>2>>>0<=n>>>0){r=f_(4)|0;s=r;c[s>>2]=619800;eh(r|0,625536,1e3)}k=c[q+(n<<2)>>2]|0;if((k|0)==0){r=f_(4)|0;s=r;c[s>>2]=619800;eh(r|0,625536,1e3)}r=k;s=c[p>>2]|0;if((c[2384964]|0)!=-1){c[m>>2]=9539856;c[m+4>>2]=180;c[m+8>>2]=0;gAp(9539856,m)}m=(c[2384965]|0)-1|0;p=c[s+8>>2]|0;if((c[s+12>>2]|0)-p>>2>>>0<=m>>>0){t=f_(4)|0;u=t;c[u>>2]=619800;eh(t|0,625536,1e3)}s=c[p+(m<<2)>>2]|0;if((s|0)==0){t=f_(4)|0;u=t;c[u>>2]=619800;eh(t|0,625536,1e3)}t=s;gg[c[(c[s>>2]|0)+20>>2]&4095](o,t);u=o;m=o;p=d[m]|0;if((p&1|0)==0){v=p>>>1}else{v=c[o+4>>2]|0}do{if((v|0)==0){p=c[(c[k>>2]|0)+32>>2]|0;gJ[p&31](r,b,f,g)|0;c[j>>2]=g+(f-b)}else{c[j>>2]=g;p=a[b]|0;if((p<<24>>24|0)==45|(p<<24>>24|0)==43){n=gA[c[(c[k>>2]|0)+28>>2]&16383](r,p)|0;p=c[j>>2]|0;c[j>>2]=p+1;a[p]=n;w=b+1|0}else{w=b}do{if((f-w|0)>1){if((a[w]|0)!=48){x=w;break}n=w+1|0;p=a[n]|0;if(!((p<<24>>24|0)==120|(p<<24>>24|0)==88)){x=w;break}p=k;q=gA[c[(c[p>>2]|0)+28>>2]&16383](r,48)|0;y=c[j>>2]|0;c[j>>2]=y+1;a[y]=q;q=gA[c[(c[p>>2]|0)+28>>2]&16383](r,a[n]|0)|0;n=c[j>>2]|0;c[j>>2]=n+1;a[n]=q;x=w+2|0}else{x=w}}while(0);do{if((x|0)!=(f|0)){q=f-1|0;if(x>>>0<q>>>0){z=x;A=q}else{break}do{q=a[z]|0;a[z]=a[A]|0;a[A]=q;z=z+1|0;A=A-1|0;}while(z>>>0<A>>>0)}}while(0);q=gj[c[(c[s>>2]|0)+16>>2]&4095](t)|0;if(x>>>0<f>>>0){n=u+1|0;p=k;y=o+4|0;B=o+8|0;C=0;D=0;E=x;while(1){F=a[((a[m]&1)==0?n:c[B>>2]|0)+D|0]|0;if(F<<24>>24!=0&(C|0)==(F<<24>>24|0)){F=c[j>>2]|0;c[j>>2]=F+1;a[F]=q;F=d[m]|0;G=(D>>>0<(((F&1|0)==0?F>>>1:c[y>>2]|0)-1|0)>>>0)+D|0;H=0}else{G=D;H=C}F=gA[c[(c[p>>2]|0)+28>>2]&16383](r,a[E]|0)|0;I=c[j>>2]|0;c[j>>2]=I+1;a[I]=F;F=E+1|0;if(F>>>0<f>>>0){C=H+1|0;D=G;E=F}else{break}}}E=g+(x-b)|0;D=c[j>>2]|0;if((E|0)==(D|0)){break}C=D-1|0;if(E>>>0<C>>>0){J=E;K=C}else{break}do{C=a[J]|0;a[J]=a[K]|0;a[K]=C;J=J+1|0;K=K-1|0;}while(J>>>0<K>>>0)}}while(0);if((e|0)==(f|0)){L=c[j>>2]|0}else{L=g+(e-b)|0}c[h>>2]=L;if((a[m]&1)==0){i=l;return}m=c[o+8>>2]|0;if((m|0)==0){i=l;return}gGr(m);i=l;return}function gCl(b,d,e,f,g,h,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;k=i;i=i+16|0;l=k|0;if((d|0)==0){c[b>>2]=0;i=k;return}m=g;g=e;n=m-g|0;o=h+12|0;h=c[o>>2]|0;p=(h|0)>(n|0)?h-n|0:0;n=f;h=n-g|0;do{if((h|0)>0){if((gp[c[(c[d>>2]|0)+48>>2]&16383](d,e,h)|0)==(h|0)){break}c[b>>2]=0;i=k;return}}while(0);do{if((p|0)>0){do{if(p>>>0<11){h=p<<1&255;e=l;a[e]=h;q=l+1|0;r=h;s=e}else{e=p+16&-16;h=(e|0)==0?1:e;while(1){t=gGq(h)|0;if((t|0)!=0){u=9213;break}g=(I=c[2439328]|0,c[2439328]=I+0,I);if((g|0)==0){break}gu[g&16383]()}if((u|0)==9213){c[l+8>>2]=t;h=e|1;c[l>>2]=h;c[l+4>>2]=p;q=t;r=h&255;s=l;break}h=f_(4)|0;c[h>>2]=619768;eh(h|0,625520,1206)}}while(0);gGz(q|0,j|0,p|0);a[q+p|0]=0;if((r&1)==0){v=l+1|0}else{v=c[l+8>>2]|0}if((gp[c[(c[d>>2]|0)+48>>2]&16383](d,v,p)|0)==(p|0)){if((a[s]&1)==0){break}h=c[l+8>>2]|0;if((h|0)==0){break}gGr(h);break}c[b>>2]=0;if((a[s]&1)==0){i=k;return}h=c[l+8>>2]|0;if((h|0)==0){i=k;return}gGr(h);i=k;return}}while(0);l=m-n|0;do{if((l|0)>0){if((gp[c[(c[d>>2]|0)+48>>2]&16383](d,f,l)|0)==(l|0)){break}c[b>>2]=0;i=k;return}}while(0);c[o>>2]=0;c[b>>2]=d;i=k;return}function gCm(b,d,e,f,g,h,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;d=i;i=i+104|0;k=e;e=i;i=i+4|0;i=i+7&-8;c[e>>2]=c[k>>2];k=d|0;l=d+8|0;m=d+32|0;n=d+80|0;o=d+88|0;p=d+96|0;c[k>>2]=37;c[k+4>>2]=0;q=k;k=q+1|0;r=f+4|0;s=c[r>>2]|0;if((s&2048|0)==0){t=k}else{a[k]=43;t=q+2|0}if((s&512|0)==0){u=t}else{a[t]=35;u=t+1|0}a[u]=108;a[u+1|0]=108;t=u+2|0;u=s&74;do{if((u|0)==8){if((s&16384|0)==0){a[t]=120;break}else{a[t]=88;break}}else if((u|0)==64){a[t]=111}else{a[t]=100}}while(0);t=l|0;do{if((a[14125e3]|0)==0){if((bp(14125e3)|0)==0){break}c[2384150]=e6(2147483647,485280,0)|0}}while(0);u=gCj(t,22,c[2384150]|0,q,(q=i,i=i+16|0,c[q>>2]=h,c[q+8>>2]=j,q)|0)|0;i=q;q=l+u|0;j=c[r>>2]&176;do{if((j|0)==16){r=a[t]|0;if((r<<24>>24|0)==45|(r<<24>>24|0)==43){v=l+1|0;break}if(!((u|0)>1&r<<24>>24==48)){w=9262;break}r=a[l+1|0]|0;if(!((r<<24>>24|0)==120|(r<<24>>24|0)==88)){w=9262;break}v=l+2|0}else if((j|0)==32){v=q}else{w=9262}}while(0);if((w|0)==9262){v=t}w=m|0;m=p|0;j=c[f+28>>2]|0;c[m>>2]=j;l=j+4|0;I=c[l>>2]|0,c[l>>2]=I+1,I;gCk(t,v,q,w,n,o,p);p=c[m>>2]|0;m=p+4|0;if(((I=c[m>>2]|0,c[m>>2]=I+ -1,I)|0)!=0){x=e|0;y=c[x>>2]|0;z=c[n>>2]|0;A=c[o>>2]|0;gCl(b,y,w,z,A,f,g);i=d;return}gf[c[(c[p>>2]|0)+8>>2]&2047](p|0);x=e|0;y=c[x>>2]|0;z=c[n>>2]|0;A=c[o>>2]|0;gCl(b,y,w,z,A,f,g);i=d;return}function gCn(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;d=i;i=i+72|0;j=e;e=i;i=i+4|0;i=i+7&-8;c[e>>2]=c[j>>2];j=d|0;k=d+8|0;l=d+24|0;m=d+48|0;n=d+56|0;o=d+64|0;p=j|0;a[p]=a[591144]|0;a[p+1|0]=a[591145]|0;a[p+2|0]=a[591146]|0;a[p+3|0]=a[591147]|0;a[p+4|0]=a[591148]|0;a[p+5|0]=a[591149]|0;q=j+1|0;r=f+4|0;s=c[r>>2]|0;if((s&2048|0)==0){t=q}else{a[q]=43;t=j+2|0}if((s&512|0)==0){u=t}else{a[t]=35;u=t+1|0}a[u]=108;t=u+1|0;u=s&74;do{if((u|0)==8){if((s&16384|0)==0){a[t]=120;break}else{a[t]=88;break}}else if((u|0)==64){a[t]=111}else{a[t]=117}}while(0);t=k|0;do{if((a[14125e3]|0)==0){if((bp(14125e3)|0)==0){break}c[2384150]=e6(2147483647,485280,0)|0}}while(0);u=gCj(t,12,c[2384150]|0,p,(p=i,i=i+8|0,c[p>>2]=h,p)|0)|0;i=p;p=k+u|0;h=c[r>>2]&176;do{if((h|0)==32){v=p}else if((h|0)==16){r=a[t]|0;if((r<<24>>24|0)==45|(r<<24>>24|0)==43){v=k+1|0;break}if(!((u|0)>1&r<<24>>24==48)){w=9293;break}r=a[k+1|0]|0;if(!((r<<24>>24|0)==120|(r<<24>>24|0)==88)){w=9293;break}v=k+2|0}else{w=9293}}while(0);if((w|0)==9293){v=t}w=l|0;l=o|0;k=c[f+28>>2]|0;c[l>>2]=k;u=k+4|0;I=c[u>>2]|0,c[u>>2]=I+1,I;gCk(t,v,p,w,m,n,o);o=c[l>>2]|0;l=o+4|0;if(((I=c[l>>2]|0,c[l>>2]=I+ -1,I)|0)!=0){x=e|0;y=c[x>>2]|0;z=c[m>>2]|0;A=c[n>>2]|0;gCl(b,y,w,z,A,f,g);i=d;return}gf[c[(c[o>>2]|0)+8>>2]&2047](o|0);x=e|0;y=c[x>>2]|0;z=c[m>>2]|0;A=c[n>>2]|0;gCl(b,y,w,z,A,f,g);i=d;return}function gCo(b,d,e,f,g,h,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;d=i;i=i+104|0;k=e;e=i;i=i+4|0;i=i+7&-8;c[e>>2]=c[k>>2];k=d|0;l=d+8|0;m=d+32|0;n=d+80|0;o=d+88|0;p=d+96|0;c[k>>2]=37;c[k+4>>2]=0;q=k;k=q+1|0;r=f+4|0;s=c[r>>2]|0;if((s&2048|0)==0){t=k}else{a[k]=43;t=q+2|0}if((s&512|0)==0){u=t}else{a[t]=35;u=t+1|0}a[u]=108;a[u+1|0]=108;t=u+2|0;u=s&74;do{if((u|0)==8){if((s&16384|0)==0){a[t]=120;break}else{a[t]=88;break}}else if((u|0)==64){a[t]=111}else{a[t]=117}}while(0);t=l|0;do{if((a[14125e3]|0)==0){if((bp(14125e3)|0)==0){break}c[2384150]=e6(2147483647,485280,0)|0}}while(0);u=gCj(t,23,c[2384150]|0,q,(q=i,i=i+16|0,c[q>>2]=h,c[q+8>>2]=j,q)|0)|0;i=q;q=l+u|0;j=c[r>>2]&176;do{if((j|0)==16){r=a[t]|0;if((r<<24>>24|0)==45|(r<<24>>24|0)==43){v=l+1|0;break}if(!((u|0)>1&r<<24>>24==48)){w=9324;break}r=a[l+1|0]|0;if(!((r<<24>>24|0)==120|(r<<24>>24|0)==88)){w=9324;break}v=l+2|0}else if((j|0)==32){v=q}else{w=9324}}while(0);if((w|0)==9324){v=t}w=m|0;m=p|0;j=c[f+28>>2]|0;c[m>>2]=j;l=j+4|0;I=c[l>>2]|0,c[l>>2]=I+1,I;gCk(t,v,q,w,n,o,p);p=c[m>>2]|0;m=p+4|0;if(((I=c[m>>2]|0,c[m>>2]=I+ -1,I)|0)!=0){x=e|0;y=c[x>>2]|0;z=c[n>>2]|0;A=c[o>>2]|0;gCl(b,y,w,z,A,f,g);i=d;return}gf[c[(c[p>>2]|0)+8>>2]&2047](p|0);x=e|0;y=c[x>>2]|0;z=c[n>>2]|0;A=c[o>>2]|0;gCl(b,y,w,z,A,f,g);i=d;return}function gCp(b,d,e,f,g,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;j=+j;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,J=0;d=i;i=i+144|0;k=e;e=i;i=i+4|0;i=i+7&-8;c[e>>2]=c[k>>2];k=d|0;l=d+8|0;m=d+40|0;n=d+48|0;o=d+112|0;p=d+120|0;q=d+128|0;r=d+136|0;c[k>>2]=37;c[k+4>>2]=0;s=k;k=s+1|0;t=f+4|0;u=c[t>>2]|0;if((u&2048|0)==0){v=k}else{a[k]=43;v=s+2|0}if((u&1024|0)==0){w=v}else{a[v]=35;w=v+1|0}v=u&260;k=u>>>14;do{if((v|0)==260){if((k&1|0)==0){a[w]=97;x=0;break}else{a[w]=65;x=0;break}}else{a[w]=46;u=w+2|0;a[w+1|0]=42;if((v|0)==256){if((k&1|0)==0){a[u]=101;x=1;break}else{a[u]=69;x=1;break}}else if((v|0)==4){if((k&1|0)==0){a[u]=102;x=1;break}else{a[u]=70;x=1;break}}else{if((k&1|0)==0){a[u]=103;x=1;break}else{a[u]=71;x=1;break}}}}while(0);k=l|0;c[m>>2]=k;do{if((a[14125e3]|0)==0){if((bp(14125e3)|0)==0){break}c[2384150]=e6(2147483647,485280,0)|0}}while(0);l=c[2384150]|0;if(x){v=gCj(k,30,l,s,(y=i,i=i+16|0,c[y>>2]=c[f+8>>2],h[y+8>>3]=j,y)|0)|0;i=y;z=v}else{v=gCj(k,30,l,s,(y=i,i=i+8|0,h[y>>3]=j,y)|0)|0;i=y;z=v}do{if((z|0)>29){v=(a[14125e3]|0)==0;if(x){do{if(v){if((bp(14125e3)|0)==0){break}c[2384150]=e6(2147483647,485280,0)|0}}while(0);l=gCq(m,c[2384150]|0,s,(y=i,i=i+16|0,c[y>>2]=c[f+8>>2],h[y+8>>3]=j,y)|0)|0;i=y;A=l}else{do{if(v){if((bp(14125e3)|0)==0){break}c[2384150]=e6(2147483647,485280,0)|0}}while(0);v=gCq(m,c[2384150]|0,s,(y=i,i=i+16|0,c[y>>2]=c[f+8>>2],h[y+8>>3]=j,y)|0)|0;i=y;A=v}v=c[m>>2]|0;if((v|0)!=0){B=A;C=v;D=v;break}v=f_(4)|0;c[v>>2]=619768;eh(v|0,625520,1206)}else{B=z;C=0;D=c[m>>2]|0}}while(0);m=D+B|0;z=c[t>>2]&176;do{if((z|0)==32){E=m}else if((z|0)==16){t=a[D]|0;if((t<<24>>24|0)==45|(t<<24>>24|0)==43){E=D+1|0;break}if(!((B|0)>1&t<<24>>24==48)){F=9386;break}t=a[D+1|0]|0;if(!((t<<24>>24|0)==120|(t<<24>>24|0)==88)){F=9386;break}E=D+2|0}else{F=9386}}while(0);if((F|0)==9386){E=D}do{if((D|0)==(k|0)){G=n|0;H=0;J=k}else{F=gGq(B<<1)|0;if((F|0)!=0){G=F;H=F;J=D;break}F=f_(4)|0;c[F>>2]=619768;eh(F|0,625520,1206)}}while(0);D=q|0;B=c[f+28>>2]|0;c[D>>2]=B;k=B+4|0;I=c[k>>2]|0,c[k>>2]=I+1,I;gCr(J,E,m,G,o,p,q);q=c[D>>2]|0;D=q+4|0;if(((I=c[D>>2]|0,c[D>>2]=I+ -1,I)|0)==0){gf[c[(c[q>>2]|0)+8>>2]&2047](q|0)}q=e|0;gCl(r,c[q>>2]|0,G,c[o>>2]|0,c[p>>2]|0,f,g);g=c[r>>2]|0;c[q>>2]=g;c[b>>2]=g;if((H|0)!=0){gGr(H)}if((C|0)==0){i=d;return}gGr(C);i=d;return}function gCq(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=i;i=i+16|0;g=f|0;h=g;c[h>>2]=e;c[h+4>>2]=0;h=fN(b|0)|0;b=b6(a|0,d|0,g|0)|0;if((h|0)==0){i=f;return b|0}fN(h|0)|0;i=f;return b|0}function gCr(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;l=i;i=i+48|0;m=l|0;n=l+16|0;o=l+32|0;p=k|0;k=c[p>>2]|0;if((c[2385060]|0)!=-1){c[n>>2]=9540240;c[n+4>>2]=180;c[n+8>>2]=0;gAp(9540240,n)}n=(c[2385061]|0)-1|0;q=c[k+8>>2]|0;if((c[k+12>>2]|0)-q>>2>>>0<=n>>>0){r=f_(4)|0;s=r;c[s>>2]=619800;eh(r|0,625536,1e3)}k=c[q+(n<<2)>>2]|0;if((k|0)==0){r=f_(4)|0;s=r;c[s>>2]=619800;eh(r|0,625536,1e3)}r=k;s=c[p>>2]|0;if((c[2384964]|0)!=-1){c[m>>2]=9539856;c[m+4>>2]=180;c[m+8>>2]=0;gAp(9539856,m)}m=(c[2384965]|0)-1|0;p=c[s+8>>2]|0;if((c[s+12>>2]|0)-p>>2>>>0<=m>>>0){t=f_(4)|0;u=t;c[u>>2]=619800;eh(t|0,625536,1e3)}s=c[p+(m<<2)>>2]|0;if((s|0)==0){t=f_(4)|0;u=t;c[u>>2]=619800;eh(t|0,625536,1e3)}t=s;gg[c[(c[s>>2]|0)+20>>2]&4095](o,t);c[j>>2]=g;u=a[b]|0;if((u<<24>>24|0)==45|(u<<24>>24|0)==43){m=gA[c[(c[k>>2]|0)+28>>2]&16383](r,u)|0;u=c[j>>2]|0;c[j>>2]=u+1;a[u]=m;v=b+1|0}else{v=b}m=f;L10913:do{if((m-v|0)>1){if((a[v]|0)!=48){w=v;x=9457;break}u=v+1|0;p=a[u]|0;if(!((p<<24>>24|0)==120|(p<<24>>24|0)==88)){w=v;x=9457;break}p=k;n=gA[c[(c[p>>2]|0)+28>>2]&16383](r,48)|0;q=c[j>>2]|0;c[j>>2]=q+1;a[q]=n;n=v+2|0;q=gA[c[(c[p>>2]|0)+28>>2]&16383](r,a[u]|0)|0;u=c[j>>2]|0;c[j>>2]=u+1;a[u]=q;q=n;while(1){if(q>>>0>=f>>>0){y=q;z=n;break L10913}u=a[q]|0;do{if((a[14125e3]|0)==0){if((bp(14125e3)|0)==0){break}c[2384150]=e6(2147483647,485280,0)|0}}while(0);if((fk(u<<24>>24|0,c[2384150]|0)|0)==0){y=q;z=n;break}else{q=q+1|0}}}else{w=v;x=9457}}while(0);L10928:do{if((x|0)==9457){while(1){x=0;if(w>>>0>=f>>>0){y=w;z=v;break L10928}q=a[w]|0;do{if((a[14125e3]|0)==0){if((bp(14125e3)|0)==0){break}c[2384150]=e6(2147483647,485280,0)|0}}while(0);if((fV(q<<24>>24|0,c[2384150]|0)|0)==0){y=w;z=v;break}else{w=w+1|0;x=9457}}}}while(0);x=o;w=o;v=d[w]|0;if((v&1|0)==0){A=v>>>1}else{A=c[o+4>>2]|0}do{if((A|0)==0){v=c[j>>2]|0;u=c[(c[k>>2]|0)+32>>2]|0;gJ[u&31](r,z,y,v)|0;c[j>>2]=(c[j>>2]|0)+(y-z)}else{do{if((z|0)!=(y|0)){v=y-1|0;if(z>>>0<v>>>0){B=z;C=v}else{break}do{v=a[B]|0;a[B]=a[C]|0;a[C]=v;B=B+1|0;C=C-1|0;}while(B>>>0<C>>>0)}}while(0);q=gj[c[(c[s>>2]|0)+16>>2]&4095](t)|0;if(z>>>0<y>>>0){v=x+1|0;u=o+4|0;n=o+8|0;p=k;D=0;E=0;F=z;while(1){G=a[((a[w]&1)==0?v:c[n>>2]|0)+E|0]|0;if(G<<24>>24>0&(D|0)==(G<<24>>24|0)){G=c[j>>2]|0;c[j>>2]=G+1;a[G]=q;G=d[w]|0;H=(E>>>0<(((G&1|0)==0?G>>>1:c[u>>2]|0)-1|0)>>>0)+E|0;I=0}else{H=E;I=D}G=gA[c[(c[p>>2]|0)+28>>2]&16383](r,a[F]|0)|0;J=c[j>>2]|0;c[j>>2]=J+1;a[J]=G;G=F+1|0;if(G>>>0<y>>>0){D=I+1|0;E=H;F=G}else{break}}}F=g+(z-b)|0;E=c[j>>2]|0;if((F|0)==(E|0)){break}D=E-1|0;if(F>>>0<D>>>0){K=F;L=D}else{break}do{D=a[K]|0;a[K]=a[L]|0;a[L]=D;K=K+1|0;L=L-1|0;}while(K>>>0<L>>>0)}}while(0);L10966:do{if(y>>>0<f>>>0){L=k;K=y;while(1){z=a[K]|0;if(z<<24>>24==46){break}H=gA[c[(c[L>>2]|0)+28>>2]&16383](r,z)|0;z=c[j>>2]|0;c[j>>2]=z+1;a[z]=H;H=K+1|0;if(H>>>0<f>>>0){K=H}else{M=H;break L10966}}L=gj[c[(c[s>>2]|0)+12>>2]&4095](t)|0;H=c[j>>2]|0;c[j>>2]=H+1;a[H]=L;M=K+1|0}else{M=y}}while(0);gJ[c[(c[k>>2]|0)+32>>2]&31](r,M,f,c[j>>2]|0)|0;r=(c[j>>2]|0)+(m-M)|0;c[j>>2]=r;if((e|0)==(f|0)){N=r}else{N=g+(e-b)|0}c[h>>2]=N;if((a[w]&1)==0){i=l;return}w=c[o+8>>2]|0;if((w|0)==0){i=l;return}gGr(w);i=l;return}function gCs(b,d,e,f,g,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;j=+j;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,J=0;d=i;i=i+144|0;k=e;e=i;i=i+4|0;i=i+7&-8;c[e>>2]=c[k>>2];k=d|0;l=d+8|0;m=d+40|0;n=d+48|0;o=d+112|0;p=d+120|0;q=d+128|0;r=d+136|0;c[k>>2]=37;c[k+4>>2]=0;s=k;k=s+1|0;t=f+4|0;u=c[t>>2]|0;if((u&2048|0)==0){v=k}else{a[k]=43;v=s+2|0}if((u&1024|0)==0){w=v}else{a[v]=35;w=v+1|0}v=u&260;k=u>>>14;do{if((v|0)==260){a[w]=76;u=w+1|0;if((k&1|0)==0){a[u]=97;x=0;break}else{a[u]=65;x=0;break}}else{a[w]=46;a[w+1|0]=42;a[w+2|0]=76;u=w+3|0;if((v|0)==256){if((k&1|0)==0){a[u]=101;x=1;break}else{a[u]=69;x=1;break}}else if((v|0)==4){if((k&1|0)==0){a[u]=102;x=1;break}else{a[u]=70;x=1;break}}else{if((k&1|0)==0){a[u]=103;x=1;break}else{a[u]=71;x=1;break}}}}while(0);k=l|0;c[m>>2]=k;do{if((a[14125e3]|0)==0){if((bp(14125e3)|0)==0){break}c[2384150]=e6(2147483647,485280,0)|0}}while(0);l=c[2384150]|0;if(x){v=gCj(k,30,l,s,(y=i,i=i+16|0,c[y>>2]=c[f+8>>2],h[y+8>>3]=j,y)|0)|0;i=y;z=v}else{v=gCj(k,30,l,s,(y=i,i=i+8|0,h[y>>3]=j,y)|0)|0;i=y;z=v}do{if((z|0)>29){v=(a[14125e3]|0)==0;if(x){do{if(v){if((bp(14125e3)|0)==0){break}c[2384150]=e6(2147483647,485280,0)|0}}while(0);l=gCq(m,c[2384150]|0,s,(y=i,i=i+16|0,c[y>>2]=c[f+8>>2],h[y+8>>3]=j,y)|0)|0;i=y;A=l}else{do{if(v){if((bp(14125e3)|0)==0){break}c[2384150]=e6(2147483647,485280,0)|0}}while(0);v=gCq(m,c[2384150]|0,s,(y=i,i=i+8|0,h[y>>3]=j,y)|0)|0;i=y;A=v}v=c[m>>2]|0;if((v|0)!=0){B=A;C=v;D=v;break}v=f_(4)|0;c[v>>2]=619768;eh(v|0,625520,1206)}else{B=z;C=0;D=c[m>>2]|0}}while(0);m=D+B|0;z=c[t>>2]&176;do{if((z|0)==32){E=m}else if((z|0)==16){t=a[D]|0;if((t<<24>>24|0)==45|(t<<24>>24|0)==43){E=D+1|0;break}if(!((B|0)>1&t<<24>>24==48)){F=9557;break}t=a[D+1|0]|0;if(!((t<<24>>24|0)==120|(t<<24>>24|0)==88)){F=9557;break}E=D+2|0}else{F=9557}}while(0);if((F|0)==9557){E=D}do{if((D|0)==(k|0)){G=n|0;H=0;J=k}else{F=gGq(B<<1)|0;if((F|0)!=0){G=F;H=F;J=D;break}F=f_(4)|0;c[F>>2]=619768;eh(F|0,625520,1206)}}while(0);D=q|0;B=c[f+28>>2]|0;c[D>>2]=B;k=B+4|0;I=c[k>>2]|0,c[k>>2]=I+1,I;gCr(J,E,m,G,o,p,q);q=c[D>>2]|0;D=q+4|0;if(((I=c[D>>2]|0,c[D>>2]=I+ -1,I)|0)==0){gf[c[(c[q>>2]|0)+8>>2]&2047](q|0)}q=e|0;gCl(r,c[q>>2]|0,G,c[o>>2]|0,c[p>>2]|0,f,g);g=c[r>>2]|0;c[q>>2]=g;c[b>>2]=g;if((H|0)!=0){gGr(H)}if((C|0)==0){i=d;return}gGr(C);i=d;return}function gCt(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;d=i;i=i+88|0;j=e;e=i;i=i+4|0;i=i+7&-8;c[e>>2]=c[j>>2];j=d|0;k=d+24|0;l=d+48|0;m=d+16|0;a[m]=a[591152]|0;a[m+1|0]=a[591153]|0;a[m+2|0]=a[591154]|0;a[m+3|0]=a[591155]|0;a[m+4|0]=a[591156]|0;a[m+5|0]=a[591157]|0;n=k|0;do{if((a[14125e3]|0)==0){if((bp(14125e3)|0)==0){break}c[2384150]=e6(2147483647,485280,0)|0}}while(0);o=gCj(n,20,c[2384150]|0,m,(m=i,i=i+8|0,c[m>>2]=h,m)|0)|0;i=m;m=k+o|0;h=c[f+4>>2]&176;do{if((h|0)==32){p=m}else if((h|0)==16){q=a[n]|0;if((q<<24>>24|0)==45|(q<<24>>24|0)==43){p=k+1|0;break}if(!((o|0)>1&q<<24>>24==48)){r=9592;break}q=a[k+1|0]|0;if(!((q<<24>>24|0)==120|(q<<24>>24|0)==88)){r=9592;break}p=k+2|0}else{r=9592}}while(0);if((r|0)==9592){p=n}r=c[f+28>>2]|0;h=r+4|0;I=c[h>>2]|0,c[h>>2]=I+1,I;if((c[2385060]|0)!=-1){c[j>>2]=9540240;c[j+4>>2]=180;c[j+8>>2]=0;gAp(9540240,j)}j=(c[2385061]|0)-1|0;q=c[r+8>>2]|0;do{if((c[r+12>>2]|0)-q>>2>>>0>j>>>0){s=c[q+(j<<2)>>2]|0;if((s|0)==0){break}t=s;if(((I=c[h>>2]|0,c[h>>2]=I+ -1,I)|0)==0){gf[c[(c[r>>2]|0)+8>>2]&2047](r)}u=l|0;v=c[(c[s>>2]|0)+32>>2]|0;gJ[v&31](t,n,m,u)|0;t=l+o|0;if((p|0)==(m|0)){w=t;x=e|0;y=c[x>>2]|0;gCl(b,y,u,w,t,f,g);i=d;return}w=l+(p-k)|0;x=e|0;y=c[x>>2]|0;gCl(b,y,u,w,t,f,g);i=d;return}}while(0);d=f_(4)|0;c[d>>2]=619800;eh(d|0,625536,1e3)}function gCu(a){a=a|0;if((a|0)==0){return}gGr(a);return}function gCv(a){a=a|0;return}function gCw(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;j=i;i=i+40|0;k=e;e=i;i=i+4|0;i=i+7&-8;c[e>>2]=c[k>>2];k=j|0;l=j+16|0;m=j+24|0;if((c[f+4>>2]&1|0)==0){n=c[(c[d>>2]|0)+24>>2]|0;c[l>>2]=c[e>>2];gB[n&127](b,d,l,f,g,h&1);i=j;return}g=c[f+28>>2]|0;f=g+4|0;I=c[f>>2]|0,c[f>>2]=I+1,I;if((c[2384962]|0)!=-1){c[k>>2]=9539848;c[k+4>>2]=180;c[k+8>>2]=0;gAp(9539848,k)}k=(c[2384963]|0)-1|0;l=c[g+8>>2]|0;do{if((c[g+12>>2]|0)-l>>2>>>0>k>>>0){d=c[l+(k<<2)>>2]|0;if((d|0)==0){break}n=d;if(((I=c[f>>2]|0,c[f>>2]=I+ -1,I)|0)==0){gf[c[(c[g>>2]|0)+8>>2]&2047](g)}o=c[d>>2]|0;if(h){gg[c[o+24>>2]&4095](m,n)}else{gg[c[o+28>>2]&4095](m,n)}n=m;o=a[n]|0;if((o&1)==0){d=m+4|0;p=d;q=d;r=m+8|0}else{d=m+8|0;p=c[d>>2]|0;q=m+4|0;r=d}d=e|0;s=p;t=o;while(1){u=(t&1)==0;if(u){v=q}else{v=c[r>>2]|0}o=t&255;if((o&1|0)==0){w=o>>>1}else{w=c[q>>2]|0}if((s|0)==(v+(w<<2)|0)){break}o=c[s>>2]|0;x=c[d>>2]|0;do{if((x|0)!=0){y=x+24|0;z=c[y>>2]|0;if((z|0)==(c[x+28>>2]|0)){A=gA[c[(c[x>>2]|0)+52>>2]&16383](x,o)|0}else{c[y>>2]=z+4;c[z>>2]=o;A=o}if((A|0)!=-1){break}c[d>>2]=0}}while(0);s=s+4|0;t=a[n]|0}c[b>>2]=c[d>>2];if(u){i=j;return}n=c[m+8>>2]|0;if((n|0)==0){i=j;return}gGr(n);i=j;return}}while(0);j=f_(4)|0;c[j>>2]=619800;eh(j|0,625536,1e3)}function gCx(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;d=i;i=i+136|0;j=e;e=i;i=i+4|0;i=i+7&-8;c[e>>2]=c[j>>2];j=d|0;k=d+8|0;l=d+24|0;m=d+112|0;n=d+120|0;o=d+128|0;p=j|0;a[p]=a[591144]|0;a[p+1|0]=a[591145]|0;a[p+2|0]=a[591146]|0;a[p+3|0]=a[591147]|0;a[p+4|0]=a[591148]|0;a[p+5|0]=a[591149]|0;q=j+1|0;r=f+4|0;s=c[r>>2]|0;if((s&2048|0)==0){t=q}else{a[q]=43;t=j+2|0}if((s&512|0)==0){u=t}else{a[t]=35;u=t+1|0}a[u]=108;t=u+1|0;u=s&74;do{if((u|0)==8){if((s&16384|0)==0){a[t]=120;break}else{a[t]=88;break}}else if((u|0)==64){a[t]=111}else{a[t]=100}}while(0);t=k|0;do{if((a[14125e3]|0)==0){if((bp(14125e3)|0)==0){break}c[2384150]=e6(2147483647,485280,0)|0}}while(0);u=gCj(t,12,c[2384150]|0,p,(p=i,i=i+8|0,c[p>>2]=h,p)|0)|0;i=p;p=k+u|0;h=c[r>>2]&176;do{if((h|0)==16){r=a[t]|0;if((r<<24>>24|0)==45|(r<<24>>24|0)==43){v=k+1|0;break}if(!((u|0)>1&r<<24>>24==48)){w=9680;break}r=a[k+1|0]|0;if(!((r<<24>>24|0)==120|(r<<24>>24|0)==88)){w=9680;break}v=k+2|0}else if((h|0)==32){v=p}else{w=9680}}while(0);if((w|0)==9680){v=t}w=l|0;l=o|0;h=c[f+28>>2]|0;c[l>>2]=h;k=h+4|0;I=c[k>>2]|0,c[k>>2]=I+1,I;gCy(t,v,p,w,m,n,o);o=c[l>>2]|0;l=o+4|0;if(((I=c[l>>2]|0,c[l>>2]=I+ -1,I)|0)!=0){x=e|0;y=c[x>>2]|0;z=c[m>>2]|0;A=c[n>>2]|0;gCz(b,y,w,z,A,f,g);i=d;return}gf[c[(c[o>>2]|0)+8>>2]&2047](o|0);x=e|0;y=c[x>>2]|0;z=c[m>>2]|0;A=c[n>>2]|0;gCz(b,y,w,z,A,f,g);i=d;return}function gCy(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;l=i;i=i+48|0;m=l|0;n=l+16|0;o=l+32|0;p=k|0;k=c[p>>2]|0;if((c[2385058]|0)!=-1){c[n>>2]=9540232;c[n+4>>2]=180;c[n+8>>2]=0;gAp(9540232,n)}n=(c[2385059]|0)-1|0;q=c[k+8>>2]|0;if((c[k+12>>2]|0)-q>>2>>>0<=n>>>0){r=f_(4)|0;s=r;c[s>>2]=619800;eh(r|0,625536,1e3)}k=c[q+(n<<2)>>2]|0;if((k|0)==0){r=f_(4)|0;s=r;c[s>>2]=619800;eh(r|0,625536,1e3)}r=k;s=c[p>>2]|0;if((c[2384962]|0)!=-1){c[m>>2]=9539848;c[m+4>>2]=180;c[m+8>>2]=0;gAp(9539848,m)}m=(c[2384963]|0)-1|0;p=c[s+8>>2]|0;if((c[s+12>>2]|0)-p>>2>>>0<=m>>>0){t=f_(4)|0;u=t;c[u>>2]=619800;eh(t|0,625536,1e3)}s=c[p+(m<<2)>>2]|0;if((s|0)==0){t=f_(4)|0;u=t;c[u>>2]=619800;eh(t|0,625536,1e3)}t=s;gg[c[(c[s>>2]|0)+20>>2]&4095](o,t);u=o;m=o;p=d[m]|0;if((p&1|0)==0){v=p>>>1}else{v=c[o+4>>2]|0}do{if((v|0)==0){p=c[(c[k>>2]|0)+48>>2]|0;gJ[p&31](r,b,f,g)|0;c[j>>2]=g+(f-b<<2)}else{c[j>>2]=g;p=a[b]|0;if((p<<24>>24|0)==45|(p<<24>>24|0)==43){n=gA[c[(c[k>>2]|0)+44>>2]&16383](r,p)|0;p=c[j>>2]|0;c[j>>2]=p+4;c[p>>2]=n;w=b+1|0}else{w=b}do{if((f-w|0)>1){if((a[w]|0)!=48){x=w;break}n=w+1|0;p=a[n]|0;if(!((p<<24>>24|0)==120|(p<<24>>24|0)==88)){x=w;break}p=k;q=gA[c[(c[p>>2]|0)+44>>2]&16383](r,48)|0;y=c[j>>2]|0;c[j>>2]=y+4;c[y>>2]=q;q=gA[c[(c[p>>2]|0)+44>>2]&16383](r,a[n]|0)|0;n=c[j>>2]|0;c[j>>2]=n+4;c[n>>2]=q;x=w+2|0}else{x=w}}while(0);do{if((x|0)!=(f|0)){q=f-1|0;if(x>>>0<q>>>0){z=x;A=q}else{break}do{q=a[z]|0;a[z]=a[A]|0;a[A]=q;z=z+1|0;A=A-1|0;}while(z>>>0<A>>>0)}}while(0);q=gj[c[(c[s>>2]|0)+16>>2]&4095](t)|0;if(x>>>0<f>>>0){n=u+1|0;p=k;y=o+4|0;B=o+8|0;C=0;D=0;E=x;while(1){F=a[((a[m]&1)==0?n:c[B>>2]|0)+D|0]|0;if(F<<24>>24!=0&(C|0)==(F<<24>>24|0)){F=c[j>>2]|0;c[j>>2]=F+4;c[F>>2]=q;F=d[m]|0;G=(D>>>0<(((F&1|0)==0?F>>>1:c[y>>2]|0)-1|0)>>>0)+D|0;H=0}else{G=D;H=C}F=gA[c[(c[p>>2]|0)+44>>2]&16383](r,a[E]|0)|0;I=c[j>>2]|0;c[j>>2]=I+4;c[I>>2]=F;F=E+1|0;if(F>>>0<f>>>0){C=H+1|0;D=G;E=F}else{break}}}E=g+(x-b<<2)|0;D=c[j>>2]|0;if((E|0)==(D|0)){break}C=D-4|0;if(E>>>0<C>>>0){J=E;K=C}else{break}do{C=c[J>>2]|0;c[J>>2]=c[K>>2];c[K>>2]=C;J=J+4|0;K=K-4|0;}while(J>>>0<K>>>0)}}while(0);if((e|0)==(f|0)){L=c[j>>2]|0}else{L=g+(e-b<<2)|0}c[h>>2]=L;if((a[m]&1)==0){i=l;return}m=c[o+8>>2]|0;if((m|0)==0){i=l;return}gGr(m);i=l;return}function gCz(b,d,e,f,g,h,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;k=i;i=i+16|0;l=k|0;if((d|0)==0){c[b>>2]=0;i=k;return}m=g;g=e;n=m-g>>2;o=h+12|0;h=c[o>>2]|0;p=(h|0)>(n|0)?h-n|0:0;n=f;h=n-g|0;g=h>>2;do{if((h|0)>0){if((gp[c[(c[d>>2]|0)+48>>2]&16383](d,e,g)|0)==(g|0)){break}c[b>>2]=0;i=k;return}}while(0);do{if((p|0)>0){if(p>>>0>1073741807){gAq()}do{if(p>>>0<2){a[l]=p<<1&255;q=1;r=l+4|0}else{g=p+4&-4;e=g<<2;h=(e|0)==0?1:e;while(1){s=gGq(h)|0;if((s|0)!=0){t=9769;break}e=(I=c[2439328]|0,c[2439328]=I+0,I);if((e|0)==0){break}gu[e&16383]()}if((t|0)==9769){h=s;c[l+8>>2]=h;c[l>>2]=g|1;c[l+4>>2]=p;q=p;r=h;break}h=f_(4)|0;c[h>>2]=619768;eh(h|0,625520,1206)}}while(0);h=q;e=r;while(1){u=h-1|0;c[e>>2]=j;if((u|0)==0){break}else{h=u;e=e+4|0}}c[r+(p<<2)>>2]=0;e=l;if((a[e]&1)==0){v=l+4|0}else{v=c[l+8>>2]|0}if((gp[c[(c[d>>2]|0)+48>>2]&16383](d,v,p)|0)==(p|0)){if((a[e]&1)==0){break}h=c[l+8>>2]|0;if((h|0)==0){break}gGr(h);break}c[b>>2]=0;if((a[e]&1)==0){i=k;return}e=c[l+8>>2]|0;if((e|0)==0){i=k;return}gGr(e);i=k;return}}while(0);l=m-n|0;n=l>>2;do{if((l|0)>0){if((gp[c[(c[d>>2]|0)+48>>2]&16383](d,f,n)|0)==(n|0)){break}c[b>>2]=0;i=k;return}}while(0);c[o>>2]=0;c[b>>2]=d;i=k;return}function gCA(b,d,e,f,g,h,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;d=i;i=i+224|0;k=e;e=i;i=i+4|0;i=i+7&-8;c[e>>2]=c[k>>2];k=d|0;l=d+8|0;m=d+32|0;n=d+200|0;o=d+208|0;p=d+216|0;c[k>>2]=37;c[k+4>>2]=0;q=k;k=q+1|0;r=f+4|0;s=c[r>>2]|0;if((s&2048|0)==0){t=k}else{a[k]=43;t=q+2|0}if((s&512|0)==0){u=t}else{a[t]=35;u=t+1|0}a[u]=108;a[u+1|0]=108;t=u+2|0;u=s&74;do{if((u|0)==8){if((s&16384|0)==0){a[t]=120;break}else{a[t]=88;break}}else if((u|0)==64){a[t]=111}else{a[t]=100}}while(0);t=l|0;do{if((a[14125e3]|0)==0){if((bp(14125e3)|0)==0){break}c[2384150]=e6(2147483647,485280,0)|0}}while(0);u=gCj(t,22,c[2384150]|0,q,(q=i,i=i+16|0,c[q>>2]=h,c[q+8>>2]=j,q)|0)|0;i=q;q=l+u|0;j=c[r>>2]&176;do{if((j|0)==32){v=q}else if((j|0)==16){r=a[t]|0;if((r<<24>>24|0)==45|(r<<24>>24|0)==43){v=l+1|0;break}if(!((u|0)>1&r<<24>>24==48)){w=9820;break}r=a[l+1|0]|0;if(!((r<<24>>24|0)==120|(r<<24>>24|0)==88)){w=9820;break}v=l+2|0}else{w=9820}}while(0);if((w|0)==9820){v=t}w=m|0;m=p|0;l=c[f+28>>2]|0;c[m>>2]=l;u=l+4|0;I=c[u>>2]|0,c[u>>2]=I+1,I;gCy(t,v,q,w,n,o,p);p=c[m>>2]|0;m=p+4|0;if(((I=c[m>>2]|0,c[m>>2]=I+ -1,I)|0)!=0){x=e|0;y=c[x>>2]|0;z=c[n>>2]|0;A=c[o>>2]|0;gCz(b,y,w,z,A,f,g);i=d;return}gf[c[(c[p>>2]|0)+8>>2]&2047](p|0);x=e|0;y=c[x>>2]|0;z=c[n>>2]|0;A=c[o>>2]|0;gCz(b,y,w,z,A,f,g);i=d;return}function gCB(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;d=i;i=i+136|0;j=e;e=i;i=i+4|0;i=i+7&-8;c[e>>2]=c[j>>2];j=d|0;k=d+8|0;l=d+24|0;m=d+112|0;n=d+120|0;o=d+128|0;p=j|0;a[p]=a[591144]|0;a[p+1|0]=a[591145]|0;a[p+2|0]=a[591146]|0;a[p+3|0]=a[591147]|0;a[p+4|0]=a[591148]|0;a[p+5|0]=a[591149]|0;q=j+1|0;r=f+4|0;s=c[r>>2]|0;if((s&2048|0)==0){t=q}else{a[q]=43;t=j+2|0}if((s&512|0)==0){u=t}else{a[t]=35;u=t+1|0}a[u]=108;t=u+1|0;u=s&74;do{if((u|0)==8){if((s&16384|0)==0){a[t]=120;break}else{a[t]=88;break}}else if((u|0)==64){a[t]=111}else{a[t]=117}}while(0);t=k|0;do{if((a[14125e3]|0)==0){if((bp(14125e3)|0)==0){break}c[2384150]=e6(2147483647,485280,0)|0}}while(0);u=gCj(t,12,c[2384150]|0,p,(p=i,i=i+8|0,c[p>>2]=h,p)|0)|0;i=p;p=k+u|0;h=c[r>>2]&176;do{if((h|0)==16){r=a[t]|0;if((r<<24>>24|0)==45|(r<<24>>24|0)==43){v=k+1|0;break}if(!((u|0)>1&r<<24>>24==48)){w=9851;break}r=a[k+1|0]|0;if(!((r<<24>>24|0)==120|(r<<24>>24|0)==88)){w=9851;break}v=k+2|0}else if((h|0)==32){v=p}else{w=9851}}while(0);if((w|0)==9851){v=t}w=l|0;l=o|0;h=c[f+28>>2]|0;c[l>>2]=h;k=h+4|0;I=c[k>>2]|0,c[k>>2]=I+1,I;gCy(t,v,p,w,m,n,o);o=c[l>>2]|0;l=o+4|0;if(((I=c[l>>2]|0,c[l>>2]=I+ -1,I)|0)!=0){x=e|0;y=c[x>>2]|0;z=c[m>>2]|0;A=c[n>>2]|0;gCz(b,y,w,z,A,f,g);i=d;return}gf[c[(c[o>>2]|0)+8>>2]&2047](o|0);x=e|0;y=c[x>>2]|0;z=c[m>>2]|0;A=c[n>>2]|0;gCz(b,y,w,z,A,f,g);i=d;return}function gCC(b,d,e,f,g,h,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;d=i;i=i+232|0;k=e;e=i;i=i+4|0;i=i+7&-8;c[e>>2]=c[k>>2];k=d|0;l=d+8|0;m=d+32|0;n=d+208|0;o=d+216|0;p=d+224|0;c[k>>2]=37;c[k+4>>2]=0;q=k;k=q+1|0;r=f+4|0;s=c[r>>2]|0;if((s&2048|0)==0){t=k}else{a[k]=43;t=q+2|0}if((s&512|0)==0){u=t}else{a[t]=35;u=t+1|0}a[u]=108;a[u+1|0]=108;t=u+2|0;u=s&74;do{if((u|0)==64){a[t]=111}else if((u|0)==8){if((s&16384|0)==0){a[t]=120;break}else{a[t]=88;break}}else{a[t]=117}}while(0);t=l|0;do{if((a[14125e3]|0)==0){if((bp(14125e3)|0)==0){break}c[2384150]=e6(2147483647,485280,0)|0}}while(0);s=gCj(t,23,c[2384150]|0,q,(q=i,i=i+16|0,c[q>>2]=h,c[q+8>>2]=j,q)|0)|0;i=q;q=l+s|0;j=c[r>>2]&176;do{if((j|0)==32){v=q}else if((j|0)==16){r=a[t]|0;if((r<<24>>24|0)==45|(r<<24>>24|0)==43){v=l+1|0;break}if(!((s|0)>1&r<<24>>24==48)){w=9882;break}r=a[l+1|0]|0;if(!((r<<24>>24|0)==120|(r<<24>>24|0)==88)){w=9882;break}v=l+2|0}else{w=9882}}while(0);if((w|0)==9882){v=t}w=m|0;m=p|0;l=c[f+28>>2]|0;c[m>>2]=l;s=l+4|0;I=c[s>>2]|0,c[s>>2]=I+1,I;gCy(t,v,q,w,n,o,p);p=c[m>>2]|0;m=p+4|0;if(((I=c[m>>2]|0,c[m>>2]=I+ -1,I)|0)!=0){x=e|0;y=c[x>>2]|0;z=c[n>>2]|0;A=c[o>>2]|0;gCz(b,y,w,z,A,f,g);i=d;return}gf[c[(c[p>>2]|0)+8>>2]&2047](p|0);x=e|0;y=c[x>>2]|0;z=c[n>>2]|0;A=c[o>>2]|0;gCz(b,y,w,z,A,f,g);i=d;return}function gCD(b,d,e,f,g,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;j=+j;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,J=0;d=i;i=i+312|0;k=e;e=i;i=i+4|0;i=i+7&-8;c[e>>2]=c[k>>2];k=d|0;l=d+8|0;m=d+40|0;n=d+48|0;o=d+280|0;p=d+288|0;q=d+296|0;r=d+304|0;c[k>>2]=37;c[k+4>>2]=0;s=k;k=s+1|0;t=f+4|0;u=c[t>>2]|0;if((u&2048|0)==0){v=k}else{a[k]=43;v=s+2|0}if((u&1024|0)==0){w=v}else{a[v]=35;w=v+1|0}v=u&260;k=u>>>14;do{if((v|0)==260){if((k&1|0)==0){a[w]=97;x=0;break}else{a[w]=65;x=0;break}}else{a[w]=46;u=w+2|0;a[w+1|0]=42;if((v|0)==256){if((k&1|0)==0){a[u]=101;x=1;break}else{a[u]=69;x=1;break}}else if((v|0)==4){if((k&1|0)==0){a[u]=102;x=1;break}else{a[u]=70;x=1;break}}else{if((k&1|0)==0){a[u]=103;x=1;break}else{a[u]=71;x=1;break}}}}while(0);k=l|0;c[m>>2]=k;do{if((a[14125e3]|0)==0){if((bp(14125e3)|0)==0){break}c[2384150]=e6(2147483647,485280,0)|0}}while(0);l=c[2384150]|0;if(x){v=gCj(k,30,l,s,(y=i,i=i+16|0,c[y>>2]=c[f+8>>2],h[y+8>>3]=j,y)|0)|0;i=y;z=v}else{v=gCj(k,30,l,s,(y=i,i=i+8|0,h[y>>3]=j,y)|0)|0;i=y;z=v}do{if((z|0)>29){v=(a[14125e3]|0)==0;if(x){do{if(v){if((bp(14125e3)|0)==0){break}c[2384150]=e6(2147483647,485280,0)|0}}while(0);l=gCq(m,c[2384150]|0,s,(y=i,i=i+16|0,c[y>>2]=c[f+8>>2],h[y+8>>3]=j,y)|0)|0;i=y;A=l}else{do{if(v){if((bp(14125e3)|0)==0){break}c[2384150]=e6(2147483647,485280,0)|0}}while(0);v=gCq(m,c[2384150]|0,s,(y=i,i=i+16|0,c[y>>2]=c[f+8>>2],h[y+8>>3]=j,y)|0)|0;i=y;A=v}v=c[m>>2]|0;if((v|0)!=0){B=A;C=v;D=v;break}v=f_(4)|0;c[v>>2]=619768;eh(v|0,625520,1206)}else{B=z;C=0;D=c[m>>2]|0}}while(0);m=D+B|0;z=c[t>>2]&176;do{if((z|0)==16){t=a[D]|0;if((t<<24>>24|0)==45|(t<<24>>24|0)==43){E=D+1|0;break}if(!((B|0)>1&t<<24>>24==48)){F=9944;break}t=a[D+1|0]|0;if(!((t<<24>>24|0)==120|(t<<24>>24|0)==88)){F=9944;break}E=D+2|0}else if((z|0)==32){E=m}else{F=9944}}while(0);if((F|0)==9944){E=D}do{if((D|0)==(k|0)){G=n|0;H=0;J=k}else{F=gGq(B<<3)|0;z=F;if((F|0)!=0){G=z;H=z;J=D;break}z=f_(4)|0;c[z>>2]=619768;eh(z|0,625520,1206)}}while(0);D=q|0;B=c[f+28>>2]|0;c[D>>2]=B;k=B+4|0;I=c[k>>2]|0,c[k>>2]=I+1,I;gCE(J,E,m,G,o,p,q);q=c[D>>2]|0;D=q+4|0;if(((I=c[D>>2]|0,c[D>>2]=I+ -1,I)|0)==0){gf[c[(c[q>>2]|0)+8>>2]&2047](q|0)}q=e|0;gCz(r,c[q>>2]|0,G,c[o>>2]|0,c[p>>2]|0,f,g);g=c[r>>2]|0;c[q>>2]=g;c[b>>2]=g;if((H|0)!=0){gGr(H)}if((C|0)==0){i=d;return}gGr(C);i=d;return}function gCE(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;l=i;i=i+48|0;m=l|0;n=l+16|0;o=l+32|0;p=k|0;k=c[p>>2]|0;if((c[2385058]|0)!=-1){c[n>>2]=9540232;c[n+4>>2]=180;c[n+8>>2]=0;gAp(9540232,n)}n=(c[2385059]|0)-1|0;q=c[k+8>>2]|0;if((c[k+12>>2]|0)-q>>2>>>0<=n>>>0){r=f_(4)|0;s=r;c[s>>2]=619800;eh(r|0,625536,1e3)}k=c[q+(n<<2)>>2]|0;if((k|0)==0){r=f_(4)|0;s=r;c[s>>2]=619800;eh(r|0,625536,1e3)}r=k;s=c[p>>2]|0;if((c[2384962]|0)!=-1){c[m>>2]=9539848;c[m+4>>2]=180;c[m+8>>2]=0;gAp(9539848,m)}m=(c[2384963]|0)-1|0;p=c[s+8>>2]|0;if((c[s+12>>2]|0)-p>>2>>>0<=m>>>0){t=f_(4)|0;u=t;c[u>>2]=619800;eh(t|0,625536,1e3)}s=c[p+(m<<2)>>2]|0;if((s|0)==0){t=f_(4)|0;u=t;c[u>>2]=619800;eh(t|0,625536,1e3)}t=s;gg[c[(c[s>>2]|0)+20>>2]&4095](o,t);c[j>>2]=g;u=a[b]|0;if((u<<24>>24|0)==45|(u<<24>>24|0)==43){m=gA[c[(c[k>>2]|0)+44>>2]&16383](r,u)|0;u=c[j>>2]|0;c[j>>2]=u+4;c[u>>2]=m;v=b+1|0}else{v=b}m=f;L11524:do{if((m-v|0)>1){if((a[v]|0)!=48){w=v;x=10004;break}u=v+1|0;p=a[u]|0;if(!((p<<24>>24|0)==120|(p<<24>>24|0)==88)){w=v;x=10004;break}p=k;n=gA[c[(c[p>>2]|0)+44>>2]&16383](r,48)|0;q=c[j>>2]|0;c[j>>2]=q+4;c[q>>2]=n;n=v+2|0;q=gA[c[(c[p>>2]|0)+44>>2]&16383](r,a[u]|0)|0;u=c[j>>2]|0;c[j>>2]=u+4;c[u>>2]=q;q=n;while(1){if(q>>>0>=f>>>0){y=q;z=n;break L11524}u=a[q]|0;do{if((a[14125e3]|0)==0){if((bp(14125e3)|0)==0){break}c[2384150]=e6(2147483647,485280,0)|0}}while(0);if((fk(u<<24>>24|0,c[2384150]|0)|0)==0){y=q;z=n;break}else{q=q+1|0}}}else{w=v;x=10004}}while(0);L11539:do{if((x|0)==10004){while(1){x=0;if(w>>>0>=f>>>0){y=w;z=v;break L11539}q=a[w]|0;do{if((a[14125e3]|0)==0){if((bp(14125e3)|0)==0){break}c[2384150]=e6(2147483647,485280,0)|0}}while(0);if((fV(q<<24>>24|0,c[2384150]|0)|0)==0){y=w;z=v;break}else{w=w+1|0;x=10004}}}}while(0);x=o;w=o;v=d[w]|0;if((v&1|0)==0){A=v>>>1}else{A=c[o+4>>2]|0}do{if((A|0)==0){v=c[j>>2]|0;u=c[(c[k>>2]|0)+48>>2]|0;gJ[u&31](r,z,y,v)|0;c[j>>2]=(c[j>>2]|0)+(y-z<<2)}else{do{if((z|0)!=(y|0)){v=y-1|0;if(z>>>0<v>>>0){B=z;C=v}else{break}do{v=a[B]|0;a[B]=a[C]|0;a[C]=v;B=B+1|0;C=C-1|0;}while(B>>>0<C>>>0)}}while(0);q=gj[c[(c[s>>2]|0)+16>>2]&4095](t)|0;if(z>>>0<y>>>0){v=x+1|0;u=o+4|0;n=o+8|0;p=k;D=0;E=0;F=z;while(1){G=a[((a[w]&1)==0?v:c[n>>2]|0)+E|0]|0;if(G<<24>>24>0&(D|0)==(G<<24>>24|0)){G=c[j>>2]|0;c[j>>2]=G+4;c[G>>2]=q;G=d[w]|0;H=(E>>>0<(((G&1|0)==0?G>>>1:c[u>>2]|0)-1|0)>>>0)+E|0;I=0}else{H=E;I=D}G=gA[c[(c[p>>2]|0)+44>>2]&16383](r,a[F]|0)|0;J=c[j>>2]|0;c[j>>2]=J+4;c[J>>2]=G;G=F+1|0;if(G>>>0<y>>>0){D=I+1|0;E=H;F=G}else{break}}}F=g+(z-b<<2)|0;E=c[j>>2]|0;if((F|0)==(E|0)){break}D=E-4|0;if(F>>>0<D>>>0){K=F;L=D}else{break}do{D=c[K>>2]|0;c[K>>2]=c[L>>2];c[L>>2]=D;K=K+4|0;L=L-4|0;}while(K>>>0<L>>>0)}}while(0);L11577:do{if(y>>>0<f>>>0){L=k;K=y;while(1){z=a[K]|0;if(z<<24>>24==46){break}H=gA[c[(c[L>>2]|0)+44>>2]&16383](r,z)|0;z=c[j>>2]|0;c[j>>2]=z+4;c[z>>2]=H;H=K+1|0;if(H>>>0<f>>>0){K=H}else{M=H;break L11577}}L=gj[c[(c[s>>2]|0)+12>>2]&4095](t)|0;H=c[j>>2]|0;c[j>>2]=H+4;c[H>>2]=L;M=K+1|0}else{M=y}}while(0);gJ[c[(c[k>>2]|0)+48>>2]&31](r,M,f,c[j>>2]|0)|0;r=(c[j>>2]|0)+(m-M<<2)|0;c[j>>2]=r;if((e|0)==(f|0)){N=r}else{N=g+(e-b<<2)|0}c[h>>2]=N;if((a[w]&1)==0){i=l;return}w=c[o+8>>2]|0;if((w|0)==0){i=l;return}gGr(w);i=l;return}function gCF(b,d,e,f,g,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;j=+j;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,J=0;d=i;i=i+312|0;k=e;e=i;i=i+4|0;i=i+7&-8;c[e>>2]=c[k>>2];k=d|0;l=d+8|0;m=d+40|0;n=d+48|0;o=d+280|0;p=d+288|0;q=d+296|0;r=d+304|0;c[k>>2]=37;c[k+4>>2]=0;s=k;k=s+1|0;t=f+4|0;u=c[t>>2]|0;if((u&2048|0)==0){v=k}else{a[k]=43;v=s+2|0}if((u&1024|0)==0){w=v}else{a[v]=35;w=v+1|0}v=u&260;k=u>>>14;do{if((v|0)==260){a[w]=76;u=w+1|0;if((k&1|0)==0){a[u]=97;x=0;break}else{a[u]=65;x=0;break}}else{a[w]=46;a[w+1|0]=42;a[w+2|0]=76;u=w+3|0;if((v|0)==4){if((k&1|0)==0){a[u]=102;x=1;break}else{a[u]=70;x=1;break}}else if((v|0)==256){if((k&1|0)==0){a[u]=101;x=1;break}else{a[u]=69;x=1;break}}else{if((k&1|0)==0){a[u]=103;x=1;break}else{a[u]=71;x=1;break}}}}while(0);k=l|0;c[m>>2]=k;do{if((a[14125e3]|0)==0){if((bp(14125e3)|0)==0){break}c[2384150]=e6(2147483647,485280,0)|0}}while(0);l=c[2384150]|0;if(x){v=gCj(k,30,l,s,(y=i,i=i+16|0,c[y>>2]=c[f+8>>2],h[y+8>>3]=j,y)|0)|0;i=y;z=v}else{v=gCj(k,30,l,s,(y=i,i=i+8|0,h[y>>3]=j,y)|0)|0;i=y;z=v}do{if((z|0)>29){v=(a[14125e3]|0)==0;if(x){do{if(v){if((bp(14125e3)|0)==0){break}c[2384150]=e6(2147483647,485280,0)|0}}while(0);l=gCq(m,c[2384150]|0,s,(y=i,i=i+16|0,c[y>>2]=c[f+8>>2],h[y+8>>3]=j,y)|0)|0;i=y;A=l}else{do{if(v){if((bp(14125e3)|0)==0){break}c[2384150]=e6(2147483647,485280,0)|0}}while(0);v=gCq(m,c[2384150]|0,s,(y=i,i=i+8|0,h[y>>3]=j,y)|0)|0;i=y;A=v}v=c[m>>2]|0;if((v|0)!=0){B=A;C=v;D=v;break}v=f_(4)|0;c[v>>2]=619768;eh(v|0,625520,1206)}else{B=z;C=0;D=c[m>>2]|0}}while(0);m=D+B|0;z=c[t>>2]&176;do{if((z|0)==16){t=a[D]|0;if((t<<24>>24|0)==45|(t<<24>>24|0)==43){E=D+1|0;break}if(!((B|0)>1&t<<24>>24==48)){F=10104;break}t=a[D+1|0]|0;if(!((t<<24>>24|0)==120|(t<<24>>24|0)==88)){F=10104;break}E=D+2|0}else if((z|0)==32){E=m}else{F=10104}}while(0);if((F|0)==10104){E=D}do{if((D|0)==(k|0)){G=n|0;H=0;J=k}else{F=gGq(B<<3)|0;z=F;if((F|0)!=0){G=z;H=z;J=D;break}z=f_(4)|0;c[z>>2]=619768;eh(z|0,625520,1206)}}while(0);D=q|0;B=c[f+28>>2]|0;c[D>>2]=B;k=B+4|0;I=c[k>>2]|0,c[k>>2]=I+1,I;gCE(J,E,m,G,o,p,q);q=c[D>>2]|0;D=q+4|0;if(((I=c[D>>2]|0,c[D>>2]=I+ -1,I)|0)==0){gf[c[(c[q>>2]|0)+8>>2]&2047](q|0)}q=e|0;gCz(r,c[q>>2]|0,G,c[o>>2]|0,c[p>>2]|0,f,g);g=c[r>>2]|0;c[q>>2]=g;c[b>>2]=g;if((H|0)!=0){gGr(H)}if((C|0)==0){i=d;return}gGr(C);i=d;return}function gCG(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;d=i;i=i+200|0;j=e;e=i;i=i+4|0;i=i+7&-8;c[e>>2]=c[j>>2];j=d|0;k=d+24|0;l=d+48|0;m=d+16|0;a[m]=a[591152]|0;a[m+1|0]=a[591153]|0;a[m+2|0]=a[591154]|0;a[m+3|0]=a[591155]|0;a[m+4|0]=a[591156]|0;a[m+5|0]=a[591157]|0;n=k|0;do{if((a[14125e3]|0)==0){if((bp(14125e3)|0)==0){break}c[2384150]=e6(2147483647,485280,0)|0}}while(0);o=gCj(n,20,c[2384150]|0,m,(m=i,i=i+8|0,c[m>>2]=h,m)|0)|0;i=m;m=k+o|0;h=c[f+4>>2]&176;do{if((h|0)==32){p=m}else if((h|0)==16){q=a[n]|0;if((q<<24>>24|0)==45|(q<<24>>24|0)==43){p=k+1|0;break}if(!((o|0)>1&q<<24>>24==48)){r=10139;break}q=a[k+1|0]|0;if(!((q<<24>>24|0)==120|(q<<24>>24|0)==88)){r=10139;break}p=k+2|0}else{r=10139}}while(0);if((r|0)==10139){p=n}r=c[f+28>>2]|0;h=r+4|0;I=c[h>>2]|0,c[h>>2]=I+1,I;if((c[2385058]|0)!=-1){c[j>>2]=9540232;c[j+4>>2]=180;c[j+8>>2]=0;gAp(9540232,j)}j=(c[2385059]|0)-1|0;q=c[r+8>>2]|0;do{if((c[r+12>>2]|0)-q>>2>>>0>j>>>0){s=c[q+(j<<2)>>2]|0;if((s|0)==0){break}t=s;if(((I=c[h>>2]|0,c[h>>2]=I+ -1,I)|0)==0){gf[c[(c[r>>2]|0)+8>>2]&2047](r)}u=l|0;v=c[(c[s>>2]|0)+48>>2]|0;gJ[v&31](t,n,m,u)|0;t=l+(o<<2)|0;if((p|0)==(m|0)){w=t;x=e|0;y=c[x>>2]|0;gCz(b,y,u,w,t,f,g);i=d;return}w=l+(p-k<<2)|0;x=e|0;y=c[x>>2]|0;gCz(b,y,u,w,t,f,g);i=d;return}}while(0);d=f_(4)|0;c[d>>2]=619800;eh(d|0,625536,1e3)}function gCH(d,e,f,g,h,j,k,l,m){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0;n=i;i=i+40|0;o=n|0;p=n+16|0;q=n+24|0;r=n+32|0;s=c[h+28>>2]|0;t=s+4|0;I=c[t>>2]|0,c[t>>2]=I+1,I;if((c[2385060]|0)!=-1){c[o>>2]=9540240;c[o+4>>2]=180;c[o+8>>2]=0;gAp(9540240,o)}o=(c[2385061]|0)-1|0;u=c[s+8>>2]|0;do{if((c[s+12>>2]|0)-u>>2>>>0>o>>>0){v=c[u+(o<<2)>>2]|0;if((v|0)==0){break}w=v;if(((I=c[t>>2]|0,c[t>>2]=I+ -1,I)|0)==0){gf[c[(c[s>>2]|0)+8>>2]&2047](s)}c[j>>2]=0;L11721:do{if((l|0)==(m|0)){x=f;y=f;z=g}else{A=v;B=v;C=v+8|0;D=e;E=q|0;F=r|0;G=p|0;H=l;J=f;K=g;L11723:while(1){do{if((J|0)==0){L=0}else{if((c[J+12>>2]|0)!=(c[J+16>>2]|0)){L=J;break}M=(gj[c[(c[J>>2]|0)+36>>2]&4095](J)|0)==-1;L=M?0:J}}while(0);M=(L|0)==0;do{if((K|0)==0){N=10173}else{if((c[K+12>>2]|0)==(c[K+16>>2]|0)){if((gj[c[(c[K>>2]|0)+36>>2]&4095](K)|0)==-1){N=10173;break}}if(M){O=K}else{P=L;Q=K;N=10174;break L11723}}}while(0);if((N|0)==10173){N=0;if(M){P=0;Q=0;N=10174;break}else{O=0}}L11737:do{if((gp[c[(c[A>>2]|0)+36>>2]&16383](w,a[H]|0,0)|0)<<24>>24==37){R=H+1|0;if((R|0)==(m|0)){N=10180;break L11723}S=gp[c[(c[A>>2]|0)+36>>2]&16383](w,a[R]|0,0)|0;if((S<<24>>24|0)==69|(S<<24>>24|0)==48){T=H+2|0;if((T|0)==(m|0)){N=10183;break L11723}U=S;V=gp[c[(c[A>>2]|0)+36>>2]&16383](w,a[T]|0,0)|0;W=T}else{U=0;V=S;W=R}R=c[(c[D>>2]|0)+36>>2]|0;c[E>>2]=L;c[F>>2]=O;gy[R&15](p,e,q,r,h,j,k,V,U);X=W+1|0;Y=c[G>>2]|0;Z=O}else{R=a[H]|0;do{if(R<<24>>24>=0){S=c[C>>2]|0;if((b[S+(R<<24>>24<<1)>>1]&8192)==0){break}else{_=H}while(1){T=_+1|0;if((T|0)==(m|0)){$=m;break}aa=a[T]|0;if(aa<<24>>24<0){$=T;break}if((b[S+(aa<<24>>24<<1)>>1]&8192)==0){$=T;break}else{_=T}}S=L;T=O;aa=L;ab=O;while(1){do{if((S|0)==0){ac=0;ad=aa}else{if((c[S+12>>2]|0)!=(c[S+16>>2]|0)){ac=S;ad=aa;break}ae=(gj[c[(c[S>>2]|0)+36>>2]&4095](S)|0)==-1;ac=ae?0:S;ad=ae?0:aa}}while(0);ae=(ac|0)==0;do{if((T|0)==0){af=ab;N=10201}else{if((c[T+12>>2]|0)!=(c[T+16>>2]|0)){if(ae){ag=T;ah=ab;break}else{X=$;Y=ad;Z=ab;break L11737}}if((gj[c[(c[T>>2]|0)+36>>2]&4095](T)|0)==-1){af=0;N=10201;break}if(ae){ag=T;ah=ab}else{X=$;Y=ad;Z=ab;break L11737}}}while(0);if((N|0)==10201){N=0;if(ae){X=$;Y=ad;Z=af;break L11737}else{ag=0;ah=af}}ai=ac+12|0;aj=c[ai>>2]|0;ak=ac+16|0;if((aj|0)==(c[ak>>2]|0)){al=(gj[c[(c[ac>>2]|0)+36>>2]&4095](ac)|0)&255}else{al=a[aj]|0}if(al<<24>>24<0){X=$;Y=ad;Z=ah;break L11737}if((b[(c[C>>2]|0)+(al<<24>>24<<1)>>1]&8192)==0){X=$;Y=ad;Z=ah;break L11737}aj=c[ai>>2]|0;if((aj|0)==(c[ak>>2]|0)){ak=c[(c[ac>>2]|0)+40>>2]|0;gj[ak&4095](ac)|0;S=ac;T=ag;aa=ad;ab=ah;continue}else{c[ai>>2]=aj+1;S=ac;T=ag;aa=ad;ab=ah;continue}}}}while(0);R=L+12|0;ab=c[R>>2]|0;aa=L+16|0;if((ab|0)==(c[aa>>2]|0)){am=(gj[c[(c[L>>2]|0)+36>>2]&4095](L)|0)&255}else{am=a[ab]|0}ab=gA[c[(c[B>>2]|0)+12>>2]&16383](w,am)|0;if(ab<<24>>24!=(gA[c[(c[B>>2]|0)+12>>2]&16383](w,a[H]|0)|0)<<24>>24){N=10219;break L11723}ab=c[R>>2]|0;if((ab|0)==(c[aa>>2]|0)){aa=c[(c[L>>2]|0)+40>>2]|0;gj[aa&4095](L)|0}else{c[R>>2]=ab+1}X=H+1|0;Y=L;Z=O}}while(0);if((X|0)==(m|0)){x=Y;y=Y;z=Z;break L11721}if((c[j>>2]|0)==0){H=X;J=Y;K=Z}else{x=Y;y=Y;z=Z;break L11721}}if((N|0)==10174){c[j>>2]=4;x=P;y=L;z=Q;break}else if((N|0)==10183){c[j>>2]=4;x=L;y=L;z=O;break}else if((N|0)==10180){c[j>>2]=4;x=L;y=L;z=O;break}else if((N|0)==10219){c[j>>2]=4;x=L;y=L;z=O;break}}}while(0);do{if((x|0)==0){an=y}else{if((c[x+12>>2]|0)!=(c[x+16>>2]|0)){an=y;break}w=(gj[c[(c[x>>2]|0)+36>>2]&4095](x)|0)==-1;an=w?0:y}}while(0);w=(an|0)==0;do{if((z|0)==0){N=10227}else{if((c[z+12>>2]|0)==(c[z+16>>2]|0)){if((gj[c[(c[z>>2]|0)+36>>2]&4095](z)|0)==-1){N=10227;break}}if(!w){break}ao=d|0;c[ao>>2]=an;i=n;return}}while(0);do{if((N|0)==10227){if(w){break}ao=d|0;c[ao>>2]=an;i=n;return}}while(0);c[j>>2]=c[j>>2]|2;ao=d|0;c[ao>>2]=an;i=n;return}}while(0);n=f_(4)|0;c[n>>2]=619800;eh(n|0,625536,1e3)}function gCI(a){a=a|0;if((a|0)==0){return}gGr(a);return}function gCJ(a){a=a|0;return}function gCK(a){a=a|0;return 2}function gCL(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0;j=i;k=d;d=i;i=i+4|0;i=i+7&-8;c[d>>2]=c[k>>2];k=e;e=i;i=i+4|0;i=i+7&-8;c[e>>2]=c[k>>2];gCH(a,b,c[d>>2]|0,c[e>>2]|0,f,g,h,591136,591144);i=j;return}function gCM(b,d,e,f,g,h,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0;k=i;l=e;e=i;i=i+4|0;i=i+7&-8;c[e>>2]=c[l>>2];l=f;f=i;i=i+4|0;i=i+7&-8;c[f>>2]=c[l>>2];l=d+8|0;m=gj[c[(c[l>>2]|0)+20>>2]&4095](l)|0;l=a[m]|0;if((l&1)==0){n=m+1|0}else{n=c[m+8>>2]|0}o=l&255;if((o&1|0)==0){p=o>>>1}else{p=c[m+4>>2]|0}gCH(b,d,c[e>>2]|0,c[f>>2]|0,g,h,j,n,n+p|0);i=k;return}function gCN(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;j=i;i=i+16|0;k=d;d=i;i=i+4|0;i=i+7&-8;c[d>>2]=c[k>>2];k=e;e=i;i=i+4|0;i=i+7&-8;c[e>>2]=c[k>>2];k=j|0;l=c[f+28>>2]|0;f=l+4|0;I=c[f>>2]|0,c[f>>2]=I+1,I;if((c[2385060]|0)!=-1){c[k>>2]=9540240;c[k+4>>2]=180;c[k+8>>2]=0;gAp(9540240,k)}k=(c[2385061]|0)-1|0;m=c[l+8>>2]|0;do{if((c[l+12>>2]|0)-m>>2>>>0>k>>>0){n=c[m+(k<<2)>>2]|0;if((n|0)==0){break}if(((I=c[f>>2]|0,c[f>>2]=I+ -1,I)|0)==0){gf[c[(c[l>>2]|0)+8>>2]&2047](l)}o=c[e>>2]|0;p=b+8|0;q=gj[c[c[p>>2]>>2]&4095](p)|0;p=(gBJ(d,o,q,q+168|0,n,g,0)|0)-q|0;if((p|0)>=168){r=d|0;s=c[r>>2]|0;t=a|0;c[t>>2]=s;i=j;return}c[h+24>>2]=((p|0)/12|0|0)%7|0;r=d|0;s=c[r>>2]|0;t=a|0;c[t>>2]=s;i=j;return}}while(0);j=f_(4)|0;c[j>>2]=619800;eh(j|0,625536,1e3)}function gCO(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;j=i;i=i+16|0;k=d;d=i;i=i+4|0;i=i+7&-8;c[d>>2]=c[k>>2];k=e;e=i;i=i+4|0;i=i+7&-8;c[e>>2]=c[k>>2];k=j|0;l=c[f+28>>2]|0;f=l+4|0;I=c[f>>2]|0,c[f>>2]=I+1,I;if((c[2385060]|0)!=-1){c[k>>2]=9540240;c[k+4>>2]=180;c[k+8>>2]=0;gAp(9540240,k)}k=(c[2385061]|0)-1|0;m=c[l+8>>2]|0;do{if((c[l+12>>2]|0)-m>>2>>>0>k>>>0){n=c[m+(k<<2)>>2]|0;if((n|0)==0){break}if(((I=c[f>>2]|0,c[f>>2]=I+ -1,I)|0)==0){gf[c[(c[l>>2]|0)+8>>2]&2047](l)}o=c[e>>2]|0;p=b+8|0;q=gj[c[(c[p>>2]|0)+4>>2]&4095](p)|0;p=(gBJ(d,o,q,q+288|0,n,g,0)|0)-q|0;if((p|0)>=288){r=d|0;s=c[r>>2]|0;t=a|0;c[t>>2]=s;i=j;return}c[h+16>>2]=((p|0)/12|0|0)%12|0;r=d|0;s=c[r>>2]|0;t=a|0;c[t>>2]=s;i=j;return}}while(0);j=f_(4)|0;c[j>>2]=619800;eh(j|0,625536,1e3)}function gCP(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=i;i=i+16|0;j=d;d=i;i=i+4|0;i=i+7&-8;c[d>>2]=c[j>>2];j=e;e=i;i=i+4|0;i=i+7&-8;c[e>>2]=c[j>>2];j=b|0;k=c[f+28>>2]|0;f=k+4|0;I=c[f>>2]|0,c[f>>2]=I+1,I;if((c[2385060]|0)!=-1){c[j>>2]=9540240;c[j+4>>2]=180;c[j+8>>2]=0;gAp(9540240,j)}j=(c[2385061]|0)-1|0;l=c[k+8>>2]|0;do{if((c[k+12>>2]|0)-l>>2>>>0>j>>>0){m=c[l+(j<<2)>>2]|0;if((m|0)==0){break}if(((I=c[f>>2]|0,c[f>>2]=I+ -1,I)|0)==0){gf[c[(c[k>>2]|0)+8>>2]&2047](k)}n=gCR(d,c[e>>2]|0,g,m,4)|0;if((c[g>>2]&4|0)!=0){o=d|0;p=c[o>>2]|0;q=a|0;c[q>>2]=p;i=b;return}if((n|0)<69){r=n+2e3|0}else{r=(n-69|0)>>>0<31?n+1900|0:n}c[h+20>>2]=r-1900;o=d|0;p=c[o>>2]|0;q=a|0;c[q>>2]=p;i=b;return}}while(0);b=f_(4)|0;c[b>>2]=619800;eh(b|0,625536,1e3)}function gCQ(e,f,g,h,j,k,l,m,n){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;var o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0;n=i;i=i+88|0;o=g;g=i;i=i+4|0;i=i+7&-8;c[g>>2]=c[o>>2];o=h;h=i;i=i+4|0;i=i+7&-8;c[h>>2]=c[o>>2];o=n|0;p=n+16|0;q=n+24|0;r=n+32|0;s=n+40|0;t=n+48|0;u=n+56|0;v=n+64|0;w=n+72|0;x=n+80|0;c[k>>2]=0;y=c[j+28>>2]|0;z=y+4|0;I=c[z>>2]|0,c[z>>2]=I+1,I;if((c[2385060]|0)!=-1){c[o>>2]=9540240;c[o+4>>2]=180;c[o+8>>2]=0;gAp(9540240,o)}o=(c[2385061]|0)-1|0;A=c[y+8>>2]|0;do{if((c[y+12>>2]|0)-A>>2>>>0>o>>>0){B=c[A+(o<<2)>>2]|0;if((B|0)==0){break}C=B;if(((I=c[z>>2]|0,c[z>>2]=I+ -1,I)|0)==0){gf[c[(c[y>>2]|0)+8>>2]&2047](y)}L11890:do{switch(m<<24>>24|0){case 99:{D=f+8|0;E=gj[c[(c[D>>2]|0)+12>>2]&4095](D)|0;D=g|0;F=a[E]|0;if((F&1)==0){G=E+1|0}else{G=c[E+8>>2]|0}H=F&255;if((H&1|0)==0){J=H>>>1}else{J=c[E+4>>2]|0}gCH(p,f,c[D>>2]|0,c[h>>2]|0,j,k,l,G,G+J|0);c[D>>2]=c[p>>2];break};case 98:case 66:case 104:{D=c[h>>2]|0;E=f+8|0;H=gj[c[(c[E>>2]|0)+4>>2]&4095](E)|0;E=(gBJ(g,D,H,H+288|0,C,k,0)|0)-H|0;if((E|0)>=288){break L11890}c[l+16>>2]=((E|0)/12|0|0)%12|0;break};case 114:{E=g|0;gCH(s,f,c[E>>2]|0,c[h>>2]|0,j,k,l,591104,591115);c[E>>2]=c[s>>2];break};case 82:{E=g|0;gCH(t,f,c[E>>2]|0,c[h>>2]|0,j,k,l,591096,591101);c[E>>2]=c[t>>2];break};case 83:{E=gCR(g,c[h>>2]|0,k,C,2)|0;H=c[k>>2]|0;if((H&4|0)==0&(E|0)<61){c[l>>2]=E;break L11890}else{c[k>>2]=H|4;break L11890}break};case 68:{H=g|0;gCH(q,f,c[H>>2]|0,c[h>>2]|0,j,k,l,591128,591136);c[H>>2]=c[q>>2];break};case 84:{H=g|0;gCH(u,f,c[H>>2]|0,c[h>>2]|0,j,k,l,591088,591096);c[H>>2]=c[u>>2];break};case 119:{H=gCR(g,c[h>>2]|0,k,C,1)|0;E=c[k>>2]|0;if((E&4|0)==0&(H|0)<7){c[l+24>>2]=H;break L11890}else{c[k>>2]=E|4;break L11890}break};case 70:{E=g|0;gCH(r,f,c[E>>2]|0,c[h>>2]|0,j,k,l,591120,591128);c[E>>2]=c[r>>2];break};case 73:{E=l+8|0;H=gCR(g,c[h>>2]|0,k,C,2)|0;D=c[k>>2]|0;do{if((D&4|0)==0){if((H-1|0)>>>0>=12){break}c[E>>2]=H;break L11890}}while(0);c[k>>2]=D|4;break};case 97:case 65:{H=c[h>>2]|0;E=f+8|0;F=gj[c[c[E>>2]>>2]&4095](E)|0;E=(gBJ(g,H,F,F+168|0,C,k,0)|0)-F|0;if((E|0)>=168){break L11890}c[l+24>>2]=((E|0)/12|0|0)%7|0;break};case 112:{E=l+8|0;F=c[h>>2]|0;H=f+8|0;K=gj[c[(c[H>>2]|0)+8>>2]&4095](H)|0;H=d[K]|0;if((H&1|0)==0){L=H>>>1}else{L=c[K+4>>2]|0}H=d[K+12|0]|0;if((H&1|0)==0){M=H>>>1}else{M=c[K+16>>2]|0}if((L|0)==(-M|0)){c[k>>2]=c[k>>2]|4;break L11890}H=gBJ(g,F,K,K+24|0,C,k,0)|0;F=H-K|0;do{if((H|0)==(K|0)){if((c[E>>2]|0)!=12){break}c[E>>2]=0;break L11890}}while(0);if((F|0)!=12){break L11890}K=c[E>>2]|0;if((K|0)>=12){break L11890}c[E>>2]=K+12;break};case 120:{K=c[(c[f>>2]|0)+20>>2]|0;c[v>>2]=c[g>>2];c[w>>2]=c[h>>2];gw[K&127](e,f,v,w,j,k,l);i=n;return};case 88:{K=f+8|0;H=gj[c[(c[K>>2]|0)+24>>2]&4095](K)|0;K=g|0;D=a[H]|0;if((D&1)==0){N=H+1|0}else{N=c[H+8>>2]|0}O=D&255;if((O&1|0)==0){P=O>>>1}else{P=c[H+4>>2]|0}gCH(x,f,c[K>>2]|0,c[h>>2]|0,j,k,l,N,N+P|0);c[K>>2]=c[x>>2];break};case 77:{K=gCR(g,c[h>>2]|0,k,C,2)|0;H=c[k>>2]|0;if((H&4|0)==0&(K|0)<60){c[l+4>>2]=K;break L11890}else{c[k>>2]=H|4;break L11890}break};case 109:{H=(gCR(g,c[h>>2]|0,k,C,2)|0)-1|0;K=c[k>>2]|0;if((K&4|0)==0&(H|0)<12){c[l+16>>2]=H;break L11890}else{c[k>>2]=K|4;break L11890}break};case 72:{K=gCR(g,c[h>>2]|0,k,C,2)|0;H=c[k>>2]|0;if((H&4|0)==0&(K|0)<24){c[l+8>>2]=K;break L11890}else{c[k>>2]=H|4;break L11890}break};case 100:case 101:{H=l+12|0;K=gCR(g,c[h>>2]|0,k,C,2)|0;O=c[k>>2]|0;do{if((O&4|0)==0){if((K-1|0)>>>0>=31){break}c[H>>2]=K;break L11890}}while(0);c[k>>2]=O|4;break};case 110:case 116:{K=g|0;H=B+8|0;E=c[h>>2]|0;L11970:while(1){F=c[K>>2]|0;do{if((F|0)==0){Q=0}else{if((c[F+12>>2]|0)!=(c[F+16>>2]|0)){Q=F;break}if((gj[c[(c[F>>2]|0)+36>>2]&4095](F)|0)==-1){c[K>>2]=0;Q=0;break}else{Q=c[K>>2]|0;break}}}while(0);F=(Q|0)==0;do{if((E|0)==0){R=10354}else{if((c[E+12>>2]|0)==(c[E+16>>2]|0)){if((gj[c[(c[E>>2]|0)+36>>2]&4095](E)|0)==-1){R=10354;break}}if(F){S=0;T=E}else{U=E;V=0;break L11970}}}while(0);if((R|0)==10354){R=0;if(F){U=0;V=1;break}else{S=1;T=0}}D=c[K>>2]|0;W=c[D+12>>2]|0;if((W|0)==(c[D+16>>2]|0)){X=(gj[c[(c[D>>2]|0)+36>>2]&4095](D)|0)&255}else{X=a[W]|0}if(X<<24>>24<0){U=T;V=S;break}if((b[(c[H>>2]|0)+(X<<24>>24<<1)>>1]&8192)==0){U=T;V=S;break}W=c[K>>2]|0;D=W+12|0;Y=c[D>>2]|0;if((Y|0)==(c[W+16>>2]|0)){Z=c[(c[W>>2]|0)+40>>2]|0;gj[Z&4095](W)|0;E=T;continue}else{c[D>>2]=Y+1;E=T;continue}}E=c[K>>2]|0;do{if((E|0)==0){_=0}else{if((c[E+12>>2]|0)!=(c[E+16>>2]|0)){_=E;break}if((gj[c[(c[E>>2]|0)+36>>2]&4095](E)|0)==-1){c[K>>2]=0;_=0;break}else{_=c[K>>2]|0;break}}}while(0);K=(_|0)==0;do{if(V){R=10372}else{if((c[U+12>>2]|0)!=(c[U+16>>2]|0)){if(K^(U|0)==0){break L11890}else{break}}if((gj[c[(c[U>>2]|0)+36>>2]&4095](U)|0)==-1){R=10372;break}if(K){break L11890}}}while(0);if((R|0)==10372){if(!K){break L11890}}c[k>>2]=c[k>>2]|2;break};case 106:{E=gCR(g,c[h>>2]|0,k,C,3)|0;H=c[k>>2]|0;if((H&4|0)==0&(E|0)<366){c[l+28>>2]=E;break L11890}else{c[k>>2]=H|4;break L11890}break};case 121:{H=gCR(g,c[h>>2]|0,k,C,4)|0;if((c[k>>2]&4|0)!=0){break L11890}if((H|0)<69){$=H+2e3|0}else{$=(H-69|0)>>>0<31?H+1900|0:H}c[l+20>>2]=$-1900;break};case 89:{H=gCR(g,c[h>>2]|0,k,C,4)|0;if((c[k>>2]&4|0)!=0){break L11890}c[l+20>>2]=H-1900;break};case 37:{H=c[h>>2]|0;E=g|0;O=c[E>>2]|0;do{if((O|0)==0){aa=0}else{if((c[O+12>>2]|0)!=(c[O+16>>2]|0)){aa=O;break}if((gj[c[(c[O>>2]|0)+36>>2]&4095](O)|0)==-1){c[E>>2]=0;aa=0;break}else{aa=c[E>>2]|0;break}}}while(0);O=(aa|0)==0;do{if((H|0)==0){R=10422}else{if((c[H+12>>2]|0)==(c[H+16>>2]|0)){if((gj[c[(c[H>>2]|0)+36>>2]&4095](H)|0)==-1){R=10422;break}}if(O){ab=H;ac=0}else{R=10423}}}while(0);if((R|0)==10422){if(O){R=10423}else{ab=0;ac=1}}if((R|0)==10423){c[k>>2]=c[k>>2]|6;break L11890}H=c[E>>2]|0;K=c[H+12>>2]|0;if((K|0)==(c[H+16>>2]|0)){ad=(gj[c[(c[H>>2]|0)+36>>2]&4095](H)|0)&255}else{ad=a[K]|0}if((gp[c[(c[B>>2]|0)+36>>2]&16383](C,ad,0)|0)<<24>>24!=37){c[k>>2]=c[k>>2]|4;break L11890}K=c[E>>2]|0;H=K+12|0;Y=c[H>>2]|0;if((Y|0)==(c[K+16>>2]|0)){D=c[(c[K>>2]|0)+40>>2]|0;gj[D&4095](K)|0}else{c[H>>2]=Y+1}Y=c[E>>2]|0;do{if((Y|0)==0){ae=0}else{if((c[Y+12>>2]|0)!=(c[Y+16>>2]|0)){ae=Y;break}if((gj[c[(c[Y>>2]|0)+36>>2]&4095](Y)|0)==-1){c[E>>2]=0;ae=0;break}else{ae=c[E>>2]|0;break}}}while(0);E=(ae|0)==0;do{if(ac){R=10441}else{if((c[ab+12>>2]|0)!=(c[ab+16>>2]|0)){if(E^(ab|0)==0){break L11890}else{break}}if((gj[c[(c[ab>>2]|0)+36>>2]&4095](ab)|0)==-1){R=10441;break}if(E){break L11890}}}while(0);if((R|0)==10441){if(!E){break L11890}}c[k>>2]=c[k>>2]|2;break};default:{c[k>>2]=c[k>>2]|4}}}while(0);c[e>>2]=c[g>>2];i=n;return}}while(0);n=f_(4)|0;c[n>>2]=619800;eh(n|0,625536,1e3)}function gCR(d,e,f,g,h){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;i=d|0;d=c[i>>2]|0;do{if((d|0)==0){j=0}else{if((c[d+12>>2]|0)!=(c[d+16>>2]|0)){j=d;break}if((gj[c[(c[d>>2]|0)+36>>2]&4095](d)|0)==-1){c[i>>2]=0;j=0;break}else{j=c[i>>2]|0;break}}}while(0);d=(j|0)==0;do{if((e|0)==0){k=10458}else{if((c[e+12>>2]|0)==(c[e+16>>2]|0)){if((gj[c[(c[e>>2]|0)+36>>2]&4095](e)|0)==-1){k=10458;break}}if(d){l=e}else{k=10459}}}while(0);if((k|0)==10458){if(d){k=10459}else{l=0}}if((k|0)==10459){c[f>>2]=c[f>>2]|6;m=0;return m|0}d=c[i>>2]|0;e=c[d+12>>2]|0;if((e|0)==(c[d+16>>2]|0)){n=(gj[c[(c[d>>2]|0)+36>>2]&4095](d)|0)&255}else{n=a[e]|0}do{if(n<<24>>24>=0){e=g+8|0;if((b[(c[e>>2]|0)+(n<<24>>24<<1)>>1]&2048)==0){break}d=g;j=(gp[c[(c[d>>2]|0)+36>>2]&16383](g,n,0)|0)<<24>>24;o=c[i>>2]|0;p=o+12|0;q=c[p>>2]|0;if((q|0)==(c[o+16>>2]|0)){r=c[(c[o>>2]|0)+40>>2]|0;gj[r&4095](o)|0;s=j;t=h;u=l}else{c[p>>2]=q+1;s=j;t=h;u=l}while(1){v=s-48|0;j=t-1|0;q=c[i>>2]|0;do{if((q|0)==0){w=0}else{if((c[q+12>>2]|0)!=(c[q+16>>2]|0)){w=q;break}if((gj[c[(c[q>>2]|0)+36>>2]&4095](q)|0)==-1){c[i>>2]=0;w=0;break}else{w=c[i>>2]|0;break}}}while(0);q=(w|0)==0;if((u|0)==0){x=w;y=0}else{if((c[u+12>>2]|0)==(c[u+16>>2]|0)){p=(gj[c[(c[u>>2]|0)+36>>2]&4095](u)|0)==-1;z=p?0:u}else{z=u}x=c[i>>2]|0;y=z}A=(y|0)==0;if(!((q^A)&(j|0)>0)){k=10487;break}q=c[x+12>>2]|0;if((q|0)==(c[x+16>>2]|0)){B=(gj[c[(c[x>>2]|0)+36>>2]&4095](x)|0)&255}else{B=a[q]|0}if(B<<24>>24<0){m=v;k=10505;break}if((b[(c[e>>2]|0)+(B<<24>>24<<1)>>1]&2048)==0){m=v;k=10500;break}q=((gp[c[(c[d>>2]|0)+36>>2]&16383](g,B,0)|0)<<24>>24)+(v*10|0)|0;p=c[i>>2]|0;o=p+12|0;r=c[o>>2]|0;if((r|0)==(c[p+16>>2]|0)){C=c[(c[p>>2]|0)+40>>2]|0;gj[C&4095](p)|0;s=q;t=j;u=y;continue}else{c[o>>2]=r+1;s=q;t=j;u=y;continue}}if((k|0)==10500){return m|0}else if((k|0)==10487){do{if((x|0)==0){D=0}else{if((c[x+12>>2]|0)!=(c[x+16>>2]|0)){D=x;break}if((gj[c[(c[x>>2]|0)+36>>2]&4095](x)|0)==-1){c[i>>2]=0;D=0;break}else{D=c[i>>2]|0;break}}}while(0);d=(D|0)==0;do{if(A){k=10496}else{if((c[y+12>>2]|0)==(c[y+16>>2]|0)){if((gj[c[(c[y>>2]|0)+36>>2]&4095](y)|0)==-1){k=10496;break}}if(d){m=v}else{break}return m|0}}while(0);do{if((k|0)==10496){if(d){break}else{m=v}return m|0}}while(0);c[f>>2]=c[f>>2]|2;m=v;return m|0}else if((k|0)==10505){return m|0}}}while(0);c[f>>2]=c[f>>2]|4;m=0;return m|0}function gCS(a,b,d,e,f,g,h,j,k){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0;l=i;i=i+40|0;m=l|0;n=l+16|0;o=l+24|0;p=l+32|0;q=c[f+28>>2]|0;r=q+4|0;I=c[r>>2]|0,c[r>>2]=I+1,I;if((c[2385058]|0)!=-1){c[m>>2]=9540232;c[m+4>>2]=180;c[m+8>>2]=0;gAp(9540232,m)}m=(c[2385059]|0)-1|0;s=c[q+8>>2]|0;do{if((c[q+12>>2]|0)-s>>2>>>0>m>>>0){t=c[s+(m<<2)>>2]|0;if((t|0)==0){break}u=t;if(((I=c[r>>2]|0,c[r>>2]=I+ -1,I)|0)==0){gf[c[(c[q>>2]|0)+8>>2]&2047](q)}c[g>>2]=0;L12162:do{if((j|0)==(k|0)){v=d;w=d;x=e}else{y=t;z=t;A=t;B=b;C=o|0;D=p|0;E=n|0;F=j;G=d;H=e;L12164:while(1){if((G|0)==0){J=0}else{K=c[G+12>>2]|0;if((K|0)==(c[G+16>>2]|0)){L=gj[c[(c[G>>2]|0)+36>>2]&4095](G)|0}else{L=c[K>>2]|0}J=(L|0)==-1?0:G}K=(J|0)==0;do{if((H|0)==0){M=10526}else{N=c[H+12>>2]|0;if((N|0)==(c[H+16>>2]|0)){O=gj[c[(c[H>>2]|0)+36>>2]&4095](H)|0}else{O=c[N>>2]|0}if((O|0)==-1){M=10526;break}if(K){P=H}else{Q=J;R=H;M=10528;break L12164}}}while(0);if((M|0)==10526){M=0;if(K){Q=0;R=0;M=10528;break}else{P=0}}L12183:do{if((gp[c[(c[y>>2]|0)+52>>2]&16383](u,c[F>>2]|0,0)|0)<<24>>24==37){N=F+4|0;if((N|0)==(k|0)){M=10534;break L12164}S=gp[c[(c[y>>2]|0)+52>>2]&16383](u,c[N>>2]|0,0)|0;if((S<<24>>24|0)==69|(S<<24>>24|0)==48){T=F+8|0;if((T|0)==(k|0)){M=10537;break L12164}U=S;V=gp[c[(c[y>>2]|0)+52>>2]&16383](u,c[T>>2]|0,0)|0;W=T}else{U=0;V=S;W=N}N=c[(c[B>>2]|0)+36>>2]|0;c[C>>2]=J;c[D>>2]=P;gy[N&15](n,b,o,p,f,g,h,V,U);X=W+4|0;Y=c[E>>2]|0;Z=P}else{if(gp[c[(c[z>>2]|0)+12>>2]&16383](u,8192,c[F>>2]|0)|0){_=F}else{N=J+12|0;S=c[N>>2]|0;T=J+16|0;if((S|0)==(c[T>>2]|0)){$=gj[c[(c[J>>2]|0)+36>>2]&4095](J)|0}else{$=c[S>>2]|0}S=gA[c[(c[A>>2]|0)+28>>2]&16383](u,$)|0;if((S|0)!=(gA[c[(c[A>>2]|0)+28>>2]&16383](u,c[F>>2]|0)|0)){M=10573;break L12164}S=c[N>>2]|0;if((S|0)==(c[T>>2]|0)){T=c[(c[J>>2]|0)+40>>2]|0;gj[T&4095](J)|0}else{c[N>>2]=S+4}X=F+4|0;Y=J;Z=P;break}while(1){S=_+4|0;if((S|0)==(k|0)){aa=k;break}if(gp[c[(c[z>>2]|0)+12>>2]&16383](u,8192,c[S>>2]|0)|0){_=S}else{aa=S;break}}S=J;N=P;T=J;ab=P;while(1){if((S|0)==0){ac=0;ad=T}else{ae=c[S+12>>2]|0;if((ae|0)==(c[S+16>>2]|0)){af=gj[c[(c[S>>2]|0)+36>>2]&4095](S)|0}else{af=c[ae>>2]|0}ae=(af|0)==-1;ac=ae?0:S;ad=ae?0:T}ae=(ac|0)==0;do{if((N|0)==0){ag=ab;M=10556}else{ah=c[N+12>>2]|0;if((ah|0)==(c[N+16>>2]|0)){ai=gj[c[(c[N>>2]|0)+36>>2]&4095](N)|0}else{ai=c[ah>>2]|0}if((ai|0)==-1){ag=0;M=10556;break}if(ae){aj=N;ak=ab}else{X=aa;Y=ad;Z=ab;break L12183}}}while(0);if((M|0)==10556){M=0;if(ae){X=aa;Y=ad;Z=ag;break L12183}else{aj=0;ak=ag}}ah=ac+12|0;al=c[ah>>2]|0;am=ac+16|0;if((al|0)==(c[am>>2]|0)){an=gj[c[(c[ac>>2]|0)+36>>2]&4095](ac)|0}else{an=c[al>>2]|0}if(!(gp[c[(c[z>>2]|0)+12>>2]&16383](u,8192,an)|0)){X=aa;Y=ad;Z=ak;break L12183}al=c[ah>>2]|0;if((al|0)==(c[am>>2]|0)){am=c[(c[ac>>2]|0)+40>>2]|0;gj[am&4095](ac)|0;S=ac;N=aj;T=ad;ab=ak;continue}else{c[ah>>2]=al+4;S=ac;N=aj;T=ad;ab=ak;continue}}}}while(0);if((X|0)==(k|0)){v=Y;w=Y;x=Z;break L12162}if((c[g>>2]|0)==0){F=X;G=Y;H=Z}else{v=Y;w=Y;x=Z;break L12162}}if((M|0)==10528){c[g>>2]=4;v=Q;w=J;x=R;break}else if((M|0)==10537){c[g>>2]=4;v=J;w=J;x=P;break}else if((M|0)==10573){c[g>>2]=4;v=J;w=J;x=P;break}else if((M|0)==10534){c[g>>2]=4;v=J;w=J;x=P;break}}}while(0);if((v|0)==0){ao=w}else{u=c[v+12>>2]|0;if((u|0)==(c[v+16>>2]|0)){ap=gj[c[(c[v>>2]|0)+36>>2]&4095](v)|0}else{ap=c[u>>2]|0}ao=(ap|0)==-1?0:w}u=(ao|0)==0;do{if((x|0)==0){M=10584}else{t=c[x+12>>2]|0;if((t|0)==(c[x+16>>2]|0)){aq=gj[c[(c[x>>2]|0)+36>>2]&4095](x)|0}else{aq=c[t>>2]|0}if((aq|0)==-1){M=10584;break}if(!u){break}ar=a|0;c[ar>>2]=ao;i=l;return}}while(0);do{if((M|0)==10584){if(u){break}ar=a|0;c[ar>>2]=ao;i=l;return}}while(0);c[g>>2]=c[g>>2]|2;ar=a|0;c[ar>>2]=ao;i=l;return}}while(0);l=f_(4)|0;c[l>>2]=619800;eh(l|0,625536,1e3)}function gCT(a){a=a|0;if((a|0)==0){return}gGr(a);return}function gCU(a){a=a|0;return}function gCV(a){a=a|0;return 2}function gCW(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0;j=i;k=d;d=i;i=i+4|0;i=i+7&-8;c[d>>2]=c[k>>2];k=e;e=i;i=i+4|0;i=i+7&-8;c[e>>2]=c[k>>2];gCS(a,b,c[d>>2]|0,c[e>>2]|0,f,g,h,591056,591088);i=j;return}function gCX(b,d,e,f,g,h,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0;k=i;l=e;e=i;i=i+4|0;i=i+7&-8;c[e>>2]=c[l>>2];l=f;f=i;i=i+4|0;i=i+7&-8;c[f>>2]=c[l>>2];l=d+8|0;m=gj[c[(c[l>>2]|0)+20>>2]&4095](l)|0;l=a[m]|0;if((l&1)==0){n=m+4|0}else{n=c[m+8>>2]|0}o=l&255;if((o&1|0)==0){p=o>>>1}else{p=c[m+4>>2]|0}gCS(b,d,c[e>>2]|0,c[f>>2]|0,g,h,j,n,n+(p<<2)|0);i=k;return}function gCY(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;j=i;i=i+16|0;k=d;d=i;i=i+4|0;i=i+7&-8;c[d>>2]=c[k>>2];k=e;e=i;i=i+4|0;i=i+7&-8;c[e>>2]=c[k>>2];k=j|0;l=c[f+28>>2]|0;f=l+4|0;I=c[f>>2]|0,c[f>>2]=I+1,I;if((c[2385058]|0)!=-1){c[k>>2]=9540232;c[k+4>>2]=180;c[k+8>>2]=0;gAp(9540232,k)}k=(c[2385059]|0)-1|0;m=c[l+8>>2]|0;do{if((c[l+12>>2]|0)-m>>2>>>0>k>>>0){n=c[m+(k<<2)>>2]|0;if((n|0)==0){break}if(((I=c[f>>2]|0,c[f>>2]=I+ -1,I)|0)==0){gf[c[(c[l>>2]|0)+8>>2]&2047](l)}o=c[e>>2]|0;p=b+8|0;q=gj[c[c[p>>2]>>2]&4095](p)|0;p=(gBZ(d,o,q,q+168|0,n,g,0)|0)-q|0;if((p|0)>=168){r=d|0;s=c[r>>2]|0;t=a|0;c[t>>2]=s;i=j;return}c[h+24>>2]=((p|0)/12|0|0)%7|0;r=d|0;s=c[r>>2]|0;t=a|0;c[t>>2]=s;i=j;return}}while(0);j=f_(4)|0;c[j>>2]=619800;eh(j|0,625536,1e3)}function gCZ(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;j=i;i=i+16|0;k=d;d=i;i=i+4|0;i=i+7&-8;c[d>>2]=c[k>>2];k=e;e=i;i=i+4|0;i=i+7&-8;c[e>>2]=c[k>>2];k=j|0;l=c[f+28>>2]|0;f=l+4|0;I=c[f>>2]|0,c[f>>2]=I+1,I;if((c[2385058]|0)!=-1){c[k>>2]=9540232;c[k+4>>2]=180;c[k+8>>2]=0;gAp(9540232,k)}k=(c[2385059]|0)-1|0;m=c[l+8>>2]|0;do{if((c[l+12>>2]|0)-m>>2>>>0>k>>>0){n=c[m+(k<<2)>>2]|0;if((n|0)==0){break}if(((I=c[f>>2]|0,c[f>>2]=I+ -1,I)|0)==0){gf[c[(c[l>>2]|0)+8>>2]&2047](l)}o=c[e>>2]|0;p=b+8|0;q=gj[c[(c[p>>2]|0)+4>>2]&4095](p)|0;p=(gBZ(d,o,q,q+288|0,n,g,0)|0)-q|0;if((p|0)>=288){r=d|0;s=c[r>>2]|0;t=a|0;c[t>>2]=s;i=j;return}c[h+16>>2]=((p|0)/12|0|0)%12|0;r=d|0;s=c[r>>2]|0;t=a|0;c[t>>2]=s;i=j;return}}while(0);j=f_(4)|0;c[j>>2]=619800;eh(j|0,625536,1e3)}function gC_(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=i;i=i+16|0;j=d;d=i;i=i+4|0;i=i+7&-8;c[d>>2]=c[j>>2];j=e;e=i;i=i+4|0;i=i+7&-8;c[e>>2]=c[j>>2];j=b|0;k=c[f+28>>2]|0;f=k+4|0;I=c[f>>2]|0,c[f>>2]=I+1,I;if((c[2385058]|0)!=-1){c[j>>2]=9540232;c[j+4>>2]=180;c[j+8>>2]=0;gAp(9540232,j)}j=(c[2385059]|0)-1|0;l=c[k+8>>2]|0;do{if((c[k+12>>2]|0)-l>>2>>>0>j>>>0){m=c[l+(j<<2)>>2]|0;if((m|0)==0){break}if(((I=c[f>>2]|0,c[f>>2]=I+ -1,I)|0)==0){gf[c[(c[k>>2]|0)+8>>2]&2047](k)}n=gC0(d,c[e>>2]|0,g,m,4)|0;if((c[g>>2]&4|0)!=0){o=d|0;p=c[o>>2]|0;q=a|0;c[q>>2]=p;i=b;return}if((n|0)<69){r=n+2e3|0}else{r=(n-69|0)>>>0<31?n+1900|0:n}c[h+20>>2]=r-1900;o=d|0;p=c[o>>2]|0;q=a|0;c[q>>2]=p;i=b;return}}while(0);b=f_(4)|0;c[b>>2]=619800;eh(b|0,625536,1e3)}function gC$(b,e,f,g,h,j,k,l,m){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0;m=i;i=i+88|0;n=f;f=i;i=i+4|0;i=i+7&-8;c[f>>2]=c[n>>2];n=g;g=i;i=i+4|0;i=i+7&-8;c[g>>2]=c[n>>2];n=m|0;o=m+16|0;p=m+24|0;q=m+32|0;r=m+40|0;s=m+48|0;t=m+56|0;u=m+64|0;v=m+72|0;w=m+80|0;c[j>>2]=0;x=c[h+28>>2]|0;y=x+4|0;I=c[y>>2]|0,c[y>>2]=I+1,I;if((c[2385058]|0)!=-1){c[n>>2]=9540232;c[n+4>>2]=180;c[n+8>>2]=0;gAp(9540232,n)}n=(c[2385059]|0)-1|0;z=c[x+8>>2]|0;do{if((c[x+12>>2]|0)-z>>2>>>0>n>>>0){A=c[z+(n<<2)>>2]|0;if((A|0)==0){break}B=A;if(((I=c[y>>2]|0,c[y>>2]=I+ -1,I)|0)==0){gf[c[(c[x>>2]|0)+8>>2]&2047](x)}L12342:do{switch(l<<24>>24|0){case 100:case 101:{C=k+12|0;D=gC0(f,c[g>>2]|0,j,B,2)|0;E=c[j>>2]|0;do{if((E&4|0)==0){if((D-1|0)>>>0>=31){break}c[C>>2]=D;break L12342}}while(0);c[j>>2]=E|4;break};case 99:{D=e+8|0;C=gj[c[(c[D>>2]|0)+12>>2]&4095](D)|0;D=f|0;F=a[C]|0;if((F&1)==0){G=C+4|0}else{G=c[C+8>>2]|0}H=F&255;if((H&1|0)==0){J=H>>>1}else{J=c[C+4>>2]|0}gCS(o,e,c[D>>2]|0,c[g>>2]|0,h,j,k,G,G+(J<<2)|0);c[D>>2]=c[o>>2];break};case 84:{D=f|0;gCS(t,e,c[D>>2]|0,c[g>>2]|0,h,j,k,590920,590952);c[D>>2]=c[t>>2];break};case 119:{D=gC0(f,c[g>>2]|0,j,B,1)|0;C=c[j>>2]|0;if((C&4|0)==0&(D|0)<7){c[k+24>>2]=D;break L12342}else{c[j>>2]=C|4;break L12342}break};case 109:{C=(gC0(f,c[g>>2]|0,j,B,2)|0)-1|0;D=c[j>>2]|0;if((D&4|0)==0&(C|0)<12){c[k+16>>2]=C;break L12342}else{c[j>>2]=D|4;break L12342}break};case 120:{D=c[(c[e>>2]|0)+20>>2]|0;c[u>>2]=c[f>>2];c[v>>2]=c[g>>2];gw[D&127](b,e,u,v,h,j,k);i=m;return};case 88:{D=e+8|0;C=gj[c[(c[D>>2]|0)+24>>2]&4095](D)|0;D=f|0;H=a[C]|0;if((H&1)==0){K=C+4|0}else{K=c[C+8>>2]|0}F=H&255;if((F&1|0)==0){L=F>>>1}else{L=c[C+4>>2]|0}gCS(w,e,c[D>>2]|0,c[g>>2]|0,h,j,k,K,K+(L<<2)|0);c[D>>2]=c[w>>2];break};case 98:case 66:case 104:{D=c[g>>2]|0;C=e+8|0;F=gj[c[(c[C>>2]|0)+4>>2]&4095](C)|0;C=(gBZ(f,D,F,F+288|0,B,j,0)|0)-F|0;if((C|0)>=288){break L12342}c[k+16>>2]=((C|0)/12|0|0)%12|0;break};case 110:case 116:{C=f|0;F=A;D=c[g>>2]|0;L12380:while(1){H=c[C>>2]|0;do{if((H|0)==0){M=1}else{N=c[H+12>>2]|0;if((N|0)==(c[H+16>>2]|0)){O=gj[c[(c[H>>2]|0)+36>>2]&4095](H)|0}else{O=c[N>>2]|0}if((O|0)==-1){c[C>>2]=0;M=1;break}else{M=(c[C>>2]|0)==0;break}}}while(0);do{if((D|0)==0){P=10715}else{H=c[D+12>>2]|0;if((H|0)==(c[D+16>>2]|0)){Q=gj[c[(c[D>>2]|0)+36>>2]&4095](D)|0}else{Q=c[H>>2]|0}if((Q|0)==-1){P=10715;break}if(M){R=0;S=D}else{T=D;U=0;break L12380}}}while(0);if((P|0)==10715){P=0;if(M){T=0;U=1;break}else{R=1;S=0}}H=c[C>>2]|0;N=c[H+12>>2]|0;if((N|0)==(c[H+16>>2]|0)){V=gj[c[(c[H>>2]|0)+36>>2]&4095](H)|0}else{V=c[N>>2]|0}if(!(gp[c[(c[F>>2]|0)+12>>2]&16383](B,8192,V)|0)){T=S;U=R;break}N=c[C>>2]|0;H=N+12|0;W=c[H>>2]|0;if((W|0)==(c[N+16>>2]|0)){X=c[(c[N>>2]|0)+40>>2]|0;gj[X&4095](N)|0;D=S;continue}else{c[H>>2]=W+4;D=S;continue}}D=c[C>>2]|0;do{if((D|0)==0){Y=1}else{F=c[D+12>>2]|0;if((F|0)==(c[D+16>>2]|0)){Z=gj[c[(c[D>>2]|0)+36>>2]&4095](D)|0}else{Z=c[F>>2]|0}if((Z|0)==-1){c[C>>2]=0;Y=1;break}else{Y=(c[C>>2]|0)==0;break}}}while(0);do{if(U){P=10736}else{C=c[T+12>>2]|0;if((C|0)==(c[T+16>>2]|0)){_=gj[c[(c[T>>2]|0)+36>>2]&4095](T)|0}else{_=c[C>>2]|0}if((_|0)==-1){P=10736;break}if(Y^(T|0)==0){break L12342}}}while(0);if((P|0)==10736){if(!Y){break L12342}}c[j>>2]=c[j>>2]|2;break};case 37:{C=c[g>>2]|0;D=f|0;F=c[D>>2]|0;do{if((F|0)==0){$=1}else{E=c[F+12>>2]|0;if((E|0)==(c[F+16>>2]|0)){aa=gj[c[(c[F>>2]|0)+36>>2]&4095](F)|0}else{aa=c[E>>2]|0}if((aa|0)==-1){c[D>>2]=0;$=1;break}else{$=(c[D>>2]|0)==0;break}}}while(0);do{if((C|0)==0){P=10789}else{F=c[C+12>>2]|0;if((F|0)==(c[C+16>>2]|0)){ab=gj[c[(c[C>>2]|0)+36>>2]&4095](C)|0}else{ab=c[F>>2]|0}if((ab|0)==-1){P=10789;break}if($){ac=C;ad=0}else{P=10791}}}while(0);if((P|0)==10789){if($){P=10791}else{ac=0;ad=1}}if((P|0)==10791){c[j>>2]=c[j>>2]|6;break L12342}C=c[D>>2]|0;F=c[C+12>>2]|0;if((F|0)==(c[C+16>>2]|0)){ae=gj[c[(c[C>>2]|0)+36>>2]&4095](C)|0}else{ae=c[F>>2]|0}if((gp[c[(c[A>>2]|0)+52>>2]&16383](B,ae,0)|0)<<24>>24!=37){c[j>>2]=c[j>>2]|4;break L12342}F=c[D>>2]|0;C=F+12|0;E=c[C>>2]|0;if((E|0)==(c[F+16>>2]|0)){W=c[(c[F>>2]|0)+40>>2]|0;gj[W&4095](F)|0}else{c[C>>2]=E+4}E=c[D>>2]|0;do{if((E|0)==0){af=1}else{C=c[E+12>>2]|0;if((C|0)==(c[E+16>>2]|0)){ag=gj[c[(c[E>>2]|0)+36>>2]&4095](E)|0}else{ag=c[C>>2]|0}if((ag|0)==-1){c[D>>2]=0;af=1;break}else{af=(c[D>>2]|0)==0;break}}}while(0);do{if(ad){P=10812}else{D=c[ac+12>>2]|0;if((D|0)==(c[ac+16>>2]|0)){ah=gj[c[(c[ac>>2]|0)+36>>2]&4095](ac)|0}else{ah=c[D>>2]|0}if((ah|0)==-1){P=10812;break}if(af^(ac|0)==0){break L12342}}}while(0);if((P|0)==10812){if(!af){break L12342}}c[j>>2]=c[j>>2]|2;break};case 106:{D=gC0(f,c[g>>2]|0,j,B,3)|0;E=c[j>>2]|0;if((E&4|0)==0&(D|0)<366){c[k+28>>2]=D;break L12342}else{c[j>>2]=E|4;break L12342}break};case 112:{E=k+8|0;D=c[g>>2]|0;C=e+8|0;F=gj[c[(c[C>>2]|0)+8>>2]&4095](C)|0;C=d[F]|0;if((C&1|0)==0){ai=C>>>1}else{ai=c[F+4>>2]|0}C=d[F+12|0]|0;if((C&1|0)==0){aj=C>>>1}else{aj=c[F+16>>2]|0}if((ai|0)==(-aj|0)){c[j>>2]=c[j>>2]|4;break L12342}C=gBZ(f,D,F,F+24|0,B,j,0)|0;D=C-F|0;do{if((C|0)==(F|0)){if((c[E>>2]|0)!=12){break}c[E>>2]=0;break L12342}}while(0);if((D|0)!=12){break L12342}F=c[E>>2]|0;if((F|0)>=12){break L12342}c[E>>2]=F+12;break};case 114:{F=f|0;gCS(r,e,c[F>>2]|0,c[g>>2]|0,h,j,k,590976,591020);c[F>>2]=c[r>>2];break};case 82:{F=f|0;gCS(s,e,c[F>>2]|0,c[g>>2]|0,h,j,k,590952,590972);c[F>>2]=c[s>>2];break};case 83:{F=gC0(f,c[g>>2]|0,j,B,2)|0;C=c[j>>2]|0;if((C&4|0)==0&(F|0)<61){c[k>>2]=F;break L12342}else{c[j>>2]=C|4;break L12342}break};case 121:{C=gC0(f,c[g>>2]|0,j,B,4)|0;if((c[j>>2]&4|0)!=0){break L12342}if((C|0)<69){ak=C+2e3|0}else{ak=(C-69|0)>>>0<31?C+1900|0:C}c[k+20>>2]=ak-1900;break};case 89:{C=gC0(f,c[g>>2]|0,j,B,4)|0;if((c[j>>2]&4|0)!=0){break L12342}c[k+20>>2]=C-1900;break};case 77:{C=gC0(f,c[g>>2]|0,j,B,2)|0;F=c[j>>2]|0;if((F&4|0)==0&(C|0)<60){c[k+4>>2]=C;break L12342}else{c[j>>2]=F|4;break L12342}break};case 72:{F=gC0(f,c[g>>2]|0,j,B,2)|0;C=c[j>>2]|0;if((C&4|0)==0&(F|0)<24){c[k+8>>2]=F;break L12342}else{c[j>>2]=C|4;break L12342}break};case 97:case 65:{C=c[g>>2]|0;F=e+8|0;W=gj[c[c[F>>2]>>2]&4095](F)|0;F=(gBZ(f,C,W,W+168|0,B,j,0)|0)-W|0;if((F|0)>=168){break L12342}c[k+24>>2]=((F|0)/12|0|0)%7|0;break};case 68:{F=f|0;gCS(p,e,c[F>>2]|0,c[g>>2]|0,h,j,k,591024,591056);c[F>>2]=c[p>>2];break};case 73:{F=k+8|0;W=gC0(f,c[g>>2]|0,j,B,2)|0;C=c[j>>2]|0;do{if((C&4|0)==0){if((W-1|0)>>>0>=12){break}c[F>>2]=W;break L12342}}while(0);c[j>>2]=C|4;break};case 70:{W=f|0;gCS(q,e,c[W>>2]|0,c[g>>2]|0,h,j,k,590888,590920);c[W>>2]=c[q>>2];break};default:{c[j>>2]=c[j>>2]|4}}}while(0);c[b>>2]=c[f>>2];i=m;return}}while(0);m=f_(4)|0;c[m>>2]=619800;eh(m|0,625536,1e3)}function gC0(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;g=a|0;a=c[g>>2]|0;do{if((a|0)==0){h=1}else{i=c[a+12>>2]|0;if((i|0)==(c[a+16>>2]|0)){j=gj[c[(c[a>>2]|0)+36>>2]&4095](a)|0}else{j=c[i>>2]|0}if((j|0)==-1){c[g>>2]=0;h=1;break}else{h=(c[g>>2]|0)==0;break}}}while(0);do{if((b|0)==0){k=10832}else{j=c[b+12>>2]|0;if((j|0)==(c[b+16>>2]|0)){l=gj[c[(c[b>>2]|0)+36>>2]&4095](b)|0}else{l=c[j>>2]|0}if((l|0)==-1){k=10832;break}if(h){m=b}else{k=10834}}}while(0);if((k|0)==10832){if(h){k=10834}else{m=0}}if((k|0)==10834){c[d>>2]=c[d>>2]|6;n=0;return n|0}h=c[g>>2]|0;b=c[h+12>>2]|0;if((b|0)==(c[h+16>>2]|0)){o=gj[c[(c[h>>2]|0)+36>>2]&4095](h)|0}else{o=c[b>>2]|0}b=e;if(!(gp[c[(c[b>>2]|0)+12>>2]&16383](e,2048,o)|0)){c[d>>2]=c[d>>2]|4;n=0;return n|0}h=e;l=(gp[c[(c[h>>2]|0)+52>>2]&16383](e,o,0)|0)<<24>>24;o=c[g>>2]|0;j=o+12|0;a=c[j>>2]|0;if((a|0)==(c[o+16>>2]|0)){i=c[(c[o>>2]|0)+40>>2]|0;gj[i&4095](o)|0;p=l;q=f;r=m}else{c[j>>2]=a+4;p=l;q=f;r=m}while(1){s=p-48|0;m=q-1|0;f=c[g>>2]|0;do{if((f|0)==0){t=0}else{l=c[f+12>>2]|0;if((l|0)==(c[f+16>>2]|0)){u=gj[c[(c[f>>2]|0)+36>>2]&4095](f)|0}else{u=c[l>>2]|0}if((u|0)==-1){c[g>>2]=0;t=0;break}else{t=c[g>>2]|0;break}}}while(0);f=(t|0)==0;if((r|0)==0){v=t;w=0}else{l=c[r+12>>2]|0;if((l|0)==(c[r+16>>2]|0)){x=gj[c[(c[r>>2]|0)+36>>2]&4095](r)|0}else{x=c[l>>2]|0}v=c[g>>2]|0;w=(x|0)==-1?0:r}y=(w|0)==0;if(!((f^y)&(m|0)>0)){break}f=c[v+12>>2]|0;if((f|0)==(c[v+16>>2]|0)){z=gj[c[(c[v>>2]|0)+36>>2]&4095](v)|0}else{z=c[f>>2]|0}if(!(gp[c[(c[b>>2]|0)+12>>2]&16383](e,2048,z)|0)){n=s;k=10881;break}f=((gp[c[(c[h>>2]|0)+52>>2]&16383](e,z,0)|0)<<24>>24)+(s*10|0)|0;l=c[g>>2]|0;a=l+12|0;j=c[a>>2]|0;if((j|0)==(c[l+16>>2]|0)){o=c[(c[l>>2]|0)+40>>2]|0;gj[o&4095](l)|0;p=f;q=m;r=w;continue}else{c[a>>2]=j+4;p=f;q=m;r=w;continue}}if((k|0)==10881){return n|0}do{if((v|0)==0){A=1}else{r=c[v+12>>2]|0;if((r|0)==(c[v+16>>2]|0)){B=gj[c[(c[v>>2]|0)+36>>2]&4095](v)|0}else{B=c[r>>2]|0}if((B|0)==-1){c[g>>2]=0;A=1;break}else{A=(c[g>>2]|0)==0;break}}}while(0);do{if(y){k=10875}else{g=c[w+12>>2]|0;if((g|0)==(c[w+16>>2]|0)){C=gj[c[(c[w>>2]|0)+36>>2]&4095](w)|0}else{C=c[g>>2]|0}if((C|0)==-1){k=10875;break}if(A){n=s}else{break}return n|0}}while(0);do{if((k|0)==10875){if(A){break}else{n=s}return n|0}}while(0);c[d>>2]=c[d>>2]|2;n=s;return n|0}function gC1(b){b=b|0;var d=0,e=0,f=0;d=b;e=b+8|0;f=c[e>>2]|0;do{if((a[14125e3]|0)==0){if((bp(14125e3)|0)==0){break}c[2384150]=e6(2147483647,485280,0)|0}}while(0);if((f|0)!=(c[2384150]|0)){d4(c[e>>2]|0)}if((b|0)==0){return}gGr(d);return}function gC2(b){b=b|0;var d=0;d=b+8|0;b=c[d>>2]|0;do{if((a[14125e3]|0)==0){if((bp(14125e3)|0)==0){break}c[2384150]=e6(2147483647,485280,0)|0}}while(0);if((b|0)==(c[2384150]|0)){return}d4(c[d>>2]|0);return}function gC3(b,d,e,f,g,h,j,k){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+112|0;f=e;e=i;i=i+4|0;i=i+7&-8;c[e>>2]=c[f>>2];f=g|0;l=g+8|0;m=l|0;n=f|0;a[n]=37;o=f+1|0;a[o]=j;p=f+2|0;a[p]=k;a[f+3|0]=0;if(k<<24>>24!=0){a[o]=k;a[p]=j}j=ed(m|0,100,n|0,h|0,c[d+8>>2]|0)|0;d=l+j|0;l=c[e>>2]|0;if((j|0)==0){q=l;r=b|0;c[r>>2]=q;i=g;return}else{s=l;t=m}while(1){m=a[t]|0;if((s|0)==0){u=0}else{l=s+24|0;j=c[l>>2]|0;if((j|0)==(c[s+28>>2]|0)){v=gA[c[(c[s>>2]|0)+52>>2]&16383](s,m&255)|0}else{c[l>>2]=j+1;a[j]=m;v=m&255}u=(v|0)==-1?0:s}m=t+1|0;if((m|0)==(d|0)){q=u;break}else{s=u;t=m}}r=b|0;c[r>>2]=q;i=g;return}function gC4(b){b=b|0;var d=0,e=0,f=0;d=b;e=b+8|0;f=c[e>>2]|0;do{if((a[14125e3]|0)==0){if((bp(14125e3)|0)==0){break}c[2384150]=e6(2147483647,485280,0)|0}}while(0);if((f|0)!=(c[2384150]|0)){d4(c[e>>2]|0)}if((b|0)==0){return}gGr(d);return}function gC5(b){b=b|0;var d=0;d=b+8|0;b=c[d>>2]|0;do{if((a[14125e3]|0)==0){if((bp(14125e3)|0)==0){break}c[2384150]=e6(2147483647,485280,0)|0}}while(0);if((b|0)==(c[2384150]|0)){return}d4(c[d>>2]|0);return}function gC6(b,d,e,f,g,h,j,k){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;g=i;i=i+528|0;f=e;e=i;i=i+4|0;i=i+7&-8;c[e>>2]=c[f>>2];f=g|0;l=g+112|0;m=g+120|0;n=g+128|0;o=n|0;p=g+8|0;q=f|0;a[q]=37;r=f+1|0;a[r]=j;s=f+2|0;a[s]=k;a[f+3|0]=0;if(k<<24>>24!=0){a[r]=k;a[s]=j}j=d+8|0;ed(p|0,100,q|0,h|0,c[j>>2]|0)|0;c[l>>2]=0;c[l+4>>2]=0;c[m>>2]=p;p=fN(c[j>>2]|0)|0;j=gF5(o,m,100,l)|0;if((p|0)!=0){fN(p|0)|0}if((j|0)==-1){gDU(277488)}p=n+(j<<2)|0;n=c[e>>2]|0;if((j|0)==0){t=n;u=b|0;c[u>>2]=t;i=g;return}else{v=n;w=o}while(1){o=c[w>>2]|0;if((v|0)==0){x=0}else{n=v+24|0;j=c[n>>2]|0;if((j|0)==(c[v+28>>2]|0)){y=gA[c[(c[v>>2]|0)+52>>2]&16383](v,o)|0}else{c[n>>2]=j+4;c[j>>2]=o;y=o}x=(y|0)==-1?0:v}o=w+4|0;if((o|0)==(p|0)){t=x;break}else{v=x;w=o}}u=b|0;c[u>>2]=t;i=g;return}function gC7(a){a=a|0;if((a|0)==0){return}gGr(a);return}function gC8(a){a=a|0;return}function gC9(a){a=a|0;return 127}function gDa(a){a=a|0;return 127}function gDb(a,b){a=a|0;b=b|0;gGz(a|0,0,12);return}function gDc(a,b){a=a|0;b=b|0;gGz(a|0,0,12);return}function gDd(a,b){a=a|0;b=b|0;gGz(a|0,0,12);return}function gDe(b,c){b=b|0;c=c|0;c=b;a[b]=2;a[c+1|0]=45;a[c+2|0]=0;return}function gDf(a){a=a|0;return 0}function gDg(b,c){b=b|0;c=c|0;c=b;C=67109634;a[c]=C&255;C=C>>8;a[c+1|0]=C&255;C=C>>8;a[c+2|0]=C&255;C=C>>8;a[c+3|0]=C&255;return}function gDh(b,c){b=b|0;c=c|0;c=b;C=67109634;a[c]=C&255;C=C>>8;a[c+1|0]=C&255;C=C>>8;a[c+2|0]=C&255;C=C>>8;a[c+3|0]=C&255;return}function gDi(a){a=a|0;if((a|0)==0){return}gGr(a);return}function gDj(a){a=a|0;return}function gDk(a){a=a|0;return 127}function gDl(a){a=a|0;return 127}function gDm(a,b){a=a|0;b=b|0;gGz(a|0,0,12);return}function gDn(a,b){a=a|0;b=b|0;gGz(a|0,0,12);return}function gDo(a,b){a=a|0;b=b|0;gGz(a|0,0,12);return}function gDp(b,c){b=b|0;c=c|0;c=b;a[b]=2;a[c+1|0]=45;a[c+2|0]=0;return}function gDq(a){a=a|0;return 0}function gDr(b,c){b=b|0;c=c|0;c=b;C=67109634;a[c]=C&255;C=C>>8;a[c+1|0]=C&255;C=C>>8;a[c+2|0]=C&255;C=C>>8;a[c+3|0]=C&255;return}function gDs(b,c){b=b|0;c=c|0;c=b;C=67109634;a[c]=C&255;C=C>>8;a[c+1|0]=C&255;C=C>>8;a[c+2|0]=C&255;C=C>>8;a[c+3|0]=C&255;return}function gDt(a){a=a|0;if((a|0)==0){return}gGr(a);return}function gDu(a){a=a|0;return}function gDv(a){a=a|0;return 2147483647}function gDw(a){a=a|0;return 2147483647}function gDx(a,b){a=a|0;b=b|0;gGz(a|0,0,12);return}function gDy(a,b){a=a|0;b=b|0;gGz(a|0,0,12);return}function gDz(a,b){a=a|0;b=b|0;gGz(a|0,0,12);return}function gDA(b,d){b=b|0;d=d|0;a[b]=2;d=b+4|0;c[d>>2]=45;c[d+4>>2]=0;return}function gDB(a){a=a|0;return 0}function gDC(b,c){b=b|0;c=c|0;c=b;C=67109634;a[c]=C&255;C=C>>8;a[c+1|0]=C&255;C=C>>8;a[c+2|0]=C&255;C=C>>8;a[c+3|0]=C&255;return}function gDD(b,c){b=b|0;c=c|0;c=b;C=67109634;a[c]=C&255;C=C>>8;a[c+1|0]=C&255;C=C>>8;a[c+2|0]=C&255;C=C>>8;a[c+3|0]=C&255;return}function gDE(a){a=a|0;if((a|0)==0){return}gGr(a);return}function gDF(a){a=a|0;return}function gDG(a){a=a|0;return 2147483647}function gDH(a){a=a|0;return 2147483647}function gDI(a,b){a=a|0;b=b|0;gGz(a|0,0,12);return}function gDJ(a,b){a=a|0;b=b|0;gGz(a|0,0,12);return}function gDK(a,b){a=a|0;b=b|0;gGz(a|0,0,12);return}function gDL(b,d){b=b|0;d=d|0;a[b]=2;d=b+4|0;c[d>>2]=45;c[d+4>>2]=0;return}function gDM(a){a=a|0;return 0}function gDN(b,c){b=b|0;c=c|0;c=b;C=67109634;a[c]=C&255;C=C>>8;a[c+1|0]=C&255;C=C>>8;a[c+2|0]=C&255;C=C>>8;a[c+3|0]=C&255;return}function gDO(b,c){b=b|0;c=c|0;c=b;C=67109634;a[c]=C&255;C=C>>8;a[c+1|0]=C&255;C=C>>8;a[c+2|0]=C&255;C=C>>8;a[c+3|0]=C&255;return}function gDP(a){a=a|0;if((a|0)==0){return}gGr(a);return}function gDQ(a){a=a|0;return}function gDR(b,d,e,f,g,h,j,k){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;d=i;i=i+264|0;l=e;e=i;i=i+4|0;i=i+7&-8;c[e>>2]=c[l>>2];l=f;f=i;i=i+4|0;i=i+7&-8;c[f>>2]=c[l>>2];l=d|0;m=d+16|0;n=d+120|0;o=d+128|0;p=d+136|0;q=d+144|0;r=d+160|0;s=n|0;c[s>>2]=m;t=n+4|0;c[t>>2]=1380;u=m+100|0;m=c[h+28>>2]|0;v=m;w=m+4|0;I=c[w>>2]|0,c[w>>2]=I+1,I;if((c[2385060]|0)!=-1){c[l>>2]=9540240;c[l+4>>2]=180;c[l+8>>2]=0;gAp(9540240,l)}l=(c[2385061]|0)-1|0;w=c[m+8>>2]|0;do{if((c[m+12>>2]|0)-w>>2>>>0>l>>>0){x=c[w+(l<<2)>>2]|0;if((x|0)==0){break}y=x;a[p]=0;z=f|0;do{if(gDT(e,c[z>>2]|0,g,v,c[h+4>>2]|0,j,p,y,n,o,u)|0){A=q|0;B=c[(c[x>>2]|0)+32>>2]|0;gJ[B&31](y,590872,590882,A)|0;B=r|0;C=c[o>>2]|0;D=c[s>>2]|0;E=C-D|0;do{if((E|0)>98){F=gGq(E+2|0)|0;if((F|0)!=0){G=F;H=F;break}F=f_(4)|0;c[F>>2]=619768;eh(F|0,625520,1206)}else{G=B;H=0}}while(0);if((a[p]&1)==0){J=G}else{a[G]=45;J=G+1|0}if(D>>>0<C>>>0){E=q+10|0;F=q;K=J;L=D;while(1){M=A;while(1){if((M|0)==(E|0)){N=E;break}if((a[M]|0)==(a[L]|0)){N=M;break}else{M=M+1|0}}a[K]=a[590872+(N-F)|0]|0;M=L+1|0;O=K+1|0;if(M>>>0<(c[o>>2]|0)>>>0){K=O;L=M}else{P=O;break}}}else{P=J}a[P]=0;L=fO(B|0,537664,(K=i,i=i+8|0,c[K>>2]=k,K)|0)|0;i=K;if((L|0)==1){if((H|0)==0){break}gGr(H);break}L=f_(8)|0;c[L>>2]=619832;K=L+4|0;F=K;do{if((K|0)!=0){while(1){Q=gGq(28)|0;if((Q|0)!=0){R=11073;break}E=(I=c[2439328]|0,c[2439328]=I+0,I);if((E|0)==0){break}gu[E&16383]()}if((R|0)==11073){c[Q+4>>2]=15;c[Q>>2]=15;E=Q+12|0;c[F>>2]=E;c[Q+8>>2]=0;gGC(E|0,524400,16)|0;break}E=f_(4)|0;c[E>>2]=619768;eh(E|0,625520,1206)}}while(0);eh(L|0,625552,314)}}while(0);y=e|0;x=c[y>>2]|0;do{if((x|0)==0){S=0}else{if((c[x+12>>2]|0)!=(c[x+16>>2]|0)){S=x;break}if((gj[c[(c[x>>2]|0)+36>>2]&4095](x)|0)!=-1){S=x;break}c[y>>2]=0;S=0}}while(0);y=(S|0)==0;x=c[z>>2]|0;do{if((x|0)==0){R=11091}else{if((c[x+12>>2]|0)!=(c[x+16>>2]|0)){if(y){break}else{R=11093;break}}if((gj[c[(c[x>>2]|0)+36>>2]&4095](x)|0)==-1){c[z>>2]=0;R=11091;break}else{if(y){break}else{R=11093;break}}}}while(0);if((R|0)==11091){if(y){R=11093}}if((R|0)==11093){c[j>>2]=c[j>>2]|2}c[b>>2]=S;z=m+4|0;if(((I=c[z>>2]|0,c[z>>2]=I+ -1,I)|0)==0){gf[c[(c[m>>2]|0)+8>>2]&2047](m)}z=c[s>>2]|0;c[s>>2]=0;if((z|0)==0){i=d;return}gf[c[t>>2]&2047](z);i=d;return}}while(0);d=f_(4)|0;c[d>>2]=619800;eh(d|0,625536,1e3)}function gDS(a){a=a|0;return}function gDT(e,f,g,h,j,k,l,m,n,o,p){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;var q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0,cf=0,cg=0,ch=0;q=i;i=i+584|0;r=q|0;s=q+16|0;t=q+32|0;u=q+40|0;v=q+56|0;w=q+72|0;x=q+88|0;y=q+104|0;z=q+112|0;A=q+128|0;B=q+144|0;C=q+160|0;D=q+176|0;E=q+576|0;F=E;G=i;i=i+12|0;i=i+7&-8;H=G;J=i;i=i+12|0;i=i+7&-8;K=i;i=i+12|0;i=i+7&-8;L=i;i=i+12|0;i=i+7&-8;M=i;i=i+12|0;i=i+7&-8;N=i;i=i+4|0;i=i+7&-8;O=D|0;gGz(H|0,0,12);P=J;Q=K;R=L;S=M;gGz(P|0,0,12);gGz(Q|0,0,12);gGz(R|0,0,12);gGz(S|0,0,12);T=u;U=v;V=w;W=x;X=z;Y=A;Z=B;_=C;L12857:do{if(g){$=t;if((c[2385178]|0)!=-1){c[s>>2]=9540712;c[s+4>>2]=180;c[s+8>>2]=0;gAp(9540712,s)}aa=(c[2385179]|0)-1|0;ab=c[h+8>>2]|0;do{if((c[h+12>>2]|0)-ab>>2>>>0>aa>>>0){ac=c[ab+(aa<<2)>>2]|0;if((ac|0)==0){break}ad=ac;gg[c[(c[ac>>2]|0)+44>>2]&4095]($,ad);c[E>>2]=c[t>>2];ae=ac;gg[c[(c[ae>>2]|0)+32>>2]&4095](u,ad);if((a[R]&1)==0){a[L+1|0]=0;a[R]=0}else{a[c[L+8>>2]|0]=0;c[L+4>>2]=0}gAu(L);c[R>>2]=c[T>>2];c[R+4>>2]=c[T+4>>2];c[R+8>>2]=c[T+8>>2];gGz(T|0,0,12);gg[c[(c[ae>>2]|0)+28>>2]&4095](v,ad);if((a[Q]&1)==0){a[K+1|0]=0;a[Q]=0}else{a[c[K+8>>2]|0]=0;c[K+4>>2]=0}gAu(K);c[Q>>2]=c[U>>2];c[Q+4>>2]=c[U+4>>2];c[Q+8>>2]=c[U+8>>2];gGz(U|0,0,12);af=ac;ag=gj[c[(c[af>>2]|0)+12>>2]&4095](ad)|0;ah=gj[c[(c[af>>2]|0)+16>>2]&4095](ad)|0;gg[c[(c[ae>>2]|0)+20>>2]&4095](w,ad);if((a[H]&1)==0){a[G+1|0]=0;a[H]=0}else{a[c[G+8>>2]|0]=0;c[G+4>>2]=0}gAu(G);c[H>>2]=c[V>>2];c[H+4>>2]=c[V+4>>2];c[H+8>>2]=c[V+8>>2];gGz(V|0,0,12);gg[c[(c[ae>>2]|0)+24>>2]&4095](x,ad);if((a[P]&1)==0){a[J+1|0]=0;a[P]=0}else{a[c[J+8>>2]|0]=0;c[J+4>>2]=0}gAu(J);c[P>>2]=c[W>>2];c[P+4>>2]=c[W+4>>2];c[P+8>>2]=c[W+8>>2];gGz(W|0,0,12);ai=gj[c[(c[ac>>2]|0)+36>>2]&4095](ad)|0;aj=ah;ak=ag;break L12857}}while(0);$=f_(4)|0;c[$>>2]=619800;eh($|0,625536,1e3);return 0}else{$=y;if((c[2385180]|0)!=-1){c[r>>2]=9540720;c[r+4>>2]=180;c[r+8>>2]=0;gAp(9540720,r)}aa=(c[2385181]|0)-1|0;ab=c[h+8>>2]|0;do{if((c[h+12>>2]|0)-ab>>2>>>0>aa>>>0){ag=c[ab+(aa<<2)>>2]|0;if((ag|0)==0){break}ah=ag;gg[c[(c[ag>>2]|0)+44>>2]&4095]($,ah);c[E>>2]=c[y>>2];ad=ag;gg[c[(c[ad>>2]|0)+32>>2]&4095](z,ah);if((a[R]&1)==0){a[L+1|0]=0;a[R]=0}else{a[c[L+8>>2]|0]=0;c[L+4>>2]=0}gAu(L);c[R>>2]=c[X>>2];c[R+4>>2]=c[X+4>>2];c[R+8>>2]=c[X+8>>2];gGz(X|0,0,12);gg[c[(c[ad>>2]|0)+28>>2]&4095](A,ah);if((a[Q]&1)==0){a[K+1|0]=0;a[Q]=0}else{a[c[K+8>>2]|0]=0;c[K+4>>2]=0}gAu(K);c[Q>>2]=c[Y>>2];c[Q+4>>2]=c[Y+4>>2];c[Q+8>>2]=c[Y+8>>2];gGz(Y|0,0,12);ac=ag;ae=gj[c[(c[ac>>2]|0)+12>>2]&4095](ah)|0;af=gj[c[(c[ac>>2]|0)+16>>2]&4095](ah)|0;gg[c[(c[ad>>2]|0)+20>>2]&4095](B,ah);if((a[H]&1)==0){a[G+1|0]=0;a[H]=0}else{a[c[G+8>>2]|0]=0;c[G+4>>2]=0}gAu(G);c[H>>2]=c[Z>>2];c[H+4>>2]=c[Z+4>>2];c[H+8>>2]=c[Z+8>>2];gGz(Z|0,0,12);gg[c[(c[ad>>2]|0)+24>>2]&4095](C,ah);if((a[P]&1)==0){a[J+1|0]=0;a[P]=0}else{a[c[J+8>>2]|0]=0;c[J+4>>2]=0}gAu(J);c[P>>2]=c[_>>2];c[P+4>>2]=c[_+4>>2];c[P+8>>2]=c[_+8>>2];gGz(_|0,0,12);ai=gj[c[(c[ag>>2]|0)+36>>2]&4095](ah)|0;aj=af;ak=ae;break L12857}}while(0);$=f_(4)|0;c[$>>2]=619800;eh($|0,625536,1e3);return 0}}while(0);_=n|0;c[o>>2]=c[_>>2];C=e|0;e=m+8|0;m=L+1|0;Z=L+4|0;B=L+8|0;Y=K+1|0;A=K+4|0;X=K+8|0;z=(j&512|0)!=0;j=J+1|0;y=J+4|0;E=J+8|0;J=M+1|0;h=M+4|0;r=M+8|0;W=F+3|0;x=G+4|0;V=n+4|0;n=M|0;M=p;p=1380;w=O;U=O;O=D+400|0;D=0;v=0;T=ai;ai=f;L12931:while(1){f=c[C>>2]|0;do{if((f|0)==0){al=0}else{if((c[f+12>>2]|0)!=(c[f+16>>2]|0)){al=f;break}if((gj[c[(c[f>>2]|0)+36>>2]&4095](f)|0)==-1){c[C>>2]=0;al=0;break}else{al=c[C>>2]|0;break}}}while(0);f=(al|0)==0;do{if((ai|0)==0){am=11190}else{if((c[ai+12>>2]|0)!=(c[ai+16>>2]|0)){if(f){an=ai;break}else{ao=p;ap=w;aq=U;ar=D;as=ai;am=11522;break L12931}}if((gj[c[(c[ai>>2]|0)+36>>2]&4095](ai)|0)==-1){am=11190;break}if(f){an=ai}else{ao=p;ap=w;aq=U;ar=D;as=ai;am=11522;break L12931}}}while(0);if((am|0)==11190){am=0;if(f){ao=p;ap=w;aq=U;ar=D;as=0;am=11522;break}else{an=0}}L12951:do{switch(a[F+v|0]|0){case 1:{if((v|0)==3){ao=p;ap=w;aq=U;ar=D;as=an;am=11522;break L12931}u=c[C>>2]|0;t=c[u+12>>2]|0;if((t|0)==(c[u+16>>2]|0)){at=(gj[c[(c[u>>2]|0)+36>>2]&4095](u)|0)&255}else{at=a[t]|0}t=at<<24>>24;if((c4(t|0)|0)==0){am=11265;break L12931}if((b[(c[e>>2]|0)+(t<<1)>>1]&8192)==0){am=11265;break L12931}t=c[C>>2]|0;u=t+12|0;s=c[u>>2]|0;if((s|0)==(c[t+16>>2]|0)){au=(gj[c[(c[t>>2]|0)+40>>2]&4095](t)|0)&255}else{c[u>>2]=s+1;au=a[s]|0}s=a[S]|0;if((s&1)==0){av=(s&255)>>>1;aw=10;ax=s}else{u=c[n>>2]|0;av=c[h>>2]|0;aw=(u&-2)-1|0;ax=u&255}if((av|0)==(aw|0)){if((aw|0)==-17){am=11242;break L12931}u=(ax&1)==0?J:c[r>>2]|0;do{if(aw>>>0<2147483623){t=aw+1|0;g=aw<<1;$=t>>>0<g>>>0?g:t;if($>>>0<11){ay=11;break}ay=$+16&-16}else{ay=-17}}while(0);$=(ay|0)==0?1:ay;while(1){az=gGq($)|0;if((az|0)!=0){break}t=(I=c[2439328]|0,c[2439328]=I+0,I);if((t|0)==0){am=11256;break L12931}gu[t&16383]()}gGC(az|0,u|0,aw)|0;if(!((aw|0)==10|(u|0)==0)){gGr(u)}c[r>>2]=az;$=ay|1;c[n>>2]=$;aA=$&255}else{aA=s}if((aA&1)==0){a[S]=(av<<1)+2&255;aB=J;aC=av+1|0}else{$=c[r>>2]|0;t=av+1|0;c[h>>2]=t;aB=$;aC=t}a[aB+av|0]=au;a[aB+aC|0]=0;am=11266;break};case 4:{t=0;$=O;g=U;aa=w;ab=p;ae=M;af=an;L12991:while(1){ah=c[C>>2]|0;do{if((ah|0)==0){aD=0}else{if((c[ah+12>>2]|0)!=(c[ah+16>>2]|0)){aD=ah;break}if((gj[c[(c[ah>>2]|0)+36>>2]&4095](ah)|0)==-1){c[C>>2]=0;aD=0;break}else{aD=c[C>>2]|0;break}}}while(0);ah=(aD|0)==0;do{if((af|0)==0){am=11414}else{if((c[af+12>>2]|0)!=(c[af+16>>2]|0)){if(ah){aE=af;break}else{aF=af;break L12991}}if((gj[c[(c[af>>2]|0)+36>>2]&4095](af)|0)==-1){am=11414;break}if(ah){aE=af}else{aF=af;break L12991}}}while(0);if((am|0)==11414){am=0;if(ah){aF=0;break}else{aE=0}}ag=c[C>>2]|0;ad=c[ag+12>>2]|0;if((ad|0)==(c[ag+16>>2]|0)){aG=(gj[c[(c[ag>>2]|0)+36>>2]&4095](ag)|0)&255}else{aG=a[ad]|0}ad=aG<<24>>24;do{if((c4(ad|0)|0)==0){am=11435}else{if((b[(c[e>>2]|0)+(ad<<1)>>1]&2048)==0){am=11435;break}ag=c[o>>2]|0;if((ag|0)==(ae|0)){ac=(c[V>>2]|0)!=1380;aH=c[_>>2]|0;aI=ae-aH|0;aJ=aI>>>0<2147483647?aI<<1:-1;aK=gGs(ac?aH:0,aJ)|0;if((aK|0)==0){am=11425;break L12931}do{if(ac){c[_>>2]=aK;aL=aK}else{aH=c[_>>2]|0;c[_>>2]=aK;if((aH|0)==0){aL=aK;break}gf[c[V>>2]&2047](aH);aL=c[_>>2]|0}}while(0);c[V>>2]=382;aK=aL+aI|0;c[o>>2]=aK;aM=(c[_>>2]|0)+aJ|0;aN=aK}else{aM=ae;aN=ag}c[o>>2]=aN+1;a[aN]=aG;aO=t+1|0;aP=$;aQ=g;aR=aa;aS=ab;aT=aM}}while(0);if((am|0)==11435){am=0;ad=d[H]|0;if(!((t|0)!=0&(((ad&1|0)==0?ad>>>1:c[x>>2]|0)|0)!=0&aG<<24>>24==aj<<24>>24)){aF=aE;break}if((g|0)==($|0)){ad=g-aa|0;ah=ad>>>0<2147483647?ad<<1:-1;if((ab|0)==1380){aU=0}else{aU=aa}aK=gGs(aU,ah)|0;ac=aK;if((aK|0)==0){am=11440;break L12931}aV=ac+(ah>>>2<<2)|0;aW=ac+(ad>>2<<2)|0;aX=ac;aY=382}else{aV=$;aW=g;aX=aa;aY=ab}c[aW>>2]=t;aO=0;aP=aV;aQ=aW+4|0;aR=aX;aS=aY;aT=ae}ac=c[C>>2]|0;ad=ac+12|0;ah=c[ad>>2]|0;if((ah|0)==(c[ac+16>>2]|0)){aK=c[(c[ac>>2]|0)+40>>2]|0;gj[aK&4095](ac)|0;t=aO;$=aP;g=aQ;aa=aR;ab=aS;ae=aT;af=aE;continue}else{c[ad>>2]=ah+1;t=aO;$=aP;g=aQ;aa=aR;ab=aS;ae=aT;af=aE;continue}}if((aa|0)==(g|0)|(t|0)==0){aZ=$;a_=g;a$=aa;a0=ab}else{if((g|0)==($|0)){af=g-aa|0;s=af>>>0<2147483647?af<<1:-1;if((ab|0)==1380){a1=0}else{a1=aa}u=gGs(a1,s)|0;ah=u;if((u|0)==0){am=11452;break L12931}a2=ah+(s>>>2<<2)|0;a3=ah+(af>>2<<2)|0;a4=ah;a5=382}else{a2=$;a3=g;a4=aa;a5=ab}c[a3>>2]=t;aZ=a2;a_=a3+4|0;a$=a4;a0=a5}if((T|0)>0){ah=c[C>>2]|0;do{if((ah|0)==0){a6=0}else{if((c[ah+12>>2]|0)!=(c[ah+16>>2]|0)){a6=ah;break}if((gj[c[(c[ah>>2]|0)+36>>2]&4095](ah)|0)==-1){c[C>>2]=0;a6=0;break}else{a6=c[C>>2]|0;break}}}while(0);ah=(a6|0)==0;do{if((aF|0)==0){am=11468}else{if((c[aF+12>>2]|0)!=(c[aF+16>>2]|0)){if(ah){a7=aF;break}else{am=11475;break L12931}}if((gj[c[(c[aF>>2]|0)+36>>2]&4095](aF)|0)==-1){am=11468;break}if(ah){a7=aF}else{am=11475;break L12931}}}while(0);if((am|0)==11468){am=0;if(ah){am=11475;break L12931}else{a7=0}}t=c[C>>2]|0;ab=c[t+12>>2]|0;if((ab|0)==(c[t+16>>2]|0)){a8=(gj[c[(c[t>>2]|0)+36>>2]&4095](t)|0)&255}else{a8=a[ab]|0}if(a8<<24>>24!=ak<<24>>24){am=11475;break L12931}ab=c[C>>2]|0;t=ab+12|0;aa=c[t>>2]|0;if((aa|0)==(c[ab+16>>2]|0)){g=c[(c[ab>>2]|0)+40>>2]|0;gj[g&4095](ab)|0;a9=ae;ba=a7;bb=T;bc=a7}else{c[t>>2]=aa+1;a9=ae;ba=a7;bb=T;bc=a7}while(1){aa=c[C>>2]|0;do{if((aa|0)==0){bd=0}else{if((c[aa+12>>2]|0)!=(c[aa+16>>2]|0)){bd=aa;break}if((gj[c[(c[aa>>2]|0)+36>>2]&4095](aa)|0)==-1){c[C>>2]=0;bd=0;break}else{bd=c[C>>2]|0;break}}}while(0);aa=(bd|0)==0;do{if((ba|0)==0){be=bc;am=11490}else{if((c[ba+12>>2]|0)!=(c[ba+16>>2]|0)){if(aa){bf=ba;bg=bc;break}else{am=11499;break L12931}}if((gj[c[(c[ba>>2]|0)+36>>2]&4095](ba)|0)==-1){be=0;am=11490;break}if(aa){bf=ba;bg=bc}else{am=11499;break L12931}}}while(0);if((am|0)==11490){am=0;if(aa){am=11499;break L12931}else{bf=0;bg=be}}t=c[C>>2]|0;ab=c[t+12>>2]|0;if((ab|0)==(c[t+16>>2]|0)){bh=(gj[c[(c[t>>2]|0)+36>>2]&4095](t)|0)&255}else{bh=a[ab]|0}ab=bh<<24>>24;if((c4(ab|0)|0)==0){am=11499;break L12931}if((b[(c[e>>2]|0)+(ab<<1)>>1]&2048)==0){am=11499;break L12931}ab=c[o>>2]|0;if((ab|0)==(a9|0)){t=(c[V>>2]|0)!=1380;g=c[_>>2]|0;$=a9-g|0;af=$>>>0<2147483647?$<<1:-1;s=gGs(t?g:0,af)|0;if((s|0)==0){am=11502;break L12931}do{if(t){c[_>>2]=s;bi=s}else{g=c[_>>2]|0;c[_>>2]=s;if((g|0)==0){bi=s;break}gf[c[V>>2]&2047](g);bi=c[_>>2]|0}}while(0);c[V>>2]=382;s=bi+$|0;c[o>>2]=s;bj=(c[_>>2]|0)+af|0;bk=s}else{bj=a9;bk=ab}s=c[C>>2]|0;t=c[s+12>>2]|0;if((t|0)==(c[s+16>>2]|0)){aa=(gj[c[(c[s>>2]|0)+36>>2]&4095](s)|0)&255;bl=aa;bm=c[o>>2]|0}else{bl=a[t]|0;bm=bk}c[o>>2]=bm+1;a[bm]=bl;t=bb-1|0;aa=c[C>>2]|0;s=aa+12|0;g=c[s>>2]|0;if((g|0)==(c[aa+16>>2]|0)){u=c[(c[aa>>2]|0)+40>>2]|0;gj[u&4095](aa)|0}else{c[s>>2]=g+1}if((t|0)>0){a9=bj;ba=bf;bb=t;bc=bg}else{bn=bj;bo=t;bp=bg;break}}}else{bn=ae;bo=T;bp=aF}if((c[o>>2]|0)==(c[_>>2]|0)){am=11520;break L12931}else{bq=D;br=aZ;bs=a_;bt=a$;bu=a0;bv=bn;bw=bo;bx=bp}break};case 3:{ah=a[Q]|0;t=ah&255;g=(t&1|0)==0?t>>>1:c[A>>2]|0;t=a[R]|0;s=t&255;aa=(s&1|0)==0?s>>>1:c[Z>>2]|0;if((g|0)==(-aa|0)){bq=D;br=O;bs=U;bt=w;bu=p;bv=M;bw=T;bx=an;break L12951}s=(g|0)==0;g=c[C>>2]|0;u=c[g+12>>2]|0;ad=c[g+16>>2]|0;ac=(u|0)==(ad|0);if(!(s|(aa|0)==0)){if(ac){aa=(gj[c[(c[g>>2]|0)+36>>2]&4095](g)|0)&255;aK=c[C>>2]|0;by=aa;bz=a[Q]|0;bA=aK;bB=c[aK+12>>2]|0;bC=c[aK+16>>2]|0}else{by=a[u]|0;bz=ah;bA=g;bB=u;bC=ad}ad=bA+12|0;aK=(bB|0)==(bC|0);if(by<<24>>24==(a[(bz&1)==0?Y:c[X>>2]|0]|0)){if(aK){aa=c[(c[bA>>2]|0)+40>>2]|0;gj[aa&4095](bA)|0}else{c[ad>>2]=bB+1}ad=d[Q]|0;bq=((ad&1|0)==0?ad>>>1:c[A>>2]|0)>>>0>1?K:D;br=O;bs=U;bt=w;bu=p;bv=M;bw=T;bx=an;break L12951}if(aK){bD=(gj[c[(c[bA>>2]|0)+36>>2]&4095](bA)|0)&255}else{bD=a[bB]|0}if(bD<<24>>24!=(a[(a[R]&1)==0?m:c[B>>2]|0]|0)){am=11359;break L12931}aK=c[C>>2]|0;ad=aK+12|0;aa=c[ad>>2]|0;if((aa|0)==(c[aK+16>>2]|0)){aH=c[(c[aK>>2]|0)+40>>2]|0;gj[aH&4095](aK)|0}else{c[ad>>2]=aa+1}a[l]=1;aa=d[R]|0;bq=((aa&1|0)==0?aa>>>1:c[Z>>2]|0)>>>0>1?L:D;br=O;bs=U;bt=w;bu=p;bv=M;bw=T;bx=an;break L12951}if(s){if(ac){s=(gj[c[(c[g>>2]|0)+36>>2]&4095](g)|0)&255;bE=s;bF=a[R]|0}else{bE=a[u]|0;bF=t}if(bE<<24>>24!=(a[(bF&1)==0?m:c[B>>2]|0]|0)){bq=D;br=O;bs=U;bt=w;bu=p;bv=M;bw=T;bx=an;break L12951}t=c[C>>2]|0;s=t+12|0;aa=c[s>>2]|0;if((aa|0)==(c[t+16>>2]|0)){ad=c[(c[t>>2]|0)+40>>2]|0;gj[ad&4095](t)|0}else{c[s>>2]=aa+1}a[l]=1;aa=d[R]|0;bq=((aa&1|0)==0?aa>>>1:c[Z>>2]|0)>>>0>1?L:D;br=O;bs=U;bt=w;bu=p;bv=M;bw=T;bx=an;break L12951}if(ac){ac=(gj[c[(c[g>>2]|0)+36>>2]&4095](g)|0)&255;bG=ac;bH=a[Q]|0}else{bG=a[u]|0;bH=ah}if(bG<<24>>24!=(a[(bH&1)==0?Y:c[X>>2]|0]|0)){a[l]=1;bq=D;br=O;bs=U;bt=w;bu=p;bv=M;bw=T;bx=an;break L12951}ah=c[C>>2]|0;u=ah+12|0;ac=c[u>>2]|0;if((ac|0)==(c[ah+16>>2]|0)){g=c[(c[ah>>2]|0)+40>>2]|0;gj[g&4095](ah)|0}else{c[u>>2]=ac+1}ac=d[Q]|0;bq=((ac&1|0)==0?ac>>>1:c[A>>2]|0)>>>0>1?K:D;br=O;bs=U;bt=w;bu=p;bv=M;bw=T;bx=an;break};case 2:{if(!((D|0)!=0|v>>>0<2)){if((v|0)==2){bI=(a[W]|0)!=0}else{bI=0}if(!(z|bI)){bq=0;br=O;bs=U;bt=w;bu=p;bv=M;bw=T;bx=an;break L12951}}ac=a[P]|0;u=c[E>>2]|0;ah=(ac&1)==0?j:u;L13191:do{if((v|0)==0){bJ=ah;bK=ac;bL=u}else{if((d[F+(v-1)|0]|0)>=2){bJ=ah;bK=ac;bL=u;break}g=ac&255;L13194:do{if((((g&1|0)==0?g>>>1:c[y>>2]|0)|0)==0){bM=ah;bN=ac;bO=u}else{aa=ah;while(1){s=a[aa]|0;if((c4(s|0)|0)==0){break}if((b[(c[e>>2]|0)+(s<<1)>>1]&8192)==0){break}s=aa+1|0;t=a[P]|0;ad=c[E>>2]|0;aK=t&255;if((s|0)==(((t&1)==0?j:ad)+((aK&1|0)==0?aK>>>1:c[y>>2]|0)|0)){bM=s;bN=t;bO=ad;break L13194}else{aa=s}}bM=aa;bN=a[P]|0;bO=c[E>>2]|0}}while(0);g=(bN&1)==0?j:bO;ab=bM-g|0;af=a[S]|0;$=af&255;ag=($&1|0)==0?$>>>1:c[h>>2]|0;if(ab>>>0>ag>>>0){bJ=g;bK=bN;bL=bO;break}$=(af&1)==0?J:c[r>>2]|0;af=$+ag|0;if((bM|0)==(g|0)){bJ=bM;bK=bN;bL=bO;break}aJ=$+(ag-ab)|0;ab=g;while(1){if((a[aJ]|0)!=(a[ab]|0)){bJ=g;bK=bN;bL=bO;break L13191}ag=aJ+1|0;if((ag|0)==(af|0)){bJ=bM;bK=bN;bL=bO;break}else{aJ=ag;ab=ab+1|0}}}}while(0);ah=bK&255;L13208:do{if((bJ|0)==(((bK&1)==0?j:bL)+((ah&1|0)==0?ah>>>1:c[y>>2]|0)|0)){bP=bJ;bQ=an}else{u=an;ac=bJ;ae=an;while(1){ab=c[C>>2]|0;do{if((ab|0)==0){bR=0}else{if((c[ab+12>>2]|0)!=(c[ab+16>>2]|0)){bR=ab;break}if((gj[c[(c[ab>>2]|0)+36>>2]&4095](ab)|0)==-1){c[C>>2]=0;bR=0;break}else{bR=c[C>>2]|0;break}}}while(0);ab=(bR|0)==0;do{if((u|0)==0){bS=ae;am=11389}else{if((c[u+12>>2]|0)!=(c[u+16>>2]|0)){if(ab){bT=u;bU=ae;break}else{bP=ac;bQ=ae;break L13208}}if((gj[c[(c[u>>2]|0)+36>>2]&4095](u)|0)==-1){bS=0;am=11389;break}if(ab){bT=u;bU=ae}else{bP=ac;bQ=ae;break L13208}}}while(0);if((am|0)==11389){am=0;if(ab){bP=ac;bQ=bS;break L13208}else{bT=0;bU=bS}}aa=c[C>>2]|0;aJ=c[aa+12>>2]|0;if((aJ|0)==(c[aa+16>>2]|0)){bV=(gj[c[(c[aa>>2]|0)+36>>2]&4095](aa)|0)&255}else{bV=a[aJ]|0}if(bV<<24>>24!=(a[ac]|0)){bP=ac;bQ=bU;break L13208}aJ=c[C>>2]|0;aa=aJ+12|0;af=c[aa>>2]|0;if((af|0)==(c[aJ+16>>2]|0)){g=c[(c[aJ>>2]|0)+40>>2]|0;gj[g&4095](aJ)|0}else{c[aa>>2]=af+1}af=ac+1|0;aa=a[P]|0;aJ=aa&255;if((af|0)==(((aa&1)==0?j:c[E>>2]|0)+((aJ&1|0)==0?aJ>>>1:c[y>>2]|0)|0)){bP=af;bQ=bU;break}else{u=bT;ac=af;ae=bU}}}}while(0);if(!z){bq=D;br=O;bs=U;bt=w;bu=p;bv=M;bw=T;bx=bQ;break L12951}ah=a[P]|0;ae=ah&255;if((bP|0)==(((ah&1)==0?j:c[E>>2]|0)+((ae&1|0)==0?ae>>>1:c[y>>2]|0)|0)){bq=D;br=O;bs=U;bt=w;bu=p;bv=M;bw=T;bx=bQ}else{am=11402;break L12931}break};case 0:{am=11266;break};default:{bq=D;br=O;bs=U;bt=w;bu=p;bv=M;bw=T;bx=an}}}while(0);L13241:do{if((am|0)==11266){am=0;if((v|0)==3){ao=p;ap=w;aq=U;ar=D;as=an;am=11522;break L12931}else{bW=an;bX=an}while(1){f=c[C>>2]|0;do{if((f|0)==0){bY=0}else{if((c[f+12>>2]|0)!=(c[f+16>>2]|0)){bY=f;break}if((gj[c[(c[f>>2]|0)+36>>2]&4095](f)|0)==-1){c[C>>2]=0;bY=0;break}else{bY=c[C>>2]|0;break}}}while(0);f=(bY|0)==0;do{if((bW|0)==0){bZ=bX;am=11278}else{if((c[bW+12>>2]|0)!=(c[bW+16>>2]|0)){if(f){b_=bW;b$=bX;break}else{bq=D;br=O;bs=U;bt=w;bu=p;bv=M;bw=T;bx=bX;break L13241}}if((gj[c[(c[bW>>2]|0)+36>>2]&4095](bW)|0)==-1){bZ=0;am=11278;break}if(f){b_=bW;b$=bX}else{bq=D;br=O;bs=U;bt=w;bu=p;bv=M;bw=T;bx=bX;break L13241}}}while(0);if((am|0)==11278){am=0;if(f){bq=D;br=O;bs=U;bt=w;bu=p;bv=M;bw=T;bx=bZ;break L13241}else{b_=0;b$=bZ}}ae=c[C>>2]|0;ah=c[ae+12>>2]|0;if((ah|0)==(c[ae+16>>2]|0)){b0=(gj[c[(c[ae>>2]|0)+36>>2]&4095](ae)|0)&255}else{b0=a[ah]|0}ah=b0<<24>>24;if((c4(ah|0)|0)==0){bq=D;br=O;bs=U;bt=w;bu=p;bv=M;bw=T;bx=b$;break L13241}if((b[(c[e>>2]|0)+(ah<<1)>>1]&8192)==0){bq=D;br=O;bs=U;bt=w;bu=p;bv=M;bw=T;bx=b$;break L13241}ah=c[C>>2]|0;ae=ah+12|0;ac=c[ae>>2]|0;if((ac|0)==(c[ah+16>>2]|0)){b1=(gj[c[(c[ah>>2]|0)+40>>2]&4095](ah)|0)&255}else{c[ae>>2]=ac+1;b1=a[ac]|0}ac=a[S]|0;if((ac&1)==0){b2=(ac&255)>>>1;b3=10;b4=ac}else{ae=c[n>>2]|0;b2=c[h>>2]|0;b3=(ae&-2)-1|0;b4=ae&255}if((b2|0)==(b3|0)){if((b3|0)==-17){am=11296;break L12931}ae=(b4&1)==0?J:c[r>>2]|0;do{if(b3>>>0<2147483623){ah=b3+1|0;u=b3<<1;af=ah>>>0<u>>>0?u:ah;if(af>>>0<11){b5=11;break}b5=af+16&-16}else{b5=-17}}while(0);f=(b5|0)==0?1:b5;while(1){b6=gGq(f)|0;if((b6|0)!=0){break}af=(I=c[2439328]|0,c[2439328]=I+0,I);if((af|0)==0){am=11310;break L12931}gu[af&16383]()}gGC(b6|0,ae|0,b3)|0;if(!((b3|0)==10|(ae|0)==0)){gGr(ae)}c[r>>2]=b6;f=b5|1;c[n>>2]=f;b7=f&255}else{b7=ac}if((b7&1)==0){a[S]=(b2<<1)+2&255;b8=J;b9=b2+1|0}else{f=c[r>>2]|0;af=b2+1|0;c[h>>2]=af;b8=f;b9=af}a[b8+b2|0]=b1;a[b8+b9|0]=0;bW=b_;bX=b$}}}while(0);af=v+1|0;if(af>>>0<4){M=bv;p=bu;w=bt;U=bs;O=br;D=bq;v=af;T=bw;ai=bx}else{ao=bu;ap=bt;aq=bs;ar=bq;as=bx;am=11522;break}}L13301:do{if((am|0)==11296){gAq();return 0}else if((am|0)==11452){bx=f_(4)|0;c[bx>>2]=619768;eh(bx|0,625520,1206);return 0}else if((am|0)==11425){bx=f_(4)|0;c[bx>>2]=619768;eh(bx|0,625520,1206);return 0}else if((am|0)==11440){bx=f_(4)|0;c[bx>>2]=619768;eh(bx|0,625520,1206);return 0}else if((am|0)==11402){c[k>>2]=c[k>>2]|4;ca=0;cb=w;cc=p}else if((am|0)==11475){c[k>>2]=c[k>>2]|4;ca=0;cb=a$;cc=a0}else if((am|0)==11499){c[k>>2]=c[k>>2]|4;ca=0;cb=a$;cc=a0}else if((am|0)==11502){bx=f_(4)|0;c[bx>>2]=619768;eh(bx|0,625520,1206);return 0}else if((am|0)==11520){c[k>>2]=c[k>>2]|4;ca=0;cb=a$;cc=a0}else if((am|0)==11522){L13317:do{if((ar|0)!=0){bx=ar;bq=ar+1|0;bs=ar+8|0;bt=ar+4|0;bu=1;ai=as;L13319:while(1){bw=d[bx]|0;if((bw&1|0)==0){cd=bw>>>1}else{cd=c[bt>>2]|0}if(bu>>>0>=cd>>>0){break L13317}bw=c[C>>2]|0;do{if((bw|0)==0){ce=0}else{if((c[bw+12>>2]|0)!=(c[bw+16>>2]|0)){ce=bw;break}if((gj[c[(c[bw>>2]|0)+36>>2]&4095](bw)|0)==-1){c[C>>2]=0;ce=0;break}else{ce=c[C>>2]|0;break}}}while(0);bw=(ce|0)==0;do{if((ai|0)==0){am=11539}else{if((c[ai+12>>2]|0)!=(c[ai+16>>2]|0)){if(bw){cf=ai;break}else{break L13319}}if((gj[c[(c[ai>>2]|0)+36>>2]&4095](ai)|0)==-1){am=11539;break}if(bw){cf=ai}else{break L13319}}}while(0);if((am|0)==11539){am=0;if(bw){break}else{cf=0}}ac=c[C>>2]|0;ae=c[ac+12>>2]|0;if((ae|0)==(c[ac+16>>2]|0)){cg=(gj[c[(c[ac>>2]|0)+36>>2]&4095](ac)|0)&255}else{cg=a[ae]|0}if((a[bx]&1)==0){ch=bq}else{ch=c[bs>>2]|0}if(cg<<24>>24!=(a[ch+bu|0]|0)){break}ae=bu+1|0;ac=c[C>>2]|0;T=ac+12|0;v=c[T>>2]|0;if((v|0)==(c[ac+16>>2]|0)){D=c[(c[ac>>2]|0)+40>>2]|0;gj[D&4095](ac)|0;bu=ae;ai=cf;continue}else{c[T>>2]=v+1;bu=ae;ai=cf;continue}}c[k>>2]=c[k>>2]|4;ca=0;cb=ap;cc=ao;break L13301}}while(0);if((ap|0)==(aq|0)){ca=1;cb=aq;cc=ao;break}c[N>>2]=0;gDW(G,ap,aq,N);if((c[N>>2]|0)==0){ca=1;cb=ap;cc=ao;break}c[k>>2]=c[k>>2]|4;ca=0;cb=ap;cc=ao}else if((am|0)==11359){c[k>>2]=c[k>>2]|4;ca=0;cb=w;cc=p}else if((am|0)==11310){ai=f_(4)|0;c[ai>>2]=619768;eh(ai|0,625520,1206);return 0}else if((am|0)==11256){ai=f_(4)|0;c[ai>>2]=619768;eh(ai|0,625520,1206);return 0}else if((am|0)==11265){c[k>>2]=c[k>>2]|4;ca=0;cb=w;cc=p}else if((am|0)==11242){gAq();return 0}}while(0);do{if((a[S]&1)!=0){am=c[r>>2]|0;if((am|0)==0){break}gGr(am)}}while(0);do{if((a[R]&1)!=0){r=c[B>>2]|0;if((r|0)==0){break}gGr(r)}}while(0);do{if((a[Q]&1)!=0){B=c[X>>2]|0;if((B|0)==0){break}gGr(B)}}while(0);do{if((a[P]&1)!=0){X=c[E>>2]|0;if((X|0)==0){break}gGr(X)}}while(0);do{if((a[H]&1)!=0){E=c[G+8>>2]|0;if((E|0)==0){break}gGr(E)}}while(0);if((cb|0)==0){i=q;return ca|0}gf[cc&2047](cb);i=q;return ca|0}function gDU(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=f_(8)|0;c[b>>2]=619832;d=b+4|0;e=d;if((d|0)==0){eh(b|0,625552,314)}d=gGy(a|0)|0;f=d+13|0;g=(f|0)==0?1:f;while(1){h=gGq(g)|0;if((h|0)!=0){i=11593;break}f=(I=c[2439328]|0,c[2439328]=I+0,I);if((f|0)==0){i=11587;break}gu[f&16383]()}if((i|0)==11593){g=d+1|0;c[h+4>>2]=d;c[h>>2]=d;d=h+12|0;c[e>>2]=d;c[h+8>>2]=0;gGC(d|0,a|0,g)|0;eh(b|0,625552,314)}else if((i|0)==11587){i=f_(4)|0;c[i>>2]=619768;eh(i|0,625520,1206)}}function gDV(b,d,e,f,g,h,j,k){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;d=i;i=i+144|0;l=e;e=i;i=i+4|0;i=i+7&-8;c[e>>2]=c[l>>2];l=f;f=i;i=i+4|0;i=i+7&-8;c[f>>2]=c[l>>2];l=d|0;m=d+16|0;n=d+120|0;o=d+128|0;p=d+136|0;q=n|0;c[q>>2]=m;r=n+4|0;c[r>>2]=1380;s=m+100|0;m=c[h+28>>2]|0;t=m;u=m+4|0;I=c[u>>2]|0,c[u>>2]=I+1,I;if((c[2385060]|0)!=-1){c[l>>2]=9540240;c[l+4>>2]=180;c[l+8>>2]=0;gAp(9540240,l)}l=(c[2385061]|0)-1|0;u=c[m+8>>2]|0;do{if((c[m+12>>2]|0)-u>>2>>>0>l>>>0){v=c[u+(l<<2)>>2]|0;if((v|0)==0){break}w=v;a[p]=0;x=f|0;y=c[x>>2]|0;do{if(gDT(e,y,g,t,c[h+4>>2]|0,j,p,w,n,o,s)|0){z=k;if((a[z]&1)==0){a[k+1|0]=0;a[z]=0}else{a[c[k+8>>2]|0]=0;c[k+4>>2]=0}A=v;if((a[p]&1)!=0){B=gA[c[(c[A>>2]|0)+28>>2]&16383](w,45)|0;C=a[z]|0;if((C&1)==0){D=(C&255)>>>1;E=10}else{D=c[k+4>>2]|0;E=(c[k>>2]&-2)-1|0}if((D|0)==(E|0)){gAx(k,E,1,E,E,0);F=a[z]|0}else{F=C}if((F&1)==0){a[z]=(D<<1)+2&255;G=k+1|0;H=D+1|0}else{C=c[k+8>>2]|0;J=D+1|0;c[k+4>>2]=J;G=C;H=J}a[G+D|0]=B;a[G+H|0]=0}B=gA[c[(c[A>>2]|0)+28>>2]&16383](w,48)|0;A=c[o>>2]|0;J=A-1|0;C=c[q>>2]|0;while(1){if(C>>>0>=J>>>0){break}if((a[C]|0)==B<<24>>24){C=C+1|0}else{break}}B=C;J=a[z]|0;K=J&255;if((K&1|0)==0){L=K>>>1}else{L=c[k+4>>2]|0}if((J&1)==0){M=10;N=J}else{J=c[k>>2]|0;M=(J&-2)-1|0;N=J&255}J=A-B|0;if((A|0)==(C|0)){break}if((M-L|0)>>>0<J>>>0){gAx(k,M,L+J-M|0,L,L,0);O=a[z]|0}else{O=N}if((O&1)==0){P=k+1|0}else{P=c[k+8>>2]|0}K=A+(L-B)|0;B=C;Q=P+L|0;while(1){a[Q]=a[B]|0;R=B+1|0;if((R|0)==(A|0)){break}B=R;Q=Q+1|0}a[P+K|0]=0;Q=L+J|0;if((a[z]&1)==0){a[z]=Q<<1&255;break}else{c[k+4>>2]=Q;break}}}while(0);w=e|0;v=c[w>>2]|0;do{if((v|0)==0){S=0}else{if((c[v+12>>2]|0)!=(c[v+16>>2]|0)){S=v;break}if((gj[c[(c[v>>2]|0)+36>>2]&4095](v)|0)!=-1){S=v;break}c[w>>2]=0;S=0}}while(0);w=(S|0)==0;do{if((y|0)==0){T=11655}else{if((c[y+12>>2]|0)!=(c[y+16>>2]|0)){if(w){break}else{T=11657;break}}if((gj[c[(c[y>>2]|0)+36>>2]&4095](y)|0)==-1){c[x>>2]=0;T=11655;break}else{if(w){break}else{T=11657;break}}}}while(0);if((T|0)==11655){if(w){T=11657}}if((T|0)==11657){c[j>>2]=c[j>>2]|2}c[b>>2]=S;x=m+4|0;if(((I=c[x>>2]|0,c[x>>2]=I+ -1,I)|0)==0){gf[c[(c[m>>2]|0)+8>>2]&2047](m)}x=c[q>>2]|0;c[q>>2]=0;if((x|0)==0){i=d;return}gf[c[r>>2]&2047](x);i=d;return}}while(0);d=f_(4)|0;c[d>>2]=619800;eh(d|0,625536,1e3)}function gDW(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=b;h=b;i=a[h]|0;j=i&255;if((j&1|0)==0){k=j>>>1}else{k=c[b+4>>2]|0}if((k|0)==0){return}do{if((d|0)==(e|0)){l=i}else{k=e-4|0;if(k>>>0>d>>>0){m=d;n=k}else{l=i;break}do{k=c[m>>2]|0;c[m>>2]=c[n>>2];c[n>>2]=k;m=m+4|0;n=n-4|0;}while(m>>>0<n>>>0);l=a[h]|0}}while(0);if((l&1)==0){o=g+1|0}else{o=c[b+8>>2]|0}g=l&255;if((g&1|0)==0){p=g>>>1}else{p=c[b+4>>2]|0}b=e-4|0;e=a[o]|0;g=e<<24>>24;l=e<<24>>24<1|e<<24>>24==127;L13516:do{if(b>>>0>d>>>0){e=o+p|0;h=o;n=d;m=g;i=l;while(1){if(!i){if((m|0)!=(c[n>>2]|0)){break}}k=(e-h|0)>1?h+1|0:h;j=n+4|0;q=a[k]|0;r=q<<24>>24;s=q<<24>>24<1|q<<24>>24==127;if(j>>>0<b>>>0){h=k;n=j;m=r;i=s}else{t=r;u=s;break L13516}}c[f>>2]=4;return}else{t=g;u=l}}while(0);if(u){return}u=c[b>>2]|0;if(!(t>>>0<u>>>0|(u|0)==0)){return}c[f>>2]=4;return}function gDX(a){a=a|0;if((a|0)==0){return}gGr(a);return}function gDY(a){a=a|0;return}function gDZ(b,d,e,f,g,h,j,k){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;d=i;i=i+584|0;l=e;e=i;i=i+4|0;i=i+7&-8;c[e>>2]=c[l>>2];l=f;f=i;i=i+4|0;i=i+7&-8;c[f>>2]=c[l>>2];l=d|0;m=d+16|0;n=d+416|0;o=d+424|0;p=d+432|0;q=d+440|0;r=d+480|0;s=n|0;c[s>>2]=m;t=n+4|0;c[t>>2]=1380;u=m+400|0;m=c[h+28>>2]|0;v=m;w=m+4|0;I=c[w>>2]|0,c[w>>2]=I+1,I;if((c[2385058]|0)!=-1){c[l>>2]=9540232;c[l+4>>2]=180;c[l+8>>2]=0;gAp(9540232,l)}l=(c[2385059]|0)-1|0;w=c[m+8>>2]|0;do{if((c[m+12>>2]|0)-w>>2>>>0>l>>>0){x=c[w+(l<<2)>>2]|0;if((x|0)==0){break}y=x;a[p]=0;z=f|0;do{if(gD_(e,c[z>>2]|0,g,v,c[h+4>>2]|0,j,p,y,n,o,u)|0){A=q|0;B=c[(c[x>>2]|0)+48>>2]|0;gJ[B&31](y,590856,590866,A)|0;B=r|0;C=c[o>>2]|0;D=c[s>>2]|0;E=C-D|0;do{if((E|0)>392){F=gGq((E>>2)+2|0)|0;if((F|0)!=0){G=F;H=F;break}F=f_(4)|0;c[F>>2]=619768;eh(F|0,625520,1206)}else{G=B;H=0}}while(0);if((a[p]&1)==0){J=G}else{a[G]=45;J=G+1|0}if(D>>>0<C>>>0){E=q+40|0;F=q;K=J;L=D;while(1){M=A;while(1){if((M|0)==(E|0)){N=E;break}if((c[M>>2]|0)==(c[L>>2]|0)){N=M;break}else{M=M+4|0}}a[K]=a[590856+(N-F>>2)|0]|0;M=L+4|0;O=K+1|0;if(M>>>0<(c[o>>2]|0)>>>0){K=O;L=M}else{P=O;break}}}else{P=J}a[P]=0;L=fO(B|0,537664,(K=i,i=i+8|0,c[K>>2]=k,K)|0)|0;i=K;if((L|0)==1){if((H|0)==0){break}gGr(H);break}L=f_(8)|0;c[L>>2]=619832;K=L+4|0;F=K;do{if((K|0)!=0){while(1){Q=gGq(28)|0;if((Q|0)!=0){R=11748;break}E=(I=c[2439328]|0,c[2439328]=I+0,I);if((E|0)==0){break}gu[E&16383]()}if((R|0)==11748){c[Q+4>>2]=15;c[Q>>2]=15;E=Q+12|0;c[F>>2]=E;c[Q+8>>2]=0;gGC(E|0,524400,16)|0;break}E=f_(4)|0;c[E>>2]=619768;eh(E|0,625520,1206)}}while(0);eh(L|0,625552,314)}}while(0);y=e|0;x=c[y>>2]|0;do{if((x|0)==0){S=0}else{F=c[x+12>>2]|0;if((F|0)==(c[x+16>>2]|0)){T=gj[c[(c[x>>2]|0)+36>>2]&4095](x)|0}else{T=c[F>>2]|0}if((T|0)!=-1){S=x;break}c[y>>2]=0;S=0}}while(0);y=(S|0)==0;x=c[z>>2]|0;do{if((x|0)==0){R=11767}else{F=c[x+12>>2]|0;if((F|0)==(c[x+16>>2]|0)){U=gj[c[(c[x>>2]|0)+36>>2]&4095](x)|0}else{U=c[F>>2]|0}if((U|0)==-1){c[z>>2]=0;R=11767;break}else{if(y){break}else{R=11769;break}}}}while(0);if((R|0)==11767){if(y){R=11769}}if((R|0)==11769){c[j>>2]=c[j>>2]|2}c[b>>2]=S;z=m+4|0;if(((I=c[z>>2]|0,c[z>>2]=I+ -1,I)|0)==0){gf[c[(c[m>>2]|0)+8>>2]&2047](m)}z=c[s>>2]|0;c[s>>2]=0;if((z|0)==0){i=d;return}gf[c[t>>2]&2047](z);i=d;return}}while(0);d=f_(4)|0;c[d>>2]=619800;eh(d|0,625536,1e3)}function gD_(b,e,f,g,h,j,k,l,m,n,o){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0;p=i;i=i+592|0;q=p|0;r=p+16|0;s=p+32|0;t=p+40|0;u=p+56|0;v=p+72|0;w=p+88|0;x=p+104|0;y=p+112|0;z=p+128|0;A=p+144|0;B=p+160|0;C=p+176|0;D=p+184|0;E=p+584|0;F=E;G=i;i=i+12|0;i=i+7&-8;H=G;I=i;i=i+12|0;i=i+7&-8;J=i;i=i+12|0;i=i+7&-8;K=i;i=i+12|0;i=i+7&-8;L=i;i=i+12|0;i=i+7&-8;M=i;i=i+4|0;i=i+7&-8;c[C>>2]=o;o=D|0;gGz(H|0,0,12);N=I;O=J;P=K;Q=L;gGz(N|0,0,12);gGz(O|0,0,12);gGz(P|0,0,12);gGz(Q|0,0,12);R=t;S=u;T=v;U=w;V=y;W=z;X=A;Y=B;L13615:do{if(f){Z=s;if((c[2385174]|0)!=-1){c[r>>2]=9540696;c[r+4>>2]=180;c[r+8>>2]=0;gAp(9540696,r)}_=(c[2385175]|0)-1|0;$=c[g+8>>2]|0;do{if((c[g+12>>2]|0)-$>>2>>>0>_>>>0){aa=c[$+(_<<2)>>2]|0;if((aa|0)==0){break}ab=aa;gg[c[(c[aa>>2]|0)+44>>2]&4095](Z,ab);c[E>>2]=c[s>>2];ac=aa;gg[c[(c[ac>>2]|0)+32>>2]&4095](t,ab);if((a[P]&1)==0){c[K+4>>2]=0;a[P]=0}else{c[c[K+8>>2]>>2]=0;c[K+4>>2]=0}gAA(K);c[P>>2]=c[R>>2];c[P+4>>2]=c[R+4>>2];c[P+8>>2]=c[R+8>>2];gGz(R|0,0,12);gg[c[(c[ac>>2]|0)+28>>2]&4095](u,ab);if((a[O]&1)==0){c[J+4>>2]=0;a[O]=0}else{c[c[J+8>>2]>>2]=0;c[J+4>>2]=0}gAA(J);c[O>>2]=c[S>>2];c[O+4>>2]=c[S+4>>2];c[O+8>>2]=c[S+8>>2];gGz(S|0,0,12);ad=aa;ae=gj[c[(c[ad>>2]|0)+12>>2]&4095](ab)|0;af=gj[c[(c[ad>>2]|0)+16>>2]&4095](ab)|0;gg[c[(c[aa>>2]|0)+20>>2]&4095](v,ab);if((a[H]&1)==0){a[G+1|0]=0;a[H]=0}else{a[c[G+8>>2]|0]=0;c[G+4>>2]=0}gAu(G);c[H>>2]=c[T>>2];c[H+4>>2]=c[T+4>>2];c[H+8>>2]=c[T+8>>2];gGz(T|0,0,12);gg[c[(c[ac>>2]|0)+24>>2]&4095](w,ab);if((a[N]&1)==0){c[I+4>>2]=0;a[N]=0}else{c[c[I+8>>2]>>2]=0;c[I+4>>2]=0}gAA(I);c[N>>2]=c[U>>2];c[N+4>>2]=c[U+4>>2];c[N+8>>2]=c[U+8>>2];gGz(U|0,0,12);ag=gj[c[(c[ad>>2]|0)+36>>2]&4095](ab)|0;ah=af;ai=ae;break L13615}}while(0);Z=f_(4)|0;c[Z>>2]=619800;eh(Z|0,625536,1e3);return 0}else{Z=x;if((c[2385176]|0)!=-1){c[q>>2]=9540704;c[q+4>>2]=180;c[q+8>>2]=0;gAp(9540704,q)}_=(c[2385177]|0)-1|0;$=c[g+8>>2]|0;do{if((c[g+12>>2]|0)-$>>2>>>0>_>>>0){ae=c[$+(_<<2)>>2]|0;if((ae|0)==0){break}af=ae;gg[c[(c[ae>>2]|0)+44>>2]&4095](Z,af);c[E>>2]=c[x>>2];ab=ae;gg[c[(c[ab>>2]|0)+32>>2]&4095](y,af);if((a[P]&1)==0){c[K+4>>2]=0;a[P]=0}else{c[c[K+8>>2]>>2]=0;c[K+4>>2]=0}gAA(K);c[P>>2]=c[V>>2];c[P+4>>2]=c[V+4>>2];c[P+8>>2]=c[V+8>>2];gGz(V|0,0,12);gg[c[(c[ab>>2]|0)+28>>2]&4095](z,af);if((a[O]&1)==0){c[J+4>>2]=0;a[O]=0}else{c[c[J+8>>2]>>2]=0;c[J+4>>2]=0}gAA(J);c[O>>2]=c[W>>2];c[O+4>>2]=c[W+4>>2];c[O+8>>2]=c[W+8>>2];gGz(W|0,0,12);ad=ae;ac=gj[c[(c[ad>>2]|0)+12>>2]&4095](af)|0;aa=gj[c[(c[ad>>2]|0)+16>>2]&4095](af)|0;gg[c[(c[ae>>2]|0)+20>>2]&4095](A,af);if((a[H]&1)==0){a[G+1|0]=0;a[H]=0}else{a[c[G+8>>2]|0]=0;c[G+4>>2]=0}gAu(G);c[H>>2]=c[X>>2];c[H+4>>2]=c[X+4>>2];c[H+8>>2]=c[X+8>>2];gGz(X|0,0,12);gg[c[(c[ab>>2]|0)+24>>2]&4095](B,af);if((a[N]&1)==0){c[I+4>>2]=0;a[N]=0}else{c[c[I+8>>2]>>2]=0;c[I+4>>2]=0}gAA(I);c[N>>2]=c[Y>>2];c[N+4>>2]=c[Y+4>>2];c[N+8>>2]=c[Y+8>>2];gGz(Y|0,0,12);ag=gj[c[(c[ad>>2]|0)+36>>2]&4095](af)|0;ah=aa;ai=ac;break L13615}}while(0);Z=f_(4)|0;c[Z>>2]=619800;eh(Z|0,625536,1e3);return 0}}while(0);Y=m|0;c[n>>2]=c[Y>>2];B=b|0;b=l;X=K+4|0;A=K+8|0;W=J+4|0;z=J+8|0;V=(h&512|0)!=0;h=I+4|0;y=I+8|0;I=L+4|0;x=L+8|0;E=F+3|0;g=G+4|0;q=L|0;U=1380;w=o;T=o;o=D+400|0;D=0;v=0;S=ag;ag=e;L13689:while(1){e=c[B>>2]|0;do{if((e|0)==0){aj=1}else{u=c[e+12>>2]|0;if((u|0)==(c[e+16>>2]|0)){ak=gj[c[(c[e>>2]|0)+36>>2]&4095](e)|0}else{ak=c[u>>2]|0}if((ak|0)==-1){c[B>>2]=0;aj=1;break}else{aj=(c[B>>2]|0)==0;break}}}while(0);do{if((ag|0)==0){al=11866}else{e=c[ag+12>>2]|0;if((e|0)==(c[ag+16>>2]|0)){am=gj[c[(c[ag>>2]|0)+36>>2]&4095](ag)|0}else{am=c[e>>2]|0}if((am|0)==-1){al=11866;break}if(aj){an=ag}else{ao=U;ap=w;aq=T;ar=D;as=ag;al=12131;break L13689}}}while(0);if((al|0)==11866){al=0;if(aj){ao=U;ap=w;aq=T;ar=D;as=0;al=12131;break}else{an=0}}L13711:do{switch(a[F+v|0]|0){case 3:{e=a[O]|0;u=e&255;R=(u&1|0)==0?u>>>1:c[W>>2]|0;u=a[P]|0;t=u&255;s=(t&1|0)==0?t>>>1:c[X>>2]|0;if((R|0)==(-s|0)){at=D;au=o;av=T;aw=w;ax=U;ay=S;az=an;break L13711}t=(R|0)==0;R=c[B>>2]|0;r=c[R+12>>2]|0;f=c[R+16>>2]|0;Z=(r|0)==(f|0);if(!(t|(s|0)==0)){if(Z){s=gj[c[(c[R>>2]|0)+36>>2]&4095](R)|0;_=c[B>>2]|0;aA=s;aB=a[O]|0;aC=_;aD=c[_+12>>2]|0;aE=c[_+16>>2]|0}else{aA=c[r>>2]|0;aB=e;aC=R;aD=r;aE=f}f=aC+12|0;_=(aD|0)==(aE|0);if((aA|0)==(c[((aB&1)==0?W:c[z>>2]|0)>>2]|0)){if(_){s=c[(c[aC>>2]|0)+40>>2]|0;gj[s&4095](aC)|0}else{c[f>>2]=aD+4}f=d[O]|0;at=((f&1|0)==0?f>>>1:c[W>>2]|0)>>>0>1?J:D;au=o;av=T;aw=w;ax=U;ay=S;az=an;break L13711}if(_){aF=gj[c[(c[aC>>2]|0)+36>>2]&4095](aC)|0}else{aF=c[aD>>2]|0}if((aF|0)!=(c[((a[P]&1)==0?X:c[A>>2]|0)>>2]|0)){al=11989;break L13689}_=c[B>>2]|0;f=_+12|0;s=c[f>>2]|0;if((s|0)==(c[_+16>>2]|0)){$=c[(c[_>>2]|0)+40>>2]|0;gj[$&4095](_)|0}else{c[f>>2]=s+4}a[k]=1;s=d[P]|0;at=((s&1|0)==0?s>>>1:c[X>>2]|0)>>>0>1?K:D;au=o;av=T;aw=w;ax=U;ay=S;az=an;break L13711}if(t){if(Z){t=gj[c[(c[R>>2]|0)+36>>2]&4095](R)|0;aG=t;aH=a[P]|0}else{aG=c[r>>2]|0;aH=u}if((aG|0)!=(c[((aH&1)==0?X:c[A>>2]|0)>>2]|0)){at=D;au=o;av=T;aw=w;ax=U;ay=S;az=an;break L13711}u=c[B>>2]|0;t=u+12|0;s=c[t>>2]|0;if((s|0)==(c[u+16>>2]|0)){f=c[(c[u>>2]|0)+40>>2]|0;gj[f&4095](u)|0}else{c[t>>2]=s+4}a[k]=1;s=d[P]|0;at=((s&1|0)==0?s>>>1:c[X>>2]|0)>>>0>1?K:D;au=o;av=T;aw=w;ax=U;ay=S;az=an;break L13711}if(Z){Z=gj[c[(c[R>>2]|0)+36>>2]&4095](R)|0;aI=Z;aJ=a[O]|0}else{aI=c[r>>2]|0;aJ=e}if((aI|0)!=(c[((aJ&1)==0?W:c[z>>2]|0)>>2]|0)){a[k]=1;at=D;au=o;av=T;aw=w;ax=U;ay=S;az=an;break L13711}e=c[B>>2]|0;r=e+12|0;Z=c[r>>2]|0;if((Z|0)==(c[e+16>>2]|0)){R=c[(c[e>>2]|0)+40>>2]|0;gj[R&4095](e)|0}else{c[r>>2]=Z+4}Z=d[O]|0;at=((Z&1|0)==0?Z>>>1:c[W>>2]|0)>>>0>1?J:D;au=o;av=T;aw=w;ax=U;ay=S;az=an;break};case 2:{if(!((D|0)!=0|v>>>0<2)){if((v|0)==2){aK=(a[E]|0)!=0}else{aK=0}if(!(V|aK)){at=0;au=o;av=T;aw=w;ax=U;ay=S;az=an;break L13711}}Z=a[N]|0;r=c[y>>2]|0;e=(Z&1)==0?h:r;L13770:do{if((v|0)==0){aL=e;aM=Z;aN=r}else{if((d[F+(v-1)|0]|0)>=2){aL=e;aM=Z;aN=r;break}R=Z&255;L13773:do{if((((R&1|0)==0?R>>>1:c[h>>2]|0)|0)==0){aO=Z;aP=e;aQ=r}else{s=e;while(1){if(!(gp[c[(c[b>>2]|0)+12>>2]&16383](l,8192,c[s>>2]|0)|0)){break}t=s+4|0;u=a[N]|0;f=c[y>>2]|0;_=u&255;if((t|0)==(((u&1)==0?h:f)+(((_&1|0)==0?_>>>1:c[h>>2]|0)<<2)|0)){aO=u;aP=t;aQ=f;break L13773}else{s=t}}aO=a[N]|0;aP=s;aQ=c[y>>2]|0}}while(0);R=(aO&1)==0?h:aQ;t=aP-R>>2;f=a[Q]|0;u=f&255;_=(u&1|0)==0?u>>>1:c[I>>2]|0;if(t>>>0>_>>>0){aL=R;aM=aO;aN=aQ;break}u=(f&1)==0?I:c[x>>2]|0;f=u+(_<<2)|0;if((t|0)==0){aL=aP;aM=aO;aN=aQ;break}$=u+(_-t<<2)|0;t=R;while(1){if((c[$>>2]|0)!=(c[t>>2]|0)){aL=R;aM=aO;aN=aQ;break L13770}_=$+4|0;if((_|0)==(f|0)){aL=aP;aM=aO;aN=aQ;break}else{$=_;t=t+4|0}}}}while(0);e=aM&255;L13786:do{if((aL|0)==(((aM&1)==0?h:aN)+(((e&1|0)==0?e>>>1:c[h>>2]|0)<<2)|0)){aR=aL;aS=an}else{r=an;Z=aL;t=an;while(1){$=c[B>>2]|0;do{if(($|0)==0){aT=1}else{f=c[$+12>>2]|0;if((f|0)==(c[$+16>>2]|0)){aU=gj[c[(c[$>>2]|0)+36>>2]&4095]($)|0}else{aU=c[f>>2]|0}if((aU|0)==-1){c[B>>2]=0;aT=1;break}else{aT=(c[B>>2]|0)==0;break}}}while(0);do{if((r|0)==0){aV=t;al=12019}else{$=c[r+12>>2]|0;if(($|0)==(c[r+16>>2]|0)){aW=gj[c[(c[r>>2]|0)+36>>2]&4095](r)|0}else{aW=c[$>>2]|0}if((aW|0)==-1){aV=0;al=12019;break}if(aT){aX=r;aY=t}else{aR=Z;aS=t;break L13786}}}while(0);if((al|0)==12019){al=0;if(aT){aR=Z;aS=aV;break L13786}else{aX=0;aY=aV}}$=c[B>>2]|0;s=c[$+12>>2]|0;if((s|0)==(c[$+16>>2]|0)){aZ=gj[c[(c[$>>2]|0)+36>>2]&4095]($)|0}else{aZ=c[s>>2]|0}if((aZ|0)!=(c[Z>>2]|0)){aR=Z;aS=aY;break L13786}s=c[B>>2]|0;$=s+12|0;f=c[$>>2]|0;if((f|0)==(c[s+16>>2]|0)){R=c[(c[s>>2]|0)+40>>2]|0;gj[R&4095](s)|0}else{c[$>>2]=f+4}f=Z+4|0;$=a[N]|0;s=$&255;if((f|0)==((($&1)==0?h:c[y>>2]|0)+(((s&1|0)==0?s>>>1:c[h>>2]|0)<<2)|0)){aR=f;aS=aY;break}else{r=aX;Z=f;t=aY}}}}while(0);if(!V){at=D;au=o;av=T;aw=w;ax=U;ay=S;az=aS;break L13711}e=a[N]|0;t=e&255;if((aR|0)==(((e&1)==0?h:c[y>>2]|0)+(((t&1|0)==0?t>>>1:c[h>>2]|0)<<2)|0)){at=D;au=o;av=T;aw=w;ax=U;ay=S;az=aS}else{al=12031;break L13689}break};case 1:{if((v|0)==3){ao=U;ap=w;aq=T;ar=D;as=an;al=12131;break L13689}t=c[B>>2]|0;e=c[t+12>>2]|0;if((e|0)==(c[t+16>>2]|0)){a_=gj[c[(c[t>>2]|0)+36>>2]&4095](t)|0}else{a_=c[e>>2]|0}if(!(gp[c[(c[b>>2]|0)+12>>2]&16383](l,8192,a_)|0)){al=11916;break L13689}e=c[B>>2]|0;t=e+12|0;Z=c[t>>2]|0;if((Z|0)==(c[e+16>>2]|0)){a$=gj[c[(c[e>>2]|0)+40>>2]&4095](e)|0}else{c[t>>2]=Z+4;a$=c[Z>>2]|0}Z=a[Q]|0;if((Z&1)==0){a0=(Z&255)>>>1;a1=1}else{a0=c[I>>2]|0;a1=(c[q>>2]&-2)-1|0}if((a0|0)==(a1|0)){gAB(L,a1,1,a1,a1,0,0);a2=a[Q]|0}else{a2=Z}if((a2&1)==0){a[Q]=(a0<<1)+2&255;a3=I;a4=a0+1|0}else{Z=c[x>>2]|0;t=a0+1|0;c[I>>2]=t;a3=Z;a4=t}c[a3+(a0<<2)>>2]=a$;c[a3+(a4<<2)>>2]=0;al=11917;break};case 4:{t=0;Z=o;e=T;r=w;f=U;s=an;L13844:while(1){$=c[B>>2]|0;do{if(($|0)==0){a5=1}else{R=c[$+12>>2]|0;if((R|0)==(c[$+16>>2]|0)){a6=gj[c[(c[$>>2]|0)+36>>2]&4095]($)|0}else{a6=c[R>>2]|0}if((a6|0)==-1){c[B>>2]=0;a5=1;break}else{a5=(c[B>>2]|0)==0;break}}}while(0);do{if((s|0)==0){al=12044}else{$=c[s+12>>2]|0;if(($|0)==(c[s+16>>2]|0)){a7=gj[c[(c[s>>2]|0)+36>>2]&4095](s)|0}else{a7=c[$>>2]|0}if((a7|0)==-1){al=12044;break}if(a5){a8=s}else{a9=s;break L13844}}}while(0);if((al|0)==12044){al=0;if(a5){a9=0;break}else{a8=0}}$=c[B>>2]|0;R=c[$+12>>2]|0;if((R|0)==(c[$+16>>2]|0)){ba=gj[c[(c[$>>2]|0)+36>>2]&4095]($)|0}else{ba=c[R>>2]|0}if(gp[c[(c[b>>2]|0)+12>>2]&16383](l,2048,ba)|0){R=c[n>>2]|0;if((R|0)==(c[C>>2]|0)){gD0(m,n,C);bb=c[n>>2]|0}else{bb=R}c[n>>2]=bb+4;c[bb>>2]=ba;bc=t+1|0;bd=Z;be=e;bf=r;bg=f}else{R=d[H]|0;if(!((((((R&1|0)==0?R>>>1:c[g>>2]|0)|0)==0|(t|0)==0)^1)&(ba|0)==(ah|0))){a9=a8;break}if((e|0)==(Z|0)){R=e-r|0;$=R>>>0<2147483647?R<<1:-1;if((f|0)==1380){bh=0}else{bh=r}_=gGs(bh,$)|0;u=_;if((_|0)==0){al=12060;break L13689}bi=u+($>>>2<<2)|0;bj=u+(R>>2<<2)|0;bk=u;bl=382}else{bi=Z;bj=e;bk=r;bl=f}c[bj>>2]=t;bc=0;bd=bi;be=bj+4|0;bf=bk;bg=bl}u=c[B>>2]|0;R=u+12|0;$=c[R>>2]|0;if(($|0)==(c[u+16>>2]|0)){_=c[(c[u>>2]|0)+40>>2]|0;gj[_&4095](u)|0;t=bc;Z=bd;e=be;r=bf;f=bg;s=a8;continue}else{c[R>>2]=$+4;t=bc;Z=bd;e=be;r=bf;f=bg;s=a8;continue}}if((r|0)==(e|0)|(t|0)==0){bm=Z;bn=e;bo=r;bp=f}else{if((e|0)==(Z|0)){s=e-r|0;$=s>>>0<2147483647?s<<1:-1;if((f|0)==1380){bq=0}else{bq=r}R=gGs(bq,$)|0;u=R;if((R|0)==0){al=12072;break L13689}br=u+($>>>2<<2)|0;bs=u+(s>>2<<2)|0;bt=u;bu=382}else{br=Z;bs=e;bt=r;bu=f}c[bs>>2]=t;bm=br;bn=bs+4|0;bo=bt;bp=bu}if((S|0)>0){u=c[B>>2]|0;do{if((u|0)==0){bv=1}else{s=c[u+12>>2]|0;if((s|0)==(c[u+16>>2]|0)){bw=gj[c[(c[u>>2]|0)+36>>2]&4095](u)|0}else{bw=c[s>>2]|0}if((bw|0)==-1){c[B>>2]=0;bv=1;break}else{bv=(c[B>>2]|0)==0;break}}}while(0);do{if((a9|0)==0){al=12089}else{u=c[a9+12>>2]|0;if((u|0)==(c[a9+16>>2]|0)){bx=gj[c[(c[a9>>2]|0)+36>>2]&4095](a9)|0}else{bx=c[u>>2]|0}if((bx|0)==-1){al=12089;break}if(bv){by=a9}else{al=12095;break L13689}}}while(0);if((al|0)==12089){al=0;if(bv){al=12095;break L13689}else{by=0}}u=c[B>>2]|0;t=c[u+12>>2]|0;if((t|0)==(c[u+16>>2]|0)){bz=gj[c[(c[u>>2]|0)+36>>2]&4095](u)|0}else{bz=c[t>>2]|0}if((bz|0)!=(ai|0)){al=12095;break L13689}t=c[B>>2]|0;u=t+12|0;f=c[u>>2]|0;if((f|0)==(c[t+16>>2]|0)){r=c[(c[t>>2]|0)+40>>2]|0;gj[r&4095](t)|0;bA=by;bB=S;bC=by}else{c[u>>2]=f+4;bA=by;bB=S;bC=by}while(1){f=c[B>>2]|0;do{if((f|0)==0){bD=1}else{u=c[f+12>>2]|0;if((u|0)==(c[f+16>>2]|0)){bE=gj[c[(c[f>>2]|0)+36>>2]&4095](f)|0}else{bE=c[u>>2]|0}if((bE|0)==-1){c[B>>2]=0;bD=1;break}else{bD=(c[B>>2]|0)==0;break}}}while(0);do{if((bA|0)==0){bF=bC;al=12111}else{f=c[bA+12>>2]|0;if((f|0)==(c[bA+16>>2]|0)){bG=gj[c[(c[bA>>2]|0)+36>>2]&4095](bA)|0}else{bG=c[f>>2]|0}if((bG|0)==-1){bF=0;al=12111;break}if(bD){bH=bA;bI=bC}else{al=12118;break L13689}}}while(0);if((al|0)==12111){al=0;if(bD){al=12118;break L13689}else{bH=0;bI=bF}}f=c[B>>2]|0;u=c[f+12>>2]|0;if((u|0)==(c[f+16>>2]|0)){bJ=gj[c[(c[f>>2]|0)+36>>2]&4095](f)|0}else{bJ=c[u>>2]|0}if(!(gp[c[(c[b>>2]|0)+12>>2]&16383](l,2048,bJ)|0)){al=12118;break L13689}if((c[n>>2]|0)==(c[C>>2]|0)){gD0(m,n,C)}u=c[B>>2]|0;f=c[u+12>>2]|0;if((f|0)==(c[u+16>>2]|0)){bK=gj[c[(c[u>>2]|0)+36>>2]&4095](u)|0}else{bK=c[f>>2]|0}f=c[n>>2]|0;c[n>>2]=f+4;c[f>>2]=bK;f=bB-1|0;u=c[B>>2]|0;t=u+12|0;r=c[t>>2]|0;if((r|0)==(c[u+16>>2]|0)){e=c[(c[u>>2]|0)+40>>2]|0;gj[e&4095](u)|0}else{c[t>>2]=r+4}if((f|0)>0){bA=bH;bB=f;bC=bI}else{bL=f;bM=bI;break}}}else{bL=S;bM=a9}if((c[n>>2]|0)==(c[Y>>2]|0)){al=12129;break L13689}else{at=D;au=bm;av=bn;aw=bo;ax=bp;ay=bL;az=bM}break};case 0:{al=11917;break};default:{at=D;au=o;av=T;aw=w;ax=U;ay=S;az=an}}}while(0);L13971:do{if((al|0)==11917){al=0;if((v|0)==3){ao=U;ap=w;aq=T;ar=D;as=an;al=12131;break L13689}else{bN=an;bO=an}while(1){f=c[B>>2]|0;do{if((f|0)==0){bP=1}else{r=c[f+12>>2]|0;if((r|0)==(c[f+16>>2]|0)){bQ=gj[c[(c[f>>2]|0)+36>>2]&4095](f)|0}else{bQ=c[r>>2]|0}if((bQ|0)==-1){c[B>>2]=0;bP=1;break}else{bP=(c[B>>2]|0)==0;break}}}while(0);do{if((bN|0)==0){bR=bO;al=11930}else{f=c[bN+12>>2]|0;if((f|0)==(c[bN+16>>2]|0)){bS=gj[c[(c[bN>>2]|0)+36>>2]&4095](bN)|0}else{bS=c[f>>2]|0}if((bS|0)==-1){bR=0;al=11930;break}if(bP){bT=bN;bU=bO}else{at=D;au=o;av=T;aw=w;ax=U;ay=S;az=bO;break L13971}}}while(0);if((al|0)==11930){al=0;if(bP){at=D;au=o;av=T;aw=w;ax=U;ay=S;az=bR;break L13971}else{bT=0;bU=bR}}f=c[B>>2]|0;r=c[f+12>>2]|0;if((r|0)==(c[f+16>>2]|0)){bV=gj[c[(c[f>>2]|0)+36>>2]&4095](f)|0}else{bV=c[r>>2]|0}if(!(gp[c[(c[b>>2]|0)+12>>2]&16383](l,8192,bV)|0)){at=D;au=o;av=T;aw=w;ax=U;ay=S;az=bU;break L13971}r=c[B>>2]|0;f=r+12|0;t=c[f>>2]|0;if((t|0)==(c[r+16>>2]|0)){bW=gj[c[(c[r>>2]|0)+40>>2]&4095](r)|0}else{c[f>>2]=t+4;bW=c[t>>2]|0}t=a[Q]|0;if((t&1)==0){bX=(t&255)>>>1;bY=1}else{bX=c[I>>2]|0;bY=(c[q>>2]&-2)-1|0}if((bX|0)==(bY|0)){gAB(L,bY,1,bY,bY,0,0);bZ=a[Q]|0}else{bZ=t}if((bZ&1)==0){a[Q]=(bX<<1)+2&255;b_=I;b$=bX+1|0}else{t=c[x>>2]|0;f=bX+1|0;c[I>>2]=f;b_=t;b$=f}c[b_+(bX<<2)>>2]=bW;c[b_+(b$<<2)>>2]=0;bN=bT;bO=bU}}}while(0);f=v+1|0;if(f>>>0<4){U=ax;w=aw;T=av;o=au;D=at;v=f;S=ay;ag=az}else{ao=ax;ap=aw;aq=av;ar=at;as=az;al=12131;break}}L14018:do{if((al|0)==12072){az=f_(4)|0;c[az>>2]=619768;eh(az|0,625520,1206);return 0}else if((al|0)==12095){c[j>>2]=c[j>>2]|4;b0=0;b1=bo;b2=bp}else if((al|0)==12118){c[j>>2]=c[j>>2]|4;b0=0;b1=bo;b2=bp}else if((al|0)==11989){c[j>>2]=c[j>>2]|4;b0=0;b1=w;b2=U}else if((al|0)==12129){c[j>>2]=c[j>>2]|4;b0=0;b1=bo;b2=bp}else if((al|0)==12131){L14026:do{if((ar|0)!=0){az=ar;at=ar+4|0;av=ar+8|0;aw=1;ax=as;L14028:while(1){ag=d[az]|0;if((ag&1|0)==0){b3=ag>>>1}else{b3=c[at>>2]|0}if(aw>>>0>=b3>>>0){break L14026}ag=c[B>>2]|0;do{if((ag|0)==0){b4=1}else{ay=c[ag+12>>2]|0;if((ay|0)==(c[ag+16>>2]|0)){b5=gj[c[(c[ag>>2]|0)+36>>2]&4095](ag)|0}else{b5=c[ay>>2]|0}if((b5|0)==-1){c[B>>2]=0;b4=1;break}else{b4=(c[B>>2]|0)==0;break}}}while(0);do{if((ax|0)==0){al=12149}else{ag=c[ax+12>>2]|0;if((ag|0)==(c[ax+16>>2]|0)){b6=gj[c[(c[ax>>2]|0)+36>>2]&4095](ax)|0}else{b6=c[ag>>2]|0}if((b6|0)==-1){al=12149;break}if(b4){b7=ax}else{break L14028}}}while(0);if((al|0)==12149){al=0;if(b4){break}else{b7=0}}ag=c[B>>2]|0;ay=c[ag+12>>2]|0;if((ay|0)==(c[ag+16>>2]|0)){b8=gj[c[(c[ag>>2]|0)+36>>2]&4095](ag)|0}else{b8=c[ay>>2]|0}if((a[az]&1)==0){b9=at}else{b9=c[av>>2]|0}if((b8|0)!=(c[b9+(aw<<2)>>2]|0)){break}ay=aw+1|0;ag=c[B>>2]|0;S=ag+12|0;v=c[S>>2]|0;if((v|0)==(c[ag+16>>2]|0)){D=c[(c[ag>>2]|0)+40>>2]|0;gj[D&4095](ag)|0;aw=ay;ax=b7;continue}else{c[S>>2]=v+4;aw=ay;ax=b7;continue}}c[j>>2]=c[j>>2]|4;b0=0;b1=ap;b2=ao;break L14018}}while(0);if((ap|0)==(aq|0)){b0=1;b1=aq;b2=ao;break}c[M>>2]=0;gDW(G,ap,aq,M);if((c[M>>2]|0)==0){b0=1;b1=ap;b2=ao;break}c[j>>2]=c[j>>2]|4;b0=0;b1=ap;b2=ao}else if((al|0)==12060){ax=f_(4)|0;c[ax>>2]=619768;eh(ax|0,625520,1206);return 0}else if((al|0)==12031){c[j>>2]=c[j>>2]|4;b0=0;b1=w;b2=U}else if((al|0)==11916){c[j>>2]=c[j>>2]|4;b0=0;b1=w;b2=U}}while(0);do{if((a[Q]&1)!=0){U=c[x>>2]|0;if((U|0)==0){break}gGr(U)}}while(0);do{if((a[P]&1)!=0){x=c[A>>2]|0;if((x|0)==0){break}gGr(x)}}while(0);do{if((a[O]&1)!=0){A=c[z>>2]|0;if((A|0)==0){break}gGr(A)}}while(0);do{if((a[N]&1)!=0){z=c[y>>2]|0;if((z|0)==0){break}gGr(z)}}while(0);do{if((a[H]&1)!=0){y=c[G+8>>2]|0;if((y|0)==0){break}gGr(y)}}while(0);if((b1|0)==0){i=p;return b0|0}gf[b2&2047](b1);i=p;return b0|0}function gD$(b,d,e,f,g,h,j,k){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0;d=i;i=i+440|0;l=e;e=i;i=i+4|0;i=i+7&-8;c[e>>2]=c[l>>2];l=f;f=i;i=i+4|0;i=i+7&-8;c[f>>2]=c[l>>2];l=d|0;m=d+16|0;n=d+416|0;o=d+424|0;p=d+432|0;q=n|0;c[q>>2]=m;r=n+4|0;c[r>>2]=1380;s=m+400|0;m=c[h+28>>2]|0;t=m;u=m+4|0;I=c[u>>2]|0,c[u>>2]=I+1,I;if((c[2385058]|0)!=-1){c[l>>2]=9540232;c[l+4>>2]=180;c[l+8>>2]=0;gAp(9540232,l)}l=(c[2385059]|0)-1|0;u=c[m+8>>2]|0;do{if((c[m+12>>2]|0)-u>>2>>>0>l>>>0){v=c[u+(l<<2)>>2]|0;if((v|0)==0){break}w=v;a[p]=0;x=f|0;y=c[x>>2]|0;do{if(gD_(e,y,g,t,c[h+4>>2]|0,j,p,w,n,o,s)|0){z=k;if((a[z]&1)==0){c[k+4>>2]=0;a[z]=0}else{c[c[k+8>>2]>>2]=0;c[k+4>>2]=0}A=v;if((a[p]&1)!=0){B=gA[c[(c[A>>2]|0)+44>>2]&16383](w,45)|0;C=a[z]|0;if((C&1)==0){D=(C&255)>>>1;E=1}else{D=c[k+4>>2]|0;E=(c[k>>2]&-2)-1|0}if((D|0)==(E|0)){gAB(k,E,1,E,E,0,0);F=a[z]|0}else{F=C}if((F&1)==0){a[z]=(D<<1)+2&255;G=k+4|0;H=D+1|0}else{C=c[k+8>>2]|0;J=D+1|0;c[k+4>>2]=J;G=C;H=J}c[G+(D<<2)>>2]=B;c[G+(H<<2)>>2]=0}B=gA[c[(c[A>>2]|0)+44>>2]&16383](w,48)|0;A=c[o>>2]|0;J=A-4|0;C=c[q>>2]|0;while(1){if(C>>>0>=J>>>0){break}if((c[C>>2]|0)==(B|0)){C=C+4|0}else{break}}B=C;K=a[z]|0;L=K&255;if((L&1|0)==0){M=L>>>1}else{M=c[k+4>>2]|0}if((K&1)==0){N=1;O=K}else{K=c[k>>2]|0;N=(K&-2)-1|0;O=K&255}K=A-B>>2;if((K|0)==0){break}if((N-M|0)>>>0<K>>>0){gAB(k,N,M+K-N|0,M,M,0,0);P=a[z]|0}else{P=O}if((P&1)==0){Q=k+4|0}else{Q=c[k+8>>2]|0}L=Q+(M<<2)|0;if((C|0)==(A|0)){R=L}else{S=((J+(-B|0)|0)>>>2)+1|0;B=C;T=L;while(1){c[T>>2]=c[B>>2];L=B+4|0;if((L|0)==(A|0)){break}B=L;T=T+4|0}R=Q+(S+M<<2)|0}c[R>>2]=0;T=M+K|0;if((a[z]&1)==0){a[z]=T<<1&255;break}else{c[k+4>>2]=T;break}}}while(0);w=e|0;v=c[w>>2]|0;do{if((v|0)==0){U=0}else{T=c[v+12>>2]|0;if((T|0)==(c[v+16>>2]|0)){V=gj[c[(c[v>>2]|0)+36>>2]&4095](v)|0}else{V=c[T>>2]|0}if((V|0)!=-1){U=v;break}c[w>>2]=0;U=0}}while(0);w=(U|0)==0;do{if((y|0)==0){W=12245}else{v=c[y+12>>2]|0;if((v|0)==(c[y+16>>2]|0)){X=gj[c[(c[y>>2]|0)+36>>2]&4095](y)|0}else{X=c[v>>2]|0}if((X|0)==-1){c[x>>2]=0;W=12245;break}else{if(w){break}else{W=12247;break}}}}while(0);if((W|0)==12245){if(w){W=12247}}if((W|0)==12247){c[j>>2]=c[j>>2]|2}c[b>>2]=U;x=m+4|0;if(((I=c[x>>2]|0,c[x>>2]=I+ -1,I)|0)==0){gf[c[(c[m>>2]|0)+8>>2]&2047](m)}x=c[q>>2]|0;c[q>>2]=0;if((x|0)==0){i=d;return}gf[c[r>>2]&2047](x);i=d;return}}while(0);d=f_(4)|0;c[d>>2]=619800;eh(d|0,625536,1e3)}function gD0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=a+4|0;f=(c[e>>2]|0)!=1380;g=a|0;a=c[g>>2]|0;h=a;i=(c[d>>2]|0)-h|0;j=i>>>0<2147483647?i<<1:-1;i=(c[b>>2]|0)-h>>2;if(f){k=a}else{k=0}a=gGs(k,j)|0;k=a;if((a|0)==0){a=f_(4)|0;c[a>>2]=619768;eh(a|0,625520,1206)}do{if(f){c[g>>2]=k;l=k}else{a=c[g>>2]|0;c[g>>2]=k;if((a|0)==0){l=k;break}gf[c[e>>2]&2047](a);l=c[g>>2]|0}}while(0);c[e>>2]=382;c[b>>2]=l+(i<<2);c[d>>2]=(c[g>>2]|0)+(j>>>2<<2);return}function gD1(a){a=a|0;if((a|0)==0){return}gGr(a);return}function gD2(a){a=a|0;return}function gD3(b,e,f,g,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;j=j|0;k=k|0;l=+l;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;e=i;i=i+272|0;m=f;f=i;i=i+4|0;i=i+7&-8;c[f>>2]=c[m>>2];m=e|0;n=e+120|0;o=e+232|0;p=e+240|0;q=e+248|0;r=e+256|0;s=r;t=i;i=i+12|0;i=i+7&-8;u=t;v=i;i=i+12|0;i=i+7&-8;w=v;x=i;i=i+4|0;i=i+7&-8;y=i;i=i+100|0;i=i+7&-8;z=i;i=i+4|0;i=i+7&-8;A=i;i=i+4|0;i=i+7&-8;B=e+16|0;c[n>>2]=B;C=e+128|0;D=be(B|0,100,510696,(B=i,i=i+8|0,h[B>>3]=l,B)|0)|0;i=B;do{if(D>>>0>99){do{if((a[14125e3]|0)==0){if((bp(14125e3)|0)==0){break}c[2384150]=e6(2147483647,485280,0)|0}}while(0);E=gCq(n,c[2384150]|0,510696,(B=i,i=i+8|0,h[B>>3]=l,B)|0)|0;i=B;F=c[n>>2]|0;if((F|0)==0){G=f_(4)|0;c[G>>2]=619768;eh(G|0,625520,1206)}G=gGq(E)|0;if((G|0)!=0){H=G;J=E;K=F;L=G;break}G=f_(4)|0;c[G>>2]=619768;eh(G|0,625520,1206)}else{H=C;J=D;K=0;L=0}}while(0);D=c[j+28>>2]|0;C=D;B=D+4|0;I=c[B>>2]|0,c[B>>2]=I+1,I;if((c[2385060]|0)!=-1){c[m>>2]=9540240;c[m+4>>2]=180;c[m+8>>2]=0;gAp(9540240,m)}m=(c[2385061]|0)-1|0;B=c[D+8>>2]|0;do{if((c[D+12>>2]|0)-B>>2>>>0>m>>>0){G=c[B+(m<<2)>>2]|0;if((G|0)==0){break}F=G;E=c[n>>2]|0;M=E+J|0;N=c[(c[G>>2]|0)+32>>2]|0;gJ[N&31](F,E,M,H)|0;if((J|0)==0){O=0}else{O=(a[c[n>>2]|0]|0)==45}gGz(s|0,0,12);gGz(u|0,0,12);gGz(w|0,0,12);gD4(g,O,C,o,p,q,r,t,v,x);M=y|0;E=c[x>>2]|0;if((J|0)>(E|0)){N=d[w]|0;if((N&1|0)==0){P=N>>>1}else{P=c[v+4>>2]|0}N=d[u]|0;if((N&1|0)==0){Q=N>>>1}else{Q=c[t+4>>2]|0}R=P+(J-E<<1|1)+Q|0}else{N=d[w]|0;if((N&1|0)==0){S=N>>>1}else{S=c[v+4>>2]|0}N=d[u]|0;if((N&1|0)==0){T=N>>>1}else{T=c[t+4>>2]|0}R=S+2+T|0}N=R+E|0;do{if(N>>>0>100){G=gGq(N)|0;if((G|0)!=0){U=G;V=G;break}G=f_(4)|0;c[G>>2]=619768;eh(G|0,625520,1206)}else{U=M;V=0}}while(0);gD5(U,z,A,c[j+4>>2]|0,H,H+J|0,F,O,o,a[p]|0,a[q]|0,r,t,v,E);gCl(b,c[f>>2]|0,U,c[z>>2]|0,c[A>>2]|0,j,k);if((V|0)!=0){gGr(V)}do{if((a[w]&1)!=0){M=c[v+8>>2]|0;if((M|0)==0){break}gGr(M)}}while(0);do{if((a[u]&1)!=0){E=c[t+8>>2]|0;if((E|0)==0){break}gGr(E)}}while(0);do{if((a[s]&1)!=0){E=c[r+8>>2]|0;if((E|0)==0){break}gGr(E)}}while(0);E=D+4|0;if(((I=c[E>>2]|0,c[E>>2]=I+ -1,I)|0)==0){gf[c[(c[D>>2]|0)+8>>2]&2047](D)}if((L|0)!=0){gGr(L)}if((K|0)==0){i=e;return}gGr(K);i=e;return}}while(0);e=f_(4)|0;c[e>>2]=619800;eh(e|0,625536,1e3)}function gD4(b,d,e,f,g,h,j,k,l,m){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;n=i;i=i+40|0;o=n|0;p=n+16|0;q=n+32|0;r=q;s=i;i=i+12|0;i=i+7&-8;t=s;u=i;i=i+4|0;i=i+7&-8;v=u;w=i;i=i+12|0;i=i+7&-8;x=w;y=i;i=i+12|0;i=i+7&-8;z=y;A=i;i=i+12|0;i=i+7&-8;B=A;D=i;i=i+4|0;i=i+7&-8;E=D;F=i;i=i+12|0;i=i+7&-8;G=F;H=i;i=i+4|0;i=i+7&-8;I=H;J=i;i=i+12|0;i=i+7&-8;K=J;L=i;i=i+12|0;i=i+7&-8;M=L;N=i;i=i+12|0;i=i+7&-8;O=N;if(b){if((c[2385178]|0)!=-1){c[p>>2]=9540712;c[p+4>>2]=180;c[p+8>>2]=0;gAp(9540712,p)}p=(c[2385179]|0)-1|0;b=c[e+8>>2]|0;if((c[e+12>>2]|0)-b>>2>>>0<=p>>>0){P=f_(4)|0;Q=P;c[Q>>2]=619800;eh(P|0,625536,1e3)}R=c[b+(p<<2)>>2]|0;if((R|0)==0){P=f_(4)|0;Q=P;c[Q>>2]=619800;eh(P|0,625536,1e3)}P=R;Q=c[R>>2]|0;if(d){gg[c[Q+44>>2]&4095](r,P);r=f;C=c[q>>2]|0;a[r]=C&255;C=C>>8;a[r+1|0]=C&255;C=C>>8;a[r+2|0]=C&255;C=C>>8;a[r+3|0]=C&255;gg[c[(c[R>>2]|0)+32>>2]&4095](s,P);s=l;if((a[s]&1)==0){a[l+1|0]=0;a[s]=0}else{a[c[l+8>>2]|0]=0;c[l+4>>2]=0}gAu(l);c[s>>2]=c[t>>2];c[s+4>>2]=c[t+4>>2];c[s+8>>2]=c[t+8>>2];gGz(t|0,0,12)}else{gg[c[Q+40>>2]&4095](v,P);v=f;C=c[u>>2]|0;a[v]=C&255;C=C>>8;a[v+1|0]=C&255;C=C>>8;a[v+2|0]=C&255;C=C>>8;a[v+3|0]=C&255;gg[c[(c[R>>2]|0)+28>>2]&4095](w,P);w=l;if((a[w]&1)==0){a[l+1|0]=0;a[w]=0}else{a[c[l+8>>2]|0]=0;c[l+4>>2]=0}gAu(l);c[w>>2]=c[x>>2];c[w+4>>2]=c[x+4>>2];c[w+8>>2]=c[x+8>>2];gGz(x|0,0,12)}x=R;a[g]=gj[c[(c[x>>2]|0)+12>>2]&4095](P)|0;a[h]=gj[c[(c[x>>2]|0)+16>>2]&4095](P)|0;x=R;gg[c[(c[x>>2]|0)+20>>2]&4095](y,P);y=j;if((a[y]&1)==0){a[j+1|0]=0;a[y]=0}else{a[c[j+8>>2]|0]=0;c[j+4>>2]=0}gAu(j);c[y>>2]=c[z>>2];c[y+4>>2]=c[z+4>>2];c[y+8>>2]=c[z+8>>2];gGz(z|0,0,12);gg[c[(c[x>>2]|0)+24>>2]&4095](A,P);A=k;if((a[A]&1)==0){a[k+1|0]=0;a[A]=0}else{a[c[k+8>>2]|0]=0;c[k+4>>2]=0}gAu(k);c[A>>2]=c[B>>2];c[A+4>>2]=c[B+4>>2];c[A+8>>2]=c[B+8>>2];gGz(B|0,0,12);S=gj[c[(c[R>>2]|0)+36>>2]&4095](P)|0;c[m>>2]=S;i=n;return}else{if((c[2385180]|0)!=-1){c[o>>2]=9540720;c[o+4>>2]=180;c[o+8>>2]=0;gAp(9540720,o)}o=(c[2385181]|0)-1|0;P=c[e+8>>2]|0;if((c[e+12>>2]|0)-P>>2>>>0<=o>>>0){T=f_(4)|0;U=T;c[U>>2]=619800;eh(T|0,625536,1e3)}e=c[P+(o<<2)>>2]|0;if((e|0)==0){T=f_(4)|0;U=T;c[U>>2]=619800;eh(T|0,625536,1e3)}T=e;U=c[e>>2]|0;if(d){gg[c[U+44>>2]&4095](E,T);E=f;C=c[D>>2]|0;a[E]=C&255;C=C>>8;a[E+1|0]=C&255;C=C>>8;a[E+2|0]=C&255;C=C>>8;a[E+3|0]=C&255;gg[c[(c[e>>2]|0)+32>>2]&4095](F,T);F=l;if((a[F]&1)==0){a[l+1|0]=0;a[F]=0}else{a[c[l+8>>2]|0]=0;c[l+4>>2]=0}gAu(l);c[F>>2]=c[G>>2];c[F+4>>2]=c[G+4>>2];c[F+8>>2]=c[G+8>>2];gGz(G|0,0,12)}else{gg[c[U+40>>2]&4095](I,T);I=f;C=c[H>>2]|0;a[I]=C&255;C=C>>8;a[I+1|0]=C&255;C=C>>8;a[I+2|0]=C&255;C=C>>8;a[I+3|0]=C&255;gg[c[(c[e>>2]|0)+28>>2]&4095](J,T);J=l;if((a[J]&1)==0){a[l+1|0]=0;a[J]=0}else{a[c[l+8>>2]|0]=0;c[l+4>>2]=0}gAu(l);c[J>>2]=c[K>>2];c[J+4>>2]=c[K+4>>2];c[J+8>>2]=c[K+8>>2];gGz(K|0,0,12)}K=e;a[g]=gj[c[(c[K>>2]|0)+12>>2]&4095](T)|0;a[h]=gj[c[(c[K>>2]|0)+16>>2]&4095](T)|0;K=e;gg[c[(c[K>>2]|0)+20>>2]&4095](L,T);L=j;if((a[L]&1)==0){a[j+1|0]=0;a[L]=0}else{a[c[j+8>>2]|0]=0;c[j+4>>2]=0}gAu(j);c[L>>2]=c[M>>2];c[L+4>>2]=c[M+4>>2];c[L+8>>2]=c[M+8>>2];gGz(M|0,0,12);gg[c[(c[K>>2]|0)+24>>2]&4095](N,T);N=k;if((a[N]&1)==0){a[k+1|0]=0;a[N]=0}else{a[c[k+8>>2]|0]=0;c[k+4>>2]=0}gAu(k);c[N>>2]=c[O>>2];c[N+4>>2]=c[O+4>>2];c[N+8>>2]=c[O+8>>2];gGz(O|0,0,12);S=gj[c[(c[e>>2]|0)+36>>2]&4095](T)|0;c[m>>2]=S;i=n;return}}function gD5(d,e,f,g,h,i,j,k,l,m,n,o,p,q,r){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;q=q|0;r=r|0;var s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0;c[f>>2]=d;s=j;t=q;u=q+1|0;v=q+8|0;w=q+4|0;q=p;x=(g&512|0)==0;y=p+1|0;z=p+4|0;A=p+8|0;p=j+8|0;B=(r|0)>0;C=o;D=o+1|0;E=o+8|0;F=o+4|0;o=-r|0;G=r-1|0;H=(G|0)>0;I=h;h=0;while(1){L14367:do{switch(a[l+h|0]|0){case 1:{c[e>>2]=c[f>>2];J=gA[c[(c[s>>2]|0)+28>>2]&16383](j,32)|0;K=c[f>>2]|0;c[f>>2]=K+1;a[K]=J;L=I;break};case 0:{c[e>>2]=c[f>>2];L=I;break};case 4:{J=c[f>>2]|0;K=k?I+1|0:I;M=K;while(1){if(M>>>0>=i>>>0){break}N=a[M]|0;if(N<<24>>24<0){break}if((b[(c[p>>2]|0)+(N<<24>>24<<1)>>1]&2048)==0){break}else{M=M+1|0}}N=M;if(B){if(M>>>0>K>>>0){O=K+(-N|0)|0;N=O>>>0<o>>>0?o:O;O=N+r|0;P=M-1|0;Q=a[P]|0;c[f>>2]=J+1;a[J]=Q;if(P>>>0>K>>>0&H){Q=P;P=G;while(1){R=c[f>>2]|0;S=Q-1|0;T=a[S]|0;c[f>>2]=R+1;a[R]=T;T=P-1|0;R=(T|0)>0;if(S>>>0>K>>>0&R){Q=S;P=T}else{U=R;break}}}else{U=H}P=M+N|0;if(U){V=O;W=P;X=12465}else{Y=0;Z=O;_=P}}else{V=r;W=M;X=12465}if((X|0)==12465){X=0;Y=gA[c[(c[s>>2]|0)+28>>2]&16383](j,48)|0;Z=V;_=W}P=c[f>>2]|0;c[f>>2]=P+1;if((Z|0)>0){Q=Z;R=P;while(1){a[R]=Y;T=Q-1|0;S=c[f>>2]|0;c[f>>2]=S+1;if((T|0)>0){Q=T;R=S}else{$=S;break}}}else{$=P}a[$]=m;aa=_}else{aa=M}if((aa|0)==(K|0)){R=gA[c[(c[s>>2]|0)+28>>2]&16383](j,48)|0;Q=c[f>>2]|0;c[f>>2]=Q+1;a[Q]=R}else{R=a[C]|0;Q=R&255;if((Q&1|0)==0){ab=Q>>>1}else{ab=c[F>>2]|0}if((ab|0)==0){ac=aa;ad=0;ae=0;af=-1}else{if((R&1)==0){ag=D}else{ag=c[E>>2]|0}ac=aa;ad=0;ae=0;af=a[ag]|0}while(1){do{if((ad|0)==(af|0)){R=c[f>>2]|0;c[f>>2]=R+1;a[R]=n;R=ae+1|0;Q=a[C]|0;O=Q&255;if((O&1|0)==0){ah=O>>>1}else{ah=c[F>>2]|0}if(R>>>0>=ah>>>0){ai=af;aj=R;ak=0;break}O=(Q&1)==0;if(O){al=D}else{al=c[E>>2]|0}if((a[al+R|0]|0)==127){ai=-1;aj=R;ak=0;break}if(O){am=D}else{am=c[E>>2]|0}ai=a[am+R|0]|0;aj=R;ak=0}else{ai=af;aj=ae;ak=ad}}while(0);R=ac-1|0;O=a[R]|0;Q=c[f>>2]|0;c[f>>2]=Q+1;a[Q]=O;if((R|0)==(K|0)){break}else{ac=R;ad=ak+1|0;ae=aj;af=ai}}}M=c[f>>2]|0;if((J|0)==(M|0)){L=K;break L14367}P=M-1|0;if(J>>>0<P>>>0){an=J;ao=P}else{L=K;break L14367}while(1){P=a[an]|0;a[an]=a[ao]|0;a[ao]=P;P=an+1|0;M=ao-1|0;if(P>>>0<M>>>0){an=P;ao=M}else{L=K;break}}break};case 2:{K=a[q]|0;J=K&255;M=(J&1|0)==0;if(M){ap=J>>>1}else{ap=c[z>>2]|0}if((ap|0)==0|x){L=I;break L14367}if((K&1)==0){aq=y}else{aq=c[A>>2]|0}if(M){ar=J>>>1}else{ar=c[z>>2]|0}J=aq+ar|0;M=c[f>>2]|0;if((ar|0)==0){as=M}else{K=aq;P=M;while(1){a[P]=a[K]|0;R=K+1|0;if((R|0)==(J|0)){break}else{K=R;P=P+1|0}}as=M+ar|0}c[f>>2]=as;L=I;break};case 3:{P=a[t]|0;K=P&255;if((K&1|0)==0){at=K>>>1}else{at=c[w>>2]|0}if((at|0)==0){L=I;break L14367}if((P&1)==0){au=u}else{au=c[v>>2]|0}P=a[au]|0;K=c[f>>2]|0;c[f>>2]=K+1;a[K]=P;L=I;break};default:{L=I}}}while(0);P=h+1|0;if(P>>>0<4){I=L;h=P}else{break}}h=a[t]|0;t=h&255;L=(t&1|0)==0;if(L){av=t>>>1}else{av=c[w>>2]|0}if(av>>>0>1){if((h&1)==0){aw=u}else{aw=c[v>>2]|0}if(L){ax=t>>>1}else{ax=c[w>>2]|0}w=aw+ax|0;t=c[f>>2]|0;if((ax|0)==1){ay=t}else{L=ax-1|0;ax=t;v=aw+1|0;while(1){a[ax]=a[v]|0;aw=v+1|0;if((aw|0)==(w|0)){break}else{ax=ax+1|0;v=aw}}ay=t+L|0}c[f>>2]=ay}ay=g&176;if((ay|0)==32){c[e>>2]=c[f>>2];return}else if((ay|0)==16){return}else{c[e>>2]=d;return}}function gD6(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;e=i;i=i+56|0;l=f;f=i;i=i+4|0;i=i+7&-8;c[f>>2]=c[l>>2];l=e|0;m=e+16|0;n=e+24|0;o=e+32|0;p=e+40|0;q=p;r=i;i=i+12|0;i=i+7&-8;s=r;t=i;i=i+12|0;i=i+7&-8;u=t;v=i;i=i+4|0;i=i+7&-8;w=i;i=i+100|0;i=i+7&-8;x=i;i=i+4|0;i=i+7&-8;y=i;i=i+4|0;i=i+7&-8;z=c[h+28>>2]|0;A=z;B=z+4|0;I=c[B>>2]|0,c[B>>2]=I+1,I;if((c[2385060]|0)!=-1){c[l>>2]=9540240;c[l+4>>2]=180;c[l+8>>2]=0;gAp(9540240,l)}l=(c[2385061]|0)-1|0;B=c[z+8>>2]|0;do{if((c[z+12>>2]|0)-B>>2>>>0>l>>>0){C=c[B+(l<<2)>>2]|0;if((C|0)==0){break}D=C;E=k;F=k;G=a[F]|0;H=G&255;if((H&1|0)==0){J=H>>>1}else{J=c[k+4>>2]|0}if((J|0)==0){K=0}else{if((G&1)==0){L=E+1|0}else{L=c[k+8>>2]|0}G=a[L]|0;K=G<<24>>24==(gA[c[(c[C>>2]|0)+28>>2]&16383](D,45)|0)<<24>>24}gGz(q|0,0,12);gGz(s|0,0,12);gGz(u|0,0,12);gD4(g,K,A,m,n,o,p,r,t,v);C=w|0;G=a[F]|0;F=G&255;H=(F&1|0)==0;if(H){M=F>>>1}else{M=c[k+4>>2]|0}N=c[v>>2]|0;if((M|0)>(N|0)){if(H){O=F>>>1}else{O=c[k+4>>2]|0}P=d[u]|0;if((P&1|0)==0){Q=P>>>1}else{Q=c[t+4>>2]|0}P=d[s]|0;if((P&1|0)==0){R=P>>>1}else{R=c[r+4>>2]|0}S=Q+(O-N<<1|1)+R|0}else{P=d[u]|0;if((P&1|0)==0){T=P>>>1}else{T=c[t+4>>2]|0}P=d[s]|0;if((P&1|0)==0){U=P>>>1}else{U=c[r+4>>2]|0}S=T+2+U|0}P=S+N|0;do{if(P>>>0>100){V=gGq(P)|0;if((V|0)!=0){W=V;X=V;break}V=f_(4)|0;c[V>>2]=619768;eh(V|0,625520,1206)}else{W=C;X=0}}while(0);if((G&1)==0){Y=E+1|0}else{Y=c[k+8>>2]|0}if(H){Z=F>>>1}else{Z=c[k+4>>2]|0}gD5(W,x,y,c[h+4>>2]|0,Y,Y+Z|0,D,K,m,a[n]|0,a[o]|0,p,r,t,N);gCl(b,c[f>>2]|0,W,c[x>>2]|0,c[y>>2]|0,h,j);if((X|0)!=0){gGr(X)}do{if((a[u]&1)!=0){C=c[t+8>>2]|0;if((C|0)==0){break}gGr(C)}}while(0);do{if((a[s]&1)!=0){N=c[r+8>>2]|0;if((N|0)==0){break}gGr(N)}}while(0);do{if((a[q]&1)!=0){N=c[p+8>>2]|0;if((N|0)==0){break}gGr(N)}}while(0);N=z+4|0;if(((I=c[N>>2]|0,c[N>>2]=I+ -1,I)|0)!=0){i=e;return}gf[c[(c[z>>2]|0)+8>>2]&2047](z);i=e;return}}while(0);e=f_(4)|0;c[e>>2]=619800;eh(e|0,625536,1e3)}function gD7(a){a=a|0;if((a|0)==0){return}gGr(a);return}function gD8(a){a=a|0;return}function gD9(b,e,f,g,j,k,l){b=b|0;e=e|0;f=f|0;g=g|0;j=j|0;k=k|0;l=+l;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;e=i;i=i+568|0;m=f;f=i;i=i+4|0;i=i+7&-8;c[f>>2]=c[m>>2];m=e|0;n=e+120|0;o=e+528|0;p=e+536|0;q=e+544|0;r=e+552|0;s=r;t=i;i=i+12|0;i=i+7&-8;u=t;v=i;i=i+12|0;i=i+7&-8;w=v;x=i;i=i+4|0;i=i+7&-8;y=i;i=i+400|0;z=i;i=i+4|0;i=i+7&-8;A=i;i=i+4|0;i=i+7&-8;B=e+16|0;c[n>>2]=B;C=e+128|0;D=be(B|0,100,510696,(B=i,i=i+8|0,h[B>>3]=l,B)|0)|0;i=B;do{if(D>>>0>99){do{if((a[14125e3]|0)==0){if((bp(14125e3)|0)==0){break}c[2384150]=e6(2147483647,485280,0)|0}}while(0);E=gCq(n,c[2384150]|0,510696,(B=i,i=i+8|0,h[B>>3]=l,B)|0)|0;i=B;F=c[n>>2]|0;if((F|0)==0){G=f_(4)|0;c[G>>2]=619768;eh(G|0,625520,1206)}G=gGq(E<<2)|0;H=G;if((G|0)!=0){J=H;K=E;L=F;M=H;break}H=f_(4)|0;c[H>>2]=619768;eh(H|0,625520,1206)}else{J=C;K=D;L=0;M=0}}while(0);D=c[j+28>>2]|0;C=D;B=D+4|0;I=c[B>>2]|0,c[B>>2]=I+1,I;if((c[2385058]|0)!=-1){c[m>>2]=9540232;c[m+4>>2]=180;c[m+8>>2]=0;gAp(9540232,m)}m=(c[2385059]|0)-1|0;B=c[D+8>>2]|0;do{if((c[D+12>>2]|0)-B>>2>>>0>m>>>0){H=c[B+(m<<2)>>2]|0;if((H|0)==0){break}F=H;E=c[n>>2]|0;G=E+K|0;N=c[(c[H>>2]|0)+48>>2]|0;gJ[N&31](F,E,G,J)|0;if((K|0)==0){O=0}else{O=(a[c[n>>2]|0]|0)==45}gGz(s|0,0,12);gGz(u|0,0,12);gGz(w|0,0,12);gEa(g,O,C,o,p,q,r,t,v,x);G=y|0;E=c[x>>2]|0;if((K|0)>(E|0)){N=d[w]|0;if((N&1|0)==0){P=N>>>1}else{P=c[v+4>>2]|0}N=d[u]|0;if((N&1|0)==0){Q=N>>>1}else{Q=c[t+4>>2]|0}R=P+(K-E<<1|1)+Q|0}else{N=d[w]|0;if((N&1|0)==0){S=N>>>1}else{S=c[v+4>>2]|0}N=d[u]|0;if((N&1|0)==0){T=N>>>1}else{T=c[t+4>>2]|0}R=S+2+T|0}N=R+E|0;do{if(N>>>0>100){H=gGq(N<<2)|0;U=H;if((H|0)!=0){V=U;W=U;break}U=f_(4)|0;c[U>>2]=619768;eh(U|0,625520,1206)}else{V=G;W=0}}while(0);gEb(V,z,A,c[j+4>>2]|0,J,J+(K<<2)|0,F,O,o,c[p>>2]|0,c[q>>2]|0,r,t,v,E);gCz(b,c[f>>2]|0,V,c[z>>2]|0,c[A>>2]|0,j,k);if((W|0)!=0){gGr(W)}do{if((a[w]&1)!=0){G=c[v+8>>2]|0;if((G|0)==0){break}gGr(G)}}while(0);do{if((a[u]&1)!=0){E=c[t+8>>2]|0;if((E|0)==0){break}gGr(E)}}while(0);do{if((a[s]&1)!=0){E=c[r+8>>2]|0;if((E|0)==0){break}gGr(E)}}while(0);E=D+4|0;if(((I=c[E>>2]|0,c[E>>2]=I+ -1,I)|0)==0){gf[c[(c[D>>2]|0)+8>>2]&2047](D)}if((M|0)!=0){gGr(M)}if((L|0)==0){i=e;return}gGr(L);i=e;return}}while(0);e=f_(4)|0;c[e>>2]=619800;eh(e|0,625536,1e3)}function gEa(b,d,e,f,g,h,j,k,l,m){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;var n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;n=i;i=i+40|0;o=n|0;p=n+16|0;q=n+32|0;r=q;s=i;i=i+12|0;i=i+7&-8;t=s;u=i;i=i+4|0;i=i+7&-8;v=u;w=i;i=i+12|0;i=i+7&-8;x=w;y=i;i=i+12|0;i=i+7&-8;z=y;A=i;i=i+12|0;i=i+7&-8;B=A;D=i;i=i+4|0;i=i+7&-8;E=D;F=i;i=i+12|0;i=i+7&-8;G=F;H=i;i=i+4|0;i=i+7&-8;I=H;J=i;i=i+12|0;i=i+7&-8;K=J;L=i;i=i+12|0;i=i+7&-8;M=L;N=i;i=i+12|0;i=i+7&-8;O=N;if(b){if((c[2385174]|0)!=-1){c[p>>2]=9540696;c[p+4>>2]=180;c[p+8>>2]=0;gAp(9540696,p)}p=(c[2385175]|0)-1|0;b=c[e+8>>2]|0;if((c[e+12>>2]|0)-b>>2>>>0<=p>>>0){P=f_(4)|0;Q=P;c[Q>>2]=619800;eh(P|0,625536,1e3)}R=c[b+(p<<2)>>2]|0;if((R|0)==0){P=f_(4)|0;Q=P;c[Q>>2]=619800;eh(P|0,625536,1e3)}P=R;Q=c[R>>2]|0;if(d){gg[c[Q+44>>2]&4095](r,P);r=f;C=c[q>>2]|0;a[r]=C&255;C=C>>8;a[r+1|0]=C&255;C=C>>8;a[r+2|0]=C&255;C=C>>8;a[r+3|0]=C&255;gg[c[(c[R>>2]|0)+32>>2]&4095](s,P);s=l;if((a[s]&1)==0){c[l+4>>2]=0;a[s]=0}else{c[c[l+8>>2]>>2]=0;c[l+4>>2]=0}gAA(l);c[s>>2]=c[t>>2];c[s+4>>2]=c[t+4>>2];c[s+8>>2]=c[t+8>>2];gGz(t|0,0,12)}else{gg[c[Q+40>>2]&4095](v,P);v=f;C=c[u>>2]|0;a[v]=C&255;C=C>>8;a[v+1|0]=C&255;C=C>>8;a[v+2|0]=C&255;C=C>>8;a[v+3|0]=C&255;gg[c[(c[R>>2]|0)+28>>2]&4095](w,P);w=l;if((a[w]&1)==0){c[l+4>>2]=0;a[w]=0}else{c[c[l+8>>2]>>2]=0;c[l+4>>2]=0}gAA(l);c[w>>2]=c[x>>2];c[w+4>>2]=c[x+4>>2];c[w+8>>2]=c[x+8>>2];gGz(x|0,0,12)}x=R;c[g>>2]=gj[c[(c[x>>2]|0)+12>>2]&4095](P)|0;c[h>>2]=gj[c[(c[x>>2]|0)+16>>2]&4095](P)|0;gg[c[(c[R>>2]|0)+20>>2]&4095](y,P);y=j;if((a[y]&1)==0){a[j+1|0]=0;a[y]=0}else{a[c[j+8>>2]|0]=0;c[j+4>>2]=0}gAu(j);c[y>>2]=c[z>>2];c[y+4>>2]=c[z+4>>2];c[y+8>>2]=c[z+8>>2];gGz(z|0,0,12);gg[c[(c[R>>2]|0)+24>>2]&4095](A,P);A=k;if((a[A]&1)==0){c[k+4>>2]=0;a[A]=0}else{c[c[k+8>>2]>>2]=0;c[k+4>>2]=0}gAA(k);c[A>>2]=c[B>>2];c[A+4>>2]=c[B+4>>2];c[A+8>>2]=c[B+8>>2];gGz(B|0,0,12);S=gj[c[(c[x>>2]|0)+36>>2]&4095](P)|0;c[m>>2]=S;i=n;return}else{if((c[2385176]|0)!=-1){c[o>>2]=9540704;c[o+4>>2]=180;c[o+8>>2]=0;gAp(9540704,o)}o=(c[2385177]|0)-1|0;P=c[e+8>>2]|0;if((c[e+12>>2]|0)-P>>2>>>0<=o>>>0){T=f_(4)|0;U=T;c[U>>2]=619800;eh(T|0,625536,1e3)}e=c[P+(o<<2)>>2]|0;if((e|0)==0){T=f_(4)|0;U=T;c[U>>2]=619800;eh(T|0,625536,1e3)}T=e;U=c[e>>2]|0;if(d){gg[c[U+44>>2]&4095](E,T);E=f;C=c[D>>2]|0;a[E]=C&255;C=C>>8;a[E+1|0]=C&255;C=C>>8;a[E+2|0]=C&255;C=C>>8;a[E+3|0]=C&255;gg[c[(c[e>>2]|0)+32>>2]&4095](F,T);F=l;if((a[F]&1)==0){c[l+4>>2]=0;a[F]=0}else{c[c[l+8>>2]>>2]=0;c[l+4>>2]=0}gAA(l);c[F>>2]=c[G>>2];c[F+4>>2]=c[G+4>>2];c[F+8>>2]=c[G+8>>2];gGz(G|0,0,12)}else{gg[c[U+40>>2]&4095](I,T);I=f;C=c[H>>2]|0;a[I]=C&255;C=C>>8;a[I+1|0]=C&255;C=C>>8;a[I+2|0]=C&255;C=C>>8;a[I+3|0]=C&255;gg[c[(c[e>>2]|0)+28>>2]&4095](J,T);J=l;if((a[J]&1)==0){c[l+4>>2]=0;a[J]=0}else{c[c[l+8>>2]>>2]=0;c[l+4>>2]=0}gAA(l);c[J>>2]=c[K>>2];c[J+4>>2]=c[K+4>>2];c[J+8>>2]=c[K+8>>2];gGz(K|0,0,12)}K=e;c[g>>2]=gj[c[(c[K>>2]|0)+12>>2]&4095](T)|0;c[h>>2]=gj[c[(c[K>>2]|0)+16>>2]&4095](T)|0;gg[c[(c[e>>2]|0)+20>>2]&4095](L,T);L=j;if((a[L]&1)==0){a[j+1|0]=0;a[L]=0}else{a[c[j+8>>2]|0]=0;c[j+4>>2]=0}gAu(j);c[L>>2]=c[M>>2];c[L+4>>2]=c[M+4>>2];c[L+8>>2]=c[M+8>>2];gGz(M|0,0,12);gg[c[(c[e>>2]|0)+24>>2]&4095](N,T);N=k;if((a[N]&1)==0){c[k+4>>2]=0;a[N]=0}else{c[c[k+8>>2]>>2]=0;c[k+4>>2]=0}gAA(k);c[N>>2]=c[O>>2];c[N+4>>2]=c[O+4>>2];c[N+8>>2]=c[O+8>>2];gGz(O|0,0,12);S=gj[c[(c[K>>2]|0)+36>>2]&4095](T)|0;c[m>>2]=S;i=n;return}}function gEb(b,d,e,f,g,h,i,j,k,l,m,n,o,p,q){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;q=q|0;var r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0;c[e>>2]=b;r=i;s=p;t=p+4|0;u=p+8|0;p=o;v=(f&512|0)==0;w=o+4|0;x=o+8|0;o=i;y=(q|0)>0;z=n;A=n+1|0;B=n+8|0;C=n+4|0;n=g;g=0;while(1){L14726:do{switch(a[k+g|0]|0){case 0:{c[d>>2]=c[e>>2];D=n;break};case 3:{E=a[s]|0;F=E&255;if((F&1|0)==0){G=F>>>1}else{G=c[t>>2]|0}if((G|0)==0){D=n;break L14726}if((E&1)==0){H=t}else{H=c[u>>2]|0}E=c[H>>2]|0;F=c[e>>2]|0;c[e>>2]=F+4;c[F>>2]=E;D=n;break};case 1:{c[d>>2]=c[e>>2];E=gA[c[(c[r>>2]|0)+44>>2]&16383](i,32)|0;F=c[e>>2]|0;c[e>>2]=F+4;c[F>>2]=E;D=n;break};case 2:{E=a[p]|0;F=E&255;I=(F&1|0)==0;if(I){J=F>>>1}else{J=c[w>>2]|0}if((J|0)==0|v){D=n;break L14726}if((E&1)==0){K=w}else{K=c[x>>2]|0}if(I){L=F>>>1}else{L=c[w>>2]|0}F=K+(L<<2)|0;I=c[e>>2]|0;if((L|0)==0){M=I}else{E=K+(L-1<<2)+(-K|0)|0;N=K;O=I;while(1){c[O>>2]=c[N>>2];P=N+4|0;if((P|0)==(F|0)){break}N=P;O=O+4|0}M=I+((E>>>2)+1<<2)|0}c[e>>2]=M;D=n;break};case 4:{O=c[e>>2]|0;N=j?n+4|0:n;F=N;while(1){if(F>>>0>=h>>>0){break}if(gp[c[(c[o>>2]|0)+12>>2]&16383](i,2048,c[F>>2]|0)|0){F=F+4|0}else{break}}if(y){do{if(F>>>0>N>>>0){E=F;I=q;do{E=E-4|0;P=c[E>>2]|0;Q=c[e>>2]|0;c[e>>2]=Q+4;c[Q>>2]=P;I=I-1|0;R=(I|0)>0;}while(E>>>0>N>>>0&R);if(R){S=I;T=E;U=12789;break}P=c[e>>2]|0;c[e>>2]=P+4;V=P;W=E}else{S=q;T=F;U=12789}}while(0);do{if((U|0)==12789){U=0;P=gA[c[(c[r>>2]|0)+44>>2]&16383](i,48)|0;Q=c[e>>2]|0;c[e>>2]=Q+4;if((S|0)>0){X=S;Y=Q}else{V=Q;W=T;break}while(1){c[Y>>2]=P;Q=X-1|0;Z=c[e>>2]|0;c[e>>2]=Z+4;if((Q|0)>0){X=Q;Y=Z}else{V=Z;W=T;break}}}}while(0);c[V>>2]=l;_=W}else{_=F}if((_|0)==(N|0)){P=gA[c[(c[r>>2]|0)+44>>2]&16383](i,48)|0;E=c[e>>2]|0;c[e>>2]=E+4;c[E>>2]=P}else{P=a[z]|0;E=P&255;if((E&1|0)==0){$=E>>>1}else{$=c[C>>2]|0}if(($|0)==0){aa=_;ab=0;ac=0;ad=-1}else{if((P&1)==0){ae=A}else{ae=c[B>>2]|0}aa=_;ab=0;ac=0;ad=a[ae]|0}while(1){do{if((ab|0)==(ad|0)){P=c[e>>2]|0;c[e>>2]=P+4;c[P>>2]=m;P=ac+1|0;E=a[z]|0;I=E&255;if((I&1|0)==0){af=I>>>1}else{af=c[C>>2]|0}if(P>>>0>=af>>>0){ag=ad;ah=P;ai=0;break}I=(E&1)==0;if(I){aj=A}else{aj=c[B>>2]|0}if((a[aj+P|0]|0)==127){ag=-1;ah=P;ai=0;break}if(I){ak=A}else{ak=c[B>>2]|0}ag=a[ak+P|0]|0;ah=P;ai=0}else{ag=ad;ah=ac;ai=ab}}while(0);P=aa-4|0;I=c[P>>2]|0;E=c[e>>2]|0;c[e>>2]=E+4;c[E>>2]=I;if((P|0)==(N|0)){break}else{aa=P;ab=ai+1|0;ac=ah;ad=ag}}}F=c[e>>2]|0;if((O|0)==(F|0)){D=N;break L14726}P=F-4|0;if(O>>>0<P>>>0){al=O;am=P}else{D=N;break L14726}while(1){P=c[al>>2]|0;c[al>>2]=c[am>>2];c[am>>2]=P;P=al+4|0;F=am-4|0;if(P>>>0<F>>>0){al=P;am=F}else{D=N;break}}break};default:{D=n}}}while(0);N=g+1|0;if(N>>>0<4){n=D;g=N}else{break}}g=a[s]|0;s=g&255;D=(s&1|0)==0;if(D){an=s>>>1}else{an=c[t>>2]|0}if(an>>>0>1){if((g&1)==0){ao=t}else{ao=c[u>>2]|0}if(D){ap=s>>>1}else{ap=c[t>>2]|0}t=ao+(ap<<2)|0;s=c[e>>2]|0;if((ap|0)==1){aq=s}else{D=(ao+(ap-2<<2)+(-ao|0)|0)>>>2;ap=s;u=ao+4|0;while(1){c[ap>>2]=c[u>>2];ao=u+4|0;if((ao|0)==(t|0)){break}else{ap=ap+4|0;u=ao}}aq=s+(D+1<<2)|0}c[e>>2]=aq}aq=f&176;if((aq|0)==32){c[d>>2]=c[e>>2];return}else if((aq|0)==16){return}else{c[d>>2]=b;return}}function gEc(b,e,f,g,h,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;e=i;i=i+56|0;l=f;f=i;i=i+4|0;i=i+7&-8;c[f>>2]=c[l>>2];l=e|0;m=e+16|0;n=e+24|0;o=e+32|0;p=e+40|0;q=p;r=i;i=i+12|0;i=i+7&-8;s=r;t=i;i=i+12|0;i=i+7&-8;u=t;v=i;i=i+4|0;i=i+7&-8;w=i;i=i+400|0;x=i;i=i+4|0;i=i+7&-8;y=i;i=i+4|0;i=i+7&-8;z=c[h+28>>2]|0;A=z;B=z+4|0;I=c[B>>2]|0,c[B>>2]=I+1,I;if((c[2385058]|0)!=-1){c[l>>2]=9540232;c[l+4>>2]=180;c[l+8>>2]=0;gAp(9540232,l)}l=(c[2385059]|0)-1|0;B=c[z+8>>2]|0;do{if((c[z+12>>2]|0)-B>>2>>>0>l>>>0){C=c[B+(l<<2)>>2]|0;if((C|0)==0){break}D=C;E=k;F=a[E]|0;G=F&255;if((G&1|0)==0){H=G>>>1}else{H=c[k+4>>2]|0}if((H|0)==0){J=0}else{if((F&1)==0){K=k+4|0}else{K=c[k+8>>2]|0}F=c[K>>2]|0;J=(F|0)==(gA[c[(c[C>>2]|0)+44>>2]&16383](D,45)|0)}gGz(q|0,0,12);gGz(s|0,0,12);gGz(u|0,0,12);gEa(g,J,A,m,n,o,p,r,t,v);C=w|0;F=a[E]|0;E=F&255;G=(E&1|0)==0;if(G){L=E>>>1}else{L=c[k+4>>2]|0}M=c[v>>2]|0;if((L|0)>(M|0)){if(G){N=E>>>1}else{N=c[k+4>>2]|0}O=d[u]|0;if((O&1|0)==0){P=O>>>1}else{P=c[t+4>>2]|0}O=d[s]|0;if((O&1|0)==0){Q=O>>>1}else{Q=c[r+4>>2]|0}R=P+(N-M<<1|1)+Q|0}else{O=d[u]|0;if((O&1|0)==0){S=O>>>1}else{S=c[t+4>>2]|0}O=d[s]|0;if((O&1|0)==0){T=O>>>1}else{T=c[r+4>>2]|0}R=S+2+T|0}O=R+M|0;do{if(O>>>0>100){U=gGq(O<<2)|0;V=U;if((U|0)!=0){W=V;X=V;break}V=f_(4)|0;c[V>>2]=619768;eh(V|0,625520,1206)}else{W=C;X=0}}while(0);if((F&1)==0){Y=k+4|0}else{Y=c[k+8>>2]|0}if(G){Z=E>>>1}else{Z=c[k+4>>2]|0}gEb(W,x,y,c[h+4>>2]|0,Y,Y+(Z<<2)|0,D,J,m,c[n>>2]|0,c[o>>2]|0,p,r,t,M);gCz(b,c[f>>2]|0,W,c[x>>2]|0,c[y>>2]|0,h,j);if((X|0)!=0){gGr(X)}do{if((a[u]&1)!=0){C=c[t+8>>2]|0;if((C|0)==0){break}gGr(C)}}while(0);do{if((a[s]&1)!=0){M=c[r+8>>2]|0;if((M|0)==0){break}gGr(M)}}while(0);do{if((a[q]&1)!=0){M=c[p+8>>2]|0;if((M|0)==0){break}gGr(M)}}while(0);M=z+4|0;if(((I=c[M>>2]|0,c[M>>2]=I+ -1,I)|0)!=0){i=e;return}gf[c[(c[z>>2]|0)+8>>2]&2047](z);i=e;return}}while(0);e=f_(4)|0;c[e>>2]=619800;eh(e|0,625536,1e3)}function gEd(a){a=a|0;if((a|0)==0){return}gGr(a);return}function gEe(a){a=a|0;return}function gEf(b,d,e){b=b|0;d=d|0;e=e|0;var f=0;if((a[d]&1)==0){f=d+1|0}else{f=c[d+8>>2]|0}d=dn(f|0,1)|0;return d>>>(((d|0)!=-1|0)>>>0)|0}function gEg(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;d=i;i=i+16|0;j=d|0;k=j;gGz(k|0,0,12);l=b;m=a[h]|0;if((m&1)==0){n=h+1|0}else{n=c[h+8>>2]|0}o=m&255;if((o&1|0)==0){p=o>>>1}else{p=c[h+4>>2]|0}h=n+p|0;do{if((p|0)>0){o=j+1|0;m=j+8|0;q=j|0;r=j+4|0;s=n;t=0;L14943:while(1){u=a[s]|0;if((t&1)==0){v=(t&255)>>>1;w=10;x=t}else{y=c[q>>2]|0;v=c[r>>2]|0;w=(y&-2)-1|0;x=y&255}if((v|0)==(w|0)){if((w|0)==-17){z=12943;break}y=(x&1)==0?o:c[m>>2]|0;do{if(w>>>0<2147483623){A=w+1|0;B=w<<1;C=A>>>0<B>>>0?B:A;if(C>>>0<11){D=11;break}D=C+16&-16}else{D=-17}}while(0);C=(D|0)==0?1:D;while(1){E=gGq(C)|0;if((E|0)!=0){break}A=(I=c[2439328]|0,c[2439328]=I+0,I);if((A|0)==0){z=12957;break L14943}gu[A&16383]()}gGC(E|0,y|0,w)|0;if(!((w|0)==10|(y|0)==0)){gGr(y)}c[m>>2]=E;C=D|1;c[q>>2]=C;F=C&255}else{F=t}if((F&1)==0){a[k]=(v<<1)+2&255;G=o;H=v+1|0}else{C=c[m>>2]|0;A=v+1|0;c[r>>2]=A;G=C;H=A}a[G+v|0]=u;a[G+H|0]=0;A=s+1|0;J=a[k]|0;if(A>>>0<h>>>0){s=A;t=J}else{z=12966;break}}if((z|0)==12943){gAq()}else if((z|0)==12966){K=(J&1)==0?o:c[m>>2]|0;L=(e|0)==-1?-1:e<<1;break}else if((z|0)==12957){t=f_(4)|0;c[t>>2]=619768;eh(t|0,625520,1206)}}else{K=j+1|0;L=(e|0)==-1?-1:e<<1}}while(0);e=cG(L|0,f|0,g|0,K|0)|0;gGz(l|0,0,12);K=gGy(e|0)|0;g=e+K|0;L14978:do{if((K|0)>0){f=b+1|0;L=b+8|0;z=b+4|0;J=b|0;h=e;H=0;while(1){G=a[h]|0;if((H&1)==0){M=(H&255)>>>1;N=10}else{M=c[z>>2]|0;N=(c[J>>2]&-2)-1|0}if((M|0)==(N|0)){gAx(b,N,1,N,N,0);O=a[l]|0}else{O=H}if((O&1)==0){a[l]=(M<<1)+2&255;P=f;Q=M+1|0}else{v=c[L>>2]|0;F=M+1|0;c[z>>2]=F;P=v;Q=F}a[P+M|0]=G;a[P+Q|0]=0;G=h+1|0;if(G>>>0>=g>>>0){break L14978}h=G;H=a[l]|0}}}while(0);if((a[k]&1)==0){i=d;return}k=c[j+8>>2]|0;if((k|0)==0){i=d;return}gGr(k);i=d;return}function gEh(a,b){a=a|0;b=b|0;bR(((b|0)==-1?-1:b<<1)|0)|0;return}function gEi(a){a=a|0;if((a|0)==0){return}gGr(a);return}function gEj(a){a=a|0;return}function gEk(b,d,e){b=b|0;d=d|0;e=e|0;var f=0;if((a[d]&1)==0){f=d+1|0}else{f=c[d+8>>2]|0}d=dn(f|0,1)|0;return d>>>(((d|0)!=-1|0)>>>0)|0}function gEl(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0;d=i;i=i+224|0;j=d|0;k=d+8|0;l=d+40|0;m=d+48|0;n=d+56|0;o=d+64|0;p=d+192|0;q=d+200|0;r=d+208|0;s=r;t=i;i=i+8|0;u=i;i=i+8|0;gGz(s|0,0,12);v=b;w=t|0;c[t+4>>2]=0;c[t>>2]=621464;x=a[h]|0;if((x&1)==0){y=h+4|0}else{y=c[h+8>>2]|0}z=x&255;if((z&1|0)==0){A=z>>>1}else{A=c[h+4>>2]|0}h=y+(A<<2)|0;do{if((A|0)>0){z=t;x=k|0;B=k+32|0;C=r+1|0;D=r+8|0;E=r|0;F=r+4|0;G=y;H=621464;L15027:while(1){c[m>>2]=G;J=(gI[c[H+12>>2]&31](w,j,G,h,m,x,B,l)|0)==2;K=c[m>>2]|0;if(J|(K|0)==(G|0)){L=13022;break}if(x>>>0<(c[l>>2]|0)>>>0){J=x;do{M=a[J]|0;N=a[s]|0;if((N&1)==0){O=(N&255)>>>1;P=10;Q=N}else{R=c[E>>2]|0;O=c[F>>2]|0;P=(R&-2)-1|0;Q=R&255}if((O|0)==(P|0)){if((P|0)==-17){L=13047;break L15027}R=(Q&1)==0?C:c[D>>2]|0;do{if(P>>>0<2147483623){S=P+1|0;T=P<<1;U=S>>>0<T>>>0?T:S;if(U>>>0<11){V=11;break}V=U+16&-16}else{V=-17}}while(0);U=(V|0)==0?1:V;while(1){W=gGq(U)|0;if((W|0)!=0){break}S=(I=c[2439328]|0,c[2439328]=I+0,I);if((S|0)==0){L=13061;break L15027}gu[S&16383]()}gGC(W|0,R|0,P)|0;if(!((P|0)==10|(R|0)==0)){gGr(R)}c[D>>2]=W;U=V|1;c[E>>2]=U;X=U&255}else{X=N}if((X&1)==0){a[s]=(O<<1)+2&255;Y=C;Z=O+1|0}else{U=c[D>>2]|0;S=O+1|0;c[F>>2]=S;Y=U;Z=S}a[Y+O|0]=M;a[Y+Z|0]=0;J=J+1|0;}while(J>>>0<(c[l>>2]|0)>>>0);_=c[m>>2]|0}else{_=K}if(_>>>0>=h>>>0){L=13073;break}G=_;H=c[z>>2]|0}if((L|0)==13061){z=f_(4)|0;c[z>>2]=619768;eh(z|0,625520,1206)}else if((L|0)==13073){$=(a[s]&1)==0?C:c[D>>2]|0;aa=(e|0)==-1?-1:e<<1;break}else if((L|0)==13022){z=f_(8)|0;c[z>>2]=619832;H=z+4|0;G=H;do{if((H|0)!=0){while(1){ab=gGq(33)|0;if((ab|0)!=0){L=13037;break}F=(I=c[2439328]|0,c[2439328]=I+0,I);if((F|0)==0){break}gu[F&16383]()}if((L|0)==13037){c[ab+4>>2]=20;c[ab>>2]=20;K=ab+12|0;c[G>>2]=K;c[ab+8>>2]=0;gGC(K|0,277488,21)|0;break}K=f_(4)|0;c[K>>2]=619768;eh(K|0,625520,1206)}}while(0);eh(z|0,625552,314)}else if((L|0)==13047){gAq()}}else{$=r+1|0;aa=(e|0)==-1?-1:e<<1}}while(0);e=cG(aa|0,f|0,g|0,$|0)|0;gGz(v|0,0,12);$=u|0;c[u+4>>2]=0;c[u>>2]=621408;g=gGy(e|0)|0;f=e+g|0;L15081:do{if((g|0)>=1){aa=u;ab=f;_=o|0;h=o+128|0;m=b+4|0;l=b+8|0;Z=b|0;Y=e;O=621408;while(1){c[q>>2]=Y;X=(gI[c[O+16>>2]&31]($,n,Y,(ab-Y|0)>32?Y+32|0:f,q,_,h,p)|0)==2;V=c[q>>2]|0;if(X|(V|0)==(Y|0)){break}if(_>>>0<(c[p>>2]|0)>>>0){X=_;do{W=c[X>>2]|0;P=a[v]|0;if((P&1)==0){ac=(P&255)>>>1;ad=1}else{ac=c[m>>2]|0;ad=(c[Z>>2]&-2)-1|0}if((ac|0)==(ad|0)){gAB(b,ad,1,ad,ad,0,0);ae=a[v]|0}else{ae=P}if((ae&1)==0){a[v]=(ac<<1)+2&255;af=m;ag=ac+1|0}else{P=c[l>>2]|0;Q=ac+1|0;c[m>>2]=Q;af=P;ag=Q}c[af+(ac<<2)>>2]=W;c[af+(ag<<2)>>2]=0;X=X+4|0;}while(X>>>0<(c[p>>2]|0)>>>0);ah=c[q>>2]|0}else{ah=V}if(ah>>>0>=f>>>0){break L15081}Y=ah;O=c[aa>>2]|0}aa=f_(8)|0;c[aa>>2]=619832;O=aa+4|0;Y=O;do{if((O|0)!=0){while(1){ai=gGq(33)|0;if((ai|0)!=0){L=13101;break}m=(I=c[2439328]|0,c[2439328]=I+0,I);if((m|0)==0){break}gu[m&16383]()}if((L|0)==13101){c[ai+4>>2]=20;c[ai>>2]=20;V=ai+12|0;c[Y>>2]=V;c[ai+8>>2]=0;gGC(V|0,277488,21)|0;break}V=f_(4)|0;c[V>>2]=619768;eh(V|0,625520,1206)}}while(0);eh(aa|0,625552,314)}}while(0);if((a[s]&1)==0){i=d;return}s=c[r+8>>2]|0;if((s|0)==0){i=d;return}gGr(s);i=d;return}function gEm(a,b){a=a|0;b=b|0;bR(((b|0)==-1?-1:b<<1)|0)|0;return}function gEn(b){b=b|0;var d=0;c[b>>2]=620928;d=b+8|0;b=c[d>>2]|0;do{if((a[14125e3]|0)==0){if((bp(14125e3)|0)==0){break}c[2384150]=e6(2147483647,485280,0)|0}}while(0);if((b|0)==(c[2384150]|0)){return}d4(c[d>>2]|0);return}function gEo(){var b=0,d=0,e=0,f=0,g=0,h=0;b=f_(8)|0;c[b>>2]=619896;d=b+4|0;e=d;if((d|0)==0){f=b;c[f>>2]=619864;eh(b|0,625568,868)}while(1){g=gGq(19)|0;if((g|0)!=0){h=13164;break}d=(I=c[2439328]|0,c[2439328]=I+0,I);if((d|0)==0){h=13158;break}gu[d&16383]()}if((h|0)==13164){c[g+4>>2]=6;c[g>>2]=6;d=g+12|0;c[e>>2]=d;c[g+8>>2]=0;a[d]=a[498088]|0;a[d+1|0]=a[498089]|0;a[d+2|0]=a[498090]|0;a[d+3|0]=a[498091]|0;a[d+4|0]=a[498092]|0;a[d+5|0]=a[498093]|0;a[d+6|0]=a[498094]|0;f=b;c[f>>2]=619864;eh(b|0,625568,868)}else if((h|0)==13158){h=f_(4)|0;c[h>>2]=619768;eh(h|0,625520,1206)}}function gEp(a){a=a|0;gEq(a);if((a|0)==0){return}gGr(a);return}function gEq(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;c[b>>2]=621184;d=b+12|0;e=c[d>>2]|0;f=b+8|0;g=c[f>>2]|0;if((e|0)==(g|0)){h=e}else{i=0;j=g;g=e;while(1){e=c[j+(i<<2)>>2]|0;if((e|0)==0){k=g;l=j}else{m=e+4|0;if(((I=c[m>>2]|0,c[m>>2]=I+ -1,I)|0)==0){gf[c[(c[e>>2]|0)+8>>2]&2047](e|0)}k=c[d>>2]|0;l=c[f>>2]|0}e=i+1|0;if(e>>>0<k-l>>2>>>0){i=e;j=l;g=k}else{h=l;break}}}do{if((a[b+144|0]&1)==0){n=h}else{l=c[b+152>>2]|0;if((l|0)==0){n=h;break}gGr(l);n=c[f>>2]|0}}while(0);if((n|0)==0){return}f=c[d>>2]|0;if((n|0)!=(f|0)){c[d>>2]=f+(~((f-4+(-n|0)|0)>>>2)<<2)}if((n|0)==(b+24|0)){a[b+136|0]=0;return}else{gGr(n);return}}function __Z13m6809_executei$0(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0,cf=0,cg=0,ch=0,ci=0,cj=0,ck=0,cl=0,cm=0,cn=0,co=0,cp=0,cq=0,cr=0,cs=0,ct=0,cu=0,cv=0,cw=0,cx=0,cy=0,cz=0,cA=0,cB=0,cC=0,cD=0,cE=0,cF=0,cG=0,cH=0,cI=0,cJ=0,cK=0,cL=0,cM=0,cN=0,cO=0,cP=0,cQ=0,cR=0,cS=0,cT=0,cU=0,cV=0,cW=0,cX=0,cY=0,cZ=0,c_=0,c$=0,c0=0,c1=0,c2=0,c3=0,c4=0,c5=0,c6=0,c7=0,c8=0,c9=0,da=0,db=0,dc=0,dd=0,de=0,df=0,dg=0,dh=0,di=0,dj=0,dk=0,dl=0,dm=0,dn=0,dp=0,dq=0,dr=0,ds=0,dt=0,du=0,dv=0,dw=0,dx=0,dy=0,dz=0,dA=0,dB=0,dC=0,dD=0,dE=0,dF=0,dG=0,dH=0,dI=0,dJ=0,dK=0,dL=0,dM=0,dN=0,dO=0,dP=0,dQ=0,dR=0,dS=0,dT=0,dU=0,dV=0,dW=0,dX=0,dY=0,dZ=0,d_=0,d$=0,d0=0,d1=0,d2=0,d3=0,d4=0,d5=0,d6=0,d7=0,d8=0,d9=0,ea=0,eb=0,ec=0,ed=0,ee=0,ef=0,eg=0,eh=0,ei=0,ej=0,ek=0,el=0,em=0,en=0,eo=0,ep=0,eq=0,er=0,es=0,et=0,eu=0,ev=0,ew=0,ex=0,ey=0,ez=0,eA=0,eB=0,eC=0,eD=0,eE=0,eF=0,eG=0,eH=0,eI=0,eJ=0,eK=0,eL=0,eM=0,eN=0,eO=0,eP=0,eQ=0,eR=0,eS=0,eT=0,eU=0,eV=0,eW=0,eX=0,eY=0,eZ=0,e_=0,e$=0,e0=0,e1=0,e2=0,e3=0,e4=0,e5=0,e6=0,e7=0,e8=0,e9=0,fa=0,fb=0,fc=0,fd=0,fe=0,ff=0,fg=0,fh=0,fi=0,fj=0,fk=0,fl=0,fm=0,fn=0,fo=0,fp=0,fq=0,fr=0,fs=0,ft=0,fu=0,fv=0,fw=0,fx=0,fy=0,fz=0,fA=0,fB=0,fC=0,fD=0,fE=0,fF=0,fG=0,fH=0,fI=0,fJ=0,fK=0,fL=0,fM=0,fN=0,fO=0,fP=0,fQ=0,fR=0,fS=0,fT=0,fU=0,fV=0,fW=0,fX=0,fY=0,fZ=0,f_=0,f$=0,f0=0,f1=0,f2=0,f3=0,f4=0,f5=0,f6=0,f7=0,f8=0,f9=0,ga=0,gb=0,gc=0,gd=0,ge=0,gf=0,gh=0,gi=0,gk=0,gl=0,gm=0,gn=0,go=0,gp=0,gq=0,gr=0,gs=0,gt=0,gu=0,gv=0,gw=0,gx=0,gy=0,gz=0,gA=0,gB=0,gC=0,gD=0,gE=0,gF=0,gG=0,gH=0,gI=0,gJ=0,gK=0,gL=0,gM=0,gN=0,gO=0,gP=0,gQ=0,gR=0,gS=0,gT=0,gU=0,gV=0,gW=0,gX=0,gY=0,gZ=0,g_=0,g$=0,g0=0,g1=0,g2=0,g3=0,g4=0,g5=0,g6=0,g7=0,g8=0,g9=0,ha=0,hb=0,hc=0,hd=0,he=0,hf=0,hg=0,hh=0,hi=0,hj=0,hk=0,hl=0,hm=0,hn=0,ho=0,hp=0,hq=0,hr=0,hs=0,ht=0,hu=0,hv=0,hw=0,hx=0,hy=0,hz=0,hA=0,hB=0,hC=0,hD=0,hE=0,hF=0,hG=0,hH=0,hI=0,hJ=0,hK=0,hL=0,hM=0,hN=0,hO=0,hP=0,hQ=0;f=c[d+51624>>2]|0;g=c[d+51656>>2]|0;h=c[d+51664>>2]|0;i=c[d+51672>>2]|0;if(h){h=0;switch(i|0){case 171:{f46();j=c[2426864]|0;k=c[3528554]|0;l=c[2433592]|0;m=c[l+(k*3148|0)+48+((j>>>8&255)<<2)>>2]|0;do{if((m|0)==0){n=c[l+(k*3148|0)+3120>>2]|0;if((n|0)==0){o=0;break}o=gj[n&4095](j&65535)|0}else{o=a[m+(j&255)|0]|0}}while(0);j=a[9660761]|0;m=(j&255)+(o&255)|0;k=(m>>>4&8|a[9660784]&-48&255)&255;l=(j^o)&255^m;a[9660784]=(l<<1&32|m>>>8&1|(l^m>>>1)>>>6&2|((m&255)<<24>>24==0?k|4:k)&255)&255;a[9660761]=m&255;m=(c[2440592]|0)-4|0;c[2440592]=m;f=m;break};case 172:{f46();m=c[2426864]|0;k=c[3528554]|0;l=c[2433592]|0;o=c[l+(k*3148|0)+48+((m>>>8&255)<<2)>>2]|0;do{if((o|0)==0){j=c[l+(k*3148|0)+3120>>2]|0;if((j|0)==0){p=0;q=k;r=l;break}n=gj[j&4095](m&65535)|0;p=n;q=c[3528554]|0;r=c[2433592]|0}else{p=a[o+(m&255)|0]|0;q=k;r=l}}while(0);l=(p&255)<<8;p=c[r+(q*3148|0)+48+(((m+1|0)>>>8&255)<<2)>>2]|0;do{if((p|0)==0){k=c[r+(q*3148|0)+3120>>2]|0;if((k|0)==0){s=0;break}s=gj[k&4095]((m+1|0)&65535)|0}else{s=a[p+((m+1|0)&255)|0]|0}}while(0);m=e[4830388]|0;p=m-(s&255|l)|0;s=(p>>>12&8|a[9660784]&-16&255)&255;a[9660784]=((m^l^p^p>>>1)>>>14&2|p>>>16&1|((p&65535)<<16>>16==0?s|4:s)&255)&255;s=(c[2440592]|0)-6|0;c[2440592]=s;f=s;break};case 173:{f46();b[4830386]=(b[4830386]|0)-1&65535;s=c[2415193]|0;p=a[9660752]|0;l=c[3528554]|0;m=c[2433592]|0;q=c[m+(l*3148|0)+48+((s>>>8&255|256)<<2)>>2]|0;do{if((q|0)==0){r=c[m+(l*3148|0)+3124>>2]|0;if((r|0)==0){t=l;u=m;break}gg[r&4095](s&65535,p);t=c[3528554]|0;u=c[2433592]|0}else{a[q+(s&255)|0]=p;t=l;u=m}}while(0);b[4830386]=(b[4830386]|0)-1&65535;m=c[2415193]|0;l=a[9660753]|0;p=c[u+(t*3148|0)+48+((m>>>8&255|256)<<2)>>2]|0;do{if((p|0)==0){s=c[u+(t*3148|0)+3124>>2]|0;if((s|0)==0){break}gg[s&4095](m&65535,l)}else{a[p+(m&255)|0]=l}}while(0);l=c[2426864]|0;c[2415188]=l;b[4830376]=l&65535;l=(c[2440592]|0)-7|0;c[2440592]=l;f=l;break};case 174:{f46();l=c[2426864]|0;m=c[3528554]|0;p=c[2433592]|0;t=c[p+(m*3148|0)+48+((l>>>8&255)<<2)>>2]|0;do{if((t|0)==0){u=c[p+(m*3148|0)+3120>>2]|0;if((u|0)==0){v=0;w=m;x=p;break}s=gj[u&4095](l&65535)|0;v=s;w=c[3528554]|0;x=c[2433592]|0}else{v=a[t+(l&255)|0]|0;w=m;x=p}}while(0);p=(v&255)<<8;v=c[x+(w*3148|0)+48+(((l+1|0)>>>8&255)<<2)>>2]|0;do{if((v|0)==0){m=c[x+(w*3148|0)+3120>>2]|0;if((m|0)==0){y=0;break}y=gj[m&4095]((l+1|0)&65535)|0}else{y=a[v+((l+1|0)&255)|0]|0}}while(0);l=y&255|p;b[4830388]=l;y=a[9660784]&-15;a[9660784]=y;if(l<<16>>16==0){z=(y&255|(p&65535)>>>12&8|4)&255}else{z=(y&255|(p&65535)>>>12&8)&255}a[9660784]=z;z=(c[2440592]|0)-5|0;c[2440592]=z;f=z;break};case 175:{f46();z=a[9660784]&-15;a[9660784]=z;p=b[4830388]|0;if(p<<16>>16==0){A=((p&65535)>>>12&8|z&255|4)&255}else{A=((p&65535)>>>12&8|z&255)&255}a[9660784]=A;A=c[2426864]|0;z=a[9660777]|0;p=c[3528554]|0;y=c[2433592]|0;l=c[y+(p*3148|0)+48+((A>>>8&255|256)<<2)>>2]|0;do{if((l|0)==0){v=c[y+(p*3148|0)+3124>>2]|0;if((v|0)==0){B=p;C=y;break}gg[v&4095](A&65535,z);B=c[3528554]|0;C=c[2433592]|0}else{a[l+(A&255)|0]=z;B=p;C=y}}while(0);y=a[9660776]|0;p=c[C+(B*3148|0)+48+(((A+1|0)>>>8&255|256)<<2)>>2]|0;do{if((p|0)==0){z=c[C+(B*3148|0)+3124>>2]|0;if((z|0)==0){break}gg[z&4095]((A+1|0)&65535,y)}else{a[p+((A+1|0)&255)|0]=y}}while(0);y=(c[2440592]|0)-5|0;c[2440592]=y;f=y;break};case 176:{y=c[2415188]|0;A=c[3528554]|0;p=c[2433592]|0;B=c[p+(A*3148|0)+48+((y>>>8&255)<<2)>>2]|0;do{if((B|0)==0){C=c[p+(A*3148|0)+3132>>2]|0;if((C|0)==0){D=0;E=y;F=A;G=p;H=y&65535;break}z=gj[C&4095](y&65535)|0;C=c[2415188]|0;D=z;E=C;F=c[3528554]|0;G=c[2433592]|0;H=C&65535}else{D=a[B+(y&255)|0]|0;E=y;F=A;G=p;H=y&65535}}while(0);y=D&255;D=E+1|0;E=c[G+(F*3148|0)+48+((D>>>8&255)<<2)>>2]|0;do{if((E|0)==0){p=c[G+(F*3148|0)+3132>>2]|0;if((p|0)==0){I=0;J=H;K=F;L=G;break}A=gj[p&4095](D&65535)|0;I=A;J=b[4830376]|0;K=c[3528554]|0;L=c[2433592]|0}else{I=a[E+(D&255)|0]|0;J=H;K=F;L=G}}while(0);G=I&255;c[2426864]=G|y<<8;b[4830376]=J+2&65535;J=c[L+(K*3148|0)+48+(y<<2)>>2]|0;do{if((J|0)==0){I=c[L+(K*3148|0)+3120>>2]|0;if((I|0)==0){M=0;break}M=gj[I&4095]((G|y<<8)&65535)|0}else{M=a[J+G|0]|0}}while(0);G=a[9660761]|0;J=(G&255)-(M&255)|0;y=(J>>>4&8|a[9660784]&-16&255)&255;a[9660784]=(((G^M)&255^J^J>>>1)>>>6&2|J>>>8&1|((J&255)<<24>>24==0?y|4:y)&255)&255;a[9660761]=J&255;J=(c[2440592]|0)-5|0;c[2440592]=J;f=J;break};case 177:{J=c[2415188]|0;y=c[3528554]|0;M=c[2433592]|0;G=c[M+(y*3148|0)+48+((J>>>8&255)<<2)>>2]|0;do{if((G|0)==0){K=c[M+(y*3148|0)+3132>>2]|0;if((K|0)==0){N=0;O=J;P=y;Q=M;R=J&65535;break}L=gj[K&4095](J&65535)|0;K=c[2415188]|0;N=L;O=K;P=c[3528554]|0;Q=c[2433592]|0;R=K&65535}else{N=a[G+(J&255)|0]|0;O=J;P=y;Q=M;R=J&65535}}while(0);J=N&255;N=O+1|0;O=c[Q+(P*3148|0)+48+((N>>>8&255)<<2)>>2]|0;do{if((O|0)==0){M=c[Q+(P*3148|0)+3132>>2]|0;if((M|0)==0){S=0;T=R;U=P;V=Q;break}y=gj[M&4095](N&65535)|0;S=y;T=b[4830376]|0;U=c[3528554]|0;V=c[2433592]|0}else{S=a[O+(N&255)|0]|0;T=R;U=P;V=Q}}while(0);Q=S&255;c[2426864]=Q|J<<8;b[4830376]=T+2&65535;T=c[V+(U*3148|0)+48+(J<<2)>>2]|0;do{if((T|0)==0){S=c[V+(U*3148|0)+3120>>2]|0;if((S|0)==0){W=0;break}W=gj[S&4095]((Q|J<<8)&65535)|0}else{W=a[T+Q|0]|0}}while(0);Q=a[9660761]|0;T=(Q&255)-(W&255)|0;J=(T>>>4&8|a[9660784]&-16&255)&255;a[9660784]=(((Q^W)&255^T^T>>>1)>>>6&2|T>>>8&1|((T&255)<<24>>24==0?J|4:J)&255)&255;J=(c[2440592]|0)-5|0;c[2440592]=J;f=J;break};case 178:{J=c[2415188]|0;T=c[3528554]|0;W=c[2433592]|0;Q=c[W+(T*3148|0)+48+((J>>>8&255)<<2)>>2]|0;do{if((Q|0)==0){U=c[W+(T*3148|0)+3132>>2]|0;if((U|0)==0){X=0;Y=J;Z=T;_=W;$=J&65535;break}V=gj[U&4095](J&65535)|0;U=c[2415188]|0;X=V;Y=U;Z=c[3528554]|0;_=c[2433592]|0;$=U&65535}else{X=a[Q+(J&255)|0]|0;Y=J;Z=T;_=W;$=J&65535}}while(0);J=X&255;X=Y+1|0;Y=c[_+(Z*3148|0)+48+((X>>>8&255)<<2)>>2]|0;do{if((Y|0)==0){W=c[_+(Z*3148|0)+3132>>2]|0;if((W|0)==0){aa=0;ab=$;ac=Z;ad=_;break}T=gj[W&4095](X&65535)|0;aa=T;ab=b[4830376]|0;ac=c[3528554]|0;ad=c[2433592]|0}else{aa=a[Y+(X&255)|0]|0;ab=$;ac=Z;ad=_}}while(0);_=aa&255;c[2426864]=_|J<<8;b[4830376]=ab+2&65535;ab=c[ad+(ac*3148|0)+48+(J<<2)>>2]|0;do{if((ab|0)==0){aa=c[ad+(ac*3148|0)+3120>>2]|0;if((aa|0)==0){ae=0;break}ae=gj[aa&4095]((_|J<<8)&65535)|0}else{ae=a[ab+_|0]|0}}while(0);_=a[9660761]|0;ab=a[9660784]|0;J=(_&255)-(ae&255)-(ab&1)|0;a[9660784]=((J^(_^ae)&255^J>>>1)>>>6&2|J>>>8&1|((J&255)<<24>>24==0?(J>>>4&8|ab&-16&255)&255|4:(J>>>4&8|ab&-16&255)&255)&255)&255;a[9660761]=J&255;J=(c[2440592]|0)-5|0;c[2440592]=J;f=J;break};case 179:{J=c[2415188]|0;ab=c[3528554]|0;ae=c[2433592]|0;_=c[ae+(ab*3148|0)+48+((J>>>8&255)<<2)>>2]|0;do{if((_|0)==0){ac=c[ae+(ab*3148|0)+3132>>2]|0;if((ac|0)==0){af=0;ag=J;ah=ab;ai=ae;aj=J&65535;break}ad=gj[ac&4095](J&65535)|0;ac=c[2415188]|0;af=ad;ag=ac;ah=c[3528554]|0;ai=c[2433592]|0;aj=ac&65535}else{af=a[_+(J&255)|0]|0;ag=J;ah=ab;ai=ae;aj=J&65535}}while(0);J=af&255;af=ag+1|0;ag=c[ai+(ah*3148|0)+48+((af>>>8&255)<<2)>>2]|0;do{if((ag|0)==0){ae=c[ai+(ah*3148|0)+3132>>2]|0;if((ae|0)==0){ak=0;al=aj;am=ah;an=ai;break}ab=gj[ae&4095](af&65535)|0;ak=ab;al=b[4830376]|0;am=c[3528554]|0;an=c[2433592]|0}else{ak=a[ag+(af&255)|0]|0;al=aj;am=ah;an=ai}}while(0);ai=ak&255;c[2426864]=ai|J<<8;b[4830376]=al+2&65535;al=c[an+(am*3148|0)+48+(J<<2)>>2]|0;do{if((al|0)==0){ak=c[an+(am*3148|0)+3120>>2]|0;if((ak|0)==0){ao=0;ap=am;aq=an;break}ah=gj[ak&4095]((ai|J<<8)&65535)|0;ao=ah;ap=c[3528554]|0;aq=c[2433592]|0}else{ao=a[al+ai|0]|0;ap=am;aq=an}}while(0);an=(ao&255)<<8;ao=c[aq+(ap*3148|0)+48+((((ai|J<<8)+1|0)>>>8&255)<<2)>>2]|0;do{if((ao|0)==0){am=c[aq+(ap*3148|0)+3120>>2]|0;if((am|0)==0){ar=0;break}ar=gj[am&4095](((ai|J<<8)+1|0)&65535)|0}else{ar=a[ao+(((ai|J<<8)+1|0)&255)|0]|0}}while(0);J=e[4830380]|0;ai=J-(ar&255|an)|0;ar=(ai>>>12&8|a[9660784]&-16&255)&255;a[9660784]=((J^an^ai^ai>>>1)>>>14&2|ai>>>16&1|((ai&65535)<<16>>16==0?ar|4:ar)&255)&255;b[4830380]=ai&65535;ai=(c[2440592]|0)-7|0;c[2440592]=ai;f=ai;break};case 180:{ai=c[2415188]|0;ar=c[3528554]|0;an=c[2433592]|0;J=c[an+(ar*3148|0)+48+((ai>>>8&255)<<2)>>2]|0;do{if((J|0)==0){ao=c[an+(ar*3148|0)+3132>>2]|0;if((ao|0)==0){as=0;at=ai;au=ar;av=an;aw=ai&65535;break}ap=gj[ao&4095](ai&65535)|0;ao=c[2415188]|0;as=ap;at=ao;au=c[3528554]|0;av=c[2433592]|0;aw=ao&65535}else{as=a[J+(ai&255)|0]|0;at=ai;au=ar;av=an;aw=ai&65535}}while(0);ai=as&255;as=at+1|0;at=c[av+(au*3148|0)+48+((as>>>8&255)<<2)>>2]|0;do{if((at|0)==0){an=c[av+(au*3148|0)+3132>>2]|0;if((an|0)==0){ax=0;ay=aw;az=au;aA=av;break}ar=gj[an&4095](as&65535)|0;ax=ar;ay=b[4830376]|0;az=c[3528554]|0;aA=c[2433592]|0}else{ax=a[at+(as&255)|0]|0;ay=aw;az=au;aA=av}}while(0);av=ax&255;c[2426864]=av|ai<<8;b[4830376]=ay+2&65535;ay=c[aA+(az*3148|0)+48+(ai<<2)>>2]|0;do{if((ay|0)==0){ax=c[aA+(az*3148|0)+3120>>2]|0;if((ax|0)==0){aB=0;break}aB=gj[ax&4095]((av|ai<<8)&65535)|0}else{aB=a[ay+av|0]|0}}while(0);av=a[9660761]&aB;a[9660761]=av;aB=(av&255)>>>4&8|a[9660784]&-15;a[9660784]=av<<24>>24==0?aB|4:aB;aB=(c[2440592]|0)-5|0;c[2440592]=aB;f=aB;break};case 181:{aB=c[2415188]|0;av=c[3528554]|0;ay=c[2433592]|0;ai=c[ay+(av*3148|0)+48+((aB>>>8&255)<<2)>>2]|0;do{if((ai|0)==0){az=c[ay+(av*3148|0)+3132>>2]|0;if((az|0)==0){aC=0;aD=aB;aE=av;aF=ay;aG=aB&65535;break}aA=gj[az&4095](aB&65535)|0;az=c[2415188]|0;aC=aA;aD=az;aE=c[3528554]|0;aF=c[2433592]|0;aG=az&65535}else{aC=a[ai+(aB&255)|0]|0;aD=aB;aE=av;aF=ay;aG=aB&65535}}while(0);aB=aC&255;aC=aD+1|0;aD=c[aF+(aE*3148|0)+48+((aC>>>8&255)<<2)>>2]|0;do{if((aD|0)==0){ay=c[aF+(aE*3148|0)+3132>>2]|0;if((ay|0)==0){aH=0;aI=aG;aJ=aE;aK=aF;break}av=gj[ay&4095](aC&65535)|0;aH=av;aI=b[4830376]|0;aJ=c[3528554]|0;aK=c[2433592]|0}else{aH=a[aD+(aC&255)|0]|0;aI=aG;aJ=aE;aK=aF}}while(0);aF=aH&255;c[2426864]=aF|aB<<8;b[4830376]=aI+2&65535;aI=c[aK+(aJ*3148|0)+48+(aB<<2)>>2]|0;do{if((aI|0)==0){aH=c[aK+(aJ*3148|0)+3120>>2]|0;if((aH|0)==0){aL=0;break}aL=gj[aH&4095]((aF|aB<<8)&65535)|0}else{aL=a[aI+aF|0]|0}}while(0);aF=a[9660761]&aL;aL=(aF&255)>>>4&8|a[9660784]&-15;a[9660784]=aF<<24>>24==0?aL|4:aL;aL=(c[2440592]|0)-5|0;c[2440592]=aL;f=aL;break};case 182:{aL=c[2415188]|0;aF=c[3528554]|0;aI=c[2433592]|0;aB=c[aI+(aF*3148|0)+48+((aL>>>8&255)<<2)>>2]|0;do{if((aB|0)==0){aJ=c[aI+(aF*3148|0)+3132>>2]|0;if((aJ|0)==0){aM=0;aN=aL;aO=aF;aP=aI;aQ=aL&65535;break}aK=gj[aJ&4095](aL&65535)|0;aJ=c[2415188]|0;aM=aK;aN=aJ;aO=c[3528554]|0;aP=c[2433592]|0;aQ=aJ&65535}else{aM=a[aB+(aL&255)|0]|0;aN=aL;aO=aF;aP=aI;aQ=aL&65535}}while(0);aL=aM&255;aM=aN+1|0;aN=c[aP+(aO*3148|0)+48+((aM>>>8&255)<<2)>>2]|0;do{if((aN|0)==0){aI=c[aP+(aO*3148|0)+3132>>2]|0;if((aI|0)==0){aR=0;aS=aQ;aT=aO;aU=aP;break}aF=gj[aI&4095](aM&65535)|0;aR=aF;aS=b[4830376]|0;aT=c[3528554]|0;aU=c[2433592]|0}else{aR=a[aN+(aM&255)|0]|0;aS=aQ;aT=aO;aU=aP}}while(0);aP=aR&255;c[2426864]=aP|aL<<8;b[4830376]=aS+2&65535;aS=c[aU+(aT*3148|0)+48+(aL<<2)>>2]|0;do{if((aS|0)==0){aR=c[aU+(aT*3148|0)+3120>>2]|0;if((aR|0)==0){aV=0;break}aV=gj[aR&4095]((aP|aL<<8)&65535)|0}else{aV=a[aS+aP|0]|0}}while(0);a[9660761]=aV;aP=(aV&255)>>>4&8|a[9660784]&-15;a[9660784]=aV<<24>>24==0?aP|4:aP;aP=(c[2440592]|0)-5|0;c[2440592]=aP;f=aP;break};case 183:{aP=a[9660761]|0;aV=(aP&255)>>>4&8|a[9660784]&-15;a[9660784]=aP<<24>>24==0?aV|4:aV;aV=c[2415188]|0;aP=c[3528554]|0;aS=c[2433592]|0;aL=c[aS+(aP*3148|0)+48+((aV>>>8&255)<<2)>>2]|0;do{if((aL|0)==0){aT=c[aS+(aP*3148|0)+3132>>2]|0;if((aT|0)==0){aW=0;aX=aV;aY=aP;aZ=aS;a_=aV&65535;break}aU=gj[aT&4095](aV&65535)|0;aT=c[2415188]|0;aW=aU;aX=aT;aY=c[3528554]|0;aZ=c[2433592]|0;a_=aT&65535}else{aW=a[aL+(aV&255)|0]|0;aX=aV;aY=aP;aZ=aS;a_=aV&65535}}while(0);aV=aW&255;aW=aX+1|0;aX=c[aZ+(aY*3148|0)+48+((aW>>>8&255)<<2)>>2]|0;do{if((aX|0)==0){aS=c[aZ+(aY*3148|0)+3132>>2]|0;if((aS|0)==0){a$=0;a0=a_;a1=aY;a2=aZ;break}aP=gj[aS&4095](aW&65535)|0;a$=aP;a0=b[4830376]|0;a1=c[3528554]|0;a2=c[2433592]|0}else{a$=a[aX+(aW&255)|0]|0;a0=a_;a1=aY;a2=aZ}}while(0);aZ=a$&255;c[2426864]=aZ|aV<<8;b[4830376]=a0+2&65535;a0=a[9660761]|0;a$=c[a2+(a1*3148|0)+48+((aV|256)<<2)>>2]|0;do{if((a$|0)==0){aY=c[a2+(a1*3148|0)+3124>>2]|0;if((aY|0)==0){break}gg[aY&4095]((aZ|aV<<8)&65535,a0)}else{a[a$+aZ|0]=a0}}while(0);a0=(c[2440592]|0)-5|0;c[2440592]=a0;f=a0;break};case 184:{a0=c[2415188]|0;aZ=c[3528554]|0;a$=c[2433592]|0;aV=c[a$+(aZ*3148|0)+48+((a0>>>8&255)<<2)>>2]|0;do{if((aV|0)==0){a1=c[a$+(aZ*3148|0)+3132>>2]|0;if((a1|0)==0){a3=0;a4=a0;a5=aZ;a6=a$;a7=a0&65535;break}a2=gj[a1&4095](a0&65535)|0;a1=c[2415188]|0;a3=a2;a4=a1;a5=c[3528554]|0;a6=c[2433592]|0;a7=a1&65535}else{a3=a[aV+(a0&255)|0]|0;a4=a0;a5=aZ;a6=a$;a7=a0&65535}}while(0);a0=a3&255;a3=a4+1|0;a4=c[a6+(a5*3148|0)+48+((a3>>>8&255)<<2)>>2]|0;do{if((a4|0)==0){a$=c[a6+(a5*3148|0)+3132>>2]|0;if((a$|0)==0){a8=0;a9=a7;ba=a5;bb=a6;break}aZ=gj[a$&4095](a3&65535)|0;a8=aZ;a9=b[4830376]|0;ba=c[3528554]|0;bb=c[2433592]|0}else{a8=a[a4+(a3&255)|0]|0;a9=a7;ba=a5;bb=a6}}while(0);a6=a8&255;c[2426864]=a6|a0<<8;b[4830376]=a9+2&65535;a9=c[bb+(ba*3148|0)+48+(a0<<2)>>2]|0;do{if((a9|0)==0){a8=c[bb+(ba*3148|0)+3120>>2]|0;if((a8|0)==0){bc=0;break}bc=gj[a8&4095]((a6|a0<<8)&65535)|0}else{bc=a[a9+a6|0]|0}}while(0);a6=a[9660761]|0;a9=a6^bc;a[9660761]=a9;a0=(a9&255)>>>4&8|a[9660784]&-15;a[9660784]=a6<<24>>24==bc<<24>>24?a0|4:a0;a0=(c[2440592]|0)-5|0;c[2440592]=a0;f=a0;break};case 185:{a0=c[2415188]|0;bc=c[3528554]|0;a6=c[2433592]|0;a9=c[a6+(bc*3148|0)+48+((a0>>>8&255)<<2)>>2]|0;do{if((a9|0)==0){ba=c[a6+(bc*3148|0)+3132>>2]|0;if((ba|0)==0){bd=0;be=a0;bf=bc;bg=a6;bh=a0&65535;break}bb=gj[ba&4095](a0&65535)|0;ba=c[2415188]|0;bd=bb;be=ba;bf=c[3528554]|0;bg=c[2433592]|0;bh=ba&65535}else{bd=a[a9+(a0&255)|0]|0;be=a0;bf=bc;bg=a6;bh=a0&65535}}while(0);a0=bd&255;bd=be+1|0;be=c[bg+(bf*3148|0)+48+((bd>>>8&255)<<2)>>2]|0;do{if((be|0)==0){a6=c[bg+(bf*3148|0)+3132>>2]|0;if((a6|0)==0){bi=0;bj=bh;bk=bf;bl=bg;break}bc=gj[a6&4095](bd&65535)|0;bi=bc;bj=b[4830376]|0;bk=c[3528554]|0;bl=c[2433592]|0}else{bi=a[be+(bd&255)|0]|0;bj=bh;bk=bf;bl=bg}}while(0);bg=bi&255;c[2426864]=bg|a0<<8;b[4830376]=bj+2&65535;bj=c[bl+(bk*3148|0)+48+(a0<<2)>>2]|0;do{if((bj|0)==0){bi=c[bl+(bk*3148|0)+3120>>2]|0;if((bi|0)==0){bm=0;break}bm=gj[bi&4095]((bg|a0<<8)&65535)|0}else{bm=a[bj+bg|0]|0}}while(0);bg=a[9660761]|0;bj=a[9660784]|0;a0=(bg&255)+(bm&255)+(bj&1)|0;bk=a0^(bg^bm)&255;a[9660784]=(bk<<1&32|a0>>>8&1|(bk^a0>>>1)>>>6&2|((a0&255)<<24>>24==0?(a0>>>4&8|bj&-48&255)&255|4:(a0>>>4&8|bj&-48&255)&255)&255)&255;a[9660761]=a0&255;a0=(c[2440592]|0)-5|0;c[2440592]=a0;f=a0;break};case 186:{a0=c[2415188]|0;bj=c[3528554]|0;bk=c[2433592]|0;bm=c[bk+(bj*3148|0)+48+((a0>>>8&255)<<2)>>2]|0;do{if((bm|0)==0){bg=c[bk+(bj*3148|0)+3132>>2]|0;if((bg|0)==0){bn=0;bo=a0;bp=bj;bq=bk;br=a0&65535;break}bl=gj[bg&4095](a0&65535)|0;bg=c[2415188]|0;bn=bl;bo=bg;bp=c[3528554]|0;bq=c[2433592]|0;br=bg&65535}else{bn=a[bm+(a0&255)|0]|0;bo=a0;bp=bj;bq=bk;br=a0&65535}}while(0);a0=bn&255;bn=bo+1|0;bo=c[bq+(bp*3148|0)+48+((bn>>>8&255)<<2)>>2]|0;do{if((bo|0)==0){bk=c[bq+(bp*3148|0)+3132>>2]|0;if((bk|0)==0){bs=0;bt=br;bu=bp;bv=bq;break}bj=gj[bk&4095](bn&65535)|0;bs=bj;bt=b[4830376]|0;bu=c[3528554]|0;bv=c[2433592]|0}else{bs=a[bo+(bn&255)|0]|0;bt=br;bu=bp;bv=bq}}while(0);bq=bs&255;c[2426864]=bq|a0<<8;b[4830376]=bt+2&65535;bt=c[bv+(bu*3148|0)+48+(a0<<2)>>2]|0;do{if((bt|0)==0){bs=c[bv+(bu*3148|0)+3120>>2]|0;if((bs|0)==0){bw=0;break}bw=gj[bs&4095]((bq|a0<<8)&65535)|0}else{bw=a[bt+bq|0]|0}}while(0);bq=a[9660761]|bw;a[9660761]=bq;bw=(bq&255)>>>4&8|a[9660784]&-15;a[9660784]=bq<<24>>24==0?bw|4:bw;bw=(c[2440592]|0)-5|0;c[2440592]=bw;f=bw;break};case 187:{bw=c[2415188]|0;bq=c[3528554]|0;bt=c[2433592]|0;a0=c[bt+(bq*3148|0)+48+((bw>>>8&255)<<2)>>2]|0;do{if((a0|0)==0){bu=c[bt+(bq*3148|0)+3132>>2]|0;if((bu|0)==0){bx=0;by=bw;bz=bq;bA=bt;bB=bw&65535;break}bv=gj[bu&4095](bw&65535)|0;bu=c[2415188]|0;bx=bv;by=bu;bz=c[3528554]|0;bA=c[2433592]|0;bB=bu&65535}else{bx=a[a0+(bw&255)|0]|0;by=bw;bz=bq;bA=bt;bB=bw&65535}}while(0);bw=bx&255;bx=by+1|0;by=c[bA+(bz*3148|0)+48+((bx>>>8&255)<<2)>>2]|0;do{if((by|0)==0){bt=c[bA+(bz*3148|0)+3132>>2]|0;if((bt|0)==0){bC=0;bD=bB;bE=bz;bF=bA;break}bq=gj[bt&4095](bx&65535)|0;bC=bq;bD=b[4830376]|0;bE=c[3528554]|0;bF=c[2433592]|0}else{bC=a[by+(bx&255)|0]|0;bD=bB;bE=bz;bF=bA}}while(0);bA=bC&255;c[2426864]=bA|bw<<8;b[4830376]=bD+2&65535;bD=c[bF+(bE*3148|0)+48+(bw<<2)>>2]|0;do{if((bD|0)==0){bC=c[bF+(bE*3148|0)+3120>>2]|0;if((bC|0)==0){bG=0;break}bG=gj[bC&4095]((bA|bw<<8)&65535)|0}else{bG=a[bD+bA|0]|0}}while(0);bA=a[9660761]|0;bD=(bA&255)+(bG&255)|0;bw=(bD>>>4&8|a[9660784]&-48&255)&255;bE=(bA^bG)&255^bD;a[9660784]=(bE<<1&32|bD>>>8&1|(bE^bD>>>1)>>>6&2|((bD&255)<<24>>24==0?bw|4:bw)&255)&255;a[9660761]=bD&255;bD=(c[2440592]|0)-5|0;c[2440592]=bD;f=bD;break};case 188:{bD=c[2415188]|0;bw=c[3528554]|0;bE=c[2433592]|0;bG=c[bE+(bw*3148|0)+48+((bD>>>8&255)<<2)>>2]|0;do{if((bG|0)==0){bA=c[bE+(bw*3148|0)+3132>>2]|0;if((bA|0)==0){bH=0;bI=bD;bJ=bw;bK=bE;bL=bD&65535;break}bF=gj[bA&4095](bD&65535)|0;bA=c[2415188]|0;bH=bF;bI=bA;bJ=c[3528554]|0;bK=c[2433592]|0;bL=bA&65535}else{bH=a[bG+(bD&255)|0]|0;bI=bD;bJ=bw;bK=bE;bL=bD&65535}}while(0);bD=bH&255;bH=bI+1|0;bI=c[bK+(bJ*3148|0)+48+((bH>>>8&255)<<2)>>2]|0;do{if((bI|0)==0){bE=c[bK+(bJ*3148|0)+3132>>2]|0;if((bE|0)==0){bM=0;bN=bL;bO=bJ;bP=bK;break}bw=gj[bE&4095](bH&65535)|0;bM=bw;bN=b[4830376]|0;bO=c[3528554]|0;bP=c[2433592]|0}else{bM=a[bI+(bH&255)|0]|0;bN=bL;bO=bJ;bP=bK}}while(0);bK=bM&255;c[2426864]=bK|bD<<8;b[4830376]=bN+2&65535;bN=c[bP+(bO*3148|0)+48+(bD<<2)>>2]|0;do{if((bN|0)==0){bM=c[bP+(bO*3148|0)+3120>>2]|0;if((bM|0)==0){bQ=0;bR=bO;bS=bP;break}bJ=gj[bM&4095]((bK|bD<<8)&65535)|0;bQ=bJ;bR=c[3528554]|0;bS=c[2433592]|0}else{bQ=a[bN+bK|0]|0;bR=bO;bS=bP}}while(0);bP=(bQ&255)<<8;bQ=c[bS+(bR*3148|0)+48+((((bK|bD<<8)+1|0)>>>8&255)<<2)>>2]|0;do{if((bQ|0)==0){bO=c[bS+(bR*3148|0)+3120>>2]|0;if((bO|0)==0){bT=0;break}bT=gj[bO&4095](((bK|bD<<8)+1|0)&65535)|0}else{bT=a[bQ+(((bK|bD<<8)+1|0)&255)|0]|0}}while(0);bD=e[4830388]|0;bK=bD-(bT&255|bP)|0;bT=(bK>>>12&8|a[9660784]&-16&255)&255;a[9660784]=((bD^bP^bK^bK>>>1)>>>14&2|bK>>>16&1|((bK&65535)<<16>>16==0?bT|4:bT)&255)&255;bT=(c[2440592]|0)-7|0;c[2440592]=bT;f=bT;break};case 189:{bT=c[2415188]|0;bK=c[3528554]|0;bP=c[2433592]|0;bD=c[bP+(bK*3148|0)+48+((bT>>>8&255)<<2)>>2]|0;do{if((bD|0)==0){bQ=c[bP+(bK*3148|0)+3132>>2]|0;if((bQ|0)==0){bU=0;bV=bT;bW=bK;bX=bP;bY=bT&65535;break}bR=gj[bQ&4095](bT&65535)|0;bQ=c[2415188]|0;bU=bR;bV=bQ;bW=c[3528554]|0;bX=c[2433592]|0;bY=bQ&65535}else{bU=a[bD+(bT&255)|0]|0;bV=bT;bW=bK;bX=bP;bY=bT&65535}}while(0);bT=(bU&255)<<8;bU=bV+1|0;bV=c[bX+(bW*3148|0)+48+((bU>>>8&255)<<2)>>2]|0;do{if((bV|0)==0){bP=c[bX+(bW*3148|0)+3132>>2]|0;if((bP|0)==0){bZ=0;b_=bY;b$=bW;b0=bX;break}bK=gj[bP&4095](bU&65535)|0;bZ=bK;b_=b[4830376]|0;b$=c[3528554]|0;b0=c[2433592]|0}else{bZ=a[bV+(bU&255)|0]|0;b_=bY;b$=bW;b0=bX}}while(0);c[2426864]=bZ&255|bT;bT=b_+2&65535;b[4830376]=bT;b[4830386]=(b[4830386]|0)-1&65535;b_=c[2415193]|0;bZ=c[b0+(b$*3148|0)+48+((b_>>>8&255|256)<<2)>>2]|0;do{if((bZ|0)==0){bX=c[b0+(b$*3148|0)+3124>>2]|0;if((bX|0)==0){b1=b$;b2=b0;break}gg[bX&4095](b_&65535,bT&255);b1=c[3528554]|0;b2=c[2433592]|0}else{a[bZ+(b_&255)|0]=bT&255;b1=b$;b2=b0}}while(0);b[4830386]=(b[4830386]|0)-1&65535;b0=c[2415193]|0;b$=a[9660753]|0;bT=c[b2+(b1*3148|0)+48+((b0>>>8&255|256)<<2)>>2]|0;do{if((bT|0)==0){b_=c[b2+(b1*3148|0)+3124>>2]|0;if((b_|0)==0){break}gg[b_&4095](b0&65535,b$)}else{a[bT+(b0&255)|0]=b$}}while(0);b$=c[2426864]|0;c[2415188]=b$;b[4830376]=b$&65535;b$=(c[2440592]|0)-8|0;c[2440592]=b$;f=b$;break};default:{h=1}}}if(h){h=0;switch(i|0){case 190:{b$=c[2415188]|0;b0=c[3528554]|0;bT=c[2433592]|0;b1=c[bT+(b0*3148|0)+48+((b$>>>8&255)<<2)>>2]|0;do{if((b1|0)==0){b2=c[bT+(b0*3148|0)+3132>>2]|0;if((b2|0)==0){b3=0;b4=b$;b5=b0;b6=bT;b7=b$&65535;break}b_=gj[b2&4095](b$&65535)|0;b2=c[2415188]|0;b3=b_;b4=b2;b5=c[3528554]|0;b6=c[2433592]|0;b7=b2&65535}else{b3=a[b1+(b$&255)|0]|0;b4=b$;b5=b0;b6=bT;b7=b$&65535}}while(0);b$=b3&255;b3=b4+1|0;b4=c[b6+(b5*3148|0)+48+((b3>>>8&255)<<2)>>2]|0;do{if((b4|0)==0){bT=c[b6+(b5*3148|0)+3132>>2]|0;if((bT|0)==0){b8=0;b9=b7;ca=b5;cb=b6;break}b0=gj[bT&4095](b3&65535)|0;b8=b0;b9=b[4830376]|0;ca=c[3528554]|0;cb=c[2433592]|0}else{b8=a[b4+(b3&255)|0]|0;b9=b7;ca=b5;cb=b6}}while(0);b6=b8&255;c[2426864]=b6|b$<<8;b[4830376]=b9+2&65535;b9=c[cb+(ca*3148|0)+48+(b$<<2)>>2]|0;do{if((b9|0)==0){b8=c[cb+(ca*3148|0)+3120>>2]|0;if((b8|0)==0){cc=0;cd=ca;ce=cb;break}b5=gj[b8&4095]((b6|b$<<8)&65535)|0;cc=b5;cd=c[3528554]|0;ce=c[2433592]|0}else{cc=a[b9+b6|0]|0;cd=ca;ce=cb}}while(0);cb=cc&255;cc=c[ce+(cd*3148|0)+48+((((b6|b$<<8)+1|0)>>>8&255)<<2)>>2]|0;do{if((cc|0)==0){ca=c[ce+(cd*3148|0)+3120>>2]|0;if((ca|0)==0){cf=0;break}cf=gj[ca&4095](((b6|b$<<8)+1|0)&65535)|0}else{cf=a[cc+(((b6|b$<<8)+1|0)&255)|0]|0}}while(0);b$=cf&255|cb<<8;c[2415194]=b$;cf=a[9660784]&-15;a[9660784]=cf;if((b$|0)==0){cg=(cf&255|cb>>>4&8|4)&255}else{cg=(cf&255|cb>>>4&8)&255}a[9660784]=cg;cg=(c[2440592]|0)-6|0;c[2440592]=cg;f=cg;break};case 191:{cg=b[4830388]|0;cb=(cg&65535)>>>12&8|a[9660784]&-15&255;a[9660784]=(cg<<16>>16==0?cb|4:cb)&255;cb=c[2415188]|0;cg=c[3528554]|0;cf=c[2433592]|0;b$=c[cf+(cg*3148|0)+48+((cb>>>8&255)<<2)>>2]|0;do{if((b$|0)==0){b6=c[cf+(cg*3148|0)+3132>>2]|0;if((b6|0)==0){ch=0;ci=cb;cj=cg;ck=cf;cl=cb&65535;break}cc=gj[b6&4095](cb&65535)|0;b6=c[2415188]|0;ch=cc;ci=b6;cj=c[3528554]|0;ck=c[2433592]|0;cl=b6&65535}else{ch=a[b$+(cb&255)|0]|0;ci=cb;cj=cg;ck=cf;cl=cb&65535}}while(0);cb=ch&255;ch=ci+1|0;ci=c[ck+(cj*3148|0)+48+((ch>>>8&255)<<2)>>2]|0;do{if((ci|0)==0){cf=c[ck+(cj*3148|0)+3132>>2]|0;if((cf|0)==0){cm=0;cn=cl;co=cj;cp=ck;break}cg=gj[cf&4095](ch&65535)|0;cm=cg;cn=b[4830376]|0;co=c[3528554]|0;cp=c[2433592]|0}else{cm=a[ci+(ch&255)|0]|0;cn=cl;co=cj;cp=ck}}while(0);ck=cm&255;c[2426864]=ck|cb<<8;b[4830376]=cn+2&65535;cn=a[9660777]|0;cm=c[cp+(co*3148|0)+48+((cb|256)<<2)>>2]|0;do{if((cm|0)==0){cj=c[cp+(co*3148|0)+3124>>2]|0;if((cj|0)==0){cq=co;cr=cp;break}gg[cj&4095]((ck|cb<<8)&65535,cn);cq=c[3528554]|0;cr=c[2433592]|0}else{a[cm+ck|0]=cn;cq=co;cr=cp}}while(0);cp=a[9660776]|0;co=c[cr+(cq*3148|0)+48+((((ck|cb<<8)+1|0)>>>8&255|256)<<2)>>2]|0;do{if((co|0)==0){cn=c[cr+(cq*3148|0)+3124>>2]|0;if((cn|0)==0){break}gg[cn&4095](((ck|cb<<8)+1|0)&65535,cp)}else{a[co+(((ck|cb<<8)+1|0)&255)|0]=cp}}while(0);cp=(c[2440592]|0)-6|0;c[2440592]=cp;f=cp;break};case 192:{cp=c[2415188]|0;cb=c[3528554]|0;ck=c[2433592]|0;co=c[ck+(cb*3148|0)+48+((cp>>>8&255)<<2)>>2]|0;do{if((co|0)==0){cq=c[ck+(cb*3148|0)+3132>>2]|0;if((cq|0)==0){cs=0;ct=cp&65535;break}cr=gj[cq&4095](cp&65535)|0;cs=cr;ct=b[4830376]|0}else{cs=a[co+(cp&255)|0]|0;ct=cp&65535}}while(0);b[4830376]=ct+1&65535;ct=a[9660760]|0;cp=(ct&255)-(cs&255)|0;co=(cp>>>4&8|a[9660784]&-16&255)&255;a[9660784]=(((ct^cs)&255^cp^cp>>>1)>>>6&2|cp>>>8&1|((cp&255)<<24>>24==0?co|4:co)&255)&255;a[9660760]=cp&255;cp=(c[2440592]|0)-2|0;c[2440592]=cp;f=cp;break};case 193:{cp=c[2415188]|0;co=c[3528554]|0;cs=c[2433592]|0;ct=c[cs+(co*3148|0)+48+((cp>>>8&255)<<2)>>2]|0;do{if((ct|0)==0){cb=c[cs+(co*3148|0)+3132>>2]|0;if((cb|0)==0){cu=0;cv=cp&65535;break}ck=gj[cb&4095](cp&65535)|0;cu=ck;cv=b[4830376]|0}else{cu=a[ct+(cp&255)|0]|0;cv=cp&65535}}while(0);b[4830376]=cv+1&65535;cv=a[9660760]|0;cp=(cv&255)-(cu&255)|0;ct=(cp>>>4&8|a[9660784]&-16&255)&255;a[9660784]=(((cv^cu)&255^cp^cp>>>1)>>>6&2|cp>>>8&1|((cp&255)<<24>>24==0?ct|4:ct)&255)&255;ct=(c[2440592]|0)-2|0;c[2440592]=ct;f=ct;break};case 194:{ct=c[2415188]|0;cp=c[3528554]|0;cu=c[2433592]|0;cv=c[cu+(cp*3148|0)+48+((ct>>>8&255)<<2)>>2]|0;do{if((cv|0)==0){co=c[cu+(cp*3148|0)+3132>>2]|0;if((co|0)==0){cw=0;cx=ct&65535;break}cs=gj[co&4095](ct&65535)|0;cw=cs;cx=b[4830376]|0}else{cw=a[cv+(ct&255)|0]|0;cx=ct&65535}}while(0);b[4830376]=cx+1&65535;cx=a[9660760]|0;ct=a[9660784]|0;cv=(cx&255)-(cw&255)-(ct&1)|0;a[9660784]=((cv^(cx^cw)&255^cv>>>1)>>>6&2|cv>>>8&1|((cv&255)<<24>>24==0?(cv>>>4&8|ct&-16&255)&255|4:(cv>>>4&8|ct&-16&255)&255)&255)&255;a[9660760]=cv&255;cv=(c[2440592]|0)-2|0;c[2440592]=cv;f=cv;break};case 195:{cv=c[2415188]|0;ct=c[3528554]|0;cw=c[2433592]|0;cx=c[cw+(ct*3148|0)+48+((cv>>>8&255)<<2)>>2]|0;do{if((cx|0)==0){cp=c[cw+(ct*3148|0)+3132>>2]|0;if((cp|0)==0){cy=0;cz=cv;cA=ct;cB=cw;cC=cv&65535;break}cu=gj[cp&4095](cv&65535)|0;cp=c[2415188]|0;cy=cu;cz=cp;cA=c[3528554]|0;cB=c[2433592]|0;cC=cp&65535}else{cy=a[cx+(cv&255)|0]|0;cz=cv;cA=ct;cB=cw;cC=cv&65535}}while(0);cv=(cy&255)<<8;cy=cz+1|0;cz=c[cB+(cA*3148|0)+48+((cy>>>8&255)<<2)>>2]|0;do{if((cz|0)==0){cw=c[cB+(cA*3148|0)+3132>>2]|0;if((cw|0)==0){cD=0;cE=cC;break}ct=gj[cw&4095](cy&65535)|0;cD=ct;cE=b[4830376]|0}else{cD=a[cz+(cy&255)|0]|0;cE=cC}}while(0);b[4830376]=cE+2&65535;cE=e[4830380]|0;cC=cE+(cD&255|cv)|0;cD=(cC>>>12&8|a[9660784]&-16&255)&255;a[9660784]=((cE^cv^cC^cC>>>1)>>>14&2|cC>>>16&1|((cC&65535)<<16>>16==0?cD|4:cD)&255)&255;b[4830380]=cC&65535;cC=(c[2440592]|0)-4|0;c[2440592]=cC;f=cC;break};case 196:{cC=c[2415188]|0;cD=c[3528554]|0;cv=c[2433592]|0;cE=c[cv+(cD*3148|0)+48+((cC>>>8&255)<<2)>>2]|0;do{if((cE|0)==0){cy=c[cv+(cD*3148|0)+3132>>2]|0;if((cy|0)==0){cF=0;cG=cC&65535;break}cz=gj[cy&4095](cC&65535)|0;cF=cz;cG=b[4830376]|0}else{cF=a[cE+(cC&255)|0]|0;cG=cC&65535}}while(0);b[4830376]=cG+1&65535;cG=a[9660760]&cF;a[9660760]=cG;cF=(cG&255)>>>4&8|a[9660784]&-15;a[9660784]=cG<<24>>24==0?cF|4:cF;cF=(c[2440592]|0)-2|0;c[2440592]=cF;f=cF;break};case 197:{cF=c[2415188]|0;cG=c[3528554]|0;cC=c[2433592]|0;cE=c[cC+(cG*3148|0)+48+((cF>>>8&255)<<2)>>2]|0;do{if((cE|0)==0){cD=c[cC+(cG*3148|0)+3132>>2]|0;if((cD|0)==0){cH=0;cI=cF&65535;break}cv=gj[cD&4095](cF&65535)|0;cH=cv;cI=b[4830376]|0}else{cH=a[cE+(cF&255)|0]|0;cI=cF&65535}}while(0);b[4830376]=cI+1&65535;cI=a[9660760]&cH;cH=(cI&255)>>>4&8|a[9660784]&-15;a[9660784]=cI<<24>>24==0?cH|4:cH;cH=(c[2440592]|0)-2|0;c[2440592]=cH;f=cH;break};case 198:{cH=c[2415188]|0;cI=c[3528554]|0;cF=c[2433592]|0;cE=c[cF+(cI*3148|0)+48+((cH>>>8&255)<<2)>>2]|0;do{if((cE|0)==0){cG=c[cF+(cI*3148|0)+3132>>2]|0;if((cG|0)==0){cJ=0;cK=cH&65535;break}cC=gj[cG&4095](cH&65535)|0;cJ=cC;cK=b[4830376]|0}else{cJ=a[cE+(cH&255)|0]|0;cK=cH&65535}}while(0);a[9660760]=cJ;b[4830376]=cK+1&65535;cK=a[9660784]&-15|(cJ&255)>>>4&8;a[9660784]=cJ<<24>>24==0?cK|4:cK;cK=(c[2440592]|0)-2|0;c[2440592]=cK;f=cK;break};case 199:{cK=a[9660760]|0;cJ=(cK&255)>>>4&8|a[9660784]&-15;a[9660784]=cK<<24>>24==0?cJ|4:cJ;cJ=c[2415188]|0;c[2426864]=cJ;b[4830376]=(cJ&65535)+1&65535;cH=c[3528554]|0;cE=c[2433592]|0;cI=c[cE+(cH*3148|0)+48+((cJ>>>8&255|256)<<2)>>2]|0;do{if((cI|0)==0){cF=c[cE+(cH*3148|0)+3124>>2]|0;if((cF|0)==0){break}gg[cF&4095](cJ&65535,cK)}else{a[cI+(cJ&255)|0]=cK}}while(0);cK=(c[2440592]|0)-2|0;c[2440592]=cK;f=cK;break};case 200:{cK=c[2415188]|0;cJ=c[3528554]|0;cI=c[2433592]|0;cH=c[cI+(cJ*3148|0)+48+((cK>>>8&255)<<2)>>2]|0;do{if((cH|0)==0){cE=c[cI+(cJ*3148|0)+3132>>2]|0;if((cE|0)==0){cL=0;cM=cK&65535;break}cF=gj[cE&4095](cK&65535)|0;cL=cF;cM=b[4830376]|0}else{cL=a[cH+(cK&255)|0]|0;cM=cK&65535}}while(0);b[4830376]=cM+1&65535;cM=a[9660760]|0;cK=cM^cL;a[9660760]=cK;cH=(cK&255)>>>4&8|a[9660784]&-15;a[9660784]=cM<<24>>24==cL<<24>>24?cH|4:cH;cH=(c[2440592]|0)-2|0;c[2440592]=cH;f=cH;break};case 201:{cH=c[2415188]|0;cL=c[3528554]|0;cM=c[2433592]|0;cK=c[cM+(cL*3148|0)+48+((cH>>>8&255)<<2)>>2]|0;do{if((cK|0)==0){cJ=c[cM+(cL*3148|0)+3132>>2]|0;if((cJ|0)==0){cN=0;cO=cH&65535;break}cI=gj[cJ&4095](cH&65535)|0;cN=cI;cO=b[4830376]|0}else{cN=a[cK+(cH&255)|0]|0;cO=cH&65535}}while(0);b[4830376]=cO+1&65535;cO=a[9660760]|0;cH=a[9660784]|0;cK=(cO&255)+(cN&255)+(cH&1)|0;cL=cK^(cO^cN)&255;a[9660784]=(cL<<1&32|cK>>>8&1|(cL^cK>>>1)>>>6&2|((cK&255)<<24>>24==0?(cK>>>4&8|cH&-48&255)&255|4:(cK>>>4&8|cH&-48&255)&255)&255)&255;a[9660760]=cK&255;cK=(c[2440592]|0)-2|0;c[2440592]=cK;f=cK;break};case 202:{cK=c[2415188]|0;cH=c[3528554]|0;cL=c[2433592]|0;cN=c[cL+(cH*3148|0)+48+((cK>>>8&255)<<2)>>2]|0;do{if((cN|0)==0){cO=c[cL+(cH*3148|0)+3132>>2]|0;if((cO|0)==0){cP=0;cQ=cK&65535;break}cM=gj[cO&4095](cK&65535)|0;cP=cM;cQ=b[4830376]|0}else{cP=a[cN+(cK&255)|0]|0;cQ=cK&65535}}while(0);b[4830376]=cQ+1&65535;cQ=a[9660760]|cP;a[9660760]=cQ;cP=(cQ&255)>>>4&8|a[9660784]&-15;a[9660784]=cQ<<24>>24==0?cP|4:cP;cP=(c[2440592]|0)-2|0;c[2440592]=cP;f=cP;break};case 203:{cP=c[2415188]|0;cQ=c[3528554]|0;cK=c[2433592]|0;cN=c[cK+(cQ*3148|0)+48+((cP>>>8&255)<<2)>>2]|0;do{if((cN|0)==0){cH=c[cK+(cQ*3148|0)+3132>>2]|0;if((cH|0)==0){cR=0;cS=cP&65535;break}cL=gj[cH&4095](cP&65535)|0;cR=cL;cS=b[4830376]|0}else{cR=a[cN+(cP&255)|0]|0;cS=cP&65535}}while(0);b[4830376]=cS+1&65535;cS=a[9660760]|0;cP=(cS&255)+(cR&255)|0;cN=(cP>>>4&8|a[9660784]&-48&255)&255;cQ=(cS^cR)&255^cP;a[9660784]=(cQ<<1&32|cP>>>8&1|(cQ^cP>>>1)>>>6&2|((cP&255)<<24>>24==0?cN|4:cN)&255)&255;a[9660760]=cP&255;cP=(c[2440592]|0)-2|0;c[2440592]=cP;f=cP;break};case 204:{cP=c[2415188]|0;cN=c[3528554]|0;cQ=c[2433592]|0;cR=c[cQ+(cN*3148|0)+48+((cP>>>8&255)<<2)>>2]|0;do{if((cR|0)==0){cS=c[cQ+(cN*3148|0)+3132>>2]|0;if((cS|0)==0){cT=0;cU=cP;cV=cN;cW=cQ;cX=cP&65535;break}cK=gj[cS&4095](cP&65535)|0;cS=c[2415188]|0;cT=cK;cU=cS;cV=c[3528554]|0;cW=c[2433592]|0;cX=cS&65535}else{cT=a[cR+(cP&255)|0]|0;cU=cP;cV=cN;cW=cQ;cX=cP&65535}}while(0);cP=cT&255;cT=cU+1|0;cU=c[cW+(cV*3148|0)+48+((cT>>>8&255)<<2)>>2]|0;do{if((cU|0)==0){cQ=c[cW+(cV*3148|0)+3132>>2]|0;if((cQ|0)==0){cY=0;cZ=cX;break}cN=gj[cQ&4095](cT&65535)|0;cY=cN;cZ=b[4830376]|0}else{cY=a[cU+(cT&255)|0]|0;cZ=cX}}while(0);cX=cY&255|cP<<8;c[2415190]=cX;b[4830376]=cZ+2&65535;cZ=a[9660784]&-15;a[9660784]=cZ;if((cX|0)==0){c_=(cZ&255|cP>>>4&8|4)&255}else{c_=(cZ&255|cP>>>4&8)&255}a[9660784]=c_;c_=(c[2440592]|0)-3|0;c[2440592]=c_;f=c_;break};case 205:{c_=b[4830380]|0;cP=(c_&65535)>>>12&8|a[9660784]&-15&255;a[9660784]=(c_<<16>>16==0?cP|4:cP)&255;cP=c[2415188]|0;c[2426864]=cP;b[4830376]=(cP&65535)+2&65535;c_=a[9660761]|0;cZ=c[3528554]|0;cX=c[2433592]|0;cY=c[cX+(cZ*3148|0)+48+((cP>>>8&255|256)<<2)>>2]|0;do{if((cY|0)==0){cT=c[cX+(cZ*3148|0)+3124>>2]|0;if((cT|0)==0){c$=cZ;c0=cX;break}gg[cT&4095](cP&65535,c_);c$=c[3528554]|0;c0=c[2433592]|0}else{a[cY+(cP&255)|0]=c_;c$=cZ;c0=cX}}while(0);cX=a[9660760]|0;cZ=c[c0+(c$*3148|0)+48+(((cP+1|0)>>>8&255|256)<<2)>>2]|0;do{if((cZ|0)==0){c_=c[c0+(c$*3148|0)+3124>>2]|0;if((c_|0)==0){break}gg[c_&4095]((cP+1|0)&65535,cX)}else{a[cZ+((cP+1|0)&255)|0]=cX}}while(0);cX=(c[2440592]|0)-2|0;c[2440592]=cX;f=cX;break};case 206:{cX=c[2415188]|0;cP=c[3528554]|0;cZ=c[2433592]|0;c$=c[cZ+(cP*3148|0)+48+((cX>>>8&255)<<2)>>2]|0;do{if((c$|0)==0){c0=c[cZ+(cP*3148|0)+3132>>2]|0;if((c0|0)==0){c1=0;c2=cX;c3=cP;c4=cZ;c5=cX&65535;break}c_=gj[c0&4095](cX&65535)|0;c0=c[2415188]|0;c1=c_;c2=c0;c3=c[3528554]|0;c4=c[2433592]|0;c5=c0&65535}else{c1=a[c$+(cX&255)|0]|0;c2=cX;c3=cP;c4=cZ;c5=cX&65535}}while(0);cX=c1&255;c1=c2+1|0;c2=c[c4+(c3*3148|0)+48+((c1>>>8&255)<<2)>>2]|0;do{if((c2|0)==0){cZ=c[c4+(c3*3148|0)+3132>>2]|0;if((cZ|0)==0){c6=0;c7=c5;break}cP=gj[cZ&4095](c1&65535)|0;c6=cP;c7=b[4830376]|0}else{c6=a[c2+(c1&255)|0]|0;c7=c5}}while(0);c5=c6&255|cX<<8;c[2415192]=c5;b[4830376]=c7+2&65535;c7=a[9660784]&-15;a[9660784]=c7;if((c5|0)==0){c8=(c7&255|cX>>>4&8|4)&255}else{c8=(c7&255|cX>>>4&8)&255}a[9660784]=c8;c8=(c[2440592]|0)-3|0;c[2440592]=c8;f=c8;break};case 207:{c8=b[4830384]|0;cX=(c8&65535)>>>12&8|a[9660784]&-15&255;a[9660784]=(c8<<16>>16==0?cX|4:cX)&255;cX=c[2415188]|0;c[2426864]=cX;b[4830376]=(cX&65535)+2&65535;c8=a[9660769]|0;c7=c[3528554]|0;c5=c[2433592]|0;c6=c[c5+(c7*3148|0)+48+((cX>>>8&255|256)<<2)>>2]|0;do{if((c6|0)==0){c1=c[c5+(c7*3148|0)+3124>>2]|0;if((c1|0)==0){c9=c7;da=c5;break}gg[c1&4095](cX&65535,c8);c9=c[3528554]|0;da=c[2433592]|0}else{a[c6+(cX&255)|0]=c8;c9=c7;da=c5}}while(0);c5=a[9660768]|0;c7=c[da+(c9*3148|0)+48+(((cX+1|0)>>>8&255|256)<<2)>>2]|0;do{if((c7|0)==0){c8=c[da+(c9*3148|0)+3124>>2]|0;if((c8|0)==0){break}gg[c8&4095]((cX+1|0)&65535,c5)}else{a[c7+((cX+1|0)&255)|0]=c5}}while(0);c5=(c[2440592]|0)-3|0;c[2440592]=c5;f=c5;break};case 208:{c[2426864]=c[2415191];c5=c[2415188]|0;cX=c[3528554]|0;c7=c[2433592]|0;c9=c[c7+(cX*3148|0)+48+((c5>>>8&255)<<2)>>2]|0;do{if((c9|0)==0){da=c[c7+(cX*3148|0)+3132>>2]|0;if((da|0)==0){db=0;dc=c5&65535;dd=cX;de=c7;break}c8=gj[da&4095](c5&65535)|0;db=c8;dc=b[4830376]|0;dd=c[3528554]|0;de=c[2433592]|0}else{db=a[c9+(c5&255)|0]|0;dc=c5&65535;dd=cX;de=c7}}while(0);a[9707456]=db;b[4830376]=dc+1&65535;dc=c[2426864]|0;db=c[de+(dd*3148|0)+48+((dc>>>8&255)<<2)>>2]|0;do{if((db|0)==0){c7=c[de+(dd*3148|0)+3120>>2]|0;if((c7|0)==0){df=0;break}df=gj[c7&4095](dc&65535)|0}else{df=a[db+(dc&255)|0]|0}}while(0);dc=a[9660760]|0;db=(dc&255)-(df&255)|0;dd=(db>>>4&8|a[9660784]&-16&255)&255;a[9660784]=(((dc^df)&255^db^db>>>1)>>>6&2|db>>>8&1|((db&255)<<24>>24==0?dd|4:dd)&255)&255;a[9660760]=db&255;db=(c[2440592]|0)-4|0;c[2440592]=db;f=db;break};case 209:{c[2426864]=c[2415191];db=c[2415188]|0;dd=c[3528554]|0;df=c[2433592]|0;dc=c[df+(dd*3148|0)+48+((db>>>8&255)<<2)>>2]|0;do{if((dc|0)==0){de=c[df+(dd*3148|0)+3132>>2]|0;if((de|0)==0){dg=0;dh=db&65535;di=dd;dj=df;break}c7=gj[de&4095](db&65535)|0;dg=c7;dh=b[4830376]|0;di=c[3528554]|0;dj=c[2433592]|0}else{dg=a[dc+(db&255)|0]|0;dh=db&65535;di=dd;dj=df}}while(0);a[9707456]=dg;b[4830376]=dh+1&65535;dh=c[2426864]|0;dg=c[dj+(di*3148|0)+48+((dh>>>8&255)<<2)>>2]|0;do{if((dg|0)==0){df=c[dj+(di*3148|0)+3120>>2]|0;if((df|0)==0){dk=0;break}dk=gj[df&4095](dh&65535)|0}else{dk=a[dg+(dh&255)|0]|0}}while(0);dh=a[9660760]|0;dg=(dh&255)-(dk&255)|0;di=(dg>>>4&8|a[9660784]&-16&255)&255;a[9660784]=(((dh^dk)&255^dg^dg>>>1)>>>6&2|dg>>>8&1|((dg&255)<<24>>24==0?di|4:di)&255)&255;di=(c[2440592]|0)-4|0;c[2440592]=di;f=di;break};case 210:{c[2426864]=c[2415191];di=c[2415188]|0;dg=c[3528554]|0;dk=c[2433592]|0;dh=c[dk+(dg*3148|0)+48+((di>>>8&255)<<2)>>2]|0;do{if((dh|0)==0){dj=c[dk+(dg*3148|0)+3132>>2]|0;if((dj|0)==0){dl=0;dm=di&65535;dn=dg;dp=dk;break}df=gj[dj&4095](di&65535)|0;dl=df;dm=b[4830376]|0;dn=c[3528554]|0;dp=c[2433592]|0}else{dl=a[dh+(di&255)|0]|0;dm=di&65535;dn=dg;dp=dk}}while(0);a[9707456]=dl;b[4830376]=dm+1&65535;dm=c[2426864]|0;dl=c[dp+(dn*3148|0)+48+((dm>>>8&255)<<2)>>2]|0;do{if((dl|0)==0){dk=c[dp+(dn*3148|0)+3120>>2]|0;if((dk|0)==0){dq=0;break}dq=gj[dk&4095](dm&65535)|0}else{dq=a[dl+(dm&255)|0]|0}}while(0);dm=a[9660760]|0;dl=a[9660784]|0;dn=(dm&255)-(dq&255)-(dl&1)|0;a[9660784]=((dn^(dm^dq)&255^dn>>>1)>>>6&2|dn>>>8&1|((dn&255)<<24>>24==0?(dn>>>4&8|dl&-16&255)&255|4:(dn>>>4&8|dl&-16&255)&255)&255)&255;a[9660760]=dn&255;dn=(c[2440592]|0)-4|0;c[2440592]=dn;f=dn;break};case 211:{c[2426864]=c[2415191];dn=c[2415188]|0;dl=c[3528554]|0;dq=c[2433592]|0;dm=c[dq+(dl*3148|0)+48+((dn>>>8&255)<<2)>>2]|0;do{if((dm|0)==0){dp=c[dq+(dl*3148|0)+3132>>2]|0;if((dp|0)==0){dr=0;ds=dn&65535;dt=dl;du=dq;break}dk=gj[dp&4095](dn&65535)|0;dr=dk;ds=b[4830376]|0;dt=c[3528554]|0;du=c[2433592]|0}else{dr=a[dm+(dn&255)|0]|0;ds=dn&65535;dt=dl;du=dq}}while(0);a[9707456]=dr;b[4830376]=ds+1&65535;ds=c[2426864]|0;dr=c[du+(dt*3148|0)+48+((ds>>>8&255)<<2)>>2]|0;do{if((dr|0)==0){dq=c[du+(dt*3148|0)+3120>>2]|0;if((dq|0)==0){dv=0;dw=dt;dx=du;break}dl=gj[dq&4095](ds&65535)|0;dv=dl;dw=c[3528554]|0;dx=c[2433592]|0}else{dv=a[dr+(ds&255)|0]|0;dw=dt;dx=du}}while(0);du=(dv&255)<<8;dv=c[dx+(dw*3148|0)+48+(((ds+1|0)>>>8&255)<<2)>>2]|0;do{if((dv|0)==0){dt=c[dx+(dw*3148|0)+3120>>2]|0;if((dt|0)==0){dy=0;break}dy=gj[dt&4095]((ds+1|0)&65535)|0}else{dy=a[dv+((ds+1|0)&255)|0]|0}}while(0);ds=e[4830380]|0;dv=ds+(dy&255|du)|0;dy=(dv>>>12&8|a[9660784]&-16&255)&255;a[9660784]=((ds^du^dv^dv>>>1)>>>14&2|dv>>>16&1|((dv&65535)<<16>>16==0?dy|4:dy)&255)&255;b[4830380]=dv&65535;dv=(c[2440592]|0)-6|0;c[2440592]=dv;f=dv;break};case 212:{c[2426864]=c[2415191];dv=c[2415188]|0;dy=c[3528554]|0;du=c[2433592]|0;ds=c[du+(dy*3148|0)+48+((dv>>>8&255)<<2)>>2]|0;do{if((ds|0)==0){dw=c[du+(dy*3148|0)+3132>>2]|0;if((dw|0)==0){dz=0;dA=dv&65535;dB=dy;dC=du;break}dx=gj[dw&4095](dv&65535)|0;dz=dx;dA=b[4830376]|0;dB=c[3528554]|0;dC=c[2433592]|0}else{dz=a[ds+(dv&255)|0]|0;dA=dv&65535;dB=dy;dC=du}}while(0);a[9707456]=dz;b[4830376]=dA+1&65535;dA=c[2426864]|0;dz=c[dC+(dB*3148|0)+48+((dA>>>8&255)<<2)>>2]|0;do{if((dz|0)==0){du=c[dC+(dB*3148|0)+3120>>2]|0;if((du|0)==0){dD=0;break}dD=gj[du&4095](dA&65535)|0}else{dD=a[dz+(dA&255)|0]|0}}while(0);dA=a[9660760]&dD;a[9660760]=dA;dD=(dA&255)>>>4&8|a[9660784]&-15;a[9660784]=dA<<24>>24==0?dD|4:dD;dD=(c[2440592]|0)-4|0;c[2440592]=dD;f=dD;break};case 213:{c[2426864]=c[2415191];dD=c[2415188]|0;dA=c[3528554]|0;dz=c[2433592]|0;dB=c[dz+(dA*3148|0)+48+((dD>>>8&255)<<2)>>2]|0;do{if((dB|0)==0){dC=c[dz+(dA*3148|0)+3132>>2]|0;if((dC|0)==0){dE=0;dF=dD&65535;dG=dA;dH=dz;break}du=gj[dC&4095](dD&65535)|0;dE=du;dF=b[4830376]|0;dG=c[3528554]|0;dH=c[2433592]|0}else{dE=a[dB+(dD&255)|0]|0;dF=dD&65535;dG=dA;dH=dz}}while(0);a[9707456]=dE;b[4830376]=dF+1&65535;dF=c[2426864]|0;dE=c[dH+(dG*3148|0)+48+((dF>>>8&255)<<2)>>2]|0;do{if((dE|0)==0){dz=c[dH+(dG*3148|0)+3120>>2]|0;if((dz|0)==0){dI=0;break}dI=gj[dz&4095](dF&65535)|0}else{dI=a[dE+(dF&255)|0]|0}}while(0);dF=a[9660760]&dI;dI=(dF&255)>>>4&8|a[9660784]&-15;a[9660784]=dF<<24>>24==0?dI|4:dI;dI=(c[2440592]|0)-4|0;c[2440592]=dI;f=dI;break};case 214:{c[2426864]=c[2415191];dI=c[2415188]|0;dF=c[3528554]|0;dE=c[2433592]|0;dG=c[dE+(dF*3148|0)+48+((dI>>>8&255)<<2)>>2]|0;do{if((dG|0)==0){dH=c[dE+(dF*3148|0)+3132>>2]|0;if((dH|0)==0){dJ=0;dK=dI&65535;dL=dF;dM=dE;break}dz=gj[dH&4095](dI&65535)|0;dJ=dz;dK=b[4830376]|0;dL=c[3528554]|0;dM=c[2433592]|0}else{dJ=a[dG+(dI&255)|0]|0;dK=dI&65535;dL=dF;dM=dE}}while(0);a[9707456]=dJ;b[4830376]=dK+1&65535;dK=c[2426864]|0;dJ=c[dM+(dL*3148|0)+48+((dK>>>8&255)<<2)>>2]|0;do{if((dJ|0)==0){dE=c[dM+(dL*3148|0)+3120>>2]|0;if((dE|0)==0){dN=0;break}dN=gj[dE&4095](dK&65535)|0}else{dN=a[dJ+(dK&255)|0]|0}}while(0);a[9660760]=dN;dK=(dN&255)>>>4&8|a[9660784]&-15;a[9660784]=dN<<24>>24==0?dK|4:dK;dK=(c[2440592]|0)-4|0;c[2440592]=dK;f=dK;break};case 215:{dK=a[9660760]|0;dN=(dK&255)>>>4&8|a[9660784]&-15;a[9660784]=dK<<24>>24==0?dN|4:dN;c[2426864]=c[2415191];dN=c[2415188]|0;dJ=c[3528554]|0;dL=c[2433592]|0;dM=c[dL+(dJ*3148|0)+48+((dN>>>8&255)<<2)>>2]|0;do{if((dM|0)==0){dE=c[dL+(dJ*3148|0)+3132>>2]|0;if((dE|0)==0){dO=0;dP=dN&65535;dQ=dK;dR=dJ;dS=dL;break}dF=gj[dE&4095](dN&65535)|0;dO=dF;dP=b[4830376]|0;dQ=a[9660760]|0;dR=c[3528554]|0;dS=c[2433592]|0}else{dO=a[dM+(dN&255)|0]|0;dP=dN&65535;dQ=dK;dR=dJ;dS=dL}}while(0);a[9707456]=dO;b[4830376]=dP+1&65535;dP=c[2426864]|0;dO=c[dS+(dR*3148|0)+48+((dP>>>8&255|256)<<2)>>2]|0;do{if((dO|0)==0){dL=c[dS+(dR*3148|0)+3124>>2]|0;if((dL|0)==0){break}gg[dL&4095](dP&65535,dQ)}else{a[dO+(dP&255)|0]=dQ}}while(0);dQ=(c[2440592]|0)-4|0;c[2440592]=dQ;f=dQ;break};case 216:{c[2426864]=c[2415191];dQ=c[2415188]|0;dP=c[3528554]|0;dO=c[2433592]|0;dR=c[dO+(dP*3148|0)+48+((dQ>>>8&255)<<2)>>2]|0;do{if((dR|0)==0){dS=c[dO+(dP*3148|0)+3132>>2]|0;if((dS|0)==0){dT=0;dU=dQ&65535;dV=dP;dW=dO;break}dL=gj[dS&4095](dQ&65535)|0;dT=dL;dU=b[4830376]|0;dV=c[3528554]|0;dW=c[2433592]|0}else{dT=a[dR+(dQ&255)|0]|0;dU=dQ&65535;dV=dP;dW=dO}}while(0);a[9707456]=dT;b[4830376]=dU+1&65535;dU=c[2426864]|0;dT=c[dW+(dV*3148|0)+48+((dU>>>8&255)<<2)>>2]|0;do{if((dT|0)==0){dO=c[dW+(dV*3148|0)+3120>>2]|0;if((dO|0)==0){dX=0;break}dX=gj[dO&4095](dU&65535)|0}else{dX=a[dT+(dU&255)|0]|0}}while(0);dU=a[9660760]|0;dT=dU^dX;a[9660760]=dT;dV=(dT&255)>>>4&8|a[9660784]&-15;a[9660784]=dU<<24>>24==dX<<24>>24?dV|4:dV;dV=(c[2440592]|0)-4|0;c[2440592]=dV;f=dV;break};default:{h=1}}}if(h){h=0;switch(i|0){case 217:{c[2426864]=c[2415191];dV=c[2415188]|0;dX=c[3528554]|0;dU=c[2433592]|0;dT=c[dU+(dX*3148|0)+48+((dV>>>8&255)<<2)>>2]|0;do{if((dT|0)==0){dW=c[dU+(dX*3148|0)+3132>>2]|0;if((dW|0)==0){dY=0;dZ=dV&65535;d_=dX;d$=dU;break}dO=gj[dW&4095](dV&65535)|0;dY=dO;dZ=b[4830376]|0;d_=c[3528554]|0;d$=c[2433592]|0}else{dY=a[dT+(dV&255)|0]|0;dZ=dV&65535;d_=dX;d$=dU}}while(0);a[9707456]=dY;b[4830376]=dZ+1&65535;dZ=c[2426864]|0;dY=c[d$+(d_*3148|0)+48+((dZ>>>8&255)<<2)>>2]|0;do{if((dY|0)==0){dU=c[d$+(d_*3148|0)+3120>>2]|0;if((dU|0)==0){d0=0;break}d0=gj[dU&4095](dZ&65535)|0}else{d0=a[dY+(dZ&255)|0]|0}}while(0);dZ=a[9660760]|0;dY=a[9660784]|0;d_=(dZ&255)+(d0&255)+(dY&1)|0;d$=d_^(dZ^d0)&255;a[9660784]=(d$<<1&32|d_>>>8&1|(d$^d_>>>1)>>>6&2|((d_&255)<<24>>24==0?(d_>>>4&8|dY&-48&255)&255|4:(d_>>>4&8|dY&-48&255)&255)&255)&255;a[9660760]=d_&255;d_=(c[2440592]|0)-4|0;c[2440592]=d_;f=d_;break};case 218:{c[2426864]=c[2415191];d_=c[2415188]|0;dY=c[3528554]|0;d$=c[2433592]|0;d0=c[d$+(dY*3148|0)+48+((d_>>>8&255)<<2)>>2]|0;do{if((d0|0)==0){dZ=c[d$+(dY*3148|0)+3132>>2]|0;if((dZ|0)==0){d1=0;d2=d_&65535;d3=dY;d4=d$;break}dU=gj[dZ&4095](d_&65535)|0;d1=dU;d2=b[4830376]|0;d3=c[3528554]|0;d4=c[2433592]|0}else{d1=a[d0+(d_&255)|0]|0;d2=d_&65535;d3=dY;d4=d$}}while(0);a[9707456]=d1;b[4830376]=d2+1&65535;d2=c[2426864]|0;d1=c[d4+(d3*3148|0)+48+((d2>>>8&255)<<2)>>2]|0;do{if((d1|0)==0){d$=c[d4+(d3*3148|0)+3120>>2]|0;if((d$|0)==0){d5=0;break}d5=gj[d$&4095](d2&65535)|0}else{d5=a[d1+(d2&255)|0]|0}}while(0);d2=a[9660760]|d5;a[9660760]=d2;d5=(d2&255)>>>4&8|a[9660784]&-15;a[9660784]=d2<<24>>24==0?d5|4:d5;d5=(c[2440592]|0)-4|0;c[2440592]=d5;f=d5;break};case 219:{c[2426864]=c[2415191];d5=c[2415188]|0;d2=c[3528554]|0;d1=c[2433592]|0;d3=c[d1+(d2*3148|0)+48+((d5>>>8&255)<<2)>>2]|0;do{if((d3|0)==0){d4=c[d1+(d2*3148|0)+3132>>2]|0;if((d4|0)==0){d6=0;d7=d5&65535;d8=d2;d9=d1;break}d$=gj[d4&4095](d5&65535)|0;d6=d$;d7=b[4830376]|0;d8=c[3528554]|0;d9=c[2433592]|0}else{d6=a[d3+(d5&255)|0]|0;d7=d5&65535;d8=d2;d9=d1}}while(0);a[9707456]=d6;b[4830376]=d7+1&65535;d7=c[2426864]|0;d6=c[d9+(d8*3148|0)+48+((d7>>>8&255)<<2)>>2]|0;do{if((d6|0)==0){d1=c[d9+(d8*3148|0)+3120>>2]|0;if((d1|0)==0){ea=0;break}ea=gj[d1&4095](d7&65535)|0}else{ea=a[d6+(d7&255)|0]|0}}while(0);d7=a[9660760]|0;d6=(d7&255)+(ea&255)|0;d8=(d6>>>4&8|a[9660784]&-48&255)&255;d9=(d7^ea)&255^d6;a[9660784]=(d9<<1&32|d6>>>8&1|(d9^d6>>>1)>>>6&2|((d6&255)<<24>>24==0?d8|4:d8)&255)&255;a[9660760]=d6&255;d6=(c[2440592]|0)-4|0;c[2440592]=d6;f=d6;break};case 220:{c[2426864]=c[2415191];d6=c[2415188]|0;d8=c[3528554]|0;d9=c[2433592]|0;ea=c[d9+(d8*3148|0)+48+((d6>>>8&255)<<2)>>2]|0;do{if((ea|0)==0){d7=c[d9+(d8*3148|0)+3132>>2]|0;if((d7|0)==0){eb=0;ec=d6&65535;ed=d8;ee=d9;break}d1=gj[d7&4095](d6&65535)|0;eb=d1;ec=b[4830376]|0;ed=c[3528554]|0;ee=c[2433592]|0}else{eb=a[ea+(d6&255)|0]|0;ec=d6&65535;ed=d8;ee=d9}}while(0);a[9707456]=eb;b[4830376]=ec+1&65535;ec=c[2426864]|0;eb=c[ee+(ed*3148|0)+48+((ec>>>8&255)<<2)>>2]|0;do{if((eb|0)==0){d9=c[ee+(ed*3148|0)+3120>>2]|0;if((d9|0)==0){ef=0;eg=ed;eh=ee;break}d8=gj[d9&4095](ec&65535)|0;ef=d8;eg=c[3528554]|0;eh=c[2433592]|0}else{ef=a[eb+(ec&255)|0]|0;eg=ed;eh=ee}}while(0);ee=ef&255;ef=c[eh+(eg*3148|0)+48+(((ec+1|0)>>>8&255)<<2)>>2]|0;do{if((ef|0)==0){ed=c[eh+(eg*3148|0)+3120>>2]|0;if((ed|0)==0){ei=0;break}ei=gj[ed&4095]((ec+1|0)&65535)|0}else{ei=a[ef+((ec+1|0)&255)|0]|0}}while(0);ec=ei&255|ee<<8;c[2415190]=ec;ei=a[9660784]&-15;a[9660784]=ei;if((ec|0)==0){ej=(ei&255|ee>>>4&8|4)&255}else{ej=(ei&255|ee>>>4&8)&255}a[9660784]=ej;ej=(c[2440592]|0)-5|0;c[2440592]=ej;f=ej;break};case 221:{ej=b[4830380]|0;ee=(ej&65535)>>>12&8|a[9660784]&-15&255;a[9660784]=(ej<<16>>16==0?ee|4:ee)&255;c[2426864]=c[2415191];ee=c[2415188]|0;ej=c[3528554]|0;ei=c[2433592]|0;ec=c[ei+(ej*3148|0)+48+((ee>>>8&255)<<2)>>2]|0;do{if((ec|0)==0){ef=c[ei+(ej*3148|0)+3132>>2]|0;if((ef|0)==0){ek=0;el=ee&65535;em=ej;en=ei;break}eg=gj[ef&4095](ee&65535)|0;ek=eg;el=b[4830376]|0;em=c[3528554]|0;en=c[2433592]|0}else{ek=a[ec+(ee&255)|0]|0;el=ee&65535;em=ej;en=ei}}while(0);a[9707456]=ek;b[4830376]=el+1&65535;el=c[2426864]|0;ek=a[9660761]|0;ei=c[en+(em*3148|0)+48+((el>>>8&255|256)<<2)>>2]|0;do{if((ei|0)==0){ej=c[en+(em*3148|0)+3124>>2]|0;if((ej|0)==0){eo=em;ep=en;break}gg[ej&4095](el&65535,ek);eo=c[3528554]|0;ep=c[2433592]|0}else{a[ei+(el&255)|0]=ek;eo=em;ep=en}}while(0);en=a[9660760]|0;em=c[ep+(eo*3148|0)+48+(((el+1|0)>>>8&255|256)<<2)>>2]|0;do{if((em|0)==0){ek=c[ep+(eo*3148|0)+3124>>2]|0;if((ek|0)==0){break}gg[ek&4095]((el+1|0)&65535,en)}else{a[em+((el+1|0)&255)|0]=en}}while(0);en=(c[2440592]|0)-5|0;c[2440592]=en;f=en;break};case 222:{c[2426864]=c[2415191];en=c[2415188]|0;el=c[3528554]|0;em=c[2433592]|0;eo=c[em+(el*3148|0)+48+((en>>>8&255)<<2)>>2]|0;do{if((eo|0)==0){ep=c[em+(el*3148|0)+3132>>2]|0;if((ep|0)==0){eq=0;er=en&65535;es=el;et=em;break}ek=gj[ep&4095](en&65535)|0;eq=ek;er=b[4830376]|0;es=c[3528554]|0;et=c[2433592]|0}else{eq=a[eo+(en&255)|0]|0;er=en&65535;es=el;et=em}}while(0);a[9707456]=eq;b[4830376]=er+1&65535;er=c[2426864]|0;eq=c[et+(es*3148|0)+48+((er>>>8&255)<<2)>>2]|0;do{if((eq|0)==0){em=c[et+(es*3148|0)+3120>>2]|0;if((em|0)==0){eu=0;ev=es;ew=et;break}el=gj[em&4095](er&65535)|0;eu=el;ev=c[3528554]|0;ew=c[2433592]|0}else{eu=a[eq+(er&255)|0]|0;ev=es;ew=et}}while(0);et=eu&255;eu=c[ew+(ev*3148|0)+48+(((er+1|0)>>>8&255)<<2)>>2]|0;do{if((eu|0)==0){es=c[ew+(ev*3148|0)+3120>>2]|0;if((es|0)==0){ex=0;break}ex=gj[es&4095]((er+1|0)&65535)|0}else{ex=a[eu+((er+1|0)&255)|0]|0}}while(0);er=ex&255|et<<8;c[2415192]=er;ex=a[9660784]&-15;a[9660784]=ex;if((er|0)==0){ey=(ex&255|et>>>4&8|4)&255}else{ey=(ex&255|et>>>4&8)&255}a[9660784]=ey;ey=(c[2440592]|0)-5|0;c[2440592]=ey;f=ey;break};case 223:{ey=b[4830384]|0;et=(ey&65535)>>>12&8|a[9660784]&-15&255;a[9660784]=(ey<<16>>16==0?et|4:et)&255;c[2426864]=c[2415191];et=c[2415188]|0;ey=c[3528554]|0;ex=c[2433592]|0;er=c[ex+(ey*3148|0)+48+((et>>>8&255)<<2)>>2]|0;do{if((er|0)==0){eu=c[ex+(ey*3148|0)+3132>>2]|0;if((eu|0)==0){ez=0;eA=et&65535;eB=ey;eC=ex;break}ev=gj[eu&4095](et&65535)|0;ez=ev;eA=b[4830376]|0;eB=c[3528554]|0;eC=c[2433592]|0}else{ez=a[er+(et&255)|0]|0;eA=et&65535;eB=ey;eC=ex}}while(0);a[9707456]=ez;b[4830376]=eA+1&65535;eA=c[2426864]|0;ez=a[9660769]|0;ex=c[eC+(eB*3148|0)+48+((eA>>>8&255|256)<<2)>>2]|0;do{if((ex|0)==0){ey=c[eC+(eB*3148|0)+3124>>2]|0;if((ey|0)==0){eD=eB;eE=eC;break}gg[ey&4095](eA&65535,ez);eD=c[3528554]|0;eE=c[2433592]|0}else{a[ex+(eA&255)|0]=ez;eD=eB;eE=eC}}while(0);eC=a[9660768]|0;eB=c[eE+(eD*3148|0)+48+(((eA+1|0)>>>8&255|256)<<2)>>2]|0;do{if((eB|0)==0){ez=c[eE+(eD*3148|0)+3124>>2]|0;if((ez|0)==0){break}gg[ez&4095]((eA+1|0)&65535,eC)}else{a[eB+((eA+1|0)&255)|0]=eC}}while(0);eC=(c[2440592]|0)-5|0;c[2440592]=eC;f=eC;break};case 224:{f46();eC=c[2426864]|0;eA=c[3528554]|0;eB=c[2433592]|0;eD=c[eB+(eA*3148|0)+48+((eC>>>8&255)<<2)>>2]|0;do{if((eD|0)==0){eE=c[eB+(eA*3148|0)+3120>>2]|0;if((eE|0)==0){eF=0;break}eF=gj[eE&4095](eC&65535)|0}else{eF=a[eD+(eC&255)|0]|0}}while(0);eC=a[9660760]|0;eD=(eC&255)-(eF&255)|0;eA=(eD>>>4&8|a[9660784]&-16&255)&255;a[9660784]=(((eC^eF)&255^eD^eD>>>1)>>>6&2|eD>>>8&1|((eD&255)<<24>>24==0?eA|4:eA)&255)&255;a[9660760]=eD&255;eD=(c[2440592]|0)-4|0;c[2440592]=eD;f=eD;break};case 225:{f46();eD=c[2426864]|0;eA=c[3528554]|0;eF=c[2433592]|0;eC=c[eF+(eA*3148|0)+48+((eD>>>8&255)<<2)>>2]|0;do{if((eC|0)==0){eB=c[eF+(eA*3148|0)+3120>>2]|0;if((eB|0)==0){eG=0;break}eG=gj[eB&4095](eD&65535)|0}else{eG=a[eC+(eD&255)|0]|0}}while(0);eD=a[9660760]|0;eC=(eD&255)-(eG&255)|0;eA=(eC>>>4&8|a[9660784]&-16&255)&255;a[9660784]=(((eD^eG)&255^eC^eC>>>1)>>>6&2|eC>>>8&1|((eC&255)<<24>>24==0?eA|4:eA)&255)&255;eA=(c[2440592]|0)-4|0;c[2440592]=eA;f=eA;break};case 226:{f46();eA=c[2426864]|0;eC=c[3528554]|0;eG=c[2433592]|0;eD=c[eG+(eC*3148|0)+48+((eA>>>8&255)<<2)>>2]|0;do{if((eD|0)==0){eF=c[eG+(eC*3148|0)+3120>>2]|0;if((eF|0)==0){eH=0;break}eH=gj[eF&4095](eA&65535)|0}else{eH=a[eD+(eA&255)|0]|0}}while(0);eA=a[9660760]|0;eD=a[9660784]|0;eC=(eA&255)-(eH&255)-(eD&1)|0;a[9660784]=((eC^(eA^eH)&255^eC>>>1)>>>6&2|eC>>>8&1|((eC&255)<<24>>24==0?(eC>>>4&8|eD&-16&255)&255|4:(eC>>>4&8|eD&-16&255)&255)&255)&255;a[9660760]=eC&255;eC=(c[2440592]|0)-4|0;c[2440592]=eC;f=eC;break};case 227:{f46();eC=c[2426864]|0;eD=c[3528554]|0;eH=c[2433592]|0;eA=c[eH+(eD*3148|0)+48+((eC>>>8&255)<<2)>>2]|0;do{if((eA|0)==0){eG=c[eH+(eD*3148|0)+3120>>2]|0;if((eG|0)==0){eI=0;eJ=eD;eK=eH;break}eF=gj[eG&4095](eC&65535)|0;eI=eF;eJ=c[3528554]|0;eK=c[2433592]|0}else{eI=a[eA+(eC&255)|0]|0;eJ=eD;eK=eH}}while(0);eH=(eI&255)<<8;eI=c[eK+(eJ*3148|0)+48+(((eC+1|0)>>>8&255)<<2)>>2]|0;do{if((eI|0)==0){eD=c[eK+(eJ*3148|0)+3120>>2]|0;if((eD|0)==0){eL=0;break}eL=gj[eD&4095]((eC+1|0)&65535)|0}else{eL=a[eI+((eC+1|0)&255)|0]|0}}while(0);eC=e[4830380]|0;eI=eC+(eL&255|eH)|0;eL=(eI>>>12&8|a[9660784]&-16&255)&255;a[9660784]=((eC^eH^eI^eI>>>1)>>>14&2|eI>>>16&1|((eI&65535)<<16>>16==0?eL|4:eL)&255)&255;b[4830380]=eI&65535;eI=(c[2440592]|0)-6|0;c[2440592]=eI;f=eI;break};case 228:{f46();eI=c[2426864]|0;eL=c[3528554]|0;eH=c[2433592]|0;eC=c[eH+(eL*3148|0)+48+((eI>>>8&255)<<2)>>2]|0;do{if((eC|0)==0){eJ=c[eH+(eL*3148|0)+3120>>2]|0;if((eJ|0)==0){eM=0;break}eM=gj[eJ&4095](eI&65535)|0}else{eM=a[eC+(eI&255)|0]|0}}while(0);eI=a[9660760]&eM;a[9660760]=eI;eM=(eI&255)>>>4&8|a[9660784]&-15;a[9660784]=eI<<24>>24==0?eM|4:eM;eM=(c[2440592]|0)-4|0;c[2440592]=eM;f=eM;break};case 229:{f46();eM=a[9660760]|0;eI=c[2426864]|0;eC=c[3528554]|0;eL=c[2433592]|0;eH=c[eL+(eC*3148|0)+48+((eI>>>8&255)<<2)>>2]|0;do{if((eH|0)==0){eJ=c[eL+(eC*3148|0)+3120>>2]|0;if((eJ|0)==0){eN=0;break}eN=gj[eJ&4095](eI&65535)|0}else{eN=a[eH+(eI&255)|0]|0}}while(0);eI=eN&eM;eM=(eI&255)>>>4&8|a[9660784]&-15;a[9660784]=eI<<24>>24==0?eM|4:eM;eM=(c[2440592]|0)-4|0;c[2440592]=eM;f=eM;break};case 230:{f46();eM=c[2426864]|0;eI=c[3528554]|0;eN=c[2433592]|0;eH=c[eN+(eI*3148|0)+48+((eM>>>8&255)<<2)>>2]|0;do{if((eH|0)==0){eC=c[eN+(eI*3148|0)+3120>>2]|0;if((eC|0)==0){eO=0;break}eO=gj[eC&4095](eM&65535)|0}else{eO=a[eH+(eM&255)|0]|0}}while(0);a[9660760]=eO;eM=(eO&255)>>>4&8|a[9660784]&-15;a[9660784]=eO<<24>>24==0?eM|4:eM;eM=(c[2440592]|0)-4|0;c[2440592]=eM;f=eM;break};case 231:{f46();eM=a[9660760]|0;eO=(eM&255)>>>4&8|a[9660784]&-15;a[9660784]=eM<<24>>24==0?eO|4:eO;eO=c[2426864]|0;eH=c[3528554]|0;eI=c[2433592]|0;eN=c[eI+(eH*3148|0)+48+((eO>>>8&255|256)<<2)>>2]|0;do{if((eN|0)==0){eC=c[eI+(eH*3148|0)+3124>>2]|0;if((eC|0)==0){break}gg[eC&4095](eO&65535,eM)}else{a[eN+(eO&255)|0]=eM}}while(0);eM=(c[2440592]|0)-4|0;c[2440592]=eM;f=eM;break};case 232:{f46();eM=c[2426864]|0;eO=c[3528554]|0;eN=c[2433592]|0;eH=c[eN+(eO*3148|0)+48+((eM>>>8&255)<<2)>>2]|0;do{if((eH|0)==0){eI=c[eN+(eO*3148|0)+3120>>2]|0;if((eI|0)==0){eP=0;break}eP=gj[eI&4095](eM&65535)|0}else{eP=a[eH+(eM&255)|0]|0}}while(0);eM=a[9660760]|0;eH=eM^eP;a[9660760]=eH;eO=(eH&255)>>>4&8|a[9660784]&-15;a[9660784]=eM<<24>>24==eP<<24>>24?eO|4:eO;eO=(c[2440592]|0)-4|0;c[2440592]=eO;f=eO;break};case 233:{f46();eO=c[2426864]|0;eP=c[3528554]|0;eM=c[2433592]|0;eH=c[eM+(eP*3148|0)+48+((eO>>>8&255)<<2)>>2]|0;do{if((eH|0)==0){eN=c[eM+(eP*3148|0)+3120>>2]|0;if((eN|0)==0){eQ=0;break}eQ=gj[eN&4095](eO&65535)|0}else{eQ=a[eH+(eO&255)|0]|0}}while(0);eO=a[9660760]|0;eH=a[9660784]|0;eP=(eO&255)+(eQ&255)+(eH&1)|0;eM=eP^(eO^eQ)&255;a[9660784]=(eM<<1&32|eP>>>8&1|(eM^eP>>>1)>>>6&2|((eP&255)<<24>>24==0?(eP>>>4&8|eH&-48&255)&255|4:(eP>>>4&8|eH&-48&255)&255)&255)&255;a[9660760]=eP&255;eP=(c[2440592]|0)-4|0;c[2440592]=eP;f=eP;break};case 234:{f46();eP=c[2426864]|0;eH=c[3528554]|0;eM=c[2433592]|0;eQ=c[eM+(eH*3148|0)+48+((eP>>>8&255)<<2)>>2]|0;do{if((eQ|0)==0){eO=c[eM+(eH*3148|0)+3120>>2]|0;if((eO|0)==0){eR=0;break}eR=gj[eO&4095](eP&65535)|0}else{eR=a[eQ+(eP&255)|0]|0}}while(0);eP=a[9660760]|eR;a[9660760]=eP;eR=(eP&255)>>>4&8|a[9660784]&-15;a[9660784]=eP<<24>>24==0?eR|4:eR;eR=(c[2440592]|0)-4|0;c[2440592]=eR;f=eR;break};case 235:{f46();eR=c[2426864]|0;eP=c[3528554]|0;eQ=c[2433592]|0;eH=c[eQ+(eP*3148|0)+48+((eR>>>8&255)<<2)>>2]|0;do{if((eH|0)==0){eM=c[eQ+(eP*3148|0)+3120>>2]|0;if((eM|0)==0){eS=0;break}eS=gj[eM&4095](eR&65535)|0}else{eS=a[eH+(eR&255)|0]|0}}while(0);eR=a[9660760]|0;eH=(eR&255)+(eS&255)|0;eP=(eH>>>4&8|a[9660784]&-48&255)&255;eQ=(eR^eS)&255^eH;a[9660784]=(eQ<<1&32|eH>>>8&1|(eQ^eH>>>1)>>>6&2|((eH&255)<<24>>24==0?eP|4:eP)&255)&255;a[9660760]=eH&255;eH=(c[2440592]|0)-4|0;c[2440592]=eH;f=eH;break};case 236:{f46();eH=c[2426864]|0;eP=c[3528554]|0;eQ=c[2433592]|0;eS=c[eQ+(eP*3148|0)+48+((eH>>>8&255)<<2)>>2]|0;do{if((eS|0)==0){eR=c[eQ+(eP*3148|0)+3120>>2]|0;if((eR|0)==0){eT=0;eU=eP;eV=eQ;break}eM=gj[eR&4095](eH&65535)|0;eT=eM;eU=c[3528554]|0;eV=c[2433592]|0}else{eT=a[eS+(eH&255)|0]|0;eU=eP;eV=eQ}}while(0);eQ=(eT&255)<<8;eT=c[eV+(eU*3148|0)+48+(((eH+1|0)>>>8&255)<<2)>>2]|0;do{if((eT|0)==0){eP=c[eV+(eU*3148|0)+3120>>2]|0;if((eP|0)==0){eW=0;break}eW=gj[eP&4095]((eH+1|0)&65535)|0}else{eW=a[eT+((eH+1|0)&255)|0]|0}}while(0);eH=eW&255|eQ;b[4830380]=eH;eW=a[9660784]&-15;a[9660784]=eW;if(eH<<16>>16==0){eX=(eW&255|(eQ&65535)>>>12&8|4)&255}else{eX=(eW&255|(eQ&65535)>>>12&8)&255}a[9660784]=eX;eX=(c[2440592]|0)-5|0;c[2440592]=eX;f=eX;break};case 237:{f46();eX=a[9660784]&-15;a[9660784]=eX;eQ=b[4830380]|0;if(eQ<<16>>16==0){eY=((eQ&65535)>>>12&8|eX&255|4)&255}else{eY=((eQ&65535)>>>12&8|eX&255)&255}a[9660784]=eY;eY=c[2426864]|0;eX=a[9660761]|0;eQ=c[3528554]|0;eW=c[2433592]|0;eH=c[eW+(eQ*3148|0)+48+((eY>>>8&255|256)<<2)>>2]|0;do{if((eH|0)==0){eT=c[eW+(eQ*3148|0)+3124>>2]|0;if((eT|0)==0){eZ=eQ;e_=eW;break}gg[eT&4095](eY&65535,eX);eZ=c[3528554]|0;e_=c[2433592]|0}else{a[eH+(eY&255)|0]=eX;eZ=eQ;e_=eW}}while(0);eW=a[9660760]|0;eQ=c[e_+(eZ*3148|0)+48+(((eY+1|0)>>>8&255|256)<<2)>>2]|0;do{if((eQ|0)==0){eX=c[e_+(eZ*3148|0)+3124>>2]|0;if((eX|0)==0){break}gg[eX&4095]((eY+1|0)&65535,eW)}else{a[eQ+((eY+1|0)&255)|0]=eW}}while(0);eW=(c[2440592]|0)-5|0;c[2440592]=eW;f=eW;break};case 238:{f46();eW=c[2426864]|0;eY=c[3528554]|0;eQ=c[2433592]|0;eZ=c[eQ+(eY*3148|0)+48+((eW>>>8&255)<<2)>>2]|0;do{if((eZ|0)==0){e_=c[eQ+(eY*3148|0)+3120>>2]|0;if((e_|0)==0){e$=0;e0=eY;e1=eQ;break}eX=gj[e_&4095](eW&65535)|0;e$=eX;e0=c[3528554]|0;e1=c[2433592]|0}else{e$=a[eZ+(eW&255)|0]|0;e0=eY;e1=eQ}}while(0);eQ=(e$&255)<<8;e$=c[e1+(e0*3148|0)+48+(((eW+1|0)>>>8&255)<<2)>>2]|0;do{if((e$|0)==0){eY=c[e1+(e0*3148|0)+3120>>2]|0;if((eY|0)==0){e2=0;break}e2=gj[eY&4095]((eW+1|0)&65535)|0}else{e2=a[e$+((eW+1|0)&255)|0]|0}}while(0);eW=e2&255|eQ;b[4830384]=eW;e2=a[9660784]&-15;a[9660784]=e2;if(eW<<16>>16==0){e3=(e2&255|(eQ&65535)>>>12&8|4)&255}else{e3=(e2&255|(eQ&65535)>>>12&8)&255}a[9660784]=e3;e3=(c[2440592]|0)-5|0;c[2440592]=e3;f=e3;break};case 239:{f46();e3=a[9660784]&-15;a[9660784]=e3;eQ=b[4830384]|0;if(eQ<<16>>16==0){e4=((eQ&65535)>>>12&8|e3&255|4)&255}else{e4=((eQ&65535)>>>12&8|e3&255)&255}a[9660784]=e4;e4=c[2426864]|0;e3=a[9660769]|0;eQ=c[3528554]|0;e2=c[2433592]|0;eW=c[e2+(eQ*3148|0)+48+((e4>>>8&255|256)<<2)>>2]|0;do{if((eW|0)==0){e$=c[e2+(eQ*3148|0)+3124>>2]|0;if((e$|0)==0){e5=eQ;e6=e2;break}gg[e$&4095](e4&65535,e3);e5=c[3528554]|0;e6=c[2433592]|0}else{a[eW+(e4&255)|0]=e3;e5=eQ;e6=e2}}while(0);e2=a[9660768]|0;eQ=c[e6+(e5*3148|0)+48+(((e4+1|0)>>>8&255|256)<<2)>>2]|0;do{if((eQ|0)==0){e3=c[e6+(e5*3148|0)+3124>>2]|0;if((e3|0)==0){break}gg[e3&4095]((e4+1|0)&65535,e2)}else{a[eQ+((e4+1|0)&255)|0]=e2}}while(0);e2=(c[2440592]|0)-5|0;c[2440592]=e2;f=e2;break};case 240:{e2=c[2415188]|0;e4=c[3528554]|0;eQ=c[2433592]|0;e5=c[eQ+(e4*3148|0)+48+((e2>>>8&255)<<2)>>2]|0;do{if((e5|0)==0){e6=c[eQ+(e4*3148|0)+3132>>2]|0;if((e6|0)==0){e7=0;e8=e2;e9=e4;fa=eQ;fb=e2&65535;break}e3=gj[e6&4095](e2&65535)|0;e6=c[2415188]|0;e7=e3;e8=e6;e9=c[3528554]|0;fa=c[2433592]|0;fb=e6&65535}else{e7=a[e5+(e2&255)|0]|0;e8=e2;e9=e4;fa=eQ;fb=e2&65535}}while(0);e2=e7&255;e7=e8+1|0;e8=c[fa+(e9*3148|0)+48+((e7>>>8&255)<<2)>>2]|0;do{if((e8|0)==0){eQ=c[fa+(e9*3148|0)+3132>>2]|0;if((eQ|0)==0){fc=0;fd=fb;fe=e9;ff=fa;break}e4=gj[eQ&4095](e7&65535)|0;fc=e4;fd=b[4830376]|0;fe=c[3528554]|0;ff=c[2433592]|0}else{fc=a[e8+(e7&255)|0]|0;fd=fb;fe=e9;ff=fa}}while(0);fa=fc&255;c[2426864]=fa|e2<<8;b[4830376]=fd+2&65535;fd=c[ff+(fe*3148|0)+48+(e2<<2)>>2]|0;do{if((fd|0)==0){fc=c[ff+(fe*3148|0)+3120>>2]|0;if((fc|0)==0){fg=0;break}fg=gj[fc&4095]((fa|e2<<8)&65535)|0}else{fg=a[fd+fa|0]|0}}while(0);fa=a[9660760]|0;fd=(fa&255)-(fg&255)|0;e2=(fd>>>4&8|a[9660784]&-16&255)&255;a[9660784]=(((fa^fg)&255^fd^fd>>>1)>>>6&2|fd>>>8&1|((fd&255)<<24>>24==0?e2|4:e2)&255)&255;a[9660760]=fd&255;fd=(c[2440592]|0)-5|0;c[2440592]=fd;f=fd;break};case 241:{fd=c[2415188]|0;e2=c[3528554]|0;fg=c[2433592]|0;fa=c[fg+(e2*3148|0)+48+((fd>>>8&255)<<2)>>2]|0;do{if((fa|0)==0){fe=c[fg+(e2*3148|0)+3132>>2]|0;if((fe|0)==0){fh=0;fi=fd;fj=e2;fk=fg;fl=fd&65535;break}ff=gj[fe&4095](fd&65535)|0;fe=c[2415188]|0;fh=ff;fi=fe;fj=c[3528554]|0;fk=c[2433592]|0;fl=fe&65535}else{fh=a[fa+(fd&255)|0]|0;fi=fd;fj=e2;fk=fg;fl=fd&65535}}while(0);fd=fh&255;fh=fi+1|0;fi=c[fk+(fj*3148|0)+48+((fh>>>8&255)<<2)>>2]|0;do{if((fi|0)==0){fg=c[fk+(fj*3148|0)+3132>>2]|0;if((fg|0)==0){fm=0;fn=fl;fo=fj;fp=fk;break}e2=gj[fg&4095](fh&65535)|0;fm=e2;fn=b[4830376]|0;fo=c[3528554]|0;fp=c[2433592]|0}else{fm=a[fi+(fh&255)|0]|0;fn=fl;fo=fj;fp=fk}}while(0);fk=fm&255;c[2426864]=fk|fd<<8;b[4830376]=fn+2&65535;fn=c[fp+(fo*3148|0)+48+(fd<<2)>>2]|0;do{if((fn|0)==0){fm=c[fp+(fo*3148|0)+3120>>2]|0;if((fm|0)==0){fq=0;break}fq=gj[fm&4095]((fk|fd<<8)&65535)|0}else{fq=a[fn+fk|0]|0}}while(0);fk=a[9660760]|0;fn=(fk&255)-(fq&255)|0;fd=(fn>>>4&8|a[9660784]&-16&255)&255;a[9660784]=(((fk^fq)&255^fn^fn>>>1)>>>6&2|fn>>>8&1|((fn&255)<<24>>24==0?fd|4:fd)&255)&255;fd=(c[2440592]|0)-5|0;c[2440592]=fd;f=fd;break};case 242:{fd=c[2415188]|0;fn=c[3528554]|0;fq=c[2433592]|0;fk=c[fq+(fn*3148|0)+48+((fd>>>8&255)<<2)>>2]|0;do{if((fk|0)==0){fo=c[fq+(fn*3148|0)+3132>>2]|0;if((fo|0)==0){fr=0;fs=fd;ft=fn;fu=fq;fv=fd&65535;break}fp=gj[fo&4095](fd&65535)|0;fo=c[2415188]|0;fr=fp;fs=fo;ft=c[3528554]|0;fu=c[2433592]|0;fv=fo&65535}else{fr=a[fk+(fd&255)|0]|0;fs=fd;ft=fn;fu=fq;fv=fd&65535}}while(0);fd=fr&255;fr=fs+1|0;fs=c[fu+(ft*3148|0)+48+((fr>>>8&255)<<2)>>2]|0;do{if((fs|0)==0){fq=c[fu+(ft*3148|0)+3132>>2]|0;if((fq|0)==0){fw=0;fx=fv;fy=ft;fz=fu;break}fn=gj[fq&4095](fr&65535)|0;fw=fn;fx=b[4830376]|0;fy=c[3528554]|0;fz=c[2433592]|0}else{fw=a[fs+(fr&255)|0]|0;fx=fv;fy=ft;fz=fu}}while(0);fu=fw&255;c[2426864]=fu|fd<<8;b[4830376]=fx+2&65535;fx=c[fz+(fy*3148|0)+48+(fd<<2)>>2]|0;do{if((fx|0)==0){fw=c[fz+(fy*3148|0)+3120>>2]|0;if((fw|0)==0){fA=0;break}fA=gj[fw&4095]((fu|fd<<8)&65535)|0}else{fA=a[fx+fu|0]|0}}while(0);fu=a[9660760]|0;fx=a[9660784]|0;fd=(fu&255)-(fA&255)-(fx&1)|0;a[9660784]=((fd^(fu^fA)&255^fd>>>1)>>>6&2|fd>>>8&1|((fd&255)<<24>>24==0?(fd>>>4&8|fx&-16&255)&255|4:(fd>>>4&8|fx&-16&255)&255)&255)&255;a[9660760]=fd&255;fd=(c[2440592]|0)-5|0;c[2440592]=fd;f=fd;break};default:{h=1}}}if(h){h=0;switch(i|0){case 243:{i=c[2415188]|0;fd=c[3528554]|0;fx=c[2433592]|0;fA=c[fx+(fd*3148|0)+48+((i>>>8&255)<<2)>>2]|0;do{if((fA|0)==0){fu=c[fx+(fd*3148|0)+3132>>2]|0;if((fu|0)==0){fB=0;fC=i;fD=fd;fE=fx;fF=i&65535;break}fy=gj[fu&4095](i&65535)|0;fu=c[2415188]|0;fB=fy;fC=fu;fD=c[3528554]|0;fE=c[2433592]|0;fF=fu&65535}else{fB=a[fA+(i&255)|0]|0;fC=i;fD=fd;fE=fx;fF=i&65535}}while(0);i=fB&255;fB=fC+1|0;fC=c[fE+(fD*3148|0)+48+((fB>>>8&255)<<2)>>2]|0;do{if((fC|0)==0){fx=c[fE+(fD*3148|0)+3132>>2]|0;if((fx|0)==0){fG=0;fH=fF;fI=fD;fJ=fE;break}fd=gj[fx&4095](fB&65535)|0;fG=fd;fH=b[4830376]|0;fI=c[3528554]|0;fJ=c[2433592]|0}else{fG=a[fC+(fB&255)|0]|0;fH=fF;fI=fD;fJ=fE}}while(0);fE=fG&255;c[2426864]=fE|i<<8;b[4830376]=fH+2&65535;fH=c[fJ+(fI*3148|0)+48+(i<<2)>>2]|0;do{if((fH|0)==0){fG=c[fJ+(fI*3148|0)+3120>>2]|0;if((fG|0)==0){fK=0;fL=fI;fM=fJ;break}fD=gj[fG&4095]((fE|i<<8)&65535)|0;fK=fD;fL=c[3528554]|0;fM=c[2433592]|0}else{fK=a[fH+fE|0]|0;fL=fI;fM=fJ}}while(0);fJ=(fK&255)<<8;fK=c[fM+(fL*3148|0)+48+((((fE|i<<8)+1|0)>>>8&255)<<2)>>2]|0;do{if((fK|0)==0){fI=c[fM+(fL*3148|0)+3120>>2]|0;if((fI|0)==0){fN=0;break}fN=gj[fI&4095](((fE|i<<8)+1|0)&65535)|0}else{fN=a[fK+(((fE|i<<8)+1|0)&255)|0]|0}}while(0);i=e[4830380]|0;fE=i+(fN&255|fJ)|0;fN=(fE>>>12&8|a[9660784]&-16&255)&255;a[9660784]=((i^fJ^fE^fE>>>1)>>>14&2|fE>>>16&1|((fE&65535)<<16>>16==0?fN|4:fN)&255)&255;b[4830380]=fE&65535;fE=(c[2440592]|0)-7|0;c[2440592]=fE;f=fE;break};case 244:{fE=c[2415188]|0;fN=c[3528554]|0;fJ=c[2433592]|0;i=c[fJ+(fN*3148|0)+48+((fE>>>8&255)<<2)>>2]|0;do{if((i|0)==0){fK=c[fJ+(fN*3148|0)+3132>>2]|0;if((fK|0)==0){fO=0;fP=fE;fQ=fN;fR=fJ;fS=fE&65535;break}fL=gj[fK&4095](fE&65535)|0;fK=c[2415188]|0;fO=fL;fP=fK;fQ=c[3528554]|0;fR=c[2433592]|0;fS=fK&65535}else{fO=a[i+(fE&255)|0]|0;fP=fE;fQ=fN;fR=fJ;fS=fE&65535}}while(0);fE=fO&255;fO=fP+1|0;fP=c[fR+(fQ*3148|0)+48+((fO>>>8&255)<<2)>>2]|0;do{if((fP|0)==0){fJ=c[fR+(fQ*3148|0)+3132>>2]|0;if((fJ|0)==0){fT=0;fU=fS;fV=fQ;fW=fR;break}fN=gj[fJ&4095](fO&65535)|0;fT=fN;fU=b[4830376]|0;fV=c[3528554]|0;fW=c[2433592]|0}else{fT=a[fP+(fO&255)|0]|0;fU=fS;fV=fQ;fW=fR}}while(0);fR=fT&255;c[2426864]=fR|fE<<8;b[4830376]=fU+2&65535;fU=c[fW+(fV*3148|0)+48+(fE<<2)>>2]|0;do{if((fU|0)==0){fT=c[fW+(fV*3148|0)+3120>>2]|0;if((fT|0)==0){fX=0;break}fX=gj[fT&4095]((fR|fE<<8)&65535)|0}else{fX=a[fU+fR|0]|0}}while(0);fR=a[9660760]&fX;a[9660760]=fR;fX=(fR&255)>>>4&8|a[9660784]&-15;a[9660784]=fR<<24>>24==0?fX|4:fX;fX=(c[2440592]|0)-5|0;c[2440592]=fX;f=fX;break};case 245:{fX=c[2415188]|0;fR=c[3528554]|0;fU=c[2433592]|0;fE=c[fU+(fR*3148|0)+48+((fX>>>8&255)<<2)>>2]|0;do{if((fE|0)==0){fV=c[fU+(fR*3148|0)+3132>>2]|0;if((fV|0)==0){fY=0;fZ=fX;f_=fR;f$=fU;f0=fX&65535;break}fW=gj[fV&4095](fX&65535)|0;fV=c[2415188]|0;fY=fW;fZ=fV;f_=c[3528554]|0;f$=c[2433592]|0;f0=fV&65535}else{fY=a[fE+(fX&255)|0]|0;fZ=fX;f_=fR;f$=fU;f0=fX&65535}}while(0);fX=fY&255;fY=fZ+1|0;fZ=c[f$+(f_*3148|0)+48+((fY>>>8&255)<<2)>>2]|0;do{if((fZ|0)==0){fU=c[f$+(f_*3148|0)+3132>>2]|0;if((fU|0)==0){f1=0;f2=f0;f3=f_;f4=f$;break}fR=gj[fU&4095](fY&65535)|0;f1=fR;f2=b[4830376]|0;f3=c[3528554]|0;f4=c[2433592]|0}else{f1=a[fZ+(fY&255)|0]|0;f2=f0;f3=f_;f4=f$}}while(0);f$=f1&255;c[2426864]=f$|fX<<8;b[4830376]=f2+2&65535;f2=c[f4+(f3*3148|0)+48+(fX<<2)>>2]|0;do{if((f2|0)==0){f1=c[f4+(f3*3148|0)+3120>>2]|0;if((f1|0)==0){f5=0;break}f5=gj[f1&4095]((f$|fX<<8)&65535)|0}else{f5=a[f2+f$|0]|0}}while(0);f$=a[9660760]&f5;f5=(f$&255)>>>4&8|a[9660784]&-15;a[9660784]=f$<<24>>24==0?f5|4:f5;f5=(c[2440592]|0)-5|0;c[2440592]=f5;f=f5;break};case 246:{f5=c[2415188]|0;f$=c[3528554]|0;f2=c[2433592]|0;fX=c[f2+(f$*3148|0)+48+((f5>>>8&255)<<2)>>2]|0;do{if((fX|0)==0){f3=c[f2+(f$*3148|0)+3132>>2]|0;if((f3|0)==0){f6=0;f7=f5;f8=f$;f9=f2;ga=f5&65535;break}f4=gj[f3&4095](f5&65535)|0;f3=c[2415188]|0;f6=f4;f7=f3;f8=c[3528554]|0;f9=c[2433592]|0;ga=f3&65535}else{f6=a[fX+(f5&255)|0]|0;f7=f5;f8=f$;f9=f2;ga=f5&65535}}while(0);f5=f6&255;f6=f7+1|0;f7=c[f9+(f8*3148|0)+48+((f6>>>8&255)<<2)>>2]|0;do{if((f7|0)==0){f2=c[f9+(f8*3148|0)+3132>>2]|0;if((f2|0)==0){gb=0;gc=ga;gd=f8;ge=f9;break}f$=gj[f2&4095](f6&65535)|0;gb=f$;gc=b[4830376]|0;gd=c[3528554]|0;ge=c[2433592]|0}else{gb=a[f7+(f6&255)|0]|0;gc=ga;gd=f8;ge=f9}}while(0);f9=gb&255;c[2426864]=f9|f5<<8;b[4830376]=gc+2&65535;gc=c[ge+(gd*3148|0)+48+(f5<<2)>>2]|0;do{if((gc|0)==0){gb=c[ge+(gd*3148|0)+3120>>2]|0;if((gb|0)==0){gf=0;break}gf=gj[gb&4095]((f9|f5<<8)&65535)|0}else{gf=a[gc+f9|0]|0}}while(0);a[9660760]=gf;f9=(gf&255)>>>4&8|a[9660784]&-15;a[9660784]=gf<<24>>24==0?f9|4:f9;f9=(c[2440592]|0)-5|0;c[2440592]=f9;f=f9;break};case 247:{f9=a[9660760]|0;gf=(f9&255)>>>4&8|a[9660784]&-15;a[9660784]=f9<<24>>24==0?gf|4:gf;gf=c[2415188]|0;f9=c[3528554]|0;gc=c[2433592]|0;f5=c[gc+(f9*3148|0)+48+((gf>>>8&255)<<2)>>2]|0;do{if((f5|0)==0){gd=c[gc+(f9*3148|0)+3132>>2]|0;if((gd|0)==0){gh=0;gi=gf;gk=f9;gl=gc;gm=gf&65535;break}ge=gj[gd&4095](gf&65535)|0;gd=c[2415188]|0;gh=ge;gi=gd;gk=c[3528554]|0;gl=c[2433592]|0;gm=gd&65535}else{gh=a[f5+(gf&255)|0]|0;gi=gf;gk=f9;gl=gc;gm=gf&65535}}while(0);gf=gh&255;gh=gi+1|0;gi=c[gl+(gk*3148|0)+48+((gh>>>8&255)<<2)>>2]|0;do{if((gi|0)==0){gc=c[gl+(gk*3148|0)+3132>>2]|0;if((gc|0)==0){gn=0;go=gm;gp=gk;gq=gl;break}f9=gj[gc&4095](gh&65535)|0;gn=f9;go=b[4830376]|0;gp=c[3528554]|0;gq=c[2433592]|0}else{gn=a[gi+(gh&255)|0]|0;go=gm;gp=gk;gq=gl}}while(0);gl=gn&255;c[2426864]=gl|gf<<8;b[4830376]=go+2&65535;go=a[9660760]|0;gn=c[gq+(gp*3148|0)+48+((gf|256)<<2)>>2]|0;do{if((gn|0)==0){gk=c[gq+(gp*3148|0)+3124>>2]|0;if((gk|0)==0){break}gg[gk&4095]((gl|gf<<8)&65535,go)}else{a[gn+gl|0]=go}}while(0);go=(c[2440592]|0)-5|0;c[2440592]=go;f=go;break};case 248:{go=c[2415188]|0;gl=c[3528554]|0;gn=c[2433592]|0;gf=c[gn+(gl*3148|0)+48+((go>>>8&255)<<2)>>2]|0;do{if((gf|0)==0){gp=c[gn+(gl*3148|0)+3132>>2]|0;if((gp|0)==0){gr=0;gs=go;gt=gl;gu=gn;gv=go&65535;break}gq=gj[gp&4095](go&65535)|0;gp=c[2415188]|0;gr=gq;gs=gp;gt=c[3528554]|0;gu=c[2433592]|0;gv=gp&65535}else{gr=a[gf+(go&255)|0]|0;gs=go;gt=gl;gu=gn;gv=go&65535}}while(0);go=gr&255;gr=gs+1|0;gs=c[gu+(gt*3148|0)+48+((gr>>>8&255)<<2)>>2]|0;do{if((gs|0)==0){gn=c[gu+(gt*3148|0)+3132>>2]|0;if((gn|0)==0){gw=0;gx=gv;gy=gt;gz=gu;break}gl=gj[gn&4095](gr&65535)|0;gw=gl;gx=b[4830376]|0;gy=c[3528554]|0;gz=c[2433592]|0}else{gw=a[gs+(gr&255)|0]|0;gx=gv;gy=gt;gz=gu}}while(0);gu=gw&255;c[2426864]=gu|go<<8;b[4830376]=gx+2&65535;gx=c[gz+(gy*3148|0)+48+(go<<2)>>2]|0;do{if((gx|0)==0){gw=c[gz+(gy*3148|0)+3120>>2]|0;if((gw|0)==0){gA=0;break}gA=gj[gw&4095]((gu|go<<8)&65535)|0}else{gA=a[gx+gu|0]|0}}while(0);gu=a[9660760]|0;gx=gu^gA;a[9660760]=gx;go=(gx&255)>>>4&8|a[9660784]&-15;a[9660784]=gu<<24>>24==gA<<24>>24?go|4:go;go=(c[2440592]|0)-5|0;c[2440592]=go;f=go;break};case 249:{go=c[2415188]|0;gA=c[3528554]|0;gu=c[2433592]|0;gx=c[gu+(gA*3148|0)+48+((go>>>8&255)<<2)>>2]|0;do{if((gx|0)==0){gy=c[gu+(gA*3148|0)+3132>>2]|0;if((gy|0)==0){gB=0;gC=go;gD=gA;gE=gu;gF=go&65535;break}gz=gj[gy&4095](go&65535)|0;gy=c[2415188]|0;gB=gz;gC=gy;gD=c[3528554]|0;gE=c[2433592]|0;gF=gy&65535}else{gB=a[gx+(go&255)|0]|0;gC=go;gD=gA;gE=gu;gF=go&65535}}while(0);go=gB&255;gB=gC+1|0;gC=c[gE+(gD*3148|0)+48+((gB>>>8&255)<<2)>>2]|0;do{if((gC|0)==0){gu=c[gE+(gD*3148|0)+3132>>2]|0;if((gu|0)==0){gG=0;gH=gF;gI=gD;gJ=gE;break}gA=gj[gu&4095](gB&65535)|0;gG=gA;gH=b[4830376]|0;gI=c[3528554]|0;gJ=c[2433592]|0}else{gG=a[gC+(gB&255)|0]|0;gH=gF;gI=gD;gJ=gE}}while(0);gE=gG&255;c[2426864]=gE|go<<8;b[4830376]=gH+2&65535;gH=c[gJ+(gI*3148|0)+48+(go<<2)>>2]|0;do{if((gH|0)==0){gG=c[gJ+(gI*3148|0)+3120>>2]|0;if((gG|0)==0){gK=0;break}gK=gj[gG&4095]((gE|go<<8)&65535)|0}else{gK=a[gH+gE|0]|0}}while(0);gE=a[9660760]|0;gH=a[9660784]|0;go=(gE&255)+(gK&255)+(gH&1)|0;gI=go^(gE^gK)&255;a[9660784]=(gI<<1&32|go>>>8&1|(gI^go>>>1)>>>6&2|((go&255)<<24>>24==0?(go>>>4&8|gH&-48&255)&255|4:(go>>>4&8|gH&-48&255)&255)&255)&255;a[9660760]=go&255;go=(c[2440592]|0)-5|0;c[2440592]=go;f=go;break};case 250:{go=c[2415188]|0;gH=c[3528554]|0;gI=c[2433592]|0;gK=c[gI+(gH*3148|0)+48+((go>>>8&255)<<2)>>2]|0;do{if((gK|0)==0){gE=c[gI+(gH*3148|0)+3132>>2]|0;if((gE|0)==0){gL=0;gM=go;gN=gH;gO=gI;gP=go&65535;break}gJ=gj[gE&4095](go&65535)|0;gE=c[2415188]|0;gL=gJ;gM=gE;gN=c[3528554]|0;gO=c[2433592]|0;gP=gE&65535}else{gL=a[gK+(go&255)|0]|0;gM=go;gN=gH;gO=gI;gP=go&65535}}while(0);go=gL&255;gL=gM+1|0;gM=c[gO+(gN*3148|0)+48+((gL>>>8&255)<<2)>>2]|0;do{if((gM|0)==0){gI=c[gO+(gN*3148|0)+3132>>2]|0;if((gI|0)==0){gQ=0;gR=gP;gS=gN;gT=gO;break}gH=gj[gI&4095](gL&65535)|0;gQ=gH;gR=b[4830376]|0;gS=c[3528554]|0;gT=c[2433592]|0}else{gQ=a[gM+(gL&255)|0]|0;gR=gP;gS=gN;gT=gO}}while(0);gO=gQ&255;c[2426864]=gO|go<<8;b[4830376]=gR+2&65535;gR=c[gT+(gS*3148|0)+48+(go<<2)>>2]|0;do{if((gR|0)==0){gQ=c[gT+(gS*3148|0)+3120>>2]|0;if((gQ|0)==0){gU=0;break}gU=gj[gQ&4095]((gO|go<<8)&65535)|0}else{gU=a[gR+gO|0]|0}}while(0);gO=a[9660760]|gU;a[9660760]=gO;gU=(gO&255)>>>4&8|a[9660784]&-15;a[9660784]=gO<<24>>24==0?gU|4:gU;gU=(c[2440592]|0)-5|0;c[2440592]=gU;f=gU;break};case 251:{gU=c[2415188]|0;gO=c[3528554]|0;gR=c[2433592]|0;go=c[gR+(gO*3148|0)+48+((gU>>>8&255)<<2)>>2]|0;do{if((go|0)==0){gS=c[gR+(gO*3148|0)+3132>>2]|0;if((gS|0)==0){gV=0;gW=gU;gX=gO;gY=gR;gZ=gU&65535;break}gT=gj[gS&4095](gU&65535)|0;gS=c[2415188]|0;gV=gT;gW=gS;gX=c[3528554]|0;gY=c[2433592]|0;gZ=gS&65535}else{gV=a[go+(gU&255)|0]|0;gW=gU;gX=gO;gY=gR;gZ=gU&65535}}while(0);gU=gV&255;gV=gW+1|0;gW=c[gY+(gX*3148|0)+48+((gV>>>8&255)<<2)>>2]|0;do{if((gW|0)==0){gR=c[gY+(gX*3148|0)+3132>>2]|0;if((gR|0)==0){g_=0;g$=gZ;g0=gX;g1=gY;break}gO=gj[gR&4095](gV&65535)|0;g_=gO;g$=b[4830376]|0;g0=c[3528554]|0;g1=c[2433592]|0}else{g_=a[gW+(gV&255)|0]|0;g$=gZ;g0=gX;g1=gY}}while(0);gY=g_&255;c[2426864]=gY|gU<<8;b[4830376]=g$+2&65535;g$=c[g1+(g0*3148|0)+48+(gU<<2)>>2]|0;do{if((g$|0)==0){g_=c[g1+(g0*3148|0)+3120>>2]|0;if((g_|0)==0){g2=0;break}g2=gj[g_&4095]((gY|gU<<8)&65535)|0}else{g2=a[g$+gY|0]|0}}while(0);gY=a[9660760]|0;g$=(gY&255)+(g2&255)|0;gU=(g$>>>4&8|a[9660784]&-48&255)&255;g0=(gY^g2)&255^g$;a[9660784]=(g0<<1&32|g$>>>8&1|(g0^g$>>>1)>>>6&2|((g$&255)<<24>>24==0?gU|4:gU)&255)&255;a[9660760]=g$&255;g$=(c[2440592]|0)-5|0;c[2440592]=g$;f=g$;break};case 252:{g$=c[2415188]|0;gU=c[3528554]|0;g0=c[2433592]|0;g2=c[g0+(gU*3148|0)+48+((g$>>>8&255)<<2)>>2]|0;do{if((g2|0)==0){gY=c[g0+(gU*3148|0)+3132>>2]|0;if((gY|0)==0){g3=0;g4=g$;g5=gU;g6=g0;g7=g$&65535;break}g1=gj[gY&4095](g$&65535)|0;gY=c[2415188]|0;g3=g1;g4=gY;g5=c[3528554]|0;g6=c[2433592]|0;g7=gY&65535}else{g3=a[g2+(g$&255)|0]|0;g4=g$;g5=gU;g6=g0;g7=g$&65535}}while(0);g$=g3&255;g3=g4+1|0;g4=c[g6+(g5*3148|0)+48+((g3>>>8&255)<<2)>>2]|0;do{if((g4|0)==0){g0=c[g6+(g5*3148|0)+3132>>2]|0;if((g0|0)==0){g8=0;g9=g7;ha=g5;hb=g6;break}gU=gj[g0&4095](g3&65535)|0;g8=gU;g9=b[4830376]|0;ha=c[3528554]|0;hb=c[2433592]|0}else{g8=a[g4+(g3&255)|0]|0;g9=g7;ha=g5;hb=g6}}while(0);g6=g8&255;c[2426864]=g6|g$<<8;b[4830376]=g9+2&65535;g9=c[hb+(ha*3148|0)+48+(g$<<2)>>2]|0;do{if((g9|0)==0){g8=c[hb+(ha*3148|0)+3120>>2]|0;if((g8|0)==0){hc=0;hd=ha;he=hb;break}g5=gj[g8&4095]((g6|g$<<8)&65535)|0;hc=g5;hd=c[3528554]|0;he=c[2433592]|0}else{hc=a[g9+g6|0]|0;hd=ha;he=hb}}while(0);hb=hc&255;hc=c[he+(hd*3148|0)+48+((((g6|g$<<8)+1|0)>>>8&255)<<2)>>2]|0;do{if((hc|0)==0){ha=c[he+(hd*3148|0)+3120>>2]|0;if((ha|0)==0){hf=0;break}hf=gj[ha&4095](((g6|g$<<8)+1|0)&65535)|0}else{hf=a[hc+(((g6|g$<<8)+1|0)&255)|0]|0}}while(0);g$=hf&255|hb<<8;c[2415190]=g$;hf=a[9660784]&-15;a[9660784]=hf;if((g$|0)==0){hg=(hf&255|hb>>>4&8|4)&255}else{hg=(hf&255|hb>>>4&8)&255}a[9660784]=hg;hg=(c[2440592]|0)-6|0;c[2440592]=hg;f=hg;break};case 253:{hg=b[4830380]|0;hb=(hg&65535)>>>12&8|a[9660784]&-15&255;a[9660784]=(hg<<16>>16==0?hb|4:hb)&255;hb=c[2415188]|0;hg=c[3528554]|0;hf=c[2433592]|0;g$=c[hf+(hg*3148|0)+48+((hb>>>8&255)<<2)>>2]|0;do{if((g$|0)==0){g6=c[hf+(hg*3148|0)+3132>>2]|0;if((g6|0)==0){hh=0;hi=hb;hj=hg;hk=hf;hl=hb&65535;break}hc=gj[g6&4095](hb&65535)|0;g6=c[2415188]|0;hh=hc;hi=g6;hj=c[3528554]|0;hk=c[2433592]|0;hl=g6&65535}else{hh=a[g$+(hb&255)|0]|0;hi=hb;hj=hg;hk=hf;hl=hb&65535}}while(0);hb=hh&255;hh=hi+1|0;hi=c[hk+(hj*3148|0)+48+((hh>>>8&255)<<2)>>2]|0;do{if((hi|0)==0){hf=c[hk+(hj*3148|0)+3132>>2]|0;if((hf|0)==0){hm=0;hn=hl;ho=hj;hp=hk;break}hg=gj[hf&4095](hh&65535)|0;hm=hg;hn=b[4830376]|0;ho=c[3528554]|0;hp=c[2433592]|0}else{hm=a[hi+(hh&255)|0]|0;hn=hl;ho=hj;hp=hk}}while(0);hk=hm&255;c[2426864]=hk|hb<<8;b[4830376]=hn+2&65535;hn=a[9660761]|0;hm=c[hp+(ho*3148|0)+48+((hb|256)<<2)>>2]|0;do{if((hm|0)==0){hj=c[hp+(ho*3148|0)+3124>>2]|0;if((hj|0)==0){hq=ho;hr=hp;break}gg[hj&4095]((hk|hb<<8)&65535,hn);hq=c[3528554]|0;hr=c[2433592]|0}else{a[hm+hk|0]=hn;hq=ho;hr=hp}}while(0);hp=a[9660760]|0;ho=c[hr+(hq*3148|0)+48+((((hk|hb<<8)+1|0)>>>8&255|256)<<2)>>2]|0;do{if((ho|0)==0){hn=c[hr+(hq*3148|0)+3124>>2]|0;if((hn|0)==0){break}gg[hn&4095](((hk|hb<<8)+1|0)&65535,hp)}else{a[ho+(((hk|hb<<8)+1|0)&255)|0]=hp}}while(0);hp=(c[2440592]|0)-6|0;c[2440592]=hp;f=hp;break};case 254:{hp=c[2415188]|0;hb=c[3528554]|0;hk=c[2433592]|0;ho=c[hk+(hb*3148|0)+48+((hp>>>8&255)<<2)>>2]|0;do{if((ho|0)==0){hq=c[hk+(hb*3148|0)+3132>>2]|0;if((hq|0)==0){hs=0;ht=hp;hu=hb;hv=hk;hw=hp&65535;break}hr=gj[hq&4095](hp&65535)|0;hq=c[2415188]|0;hs=hr;ht=hq;hu=c[3528554]|0;hv=c[2433592]|0;hw=hq&65535}else{hs=a[ho+(hp&255)|0]|0;ht=hp;hu=hb;hv=hk;hw=hp&65535}}while(0);hp=hs&255;hs=ht+1|0;ht=c[hv+(hu*3148|0)+48+((hs>>>8&255)<<2)>>2]|0;do{if((ht|0)==0){hk=c[hv+(hu*3148|0)+3132>>2]|0;if((hk|0)==0){hx=0;hy=hw;hz=hu;hA=hv;break}hb=gj[hk&4095](hs&65535)|0;hx=hb;hy=b[4830376]|0;hz=c[3528554]|0;hA=c[2433592]|0}else{hx=a[ht+(hs&255)|0]|0;hy=hw;hz=hu;hA=hv}}while(0);hv=hx&255;c[2426864]=hv|hp<<8;b[4830376]=hy+2&65535;hy=c[hA+(hz*3148|0)+48+(hp<<2)>>2]|0;do{if((hy|0)==0){hx=c[hA+(hz*3148|0)+3120>>2]|0;if((hx|0)==0){hB=0;hC=hz;hD=hA;break}hu=gj[hx&4095]((hv|hp<<8)&65535)|0;hB=hu;hC=c[3528554]|0;hD=c[2433592]|0}else{hB=a[hy+hv|0]|0;hC=hz;hD=hA}}while(0);hA=hB&255;hB=c[hD+(hC*3148|0)+48+((((hv|hp<<8)+1|0)>>>8&255)<<2)>>2]|0;do{if((hB|0)==0){hz=c[hD+(hC*3148|0)+3120>>2]|0;if((hz|0)==0){hE=0;break}hE=gj[hz&4095](((hv|hp<<8)+1|0)&65535)|0}else{hE=a[hB+(((hv|hp<<8)+1|0)&255)|0]|0}}while(0);hp=hE&255|hA<<8;c[2415192]=hp;hE=a[9660784]&-15;a[9660784]=hE;if((hp|0)==0){hF=(hE&255|hA>>>4&8|4)&255}else{hF=(hE&255|hA>>>4&8)&255}a[9660784]=hF;hF=(c[2440592]|0)-6|0;c[2440592]=hF;f=hF;break};case 255:{hF=b[4830384]|0;hA=(hF&65535)>>>12&8|a[9660784]&-15&255;a[9660784]=(hF<<16>>16==0?hA|4:hA)&255;hA=c[2415188]|0;hF=c[3528554]|0;hE=c[2433592]|0;hp=c[hE+(hF*3148|0)+48+((hA>>>8&255)<<2)>>2]|0;do{if((hp|0)==0){hv=c[hE+(hF*3148|0)+3132>>2]|0;if((hv|0)==0){hG=0;hH=hA;hI=hF;hJ=hE;hK=hA&65535;break}hB=gj[hv&4095](hA&65535)|0;hv=c[2415188]|0;hG=hB;hH=hv;hI=c[3528554]|0;hJ=c[2433592]|0;hK=hv&65535}else{hG=a[hp+(hA&255)|0]|0;hH=hA;hI=hF;hJ=hE;hK=hA&65535}}while(0);hA=hG&255;hG=hH+1|0;hH=c[hJ+(hI*3148|0)+48+((hG>>>8&255)<<2)>>2]|0;do{if((hH|0)==0){hE=c[hJ+(hI*3148|0)+3132>>2]|0;if((hE|0)==0){hL=0;hM=hK;hN=hI;hO=hJ;break}hF=gj[hE&4095](hG&65535)|0;hL=hF;hM=b[4830376]|0;hN=c[3528554]|0;hO=c[2433592]|0}else{hL=a[hH+(hG&255)|0]|0;hM=hK;hN=hI;hO=hJ}}while(0);hJ=hL&255;c[2426864]=hJ|hA<<8;b[4830376]=hM+2&65535;hM=a[9660769]|0;hL=c[hO+(hN*3148|0)+48+((hA|256)<<2)>>2]|0;do{if((hL|0)==0){hI=c[hO+(hN*3148|0)+3124>>2]|0;if((hI|0)==0){hP=hN;hQ=hO;break}gg[hI&4095]((hJ|hA<<8)&65535,hM);hP=c[3528554]|0;hQ=c[2433592]|0}else{a[hL+hJ|0]=hM;hP=hN;hQ=hO}}while(0);hO=a[9660768]|0;hN=c[hQ+(hP*3148|0)+48+((((hJ|hA<<8)+1|0)>>>8&255|256)<<2)>>2]|0;do{if((hN|0)==0){hM=c[hQ+(hP*3148|0)+3124>>2]|0;if((hM|0)==0){break}gg[hM&4095](((hJ|hA<<8)+1|0)&65535,hO)}else{a[hN+(((hJ|hA<<8)+1|0)&255)|0]=hO}}while(0);hO=(c[2440592]|0)-6|0;c[2440592]=hO;f=hO;break};default:{g=43386}}}c[d+51624>>2]=f;c[d+51656>>2]=g;c[d+51664>>2]=h}function __Z13m6809_executei$1(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0,cf=0,cg=0,ch=0,ci=0,cj=0,ck=0,cl=0,cm=0,cn=0,co=0,cp=0,cq=0,cr=0,cs=0,ct=0,cu=0,cv=0,cw=0,cx=0,cy=0,cz=0,cA=0,cB=0,cC=0,cD=0,cE=0,cF=0,cG=0,cH=0,cI=0,cJ=0,cK=0,cL=0,cM=0,cN=0,cO=0,cP=0,cQ=0,cR=0,cS=0,cT=0,cU=0,cV=0,cW=0,cX=0,cY=0,cZ=0,c_=0,c$=0,c0=0,c1=0,c2=0,c3=0,c4=0,c5=0,c6=0,c7=0,c8=0,c9=0,da=0,db=0,dc=0,dd=0,de=0,df=0,dg=0,dh=0,di=0,dj=0,dk=0,dl=0,dm=0,dn=0,dp=0,dq=0,dr=0,ds=0,dt=0,du=0,dv=0,dw=0,dx=0,dy=0,dz=0,dA=0,dB=0,dC=0,dD=0,dE=0,dF=0,dG=0,dH=0,dI=0,dJ=0,dK=0,dL=0,dM=0,dN=0,dO=0,dP=0,dQ=0,dR=0,dS=0,dT=0,dU=0,dV=0,dW=0,dX=0,dY=0,dZ=0,d_=0,d$=0,d0=0,d1=0,d2=0,d3=0,d4=0,d5=0,d6=0,d7=0,d8=0,d9=0,ea=0,eb=0,ec=0,ed=0,ee=0,ef=0,eg=0,eh=0,ei=0,ej=0,ek=0,el=0,em=0,en=0,eo=0,ep=0,eq=0,er=0,es=0,et=0,eu=0,ev=0,ew=0,ex=0,ey=0,ez=0,eA=0,eB=0,eC=0,eD=0,eE=0,eF=0,eG=0,eH=0,eI=0,eJ=0,eK=0,eL=0,eM=0,eN=0,eO=0,eP=0,eQ=0,eR=0,eS=0,eT=0,eU=0,eV=0,eW=0,eX=0,eY=0,eZ=0,e_=0,e$=0,e0=0,e1=0,e2=0,e3=0,e4=0,e5=0,e6=0,e7=0,e8=0,e9=0,fa=0,fb=0,fc=0,fd=0,fe=0,ff=0,fg=0,fh=0,fi=0,fj=0,fk=0,fl=0,fm=0,fn=0,fo=0,fp=0,fq=0,fr=0,fs=0,ft=0,fu=0,fv=0,fw=0,fx=0,fy=0,fz=0,fA=0,fB=0,fC=0,fD=0,fE=0,fF=0,fG=0,fH=0,fI=0,fJ=0,fK=0,fL=0,fM=0,fN=0,fO=0,fP=0,fQ=0,fR=0,fS=0,fT=0,fU=0,fV=0,fW=0,fX=0,fY=0,fZ=0,f_=0,f$=0,f0=0,f1=0,f2=0,f3=0,f4=0,f5=0,f6=0,f7=0,f8=0,f9=0,ga=0,gb=0,gc=0,gd=0,ge=0,gf=0,gh=0,gi=0,gk=0,gl=0,gm=0,gn=0,go=0,gp=0,gq=0,gr=0,gs=0,gt=0,gu=0,gv=0,gw=0,gx=0,gy=0,gz=0,gA=0,gB=0,gC=0,gD=0,gE=0,gF=0,gG=0,gH=0,gI=0,gJ=0,gK=0,gL=0,gM=0,gN=0,gO=0,gP=0,gQ=0,gR=0,gS=0,gT=0,gU=0,gV=0,gW=0,gX=0,gY=0,gZ=0,g_=0,g$=0,g0=0,g1=0,g2=0,g3=0,g4=0,g5=0,g6=0,g7=0,g8=0,g9=0,ha=0,hb=0,hc=0,hd=0,he=0,hf=0,hg=0,hh=0,hi=0,hj=0,hk=0,hl=0,hm=0,hn=0,ho=0,hp=0,hq=0,hr=0,hs=0,ht=0,hu=0,hv=0,hw=0,hx=0,hy=0,hz=0,hA=0;g=c[f+80>>2]|0;h=c[f+51624>>2]|0;i=c[f+51656>>2]|0;j=c[f+51664>>2]|0;k=c[f+51672>>2]|0;if(j){j=0;switch(k|0){case 59:{l=c[2415193]|0;m=c[3528554]|0;n=c[2433592]|0;o=c[n+(m*3148|0)+48+((l>>>8&255)<<2)>>2]|0;do{if((o|0)==0){p=c[n+(m*3148|0)+3120>>2]|0;if((p|0)==0){a[9660784]=0;b[4830386]=(l&65535)+1&65535;break}else{q=gj[p&4095](l&65535)|0;r=q;s=b[4830386]|0;i=41568;break}}else{r=a[o+(l&255)|0]|0;s=l&65535;i=41568}}while(0);do{if((i|0)==41568){i=0;a[9660784]=r;b[4830386]=s+1&65535;if(r<<24>>24>=0){break}c[2440592]=(c[2440592]|0)-9;l=c[2415193]|0;o=c[3528554]|0;m=c[2433592]|0;n=c[m+(o*3148|0)+48+((l>>>8&255)<<2)>>2]|0;do{if((n|0)==0){q=c[m+(o*3148|0)+3120>>2]|0;if((q|0)==0){t=0;u=l&65535;v=o;w=m;break}p=gj[q&4095](l&65535)|0;t=p;u=b[4830386]|0;v=c[3528554]|0;w=c[2433592]|0}else{t=a[n+(l&255)|0]|0;u=l&65535;v=o;w=m}}while(0);a[9660761]=t;b[4830386]=u+1&65535;m=c[2415193]|0;o=c[w+(v*3148|0)+48+((m>>>8&255)<<2)>>2]|0;do{if((o|0)==0){l=c[w+(v*3148|0)+3120>>2]|0;if((l|0)==0){x=0;y=m&65535;z=v;A=w;break}n=gj[l&4095](m&65535)|0;x=n;y=b[4830386]|0;z=c[3528554]|0;A=c[2433592]|0}else{x=a[o+(m&255)|0]|0;y=m&65535;z=v;A=w}}while(0);a[9660760]=x;b[4830386]=y+1&65535;m=c[2415193]|0;o=c[A+(z*3148|0)+48+((m>>>8&255)<<2)>>2]|0;do{if((o|0)==0){n=c[A+(z*3148|0)+3120>>2]|0;if((n|0)==0){B=0;C=m&65535;D=z;E=A;break}l=gj[n&4095](m&65535)|0;B=l;C=b[4830386]|0;D=c[3528554]|0;E=c[2433592]|0}else{B=a[o+(m&255)|0]|0;C=m&65535;D=z;E=A}}while(0);a[9660765]=B;b[4830386]=C+1&65535;m=c[2415193]|0;o=c[E+(D*3148|0)+48+((m>>>8&255)<<2)>>2]|0;do{if((o|0)==0){l=c[E+(D*3148|0)+3120>>2]|0;if((l|0)==0){F=0;G=m&65535;H=D;I=E;break}n=gj[l&4095](m&65535)|0;F=n;G=b[4830386]|0;H=c[3528554]|0;I=c[2433592]|0}else{F=a[o+(m&255)|0]|0;G=m&65535;H=D;I=E}}while(0);m=(F&255)<<8;c[2415194]=m;b[4830386]=G+1&65535;o=c[2415193]|0;n=c[I+(H*3148|0)+48+((o>>>8&255)<<2)>>2]|0;do{if((n|0)==0){l=c[I+(H*3148|0)+3120>>2]|0;if((l|0)==0){J=0;K=m;L=o&65535;M=H;N=I;break}p=gj[l&4095](o&65535)|0;J=p;K=c[2415194]|0;L=b[4830386]|0;M=c[3528554]|0;N=c[2433592]|0}else{J=a[n+(o&255)|0]|0;K=m;L=o&65535;M=H;N=I}}while(0);c[2415194]=K|J&255;b[4830386]=L+1&65535;o=c[2415193]|0;m=c[N+(M*3148|0)+48+((o>>>8&255)<<2)>>2]|0;do{if((m|0)==0){n=c[N+(M*3148|0)+3120>>2]|0;if((n|0)==0){O=0;P=o&65535;Q=M;R=N;break}p=gj[n&4095](o&65535)|0;O=p;P=b[4830386]|0;Q=c[3528554]|0;R=c[2433592]|0}else{O=a[m+(o&255)|0]|0;P=o&65535;Q=M;R=N}}while(0);o=(O&255)<<8;c[2415195]=o;b[4830386]=P+1&65535;m=c[2415193]|0;p=c[R+(Q*3148|0)+48+((m>>>8&255)<<2)>>2]|0;do{if((p|0)==0){n=c[R+(Q*3148|0)+3120>>2]|0;if((n|0)==0){S=0;T=o;U=m&65535;V=Q;W=R;break}l=gj[n&4095](m&65535)|0;S=l;T=c[2415195]|0;U=b[4830386]|0;V=c[3528554]|0;W=c[2433592]|0}else{S=a[p+(m&255)|0]|0;T=o;U=m&65535;V=Q;W=R}}while(0);c[2415195]=T|S&255;b[4830386]=U+1&65535;m=c[2415193]|0;o=c[W+(V*3148|0)+48+((m>>>8&255)<<2)>>2]|0;do{if((o|0)==0){p=c[W+(V*3148|0)+3120>>2]|0;if((p|0)==0){X=0;Y=m&65535;Z=V;_=W;break}l=gj[p&4095](m&65535)|0;X=l;Y=b[4830386]|0;Z=c[3528554]|0;_=c[2433592]|0}else{X=a[o+(m&255)|0]|0;Y=m&65535;Z=V;_=W}}while(0);m=(X&255)<<8;c[2415192]=m;b[4830386]=Y+1&65535;o=c[2415193]|0;l=c[_+(Z*3148|0)+48+((o>>>8&255)<<2)>>2]|0;do{if((l|0)==0){p=c[_+(Z*3148|0)+3120>>2]|0;if((p|0)==0){$=0;aa=m;ab=o&65535;break}n=gj[p&4095](o&65535)|0;$=n;aa=c[2415192]|0;ab=b[4830386]|0}else{$=a[l+(o&255)|0]|0;aa=m;ab=o&65535}}while(0);c[2415192]=aa|$&255;b[4830386]=ab+1&65535}}while(0);ab=c[2415193]|0;$=c[3528554]|0;aa=c[2433592]|0;Z=c[aa+($*3148|0)+48+((ab>>>8&255)<<2)>>2]|0;do{if((Z|0)==0){_=c[aa+($*3148|0)+3120>>2]|0;if((_|0)==0){ac=0;ad=ab&65535;ae=$;af=aa;break}Y=gj[_&4095](ab&65535)|0;ac=Y;ad=b[4830386]|0;ae=c[3528554]|0;af=c[2433592]|0}else{ac=a[Z+(ab&255)|0]|0;ad=ab&65535;ae=$;af=aa}}while(0);aa=(ac&255)<<8;c[2415188]=aa;b[4830386]=ad+1&65535;ad=c[2415193]|0;ac=c[af+(ae*3148|0)+48+((ad>>>8&255)<<2)>>2]|0;do{if((ac|0)==0){$=c[af+(ae*3148|0)+3120>>2]|0;if(($|0)==0){ah=0;ai=aa;aj=ad&65535;break}ab=gj[$&4095](ad&65535)|0;ah=ab;ai=c[2415188]|0;aj=b[4830386]|0}else{ah=a[ac+(ad&255)|0]|0;ai=aa;aj=ad&65535}}while(0);ad=ai|ah&255;c[2415188]=ad;b[4830386]=aj+1&65535;b[4830376]=ad&65535;ah=a[9660786]|0;ai=a[9660787]|0;if((ai|ah)<<24>>24!=0){a[9660796]=a[9660796]&-17}do{if(ai<<24>>24==0){i=41641}else{aa=a[9660784]|0;if((aa&64)!=0){i=41641;break}ac=a[9660796]|0;if((ac&8)==0){a[9660784]=aa&127;b[4830386]=aj;ae=c[2415193]|0;af=c[3528554]|0;ab=c[2433592]|0;$=c[ab+(af*3148|0)+48+((ae>>>8&255|256)<<2)>>2]|0;do{if(($|0)==0){Z=c[ab+(af*3148|0)+3124>>2]|0;if((Z|0)==0){ak=af;al=ab;break}gg[Z&4095](ae&65535,ad&255);ak=c[3528554]|0;al=c[2433592]|0}else{a[$+(ae&255)|0]=ad&255;ak=af;al=ab}}while(0);b[4830386]=(b[4830386]|0)-1&65535;ab=c[2415193]|0;af=a[9660753]|0;ae=c[al+(ak*3148|0)+48+((ab>>>8&255|256)<<2)>>2]|0;do{if((ae|0)==0){$=c[al+(ak*3148|0)+3124>>2]|0;if(($|0)==0){am=ak;an=al;break}gg[$&4095](ab&65535,af);am=c[3528554]|0;an=c[2433592]|0}else{a[ae+(ab&255)|0]=af;am=ak;an=al}}while(0);b[4830386]=(b[4830386]|0)-1&65535;af=c[2415193]|0;ab=a[9660784]|0;ae=c[an+(am*3148|0)+48+((af>>>8&255|256)<<2)>>2]|0;do{if((ae|0)==0){$=c[an+(am*3148|0)+3124>>2]|0;if(($|0)==0){break}gg[$&4095](af&65535,ab)}else{a[ae+(af&255)|0]=ab}}while(0);ao=(c[2415197]|0)+10|0;ap=a[9660784]|0}else{a[9660796]=ac&-9;ao=(c[2415197]|0)+7|0;ap=aa}c[2415197]=ao;a[9660784]=ap|80;ab=c[3528554]|0;af=c[2433592]|0;ae=c[af+(ab*3148|0)+1068>>2]|0;do{if((ae|0)==0){$=c[af+(ab*3148|0)+3120>>2]|0;if(($|0)==0){aq=0;ar=0;break}Z=gj[$&4095](-10)|0;$=c[3528554]|0;Y=c[2433592]|0;_=c[Y+($*3148|0)+1068>>2]|0;if((_|0)!=0){as=_;at=(Z&255)<<8;i=41637;break}_=c[Y+($*3148|0)+3120>>2]|0;if((_|0)==0){aq=0;ar=(Z&255)<<8;break}aq=gj[_&4095](-9)|0;ar=(Z&255)<<8}else{as=ae;at=(d[ae+246|0]|0)<<8;i=41637}}while(0);if((i|0)==41637){i=0;aq=a[as+247|0]|0;ar=at}ae=aq&255|ar;c[2415188]=ae;b[4830376]=ae&65535}}while(0);do{if((i|0)==41641){i=0;if(ah<<24>>24==0){break}ar=a[9660784]|0;if((ar&16)!=0){break}aq=a[9660796]|0;if((aq&8)==0){a[9660784]=ar|-128;b[4830386]=aj;at=c[2415193]|0;as=c[3528554]|0;ap=c[2433592]|0;ao=c[ap+(as*3148|0)+48+((at>>>8&255|256)<<2)>>2]|0;do{if((ao|0)==0){am=c[ap+(as*3148|0)+3124>>2]|0;if((am|0)==0){au=as;av=ap;break}gg[am&4095](at&65535,ad&255);au=c[3528554]|0;av=c[2433592]|0}else{a[ao+(at&255)|0]=ad&255;au=as;av=ap}}while(0);b[4830386]=(b[4830386]|0)-1&65535;ap=c[2415193]|0;as=a[9660753]|0;at=c[av+(au*3148|0)+48+((ap>>>8&255|256)<<2)>>2]|0;do{if((at|0)==0){ao=c[av+(au*3148|0)+3124>>2]|0;if((ao|0)==0){aw=au;ax=av;break}gg[ao&4095](ap&65535,as);aw=c[3528554]|0;ax=c[2433592]|0}else{a[at+(ap&255)|0]=as;aw=au;ax=av}}while(0);b[4830386]=(b[4830386]|0)-1&65535;as=c[2415193]|0;ap=a[9660768]|0;at=c[ax+(aw*3148|0)+48+((as>>>8&255|256)<<2)>>2]|0;do{if((at|0)==0){ao=c[ax+(aw*3148|0)+3124>>2]|0;if((ao|0)==0){ay=aw;az=ax;break}gg[ao&4095](as&65535,ap);ay=c[3528554]|0;az=c[2433592]|0}else{a[at+(as&255)|0]=ap;ay=aw;az=ax}}while(0);b[4830386]=(b[4830386]|0)-1&65535;ap=c[2415193]|0;as=a[9660769]|0;at=c[az+(ay*3148|0)+48+((ap>>>8&255|256)<<2)>>2]|0;do{if((at|0)==0){ao=c[az+(ay*3148|0)+3124>>2]|0;if((ao|0)==0){aA=ay;aB=az;break}gg[ao&4095](ap&65535,as);aA=c[3528554]|0;aB=c[2433592]|0}else{a[at+(ap&255)|0]=as;aA=ay;aB=az}}while(0);b[4830386]=(b[4830386]|0)-1&65535;as=c[2415193]|0;ap=a[9660780]|0;at=c[aB+(aA*3148|0)+48+((as>>>8&255|256)<<2)>>2]|0;do{if((at|0)==0){ao=c[aB+(aA*3148|0)+3124>>2]|0;if((ao|0)==0){aC=aA;aD=aB;break}gg[ao&4095](as&65535,ap);aC=c[3528554]|0;aD=c[2433592]|0}else{a[at+(as&255)|0]=ap;aC=aA;aD=aB}}while(0);b[4830386]=(b[4830386]|0)-1&65535;ap=c[2415193]|0;as=a[9660781]|0;at=c[aD+(aC*3148|0)+48+((ap>>>8&255|256)<<2)>>2]|0;do{if((at|0)==0){ao=c[aD+(aC*3148|0)+3124>>2]|0;if((ao|0)==0){aE=aC;aF=aD;break}gg[ao&4095](ap&65535,as);aE=c[3528554]|0;aF=c[2433592]|0}else{a[at+(ap&255)|0]=as;aE=aC;aF=aD}}while(0);b[4830386]=(b[4830386]|0)-1&65535;as=c[2415193]|0;ap=a[9660776]|0;at=c[aF+(aE*3148|0)+48+((as>>>8&255|256)<<2)>>2]|0;do{if((at|0)==0){ao=c[aF+(aE*3148|0)+3124>>2]|0;if((ao|0)==0){aG=aE;aH=aF;break}gg[ao&4095](as&65535,ap);aG=c[3528554]|0;aH=c[2433592]|0}else{a[at+(as&255)|0]=ap;aG=aE;aH=aF}}while(0);b[4830386]=(b[4830386]|0)-1&65535;ap=c[2415193]|0;as=a[9660777]|0;at=c[aH+(aG*3148|0)+48+((ap>>>8&255|256)<<2)>>2]|0;do{if((at|0)==0){ao=c[aH+(aG*3148|0)+3124>>2]|0;if((ao|0)==0){aI=aG;aJ=aH;break}gg[ao&4095](ap&65535,as);aI=c[3528554]|0;aJ=c[2433592]|0}else{a[at+(ap&255)|0]=as;aI=aG;aJ=aH}}while(0);b[4830386]=(b[4830386]|0)-1&65535;as=c[2415193]|0;ap=a[9660765]|0;at=c[aJ+(aI*3148|0)+48+((as>>>8&255|256)<<2)>>2]|0;do{if((at|0)==0){ao=c[aJ+(aI*3148|0)+3124>>2]|0;if((ao|0)==0){aK=aI;aL=aJ;break}gg[ao&4095](as&65535,ap);aK=c[3528554]|0;aL=c[2433592]|0}else{a[at+(as&255)|0]=ap;aK=aI;aL=aJ}}while(0);b[4830386]=(b[4830386]|0)-1&65535;ap=c[2415193]|0;as=a[9660760]|0;at=c[aL+(aK*3148|0)+48+((ap>>>8&255|256)<<2)>>2]|0;do{if((at|0)==0){ao=c[aL+(aK*3148|0)+3124>>2]|0;if((ao|0)==0){aM=aK;aN=aL;break}gg[ao&4095](ap&65535,as);aM=c[3528554]|0;aN=c[2433592]|0}else{a[at+(ap&255)|0]=as;aM=aK;aN=aL}}while(0);b[4830386]=(b[4830386]|0)-1&65535;as=c[2415193]|0;ap=a[9660761]|0;at=c[aN+(aM*3148|0)+48+((as>>>8&255|256)<<2)>>2]|0;do{if((at|0)==0){ao=c[aN+(aM*3148|0)+3124>>2]|0;if((ao|0)==0){aO=aM;aP=aN;break}gg[ao&4095](as&65535,ap);aO=c[3528554]|0;aP=c[2433592]|0}else{a[at+(as&255)|0]=ap;aO=aM;aP=aN}}while(0);b[4830386]=(b[4830386]|0)-1&65535;ap=c[2415193]|0;as=a[9660784]|0;at=c[aP+(aO*3148|0)+48+((ap>>>8&255|256)<<2)>>2]|0;do{if((at|0)==0){ao=c[aP+(aO*3148|0)+3124>>2]|0;if((ao|0)==0){break}gg[ao&4095](ap&65535,as)}else{a[at+(ap&255)|0]=as}}while(0);aQ=(c[2415197]|0)+19|0;aR=a[9660784]|0}else{a[9660796]=aq&-9;aQ=(c[2415197]|0)+7|0;aR=ar}c[2415197]=aQ;a[9660784]=aR|16;as=c[3528554]|0;ap=c[2433592]|0;at=c[ap+(as*3148|0)+1068>>2]|0;do{if((at|0)==0){ao=c[ap+(as*3148|0)+3120>>2]|0;if((ao|0)==0){aS=0;aT=0;break}am=gj[ao&4095](-8)|0;ao=c[3528554]|0;an=c[2433592]|0;al=c[an+(ao*3148|0)+1068>>2]|0;if((al|0)!=0){aU=al;aV=(am&255)<<8;i=41698;break}al=c[an+(ao*3148|0)+3120>>2]|0;if((al|0)==0){aS=0;aT=(am&255)<<8;break}aS=gj[al&4095](-7)|0;aT=(am&255)<<8}else{aU=at;aV=(d[at+248|0]|0)<<8;i=41698}}while(0);if((i|0)==41698){i=0;aS=a[aU+249|0]|0;aT=aV}at=aS&255|aT;c[2415188]=at;b[4830376]=at&65535}}while(0);aT=(c[2440592]|0)-6|0;c[2440592]=aT;h=aT;break};case 60:{aT=c[2415188]|0;aS=c[3528554]|0;aV=c[2433592]|0;aU=c[aV+(aS*3148|0)+48+((aT>>>8&255)<<2)>>2]|0;do{if((aU|0)==0){aR=c[aV+(aS*3148|0)+3132>>2]|0;if((aR|0)==0){aW=0;aX=aT&65535;aY=aS;aZ=aV;break}aQ=gj[aR&4095](aT&65535)|0;aW=aQ;aX=b[4830376]|0;aY=c[3528554]|0;aZ=c[2433592]|0}else{aW=a[aU+(aT&255)|0]|0;aX=aT&65535;aY=aS;aZ=aV}}while(0);aV=aX+1&65535;b[4830376]=aV;a[9660784]=a[9660784]&aW|-128;b[4830386]=(b[4830386]|0)-1&65535;aW=c[2415193]|0;aX=c[aZ+(aY*3148|0)+48+((aW>>>8&255|256)<<2)>>2]|0;do{if((aX|0)==0){aS=c[aZ+(aY*3148|0)+3124>>2]|0;if((aS|0)==0){a_=aY;a$=aZ;break}gg[aS&4095](aW&65535,aV&255);a_=c[3528554]|0;a$=c[2433592]|0}else{a[aX+(aW&255)|0]=aV&255;a_=aY;a$=aZ}}while(0);b[4830386]=(b[4830386]|0)-1&65535;aZ=c[2415193]|0;aY=a[9660753]|0;aV=c[a$+(a_*3148|0)+48+((aZ>>>8&255|256)<<2)>>2]|0;do{if((aV|0)==0){aW=c[a$+(a_*3148|0)+3124>>2]|0;if((aW|0)==0){a0=a_;a1=a$;break}gg[aW&4095](aZ&65535,aY);a0=c[3528554]|0;a1=c[2433592]|0}else{a[aV+(aZ&255)|0]=aY;a0=a_;a1=a$}}while(0);b[4830386]=(b[4830386]|0)-1&65535;a$=c[2415193]|0;a_=a[9660768]|0;aY=c[a1+(a0*3148|0)+48+((a$>>>8&255|256)<<2)>>2]|0;do{if((aY|0)==0){aZ=c[a1+(a0*3148|0)+3124>>2]|0;if((aZ|0)==0){a2=a0;a3=a1;break}gg[aZ&4095](a$&65535,a_);a2=c[3528554]|0;a3=c[2433592]|0}else{a[aY+(a$&255)|0]=a_;a2=a0;a3=a1}}while(0);b[4830386]=(b[4830386]|0)-1&65535;a1=c[2415193]|0;a0=a[9660769]|0;a_=c[a3+(a2*3148|0)+48+((a1>>>8&255|256)<<2)>>2]|0;do{if((a_|0)==0){a$=c[a3+(a2*3148|0)+3124>>2]|0;if((a$|0)==0){a4=a2;a5=a3;break}gg[a$&4095](a1&65535,a0);a4=c[3528554]|0;a5=c[2433592]|0}else{a[a_+(a1&255)|0]=a0;a4=a2;a5=a3}}while(0);b[4830386]=(b[4830386]|0)-1&65535;a3=c[2415193]|0;a2=a[9660780]|0;a0=c[a5+(a4*3148|0)+48+((a3>>>8&255|256)<<2)>>2]|0;do{if((a0|0)==0){a1=c[a5+(a4*3148|0)+3124>>2]|0;if((a1|0)==0){a6=a4;a7=a5;break}gg[a1&4095](a3&65535,a2);a6=c[3528554]|0;a7=c[2433592]|0}else{a[a0+(a3&255)|0]=a2;a6=a4;a7=a5}}while(0);b[4830386]=(b[4830386]|0)-1&65535;a5=c[2415193]|0;a4=a[9660781]|0;a2=c[a7+(a6*3148|0)+48+((a5>>>8&255|256)<<2)>>2]|0;do{if((a2|0)==0){a3=c[a7+(a6*3148|0)+3124>>2]|0;if((a3|0)==0){a8=a6;a9=a7;break}gg[a3&4095](a5&65535,a4);a8=c[3528554]|0;a9=c[2433592]|0}else{a[a2+(a5&255)|0]=a4;a8=a6;a9=a7}}while(0);b[4830386]=(b[4830386]|0)-1&65535;a7=c[2415193]|0;a6=a[9660776]|0;a4=c[a9+(a8*3148|0)+48+((a7>>>8&255|256)<<2)>>2]|0;do{if((a4|0)==0){a5=c[a9+(a8*3148|0)+3124>>2]|0;if((a5|0)==0){ba=a8;bb=a9;break}gg[a5&4095](a7&65535,a6);ba=c[3528554]|0;bb=c[2433592]|0}else{a[a4+(a7&255)|0]=a6;ba=a8;bb=a9}}while(0);b[4830386]=(b[4830386]|0)-1&65535;a9=c[2415193]|0;a8=a[9660777]|0;a6=c[bb+(ba*3148|0)+48+((a9>>>8&255|256)<<2)>>2]|0;do{if((a6|0)==0){a7=c[bb+(ba*3148|0)+3124>>2]|0;if((a7|0)==0){bc=ba;bd=bb;break}gg[a7&4095](a9&65535,a8);bc=c[3528554]|0;bd=c[2433592]|0}else{a[a6+(a9&255)|0]=a8;bc=ba;bd=bb}}while(0);b[4830386]=(b[4830386]|0)-1&65535;bb=c[2415193]|0;ba=a[9660765]|0;a8=c[bd+(bc*3148|0)+48+((bb>>>8&255|256)<<2)>>2]|0;do{if((a8|0)==0){a9=c[bd+(bc*3148|0)+3124>>2]|0;if((a9|0)==0){be=bc;bf=bd;break}gg[a9&4095](bb&65535,ba);be=c[3528554]|0;bf=c[2433592]|0}else{a[a8+(bb&255)|0]=ba;be=bc;bf=bd}}while(0);b[4830386]=(b[4830386]|0)-1&65535;bd=c[2415193]|0;bc=a[9660760]|0;ba=c[bf+(be*3148|0)+48+((bd>>>8&255|256)<<2)>>2]|0;do{if((ba|0)==0){bb=c[bf+(be*3148|0)+3124>>2]|0;if((bb|0)==0){bg=be;bh=bf;break}gg[bb&4095](bd&65535,bc);bg=c[3528554]|0;bh=c[2433592]|0}else{a[ba+(bd&255)|0]=bc;bg=be;bh=bf}}while(0);b[4830386]=(b[4830386]|0)-1&65535;bf=c[2415193]|0;be=a[9660761]|0;bc=c[bh+(bg*3148|0)+48+((bf>>>8&255|256)<<2)>>2]|0;do{if((bc|0)==0){bd=c[bh+(bg*3148|0)+3124>>2]|0;if((bd|0)==0){bi=bg;bj=bh;break}gg[bd&4095](bf&65535,be);bi=c[3528554]|0;bj=c[2433592]|0}else{a[bc+(bf&255)|0]=be;bi=bg;bj=bh}}while(0);b[4830386]=(b[4830386]|0)-1&65535;bh=c[2415193]|0;bg=a[9660784]|0;be=c[bj+(bi*3148|0)+48+((bh>>>8&255|256)<<2)>>2]|0;do{if((be|0)==0){bf=c[bj+(bi*3148|0)+3124>>2]|0;if((bf|0)==0){break}gg[bf&4095](bh&65535,bg)}else{a[be+(bh&255)|0]=bg}}while(0);bg=a[9660796]|8;a[9660796]=bg;bh=a[9660786]|0;be=a[9660787]|0;if((be|bh)<<24>>24==0){bk=bg}else{a[9660796]=bg&-17;bk=bg&-17}do{if(be<<24>>24==0){i=41767}else{bg=a[9660784]|0;if((bg&64)!=0){i=41767;break}a[9660796]=bk&-9;c[2415197]=(c[2415197]|0)+7;a[9660784]=bg|80;bg=c[3528554]|0;bi=c[2433592]|0;bj=c[bi+(bg*3148|0)+1068>>2]|0;do{if((bj|0)==0){bf=c[bi+(bg*3148|0)+3120>>2]|0;if((bf|0)==0){bl=0;bm=0;break}bc=gj[bf&4095](-10)|0;bf=c[3528554]|0;bd=c[2433592]|0;ba=c[bd+(bf*3148|0)+1068>>2]|0;if((ba|0)!=0){bn=ba;bo=(bc&255)<<8;i=41763;break}ba=c[bd+(bf*3148|0)+3120>>2]|0;if((ba|0)==0){bl=0;bm=(bc&255)<<8;break}bl=gj[ba&4095](-9)|0;bm=(bc&255)<<8}else{bn=bj;bo=(d[bj+246|0]|0)<<8;i=41763}}while(0);if((i|0)==41763){i=0;bl=a[bn+247|0]|0;bm=bo}bj=bl&255|bm;c[2415188]=bj;b[4830376]=bj&65535}}while(0);do{if((i|0)==41767){i=0;if(bh<<24>>24==0){break}bm=a[9660784]|0;if((bm&16)!=0){break}a[9660796]=bk&-9;c[2415197]=(c[2415197]|0)+7;a[9660784]=bm|16;bm=c[3528554]|0;bl=c[2433592]|0;bo=c[bl+(bm*3148|0)+1068>>2]|0;do{if((bo|0)==0){bn=c[bl+(bm*3148|0)+3120>>2]|0;if((bn|0)==0){bp=0;bq=0;break}be=gj[bn&4095](-8)|0;bn=c[3528554]|0;bj=c[2433592]|0;bg=c[bj+(bn*3148|0)+1068>>2]|0;if((bg|0)!=0){br=bg;bs=(be&255)<<8;i=41773;break}bg=c[bj+(bn*3148|0)+3120>>2]|0;if((bg|0)==0){bp=0;bq=(be&255)<<8;break}bp=gj[bg&4095](-7)|0;bq=(be&255)<<8}else{br=bo;bs=(d[bo+248|0]|0)<<8;i=41773}}while(0);if((i|0)==41773){i=0;bp=a[br+249|0]|0;bq=bs}bo=bp&255|bq;c[2415188]=bo;b[4830376]=bo&65535}}while(0);bq=c[2440592]|0;if((a[9660796]&8)!=0&(bq|0)>0){c[2440592]=0;bt=0}else{bt=bq}bq=bt-20|0;c[2440592]=bq;h=bq;break};case 61:{bq=ag(d[9660760]|0,d[9660761]|0)|0;bt=a[9660784]&-6;a[9660784]=(bq&65535)>>>7&1|(bq<<16>>16==0?bt|4:bt);b[4830380]=bq;bq=(c[2440592]|0)-11|0;c[2440592]=bq;h=bq;break};case 62:{bq=(c[2440592]|0)-2|0;c[2440592]=bq;h=bq;break};case 63:{a[9660784]=a[9660784]|-128;b[4830386]=(b[4830386]|0)-1&65535;bq=c[2415193]|0;bt=c[3528554]|0;bp=c[2433592]|0;bs=c[bp+(bt*3148|0)+48+((bq>>>8&255|256)<<2)>>2]|0;do{if((bs|0)==0){br=c[bp+(bt*3148|0)+3124>>2]|0;if((br|0)==0){bu=bt;bv=bp;break}gg[br&4095](bq&65535,g&255);bu=c[3528554]|0;bv=c[2433592]|0}else{a[bs+(bq&255)|0]=g&255;bu=bt;bv=bp}}while(0);b[4830386]=(b[4830386]|0)-1&65535;bp=c[2415193]|0;bt=a[9660753]|0;g=c[bv+(bu*3148|0)+48+((bp>>>8&255|256)<<2)>>2]|0;do{if((g|0)==0){bq=c[bv+(bu*3148|0)+3124>>2]|0;if((bq|0)==0){bw=bu;bx=bv;break}gg[bq&4095](bp&65535,bt);bw=c[3528554]|0;bx=c[2433592]|0}else{a[g+(bp&255)|0]=bt;bw=bu;bx=bv}}while(0);b[4830386]=(b[4830386]|0)-1&65535;bv=c[2415193]|0;bu=a[9660768]|0;bt=c[bx+(bw*3148|0)+48+((bv>>>8&255|256)<<2)>>2]|0;do{if((bt|0)==0){bp=c[bx+(bw*3148|0)+3124>>2]|0;if((bp|0)==0){by=bw;bz=bx;break}gg[bp&4095](bv&65535,bu);by=c[3528554]|0;bz=c[2433592]|0}else{a[bt+(bv&255)|0]=bu;by=bw;bz=bx}}while(0);b[4830386]=(b[4830386]|0)-1&65535;bx=c[2415193]|0;bw=a[9660769]|0;bu=c[bz+(by*3148|0)+48+((bx>>>8&255|256)<<2)>>2]|0;do{if((bu|0)==0){bv=c[bz+(by*3148|0)+3124>>2]|0;if((bv|0)==0){bA=by;bB=bz;break}gg[bv&4095](bx&65535,bw);bA=c[3528554]|0;bB=c[2433592]|0}else{a[bu+(bx&255)|0]=bw;bA=by;bB=bz}}while(0);b[4830386]=(b[4830386]|0)-1&65535;bz=c[2415193]|0;by=a[9660780]|0;bw=c[bB+(bA*3148|0)+48+((bz>>>8&255|256)<<2)>>2]|0;do{if((bw|0)==0){bx=c[bB+(bA*3148|0)+3124>>2]|0;if((bx|0)==0){bC=bA;bD=bB;break}gg[bx&4095](bz&65535,by);bC=c[3528554]|0;bD=c[2433592]|0}else{a[bw+(bz&255)|0]=by;bC=bA;bD=bB}}while(0);b[4830386]=(b[4830386]|0)-1&65535;bB=c[2415193]|0;bA=a[9660781]|0;by=c[bD+(bC*3148|0)+48+((bB>>>8&255|256)<<2)>>2]|0;do{if((by|0)==0){bz=c[bD+(bC*3148|0)+3124>>2]|0;if((bz|0)==0){bE=bC;bF=bD;break}gg[bz&4095](bB&65535,bA);bE=c[3528554]|0;bF=c[2433592]|0}else{a[by+(bB&255)|0]=bA;bE=bC;bF=bD}}while(0);b[4830386]=(b[4830386]|0)-1&65535;bD=c[2415193]|0;bC=a[9660776]|0;bA=c[bF+(bE*3148|0)+48+((bD>>>8&255|256)<<2)>>2]|0;do{if((bA|0)==0){bB=c[bF+(bE*3148|0)+3124>>2]|0;if((bB|0)==0){bG=bE;bH=bF;break}gg[bB&4095](bD&65535,bC);bG=c[3528554]|0;bH=c[2433592]|0}else{a[bA+(bD&255)|0]=bC;bG=bE;bH=bF}}while(0);b[4830386]=(b[4830386]|0)-1&65535;bF=c[2415193]|0;bE=a[9660777]|0;bC=c[bH+(bG*3148|0)+48+((bF>>>8&255|256)<<2)>>2]|0;do{if((bC|0)==0){bD=c[bH+(bG*3148|0)+3124>>2]|0;if((bD|0)==0){bI=bG;bJ=bH;break}gg[bD&4095](bF&65535,bE);bI=c[3528554]|0;bJ=c[2433592]|0}else{a[bC+(bF&255)|0]=bE;bI=bG;bJ=bH}}while(0);b[4830386]=(b[4830386]|0)-1&65535;bH=c[2415193]|0;bG=a[9660765]|0;bE=c[bJ+(bI*3148|0)+48+((bH>>>8&255|256)<<2)>>2]|0;do{if((bE|0)==0){bF=c[bJ+(bI*3148|0)+3124>>2]|0;if((bF|0)==0){bK=bI;bL=bJ;break}gg[bF&4095](bH&65535,bG);bK=c[3528554]|0;bL=c[2433592]|0}else{a[bE+(bH&255)|0]=bG;bK=bI;bL=bJ}}while(0);b[4830386]=(b[4830386]|0)-1&65535;bJ=c[2415193]|0;bI=a[9660760]|0;bG=c[bL+(bK*3148|0)+48+((bJ>>>8&255|256)<<2)>>2]|0;do{if((bG|0)==0){bH=c[bL+(bK*3148|0)+3124>>2]|0;if((bH|0)==0){bM=bK;bN=bL;break}gg[bH&4095](bJ&65535,bI);bM=c[3528554]|0;bN=c[2433592]|0}else{a[bG+(bJ&255)|0]=bI;bM=bK;bN=bL}}while(0);b[4830386]=(b[4830386]|0)-1&65535;bL=c[2415193]|0;bK=a[9660761]|0;bI=c[bN+(bM*3148|0)+48+((bL>>>8&255|256)<<2)>>2]|0;do{if((bI|0)==0){bJ=c[bN+(bM*3148|0)+3124>>2]|0;if((bJ|0)==0){bO=bM;bP=bN;break}gg[bJ&4095](bL&65535,bK);bO=c[3528554]|0;bP=c[2433592]|0}else{a[bI+(bL&255)|0]=bK;bO=bM;bP=bN}}while(0);b[4830386]=(b[4830386]|0)-1&65535;bN=c[2415193]|0;bM=a[9660784]|0;bK=c[bP+(bO*3148|0)+48+((bN>>>8&255|256)<<2)>>2]|0;do{if((bK|0)==0){bL=c[bP+(bO*3148|0)+3124>>2]|0;if((bL|0)==0){bQ=bO;bR=bP;break}gg[bL&4095](bN&65535,bM);bQ=c[3528554]|0;bR=c[2433592]|0}else{a[bK+(bN&255)|0]=bM;bQ=bO;bR=bP}}while(0);a[9660784]=a[9660784]|80;bP=c[bR+(bQ*3148|0)+1068>>2]|0;do{if((bP|0)==0){bO=c[bR+(bQ*3148|0)+3120>>2]|0;if((bO|0)==0){bS=0;bT=0;break}bM=gj[bO&4095](-6)|0;bO=c[3528554]|0;bN=c[2433592]|0;bK=c[bN+(bO*3148|0)+1068>>2]|0;if((bK|0)!=0){bU=bK;bV=(bM&255)<<8;i=41834;break}bK=c[bN+(bO*3148|0)+3120>>2]|0;if((bK|0)==0){bS=0;bT=(bM&255)<<8;break}bS=gj[bK&4095](-5)|0;bT=(bM&255)<<8}else{bU=bP;bV=(d[bP+250|0]|0)<<8;i=41834}}while(0);if((i|0)==41834){i=0;bS=a[bU+251|0]|0;bT=bV}bV=bS&255|bT;c[2415188]=bV;b[4830376]=bV&65535;bV=(c[2440592]|0)-19|0;c[2440592]=bV;h=bV;break};case 64:{bV=a[9660761]|0;bT=-(bV&255)&65535&65535;bS=(bT>>>4&8|a[9660784]&-16&255)&255;a[9660784]=((bT^bV&255^bT>>>1)>>>6&2|bT>>>8&1|((-(bV&255)&65535&255)<<24>>24==0?bS|4:bS)&255)&255;a[9660761]=-(bV&255)&65535&255;bV=(c[2440592]|0)-2|0;c[2440592]=bV;h=bV;break};case 65:{bV=(c[2440592]|0)-2|0;c[2440592]=bV;h=bV;break};default:{j=1}}}if(j){j=0;switch(k|0){case 66:{bV=(c[2440592]|0)-2|0;c[2440592]=bV;h=bV;break};case 67:{bV=a[9660761]|0;a[9660761]=~bV;bS=(~bV&255)>>>4&8|a[9660784]&-15;a[9660784]=(bV<<24>>24==-1?bS|4:bS)|1;bS=(c[2440592]|0)-2|0;c[2440592]=bS;h=bS;break};case 68:{bS=a[9660761]|0;bV=bS&1|a[9660784]&-14;a[9660784]=bV;a[9660761]=(bS&255)>>>1;if((bS&255)>>>1<<24>>24==0){a[9660784]=bV|4}bV=(c[2440592]|0)-2|0;c[2440592]=bV;h=bV;break};case 69:{bV=(c[2440592]|0)-2|0;c[2440592]=bV;h=bV;break};case 70:{bV=a[9660784]|0;bS=a[9660761]|0;a[9660784]=((bS&255)>>>1|bV<<7)<<24>>24==0?bS&1|bV&-14|bV<<3&8|4:bS&1|bV&-14|bV<<3&8;a[9660761]=(bS&255)>>>1|bV<<7;bV=(c[2440592]|0)-2|0;c[2440592]=bV;h=bV;break};case 71:{bV=a[9660761]|0;bS=bV&1|a[9660784]&-14;a[9660761]=bV&-128|(bV&255)>>>1;a[9660784]=(bV&-128|(bV&255)>>>1)<<24>>24==0?bS|(bV&255)>>>4&8|4:bS|(bV&255)>>>4&8;bV=(c[2440592]|0)-2|0;c[2440592]=bV;h=bV;break};case 72:{bV=(d[9660761]|0)<<1;bS=((bV&65535)>>>4&8|a[9660784]&-16&255)&255;a[9660784]=(((bV&65535)>>>1^bV&65535)>>>6&2|(bV&65535)>>>8|((bV&255)<<24>>24==0?bS|4:bS)&255)&255;a[9660761]=bV&255;bV=(c[2440592]|0)-2|0;c[2440592]=bV;h=bV;break};case 73:{bV=a[9660761]|0;bS=a[9660784]|0;a[9660784]=(((bV&255)<<1^bV&255)>>>6&2|(bV&255)>>>7|(((bS&1|(bV&255)<<1)&255)<<24>>24==0?bS&-16|(bV&255)>>>3&8|4:bS&-16|(bV&255)>>>3&8)&255)&255;a[9660761]=(bS&1|(bV&255)<<1)&255;bV=(c[2440592]|0)-2|0;c[2440592]=bV;h=bV;break};case 74:{bV=(a[9660761]|0)-1&255;a[9660761]=bV;a[9660784]=a[669184+(bV&255)|0]|a[9660784]&-15;bV=(c[2440592]|0)-2|0;c[2440592]=bV;h=bV;break};case 75:{bV=(c[2440592]|0)-2|0;c[2440592]=bV;h=bV;break};case 76:{bV=(a[9660761]|0)+1&255;a[9660761]=bV;a[9660784]=a[668928+(bV&255)|0]|a[9660784]&-15;bV=(c[2440592]|0)-2|0;c[2440592]=bV;h=bV;break};case 77:{bV=a[9660761]|0;bS=(bV&255)>>>4&8|a[9660784]&-15;a[9660784]=bV<<24>>24==0?bS|4:bS;bS=(c[2440592]|0)-2|0;c[2440592]=bS;h=bS;break};case 78:{bS=(c[2440592]|0)-2|0;c[2440592]=bS;h=bS;break};case 79:{a[9660761]=0;a[9660784]=a[9660784]&-16|4;bS=(c[2440592]|0)-2|0;c[2440592]=bS;h=bS;break};case 80:{bS=a[9660760]|0;bV=-(bS&255)&65535&65535;bT=(bV>>>4&8|a[9660784]&-16&255)&255;a[9660784]=((bV^bS&255^bV>>>1)>>>6&2|bV>>>8&1|((-(bS&255)&65535&255)<<24>>24==0?bT|4:bT)&255)&255;a[9660760]=-(bS&255)&65535&255;bS=(c[2440592]|0)-2|0;c[2440592]=bS;h=bS;break};case 81:{bS=(c[2440592]|0)-2|0;c[2440592]=bS;h=bS;break};case 82:{bS=(c[2440592]|0)-2|0;c[2440592]=bS;h=bS;break};case 83:{bS=a[9660760]|0;a[9660760]=~bS;bT=(~bS&255)>>>4&8|a[9660784]&-15;a[9660784]=(bS<<24>>24==-1?bT|4:bT)|1;bT=(c[2440592]|0)-2|0;c[2440592]=bT;h=bT;break};case 84:{bT=a[9660760]|0;bS=bT&1|a[9660784]&-14;a[9660784]=bS;a[9660760]=(bT&255)>>>1;if((bT&255)>>>1<<24>>24==0){a[9660784]=bS|4}bS=(c[2440592]|0)-2|0;c[2440592]=bS;h=bS;break};case 85:{bS=(c[2440592]|0)-2|0;c[2440592]=bS;h=bS;break};case 86:{bS=a[9660784]|0;bT=a[9660760]|0;a[9660784]=((bT&255)>>>1|bS<<7)<<24>>24==0?bT&1|bS&-14|bS<<3&8|4:bT&1|bS&-14|bS<<3&8;a[9660760]=(bT&255)>>>1|bS<<7;bS=(c[2440592]|0)-2|0;c[2440592]=bS;h=bS;break};case 87:{bS=a[9660760]|0;bT=bS&1|a[9660784]&-14;a[9660760]=bS&-128|(bS&255)>>>1;a[9660784]=(bS&-128|(bS&255)>>>1)<<24>>24==0?bT|(bS&255)>>>4&8|4:bT|(bS&255)>>>4&8;bS=(c[2440592]|0)-2|0;c[2440592]=bS;h=bS;break};case 88:{bS=(d[9660760]|0)<<1;bT=((bS&65535)>>>4&8|a[9660784]&-16&255)&255;a[9660784]=(((bS&65535)>>>1^bS&65535)>>>6&2|(bS&65535)>>>8|((bS&255)<<24>>24==0?bT|4:bT)&255)&255;a[9660760]=bS&255;bS=(c[2440592]|0)-2|0;c[2440592]=bS;h=bS;break};case 89:{bS=a[9660784]|0;bT=bS&1|(d[9660760]|0)<<1;a[9660784]=(((bT&65535)>>>1^bT&65535)>>>6&2|(bT&65535)>>>8|((bT&255)<<24>>24==0?((bT&65535)>>>4&8|bS&-16&255)&255|4:((bT&65535)>>>4&8|bS&-16&255)&255)&255)&255;a[9660760]=bT&255;bT=(c[2440592]|0)-2|0;c[2440592]=bT;h=bT;break};case 90:{bT=(a[9660760]|0)-1&255;a[9660760]=bT;a[9660784]=a[669184+(bT&255)|0]|a[9660784]&-15;bT=(c[2440592]|0)-2|0;c[2440592]=bT;h=bT;break};case 91:{bT=(c[2440592]|0)-2|0;c[2440592]=bT;h=bT;break};case 92:{bT=(a[9660760]|0)+1&255;a[9660760]=bT;a[9660784]=a[668928+(bT&255)|0]|a[9660784]&-15;bT=(c[2440592]|0)-2|0;c[2440592]=bT;h=bT;break};case 93:{bT=a[9660760]|0;bS=(bT&255)>>>4&8|a[9660784]&-15;a[9660784]=bT<<24>>24==0?bS|4:bS;bS=(c[2440592]|0)-2|0;c[2440592]=bS;h=bS;break};case 94:{bS=(c[2440592]|0)-2|0;c[2440592]=bS;h=bS;break};case 95:{a[9660760]=0;a[9660784]=a[9660784]&-16|4;bS=(c[2440592]|0)-2|0;c[2440592]=bS;h=bS;break};case 96:{f46();bS=c[2426864]|0;bT=c[3528554]|0;bV=c[2433592]|0;bU=c[bV+(bT*3148|0)+48+((bS>>>8&255)<<2)>>2]|0;do{if((bU|0)==0){bP=c[bV+(bT*3148|0)+3120>>2]|0;if((bP|0)==0){bW=0;bX=bS;bY=bT;bZ=bV;break}bQ=gj[bP&4095](bS&65535)|0;bW=bQ;bX=c[2426864]|0;bY=c[3528554]|0;bZ=c[2433592]|0}else{bW=a[bU+(bS&255)|0]|0;bX=bS;bY=bT;bZ=bV}}while(0);bV=bW&255;bW=(a[9660784]&-16&255|(-bV|0)>>>4&8)&255;a[9660784]=((bV^(-bV|0)^(-bV|0)>>>1)>>>6&2|(-bV|0)>>>8&1|(((-bV|0)&255)<<24>>24==0?bW|4:bW)&255)&255;bW=bX&65535;bT=c[bZ+(bY*3148|0)+48+((bX>>>8&255|256)<<2)>>2]|0;do{if((bT|0)==0){bS=c[bZ+(bY*3148|0)+3124>>2]|0;if((bS|0)==0){break}gg[bS&4095](bW,(-bV|0)&255)}else{a[bT+(bX&255)|0]=(-bV|0)&255}}while(0);bV=(c[2440592]|0)-6|0;c[2440592]=bV;h=bV;break};case 97:{bV=(c[2440592]|0)-2|0;c[2440592]=bV;h=bV;break};case 98:{bV=(c[2440592]|0)-2|0;c[2440592]=bV;h=bV;break};case 99:{f46();bV=c[2426864]|0;bX=c[3528554]|0;bT=c[2433592]|0;bW=c[bT+(bX*3148|0)+48+((bV>>>8&255)<<2)>>2]|0;do{if((bW|0)==0){bY=c[bT+(bX*3148|0)+3120>>2]|0;if((bY|0)==0){b_=0;b$=bV;b0=bX;b1=bT;break}bZ=gj[bY&4095](bV&65535)|0;b_=bZ;b$=c[2426864]|0;b0=c[3528554]|0;b1=c[2433592]|0}else{b_=a[bW+(bV&255)|0]|0;b$=bV;b0=bX;b1=bT}}while(0);bT=~b_;bX=a[9660784]&-15|(bT&255)>>>4&8;a[9660784]=(b_<<24>>24==-1?bX|4:bX)|1;bX=b$&65535;b_=c[b1+(b0*3148|0)+48+((b$>>>8&255|256)<<2)>>2]|0;do{if((b_|0)==0){bV=c[b1+(b0*3148|0)+3124>>2]|0;if((bV|0)==0){break}gg[bV&4095](bX,bT)}else{a[b_+(b$&255)|0]=bT}}while(0);bT=(c[2440592]|0)-6|0;c[2440592]=bT;h=bT;break};case 100:{f46();bT=c[2426864]|0;b$=c[3528554]|0;b_=c[2433592]|0;bX=c[b_+(b$*3148|0)+48+((bT>>>8&255)<<2)>>2]|0;do{if((bX|0)==0){b0=c[b_+(b$*3148|0)+3120>>2]|0;if((b0|0)==0){b2=0;b3=bT;b4=b$;b5=b_;break}b1=gj[b0&4095](bT&65535)|0;b2=b1;b3=c[2426864]|0;b4=c[3528554]|0;b5=c[2433592]|0}else{b2=a[bX+(bT&255)|0]|0;b3=bT;b4=b$;b5=b_}}while(0);b_=a[9660784]&-14|b2&1;b$=(b2&255)>>>1;a[9660784]=b$<<24>>24==0?b_|4:b_;b_=b3&65535;b2=c[b5+(b4*3148|0)+48+((b3>>>8&255|256)<<2)>>2]|0;do{if((b2|0)==0){bT=c[b5+(b4*3148|0)+3124>>2]|0;if((bT|0)==0){break}gg[bT&4095](b_,b$)}else{a[b2+(b3&255)|0]=b$}}while(0);b$=(c[2440592]|0)-6|0;c[2440592]=b$;h=b$;break};case 101:{b$=(c[2440592]|0)-2|0;c[2440592]=b$;h=b$;break};case 102:{f46();b$=c[2426864]|0;b3=c[3528554]|0;b2=c[2433592]|0;b_=c[b2+(b3*3148|0)+48+((b$>>>8&255)<<2)>>2]|0;do{if((b_|0)==0){b4=c[b2+(b3*3148|0)+3120>>2]|0;if((b4|0)==0){b6=0;b7=b$;b8=b3;b9=b2;break}b5=gj[b4&4095](b$&65535)|0;b6=b5;b7=c[2426864]|0;b8=c[3528554]|0;b9=c[2433592]|0}else{b6=a[b_+(b$&255)|0]|0;b7=b$;b8=b3;b9=b2}}while(0);b2=a[9660784]|0;b3=b2<<7|(b6&255)>>>1;b$=b2&-14|b6&1|b2<<3&8;a[9660784]=b3<<24>>24==0?b$|4:b$;b$=b7&65535;b2=c[b9+(b8*3148|0)+48+((b7>>>8&255|256)<<2)>>2]|0;do{if((b2|0)==0){b6=c[b9+(b8*3148|0)+3124>>2]|0;if((b6|0)==0){break}gg[b6&4095](b$,b3)}else{a[b2+(b7&255)|0]=b3}}while(0);b3=(c[2440592]|0)-6|0;c[2440592]=b3;h=b3;break};case 103:{f46();b3=c[2426864]|0;b7=c[3528554]|0;b2=c[2433592]|0;b$=c[b2+(b7*3148|0)+48+((b3>>>8&255)<<2)>>2]|0;do{if((b$|0)==0){b8=c[b2+(b7*3148|0)+3120>>2]|0;if((b8|0)==0){ca=0;cb=b3;cc=b7;cd=b2;break}b9=gj[b8&4095](b3&65535)|0;ca=b9;cb=c[2426864]|0;cc=c[3528554]|0;cd=c[2433592]|0}else{ca=a[b$+(b3&255)|0]|0;cb=b3;cc=b7;cd=b2}}while(0);b2=ca&-128|(ca&255)>>>1;b7=a[9660784]&-14|ca&1|(ca&255)>>>4&8;a[9660784]=b2<<24>>24==0?b7|4:b7;b7=cb&65535;ca=c[cd+(cc*3148|0)+48+((cb>>>8&255|256)<<2)>>2]|0;do{if((ca|0)==0){b3=c[cd+(cc*3148|0)+3124>>2]|0;if((b3|0)==0){break}gg[b3&4095](b7,b2)}else{a[ca+(cb&255)|0]=b2}}while(0);b2=(c[2440592]|0)-6|0;c[2440592]=b2;h=b2;break};case 104:{f46();b2=c[2426864]|0;cb=c[3528554]|0;ca=c[2433592]|0;b7=c[ca+(cb*3148|0)+48+((b2>>>8&255)<<2)>>2]|0;do{if((b7|0)==0){cc=c[ca+(cb*3148|0)+3120>>2]|0;if((cc|0)==0){ce=0;cf=b2;cg=cb;ch=ca;break}cd=gj[cc&4095](b2&65535)|0;ce=cd;cf=c[2426864]|0;cg=c[3528554]|0;ch=c[2433592]|0}else{ce=a[b7+(b2&255)|0]|0;cf=b2;cg=cb;ch=ca}}while(0);ca=(ce&255)<<1;ce=((ca&65535)>>>4&8|a[9660784]&-16&255)&255;a[9660784]=(((ca&65535)>>>1^ca&65535)>>>6&2|(ca&65535)>>>8|((ca&255)<<24>>24==0?ce|4:ce)&255)&255;ce=cf&65535;cb=c[ch+(cg*3148|0)+48+((cf>>>8&255|256)<<2)>>2]|0;do{if((cb|0)==0){b2=c[ch+(cg*3148|0)+3124>>2]|0;if((b2|0)==0){break}gg[b2&4095](ce,ca&255)}else{a[cb+(cf&255)|0]=ca&255}}while(0);ca=(c[2440592]|0)-6|0;c[2440592]=ca;h=ca;break};case 105:{f46();ca=c[2426864]|0;cf=c[3528554]|0;cb=c[2433592]|0;ce=c[cb+(cf*3148|0)+48+((ca>>>8&255)<<2)>>2]|0;do{if((ce|0)==0){cg=c[cb+(cf*3148|0)+3120>>2]|0;if((cg|0)==0){ci=0;cj=ca;ck=cf;cl=cb;break}ch=gj[cg&4095](ca&65535)|0;ci=ch;cj=c[2426864]|0;ck=c[3528554]|0;cl=c[2433592]|0}else{ci=a[ce+(ca&255)|0]|0;cj=ca;ck=cf;cl=cb}}while(0);cb=a[9660784]|0;cf=cb&1|(ci&255)<<1;a[9660784]=(((cf&65535)>>>1^cf&65535)>>>6&2|(cf&65535)>>>8|((cf&255)<<24>>24==0?((cf&65535)>>>4&8|cb&-16&255)&255|4:((cf&65535)>>>4&8|cb&-16&255)&255)&255)&255;cb=cj&65535;ci=c[cl+(ck*3148|0)+48+((cj>>>8&255|256)<<2)>>2]|0;do{if((ci|0)==0){ca=c[cl+(ck*3148|0)+3124>>2]|0;if((ca|0)==0){break}gg[ca&4095](cb,cf&255)}else{a[ci+(cj&255)|0]=cf&255}}while(0);cf=(c[2440592]|0)-6|0;c[2440592]=cf;h=cf;break};case 106:{f46();cf=c[2426864]|0;cj=c[3528554]|0;ci=c[2433592]|0;cb=c[ci+(cj*3148|0)+48+((cf>>>8&255)<<2)>>2]|0;do{if((cb|0)==0){ck=c[ci+(cj*3148|0)+3120>>2]|0;if((ck|0)==0){cm=0;cn=cf;co=cj;cp=ci;break}cl=gj[ck&4095](cf&65535)|0;cm=cl;cn=c[2426864]|0;co=c[3528554]|0;cp=c[2433592]|0}else{cm=a[cb+(cf&255)|0]|0;cn=cf;co=cj;cp=ci}}while(0);ci=cm-1&255;a[9660784]=a[9660784]&-15|a[669184+(ci&255)|0];cm=cn&65535;cj=c[cp+(co*3148|0)+48+((cn>>>8&255|256)<<2)>>2]|0;do{if((cj|0)==0){cf=c[cp+(co*3148|0)+3124>>2]|0;if((cf|0)==0){break}gg[cf&4095](cm,ci)}else{a[cj+(cn&255)|0]=ci}}while(0);ci=(c[2440592]|0)-6|0;c[2440592]=ci;h=ci;break};case 107:{ci=(c[2440592]|0)-2|0;c[2440592]=ci;h=ci;break};case 108:{f46();ci=c[2426864]|0;cn=c[3528554]|0;cj=c[2433592]|0;cm=c[cj+(cn*3148|0)+48+((ci>>>8&255)<<2)>>2]|0;do{if((cm|0)==0){co=c[cj+(cn*3148|0)+3120>>2]|0;if((co|0)==0){cq=0;cr=ci;cs=cn;ct=cj;break}cp=gj[co&4095](ci&65535)|0;cq=cp;cr=c[2426864]|0;cs=c[3528554]|0;ct=c[2433592]|0}else{cq=a[cm+(ci&255)|0]|0;cr=ci;cs=cn;ct=cj}}while(0);cj=cq+1&255;a[9660784]=a[9660784]&-15|a[668928+(cj&255)|0];cq=cr&65535;cn=c[ct+(cs*3148|0)+48+((cr>>>8&255|256)<<2)>>2]|0;do{if((cn|0)==0){ci=c[ct+(cs*3148|0)+3124>>2]|0;if((ci|0)==0){break}gg[ci&4095](cq,cj)}else{a[cn+(cr&255)|0]=cj}}while(0);cj=(c[2440592]|0)-6|0;c[2440592]=cj;h=cj;break};case 109:{f46();cj=c[2426864]|0;cr=c[3528554]|0;cn=c[2433592]|0;cq=c[cn+(cr*3148|0)+48+((cj>>>8&255)<<2)>>2]|0;do{if((cq|0)==0){cs=c[cn+(cr*3148|0)+3120>>2]|0;if((cs|0)==0){cu=0;break}cu=gj[cs&4095](cj&65535)|0}else{cu=a[cq+(cj&255)|0]|0}}while(0);cj=a[9660784]&-15|(cu&255)>>>4&8;a[9660784]=cu<<24>>24==0?cj|4:cj;cj=(c[2440592]|0)-6|0;c[2440592]=cj;h=cj;break};case 110:{f46();cj=c[2426864]|0;c[2415188]=cj;b[4830376]=cj&65535;cj=(c[2440592]|0)-3|0;c[2440592]=cj;h=cj;break};case 111:{f46();cj=c[2426864]|0;cu=c[3528554]|0;cq=c[2433592]|0;do{if((c[cq+(cu*3148|0)+48+((cj>>>8&255)<<2)>>2]|0)==0){cr=c[cq+(cu*3148|0)+3120>>2]|0;if((cr|0)==0){cv=cj;cw=cu;cx=cq;break}gj[cr&4095](cj&65535)|0;cv=c[2426864]|0;cw=c[3528554]|0;cx=c[2433592]|0}else{cv=cj;cw=cu;cx=cq}}while(0);cq=cv&65535;cu=c[cx+(cw*3148|0)+48+((cv>>>8&255|256)<<2)>>2]|0;do{if((cu|0)==0){cj=c[cx+(cw*3148|0)+3124>>2]|0;if((cj|0)==0){break}gg[cj&4095](cq,0)}else{a[cu+(cv&255)|0]=0}}while(0);a[9660784]=a[9660784]&-16|4;cv=(c[2440592]|0)-6|0;c[2440592]=cv;h=cv;break};case 112:{cv=c[2415188]|0;cu=c[3528554]|0;cq=c[2433592]|0;cw=c[cq+(cu*3148|0)+48+((cv>>>8&255)<<2)>>2]|0;do{if((cw|0)==0){cx=c[cq+(cu*3148|0)+3132>>2]|0;if((cx|0)==0){cy=0;cz=cv;cA=cu;cB=cq;cC=cv&65535;break}cj=gj[cx&4095](cv&65535)|0;cx=c[2415188]|0;cy=cj;cz=cx;cA=c[3528554]|0;cB=c[2433592]|0;cC=cx&65535}else{cy=a[cw+(cv&255)|0]|0;cz=cv;cA=cu;cB=cq;cC=cv&65535}}while(0);cv=cy&255;cy=cz+1|0;cz=c[cB+(cA*3148|0)+48+((cy>>>8&255)<<2)>>2]|0;do{if((cz|0)==0){cq=c[cB+(cA*3148|0)+3132>>2]|0;if((cq|0)==0){cD=0;cE=cC;cF=cA;cG=cB;break}cu=gj[cq&4095](cy&65535)|0;cD=cu;cE=b[4830376]|0;cF=c[3528554]|0;cG=c[2433592]|0}else{cD=a[cz+(cy&255)|0]|0;cE=cC;cF=cA;cG=cB}}while(0);cB=cD&255;c[2426864]=cB|cv<<8;b[4830376]=cE+2&65535;cE=c[cG+(cF*3148|0)+48+(cv<<2)>>2]|0;do{if((cE|0)==0){cD=c[cG+(cF*3148|0)+3120>>2]|0;if((cD|0)==0){cH=0;cI=cB|cv<<8;cJ=cF;cK=cG;break}cA=gj[cD&4095]((cB|cv<<8)&65535)|0;cH=cA;cI=c[2426864]|0;cJ=c[3528554]|0;cK=c[2433592]|0}else{cH=a[cE+cB|0]|0;cI=cB|cv<<8;cJ=cF;cK=cG}}while(0);cG=cH&255;cH=(a[9660784]&-16&255|(-cG|0)>>>4&8)&255;a[9660784]=((cG^(-cG|0)^(-cG|0)>>>1)>>>6&2|(-cG|0)>>>8&1|(((-cG|0)&255)<<24>>24==0?cH|4:cH)&255)&255;cH=cI&65535;cF=c[cK+(cJ*3148|0)+48+((cI>>>8&255|256)<<2)>>2]|0;do{if((cF|0)==0){cv=c[cK+(cJ*3148|0)+3124>>2]|0;if((cv|0)==0){break}gg[cv&4095](cH,(-cG|0)&255)}else{a[cF+(cI&255)|0]=(-cG|0)&255}}while(0);cG=(c[2440592]|0)-7|0;c[2440592]=cG;h=cG;break};case 113:{cG=(c[2440592]|0)-2|0;c[2440592]=cG;h=cG;break};case 114:{cG=(c[2440592]|0)-2|0;c[2440592]=cG;h=cG;break};case 115:{cG=c[2415188]|0;cI=c[3528554]|0;cF=c[2433592]|0;cH=c[cF+(cI*3148|0)+48+((cG>>>8&255)<<2)>>2]|0;do{if((cH|0)==0){cJ=c[cF+(cI*3148|0)+3132>>2]|0;if((cJ|0)==0){cL=0;cM=cG;cN=cI;cO=cF;cP=cG&65535;break}cK=gj[cJ&4095](cG&65535)|0;cJ=c[2415188]|0;cL=cK;cM=cJ;cN=c[3528554]|0;cO=c[2433592]|0;cP=cJ&65535}else{cL=a[cH+(cG&255)|0]|0;cM=cG;cN=cI;cO=cF;cP=cG&65535}}while(0);cG=cL&255;cL=cM+1|0;cM=c[cO+(cN*3148|0)+48+((cL>>>8&255)<<2)>>2]|0;do{if((cM|0)==0){cF=c[cO+(cN*3148|0)+3132>>2]|0;if((cF|0)==0){cQ=0;cR=cP;cS=cN;cT=cO;break}cI=gj[cF&4095](cL&65535)|0;cQ=cI;cR=b[4830376]|0;cS=c[3528554]|0;cT=c[2433592]|0}else{cQ=a[cM+(cL&255)|0]|0;cR=cP;cS=cN;cT=cO}}while(0);cO=cQ&255;c[2426864]=cO|cG<<8;b[4830376]=cR+2&65535;cR=c[cT+(cS*3148|0)+48+(cG<<2)>>2]|0;do{if((cR|0)==0){cQ=c[cT+(cS*3148|0)+3120>>2]|0;if((cQ|0)==0){cU=0;cV=cO|cG<<8;cW=cS;cX=cT;break}cN=gj[cQ&4095]((cO|cG<<8)&65535)|0;cU=cN;cV=c[2426864]|0;cW=c[3528554]|0;cX=c[2433592]|0}else{cU=a[cR+cO|0]|0;cV=cO|cG<<8;cW=cS;cX=cT}}while(0);cT=~cU;cS=a[9660784]&-15|(cT&255)>>>4&8;a[9660784]=(cU<<24>>24==-1?cS|4:cS)|1;cS=cV&65535;cU=c[cX+(cW*3148|0)+48+((cV>>>8&255|256)<<2)>>2]|0;do{if((cU|0)==0){cG=c[cX+(cW*3148|0)+3124>>2]|0;if((cG|0)==0){break}gg[cG&4095](cS,cT)}else{a[cU+(cV&255)|0]=cT}}while(0);cT=(c[2440592]|0)-7|0;c[2440592]=cT;h=cT;break};case 116:{cT=c[2415188]|0;cV=c[3528554]|0;cU=c[2433592]|0;cS=c[cU+(cV*3148|0)+48+((cT>>>8&255)<<2)>>2]|0;do{if((cS|0)==0){cW=c[cU+(cV*3148|0)+3132>>2]|0;if((cW|0)==0){cY=0;cZ=cT;c_=cV;c$=cU;c0=cT&65535;break}cX=gj[cW&4095](cT&65535)|0;cW=c[2415188]|0;cY=cX;cZ=cW;c_=c[3528554]|0;c$=c[2433592]|0;c0=cW&65535}else{cY=a[cS+(cT&255)|0]|0;cZ=cT;c_=cV;c$=cU;c0=cT&65535}}while(0);cT=cY&255;cY=cZ+1|0;cZ=c[c$+(c_*3148|0)+48+((cY>>>8&255)<<2)>>2]|0;do{if((cZ|0)==0){cU=c[c$+(c_*3148|0)+3132>>2]|0;if((cU|0)==0){c1=0;c2=c0;c3=c_;c4=c$;break}cV=gj[cU&4095](cY&65535)|0;c1=cV;c2=b[4830376]|0;c3=c[3528554]|0;c4=c[2433592]|0}else{c1=a[cZ+(cY&255)|0]|0;c2=c0;c3=c_;c4=c$}}while(0);c$=c1&255;c[2426864]=c$|cT<<8;b[4830376]=c2+2&65535;c2=c[c4+(c3*3148|0)+48+(cT<<2)>>2]|0;do{if((c2|0)==0){c1=c[c4+(c3*3148|0)+3120>>2]|0;if((c1|0)==0){c5=0;c6=c$|cT<<8;c7=c3;c8=c4;break}c_=gj[c1&4095]((c$|cT<<8)&65535)|0;c5=c_;c6=c[2426864]|0;c7=c[3528554]|0;c8=c[2433592]|0}else{c5=a[c2+c$|0]|0;c6=c$|cT<<8;c7=c3;c8=c4}}while(0);c4=a[9660784]&-14|c5&1;c3=(c5&255)>>>1;a[9660784]=c3<<24>>24==0?c4|4:c4;c4=c6&65535;c5=c[c8+(c7*3148|0)+48+((c6>>>8&255|256)<<2)>>2]|0;do{if((c5|0)==0){cT=c[c8+(c7*3148|0)+3124>>2]|0;if((cT|0)==0){break}gg[cT&4095](c4,c3)}else{a[c5+(c6&255)|0]=c3}}while(0);c3=(c[2440592]|0)-7|0;c[2440592]=c3;h=c3;break};case 117:{c3=(c[2440592]|0)-2|0;c[2440592]=c3;h=c3;break};case 118:{c3=c[2415188]|0;c6=c[3528554]|0;c5=c[2433592]|0;c4=c[c5+(c6*3148|0)+48+((c3>>>8&255)<<2)>>2]|0;do{if((c4|0)==0){c7=c[c5+(c6*3148|0)+3132>>2]|0;if((c7|0)==0){c9=0;da=c3;db=c6;dc=c5;dd=c3&65535;break}c8=gj[c7&4095](c3&65535)|0;c7=c[2415188]|0;c9=c8;da=c7;db=c[3528554]|0;dc=c[2433592]|0;dd=c7&65535}else{c9=a[c4+(c3&255)|0]|0;da=c3;db=c6;dc=c5;dd=c3&65535}}while(0);c3=c9&255;c9=da+1|0;da=c[dc+(db*3148|0)+48+((c9>>>8&255)<<2)>>2]|0;do{if((da|0)==0){c5=c[dc+(db*3148|0)+3132>>2]|0;if((c5|0)==0){de=0;df=dd;dg=db;dh=dc;break}c6=gj[c5&4095](c9&65535)|0;de=c6;df=b[4830376]|0;dg=c[3528554]|0;dh=c[2433592]|0}else{de=a[da+(c9&255)|0]|0;df=dd;dg=db;dh=dc}}while(0);dc=de&255;c[2426864]=dc|c3<<8;b[4830376]=df+2&65535;df=c[dh+(dg*3148|0)+48+(c3<<2)>>2]|0;do{if((df|0)==0){de=c[dh+(dg*3148|0)+3120>>2]|0;if((de|0)==0){di=0;dj=dc|c3<<8;dk=dg;dl=dh;break}db=gj[de&4095]((dc|c3<<8)&65535)|0;di=db;dj=c[2426864]|0;dk=c[3528554]|0;dl=c[2433592]|0}else{di=a[df+dc|0]|0;dj=dc|c3<<8;dk=dg;dl=dh}}while(0);dh=a[9660784]|0;dg=dh<<7|(di&255)>>>1;c3=dh&-14|di&1|dh<<3&8;a[9660784]=dg<<24>>24==0?c3|4:c3;c3=dj&65535;dh=c[dl+(dk*3148|0)+48+((dj>>>8&255|256)<<2)>>2]|0;do{if((dh|0)==0){di=c[dl+(dk*3148|0)+3124>>2]|0;if((di|0)==0){break}gg[di&4095](c3,dg)}else{a[dh+(dj&255)|0]=dg}}while(0);dg=(c[2440592]|0)-7|0;c[2440592]=dg;h=dg;break};case 119:{dg=c[2415188]|0;dj=c[3528554]|0;dh=c[2433592]|0;c3=c[dh+(dj*3148|0)+48+((dg>>>8&255)<<2)>>2]|0;do{if((c3|0)==0){dk=c[dh+(dj*3148|0)+3132>>2]|0;if((dk|0)==0){dm=0;dn=dg;dp=dj;dq=dh;dr=dg&65535;break}dl=gj[dk&4095](dg&65535)|0;dk=c[2415188]|0;dm=dl;dn=dk;dp=c[3528554]|0;dq=c[2433592]|0;dr=dk&65535}else{dm=a[c3+(dg&255)|0]|0;dn=dg;dp=dj;dq=dh;dr=dg&65535}}while(0);dg=dm&255;dm=dn+1|0;dn=c[dq+(dp*3148|0)+48+((dm>>>8&255)<<2)>>2]|0;do{if((dn|0)==0){dh=c[dq+(dp*3148|0)+3132>>2]|0;if((dh|0)==0){ds=0;dt=dr;du=dp;dv=dq;break}dj=gj[dh&4095](dm&65535)|0;ds=dj;dt=b[4830376]|0;du=c[3528554]|0;dv=c[2433592]|0}else{ds=a[dn+(dm&255)|0]|0;dt=dr;du=dp;dv=dq}}while(0);dq=ds&255;c[2426864]=dq|dg<<8;b[4830376]=dt+2&65535;dt=c[dv+(du*3148|0)+48+(dg<<2)>>2]|0;do{if((dt|0)==0){ds=c[dv+(du*3148|0)+3120>>2]|0;if((ds|0)==0){dw=0;dx=dq|dg<<8;dy=du;dz=dv;break}dp=gj[ds&4095]((dq|dg<<8)&65535)|0;dw=dp;dx=c[2426864]|0;dy=c[3528554]|0;dz=c[2433592]|0}else{dw=a[dt+dq|0]|0;dx=dq|dg<<8;dy=du;dz=dv}}while(0);dv=dw&-128|(dw&255)>>>1;du=a[9660784]&-14|dw&1|(dw&255)>>>4&8;a[9660784]=dv<<24>>24==0?du|4:du;du=dx&65535;dw=c[dz+(dy*3148|0)+48+((dx>>>8&255|256)<<2)>>2]|0;do{if((dw|0)==0){dg=c[dz+(dy*3148|0)+3124>>2]|0;if((dg|0)==0){break}gg[dg&4095](du,dv)}else{a[dw+(dx&255)|0]=dv}}while(0);dv=(c[2440592]|0)-7|0;c[2440592]=dv;h=dv;break};case 120:{dv=c[2415188]|0;dx=c[3528554]|0;dw=c[2433592]|0;du=c[dw+(dx*3148|0)+48+((dv>>>8&255)<<2)>>2]|0;do{if((du|0)==0){dy=c[dw+(dx*3148|0)+3132>>2]|0;if((dy|0)==0){dA=0;dB=dv;dC=dx;dD=dw;dE=dv&65535;break}dz=gj[dy&4095](dv&65535)|0;dy=c[2415188]|0;dA=dz;dB=dy;dC=c[3528554]|0;dD=c[2433592]|0;dE=dy&65535}else{dA=a[du+(dv&255)|0]|0;dB=dv;dC=dx;dD=dw;dE=dv&65535}}while(0);dv=dA&255;dA=dB+1|0;dB=c[dD+(dC*3148|0)+48+((dA>>>8&255)<<2)>>2]|0;do{if((dB|0)==0){dw=c[dD+(dC*3148|0)+3132>>2]|0;if((dw|0)==0){dF=0;dG=dE;dH=dC;dI=dD;break}dx=gj[dw&4095](dA&65535)|0;dF=dx;dG=b[4830376]|0;dH=c[3528554]|0;dI=c[2433592]|0}else{dF=a[dB+(dA&255)|0]|0;dG=dE;dH=dC;dI=dD}}while(0);dD=dF&255;c[2426864]=dD|dv<<8;b[4830376]=dG+2&65535;dG=c[dI+(dH*3148|0)+48+(dv<<2)>>2]|0;do{if((dG|0)==0){dF=c[dI+(dH*3148|0)+3120>>2]|0;if((dF|0)==0){dJ=0;dK=dD|dv<<8;dL=dH;dM=dI;break}dC=gj[dF&4095]((dD|dv<<8)&65535)|0;dJ=dC;dK=c[2426864]|0;dL=c[3528554]|0;dM=c[2433592]|0}else{dJ=a[dG+dD|0]|0;dK=dD|dv<<8;dL=dH;dM=dI}}while(0);dI=(dJ&255)<<1;dJ=((dI&65535)>>>4&8|a[9660784]&-16&255)&255;a[9660784]=(((dI&65535)>>>1^dI&65535)>>>6&2|(dI&65535)>>>8|((dI&255)<<24>>24==0?dJ|4:dJ)&255)&255;dJ=dK&65535;dH=c[dM+(dL*3148|0)+48+((dK>>>8&255|256)<<2)>>2]|0;do{if((dH|0)==0){dv=c[dM+(dL*3148|0)+3124>>2]|0;if((dv|0)==0){break}gg[dv&4095](dJ,dI&255)}else{a[dH+(dK&255)|0]=dI&255}}while(0);dI=(c[2440592]|0)-7|0;c[2440592]=dI;h=dI;break};default:{j=1}}}if(j){j=0;switch(k|0){case 121:{dI=c[2415188]|0;dK=c[3528554]|0;dH=c[2433592]|0;dJ=c[dH+(dK*3148|0)+48+((dI>>>8&255)<<2)>>2]|0;do{if((dJ|0)==0){dL=c[dH+(dK*3148|0)+3132>>2]|0;if((dL|0)==0){dN=0;dO=dI;dP=dK;dQ=dH;dR=dI&65535;break}dM=gj[dL&4095](dI&65535)|0;dL=c[2415188]|0;dN=dM;dO=dL;dP=c[3528554]|0;dQ=c[2433592]|0;dR=dL&65535}else{dN=a[dJ+(dI&255)|0]|0;dO=dI;dP=dK;dQ=dH;dR=dI&65535}}while(0);dI=dN&255;dN=dO+1|0;dO=c[dQ+(dP*3148|0)+48+((dN>>>8&255)<<2)>>2]|0;do{if((dO|0)==0){dH=c[dQ+(dP*3148|0)+3132>>2]|0;if((dH|0)==0){dS=0;dT=dR;dU=dP;dV=dQ;break}dK=gj[dH&4095](dN&65535)|0;dS=dK;dT=b[4830376]|0;dU=c[3528554]|0;dV=c[2433592]|0}else{dS=a[dO+(dN&255)|0]|0;dT=dR;dU=dP;dV=dQ}}while(0);dQ=dS&255;c[2426864]=dQ|dI<<8;b[4830376]=dT+2&65535;dT=c[dV+(dU*3148|0)+48+(dI<<2)>>2]|0;do{if((dT|0)==0){dS=c[dV+(dU*3148|0)+3120>>2]|0;if((dS|0)==0){dW=0;dX=dQ|dI<<8;dY=dU;dZ=dV;break}dP=gj[dS&4095]((dQ|dI<<8)&65535)|0;dW=dP;dX=c[2426864]|0;dY=c[3528554]|0;dZ=c[2433592]|0}else{dW=a[dT+dQ|0]|0;dX=dQ|dI<<8;dY=dU;dZ=dV}}while(0);dV=a[9660784]|0;dU=dW&255;dI=dV&-16|(dW&255)>>>3&8;a[9660784]=((dU<<1^dU)>>>6&2|dU>>>7|(((dV&1|dU<<1)&255)<<24>>24==0?dI|4:dI)&255)&255;dI=dX&65535;dW=c[dZ+(dY*3148|0)+48+((dX>>>8&255|256)<<2)>>2]|0;do{if((dW|0)==0){dQ=c[dZ+(dY*3148|0)+3124>>2]|0;if((dQ|0)==0){break}gg[dQ&4095](dI,(dV&1|dU<<1)&255)}else{a[dW+(dX&255)|0]=(dV&1|dU<<1)&255}}while(0);dU=(c[2440592]|0)-7|0;c[2440592]=dU;h=dU;break};case 122:{dU=c[2415188]|0;dV=c[3528554]|0;dX=c[2433592]|0;dW=c[dX+(dV*3148|0)+48+((dU>>>8&255)<<2)>>2]|0;do{if((dW|0)==0){dI=c[dX+(dV*3148|0)+3132>>2]|0;if((dI|0)==0){d_=0;d$=dU;d0=dV;d1=dX;d2=dU&65535;break}dY=gj[dI&4095](dU&65535)|0;dI=c[2415188]|0;d_=dY;d$=dI;d0=c[3528554]|0;d1=c[2433592]|0;d2=dI&65535}else{d_=a[dW+(dU&255)|0]|0;d$=dU;d0=dV;d1=dX;d2=dU&65535}}while(0);dU=d_&255;d_=d$+1|0;d$=c[d1+(d0*3148|0)+48+((d_>>>8&255)<<2)>>2]|0;do{if((d$|0)==0){dX=c[d1+(d0*3148|0)+3132>>2]|0;if((dX|0)==0){d3=0;d4=d2;d5=d0;d6=d1;break}dV=gj[dX&4095](d_&65535)|0;d3=dV;d4=b[4830376]|0;d5=c[3528554]|0;d6=c[2433592]|0}else{d3=a[d$+(d_&255)|0]|0;d4=d2;d5=d0;d6=d1}}while(0);d1=d3&255;c[2426864]=d1|dU<<8;b[4830376]=d4+2&65535;d4=c[d6+(d5*3148|0)+48+(dU<<2)>>2]|0;do{if((d4|0)==0){d3=c[d6+(d5*3148|0)+3120>>2]|0;if((d3|0)==0){d7=0;d8=d1|dU<<8;d9=d5;ea=d6;break}d0=gj[d3&4095]((d1|dU<<8)&65535)|0;d7=d0;d8=c[2426864]|0;d9=c[3528554]|0;ea=c[2433592]|0}else{d7=a[d4+d1|0]|0;d8=d1|dU<<8;d9=d5;ea=d6}}while(0);d6=d7-1&255;a[9660784]=a[9660784]&-15|a[669184+(d6&255)|0];d7=d8&65535;d5=c[ea+(d9*3148|0)+48+((d8>>>8&255|256)<<2)>>2]|0;do{if((d5|0)==0){dU=c[ea+(d9*3148|0)+3124>>2]|0;if((dU|0)==0){break}gg[dU&4095](d7,d6)}else{a[d5+(d8&255)|0]=d6}}while(0);d6=(c[2440592]|0)-7|0;c[2440592]=d6;h=d6;break};case 123:{d6=(c[2440592]|0)-2|0;c[2440592]=d6;h=d6;break};case 124:{d6=c[2415188]|0;d8=c[3528554]|0;d5=c[2433592]|0;d7=c[d5+(d8*3148|0)+48+((d6>>>8&255)<<2)>>2]|0;do{if((d7|0)==0){d9=c[d5+(d8*3148|0)+3132>>2]|0;if((d9|0)==0){eb=0;ec=d6;ed=d8;ee=d5;ef=d6&65535;break}ea=gj[d9&4095](d6&65535)|0;d9=c[2415188]|0;eb=ea;ec=d9;ed=c[3528554]|0;ee=c[2433592]|0;ef=d9&65535}else{eb=a[d7+(d6&255)|0]|0;ec=d6;ed=d8;ee=d5;ef=d6&65535}}while(0);d6=eb&255;eb=ec+1|0;ec=c[ee+(ed*3148|0)+48+((eb>>>8&255)<<2)>>2]|0;do{if((ec|0)==0){d5=c[ee+(ed*3148|0)+3132>>2]|0;if((d5|0)==0){eg=0;eh=ef;ei=ed;ej=ee;break}d8=gj[d5&4095](eb&65535)|0;eg=d8;eh=b[4830376]|0;ei=c[3528554]|0;ej=c[2433592]|0}else{eg=a[ec+(eb&255)|0]|0;eh=ef;ei=ed;ej=ee}}while(0);ee=eg&255;c[2426864]=ee|d6<<8;b[4830376]=eh+2&65535;eh=c[ej+(ei*3148|0)+48+(d6<<2)>>2]|0;do{if((eh|0)==0){eg=c[ej+(ei*3148|0)+3120>>2]|0;if((eg|0)==0){ek=0;el=ee|d6<<8;em=ei;en=ej;break}ed=gj[eg&4095]((ee|d6<<8)&65535)|0;ek=ed;el=c[2426864]|0;em=c[3528554]|0;en=c[2433592]|0}else{ek=a[eh+ee|0]|0;el=ee|d6<<8;em=ei;en=ej}}while(0);ej=ek+1&255;a[9660784]=a[9660784]&-15|a[668928+(ej&255)|0];ek=el&65535;ei=c[en+(em*3148|0)+48+((el>>>8&255|256)<<2)>>2]|0;do{if((ei|0)==0){d6=c[en+(em*3148|0)+3124>>2]|0;if((d6|0)==0){break}gg[d6&4095](ek,ej)}else{a[ei+(el&255)|0]=ej}}while(0);ej=(c[2440592]|0)-7|0;c[2440592]=ej;h=ej;break};case 125:{ej=c[2415188]|0;el=c[3528554]|0;ei=c[2433592]|0;ek=c[ei+(el*3148|0)+48+((ej>>>8&255)<<2)>>2]|0;do{if((ek|0)==0){em=c[ei+(el*3148|0)+3132>>2]|0;if((em|0)==0){eo=0;ep=ej;eq=el;er=ei;es=ej&65535;break}en=gj[em&4095](ej&65535)|0;em=c[2415188]|0;eo=en;ep=em;eq=c[3528554]|0;er=c[2433592]|0;es=em&65535}else{eo=a[ek+(ej&255)|0]|0;ep=ej;eq=el;er=ei;es=ej&65535}}while(0);ej=eo&255;eo=ep+1|0;ep=c[er+(eq*3148|0)+48+((eo>>>8&255)<<2)>>2]|0;do{if((ep|0)==0){ei=c[er+(eq*3148|0)+3132>>2]|0;if((ei|0)==0){et=0;eu=es;ev=eq;ew=er;break}el=gj[ei&4095](eo&65535)|0;et=el;eu=b[4830376]|0;ev=c[3528554]|0;ew=c[2433592]|0}else{et=a[ep+(eo&255)|0]|0;eu=es;ev=eq;ew=er}}while(0);er=et&255;c[2426864]=er|ej<<8;b[4830376]=eu+2&65535;eu=c[ew+(ev*3148|0)+48+(ej<<2)>>2]|0;do{if((eu|0)==0){et=c[ew+(ev*3148|0)+3120>>2]|0;if((et|0)==0){ex=0;break}ex=gj[et&4095]((er|ej<<8)&65535)|0}else{ex=a[eu+er|0]|0}}while(0);er=a[9660784]&-15|(ex&255)>>>4&8;a[9660784]=ex<<24>>24==0?er|4:er;er=(c[2440592]|0)-7|0;c[2440592]=er;h=er;break};case 126:{er=c[2415188]|0;ex=c[3528554]|0;eu=c[2433592]|0;ej=c[eu+(ex*3148|0)+48+((er>>>8&255)<<2)>>2]|0;do{if((ej|0)==0){ev=c[eu+(ex*3148|0)+3132>>2]|0;if((ev|0)==0){ey=0;ez=er;eA=ex;eB=eu;break}ew=gj[ev&4095](er&65535)|0;ey=ew;ez=c[2415188]|0;eA=c[3528554]|0;eB=c[2433592]|0}else{ey=a[ej+(er&255)|0]|0;ez=er;eA=ex;eB=eu}}while(0);eu=(ey&255)<<8;ey=ez+1|0;ez=c[eB+(eA*3148|0)+48+((ey>>>8&255)<<2)>>2]|0;do{if((ez|0)==0){ex=c[eB+(eA*3148|0)+3132>>2]|0;if((ex|0)==0){eC=0;break}eC=gj[ex&4095](ey&65535)|0}else{eC=a[ez+(ey&255)|0]|0}}while(0);ey=eC&255|eu;c[2426864]=ey;c[2415188]=ey;b[4830376]=ey&65535;ey=(c[2440592]|0)-4|0;c[2440592]=ey;h=ey;break};case 127:{ey=c[2415188]|0;eu=c[3528554]|0;eC=c[2433592]|0;ez=c[eC+(eu*3148|0)+48+((ey>>>8&255)<<2)>>2]|0;do{if((ez|0)==0){eA=c[eC+(eu*3148|0)+3132>>2]|0;if((eA|0)==0){eD=0;eE=ey;eF=eu;eG=eC;eH=ey&65535;break}eB=gj[eA&4095](ey&65535)|0;eA=c[2415188]|0;eD=eB;eE=eA;eF=c[3528554]|0;eG=c[2433592]|0;eH=eA&65535}else{eD=a[ez+(ey&255)|0]|0;eE=ey;eF=eu;eG=eC;eH=ey&65535}}while(0);ey=eD&255;eD=eE+1|0;eE=c[eG+(eF*3148|0)+48+((eD>>>8&255)<<2)>>2]|0;do{if((eE|0)==0){eC=c[eG+(eF*3148|0)+3132>>2]|0;if((eC|0)==0){eI=0;eJ=eH;eK=eF;eL=eG;break}eu=gj[eC&4095](eD&65535)|0;eI=eu;eJ=b[4830376]|0;eK=c[3528554]|0;eL=c[2433592]|0}else{eI=a[eE+(eD&255)|0]|0;eJ=eH;eK=eF;eL=eG}}while(0);eG=eI&255|ey<<8;c[2426864]=eG;b[4830376]=eJ+2&65535;do{if((c[eL+(eK*3148|0)+48+(ey<<2)>>2]|0)==0){eJ=c[eL+(eK*3148|0)+3120>>2]|0;if((eJ|0)==0){eM=eG;eN=eK;eO=eL;break}gj[eJ&4095](eG&65535)|0;eM=c[2426864]|0;eN=c[3528554]|0;eO=c[2433592]|0}else{eM=eG;eN=eK;eO=eL}}while(0);eL=eM&65535;eK=c[eO+(eN*3148|0)+48+((eM>>>8&255|256)<<2)>>2]|0;do{if((eK|0)==0){eG=c[eO+(eN*3148|0)+3124>>2]|0;if((eG|0)==0){break}gg[eG&4095](eL,0)}else{a[eK+(eM&255)|0]=0}}while(0);a[9660784]=a[9660784]&-16|4;eM=(c[2440592]|0)-7|0;c[2440592]=eM;h=eM;break};case 128:{eM=c[2415188]|0;eK=c[3528554]|0;eL=c[2433592]|0;eN=c[eL+(eK*3148|0)+48+((eM>>>8&255)<<2)>>2]|0;do{if((eN|0)==0){eO=c[eL+(eK*3148|0)+3132>>2]|0;if((eO|0)==0){eP=0;eQ=eM&65535;break}eG=gj[eO&4095](eM&65535)|0;eP=eG;eQ=b[4830376]|0}else{eP=a[eN+(eM&255)|0]|0;eQ=eM&65535}}while(0);b[4830376]=eQ+1&65535;eQ=a[9660761]|0;eM=(eQ&255)-(eP&255)|0;eN=(eM>>>4&8|a[9660784]&-16&255)&255;a[9660784]=(((eQ^eP)&255^eM^eM>>>1)>>>6&2|eM>>>8&1|((eM&255)<<24>>24==0?eN|4:eN)&255)&255;a[9660761]=eM&255;eM=(c[2440592]|0)-2|0;c[2440592]=eM;h=eM;break};case 129:{eM=c[2415188]|0;eN=c[3528554]|0;eP=c[2433592]|0;eQ=c[eP+(eN*3148|0)+48+((eM>>>8&255)<<2)>>2]|0;do{if((eQ|0)==0){eK=c[eP+(eN*3148|0)+3132>>2]|0;if((eK|0)==0){eR=0;eS=eM&65535;break}eL=gj[eK&4095](eM&65535)|0;eR=eL;eS=b[4830376]|0}else{eR=a[eQ+(eM&255)|0]|0;eS=eM&65535}}while(0);b[4830376]=eS+1&65535;eS=a[9660761]|0;eM=(eS&255)-(eR&255)|0;eQ=(eM>>>4&8|a[9660784]&-16&255)&255;a[9660784]=(((eS^eR)&255^eM^eM>>>1)>>>6&2|eM>>>8&1|((eM&255)<<24>>24==0?eQ|4:eQ)&255)&255;eQ=(c[2440592]|0)-2|0;c[2440592]=eQ;h=eQ;break};case 130:{eQ=c[2415188]|0;eM=c[3528554]|0;eR=c[2433592]|0;eS=c[eR+(eM*3148|0)+48+((eQ>>>8&255)<<2)>>2]|0;do{if((eS|0)==0){eN=c[eR+(eM*3148|0)+3132>>2]|0;if((eN|0)==0){eT=0;eU=eQ&65535;break}eP=gj[eN&4095](eQ&65535)|0;eT=eP;eU=b[4830376]|0}else{eT=a[eS+(eQ&255)|0]|0;eU=eQ&65535}}while(0);b[4830376]=eU+1&65535;eU=a[9660761]|0;eQ=a[9660784]|0;eS=(eU&255)-(eT&255)-(eQ&1)|0;a[9660784]=((eS^(eU^eT)&255^eS>>>1)>>>6&2|eS>>>8&1|((eS&255)<<24>>24==0?(eS>>>4&8|eQ&-16&255)&255|4:(eS>>>4&8|eQ&-16&255)&255)&255)&255;a[9660761]=eS&255;eS=(c[2440592]|0)-2|0;c[2440592]=eS;h=eS;break};case 131:{eS=c[2415188]|0;eQ=c[3528554]|0;eT=c[2433592]|0;eU=c[eT+(eQ*3148|0)+48+((eS>>>8&255)<<2)>>2]|0;do{if((eU|0)==0){eM=c[eT+(eQ*3148|0)+3132>>2]|0;if((eM|0)==0){eV=0;eW=eS;eX=eQ;eY=eT;eZ=eS&65535;break}eR=gj[eM&4095](eS&65535)|0;eM=c[2415188]|0;eV=eR;eW=eM;eX=c[3528554]|0;eY=c[2433592]|0;eZ=eM&65535}else{eV=a[eU+(eS&255)|0]|0;eW=eS;eX=eQ;eY=eT;eZ=eS&65535}}while(0);eS=(eV&255)<<8;eV=eW+1|0;eW=c[eY+(eX*3148|0)+48+((eV>>>8&255)<<2)>>2]|0;do{if((eW|0)==0){eT=c[eY+(eX*3148|0)+3132>>2]|0;if((eT|0)==0){e_=0;e$=eZ;break}eQ=gj[eT&4095](eV&65535)|0;e_=eQ;e$=b[4830376]|0}else{e_=a[eW+(eV&255)|0]|0;e$=eZ}}while(0);b[4830376]=e$+2&65535;e$=e[4830380]|0;eZ=e$-(e_&255|eS)|0;e_=(eZ>>>12&8|a[9660784]&-16&255)&255;a[9660784]=((e$^eS^eZ^eZ>>>1)>>>14&2|eZ>>>16&1|((eZ&65535)<<16>>16==0?e_|4:e_)&255)&255;b[4830380]=eZ&65535;eZ=(c[2440592]|0)-4|0;c[2440592]=eZ;h=eZ;break};case 132:{eZ=c[2415188]|0;e_=c[3528554]|0;eS=c[2433592]|0;e$=c[eS+(e_*3148|0)+48+((eZ>>>8&255)<<2)>>2]|0;do{if((e$|0)==0){eV=c[eS+(e_*3148|0)+3132>>2]|0;if((eV|0)==0){e0=0;e1=eZ&65535;break}eW=gj[eV&4095](eZ&65535)|0;e0=eW;e1=b[4830376]|0}else{e0=a[e$+(eZ&255)|0]|0;e1=eZ&65535}}while(0);b[4830376]=e1+1&65535;e1=a[9660761]&e0;a[9660761]=e1;e0=(e1&255)>>>4&8|a[9660784]&-15;a[9660784]=e1<<24>>24==0?e0|4:e0;e0=(c[2440592]|0)-2|0;c[2440592]=e0;h=e0;break};case 133:{e0=c[2415188]|0;e1=c[3528554]|0;eZ=c[2433592]|0;e$=c[eZ+(e1*3148|0)+48+((e0>>>8&255)<<2)>>2]|0;do{if((e$|0)==0){e_=c[eZ+(e1*3148|0)+3132>>2]|0;if((e_|0)==0){e2=0;e3=e0&65535;break}eS=gj[e_&4095](e0&65535)|0;e2=eS;e3=b[4830376]|0}else{e2=a[e$+(e0&255)|0]|0;e3=e0&65535}}while(0);b[4830376]=e3+1&65535;e3=a[9660761]&e2;e2=(e3&255)>>>4&8|a[9660784]&-15;a[9660784]=e3<<24>>24==0?e2|4:e2;e2=(c[2440592]|0)-2|0;c[2440592]=e2;h=e2;break};case 134:{e2=c[2415188]|0;e3=c[3528554]|0;e0=c[2433592]|0;e$=c[e0+(e3*3148|0)+48+((e2>>>8&255)<<2)>>2]|0;do{if((e$|0)==0){e1=c[e0+(e3*3148|0)+3132>>2]|0;if((e1|0)==0){e4=0;e5=e2&65535;break}eZ=gj[e1&4095](e2&65535)|0;e4=eZ;e5=b[4830376]|0}else{e4=a[e$+(e2&255)|0]|0;e5=e2&65535}}while(0);a[9660761]=e4;b[4830376]=e5+1&65535;e5=a[9660784]&-15|(e4&255)>>>4&8;a[9660784]=e4<<24>>24==0?e5|4:e5;e5=(c[2440592]|0)-2|0;c[2440592]=e5;h=e5;break};case 135:{e5=a[9660761]|0;e4=(e5&255)>>>4&8|a[9660784]&-15;a[9660784]=e5<<24>>24==0?e4|4:e4;e4=c[2415188]|0;c[2426864]=e4;b[4830376]=(e4&65535)+1&65535;e2=c[3528554]|0;e$=c[2433592]|0;e3=c[e$+(e2*3148|0)+48+((e4>>>8&255|256)<<2)>>2]|0;do{if((e3|0)==0){e0=c[e$+(e2*3148|0)+3124>>2]|0;if((e0|0)==0){break}gg[e0&4095](e4&65535,e5)}else{a[e3+(e4&255)|0]=e5}}while(0);e5=(c[2440592]|0)-2|0;c[2440592]=e5;h=e5;break};case 136:{e5=c[2415188]|0;e4=c[3528554]|0;e3=c[2433592]|0;e2=c[e3+(e4*3148|0)+48+((e5>>>8&255)<<2)>>2]|0;do{if((e2|0)==0){e$=c[e3+(e4*3148|0)+3132>>2]|0;if((e$|0)==0){e6=0;e7=e5&65535;break}e0=gj[e$&4095](e5&65535)|0;e6=e0;e7=b[4830376]|0}else{e6=a[e2+(e5&255)|0]|0;e7=e5&65535}}while(0);b[4830376]=e7+1&65535;e7=a[9660761]|0;e5=e7^e6;a[9660761]=e5;e2=(e5&255)>>>4&8|a[9660784]&-15;a[9660784]=e7<<24>>24==e6<<24>>24?e2|4:e2;e2=(c[2440592]|0)-2|0;c[2440592]=e2;h=e2;break};case 137:{e2=c[2415188]|0;e6=c[3528554]|0;e7=c[2433592]|0;e5=c[e7+(e6*3148|0)+48+((e2>>>8&255)<<2)>>2]|0;do{if((e5|0)==0){e4=c[e7+(e6*3148|0)+3132>>2]|0;if((e4|0)==0){e8=0;e9=e2&65535;break}e3=gj[e4&4095](e2&65535)|0;e8=e3;e9=b[4830376]|0}else{e8=a[e5+(e2&255)|0]|0;e9=e2&65535}}while(0);b[4830376]=e9+1&65535;e9=a[9660761]|0;e2=a[9660784]|0;e5=(e9&255)+(e8&255)+(e2&1)|0;e6=e5^(e9^e8)&255;a[9660784]=(e6<<1&32|e5>>>8&1|(e6^e5>>>1)>>>6&2|((e5&255)<<24>>24==0?(e5>>>4&8|e2&-48&255)&255|4:(e5>>>4&8|e2&-48&255)&255)&255)&255;a[9660761]=e5&255;e5=(c[2440592]|0)-2|0;c[2440592]=e5;h=e5;break};case 138:{e5=c[2415188]|0;e2=c[3528554]|0;e6=c[2433592]|0;e8=c[e6+(e2*3148|0)+48+((e5>>>8&255)<<2)>>2]|0;do{if((e8|0)==0){e9=c[e6+(e2*3148|0)+3132>>2]|0;if((e9|0)==0){fa=0;fb=e5&65535;break}e7=gj[e9&4095](e5&65535)|0;fa=e7;fb=b[4830376]|0}else{fa=a[e8+(e5&255)|0]|0;fb=e5&65535}}while(0);b[4830376]=fb+1&65535;fb=a[9660761]|fa;a[9660761]=fb;fa=(fb&255)>>>4&8|a[9660784]&-15;a[9660784]=fb<<24>>24==0?fa|4:fa;fa=(c[2440592]|0)-2|0;c[2440592]=fa;h=fa;break};case 139:{fa=c[2415188]|0;fb=c[3528554]|0;e5=c[2433592]|0;e8=c[e5+(fb*3148|0)+48+((fa>>>8&255)<<2)>>2]|0;do{if((e8|0)==0){e2=c[e5+(fb*3148|0)+3132>>2]|0;if((e2|0)==0){fc=0;fd=fa&65535;break}e6=gj[e2&4095](fa&65535)|0;fc=e6;fd=b[4830376]|0}else{fc=a[e8+(fa&255)|0]|0;fd=fa&65535}}while(0);b[4830376]=fd+1&65535;fd=a[9660761]|0;fa=(fd&255)+(fc&255)|0;e8=(fa>>>4&8|a[9660784]&-48&255)&255;fb=(fd^fc)&255^fa;a[9660784]=(fb<<1&32|fa>>>8&1|(fb^fa>>>1)>>>6&2|((fa&255)<<24>>24==0?e8|4:e8)&255)&255;a[9660761]=fa&255;fa=(c[2440592]|0)-2|0;c[2440592]=fa;h=fa;break};case 140:{fa=c[2415188]|0;e8=c[3528554]|0;fb=c[2433592]|0;fc=c[fb+(e8*3148|0)+48+((fa>>>8&255)<<2)>>2]|0;do{if((fc|0)==0){fd=c[fb+(e8*3148|0)+3132>>2]|0;if((fd|0)==0){fe=0;ff=fa;fg=e8;fh=fb;fi=fa&65535;break}e5=gj[fd&4095](fa&65535)|0;fd=c[2415188]|0;fe=e5;ff=fd;fg=c[3528554]|0;fh=c[2433592]|0;fi=fd&65535}else{fe=a[fc+(fa&255)|0]|0;ff=fa;fg=e8;fh=fb;fi=fa&65535}}while(0);fa=(fe&255)<<8;fe=ff+1|0;ff=c[fh+(fg*3148|0)+48+((fe>>>8&255)<<2)>>2]|0;do{if((ff|0)==0){fb=c[fh+(fg*3148|0)+3132>>2]|0;if((fb|0)==0){fj=0;fk=fi;break}e8=gj[fb&4095](fe&65535)|0;fj=e8;fk=b[4830376]|0}else{fj=a[ff+(fe&255)|0]|0;fk=fi}}while(0);b[4830376]=fk+2&65535;fk=e[4830388]|0;fi=fk-(fj&255|fa)|0;fj=(fi>>>12&8|a[9660784]&-16&255)&255;a[9660784]=((fk^fa^fi^fi>>>1)>>>14&2|fi>>>16&1|((fi&65535)<<16>>16==0?fj|4:fj)&255)&255;fj=(c[2440592]|0)-4|0;c[2440592]=fj;h=fj;break};case 141:{fj=c[2415188]|0;fi=c[3528554]|0;fa=c[2433592]|0;fk=c[fa+(fi*3148|0)+48+((fj>>>8&255)<<2)>>2]|0;do{if((fk|0)==0){fe=c[fa+(fi*3148|0)+3132>>2]|0;if((fe|0)==0){fl=0;fm=fj&65535;fn=fi;fo=fa;break}ff=gj[fe&4095](fj&65535)|0;fl=ff;fm=b[4830376]|0;fn=c[3528554]|0;fo=c[2433592]|0}else{fl=a[fk+(fj&255)|0]|0;fm=fj&65535;fn=fi;fo=fa}}while(0);fa=fm+1&65535;b[4830376]=fa;b[4830386]=(b[4830386]|0)-1&65535;fm=c[2415193]|0;fi=c[fo+(fn*3148|0)+48+((fm>>>8&255|256)<<2)>>2]|0;do{if((fi|0)==0){fj=c[fo+(fn*3148|0)+3124>>2]|0;if((fj|0)==0){fp=fn;fq=fo;break}gg[fj&4095](fm&65535,fa&255);fp=c[3528554]|0;fq=c[2433592]|0}else{a[fi+(fm&255)|0]=fa&255;fp=fn;fq=fo}}while(0);b[4830386]=(b[4830386]|0)-1&65535;fo=c[2415193]|0;fn=a[9660753]|0;fa=c[fq+(fp*3148|0)+48+((fo>>>8&255|256)<<2)>>2]|0;do{if((fa|0)==0){fm=c[fq+(fp*3148|0)+3124>>2]|0;if((fm|0)==0){break}gg[fm&4095](fo&65535,fn)}else{a[fa+(fo&255)|0]=fn}}while(0);fn=fl&255;b[4830376]=(e[4830376]|0)+((fn&128|0)!=0?fn|65280:fn)&65535;b[4830376]=c[2415188]&65535;fn=(c[2440592]|0)-7|0;c[2440592]=fn;h=fn;break};case 142:{fn=c[2415188]|0;fl=c[3528554]|0;fo=c[2433592]|0;fa=c[fo+(fl*3148|0)+48+((fn>>>8&255)<<2)>>2]|0;do{if((fa|0)==0){fp=c[fo+(fl*3148|0)+3132>>2]|0;if((fp|0)==0){fr=0;fs=fn;ft=fl;fu=fo;fv=fn&65535;break}fq=gj[fp&4095](fn&65535)|0;fp=c[2415188]|0;fr=fq;fs=fp;ft=c[3528554]|0;fu=c[2433592]|0;fv=fp&65535}else{fr=a[fa+(fn&255)|0]|0;fs=fn;ft=fl;fu=fo;fv=fn&65535}}while(0);fn=fr&255;fr=fs+1|0;fs=c[fu+(ft*3148|0)+48+((fr>>>8&255)<<2)>>2]|0;do{if((fs|0)==0){fo=c[fu+(ft*3148|0)+3132>>2]|0;if((fo|0)==0){fw=0;fx=fv;break}fl=gj[fo&4095](fr&65535)|0;fw=fl;fx=b[4830376]|0}else{fw=a[fs+(fr&255)|0]|0;fx=fv}}while(0);fv=fw&255|fn<<8;c[2415194]=fv;b[4830376]=fx+2&65535;fx=a[9660784]&-15;a[9660784]=fx;if((fv|0)==0){fy=(fx&255|fn>>>4&8|4)&255}else{fy=(fx&255|fn>>>4&8)&255}a[9660784]=fy;fy=(c[2440592]|0)-3|0;c[2440592]=fy;h=fy;break};case 143:{fy=b[4830388]|0;fn=(fy&65535)>>>12&8|a[9660784]&-15&255;a[9660784]=(fy<<16>>16==0?fn|4:fn)&255;fn=c[2415188]|0;c[2426864]=fn;b[4830376]=(fn&65535)+2&65535;fy=a[9660777]|0;fx=c[3528554]|0;fv=c[2433592]|0;fw=c[fv+(fx*3148|0)+48+((fn>>>8&255|256)<<2)>>2]|0;do{if((fw|0)==0){fr=c[fv+(fx*3148|0)+3124>>2]|0;if((fr|0)==0){fz=fx;fA=fv;break}gg[fr&4095](fn&65535,fy);fz=c[3528554]|0;fA=c[2433592]|0}else{a[fw+(fn&255)|0]=fy;fz=fx;fA=fv}}while(0);fv=a[9660776]|0;fx=c[fA+(fz*3148|0)+48+(((fn+1|0)>>>8&255|256)<<2)>>2]|0;do{if((fx|0)==0){fy=c[fA+(fz*3148|0)+3124>>2]|0;if((fy|0)==0){break}gg[fy&4095]((fn+1|0)&65535,fv)}else{a[fx+((fn+1|0)&255)|0]=fv}}while(0);fv=(c[2440592]|0)-2|0;c[2440592]=fv;h=fv;break};case 144:{c[2426864]=c[2415191];fv=c[2415188]|0;fn=c[3528554]|0;fx=c[2433592]|0;fz=c[fx+(fn*3148|0)+48+((fv>>>8&255)<<2)>>2]|0;do{if((fz|0)==0){fA=c[fx+(fn*3148|0)+3132>>2]|0;if((fA|0)==0){fB=0;fC=fv&65535;fD=fn;fE=fx;break}fy=gj[fA&4095](fv&65535)|0;fB=fy;fC=b[4830376]|0;fD=c[3528554]|0;fE=c[2433592]|0}else{fB=a[fz+(fv&255)|0]|0;fC=fv&65535;fD=fn;fE=fx}}while(0);a[9707456]=fB;b[4830376]=fC+1&65535;fC=c[2426864]|0;fB=c[fE+(fD*3148|0)+48+((fC>>>8&255)<<2)>>2]|0;do{if((fB|0)==0){fx=c[fE+(fD*3148|0)+3120>>2]|0;if((fx|0)==0){fF=0;break}fF=gj[fx&4095](fC&65535)|0}else{fF=a[fB+(fC&255)|0]|0}}while(0);fC=a[9660761]|0;fB=(fC&255)-(fF&255)|0;fD=(fB>>>4&8|a[9660784]&-16&255)&255;a[9660784]=(((fC^fF)&255^fB^fB>>>1)>>>6&2|fB>>>8&1|((fB&255)<<24>>24==0?fD|4:fD)&255)&255;a[9660761]=fB&255;fB=(c[2440592]|0)-4|0;c[2440592]=fB;h=fB;break};case 145:{c[2426864]=c[2415191];fB=c[2415188]|0;fD=c[3528554]|0;fF=c[2433592]|0;fC=c[fF+(fD*3148|0)+48+((fB>>>8&255)<<2)>>2]|0;do{if((fC|0)==0){fE=c[fF+(fD*3148|0)+3132>>2]|0;if((fE|0)==0){fG=0;fH=fB&65535;fI=fD;fJ=fF;break}fx=gj[fE&4095](fB&65535)|0;fG=fx;fH=b[4830376]|0;fI=c[3528554]|0;fJ=c[2433592]|0}else{fG=a[fC+(fB&255)|0]|0;fH=fB&65535;fI=fD;fJ=fF}}while(0);a[9707456]=fG;b[4830376]=fH+1&65535;fH=c[2426864]|0;fG=c[fJ+(fI*3148|0)+48+((fH>>>8&255)<<2)>>2]|0;do{if((fG|0)==0){fF=c[fJ+(fI*3148|0)+3120>>2]|0;if((fF|0)==0){fK=0;break}fK=gj[fF&4095](fH&65535)|0}else{fK=a[fG+(fH&255)|0]|0}}while(0);fH=a[9660761]|0;fG=(fH&255)-(fK&255)|0;fI=(fG>>>4&8|a[9660784]&-16&255)&255;a[9660784]=(((fH^fK)&255^fG^fG>>>1)>>>6&2|fG>>>8&1|((fG&255)<<24>>24==0?fI|4:fI)&255)&255;fI=(c[2440592]|0)-4|0;c[2440592]=fI;h=fI;break};case 146:{c[2426864]=c[2415191];fI=c[2415188]|0;fG=c[3528554]|0;fK=c[2433592]|0;fH=c[fK+(fG*3148|0)+48+((fI>>>8&255)<<2)>>2]|0;do{if((fH|0)==0){fJ=c[fK+(fG*3148|0)+3132>>2]|0;if((fJ|0)==0){fL=0;fM=fI&65535;fN=fG;fO=fK;break}fF=gj[fJ&4095](fI&65535)|0;fL=fF;fM=b[4830376]|0;fN=c[3528554]|0;fO=c[2433592]|0}else{fL=a[fH+(fI&255)|0]|0;fM=fI&65535;fN=fG;fO=fK}}while(0);a[9707456]=fL;b[4830376]=fM+1&65535;fM=c[2426864]|0;fL=c[fO+(fN*3148|0)+48+((fM>>>8&255)<<2)>>2]|0;do{if((fL|0)==0){fK=c[fO+(fN*3148|0)+3120>>2]|0;if((fK|0)==0){fP=0;break}fP=gj[fK&4095](fM&65535)|0}else{fP=a[fL+(fM&255)|0]|0}}while(0);fM=a[9660761]|0;fL=a[9660784]|0;fN=(fM&255)-(fP&255)-(fL&1)|0;a[9660784]=((fN^(fM^fP)&255^fN>>>1)>>>6&2|fN>>>8&1|((fN&255)<<24>>24==0?(fN>>>4&8|fL&-16&255)&255|4:(fN>>>4&8|fL&-16&255)&255)&255)&255;a[9660761]=fN&255;fN=(c[2440592]|0)-4|0;c[2440592]=fN;h=fN;break};default:{j=1}}}if(j){j=0;switch(k|0){case 147:{c[2426864]=c[2415191];k=c[2415188]|0;fN=c[3528554]|0;fL=c[2433592]|0;fP=c[fL+(fN*3148|0)+48+((k>>>8&255)<<2)>>2]|0;do{if((fP|0)==0){fM=c[fL+(fN*3148|0)+3132>>2]|0;if((fM|0)==0){fQ=0;fR=k&65535;fS=fN;fT=fL;break}fO=gj[fM&4095](k&65535)|0;fQ=fO;fR=b[4830376]|0;fS=c[3528554]|0;fT=c[2433592]|0}else{fQ=a[fP+(k&255)|0]|0;fR=k&65535;fS=fN;fT=fL}}while(0);a[9707456]=fQ;b[4830376]=fR+1&65535;fR=c[2426864]|0;fQ=c[fT+(fS*3148|0)+48+((fR>>>8&255)<<2)>>2]|0;do{if((fQ|0)==0){fL=c[fT+(fS*3148|0)+3120>>2]|0;if((fL|0)==0){fU=0;fV=fS;fW=fT;break}fN=gj[fL&4095](fR&65535)|0;fU=fN;fV=c[3528554]|0;fW=c[2433592]|0}else{fU=a[fQ+(fR&255)|0]|0;fV=fS;fW=fT}}while(0);fT=(fU&255)<<8;fU=c[fW+(fV*3148|0)+48+(((fR+1|0)>>>8&255)<<2)>>2]|0;do{if((fU|0)==0){fS=c[fW+(fV*3148|0)+3120>>2]|0;if((fS|0)==0){fX=0;break}fX=gj[fS&4095]((fR+1|0)&65535)|0}else{fX=a[fU+((fR+1|0)&255)|0]|0}}while(0);fR=e[4830380]|0;fU=fR-(fX&255|fT)|0;fX=(fU>>>12&8|a[9660784]&-16&255)&255;a[9660784]=((fR^fT^fU^fU>>>1)>>>14&2|fU>>>16&1|((fU&65535)<<16>>16==0?fX|4:fX)&255)&255;b[4830380]=fU&65535;fU=(c[2440592]|0)-6|0;c[2440592]=fU;h=fU;break};case 148:{c[2426864]=c[2415191];fU=c[2415188]|0;fX=c[3528554]|0;fT=c[2433592]|0;fR=c[fT+(fX*3148|0)+48+((fU>>>8&255)<<2)>>2]|0;do{if((fR|0)==0){fV=c[fT+(fX*3148|0)+3132>>2]|0;if((fV|0)==0){fY=0;fZ=fU&65535;f_=fX;f$=fT;break}fW=gj[fV&4095](fU&65535)|0;fY=fW;fZ=b[4830376]|0;f_=c[3528554]|0;f$=c[2433592]|0}else{fY=a[fR+(fU&255)|0]|0;fZ=fU&65535;f_=fX;f$=fT}}while(0);a[9707456]=fY;b[4830376]=fZ+1&65535;fZ=c[2426864]|0;fY=c[f$+(f_*3148|0)+48+((fZ>>>8&255)<<2)>>2]|0;do{if((fY|0)==0){fT=c[f$+(f_*3148|0)+3120>>2]|0;if((fT|0)==0){f0=0;break}f0=gj[fT&4095](fZ&65535)|0}else{f0=a[fY+(fZ&255)|0]|0}}while(0);fZ=a[9660761]&f0;a[9660761]=fZ;f0=(fZ&255)>>>4&8|a[9660784]&-15;a[9660784]=fZ<<24>>24==0?f0|4:f0;f0=(c[2440592]|0)-4|0;c[2440592]=f0;h=f0;break};case 149:{c[2426864]=c[2415191];f0=c[2415188]|0;fZ=c[3528554]|0;fY=c[2433592]|0;f_=c[fY+(fZ*3148|0)+48+((f0>>>8&255)<<2)>>2]|0;do{if((f_|0)==0){f$=c[fY+(fZ*3148|0)+3132>>2]|0;if((f$|0)==0){f1=0;f2=f0&65535;f3=fZ;f4=fY;break}fT=gj[f$&4095](f0&65535)|0;f1=fT;f2=b[4830376]|0;f3=c[3528554]|0;f4=c[2433592]|0}else{f1=a[f_+(f0&255)|0]|0;f2=f0&65535;f3=fZ;f4=fY}}while(0);a[9707456]=f1;b[4830376]=f2+1&65535;f2=c[2426864]|0;f1=c[f4+(f3*3148|0)+48+((f2>>>8&255)<<2)>>2]|0;do{if((f1|0)==0){fY=c[f4+(f3*3148|0)+3120>>2]|0;if((fY|0)==0){f5=0;break}f5=gj[fY&4095](f2&65535)|0}else{f5=a[f1+(f2&255)|0]|0}}while(0);f2=a[9660761]&f5;f5=(f2&255)>>>4&8|a[9660784]&-15;a[9660784]=f2<<24>>24==0?f5|4:f5;f5=(c[2440592]|0)-4|0;c[2440592]=f5;h=f5;break};case 150:{c[2426864]=c[2415191];f5=c[2415188]|0;f2=c[3528554]|0;f1=c[2433592]|0;f3=c[f1+(f2*3148|0)+48+((f5>>>8&255)<<2)>>2]|0;do{if((f3|0)==0){f4=c[f1+(f2*3148|0)+3132>>2]|0;if((f4|0)==0){f6=0;f7=f5&65535;f8=f2;f9=f1;break}fY=gj[f4&4095](f5&65535)|0;f6=fY;f7=b[4830376]|0;f8=c[3528554]|0;f9=c[2433592]|0}else{f6=a[f3+(f5&255)|0]|0;f7=f5&65535;f8=f2;f9=f1}}while(0);a[9707456]=f6;b[4830376]=f7+1&65535;f7=c[2426864]|0;f6=c[f9+(f8*3148|0)+48+((f7>>>8&255)<<2)>>2]|0;do{if((f6|0)==0){f1=c[f9+(f8*3148|0)+3120>>2]|0;if((f1|0)==0){ga=0;break}ga=gj[f1&4095](f7&65535)|0}else{ga=a[f6+(f7&255)|0]|0}}while(0);a[9660761]=ga;f7=(ga&255)>>>4&8|a[9660784]&-15;a[9660784]=ga<<24>>24==0?f7|4:f7;f7=(c[2440592]|0)-4|0;c[2440592]=f7;h=f7;break};case 151:{f7=a[9660761]|0;ga=(f7&255)>>>4&8|a[9660784]&-15;a[9660784]=f7<<24>>24==0?ga|4:ga;c[2426864]=c[2415191];ga=c[2415188]|0;f6=c[3528554]|0;f8=c[2433592]|0;f9=c[f8+(f6*3148|0)+48+((ga>>>8&255)<<2)>>2]|0;do{if((f9|0)==0){f1=c[f8+(f6*3148|0)+3132>>2]|0;if((f1|0)==0){gb=0;gc=ga&65535;gd=f7;ge=f6;gf=f8;break}f2=gj[f1&4095](ga&65535)|0;gb=f2;gc=b[4830376]|0;gd=a[9660761]|0;ge=c[3528554]|0;gf=c[2433592]|0}else{gb=a[f9+(ga&255)|0]|0;gc=ga&65535;gd=f7;ge=f6;gf=f8}}while(0);a[9707456]=gb;b[4830376]=gc+1&65535;gc=c[2426864]|0;gb=c[gf+(ge*3148|0)+48+((gc>>>8&255|256)<<2)>>2]|0;do{if((gb|0)==0){f8=c[gf+(ge*3148|0)+3124>>2]|0;if((f8|0)==0){break}gg[f8&4095](gc&65535,gd)}else{a[gb+(gc&255)|0]=gd}}while(0);gd=(c[2440592]|0)-4|0;c[2440592]=gd;h=gd;break};case 152:{c[2426864]=c[2415191];gd=c[2415188]|0;gc=c[3528554]|0;gb=c[2433592]|0;ge=c[gb+(gc*3148|0)+48+((gd>>>8&255)<<2)>>2]|0;do{if((ge|0)==0){gf=c[gb+(gc*3148|0)+3132>>2]|0;if((gf|0)==0){gh=0;gi=gd&65535;gk=gc;gl=gb;break}f8=gj[gf&4095](gd&65535)|0;gh=f8;gi=b[4830376]|0;gk=c[3528554]|0;gl=c[2433592]|0}else{gh=a[ge+(gd&255)|0]|0;gi=gd&65535;gk=gc;gl=gb}}while(0);a[9707456]=gh;b[4830376]=gi+1&65535;gi=c[2426864]|0;gh=c[gl+(gk*3148|0)+48+((gi>>>8&255)<<2)>>2]|0;do{if((gh|0)==0){gb=c[gl+(gk*3148|0)+3120>>2]|0;if((gb|0)==0){gm=0;break}gm=gj[gb&4095](gi&65535)|0}else{gm=a[gh+(gi&255)|0]|0}}while(0);gi=a[9660761]|0;gh=gi^gm;a[9660761]=gh;gk=(gh&255)>>>4&8|a[9660784]&-15;a[9660784]=gi<<24>>24==gm<<24>>24?gk|4:gk;gk=(c[2440592]|0)-4|0;c[2440592]=gk;h=gk;break};case 153:{c[2426864]=c[2415191];gk=c[2415188]|0;gm=c[3528554]|0;gi=c[2433592]|0;gh=c[gi+(gm*3148|0)+48+((gk>>>8&255)<<2)>>2]|0;do{if((gh|0)==0){gl=c[gi+(gm*3148|0)+3132>>2]|0;if((gl|0)==0){gn=0;go=gk&65535;gp=gm;gq=gi;break}gb=gj[gl&4095](gk&65535)|0;gn=gb;go=b[4830376]|0;gp=c[3528554]|0;gq=c[2433592]|0}else{gn=a[gh+(gk&255)|0]|0;go=gk&65535;gp=gm;gq=gi}}while(0);a[9707456]=gn;b[4830376]=go+1&65535;go=c[2426864]|0;gn=c[gq+(gp*3148|0)+48+((go>>>8&255)<<2)>>2]|0;do{if((gn|0)==0){gi=c[gq+(gp*3148|0)+3120>>2]|0;if((gi|0)==0){gr=0;break}gr=gj[gi&4095](go&65535)|0}else{gr=a[gn+(go&255)|0]|0}}while(0);go=a[9660761]|0;gn=a[9660784]|0;gp=(go&255)+(gr&255)+(gn&1)|0;gq=gp^(go^gr)&255;a[9660784]=(gq<<1&32|gp>>>8&1|(gq^gp>>>1)>>>6&2|((gp&255)<<24>>24==0?(gp>>>4&8|gn&-48&255)&255|4:(gp>>>4&8|gn&-48&255)&255)&255)&255;a[9660761]=gp&255;gp=(c[2440592]|0)-4|0;c[2440592]=gp;h=gp;break};case 154:{c[2426864]=c[2415191];gp=c[2415188]|0;gn=c[3528554]|0;gq=c[2433592]|0;gr=c[gq+(gn*3148|0)+48+((gp>>>8&255)<<2)>>2]|0;do{if((gr|0)==0){go=c[gq+(gn*3148|0)+3132>>2]|0;if((go|0)==0){gs=0;gt=gp&65535;gu=gn;gv=gq;break}gi=gj[go&4095](gp&65535)|0;gs=gi;gt=b[4830376]|0;gu=c[3528554]|0;gv=c[2433592]|0}else{gs=a[gr+(gp&255)|0]|0;gt=gp&65535;gu=gn;gv=gq}}while(0);a[9707456]=gs;b[4830376]=gt+1&65535;gt=c[2426864]|0;gs=c[gv+(gu*3148|0)+48+((gt>>>8&255)<<2)>>2]|0;do{if((gs|0)==0){gq=c[gv+(gu*3148|0)+3120>>2]|0;if((gq|0)==0){gw=0;break}gw=gj[gq&4095](gt&65535)|0}else{gw=a[gs+(gt&255)|0]|0}}while(0);gt=a[9660761]|gw;a[9660761]=gt;gw=(gt&255)>>>4&8|a[9660784]&-15;a[9660784]=gt<<24>>24==0?gw|4:gw;gw=(c[2440592]|0)-4|0;c[2440592]=gw;h=gw;break};case 155:{c[2426864]=c[2415191];gw=c[2415188]|0;gt=c[3528554]|0;gs=c[2433592]|0;gu=c[gs+(gt*3148|0)+48+((gw>>>8&255)<<2)>>2]|0;do{if((gu|0)==0){gv=c[gs+(gt*3148|0)+3132>>2]|0;if((gv|0)==0){gx=0;gy=gw&65535;gz=gt;gA=gs;break}gq=gj[gv&4095](gw&65535)|0;gx=gq;gy=b[4830376]|0;gz=c[3528554]|0;gA=c[2433592]|0}else{gx=a[gu+(gw&255)|0]|0;gy=gw&65535;gz=gt;gA=gs}}while(0);a[9707456]=gx;b[4830376]=gy+1&65535;gy=c[2426864]|0;gx=c[gA+(gz*3148|0)+48+((gy>>>8&255)<<2)>>2]|0;do{if((gx|0)==0){gs=c[gA+(gz*3148|0)+3120>>2]|0;if((gs|0)==0){gB=0;break}gB=gj[gs&4095](gy&65535)|0}else{gB=a[gx+(gy&255)|0]|0}}while(0);gy=a[9660761]|0;gx=(gy&255)+(gB&255)|0;gz=(gx>>>4&8|a[9660784]&-48&255)&255;gA=(gy^gB)&255^gx;a[9660784]=(gA<<1&32|gx>>>8&1|(gA^gx>>>1)>>>6&2|((gx&255)<<24>>24==0?gz|4:gz)&255)&255;a[9660761]=gx&255;gx=(c[2440592]|0)-4|0;c[2440592]=gx;h=gx;break};case 156:{c[2426864]=c[2415191];gx=c[2415188]|0;gz=c[3528554]|0;gA=c[2433592]|0;gB=c[gA+(gz*3148|0)+48+((gx>>>8&255)<<2)>>2]|0;do{if((gB|0)==0){gy=c[gA+(gz*3148|0)+3132>>2]|0;if((gy|0)==0){gC=0;gD=gx&65535;gE=gz;gF=gA;break}gs=gj[gy&4095](gx&65535)|0;gC=gs;gD=b[4830376]|0;gE=c[3528554]|0;gF=c[2433592]|0}else{gC=a[gB+(gx&255)|0]|0;gD=gx&65535;gE=gz;gF=gA}}while(0);a[9707456]=gC;b[4830376]=gD+1&65535;gD=c[2426864]|0;gC=c[gF+(gE*3148|0)+48+((gD>>>8&255)<<2)>>2]|0;do{if((gC|0)==0){gA=c[gF+(gE*3148|0)+3120>>2]|0;if((gA|0)==0){gG=0;gH=gE;gI=gF;break}gz=gj[gA&4095](gD&65535)|0;gG=gz;gH=c[3528554]|0;gI=c[2433592]|0}else{gG=a[gC+(gD&255)|0]|0;gH=gE;gI=gF}}while(0);gF=(gG&255)<<8;gG=c[gI+(gH*3148|0)+48+(((gD+1|0)>>>8&255)<<2)>>2]|0;do{if((gG|0)==0){gE=c[gI+(gH*3148|0)+3120>>2]|0;if((gE|0)==0){gJ=0;break}gJ=gj[gE&4095]((gD+1|0)&65535)|0}else{gJ=a[gG+((gD+1|0)&255)|0]|0}}while(0);gD=e[4830388]|0;gG=gD-(gJ&255|gF)|0;gJ=(gG>>>12&8|a[9660784]&-16&255)&255;a[9660784]=((gD^gF^gG^gG>>>1)>>>14&2|gG>>>16&1|((gG&65535)<<16>>16==0?gJ|4:gJ)&255)&255;gJ=(c[2440592]|0)-6|0;c[2440592]=gJ;h=gJ;break};case 157:{c[2426864]=c[2415191];gJ=c[2415188]|0;gG=c[3528554]|0;gF=c[2433592]|0;gD=c[gF+(gG*3148|0)+48+((gJ>>>8&255)<<2)>>2]|0;do{if((gD|0)==0){gH=c[gF+(gG*3148|0)+3132>>2]|0;if((gH|0)==0){gK=0;gL=gJ&65535;gM=gG;gN=gF;break}gI=gj[gH&4095](gJ&65535)|0;gK=gI;gL=b[4830376]|0;gM=c[3528554]|0;gN=c[2433592]|0}else{gK=a[gD+(gJ&255)|0]|0;gL=gJ&65535;gM=gG;gN=gF}}while(0);a[9707456]=gK;gK=gL+1&65535;b[4830376]=gK;b[4830386]=(b[4830386]|0)-1&65535;gL=c[2415193]|0;gF=c[gN+(gM*3148|0)+48+((gL>>>8&255|256)<<2)>>2]|0;do{if((gF|0)==0){gG=c[gN+(gM*3148|0)+3124>>2]|0;if((gG|0)==0){gO=gM;gP=gN;break}gg[gG&4095](gL&65535,gK&255);gO=c[3528554]|0;gP=c[2433592]|0}else{a[gF+(gL&255)|0]=gK&255;gO=gM;gP=gN}}while(0);b[4830386]=(b[4830386]|0)-1&65535;gN=c[2415193]|0;gM=a[9660753]|0;gK=c[gP+(gO*3148|0)+48+((gN>>>8&255|256)<<2)>>2]|0;do{if((gK|0)==0){gL=c[gP+(gO*3148|0)+3124>>2]|0;if((gL|0)==0){break}gg[gL&4095](gN&65535,gM)}else{a[gK+(gN&255)|0]=gM}}while(0);gM=c[2426864]|0;c[2415188]=gM;b[4830376]=gM&65535;gM=(c[2440592]|0)-7|0;c[2440592]=gM;h=gM;break};case 158:{c[2426864]=c[2415191];gM=c[2415188]|0;gN=c[3528554]|0;gK=c[2433592]|0;gO=c[gK+(gN*3148|0)+48+((gM>>>8&255)<<2)>>2]|0;do{if((gO|0)==0){gP=c[gK+(gN*3148|0)+3132>>2]|0;if((gP|0)==0){gQ=0;gR=gM&65535;gS=gN;gT=gK;break}gL=gj[gP&4095](gM&65535)|0;gQ=gL;gR=b[4830376]|0;gS=c[3528554]|0;gT=c[2433592]|0}else{gQ=a[gO+(gM&255)|0]|0;gR=gM&65535;gS=gN;gT=gK}}while(0);a[9707456]=gQ;b[4830376]=gR+1&65535;gR=c[2426864]|0;gQ=c[gT+(gS*3148|0)+48+((gR>>>8&255)<<2)>>2]|0;do{if((gQ|0)==0){gK=c[gT+(gS*3148|0)+3120>>2]|0;if((gK|0)==0){gU=0;gV=gS;gW=gT;break}gN=gj[gK&4095](gR&65535)|0;gU=gN;gV=c[3528554]|0;gW=c[2433592]|0}else{gU=a[gQ+(gR&255)|0]|0;gV=gS;gW=gT}}while(0);gT=gU&255;gU=c[gW+(gV*3148|0)+48+(((gR+1|0)>>>8&255)<<2)>>2]|0;do{if((gU|0)==0){gS=c[gW+(gV*3148|0)+3120>>2]|0;if((gS|0)==0){gX=0;break}gX=gj[gS&4095]((gR+1|0)&65535)|0}else{gX=a[gU+((gR+1|0)&255)|0]|0}}while(0);gR=gX&255|gT<<8;c[2415194]=gR;gX=a[9660784]&-15;a[9660784]=gX;if((gR|0)==0){gY=(gX&255|gT>>>4&8|4)&255}else{gY=(gX&255|gT>>>4&8)&255}a[9660784]=gY;gY=(c[2440592]|0)-5|0;c[2440592]=gY;h=gY;break};case 159:{gY=b[4830388]|0;gT=(gY&65535)>>>12&8|a[9660784]&-15&255;a[9660784]=(gY<<16>>16==0?gT|4:gT)&255;c[2426864]=c[2415191];gT=c[2415188]|0;gY=c[3528554]|0;gX=c[2433592]|0;gR=c[gX+(gY*3148|0)+48+((gT>>>8&255)<<2)>>2]|0;do{if((gR|0)==0){gU=c[gX+(gY*3148|0)+3132>>2]|0;if((gU|0)==0){gZ=0;g_=gT&65535;g$=gY;g0=gX;break}gV=gj[gU&4095](gT&65535)|0;gZ=gV;g_=b[4830376]|0;g$=c[3528554]|0;g0=c[2433592]|0}else{gZ=a[gR+(gT&255)|0]|0;g_=gT&65535;g$=gY;g0=gX}}while(0);a[9707456]=gZ;b[4830376]=g_+1&65535;g_=c[2426864]|0;gZ=a[9660777]|0;gX=c[g0+(g$*3148|0)+48+((g_>>>8&255|256)<<2)>>2]|0;do{if((gX|0)==0){gY=c[g0+(g$*3148|0)+3124>>2]|0;if((gY|0)==0){g1=g$;g2=g0;break}gg[gY&4095](g_&65535,gZ);g1=c[3528554]|0;g2=c[2433592]|0}else{a[gX+(g_&255)|0]=gZ;g1=g$;g2=g0}}while(0);g0=a[9660776]|0;g$=c[g2+(g1*3148|0)+48+(((g_+1|0)>>>8&255|256)<<2)>>2]|0;do{if((g$|0)==0){gZ=c[g2+(g1*3148|0)+3124>>2]|0;if((gZ|0)==0){break}gg[gZ&4095]((g_+1|0)&65535,g0)}else{a[g$+((g_+1|0)&255)|0]=g0}}while(0);g0=(c[2440592]|0)-5|0;c[2440592]=g0;h=g0;break};case 160:{f46();g0=c[2426864]|0;g_=c[3528554]|0;g$=c[2433592]|0;g1=c[g$+(g_*3148|0)+48+((g0>>>8&255)<<2)>>2]|0;do{if((g1|0)==0){g2=c[g$+(g_*3148|0)+3120>>2]|0;if((g2|0)==0){g3=0;break}g3=gj[g2&4095](g0&65535)|0}else{g3=a[g1+(g0&255)|0]|0}}while(0);g0=a[9660761]|0;g1=(g0&255)-(g3&255)|0;g_=(g1>>>4&8|a[9660784]&-16&255)&255;a[9660784]=(((g0^g3)&255^g1^g1>>>1)>>>6&2|g1>>>8&1|((g1&255)<<24>>24==0?g_|4:g_)&255)&255;a[9660761]=g1&255;g1=(c[2440592]|0)-4|0;c[2440592]=g1;h=g1;break};case 161:{f46();g1=c[2426864]|0;g_=c[3528554]|0;g3=c[2433592]|0;g0=c[g3+(g_*3148|0)+48+((g1>>>8&255)<<2)>>2]|0;do{if((g0|0)==0){g$=c[g3+(g_*3148|0)+3120>>2]|0;if((g$|0)==0){g4=0;break}g4=gj[g$&4095](g1&65535)|0}else{g4=a[g0+(g1&255)|0]|0}}while(0);g1=a[9660761]|0;g0=(g1&255)-(g4&255)|0;g_=(g0>>>4&8|a[9660784]&-16&255)&255;a[9660784]=(((g1^g4)&255^g0^g0>>>1)>>>6&2|g0>>>8&1|((g0&255)<<24>>24==0?g_|4:g_)&255)&255;g_=(c[2440592]|0)-4|0;c[2440592]=g_;h=g_;break};case 162:{f46();g_=c[2426864]|0;g0=c[3528554]|0;g4=c[2433592]|0;g1=c[g4+(g0*3148|0)+48+((g_>>>8&255)<<2)>>2]|0;do{if((g1|0)==0){g3=c[g4+(g0*3148|0)+3120>>2]|0;if((g3|0)==0){g5=0;break}g5=gj[g3&4095](g_&65535)|0}else{g5=a[g1+(g_&255)|0]|0}}while(0);g_=a[9660761]|0;g1=a[9660784]|0;g0=(g_&255)-(g5&255)-(g1&1)|0;a[9660784]=((g0^(g_^g5)&255^g0>>>1)>>>6&2|g0>>>8&1|((g0&255)<<24>>24==0?(g0>>>4&8|g1&-16&255)&255|4:(g0>>>4&8|g1&-16&255)&255)&255)&255;a[9660761]=g0&255;g0=(c[2440592]|0)-4|0;c[2440592]=g0;h=g0;break};case 163:{f46();g0=c[2426864]|0;g1=c[3528554]|0;g5=c[2433592]|0;g_=c[g5+(g1*3148|0)+48+((g0>>>8&255)<<2)>>2]|0;do{if((g_|0)==0){g4=c[g5+(g1*3148|0)+3120>>2]|0;if((g4|0)==0){g6=0;g7=g1;g8=g5;break}g3=gj[g4&4095](g0&65535)|0;g6=g3;g7=c[3528554]|0;g8=c[2433592]|0}else{g6=a[g_+(g0&255)|0]|0;g7=g1;g8=g5}}while(0);g5=(g6&255)<<8;g6=c[g8+(g7*3148|0)+48+(((g0+1|0)>>>8&255)<<2)>>2]|0;do{if((g6|0)==0){g1=c[g8+(g7*3148|0)+3120>>2]|0;if((g1|0)==0){g9=0;break}g9=gj[g1&4095]((g0+1|0)&65535)|0}else{g9=a[g6+((g0+1|0)&255)|0]|0}}while(0);g0=e[4830380]|0;g6=g0-(g9&255|g5)|0;g9=(g6>>>12&8|a[9660784]&-16&255)&255;a[9660784]=((g0^g5^g6^g6>>>1)>>>14&2|g6>>>16&1|((g6&65535)<<16>>16==0?g9|4:g9)&255)&255;b[4830380]=g6&65535;g6=(c[2440592]|0)-6|0;c[2440592]=g6;h=g6;break};case 164:{f46();g6=c[2426864]|0;g9=c[3528554]|0;g5=c[2433592]|0;g0=c[g5+(g9*3148|0)+48+((g6>>>8&255)<<2)>>2]|0;do{if((g0|0)==0){g7=c[g5+(g9*3148|0)+3120>>2]|0;if((g7|0)==0){ha=0;break}ha=gj[g7&4095](g6&65535)|0}else{ha=a[g0+(g6&255)|0]|0}}while(0);g6=a[9660761]&ha;a[9660761]=g6;ha=(g6&255)>>>4&8|a[9660784]&-15;a[9660784]=g6<<24>>24==0?ha|4:ha;ha=(c[2440592]|0)-4|0;c[2440592]=ha;h=ha;break};case 165:{f46();ha=a[9660761]|0;g6=c[2426864]|0;g0=c[3528554]|0;g9=c[2433592]|0;g5=c[g9+(g0*3148|0)+48+((g6>>>8&255)<<2)>>2]|0;do{if((g5|0)==0){g7=c[g9+(g0*3148|0)+3120>>2]|0;if((g7|0)==0){hb=0;break}hb=gj[g7&4095](g6&65535)|0}else{hb=a[g5+(g6&255)|0]|0}}while(0);g6=hb&ha;ha=(g6&255)>>>4&8|a[9660784]&-15;a[9660784]=g6<<24>>24==0?ha|4:ha;ha=(c[2440592]|0)-4|0;c[2440592]=ha;h=ha;break};case 166:{f46();ha=c[2426864]|0;g6=c[3528554]|0;hb=c[2433592]|0;g5=c[hb+(g6*3148|0)+48+((ha>>>8&255)<<2)>>2]|0;do{if((g5|0)==0){g0=c[hb+(g6*3148|0)+3120>>2]|0;if((g0|0)==0){hc=0;break}hc=gj[g0&4095](ha&65535)|0}else{hc=a[g5+(ha&255)|0]|0}}while(0);a[9660761]=hc;ha=(hc&255)>>>4&8|a[9660784]&-15;a[9660784]=hc<<24>>24==0?ha|4:ha;ha=(c[2440592]|0)-4|0;c[2440592]=ha;h=ha;break};case 167:{f46();ha=a[9660761]|0;hc=(ha&255)>>>4&8|a[9660784]&-15;a[9660784]=ha<<24>>24==0?hc|4:hc;hc=c[2426864]|0;g5=c[3528554]|0;g6=c[2433592]|0;hb=c[g6+(g5*3148|0)+48+((hc>>>8&255|256)<<2)>>2]|0;do{if((hb|0)==0){g0=c[g6+(g5*3148|0)+3124>>2]|0;if((g0|0)==0){break}gg[g0&4095](hc&65535,ha)}else{a[hb+(hc&255)|0]=ha}}while(0);ha=(c[2440592]|0)-4|0;c[2440592]=ha;h=ha;break};case 168:{f46();ha=c[2426864]|0;hc=c[3528554]|0;hb=c[2433592]|0;g5=c[hb+(hc*3148|0)+48+((ha>>>8&255)<<2)>>2]|0;do{if((g5|0)==0){g6=c[hb+(hc*3148|0)+3120>>2]|0;if((g6|0)==0){hd=0;break}hd=gj[g6&4095](ha&65535)|0}else{hd=a[g5+(ha&255)|0]|0}}while(0);ha=a[9660761]|0;g5=ha^hd;a[9660761]=g5;hc=(g5&255)>>>4&8|a[9660784]&-15;a[9660784]=ha<<24>>24==hd<<24>>24?hc|4:hc;hc=(c[2440592]|0)-4|0;c[2440592]=hc;h=hc;break};case 169:{f46();hc=c[2426864]|0;hd=c[3528554]|0;ha=c[2433592]|0;g5=c[ha+(hd*3148|0)+48+((hc>>>8&255)<<2)>>2]|0;do{if((g5|0)==0){hb=c[ha+(hd*3148|0)+3120>>2]|0;if((hb|0)==0){he=0;break}he=gj[hb&4095](hc&65535)|0}else{he=a[g5+(hc&255)|0]|0}}while(0);hc=a[9660761]|0;g5=a[9660784]|0;hd=(hc&255)+(he&255)+(g5&1)|0;ha=hd^(hc^he)&255;a[9660784]=(ha<<1&32|hd>>>8&1|(ha^hd>>>1)>>>6&2|((hd&255)<<24>>24==0?(hd>>>4&8|g5&-48&255)&255|4:(hd>>>4&8|g5&-48&255)&255)&255)&255;a[9660761]=hd&255;hd=(c[2440592]|0)-4|0;c[2440592]=hd;h=hd;break};case 170:{f46();hd=c[2426864]|0;g5=c[3528554]|0;ha=c[2433592]|0;he=c[ha+(g5*3148|0)+48+((hd>>>8&255)<<2)>>2]|0;do{if((he|0)==0){hc=c[ha+(g5*3148|0)+3120>>2]|0;if((hc|0)==0){hf=0;break}hf=gj[hc&4095](hd&65535)|0}else{hf=a[he+(hd&255)|0]|0}}while(0);hd=a[9660761]|hf;a[9660761]=hd;hf=(hd&255)>>>4&8|a[9660784]&-15;a[9660784]=hd<<24>>24==0?hf|4:hf;hf=(c[2440592]|0)-4|0;c[2440592]=hf;h=hf;break};case 11:{hf=(c[2440592]|0)-2|0;c[2440592]=hf;h=hf;break};case 12:{c[2426864]=c[2415191];hf=c[2415188]|0;hd=c[3528554]|0;he=c[2433592]|0;g5=c[he+(hd*3148|0)+48+((hf>>>8&255)<<2)>>2]|0;do{if((g5|0)==0){ha=c[he+(hd*3148|0)+3132>>2]|0;if((ha|0)==0){hg=0;hh=hf&65535;hi=hd;hj=he;break}hc=gj[ha&4095](hf&65535)|0;hg=hc;hh=b[4830376]|0;hi=c[3528554]|0;hj=c[2433592]|0}else{hg=a[g5+(hf&255)|0]|0;hh=hf&65535;hi=hd;hj=he}}while(0);a[9707456]=hg;b[4830376]=hh+1&65535;hh=c[2426864]|0;hg=c[hj+(hi*3148|0)+48+((hh>>>8&255)<<2)>>2]|0;do{if((hg|0)==0){he=c[hj+(hi*3148|0)+3120>>2]|0;if((he|0)==0){hk=0;hl=hh;hm=hi;hn=hj;break}hd=gj[he&4095](hh&65535)|0;hk=hd;hl=c[2426864]|0;hm=c[3528554]|0;hn=c[2433592]|0}else{hk=a[hg+(hh&255)|0]|0;hl=hh;hm=hi;hn=hj}}while(0);hj=hk+1&255;a[9660784]=a[9660784]&-15|a[668928+(hj&255)|0];hk=hl&65535;hi=c[hn+(hm*3148|0)+48+((hl>>>8&255|256)<<2)>>2]|0;do{if((hi|0)==0){hh=c[hn+(hm*3148|0)+3124>>2]|0;if((hh|0)==0){break}gg[hh&4095](hk,hj)}else{a[hi+(hl&255)|0]=hj}}while(0);hj=(c[2440592]|0)-6|0;c[2440592]=hj;h=hj;break};case 13:{c[2426864]=c[2415191];hj=c[2415188]|0;hl=c[3528554]|0;hi=c[2433592]|0;hk=c[hi+(hl*3148|0)+48+((hj>>>8&255)<<2)>>2]|0;do{if((hk|0)==0){hm=c[hi+(hl*3148|0)+3132>>2]|0;if((hm|0)==0){ho=0;hp=hj&65535;hq=hl;hr=hi;break}hn=gj[hm&4095](hj&65535)|0;ho=hn;hp=b[4830376]|0;hq=c[3528554]|0;hr=c[2433592]|0}else{ho=a[hk+(hj&255)|0]|0;hp=hj&65535;hq=hl;hr=hi}}while(0);a[9707456]=ho;b[4830376]=hp+1&65535;hp=c[2426864]|0;ho=c[hr+(hq*3148|0)+48+((hp>>>8&255)<<2)>>2]|0;do{if((ho|0)==0){hi=c[hr+(hq*3148|0)+3120>>2]|0;if((hi|0)==0){hs=0;break}hs=gj[hi&4095](hp&65535)|0}else{hs=a[ho+(hp&255)|0]|0}}while(0);hp=a[9660784]&-15|(hs&255)>>>4&8;a[9660784]=hs<<24>>24==0?hp|4:hp;hp=(c[2440592]|0)-6|0;c[2440592]=hp;h=hp;break};case 14:{c[2426864]=c[2415191];hp=c[2415188]|0;hs=c[3528554]|0;ho=c[2433592]|0;hq=c[ho+(hs*3148|0)+48+((hp>>>8&255)<<2)>>2]|0;do{if((hq|0)==0){hr=c[ho+(hs*3148|0)+3132>>2]|0;if((hr|0)==0){ht=0;break}ht=gj[hr&4095](hp&65535)|0}else{ht=a[hq+(hp&255)|0]|0}}while(0);a[9707456]=ht;ht=c[2426864]|0;c[2415188]=ht;b[4830376]=ht&65535;ht=(c[2440592]|0)-3|0;c[2440592]=ht;h=ht;break};case 15:{c[2426864]=c[2415191];ht=c[2415188]|0;hp=c[3528554]|0;hq=c[2433592]|0;hs=c[hq+(hp*3148|0)+48+((ht>>>8&255)<<2)>>2]|0;do{if((hs|0)==0){ho=c[hq+(hp*3148|0)+3132>>2]|0;if((ho|0)==0){hu=0;hv=ht&65535;hw=hp;hx=hq;break}hr=gj[ho&4095](ht&65535)|0;hu=hr;hv=b[4830376]|0;hw=c[3528554]|0;hx=c[2433592]|0}else{hu=a[hs+(ht&255)|0]|0;hv=ht&65535;hw=hp;hx=hq}}while(0);a[9707456]=hu;b[4830376]=hv+1&65535;hv=c[2426864]|0;do{if((c[hx+(hw*3148|0)+48+((hv>>>8&255)<<2)>>2]|0)==0){hu=c[hx+(hw*3148|0)+3120>>2]|0;if((hu|0)==0){hy=hv;hz=hw;hA=hx;break}gj[hu&4095](hv&65535)|0;hy=c[2426864]|0;hz=c[3528554]|0;hA=c[2433592]|0}else{hy=hv;hz=hw;hA=hx}}while(0);hx=hy&65535;hw=c[hA+(hz*3148|0)+48+((hy>>>8&255|256)<<2)>>2]|0;do{if((hw|0)==0){hv=c[hA+(hz*3148|0)+3124>>2]|0;if((hv|0)==0){break}gg[hv&4095](hx,0)}else{a[hw+(hy&255)|0]=0}}while(0);a[9660784]=a[9660784]&-16|4;hy=(c[2440592]|0)-6|0;c[2440592]=hy;h=hy;break};default:{j=1}}}c[f+51624>>2]=h;c[f+51656>>2]=i;c[f+51664>>2]=j}function __Z13m6809_executei$2(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0,cf=0,cg=0,ch=0,ci=0,cj=0,ck=0,cl=0,cm=0,cn=0,co=0,cp=0,cq=0,cr=0,cs=0,ct=0,cu=0,cv=0,cw=0,cx=0,cy=0,cz=0,cA=0,cB=0,cC=0,cD=0,cE=0,cF=0,cG=0,cH=0,cI=0,cJ=0,cK=0,cL=0,cM=0,cN=0,cO=0,cP=0,cQ=0,cR=0,cS=0,cT=0,cU=0,cV=0,cW=0,cX=0,cY=0,cZ=0,c_=0,c$=0,c0=0,c1=0,c2=0,c3=0,c4=0,c5=0,c6=0,c7=0,c8=0,c9=0,da=0,db=0,dc=0,dd=0,de=0,df=0,dg=0,dh=0,di=0,dj=0,dk=0,dl=0,dm=0,dn=0,dp=0,dq=0,dr=0,ds=0,dt=0,du=0,dv=0,dw=0,dx=0,dy=0,dz=0,dA=0,dB=0,dC=0,dD=0,dE=0,dF=0,dG=0,dH=0,dI=0,dJ=0,dK=0,dL=0,dM=0,dN=0,dO=0,dP=0,dQ=0,dR=0,dS=0,dT=0,dU=0,dV=0,dW=0,dX=0,dY=0,dZ=0,d_=0,d$=0,d0=0,d1=0,d2=0,d3=0,d4=0,d5=0,d6=0,d7=0,d8=0,d9=0,ea=0,eb=0,ec=0,ed=0,ee=0,ef=0,eg=0,eh=0,ei=0,ej=0,ek=0,el=0,em=0,en=0,eo=0,ep=0,eq=0,er=0,es=0,et=0,eu=0,ev=0,ew=0,ex=0,ey=0,ez=0,eA=0,eB=0,eC=0,eD=0,eE=0,eF=0,eG=0,eH=0,eI=0,eJ=0,eK=0,eL=0,eM=0,eN=0,eO=0,eP=0,eQ=0,eR=0,eS=0,eT=0,eU=0,eV=0,eW=0,eX=0,eY=0,eZ=0,e_=0,e$=0,e0=0,e1=0,e2=0,e3=0,e4=0,e5=0,e6=0,e7=0,e8=0,e9=0,fa=0,fb=0,fc=0,fd=0,fe=0,ff=0,fg=0,fh=0,fi=0,fj=0,fk=0,fl=0,fm=0,fn=0,fo=0,fp=0,fq=0,fr=0,fs=0,ft=0,fu=0,fv=0,fw=0,fx=0,fy=0,fz=0,fA=0,fB=0,fC=0,fD=0,fE=0,fF=0,fG=0,fH=0,fI=0,fJ=0,fK=0,fL=0,fM=0,fN=0,fO=0,fP=0,fQ=0,fR=0,fS=0,fT=0,fU=0,fV=0,fW=0,fX=0,fY=0,fZ=0,f_=0,f$=0,f0=0,f1=0,f2=0,f3=0,f4=0,f5=0,f6=0,f7=0,f8=0,f9=0,ga=0,gb=0,gc=0,gd=0,ge=0,gf=0,gh=0,gi=0,gk=0,gl=0,gm=0,gn=0,go=0,gp=0,gq=0,gr=0,gs=0,gt=0,gu=0,gv=0,gw=0,gx=0,gy=0,gz=0,gA=0,gB=0,gC=0,gD=0,gE=0,gF=0,gG=0,gH=0,gI=0,gJ=0,gK=0,gL=0,gM=0,gN=0,gO=0,gP=0,gQ=0,gR=0,gS=0,gT=0,gU=0,gV=0,gW=0,gX=0,gY=0,gZ=0,g_=0,g$=0,g0=0,g1=0,g2=0,g3=0,g4=0,g5=0,g6=0,g7=0,g8=0,g9=0,ha=0,hb=0,hc=0,hd=0,he=0,hf=0,hg=0,hh=0,hi=0,hj=0,hk=0,hl=0,hm=0,hn=0,ho=0,hp=0,hq=0,hr=0,hs=0,ht=0,hu=0,hv=0,hw=0,hx=0,hy=0,hz=0,hA=0,hB=0,hC=0,hD=0,hE=0,hF=0,hG=0,hH=0,hI=0,hJ=0,hK=0,hL=0,hM=0,hN=0,hO=0,hP=0,hQ=0,hR=0,hS=0,hT=0,hU=0,hV=0,hW=0,hX=0,hY=0,hZ=0,h_=0,h$=0,h0=0,h1=0,h2=0,h3=0,h4=0,h5=0,h6=0,h7=0,h8=0,h9=0,ia=0,ib=0,ic=0,id=0,ie=0,ig=0,ih=0,ii=0,ij=0,ik=0,il=0,im=0,io=0,ip=0,iq=0,ir=0,is=0,it=0,iu=0,iv=0,iw=0,ix=0,iy=0,iz=0,iA=0,iB=0,iC=0,iD=0,iE=0,iF=0,iG=0,iH=0,iI=0,iJ=0,iK=0,iL=0,iM=0,iN=0,iO=0,iP=0,iQ=0,iR=0,iS=0,iT=0,iU=0,iV=0,iW=0,iX=0,iY=0,iZ=0,i_=0,i$=0,i0=0,i1=0,i2=0,i3=0,i4=0;g=c[f+51624>>2]|0;h=c[f+51656>>2]|0;i=c[f+51664>>2]|0;j=c[f+51672>>2]|0;OL:do{if(i){i=0;switch(j|0){case 16:{k=c[2415188]|0;l=c[3528554]|0;m=c[2433592]|0;n=c[m+(l*3148|0)+48+((k>>>8&255|512)<<2)>>2]|0;do{if((n|0)==0){o=c[m+(l*3148|0)+3128>>2]|0;if((o|0)==0){p=0;q=k&65535;break}r=gj[o&4095](k&65535)|0;p=r;q=b[4830376]|0}else{p=a[n+(k&255)|0]|0;q=k&65535}}while(0);k=q+1&65535;b[4830376]=k;n=1;l=p&255|0;if(n){n=0;switch(l|0){case 255:{m=b[4830386]|0;r=(m&65535)>>>12&8|a[9660784]&-15&255;a[9660784]=(m<<16>>16==0?r|4:r)&255;r=c[2415188]|0;m=c[3528554]|0;o=c[2433592]|0;s=c[o+(m*3148|0)+48+((r>>>8&255)<<2)>>2]|0;do{if((s|0)==0){t=c[o+(m*3148|0)+3132>>2]|0;if((t|0)==0){u=0;v=r;w=m;x=o;y=r&65535;break}z=gj[t&4095](r&65535)|0;t=c[2415188]|0;u=z;v=t;w=c[3528554]|0;x=c[2433592]|0;y=t&65535}else{u=a[s+(r&255)|0]|0;v=r;w=m;x=o;y=r&65535}}while(0);r=u&255;o=v+1|0;m=c[x+(w*3148|0)+48+((o>>>8&255)<<2)>>2]|0;do{if((m|0)==0){s=c[x+(w*3148|0)+3132>>2]|0;if((s|0)==0){A=0;B=y;C=w;D=x;break}t=gj[s&4095](o&65535)|0;A=t;B=b[4830376]|0;C=c[3528554]|0;D=c[2433592]|0}else{A=a[m+(o&255)|0]|0;B=y;C=w;D=x}}while(0);o=A&255;c[2426864]=o|r<<8;b[4830376]=B+2&65535;m=a[9660773]|0;t=c[D+(C*3148|0)+48+((r|256)<<2)>>2]|0;do{if((t|0)==0){s=c[D+(C*3148|0)+3124>>2]|0;if((s|0)==0){E=C;F=D;break}gg[s&4095]((o|r<<8)&65535,m);E=c[3528554]|0;F=c[2433592]|0}else{a[t+o|0]=m;E=C;F=D}}while(0);m=a[9660772]|0;t=c[F+(E*3148|0)+48+((((o|r<<8)+1|0)>>>8&255|256)<<2)>>2]|0;do{if((t|0)==0){s=c[F+(E*3148|0)+3124>>2]|0;if((s|0)==0){break}gg[s&4095](((o|r<<8)+1|0)&65535,m)}else{a[t+(((o|r<<8)+1|0)&255)|0]=m}}while(0);m=(c[2440592]|0)-7|0;c[2440592]=m;g=m;c[f+51712>>2]=2;c[f+51716>>2]=45;break OL;break};case 33:{m=c[2415188]|0;r=c[3528554]|0;o=c[2433592]|0;t=c[o+(r*3148|0)+48+((m>>>8&255)<<2)>>2]|0;do{if((t|0)==0){s=c[o+(r*3148|0)+3132>>2]|0;if((s|0)==0){G=0;H=m;I=r;J=o;K=m&65535;break}z=gj[s&4095](m&65535)|0;s=c[2415188]|0;G=z;H=s;I=c[3528554]|0;J=c[2433592]|0;K=s&65535}else{G=a[t+(m&255)|0]|0;H=m;I=r;J=o;K=m&65535}}while(0);m=(G&255)<<8;o=H+1|0;r=c[J+(I*3148|0)+48+((o>>>8&255)<<2)>>2]|0;do{if((r|0)==0){t=c[J+(I*3148|0)+3132>>2]|0;if((t|0)==0){L=0;M=K;break}s=gj[t&4095](o&65535)|0;L=s;M=b[4830376]|0}else{L=a[r+(o&255)|0]|0;M=K}}while(0);c[2426864]=L&255|m;b[4830376]=M+2&65535;o=(c[2440592]|0)-5|0;c[2440592]=o;g=o;c[f+51712>>2]=2;c[f+51716>>2]=45;break OL;break};case 34:{o=c[2415188]|0;r=c[3528554]|0;s=c[2433592]|0;t=c[s+(r*3148|0)+48+((o>>>8&255)<<2)>>2]|0;do{if((t|0)==0){z=c[s+(r*3148|0)+3132>>2]|0;if((z|0)==0){N=0;O=o;P=r;Q=s;R=o&65535;break}S=gj[z&4095](o&65535)|0;z=c[2415188]|0;N=S;O=z;P=c[3528554]|0;Q=c[2433592]|0;R=z&65535}else{N=a[t+(o&255)|0]|0;O=o;P=r;Q=s;R=o&65535}}while(0);o=O+1|0;s=c[Q+(P*3148|0)+48+((o>>>8&255)<<2)>>2]|0;do{if((s|0)==0){r=c[Q+(P*3148|0)+3132>>2]|0;if((r|0)==0){T=0;U=R;break}t=gj[r&4095](o&65535)|0;T=t;U=b[4830376]|0}else{T=a[s+(o&255)|0]|0;U=R}}while(0);o=U+2&65535;b[4830376]=o;if((a[9660784]&5)==0){s=(c[2440592]|0)-1|0;c[2440592]=s;b[4830376]=o+(T&255|(N&255)<<8)&65535;b[4830376]=c[2415188]&65535;V=s}else{V=c[2440592]|0}s=V-5|0;c[2440592]=s;g=s;c[f+51712>>2]=2;c[f+51716>>2]=45;break OL;break};case 131:{s=c[2415188]|0;o=c[3528554]|0;t=c[2433592]|0;r=c[t+(o*3148|0)+48+((s>>>8&255)<<2)>>2]|0;do{if((r|0)==0){m=c[t+(o*3148|0)+3132>>2]|0;if((m|0)==0){W=0;X=s;Y=o;Z=t;_=s&65535;break}z=gj[m&4095](s&65535)|0;m=c[2415188]|0;W=z;X=m;Y=c[3528554]|0;Z=c[2433592]|0;_=m&65535}else{W=a[r+(s&255)|0]|0;X=s;Y=o;Z=t;_=s&65535}}while(0);s=(W&255)<<8;t=X+1|0;o=c[Z+(Y*3148|0)+48+((t>>>8&255)<<2)>>2]|0;do{if((o|0)==0){r=c[Z+(Y*3148|0)+3132>>2]|0;if((r|0)==0){$=0;aa=_;break}m=gj[r&4095](t&65535)|0;$=m;aa=b[4830376]|0}else{$=a[o+(t&255)|0]|0;aa=_}}while(0);b[4830376]=aa+2&65535;t=e[4830380]|0;o=t-($&255|s)|0;m=(o>>>12&8|a[9660784]&-16&255)&255;a[9660784]=((t^s^o^o>>>1)>>>14&2|o>>>16&1|((o&65535)<<16>>16==0?m|4:m)&255)&255;m=(c[2440592]|0)-5|0;c[2440592]=m;g=m;c[f+51712>>2]=2;c[f+51716>>2]=45;break OL;break};case 140:{m=c[2415188]|0;o=c[3528554]|0;t=c[2433592]|0;r=c[t+(o*3148|0)+48+((m>>>8&255)<<2)>>2]|0;do{if((r|0)==0){z=c[t+(o*3148|0)+3132>>2]|0;if((z|0)==0){ab=0;ac=m;ad=o;ae=t;af=m&65535;break}S=gj[z&4095](m&65535)|0;z=c[2415188]|0;ab=S;ac=z;ad=c[3528554]|0;ae=c[2433592]|0;af=z&65535}else{ab=a[r+(m&255)|0]|0;ac=m;ad=o;ae=t;af=m&65535}}while(0);m=(ab&255)<<8;t=ac+1|0;o=c[ae+(ad*3148|0)+48+((t>>>8&255)<<2)>>2]|0;do{if((o|0)==0){r=c[ae+(ad*3148|0)+3132>>2]|0;if((r|0)==0){ag=0;ah=af;break}s=gj[r&4095](t&65535)|0;ag=s;ah=b[4830376]|0}else{ag=a[o+(t&255)|0]|0;ah=af}}while(0);b[4830376]=ah+2&65535;t=e[4830390]|0;o=t-(ag&255|m)|0;s=(o>>>12&8|a[9660784]&-16&255)&255;a[9660784]=((t^m^o^o>>>1)>>>14&2|o>>>16&1|((o&65535)<<16>>16==0?s|4:s)&255)&255;s=(c[2440592]|0)-5|0;c[2440592]=s;g=s;c[f+51712>>2]=2;c[f+51716>>2]=45;break OL;break};case 142:{s=c[2415188]|0;o=c[3528554]|0;t=c[2433592]|0;r=c[t+(o*3148|0)+48+((s>>>8&255)<<2)>>2]|0;do{if((r|0)==0){z=c[t+(o*3148|0)+3132>>2]|0;if((z|0)==0){ai=0;aj=s;ak=o;al=t;am=s&65535;break}S=gj[z&4095](s&65535)|0;z=c[2415188]|0;ai=S;aj=z;ak=c[3528554]|0;al=c[2433592]|0;am=z&65535}else{ai=a[r+(s&255)|0]|0;aj=s;ak=o;al=t;am=s&65535}}while(0);s=ai&255;t=aj+1|0;o=c[al+(ak*3148|0)+48+((t>>>8&255)<<2)>>2]|0;do{if((o|0)==0){r=c[al+(ak*3148|0)+3132>>2]|0;if((r|0)==0){an=0;ao=am;break}m=gj[r&4095](t&65535)|0;an=m;ao=b[4830376]|0}else{an=a[o+(t&255)|0]|0;ao=am}}while(0);t=an&255|s<<8;c[2415195]=t;b[4830376]=ao+2&65535;o=a[9660784]&-15;a[9660784]=o;if((t|0)==0){ap=(o&255|s>>>4&8|4)&255}else{ap=(o&255|s>>>4&8)&255}a[9660784]=ap;o=(c[2440592]|0)-4|0;c[2440592]=o;g=o;c[f+51712>>2]=2;c[f+51716>>2]=45;break OL;break};case 143:{o=b[4830390]|0;t=(o&65535)>>>12&8|a[9660784]&-15&255;a[9660784]=(o<<16>>16==0?t|4:t)&255;t=c[2415188]|0;c[2426864]=t;b[4830376]=(t&65535)+2&65535;o=a[9660781]|0;m=c[3528554]|0;r=c[2433592]|0;z=c[r+(m*3148|0)+48+((t>>>8&255|256)<<2)>>2]|0;do{if((z|0)==0){S=c[r+(m*3148|0)+3124>>2]|0;if((S|0)==0){aq=m;ar=r;break}gg[S&4095](t&65535,o);aq=c[3528554]|0;ar=c[2433592]|0}else{a[z+(t&255)|0]=o;aq=m;ar=r}}while(0);r=a[9660780]|0;m=c[ar+(aq*3148|0)+48+(((t+1|0)>>>8&255|256)<<2)>>2]|0;do{if((m|0)==0){o=c[ar+(aq*3148|0)+3124>>2]|0;if((o|0)==0){break}gg[o&4095]((t+1|0)&65535,r)}else{a[m+((t+1|0)&255)|0]=r}}while(0);r=(c[2440592]|0)-4|0;c[2440592]=r;g=r;c[f+51712>>2]=2;c[f+51716>>2]=45;break OL;break};case 147:{c[2426864]=c[2415191];r=c[2415188]|0;t=c[3528554]|0;m=c[2433592]|0;o=c[m+(t*3148|0)+48+((r>>>8&255)<<2)>>2]|0;do{if((o|0)==0){z=c[m+(t*3148|0)+3132>>2]|0;if((z|0)==0){as=0;at=r&65535;au=t;av=m;break}s=gj[z&4095](r&65535)|0;as=s;at=b[4830376]|0;au=c[3528554]|0;av=c[2433592]|0}else{as=a[o+(r&255)|0]|0;at=r&65535;au=t;av=m}}while(0);a[9707456]=as;b[4830376]=at+1&65535;m=c[2426864]|0;t=c[av+(au*3148|0)+48+((m>>>8&255)<<2)>>2]|0;do{if((t|0)==0){r=c[av+(au*3148|0)+3120>>2]|0;if((r|0)==0){aw=0;ax=au;ay=av;break}o=gj[r&4095](m&65535)|0;aw=o;ax=c[3528554]|0;ay=c[2433592]|0}else{aw=a[t+(m&255)|0]|0;ax=au;ay=av}}while(0);t=(aw&255)<<8;o=c[ay+(ax*3148|0)+48+(((m+1|0)>>>8&255)<<2)>>2]|0;do{if((o|0)==0){r=c[ay+(ax*3148|0)+3120>>2]|0;if((r|0)==0){az=0;break}az=gj[r&4095]((m+1|0)&65535)|0}else{az=a[o+((m+1|0)&255)|0]|0}}while(0);m=e[4830380]|0;o=m-(az&255|t)|0;r=(o>>>12&8|a[9660784]&-16&255)&255;a[9660784]=((m^t^o^o>>>1)>>>14&2|o>>>16&1|((o&65535)<<16>>16==0?r|4:r)&255)&255;r=(c[2440592]|0)-7|0;c[2440592]=r;g=r;c[f+51712>>2]=2;c[f+51716>>2]=45;break OL;break};case 156:{c[2426864]=c[2415191];r=c[2415188]|0;o=c[3528554]|0;m=c[2433592]|0;s=c[m+(o*3148|0)+48+((r>>>8&255)<<2)>>2]|0;do{if((s|0)==0){z=c[m+(o*3148|0)+3132>>2]|0;if((z|0)==0){aA=0;aB=r&65535;aC=o;aD=m;break}S=gj[z&4095](r&65535)|0;aA=S;aB=b[4830376]|0;aC=c[3528554]|0;aD=c[2433592]|0}else{aA=a[s+(r&255)|0]|0;aB=r&65535;aC=o;aD=m}}while(0);a[9707456]=aA;b[4830376]=aB+1&65535;m=c[2426864]|0;o=c[aD+(aC*3148|0)+48+((m>>>8&255)<<2)>>2]|0;do{if((o|0)==0){r=c[aD+(aC*3148|0)+3120>>2]|0;if((r|0)==0){aE=0;aF=aC;aG=aD;break}s=gj[r&4095](m&65535)|0;aE=s;aF=c[3528554]|0;aG=c[2433592]|0}else{aE=a[o+(m&255)|0]|0;aF=aC;aG=aD}}while(0);o=(aE&255)<<8;s=c[aG+(aF*3148|0)+48+(((m+1|0)>>>8&255)<<2)>>2]|0;do{if((s|0)==0){r=c[aG+(aF*3148|0)+3120>>2]|0;if((r|0)==0){aH=0;break}aH=gj[r&4095]((m+1|0)&65535)|0}else{aH=a[s+((m+1|0)&255)|0]|0}}while(0);m=e[4830390]|0;s=m-(aH&255|o)|0;r=(s>>>12&8|a[9660784]&-16&255)&255;a[9660784]=((m^o^s^s>>>1)>>>14&2|s>>>16&1|((s&65535)<<16>>16==0?r|4:r)&255)&255;r=(c[2440592]|0)-7|0;c[2440592]=r;g=r;c[f+51712>>2]=2;c[f+51716>>2]=45;break OL;break};case 158:{c[2426864]=c[2415191];r=c[2415188]|0;s=c[3528554]|0;m=c[2433592]|0;t=c[m+(s*3148|0)+48+((r>>>8&255)<<2)>>2]|0;do{if((t|0)==0){S=c[m+(s*3148|0)+3132>>2]|0;if((S|0)==0){aI=0;aJ=r&65535;aK=s;aL=m;break}z=gj[S&4095](r&65535)|0;aI=z;aJ=b[4830376]|0;aK=c[3528554]|0;aL=c[2433592]|0}else{aI=a[t+(r&255)|0]|0;aJ=r&65535;aK=s;aL=m}}while(0);a[9707456]=aI;b[4830376]=aJ+1&65535;m=c[2426864]|0;s=c[aL+(aK*3148|0)+48+((m>>>8&255)<<2)>>2]|0;do{if((s|0)==0){r=c[aL+(aK*3148|0)+3120>>2]|0;if((r|0)==0){aM=0;aN=aK;aO=aL;break}t=gj[r&4095](m&65535)|0;aM=t;aN=c[3528554]|0;aO=c[2433592]|0}else{aM=a[s+(m&255)|0]|0;aN=aK;aO=aL}}while(0);s=aM&255;t=c[aO+(aN*3148|0)+48+(((m+1|0)>>>8&255)<<2)>>2]|0;do{if((t|0)==0){r=c[aO+(aN*3148|0)+3120>>2]|0;if((r|0)==0){aP=0;break}aP=gj[r&4095]((m+1|0)&65535)|0}else{aP=a[t+((m+1|0)&255)|0]|0}}while(0);m=aP&255|s<<8;c[2415195]=m;t=a[9660784]&-15;a[9660784]=t;if((m|0)==0){aQ=(t&255|s>>>4&8|4)&255}else{aQ=(t&255|s>>>4&8)&255}a[9660784]=aQ;t=(c[2440592]|0)-6|0;c[2440592]=t;g=t;c[f+51712>>2]=2;c[f+51716>>2]=45;break OL;break};case 159:{t=b[4830390]|0;m=(t&65535)>>>12&8|a[9660784]&-15&255;a[9660784]=(t<<16>>16==0?m|4:m)&255;c[2426864]=c[2415191];m=c[2415188]|0;t=c[3528554]|0;r=c[2433592]|0;o=c[r+(t*3148|0)+48+((m>>>8&255)<<2)>>2]|0;do{if((o|0)==0){z=c[r+(t*3148|0)+3132>>2]|0;if((z|0)==0){aR=0;aS=m&65535;aT=t;aU=r;break}S=gj[z&4095](m&65535)|0;aR=S;aS=b[4830376]|0;aT=c[3528554]|0;aU=c[2433592]|0}else{aR=a[o+(m&255)|0]|0;aS=m&65535;aT=t;aU=r}}while(0);a[9707456]=aR;b[4830376]=aS+1&65535;r=c[2426864]|0;t=a[9660781]|0;m=c[aU+(aT*3148|0)+48+((r>>>8&255|256)<<2)>>2]|0;do{if((m|0)==0){o=c[aU+(aT*3148|0)+3124>>2]|0;if((o|0)==0){aV=aT;aW=aU;break}gg[o&4095](r&65535,t);aV=c[3528554]|0;aW=c[2433592]|0}else{a[m+(r&255)|0]=t;aV=aT;aW=aU}}while(0);t=a[9660780]|0;m=c[aW+(aV*3148|0)+48+(((r+1|0)>>>8&255|256)<<2)>>2]|0;do{if((m|0)==0){o=c[aW+(aV*3148|0)+3124>>2]|0;if((o|0)==0){break}gg[o&4095]((r+1|0)&65535,t)}else{a[m+((r+1|0)&255)|0]=t}}while(0);t=(c[2440592]|0)-6|0;c[2440592]=t;g=t;c[f+51712>>2]=2;c[f+51716>>2]=45;break OL;break};case 163:{f46();t=c[2426864]|0;r=c[3528554]|0;m=c[2433592]|0;o=c[m+(r*3148|0)+48+((t>>>8&255)<<2)>>2]|0;do{if((o|0)==0){s=c[m+(r*3148|0)+3120>>2]|0;if((s|0)==0){aX=0;aY=r;aZ=m;break}S=gj[s&4095](t&65535)|0;aX=S;aY=c[3528554]|0;aZ=c[2433592]|0}else{aX=a[o+(t&255)|0]|0;aY=r;aZ=m}}while(0);m=(aX&255)<<8;r=c[aZ+(aY*3148|0)+48+(((t+1|0)>>>8&255)<<2)>>2]|0;do{if((r|0)==0){o=c[aZ+(aY*3148|0)+3120>>2]|0;if((o|0)==0){a_=0;break}a_=gj[o&4095]((t+1|0)&65535)|0}else{a_=a[r+((t+1|0)&255)|0]|0}}while(0);t=e[4830380]|0;r=t-(a_&255|m)|0;o=(r>>>12&8|a[9660784]&-16&255)&255;a[9660784]=((t^m^r^r>>>1)>>>14&2|r>>>16&1|((r&65535)<<16>>16==0?o|4:o)&255)&255;o=(c[2440592]|0)-7|0;c[2440592]=o;g=o;c[f+51712>>2]=2;c[f+51716>>2]=45;break OL;break};case 172:{f46();o=c[2426864]|0;r=c[3528554]|0;t=c[2433592]|0;S=c[t+(r*3148|0)+48+((o>>>8&255)<<2)>>2]|0;do{if((S|0)==0){s=c[t+(r*3148|0)+3120>>2]|0;if((s|0)==0){a$=0;a0=r;a1=t;break}z=gj[s&4095](o&65535)|0;a$=z;a0=c[3528554]|0;a1=c[2433592]|0}else{a$=a[S+(o&255)|0]|0;a0=r;a1=t}}while(0);t=(a$&255)<<8;r=c[a1+(a0*3148|0)+48+(((o+1|0)>>>8&255)<<2)>>2]|0;do{if((r|0)==0){S=c[a1+(a0*3148|0)+3120>>2]|0;if((S|0)==0){a2=0;break}a2=gj[S&4095]((o+1|0)&65535)|0}else{a2=a[r+((o+1|0)&255)|0]|0}}while(0);o=e[4830390]|0;r=o-(a2&255|t)|0;S=(r>>>12&8|a[9660784]&-16&255)&255;a[9660784]=((o^t^r^r>>>1)>>>14&2|r>>>16&1|((r&65535)<<16>>16==0?S|4:S)&255)&255;S=(c[2440592]|0)-7|0;c[2440592]=S;g=S;c[f+51712>>2]=2;c[f+51716>>2]=45;break OL;break};case 174:{f46();S=c[2426864]|0;r=c[3528554]|0;o=c[2433592]|0;m=c[o+(r*3148|0)+48+((S>>>8&255)<<2)>>2]|0;do{if((m|0)==0){z=c[o+(r*3148|0)+3120>>2]|0;if((z|0)==0){a3=0;a4=r;a5=o;break}s=gj[z&4095](S&65535)|0;a3=s;a4=c[3528554]|0;a5=c[2433592]|0}else{a3=a[m+(S&255)|0]|0;a4=r;a5=o}}while(0);o=(a3&255)<<8;r=c[a5+(a4*3148|0)+48+(((S+1|0)>>>8&255)<<2)>>2]|0;do{if((r|0)==0){m=c[a5+(a4*3148|0)+3120>>2]|0;if((m|0)==0){a6=0;break}a6=gj[m&4095]((S+1|0)&65535)|0}else{a6=a[r+((S+1|0)&255)|0]|0}}while(0);S=a6&255|o;b[4830390]=S;r=a[9660784]&-15;a[9660784]=r;if(S<<16>>16==0){a7=(r&255|(o&65535)>>>12&8|4)&255}else{a7=(r&255|(o&65535)>>>12&8)&255}a[9660784]=a7;r=(c[2440592]|0)-6|0;c[2440592]=r;g=r;c[f+51712>>2]=2;c[f+51716>>2]=45;break OL;break};case 175:{f46();r=a[9660784]&-15;a[9660784]=r;S=b[4830390]|0;if(S<<16>>16==0){a8=((S&65535)>>>12&8|r&255|4)&255}else{a8=((S&65535)>>>12&8|r&255)&255}a[9660784]=a8;r=c[2426864]|0;S=a[9660781]|0;m=c[3528554]|0;t=c[2433592]|0;s=c[t+(m*3148|0)+48+((r>>>8&255|256)<<2)>>2]|0;do{if((s|0)==0){z=c[t+(m*3148|0)+3124>>2]|0;if((z|0)==0){a9=m;ba=t;break}gg[z&4095](r&65535,S);a9=c[3528554]|0;ba=c[2433592]|0}else{a[s+(r&255)|0]=S;a9=m;ba=t}}while(0);t=a[9660780]|0;m=c[ba+(a9*3148|0)+48+(((r+1|0)>>>8&255|256)<<2)>>2]|0;do{if((m|0)==0){S=c[ba+(a9*3148|0)+3124>>2]|0;if((S|0)==0){break}gg[S&4095]((r+1|0)&65535,t)}else{a[m+((r+1|0)&255)|0]=t}}while(0);t=(c[2440592]|0)-6|0;c[2440592]=t;g=t;c[f+51712>>2]=2;c[f+51716>>2]=45;break OL;break};case 179:{t=c[2415188]|0;r=c[3528554]|0;m=c[2433592]|0;S=c[m+(r*3148|0)+48+((t>>>8&255)<<2)>>2]|0;do{if((S|0)==0){s=c[m+(r*3148|0)+3132>>2]|0;if((s|0)==0){bb=0;bc=t;bd=r;be=m;bf=t&65535;break}o=gj[s&4095](t&65535)|0;s=c[2415188]|0;bb=o;bc=s;bd=c[3528554]|0;be=c[2433592]|0;bf=s&65535}else{bb=a[S+(t&255)|0]|0;bc=t;bd=r;be=m;bf=t&65535}}while(0);t=bb&255;m=bc+1|0;r=c[be+(bd*3148|0)+48+((m>>>8&255)<<2)>>2]|0;do{if((r|0)==0){S=c[be+(bd*3148|0)+3132>>2]|0;if((S|0)==0){bg=0;bh=bf;bi=bd;bj=be;break}s=gj[S&4095](m&65535)|0;bg=s;bh=b[4830376]|0;bi=c[3528554]|0;bj=c[2433592]|0}else{bg=a[r+(m&255)|0]|0;bh=bf;bi=bd;bj=be}}while(0);m=bg&255;c[2426864]=m|t<<8;b[4830376]=bh+2&65535;r=c[bj+(bi*3148|0)+48+(t<<2)>>2]|0;do{if((r|0)==0){s=c[bj+(bi*3148|0)+3120>>2]|0;if((s|0)==0){bk=0;bl=bi;bm=bj;break}S=gj[s&4095]((m|t<<8)&65535)|0;bk=S;bl=c[3528554]|0;bm=c[2433592]|0}else{bk=a[r+m|0]|0;bl=bi;bm=bj}}while(0);r=(bk&255)<<8;S=c[bm+(bl*3148|0)+48+((((m|t<<8)+1|0)>>>8&255)<<2)>>2]|0;do{if((S|0)==0){s=c[bm+(bl*3148|0)+3120>>2]|0;if((s|0)==0){bn=0;break}bn=gj[s&4095](((m|t<<8)+1|0)&65535)|0}else{bn=a[S+(((m|t<<8)+1|0)&255)|0]|0}}while(0);t=e[4830380]|0;m=t-(bn&255|r)|0;S=(m>>>12&8|a[9660784]&-16&255)&255;a[9660784]=((t^r^m^m>>>1)>>>14&2|m>>>16&1|((m&65535)<<16>>16==0?S|4:S)&255)&255;S=(c[2440592]|0)-8|0;c[2440592]=S;g=S;c[f+51712>>2]=2;c[f+51716>>2]=45;break OL;break};case 188:{S=c[2415188]|0;m=c[3528554]|0;t=c[2433592]|0;s=c[t+(m*3148|0)+48+((S>>>8&255)<<2)>>2]|0;do{if((s|0)==0){o=c[t+(m*3148|0)+3132>>2]|0;if((o|0)==0){bo=0;bp=S;bq=m;br=t;bs=S&65535;break}z=gj[o&4095](S&65535)|0;o=c[2415188]|0;bo=z;bp=o;bq=c[3528554]|0;br=c[2433592]|0;bs=o&65535}else{bo=a[s+(S&255)|0]|0;bp=S;bq=m;br=t;bs=S&65535}}while(0);S=bo&255;t=bp+1|0;m=c[br+(bq*3148|0)+48+((t>>>8&255)<<2)>>2]|0;do{if((m|0)==0){s=c[br+(bq*3148|0)+3132>>2]|0;if((s|0)==0){bt=0;bu=bs;bv=bq;bw=br;break}r=gj[s&4095](t&65535)|0;bt=r;bu=b[4830376]|0;bv=c[3528554]|0;bw=c[2433592]|0}else{bt=a[m+(t&255)|0]|0;bu=bs;bv=bq;bw=br}}while(0);t=bt&255;c[2426864]=t|S<<8;b[4830376]=bu+2&65535;m=c[bw+(bv*3148|0)+48+(S<<2)>>2]|0;do{if((m|0)==0){r=c[bw+(bv*3148|0)+3120>>2]|0;if((r|0)==0){bx=0;by=bv;bz=bw;break}s=gj[r&4095]((t|S<<8)&65535)|0;bx=s;by=c[3528554]|0;bz=c[2433592]|0}else{bx=a[m+t|0]|0;by=bv;bz=bw}}while(0);m=(bx&255)<<8;s=c[bz+(by*3148|0)+48+((((t|S<<8)+1|0)>>>8&255)<<2)>>2]|0;do{if((s|0)==0){r=c[bz+(by*3148|0)+3120>>2]|0;if((r|0)==0){bA=0;break}bA=gj[r&4095](((t|S<<8)+1|0)&65535)|0}else{bA=a[s+(((t|S<<8)+1|0)&255)|0]|0}}while(0);S=e[4830390]|0;t=S-(bA&255|m)|0;s=(t>>>12&8|a[9660784]&-16&255)&255;a[9660784]=((S^m^t^t>>>1)>>>14&2|t>>>16&1|((t&65535)<<16>>16==0?s|4:s)&255)&255;s=(c[2440592]|0)-8|0;c[2440592]=s;g=s;c[f+51712>>2]=2;c[f+51716>>2]=45;break OL;break};case 190:{s=c[2415188]|0;t=c[3528554]|0;S=c[2433592]|0;r=c[S+(t*3148|0)+48+((s>>>8&255)<<2)>>2]|0;do{if((r|0)==0){o=c[S+(t*3148|0)+3132>>2]|0;if((o|0)==0){bB=0;bC=s;bD=t;bE=S;bF=s&65535;break}z=gj[o&4095](s&65535)|0;o=c[2415188]|0;bB=z;bC=o;bD=c[3528554]|0;bE=c[2433592]|0;bF=o&65535}else{bB=a[r+(s&255)|0]|0;bC=s;bD=t;bE=S;bF=s&65535}}while(0);s=bB&255;S=bC+1|0;t=c[bE+(bD*3148|0)+48+((S>>>8&255)<<2)>>2]|0;do{if((t|0)==0){r=c[bE+(bD*3148|0)+3132>>2]|0;if((r|0)==0){bG=0;bH=bF;bI=bD;bJ=bE;break}m=gj[r&4095](S&65535)|0;bG=m;bH=b[4830376]|0;bI=c[3528554]|0;bJ=c[2433592]|0}else{bG=a[t+(S&255)|0]|0;bH=bF;bI=bD;bJ=bE}}while(0);S=bG&255;c[2426864]=S|s<<8;b[4830376]=bH+2&65535;t=c[bJ+(bI*3148|0)+48+(s<<2)>>2]|0;do{if((t|0)==0){m=c[bJ+(bI*3148|0)+3120>>2]|0;if((m|0)==0){bK=0;bL=bI;bM=bJ;break}r=gj[m&4095]((S|s<<8)&65535)|0;bK=r;bL=c[3528554]|0;bM=c[2433592]|0}else{bK=a[t+S|0]|0;bL=bI;bM=bJ}}while(0);t=bK&255;r=c[bM+(bL*3148|0)+48+((((S|s<<8)+1|0)>>>8&255)<<2)>>2]|0;do{if((r|0)==0){m=c[bM+(bL*3148|0)+3120>>2]|0;if((m|0)==0){bN=0;break}bN=gj[m&4095](((S|s<<8)+1|0)&65535)|0}else{bN=a[r+(((S|s<<8)+1|0)&255)|0]|0}}while(0);s=bN&255|t<<8;c[2415195]=s;S=a[9660784]&-15;a[9660784]=S;if((s|0)==0){bO=(S&255|t>>>4&8|4)&255}else{bO=(S&255|t>>>4&8)&255}a[9660784]=bO;S=(c[2440592]|0)-7|0;c[2440592]=S;g=S;c[f+51712>>2]=2;c[f+51716>>2]=45;break OL;break};case 191:{S=b[4830390]|0;s=(S&65535)>>>12&8|a[9660784]&-15&255;a[9660784]=(S<<16>>16==0?s|4:s)&255;s=c[2415188]|0;S=c[3528554]|0;r=c[2433592]|0;m=c[r+(S*3148|0)+48+((s>>>8&255)<<2)>>2]|0;do{if((m|0)==0){o=c[r+(S*3148|0)+3132>>2]|0;if((o|0)==0){bP=0;bQ=s;bR=S;bS=r;bT=s&65535;break}z=gj[o&4095](s&65535)|0;o=c[2415188]|0;bP=z;bQ=o;bR=c[3528554]|0;bS=c[2433592]|0;bT=o&65535}else{bP=a[m+(s&255)|0]|0;bQ=s;bR=S;bS=r;bT=s&65535}}while(0);s=bP&255;r=bQ+1|0;S=c[bS+(bR*3148|0)+48+((r>>>8&255)<<2)>>2]|0;do{if((S|0)==0){m=c[bS+(bR*3148|0)+3132>>2]|0;if((m|0)==0){bU=0;bV=bT;bW=bR;bX=bS;break}t=gj[m&4095](r&65535)|0;bU=t;bV=b[4830376]|0;bW=c[3528554]|0;bX=c[2433592]|0}else{bU=a[S+(r&255)|0]|0;bV=bT;bW=bR;bX=bS}}while(0);r=bU&255;c[2426864]=r|s<<8;b[4830376]=bV+2&65535;S=a[9660781]|0;t=c[bX+(bW*3148|0)+48+((s|256)<<2)>>2]|0;do{if((t|0)==0){m=c[bX+(bW*3148|0)+3124>>2]|0;if((m|0)==0){bY=bW;bZ=bX;break}gg[m&4095]((r|s<<8)&65535,S);bY=c[3528554]|0;bZ=c[2433592]|0}else{a[t+r|0]=S;bY=bW;bZ=bX}}while(0);S=a[9660780]|0;t=c[bZ+(bY*3148|0)+48+((((r|s<<8)+1|0)>>>8&255|256)<<2)>>2]|0;do{if((t|0)==0){m=c[bZ+(bY*3148|0)+3124>>2]|0;if((m|0)==0){break}gg[m&4095](((r|s<<8)+1|0)&65535,S)}else{a[t+(((r|s<<8)+1|0)&255)|0]=S}}while(0);S=(c[2440592]|0)-7|0;c[2440592]=S;g=S;c[f+51712>>2]=2;c[f+51716>>2]=45;break OL;break};case 206:{S=c[2415188]|0;s=c[3528554]|0;r=c[2433592]|0;t=c[r+(s*3148|0)+48+((S>>>8&255)<<2)>>2]|0;do{if((t|0)==0){m=c[r+(s*3148|0)+3132>>2]|0;if((m|0)==0){b_=0;b$=S;b0=s;b1=r;b2=S&65535;break}o=gj[m&4095](S&65535)|0;m=c[2415188]|0;b_=o;b$=m;b0=c[3528554]|0;b1=c[2433592]|0;b2=m&65535}else{b_=a[t+(S&255)|0]|0;b$=S;b0=s;b1=r;b2=S&65535}}while(0);S=b_&255;r=b$+1|0;s=c[b1+(b0*3148|0)+48+((r>>>8&255)<<2)>>2]|0;do{if((s|0)==0){t=c[b1+(b0*3148|0)+3132>>2]|0;if((t|0)==0){b3=0;b4=b2;break}m=gj[t&4095](r&65535)|0;b3=m;b4=b[4830376]|0}else{b3=a[s+(r&255)|0]|0;b4=b2}}while(0);r=b3&255|S<<8;c[2415193]=r;b[4830376]=b4+2&65535;s=a[9660784]&-15;a[9660784]=s;if((r|0)==0){b5=(s&255|S>>>4&8|4)&255}else{b5=(s&255|S>>>4&8)&255}a[9660784]=b5;a[9660796]=a[9660796]|32;s=(c[2440592]|0)-4|0;c[2440592]=s;g=s;c[f+51712>>2]=2;c[f+51716>>2]=45;break OL;break};default:{n=1}}}if(n){n=0;switch(l|0){case 207:{s=b[4830386]|0;r=(s&65535)>>>12&8|a[9660784]&-15&255;a[9660784]=(s<<16>>16==0?r|4:r)&255;r=c[2415188]|0;c[2426864]=r;b[4830376]=(r&65535)+2&65535;s=a[9660773]|0;m=c[3528554]|0;t=c[2433592]|0;o=c[t+(m*3148|0)+48+((r>>>8&255|256)<<2)>>2]|0;do{if((o|0)==0){z=c[t+(m*3148|0)+3124>>2]|0;if((z|0)==0){b6=m;b7=t;break}gg[z&4095](r&65535,s);b6=c[3528554]|0;b7=c[2433592]|0}else{a[o+(r&255)|0]=s;b6=m;b7=t}}while(0);t=a[9660772]|0;m=c[b7+(b6*3148|0)+48+(((r+1|0)>>>8&255|256)<<2)>>2]|0;do{if((m|0)==0){s=c[b7+(b6*3148|0)+3124>>2]|0;if((s|0)==0){break}gg[s&4095]((r+1|0)&65535,t)}else{a[m+((r+1|0)&255)|0]=t}}while(0);t=(c[2440592]|0)-4|0;c[2440592]=t;g=t;c[f+51712>>2]=2;c[f+51716>>2]=45;break OL;break};case 222:{c[2426864]=c[2415191];t=c[2415188]|0;r=c[3528554]|0;m=c[2433592]|0;s=c[m+(r*3148|0)+48+((t>>>8&255)<<2)>>2]|0;do{if((s|0)==0){o=c[m+(r*3148|0)+3132>>2]|0;if((o|0)==0){b8=0;b9=t&65535;ca=r;cb=m;break}S=gj[o&4095](t&65535)|0;b8=S;b9=b[4830376]|0;ca=c[3528554]|0;cb=c[2433592]|0}else{b8=a[s+(t&255)|0]|0;b9=t&65535;ca=r;cb=m}}while(0);a[9707456]=b8;b[4830376]=b9+1&65535;m=c[2426864]|0;r=c[cb+(ca*3148|0)+48+((m>>>8&255)<<2)>>2]|0;do{if((r|0)==0){t=c[cb+(ca*3148|0)+3120>>2]|0;if((t|0)==0){cc=0;cd=ca;ce=cb;break}s=gj[t&4095](m&65535)|0;cc=s;cd=c[3528554]|0;ce=c[2433592]|0}else{cc=a[r+(m&255)|0]|0;cd=ca;ce=cb}}while(0);r=cc&255;s=c[ce+(cd*3148|0)+48+(((m+1|0)>>>8&255)<<2)>>2]|0;do{if((s|0)==0){t=c[ce+(cd*3148|0)+3120>>2]|0;if((t|0)==0){cf=0;break}cf=gj[t&4095]((m+1|0)&65535)|0}else{cf=a[s+((m+1|0)&255)|0]|0}}while(0);m=cf&255|r<<8;c[2415193]=m;s=a[9660784]&-15;a[9660784]=s;if((m|0)==0){cg=(s&255|r>>>4&8|4)&255}else{cg=(s&255|r>>>4&8)&255}a[9660784]=cg;a[9660796]=a[9660796]|32;s=(c[2440592]|0)-6|0;c[2440592]=s;g=s;c[f+51712>>2]=2;c[f+51716>>2]=45;break OL;break};case 223:{s=b[4830386]|0;m=(s&65535)>>>12&8|a[9660784]&-15&255;a[9660784]=(s<<16>>16==0?m|4:m)&255;c[2426864]=c[2415191];m=c[2415188]|0;s=c[3528554]|0;t=c[2433592]|0;S=c[t+(s*3148|0)+48+((m>>>8&255)<<2)>>2]|0;do{if((S|0)==0){o=c[t+(s*3148|0)+3132>>2]|0;if((o|0)==0){ch=0;ci=m&65535;cj=s;ck=t;break}z=gj[o&4095](m&65535)|0;ch=z;ci=b[4830376]|0;cj=c[3528554]|0;ck=c[2433592]|0}else{ch=a[S+(m&255)|0]|0;ci=m&65535;cj=s;ck=t}}while(0);a[9707456]=ch;b[4830376]=ci+1&65535;t=c[2426864]|0;s=a[9660773]|0;m=c[ck+(cj*3148|0)+48+((t>>>8&255|256)<<2)>>2]|0;do{if((m|0)==0){S=c[ck+(cj*3148|0)+3124>>2]|0;if((S|0)==0){cl=cj;cm=ck;break}gg[S&4095](t&65535,s);cl=c[3528554]|0;cm=c[2433592]|0}else{a[m+(t&255)|0]=s;cl=cj;cm=ck}}while(0);s=a[9660772]|0;m=c[cm+(cl*3148|0)+48+(((t+1|0)>>>8&255|256)<<2)>>2]|0;do{if((m|0)==0){S=c[cm+(cl*3148|0)+3124>>2]|0;if((S|0)==0){break}gg[S&4095]((t+1|0)&65535,s)}else{a[m+((t+1|0)&255)|0]=s}}while(0);s=(c[2440592]|0)-6|0;c[2440592]=s;g=s;c[f+51712>>2]=2;c[f+51716>>2]=45;break OL;break};case 238:{f46();s=c[2426864]|0;t=c[3528554]|0;m=c[2433592]|0;S=c[m+(t*3148|0)+48+((s>>>8&255)<<2)>>2]|0;do{if((S|0)==0){r=c[m+(t*3148|0)+3120>>2]|0;if((r|0)==0){cn=0;co=t;cp=m;break}z=gj[r&4095](s&65535)|0;cn=z;co=c[3528554]|0;cp=c[2433592]|0}else{cn=a[S+(s&255)|0]|0;co=t;cp=m}}while(0);m=(cn&255)<<8;t=c[cp+(co*3148|0)+48+(((s+1|0)>>>8&255)<<2)>>2]|0;do{if((t|0)==0){S=c[cp+(co*3148|0)+3120>>2]|0;if((S|0)==0){cq=0;break}cq=gj[S&4095]((s+1|0)&65535)|0}else{cq=a[t+((s+1|0)&255)|0]|0}}while(0);s=cq&255|m;b[4830386]=s;t=a[9660784]&-15;a[9660784]=t;if(s<<16>>16==0){cr=(t&255|(m&65535)>>>12&8|4)&255}else{cr=(t&255|(m&65535)>>>12&8)&255}a[9660784]=cr;a[9660796]=a[9660796]|32;t=(c[2440592]|0)-6|0;c[2440592]=t;g=t;c[f+51712>>2]=2;c[f+51716>>2]=45;break OL;break};case 239:{f46();t=a[9660784]&-15;a[9660784]=t;s=b[4830386]|0;if(s<<16>>16==0){cs=((s&65535)>>>12&8|t&255|4)&255}else{cs=((s&65535)>>>12&8|t&255)&255}a[9660784]=cs;t=c[2426864]|0;s=a[9660773]|0;S=c[3528554]|0;z=c[2433592]|0;r=c[z+(S*3148|0)+48+((t>>>8&255|256)<<2)>>2]|0;do{if((r|0)==0){o=c[z+(S*3148|0)+3124>>2]|0;if((o|0)==0){ct=S;cu=z;break}gg[o&4095](t&65535,s);ct=c[3528554]|0;cu=c[2433592]|0}else{a[r+(t&255)|0]=s;ct=S;cu=z}}while(0);z=a[9660772]|0;S=c[cu+(ct*3148|0)+48+(((t+1|0)>>>8&255|256)<<2)>>2]|0;do{if((S|0)==0){s=c[cu+(ct*3148|0)+3124>>2]|0;if((s|0)==0){break}gg[s&4095]((t+1|0)&65535,z)}else{a[S+((t+1|0)&255)|0]=z}}while(0);z=(c[2440592]|0)-6|0;c[2440592]=z;g=z;c[f+51712>>2]=2;c[f+51716>>2]=45;break OL;break};case 254:{z=c[2415188]|0;t=c[3528554]|0;S=c[2433592]|0;s=c[S+(t*3148|0)+48+((z>>>8&255)<<2)>>2]|0;do{if((s|0)==0){r=c[S+(t*3148|0)+3132>>2]|0;if((r|0)==0){cv=0;cw=z;cx=t;cy=S;cz=z&65535;break}m=gj[r&4095](z&65535)|0;r=c[2415188]|0;cv=m;cw=r;cx=c[3528554]|0;cy=c[2433592]|0;cz=r&65535}else{cv=a[s+(z&255)|0]|0;cw=z;cx=t;cy=S;cz=z&65535}}while(0);z=cv&255;S=cw+1|0;t=c[cy+(cx*3148|0)+48+((S>>>8&255)<<2)>>2]|0;do{if((t|0)==0){s=c[cy+(cx*3148|0)+3132>>2]|0;if((s|0)==0){cA=0;cB=cz;cC=cx;cD=cy;break}r=gj[s&4095](S&65535)|0;cA=r;cB=b[4830376]|0;cC=c[3528554]|0;cD=c[2433592]|0}else{cA=a[t+(S&255)|0]|0;cB=cz;cC=cx;cD=cy}}while(0);S=cA&255;c[2426864]=S|z<<8;b[4830376]=cB+2&65535;t=c[cD+(cC*3148|0)+48+(z<<2)>>2]|0;do{if((t|0)==0){r=c[cD+(cC*3148|0)+3120>>2]|0;if((r|0)==0){cE=0;cF=cC;cG=cD;break}s=gj[r&4095]((S|z<<8)&65535)|0;cE=s;cF=c[3528554]|0;cG=c[2433592]|0}else{cE=a[t+S|0]|0;cF=cC;cG=cD}}while(0);t=cE&255;s=c[cG+(cF*3148|0)+48+((((S|z<<8)+1|0)>>>8&255)<<2)>>2]|0;do{if((s|0)==0){r=c[cG+(cF*3148|0)+3120>>2]|0;if((r|0)==0){cH=0;break}cH=gj[r&4095](((S|z<<8)+1|0)&65535)|0}else{cH=a[s+(((S|z<<8)+1|0)&255)|0]|0}}while(0);z=cH&255|t<<8;c[2415193]=z;S=a[9660784]&-15;a[9660784]=S;if((z|0)==0){cI=(S&255|t>>>4&8|4)&255}else{cI=(S&255|t>>>4&8)&255}a[9660784]=cI;a[9660796]=a[9660796]|32;S=(c[2440592]|0)-7|0;c[2440592]=S;g=S;c[f+51712>>2]=2;c[f+51716>>2]=45;break OL;break};case 43:{S=c[2415188]|0;z=c[3528554]|0;s=c[2433592]|0;r=c[s+(z*3148|0)+48+((S>>>8&255)<<2)>>2]|0;do{if((r|0)==0){m=c[s+(z*3148|0)+3132>>2]|0;if((m|0)==0){cJ=0;cK=S;cL=z;cM=s;cN=S&65535;break}o=gj[m&4095](S&65535)|0;m=c[2415188]|0;cJ=o;cK=m;cL=c[3528554]|0;cM=c[2433592]|0;cN=m&65535}else{cJ=a[r+(S&255)|0]|0;cK=S;cL=z;cM=s;cN=S&65535}}while(0);S=cK+1|0;s=c[cM+(cL*3148|0)+48+((S>>>8&255)<<2)>>2]|0;do{if((s|0)==0){z=c[cM+(cL*3148|0)+3132>>2]|0;if((z|0)==0){cO=0;cP=cN;break}r=gj[z&4095](S&65535)|0;cO=r;cP=b[4830376]|0}else{cO=a[s+(S&255)|0]|0;cP=cN}}while(0);S=cP+2&65535;b[4830376]=S;if((a[9660784]&8)==0){cQ=c[2440592]|0}else{s=(c[2440592]|0)-1|0;c[2440592]=s;b[4830376]=S+(cO&255|(cJ&255)<<8)&65535;b[4830376]=c[2415188]&65535;cQ=s}s=cQ-5|0;c[2440592]=s;g=s;c[f+51712>>2]=2;c[f+51716>>2]=45;break OL;break};case 44:{s=c[2415188]|0;S=c[3528554]|0;r=c[2433592]|0;z=c[r+(S*3148|0)+48+((s>>>8&255)<<2)>>2]|0;do{if((z|0)==0){t=c[r+(S*3148|0)+3132>>2]|0;if((t|0)==0){cR=0;cS=s;cT=S;cU=r;cV=s&65535;break}m=gj[t&4095](s&65535)|0;t=c[2415188]|0;cR=m;cS=t;cT=c[3528554]|0;cU=c[2433592]|0;cV=t&65535}else{cR=a[z+(s&255)|0]|0;cS=s;cT=S;cU=r;cV=s&65535}}while(0);s=cS+1|0;r=c[cU+(cT*3148|0)+48+((s>>>8&255)<<2)>>2]|0;do{if((r|0)==0){S=c[cU+(cT*3148|0)+3132>>2]|0;if((S|0)==0){cW=0;cX=cV;break}z=gj[S&4095](s&65535)|0;cW=z;cX=b[4830376]|0}else{cW=a[r+(s&255)|0]|0;cX=cV}}while(0);s=cX+2&65535;b[4830376]=s;r=d[9660784]|0;if(((r<<2^r)&8|0)==0){r=(c[2440592]|0)-1|0;c[2440592]=r;b[4830376]=s+(cW&255|(cR&255)<<8)&65535;b[4830376]=c[2415188]&65535;cY=r}else{cY=c[2440592]|0}r=cY-5|0;c[2440592]=r;g=r;c[f+51712>>2]=2;c[f+51716>>2]=45;break OL;break};case 45:{r=c[2415188]|0;s=c[3528554]|0;z=c[2433592]|0;S=c[z+(s*3148|0)+48+((r>>>8&255)<<2)>>2]|0;do{if((S|0)==0){t=c[z+(s*3148|0)+3132>>2]|0;if((t|0)==0){cZ=0;c_=r;c$=s;c0=z;c1=r&65535;break}m=gj[t&4095](r&65535)|0;t=c[2415188]|0;cZ=m;c_=t;c$=c[3528554]|0;c0=c[2433592]|0;c1=t&65535}else{cZ=a[S+(r&255)|0]|0;c_=r;c$=s;c0=z;c1=r&65535}}while(0);r=c_+1|0;z=c[c0+(c$*3148|0)+48+((r>>>8&255)<<2)>>2]|0;do{if((z|0)==0){s=c[c0+(c$*3148|0)+3132>>2]|0;if((s|0)==0){c2=0;c3=c1;break}S=gj[s&4095](r&65535)|0;c2=S;c3=b[4830376]|0}else{c2=a[z+(r&255)|0]|0;c3=c1}}while(0);r=c3+2&65535;b[4830376]=r;z=d[9660784]|0;if(((z<<2^z)&8|0)==0){c4=c[2440592]|0}else{z=(c[2440592]|0)-1|0;c[2440592]=z;b[4830376]=r+(c2&255|(cZ&255)<<8)&65535;b[4830376]=c[2415188]&65535;c4=z}z=c4-5|0;c[2440592]=z;g=z;c[f+51712>>2]=2;c[f+51716>>2]=45;break OL;break};case 46:{z=c[2415188]|0;r=c[3528554]|0;S=c[2433592]|0;s=c[S+(r*3148|0)+48+((z>>>8&255)<<2)>>2]|0;do{if((s|0)==0){t=c[S+(r*3148|0)+3132>>2]|0;if((t|0)==0){c5=0;c6=z;c7=r;c8=S;c9=z&65535;break}m=gj[t&4095](z&65535)|0;t=c[2415188]|0;c5=m;c6=t;c7=c[3528554]|0;c8=c[2433592]|0;c9=t&65535}else{c5=a[s+(z&255)|0]|0;c6=z;c7=r;c8=S;c9=z&65535}}while(0);z=c6+1|0;S=c[c8+(c7*3148|0)+48+((z>>>8&255)<<2)>>2]|0;do{if((S|0)==0){r=c[c8+(c7*3148|0)+3132>>2]|0;if((r|0)==0){da=0;db=c9;break}s=gj[r&4095](z&65535)|0;da=s;db=b[4830376]|0}else{da=a[S+(z&255)|0]|0;db=c9}}while(0);z=db+2&65535;b[4830376]=z;S=d[9660784]|0;if(((S<<2^S)&8|S&4|0)==0){S=(c[2440592]|0)-1|0;c[2440592]=S;b[4830376]=z+(da&255|(c5&255)<<8)&65535;b[4830376]=c[2415188]&65535;dc=S}else{dc=c[2440592]|0}S=dc-5|0;c[2440592]=S;g=S;c[f+51712>>2]=2;c[f+51716>>2]=45;break OL;break};case 47:{S=c[2415188]|0;z=c[3528554]|0;s=c[2433592]|0;r=c[s+(z*3148|0)+48+((S>>>8&255)<<2)>>2]|0;do{if((r|0)==0){t=c[s+(z*3148|0)+3132>>2]|0;if((t|0)==0){dd=0;de=S;df=z;dg=s;dh=S&65535;break}m=gj[t&4095](S&65535)|0;t=c[2415188]|0;dd=m;de=t;df=c[3528554]|0;dg=c[2433592]|0;dh=t&65535}else{dd=a[r+(S&255)|0]|0;de=S;df=z;dg=s;dh=S&65535}}while(0);S=de+1|0;s=c[dg+(df*3148|0)+48+((S>>>8&255)<<2)>>2]|0;do{if((s|0)==0){z=c[dg+(df*3148|0)+3132>>2]|0;if((z|0)==0){di=0;dj=dh;break}r=gj[z&4095](S&65535)|0;di=r;dj=b[4830376]|0}else{di=a[s+(S&255)|0]|0;dj=dh}}while(0);S=dj+2&65535;b[4830376]=S;s=d[9660784]|0;if(((s<<2^s)&8|s&4|0)==0){dk=c[2440592]|0}else{s=(c[2440592]|0)-1|0;c[2440592]=s;b[4830376]=S+(di&255|(dd&255)<<8)&65535;b[4830376]=c[2415188]&65535;dk=s}s=dk-5|0;c[2440592]=s;g=s;c[f+51712>>2]=2;c[f+51716>>2]=45;break OL;break};case 63:{a[9660784]=a[9660784]|-128;b[4830386]=(b[4830386]|0)-1&65535;s=c[2415193]|0;S=c[3528554]|0;r=c[2433592]|0;z=c[r+(S*3148|0)+48+((s>>>8&255|256)<<2)>>2]|0;do{if((z|0)==0){t=c[r+(S*3148|0)+3124>>2]|0;if((t|0)==0){dl=S;dm=r;break}gg[t&4095](s&65535,k&255);dl=c[3528554]|0;dm=c[2433592]|0}else{a[z+(s&255)|0]=k&255;dl=S;dm=r}}while(0);b[4830386]=(b[4830386]|0)-1&65535;r=c[2415193]|0;S=a[9660753]|0;k=c[dm+(dl*3148|0)+48+((r>>>8&255|256)<<2)>>2]|0;do{if((k|0)==0){s=c[dm+(dl*3148|0)+3124>>2]|0;if((s|0)==0){dn=dl;dp=dm;break}gg[s&4095](r&65535,S);dn=c[3528554]|0;dp=c[2433592]|0}else{a[k+(r&255)|0]=S;dn=dl;dp=dm}}while(0);b[4830386]=(b[4830386]|0)-1&65535;S=c[2415193]|0;r=a[9660768]|0;k=c[dp+(dn*3148|0)+48+((S>>>8&255|256)<<2)>>2]|0;do{if((k|0)==0){s=c[dp+(dn*3148|0)+3124>>2]|0;if((s|0)==0){dq=dn;dr=dp;break}gg[s&4095](S&65535,r);dq=c[3528554]|0;dr=c[2433592]|0}else{a[k+(S&255)|0]=r;dq=dn;dr=dp}}while(0);b[4830386]=(b[4830386]|0)-1&65535;r=c[2415193]|0;S=a[9660769]|0;k=c[dr+(dq*3148|0)+48+((r>>>8&255|256)<<2)>>2]|0;do{if((k|0)==0){s=c[dr+(dq*3148|0)+3124>>2]|0;if((s|0)==0){ds=dq;dt=dr;break}gg[s&4095](r&65535,S);ds=c[3528554]|0;dt=c[2433592]|0}else{a[k+(r&255)|0]=S;ds=dq;dt=dr}}while(0);b[4830386]=(b[4830386]|0)-1&65535;S=c[2415193]|0;r=a[9660780]|0;k=c[dt+(ds*3148|0)+48+((S>>>8&255|256)<<2)>>2]|0;do{if((k|0)==0){s=c[dt+(ds*3148|0)+3124>>2]|0;if((s|0)==0){du=ds;dv=dt;break}gg[s&4095](S&65535,r);du=c[3528554]|0;dv=c[2433592]|0}else{a[k+(S&255)|0]=r;du=ds;dv=dt}}while(0);b[4830386]=(b[4830386]|0)-1&65535;r=c[2415193]|0;S=a[9660781]|0;k=c[dv+(du*3148|0)+48+((r>>>8&255|256)<<2)>>2]|0;do{if((k|0)==0){s=c[dv+(du*3148|0)+3124>>2]|0;if((s|0)==0){dw=du;dx=dv;break}gg[s&4095](r&65535,S);dw=c[3528554]|0;dx=c[2433592]|0}else{a[k+(r&255)|0]=S;dw=du;dx=dv}}while(0);b[4830386]=(b[4830386]|0)-1&65535;S=c[2415193]|0;r=a[9660776]|0;k=c[dx+(dw*3148|0)+48+((S>>>8&255|256)<<2)>>2]|0;do{if((k|0)==0){s=c[dx+(dw*3148|0)+3124>>2]|0;if((s|0)==0){dy=dw;dz=dx;break}gg[s&4095](S&65535,r);dy=c[3528554]|0;dz=c[2433592]|0}else{a[k+(S&255)|0]=r;dy=dw;dz=dx}}while(0);b[4830386]=(b[4830386]|0)-1&65535;r=c[2415193]|0;S=a[9660777]|0;k=c[dz+(dy*3148|0)+48+((r>>>8&255|256)<<2)>>2]|0;do{if((k|0)==0){s=c[dz+(dy*3148|0)+3124>>2]|0;if((s|0)==0){dA=dy;dB=dz;break}gg[s&4095](r&65535,S);dA=c[3528554]|0;dB=c[2433592]|0}else{a[k+(r&255)|0]=S;dA=dy;dB=dz}}while(0);b[4830386]=(b[4830386]|0)-1&65535;S=c[2415193]|0;r=a[9660765]|0;k=c[dB+(dA*3148|0)+48+((S>>>8&255|256)<<2)>>2]|0;do{if((k|0)==0){s=c[dB+(dA*3148|0)+3124>>2]|0;if((s|0)==0){dC=dA;dD=dB;break}gg[s&4095](S&65535,r);dC=c[3528554]|0;dD=c[2433592]|0}else{a[k+(S&255)|0]=r;dC=dA;dD=dB}}while(0);b[4830386]=(b[4830386]|0)-1&65535;r=c[2415193]|0;S=a[9660760]|0;k=c[dD+(dC*3148|0)+48+((r>>>8&255|256)<<2)>>2]|0;do{if((k|0)==0){s=c[dD+(dC*3148|0)+3124>>2]|0;if((s|0)==0){dE=dC;dF=dD;break}gg[s&4095](r&65535,S);dE=c[3528554]|0;dF=c[2433592]|0}else{a[k+(r&255)|0]=S;dE=dC;dF=dD}}while(0);b[4830386]=(b[4830386]|0)-1&65535;S=c[2415193]|0;r=a[9660761]|0;k=c[dF+(dE*3148|0)+48+((S>>>8&255|256)<<2)>>2]|0;do{if((k|0)==0){s=c[dF+(dE*3148|0)+3124>>2]|0;if((s|0)==0){dG=dE;dH=dF;break}gg[s&4095](S&65535,r);dG=c[3528554]|0;dH=c[2433592]|0}else{a[k+(S&255)|0]=r;dG=dE;dH=dF}}while(0);b[4830386]=(b[4830386]|0)-1&65535;r=c[2415193]|0;S=a[9660784]|0;k=c[dH+(dG*3148|0)+48+((r>>>8&255|256)<<2)>>2]|0;do{if((k|0)==0){s=c[dH+(dG*3148|0)+3124>>2]|0;if((s|0)==0){dI=dG;dJ=dH;break}gg[s&4095](r&65535,S);dI=c[3528554]|0;dJ=c[2433592]|0}else{a[k+(r&255)|0]=S;dI=dG;dJ=dH}}while(0);S=c[dJ+(dI*3148|0)+1068>>2]|0;do{if((S|0)==0){r=c[dJ+(dI*3148|0)+3120>>2]|0;if((r|0)==0){dK=0;dL=0;break}k=gj[r&4095](-12)|0;r=c[3528554]|0;s=c[2433592]|0;z=c[s+(r*3148|0)+1068>>2]|0;if((z|0)!=0){dM=z;dN=(k&255)<<8;h=40116;break}z=c[s+(r*3148|0)+3120>>2]|0;if((z|0)==0){dK=0;dL=(k&255)<<8;break}dK=gj[z&4095](-11)|0;dL=(k&255)<<8}else{dM=S;dN=(d[S+244|0]|0)<<8;h=40116}}while(0);if((h|0)==40116){h=0;dK=a[dM+245|0]|0;dL=dN}S=dK&255|dL;c[2415188]=S;b[4830376]=S&65535;S=(c[2440592]|0)-20|0;c[2440592]=S;g=S;c[f+51712>>2]=2;c[f+51716>>2]=45;break OL;break};case 35:{S=c[2415188]|0;k=c[3528554]|0;z=c[2433592]|0;r=c[z+(k*3148|0)+48+((S>>>8&255)<<2)>>2]|0;do{if((r|0)==0){s=c[z+(k*3148|0)+3132>>2]|0;if((s|0)==0){dO=0;dP=S;dQ=k;dR=z;dS=S&65535;break}t=gj[s&4095](S&65535)|0;s=c[2415188]|0;dO=t;dP=s;dQ=c[3528554]|0;dR=c[2433592]|0;dS=s&65535}else{dO=a[r+(S&255)|0]|0;dP=S;dQ=k;dR=z;dS=S&65535}}while(0);S=dP+1|0;z=c[dR+(dQ*3148|0)+48+((S>>>8&255)<<2)>>2]|0;do{if((z|0)==0){k=c[dR+(dQ*3148|0)+3132>>2]|0;if((k|0)==0){dT=0;dU=dS;break}r=gj[k&4095](S&65535)|0;dT=r;dU=b[4830376]|0}else{dT=a[z+(S&255)|0]|0;dU=dS}}while(0);S=dU+2&65535;b[4830376]=S;if((a[9660784]&5)==0){dV=c[2440592]|0}else{z=(c[2440592]|0)-1|0;c[2440592]=z;b[4830376]=S+(dT&255|(dO&255)<<8)&65535;b[4830376]=c[2415188]&65535;dV=z}z=dV-5|0;c[2440592]=z;g=z;c[f+51712>>2]=2;c[f+51716>>2]=45;break OL;break};case 36:{z=c[2415188]|0;S=c[3528554]|0;r=c[2433592]|0;k=c[r+(S*3148|0)+48+((z>>>8&255)<<2)>>2]|0;do{if((k|0)==0){s=c[r+(S*3148|0)+3132>>2]|0;if((s|0)==0){dW=0;dX=z;dY=S;dZ=r;d_=z&65535;break}t=gj[s&4095](z&65535)|0;s=c[2415188]|0;dW=t;dX=s;dY=c[3528554]|0;dZ=c[2433592]|0;d_=s&65535}else{dW=a[k+(z&255)|0]|0;dX=z;dY=S;dZ=r;d_=z&65535}}while(0);z=dX+1|0;r=c[dZ+(dY*3148|0)+48+((z>>>8&255)<<2)>>2]|0;do{if((r|0)==0){S=c[dZ+(dY*3148|0)+3132>>2]|0;if((S|0)==0){d$=0;d0=d_;break}k=gj[S&4095](z&65535)|0;d$=k;d0=b[4830376]|0}else{d$=a[r+(z&255)|0]|0;d0=d_}}while(0);z=d0+2&65535;b[4830376]=z;if((a[9660784]&1)==0){r=(c[2440592]|0)-1|0;c[2440592]=r;b[4830376]=z+(d$&255|(dW&255)<<8)&65535;b[4830376]=c[2415188]&65535;d1=r}else{d1=c[2440592]|0}r=d1-5|0;c[2440592]=r;g=r;c[f+51712>>2]=2;c[f+51716>>2]=45;break OL;break};case 37:{r=c[2415188]|0;z=c[3528554]|0;k=c[2433592]|0;S=c[k+(z*3148|0)+48+((r>>>8&255)<<2)>>2]|0;do{if((S|0)==0){s=c[k+(z*3148|0)+3132>>2]|0;if((s|0)==0){d2=0;d3=r;d4=z;d5=k;d6=r&65535;break}t=gj[s&4095](r&65535)|0;s=c[2415188]|0;d2=t;d3=s;d4=c[3528554]|0;d5=c[2433592]|0;d6=s&65535}else{d2=a[S+(r&255)|0]|0;d3=r;d4=z;d5=k;d6=r&65535}}while(0);r=d3+1|0;k=c[d5+(d4*3148|0)+48+((r>>>8&255)<<2)>>2]|0;do{if((k|0)==0){z=c[d5+(d4*3148|0)+3132>>2]|0;if((z|0)==0){d7=0;d8=d6;break}S=gj[z&4095](r&65535)|0;d7=S;d8=b[4830376]|0}else{d7=a[k+(r&255)|0]|0;d8=d6}}while(0);r=d8+2&65535;b[4830376]=r;if((a[9660784]&1)==0){d9=c[2440592]|0}else{k=(c[2440592]|0)-1|0;c[2440592]=k;b[4830376]=r+(d7&255|(d2&255)<<8)&65535;b[4830376]=c[2415188]&65535;d9=k}k=d9-5|0;c[2440592]=k;g=k;c[f+51712>>2]=2;c[f+51716>>2]=45;break OL;break};case 38:{k=c[2415188]|0;r=c[3528554]|0;S=c[2433592]|0;z=c[S+(r*3148|0)+48+((k>>>8&255)<<2)>>2]|0;do{if((z|0)==0){s=c[S+(r*3148|0)+3132>>2]|0;if((s|0)==0){ea=0;eb=k;ec=r;ed=S;ee=k&65535;break}t=gj[s&4095](k&65535)|0;s=c[2415188]|0;ea=t;eb=s;ec=c[3528554]|0;ed=c[2433592]|0;ee=s&65535}else{ea=a[z+(k&255)|0]|0;eb=k;ec=r;ed=S;ee=k&65535}}while(0);k=eb+1|0;S=c[ed+(ec*3148|0)+48+((k>>>8&255)<<2)>>2]|0;do{if((S|0)==0){r=c[ed+(ec*3148|0)+3132>>2]|0;if((r|0)==0){ef=0;eg=ee;break}z=gj[r&4095](k&65535)|0;ef=z;eg=b[4830376]|0}else{ef=a[S+(k&255)|0]|0;eg=ee}}while(0);k=eg+2&65535;b[4830376]=k;if((a[9660784]&4)==0){S=(c[2440592]|0)-1|0;c[2440592]=S;b[4830376]=k+(ef&255|(ea&255)<<8)&65535;b[4830376]=c[2415188]&65535;eh=S}else{eh=c[2440592]|0}S=eh-5|0;c[2440592]=S;g=S;c[f+51712>>2]=2;c[f+51716>>2]=45;break OL;break};case 39:{S=c[2415188]|0;k=c[3528554]|0;z=c[2433592]|0;r=c[z+(k*3148|0)+48+((S>>>8&255)<<2)>>2]|0;do{if((r|0)==0){s=c[z+(k*3148|0)+3132>>2]|0;if((s|0)==0){ei=0;ej=S;ek=k;el=z;em=S&65535;break}t=gj[s&4095](S&65535)|0;s=c[2415188]|0;ei=t;ej=s;ek=c[3528554]|0;el=c[2433592]|0;em=s&65535}else{ei=a[r+(S&255)|0]|0;ej=S;ek=k;el=z;em=S&65535}}while(0);S=ej+1|0;z=c[el+(ek*3148|0)+48+((S>>>8&255)<<2)>>2]|0;do{if((z|0)==0){k=c[el+(ek*3148|0)+3132>>2]|0;if((k|0)==0){en=0;eo=em;break}r=gj[k&4095](S&65535)|0;en=r;eo=b[4830376]|0}else{en=a[z+(S&255)|0]|0;eo=em}}while(0);S=eo+2&65535;b[4830376]=S;if((a[9660784]&4)==0){ep=c[2440592]|0}else{z=(c[2440592]|0)-1|0;c[2440592]=z;b[4830376]=S+(en&255|(ei&255)<<8)&65535;b[4830376]=c[2415188]&65535;ep=z}z=ep-5|0;c[2440592]=z;g=z;c[f+51712>>2]=2;c[f+51716>>2]=45;break OL;break};case 40:{z=c[2415188]|0;S=c[3528554]|0;r=c[2433592]|0;k=c[r+(S*3148|0)+48+((z>>>8&255)<<2)>>2]|0;do{if((k|0)==0){s=c[r+(S*3148|0)+3132>>2]|0;if((s|0)==0){eq=0;er=z;es=S;et=r;eu=z&65535;break}t=gj[s&4095](z&65535)|0;s=c[2415188]|0;eq=t;er=s;es=c[3528554]|0;et=c[2433592]|0;eu=s&65535}else{eq=a[k+(z&255)|0]|0;er=z;es=S;et=r;eu=z&65535}}while(0);z=er+1|0;r=c[et+(es*3148|0)+48+((z>>>8&255)<<2)>>2]|0;do{if((r|0)==0){S=c[et+(es*3148|0)+3132>>2]|0;if((S|0)==0){ev=0;ew=eu;break}k=gj[S&4095](z&65535)|0;ev=k;ew=b[4830376]|0}else{ev=a[r+(z&255)|0]|0;ew=eu}}while(0);z=ew+2&65535;b[4830376]=z;if((a[9660784]&2)==0){r=(c[2440592]|0)-1|0;c[2440592]=r;b[4830376]=z+(ev&255|(eq&255)<<8)&65535;b[4830376]=c[2415188]&65535;ex=r}else{ex=c[2440592]|0}r=ex-5|0;c[2440592]=r;g=r;c[f+51712>>2]=2;c[f+51716>>2]=45;break OL;break};case 41:{r=c[2415188]|0;z=c[3528554]|0;k=c[2433592]|0;S=c[k+(z*3148|0)+48+((r>>>8&255)<<2)>>2]|0;do{if((S|0)==0){s=c[k+(z*3148|0)+3132>>2]|0;if((s|0)==0){ey=0;ez=r;eA=z;eB=k;eC=r&65535;break}t=gj[s&4095](r&65535)|0;s=c[2415188]|0;ey=t;ez=s;eA=c[3528554]|0;eB=c[2433592]|0;eC=s&65535}else{ey=a[S+(r&255)|0]|0;ez=r;eA=z;eB=k;eC=r&65535}}while(0);r=ez+1|0;k=c[eB+(eA*3148|0)+48+((r>>>8&255)<<2)>>2]|0;do{if((k|0)==0){z=c[eB+(eA*3148|0)+3132>>2]|0;if((z|0)==0){eD=0;eE=eC;break}S=gj[z&4095](r&65535)|0;eD=S;eE=b[4830376]|0}else{eD=a[k+(r&255)|0]|0;eE=eC}}while(0);r=eE+2&65535;b[4830376]=r;if((a[9660784]&2)==0){eF=c[2440592]|0}else{k=(c[2440592]|0)-1|0;c[2440592]=k;b[4830376]=r+(eD&255|(ey&255)<<8)&65535;b[4830376]=c[2415188]&65535;eF=k}k=eF-5|0;c[2440592]=k;g=k;c[f+51712>>2]=2;c[f+51716>>2]=45;break OL;break};default:{n=1}}}if(n){n=0;switch(l|0){case 42:{k=c[2415188]|0;r=c[3528554]|0;S=c[2433592]|0;z=c[S+(r*3148|0)+48+((k>>>8&255)<<2)>>2]|0;do{if((z|0)==0){s=c[S+(r*3148|0)+3132>>2]|0;if((s|0)==0){eG=0;eH=k;eI=r;eJ=S;eK=k&65535;break}t=gj[s&4095](k&65535)|0;s=c[2415188]|0;eG=t;eH=s;eI=c[3528554]|0;eJ=c[2433592]|0;eK=s&65535}else{eG=a[z+(k&255)|0]|0;eH=k;eI=r;eJ=S;eK=k&65535}}while(0);k=eH+1|0;S=c[eJ+(eI*3148|0)+48+((k>>>8&255)<<2)>>2]|0;do{if((S|0)==0){r=c[eJ+(eI*3148|0)+3132>>2]|0;if((r|0)==0){eL=0;eM=eK;break}z=gj[r&4095](k&65535)|0;eL=z;eM=b[4830376]|0}else{eL=a[S+(k&255)|0]|0;eM=eK}}while(0);k=eM+2&65535;b[4830376]=k;if((a[9660784]&8)==0){S=(c[2440592]|0)-1|0;c[2440592]=S;b[4830376]=k+(eL&255|(eG&255)<<8)&65535;b[4830376]=c[2415188]&65535;eN=S}else{eN=c[2440592]|0}S=eN-5|0;c[2440592]=S;g=S;c[f+51712>>2]=2;c[f+51716>>2]=45;break OL;break};default:{h=43386;c[f+51712>>2]=2;c[f+51716>>2]=45;break OL}}}break};default:{i=1}}}if(i){i=0;switch(j|0){case 0:{c[2426864]=c[2415191];S=c[2415188]|0;k=c[3528554]|0;z=c[2433592]|0;r=c[z+(k*3148|0)+48+((S>>>8&255)<<2)>>2]|0;do{if((r|0)==0){l=c[z+(k*3148|0)+3132>>2]|0;if((l|0)==0){eO=0;eP=S&65535;eQ=k;eR=z;break}n=gj[l&4095](S&65535)|0;eO=n;eP=b[4830376]|0;eQ=c[3528554]|0;eR=c[2433592]|0}else{eO=a[r+(S&255)|0]|0;eP=S&65535;eQ=k;eR=z}}while(0);a[9707456]=eO;b[4830376]=eP+1&65535;z=c[2426864]|0;k=c[eR+(eQ*3148|0)+48+((z>>>8&255)<<2)>>2]|0;do{if((k|0)==0){S=c[eR+(eQ*3148|0)+3120>>2]|0;if((S|0)==0){eS=0;eT=z;eU=eQ;eV=eR;break}r=gj[S&4095](z&65535)|0;eS=r;eT=c[2426864]|0;eU=c[3528554]|0;eV=c[2433592]|0}else{eS=a[k+(z&255)|0]|0;eT=z;eU=eQ;eV=eR}}while(0);z=eS&255;k=(a[9660784]&-16&255|(-z|0)>>>4&8)&255;a[9660784]=((z^(-z|0)^(-z|0)>>>1)>>>6&2|(-z|0)>>>8&1|(((-z|0)&255)<<24>>24==0?k|4:k)&255)&255;k=eT&65535;r=c[eV+(eU*3148|0)+48+((eT>>>8&255|256)<<2)>>2]|0;do{if((r|0)==0){S=c[eV+(eU*3148|0)+3124>>2]|0;if((S|0)==0){break}gg[S&4095](k,(-z|0)&255)}else{a[r+(eT&255)|0]=(-z|0)&255}}while(0);z=(c[2440592]|0)-6|0;c[2440592]=z;g=z;break};case 27:{z=(c[2440592]|0)-2|0;c[2440592]=z;g=z;break};case 28:{z=c[2415188]|0;r=c[3528554]|0;k=c[2433592]|0;S=c[k+(r*3148|0)+48+((z>>>8&255)<<2)>>2]|0;do{if((S|0)==0){n=c[k+(r*3148|0)+3132>>2]|0;if((n|0)==0){eW=0;eX=z&65535;break}l=gj[n&4095](z&65535)|0;eW=l;eX=b[4830376]|0}else{eW=a[S+(z&255)|0]|0;eX=z&65535}}while(0);z=eX+1&65535;b[4830376]=z;S=a[9660784]&eW;a[9660784]=S;r=a[9660786]|0;k=a[9660787]|0;if((k|r)<<24>>24!=0){a[9660796]=a[9660796]&-17}do{if(k<<24>>24==0){h=40842}else{if((S&64)!=0){h=40842;break}l=a[9660796]|0;if((l&8)==0){a[9660784]=S&127;b[4830386]=(b[4830386]|0)-1&65535;n=c[2415193]|0;s=c[3528554]|0;t=c[2433592]|0;m=c[t+(s*3148|0)+48+((n>>>8&255|256)<<2)>>2]|0;do{if((m|0)==0){o=c[t+(s*3148|0)+3124>>2]|0;if((o|0)==0){eY=s;eZ=t;break}gg[o&4095](n&65535,z&255);eY=c[3528554]|0;eZ=c[2433592]|0}else{a[m+(n&255)|0]=z&255;eY=s;eZ=t}}while(0);b[4830386]=(b[4830386]|0)-1&65535;t=c[2415193]|0;s=a[9660753]|0;n=c[eZ+(eY*3148|0)+48+((t>>>8&255|256)<<2)>>2]|0;do{if((n|0)==0){m=c[eZ+(eY*3148|0)+3124>>2]|0;if((m|0)==0){e_=eY;e$=eZ;break}gg[m&4095](t&65535,s);e_=c[3528554]|0;e$=c[2433592]|0}else{a[n+(t&255)|0]=s;e_=eY;e$=eZ}}while(0);b[4830386]=(b[4830386]|0)-1&65535;s=c[2415193]|0;t=a[9660784]|0;n=c[e$+(e_*3148|0)+48+((s>>>8&255|256)<<2)>>2]|0;do{if((n|0)==0){m=c[e$+(e_*3148|0)+3124>>2]|0;if((m|0)==0){break}gg[m&4095](s&65535,t)}else{a[n+(s&255)|0]=t}}while(0);e0=(c[2415197]|0)+10|0;e1=a[9660784]|0}else{a[9660796]=l&-9;e0=(c[2415197]|0)+7|0;e1=S}c[2415197]=e0;a[9660784]=e1|80;t=c[3528554]|0;s=c[2433592]|0;n=c[s+(t*3148|0)+1068>>2]|0;do{if((n|0)==0){m=c[s+(t*3148|0)+3120>>2]|0;if((m|0)==0){e2=0;e3=0;break}o=gj[m&4095](-10)|0;m=c[3528554]|0;e4=c[2433592]|0;e5=c[e4+(m*3148|0)+1068>>2]|0;if((e5|0)!=0){e6=e5;e7=(o&255)<<8;h=40838;break}e5=c[e4+(m*3148|0)+3120>>2]|0;if((e5|0)==0){e2=0;e3=(o&255)<<8;break}e2=gj[e5&4095](-9)|0;e3=(o&255)<<8}else{e6=n;e7=(d[n+246|0]|0)<<8;h=40838}}while(0);if((h|0)==40838){h=0;e2=a[e6+247|0]|0;e3=e7}n=e2&255|e3;c[2415188]=n;b[4830376]=n&65535}}while(0);do{if((h|0)==40842){h=0;if(r<<24>>24==0){break}if((S&16)!=0){break}k=a[9660796]|0;if((k&8)==0){a[9660784]=S|-128;b[4830386]=(b[4830386]|0)-1&65535;n=c[2415193]|0;t=c[3528554]|0;s=c[2433592]|0;l=c[s+(t*3148|0)+48+((n>>>8&255|256)<<2)>>2]|0;do{if((l|0)==0){o=c[s+(t*3148|0)+3124>>2]|0;if((o|0)==0){e8=t;e9=s;break}gg[o&4095](n&65535,z&255);e8=c[3528554]|0;e9=c[2433592]|0}else{a[l+(n&255)|0]=z&255;e8=t;e9=s}}while(0);b[4830386]=(b[4830386]|0)-1&65535;s=c[2415193]|0;t=a[9660753]|0;n=c[e9+(e8*3148|0)+48+((s>>>8&255|256)<<2)>>2]|0;do{if((n|0)==0){l=c[e9+(e8*3148|0)+3124>>2]|0;if((l|0)==0){fa=e8;fb=e9;break}gg[l&4095](s&65535,t);fa=c[3528554]|0;fb=c[2433592]|0}else{a[n+(s&255)|0]=t;fa=e8;fb=e9}}while(0);b[4830386]=(b[4830386]|0)-1&65535;t=c[2415193]|0;s=a[9660768]|0;n=c[fb+(fa*3148|0)+48+((t>>>8&255|256)<<2)>>2]|0;do{if((n|0)==0){l=c[fb+(fa*3148|0)+3124>>2]|0;if((l|0)==0){fc=fa;fd=fb;break}gg[l&4095](t&65535,s);fc=c[3528554]|0;fd=c[2433592]|0}else{a[n+(t&255)|0]=s;fc=fa;fd=fb}}while(0);b[4830386]=(b[4830386]|0)-1&65535;s=c[2415193]|0;t=a[9660769]|0;n=c[fd+(fc*3148|0)+48+((s>>>8&255|256)<<2)>>2]|0;do{if((n|0)==0){l=c[fd+(fc*3148|0)+3124>>2]|0;if((l|0)==0){fe=fc;ff=fd;break}gg[l&4095](s&65535,t);fe=c[3528554]|0;ff=c[2433592]|0}else{a[n+(s&255)|0]=t;fe=fc;ff=fd}}while(0);b[4830386]=(b[4830386]|0)-1&65535;t=c[2415193]|0;s=a[9660780]|0;n=c[ff+(fe*3148|0)+48+((t>>>8&255|256)<<2)>>2]|0;do{if((n|0)==0){l=c[ff+(fe*3148|0)+3124>>2]|0;if((l|0)==0){fg=fe;fh=ff;break}gg[l&4095](t&65535,s);fg=c[3528554]|0;fh=c[2433592]|0}else{a[n+(t&255)|0]=s;fg=fe;fh=ff}}while(0);b[4830386]=(b[4830386]|0)-1&65535;s=c[2415193]|0;t=a[9660781]|0;n=c[fh+(fg*3148|0)+48+((s>>>8&255|256)<<2)>>2]|0;do{if((n|0)==0){l=c[fh+(fg*3148|0)+3124>>2]|0;if((l|0)==0){fi=fg;fj=fh;break}gg[l&4095](s&65535,t);fi=c[3528554]|0;fj=c[2433592]|0}else{a[n+(s&255)|0]=t;fi=fg;fj=fh}}while(0);b[4830386]=(b[4830386]|0)-1&65535;t=c[2415193]|0;s=a[9660776]|0;n=c[fj+(fi*3148|0)+48+((t>>>8&255|256)<<2)>>2]|0;do{if((n|0)==0){l=c[fj+(fi*3148|0)+3124>>2]|0;if((l|0)==0){fk=fi;fl=fj;break}gg[l&4095](t&65535,s);fk=c[3528554]|0;fl=c[2433592]|0}else{a[n+(t&255)|0]=s;fk=fi;fl=fj}}while(0);b[4830386]=(b[4830386]|0)-1&65535;s=c[2415193]|0;t=a[9660777]|0;n=c[fl+(fk*3148|0)+48+((s>>>8&255|256)<<2)>>2]|0;do{if((n|0)==0){l=c[fl+(fk*3148|0)+3124>>2]|0;if((l|0)==0){fm=fk;fn=fl;break}gg[l&4095](s&65535,t);fm=c[3528554]|0;fn=c[2433592]|0}else{a[n+(s&255)|0]=t;fm=fk;fn=fl}}while(0);b[4830386]=(b[4830386]|0)-1&65535;t=c[2415193]|0;s=a[9660765]|0;n=c[fn+(fm*3148|0)+48+((t>>>8&255|256)<<2)>>2]|0;do{if((n|0)==0){l=c[fn+(fm*3148|0)+3124>>2]|0;if((l|0)==0){fo=fm;fp=fn;break}gg[l&4095](t&65535,s);fo=c[3528554]|0;fp=c[2433592]|0}else{a[n+(t&255)|0]=s;fo=fm;fp=fn}}while(0);b[4830386]=(b[4830386]|0)-1&65535;s=c[2415193]|0;t=a[9660760]|0;n=c[fp+(fo*3148|0)+48+((s>>>8&255|256)<<2)>>2]|0;do{if((n|0)==0){l=c[fp+(fo*3148|0)+3124>>2]|0;if((l|0)==0){fq=fo;fr=fp;break}gg[l&4095](s&65535,t);fq=c[3528554]|0;fr=c[2433592]|0}else{a[n+(s&255)|0]=t;fq=fo;fr=fp}}while(0);b[4830386]=(b[4830386]|0)-1&65535;t=c[2415193]|0;s=a[9660761]|0;n=c[fr+(fq*3148|0)+48+((t>>>8&255|256)<<2)>>2]|0;do{if((n|0)==0){l=c[fr+(fq*3148|0)+3124>>2]|0;if((l|0)==0){fs=fq;ft=fr;break}gg[l&4095](t&65535,s);fs=c[3528554]|0;ft=c[2433592]|0}else{a[n+(t&255)|0]=s;fs=fq;ft=fr}}while(0);b[4830386]=(b[4830386]|0)-1&65535;s=c[2415193]|0;t=a[9660784]|0;n=c[ft+(fs*3148|0)+48+((s>>>8&255|256)<<2)>>2]|0;do{if((n|0)==0){l=c[ft+(fs*3148|0)+3124>>2]|0;if((l|0)==0){break}gg[l&4095](s&65535,t)}else{a[n+(s&255)|0]=t}}while(0);fu=(c[2415197]|0)+19|0;fv=a[9660784]|0}else{a[9660796]=k&-9;fu=(c[2415197]|0)+7|0;fv=S}c[2415197]=fu;a[9660784]=fv|16;t=c[3528554]|0;s=c[2433592]|0;n=c[s+(t*3148|0)+1068>>2]|0;do{if((n|0)==0){l=c[s+(t*3148|0)+3120>>2]|0;if((l|0)==0){fw=0;fx=0;break}o=gj[l&4095](-8)|0;l=c[3528554]|0;e5=c[2433592]|0;m=c[e5+(l*3148|0)+1068>>2]|0;if((m|0)!=0){fy=m;fz=(o&255)<<8;h=40899;break}m=c[e5+(l*3148|0)+3120>>2]|0;if((m|0)==0){fw=0;fx=(o&255)<<8;break}fw=gj[m&4095](-7)|0;fx=(o&255)<<8}else{fy=n;fz=(d[n+248|0]|0)<<8;h=40899}}while(0);if((h|0)==40899){h=0;fw=a[fy+249|0]|0;fx=fz}n=fw&255|fx;c[2415188]=n;b[4830376]=n&65535}}while(0);S=(c[2440592]|0)-3|0;c[2440592]=S;g=S;break};case 29:{S=d[9660760]|0;z=(S&128|0)!=0?S|65280:S;b[4830380]=z&65535;S=(z>>>12&8|a[9660784]&-13&255)&255;a[9660784]=(z&65535)<<16>>16==0?S|4:S;S=(c[2440592]|0)-2|0;c[2440592]=S;g=S;break};case 30:{S=c[2415188]|0;z=c[3528554]|0;r=c[2433592]|0;n=c[r+(z*3148|0)+48+((S>>>8&255)<<2)>>2]|0;do{if((n|0)==0){t=c[r+(z*3148|0)+3132>>2]|0;if((t|0)==0){fA=0;fB=S&65535;break}s=gj[t&4095](S&65535)|0;fA=s;fB=b[4830376]|0}else{fA=a[n+(S&255)|0]|0;fB=S&65535}}while(0);S=fB+1&65535;b[4830376]=S;n=fA&255;L50080:do{if(((n>>>4^n)&8|0)==0){switch(n>>>4|0){case 0:{fC=b[4830380]|0;break};case 1:{fC=b[4830388]|0;break};case 2:{fC=b[4830390]|0;break};case 3:{fC=b[4830384]|0;break};case 4:{fC=b[4830386]|0;break};case 8:{fC=d[9660761]|0;break};case 9:{fC=d[9660760]|0;break};case 10:{fC=d[9660784]|0;break};case 11:{fC=d[9660765]|0;break};case 5:{fC=S;break};default:{fC=255}}switch(n&15|0){case 0:{fD=fC;fE=b[4830380]|0;break L50080;break};case 1:{fD=fC;fE=b[4830388]|0;break L50080;break};case 2:{fD=fC;fE=b[4830390]|0;break L50080;break};case 3:{fD=fC;fE=b[4830384]|0;break L50080;break};case 4:{fD=fC;fE=b[4830386]|0;break L50080;break};case 5:{fD=fC;fE=S;break L50080;break};case 8:{fD=fC;fE=d[9660761]|0;break L50080;break};case 9:{fD=fC;fE=d[9660760]|0;break L50080;break};case 10:{fD=fC;fE=d[9660784]|0;break L50080;break};case 11:{fD=fC;fE=d[9660765]|0;break L50080;break};default:{fD=fC;fE=255;break L50080}}}else{fD=255;fE=255}}while(0);switch(n>>>4|0){case 0:{b[4830380]=fE;break};case 1:{b[4830388]=fE;break};case 2:{b[4830390]=fE;break};case 3:{b[4830384]=fE;break};case 4:{b[4830386]=fE;break};case 5:{b[4830376]=fE;b[4830376]=c[2415188]&65535;break};case 8:{a[9660761]=fE&255;break};case 9:{a[9660760]=fE&255;break};case 10:{a[9660784]=fE&255;break};case 11:{a[9660765]=fE&255;break};default:{}}switch(n&15|0){case 0:{b[4830380]=fD;break};case 1:{b[4830388]=fD;break};case 2:{b[4830390]=fD;break};case 3:{b[4830384]=fD;break};case 4:{b[4830386]=fD;break};case 5:{b[4830376]=fD;b[4830376]=c[2415188]&65535;break};case 8:{a[9660761]=fD&255;break};case 9:{a[9660760]=fD&255;break};case 10:{a[9660784]=fD&255;break};case 11:{a[9660765]=fD&255;break};default:{}}S=(c[2440592]|0)-8|0;c[2440592]=S;g=S;break};case 31:{S=c[2415188]|0;z=c[3528554]|0;r=c[2433592]|0;s=c[r+(z*3148|0)+48+((S>>>8&255)<<2)>>2]|0;do{if((s|0)==0){t=c[r+(z*3148|0)+3132>>2]|0;if((t|0)==0){fF=0;fG=S&65535;break}k=gj[t&4095](S&65535)|0;fF=k;fG=b[4830376]|0}else{fF=a[s+(S&255)|0]|0;fG=S&65535}}while(0);S=fG+1&65535;b[4830376]=S;s=fF&255;L50136:do{if(((s>>>4^s)&8|0)==0){switch(s>>>4|0){case 0:{fH=b[4830380]|0;break L50136;break};case 1:{fH=b[4830388]|0;break L50136;break};case 2:{fH=b[4830390]|0;break L50136;break};case 3:{fH=b[4830384]|0;break L50136;break};case 4:{fH=b[4830386]|0;break L50136;break};case 8:{fH=d[9660761]|0;break L50136;break};case 9:{fH=d[9660760]|0;break L50136;break};case 10:{fH=d[9660784]|0;break L50136;break};case 11:{fH=d[9660765]|0;break L50136;break};case 5:{fH=S;break L50136;break};default:{fH=255;break L50136}}}else{fH=255}}while(0);switch(s&15|0){case 0:{b[4830380]=fH;break};case 1:{b[4830388]=fH;break};case 2:{b[4830390]=fH;break};case 3:{b[4830384]=fH;break};case 4:{b[4830386]=fH;break};case 5:{b[4830376]=fH;b[4830376]=c[2415188]&65535;break};case 8:{a[9660761]=fH&255;break};case 9:{a[9660760]=fH&255;break};case 10:{a[9660784]=fH&255;break};case 11:{a[9660765]=fH&255;break};default:{}}S=(c[2440592]|0)-6|0;c[2440592]=S;g=S;break};case 32:{S=c[2415188]|0;z=c[3528554]|0;r=c[2433592]|0;n=c[r+(z*3148|0)+48+((S>>>8&255)<<2)>>2]|0;do{if((n|0)==0){k=c[r+(z*3148|0)+3132>>2]|0;if((k|0)==0){fI=0;fJ=S&65535;break}t=gj[k&4095](S&65535)|0;fI=t;fJ=b[4830376]|0}else{fI=a[n+(S&255)|0]|0;fJ=S&65535}}while(0);S=fI&255;b[4830376]=((S&128|0)!=0?S|65280:S)+(fJ+1&65535)&65535;b[4830376]=c[2415188]&65535;S=c[2440592]|0;if(fI<<24>>24==-2&(S|0)>0){c[2440592]=0;fK=0}else{fK=S}S=fK-3|0;c[2440592]=S;g=S;break};case 33:{S=c[2415188]|0;n=c[3528554]|0;z=c[2433592]|0;do{if((c[z+(n*3148|0)+48+((S>>>8&255)<<2)>>2]|0)==0){r=c[z+(n*3148|0)+3132>>2]|0;if((r|0)==0){fL=S&65535;break}gj[r&4095](S&65535)|0;fL=b[4830376]|0}else{fL=S&65535}}while(0);b[4830376]=fL+1&65535;S=(c[2440592]|0)-3|0;c[2440592]=S;g=S;break};case 34:{S=c[2415188]|0;n=c[3528554]|0;z=c[2433592]|0;r=c[z+(n*3148|0)+48+((S>>>8&255)<<2)>>2]|0;do{if((r|0)==0){s=c[z+(n*3148|0)+3132>>2]|0;if((s|0)==0){fM=0;fN=S&65535;break}t=gj[s&4095](S&65535)|0;fM=t;fN=b[4830376]|0}else{fM=a[r+(S&255)|0]|0;fN=S&65535}}while(0);S=fN+1&65535;b[4830376]=S;if((a[9660784]&5)==0){r=fM&255;b[4830376]=((r&128|0)!=0?r|65280:r)+(S&65535)&65535;b[4830376]=c[2415188]&65535}S=(c[2440592]|0)-3|0;c[2440592]=S;g=S;break};case 35:{S=c[2415188]|0;r=c[3528554]|0;n=c[2433592]|0;z=c[n+(r*3148|0)+48+((S>>>8&255)<<2)>>2]|0;do{if((z|0)==0){t=c[n+(r*3148|0)+3132>>2]|0;if((t|0)==0){fO=0;fP=S&65535;break}s=gj[t&4095](S&65535)|0;fO=s;fP=b[4830376]|0}else{fO=a[z+(S&255)|0]|0;fP=S&65535}}while(0);S=fP+1&65535;b[4830376]=S;if((a[9660784]&5)!=0){z=fO&255;b[4830376]=((z&128|0)!=0?z|65280:z)+(S&65535)&65535;b[4830376]=c[2415188]&65535}S=(c[2440592]|0)-3|0;c[2440592]=S;g=S;break};case 36:{S=c[2415188]|0;z=c[3528554]|0;r=c[2433592]|0;n=c[r+(z*3148|0)+48+((S>>>8&255)<<2)>>2]|0;do{if((n|0)==0){s=c[r+(z*3148|0)+3132>>2]|0;if((s|0)==0){fQ=0;fR=S&65535;break}t=gj[s&4095](S&65535)|0;fQ=t;fR=b[4830376]|0}else{fQ=a[n+(S&255)|0]|0;fR=S&65535}}while(0);S=fR+1&65535;b[4830376]=S;if((a[9660784]&1)==0){n=fQ&255;b[4830376]=((n&128|0)!=0?n|65280:n)+(S&65535)&65535;b[4830376]=c[2415188]&65535}S=(c[2440592]|0)-3|0;c[2440592]=S;g=S;break};case 37:{S=c[2415188]|0;n=c[3528554]|0;z=c[2433592]|0;r=c[z+(n*3148|0)+48+((S>>>8&255)<<2)>>2]|0;do{if((r|0)==0){t=c[z+(n*3148|0)+3132>>2]|0;if((t|0)==0){fS=0;fT=S&65535;break}s=gj[t&4095](S&65535)|0;fS=s;fT=b[4830376]|0}else{fS=a[r+(S&255)|0]|0;fT=S&65535}}while(0);S=fT+1&65535;b[4830376]=S;if((a[9660784]&1)!=0){r=fS&255;b[4830376]=((r&128|0)!=0?r|65280:r)+(S&65535)&65535;b[4830376]=c[2415188]&65535}S=(c[2440592]|0)-3|0;c[2440592]=S;g=S;break};case 38:{S=c[2415188]|0;r=c[3528554]|0;n=c[2433592]|0;z=c[n+(r*3148|0)+48+((S>>>8&255)<<2)>>2]|0;do{if((z|0)==0){s=c[n+(r*3148|0)+3132>>2]|0;if((s|0)==0){fU=0;fV=S&65535;break}t=gj[s&4095](S&65535)|0;fU=t;fV=b[4830376]|0}else{fU=a[z+(S&255)|0]|0;fV=S&65535}}while(0);S=fV+1&65535;b[4830376]=S;if((a[9660784]&4)==0){z=fU&255;b[4830376]=((z&128|0)!=0?z|65280:z)+(S&65535)&65535;b[4830376]=c[2415188]&65535}S=(c[2440592]|0)-3|0;c[2440592]=S;g=S;break};case 39:{S=c[2415188]|0;z=c[3528554]|0;r=c[2433592]|0;n=c[r+(z*3148|0)+48+((S>>>8&255)<<2)>>2]|0;do{if((n|0)==0){t=c[r+(z*3148|0)+3132>>2]|0;if((t|0)==0){fW=0;fX=S&65535;break}s=gj[t&4095](S&65535)|0;fW=s;fX=b[4830376]|0}else{fW=a[n+(S&255)|0]|0;fX=S&65535}}while(0);S=fX+1&65535;b[4830376]=S;if((a[9660784]&4)!=0){n=fW&255;b[4830376]=((n&128|0)!=0?n|65280:n)+(S&65535)&65535;b[4830376]=c[2415188]&65535}S=(c[2440592]|0)-3|0;c[2440592]=S;g=S;break};case 40:{S=c[2415188]|0;n=c[3528554]|0;z=c[2433592]|0;r=c[z+(n*3148|0)+48+((S>>>8&255)<<2)>>2]|0;do{if((r|0)==0){s=c[z+(n*3148|0)+3132>>2]|0;if((s|0)==0){fY=0;fZ=S&65535;break}t=gj[s&4095](S&65535)|0;fY=t;fZ=b[4830376]|0}else{fY=a[r+(S&255)|0]|0;fZ=S&65535}}while(0);S=fZ+1&65535;b[4830376]=S;if((a[9660784]&2)==0){r=fY&255;b[4830376]=((r&128|0)!=0?r|65280:r)+(S&65535)&65535;b[4830376]=c[2415188]&65535}S=(c[2440592]|0)-3|0;c[2440592]=S;g=S;break};case 41:{S=c[2415188]|0;r=c[3528554]|0;n=c[2433592]|0;z=c[n+(r*3148|0)+48+((S>>>8&255)<<2)>>2]|0;do{if((z|0)==0){t=c[n+(r*3148|0)+3132>>2]|0;if((t|0)==0){f_=0;f$=S&65535;break}s=gj[t&4095](S&65535)|0;f_=s;f$=b[4830376]|0}else{f_=a[z+(S&255)|0]|0;f$=S&65535}}while(0);S=f$+1&65535;b[4830376]=S;if((a[9660784]&2)!=0){z=f_&255;b[4830376]=((z&128|0)!=0?z|65280:z)+(S&65535)&65535;b[4830376]=c[2415188]&65535}S=(c[2440592]|0)-3|0;c[2440592]=S;g=S;break};case 42:{S=c[2415188]|0;z=c[3528554]|0;r=c[2433592]|0;n=c[r+(z*3148|0)+48+((S>>>8&255)<<2)>>2]|0;do{if((n|0)==0){s=c[r+(z*3148|0)+3132>>2]|0;if((s|0)==0){f0=0;f1=S&65535;break}t=gj[s&4095](S&65535)|0;f0=t;f1=b[4830376]|0}else{f0=a[n+(S&255)|0]|0;f1=S&65535}}while(0);S=f1+1&65535;b[4830376]=S;if((a[9660784]&8)==0){n=f0&255;b[4830376]=((n&128|0)!=0?n|65280:n)+(S&65535)&65535;b[4830376]=c[2415188]&65535}S=(c[2440592]|0)-3|0;c[2440592]=S;g=S;break};case 43:{S=c[2415188]|0;n=c[3528554]|0;z=c[2433592]|0;r=c[z+(n*3148|0)+48+((S>>>8&255)<<2)>>2]|0;do{if((r|0)==0){t=c[z+(n*3148|0)+3132>>2]|0;if((t|0)==0){f2=0;f3=S&65535;break}s=gj[t&4095](S&65535)|0;f2=s;f3=b[4830376]|0}else{f2=a[r+(S&255)|0]|0;f3=S&65535}}while(0);S=f3+1&65535;b[4830376]=S;if((a[9660784]&8)!=0){r=f2&255;b[4830376]=((r&128|0)!=0?r|65280:r)+(S&65535)&65535;b[4830376]=c[2415188]&65535}S=(c[2440592]|0)-3|0;c[2440592]=S;g=S;break};case 44:{S=c[2415188]|0;r=c[3528554]|0;n=c[2433592]|0;z=c[n+(r*3148|0)+48+((S>>>8&255)<<2)>>2]|0;do{if((z|0)==0){s=c[n+(r*3148|0)+3132>>2]|0;if((s|0)==0){f4=0;f5=S&65535;break}t=gj[s&4095](S&65535)|0;f4=t;f5=b[4830376]|0}else{f4=a[z+(S&255)|0]|0;f5=S&65535}}while(0);S=f5+1&65535;b[4830376]=S;z=d[9660784]|0;if(((z<<2^z)&8|0)==0){z=f4&255;b[4830376]=((z&128|0)!=0?z|65280:z)+(S&65535)&65535;b[4830376]=c[2415188]&65535}S=(c[2440592]|0)-3|0;c[2440592]=S;g=S;break};case 45:{S=c[2415188]|0;z=c[3528554]|0;r=c[2433592]|0;n=c[r+(z*3148|0)+48+((S>>>8&255)<<2)>>2]|0;do{if((n|0)==0){t=c[r+(z*3148|0)+3132>>2]|0;if((t|0)==0){f6=0;f7=S&65535;break}s=gj[t&4095](S&65535)|0;f6=s;f7=b[4830376]|0}else{f6=a[n+(S&255)|0]|0;f7=S&65535}}while(0);S=f7+1&65535;b[4830376]=S;n=d[9660784]|0;if(((n<<2^n)&8|0)!=0){n=f6&255;b[4830376]=((n&128|0)!=0?n|65280:n)+(S&65535)&65535;b[4830376]=c[2415188]&65535}S=(c[2440592]|0)-3|0;c[2440592]=S;g=S;break};case 46:{S=c[2415188]|0;n=c[3528554]|0;z=c[2433592]|0;r=c[z+(n*3148|0)+48+((S>>>8&255)<<2)>>2]|0;do{if((r|0)==0){s=c[z+(n*3148|0)+3132>>2]|0;if((s|0)==0){f8=0;f9=S&65535;break}t=gj[s&4095](S&65535)|0;f8=t;f9=b[4830376]|0}else{f8=a[r+(S&255)|0]|0;f9=S&65535}}while(0);S=f9+1&65535;b[4830376]=S;r=d[9660784]|0;if(((r<<2^r)&8|r&4|0)==0){r=f8&255;b[4830376]=((r&128|0)!=0?r|65280:r)+(S&65535)&65535;b[4830376]=c[2415188]&65535}S=(c[2440592]|0)-3|0;c[2440592]=S;g=S;break};case 47:{S=c[2415188]|0;r=c[3528554]|0;n=c[2433592]|0;z=c[n+(r*3148|0)+48+((S>>>8&255)<<2)>>2]|0;do{if((z|0)==0){t=c[n+(r*3148|0)+3132>>2]|0;if((t|0)==0){ga=0;gb=S&65535;break}s=gj[t&4095](S&65535)|0;ga=s;gb=b[4830376]|0}else{ga=a[z+(S&255)|0]|0;gb=S&65535}}while(0);S=gb+1&65535;b[4830376]=S;z=d[9660784]|0;if(((z<<2^z)&8|z&4|0)!=0){z=ga&255;b[4830376]=((z&128|0)!=0?z|65280:z)+(S&65535)&65535;b[4830376]=c[2415188]&65535}S=(c[2440592]|0)-3|0;c[2440592]=S;g=S;break};case 48:{f46();S=b[4853728]|0;b[4830388]=S;z=a[9660784]|0;a[9660784]=S<<16>>16==0?z|4:z&-5;z=(c[2440592]|0)-4|0;c[2440592]=z;g=z;break};case 49:{f46();z=b[4853728]|0;b[4830390]=z;S=a[9660784]|0;a[9660784]=z<<16>>16==0?S|4:S&-5;S=(c[2440592]|0)-4|0;c[2440592]=S;g=S;break};case 50:{f46();b[4830386]=b[4853728]|0;a[9660796]=a[9660796]|32;S=(c[2440592]|0)-4|0;c[2440592]=S;g=S;break};case 51:{f46();b[4830384]=b[4853728]|0;S=(c[2440592]|0)-4|0;c[2440592]=S;g=S;break};default:{i=1}}}if(i){i=0;switch(j|0){case 52:{S=c[2415188]|0;z=c[3528554]|0;r=c[2433592]|0;n=c[r+(z*3148|0)+48+((S>>>8&255)<<2)>>2]|0;do{if((n|0)==0){s=c[r+(z*3148|0)+3132>>2]|0;if((s|0)==0){gc=0;gd=S&65535;break}t=gj[s&4095](S&65535)|0;gc=t;gd=b[4830376]|0}else{gc=a[n+(S&255)|0]|0;gd=S&65535}}while(0);S=gd+1&65535;b[4830376]=S;n=gc&255;if((n&128|0)!=0){b[4830386]=(b[4830386]|0)-1&65535;z=c[2415193]|0;r=c[3528554]|0;t=c[2433592]|0;s=c[t+(r*3148|0)+48+((z>>>8&255|256)<<2)>>2]|0;do{if((s|0)==0){k=c[t+(r*3148|0)+3124>>2]|0;if((k|0)==0){ge=r;gf=t;break}gg[k&4095](z&65535,S&255);ge=c[3528554]|0;gf=c[2433592]|0}else{a[s+(z&255)|0]=S&255;ge=r;gf=t}}while(0);b[4830386]=(b[4830386]|0)-1&65535;t=c[2415193]|0;r=a[9660753]|0;S=c[gf+(ge*3148|0)+48+((t>>>8&255|256)<<2)>>2]|0;do{if((S|0)==0){z=c[gf+(ge*3148|0)+3124>>2]|0;if((z|0)==0){break}gg[z&4095](t&65535,r)}else{a[S+(t&255)|0]=r}}while(0);c[2440592]=(c[2440592]|0)-2}if((n&64|0)!=0){b[4830386]=(b[4830386]|0)-1&65535;r=c[2415193]|0;t=a[9660768]|0;S=c[3528554]|0;z=c[2433592]|0;s=c[z+(S*3148|0)+48+((r>>>8&255|256)<<2)>>2]|0;do{if((s|0)==0){k=c[z+(S*3148|0)+3124>>2]|0;if((k|0)==0){gh=S;gi=z;break}gg[k&4095](r&65535,t);gh=c[3528554]|0;gi=c[2433592]|0}else{a[s+(r&255)|0]=t;gh=S;gi=z}}while(0);b[4830386]=(b[4830386]|0)-1&65535;z=c[2415193]|0;S=a[9660769]|0;t=c[gi+(gh*3148|0)+48+((z>>>8&255|256)<<2)>>2]|0;do{if((t|0)==0){r=c[gi+(gh*3148|0)+3124>>2]|0;if((r|0)==0){break}gg[r&4095](z&65535,S)}else{a[t+(z&255)|0]=S}}while(0);c[2440592]=(c[2440592]|0)-2}if((n&32|0)!=0){b[4830386]=(b[4830386]|0)-1&65535;S=c[2415193]|0;z=a[9660780]|0;t=c[3528554]|0;r=c[2433592]|0;s=c[r+(t*3148|0)+48+((S>>>8&255|256)<<2)>>2]|0;do{if((s|0)==0){k=c[r+(t*3148|0)+3124>>2]|0;if((k|0)==0){gk=t;gl=r;break}gg[k&4095](S&65535,z);gk=c[3528554]|0;gl=c[2433592]|0}else{a[s+(S&255)|0]=z;gk=t;gl=r}}while(0);b[4830386]=(b[4830386]|0)-1&65535;r=c[2415193]|0;t=a[9660781]|0;z=c[gl+(gk*3148|0)+48+((r>>>8&255|256)<<2)>>2]|0;do{if((z|0)==0){S=c[gl+(gk*3148|0)+3124>>2]|0;if((S|0)==0){break}gg[S&4095](r&65535,t)}else{a[z+(r&255)|0]=t}}while(0);c[2440592]=(c[2440592]|0)-2}if((n&16|0)!=0){b[4830386]=(b[4830386]|0)-1&65535;t=c[2415193]|0;r=a[9660776]|0;z=c[3528554]|0;S=c[2433592]|0;s=c[S+(z*3148|0)+48+((t>>>8&255|256)<<2)>>2]|0;do{if((s|0)==0){k=c[S+(z*3148|0)+3124>>2]|0;if((k|0)==0){gm=z;gn=S;break}gg[k&4095](t&65535,r);gm=c[3528554]|0;gn=c[2433592]|0}else{a[s+(t&255)|0]=r;gm=z;gn=S}}while(0);b[4830386]=(b[4830386]|0)-1&65535;S=c[2415193]|0;z=a[9660777]|0;r=c[gn+(gm*3148|0)+48+((S>>>8&255|256)<<2)>>2]|0;do{if((r|0)==0){t=c[gn+(gm*3148|0)+3124>>2]|0;if((t|0)==0){break}gg[t&4095](S&65535,z)}else{a[r+(S&255)|0]=z}}while(0);c[2440592]=(c[2440592]|0)-2}if((n&8|0)!=0){b[4830386]=(b[4830386]|0)-1&65535;z=c[2415193]|0;S=a[9660765]|0;r=c[3528554]|0;t=c[2433592]|0;s=c[t+(r*3148|0)+48+((z>>>8&255|256)<<2)>>2]|0;do{if((s|0)==0){k=c[t+(r*3148|0)+3124>>2]|0;if((k|0)==0){break}gg[k&4095](z&65535,S)}else{a[s+(z&255)|0]=S}}while(0);c[2440592]=(c[2440592]|0)-1}if((n&4|0)!=0){b[4830386]=(b[4830386]|0)-1&65535;S=c[2415193]|0;z=a[9660760]|0;s=c[3528554]|0;r=c[2433592]|0;t=c[r+(s*3148|0)+48+((S>>>8&255|256)<<2)>>2]|0;do{if((t|0)==0){k=c[r+(s*3148|0)+3124>>2]|0;if((k|0)==0){break}gg[k&4095](S&65535,z)}else{a[t+(S&255)|0]=z}}while(0);c[2440592]=(c[2440592]|0)-1}if((n&2|0)!=0){b[4830386]=(b[4830386]|0)-1&65535;z=c[2415193]|0;S=a[9660761]|0;t=c[3528554]|0;s=c[2433592]|0;r=c[s+(t*3148|0)+48+((z>>>8&255|256)<<2)>>2]|0;do{if((r|0)==0){k=c[s+(t*3148|0)+3124>>2]|0;if((k|0)==0){break}gg[k&4095](z&65535,S)}else{a[r+(z&255)|0]=S}}while(0);c[2440592]=(c[2440592]|0)-1}if((n&1|0)==0){go=c[2440592]|0}else{b[4830386]=(b[4830386]|0)-1&65535;S=c[2415193]|0;z=a[9660784]|0;r=c[3528554]|0;t=c[2433592]|0;s=c[t+(r*3148|0)+48+((S>>>8&255|256)<<2)>>2]|0;do{if((s|0)==0){k=c[t+(r*3148|0)+3124>>2]|0;if((k|0)==0){break}gg[k&4095](S&65535,z)}else{a[s+(S&255)|0]=z}}while(0);z=(c[2440592]|0)-1|0;c[2440592]=z;go=z}z=go-5|0;c[2440592]=z;g=z;break};case 53:{z=c[2415188]|0;S=c[3528554]|0;s=c[2433592]|0;r=c[s+(S*3148|0)+48+((z>>>8&255)<<2)>>2]|0;do{if((r|0)==0){t=c[s+(S*3148|0)+3132>>2]|0;if((t|0)==0){gp=0;gq=z&65535;break}n=gj[t&4095](z&65535)|0;gp=n;gq=b[4830376]|0}else{gp=a[r+(z&255)|0]|0;gq=z&65535}}while(0);b[4830376]=gq+1&65535;z=gp&255;if((z&1|0)!=0){r=c[2415193]|0;S=c[3528554]|0;s=c[2433592]|0;n=c[s+(S*3148|0)+48+((r>>>8&255)<<2)>>2]|0;do{if((n|0)==0){t=c[s+(S*3148|0)+3120>>2]|0;if((t|0)==0){gr=0;gs=r&65535;break}k=gj[t&4095](r&65535)|0;gr=k;gs=b[4830386]|0}else{gr=a[n+(r&255)|0]|0;gs=r&65535}}while(0);a[9660784]=gr;b[4830386]=gs+1&65535;c[2440592]=(c[2440592]|0)-1}if((z&2|0)!=0){r=c[2415193]|0;n=c[3528554]|0;S=c[2433592]|0;s=c[S+(n*3148|0)+48+((r>>>8&255)<<2)>>2]|0;do{if((s|0)==0){k=c[S+(n*3148|0)+3120>>2]|0;if((k|0)==0){gt=0;gu=r&65535;break}t=gj[k&4095](r&65535)|0;gt=t;gu=b[4830386]|0}else{gt=a[s+(r&255)|0]|0;gu=r&65535}}while(0);a[9660761]=gt;b[4830386]=gu+1&65535;c[2440592]=(c[2440592]|0)-1}if((z&4|0)!=0){r=c[2415193]|0;s=c[3528554]|0;n=c[2433592]|0;S=c[n+(s*3148|0)+48+((r>>>8&255)<<2)>>2]|0;do{if((S|0)==0){t=c[n+(s*3148|0)+3120>>2]|0;if((t|0)==0){gv=0;gw=r&65535;break}k=gj[t&4095](r&65535)|0;gv=k;gw=b[4830386]|0}else{gv=a[S+(r&255)|0]|0;gw=r&65535}}while(0);a[9660760]=gv;b[4830386]=gw+1&65535;c[2440592]=(c[2440592]|0)-1}if((z&8|0)!=0){r=c[2415193]|0;S=c[3528554]|0;s=c[2433592]|0;n=c[s+(S*3148|0)+48+((r>>>8&255)<<2)>>2]|0;do{if((n|0)==0){k=c[s+(S*3148|0)+3120>>2]|0;if((k|0)==0){gx=0;gy=r&65535;break}t=gj[k&4095](r&65535)|0;gx=t;gy=b[4830386]|0}else{gx=a[n+(r&255)|0]|0;gy=r&65535}}while(0);a[9660765]=gx;b[4830386]=gy+1&65535;c[2440592]=(c[2440592]|0)-1}if((z&16|0)!=0){r=c[2415193]|0;n=c[3528554]|0;S=c[2433592]|0;s=c[S+(n*3148|0)+48+((r>>>8&255)<<2)>>2]|0;do{if((s|0)==0){t=c[S+(n*3148|0)+3120>>2]|0;if((t|0)==0){gz=0;gA=r&65535;gB=n;gC=S;break}k=gj[t&4095](r&65535)|0;gz=k;gA=b[4830386]|0;gB=c[3528554]|0;gC=c[2433592]|0}else{gz=a[s+(r&255)|0]|0;gA=r&65535;gB=n;gC=S}}while(0);S=(gz&255)<<8;c[2415194]=S;b[4830386]=gA+1&65535;n=c[2415193]|0;r=c[gC+(gB*3148|0)+48+((n>>>8&255)<<2)>>2]|0;do{if((r|0)==0){s=c[gC+(gB*3148|0)+3120>>2]|0;if((s|0)==0){gD=0;gE=S;gF=n&65535;break}k=gj[s&4095](n&65535)|0;gD=k;gE=c[2415194]|0;gF=b[4830386]|0}else{gD=a[r+(n&255)|0]|0;gE=S;gF=n&65535}}while(0);c[2415194]=gE|gD&255;b[4830386]=gF+1&65535;c[2440592]=(c[2440592]|0)-2}if((z&32|0)!=0){n=c[2415193]|0;S=c[3528554]|0;r=c[2433592]|0;k=c[r+(S*3148|0)+48+((n>>>8&255)<<2)>>2]|0;do{if((k|0)==0){s=c[r+(S*3148|0)+3120>>2]|0;if((s|0)==0){gG=0;gH=n&65535;gI=S;gJ=r;break}t=gj[s&4095](n&65535)|0;gG=t;gH=b[4830386]|0;gI=c[3528554]|0;gJ=c[2433592]|0}else{gG=a[k+(n&255)|0]|0;gH=n&65535;gI=S;gJ=r}}while(0);r=(gG&255)<<8;c[2415195]=r;b[4830386]=gH+1&65535;S=c[2415193]|0;n=c[gJ+(gI*3148|0)+48+((S>>>8&255)<<2)>>2]|0;do{if((n|0)==0){k=c[gJ+(gI*3148|0)+3120>>2]|0;if((k|0)==0){gK=0;gL=r;gM=S&65535;break}t=gj[k&4095](S&65535)|0;gK=t;gL=c[2415195]|0;gM=b[4830386]|0}else{gK=a[n+(S&255)|0]|0;gL=r;gM=S&65535}}while(0);c[2415195]=gL|gK&255;b[4830386]=gM+1&65535;c[2440592]=(c[2440592]|0)-2}if((z&64|0)!=0){S=c[2415193]|0;r=c[3528554]|0;n=c[2433592]|0;t=c[n+(r*3148|0)+48+((S>>>8&255)<<2)>>2]|0;do{if((t|0)==0){k=c[n+(r*3148|0)+3120>>2]|0;if((k|0)==0){gN=0;gO=S&65535;gP=r;gQ=n;break}s=gj[k&4095](S&65535)|0;gN=s;gO=b[4830386]|0;gP=c[3528554]|0;gQ=c[2433592]|0}else{gN=a[t+(S&255)|0]|0;gO=S&65535;gP=r;gQ=n}}while(0);n=(gN&255)<<8;c[2415192]=n;b[4830386]=gO+1&65535;r=c[2415193]|0;S=c[gQ+(gP*3148|0)+48+((r>>>8&255)<<2)>>2]|0;do{if((S|0)==0){t=c[gQ+(gP*3148|0)+3120>>2]|0;if((t|0)==0){gR=0;gS=n;gT=r&65535;break}s=gj[t&4095](r&65535)|0;gR=s;gS=c[2415192]|0;gT=b[4830386]|0}else{gR=a[S+(r&255)|0]|0;gS=n;gT=r&65535}}while(0);c[2415192]=gS|gR&255;b[4830386]=gT+1&65535;c[2440592]=(c[2440592]|0)-2}if((z&128|0)!=0){r=c[2415193]|0;n=c[3528554]|0;S=c[2433592]|0;s=c[S+(n*3148|0)+48+((r>>>8&255)<<2)>>2]|0;do{if((s|0)==0){t=c[S+(n*3148|0)+3120>>2]|0;if((t|0)==0){gU=0;gV=r&65535;gW=n;gX=S;break}k=gj[t&4095](r&65535)|0;gU=k;gV=b[4830386]|0;gW=c[3528554]|0;gX=c[2433592]|0}else{gU=a[s+(r&255)|0]|0;gV=r&65535;gW=n;gX=S}}while(0);S=(gU&255)<<8;c[2415188]=S;b[4830386]=gV+1&65535;n=c[2415193]|0;r=c[gX+(gW*3148|0)+48+((n>>>8&255)<<2)>>2]|0;do{if((r|0)==0){s=c[gX+(gW*3148|0)+3120>>2]|0;if((s|0)==0){gY=0;gZ=S;g_=n&65535;break}k=gj[s&4095](n&65535)|0;gY=k;gZ=c[2415188]|0;g_=b[4830386]|0}else{gY=a[r+(n&255)|0]|0;gZ=S;g_=n&65535}}while(0);n=gZ|gY&255;c[2415188]=n;b[4830386]=g_+1&65535;b[4830376]=n&65535;c[2440592]=(c[2440592]|0)-2}L50487:do{if((z&1|0)!=0){n=a[9660786]|0;S=a[9660787]|0;if((S|n)<<24>>24!=0){a[9660796]=a[9660796]&-17}do{if(S<<24>>24!=0){r=a[9660784]|0;if((r&64)!=0){break}k=a[9660796]|0;if((k&8)==0){a[9660784]=r&127;b[4830386]=(b[4830386]|0)-1&65535;s=c[2415193]|0;t=a[9660752]|0;o=c[3528554]|0;m=c[2433592]|0;l=c[m+(o*3148|0)+48+((s>>>8&255|256)<<2)>>2]|0;do{if((l|0)==0){e5=c[m+(o*3148|0)+3124>>2]|0;if((e5|0)==0){g$=o;g0=m;break}gg[e5&4095](s&65535,t);g$=c[3528554]|0;g0=c[2433592]|0}else{a[l+(s&255)|0]=t;g$=o;g0=m}}while(0);b[4830386]=(b[4830386]|0)-1&65535;m=c[2415193]|0;o=a[9660753]|0;t=c[g0+(g$*3148|0)+48+((m>>>8&255|256)<<2)>>2]|0;do{if((t|0)==0){s=c[g0+(g$*3148|0)+3124>>2]|0;if((s|0)==0){g1=g$;g2=g0;break}gg[s&4095](m&65535,o);g1=c[3528554]|0;g2=c[2433592]|0}else{a[t+(m&255)|0]=o;g1=g$;g2=g0}}while(0);b[4830386]=(b[4830386]|0)-1&65535;o=c[2415193]|0;m=a[9660784]|0;t=c[g2+(g1*3148|0)+48+((o>>>8&255|256)<<2)>>2]|0;do{if((t|0)==0){s=c[g2+(g1*3148|0)+3124>>2]|0;if((s|0)==0){break}gg[s&4095](o&65535,m)}else{a[t+(o&255)|0]=m}}while(0);g3=(c[2415197]|0)+10|0;g4=a[9660784]|0}else{a[9660796]=k&-9;g3=(c[2415197]|0)+7|0;g4=r}c[2415197]=g3;a[9660784]=g4|80;m=c[3528554]|0;o=c[2433592]|0;t=c[o+(m*3148|0)+1068>>2]|0;do{if((t|0)==0){s=c[o+(m*3148|0)+3120>>2]|0;if((s|0)==0){g5=0;g6=0;break}l=gj[s&4095](-10)|0;s=c[3528554]|0;e5=c[2433592]|0;e4=c[e5+(s*3148|0)+1068>>2]|0;if((e4|0)!=0){g7=e4;g8=(l&255)<<8;h=41258;break}e4=c[e5+(s*3148|0)+3120>>2]|0;if((e4|0)==0){g5=0;g6=(l&255)<<8;break}g5=gj[e4&4095](-9)|0;g6=(l&255)<<8}else{g7=t;g8=(d[t+246|0]|0)<<8;h=41258}}while(0);if((h|0)==41258){h=0;g5=a[g7+247|0]|0;g6=g8}t=g5&255|g6;c[2415188]=t;b[4830376]=t&65535;break L50487}}while(0);if(n<<24>>24==0){break}S=a[9660784]|0;if((S&16)!=0){break}t=a[9660796]|0;if((t&8)==0){a[9660784]=S|-128;b[4830386]=(b[4830386]|0)-1&65535;m=c[2415193]|0;o=a[9660752]|0;r=c[3528554]|0;k=c[2433592]|0;l=c[k+(r*3148|0)+48+((m>>>8&255|256)<<2)>>2]|0;do{if((l|0)==0){e4=c[k+(r*3148|0)+3124>>2]|0;if((e4|0)==0){g9=r;ha=k;break}gg[e4&4095](m&65535,o);g9=c[3528554]|0;ha=c[2433592]|0}else{a[l+(m&255)|0]=o;g9=r;ha=k}}while(0);b[4830386]=(b[4830386]|0)-1&65535;k=c[2415193]|0;r=a[9660753]|0;o=c[ha+(g9*3148|0)+48+((k>>>8&255|256)<<2)>>2]|0;do{if((o|0)==0){m=c[ha+(g9*3148|0)+3124>>2]|0;if((m|0)==0){hb=g9;hc=ha;break}gg[m&4095](k&65535,r);hb=c[3528554]|0;hc=c[2433592]|0}else{a[o+(k&255)|0]=r;hb=g9;hc=ha}}while(0);b[4830386]=(b[4830386]|0)-1&65535;r=c[2415193]|0;k=a[9660768]|0;o=c[hc+(hb*3148|0)+48+((r>>>8&255|256)<<2)>>2]|0;do{if((o|0)==0){m=c[hc+(hb*3148|0)+3124>>2]|0;if((m|0)==0){hd=hb;he=hc;break}gg[m&4095](r&65535,k);hd=c[3528554]|0;he=c[2433592]|0}else{a[o+(r&255)|0]=k;hd=hb;he=hc}}while(0);b[4830386]=(b[4830386]|0)-1&65535;k=c[2415193]|0;r=a[9660769]|0;o=c[he+(hd*3148|0)+48+((k>>>8&255|256)<<2)>>2]|0;do{if((o|0)==0){m=c[he+(hd*3148|0)+3124>>2]|0;if((m|0)==0){hf=hd;hg=he;break}gg[m&4095](k&65535,r);hf=c[3528554]|0;hg=c[2433592]|0}else{a[o+(k&255)|0]=r;hf=hd;hg=he}}while(0);b[4830386]=(b[4830386]|0)-1&65535;r=c[2415193]|0;k=a[9660780]|0;o=c[hg+(hf*3148|0)+48+((r>>>8&255|256)<<2)>>2]|0;do{if((o|0)==0){m=c[hg+(hf*3148|0)+3124>>2]|0;if((m|0)==0){hh=hf;hi=hg;break}gg[m&4095](r&65535,k);hh=c[3528554]|0;hi=c[2433592]|0}else{a[o+(r&255)|0]=k;hh=hf;hi=hg}}while(0);b[4830386]=(b[4830386]|0)-1&65535;k=c[2415193]|0;r=a[9660781]|0;o=c[hi+(hh*3148|0)+48+((k>>>8&255|256)<<2)>>2]|0;do{if((o|0)==0){m=c[hi+(hh*3148|0)+3124>>2]|0;if((m|0)==0){hj=hh;hk=hi;break}gg[m&4095](k&65535,r);hj=c[3528554]|0;hk=c[2433592]|0}else{a[o+(k&255)|0]=r;hj=hh;hk=hi}}while(0);b[4830386]=(b[4830386]|0)-1&65535;r=c[2415193]|0;k=a[9660776]|0;o=c[hk+(hj*3148|0)+48+((r>>>8&255|256)<<2)>>2]|0;do{if((o|0)==0){m=c[hk+(hj*3148|0)+3124>>2]|0;if((m|0)==0){hl=hj;hm=hk;break}gg[m&4095](r&65535,k);hl=c[3528554]|0;hm=c[2433592]|0}else{a[o+(r&255)|0]=k;hl=hj;hm=hk}}while(0);b[4830386]=(b[4830386]|0)-1&65535;k=c[2415193]|0;r=a[9660777]|0;o=c[hm+(hl*3148|0)+48+((k>>>8&255|256)<<2)>>2]|0;do{if((o|0)==0){m=c[hm+(hl*3148|0)+3124>>2]|0;if((m|0)==0){hn=hl;ho=hm;break}gg[m&4095](k&65535,r);hn=c[3528554]|0;ho=c[2433592]|0}else{a[o+(k&255)|0]=r;hn=hl;ho=hm}}while(0);b[4830386]=(b[4830386]|0)-1&65535;r=c[2415193]|0;k=a[9660765]|0;o=c[ho+(hn*3148|0)+48+((r>>>8&255|256)<<2)>>2]|0;do{if((o|0)==0){m=c[ho+(hn*3148|0)+3124>>2]|0;if((m|0)==0){hp=hn;hq=ho;break}gg[m&4095](r&65535,k);hp=c[3528554]|0;hq=c[2433592]|0}else{a[o+(r&255)|0]=k;hp=hn;hq=ho}}while(0);b[4830386]=(b[4830386]|0)-1&65535;k=c[2415193]|0;r=a[9660760]|0;o=c[hq+(hp*3148|0)+48+((k>>>8&255|256)<<2)>>2]|0;do{if((o|0)==0){m=c[hq+(hp*3148|0)+3124>>2]|0;if((m|0)==0){hr=hp;hs=hq;break}gg[m&4095](k&65535,r);hr=c[3528554]|0;hs=c[2433592]|0}else{a[o+(k&255)|0]=r;hr=hp;hs=hq}}while(0);b[4830386]=(b[4830386]|0)-1&65535;r=c[2415193]|0;k=a[9660761]|0;o=c[hs+(hr*3148|0)+48+((r>>>8&255|256)<<2)>>2]|0;do{if((o|0)==0){m=c[hs+(hr*3148|0)+3124>>2]|0;if((m|0)==0){ht=hr;hu=hs;break}gg[m&4095](r&65535,k);ht=c[3528554]|0;hu=c[2433592]|0}else{a[o+(r&255)|0]=k;ht=hr;hu=hs}}while(0);b[4830386]=(b[4830386]|0)-1&65535;k=c[2415193]|0;r=a[9660784]|0;o=c[hu+(ht*3148|0)+48+((k>>>8&255|256)<<2)>>2]|0;do{if((o|0)==0){m=c[hu+(ht*3148|0)+3124>>2]|0;if((m|0)==0){break}gg[m&4095](k&65535,r)}else{a[o+(k&255)|0]=r}}while(0);hv=(c[2415197]|0)+19|0;hw=a[9660784]|0}else{a[9660796]=t&-9;hv=(c[2415197]|0)+7|0;hw=S}c[2415197]=hv;a[9660784]=hw|16;r=c[3528554]|0;k=c[2433592]|0;o=c[k+(r*3148|0)+1068>>2]|0;do{if((o|0)==0){m=c[k+(r*3148|0)+3120>>2]|0;if((m|0)==0){hx=0;hy=0;break}l=gj[m&4095](-8)|0;m=c[3528554]|0;n=c[2433592]|0;e4=c[n+(m*3148|0)+1068>>2]|0;if((e4|0)!=0){hz=e4;hA=(l&255)<<8;h=41319;break}e4=c[n+(m*3148|0)+3120>>2]|0;if((e4|0)==0){hx=0;hy=(l&255)<<8;break}hx=gj[e4&4095](-7)|0;hy=(l&255)<<8}else{hz=o;hA=(d[o+248|0]|0)<<8;h=41319}}while(0);if((h|0)==41319){h=0;hx=a[hz+249|0]|0;hy=hA}o=hx&255|hy;c[2415188]=o;b[4830376]=o&65535}}while(0);z=(c[2440592]|0)-5|0;c[2440592]=z;g=z;break};case 54:{z=c[2415188]|0;o=c[3528554]|0;r=c[2433592]|0;k=c[r+(o*3148|0)+48+((z>>>8&255)<<2)>>2]|0;do{if((k|0)==0){S=c[r+(o*3148|0)+3132>>2]|0;if((S|0)==0){hB=0;hC=z&65535;break}t=gj[S&4095](z&65535)|0;hB=t;hC=b[4830376]|0}else{hB=a[k+(z&255)|0]|0;hC=z&65535}}while(0);z=hC+1&65535;b[4830376]=z;k=hB&255;if((k&128|0)!=0){b[4830384]=(b[4830384]|0)-1&65535;o=c[2415192]|0;r=c[3528554]|0;t=c[2433592]|0;S=c[t+(r*3148|0)+48+((o>>>8&255|256)<<2)>>2]|0;do{if((S|0)==0){l=c[t+(r*3148|0)+3124>>2]|0;if((l|0)==0){hD=r;hE=t;break}gg[l&4095](o&65535,z&255);hD=c[3528554]|0;hE=c[2433592]|0}else{a[S+(o&255)|0]=z&255;hD=r;hE=t}}while(0);b[4830384]=(b[4830384]|0)-1&65535;t=c[2415192]|0;r=a[9660753]|0;z=c[hE+(hD*3148|0)+48+((t>>>8&255|256)<<2)>>2]|0;do{if((z|0)==0){o=c[hE+(hD*3148|0)+3124>>2]|0;if((o|0)==0){break}gg[o&4095](t&65535,r)}else{a[z+(t&255)|0]=r}}while(0);c[2440592]=(c[2440592]|0)-2}if((k&64|0)!=0){b[4830384]=(b[4830384]|0)-1&65535;r=c[2415192]|0;t=a[9660772]|0;z=c[3528554]|0;o=c[2433592]|0;S=c[o+(z*3148|0)+48+((r>>>8&255|256)<<2)>>2]|0;do{if((S|0)==0){l=c[o+(z*3148|0)+3124>>2]|0;if((l|0)==0){hF=z;hG=o;break}gg[l&4095](r&65535,t);hF=c[3528554]|0;hG=c[2433592]|0}else{a[S+(r&255)|0]=t;hF=z;hG=o}}while(0);b[4830384]=(b[4830384]|0)-1&65535;o=c[2415192]|0;z=a[9660773]|0;t=c[hG+(hF*3148|0)+48+((o>>>8&255|256)<<2)>>2]|0;do{if((t|0)==0){r=c[hG+(hF*3148|0)+3124>>2]|0;if((r|0)==0){break}gg[r&4095](o&65535,z)}else{a[t+(o&255)|0]=z}}while(0);c[2440592]=(c[2440592]|0)-2}if((k&32|0)!=0){b[4830384]=(b[4830384]|0)-1&65535;z=c[2415192]|0;o=a[9660780]|0;t=c[3528554]|0;r=c[2433592]|0;S=c[r+(t*3148|0)+48+((z>>>8&255|256)<<2)>>2]|0;do{if((S|0)==0){l=c[r+(t*3148|0)+3124>>2]|0;if((l|0)==0){hH=t;hI=r;break}gg[l&4095](z&65535,o);hH=c[3528554]|0;hI=c[2433592]|0}else{a[S+(z&255)|0]=o;hH=t;hI=r}}while(0);b[4830384]=(b[4830384]|0)-1&65535;r=c[2415192]|0;t=a[9660781]|0;o=c[hI+(hH*3148|0)+48+((r>>>8&255|256)<<2)>>2]|0;do{if((o|0)==0){z=c[hI+(hH*3148|0)+3124>>2]|0;if((z|0)==0){break}gg[z&4095](r&65535,t)}else{a[o+(r&255)|0]=t}}while(0);c[2440592]=(c[2440592]|0)-2}if((k&16|0)!=0){b[4830384]=(b[4830384]|0)-1&65535;t=c[2415192]|0;r=a[9660776]|0;o=c[3528554]|0;z=c[2433592]|0;S=c[z+(o*3148|0)+48+((t>>>8&255|256)<<2)>>2]|0;do{if((S|0)==0){l=c[z+(o*3148|0)+3124>>2]|0;if((l|0)==0){hJ=o;hK=z;break}gg[l&4095](t&65535,r);hJ=c[3528554]|0;hK=c[2433592]|0}else{a[S+(t&255)|0]=r;hJ=o;hK=z}}while(0);b[4830384]=(b[4830384]|0)-1&65535;z=c[2415192]|0;o=a[9660777]|0;r=c[hK+(hJ*3148|0)+48+((z>>>8&255|256)<<2)>>2]|0;do{if((r|0)==0){t=c[hK+(hJ*3148|0)+3124>>2]|0;if((t|0)==0){break}gg[t&4095](z&65535,o)}else{a[r+(z&255)|0]=o}}while(0);c[2440592]=(c[2440592]|0)-2}if((k&8|0)!=0){b[4830384]=(b[4830384]|0)-1&65535;o=c[2415192]|0;z=a[9660765]|0;r=c[3528554]|0;t=c[2433592]|0;S=c[t+(r*3148|0)+48+((o>>>8&255|256)<<2)>>2]|0;do{if((S|0)==0){l=c[t+(r*3148|0)+3124>>2]|0;if((l|0)==0){break}gg[l&4095](o&65535,z)}else{a[S+(o&255)|0]=z}}while(0);c[2440592]=(c[2440592]|0)-1}if((k&4|0)!=0){b[4830384]=(b[4830384]|0)-1&65535;z=c[2415192]|0;o=a[9660760]|0;S=c[3528554]|0;r=c[2433592]|0;t=c[r+(S*3148|0)+48+((z>>>8&255|256)<<2)>>2]|0;do{if((t|0)==0){l=c[r+(S*3148|0)+3124>>2]|0;if((l|0)==0){break}gg[l&4095](z&65535,o)}else{a[t+(z&255)|0]=o}}while(0);c[2440592]=(c[2440592]|0)-1}if((k&2|0)!=0){b[4830384]=(b[4830384]|0)-1&65535;o=c[2415192]|0;z=a[9660761]|0;t=c[3528554]|0;S=c[2433592]|0;r=c[S+(t*3148|0)+48+((o>>>8&255|256)<<2)>>2]|0;do{if((r|0)==0){l=c[S+(t*3148|0)+3124>>2]|0;if((l|0)==0){break}gg[l&4095](o&65535,z)}else{a[r+(o&255)|0]=z}}while(0);c[2440592]=(c[2440592]|0)-1}if((k&1|0)==0){hL=c[2440592]|0}else{b[4830384]=(b[4830384]|0)-1&65535;z=c[2415192]|0;o=a[9660784]|0;r=c[3528554]|0;t=c[2433592]|0;S=c[t+(r*3148|0)+48+((z>>>8&255|256)<<2)>>2]|0;do{if((S|0)==0){l=c[t+(r*3148|0)+3124>>2]|0;if((l|0)==0){break}gg[l&4095](z&65535,o)}else{a[S+(z&255)|0]=o}}while(0);o=(c[2440592]|0)-1|0;c[2440592]=o;hL=o}o=hL-5|0;c[2440592]=o;g=o;break};default:{i=1}}}if(i){i=0;switch(j|0){case 55:{o=c[2415188]|0;z=c[3528554]|0;S=c[2433592]|0;r=c[S+(z*3148|0)+48+((o>>>8&255)<<2)>>2]|0;do{if((r|0)==0){t=c[S+(z*3148|0)+3132>>2]|0;if((t|0)==0){hM=0;hN=o&65535;break}k=gj[t&4095](o&65535)|0;hM=k;hN=b[4830376]|0}else{hM=a[r+(o&255)|0]|0;hN=o&65535}}while(0);b[4830376]=hN+1&65535;o=hM&255;if((o&1|0)!=0){r=c[2415192]|0;z=c[3528554]|0;S=c[2433592]|0;k=c[S+(z*3148|0)+48+((r>>>8&255)<<2)>>2]|0;do{if((k|0)==0){t=c[S+(z*3148|0)+3120>>2]|0;if((t|0)==0){hO=0;hP=r&65535;break}l=gj[t&4095](r&65535)|0;hO=l;hP=b[4830384]|0}else{hO=a[k+(r&255)|0]|0;hP=r&65535}}while(0);a[9660784]=hO;b[4830384]=hP+1&65535;c[2440592]=(c[2440592]|0)-1}if((o&2|0)!=0){r=c[2415192]|0;k=c[3528554]|0;z=c[2433592]|0;S=c[z+(k*3148|0)+48+((r>>>8&255)<<2)>>2]|0;do{if((S|0)==0){l=c[z+(k*3148|0)+3120>>2]|0;if((l|0)==0){hQ=0;hR=r&65535;break}t=gj[l&4095](r&65535)|0;hQ=t;hR=b[4830384]|0}else{hQ=a[S+(r&255)|0]|0;hR=r&65535}}while(0);a[9660761]=hQ;b[4830384]=hR+1&65535;c[2440592]=(c[2440592]|0)-1}if((o&4|0)!=0){r=c[2415192]|0;S=c[3528554]|0;k=c[2433592]|0;z=c[k+(S*3148|0)+48+((r>>>8&255)<<2)>>2]|0;do{if((z|0)==0){t=c[k+(S*3148|0)+3120>>2]|0;if((t|0)==0){hS=0;hT=r&65535;break}l=gj[t&4095](r&65535)|0;hS=l;hT=b[4830384]|0}else{hS=a[z+(r&255)|0]|0;hT=r&65535}}while(0);a[9660760]=hS;b[4830384]=hT+1&65535;c[2440592]=(c[2440592]|0)-1}if((o&8|0)!=0){r=c[2415192]|0;z=c[3528554]|0;S=c[2433592]|0;k=c[S+(z*3148|0)+48+((r>>>8&255)<<2)>>2]|0;do{if((k|0)==0){l=c[S+(z*3148|0)+3120>>2]|0;if((l|0)==0){hU=0;hV=r&65535;break}t=gj[l&4095](r&65535)|0;hU=t;hV=b[4830384]|0}else{hU=a[k+(r&255)|0]|0;hV=r&65535}}while(0);a[9660765]=hU;b[4830384]=hV+1&65535;c[2440592]=(c[2440592]|0)-1}if((o&16|0)!=0){r=c[2415192]|0;k=c[3528554]|0;z=c[2433592]|0;S=c[z+(k*3148|0)+48+((r>>>8&255)<<2)>>2]|0;do{if((S|0)==0){t=c[z+(k*3148|0)+3120>>2]|0;if((t|0)==0){hW=0;hX=r&65535;hY=k;hZ=z;break}l=gj[t&4095](r&65535)|0;hW=l;hX=b[4830384]|0;hY=c[3528554]|0;hZ=c[2433592]|0}else{hW=a[S+(r&255)|0]|0;hX=r&65535;hY=k;hZ=z}}while(0);z=(hW&255)<<8;c[2415194]=z;b[4830384]=hX+1&65535;k=c[2415192]|0;r=c[hZ+(hY*3148|0)+48+((k>>>8&255)<<2)>>2]|0;do{if((r|0)==0){S=c[hZ+(hY*3148|0)+3120>>2]|0;if((S|0)==0){h_=0;h$=z;h0=k&65535;break}l=gj[S&4095](k&65535)|0;h_=l;h$=c[2415194]|0;h0=b[4830384]|0}else{h_=a[r+(k&255)|0]|0;h$=z;h0=k&65535}}while(0);c[2415194]=h$|h_&255;b[4830384]=h0+1&65535;c[2440592]=(c[2440592]|0)-2}if((o&32|0)!=0){k=c[2415192]|0;z=c[3528554]|0;r=c[2433592]|0;l=c[r+(z*3148|0)+48+((k>>>8&255)<<2)>>2]|0;do{if((l|0)==0){S=c[r+(z*3148|0)+3120>>2]|0;if((S|0)==0){h1=0;h2=k&65535;h3=z;h4=r;break}t=gj[S&4095](k&65535)|0;h1=t;h2=b[4830384]|0;h3=c[3528554]|0;h4=c[2433592]|0}else{h1=a[l+(k&255)|0]|0;h2=k&65535;h3=z;h4=r}}while(0);r=(h1&255)<<8;c[2415195]=r;b[4830384]=h2+1&65535;z=c[2415192]|0;k=c[h4+(h3*3148|0)+48+((z>>>8&255)<<2)>>2]|0;do{if((k|0)==0){l=c[h4+(h3*3148|0)+3120>>2]|0;if((l|0)==0){h5=0;h6=r;h7=z&65535;break}t=gj[l&4095](z&65535)|0;h5=t;h6=c[2415195]|0;h7=b[4830384]|0}else{h5=a[k+(z&255)|0]|0;h6=r;h7=z&65535}}while(0);c[2415195]=h6|h5&255;b[4830384]=h7+1&65535;c[2440592]=(c[2440592]|0)-2}if((o&64|0)!=0){z=c[2415192]|0;r=c[3528554]|0;k=c[2433592]|0;t=c[k+(r*3148|0)+48+((z>>>8&255)<<2)>>2]|0;do{if((t|0)==0){l=c[k+(r*3148|0)+3120>>2]|0;if((l|0)==0){h8=0;h9=z&65535;ia=r;ib=k;break}S=gj[l&4095](z&65535)|0;h8=S;h9=b[4830384]|0;ia=c[3528554]|0;ib=c[2433592]|0}else{h8=a[t+(z&255)|0]|0;h9=z&65535;ia=r;ib=k}}while(0);k=(h8&255)<<8;c[2415193]=k;b[4830384]=h9+1&65535;r=c[2415192]|0;z=c[ib+(ia*3148|0)+48+((r>>>8&255)<<2)>>2]|0;do{if((z|0)==0){t=c[ib+(ia*3148|0)+3120>>2]|0;if((t|0)==0){ic=0;id=k;ie=r&65535;break}S=gj[t&4095](r&65535)|0;ic=S;id=c[2415193]|0;ie=b[4830384]|0}else{ic=a[z+(r&255)|0]|0;id=k;ie=r&65535}}while(0);c[2415193]=id|ic&255;b[4830384]=ie+1&65535;c[2440592]=(c[2440592]|0)-2}if((o&128|0)!=0){r=c[2415192]|0;k=c[3528554]|0;z=c[2433592]|0;S=c[z+(k*3148|0)+48+((r>>>8&255)<<2)>>2]|0;do{if((S|0)==0){t=c[z+(k*3148|0)+3120>>2]|0;if((t|0)==0){ig=0;ih=r&65535;ii=k;ij=z;break}l=gj[t&4095](r&65535)|0;ig=l;ih=b[4830384]|0;ii=c[3528554]|0;ij=c[2433592]|0}else{ig=a[S+(r&255)|0]|0;ih=r&65535;ii=k;ij=z}}while(0);z=(ig&255)<<8;c[2415188]=z;b[4830384]=ih+1&65535;k=c[2415192]|0;r=c[ij+(ii*3148|0)+48+((k>>>8&255)<<2)>>2]|0;do{if((r|0)==0){S=c[ij+(ii*3148|0)+3120>>2]|0;if((S|0)==0){ik=0;il=z;im=k&65535;break}l=gj[S&4095](k&65535)|0;ik=l;il=c[2415188]|0;im=b[4830384]|0}else{ik=a[r+(k&255)|0]|0;il=z;im=k&65535}}while(0);k=il|ik&255;c[2415188]=k;b[4830384]=im+1&65535;b[4830376]=k&65535;c[2440592]=(c[2440592]|0)-2}L50781:do{if((o&1|0)!=0){k=a[9660786]|0;z=a[9660787]|0;if((z|k)<<24>>24!=0){a[9660796]=a[9660796]&-17}do{if(z<<24>>24!=0){r=a[9660784]|0;if((r&64)!=0){break}l=a[9660796]|0;if((l&8)==0){a[9660784]=r&127;b[4830386]=(b[4830386]|0)-1&65535;S=c[2415193]|0;t=a[9660752]|0;e4=c[3528554]|0;m=c[2433592]|0;n=c[m+(e4*3148|0)+48+((S>>>8&255|256)<<2)>>2]|0;do{if((n|0)==0){s=c[m+(e4*3148|0)+3124>>2]|0;if((s|0)==0){io=e4;ip=m;break}gg[s&4095](S&65535,t);io=c[3528554]|0;ip=c[2433592]|0}else{a[n+(S&255)|0]=t;io=e4;ip=m}}while(0);b[4830386]=(b[4830386]|0)-1&65535;m=c[2415193]|0;e4=a[9660753]|0;t=c[ip+(io*3148|0)+48+((m>>>8&255|256)<<2)>>2]|0;do{if((t|0)==0){S=c[ip+(io*3148|0)+3124>>2]|0;if((S|0)==0){iq=io;ir=ip;break}gg[S&4095](m&65535,e4);iq=c[3528554]|0;ir=c[2433592]|0}else{a[t+(m&255)|0]=e4;iq=io;ir=ip}}while(0);b[4830386]=(b[4830386]|0)-1&65535;e4=c[2415193]|0;m=a[9660784]|0;t=c[ir+(iq*3148|0)+48+((e4>>>8&255|256)<<2)>>2]|0;do{if((t|0)==0){S=c[ir+(iq*3148|0)+3124>>2]|0;if((S|0)==0){break}gg[S&4095](e4&65535,m)}else{a[t+(e4&255)|0]=m}}while(0);is=(c[2415197]|0)+10|0;it=a[9660784]|0}else{a[9660796]=l&-9;is=(c[2415197]|0)+7|0;it=r}c[2415197]=is;a[9660784]=it|80;m=c[3528554]|0;e4=c[2433592]|0;t=c[e4+(m*3148|0)+1068>>2]|0;do{if((t|0)==0){S=c[e4+(m*3148|0)+3120>>2]|0;if((S|0)==0){iu=0;iv=0;break}n=gj[S&4095](-10)|0;S=c[3528554]|0;s=c[2433592]|0;e5=c[s+(S*3148|0)+1068>>2]|0;if((e5|0)!=0){iw=e5;ix=(n&255)<<8;h=41486;break}e5=c[s+(S*3148|0)+3120>>2]|0;if((e5|0)==0){iu=0;iv=(n&255)<<8;break}iu=gj[e5&4095](-9)|0;iv=(n&255)<<8}else{iw=t;ix=(d[t+246|0]|0)<<8;h=41486}}while(0);if((h|0)==41486){h=0;iu=a[iw+247|0]|0;iv=ix}t=iu&255|iv;c[2415188]=t;b[4830376]=t&65535;break L50781}}while(0);if(k<<24>>24==0){break}z=a[9660784]|0;if((z&16)!=0){break}t=a[9660796]|0;if((t&8)==0){a[9660784]=z|-128;b[4830386]=(b[4830386]|0)-1&65535;m=c[2415193]|0;e4=a[9660752]|0;r=c[3528554]|0;l=c[2433592]|0;n=c[l+(r*3148|0)+48+((m>>>8&255|256)<<2)>>2]|0;do{if((n|0)==0){e5=c[l+(r*3148|0)+3124>>2]|0;if((e5|0)==0){iy=r;iz=l;break}gg[e5&4095](m&65535,e4);iy=c[3528554]|0;iz=c[2433592]|0}else{a[n+(m&255)|0]=e4;iy=r;iz=l}}while(0);b[4830386]=(b[4830386]|0)-1&65535;l=c[2415193]|0;r=a[9660753]|0;e4=c[iz+(iy*3148|0)+48+((l>>>8&255|256)<<2)>>2]|0;do{if((e4|0)==0){m=c[iz+(iy*3148|0)+3124>>2]|0;if((m|0)==0){iA=iy;iB=iz;break}gg[m&4095](l&65535,r);iA=c[3528554]|0;iB=c[2433592]|0}else{a[e4+(l&255)|0]=r;iA=iy;iB=iz}}while(0);b[4830386]=(b[4830386]|0)-1&65535;r=c[2415193]|0;l=a[9660768]|0;e4=c[iB+(iA*3148|0)+48+((r>>>8&255|256)<<2)>>2]|0;do{if((e4|0)==0){m=c[iB+(iA*3148|0)+3124>>2]|0;if((m|0)==0){iC=iA;iD=iB;break}gg[m&4095](r&65535,l);iC=c[3528554]|0;iD=c[2433592]|0}else{a[e4+(r&255)|0]=l;iC=iA;iD=iB}}while(0);b[4830386]=(b[4830386]|0)-1&65535;l=c[2415193]|0;r=a[9660769]|0;e4=c[iD+(iC*3148|0)+48+((l>>>8&255|256)<<2)>>2]|0;do{if((e4|0)==0){m=c[iD+(iC*3148|0)+3124>>2]|0;if((m|0)==0){iE=iC;iF=iD;break}gg[m&4095](l&65535,r);iE=c[3528554]|0;iF=c[2433592]|0}else{a[e4+(l&255)|0]=r;iE=iC;iF=iD}}while(0);b[4830386]=(b[4830386]|0)-1&65535;r=c[2415193]|0;l=a[9660780]|0;e4=c[iF+(iE*3148|0)+48+((r>>>8&255|256)<<2)>>2]|0;do{if((e4|0)==0){m=c[iF+(iE*3148|0)+3124>>2]|0;if((m|0)==0){iG=iE;iH=iF;break}gg[m&4095](r&65535,l);iG=c[3528554]|0;iH=c[2433592]|0}else{a[e4+(r&255)|0]=l;iG=iE;iH=iF}}while(0);b[4830386]=(b[4830386]|0)-1&65535;l=c[2415193]|0;r=a[9660781]|0;e4=c[iH+(iG*3148|0)+48+((l>>>8&255|256)<<2)>>2]|0;do{if((e4|0)==0){m=c[iH+(iG*3148|0)+3124>>2]|0;if((m|0)==0){iI=iG;iJ=iH;break}gg[m&4095](l&65535,r);iI=c[3528554]|0;iJ=c[2433592]|0}else{a[e4+(l&255)|0]=r;iI=iG;iJ=iH}}while(0);b[4830386]=(b[4830386]|0)-1&65535;r=c[2415193]|0;l=a[9660776]|0;e4=c[iJ+(iI*3148|0)+48+((r>>>8&255|256)<<2)>>2]|0;do{if((e4|0)==0){m=c[iJ+(iI*3148|0)+3124>>2]|0;if((m|0)==0){iK=iI;iL=iJ;break}gg[m&4095](r&65535,l);iK=c[3528554]|0;iL=c[2433592]|0}else{a[e4+(r&255)|0]=l;iK=iI;iL=iJ}}while(0);b[4830386]=(b[4830386]|0)-1&65535;l=c[2415193]|0;r=a[9660777]|0;e4=c[iL+(iK*3148|0)+48+((l>>>8&255|256)<<2)>>2]|0;do{if((e4|0)==0){m=c[iL+(iK*3148|0)+3124>>2]|0;if((m|0)==0){iM=iK;iN=iL;break}gg[m&4095](l&65535,r);iM=c[3528554]|0;iN=c[2433592]|0}else{a[e4+(l&255)|0]=r;iM=iK;iN=iL}}while(0);b[4830386]=(b[4830386]|0)-1&65535;r=c[2415193]|0;l=a[9660765]|0;e4=c[iN+(iM*3148|0)+48+((r>>>8&255|256)<<2)>>2]|0;do{if((e4|0)==0){m=c[iN+(iM*3148|0)+3124>>2]|0;if((m|0)==0){iO=iM;iP=iN;break}gg[m&4095](r&65535,l);iO=c[3528554]|0;iP=c[2433592]|0}else{a[e4+(r&255)|0]=l;iO=iM;iP=iN}}while(0);b[4830386]=(b[4830386]|0)-1&65535;l=c[2415193]|0;r=a[9660760]|0;e4=c[iP+(iO*3148|0)+48+((l>>>8&255|256)<<2)>>2]|0;do{if((e4|0)==0){m=c[iP+(iO*3148|0)+3124>>2]|0;if((m|0)==0){iQ=iO;iR=iP;break}gg[m&4095](l&65535,r);iQ=c[3528554]|0;iR=c[2433592]|0}else{a[e4+(l&255)|0]=r;iQ=iO;iR=iP}}while(0);b[4830386]=(b[4830386]|0)-1&65535;r=c[2415193]|0;l=a[9660761]|0;e4=c[iR+(iQ*3148|0)+48+((r>>>8&255|256)<<2)>>2]|0;do{if((e4|0)==0){m=c[iR+(iQ*3148|0)+3124>>2]|0;if((m|0)==0){iS=iQ;iT=iR;break}gg[m&4095](r&65535,l);iS=c[3528554]|0;iT=c[2433592]|0}else{a[e4+(r&255)|0]=l;iS=iQ;iT=iR}}while(0);b[4830386]=(b[4830386]|0)-1&65535;l=c[2415193]|0;r=a[9660784]|0;e4=c[iT+(iS*3148|0)+48+((l>>>8&255|256)<<2)>>2]|0;do{if((e4|0)==0){m=c[iT+(iS*3148|0)+3124>>2]|0;if((m|0)==0){break}gg[m&4095](l&65535,r)}else{a[e4+(l&255)|0]=r}}while(0);iU=(c[2415197]|0)+19|0;iV=a[9660784]|0}else{a[9660796]=t&-9;iU=(c[2415197]|0)+7|0;iV=z}c[2415197]=iU;a[9660784]=iV|16;r=c[3528554]|0;l=c[2433592]|0;e4=c[l+(r*3148|0)+1068>>2]|0;do{if((e4|0)==0){m=c[l+(r*3148|0)+3120>>2]|0;if((m|0)==0){iW=0;iX=0;break}n=gj[m&4095](-8)|0;m=c[3528554]|0;k=c[2433592]|0;e5=c[k+(m*3148|0)+1068>>2]|0;if((e5|0)!=0){iY=e5;iZ=(n&255)<<8;h=41547;break}e5=c[k+(m*3148|0)+3120>>2]|0;if((e5|0)==0){iW=0;iX=(n&255)<<8;break}iW=gj[e5&4095](-7)|0;iX=(n&255)<<8}else{iY=e4;iZ=(d[e4+248|0]|0)<<8;h=41547}}while(0);if((h|0)==41547){h=0;iW=a[iY+249|0]|0;iX=iZ}e4=iW&255|iX;c[2415188]=e4;b[4830376]=e4&65535}}while(0);o=(c[2440592]|0)-5|0;c[2440592]=o;g=o;break};case 56:{o=(c[2440592]|0)-2|0;c[2440592]=o;g=o;break};case 57:{o=c[2415193]|0;e4=c[3528554]|0;r=c[2433592]|0;l=c[r+(e4*3148|0)+48+((o>>>8&255)<<2)>>2]|0;do{if((l|0)==0){z=c[r+(e4*3148|0)+3120>>2]|0;if((z|0)==0){i_=0;i$=o&65535;i0=e4;i1=r;break}t=gj[z&4095](o&65535)|0;i_=t;i$=b[4830386]|0;i0=c[3528554]|0;i1=c[2433592]|0}else{i_=a[l+(o&255)|0]|0;i$=o&65535;i0=e4;i1=r}}while(0);r=(i_&255)<<8;c[2415188]=r;b[4830386]=i$+1&65535;e4=c[2415193]|0;o=c[i1+(i0*3148|0)+48+((e4>>>8&255)<<2)>>2]|0;do{if((o|0)==0){l=c[i1+(i0*3148|0)+3120>>2]|0;if((l|0)==0){i2=0;i3=r;i4=e4&65535;break}t=gj[l&4095](e4&65535)|0;i2=t;i3=c[2415188]|0;i4=b[4830386]|0}else{i2=a[o+(e4&255)|0]|0;i3=r;i4=e4&65535}}while(0);e4=i3|i2&255;c[2415188]=e4;b[4830386]=i4+1&65535;b[4830376]=e4&65535;e4=(c[2440592]|0)-5|0;c[2440592]=e4;g=e4;break};case 58:{b[4830388]=(b[4830388]|0)+(d[9660760]|0)&65535;e4=(c[2440592]|0)-3|0;c[2440592]=e4;g=e4;break};default:{i=1}}}}while(0);c[f+51624>>2]=g;c[f+51656>>2]=h;c[f+51664>>2]=i}function __Z8s2650Runi$0(e){e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0,cf=0,cg=0,ch=0,ci=0,cj=0,ck=0,cl=0,cm=0,cn=0,co=0,cp=0,cq=0,cr=0,cs=0,ct=0,cu=0,cv=0,cw=0,cx=0,cy=0,cz=0,cA=0,cB=0,cC=0,cD=0,cE=0,cF=0,cG=0,cH=0,cI=0,cJ=0,cK=0,cL=0,cM=0,cN=0,cO=0,cP=0,cQ=0,cR=0,cS=0,cT=0,cU=0,cV=0,cW=0,cX=0,cY=0,cZ=0,c_=0,c$=0,c0=0,c1=0,c2=0,c3=0,c4=0,c5=0,c6=0,c7=0,c8=0,c9=0,da=0,db=0,dc=0,dd=0,de=0,df=0,dg=0,dh=0,di=0,dj=0,dk=0,dl=0,dm=0,dn=0,dp=0,dq=0,dr=0,ds=0,dt=0,du=0,dv=0,dw=0,dx=0,dy=0;f=c[e+72>>2]|0;g=c[e+88>>2]|0;h=c[e+96>>2]|0;i=c[e+13928>>2]|0;j=c[e+13952>>2]|0;k=c[e+13960>>2]|0;l=c[e+13968>>2]|0;OL:do{if(k){k=0;switch(l|0){case 119:{c[2440218]=(c[2440218]|0)-9;m=(b[4859069]|0)+g&32767;n=c[2110940]|0;o=c[n+1040+((m&65535)>>>8<<2)>>2]|0;do{if((o|0)==0){p=c[n+16+((m&65535)>>>8<<2)>>2]|0;if((p|0)!=0){q=a[p+(m&65535&255)|0]|0;r=g;j=54372;break}p=c[n>>2]|0;if((p|0)==0){b[4859070]=f+2&8191;s=0;t=a[9718144]|0;break}else{u=gj[p&4095](m)|0;q=u;r=b[4859070]|0;j=54372;break}}else{q=a[o+(m&65535&255)|0]|0;r=g;j=54372}}while(0);do{if((j|0)==54372){j=0;b[4859070]=r+1&8191;m=a[9718144]|0;if((q&16)==0){s=q;t=m;break}if((m&16)!=0){s=q;t=m;break}o=a[9718148]|0;a[9718148]=a[9718151]|0;a[9718151]=o;o=a[9718149]|0;a[9718149]=a[9718152]|0;a[9718152]=o;o=a[9718150]|0;a[9718150]=a[9718153]|0;a[9718153]=o;s=q;t=m}}while(0);a[9718144]=t|s;j=55018;break};case 117:{c[2440218]=(c[2440218]|0)-9;m=(b[4859069]|0)+g&32767;o=c[2110940]|0;n=c[o+1040+((m&65535)>>>8<<2)>>2]|0;do{if((n|0)==0){u=c[o+16+((m&65535)>>>8<<2)>>2]|0;if((u|0)!=0){v=a[u+(m&65535&255)|0]|0;w=g;j=54338;break}u=c[o>>2]|0;if((u|0)==0){b[4859070]=f+2&8191;x=g;y=0;z=a[9718144]|0;break}else{p=gj[u&4095](m)|0;v=p;w=b[4859070]|0;j=54338;break}}else{v=a[n+(m&65535&255)|0]|0;w=g;j=54338}}while(0);do{if((j|0)==54338){j=0;b[4859070]=w+1&8191;m=a[9718144]|0;if((v&16)==0){x=w;y=v;z=m;break}if((m&16)==0){x=w;y=v;z=m;break}n=a[9718148]|0;a[9718148]=a[9718151]|0;a[9718151]=n;n=a[9718149]|0;a[9718149]=a[9718152]|0;a[9718152]=n;n=a[9718150]|0;a[9718150]=a[9718153]|0;a[9718153]=n;x=w;y=v;z=m}}while(0);a[9718144]=z&~y;if((a[9718172]|0)==0){j=55018;c[e+13976>>2]=2;c[e+13980>>2]=33;break OL}if((a[9718145]&32)!=0){j=55018;c[e+13976>>2]=2;c[e+13980>>2]=33;break OL}if((a[9718154]|0)!=0){a[9718154]=0;b[4859070]=x+2&8191}m=c[8449976+(c[2444]<<2)>>2]|0;if((m|0)==0){A=0}else{A=(gj[m&4095](0)|0)&255}m=c[5093528+(A<<2)>>2]&8191;b[4859071]=m;if((A&128|0)!=0){c[2440218]=(c[2440218]|0)-6;n=c[2110940]|0;o=c[n+16+((m&65535)>>>8<<2)>>2]|0;do{if((o|0)==0){p=c[n>>2]|0;if((p|0)==0){B=0;C=n;break}u=gj[p&4095](m)|0;B=u;C=c[2110940]|0}else{B=a[o+(m&65535&255)|0]|0;C=n}}while(0);n=(B&255)<<8;b[4859071]=n;o=((((m&65535)+1|0)&8191|0)==0?m+24577&65535:((m&65535)+1|0)&65535)&32767;u=c[C+16+((o&65535)>>>8<<2)>>2]|0;do{if((u|0)==0){p=c[C>>2]|0;if((p|0)==0){D=0;break}D=gj[p&4095](o)|0}else{D=a[u+(o&65535&255)|0]|0}}while(0);b[4859071]=D&255|n&32512}o=a[9718145]|0;a[9718145]=o&-40|o+1&255&7|32;b[9718156+((o+1&255&7)<<1)>>1]=(b[4859070]|0)+(b[4859069]|0)&65535;o=b[4859071]|0;b[4859069]=o&24576;b[4859070]=o&8191;j=55018;break};case 136:case 137:case 138:case 139:{c[2440218]=(c[2440218]|0)-9;o=b[4859069]|0;u=c[2110940]|0;m=c[u+1040+((o+g&32767&65535)>>>8<<2)>>2]|0;do{if((m|0)==0){p=c[u+16+((o+g&32767&65535)>>>8<<2)>>2]|0;if((p|0)!=0){E=a[p+(o+g&32767&65535&255)|0]|0;F=g;G=o;break}p=c[u>>2]|0;if((p|0)==0){E=0;F=g;G=o;break}H=gj[p&4095](o+g&32767)|0;E=H;F=b[4859070]|0;G=b[4859069]|0}else{E=a[m+(o+g&32767&65535&255)|0]|0;F=g;G=o}}while(0);o=F+1&65535;b[4859070]=o&8191;m=E&255;u=((o&65535)+(c[5093528+(m<<2)>>2]|0)&8191)+(G&65535)|0;b[4859071]=u&65535;if((m&128|0)==0){I=u&65535}else{c[2440218]=(c[2440218]|0)-6;m=c[2110940]|0;o=c[m+16+((u&65535&32767&65535)>>>8<<2)>>2]|0;do{if((o|0)==0){n=c[m>>2]|0;if((n|0)==0){J=0;K=m;break}H=gj[n&4095](u&65535&32767)|0;J=H;K=c[2110940]|0}else{J=a[o+(u&65535&32767&65535&255)|0]|0;K=m}}while(0);m=(J&255)<<8;b[4859071]=m;o=(((u+1|0)&8191|0)==0?u+24577|0:u+1|0)&32767;H=c[K+16+((o&65535)>>>8<<2)>>2]|0;do{if((H|0)==0){n=c[K>>2]|0;if((n|0)==0){L=0;break}L=gj[n&4095](o)|0}else{L=a[H+(o&65535&255)|0]|0}}while(0);o=L&255|m&32512;b[4859071]=o;I=o}o=I&32767;H=c[2110940]|0;u=c[H+16+((o&65535)>>>8<<2)>>2]|0;do{if((u|0)==0){n=c[H>>2]|0;if((n|0)==0){M=0;break}M=gj[n&4095](o)|0}else{M=a[u+(o&65535&255)|0]|0}}while(0);o=9718147+(d[9718146]|0)|0;u=a[o]|0;H=a[9718144]|0;m=(u&255)+(M&255)+(H&255&1&(H&255)>>>3)|0;a[9718144]=m>>>8&1|H&-38;a[o]=m&255;m=9718147+(d[9718146]|0)|0;o=a[m]|0;H=a[9718144]|0;if((o&15)>>>0<(u&255&15)>>>0){a[9718144]=H|32;N=a[m]|0;O=H|32}else{N=o;O=H}a[9718144]=a[680792+(((N^u)&255&((u^M)&255^128))<<1&256|N&255)|0]|O&59;j=55018;break};case 120:case 121:case 122:case 123:{c[2440218]=(c[2440218]|0)-9;if((a[9718147+(h&255)|0]|0)==0){b[4859070]=f+2&8191;j=55018;c[e+13976>>2]=2;c[e+13980>>2]=33;break OL}u=b[4859069]|0;H=c[2110940]|0;o=c[H+1040+((u+g&32767&65535)>>>8<<2)>>2]|0;do{if((o|0)==0){m=c[H+16+((u+g&32767&65535)>>>8<<2)>>2]|0;if((m|0)!=0){P=a[m+(u+g&32767&65535&255)|0]|0;Q=g;R=u;break}m=c[H>>2]|0;if((m|0)==0){P=0;Q=g;R=u;break}n=gj[m&4095](u+g&32767)|0;P=n;Q=b[4859070]|0;R=b[4859069]|0}else{P=a[o+(u+g&32767&65535&255)|0]|0;Q=g;R=u}}while(0);u=Q+1&65535;b[4859070]=u&8191;o=P&255;H=((u&65535)+(c[5093528+(o<<2)>>2]|0)&8191)+(R&65535)|0;b[4859071]=H&65535;if((o&128|0)==0){S=R;T=u&8191}else{c[2440218]=(c[2440218]|0)-6;u=c[2110940]|0;o=c[u+16+((H&65535&32767&65535)>>>8<<2)>>2]|0;do{if((o|0)==0){n=c[u>>2]|0;if((n|0)==0){U=0;V=u;break}m=gj[n&4095](H&65535&32767)|0;U=m;V=c[2110940]|0}else{U=a[o+(H&65535&32767&65535&255)|0]|0;V=u}}while(0);u=(U&255)<<8;b[4859071]=u;o=(((H+1|0)&8191|0)==0?H+24577|0:H+1|0)&32767;m=c[V+16+((o&65535)>>>8<<2)>>2]|0;do{if((m|0)==0){n=c[V>>2]|0;if((n|0)==0){W=0;break}W=gj[n&4095](o)|0}else{W=a[m+(o&65535&255)|0]|0}}while(0);b[4859071]=W&255|u&32512;S=b[4859069]|0;T=b[4859070]|0}o=a[9718145]|0;a[9718145]=o+1&255&7|o&-8;b[9718156+((o+1&255&7)<<1)>>1]=S+T&65535;o=b[4859071]|0;b[4859069]=o&24576;b[4859070]=o&8191;j=55018;break};case 144:case 145:{o=(c[2440218]|0)-7|0;c[2440218]=o;i=o;break};case 146:{c[2440218]=(c[2440218]|0)-6;a[9718145]=a[9718147]&103;j=55018;break};case 60:case 61:case 62:{c[2440218]=(c[2440218]|0)-9;if(((d[9718144]|0)>>>6|0)!=(h&255|0)){b[4859070]=f+3&8191;j=55018;c[e+13976>>2]=2;c[e+13980>>2]=33;break OL}o=b[4859069]|0;m=c[2110940]|0;H=c[m+1040+((o+g&32767&65535)>>>8<<2)>>2]|0;do{if((H|0)==0){n=c[m+16+((o+g&32767&65535)>>>8<<2)>>2]|0;if((n|0)!=0){X=a[n+(o+g&32767&65535&255)|0]|0;Y=g;Z=o;_=m;break}n=c[m>>2]|0;if((n|0)==0){X=0;Y=g;Z=o;_=m;break}p=gj[n&4095](o+g&32767)|0;X=p;Y=b[4859070]|0;Z=b[4859069]|0;_=c[2110940]|0}else{X=a[H+(o+g&32767&65535&255)|0]|0;Y=g;Z=o;_=m}}while(0);m=Y+1&8191;b[4859070]=m;o=m+Z&32767;H=c[_+1040+((o&65535)>>>8<<2)>>2]|0;do{if((H|0)==0){u=c[_+16+((o&65535)>>>8<<2)>>2]|0;if((u|0)!=0){$=a[u+(o&65535&255)|0]|0;aa=m;break}u=c[_>>2]|0;if((u|0)==0){$=0;aa=m;break}p=gj[u&4095](o)|0;$=p;aa=b[4859070]|0}else{$=a[H+(o&65535&255)|0]|0;aa=m}}while(0);m=aa+1&8191;b[4859070]=m;o=X&255;H=$&255;b[4859071]=(H|o<<8&32512)&65535;if((o&128|0)==0){ab=m}else{c[2440218]=(c[2440218]|0)-6;m=c[2110940]|0;p=c[m+16+((o<<8&32512)>>>8<<2)>>2]|0;do{if((p|0)==0){u=c[m>>2]|0;if((u|0)==0){ac=0;ad=m;break}n=gj[u&4095]((H|o<<8&32512)&65535)|0;ac=n;ad=c[2110940]|0}else{ac=a[p+H|0]|0;ad=m}}while(0);m=(ac&255)<<8;b[4859071]=m;p=((((H|o<<8&32512)+1|0)&8191|0)==0?(H|o<<8&32512)+24577|0:(H|o<<8&32512)+1|0)&32767;n=c[ad+16+((p&65535)>>>8<<2)>>2]|0;do{if((n|0)==0){u=c[ad>>2]|0;if((u|0)==0){ae=0;break}ae=gj[u&4095](p)|0}else{ae=a[n+(p&65535&255)|0]|0}}while(0);b[4859071]=ae&255|m&32512;ab=b[4859070]|0}p=a[9718145]|0;a[9718145]=p+1&255&7|p&-8;b[9718156+((p+1&255&7)<<1)>>1]=(b[4859069]|0)+ab&65535;p=b[4859071]|0;b[4859069]=p&24576;b[4859070]=p&8191;j=55018;break};case 27:{c[2440218]=(c[2440218]|0)-9;p=b[4859069]|0;n=c[2110940]|0;o=c[n+1040+((p+g&32767&65535)>>>8<<2)>>2]|0;do{if((o|0)==0){H=c[n+16+((p+g&32767&65535)>>>8<<2)>>2]|0;if((H|0)!=0){af=a[H+(p+g&32767&65535&255)|0]|0;ag=g;ah=p;break}H=c[n>>2]|0;if((H|0)==0){af=0;ag=g;ah=p;break}u=gj[H&4095](p+g&32767)|0;af=u;ag=b[4859070]|0;ah=b[4859069]|0}else{af=a[o+(p+g&32767&65535&255)|0]|0;ag=g;ah=p}}while(0);p=ag+1&65535;b[4859070]=p&8191;o=af&255;n=((p&65535)+(c[5093528+(o<<2)>>2]|0)&8191)+(ah&65535)|0;b[4859071]=n&65535;if((o&128|0)==0){ai=n&65535}else{c[2440218]=(c[2440218]|0)-6;o=c[2110940]|0;p=c[o+16+((n&65535&32767&65535)>>>8<<2)>>2]|0;do{if((p|0)==0){m=c[o>>2]|0;if((m|0)==0){aj=0;ak=o;break}u=gj[m&4095](n&65535&32767)|0;aj=u;ak=c[2110940]|0}else{aj=a[p+(n&65535&32767&65535&255)|0]|0;ak=o}}while(0);o=(aj&255)<<8;b[4859071]=o;p=(((n+1|0)&8191|0)==0?n+24577|0:n+1|0)&32767;u=c[ak+16+((p&65535)>>>8<<2)>>2]|0;do{if((u|0)==0){m=c[ak>>2]|0;if((m|0)==0){al=0;break}al=gj[m&4095](p)|0}else{al=a[u+(p&65535&255)|0]|0}}while(0);p=al&255|o&32512;b[4859071]=p;ai=p}b[4859069]=ai&24576;b[4859070]=ai&8191;j=55018;break};case 118:{c[2440218]=(c[2440218]|0)-9;p=(b[4859069]|0)+g&32767;u=c[2110940]|0;n=c[u+1040+((p&65535)>>>8<<2)>>2]|0;do{if((n|0)==0){m=c[u+16+((p&65535)>>>8<<2)>>2]|0;if((m|0)!=0){am=a[m+(p&65535&255)|0]|0;an=g;break}m=c[u>>2]|0;if((m|0)==0){am=0;an=g;break}H=gj[m&4095](p)|0;am=H;an=b[4859070]|0}else{am=a[n+(p&65535&255)|0]|0;an=g}}while(0);b[4859070]=an+1&8191;a[9718145]=a[9718145]|am&103;j=55018;break};case 44:case 45:case 46:case 47:{c[2440218]=(c[2440218]|0)-12;p=b[4859069]|0;n=c[2110940]|0;u=c[n+1040+((p+g&32767&65535)>>>8<<2)>>2]|0;do{if((u|0)==0){o=c[n+16+((p+g&32767&65535)>>>8<<2)>>2]|0;if((o|0)!=0){ao=a[o+(p+g&32767&65535&255)|0]|0;ap=g;aq=p;ar=n;break}o=c[n>>2]|0;if((o|0)==0){ao=0;ap=g;aq=p;ar=n;break}H=gj[o&4095](p+g&32767)|0;ao=H;ap=b[4859070]|0;aq=b[4859069]|0;ar=c[2110940]|0}else{ao=a[u+(p+g&32767&65535&255)|0]|0;ap=g;aq=p;ar=n}}while(0);n=ap+1&8191;b[4859070]=n;p=n+aq&32767;u=c[ar+1040+((p&65535)>>>8<<2)>>2]|0;do{if((u|0)==0){H=c[ar+16+((p&65535)>>>8<<2)>>2]|0;if((H|0)!=0){as=a[H+(p&65535&255)|0]|0;at=n;au=aq;break}H=c[ar>>2]|0;if((H|0)==0){as=0;at=n;au=aq;break}o=gj[H&4095](p)|0;as=o;at=b[4859070]|0;au=b[4859069]|0}else{as=a[u+(p&65535&255)|0]|0;at=n;au=aq}}while(0);b[4859070]=at+1&8191;n=ao&255;p=(au&65535)+(as&255|n<<8&7936)|0;b[4859071]=p&65535;if((n&128|0)==0){av=p&65535}else{c[2440218]=(c[2440218]|0)-6;u=c[2110940]|0;o=c[u+16+((p&65535&32767&65535)>>>8<<2)>>2]|0;do{if((o|0)==0){H=c[u>>2]|0;if((H|0)==0){aw=0;ax=u;break}m=gj[H&4095](p&65535&32767)|0;aw=m;ax=c[2110940]|0}else{aw=a[o+(p&65535&32767&65535&255)|0]|0;ax=u}}while(0);u=(aw&255)<<8;b[4859071]=u;o=(((p+1|0)&8191|0)==0?p+24577|0:p+1|0)&32767;m=c[ax+16+((o&65535)>>>8<<2)>>2]|0;do{if((m|0)==0){H=c[ax>>2]|0;if((H|0)==0){ay=0;break}ay=gj[H&4095](o)|0}else{ay=a[m+(o&65535&255)|0]|0}}while(0);o=ay&255|u&32512;b[4859071]=o;av=o}if((n&96|0)==32){o=9718147+(d[9718146]|0)|0;a[o]=(a[o]|0)+1&255;o=b[4859071]|0;m=(d[9718147+(d[9718146]|0)|0]|0)+o&8191|o&24576;b[4859071]=m;a[9718146]=0;az=m}else if((n&96|0)==64){m=9718147+(d[9718146]|0)|0;a[m]=(a[m]|0)-1&255;m=b[4859071]|0;o=(d[9718147+(d[9718146]|0)|0]|0)+m&8191|m&24576;b[4859071]=o;a[9718146]=0;az=o}else if((n&96|0)==96){o=(d[9718147+(d[9718146]|0)|0]|0)+av&8191|av&24576;b[4859071]=o;a[9718146]=0;az=o}else{az=av}o=az&32767;m=c[2110940]|0;p=c[m+16+((o&65535)>>>8<<2)>>2]|0;do{if((p|0)==0){H=c[m>>2]|0;if((H|0)==0){aA=0;break}aA=gj[H&4095](o)|0}else{aA=a[p+(o&65535&255)|0]|0}}while(0);o=9718147+(d[9718146]|0)|0;a[o]=a[o]^aA;a[9718144]=a[680792+(d[9718147+(d[9718146]|0)|0]|0)|0]|a[9718144]&63;j=55018;break};case 204:case 205:case 206:case 207:{c[2440218]=(c[2440218]|0)-12;o=b[4859069]|0;p=c[2110940]|0;m=c[p+1040+((o+g&32767&65535)>>>8<<2)>>2]|0;do{if((m|0)==0){n=c[p+16+((o+g&32767&65535)>>>8<<2)>>2]|0;if((n|0)!=0){aB=a[n+(o+g&32767&65535&255)|0]|0;aC=g;aD=o;aE=p;break}n=c[p>>2]|0;if((n|0)==0){aB=0;aC=g;aD=o;aE=p;break}u=gj[n&4095](o+g&32767)|0;aB=u;aC=b[4859070]|0;aD=b[4859069]|0;aE=c[2110940]|0}else{aB=a[m+(o+g&32767&65535&255)|0]|0;aC=g;aD=o;aE=p}}while(0);p=aC+1&8191;b[4859070]=p;o=p+aD&32767;m=c[aE+1040+((o&65535)>>>8<<2)>>2]|0;do{if((m|0)==0){u=c[aE+16+((o&65535)>>>8<<2)>>2]|0;if((u|0)!=0){aF=a[u+(o&65535&255)|0]|0;aG=p;aH=aD;break}u=c[aE>>2]|0;if((u|0)==0){aF=0;aG=p;aH=aD;break}n=gj[u&4095](o)|0;aF=n;aG=b[4859070]|0;aH=b[4859069]|0}else{aF=a[m+(o&65535&255)|0]|0;aG=p;aH=aD}}while(0);b[4859070]=aG+1&8191;p=aB&255;o=(aH&65535)+(aF&255|p<<8&7936)|0;b[4859071]=o&65535;if((p&128|0)==0){aI=o&65535}else{c[2440218]=(c[2440218]|0)-6;m=c[2110940]|0;n=c[m+16+((o&65535&32767&65535)>>>8<<2)>>2]|0;do{if((n|0)==0){u=c[m>>2]|0;if((u|0)==0){aJ=0;aK=m;break}H=gj[u&4095](o&65535&32767)|0;aJ=H;aK=c[2110940]|0}else{aJ=a[n+(o&65535&32767&65535&255)|0]|0;aK=m}}while(0);m=(aJ&255)<<8;b[4859071]=m;n=(((o+1|0)&8191|0)==0?o+24577|0:o+1|0)&32767;H=c[aK+16+((n&65535)>>>8<<2)>>2]|0;do{if((H|0)==0){u=c[aK>>2]|0;if((u|0)==0){aL=0;break}aL=gj[u&4095](n)|0}else{aL=a[H+(n&65535&255)|0]|0}}while(0);n=aL&255|m&32512;b[4859071]=n;aI=n}if((p&96|0)==32){n=9718147+(d[9718146]|0)|0;a[n]=(a[n]|0)+1&255;n=b[4859071]|0;H=(d[9718147+(d[9718146]|0)|0]|0)+n&8191|n&24576;b[4859071]=H;a[9718146]=0;aM=H;aN=0}else if((p&96|0)==64){H=9718147+(d[9718146]|0)|0;a[H]=(a[H]|0)-1&255;H=b[4859071]|0;n=(d[9718147+(d[9718146]|0)|0]|0)+H&8191|H&24576;b[4859071]=n;a[9718146]=0;aM=n;aN=0}else if((p&96|0)==96){n=(d[9718147+(d[9718146]|0)|0]|0)+aI&8191|aI&24576;b[4859071]=n;a[9718146]=0;aM=n;aN=0}else{aM=aI;aN=d[9718146]|0}n=a[9718147+aN|0]|0;H=aM&32767;o=c[2110940]|0;u=c[o+528+((H&65535)>>>8<<2)>>2]|0;if((u|0)!=0){a[u+(H&65535&255)|0]=n;j=55018;c[e+13976>>2]=2;c[e+13980>>2]=33;break OL}u=c[o+4>>2]|0;if((u|0)==0){j=55018;c[e+13976>>2]=2;c[e+13980>>2]=33;break OL}gg[u&4095](H,n);j=55018;break};case 191:{c[2440218]=(c[2440218]|0)-9;n=b[4859069]|0;H=c[2110940]|0;u=c[H+1040+((n+g&32767&65535)>>>8<<2)>>2]|0;do{if((u|0)==0){o=c[H+16+((n+g&32767&65535)>>>8<<2)>>2]|0;if((o|0)!=0){aO=a[o+(n+g&32767&65535&255)|0]|0;aP=g;aQ=n;aR=H;break}o=c[H>>2]|0;if((o|0)==0){aO=0;aP=g;aQ=n;aR=H;break}aS=gj[o&4095](n+g&32767)|0;aO=aS;aP=b[4859070]|0;aQ=b[4859069]|0;aR=c[2110940]|0}else{aO=a[u+(n+g&32767&65535&255)|0]|0;aP=g;aQ=n;aR=H}}while(0);H=aP+1&8191;b[4859070]=H;n=H+aQ&32767;u=c[aR+1040+((n&65535)>>>8<<2)>>2]|0;do{if((u|0)==0){p=c[aR+16+((n&65535)>>>8<<2)>>2]|0;if((p|0)!=0){aT=a[p+(n&65535&255)|0]|0;aU=H;break}p=c[aR>>2]|0;if((p|0)==0){aT=0;aU=H;break}m=gj[p&4095](n)|0;aT=m;aU=b[4859070]|0}else{aT=a[u+(n&65535&255)|0]|0;aU=H}}while(0);H=aU+1&8191;b[4859070]=H;n=aO&255;u=aT&255;b[4859071]=(u|n<<8&32512)&65535;if((n&128|0)==0){aV=(u|n<<8&32512)&65535;aW=H}else{c[2440218]=(c[2440218]|0)-6;H=c[2110940]|0;m=c[H+16+((n<<8&32512)>>>8<<2)>>2]|0;do{if((m|0)==0){p=c[H>>2]|0;if((p|0)==0){aX=0;aY=H;break}aS=gj[p&4095]((u|n<<8&32512)&65535)|0;aX=aS;aY=c[2110940]|0}else{aX=a[m+u|0]|0;aY=H}}while(0);H=(aX&255)<<8;b[4859071]=H;m=((((u|n<<8&32512)+1|0)&8191|0)==0?(u|n<<8&32512)+24577|0:(u|n<<8&32512)+1|0)&32767;aS=c[aY+16+((m&65535)>>>8<<2)>>2]|0;do{if((aS|0)==0){p=c[aY>>2]|0;if((p|0)==0){aZ=0;break}aZ=gj[p&4095](m)|0}else{aZ=a[aS+(m&65535&255)|0]|0}}while(0);m=aZ&255|H&32512;b[4859071]=m;aV=m;aW=b[4859070]|0}b[4859071]=(d[9718150]|0)+aV&32767;m=a[9718145]|0;a[9718145]=m+1&255&7|m&-8;b[9718156+((m+1&255&7)<<1)>>1]=(b[4859069]|0)+aW&65535;m=b[4859071]|0;b[4859069]=m&24576;b[4859070]=m&8191;j=55018;break};case 240:case 241:case 242:case 243:{c[2440218]=(c[2440218]|0)-6;m=c[(c[2110940]|0)+12>>2]|0;if((m|0)==0){j=55018;c[e+13976>>2]=2;c[e+13980>>2]=33;break OL}gg[m&4095](257,a[9718147+(h&255)|0]|0);j=55018;break};case 244:case 245:case 246:case 247:{c[2440218]=(c[2440218]|0)-9;m=(b[4859069]|0)+g&32767;aS=c[2110940]|0;n=c[aS+1040+((m&65535)>>>8<<2)>>2]|0;do{if((n|0)==0){u=c[aS+16+((m&65535)>>>8<<2)>>2]|0;if((u|0)!=0){a_=a[u+(m&65535&255)|0]|0;a$=g;a0=h;break}u=c[aS>>2]|0;if((u|0)==0){a_=0;a$=g;a0=h;break}p=gj[u&4095](m)|0;a_=p;a$=b[4859070]|0;a0=a[9718146]|0}else{a_=a[n+(m&65535&255)|0]|0;a$=g;a0=h}}while(0);b[4859070]=a$+1&8191;m=a[9718144]&63;a[9718144]=m;if((a[9718147+(a0&255)|0]&a_)<<24>>24==a_<<24>>24){j=55018;c[e+13976>>2]=2;c[e+13980>>2]=33;break OL}a[9718144]=m|-128;j=55018;break};case 248:case 249:case 250:case 251:{c[2440218]=(c[2440218]|0)-9;m=(a[9718147+(h&255)|0]|0)-1&255;a[9718147+(h&255)|0]=m;if(m<<24>>24==0){b[4859070]=(b[4859070]|0)+1&8191;j=55018;c[e+13976>>2]=2;c[e+13980>>2]=33;break OL}m=b[4859069]|0;n=b[4859070]|0;aS=c[2110940]|0;H=c[aS+1040+((n+m&32767&65535)>>>8<<2)>>2]|0;do{if((H|0)==0){p=c[aS+16+((n+m&32767&65535)>>>8<<2)>>2]|0;if((p|0)!=0){a1=a[p+(n+m&32767&65535&255)|0]|0;a2=n;a3=m;break}p=c[aS>>2]|0;if((p|0)==0){a1=0;a2=n;a3=m;break}u=gj[p&4095](n+m&32767)|0;a1=u;a2=b[4859070]|0;a3=b[4859069]|0}else{a1=a[H+(n+m&32767&65535&255)|0]|0;a2=n;a3=m}}while(0);m=a2+1&65535;b[4859070]=m&8191;n=a1&255;H=((m&65535)+(c[5093528+(n<<2)>>2]|0)&8191)+(a3&65535)|0;b[4859071]=H&65535;if((n&128|0)==0){a4=H&65535}else{c[2440218]=(c[2440218]|0)-6;n=c[2110940]|0;m=c[n+16+((H&65535&32767&65535)>>>8<<2)>>2]|0;do{if((m|0)==0){aS=c[n>>2]|0;if((aS|0)==0){a5=0;a6=n;break}u=gj[aS&4095](H&65535&32767)|0;a5=u;a6=c[2110940]|0}else{a5=a[m+(H&65535&32767&65535&255)|0]|0;a6=n}}while(0);n=(a5&255)<<8;b[4859071]=n;m=(((H+1|0)&8191|0)==0?H+24577|0:H+1|0)&32767;u=c[a6+16+((m&65535)>>>8<<2)>>2]|0;do{if((u|0)==0){aS=c[a6>>2]|0;if((aS|0)==0){a7=0;break}a7=gj[aS&4095](m)|0}else{a7=a[u+(m&65535&255)|0]|0}}while(0);m=a7&255|n&32512;b[4859071]=m;a4=m}b[4859069]=a4&24576;b[4859070]=a4&8191;j=55018;break};case 12:case 13:case 14:case 15:{c[2440218]=(c[2440218]|0)-12;m=b[4859069]|0;u=c[2110940]|0;H=c[u+1040+((m+g&32767&65535)>>>8<<2)>>2]|0;do{if((H|0)==0){aS=c[u+16+((m+g&32767&65535)>>>8<<2)>>2]|0;if((aS|0)!=0){a8=a[aS+(m+g&32767&65535&255)|0]|0;a9=g;ba=m;bb=u;break}aS=c[u>>2]|0;if((aS|0)==0){a8=0;a9=g;ba=m;bb=u;break}p=gj[aS&4095](m+g&32767)|0;a8=p;a9=b[4859070]|0;ba=b[4859069]|0;bb=c[2110940]|0}else{a8=a[H+(m+g&32767&65535&255)|0]|0;a9=g;ba=m;bb=u}}while(0);u=a9+1&8191;b[4859070]=u;m=u+ba&32767;H=c[bb+1040+((m&65535)>>>8<<2)>>2]|0;do{if((H|0)==0){n=c[bb+16+((m&65535)>>>8<<2)>>2]|0;if((n|0)!=0){bc=a[n+(m&65535&255)|0]|0;bd=u;be=ba;break}n=c[bb>>2]|0;if((n|0)==0){bc=0;bd=u;be=ba;break}p=gj[n&4095](m)|0;bc=p;bd=b[4859070]|0;be=b[4859069]|0}else{bc=a[H+(m&65535&255)|0]|0;bd=u;be=ba}}while(0);b[4859070]=bd+1&8191;u=a8&255;m=(be&65535)+(bc&255|u<<8&7936)|0;b[4859071]=m&65535;if((u&128|0)==0){bf=m&65535}else{c[2440218]=(c[2440218]|0)-6;H=c[2110940]|0;p=c[H+16+((m&65535&32767&65535)>>>8<<2)>>2]|0;do{if((p|0)==0){n=c[H>>2]|0;if((n|0)==0){bg=0;bh=H;break}aS=gj[n&4095](m&65535&32767)|0;bg=aS;bh=c[2110940]|0}else{bg=a[p+(m&65535&32767&65535&255)|0]|0;bh=H}}while(0);H=(bg&255)<<8;b[4859071]=H;p=(((m+1|0)&8191|0)==0?m+24577|0:m+1|0)&32767;aS=c[bh+16+((p&65535)>>>8<<2)>>2]|0;do{if((aS|0)==0){n=c[bh>>2]|0;if((n|0)==0){bi=0;break}bi=gj[n&4095](p)|0}else{bi=a[aS+(p&65535&255)|0]|0}}while(0);p=bi&255|H&32512;b[4859071]=p;bf=p}if((u&96|0)==96){p=(d[9718147+(d[9718146]|0)|0]|0)+bf&8191|bf&24576;b[4859071]=p;a[9718146]=0;bj=p}else if((u&96|0)==32){p=9718147+(d[9718146]|0)|0;a[p]=(a[p]|0)+1&255;p=b[4859071]|0;aS=(d[9718147+(d[9718146]|0)|0]|0)+p&8191|p&24576;b[4859071]=aS;a[9718146]=0;bj=aS}else if((u&96|0)==64){aS=9718147+(d[9718146]|0)|0;a[aS]=(a[aS]|0)-1&255;aS=b[4859071]|0;p=(d[9718147+(d[9718146]|0)|0]|0)+aS&8191|aS&24576;b[4859071]=p;a[9718146]=0;bj=p}else{bj=bf}p=bj&32767;aS=c[2110940]|0;m=c[aS+16+((p&65535)>>>8<<2)>>2]|0;do{if((m|0)==0){n=c[aS>>2]|0;if((n|0)==0){bk=0;break}bk=gj[n&4095](p)|0}else{bk=a[m+(p&65535&255)|0]|0}}while(0);a[9718147+(d[9718146]|0)|0]=bk;a[9718144]=a[680792+(d[9718147+(d[9718146]|0)|0]|0)|0]|a[9718144]&63;j=55018;break};case 208:case 209:case 210:case 211:{c[2440218]=(c[2440218]|0)-6;p=a[9718147+(h&255)|0]|0;m=a[9718144]|0;if((m&8)==0){a[9718147+(h&255)|0]=p<<1|(p&255)>>>7;bl=a[9718144]|0;bm=a[9718146]|0}else{a[9718144]=m&-34;a[9718147+(h&255)|0]=m&1|p<<1;m=a[9718146]|0;aS=a[9718147+(m&255)|0]&32|(p&255)>>>7|a[9718144];a[9718144]=aS;bl=aS;bm=m}m=9718147+(bm&255)|0;aS=a[680792+(d[m]|0)|0]|bl&63;a[9718144]=aS;a[9718144]=((a[m]^p)&255)>>>5&4|aS&-5;j=55018;break};case 212:case 213:case 214:case 215:{c[2440218]=(c[2440218]|0)-9;aS=(b[4859069]|0)+g&32767;p=c[2110940]|0;m=c[p+1040+((aS&65535)>>>8<<2)>>2]|0;do{if((m|0)==0){u=c[p+16+((aS&65535)>>>8<<2)>>2]|0;if((u|0)!=0){bn=a[u+(aS&65535&255)|0]|0;bo=g;bp=p;break}u=c[p>>2]|0;if((u|0)==0){bn=0;bo=g;bp=p;break}H=gj[u&4095](aS)|0;bn=H;bo=b[4859070]|0;bp=c[2110940]|0}else{bn=a[m+(aS&65535&255)|0]|0;bo=g;bp=p}}while(0);b[4859070]=bo+1&8191;p=c[bp+12>>2]|0;if((p|0)==0){j=55018;c[e+13976>>2]=2;c[e+13980>>2]=33;break OL}gg[p&4095](bn&255,a[9718147+(d[9718146]|0)|0]|0);j=55018;break};default:{k=1}}}if(k){k=0;switch(l|0){case 18:{c[2440218]=(c[2440218]|0)-6;p=a[9718145]&-25;aS=c[(c[2110940]|0)+8>>2]|0;if((aS|0)==0){bq=0}else{bq=(gj[aS&4095](258)|0)&-128}aS=bq|p;a[9718147]=aS;a[9718144]=a[9718144]&63|a[680792+(aS&255)|0];j=55018;break};case 55:{c[2440218]=(c[2440218]|0)-9;aS=a[9718145]|0;p=b[9718156+((aS&7)<<1)>>1]|0;b[4859071]=p;b[4859069]=p&24576;b[4859070]=p&8191;a[9718145]=aS+7&7|aS&-40;if((a[9718172]|0)==0){j=55018;c[e+13976>>2]=2;c[e+13980>>2]=33;break OL}if((a[9718154]|0)!=0){a[9718154]=0;b[4859070]=p+1&8191}p=c[8449976+(c[2444]<<2)>>2]|0;if((p|0)==0){br=0}else{br=(gj[p&4095](0)|0)&255}p=c[5093528+(br<<2)>>2]&8191;b[4859071]=p;if((br&128|0)!=0){c[2440218]=(c[2440218]|0)-6;aS=c[2110940]|0;m=c[aS+16+((p&65535)>>>8<<2)>>2]|0;do{if((m|0)==0){H=c[aS>>2]|0;if((H|0)==0){bs=0;bt=aS;break}u=gj[H&4095](p)|0;bs=u;bt=c[2110940]|0}else{bs=a[m+(p&65535&255)|0]|0;bt=aS}}while(0);aS=(bs&255)<<8;b[4859071]=aS;m=((((p&65535)+1|0)&8191|0)==0?p+24577&65535:((p&65535)+1|0)&65535)&32767;u=c[bt+16+((m&65535)>>>8<<2)>>2]|0;do{if((u|0)==0){H=c[bt>>2]|0;if((H|0)==0){bu=0;break}bu=gj[H&4095](m)|0}else{bu=a[u+(m&65535&255)|0]|0}}while(0);b[4859071]=bu&255|aS&32512}m=a[9718145]|0;a[9718145]=m&-40|m+1&255&7|32;b[9718156+((m+1&255&7)<<1)>>1]=(b[4859070]|0)+(b[4859069]|0)&65535;m=b[4859071]|0;b[4859069]=m&24576;b[4859070]=m&8191;j=55018;break};case 20:case 21:case 22:{m=c[2440218]|0;c[2440218]=m-9;if(((d[9718144]|0)>>>6|0)!=(h&255|0)){j=55018;c[e+13976>>2]=2;c[e+13980>>2]=33;break OL}c[2440218]=m-15;m=a[9718145]|0;u=b[9718156+((m&7)<<1)>>1]|0;b[4859071]=u;a[9718145]=m+7&7|m&-8;b[4859069]=u&24576;b[4859070]=u&8191;j=55018;break};case 76:case 77:case 78:case 79:{c[2440218]=(c[2440218]|0)-12;u=b[4859069]|0;m=c[2110940]|0;p=c[m+1040+((u+g&32767&65535)>>>8<<2)>>2]|0;do{if((p|0)==0){H=c[m+16+((u+g&32767&65535)>>>8<<2)>>2]|0;if((H|0)!=0){bv=a[H+(u+g&32767&65535&255)|0]|0;bw=g;bx=u;by=m;break}H=c[m>>2]|0;if((H|0)==0){bv=0;bw=g;bx=u;by=m;break}n=gj[H&4095](u+g&32767)|0;bv=n;bw=b[4859070]|0;bx=b[4859069]|0;by=c[2110940]|0}else{bv=a[p+(u+g&32767&65535&255)|0]|0;bw=g;bx=u;by=m}}while(0);m=bw+1&8191;b[4859070]=m;u=m+bx&32767;p=c[by+1040+((u&65535)>>>8<<2)>>2]|0;do{if((p|0)==0){aS=c[by+16+((u&65535)>>>8<<2)>>2]|0;if((aS|0)!=0){bz=a[aS+(u&65535&255)|0]|0;bA=m;bB=bx;break}aS=c[by>>2]|0;if((aS|0)==0){bz=0;bA=m;bB=bx;break}n=gj[aS&4095](u)|0;bz=n;bA=b[4859070]|0;bB=b[4859069]|0}else{bz=a[p+(u&65535&255)|0]|0;bA=m;bB=bx}}while(0);b[4859070]=bA+1&8191;m=bv&255;u=(bB&65535)+(bz&255|m<<8&7936)|0;b[4859071]=u&65535;if((m&128|0)==0){bC=u&65535}else{c[2440218]=(c[2440218]|0)-6;p=c[2110940]|0;n=c[p+16+((u&65535&32767&65535)>>>8<<2)>>2]|0;do{if((n|0)==0){aS=c[p>>2]|0;if((aS|0)==0){bD=0;bE=p;break}H=gj[aS&4095](u&65535&32767)|0;bD=H;bE=c[2110940]|0}else{bD=a[n+(u&65535&32767&65535&255)|0]|0;bE=p}}while(0);p=(bD&255)<<8;b[4859071]=p;n=(((u+1|0)&8191|0)==0?u+24577|0:u+1|0)&32767;H=c[bE+16+((n&65535)>>>8<<2)>>2]|0;do{if((H|0)==0){aS=c[bE>>2]|0;if((aS|0)==0){bF=0;break}bF=gj[aS&4095](n)|0}else{bF=a[H+(n&65535&255)|0]|0}}while(0);n=bF&255|p&32512;b[4859071]=n;bC=n}if((m&96|0)==32){n=9718147+(d[9718146]|0)|0;a[n]=(a[n]|0)+1&255;n=b[4859071]|0;H=(d[9718147+(d[9718146]|0)|0]|0)+n&8191|n&24576;b[4859071]=H;a[9718146]=0;bG=H}else if((m&96|0)==64){H=9718147+(d[9718146]|0)|0;a[H]=(a[H]|0)-1&255;H=b[4859071]|0;n=(d[9718147+(d[9718146]|0)|0]|0)+H&8191|H&24576;b[4859071]=n;a[9718146]=0;bG=n}else if((m&96|0)==96){n=(d[9718147+(d[9718146]|0)|0]|0)+bC&8191|bC&24576;b[4859071]=n;a[9718146]=0;bG=n}else{bG=bC}n=bG&32767;H=c[2110940]|0;u=c[H+16+((n&65535)>>>8<<2)>>2]|0;do{if((u|0)==0){aS=c[H>>2]|0;if((aS|0)==0){bH=0;break}bH=gj[aS&4095](n)|0}else{bH=a[u+(n&65535&255)|0]|0}}while(0);n=9718147+(d[9718146]|0)|0;a[n]=a[n]&bH;a[9718144]=a[680792+(d[9718147+(d[9718146]|0)|0]|0)|0]|a[9718144]&63;j=55018;break};case 181:{c[2440218]=(c[2440218]|0)-9;n=(b[4859069]|0)+g&32767;u=c[2110940]|0;H=c[u+1040+((n&65535)>>>8<<2)>>2]|0;do{if((H|0)==0){m=c[u+16+((n&65535)>>>8<<2)>>2]|0;if((m|0)!=0){bI=a[m+(n&65535&255)|0]|0;bJ=g;break}m=c[u>>2]|0;if((m|0)==0){bI=0;bJ=g;break}p=gj[m&4095](n)|0;bI=p;bJ=b[4859070]|0}else{bI=a[H+(n&65535&255)|0]|0;bJ=g}}while(0);b[4859070]=bJ+1&8191;n=a[9718144]|0;if((n&bI)<<24>>24==bI<<24>>24){a[9718144]=n&63&255;j=55018;c[e+13976>>2]=2;c[e+13980>>2]=33;break OL}else{a[9718144]=(n&63|128)&255;j=55018;c[e+13976>>2]=2;c[e+13980>>2]=33;break OL}break};case 182:case 183:{n=(c[2440218]|0)-7|0;c[2440218]=n;i=n;break};case 184:case 185:case 186:{c[2440218]=(c[2440218]|0)-9;if(((d[9718144]|0)>>>6|0)==(h&255|0)){b[4859070]=f+2&8191;j=55018;c[e+13976>>2]=2;c[e+13980>>2]=33;break OL}n=b[4859069]|0;H=c[2110940]|0;u=c[H+1040+((n+g&32767&65535)>>>8<<2)>>2]|0;do{if((u|0)==0){p=c[H+16+((n+g&32767&65535)>>>8<<2)>>2]|0;if((p|0)!=0){bK=a[p+(n+g&32767&65535&255)|0]|0;bL=g;bM=n;break}p=c[H>>2]|0;if((p|0)==0){bK=0;bL=g;bM=n;break}m=gj[p&4095](n+g&32767)|0;bK=m;bL=b[4859070]|0;bM=b[4859069]|0}else{bK=a[u+(n+g&32767&65535&255)|0]|0;bL=g;bM=n}}while(0);n=bL+1&65535;b[4859070]=n&8191;u=bK&255;H=((n&65535)+(c[5093528+(u<<2)>>2]|0)&8191)+(bM&65535)|0;b[4859071]=H&65535;if((u&128|0)==0){bN=bM;bO=n&8191}else{c[2440218]=(c[2440218]|0)-6;n=c[2110940]|0;u=c[n+16+((H&65535&32767&65535)>>>8<<2)>>2]|0;do{if((u|0)==0){m=c[n>>2]|0;if((m|0)==0){bP=0;bQ=n;break}p=gj[m&4095](H&65535&32767)|0;bP=p;bQ=c[2110940]|0}else{bP=a[u+(H&65535&32767&65535&255)|0]|0;bQ=n}}while(0);n=(bP&255)<<8;b[4859071]=n;u=(((H+1|0)&8191|0)==0?H+24577|0:H+1|0)&32767;p=c[bQ+16+((u&65535)>>>8<<2)>>2]|0;do{if((p|0)==0){m=c[bQ>>2]|0;if((m|0)==0){bR=0;break}bR=gj[m&4095](u)|0}else{bR=a[p+(u&65535&255)|0]|0}}while(0);b[4859071]=bR&255|n&32512;bN=b[4859069]|0;bO=b[4859070]|0}u=a[9718145]|0;a[9718145]=u+1&255&7|u&-8;b[9718156+((u+1&255&7)<<1)>>1]=bN+bO&65535;u=b[4859071]|0;b[4859069]=u&24576;b[4859070]=u&8191;j=55018;break};case 192:{u=(c[2440218]|0)-6|0;c[2440218]=u;i=u;break};case 193:case 194:case 195:{c[2440218]=(c[2440218]|0)-6;a[9718147+(h&255)|0]=a[9718147]|0;a[9718144]=a[680792+(d[9718147+(d[9718146]|0)|0]|0)|0]|a[9718144]&63;j=55018;break};case 196:case 197:case 198:case 199:{u=(c[2440218]|0)-7|0;c[2440218]=u;i=u;break};case 200:case 201:case 202:case 203:{c[2440218]=(c[2440218]|0)-9;u=b[4859069]|0;p=c[2110940]|0;H=c[p+1040+((u+g&32767&65535)>>>8<<2)>>2]|0;do{if((H|0)==0){m=c[p+16+((u+g&32767&65535)>>>8<<2)>>2]|0;if((m|0)!=0){bS=a[m+(u+g&32767&65535&255)|0]|0;bT=g;bU=u;break}m=c[p>>2]|0;if((m|0)==0){bS=0;bT=g;bU=u;break}aS=gj[m&4095](u+g&32767)|0;bS=aS;bT=b[4859070]|0;bU=b[4859069]|0}else{bS=a[H+(u+g&32767&65535&255)|0]|0;bT=g;bU=u}}while(0);u=bT+1&65535;b[4859070]=u&8191;H=bS&255;p=((u&65535)+(c[5093528+(H<<2)>>2]|0)&8191)+(bU&65535)|0;b[4859071]=p&65535;if((H&128|0)==0){bV=p&65535}else{c[2440218]=(c[2440218]|0)-6;H=c[2110940]|0;u=c[H+16+((p&65535&32767&65535)>>>8<<2)>>2]|0;do{if((u|0)==0){n=c[H>>2]|0;if((n|0)==0){bW=0;bX=H;break}aS=gj[n&4095](p&65535&32767)|0;bW=aS;bX=c[2110940]|0}else{bW=a[u+(p&65535&32767&65535&255)|0]|0;bX=H}}while(0);H=(bW&255)<<8;b[4859071]=H;u=(((p+1|0)&8191|0)==0?p+24577|0:p+1|0)&32767;aS=c[bX+16+((u&65535)>>>8<<2)>>2]|0;do{if((aS|0)==0){n=c[bX>>2]|0;if((n|0)==0){bY=0;break}bY=gj[n&4095](u)|0}else{bY=a[aS+(u&65535&255)|0]|0}}while(0);u=bY&255|H&32512;b[4859071]=u;bV=u}u=a[9718147+(d[9718146]|0)|0]|0;aS=bV&32767;p=c[2110940]|0;n=c[p+528+((aS&65535)>>>8<<2)>>2]|0;if((n|0)!=0){a[n+(aS&65535&255)|0]=u;j=55018;c[e+13976>>2]=2;c[e+13980>>2]=33;break OL}n=c[p+4>>2]|0;if((n|0)==0){j=55018;c[e+13976>>2]=2;c[e+13980>>2]=33;break OL}gg[n&4095](aS,u);j=55018;break};case 236:case 237:case 238:case 239:{c[2440218]=(c[2440218]|0)-12;u=b[4859069]|0;aS=c[2110940]|0;n=c[aS+1040+((u+g&32767&65535)>>>8<<2)>>2]|0;do{if((n|0)==0){p=c[aS+16+((u+g&32767&65535)>>>8<<2)>>2]|0;if((p|0)!=0){bZ=a[p+(u+g&32767&65535&255)|0]|0;b_=g;b$=u;b0=aS;break}p=c[aS>>2]|0;if((p|0)==0){bZ=0;b_=g;b$=u;b0=aS;break}m=gj[p&4095](u+g&32767)|0;bZ=m;b_=b[4859070]|0;b$=b[4859069]|0;b0=c[2110940]|0}else{bZ=a[n+(u+g&32767&65535&255)|0]|0;b_=g;b$=u;b0=aS}}while(0);aS=b_+1&8191;b[4859070]=aS;u=aS+b$&32767;n=c[b0+1040+((u&65535)>>>8<<2)>>2]|0;do{if((n|0)==0){H=c[b0+16+((u&65535)>>>8<<2)>>2]|0;if((H|0)!=0){b1=a[H+(u&65535&255)|0]|0;b2=aS;b3=b$;break}H=c[b0>>2]|0;if((H|0)==0){b1=0;b2=aS;b3=b$;break}m=gj[H&4095](u)|0;b1=m;b2=b[4859070]|0;b3=b[4859069]|0}else{b1=a[n+(u&65535&255)|0]|0;b2=aS;b3=b$}}while(0);b[4859070]=b2+1&8191;aS=bZ&255;u=(b3&65535)+(b1&255|aS<<8&7936)|0;b[4859071]=u&65535;if((aS&128|0)==0){b4=u&65535}else{c[2440218]=(c[2440218]|0)-6;n=c[2110940]|0;m=c[n+16+((u&65535&32767&65535)>>>8<<2)>>2]|0;do{if((m|0)==0){H=c[n>>2]|0;if((H|0)==0){b5=0;b6=n;break}p=gj[H&4095](u&65535&32767)|0;b5=p;b6=c[2110940]|0}else{b5=a[m+(u&65535&32767&65535&255)|0]|0;b6=n}}while(0);n=(b5&255)<<8;b[4859071]=n;m=(((u+1|0)&8191|0)==0?u+24577|0:u+1|0)&32767;p=c[b6+16+((m&65535)>>>8<<2)>>2]|0;do{if((p|0)==0){H=c[b6>>2]|0;if((H|0)==0){b7=0;break}b7=gj[H&4095](m)|0}else{b7=a[p+(m&65535&255)|0]|0}}while(0);m=b7&255|n&32512;b[4859071]=m;b4=m}if((aS&96|0)==32){m=9718147+(d[9718146]|0)|0;a[m]=(a[m]|0)+1&255;m=b[4859071]|0;p=(d[9718147+(d[9718146]|0)|0]|0)+m&8191|m&24576;b[4859071]=p;a[9718146]=0;b8=p;b9=0}else if((aS&96|0)==64){p=9718147+(d[9718146]|0)|0;a[p]=(a[p]|0)-1&255;p=b[4859071]|0;m=(d[9718147+(d[9718146]|0)|0]|0)+p&8191|p&24576;b[4859071]=m;a[9718146]=0;b8=m;b9=0}else if((aS&96|0)==96){m=(d[9718147+(d[9718146]|0)|0]|0)+b4&8191|b4&24576;b[4859071]=m;a[9718146]=0;b8=m;b9=0}else{b8=b4;b9=d[9718146]|0}m=a[9718144]|0;a[9718144]=m&63;p=a[9718147+b9|0]|0;if((m&2)==0){m=b8&32767;u=c[2110940]|0;H=c[u+16+((m&65535)>>>8<<2)>>2]|0;do{if((H|0)==0){o=c[u>>2]|0;if((o|0)==0){ca=0;break}ca=gj[o&4095](m)|0}else{ca=a[H+(m&65535&255)|0]|0}}while(0);cb=(p<<24>>24)-(ca<<24>>24)|0}else{m=b8&32767;H=c[2110940]|0;u=c[H+16+((m&65535)>>>8<<2)>>2]|0;do{if((u|0)==0){aS=c[H>>2]|0;if((aS|0)==0){cc=0;break}cc=gj[aS&4095](m)|0}else{cc=a[u+(m&65535&255)|0]|0}}while(0);cb=(p&255)-(cc&255)|0}if((cb|0)<0){a[9718144]=a[9718144]|-128;j=55018;c[e+13976>>2]=2;c[e+13980>>2]=33;break OL}if((cb|0)<=0){j=55018;c[e+13976>>2]=2;c[e+13980>>2]=33;break OL}a[9718144]=a[9718144]|64;j=55018;break};case 56:case 57:case 58:{c[2440218]=(c[2440218]|0)-9;if(((d[9718144]|0)>>>6|0)!=(h&255|0)){b[4859070]=f+2&8191;j=55018;c[e+13976>>2]=2;c[e+13980>>2]=33;break OL}m=b[4859069]|0;u=c[2110940]|0;H=c[u+1040+((m+g&32767&65535)>>>8<<2)>>2]|0;do{if((H|0)==0){aS=c[u+16+((m+g&32767&65535)>>>8<<2)>>2]|0;if((aS|0)!=0){cd=a[aS+(m+g&32767&65535&255)|0]|0;ce=g;cf=m;break}aS=c[u>>2]|0;if((aS|0)==0){cd=0;ce=g;cf=m;break}n=gj[aS&4095](m+g&32767)|0;cd=n;ce=b[4859070]|0;cf=b[4859069]|0}else{cd=a[H+(m+g&32767&65535&255)|0]|0;ce=g;cf=m}}while(0);m=ce+1&65535;b[4859070]=m&8191;H=cd&255;u=((m&65535)+(c[5093528+(H<<2)>>2]|0)&8191)+(cf&65535)|0;b[4859071]=u&65535;if((H&128|0)==0){cg=cf;ch=m&8191}else{c[2440218]=(c[2440218]|0)-6;m=c[2110940]|0;H=c[m+16+((u&65535&32767&65535)>>>8<<2)>>2]|0;do{if((H|0)==0){p=c[m>>2]|0;if((p|0)==0){ci=0;cj=m;break}n=gj[p&4095](u&65535&32767)|0;ci=n;cj=c[2110940]|0}else{ci=a[H+(u&65535&32767&65535&255)|0]|0;cj=m}}while(0);m=(ci&255)<<8;b[4859071]=m;H=(((u+1|0)&8191|0)==0?u+24577|0:u+1|0)&32767;n=c[cj+16+((H&65535)>>>8<<2)>>2]|0;do{if((n|0)==0){p=c[cj>>2]|0;if((p|0)==0){ck=0;break}ck=gj[p&4095](H)|0}else{ck=a[n+(H&65535&255)|0]|0}}while(0);b[4859071]=ck&255|m&32512;cg=b[4859069]|0;ch=b[4859070]|0}H=a[9718145]|0;a[9718145]=H+1&255&7|H&-8;b[9718156+((H+1&255&7)<<1)>>1]=cg+ch&65535;H=b[4859071]|0;b[4859069]=H&24576;b[4859070]=H&8191;j=55018;break};case 232:case 233:case 234:case 235:{c[2440218]=(c[2440218]|0)-9;H=b[4859069]|0;n=c[2110940]|0;u=c[n+1040+((H+g&32767&65535)>>>8<<2)>>2]|0;do{if((u|0)==0){p=c[n+16+((H+g&32767&65535)>>>8<<2)>>2]|0;if((p|0)!=0){cl=a[p+(H+g&32767&65535&255)|0]|0;cm=g;cn=H;break}p=c[n>>2]|0;if((p|0)==0){cl=0;cm=g;cn=H;break}aS=gj[p&4095](H+g&32767)|0;cl=aS;cm=b[4859070]|0;cn=b[4859069]|0}else{cl=a[u+(H+g&32767&65535&255)|0]|0;cm=g;cn=H}}while(0);H=cm+1&65535;b[4859070]=H&8191;u=cl&255;n=((H&65535)+(c[5093528+(u<<2)>>2]|0)&8191)+(cn&65535)|0;b[4859071]=n&65535;if((u&128|0)==0){co=n&65535}else{c[2440218]=(c[2440218]|0)-6;u=c[2110940]|0;H=c[u+16+((n&65535&32767&65535)>>>8<<2)>>2]|0;do{if((H|0)==0){m=c[u>>2]|0;if((m|0)==0){cp=0;cq=u;break}aS=gj[m&4095](n&65535&32767)|0;cp=aS;cq=c[2110940]|0}else{cp=a[H+(n&65535&32767&65535&255)|0]|0;cq=u}}while(0);u=(cp&255)<<8;b[4859071]=u;H=(((n+1|0)&8191|0)==0?n+24577|0:n+1|0)&32767;aS=c[cq+16+((H&65535)>>>8<<2)>>2]|0;do{if((aS|0)==0){m=c[cq>>2]|0;if((m|0)==0){cr=0;break}cr=gj[m&4095](H)|0}else{cr=a[aS+(H&65535&255)|0]|0}}while(0);H=cr&255|u&32512;b[4859071]=H;co=H}H=a[9718144]|0;a[9718144]=H&63;aS=a[9718147+(d[9718146]|0)|0]|0;if((H&2)==0){H=co&32767;n=c[2110940]|0;m=c[n+16+((H&65535)>>>8<<2)>>2]|0;do{if((m|0)==0){p=c[n>>2]|0;if((p|0)==0){cs=0;break}cs=gj[p&4095](H)|0}else{cs=a[m+(H&65535&255)|0]|0}}while(0);ct=(aS<<24>>24)-(cs<<24>>24)|0}else{H=co&32767;m=c[2110940]|0;n=c[m+16+((H&65535)>>>8<<2)>>2]|0;do{if((n|0)==0){u=c[m>>2]|0;if((u|0)==0){cu=0;break}cu=gj[u&4095](H)|0}else{cu=a[n+(H&65535&255)|0]|0}}while(0);ct=(aS&255)-(cu&255)|0}if((ct|0)<0){a[9718144]=a[9718144]|-128;j=55018;c[e+13976>>2]=2;c[e+13980>>2]=33;break OL}if((ct|0)<=0){j=55018;c[e+13976>>2]=2;c[e+13980>>2]=33;break OL}a[9718144]=a[9718144]|64;j=55018;break};case 23:{c[2440218]=(c[2440218]|0)-15;H=a[9718145]|0;n=b[9718156+((H&7)<<1)>>1]|0;b[4859071]=n;a[9718145]=H+7&7|H&-8;b[4859069]=n&24576;b[4859070]=n&8191;j=55018;break};case 16:case 17:{n=(c[2440218]|0)-7|0;c[2440218]=n;i=n;break};case 64:{c[e+13976>>2]=2;c[e+13980>>2]=23;break OL;break};case 65:case 66:case 67:{c[2440218]=(c[2440218]|0)-6;n=a[9718147]&a[9718147+(h&255)|0];a[9718147]=n;a[9718144]=a[9718144]&63|a[680792+(n&255)|0];j=55018;break};case 68:case 69:case 70:case 71:{c[2440218]=(c[2440218]|0)-6;n=(b[4859069]|0)+g&32767;H=c[2110940]|0;m=c[H+1040+((n&65535)>>>8<<2)>>2]|0;do{if((m|0)==0){u=c[H+16+((n&65535)>>>8<<2)>>2]|0;if((u|0)!=0){cv=a[u+(n&65535&255)|0]|0;cw=g;cx=h;break}u=c[H>>2]|0;if((u|0)==0){cv=0;cw=g;cx=h;break}p=gj[u&4095](n)|0;cv=p;cw=b[4859070]|0;cx=a[9718146]|0}else{cv=a[m+(n&65535&255)|0]|0;cw=g;cx=h}}while(0);b[4859070]=cw+1&8191;n=9718147+(cx&255)|0;a[n]=a[n]&cv;a[9718144]=a[680792+(d[9718147+(d[9718146]|0)|0]|0)|0]|a[9718144]&63;j=55018;break};case 116:{c[2440218]=(c[2440218]|0)-9;n=(b[4859069]|0)+g&32767;m=c[2110940]|0;H=c[m+1040+((n&65535)>>>8<<2)>>2]|0;do{if((H|0)==0){aS=c[m+16+((n&65535)>>>8<<2)>>2]|0;if((aS|0)!=0){cy=a[aS+(n&65535&255)|0]|0;cz=g;break}aS=c[m>>2]|0;if((aS|0)==0){cy=0;cz=g;break}p=gj[aS&4095](n)|0;cy=p;cz=b[4859070]|0}else{cy=a[H+(n&65535&255)|0]|0;cz=g}}while(0);b[4859070]=cz+1&8191;n=a[9718145]&~cy;a[9718145]=n;if((a[9718172]|0)==0){j=55018;c[e+13976>>2]=2;c[e+13980>>2]=33;break OL}if((n&32)!=0){j=55018;c[e+13976>>2]=2;c[e+13980>>2]=33;break OL}if((a[9718154]|0)!=0){a[9718154]=0;b[4859070]=cz+2&8191}n=c[8449976+(c[2444]<<2)>>2]|0;if((n|0)==0){cA=0}else{cA=(gj[n&4095](0)|0)&255}n=c[5093528+(cA<<2)>>2]&8191;b[4859071]=n;if((cA&128|0)!=0){c[2440218]=(c[2440218]|0)-6;H=c[2110940]|0;m=c[H+16+((n&65535)>>>8<<2)>>2]|0;do{if((m|0)==0){p=c[H>>2]|0;if((p|0)==0){cB=0;cC=H;break}aS=gj[p&4095](n)|0;cB=aS;cC=c[2110940]|0}else{cB=a[m+(n&65535&255)|0]|0;cC=H}}while(0);H=(cB&255)<<8;b[4859071]=H;m=((((n&65535)+1|0)&8191|0)==0?n+24577&65535:((n&65535)+1|0)&65535)&32767;aS=c[cC+16+((m&65535)>>>8<<2)>>2]|0;do{if((aS|0)==0){p=c[cC>>2]|0;if((p|0)==0){cD=0;break}cD=gj[p&4095](m)|0}else{cD=a[aS+(m&65535&255)|0]|0}}while(0);b[4859071]=cD&255|H&32512}m=a[9718145]|0;a[9718145]=m&-40|m+1&255&7|32;b[9718156+((m+1&255&7)<<1)>>1]=(b[4859070]|0)+(b[4859069]|0)&65535;m=b[4859071]|0;b[4859069]=m&24576;b[4859070]=m&8191;j=55018;break};case 72:case 73:case 74:case 75:{c[2440218]=(c[2440218]|0)-9;m=b[4859069]|0;aS=c[2110940]|0;n=c[aS+1040+((m+g&32767&65535)>>>8<<2)>>2]|0;do{if((n|0)==0){p=c[aS+16+((m+g&32767&65535)>>>8<<2)>>2]|0;if((p|0)!=0){cE=a[p+(m+g&32767&65535&255)|0]|0;cF=g;cG=m;break}p=c[aS>>2]|0;if((p|0)==0){cE=0;cF=g;cG=m;break}u=gj[p&4095](m+g&32767)|0;cE=u;cF=b[4859070]|0;cG=b[4859069]|0}else{cE=a[n+(m+g&32767&65535&255)|0]|0;cF=g;cG=m}}while(0);m=cF+1&65535;b[4859070]=m&8191;n=cE&255;aS=((m&65535)+(c[5093528+(n<<2)>>2]|0)&8191)+(cG&65535)|0;b[4859071]=aS&65535;if((n&128|0)==0){cH=aS&65535}else{c[2440218]=(c[2440218]|0)-6;n=c[2110940]|0;m=c[n+16+((aS&65535&32767&65535)>>>8<<2)>>2]|0;do{if((m|0)==0){H=c[n>>2]|0;if((H|0)==0){cI=0;cJ=n;break}u=gj[H&4095](aS&65535&32767)|0;cI=u;cJ=c[2110940]|0}else{cI=a[m+(aS&65535&32767&65535&255)|0]|0;cJ=n}}while(0);n=(cI&255)<<8;b[4859071]=n;m=(((aS+1|0)&8191|0)==0?aS+24577|0:aS+1|0)&32767;u=c[cJ+16+((m&65535)>>>8<<2)>>2]|0;do{if((u|0)==0){H=c[cJ>>2]|0;if((H|0)==0){cK=0;break}cK=gj[H&4095](m)|0}else{cK=a[u+(m&65535&255)|0]|0}}while(0);m=cK&255|n&32512;b[4859071]=m;cH=m}m=cH&32767;u=c[2110940]|0;aS=c[u+16+((m&65535)>>>8<<2)>>2]|0;do{if((aS|0)==0){H=c[u>>2]|0;if((H|0)==0){cL=0;break}cL=gj[H&4095](m)|0}else{cL=a[aS+(m&65535&255)|0]|0}}while(0);m=9718147+(d[9718146]|0)|0;a[m]=a[m]&cL;a[9718144]=a[680792+(d[9718147+(d[9718146]|0)|0]|0)|0]|a[9718144]&63;j=55018;break};case 176:case 177:case 178:case 179:{c[2440218]=(c[2440218]|0)-6;m=c[(c[2110940]|0)+12>>2]|0;if((m|0)==0){j=55018;c[e+13976>>2]=2;c[e+13980>>2]=33;break OL}gg[m&4095](256,a[9718147+(h&255)|0]|0);j=55018;break};case 180:{c[2440218]=(c[2440218]|0)-9;m=(b[4859069]|0)+g&32767;aS=c[2110940]|0;u=c[aS+1040+((m&65535)>>>8<<2)>>2]|0;do{if((u|0)==0){n=c[aS+16+((m&65535)>>>8<<2)>>2]|0;if((n|0)!=0){cM=a[n+(m&65535&255)|0]|0;cN=g;cO=aS;break}n=c[aS>>2]|0;if((n|0)==0){cM=0;cN=g;cO=aS;break}H=gj[n&4095](m)|0;cM=H;cN=b[4859070]|0;cO=c[2110940]|0}else{cM=a[u+(m&65535&255)|0]|0;cN=g;cO=aS}}while(0);b[4859070]=cN+1&8191;aS=a[9718145]|0;m=c[cO+8>>2]|0;if((m|0)==0){cP=0}else{cP=(gj[m&4095](258)|0)&-128}m=a[9718144]&63;a[9718144]=m;if(((cP|aS)&cM)<<24>>24==cM<<24>>24){j=55018;c[e+13976>>2]=2;c[e+13980>>2]=33;break OL}a[9718144]=m|-128;j=55018;break};case 224:case 225:case 226:case 227:{c[2440218]=(c[2440218]|0)-6;m=a[9718144]|0;a[9718144]=m&63;aS=a[9718147]|0;if((m&2)==0){cQ=(aS<<24>>24)-(a[9718147+(h&255)|0]|0)|0}else{cQ=(aS&255)-(d[9718147+(h&255)|0]|0)|0}if((cQ|0)<0){a[9718144]=m&63|-128;j=55018;c[e+13976>>2]=2;c[e+13980>>2]=33;break OL}if((cQ|0)<=0){j=55018;c[e+13976>>2]=2;c[e+13980>>2]=33;break OL}a[9718144]=m&63|64;j=55018;break};case 228:case 229:case 230:case 231:{c[2440218]=(c[2440218]|0)-6;m=a[9718144]|0;a[9718144]=m&63;aS=a[9718147+(h&255)|0]|0;if((m&2)==0){m=(b[4859069]|0)+g&32767;u=c[2110940]|0;H=c[u+1040+((m&65535)>>>8<<2)>>2]|0;do{if((H|0)==0){n=c[u+16+((m&65535)>>>8<<2)>>2]|0;if((n|0)!=0){cR=a[n+(m&65535&255)|0]|0;cS=g;break}n=c[u>>2]|0;if((n|0)==0){cR=0;cS=g;break}p=gj[n&4095](m)|0;cR=p;cS=b[4859070]|0}else{cR=a[H+(m&65535&255)|0]|0;cS=g}}while(0);b[4859070]=cS+1&8191;cT=(aS<<24>>24)-(cR<<24>>24)|0}else{m=(b[4859069]|0)+g&32767;H=c[2110940]|0;u=c[H+1040+((m&65535)>>>8<<2)>>2]|0;do{if((u|0)==0){p=c[H+16+((m&65535)>>>8<<2)>>2]|0;if((p|0)!=0){cU=a[p+(m&65535&255)|0]|0;cV=g;break}p=c[H>>2]|0;if((p|0)==0){cU=0;cV=g;break}n=gj[p&4095](m)|0;cU=n;cV=b[4859070]|0}else{cU=a[u+(m&65535&255)|0]|0;cV=g}}while(0);b[4859070]=cV+1&8191;cT=(aS&255)-(cU&255)|0}if((cT|0)<0){a[9718144]=a[9718144]|-128;j=55018;c[e+13976>>2]=2;c[e+13980>>2]=33;break OL}if((cT|0)<=0){j=55018;c[e+13976>>2]=2;c[e+13980>>2]=33;break OL}a[9718144]=a[9718144]|64;j=55018;break};default:{k=1}}}if(k){k=0;switch(l|0){case 59:{c[2440218]=(c[2440218]|0)-9;m=b[4859069]|0;u=c[2110940]|0;H=c[u+1040+((m+g&32767&65535)>>>8<<2)>>2]|0;do{if((H|0)==0){n=c[u+16+((m+g&32767&65535)>>>8<<2)>>2]|0;if((n|0)!=0){cW=a[n+(m+g&32767&65535&255)|0]|0;cX=g;cY=m;break}n=c[u>>2]|0;if((n|0)==0){cW=0;cX=g;cY=m;break}p=gj[n&4095](m+g&32767)|0;cW=p;cX=b[4859070]|0;cY=b[4859069]|0}else{cW=a[H+(m+g&32767&65535&255)|0]|0;cX=g;cY=m}}while(0);m=cX+1&65535;b[4859070]=m&8191;H=cW&255;u=((m&65535)+(c[5093528+(H<<2)>>2]|0)&8191)+(cY&65535)|0;b[4859071]=u&65535;if((H&128|0)==0){cZ=cY;c_=m&8191}else{c[2440218]=(c[2440218]|0)-6;m=c[2110940]|0;H=c[m+16+((u&65535&32767&65535)>>>8<<2)>>2]|0;do{if((H|0)==0){aS=c[m>>2]|0;if((aS|0)==0){c$=0;c0=m;break}p=gj[aS&4095](u&65535&32767)|0;c$=p;c0=c[2110940]|0}else{c$=a[H+(u&65535&32767&65535&255)|0]|0;c0=m}}while(0);m=(c$&255)<<8;b[4859071]=m;H=(((u+1|0)&8191|0)==0?u+24577|0:u+1|0)&32767;p=c[c0+16+((H&65535)>>>8<<2)>>2]|0;do{if((p|0)==0){aS=c[c0>>2]|0;if((aS|0)==0){c1=0;break}c1=gj[aS&4095](H)|0}else{c1=a[p+(H&65535&255)|0]|0}}while(0);b[4859071]=c1&255|m&32512;cZ=b[4859069]|0;c_=b[4859070]|0}H=a[9718145]|0;a[9718145]=H+1&255&7|H&-8;b[9718156+((H+1&255&7)<<1)>>1]=cZ+c_&65535;H=b[4859071]|0;b[4859069]=H&24576;b[4859070]=H&8191;j=55018;break};case 172:case 173:case 174:case 175:{c[2440218]=(c[2440218]|0)-12;H=b[4859069]|0;p=c[2110940]|0;u=c[p+1040+((H+g&32767&65535)>>>8<<2)>>2]|0;do{if((u|0)==0){aS=c[p+16+((H+g&32767&65535)>>>8<<2)>>2]|0;if((aS|0)!=0){c2=a[aS+(H+g&32767&65535&255)|0]|0;c3=g;c4=H;c5=p;break}aS=c[p>>2]|0;if((aS|0)==0){c2=0;c3=g;c4=H;c5=p;break}n=gj[aS&4095](H+g&32767)|0;c2=n;c3=b[4859070]|0;c4=b[4859069]|0;c5=c[2110940]|0}else{c2=a[u+(H+g&32767&65535&255)|0]|0;c3=g;c4=H;c5=p}}while(0);p=c3+1&8191;b[4859070]=p;H=p+c4&32767;u=c[c5+1040+((H&65535)>>>8<<2)>>2]|0;do{if((u|0)==0){m=c[c5+16+((H&65535)>>>8<<2)>>2]|0;if((m|0)!=0){c6=a[m+(H&65535&255)|0]|0;c7=p;c8=c4;break}m=c[c5>>2]|0;if((m|0)==0){c6=0;c7=p;c8=c4;break}n=gj[m&4095](H)|0;c6=n;c7=b[4859070]|0;c8=b[4859069]|0}else{c6=a[u+(H&65535&255)|0]|0;c7=p;c8=c4}}while(0);b[4859070]=c7+1&8191;p=c2&255;H=(c8&65535)+(c6&255|p<<8&7936)|0;b[4859071]=H&65535;if((p&128|0)==0){c9=H&65535}else{c[2440218]=(c[2440218]|0)-6;u=c[2110940]|0;n=c[u+16+((H&65535&32767&65535)>>>8<<2)>>2]|0;do{if((n|0)==0){m=c[u>>2]|0;if((m|0)==0){da=0;db=u;break}aS=gj[m&4095](H&65535&32767)|0;da=aS;db=c[2110940]|0}else{da=a[n+(H&65535&32767&65535&255)|0]|0;db=u}}while(0);u=(da&255)<<8;b[4859071]=u;n=(((H+1|0)&8191|0)==0?H+24577|0:H+1|0)&32767;aS=c[db+16+((n&65535)>>>8<<2)>>2]|0;do{if((aS|0)==0){m=c[db>>2]|0;if((m|0)==0){dc=0;break}dc=gj[m&4095](n)|0}else{dc=a[aS+(n&65535&255)|0]|0}}while(0);n=dc&255|u&32512;b[4859071]=n;c9=n}if((p&96|0)==32){n=9718147+(d[9718146]|0)|0;a[n]=(a[n]|0)+1&255;n=b[4859071]|0;aS=(d[9718147+(d[9718146]|0)|0]|0)+n&8191|n&24576;b[4859071]=aS;a[9718146]=0;dd=aS}else if((p&96|0)==64){aS=9718147+(d[9718146]|0)|0;a[aS]=(a[aS]|0)-1&255;aS=b[4859071]|0;n=(d[9718147+(d[9718146]|0)|0]|0)+aS&8191|aS&24576;b[4859071]=n;a[9718146]=0;dd=n}else if((p&96|0)==96){n=(d[9718147+(d[9718146]|0)|0]|0)+c9&8191|c9&24576;b[4859071]=n;a[9718146]=0;dd=n}else{dd=c9}n=dd&32767;aS=c[2110940]|0;H=c[aS+16+((n&65535)>>>8<<2)>>2]|0;do{if((H|0)==0){m=c[aS>>2]|0;if((m|0)==0){de=0;break}de=gj[m&4095](n)|0}else{de=a[H+(n&65535&255)|0]|0}}while(0);n=9718147+(d[9718146]|0)|0;H=a[n]|0;aS=a[9718144]|0;p=(H&255)-(de&255)-((aS&255&1^1)&(aS&255)>>>3)|0;a[9718144]=(p>>>8&1^1)&255|aS&-38;a[n]=p&255;p=9718147+(d[9718146]|0)|0;n=a[p]|0;aS=a[9718144]|0;if((n&15)>>>0>(H&255&15)>>>0){df=n;dg=aS}else{a[9718144]=aS|32;df=a[p]|0;dg=aS|32}a[9718144]=a[680792+(((df^H)&255&((H^de)&255^128))<<1&256|df&255)|0]|dg&59;j=55018;break};case 216:case 217:case 218:case 219:{c[2440218]=(c[2440218]|0)-9;H=(a[9718147+(h&255)|0]|0)+1&255;a[9718147+(h&255)|0]=H;if(H<<24>>24==0){b[4859070]=(b[4859070]|0)+1&8191;j=55018;c[e+13976>>2]=2;c[e+13980>>2]=33;break OL}H=b[4859069]|0;aS=b[4859070]|0;p=c[2110940]|0;n=c[p+1040+((aS+H&32767&65535)>>>8<<2)>>2]|0;do{if((n|0)==0){u=c[p+16+((aS+H&32767&65535)>>>8<<2)>>2]|0;if((u|0)!=0){dh=a[u+(aS+H&32767&65535&255)|0]|0;di=aS;dj=H;break}u=c[p>>2]|0;if((u|0)==0){dh=0;di=aS;dj=H;break}m=gj[u&4095](aS+H&32767)|0;dh=m;di=b[4859070]|0;dj=b[4859069]|0}else{dh=a[n+(aS+H&32767&65535&255)|0]|0;di=aS;dj=H}}while(0);H=di+1&65535;b[4859070]=H&8191;aS=dh&255;n=((H&65535)+(c[5093528+(aS<<2)>>2]|0)&8191)+(dj&65535)|0;b[4859071]=n&65535;if((aS&128|0)==0){dk=n&65535}else{c[2440218]=(c[2440218]|0)-6;aS=c[2110940]|0;H=c[aS+16+((n&65535&32767&65535)>>>8<<2)>>2]|0;do{if((H|0)==0){p=c[aS>>2]|0;if((p|0)==0){dl=0;dm=aS;break}m=gj[p&4095](n&65535&32767)|0;dl=m;dm=c[2110940]|0}else{dl=a[H+(n&65535&32767&65535&255)|0]|0;dm=aS}}while(0);aS=(dl&255)<<8;b[4859071]=aS;H=(((n+1|0)&8191|0)==0?n+24577|0:n+1|0)&32767;m=c[dm+16+((H&65535)>>>8<<2)>>2]|0;do{if((m|0)==0){p=c[dm>>2]|0;if((p|0)==0){dn=0;break}dn=gj[p&4095](H)|0}else{dn=a[m+(H&65535&255)|0]|0}}while(0);H=dn&255|aS&32512;b[4859071]=H;dk=H}b[4859069]=dk&24576;b[4859070]=dk&8191;j=55018;break};case 220:case 221:case 222:case 223:{c[2440218]=(c[2440218]|0)-9;H=(a[9718147+(h&255)|0]|0)+1&255;a[9718147+(h&255)|0]=H;if(H<<24>>24==0){b[4859070]=(b[4859070]|0)+2&8191;j=55018;c[e+13976>>2]=2;c[e+13980>>2]=33;break OL}H=b[4859069]|0;m=b[4859070]|0;n=c[2110940]|0;p=c[n+1040+((m+H&32767&65535)>>>8<<2)>>2]|0;do{if((p|0)==0){u=c[n+16+((m+H&32767&65535)>>>8<<2)>>2]|0;if((u|0)!=0){dp=a[u+(m+H&32767&65535&255)|0]|0;dq=m;dr=H;ds=n;break}u=c[n>>2]|0;if((u|0)==0){dp=0;dq=m;dr=H;ds=n;break}o=gj[u&4095](m+H&32767)|0;dp=o;dq=b[4859070]|0;dr=b[4859069]|0;ds=c[2110940]|0}else{dp=a[p+(m+H&32767&65535&255)|0]|0;dq=m;dr=H;ds=n}}while(0);n=dq+1&8191;b[4859070]=n;H=n+dr&32767;m=c[ds+1040+((H&65535)>>>8<<2)>>2]|0;do{if((m|0)==0){p=c[ds+16+((H&65535)>>>8<<2)>>2]|0;if((p|0)!=0){dt=a[p+(H&65535&255)|0]|0;du=n;break}p=c[ds>>2]|0;if((p|0)==0){dt=0;du=n;break}aS=gj[p&4095](H)|0;dt=aS;du=b[4859070]|0}else{dt=a[m+(H&65535&255)|0]|0;du=n}}while(0);b[4859070]=du+1&8191;n=dp&255;H=dt&255;b[4859071]=(H|n<<8&32512)&65535;if((n&128|0)==0){dv=(H|n<<8&32512)&65535}else{c[2440218]=(c[2440218]|0)-6;m=c[2110940]|0;aS=c[m+16+((n<<8&32512)>>>8<<2)>>2]|0;do{if((aS|0)==0){p=c[m>>2]|0;if((p|0)==0){dw=0;dx=m;break}o=gj[p&4095]((H|n<<8&32512)&65535)|0;dw=o;dx=c[2110940]|0}else{dw=a[aS+H|0]|0;dx=m}}while(0);m=(dw&255)<<8;b[4859071]=m;aS=((((H|n<<8&32512)+1|0)&8191|0)==0?(H|n<<8&32512)+24577|0:(H|n<<8&32512)+1|0)&32767;o=c[dx+16+((aS&65535)>>>8<<2)>>2]|0;do{if((o|0)==0){p=c[dx>>2]|0;if((p|0)==0){dy=0;break}dy=gj[p&4095](aS)|0}else{dy=a[o+(aS&65535&255)|0]|0}}while(0);aS=dy&255|m&32512;b[4859071]=aS;dv=aS}b[4859069]=dv&24576;b[4859070]=dv&8191;j=55018;break};default:{j=55018}}}}while(0);c[e+13928>>2]=i;c[e+13952>>2]=j;c[e+13960>>2]=k}
function gM(a){a=a|0;var b=0;b=i;i=i+a|0;i=i+7&-8;return b|0}function gN(){return i|0}function gO(a){a=a|0;i=a}function gP(a,b){a=a|0;b=b|0;if((x|0)==0){x=a;y=b}}function gQ(b){b=b|0;a[k]=a[b];a[k+1|0]=a[b+1|0];a[k+2|0]=a[b+2|0];a[k+3|0]=a[b+3|0]}function gR(b){b=b|0;a[k]=a[b];a[k+1|0]=a[b+1|0];a[k+2|0]=a[b+2|0];a[k+3|0]=a[b+3|0];a[k+4|0]=a[b+4|0];a[k+5|0]=a[b+5|0];a[k+6|0]=a[b+6|0];a[k+7|0]=a[b+7|0]}function gS(a){a=a|0;K=a}function gT(a){a=a|0;L=a}function gU(a){a=a|0;M=a}function gV(a){a=a|0;N=a}function gW(a){a=a|0;O=a}function gX(a){a=a|0;P=a}function gY(a){a=a|0;Q=a}function gZ(a){a=a|0;R=a}function g_(a){a=a|0;S=a}function g$(a){a=a|0;T=a}function g0(){c[156376]=o+8;c[156378]=o+8;c[156380]=r+8;c[156384]=r+8;c[156388]=r+8;c[156392]=r+8;c[156396]=r+8;c[156400]=o+8;c[156434]=r+8;c[156438]=r+8;c[156502]=r+8;c[156506]=r+8;c[156526]=o+8;c[156528]=r+8;c[156564]=r+8;c[156568]=r+8;c[156604]=r+8;c[156608]=r+8;c[156628]=o+8;c[156630]=o+8;c[156632]=r+8;c[156636]=r+8;c[156640]=r+8;c[156644]=o+8;c[156646]=o+8;c[156648]=o+8;c[156650]=o+8;c[156652]=o+8;c[156654]=o+8;c[156656]=o+8;c[156682]=r+8;c[156686]=o+8;c[156688]=r+8;c[156692]=r+8;c[156696]=r+8;c[156700]=o+8;c[156702]=o+8;c[156704]=o+8;c[156706]=o+8;c[156740]=o+8;c[156742]=o+8;c[156744]=o+8;c[156746]=r+8;c[156750]=r+8;c[156754]=r+8;c[156758]=r+8;c[156762]=r+8;c[156766]=r+8}function g1(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,v=0,w=0,x=0,y=0,z=0,A=0;e=i;i=i+8200|0;f=e|0;g=e+4096|0;h=e+8192|0;dw(800,600);gGz(9263480,0,110584);j=c[2383028]|0;if((j|0)!=0){aY(j|0)|0}gGz(9375104,0,158208);a[9375106]=1;a[9375105]=1;c[2344802]=0;c[2331058]=1;c[2331059]=1;c[2331060]=1;c[2331061]=1;c[2331062]=1;c[2331063]=1;c[2331064]=1;c[2331065]=1;ha();j=hk(b,d)|0;if((j|0)!=0){k=j;i=e;return k|0}j=gGq(132176)|0;d=(j|0)==0;do{if(!d){if((c[j-4>>2]&3|0)==0){break}gGz(j|0,0,132176)}}while(0);c[j+36>>2]=8453328;c[j+28>>2]=320;c[j+32>>2]=240;c[j+40>>2]=640;c[j+16692>>2]=62168;if(d){d=c[u>>2]|0;cj(418808,48,1,d|0)|0;eY(d|0)|0;if((a[9532117]&1)==0){bU(d|0,547632,(l=i,i=i+16|0,c[l>>2]=545704,c[l+8>>2]=729,l)|0)|0;i=l;eY(d|0)|0;fm(2);return 0}else{a[9532119]=109;a[9532120]=101;a[9532121]=110;a[9532122]=117;a[9532123]=95;a[9532124]=105;a[9532125]=110;a[9532126]=105;a[9532127]=116;a[9532128]=40;a[9532129]=41;a[9532130]=0;eM(9533144,1);return 0}}c[2161332]=10144;c[2112498]=j;d=4096;b=j+4404|0;j=9365865;while(1){m=d-1|0;if((m|0)==0){n=14;break}o=a[j]|0;a[b]=o;if(o<<24>>24==0){break}else{d=m;b=b+1|0;j=j+1|0}}do{if((n|0)==14){a[b]=0;if((a[j]|0)==0){break}else{p=j}do{p=p+1|0;}while((a[p]|0)!=0)}}while(0);p=gGq(12)|0;do{if((p|0)!=0){if((c[p-4>>2]&3|0)==0){break}gGz(p|0,0,12)}}while(0);c[(c[2112498]|0)+48>>2]=p;p=gGq(12)|0;do{if((p|0)!=0){if((c[p-4>>2]&3|0)==0){break}gGz(p|0,0,12)}}while(0);j=c[2112498]|0;c[j+52>>2]=p;p=c[j+48>>2]|0;if((p|0)==0){q=j}else{j=p+8|0;b=p+4|0;d=c[b>>2]|0;if((c[j>>2]|0)>>>0<d>>>0){r=p|0}else{m=(d<<1)+2|0;c[b>>2]=m;b=p|0;c[b>>2]=gGs(c[b>>2]|0,m<<4)|0;r=b}b=bG(9534384)|0;c[(c[r>>2]|0)+(c[j>>2]<<4)>>2]=b;c[(c[r>>2]|0)+(c[j>>2]<<4)+4>>2]=0;c[(c[r>>2]|0)+(c[j>>2]<<4)+8>>2]=4;c[(c[r>>2]|0)+(c[j>>2]<<4)+12>>2]=0;c[j>>2]=(c[j>>2]|0)+1;q=c[2112498]|0}c[q+56>>2]=0;a[q+62|0]=a[9374057]&1;a[9374057]=0;jR(q,4);q=c[2112498]|0;gGz(q|0,0,17);a[q+44|0]=1;c[q+130280>>2]=0;jP();jM(c[2112498]|0);jQ();if((cu(1,h|0)|0)<0){s=0;t=0}else{q=c[h>>2]|0;j=gGU(q,(q|0)<0|0?-1:0,1e6,0)|0;q=((c[h+4>>2]|0)+500|0)/1e3|0;h=gGK(q,(q|0)<0|0?-1:0,j,K)|0;s=K;t=h}h=(c[2112498]|0)+130288|0;c[h>>2]=t;c[h+4>>2]=s;s=9532104;h=c[s+4>>2]|0;t=9532104;c[t>>2]=c[s>>2]|3;c[t+4>>2]=h;do{if((a[9533305]&1)==0){h=g|0;L45:do{if((a[9375108]&1)==0){t=4096;s=h;j=9411994;while(1){q=t-1|0;if((q|0)==0){break}r=a[j]|0;a[s]=r;if(r<<24>>24==0){break L45}else{t=q;s=s+1|0;j=j+1|0}}a[s]=0;if((a[j]|0)==0){break}else{v=j}do{v=v+1|0;}while((a[v]|0)!=0)}else{be(h|0,4096,328824,(l=i,i=i+8|0,c[l>>2]=9407898,l)|0)|0;i=l}}while(0);L54:do{if((a[h]|0)!=0){j=f|0;s=4096;t=j;q=h;while(1){r=s-1|0;if((r|0)==0){n=40;break}b=a[q]|0;a[t]=b;if(b<<24>>24==0){break}else{s=r;t=t+1|0;q=q+1|0}}do{if((n|0)==40){a[t]=0;if((a[q]|0)==0){break}else{w=q}do{w=w+1|0;}while((a[w]|0)!=0)}}while(0);if((dl(j|0,h|0)|0)==0){x=4096;y=h;z=j}else{break}while(1){q=x-1|0;if((q|0)==0){break}t=a[z]|0;a[y]=t;if(t<<24>>24==0){break L54}else{x=q;y=y+1|0;z=z+1|0}}a[y]=0;if((a[z]|0)==0){break}else{A=z}do{A=A+1|0;}while((a[A]|0)!=0)}}while(0);if((a[9469446]&1)==0){if((a[h]|0)==0){break}}j=c[(c[2112498]|0)+130284>>2]|0;if((j|0)==0){break}j1(j,(a[h]|0)!=0?h:0,c[2367342]|0)}}while(0);b7(1784,((a[9263568]&1)!=0?0:2147483647)|0,1);k=0;i=e;return k|0}function g2(){var b=0,d=0,e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,W=0,X=0.0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,ag=0,ah=0,ai=0,aj=0,ak=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0;b=i;i=i+8512|0;d=b|0;e=b+8|0;f=b+16|0;h=b+24|0;j=b+32|0;k=b+160|0;l=b+288|0;m=b+4384|0;n=b+8480|0;o=b+8488|0;p=b+8496|0;q=b+8504|0;if((a[9469432]&1)!=0){a[9469432]=0;do{if((c[2161332]|0)!=0){r=c[2112498]|0;if((a[r+16696|0]&1)==0){break}gGr(c[r+16692>>2]|0)}}while(0);r=c[(c[2112498]|0)+48>>2]|0;s=r+8|0;t=r|0;v=c[t>>2]|0;if((c[s>>2]|0)==0){w=v}else{x=0;y=v;while(1){gGr(c[y+(x<<4)>>2]|0);v=x+1|0;z=c[t>>2]|0;if(v>>>0<(c[s>>2]|0)>>>0){x=v;y=z}else{w=z;break}}}gGr(w);gGr(r);r=c[(c[2112498]|0)+52>>2]|0;w=r+8|0;y=r|0;x=c[y>>2]|0;if((c[w>>2]|0)==0){A=x}else{s=0;t=x;while(1){gGr(c[t+(s<<4)>>2]|0);x=s+1|0;z=c[y>>2]|0;if(x>>>0<(c[w>>2]|0)>>>0){s=x;t=z}else{A=z;break}}}gGr(A);gGr(r);j2(c[(c[2112498]|0)+130284>>2]|0);jJ(c[(c[2112498]|0)+64>>2]|0);gGr(c[2112498]|0);if(!((a[9532118]&1)==0|(a[9395610]|0)==0)){h3(9395610)|0}if((a[9532116]&1)!=0){hm()}r=c[2380901]|0;if((r|0)!=0){A=r+4|0;t=c[A>>2]|0;s=r|0;if(t>>>0>1){w=1;y=t;while(1){t=c[(c[s>>2]|0)+(w<<2)>>2]|0;if((t|0)==0){B=y}else{gGr(c[t+8>>2]|0);gGr(c[(c[s>>2]|0)+(w<<2)>>2]|0);c[(c[s>>2]|0)+(w<<2)>>2]=0;B=c[A>>2]|0}t=w+1|0;if(t>>>0<B>>>0){w=t;y=B}else{break}}}c[A>>2]=1;A=r+12|0;gGr(c[A>>2]|0);c[A>>2]=0;gGr(c[s>>2]|0);gGr(r);c[2380901]=0}gGz(9263480,0,110584);r=c[2383028]|0;if((r|0)==0){gGz(9375104,0,158208);a[9375106]=1;a[9375105]=1;c[2344802]=0;c[2331058]=1;c[2331059]=1;c[2331060]=1;c[2331061]=1;c[2331062]=1;c[2331063]=1;c[2331064]=1;c[2331065]=1;fm(0)}aY(r|0)|0;gGz(9375104,0,158208);a[9375106]=1;a[9375105]=1;c[2344802]=0;c[2331058]=1;c[2331059]=1;c[2331060]=1;c[2331061]=1;c[2331062]=1;c[2331063]=1;c[2331064]=1;c[2331065]=1;fm(0)}r=9532104;s=c[r>>2]|0;A=c[r+4>>2]|0;if(a[10056]|0){if(!((s&128|0)==0&(A&0|0)==0)){r=c[2112498]|0;a[r+60|0]=1;B=9532104;y=c[B+4>>2]|0;w=9532104;c[w>>2]=c[B>>2]&-129;c[w+4>>2]=y;y=r|0;r=c[y+4>>2]|8388608;c[y>>2]=c[y>>2];c[y+4>>2]=r}g9();if((c[2383400]|0)!=0){do{if((a[9533447]&1)==0){r=gA[c[(c[2383356]|0)+12>>2]&16383](c[2383359]|0,51)|0;y=9533608;if((c[y>>2]&0|r&1|0)==0&(c[y+4>>2]&524288|0)==0){C=0;break}if((a[8451296]&1)!=0){C=1;break}y=c[2383400]|0;r=y+28|0;w=c[r>>2]|0;B=y+20|0;c[B>>2]=w;c[y+16>>2]=(c[y+12>>2]|0)+(w*144|0);i4(y);a[y+9|0]=1;c[r>>2]=(((c[B>>2]|0)+1|0)>>>0)%((c[y+24>>2]|0)>>>0)|0;C=1}else{C=0}}while(0);a[8451296]=C}if((a[9533447]&1)==0){C=gA[c[(c[2383356]|0)+12>>2]&16383](c[2383359]|0,30)|0;y=9533608;if((c[y>>2]&1073741824|C&1|0)==0&(c[y+4>>2]&0|0)==0){D=87}else{D=88}}else{D=87}do{if((D|0)==87){if(gj[c[(c[2383355]|0)+12>>2]&4095](c[2383358]|0)|0){E=0;F=0;G=0}else{D=88;break}do{y=(gh[c[(c[2383356]|0)+8>>2]&15](c[2383359]|0,10136,0,1,0,E)|0)<<16>>16==0;C=gGM(1,0,E|0)|0;B=K;r=9533608;w=(c[r>>2]&C|0)==0&(c[r+4>>2]&B|0)==0;G=(y?0:C)|G|(w?0:C);F=(y?0:B)|F|(w?0:B);E=E+1|0;}while(E>>>0<13);if((a[9533447]&1)==0){B=gA[c[(c[2383356]|0)+12>>2]&16383](c[2383359]|0,55)|0;w=9533608;y=(c[w>>2]&0|B&1|0)!=0|(c[w+4>>2]&8388608|0)!=0;H=y?8388608:0;I=y?0:0}else{H=0;I=0}y=I|G;w=H|F;B=c[2112498]|0;C=B|0;r=y&~c[C>>2];t=w&~c[C+4>>2];z=B+8|0;c[z>>2]=r;c[z+4>>2]=t;do{if((G&3312|0)==0&(F&0|0)==0){a[B+16|0]=0;D=100}else{x=((w>>>23|0<<9)&1^1)&255;a[B+16|0]=x;if((x&1)==0){D=100;break}do{if(a[10128]|0){x=c[B+24>>2]|0;if(x>>>0<(c[B+20>>2]|0)>>>0){J=t;L=r;M=x;break}a[10128]=0;c[z>>2]=y;c[z+4>>2]=w;v=B+4400|0;N=(c[v>>2]|0)+1|0;c[v>>2]=N>>>0<64?N:64;J=w;L=y;M=x}else{a[10128]=1;c[B+20>>2]=a[10120]|0?6:12;c[B+24>>2]=0;J=t;L=r;M=0}}while(0);a[10120]=1;O=J;P=L;Q=M}}while(0);if((D|0)==100){a[10128]=0;a[10120]=0;c[B+4400>>2]=0;O=t;P=r;Q=c[B+24>>2]|0}c[B+24>>2]=Q+1;c[C>>2]=y;c[C+4>>2]=w;do{if((P&16|0)==0&(O&0|0)==0){if(!((P&32|0)==0&(O&0|0)==0)){R=1;break}if(!((P&64|0)==0&(O&0|0)==0)){R=2;break}if(!((P&128|0)==0&(O&0|0)==0)){R=3;break}if(!((P&1024|0)==0&(O&0|0)==0)){R=10;break}if(!((P&2048|0)==0&(O&0|0)==0)){R=9;break}if(!((P&1|0)==0&(O&0|0)==0)){R=5;break}if(!((P&256|0)==0&(O&0|0)==0)){R=4;break}R=(P&8|0)==0&(O&0|0)==0?13:7}else{R=0}}while(0);if((c[2161332]|0)==0){S=0}else{S=jO(B,R)|0}w=c[2383406]|0;do{if((w|0)!=0){C=c[w+24>>2]|0;if((C|0)==0){break}gG[C&255](c[2383358]|0,(a[(c[2112498]|0)+44|0]&1)!=0,0)}}while(0);g4();if((cu(1,o|0)|0)<0){T=0;W=0}else{w=c[o>>2]|0;B=gGU(w,(w|0)<0|0?-1:0,1e6,0)|0;w=((c[o+4>>2]|0)+500|0)/1e3|0;C=gGK(w,(w|0)<0|0?-1:0,B,K)|0;T=K;W=C}C=(c[2112498]|0)+130288|0;B=gGL(W,T,c[C>>2]|0,c[C+4>>2]|0)|0;C=gGS(B,K,1e3,0)|0;B=K;X=750.0/+g[2317949];w=gGL(~~X>>>0,+V(X)>=1.0?X>0.0?(al(+U(X/4294967296.0),4294967295.0)|0)>>>0:~~+af((X- +(~~X>>>0))/4294967296.0)>>>0:0,C,B)|0;B=K;C=0;if((B|0)>(C|0)|(B|0)==(C|0)&w>>>0>0>>>0){C=w;w=p;c[p>>2]=0;c[p+4>>2]=0;c[p>>2]=(C>>>0)/1e3|0;c[w+4>>2]=((C>>>0)%1e3|0)*1e6|0;em(w|0,0)|0}if((cu(1,n|0)|0)<0){Y=0;Z=0}else{w=c[n>>2]|0;C=gGU(w,(w|0)<0|0?-1:0,1e6,0)|0;w=((c[n+4>>2]|0)+500|0)/1e3|0;B=gGK(w,(w|0)<0|0?-1:0,C,K)|0;Y=K;Z=B}B=c[2112498]|0;C=B+130288|0;c[C>>2]=Z;c[C+4>>2]=Y;C=c[2383406]|0;do{if((C|0)==0){_=B}else{w=c[C+24>>2]|0;if((w|0)==0){_=B;break}gG[w&255](c[2383358]|0,0,0);_=c[2112498]|0}}while(0);B=_+8|0;do{if((c[B>>2]&0|0)==0&(c[B+4>>2]&8388608|0)==0){$=0}else{if((a[9532116]&1)==0){$=0;break}if((a[9533305]&1)!=0){$=0;break}C=9532104;w=c[C+4>>2]|0;y=9532104;c[y>>2]=c[C>>2]|1;c[y+4>>2]=w;w=c[_+48>>2]|0;y=c[w+8>>2]|0;if((y|0)==0){aa=0;ab=_;ac=w;ad=0}else{C=c[(c[w>>2]|0)+(y-1<<4)+8>>2]|0;if((C|0)==4){$=-1;break}else{aa=C;ab=_;ac=w;ad=y}}while(1){y=ab+56|0;w=ac+8|0;if((ad|0)!=0){C=ad-1|0;c[w>>2]=C;gGr(c[(c[ac>>2]|0)+(C<<4)>>2]|0)}if((y|0)!=0){c[y>>2]=c[(c[ac>>2]|0)+(c[w>>2]<<4)+12>>2]}w=c[2112498]|0;y=c[w+48>>2]|0;C=c[y+8>>2]|0;if((C|0)==0){ae=aa}else{ae=c[(c[y>>2]|0)+(C-1<<4)+8>>2]|0}if((ae|0)==4){$=-1;break}else{aa=ae;ab=w;ac=y;ad=C}}}}while(0);if(($|S|0)!=0){break}i=b;return}}while(0);if((D|0)==88){S=9532104;$=c[S+4>>2]|0;ad=9532104;c[ad>>2]=c[S>>2]|1;c[ad+4>>2]=$}a[10056]=0;$=(a[9533448]&1)!=0;ad=c[2383358]|0;if((a[9375106]&1)!=0&(ad|0)!=0){if((a[9263568]&1)==0){D=140}else{if((a[9469445]&1)==0){ag=$}else{D=140}}if((D|0)==140){ag=1}gg[c[(c[2383355]|0)+8>>2]&4095](ad,ag)}ag=c[2383357]|0;if((a[9375105]&1)!=0&(ag|0)!=0){gg[c[(c[2383354]|0)+16>>2]&4095](ag,(a[9284180]&1)==0|$);ah=c[2383357]|0}else{ah=ag}c[2368546]=$?c[2368547]|0:c[2368548]|0;do{if((ah|0)!=0){if(gj[c[(c[2383354]|0)+12>>2]&4095](ah)|0){break}$=c[u>>2]|0;cj(79720,81,1,$|0)|0;eY($|0)|0;a[9375105]=0}}while(0);ah=9532104;$=c[ah+4>>2]|0;ag=9532104;c[ag>>2]=c[ah>>2]&-9;c[ag+4>>2]=$;i=b;return}if((s&4|0)==0&(A&0|0)==0){if((s&1|0)==0&(A&0|0)==0){if((s&8|0)==0&(A&0|0)==0){a[9469432]=1;i=b;return}$=9532104;c[$>>2]=s|128;c[$+4>>2]=A;gg[c[(c[2383355]|0)+8>>2]&4095](c[2383358]|0,0);A=c[2383357]|0;if((A|0)!=0){$=c[(c[2383354]|0)+8>>2]|0;gj[$&4095](A)|0}a[10056]=1;i=b;return}do{if((a[9531831]&1)==0){D=222}else{if((a[9531832]&1)!=0){D=222;break}if((a[9533447]&1)==0){A=gA[c[(c[2383356]|0)+12>>2]&16383](c[2383359]|0,30)|0;$=9533608;if(!((c[$>>2]&1073741824|A&1|0)==0&(c[$+4>>2]&0|0)==0)){break}}if(!(gj[c[(c[2383355]|0)+12>>2]&4095](c[2383358]|0)|0)){break}hl();g9();$=q;c[q>>2]=0;c[q+4>>2]=0;c[q>>2]=0;c[$+4>>2]=1e7;em($|0,0)|0;i=b;return}}while(0);L238:do{if((D|0)==222){if((a[9533447]&1)==0){q=gA[c[(c[2383356]|0)+12>>2]&16383](c[2383359]|0,30)|0;$=9533608;if(!((c[$>>2]&1073741824|q&1|0)==0&(c[$+4>>2]&0|0)==0)){break}}if(!(gj[c[(c[2383355]|0)+12>>2]&4095](c[2383358]|0)|0)){break}do{if((a[9533447]&1)==0){$=gA[c[(c[2383356]|0)+12>>2]&16383](c[2383359]|0,55)|0;q=9533608;if((c[q>>2]&0|$&1|0)==0&(c[q+4>>2]&8388608|0)==0){D=228;break}ai=a[61856]|0;D=230}else{D=228}}while(0);do{if((D|0)==228){if((a[9533305]&1)==0){aj=0;break}q=a[61856]|0;if((q&1)==0){ai=q;D=230}else{aj=0}}}while(0);do{if((D|0)==230){if((ai&1)!=0){aj=1;break}q=9532104;$=c[q+4>>2]|0;A=9532104;c[A>>2]=c[q>>2]|8;c[A+4>>2]=$;a[61856]=1;$=9474152;c[$>>2]=0;c[$+4>>2]=0;break L238}}while(0);a[61856]=aj;if((a[9523608]&1)!=0){a[9523608]=0;break}hl();$=c[2380907]|0;if(($|0)!=0){A=fl(c[$>>2]|0)|0;c[(c[$+4>>2]|0)+(c[$+12>>2]<<2)>>2]=A}if((c[2368534]|0)!=0){if((cu(1,f|0)|0)<0){ak=0;am=0}else{A=c[f>>2]|0;$=gGU(A,(A|0)<0|0?-1:0,1e6,0)|0;A=((c[f+4>>2]|0)+500|0)/1e3|0;q=gGK(A,(A|0)<0|0?-1:0,$,K)|0;ak=K;am=q}do{if((a[9531831]&1)==0){q=(a[9533448]&1)!=0;$=9474152;A=c[$>>2]|0;s=c[$+4>>2]|0;$=(A|0)==0&(s|0)==0|q;ag=9474144;ah=c[ag>>2]|0;ad=c[ag+4>>2]|0;ag=gGL(am,ak,A,s)|0;s=$?ah:ag;ag=$?ad:K;if(q){an=ag;ao=s;ap=0;aq=0;break}if((a[9531833]&1)==0){an=ag;ao=s;ap=ak;aq=am;break}X=(+(s>>>0)+ +(ag|0)*4294967296.0)/+g[2341460];an=+V(X)>=1.0?X>0.0?(al(+U(X/4294967296.0),4294967295.0)|0)>>>0:~~+af((X- +(~~X>>>0))/4294967296.0)>>>0:0;ao=~~X>>>0;ap=ak;aq=am}else{ag=9474144;an=c[ag+4>>2]|0;ao=c[ag>>2]|0;ap=0;aq=0}}while(0);ag=9474152;c[ag>>2]=aq;c[ag+4>>2]=ap;gg[c[2368534]&4095](ao,an)}gu[c[2112848]&16383]();do{if(+g[2341461]>=0.0){if((cu(1,e|0)|0)<0){ar=0;as=0}else{ag=c[e>>2]|0;s=gGU(ag,(ag|0)<0|0?-1:0,1e6,0)|0;ag=((c[e+4>>2]|0)+500|0)/1e3|0;q=gGK(ag,(ag|0)<0|0?-1:0,s,K)|0;ar=K;as=q}q=9469360;s=9469352;ag=c[s>>2]|0;ad=c[s+4>>2]|0;s=gGL(c[q>>2]|0,c[q+4>>2]|0,as,ar)|0;q=gGK(s,K,ag,ad)|0;ad=K;ag=0;if((ad|0)>(ag|0)|(ad|0)==(ag|0)&q>>>0>999>>>0){ag=gGS(q,ad,1e3,0)|0;ad=ag;ag=h;c[h>>2]=0;c[h+4>>2]=0;c[h>>2]=(ad>>>0)/1e3|0;c[ag+4>>2]=((ad>>>0)%1e3|0)*1e6|0;em(ag|0,0)|0;ag=9469352;ad=9469360;q=gGK(c[ad>>2]|0,c[ad+4>>2]|0,c[ag>>2]|0,c[ag+4>>2]|0)|0;ag=9469360;c[ag>>2]=q;c[ag+4>>2]=K;break}if((cu(1,d|0)|0)<0){at=0;au=0}else{ag=c[d>>2]|0;q=gGU(ag,(ag|0)<0|0?-1:0,1e6,0)|0;ag=((c[d+4>>2]|0)+500|0)/1e3|0;ad=gGK(ag,(ag|0)<0|0?-1:0,q,K)|0;at=K;au=ad}ad=9469360;c[ad>>2]=au;c[ad+4>>2]=at}}while(0);ad=c[2380907]|0;if((ad|0)==0){i=b;return}q=ad+12|0;c[q>>2]=(c[q>>2]|0)+1&c[ad+8>>2];q=ad+30|0;a[ad+29|0]=a[q]&1^1;a[q]=0;i=b;return}}while(0);at=9532104;au=c[at+4>>2]|0;d=9532104;c[d>>2]=c[at>>2]&-2;c[d+4>>2]=au;i=b;return}au=l|0;l=m|0;if((a[9411994]|0)==0){m=c[2112498]|0;if((a[m+20812|0]&1)==0){av=m}else{aw=m;D=166}}else{m=cE(9411994,47)|0;d=4096;at=0;h=au;ar=(m|0)==0?9411994:m+1|0;while(1){m=d-1|0;if((m|0)==0){D=154;break}as=a[ar]|0;a[h]=as;if(as<<24>>24==0){ax=at;break}else{d=m;at=at+1|0;h=h+1|0;ar=ar+1|0}}do{if((D|0)==154){a[h]=0;if((a[ar]|0)==0){ax=at;break}else{ay=ar;az=at}while(1){d=ay+1|0;m=az+1|0;if((a[d]|0)==0){ax=m;break}else{ay=d;az=m}}}}while(0);if(ax>>>0>=4096){ax=c[u>>2]|0;bU(ax|0,547632,(aA=i,i=i+16|0,c[aA>>2]=551256,c[aA+8>>2]=579,aA)|0)|0;i=aA;eY(ax|0)|0;fm(2)}be(l|0,4096,463728,(aA=i,i=i+8|0,c[aA>>2]=au,aA)|0)|0;i=aA;ax=c[2380901]|0;az=ax+4|0;L305:do{if((c[az>>2]|0)>>>0<(c[ax+8>>2]|0)>>>0){ay=gGq(12)|0;do{if((ay|0)!=0){if((c[ay-4>>2]&3|0)==0){break}gGz(ay|0,0,12)}}while(0);c[ay+4>>2]=1;c[ay>>2]=1;at=bG(l|0)|0;ar=c[az>>2]|0;c[ay+8>>2]=at;at=ax|0;c[(c[at>>2]|0)+(ar<<2)>>2]=ay;ar=c[az>>2]|0;c[az>>2]=ar+1;if(ar>>>0>1){aB=ar}else{break}while(1){ar=aB>>>1;h=c[at>>2]|0;m=h+(ar<<2)|0;d=c[m>>2]|0;as=c[h+(aB<<2)>>2]|0;if((c[as+4>>2]|0)>>>0<=(c[d+4>>2]|0)>>>0){break L305}c[m>>2]=as;c[(c[at>>2]|0)+(aB<<2)>>2]=d;if(aB>>>0>3){aB=ar}else{break}}}}while(0);aw=c[2112498]|0;D=166}do{if((D|0)==166){aB=c[aw+20796>>2]|0;az=c[aw+130284>>2]|0;if((az|0)==0){av=aw;break}j1(az,(a[9411994]|0)!=0?9411994:0,(aB|0)==0?9534384:aB);av=c[2112498]|0}}while(0);gGz(av|0,0,17);a[av+61|0]=1;if((c[2161332]|0)!=0){aw=av;jO(aw,13)|0}aw=c[2383406]|0;do{if((aw|0)!=0){av=c[aw+24>>2]|0;if((av|0)==0){break}gG[av&255](c[2383358]|0,(a[(c[2112498]|0)+44|0]&1)!=0,0)}}while(0);if((c[2383355]|0)!=0){g4()}aw=c[2383406]|0;do{if((aw|0)!=0){av=c[aw+24>>2]|0;if((av|0)==0){break}gG[av&255](c[2383358]|0,0,0)}}while(0);if((a[9532116]&1)!=0){hm()}aw=a[9375104]&1;av=(a[9395610]|0)!=0;aB=av?9395610:0;az=(a[9444762]|0)!=0;ax=az?9444762:0;at=(a[9448858]|0)!=0;ay=at?9448858:0;ar=(a[9411994]|0)!=0;d=ar?9411994:0;as=(c[2112498]|0)+20812|0;m=a[as]&1;a[as]=0;as=j;h=k;if((a[9532116]&1)!=0){hm()}gGz(as|0,0,128);e=j|0;c[e>>2]=bG(223168)|0;do{if(m<<24>>24==0){an=(a[9375104]&1)!=0;if(ar){if(an){ao=c[u>>2]|0;bU(ao|0,218504,(aA=i,i=i+8|0,c[aA>>2]=d,aA)|0)|0;i=aA;eY(ao|0)|0}c[j+4>>2]=bG(d|0)|0;aC=2;break}else{if(an){an=c[u>>2]|0;cj(214728,40,1,an|0)|0;eY(an|0)|0}c[j+4>>2]=bG(211624)|0;aC=2;break}}else{aC=1}}while(0);if(az){c[j+(aC<<2)>>2]=bG(206608)|0;c[j+(aC+1<<2)>>2]=bG(ax|0)|0;aD=aC+2|0}else{aD=aC}if(at){c[j+(aD<<2)>>2]=bG(200448)|0;c[j+(aD+1<<2)>>2]=bG(ay|0)|0;aE=aD+2|0}else{aE=aD}if(av){c[j+(aE<<2)>>2]=bG(195040)|0;c[j+(aE+1<<2)>>2]=bG(aB|0)|0;aF=aE+2|0}else{aF=aE}if(aw<<24>>24==0){aG=aF}else{c[j+(aF<<2)>>2]=bG(188736)|0;aG=aF+1|0}gGC(h|0,as|0,128)|0;as=hk(aG,e)|0;e=0;do{gGr(c[k+(e<<2)>>2]|0);e=e+1|0;}while(e>>>0<32);if((as|0)==0){if((a[9375104]&1)!=0){as=c[u>>2]|0;cj(452544,45,1,as|0)|0;eY(as|0)|0}jP();jQ();jM(c[2112498]|0);as=9532104;e=c[as+4>>2]|0|0;k=9532104;c[k>>2]=c[as>>2]&-6|1;c[k+4>>2]=e;i=b;return}e=cE(9411994,47)|0;k=4096;as=0;aG=au;h=(e|0)==0?9411994:e+1|0;while(1){e=k-1|0;if((e|0)==0){D=206;break}aF=a[h]|0;a[aG]=aF;if(aF<<24>>24==0){aH=as;break}else{k=e;as=as+1|0;aG=aG+1|0;h=h+1|0}}do{if((D|0)==206){a[aG]=0;if((a[h]|0)==0){aH=as;break}else{aI=h;aJ=as}while(1){k=aI+1|0;e=aJ+1|0;if((a[k]|0)==0){aH=e;break}else{aI=k;aJ=e}}}}while(0);if(aH>>>0>=4096){aH=c[u>>2]|0;bU(aH|0,547632,(aA=i,i=i+16|0,c[aA>>2]=551256,c[aA+8>>2]=579,aA)|0)|0;i=aA;eY(aH|0)|0;fm(2)}be(l|0,4096,441880,(aA=i,i=i+8|0,c[aA>>2]=au,aA)|0)|0;i=aA;aA=c[2380901]|0;au=aA+4|0;L384:do{if((c[au>>2]|0)>>>0<(c[aA+8>>2]|0)>>>0){aH=gGq(12)|0;do{if((aH|0)!=0){if((c[aH-4>>2]&3|0)==0){break}gGz(aH|0,0,12)}}while(0);c[aH+4>>2]=1;c[aH>>2]=90;aJ=bG(l|0)|0;aI=c[au>>2]|0;c[aH+8>>2]=aJ;aJ=aA|0;c[(c[aJ>>2]|0)+(aI<<2)>>2]=aH;aI=c[au>>2]|0;c[au>>2]=aI+1;if(aI>>>0>1){aK=aI}else{break}while(1){aI=aK>>>1;as=c[aJ>>2]|0;h=as+(aI<<2)|0;aG=c[h>>2]|0;D=c[as+(aK<<2)>>2]|0;if((c[D+4>>2]|0)>>>0<=(c[aG+4>>2]|0)>>>0){break L384}c[h>>2]=D;c[(c[aJ>>2]|0)+(aK<<2)>>2]=aG;if(aK>>>0>3){aK=aI}else{break}}}}while(0);a[(c[2112498]|0)+61|0]=1;aK=c[u>>2]|0;cj(429944,52,1,aK|0)|0;eY(aK|0)|0;i=b;return}function g3(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,v=0,w=0;b=i;i=i+4120|0;d=b|0;e=b+24|0;if((a[9407898]|a[9357636])<<24>>24==0){i=b;return}do{if((a[9280027]&1)!=0|(c[2368524]|0)!=0){f=c[2383355]|0;if((c[f+44>>2]|0)==0){g=281;break}h=(c[f+40>>2]|0)==0;f=c[2380901]|0;j=f+4|0;k=c[j>>2]|0;if(k>>>0>1){l=f|0;m=1;n=k;while(1){k=c[(c[l>>2]|0)+(m<<2)>>2]|0;if((k|0)==0){o=n}else{gGr(c[k+8>>2]|0);gGr(c[(c[l>>2]|0)+(m<<2)>>2]|0);c[(c[l>>2]|0)+(m<<2)>>2]=0;o=c[j>>2]|0}k=m+1|0;if(k>>>0<o>>>0){m=k;n=o}else{break}}}c[j>>2]=1;n=f+12|0;gGr(c[n>>2]|0);c[n>>2]=0;if(h){g=306;break}n=c[2383406]|0;do{if((n|0)!=0){m=c[n+24>>2]|0;if((m|0)==0){break}gG[m&255](c[2383358]|0,0,0)}}while(0);if((c[2383355]|0)==0){p=0}else{g4();p=c[2383355]|0}n=e|0;gGz(d|0,0,24);gg[c[p+40>>2]&4095](c[2383358]|0,d);h=d+8|0;f=c[h>>2]|0;if((f|0)==0){g=313;break}j=d+12|0;m=c[j>>2]|0;if((m|0)==0){g=313;break}l=gGq(ag(f*3|0,m)|0)|0;if((l|0)==0){g=313;break}if(!(gA[c[(c[2383355]|0)+44>>2]&16383](c[2383358]|0,l)|0)){gGr(l);g=313;break}if((a[9357636]|0)==0){hJ(n,9407898);q=n}else{q=9357636}n=c[h>>2]|0;h=iS(q,l,n,c[j>>2]|0,n*3|0,1)|0;gGr(l);if(h){g=311}else{g=313}}else{g=281}}while(0);if((g|0)==281){q=c[2380901]|0;d=q+4|0;p=c[d>>2]|0;if(p>>>0>1){o=q|0;h=1;l=p;while(1){p=c[(c[o>>2]|0)+(h<<2)>>2]|0;if((p|0)==0){r=l}else{gGr(c[p+8>>2]|0);gGr(c[(c[o>>2]|0)+(h<<2)>>2]|0);c[(c[o>>2]|0)+(h<<2)>>2]=0;r=c[d>>2]|0}p=h+1|0;if(p>>>0<r>>>0){h=p;l=r}else{break}}}c[d>>2]=1;d=q+12|0;gGr(c[d>>2]|0);c[d>>2]=0;g=306}do{if((g|0)==306){d=c[2382968]|0;q=d;if((q|0)==(-1|0)|(q|0)==0){q=c[u>>2]|0;cj(589872,103,1,q|0)|0;eY(q|0)|0;g=313;break}q=e|0;r=c[2382969]|0;l=c[2382970]|0;h=c[2382971]|0;if((a[9357636]|0)==0){hJ(q,9407898);s=q}else{s=9357636}if(iS(s,d+(ag(l-1|0,h)|0)|0,r,l,-h|0,0)|0){g=311}else{g=313}}}while(0);do{if((g|0)==311){if((a[9375104]&1)==0){t=454136;break}s=c[u>>2]|0;cj(556440,30,1,s|0)|0;eY(s|0)|0;t=454136}else if((g|0)==313){s=c[u>>2]|0;cj(350512,50,1,s|0)|0;eY(s|0)|0;t=272208}}while(0);s=c[2380901]|0;e=s+4|0;h=(c[e>>2]|0)>>>0<(c[s+8>>2]|0)>>>0;if((a[9531831]&1)!=0){L452:do{if(h){l=gGq(12)|0;do{if((l|0)!=0){if((c[l-4>>2]&3|0)==0){break}gGz(l|0,0,12)}}while(0);c[l+4>>2]=1;c[l>>2]=1;r=bG(t|0)|0;d=c[e>>2]|0;c[l+8>>2]=r;r=s|0;c[(c[r>>2]|0)+(d<<2)>>2]=l;d=c[e>>2]|0;c[e>>2]=d+1;if(d>>>0>1){v=d}else{break}while(1){d=v>>>1;q=c[r>>2]|0;o=q+(d<<2)|0;p=c[o>>2]|0;n=c[q+(v<<2)>>2]|0;if((c[n+4>>2]|0)>>>0<=(c[p+4>>2]|0)>>>0){break L452}c[o>>2]=n;c[(c[r>>2]|0)+(v<<2)>>2]=p;if(v>>>0>3){v=d}else{break}}}}while(0);g4();i=b;return}if(!h){i=b;return}h=gGq(12)|0;do{if((h|0)!=0){if((c[h-4>>2]&3|0)==0){break}gGz(h|0,0,12)}}while(0);c[h+4>>2]=1;c[h>>2]=180;v=bG(t|0)|0;t=c[e>>2]|0;c[h+8>>2]=v;v=s|0;c[(c[v>>2]|0)+(t<<2)>>2]=h;h=c[e>>2]|0;c[e>>2]=h+1;if(h>>>0>1){w=h}else{i=b;return}while(1){h=w>>>1;e=c[v>>2]|0;t=e+(h<<2)|0;s=c[t>>2]|0;r=c[e+(w<<2)>>2]|0;if((c[r+4>>2]|0)>>>0<=(c[s+4>>2]|0)>>>0){g=334;break}c[t>>2]=r;c[(c[v>>2]|0)+(w<<2)>>2]=s;if(w>>>0>3){w=h}else{g=335;break}}if((g|0)==334){i=b;return}else if((g|0)==335){i=b;return}}function g4(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=c[2382968]|0;d=(b|0)==-1?0:b;b=c[2382969]|0;e=c[2382970]|0;f=c[2382971]|0;if((a[9375106]&1)==0){return}c[2382968]=d;c[2382969]=b;c[2382970]=e;c[2382971]=f;do{if((c[2367360]|0)==0){g=d;if((g|0)==(-1|0)|(g|0)==0){h=d;i=f;break}c[2383366]=b;c[2383367]=e;c[2383369]=b;c[2383370]=e;c[2383368]=f;c[2383371]=b<<1;i7(9533464,c[2383398]|0,d);h=c[2383398]|0;i=c[2383371]|0}else{h=d;i=f}}while(0);f=iy(c[2380901]|0)|0;c[2383407]=f;if(gh[c[(c[2383355]|0)+4>>2]&15](c[2383358]|0,h,b,e,i,f)|0){return}a[9375106]=0;return}function g5(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;if((a[9375106]&1)==0){return}c[2382968]=b;c[2382969]=d;c[2382970]=e;c[2382971]=f;do{if((c[2367360]|0)==0){g=b;if((g|0)==(-1|0)|(g|0)==0){h=b;i=f;break}c[2383366]=d;c[2383367]=e;c[2383369]=d;c[2383370]=e;c[2383368]=f;c[2383371]=d<<1;i7(9533464,c[2383398]|0,b);h=c[2383398]|0;i=c[2383371]|0}else{h=b;i=f}}while(0);f=iy(c[2380901]|0)|0;c[2383407]=f;if(gh[c[(c[2383355]|0)+4>>2]&15](c[2383358]|0,h,d,e,i,f)|0){return}a[9375106]=0;return}function g6(a,d){a=a|0;d=d|0;var e=0,f=0,g=0,h=0;e=d<<1;if((e|0)==0){return d|0}else{f=0}do{g=b[a+(f<<1)>>1]|0;h=(c[2368556]|0)-1|0;c[2368556]=h;b[(c[2368555]|0)+(h<<1)>>1]=g;f=f+1|0;}while(f>>>0<e>>>0);return d|0}function g7(b,c){b=b|0;c=c|0;var d=0,e=0;d=c>>>0>1024?1024:c;if(g8(b,d<<1)|0){e=a[9375105]&1}else{e=0}a[9375105]=e;return d|0}function g8(d,e){d=d|0;e=e|0;var f=0,j=0,k=0,l=0,m=0.0,n=0,o=0,p=0.0,q=0,r=0;f=i;i=i+24|0;j=f|0;if((a[9531831]&1)!=0){k=1;i=f;return k|0}if((a[9474209]&1)!=0){k=1;i=f;return k|0}if((a[9375105]&1)==0){k=0;i=f;return k|0}gGz(j|0,0,24);l=c[2368544]|0;m=+g[2368566]*30517578125.0e-15;if((e|0)==0){n=l}else{o=0;do{g[l+(o<<2)>>2]=m*+(b[d+(o<<1)>>1]|0);o=o+1|0;}while(o>>>0<e>>>0);n=c[2368544]|0}c[j>>2]=n;c[j+8>>2]=e>>>1;c[j+4>>2]=c[2368553];if((a[9474244]&1)==0){p=+h[1184275]}else{e=gj[c[(c[2383354]|0)+32>>2]&4095](c[2383357]|0)|0;n=9507040;o=c[n>>2]|0;d=gGK(o,c[n+4>>2]|0,1,0)|0;n=9507040;c[n>>2]=d;c[n+4>>2]=K;c[9474272+((o&8191)<<2)>>2]=e;o=(c[2368564]|0)>>>1;m=+h[1184281]*(+(e-o|0)/+(o|0)*+g[2322070]+1.0);h[1184275]=m;p=m}o=j+16|0;h[o>>3]=p;if((a[9531833]&1)!=0){h[o>>3]=p*+g[2341460]}gg[c[(c[2368543]|0)+4>>2]&4095](c[2368542]|0,j);o=c[2368553]|0;e=c[j+12>>2]|0;if((a[9474208]&1)!=0){if((gp[c[(c[2383354]|0)+4>>2]&16383](c[2383357]|0,o,e<<3)|0)>=0){k=1;i=f;return k|0}j=c[u>>2]|0;cj(383640,81,1,j|0)|0;eY(j|0)|0;k=0;i=f;return k|0}j=c[2368554]|0;n=e<<1;if((n|0)==0){q=j}else{d=0;do{l=~~(+g[o+(d<<2)>>2]*32768.0);if((l|0)>32767){r=32767}else{r=(l|0)<-32768?-32768:l&65535}b[j+(d<<1)>>1]=r;d=d+1|0;}while(d>>>0<n>>>0);q=c[2368554]|0}if((gp[c[(c[2383354]|0)+4>>2]&16383](c[2383357]|0,q,e<<2)|0)>=0){k=1;i=f;return k|0}e=c[u>>2]|0;cj(383640,81,1,e|0)|0;eY(e|0)|0;k=0;i=f;return k|0}function g9(){var d=0,e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0.0,x=0.0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0.0,J=0,K=0.0,L=0.0,M=0.0,N=0,O=0,P=0,Q=0.0,R=0,S=0,T=0,U=0,W=0,X=0;d=i;i=i+16|0;e=d|0;gf[c[(c[2383356]|0)+4>>2]&2047](c[2383359]|0);f=c[2383400]|0;if((f|0)==0){i=d;return}h=e;gGz(9533608,0,16);j=(a[(c[f+16>>2]|0)+68|0]&1)!=0?65542:6;if((gh[c[(c[2383356]|0)+8>>2]&15](c[2383359]|0,0,0,j,0,2)|0)<<16>>16==0){f=c[2383400]|0;a[f+9|0]=0;k=f+16|0;l=c[k>>2]|0;if((c[l+140>>2]|0)==0){m=l}else{l=f+4|0;n=f|0;f=0;while(1){gK[c[(c[l>>2]|0)+20>>2]&7](c[n>>2]|0,f,+g[2332238]);o=f+1|0;p=c[k>>2]|0;if(o>>>0<(c[p+140>>2]|0)>>>0){f=o}else{m=p;break}}}if((c[m+4>>2]|0)==0){i=d;return}else{q=0;r=m}do{m=c[r>>2]|0;g[m+(q*152|0)+20>>2]=+g[m+(q*152|0)+12>>2];g[m+(q*152|0)+24>>2]=+g[m+(q*152|0)+16>>2];q=q+1|0;r=c[k>>2]|0;}while(q>>>0<(c[r+4>>2]|0)>>>0);i=d;return}r=e|0;q=e+8|0;k=e+10|0;m=e+12|0;f=e+14|0;n=0;do{l=gh[c[(c[2383356]|0)+8>>2]&15](c[2383359]|0,0,0,j,n,0)|0;p=gh[c[(c[2383356]|0)+8>>2]&15](c[2383359]|0,0,0,j,n,1)|0;o=c[2383400]|0;gGz(h|0,0,16);L573:do{if((a[o+8|0]&1)==0){a[o+9|0]=0;s=0;t=0}else{u=o+16|0;v=c[u>>2]|0;w=(+((l<<16>>16)+32767|0)/65535.0- +g[v+24>>2])/+g[v+32>>2];x=(+((p<<16>>16)+32767|0)/65535.0- +g[v+28>>2])/+g[v+36>>2];if((c[v+140>>2]|0)==0){y=v}else{v=o+4|0;z=o|0;A=0;while(1){gK[c[(c[v>>2]|0)+20>>2]&7](c[z>>2]|0,A,+g[2332238]);B=A+1|0;C=c[u>>2]|0;if(B>>>0<(c[C+140>>2]|0)>>>0){A=B}else{y=C;break}}}do{if((c[y+4>>2]|0)==0){D=o+9|0}else{A=o+28|0;z=o+4|0;v=o|0;C=0;B=y;do{E=c[B>>2]|0;F=E+(C*152|0)|0;G=c[E+(C*152|0)+8>>2]|0;do{if((G|0)==0){H=E+(C*152|0)+20|0;I=(w- +g[F>>2])/+g[H>>2];J=E+(C*152|0)+24|0;K=(x- +g[E+(C*152|0)+4>>2])/+g[J>>2];L=+g[E+(C*152|0)+12>>2];if(I*I+K*K>1.0){M=L;N=H;O=J;P=411}else{Q=L;P=412}}else if((G|0)==1){L=+V(+(w- +g[F>>2]));J=E+(C*152|0)+20|0;if(L>+g[J>>2]){R=J;P=409;break}L=+V(+(x- +g[E+(C*152|0)+4>>2]));H=E+(C*152|0)+24|0;K=+g[E+(C*152|0)+12>>2];if(L>+g[H>>2]){M=K;N=J;O=H;P=411}else{Q=K;P=412}}else{R=E+(C*152|0)+20|0;P=409}}while(0);do{if((P|0)==409){P=0;M=+g[E+(C*152|0)+12>>2];N=R;O=E+(C*152|0)+24|0;P=411}else if((P|0)==412){P=0;K=+g[E+(C*152|0)+148>>2];G=E+(C*152|0)+20|0;g[G>>2]=Q*K;H=E+(C*152|0)+24|0;g[H>>2]=K*+g[E+(C*152|0)+16>>2];if((c[E+(C*152|0)+128>>2]|0)!=0){gK[c[(c[z>>2]|0)+20>>2]&7](c[v>>2]|0,c[E+(C*152|0)+140>>2]|0,+g[E+(C*152|0)+144>>2]*+g[2332238])}J=c[E+(C*152|0)+44>>2]|0;if((J|0)==0){S=E+(C*152|0)+48|0;T=c[S>>2]|0;U=c[S+4>>2]|0;S=c[r+4>>2]|U;c[r>>2]=c[r>>2]|T;c[r+4>>2]=S;if((T&0|0)==0&(U&524288|0)==0){break}c[A>>2]=c[E+(C*152|0)+60>>2];break}K=+g[E+(C*152|0)+56>>2];L=(w- +g[F>>2])/+g[G>>2]/K;I=(x- +g[E+(C*152|0)+4>>2])/+g[H>>2]/K;H=(J|0)==2?2:0;if(L<-1.0){W=-32767}else{W=L>1.0?32767:~~(L*32767.0)}b[e+8+(H<<1)>>1]=W;if(I<-1.0){X=-32767}else{X=I>1.0?32767:~~(I*32767.0)}b[e+8+((H|1)<<1)>>1]=X}}while(0);if((P|0)==411){P=0;g[N>>2]=M;g[O>>2]=+g[E+(C*152|0)+16>>2]}C=C+1|0;B=c[u>>2]|0;}while(C>>>0<(c[B+4>>2]|0)>>>0);B=c[r>>2]|0;C=c[r+4>>2]|0;A=o+9|0;if((B|0)==0&(C|0)==0){D=A;break}if((a[A]&1)==0){s=C;t=B;break L573}gGz(h|0,0,16);s=0;t=0;break L573}}while(0);a[D]=0;s=0;t=0}}while(0);o=9533608;p=c[o+4>>2]|s;l=9533608;c[l>>2]=c[o>>2]|t;c[l+4>>2]=p;if((b[4766808]|0)==0){b[4766808]=b[q>>1]|0}if((b[4766809]|0)==0){b[4766809]=b[k>>1]|0}if((b[4766810]|0)==0){b[4766810]=b[m>>1]|0}if((b[4766811]|0)==0){b[4766811]=b[f>>1]|0}n=n+1|0;}while((gh[c[(c[2383356]|0)+8>>2]&15](c[2383359]|0,0,0,j,n,2)|0)<<16>>16!=0);i=d;return}function ha(){var a=0,b=0,d=0;a=i;if((c[2380901]|0)!=0){i=a;return}b=gGq(16)|0;do{if((b|0)!=0){if((c[b-4>>2]&3|0)!=0){gGz(b|0,0,16)}c[b+8>>2]=9;d=gGq(36)|0;if((d|0)==0){c[b>>2]=0;gGr(b);break}if((c[d-4>>2]&3|0)!=0){gGz(d|0,0,36)}c[b>>2]=d;c[b+4>>2]=1;c[2380901]=b;i=a;return}}while(0);c[2380901]=0;a=c[u>>2]|0;bU(a|0,547632,(b=i,i=i+16|0,c[b>>2]=165128,c[b+8>>2]=1440,b)|0)|0;i=b;eY(a|0)|0;fm(2)}function hb(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=i;if((a[9365828]&1)==0|(c[2380903]|0)!=0){i=b;return}if((c[2368515]|0)!=0){d=c[u>>2]|0;cj(133376,76,1,d|0)|0;eY(d|0)|0;i=b;return}d=gD[c[2112844]&8191]()|0;c[2380905]=d;if((d|0)==0){e=c[u>>2]|0;cj(107904,85,1,e|0)|0;eY(e|0)|0;i=b;return}e=d+3|0;f=e&-4;g=gGq(f)|0;if((g|0)==0){c[2380904]=0;h=c[u>>2]|0;cj(83232,66,1,h|0)|0;eY(h|0)|0;i=b;return}if((c[g-4>>2]&3|0)!=0){gGz(g|0,0,f|0)}c[2380904]=g;if(!(gA[c[2112846]&16383](g,d)|0)){d=c[u>>2]|0;cj(589792,73,1,d|0)|0;eY(d|0)|0;gGr(c[2380904]|0);c[2380904]=0;i=b;return}if((a[9375104]&1)!=0){d=c[u>>2]|0;g=((c[2341458]|0)>>>0)/1e6|0;bU(d|0,573512,(j=i,i=i+8|0,c[j>>2]=g,j)|0)|0;i=j;eY(d|0)|0}d=c[2341458]|0;g=c[2380904]|0;L671:do{if(f<<2>>>0<d>>>0){h=gGq(32)|0;if((h|0)==0){k=488;break}if((c[h-4>>2]&3|0)!=0){gGz(h|0,0,32)}l=h;c[h+16>>2]=1;m=e>>>2;c[h+24>>2]=m;n=d-1|0;o=n>>>1|n;n=o>>>2|o;o=n>>>4|n;n=o>>>8|o;o=(n>>>16|n)+1|0;n=o>>>1;p=(o-d|0)>>>0<(d-n|0)>>>0?o:n;n=p>>>3;c[h+4>>2]=n;c[h+8>>2]=n-1;if((a[9375104]&1)!=0){o=c[u>>2]|0;q=p>>>23<<3;bU(o|0,362616,(j=i,i=i+8|0,c[j>>2]=q,j)|0)|0;i=j;eY(o|0)|0}o=n<<3;n=gGq(o)|0;do{if((n|0)==0){c[h>>2]=0;r=h+12|0}else{if((c[n-4>>2]&3|0)==0){c[h>>2]=n}else{gGz(n|0,0,o|0);c[h>>2]=n}q=m<<2;p=gGq(q)|0;if((p|0)==0){s=h+12|0;c[s>>2]=0;r=s;break}if((c[p-4>>2]&3|0)==0){c[h+12>>2]=p;gGC(p|0,g|0,f)|0;c[2380903]=l;if((h|0)==0){break L671}i=b;return}else{gGz(p|0,0,q|0);c[h+12>>2]=p;gGC(p|0,g|0,f)|0;c[2380903]=l;i=b;return}}}while(0);gGr(n);gGr(c[r>>2]|0);gGr(h);k=488}else{k=488}}while(0);if((k|0)==488){c[2380903]=0}k=c[u>>2]|0;cj(552e3,78,1,k|0)|0;eY(k|0)|0;i=b;return}function hc(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=i;i=i+4608|0;d=b+4096|0;e=c[2367336]|0;f=b|0;if((e|0)==0){be(f|0,4096,196880,(g=i,i=i+8|0,c[g>>2]=9436570,g)|0)|0;i=g}else{be(f|0,4096,541480,(g=i,i=i+16|0,c[g>>2]=9436570,c[g+8>>2]=e,g)|0)|0;i=g}L705:do{if((gD[c[2112844]&8191]()|0)==0){e=512;h=d|0;j=490048;while(1){k=e-1|0;if((k|0)==0){break}l=a[j]|0;a[h]=l;if(l<<24>>24==0){break L705}else{e=k;h=h+1|0;j=j+1|0}}a[h]=0;if((a[j]|0)==0){break}else{m=j}do{m=m+1|0;}while((a[m]|0)!=0)}else{j=d|0;if(ht(f)|0){h=c[2367336]|0;be(j|0,512,514568,(g=i,i=i+8|0,c[g>>2]=h,g)|0)|0;i=g;break}else{be(j|0,512,501528,(g=i,i=i+8|0,c[g>>2]=f,g)|0)|0;i=g;break}}}while(0);f=c[2380901]|0;m=f+4|0;j=c[m>>2]|0;if(j>>>0>1){h=f|0;e=1;k=j;while(1){j=c[(c[h>>2]|0)+(e<<2)>>2]|0;if((j|0)==0){n=k}else{gGr(c[j+8>>2]|0);gGr(c[(c[h>>2]|0)+(e<<2)>>2]|0);c[(c[h>>2]|0)+(e<<2)>>2]=0;n=c[m>>2]|0}j=e+1|0;if(j>>>0<n>>>0){e=j;k=n}else{break}}}c[m>>2]=1;m=f+12|0;gGr(c[m>>2]|0);c[m>>2]=0;m=c[2380901]|0;f=d|0;d=m+4|0;L726:do{if((c[d>>2]|0)>>>0<(c[m+8>>2]|0)>>>0){n=gGq(12)|0;do{if((n|0)!=0){if((c[n-4>>2]&3|0)==0){break}gGz(n|0,0,12)}}while(0);c[n+4>>2]=2;c[n>>2]=180;k=bG(f|0)|0;e=c[d>>2]|0;c[n+8>>2]=k;k=m|0;c[(c[k>>2]|0)+(e<<2)>>2]=n;e=c[d>>2]|0;c[d>>2]=e+1;if(e>>>0>1){o=e}else{break}while(1){e=o>>>1;h=c[k>>2]|0;j=h+(e<<2)|0;l=c[j>>2]|0;p=c[h+(o<<2)>>2]|0;if((c[p+4>>2]|0)>>>0<=(c[l+4>>2]|0)>>>0){break L726}c[j>>2]=p;c[(c[k>>2]|0)+(o<<2)>>2]=l;if(o>>>0>3){o=e}else{break}}}}while(0);if((a[9375104]&1)==0){i=b;return}o=c[u>>2]|0;bU(o|0,324680,(g=i,i=i+8|0,c[g>>2]=f,g)|0)|0;i=g;eY(o|0)|0;i=b;return}function hd(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=i;i=i+4608|0;d=b+4096|0;e=c[2367336]|0;if((a[9365857]&1)==0){f=e}else{g=e+1|0;c[2367336]=g;f=g}g=b|0;if((f|0)==0){be(g|0,4096,196880,(h=i,i=i+8|0,c[h>>2]=9436570,h)|0)|0;i=h}else{be(g|0,4096,541480,(h=i,i=i+16|0,c[h>>2]=9436570,c[h+8>>2]=f,h)|0)|0;i=h}L748:do{if((gD[c[2112844]&8191]()|0)==0){f=512;e=d|0;j=490048;while(1){k=f-1|0;if((k|0)==0){break}l=a[j]|0;a[e]=l;if(l<<24>>24==0){break L748}else{f=k;e=e+1|0;j=j+1|0}}a[e]=0;if((a[j]|0)==0){break}else{m=j}do{m=m+1|0;}while((a[m]|0)!=0)}else{j=d|0;if(hs(g)|0){e=c[2367336]|0;be(j|0,512,465384,(h=i,i=i+8|0,c[h>>2]=e,h)|0)|0;i=h;break}else{be(j|0,512,454104,(h=i,i=i+8|0,c[h>>2]=g,h)|0)|0;i=h;break}}}while(0);g=c[2380901]|0;m=g+4|0;j=c[m>>2]|0;if(j>>>0>1){e=g|0;f=1;k=j;while(1){j=c[(c[e>>2]|0)+(f<<2)>>2]|0;if((j|0)==0){n=k}else{gGr(c[j+8>>2]|0);gGr(c[(c[e>>2]|0)+(f<<2)>>2]|0);c[(c[e>>2]|0)+(f<<2)>>2]=0;n=c[m>>2]|0}j=f+1|0;if(j>>>0<n>>>0){f=j;k=n}else{break}}}c[m>>2]=1;m=g+12|0;gGr(c[m>>2]|0);c[m>>2]=0;m=c[2380901]|0;g=d|0;d=m+4|0;L769:do{if((c[d>>2]|0)>>>0<(c[m+8>>2]|0)>>>0){n=gGq(12)|0;do{if((n|0)!=0){if((c[n-4>>2]&3|0)==0){break}gGz(n|0,0,12)}}while(0);c[n+4>>2]=2;c[n>>2]=180;k=bG(g|0)|0;f=c[d>>2]|0;c[n+8>>2]=k;k=m|0;c[(c[k>>2]|0)+(f<<2)>>2]=n;f=c[d>>2]|0;c[d>>2]=f+1;if(f>>>0>1){o=f}else{break}while(1){f=o>>>1;e=c[k>>2]|0;j=e+(f<<2)|0;l=c[j>>2]|0;p=c[e+(o<<2)>>2]|0;if((c[p+4>>2]|0)>>>0<=(c[l+4>>2]|0)>>>0){break L769}c[j>>2]=p;c[(c[k>>2]|0)+(o<<2)>>2]=l;if(o>>>0>3){o=f}else{break}}}}while(0);if((a[9375104]&1)==0){i=b;return}o=c[u>>2]|0;bU(o|0,324680,(h=i,i=i+8|0,c[h>>2]=g,h)|0)|0;i=h;eY(o|0)|0;i=b;return}function he(b){b=b|0;a[9263552]=b&1;a[9533441]=a[9474124]&1;a[9533442]=0;hV();b=c[2368532]|0;do{if((b|0)!=0){if((a[9533441]&1)!=0){break}gu[b&16383]()}}while(0);hW();if((a[9533443]&1)!=0){c[2383358]=0}if((a[9533444]&1)!=0){c[2383357]=0}if((a[9533445]&1)!=0){c[2383359]=0}a[9533443]=0;a[9533444]=0;a[9533445]=0;hU();a[9533441]=0;b=c[2383356]|0;if((b|0)==0){return}gf[c[b+4>>2]&2047](c[2383359]|0);return}function hf(){var b=0,d=0,e=0,f=0,g=0;b=i;d=c[u>>2]|0;e=0;do{f=c[9324232+(e<<2)>>2]|0;L804:do{if((f|0)!=1){gg[c[2112838]&4095](e,f);switch(f|0){case 5:{if((a[9375104]&1)==0){break L804}bU(d|0,389448,(g=i,i=i+8|0,c[g>>2]=e+1,g)|0)|0;i=g;eY(d|0)|0;break L804;break};case 0:{if((a[9375104]&1)==0){break L804}bU(d|0,391152,(g=i,i=i+8|0,c[g>>2]=e+1,g)|0)|0;i=g;eY(d|0)|0;break L804;break};case 516:{if((a[9375104]&1)==0){break L804}bU(d|0,387640,(g=i,i=i+8|0,c[g>>2]=e+1,g)|0)|0;i=g;eY(d|0)|0;break L804;break};case 260:{if((a[9375104]&1)==0){break L804}bU(d|0,384840,(g=i,i=i+8|0,c[g>>2]=e+1,g)|0)|0;i=g;eY(d|0)|0;break L804;break};case 2:{if((a[9375104]&1)==0){break L804}bU(d|0,388568,(g=i,i=i+8|0,c[g>>2]=e+1,g)|0)|0;i=g;eY(d|0)|0;break L804;break};case 257:{if((a[9375104]&1)==0){break L804}bU(d|0,385976,(g=i,i=i+8|0,c[g>>2]=e+1,g)|0)|0;i=g;eY(d|0)|0;break L804;break};case 772:{if((a[9375104]&1)==0){break L804}bU(d|0,386808,(g=i,i=i+8|0,c[g>>2]=e+1,g)|0)|0;i=g;eY(d|0)|0;break L804;break};default:{break L804}}}}while(0);e=e+1|0;}while(e>>>0<8);i=b;return}function hg(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;e=i;i=i+256|0;if((c[2368521]|0)==0){i=e;return}f=e|0;a[f]=0;if(gj[c[2368517]&4095](b)|0){g=b?386024:375952;be(f|0,256,398032,(h=i,i=i+8|0,c[h>>2]=g,h)|0)|0;i=h;j=0}else{g=b?358160:350504;be(f|0,256,365568,(h=i,i=i+8|0,c[h>>2]=g,h)|0)|0;i=h;j=1}if((a[f]|0)==0){i=e;return}do{if(j){g=c[u>>2]|0;bU(g|0,374408,(h=i,i=i+8|0,c[h>>2]=f,h)|0)|0;i=h;eY(g|0)|0}else{if((a[9375104]&1)==0){break}g=c[u>>2]|0;bU(g|0,324680,(h=i,i=i+8|0,c[h>>2]=f,h)|0)|0;i=h;eY(g|0)|0}}while(0);if(!d){i=e;return}d=c[2380901]|0;h=d+4|0;j=c[h>>2]|0;if(j>>>0>1){g=d|0;b=1;k=j;while(1){j=c[(c[g>>2]|0)+(b<<2)>>2]|0;if((j|0)==0){l=k}else{gGr(c[j+8>>2]|0);gGr(c[(c[g>>2]|0)+(b<<2)>>2]|0);c[(c[g>>2]|0)+(b<<2)>>2]=0;l=c[h>>2]|0}j=b+1|0;if(j>>>0<l>>>0){b=j;k=l}else{break}}}c[h>>2]=1;h=d+12|0;gGr(c[h>>2]|0);c[h>>2]=0;h=c[2380901]|0;d=h+4|0;if((c[d>>2]|0)>>>0>=(c[h+8>>2]|0)>>>0){i=e;return}l=gGq(12)|0;do{if((l|0)!=0){if((c[l-4>>2]&3|0)==0){break}gGz(l|0,0,12)}}while(0);c[l+4>>2]=1;c[l>>2]=180;k=bG(f|0)|0;f=c[d>>2]|0;c[l+8>>2]=k;k=h|0;c[(c[k>>2]|0)+(f<<2)>>2]=l;l=c[d>>2]|0;c[d>>2]=l+1;if(l>>>0>1){m=l}else{i=e;return}while(1){l=m>>>1;d=c[k>>2]|0;f=d+(l<<2)|0;h=c[f>>2]|0;b=c[d+(m<<2)>>2]|0;if((c[b+4>>2]|0)>>>0<=(c[h+4>>2]|0)>>>0){n=622;break}c[f>>2]=b;c[(c[k>>2]|0)+(m<<2)>>2]=h;if(m>>>0>3){m=l}else{n=617;break}}if((n|0)==617){i=e;return}else if((n|0)==622){i=e;return}}function hh(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;i=i+256|0;e=c[2368521]|0;if((e|0)==0){i=d;return}f=d|0;a[f]=0;g=gD[e&8191]()|0;e=g>>>0>b>>>0;do{if(gj[c[2368520]&4095](b)|0){if(e){h=b+1|0;be(f|0,256,334624,(j=i,i=i+16|0,c[j>>2]=h,c[j+8>>2]=g,j)|0)|0;i=j;k=0;break}else{be(f|0,256,326368,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0)|0;i=j;k=0;break}}else{if(e){h=b+1|0;be(f|0,256,317320,(j=i,i=i+16|0,c[j>>2]=h,c[j+8>>2]=g,j)|0)|0;i=j;k=1;break}else{be(f|0,256,308544,(j=i,i=i+1|0,i=i+7&-8,c[j>>2]=0,j)|0)|0;i=j;k=1;break}}}while(0);if((a[f]|0)==0){i=d;return}do{if(k){g=c[u>>2]|0;bU(g|0,374408,(j=i,i=i+8|0,c[j>>2]=f,j)|0)|0;i=j;eY(g|0)|0}else{if((a[9375104]&1)==0){break}g=c[u>>2]|0;bU(g|0,324680,(j=i,i=i+8|0,c[j>>2]=f,j)|0)|0;i=j;eY(g|0)|0}}while(0);j=c[2380901]|0;k=j+4|0;g=c[k>>2]|0;if(g>>>0>1){b=j|0;e=1;h=g;while(1){g=c[(c[b>>2]|0)+(e<<2)>>2]|0;if((g|0)==0){l=h}else{gGr(c[g+8>>2]|0);gGr(c[(c[b>>2]|0)+(e<<2)>>2]|0);c[(c[b>>2]|0)+(e<<2)>>2]=0;l=c[k>>2]|0}g=e+1|0;if(g>>>0<l>>>0){e=g;h=l}else{break}}}c[k>>2]=1;k=j+12|0;gGr(c[k>>2]|0);c[k>>2]=0;k=c[2380901]|0;j=k+4|0;if((c[j>>2]|0)>>>0>=(c[k+8>>2]|0)>>>0){i=d;return}l=gGq(12)|0;do{if((l|0)!=0){if((c[l-4>>2]&3|0)==0){break}gGz(l|0,0,12)}}while(0);c[l+4>>2]=1;c[l>>2]=180;h=bG(f|0)|0;f=c[j>>2]|0;c[l+8>>2]=h;h=k|0;c[(c[h>>2]|0)+(f<<2)>>2]=l;l=c[j>>2]|0;c[j>>2]=l+1;if(l>>>0>1){m=l}else{i=d;return}while(1){l=m>>>1;j=c[h>>2]|0;f=j+(l<<2)|0;k=c[f>>2]|0;e=c[j+(m<<2)>>2]|0;if((c[e+4>>2]|0)>>>0<=(c[k+4>>2]|0)>>>0){n=653;break}c[f>>2]=e;c[(c[h>>2]|0)+(m<<2)>>2]=k;if(m>>>0>3){m=l}else{n=654;break}}if((n|0)==653){i=d;return}else if((n|0)==654){i=d;return}}function hi(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=i;i=i+160|0;e=d|0;f=d+80|0;g=4096;h=9411994;j=b;while(1){k=g-1|0;if((k|0)==0){l=658;break}m=a[j]|0;a[h]=m;if(m<<24>>24==0){n=4096;o=9407898;p=b;break}else{g=k;h=h+1|0;j=j+1|0}}do{if((l|0)==658){a[h]=0;if((a[j]|0)==0){n=4096;o=9407898;p=b;break}else{q=j}while(1){g=q+1|0;if((a[g]|0)==0){n=4096;o=9407898;p=b;break}else{q=g}}}}while(0);while(1){q=n-1|0;if((q|0)==0){l=662;break}j=a[p]|0;a[o]=j;if(j<<24>>24==0){break}else{n=q;o=o+1|0;p=p+1|0}}do{if((l|0)==662){a[o]=0;if((a[p]|0)==0){break}else{r=p}do{r=r+1|0;}while((a[r]|0)!=0)}}while(0);r=cE(9407898,46)|0;if((r|0)!=0){a[r]=0}if((a[9395600]&1)==0){hG(9416090,9407898,568864)}if((a[9395601]&1)==0){hG(9436570,9407898,562608)}do{if((f$(9416090,f|0)|0)>=0){if((c[f+12>>2]&61440|0)!=16384){break}hH(9416090,568864);if((a[9375104]&1)==0){break}r=c[u>>2]|0;bU(r|0,394352,(s=i,i=i+8|0,c[s>>2]=9416090,s)|0)|0;i=s;eY(r|0)|0}}while(0);do{if((f$(9436570,e|0)|0)>=0){if((c[e+12>>2]&61440|0)!=16384){break}hH(9436570,562608);if((a[9375104]&1)==0){break}f=c[u>>2]|0;bU(f|0,392984,(s=i,i=i+8|0,c[s>>2]=9436570,s)|0)|0;i=s;eY(f|0)|0}}while(0);if((a[9361732]|0)!=0){i=d;return}hJ(9361732,b);i=d;return}function hj(){var b=0,d=0;b=c[2344802]|0;do{if((b|0)==2|(b|0)==3){if((a[9395600]&1)==0){hF(9416090,9383312,568864)}hF(9424282,9416090,402680);if((a[9395601]&1)!=0){break}hF(9436570,9383312,562608)}else if((b|0)==4){if(!((a[9395600]&1)==0|(a[9387408]|0)==0|(a[9391504]|0)==0)){d=c[u>>2]|0;cj(400624,109,1,d|0)|0;eY(d|0)|0}hF(9428378,9387408,568864);hF(9432474,9391504,568864);if((a[9395601]&1)!=0){break}hF(9436570,(a[9387408]|0)!=0?9387408:9391504,562608)}else if((b|0)==1){if((a[9395600]&1)==0){hF(9416090,9379216,568864)}if((a[9395601]&1)==0){hF(9436570,9379216,562608)}hF(9420186,9416090,277512)}else{hF(9420186,9416090,277512)}}while(0);hF(9523632,9416090,9534384);if((a[9407898]|0)==0){return}if((a[9457054]|0)==0){hG(9457054,9407898,399024)}if((a[9461150]|0)==0){hG(9461150,9407898,398024)}if((a[9465246]|0)==0){hG(9465246,9407898,397344)}if((a[9440666]|0)!=0){return}hG(9440666,9407898,395976);return}function hk(d,e){d=d|0;e=e|0;var f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,v=0,w=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,ag=0,ah=0,ai=0,aj=0,ak=0,am=0,an=0,ao=0,ar=0,as=0,au=0,av=0,aw=0,ax=0,ay=0,aA=0,aB=0,aC=0,aD=0,aF=0,aG=0,aI=0,aJ=0,aL=0,aM=0,aO=0,aP=0,aR=0,aS=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0,cf=0,cg=0,ch=0,ci=0,cj=0,ck=0,cl=0,cm=0,cn=0,co=0,cp=0,cq=0,cr=0,cs=0,ct=0,cu=0,cv=0,cw=0,cx=0,cy=0,cz=0,cA=0,cB=0,cC=0,cD=0,cE=0,cF=0,cG=0,cH=0,cI=0,cJ=0,cK=0,cL=0,cM=0,cN=0,cO=0,cP=0,cQ=0,cR=0,cS=0,cT=0,cU=0,cV=0,cW=0,cX=0,cY=0,cZ=0,c_=0,c$=0,c0=0,c1=0,c2=0,c3=0,c4=0,c5=0,c6=0,c7=0,c8=0,c9=0,da=0,db=0,dc=0,dd=0,de=0,df=0,dg=0,dh=0,di=0,dj=0,dk=0,dl=0,dm=0,dn=0,dp=0,dq=0,dr=0,ds=0,dt=0,du=0,dv=0,dw=0,dx=0,dy=0,dz=0,dA=0,dB=0,dC=0,dD=0,dE=0,dF=0,dG=0,dH=0,dI=0,dJ=0,dK=0,dL=0,dM=0,dN=0,dO=0,dP=0,dQ=0,dR=0,dS=0,dT=0,dU=0,dV=0,dW=0,dX=0,dY=0,dZ=0,d_=0,d$=0,d0=0,d1=0,d2=0,d3=0,d4=0,d5=0,d6=0,d7=0,d8=0,d9=0,ea=0,eb=0,ec=0,ed=0,ee=0,ef=0,eg=0,eh=0,ei=0,ej=0,ek=0,el=0,em=0,en=0,eo=0,ep=0,eq=0,er=0,es=0,et=0,eu=0,ev=0,ew=0,ex=0.0,ey=0,ez=0,eA=0,eB=0,eC=0,eD=0,eE=0,eF=0,eG=0,eH=0,eI=0,eJ=0,eK=0,eL=0,eM=0,eN=0,eO=0,eP=0,eQ=0,eR=0,eS=0,eT=0,eU=0,eV=0,eW=0,eX=0,eY=0,eZ=0,e_=0,e$=0,e0=0,e1=0,e2=0,e3=0,e4=0,e5=0,e6=0,e7=0,e8=0,e9=0,fa=0,fb=0,fc=0,fd=0,fe=0,ff=0,fg=0,fh=0,fi=0,fj=0,fk=0,fl=0,fm=0,fn=0,fo=0,fp=0,fq=0,fr=0,fs=0,ft=0,fu=0,fv=0,fw=0,fx=0,fy=0,fz=0,fA=0,fB=0,fC=0,fD=0,fE=0,fF=0,fG=0,fH=0,fI=0,fJ=0,fK=0,fL=0,fM=0,fN=0,fO=0,fP=0,fQ=0,fR=0,fS=0,fT=0,fU=0,fV=0,fW=0,fX=0,fY=0,fZ=0,f_=0,f$=0,f0=0,f1=0;f=i;i=i+13032|0;j=1;k=0;l=i;i=i+168|0;c[l>>2]=0;while(1)switch(j|0){case 1:m=f|0;n=f+8|0;o=f+16|0;p=f+24|0;q=f+32|0;r=f+40|0;s=f+48|0;t=f+56|0;v=f+64|0;w=f+72|0;z=f+152|0;A=f+232|0;B=f+240|0;C=f+4336|0;D=f+8432|0;E=f+12528|0;F=f+12536|0;a[9375106]=1;a[9375105]=1;c[2344802]=0;G=gGA(9533144,j,l)|0;j=582;break;case 582:if((G|0)>0){j=2;break}else{j=3;break};case 2:H=c[u>>2]|0;az(6140,H|0,272152,(I=i,i=i+8|0,c[I>>2]=9532119,I)|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=I;at(620,H|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;J=G;j=581;break;case 3:a[9532117]=1;a[9533304]=0;a[9533305]=0;a[9395600]=0;a[9395601]=0;if((d|0)<2){j=4;break}else{j=5;break};case 4:a[9533305]=1;j=196;break;case 5:c[2374]=0;c[E>>2]=0;c[F>>2]=562080;c[F+4>>2]=0;c[F+8>>2]=E;c[F+12>>2]=77;c[F+16>>2]=560600;c[F+20>>2]=0;c[F+24>>2]=0;c[F+28>>2]=104;c[F+32>>2]=559400;c[F+36>>2]=1;c[F+40>>2]=0;c[F+44>>2]=115;c[F+48>>2]=558008;c[F+52>>2]=0;c[F+56>>2]=0;c[F+60>>2]=102;c[F+64>>2]=556432;c[F+68>>2]=0;c[F+72>>2]=0;c[F+76>>2]=118;c[F+80>>2]=555608;c[F+84>>2]=1;c[F+88>>2]=0;c[F+92>>2]=103;c[F+96>>2]=553664;c[F+100>>2]=1;c[F+104>>2]=0;c[F+108>>2]=99;c[F+112>>2]=551080;c[F+116>>2]=1;c[F+120>>2]=E;c[F+124>>2]=67;c[F+128>>2]=245912;c[F+132>>2]=1;c[F+136>>2]=0;c[F+140>>2]=109;c[F+144>>2]=547928;c[F+148>>2]=1;c[F+152>>2]=0;c[F+156>>2]=78;c[F+160>>2]=545880;c[F+164>>2]=0;c[F+168>>2]=0;c[F+172>>2]=112;c[F+176>>2]=544768;c[F+180>>2]=0;c[F+184>>2]=0;c[F+188>>2]=106;c[F+192>>2]=543536;c[F+196>>2]=0;c[F+200>>2]=0;c[F+204>>2]=74;c[F+208>>2]=542232;c[F+212>>2]=1;c[F+216>>2]=0;c[F+220>>2]=65;c[F+224>>2]=541464;c[F+228>>2]=1;c[F+232>>2]=0;c[F+236>>2]=83;c[F+240>>2]=540688;c[F+244>>2]=1;c[F+248>>2]=0;c[F+252>>2]=98;c[F+256>>2]=538960;c[F+260>>2]=1;c[F+264>>2]=0;c[F+268>>2]=66;c[F+272>>2]=537496;c[F+276>>2]=0;c[F+280>>2]=0;c[F+284>>2]=52;c[F+288>>2]=535544;c[F+292>>2]=1;c[F+296>>2]=0;c[F+300>>2]=89;c[F+304>>2]=533704;c[F+308>>2]=1;c[F+312>>2]=0;c[F+316>>2]=90;c[F+320>>2]=532224;c[F+324>>2]=1;c[F+328>>2]=0;c[F+332>>2]=80;c[F+336>>2]=531328;c[F+340>>2]=1;c[F+344>>2]=0;c[F+348>>2]=82;c[F+352>>2]=530200;c[F+356>>2]=1;c[F+360>>2]=0;c[F+364>>2]=77;c[F+368>>2]=529224;c[F+372>>2]=1;c[F+376>>2]=0;c[F+380>>2]=85;c[F+384>>2]=528520;c[F+388>>2]=1;c[F+392>>2]=E;c[F+396>>2]=66;c[F+400>>2]=527448;c[F+404>>2]=1;c[F+408>>2]=E;c[F+412>>2]=73;c[F+416>>2]=525576;c[F+420>>2]=0;c[F+424>>2]=E;c[F+428>>2]=110;c[F+432>>2]=524256;c[F+436>>2]=1;c[F+440>>2]=0;c[F+444>>2]=88;c[F+448>>2]=522256;c[F+452>>2]=0;c[F+456>>2]=0;c[F+460>>2]=68;c[F+464>>2]=520184;c[F+468>>2]=0;c[F+472>>2]=E;c[F+476>>2]=102;gGz(F+480|0,0,16);L=0;j=6;break;case 6:c[E>>2]=0;if((L|0)==0){j=7;break}else{M=L;j=8;break};case 7:c[2374]=1;M=1;j=8;break;case 8:if((d|0)==1){N=M;j=176;break}else{j=9;break};case 9:O=e+(M<<2)|0;P=c[O>>2]|0;if((P|0)==0){Q=-1;R=-1;j=17;break}else{S=0;T=P;j=10;break};case 10:if((a[T]|0)==45){j=11;break}else{j=12;break};case 11:if((a[T+1|0]|0)==45){j=12;break}else{W=S;j=13;break};case 12:H=S+1|0;X=c[e+(H+M<<2)>>2]|0;if((X|0)==0){W=-1;j=13;break}else{S=H;T=X;j=10;break};case 13:Y=0;Z=P;j=14;break;case 14:if((a[Z]|0)==45){j=15;break}else{j=16;break};case 15:if((a[Z+1|0]|0)==45){Q=Y;R=W;j=17;break}else{j=16;break};case 16:X=Y+1|0;H=c[e+(X+M<<2)>>2]|0;if((H|0)==0){Q=-1;R=W;j=17;break}else{Y=X;Z=H;j=14;break};case 17:_=(R|0)==-1;$=(Q|0)==-1;if(_&$){N=M;j=176;break}else{j=18;break};case 18:if((R|0)>0){j=19;break}else{j=28;break};case 19:if((R|0)<(Q|0)|$){j=20;break}else{j=28;break};case 20:aa=R+M|0;ab=e+(aa<<2)|0;ac=ab-O|0;ad=ac>>2;if((ad|0)==0){ae=0;j=23;break}else{j=21;break};case 21:if(ad>>>0>65535){j=22;break}else{ae=ac;j=23;break};case 22:ae=((ac>>>0)/(ad>>>0)|0|0)==4?ac:-1;j=23;break;case 23:ag=at(1570,ae|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((ag|0)==0){j=26;break}else{j=24;break};case 24:if((c[ag-4>>2]&3|0)==0){j=27;break}else{j=25;break};case 25:gGz(ag|0,0,ae|0);j=27;break;case 26:H=c[u>>2]|0;az(6140,H|0,547632,(I=i,i=i+16|0,c[I>>2]=571864,c[I+8>>2]=153,I)|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=I;at(620,H|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ap(930,2);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;return 0;case 27:H=O;gGC(ag|0,H|0,ac)|0;aQ(70,H|0,ab|0,d-aa<<2|0);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;gGC(e+(d-ad<<2)|0,ag|0,ac)|0;ap(382,ag|0);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=42;break;case 28:if((Q|0)>0){j=29;break}else{j=39;break};case 29:if((Q|0)<(R|0)|_){j=30;break}else{j=39;break};case 30:ah=Q+M|0;ai=e+(ah<<2)|0;aj=ai-O|0;ak=aj>>2;if((ak|0)==0){am=0;j=33;break}else{j=31;break};case 31:if(ak>>>0>65535){j=32;break}else{am=aj;j=33;break};case 32:am=((aj>>>0)/(ak>>>0)|0|0)==4?aj:-1;j=33;break;case 33:an=at(1570,am|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((an|0)==0){j=36;break}else{j=34;break};case 34:if((c[an-4>>2]&3|0)==0){j=37;break}else{j=35;break};case 35:gGz(an|0,0,am|0);j=37;break;case 36:H=c[u>>2]|0;az(6140,H|0,547632,(I=i,i=i+16|0,c[I>>2]=571864,c[I+8>>2]=153,I)|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=I;at(620,H|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ap(930,2);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;return 0;case 37:H=O;gGC(an|0,H|0,aj)|0;aQ(70,H|0,ai|0,d-ah<<2|0);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;gGC(e+(d-ak<<2)|0,an|0,aj)|0;ap(382,an|0);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((R|0)==0){j=42;break}else{j=38;break};case 38:ao=c[2374]|0;j=54;break;case 39:ar=(R|0)==0;as=(Q|0)==0;if(ar|as){j=41;break}else{j=40;break};case 40:H=c[u>>2]|0;az(6140,H|0,547632,(I=i,i=i+16|0,c[I>>2]=571864,c[I+8>>2]=193,I)|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=I;at(620,H|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ap(930,2);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;return 0;case 41:if(ar){j=42;break}else{j=53;break};case 42:au=c[2374]|0;av=c[e+(au<<2)>>2]|0;aw=av+1|0;ax=a[aw]|0;if(ax<<24>>24==58){j=174;break}else{j=43;break};case 43:ay=az(5010,518568,ax<<24>>24|0,41)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((ay|0)==0){j=174;break}else{j=44;break};case 44:aA=av+2|0;H=(a[ay+1|0]|0)==58;aB=H&(a[aA]|0)!=0;if(H){j=45;break}else{j=50;break};case 45:if(aB){j=46;break}else{j=47;break};case 46:c[2113002]=aA;aC=au+1|0;aD=aA;j=48;break;case 47:H=c[e+(au+1<<2)>>2]|0;c[2113002]=H;aC=au+2|0;aD=H;j=48;break;case 48:c[2374]=aC;if((aD|0)==0){j=174;break}else{j=49;break};case 49:aF=a[ay]|0;aG=aC;j=63;break;case 50:if(aB){j=51;break}else{j=52;break};case 51:H=at(2092,aA|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;aQ(70,aw|0,aA|0,H+1|0);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;aF=a[ay]|0;aG=au;j=63;break;case 52:H=au+1|0;c[2374]=H;aF=a[ay]|0;aG=H;j=63;break;case 53:if(as){ao=M;j=54;break}else{j=174;break};case 54:aI=0;j=55;break;case 55:aJ=c[F+(aI<<4)>>2]|0;if((aJ|0)==0){j=174;break}else{j=56;break};case 56:H=aK(13206,aJ|0,(c[e+(ao<<2)>>2]|0)+2|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((H|0)==0){j=58;break}else{j=57;break};case 57:aI=aI+1|0;j=55;break;case 58:aL=ao+1|0;if((c[F+(aI<<4)+4>>2]|0)==0){aM=aL;j=61;break}else{j=59;break};case 59:aO=c[e+(aL<<2)>>2]|0;if((aO|0)==0){j=174;break}else{j=60;break};case 60:c[2113002]=aO;aM=ao+2|0;j=61;break;case 61:c[2374]=aM;aP=c[F+(aI<<4)+8>>2]|0;aR=c[F+(aI<<4)+12>>2]|0;if((aP|0)==0){aF=aR;aG=aM;j=63;break}else{j=62;break};case 62:c[aP>>2]=aR;j=153;break;case 63:switch(aF|0){case 90:{j=103;break};case 83:{j=109;break};case 118:{j=115;break};case 109:{j=116;break};case 78:{j=119;break};case 112:{j=122;break};case 99:{j=123;break};case 80:case 82:{j=128;break};case 77:{j=134;break};case 85:{j=142;break};case 88:{j=148;break};case 0:{j=153;break};case 63:{j=174;break};case-1:{N=aG;j=176;break};case 68:{j=64;break};case 104:{j=65;break};case 52:{j=66;break};case 106:{j=67;break};case 74:{j=68;break};case 65:{j=69;break};case 115:{j=72;break};case 102:{j=78;break};case 103:{j=79;break};case 98:{j=85;break};case 66:{j=91;break};case 89:{j=97;break};default:{j=175;break}}break;case 64:L=c[2374]|0;j=6;break;case 65:aE(2318);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ap(930,0);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;return 0;case 66:c[2331059]=257;a[9395603]=1;j=64;break;case 67:c[2331059]=516;a[9395603]=1;j=64;break;case 68:c[2331059]=772;a[9395603]=1;j=64;break;case 69:H=az(5232,c[2113002]|0,0,0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;aS=H-1|0;if(aS>>>0>7){j=70;break}else{j=71;break};case 70:H=c[u>>2]|0;aT(8,517432,57,1,H|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;at(620,H|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;aE(2318);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ap(84,516528);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;return 0;case 71:c[9324232+(aS<<2)>>2]=5;a[9395602+aS|0]=1;j=64;break;case 72:aU=4096;aV=9416090;aW=c[2113002]|0;j=73;break;case 73:aX=aU-1|0;if((aX|0)==0){j=75;break}else{j=74;break};case 74:H=a[aW]|0;a[aV]=H;if(H<<24>>24==0){j=77;break}else{aU=aX;aV=aV+1|0;aW=aW+1|0;j=73;break};case 75:a[aV]=0;if((a[aW]|0)==0){j=77;break}else{aY=aW;j=76;break};case 76:H=aY+1|0;if((a[H]|0)==0){j=77;break}else{aY=H;j=76;break};case 77:a[9395600]=1;j=64;break;case 78:a[9375107]=1;j=64;break;case 79:aZ=4096;a_=9379216;a$=c[2113002]|0;j=80;break;case 80:a0=aZ-1|0;if((a0|0)==0){j=82;break}else{j=81;break};case 81:H=a[a$]|0;a[a_]=H;if(H<<24>>24==0){j=84;break}else{aZ=a0;a_=a_+1|0;a$=a$+1|0;j=80;break};case 82:a[a_]=0;if((a[a$]|0)==0){j=84;break}else{a1=a$;j=83;break};case 83:H=a1+1|0;if((a[H]|0)==0){j=84;break}else{a1=H;j=83;break};case 84:c[2344802]=1;j=64;break;case 85:a2=4096;a3=9383312;a4=c[2113002]|0;j=86;break;case 86:a5=a2-1|0;if((a5|0)==0){j=88;break}else{j=87;break};case 87:H=a[a4]|0;a[a3]=H;if(H<<24>>24==0){j=90;break}else{a2=a5;a3=a3+1|0;a4=a4+1|0;j=86;break};case 88:a[a3]=0;if((a[a4]|0)==0){j=90;break}else{a6=a4;j=89;break};case 89:H=a6+1|0;if((a[H]|0)==0){j=90;break}else{a6=H;j=89;break};case 90:c[2344802]=2;j=64;break;case 91:a7=4096;a8=9383312;a9=c[2113002]|0;j=92;break;case 92:ba=a7-1|0;if((ba|0)==0){j=94;break}else{j=93;break};case 93:H=a[a9]|0;a[a8]=H;if(H<<24>>24==0){j=96;break}else{a7=ba;a8=a8+1|0;a9=a9+1|0;j=92;break};case 94:a[a8]=0;if((a[a9]|0)==0){j=96;break}else{bb=a9;j=95;break};case 95:H=bb+1|0;if((a[H]|0)==0){j=96;break}else{bb=H;j=95;break};case 96:c[2344802]=3;j=64;break;case 97:bc=4096;bd=9387408;be=c[2113002]|0;j=98;break;case 98:bf=bc-1|0;if((bf|0)==0){j=100;break}else{j=99;break};case 99:H=a[be]|0;a[bd]=H;if(H<<24>>24==0){j=102;break}else{bc=bf;bd=bd+1|0;be=be+1|0;j=98;break};case 100:a[bd]=0;if((a[be]|0)==0){j=102;break}else{bg=be;j=101;break};case 101:H=bg+1|0;if((a[H]|0)==0){j=102;break}else{bg=H;j=101;break};case 102:c[2344802]=4;j=64;break;case 103:bh=4096;bi=9391504;bj=c[2113002]|0;j=104;break;case 104:bk=bh-1|0;if((bk|0)==0){j=106;break}else{j=105;break};case 105:H=a[bj]|0;a[bi]=H;if(H<<24>>24==0){j=108;break}else{bh=bk;bi=bi+1|0;bj=bj+1|0;j=104;break};case 106:a[bi]=0;if((a[bj]|0)==0){j=108;break}else{bl=bj;j=107;break};case 107:H=bl+1|0;if((a[H]|0)==0){j=108;break}else{bl=H;j=107;break};case 108:c[2344802]=4;j=64;break;case 109:bm=4096;bn=9436570;bo=c[2113002]|0;j=110;break;case 110:bp=bm-1|0;if((bp|0)==0){j=112;break}else{j=111;break};case 111:H=a[bo]|0;a[bn]=H;if(H<<24>>24==0){j=114;break}else{bm=bp;bn=bn+1|0;bo=bo+1|0;j=110;break};case 112:a[bn]=0;if((a[bo]|0)==0){j=114;break}else{bq=bo;j=113;break};case 113:H=bq+1|0;if((a[H]|0)==0){j=114;break}else{bq=H;j=113;break};case 114:a[9395601]=1;j=64;break;case 115:a[9375104]=1;j=64;break;case 116:H=az(5232,c[2113002]|0,0,0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;br=H-1|0;if(br>>>0>7){j=117;break}else{j=118;break};case 117:H=c[u>>2]|0;aT(8,515568,52,1,H|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;at(620,H|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;aE(2318);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ap(84,516528);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;return 0;case 118:c[9324232+(br<<2)>>2]=2;a[9395602+br|0]=1;j=64;break;case 119:H=az(5232,c[2113002]|0,0,0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;bs=H-1|0;if(bs>>>0>7){j=120;break}else{j=121;break};case 120:H=c[u>>2]|0;aT(8,514504,58,1,H|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;at(620,H|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;aE(2318);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ap(84,516528);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;return 0;case 121:c[9324232+(bs<<2)>>2]=0;a[9395602+bs|0]=1;j=64;break;case 122:c[2331059]=260;a[9395603]=1;j=64;break;case 123:bt=4096;bu=9395610;bv=c[2113002]|0;j=124;break;case 124:bw=bt-1|0;if((bw|0)==0){j=126;break}else{j=125;break};case 125:H=a[bv]|0;a[bu]=H;if(H<<24>>24==0){j=64;break}else{bt=bw;bu=bu+1|0;bv=bv+1|0;j=124;break};case 126:a[bu]=0;if((a[bv]|0)==0){j=64;break}else{bx=bv;j=127;break};case 127:H=bx+1|0;if((a[H]|0)==0){j=64;break}else{bx=H;j=127;break};case 128:by=4096;bz=9527729;bA=c[2113002]|0;j=129;break;case 129:bB=by-1|0;if((bB|0)==0){j=131;break}else{j=130;break};case 130:H=a[bA]|0;a[bz]=H;if(H<<24>>24==0){j=133;break}else{by=bB;bz=bz+1|0;bA=bA+1|0;j=129;break};case 131:a[bz]=0;if((a[bA]|0)==0){j=133;break}else{bC=bA;j=132;break};case 132:H=bC+1|0;if((a[H]|0)==0){j=133;break}else{bC=H;j=132;break};case 133:a[9531826]=(aF|0)==80|0;a[9531825]=(aF|0)==82|0;j=64;break;case 134:bD=c[2113002]|0;H=aK(13206,bD|0,513680)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((H|0)==0){j=135;break}else{j=136;break};case 135:a[9531828]=1;a[9531829]=1;j=64;break;case 136:H=aK(13206,bD|0,511912)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((H|0)==0){j=137;break}else{j=138;break};case 137:a[9531828]=1;j=64;break;case 138:H=aK(13206,bD|0,510544)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((H|0)==0){j=139;break}else{j=140;break};case 139:a[9531829]=1;j=64;break;case 140:H=aK(13206,bD|0,508816)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((H|0)==0){j=64;break}else{j=141;break};case 141:H=c[u>>2]|0;aT(8,506792,54,1,H|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;at(620,H|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;aE(2318);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ap(84,516528);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;return 0;case 142:bE=4096;bF=9457054;bG=c[2113002]|0;j=143;break;case 143:bH=bE-1|0;if((bH|0)==0){j=145;break}else{j=144;break};case 144:H=a[bG]|0;a[bF]=H;if(H<<24>>24==0){j=147;break}else{bE=bH;bF=bF+1|0;bG=bG+1|0;j=143;break};case 145:a[bF]=0;if((a[bG]|0)==0){j=147;break}else{bI=bG;j=146;break};case 146:H=bI+1|0;if((a[H]|0)==0){j=147;break}else{bI=H;j=146;break};case 147:a[9457051]=1;j=64;break;case 148:bJ=4096;bK=9440666;bL=c[2113002]|0;j=149;break;case 149:bM=bJ-1|0;if((bM|0)==0){j=151;break}else{j=150;break};case 150:H=a[bL]|0;a[bK]=H;if(H<<24>>24==0){j=64;break}else{bJ=bM;bK=bK+1|0;bL=bL+1|0;j=149;break};case 151:a[bK]=0;if((a[bL]|0)==0){j=64;break}else{bN=bL;j=152;break};case 152:H=bN+1|0;if((a[H]|0)==0){j=64;break}else{bN=H;j=152;break};case 153:switch(c[E>>2]|0){case 77:{j=154;break};case 67:{j=155;break};case 66:{j=160;break};case 73:{j=166;break};case 110:{j=172;break};case 102:{j=173;break};default:{j=64;break}}break;case 154:a[9533305]=1;j=64;break;case 155:bO=4096;bP=9399706;bQ=c[2113002]|0;j=156;break;case 156:bR=bO-1|0;if((bR|0)==0){j=158;break}else{j=157;break};case 157:H=a[bQ]|0;a[bP]=H;if(H<<24>>24==0){j=64;break}else{bO=bR;bP=bP+1|0;bQ=bQ+1|0;j=156;break};case 158:a[bP]=0;if((a[bQ]|0)==0){j=64;break}else{bS=bQ;j=159;break};case 159:H=bS+1|0;if((a[H]|0)==0){j=64;break}else{bS=H;j=159;break};case 160:bT=4096;bU=9461150;bV=c[2113002]|0;j=161;break;case 161:bW=bT-1|0;if((bW|0)==0){j=163;break}else{j=162;break};case 162:H=a[bV]|0;a[bU]=H;if(H<<24>>24==0){j=165;break}else{bT=bW;bU=bU+1|0;bV=bV+1|0;j=161;break};case 163:a[bU]=0;if((a[bV]|0)==0){j=165;break}else{bX=bV;j=164;break};case 164:H=bX+1|0;if((a[H]|0)==0){j=165;break}else{bX=H;j=164;break};case 165:a[9457052]=1;j=64;break;case 166:bY=4096;bZ=9465246;b_=c[2113002]|0;j=167;break;case 167:b$=bY-1|0;if((b$|0)==0){j=169;break}else{j=168;break};case 168:H=a[b_]|0;a[bZ]=H;if(H<<24>>24==0){j=171;break}else{bY=b$;bZ=bZ+1|0;b_=b_+1|0;j=167;break};case 169:a[bZ]=0;if((a[b_]|0)==0){j=171;break}else{b0=b_;j=170;break};case 170:H=b0+1|0;if((a[H]|0)==0){j=171;break}else{b0=H;j=170;break};case 171:a[9457053]=1;j=64;break;case 172:a[9457050]=1;j=64;break;case 173:at(2570,10)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;at(592,502560)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;aK(12540,501512,(I=i,i=i+24|0,c[I>>2]=500480,c[I+8>>2]=499144,c[I+16>>2]=243216,I)|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=I;aK(12540,501512,(I=i,i=i+24|0,c[I>>2]=497960,c[I+8>>2]=496496,c[I+16>>2]=243216,I)|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=I;aK(12540,501512,(I=i,i=i+24|0,c[I>>2]=494744,c[I+8>>2]=493328,c[I+16>>2]=250320,I)|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=I;aK(12540,501512,(I=i,i=i+24|0,c[I>>2]=492536,c[I+8>>2]=491648,c[I+16>>2]=243216,I)|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=I;aK(12540,501512,(I=i,i=i+24|0,c[I>>2]=490976,c[I+8>>2]=490024,c[I+16>>2]=250320,I)|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=I;aK(12540,501512,(I=i,i=i+24|0,c[I>>2]=489120,c[I+8>>2]=487680,c[I+16>>2]=243216,I)|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=I;aK(12540,501512,(I=i,i=i+24|0,c[I>>2]=486184,c[I+8>>2]=484624,c[I+16>>2]=243216,I)|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=I;aK(12540,501512,(I=i,i=i+24|0,c[I>>2]=482784,c[I+8>>2]=481184,c[I+16>>2]=243216,I)|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=I;aK(12540,501512,(I=i,i=i+24|0,c[I>>2]=479816,c[I+8>>2]=481184,c[I+16>>2]=243216,I)|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=I;aK(12540,501512,(I=i,i=i+24|0,c[I>>2]=478904,c[I+8>>2]=481184,c[I+16>>2]=243216,I)|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=I;aK(12540,501512,(I=i,i=i+24|0,c[I>>2]=478144,c[I+8>>2]=481184,c[I+16>>2]=243216,I)|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=I;aK(12540,501512,(I=i,i=i+24|0,c[I>>2]=477144,c[I+8>>2]=481184,c[I+16>>2]=243216,I)|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=I;aK(12540,501512,(I=i,i=i+24|0,c[I>>2]=476008,c[I+8>>2]=481184,c[I+16>>2]=243216,I)|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=I;aK(12540,501512,(I=i,i=i+24|0,c[I>>2]=474736,c[I+8>>2]=481184,c[I+16>>2]=243216,I)|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=I;aK(12540,501512,(I=i,i=i+24|0,c[I>>2]=473304,c[I+8>>2]=481184,c[I+16>>2]=243216,I)|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=I;aK(12540,501512,(I=i,i=i+24|0,c[I>>2]=471656,c[I+8>>2]=470304,c[I+16>>2]=250320,I)|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=I;aK(12540,501512,(I=i,i=i+24|0,c[I>>2]=468680,c[I+8>>2]=481184,c[I+16>>2]=243216,I)|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=I;aK(12540,501512,(I=i,i=i+24|0,c[I>>2]=467752,c[I+8>>2]=467080,c[I+16>>2]=243216,I)|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=I;aK(12540,501512,(I=i,i=i+24|0,c[I>>2]=466096,c[I+8>>2]=465360,c[I+16>>2]=243216,I)|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=I;aK(12540,501512,(I=i,i=i+24|0,c[I>>2]=464752,c[I+8>>2]=463296,c[I+16>>2]=243216,I)|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=I;aK(12540,501512,(I=i,i=i+24|0,c[I>>2]=461904,c[I+8>>2]=460480,c[I+16>>2]=243216,I)|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=I;aK(12540,501512,(I=i,i=i+24|0,c[I>>2]=458848,c[I+8>>2]=457440,c[I+16>>2]=250320,I)|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=I;aK(12540,501512,(I=i,i=i+24|0,c[I>>2]=456688,c[I+8>>2]=455768,c[I+16>>2]=243216,I)|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=I;aK(12540,501512,(I=i,i=i+24|0,c[I>>2]=454752,c[I+8>>2]=454048,c[I+16>>2]=243216,I)|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=I;aK(12540,501512,(I=i,i=i+24|0,c[I>>2]=453408,c[I+8>>2]=452104,c[I+16>>2]=243216,I)|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=I;aK(12540,501512,(I=i,i=i+24|0,c[I>>2]=450936,c[I+8>>2]=449824,c[I+16>>2]=243216,I)|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=I;aK(12540,501512,(I=i,i=i+24|0,c[I>>2]=448592,c[I+8>>2]=447200,c[I+16>>2]=243216,I)|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=I;ap(930,0);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;return 0;case 174:aE(2318);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ap(84,516528);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;return 0;case 175:H=c[u>>2]|0;aT(8,505392,46,1,H|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;at(620,H|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ap(84,516528);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;return 0;case 176:b1=(N|0)<(d|0);if((a[9533305]&1)==0){j=179;break}else{j=177;break};case 177:if(b1){j=178;break}else{j=182;break};case 178:H=c[u>>2]|0;aT(8,504376,71,1,H|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;at(620,H|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ap(84,516528);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;return 0;case 179:if(b1){j=180;break}else{j=181;break};case 180:ap(1418,c[e+(N<<2)>>2]|0);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=182;break;case 181:a[9533304]=1;j=182;break;case 182:if((a[9395600]&1)==0){j=189;break}else{j=183;break};case 183:H=aK(2522,9416090,z|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((H|0)<0){j=189;break}else{j=184;break};case 184:if((c[z+12>>2]&61440|0)==16384){b2=4096;b3=9444762;b4=9416090;j=185;break}else{j=189;break};case 185:b5=b2-1|0;if((b5|0)==0){j=187;break}else{j=186;break};case 186:H=a[b4]|0;a[b3]=H;if(H<<24>>24==0){j=189;break}else{b2=b5;b3=b3+1|0;b4=b4+1|0;j=185;break};case 187:a[b3]=0;if((a[b4]|0)==0){j=189;break}else{b6=b4;j=188;break};case 188:H=b6+1|0;if((a[H]|0)==0){j=189;break}else{b6=H;j=188;break};case 189:if((a[9395601]&1)==0){j=196;break}else{j=190;break};case 190:H=aK(2522,9436570,w|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((H|0)<0){j=196;break}else{j=191;break};case 191:if((c[w+12>>2]&61440|0)==16384){b7=4096;b8=9448858;b9=9436570;j=192;break}else{j=196;break};case 192:ca=b7-1|0;if((ca|0)==0){j=194;break}else{j=193;break};case 193:H=a[b9]|0;a[b8]=H;if(H<<24>>24==0){j=196;break}else{b7=ca;b8=b8+1|0;b9=b9+1|0;j=192;break};case 194:a[b8]=0;if((a[b9]|0)==0){j=196;break}else{cb=b9;j=195;break};case 195:H=cb+1|0;if((a[H]|0)==0){j=196;break}else{cb=H;j=195;break};case 196:if((a[9375104]&1)==0){j=199;break}else{j=197;break};case 197:cc=c[u>>2]|0;aT(8,265480,49,1,cc|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;at(620,cc|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;aT(8,572264,11,1,cc|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;az(6140,cc|0,569712,(I=i,i=i+16|0,c[I>>2]=568240,c[I+8>>2]=32,I)|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=I;az(6140,cc|0,565840,(I=i,i=i+8|0,c[I>>2]=563680,I)|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=I;if((a[9375104]&1)==0){j=199;break}else{j=198;break};case 198:aT(8,256688,50,1,cc|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;at(620,cc|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=199;break;case 199:if((a[9532036]&1)==0){j=200;break}else{j=268;break};case 200:a[9263480]=103;a[9263481]=108;a[9263482]=0;a[9280032]=114;a[9280033]=119;a[9280034]=101;a[9280035]=98;a[9280036]=97;a[9280037]=117;a[9280038]=100;a[9280039]=105;a[9280040]=111;a[9280041]=0;a[9288320]=114;a[9288321]=119;a[9288322]=101;a[9288323]=98;a[9288324]=105;a[9288325]=110;a[9288326]=112;a[9288327]=117;a[9288328]=116;a[9288329]=0;g[2315886]=3.0;g[2315887]=3.0;a[9263552]=a[9375107]&1;a[9263553]=1;c[2315889]=0;c[2315890]=0;c[2315891]=0;a[9280024]=0;a[9263568]=1;a[9263569]=0;c[2315894]=0;a[9263570]=0;c[2315893]=1;a[9271800]=0;a[9263580]=1;a[9263581]=1;a[9263589]=0;a[9263582]=1;g[2315896]=-1.0;a[9263588]=0;c[2315898]=4;a[9267696]=0;a[9280028]=1;a[928e4]=1;g[2319999]=48.0;a[9280001]=1;g[2320001]=.05000000074505806;g[2320002]=.05000000074505806;g[2320003]=1.0;g[2320004]=1.0;g[2320005]=0.0;g[2317949]=59.95000076293945;a[9280025]=0;a[9280026]=0;a[9280027]=1;c[2315899]=0;a[9280064]=1;c[2320017]=48e3;c[2320018]=0;g[2320019]=48.0e3;c[2321044]=64;a[9284180]=1;a[9288277]=1;g[2322070]=.004999999888241291;g[2322071]=0.0;a[9365828]=0;c[2341458]=20971520;c[2341459]=1;g[2341460]=3.0;g[2341461]=-1.0;a[9365848]=0;gGz(9365852,0,7);a[9365859]=1;a[9365860]=0;b[4682931]=-10181;a[9365864]=0;c[2335312]=100;a[9374057]=1;gGC(9288384,4480,2240)|0;gGC(9290624,3480,1e3)|0;gGC(9292864,3480,1e3)|0;gGC(9295104,3480,1e3)|0;gGC(9297344,3480,1e3)|0;gGC(9299584,3480,1e3)|0;gGC(9301824,3480,1e3)|0;gGC(9304064,3480,1e3)|0;cd=0;j=201;break;case 201:H=9306320+(cd*40|0)|0;c[H>>2]=65535;c[H+4>>2]=0;c[9306336+(cd*40|0)>>2]=-1;H=cd+1|0;if(H>>>0<56){cd=H;j=201;break}else{ce=0;j=247;break};case 202:if((a[9288384+(cf*40|0)|0]&1)==0){j=205;break}else{j=203;break};case 203:if((cf|0)==(c[9288388+(cf*40|0)>>2]|0)){j=205;break}else{j=204;break};case 204:H=c[u>>2]|0;az(6140,H|0,547632,(I=i,i=i+16|0,c[I>>2]=237800,c[I+8>>2]=256,I)|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=I;at(620,H|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ap(930,2);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;return 0;case 205:H=cf+1|0;if(H>>>0<56){cf=H;j=202;break}else{cg=0;j=225;break};case 206:c[2331058]=1;j=207;break;case 207:c[2331068]=1;if((a[9395603]&1)==0){j=211;break}else{j=212;break};case 208:a[9444762]=0;j=209;break;case 209:if((a[9395601]&1)==0){j=210;break}else{j=255;break};case 210:a[9448858]=0;j=255;break;case 211:c[2331059]=1;j=212;break;case 212:c[2331069]=2;if((a[9395604]&1)==0){j=213;break}else{j=214;break};case 213:c[2331060]=1;j=214;break;case 214:c[2331070]=3;if((a[9395605]&1)==0){j=215;break}else{j=216;break};case 215:c[2331061]=1;j=216;break;case 216:c[2331071]=4;if((a[9395606]&1)==0){j=217;break}else{j=218;break};case 217:c[2331062]=1;j=218;break;case 218:c[2331072]=5;if((a[9395607]&1)==0){j=219;break}else{j=220;break};case 219:c[2331063]=1;j=220;break;case 220:c[2331073]=6;if((a[9395608]&1)==0){j=221;break}else{j=222;break};case 221:c[2331064]=1;j=222;break;case 222:c[2331074]=7;if((a[9395609]&1)==0){j=223;break}else{j=224;break};case 223:c[2331065]=1;j=224;break;case 224:gGz(9532068,0,16);if((a[9395600]&1)==0){j=208;break}else{j=209;break};case 225:if((a[9290624+(cg*40|0)|0]&1)==0){j=227;break}else{j=226;break};case 226:if((cg|0)==(c[9290628+(cg*40|0)>>2]|0)){j=227;break}else{j=204;break};case 227:H=cg+1|0;if(H>>>0<56){cg=H;j=225;break}else{ch=0;j=228;break};case 228:if((a[9292864+(ch*40|0)|0]&1)==0){j=230;break}else{j=229;break};case 229:if((ch|0)==(c[9292868+(ch*40|0)>>2]|0)){j=230;break}else{j=204;break};case 230:H=ch+1|0;if(H>>>0<56){ch=H;j=228;break}else{ci=0;j=231;break};case 231:if((a[9295104+(ci*40|0)|0]&1)==0){j=233;break}else{j=232;break};case 232:if((ci|0)==(c[9295108+(ci*40|0)>>2]|0)){j=233;break}else{j=204;break};case 233:H=ci+1|0;if(H>>>0<56){ci=H;j=231;break}else{cj=0;j=234;break};case 234:if((a[9297344+(cj*40|0)|0]&1)==0){j=236;break}else{j=235;break};case 235:if((cj|0)==(c[9297348+(cj*40|0)>>2]|0)){j=236;break}else{j=204;break};case 236:H=cj+1|0;if(H>>>0<56){cj=H;j=234;break}else{ck=0;j=237;break};case 237:if((a[9299584+(ck*40|0)|0]&1)==0){j=239;break}else{j=238;break};case 238:if((ck|0)==(c[9299588+(ck*40|0)>>2]|0)){j=239;break}else{j=204;break};case 239:H=ck+1|0;if(H>>>0<56){ck=H;j=237;break}else{cl=0;j=240;break};case 240:if((a[9301824+(cl*40|0)|0]&1)==0){j=242;break}else{j=241;break};case 241:if((cl|0)==(c[9301828+(cl*40|0)>>2]|0)){j=242;break}else{j=204;break};case 242:H=cl+1|0;if(H>>>0<56){cl=H;j=240;break}else{cm=0;j=243;break};case 243:if((a[9304064+(cm*40|0)|0]&1)==0){j=245;break}else{j=244;break};case 244:if((cm|0)==(c[9304068+(cm*40|0)>>2]|0)){j=245;break}else{j=204;break};case 245:H=cm+1|0;if(H>>>0<56){cm=H;j=243;break}else{j=246;break};case 246:g[2331066]=.5;a[9324846]=1;c[2331212]=6;c[2331213]=3;g[2332238]=1.0;g[2332239]=1.0;a[9324844]=0;a[9324845]=1;c[2331067]=0;if((a[9395602]&1)==0){j=206;break}else{j=207;break};case 247:H=9308560+(ce*40|0)|0;c[H>>2]=65535;c[H+4>>2]=0;c[9308576+(ce*40|0)>>2]=-1;H=ce+1|0;if(H>>>0<56){ce=H;j=247;break}else{cn=0;j=248;break};case 248:H=9310800+(cn*40|0)|0;c[H>>2]=65535;c[H+4>>2]=0;c[9310816+(cn*40|0)>>2]=-1;H=cn+1|0;if(H>>>0<56){cn=H;j=248;break}else{co=0;j=249;break};case 249:H=9313040+(co*40|0)|0;c[H>>2]=65535;c[H+4>>2]=0;c[9313056+(co*40|0)>>2]=-1;H=co+1|0;if(H>>>0<56){co=H;j=249;break}else{cp=0;j=250;break};case 250:H=9315280+(cp*40|0)|0;c[H>>2]=65535;c[H+4>>2]=0;c[9315296+(cp*40|0)>>2]=-1;H=cp+1|0;if(H>>>0<56){cp=H;j=250;break}else{cq=0;j=251;break};case 251:H=9317520+(cq*40|0)|0;c[H>>2]=65535;c[H+4>>2]=0;c[9317536+(cq*40|0)>>2]=-1;H=cq+1|0;if(H>>>0<56){cq=H;j=251;break}else{cr=0;j=252;break};case 252:H=9319760+(cr*40|0)|0;c[H>>2]=65535;c[H+4>>2]=0;c[9319776+(cr*40|0)>>2]=-1;H=cr+1|0;if(H>>>0<56){cr=H;j=252;break}else{cs=0;j=253;break};case 253:H=9322e3+(cs*40|0)|0;c[H>>2]=65535;c[H+4>>2]=0;c[9322016+(cs*40|0)>>2]=-1;H=cs+1|0;if(H>>>0<56){cs=H;j=253;break}else{j=254;break};case 254:H=9324224;c[H>>2]=0;c[H+4>>2]=0;cf=0;j=202;break;case 255:a[9345348]=0;a[9333056]=0;a[9337152]=0;a[9349444]=0;a[9353540]=0;a[9357636]=0;a[9361732]=0;a[9328960]=0;a[9324856]=0;a[9365865]=0;a[9369961]=0;a[9532118]=0;a[9532036]=1;aE(9688);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ct=(a[9375104]&1)!=0;if((a[9395610]|0)==0){j=259;break}else{j=256;break};case 256:if(ct){j=257;break}else{j=258;break};case 257:H=c[u>>2]|0;az(6140,H|0,512336,(I=i,i=i+8|0,c[I>>2]=9395610,I)|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=I;at(620,H|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=258;break;case 258:H=at(100,9395610)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if(H){j=268;break}else{j=265;break};case 259:if(ct){j=260;break}else{j=261;break};case 260:H=c[u>>2]|0;aT(8,511064,35,1,H|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;at(620,H|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=261;break;case 261:cu=at(100,0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((a[9395610]|0)==0){j=264;break}else{j=262;break};case 262:if((a[9375104]&1)==0){j=264;break}else{j=263;break};case 263:H=c[u>>2]|0;az(6140,H|0,509152,(I=i,i=i+8|0,c[I>>2]=9395610,I)|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=I;at(620,H|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if(cu){j=268;break}else{j=265;break};case 264:if(cu){j=268;break}else{j=265;break};case 265:cv=c[u>>2]|0;az(6140,cv|0,507400,(I=i,i=i+8|0,c[I>>2]=9395610,I)|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=I;at(620,cv|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((a[9532117]&1)==0){j=266;break}else{j=267;break};case 266:az(6140,cv|0,547632,(I=i,i=i+16|0,c[I>>2]=504696,c[I+8>>2]=729,I)|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=I;at(620,cv|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ap(930,2);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;return 0;case 267:a[9532119]=112;a[9532120]=97;a[9532121]=114;a[9532122]=115;a[9532123]=101;a[9532124]=95;a[9532125]=99;a[9532126]=111;a[9532127]=110;a[9532128]=102;a[9532129]=105;a[9532130]=103;a[9532131]=95;a[9532132]=102;a[9532133]=105;a[9532134]=108;a[9532135]=101;a[9532136]=40;a[9532137]=41;a[9532138]=0;aq(1238,9533144,1);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;return 0;case 268:H=(a[9533305]&1)!=0;X=H?796:778;c[2112856]=H?7728:10390;c[2112868]=H?4396:11812;c[2112874]=H?1074:3694;c[2112858]=H?132:1286;c[2112860]=H?52:1018;c[2112836]=X;c[2112830]=H?1004:22;c[2112842]=H?360:36;c[2112840]=H?962:678;c[2112834]=H?1462:1012;c[2112832]=H?1164:430;c[2112838]=H?406:770;c[2112850]=H?11044:10754;c[2112848]=H?5454:6564;c[2112844]=H?362:2698;c[2112846]=H?1112:720;c[2112826]=H?11952:15404;c[2112872]=H?2706:10314;c[2112870]=H?36:98;c[2112854]=H?3418:2970;c[2112852]=H?5548:6746;c[2112828]=H?7112:10280;c[2112862]=H?140:1584;c[2112866]=H?584:1098;c[2112864]=H?418:3264;ap(X|0,9710);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ap(c[2112858]|0,9469368);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;X=c[2367342]|0;if((X|0)==0){j=269;break}else{cw=X;j=270;break};case 269:c[2367342]=505984;cw=505984;j=270;break;case 270:X=c[2367343]|0;if((X|0)==0){j=271;break}else{cx=X;j=272;break};case 271:c[2367343]=292880;cx=292880;j=272;break;case 272:aT(4,9531892,64,286496,(I=i,i=i+16|0,c[I>>2]=cw,c[I+8>>2]=cx,I)|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=I;X=c[2367344]|0;cy=4096;cz=9469960;cA=(X|0)==0?279616:X;j=273;break;case 273:cB=cy-1|0;if((cB|0)==0){j=275;break}else{j=274;break};case 274:X=a[cA]|0;a[cz]=X;if(X<<24>>24==0){j=277;break}else{cy=cB;cz=cz+1|0;cA=cA+1|0;j=273;break};case 275:a[cz]=0;if((a[cA]|0)==0){j=277;break}else{cC=cA;j=276;break};case 276:X=cC+1|0;if((a[X]|0)==0){j=277;break}else{cC=X;j=276;break};case 277:a[9469444]=a[9469381]&1;cD=0;j=278;break;case 278:if(cD>>>0<2){j=279;break}else{j=281;break};case 279:cE=c[64376+(cD<<2)>>2]|0;X=aK(15462,9280032,c[cE+28>>2]|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((X|0)==0){j=280;break}else{cD=cD+1|0;j=278;break};case 280:if((cD|0)>-1){j=288;break}else{j=281;break};case 281:cF=c[u>>2]|0;az(6140,cF|0,245504,(I=i,i=i+8|0,c[I>>2]=9280032,I)|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=I;at(620,cF|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;X=a[9375104]|0;if((X&1)==0){cG=X;j=283;break}else{j=282;break};case 282:aT(8,238960,29,1,cF|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;at(620,cF|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;cG=a[9375104]|0;j=283;break;case 283:if((cG&1)==0){cH=cG;j=285;break}else{j=284;break};case 284:az(6140,cF|0,29e4,(I=i,i=i+8|0,c[I>>2]=558728,I)|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=I;at(620,cF|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;cH=a[9375104]|0;j=285;break;case 285:if((cH&1)==0){j=287;break}else{j=286;break};case 286:az(6140,cF|0,29e4,(I=i,i=i+8|0,c[I>>2]=515776,I)|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=I;at(620,cF|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=287;break;case 287:ap(432,232512);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;return 0;case 288:c[2383354]=cE;aE(2818);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;X=aK(15462,9288320,574664)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((X|0)==0){j=294;break}else{j=289;break};case 289:cI=c[u>>2]|0;az(6140,cI|0,305064,(I=i,i=i+8|0,c[I>>2]=9288320,I)|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=I;at(620,cI|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;X=a[9375104]|0;if((X&1)==0){cJ=X;j=291;break}else{j=290;break};case 290:aT(8,297e3,29,1,cI|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;at(620,cI|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;cJ=a[9375104]|0;j=291;break;case 291:if((cJ&1)==0){j=293;break}else{j=292;break};case 292:az(6140,cI|0,29e4,(I=i,i=i+8|0,c[I>>2]=574664,I)|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=I;at(620,cI|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=293;break;case 293:ap(432,283408);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;return 0;case 294:c[2383356]=46096;X=a[9375104]|0;if((X&1)==0){cK=X;j=296;break}else{j=295;break};case 295:X=c[u>>2]|0;H=aN(c[2112874]|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;az(6140,X|0,575912,(I=i,i=i+8|0,c[I>>2]=H,I)|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=I;at(620,X|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;cK=a[9375104]|0;j=296;break;case 296:if((cK&1)==0){j=298;break}else{j=297;break};case 297:X=c[u>>2]|0;az(6140,X|0,574728,(I=i,i=i+8|0,c[I>>2]=1,I)|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=I;at(620,X|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=298;break;case 298:X=aN(c[2112874]|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((X|0)==1){j=300;break}else{j=299;break};case 299:X=c[u>>2]|0;aT(8,573392,117,1,X|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;at(620,X|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=300;break;case 300:aE(c[2112856]|0);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;cL=(a[9533305]&1)==0;X=a[9533304]&1;a[9531830]=cL?X^1:0;if(X<<24>>24==0){j=303;break}else{j=301;break};case 301:if(cL){j=302;break}else{j=437;break};case 302:X=at(3394,c[2344802]|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if(X){j=437;break}else{j=565;break};case 303:if(cL){j=304;break}else{j=437;break};case 304:aE(2240);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;X=at(3394,c[2344802]|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if(X){j=305;break}else{j=565;break};case 305:cM=B|0;cN=C|0;cO=D|0;if((a[9365857]&1)==0){j=333;break}else{j=306;break};case 306:aq(552,cM|0,9436570);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;X=aK(134,9436570,47)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;cP=4096;cQ=0;cR=cN;cS=(X|0)==0?9436570:X+1|0;j=307;break;case 307:cT=cP-1|0;if((cT|0)==0){j=309;break}else{j=308;break};case 308:X=a[cS]|0;a[cR]=X;if(X<<24>>24==0){cU=cQ;j=311;break}else{cP=cT;cQ=cQ+1|0;cR=cR+1|0;cS=cS+1|0;j=307;break};case 309:a[cR]=0;if((a[cS]|0)==0){cU=cQ;j=311;break}else{cV=cS;cW=cQ;j=310;break};case 310:X=cV+1|0;H=cW+1|0;if((a[X]|0)==0){cU=H;j=311;break}else{cV=X;cW=H;j=310;break};case 311:if(cU>>>0<4096){j=313;break}else{j=312;break};case 312:H=c[u>>2]|0;az(6140,H|0,547632,(I=i,i=i+16|0,c[I>>2]=551256,c[I+8>>2]=579,I)|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=I;at(620,H|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ap(930,2);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;return 0;case 313:cX=az(7640,cM|0,0,0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((cX|0)==0){j=333;break}else{j=314;break};case 314:cY=cX+4|0;cZ=cX|0;if((c[cY>>2]|0)==0){j=315;break}else{c_=0;c$=0;j=316;break};case 315:c0=c[cZ>>2]|0;c1=0;j=331;break;case 316:c2=c[(c[cZ>>2]|0)+(c_<<3)>>2]|0;H=aK(134,c2|0,47)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;c3=4096;c4=0;c5=cO;c6=(H|0)==0?c2:H+1|0;j=317;break;case 317:c7=c3-1|0;if((c7|0)==0){j=319;break}else{j=318;break};case 318:H=a[c6]|0;a[c5]=H;if(H<<24>>24==0){c8=c4;j=321;break}else{c3=c7;c4=c4+1|0;c5=c5+1|0;c6=c6+1|0;j=317;break};case 319:a[c5]=0;if((a[c6]|0)==0){c8=c4;j=321;break}else{c9=c6;da=c4;j=320;break};case 320:H=c9+1|0;X=da+1|0;if((a[H]|0)==0){c8=X;j=321;break}else{c9=H;da=X;j=320;break};case 321:if(c8>>>0<4096){j=323;break}else{j=322;break};case 322:X=c[u>>2]|0;az(6140,X|0,547632,(I=i,i=i+16|0,c[I>>2]=551256,c[I+8>>2]=579,I)|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=I;at(620,X|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ap(930,2);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;return 0;case 323:X=at(2092,cN|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;H=az(10056,cO|0,cN|0,X|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((H|0)==0){j=324;break}else{db=c$;j=328;break};case 324:H=at(2092,c2|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;dc=c2+H|0;j=325;break;case 325:if(dc>>>0>c2>>>0){j=326;break}else{j=327;break};case 326:H=dc-1|0;if(((a[H]|0)-48|0)>>>0<10){dc=H;j=325;break}else{j=327;break};case 327:H=az(3094,dc|0,0,0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;db=H>>>0>c$>>>0?H:c$;j=328;break;case 328:H=c_+1|0;dd=c[cY>>2]|0;if(H>>>0<dd>>>0){c_=H;c$=db;j=316;break}else{j=329;break};case 329:H=c[cZ>>2]|0;if((dd|0)==0){c0=H;c1=db;j=331;break}else{de=0;df=H;j=330;break};case 330:ap(382,c[df+(de<<3)>>2]|0);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;H=de+1|0;X=c[cZ>>2]|0;if(H>>>0<(c[cY>>2]|0)>>>0){de=H;df=X;j=330;break}else{c0=X;c1=db;j=331;break};case 331:ap(382,c0|0);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ap(382,cX|0);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;c[2367336]=c1;if((a[9375104]&1)==0){j=333;break}else{j=332;break};case 332:X=c[u>>2]|0;az(6140,X|0,577072,(I=i,i=i+8|0,c[I>>2]=c1,I)|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=I;at(620,X|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=333;break;case 333:if((a[9531828]&1)==0){j=334;break}else{j=391;break};case 334:switch(c[2344802]|0){case 0:{j=335;break};case 1:{j=349;break};case 2:case 3:{j=363;break};case 4:{j=377;break};default:{j=393;break}}break;case 335:dg=at(c[2112864]|0,0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;dh=at(c[2112866]|0,0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((dg|0)==0|(dh|0)==0){j=342;break}else{j=336;break};case 336:c[v>>2]=0;di=aK(7992,9416090,v|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((di|0)>0){j=338;break}else{j=337;break};case 337:dj=c[v>>2]|0;j=341;break;case 338:if((di|0)>(dg|0)){j=339;break}else{dk=di;j=340;break};case 339:X=c[u>>2]|0;az(6140,X|0,101112,(I=i,i=i+16|0,c[I>>2]=di,c[I+8>>2]=dg,I)|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=I;at(620,X|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;dk=dg;j=340;break;case 340:X=c[v>>2]|0;gGC(dh|0,X|0,dk)|0;dj=X;j=341;break;case 341:ap(382,dj|0);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=342;break;case 342:dl=at(c[2112864]|0,1)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;dm=at(c[2112866]|0,1)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((dl|0)==0|(dm|0)==0){j=393;break}else{j=343;break};case 343:c[t>>2]=0;dn=aK(7992,9420186,t|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((dn|0)>0){j=345;break}else{j=344;break};case 344:dp=c[t>>2]|0;j=348;break;case 345:if((dn|0)>(dl|0)){j=346;break}else{dq=dn;j=347;break};case 346:X=c[u>>2]|0;az(6140,X|0,101112,(I=i,i=i+16|0,c[I>>2]=dn,c[I+8>>2]=dl,I)|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=I;at(620,X|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;dq=dl;j=347;break;case 347:X=c[t>>2]|0;gGC(dm|0,X|0,dq)|0;dp=X;j=348;break;case 348:ap(382,dp|0);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=393;break;case 349:dr=at(c[2112864]|0,1280)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ds=at(c[2112866]|0,1280)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((dr|0)==0|(ds|0)==0){j=356;break}else{j=350;break};case 350:c[s>>2]=0;dt=aK(7992,9416090,s|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((dt|0)>0){j=352;break}else{j=351;break};case 351:du=c[s>>2]|0;j=355;break;case 352:if((dt|0)>(dr|0)){j=353;break}else{dv=dt;j=354;break};case 353:X=c[u>>2]|0;az(6140,X|0,101112,(I=i,i=i+16|0,c[I>>2]=dt,c[I+8>>2]=dr,I)|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=I;at(620,X|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;dv=dr;j=354;break;case 354:X=c[s>>2]|0;gGC(ds|0,X|0,dv)|0;du=X;j=355;break;case 355:ap(382,du|0);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=356;break;case 356:dw=at(c[2112864]|0,1537)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;dx=at(c[2112866]|0,1537)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((dw|0)==0|(dx|0)==0){j=393;break}else{j=357;break};case 357:c[r>>2]=0;dy=aK(7992,9420186,r|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((dy|0)>0){j=359;break}else{j=358;break};case 358:dz=c[r>>2]|0;j=362;break;case 359:if((dy|0)>(dw|0)){j=360;break}else{dA=dy;j=361;break};case 360:X=c[u>>2]|0;az(6140,X|0,101112,(I=i,i=i+16|0,c[I>>2]=dy,c[I+8>>2]=dw,I)|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=I;at(620,X|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;dA=dw;j=361;break;case 361:X=c[r>>2]|0;gGC(dx|0,X|0,dA)|0;dz=X;j=362;break;case 362:ap(382,dz|0);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=393;break;case 363:dB=at(c[2112864]|0,256)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;dC=at(c[2112866]|0,256)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((dB|0)==0|(dC|0)==0){j=370;break}else{j=364;break};case 364:c[q>>2]=0;dD=aK(7992,9416090,q|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((dD|0)>0){j=366;break}else{j=365;break};case 365:dE=c[q>>2]|0;j=369;break;case 366:if((dD|0)>(dB|0)){j=367;break}else{dF=dD;j=368;break};case 367:X=c[u>>2]|0;az(6140,X|0,101112,(I=i,i=i+16|0,c[I>>2]=dD,c[I+8>>2]=dB,I)|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=I;at(620,X|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;dF=dB;j=368;break;case 368:X=c[q>>2]|0;gGC(dC|0,X|0,dF)|0;dE=X;j=369;break;case 369:ap(382,dE|0);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=370;break;case 370:dG=at(c[2112864]|0,512)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;dH=at(c[2112866]|0,512)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((dG|0)==0|(dH|0)==0){j=393;break}else{j=371;break};case 371:c[p>>2]=0;dI=aK(7992,9424282,p|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((dI|0)>0){j=373;break}else{j=372;break};case 372:dJ=c[p>>2]|0;j=376;break;case 373:if((dI|0)>(dG|0)){j=374;break}else{dK=dI;j=375;break};case 374:X=c[u>>2]|0;az(6140,X|0,101112,(I=i,i=i+16|0,c[I>>2]=dI,c[I+8>>2]=dG,I)|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=I;at(620,X|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;dK=dG;j=375;break;case 375:X=c[p>>2]|0;gGC(dH|0,X|0,dK)|0;dJ=X;j=376;break;case 376:ap(382,dJ|0);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=393;break;case 377:dL=at(c[2112864]|0,768)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;dM=at(c[2112866]|0,768)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((dL|0)==0|(dM|0)==0){j=384;break}else{j=378;break};case 378:c[o>>2]=0;dN=aK(7992,9428378,o|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((dN|0)>0){j=380;break}else{j=379;break};case 379:dO=c[o>>2]|0;j=383;break;case 380:if((dN|0)>(dL|0)){j=381;break}else{dP=dN;j=382;break};case 381:X=c[u>>2]|0;az(6140,X|0,101112,(I=i,i=i+16|0,c[I>>2]=dN,c[I+8>>2]=dL,I)|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=I;at(620,X|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;dP=dL;j=382;break;case 382:X=c[o>>2]|0;gGC(dM|0,X|0,dP)|0;dO=X;j=383;break;case 383:ap(382,dO|0);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=384;break;case 384:dQ=at(c[2112864]|0,1024)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;dR=at(c[2112866]|0,1024)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((dQ|0)==0|(dR|0)==0){j=393;break}else{j=385;break};case 385:c[n>>2]=0;dS=aK(7992,9432474,n|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((dS|0)>0){j=387;break}else{j=386;break};case 386:dT=c[n>>2]|0;j=390;break;case 387:if((dS|0)>(dQ|0)){j=388;break}else{dU=dS;j=389;break};case 388:X=c[u>>2]|0;az(6140,X|0,101112,(I=i,i=i+16|0,c[I>>2]=dS,c[I+8>>2]=dQ,I)|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=I;at(620,X|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;dU=dQ;j=389;break;case 389:X=c[n>>2]|0;gGC(dR|0,X|0,dU)|0;dT=X;j=390;break;case 390:ap(382,dT|0);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=393;break;case 391:if((a[9375104]&1)==0){j=393;break}else{j=392;break};case 392:X=c[u>>2]|0;aT(8,248640,31,1,X|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;at(620,X|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=393;break;case 393:if((a[9365859]&1)==0){j=406;break}else{j=394;break};case 394:aQ(4,cM|0,9436570,183464);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;dV=aK(8240,cM|0,364392)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((dV|0)==0){j=406;break}else{j=395;break};case 395:at(1814,dV|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((a[9375104]&1)==0){j=397;break}else{j=396;break};case 396:X=c[u>>2]|0;az(6140,X|0,580648,(I=i,i=i+8|0,c[I>>2]=cM,I)|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=I;at(620,X|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=397;break;case 397:X=at(1992,cM|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;aT(4,cN|0,4096,578400,(I=i,i=i+16|0,c[I>>2]=cM,c[I+8>>2]=X?175160:171344,I)|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=I;dW=c[2380901]|0;dX=dW+4|0;if((c[dX>>2]|0)>>>0<(c[dW+8>>2]|0)>>>0){j=398;break}else{j=404;break};case 398:dY=at(1570,12)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((dY|0)==0){j=401;break}else{j=399;break};case 399:if((c[dY-4>>2]&3|0)==0){j=401;break}else{j=400;break};case 400:gGz(dY|0,0,12);j=401;break;case 401:X=dY;c[dY+4>>2]=1;c[dY>>2]=180;H=at(2466,cN|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;dZ=c[dX>>2]|0;c[dY+8>>2]=H;d_=dW|0;c[(c[d_>>2]|0)+(dZ<<2)>>2]=X;X=c[dX>>2]|0;c[dX>>2]=X+1;if(X>>>0>1){d$=X;j=402;break}else{j=404;break};case 402:d0=d$>>>1;X=c[d_>>2]|0;d1=X+(d0<<2)|0;d2=c[d1>>2]|0;d3=c[X+(d$<<2)>>2]|0;if((c[d3+4>>2]|0)>>>0>(c[d2+4>>2]|0)>>>0){j=403;break}else{j=404;break};case 403:c[d1>>2]=d3;c[(c[d_>>2]|0)+(d$<<2)>>2]=d2;if(d$>>>0>3){d$=d0;j=402;break}else{j=404;break};case 404:if((a[9375104]&1)==0){j=406;break}else{j=405;break};case 405:X=c[u>>2]|0;az(6140,X|0,324680,(I=i,i=i+8|0,c[I>>2]=cN,I)|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=I;at(620,X|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=406;break;case 406:if((a[9531826]&1)==0){j=419;break}else{j=407;break};case 407:X=aK(5526,9527729,0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;c[2380907]=X;if((X|0)==0){j=408;break}else{j=409;break};case 408:X=c[u>>2]|0;az(6140,X|0,589736,(I=i,i=i+8|0,c[I>>2]=9527729,I)|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=I;at(620,X|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ap(84,588528);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;return 0;case 409:a[9527728]=1;d4=c[2380901]|0;d5=d4+4|0;if((c[d5>>2]|0)>>>0<(c[d4+8>>2]|0)>>>0){j=410;break}else{j=416;break};case 410:d6=at(1570,12)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((d6|0)==0){j=413;break}else{j=411;break};case 411:if((c[d6-4>>2]&3|0)==0){j=413;break}else{j=412;break};case 412:gGz(d6|0,0,12);j=413;break;case 413:X=d6;c[d6+4>>2]=2;c[d6>>2]=180;dZ=at(2466,586384)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;H=c[d5>>2]|0;c[d6+8>>2]=dZ;d7=d4|0;c[(c[d7>>2]|0)+(H<<2)>>2]=X;X=c[d5>>2]|0;c[d5>>2]=X+1;if(X>>>0>1){d8=X;j=414;break}else{j=416;break};case 414:d9=d8>>>1;X=c[d7>>2]|0;ea=X+(d9<<2)|0;eb=c[ea>>2]|0;ec=c[X+(d8<<2)>>2]|0;if((c[ec+4>>2]|0)>>>0>(c[eb+4>>2]|0)>>>0){j=415;break}else{j=416;break};case 415:c[ea>>2]=ec;c[(c[d7>>2]|0)+(d8<<2)>>2]=eb;if(d8>>>0>3){d8=d9;j=414;break}else{j=416;break};case 416:if((a[9375104]&1)==0){j=418;break}else{j=417;break};case 417:X=c[u>>2]|0;aT(8,584640,36,1,X|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;at(620,X|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=418;break;case 418:c[2341459]=1;j=437;break;case 419:if((a[9531825]&1)==0){j=437;break}else{j=420;break};case 420:aT(4,cM|0,4096,107872,(I=i,i=i+8|0,c[I>>2]=9527729,I)|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=I;X=aK(5526,9527729,1)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;c[2380907]=X;ed=c[2380901]|0;ee=ed+4|0;ef=c[ee>>2]|0;if(ef>>>0>1){j=421;break}else{j=425;break};case 421:eg=ed|0;eh=1;ei=ef;j=422;break;case 422:ej=c[(c[eg>>2]|0)+(eh<<2)>>2]|0;if((ej|0)==0){ek=ei;j=424;break}else{j=423;break};case 423:ap(382,c[ej+8>>2]|0);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ap(382,c[(c[eg>>2]|0)+(eh<<2)>>2]|0);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;c[(c[eg>>2]|0)+(eh<<2)>>2]=0;ek=c[ee>>2]|0;j=424;break;case 424:X=eh+1|0;if(X>>>0<ek>>>0){eh=X;ei=ek;j=422;break}else{j=425;break};case 425:c[ee>>2]=1;X=ed+12|0;ap(382,c[X>>2]|0);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;c[X>>2]=0;el=c[2380901]|0;em=el+4|0;if((c[em>>2]|0)>>>0<(c[el+8>>2]|0)>>>0){j=426;break}else{j=432;break};case 426:en=(c[2380907]|0)!=0?cM:106176;eo=at(1570,12)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((eo|0)==0){j=429;break}else{j=427;break};case 427:if((c[eo-4>>2]&3|0)==0){j=429;break}else{j=428;break};case 428:gGz(eo|0,0,12);j=429;break;case 429:X=eo;c[eo+4>>2]=1;c[eo>>2]=180;H=at(2466,en|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;dZ=c[em>>2]|0;c[eo+8>>2]=H;ep=el|0;c[(c[ep>>2]|0)+(dZ<<2)>>2]=X;X=c[em>>2]|0;c[em>>2]=X+1;if(X>>>0>1){eq=X;j=430;break}else{j=432;break};case 430:er=eq>>>1;X=c[ep>>2]|0;es=X+(er<<2)|0;et=c[es>>2]|0;eu=c[X+(eq<<2)>>2]|0;if((c[eu+4>>2]|0)>>>0>(c[et+4>>2]|0)>>>0){j=431;break}else{j=432;break};case 431:c[es>>2]=eu;c[(c[ep>>2]|0)+(eq<<2)>>2]=et;if(eq>>>0>3){eq=er;j=430;break}else{j=432;break};case 432:if((c[2380907]|0)==0){j=436;break}else{j=433;break};case 433:if((a[9375104]&1)==0){j=435;break}else{j=434;break};case 434:X=c[u>>2]|0;az(6140,X|0,103024,(I=i,i=i+8|0,c[I>>2]=9527729,I)|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=I;at(620,X|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=435;break;case 435:c[2341459]=1;j=437;break;case 436:X=c[u>>2]|0;aT(8,100280,51,1,X|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;at(620,X|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=437;break;case 437:ap(c[2112830]|0,44);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ap(c[2112842]|0,1792);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ap(c[2112840]|0,15108);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ap(c[2112832]|0,26);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ap(c[2112834]|0,1022);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ap(c[2112860]|0,9469384);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;X=aK(7764,1,A|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((X|0)<0){ev=0;ew=0;j=439;break}else{j=438;break};case 438:X=c[A>>2]|0;dZ=gGU(X,(X|0)<0|0?-1:0,1e6,0)|0;X=((c[A+4>>2]|0)+500|0)/1e3|0;H=gGK(X,(X|0)<0|0?-1:0,dZ,K)|0;ev=K;ew=H;j=439;break;case 439:H=9469360;c[H>>2]=ew;c[H+4>>2]=ev;ex=+aH(2,+(1.0e6/(+h[1183676]*+g[2341461])));if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;H=+V(ex)>=1.0?ex>0.0?(al(+U(ex/4294967296.0),4294967295.0)|0)>>>0:~~+af((ex- +(~~ex>>>0))/4294967296.0)>>>0:0;dZ=9469352;c[dZ>>2]=~~ex>>>0;c[dZ+4>>2]=H;aE(3956);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;aE(9984);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;aE(8074);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((a[9531830]&1)==0){j=440;break}else{j=441;break};case 440:a[9531830]=0;j=442;break;case 441:H=a[9531829]&1;a[9531830]=H^1;if(H<<24>>24==0){j=444;break}else{j=442;break};case 442:if((a[9375104]&1)==0){j=444;break}else{j=443;break};case 443:H=c[u>>2]|0;aT(8,241648,35,1,H|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;at(620,H|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=444;break;case 444:if((c[2380907]|0)!=0|(a[9349444]|0)==0){j=564;break}else{j=445;break};case 445:aE(c[2112872]|0);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ey=at(1570,16)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((ey|0)==0){ez=0;j=563;break}else{j=446;break};case 446:if((c[ey-4>>2]&3|0)==0){j=448;break}else{j=447;break};case 447:gGz(ey|0,0,16);j=448;break;case 448:eA=ey;eB=ey+12|0;c[eB>>2]=1;eC=at(1570,12)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((eC|0)==0){j=452;break}else{j=449;break};case 449:if((c[eC-4>>2]&3|0)==0){j=450;break}else{j=451;break};case 450:H=ey;c[H>>2]=eC;eD=H;j=453;break;case 451:gGz(eC|0,0,12);H=ey;c[H>>2]=eC;eD=H;j=453;break;case 452:c[ey>>2]=0;c[eB>>2]=0;j=556;break;case 453:eE=at(1590,9349444)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((eE|0)==0){j=454;break}else{j=455;break};case 454:H=c[u>>2]|0;az(6140,H|0,204536,(I=i,i=i+8|0,c[I>>2]=9349444,I)|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=I;at(620,H|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=556;break;case 455:eF=eE|0;H=c[eF>>2]|0;if((H|0)==0){j=456;break}else{eG=H;j=457;break};case 456:ap(554,eA|0);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=558;break;case 457:if((c[eG+20>>2]|0)==0){j=458;break}else{j=459;break};case 458:H=aK(13206,c[eG>>2]|0,571248)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((H|0)==0){j=460;break}else{j=459;break};case 459:H=c[eG+16>>2]|0;if((H|0)==0){j=557;break}else{eG=H;j=457;break};case 460:eH=c[eG+12>>2]|0;if((eH|0)==0){j=557;break}else{j=461;break};case 461:if((a[9531964]|0)==0){eI=eH;j=462;break}else{eJ=eH;j=468;break};case 462:if((c[eI+20>>2]|0)==0){j=463;break}else{j=467;break};case 463:H=aK(13206,c[eI>>2]|0,441912)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((H|0)==0){j=464;break}else{j=467;break};case 464:eK=eI+8|0;j=465;break;case 465:eL=c[eK>>2]|0;if((eL|0)==0){j=467;break}else{j=466;break};case 466:H=aK(13206,341512,c[eL>>2]|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((H|0)==0){j=467;break}else{eK=eL+8|0;j=465;break};case 467:H=c[eI+16>>2]|0;if((H|0)==0){j=557;break}else{eI=H;j=462;break};case 468:if((c[eJ+20>>2]|0)==0){j=469;break}else{j=475;break};case 469:H=aK(13206,c[eJ>>2]|0,441912)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((H|0)==0){j=470;break}else{j=475;break};case 470:eM=eJ+8|0;j=471;break;case 471:eN=c[eM>>2]|0;if((eN|0)==0){j=475;break}else{j=472;break};case 472:H=aK(13206,341512,c[eN>>2]|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((H|0)==0){j=473;break}else{eM=eN+8|0;j=471;break};case 473:eO=c[eN+4>>2]|0;if((eO|0)==0){j=475;break}else{j=474;break};case 474:H=aK(13206,eO|0,9531964)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((H|0)==0){j=476;break}else{j=475;break};case 475:H=c[eJ+16>>2]|0;if((H|0)==0){j=557;break}else{eJ=H;j=468;break};case 476:eP=c[eJ+12>>2]|0;if((eP|0)==0){j=477;break}else{j=478;break};case 477:eQ=ey+8|0;j=537;break;case 478:eR=c[u>>2]|0;eS=ey+8|0;eT=eP;j=479;break;case 479:eU=c[eT>>2]|0;H=aK(13206,eU|0,527272)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((H|0)==0){j=480;break}else{j=483;break};case 480:eV=c[eT+4>>2]|0;if((eV|0)==0){j=535;break}else{j=481;break};case 481:if((a[9375104]&1)==0){j=535;break}else{j=482;break};case 482:az(6140,eR|0,513416,(I=i,i=i+8|0,c[I>>2]=eV,I)|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=I;at(620,eR|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=535;break;case 483:H=aK(13206,eU|0,500328)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((H|0)==0){j=484;break}else{j=535;break};case 484:eW=c[eS>>2]|0;if((eW|0)==(c[eB>>2]|0)){j=486;break}else{j=485;break};case 485:eX=eW;eY=c[eD>>2]|0;j=488;break;case 486:c[eB>>2]=eW<<1;H=aK(1732,c[eD>>2]|0,eW*24|0|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;eZ=H;c[eD>>2]=eZ;if((H|0)==0){j=536;break}else{j=487;break};case 487:eX=c[eS>>2]|0;eY=eZ;j=488;break;case 488:e_=eY+(eX*12|0)|0;e$=c[eT+12>>2]|0;if((e$|0)==0){j=535;break}else{j=489;break};case 489:gGz(e_|0,0,12);e0=e_|0;e1=eY+(eX*12|0)+8|0;e2=e$;e3=1;e4=0;e5=0;j=490;break;case 490:e6=c[e2>>2]|0;H=aK(13206,e6|0,488880)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((H|0)==0){j=491;break}else{j=492;break};case 491:c[e0>>2]=c[e2+4>>2];e7=e3;e8=e4;e9=e5;j=533;break;case 492:H=aK(13206,e6|0,475632)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((H|0)==0){j=493;break}else{e7=e3;e8=e4;e9=e5;j=533;break};case 493:if(e3){fa=e4;j=512;break}else{j=494;break};case 494:fb=(e5|0)!=0;if(fb){j=495;break}else{fc=2;j=496;break};case 495:H=at(2092,e5|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;fc=H+2|0;j=496;break;case 496:fd=aK(1732,e5|0,fc|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((fd|0)==0){j=497;break}else{j=498;break};case 497:c[e1>>2]=0;j=535;break;case 498:if(fb){j=499;break}else{j=506;break};case 499:fe=at(2092,fd|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ff=fe>>>0>fc>>>0?0:fc-fe|0;if((ff|0)==0){fg=183016;j=503;break}else{j=500;break};case 500:fh=fd+fe|0;if((ff|0)==1){fi=183016;fj=fh;j=502;break}else{j=501;break};case 501:fk=fd+(fe+1)|0;a[fh]=43;if((ff|0)==2){fi=183017;fj=fk;j=502;break}else{j=562;break};case 502:a[fj]=0;fg=fi;j=503;break;case 503:if((a[fg]|0)==0){j=505;break}else{fl=fg;j=504;break};case 504:H=fl+1|0;if((a[H]|0)==0){j=505;break}else{fl=H;j=504;break};case 505:c[e1>>2]=fd;fa=fd;j=512;break;case 506:if((fc|0)==1){fm=183016;fn=fd;j=508;break}else if((fc|0)==0){fo=183016;j=509;break}else{j=507;break};case 507:fp=fd+1|0;a[fd]=43;if((fc|0)==2){fm=183017;fn=fp;j=508;break}else{j=561;break};case 508:a[fn]=0;fo=fm;j=509;break;case 509:if((a[fo]|0)==0){j=511;break}else{fq=fo;j=510;break};case 510:H=fq+1|0;if((a[H]|0)==0){j=511;break}else{fq=H;j=510;break};case 511:c[e1>>2]=fd;fa=fd;j=512;break;case 512:fr=c[e2+4>>2]|0;if((fr|0)==0){j=535;break}else{j=513;break};case 513:fs=(fa|0)!=0;if(fs){j=514;break}else{ft=1;j=515;break};case 514:H=at(2092,fa|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ft=H+1|0;j=515;break;case 515:H=at(2092,fr|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;fu=H+ft|0;fv=aK(1732,fa|0,fu|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((fv|0)==0){j=516;break}else{j=517;break};case 516:c[e1>>2]=0;j=535;break;case 517:if(fs){j=518;break}else{j=526;break};case 518:fw=at(2092,fv|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;fx=fw>>>0>fu>>>0?0:fu-fw|0;if((fx|0)==0){fy=fr;j=523;break}else{j=519;break};case 519:fz=fx;fA=fv+fw|0;fB=fr;j=520;break;case 520:fC=fz-1|0;if((fC|0)==0){j=522;break}else{j=521;break};case 521:H=a[fB]|0;a[fA]=H;if(H<<24>>24==0){j=525;break}else{fz=fC;fA=fA+1|0;fB=fB+1|0;j=520;break};case 522:a[fA]=0;fy=fB;j=523;break;case 523:if((a[fy]|0)==0){j=525;break}else{fD=fy;j=524;break};case 524:H=fD+1|0;if((a[H]|0)==0){j=525;break}else{fD=H;j=524;break};case 525:c[e1>>2]=fv;e7=0;e8=fv;e9=fv;j=533;break;case 526:if((fu|0)==0){fE=fr;j=530;break}else{fF=fu;fG=fv;fH=fr;j=527;break};case 527:fI=fF-1|0;if((fI|0)==0){j=529;break}else{j=528;break};case 528:H=a[fH]|0;a[fG]=H;if(H<<24>>24==0){j=532;break}else{fF=fI;fG=fG+1|0;fH=fH+1|0;j=527;break};case 529:a[fG]=0;fE=fH;j=530;break;case 530:if((a[fE]|0)==0){j=532;break}else{fJ=fE;j=531;break};case 531:H=fJ+1|0;if((a[H]|0)==0){j=532;break}else{fJ=H;j=531;break};case 532:c[e1>>2]=fv;e7=0;e8=fv;e9=fv;j=533;break;case 533:H=c[e2+16>>2]|0;if((H|0)==0){j=534;break}else{e2=H;e3=e7;e4=e8;e5=e9;j=490;break};case 534:c[eS>>2]=(c[eS>>2]|0)+1;j=535;break;case 535:H=c[eT+16>>2]|0;if((H|0)==0){eQ=eS;j=537;break}else{eT=H;j=479;break};case 536:aT(8,264128,68,1,eR|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;at(620,eR|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=557;break;case 537:if((c[eQ>>2]|0)==0){j=538;break}else{j=539;break};case 538:H=c[u>>2]|0;az(6140,H|0,205952,(I=i,i=i+8|0,c[I>>2]=9349444,I)|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;i=I;at(620,H|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=557;break;case 539:if((a[9353540]|0)==0){j=553;break}else{j=540;break};case 540:fK=aK(15768,9353540,0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((fK|0)==0){j=553;break}else{j=541;break};case 541:fL=fK+4|0;j=542;break;case 542:fM=c[fL>>2]|0;if((fM|0)==0){j=544;break}else{j=543;break};case 543:H=aK(13206,9531964,c[fM+4>>2]|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((H|0)==0){j=545;break}else{fL=fM+12|0;j=542;break};case 544:ap(1186,fK|0);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=553;break;case 545:fN=at(2466,c[fM+8>>2]|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;H=az(10972,fN|0,316184,m|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((H|0)==0){j=549;break}else{fO=H;j=546;break};case 546:fP=az(3094,fO|0,0,0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if(fP>>>0<(c[eQ>>2]|0)>>>0){j=547;break}else{j=548;break};case 547:a[(c[eD>>2]|0)+(fP*12|0)+4|0]=1;j=548;break;case 548:H=az(10972,0,316184,m|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((H|0)==0){j=549;break}else{fO=H;j=546;break};case 549:ap(382,fN|0);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ap(1186,fK|0);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;aE(c[2112872]|0);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;H=c[eQ>>2]|0;if((H|0)==0){j=553;break}else{fQ=0;fR=0;fS=H;j=550;break};case 550:fT=c[eD>>2]|0;if((a[fT+(fQ*12|0)+4|0]&1)==0){fU=fR;fV=fS;j=552;break}else{j=551;break};case 551:H=fR+1|0;aQ(c[2112870]|0,fR|0,1,c[fT+(fQ*12|0)+8>>2]|0);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;fU=H;fV=c[eQ>>2]|0;j=552;break;case 552:H=fQ+1|0;if(H>>>0<fV>>>0){fQ=H;fR=fU;fS=fV;j=550;break}else{j=553;break};case 553:fW=c[eF>>2]|0;if((fW|0)==0){j=555;break}else{j=554;break};case 554:ap(1506,fW|0);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=555;break;case 555:ap(382,eE|0);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ez=eA;j=563;break;case 556:ap(554,eA|0);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ez=0;j=563;break;case 557:ap(554,eA|0);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=558;break;case 558:fX=c[eF>>2]|0;if((fX|0)==0){j=560;break}else{j=559;break};case 559:ap(1506,fX|0);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=560;break;case 560:ap(382,eE|0);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ez=0;j=563;break;case 561:a[fp]=0;j=511;break;case 562:a[fk]=0;j=505;break;case 563:c[2383008]=ez;j=564;break;case 564:a[9532117]=0;a[9532116]=1;J=0;j=581;break;case 565:aE(5250);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;fY=c[2368532]|0;if((fY|0)==0){j=568;break}else{j=566;break};case 566:if((a[9533441]&1)==0){j=567;break}else{j=568;break};case 567:aE(fY|0);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=568;break;case 568:aE(11322);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;if((a[9533443]&1)==0){j=570;break}else{j=569;break};case 569:c[2383358]=0;j=570;break;case 570:if((a[9533444]&1)==0){j=572;break}else{j=571;break};case 571:c[2383357]=0;j=572;break;case 572:if((a[9533445]&1)==0){j=574;break}else{j=573;break};case 573:c[2383359]=0;j=574;break;case 574:a[9533443]=0;a[9533444]=0;a[9533445]=0;aE(c[2112828]|0);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;aE(c[2112868]|0);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;fZ=c[2368540]|0;if((fZ|0)==0){j=580;break}else{j=575;break};case 575:f_=fZ+4104|0;if((c[f_>>2]|0)==0){j=576;break}else{j=577;break};case 576:f$=fZ|0;j=579;break;case 577:f0=fZ|0;f1=0;j=578;break;case 578:H=c[fZ+4100>>2]|0;aQ(78,c[f0>>2]|0,c[H+(f1<<4)+4>>2]|0,c[(c[c[H+(f1<<4)+8>>2]>>2]|0)+(c[H+(f1<<4)+12>>2]<<3)>>2]|0);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;H=f1+1|0;if(H>>>0<(c[f_>>2]|0)>>>0){f1=H;j=578;break}else{f$=f0;j=579;break};case 579:aK(15930,c[f$>>2]|0,fZ+4|0)|0;if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;ap(1142,c[2368540]|0);if((x|0)!=0&(y|0)!=0){k=gGB(c[x>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}x=y=0;j=580;break;case 580:gGz(9469368,0,4800);a[9532116]=0;J=1;j=581;break;case 581:i=f;return J|0;case-1:if((k|0)==1){G=y;j=582}x=y=0;break}return 0}function hl(){var d=0,e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0.0,J=0.0,L=0.0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0;d=i;i=i+9216|0;e=d|0;f=d+256|0;j=d+768|0;k=d+4864|0;l=d+8960|0;a[9533447]=0;m=9290320;if((c[2322579]|0)==0&((c[m>>2]|0)==65535&(c[m+4>>2]|0)==0)&(c[2322584]|0)==-1){n=713}else{m=gA[c[(c[2383356]|0)+12>>2]&16383](c[2383359]|0,48)|0;o=9533608;p=(c[o>>2]&0|m&1|0)==0&(c[o+4>>2]&65536|0)==0;a[9533447]=p&1;if(p){q=0}else{n=713}}do{if((n|0)==713){p=gA[c[(c[2383356]|0)+12>>2]&16383](c[2383359]|0,43)|0;o=9533608;if((c[o>>2]&0|p&1|0)==0&(c[o+4>>2]&2048|0)==0){q=0;break}if((a[9534032]&1)!=0){q=1;break}g3();q=1}}while(0);a[9534032]=q;q=a[9375105]|0;if((q&1)==0){r=q}else{do{if((a[9533447]&1)==0){q=gA[c[(c[2383356]|0)+12>>2]&16383](c[2383359]|0,45)|0;o=9533608;if((c[o>>2]&0|q&1|0)==0&(c[o+4>>2]&8192|0)==0){s=0;break}if((a[9534096]&1)!=0){s=1;break}o=a[9474209]&1;a[9474209]=o^1;q=o<<24>>24==0?69e3:67744;o=c[2380901]|0;p=o+4|0;m=c[p>>2]|0;if(m>>>0>1){t=o|0;v=1;w=m;while(1){m=c[(c[t>>2]|0)+(v<<2)>>2]|0;if((m|0)==0){x=w}else{gGr(c[m+8>>2]|0);gGr(c[(c[t>>2]|0)+(v<<2)>>2]|0);c[(c[t>>2]|0)+(v<<2)>>2]=0;x=c[p>>2]|0}m=v+1|0;if(m>>>0<x>>>0){v=m;w=x}else{break}}}c[p>>2]=1;w=o+12|0;gGr(c[w>>2]|0);c[w>>2]=0;w=c[2380901]|0;v=w+4|0;L1008:do{if((c[v>>2]|0)>>>0<(c[w+8>>2]|0)>>>0){t=gGq(12)|0;do{if((t|0)!=0){if((c[t-4>>2]&3|0)==0){break}gGz(t|0,0,12)}}while(0);c[t+4>>2]=1;c[t>>2]=180;m=bG(q|0)|0;y=c[v>>2]|0;c[t+8>>2]=m;m=w|0;c[(c[m>>2]|0)+(y<<2)>>2]=t;y=c[v>>2]|0;c[v>>2]=y+1;if(y>>>0>1){z=y}else{break}while(1){y=z>>>1;A=c[m>>2]|0;B=A+(y<<2)|0;C=c[B>>2]|0;D=c[A+(z<<2)>>2]|0;if((c[D+4>>2]|0)>>>0<=(c[C+4>>2]|0)>>>0){break L1008}c[B>>2]=D;c[(c[m>>2]|0)+(z<<2)>>2]=C;if(z>>>0>3){z=y}else{break}}}}while(0);v=c[2383357]|0;do{if((v|0)!=0){w=c[2383354]|0;if((a[9474209]&1)!=0){o=c[w+8>>2]|0;gj[o&4095](v)|0;break}if(gj[c[w+12>>2]&4095](v)|0){break}w=c[u>>2]|0;cj(66216,45,1,w|0)|0;eY(w|0)|0;a[9375105]=0}}while(0);if((a[9375104]&1)==0){s=1;break}v=c[u>>2]|0;bU(v|0,324680,(E=i,i=i+8|0,c[E>>2]=q,E)|0)|0;i=E;eY(v|0)|0;s=1}else{s=0}}while(0);a[9534096]=s;r=a[9375105]|0}s=l|0;do{if((r&1)!=0){l=a[9533447]|0;if((l&1)==0){z=gA[c[(c[2383356]|0)+12>>2]&16383](c[2383359]|0,49)|0;x=9533608;F=(c[x>>2]&0|z&1|0)!=0|(c[x+4>>2]&131072|0)!=0;G=a[9533447]|0}else{F=0;G=l}if((G&1)==0){l=gA[c[(c[2383356]|0)+12>>2]&16383](c[2383359]|0,50)|0;x=9533608;H=(c[x>>2]&0|l&1|0)!=0|(c[x+4>>2]&262144|0)!=0}else{H=0}if(!(F|H)){break}I=F?.5:0.0;if(H){J=I+-.5}else{J=I}I=J+ +g[2368565];g[2368565]=I;do{if(I>12.0){g[2368565]=12.0;L=12.0}else{if(I>=-80.0){L=I;break}g[2368565]=-80.0;L=-80.0}}while(0);I=L;be(s|0,256,70448,(E=i,i=i+8|0,h[E>>3]=I,E)|0)|0;i=E;q=c[2380901]|0;x=q+4|0;l=c[x>>2]|0;if(l>>>0>1){z=q|0;v=1;w=l;while(1){l=c[(c[z>>2]|0)+(v<<2)>>2]|0;if((l|0)==0){M=w}else{gGr(c[l+8>>2]|0);gGr(c[(c[z>>2]|0)+(v<<2)>>2]|0);c[(c[z>>2]|0)+(v<<2)>>2]=0;M=c[x>>2]|0}l=v+1|0;if(l>>>0<M>>>0){v=l;w=M}else{break}}}c[x>>2]=1;w=q+12|0;gGr(c[w>>2]|0);c[w>>2]=0;w=c[2380901]|0;v=w+4|0;L1053:do{if((c[v>>2]|0)>>>0<(c[w+8>>2]|0)>>>0){z=gGq(12)|0;do{if((z|0)!=0){if((c[z-4>>2]&3|0)==0){break}gGz(z|0,0,12)}}while(0);c[z+4>>2]=1;c[z>>2]=180;l=bG(s|0)|0;o=c[v>>2]|0;c[z+8>>2]=l;l=w|0;c[(c[l>>2]|0)+(o<<2)>>2]=z;o=c[v>>2]|0;c[v>>2]=o+1;if(o>>>0>1){N=o}else{break}while(1){o=N>>>1;p=c[l>>2]|0;m=p+(o<<2)|0;t=c[m>>2]|0;y=c[p+(N<<2)>>2]|0;if((c[y+4>>2]|0)>>>0<=(c[t+4>>2]|0)>>>0){break L1053}c[m>>2]=y;c[(c[l>>2]|0)+(N<<2)>>2]=t;if(N>>>0>3){N=o}else{break}}}}while(0);if((a[9375104]&1)!=0){v=c[u>>2]|0;bU(v|0,324680,(E=i,i=i+8|0,c[E>>2]=s,E)|0)|0;i=E;eY(v|0)|0}g[2368566]=+X(+10.0,+(+g[2368565]/20.0))}}while(0);c[2382965]=(c[2382965]|0)+1;a[9531834]=(gh[c[(c[2383356]|0)+8>>2]&15](c[2383359]|0,61808,0,1,0,24)|0)<<16>>16!=0|0;a[9531835]=(gh[c[(c[2383356]|0)+8>>2]&15](c[2383359]|0,61808,1,1,0,24)|0)<<16>>16!=0|0;a[9531836]=(gh[c[(c[2383356]|0)+8>>2]&15](c[2383359]|0,61808,2,1,0,24)|0)<<16>>16!=0|0;a[9531837]=(gh[c[(c[2383356]|0)+8>>2]&15](c[2383359]|0,61808,3,1,0,24)|0)<<16>>16!=0|0;a[9531838]=(gh[c[(c[2383356]|0)+8>>2]&15](c[2383359]|0,61808,4,1,0,24)|0)<<16>>16!=0|0;a[9531839]=(gh[c[(c[2383356]|0)+8>>2]&15](c[2383359]|0,61808,5,1,0,24)|0)<<16>>16!=0|0;a[9531840]=(gh[c[(c[2383356]|0)+8>>2]&15](c[2383359]|0,61808,6,1,0,24)|0)<<16>>16!=0|0;a[9531841]=(gh[c[(c[2383356]|0)+8>>2]&15](c[2383359]|0,61808,7,1,0,24)|0)<<16>>16!=0|0;do{if((a[9533447]&1)==0){s=gA[c[(c[2383356]|0)+12>>2]&16383](c[2383359]|0,54)|0;N=9533608;if((c[N>>2]&0|s&1|0)==0&(c[N+4>>2]&4194304|0)==0){O=0;break}N=c[(c[2383356]|0)+36>>2]|0;if((N|0)==0){O=0;break}if((a[9534112]&1)!=0){O=1;break}s=a[9534120]&1;M=s^1;a[9534120]=M;if((a[9375104]&1)==0){P=N;Q=M}else{M=c[u>>2]|0;N=s<<24>>24==0?250320:243216;bU(M|0,77808,(E=i,i=i+8|0,c[E>>2]=N,E)|0)|0;i=E;eY(M|0)|0;P=c[(c[2383356]|0)+36>>2]|0;Q=a[9534120]|0}gg[P&4095](c[2383359]|0,(Q&1)!=0);M=c[2383406]|0;if((M|0)==0){O=1;break}N=c[M+32>>2]|0;if((N|0)==0){O=1;break}gg[N&4095](c[2383358]|0,(a[9534120]&1)==0);O=1}else{O=0}}while(0);a[9534112]=O;if((c[2383400]|0)!=0){do{if((a[9533447]&1)==0){O=gA[c[(c[2383356]|0)+12>>2]&16383](c[2383359]|0,51)|0;Q=9533608;if((c[Q>>2]&0|O&1|0)==0&(c[Q+4>>2]&524288|0)==0){R=0;break}if((a[8451296]&1)!=0){R=1;break}Q=c[2383400]|0;O=Q+28|0;P=c[O>>2]|0;N=Q+20|0;c[N>>2]=P;c[Q+16>>2]=(c[Q+12>>2]|0)+(P*144|0);i4(Q);a[Q+9|0]=1;c[O>>2]=(((c[N>>2]|0)+1|0)>>>0)%((c[Q+24>>2]|0)>>>0)|0;R=1}else{R=0}}while(0);a[8451296]=R}if((a[9533447]&1)==0){R=gA[c[(c[2383356]|0)+12>>2]&16383](c[2383359]|0,35)|0;Q=9533608;S=((c[Q>>2]&0|R&1|0)!=0|(c[Q+4>>2]&8|0)!=0)&1}else{S=0}do{if((a[9531831]&1)==0){if((a[9533447]&1)!=0){T=0;break}Q=gA[c[(c[2383356]|0)+12>>2]&16383](c[2383359]|0,36)|0;R=9533608;T=((c[R>>2]&0|Q&1|0)!=0|(c[R+4>>2]&16|0)!=0)&1}else{T=0}}while(0);R=T|S;if((a[9365848]&1)==0){U=1}else{U=gj[c[(c[2383355]|0)+16>>2]&4095](c[2383358]|0)|0}do{if(R<<24>>24==0|U^1){n=802}else{if((a[9534072]&1)!=0){n=802;break}S=a[9531831]&1;a[9531831]=S^1;T=(a[9375104]&1)!=0;if(S<<24>>24==0){if(T){S=c[u>>2]|0;cj(83208,19,1,S|0)|0;eY(S|0)|0}S=c[2383357]|0;if((S|0)==0){break}Q=c[(c[2383354]|0)+8>>2]|0;gj[Q&4095](S)|0;break}if(T){T=c[u>>2]|0;cj(81848,21,1,T|0)|0;eY(T|0)|0}T=c[2383357]|0;if((T|0)==0){break}if((a[9474209]&1)!=0){break}if(gj[c[(c[2383354]|0)+12>>2]&4095](T)|0){break}T=c[u>>2]|0;cj(79720,81,1,T|0)|0;eY(T|0)|0;a[9375105]=0}}while(0);do{if((n|0)==802){T=(a[61848]&1)==0;if(!U){if(T){break}if((a[9375104]&1)!=0){S=c[u>>2]|0;cj(83208,19,1,S|0)|0;eY(S|0)|0}a[9531831]=1;S=c[2383357]|0;if((S|0)==0){break}Q=c[(c[2383354]|0)+8>>2]|0;gj[Q&4095](S)|0;break}if(!T){break}if((a[9375104]&1)!=0){T=c[u>>2]|0;cj(81848,21,1,T|0)|0;eY(T|0)|0}a[9531831]=0;T=c[2383357]|0;if((T|0)==0){break}if((a[9474209]&1)!=0){break}if(gj[c[(c[2383354]|0)+12>>2]&4095](T)|0){break}T=c[u>>2]|0;cj(79720,81,1,T|0)|0;eY(T|0)|0;a[9375105]=0}}while(0);a[61848]=U&1;a[9534072]=R;do{if((a[9533447]&1)==0){R=gA[c[(c[2383356]|0)+12>>2]&16383](c[2383359]|0,36)|0;U=9533608;if((c[U>>2]&0|R&1|0)==0&(c[U+4>>2]&16|0)==0){V=0;W=0;break}V=a[9534080]&1^1;W=1}else{V=0;W=0}}while(0);a[9531832]=V;a[9534080]=W;do{if((a[9533447]&1)==0){W=gA[c[(c[2383356]|0)+12>>2]&16383](c[2383359]|0,33)|0;V=9533608;if((c[V>>2]&0|W&1|0)==0&(c[V+4>>2]&2|0)==0){Y=0;Z=0;break}Y=a[9534088]&1^1;Z=1}else{Y=0;Z=0}}while(0);a[9531832]=(a[9531832]&1|Y|0)!=0|0;a[9534088]=Z;do{if((a[9533447]&1)==0){Z=gA[c[(c[2383356]|0)+12>>2]&16383](c[2383359]|0,29)|0;Y=9533608;if((c[Y>>2]&536870912|Z&1|0)==0&(c[Y+4>>2]&0|0)==0){_=0;n=835;break}if((a[9534128]&1)!=0){_=1;n=835;break}a[9263552]=a[9263552]&1^1;a[9533441]=a[9474124]&1;a[9533442]=0;hV();Y=c[2368532]|0;do{if((Y|0)!=0){if((a[9533441]&1)!=0){break}gu[Y&16383]()}}while(0);hW();if((a[9533443]&1)!=0){c[2383358]=0}if((a[9533444]&1)!=0){c[2383357]=0}if((a[9533445]&1)!=0){c[2383359]=0}a[9533443]=0;a[9533444]=0;a[9533445]=0;hU();a[9533441]=0;Y=c[2383356]|0;if((Y|0)!=0){gf[c[Y+4>>2]&2047](c[2383359]|0)}a[9534128]=1;if((a[9531831]&1)==0){break}g4()}else{_=0;n=835}}while(0);if((n|0)==835){a[9534128]=_}do{if((a[9531831]&1)!=0){if((a[9531832]&1)!=0){break}i=d;return}}while(0);_=a[9533447]|0;if((_&1)==0){Y=gA[c[(c[2383356]|0)+12>>2]&16383](c[2383359]|0,25)|0;Z=9533608;$=(c[Z>>2]&33554432|Y&1|0)!=0|(c[Z+4>>2]&0|0)!=0;aa=a[9533447]|0}else{$=0;aa=_}if((aa&1)==0){aa=gA[c[(c[2383356]|0)+12>>2]&16383](c[2383359]|0,26)|0;_=9533608;ab=(c[_>>2]&67108864|aa&1|0)!=0|(c[_+4>>2]&0|0)!=0}else{ab=0}do{if($){if((a[9534144]&1)!=0){n=854;break}_=a[9533448]&1;a[9533448]=_^1;aa=_<<24>>24==0;Z=c[2383358]|0;if((a[9375106]&1)!=0&(Z|0)!=0){if((a[9263568]&1)==0){n=849}else{if((a[9469445]&1)==0){ac=aa}else{n=849}}if((n|0)==849){ac=1}gg[c[(c[2383355]|0)+8>>2]&4095](Z,ac)}Z=c[2383357]|0;if((a[9375105]&1)!=0&(Z|0)!=0){gg[c[(c[2383354]|0)+16>>2]&4095](Z,(_&a[9284180])<<24>>24==0)}c[2368546]=aa?c[2368547]|0:c[2368548]|0}else{n=854}}while(0);do{if((n|0)==854){if((a[9534136]&1|0)==(ab&1|0)){break}a[9533448]=ab&1;ac=c[2383358]|0;if((a[9375106]&1)!=0&(ac|0)!=0){if((a[9263568]&1)==0){n=858}else{if((a[9469445]&1)==0){ad=ab}else{n=858}}if((n|0)==858){ad=1}gg[c[(c[2383355]|0)+8>>2]&4095](ac,ad)}ac=c[2383357]|0;if((a[9375105]&1)!=0&(ac|0)!=0){gg[c[(c[2383354]|0)+16>>2]&4095](ac,(a[9284180]&1)==0|ab)}c[2368546]=ab?c[2368547]|0:c[2368548]|0}}while(0);a[9534144]=$&1;a[9534136]=ab&1;do{if((a[9533447]&1)==0){ab=gA[c[(c[2383356]|0)+12>>2]&16383](c[2383359]|0,31)|0;$=9533608;if((c[$>>2]&-2147483648|ab&1|0)==0&(c[$+4>>2]&0|0)==0){ae=0;break}if((a[9534e3]&1)!=0){ae=1;break}$=e|0;ab=(c[2367336]|0)+1|0;c[2367336]=ab;ad=c[2380901]|0;if((ad|0)==0){af=ab}else{ab=ad+4|0;ac=c[ab>>2]|0;if(ac>>>0>1){aa=ad|0;_=1;Z=ac;while(1){ac=c[(c[aa>>2]|0)+(_<<2)>>2]|0;if((ac|0)==0){ag=Z}else{gGr(c[ac+8>>2]|0);gGr(c[(c[aa>>2]|0)+(_<<2)>>2]|0);c[(c[aa>>2]|0)+(_<<2)>>2]=0;ag=c[ab>>2]|0}ac=_+1|0;if(ac>>>0<ag>>>0){_=ac;Z=ag}else{break}}}c[ab>>2]=1;Z=ad+12|0;gGr(c[Z>>2]|0);c[Z>>2]=0;af=c[2367336]|0}be($|0,256,443640,(E=i,i=i+8|0,c[E>>2]=af,E)|0)|0;i=E;Z=c[2380901]|0;L1216:do{if((Z|0)!=0){_=Z+4|0;if((c[_>>2]|0)>>>0>=(c[Z+8>>2]|0)>>>0){break}aa=gGq(12)|0;do{if((aa|0)!=0){if((c[aa-4>>2]&3|0)==0){break}gGz(aa|0,0,12)}}while(0);c[aa+4>>2]=1;c[aa>>2]=180;ac=bG($|0)|0;Y=c[_>>2]|0;c[aa+8>>2]=ac;ac=Z|0;c[(c[ac>>2]|0)+(Y<<2)>>2]=aa;Y=c[_>>2]|0;c[_>>2]=Y+1;if(Y>>>0>1){ah=Y}else{break}while(1){Y=ah>>>1;V=c[ac>>2]|0;W=V+(Y<<2)|0;U=c[W>>2]|0;R=c[V+(ah<<2)>>2]|0;if((c[R+4>>2]|0)>>>0<=(c[U+4>>2]|0)>>>0){break L1216}c[W>>2]=R;c[(c[ac>>2]|0)+(ah<<2)>>2]=U;if(ah>>>0>3){ah=Y}else{break}}}}while(0);if((a[9375104]&1)==0){ae=1;break}Z=c[u>>2]|0;bU(Z|0,324680,(E=i,i=i+8|0,c[E>>2]=$,E)|0)|0;i=E;eY(Z|0)|0;ae=1}else{ae=0}}while(0);a[9534e3]=ae;do{if((a[9533447]&1)==0){ae=gA[c[(c[2383356]|0)+12>>2]&16383](c[2383359]|0,32)|0;ah=9533608;if((c[ah>>2]&0|ae&1|0)==0&(c[ah+4>>2]&1|0)==0){ai=0;break}if((a[9534008]&1)!=0){ai=1;break}ah=e|0;ae=c[2367336]|0;if((ae|0)==0){aj=0}else{af=ae-1|0;c[2367336]=af;aj=af}af=c[2380901]|0;if((af|0)==0){ak=aj}else{ae=af+4|0;ag=c[ae>>2]|0;if(ag>>>0>1){Z=af|0;ad=1;ab=ag;while(1){ag=c[(c[Z>>2]|0)+(ad<<2)>>2]|0;if((ag|0)==0){al=ab}else{gGr(c[ag+8>>2]|0);gGr(c[(c[Z>>2]|0)+(ad<<2)>>2]|0);c[(c[Z>>2]|0)+(ad<<2)>>2]=0;al=c[ae>>2]|0}ag=ad+1|0;if(ag>>>0<al>>>0){ad=ag;ab=al}else{break}}}c[ae>>2]=1;ab=af+12|0;gGr(c[ab>>2]|0);c[ab>>2]=0;ak=c[2367336]|0}be(ah|0,256,443640,(E=i,i=i+8|0,c[E>>2]=ak,E)|0)|0;i=E;ab=c[2380901]|0;L1247:do{if((ab|0)!=0){ad=ab+4|0;if((c[ad>>2]|0)>>>0>=(c[ab+8>>2]|0)>>>0){break}Z=gGq(12)|0;do{if((Z|0)!=0){if((c[Z-4>>2]&3|0)==0){break}gGz(Z|0,0,12)}}while(0);c[Z+4>>2]=1;c[Z>>2]=180;$=bG(ah|0)|0;ag=c[ad>>2]|0;c[Z+8>>2]=$;$=ab|0;c[(c[$>>2]|0)+(ag<<2)>>2]=Z;ag=c[ad>>2]|0;c[ad>>2]=ag+1;if(ag>>>0>1){am=ag}else{break}while(1){ag=am>>>1;ac=c[$>>2]|0;_=ac+(ag<<2)|0;aa=c[_>>2]|0;Y=c[ac+(am<<2)>>2]|0;if((c[Y+4>>2]|0)>>>0<=(c[aa+4>>2]|0)>>>0){break L1247}c[_>>2]=Y;c[(c[$>>2]|0)+(am<<2)>>2]=aa;if(am>>>0>3){am=ag}else{break}}}}while(0);if((a[9375104]&1)==0){ai=1;break}ab=c[u>>2]|0;bU(ab|0,324680,(E=i,i=i+8|0,c[E>>2]=ah,E)|0)|0;i=E;eY(ab|0)|0;ai=1}else{ai=0}}while(0);a[9534008]=ai;ai=(c[2380907]|0)==0;do{if((a[9533447]&1)==0){am=gA[c[(c[2383356]|0)+12>>2]&16383](c[2383359]|0,28)|0;ak=9533608;if((c[ak>>2]&268435456|am&1|0)==0&(c[ak+4>>2]&0|0)==0){an=0;break}if((a[9534040]&1)!=0){an=1;break}hd();an=1}else{an=0}}while(0);a[9534040]=an&1;if(ai){do{if((a[9533447]&1)==0){ai=gA[c[(c[2383356]|0)+12>>2]&16383](c[2383359]|0,27)|0;ak=9533608;am=(c[ak>>2]&134217728|ai&1|0)!=0|(c[ak+4>>2]&0|0)!=0;if(an|am^1){ao=am;break}if((a[9534048]&1)!=0){ao=am;break}hc();ao=am}else{ao=0}}while(0);a[9534048]=ao&1}if((a[9523624]&1)!=0){ao=c[2368556]|0;if(g8((c[2368555]|0)+(ao<<1)|0,(c[2368557]|0)-ao|0)|0){ap=a[9375105]&1}else{ap=0}a[9375105]=ap}a[9523624]=0;do{if(a[61840]|0){if((c[2380903]|0)==0){break}L1283:do{if((a[9533447]&1)==0){ap=gA[c[(c[2383356]|0)+12>>2]&16383](c[2383359]|0,33)|0;ao=9533608;if((c[ao>>2]&0|ap&1|0)==0&(c[ao+4>>2]&2|0)==0){n=966;break}ao=c[2380901]|0;ap=ao+4|0;an=c[ap>>2]|0;if(an>>>0>1){am=ao|0;ak=1;ai=an;while(1){an=c[(c[am>>2]|0)+(ak<<2)>>2]|0;if((an|0)==0){aq=ai}else{gGr(c[an+8>>2]|0);gGr(c[(c[am>>2]|0)+(ak<<2)>>2]|0);c[(c[am>>2]|0)+(ak<<2)>>2]=0;aq=c[ap>>2]|0}an=ak+1|0;if(an>>>0<aq>>>0){ak=an;ai=aq}else{break}}}c[ap>>2]=1;ai=ao+12|0;gGr(c[ai>>2]|0);c[ai>>2]=0;ai=c[2380903]|0;ak=ai+12|0;am=c[ak>>2]|0;an=am;al=ai+28|0;do{if((a[al]&1)==0){aj=ai+16|0;e=ai+8|0;ab=c[e>>2]|0;af=(c[aj>>2]|0)-1&ab;c[aj>>2]=af;ae=ai+20|0;$=c[ae>>2]|0;if((af|0)==($|0)){c[aj>>2]=af+1&ab;ad=c[2380901]|0;Z=ad+4|0;if((c[Z>>2]|0)>>>0>=(c[ad+8>>2]|0)>>>0){break L1283}ag=gGq(12)|0;do{if((ag|0)!=0){if((c[ag-4>>2]&3|0)==0){break}gGz(ag|0,0,12)}}while(0);c[ag+4>>2]=0;c[ag>>2]=30;aa=bG(84960)|0;Y=c[Z>>2]|0;c[ag+8>>2]=aa;aa=ad|0;c[(c[aa>>2]|0)+(Y<<2)>>2]=ag;Y=c[Z>>2]|0;c[Z>>2]=Y+1;if(Y>>>0>1){ar=Y}else{break L1283}while(1){Y=ar>>>1;_=c[aa>>2]|0;ac=_+(Y<<2)|0;U=c[ac>>2]|0;R=c[_+(ar<<2)>>2]|0;if((c[R+4>>2]|0)>>>0<=(c[U+4>>2]|0)>>>0){break L1283}c[ac>>2]=R;c[(c[aa>>2]|0)+(ar<<2)>>2]=U;if(ar>>>0>3){ar=Y}else{break L1283}}}else{aa=ai|0;Z=(c[aa>>2]|0)+(af<<3)|0;ag=c[Z>>2]|0;ad=c[Z+4>>2]|0;if((ag|0)==0&(ad|0)==0){as=af;at=$;au=ab}else{Z=ad;ad=ag;ag=am;while(1){Y=ag+(Z<<2)|0;c[Y>>2]=c[Y>>2]^ad;av=c[e>>2]|0;aw=(c[aj>>2]|0)-1&av;c[aj>>2]=aw;Y=(c[aa>>2]|0)+(aw<<3)|0;U=c[Y>>2]|0;R=c[Y+4>>2]|0;if((U|0)==0&(R|0)==0){break}Z=R;ad=U;ag=c[ak>>2]|0}as=aw;at=c[ae>>2]|0;au=av}if((as|0)!=(at|0)){break}c[aj>>2]=at+1&au;break}}else{a[al]=0}}while(0);a[9523624]=1;al=c[2368557]|0;c[2368556]=al;L1317:do{if((c[2368545]|0)!=0){ak=0;am=al;while(1){ai=b[(c[2368554]|0)+((ak|1)<<1)>>1]|0;ao=am-1|0;c[2368556]=ao;b[(c[2368555]|0)+(ao<<1)>>1]=ai;ai=b[(c[2368554]|0)+(ak<<1)>>1]|0;ao=(c[2368556]|0)-1|0;c[2368556]=ao;b[(c[2368555]|0)+(ao<<1)>>1]=ai;ai=ak+2|0;if(ai>>>0>=(c[2368545]|0)>>>0){break L1317}ak=ai;am=c[2368556]|0}}}while(0);c[2368545]=0;al=c[2380901]|0;am=al+4|0;L1322:do{if((c[am>>2]|0)>>>0<(c[al+8>>2]|0)>>>0){ak=(a[9531831]&1)!=0?1:30;aj=gGq(12)|0;do{if((aj|0)!=0){if((c[aj-4>>2]&3|0)==0){break}gGz(aj|0,0,12)}}while(0);c[aj+4>>2]=0;c[aj>>2]=ak;ae=bG(87e3)|0;ai=c[am>>2]|0;c[aj+8>>2]=ae;ae=al|0;c[(c[ae>>2]|0)+(ai<<2)>>2]=aj;ai=c[am>>2]|0;c[am>>2]=ai+1;if(ai>>>0>1){ax=ai}else{break}while(1){ai=ax>>>1;ao=c[ae>>2]|0;ap=ao+(ai<<2)|0;ag=c[ap>>2]|0;ad=c[ao+(ax<<2)>>2]|0;if((c[ad+4>>2]|0)>>>0<=(c[ag+4>>2]|0)>>>0){break L1322}c[ap>>2]=ad;c[(c[ae>>2]|0)+(ax<<2)>>2]=ag;if(ax>>>0>3){ax=ai}else{break}}}}while(0);am=c[2112826]|0;al=c[2380905]|0;gA[am&16383](an,al)|0;al=c[2380907]|0;if((al|0)==0){break}a[al+30|0]=1;am=al+12|0;ae=c[am>>2]|0;aj=c[al+4>>2]|0;do{if(ae>>>0<2){ak=c[aj>>2]|0;ai=al+16|0;if((ak|0)!=(c[ai>>2]|0)){ay=ai;n=954;break}c[am>>2]=0;ag=c[al>>2]|0;dh(ag|0,ak|0,0)|0;az=ai}else{ay=al+16|0;n=954}}while(0);if((n|0)==954){an=ae-((a[al+29|0]&1)!=0?1:2)&c[al+8>>2];c[am>>2]=an;ai=c[al>>2]|0;ak=c[aj+(an<<2)>>2]|0;dh(ai|0,ak|0,0)|0;az=ay}ak=al|0;ai=fl(c[ak>>2]|0)|0;an=c[az>>2]|0;if((ai|0)>(an|0)){break}ai=c[ak>>2]|0;if((a[al+28|0]&1)==0){dh(ai|0,16,0)|0;ag=c[2112846]|0;ad=al+24|0;ap=c[ad>>2]|0;ao=al+20|0;Z=c[ao>>2]|0;gA[ag&16383](ap,Z)|0;Z=c[ad>>2]|0;ad=c[ao>>2]|0;ao=c[ak>>2]|0;cj(Z|0,1,ad|0,ao|0)|0;break}else{dh(ai|0,an|0,0)|0;break}}else{n=966}}while(0);do{if((n|0)==966){ah=c[2341459]|0;an=(((c[2383514]|0)+1|0)>>>0)%(((ah|0)!=0?ah:1)>>>0)|0;c[2383514]=an;if(!((an|0)==0|(c[2380907]|0)!=0)){break}an=c[2112846]|0;ah=c[2380904]|0;ai=c[2380905]|0;gA[an&16383](ah,ai)|0;ai=c[2380903]|0;ah=c[2380904]|0;an=ai+12|0;ao=c[an>>2]|0;ad=ah;Z=ai+16|0;ak=c[Z>>2]|0;c[Z>>2]=ak+1;ap=ai|0;ag=(c[ap>>2]|0)+(ak<<3)|0;c[ag>>2]=0;c[ag+4>>2]=0;ag=ai+8|0;ak=c[ag>>2]|0;aa=c[Z>>2]&ak;c[Z>>2]=aa;e=ai+20|0;ab=(aa|0)==(c[e>>2]|0);$=ai+24|0;af=c[$>>2]|0;if((af|0)==0){aA=ab;aB=aa;aC=ak;aD=0}else{U=ab;ab=0;R=0;Y=aa;aa=ak;ak=af;while(1){af=R;ac=c[ao+(af<<2)>>2]|0;_=c[ad+(af<<2)>>2]|0;if((ac|0)==(_|0)){aE=U;aF=Y;aG=aa;aH=ak}else{af=(c[ap>>2]|0)+(Y<<3)|0;c[af>>2]=_^ac;c[af+4>>2]=R;af=c[ag>>2]|0;ac=(c[Z>>2]|0)+1&af;c[Z>>2]=ac;aE=(ac|0)==(c[e>>2]|0)|U;aF=ac;aG=af;aH=c[$>>2]|0}af=gGK(R,ab,1,0)|0;ac=K;_=0;if(ac>>>0<_>>>0|ac>>>0==_>>>0&af>>>0<aH>>>0){U=aE;ab=ac;R=af;Y=aF;aa=aG;ak=aH}else{aA=aE;aB=aF;aC=aG;aD=aH;break}}}do{if(aA){ak=aB+1&aC;c[e>>2]=ak;aa=c[ap>>2]|0;Y=aa+(ak<<3)|0;if((c[Y>>2]|0)==0&(c[Y+4>>2]|0)==0){break}else{aI=ak}do{aI=aI+1&aC;c[e>>2]=aI;ak=aa+(aI<<3)|0;}while(!((c[ak>>2]|0)==0&(c[ak+4>>2]|0)==0))}}while(0);e=c[an>>2]|0;ap=aD<<2;gGC(e|0,ah|0,ap)|0;a[ai+28|0]=1}}while(0);gf[c[2112842]&2047]((a[9523624]&1)!=0?1582:1792);gf[c[2112840]&2047]((a[9523624]&1)!=0?15196:15108)}else{a[61840]=1}}while(0);L1361:do{if((a[9533447]&1)==0){aD=gA[c[(c[2383356]|0)+12>>2]&16383](c[2383359]|0,47)|0;aI=9533608;aC=(c[aI>>2]&0|aD&1|0)!=0|(c[aI+4>>2]&32768|0)!=0;a[9531833]=aC&1;if(!aC){break}aC=c[2380901]|0;aI=aC+4|0;aD=c[aI>>2]|0;if(aD>>>0>1){aB=aC|0;aA=1;aH=aD;while(1){aD=c[(c[aB>>2]|0)+(aA<<2)>>2]|0;if((aD|0)==0){aJ=aH}else{gGr(c[aD+8>>2]|0);gGr(c[(c[aB>>2]|0)+(aA<<2)>>2]|0);c[(c[aB>>2]|0)+(aA<<2)>>2]=0;aJ=c[aI>>2]|0}aD=aA+1|0;if(aD>>>0<aJ>>>0){aA=aD;aH=aJ}else{break}}}c[aI>>2]=1;aH=aC+12|0;gGr(c[aH>>2]|0);c[aH>>2]=0;aH=c[2380901]|0;aA=aH+4|0;if((c[aA>>2]|0)>>>0>=(c[aH+8>>2]|0)>>>0){break}aB=(a[9523624]&1)!=0?90352:88576;aD=gGq(12)|0;do{if((aD|0)!=0){if((c[aD-4>>2]&3|0)==0){break}gGz(aD|0,0,12)}}while(0);c[aD+4>>2]=0;c[aD>>2]=30;aC=bG(aB|0)|0;aI=c[aA>>2]|0;c[aD+8>>2]=aC;aC=aH|0;c[(c[aC>>2]|0)+(aI<<2)>>2]=aD;aI=c[aA>>2]|0;c[aA>>2]=aI+1;if(aI>>>0>1){aK=aI}else{break}while(1){aI=aK>>>1;aG=c[aC>>2]|0;aF=aG+(aI<<2)|0;aE=c[aF>>2]|0;az=c[aG+(aK<<2)>>2]|0;if((c[az+4>>2]|0)>>>0<=(c[aE+4>>2]|0)>>>0){break L1361}c[aF>>2]=az;c[(c[aC>>2]|0)+(aK<<2)>>2]=aE;if(aK>>>0>3){aK=aI}else{break}}}else{a[9531833]=0}}while(0);do{if((a[9533447]&1)==0){aK=gA[c[(c[2383356]|0)+12>>2]&16383](c[2383359]|0,34)|0;aJ=9533608;if((c[aJ>>2]&0|aK&1|0)==0&(c[aJ+4>>2]&4|0)==0){aL=0;aM=0;break}aL=(a[9534104]&1)==0;aM=1}else{aL=0;aM=0}}while(0);do{if((a[9527728]&1)==0){if(!aL){break}aJ=j|0;aK=k|0;if((c[2380907]|0)==0){c[2341459]=1;aC=c[2367336]|0;if((aC|0)==0){be(aJ|0,4096,109912,(E=i,i=i+8|0,c[E>>2]=9523632,E)|0)|0;i=E}else{be(aJ|0,4096,111656,(E=i,i=i+16|0,c[E>>2]=9523632,c[E+8>>2]=aC,E)|0)|0;i=E}be(aK|0,4096,107872,(E=i,i=i+8|0,c[E>>2]=aJ,E)|0)|0;i=E;c[2380907]=iz(aJ,1)|0;aC=c[2380901]|0;aA=aC+4|0;aD=c[aA>>2]|0;if(aD>>>0>1){aH=aC|0;aB=1;aI=aD;while(1){aD=c[(c[aH>>2]|0)+(aB<<2)>>2]|0;if((aD|0)==0){aN=aI}else{gGr(c[aD+8>>2]|0);gGr(c[(c[aH>>2]|0)+(aB<<2)>>2]|0);c[(c[aH>>2]|0)+(aB<<2)>>2]=0;aN=c[aA>>2]|0}aD=aB+1|0;if(aD>>>0<aN>>>0){aB=aD;aI=aN}else{break}}}c[aA>>2]=1;aI=aC+12|0;gGr(c[aI>>2]|0);c[aI>>2]=0;aI=c[2380901]|0;aB=aI+4|0;L1452:do{if((c[aB>>2]|0)>>>0<(c[aI+8>>2]|0)>>>0){aH=(c[2380907]|0)!=0?aK:106176;aD=gGq(12)|0;do{if((aD|0)!=0){if((c[aD-4>>2]&3|0)==0){break}gGz(aD|0,0,12)}}while(0);c[aD+4>>2]=1;c[aD>>2]=180;ai=bG(aH|0)|0;ah=c[aB>>2]|0;c[aD+8>>2]=ai;ai=aI|0;c[(c[ai>>2]|0)+(ah<<2)>>2]=aD;ah=c[aB>>2]|0;c[aB>>2]=ah+1;if(ah>>>0>1){aO=ah}else{break}while(1){ah=aO>>>1;an=c[ai>>2]|0;aE=an+(ah<<2)|0;az=c[aE>>2]|0;aF=c[an+(aO<<2)>>2]|0;if((c[aF+4>>2]|0)>>>0<=(c[az+4>>2]|0)>>>0){break L1452}c[aE>>2]=aF;c[(c[ai>>2]|0)+(aO<<2)>>2]=az;if(aO>>>0>3){aO=ah}else{break}}}}while(0);if((c[2380907]|0)==0){aB=c[u>>2]|0;cj(100280,51,1,aB|0)|0;eY(aB|0)|0;break}if((a[9375104]&1)==0){break}aB=c[u>>2]|0;bU(aB|0,103024,(E=i,i=i+8|0,c[E>>2]=aJ,E)|0)|0;i=E;eY(aB|0)|0;break}else{aB=c[2380901]|0;aI=aB+4|0;aK=c[aI>>2]|0;if(aK>>>0>1){aC=aB|0;aA=1;ai=aK;while(1){aK=c[(c[aC>>2]|0)+(aA<<2)>>2]|0;if((aK|0)==0){aP=ai}else{gGr(c[aK+8>>2]|0);gGr(c[(c[aC>>2]|0)+(aA<<2)>>2]|0);c[(c[aC>>2]|0)+(aA<<2)>>2]=0;aP=c[aI>>2]|0}aK=aA+1|0;if(aK>>>0<aP>>>0){aA=aK;ai=aP}else{break}}}c[aI>>2]=1;ai=aB+12|0;gGr(c[ai>>2]|0);c[ai>>2]=0;ai=c[2380901]|0;aA=ai+4|0;L1420:do{if((c[aA>>2]|0)>>>0<(c[ai+8>>2]|0)>>>0){aC=gGq(12)|0;do{if((aC|0)!=0){if((c[aC-4>>2]&3|0)==0){break}gGz(aC|0,0,12)}}while(0);c[aC+4>>2]=2;c[aC>>2]=180;aJ=bG(115368)|0;aK=c[aA>>2]|0;c[aC+8>>2]=aJ;aJ=ai|0;c[(c[aJ>>2]|0)+(aK<<2)>>2]=aC;aK=c[aA>>2]|0;c[aA>>2]=aK+1;if(aK>>>0>1){aQ=aK}else{break}while(1){aK=aQ>>>1;aD=c[aJ>>2]|0;aH=aD+(aK<<2)|0;ah=c[aH>>2]|0;az=c[aD+(aQ<<2)>>2]|0;if((c[az+4>>2]|0)>>>0<=(c[ah+4>>2]|0)>>>0){break L1420}c[aH>>2]=az;c[(c[aJ>>2]|0)+(aQ<<2)>>2]=ah;if(aQ>>>0>3){aQ=aK}else{break}}}}while(0);if((a[9375104]&1)!=0){aA=c[u>>2]|0;cj(113528,34,1,aA|0)|0;eY(aA|0)|0}aA=c[2380907]|0;if((aA|0)!=0){ai=c[aA>>2]|0;if((ai|0)!=0){aY(ai|0)|0}gGr(c[aA+24>>2]|0);gGr(c[aA+4>>2]|0);gGr(aA)}c[2380907]=0;break}}else{if(!((a[9531827]&1)!=0|aL)){break}aA=c[2380901]|0;ai=aA+4|0;L1389:do{if((c[ai>>2]|0)>>>0<(c[aA+8>>2]|0)>>>0){aB=gGq(12)|0;do{if((aB|0)!=0){if((c[aB-4>>2]&3|0)==0){break}gGz(aB|0,0,12)}}while(0);c[aB+4>>2]=1;c[aB>>2]=180;aI=bG(96824)|0;aJ=c[ai>>2]|0;c[aB+8>>2]=aI;aI=aA|0;c[(c[aI>>2]|0)+(aJ<<2)>>2]=aB;aJ=c[ai>>2]|0;c[ai>>2]=aJ+1;if(aJ>>>0>1){aR=aJ}else{break}while(1){aJ=aR>>>1;aC=c[aI>>2]|0;aK=aC+(aJ<<2)|0;ah=c[aK>>2]|0;az=c[aC+(aR<<2)>>2]|0;if((c[az+4>>2]|0)>>>0<=(c[ah+4>>2]|0)>>>0){break L1389}c[aK>>2]=az;c[(c[aI>>2]|0)+(aR<<2)>>2]=ah;if(aR>>>0>3){aR=aJ}else{break}}}}while(0);if((a[9375104]&1)!=0){ai=c[u>>2]|0;cj(93304,33,1,ai|0)|0;eY(ai|0)|0}ai=c[2380907]|0;if((ai|0)!=0){aA=c[ai>>2]|0;if((aA|0)!=0){aY(aA|0)|0}gGr(c[ai+24>>2]|0);gGr(c[ai+4>>2]|0);gGr(ai)}c[2380907]=0;a[9531827]=0;a[9527728]=0}}while(0);a[9534104]=aM;aM=f|0;L1467:do{if((c[2382989]|0)!=0){if((c[(c[2383355]|0)+20>>2]|0)==0){break}f=a[9533447]|0;if((f&1)==0){aR=gA[c[(c[2383356]|0)+12>>2]&16383](c[2383359]|0,38)|0;aL=9533608;aS=(c[aL>>2]&0|aR&1|0)!=0|(c[aL+4>>2]&64|0)!=0;aT=a[9533447]|0}else{aS=0;aT=f}if((aT&1)==0){f=gA[c[(c[2383356]|0)+12>>2]&16383](c[2383359]|0,39)|0;aL=9533608;aU=(c[aL>>2]&0|f&1|0)!=0|(c[aL+4>>2]&128|0)!=0}else{aU=0}do{if(aS){if((a[9534024]&1)!=0){n=1059;break}aL=c[2382989]|0;f=(((c[2382990]|0)+1|0)>>>0)%((c[aL+4>>2]|0)>>>0)|0;c[2382990]=f;aV=f;aW=aL;n=1064}else{n=1059}}while(0);do{if((n|0)==1059){if(!aU){break}if((a[9534016]&1)!=0){break}aL=c[2382990]|0;if((aL|0)==0){f=c[2382989]|0;aR=(c[f+4>>2]|0)-1|0;c[2382990]=aR;aV=aR;aW=f;n=1064;break}else{f=aL-1|0;c[2382990]=f;aV=f;aW=c[2382989]|0;n=1064;break}}}while(0);do{if((n|0)==1064){f=c[(c[aW>>2]|0)+(aV<<3)>>2]|0;aL=cE(f|0,46)|0;if((aL|0)==0){break L1467}do{if((fa(aL|0,133368)|0)==0){aX=2}else{if((fa(aL|0,131552)|0)==0){aX=0;break}if((fa(aL|0,563632)|0)==0){aX=0}else{break L1467}}}while(0);aL=c[2380901]|0;aR=aL+4|0;aQ=c[aR>>2]|0;if(aQ>>>0>1){aP=aL|0;aO=1;aN=aQ;while(1){aQ=c[(c[aP>>2]|0)+(aO<<2)>>2]|0;if((aQ|0)==0){aZ=aN}else{gGr(c[aQ+8>>2]|0);gGr(c[(c[aP>>2]|0)+(aO<<2)>>2]|0);c[(c[aP>>2]|0)+(aO<<2)>>2]=0;aZ=c[aR>>2]|0}aQ=aO+1|0;if(aQ>>>0<aZ>>>0){aO=aQ;aN=aZ}else{break}}}c[aR>>2]=1;aN=aL+12|0;gGr(c[aN>>2]|0);c[aN>>2]=0;aN=c[2382990]|0;be(aM|0,512,125352,(E=i,i=i+16|0,c[E>>2]=aN,c[E+8>>2]=f,E)|0)|0;i=E;aN=c[2380901]|0;aO=aN+4|0;L1501:do{if((c[aO>>2]|0)>>>0<(c[aN+8>>2]|0)>>>0){aP=gGq(12)|0;do{if((aP|0)!=0){if((c[aP-4>>2]&3|0)==0){break}gGz(aP|0,0,12)}}while(0);c[aP+4>>2]=1;c[aP>>2]=120;aQ=bG(aM|0)|0;k=c[aO>>2]|0;c[aP+8>>2]=aQ;aQ=aN|0;c[(c[aQ>>2]|0)+(k<<2)>>2]=aP;k=c[aO>>2]|0;c[aO>>2]=k+1;if(k>>>0>1){a_=k}else{break}while(1){k=a_>>>1;j=c[aQ>>2]|0;ai=j+(k<<2)|0;aA=c[ai>>2]|0;aI=c[j+(a_<<2)>>2]|0;if((c[aI+4>>2]|0)>>>0<=(c[aA+4>>2]|0)>>>0){break L1501}c[ai>>2]=aI;c[(c[aQ>>2]|0)+(a_<<2)>>2]=aA;if(a_>>>0>3){a_=k}else{break}}}}while(0);if((a[9375104]&1)!=0){aO=c[u>>2]|0;bU(aO|0,121928,(E=i,i=i+8|0,c[E>>2]=f,E)|0)|0;i=E;eY(aO|0)|0}if(gp[c[(c[2383355]|0)+20>>2]&16383](c[2383358]|0,aX,f)|0){break}aO=c[u>>2]|0;cj(118392,44,1,aO|0)|0;eY(aO|0)|0}}while(0);a[9534024]=aS&1;a[9534016]=aU&1}}while(0);if((c[2383008]|0)!=0){aU=a[9533447]|0;if((aU&1)==0){aS=gA[c[(c[2383356]|0)+12>>2]&16383](c[2383359]|0,40)|0;aX=9533608;a$=(c[aX>>2]&0|aS&1|0)!=0|(c[aX+4>>2]&256|0)!=0;a0=a[9533447]|0}else{a$=0;a0=aU}if((a0&1)==0){aU=gA[c[(c[2383356]|0)+12>>2]&16383](c[2383359]|0,41)|0;aX=9533608;a1=(c[aX>>2]&0|aU&1|0)!=0|(c[aX+4>>2]&512|0)!=0;a2=a[9533447]|0}else{a1=0;a2=a0}if((a2&1)==0){a2=gA[c[(c[2383356]|0)+12>>2]&16383](c[2383359]|0,42)|0;a0=9533608;a3=(c[a0>>2]&0|a2&1|0)!=0|(c[a0+4>>2]&1024|0)!=0}else{a3=0}do{if(a$){if((a[9534184]&1)!=0){n=1095;break}a0=c[2383008]|0;a2=a0+4|0;c[a2>>2]=(((c[a2>>2]|0)+1|0)>>>0)%((c[a0+8>>2]|0)>>>0)|0;iU(a0)}else{n=1095}}while(0);L1531:do{if((n|0)==1095){do{if(a1){if((a[9534176]&1)!=0){break}a0=c[2383008]|0;a2=a0+4|0;aX=c[a2>>2]|0;if((aX|0)==0){a4=c[a0+8>>2]|0}else{a4=aX}c[a2>>2]=a4-1;iU(a0);break L1531}}while(0);if(!a3){break}if((a[9534168]&1)!=0){break}a0=c[2383008]|0;a2=a0|0;aX=(c[a2>>2]|0)+((c[a0+4>>2]|0)*12|0)+4|0;a[aX]=a[aX]&1^1;gu[c[2112872]&16383]();aX=a0+8|0;aU=c[aX>>2]|0;if((aU|0)!=0){aS=0;E=0;a_=aU;while(1){aU=c[a2>>2]|0;if((a[aU+(aS*12|0)+4|0]&1)==0){a5=E;a6=a_}else{gG[c[2112870]&255](E,1,c[aU+(aS*12|0)+8>>2]|0);a5=E+1|0;a6=c[aX>>2]|0}aU=aS+1|0;if(aU>>>0<a6>>>0){aS=aU;E=a5;a_=a6}else{break}}}iU(a0)}}while(0);a[9534176]=a1&1;a[9534184]=a$&1;a[9534168]=a3&1}if((c[2368521]|0)!=0){a3=a[9533447]|0;if((a3&1)==0){a$=gA[c[(c[2383356]|0)+12>>2]&16383](c[2383359]|0,52)|0;a1=9533608;a7=(c[a1>>2]&0|a$&1|0)!=0|(c[a1+4>>2]&1048576|0)!=0;a8=a[9533447]|0}else{a7=0;a8=a3}if((a8&1)==0){a8=gA[c[(c[2383356]|0)+12>>2]&16383](c[2383359]|0,53)|0;a3=9533608;a9=(c[a3>>2]&0|a8&1|0)!=0|(c[a3+4>>2]&2097152|0)!=0}else{a9=0}do{if(a7){if((a[9534160]&1)!=0){n=1116;break}hg((gD[c[2368518]&8191]()|0)^1,1)}else{n=1116}}while(0);do{if((n|0)==1116){if(!a9){break}if((a[9534152]&1)!=0){break}a3=gD[c[2368521]&8191]()|0;a8=gD[c[2368519]&8191]()|0;if((a3|0)==(-1|0)|(a3|0)==0){a1=c[u>>2]|0;cj(135656,59,1,a1|0)|0;eY(a1|0)|0;break}if(a8>>>0<a3>>>0){ba=((a8+1|0)>>>0)%((a3+1|0)>>>0)|0}else{ba=0}hh(ba)}}while(0);a[9534160]=a7&1;a[9534152]=a9&1}do{if((a[9533447]&1)==0){a9=gA[c[(c[2383356]|0)+12>>2]&16383](c[2383359]|0,37)|0;a7=9533608;if((c[a7>>2]&0|a9&1|0)==0&(c[a7+4>>2]&32|0)==0){bb=0;break}if((a[9534064]&1)!=0){bb=1;break}if((a[9375104]&1)!=0){a7=c[u>>2]|0;cj(431624,27,1,a7|0)|0;eY(a7|0)|0}a7=c[2380901]|0;a9=a7+4|0;ba=c[a9>>2]|0;if(ba>>>0>1){n=a7|0;a3=1;a8=ba;while(1){ba=c[(c[n>>2]|0)+(a3<<2)>>2]|0;if((ba|0)==0){bc=a8}else{gGr(c[ba+8>>2]|0);gGr(c[(c[n>>2]|0)+(a3<<2)>>2]|0);c[(c[n>>2]|0)+(a3<<2)>>2]=0;bc=c[a9>>2]|0}ba=a3+1|0;if(ba>>>0<bc>>>0){a3=ba;a8=bc}else{break}}}c[a9>>2]=1;a8=a7+12|0;gGr(c[a8>>2]|0);c[a8>>2]=0;a8=c[2380901]|0;a3=a8+4|0;L1589:do{if((c[a3>>2]|0)>>>0<(c[a8+8>>2]|0)>>>0){n=gGq(12)|0;do{if((n|0)!=0){if((c[n-4>>2]&3|0)==0){break}gGz(n|0,0,12)}}while(0);c[n+4>>2]=1;c[n>>2]=120;f=bG(421080)|0;a0=c[a3>>2]|0;c[n+8>>2]=f;f=a8|0;c[(c[f>>2]|0)+(a0<<2)>>2]=n;a0=c[a3>>2]|0;c[a3>>2]=a0+1;if(a0>>>0>1){bd=a0}else{break}while(1){a0=bd>>>1;ba=c[f>>2]|0;a1=ba+(a0<<2)|0;a$=c[a1>>2]|0;a6=c[ba+(bd<<2)>>2]|0;if((c[a6+4>>2]|0)>>>0<=(c[a$+4>>2]|0)>>>0){break L1589}c[a1>>2]=a6;c[(c[f>>2]|0)+(bd<<2)>>2]=a$;if(bd>>>0>3){bd=a0}else{break}}}}while(0);gu[c[2112850]&16383]();hf();bb=1}else{bb=0}}while(0);a[9534064]=bb;i=d;return}function hm(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=i;i=i+4096|0;d=b|0;L1602:do{if((a[9531830]&1)!=0){switch(c[2344802]|0){case 1:{e=a[9375104]|0;if((e&1)==0){f=e}else{e=c[u>>2]|0;cj(158104,32,1,e|0)|0;eY(e|0)|0;f=a[9375104]|0}if((f&1)==0){g=f}else{e=c[u>>2]|0;bU(e|0,165104,(h=i,i=i+8|0,c[h>>2]=9416090,h)|0)|0;i=h;eY(e|0)|0;g=a[9375104]|0}if((g&1)!=0){e=c[u>>2]|0;bU(e|0,161960,(h=i,i=i+8|0,c[h>>2]=9420186,h)|0)|0;i=h;eY(e|0)|0}hu(9416090,1280);hu(9420186,1537);break L1602;break};case 2:case 3:{e=a[9375104]|0;if((e&1)==0){j=e}else{e=c[u>>2]|0;cj(155192,30,1,e|0)|0;eY(e|0)|0;j=a[9375104]|0}if((j&1)==0){k=j}else{e=c[u>>2]|0;bU(e|0,151080,(h=i,i=i+8|0,c[h>>2]=9416090,h)|0)|0;i=h;eY(e|0)|0;k=a[9375104]|0}if((k&1)!=0){e=c[u>>2]|0;bU(e|0,147992,(h=i,i=i+8|0,c[h>>2]=9424282,h)|0)|0;i=h;eY(e|0)|0}hu(9416090,256);hu(9424282,512);break L1602;break};case 4:{e=a[9375104]|0;if((e&1)==0){l=e}else{e=c[u>>2]|0;cj(143664,40,1,e|0)|0;eY(e|0)|0;l=a[9375104]|0}if((l&1)==0){m=l}else{e=c[u>>2]|0;bU(e|0,140840,(h=i,i=i+8|0,c[h>>2]=9428378,h)|0)|0;i=h;eY(e|0)|0;m=a[9375104]|0}if((m&1)!=0){e=c[u>>2]|0;bU(e|0,138248,(h=i,i=i+8|0,c[h>>2]=9432474,h)|0)|0;i=h;eY(e|0)|0}hu(9428378,768);hu(9432474,1024);break L1602;break};case 0:{e=a[9375104]|0;if((e&1)==0){n=e}else{e=c[u>>2]|0;cj(168064,32,1,e|0)|0;eY(e|0)|0;n=a[9375104]|0}if((n&1)==0){o=n}else{e=c[u>>2]|0;bU(e|0,165104,(h=i,i=i+8|0,c[h>>2]=9416090,h)|0)|0;i=h;eY(e|0)|0;o=a[9375104]|0}if((o&1)!=0){e=c[u>>2]|0;bU(e|0,161960,(h=i,i=i+8|0,c[h>>2]=9420186,h)|0)|0;i=h;eY(e|0)|0}hu(9416090,0);hu(9420186,1);break L1602;break};default:{break L1602}}}}while(0);o=c[2380903]|0;if((o|0)!=0){gGr(c[o>>2]|0);gGr(c[o+12>>2]|0);gGr(o)}c[2380903]=0;gGr(c[2380904]|0);c[2380904]=0;o=c[2383008]|0;if((o|0)!=0){iT(o)}o=c[2380907]|0;if((o|0)!=0){n=c[o>>2]|0;if((n|0)!=0){aY(n|0)|0}gGr(c[o+24>>2]|0);gGr(c[o+4>>2]|0);gGr(o)}do{if((a[9533305]&1)==0){if((a[9533304]&1)!=0){break}o=d|0;if((a[9365858]&1)==0){break}hG(o,9436570,183464);n=hs(o)|0;if((a[9375104]&1)==0){break}m=c[u>>2]|0;l=n?175160:171344;bU(m|0,178584,(h=i,i=i+16|0,c[h>>2]=o,c[h+8>>2]=l,h)|0)|0;i=h;eY(m|0)|0}}while(0);hV();d=c[2368532]|0;do{if((d|0)!=0){if((a[9533441]&1)!=0){break}gu[d&16383]()}}while(0);hW();if((a[9533443]&1)!=0){c[2383358]=0}if((a[9533444]&1)!=0){c[2383357]=0}if((a[9533445]&1)!=0){c[2383359]=0}a[9533443]=0;a[9533444]=0;a[9533445]=0;gu[c[2112828]&16383]();gu[c[2112868]&16383]();d=c[2368540]|0;if((d|0)!=0){m=d+4104|0;if((c[m>>2]|0)==0){p=d|0}else{l=d+4100|0;o=d|0;n=0;while(1){k=c[l>>2]|0;h0(c[o>>2]|0,c[k+(n<<4)+4>>2]|0,c[(c[c[k+(n<<4)+8>>2]>>2]|0)+(c[k+(n<<4)+12>>2]<<3)>>2]|0);k=n+1|0;if(k>>>0<(c[m>>2]|0)>>>0){n=k}else{p=o;break}}}o=c[p>>2]|0;p=d+4|0;h1(o,p)|0;iL(c[2368540]|0)}gGz(9469368,0,4800);if((a[9375108]&1)==0){a[9532116]=0;i=b;return}if((a[9375104]&1)!=0){p=c[u>>2]|0;bU(p|0,235544,(h=i,i=i+8|0,c[h>>2]=9375109,h)|0)|0;i=h;eY(p|0)|0}if((dR(9375109)|0)<0){p=c[u>>2]|0;bU(p|0,229072,(h=i,i=i+8|0,c[h>>2]=9375109,h)|0)|0;i=h;eY(p|0)|0}a[9375108]=0;a[9532116]=0;i=b;return}function hn(a,d){a=a|0;d=d|0;var e=0;e=(c[2368556]|0)-1|0;c[2368556]=e;b[(c[2368555]|0)+(e<<1)>>1]=d;d=(c[2368556]|0)-1|0;c[2368556]=d;b[(c[2368555]|0)+(d<<1)>>1]=a;return}function ho(d,e){d=d|0;e=e|0;var f=0,g=0;f=c[2368545]|0;c[2368545]=f+1;b[(c[2368554]|0)+(f<<1)>>1]=d;d=c[2368545]|0;c[2368545]=d+1;b[(c[2368554]|0)+(d<<1)>>1]=e;e=c[2368545]|0;if(e>>>0<(c[2368546]|0)>>>0){return}if(g8(c[2368554]|0,e)|0){g=a[9375105]&1}else{g=0}a[9375105]=g;c[2368545]=0;return}function hp(d,f,g,h){d=d|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;j=i;i=i+16|0;k=j|0;l=j+8|0;m=f&255;f=c[2380907]|0;do{if((f|0)!=0){if((a[9527728]&1)==0){break}if((ew(l|0,2,1,c[f>>2]|0)|0)!=1){a[9531827]=1;break}n=b[l>>1]|0;i=j;return n|0}}while(0);if(h>>>0<25|(m|0)==3){o=gh[c[(c[2383356]|0)+8>>2]&15](c[2383359]|0,46064,d,m,g,h)|0}else{o=0}l=(m|0)==1;f=(d|0)==0;do{if(l&f){p=9533608;q=c[p>>2]|0;r=c[p+4>>2]|0;p=gGM(1,0,h|0)|0;s=((q&p|0)!=0|(r&K|0)!=0)&1|o}else{if(!((m|0)==5&f)){s=o;break}s=(b[9533616+(((h|0)==1|((g|0)==1?2:0))<<1)>>1]|0)+o&65535}}while(0);do{if(l){if((h-4|0)>>>0<=3){t=s;break}if(s<<16>>16==0){o=9531842+(d<<1)|0;b[o>>1]=(e[o>>1]|0)&(1<<h^65535)&65535;t=0;break}if((a[9531834+d|0]&1)==0){u=b[9531842+(d<<1)>>1]|0;v=1<<h}else{o=1<<h;g=9531842+(d<<1)|0;f=(e[g>>1]|0|o)&65535;b[g>>1]=f;u=f;v=o}if((u&65535&v|0)==0){t=1;break}t=(((c[2382965]|0)>>>0)%((c[2331212]|0)>>>0)|0)>>>0<(c[2331213]|0)>>>0|0}else{t=s}}while(0);s=c[2380907]|0;if((s|0)==0){n=t;i=j;return n|0}if((a[9527728]&1)!=0){n=t;i=j;return n|0}b[k>>1]=t;cj(k|0,2,1,c[s>>2]|0)|0;n=t;i=j;return n|0}function hq(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;if((a[9532117]&1)==0){d=c[u>>2]|0;bU(d|0,547632,(e=i,i=i+16|0,c[e>>2]=504696,c[e+8>>2]=729,e)|0)|0;i=e;eY(d|0)|0;fm(2)}else{f=1024;g=9532119;h=b}while(1){b=f-1|0;if((b|0)==0){break}d=a[h]|0;a[g]=d;if(d<<24>>24==0){j=1258;break}else{f=b;g=g+1|0;h=h+1|0}}if((j|0)==1258){eM(9533144,1)}a[g]=0;if((a[h]|0)==0){eM(9533144,1)}else{k=h}do{k=k+1|0;}while((a[k]|0)!=0);eM(9533144,1)}function hr(){var a=0,b=0,d=0;a=i;el(446184)|0;el(445240)|0;b=c[s>>2]|0;cj(572264,11,1,b|0)|0;bU(b|0,569712,(d=i,i=i+16|0,c[d>>2]=568240,c[d+8>>2]=32,d)|0)|0;i=d;bU(b|0,565840,(d=i,i=i+8|0,c[d>>2]=563680,d)|0)|0;i=d;el(446184)|0;el(444448)|0;el(443600)|0;el(442728)|0;el(441296)|0;el(439728)|0;el(438280)|0;el(436624)|0;el(435128)|0;el(434e3)|0;el(433376)|0;el(432408)|0;el(431544)|0;el(430800)|0;el(429568)|0;el(428544)|0;el(427408)|0;bw(426e3,(d=i,i=i+8|0,c[d>>2]=8,d)|0)|0;i=d;bw(424760,(d=i,i=i+8|0,c[d>>2]=8,d)|0)|0;i=d;bw(423696,(d=i,i=i+8|0,c[d>>2]=8,d)|0)|0;i=d;el(422800)|0;el(421888)|0;el(420984)|0;el(419752)|0;el(418296)|0;el(417240)|0;el(415504)|0;el(413600)|0;el(411952)|0;el(410688)|0;el(409608)|0;el(408824)|0;el(408128)|0;el(407528)|0;el(406456)|0;el(405176)|0;i=a;return}function hs(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;d=i;if((a[9375104]&1)!=0){e=c[u>>2]|0;bU(e|0,382672,(f=i,i=i+8|0,c[f>>2]=b,f)|0)|0;i=f;eY(e|0)|0}e=gD[c[2112844]&8191]()|0;if((e|0)==0){g=0;i=d;return g|0}h=gGq(e)|0;if((h|0)==0){j=c[u>>2]|0;cj(545360,70,1,j|0)|0;eY(j|0)|0;g=0;i=d;return g|0}if((a[9375104]&1)!=0){j=c[u>>2]|0;bU(j|0,424096,(f=i,i=i+8|0,c[f>>2]=e,f)|0)|0;i=f;eY(j|0)|0}do{if(gA[c[2112846]&16383](h,e)|0){j=fw(b|0,389440)|0;if((j|0)==0){k=1270;break}l=(cj(h|0,1,e|0,j|0)|0)==(e|0);aY(j|0)|0;if(l){m=1}else{k=1270}}else{k=1270}}while(0);if((k|0)==1270){k=c[u>>2]|0;bU(k|0,329024,(f=i,i=i+8|0,c[f>>2]=b,f)|0)|0;i=f;eY(k|0)|0;m=0}gGr(h);g=m;i=d;return g|0}function ht(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,v=0,w=0,x=0,y=0,z=0,A=0;d=i;i=i+16|0;e=d|0;f=d+8|0;c[e>>2]=0;g=hx(b,e)|0;if((a[9375104]&1)!=0){h=c[u>>2]|0;bU(h|0,250544,(j=i,i=i+8|0,c[j>>2]=b,j)|0)|0;i=j;eY(h|0)|0}if((g|0)<0){h=c[u>>2]|0;bU(h|0,196144,(j=i,i=i+8|0,c[j>>2]=b,j)|0)|0;i=j;eY(h|0)|0;k=0;i=d;return k|0}if((a[9375104]&1)!=0){h=c[u>>2]|0;bU(h|0,156128,(j=i,i=i+8|0,c[j>>2]=g,j)|0)|0;i=j;eY(h|0)|0}c[f>>2]=0;L1788:do{if((a[9365856]&1)==0){l=1293}else{if((a[9375104]&1)!=0){h=c[u>>2]|0;cj(125840,36,1,h|0)|0;eY(h|0)|0}switch(c[2344802]|0){case 1:{m=1280;n=1537;break};case 0:{m=0;n=1;break};case 2:case 3:{m=256;n=512;break};case 4:{m=768;n=1024;break};default:{l=1293;break L1788}}h=gj[c[2112864]&4095](m)|0;j=gj[c[2112864]&4095](n)|0;if((h|0)==0){o=0;p=0}else{o=gGq(h)|0;p=h}if((j|0)==0){q=0;r=0}else{h=gGq(j)|0;c[f>>2]=h;q=h;r=j}do{if((o|0)!=0){j=gj[c[2112866]&4095](m)|0;if((j|0)==0){break}gGC(o|0,j|0,p)|0}}while(0);j=f;if((q|0)==0){s=0;t=r;v=m;w=n;x=p;y=o;z=j;break}h=gj[c[2112866]&4095](n)|0;if((h|0)==0){s=q;t=r;v=m;w=n;x=p;y=o;z=j;break}gGC(q|0,h|0,r)|0;s=q;t=r;v=m;w=n;x=p;y=o;z=j}}while(0);if((l|0)==1293){s=0;t=0;v=-1;w=-1;x=0;y=0;z=f}f=c[e>>2]|0;e=gA[c[2112826]&16383](f,g)|0;do{if(e){do{if((y|0)!=0){g=gj[c[2112866]&4095](v)|0;if((g|0)==0){break}gGC(g|0,y|0,x)|0}}while(0);if((s|0)==0){break}g=gj[c[2112866]&4095](w)|0;if((g|0)==0){break}gGC(g|0,s|0,t)|0}}while(0);if((y|0)==0){A=s}else{gGr(y);A=c[z>>2]|0}if((A|0)!=0){gGr(A)}gGr(f);k=e;i=d;return k|0}function hu(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;e=i;i=i+8200|0;f=e|0;g=e+4096|0;h=e+8192|0;j=gj[c[2112864]&4095](d)|0;k=gj[c[2112866]&4095](d)|0;if((k|0)==0|(j|0)==0){i=e;return}l=fw(b|0,389440)|0;do{if((l|0)!=0){m=(cj(k|0,1,j|0,l|0)|0)==(j|0);aY(l|0)|0;if(!m){break}if((a[9375104]&1)==0){i=e;return}m=c[u>>2]|0;bU(m|0,568592,(n=i,i=i+8|0,c[n>>2]=b,n)|0)|0;i=n;eY(m|0)|0;i=e;return}}while(0);b=c[u>>2]|0;cj(78176,42,1,b|0)|0;eY(b|0)|0;cj(585080,46,1,b|0)|0;eY(b|0)|0;l=f|0;m=g|0;g=fE(488528)|0;do{if((g|0)!=0){be(l|0,4096,314824,(n=i,i=i+8|0,c[n>>2]=g,n)|0)|0;i=n;gb(h|0)|0;o=a5(h|0)|0;ed(m|0,4096,306136,o|0)|0;o=gGy(l|0)|0;p=o>>>0>4096?0:4096-o|0;L1843:do{if((p|0)==0){q=m;r=1324}else{s=p;t=f+o|0;v=m;while(1){w=s-1|0;if((w|0)==0){break}x=a[v]|0;a[t]=x;if(x<<24>>24==0){break L1843}else{s=w;t=t+1|0;v=v+1|0}}a[t]=0;q=v;r=1324}}while(0);do{if((r|0)==1324){if((a[q]|0)==0){break}else{y=q}do{y=y+1|0;}while((a[y]|0)!=0)}}while(0);switch(d|0){case 1:case 1537:{z=277512;break};case 512:{z=270208;break};case 768:{z=262904;break};case 1024:{z=254360;break};case 0:case 1280:case 256:{z=568864;break};default:{z=9534384}}v=gGy(l|0)|0;t=v>>>0>4096?0:4096-v|0;L1861:do{if((t|0)==0){A=z;r=1337}else{o=t;p=f+v|0;s=z;while(1){w=o-1|0;if((w|0)==0){break}x=a[s]|0;a[p]=x;if(x<<24>>24==0){break L1861}else{o=w;p=p+1|0;s=s+1|0}}a[p]=0;A=s;r=1337}}while(0);do{if((r|0)==1337){if((a[A]|0)==0){break}else{B=A}do{B=B+1|0;}while((a[B]|0)!=0)}}while(0);s=fw(l|0,389440)|0;if((s|0)==0){break}p=(cj(k|0,1,j|0,s|0)|0)==(j|0);aY(s|0)|0;if(!p){break}bU(b|0,298088,(n=i,i=i+8|0,c[n>>2]=l,n)|0)|0;i=n;eY(b|0)|0;i=e;return}}while(0);cj(290728,57,1,b|0)|0;eY(b|0)|0;i=e;return}function hv(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,v=0,w=0,x=0,y=0,z=0,A=0;d=i;i=i+48|0;e=d|0;f=d+16|0;g=d+32|0;h=d+40|0;L1878:do{if((a[9411994]|0)!=0){if((a[9469444]&1)!=0){break}j=cE(9411994,47)|0;k=cE(((j|0)==0?9411994:j+1|0)|0,46)|0;j=(k|0)==0?9534384:k+1|0;if((j|0)==0){break}if((gGF(j|0,104560)|0)!=0){break}a[9375108]=1;j=e;c[j>>2]=c[2];c[j+4>>2]=c[3];c[j+8>>2]=c[4];c[j+12>>2]=c[5];k=hA(9469960,256984)|0;do{if((k|0)==0){l=c[u>>2]|0;bU(l|0,557312,(m=i,i=i+8|0,c[m>>2]=372,m)|0)|0;i=m;eY(l|0)|0;n=l}else{c[e>>2]=9411994;c[e+4>>2]=4096;c[e+8>>2]=k;do{if(k8(9411994,6,j)|0){if((a[e+12|0]&1)!=0){o=1;break}l=c[u>>2]|0;cj(158176,101,1,l|0)|0;eY(l|0)|0;bU(l|0,557312,(m=i,i=i+8|0,c[m>>2]=387,m)|0)|0;i=m;eY(l|0)|0;o=0}else{l=c[u>>2]|0;cj(200536,41,1,l|0)|0;eY(l|0)|0;bU(l|0,557312,(m=i,i=i+8|0,c[m>>2]=381,m)|0)|0;i=m;eY(l|0)|0;o=0}}while(0);l=k+4|0;p=k|0;q=c[p>>2]|0;if((c[l>>2]|0)==0){r=q}else{s=0;t=q;while(1){gGr(c[t+(s<<3)>>2]|0);q=s+1|0;v=c[p>>2]|0;if(q>>>0<(c[l>>2]|0)>>>0){s=q;t=v}else{r=v;break}}}gGr(r);gGr(k);if(o){w=4096;x=9375109;y=9411994}else{n=c[u>>2]|0;break}while(1){t=w-1|0;if((t|0)==0){break}s=a[y]|0;a[x]=s;if(s<<24>>24==0){break L1878}else{w=t;x=x+1|0;y=y+1|0}}a[x]=0;if((a[y]|0)==0){break L1878}else{z=y}while(1){z=z+1|0;if((a[z]|0)==0){break L1878}}}}while(0);bU(n|0,537848,(m=i,i=i+8|0,c[m>>2]=9411994,m)|0)|0;i=m;eY(n|0)|0;a[9375108]=0;A=0;i=d;return A|0}}while(0);L1906:do{switch(b|0){case 1:{n=h|0;c[n>>2]=(a[9411994]|0)!=0?9411994:0;c[h+4>>2]=9379216;if(hw(260,n,2)|0){break L1906}else{A=0}i=d;return A|0};case 0:{if((a[9533304]&1)==0){c[g>>2]=9411994;if(hw(0,g,1)|0){break L1906}else{A=0}i=d;return A|0}if((a[9469446]&1)==0){n=c[u>>2]|0;cj(332440,78,1,n|0)|0;eY(n|0)|0;A=0;i=d;return A|0}else{if(gj[c[2112854]&4095](0)|0){break L1906}else{A=0}i=d;return A|0}break};case 2:{n=h|0;c[n>>2]=(a[9411994]|0)!=0?9411994:0;c[h+4>>2]=9383312;if(hw(257,n,2)|0){break L1906}else{A=0}i=d;return A|0};case 3:{n=h|0;c[n>>2]=(a[9411994]|0)!=0?9411994:0;c[h+4>>2]=9383312;if(hw(258,n,2)|0){break L1906}else{A=0}i=d;return A|0};case 4:{n=f|0;c[n>>2]=(a[9411994]|0)!=0?9411994:0;c[f+4>>2]=(a[9387408]|0)!=0?9387408:0;c[f+8>>2]=(a[9391504]|0)!=0?9391504:0;if(hw(259,n,3)|0){break L1906}else{A=0}i=d;return A|0};default:{n=c[u>>2]|0;cj(524520,39,1,n|0)|0;eY(n|0)|0;A=0;i=d;return A|0}}}while(0);A=1;i=d;return A|0}function hw(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0;g=i;i=i+520|0;h=g|0;j=g+368|0;k=g+400|0;l=g+408|0;m=g+416|0;n=g+424|0;o=g+440|0;p=g+456|0;if((f|0)==0|f>>>0>4){q=0;i=g;return q|0}gGz(n|0,0,16);gGz(o|0,0,16);gGz(p|0,0,64);do{if((a[9440666]|0)==0){r=0}else{s=fw(9440666,68376)|0;if((s|0)==0){r=0;break}dh(s|0,0,2)|0;t=(fl(s|0)|0)+2|0;b4(s|0);v=(t|0)==0?0:t;w=gGq(v)|0;if((w|0)==0){aY(s|0)|0;r=0;break}if((c[w-4>>2]&3|0)!=0){gGz(w|0,0,v|0)}v=w;x=w;while(1){if((b0(s|0)|0)!=0){y=x;break}fh(x|0,t-x+v|0,s|0)|0;z=x+(gGy(x|0)|0)|0;if((z|0)==0){y=0;break}else{x=z}}x=d0(y|0,-1|0)|0;if((x|0)!=0){a[x]=0}aY(s|0)|0;if((a[9375104]&1)==0){r=w;break}x=c[u>>2]|0;bU(x|0,340376,(A=i,i=i+8|0,c[A>>2]=9440666,A)|0)|0;i=A;eY(x|0)|0;r=w}}while(0);y=(a[9375104]&1)!=0;do{if((a[9469380]&1)==0){if(y){x=c[u>>2]|0;v=c[e>>2]|0;bU(x|0,510760,(A=i,i=i+8|0,c[A>>2]=v,A)|0)|0;i=A;eY(x|0)|0}x=c[e>>2]|0;v=n|0;c[m>>2]=0;t=hx(x,m)|0;if((t|0)<1){B=t;C=0}else{L1960:do{if((a[9457050]&1)==0){x=c[m>>2]|0;c[k>>2]=0;z=a[9457051]|0;D=a[9457052]|0;E=a[9457053]|0;if(((D&1)+(z&1)+(E&1)|0)>1){F=c[u>>2]|0;cj(428728,77,1,F|0)|0;eY(F|0)|0;G=t;H=x;break}F=(E|z)&1;I=((D|z)&1)!=0;if(((E|D)&1)!=0|(a[9457054]|0)==0){J=1417}else{D=hx(9457054,k)|0;if((D|0)>-1){K=417384;L=9457054;M=8;N=D}else{J=1417}}do{if((J|0)==1417){if(!(F<<24>>24!=0|(a[9461150]|0)==0)){D=hx(9461150,k)|0;if((D|0)>-1){K=405352;L=9461150;M=2;N=D;break}}if(!(I|(a[9465246]|0)==0)){D=hx(9465246,k)|0;if((D|0)>-1){K=394488;L=9465246;M=4;N=D;break}}if((a[9375104]&1)==0){G=t;H=x;break L1960}D=c[u>>2]|0;cj(382792,43,1,D|0)|0;eY(D|0)|0;G=t;H=x;break L1960}}while(0);if((a[9375104]&1)!=0){I=c[u>>2]|0;bU(I|0,372960,(A=i,i=i+16|0,c[A>>2]=K,c[A+8>>2]=L,A)|0)|0;i=A;eY(I|0)|0}I=t<<2;c[l>>2]=I;F=gGq(I)|0;if((F|0)==0){I=c[u>>2]|0;cj(363336,67,1,I|0)|0;eY(I|0)|0;c[m>>2]=x;gGr(c[k>>2]|0);G=t;H=x;break}I=c[k>>2]|0;D=gh[M&15](I,N,x,t,F,l)|0;if((D|0)==1){if((a[9375104]&1)!=0){E=c[u>>2]|0;bU(E|0,356264,(A=i,i=i+8|0,c[A>>2]=K,A)|0)|0;i=A;eY(E|0)|0}gGr(x);c[m>>2]=F;O=c[l>>2]|0;P=F}else{F=c[u>>2]|0;bU(F|0,348048,(A=i,i=i+16|0,c[A>>2]=K,c[A+8>>2]=D,A)|0)|0;i=A;eY(F|0)|0;O=t;P=x}gGr(I);G=O;H=P}else{G=t;H=c[m>>2]|0}}while(0);c[2344803]=RK(0,H,G)|0;t=h;gGz(t|0,0,360);w=h+324|0;gGC(w|0,7461472,32)|0;w=h+360|0;c[w>>2]=G;c[w+4>>2]=0;s=h+64|0;if((G|0)==0){Q=0}else{I=G;F=H;D=0;while(1){E=64-D|0;z=I>>>0<E>>>0?I:E;E=t+D|0;gGC(E|0,F|0,z)|0;E=z+(c[s>>2]|0)|0;c[s>>2]=E;if((E|0)==64){h5(h);R=c[s>>2]|0}else{R=E}if((I|0)==(z|0)){Q=R;break}else{I=I-z|0;F=F+z|0;D=R}}}c[s>>2]=Q+1;a[h+Q|0]=-128;D=c[s>>2]|0;if(D>>>0>56){gGz(t+D|0,0,64-D|0);h5(h);S=c[s>>2]|0}else{S=D}gGz(t+S|0,0,56-S|0);D=c[w>>2]|0;c[h+56>>2]=c9(D>>>29|c[w+4>>2]<<3|0)|0;c[h+60>>2]=c9(D<<3|0>>>29|0)|0;h5(h);c[j>>2]=c9(c[h+324>>2]|0)|0;c[j+4>>2]=c9(c[h+328>>2]|0)|0;c[j+8>>2]=c9(c[h+332>>2]|0)|0;c[j+12>>2]=c9(c[h+336>>2]|0)|0;c[j+16>>2]=c9(c[h+340>>2]|0)|0;c[j+20>>2]=c9(c[h+344>>2]|0)|0;c[j+24>>2]=c9(c[h+348>>2]|0)|0;c[j+28>>2]=c9(c[h+352>>2]|0)|0;D=j;F=0;do{be(9531964+(F<<1)|0,3,140832,(A=i,i=i+8|0,c[A>>2]=d[D+F|0]|0,A)|0)|0;i=A;F=F+1|0;}while(F>>>0<32);if((a[9375104]&1)!=0){F=c[u>>2]|0;D=c[2344803]|0;bU(F|0,439872,(A=i,i=i+16|0,c[A>>2]=D,c[A+8>>2]=9531964,A)|0)|0;i=A;eY(F|0)|0}c[v>>2]=H;B=G;C=H}c[o>>2]=B;if((B|0)==-1){F=c[u>>2]|0;cj(498176,46,1,F|0)|0;eY(F|0)|0;T=0;break}if((a[9375104]&1)==0){U=B;V=C;J=1450;break}F=c[u>>2]|0;bU(F|0,486296,(A=i,i=i+8|0,c[A>>2]=B,A)|0)|0;i=A;eY(F|0)|0;U=B;V=C;J=1450}else{if(!y){U=0;V=0;J=1450;break}F=c[u>>2]|0;cj(473440,72,1,F|0)|0;eY(F|0)|0;U=0;V=0;J=1450}}while(0);L2013:do{if((J|0)==1450){y=p|0;c[p>>2]=c[e>>2];c[p+4>>2]=V;c[p+8>>2]=U;c[p+12>>2]=r;L2015:do{if(f>>>0>1){C=1;L2016:while(1){W=e+(C<<2)|0;B=c[W>>2]|0;do{if((B|0)==0){X=0}else{if((a[9469380]&1)!=0){X=B;break}H=hx(B,n+(C<<2)|0)|0;c[o+(C<<2)>>2]=H;if((H|0)==-1){break L2016}X=c[W>>2]|0}}while(0);c[p+(C<<4)>>2]=X;c[p+(C<<4)+4>>2]=c[n+(C<<2)>>2];c[p+(C<<4)+8>>2]=c[o+(C<<2)>>2];C=C+1|0;if(C>>>0>=f>>>0){break L2015}}C=c[u>>2]|0;bU(C|0,462096,(A=i,i=i+8|0,c[A>>2]=c[W>>2],A)|0)|0;i=A;eY(C|0)|0;T=0;break L2013}}while(0);if((b|0)==0){if(gj[c[2112854]&4095](y)|0){T=1;break}}else{if(gp[c[2112852]&16383](b,y,f)|0){T=1;break}}v=c[u>>2]|0;cj(451128,42,1,v|0)|0;eY(v|0)|0;T=0}}while(0);gGr(c[n>>2]|0);gGr(c[n+4>>2]|0);gGr(c[n+8>>2]|0);gGr(c[n+12>>2]|0);gGr(r);q=T;i=g;return q|0}function hx(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=fw(b|0,364392)|0;do{if((e|0)!=0){dh(e|0,0,2)|0;b=fl(e|0)|0;b4(e|0);f=gGq(b+1|0)|0;if((f|0)==0){g=c[u>>2]|0;cj(418424,47,1,g|0)|0;eY(g|0)|0;aY(e|0)|0;break}g=ew(f|0,1,b|0,e|0)|0;if((g|0)<(b|0)){h=c[u>>2]|0;cj(324328,44,1,h|0)|0;eY(h|0)|0}c[d>>2]=f;a[f+b|0]=0;aY(e|0)|0;i=g;return i|0}}while(0);c[d>>2]=0;i=-1;return i|0}function hy(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;a=i;b=gGq(12)|0;if((b|0)==0){d=0;i=a;return d|0}do{if((c[b-4>>2]&3|0)==0){e=c[b+4>>2]|0;if(e>>>0<32){f=e;g=b;break}e=c[u>>2]|0;bU(e|0,547632,(h=i,i=i+16|0,c[h>>2]=551256,c[h+8>>2]=168,h)|0)|0;i=h;eY(e|0)|0;fm(2);return 0}else{gGz(b|0,0,12);f=0;g=b}}while(0);e=b;h=c[e>>2]|0;j=h;k=gGs(j,256)|0;if((k|0)!=0){c[e>>2]=k;c[b+8>>2]=32;d=g;i=a;return d|0}if((f|0)!=0){g=0;do{gGr(c[h+(g<<3)>>2]|0);g=g+1|0;}while(g>>>0<f>>>0)}gGr(j);gGr(b);d=0;i=a;return d|0}function hz(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;e=i;f=a+4|0;g=c[f>>2]|0;h=a+8|0;j=c[h>>2]|0;do{if(g>>>0>=j>>>0){k=j<<1;if(g>>>0>=k>>>0){l=c[u>>2]|0;bU(l|0,547632,(m=i,i=i+16|0,c[m>>2]=551256,c[m+8>>2]=168,m)|0)|0;i=m;eY(l|0)|0;fm(2);return 0}l=a|0;m=gGs(c[l>>2]|0,j<<4)|0;if((m|0)==0){n=0;i=e;return n|0}else{c[l>>2]=m;c[h>>2]=k;break}}}while(0);h=bG(b|0)|0;if((h|0)==0){n=0;i=e;return n|0}b=a|0;c[(c[b>>2]|0)+(c[f>>2]<<3)>>2]=h;c[(c[b>>2]|0)+(c[f>>2]<<3)+4>>2]=d;c[f>>2]=(c[f>>2]|0)+1;n=1;i=e;return n|0}function hA(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;d=i;i=i+8|0;e=d|0;f=hy()|0;if((f|0)==0){g=0}else{h=bG(a|0)|0;L2078:do{if((h|0)==0){j=0}else{a=de(h|0,b|0,e|0)|0;if((a|0)!=0){k=a;do{if(!(hz(f,k,0)|0)){j=h;break L2078}k=de(0,b|0,e|0)|0;}while((k|0)!=0)}gGr(h);l=f;i=d;return l|0}}while(0);h=c[f+4>>2]|0;e=c[f>>2]|0;if((h|0)!=0){b=0;do{gGr(c[e+(b<<3)>>2]|0);b=b+1|0;}while(b>>>0<h>>>0)}gGr(e);gGr(f);g=j}gGr(g);l=0;i=d;return l|0}function hB(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;e=a[b+4|0]&1;f=a[d+4|0]&1;if(e<<24>>24==f<<24>>24){g=gGF(c[b>>2]|0,c[d>>2]|0)|0;return g|0}else{g=(f&255)-(e&255)|0;return g|0}return 0}function hC(a,b){a=a|0;b=b|0;return gGF(c[a>>2]|0,c[b>>2]|0)|0}function hD(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;f=i;i=i+8272|0;g=f|0;h=f+4096|0;j=f+4176|0;k=hy()|0;if((k|0)==0){l=0;i=f;return l|0}if((d|0)==0){m=0}else{m=hA(d,256984)|0}d=a7(b|0)|0;L2107:do{if((d|0)==0){n=c[u>>2]|0;bU(n|0,584144,(o=i,i=i+8|0,c[o>>2]=b,o)|0)|0;i=o;eY(n|0)|0}else{n=fd(d|0)|0;L2109:do{if((n|0)!=0){p=j|0;q=(m|0)==0;r=g|0;s=m|0;t=m+4|0;v=h+12|0;L2111:do{if(e){w=n;while(1){x=w+11|0;y=cE(x|0,47)|0;z=cE(((y|0)==0?x:y+1|0)|0,46)|0;y=(z|0)==0?9534384:z+1|0;hE(p,b,x);z=a[w+10|0]|0;do{if((z<<24>>24|0)==4){A=1;B=1529}else if((z<<24>>24|0)==0|(z<<24>>24|0)==10){if((f$(p|0,h|0)|0)<0){C=0;break}A=(c[v>>2]&61440|0)==16384;B=1529}else{C=0}}while(0);if((B|0)==1529){B=0;C=A}L2120:do{if((fa(x|0,393632)|0)!=0){if((fa(x|0,77024)|0)==0){break}L2123:do{if(!(C|q)){be(r|0,4096,285248,(o=i,i=i+16|0,c[o>>2]=393632,c[o+8>>2]=y,o)|0)|0;i=o;z=c[t>>2]|0;D=0;while(1){if(D>>>0>=z>>>0){break L2120}E=c[(c[s>>2]|0)+(D<<3)>>2]|0;if((gGF(E|0,y|0)|0)==0){break L2123}if((gGF(E|0,r|0)|0)==0){break}else{D=D+1|0}}}}while(0);if(!(hz(k,p,C&1)|0)){break L2111}}}while(0);w=fd(d|0)|0;if((w|0)==0){break L2109}}}else{w=n;while(1){y=w+11|0;x=cE(y|0,47)|0;D=cE(((x|0)==0?y:x+1|0)|0,46)|0;x=(D|0)==0?9534384:D+1|0;hE(p,b,y);D=a[w+10|0]|0;do{if((D<<24>>24|0)==0|(D<<24>>24|0)==10){if((f$(p|0,h|0)|0)<0){B=1542;break}if((c[v>>2]&61440|0)!=16384){B=1542}}else if((D<<24>>24|0)!=4){B=1542}}while(0);L2136:do{if((B|0)==1542){B=0;if((fa(y|0,393632)|0)==0){break}if((fa(y|0,77024)|0)==0){break}L2140:do{if(!q){be(r|0,4096,285248,(o=i,i=i+16|0,c[o>>2]=393632,c[o+8>>2]=x,o)|0)|0;i=o;D=c[t>>2]|0;z=0;while(1){if(z>>>0>=D>>>0){break L2136}E=c[(c[s>>2]|0)+(z<<3)>>2]|0;if((gGF(E|0,x|0)|0)==0){break L2140}if((gGF(E|0,r|0)|0)==0){break}else{z=z+1|0}}}}while(0);if(!(hz(k,p,0)|0)){break L2111}}}while(0);w=fd(d|0)|0;if((w|0)==0){break L2109}}}}while(0);p=c[u>>2]|0;bU(p|0,584144,(o=i,i=i+8|0,c[o>>2]=b,o)|0)|0;i=o;eY(p|0)|0;f4(d|0)|0;break L2107}}while(0);f4(d|0)|0;if((m|0)==0){l=k;i=f;return l|0}n=m+4|0;p=m|0;r=c[p>>2]|0;if((c[n>>2]|0)==0){F=r}else{s=0;t=r;while(1){gGr(c[t+(s<<3)>>2]|0);r=s+1|0;q=c[p>>2]|0;if(r>>>0<(c[n>>2]|0)>>>0){s=r;t=q}else{F=q;break}}}gGr(F);gGr(m);l=k;i=f;return l|0}}while(0);F=c[k+4>>2]|0;d=c[k>>2]|0;if((F|0)!=0){o=0;do{gGr(c[d+(o<<3)>>2]|0);o=o+1|0;}while(o>>>0<F>>>0)}gGr(d);gGr(k);if((m|0)==0){l=0;i=f;return l|0}k=m+4|0;d=m|0;F=c[d>>2]|0;if((c[k>>2]|0)==0){G=F}else{o=0;b=F;while(1){gGr(c[b+(o<<3)>>2]|0);F=o+1|0;B=c[d>>2]|0;if(F>>>0<(c[k>>2]|0)>>>0){o=F;b=B}else{G=B;break}}}gGr(G);gGr(m);l=0;i=f;return l|0}function hE(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,v=0,w=0;f=i;g=4096;h=0;j=b;k=d;while(1){d=g-1|0;if((d|0)==0){l=1572;break}m=a[k]|0;a[j]=m;if(m<<24>>24==0){n=h;break}else{g=d;h=h+1|0;j=j+1|0;k=k+1|0}}do{if((l|0)==1572){a[j]=0;if((a[k]|0)==0){n=h;break}else{o=k;p=h}while(1){g=o+1|0;d=p+1|0;if((a[g]|0)==0){n=d;break}else{o=g;p=d}}}}while(0);if(n>>>0>=4096){n=c[u>>2]|0;bU(n|0,547632,(q=i,i=i+16|0,c[q>>2]=551256,c[q+8>>2]=735,q)|0)|0;i=q;eY(n|0)|0;fm(2)}if((a[b]|0)!=0){hI(b)}n=gGy(b|0)|0;p=n>>>0>4096?0:4096-n|0;L2187:do{if((p|0)==0){r=0;s=e;l=1583}else{o=p;h=0;k=b+n|0;j=e;while(1){d=o-1|0;if((d|0)==0){break}g=a[j]|0;a[k]=g;if(g<<24>>24==0){t=h;break L2187}else{o=d;h=h+1|0;k=k+1|0;j=j+1|0}}a[k]=0;r=h;s=j;l=1583}}while(0);do{if((l|0)==1583){if((a[s]|0)==0){t=r;break}else{v=s;w=r}while(1){e=v+1|0;b=w+1|0;if((a[e]|0)==0){t=b;break}else{v=e;w=b}}}}while(0);if((t+n|0)>>>0<4096){i=f;return}else{f=c[u>>2]|0;bU(f|0,547632,(q=i,i=i+16|0,c[q>>2]=551256,c[q+8>>2]=740,q)|0)|0;i=q;eY(f|0)|0;fm(2)}}function hF(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;f=i;i=i+4096|0;g=f|0;h=4096;j=0;k=g;l=d;while(1){d=h-1|0;if((d|0)==0){m=1591;break}n=a[l]|0;a[k]=n;if(n<<24>>24==0){o=j;break}else{h=d;j=j+1|0;k=k+1|0;l=l+1|0}}do{if((m|0)==1591){a[k]=0;if((a[l]|0)==0){o=j;break}else{p=l;q=j}while(1){h=p+1|0;d=q+1|0;if((a[h]|0)==0){o=d;break}else{p=h;q=d}}}}while(0);if(o>>>0>=4096){o=c[u>>2]|0;bU(o|0,547632,(r=i,i=i+16|0,c[r>>2]=551256,c[r+8>>2]=518,r)|0)|0;i=r;eY(o|0)|0;fm(2)}o=cE(g|0,47)|0;q=cE(((o|0)==0?g:o+1|0)|0,46)|0;if((q|0)==0){s=4096;t=0;v=b;w=g}else{a[q]=0;s=4096;t=0;v=b;w=g}while(1){g=s-1|0;if((g|0)==0){m=1599;break}q=a[w]|0;a[v]=q;if(q<<24>>24==0){x=t;break}else{s=g;t=t+1|0;v=v+1|0;w=w+1|0}}do{if((m|0)==1599){a[v]=0;if((a[w]|0)==0){x=t;break}else{y=w;z=t}while(1){s=y+1|0;g=z+1|0;if((a[s]|0)==0){x=g;break}else{y=s;z=g}}}}while(0);if(x>>>0>=4096){x=c[u>>2]|0;bU(x|0,547632,(r=i,i=i+16|0,c[r>>2]=551256,c[r+8>>2]=523,r)|0)|0;i=r;eY(x|0)|0;fm(2)}x=gGy(b|0)|0;z=x>>>0>4096?0:4096-x|0;L2226:do{if((z|0)==0){A=0;B=e;m=1608}else{y=z;t=0;w=b+x|0;v=e;while(1){g=y-1|0;if((g|0)==0){break}s=a[v]|0;a[w]=s;if(s<<24>>24==0){C=t;break L2226}else{y=g;t=t+1|0;w=w+1|0;v=v+1|0}}a[w]=0;A=t;B=v;m=1608}}while(0);do{if((m|0)==1608){if((a[B]|0)==0){C=A;break}else{D=B;E=A}while(1){e=D+1|0;b=E+1|0;if((a[e]|0)==0){C=b;break}else{D=e;E=b}}}}while(0);if((C+x|0)>>>0<4096){i=f;return}else{f=c[u>>2]|0;bU(f|0,547632,(r=i,i=i+16|0,c[r>>2]=551256,c[r+8>>2]=524,r)|0)|0;i=r;eY(f|0)|0;fm(2)}}function hG(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,v=0,w=0;f=i;g=4096;h=0;j=b;k=d;while(1){d=g-1|0;if((d|0)==0){l=1616;break}m=a[k]|0;a[j]=m;if(m<<24>>24==0){n=h;break}else{g=d;h=h+1|0;j=j+1|0;k=k+1|0}}do{if((l|0)==1616){a[j]=0;if((a[k]|0)==0){n=h;break}else{o=k;p=h}while(1){g=o+1|0;d=p+1|0;if((a[g]|0)==0){n=d;break}else{o=g;p=d}}}}while(0);if(n>>>0>=4096){n=c[u>>2]|0;bU(n|0,547632,(q=i,i=i+16|0,c[q>>2]=551256,c[q+8>>2]=529,q)|0)|0;i=q;eY(n|0)|0;fm(2)}n=gGy(b|0)|0;p=n>>>0>4096?0:4096-n|0;L2252:do{if((p|0)==0){r=0;s=e;l=1625}else{o=p;h=0;k=b+n|0;j=e;while(1){d=o-1|0;if((d|0)==0){break}g=a[j]|0;a[k]=g;if(g<<24>>24==0){t=h;break L2252}else{o=d;h=h+1|0;k=k+1|0;j=j+1|0}}a[k]=0;r=h;s=j;l=1625}}while(0);do{if((l|0)==1625){if((a[s]|0)==0){t=r;break}else{v=s;w=r}while(1){e=v+1|0;b=w+1|0;if((a[e]|0)==0){t=b;break}else{v=e;w=b}}}}while(0);if((t+n|0)>>>0<4096){i=f;return}else{f=c[u>>2]|0;bU(f|0,547632,(q=i,i=i+16|0,c[q>>2]=551256,c[q+8>>2]=530,q)|0)|0;i=q;eY(f|0)|0;fm(2)}}function hH(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;e=i;hI(b);f=cE(9407898,47)|0;g=(f|0)==0?9407898:f+1|0;f=gGy(b|0)|0;h=f>>>0>4096?0:4096-f|0;L2267:do{if((h|0)==0){j=0;k=g;l=1635}else{m=h;n=0;o=b+f|0;p=g;while(1){q=m-1|0;if((q|0)==0){break}r=a[p]|0;a[o]=r;if(r<<24>>24==0){s=n;break L2267}else{m=q;n=n+1|0;o=o+1|0;p=p+1|0}}a[o]=0;j=n;k=p;l=1635}}while(0);do{if((l|0)==1635){if((a[k]|0)==0){s=j;break}else{t=k;v=j}while(1){g=t+1|0;h=v+1|0;if((a[g]|0)==0){s=h;break}else{t=g;v=h}}}}while(0);if((s+f|0)>>>0>=4096){f=c[u>>2]|0;bU(f|0,547632,(w=i,i=i+16|0,c[w>>2]=551256,c[w+8>>2]=566,w)|0)|0;i=w;eY(f|0)|0;fm(2)}f=gGy(b|0)|0;s=f>>>0>4096?0:4096-f|0;L2281:do{if((s|0)==0){x=0;y=d;l=1644}else{v=s;t=0;j=b+f|0;k=d;while(1){p=v-1|0;if((p|0)==0){break}n=a[k]|0;a[j]=n;if(n<<24>>24==0){z=t;break L2281}else{v=p;t=t+1|0;j=j+1|0;k=k+1|0}}a[j]=0;x=t;y=k;l=1644}}while(0);do{if((l|0)==1644){if((a[y]|0)==0){z=x;break}else{A=y;B=x}while(1){d=A+1|0;b=B+1|0;if((a[d]|0)==0){z=b;break}else{A=d;B=b}}}}while(0);if((z+f|0)>>>0<4096){i=e;return}else{e=c[u>>2]|0;bU(e|0,547632,(w=i,i=i+16|0,c[w>>2]=551256,c[w+8>>2]=567,w)|0)|0;i=w;eY(e|0)|0;fm(2)}}function hI(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;d=i;i=i+8|0;e=d|0;f=cE(b|0,47)|0;g=gGy(b|0)|0;if((f|0)==0){h=g>>>0>4096?0:4096-g|0;L2298:do{if((h|0)==0){j=0;k=571976;l=1664}else{m=b+g|0;do{if((h|0)==1){n=571976;o=m;p=0}else{q=b+(g+1)|0;a[m]=47;if((h|0)==2){n=571977;o=q;p=1;break}a[q]=0;r=1;break L2298}}while(0);a[o]=0;j=p;k=n;l=1664}}while(0);do{if((l|0)==1664){if((a[k]|0)==0){r=j;break}else{s=k;t=j}while(1){n=s+1|0;p=t+1|0;if((a[n]|0)==0){r=p;break}else{s=n;t=p}}}}while(0);if((r+g|0)>>>0<4096){i=d;return}else{r=c[u>>2]|0;bU(r|0,547632,(v=i,i=i+16|0,c[v>>2]=551256,c[v+8>>2]=559,v)|0)|0;i=v;eY(r|0)|0;fm(2)}}if((f|0)==(b+(g-1)|0)){i=d;return}g=e|0;r=a[f]|0;a[g]=r;a[e+1|0]=0;e=gGy(b|0)|0;f=e>>>0>4096?0:4096-e|0;L2316:do{if((f|0)==0){w=0;x=g;y=r;l=1656}else{t=f;s=0;j=b+e|0;k=g;while(1){p=t-1|0;if((p|0)==0){break}n=a[k]|0;a[j]=n;if(n<<24>>24==0){z=s;break L2316}else{t=p;s=s+1|0;j=j+1|0;k=k+1|0}}a[j]=0;w=s;x=k;y=a[k]|0;l=1656}}while(0);do{if((l|0)==1656){if(y<<24>>24==0){z=w;break}else{A=x;B=w}while(1){g=A+1|0;b=B+1|0;if((a[g]|0)==0){z=b;break}else{A=g;B=b}}}}while(0);if((z+e|0)>>>0<4096){i=d;return}else{d=c[u>>2]|0;bU(d|0,547632,(v=i,i=i+16|0,c[v>>2]=551256,c[v+8>>2]=556,v)|0)|0;i=v;eY(d|0)|0;fm(2)}}function hJ(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=i;f=4096;g=0;h=b;j=d;while(1){d=f-1|0;if((d|0)==0){k=1676;break}l=a[j]|0;a[h]=l;if(l<<24>>24==0){m=g;break}else{f=d;g=g+1|0;h=h+1|0;j=j+1|0}}do{if((k|0)==1676){a[h]=0;if((a[j]|0)==0){m=g;break}else{n=j;o=g}while(1){f=n+1|0;d=o+1|0;if((a[f]|0)==0){m=d;break}else{n=f;o=d}}}}while(0);if(m>>>0>=4096){m=c[u>>2]|0;bU(m|0,547632,(p=i,i=i+16|0,c[p>>2]=551256,c[p+8>>2]=584,p)|0)|0;i=p;eY(m|0)|0;fm(2)}if((gGy(b|0)|0)>>>0<2){i=e;return}m=cE(b|0,47)|0;if((m|0)==0){be(b|0,3,523352,(p=i,i=i+8|0,c[p>>2]=571976,p)|0)|0;i=p;i=e;return}else{a[m+1|0]=0;i=e;return}}function hK(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;d=i;i=i+80|0;e=d|0;f=bG(b|0)|0;if((f|0)==0){g=0;i=d;return g|0}h=gGy(f|0)|0;do{if((h|0)!=0){j=f+(h-1)|0;if((a[j]|0)!=47){break}a[j]=0}}while(0);do{if((gGy(f|0)|0)>>>0>=2){h=cE(f|0,47)|0;if((h|0)==0){be(f|0,3,523352,(k=i,i=i+8|0,c[k>>2]=571976,k)|0)|0;i=k;break}else{a[h+1|0]=0;break}}}while(0);do{if((a[f]|0)==0){l=0}else{if((fa(f|0,b|0)|0)==0){l=0;break}do{if((f$(f|0,e|0)|0)<0){m=1701}else{if((c[e+12>>2]&61440|0)!=16384){m=1701;break}n=hL(b)|0;o=b}}while(0);do{if((m|0)==1701){if(!(hK(f)|0)){n=0;o=f;break}n=hL(b)|0;o=b}}while(0);if((o|0)==0|n){l=n;break}h=c[u>>2]|0;bU(h|0,509712,(k=i,i=i+8|0,c[k>>2]=o,k)|0)|0;i=k;eY(h|0)|0;l=0}}while(0);gGr(f);g=l;i=d;return g|0}function hL(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;b=i;i=i+80|0;d=b|0;e=cW(a|0,488)|0;if((e|0)>=0){f=e;g=(f|0)==0;i=b;return g|0}h=bO()|0;j=c[h>>2]|0;do{if((j|0)==17){if((f$(a|0,d|0)|0)<0){k=e}else{k=(c[d+12>>2]&61440|0)==16384?0:e}if((k|0)<0){l=k;m=c[h>>2]|0;break}else{f=k;g=(f|0)==0;i=b;return g|0}}else{l=e;m=j}}while(0);j=c[u>>2]|0;e=bP(m|0)|0;bU(j|0,439080,(m=i,i=i+16|0,c[m>>2]=a,c[m+8>>2]=e,m)|0)|0;i=m;eY(j|0)|0;f=l;g=(f|0)==0;i=b;return g|0}function hM(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;f=i;if((a[e]|0)==47){g=4096;h=0;j=b;k=e;while(1){l=g-1|0;if((l|0)==0){m=1723;break}n=a[k]|0;a[j]=n;if(n<<24>>24==0){o=h;break}else{g=l;h=h+1|0;j=j+1|0;k=k+1|0}}do{if((m|0)==1723){a[j]=0;if((a[k]|0)==0){o=h;break}else{p=k;q=h}while(1){g=p+1|0;l=q+1|0;if((a[g]|0)==0){o=l;break}else{p=g;q=l}}}}while(0);if(o>>>0<4096){i=f;return}else{o=c[u>>2]|0;bU(o|0,547632,(r=i,i=i+16|0,c[r>>2]=551256,c[r+8>>2]=724,r)|0)|0;i=r;eY(o|0)|0;fm(2)}}else{s=4096;t=0;v=b;w=d}while(1){d=s-1|0;if((d|0)==0){m=1729;break}o=a[w]|0;a[v]=o;if(o<<24>>24==0){x=t;break}else{s=d;t=t+1|0;v=v+1|0;w=w+1|0}}do{if((m|0)==1729){a[v]=0;if((a[w]|0)==0){x=t;break}else{y=w;z=t}while(1){s=y+1|0;d=z+1|0;if((a[s]|0)==0){x=d;break}else{y=s;z=d}}}}while(0);if(x>>>0>=4096){x=c[u>>2]|0;bU(x|0,547632,(r=i,i=i+16|0,c[r>>2]=551256,c[r+8>>2]=727,r)|0)|0;i=r;eY(x|0)|0;fm(2)}do{if((gGy(b|0)|0)>>>0>=2){x=cE(b|0,47)|0;if((x|0)==0){be(b|0,3,523352,(r=i,i=i+8|0,c[r>>2]=571976,r)|0)|0;i=r;break}else{a[x+1|0]=0;break}}}while(0);x=gGy(b|0)|0;z=x>>>0>4096?0:4096-x|0;L2421:do{if((z|0)==0){A=0;B=e;m=1742}else{y=z;t=0;w=b+x|0;v=e;while(1){d=y-1|0;if((d|0)==0){break}s=a[v]|0;a[w]=s;if(s<<24>>24==0){C=t;break L2421}else{y=d;t=t+1|0;w=w+1|0;v=v+1|0}}a[w]=0;A=t;B=v;m=1742}}while(0);do{if((m|0)==1742){if((a[B]|0)==0){C=A;break}else{D=B;E=A}while(1){e=D+1|0;b=E+1|0;if((a[e]|0)==0){C=b;break}else{D=e;E=b}}}}while(0);if((C+x|0)>>>0<4096){i=f;return}else{f=c[u>>2]|0;bU(f|0,547632,(r=i,i=i+16|0,c[r>>2]=551256,c[r+8>>2]=729,r)|0)|0;i=r;eY(f|0)|0;fm(2)}}function hN(){var b=0,d=0,e=0,f=0;b=i;if((c[2368524]|0)!=0){if((a[9375104]&1)==0){c[2383355]=152;i=b;return}d=c[u>>2]|0;cj(276448,50,1,d|0)|0;eY(d|0)|0;c[2383355]=152;i=b;return}if((gGF(9263480,433600)|0)==0){c[2383355]=152;i=b;return}b=c[u>>2]|0;bU(b|0,269288,(d=i,i=i+8|0,c[d>>2]=9263480,d)|0)|0;i=d;eY(b|0)|0;e=a[9375104]|0;if((e&1)==0){f=e}else{cj(261592,29,1,b|0)|0;eY(b|0)|0;f=a[9375104]|0}if((f&1)==0){hX(253200)}bU(b|0,29e4,(d=i,i=i+8|0,c[d>>2]=433600,d)|0)|0;i=d;eY(b|0)|0;hX(253200)}function hO(){var b=0,d=0.0,e=0.0,f=0.0,j=0.0,k=0.0,l=0.0,m=0,n=0,o=0.0;b=i;a[9469445]=0;d=+h[1183676];if(d<=0.0){i=b;return}e=+h[1183677];if(e<=0.0){i=b;return}f=+g[2317949];j=f;if(+V(+(1.0-d/j))>.05000000074505806){if((a[9375104]&1)==0){k=d;l=f}else{m=c[u>>2]|0;f=d;bU(m|0,331432,(n=i,i=i+16|0,h[n>>3]=j,h[n+8>>3]=f,n)|0)|0;i=n;eY(m|0)|0;k=+h[1183676];l=+g[2317949]}do{if(k>l){a[9469445]=1;if((a[9375104]&1)==0){break}m=c[u>>2]|0;cj(322504,57,1,m|0)|0;eY(m|0)|0}}while(0);o=+h[1183677]}else{o=e*(j/d)}d=o;g[2320019]=d;if((a[9375104]&1)!=0){m=c[u>>2]|0;o=d;bU(m|0,313056,(n=i,i=i+8|0,h[n>>3]=o,n)|0)|0;i=n;eY(m|0)|0}m=c[2383358]|0;if((m|0)==0){i=b;return}if((a[9469445]&1)!=0){gg[c[(c[2383355]|0)+8>>2]&4095](m,1);i=b;return}n=(a[9533448]&1)!=0;if((a[9375106]&1)!=0){gg[c[(c[2383355]|0)+8>>2]&4095](m,(a[9263568]&1)==0|n)}m=c[2383357]|0;if((a[9375105]&1)!=0&(m|0)!=0){gg[c[(c[2383354]|0)+16>>2]&4095](m,(a[9284180]&1)==0|n)}c[2368546]=n?c[2368547]|0:c[2368548]|0;i=b;return}function hP(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=c[2383356]|0;f=c[2383359]|0;if(!((e|0)!=0&(f|0)!=0)){g=0;return g|0}h=c[e+40>>2]|0;if((h|0)==0){g=0;return g|0}g=gJ[h&31](f,a,b,d)|0;return g|0}function hQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=c[2383356]|0;f=c[2383359]|0;if(!((e|0)!=0&(f|0)!=0)){g=0;return g|0}h=c[e+24>>2]|0;if((h|0)==0){g=0;return g|0}g=gJ[h&31](f,a,b,d)|0;return g|0}function hR(){var a=0,b=0,d=0;a=c[2383406]|0;if((a|0)==0){b=0;return b|0}d=c[a+4>>2]|0;if((d|0)==0){b=0;return b|0}b=gj[d&4095](c[2383358]|0)|0;return b|0}function hS(a){a=a|0;var b=0,d=0,e=0;b=c[2383406]|0;if((b|0)==0){d=0;return d|0}e=c[b+8>>2]|0;if((e|0)==0){d=0;return d|0}d=gA[e&16383](c[2383358]|0,a)|0;return d|0}function hT(){var b=0,d=0,e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0.0,s=0.0,t=0.0,v=0.0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;b=i;i=i+24|0;d=b|0;L2521:do{if((a[9271801]|0)!=0){e=hD(9271801,362224,0)|0;c[2382989]=e;do{if((e|0)!=0){f=c[e+4>>2]|0;if((f|0)==0){gGr(c[e>>2]|0);gGr(e);break}c[2382990]=0;c0(c[e>>2]|0,f|0,8,5450);f=c[2382989]|0;if((c[f+4>>2]|0)==0){break L2521}h=c[u>>2]|0;j=0;k=f;while(1){if((a[9375104]&1)==0){l=k}else{f=c[(c[k>>2]|0)+(j<<3)>>2]|0;bU(h|0,355368,(m=i,i=i+8|0,c[m>>2]=f,m)|0)|0;i=m;eY(h|0)|0;l=c[2382989]|0}f=j+1|0;if(f>>>0<(c[l+4>>2]|0)>>>0){j=f;k=l}else{break L2521}}}}while(0);c[2382989]=0;c[2382990]=0}}while(0);l=c[2367348]|0;e=c[2367349]|0;k=(l>>>0>e>>>0?l:e)-1|0;e=k>>>1|k;k=e>>>2|e;e=k>>>4|k;k=e>>>8|e;e=((k>>>16|k)+1|0)>>>8;k=(a[9523440]&1)==0?e>>>0>1?e:1:c[2380865]|0;e=c[2367346]|0;l=c[2367347]|0;if((e|0)==0|(l|0)==0){n=e}else{j=e>>>0<l>>>0?e:l;if(j>>>0>1){h=1;f=1;while(1){if(((e>>>0)%(h>>>0)|0|0)==0){o=((l>>>0)%(h>>>0)|0|0)==0?h:f}else{o=f}p=h+1|0;if(p>>>0<j>>>0){h=p;f=o}else{q=o;break}}}else{q=1}o=(e>>>0)/(q>>>0)|0;e=(l>>>0)/(q>>>0)|0;be(64732,64,280952,(m=i,i=i+16|0,c[m>>2]=o,c[m+8>>2]=e,m)|0)|0;i=m;g[16199]=+(o>>>0>>>0)/+(e>>>0>>>0);n=c[2367346]|0}r=+(n>>>0>>>0);do{if(r>0.0){s=+((c[2367347]|0)>>>0>>>0);if(s<=0.0){break}t=+g[2367350];if(t>0.0){g[16216]=t;break}else{g[16216]=r/s;break}}}while(0);s=+g[2315896];L2553:do{if(s<0.0){t=+g[2367350];do{if(t>0.0){if((a[9263588]&1)==0){break}g[16182]=t;break L2553}}while(0);g[16182]=r/+((c[2367347]|0)>>>0>>>0)}else{g[16182]=s}}while(0);n=c[2315898]|0;if((n|0)==7){s=+g[16216];e=c[2383019]|0;do{if((e|0)==0){v=s}else{o=c[2383020]|0;if((o|0)==0){v=s;break}v=+(e>>>0>>>0)/+(o>>>0>>>0)}}while(0);g[16233]=v}v=+g[64456+(n*68|0)>>2];g[2367356]=v;do{if((a[9263552]&1)==0){if((a[9263581]&1)==0){n=~~+ba(+(r*+g[2315886]));w=n;x=~~+ba(+(+((c[2367347]|0)>>>0>>>0)*+g[2315887]));break}else{s=+((c[2367347]|0)>>>0>>>0);t=+(~~+ba(+(v*s))>>>0>>>0);n=~~+ba(+(+g[2315886]*t));w=n;x=~~+ba(+(s*+g[2315887]));break}}else{w=c[2315890]|0;x=c[2315891]|0}}while(0);n=(a[9375104]&1)==0;do{if((w|0)==0|(x|0)==0){if(n){break}e=c[u>>2]|0;cj(508912,30,1,e|0)|0;eY(e|0)|0}else{if(n){break}e=c[u>>2]|0;bU(e|0,522560,(m=i,i=i+16|0,c[m>>2]=w,c[m+8>>2]=x,m)|0)|0;i=m;eY(e|0)|0}}while(0);c[2383365]=0;c[2383363]=0;c[2383364]=0;m=k<<8;gGr(c[2383382]|0);gGr(c[2383385]|0);gGr(c[2383386]|0);gGr(c[2383389]|0);gGr(c[2383392]|0);gGr(c[2383390]|0);gGr(c[2383396]|0);gGz(9533464,0,128);gGr(c[2383398]|0);c[2383398]=0;if((c[2367360]|0)==0){n=c[u>>2]|0;cj(371384,120,1,n|0)|0;eY(n|0)|0;c[2383374]=1;c[2383372]=2;c[2383373]=3;if(!(i6(9533464)|0)){cj(496656,53,1,n|0)|0;eY(n|0)|0;hX(484704)}n=ag(m,m)|0;m=n<<1;if(n>>>0>65535){y=(n&2147418112|0)==(n|0)?m:-1}else{y=m}m=gGq(y)|0;do{if((m|0)!=0){if((c[m-4>>2]&3|0)==0){break}gGz(m|0,0,y|0)}}while(0);c[2383398]=m}m=d;c[m>>2]=c[11958];c[m+4>>2]=c[11959];c[m+8>>2]=c[11960];c[m+12>>2]=c[11961];c[m+16>>2]=c[11962];c[d>>2]=w;c[d+4>>2]=x;a[d+8|0]=a[9263552]&1;if((a[9263568]&1)==0){z=0}else{z=a[9469445]&1^1}a[d+9|0]=z;a[d+10|0]=a[9263581]&1;a[d+11|0]=a[9263580]&1;c[d+12>>2]=k;if((a[9523440]&1)==0){A=(c[2367360]|0)==1|0}else{A=1}a[d+16|0]=A;A=c[2383356]|0;hN();k=gp[c[c[2383355]>>2]&16383](d,9533424,9533436)|0;c[2383358]=k;if((k|0)==0){d=c[u>>2]|0;cj(471744,62,1,d|0)|0;eY(d|0)|0;hX(484704)}c[2383406]=0;d=c[2383355]|0;z=c[d+52>>2]|0;if((z|0)==0){B=d}else{gg[z&4095](k,9533624);B=c[2383355]|0}k=B+40|0;do{if((c[k>>2]|0)==0){C=B}else{if(!((c[2383019]|0)==0|(c[2383020]|0)==0)){C=B;break}c[2383019]=w;c[2383020]=x;gg[c[k>>2]&4095](c[2383358]|0,9532068);C=c[2383355]|0}}while(0);k=c[C+36>>2]|0;if((k|0)!=0){gg[k&4095](c[2383358]|0,(c[2367357]|0)+(c[2315899]|0)&3)}do{if((c[2383356]|0)==0){if((a[9375104]&1)!=0){k=c[u>>2]|0;cj(460584,101,1,k|0)|0;eY(k|0)|0}c[2383356]=A;if((A|0)==0){k=c[u>>2]|0;cj(438352,59,1,k|0)|0;eY(k|0)|0;hX(484704)}k=gD[c[A>>2]&8191]()|0;c[2383359]=k;if((k|0)!=0){break}k=c[u>>2]|0;cj(449880,59,1,k|0)|0;eY(k|0)|0;hX(484704)}}while(0);A=c[2383400]|0;if((A|0)!=0){i5(A);c[2383400]=0}if((a[9324856]|0)==0){D=9523432;E=0;F=0;G=D|0;c[G>>2]=E;H=D+4|0;c[H>>2]=F;i=b;return}A=i3()|0;c[2383400]=A;if((A|0)!=0){D=9523432;E=0;F=0;G=D|0;c[G>>2]=E;H=D+4|0;c[H>>2]=F;i=b;return}A=c[u>>2]|0;cj(561752,45,1,A|0)|0;eY(A|0)|0;D=9523432;E=0;F=0;G=D|0;c[G>>2]=E;H=D+4|0;c[H>>2]=F;i=b;return}function hU(){var b=0,d=0,e=0,f=0,j=0,k=0.0,l=0,m=0,n=0,o=0,p=0,q=0;b=i;a[9533443]=(c[2383358]|0)==0|0;a[9533444]=(c[2383357]|0)==0|0;a[9533445]=(c[2383359]|0)==0|0;hO();c[2382972]=0;hT();d=c[2368525]|0;if((a[9533442]&1)==0&(d|0)!=0){gu[d&16383]()}a[9533442]=0;do{if((c[2383357]|0)==0){d=~~(+g[2341460]*65536.0);e=gGq(d<<1)|0;c[2368554]=e;if((e|0)==0){e=c[u>>2]|0;bU(e|0,547632,(f=i,i=i+16|0,c[f>>2]=76008,c[f+8>>2]=598,f)|0)|0;i=f;eY(e|0)|0;fm(2)}c[2368548]=512;c[2368547]=2048;c[2368546]=512;e=gGq(8192)|0;c[2368555]=e;if((e|0)==0){e=c[u>>2]|0;bU(e|0,547632,(f=i,i=i+16|0,c[f>>2]=76008,c[f+8>>2]=605,f)|0)|0;i=f;eY(e|0)|0;fm(2)}c[2368557]=4096;if((a[9280064]&1)==0){a[9375105]=0;break}e=gp[c[c[2383354]>>2]&16383]((a[9280080]|0)!=0?9280080:0,c[2320017]|0,c[2321044]|0)|0;c[2383357]=e;do{if((e|0)==0){j=c[u>>2]|0;cj(583112,85,1,j|0)|0;eY(j|0)|0;a[9375105]=0;a[9474208]=0}else{j=(a[9375105]&1)==0;a[9474208]=0;if(j){break}j=c[(c[2383354]|0)+24>>2]|0;if((j|0)==0){break}if(!(gj[j&4095](e)|0)){break}a[9474208]=1}}while(0);do{if((a[9284180]&1)==0){if((a[9375105]&1)==0){break}gg[c[(c[2383354]|0)+16>>2]&4095](c[2383357]|0,1);c[2368546]=c[2368547]}}while(0);k=+((c[2320017]|0)>>>0>>>0)/+g[2320019];h[1184275]=k;h[1184281]=k;e=a[9288288]|0;j=c[2368542]|0;do{if((j|0)!=0){l=c[2368543]|0;if((l|0)==0){break}gf[c[l+8>>2]&2047](j)}}while(0);c[2368543]=2832;j=jy(k)|0;c[2368542]=j;if((j|0)==0){c[2368543]=0;j=c[u>>2]|0;l=e<<24>>24!=0?9288288:550288;bU(j|0,566184,(f=i,i=i+8|0,c[f>>2]=l,f)|0)|0;i=f;eY(j|0)|0;a[9375105]=0}j=gGq(16384)|0;c[2368544]=j;if((j|0)==0){j=c[u>>2]|0;bU(j|0,547632,(f=i,i=i+16|0,c[f>>2]=76008,c[f+8>>2]=663,f)|0)|0;i=f;eY(j|0)|0;fm(2)}c[2368545]=0;if(+((c[2320017]|0)>>>0>>>0)>=+g[2320019]*16.0){j=c[u>>2]|0;bU(j|0,547632,(f=i,i=i+16|0,c[f>>2]=76008,c[f+8>>2]=667,f)|0)|0;i=f;eY(j|0)|0;fm(2)}j=gGq(d<<2)|0;c[2368553]=j;if((j|0)==0){j=c[u>>2]|0;bU(j|0,547632,(f=i,i=i+16|0,c[f>>2]=76008,c[f+8>>2]=668,f)|0)|0;i=f;eY(j|0)|0;fm(2)}a[9474244]=0;L2675:do{if((c[2368515]|0)==0){if((a[9375105]&1)==0){break}if((a[9288277]&1)==0){break}j=c[2383354]|0;l=c[j+36>>2]|0;do{if((l|0)!=0){if((c[j+32>>2]|0)==0){break}c[2368564]=gj[l&4095](c[2383357]|0)|0;a[9474244]=1;break L2675}}while(0);l=c[u>>2]|0;cj(535712,97,1,l|0)|0;eY(l|0)|0}}while(0);k=+g[2322071];g[2368565]=k;g[2368566]=+X(+10.0,+(k/20.0));d=9507040;c[d>>2]=0;c[d+4>>2]=0;if((a[9375105]&1)==0){break}if(!((a[9474209]&1)==0&(c[2368515]|0)!=0)){break}d=c[(c[2383354]|0)+12>>2]|0;e=c[2383357]|0;gj[d&4095](e)|0}}while(0);if((a[9533448]&1)==0){m=9474152;n=0;o=0;p=m|0;c[p>>2]=n;q=m+4|0;c[q>>2]=o;i=b;return}f=c[2383358]|0;if((a[9375106]&1)!=0&(f|0)!=0){gg[c[(c[2383355]|0)+8>>2]&4095](f,1)}f=c[2383357]|0;if((a[9375105]&1)!=0&(f|0)!=0){gg[c[(c[2383354]|0)+16>>2]&4095](f,1)}c[2368546]=c[2368547];m=9474152;n=0;o=0;p=m|0;c[p>>2]=n;q=m+4|0;c[q>>2]=o;i=b;return}function hV(){var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0.0,n=0.0,o=0.0,p=0,q=0,r=0,s=0,t=0.0,v=0;b=i;d=c[2383357]|0;e=c[2383354]|0;if((d|0)!=0&(e|0)!=0){gf[c[e+20>>2]&2047](d)}gGr(c[2368554]|0);c[2368554]=0;c[2368545]=0;gGr(c[2368555]|0);c[2368555]=0;if((a[9280064]&1)==0){a[9375105]=0;i=b;return}d=c[2368543]|0;e=c[2368542]|0;if((d|0)!=0&(e|0)!=0){gf[c[d+8>>2]&2047](e)}c[2368543]=0;c[2368542]=0;gGr(c[2368544]|0);c[2368544]=0;gGr(c[2368553]|0);c[2368553]=0;e=9507040;d=c[e>>2]|0;f=c[e+4>>2]|0;e=0;g=f>>>0<e>>>0|f>>>0==e>>>0&d>>>0<8192>>>0?d:8192;if(g>>>0<3){i=b;return}else{j=0;k=0;l=1}do{k=gGK(c[9474272+(l<<2)>>2]|0,0,k,j)|0;j=K;l=l+1|0;}while(l>>>0<g>>>0);l=g-1|0;d=gGV(k,j,l,0)|0;j=d;d=0;k=0;e=1;do{f=j-(c[9474272+(e<<2)>>2]|0)|0;k=gGK(ag(f,f)|0,0,k,d)|0;d=K;e=e+1|0;}while(e>>>0<g>>>0);m=+W(+((+(k>>>0)+ +(d>>>0)*4294967296.0)/+((g-2|0)>>>0>>>0)));d=c[2368564]|0;n=+(d>>>0>>>0);o=+(j|0)/n;j=(d*3|0)>>>2;k=d>>>2;d=1;e=0;f=0;while(1){p=c[9474272+(d<<2)>>2]|0;if(p>>>0<j>>>0){q=(p>>>0<=k>>>0)+f|0;r=e}else{q=f;r=e+1|0}p=d+1|0;if(p>>>0<g>>>0){d=p;e=r;f=q}else{break}}f=a[9375104]|0;if((f&1)==0){s=f}else{f=c[u>>2]|0;t=(1.0-o)*100.0;o=+(~~m>>>0>>>0)/n*100.0;bU(f|0,347200,(v=i,i=i+16|0,h[v>>3]=t,h[v+8>>3]=o,v)|0)|0;i=v;eY(f|0)|0;s=a[9375104]|0}if((s&1)==0){i=b;return}s=c[u>>2]|0;o=+(l>>>0>>>0);bU(s|0,339056,(v=i,i=i+16|0,h[v>>3]=+(r>>>0>>>0)*100.0/o,h[v+8>>3]=+(q>>>0>>>0)*100.0/o,v)|0)|0;i=v;eY(s|0)|0;i=b;return}function hW(){var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0.0,s=0.0;b=i;d=c[2383400]|0;if((d|0)!=0){i5(d);c[2383400]=0;gGz(9533608,0,16)}d=c[2383359]|0;e=c[2383358]|0;f=c[2383356]|0;if((d|0)!=(e|0)&(f|0)!=0){gf[c[f+16>>2]&2047](d);g=c[2383358]|0}else{g=e}e=c[2383355]|0;if((g|0)!=0&(e|0)!=0){gf[c[e+24>>2]&2047](g)}gGr(c[2383382]|0);gGr(c[2383385]|0);gGr(c[2383386]|0);gGr(c[2383389]|0);gGr(c[2383392]|0);gGr(c[2383390]|0);gGr(c[2383396]|0);gGz(9533464,0,128);gGr(c[2383398]|0);c[2383398]=0;g=c[2382989]|0;if((g|0)!=0){e=g+4|0;d=g|0;f=c[d>>2]|0;if((c[e>>2]|0)==0){j=f}else{k=0;l=f;while(1){gGr(c[l+(k<<3)>>2]|0);f=k+1|0;m=c[d>>2]|0;if(f>>>0<(c[e>>2]|0)>>>0){k=f;l=m}else{j=m;break}}}gGr(j);gGr(g)}c[2382989]=0;c[2382990]=0;if((a[9271800]&1)!=0){if((a[9375104]&1)==0){i=b;return}g=c[u>>2]|0;cj(415640,66,1,g|0)|0;eY(g|0)|0;i=b;return}g=9523432;j=c[g+4>>2]|0;l=0;if(j>>>0<l>>>0|j>>>0==l>>>0&(c[g>>2]|0)>>>0<4096>>>0){if((a[9375104]&1)==0){i=b;return}g=c[u>>2]|0;bU(g|0,403936,(n=i,i=i+8|0,c[n>>2]=4096,n)|0)|0;i=n;eY(g|0)|0;i=b;return}else{o=0;p=0;q=0}do{g=9507048+(q<<3)|0;p=gGK(c[g>>2]|0,c[g+4>>2]|0,p,o)|0;o=K;q=q+1|0;}while(q>>>0<2048);q=gGS(p,o,2048,0)|0;o=K;p=0;g=0;l=0;do{j=9507048+(p<<3)|0;k=gGL(c[j>>2]|0,c[j+4>>2]|0,q,o)|0;j=K;e=gGU(k,j,k,j)|0;l=gGK(e,K,l,g)|0;g=K;p=p+1|0;}while(p>>>0<2048);r=+(q>>>0)+ +(o|0)*4294967296.0;if((a[9375104]&1)==0){i=b;return}s=+W(+((+(l>>>0)+ +(g|0)*4294967296.0)/2047.0))/r;g=c[u>>2]|0;bU(g|0,393032,(n=i,i=i+24|0,h[n>>3]=1.0e6/r,h[n+8>>3]=s*100.0,c[n+16>>2]=2048,n)|0)|0;i=n;eY(g|0)|0;i=b;return}function hX(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;if((a[9532117]&1)==0){d=c[u>>2]|0;bU(d|0,547632,(e=i,i=i+16|0,c[e>>2]=504696,c[e+8>>2]=729,e)|0)|0;i=e;eY(d|0)|0;fm(2)}else{f=1024;g=9532119;h=b}while(1){b=f-1|0;if((b|0)==0){break}d=a[h]|0;a[g]=d;if(d<<24>>24==0){j=2005;break}else{f=b;g=g+1|0;h=h+1|0}}if((j|0)==2005){eM(9533144,1)}a[g]=0;if((a[h]|0)==0){eM(9533144,1)}else{k=h}do{k=k+1|0;}while((a[k]|0)!=0);eM(9533144,1)}function hY(a){a=a|0;var b=0,d=0;if((a|0)==0){return}b=c[a+4>>2]|0;if((b|0)!=0){d=b;while(1){gGr(c[d+4>>2]|0);gGr(c[d+8>>2]|0);b=c[d+12>>2]|0;gGr(d|0);if((b|0)==0){break}else{d=b}}}d=c[a+16>>2]|0;if((d|0)!=0){b=d;while(1){gGr(c[b>>2]|0);d=c[b+4>>2]|0;gGr(b);if((d|0)==0){break}else{b=d}}}gGr(c[a>>2]|0);gGr(a);return}function hZ(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0;e=i;i=i+4112|0;f=e|0;g=e+8|0;h=e+4104|0;j=gGq(20)|0;if((j|0)==0){k=0;i=e;return k|0}if((c[j-4>>2]&3|0)!=0){gGz(j|0,0,20)}l=j;if((b|0)==0){k=l;i=e;return k|0}m=bG(b|0)|0;n=j;c[n>>2]=m;if((m|0)==0){gGr(j);k=0;i=e;return k|0}o=j+12|0;c[o>>2]=d;d=fw(b|0,68376)|0;if((d|0)==0){gGr(m);gGr(j);k=0;i=e;return k|0}if((b0(d|0)|0)==0){m=j+8|0;b=j+4|0;p=g|0;q=j+16|0;j=c[u>>2]|0;do{r=gGq(16)|0;do{if((r|0)!=0){if((c[r-4>>2]&3|0)==0){break}gGz(r|0,0,16)}}while(0);s=r;t=gGq(9)|0;v=fc(d|0)|0;w=0;x=8;y=t;while(1){if((v|0)==(-1|0)|(v|0)==10){break}if((w|0)==(x|0)){t=x<<1;z=t;A=gGs(y,t|1)|0}else{z=x;A=y}a[A+w|0]=v&255;v=fc(d|0)|0;w=w+1|0;x=z;y=A}a[y+w|0]=0;if((y|0)!=0){L2832:do{if((a[y]|0)!=0){x=y+(gGy(y|0)|0)|0;v=y;t=1;L2834:while(1){L2836:do{if(t){B=v;while(1){D=d0(B|0,34)|0;E=(D|0)==0?x:D;D=d0(B|0,35)|0;F=(D|0)==0?x:D;if(E>>>0<F>>>0){G=0;H=E;break L2836}if((F|0)!=0){I=2041;break L2834}if((a[x]|0)==0){J=x;break L2834}else{B=x}}}else{B=v;while(1){E=d0(B|0,34)|0;D=(E|0)==0?x:E;E=d0(B|0,35)|0;K=(E|0)==0?x:E;if((D|0)!=0){G=1;H=D;break L2836}if((K|0)!=0){I=2046;break L2834}if((a[x]|0)==0){J=x;break L2834}else{B=x}}}}while(0);B=H+1|0;if((a[B]|0)==0){J=B;break}else{v=B;t=G}}if((I|0)==2041){I=0;a[F]=0;J=F}else if((I|0)==2046){I=0;a[K]=0;J=K}t=c[o>>2]|0;do{if((J|0)==(y|0)){if(t>>>0>=16){I=2096;break}if((dW(y+1|0,449008,8)|0)!=0){L=y;break}v=y+9|0;while(1){M=v+1|0;if((a4(a[v]|0)|0)==0){break}else{v=M}}x=a[v]|0;if((x<<24>>24|0)==0){break L2832}else if((x<<24>>24|0)==34){x=de(M|0,426600,f|0)|0;if((x|0)==0){break L2832}N=bG(x|0)|0}else{x=de(v|0,414272,f|0)|0;if((x|0)==0){break L2832}N=bG(x|0)|0}if((N|0)==0){break L2832}x=c[q>>2]|0;B=gGq(8)|0;do{if((B|0)!=0){if((c[B-4>>2]&3|0)==0){break}D=B;E=D|0;C=0;a[E]=C&255;C=C>>8;a[E+1|0]=C&255;C=C>>8;a[E+2|0]=C&255;C=C>>8;a[E+3|0]=C&255;E=D+4|0;C=0;a[E]=C&255;C=C>>8;a[E+1|0]=C&255;C=C>>8;a[E+2|0]=C&255;C=C>>8;a[E+3|0]=C&255}}while(0);v=B;c[B>>2]=bG(N|0)|0;if((x|0)==0){c[q>>2]=v}else{E=x;do{O=E+4|0;E=c[O>>2]|0;}while((E|0)!=0);c[O>>2]=v}L2875:do{if((a[N]|0)==126){E=fE(488528)|0;x=4096;B=p;D=(E|0)!=0?E:9534384;while(1){E=x-1|0;if((E|0)==0){I=2070;break}P=a[D]|0;a[B]=P;if(P<<24>>24==0){break}else{x=E;B=B+1|0;D=D+1|0}}do{if((I|0)==2070){I=0;a[B]=0;if((a[D]|0)==0){break}else{Q=D}do{Q=Q+1|0;}while((a[Q]|0)!=0)}}while(0);D=N+1|0;B=gGy(p|0)|0;x=B>>>0>4096?0:4096-B|0;if((x|0)==0){R=D}else{E=x;x=g+B|0;B=D;while(1){D=E-1|0;if((D|0)==0){break}P=a[B]|0;a[x]=P;if(P<<24>>24==0){break L2875}else{E=D;x=x+1|0;B=B+1|0}}a[x]=0;R=B}if((a[R]|0)==0){break}else{S=R}do{S=S+1|0;}while((a[S]|0)!=0)}else{hM(p,c[n>>2]|0,N)}}while(0);v=hZ(p,(c[o>>2]|0)+1|0)|0;if((v|0)==0){gGr(N);break L2832}B=c[b>>2]|0;if((B|0)==0){x=v+4|0;E=c[x>>2]|0;if((E|0)==0){T=0}else{D=E;do{a[D|0]=1;D=c[D+12>>2]|0;}while((D|0)!=0);T=c[x>>2]|0}c[b>>2]=T;U=T}else{D=B;do{V=D+12|0;D=c[V>>2]|0;}while((D|0)!=0);D=v+4|0;B=c[D>>2]|0;if((B|0)==0){W=0}else{x=B;do{a[x|0]=1;x=c[x+12>>2]|0;}while((x|0)!=0);W=c[D>>2]|0}c[V>>2]=W;U=c[b>>2]|0}c[v+4>>2]=0;if((U|0)==0){X=0}else{x=U;while(1){B=c[x+12>>2]|0;if((B|0)==0){X=x;break}else{x=B}}}c[m>>2]=X;hY(v);gGr(N);break L2832}else{if(t>>>0>15){I=2096}else{L=y}}}while(0);if((I|0)==2096){I=0;cj(437488,58,1,j|0)|0;L=y}while(1){if((a4(a[L]|0)|0)==0){break}L=L+1|0}t=gGq(9)|0;if((eO(a[L]|0)|0)==0){Y=L;Z=t;_=0}else{x=L;D=t;t=8;B=0;while(1){if((B|0)==(t|0)){E=B<<1;$=E;aa=gGs(D,E|1)|0}else{$=t;aa=D}E=x+1|0;P=B+1|0;a[aa+B|0]=a[x]|0;if((eO(a[E]|0)|0)==0){Y=E;Z=aa;_=P;break}else{x=E;D=aa;t=$;B=P}}}a[Z+_|0]=0;B=r+4|0;c[B>>2]=Z;t=Y;while(1){ab=t+1|0;if((a4(a[t]|0)|0)==0){break}else{t=ab}}do{if((a[t]|0)==61){D=ab;while(1){ac=D+1|0;if((a4(a[D]|0)|0)==0){break}else{D=ac}}v=a[D]|0;if((v<<24>>24|0)==34){x=de(ac|0,426600,h|0)|0;if((x|0)==0){I=2112;break}ad=bG(x|0)|0}else if((v<<24>>24|0)==0){I=2112;break}else{v=de(D|0,414272,h|0)|0;if((v|0)==0){I=2112;break}ad=bG(v|0)|0}c[r+8>>2]=ad;if((ad|0)==0){break}if((c[b>>2]|0)==0){c[b>>2]=s;c[m>>2]=s;break L2832}else{c[(c[m>>2]|0)+12>>2]=s;c[m>>2]=s;break L2832}}else{I=2112}}while(0);if((I|0)==2112){I=0;c[r+8>>2]=0}c[B>>2]=0;gGr(Z)}}while(0);gGr(y)}if((s|0)!=(c[m>>2]|0)){gGr(r)}}while((b0(d|0)|0)==0)}aY(d|0)|0;k=l;i=e;return k|0}function h_(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;f=i;i=i+8192|0;g=f|0;h=f+4096|0;j=b+4|0;while(1){k=c[j>>2]|0;if((k|0)==0){l=0;m=2168;break}if((fa(d|0,c[k+4>>2]|0)|0)==0){break}else{j=k+12|0}}if((m|0)==2168){i=f;return l|0}j=c[k+8>>2]|0;k=a[j]|0;do{if((k<<24>>24|0)==58){if((a[j+1|0]|0)!=47){n=e;o=j;p=4096;m=2159;break}d=h|0;b=g|0;a[d]=0;q=fi()|0;r=0;while(1){if(r>>>0>=3){m=2145;break}s=c[51456+(r<<2)>>2]|0;be(b|0,4096,461304,(t=i,i=i+16|0,c[t>>2]=q,c[t+8>>2]=s,t)|0)|0;i=t;v=f5(b|0,d|0,4095)|0;if((v|0)>-1){m=2144;break}else{r=r+1|0}}if((m|0)==2144){a[h+v|0]=0}else if((m|0)==2145){r=c[u>>2]|0;cj(450472,78,1,r|0)|0;eY(r|0)|0}if((a[9375104]&1)!=0){r=c[u>>2]|0;bU(r|0,405816,(t=i,i=i+8|0,c[t>>2]=d,t)|0)|0;i=t;eY(r|0)|0}do{if((gGy(d|0)|0)>>>0<2){w=4096;x=0;y=e;z=d}else{r=cE(d|0,47)|0;if((r|0)==0){be(d|0,3,523352,(t=i,i=i+8|0,c[t>>2]=571976,t)|0)|0;i=t;w=4096;x=0;y=e;z=d;break}else{a[r+1|0]=0;w=4096;x=0;y=e;z=d;break}}}while(0);while(1){d=w-1|0;if((d|0)==0){m=2154;break}r=a[z]|0;a[y]=r;if(r<<24>>24==0){A=x;break}else{w=d;x=x+1|0;y=y+1|0;z=z+1|0}}do{if((m|0)==2154){a[y]=0;if((a[z]|0)==0){A=x;break}else{B=z;C=x}while(1){d=B+1|0;r=C+1|0;if((a[d]|0)==0){A=r;break}else{B=d;C=r}}}}while(0);if(A>>>0<4096){D=A;E=j+2|0;m=2158;break}else{l=0;i=f;return l|0}}else if((k<<24>>24|0)==126){r=fE(488528)|0;if((r|0)==0){n=e;o=j;p=4096;m=2159;break}else{F=4096;G=0;H=e;I=r}while(1){r=F-1|0;if((r|0)==0){m=2136;break}d=a[I]|0;a[H]=d;if(d<<24>>24==0){J=G;break}else{F=r;G=G+1|0;H=H+1|0;I=I+1|0}}do{if((m|0)==2136){a[H]=0;if((a[I]|0)==0){J=G;break}else{K=I;L=G}while(1){r=K+1|0;d=L+1|0;if((a[r]|0)==0){J=d;break}else{K=r;L=d}}}}while(0);if(J>>>0<4096){D=J;E=j+1|0;m=2158;break}else{l=0;i=f;return l|0}}else{n=e;o=j;p=4096;m=2159}}while(0);if((m|0)==2158){if((D|0)==4096){M=0;N=E;O=0;m=2163}else{n=e+D|0;o=E;p=4096-D|0;m=2159}}L3009:do{if((m|0)==2159){D=p;E=0;e=n;j=o;while(1){J=D-1|0;if((J|0)==0){break}L=a[j]|0;a[e]=L;if(L<<24>>24==0){P=E;Q=p;break L3009}else{D=J;E=E+1|0;e=e+1|0;j=j+1|0}}a[e]=0;M=E;N=j;O=p;m=2163}}while(0);do{if((m|0)==2163){if((a[N]|0)==0){P=M;Q=O;break}else{R=N;S=M}while(1){p=R+1|0;o=S+1|0;if((a[p]|0)==0){P=o;Q=O;break}else{R=p;S=o}}}}while(0);l=P>>>0<Q>>>0;i=f;return l|0}function h$(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=b+4|0;while(1){g=c[f>>2]|0;if((g|0)==0){h=0;i=2184;break}if((fa(d|0,c[g+4>>2]|0)|0)==0){break}else{f=g+12|0}}if((i|0)==2184){return h|0}i=c[g+8>>2]|0;if((gGF(i|0,577008)|0)==0){a[e]=1;h=1;return h|0}if((gGF(i|0,196544)|0)==0){a[e]=1;h=1;return h|0}if((gGF(i|0,372864)|0)==0){a[e]=0;h=1;return h|0}if((gGF(i|0,511256)|0)!=0){h=0;return h|0}a[e]=0;h=1;return h|0}function h0(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=b+4|0;b=c[f>>2]|0;L3045:do{if((b|0)==0){g=0}else{h=b;while(1){if((a[h|0]&1)==0){if((fa(d|0,c[h+4>>2]|0)|0)==0){break}}i=c[h+12>>2]|0;if((i|0)==0){g=h;break L3045}else{h=i}}i=h+8|0;gGr(c[i>>2]|0);c[i>>2]=bG(e|0)|0;return}}while(0);b=gGq(16)|0;do{if((b|0)!=0){if((c[b-4>>2]&3|0)==0){break}gGz(b|0,0,16)}}while(0);i=b;c[b+4>>2]=bG(d|0)|0;c[b+8>>2]=bG(e|0)|0;if((g|0)==0){c[f>>2]=i;return}else{c[g+12>>2]=i;return}}function h1(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0;e=i;f=(d|0)!=0;do{if(f){g=fw(d|0,622488)|0;if((g|0)==0){h=0}else{j=g;break}i=e;return h|0}else{j=c[s>>2]|0}}while(0);d=c[b+16>>2]|0;if((d|0)!=0){g=d;do{bU(j|0,521304,(k=i,i=i+8|0,c[k>>2]=c[g>>2],k)|0)|0;i=k;g=c[g+4>>2]|0;}while((g|0)!=0)}g=c[b+4>>2]|0;if((g|0)!=0){b=g;do{if((a[b|0]&1)==0){g=c[b+4>>2]|0;d=c[b+8>>2]|0;bU(j|0,507984,(k=i,i=i+16|0,c[k>>2]=g,c[k+8>>2]=d,k)|0)|0;i=k}b=c[b+12>>2]|0;}while((b|0)!=0)}if(!f){h=1;i=e;return h|0}aY(j|0)|0;h=1;i=e;return h|0}function h2(d){d=d|0;var e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0.0,bP=0.0,bQ=0,bR=0,bS=0,bT=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0,cf=0,cg=0,ci=0,ck=0,cl=0,cm=0;e=i;i=i+21080|0;f=e|0;h=e+80|0;j=e+160|0;k=e+12528|0;l=e+12536|0;m=e+16632|0;n=e+20728|0;o=e+20736|0;p=e+20744|0;q=e+20752|0;r=e+20760|0;s=e+20768|0;t=e+20776|0;v=e+20784|0;w=e+20792|0;x=e+20800|0;y=e+20808|0;z=e+20816|0;A=e+20824|0;B=e+20832|0;C=e+20840|0;D=e+20848|0;E=e+20856|0;F=e+20864|0;G=e+20872|0;H=e+20880|0;I=e+20888|0;J=e+20952|0;K=e+20960|0;L=e+20968|0;M=e+20976|0;N=e+20984|0;O=e+20992|0;P=e+21e3|0;Q=e+21008|0;R=e+21016|0;S=e+21024|0;T=e+21032|0;U=e+21040|0;V=e+21048|0;W=e+21056|0;X=e+21064|0;Y=e+21072|0;do{if((d|0)==0){Z=e+240|0;_=e+4336|0;$=e+8432|0;aa=fE(527592)|0;ab=fE(488528)|0;ac=(aa|0)!=0;do{if(ac){hE(Z,aa,524736);ad=2225}else{if((ab|0)==0){ad=2232;break}hE(Z,ab,522904);ad=2225}}while(0);if((ad|0)==2225){if((a[9375104]&1)!=0){ae=c[u>>2]|0;bU(ae|0,520648,(af=i,i=i+8|0,c[af>>2]=Z,af)|0)|0;i=af;eY(ae|0)|0}ae=hZ(Z,0)|0;if((ae|0)!=0|(ab|0)==0){ag=ae}else{hE(Z,ab,519240);if((a[9375104]&1)!=0){ae=c[u>>2]|0;bU(ae|0,520648,(af=i,i=i+8|0,c[af>>2]=Z,af)|0)|0;i=af;eY(ae|0)|0}ag=hZ(Z,0)|0}if((ag|0)==0){ad=2232}else{ah=ag;ad=2248}}L3102:do{if((ad|0)==2232){ae=(ab|0)!=0;if(!(ae|ac)){ai=0;break}do{if(ac){hE(Z,aa,524736)}else{if(!ae){break}hE(Z,ab,522904)}}while(0);hJ(_,Z);if(!(hK(_)|0)){ai=0;break}hE($,517752,516752);ae=hZ($,0)|0;do{if((ae|0)==0){aj=gGq(20)|0;if((aj|0)==0){ak=0;al=c[u>>2]|0;break}if((c[aj-4>>2]&3|0)!=0){gGz(aj|0,0,20)}am=aj;an=c[u>>2]|0;ad=2245}else{aj=c[u>>2]|0;bU(aj|0,515784,(af=i,i=i+8|0,c[af>>2]=$,af)|0)|0;i=af;eY(aj|0)|0;am=ae;an=aj;ad=2245}}while(0);do{if((ad|0)==2245){h0(am,572472,577008);if(!(h1(am,Z)|0)){ak=am;al=an;break}bU(an|0,514752,(af=i,i=i+8|0,c[af>>2]=Z,af)|0)|0;i=af;eY(an|0)|0;if((am|0)==0){ai=0;break L3102}else{ah=am;ad=2248;break L3102}}}while(0);bU(al|0,513800,(af=i,i=i+8|0,c[af>>2]=Z,af)|0)|0;i=af;eY(al|0)|0;hY(ak);ai=0}}while(0);L3124:do{if((ad|0)==2248){$=4096;_=9395610;ab=Z;while(1){aa=$-1|0;if((aa|0)==0){break}ac=a[ab]|0;a[_]=ac;if(ac<<24>>24==0){ai=ah;break L3124}else{$=aa;_=_+1|0;ab=ab+1|0}}a[_]=0;if((a[ab]|0)==0){ai=ah;break}else{ao=ab}while(1){$=ao+1|0;if((a[$]|0)==0){ai=ah;break}else{ao=$}}}}while(0);if((ai|0)==0){ap=1}else{aq=ai;break}i=e;return ap|0}else{Z=hZ(d,0)|0;if((Z|0)==0){ap=0}else{aq=Z;break}i=e;return ap|0}}while(0);d=l|0;l=4096;ai=d;ao=9399706;while(1){ah=l-1|0;if((ah|0)==0){ad=2257;break}ak=a[ao]|0;a[ai]=ak;if(ak<<24>>24==0){break}else{l=ah;ai=ai+1|0;ao=ao+1|0}}do{if((ad|0)==2257){a[ai]=0;if((a[ao]|0)==0){break}else{ar=ao}do{ar=ar+1|0;}while((a[ar]|0)!=0)}}while(0);ar=de(d|0,185104,k|0)|0;d=(a[9375104]&1)!=0;if((ar|0)==0){as=d}else{ao=c[u>>2]|0;ai=aq+4|0;l=ar;ar=d;while(1){if(ar){bU(ao|0,148904,(af=i,i=i+8|0,c[af>>2]=l,af)|0)|0;i=af;eY(ao|0)|0}d=hZ(l,0)|0;if((d|0)==0){bU(ao|0,119328,(af=i,i=i+8|0,c[af>>2]=l,af)|0)|0;i=af;eY(ao|0)|0}else{ah=c[d+8>>2]|0;if((ah|0)!=0){c[ah+12>>2]=c[ai>>2];ah=d+4|0;c[ai>>2]=c[ah>>2];c[ah>>2]=0}hY(d)}d=de(0,316184,k|0)|0;ah=(a[9375104]&1)!=0;if((d|0)==0){as=ah;break}else{l=d;ar=ah}}}do{if(as){ar=c[u>>2]|0;cj(73936,15,1,ar|0)|0;eY(ar|0)|0;l=c[aq+16>>2]|0;if((l|0)!=0){k=l;do{bU(ar|0,521304,(af=i,i=i+8|0,c[af>>2]=c[k>>2],af)|0)|0;i=af;k=c[k+4>>2]|0;}while((k|0)!=0)}k=aq+4|0;l=c[k>>2]|0;if((l|0)!=0){ai=l;do{l=c[ai+8>>2]|0;ao=(a[ai|0]&1)!=0?483784:9534384;bU(ar|0,495600,(af=i,i=i+24|0,c[af>>2]=c[ai+4>>2],c[af+8>>2]=l,c[af+16>>2]=ao,af)|0)|0;i=af;ai=c[ai+12>>2]|0;}while((ai|0)!=0)}if((a[9375104]&1)==0){at=k;break}cj(581232,19,1,ar|0)|0;eY(ar|0)|0;at=k}else{at=aq+4|0}}while(0);as=at;while(1){au=c[as>>2]|0;if((au|0)==0){av=at;break}if((fa(564104,c[au+4>>2]|0)|0)==0){ad=2281;break}as=au+12|0}if((ad|0)==2281){g[2315886]=+gGx(c[au+8>>2]|0,0);av=at}while(1){aw=c[av>>2]|0;if((aw|0)==0){ax=at;break}if((fa(548296,c[aw+4>>2]|0)|0)==0){ad=2285;break}av=aw+12|0}if((ad|0)==2285){g[2315887]=+gGx(c[aw+8>>2]|0,0);ax=at}while(1){ay=c[ax>>2]|0;if((ay|0)==0){az=at;break}if((fa(534016,c[ay+4>>2]|0)|0)==0){ad=2289;break}ax=ay+12|0}do{if((ad|0)==2289){ax=bO()|0;c[ax>>2]=0;aw=dE(c[ay+8>>2]|0,0,0)|0;if((c[ax>>2]|0)!=0){az=at;break}c[2315890]=aw;az=at}}while(0);while(1){aA=c[az>>2]|0;if((aA|0)==0){break}if((fa(520544,c[aA+4>>2]|0)|0)==0){ad=2294;break}az=aA+12|0}do{if((ad|0)==2294){az=bO()|0;c[az>>2]=0;ay=dE(c[aA+8>>2]|0,0,0)|0;if((c[az>>2]|0)!=0){break}c[2315891]=ay}}while(0);do{if((a[9375107]&1)==0){a[n]=0;if(!(h$(aq,507312,n)|0)){break}a[9263552]=a[n]&1}}while(0);a[o]=0;if(h$(aq,495112,o)|0){a[9263553]=a[o]&1;aB=at}else{aB=at}while(1){aC=c[aB>>2]|0;if((aC|0)==0){break}if((fa(483176,c[aC+4>>2]|0)|0)==0){ad=2303;break}else{aB=aC+12|0}}do{if((ad|0)==2303){aB=bO()|0;c[aB>>2]=0;o=dE(c[aC+8>>2]|0,0,0)|0;if((c[aB>>2]|0)!=0){break}c[2315889]=o}}while(0);a[p]=0;if(h$(aq,470736,p)|0){a[9280024]=a[p]&1}a[q]=0;if(h$(aq,459224,q)|0){a[9263568]=a[q]&1}a[r]=0;if(h$(aq,448816,r)|0){a[9263569]=a[r]&1;aD=at}else{aD=at}while(1){aE=c[aD>>2]|0;if((aE|0)==0){ad=2315;break}if((fa(437144,c[aE+4>>2]|0)|0)==0){ad=2313;break}else{aD=aE+12|0}}do{if((ad|0)==2313){aD=bO()|0;c[aD>>2]=0;r=dE(c[aE+8>>2]|0,0,0)|0;if((c[aD>>2]|0)!=0){ad=2315;break}c[2315894]=r;aF=r}}while(0);if((ad|0)==2315){aF=c[2315894]|0}if(aF>>>0>3){c[2315894]=3}a[s]=0;if(h$(aq,426312,s)|0){a[9263570]=a[s]&1;aG=at}else{aG=at}while(1){aH=c[aG>>2]|0;if((aH|0)==0){ad=2323;break}if((fa(413960,c[aH+4>>2]|0)|0)==0){ad=2322;break}else{aG=aH+12|0}}do{if((ad|0)==2322){aG=bO()|0;c[aG>>2]=0;s=dE(c[aH+8>>2]|0,0,0)|0;if((c[aG>>2]|0)!=0){ad=2323;break}c[2315893]=s;aI=s}}while(0);if((ad|0)==2323){aI=c[2315893]|0}aH=aI>>>0>1?aI:1;c[2315893]=aH>>>0<4?aH:4;a[t]=0;if(h$(aq,403152,t)|0){a[9271800]=a[t]&1}a[v]=0;if(h$(aq,391768,v)|0){a[9263580]=a[v]&1}a[w]=0;if(h$(aq,380632,w)|0){a[9263581]=a[w]&1}a[x]=0;if(h$(aq,370360,x)|0){a[9263589]=a[x]&1}a[y]=0;if(h$(aq,361416,y)|0){a[9263582]=a[y]&1;aJ=at}else{aJ=at}while(1){aK=c[aJ>>2]|0;if((aK|0)==0){aL=at;break}if((fa(354352,c[aK+4>>2]|0)|0)==0){ad=2337;break}else{aJ=aK+12|0}}if((ad|0)==2337){g[2315896]=+gGx(c[aK+8>>2]|0,0);aL=at}while(1){aM=c[aL>>2]|0;if((aM|0)==0){break}if((fa(346344,c[aM+4>>2]|0)|0)==0){ad=2340;break}else{aL=aM+12|0}}do{if((ad|0)==2340){aL=bO()|0;c[aL>>2]=0;aK=dE(c[aM+8>>2]|0,0,0)|0;if((c[aL>>2]|0)!=0){break}c[2315898]=aK}}while(0);a[z]=0;if(h$(aq,338256,z)|0){a[9263588]=a[z]&1;aN=at}else{aN=at}while(1){aO=c[aN>>2]|0;if((aO|0)==0){break}if((fa(330480,c[aO+4>>2]|0)|0)==0){ad=2346;break}else{aN=aO+12|0}}if((ad|0)==2346){g[2317949]=+gGx(c[aO+8>>2]|0,0)}h_(aq,321680,9263600)|0;a[A]=0;if(h$(aq,312328,A)|0){a[9267696]=a[A]&1}a[B]=0;if(h$(aq,304144,B)|0){a[9280028]=a[B]&1}h_(aq,296280,9275897)|0;B=at;while(1){aP=c[B>>2]|0;if((aP|0)==0){break}if((fa(289328,c[aP+4>>2]|0)|0)==0){ad=2354;break}else{B=aP+12|0}}if((ad|0)==2354){g[2319999]=+gGx(c[aP+8>>2]|0,0)}a[C]=0;if(h$(aq,282488,C)|0){a[928e4]=a[C]&1}a[D]=0;if(h$(aq,275784,D)|0){a[9280001]=a[D]&1;aQ=at}else{aQ=at}while(1){aR=c[aQ>>2]|0;if((aR|0)==0){aS=at;break}if((fa(268656,c[aR+4>>2]|0)|0)==0){ad=2361;break}else{aQ=aR+12|0}}if((ad|0)==2361){g[2320001]=+gGx(c[aR+8>>2]|0,0);aS=at}while(1){aT=c[aS>>2]|0;if((aT|0)==0){aU=at;break}if((fa(260784,c[aT+4>>2]|0)|0)==0){ad=2364;break}else{aS=aT+12|0}}if((ad|0)==2364){g[2320002]=+gGx(c[aT+8>>2]|0,0);aU=at}while(1){aV=c[aU>>2]|0;if((aV|0)==0){aW=at;break}if((fa(252368,c[aV+4>>2]|0)|0)==0){ad=2367;break}else{aU=aV+12|0}}do{if((ad|0)==2367){aU=bO()|0;c[aU>>2]=0;aT=dE(c[aV+8>>2]|0,0,0)|0;if((c[aU>>2]|0)!=0){aW=at;break}c[2315899]=aT;aW=at}}while(0);while(1){aX=c[aW>>2]|0;if((aX|0)==0){aY=at;break}if((fa(244864,c[aX+4>>2]|0)|0)==0){ad=2371;break}else{aW=aX+12|0}}do{if((ad|0)==2371){aW=bO()|0;c[aW>>2]=0;aV=dE(c[aX+8>>2]|0,0,0)|0;if((c[aW>>2]|0)!=0){aY=at;break}c[2367336]=aV;aY=at}}while(0);while(1){aZ=c[aY>>2]|0;if((aZ|0)==0){a_=at;break}if((fa(90088,c[aZ+4>>2]|0)|0)==0){ad=2375;break}else{aY=aZ+12|0}}do{if((ad|0)==2375){aY=bO()|0;c[aY>>2]=0;aX=dE(c[aZ+8>>2]|0,0,0)|0;if((c[aY>>2]|0)!=0){a_=at;break}a[9474209]=(aX|0)!=0|0;a_=at}}while(0);while(1){a$=c[a_>>2]|0;if((a$|0)==0){a0=at;break}if((fa(231776,c[a$+4>>2]|0)|0)==0){ad=2379;break}else{a_=a$+12|0}}do{if((ad|0)==2379){a_=bO()|0;c[a_>>2]=0;aZ=dE(c[a$+8>>2]|0,0,0)|0;if((c[a_>>2]|0)!=0){a0=at;break}c[2383017]=aZ;a0=at}}while(0);while(1){a1=c[a0>>2]|0;if((a1|0)==0){a2=at;break}if((fa(225712,c[a1+4>>2]|0)|0)==0){ad=2383;break}else{a0=a1+12|0}}do{if((ad|0)==2383){a0=bO()|0;c[a0>>2]=0;a$=dE(c[a1+8>>2]|0,0,0)|0;if((c[a0>>2]|0)!=0){a2=at;break}c[2383018]=a$;a2=at}}while(0);while(1){a3=c[a2>>2]|0;if((a3|0)==0){a4=at;break}if((fa(220088,c[a3+4>>2]|0)|0)==0){ad=2387;break}else{a2=a3+12|0}}do{if((ad|0)==2387){a2=bO()|0;c[a2>>2]=0;a1=dE(c[a3+8>>2]|0,0,0)|0;if((c[a2>>2]|0)!=0){a4=at;break}c[2383019]=a1;a4=at}}while(0);while(1){a5=c[a4>>2]|0;if((a5|0)==0){a6=at;break}if((fa(216360,c[a5+4>>2]|0)|0)==0){ad=2391;break}else{a4=a5+12|0}}do{if((ad|0)==2391){a4=bO()|0;c[a4>>2]=0;a3=dE(c[a5+8>>2]|0,0,0)|0;if((c[a4>>2]|0)!=0){a6=at;break}c[2383020]=a3;a6=at}}while(0);while(1){a7=c[a6>>2]|0;if((a7|0)==0){break}if((fa(212928,c[a7+4>>2]|0)|0)==0){ad=2395;break}else{a6=a7+12|0}}do{if((ad|0)==2395){a6=bO()|0;c[a6>>2]=0;a5=ch(c[a7+8>>2]|0,0,16)|0;if((c[a6>>2]|0)!=0){break}g[2320003]=+((a5>>>16&255)>>>0>>>0)/255.0;g[2320004]=+((a5>>>8&255)>>>0>>>0)/255.0;g[2320005]=+((a5&255)>>>0>>>0)/255.0}}while(0);a[E]=0;if(h$(aq,208800,E)|0){a[9280025]=a[E]&1}a[F]=0;if(h$(aq,203240,F)|0){a[9280026]=a[F]&1}a[G]=0;if(h$(aq,197208,G)|0){a[9280027]=a[G]&1}h_(aq,191856,9271801)|0;if((fa(9271801,185584)|0)==0){a[9271801]=0;a8=at}else{a8=at}while(1){a9=c[a8>>2]|0;if((a9|0)==0){break}if((fa(180792,c[a9+4>>2]|0)|0)==0){ad=2407;break}else{a8=a9+12|0}}if((ad|0)==2407){g[2331066]=+gGx(c[a9+8>>2]|0,0)}a[H]=0;if(h$(aq,176448,H)|0){a[9324846]=a[H]&1}H=I|0;I=0;while(1){a9=I+1|0;be(H|0,64,172808,(af=i,i=i+8|0,c[af>>2]=a9,af)|0)|0;i=af;a8=at;while(1){ba=c[a8>>2]|0;if((ba|0)==0){break}if((fa(H|0,c[ba+4>>2]|0)|0)==0){ad=2414;break}else{a8=ba+12|0}}do{if((ad|0)==2414){ad=0;a8=bO()|0;c[a8>>2]=0;k=dE(c[ba+8>>2]|0,0,0)|0;if((c[a8>>2]|0)!=0){break}c[9324268+(I<<2)>>2]=k}}while(0);L3383:do{if((a[9395602+I|0]&1)==0){be(H|0,64,169296,(af=i,i=i+8|0,c[af>>2]=a9,af)|0)|0;i=af;k=at;while(1){bb=c[k>>2]|0;if((bb|0)==0){break L3383}if((fa(H|0,c[bb+4>>2]|0)|0)==0){break}else{k=bb+12|0}}k=bO()|0;c[k>>2]=0;a8=dE(c[bb+8>>2]|0,0,0)|0;if((c[k>>2]|0)!=0){break}c[9324232+(I<<2)>>2]=a8}}while(0);if(a9>>>0<8){I=a9}else{break}}a[J]=0;if(h$(aq,166280,J)|0){a[9280064]=a[J]&1;bc=at}else{bc=at}while(1){bd=c[bc>>2]|0;if((bd|0)==0){bf=at;break}if((fa(163240,c[bd+4>>2]|0)|0)==0){ad=2427;break}else{bc=bd+12|0}}do{if((ad|0)==2427){bc=bO()|0;c[bc>>2]=0;J=dE(c[bd+8>>2]|0,0,0)|0;if((c[bc>>2]|0)!=0){bf=at;break}c[2320017]=J;bf=at}}while(0);while(1){bg=c[bf>>2]|0;if((bg|0)==0){bh=at;break}if((fa(159392,c[bg+4>>2]|0)|0)==0){ad=2431;break}else{bf=bg+12|0}}do{if((ad|0)==2431){bf=bO()|0;c[bf>>2]=0;bd=dE(c[bg+8>>2]|0,0,0)|0;if((c[bf>>2]|0)!=0){bh=at;break}c[2320018]=bd;bh=at}}while(0);while(1){bi=c[bh>>2]|0;if((bi|0)==0){bj=at;break}if((fa(156648,c[bi+4>>2]|0)|0)==0){ad=2435;break}else{bh=bi+12|0}}L3409:do{if((ad|0)==2435){bh=4096;bg=9280080;bd=c[bi+8>>2]|0;while(1){bf=bh-1|0;if((bf|0)==0){break}J=a[bd]|0;a[bg]=J;if(J<<24>>24==0){bj=at;break L3409}else{bh=bf;bg=bg+1|0;bd=bd+1|0}}a[bg]=0;if((a[bd]|0)==0){bj=at;break}else{bk=bd}while(1){bh=bk+1|0;if((a[bh]|0)==0){bj=at;break}else{bk=bh}}}}while(0);while(1){bl=c[bj>>2]|0;if((bl|0)==0){break}if((fa(152592,c[bl+4>>2]|0)|0)==0){ad=2442;break}else{bj=bl+12|0}}do{if((ad|0)==2442){bj=bO()|0;c[bj>>2]=0;bk=dE(c[bl+8>>2]|0,0,0)|0;if((c[bj>>2]|0)!=0){break}c[2321044]=bk}}while(0);a[K]=0;if(h$(aq,149248,K)|0){a[9284180]=a[K]&1}a[L]=0;if(h$(aq,145808,L)|0){a[9288277]=a[L]&1;bm=at}else{bm=at}while(1){bn=c[bm>>2]|0;if((bn|0)==0){bo=at;break}if((fa(141976,c[bn+4>>2]|0)|0)==0){ad=2450;break}else{bm=bn+12|0}}if((ad|0)==2450){g[2322070]=+gGx(c[bn+8>>2]|0,0);bo=at}while(1){bp=c[bo>>2]|0;if((bp|0)==0){bq=at;break}if((fa(139136,c[bp+4>>2]|0)|0)==0){ad=2453;break}else{bo=bp+12|0}}if((ad|0)==2453){g[2322071]=+gGx(c[bp+8>>2]|0,0);bq=at}while(1){br=c[bq>>2]|0;if((br|0)==0){bs=at;break}if((fa(136360,c[br+4>>2]|0)|0)==0){ad=2456;break}else{bq=br+12|0}}L3442:do{if((ad|0)==2456){bq=32;bp=9263480;bo=c[br+8>>2]|0;while(1){bn=bq-1|0;if((bn|0)==0){break}bm=a[bo]|0;a[bp]=bm;if(bm<<24>>24==0){bs=at;break L3442}else{bq=bn;bp=bp+1|0;bo=bo+1|0}}a[bp]=0;if((a[bo]|0)==0){bs=at;break}else{bt=bo}while(1){bq=bt+1|0;if((a[bq]|0)==0){bs=at;break}else{bt=bq}}}}while(0);while(1){bu=c[bs>>2]|0;if((bu|0)==0){bv=at;break}if((fa(134016,c[bu+4>>2]|0)|0)==0){ad=2463;break}else{bs=bu+12|0}}L3453:do{if((ad|0)==2463){bs=32;bt=9263512;br=c[bu+8>>2]|0;while(1){bo=bs-1|0;if((bo|0)==0){break}bp=a[br]|0;a[bt]=bp;if(bp<<24>>24==0){bv=at;break L3453}else{bs=bo;bt=bt+1|0;br=br+1|0}}a[bt]=0;if((a[br]|0)==0){bv=at;break}else{bw=br}while(1){bs=bw+1|0;if((a[bs]|0)==0){bv=at;break}else{bw=bs}}}}while(0);while(1){bx=c[bv>>2]|0;if((bx|0)==0){break}if((fa(132272,c[bx+4>>2]|0)|0)==0){ad=2470;break}else{bv=bx+12|0}}L3464:do{if((ad|0)==2470){bv=32;bw=9280032;bu=c[bx+8>>2]|0;while(1){br=bv-1|0;if((br|0)==0){break}bt=a[bu]|0;a[bw]=bt;if(bt<<24>>24==0){break L3464}else{bv=br;bw=bw+1|0;bu=bu+1|0}}a[bw]=0;if((a[bu]|0)==0){break}else{by=bu}do{by=by+1|0;}while((a[by]|0)!=0)}}while(0);h_(aq,128728,9284181)|0;by=at;while(1){bz=c[by>>2]|0;if((bz|0)==0){bA=at;break}if((fa(466008,c[bz+4>>2]|0)|0)==0){ad=2478;break}else{by=bz+12|0}}L3476:do{if((ad|0)==2478){by=32;bx=9288320;bu=c[bz+8>>2]|0;while(1){bw=by-1|0;if((bw|0)==0){break}bv=a[bu]|0;a[bx]=bv;if(bv<<24>>24==0){bA=at;break L3476}else{by=bw;bx=bx+1|0;bu=bu+1|0}}a[bx]=0;if((a[bu]|0)==0){bA=at;break}else{bB=bu}while(1){by=bB+1|0;if((a[by]|0)==0){bA=at;break}else{bB=by}}}}while(0);while(1){bC=c[bA>>2]|0;if((bC|0)==0){break}if((fa(123376,c[bC+4>>2]|0)|0)==0){ad=2485;break}else{bA=bC+12|0}}L3487:do{if((ad|0)==2485){bA=32;bB=9288352;bz=c[bC+8>>2]|0;while(1){bu=bA-1|0;if((bu|0)==0){break}bx=a[bz]|0;a[bB]=bx;if(bx<<24>>24==0){break L3487}else{bA=bu;bB=bB+1|0;bz=bz+1|0}}a[bB]=0;if((a[bz]|0)==0){break}else{bD=bz}do{bD=bD+1|0;}while((a[bD]|0)!=0)}}while(0);if((a[9341252]|0)==0){h_(aq,119488,9341252)|0}a[M]=0;if(h$(aq,116480,M)|0){a[9374058]=a[M]&1}h_(aq,114152,9345348)|0;h_(aq,112272,9333056)|0;h_(aq,110384,9357636)|0;do{if((a[9357636]|0)!=0){if((fa(9357636,185584)|0)==0){a[9357636]=0;break}if((f$(9357636,j|0)|0)>=0){if((c[j+12>>2]&61440|0)==16384){break}}M=c[u>>2]|0;cj(108496,84,1,M|0)|0;eY(M|0)|0;a[9357636]=0}}while(0);h_(aq,106648,9365865)|0;if((fa(9365865,185584)|0)==0){a[9365865]=0}h_(aq,104120,9369961)|0;if((fa(9369961,185584)|0)==0){a[9369961]=0}a[N]=0;if(h$(aq,101696,N)|0){a[9374057]=a[N]&1}h_(aq,98024,9452954)|0;if((fa(9452954,185584)|0)==0){a[9452954]=0}h_(aq,94664,9324856)|0;N=at;while(1){bE=c[N>>2]|0;if((bE|0)==0){bF=at;break}if((fa(91520,c[bE+4>>2]|0)|0)==0){ad=2511;break}else{N=bE+12|0}}if((ad|0)==2511){g[2332238]=+gGx(c[bE+8>>2]|0,0);bF=at}while(1){bG=c[bF>>2]|0;if((bG|0)==0){break}if((fa(89152,c[bG+4>>2]|0)|0)==0){ad=2514;break}else{bF=bG+12|0}}if((ad|0)==2514){g[2332239]=+gGx(c[bG+8>>2]|0,0)}a[O]=0;if(h$(aq,87528,O)|0){a[9365828]=a[O]&1;bH=at}else{bH=at}while(1){bI=c[bH>>2]|0;if((bI|0)==0){bJ=at;break}if((fa(85360,c[bI+4>>2]|0)|0)==0){ad=2519;break}else{bH=bI+12|0}}do{if((ad|0)==2519){bH=bO()|0;c[bH>>2]=0;O=dE(c[bI+8>>2]|0,0,0)|0;if((c[bH>>2]|0)!=0){bJ=at;break}c[2341458]=O*1e6|0;bJ=at}}while(0);while(1){bK=c[bJ>>2]|0;if((bK|0)==0){bL=at;break}if((fa(83752,c[bK+4>>2]|0)|0)==0){ad=2523;break}else{bJ=bK+12|0}}do{if((ad|0)==2523){bJ=bO()|0;c[bJ>>2]=0;bI=dE(c[bK+8>>2]|0,0,0)|0;if((c[bJ>>2]|0)!=0){bL=at;break}c[2341459]=bI;bL=at}}while(0);while(1){bM=c[bL>>2]|0;if((bM|0)==0){ad=2528;break}if((fa(82288,c[bM+4>>2]|0)|0)==0){ad=2527;break}else{bL=bM+12|0}}if((ad|0)==2527){bN=+gGx(c[bM+8>>2]|0,0);g[2341460]=bN;bP=bN}else if((ad|0)==2528){bP=+g[2341460]}if(bP<1.0){g[2341460]=1.0;bQ=at}else{bQ=at}while(1){bR=c[bQ>>2]|0;if((bR|0)==0){break}if((fa(80512,c[bR+4>>2]|0)|0)==0){ad=2533;break}else{bQ=bR+12|0}}if((ad|0)==2533){g[2341461]=+gGx(c[bR+8>>2]|0,0)}a[P]=0;if(h$(aq,78432,P)|0){a[9365848]=a[P]&1;bS=at}else{bS=at}while(1){bT=c[bS>>2]|0;if((bT|0)==0){break}if((fa(76352,c[bT+4>>2]|0)|0)==0){ad=2538;break}else{bS=bT+12|0}}do{if((ad|0)==2538){bS=bO()|0;c[bS>>2]=0;P=dE(c[bT+8>>2]|0,0,0)|0;if((c[bS>>2]|0)!=0){break}c[2341463]=P}}while(0);h_(aq,74024,9349444)|0;h_(aq,71536,9353540)|0;a[Q]=0;if(h$(aq,69384,Q)|0){a[9365856]=a[Q]&1}a[R]=0;if(h$(aq,68104,R)|0){a[9365857]=a[R]&1}a[S]=0;if(h$(aq,66576,S)|0){a[9365858]=a[S]&1}a[T]=0;if(h$(aq,65296,T)|0){a[9365859]=a[T]&1}a[U]=0;if(h$(aq,588760,U)|0){a[9365860]=a[U]&1;bV=at}else{bV=at}while(1){bW=c[bV>>2]|0;if((bW|0)==0){break}if((fa(587128,c[bW+4>>2]|0)|0)==0){ad=2552;break}else{bV=bW+12|0}}do{if((ad|0)==2552){bV=bO()|0;c[bV>>2]=0;U=dE(c[bW+8>>2]|0,0,0)|0;if((c[bV>>2]|0)!=0){break}b[4682931]=U&65535}}while(0);a[V]=0;if(h$(aq,585536,V)|0){a[9365864]=a[V]&1}h_(aq,583504,9337152)|0;V=at;while(1){bX=c[V>>2]|0;if((bX|0)==0){bY=at;break}if((fa(581336,c[bX+4>>2]|0)|0)==0){ad=2559;break}else{V=bX+12|0}}do{if((ad|0)==2559){V=bO()|0;c[V>>2]=0;bW=dE(c[bX+8>>2]|0,0,0)|0;if((c[V>>2]|0)!=0){bY=at;break}c[2335312]=bW;bY=at}}while(0);while(1){bZ=c[bY>>2]|0;if((bZ|0)==0){b_=at;break}if((fa(579168,c[bZ+4>>2]|0)|0)==0){ad=2563;break}else{bY=bZ+12|0}}do{if((ad|0)==2563){bY=bO()|0;c[bY>>2]=0;bX=dE(c[bZ+8>>2]|0,0,0)|0;if((c[bY>>2]|0)!=0){b_=at;break}c[2331212]=bX;b_=at}}while(0);while(1){b$=c[b_>>2]|0;if((b$|0)==0){break}if((fa(577336,c[b$+4>>2]|0)|0)==0){ad=2567;break}else{b_=b$+12|0}}do{if((ad|0)==2567){b_=bO()|0;c[b_>>2]=0;at=dE(c[b$+8>>2]|0,0,0)|0;if((c[b_>>2]|0)!=0){break}c[2331213]=at}}while(0);a[W]=0;if(h$(aq,576248,W)|0){a[9324844]=a[W]&1}a[X]=0;if(h$(aq,574960,X)|0){a[9324845]=a[X]&1}h_(aq,573784,9328960)|0;a[Y]=0;if(h$(aq,572472,Y)|0){a[9532118]=a[Y]&1}L3624:do{if((a[9395600]&1)==0){Y=m|0;if(!(h_(aq,570720,Y)|0)){break}if((fa(Y|0,185584)|0)==0){a[9444762]=0;break}do{if((f$(Y|0,h|0)|0)>=0){if((c[h+12>>2]&61440|0)==16384){b0=4096;b1=9444762;b2=Y}else{break}while(1){X=b0-1|0;if((X|0)==0){ad=2583;break}W=a[b2]|0;a[b1]=W;if(W<<24>>24==0){b3=4096;b4=9416090;b5=Y;break}else{b0=X;b1=b1+1|0;b2=b2+1|0}}do{if((ad|0)==2583){a[b1]=0;if((a[b2]|0)==0){b3=4096;b4=9416090;b5=Y;break}else{b6=b2}while(1){X=b6+1|0;if((a[X]|0)==0){b3=4096;b4=9416090;b5=Y;break}else{b6=X}}}}while(0);while(1){X=b3-1|0;if((X|0)==0){ad=2587;break}W=a[b5]|0;a[b4]=W;if(W<<24>>24==0){break}else{b3=X;b4=b4+1|0;b5=b5+1|0}}do{if((ad|0)==2587){a[b4]=0;if((a[b5]|0)==0){break}else{b7=b5}do{b7=b7+1|0;}while((a[b7]|0)!=0)}}while(0);hH(9416090,568864);break L3624}}while(0);Y=c[u>>2]|0;cj(566512,72,1,Y|0)|0;eY(Y|0)|0}}while(0);L3649:do{if((a[9395601]&1)==0){b7=m|0;if(!(h_(aq,564288,b7)|0)){break}if((fa(b7|0,185584)|0)==0){a[9448858]=0;break}do{if((f$(b7|0,f|0)|0)>=0){if((c[f+12>>2]&61440|0)==16384){b8=4096;b9=9448858;ca=b7}else{break}while(1){b5=b8-1|0;if((b5|0)==0){ad=2599;break}b4=a[ca]|0;a[b9]=b4;if(b4<<24>>24==0){cb=4096;cc=9436570;cd=b7;break}else{b8=b5;b9=b9+1|0;ca=ca+1|0}}do{if((ad|0)==2599){a[b9]=0;if((a[ca]|0)==0){cb=4096;cc=9436570;cd=b7;break}else{ce=ca}while(1){b5=ce+1|0;if((a[b5]|0)==0){cb=4096;cc=9436570;cd=b7;break}else{ce=b5}}}}while(0);while(1){b5=cb-1|0;if((b5|0)==0){ad=2603;break}b4=a[cd]|0;a[cc]=b4;if(b4<<24>>24==0){break}else{cb=b5;cc=cc+1|0;cd=cd+1|0}}do{if((ad|0)==2603){a[cc]=0;if((a[cd]|0)==0){break}else{cf=cd}do{cf=cf+1|0;}while((a[cf]|0)!=0)}}while(0);hH(9436570,562608);break L3649}}while(0);b7=c[u>>2]|0;cj(560904,73,1,b7|0)|0;eY(b7|0)|0}}while(0);if(!(h_(aq,559800,9361732)|0)){cf=c[u>>2]|0;bU(cf|0,558272,(af=i,i=i+8|0,c[af>>2]=9361732,af)|0)|0;i=af;eY(cf|0)|0}if((fa(9361732,185584)|0)==0){a[9361732]=0;cg=0}else{cg=0}do{cf=63960+(cg<<2)|0;L3681:do{if((cg|0)==0){af=0;cd=46688;while(1){cc=9288384+(af*40|0)|0;do{if((a[cc|0]&1)==0){ad=2618}else{cb=c[46696+(af*20|0)>>2]|0;if((af|0)==56){ci=57;break}ce=(af-25|0)>>>0<31?471528:461712;iB(aq,ce,cb,cc);ca=a[cd]|0;if((ca&1)==0){ck=ca}else{iC(aq,ce,cb,cc);ck=a[cd]|0}if((ck&1)==0){ad=2618;break}iD(aq,ce,cb,cc);ad=2618}}while(0);if((ad|0)==2618){ad=0;cc=af+1|0;if((cc|0)==56){break L3681}else{ci=cc}}af=ci;cd=46688+(ci*20|0)|0}}else{cd=0;af=46688;while(1){cc=9288384+(cg*2240|0)+(cd*40|0)|0;do{if((a[cc|0]&1)==0){ad=2627}else{cb=c[46696+(cd*20|0)>>2]|0;if((cd|0)==56){cl=57;break}if((cd-25|0)>>>0<31){ad=2627;break}ce=c[cf>>2]|0;iB(aq,ce,cb,cc);ca=a[af]|0;if((ca&1)==0){cm=ca}else{iC(aq,ce,cb,cc);cm=a[af]|0}if((cm&1)==0){ad=2627;break}iD(aq,ce,cb,cc);ad=2627}}while(0);if((ad|0)==2627){ad=0;cc=cd+1|0;if((cc|0)==56){break L3681}else{cl=cc}}cd=cl;af=46688+(cl*20|0)|0}}}while(0);cg=cg+1|0;}while(cg>>>0<8);hY(aq);ap=1;i=e;return ap|0}function h3(b){b=b|0;var e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;e=i;i=i+336|0;f=e|0;j=e+128|0;k=e+144|0;l=e+208|0;m=e+272|0;n=hZ(b,0)|0;if((n|0)==0){o=gGq(20)|0;if((o|0)==0){p=0;i=e;return p|0}if((c[o-4>>2]&3|0)!=0){gGz(o|0,0,20)}q=o}else{q=n}if((a[9375104]&1)!=0){n=c[u>>2]|0;bU(n|0,556680,(r=i,i=i+8|0,c[r>>2]=b,r)|0)|0;i=r;eY(n|0)|0}h0(q,116480,(a[9374058]&1)!=0?577008:372864);h0(q,119488,9341252);h0(q,114152,9345348);h0(q,74024,9349444);h0(q,87528,(a[9365828]&1)!=0?577008:372864);n=f|0;be(n|0,128,66464,(r=i,i=i+8|0,c[r>>2]=c[2341459],r)|0)|0;i=r;h0(q,83752,n);h0(q,321680,9263600);h0(q,312328,(a[9267696]&1)!=0?577008:372864);be(n|0,128,502616,(r=i,i=i+8|0,h[r>>3]=+g[2315896],r)|0)|0;i=r;h0(q,354352,n);be(n|0,128,502616,(r=i,i=i+8|0,h[r>>3]=+g[2315886],r)|0)|0;i=r;h0(q,564104,n);be(n|0,128,66464,(r=i,i=i+8|0,c[r>>2]=c[2341463],r)|0)|0;i=r;h0(q,76352,n);be(n|0,128,502616,(r=i,i=i+8|0,h[r>>3]=+g[2315887],r)|0)|0;i=r;h0(q,548296,n);h0(q,361416,(a[9263582]&1)!=0?577008:372864);h0(q,370360,(a[9263589]&1)!=0?577008:372864);h0(q,391768,(a[9263580]&1)!=0?577008:372864);h0(q,403152,(a[9271800]&1)!=0?577008:372864);h0(q,507312,(a[9263552]&1)!=0?577008:372864);be(n|0,128,502616,(r=i,i=i+8|0,h[r>>3]=+g[2317949],r)|0)|0;i=r;h0(q,330480,n);h0(q,136360,9263480);h0(q,459224,(a[9263568]&1)!=0?577008:372864);h0(q,448816,(a[9263569]&1)!=0?577008:372864);be(n|0,128,66464,(r=i,i=i+8|0,c[r>>2]=c[2315894],r)|0)|0;i=r;h0(q,437144,n);h0(q,426312,(a[9263570]&1)!=0?577008:372864);be(n|0,128,66464,(r=i,i=i+8|0,c[r>>2]=c[2315893],r)|0)|0;i=r;h0(q,413960,n);h0(q,197208,(a[9280027]&1)!=0?577008:372864);be(n|0,128,66464,(r=i,i=i+8|0,c[r>>2]=c[2315899],r)|0)|0;i=r;h0(q,252368,n);h0(q,110384,(a[9357636]|0)!=0?9357636:185584);be(n|0,128,66464,(r=i,i=i+8|0,c[r>>2]=c[2315898],r)|0)|0;i=r;h0(q,346344,n);h0(q,156648,9280080);h0(q,145808,(a[9288277]&1)!=0?577008:372864);be(n|0,128,502616,(r=i,i=i+8|0,h[r>>3]=+g[2322070],r)|0)|0;i=r;h0(q,141976,n);h0(q,132272,9280032);h0(q,156648,9280080);be(n|0,128,66464,(r=i,i=i+8|0,c[r>>2]=c[2320017],r)|0)|0;i=r;h0(q,163240,n);h0(q,559800,(a[9361732]|0)!=0?9361732:185584);h0(q,570720,(a[9444762]|0)!=0?9444762:185584);h0(q,564288,(a[9448858]|0)!=0?9448858:185584);h0(q,191856,(a[9271801]|0)!=0?9271801:185584);h0(q,106648,(a[9365865]|0)!=0?9365865:185584);h0(q,104120,(a[9369961]|0)!=0?9369961:185584);h0(q,101696,(a[9374057]&1)!=0?577008:372864);h0(q,583504,9337152);be(n|0,128,66464,(r=i,i=i+8|0,c[r>>2]=c[2335312],r)|0)|0;i=r;h0(q,581336,n);h0(q,573784,9328960);h0(q,98024,(a[9452954]|0)!=0?9452954:185584);h0(q,94664,9324856);be(n|0,128,502616,(r=i,i=i+8|0,h[r>>3]=+g[2332238],r)|0)|0;i=r;h0(q,91520,n);be(n|0,128,502616,(r=i,i=i+8|0,h[r>>3]=+g[2332239],r)|0)|0;i=r;h0(q,89152,n);h0(q,555768,(c[2383023]|0)!=0?577008:372864);f=9532104;o=c[f>>2]|0;s=c[f+4>>2]|0;h0(q,554096,(o&8192|0)!=0|(s&0|0)!=0?577008:372864);h0(q,552576,(o&32768|0)!=0|(s&0|0)!=0?577008:372864);h0(q,550648,(o&16384|0)!=0|(s&0|0)!=0?577008:372864);be(n|0,128,66464,(r=i,i=i+8|0,c[r>>2]=d[9532096]|0,r)|0)|0;i=r;h0(q,548432,n);be(n|0,128,66464,(r=i,i=i+8|0,c[r>>2]=d[9532097]|0,r)|0)|0;i=r;h0(q,546520,n);be(n|0,128,66464,(r=i,i=i+8|0,c[r>>2]=c[2383011],r)|0)|0;i=r;h0(q,545016,n);be(n|0,128,66464,(r=i,i=i+8|0,c[r>>2]=c[2383019],r)|0)|0;i=r;h0(q,220088,n);be(n|0,128,66464,(r=i,i=i+8|0,c[r>>2]=c[2383020],r)|0)|0;i=r;h0(q,216360,n);be(n|0,128,66464,(r=i,i=i+8|0,c[r>>2]=c[2383017],r)|0)|0;i=r;h0(q,231776,n);be(n|0,128,66464,(r=i,i=i+8|0,c[r>>2]=c[2383018],r)|0)|0;i=r;h0(q,225712,n);be(n|0,128,502616,(r=i,i=i+8|0,h[r>>3]=+g[2319999],r)|0)|0;i=r;h0(q,289328,n);h0(q,572472,(a[9532118]&1)!=0?577008:372864);be(n|0,128,66464,(r=i,i=i+8|0,c[r>>2]=c[2383025],r)|0)|0;i=r;h0(q,543856,n);be(n|0,128,66464,(r=i,i=i+8|0,c[r>>2]=c[2367336],r)|0)|0;i=r;h0(q,244864,n);be(n|0,128,66464,(r=i,i=i+8|0,c[r>>2]=a[9474209]&1,r)|0)|0;i=r;h0(q,90088,n);s=9532104;h0(q,542416,(c[s>>2]&262144|0)!=0|(c[s+4>>2]&0|0)!=0?577008:372864);h0(q,466008,9288320);h0(q,123376,9288352);s=m|0;m=0;while(1){o=m+1|0;be(s|0,64,541720,(r=i,i=i+8|0,c[r>>2]=o,r)|0)|0;i=r;be(n|0,128,66464,(r=i,i=i+8|0,c[r>>2]=c[9324300+(m<<2)>>2],r)|0)|0;i=r;h0(q,s,n);be(s|0,64,172808,(r=i,i=i+8|0,c[r>>2]=o,r)|0)|0;i=r;be(n|0,128,66464,(r=i,i=i+8|0,c[r>>2]=c[9324268+(m<<2)>>2],r)|0)|0;i=r;h0(q,s,n);be(s|0,64,169296,(r=i,i=i+8|0,c[r>>2]=o,r)|0)|0;i=r;be(n|0,128,66464,(r=i,i=i+8|0,c[r>>2]=c[9324232+(m<<2)>>2],r)|0)|0;i=r;h0(q,s,n);if(o>>>0<8){m=o}else{break}}m=k|0;k=l|0;s=j|0;j=l+1|0;l=0;L3726:do{o=(l|0)==0;f=63960+(l<<2)|0;t=0;do{v=(t-25|0)>>>0<31;do{if(o){w=v?471528:461712;x=2650}else{if(v){break}w=c[f>>2]|0;x=2650}}while(0);do{if((x|0)==2650){x=0;v=c[46696+(t*20|0)>>2]|0;if((a[9288384+(l*2240|0)+(t*40|0)|0]&1)==0){break}be(m|0,64,473112,(r=i,i=i+16|0,c[r>>2]=w,c[r+8>>2]=v,r)|0)|0;i=r;y=c[9288384+(l*2240|0)+(t*40|0)+12>>2]|0;a[k]=0;L3737:do{if((y-97|0)>>>0<26){a[k]=y&255;a[j]=0}else{z=0;while(1){if((z|0)==67){break L3737}if((c[46148+(z<<3)>>2]|0)==(y|0)){break}else{z=z+1|0}}A=64;B=k;C=c[46144+(z<<3)>>2]|0;while(1){D=A-1|0;if((D|0)==0){break}E=a[C]|0;a[B]=E;if(E<<24>>24==0){break L3737}else{A=D;B=B+1|0;C=C+1|0}}a[B]=0;if((a[C]|0)==0){break}else{F=C}do{F=F+1|0;}while((a[F]|0)!=0)}}while(0);h0(q,m,k);be(m|0,64,470032,(r=i,i=i+16|0,c[r>>2]=w,c[r+8>>2]=v,r)|0)|0;i=r;y=9288384+(l*2240|0)+(t*40|0)+16|0;C=c[y>>2]|0;B=c[y+4>>2]|0;do{if((C|0)==65535&(B|0)==0){h0(q,m,333832)}else{y=C&61440;A=B&0;if((y|0)==0&(A|0)==0){z=520248;be(n|0,128,z|0,(r=i,i=i+16|0,c[r>>2]=C,c[r+8>>2]=B,r)|0)|0;i=r;h0(q,m,n);break}z=C&-61441;D=4096;E=0;G=8192;H=0;I=32768;J=0;if((y|0)==16384&(A|0)==0){K=181376}else if((y|0)==(G|0)&(A|0)==(H|0)){K=173408}else if((y|0)==(D|0)&(A|0)==(E|0)){K=166840}else if((y|0)==(I|0)&(A|0)==(J|0)){K=192464}else{x=2667;break L3726}be(s|0,16,529336,(r=i,i=i+16|0,c[r>>2]=z,c[r+8>>2]=K,r)|0)|0;i=r;h0(q,m,s)}}while(0);be(m|0,64,468488,(r=i,i=i+16|0,c[r>>2]=w,c[r+8>>2]=v,r)|0)|0;i=r;C=c[9288384+(l*2240|0)+(t*40|0)+32>>2]|0;if((C|0)==-1){h0(q,m,333832);break}B=C>>>16;if((B|0)==65535){z=C&65535;C=(z|0)==65535;if(C){break}else{L=C?0:z;M=C?0:43}}else{L=B;M=45}B=M&255;be(s|0,16,538144,(r=i,i=i+16|0,c[r>>2]=B,c[r+8>>2]=L,r)|0)|0;i=r;h0(q,m,s)}}while(0);t=t+1|0;}while((t|0)!=56);l=l+1|0;}while(l>>>0<8);if((x|0)==2667){x=c[u>>2]|0;bU(x|0,547632,(r=i,i=i+16|0,c[r>>2]=237800,c[r+8>>2]=958,r)|0)|0;i=r;eY(x|0)|0;fm(2);return 0}x=h1(q,b)|0;hY(q);p=x;i=e;return p|0}function h4(b,d){b=b|0;d=d|0;var e=0.0,f=0,h=0,i=0,j=0,k=0.0,l=0.0,m=0,n=0,o=0;do{if(!((b&524288|0)==0&(d&0|0)==0)){e=+g[2332238]+-.009999999776482582;g[2332238]=e;if(e>=0.0){break}g[2332238]=0.0}}while(0);do{if(!((b&1048576|0)==0&(d&0|0)==0)){e=+g[2332238]+.009999999776482582;g[2332238]=e;if(e<=1.0){break}g[2332238]=1.0}}while(0);if(!((b&1073741824|0)==0&(d&0|0)==0)){g[2332238]=1.0}do{if(!((b&2097152|0)==0&(d&0|0)==0)){e=+g[2332239]+-.009999999776482582;g[2332239]=e;if(e>=.009999999776482582){break}g[2332239]=.009999999776482582}}while(0);do{if(!((b&4194304|0)==0&(d&0|0)==0)){e=+g[2332239]+.009999999776482582;g[2332239]=e;if(e<=2.0){break}g[2332239]=2.0}}while(0);if(!((b&-2147483648|0)==0&(d&0|0)==0)){g[2332239]=1.0}f=c[2341459]|0;if((b&67108864|0)==0&(d&0|0)==0){h=f}else{i=f+1|0;c[2341459]=i;h=i}if(((b&33554432|0)!=0|(d&0|0)!=0)&h>>>0>1){c[2341459]=h-1}if(!((b&134217728|0)==0&(d&0|0)==0)){c[2341459]=1}if(!((b&8388608|0)==0&(d&0|0)==0)){a[9263568]=a[9263568]&1^1}if(!((b&16777216|0)==0&(d&0|0)==0)){a[9263552]=a[9263552]&1^1}if(!((b&536870912|0)==0&(d&0|0)==0)){a[9263568]=1}h=c[2315898]|0;if(((b&1|0)!=0|(d&0|0)!=0)&(h|0)!=0){i=h-1|0;c[2315898]=i;j=i}else{j=h}if(((b&2|0)!=0|(d&0|0)!=0)&j>>>0<7){c[2315898]=j+1}if(!((b&4|0)==0&(d&0|0)==0)){a[9263589]=a[9263589]&1^1}if(!((b&8|0)==0&(d&0|0)==0)){a[9474209]=a[9474209]&1^1}do{if(!((b&16|0)==0&(d&0|0)==0)){e=+g[2322070];if(e>0.0){k=e+-.001;g[2322070]=k;l=k}else{l=e}if(l<5.0e-4){a[9288277]=0;g[2322070]=0.0;break}else{a[9288277]=1;break}}}while(0);if(!((b&32|0)==0&(d&0|0)==0)){l=+g[2322070];if(l<.2){g[2322070]=l+.001}a[9288277]=1}if(!((b&64|0)==0&(d&0|0)==0)){a[9263580]=a[9263580]&1^1}j=c[2383010]|0;if(((b&128|0)!=0|(d&0|0)!=0)&(j|0)!=0){h=j-1|0;c[2383010]=h;c[2383011]=c[(c[2383014]|0)+(h<<2)>>2];m=h}else{m=j}do{if(!((b&256|0)==0&(d&0|0)==0)){j=m+1|0;if(j>>>0>=(c[2383015]|0)>>>0){break}c[2383010]=j;c[2383011]=c[(c[2383014]|0)+(j<<2)>>2]}}while(0);m=c[2315899]|0;if(((b&512|0)!=0|(d&0|0)!=0)&(m|0)!=0){j=m-1|0;c[2315899]=j;n=j}else{n=m}if(((b&1024|0)!=0|(d&0|0)!=0)&n>>>0<3){c[2315899]=n+1}if(!((b&2048|0)==0&(d&0|0)==0)){a[9365828]=a[9365828]&1^1}n=c[2367336]|0;if(((b&4096|0)!=0|(d&0|0)!=0)&(n|0)!=0){m=n-1|0;c[2367336]=m;o=m}else{o=n}if(!((b&8192|0)==0&(d&0|0)==0)){c[2367336]=o+1}do{if(!((b&16384|0)==0&(d&0|0)==0)){o=9532104;n=c[o>>2]|0;m=c[o+4>>2]|0;if((n&8192|0)==0&(m&0|0)==0){o=9532104;c[o>>2]=n|8192;c[o+4>>2]=m;break}else{o=9532104;c[o>>2]=n&-8193;c[o+4>>2]=m|0;break}}}while(0);if(!((b&32768|0)==0&(d&0|0)==0)){g[2317949]=+g[2317949]+-.009999999776482582}if(!((b&65536|0)==0&(d&0|0)==0)){g[2317949]=+g[2317949]+.009999999776482582}if(!((b&131072|0)==0&(d&0|0)==0)){a[9374058]=a[9374058]&1^1}if(!((b&268435456|0)==0&(d&0|0)==0)){c[2315898]=4}if(!((b&0|0)==0&(d&1|0)==0)){a[9263589]=0}if(!((b&0|0)==0&(d&2|0)==0)){a[9474209]=0}if(!((b&0|0)==0&(d&4|0)==0)){g[2322070]=.004999999888241291;a[9288277]=1}if(!((b&0|0)==0&(d&8|0)==0)){a[9263580]=1}if(!((b&0|0)==0&(d&16|0)==0)){c[2315899]=0}if(!((b&0|0)==0&(d&32|0)==0)){m=9532104;o=c[m+4>>2]|0;n=9532104;c[n>>2]=c[m>>2]|8192;c[n+4>>2]=o}if(!((b&0|0)==0&(d&64|0)==0)){c[2367336]=0}if(!((b&0|0)==0&(d&128|0)==0)){g[2317949]=59.95000076293945}if((b&0|0)==0&(d&256|0)==0){return}a[9374058]=0;return}function h5(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;b=c9(c[a>>2]|0)|0;c[a+68>>2]=b;c[a+72>>2]=c9(c[a+4>>2]|0)|0;c[a+76>>2]=c9(c[a+8>>2]|0)|0;c[a+80>>2]=c9(c[a+12>>2]|0)|0;c[a+84>>2]=c9(c[a+16>>2]|0)|0;c[a+88>>2]=c9(c[a+20>>2]|0)|0;c[a+92>>2]=c9(c[a+24>>2]|0)|0;c[a+96>>2]=c9(c[a+28>>2]|0)|0;c[a+100>>2]=c9(c[a+32>>2]|0)|0;c[a+104>>2]=c9(c[a+36>>2]|0)|0;c[a+108>>2]=c9(c[a+40>>2]|0)|0;c[a+112>>2]=c9(c[a+44>>2]|0)|0;c[a+116>>2]=c9(c[a+48>>2]|0)|0;c[a+120>>2]=c9(c[a+52>>2]|0)|0;c[a+124>>2]=c9(c[a+56>>2]|0)|0;c[a+128>>2]=c9(c[a+60>>2]|0)|0;d=16;e=b;while(1){b=c[a+68+(d-15<<2)>>2]|0;f=c[a+68+(d-2<<2)>>2]|0;c[a+68+(d<<2)>>2]=(c[a+68+(d-7<<2)>>2]|0)+e+((b>>>18|b<<14)^b>>>3^(b>>>7|b<<25))+((f>>>19|f<<13)^f>>>10^(f>>>17|f<<15));f=d+1|0;if(f>>>0<64){d=f;e=b}else{break}}e=a+324|0;d=c[e>>2]|0;b=a+328|0;f=c[b>>2]|0;g=a+332|0;h=c[g>>2]|0;i=a+336|0;j=c[i>>2]|0;k=a+340|0;l=c[k>>2]|0;m=a+344|0;n=c[m>>2]|0;o=a+348|0;p=c[o>>2]|0;q=a+352|0;r=c[q>>2]|0;s=f;t=h;u=j;v=l;w=n;x=p;y=r;z=d;A=0;while(1){B=(x&~v^v&w)+y+((v>>>6|v<<26)^(v>>>11|v<<21)^(v>>>25|v<<7))+(c[7461216+(A<<2)>>2]|0)+(c[a+68+(A<<2)>>2]|0)|0;C=B+u|0;D=((s^t)&z^s&t)+((z>>>2|z<<30)^(z>>>13|z<<19)^(z>>>22|z<<10))+B|0;B=A+1|0;if(B>>>0<64){u=t;t=s;s=z;y=x;x=w;w=v;v=C;z=D;A=B}else{break}}c[e>>2]=D+d;c[b>>2]=z+f;c[g>>2]=s+h;c[i>>2]=t+j;c[k>>2]=C+l;c[m>>2]=v+n;c[o>>2]=w+p;c[q>>2]=x+r;c[a+64>>2]=0;return}function h6(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0;e=i;i=i+4096|0;f=e|0;if((b|0)==16){if((a[9375104]&1)!=0){g=c[u>>2]|0;cj(141168,34,1,g|0)|0;eY(g|0)|0}g=c[2368540]|0;if((g|0)!=0){h=g+4104|0;if((c[h>>2]|0)==0){j=g|0}else{k=g+4100|0;l=g|0;m=0;while(1){n=c[k>>2]|0;h0(c[l>>2]|0,c[n+(m<<4)+4>>2]|0,c[(c[c[n+(m<<4)+8>>2]>>2]|0)+(c[n+(m<<4)+12>>2]<<3)>>2]|0);n=m+1|0;if(n>>>0<(c[h>>2]|0)>>>0){m=n}else{j=l;break}}}l=c[j>>2]|0;j=g+4|0;h1(l,j)|0;iL(c[2368540]|0)}j=d;if((a[9333056]|0)!=0|(a[9395610]|0)==0){o=9333056}else{l=f|0;hM(l,9395610,113744);o=l}l=gGq(4112)|0;L3938:do{if((l|0)==0){p=0}else{if((c[l-4>>2]&3|0)!=0){gGz(l|0,0,4112)}f=l;if((a[o]|0)==0){q=c[l>>2]|0}else{g=hZ(o,0)|0;c[l>>2]=g;q=g}g=l;if((q|0)==0){m=gGq(20)|0;do{if((m|0)!=0){if((c[m-4>>2]&3|0)==0){break}gGz(m|0,0,20)}}while(0);c[g>>2]=m}h=4096;k=l+4|0;n=o;while(1){r=h-1|0;if((r|0)==0){s=2825;break}t=a[n]|0;a[k]=t;if(t<<24>>24==0){break}else{h=r;k=k+1|0;n=n+1|0}}do{if((s|0)==2825){a[k]=0;if((a[n]|0)==0){break}else{v=n}do{v=v+1|0;}while((a[v]|0)!=0)}}while(0);do{if((c[g>>2]|0)!=0){n=d;k=c[n>>2]|0;h=(k|0)==0;do{if(h){w=0;x=0}else{m=j;r=0;while(1){if((c[m+4>>2]|0)==0){y=r;break}t=r+1|0;z=m+8|0;if((c[z>>2]|0)==0){y=t;break}else{m=z;r=t}}if((y|0)==0){w=0;x=0;break}r=y<<4;if(y>>>0<=65535){w=r;x=y;break}w=((r>>>0)/(y>>>0)|0|0)==16?r:-1;x=y}}while(0);r=gGq(w)|0;if((r|0)==0){c[l+4100>>2]=0;break}if((c[r-4>>2]&3|0)==0){m=l+4100|0;c[m>>2]=r;A=m}else{gGz(r|0,0,w|0);m=l+4100|0;c[m>>2]=r;A=m}c[l+4104>>2]=x;if(h){p=f;break L3938}m=c[u>>2]|0;r=0;t=n;z=k;while(1){B=t+4|0;if((c[B>>2]|0)==0){p=f;break L3938}C=c[A>>2]|0;D=C+(r<<4)+4|0;c[D>>2]=bG(z|0)|0;E=bG(c[B>>2]|0)|0;B=e3(E|0,574e3)|0;if((B|0)==0){s=2843;break}a[B]=0;F=C+(r<<4)|0;c[F>>2]=bG(E|0)|0;G=hA(B+2|0,256984)|0;B=C+(r<<4)+8|0;c[B>>2]=G;if((G|0)==0){s=2845;break}G=c[D>>2]|0;H=(c[g>>2]|0)+4|0;while(1){I=c[H>>2]|0;if((I|0)==0){break}if((fa(G|0,c[I+4>>2]|0)|0)==0){s=2849;break}else{H=I+12|0}}if((s|0)==2849){s=0;H=bG(c[I+8>>2]|0)|0;G=c[B>>2]|0;J=c[G+4>>2]|0;L=G|0;G=0;while(1){if(G>>>0>=J>>>0){break}if((fa(c[(c[L>>2]|0)+(G<<3)>>2]|0,H|0)|0)==0){s=2852;break}else{G=G+1|0}}if((s|0)==2852){s=0;c[C+(r<<4)+12>>2]=G}gGr(H)}gGr(E);L=a[9375104]|0;if((L&1)==0){M=L}else{cj(442816,24,1,m|0)|0;eY(m|0)|0;M=a[9375104]|0}if((M&1)==0){N=M}else{L=c[F>>2]|0;bU(m|0,342040,(O=i,i=i+8|0,c[O>>2]=L,O)|0)|0;i=O;eY(m|0)|0;N=a[9375104]|0}if((N&1)==0){P=N}else{L=c[D>>2]|0;bU(m|0,264968,(O=i,i=i+8|0,c[O>>2]=L,O)|0)|0;i=O;eY(m|0)|0;P=a[9375104]|0}if((P&1)==0){Q=P}else{L=c[A>>2]|0;J=c[(c[c[L+(r<<4)+8>>2]>>2]|0)+(c[L+(r<<4)+12>>2]<<3)>>2]|0;bU(m|0,206432,(O=i,i=i+8|0,c[O>>2]=J,O)|0)|0;i=O;eY(m|0)|0;Q=a[9375104]|0}if((Q&1)!=0){cj(161752,29,1,m|0)|0;eY(m|0)|0}J=c[B>>2]|0;if((c[J+4>>2]|0)!=0){L=0;R=J;while(1){if((a[9375104]&1)==0){S=R}else{J=c[(c[R>>2]|0)+(L<<3)>>2]|0;bU(m|0,131400,(O=i,i=i+8|0,c[O>>2]=J,O)|0)|0;i=O;eY(m|0)|0;S=c[B>>2]|0}J=L+1|0;if(J>>>0<(c[S+4>>2]|0)>>>0){L=J;R=S}else{break}}}R=t+8|0;L=c[R>>2]|0;if((L|0)==0){p=f;break L3938}else{r=r+1|0;t=R;z=L}}if((s|0)==2845){gGr(E);break}else if((s|0)==2843){gGr(E);break}}}while(0);iL(f);p=0}}while(0);c[2368540]=p;T=1;i=e;return T|0}else if((b|0)==15){if((a[9375104]&1)!=0){p=c[u>>2]|0;E=c[d>>2]|0;bU(p|0,293976,(O=i,i=i+8|0,c[O>>2]=E,O)|0)|0;i=O;eY(p|0)|0}p=c[2368540]|0;do{if((p|0)==0){c[d+4>>2]=0;U=0}else{a[p+4108|0]=0;E=c[p+4104>>2]|0;S=p+4100|0;Q=d;A=0;while(1){if(A>>>0>=E>>>0){s=2794;break}V=c[S>>2]|0;if((fa(c[V+(A<<4)+4>>2]|0,c[Q>>2]|0)|0)==0){s=2793;break}else{A=A+1|0}}if((s|0)==2793){Q=c[(c[c[V+(A<<4)+8>>2]>>2]|0)+(c[V+(A<<4)+12>>2]<<3)>>2]|0;c[d+4>>2]=Q;U=Q;break}else if((s|0)==2794){c[d+4>>2]=0;U=0;break}}}while(0);if((a[9375104]&1)==0){T=1;i=e;return T|0}V=c[u>>2]|0;bU(V|0,224024,(O=i,i=i+8|0,c[O>>2]=(U|0)==0?539208:U,O)|0)|0;i=O;eY(V|0)|0;T=1;i=e;return T|0}else if((b|0)==131073|(b|0)==131074){L4044:do{if((d|0)==0){a[9411994]=0}else{V=4096;U=9411994;p=d;while(1){Q=V-1|0;if((Q|0)==0){break}S=a[p]|0;a[U]=S;if(S<<24>>24==0){break L4044}else{V=Q;U=U+1|0;p=p+1|0}}a[U]=0;if((a[p]|0)==0){break}else{W=p}do{W=W+1|0;}while((a[W]|0)!=0)}}while(0);W=(a[9375104]&1)!=0;if((b|0)==131074){if(W){p=c[u>>2]|0;cj(212040,42,1,p|0)|0;eY(p|0)|0}a[9523608]=1;T=1;i=e;return T|0}else{if(!W){T=1;i=e;return T|0}W=c[u>>2]|0;cj(207304,35,1,W|0)|0;eY(W|0)|0;T=1;i=e;return T|0}}else if((b|0)==10){W=c[d>>2]|0;do{if((W|0)==0){if((a[9375104]&1)==0){break}p=c[u>>2]|0;cj(531360,47,1,p|0)|0;eY(p|0)|0}else if((W|0)==2){if((a[9375104]&1)==0){break}p=c[u>>2]|0;cj(517568,45,1,p|0)|0;eY(p|0)|0}else if((W|0)==1){if((a[9375104]&1)==0){break}p=c[u>>2]|0;cj(504464,47,1,p|0)|0;eY(p|0)|0}else{T=0;i=e;return T|0}}while(0);c[2367360]=W;T=1;i=e;return T|0}else if((b|0)==11){gGz(9469448,0,512);W=c[d+16>>2]|0;if((W|0)!=0){p=d;U=W;while(1){W=c[p>>2]|0;do{if(W>>>0<=7){if((c[p+4>>2]|0)!=1){break}V=c[p+12>>2]|0;if(V>>>0>15){break}c[9469448+(W<<6)+(V<<2)>>2]=U}}while(0);W=c[p+36>>2]|0;if((W|0)==0){break}else{p=p+20|0;U=W}}}U=c[u>>2]|0;if((a[9375104]&1)==0){X=0}else{cj(328720,42,1,U|0)|0;eY(U|0)|0;X=0}while(1){p=X+1|0;W=0;do{V=c[9469448+(X<<6)+(W<<2)>>2]|0;do{if((V|0)!=0){if((a[9375104]&1)==0){break}A=c[7400+(W<<2)>>2]|0;bU(U|0,319280,(O=i,i=i+24|0,c[O>>2]=p,c[O+8>>2]=A,c[O+16>>2]=V,O)|0)|0;i=O;eY(U|0)|0}}while(0);W=W+1|0;}while(W>>>0<16);if(p>>>0<8){X=p}else{T=1;break}}i=e;return T|0}else if((b|0)==6){if((a[9375104]&1)!=0){X=c[u>>2]|0;U=c[d>>2]|0;bU(X|0,88712,(O=i,i=i+8|0,c[O>>2]=U,O)|0)|0;i=O;eY(X|0)|0}X=c[2380901]|0;if((X|0)==0){T=1;i=e;return T|0}U=X+4|0;W=c[U>>2]|0;if(W>>>0>1){V=X|0;A=1;Q=W;while(1){W=c[(c[V>>2]|0)+(A<<2)>>2]|0;if((W|0)==0){Y=Q}else{gGr(c[W+8>>2]|0);gGr(c[(c[V>>2]|0)+(A<<2)>>2]|0);c[(c[V>>2]|0)+(A<<2)>>2]=0;Y=c[U>>2]|0}W=A+1|0;if(W>>>0<Y>>>0){A=W;Q=Y}else{break}}}c[U>>2]=1;U=X+12|0;gGr(c[U>>2]|0);c[U>>2]=0;U=c[2380901]|0;X=c[d>>2]|0;Y=U+4|0;Q=c[Y>>2]|0;if(Q>>>0>=(c[U+8>>2]|0)>>>0){T=1;i=e;return T|0}A=c[d+4>>2]|0;V=gGq(12)|0;do{if((V|0)!=0){if((c[V-4>>2]&3|0)==0){break}gGz(V|0,0,12)}}while(0);c[V+4>>2]=1;c[V>>2]=A;if((X|0)==0){Z=0;_=Q}else{Q=bG(X|0)|0;Z=Q;_=c[Y>>2]|0}c[V+8>>2]=Z;Z=U|0;c[(c[Z>>2]|0)+(_<<2)>>2]=V;V=c[Y>>2]|0;c[Y>>2]=V+1;if(V>>>0>1){$=V}else{T=1;i=e;return T|0}while(1){V=$>>>1;Y=c[Z>>2]|0;_=Y+(V<<2)|0;U=c[_>>2]|0;Q=c[Y+($<<2)>>2]|0;if((c[Q+4>>2]|0)>>>0<=(c[U+4>>2]|0)>>>0){T=1;s=3001;break}c[_>>2]=Q;c[(c[Z>>2]|0)+($<<2)>>2]=U;if($>>>0>3){$=V}else{T=1;s=3002;break}}if((s|0)==3001){i=e;return T|0}else if((s|0)==3002){i=e;return T|0}}else if((b|0)==1){$=c[d>>2]|0;if((a[9375104]&1)!=0){Z=c[u>>2]|0;bU(Z|0,69088,(O=i,i=i+8|0,c[O>>2]=$,O)|0)|0;i=O;eY(Z|0)|0}if((a[9280028]&1)==0){T=1;i=e;return T|0}c[2367357]=$;Z=c[2383355]|0;if((Z|0)==0){T=0;i=e;return T|0}V=c[Z+36>>2]|0;if((V|0)==0){T=0;i=e;return T|0}Z=c[2383358]|0;if((Z|0)==0){T=1;i=e;return T|0}gg[V&4095](Z,$);T=1;i=e;return T|0}else if((b|0)==2){a[d]=a[9263582]&1^1;if((a[9375104]&1)==0){T=1;i=e;return T|0}$=c[u>>2]|0;bU($|0,491832,(O=i,i=i+8|0,c[O>>2]=(a[9263582]&1^1)&255,O)|0)|0;i=O;eY($|0)|0;T=1;i=e;return T|0}else if((b|0)==3){a[d]=1;if((a[9375104]&1)==0){T=1;i=e;return T|0}$=c[u>>2]|0;cj(377616,38,1,$|0)|0;eY($|0)|0;T=1;i=e;return T|0}else if((b|0)==12){if((a[9375104]&1)!=0){$=c[u>>2]|0;cj(310296,42,1,$|0)|0;eY($|0)|0}c[2368514]=c[d>>2];T=1;i=e;return T|0}else if((b|0)==13){if((a[9375104]&1)!=0){$=c[u>>2]|0;cj(302176,47,1,$|0)|0;eY($|0)|0}c[2368517]=c[d>>2];c[2368518]=c[d+4>>2];c[2368519]=c[d+8>>2];c[2368520]=c[d+12>>2];c[2368521]=c[d+16>>2];c[2368522]=c[d+20>>2];c[2368523]=c[d+24>>2];T=1;i=e;return T|0}else if((b|0)==14|(b|0)==65550){if((a[9375104]&1)!=0){$=c[u>>2]|0;cj(294512,34,1,$|0)|0;eY($|0)|0}$=c[d>>2]|0;do{if(($|0)==0){if((a[9375104]&1)==0){break}Z=c[u>>2]|0;cj(287776,37,1,Z|0)|0;eY(Z|0)|0}else if(($|0)==2){if((a[9375104]&1)==0){break}Z=c[u>>2]|0;cj(281040,41,1,Z|0)|0;eY(Z|0)|0}else if(($|0)==1|($|0)==3){Z=c[u>>2]|0;cj(273712,116,1,Z|0)|0;eY(Z|0)|0;T=0;i=e;return T|0}else{if((a[9375104]&1)==0){T=0;i=e;return T|0}Z=c[u>>2]|0;cj(266960,39,1,Z|0)|0;eY(Z|0)|0;T=0;i=e;return T|0}}while(0);c[d+8>>2]=3016;c[d+12>>2]=2284;if((b&65536|0)==0){gGC(9474096,d|0,40)|0;T=1;i=e;return T|0}else{c[2368524]=c[d>>2];c[2368525]=c[d+4>>2];c[2368526]=c[d+8>>2];c[2368527]=c[d+12>>2];a[9474112]=a[d+16|0]|0;T=1;i=e;return T|0}}else if((b|0)==17){$=c[2368540]|0;if(($|0)==0){aa=0}else{aa=a[$+4108|0]&1}a[d]=aa;T=1;i=e;return T|0}else if((b|0)==7){if((a[9375104]&1)!=0){aa=c[u>>2]|0;cj(577176,29,1,aa|0)|0;eY(aa|0)|0}a[9469432]=1;T=1;i=e;return T|0}else if((b|0)==8){aa=c[d>>2]|0;c[2367359]=aa;if((a[9375104]&1)==0){T=1;i=e;return T|0}$=c[u>>2]|0;bU($|0,560672,(O=i,i=i+8|0,c[O>>2]=aa,O)|0)|0;i=O;eY($|0)|0;T=1;i=e;return T|0}else if((b|0)==9){c[d>>2]=(a[9361732]|0)!=0?9361732:0;if((a[9375104]&1)==0){T=1;i=e;return T|0}$=c[u>>2]|0;bU($|0,544816,(O=i,i=i+8|0,c[O>>2]=9361732,O)|0)|0;i=O;eY($|0)|0;T=1;i=e;return T|0}else if((b|0)==24){if((a[9375104]&1)!=0){$=c[u>>2]|0;cj(224352,50,1,$|0)|0;eY($|0)|0}$=d;aa=c[2383356]|0;if((aa|0)==0){T=0;i=e;return T|0}Z=c[aa+28>>2]|0;aa=c[2383359]|0;if(!((Z|0)!=0&(aa|0)!=0)){T=0;i=e;return T|0}V=gj[Z&4095](aa)|0;c[$>>2]=V;c[$+4>>2]=K;T=1;i=e;return T|0}else if((b|0)==65561){if((a[9375104]&1)!=0){$=c[u>>2]|0;cj(219152,41,1,$|0)|0;eY($|0)|0}c[d>>2]=2264;T=1;i=e;return T|0}else if((b|0)==131072){if((a[9375104]&1)!=0){$=c[u>>2]|0;cj(215392,48,1,$|0)|0;eY($|0)|0}$=fw(d|0,364392)|0;if(($|0)==0){T=0;i=e;return T|0}aY($|0)|0;$=4096;V=9341252;aa=d;while(1){Z=$-1|0;if((Z|0)==0){break}U=a[aa]|0;a[V]=U;if(U<<24>>24==0){T=1;s=2993;break}else{$=Z;V=V+1|0;aa=aa+1|0}}if((s|0)==2993){i=e;return T|0}a[V]=0;if((a[aa]|0)==0){T=1;i=e;return T|0}else{ab=aa}while(1){aa=ab+1|0;if((a[aa]|0)==0){T=1;break}else{ab=aa}}i=e;return T|0}else if((b|0)==18){ab=a[d]|0;if((a[9375104]&1)==0){ac=ab&1}else{aa=c[u>>2]|0;V=ab&1;ab=V<<24>>24!=0?250320:243216;bU(aa|0,258784,(O=i,i=i+8|0,c[O>>2]=ab,O)|0)|0;i=O;eY(aa|0)|0;ac=V}a[9469446]=ac;T=1;i=e;return T|0}else if((b|0)==19){c[d>>2]=0;T=1;i=e;return T|0}else if((b|0)==21){if((a[9375104]&1)!=0){ac=c[u>>2]|0;cj(236856,44,1,ac|0)|0;eY(ac|0)|0}c[2368534]=c[d>>2];c[2368535]=c[d+4>>2];c[2368536]=c[d+8>>2];c[2368537]=c[d+12>>2];T=1;i=e;return T|0}else if((b|0)==23){if((a[9375104]&1)!=0){ac=c[u>>2]|0;cj(230336,41,1,ac|0)|0;eY(ac|0)|0}c[d>>2]=2060;T=1;i=e;return T|0}else{if((a[9375104]&1)==0){T=0;i=e;return T|0}d=c[u>>2]|0;bU(d|0,201456,(O=i,i=i+8|0,c[O>>2]=b,O)|0)|0;i=O;eY(d|0)|0;T=0;i=e;return T|0}return 0}function h7(){var a=0;a=gGq(153600)|0;do{if((a|0)!=0){if((c[a-4>>2]&3|0)==0){break}gGz(a|0,0,153600)}}while(0);c[2383340]=a;return}function h8(){gGr(c[2383340]|0);c[2383340]=0;return}function h9(){return 1}function ia(a,b){a=a|0;b=b|0;return}function ib(b){b=b|0;gGz(b|0,0,16);c[b>>2]=396272;c[b+4>>2]=9534384;a[b+12|0]=0;c[b+8>>2]=9534384;return}function ic(a){a=a|0;h[a+24>>3]=60.0;h[a+32>>3]=3.0e4;c[a>>2]=320;c[a+4>>2]=240;c[a+8>>2]=320;c[a+12>>2]=240;g[a+16>>2]=1.3333333730697632;return}function id(a){a=a|0;var b=0,d=0;b=i;i=i+8|0;d=b|0;c[2383348]=a;c[d>>2]=2;gA[a&16383](10,d)|0;i=b;return}function ie(a){a=a|0;c[2383350]=a;return}function ig(a){a=a|0;c[2383352]=a;return}function ih(a){a=a|0;c[2383346]=a;return}function ii(a){a=a|0;c[2383344]=a;return}function ij(a){a=a|0;c[2383342]=a;return}function ik(){return}function il(){var a=0,d=0;gu[c[2383346]&16383]();a=c[2383340]|0;d=0;do{b[a+(d<<1)>>1]=128;d=d+1|0;}while(d>>>0<76800);gL[c[2383342]&255](a,320,240,640);return}function im(a){a=a|0;return 0}function io(){return}function ip(){return 0}function iq(a,b,c){a=a|0;b=b|0;c=c|0;return 0}function ir(){return 0}function is(a,b){a=a|0;b=b|0;return 0}function it(a,b){a=a|0;b=b|0;return 0}function iu(a){a=a|0;return 0}function iv(a){a=a|0;return 0}function iw(){return}function ix(a,b,c){a=a|0;b=b|0;c=c|0;return}function iy(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=a+4|0;if((c[b>>2]|0)==1){d=0;return d|0}e=a|0;f=c[(c[e>>2]|0)+4>>2]|0;g=f|0;h=(c[g>>2]|0)-1|0;c[g>>2]=h;if((h|0)!=0){d=c[f+8>>2]|0;return d|0}h=a+12|0;gGr(c[h>>2]|0);a=f+8|0;c[h>>2]=c[a>>2];c[a>>2]=0;a=c[e>>2]|0;f=a+4|0;g=c[f>>2]|0;i=(c[b>>2]|0)-1|0;c[b>>2]=i;c[f>>2]=c[a+(i<<2)>>2];gGr(g);g=1;while(1){i=g<<1;a=c[b>>2]|0;if(i>>>0>a>>>0){j=0}else{f=c[e>>2]|0;j=(c[f+(g<<2)>>2]|0)>>>0<(c[f+(i<<2)>>2]|0)>>>0}f=i|1;if(f>>>0>a>>>0){k=0}else{a=c[e>>2]|0;k=(c[a+(g<<2)>>2]|0)>>>0<(c[a+(f<<2)>>2]|0)>>>0}if(!(j|k)){break}do{if(k|j^1){if(!(j|k^1)){l=f;break}a=c[e>>2]|0;l=(c[a+(i<<2)>>2]|0)>>>0<(c[a+(f<<2)>>2]|0)>>>0?f:i}else{l=i}}while(0);i=c[e>>2]|0;f=i+(g<<2)|0;a=c[f>>2]|0;c[f>>2]=c[i+(l<<2)>>2];c[(c[e>>2]|0)+(l<<2)>>2]=a;g=l}d=c[h>>2]|0;return d|0}function iz(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,v=0,w=0,x=0,y=0,z=0,A=0;e=i;i=i+16|0;f=e|0;g=f|0;h=f;j=gGq(32)|0;if((j|0)==0){k=0;i=e;return k|0}if((c[j-4>>2]&3|0)!=0){gGz(j|0,0,32)}l=j;m=f;L4329:do{if((d|0)==0){a[j+28|0]=1;n=fw(b|0,364392)|0;c[j>>2]=n;if((n|0)==0){o=c[u>>2]|0;bU(o|0,282616,(p=i,i=i+8|0,c[p>>2]=b,p)|0)|0;i=p;eY(o|0)|0;break}gGz(m|0,0,16);if((ew(m|0,4,4,n|0)|0)!=4){o=c[u>>2]|0;cj(216496,49,1,o|0)|0;eY(o|0)|0;q=n;r=3115;break}o=c[f>>2]|0;if(!((o|0)==1112757809|(o|0)==827740994)){o=c[u>>2]|0;cj(169440,58,1,o|0)|0;eY(o|0)|0;s=n;r=3114;break}if((c[f+8>>2]|0)!=(c[2344803]|0)){o=c[u>>2]|0;cj(136536,151,1,o|0)|0;eY(o|0)|0}o=c[h+12>>2]|0;do{if((o|0)!=0){t=gGq(o)|0;c[j+24>>2]=t;c[j+20>>2]=o;if((t|0)==0){s=n;r=3114;break L4329}if((ew(t|0,1,o|0,n|0)|0)!=(o|0)){v=c[u>>2]|0;cj(110496,53,1,v|0)|0;eY(v|0)|0;s=n;r=3114;break L4329}if((gD[c[2112844]&8191]()|0)==(o|0)){v=c[2112826]|0;gA[v&16383](t,o)|0;break}else{t=c[u>>2]|0;cj(85408,102,1,t|0)|0;eY(t|0)|0;break}}}while(0);t=o+16|0;c[j+16>>2]=t;w=n;x=t;r=3109}else{t=fw(b|0,389440)|0;c[j>>2]=t;if((t|0)==0){v=c[u>>2]|0;bU(v|0,470928,(p=i,i=i+8|0,c[p>>2]=b,p)|0)|0;i=p;eY(v|0)|0;break}c[g>>2]=0;c[g+4>>2]=0;c[f>>2]=827740994;c[f+8>>2]=c[2344803];v=gD[c[2112844]&8191]()|0;c[h+12>>2]=v;cj(m|0,4,4,t|0)|0;y=v+16|0;c[j+16>>2]=y;c[j+20>>2]=v;if((v|0)==0){w=t;x=y;r=3109;break}z=gGq(v)|0;c[j+24>>2]=z;if((z|0)==0){s=t;r=3114;break}A=c[2112846]|0;gA[A&16383](z,v)|0;cj(z|0,1,v|0,t|0)|0;w=t;x=y;r=3109}}while(0);do{if((r|0)==3109){m=gGq(4194304)|0;if((m|0)==0){c[j+4>>2]=0;s=w;r=3114;break}if((c[m-4>>2]&3|0)!=0){gGz(m|0,0,4194304)}h=m;c[j+4>>2]=h;c[h>>2]=x;c[j+8>>2]=1048575;k=l;i=e;return k|0}}while(0);if((r|0)==3114){if((s|0)!=0){q=s;r=3115}}if((r|0)==3115){aY(q|0)|0}gGr(c[j+24>>2]|0);gGr(c[j+4>>2]|0);gGr(j);k=0;i=e;return k|0}function iA(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;f=i;i=i+128|0;g=f|0;h=f+64|0;a[b]=0;j=d+16|0;k=c[j>>2]|0;l=c[j+4>>2]|0;do{if((k|0)==65535&(l|0)==0){j=c[d+32>>2]|0;if((j|0)==-1){break}m=j>>>16;if((m|0)==65535){n=j&65535;j=(n|0)==65535;o=j?0:43;p=j?0:n}else{o=45;p=m}be(b|0,e|0,475896,(q=i,i=i+16|0,c[q>>2]=o,c[q+8>>2]=p,q)|0)|0;i=q}else{m=k&61440;n=l&0;j=4096;r=0;s=16384;t=0;u=32768;v=0;w=0;x=0;if((m|0)==8192&(n|0)==0){y=173408}else if((m|0)==(j|0)&(n|0)==(r|0)){y=166840}else if((m|0)==(u|0)&(n|0)==(v|0)){y=192464}else if((m|0)==(w|0)&(n|0)==(x|0)){be(b|0,e|0,477040,(q=i,i=i+8|0,c[q>>2]=k,q)|0)|0;i=q;break}else if((m|0)==(s|0)&(n|0)==(t|0)){y=181376}else{y=177920}t=k&-61441;be(b|0,e|0,478040,(q=i,i=i+16|0,c[q>>2]=t,c[q+8>>2]=y,q)|0)|0;i=q}}while(0);y=c[d+12>>2]|0;d=g|0;a[d]=0;L4390:do{if((y-97|0)>>>0<26){a[d]=y&255;a[g+1|0]=0}else{k=0;while(1){if((k|0)==67){break L4390}if((c[46148+(k<<3)>>2]|0)==(y|0)){break}else{k=k+1|0}}l=64;p=d;o=c[46144+(k<<3)>>2]|0;while(1){t=l-1|0;if((t|0)==0){break}n=a[o]|0;a[p]=n;if(n<<24>>24==0){break L4390}else{l=t;p=p+1|0;o=o+1|0}}a[p]=0;if((a[o]|0)==0){break}else{z=o}do{z=z+1|0;}while((a[z]|0)!=0)}}while(0);if((fa(d|0,333832)|0)==0){a[d]=0}z=h|0;be(z|0,64,474632,(q=i,i=i+8|0,c[q>>2]=d,q)|0)|0;i=q;q=gGy(b|0)|0;d=q>>>0>e>>>0?0:e-q|0;do{if((d|0)==0){A=z}else{e=d;h=b+q|0;y=z;while(1){g=e-1|0;if((g|0)==0){B=3148;break}o=a[y]|0;a[h]=o;if(o<<24>>24==0){B=3152;break}else{e=g;h=h+1|0;y=y+1|0}}if((B|0)==3148){a[h]=0;A=y;break}else if((B|0)==3152){i=f;return}}}while(0);if((a[A]|0)==0){i=f;return}else{C=A}do{C=C+1|0;}while((a[C]|0)!=0);i=f;return}function iB(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+128|0;h=g+64|0;be(h|0,64,473112,(j=i,i=i+16|0,c[j>>2]=d,c[j+8>>2]=e,j)|0)|0;i=j;j=g|0;e=b+4|0;while(1){k=c[e>>2]|0;if((k|0)==0){l=3173;break}if((fa(h|0,c[k+4>>2]|0)|0)==0){break}else{e=k+12|0}}if((l|0)==3173){i=g;return}e=64;h=0;b=j;d=c[k+8>>2]|0;while(1){k=e-1|0;if((k|0)==0){l=3161;break}m=a[d]|0;a[b]=m;if(m<<24>>24==0){n=h;break}else{e=k;h=h+1|0;b=b+1|0;d=d+1|0}}do{if((l|0)==3161){a[b]=0;if((a[d]|0)==0){n=h;break}else{o=d;p=h}while(1){e=o+1|0;k=p+1|0;if((a[e]|0)==0){n=k;break}else{o=e;p=k}}}}while(0);if(n>>>0>=64){i=g;return}do{if((gGy(j|0)|0)==1){n=a[j]|0;if((c1(n|0)|0)==0){q=0;l=3167;break}r=gGD(n|0)|0}else{q=0;l=3167}}while(0);L4441:do{if((l|0)==3167){while(1){l=0;if((q|0)==67){r=0;break L4441}if((gGF(c[46144+(q<<3)>>2]|0,j|0)|0)==0){break}else{q=q+1|0;l=3167}}r=c[46148+(q<<3)>>2]|0}}while(0);c[f+12>>2]=r;i=g;return}function iC(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=i;i=i+136|0;h=g|0;j=g+8|0;k=g+72|0;be(k|0,64,470032,(l=i,i=i+16|0,c[l>>2]=d,c[l+8>>2]=e,l)|0)|0;i=l;l=j|0;e=b+4|0;while(1){m=c[e>>2]|0;if((m|0)==0){n=3200;break}if((fa(k|0,c[m+4>>2]|0)|0)==0){break}else{e=m+12|0}}if((n|0)==3200){i=g;return}e=64;k=0;b=l;d=c[m+8>>2]|0;while(1){m=e-1|0;if((m|0)==0){n=3181;break}o=a[d]|0;a[b]=o;if(o<<24>>24==0){p=k;break}else{e=m;k=k+1|0;b=b+1|0;d=d+1|0}}do{if((n|0)==3181){a[b]=0;if((a[d]|0)==0){p=k;break}else{q=d;r=k}while(1){e=q+1|0;m=r+1|0;if((a[e]|0)==0){p=m;break}else{q=e;r=m}}}}while(0);if(p>>>0>=64){i=g;return}if((fa(l|0,333832)|0)==0){p=f+16|0;c[p>>2]=65535;c[p+4>>2]=0;i=g;return}if((a[l]|0)!=104){p=dC(l|0,0,0)|0;l=f+16|0;c[l>>2]=p;c[l+4>>2]=K;i=g;return}l=j+1|0;if(((a[l]|0)-48|0)>>>0>=10){i=g;return}c[h>>2]=0;j=ch(l|0,h|0,0)|0;l=c[h>>2]|0;if((l|0)==0){h=c[u>>2]|0;cj(463192,49,1,h|0)|0;eY(h|0)|0;i=g;return}do{if((gGF(l|0,192464)|0)==0){s=-32768}else{if((gGF(l|0,181376)|0)==0){s=16384;break}if((gGF(l|0,173408)|0)==0){s=8192;break}h=(gGF(l|0,166840)|0)==0;if(h){s=h?4096:0;break}i=g;return}}while(0);l=f+16|0;c[l>>2]=s&65535|j&4095;c[l+4>>2]=0;i=g;return}function iD(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=i;i=i+128|0;h=g|0;j=g+64|0;be(j|0,64,468488,(k=i,i=i+16|0,c[k>>2]=d,c[k+8>>2]=e,k)|0)|0;i=k;k=h|0;e=b+4|0;while(1){l=c[e>>2]|0;if((l|0)==0){m=3228;break}if((fa(j|0,c[l+4>>2]|0)|0)==0){break}else{e=l+12|0}}if((m|0)==3228){i=g;return}e=64;j=0;b=k;d=c[l+8>>2]|0;while(1){l=e-1|0;if((l|0)==0){m=3211;break}n=a[d]|0;a[b]=n;if(n<<24>>24==0){o=j;break}else{e=l;j=j+1|0;b=b+1|0;d=d+1|0}}do{if((m|0)==3211){a[b]=0;if((a[d]|0)==0){o=j;break}else{p=d;q=j}while(1){e=p+1|0;l=q+1|0;if((a[e]|0)==0){o=l;break}else{p=e;q=l}}}}while(0);if(o>>>0>=64){i=g;return}if((fa(k|0,333832)|0)==0){c[f+32>>2]=-1;i=g;return}if((gGy(k|0)|0)>>>0<=1){i=g;return}o=a[k]|0;if(!((o<<24>>24|0)==43|(o<<24>>24|0)==45)){i=g;return}o=dE(h+1|0,0,0)|0;if((a[k]|0)==43){c[f+32>>2]=o|-65536;i=g;return}else{c[f+32>>2]=o<<16|65535;i=g;return}}function iE(){var a=0,b=0,d=0,e=0,f=0;a=gGq(48)|0;if((a|0)==0){b=0;return b|0}if((c[a-4>>2]&3|0)!=0){gGz(a|0,0,48)}d=e1()|0;c[a+44>>2]=d;if((d|0)==0){gGr(a);b=0;return b|0}gGz(845e4,0,1292);d=6720;e=276;while(1){c[845e4+(e<<2)>>2]=c[d>>2];f=c[d+12>>2]|0;if((f|0)==0){b=a;break}else{d=d+8|0;e=f}}return b|0}function iF(a){a=a|0;var b=0;b=cF(c[a+44>>2]|0)|0;gGC(a|0,b|0,44)|0;return}function iG(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0;g=b;do{if((f|0)==3){if((h|0)>322){i=0;break}j=c[845e4+(h<<2)>>2]|0;i=(a[g+(j>>>3)|0]&1<<(j&7)|0)!=0|0}else if((f|0)==2){if((h|0)==1){i=c[b+36>>2]&65535;break}else if((h|0)==2){i=a[b+40|0]|0;break}else if((h|0)==0){i=c[b+32>>2]&65535;break}else if((h|0)==3){i=a[b+41|0]|0;break}else{i=0;break}}else if((f|0)==1){j=c[d+(e<<2)>>2]|0;if(h>>>0>=56){i=0;break}if((a[j+(h*40|0)|0]&1)==0){i=0;break}k=c[j+(h*40|0)+12>>2]|0;if((k|0)>322){i=0;break}j=c[845e4+(k<<2)>>2]|0;i=(a[g+(j>>>3)|0]&1<<(j&7)|0)!=0|0}else{i=0}}while(0);return i|0}function iH(b,d){b=b|0;d=d|0;var e=0,f=0;if(d>>>0>=56){e=0;return e|0}if((a[9288384+(d*40|0)|0]&1)==0){e=0;return e|0}f=c[9288396+(d*40|0)>>2]|0;if((f|0)>322){e=0;return e|0}d=c[845e4+(f<<2)>>2]|0;e=(a[b+(d>>>3)|0]&1<<(d&7)|0)!=0;return e|0}function iI(a){a=a|0;aW(c[a+44>>2]|0);gGr(a);return}function iJ(a){a=a|0;return(K=0,14)|0}function iK(a,b){a=a|0;b=b|0;return}function iL(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((a|0)==0){return}b=a+4104|0;if((c[b>>2]|0)!=0){d=a+4100|0;e=0;do{gGr(c[(c[d>>2]|0)+(e<<4)>>2]|0);gGr(c[(c[d>>2]|0)+(e<<4)+4>>2]|0);f=c[(c[d>>2]|0)+(e<<4)+8>>2]|0;if((f|0)!=0){g=f+4|0;h=f|0;i=c[h>>2]|0;if((c[g>>2]|0)==0){j=i}else{k=0;l=i;while(1){gGr(c[l+(k<<3)>>2]|0);i=k+1|0;m=c[h>>2]|0;if(i>>>0<(c[g>>2]|0)>>>0){k=i;l=m}else{j=m;break}}}gGr(j);gGr(f)}e=e+1|0;}while(e>>>0<(c[b>>2]|0)>>>0)}b=c[a>>2]|0;if((b|0)!=0){hY(b)}gGr(c[a+4100>>2]|0);gGr(a);return}function iM(b,e,f,g,h,j){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0;k=i;i=i+136|0;l=k|0;m=k+8|0;n=k+16|0;o=k+24|0;p=k+32|0;q=k+40|0;r=k+48|0;s=k+56|0;t=k+64|0;u=k+72|0;v=k+80|0;w=k+88|0;x=k+96|0;y=k+104|0;z=k+112|0;A=k+120|0;B=k+128|0;if(e>>>0<19){C=2;i=k;return C|0}D=c[j>>2]|0;E=a[b]|0;a[B]=E;F=RK(0,B,1)|0;if(E<<24>>24!=66){C=3;i=k;return C|0}E=a[b+1|0]|0;a[A]=E;B=RK(F,A,1)|0;if(E<<24>>24!=80){C=3;i=k;return C|0}E=a[b+2|0]|0;a[z]=E;A=RK(B,z,1)|0;if(E<<24>>24!=83){C=3;i=k;return C|0}E=a[b+3|0]|0;a[y]=E;z=RK(A,y,1)|0;if(E<<24>>24!=49){C=3;i=k;return C|0}E=0;y=0;A=0;B=1;F=~z;z=4;G=7;while(1){H=z+1|0;I=a[b+z|0]|0;a[x]=I;J=~(RK(~F,x,1)|0);L=I&255;I=gGU(L&127,0,B,A)|0;M=gGK(I,K,y,E)|0;if((L&128|0)!=0){N=0;O=0;P=0;Q=1;R=J;S=H;T=G;break}L=B<<7|0>>>25;I=A<<7|B>>>25;U=gGK(M,K,L,I)|0;E=K;y=U;A=I;B=L;F=J;z=H;G=G+1|0}while(1){G=S+1|0;z=a[b+S|0]|0;a[w]=z;F=~(RK(~R,w,1)|0);B=z&255;z=gGU(B&127,0,Q,P)|0;V=gGK(z,K,O,N)|0;if((B&128|0)!=0){W=0;X=0;Y=0;Z=1;_=F;$=G;aa=T;break}B=Q<<7|0>>>25;z=P<<7|Q>>>25;A=gGK(V,K,B,z)|0;N=K;O=A;P=z;Q=B;R=F;S=G;T=T+1|0}while(1){ab=$+1|0;ac=a[b+$|0]|0;a[v]=ac;ad=~(RK(~_,v,1)|0);T=ac&255;S=gGU(T&127,0,Z,Y)|0;ae=gGK(S,K,X,W)|0;if((T&128|0)!=0){break}T=Z<<7|0>>>25;S=Y<<7|Z>>>25;R=gGK(ae,K,T,S)|0;W=K;X=R;Y=S;Z=T;_=ad;$=ab;aa=aa+1|0}$=M;M=V;V=ae;if((V|0)==0){af=ad;ag=ab}else{ae=gGU(ac&127,0,Z,Y)|0;Y=gGK(ae,K,X,W)|0;W=ad;ad=ab;ab=0;while(1){a[u]=a[b+ad|0]|0;ah=~(RK(~W,u,1)|0);X=ab+1|0;if(X>>>0<V>>>0){W=ah;ad=ad+1|0;ab=X}else{break}}af=ah;ag=Y+aa|0}if($>>>0>g>>>0){C=5;i=k;return C|0}if(M>>>0>D>>>0){C=6;i=k;return C|0}D=e-12|0;e=ag;ag=0;$=0;aa=af;af=-1;Y=0;L4623:while(1){ah=e;ab=ag;ad=aa;W=af;V=Y;while(1){u=ah;X=ad;ai=W;aj=V;L4627:while(1){ak=u;al=X;while(1){if(ak>>>0<D>>>0){am=0;an=0;ao=0;ap=1;aq=al;ar=ak}else{break L4623}while(1){as=ar+1|0;ae=a[b+ar|0]|0;a[t]=ae;at=~(RK(~aq,t,1)|0);Z=ae&255;ae=gGU(Z&127,0,ap,ao)|0;au=gGK(ae,K,an,am)|0;if((Z&128|0)!=0){break}Z=ap<<7|0>>>25;ae=ao<<7|ap>>>25;ac=gGK(au,K,Z,ae)|0;am=K;an=ac;ao=ae;ap=Z;aq=at;ar=as}av=au;aw=av&3;if((aw|0)==0){ax=3311;break}else if((aw|0)==2|(aw|0)==3){break L4627}else if((aw|0)==1){ax=3313;break}else{ak=as;al=at}}if((ax|0)==3311){ax=0;Z=(av>>>2)+1|0;ae=aj;ac=ai;_=Z;while(1){v=_-1|0;T=a[f+ae|0]|0;a[h+ae|0]=T;a[s]=T;T=~(RK(~ac,s,1)|0);if((v|0)==0){ay=as;az=at;aA=T;aB=Z;break}else{ae=ae+1|0;ac=T;_=v}}}else if((ax|0)==3313){ax=0;_=(av>>>2)+1|0;ac=aj;ae=ai;Z=at;v=as;T=_;while(1){S=T-1|0;R=a[b+v|0]|0;a[r]=R;aC=~(RK(~Z,r,1)|0);a[h+ac|0]=R;a[q]=R;aD=~(RK(~ae,q,1)|0);if((S|0)==0){break}else{ac=ac+1|0;ae=aD;Z=aC;v=v+1|0;T=S}}ay=_+as|0;az=aC;aA=aD;aB=_}u=ay;X=az;ai=aA;aj=aB+aj|0}aE=(av>>>2)+1|0;X=0;u=0;T=0;v=1;Z=at;ae=as;while(1){aF=ae+1|0;ac=a[b+ae|0]|0;a[p]=ac;aG=~(RK(~Z,p,1)|0);S=ac&255;ac=gGU(S&127,0,v,T)|0;aH=gGK(ac,K,u,X)|0;if((S&128|0)!=0){break}S=v<<7|0>>>25;ac=T<<7|v>>>25;R=gGK(aH,K,S,ac)|0;X=K;u=R;T=ac;v=S;Z=aG;ae=aF}ae=aH;Z=ae>>1;aI=(ae&1|0)==0?Z:-Z|0;if((aw|0)!=2){break}Z=aj;ae=ai;v=aI+ab|0;T=aE;while(1){u=T-1|0;X=a[f+v|0]|0;a[h+Z|0]=X;a[o]=X;aJ=~(RK(~ae,o,1)|0);if((u|0)==0){break}else{Z=Z+1|0;ae=aJ;v=v+1|0;T=u}}ah=aF;ab=aE+ab+aI|0;ad=aG;W=aJ;V=aE+aj|0}V=aj;W=ai;ad=aI+$|0;ah=aE;while(1){T=ah-1|0;v=a[h+ad|0]|0;a[h+V|0]=v;a[n]=v;aK=~(RK(~W,n,1)|0);if((T|0)==0){break}else{V=V+1|0;W=aK;ad=ad+1|0;ah=T}}e=aF;ag=ab;$=aE+$+aI|0;aa=aG;af=aK;Y=aE+aj|0}aj=a[b+ak|0]|0;a[m]=aj;aE=RK(~al,m,1)|0;al=a[b+(ak+1)|0]|0;a[m]=al;Y=RK(aE,m,1)|0;aE=a[b+(ak+2)|0]|0;a[m]=aE;aK=RK(Y,m,1)|0;Y=a[b+(ak+3)|0]|0;a[m]=Y;af=RK(aK,m,1)|0;m=a[b+(ak+4)|0]|0;a[l]=m;aK=RK(af,l,1)|0;af=a[b+(ak+5)|0]|0;a[l]=af;aG=RK(aK,l,1)|0;aK=a[b+(ak+6)|0]|0;a[l]=aK;aa=RK(aG,l,1)|0;aG=a[b+(ak+7)|0]|0;a[l]=aG;aI=RK(aa,l,1)|0;l=(d[b+(ak+9)|0]|0)<<8|(d[b+(ak+8)|0]|0)|(d[b+(ak+10)|0]|0)<<16|(d[b+(ak+11)|0]|0)<<24;if((RK(0,f,g)|0)!=((al&255)<<8|aj&255|(aE&255)<<16|(Y&255)<<24|0)){C=9;i=k;return C|0}if(((af&255)<<8|m&255|(aK&255)<<16|(aG&255)<<24|0)!=(~ai|0)){C=10;i=k;return C|0}if((l|0)!=(aI|0)){C=11;i=k;return C|0}c[j>>2]=M;C=1;i=k;return C|0}function iN(b,e,f,g,h,j){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0;k=i;i=i+144|0;l=k|0;m=k+8|0;n=k+16|0;o=k+24|0;p=k+32|0;q=k+40|0;r=k+48|0;s=k+56|0;t=k+64|0;u=k+72|0;v=k+80|0;w=k+88|0;x=k+96|0;y=k+104|0;z=k+112|0;A=k+120|0;B=k+128|0;C=k+136|0;D=c[j>>2]|0;if(e>>>0<=17){E=4;i=k;return E|0}F=a[b]|0;a[C]=F;G=RK(0,C,1)|0;if(F<<24>>24!=85){E=4;i=k;return E|0}F=a[b+1|0]|0;a[B]=F;C=RK(G,B,1)|0;if(F<<24>>24!=80){E=4;i=k;return E|0}F=a[b+2|0]|0;a[A]=F;B=RK(C,A,1)|0;if(F<<24>>24!=83){E=4;i=k;return E|0}F=a[b+3|0]|0;a[z]=F;A=RK(B,z,1)|0;if(F<<24>>24!=49){E=4;i=k;return E|0}F=0;z=0;B=0;C=1;G=4;H=~A;while(1){if(G>>>0<e>>>0){A=G+1|0;I=a[b+G|0]|0;a[y]=I;J=~(RK(~H,y,1)|0);L=I&255;I=gGU(L&127,0,C,B)|0;M=gGK(I,K,z,F)|0;if((L&128|0)==0){N=K;O=M;P=A;Q=J}else{R=0;S=0;T=0;U=1;V=A;W=J;break}}else{N=F;O=z;P=G;Q=H}J=C<<7|0>>>25;A=B<<7|C>>>25;L=gGK(O,N,J,A)|0;F=K;z=L;B=A;C=J;G=P;H=Q}while(1){if(V>>>0<e>>>0){X=V+1|0;Q=a[b+V|0]|0;a[x]=Q;Y=~(RK(~W,x,1)|0);H=Q&255;Q=gGU(H&127,0,U,T)|0;Z=gGK(Q,K,S,R)|0;if((H&128|0)==0){_=K;$=Z;aa=X;ab=Y}else{break}}else{_=R;$=S;aa=V;ab=W}H=U<<7|0>>>25;Q=T<<7|U>>>25;P=gGK($,_,H,Q)|0;R=K;S=P;T=Q;U=H;V=aa;W=ab}ab=M;M=Z;Z=(ab|0)==(g|0);W=(M|0)==(g|0);if(!(Z|W)){E=7;i=k;return E|0}aa=Z?M:ab;c[j>>2]=aa;if(D>>>0<aa>>>0){E=6;i=k;return E|0}D=e-12|0;if(X>>>0<D>>>0){j=-1;V=-1;U=Y;T=0;S=0;R=X;while(1){_=0;$=0;x=0;H=1;Q=R;P=U;while(1){if(Q>>>0<e>>>0){ac=Q+1|0;G=a[b+Q|0]|0;a[w]=G;ad=~(RK(~P,w,1)|0);C=G&255;G=gGU(C&127,0,H,x)|0;ae=gGK(G,K,$,_)|0;if((C&128|0)==0){af=K;ag=ae;ah=ac;ai=ad}else{break}}else{af=_;ag=$;ah=Q;ai=P}C=H<<7|0>>>25;G=x<<7|H>>>25;B=gGK(ag,af,C,G)|0;_=K;$=B;x=G;H=C;Q=ah;P=ai}P=ae;if((P|0)==0){aj=ac;ak=S;al=T;am=ad;an=V;ao=j}else{Q=j;H=V;x=T;$=S;_=P;while(1){C=_-1|0;if($>>>0<g>>>0){G=a[f+$|0]|0;a[v]=G;ap=G;aq=$+1|0;ar=~(RK(~H,v,1)|0)}else{ap=0;aq=$;ar=H}if(x>>>0<aa>>>0){a[h+x|0]=ap;a[u]=ap;as=~(RK(~Q,u,1)|0)}else{as=Q}if((C|0)==0){break}else{Q=as;H=ar;x=x+1|0;$=aq;_=C}}aj=ac;ak=aq;al=P+T|0;am=ad;an=ar;ao=as}while(1){if(aj>>>0<e>>>0){_=a[b+aj|0]|0;a[t]=_;at=_;au=aj+1|0;av=~(RK(~am,t,1)|0)}else{at=0;au=aj;av=am}if(ak>>>0<g>>>0){_=a[f+ak|0]|0;a[s]=_;aw=_;ax=ak+1|0;ay=~(RK(~an,s,1)|0)}else{aw=0;ax=ak;ay=an}_=aw^at;if(al>>>0<aa>>>0){a[h+al|0]=_;a[r]=_;az=~(RK(~ao,r,1)|0)}else{az=ao}aA=al+1|0;if(at<<24>>24==0){break}else{aj=au;ak=ax;al=aA;am=av;an=ay;ao=az}}if(au>>>0<D>>>0){j=az;V=ay;U=av;T=aA;S=ax;R=au}else{aB=az;aC=ay;aD=av;aE=aA;aF=ax;aG=au;break}}}else{aB=-1;aC=-1;aD=Y;aE=0;aF=0;aG=X}if(aF>>>0<g>>>0){X=aB;Y=aC;au=aE;ax=aF;while(1){aA=ax+1|0;av=a[f+ax|0]|0;a[q]=av;aH=~(RK(~Y,q,1)|0);if(au>>>0<aa>>>0){a[h+au|0]=av;a[p]=av;aI=~(RK(~X,p,1)|0)}else{aI=X}if(aA>>>0<g>>>0){X=aI;Y=aH;au=au+1|0;ax=aA}else{break}}aJ=aI;aK=aH;aL=g-aF+aE|0;aM=g}else{aJ=aB;aK=aC;aL=aE;aM=aF}if(aL>>>0<aa>>>0){aF=aJ;aE=aK;aC=aL;aL=aM;while(1){if(aL>>>0<g>>>0){aM=a[f+aL|0]|0;a[o]=aM;aN=aM;aO=aL+1|0;aP=~(RK(~aE,o,1)|0)}else{aN=0;aO=aL;aP=aE}a[h+aC|0]=aN;a[n]=aN;aM=~(RK(~aF,n,1)|0);aB=aC+1|0;if(aB>>>0<aa>>>0){aF=aM;aE=aP;aC=aB;aL=aO}else{aQ=aM;aR=aP;break}}}else{aQ=aJ;aR=aK}if(aG>>>0<e>>>0){aK=a[b+aG|0]|0;a[m]=aK;aS=aK&255;aT=aG+1|0;aU=~(RK(~aD,m,1)|0)}else{aS=0;aT=aG;aU=aD}if(aT>>>0<e>>>0){aD=a[b+aT|0]|0;a[m]=aD;aV=(aD&255)<<8;aW=aT+1|0;aX=~(RK(~aU,m,1)|0)}else{aV=0;aW=aT;aX=aU}if(aW>>>0<e>>>0){aU=a[b+aW|0]|0;a[m]=aU;aY=(aU&255)<<16;aZ=aW+1|0;a_=~(RK(~aX,m,1)|0)}else{aY=0;aZ=aW;a_=aX}if(aZ>>>0<e>>>0){aX=a[b+aZ|0]|0;a[m]=aX;a$=(aX&255)<<24;a0=aZ+1|0;a1=~(RK(~a_,m,1)|0)}else{a$=0;a0=aZ;a1=a_}a_=aV|aS|aY|a$;if(a0>>>0<e>>>0){a$=a[b+a0|0]|0;a[l]=a$;a2=a$&255;a3=a0+1|0;a4=~(RK(~a1,l,1)|0)}else{a2=0;a3=a0;a4=a1}if(a3>>>0<e>>>0){a1=a[b+a3|0]|0;a[l]=a1;a5=(a1&255)<<8;a6=a3+1|0;a7=~(RK(~a4,l,1)|0)}else{a5=0;a6=a3;a7=a4}if(a6>>>0<e>>>0){a4=a[b+a6|0]|0;a[l]=a4;a8=(a4&255)<<16;a9=a6+1|0;ba=~(RK(~a7,l,1)|0)}else{a8=0;a9=a6;ba=a7}if(a9>>>0<e>>>0){a7=a[b+a9|0]|0;a[l]=a7;bb=(a7&255)<<24;bc=a9+1|0;bd=~(RK(~ba,l,1)|0)}else{bb=0;bc=a9;bd=ba}ba=a5|a2|a8|bb;bb=~aR;if(bc>>>0<e>>>0){be=d[b+bc|0]|0;bf=bc+1|0}else{be=0;bf=bc}if(bf>>>0<e>>>0){bg=(d[b+bf|0]|0)<<8;bh=bf+1|0}else{bg=0;bh=bf}if(bh>>>0<e>>>0){bi=(d[b+bh|0]|0)<<16;bj=bh+1|0}else{bi=0;bj=bh}if(bj>>>0<e>>>0){bk=(d[b+bj|0]|0)<<24}else{bk=0}bj=~aQ;if((bg|be|bi|bk|0)!=(~bd|0)){E=4;i=k;return E|0}if(!((a_|0)!=(bb|0)|Z^1)){i=k;return((ba|0)==(bj|0)&(aa|0)==(M|0)?1:8)|0}if((ba|0)!=(bb|0)|W^1){E=7;i=k;return E|0}E=(a_|0)==(bj|0)&(aa|0)==(ab|0)?1:8;i=k;return E|0}function iO(b,e,f,g,h,i){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;if(e>>>0<8){j=4;return j|0}if((a[b]|0)!=80){j=4;return j|0}if((a[b+1|0]|0)!=65){j=4;return j|0}if((a[b+2|0]|0)!=84){j=4;return j|0}if((a[b+3|0]|0)!=67){j=4;return j|0}if((a[b+4|0]|0)!=72){j=4;return j|0}gGC(h|0,f|0,g)|0;c[i>>2]=g;g=e-3|0;if(g>>>0<5){j=4;return j|0}f=e-2|0;k=5;while(1){l=k+3|0;m=d[b+(k+1)|0]<<8|d[b+k|0]<<16|d[b+(k+2)|0];if((m|0)==4542278){if((l|0)==(e|0)){j=1;n=3447;break}if((l|0)==(g|0)){n=3432;break}}if(l>>>0>f>>>0){j=4;n=3451;break}o=k+5|0;p=d[b+l|0]<<8|d[b+(k+4)|0];if((p|0)==0){if(o>>>0>g>>>0){j=4;n=3454;break}l=d[b+o|0]<<8|d[b+(k+6)|0];if((l|0)==0){j=4;n=3460;break}q=b+(k+7)|0;r=m;s=l;while(1){t=s-1|0;a[h+r|0]=a[q]|0;if((t|0)==0){break}else{r=r+1|0;s=t}}u=l;v=k+8|0}else{if(o>>>0>(e-p|0)>>>0){j=4;n=3449;break}else{w=o;x=m;y=p}while(1){s=y-1|0;a[h+x|0]=a[b+w|0]|0;if((s|0)==0){break}else{w=w+1|0;x=x+1|0;y=s}}u=p;v=p+o|0}l=u+m|0;if(l>>>0>(c[i>>2]|0)>>>0){c[i>>2]=l}if(v>>>0>g>>>0){j=4;n=3459;break}else{k=v}}if((n|0)==3432){c[i>>2]=d[b+(k+4)|0]<<8|d[b+g|0]<<16|d[b+(k+5)|0];j=1;return j|0}else if((n|0)==3460){return j|0}else if((n|0)==3449){return j|0}else if((n|0)==3451){return j|0}else if((n|0)==3447){return j|0}else if((n|0)==3459){return j|0}else if((n|0)==3454){return j|0}return 0}function iP(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,v=0,w=0,x=0,y=0,z=0,A=0;d=i;i=i+8|0;e=d|0;f=c[u>>2]|0;cj(568152,85,1,f|0)|0;eY(f|0)|0;c[e>>2]=0;f=fw(b|0,68376)|0;if((f|0)==0){g=0;i=d;return g|0}b=gGq(4)|0;if((b|0)==0){aY(f|0)|0;g=0;i=d;return g|0}if((c[b-4>>2]&3|0)!=0){h=b;C=0;a[h]=C&255;C=C>>8;a[h+1|0]=C&255;C=C>>8;a[h+2|0]=C&255;C=C>>8;a[h+3|0]=C&255}h=b;dh(f|0,0,2)|0;j=fl(f|0)|0;b4(f|0);k=gGq(j+1|0)|0;do{if((k|0)==0){l=0;m=3475}else{a[k+j|0]=0;if((ew(k|0,1,j|0,f|0)|0)!=(j|0)){l=k;m=3475;break}aY(f|0)|0;c[e>>2]=k;do{if((gGH(k|0,572048,5)|0)==0){n=e3(k|0,555408)|0;if((n|0)==0){o=k;break}p=n+3|0;c[e>>2]=p;q=p;m=3470}else{q=k;m=3470}}while(0);do{if((m|0)==3470){p=gGy(q|0)|0;n=gGq(p+1|0)|0;if((n|0)==0){o=k;break}a[n+p|0]=0;p=e3(q|0,81608)|0;r=e3(q|0,588328)|0;if((p|0)==0|(r|0)==0){s=q;t=n}else{v=q;w=n;x=p;p=r;while(1){r=x-v|0;gGC(w|0,v|0,r)|0;y=w+r|0;r=p+3|0;z=e3(r|0,81608)|0;A=e3(r|0,588328)|0;if((z|0)==0|(A|0)==0){s=r;t=y;break}else{v=r;w=y;x=z;p=A}}}p=gGy(s|0)|0;gGC(t|0,s|0,p)|0;a[t+p|0]=0;gGr(k);c[e>>2]=n;p=iQ(e)|0;c[b>>2]=p;if((p|0)==0){o=n;break}gGr(n);g=h;i=d;return g|0}}while(0);gGr(o)}}while(0);if((m|0)==3475){gGr(l);aY(f|0)|0}f=c[b>>2]|0;if((f|0)!=0){iR(f)}gGr(b);g=0;i=d;return g|0}function iQ(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;d=i;i=i+16|0;e=d|0;f=d+8|0;g=gGq(24)|0;if((g|0)==0){h=0;i=d;return h|0}if((c[g-4>>2]&3|0)!=0){gGz(g|0,0,24)}j=g;k=c[b>>2]|0;while(1){l=k+1|0;if((a4(a[k]|0)|0)==0){break}else{k=l}}c[b>>2]=k;L4891:do{if((a[k]|0)==60){m=d0(k|0,62)|0;if((m|0)==0){n=0;break}o=m-l|0;p=gGq(o+1|0)|0;if((p|0)==0){n=0;break}gGC(p|0,l|0,o)|0;a[p+o|0]=0;o=p;while(1){if((a4(a[o]|0)|0)==0){q=o;break}else{o=o+1|0}}while(1){r=a[q]|0;if(r<<24>>24==0){s=0;break}if((a4(r<<24>>24|0)|0)==0){q=q+1|0}else{t=3498;break}}if((t|0)==3498){s=a[q]|0}r=(a4(s|0)|0)!=0;u=r?q:0;if((u|0)==0){r=bG(o|0)|0;c[g>>2]=r;if((r|0)==0){n=p;break}if((a[r]|0)==0){n=p;break}}else{r=u-o|0;v=gGq(r+1|0)|0;if((v|0)==0){c[g>>2]=0;n=p;break}gGC(v|0,o|0,r)|0;a[v+r|0]=0;c[g>>2]=v;if((a[v]|0)==0){n=p;break}v=bG(u|0)|0;if((v|0)==0){w=0}else{u=v+((gGy(v|0)|0)-1)|0;if((a[u]|0)==47){a[u]=0}u=de(v|0,131160,e|0)|0;L4914:do{if((u|0)==0){x=0;y=0;z=0}else{r=u;A=0;B=0;while(1){C=e3(r|0,105856)|0;if((C|0)==0){x=0;y=0;z=B;break L4914}D=C+2|0;E=cE(D|0,34)|0;if((E|0)==0){x=0;y=0;z=B;break L4914}if((E|0)!=(r+((gGy(r|0)|0)-1)|0)){x=0;y=0;z=B;break L4914}F=C-r|0;C=gGq(F+1|0)|0;if((C|0)==0){G=0}else{gGC(C|0,r|0,F)|0;a[C+F|0]=0;G=C}C=E-D|0;E=gGq(C+1|0)|0;if((E|0)==0){x=0;y=G;z=B;break L4914}gGC(E|0,D|0,C)|0;a[E+C|0]=0;if((G|0)==0){x=E;y=0;z=B;break L4914}C=gGq(12)|0;if((C|0)==0){x=E;y=G;z=B;break L4914}if((c[C-4>>2]&3|0)!=0){gGz(C|0,0,12)}D=C;c[C>>2]=G;c[C+4>>2]=E;if((A|0)==0){H=D}else{c[A+8>>2]=D;H=B}E=de(0,131160,e|0)|0;if((E|0)==0){x=0;y=0;z=H;break}else{r=E;A=D;B=H}}}}while(0);gGr(v);gGr(y);gGr(x);w=z}c[g+8>>2]=w}if(((e3(k|0,442176)|0)+1|0)==(m|0)){c[b>>2]=m+1}else{u=c[g>>2]|0;o=(gGy(u|0)|0)+4|0;B=gGq(o)|0;if((B|0)==0){n=p;break}be(B|0,o|0,341656,(o=i,i=i+8|0,c[o>>2]=u,o)|0)|0;i=o;o=m+1|0;u=e3(o|0,264352)|0;A=d0(o|0,60)|0;r=e3(o|0,B|0)|0;if((r|0)==0){gGr(B);n=p;break}L4944:do{if((u|0)==0){t=3536}else{D=o;while(1){if(D>>>0>=u>>>0){break}if((a4(a[D]|0)|0)==0){t=3536;break L4944}else{D=D+1|0}}D=e3(u|0,206048)|0;if((D|0)==0){gGr(B);n=p;break L4891}E=u+9|0;C=D-E|0;D=gGq(C+1|0)|0;if((D|0)==0){I=0}else{gGC(D|0,E|0,C)|0;a[D+C|0]=0;I=D}c[g+4>>2]=I;J=r}}while(0);do{if((t|0)==3536){if((r|0)==(A|0)){u=A-o|0;m=gGq(u+1|0)|0;if((m|0)==0){K=0}else{gGC(m|0,o|0,u)|0;a[m+u|0]=0;K=m}c[g+4>>2]=K;J=A;break}c[f>>2]=A;m=d0(A|0,60)|0;u=e3(A|0,161512)|0;L4963:do{if((u|0)!=0&(m|0)!=0&m>>>0<u>>>0){v=0;D=0;while(1){C=iQ(f)|0;if((C|0)==0){break}if((D|0)==0){L=C}else{c[D+16>>2]=C;L=v}E=c[f>>2]|0;F=d0(E|0,60)|0;M=e3(E|0,161512)|0;if((M|0)!=0&(F|0)!=0&F>>>0<M>>>0){v=L;D=C}else{N=L;O=E;break L4963}}gGr(B);n=p;break L4891}else{N=0;O=A}}while(0);c[g+12>>2]=N;u=e3(O|0,B|0)|0;if((u|0)!=0){J=u;break}gGr(B);n=p;break L4891}}while(0);c[b>>2]=J+(gGy(B|0)|0);gGr(B)}gGr(p);h=j;i=d;return h|0}else{n=0}}while(0);gGr(n);iR(j);h=0;i=d;return h|0}function iR(a){a=a|0;var b=0,d=0;b=c[a+12>>2]|0;if((b|0)!=0){d=b;while(1){b=c[d+16>>2]|0;iR(d);if((b|0)==0){break}else{d=b}}}d=c[a+8>>2]|0;if((d|0)!=0){b=d;while(1){d=c[b+8>>2]|0;gGr(c[b>>2]|0);gGr(c[b+4>>2]|0);gGr(b);if((d|0)==0){break}else{b=d}}}gGr(c[a>>2]|0);gGr(c[a+4>>2]|0);gGr(a);return}function iS(f,g,h,j,k,l){f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bV=0,bW=0;m=i;i=i+8432|0;n=m|0;o=m+8|0;p=m+16|0;q=m+24|0;r=m+48|0;s=m+104|0;t=m+112|0;v=m+4208|0;w=m+8304|0;x=v|0;gb(s|0)|0;ed(x|0,4096,536808,a5(s|0)|0)|0;s=gGy(x|0)|0;y=s>>>0>4096?0:4096-s|0;L4988:do{if((y|0)==0){z=564704;A=3565}else{B=v+s|0;do{if((y|0)==1){D=564704;E=B}else{F=v+(s+1)|0;a[B]=112;if((y|0)==2){D=564705;E=F;break}G=v+(s+2)|0;a[F]=110;if((y|0)==3){D=564706;E=G;break}F=v+(s+3)|0;a[G]=103;if((y|0)==4){D=564707;E=F;break}a[F]=0;break L4988}}while(0);a[E]=0;z=D;A=3565}}while(0);do{if((A|0)==3565){if((a[z]|0)==0){break}else{H=z}do{H=H+1|0;}while((a[H]|0)!=0)}}while(0);H=t|0;hE(H,f,x);x=h*3|0;f=gGq(ag(x,j)|0)|0;if((f|0)==0){I=0;i=m;return I|0}gGz(w|0,0,128);c[w>>2]=h;c[w+4>>2]=j;c[w+12>>2]=h;c[w+16>>2]=j;c[w+8>>2]=-k;c[w+20>>2]=x;c[w+28>>2]=4;c[w+32>>2]=1;do{if(l){c[w+24>>2]=4}else{t=w+24|0;if((c[2367360]|0)==1){c[t>>2]=0;break}else{c[t>>2]=3;break}}}while(0);i6(w)|0;i7(w,f,g+(ag(j-1|0,k)|0)|0);k=w+64|0;gGr(c[k>>2]|0);gGr(c[w+76>>2]|0);gGr(c[w+80>>2]|0);gGr(c[w+92>>2]|0);gGr(c[w+104>>2]|0);gGr(c[w+96>>2]|0);gGr(c[w+120>>2]|0);gGz(k|0,0,64);if((a[9375104]&1)!=0){k=c[u>>2]|0;cj(571320,43,1,k|0)|0;eY(k|0)|0}gGz(r|0,0,56);k=fw(H|0,389440)|0;if((k|0)==0){H=c[u>>2]|0;bU(H|0,557472,(J=i,i=i+8|0,c[J>>2]=912,J)|0)|0;i=J;K=0;L=0;M=0;N=0;O=0;P=0;Q=0;R=0;S=0}else{L5017:do{if((cj(7952,1,8,k|0)|0)==8){H=q|0;w=q+4|0;c[q>>2]=808464432;a[w]=73;a[q+5|0]=72;a[q+6|0]=68;a[q+7|0]=82;g=q+8|0;l=g;c[l>>2]=0;c[l+4>>2]=0;a[q+16|0]=8;a[q+17|0]=2;a[q+18|0]=0;a[q+19|0]=0;a[q+20|0]=0;a[H]=0;a[q+1|0]=0;a[q+2|0]=0;a[q+3|0]=13;a[g]=h>>>24&255;a[q+9|0]=h>>>16&255;a[q+10|0]=h>>>8&255;a[q+11|0]=h&255;a[q+12|0]=j>>>24&255;a[q+13|0]=j>>>16&255;a[q+14|0]=j>>>8&255;a[q+15|0]=j&255;do{if((cj(H|0,1,21,k|0)|0)==21){g=p;l=RK(0,w,17)|0;c[p>>2]=0;a[g]=l>>>24&255;a[g+1|0]=l>>>16&255;a[g+2|0]=l>>>8&255;a[g+3|0]=l&255;if((cj(g|0,1,4,k|0)|0)!=4){break}g=x+1|0;l=ag(g,j)|0;t=gGq(l)|0;if((t|0)==0){z=c[u>>2]|0;bU(z|0,557472,(J=i,i=i+8|0,c[J>>2]=927,J)|0)|0;i=J;T=0;U=0;V=0;W=0;X=0;Y=0;Z=0;_=0;$=0;break L5017}z=gGq(x)|0;if((z|0)==0){D=c[u>>2]|0;bU(D|0,557472,(J=i,i=i+8|0,c[J>>2]=931,J)|0)|0;i=J;T=0;U=0;V=0;W=0;X=0;Y=0;Z=0;_=t;$=0;break L5017}if((c[z-4>>2]&3|0)!=0){gGz(z|0,0,x|0)}D=gGq(x)|0;E=gGq(x)|0;y=gGq(x)|0;s=gGq(x)|0;v=gGq(x)|0;if((D|0)==0|(E|0)==0|(y|0)==0|(s|0)==0|(v|0)==0){B=c[u>>2]|0;bU(B|0,557472,(J=i,i=i+8|0,c[J>>2]=939,J)|0)|0;i=J;T=D;U=E;V=y;W=s;X=v;Y=z;Z=0;_=t;$=0;break L5017}if((j|0)!=0){B=(h|0)==0;F=(x|0)==0;G=x>>>0>3;aa=t;ab=0;ac=f;while(1){if(!B){ad=ac;ae=D;af=0;while(1){a[ae+2|0]=a[ad]|0;a[ae+1|0]=a[ad+1|0]|0;a[ae]=a[ad+2|0]|0;ah=af+1|0;if(ah>>>0<h>>>0){ad=ad+3|0;ae=ae+3|0;af=ah}else{break}}}if(F){ai=0;aj=0}else{af=0;ae=0;while(1){ad=a[D+af|0]|0;ah=ad<<24>>24;ak=(ad<<24>>24>-1?ah:-ah|0)+ae|0;ah=af+1|0;if(ah>>>0<x>>>0){af=ah;ae=ak}else{al=0;break}}while(1){a[E+al|0]=(a[D+al|0]|0)-(a[z+al|0]|0)&255;ae=al+1|0;if(ae>>>0<x>>>0){al=ae}else{am=0;an=0;break}}while(1){ae=a[E+am|0]|0;af=ae<<24>>24;ah=(ae<<24>>24>-1?af:-af|0)+an|0;af=am+1|0;if(af>>>0<x>>>0){am=af;an=ah}else{ai=ah;aj=ak;break}}}a[y]=a[D]|0;a[y+1|0]=a[D+1|0]|0;a[y+2|0]=a[D+2|0]|0;if(G){ah=3;do{a[y+ah|0]=(a[D+ah|0]|0)-(a[D+(ah-3)|0]|0)&255;ah=ah+1|0;}while(ah>>>0<x>>>0)}if(F){ao=0}else{ah=0;af=0;while(1){ae=a[y+ah|0]|0;ad=ae<<24>>24;ap=(ae<<24>>24>-1?ad:-ad|0)+af|0;ad=ah+1|0;if(ad>>>0<x>>>0){ah=ad;af=ap}else{ao=ap;break}}}af=0;do{a[s+af|0]=(a[D+af|0]|0)-((d[z+af|0]|0)>>>1)&255;af=af+1|0;}while(af>>>0<3);if(G){af=3;do{a[s+af|0]=(d[D+af|0]|0)-(((d[z+af|0]|0)+(d[D+(af-3)|0]|0)|0)>>>1)&255;af=af+1|0;}while(af>>>0<x>>>0)}if(F){aq=0}else{af=0;ah=0;while(1){ap=a[s+af|0]|0;ad=ap<<24>>24;ae=(ap<<24>>24>-1?ad:-ad|0)+ah|0;ad=af+1|0;if(ad>>>0<x>>>0){af=ad;ah=ae}else{aq=ae;break}}}ah=0;do{a[v+ah|0]=(a[D+ah|0]|0)-(a[z+ah|0]|0)&255;ah=ah+1|0;}while(ah>>>0<3);if(G){ah=3;do{af=ah-3|0;ae=a[D+af|0]|0;ad=ae&255;ap=a[z+ah|0]|0;ar=ap&255;as=a[z+af|0]|0;af=as&255;at=ar+ad-af|0;au=at-ad|0;ad=(au|0)>-1?au:-au|0;au=at-ar|0;ar=(au|0)>-1?au:-au|0;au=at-af|0;af=(au|0)>-1?au:-au|0;if((ad|0)>(ar|0)|(ad|0)>(af|0)){av=(ar|0)>(af|0)?as:ap}else{av=ae}a[v+ah|0]=(a[D+ah|0]|0)-av&255;ah=ah+1|0;}while(ah>>>0<x>>>0)}if(F){aw=0}else{ah=0;ae=0;while(1){ap=a[v+ah|0]|0;as=ap<<24>>24;af=(ap<<24>>24>-1?as:-as|0)+ae|0;as=ah+1|0;if(as>>>0<x>>>0){ah=as;ae=af}else{aw=af;break}}}ae=ao>>>0<aj>>>0;ah=ae?ao:aj;af=ai>>>0<ah>>>0;as=af?ai:ah;ah=aq>>>0<as>>>0;ap=aw>>>0<(ah?aq:as)>>>0;as=ap?v:ah?s:af?E:ae?y:D;ar=aa+1|0;a[aa]=ap?4:ah?3:af?2:ae&1;gGC(ar|0,as|0,x)|0;gGC(z|0,D|0,x)|0;as=ab+1|0;if(as>>>0<j>>>0){aa=aa+g|0;ab=as;ac=ac+x|0}else{break}}}ac=l<<1;ab=gGq(ac)|0;if((ab|0)==0){g=c[u>>2]|0;bU(g|0,557472,(J=i,i=i+8|0,c[J>>2]=999,J)|0)|0;i=J;T=D;U=E;V=y;W=s;X=v;Y=z;Z=0;_=t;$=0;break L5017}g=r|0;c[g>>2]=t;aa=r+4|0;c[aa>>2]=l;F=r+12|0;c[F>>2]=ab+8;G=r+16|0;c[G>>2]=ac;ac=r+24|0;c[ac>>2]=0;B=r+32|0;as=c[B>>2]|0;if((as|0)==0){c[B>>2]=7122;c[r+40>>2]=0;ax=7122}else{ax=as}as=r+36|0;if((c[as>>2]|0)==0){c[as>>2]=494}ar=r+40|0;ae=gp[ax&16383](c[ar>>2]|0,1,5828)|0;af=r+28|0;L5093:do{if((ae|0)==0){ay=af}else{c[af>>2]=ae;c[ae>>2]=r;c[ae+24>>2]=1;c[ae+28>>2]=0;c[ae+48>>2]=15;ah=ae+44|0;c[ah>>2]=32768;c[ae+52>>2]=32767;c[ae+80>>2]=15;ap=ae+76|0;c[ap>>2]=32768;c[ae+84>>2]=32767;c[ae+88>>2]=5;ad=ae+56|0;c[ad>>2]=gp[c[B>>2]&16383](c[ar>>2]|0,32768,2)|0;au=ae+64|0;c[au>>2]=gp[c[B>>2]&16383](c[ar>>2]|0,c[ah>>2]|0,2)|0;ah=ae+68|0;c[ah>>2]=gp[c[B>>2]&16383](c[ar>>2]|0,c[ap>>2]|0,2)|0;c[ae+5824>>2]=0;ap=ae+5788|0;c[ap>>2]=16384;at=gp[c[B>>2]&16383](c[ar>>2]|0,16384,4)|0;az=at;c[ae+8>>2]=at;aA=c[ap>>2]|0;c[ae+12>>2]=aA<<2;do{if((c[ad>>2]|0)!=0){if((c[au>>2]|0)==0){break}if((c[ah>>2]|0)==0|(at|0)==0){break}c[ae+5796>>2]=az+(aA>>>1<<1);c[ae+5784>>2]=at+(aA*3|0);c[ae+132>>2]=9;c[ae+136>>2]=0;a[ae+36|0]=8;ap=c[af>>2]|0;if((ap|0)==0){ay=af;break L5093}if((c[B>>2]|0)==0){ay=af;break L5093}if((c[as>>2]|0)==0){ay=af;break L5093}c[r+20>>2]=0;c[r+8>>2]=0;c[ac>>2]=0;c[r+44>>2]=2;c[ap+20>>2]=0;c[ap+16>>2]=c[ap+8>>2];aB=ap+24|0;aC=c[aB>>2]|0;if((aC|0)<0){aD=-aC|0;c[aB>>2]=aD;aE=aD}else{aE=aC}c[ap+4>>2]=(aE|0)!=0?42:113;c[r+48>>2]=(aE|0)!=2;c[ap+40>>2]=0;c[ap+2840>>2]=ap+148;c[ap+2848>>2]=2344;c[ap+2852>>2]=ap+2440;c[ap+2860>>2]=2488;c[ap+2864>>2]=ap+2684;c[ap+2872>>2]=2512;b[ap+5816>>1]=0;c[ap+5820>>2]=0;RL(ap);ap=c[af>>2]|0;c[ap+60>>2]=c[ap+44>>2]<<1;aC=ap+76|0;aD=ap+68|0;b[(c[aD>>2]|0)+((c[aC>>2]|0)-1<<1)>>1]=0;gGz(c[aD>>2]|0,0,(c[aC>>2]<<1)-2|0);aC=c[ap+132>>2]|0;c[ap+128>>2]=e[61658+(aC*12|0)>>1]|0;c[ap+140>>2]=e[61656+(aC*12|0)>>1]|0;c[ap+144>>2]=e[61660+(aC*12|0)>>1]|0;c[ap+124>>2]=e[61662+(aC*12|0)>>1]|0;c[ap+108>>2]=0;c[ap+92>>2]=0;c[ap+116>>2]=0;c[ap+5812>>2]=0;c[ap+120>>2]=2;c[ap+96>>2]=2;c[ap+104>>2]=0;c[ap+72>>2]=0;ay=af;break L5093}}while(0);c[ae+4>>2]=666;c[ac>>2]=157176;aA=c[af>>2]|0;if((aA|0)==0){ay=af;break}switch(c[aA+4>>2]|0){case 666:case 113:case 103:case 91:case 73:case 69:case 42:{break};default:{ay=af;break L5093}}at=c[aA+8>>2]|0;if((at|0)==0){aF=aA}else{gg[c[as>>2]&4095](c[ar>>2]|0,at);aF=c[af>>2]|0}at=c[aF+68>>2]|0;if((at|0)==0){aG=aF}else{gg[c[as>>2]&4095](c[ar>>2]|0,at);aG=c[af>>2]|0}at=c[aG+64>>2]|0;if((at|0)==0){aH=aG}else{gg[c[as>>2]&4095](c[ar>>2]|0,at);aH=c[af>>2]|0}at=c[aH+56>>2]|0;if((at|0)==0){aI=aH}else{gg[c[as>>2]&4095](c[ar>>2]|0,at);aI=c[af>>2]|0}gg[c[as>>2]&4095](c[ar>>2]|0,aI);c[af>>2]=0;ay=af}}while(0);af=c[ay>>2]|0;ae=af;L5121:do{if((af|0)!=0){L5123:do{if((c[F>>2]|0)==0){A=3649}else{if((c[g>>2]|0)==0){if((c[aa>>2]|0)!=0){A=3649;break}}B=af+4|0;l=c[B>>2]|0;if((c[G>>2]|0)==0){c[ac>>2]=126960;aJ=0;break}at=af;c[af>>2]=r;aA=af+40|0;c[aA>>2]=4;do{if((l|0)==42){if((c[af+24>>2]|0)!=2){az=(c[af+48>>2]<<12)-30720|0;do{if((c[af+136>>2]|0)>1){aK=0}else{ah=c[af+132>>2]|0;if((ah|0)<2){aK=0;break}if((ah|0)<6){aK=64;break}aK=(ah|0)==6?128:192}}while(0);ah=aK|az;au=af+108|0;ad=(c[au>>2]|0)==0?ah:ah|32;ah=(ad|((ad>>>0)%31|0))^31;c[B>>2]=113;ad=af+20|0;ap=c[ad>>2]|0;c[ad>>2]=ap+1;aC=af+8|0;a[(c[aC>>2]|0)+ap|0]=ah>>>8&255;ap=c[ad>>2]|0;c[ad>>2]=ap+1;a[(c[aC>>2]|0)+ap|0]=ah&255;ah=r+48|0;if((c[au>>2]|0)!=0){au=c[ah>>2]|0;ap=c[ad>>2]|0;c[ad>>2]=ap+1;a[(c[aC>>2]|0)+ap|0]=au>>>24&255;ap=c[ad>>2]|0;c[ad>>2]=ap+1;a[(c[aC>>2]|0)+ap|0]=au>>>16&255;au=c[ah>>2]|0;ap=c[ad>>2]|0;c[ad>>2]=ap+1;a[(c[aC>>2]|0)+ap|0]=au>>>8&255;ap=c[ad>>2]|0;c[ad>>2]=ap+1;a[(c[aC>>2]|0)+ap|0]=au&255}c[ah>>2]=1;aL=c[B>>2]|0;A=3673;break}ah=r+48|0;c[ah>>2]=0;au=af+20|0;ap=c[au>>2]|0;c[au>>2]=ap+1;aC=af+8|0;a[(c[aC>>2]|0)+ap|0]=31;ap=c[au>>2]|0;c[au>>2]=ap+1;a[(c[aC>>2]|0)+ap|0]=-117;ap=c[au>>2]|0;c[au>>2]=ap+1;a[(c[aC>>2]|0)+ap|0]=8;ap=af+28|0;ad=c[ap>>2]|0;if((ad|0)==0){aD=c[au>>2]|0;c[au>>2]=aD+1;a[(c[aC>>2]|0)+aD|0]=0;aD=c[au>>2]|0;c[au>>2]=aD+1;a[(c[aC>>2]|0)+aD|0]=0;aD=c[au>>2]|0;c[au>>2]=aD+1;a[(c[aC>>2]|0)+aD|0]=0;aD=c[au>>2]|0;c[au>>2]=aD+1;a[(c[aC>>2]|0)+aD|0]=0;aD=c[au>>2]|0;c[au>>2]=aD+1;a[(c[aC>>2]|0)+aD|0]=0;aD=c[af+132>>2]|0;do{if((aD|0)==9){aM=2}else{if((c[af+136>>2]|0)>1){aM=4;break}aM=(aD|0)<2?4:0}}while(0);aD=c[au>>2]|0;c[au>>2]=aD+1;a[(c[aC>>2]|0)+aD|0]=aM;aD=c[au>>2]|0;c[au>>2]=aD+1;a[(c[aC>>2]|0)+aD|0]=3;c[B>>2]=113;break}aD=((c[ad+44>>2]|0)!=0?2:0)|(c[ad>>2]|0)!=0|((c[ad+16>>2]|0)==0?0:4)|((c[ad+28>>2]|0)==0?0:8)|((c[ad+36>>2]|0)==0?0:16);az=c[au>>2]|0;c[au>>2]=az+1;a[(c[aC>>2]|0)+az|0]=aD;aD=c[(c[ap>>2]|0)+4>>2]&255;az=c[au>>2]|0;c[au>>2]=az+1;a[(c[aC>>2]|0)+az|0]=aD;aD=(c[(c[ap>>2]|0)+4>>2]|0)>>>8&255;az=c[au>>2]|0;c[au>>2]=az+1;a[(c[aC>>2]|0)+az|0]=aD;aD=(c[(c[ap>>2]|0)+4>>2]|0)>>>16&255;az=c[au>>2]|0;c[au>>2]=az+1;a[(c[aC>>2]|0)+az|0]=aD;aD=(c[(c[ap>>2]|0)+4>>2]|0)>>>24&255;az=c[au>>2]|0;c[au>>2]=az+1;a[(c[aC>>2]|0)+az|0]=aD;aD=c[af+132>>2]|0;do{if((aD|0)==9){aN=2}else{if((c[af+136>>2]|0)>1){aN=4;break}aN=(aD|0)<2?4:0}}while(0);aD=c[au>>2]|0;c[au>>2]=aD+1;a[(c[aC>>2]|0)+aD|0]=aN;aD=c[(c[ap>>2]|0)+12>>2]&255;ad=c[au>>2]|0;c[au>>2]=ad+1;a[(c[aC>>2]|0)+ad|0]=aD;aD=c[ap>>2]|0;if((c[aD+16>>2]|0)==0){aO=aD}else{ad=c[aD+20>>2]&255;aD=c[au>>2]|0;c[au>>2]=aD+1;a[(c[aC>>2]|0)+aD|0]=ad;ad=(c[(c[ap>>2]|0)+20>>2]|0)>>>8&255;aD=c[au>>2]|0;c[au>>2]=aD+1;a[(c[aC>>2]|0)+aD|0]=ad;aO=c[ap>>2]|0}if((c[aO+44>>2]|0)!=0){c[ah>>2]=RK(c[ah>>2]|0,c[aC>>2]|0,c[au>>2]|0)|0}c[af+32>>2]=0;c[B>>2]=69;aP=ap;A=3675}else{aL=l;A=3673}}while(0);do{if((A|0)==3673){if((aL|0)!=69){aQ=aL;A=3701;break}aP=af+28|0;A=3675}}while(0);do{if((A|0)==3675){l=c[aP>>2]|0;if((c[l+16>>2]|0)==0){c[B>>2]=73;aR=l;A=3703;break}ad=af+20|0;aD=c[ad>>2]|0;az=af+32|0;aB=c[az>>2]|0;L5169:do{if(aB>>>0<(c[l+20>>2]&65535)>>>0){aS=af+12|0;aT=r+48|0;aU=af+8|0;aV=r+20|0;aW=aD;aX=l;aZ=aD;a_=aB;while(1){if((aZ|0)==(c[aS>>2]|0)){if((c[aX+44>>2]|0)!=0&aZ>>>0>aW>>>0){c[aT>>2]=RK(c[aT>>2]|0,(c[aU>>2]|0)+aW|0,aZ-aW|0)|0}a$=c[ay>>2]|0;a0=a$+5820|0;a1=c[a0>>2]|0;do{if((a1|0)==16){a2=a$+5816|0;a3=b[a2>>1]&255;a4=a$+20|0;a6=c[a4>>2]|0;c[a4>>2]=a6+1;a7=a$+8|0;a[(c[a7>>2]|0)+a6|0]=a3;a3=(e[a2>>1]|0)>>>8&255;a6=c[a4>>2]|0;c[a4>>2]=a6+1;a[(c[a7>>2]|0)+a6|0]=a3;b[a2>>1]=0;c[a0>>2]=0;a8=a4}else{if((a1|0)>7){a4=a$+5816|0;a2=b[a4>>1]&255;a3=a$+20|0;a6=c[a3>>2]|0;c[a3>>2]=a6+1;a[(c[a$+8>>2]|0)+a6|0]=a2;b[a4>>1]=(e[a4>>1]|0)>>>8;c[a0>>2]=(c[a0>>2]|0)-8;a8=a3;break}else{a8=a$+20|0;break}}}while(0);a0=c[a8>>2]|0;a1=c[G>>2]|0;a3=a0>>>0>a1>>>0?a1:a0;do{if((a3|0)!=0){a0=c[F>>2]|0;a1=a$+16|0;a4=a1;a2=c[a4>>2]|0;gGC(a0|0,a2|0,a3)|0;c[F>>2]=(c[F>>2]|0)+a3;a2=a1|0;c[a2>>2]=(c[a4>>2]|0)+a3;c[aV>>2]=(c[aV>>2]|0)+a3;c[G>>2]=(c[G>>2]|0)-a3;a4=c[a8>>2]|0;c[a8>>2]=a4-a3;if((a4|0)!=(a3|0)){break}c[a2>>2]=c[a$+8>>2]}}while(0);a9=c[ad>>2]|0;if((a9|0)==(c[aS>>2]|0)){break}ba=a9;bb=a9;bc=c[az>>2]|0;bd=c[aP>>2]|0}else{ba=aW;bb=aZ;bc=a_;bd=aX}a$=a[(c[bd+16>>2]|0)+bc|0]|0;c[ad>>2]=bb+1;a[(c[aU>>2]|0)+bb|0]=a$;a$=(c[az>>2]|0)+1|0;c[az>>2]=a$;a3=c[aP>>2]|0;if(a$>>>0>=(c[a3+20>>2]&65535)>>>0){be=ba;bf=a3;break L5169}aW=ba;aX=a3;aZ=c[ad>>2]|0;a_=a$}be=a9;bf=c[aP>>2]|0}else{be=aD;bf=l}}while(0);do{if((c[bf+44>>2]|0)==0){bg=bf}else{l=c[ad>>2]|0;if(l>>>0<=be>>>0){bg=bf;break}aD=r+48|0;c[aD>>2]=RK(c[aD>>2]|0,(c[af+8>>2]|0)+be|0,l-be|0)|0;bg=c[aP>>2]|0}}while(0);if((c[az>>2]|0)==(c[bg+20>>2]|0)){c[az>>2]=0;c[B>>2]=73;aR=bg;A=3703;break}else{aQ=c[B>>2]|0;A=3701;break}}}while(0);do{if((A|0)==3701){if((aQ|0)!=73){bh=aQ;A=3726;break}aR=c[af+28>>2]|0;A=3703}}while(0);do{if((A|0)==3703){ad=af+28|0;if((c[aR+28>>2]|0)==0){c[B>>2]=91;bi=ad;A=3728;break}l=af+20|0;aD=c[l>>2]|0;aB=af+12|0;ap=r+48|0;au=af+8|0;aC=r+20|0;ah=af+32|0;a_=aD;aZ=aD;while(1){if((aZ|0)==(c[aB>>2]|0)){if((c[(c[ad>>2]|0)+44>>2]|0)!=0&aZ>>>0>a_>>>0){c[ap>>2]=RK(c[ap>>2]|0,(c[au>>2]|0)+a_|0,aZ-a_|0)|0}aD=c[ay>>2]|0;aX=aD+5820|0;aW=c[aX>>2]|0;do{if((aW|0)==16){aU=aD+5816|0;aS=b[aU>>1]&255;aV=aD+20|0;aT=c[aV>>2]|0;c[aV>>2]=aT+1;a$=aD+8|0;a[(c[a$>>2]|0)+aT|0]=aS;aS=(e[aU>>1]|0)>>>8&255;aT=c[aV>>2]|0;c[aV>>2]=aT+1;a[(c[a$>>2]|0)+aT|0]=aS;b[aU>>1]=0;c[aX>>2]=0;bj=aV}else{if((aW|0)>7){aV=aD+5816|0;aU=b[aV>>1]&255;aS=aD+20|0;aT=c[aS>>2]|0;c[aS>>2]=aT+1;a[(c[aD+8>>2]|0)+aT|0]=aU;b[aV>>1]=(e[aV>>1]|0)>>>8;c[aX>>2]=(c[aX>>2]|0)-8;bj=aS;break}else{bj=aD+20|0;break}}}while(0);aX=c[bj>>2]|0;aW=c[G>>2]|0;aS=aX>>>0>aW>>>0?aW:aX;do{if((aS|0)!=0){aX=c[F>>2]|0;aW=aD+16|0;aV=aW;aU=c[aV>>2]|0;gGC(aX|0,aU|0,aS)|0;c[F>>2]=(c[F>>2]|0)+aS;aU=aW|0;c[aU>>2]=(c[aV>>2]|0)+aS;c[aC>>2]=(c[aC>>2]|0)+aS;c[G>>2]=(c[G>>2]|0)-aS;aV=c[bj>>2]|0;c[bj>>2]=aV-aS;if((aV|0)!=(aS|0)){break}c[aU>>2]=c[aD+8>>2]}}while(0);aD=c[l>>2]|0;if((aD|0)==(c[aB>>2]|0)){bk=1;bl=aD;break}else{bm=aD;bn=aD}}else{bm=a_;bn=aZ}aD=c[ah>>2]|0;c[ah>>2]=aD+1;aS=a[(c[(c[ad>>2]|0)+28>>2]|0)+aD|0]|0;c[l>>2]=bn+1;a[(c[au>>2]|0)+bn|0]=aS;if(aS<<24>>24==0){bk=0;bl=bm;break}a_=bm;aZ=c[l>>2]|0}do{if((c[(c[ad>>2]|0)+44>>2]|0)!=0){aZ=c[l>>2]|0;if(aZ>>>0<=bl>>>0){break}c[ap>>2]=RK(c[ap>>2]|0,(c[au>>2]|0)+bl|0,aZ-bl|0)|0}}while(0);if((bk|0)==0){c[ah>>2]=0;c[B>>2]=91;bi=ad;A=3728;break}else{bh=c[B>>2]|0;A=3726;break}}}while(0);do{if((A|0)==3726){if((bh|0)!=91){bo=bh;A=3751;break}bi=af+28|0;A=3728}}while(0);do{if((A|0)==3728){if((c[(c[bi>>2]|0)+36>>2]|0)==0){c[B>>2]=103;bp=bi;A=3753;break}au=af+20|0;ap=c[au>>2]|0;l=af+12|0;aZ=r+48|0;a_=af+8|0;aB=r+20|0;aC=af+32|0;az=ap;aS=ap;while(1){if((aS|0)==(c[l>>2]|0)){if((c[(c[bi>>2]|0)+44>>2]|0)!=0&aS>>>0>az>>>0){c[aZ>>2]=RK(c[aZ>>2]|0,(c[a_>>2]|0)+az|0,aS-az|0)|0}ap=c[ay>>2]|0;aD=ap+5820|0;aU=c[aD>>2]|0;do{if((aU|0)==16){aV=ap+5816|0;aW=b[aV>>1]&255;aX=ap+20|0;aT=c[aX>>2]|0;c[aX>>2]=aT+1;a$=ap+8|0;a[(c[a$>>2]|0)+aT|0]=aW;aW=(e[aV>>1]|0)>>>8&255;aT=c[aX>>2]|0;c[aX>>2]=aT+1;a[(c[a$>>2]|0)+aT|0]=aW;b[aV>>1]=0;c[aD>>2]=0;bq=aX}else{if((aU|0)>7){aX=ap+5816|0;aV=b[aX>>1]&255;aW=ap+20|0;aT=c[aW>>2]|0;c[aW>>2]=aT+1;a[(c[ap+8>>2]|0)+aT|0]=aV;b[aX>>1]=(e[aX>>1]|0)>>>8;c[aD>>2]=(c[aD>>2]|0)-8;bq=aW;break}else{bq=ap+20|0;break}}}while(0);aD=c[bq>>2]|0;aU=c[G>>2]|0;aW=aD>>>0>aU>>>0?aU:aD;do{if((aW|0)!=0){aD=c[F>>2]|0;aU=ap+16|0;aX=aU;aV=c[aX>>2]|0;gGC(aD|0,aV|0,aW)|0;c[F>>2]=(c[F>>2]|0)+aW;aV=aU|0;c[aV>>2]=(c[aX>>2]|0)+aW;c[aB>>2]=(c[aB>>2]|0)+aW;c[G>>2]=(c[G>>2]|0)-aW;aX=c[bq>>2]|0;c[bq>>2]=aX-aW;if((aX|0)!=(aW|0)){break}c[aV>>2]=c[ap+8>>2]}}while(0);ap=c[au>>2]|0;if((ap|0)==(c[l>>2]|0)){br=1;bs=ap;break}else{bt=ap;bu=ap}}else{bt=az;bu=aS}ap=c[aC>>2]|0;c[aC>>2]=ap+1;aW=a[(c[(c[bi>>2]|0)+36>>2]|0)+ap|0]|0;c[au>>2]=bu+1;a[(c[a_>>2]|0)+bu|0]=aW;if(aW<<24>>24==0){br=0;bs=bt;break}az=bt;aS=c[au>>2]|0}do{if((c[(c[bi>>2]|0)+44>>2]|0)!=0){aS=c[au>>2]|0;if(aS>>>0<=bs>>>0){break}c[aZ>>2]=RK(c[aZ>>2]|0,(c[a_>>2]|0)+bs|0,aS-bs|0)|0}}while(0);if((br|0)==0){c[B>>2]=103;bp=bi;A=3753;break}else{bo=c[B>>2]|0;A=3751;break}}}while(0);do{if((A|0)==3751){if((bo|0)!=103){break}bp=af+28|0;A=3753}}while(0);do{if((A|0)==3753){if((c[(c[bp>>2]|0)+44>>2]|0)==0){c[B>>2]=113;break}a_=af+20|0;aZ=af+12|0;do{if(((c[a_>>2]|0)+2|0)>>>0>(c[aZ>>2]|0)>>>0){au=c[ay>>2]|0;aS=au+5820|0;az=c[aS>>2]|0;do{if((az|0)==16){aC=au+5816|0;l=b[aC>>1]&255;aB=au+20|0;ad=c[aB>>2]|0;c[aB>>2]=ad+1;ah=au+8|0;a[(c[ah>>2]|0)+ad|0]=l;l=(e[aC>>1]|0)>>>8&255;ad=c[aB>>2]|0;c[aB>>2]=ad+1;a[(c[ah>>2]|0)+ad|0]=l;b[aC>>1]=0;c[aS>>2]=0;bv=aB}else{if((az|0)>7){aB=au+5816|0;aC=b[aB>>1]&255;l=au+20|0;ad=c[l>>2]|0;c[l>>2]=ad+1;a[(c[au+8>>2]|0)+ad|0]=aC;b[aB>>1]=(e[aB>>1]|0)>>>8;c[aS>>2]=(c[aS>>2]|0)-8;bv=l;break}else{bv=au+20|0;break}}}while(0);aS=c[bv>>2]|0;az=c[G>>2]|0;l=aS>>>0>az>>>0?az:aS;if((l|0)==0){break}aS=c[F>>2]|0;az=au+16|0;aB=az;aC=c[aB>>2]|0;gGC(aS|0,aC|0,l)|0;c[F>>2]=(c[F>>2]|0)+l;aC=az|0;c[aC>>2]=(c[aB>>2]|0)+l;aB=r+20|0;c[aB>>2]=(c[aB>>2]|0)+l;c[G>>2]=(c[G>>2]|0)-l;aB=c[bv>>2]|0;c[bv>>2]=aB-l;if((aB|0)!=(l|0)){break}c[aC>>2]=c[au+8>>2]}}while(0);aC=c[a_>>2]|0;if((aC+2|0)>>>0>(c[aZ>>2]|0)>>>0){break}l=r+48|0;aB=c[l>>2]&255;c[a_>>2]=aC+1;az=af+8|0;a[(c[az>>2]|0)+aC|0]=aB;aB=(c[l>>2]|0)>>>8&255;aC=c[a_>>2]|0;c[a_>>2]=aC+1;a[(c[az>>2]|0)+aC|0]=aB;c[l>>2]=0;c[B>>2]=113}}while(0);l=af+20|0;do{if((c[l>>2]|0)==0){aB=c[aa>>2]|0;bw=(aB|0)==0?0:aB}else{aB=c[ay>>2]|0;aC=aB+5820|0;az=c[aC>>2]|0;do{if((az|0)==16){aS=aB+5816|0;ad=b[aS>>1]&255;ah=aB+20|0;aW=c[ah>>2]|0;c[ah>>2]=aW+1;ap=aB+8|0;a[(c[ap>>2]|0)+aW|0]=ad;ad=(e[aS>>1]|0)>>>8&255;aW=c[ah>>2]|0;c[ah>>2]=aW+1;a[(c[ap>>2]|0)+aW|0]=ad;b[aS>>1]=0;c[aC>>2]=0;bx=ah}else{if((az|0)>7){ah=aB+5816|0;aS=b[ah>>1]&255;ad=aB+20|0;aW=c[ad>>2]|0;c[ad>>2]=aW+1;a[(c[aB+8>>2]|0)+aW|0]=aS;b[ah>>1]=(e[ah>>1]|0)>>>8;c[aC>>2]=(c[aC>>2]|0)-8;bx=ad;break}else{bx=aB+20|0;break}}}while(0);aC=c[bx>>2]|0;az=c[G>>2]|0;a_=aC>>>0>az>>>0?az:aC;if((a_|0)==0){by=az}else{az=c[F>>2]|0;aC=aB+16|0;aZ=aC;ad=c[aZ>>2]|0;gGC(az|0,ad|0,a_)|0;c[F>>2]=(c[F>>2]|0)+a_;ad=aC|0;c[ad>>2]=(c[aZ>>2]|0)+a_;aZ=r+20|0;c[aZ>>2]=(c[aZ>>2]|0)+a_;c[G>>2]=(c[G>>2]|0)-a_;aZ=c[bx>>2]|0;c[bx>>2]=aZ-a_;if((aZ|0)==(a_|0)){c[ad>>2]=c[aB+8>>2]}by=c[G>>2]|0}if((by|0)==0){c[aA>>2]=-1;aJ=0;break L5123}else{bw=c[aa>>2]|0;break}}}while(0);ad=(c[B>>2]|0)==666;a_=(bw|0)==0;do{if(ad){if(a_){A=3784;break}c[ac>>2]=126960;aJ=0;break L5123}else{if(a_){A=3784}else{A=3785}}}while(0);if((A|0)==3784){if((c[af+116>>2]|0)==0^1|ad^1){A=3785}}L5321:do{if((A|0)==3785){a_=c[af+136>>2]|0;L5323:do{if((a_|0)==3){aZ=af+116|0;aC=af+96|0;az=af+108|0;ah=af+5792|0;aS=af+5796|0;aW=af+5784|0;ap=af+2440|0;aV=af+5788|0;aX=af+56|0;aU=af+92|0;aD=af;L5325:while(1){aT=c[aZ>>2]|0;do{if(aT>>>0<259){RW(ae);a$=c[aZ>>2]|0;if((a$|0)==0){break L5325}c[aC>>2]=0;if(a$>>>0>2){bz=a$;A=3818;break}bA=c[az>>2]|0;A=3833}else{c[aC>>2]=0;bz=aT;A=3818}}while(0);do{if((A|0)==3818){A=0;aT=c[az>>2]|0;if((aT|0)==0){bA=0;A=3833;break}a$=c[aX>>2]|0;a3=a[a$+(aT-1)|0]|0;if(a3<<24>>24!=(a[a$+aT|0]|0)){bA=aT;A=3833;break}if(a3<<24>>24!=(a[a$+(aT+1)|0]|0)){bA=aT;A=3833;break}a2=a$+(aT+2)|0;if(a3<<24>>24!=(a[a2]|0)){bA=aT;A=3833;break}a4=a$+(aT+258)|0;a$=a2;while(1){a2=a$+1|0;if(a3<<24>>24!=(a[a2]|0)){bB=a2;break}a2=a$+2|0;if(a3<<24>>24!=(a[a2]|0)){bB=a2;break}a2=a$+3|0;if(a3<<24>>24!=(a[a2]|0)){bB=a2;break}a2=a$+4|0;if(a3<<24>>24!=(a[a2]|0)){bB=a2;break}a2=a$+5|0;if(a3<<24>>24!=(a[a2]|0)){bB=a2;break}a2=a$+6|0;if(a3<<24>>24!=(a[a2]|0)){bB=a2;break}a2=a$+7|0;if(a3<<24>>24!=(a[a2]|0)){bB=a2;break}a2=a$+8|0;if(a3<<24>>24==(a[a2]|0)&a2>>>0<a4>>>0){a$=a2}else{bB=a2;break}}a$=bB-a4+258|0;a3=a$>>>0>bz>>>0?bz:a$;c[aC>>2]=a3;if(a3>>>0<=2){bA=aT;A=3833;break}a$=a3+253|0;b[(c[aS>>2]|0)+(c[ah>>2]<<1)>>1]=1;a3=c[ah>>2]|0;c[ah>>2]=a3+1;a[(c[aW>>2]|0)+a3|0]=a$&255;a3=ae+148+((d[589976+(a$&255)|0]|256)+1<<2)|0;b[a3>>1]=(b[a3>>1]|0)+1&65535;b[ap>>1]=(b[ap>>1]|0)+1&65535;a3=(c[ah>>2]|0)==((c[aV>>2]|0)-1|0);a$=c[aC>>2]|0;c[aZ>>2]=(c[aZ>>2]|0)-a$;a2=(c[az>>2]|0)+a$|0;c[az>>2]=a2;c[aC>>2]=0;if(a3){bC=a2}else{continue L5325}}}while(0);if((A|0)==3833){A=0;a2=a[(c[aX>>2]|0)+bA|0]|0;b[(c[aS>>2]|0)+(c[ah>>2]<<1)>>1]=0;a3=c[ah>>2]|0;c[ah>>2]=a3+1;a[(c[aW>>2]|0)+a3|0]=a2;a3=ae+148+((a2&255)<<2)|0;b[a3>>1]=(b[a3>>1]|0)+1&65535;a3=(c[ah>>2]|0)==((c[aV>>2]|0)-1|0);c[aZ>>2]=(c[aZ>>2]|0)-1;a2=(c[az>>2]|0)+1|0;c[az>>2]=a2;if(a3){bC=a2}else{continue}}a2=c[aU>>2]|0;if((a2|0)>-1){bD=(c[aX>>2]|0)+a2|0}else{bD=0}RN(aD,bD,bC-a2|0,0);c[aU>>2]=c[az>>2];a2=c[at>>2]|0;a3=c[a2+28>>2]|0;a$=a3+5820|0;a1=c[a$>>2]|0;do{if((a1|0)==16){a0=a3+5816|0;a6=b[a0>>1]&255;a7=a3+20|0;bE=c[a7>>2]|0;c[a7>>2]=bE+1;bF=a3+8|0;a[(c[bF>>2]|0)+bE|0]=a6;a6=(e[a0>>1]|0)>>>8&255;bE=c[a7>>2]|0;c[a7>>2]=bE+1;a[(c[bF>>2]|0)+bE|0]=a6;b[a0>>1]=0;c[a$>>2]=0;bG=a7}else{if((a1|0)>7){a7=a3+5816|0;a0=b[a7>>1]&255;a6=a3+20|0;bE=c[a6>>2]|0;c[a6>>2]=bE+1;a[(c[a3+8>>2]|0)+bE|0]=a0;b[a7>>1]=(e[a7>>1]|0)>>>8;c[a$>>2]=(c[a$>>2]|0)-8;bG=a6;break}else{bG=a3+20|0;break}}}while(0);a$=c[bG>>2]|0;a1=a2+16|0;a6=c[a1>>2]|0;a7=a$>>>0>a6>>>0?a6:a$;do{if((a7|0)!=0){a$=a2+12|0;a6=c[a$>>2]|0;a0=a3+16|0;bE=c[a0>>2]|0;gGC(a6|0,bE|0,a7)|0;c[a$>>2]=(c[a$>>2]|0)+a7;c[a0>>2]=(c[a0>>2]|0)+a7;a$=a2+20|0;c[a$>>2]=(c[a$>>2]|0)+a7;c[a1>>2]=(c[a1>>2]|0)-a7;a$=c[bG>>2]|0;c[bG>>2]=a$-a7;if((a$|0)!=(a7|0)){break}c[a0>>2]=c[a3+8>>2]}}while(0);if((c[(c[at>>2]|0)+16>>2]|0)==0){break L5323}}c[af+5812>>2]=0;aZ=c[aU>>2]|0;if((aZ|0)>-1){bH=(c[aX>>2]|0)+aZ|0}else{bH=0}RN(aD,bH,(c[az>>2]|0)-aZ|0,1);c[aU>>2]=c[az>>2];aZ=c[at>>2]|0;aV=c[aZ+28>>2]|0;ah=aV+5820|0;aW=c[ah>>2]|0;do{if((aW|0)==16){aS=aV+5816|0;aC=b[aS>>1]&255;ap=aV+20|0;au=c[ap>>2]|0;c[ap>>2]=au+1;a3=aV+8|0;a[(c[a3>>2]|0)+au|0]=aC;aC=(e[aS>>1]|0)>>>8&255;au=c[ap>>2]|0;c[ap>>2]=au+1;a[(c[a3>>2]|0)+au|0]=aC;b[aS>>1]=0;c[ah>>2]=0;bI=ap}else{if((aW|0)>7){ap=aV+5816|0;aS=b[ap>>1]&255;aC=aV+20|0;au=c[aC>>2]|0;c[aC>>2]=au+1;a[(c[aV+8>>2]|0)+au|0]=aS;b[ap>>1]=(e[ap>>1]|0)>>>8;c[ah>>2]=(c[ah>>2]|0)-8;bI=aC;break}else{bI=aV+20|0;break}}}while(0);ah=c[bI>>2]|0;aW=aZ+16|0;az=c[aW>>2]|0;aU=ah>>>0>az>>>0?az:ah;do{if((aU|0)!=0){ah=aZ+12|0;az=c[ah>>2]|0;aD=aV+16|0;aX=c[aD>>2]|0;gGC(az|0,aX|0,aU)|0;c[ah>>2]=(c[ah>>2]|0)+aU;c[aD>>2]=(c[aD>>2]|0)+aU;ah=aZ+20|0;c[ah>>2]=(c[ah>>2]|0)+aU;c[aW>>2]=(c[aW>>2]|0)-aU;ah=c[bI>>2]|0;c[bI>>2]=ah-aU;if((ah|0)!=(aU|0)){break}c[aD>>2]=c[aV+8>>2]}}while(0);bJ=(c[(c[at>>2]|0)+16>>2]|0)==0?2:3;A=3857}else if((a_|0)==2){aV=af+116|0;aU=af+96|0;aW=af+108|0;aZ=af+56|0;aD=af+5792|0;ah=af+5796|0;aX=af+5784|0;az=af+5788|0;aC=af+92|0;ap=af;while(1){if((c[aV>>2]|0)==0){RW(ae);if((c[aV>>2]|0)==0){break}}c[aU>>2]=0;aS=a[(c[aZ>>2]|0)+(c[aW>>2]|0)|0]|0;b[(c[ah>>2]|0)+(c[aD>>2]<<1)>>1]=0;au=c[aD>>2]|0;c[aD>>2]=au+1;a[(c[aX>>2]|0)+au|0]=aS;au=ae+148+((aS&255)<<2)|0;b[au>>1]=(b[au>>1]|0)+1&65535;au=(c[aD>>2]|0)==((c[az>>2]|0)-1|0);c[aV>>2]=(c[aV>>2]|0)-1;aS=(c[aW>>2]|0)+1|0;c[aW>>2]=aS;if(!au){continue}au=c[aC>>2]|0;if((au|0)>-1){bK=(c[aZ>>2]|0)+au|0}else{bK=0}RN(ap,bK,aS-au|0,0);c[aC>>2]=c[aW>>2];au=c[at>>2]|0;aS=c[au+28>>2]|0;a3=aS+5820|0;a7=c[a3>>2]|0;do{if((a7|0)==16){a1=aS+5816|0;a2=b[a1>>1]&255;a0=aS+20|0;a$=c[a0>>2]|0;c[a0>>2]=a$+1;bE=aS+8|0;a[(c[bE>>2]|0)+a$|0]=a2;a2=(e[a1>>1]|0)>>>8&255;a$=c[a0>>2]|0;c[a0>>2]=a$+1;a[(c[bE>>2]|0)+a$|0]=a2;b[a1>>1]=0;c[a3>>2]=0;bL=a0}else{if((a7|0)>7){a0=aS+5816|0;a1=b[a0>>1]&255;a2=aS+20|0;a$=c[a2>>2]|0;c[a2>>2]=a$+1;a[(c[aS+8>>2]|0)+a$|0]=a1;b[a0>>1]=(e[a0>>1]|0)>>>8;c[a3>>2]=(c[a3>>2]|0)-8;bL=a2;break}else{bL=aS+20|0;break}}}while(0);a3=c[bL>>2]|0;a7=au+16|0;a2=c[a7>>2]|0;a0=a3>>>0>a2>>>0?a2:a3;do{if((a0|0)!=0){a3=au+12|0;a2=c[a3>>2]|0;a1=aS+16|0;a$=c[a1>>2]|0;gGC(a2|0,a$|0,a0)|0;c[a3>>2]=(c[a3>>2]|0)+a0;c[a1>>2]=(c[a1>>2]|0)+a0;a3=au+20|0;c[a3>>2]=(c[a3>>2]|0)+a0;c[a7>>2]=(c[a7>>2]|0)-a0;a3=c[bL>>2]|0;c[bL>>2]=a3-a0;if((a3|0)!=(a0|0)){break}c[a1>>2]=c[aS+8>>2]}}while(0);if((c[(c[at>>2]|0)+16>>2]|0)==0){break L5323}}c[af+5812>>2]=0;aV=c[aC>>2]|0;if((aV|0)>-1){bM=(c[aZ>>2]|0)+aV|0}else{bM=0}RN(ap,bM,(c[aW>>2]|0)-aV|0,1);c[aC>>2]=c[aW>>2];aV=c[at>>2]|0;az=c[aV+28>>2]|0;aD=az+5820|0;aX=c[aD>>2]|0;do{if((aX|0)==16){ah=az+5816|0;aU=b[ah>>1]&255;aS=az+20|0;a0=c[aS>>2]|0;c[aS>>2]=a0+1;a7=az+8|0;a[(c[a7>>2]|0)+a0|0]=aU;aU=(e[ah>>1]|0)>>>8&255;a0=c[aS>>2]|0;c[aS>>2]=a0+1;a[(c[a7>>2]|0)+a0|0]=aU;b[ah>>1]=0;c[aD>>2]=0;bN=aS}else{if((aX|0)>7){aS=az+5816|0;ah=b[aS>>1]&255;aU=az+20|0;a0=c[aU>>2]|0;c[aU>>2]=a0+1;a[(c[az+8>>2]|0)+a0|0]=ah;b[aS>>1]=(e[aS>>1]|0)>>>8;c[aD>>2]=(c[aD>>2]|0)-8;bN=aU;break}else{bN=az+20|0;break}}}while(0);aD=c[bN>>2]|0;aX=aV+16|0;aW=c[aX>>2]|0;aC=aD>>>0>aW>>>0?aW:aD;do{if((aC|0)!=0){aD=aV+12|0;aW=c[aD>>2]|0;ap=az+16|0;aZ=c[ap>>2]|0;gGC(aW|0,aZ|0,aC)|0;c[aD>>2]=(c[aD>>2]|0)+aC;c[ap>>2]=(c[ap>>2]|0)+aC;aD=aV+20|0;c[aD>>2]=(c[aD>>2]|0)+aC;c[aX>>2]=(c[aX>>2]|0)-aC;aD=c[bN>>2]|0;c[bN>>2]=aD-aC;if((aD|0)!=(aC|0)){break}c[ap>>2]=c[az+8>>2]}}while(0);bJ=(c[(c[at>>2]|0)+16>>2]|0)==0?2:3;A=3857}else{bJ=gA[c[61664+((c[af+132>>2]|0)*12|0)>>2]&16383](ae,4)|0;A=3857}}while(0);do{if((A|0)==3857){if((bJ-2|0)>>>0<2){c[B>>2]=666}if((bJ|0)==2|(bJ|0)==0){break}else if((bJ|0)!=1){break L5321}RM(af,0,0,0);a_=c[ay>>2]|0;aB=a_+5820|0;az=c[aB>>2]|0;do{if((az|0)==16){aC=a_+5816|0;aX=b[aC>>1]&255;aV=a_+20|0;ap=c[aV>>2]|0;c[aV>>2]=ap+1;aD=a_+8|0;a[(c[aD>>2]|0)+ap|0]=aX;aX=(e[aC>>1]|0)>>>8&255;ap=c[aV>>2]|0;c[aV>>2]=ap+1;a[(c[aD>>2]|0)+ap|0]=aX;b[aC>>1]=0;c[aB>>2]=0;bO=aV}else{if((az|0)>7){aV=a_+5816|0;aC=b[aV>>1]&255;aX=a_+20|0;ap=c[aX>>2]|0;c[aX>>2]=ap+1;a[(c[a_+8>>2]|0)+ap|0]=aC;b[aV>>1]=(e[aV>>1]|0)>>>8;c[aB>>2]=(c[aB>>2]|0)-8;bO=aX;break}else{bO=a_+20|0;break}}}while(0);aB=c[bO>>2]|0;az=c[G>>2]|0;aX=aB>>>0>az>>>0?az:aB;if((aX|0)==0){bP=az}else{az=c[F>>2]|0;aB=a_+16|0;aV=aB;aC=c[aV>>2]|0;gGC(az|0,aC|0,aX)|0;c[F>>2]=(c[F>>2]|0)+aX;aC=aB|0;c[aC>>2]=(c[aV>>2]|0)+aX;aV=r+20|0;c[aV>>2]=(c[aV>>2]|0)+aX;c[G>>2]=(c[G>>2]|0)-aX;aV=c[bO>>2]|0;c[bO>>2]=aV-aX;if((aV|0)==(aX|0)){c[aC>>2]=c[a_+8>>2]}bP=c[G>>2]|0}if((bP|0)!=0){break L5321}c[aA>>2]=-1;aJ=0;break L5123}}while(0);if((c[G>>2]|0)!=0){aJ=0;break L5123}c[aA>>2]=-1;aJ=0;break L5123}}while(0);aA=af+24|0;B=c[aA>>2]|0;if((B|0)<1){aJ=1;break}at=r+48|0;ad=c[at>>2]|0;if((B|0)==2){B=c[l>>2]|0;c[l>>2]=B+1;aC=af+8|0;a[(c[aC>>2]|0)+B|0]=ad&255;B=(c[at>>2]|0)>>>8&255;aX=c[l>>2]|0;c[l>>2]=aX+1;a[(c[aC>>2]|0)+aX|0]=B;B=(c[at>>2]|0)>>>16&255;aX=c[l>>2]|0;c[l>>2]=aX+1;a[(c[aC>>2]|0)+aX|0]=B;B=(c[at>>2]|0)>>>24&255;aX=c[l>>2]|0;c[l>>2]=aX+1;a[(c[aC>>2]|0)+aX|0]=B;B=r+8|0;aX=c[B>>2]&255;aV=c[l>>2]|0;c[l>>2]=aV+1;a[(c[aC>>2]|0)+aV|0]=aX;aX=(c[B>>2]|0)>>>8&255;aV=c[l>>2]|0;c[l>>2]=aV+1;a[(c[aC>>2]|0)+aV|0]=aX;aX=(c[B>>2]|0)>>>16&255;aV=c[l>>2]|0;c[l>>2]=aV+1;a[(c[aC>>2]|0)+aV|0]=aX;aX=(c[B>>2]|0)>>>24&255;B=c[l>>2]|0;c[l>>2]=B+1;a[(c[aC>>2]|0)+B|0]=aX}else{aX=c[l>>2]|0;c[l>>2]=aX+1;B=af+8|0;a[(c[B>>2]|0)+aX|0]=ad>>>24&255;aX=c[l>>2]|0;c[l>>2]=aX+1;a[(c[B>>2]|0)+aX|0]=ad>>>16&255;ad=c[at>>2]|0;at=c[l>>2]|0;c[l>>2]=at+1;a[(c[B>>2]|0)+at|0]=ad>>>8&255;at=c[l>>2]|0;c[l>>2]=at+1;a[(c[B>>2]|0)+at|0]=ad&255}ad=c[ay>>2]|0;at=ad+5820|0;B=c[at>>2]|0;do{if((B|0)==16){aX=ad+5816|0;aC=b[aX>>1]&255;aV=ad+20|0;aB=c[aV>>2]|0;c[aV>>2]=aB+1;az=ad+8|0;a[(c[az>>2]|0)+aB|0]=aC;aC=(e[aX>>1]|0)>>>8&255;aB=c[aV>>2]|0;c[aV>>2]=aB+1;a[(c[az>>2]|0)+aB|0]=aC;b[aX>>1]=0;c[at>>2]=0;bQ=aV}else{if((B|0)>7){aV=ad+5816|0;aX=b[aV>>1]&255;aC=ad+20|0;aB=c[aC>>2]|0;c[aC>>2]=aB+1;a[(c[ad+8>>2]|0)+aB|0]=aX;b[aV>>1]=(e[aV>>1]|0)>>>8;c[at>>2]=(c[at>>2]|0)-8;bQ=aC;break}else{bQ=ad+20|0;break}}}while(0);at=c[bQ>>2]|0;B=c[G>>2]|0;aC=at>>>0>B>>>0?B:at;do{if((aC|0)!=0){at=c[F>>2]|0;B=ad+16|0;aV=B;aX=c[aV>>2]|0;gGC(at|0,aX|0,aC)|0;c[F>>2]=(c[F>>2]|0)+aC;aX=B|0;c[aX>>2]=(c[aV>>2]|0)+aC;aV=r+20|0;c[aV>>2]=(c[aV>>2]|0)+aC;c[G>>2]=(c[G>>2]|0)-aC;aV=c[bQ>>2]|0;c[bQ>>2]=aV-aC;if((aV|0)!=(aC|0)){break}c[aX>>2]=c[ad+8>>2]}}while(0);ad=c[aA>>2]|0;if((ad|0)>0){c[aA>>2]=-ad}aJ=(c[l>>2]|0)==0}}while(0);if((A|0)==3649){c[ac>>2]=253696;aJ=0}ad=c[ay>>2]|0;L5463:do{if((ad|0)==0){bR=aJ;A=3899}else{switch(c[ad+4>>2]|0){case 666:case 113:case 103:case 91:case 73:case 69:case 42:{break};default:{bR=aJ;A=3899;break L5463}}aC=c[ad+8>>2]|0;if((aC|0)==0){bS=ad}else{gg[c[as>>2]&4095](c[ar>>2]|0,aC);bS=c[ay>>2]|0}aC=c[bS+68>>2]|0;if((aC|0)==0){bT=bS}else{gg[c[as>>2]&4095](c[ar>>2]|0,aC);bT=c[ay>>2]|0}aC=c[bT+64>>2]|0;if((aC|0)==0){bV=bT}else{gg[c[as>>2]&4095](c[ar>>2]|0,aC);bV=c[ay>>2]|0}aC=c[bV+56>>2]|0;if((aC|0)==0){bW=bV}else{gg[c[as>>2]&4095](c[ar>>2]|0,aC);bW=c[ay>>2]|0}gg[c[as>>2]&4095](c[ar>>2]|0,bW);c[ay>>2]=0;if(!aJ){break L5121}}}while(0);if((A|0)==3899){if(!bR){break}}ad=ab+4|0;aC=ad;C=1413563465;a[aC]=C&255;C=C>>8;a[aC+1|0]=C&255;C=C>>8;a[aC+2|0]=C&255;C=C>>8;a[aC+3|0]=C&255;aC=c[r+20>>2]|0;a[ab]=aC>>>24&255;a[ab+1|0]=aC>>>16&255;a[ab+2|0]=aC>>>8&255;a[ab+3|0]=aC&255;aX=aC+8|0;do{if((cj(ab|0,1,aX|0,k|0)|0)==(aX|0)){aV=n;B=RK(0,ad,aC+4|0)|0;c[n>>2]=0;a[aV]=B>>>24&255;a[aV+1|0]=B>>>16&255;a[aV+2|0]=B>>>8&255;a[aV+3|0]=B&255;if((cj(aV|0,1,4,k|0)|0)!=4){break}if((cj(7792,1,8,k|0)|0)==8){aV=o;B=RK(0,7796,4)|0;c[o>>2]=0;a[aV]=B>>>24&255;a[aV+1|0]=B>>>16&255;a[aV+2|0]=B>>>8&255;a[aV+3|0]=B&255;if((cj(aV|0,1,4,k|0)|0)==4){T=D;U=E;V=y;W=s;X=v;Y=z;Z=ab;_=t;$=1;break L5017}}aV=c[u>>2]|0;bU(aV|0,557472,(J=i,i=i+8|0,c[J>>2]=1020,J)|0)|0;i=J;T=D;U=E;V=y;W=s;X=v;Y=z;Z=ab;_=t;$=0;break L5017}}while(0);aC=c[u>>2]|0;bU(aC|0,557472,(J=i,i=i+8|0,c[J>>2]=1017,J)|0)|0;i=J;T=D;U=E;V=y;W=s;X=v;Y=z;Z=ab;_=t;$=0;break L5017}}while(0);ar=c[u>>2]|0;bU(ar|0,557472,(J=i,i=i+8|0,c[J>>2]=1010,J)|0)|0;i=J;T=D;U=E;V=y;W=s;X=v;Y=z;Z=ab;_=t;$=0;break L5017}}while(0);w=c[u>>2]|0;bU(w|0,557472,(J=i,i=i+8|0,c[J>>2]=922,J)|0)|0;i=J;T=0;U=0;V=0;W=0;X=0;Y=0;Z=0;_=0;$=0}else{w=c[u>>2]|0;bU(w|0,557472,(J=i,i=i+8|0,c[J>>2]=915,J)|0)|0;i=J;T=0;U=0;V=0;W=0;X=0;Y=0;Z=0;_=0;$=0}}while(0);aY(k|0)|0;K=T;L=U;M=V;N=W;O=X;P=Y;Q=Z;R=_;S=$}gGr(R);gGr(Q);gGr(K);gGr(P);gGr(L);gGr(M);gGr(N);gGr(O);if(!S){O=c[u>>2]|0;cj(441952,48,1,O|0)|0;eY(O|0)|0}gGr(f);I=S;i=m;return I|0}function iT(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;d=i;i=i+544|0;e=d|0;if((b|0)==0){i=d;return}f=b|0;if((c[f>>2]|0)!=0){g=e|0;h=d+512|0;do{if((a[9353540]|0)!=0){j=hZ(9353540,0)|0;if((j|0)==0){k=gGq(20)|0;if((k|0)==0){l=c[u>>2]|0;cj(588256,53,1,l|0)|0;eY(l|0)|0;break}if((c[k-4>>2]&3|0)!=0){gGz(k|0,0,20)}m=k}else{m=j}gGz(g|0,0,512);gGz(h|0,0,32);j=b+8|0;k=c[j>>2]|0;do{if((k|0)!=0){l=0;n=k;while(1){if((a[(c[f>>2]|0)+(l*12|0)+4|0]&1)==0){o=n}else{be(h|0,32,571984,(p=i,i=i+8|0,c[p>>2]=l,p)|0)|0;i=p;q=gGy(g|0)|0;r=q>>>0>512?0:512-q|0;L5519:do{if((r|0)==0){s=h;t=3933}else{v=r;w=e+q|0;x=h;while(1){y=v-1|0;if((y|0)==0){break}z=a[x]|0;a[w]=z;if(z<<24>>24==0){break L5519}else{v=y;w=w+1|0;x=x+1|0}}a[w]=0;s=x;t=3933}}while(0);do{if((t|0)==3933){t=0;if((a[s]|0)==0){break}else{A=s}do{A=A+1|0;}while((a[A]|0)!=0)}}while(0);o=c[j>>2]|0}x=l+1|0;if(x>>>0<o>>>0){l=x;n=o}else{break}}if((a[g]|0)==0){break}a[e+((gGy(g|0)|0)-1)|0]=0}}while(0);h0(m,9531964,g);if(!(h1(m,9353540)|0)){j=c[u>>2]|0;bU(j|0,555248,(p=i,i=i+8|0,c[p>>2]=9353540,p)|0)|0;i=p;eY(j|0)|0}hY(m)}}while(0);m=b+8|0;p=c[f>>2]|0;if((c[m>>2]|0)==0){B=p}else{g=0;e=p;while(1){gGr(c[e+(g*12|0)+8>>2]|0);p=g+1|0;o=c[f>>2]|0;if(p>>>0<(c[m>>2]|0)>>>0){g=p;e=o}else{B=o;break}}}gGr(B)}gGr(b);i=d;return}function iU(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=i;i=i+256|0;e=d|0;f=c[2380901]|0;g=f+4|0;h=c[g>>2]|0;if(h>>>0>1){j=f|0;k=1;l=h;while(1){h=c[(c[j>>2]|0)+(k<<2)>>2]|0;if((h|0)==0){m=l}else{gGr(c[h+8>>2]|0);gGr(c[(c[j>>2]|0)+(k<<2)>>2]|0);c[(c[j>>2]|0)+(k<<2)>>2]=0;m=c[g>>2]|0}h=k+1|0;if(h>>>0<m>>>0){k=h;l=m}else{break}}}c[g>>2]=1;g=f+12|0;gGr(c[g>>2]|0);c[g>>2]=0;g=e|0;e=c[b+4>>2]|0;f=c[b>>2]|0;b=(a[f+(e*12|0)+4|0]&1)!=0?201728:158776;m=c[f+(e*12|0)>>2]|0;be(g|0,256,161424,(f=i,i=i+24|0,c[f>>2]=e,c[f+8>>2]=b,c[f+16>>2]=m,f)|0)|0;i=f;m=c[2380901]|0;b=m+4|0;L5553:do{if((c[b>>2]|0)>>>0<(c[m+8>>2]|0)>>>0){e=gGq(12)|0;do{if((e|0)!=0){if((c[e-4>>2]&3|0)==0){break}gGz(e|0,0,12)}}while(0);c[e+4>>2]=1;c[e>>2]=180;l=bG(g|0)|0;k=c[b>>2]|0;c[e+8>>2]=l;l=m|0;c[(c[l>>2]|0)+(k<<2)>>2]=e;k=c[b>>2]|0;c[b>>2]=k+1;if(k>>>0>1){n=k}else{break}while(1){k=n>>>1;j=c[l>>2]|0;h=j+(k<<2)|0;o=c[h>>2]|0;p=c[j+(n<<2)>>2]|0;if((c[p+4>>2]|0)>>>0<=(c[o+4>>2]|0)>>>0){break L5553}c[h>>2]=p;c[(c[l>>2]|0)+(n<<2)>>2]=o;if(n>>>0>3){n=k}else{break}}}}while(0);if((a[9375104]&1)==0){i=d;return}n=c[u>>2]|0;bU(n|0,324680,(f=i,i=i+8|0,c[f>>2]=g,f)|0)|0;i=f;eY(n|0)|0;i=d;return}function iV(a,b,d){a=a|0;b=b|0;d=d|0;b=eW(d|0)|0;if((b|0)==0){return b|0}c[2320017]=cU()|0;return b|0}function iW(a,b,c){a=a|0;b=b|0;c=c|0;return cr(b|0,c|0)|0}function iX(a){a=a|0;return eG()|0}function iY(a){a=a|0;return cd()|0}function iZ(a,b){a=a|0;b=b|0;eE(b|0);return}function i_(a){a=a|0;dJ();return}function i$(a){a=a|0;return 1}function i0(a){a=a|0;return dp()|0}function i1(a){a=a|0;return dz()|0}function i2(b,d){b=b|0;d=+d;var e=0,f=0,h=0,i=0,j=0.0,k=0.0,l=0,m=0.0,n=0,o=0.0,p=0,q=0,r=0,s=0,t=0,u=0,v=0.0,w=0.0,x=0.0,y=0,z=0;e=b+24|0;if((c[e>>2]|0)!=0){f=b+12|0;h=0;do{i=c[f>>2]|0;j=(a[i+(h*144|0)+20|0]&1)==0?d:1.0;g[i+(h*144|0)+56>>2]=j;k=+g[i+(h*144|0)+48>>2]*j;l=i+(h*144|0)+32|0;g[l>>2]=k;m=+g[i+(h*144|0)+52>>2]*j;n=i+(h*144|0)+36|0;g[n>>2]=m;o=+g[i+(h*144|0)+60>>2];p=i+(h*144|0)+24|0;g[p>>2]=o+j*(+g[i+(h*144|0)+40>>2]-o);o=+g[i+(h*144|0)+64>>2];q=i+(h*144|0)+28|0;g[q>>2]=o+j*(+g[i+(h*144|0)+44>>2]-o);r=i+(h*144|0)+4|0;L5585:do{if((c[r>>2]|0)!=0){s=i+(h*144|0)|0;t=0;o=k;j=m;while(1){u=c[s>>2]|0;v=o*+g[u+(t*152|0)+12>>2];w=j*+g[u+(t*152|0)+16>>2];g[u+(t*152|0)+36>>2]=v*2.0;g[u+(t*152|0)+40>>2]=w*2.0;x=+g[q>>2]+ +g[u+(t*152|0)+4>>2]*+g[n>>2];g[u+(t*152|0)+28>>2]=+g[p>>2]+ +g[u+(t*152|0)>>2]*+g[l>>2]-v;g[u+(t*152|0)+32>>2]=x-w;u=t+1|0;if(u>>>0>=(c[r>>2]|0)>>>0){break L5585}t=u;o=+g[l>>2];j=+g[n>>2]}}}while(0);h=h+1|0;}while(h>>>0<(c[e>>2]|0)>>>0)}e=b+16|0;h=c[e>>2]|0;if((c[h+8>>2]|0)==0){y=h}else{gH[c[(c[b+4>>2]|0)+12>>2]&7](c[b>>2]|0,0,+g[h+24>>2],+g[h+28>>2],+g[h+32>>2],+g[h+36>>2]);y=c[e>>2]|0}if((c[y+4>>2]|0)==0){return}h=b+4|0;f=b|0;b=0;n=y;while(1){y=c[n>>2]|0;if((c[y+(b*152|0)+128>>2]|0)==0){z=n}else{gH[c[(c[h>>2]|0)+12>>2]&7](c[f>>2]|0,c[y+(b*152|0)+140>>2]|0,+g[y+(b*152|0)+28>>2],+g[y+(b*152|0)+32>>2],+g[y+(b*152|0)+36>>2],+g[y+(b*152|0)+40>>2]);z=c[e>>2]|0}y=b+1|0;if(y>>>0<(c[z+4>>2]|0)>>>0){b=y;n=z}else{break}}return}function i3(){var b=0,d=0,e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0.0,aS=0,aT=0.0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0.0,bn=0.0,bo=0,bp=0,bq=0,br=0.0,bs=0.0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0;b=i;i=i+17720|0;d=b|0;e=b+8|0;f=b+72|0;h=b+136|0;j=b+4232|0;k=b+8328|0;l=b+8344|0;m=b+8408|0;n=b+8664|0;o=b+8672|0;p=b+8736|0;q=b+8800|0;r=b+8864|0;s=b+8928|0;t=b+8992|0;v=b+13088|0;w=b+17184|0;x=b+17200|0;y=b+17264|0;z=b+17520|0;A=b+17584|0;B=b+17648|0;C=b+17712|0;D=gGq(36)|0;do{if((D|0)==0){E=0}else{if((c[D-4>>2]&3|0)!=0){gGz(D|0,0,36)}F=D;G=bG(9324856)|0;H=D+32|0;c[H>>2]=G;if((G|0)==0){gGr(D);I=0;i=b;return I|0}G=c[(c[2383355]|0)+48>>2]|0;if((G|0)==0){J=c[u>>2]|0;cj(558176,71,1,J|0)|0;eY(J|0)|0;E=F;break}J=D+4|0;gg[G&4095](c[2383358]|0,J);G=D;c[G>>2]=c[2383358];if((c[J>>2]|0)==0){E=F;break}L=hZ(9324856,0)|0;if((L|0)==0){M=c[u>>2]|0;bU(M|0,569848,(N=i,i=i+8|0,c[N>>2]=9324856,N)|0)|0;i=N;eY(M|0)|0;E=F;break}M=L+4|0;O=M;while(1){P=c[O>>2]|0;if((P|0)==0){Q=4010;break}if((fa(441448,c[P+4>>2]|0)|0)==0){Q=4009;break}else{O=P+12|0}}L5624:do{if((Q|0)==4009){O=bO()|0;c[O>>2]=0;R=ch(c[P+8>>2]|0,0,0)|0;if((c[O>>2]|0)!=0){Q=4010;break}if((R|0)==0){break}S=R*144|0;if(R>>>0>65535){T=((S>>>0)/(R>>>0)|0|0)==144?S:-1}else{T=S}S=gGq(T)|0;if((S|0)==0){c[D+12>>2]=0;break}if((c[S-4>>2]&3|0)!=0){gGz(S|0,0,T|0)}U=S;S=D+12|0;c[S>>2]=U;V=D+24|0;c[V>>2]=R;R=r|0;W=s|0;X=t|0;Y=v|0;Z=w;_=x|0;$=y|0;aa=z|0;ab=A|0;ac=B|0;ad=w+8|0;ae=w|0;af=w+4|0;ag=c[u>>2]|0;ah=e|0;ai=f|0;aj=h|0;ak=j|0;al=k;am=l|0;an=m|0;ao=o|0;ap=p|0;aq=q|0;ar=k+8|0;as=k|0;at=k+4|0;au=0;av=U;while(1){be(R|0,64,130976,(N=i,i=i+8|0,c[N>>2]=au,N)|0)|0;i=N;do{if(h_(L,R,X)|0){hM(Y,9324856,X);gGz(Z|0,0,12);if((a[9533596]&1)==0){if(jx(Y,w,16,0)|0){Q=4024}else{Q=4025}}else{if(jx(Y,w,0,16)|0){Q=4024}else{Q=4025}}if((Q|0)==4025){Q=0;bU(ag|0,105632,(N=i,i=i+8|0,c[N>>2]=Y,N)|0)|0;i=N;eY(ag|0)|0;aw=0;break}else if((Q|0)==4024){Q=0;c[av+(au*144|0)+8>>2]=c[ad>>2];c[av+(au*144|0)+12>>2]=c[ae>>2];c[av+(au*144|0)+16>>2]=c[af>>2];Q=4026;break}}else{Q=4026}}while(0);L5647:do{if((Q|0)==4026){Q=0;be(W|0,64,81520,(N=i,i=i+8|0,c[N>>2]=au,N)|0)|0;i=N;U=av+(au*144|0)+69|0;ax=M;while(1){ay=c[ax>>2]|0;if((ay|0)==0){break}if((fa(W|0,c[ay+4>>2]|0)|0)==0){Q=4029;break}else{ax=ay+12|0}}L5652:do{if((Q|0)==4029){Q=0;ax=64;az=U;aA=c[ay+8>>2]|0;while(1){aB=ax-1|0;if((aB|0)==0){break}aC=a[aA]|0;a[az]=aC;if(aC<<24>>24==0){break L5652}else{ax=aB;az=az+1|0;aA=aA+1|0}}a[az]=0;if((a[aA]|0)==0){break}else{aD=aA}do{aD=aD+1|0;}while((a[aD]|0)!=0)}}while(0);U=av+(au*144|0)+44|0;g[U>>2]=0.0;aA=av+(au*144|0)+40|0;g[aA>>2]=0.0;az=av+(au*144|0)+52|0;g[az>>2]=1.0;ax=av+(au*144|0)+48|0;g[ax>>2]=1.0;be(_|0,64,588152,(N=i,i=i+8|0,c[N>>2]=au,N)|0)|0;i=N;aB=M;while(1){aE=c[aB>>2]|0;if((aE|0)==0){break}if((fa(_|0,c[aE+4>>2]|0)|0)==0){Q=4037;break}else{aB=aE+12|0}}do{if((Q|0)==4037){Q=0;aB=256;aC=0;aF=$;aG=c[aE+8>>2]|0;while(1){aH=aB-1|0;if((aH|0)==0){Q=4040;break}aI=a[aG]|0;a[aF]=aI;if(aI<<24>>24==0){aJ=aC;break}else{aB=aH;aC=aC+1|0;aF=aF+1|0;aG=aG+1|0}}do{if((Q|0)==4040){Q=0;a[aF]=0;if((a[aG]|0)==0){aJ=aC;break}else{aK=aG;aL=aC}while(1){aB=aK+1|0;aH=aL+1|0;if((a[aB]|0)==0){aJ=aH;break}else{aK=aB;aL=aH}}}}while(0);if(aJ>>>0>=256){break}aC=hA($,571928)|0;aG=aC+4|0;if((c[aG>>2]|0)>>>0<4){bU(ag|0,555056,(N=i,i=i+8|0,c[N>>2]=$,N)|0)|0;i=N;eY(ag|0)|0;aw=0;break L5647}aF=aC|0;g[aA>>2]=+gGx(c[c[aF>>2]>>2]|0,0);g[U>>2]=+gGx(c[(c[aF>>2]|0)+8>>2]|0,0);g[ax>>2]=+gGx(c[(c[aF>>2]|0)+16>>2]|0,0);g[az>>2]=+gGx(c[(c[aF>>2]|0)+24>>2]|0,0);if((aC|0)==0){break}aH=c[aF>>2]|0;if((c[aG>>2]|0)==0){aM=aH}else{aB=0;aI=aH;while(1){gGr(c[aI+(aB<<3)>>2]|0);aH=aB+1|0;aN=c[aF>>2]|0;if(aH>>>0<(c[aG>>2]|0)>>>0){aB=aH;aI=aN}else{aM=aN;break}}}gGr(aM);gGr(aC)}}while(0);be(aa|0,64,540336,(N=i,i=i+8|0,c[N>>2]=au,N)|0)|0;i=N;aI=av+(au*144|0)+68|0;a[aI]=0;h$(L,aa,aI)|0;be(ab|0,64,527192,(N=i,i=i+8|0,c[N>>2]=au,N)|0)|0;i=N;aI=M;while(1){aO=c[aI>>2]|0;if((aO|0)==0){break}if((fa(ab|0,c[aO+4>>2]|0)|0)==0){Q=4052;break}else{aI=aO+12|0}}do{if((Q|0)==4052){Q=0;c[O>>2]=0;aI=ch(c[aO+8>>2]|0,0,0)|0;if((c[O>>2]|0)!=0){break}do{if((aI|0)==0){aP=0}else{aB=aI*152|0;if(aI>>>0<=65535){aP=aB;break}aP=((aB>>>0)/(aI>>>0)|0|0)==152?aB:-1}}while(0);aC=gGq(aP)|0;if((aC|0)==0){c[av+(au*144|0)>>2]=0;cj(500232,58,1,ag|0)|0;eY(ag|0)|0;aw=0;break L5647}if((c[aC-4>>2]&3|0)!=0){gGz(aC|0,0,aP|0)}aB=av+(au*144|0)|0;c[aB>>2]=aC;aC=av+(au*144|0)+4|0;c[aC>>2]=aI;a[C]=0;be(ac|0,64,488760,(N=i,i=i+8|0,c[N>>2]=au,N)|0)|0;i=N;h$(L,ac,C)|0;be(ac|0,64,475592,(N=i,i=i+8|0,c[N>>2]=au,N)|0)|0;i=N;aG=M;while(1){aQ=c[aG>>2]|0;if((aQ|0)==0){aR=1.0;break}if((fa(ac|0,c[aQ+4>>2]|0)|0)==0){Q=4064;break}else{aG=aQ+12|0}}if((Q|0)==4064){Q=0;aR=+gGx(c[aQ+8>>2]|0,0)}be(ac|0,64,464416,(N=i,i=i+8|0,c[N>>2]=au,N)|0)|0;i=N;aG=M;while(1){aS=c[aG>>2]|0;if((aS|0)==0){aT=1.0;break}if((fa(ac|0,c[aS+4>>2]|0)|0)==0){Q=4068;break}else{aG=aS+12|0}}if((Q|0)==4068){Q=0;aT=+gGx(c[aS+8>>2]|0,0)}aG=av+(au*144|0)+12|0;aI=av+(au*144|0)+16|0;aF=0;while(1){aU=c[aC>>2]|0;if(aF>>>0>=aU>>>0){break}aN=c[aB>>2]|0;aH=c[aG>>2]|0;aV=c[aI>>2]|0;a[d]=a[C]&1;be(ah|0,64,430416,(N=i,i=i+16|0,c[N>>2]=au,c[N+8>>2]=aF,N)|0)|0;i=N;be(ai|0,64,419432,(N=i,i=i+16|0,c[N>>2]=au,c[N+8>>2]=aF,N)|0)|0;i=N;do{if(h_(L,ai,aj)|0){hM(ak,c[H>>2]|0,aj);gGz(al|0,0,12);if((a[9533596]&1)==0){if(!(jx(ak,k,16,0)|0)){break}}else{if(!(jx(ak,k,0,16)|0)){break}}c[aN+(aF*152|0)+128>>2]=c[ar>>2];c[aN+(aF*152|0)+132>>2]=c[as>>2];c[aN+(aF*152|0)+136>>2]=c[at>>2]}}while(0);be(am|0,64,407264,(N=i,i=i+16|0,c[N>>2]=au,c[N+8>>2]=aF,N)|0)|0;i=N;h$(L,am,d)|0;aW=(a[d]&1)==0;do{if(aW){if(!((aH|0)==0|(aV|0)==0)){aX=M;Q=4079;break}cj(397016,94,1,ag|0)|0;eY(ag|0)|0;aY=0}else{aX=M;Q=4079}}while(0);L5725:do{if((Q|0)==4079){while(1){Q=0;aZ=c[aX>>2]|0;if((aZ|0)==0){break}if((fa(ah|0,c[aZ+4>>2]|0)|0)==0){Q=4081;break}else{aX=aZ+12|0;Q=4079}}do{if((Q|0)==4081){Q=0;a_=256;a$=0;a0=an;a1=c[aZ+8>>2]|0;while(1){a2=a_-1|0;if((a2|0)==0){Q=4084;break}a3=a[a1]|0;a[a0]=a3;if(a3<<24>>24==0){a4=a$;break}else{a_=a2;a$=a$+1|0;a0=a0+1|0;a1=a1+1|0}}do{if((Q|0)==4084){Q=0;a[a0]=0;if((a[a1]|0)==0){a4=a$;break}else{a5=a1;a6=a$}while(1){a_=a5+1|0;a2=a6+1|0;if((a[a_]|0)==0){a4=a2;break}else{a5=a_;a6=a2}}}}while(0);if(a4>>>0>=256){break}a$=hA(an,571928)|0;if((a$|0)==0){cj(374744,62,1,ag|0)|0;eY(ag|0)|0;aY=0;break L5725}a1=a$+4|0;a0=c[a1>>2]|0;if(a0>>>0<6){a2=a$|0;a_=c[a2>>2]|0;if((a0|0)==0){a7=a_}else{a0=0;a3=a_;while(1){gGr(c[a3+(a0<<3)>>2]|0);a_=a0+1|0;a8=c[a2>>2]|0;if(a_>>>0<(c[a1>>2]|0)>>>0){a0=a_;a3=a8}else{a7=a8;break}}}gGr(a7);gGr(a$);cj(364784,85,1,ag|0)|0;eY(ag|0)|0;aY=0;break L5725}a3=a$|0;a0=c[a3>>2]|0;a2=c[a0+8>>2]|0;a8=c[a0+16>>2]|0;a_=c[a0+24>>2]|0;a9=c[a0>>2]|0;a0=aN+(aF*152|0)+48|0;c[a0>>2]=0;c[a0+4>>2]=0;L5750:do{if((fa(a9|0,357392)|0)==0){c[aN+(aF*152|0)+44>>2]=1}else{ba=aN+(aF*152|0)+44|0;if((fa(a9|0,349392)|0)==0){c[ba>>2]=2;break}c[ba>>2]=0;ba=de(a9|0,256984,n|0)|0;if((ba|0)!=0){bb=ba;do{if((fa(bb|0,333832)|0)!=0){ba=0;while(1){if(ba>>>0>=56){bc=0;bd=56;break}if((fa(c[512+(ba<<3)>>2]|0,bb|0)|0)==0){Q=4102;break}else{ba=ba+1|0}}if((Q|0)==4102){Q=0;bc=0;bd=c[516+(ba<<3)>>2]|0}bf=gGM(1,0,bd|0)|0;bg=c[a0+4>>2]|K;c[a0>>2]=c[a0>>2]|bf;c[a0+4>>2]=bg}bb=de(0,256984,n|0)|0;}while((bb|0)!=0)}if((c[a0>>2]&0|0)==0&(c[a0+4>>2]&524288|0)==0){break}be(ao|0,64,325344,(N=i,i=i+16|0,c[N>>2]=au,c[N+8>>2]=aF,N)|0)|0;i=N;bb=aN+(aF*152|0)+64|0;bg=M;while(1){bh=c[bg>>2]|0;if((bh|0)==0){break L5750}if((fa(ao|0,c[bh+4>>2]|0)|0)==0){break}else{bg=bh+12|0}}bg=64;bf=bb;bi=c[bh+8>>2]|0;while(1){bj=bg-1|0;if((bj|0)==0){break}bk=a[bi]|0;a[bf]=bk;if(bk<<24>>24==0){break L5750}else{bg=bj;bf=bf+1|0;bi=bi+1|0}}a[bf]=0;if((a[bi]|0)==0){break}else{bl=bi}do{bl=bl+1|0;}while((a[bl]|0)!=0)}}while(0);if(aW){bm=1.0/+(aV>>>0>>>0);bn=1.0/+(aH>>>0>>>0)}else{bm=1.0;bn=1.0}a0=aN+(aF*152|0)|0;g[a0>>2]=bn*+gGx(a2,0);a9=aN+(aF*152|0)+4|0;g[a9>>2]=bm*+gGx(a8,0);do{if((fa(a_|0,316456)|0)==0){c[aN+(aF*152|0)+8>>2]=0;bo=0;Q=4121}else{if((fa(a_|0,307832)|0)==0){c[aN+(aF*152|0)+8>>2]=1;bo=1;Q=4121;break}else{bU(ag|0,299576,(N=i,i=i+8|0,c[N>>2]=a_,N)|0)|0;i=N;eY(ag|0)|0;bp=0;break}}}while(0);L5789:do{if((Q|0)==4121){Q=0;do{if((c[aN+(aF*152|0)+44>>2]|0)!=0){if((bo|0)!=0){cj(291976,69,1,ag|0)|0;eY(ag|0)|0;bp=0;break L5789}be(ap|0,64,285696,(N=i,i=i+16|0,c[N>>2]=au,c[N+8>>2]=aF,N)|0)|0;i=N;a_=aN+(aF*152|0)+56|0;a8=M;while(1){bq=c[a8>>2]|0;if((bq|0)==0){Q=4128;break}if((fa(ap|0,c[bq+4>>2]|0)|0)==0){Q=4127;break}else{a8=bq+12|0}}if((Q|0)==4127){Q=0;g[a_>>2]=+gGx(c[bq+8>>2]|0,0);break}else if((Q|0)==4128){Q=0;g[a_>>2]=1.0;break}}}while(0);a8=aN+(aF*152|0)+12|0;g[a8>>2]=bn*+gGx(c[(c[a3>>2]|0)+32>>2]|0,0);br=bm*+gGx(c[(c[a3>>2]|0)+40>>2]|0,0);ba=aN+(aF*152|0)+16|0;g[ba>>2]=br;bs=+g[a8>>2];g[aN+(aF*152|0)+28>>2]=+g[a0>>2]-bs;g[aN+(aF*152|0)+36>>2]=bs*2.0;g[aN+(aF*152|0)+32>>2]=+g[a9>>2]-br;g[aN+(aF*152|0)+40>>2]=br*2.0;be(aq|0,64,278736,(N=i,i=i+16|0,c[N>>2]=au,c[N+8>>2]=aF,N)|0)|0;i=N;a2=aN+(aF*152|0)+144|0;g[a2>>2]=aR;bi=M;while(1){bt=c[bi>>2]|0;if((bt|0)==0){break}if((fa(aq|0,c[bt+4>>2]|0)|0)==0){Q=4132;break}else{bi=bt+12|0}}if((Q|0)==4132){Q=0;g[a2>>2]=+gGx(c[bt+8>>2]|0,0)}be(aq|0,64,271408,(N=i,i=i+16|0,c[N>>2]=au,c[N+8>>2]=aF,N)|0)|0;i=N;bi=aN+(aF*152|0)+148|0;g[bi>>2]=aT;bf=M;while(1){bu=c[bf>>2]|0;if((bu|0)==0){break}if((fa(aq|0,c[bu+4>>2]|0)|0)==0){Q=4136;break}else{bf=bu+12|0}}if((Q|0)==4136){Q=0;g[bi>>2]=+gGx(c[bu+8>>2]|0,0)}g[aN+(aF*152|0)+20>>2]=+g[a8>>2];g[aN+(aF*152|0)+24>>2]=+g[ba>>2];bp=1}}while(0);a9=c[a3>>2]|0;if((c[a1>>2]|0)==0){bv=a9}else{a0=0;bf=a9;while(1){gGr(c[bf+(a0<<3)>>2]|0);a9=a0+1|0;a2=c[a3>>2]|0;if(a9>>>0<(c[a1>>2]|0)>>>0){a0=a9;bf=a2}else{bv=a2;break}}}gGr(bv);gGr(a$);aY=bp;break L5725}}while(0);bU(ag|0,384616,(N=i,i=i+8|0,c[N>>2]=ah,N)|0)|0;i=N;eY(ag|0)|0;aY=0}}while(0);if(aY){aF=aF+1|0}else{Q=4142;break}}if((Q|0)==4142){Q=0;bU(ag|0,453136,(N=i,i=i+8|0,c[N>>2]=aF,N)|0)|0;i=N;eY(ag|0)|0;aw=0;break L5647}aI=aU+1|0;do{if((aI|0)==0){bw=0}else{aG=aI*152|0;if(aI>>>0<=65535){bw=aG;break}bw=((aG>>>0)/(aI>>>0)|0|0)==152?aG:-1}}while(0);aI=gGq(bw)|0;if((aI|0)==0){c[av+(au*144|0)+136>>2]=0;cj(442368,64,1,ag|0)|0;eY(ag|0)|0;aw=0;break L5647}if((c[aI-4>>2]&3|0)!=0){gGz(aI|0,0,bw|0)}aF=aI;aI=av+(au*144|0)+136|0;c[aI>>2]=aF;aG=av+(au*144|0)+8|0;if((c[aG>>2]|0)!=0){aN=av+(au*144|0)+140|0;aH=c[aN>>2]|0;c[aN>>2]=aH+1;aN=aF+(aH*12|0)|0;aH=aG;c[aN>>2]=c[aH>>2];c[aN+4>>2]=c[aH+4>>2];c[aN+8>>2]=c[aH+8>>2]}if((aU|0)!=0){aH=av+(au*144|0)+140|0;aN=0;aG=aU;while(1){aF=c[aB>>2]|0;if((c[aF+(aN*152|0)+128>>2]|0)==0){bx=aG}else{c[aF+(aN*152|0)+140>>2]=c[aH>>2];aF=c[aH>>2]|0;c[aH>>2]=aF+1;aV=(c[aI>>2]|0)+(aF*12|0)|0;aF=(c[aB>>2]|0)+(aN*152|0)+128|0;c[aV>>2]=c[aF>>2];c[aV+4>>2]=c[aF+4>>2];c[aV+8>>2]=c[aF+8>>2];bx=c[aC>>2]|0}aF=aN+1|0;if(aF>>>0<bx>>>0){aN=aF;aG=bx}else{break}}}a[av+(au*144|0)+20|0]=0;g[av+(au*144|0)+60>>2]=+g[aA>>2]+ +g[ax>>2]*.5;g[av+(au*144|0)+64>>2]=+g[U>>2]+ +g[az>>2]*.5;aw=1;break L5647}}while(0);bU(ag|0,513192,(N=i,i=i+8|0,c[N>>2]=ab,N)|0)|0;i=N;eY(ag|0)|0;aw=0}}while(0);if(!aw){Q=4161;break}az=au+1|0;by=c[V>>2]|0;if(az>>>0>=by>>>0){break}au=az;av=c[S>>2]|0}if((Q|0)==4161){bU(ag|0,263640,(N=i,i=i+8|0,c[N>>2]=au,N)|0)|0;i=N;eY(ag|0)|0;break}L5853:do{if((by|0)!=0){av=0;ab=by;L5854:while(1){ah=c[S>>2]|0;aq=ah+(av*144|0)+4|0;if((c[aq>>2]|0)==0){bz=ab;bA=av+1|0}else{ap=ah+(av*144|0)|0;ao=av+1|0;an=0;do{am=c[ap>>2]|0;bB=am+(an*152|0)+64|0;if((a[bB]|0)==0){c[am+(an*152|0)+60>>2]=(ao>>>0)%(ab>>>0)|0}else{at=0;while(1){if(at>>>0>=ab>>>0){break L5854}if((fa(ah+(at*144|0)+69|0,bB|0)|0)==0){break}else{at=at+1|0}}if((at|0)<0){break L5854}c[am+(an*152|0)+60>>2]=at}an=an+1|0;}while(an>>>0<(c[aq>>2]|0)>>>0);bz=c[V>>2]|0;bA=ao}if(bA>>>0<bz>>>0){av=bA;ab=bz}else{break L5853}}bU(ag|0,161208,(N=i,i=i+8|0,c[N>>2]=bB,N)|0)|0;i=N;eY(ag|0)|0;cj(205584,64,1,ag|0)|0;eY(ag|0)|0;break L5624}}while(0);hY(L);ag=D+16|0;c[ag>>2]=c[S>>2];i4(F);gg[c[c[J>>2]>>2]&4095](c[G>>2]|0,1);a[D+8|0]=1;if((c[(c[ag>>2]|0)+140>>2]|0)!=0){au=0;do{gK[c[(c[J>>2]|0)+20>>2]&7](c[G>>2]|0,au,+g[2332238]);au=au+1|0;}while(au>>>0<(c[(c[ag>>2]|0)+140>>2]|0)>>>0)}i2(F,+g[2332239]);c[D+28>>2]=(((c[D+20>>2]|0)+1|0)>>>0)%((c[V>>2]|0)>>>0)|0;I=F;i=b;return I|0}}while(0);if((Q|0)==4010){G=c[u>>2]|0;cj(341168,62,1,G|0)|0;eY(G|0)|0}hY(L);E=F}}while(0);i5(E);I=0;i=b;return I|0}function i4(b){b=b|0;var d=0,e=0,f=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=b+4|0;e=b|0;f=b+16|0;b=c[f>>2]|0;gp[c[(c[d>>2]|0)+4>>2]&16383](c[e>>2]|0,c[b+136>>2]|0,c[b+140>>2]|0)|0;b=c[f>>2]|0;if((c[b+140>>2]|0)==0){h=b}else{b=0;while(1){gK[c[(c[d>>2]|0)+20>>2]&7](c[e>>2]|0,b,+g[2332238]);i=b+1|0;j=c[f>>2]|0;if(i>>>0<(c[j+140>>2]|0)>>>0){b=i}else{h=j;break}}}if((c[h+8>>2]|0)==0){k=h}else{gH[c[(c[d>>2]|0)+12>>2]&7](c[e>>2]|0,0,+g[h+24>>2],+g[h+28>>2],+g[h+32>>2],+g[h+36>>2]);k=c[f>>2]|0}if((c[k+4>>2]|0)==0){l=k;m=c[d>>2]|0;n=m+16|0;o=c[n>>2]|0;p=c[e>>2]|0;q=l+68|0;r=a[q]|0;s=r&1;t=s<<24>>24!=0;gg[o&4095](p,t);return}else{u=0;v=k}while(1){k=c[v>>2]|0;if((c[k+(u*152|0)+128>>2]|0)==0){w=v}else{gH[c[(c[d>>2]|0)+12>>2]&7](c[e>>2]|0,c[k+(u*152|0)+140>>2]|0,+g[k+(u*152|0)+28>>2],+g[k+(u*152|0)+32>>2],+g[k+(u*152|0)+36>>2],+g[k+(u*152|0)+40>>2]);w=c[f>>2]|0}k=u+1|0;if(k>>>0<(c[w+4>>2]|0)>>>0){u=k;v=w}else{l=w;break}}m=c[d>>2]|0;n=m+16|0;o=c[n>>2]|0;p=c[e>>2]|0;q=l+68|0;r=a[q]|0;s=r&1;t=s<<24>>24!=0;gg[o&4095](p,t);return}function i5(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;if((a|0)==0){return}b=a+24|0;d=a+12|0;e=c[d>>2]|0;if((c[b>>2]|0)==0){f=e}else{g=0;h=e;while(1){e=h+(g*144|0)+4|0;i=h+(g*144|0)|0;if((c[e>>2]|0)!=0){j=0;do{gGr(c[(c[i>>2]|0)+(j*152|0)+128>>2]|0);j=j+1|0;}while(j>>>0<(c[e>>2]|0)>>>0)}gGr(c[h+(g*144|0)+136>>2]|0);gGr(c[i>>2]|0);gGr(c[h+(g*144|0)+8>>2]|0);e=g+1|0;j=c[d>>2]|0;if(e>>>0<(c[b>>2]|0)>>>0){g=e;h=j}else{f=j;break}}}gGr(f);f=c[a+4>>2]|0;if((f|0)!=0){gg[c[f>>2]&4095](c[a>>2]|0,0)}gGr(c[a+32>>2]|0);gGr(a);return}function i6(d){d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,W=0,X=0.0,Y=0.0,_=0.0,$=0,aa=0,ab=0,ac=0,ad=0.0,ae=0.0,af=0.0,ah=0.0,ai=0.0,aj=0.0,ak=0,al=0,am=0.0,an=0.0,ao=0,ap=0,aq=0;e=i;f=d+64|0;gGr(c[f>>2]|0);g=d+76|0;gGr(c[g>>2]|0);h=d+80|0;gGr(c[h>>2]|0);j=d+92|0;gGr(c[j>>2]|0);k=d+104|0;gGr(c[k>>2]|0);l=d+96|0;gGr(c[l>>2]|0);m=d+120|0;gGr(c[m>>2]|0);gGz(f|0,0,64);n=d|0;o=c[n>>2]|0;p=d+12|0;q=c[p>>2]|0;r=d+4|0;s=c[r>>2]|0;do{if((o|0)==(q|0)){if((s|0)!=(c[d+16>>2]|0)){t=4209;break}a[d+60|0]=1;v=1}else{t=4209}}while(0);if((t|0)==4209){c[d+36>>2]=14;c[d+40>>2]=10;a[d+60|0]=0;v=0}w=d+44|0;c[w>>2]=0;x=(q<<3)+56&-64;c[d+116>>2]=x;c[d+108>>2]=q;c[d+112>>2]=s;y=ag(x,s)|0;x=y>>3;if(x>>>0>65535){z=(y>>>3|0)==(x|0)?y:-1}else{z=y}y=gGq(z)|0;if((y|0)==0){c[k>>2]=0;A=0;i=e;return A|0}if((c[y-4>>2]&3|0)!=0){gGz(y|0,0,z|0)}c[k>>2]=y;y=c[d+24>>2]|0;if((y|0)!=0){k=(o<<2)+28&-32;c[d+100>>2]=k;o=ag(k,s)|0;s=o>>2;if(s>>>0>65535){B=(o>>>2|0)==(s|0)?o:-1}else{B=o}o=gGq(B)|0;if((o|0)==0){c[l>>2]=0;A=0;i=e;return A|0}if((c[o-4>>2]&3|0)!=0){gGz(o|0,0,B|0)}c[l>>2]=o}o=c[d+28>>2]|0;l=(o|0)==0;if(!l){B=(q<<2)+28&-32;c[d+124>>2]=B;q=ag(c[d+16>>2]|0,B)|0;B=q>>2;if(B>>>0>65535){C=(q>>>2|0)==(B|0)?q:-1}else{C=q}q=gGq(C)|0;if((q|0)==0){c[m>>2]=0;A=0;i=e;return A|0}if((c[q-4>>2]&3|0)!=0){gGz(q|0,0,C|0)}c[m>>2]=q}q=v<<24>>24==0;L5958:do{if(q){if((y|0)==4){c[d+48>>2]=46}else if((y|0)==2){c[d+48>>2]=28}else if((y|0)==3){c[d+48>>2]=22}else if((y|0)!=0){A=0;i=e;return A|0}if((o|0)==0){break}else if((o|0)==2){c[d+52>>2]=82;break}else if((o|0)==4){c[d+52>>2]=76;break}else{A=0;i=e;return A|0}}else{if((y|0)==(o|0)){c[d+56>>2]=48;A=1;i=e;return A|0}v=(y|0)==2;if(v&l){c[d+56>>2]=28;A=1;i=e;return A|0}if(!((y|0)!=3|l^1)){c[d+56>>2]=22;break}m=(y|0)==3;C=(o|0)==4;if(m&C){c[d+56>>2]=60;break}if(v&(o|0)==3){c[d+56>>2]=34;break}do{if(m){if((o|0)!=2){D=0;break}c[d+56>>2]=66;break L5958}else{if((y|0)==4){if(!l){D=0;break}c[d+56>>2]=46;break L5958}else if((y|0)!=0){D=0;break}if((o|0)==2){c[d+56>>2]=82;break L5958}else if((o|0)==4){c[d+56>>2]=76;break L5958}else{D=1;break}}}while(0);if(v&C){c[d+56>>2]=20;break}if(D&(o|0)==1){c[d+56>>2]=50;break}else{A=0;i=e;return A|0}}}while(0);if(!q){A=1;i=e;return A|0}q=c[d+32>>2]|0;L6010:do{if((q|0)==1){c[d+68>>2]=1;c[d+72>>2]=1;c[d+84>>2]=1;o=d+88|0;c[o>>2]=1;D=c[p>>2]|0;y=D<<1;if(D>>>0>65535){E=(D&2147483647|0)==(D|0)?y:-1}else{E=y}y=gGq(E)|0;do{if((y|0)!=0){if((c[y-4>>2]&3|0)==0){break}gGz(y|0,0,E|0)}}while(0);C=d+64|0;c[C>>2]=y;v=c[p>>2]|0;D=v<<2;if(v>>>0>65535){F=(v&1073741823|0)==(v|0)?D:-1}else{F=D}D=gGq(F)|0;do{if((D|0)!=0){if((c[D-4>>2]&3|0)==0){break}gGz(D|0,0,F|0)}}while(0);c[g>>2]=D;y=d+16|0;v=ag(c[y>>2]|0,c[o>>2]|0)|0;l=v<<1;if(v>>>0>65535){G=(v&2147483647|0)==(v|0)?l:-1}else{G=l}l=gGq(G)|0;do{if((l|0)!=0){if((c[l-4>>2]&3|0)==0){break}gGz(l|0,0,G|0)}}while(0);c[h>>2]=l;o=c[y>>2]|0;D=o<<2;if(o>>>0>65535){H=(o&1073741823|0)==(o|0)?D:-1}else{H=D}D=gGq(H)|0;do{if((D|0)!=0){if((c[D-4>>2]&3|0)==0){break}gGz(D|0,0,H|0)}}while(0);c[j>>2]=D;if((c[C>>2]|0)==0){A=0;i=e;return A|0}if((c[h>>2]|0)==0){A=0;i=e;return A|0}l=c[n>>2]|0;o=c[p>>2]|0;v=(l<<16|0)/(o|0)|0;m=c[r>>2]|0;B=c[y>>2]|0;s=((m<<15|0)/(B|0)|0)-32768|0;k=(m<<16|0)/(B|0)|0;if((o|0)>0){m=((l<<15|0)/(o|0)|0)-32768|0;l=0;while(1){c[(c[g>>2]|0)+(l<<2)>>2]=m>>16;b[(c[C>>2]|0)+(l<<1)>>1]=16384;z=l+1|0;if((z|0)<(o|0)){m=m+v|0;l=z}else{break}}I=c[y>>2]|0}else{I=B}L6052:do{if((I|0)>0){l=s;v=0;while(1){c[(c[j>>2]|0)+(v<<2)>>2]=l>>16;b[(c[h>>2]|0)+(v<<1)>>1]=16384;m=v+1|0;if((m|0)>=(I|0)){break L6052}l=l+k|0;v=m}}}while(0);c[w>>2]=10}else if((q|0)==2){c[d+68>>2]=2;c[d+72>>2]=2;c[d+84>>2]=2;k=d+88|0;c[k>>2]=2;s=c[p>>2]|0;B=s<<1;y=s<<2;if(B>>>0>65535){J=(B&2147483646|0)==(B|0)?y:-1}else{J=y}y=gGq(J)|0;do{if((y|0)!=0){if((c[y-4>>2]&3|0)==0){break}gGz(y|0,0,J|0)}}while(0);B=d+64|0;c[B>>2]=y;s=c[p>>2]|0;v=s<<2;if(s>>>0>65535){K=(s&1073741823|0)==(s|0)?v:-1}else{K=v}v=gGq(K)|0;do{if((v|0)!=0){if((c[v-4>>2]&3|0)==0){break}gGz(v|0,0,K|0)}}while(0);c[g>>2]=v;y=d+16|0;s=ag(c[y>>2]|0,c[k>>2]|0)|0;l=s<<1;if(s>>>0>65535){L=(s&2147483647|0)==(s|0)?l:-1}else{L=l}l=gGq(L)|0;do{if((l|0)!=0){if((c[l-4>>2]&3|0)==0){break}gGz(l|0,0,L|0)}}while(0);c[h>>2]=l;k=c[y>>2]|0;v=k<<2;if(k>>>0>65535){M=(k&1073741823|0)==(k|0)?v:-1}else{M=v}v=gGq(M)|0;do{if((v|0)!=0){if((c[v-4>>2]&3|0)==0){break}gGz(v|0,0,M|0)}}while(0);c[j>>2]=v;if((c[B>>2]|0)==0){A=0;i=e;return A|0}if((c[h>>2]|0)==0){A=0;i=e;return A|0}l=c[n>>2]|0;k=c[p>>2]|0;s=(l<<16|0)/(k|0)|0;m=c[r>>2]|0;o=c[y>>2]|0;C=((m<<15|0)/(o|0)|0)-32768|0;D=(m<<16|0)/(o|0)|0;if((k|0)>0){m=((l<<15|0)/(k|0)|0)-32768|0;l=0;while(1){c[(c[g>>2]|0)+(l<<2)>>2]=m>>16;z=l<<1;x=z|1;b[(c[B>>2]|0)+(x<<1)>>1]=m>>>2&16383;N=c[B>>2]|0;b[N+(z<<1)>>1]=16384-(b[N+(x<<1)>>1]|0)&65535;x=l+1|0;if((x|0)<(k|0)){m=m+s|0;l=x}else{break}}O=c[y>>2]|0}else{O=o}if((O|0)>0){P=C;Q=0}else{break}while(1){c[(c[j>>2]|0)+(Q<<2)>>2]=P>>16;l=Q<<1;s=l|1;b[(c[h>>2]|0)+(s<<1)>>1]=P>>>2&16383;m=c[h>>2]|0;b[m+(l<<1)>>1]=16384-(b[m+(s<<1)>>1]|0)&65535;s=Q+1|0;if((s|0)>=(O|0)){break L6010}P=P+D|0;Q=s}}else if((q|0)==3){D=c[n>>2]|0;C=c[p>>2]|0;if((D|0)>(C|0)){o=((D|0)/(C|0)|0)-1|0;D=o>>>1|o;o=D>>>2|D;D=o>>>4|o;o=D>>>8|D;R=((o>>>16|o)<<3)+8|0}else{R=8}o=d+68|0;c[o>>2]=R;c[d+72>>2]=R;D=d+84|0;c[D>>2]=R;y=d+88|0;c[y>>2]=R;s=ag(R,C)|0;C=s<<1;if(s>>>0>65535){S=(s&2147483647|0)==(s|0)?C:-1}else{S=C}C=gGq(S)|0;do{if((C|0)!=0){if((c[C-4>>2]&3|0)==0){break}gGz(C|0,0,S|0)}}while(0);s=d+64|0;c[s>>2]=C;m=c[p>>2]|0;l=m<<2;if(m>>>0>65535){T=(m&1073741823|0)==(m|0)?l:-1}else{T=l}l=gGq(T)|0;do{if((l|0)!=0){if((c[l-4>>2]&3|0)==0){break}gGz(l|0,0,T|0)}}while(0);c[g>>2]=l;C=d+16|0;m=ag(c[C>>2]|0,c[y>>2]|0)|0;k=m<<1;if(m>>>0>65535){U=(m&2147483647|0)==(m|0)?k:-1}else{U=k}k=gGq(U)|0;do{if((k|0)!=0){if((c[k-4>>2]&3|0)==0){break}gGz(k|0,0,U|0)}}while(0);c[h>>2]=k;y=c[C>>2]|0;l=y<<2;if(y>>>0>65535){W=(y&1073741823|0)==(y|0)?l:-1}else{W=l}l=gGq(W)|0;do{if((l|0)!=0){if((c[l-4>>2]&3|0)==0){break}gGz(l|0,0,W|0)}}while(0);c[j>>2]=l;if((c[s>>2]|0)==0){A=0;i=e;return A|0}if((c[h>>2]|0)==0){A=0;i=e;return A|0}k=c[n>>2]|0;y=c[p>>2]|0;m=-32768-(R<<15)|0;B=((k<<15|0)/(y|0)|0)+m|0;v=(k<<16|0)/(y|0)|0;x=c[r>>2]|0;N=c[C>>2]|0;z=((x<<15|0)/(N|0)|0)+m|0;m=(x<<16|0)/(N|0)|0;if((k|0)>(y|0)){X=+(y|0)/+(k|0)}else{X=1.0}if((x|0)>(N|0)){Y=+(N|0)/+(x|0)}else{Y=1.0}x=c[o>>2]|0;L6146:do{if((y|0)>0){N=x<<15;_=+(x>>1|0);if((x|0)>0){$=0;aa=B}else{k=0;ab=B;while(1){c[(c[g>>2]|0)+(k<<2)>>2]=ab>>16;ac=k+1|0;if((ac|0)<(y|0)){k=ac;ab=ab+v|0}else{break L6146}}}while(1){c[(c[g>>2]|0)+($<<2)>>2]=aa>>16;ad=+((aa&65535)+N|0)*152587890625.0e-16;ab=ag($,x)|0;k=0;do{ae=(ad- +(k|0))*3.141592653589793;af=ae/_;ah=X*ae;if(+V(+ah)<1.0e-4){ai=16384.0}else{ai=+Z(+ah)/ah*16384.0}if(+V(+af)<1.0e-4){aj=1.0}else{aj=+Z(+af)/af}b[(c[s>>2]|0)+(k+ab<<1)>>1]=~~(X*ai*aj);k=k+1|0;}while((k|0)<(x|0));k=$+1|0;if((k|0)<(y|0)){$=k;aa=aa+v|0}else{break}}}}while(0);v=c[C>>2]|0;y=c[D>>2]|0;if((v|0)<=0){break}x=y<<15;_=+(y>>1|0);if((y|0)>0){ak=0;al=z}else{s=0;B=z;while(1){c[(c[j>>2]|0)+(s<<2)>>2]=B>>16;o=s+1|0;if((o|0)>=(v|0)){break L6010}s=o;B=B+m|0}}while(1){c[(c[j>>2]|0)+(ak<<2)>>2]=al>>16;ad=+((al&65535)+x|0)*152587890625.0e-16;B=ag(ak,y)|0;s=0;do{af=(ad- +(s|0))*3.141592653589793;ah=af/_;ae=Y*af;if(+V(+ae)<1.0e-4){am=16384.0}else{am=+Z(+ae)/ae*16384.0}if(+V(+ah)<1.0e-4){an=1.0}else{an=+Z(+ah)/ah}b[(c[h>>2]|0)+(s+B<<1)>>1]=~~(Y*am*an);s=s+1|0;}while((s|0)<(y|0));s=ak+1|0;if((s|0)>=(v|0)){break L6010}ak=s;al=al+m|0}}else{A=0;i=e;return A|0}}while(0);jm(f,c[p>>2]|0,c[n>>2]|0);f=d+16|0;jm(d+80|0,c[f>>2]|0,c[r>>2]|0);al=(c[n>>2]|0)-(c[d+68>>2]|0)|0;n=c[p>>2]|0;p=0;while(1){if((p|0)>=(n|0)){break}ao=c[(c[g>>2]|0)+(p<<2)>>2]|0;if((ao|0)>(al|0)|(ao|0)<0){t=4377;break}else{p=p+1|0}}if((t|0)==4377){al=c[u>>2]|0;bU(al|0,537752,(ap=i,i=i+16|0,c[ap>>2]=p,c[ap+8>>2]=ao,ap)|0)|0;i=ap;A=0;i=e;return A|0}ao=(c[r>>2]|0)-(c[d+84>>2]|0)|0;d=c[f>>2]|0;f=0;while(1){if((f|0)>=(d|0)){A=1;t=4394;break}aq=c[(c[j>>2]|0)+(f<<2)>>2]|0;if((aq|0)>(ao|0)|(aq|0)<0){break}else{f=f+1|0}}if((t|0)==4394){i=e;return A|0}bU(c[u>>2]|0,567400,(ap=i,i=i+16|0,c[ap>>2]=f,c[ap+8>>2]=aq,ap)|0)|0;i=ap;A=0;i=e;return A|0}function i7(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((a[b+60|0]&1)!=0){gB[c[b+56>>2]&127](d,e,c[b+12>>2]|0,c[b+16>>2]|0,c[b+20>>2]|0,c[b+8>>2]|0);return}f=b+44|0;if((c[f>>2]|0)==0){if((c[b+24>>2]|0)==0){gG[c[b+36>>2]&255](b,e,c[b+8>>2]|0)}else{g=b+96|0;h=b+100|0;gB[c[b+48>>2]&127](c[g>>2]|0,e,c[b>>2]|0,c[b+4>>2]|0,c[h>>2]|0,c[b+8>>2]|0);gG[c[b+36>>2]&255](b,c[g>>2]|0,c[h>>2]|0)}h=c[b+40>>2]|0;if((c[b+28>>2]|0)==0){gG[h&255](b,d,c[b+20>>2]|0);return}else{g=b+120|0;i=b+124|0;gG[h&255](b,c[g>>2]|0,c[i>>2]|0);gB[c[b+52>>2]&127](d,c[g>>2]|0,c[b+12>>2]|0,c[b+16>>2]|0,c[b+20>>2]|0,c[i>>2]|0);return}}else{i=c[b+8>>2]|0;if((c[b+24>>2]|0)==0){j=e;k=i}else{g=b+96|0;h=b+100|0;gB[c[b+48>>2]&127](c[g>>2]|0,e,c[b>>2]|0,c[b+4>>2]|0,c[h>>2]|0,i);j=c[g>>2]|0;k=c[h>>2]|0}h=(c[b+28>>2]|0)!=0;g=b+20|0;if(h){l=b+124|0;m=c[b+120>>2]|0}else{l=g;m=d}i=b+12|0;e=b+16|0;gy[c[f>>2]&15](b,m,j,c[i>>2]|0,c[e>>2]|0,c[b>>2]|0,c[b+4>>2]|0,c[l>>2]|0,k);if(!h){return}gB[c[b+52>>2]&127](d,c[b+120>>2]|0,c[i>>2]|0,c[e>>2]|0,c[g>>2]|0,c[b+124>>2]|0);return}}function i8(a,c,d,e,f,g){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0;if((e|0)<=0){return}h=f>>1;f=g>>1;if((d|0)<=0){return}g=a;a=c;c=0;while(1){i=0;do{j=b[a+(i<<1)>>1]|0;b[g+(i<<1)>>1]=(j&65535)>>>1&32736|j&31;i=i+1|0;}while((i|0)<(d|0));i=c+1|0;if((i|0)<(e|0)){g=g+(h<<1)|0;a=a+(f<<1)|0;c=i}else{break}}return}function i9(a,c,d,e,f,g){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0;if((e|0)<=0){return}h=f>>1;f=g>>1;if((d|0)<=0){return}g=a;a=c;c=0;while(1){i=0;do{j=b[a+(i<<1)>>1]|0;b[g+(i<<1)>>1]=j<<1&-64|j&31|(j&65535)>>>4&32;i=i+1|0;}while((i|0)<(d|0));i=c+1|0;if((i|0)<(e|0)){g=g+(h<<1)|0;a=a+(f<<1)|0;c=i}else{break}}return}function ja(a,b,d,f,g,h){a=a|0;b=b|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0;if((f|0)<=0){return}i=g>>2;g=h>>1;if((d|0)<=0){return}h=a;a=b;b=0;while(1){j=0;do{k=e[a+(j<<1)>>1]|0;l=k>>>10&31;m=k>>>5&31;n=k&31;c[h+(j<<2)>>2]=n<<3|n>>>2|(m<<3|m>>>2)<<8|(l<<3|l>>>2)<<16|-16777216;j=j+1|0;}while((j|0)<(d|0));j=b+1|0;if((j|0)<(f|0)){h=h+(i<<2)|0;a=a+(g<<1)|0;b=j}else{break}}return}function jb(a,b,d,f,g,h){a=a|0;b=b|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;if((f|0)<=0){return}i=g>>2;g=h>>1;if((d|0)<=0){return}h=a;a=b;b=0;while(1){j=0;do{k=e[a+(j<<1)>>1]|0;l=k>>>5&63;m=k&31;c[h+(j<<2)>>2]=m<<3|m>>>2|(k>>>11<<3|k>>>13)<<16|(l<<2|l>>>4)<<8|-16777216;j=j+1|0;}while((j|0)<(d|0));j=b+1|0;if((j|0)<(f|0)){h=h+(i<<2)|0;a=a+(g<<1)|0;b=j}else{break}}return}function jc(b,c,d,f,g,h){b=b|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;if((f|0)<=0){return}i=(d|0)>0;j=h>>1;h=b;b=c;c=0;while(1){if(i){k=h;l=0;while(1){m=e[b+(l<<1)>>1]|0;a[k]=(m>>>2&7|m<<3)&255;a[k+1|0]=(m>>>5<<3|m>>>7&7)&255;a[k+2|0]=(m>>>10<<3|m>>>12&7)&255;m=l+1|0;if((m|0)<(d|0)){k=k+3|0;l=m}else{break}}}l=c+1|0;if((l|0)<(f|0)){h=h+g|0;b=b+(j<<1)|0;c=l}else{break}}return}function jd(b,c,d,f,g,h){b=b|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;if((f|0)<=0){return}i=(d|0)>0;j=h>>1;h=b;b=c;c=0;while(1){if(i){k=h;l=0;while(1){m=e[b+(l<<1)>>1]|0;a[k]=(m>>>2&7|m<<3)&255;a[k+1|0]=(m>>>5<<2|m>>>9&3)&255;a[k+2|0]=(m>>>11<<3|m>>>13)&255;m=l+1|0;if((m|0)<(d|0)){k=k+3|0;l=m}else{break}}}l=c+1|0;if((l|0)<(f|0)){h=h+g|0;b=b+(j<<1)|0;c=l}else{break}}return}function je(a,b,e,f,g,h){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;if((f|0)<=0){return}i=(e|0)>0;j=g>>2;g=a;a=b;b=0;while(1){if(i){k=a;l=0;while(1){c[g+(l<<2)>>2]=d[k]|0|(d[k+1|0]|0)<<8|(d[k+2|0]|0)<<16|-16777216;m=l+1|0;if((m|0)<(e|0)){k=k+3|0;l=m}else{break}}}l=b+1|0;if((l|0)<(f|0)){g=g+(j<<2)|0;a=a+h|0;b=l}else{break}}return}function jf(a,d,e,f,g,h){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;if((f|0)<=0){return}i=(e|0)>0;j=g>>1;g=h>>2;h=a;a=d;d=0;while(1){if(i){k=0;do{l=c[a+(k<<2)>>2]|0;b[h+(k<<1)>>1]=(l>>>11<<5&992|l>>>3&31|l>>>19<<10&31744)&65535;k=k+1|0;}while((k|0)<(e|0))}k=d+1|0;if((k|0)<(f|0)){h=h+(j<<1)|0;a=a+(g<<2)|0;d=k}else{break}}return}function jg(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;if((f|0)<=0){return}i=(e|0)>0;j=h>>2;h=d;d=b;b=0;while(1){if(i){k=0;l=d;while(1){m=c[h+(k<<2)>>2]|0;a[l]=m&255;a[l+1|0]=m>>>8&255;a[l+2|0]=m>>>16&255;m=k+1|0;if((m|0)<(e|0)){k=m;l=l+3|0}else{break}}}l=b+1|0;if((l|0)<(f|0)){h=h+(j<<2)|0;d=d+g|0;b=l}else{break}}return}function jh(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;if((e|0)<=0){return}h=(d|0)>0;i=f>>2;f=g>>2;g=b;b=a;a=0;while(1){if(h){j=0;do{k=c[g+(j<<2)>>2]|0;c[b+(j<<2)>>2]=k>>>16&255|k&-16711936|k<<16&16711680;j=j+1|0;}while((j|0)<(d|0))}j=a+1|0;if((j|0)<(e|0)){g=g+(f<<2)|0;b=b+(i<<2)|0;a=j}else{break}}return}function ji(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;c=(e|0)>-1?e:-e|0;g=(f|0)>-1?f:-f|0;h=(g|0)<(c|0)?g:c;if((d|0)>0){i=0;j=b;k=a}else{return}while(1){gGC(k|0,j|0,h)|0;a=i+1|0;if((a|0)<(d|0)){i=a;j=j+f|0;k=k+e|0}else{break}}return}function jj(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;f=c[a+104>>2]|0;g=a+16|0;h=c[g>>2]|0;if((h|0)<=0){return}i=a+92|0;j=a+116|0;k=a+12|0;l=a+88|0;m=e>>2;e=a+84|0;n=c[a+80>>2]|0;a=d;d=0;o=c[k>>2]|0;p=h;while(1){h=ag(c[j>>2]>>3,c[(c[i>>2]|0)+(d<<2)>>2]|0)|0;if((o|0)>0){q=0;do{r=c[e>>2]|0;if((r|0)==0){s=0;t=0;u=0;v=0}else{w=c[j>>2]>>3;x=0;y=0;z=0;A=f+(q+h<<3)|0;B=0;C=0;while(1){D=c[A>>2]|0;E=c[A+4>>2]|0;F=b[n+(C<<1)>>1]|0;G=ag(((E>>>16|0<<16)&65535)<<16>>16,F)|0;H=ag((E&65535)<<16>>16,F)|0;I=ag(((D>>>16|E<<16)&65535)<<16>>16,F)|0;E=C+1|0;J=G+(B<<16)>>16;K=H+(x<<16)>>16;L=I+(y<<16)>>16;M=(ag((D&65535)<<16>>16,F)|0)+(z<<16)>>16;if(E>>>0<r>>>0){x=K;y=L;z=M;A=A+(w<<3)|0;B=J;C=E}else{break}}s=K>>>3;t=L>>>3;u=M>>>3;v=J>>>3}C=v&65535;B=s&65535;w=t&65535;A=u&65535;if(C<<16>>16>255){N=-16777216}else{N=C<<16>>16<0?0:v<<24}if(B<<16>>16>255){O=16711680}else{O=B<<16>>16<0?0:s<<16&16711680}if(w<<16>>16>255){P=65280}else{P=w<<16>>16<0?0:t<<8&65280}if(A<<16>>16>255){Q=255}else{Q=A<<16>>16<0?0:u&255}c[a+(q<<2)>>2]=O|N|P|Q;q=q+1|0;R=c[k>>2]|0;}while((q|0)<(R|0));S=R;T=c[g>>2]|0}else{S=o;T=p}q=d+1|0;if((q|0)>=(T|0)){break}n=n+(c[l>>2]<<1)|0;a=a+(m<<2)|0;d=q;o=S;p=T}return}function jk(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;f=a+112|0;g=c[f>>2]|0;if((g|0)<=0){return}h=a+64|0;i=a+108|0;j=e>>2;e=a+116|0;k=a+76|0;l=a+68|0;m=a+72|0;n=c[a+104>>2]|0;a=d;d=0;o=c[i>>2]|0;p=g;while(1){if((o|0)>0){g=c[h>>2]|0;q=0;while(1){r=c[(c[k>>2]|0)+(q<<2)>>2]|0;s=c[l>>2]|0;if((s|0)==0){t=0;u=0;v=0;w=0;x=0;y=0;z=0;A=0}else{B=0;C=0;D=0;E=0;F=0;while(1){G=c[a+(F+r<<2)>>2]|0;H=b[g+(F<<1)>>1]|0;I=((ag(G>>>17&32640,H)|0)>>>16)+(B&65535)|0;J=((ag(G>>>9&32640,H)|0)>>>16)+(C&65535)|0;K=((ag(G>>>1&32640,H)|0)>>>16)+(D&65535)|0;L=((ag(G<<7&32640,H)|0)>>>16)+(E&65535)|0;H=F+1|0;if(H>>>0<s>>>0){B=I&65535;C=J&65535;D=K&65535;E=L&65535;F=H}else{break}}F=K&65535;t=I<<16|0>>>16;u=0<<16|0>>>16;v=J&65535;w=0;x=0<<16|F>>>16;y=F<<16|0>>>16;z=0;A=L&65535}F=n+(q<<3)|0;c[F>>2]=y|A|w|u;c[F+4>>2]=x|z|v|t;F=q+1|0;M=c[i>>2]|0;if((F|0)<(M|0)){g=g+(c[m>>2]<<1)|0;q=F}else{break}}N=M;O=c[f>>2]|0}else{N=o;O=p}q=d+1|0;if((q|0)<(O|0)){n=n+(c[e>>2]>>3<<3)|0;a=a+(j<<2)|0;d=q;o=N;p=O}else{break}}return}function jl(a,b,d,e,f,g,h,i,j){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0;a=((g<<15|0)/(e|0)|0)-32768|0;k=(g<<16|0)/(e|0)|0;g=((h<<15|0)/(f|0)|0)-32768|0;l=(h<<16|0)/(f|0)|0;h=(a|0)<0?0:a;a=d;if((f|0)<=0){return}d=j>>2;j=i>>2;if((e|0)<=0){return}i=(g|0)<0?0:g;g=b;b=0;while(1){m=ag(i>>16,d)|0;n=0;o=h;while(1){c[g+(n<<2)>>2]=c[a+((o>>16)+m<<2)>>2];p=n+1|0;if((p|0)<(e|0)){n=p;o=o+k|0}else{break}}o=b+1|0;if((o|0)<(f|0)){i=i+l|0;g=g+(j<<2)|0;b=o}else{break}}return}function jm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=a+4|0;f=d-(c[e>>2]|0)|0;if((b|0)<=0){return}d=a+12|0;g=a|0;h=a+8|0;a=0;do{i=(c[d>>2]|0)+(a<<2)|0;j=c[i>>2]|0;k=j-f|0;l=-j|0;do{if((k|0)>0){c[i>>2]=f;m=c[g>>2]|0;n=ag(c[h>>2]|0,a)|0;o=m+(n<<1)|0;p=c[e>>2]|0;if((k|0)>(p|0)){gGz(o|0,0,p<<1|0);break}else{q=o;gGG(m+(n+k<<1)|0,q|0,p-k<<1|0);gGz(q|0,0,k<<1|0);break}}}while(0);do{if((j|0)<0){k=(c[d>>2]|0)+(a<<2)|0;c[k>>2]=(c[k>>2]|0)-j;k=c[g>>2]|0;i=ag(c[h>>2]|0,a)|0;q=c[e>>2]|0;p=k+(i<<1)|0;if((q|0)<(l|0)){gGz(p|0,0,q<<1|0);break}else{gGG(p|0,k+(i-j<<1)|0,q+j<<1|0);gGz(k+(i+j+(c[e>>2]|0)<<1)|0,0,l<<1|0);break}}}while(0);a=a+1|0;}while((a|0)<(b|0));return}function jn(d,e){d=d|0;e=e|0;var f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0;f=i;i=i+1824|0;h=f|0;j=f+8|0;k=f+16|0;l=f+1040|0;m=f+1048|0;n=f+1112|0;o=f+1176|0;p=f+1184|0;q=f+1248|0;r=f+1312|0;s=f+1376|0;t=f+1440|0;v=f+1504|0;w=f+1568|0;x=f+1632|0;y=f+1696|0;z=f+1760|0;gGz(e|0,0,109464);c[e>>2]=0;A=d+4|0;B=A;while(1){C=c[B>>2]|0;if((C|0)==0){break}if((fa(537088,c[C+4>>2]|0)|0)==0){D=4578;break}else{B=C+12|0}}do{if((D|0)==4578){B=bO()|0;c[B>>2]=0;E=ch(c[C+8>>2]|0,0,0)|0;if((c[B>>2]|0)!=0){break}if((E|0)==0){F=c[u>>2]|0;cj(439208,55,1,F|0)|0;eY(F|0)|0;G=0;i=f;return G|0}F=E>>>0<16?E:16;E=e+72|0;c[E>>2]=F;H=m|0;I=n|0;J=p|0;K=q|0;L=r|0;M=s|0;N=t|0;O=v|0;P=w|0;Q=x|0;R=y|0;S=z|0;T=c[u>>2]|0;L6438:do{if((F|0)!=0){U=0;while(1){be(H|0,64,349224,(V=i,i=i+8|0,c[V>>2]=U,V)|0)|0;i=V;L6441:do{if(h_(d,H,e+76+(U*4144|0)|0)|0){be(I|0,64,341608,(V=i,i=i+8|0,c[V>>2]=U,V)|0)|0;i=V;a[o]=0;if(h$(d,I,o)|0){c[e+76+(U*4144|0)+4132>>2]=(a[o]&1)!=0?1:2}else{c[e+76+(U*4144|0)+4132>>2]=0}be(J|0,64,333616,(V=i,i=i+8|0,c[V>>2]=U,V)|0)|0;i=V;W=A;while(1){X=c[W>>2]|0;if((X|0)==0){break}if((fa(J|0,c[X+4>>2]|0)|0)==0){D=4591;break}else{W=X+12|0}}do{if((D|0)==4591){D=0;W=64;Y=0;Z=K;_=c[X+8>>2]|0;while(1){$=W-1|0;if(($|0)==0){D=4594;break}aa=a[_]|0;a[Z]=aa;if(aa<<24>>24==0){ab=Y;break}else{W=$;Y=Y+1|0;Z=Z+1|0;_=_+1|0}}do{if((D|0)==4594){D=0;a[Z]=0;if((a[_]|0)==0){ab=Y;break}else{ac=_;ad=Y}while(1){W=ac+1|0;$=ad+1|0;if((a[W]|0)==0){ab=$;break}else{ac=W;ad=$}}}}while(0);if(ab>>>0>=64){break}c[e+76+(U*4144|0)+4136>>2]=jr(K)|0}}while(0);gGz(L|0,0,64);be(M|0,64,324824,(V=i,i=i+8|0,c[V>>2]=U,V)|0)|0;i=V;Y=A;while(1){ae=c[Y>>2]|0;if((ae|0)==0){break}if((fa(M|0,c[ae+4>>2]|0)|0)==0){D=4601;break}else{Y=ae+12|0}}do{if((D|0)==4601){D=0;Y=64;_=0;Z=L;$=c[ae+8>>2]|0;while(1){W=Y-1|0;if((W|0)==0){D=4604;break}aa=a[$]|0;a[Z]=aa;if(aa<<24>>24==0){af=_;break}else{Y=W;_=_+1|0;Z=Z+1|0;$=$+1|0}}do{if((D|0)==4604){D=0;a[Z]=0;if((a[$]|0)==0){af=_;break}else{ag=$;ah=_}while(1){Y=ag+1|0;W=ah+1|0;if((a[Y]|0)==0){af=W;break}else{ag=Y;ah=W}}}}while(0);if(af>>>0>=64){break}c[e+76+(U*4144|0)+4140>>2]=ch(L|0,0,0)|0}}while(0);gGz(N|0,0,64);gGz(O|0,0,64);gGz(P|0,0,64);be(Q|0,64,547712,(V=i,i=i+8|0,c[V>>2]=U,V)|0)|0;i=V;_=A;while(1){ai=c[_>>2]|0;if((ai|0)==0){break}if((fa(Q|0,c[ai+4>>2]|0)|0)==0){D=4611;break}else{_=ai+12|0}}L6480:do{if((D|0)==4611){D=0;_=64;$=N;Z=c[ai+8>>2]|0;while(1){W=_-1|0;if((W|0)==0){break}Y=a[Z]|0;a[$]=Y;if(Y<<24>>24==0){break L6480}else{_=W;$=$+1|0;Z=Z+1|0}}a[$]=0;if((a[Z]|0)==0){break}else{aj=Z}do{aj=aj+1|0;}while((a[aj]|0)!=0)}}while(0);be(Q|0,64,545744,(V=i,i=i+8|0,c[V>>2]=U,V)|0)|0;i=V;Z=A;while(1){ak=c[Z>>2]|0;if((ak|0)==0){break}if((fa(Q|0,c[ak+4>>2]|0)|0)==0){D=4619;break}else{Z=ak+12|0}}L6492:do{if((D|0)==4619){D=0;Z=64;$=O;_=c[ak+8>>2]|0;while(1){W=Z-1|0;if((W|0)==0){break}Y=a[_]|0;a[$]=Y;if(Y<<24>>24==0){break L6492}else{Z=W;$=$+1|0;_=_+1|0}}a[$]=0;if((a[_]|0)==0){break}else{al=_}do{al=al+1|0;}while((a[al]|0)!=0)}}while(0);be(Q|0,64,544672,(V=i,i=i+8|0,c[V>>2]=U,V)|0)|0;i=V;_=A;while(1){am=c[_>>2]|0;if((am|0)==0){break}if((fa(Q|0,c[am+4>>2]|0)|0)==0){D=4627;break}else{_=am+12|0}}L6504:do{if((D|0)==4627){D=0;_=64;$=P;Z=c[am+8>>2]|0;while(1){W=_-1|0;if((W|0)==0){break}Y=a[Z]|0;a[$]=Y;if(Y<<24>>24==0){break L6504}else{_=W;$=$+1|0;Z=Z+1|0}}a[$]=0;if((a[Z]|0)==0){break}else{an=Z}do{an=an+1|0;}while((a[an]|0)!=0)}}while(0);L6513:do{if((a[N]|0)==0){if((a[O]|0)!=0){break}if((a[P]|0)==0){ao=1;break L6441}}else{Z=64;$=O;_=N;while(1){W=Z-1|0;if((W|0)==0){D=4637;break}Y=a[_]|0;a[$]=Y;if(Y<<24>>24==0){ap=64;aq=P;ar=N;break}else{Z=W;$=$+1|0;_=_+1|0}}do{if((D|0)==4637){D=0;a[$]=0;if((a[_]|0)==0){ap=64;aq=P;ar=N;break}else{as=_}while(1){Z=as+1|0;if((a[Z]|0)==0){ap=64;aq=P;ar=N;break}else{as=Z}}}}while(0);while(1){_=ap-1|0;if((_|0)==0){break}$=a[ar]|0;a[aq]=$;if($<<24>>24==0){break L6513}else{ap=_;aq=aq+1|0;ar=ar+1|0}}a[aq]=0;if((a[ar]|0)==0){break}else{at=ar}do{at=at+1|0;}while((a[at]|0)!=0)}}while(0);a[e+76+(U*4144|0)+4129|0]=1;_=e+76+(U*4144|0)+4104|0;c[_>>2]=0;$=e+76+(U*4144|0)+4108|0;c[$>>2]=0;Z=e+76+(U*4144|0)+4112|0;g[Z>>2]=1.0;W=e+76+(U*4144|0)+4116|0;g[W>>2]=1.0;be(S|0,64,174512,(V=i,i=i+8|0,c[V>>2]=U,V)|0)|0;i=V;h$(d,S,e+76+(U*4144|0)+4128|0)|0;do{if((a[O]|0)!=0){if((fa(O|0,157864)|0)==0){c[_>>2]=0;break}if((fa(O|0,154704)|0)==0){c[_>>2]=2;break}if((fa(O|0,150672)|0)==0){c[_>>2]=1;break}else{cj(543320,40,1,T|0)|0;eY(T|0)|0;ao=0;break L6441}}}while(0);do{if((a[P]|0)!=0){if((fa(P|0,157864)|0)==0){c[$>>2]=0;break}if((fa(P|0,154704)|0)==0){c[$>>2]=2;break}if((fa(P|0,150672)|0)==0){c[$>>2]=1;break}else{cj(543320,40,1,T|0)|0;eY(T|0)|0;ao=0;break L6441}}}while(0);Y=(c[_>>2]|0)==1;be(R|0,64,542128,(V=i,i=i+8|0,c[V>>2]=U,V)|0)|0;i=V;L6554:do{if(Y){aa=A;while(1){au=c[aa>>2]|0;if((au|0)==0){break}if((fa(R|0,c[au+4>>2]|0)|0)==0){D=4662;break}else{aa=au+12|0}}do{if((D|0)==4662){D=0;c[B>>2]=0;aa=dE(c[au+8>>2]|0,0,0)|0;if((c[B>>2]|0)!=0){break}c[e+76+(U*4144|0)+4120>>2]=aa;break L6554}}while(0);be(R|0,64,541376,(V=i,i=i+8|0,c[V>>2]=U,V)|0)|0;i=V;aa=A;while(1){av=c[aa>>2]|0;if((av|0)==0){break L6554}if((fa(R|0,c[av+4>>2]|0)|0)==0){break}else{aa=av+12|0}}c[B>>2]=0;aa=dE(c[av+8>>2]|0,0,0)|0;if((c[B>>2]|0)!=0){break}c[e+76+(U*4144|0)+4120>>2]=aa}else{aa=A;while(1){aw=c[aa>>2]|0;if((aw|0)==0){break}if((fa(R|0,c[aw+4>>2]|0)|0)==0){D=4671;break}else{aa=aw+12|0}}if((D|0)==4671){D=0;g[Z>>2]=+gGx(c[aw+8>>2]|0,0);break}be(R|0,64,541376,(V=i,i=i+8|0,c[V>>2]=U,V)|0)|0;i=V;aa=A;while(1){ax=c[aa>>2]|0;if((ax|0)==0){break L6554}if((fa(R|0,c[ax+4>>2]|0)|0)==0){break}else{aa=ax+12|0}}g[Z>>2]=+gGx(c[ax+8>>2]|0,0)}}while(0);Z=(c[$>>2]|0)==1;be(R|0,64,542128,(V=i,i=i+8|0,c[V>>2]=U,V)|0)|0;i=V;if(Z){ay=A}else{Z=A;while(1){az=c[Z>>2]|0;if((az|0)==0){break}if((fa(R|0,c[az+4>>2]|0)|0)==0){D=4688;break}else{Z=az+12|0}}if((D|0)==4688){D=0;g[W>>2]=+gGx(c[az+8>>2]|0,0);ao=1;break}be(R|0,64,540448,(V=i,i=i+8|0,c[V>>2]=U,V)|0)|0;i=V;Z=A;while(1){aA=c[Z>>2]|0;if((aA|0)==0){ao=1;break L6441}if((fa(R|0,c[aA+4>>2]|0)|0)==0){break}else{Z=aA+12|0}}g[W>>2]=+gGx(c[aA+8>>2]|0,0);ao=1;break}while(1){aB=c[ay>>2]|0;if((aB|0)==0){break}if((fa(R|0,c[aB+4>>2]|0)|0)==0){D=4679;break}else{ay=aB+12|0}}do{if((D|0)==4679){D=0;c[B>>2]=0;W=dE(c[aB+8>>2]|0,0,0)|0;if((c[B>>2]|0)!=0){break}c[e+76+(U*4144|0)+4124>>2]=W;ao=1;break L6441}}while(0);be(R|0,64,540448,(V=i,i=i+8|0,c[V>>2]=U,V)|0)|0;i=V;W=A;while(1){aC=c[W>>2]|0;if((aC|0)==0){ao=1;break L6441}if((fa(R|0,c[aC+4>>2]|0)|0)==0){break}else{W=aC+12|0}}c[B>>2]=0;W=dE(c[aC+8>>2]|0,0,0)|0;if((c[B>>2]|0)!=0){ao=1;break}c[e+76+(U*4144|0)+4124>>2]=W;ao=1}else{bU(T|0,549712,(V=i,i=i+8|0,c[V>>2]=H,V)|0)|0;i=V;eY(T|0)|0;ao=0}}while(0);if(!ao){G=0;break}U=U+1|0;if(U>>>0>=(c[E>>2]|0)>>>0){break L6438}}i=f;return G|0}}while(0);E=k|0;R=A;while(1){aD=c[R>>2]|0;if((aD|0)==0){break}if((fa(307568,c[aD+4>>2]|0)|0)==0){D=4698;break}else{R=aD+12|0}}L6609:do{if((D|0)==4698){R=1024;P=0;O=E;S=c[aD+8>>2]|0;while(1){N=R-1|0;if((N|0)==0){D=4701;break}Q=a[S]|0;a[O]=Q;if(Q<<24>>24==0){aE=P;break}else{R=N;P=P+1|0;O=O+1|0;S=S+1|0}}do{if((D|0)==4701){a[O]=0;if((a[S]|0)==0){aE=P;break}else{aF=S;aG=P}while(1){R=aF+1|0;N=aG+1|0;if((a[R]|0)==0){aE=N;break}else{aF=R;aG=N}}}}while(0);if(aE>>>0>=1024){break}P=de(E|0,316184,j|0)|0;if((P|0)==0){break}S=e+66380|0;O=P;L6621:while(1){P=c[S>>2]|0;if(P>>>0>=8){break L6609}N=e+66384+(P*4168|0)+64|0;P=A;while(1){aH=c[P>>2]|0;if((aH|0)==0){break L6621}if((fa(O|0,c[aH+4>>2]|0)|0)==0){break}else{P=aH+12|0}}P=4096;R=0;Q=N;F=c[aH+8>>2]|0;while(1){U=P-1|0;if((U|0)==0){D=4713;break}W=a[F]|0;a[Q]=W;if(W<<24>>24==0){aI=R;break}else{P=U;R=R+1|0;Q=Q+1|0;F=F+1|0}}do{if((D|0)==4713){D=0;a[Q]=0;if((a[F]|0)==0){aI=R;break}else{aJ=F;aK=R}while(1){P=aJ+1|0;N=aK+1|0;if((a[P]|0)==0){aI=N;break}else{aJ=P;aK=N}}}}while(0);if(aI>>>0>=4096){break}R=64;F=e+66384+((c[S>>2]|0)*4168|0)|0;Q=O;while(1){N=R-1|0;if((N|0)==0){D=4720;break}P=a[Q]|0;a[F]=P;if(P<<24>>24==0){break}else{R=N;F=F+1|0;Q=Q+1|0}}do{if((D|0)==4720){D=0;a[F]=0;if((a[Q]|0)==0){break}else{aL=Q}do{aL=aL+1|0;}while((a[aL]|0)!=0)}}while(0);be(H|0,64,299312,(V=i,i=i+8|0,c[V>>2]=O,V)|0)|0;i=V;a[l]=0;if(h$(d,H,l)|0){c[e+66384+((c[S>>2]|0)*4168|0)+4160>>2]=(a[l]&1)!=0?1:2}else{c[e+66384+((c[S>>2]|0)*4168|0)+4160>>2]=0}be(I|0,64,291752,(V=i,i=i+8|0,c[V>>2]=O,V)|0)|0;i=V;Q=A;while(1){aM=c[Q>>2]|0;if((aM|0)==0){break}if((fa(I|0,c[aM+4>>2]|0)|0)==0){D=4728;break}else{Q=aM+12|0}}do{if((D|0)==4728){D=0;Q=64;F=0;R=J;N=c[aM+8>>2]|0;while(1){P=Q-1|0;if((P|0)==0){D=4731;break}U=a[N]|0;a[R]=U;if(U<<24>>24==0){aN=F;break}else{Q=P;F=F+1|0;R=R+1|0;N=N+1|0}}do{if((D|0)==4731){D=0;a[R]=0;if((a[N]|0)==0){aN=F;break}else{aO=N;aP=F}while(1){Q=aO+1|0;P=aP+1|0;if((a[Q]|0)==0){aN=P;break}else{aO=Q;aP=P}}}}while(0);if(aN>>>0>=64){break}F=jr(J)|0;c[e+66384+((c[S>>2]|0)*4168|0)+4164>>2]=F}}while(0);c[S>>2]=(c[S>>2]|0)+1;F=de(0,316184,j|0)|0;if((F|0)==0){break L6609}else{O=F}}bU(T|0,553488,(V=i,i=i+8|0,c[V>>2]=O,V)|0)|0;i=V;eY(T|0)|0;G=0;i=f;return G|0}}while(0);S=A;while(1){aQ=c[S>>2]|0;if((aQ|0)==0){G=1;D=4814;break}if((fa(271208,c[aQ+4>>2]|0)|0)==0){break}else{S=aQ+12|0}}if((D|0)==4814){i=f;return G|0}S=1024;F=0;N=E;R=c[aQ+8>>2]|0;while(1){P=S-1|0;if((P|0)==0){D=4742;break}Q=a[R]|0;a[N]=Q;if(Q<<24>>24==0){aR=F;break}else{S=P;F=F+1|0;N=N+1|0;R=R+1|0}}do{if((D|0)==4742){a[N]=0;if((a[R]|0)==0){aR=F;break}else{aS=R;aT=F}while(1){S=aS+1|0;P=aT+1|0;if((a[S]|0)==0){aR=P;break}else{aS=S;aT=P}}}}while(0);if(aR>>>0>=1024){G=1;i=f;return G|0}F=de(E|0,316184,h|0)|0;L6684:do{if((F|0)!=0){R=e+99728|0;N=F;L6686:while(1){O=c[R>>2]|0;if(O>>>0>=64){break L6684}P=64;S=e+99732+(O*80|0)|0;Q=N;while(1){U=P-1|0;if((U|0)==0){D=4751;break}W=a[Q]|0;a[S]=W;if(W<<24>>24==0){break}else{P=U;S=S+1|0;Q=Q+1|0}}do{if((D|0)==4751){D=0;a[S]=0;if((a[Q]|0)==0){break}else{aU=Q}do{aU=aU+1|0;}while((a[aU]|0)!=0)}}while(0);be(H|0,64,234608,(V=i,i=i+8|0,c[V>>2]=N,V)|0)|0;i=V;be(I|0,64,228232,(V=i,i=i+8|0,c[V>>2]=N,V)|0)|0;i=V;be(J|0,64,222336,(V=i,i=i+8|0,c[V>>2]=N,V)|0)|0;i=V;be(K|0,64,218088,(V=i,i=i+8|0,c[V>>2]=N,V)|0)|0;i=V;be(L|0,64,214280,(V=i,i=i+8|0,c[V>>2]=N,V)|0)|0;i=V;Q=A;while(1){aV=c[Q>>2]|0;if((aV|0)==0){D=4762;break L6686}if((fa(H|0,c[aV+4>>2]|0)|0)==0){break}else{Q=aV+12|0}}Q=64;S=0;P=M;U=c[aV+8>>2]|0;while(1){W=Q-1|0;if((W|0)==0){D=4759;break}Z=a[U]|0;a[P]=Z;if(Z<<24>>24==0){aW=S;break}else{Q=W;S=S+1|0;P=P+1|0;U=U+1|0}}do{if((D|0)==4759){D=0;a[P]=0;if((a[U]|0)==0){aW=S;break}else{aX=U;aY=S}while(1){Q=aX+1|0;W=aY+1|0;if((a[Q]|0)==0){aW=W;break}else{aX=Q;aY=W}}}}while(0);if(aW>>>0>=64){D=4762;break}do{if((fa(M|0,210960)|0)==0){c[e+99732+(O*80|0)+68>>2]=0;aZ=A;D=4776}else{if((fa(M|0,206032)|0)==0){c[e+99732+(O*80|0)+68>>2]=2;aZ=A;D=4776;break}if((fa(M|0,199680)|0)==0){c[e+99732+(O*80|0)+68>>2]=3;aZ=A;D=4776;break}if((fa(M|0,194200)|0)==0){c[e+99732+(O*80|0)+68>>2]=1;aZ=A;D=4776;break}if((fa(M|0,188128)|0)==0){c[e+99732+(O*80|0)+68>>2]=4;aZ=A;D=4776;break}if((fa(M|0,182664)|0)!=0){D=4774;break L6686}c[e+99732+(O*80|0)+68>>2]=5;a_=A}}while(0);L6726:do{if((D|0)==4776){while(1){D=0;a$=c[aZ>>2]|0;if((a$|0)==0){a0=A;break}if((fa(J|0,c[a$+4>>2]|0)|0)==0){D=4778;break}else{aZ=a$+12|0;D=4776}}do{if((D|0)==4778){D=0;c[B>>2]=0;S=ch(c[a$+8>>2]|0,0,0)|0;if((c[B>>2]|0)!=0){a0=A;break}if((S|0)==1){c[e+99732+(O*80|0)+72>>2]=2;a_=A;break L6726}else if((S|0)==2){c[e+99732+(O*80|0)+72>>2]=3;a_=A;break L6726}else{D=4782;break L6686}}}while(0);while(1){a1=c[a0>>2]|0;if((a1|0)==0){D=4787;break L6686}if((fa(I|0,c[a1+4>>2]|0)|0)==0){break}else{a0=a1+12|0}}c[B>>2]=0;S=ch(c[a1+8>>2]|0,0,16)|0;if((c[B>>2]|0)!=0){D=4787;break L6686}c[e+99732+(O*80|0)+72>>2]=1;c[e+99732+(O*80|0)+64>>2]=S;a_=A}}while(0);while(1){a2=c[a_>>2]|0;if((a2|0)==0){a3=A;break}if((fa(K|0,c[a2+4>>2]|0)|0)==0){D=4790;break}else{a_=a2+12|0}}do{if((D|0)==4790){D=0;c[B>>2]=0;S=ch(c[a2+8>>2]|0,0,16)|0;if((c[B>>2]|0)!=0){a3=A;break}b[e+99732+(O*80|0)+76>>1]=S&65535;a3=A}}while(0);while(1){a4=c[a3>>2]|0;if((a4|0)==0){break}if((fa(L|0,c[a4+4>>2]|0)|0)==0){D=4794;break}else{a3=a4+12|0}}do{if((D|0)==4794){D=0;c[B>>2]=0;S=ch(c[a4+8>>2]|0,0,16)|0;if((c[B>>2]|0)!=0){break}b[e+99732+(O*80|0)+78>>1]=S&65535}}while(0);c[R>>2]=(c[R>>2]|0)+1;N=de(0,316184,h|0)|0;if((N|0)==0){break L6684}}if((D|0)==4782){cj(99784,52,1,T|0)|0;eY(T|0)|0;G=0;i=f;return G|0}else if((D|0)==4762){cj(557864,54,1,T|0)|0;eY(T|0)|0;G=0;i=f;return G|0}else if((D|0)==4787){cj(555352,54,1,T|0)|0;eY(T|0)|0;G=0;i=f;return G|0}else if((D|0)==4774){cj(556296,39,1,T|0)|0;eY(T|0)|0;G=0;i=f;return G|0}}}while(0);h_(d,285456,e+104852|0)|0;T=e+108952|0;B=A;while(1){a5=c[B>>2]|0;if((a5|0)==0){G=1;D=4809;break}if((fa(278512,c[a5+4>>2]|0)|0)==0){break}else{B=a5+12|0}}if((D|0)==4809){i=f;return G|0}B=512;L=T;K=c[a5+8>>2]|0;while(1){I=B-1|0;if((I|0)==0){break}J=a[K]|0;a[L]=J;if(J<<24>>24==0){G=1;D=4810;break}else{B=I;L=L+1|0;K=K+1|0}}if((D|0)==4810){i=f;return G|0}a[L]=0;if((a[K]|0)==0){G=1;i=f;return G|0}else{a6=K}while(1){B=a6+1|0;if((a[B]|0)==0){G=1;break}else{a6=B}}i=f;return G|0}}while(0);a6=c[u>>2]|0;cj(567256,50,1,a6|0)|0;eY(a6|0)|0;G=0;i=f;return G|0}function jo(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,v=0,w=0,x=0,y=0,z=0;f=i;i=i+8200|0;g=f|0;h=f+4104|0;c[g>>2]=b;j=f+8|0;k=e+8|0;while(1){l=c[k>>2]|0;if((l|0)==0){break}if((fa(488472,c[l>>2]|0)|0)==0){m=4823;break}else{k=l+8|0}}do{if((m|0)==4823){k=c[l+4>>2]|0;if((k|0)==0){break}else{n=4096;o=0;p=j;q=k}while(1){k=n-1|0;if((k|0)==0){m=4827;break}e=a[q]|0;a[p]=e;if(e<<24>>24==0){r=o;break}else{n=k;o=o+1|0;p=p+1|0;q=q+1|0}}do{if((m|0)==4827){a[p]=0;if((a[q]|0)==0){r=o;break}else{s=q;t=o}while(1){k=s+1|0;e=t+1|0;if((a[k]|0)==0){r=e;break}else{s=k;t=e}}}}while(0);if(r>>>0>=4096){i=f;return b|0}gGr(b);c[g>>2]=0;e=h|0;hM(e,d,j);if((a[9375104]&1)==0){v=hx(e,g)|0;w=(v|0)>-1;x=c[g>>2]|0;y=w?x:0;i=f;return y|0}k=c[u>>2]|0;bU(k|0,559256,(z=i,i=i+8|0,c[z>>2]=e,z)|0)|0;i=z;eY(k|0)|0;v=hx(e,g)|0;w=(v|0)>-1;x=c[g>>2]|0;y=w?x:0;i=f;return y|0}}while(0);a[j]=0;i=f;return b|0}function jp(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if((a|0)==0){c=b;return c|0}d=cE(a|0,47)|0;e=cE(((d|0)==0?a:d+1|0)|0,46)|0;d=(e|0)==0?9534384:e+1|0;if((fa(d|0,128928)|0)==0){c=0;return c|0}if((fa(d|0,203216)|0)==0){c=0;return c|0}if((fa(d|0,160336)|0)==0){c=2;return c|0}if((fa(d|0,558744)|0)==0){c=2;return c|0}else{c=(fa(d|0,471856)|0)==0;return(c?2:b)|0}return 0}function jq(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=i;i=i+4096|0;f=e|0;g=b+72|0;h=c[g>>2]|0;if((h|0)!=0){j=f|0;k=0;l=h;while(1){h=b+76+(k*4144|0)|0;if((a[h]|0)==0){m=l}else{n=4096;o=j;p=h;while(1){q=n-1|0;if((q|0)==0){r=4857;break}s=a[p]|0;a[o]=s;if(s<<24>>24==0){break}else{n=q;o=o+1|0;p=p+1|0}}do{if((r|0)==4857){r=0;a[o]=0;if((a[p]|0)==0){break}else{t=p}do{t=t+1|0;}while((a[t]|0)!=0)}}while(0);hM(h,d,j);m=c[g>>2]|0}p=k+1|0;if(p>>>0<m>>>0){k=p;l=m}else{break}}}m=b+66380|0;if((c[m>>2]|0)!=0){l=f|0;k=0;do{g=b+66384+(k*4168|0)+64|0;j=4096;t=l;p=g;while(1){o=j-1|0;if((o|0)==0){r=4864;break}n=a[p]|0;a[t]=n;if(n<<24>>24==0){break}else{j=o;t=t+1|0;p=p+1|0}}do{if((r|0)==4864){r=0;a[t]=0;if((a[p]|0)==0){break}else{u=p}do{u=u+1|0;}while((a[u]|0)!=0)}}while(0);hM(g,d,l);k=k+1|0;}while(k>>>0<(c[m>>2]|0)>>>0)}m=b+104852|0;if((a[m]|0)==0){i=e;return}b=f|0;f=4096;k=b;l=m;while(1){u=f-1|0;if((u|0)==0){r=4871;break}p=a[l]|0;a[k]=p;if(p<<24>>24==0){break}else{f=u;k=k+1|0;l=l+1|0}}do{if((r|0)==4871){a[k]=0;if((a[l]|0)==0){break}else{v=l}do{v=v+1|0;}while((a[v]|0)!=0)}}while(0);hM(m,d,b);i=e;return}function jr(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;do{if((fa(a|0,147560)|0)==0){d=0}else{if((fa(a|0,143200)|0)==0){d=1;break}if((fa(a|0,140424)|0)==0){d=2;break}if((fa(a|0,137856)|0)==0){d=3;break}e=c[u>>2]|0;bU(e|0,551512,(f=i,i=i+8|0,c[f>>2]=a,f)|0)|0;i=f;eY(e|0)|0;d=0}}while(0);i=b;return d|0}function js(b,e){b=b|0;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;b=gGq(1032)|0;if((b|0)==0){f=0;return f|0}if((c[b-4>>2]&3|0)!=0){gGz(b|0,0,1032)}g=b;h=~~+ba(+(e/10.0));i=b;j=(h|0)==0?1:h;c[i>>2]=j;h=gGq(ag(j*12800|0,j)|0)|0;k=b+1028|0;c[k>>2]=h;if((h|0)==0){gGr(b);f=0;return f|0}else{l=0;m=j;n=h}while(1){h=ag(ag(m*50|0,m)|0,l)|0;c[g+4+(l<<2)>>2]=n+h;j=l*7|0;o=c[i>>2]|0;p=0;q=o;while(1){r=p*5|0;s=0;t=q;u=q;while(1){v=s+r|0;w=((1<<(v&7)&(d[62168+((v>>>3)+j)|0]|0)|0)!=0)<<31>>31;if((t|0)==0){x=0;y=u}else{v=0;z=u;while(1){if((z|0)==0){A=0}else{B=v+h|0;C=0;D=z;while(1){a[n+(B+(ag((((ag(D,p)|0)+C|0)*5|0)+s|0,D)|0))|0]=w;E=C+1|0;if(E>>>0<o>>>0){C=E;D=o}else{A=o;break}}}D=v+1|0;if(D>>>0<A>>>0){v=D;z=A}else{x=A;y=A;break}}}z=s+1|0;if(z>>>0<5){s=z;t=x;u=y}else{break}}u=p+1|0;if(u>>>0<10){p=u;q=y}else{break}}q=l+1|0;if(q>>>0>=256){f=b;break}l=q;m=o;n=c[k>>2]|0}return f|0}function jt(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=e|0;c[f>>2]=0;e=gGy(d|0)|0;if((e|0)==0){return}g=b+4|0;h=b;b=0;i=0;j=0;while(1){k=gGq(52)|0;if((k|0)==0){l=4913;break}if((c[k-4>>2]&3|0)!=0){gGz(k|0,0,52)}m=k;c[k>>2]=c[g+(a[d+j|0]<<2)>>2];n=c[h>>2]|0;o=n*5|0;c[k+4>>2]=o;p=n*10|0;c[k+8>>2]=p;c[k+12>>2]=o;c[k+32>>2]=o;c[k+36>>2]=p;c[k+40>>2]=0;c[k+44>>2]=p;c[k+24>>2]=i;c[k+28>>2]=0;c[k+48>>2]=0;if((j|0)==0){c[f>>2]=m;q=c[h>>2]|0}else{c[b+48>>2]=m;q=n}n=j+1|0;if(n>>>0<e>>>0){b=m;i=(q*6|0)+i|0;j=n}else{l=4914;break}}if((l|0)==4913){return}else if((l|0)==4914){return}}function ju(a,b){a=a|0;b=b|0;var d=0;a=b|0;b=c[a>>2]|0;if((b|0)==0){c[a>>2]=0;return}else{d=b}while(1){b=c[d+48>>2]|0;gGr(d);if((b|0)==0){break}else{d=b}}c[a>>2]=0;return}function jv(a){a=a|0;gGr(c[a+1028>>2]|0);gGr(a);return}function jw(){return 9534384}function jx(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0;h=i;i=i+1920|0;j=h|0;k=h+16|0;l=h+784|0;m=h+792|0;n=h+848|0;o=h+864|0;p=h+1888|0;q=h+1896|0;r=h+1912|0;if((e3(b|0,517560)|0)!=0){c[r>>2]=0;if((hx(b,r)|0)<0){s=c[u>>2]|0;bU(s|0,338320,(t=i,i=i+8|0,c[t>>2]=b,t)|0)|0;i=t;eY(s|0)|0;v=0;i=h;return v|0}s=c[r>>2]|0;if((a[s+2|0]|0)!=2){r=c[u>>2]|0;cj(260984,56,1,r|0)|0;eY(r|0)|0;gGr(s);v=0;i=h;return v|0}r=a[s+16|0]|0;w=d[s+13|0]<<8|d[s+12|0];x=d[s+15|0]<<8|d[s+14|0];if((a[9375104]&1)!=0){y=r&255;z=c[u>>2]|0;bU(z|0,203584,(t=i,i=i+24|0,c[t>>2]=w,c[t+8>>2]=x,c[t+16>>2]=y,t)|0)|0;i=t;eY(z|0)|0}z=ag(x,w)|0;y=gGq(z<<2)|0;A=y;B=e+8|0;c[B>>2]=A;c[e>>2]=w;c[e+4>>2]=x;if((y|0)==0){y=c[u>>2]|0;cj(159768,52,1,y|0)|0;eY(y|0)|0;gGr(s);v=0;i=h;return v|0}L6942:do{if((r<<24>>24|0)==32){if((z|0)==0){break}else{C=0;D=A}while(1){y=C<<2;c[D+(C<<2)>>2]=d[s+((y|1)+18)|0]<<8|d[s+(y+18)|0]<<g|d[s+((y|2)+18)|0]<<f|d[s+((y|3)+18)|0]<<24;y=C+1|0;if(y>>>0>=z>>>0){break L6942}C=y;D=c[B>>2]|0}}else if((r<<24>>24|0)==24){if((z|0)==0){break}else{E=0;F=A}while(1){y=E*3|0;c[F+(E<<2)>>2]=d[s+(y+18)|0]<<g|d[s+(y+19)|0]<<8|d[s+(y+20)|0]<<f|-16777216;y=E+1|0;if(y>>>0>=z>>>0){break L6942}E=y;F=c[B>>2]|0}}else{y=c[u>>2]|0;cj(129144,88,1,y|0)|0;eY(y|0)|0;gGr(s);gGr(c[B>>2]|0);c[B>>2]=0;v=0;i=h;return v|0}}while(0);gGr(s);v=1;i=h;return v|0}if((e3(b|0,563992)|0)==0){v=0;i=h;return v|0}if((a[9375104]&1)!=0){s=c[u>>2]|0;cj(437216,38,1,s|0)|0;eY(s|0)|0}s=e+8|0;B=e|0;F=e+4|0;e=n;E=p|0;p=q;c[s>>2]=0;c[B>>2]=0;c[F>>2]=0;z=fw(b|0,364392)|0;if((z|0)==0){v=0;i=h;return v|0}dh(z|0,0,2)|0;b=fl(z|0)|0;b4(z|0);gGz(m|0,0,56);c[e>>2]=c[776];c[e+4>>2]=c[777];c[e+8>>2]=c[778];c[e+12>>2]=c[779];gGz(o|0,0,1024);if((ew(E|0,1,8,z|0)|0)==8){L6968:do{if((gGH(E|0,7952,8)|0)==0){A=fl(z|0)|0;do{if((A|0)<(b|0)&(A|0)>-1){r=l;D=r+1|0;C=r+2|0;y=r+3|0;x=q|0;w=q+4|0;G=q+8|0;H=n|0;I=n+4|0;J=n+8|0;K=n+9|0;L=n+10|0;M=n+11|0;N=n+12|0;O=k|0;P=0;Q=0;R=0;S=0;T=0;U=0;V=0;W=0;X=0;Y=0;Z=0;L6972:while(1){gGz(p|0,0,12);c[l>>2]=0;if((ew(r|0,1,4,z|0)|0)!=4){_=4953;break}c[x>>2]=d[D]<<16|d[r]<<24|d[C]<<8|d[y];if((ew(w|0,1,4,z|0)|0)==4){$=0}else{_=4953;break}while(1){if($>>>0>=4){_=4957;break}if((gGH(w|0,c[61776+($<<3)>>2]|0,4)|0)==0){_=4956;break}else{$=$+1|0}}L6978:do{if((_|0)==4956){_=0;switch(c[61780+($<<3)>>2]|0){case 3:{if(T|R^1){_=5001;break L6972}if(!(V<<24>>24!=3|U)){_=5001;break L6972}aa=c[x>>2]|0;ab=aa+P|0;ac=gGs(Q,ab)|0;if((ac|0)==0){ad=Q;_=5005;break L6972}if((ew(ac+P|0,1,aa|0,z|0)|0)!=(aa|0)){ad=ac;_=5005;break L6972}if((dh(z|0,4,1)|0)<0){ad=ac;_=5005;break L6972}else{ae=U;af=0;ah=1;ai=R;aj=ac;ak=ab;al=V;am=W;an=X;ao=Y;ap=Z;break L6978}break};case 5:{if(!(R&S)){_=5007;break L6972}if((dh(z|0,4,1)|0)<0){_=5009;break L6972}else{ae=U;af=1;ah=1;ai=1;aj=Q;ak=P;al=V;am=W;an=X;ao=Y;ap=Z;break L6978}break};case 1:{_=4959;break L6972;break};case 4:{if(U|R^1|T|S){_=4990;break L6972}ab=c[x>>2]|0;if(((ab>>>0)%3|0|0)!=0){_=4992;break L6972}ac=(ab>>>0)/3|0;if(ab>>>0>770){_=4998;break L6972}if((ew(O|0,3,ac|0,z|0)|0)!=(ac|0)){_=4998;break L6972}if(ab>>>0>=3){ab=0;do{aa=ab*3|0;c[o+(ab<<2)>>2]=d[k+aa|0]<<16|d[k+(aa+1)|0]<<8|d[k+(aa+2)|0]|-16777216;ab=ab+1|0;}while(ab>>>0<ac>>>0)}if((dh(z|0,4,1)|0)>-1){ae=1;af=0;ah=0;ai=R;aj=Q;ak=P;al=V;am=W;an=X;ao=Y;ap=Z;break L6978}else{_=4998;break L6972}break};case 2:{if(R|S|T){_=4961;break L6972}gGr(c[G>>2]|0);ac=c[x>>2]|0;ab=ac+4|0;aq=gGq(ab)|0;if((aq|0)==0){_=4963;break L6972}if((c[aq-4>>2]&3|0)!=0){gGz(aq|0,0,ab|0)}c[G>>2]=aq;if((ew(aq|0,1,ab|0,z|0)|0)!=(ab|0)){_=4967;break L6972}if((ac|0)!=13){_=4969;break L6972}ac=d[aq+1|0]<<16|d[aq]<<24|d[aq+2|0]<<8|d[aq+3|0];c[H>>2]=ac;ab=d[aq+5|0]<<16|d[aq+4|0]<<24|d[aq+6|0]<<8|d[aq+7|0];c[I>>2]=ab;aa=a[aq+8|0]|0;a[J]=aa;ar=a[aq+9|0]|0;a[K]=ar;as=a[aq+10|0]|0;a[L]=as;a[M]=a[aq+11|0]|0;at=a[aq+12|0]|0;a[N]=at;if((ac|0)==0|(ab|0)==0){_=4971;break L6972}switch(ar<<24>>24){case 2:case 4:case 6:{if(!((aa<<24>>24|0)==8|(aa<<24>>24|0)==16)){_=4976;break L6972}break};case 0:{au=aa&255;av=0;while(1){if(av>>>0>=5){_=4979;break L6972}if((c[7928+(av<<2)>>2]|0)==(au|0)){break}else{av=av+1|0}}break};case 3:{av=aa&255;au=0;while(1){if(au>>>0>=4){_=4982;break L6972}if((c[7912+(au<<2)>>2]|0)==(av|0)){break}else{au=au+1|0}}break};default:{_=4983;break L6972}}if(as<<24>>24!=0){_=4985;break L6972}gGr(aq);c[G>>2]=0;ae=U;af=0;ah=0;ai=1;aj=Q;ak=P;al=ar;am=ab;an=at;ao=ac;ap=aa;break L6978;break};default:{_=4957;break L6978}}}}while(0);if((_|0)==4957){_=0;if((dh(z|0,(c[x>>2]|0)+4|0,1)|0)<0){_=4958;break}else{ae=U;af=T;ah=S;ai=R;aj=Q;ak=P;al=V;am=W;an=X;ao=Y;ap=Z}}au=fl(z|0)|0;if((au|0)<(b|0)&(au|0)>-1){P=ak;Q=aj;R=ai;S=ah;T=af;U=ae;V=al;W=am;X=an;Y=ao;Z=ap}else{_=5011;break}}if((_|0)==4982){Z=c[u>>2]|0;bU(Z|0,557472,(t=i,i=i+8|0,c[t>>2]=204,t)|0)|0;i=t;_=4986}else if((_|0)==4983){bU(c[u>>2]|0,557472,(t=i,i=i+8|0,c[t>>2]=207,t)|0)|0;i=t;_=4986}else if((_|0)==4985){bU(c[u>>2]|0,557472,(t=i,i=i+8|0,c[t>>2]=219,t)|0)|0;i=t;_=4986}else if((_|0)==5007){bU(c[u>>2]|0,557472,(t=i,i=i+8|0,c[t>>2]=675,t)|0)|0;i=t;aw=0;ax=Q;break L6968}else if((_|0)==4998){bU(c[u>>2]|0,557472,(t=i,i=i+8|0,c[t>>2]=658,t)|0)|0;i=t;aw=0;ax=Q;break L6968}else if((_|0)==4959){bU(c[u>>2]|0,557472,(t=i,i=i+8|0,c[t>>2]=638,t)|0)|0;i=t;aw=0;ax=Q;break L6968}else if((_|0)==4969){bU(c[u>>2]|0,557472,(t=i,i=i+8|0,c[t>>2]=156,t)|0)|0;i=t;_=4986}else if((_|0)==4963){c[G>>2]=0}else if((_|0)==4961){bU(c[u>>2]|0,557472,(t=i,i=i+8|0,c[t>>2]=642,t)|0)|0;i=t;aw=0;ax=Q;break L6968}else if((_|0)==4976){bU(c[u>>2]|0,557472,(t=i,i=i+8|0,c[t>>2]=172,t)|0)|0;i=t;_=4986}else if((_|0)==4958){bU(c[u>>2]|0,557472,(t=i,i=i+8|0,c[t>>2]=634,t)|0)|0;i=t;aw=0;ax=Q;break L6968}else if((_|0)==4979){bU(c[u>>2]|0,557472,(t=i,i=i+8|0,c[t>>2]=188,t)|0)|0;i=t;_=4986}else if((_|0)==4953){bU(c[u>>2]|0,557472,(t=i,i=i+8|0,c[t>>2]=627,t)|0)|0;i=t;aw=0;ax=Q;break L6968}else if((_|0)==5011){if(!(ai&ah&af)){ay=aj;break}Z=m+24|0;c[Z>>2]=0;Y=m+32|0;X=c[Y>>2]|0;if((X|0)==0){c[Y>>2]=7122;c[m+40>>2]=0;az=7122}else{az=X}X=m+36|0;if((c[X>>2]|0)==0){c[X>>2]=494}Y=m+40|0;W=gp[az&16383](c[Y>>2]|0,1,7116)|0;if((W|0)!=0){V=m+28|0;c[V>>2]=W;c[W+52>>2]=0;U=c[V>>2]|0;do{if((U|0)!=0){T=U+52|0;S=c[T>>2]|0;R=U+36|0;do{if((S|0)!=0){if((c[R>>2]|0)==15){break}gg[c[X>>2]&4095](c[Y>>2]|0,S);c[T>>2]=0}}while(0);c[U+8>>2]=1;c[R>>2]=15;T=c[V>>2]|0;if((T|0)==0){break}c[T+40>>2]=0;c[T+44>>2]=0;c[T+48>>2]=0;T=c[V>>2]|0;if((T|0)==0){break}c[T+28>>2]=0;S=m+20|0;c[S>>2]=0;c[m+8>>2]=0;c[Z>>2]=0;P=c[T+8>>2]|0;if((P|0)!=0){c[m+48>>2]=P&1}c[T>>2]=0;c[T+4>>2]=0;c[T+12>>2]=0;c[T+20>>2]=32768;c[T+32>>2]=0;c[T+56>>2]=0;c[T+60>>2]=0;P=T+1328|0;c[T+108>>2]=P;c[T+80>>2]=P;c[T+76>>2]=P;c[T+7104>>2]=1;c[T+7108>>2]=-1;switch(al&255|0){case 6:{aA=((ag((ap&255)<<2,ao)|0)+7|0)>>>3;break};case 0:{aA=((ag(ao,ap&255)|0)+7|0)>>>3;break};case 2:{aA=((ag((ap&255)*3|0,ao)|0)+7|0)>>>3;break};case 3:{aA=((ag(ao,ap&255)|0)+7|0)>>>3;break};case 4:{aA=((ag((ap&255)<<1,ao)|0)+7|0)>>>3;break};default:{aA=0}}T=an<<24>>24==1;P=(ag(am,aA+1|0)|0)<<(T&1);x=gGq(P)|0;if((x|0)==0){N=c[u>>2]|0;bU(N|0,557472,(t=i,i=i+8|0,c[t>>2]=697,t)|0)|0;i=t;aw=0;ax=aj;break L6968}c[m>>2]=aj;c[m+4>>2]=ak;c[m+16>>2]=P;c[m+12>>2]=x;P=(RS(m,4)|0)==1;N=c[V>>2]|0;do{if((N|0)!=0){M=c[X>>2]|0;if((M|0)==0){break}L=c[N+52>>2]|0;if((L|0)==0){aB=M;aC=N}else{gg[M&4095](c[Y>>2]|0,L);aB=c[X>>2]|0;aC=c[V>>2]|0}gg[aB&4095](c[Y>>2]|0,aC);c[V>>2]=0}}while(0);if(!P){N=c[u>>2]|0;bU(N|0,557472,(t=i,i=i+8|0,c[t>>2]=707,t)|0)|0;i=t;aw=x;ax=aj;break L6968}c[B>>2]=ao;c[F>>2]=am;N=gGq(ag(am<<2,ao)|0)|0;R=N;c[s>>2]=R;if((N|0)==0){N=c[u>>2]|0;bU(N|0,557472,(t=i,i=i+8|0,c[t>>2]=715,t)|0)|0;i=t;aw=x;ax=aj;break L6968}N=c[S>>2]|0;L=o|0;L7079:do{if(T){M=j;K=j|0;J=j+4|0;O=j+9|0;w=j+8|0;y=0;C=N;r=x;D=ao;L7083:while(1){au=c[7800+(y<<4)>>2]|0;do{if(D>>>0>au>>>0){av=c[I>>2]|0;aD=c[7804+(y<<4)>>2]|0;if(av>>>0<=aD>>>0){aE=r;aF=C;break}aG=c[7808+(y<<4)>>2]|0;aH=((D-1-au+aG|0)>>>0)/(aG>>>0)|0;aI=c[7812+(y<<4)>>2]|0;aJ=((av-1-aD+aI|0)>>>0)/(aI>>>0)|0;av=aH<<2;aK=gGq(ag(aJ,av)|0)|0;aL=aK;if((aK|0)==0){break L7083}c[M>>2]=c[e>>2];c[M+4>>2]=c[e+4>>2];c[M+8>>2]=c[e+8>>2];c[M+12>>2]=c[e+12>>2];c[K>>2]=aH;c[J>>2]=aJ;switch(d[O]|0){case 3:{aM=((ag(d[w]|0,aH)|0)+7|0)>>>3;break};case 4:{aM=((ag(aH<<1,d[w]|0)|0)+7|0)>>>3;break};case 6:{aM=((ag(d[w]|0,av)|0)+7|0)>>>3;break};case 0:{aM=((ag(d[w]|0,aH)|0)+7|0)>>>3;break};case 2:{aM=((ag(aH*3|0,d[w]|0)|0)+7|0)>>>3;break};default:{aM=0}}av=ag(aM+1|0,aJ)|0;if(av>>>0>C>>>0){_=5057;break L7083}if(!(k7(aL,j,r,av,L)|0)){_=5059;break L7083}aN=r+av|0;aO=C-av|0;if(!((aJ|0)==0|(aH|0)==0)){av=aL;aL=R+((ag(c[H>>2]|0,aD)|0)+au<<2)|0;aD=0;while(1){aP=0;aQ=aL;while(1){c[aQ>>2]=c[av+(aP<<2)>>2];aR=aP+1|0;if(aR>>>0<aH>>>0){aP=aR;aQ=aQ+(aG<<2)|0}else{break}}aQ=aD+1|0;aP=aL+((ag(c[H>>2]|0,aI)|0)<<2)|0;if(aQ>>>0<aJ>>>0){av=av+(aH<<2)|0;aL=aP;aD=aQ}else{break}}}gGr(aK);aE=aN;aF=aO}else{aE=r;aF=C}}while(0);au=y+1|0;if(au>>>0>=7){break L7079}y=au;C=aF;r=aE;D=c[H>>2]|0}if((_|0)==5057){gGr(aK)}else if((_|0)==5059){gGr(aK)}bU(c[u>>2]|0,557472,(t=i,i=i+8|0,c[t>>2]=720,t)|0)|0;i=t;aw=x;ax=aj;break L6968}else{if(k7(R,n,x,N,L)|0){break}bU(c[u>>2]|0,557472,(t=i,i=i+8|0,c[t>>2]=723,t)|0)|0;i=t;aw=x;ax=aj;break L6968}}while(0);aY(z|0)|0;gGr(aj);gGr(x);if((f|0)==16&(g|0)==0){v=1;i=h;return v|0}L=ag(c[F>>2]|0,c[B>>2]|0)|0;N=c[s>>2]|0;if((L|0)==0){v=1;i=h;return v|0}else{aS=0}while(1){R=N+(aS<<2)|0;T=c[R>>2]|0;c[R>>2]=(T&255)<<g|T&-16777216|(T>>>16&255)<<f|T&65280;T=aS+1|0;if(T>>>0<L>>>0){aS=T}else{v=1;break}}i=h;return v|0}}while(0);gg[c[X>>2]&4095](c[Y>>2]|0,W);c[V>>2]=0}bU(c[u>>2]|0,557472,(t=i,i=i+8|0,c[t>>2]=689,t)|0)|0;i=t;aw=0;ax=aj;break L6968}else if((_|0)==5001){bU(c[u>>2]|0,557472,(t=i,i=i+8|0,c[t>>2]=665,t)|0)|0;i=t;aw=0;ax=Q;break L6968}else if((_|0)==5009){bU(c[u>>2]|0,557472,(t=i,i=i+8|0,c[t>>2]=678,t)|0)|0;i=t;aw=0;ax=Q;break L6968}else if((_|0)==4992){bU(c[u>>2]|0,557472,(t=i,i=i+8|0,c[t>>2]=655,t)|0)|0;i=t;aw=0;ax=Q;break L6968}else if((_|0)==4971){bU(c[u>>2]|0,557472,(t=i,i=i+8|0,c[t>>2]=167,t)|0)|0;i=t;_=4986}else if((_|0)==4990){bU(c[u>>2]|0,557472,(t=i,i=i+8|0,c[t>>2]=652,t)|0)|0;i=t;aw=0;ax=Q;break L6968}else if((_|0)==4967){gGr(aq)}else if((_|0)==5005){bU(c[u>>2]|0,557472,(t=i,i=i+8|0,c[t>>2]=668,t)|0)|0;i=t;aw=0;ax=ad;break L6968}if((_|0)==4986){gGr(aq);c[G>>2]=0}bU(c[u>>2]|0,557472,(t=i,i=i+8|0,c[t>>2]=645,t)|0)|0;i=t;aw=0;ax=Q;break L6968}else{ay=0}}while(0);A=c[u>>2]|0;bU(A|0,557472,(t=i,i=i+8|0,c[t>>2]=686,t)|0)|0;i=t;aw=0;ax=ay}else{A=c[u>>2]|0;bU(A|0,557472,(t=i,i=i+8|0,c[t>>2]=620,t)|0)|0;i=t;aw=0;ax=0}}while(0);aY(z|0)|0;aT=aw;aU=ax}else{ax=c[u>>2]|0;bU(ax|0,557472,(t=i,i=i+8|0,c[t>>2]=617,t)|0)|0;i=t;aY(z|0)|0;aT=0;aU=0}gGr(c[s>>2]|0);gGr(aU);gGr(aT);v=0;i=h;return v|0}function jy(b){b=+b;var d=0,e=0,f=0,h=0,j=0.0,k=0,l=0,m=0,n=0,o=0.0,p=0.0,q=0.0,r=0.0,s=0.0,t=0.0,v=0,w=0,x=0.0,y=0.0,z=0.0,A=0,B=0.0,C=0.0,D=0,E=0,F=0.0,G=0.0,H=0;d=i;e=gGq(28)|0;if((e|0)==0){f=0;i=d;return f|0}if((c[e-4>>2]&3|0)!=0){gGz(e|0,0,28)}gGz(e|0,0,28);h=e+12|0;if(b<1.0){j=b*.825;k=~~+af(+(16.0/b))+3&-4}else{j=.825;k=16}c[h>>2]=k;l=k<<9;m=gGq((l+(k<<2)<<2)+132|0)|0;k=m+132&-128;c[k-4>>2]=m;m=k;c[e+24>>2]=m;if((k|0)==0){gGr(c[m-4>>2]|0);gGr(e);f=0;i=d;return f|0}c[e>>2]=m;c[e+4>>2]=m+(l<<2);k=c[h>>2]|0;n=k<<1;c[e+8>>2]=m+(n+l<<2);b=0.0;o=1.0;p=0.0;q=1.0;r=1.0;l=0;while(1){s=b+r*q/(o*o);t=p+1.0;v=l+1|0;if(v>>>0<18){b=s;o=o*t;p=t;q=q*30.25;r=r*.25;l=v}else{break}}r=+(k|0)*.5;q=+(k<<8|0);if((k|0)>0){l=0;while(1){v=ag(l,n)|0;w=0;do{p=+((w<<8)+l|0)/q*2.0+-1.0;o=j*r*p*3.141592653589793;if(+V(+o)<1.0e-5){x=1.0}else{x=+Z(+o)/o}o=+W(+(1.0-p*p))*5.5;p=o*o;o=0.0;b=1.0;t=0.0;y=1.0;z=1.0;A=0;while(1){B=o+z*y/(b*b);C=t+1.0;D=A+1|0;if(D>>>0<18){o=B;b=b*C;t=C;y=p*y;z=z*.25;A=D}else{break}}g[m+(w+v<<2)>>2]=j*x*B/s;w=w+1|0;}while((w|0)<(k|0));w=l+1|0;if((w|0)<256){l=w}else{E=0;break}}while(1){l=E+1|0;w=ag(l,n)|0;v=E<<1;A=ag(v,k)|0;D=ag(v|1,k)|0;v=0;do{g[m+(v+D<<2)>>2]=+g[m+(v+w<<2)>>2]- +g[m+(v+A<<2)>>2];v=v+1|0;}while((v|0)<(k|0));if((l|0)<255){E=l}else{break}}E=k*510|0;n=k*511|0;v=0;do{B=+((v<<8)+256|0)/q*2.0+-1.0;x=j*r*B*3.141592653589793;if(+V(+x)<1.0e-5){F=1.0}else{F=+Z(+x)/x}x=+W(+(1.0-B*B))*5.5;B=x*x;x=0.0;z=1.0;y=0.0;p=1.0;t=1.0;A=0;while(1){G=x+t*p/(z*z);b=y+1.0;w=A+1|0;if(w>>>0<18){x=G;z=z*b;y=b;p=B*p;t=t*.25;A=w}else{break}}g[m+(v+n<<2)>>2]=j*F*G/s- +g[m+(v+E<<2)>>2];v=v+1|0;}while((v|0)<(k|0))}k=a[9375104]|0;if((k&1)==0){H=k}else{k=c[u>>2]|0;cj(563856,30,1,k|0)|0;eY(k|0)|0;H=a[9375104]|0}if((H&1)==0){f=e;i=d;return f|0}H=c[u>>2]|0;k=c[h>>2]|0;bU(H|0,436936,(h=i,i=i+16|0,c[h>>2]=8,c[h+8>>2]=k,h)|0)|0;i=h;eY(H|0)|0;f=e;i=d;return f|0}function jz(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0.0,F=0,G=0,H=0,I=0,J=0,K=0.0,L=0.0,M=0.0,N=0.0,O=0,P=0.0,Q=0,R=0.0,S=0.0;d=~~(16777216.0/+h[b+16>>3]);e=c[b+8>>2]|0;if((e|0)==0){f=0;i=b+12|0;c[i>>2]=f;return}j=a+20|0;k=a+4|0;l=a+16|0;m=a+8|0;n=a+12|0;o=a;a=c[b>>2]|0;p=c[b+4>>2]|0;q=e;e=0;r=c[j>>2]|0;while(1){L7195:do{if((q|0)==0){s=a;t=r;u=5131}else{v=a;w=q;x=r;while(1){if(x>>>0<=16777215){y=x;z=w;A=v;break L7195}B=c[l>>2]|0;if((B|0)==0){C=c[n>>2]|0;c[l>>2]=C;D=C}else{D=B}B=D-1|0;c[l>>2]=B;E=+g[v>>2];g[(c[k>>2]|0)+(B<<2)>>2]=E;g[(c[k>>2]|0)+((c[n>>2]|0)+(c[l>>2]|0)<<2)>>2]=E;B=v+8|0;E=+g[v+4>>2];g[(c[m>>2]|0)+(c[l>>2]<<2)>>2]=E;g[(c[m>>2]|0)+((c[n>>2]|0)+(c[l>>2]|0)<<2)>>2]=E;C=(c[j>>2]|0)-16777216|0;c[j>>2]=C;F=w-1|0;if((F|0)==0){s=B;t=C;u=5131;break}else{v=B;w=F;x=C}}}}while(0);if((u|0)==5131){u=0;if(t>>>0<16777216){y=t;z=0;A=s}else{f=e;u=5138;break}}x=p;w=e;v=y;do{C=c[k>>2]|0;F=c[l>>2]|0;B=c[m>>2]|0;G=c[n>>2]|0;H=c[o>>2]|0;I=ag(G<<1,v>>>16)|0;J=I+G|0;E=+((v&65535)>>>0>>>0)*152587890625.0e-16;if((G|0)==0){K=0.0;L=0.0}else{M=0.0;N=0.0;O=0;while(1){P=+g[H+(O+I<<2)>>2]+E*+g[H+(J+O<<2)>>2];Q=O+F|0;R=N+ +g[C+(Q<<2)>>2]*P;S=M+ +g[B+(Q<<2)>>2]*P;Q=O+1|0;if(Q>>>0<G>>>0){M=S;N=R;O=Q}else{K=S;L=R;break}}}g[x>>2]=L;g[x+4>>2]=K;x=x+8|0;w=w+1|0;v=(c[j>>2]|0)+d|0;c[j>>2]=v;}while(v>>>0<16777216);if((z|0)==0){f=w;u=5137;break}else{a=A;p=x;q=z;e=w;r=v}}if((u|0)==5138){i=b+12|0;c[i>>2]=f;return}else if((u|0)==5137){i=b+12|0;c[i>>2]=f;return}}function jA(a){a=a|0;if((a|0)==0){gGr(a);return}gGr(c[(c[a+24>>2]|0)-4>>2]|0);gGr(a);return}function jB(a,b,c){a=a|0;b=b|0;c=c|0;return-1|0}function jC(a,b,c){a=a|0;b=b|0;c=c|0;return c|0}function jD(a){a=a|0;return 1}function jE(a){a=a|0;return 1}function jF(a,b){a=a|0;b=b|0;return}function jG(a){a=a|0;return}function jH(a){a=a|0;return 1}function jI(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0;d=i;i=i+8192|0;e=d|0;f=d+4096|0;g=hD(b,9534384,0)|0;if((g|0)==0){h=0;i=d;return h|0}j=gGq(12)|0;do{if((j|0)==0){k=0;l=g+4|0}else{if((c[j-4>>2]&3|0)!=0){gGz(j|0,0,12)}m=j;n=g+4|0;o=c[n>>2]|0;do{if((o|0)==0){p=0}else{q=o*28|0;if(o>>>0<=65535){p=q;break}p=((q>>>0)/(o>>>0)|0|0)==28?q:-1}}while(0);o=gGq(p)|0;if((o|0)==0){k=m;l=n;break}if((c[o-4>>2]&3|0)!=0){gGz(o|0,0,p|0)}q=o;o=j;c[o>>2]=q;r=c[n>>2]|0;s=j+4|0;c[s>>2]=r;t=g|0;do{if((c[n>>2]|0)==0){v=r}else{w=e|0;x=f|0;y=0;while(1){z=bG(c[(c[t>>2]|0)+(y<<3)>>2]|0)|0;A=q+(y*28|0)|0;c[A>>2]=z;if((z|0)==0){B=5165;break}z=c[(c[t>>2]|0)+(y<<3)>>2]|0;C=cE(z|0,47)|0;D=4096;E=0;F=w;G=(C|0)==0?z:C+1|0;while(1){C=D-1|0;if((C|0)==0){B=5172;break}z=a[G]|0;a[F]=z;if(z<<24>>24==0){H=E;break}else{D=C;E=E+1|0;F=F+1|0;G=G+1|0}}do{if((B|0)==5172){B=0;a[F]=0;if((a[G]|0)==0){H=E;break}else{I=G;J=E}while(1){D=I+1|0;C=J+1|0;if((a[D]|0)==0){H=C;break}else{I=D;J=C}}}}while(0);if(H>>>0>=4096){B=5175;break}E=cE(w|0,47)|0;G=cE(((E|0)==0?w:E+1|0)|0,46)|0;if((a[G]|0)!=0){a[G]=0}G=gGy(w|0)|0;E=G>>>0>4096?0:4096-G|0;L7261:do{if((E|0)==0){K=563728;B=5182}else{F=e+G|0;do{if((E|0)==1){L=563728;M=F}else{C=e+(G+1)|0;a[F]=46;if((E|0)==2){L=563729;M=C;break}D=e+(G+2)|0;a[C]=105;if((E|0)==3){L=563730;M=D;break}C=e+(G+3)|0;a[D]=110;if((E|0)==4){L=563731;M=C;break}D=e+(G+4)|0;a[C]=102;if((E|0)==5){L=563732;M=D;break}C=e+(G+5)|0;a[D]=111;if((E|0)==6){L=563733;M=C;break}a[C]=0;break L7261}}while(0);a[M]=0;K=L;B=5182}}while(0);do{if((B|0)==5182){B=0;if((a[K]|0)==0){break}else{N=K}do{N=N+1|0;}while((a[N]|0)!=0)}}while(0);hE(x,(a[9345348]|0)!=0?9345348:b,w);E=hZ(x,0)|0;G=q+(y*28|0)+4|0;c[G>>2]=E;F=q+(y*28|0)+8|0;L7276:do{if((E|0)!=0){C=E+4|0;while(1){O=c[C>>2]|0;if((O|0)==0){P=E;break}if((fa(436792,c[O+4>>2]|0)|0)==0){B=5188;break}else{C=O+12|0}}if((B|0)==5188){B=0;c[F>>2]=bG(c[O+8>>2]|0)|0;P=c[G>>2]|0}C=q+(y*28|0)+12|0;D=P+4|0;while(1){Q=c[D>>2]|0;if((Q|0)==0){break}if((fa(338104,c[Q+4>>2]|0)|0)==0){B=5192;break}else{D=Q+12|0}}do{if((B|0)==5192){B=0;D=bG(c[Q+8>>2]|0)|0;c[C>>2]=D;if((D|0)==0){break}c[q+(y*28|0)+20>>2]=hA(D,256984)|0}}while(0);C=q+(y*28|0)+16|0;D=(c[G>>2]|0)+4|0;while(1){R=c[D>>2]|0;if((R|0)==0){break L7276}if((fa(203424,c[R+4>>2]|0)|0)==0){break}else{D=R+12|0}}D=bG(c[R+8>>2]|0)|0;c[C>>2]=D;if((D|0)==0){break}c[q+(y*28|0)+24>>2]=hA(D,256984)|0}}while(0);if((c[F>>2]|0)==0){G=c[A>>2]|0;E=cE(G|0,47)|0;c[F>>2]=bG(((E|0)==0?G:E+1|0)|0)|0}E=y+1|0;if(E>>>0<(c[n>>2]|0)>>>0){y=E}else{B=5165;break}}if((B|0)==5165){v=c[s>>2]|0;break}else if((B|0)==5175){y=c[u>>2]|0;bU(y|0,547632,(x=i,i=i+16|0,c[x>>2]=551256,c[x+8>>2]=579,x)|0)|0;i=x;eY(y|0)|0;fm(2);return 0}}}while(0);do{if((v|0)==0){S=0;B=5206}else{q=c[o>>2]|0;r=0;y=0;do{x=c[q+(y*28|0)+12>>2]|0;if((x|0)==0){T=0}else{T=(gGy(x|0)|0)+2|0}r=T+r|0;y=y+1|0;}while(y>>>0<v>>>0);if((r|0)==0){S=v;B=5206;break}y=r+4|0;q=gGq(y)|0;do{if((q|0)!=0){if((c[q-4>>2]&3|0)==0){break}gGz(q|0,0,y|0)}}while(0);c[j+8>>2]=q;U=y;V=q;W=v}}while(0);if((B|0)==5206){U=0;V=c[j+8>>2]|0;W=S}r=j+8|0;L7320:do{if((V|0)!=0){if((W|0)==0){X=V}else{x=0;w=W;while(1){E=c[(c[o>>2]|0)+(x*28|0)+12>>2]|0;if((E|0)==0){Y=w}else{G=c[r>>2]|0;D=gGy(G|0)|0;z=D>>>0>U>>>0?0:U-D|0;L7327:do{if((z|0)==0){Z=E;B=5219}else{_=z;$=G+D|0;aa=E;while(1){ab=_-1|0;if((ab|0)==0){break}ac=a[aa]|0;a[$]=ac;if(ac<<24>>24==0){break L7327}else{_=ab;$=$+1|0;aa=aa+1|0}}a[$]=0;Z=aa;B=5219}}while(0);do{if((B|0)==5219){B=0;if((a[Z]|0)==0){break}else{ad=Z}do{ad=ad+1|0;}while((a[ad]|0)!=0)}}while(0);aa=c[r>>2]|0;$=gGy(aa|0)|0;E=$>>>0>U>>>0?0:U-$|0;L7338:do{if((E|0)==0){ae=256984;B=5225}else{D=aa+$|0;do{if((E|0)==1){af=256984;ag=D}else{G=aa+($+1)|0;a[D]=124;if((E|0)==2){af=256985;ag=G;break}a[G]=0;break L7338}}while(0);a[ag]=0;ae=af;B=5225}}while(0);do{if((B|0)==5225){B=0;if((a[ae]|0)==0){break}else{ah=ae}do{ah=ah+1|0;}while((a[ah]|0)!=0)}}while(0);Y=c[s>>2]|0}E=x+1|0;if(E>>>0<Y>>>0){x=E;w=Y}else{break}}X=c[r>>2]|0}w=gGy(X|0)|0;x=w>>>0>U>>>0?0:U-w|0;if((x|0)==0){ai=159416}else{q=X+w|0;do{if((x|0)==1){aj=159416;ak=q}else{y=X+(w+1)|0;a[q]=124;if((x|0)==2){aj=159417;ak=y;break}E=X+(w+2)|0;a[y]=122;if((x|0)==3){aj=159418;ak=E;break}y=X+(w+3)|0;a[E]=105;if((x|0)==4){aj=159419;ak=y;break}E=X+(w+4)|0;a[y]=112;if((x|0)==5){aj=159420;ak=E;break}a[E]=0;break L7320}}while(0);a[ak]=0;ai=aj}if((a[ai]|0)==0){break}else{al=ai}do{al=al+1|0;}while((a[al]|0)!=0)}}while(0);r=c[t>>2]|0;if((c[n>>2]|0)==0){am=r}else{s=0;o=r;while(1){gGr(c[o+(s<<3)>>2]|0);r=s+1|0;x=c[t>>2]|0;if(r>>>0<(c[n>>2]|0)>>>0){s=r;o=x}else{am=x;break}}}gGr(am);gGr(g);h=m;i=d;return h|0}}while(0);am=g|0;al=c[am>>2]|0;if((c[l>>2]|0)==0){an=al}else{ai=0;aj=al;while(1){gGr(c[aj+(ai<<3)>>2]|0);al=ai+1|0;ak=c[am>>2]|0;if(al>>>0<(c[l>>2]|0)>>>0){ai=al;aj=ak}else{an=ak;break}}}gGr(an);gGr(g);jJ(k);h=0;i=d;return h|0}function jJ(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((a|0)==0){return}b=a+4|0;d=a|0;if((c[b>>2]|0)!=0){e=0;do{gGr(c[(c[d>>2]|0)+(e*28|0)>>2]|0);gGr(c[(c[d>>2]|0)+(e*28|0)+8>>2]|0);gGr(c[(c[d>>2]|0)+(e*28|0)+12>>2]|0);gGr(c[(c[d>>2]|0)+(e*28|0)+16>>2]|0);f=c[d>>2]|0;g=c[f+(e*28|0)+20>>2]|0;if((g|0)==0){h=f}else{f=g+4|0;i=g|0;j=c[i>>2]|0;if((c[f>>2]|0)==0){k=j}else{l=0;m=j;while(1){gGr(c[m+(l<<3)>>2]|0);j=l+1|0;n=c[i>>2]|0;if(j>>>0<(c[f>>2]|0)>>>0){l=j;m=n}else{k=n;break}}}gGr(k);gGr(g);h=c[d>>2]|0}m=c[h+(e*28|0)+24>>2]|0;if((m|0)==0){o=h}else{l=m+4|0;f=m|0;i=c[f>>2]|0;if((c[l>>2]|0)==0){p=i}else{n=0;j=i;while(1){gGr(c[j+(n<<3)>>2]|0);i=n+1|0;q=c[f>>2]|0;if(i>>>0<(c[l>>2]|0)>>>0){n=i;j=q}else{p=q;break}}}gGr(p);gGr(m);o=c[d>>2]|0}hY(c[o+(e*28|0)+4>>2]|0);e=e+1|0;}while(e>>>0<(c[b>>2]|0)>>>0)}gGr(c[a+8>>2]|0);gGr(c[d>>2]|0);gGr(a);return}function jK(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;f=i;i=i+4096|0;g=f|0;c[2383496]=b;h=cE(b|0,47)|0;j=cE(((h|0)==0?b:h+1|0)|0,46)|0;do{if((gGF(((j|0)==0?9534384:j+1|0)|0,104560)|0)==0){h=hy()|0;if((h|0)==0){k=0;break}l=h;if(k8(b,4,l)|0){k=h;break}m=c[u>>2]|0;cj(200536,41,1,m|0)|0;eY(m|0)|0;m=h+4|0;n=h|0;h=c[n>>2]|0;if((c[m>>2]|0)==0){o=h}else{p=0;q=h;while(1){gGr(c[q+(p<<3)>>2]|0);h=p+1|0;r=c[n>>2]|0;if(h>>>0<(c[m>>2]|0)>>>0){p=h;q=r}else{o=r;break}}}gGr(o);gGr(l);k=0}else{k=0}}while(0);c[2383498]=k;o=a|0;j=a+4|0;c0(c[o>>2]|0,c[j>>2]|0,28,14430);L7410:do{if((c[j>>2]|0)==0){s=0;t=5316}else{a=(k|0)==0;q=k+4|0;p=k|0;m=g|0;L7412:do{if((b|0)==0){n=0;while(1){r=c[o>>2]|0;if(a|(r+(n*28|0)|0)==0){s=n;t=5316;break L7410}h=r+(n*28|0)+20|0;r=c[h>>2]|0;if((r|0)==0){s=n;t=5316;break L7410}v=c[q>>2]|0;if((v|0)==0){w=n;x=0;break L7412}else{y=0;z=r;A=v}L7451:while(1){v=c[(c[p>>2]|0)+(y<<3)>>2]|0;r=cE(v|0,47)|0;B=cE(((r|0)==0?v:r+1|0)|0,46)|0;r=(B|0)==0?9534384:B+1|0;if((z|0)==0){C=A}else{be(m|0,4096,285248,(D=i,i=i+16|0,c[D>>2]=393632,c[D+8>>2]=r,D)|0)|0;i=D;B=z|0;v=c[z+4>>2]|0;E=0;while(1){if(E>>>0>=v>>>0){break}F=c[(c[B>>2]|0)+(E<<3)>>2]|0;if((gGF(F|0,r|0)|0)==0){break L7451}if((gGF(F|0,m|0)|0)==0){break L7451}else{E=E+1|0}}C=c[q>>2]|0}E=y+1|0;if(E>>>0>=C>>>0){w=n;x=C;break L7412}y=E;z=c[h>>2]|0;A=C}h=n+1|0;if(h>>>0<(c[j>>2]|0)>>>0){n=h}else{s=h;t=5316;break L7410}}}else{if(a){n=0;while(1){h=c[o>>2]|0;if((h+(n*28|0)|0)==0){s=n;t=5316;break L7410}E=c[h+(n*28|0)+20>>2]|0;if((E|0)==0){s=n;t=5316;break L7410}h=cE(b|0,47)|0;r=cE(((h|0)==0?b:h+1|0)|0,46)|0;h=(r|0)==0?9534384:r+1|0;be(m|0,4096,285248,(D=i,i=i+16|0,c[D>>2]=393632,c[D+8>>2]=h,D)|0)|0;i=D;r=E|0;B=c[E+4>>2]|0;E=0;while(1){if(E>>>0>=B>>>0){s=n;t=5316;break L7410}v=c[(c[r>>2]|0)+(E<<3)>>2]|0;if((gGF(v|0,h|0)|0)==0){break}if((gGF(v|0,m|0)|0)==0){break}else{E=E+1|0}}E=n+1|0;if(E>>>0<(c[j>>2]|0)>>>0){n=E}else{s=E;t=5316;break L7410}}}else{G=0}while(1){n=c[o>>2]|0;if((n+(G*28|0)|0)==0){s=G;t=5316;break L7410}E=n+(G*28|0)+20|0;n=c[E>>2]|0;if((n|0)==0){s=G;t=5316;break L7410}h=cE(b|0,47)|0;r=cE(((h|0)==0?b:h+1|0)|0,46)|0;h=(r|0)==0?9534384:r+1|0;be(m|0,4096,285248,(D=i,i=i+16|0,c[D>>2]=393632,c[D+8>>2]=h,D)|0)|0;i=D;r=n|0;B=c[n+4>>2]|0;n=0;while(1){if(n>>>0>=B>>>0){t=5305;break}v=c[(c[r>>2]|0)+(n<<3)>>2]|0;if((gGF(v|0,h|0)|0)==0){break}if((gGF(v|0,m|0)|0)==0){break}else{n=n+1|0}}L7432:do{if((t|0)==5305){t=0;n=c[E>>2]|0;if((n|0)==0){s=G;t=5316;break L7410}h=c[q>>2]|0;if((h|0)==0){w=G;x=0;break L7412}else{H=0;I=n;J=h}while(1){h=c[(c[p>>2]|0)+(H<<3)>>2]|0;n=cE(h|0,47)|0;r=cE(((n|0)==0?h:n+1|0)|0,46)|0;n=(r|0)==0?9534384:r+1|0;if((I|0)==0){K=J}else{be(m|0,4096,285248,(D=i,i=i+16|0,c[D>>2]=393632,c[D+8>>2]=n,D)|0)|0;i=D;r=I|0;h=c[I+4>>2]|0;B=0;while(1){if(B>>>0>=h>>>0){break}v=c[(c[r>>2]|0)+(B<<3)>>2]|0;if((gGF(v|0,n|0)|0)==0){break L7432}if((gGF(v|0,m|0)|0)==0){break L7432}else{B=B+1|0}}K=c[q>>2]|0}B=H+1|0;if(B>>>0>=K>>>0){w=G;x=K;break L7412}H=B;I=c[E>>2]|0;J=K}}}while(0);E=G+1|0;if(E>>>0<(c[j>>2]|0)>>>0){G=E}else{s=E;t=5316;break L7410}}}}while(0);if(a){L=w}else{M=w;N=x;O=p;break}P=c[o>>2]|0;c[d>>2]=P;c[e>>2]=L;i=f;return}}while(0);do{if((t|0)==5316){if((k|0)==0){L=s;P=c[o>>2]|0;c[d>>2]=P;c[e>>2]=L;i=f;return}else{M=s;N=c[k+4>>2]|0;O=k|0;break}}}while(0);s=k+4|0;t=c[O>>2]|0;if((N|0)==0){Q=t}else{N=0;x=t;while(1){gGr(c[x+(N<<3)>>2]|0);t=N+1|0;w=c[O>>2]|0;if(t>>>0<(c[s>>2]|0)>>>0){N=t;x=w}else{Q=w;break}}}gGr(Q);gGr(k);L=M;P=c[o>>2]|0;c[d>>2]=P;c[e>>2]=L;i=f;return}function jL(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;d=i;i=i+4096|0;e=d|0;f=c[2383498]|0;g=(a|0)==0;L7477:do{if((f|0)==0|g){h=5338}else{j=a+20|0;k=c[j>>2]|0;if((k|0)==0){h=5338;break}l=f+4|0;m=f|0;n=c[l>>2]|0;if((n|0)==0){h=5338;break}o=e|0;p=0;q=k;k=n;while(1){n=c[(c[m>>2]|0)+(p<<3)>>2]|0;r=cE(n|0,47)|0;s=cE(((r|0)==0?n:r+1|0)|0,46)|0;r=(s|0)==0?9534384:s+1|0;if((q|0)==0){t=k}else{be(o|0,4096,285248,(u=i,i=i+16|0,c[u>>2]=393632,c[u+8>>2]=r,u)|0)|0;i=u;s=q|0;n=c[q+4>>2]|0;v=0;while(1){if(v>>>0>=n>>>0){break}w=c[(c[s>>2]|0)+(v<<3)>>2]|0;if((gGF(w|0,r|0)|0)==0){x=1;break L7477}if((gGF(w|0,o|0)|0)==0){x=1;break L7477}else{v=v+1|0}}t=c[l>>2]|0}v=p+1|0;if(v>>>0>=t>>>0){h=5338;break L7477}p=v;q=c[j>>2]|0;k=t}}}while(0);L7492:do{if((h|0)==5338){t=c[2383496]|0;if((t|0)==0|g){x=0;break}f=c[a+20>>2]|0;if((f|0)==0){x=0;break}k=cE(t|0,47)|0;j=cE(((k|0)==0?t:k+1|0)|0,46)|0;k=(j|0)==0?9534384:j+1|0;j=e|0;be(j|0,4096,285248,(u=i,i=i+16|0,c[u>>2]=393632,c[u+8>>2]=k,u)|0)|0;i=u;t=f|0;q=c[f+4>>2]|0;f=0;while(1){if(f>>>0>=q>>>0){x=0;break L7492}p=c[(c[t>>2]|0)+(f<<3)>>2]|0;if((gGF(p|0,k|0)|0)==0){x=1;break L7492}if((gGF(p|0,j|0)|0)==0){x=1;break}else{f=f+1|0}}}}while(0);g=c[2383498]|0;f=(b|0)==0;L7501:do{if((g|0)==0|f){h=5356}else{j=b+20|0;k=c[j>>2]|0;if((k|0)==0){h=5356;break}t=g+4|0;q=g|0;p=c[t>>2]|0;if((p|0)==0){h=5356;break}l=e|0;o=0;m=k;k=p;while(1){p=c[(c[q>>2]|0)+(o<<3)>>2]|0;v=cE(p|0,47)|0;r=cE(((v|0)==0?p:v+1|0)|0,46)|0;v=(r|0)==0?9534384:r+1|0;if((m|0)==0){y=k}else{be(l|0,4096,285248,(u=i,i=i+16|0,c[u>>2]=393632,c[u+8>>2]=v,u)|0)|0;i=u;r=m|0;p=c[m+4>>2]|0;s=0;while(1){if(s>>>0>=p>>>0){break}n=c[(c[r>>2]|0)+(s<<3)>>2]|0;if((gGF(n|0,v|0)|0)==0){z=1;break L7501}if((gGF(n|0,l|0)|0)==0){z=1;break L7501}else{s=s+1|0}}y=c[t>>2]|0}s=o+1|0;if(s>>>0>=y>>>0){h=5356;break L7501}o=s;m=c[j>>2]|0;k=y}}}while(0);L7516:do{if((h|0)==5356){y=c[2383496]|0;if((y|0)==0|f){z=0;break}g=c[b+20>>2]|0;if((g|0)==0){z=0;break}k=cE(y|0,47)|0;j=cE(((k|0)==0?y:k+1|0)|0,46)|0;k=(j|0)==0?9534384:j+1|0;j=e|0;be(j|0,4096,285248,(u=i,i=i+16|0,c[u>>2]=393632,c[u+8>>2]=k,u)|0)|0;i=u;y=g|0;m=c[g+4>>2]|0;g=0;while(1){if(g>>>0>=m>>>0){z=0;break L7516}o=c[(c[y>>2]|0)+(g<<3)>>2]|0;if((gGF(o|0,k|0)|0)==0){z=1;break L7516}if((gGF(o|0,j|0)|0)==0){z=1;break}else{g=g+1|0}}}}while(0);if((x|0)==(z|0)){A=gGF(c[a+8>>2]|0,c[b+8>>2]|0)|0;i=d;return A|0}else{A=z-x|0;i=d;return A|0}return 0}function jM(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;d=i;i=i+4096|0;e=d|0;f=b+20816|0;g=f;gGz(f|0,0,109464);f=b+8500|0;L7531:do{if((a[9395610]|0)==0){a[f]=114;a[b+8501|0]=103;a[b+8502|0]=117;a[b+8503|0]=105;a[b+8504|0]=46;a[b+8505|0]=103;a[b+8506|0]=108;a[b+8507|0]=115;a[b+8508|0]=108;a[b+8509|0]=112;a[b+8510|0]=0;a[b+12596|0]=114;a[b+12597|0]=103;a[b+12598|0]=117;a[b+12599|0]=105;a[b+12600|0]=46;a[b+12601|0]=99;a[b+12602|0]=103;a[b+12603|0]=112;a[b+12604|0]=0}else{h=cE(9395610,47)|0;j=4096;k=0;l=f;m=(h|0)==0?9395610:h+1|0;while(1){h=j-1|0;if((h|0)==0){n=5372;break}o=a[m]|0;a[l]=o;if(o<<24>>24==0){p=k;break}else{j=h;k=k+1|0;l=l+1|0;m=m+1|0}}do{if((n|0)==5372){a[l]=0;if((a[m]|0)==0){p=k;break}else{q=m;r=k}while(1){j=q+1|0;h=r+1|0;if((a[j]|0)==0){p=h;break}else{q=j;r=h}}}}while(0);if(p>>>0>=4096){k=c[u>>2]|0;bU(k|0,547632,(s=i,i=i+16|0,c[s>>2]=551256,c[s+8>>2]=579,s)|0)|0;i=s;eY(k|0)|0;fm(2)}k=cE(f|0,47)|0;m=cE(((k|0)==0?f:k+1|0)|0,46)|0;if((a[m]|0)!=0){a[m]=0}m=gGy(f|0)|0;k=m>>>0>4096?0:4096-m|0;L7547:do{if((k|0)==0){t=514376;n=5382}else{l=b+(m+8500)|0;do{if((k|0)==1){v=514376;w=l}else{h=b+(m+8501)|0;a[l]=46;if((k|0)==2){v=514377;w=h;break}j=b+(m+8502)|0;a[h]=103;if((k|0)==3){v=514378;w=j;break}h=b+(m+8503)|0;a[j]=108;if((k|0)==4){v=514379;w=h;break}j=b+(m+8504)|0;a[h]=115;if((k|0)==5){v=514380;w=j;break}h=b+(m+8505)|0;a[j]=108;if((k|0)==6){v=514381;w=h;break}j=b+(m+8506)|0;a[h]=112;if((k|0)==7){v=514382;w=j;break}a[j]=0;break L7547}}while(0);a[w]=0;t=v;n=5382}}while(0);do{if((n|0)==5382){if((a[t]|0)==0){break}else{x=t}do{x=x+1|0;}while((a[x]|0)!=0)}}while(0);k=b+12596|0;m=cE(9395610,47)|0;l=4096;j=0;h=k;o=(m|0)==0?9395610:m+1|0;while(1){m=l-1|0;if((m|0)==0){n=5387;break}y=a[o]|0;a[h]=y;if(y<<24>>24==0){z=j;break}else{l=m;j=j+1|0;h=h+1|0;o=o+1|0}}do{if((n|0)==5387){a[h]=0;if((a[o]|0)==0){z=j;break}else{A=o;B=j}while(1){l=A+1|0;m=B+1|0;if((a[l]|0)==0){z=m;break}else{A=l;B=m}}}}while(0);if(z>>>0>=4096){j=c[u>>2]|0;bU(j|0,547632,(s=i,i=i+16|0,c[s>>2]=551256,c[s+8>>2]=579,s)|0)|0;i=s;eY(j|0)|0;fm(2)}j=cE(k|0,47)|0;o=cE(((j|0)==0?k:j+1|0)|0,46)|0;if((a[o]|0)!=0){a[o]=0}o=gGy(k|0)|0;j=o>>>0>4096?0:4096-o|0;if((j|0)==0){C=563632}else{h=b+(o+12596)|0;do{if((j|0)==1){D=563632;E=h}else{m=b+(o+12597)|0;a[h]=46;if((j|0)==2){D=563633;E=m;break}l=b+(o+12598)|0;a[m]=99;if((j|0)==3){D=563634;E=l;break}m=b+(o+12599)|0;a[l]=103;if((j|0)==4){D=563635;E=m;break}l=b+(o+12600)|0;a[m]=112;if((j|0)==5){D=563636;E=l;break}a[l]=0;break L7531}}while(0);a[E]=0;C=D}if((a[C]|0)==0){break}else{F=C}do{F=F+1|0;}while((a[F]|0)!=0)}}while(0);F=cE(9263600,47)|0;C=cE(((F|0)==0?9263600:F+1|0)|0,46)|0;F=(C|0)==0?9534384:C+1|0;do{if((fa(F|0,558744)|0)!=0){if((fa(F|0,203216)|0)==0){break}do{if((fa(F|0,471856)|0)!=0){if((fa(F|0,128928)|0)==0){break}C=(a[9271801]|0)!=0?9271801:9361732;D=e|0;hE(D,C,436560);E=hZ(D,0)|0;do{if((E|0)==0){hE(D,C,337968);s=hZ(D,0)|0;if((s|0)!=0){G=s;break}i=d;return}else{G=E}}while(0);if(jn(G,g)|0){jq(g,D)}hY(G);i=d;return}}while(0);E=4096;C=b+20892|0;s=9263600;while(1){z=E-1|0;if((z|0)==0){n=5410;break}B=a[s]|0;a[C]=B;if(B<<24>>24==0){break}else{E=z;C=C+1|0;s=s+1|0}}do{if((n|0)==5410){a[C]=0;if((a[s]|0)==0){break}else{H=s}do{H=H+1|0;}while((a[H]|0)!=0)}}while(0);c[b+20888>>2]=1;i=d;return}}while(0);b=hZ(9263600,0)|0;if((b|0)==0){i=d;return}if(jn(b,g)|0){jq(g,9263600)}hY(b);i=d;return}function jN(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;if((a[9375104]&1)!=0){g=c[u>>2]|0;h=(e|0)!=0?e:80584;bU(g|0,104464,(j=i,i=i+8|0,c[j>>2]=h,j)|0)|0;i=j;eY(g|0)|0}if(!(gp[c[(c[2383355]|0)+20>>2]&16383](c[2383358]|0,d,e)|0)){d=c[u>>2]|0;cj(571072,46,1,d|0)|0;eY(d|0)|0;a[9267696]=0;i=f;return}d=(e|0)!=0;g=4096;j=9263600;h=d?e:9534384;while(1){k=g-1|0;if((k|0)==0){l=5441;break}m=a[h]|0;a[j]=m;if(m<<24>>24==0){break}else{g=k;j=j+1|0;h=h+1|0}}do{if((l|0)==5441){a[j]=0;if((a[h]|0)==0){break}else{n=h}do{n=n+1|0;}while((a[n]|0)!=0)}}while(0);a[9267696]=1;if((b|0)==0|d^1){i=f;return}d=hZ(e,0)|0;if((d|0)!=0){jn(d,b)|0;jq(b,e);hY(d)}a[(c[2112498]|0)+60|0]=1;i=f;return}function jO(d,e){d=d|0;e=e|0;var f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0.0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0,cf=0,cg=0,ch=0,ci=0,ck=0,cl=0,cm=0,cn=0,co=0,cp=0,cq=0,cr=0,cs=0,ct=0,cu=0,cv=0,cw=0,cx=0,cy=0,cz=0,cA=0,cB=0;f=i;i=i+34216|0;h=f|0;j=f+8|0;k=f+16|0;l=f+4112|0;m=f+8208|0;n=f+9232|0;o=f+13328|0;p=f+13584|0;q=f+13600|0;r=f+14112|0;s=f+14368|0;t=f+16248|0;v=f+16272|0;w=f+16336|0;x=f+17360|0;y=f+17744|0;z=f+17816|0;A=f+21912|0;B=f+26008|0;C=f+30104|0;D=f+34200|0;E=f+34208|0;F=d+48|0;G=c[F>>2]|0;H=c[G+8>>2]|0;if((H|0)==0){I=0;J=0}else{K=H-1|0;H=c[G>>2]|0;I=c[H+(K<<4)+8>>2]|0;J=c[H+(K<<4)>>2]|0}do{if((c[2161332]|0)!=0){K=c[2383406]|0;if((K|0)==0){break}if((c[K+24>>2]|0)==0){break}gq[c[K+20>>2]&15](c[2383358]|0,8453328,0,c[d+28>>2]|0,c[d+32>>2]|0,1.0)}}while(0);switch(I|0){case 5:{K=w|0;w=x|0;H=y;if((c[2161332]|0)!=0){jZ(d)}G=y+8|0;L=y|0;M=y+9|0;N=y+10|0;O=y+11|0;P=y+12|0;Q=y+13|0;R=y+14|0;S=y+15|0;y=0;do{T=c[2383356]|0;L8513:do{if((T|0)==0){U=5469}else{V=T+20|0;if((c[V>>2]|0)==0){U=5469;break}a[G]=85;a[M]=110;a[N]=107;a[O]=110;a[P]=111;a[Q]=119;a[R]=110;a[S]=0;W=9288400+((c[10064+(y<<2)>>2]|0)*40|0)|0;X=c[W+4>>2]|0;c[L>>2]=c[W>>2];c[L+4>>2]=X;ge[c[V>>2]&63](H,0,0,0,64);V=64;X=x+(y<<6)|0;W=G;while(1){Y=V-1|0;if((Y|0)==0){break}Z=a[W]|0;a[X]=Z;if(Z<<24>>24==0){break L8513}else{V=Y;X=X+1|0;W=W+1|0}}a[X]=0;if((a[W]|0)==0){break}else{_=W}do{_=_+1|0;}while((a[_]|0)!=0)}}while(0);if((U|0)==5469){U=0;iA(x+(y<<6)|0,9288384+((c[10064+(y<<2)>>2]|0)*40|0)|0,64)}y=y+1|0;}while(y>>>0<6);be(K|0,1024,549320,($=i,i=i+48|0,c[$>>2]=w,c[$+8>>2]=x+64,c[$+16>>2]=x+128,c[$+24>>2]=x+192,c[$+32>>2]=x+256,c[$+40>>2]=x+320,$)|0)|0;i=$;if((c[2161332]|0)!=0){jY(d,K)}if((e|0)!=4){aa=0;i=f;return aa|0}K=c[F>>2]|0;x=d+56|0;w=K+8|0;y=c[w>>2]|0;if((y|0)!=0){_=y-1|0;c[w>>2]=_;gGr(c[(c[K>>2]|0)+(_<<4)>>2]|0)}if((x|0)==0){aa=0;i=f;return aa|0}c[x>>2]=c[(c[K>>2]|0)+(c[w>>2]<<4)+12>>2];aa=0;i=f;return aa|0};case 78:case 71:case 70:case 69:case 67:case 66:case 30:case 6:case 4:case 68:{c[d+40>>2]=c[d+28>>2]<<1;do{if((e|0)==6){ab=0;ac=0}else{w=c[d+56>>2]|0;K=c[c[d+52>>2]>>2]|0;x=c[K+(w<<4)+8>>2]|0;if((x|0)==64){ab=9369961;ac=64;break}else if((x|0)==62){ab=9534384;ac=62;break}else if((x|0)==80){ab=d+4404|0;ac=80;break}else{ab=c[K+(w<<4)>>2]|0;ac=x;break}}}while(0);x=c[F>>2]|0;w=x+8|0;K=c[w>>2]|0;if((K|0)==0){ad=0}else{ad=c[(c[x>>2]|0)+(K-1<<4)+8>>2]|0}_=d+60|0;y=(a[_]&1)==0?e:13;L8550:do{switch(y|0){case 1:{G=d+56|0;H=(c[G>>2]|0)+1|0;if(H>>>0<(c[(c[d+52>>2]|0)+8>>2]|0)>>>0){c[G>>2]=H;break L8550}else{c[G>>2]=0;break L8550}break};case 0:{G=d+56|0;H=c[G>>2]|0;if((H|0)==0){c[G>>2]=(c[(c[d+52>>2]|0)+8>>2]|0)-1;break L8550}else{c[G>>2]=H-1;break L8550}break};case 2:case 3:case 4:case 7:{H=(y|0)==4;if((ac-59|0)>>>0<2&H){a[d+68|0]=(ac|0)==60|0;G=d+4404|0;L=d+56|0;S=c[L>>2]|0;if((x|0)!=0){R=x+4|0;Q=c[R>>2]|0;if((c[w>>2]|0)>>>0<Q>>>0){ae=x|0}else{P=(Q<<1)+2|0;c[R>>2]=P;R=x|0;c[R>>2]=gGs(c[R>>2]|0,P<<4)|0;ae=R}R=bG(G|0)|0;c[(c[ae>>2]|0)+(c[w>>2]<<4)>>2]=R;c[(c[ae>>2]|0)+(c[w>>2]<<4)+4>>2]=0;c[(c[ae>>2]|0)+(c[w>>2]<<4)+8>>2]=1;c[(c[ae>>2]|0)+(c[w>>2]<<4)+12>>2]=S;c[w>>2]=(c[w>>2]|0)+1}c[L>>2]=0;a[_]=1;break L8550}L8570:do{switch(ac|0){case 78:case 71:case 70:case 69:case 67:case 66:case 30:case 6:case 4:case 68:{U=5516;break};case 61:{if(H){af=61;U=5510}else{ag=0}break};default:{L=ac-35|0;if(L>>>0<24){if(((L>>>0)%3|0|0)==0){U=5516;break L8570}}else{if((ac|0)==32){ag=0;break L8570}}if(((ac-87|0)>>>0<3|(ac|0)==91|(ac|0)==92|(ac|0)==93|(ac|0)==90|(ac|0)==94|(ac|0)==86|(ac|0)==95)&H){af=ac;U=5510}else{U=5516}}}}while(0);L8577:do{if((U|0)==5516){switch(ac|0){case 78:case 71:case 70:case 69:case 67:case 66:case 30:case 6:case 4:case 68:{ag=1;break L8577;break};default:{}}ag=0}else if((U|0)==5510){L=d+56|0;S=c[L>>2]|0;if((x|0)!=0){R=x+4|0;G=c[R>>2]|0;if(K>>>0<G>>>0){ah=x|0}else{P=(G<<1)+2|0;c[R>>2]=P;R=x|0;c[R>>2]=gGs(c[R>>2]|0,P<<4)|0;ah=R}R=bG(9534384)|0;c[(c[ah>>2]|0)+(c[w>>2]<<4)>>2]=R;c[(c[ah>>2]|0)+(c[w>>2]<<4)+4>>2]=0;c[(c[ah>>2]|0)+(c[w>>2]<<4)+8>>2]=af;c[(c[ah>>2]|0)+(c[w>>2]<<4)+12>>2]=S;c[w>>2]=(c[w>>2]|0)+1}c[L>>2]=0;a[_]=1;break L8550}}while(0);if((ag|(ac|0)==62|(ac|0)==64|(ac|0)==80)&H){L=d+56|0;S=c[L>>2]|0;if((x|0)!=0){R=x+4|0;P=c[R>>2]|0;if(K>>>0<P>>>0){ai=x|0}else{G=(P<<1)+2|0;c[R>>2]=G;R=x|0;c[R>>2]=gGs(c[R>>2]|0,G<<4)|0;ai=R}R=bG(ab|0)|0;c[(c[ai>>2]|0)+(c[w>>2]<<4)>>2]=R;c[(c[ai>>2]|0)+(c[w>>2]<<4)+4>>2]=0;c[(c[ai>>2]|0)+(c[w>>2]<<4)+8>>2]=ac;c[(c[ai>>2]|0)+(c[w>>2]<<4)+12>>2]=S;c[w>>2]=(c[w>>2]|0)+1}c[L>>2]=0;a[_]=1;break L8550}if((ac|0)==15&H){L=c[d+56>>2]|0;if((x|0)!=0){S=x+4|0;R=c[S>>2]|0;if(K>>>0<R>>>0){aj=x|0}else{G=(R<<1)+2|0;c[S>>2]=G;S=x|0;c[S>>2]=gGs(c[S>>2]|0,G<<4)|0;aj=S}S=bG(9534384)|0;c[(c[aj>>2]|0)+(c[w>>2]<<4)>>2]=S;c[(c[aj>>2]|0)+(c[w>>2]<<4)+4>>2]=0;c[(c[aj>>2]|0)+(c[w>>2]<<4)+8>>2]=15;c[(c[aj>>2]|0)+(c[w>>2]<<4)+12>>2]=L;c[w>>2]=(c[w>>2]|0)+1}gg[c[(c[2383355]|0)+40>>2]&4095](c[2383358]|0,9532068);g[16233]=+((c[2383019]|0)>>>0>>>0)/+((c[2383020]|0)>>>0>>>0);c[2315898]=7;L=c[(c[2383406]|0)+12>>2]|0;if((L|0)==0){break L8550}gg[L&4095](c[2383358]|0,7);break L8550}do{if((ac-31|0)>>>0<28){L=ac-35|0;S=ac-36|0;G=ac-37|0;if((ac|0)==31){if((y|0)==7){a[9263580]=1;break L8550}else if((y|0)==2|(y|0)==3|(y|0)==4){a[9263580]=a[9263580]&1^1;break L8550}else{break L8550}}if((ac-33|0)>>>0<2){ak=jV(d,ac,y)|0;break}R=(ac|0)==32;if(!(((L>>>0)%3|0|0)==0|R)){if(((S>>>0)%3|0|0)==0){P=(S>>>0)/3|0;S=d+20892|0;if((y|0)==7){c[S+(P*4144|0)+4132>>2]=0;break L8550}else if((y|0)==2|(y|0)==3|(y|0)==4){Q=S+(P*4144|0)+4132|0;c[Q>>2]=(((c[Q>>2]|0)+((y|0)==2?2:1)|0)>>>0)%3|0;break L8550}else{break L8550}}if(((G>>>0)%3|0|0)!=0){break L8550}Q=(G>>>0)/3|0;G=d+20892|0;if((y|0)==7){g[G+(Q*4144|0)+4116>>2]=0.0;g[G+(Q*4144|0)+4112>>2]=0.0;a[G+(Q*4144|0)+4129|0]=0;break L8550}else if((y|0)==2|(y|0)==3|(y|0)==4){P=G+(Q*4144|0)+4112|0;S=((~~+g[P>>2]+((y|0)==2?5:1)|0)>>>0)%6|0;a[G+(Q*4144|0)+4129|0]=(S|0)!=0|0;al=+(S>>>0>>>0);g[G+(Q*4144|0)+4116>>2]=al;g[P>>2]=al;break L8550}else{break L8550}}if(R){am=d+20892+(((L>>>0)/3|0)*4144|0)|0}else{am=0}if((y|0)==7){if((am|0)==0){break L8550}a[am|0]=0;break L8550}else if((y|0)!=4){break L8550}L=d+56|0;R=c[L>>2]|0;if((x|0)!=0){P=x+4|0;Q=c[P>>2]|0;if(K>>>0<Q>>>0){an=x|0}else{G=(Q<<1)+2|0;c[P>>2]=G;P=x|0;c[P>>2]=gGs(c[P>>2]|0,G<<4)|0;an=P}P=bG(9271801)|0;c[(c[an>>2]|0)+(c[w>>2]<<4)>>2]=P;c[(c[an>>2]|0)+(c[w>>2]<<4)+4>>2]=0;c[(c[an>>2]|0)+(c[w>>2]<<4)+8>>2]=ac;c[(c[an>>2]|0)+(c[w>>2]<<4)+12>>2]=R;c[w>>2]=(c[w>>2]|0)+1}c[L>>2]=0;a[_]=1;break L8550}else{if(ac>>>0<=65535){ak=jV(d,ac,y)|0;break}L=ac-65536|0;if((y|0)==7){R=c[2368540]|0;c[(c[R+4100>>2]|0)+(L<<4)+12>>2]=0;a[R+4108|0]=1;break L8550}else if((y|0)==2){R=c[2368540]|0;P=c[R+4100>>2]|0;G=P+(L<<4)+12|0;Q=c[(c[P+(L<<4)+8>>2]|0)+4>>2]|0;c[G>>2]=(((c[G>>2]|0)-1+Q|0)>>>0)%(Q>>>0)|0;a[R+4108|0]=1;break L8550}else if((y|0)==3|(y|0)==4){R=c[2368540]|0;Q=c[R+4100>>2]|0;G=Q+(L<<4)+12|0;c[G>>2]=(((c[G>>2]|0)+1|0)>>>0)%((c[(c[Q+(L<<4)+8>>2]|0)+4>>2]|0)>>>0)|0;a[R+4108|0]=1;break L8550}else{break L8550}}}while(0);if((ak|0)==0){break L8550}else{aa=ak}i=f;return aa|0};case 5:{if(K>>>0<=1){break L8550}H=d+56|0;R=K-1|0;c[w>>2]=R;L=x|0;gGr(c[(c[L>>2]|0)+(R<<4)>>2]|0);if((H|0)!=0){c[H>>2]=c[(c[L>>2]|0)+(c[w>>2]<<4)+12>>2]}a[_]=1;break};case 6:{c[d+56>>2]=0;a[_]=1;break};case 8:{a[d+61|0]=1;break};default:{}}}while(0);w=c[F>>2]|0;x=c[w+8>>2]|0;if((x|0)==0){ao=ad}else{ao=c[(c[w>>2]|0)+(x-1<<4)+8>>2]|0}L8669:do{if(!((a[_]&1)==0|(ao|0)==1)){switch(ao|0){case 4:case 6:case 30:case 66:case 67:case 68:case 69:case 70:case 71:case 78:{break};default:{x=ao-35|0;if(x>>>0<24){if(((x>>>0)%3|0|0)==0){break L8669}}else{if((ao|0)==32){break L8669}}if((ao-87|0)>>>0<3|(ao|0)==91|(ao|0)==92|(ao|0)==93|(ao|0)==90|(ao|0)==94|(ao|0)==86|(ao|0)==95){break L8669}switch(ao|0){case 104:case 80:case 64:case 62:case 61:{break L8669;break};default:{}}}}a[_]=0;if((ao-68|0)>>>0<4|(ao|0)==66|(ao|0)==67|(ao|0)==78|(ao|0)==6|(ao|0)==30){jR(d,ao);break}else{jR(d,4);break}}}while(0);if((c[2161332]|0)!=0){jZ(d)}ao=d+62|0;if((a[ao]&1)==0){aa=0;i=f;return aa|0}a[ao]=0;ao=c[F>>2]|0;if((ao|0)==0){aa=0;i=f;return aa|0}_=ao+8|0;x=ao+4|0;w=c[x>>2]|0;if((c[_>>2]|0)>>>0<w>>>0){ap=ao|0}else{ad=(w<<1)+2|0;c[x>>2]=ad;x=ao|0;c[x>>2]=gGs(c[x>>2]|0,ad<<4)|0;ap=x}x=bG(9534384)|0;c[(c[ap>>2]|0)+(c[_>>2]<<4)>>2]=x;c[(c[ap>>2]|0)+(c[_>>2]<<4)+4>>2]=0;c[(c[ap>>2]|0)+(c[_>>2]<<4)+8>>2]=5;c[(c[ap>>2]|0)+(c[_>>2]<<4)+12>>2]=0;c[_>>2]=(c[_>>2]|0)+1;aa=0;i=f;return aa|0};default:{_=I-35|0;ap=(I|0)==32;do{if(!(_>>>0>23&ap)){if((I-15|0)>>>0>=2){if((I|0)!=166){break}x=r|0;ad=s;if((c[2161332]|0)!=0){jZ(d)}ao=d+130296|0;w=ao;K=c[46700+(((c[d+130300>>2]|0)-110|0)*20|0)>>2]|0;be(x|0,256,560424,($=i,i=i+8|0,c[$>>2]=K,$)|0)|0;i=$;if((c[2161332]|0)!=0){jY(d,x)}gGC(ad|0,ao|0,1876)|0;jT(s);if((a[s+1872|0]&1)==0){aq=0;U=5669}else{if((a[d+132168|0]&1)==0){U=5690}else{aq=0;U=5669}}L7670:do{if((U|0)==5669){L7671:while(1){U=0;ar=0;while(1){if((a[s+16+(aq*104|0)+ar|0]&1)!=0){if((a[w+16+(aq*104|0)+ar|0]&1)==0){U=5672;break L7671}}x=ar+1|0;if(x>>>0<32){ar=x}else{as=0;break}}while(1){at=b[s+16+(aq*104|0)+32+(as<<1)>>1]|0;x=at<<16>>16;au=s+848+(aq<<7)+64+(as<<1)|0;K=x-(b[au>>1]|0)|0;ak=x-(b[s+848+(aq<<7)+(as<<1)>>1]|0)|0;y=(((K|0)>-1?K:-K|0)|0)>19999;if(((at<<16>>16>-1?x:-x|0)|0)>19999&y&(((ak|0)>-1?ak:-ak|0)|0)>19999){U=5675;break L7671}if(y){b[au>>1]=0}y=as+1|0;if(y>>>0<32){as=y}else{av=0;break}}while(1){if(av>>>0>=4){break}y=b[s+16+(aq*104|0)+96+(av<<1)>>1]&~b[w+16+(aq*104|0)+96+(av<<1)>>1]&65535;if((y&32768|0)!=0){aw=-32768;U=5687;break L7671}if((y&16384|0)!=0){aw=16384;U=5687;break L7671}if((y&8192|0)!=0){aw=8192;U=5687;break L7671}ak=(y&4096|0)==0;if(ak){av=av+1|0}else{aw=ak?0:4096;U=5687;break L7671}}ak=aq+1|0;if(ak>>>0<8){aq=ak;U=5669}else{break L7670}}if((U|0)==5687){ak=ao;y=(c[ak>>2]|0)+16|0;c[y>>2]=aw&65535|av&4095;c[y+4>>2]=0;c[(c[ak>>2]|0)+32>>2]=-1}else if((U|0)==5672){ak=ao;y=(c[ak>>2]|0)+16|0;c[y>>2]=ar;c[y+4>>2]=0;c[(c[ak>>2]|0)+32>>2]=-1}else if((U|0)==5675){ak=at<<16>>16>0;if(ak){ax=as|-65536}else{ax=as<<16|65535}y=ao;c[(c[y>>2]|0)+32>>2]=ax;x=(c[y>>2]|0)+16|0;c[x>>2]=65535;c[x+4>>2]=0;b[au>>1]=ak?32767:-32767}c[9324268+(c[d+130308>>2]<<2)>>2]=aq;U=5690}}while(0);if((U|0)==5690){w=s+4|0;ak=(c[w>>2]|0)+1|0;c[w>>2]=ak;do{if(ak>>>0>(c[s+8>>2]|0)>>>0){w=c[F>>2]|0;x=d+56|0;y=w+8|0;K=c[y>>2]|0;if((K|0)!=0){ac=K-1|0;c[y>>2]=ac;gGr(c[(c[w>>2]|0)+(ac<<4)>>2]|0)}if((x|0)==0){break}c[x>>2]=c[(c[w>>2]|0)+(c[y>>2]<<4)+12>>2]}else{y=s|0;c[y>>2]=(c[y>>2]|0)+40}}while(0);ak=d+8|0;c[ak>>2]=0;c[ak+4>>2]=0;ak=d;c[ak>>2]=-1;c[ak+4>>2]=-1}gGC(ao|0,ad|0,1876)|0;aa=0;i=f;return aa|0}ak=v|0;y=c[F>>2]|0;w=y+8|0;x=c[w>>2]|0;ac=(x|0)==0;if(ac){ay=0}else{ay=c[(c[y>>2]|0)+(x-1<<4)+8>>2]|0}K=(a[9263589]&1)==0;an=K?1:c[2367346]|0;am=K?1:c[2367347]|0;L7716:do{switch(e|0){case 3:{do{if((ay|0)==15){c[2383017]=(c[2383017]|0)+an;aj=c[2383019]|0;if(aj>>>0<an>>>0){break}c[2383019]=aj-an}else{c[2383019]=(c[2383019]|0)+an}}while(0);aj=c[(c[2383406]|0)+16>>2]|0;if((aj|0)==0){break L7716}gf[aj&2047](c[2383358]|0);break};case 1:{do{if((ay|0)==15){c[2383018]=(c[2383018]|0)+am;aj=c[2383020]|0;if(aj>>>0<am>>>0){break}c[2383020]=aj-am}else{c[2383020]=(c[2383020]|0)+am}}while(0);aj=c[(c[2383406]|0)+16>>2]|0;if((aj|0)==0){break L7716}gf[aj&2047](c[2383358]|0);break};case 7:{if(!K){break L7716}gg[c[(c[2383355]|0)+40>>2]&4095](c[2383358]|0,t);if((ay|0)==15){c[2383019]=(c[2383019]|0)+(c[2383017]|0);c[2383020]=(c[2383020]|0)+(c[2383018]|0);c[2383017]=0;c[2383018]=0}else{c[2383019]=(c[t+16>>2]|0)-(c[2383017]|0);c[2383020]=(c[t+20>>2]|0)-(c[2383018]|0)}aj=c[(c[2383406]|0)+16>>2]|0;if((aj|0)==0){break L7716}gf[aj&2047](c[2383358]|0);break};case 5:{aj=d+56|0;ai=aj;if(!ac){ab=x-1|0;c[w>>2]=ab;gGr(c[(c[y>>2]|0)+(ab<<4)>>2]|0)}if((aj|0)!=0){c[ai>>2]=c[(c[y>>2]|0)+(c[w>>2]<<4)+12>>2]}if((ay|0)!=16){break L7716}aj=c[F>>2]|0;ab=c[ai>>2]|0;if((aj|0)==0){break L7716}ai=aj+8|0;ag=aj+4|0;ah=c[ag>>2]|0;if((c[ai>>2]|0)>>>0<ah>>>0){az=aj|0}else{af=(ah<<1)+2|0;c[ag>>2]=af;ag=aj|0;c[ag>>2]=gGs(c[ag>>2]|0,af<<4)|0;az=ag}ag=bG(9534384)|0;c[(c[az>>2]|0)+(c[ai>>2]<<4)>>2]=ag;c[(c[az>>2]|0)+(c[ai>>2]<<4)+4>>2]=0;c[(c[az>>2]|0)+(c[ai>>2]<<4)+8>>2]=15;c[(c[az>>2]|0)+(c[ai>>2]<<4)+12>>2]=ab;c[ai>>2]=(c[ai>>2]|0)+1;break};case 0:{do{if((ay|0)==15){c[2383018]=(c[2383018]|0)-am;c[2383020]=(c[2383020]|0)+am}else{ai=c[2383020]|0;if(ai>>>0<am>>>0){break}c[2383020]=ai-am}}while(0);ai=c[(c[2383406]|0)+16>>2]|0;if((ai|0)==0){break L7716}gf[ai&2047](c[2383358]|0);break};case 4:{ai=d+56|0;ab=ai;if(!ac){ag=x-1|0;c[w>>2]=ag;gGr(c[(c[y>>2]|0)+(ag<<4)>>2]|0)}if((ai|0)!=0){c[ab>>2]=c[(c[y>>2]|0)+(c[w>>2]<<4)+12>>2]}if((ay|0)!=15){break L7716}if((a[9263589]&1)!=0){break L7716}ai=c[F>>2]|0;ag=c[ab>>2]|0;if((ai|0)==0){break L7716}ab=ai+8|0;af=ai+4|0;aj=c[af>>2]|0;if((c[ab>>2]|0)>>>0<aj>>>0){aA=ai|0}else{ah=(aj<<1)+2|0;c[af>>2]=ah;af=ai|0;c[af>>2]=gGs(c[af>>2]|0,ah<<4)|0;aA=af}af=bG(9534384)|0;c[(c[aA>>2]|0)+(c[ab>>2]<<4)>>2]=af;c[(c[aA>>2]|0)+(c[ab>>2]<<4)+4>>2]=0;c[(c[aA>>2]|0)+(c[ab>>2]<<4)+8>>2]=16;c[(c[aA>>2]|0)+(c[ab>>2]<<4)+12>>2]=ag;c[ab>>2]=(c[ab>>2]|0)+1;break};case 8:{a[d+61|0]=1;break};case 2:{do{if((ay|0)==15){c[2383017]=(c[2383017]|0)-an;c[2383019]=(c[2383019]|0)+an}else{ab=c[2383019]|0;if(ab>>>0<an>>>0){break}c[2383019]=ab-an}}while(0);ab=c[(c[2383406]|0)+16>>2]|0;if((ab|0)==0){break L7716}gf[ab&2047](c[2383358]|0);break};default:{}}}while(0);w=c[F>>2]|0;y=c[w+8>>2]|0;if((y|0)==0){aB=ay}else{aB=c[(c[w>>2]|0)+(y-1<<4)+8>>2]|0}if((c[2161332]|0)!=0){jZ(d)}if((a[9263589]&1)==0){if((aB|0)==15){aC=556216}else{aC=(aB|0)==16?555224:0}y=c[2383017]|0;w=c[2383018]|0;x=c[2383019]|0;ac=c[2383020]|0;be(ak|0,64,553408,($=i,i=i+40|0,c[$>>2]=aC,c[$+8>>2]=y,c[$+16>>2]=w,c[$+24>>2]=x,c[$+32>>2]=ac,$)|0)|0;i=$}else{c[2383017]=0;c[2383018]=0;ac=c[2367346]|0;x=(c[2383019]|0)-1+ac|0;w=x-((x>>>0)%(ac>>>0)|0)|0;c[2383019]=w;y=c[2367347]|0;K=(c[2383020]|0)-1+y|0;ad=K-((K>>>0)%(y>>>0)|0)|0;c[2383020]=ad;ao=(x>>>0)/(ac>>>0)|0;ac=(K>>>0)/(y>>>0)|0;be(ak|0,64,557824,($=i,i=i+40|0,c[$>>2]=559184,c[$+8>>2]=w,c[$+16>>2]=ad,c[$+24>>2]=ao,c[$+32>>2]=ac,$)|0)|0;i=$}if((c[2161332]|0)!=0){jY(d,ak)}ac=c[2383019]|0;if((ac|0)==0){c[2383019]=an;aD=an}else{aD=ac}ac=c[2383020]|0;if((ac|0)==0){c[2383020]=am;aE=am}else{aE=ac}g[16233]=+(aD>>>0>>>0)/+(aE>>>0>>>0);ac=c[(c[2383406]|0)+16>>2]|0;if((ac|0)==0){aa=0;i=f;return aa|0}gf[ac&2047](c[2383358]|0);aa=0;i=f;return aa|0}}while(0);aE=d+60|0;aD=c[d+4400>>2]|0;if(aD>>>0>2){aF=((aD-2|0)>>>2)+1|0}else{aF=1}aD=(aF<<2)+4|0;L7811:do{switch(((a[aE]&1)==0|(e|0)==8?e:13)|0){case 6:{c[d+56>>2]=0;a[aE]=1;aG=0;break};case 8:{a[d+61|0]=1;aG=0;break};case 4:{aC=c[d+52>>2]|0;if((c[aC+8>>2]|0)==0){aa=0;i=f;return aa|0}aB=d+56|0;ay=aB;aA=c[ay>>2]|0;az=c[aC>>2]|0;aC=c[az+(aA<<4)>>2]|0;t=c[az+(aA<<4)+8>>2]|0;L7818:do{switch(t|0){case 4:case 6:case 30:case 66:case 67:case 68:case 69:case 70:case 71:case 78:{break};default:{az=t-35|0;if(az>>>0<24){if(((az>>>0)%3|0|0)!=0){U=5732}}else{if((t|0)!=32){U=5732}}do{if((U|0)==5732){if((t-87|0)>>>0<3|(t|0)==91|(t|0)==92|(t|0)==93|(t|0)==90|(t|0)==94|(t|0)==86|(t|0)==95){break}switch(t|0){case 104:case 80:case 64:case 62:case 1:{break};default:{break L7818}}}}while(0);az=z|0;hE(az,J,aC);v=c[F>>2]|0;s=c[ay>>2]|0;if((v|0)!=0){aq=v+8|0;au=v+4|0;ax=c[au>>2]|0;if((c[aq>>2]|0)>>>0<ax>>>0){aH=v|0}else{as=(ax<<1)+2|0;c[au>>2]=as;au=v|0;c[au>>2]=gGs(c[au>>2]|0,as<<4)|0;aH=au}au=bG(az|0)|0;c[(c[aH>>2]|0)+(c[aq>>2]<<4)>>2]=au;c[(c[aH>>2]|0)+(c[aq>>2]<<4)+4>>2]=0;c[(c[aH>>2]|0)+(c[aq>>2]<<4)+8>>2]=t;c[(c[aH>>2]|0)+(c[aq>>2]<<4)+12>>2]=s;c[aq>>2]=(c[aq>>2]|0)+1}c[ay>>2]=0;a[aE]=1;aG=0;break L7811}}}while(0);L7835:do{switch(I|0){case 78:case 71:case 70:case 69:case 67:case 66:case 30:case 6:case 4:case 68:{break};default:{if(_>>>0<24){if(((_>>>0)%3|0|0)!=0){break L7835}hE(d+20892+(((_>>>0)/3|0)*4144|0)|0,J,aC)}else{if(!ap){break L7835}t=A|0;hE(t,J,aC);jN(d+20816|0,jp(t,3)|0,t)}a[aE]=1;t=c[F>>2]|0;am=c[t+8>>2]|0;if((am|0)==0){aI=0}else{an=c[(c[t>>2]|0)+(am-1<<4)+8>>2]|0;if((an|0)==30){aG=0;break L7811}else{aI=an}}an=(aB|0)==0;ak=aI;aq=t;t=am;while(1){am=aq+8|0;if((t|0)!=0){s=t-1|0;c[am>>2]=s;gGr(c[(c[aq>>2]|0)+(s<<4)>>2]|0)}if(!an){c[ay>>2]=c[(c[aq>>2]|0)+(c[am>>2]<<4)+12>>2]}am=c[F>>2]|0;s=c[am+8>>2]|0;if((s|0)==0){aJ=ak}else{aJ=c[(c[am>>2]|0)+(s-1<<4)+8>>2]|0}if((aJ|0)==30){aG=0;break L7811}else{ak=aJ;aq=am;t=s}}}}}while(0);switch(I|0){case 89:{t=4096;aq=9448858;ak=J;while(1){an=t-1|0;if((an|0)==0){U=5925;break}s=a[ak]|0;a[aq]=s;if(s<<24>>24==0){break}else{t=an;aq=aq+1|0;ak=ak+1|0}}do{if((U|0)==5925){a[aq]=0;if((a[ak]|0)==0){break}else{aK=ak}do{aK=aK+1|0;}while((a[aK]|0)!=0)}}while(0);a[aE]=1;ak=c[F>>2]|0;aq=c[ak+8>>2]|0;if((aq|0)==0){aL=0}else{t=c[(c[ak>>2]|0)+(aq-1<<4)+8>>2]|0;if((t|0)==69){aG=0;break L7811}else{aL=t}}t=(aB|0)==0;an=aL;s=ak;ak=aq;while(1){aq=s+8|0;if((ak|0)!=0){am=ak-1|0;c[aq>>2]=am;gGr(c[(c[s>>2]|0)+(am<<4)>>2]|0)}if(!t){c[ay>>2]=c[(c[s>>2]|0)+(c[aq>>2]<<4)+12>>2]}aq=c[F>>2]|0;am=c[aq+8>>2]|0;if((am|0)==0){aM=an}else{aM=c[(c[aq>>2]|0)+(am-1<<4)+8>>2]|0}if((aM|0)==69){aG=0;break}else{an=aM;s=aq;ak=am}}break};case 92:{ak=4096;s=9345348;an=J;while(1){t=ak-1|0;if((t|0)==0){U=5939;break}am=a[an]|0;a[s]=am;if(am<<24>>24==0){break}else{ak=t;s=s+1|0;an=an+1|0}}do{if((U|0)==5939){a[s]=0;if((a[an]|0)==0){break}else{aN=an}do{aN=aN+1|0;}while((a[aN]|0)!=0)}}while(0);an=d+64|0;jJ(c[an>>2]|0);c[an>>2]=0;s=d+16697|0;if((a[s]|0)!=0){c[an>>2]=jI(s)|0}a[aE]=1;s=c[F>>2]|0;an=c[s+8>>2]|0;if((an|0)==0){aO=0}else{ak=c[(c[s>>2]|0)+(an-1<<4)+8>>2]|0;if((ak|0)==69){aG=0;break L7811}else{aO=ak}}ak=(aB|0)==0;t=aO;am=s;s=an;while(1){an=am+8|0;if((s|0)!=0){aq=s-1|0;c[an>>2]=aq;gGr(c[(c[am>>2]|0)+(aq<<4)>>2]|0)}if(!ak){c[ay>>2]=c[(c[am>>2]|0)+(c[an>>2]<<4)+12>>2]}an=c[F>>2]|0;aq=c[an+8>>2]|0;if((aq|0)==0){aP=t}else{aP=c[(c[an>>2]|0)+(aq-1<<4)+8>>2]|0}if((aP|0)==69){aG=0;break}else{t=aP;am=an;s=aq}}break};case 88:{s=4096;am=9271801;t=J;while(1){ak=s-1|0;if((ak|0)==0){U=5955;break}aq=a[t]|0;a[am]=aq;if(aq<<24>>24==0){break}else{s=ak;am=am+1|0;t=t+1|0}}do{if((U|0)==5955){a[am]=0;if((a[t]|0)==0){break}else{aQ=t}do{aQ=aQ+1|0;}while((a[aQ]|0)!=0)}}while(0);a[aE]=1;t=c[F>>2]|0;am=c[t+8>>2]|0;if((am|0)==0){aR=0}else{s=c[(c[t>>2]|0)+(am-1<<4)+8>>2]|0;if((s|0)==69){aG=0;break L7811}else{aR=s}}s=(aB|0)==0;ak=aR;aq=t;t=am;while(1){am=aq+8|0;if((t|0)!=0){an=t-1|0;c[am>>2]=an;gGr(c[(c[aq>>2]|0)+(an<<4)>>2]|0)}if(!s){c[ay>>2]=c[(c[aq>>2]|0)+(c[am>>2]<<4)+12>>2]}am=c[F>>2]|0;an=c[am+8>>2]|0;if((an|0)==0){aS=ak}else{aS=c[(c[am>>2]|0)+(an-1<<4)+8>>2]|0}if((aS|0)==69){aG=0;break}else{ak=aS;aq=am;t=an}}break};case 64:{t=B|0;hE(t,J,aC);a[aE]=1;aq=c[F>>2]|0;ak=c[aq+8>>2]|0;if((ak|0)==0){aT=0;aU=aq;aV=ak;U=5792}else{s=c[(c[aq>>2]|0)+(ak-1<<4)+8>>2]|0;if((s|0)!=4){aT=s;aU=aq;aV=ak;U=5792}}if((U|0)==5792){while(1){U=0;ak=aU+8|0;if((aV|0)==0){aW=0;aX=aU;aY=aU|0}else{aq=aV-1|0;c[ak>>2]=aq;s=aU|0;gGr(c[(c[s>>2]|0)+(aq<<4)>>2]|0);aW=c[ak>>2]|0;aX=c[F>>2]|0;aY=s}c[ay>>2]=c[(c[aY>>2]|0)+(aW<<4)+12>>2];s=c[aX+8>>2]|0;if((s|0)==0){aZ=aT}else{aZ=c[(c[aX>>2]|0)+(s-1<<4)+8>>2]|0}if((aZ|0)==4){break}else{aT=aZ;aU=aX;aV=s;U=5792}}}a[d+61|0]=1;if((fa(t|0,9395610)|0)==0){aG=0;break L7811}if((a[9532118]&1)==0|(a[9395610]|0)==0){a_=4096;a$=9395610;a0=t}else{h3(9395610)|0;a_=4096;a$=9395610;a0=t}while(1){s=a_-1|0;if((s|0)==0){U=5803;break}ak=a[a0]|0;a[a$]=ak;if(ak<<24>>24==0){break}else{a_=s;a$=a$+1|0;a0=a0+1|0}}do{if((U|0)==5803){a[a$]=0;if((a[a0]|0)==0){break}else{a1=a0}do{a1=a1+1|0;}while((a[a1]|0)!=0)}}while(0);a[9532036]=0;a[9411994]=0;a[9341252]=0;t=9532104;s=c[t+4>>2]|0;ak=9532104;c[ak>>2]=c[t>>2]|4;c[ak+4>>2]=s;a[(c[2112498]|0)+20812|0]=0;c[ay>>2]=0;aG=-1;break L7811;break};case 63:{s=4096;ak=9341252;t=aC;while(1){aq=s-1|0;if((aq|0)==0){U=5759;break}an=a[t]|0;a[ak]=an;if(an<<24>>24==0){break}else{s=aq;ak=ak+1|0;t=t+1|0}}do{if((U|0)==5759){a[ak]=0;if((a[t]|0)==0){break}else{a2=t}do{a2=a2+1|0;}while((a[a2]|0)!=0)}}while(0);t=4096;ak=9411994;s=d+69|0;while(1){aq=t-1|0;if((aq|0)==0){U=5764;break}an=a[s]|0;a[ak]=an;if(an<<24>>24==0){break}else{t=aq;ak=ak+1|0;s=s+1|0}}do{if((U|0)==5764){a[ak]=0;if((a[s]|0)==0){break}else{a3=s}do{a3=a3+1|0;}while((a[a3]|0)!=0)}}while(0);h6(131072,9341252)|0;s=4096;ak=9411994;while(1){t=s-1|0;if((t|0)==0){U=5769;break}if((a[ak]|0)==0){break}else{s=t;ak=ak+1|0}}if((U|0)==5769){a[ak]=0}if((a[9375104]&1)!=0){s=c[u>>2]|0;cj(207304,35,1,s|0)|0;eY(s|0)|0}a[d+61|0]=1;a[aE]=1;s=c[F>>2]|0;t=c[s+8>>2]|0;if((t|0)==0){a4=0}else{aq=c[(c[s>>2]|0)+(t-1<<4)+8>>2]|0;if((aq|0)==4){aG=-1;break L7811}else{a4=aq}}aq=(aB|0)==0;an=a4;am=s;s=t;while(1){t=am+8|0;if((s|0)!=0){au=s-1|0;c[t>>2]=au;gGr(c[(c[am>>2]|0)+(au<<4)>>2]|0)}if(!aq){c[ay>>2]=c[(c[am>>2]|0)+(c[t>>2]<<4)+12>>2]}t=c[F>>2]|0;au=c[t+8>>2]|0;if((au|0)==0){a5=an}else{a5=c[(c[t>>2]|0)+(au-1<<4)+8>>2]|0}if((a5|0)==4){aG=-1;break}else{an=a5;am=t;s=au}}break};case 104:{hE(9324856,J,aC);s=c[2383400]|0;if((s|0)!=0){i5(s)}s=i3()|0;c[2383400]=s;if((s|0)==0){s=c[u>>2]|0;cj(561752,45,1,s|0)|0;eY(s|0)|0}a[aE]=1;s=c[F>>2]|0;am=c[s+8>>2]|0;if((am|0)==0){a6=0}else{an=c[(c[s>>2]|0)+(am-1<<4)+8>>2]|0;if((an|0)==68){aG=0;break L7811}else{a6=an}}an=(aB|0)==0;aq=a6;ak=s;s=am;while(1){am=ak+8|0;if((s|0)!=0){au=s-1|0;c[am>>2]=au;gGr(c[(c[ak>>2]|0)+(au<<4)>>2]|0)}if(!an){c[ay>>2]=c[(c[ak>>2]|0)+(c[am>>2]<<4)+12>>2]}am=c[F>>2]|0;au=c[am+8>>2]|0;if((au|0)==0){a7=aq}else{a7=c[(c[am>>2]|0)+(au-1<<4)+8>>2]|0}if((a7|0)==68){aG=0;break}else{aq=a7;ak=am;s=au}}break};case 62:{a[aE]=1;s=c[F>>2]|0;ak=c[s+8>>2]|0;if((ak|0)==0){a8=0;a9=s;ba=ak}else{aq=c[(c[s>>2]|0)+(ak-1<<4)+8>>2]|0;if((aq|0)==4){aG=0;break L7811}else{a8=aq;a9=s;ba=ak}}while(1){ak=a9+8|0;if((ba|0)==0){bb=0;bc=a9;bd=a9|0}else{s=ba-1|0;c[ak>>2]=s;aq=a9|0;gGr(c[(c[aq>>2]|0)+(s<<4)>>2]|0);bb=c[ak>>2]|0;bc=c[F>>2]|0;bd=aq}c[ay>>2]=c[(c[bd>>2]|0)+(bb<<4)+12>>2];aq=c[bc+8>>2]|0;if((aq|0)==0){bf=a8}else{bf=c[(c[bc>>2]|0)+(aq-1<<4)+8>>2]|0}if((bf|0)==4){aG=0;break}else{a8=bf;a9=bc;ba=aq}}break};case 86:{aq=4096;ak=9357636;s=J;while(1){an=aq-1|0;if((an|0)==0){U=5883;break}au=a[s]|0;a[ak]=au;if(au<<24>>24==0){break}else{aq=an;ak=ak+1|0;s=s+1|0}}do{if((U|0)==5883){a[ak]=0;if((a[s]|0)==0){break}else{bg=s}do{bg=bg+1|0;}while((a[bg]|0)!=0)}}while(0);a[aE]=1;s=c[F>>2]|0;ak=c[s+8>>2]|0;if((ak|0)==0){bh=0}else{aq=c[(c[s>>2]|0)+(ak-1<<4)+8>>2]|0;if((aq|0)==69){aG=0;break L7811}else{bh=aq}}aq=(aB|0)==0;an=bh;au=s;s=ak;while(1){ak=au+8|0;if((s|0)!=0){am=s-1|0;c[ak>>2]=am;gGr(c[(c[au>>2]|0)+(am<<4)>>2]|0)}if(!aq){c[ay>>2]=c[(c[au>>2]|0)+(c[ak>>2]<<4)+12>>2]}ak=c[F>>2]|0;am=c[ak+8>>2]|0;if((am|0)==0){bi=an}else{bi=c[(c[ak>>2]|0)+(am-1<<4)+8>>2]|0}if((bi|0)==69){aG=0;break}else{an=bi;au=ak;s=am}}break};case 90:{s=4096;au=9444762;an=J;while(1){aq=s-1|0;if((aq|0)==0){U=5897;break}am=a[an]|0;a[au]=am;if(am<<24>>24==0){break}else{s=aq;au=au+1|0;an=an+1|0}}do{if((U|0)==5897){a[au]=0;if((a[an]|0)==0){break}else{bj=an}do{bj=bj+1|0;}while((a[bj]|0)!=0)}}while(0);a[aE]=1;an=c[F>>2]|0;au=c[an+8>>2]|0;if((au|0)==0){bk=0}else{s=c[(c[an>>2]|0)+(au-1<<4)+8>>2]|0;if((s|0)==69){aG=0;break L7811}else{bk=s}}s=(aB|0)==0;aq=bk;am=an;an=au;while(1){au=am+8|0;if((an|0)!=0){ak=an-1|0;c[au>>2]=ak;gGr(c[(c[am>>2]|0)+(ak<<4)>>2]|0)}if(!s){c[ay>>2]=c[(c[am>>2]|0)+(c[au>>2]<<4)+12>>2]}au=c[F>>2]|0;ak=c[au+8>>2]|0;if((ak|0)==0){bl=aq}else{bl=c[(c[au>>2]|0)+(ak-1<<4)+8>>2]|0}if((bl|0)==69){aG=0;break}else{aq=bl;am=au;an=ak}}break};case 94:{an=4096;am=9452954;aq=J;while(1){s=an-1|0;if((s|0)==0){U=5911;break}ak=a[aq]|0;a[am]=ak;if(ak<<24>>24==0){break}else{an=s;am=am+1|0;aq=aq+1|0}}do{if((U|0)==5911){a[am]=0;if((a[aq]|0)==0){break}else{bm=aq}do{bm=bm+1|0;}while((a[bm]|0)!=0)}}while(0);a[aE]=1;aq=c[F>>2]|0;am=c[aq+8>>2]|0;if((am|0)==0){bn=0}else{an=c[(c[aq>>2]|0)+(am-1<<4)+8>>2]|0;if((an|0)==69){aG=0;break L7811}else{bn=an}}an=(aB|0)==0;s=bn;ak=aq;aq=am;while(1){am=ak+8|0;if((aq|0)!=0){au=aq-1|0;c[am>>2]=au;gGr(c[(c[ak>>2]|0)+(au<<4)>>2]|0)}if(!an){c[ay>>2]=c[(c[ak>>2]|0)+(c[am>>2]<<4)+12>>2]}am=c[F>>2]|0;au=c[am+8>>2]|0;if((au|0)==0){bo=s}else{bo=c[(c[am>>2]|0)+(au-1<<4)+8>>2]|0}if((bo|0)==69){aG=0;break}else{s=bo;ak=am;aq=au}}break};case 80:{aq=C|0;hE(aq,J,aC);ak=q|0;hg(1,0);gD[c[2368523]&8191]()|0;s=gD[c[2368521]&8191]()|0;if((s|0)!=0){an=s-1|0;gGz(p|0,0,16);c[p>>2]=aq;s=c[2368522]|0;gA[s&16383](an,p)|0;hh(an);be(ak|0,512,408200,($=i,i=i+8|0,c[$>>2]=aq,$)|0)|0;i=$;if((a[9375104]&1)!=0){an=c[u>>2]|0;bU(an|0,324680,($=i,i=i+8|0,c[$>>2]=ak,$)|0)|0;i=$;eY(an|0)|0}an=c[2380901]|0;s=an+4|0;au=c[s>>2]|0;if(au>>>0>1){am=an|0;t=1;az=au;while(1){au=c[(c[am>>2]|0)+(t<<2)>>2]|0;if((au|0)==0){bp=az}else{gGr(c[au+8>>2]|0);gGr(c[(c[am>>2]|0)+(t<<2)>>2]|0);c[(c[am>>2]|0)+(t<<2)>>2]=0;bp=c[s>>2]|0}au=t+1|0;if(au>>>0<bp>>>0){t=au;az=bp}else{break}}}c[s>>2]=1;az=an+12|0;gGr(c[az>>2]|0);c[az>>2]=0;az=c[2380901]|0;t=az+4|0;L8105:do{if((c[t>>2]|0)>>>0<(c[az+8>>2]|0)>>>0){am=gGq(12)|0;do{if((am|0)!=0){if((c[am-4>>2]&3|0)==0){break}gGz(am|0,0,12)}}while(0);c[am+4>>2]=0;c[am>>2]=180;au=bG(ak|0)|0;as=c[t>>2]|0;c[am+8>>2]=au;au=az|0;c[(c[au>>2]|0)+(as<<2)>>2]=am;as=c[t>>2]|0;c[t>>2]=as+1;if(as>>>0>1){bq=as}else{break}while(1){as=bq>>>1;v=c[au>>2]|0;ax=v+(as<<2)|0;at=c[ax>>2]|0;ar=c[v+(bq<<2)>>2]|0;if((c[ar+4>>2]|0)>>>0<=(c[at+4>>2]|0)>>>0){break L8105}c[ax>>2]=ar;c[(c[au>>2]|0)+(bq<<2)>>2]=at;if(bq>>>0>3){bq=as}else{break}}}}while(0);hi(aq);hj();hg(0,0)}t=9532104;az=c[t+4>>2]|0;ak=9532104;c[ak>>2]=c[t>>2]|1;c[ak+4>>2]=az;a[aE]=1;az=c[F>>2]|0;ak=c[az+8>>2]|0;if((ak|0)==0){br=0;bs=az;bt=ak}else{t=c[(c[az>>2]|0)+(ak-1<<4)+8>>2]|0;if((t|0)==4){aG=-1;break L7811}else{br=t;bs=az;bt=ak}}while(1){ak=bs+8|0;if((bt|0)==0){bu=0;bv=bs;bw=bs|0}else{az=bt-1|0;c[ak>>2]=az;t=bs|0;gGr(c[(c[t>>2]|0)+(az<<4)>>2]|0);bu=c[ak>>2]|0;bv=c[F>>2]|0;bw=t}c[ay>>2]=c[(c[bw>>2]|0)+(bu<<4)+12>>2];t=c[bv+8>>2]|0;if((t|0)==0){bx=br}else{bx=c[(c[bv>>2]|0)+(t-1<<4)+8>>2]|0}if((bx|0)==4){aG=-1;break}else{br=bx;bs=bv;bt=t}}break};case 95:{aq=4096;t=9361732;ak=J;while(1){az=aq-1|0;if((az|0)==0){U=5969;break}an=a[ak]|0;a[t]=an;if(an<<24>>24==0){break}else{aq=az;t=t+1|0;ak=ak+1|0}}do{if((U|0)==5969){a[t]=0;if((a[ak]|0)==0){break}else{by=ak}do{by=by+1|0;}while((a[by]|0)!=0)}}while(0);a[aE]=1;ak=c[F>>2]|0;t=c[ak+8>>2]|0;if((t|0)==0){bz=0}else{aq=c[(c[ak>>2]|0)+(t-1<<4)+8>>2]|0;if((aq|0)==69){aG=0;break L7811}else{bz=aq}}aq=(aB|0)==0;az=bz;an=ak;ak=t;while(1){t=an+8|0;if((ak|0)!=0){s=ak-1|0;c[t>>2]=s;gGr(c[(c[an>>2]|0)+(s<<4)>>2]|0)}if(!aq){c[ay>>2]=c[(c[an>>2]|0)+(c[t>>2]<<4)+12>>2]}t=c[F>>2]|0;s=c[t+8>>2]|0;if((s|0)==0){bA=az}else{bA=c[(c[t>>2]|0)+(s-1<<4)+8>>2]|0}if((bA|0)==69){aG=0;break}else{az=bA;an=t;ak=s}}break};case 61:{ak=c[c[(c[2112498]|0)+130284>>2]>>2]|0;an=c[ak+(aA*12|0)>>2]|0;h6(131072,c[ak+(aA*12|0)+4>>2]|0)|0;ak=(an|0)==0;a[(c[2112498]|0)+20812|0]=ak&1;L8218:do{if(ak){a[9411994]=0}else{az=4096;aq=9411994;s=an;while(1){t=az-1|0;if((t|0)==0){break}au=a[s]|0;a[aq]=au;if(au<<24>>24==0){break L8218}else{az=t;aq=aq+1|0;s=s+1|0}}a[aq]=0;if((a[s]|0)==0){break}else{bB=s}do{bB=bB+1|0;}while((a[bB]|0)!=0)}}while(0);if((a[9375104]&1)!=0){an=c[u>>2]|0;cj(207304,35,1,an|0)|0;eY(an|0)|0}a[aE]=1;an=c[F>>2]|0;ak=c[an+8>>2]|0;if((ak|0)==0){bC=0}else{aA=c[(c[an>>2]|0)+(ak-1<<4)+8>>2]|0;if((aA|0)==4){aG=-1;break L7811}else{bC=aA}}aA=(aB|0)==0;s=bC;aq=an;an=ak;while(1){ak=aq+8|0;if((an|0)!=0){az=an-1|0;c[ak>>2]=az;gGr(c[(c[aq>>2]|0)+(az<<4)>>2]|0)}if(!aA){c[ay>>2]=c[(c[aq>>2]|0)+(c[ak>>2]<<4)+12>>2]}ak=c[F>>2]|0;az=c[ak+8>>2]|0;if((az|0)==0){bD=s}else{bD=c[(c[ak>>2]|0)+(az-1<<4)+8>>2]|0}if((bD|0)==4){aG=-1;break}else{s=bD;aq=ak;an=az}}break};case 87:{an=4096;aq=9365865;s=J;while(1){aA=an-1|0;if((aA|0)==0){U=5864;break}az=a[s]|0;a[aq]=az;if(az<<24>>24==0){break}else{an=aA;aq=aq+1|0;s=s+1|0}}do{if((U|0)==5864){a[aq]=0;if((a[s]|0)==0){break}else{bE=s}do{bE=bE+1|0;}while((a[bE]|0)!=0)}}while(0);s=4096;aq=d+4404|0;an=J;while(1){aA=s-1|0;if((aA|0)==0){U=5869;break}az=a[an]|0;a[aq]=az;if(az<<24>>24==0){break}else{s=aA;aq=aq+1|0;an=an+1|0}}do{if((U|0)==5869){a[aq]=0;if((a[an]|0)==0){break}else{bF=an}do{bF=bF+1|0;}while((a[bF]|0)!=0)}}while(0);a[aE]=1;an=c[F>>2]|0;aq=c[an+8>>2]|0;if((aq|0)==0){bH=0}else{s=c[(c[an>>2]|0)+(aq-1<<4)+8>>2]|0;if((s|0)==69){aG=0;break L7811}else{bH=s}}s=(aB|0)==0;aA=bH;az=an;an=aq;while(1){aq=az+8|0;if((an|0)!=0){ak=an-1|0;c[aq>>2]=ak;gGr(c[(c[az>>2]|0)+(ak<<4)>>2]|0)}if(!s){c[ay>>2]=c[(c[az>>2]|0)+(c[aq>>2]<<4)+12>>2]}aq=c[F>>2]|0;ak=c[aq+8>>2]|0;if((ak|0)==0){bI=aA}else{bI=c[(c[aq>>2]|0)+(ak-1<<4)+8>>2]|0}if((bI|0)==69){aG=0;break}else{aA=bI;az=aq;an=ak}}break};default:{if((a[d+68|0]&1)==0){hE(9411994,J,aC);an=9532104;az=c[an+4>>2]|0;aA=9532104;c[aA>>2]=c[an>>2]|4;c[aA+4>>2]=az;a[aE]=1;az=c[F>>2]|0;aA=c[az+8>>2]|0;if((aA|0)==0){bJ=0;bK=az;bL=aA;U=6018}else{an=c[(c[az>>2]|0)+(aA-1<<4)+8>>2]|0;if((an|0)!=4){bJ=an;bK=az;bL=aA;U=6018}}if((U|0)==6018){while(1){U=0;aA=bK+8|0;if((bL|0)==0){bM=0;bN=bK;bO=bK|0}else{az=bL-1|0;c[aA>>2]=az;an=bK|0;gGr(c[(c[an>>2]|0)+(az<<4)>>2]|0);bM=c[aA>>2]|0;bN=c[F>>2]|0;bO=an}c[ay>>2]=c[(c[bO>>2]|0)+(bM<<4)+12>>2];an=c[bN+8>>2]|0;if((an|0)==0){bP=bJ}else{bP=c[(c[bN>>2]|0)+(an-1<<4)+8>>2]|0}if((bP|0)==4){break}else{bJ=bP;bK=bN;bL=an;U=6018}}}a[d+61|0]=1;aG=-1;break L7811}an=d+69|0;hE(an,J,aC);c[D>>2]=0;c[E>>2]=0;aA=c[d+64>>2]|0;do{if((aA|0)!=0){jK(aA,an,D,E);if((c[E>>2]|0)==1){bQ=4096;bR=9411994;bS=an}else{break}while(1){az=bQ-1|0;if((az|0)==0){U=5986;break}s=a[bS]|0;a[bR]=s;if(s<<24>>24==0){break}else{bQ=az;bR=bR+1|0;bS=bS+1|0}}do{if((U|0)==5986){a[bR]=0;if((a[bS]|0)==0){break}else{bT=bS}do{bT=bT+1|0;}while((a[bT]|0)!=0)}}while(0);az=4096;s=9341252;ak=c[c[D>>2]>>2]|0;while(1){aq=az-1|0;if((aq|0)==0){U=5991;break}t=a[ak]|0;a[s]=t;if(t<<24>>24==0){break}else{az=aq;s=s+1|0;ak=ak+1|0}}do{if((U|0)==5991){a[s]=0;if((a[ak]|0)==0){break}else{bV=ak}do{bV=bV+1|0;}while((a[bV]|0)!=0)}}while(0);h6(131072,9341252)|0;ak=4096;s=9411994;while(1){az=ak-1|0;if((az|0)==0){U=5996;break}if((a[s]|0)==0){break}else{ak=az;s=s+1|0}}if((U|0)==5996){a[s]=0}if((a[9375104]&1)!=0){ak=c[u>>2]|0;cj(207304,35,1,ak|0)|0;eY(ak|0)|0}a[aE]=1;ak=c[F>>2]|0;az=c[ak+8>>2]|0;if((az|0)==0){bW=0;U=6001}else{aq=c[(c[ak>>2]|0)+(az-1<<4)+8>>2]|0;if((aq|0)!=4){bW=aq;U=6001}}if((U|0)==6001){aq=(aB|0)==0;t=bW;au=ak;ak=az;while(1){az=au+8|0;if((ak|0)!=0){am=ak-1|0;c[az>>2]=am;gGr(c[(c[au>>2]|0)+(am<<4)>>2]|0)}if(!aq){c[ay>>2]=c[(c[au>>2]|0)+(c[az>>2]<<4)+12>>2]}az=c[F>>2]|0;am=c[az+8>>2]|0;if((am|0)==0){bX=t}else{bX=c[(c[az>>2]|0)+(am-1<<4)+8>>2]|0}if((bX|0)==4){break}else{t=bX;au=az;ak=am}}}a[d+61|0]=1;aG=-1;break L7811}}while(0);aB=c[F>>2]|0;an=d+16697|0;aA=c[ay>>2]|0;if((aB|0)!=0){aC=aB+8|0;ak=aB+4|0;au=c[ak>>2]|0;if((c[aC>>2]|0)>>>0<au>>>0){bY=aB|0}else{t=(au<<1)+2|0;c[ak>>2]=t;ak=aB|0;c[ak>>2]=gGs(c[ak>>2]|0,t<<4)|0;bY=ak}ak=bG(an|0)|0;c[(c[bY>>2]|0)+(c[aC>>2]<<4)>>2]=ak;c[(c[bY>>2]|0)+(c[aC>>2]<<4)+4>>2]=0;c[(c[bY>>2]|0)+(c[aC>>2]<<4)+8>>2]=63;c[(c[bY>>2]|0)+(c[aC>>2]<<4)+12>>2]=aA;c[aC>>2]=(c[aC>>2]|0)+1}c[ay>>2]=0;a[aE]=1;aG=0;break L7811}}break};case 2:{aC=d+56|0;aA=c[aC>>2]|0;if(aA>>>0>aD>>>0){c[aC>>2]=aA-aD;aG=0;break L7811}else{c[aC>>2]=0;aG=0;break L7811}break};case 3:{aC=d+56|0;aA=(c[aC>>2]|0)+aD|0;ak=c[(c[d+52>>2]|0)+8>>2]|0;if(aA>>>0<ak>>>0){c[aC>>2]=aA;aG=0;break L7811}else{c[aC>>2]=ak-1;aG=0;break L7811}break};case 10:{ak=d+56|0;aC=c[d+4396>>2]|0;if((aC|0)==0){aG=0;break L7811}aA=c[ak>>2]|0;if((aA|0)==0){aG=0;break L7811}an=d+4168|0;t=aC;while(1){aC=t-1|0;bZ=c[an+(t-2<<2)>>2]|0;if((aC|0)==0|bZ>>>0<aA>>>0){break}else{t=aC}}c[ak>>2]=bZ;aG=0;break};case 9:{t=d+56|0;aA=c[d+4396>>2]|0;if((aA|0)==0){aG=0;break L7811}an=c[t>>2]|0;ay=aA-1|0;aA=d+4168|0;if((an|0)==(c[aA+(ay<<2)>>2]|0)){aG=0;break L7811}else{b_=0}while(1){aC=b_+1|0;b$=c[aA+(aC<<2)>>2]|0;if(b_>>>0>=ay>>>0|b$>>>0>an>>>0){break}else{b_=aC}}c[t>>2]=b$;aG=0;break};case 5:{an=c[F>>2]|0;ay=an+8|0;if((c[ay>>2]|0)>>>0<=1){aG=0;break L7811}a[aE]=1;aA=d+56|0;ak=c[ay>>2]|0;if((ak|0)!=0){aC=ak-1|0;c[ay>>2]=aC;gGr(c[(c[an>>2]|0)+(aC<<4)>>2]|0)}if((aA|0)==0){aG=0;break L7811}c[aA>>2]=c[(c[an>>2]|0)+(c[ay>>2]<<4)+12>>2];aG=0;break};case 0:{ay=d+56|0;an=c[ay>>2]|0;if(an>>>0<aF>>>0){c[ay>>2]=(c[(c[d+52>>2]|0)+8>>2]|0)-1;aG=0;break L7811}else{c[ay>>2]=an-aF;aG=0;break L7811}break};case 1:{an=d+56|0;ay=(c[an>>2]|0)+aF|0;if(ay>>>0<(c[(c[d+52>>2]|0)+8>>2]|0)>>>0){c[an>>2]=ay;aG=0;break L7811}else{c[an>>2]=0;aG=0;break L7811}break};default:{aG=0}}}while(0);aF=c[F>>2]|0;b$=c[aF+8>>2]|0;if((b$|0)==0){b0=I}else{b0=c[(c[aF>>2]|0)+(b$-1<<4)+8>>2]|0}L8311:do{if((a[aE]&1)!=0){L8313:do{switch(b0|0){case 78:case 71:case 70:case 69:case 67:case 66:case 30:case 6:case 4:case 68:{U=6035;break};case 1:{b1=1;break};default:{b$=b0-35|0;if(b$>>>0<24){if(((b$>>>0)%3|0|0)==0){b1=b0;break L8313}}else{if((b0|0)==32){b1=32;break L8313}}if((b0-87|0)>>>0<3|(b0|0)==91|(b0|0)==92|(b0|0)==93|(b0|0)==90|(b0|0)==94|(b0|0)==86|(b0|0)==95){b1=b0}else{U=6035}}}}while(0);L8319:do{if((U|0)==6035){switch(b0|0){case 62:{b1=b0;break L8319;break};case 63:{b1=b0;break L8319;break};case 64:{b1=b0;break L8319;break};case 80:{b1=b0;break L8319;break};case 104:{b1=b0;break L8319;break};case 61:{b1=61;break L8319;break};default:{break L8311}}}}while(0);a[aE]=0;t=k|0;b$=l|0;aF=m|0;I=n|0;b_=o|0;c[h>>2]=0;bZ=d+52|0;aD=c[bZ>>2]|0;bY=aD+8|0;if((c[bY>>2]|0)!=0){bX=aD|0;aD=0;do{gGr(c[(c[bX>>2]|0)+(aD<<4)>>2]|0);gGr(c[(c[bX>>2]|0)+(aD<<4)+4>>2]|0);aD=aD+1|0;}while(aD>>>0<(c[bY>>2]|0)>>>0)}c[bY>>2]=0;do{if((b1|0)==61){aD=d+130284|0;bX=c[aD>>2]|0;bW=c[bX+4>>2]|0;c[j>>2]=bW;if((bW|0)==0){c[d+4396>>2]=0;break}else{b2=0;b3=bX}while(1){bX=c[b3>>2]|0;bW=c[bX+(b2*12|0)>>2]|0;bV=c[bX+(b2*12|0)+8>>2]|0;L8339:do{if((bW|0)==0){bX=4096;D=t;bT=bV;while(1){bS=bX-1|0;if((bS|0)==0){break}bR=a[bT]|0;a[D]=bR;if(bR<<24>>24==0){break L8339}else{bX=bS;D=D+1|0;bT=bT+1|0}}a[D]=0;if((a[bT]|0)==0){break}else{b4=bT}do{b4=b4+1|0;}while((a[b4]|0)!=0)}else{bT=cE(bW|0,47)|0;hF(b$,(bT|0)==0?bW:bT+1|0,9534384);be(t|0,4096,573224,($=i,i=i+16|0,c[$>>2]=b$,c[$+8>>2]=bV,$)|0)|0;i=$}}while(0);bV=c[bZ>>2]|0;if((bV|0)!=0){bW=bV+8|0;bT=bV+4|0;D=c[bT>>2]|0;if((c[bW>>2]|0)>>>0<D>>>0){b5=bV|0}else{bX=(D<<1)+2|0;c[bT>>2]=bX;bT=bV|0;c[bT>>2]=gGs(c[bT>>2]|0,bX<<4)|0;b5=bT}bT=bG(t|0)|0;c[(c[b5>>2]|0)+(c[bW>>2]<<4)>>2]=bT;c[(c[b5>>2]|0)+(c[bW>>2]<<4)+4>>2]=0;c[(c[b5>>2]|0)+(c[bW>>2]<<4)+8>>2]=0;c[(c[b5>>2]|0)+(c[bW>>2]<<4)+12>>2]=0;c[bW>>2]=(c[bW>>2]|0)+1}bW=b2+1|0;if(bW>>>0>=(c[j>>2]|0)>>>0){break}b2=bW;b3=c[aD>>2]|0}c[d+4396>>2]=0}else if((b1|0)==63){U=6133}else{aD=c[F>>2]|0;bW=c[aD+8>>2]|0;if((bW|0)==0){b6=0;b7=b1}else{bT=bW-1|0;bW=c[aD>>2]|0;b6=c[bW+(bT<<4)>>2]|0;b7=c[bW+(bT<<4)+8>>2]|0}if((a[b6]|0)==0){bT=c[bZ>>2]|0;if((bT|0)==0){break L8311}bW=bT+8|0;aD=bT+4|0;bX=c[aD>>2]|0;if((c[bW>>2]|0)>>>0<bX>>>0){b8=bT|0}else{bV=(bX<<1)+2|0;c[aD>>2]=bV;aD=bT|0;c[aD>>2]=gGs(c[aD>>2]|0,bV<<4)|0;b8=aD}aD=bG(571976)|0;c[(c[b8>>2]|0)+(c[bW>>2]<<4)>>2]=aD;c[(c[b8>>2]|0)+(c[bW>>2]<<4)+4>>2]=0;c[(c[b8>>2]|0)+(c[bW>>2]<<4)+8>>2]=b7;c[(c[b8>>2]|0)+(c[bW>>2]<<4)+12>>2]=0;c[bW>>2]=(c[bW>>2]|0)+1;break L8311}L8369:do{switch(b7|0){case 64:{b9=341504;break};case 32:{b9=569568;break};case 78:case 71:case 70:case 69:case 67:case 66:case 30:case 6:case 4:case 68:{U=6077;break};case 62:{b9=9534384;break};default:{bW=b7-35|0;if(bW>>>0<24){if(((bW>>>0)%3|0|0)==0){b9=567856;break L8369}}else{if((b7|0)==32){b9=567856;break L8369}if((b7|0)==104){b9=341504;break L8369}}if((b7-87|0)>>>0<3|(b7|0)==91|(b7|0)==92|(b7|0)==93|(b7|0)==90|(b7|0)==94|(b7|0)==86|(b7|0)==95){b9=9534384}else{U=6077}}}}while(0);do{if((U|0)==6077){if((a[d+68|0]&1)!=0){bW=c[d+64>>2]|0;if((bW|0)==0){b9=9534384;break}b9=c[bW+8>>2]|0;break}bW=c[d+20804>>2]|0;if((bW|0)==0){b9=9469960;break}if((a[bW]|0)==0){a[aF]=0;b9=aF;break}else{be(aF|0,1024,565568,($=i,i=i+8|0,c[$>>2]=bW,$)|0)|0;i=$;b9=aF;break}}}while(0);bW=hD(b6,b9,1)|0;if((bW|0)==0){break L8311}aD=bW|0;bV=bW+4|0;bT=c[bV>>2]|0;c0(c[aD>>2]|0,bT|0,8,13558);L8390:do{switch(b7|0){case 78:case 71:case 70:case 69:case 67:case 66:case 30:case 6:case 4:case 68:{ca=bT;break};default:{bX=b7-35|0;if(bX>>>0<24){if(((bX>>>0)%3|0|0)==0){ca=bT;break L8390}}else{if((b7|0)==32){ca=bT;break L8390}}if(!((b7-87|0)>>>0<3|(b7|0)==91|(b7|0)==92|(b7|0)==93|(b7|0)==90|(b7|0)==94|(b7|0)==86|(b7|0)==95)){ca=bT;break L8390}bX=c[bZ>>2]|0;if((bX|0)==0){ca=bT;break L8390}D=bX+8|0;bS=bX+4|0;bR=c[bS>>2]|0;if((c[D>>2]|0)>>>0<bR>>>0){cb=bX|0}else{bQ=(bR<<1)+2|0;c[bS>>2]=bQ;bS=bX|0;c[bS>>2]=gGs(c[bS>>2]|0,bQ<<4)|0;cb=bS}bS=bG(563464)|0;c[(c[cb>>2]|0)+(c[D>>2]<<4)>>2]=bS;c[(c[cb>>2]|0)+(c[D>>2]<<4)+4>>2]=0;c[(c[cb>>2]|0)+(c[D>>2]<<4)+8>>2]=3;c[(c[cb>>2]|0)+(c[D>>2]<<4)+12>>2]=0;c[D>>2]=(c[D>>2]|0)+1;ca=c[bV>>2]|0}}}while(0);do{if((ca|0)==0){cc=c[aD>>2]|0}else{bT=b7-35|0;D=bT>>>0<24;bS=((b7-87|0)>>>0<3|(b7|0)==91|(b7|0)==92|(b7|0)==93|(b7|0)==90|(b7|0)==94|(b7|0)==86|(b7|0)==95)^1;bQ=((bT>>>0)%3|0|0)==0|bS;bT=(b7|0)==32|bS;bS=0;bX=ca;while(1){bR=c[aD>>2]|0;E=a[bR+(bS<<3)+4|0]|0;L8408:do{switch(b7|0){case 78:case 71:case 70:case 69:case 67:case 66:case 30:case 6:case 4:case 68:{U=6103;break};default:{if(D){if(bQ){U=6103;break L8408}}else{if(bT){U=6103;break L8408}}if((E&1)==0){cd=bX}else{U=6103}}}}while(0);do{if((U|0)==6103){U=0;J=c[bR+(bS<<3)>>2]|0;if((a[b6]|0)==0){ce=J}else{bL=cE(J|0,47)|0;ce=(bL|0)==0?J:bL+1|0}bL=c[bZ>>2]|0;if((bL|0)==0){cd=bX;break}J=bL+8|0;bN=bL+4|0;bK=c[bN>>2]|0;if((c[J>>2]|0)>>>0<bK>>>0){cf=bL|0}else{bP=(bK<<1)+2|0;c[bN>>2]=bP;bN=bL|0;c[bN>>2]=gGs(c[bN>>2]|0,bP<<4)|0;cf=bN}bN=bG(ce|0)|0;c[(c[cf>>2]|0)+(c[J>>2]<<4)>>2]=bN;c[(c[cf>>2]|0)+(c[J>>2]<<4)+4>>2]=0;c[(c[cf>>2]|0)+(c[J>>2]<<4)+8>>2]=(E&1)!=0?b7:0;c[(c[cf>>2]|0)+(c[J>>2]<<4)+12>>2]=0;c[J>>2]=(c[J>>2]|0)+1;cd=c[bV>>2]|0}}while(0);E=bS+1|0;if(E>>>0<cd>>>0){bS=E;bX=cd}else{break}}bX=c[aD>>2]|0;if((cd|0)==0){cc=bX;break}else{cg=0;ch=bX}while(1){gGr(c[ch+(cg<<3)>>2]|0);bX=cg+1|0;bS=c[aD>>2]|0;if(bX>>>0<(c[bV>>2]|0)>>>0){cg=bX;ch=bS}else{cc=bS;break}}}}while(0);gGr(cc);gGr(bW);if((b7|0)==62){bV=c[bZ>>2]|0;aD=c[F>>2]|0;bS=c[aD+8>>2]|0;if((bS|0)==0){ci=0;ck=62}else{bX=bS-1|0;bS=c[aD>>2]|0;ci=c[bS+(bX<<4)>>2]|0;ck=c[bS+(bX<<4)+8>>2]|0}bX=c[bV+8>>2]|0;c[j>>2]=bX;if((bX|0)==0){cl=bV;cm=0}else{bS=d+64|0;aD=bV|0;bV=0;bT=bX;while(1){bX=c[aD>>2]|0;L8438:do{if((c[bX+(bV<<4)+8>>2]|0)==0){hE(I,ci,c[bX+(bV<<4)>>2]|0);bQ=c[bS>>2]|0;if((bQ|0)==0){cn=bT;break}D=c[bQ+4>>2]|0;if((D|0)==0){cn=bT;break}E=c[bQ>>2]|0;bQ=0;while(1){if((fa(c[E+(bQ*28|0)>>2]|0,I|0)|0)==0){bR=c[E+(bQ*28|0)+8>>2]|0;if((bR|0)!=0){co=256;cp=b_;cq=bR;break}}bR=bQ+1|0;if(bR>>>0<D>>>0){bQ=bR}else{cn=bT;break L8438}}while(1){bQ=co-1|0;if((bQ|0)==0){U=6126;break}D=a[cq]|0;a[cp]=D;if(D<<24>>24==0){break}else{co=bQ;cp=cp+1|0;cq=cq+1|0}}do{if((U|0)==6126){U=0;a[cp]=0;if((a[cq]|0)==0){break}else{cr=cq}do{cr=cr+1|0;}while((a[cr]|0)!=0)}}while(0);gGr(c[(c[aD>>2]|0)+(bV<<4)+4>>2]|0);bQ=bG(b_|0)|0;c[(c[aD>>2]|0)+(bV<<4)+4>>2]=bQ;cn=c[j>>2]|0}else{cn=bT}}while(0);bX=bV+1|0;if(bX>>>0<cn>>>0){bV=bX;bT=cn}else{break}}bT=c[bZ>>2]|0;cl=bT;cm=c[bT+8>>2]|0}c0(c[cl>>2]|0,cm|0,16,5924);cs=ck}else if((b7|0)==63){U=6133;break}else{cs=b7}bT=d+4396|0;c[bT>>2]=0;if((cs|0)!=61){ct=bT;U=6143}}}while(0);if((U|0)==6133){jK(c[d+64>>2]|0,d+69|0,h,j);b_=c[j>>2]|0;I=c[bZ>>2]|0;if((b_|0)==0){cu=I}else{aF=c[h>>2]|0;t=0;b$=I;while(1){I=c[aF+(t*28|0)>>2]|0;if((b$|0)==0){cv=0}else{bY=b$+8|0;bT=b$+4|0;bV=c[bT>>2]|0;if((c[bY>>2]|0)>>>0<bV>>>0){cw=b$|0}else{aD=(bV<<1)+2|0;c[bT>>2]=aD;bT=b$|0;c[bT>>2]=gGs(c[bT>>2]|0,aD<<4)|0;cw=bT}bT=bG(I|0)|0;c[(c[cw>>2]|0)+(c[bY>>2]<<4)>>2]=bT;c[(c[cw>>2]|0)+(c[bY>>2]<<4)+4>>2]=0;c[(c[cw>>2]|0)+(c[bY>>2]<<4)+8>>2]=0;c[(c[cw>>2]|0)+(c[bY>>2]<<4)+12>>2]=0;c[bY>>2]=(c[bY>>2]|0)+1;cv=c[bZ>>2]|0}bY=c[aF+(t*28|0)+8>>2]|0;bT=cv|0;gGr(c[(c[bT>>2]|0)+(t<<4)+4>>2]|0);I=bG(bY|0)|0;c[(c[bT>>2]|0)+(t<<4)+4>>2]=I;I=t+1|0;bT=c[bZ>>2]|0;if(I>>>0<b_>>>0){t=I;b$=bT}else{cu=bT;break}}}c0(c[cu>>2]|0,c[cu+8>>2]|0,16,5924);b$=d+4396|0;c[b$>>2]=0;ct=b$;U=6143}do{if((U|0)==6143){b$=c[bZ>>2]|0;c[ct>>2]=0;t=b$+8|0;if((c[t>>2]|0)==0){break}c[ct>>2]=1;b_=d+4168|0;aF=b_;c[b_>>2]=0;b_=b$|0;b$=c[b_>>2]|0;bT=c[b$+4>>2]|0;if((bT|0)==0){cx=c[b$>>2]|0}else{cx=bT}bT=gGD(a[cx]|0)|0;if((bT|0)<97){cy=96}else{cy=(bT|0)<123?bT:123}bT=c[t>>2]|0;L8482:do{if(bT>>>0>1){b$=c[b_>>2]|0;I=(c[b$+8>>2]|0)!=0;bY=cy;aD=1;bV=b$;while(1){b$=c[bV+(aD<<4)+4>>2]|0;if((b$|0)==0){cz=c[bV+(aD<<4)>>2]|0}else{cz=b$}b$=gGD(a[cz]|0)|0;if((b$|0)<97){cA=96}else{cA=(b$|0)<123?b$:123}b$=(c[(c[b_>>2]|0)+(aD<<4)+8>>2]|0)!=0;if(I&(b$^1)|(cA|0)>(bY|0)){bS=c[ct>>2]|0;c[ct>>2]=bS+1;c[aF+(bS<<2)>>2]=aD}bS=aD+1|0;bW=c[t>>2]|0;if(bS>>>0>=bW>>>0){cB=bW;break L8482}I=b$;bY=cA;aD=bS;bV=c[b_>>2]|0}}else{cB=bT}}while(0);bT=c[ct>>2]|0;c[ct>>2]=bT+1;c[aF+(bT<<2)>>2]=cB-1}}while(0);bT=d+56|0;b_=c[(c[bZ>>2]|0)+8>>2]|0;t=(b_|0)==0;if(!((c[bT>>2]|0)>>>0<b_>>>0|t)){c[bT>>2]=b_-1;break}if(!t){break}c[bT>>2]=0}}while(0);if((c[2161332]|0)==0){aa=aG;i=f;return aa|0}jZ(d);aa=aG;i=f;return aa|0}}return 0}function jP(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;b=i;i=i+80|0;d=b|0;a[(c[2112498]|0)+16697|0]=0;L8698:do{if((f$(9341252,d|0)|0)<0){e=6186}else{if((c[d+12>>2]&61440|0)!=16384){e=6186;break}f=4096;g=(c[2112498]|0)+16697|0;h=9341252;while(1){j=f-1|0;if((j|0)==0){break}k=a[h]|0;a[g]=k;if(k<<24>>24==0){break L8698}else{f=j;g=g+1|0;h=h+1|0}}a[g]=0;if((a[h]|0)==0){break}else{l=h}do{l=l+1|0;}while((a[l]|0)!=0)}}while(0);do{if((e|0)==6186){if((a[9341252]|0)==0){break}hJ((c[2112498]|0)+16697|0,9341252)}}while(0);e=c[2112498]|0;c[e+20796>>2]=143440;c[e+20800>>2]=115184;a[e+20808|0]=1;a[e+20809|0]=1;c[e+20804>>2]=90208;jJ(c[e+64>>2]|0);e=c[2112498]|0;c[e+64>>2]=0;l=e+16697|0;if((a[l]|0)==0){i=b;return}e=jI(l)|0;c[(c[2112498]|0)+64>>2]=e;i=b;return}function jQ(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=i;i=i+16384|0;d=b|0;e=c[(c[2112498]|0)+130284>>2]|0;if((e|0)!=0){j2(e);c[(c[2112498]|0)+130284>>2]=0}if((a[9395610]|0)==0){i=b;return}e=b+12288|0;L8722:do{if((a[9337152]|0)==0){hM(e,9395610,544600)}else{f=4096;g=e;h=9337152;while(1){j=f-1|0;if((j|0)==0){break}k=a[h]|0;a[g]=k;if(k<<24>>24==0){break L8722}else{f=j;g=g+1|0;h=h+1|0}}a[g]=0;if((a[h]|0)==0){break}else{l=h}do{l=l+1|0;}while((a[l]|0)!=0)}}while(0);if((a[9375104]&1)!=0){l=c[u>>2]|0;bU(l|0,543072,(h=i,i=i+8|0,c[h>>2]=e,h)|0)|0;i=h;eY(l|0)|0}l=c[2335312]|0;h=gGq(16)|0;do{if((h|0)==0){m=0}else{if((c[h-4>>2]&3|0)!=0){gGz(h|0,0,16)}g=h;do{if((l|0)==0){n=0}else{f=l*12|0;if(l>>>0<=65535){n=f;break}n=((f>>>0)/(l>>>0)|0|0)==12?f:-1}}while(0);f=gGq(n)|0;if((f|0)==0){c[h>>2]=0;j2(g);m=0;break}if((c[f-4>>2]&3|0)==0){j=h;c[j>>2]=f;o=j}else{gGz(f|0,0,n|0);j=h;c[j>>2]=f;o=j}j=h+8|0;c[j>>2]=l;f=d|0;k=fw(e|0,68376)|0;if((k|0)!=0){p=h+4|0;c[p>>2]=0;L8752:do{if((c[j>>2]|0)!=0){q=d+4096|0;r=d+8192|0;do{a[f]=0;if((fh(f|0,4096,k|0)|0)==0){break L8752}s=cE(f|0,10)|0;if((s|0)!=0){a[s]=0}a[q]=0;if((fh(q|0,4096,k|0)|0)==0){break L8752}s=cE(q|0,10)|0;if((s|0)!=0){a[s]=0}a[r]=0;if((fh(r|0,4096,k|0)|0)==0){break L8752}s=cE(r|0,10)|0;if((s|0)!=0){a[s]=0}s=c[p>>2]|0;t=c[o>>2]|0;if((a[q]|0)==0){break L8752}if((a[r]|0)==0){break L8752}if((a[f]|0)!=0){c[t+(s*12|0)>>2]=bG(f|0)|0}c[t+(s*12|0)+4>>2]=bG(q|0)|0;c[t+(s*12|0)+8>>2]=bG(r|0)|0;s=(c[p>>2]|0)+1|0;c[p>>2]=s;}while(s>>>0<(c[j>>2]|0)>>>0)}}while(0);aY(k|0)|0}c[h+12>>2]=bG(e|0)|0;m=g}}while(0);c[(c[2112498]|0)+130284>>2]=m;i=b;return}function jR(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0;e=i;i=i+128|0;f=e|0;g=e+64|0;switch(d|0){case 6:{d=b+52|0;h=c[d>>2]|0;j=h+8|0;if((c[j>>2]|0)!=0){k=h|0;h=0;do{gGr(c[(c[k>>2]|0)+(h<<4)>>2]|0);gGr(c[(c[k>>2]|0)+(h<<4)+4>>2]|0);h=h+1|0;}while(h>>>0<(c[j>>2]|0)>>>0)}c[j>>2]=0;j=c[d>>2]|0;if((j|0)==0){i=e;return}h=j+8|0;k=j+4|0;l=c[k>>2]|0;if((c[h>>2]|0)>>>0<l>>>0){m=j|0}else{n=(l<<1)+2|0;c[k>>2]=n;k=j|0;c[k>>2]=gGs(c[k>>2]|0,n<<4)|0;m=k}k=bG(247568)|0;c[(c[m>>2]|0)+(c[h>>2]<<4)>>2]=k;c[(c[m>>2]|0)+(c[h>>2]<<4)+4>>2]=0;c[(c[m>>2]|0)+(c[h>>2]<<4)+8>>2]=30;c[(c[m>>2]|0)+(c[h>>2]<<4)+12>>2]=0;c[h>>2]=(c[h>>2]|0)+1;h=c[d>>2]|0;if((h|0)==0){i=e;return}m=h+8|0;k=h+4|0;n=c[k>>2]|0;if((c[m>>2]|0)>>>0<n>>>0){o=h|0}else{j=(n<<1)+2|0;c[k>>2]=j;k=h|0;c[k>>2]=gGs(c[k>>2]|0,j<<4)|0;o=k}k=bG(240736)|0;c[(c[o>>2]|0)+(c[m>>2]<<4)>>2]=k;c[(c[o>>2]|0)+(c[m>>2]<<4)+4>>2]=0;c[(c[o>>2]|0)+(c[m>>2]<<4)+8>>2]=13;c[(c[o>>2]|0)+(c[m>>2]<<4)+12>>2]=0;c[m>>2]=(c[m>>2]|0)+1;m=c[d>>2]|0;if((m|0)==0){i=e;return}o=m+8|0;k=m+4|0;j=c[k>>2]|0;if((c[o>>2]|0)>>>0<j>>>0){p=m|0}else{h=(j<<1)+2|0;c[k>>2]=h;k=m|0;c[k>>2]=gGs(c[k>>2]|0,h<<4)|0;p=k}k=bG(234528)|0;c[(c[p>>2]|0)+(c[o>>2]<<4)>>2]=k;c[(c[p>>2]|0)+(c[o>>2]<<4)+4>>2]=0;c[(c[p>>2]|0)+(c[o>>2]<<4)+8>>2]=14;c[(c[p>>2]|0)+(c[o>>2]<<4)+12>>2]=0;c[o>>2]=(c[o>>2]|0)+1;o=c[d>>2]|0;if((o|0)==0){i=e;return}p=o+8|0;k=o+4|0;h=c[k>>2]|0;if((c[p>>2]|0)>>>0<h>>>0){q=o|0}else{m=(h<<1)+2|0;c[k>>2]=m;k=o|0;c[k>>2]=gGs(c[k>>2]|0,m<<4)|0;q=k}k=bG(228152)|0;c[(c[q>>2]|0)+(c[p>>2]<<4)>>2]=k;c[(c[q>>2]|0)+(c[p>>2]<<4)+4>>2]=0;c[(c[q>>2]|0)+(c[p>>2]<<4)+8>>2]=15;c[(c[q>>2]|0)+(c[p>>2]<<4)+12>>2]=0;c[p>>2]=(c[p>>2]|0)+1;p=c[d>>2]|0;if((p|0)==0){i=e;return}q=p+8|0;k=p+4|0;m=c[k>>2]|0;if((c[q>>2]|0)>>>0<m>>>0){r=p|0}else{o=(m<<1)+2|0;c[k>>2]=o;k=p|0;c[k>>2]=gGs(c[k>>2]|0,o<<4)|0;r=k}k=bG(222248)|0;c[(c[r>>2]|0)+(c[q>>2]<<4)>>2]=k;c[(c[r>>2]|0)+(c[q>>2]<<4)+4>>2]=0;c[(c[r>>2]|0)+(c[q>>2]<<4)+8>>2]=17;c[(c[r>>2]|0)+(c[q>>2]<<4)+12>>2]=0;c[q>>2]=(c[q>>2]|0)+1;q=c[d>>2]|0;if((q|0)==0){i=e;return}r=q+8|0;k=q+4|0;o=c[k>>2]|0;if((c[r>>2]|0)>>>0<o>>>0){s=q|0}else{p=(o<<1)+2|0;c[k>>2]=p;k=q|0;c[k>>2]=gGs(c[k>>2]|0,p<<4)|0;s=k}k=bG(86160)|0;c[(c[s>>2]|0)+(c[r>>2]<<4)>>2]=k;c[(c[s>>2]|0)+(c[r>>2]<<4)+4>>2]=0;c[(c[s>>2]|0)+(c[r>>2]<<4)+8>>2]=19;c[(c[s>>2]|0)+(c[r>>2]<<4)+12>>2]=0;c[r>>2]=(c[r>>2]|0)+1;r=c[d>>2]|0;if((r|0)==0){i=e;return}s=r+8|0;k=r+4|0;p=c[k>>2]|0;if((c[s>>2]|0)>>>0<p>>>0){t=r|0}else{q=(p<<1)+2|0;c[k>>2]=q;k=r|0;c[k>>2]=gGs(c[k>>2]|0,q<<4)|0;t=k}k=bG(214272)|0;c[(c[t>>2]|0)+(c[s>>2]<<4)>>2]=k;c[(c[t>>2]|0)+(c[s>>2]<<4)+4>>2]=0;c[(c[t>>2]|0)+(c[s>>2]<<4)+8>>2]=20;c[(c[t>>2]|0)+(c[s>>2]<<4)+12>>2]=0;c[s>>2]=(c[s>>2]|0)+1;s=c[d>>2]|0;if((s|0)==0){i=e;return}t=s+8|0;k=s+4|0;q=c[k>>2]|0;if((c[t>>2]|0)>>>0<q>>>0){u=s|0}else{r=(q<<1)+2|0;c[k>>2]=r;k=s|0;c[k>>2]=gGs(c[k>>2]|0,r<<4)|0;u=k}k=bG(210912)|0;c[(c[u>>2]|0)+(c[t>>2]<<4)>>2]=k;c[(c[u>>2]|0)+(c[t>>2]<<4)+4>>2]=0;c[(c[u>>2]|0)+(c[t>>2]<<4)+8>>2]=21;c[(c[u>>2]|0)+(c[t>>2]<<4)+12>>2]=0;c[t>>2]=(c[t>>2]|0)+1;t=c[d>>2]|0;if((t|0)==0){i=e;return}u=t+8|0;k=t+4|0;r=c[k>>2]|0;if((c[u>>2]|0)>>>0<r>>>0){v=t|0}else{s=(r<<1)+2|0;c[k>>2]=s;k=t|0;c[k>>2]=gGs(c[k>>2]|0,s<<4)|0;v=k}k=bG(205928)|0;c[(c[v>>2]|0)+(c[u>>2]<<4)>>2]=k;c[(c[v>>2]|0)+(c[u>>2]<<4)+4>>2]=0;c[(c[v>>2]|0)+(c[u>>2]<<4)+8>>2]=22;c[(c[v>>2]|0)+(c[u>>2]<<4)+12>>2]=0;c[u>>2]=(c[u>>2]|0)+1;u=c[d>>2]|0;if((u|0)==0){i=e;return}v=u+8|0;k=u+4|0;s=c[k>>2]|0;if((c[v>>2]|0)>>>0<s>>>0){w=u|0}else{t=(s<<1)+2|0;c[k>>2]=t;k=u|0;c[k>>2]=gGs(c[k>>2]|0,t<<4)|0;w=k}k=bG(199576)|0;c[(c[w>>2]|0)+(c[v>>2]<<4)>>2]=k;c[(c[w>>2]|0)+(c[v>>2]<<4)+4>>2]=0;c[(c[w>>2]|0)+(c[v>>2]<<4)+8>>2]=23;c[(c[w>>2]|0)+(c[v>>2]<<4)+12>>2]=0;c[v>>2]=(c[v>>2]|0)+1;v=c[d>>2]|0;if((v|0)==0){i=e;return}w=v+8|0;k=v+4|0;t=c[k>>2]|0;if((c[w>>2]|0)>>>0<t>>>0){x=v|0}else{u=(t<<1)+2|0;c[k>>2]=u;k=v|0;c[k>>2]=gGs(c[k>>2]|0,u<<4)|0;x=k}k=bG(194144)|0;c[(c[x>>2]|0)+(c[w>>2]<<4)>>2]=k;c[(c[x>>2]|0)+(c[w>>2]<<4)+4>>2]=0;c[(c[x>>2]|0)+(c[w>>2]<<4)+8>>2]=24;c[(c[x>>2]|0)+(c[w>>2]<<4)+12>>2]=0;c[w>>2]=(c[w>>2]|0)+1;w=c[d>>2]|0;if((w|0)==0){i=e;return}x=w+8|0;k=w+4|0;u=c[k>>2]|0;if((c[x>>2]|0)>>>0<u>>>0){y=w|0}else{v=(u<<1)+2|0;c[k>>2]=v;k=w|0;c[k>>2]=gGs(c[k>>2]|0,v<<4)|0;y=k}k=bG(187792)|0;c[(c[y>>2]|0)+(c[x>>2]<<4)>>2]=k;c[(c[y>>2]|0)+(c[x>>2]<<4)+4>>2]=0;c[(c[y>>2]|0)+(c[x>>2]<<4)+8>>2]=25;c[(c[y>>2]|0)+(c[x>>2]<<4)+12>>2]=0;c[x>>2]=(c[x>>2]|0)+1;x=c[d>>2]|0;if((x|0)==0){i=e;return}y=x+8|0;k=x+4|0;v=c[k>>2]|0;if((c[y>>2]|0)>>>0<v>>>0){z=x|0}else{w=(v<<1)+2|0;c[k>>2]=w;k=x|0;c[k>>2]=gGs(c[k>>2]|0,w<<4)|0;z=k}k=bG(182632)|0;c[(c[z>>2]|0)+(c[y>>2]<<4)>>2]=k;c[(c[z>>2]|0)+(c[y>>2]<<4)+4>>2]=0;c[(c[z>>2]|0)+(c[y>>2]<<4)+8>>2]=26;c[(c[z>>2]|0)+(c[y>>2]<<4)+12>>2]=0;c[y>>2]=(c[y>>2]|0)+1;y=c[d>>2]|0;if((y|0)==0){i=e;return}z=y+8|0;k=y+4|0;w=c[k>>2]|0;if((c[z>>2]|0)>>>0<w>>>0){A=y|0}else{x=(w<<1)+2|0;c[k>>2]=x;k=y|0;c[k>>2]=gGs(c[k>>2]|0,x<<4)|0;A=k}k=bG(177864)|0;c[(c[A>>2]|0)+(c[z>>2]<<4)>>2]=k;c[(c[A>>2]|0)+(c[z>>2]<<4)+4>>2]=0;c[(c[A>>2]|0)+(c[z>>2]<<4)+8>>2]=27;c[(c[A>>2]|0)+(c[z>>2]<<4)+12>>2]=0;c[z>>2]=(c[z>>2]|0)+1;z=c[d>>2]|0;if((z|0)==0){i=e;return}d=z+8|0;A=z+4|0;k=c[A>>2]|0;if((c[d>>2]|0)>>>0<k>>>0){B=z|0}else{x=(k<<1)+2|0;c[A>>2]=x;A=z|0;c[A>>2]=gGs(c[A>>2]|0,x<<4)|0;B=A}A=bG(174464)|0;c[(c[B>>2]|0)+(c[d>>2]<<4)>>2]=A;c[(c[B>>2]|0)+(c[d>>2]<<4)+4>>2]=0;c[(c[B>>2]|0)+(c[d>>2]<<4)+8>>2]=28;c[(c[B>>2]|0)+(c[d>>2]<<4)+12>>2]=0;c[d>>2]=(c[d>>2]|0)+1;i=e;return};case 30:{d=b+52|0;B=c[d>>2]|0;A=B+8|0;if((c[A>>2]|0)!=0){x=B|0;B=0;do{gGr(c[(c[x>>2]|0)+(B<<4)>>2]|0);gGr(c[(c[x>>2]|0)+(B<<4)+4>>2]|0);B=B+1|0;}while(B>>>0<(c[A>>2]|0)>>>0)}c[A>>2]=0;A=c[d>>2]|0;do{if((A|0)!=0){B=A+8|0;x=A+4|0;z=c[x>>2]|0;if((c[B>>2]|0)>>>0<z>>>0){C=A|0}else{k=(z<<1)+2|0;c[x>>2]=k;x=A|0;c[x>>2]=gGs(c[x>>2]|0,k<<4)|0;C=x}x=bG(299192)|0;c[(c[C>>2]|0)+(c[B>>2]<<4)>>2]=x;c[(c[C>>2]|0)+(c[B>>2]<<4)+4>>2]=0;c[(c[C>>2]|0)+(c[B>>2]<<4)+8>>2]=33;c[(c[C>>2]|0)+(c[B>>2]<<4)+12>>2]=0;c[B>>2]=(c[B>>2]|0)+1;B=c[d>>2]|0;if((B|0)==0){break}x=B+8|0;k=B+4|0;z=c[k>>2]|0;if((c[x>>2]|0)>>>0<z>>>0){D=B|0}else{y=(z<<1)+2|0;c[k>>2]=y;k=B|0;c[k>>2]=gGs(c[k>>2]|0,y<<4)|0;D=k}k=bG(291648)|0;c[(c[D>>2]|0)+(c[x>>2]<<4)>>2]=k;c[(c[D>>2]|0)+(c[x>>2]<<4)+4>>2]=0;c[(c[D>>2]|0)+(c[x>>2]<<4)+8>>2]=31;c[(c[D>>2]|0)+(c[x>>2]<<4)+12>>2]=0;c[x>>2]=(c[x>>2]|0)+1;x=c[d>>2]|0;if((x|0)==0){break}k=x+8|0;y=x+4|0;B=c[y>>2]|0;if((c[k>>2]|0)>>>0<B>>>0){E=x|0}else{z=(B<<1)+2|0;c[y>>2]=z;y=x|0;c[y>>2]=gGs(c[y>>2]|0,z<<4)|0;E=y}y=bG(285368)|0;c[(c[E>>2]|0)+(c[k>>2]<<4)>>2]=y;c[(c[E>>2]|0)+(c[k>>2]<<4)+4>>2]=0;c[(c[E>>2]|0)+(c[k>>2]<<4)+8>>2]=32;c[(c[E>>2]|0)+(c[k>>2]<<4)+12>>2]=0;c[k>>2]=(c[k>>2]|0)+1;k=c[d>>2]|0;if((k|0)==0){break}y=k+8|0;z=k+4|0;x=c[z>>2]|0;if((c[y>>2]|0)>>>0<x>>>0){F=k|0}else{B=(x<<1)+2|0;c[z>>2]=B;z=k|0;c[z>>2]=gGs(c[z>>2]|0,B<<4)|0;F=z}z=bG(278456)|0;c[(c[F>>2]|0)+(c[y>>2]<<4)>>2]=z;c[(c[F>>2]|0)+(c[y>>2]<<4)+4>>2]=0;c[(c[F>>2]|0)+(c[y>>2]<<4)+8>>2]=34;c[(c[F>>2]|0)+(c[y>>2]<<4)+12>>2]=0;c[y>>2]=(c[y>>2]|0)+1}}while(0);F=b+20888|0;if((c[F>>2]|0)==0){i=e;return}E=f|0;f=0;do{be(E|0,64,271120,(G=i,i=i+8|0,c[G>>2]=f,G)|0)|0;i=G;D=c[d>>2]|0;C=f*3|0;A=C+35|0;if((D|0)!=0){y=D+8|0;z=D+4|0;B=c[z>>2]|0;if((c[y>>2]|0)>>>0<B>>>0){H=D|0}else{k=(B<<1)+2|0;c[z>>2]=k;z=D|0;c[z>>2]=gGs(c[z>>2]|0,k<<4)|0;H=z}z=bG(E|0)|0;c[(c[H>>2]|0)+(c[y>>2]<<4)>>2]=z;c[(c[H>>2]|0)+(c[y>>2]<<4)+4>>2]=0;c[(c[H>>2]|0)+(c[y>>2]<<4)+8>>2]=A;c[(c[H>>2]|0)+(c[y>>2]<<4)+12>>2]=0;c[y>>2]=(c[y>>2]|0)+1}be(E|0,64,264088,(G=i,i=i+8|0,c[G>>2]=f,G)|0)|0;i=G;y=c[d>>2]|0;A=C+36|0;if((y|0)!=0){z=y+8|0;k=y+4|0;D=c[k>>2]|0;if((c[z>>2]|0)>>>0<D>>>0){I=y|0}else{B=(D<<1)+2|0;c[k>>2]=B;k=y|0;c[k>>2]=gGs(c[k>>2]|0,B<<4)|0;I=k}k=bG(E|0)|0;c[(c[I>>2]|0)+(c[z>>2]<<4)>>2]=k;c[(c[I>>2]|0)+(c[z>>2]<<4)+4>>2]=0;c[(c[I>>2]|0)+(c[z>>2]<<4)+8>>2]=A;c[(c[I>>2]|0)+(c[z>>2]<<4)+12>>2]=0;c[z>>2]=(c[z>>2]|0)+1}be(E|0,64,255544,(G=i,i=i+8|0,c[G>>2]=f,G)|0)|0;i=G;z=c[d>>2]|0;A=C+37|0;if((z|0)!=0){C=z+8|0;k=z+4|0;B=c[k>>2]|0;if((c[C>>2]|0)>>>0<B>>>0){J=z|0}else{y=(B<<1)+2|0;c[k>>2]=y;k=z|0;c[k>>2]=gGs(c[k>>2]|0,y<<4)|0;J=k}k=bG(E|0)|0;c[(c[J>>2]|0)+(c[C>>2]<<4)>>2]=k;c[(c[J>>2]|0)+(c[C>>2]<<4)+4>>2]=0;c[(c[J>>2]|0)+(c[C>>2]<<4)+8>>2]=A;c[(c[J>>2]|0)+(c[C>>2]<<4)+12>>2]=0;c[C>>2]=(c[C>>2]|0)+1}f=f+1|0;}while(f>>>0<(c[F>>2]|0)>>>0);i=e;return};case 68:{F=b+52|0;f=c[F>>2]|0;J=f+8|0;if((c[J>>2]|0)!=0){E=f|0;f=0;do{gGr(c[(c[E>>2]|0)+(f<<4)>>2]|0);gGr(c[(c[E>>2]|0)+(f<<4)+4>>2]|0);f=f+1|0;}while(f>>>0<(c[J>>2]|0)>>>0)}c[J>>2]=0;J=c[F>>2]|0;do{if((J|0)!=0){f=J+8|0;E=J+4|0;d=c[E>>2]|0;if((c[f>>2]|0)>>>0<d>>>0){K=J|0}else{I=(d<<1)+2|0;c[E>>2]=I;E=J|0;c[E>>2]=gGs(c[E>>2]|0,I<<4)|0;K=E}E=bG(107568)|0;c[(c[K>>2]|0)+(c[f>>2]<<4)>>2]=E;c[(c[K>>2]|0)+(c[f>>2]<<4)+4>>2]=0;c[(c[K>>2]|0)+(c[f>>2]<<4)+8>>2]=104;c[(c[K>>2]|0)+(c[f>>2]<<4)+12>>2]=0;c[f>>2]=(c[f>>2]|0)+1;f=c[F>>2]|0;if((f|0)==0){break}E=f+8|0;I=f+4|0;d=c[I>>2]|0;if((c[E>>2]|0)>>>0<d>>>0){L=f|0}else{H=(d<<1)+2|0;c[I>>2]=H;I=f|0;c[I>>2]=gGs(c[I>>2]|0,H<<4)|0;L=I}I=bG(105768)|0;c[(c[L>>2]|0)+(c[E>>2]<<4)>>2]=I;c[(c[L>>2]|0)+(c[E>>2]<<4)+4>>2]=0;c[(c[L>>2]|0)+(c[E>>2]<<4)+8>>2]=105;c[(c[L>>2]|0)+(c[E>>2]<<4)+12>>2]=0;c[E>>2]=(c[E>>2]|0)+1;E=c[F>>2]|0;if((E|0)==0){break}I=E+8|0;H=E+4|0;f=c[H>>2]|0;if((c[I>>2]|0)>>>0<f>>>0){M=E|0}else{d=(f<<1)+2|0;c[H>>2]=d;H=E|0;c[H>>2]=gGs(c[H>>2]|0,d<<4)|0;M=H}H=bG(102696)|0;c[(c[M>>2]|0)+(c[I>>2]<<4)>>2]=H;c[(c[M>>2]|0)+(c[I>>2]<<4)+4>>2]=0;c[(c[M>>2]|0)+(c[I>>2]<<4)+8>>2]=106;c[(c[M>>2]|0)+(c[I>>2]<<4)+12>>2]=0;c[I>>2]=(c[I>>2]|0)+1;I=c[F>>2]|0;if((I|0)==0){break}H=I+8|0;d=I+4|0;E=c[d>>2]|0;if((c[H>>2]|0)>>>0<E>>>0){N=I|0}else{f=(E<<1)+2|0;c[d>>2]=f;d=I|0;c[d>>2]=gGs(c[d>>2]|0,f<<4)|0;N=d}d=bG(99752)|0;c[(c[N>>2]|0)+(c[H>>2]<<4)>>2]=d;c[(c[N>>2]|0)+(c[H>>2]<<4)+4>>2]=0;c[(c[N>>2]|0)+(c[H>>2]<<4)+8>>2]=107;c[(c[N>>2]|0)+(c[H>>2]<<4)+12>>2]=0;c[H>>2]=(c[H>>2]|0)+1;H=c[F>>2]|0;if((H|0)==0){break}d=H+8|0;f=H+4|0;I=c[f>>2]|0;if((c[d>>2]|0)>>>0<I>>>0){O=H|0}else{E=(I<<1)+2|0;c[f>>2]=E;f=H|0;c[f>>2]=gGs(c[f>>2]|0,E<<4)|0;O=f}f=bG(96256)|0;c[(c[O>>2]|0)+(c[d>>2]<<4)>>2]=f;c[(c[O>>2]|0)+(c[d>>2]<<4)+4>>2]=0;c[(c[O>>2]|0)+(c[d>>2]<<4)+8>>2]=108;c[(c[O>>2]|0)+(c[d>>2]<<4)+12>>2]=0;c[d>>2]=(c[d>>2]|0)+1;d=c[F>>2]|0;if((d|0)==0){break}f=d+8|0;E=d+4|0;H=c[E>>2]|0;if((c[f>>2]|0)>>>0<H>>>0){P=d|0}else{I=(H<<1)+2|0;c[E>>2]=I;E=d|0;c[E>>2]=gGs(c[E>>2]|0,I<<4)|0;P=E}E=bG(92856)|0;c[(c[P>>2]|0)+(c[f>>2]<<4)>>2]=E;c[(c[P>>2]|0)+(c[f>>2]<<4)+4>>2]=0;c[(c[P>>2]|0)+(c[f>>2]<<4)+8>>2]=109;c[(c[P>>2]|0)+(c[f>>2]<<4)+12>>2]=0;c[f>>2]=(c[f>>2]|0)+1;f=c[F>>2]|0;if((f|0)==0){break}E=f+8|0;I=f+4|0;d=c[I>>2]|0;if((c[E>>2]|0)>>>0<d>>>0){Q=f|0}else{H=(d<<1)+2|0;c[I>>2]=H;I=f|0;c[I>>2]=gGs(c[I>>2]|0,H<<4)|0;Q=I}I=bG(89992)|0;c[(c[Q>>2]|0)+(c[E>>2]<<4)>>2]=I;c[(c[Q>>2]|0)+(c[E>>2]<<4)+4>>2]=0;c[(c[Q>>2]|0)+(c[E>>2]<<4)+8>>2]=167;c[(c[Q>>2]|0)+(c[E>>2]<<4)+12>>2]=0;c[E>>2]=(c[E>>2]|0)+1;E=c[F>>2]|0;if((E|0)==0){break}I=E+8|0;H=E+4|0;f=c[H>>2]|0;if((c[I>>2]|0)>>>0<f>>>0){R=E|0}else{d=(f<<1)+2|0;c[H>>2]=d;H=E|0;c[H>>2]=gGs(c[H>>2]|0,d<<4)|0;R=H}H=bG(88352)|0;c[(c[R>>2]|0)+(c[I>>2]<<4)>>2]=H;c[(c[R>>2]|0)+(c[I>>2]<<4)+4>>2]=0;c[(c[R>>2]|0)+(c[I>>2]<<4)+8>>2]=168;c[(c[R>>2]|0)+(c[I>>2]<<4)+12>>2]=0;c[I>>2]=(c[I>>2]|0)+1}}while(0);do{if((c[b+130280>>2]|0)==0){R=c[F>>2]|0;if((R|0)==0){break}Q=R+8|0;P=R+4|0;O=c[P>>2]|0;if((c[Q>>2]|0)>>>0<O>>>0){S=R|0}else{N=(O<<1)+2|0;c[P>>2]=N;P=R|0;c[P>>2]=gGs(c[P>>2]|0,N<<4)|0;S=P}P=bG(86496)|0;c[(c[S>>2]|0)+(c[Q>>2]<<4)>>2]=P;c[(c[S>>2]|0)+(c[Q>>2]<<4)+4>>2]=0;c[(c[S>>2]|0)+(c[Q>>2]<<4)+8>>2]=165;c[(c[S>>2]|0)+(c[Q>>2]<<4)+12>>2]=0;c[Q>>2]=(c[Q>>2]|0)+1}}while(0);S=c[2383356]|0;if((S|0)==0){T=133}else{T=(c[S+20>>2]|0)!=0?125:133}S=110;do{Q=c[F>>2]|0;P=c[46700+((S-110|0)*20|0)>>2]|0;if((Q|0)!=0){N=Q+8|0;R=Q+4|0;O=c[R>>2]|0;if((c[N>>2]|0)>>>0<O>>>0){U=Q|0}else{M=(O<<1)+2|0;c[R>>2]=M;R=Q|0;c[R>>2]=gGs(c[R>>2]|0,M<<4)|0;U=R}R=bG(P|0)|0;c[(c[U>>2]|0)+(c[N>>2]<<4)>>2]=R;c[(c[U>>2]|0)+(c[N>>2]<<4)+4>>2]=0;c[(c[U>>2]|0)+(c[N>>2]<<4)+8>>2]=S;c[(c[U>>2]|0)+(c[N>>2]<<4)+12>>2]=0;c[N>>2]=(c[N>>2]|0)+1}S=S+1|0;}while(S>>>0<=T>>>0);i=e;return};case 70:{T=b+52|0;S=c[T>>2]|0;U=S+8|0;if((c[U>>2]|0)!=0){F=S|0;S=0;do{gGr(c[(c[F>>2]|0)+(S<<4)>>2]|0);gGr(c[(c[F>>2]|0)+(S<<4)+4>>2]|0);S=S+1|0;}while(S>>>0<(c[U>>2]|0)>>>0)}c[U>>2]=0;U=c[T>>2]|0;do{if((U|0)!=0){S=U+8|0;F=U+4|0;N=c[F>>2]|0;if((c[S>>2]|0)>>>0<N>>>0){V=U|0}else{R=(N<<1)+2|0;c[F>>2]=R;F=U|0;c[F>>2]=gGs(c[F>>2]|0,R<<4)|0;V=F}F=bG(167584)|0;c[(c[V>>2]|0)+(c[S>>2]<<4)>>2]=F;c[(c[V>>2]|0)+(c[S>>2]<<4)+4>>2]=0;c[(c[V>>2]|0)+(c[S>>2]<<4)+8>>2]=6;c[(c[V>>2]|0)+(c[S>>2]<<4)+12>>2]=0;c[S>>2]=(c[S>>2]|0)+1;S=c[T>>2]|0;if((S|0)==0){break}F=S+8|0;R=S+4|0;N=c[R>>2]|0;if((c[F>>2]|0)>>>0<N>>>0){W=S|0}else{P=(N<<1)+2|0;c[R>>2]=P;R=S|0;c[R>>2]=gGs(c[R>>2]|0,P<<4)|0;W=R}R=bG(164720)|0;c[(c[W>>2]|0)+(c[F>>2]<<4)>>2]=R;c[(c[W>>2]|0)+(c[F>>2]<<4)+4>>2]=0;c[(c[W>>2]|0)+(c[F>>2]<<4)+8>>2]=67;c[(c[W>>2]|0)+(c[F>>2]<<4)+12>>2]=0;c[F>>2]=(c[F>>2]|0)+1;F=c[T>>2]|0;if((F|0)==0){break}R=F+8|0;P=F+4|0;S=c[P>>2]|0;if((c[R>>2]|0)>>>0<S>>>0){X=F|0}else{N=(S<<1)+2|0;c[P>>2]=N;P=F|0;c[P>>2]=gGs(c[P>>2]|0,N<<4)|0;X=P}P=bG(161408)|0;c[(c[X>>2]|0)+(c[R>>2]<<4)>>2]=P;c[(c[X>>2]|0)+(c[R>>2]<<4)+4>>2]=0;c[(c[X>>2]|0)+(c[R>>2]<<4)+8>>2]=68;c[(c[X>>2]|0)+(c[R>>2]<<4)+12>>2]=0;c[R>>2]=(c[R>>2]|0)+1;R=c[T>>2]|0;if((R|0)==0){break}P=R+8|0;N=R+4|0;F=c[N>>2]|0;if((c[P>>2]|0)>>>0<F>>>0){Y=R|0}else{S=(F<<1)+2|0;c[N>>2]=S;N=R|0;c[N>>2]=gGs(c[N>>2]|0,S<<4)|0;Y=N}N=bG(157792)|0;c[(c[Y>>2]|0)+(c[P>>2]<<4)>>2]=N;c[(c[Y>>2]|0)+(c[P>>2]<<4)+4>>2]=0;c[(c[Y>>2]|0)+(c[P>>2]<<4)+8>>2]=69;c[(c[Y>>2]|0)+(c[P>>2]<<4)+12>>2]=0;c[P>>2]=(c[P>>2]|0)+1}}while(0);do{if((a[9532116]&1)!=0){if(!((a[9533305]&1)==0&(c[2368521]|0)!=0)){break}Y=c[T>>2]|0;if((Y|0)==0){i=e;return}X=Y+8|0;W=Y+4|0;V=c[W>>2]|0;if((c[X>>2]|0)>>>0<V>>>0){Z=Y|0}else{U=(V<<1)+2|0;c[W>>2]=U;W=Y|0;c[W>>2]=gGs(c[W>>2]|0,U<<4)|0;Z=W}W=bG(154624)|0;c[(c[Z>>2]|0)+(c[X>>2]<<4)>>2]=W;c[(c[Z>>2]|0)+(c[X>>2]<<4)+4>>2]=0;c[(c[Z>>2]|0)+(c[X>>2]<<4)+8>>2]=78;c[(c[Z>>2]|0)+(c[X>>2]<<4)+12>>2]=0;c[X>>2]=(c[X>>2]|0)+1}}while(0);Z=c[T>>2]|0;if((Z|0)==0){i=e;return}X=Z+8|0;W=Z+4|0;U=c[W>>2]|0;if((c[X>>2]|0)>>>0<U>>>0){_=Z|0}else{Y=(U<<1)+2|0;c[W>>2]=Y;W=Z|0;c[W>>2]=gGs(c[W>>2]|0,Y<<4)|0;_=W}W=bG(150632)|0;c[(c[_>>2]|0)+(c[X>>2]<<4)>>2]=W;c[(c[_>>2]|0)+(c[X>>2]<<4)+4>>2]=0;c[(c[_>>2]|0)+(c[X>>2]<<4)+8>>2]=72;c[(c[_>>2]|0)+(c[X>>2]<<4)+12>>2]=0;c[X>>2]=(c[X>>2]|0)+1;X=c[T>>2]|0;if((X|0)==0){i=e;return}_=X+8|0;W=X+4|0;Y=c[W>>2]|0;if((c[_>>2]|0)>>>0<Y>>>0){$=X|0}else{Z=(Y<<1)+2|0;c[W>>2]=Z;W=X|0;c[W>>2]=gGs(c[W>>2]|0,Z<<4)|0;$=W}W=bG(147536)|0;c[(c[$>>2]|0)+(c[_>>2]<<4)>>2]=W;c[(c[$>>2]|0)+(c[_>>2]<<4)+4>>2]=0;c[(c[$>>2]|0)+(c[_>>2]<<4)+8>>2]=73;c[(c[$>>2]|0)+(c[_>>2]<<4)+12>>2]=0;c[_>>2]=(c[_>>2]|0)+1;_=c[T>>2]|0;if((_|0)==0){i=e;return}$=_+8|0;W=_+4|0;Z=c[W>>2]|0;if((c[$>>2]|0)>>>0<Z>>>0){aa=_|0}else{X=(Z<<1)+2|0;c[W>>2]=X;W=_|0;c[W>>2]=gGs(c[W>>2]|0,X<<4)|0;aa=W}W=bG(143184)|0;c[(c[aa>>2]|0)+(c[$>>2]<<4)>>2]=W;c[(c[aa>>2]|0)+(c[$>>2]<<4)+4>>2]=0;c[(c[aa>>2]|0)+(c[$>>2]<<4)+8>>2]=85;c[(c[aa>>2]|0)+(c[$>>2]<<4)+12>>2]=0;c[$>>2]=(c[$>>2]|0)+1;$=c[T>>2]|0;if(($|0)==0){i=e;return}aa=$+8|0;W=$+4|0;X=c[W>>2]|0;if((c[aa>>2]|0)>>>0<X>>>0){ab=$|0}else{_=(X<<1)+2|0;c[W>>2]=_;W=$|0;c[W>>2]=gGs(c[W>>2]|0,_<<4)|0;ab=W}W=bG(140384)|0;c[(c[ab>>2]|0)+(c[aa>>2]<<4)>>2]=W;c[(c[ab>>2]|0)+(c[aa>>2]<<4)+4>>2]=0;c[(c[ab>>2]|0)+(c[aa>>2]<<4)+8>>2]=74;c[(c[ab>>2]|0)+(c[aa>>2]<<4)+12>>2]=0;c[aa>>2]=(c[aa>>2]|0)+1;aa=c[T>>2]|0;if((aa|0)==0){i=e;return}T=aa+8|0;ab=aa+4|0;W=c[ab>>2]|0;if((c[T>>2]|0)>>>0<W>>>0){ac=aa|0}else{_=(W<<1)+2|0;c[ab>>2]=_;ab=aa|0;c[ab>>2]=gGs(c[ab>>2]|0,_<<4)|0;ac=ab}ab=bG(137840)|0;c[(c[ac>>2]|0)+(c[T>>2]<<4)>>2]=ab;c[(c[ac>>2]|0)+(c[T>>2]<<4)+4>>2]=0;c[(c[ac>>2]|0)+(c[T>>2]<<4)+8>>2]=100;c[(c[ac>>2]|0)+(c[T>>2]<<4)+12>>2]=0;c[T>>2]=(c[T>>2]|0)+1;i=e;return};case 78:{T=b+52|0;ac=c[T>>2]|0;ab=ac+8|0;if((c[ab>>2]|0)!=0){_=ac|0;ac=0;do{gGr(c[(c[_>>2]|0)+(ac<<4)>>2]|0);gGr(c[(c[_>>2]|0)+(ac<<4)+4>>2]|0);ac=ac+1|0;}while(ac>>>0<(c[ab>>2]|0)>>>0)}c[ab>>2]=0;ab=c[T>>2]|0;if((ab|0)==0){i=e;return}ac=ab+8|0;_=ab+4|0;aa=c[_>>2]|0;if((c[ac>>2]|0)>>>0<aa>>>0){ad=ab|0}else{W=(aa<<1)+2|0;c[_>>2]=W;_=ab|0;c[_>>2]=gGs(c[_>>2]|0,W<<4)|0;ad=_}_=bG(135224)|0;c[(c[ad>>2]|0)+(c[ac>>2]<<4)>>2]=_;c[(c[ad>>2]|0)+(c[ac>>2]<<4)+4>>2]=0;c[(c[ad>>2]|0)+(c[ac>>2]<<4)+8>>2]=79;c[(c[ad>>2]|0)+(c[ac>>2]<<4)+12>>2]=0;c[ac>>2]=(c[ac>>2]|0)+1;ac=c[T>>2]|0;if((ac|0)==0){i=e;return}T=ac+8|0;ad=ac+4|0;_=c[ad>>2]|0;if((c[T>>2]|0)>>>0<_>>>0){ae=ac|0}else{W=(_<<1)+2|0;c[ad>>2]=W;ad=ac|0;c[ad>>2]=gGs(c[ad>>2]|0,W<<4)|0;ae=ad}ad=bG(132992)|0;c[(c[ae>>2]|0)+(c[T>>2]<<4)>>2]=ad;c[(c[ae>>2]|0)+(c[T>>2]<<4)+4>>2]=0;c[(c[ae>>2]|0)+(c[T>>2]<<4)+8>>2]=80;c[(c[ae>>2]|0)+(c[T>>2]<<4)+12>>2]=0;c[T>>2]=(c[T>>2]|0)+1;i=e;return};case 66:{T=b+52|0;ae=c[T>>2]|0;ad=ae+8|0;if((c[ad>>2]|0)!=0){W=ae|0;ae=0;do{gGr(c[(c[W>>2]|0)+(ae<<4)>>2]|0);gGr(c[(c[W>>2]|0)+(ae<<4)+4>>2]|0);ae=ae+1|0;}while(ae>>>0<(c[ad>>2]|0)>>>0)}c[ad>>2]=0;ad=c[2368540]|0;if((ad|0)==0){ae=c[T>>2]|0;if((ae|0)==0){i=e;return}W=ae+8|0;ac=ae+4|0;_=c[ac>>2]|0;if((c[W>>2]|0)>>>0<_>>>0){af=ae|0}else{ab=(_<<1)+2|0;c[ac>>2]=ab;ac=ae|0;c[ac>>2]=gGs(c[ac>>2]|0,ab<<4)|0;af=ac}ac=bG(170808)|0;c[(c[af>>2]|0)+(c[W>>2]<<4)>>2]=ac;c[(c[af>>2]|0)+(c[W>>2]<<4)+4>>2]=0;c[(c[af>>2]|0)+(c[W>>2]<<4)+8>>2]=65535;c[(c[af>>2]|0)+(c[W>>2]<<4)+12>>2]=0;c[W>>2]=(c[W>>2]|0)+1;i=e;return}W=c[ad+4104>>2]|0;if((W|0)==0){i=e;return}else{ag=0;ah=ad}while(1){ad=c[T>>2]|0;af=c[(c[ah+4100>>2]|0)+(ag<<4)>>2]|0;ac=ag+65536|0;if((ad|0)!=0){ab=ad+8|0;ae=ad+4|0;_=c[ae>>2]|0;if((c[ab>>2]|0)>>>0<_>>>0){ai=ad|0}else{aa=(_<<1)+2|0;c[ae>>2]=aa;ae=ad|0;c[ae>>2]=gGs(c[ae>>2]|0,aa<<4)|0;ai=ae}ae=bG(af|0)|0;c[(c[ai>>2]|0)+(c[ab>>2]<<4)>>2]=ae;c[(c[ai>>2]|0)+(c[ab>>2]<<4)+4>>2]=0;c[(c[ai>>2]|0)+(c[ab>>2]<<4)+8>>2]=ac;c[(c[ai>>2]|0)+(c[ab>>2]<<4)+12>>2]=0;c[ab>>2]=(c[ab>>2]|0)+1}ab=ag+1|0;if(ab>>>0>=W>>>0){break}ag=ab;ah=c[2368540]|0}i=e;return};case 4:{ah=b+52|0;ag=c[ah>>2]|0;W=ag+8|0;if((c[W>>2]|0)!=0){ai=ag|0;ag=0;do{gGr(c[(c[ai>>2]|0)+(ag<<4)>>2]|0);gGr(c[(c[ai>>2]|0)+(ag<<4)+4>>2]|0);ag=ag+1|0;}while(ag>>>0<(c[W>>2]|0)>>>0)}c[W>>2]=0;do{if((c[b+130284>>2]|0)!=0){W=c[ah>>2]|0;if((W|0)==0){break}ag=W+8|0;ai=W+4|0;T=c[ai>>2]|0;if((c[ag>>2]|0)>>>0<T>>>0){aj=W|0}else{ab=(T<<1)+2|0;c[ai>>2]=ab;ai=W|0;c[ai>>2]=gGs(c[ai>>2]|0,ab<<4)|0;aj=ai}ai=bG(75288)|0;c[(c[aj>>2]|0)+(c[ag>>2]<<4)>>2]=ai;c[(c[aj>>2]|0)+(c[ag>>2]<<4)+4>>2]=0;c[(c[aj>>2]|0)+(c[ag>>2]<<4)+8>>2]=61;c[(c[aj>>2]|0)+(c[ag>>2]<<4)+12>>2]=0;c[ag>>2]=(c[ag>>2]|0)+1}}while(0);aj=c[b+64>>2]|0;do{if((aj|0)!=0){ag=c[aj+4>>2]|0;if((ag|0)==0){break}ai=c[aj>>2]|0;ab=0;W=0;do{W=((c[ai+(ab*28|0)+4>>2]|0)!=0)+W|0;ab=ab+1|0;}while(ab>>>0<ag>>>0);if((W|0)==0){break}ag=c[ah>>2]|0;if((ag|0)==0){break}ab=ag+8|0;ai=ag+4|0;T=c[ai>>2]|0;if((c[ab>>2]|0)>>>0<T>>>0){ak=ag|0}else{ac=(T<<1)+2|0;c[ai>>2]=ac;ai=ag|0;c[ai>>2]=gGs(c[ai>>2]|0,ac<<4)|0;ak=ai}ai=bG(72896)|0;c[(c[ak>>2]|0)+(c[ab>>2]<<4)>>2]=ai;c[(c[ak>>2]|0)+(c[ab>>2]<<4)+4>>2]=0;c[(c[ak>>2]|0)+(c[ab>>2]<<4)+8>>2]=60;c[(c[ak>>2]|0)+(c[ab>>2]<<4)+12>>2]=0;c[ab>>2]=(c[ab>>2]|0)+1}}while(0);ak=c[b+20796>>2]|0;aj=(ak|0)!=0;ab=c[2367342]|0;do{if(aj|(ab|0)!=0){ai=g|0;ac=aj?ak:ab;be(ai|0,64,70128,(G=i,i=i+8|0,c[G>>2]=ac,G)|0)|0;i=G;ac=c[ah>>2]|0;if((ac|0)==0){break}ag=ac+8|0;T=ac+4|0;ae=c[T>>2]|0;if((c[ag>>2]|0)>>>0<ae>>>0){al=ac|0}else{af=(ae<<1)+2|0;c[T>>2]=af;T=ac|0;c[T>>2]=gGs(c[T>>2]|0,af<<4)|0;al=T}T=bG(ai|0)|0;c[(c[al>>2]|0)+(c[ag>>2]<<4)>>2]=T;c[(c[al>>2]|0)+(c[ag>>2]<<4)+4>>2]=0;c[(c[al>>2]|0)+(c[ag>>2]<<4)+8>>2]=59;c[(c[al>>2]|0)+(c[ag>>2]<<4)+12>>2]=0;c[ag>>2]=(c[ag>>2]|0)+1;am=6562}else{am=6562}}while(0);do{if((am|0)==6562){al=c[ah>>2]|0;if((al|0)==0){break}G=al+8|0;ab=al+4|0;ak=c[ab>>2]|0;if((c[G>>2]|0)>>>0<ak>>>0){an=al|0}else{aj=(ak<<1)+2|0;c[ab>>2]=aj;ab=al|0;c[ab>>2]=gGs(c[ab>>2]|0,aj<<4)|0;an=ab}ab=bG(68832)|0;c[(c[an>>2]|0)+(c[G>>2]<<4)>>2]=ab;c[(c[an>>2]|0)+(c[G>>2]<<4)+4>>2]=0;c[(c[an>>2]|0)+(c[G>>2]<<4)+8>>2]=66;c[(c[an>>2]|0)+(c[G>>2]<<4)+12>>2]=0;c[G>>2]=(c[G>>2]|0)+1;G=c[ah>>2]|0;if((G|0)==0){break}ab=G+8|0;aj=G+4|0;al=c[aj>>2]|0;if((c[ab>>2]|0)>>>0<al>>>0){ao=G|0}else{ak=(al<<1)+2|0;c[aj>>2]=ak;aj=G|0;c[aj>>2]=gGs(c[aj>>2]|0,ak<<4)|0;ao=aj}aj=bG(67536)|0;c[(c[ao>>2]|0)+(c[ab>>2]<<4)>>2]=aj;c[(c[ao>>2]|0)+(c[ab>>2]<<4)+4>>2]=0;c[(c[ao>>2]|0)+(c[ab>>2]<<4)+8>>2]=70;c[(c[ao>>2]|0)+(c[ab>>2]<<4)+12>>2]=0;c[ab>>2]=(c[ab>>2]|0)+1;ab=c[ah>>2]|0;if((ab|0)==0){break}aj=ab+8|0;ak=ab+4|0;G=c[ak>>2]|0;if((c[aj>>2]|0)>>>0<G>>>0){ap=ab|0}else{al=(G<<1)+2|0;c[ak>>2]=al;ak=ab|0;c[ak>>2]=gGs(c[ak>>2]|0,al<<4)|0;ap=ak}ak=bG(66072)|0;c[(c[ap>>2]|0)+(c[aj>>2]<<4)>>2]=ak;c[(c[ap>>2]|0)+(c[aj>>2]<<4)+4>>2]=0;c[(c[ap>>2]|0)+(c[aj>>2]<<4)+8>>2]=71;c[(c[ap>>2]|0)+(c[aj>>2]<<4)+12>>2]=0;c[aj>>2]=(c[aj>>2]|0)+1}}while(0);do{if((a[9532116]&1)!=0){if((a[9533305]&1)!=0){break}ap=c[ah>>2]|0;if((ap|0)==0){i=e;return}ao=ap+8|0;an=ap+4|0;am=c[an>>2]|0;if((c[ao>>2]|0)>>>0<am>>>0){aq=ap|0}else{aj=(am<<1)+2|0;c[an>>2]=aj;an=ap|0;c[an>>2]=gGs(c[an>>2]|0,aj<<4)|0;aq=an}an=bG(589520)|0;c[(c[aq>>2]|0)+(c[ao>>2]<<4)>>2]=an;c[(c[aq>>2]|0)+(c[ao>>2]<<4)+4>>2]=0;c[(c[aq>>2]|0)+(c[ao>>2]<<4)+8>>2]=76;c[(c[aq>>2]|0)+(c[ao>>2]<<4)+12>>2]=0;c[ao>>2]=(c[ao>>2]|0)+1;ao=c[ah>>2]|0;if((ao|0)==0){i=e;return}an=ao+8|0;aj=ao+4|0;ap=c[aj>>2]|0;if((c[an>>2]|0)>>>0<ap>>>0){ar=ao|0}else{am=(ap<<1)+2|0;c[aj>>2]=am;aj=ao|0;c[aj>>2]=gGs(c[aj>>2]|0,am<<4)|0;ar=aj}aj=bG(588240)|0;c[(c[ar>>2]|0)+(c[an>>2]<<4)>>2]=aj;c[(c[ar>>2]|0)+(c[an>>2]<<4)+4>>2]=0;c[(c[ar>>2]|0)+(c[an>>2]<<4)+8>>2]=77;c[(c[ar>>2]|0)+(c[an>>2]<<4)+12>>2]=0;c[an>>2]=(c[an>>2]|0)+1;an=c[ah>>2]|0;if((an|0)==0){i=e;return}aj=an+8|0;am=an+4|0;ao=c[am>>2]|0;if((c[aj>>2]|0)>>>0<ao>>>0){as=an|0}else{ap=(ao<<1)+2|0;c[am>>2]=ap;am=an|0;c[am>>2]=gGs(c[am>>2]|0,ap<<4)|0;as=am}am=bG(586184)|0;c[(c[as>>2]|0)+(c[aj>>2]<<4)>>2]=am;c[(c[as>>2]|0)+(c[aj>>2]<<4)+4>>2]=0;c[(c[as>>2]|0)+(c[aj>>2]<<4)+8>>2]=84;c[(c[as>>2]|0)+(c[aj>>2]<<4)+12>>2]=0;c[aj>>2]=(c[aj>>2]|0)+1;aj=c[ah>>2]|0;if((aj|0)==0){i=e;return}am=aj+8|0;ap=aj+4|0;an=c[ap>>2]|0;if((c[am>>2]|0)>>>0<an>>>0){at=aj|0}else{ao=(an<<1)+2|0;c[ap>>2]=ao;ap=aj|0;c[ap>>2]=gGs(c[ap>>2]|0,ao<<4)|0;at=ap}ap=bG(584416)|0;c[(c[at>>2]|0)+(c[am>>2]<<4)>>2]=ap;c[(c[at>>2]|0)+(c[am>>2]<<4)+4>>2]=0;c[(c[at>>2]|0)+(c[am>>2]<<4)+8>>2]=102;c[(c[at>>2]|0)+(c[am>>2]<<4)+12>>2]=0;c[am>>2]=(c[am>>2]|0)+1;am=c[ah>>2]|0;if((am|0)==0){i=e;return}ap=am+8|0;ao=am+4|0;aj=c[ao>>2]|0;if((c[ap>>2]|0)>>>0<aj>>>0){au=am|0}else{an=(aj<<1)+2|0;c[ao>>2]=an;ao=am|0;c[ao>>2]=gGs(c[ao>>2]|0,an<<4)|0;au=ao}ao=bG(582568)|0;c[(c[au>>2]|0)+(c[ap>>2]<<4)>>2]=ao;c[(c[au>>2]|0)+(c[ap>>2]<<4)+4>>2]=0;c[(c[au>>2]|0)+(c[ap>>2]<<4)+8>>2]=96;c[(c[au>>2]|0)+(c[ap>>2]<<4)+12>>2]=0;c[ap>>2]=(c[ap>>2]|0)+1}}while(0);au=c[ah>>2]|0;if((au|0)==0){i=e;return}at=au+8|0;as=au+4|0;ar=c[as>>2]|0;if((c[at>>2]|0)>>>0<ar>>>0){av=au|0}else{aq=(ar<<1)+2|0;c[as>>2]=aq;as=au|0;c[as>>2]=gGs(c[as>>2]|0,aq<<4)|0;av=as}as=bG(580336)|0;c[(c[av>>2]|0)+(c[at>>2]<<4)>>2]=as;c[(c[av>>2]|0)+(c[at>>2]<<4)+4>>2]=0;c[(c[av>>2]|0)+(c[at>>2]<<4)+8>>2]=101;c[(c[av>>2]|0)+(c[at>>2]<<4)+12>>2]=0;c[at>>2]=(c[at>>2]|0)+1;at=c[ah>>2]|0;if((at|0)==0){i=e;return}av=at+8|0;as=at+4|0;aq=c[as>>2]|0;if((c[av>>2]|0)>>>0<aq>>>0){aw=at|0}else{au=(aq<<1)+2|0;c[as>>2]=au;as=at|0;c[as>>2]=gGs(c[as>>2]|0,au<<4)|0;aw=as}as=bG(578112)|0;c[(c[aw>>2]|0)+(c[av>>2]<<4)>>2]=as;c[(c[aw>>2]|0)+(c[av>>2]<<4)+4>>2]=0;c[(c[aw>>2]|0)+(c[av>>2]<<4)+8>>2]=64;c[(c[aw>>2]|0)+(c[av>>2]<<4)+12>>2]=0;c[av>>2]=(c[av>>2]|0)+1;av=c[ah>>2]|0;if((av|0)==0){i=e;return}aw=av+8|0;as=av+4|0;au=c[as>>2]|0;if((c[aw>>2]|0)>>>0<au>>>0){ax=av|0}else{at=(au<<1)+2|0;c[as>>2]=at;as=av|0;c[as>>2]=gGs(c[as>>2]|0,at<<4)|0;ax=as}as=bG(576984)|0;c[(c[ax>>2]|0)+(c[aw>>2]<<4)>>2]=as;c[(c[ax>>2]|0)+(c[aw>>2]<<4)+4>>2]=0;c[(c[ax>>2]|0)+(c[aw>>2]<<4)+8>>2]=65;c[(c[ax>>2]|0)+(c[aw>>2]<<4)+12>>2]=0;c[aw>>2]=(c[aw>>2]|0)+1;aw=c[ah>>2]|0;if((aw|0)==0){i=e;return}ax=aw+8|0;as=aw+4|0;at=c[as>>2]|0;if((c[ax>>2]|0)>>>0<at>>>0){ay=aw|0}else{av=(at<<1)+2|0;c[as>>2]=av;as=aw|0;c[as>>2]=gGs(c[as>>2]|0,av<<4)|0;ay=as}as=bG(575688)|0;c[(c[ay>>2]|0)+(c[ax>>2]<<4)>>2]=as;c[(c[ay>>2]|0)+(c[ax>>2]<<4)+4>>2]=0;c[(c[ay>>2]|0)+(c[ax>>2]<<4)+8>>2]=5;c[(c[ay>>2]|0)+(c[ax>>2]<<4)+12>>2]=0;c[ax>>2]=(c[ax>>2]|0)+1;ax=c[ah>>2]|0;if((ax|0)==0){i=e;return}ah=ax+8|0;ay=ax+4|0;as=c[ay>>2]|0;if((c[ah>>2]|0)>>>0<as>>>0){az=ax|0}else{av=(as<<1)+2|0;c[ay>>2]=av;ay=ax|0;c[ay>>2]=gGs(c[ay>>2]|0,av<<4)|0;az=ay}ay=bG(574552)|0;c[(c[az>>2]|0)+(c[ah>>2]<<4)>>2]=ay;c[(c[az>>2]|0)+(c[ah>>2]<<4)+4>>2]=0;c[(c[az>>2]|0)+(c[ah>>2]<<4)+8>>2]=103;c[(c[az>>2]|0)+(c[ah>>2]<<4)+12>>2]=0;c[ah>>2]=(c[ah>>2]|0)+1;i=e;return};case 71:{ah=b+52|0;az=c[ah>>2]|0;ay=az+8|0;if((c[ay>>2]|0)!=0){av=az|0;az=0;do{gGr(c[(c[av>>2]|0)+(az<<4)>>2]|0);gGr(c[(c[av>>2]|0)+(az<<4)+4>>2]|0);az=az+1|0;}while(az>>>0<(c[ay>>2]|0)>>>0)}c[ay>>2]=0;ay=c[ah>>2]|0;if((ay|0)==0){i=e;return}az=ay+8|0;av=ay+4|0;ax=c[av>>2]|0;if((c[az>>2]|0)>>>0<ax>>>0){aA=ay|0}else{as=(ax<<1)+2|0;c[av>>2]=as;av=ay|0;c[av>>2]=gGs(c[av>>2]|0,as<<4)|0;aA=av}av=bG(81560)|0;c[(c[aA>>2]|0)+(c[az>>2]<<4)>>2]=av;c[(c[aA>>2]|0)+(c[az>>2]<<4)+4>>2]=0;c[(c[aA>>2]|0)+(c[az>>2]<<4)+8>>2]=81;c[(c[aA>>2]|0)+(c[az>>2]<<4)+12>>2]=0;c[az>>2]=(c[az>>2]|0)+1;az=c[ah>>2]|0;if((az|0)==0){i=e;return}aA=az+8|0;av=az+4|0;as=c[av>>2]|0;if((c[aA>>2]|0)>>>0<as>>>0){aB=az|0}else{ay=(as<<1)+2|0;c[av>>2]=ay;av=az|0;c[av>>2]=gGs(c[av>>2]|0,ay<<4)|0;aB=av}av=bG(79448)|0;c[(c[aB>>2]|0)+(c[aA>>2]<<4)>>2]=av;c[(c[aB>>2]|0)+(c[aA>>2]<<4)+4>>2]=0;c[(c[aB>>2]|0)+(c[aA>>2]<<4)+8>>2]=82;c[(c[aB>>2]|0)+(c[aA>>2]<<4)+12>>2]=0;c[aA>>2]=(c[aA>>2]|0)+1;aA=c[ah>>2]|0;if((aA|0)==0){i=e;return}ah=aA+8|0;aB=aA+4|0;av=c[aB>>2]|0;if((c[ah>>2]|0)>>>0<av>>>0){aC=aA|0}else{ay=(av<<1)+2|0;c[aB>>2]=ay;aB=aA|0;c[aB>>2]=gGs(c[aB>>2]|0,ay<<4)|0;aC=aB}aB=bG(77240)|0;c[(c[aC>>2]|0)+(c[ah>>2]<<4)>>2]=aB;c[(c[aC>>2]|0)+(c[ah>>2]<<4)+4>>2]=0;c[(c[aC>>2]|0)+(c[ah>>2]<<4)+8>>2]=83;c[(c[aC>>2]|0)+(c[ah>>2]<<4)+12>>2]=0;c[ah>>2]=(c[ah>>2]|0)+1;i=e;return};case 69:{ah=b+52|0;aC=c[ah>>2]|0;aB=aC+8|0;if((c[aB>>2]|0)!=0){ay=aC|0;aC=0;do{gGr(c[(c[ay>>2]|0)+(aC<<4)>>2]|0);gGr(c[(c[ay>>2]|0)+(aC<<4)+4>>2]|0);aC=aC+1|0;}while(aC>>>0<(c[aB>>2]|0)>>>0)}c[aB>>2]=0;aB=c[ah>>2]|0;if((aB|0)==0){i=e;return}aC=aB+8|0;ay=aB+4|0;aA=c[ay>>2]|0;if((c[aC>>2]|0)>>>0<aA>>>0){aD=aB|0}else{av=(aA<<1)+2|0;c[ay>>2]=av;ay=aB|0;c[ay>>2]=gGs(c[ay>>2]|0,av<<4)|0;aD=ay}ay=bG(131056)|0;c[(c[aD>>2]|0)+(c[aC>>2]<<4)>>2]=ay;c[(c[aD>>2]|0)+(c[aC>>2]<<4)+4>>2]=0;c[(c[aD>>2]|0)+(c[aC>>2]<<4)+8>>2]=87;c[(c[aD>>2]|0)+(c[aC>>2]<<4)+12>>2]=0;c[aC>>2]=(c[aC>>2]|0)+1;aC=c[ah>>2]|0;if((aC|0)==0){i=e;return}aD=aC+8|0;ay=aC+4|0;av=c[ay>>2]|0;if((c[aD>>2]|0)>>>0<av>>>0){aE=aC|0}else{aB=(av<<1)+2|0;c[ay>>2]=aB;ay=aC|0;c[ay>>2]=gGs(c[ay>>2]|0,aB<<4)|0;aE=ay}ay=bG(127584)|0;c[(c[aE>>2]|0)+(c[aD>>2]<<4)>>2]=ay;c[(c[aE>>2]|0)+(c[aD>>2]<<4)+4>>2]=0;c[(c[aE>>2]|0)+(c[aD>>2]<<4)+8>>2]=93;c[(c[aE>>2]|0)+(c[aD>>2]<<4)+12>>2]=0;c[aD>>2]=(c[aD>>2]|0)+1;aD=c[ah>>2]|0;if((aD|0)==0){i=e;return}aE=aD+8|0;ay=aD+4|0;aB=c[ay>>2]|0;if((c[aE>>2]|0)>>>0<aB>>>0){aF=aD|0}else{aC=(aB<<1)+2|0;c[ay>>2]=aC;ay=aD|0;c[ay>>2]=gGs(c[ay>>2]|0,aC<<4)|0;aF=ay}ay=bG(124832)|0;c[(c[aF>>2]|0)+(c[aE>>2]<<4)>>2]=ay;c[(c[aF>>2]|0)+(c[aE>>2]<<4)+4>>2]=0;c[(c[aF>>2]|0)+(c[aE>>2]<<4)+8>>2]=92;c[(c[aF>>2]|0)+(c[aE>>2]<<4)+12>>2]=0;c[aE>>2]=(c[aE>>2]|0)+1;aE=c[ah>>2]|0;if((aE|0)==0){i=e;return}aF=aE+8|0;ay=aE+4|0;aC=c[ay>>2]|0;if((c[aF>>2]|0)>>>0<aC>>>0){aG=aE|0}else{aD=(aC<<1)+2|0;c[ay>>2]=aD;ay=aE|0;c[ay>>2]=gGs(c[ay>>2]|0,aD<<4)|0;aG=ay}ay=bG(121328)|0;c[(c[aG>>2]|0)+(c[aF>>2]<<4)>>2]=ay;c[(c[aG>>2]|0)+(c[aF>>2]<<4)+4>>2]=0;c[(c[aG>>2]|0)+(c[aF>>2]<<4)+8>>2]=88;c[(c[aG>>2]|0)+(c[aF>>2]<<4)+12>>2]=0;c[aF>>2]=(c[aF>>2]|0)+1;aF=c[ah>>2]|0;if((aF|0)==0){i=e;return}aG=aF+8|0;ay=aF+4|0;aD=c[ay>>2]|0;if((c[aG>>2]|0)>>>0<aD>>>0){aH=aF|0}else{aE=(aD<<1)+2|0;c[ay>>2]=aE;ay=aF|0;c[ay>>2]=gGs(c[ay>>2]|0,aE<<4)|0;aH=ay}ay=bG(117864)|0;c[(c[aH>>2]|0)+(c[aG>>2]<<4)>>2]=ay;c[(c[aH>>2]|0)+(c[aG>>2]<<4)+4>>2]=0;c[(c[aH>>2]|0)+(c[aG>>2]<<4)+8>>2]=89;c[(c[aH>>2]|0)+(c[aG>>2]<<4)+12>>2]=0;c[aG>>2]=(c[aG>>2]|0)+1;aG=c[ah>>2]|0;if((aG|0)==0){i=e;return}aH=aG+8|0;ay=aG+4|0;aE=c[ay>>2]|0;if((c[aH>>2]|0)>>>0<aE>>>0){aI=aG|0}else{aF=(aE<<1)+2|0;c[ay>>2]=aF;ay=aG|0;c[ay>>2]=gGs(c[ay>>2]|0,aF<<4)|0;aI=ay}ay=bG(115008)|0;c[(c[aI>>2]|0)+(c[aH>>2]<<4)>>2]=ay;c[(c[aI>>2]|0)+(c[aH>>2]<<4)+4>>2]=0;c[(c[aI>>2]|0)+(c[aH>>2]<<4)+8>>2]=90;c[(c[aI>>2]|0)+(c[aH>>2]<<4)+12>>2]=0;c[aH>>2]=(c[aH>>2]|0)+1;aH=c[ah>>2]|0;if((aH|0)==0){i=e;return}aI=aH+8|0;ay=aH+4|0;aF=c[ay>>2]|0;if((c[aI>>2]|0)>>>0<aF>>>0){aJ=aH|0}else{aG=(aF<<1)+2|0;c[ay>>2]=aG;ay=aH|0;c[ay>>2]=gGs(c[ay>>2]|0,aG<<4)|0;aJ=ay}ay=bG(113224)|0;c[(c[aJ>>2]|0)+(c[aI>>2]<<4)>>2]=ay;c[(c[aJ>>2]|0)+(c[aI>>2]<<4)+4>>2]=0;c[(c[aJ>>2]|0)+(c[aI>>2]<<4)+8>>2]=94;c[(c[aJ>>2]|0)+(c[aI>>2]<<4)+12>>2]=0;c[aI>>2]=(c[aI>>2]|0)+1;aI=c[ah>>2]|0;if((aI|0)==0){i=e;return}aJ=aI+8|0;ay=aI+4|0;aG=c[ay>>2]|0;if((c[aJ>>2]|0)>>>0<aG>>>0){aK=aI|0}else{aH=(aG<<1)+2|0;c[ay>>2]=aH;ay=aI|0;c[ay>>2]=gGs(c[ay>>2]|0,aH<<4)|0;aK=ay}ay=bG(111288)|0;c[(c[aK>>2]|0)+(c[aJ>>2]<<4)>>2]=ay;c[(c[aK>>2]|0)+(c[aJ>>2]<<4)+4>>2]=0;c[(c[aK>>2]|0)+(c[aJ>>2]<<4)+8>>2]=95;c[(c[aK>>2]|0)+(c[aJ>>2]<<4)+12>>2]=0;c[aJ>>2]=(c[aJ>>2]|0)+1;aJ=c[ah>>2]|0;if((aJ|0)==0){i=e;return}ah=aJ+8|0;aK=aJ+4|0;ay=c[aK>>2]|0;if((c[ah>>2]|0)>>>0<ay>>>0){aL=aJ|0}else{aH=(ay<<1)+2|0;c[aK>>2]=aH;aK=aJ|0;c[aK>>2]=gGs(c[aK>>2]|0,aH<<4)|0;aL=aK}aK=bG(109688)|0;c[(c[aL>>2]|0)+(c[ah>>2]<<4)>>2]=aK;c[(c[aL>>2]|0)+(c[ah>>2]<<4)+4>>2]=0;c[(c[aL>>2]|0)+(c[ah>>2]<<4)+8>>2]=86;c[(c[aL>>2]|0)+(c[ah>>2]<<4)+12>>2]=0;c[ah>>2]=(c[ah>>2]|0)+1;i=e;return};case 67:{ah=b+52|0;b=c[ah>>2]|0;aL=b+8|0;if((c[aL>>2]|0)!=0){aK=b|0;b=0;do{gGr(c[(c[aK>>2]|0)+(b<<4)>>2]|0);gGr(c[(c[aK>>2]|0)+(b<<4)+4>>2]|0);b=b+1|0;}while(b>>>0<(c[aL>>2]|0)>>>0)}c[aL>>2]=0;aL=c[ah>>2]|0;if((aL|0)==0){i=e;return}b=aL+8|0;aK=aL+4|0;aH=c[aK>>2]|0;if((c[b>>2]|0)>>>0<aH>>>0){aM=aL|0}else{aJ=(aH<<1)+2|0;c[aK>>2]=aJ;aK=aL|0;c[aK>>2]=gGs(c[aK>>2]|0,aJ<<4)|0;aM=aK}aK=bG(84680)|0;c[(c[aM>>2]|0)+(c[b>>2]<<4)>>2]=aK;c[(c[aM>>2]|0)+(c[b>>2]<<4)+4>>2]=0;c[(c[aM>>2]|0)+(c[b>>2]<<4)+8>>2]=97;c[(c[aM>>2]|0)+(c[b>>2]<<4)+12>>2]=0;c[b>>2]=(c[b>>2]|0)+1;b=c[ah>>2]|0;if((b|0)==0){i=e;return}ah=b+8|0;aM=b+4|0;aK=c[aM>>2]|0;if((c[ah>>2]|0)>>>0<aK>>>0){aN=b|0}else{aJ=(aK<<1)+2|0;c[aM>>2]=aJ;aM=b|0;c[aM>>2]=gGs(c[aM>>2]|0,aJ<<4)|0;aN=aM}aM=bG(82888)|0;c[(c[aN>>2]|0)+(c[ah>>2]<<4)>>2]=aM;c[(c[aN>>2]|0)+(c[ah>>2]<<4)+4>>2]=0;c[(c[aN>>2]|0)+(c[ah>>2]<<4)+8>>2]=98;c[(c[aN>>2]|0)+(c[ah>>2]<<4)+12>>2]=0;c[ah>>2]=(c[ah>>2]|0)+1;i=e;return};default:{i=e;return}}}function jS(b,c,d,e,f){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;g=gGy(e|0)|0;if(g>>>0<=c>>>0){h=c+1|0;do{if((h|0)==0){i=e}else{j=h;k=b;l=e;while(1){m=j-1|0;if((m|0)==0){n=6686;break}o=a[l]|0;a[k]=o;if(o<<24>>24==0){n=6747;break}else{j=m;k=k+1|0;l=l+1|0}}if((n|0)==6686){a[k]=0;i=l;break}else if((n|0)==6747){return}}}while(0);if((a[i]|0)==0){return}else{p=i}do{p=p+1|0;}while((a[p]|0)!=0);return}if(!f){f=c+1|0;p=c-2|0;L9407:do{if((p|0)==0){q=e;n=6694}else{i=p;h=b;j=e;while(1){m=i-1|0;if((m|0)==0){break}o=a[j]|0;a[h]=o;if(o<<24>>24==0){break L9407}else{i=m;h=h+1|0;j=j+1|0}}a[h]=0;q=j;n=6694}}while(0);do{if((n|0)==6694){if((a[q]|0)==0){break}else{r=q}do{r=r+1|0;}while((a[r]|0)!=0)}}while(0);r=gGy(b|0)|0;q=r>>>0>f>>>0?0:f-r|0;if((q|0)==0){s=429880}else{f=b+r|0;do{if((q|0)==1){t=429880;u=f}else{j=b+(r+1)|0;a[f]=46;if((q|0)==2){t=429881;u=j;break}h=b+(r+2)|0;a[j]=46;if((q|0)==3){t=429882;u=h;break}j=b+(r+3)|0;a[h]=46;if((q|0)==4){t=429883;u=j;break}a[j]=0;return}}while(0);a[u]=0;s=t}if((a[s]|0)==0){return}else{v=s}do{v=v+1|0;}while((a[v]|0)!=0);return}v=g-c|0;g=(d>>>0)%(((v<<1)+4|0)>>>0)|0;d=v+4|0;s=g-2|0;t=d+v-g|0;if(g>>>0<2){u=c+1|0;do{if((u|0)==0){w=e}else{q=u;r=b;f=e;while(1){j=q-1|0;if((j|0)==0){n=6706;break}h=a[f]|0;a[r]=h;if(h<<24>>24==0){n=6750;break}else{q=j;r=r+1|0;f=f+1|0}}if((n|0)==6706){a[r]=0;w=f;break}else if((n|0)==6750){return}}}while(0);if((a[w]|0)==0){return}else{x=w}do{x=x+1|0;}while((a[x]|0)!=0);return}if(g>>>0<(v+2|0)>>>0){x=e+s|0;s=c+1|0;do{if((s|0)==0){y=x}else{w=s;u=b;q=x;while(1){j=w-1|0;if((j|0)==0){n=6713;break}h=a[q]|0;a[u]=h;if(h<<24>>24==0){n=6737;break}else{w=j;u=u+1|0;q=q+1|0}}if((n|0)==6713){a[u]=0;y=q;break}else if((n|0)==6737){return}}}while(0);if((a[y]|0)==0){return}else{z=y}do{z=z+1|0;}while((a[z]|0)!=0);return}if(g>>>0<d>>>0){d=e+v|0;v=c+1|0;do{if((v|0)==0){A=d}else{g=v;z=b;y=d;while(1){x=g-1|0;if((x|0)==0){n=6720;break}s=a[y]|0;a[z]=s;if(s<<24>>24==0){n=6740;break}else{g=x;z=z+1|0;y=y+1|0}}if((n|0)==6720){a[z]=0;A=y;break}else if((n|0)==6740){return}}}while(0);if((a[A]|0)==0){return}else{B=A}do{B=B+1|0;}while((a[B]|0)!=0);return}else{B=e+t|0;t=c+1|0;do{if((t|0)==0){C=B}else{c=t;e=b;A=B;while(1){d=c-1|0;if((d|0)==0){n=6726;break}v=a[A]|0;a[e]=v;if(v<<24>>24==0){n=6748;break}else{c=d;e=e+1|0;A=A+1|0}}if((n|0)==6726){a[e]=0;C=A;break}else if((n|0)==6748){return}}}while(0);if((a[C]|0)==0){return}else{D=C}do{D=D+1|0;}while((a[D]|0)!=0);return}}function jT(d){d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;gGz(d+16|0,0,832);a[d+1872|0]=(gh[c[(c[2383356]|0)+8>>2]&15](c[2383359]|0,0,0,3,0,13)|0)<<16>>16!=0|0;e=c[2383356]|0;f=c[2383359]|0;do{if((e|0)!=0&(f|0)!=0){g=c[e+44>>2]|0;if((g|0)==0){break}h=gj[g&4095](f)|0;if((h|0)==0){break}gu[c[h+20>>2]&16383]();g=h+12|0;i=h+16|0;h=0;do{j=0;while(1){a[d+16+(h*104|0)+j|0]=(gA[c[g>>2]&16383](h,j&65535)|0)&1;k=j+1|0;if(k>>>0<32){j=k}else{l=0;break}}while(1){j=gA[c[i>>2]&16383](h,l|-65536)|0;b[d+16+(h*104|0)+32+(l<<1)>>1]=(gA[c[i>>2]&16383](h,l<<16|65535)|0)+j&65535;j=l+1|0;if(j>>>0<32){l=j}else{m=0;break}}do{j=gA[c[g>>2]&16383](h,(m|32768)&65535)|0;k=d+16+(h*104|0)+96+(m<<1)|0;b[k>>1]=b[k>>1]|(j?-32768:0);j=gA[c[g>>2]&16383](h,(m|16384)&65535)|0;b[k>>1]=b[k>>1]|(j?16384:0);j=gA[c[g>>2]&16383](h,(m|8192)&65535)|0;b[k>>1]=b[k>>1]|(j?8192:0);j=gA[c[g>>2]&16383](h,(m|4096)&65535)|0;b[k>>1]=b[k>>1]|(j?4096:0);m=m+1|0;}while(m>>>0<4);h=h+1|0;}while(h>>>0<8);return}}while(0);m=c[u>>2]|0;cj(307368,50,1,m|0)|0;eY(m|0)|0;return}function jU(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=c[2383356]|0;e=c[2383359]|0;do{if((d|0)!=0&(e|0)!=0){f=c[d+44>>2]|0;if((f|0)==0){break}g=gj[f&4095](e)|0;if((g|0)==0){break}f=g+16|0;g=0;while(1){h=gA[c[f>>2]&16383](0,g|-65536)|0;b[a+848+(g<<1)>>1]=(gA[c[f>>2]&16383](0,g<<16|65535)|0)+h&65535;h=g+1|0;if(h>>>0<32){g=h}else{i=0;break}}while(1){g=gA[c[f>>2]&16383](1,i|-65536)|0;b[a+976+(i<<1)>>1]=(gA[c[f>>2]&16383](1,i<<16|65535)|0)+g&65535;g=i+1|0;if(g>>>0<32){i=g}else{j=0;break}}while(1){g=gA[c[f>>2]&16383](2,j|-65536)|0;b[a+1104+(j<<1)>>1]=(gA[c[f>>2]&16383](2,j<<16|65535)|0)+g&65535;g=j+1|0;if(g>>>0<32){j=g}else{k=0;break}}while(1){g=gA[c[f>>2]&16383](3,k|-65536)|0;b[a+1232+(k<<1)>>1]=(gA[c[f>>2]&16383](3,k<<16|65535)|0)+g&65535;g=k+1|0;if(g>>>0<32){k=g}else{l=0;break}}while(1){g=gA[c[f>>2]&16383](4,l|-65536)|0;b[a+1360+(l<<1)>>1]=(gA[c[f>>2]&16383](4,l<<16|65535)|0)+g&65535;g=l+1|0;if(g>>>0<32){l=g}else{m=0;break}}while(1){g=gA[c[f>>2]&16383](5,m|-65536)|0;b[a+1488+(m<<1)>>1]=(gA[c[f>>2]&16383](5,m<<16|65535)|0)+g&65535;g=m+1|0;if(g>>>0<32){m=g}else{n=0;break}}while(1){g=gA[c[f>>2]&16383](6,n|-65536)|0;b[a+1616+(n<<1)>>1]=(gA[c[f>>2]&16383](6,n<<16|65535)|0)+g&65535;g=n+1|0;if(g>>>0<32){n=g}else{o=0;break}}do{g=gA[c[f>>2]&16383](7,o|-65536)|0;b[a+1744+(o<<1)>>1]=(gA[c[f>>2]&16383](7,o<<16|65535)|0)+g&65535;o=o+1|0;}while(o>>>0<32);return}}while(0);o=c[u>>2]|0;cj(307368,50,1,o|0)|0;eY(o|0)|0;return}function jV(b,d,f){b=b|0;d=d|0;f=f|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,L=0,M=0,N=0,O=0.0,P=0,Q=0,R=0,S=0,T=0,U=0.0,V=0.0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0;j=i;i=i+21912|0;k=j|0;l=j+128|0;m=j+192|0;n=j+256|0;o=j+320|0;p=j+384|0;q=j+448|0;r=j+512|0;s=j+768|0;t=j+776|0;v=j+856|0;w=j+4952|0;x=j+9048|0;y=j+13144|0;z=j+13208|0;A=j+13720|0;B=j+17816|0;C=b+130280|0;D=c[C>>2]|0;switch(d|0){case 21:{if((f|0)==7){a[9263569]=0;E=0;i=j;return E|0}else if((f|0)==2|(f|0)==3|(f|0)==4){a[9263569]=a[9263569]&1^1;E=0;i=j;return E|0}else{E=0;i=j;return E|0}break};case 23:{if((f|0)==7){a[9263570]=0;E=0;i=j;return E|0}else if((f|0)==2|(f|0)==3|(f|0)==4){a[9263570]=a[9263570]&1^1;E=0;i=j;return E|0}else{E=0;i=j;return E|0}break};case 81:{if((f|0)==2){F=c[u>>2]|0;bU(F|0,410872,(G=i,i=i+8|0,c[G>>2]=9263480,G)|0)|0;i=G;eY(F|0)|0;E=0;i=j;return E|0}else if((f|0)==3){F=c[u>>2]|0;bU(F|0,319456,(G=i,i=i+8|0,c[G>>2]=9263480,G)|0)|0;i=G;eY(F|0)|0;E=0;i=j;return E|0}else{E=0;i=j;return E|0}break};case 73:{if((f-3|0)>>>0<2){c[2341459]=(c[2341459]|0)+1;E=0;i=j;return E|0}if((f|0)==7){c[2341459]=1;E=0;i=j;return E|0}else if((f|0)==2){h4(33554432,0);E=0;i=j;return E|0}else{E=0;i=j;return E|0}break};case 85:{if((f|0)==4|(f|0)==3|(f|0)==2){a[9280027]=a[9280027]&1^1;E=0;i=j;return E|0}else if((f|0)==7){a[9280027]=1;E=0;i=j;return E|0}else{E=0;i=j;return E|0}break};case 28:{if((f|0)==7){F=9523432;c[F>>2]=0;c[F+4>>2]=0;E=0;i=j;return E|0}else if((f|0)==4){if((a[9271800]&1)!=0){E=0;i=j;return E|0}F=9523432;H=c[F>>2]|0;I=c[F+4>>2]|0;F=0;J=I>>>0>F>>>0|I>>>0==F>>>0&H>>>0>2048>>>0?2048:H;if(J>>>0<2){E=0;i=j;return E|0}else{L=0;M=0;N=0}do{H=9507048+(N<<3)|0;M=gGK(c[H>>2]|0,c[H+4>>2]|0,M,L)|0;L=K;N=N+1|0;}while(N>>>0<J>>>0);N=gGS(M,L,J,0)|0;O=1.0e6/(+(N>>>0)+ +(K|0)*4294967296.0);N=r|0;be(N|0,256,151664,(G=i,i=i+8|0,h[G>>3]=O,G)|0)|0;i=G;r=c[2380901]|0;J=r+4|0;L9589:do{if((c[J>>2]|0)>>>0<(c[r+8>>2]|0)>>>0){L=gGq(12)|0;do{if((L|0)!=0){if((c[L-4>>2]&3|0)==0){break}gGz(L|0,0,12)}}while(0);c[L+4>>2]=1;c[L>>2]=180;M=bG(N|0)|0;H=c[J>>2]|0;c[L+8>>2]=M;M=r|0;c[(c[M>>2]|0)+(H<<2)>>2]=L;H=c[J>>2]|0;c[J>>2]=H+1;if(H>>>0>1){P=H}else{break}while(1){H=P>>>1;F=c[M>>2]|0;I=F+(H<<2)|0;Q=c[I>>2]|0;R=c[F+(P<<2)>>2]|0;if((c[R+4>>2]|0)>>>0<=(c[Q+4>>2]|0)>>>0){break L9589}c[I>>2]=R;c[(c[M>>2]|0)+(P<<2)>>2]=Q;if(P>>>0>3){P=H}else{break}}}}while(0);if((a[9375104]&1)!=0){P=c[u>>2]|0;bU(P|0,324680,(G=i,i=i+8|0,c[G>>2]=N,G)|0)|0;i=G;eY(P|0)|0}g[2317949]=O;hO();O=+((c[2320017]|0)>>>0>>>0)/+g[2320019];h[1184275]=O;h[1184281]=O;gg[c[(c[2383355]|0)+8>>2]&4095](c[2383358]|0,0);E=0;i=j;return E|0}else{E=0;i=j;return E|0}break};case 10:{if((f|0)==7){S=1}else{S=a[9263580]&1^1}a[9263580]=S;P=c[c[2383406]>>2]|0;if((P|0)==0){E=0;i=j;return E|0}gG[P&255](c[2383358]|0,1,(S&1)!=0);E=0;i=j;return E|0};case 79:{S=gD[c[2368521]&8191]()|0;P=gD[c[2368519]&8191]()|0;do{if((f-3|0)>>>0<2){T=1}else{N=(f|0)==2;if(N){T=N<<31>>31;break}else{E=0}i=j;return E|0}}while(0);N=S+1|0;hg(1,0);hh(((P+N+T|0)>>>0)%(N>>>0)|0);hg(0,0);E=0;i=j;return E|0};case 27:{if((f|0)==7){a[9263582]=1;E=0;i=j;return E|0}else if((f|0)==2|(f|0)==3|(f|0)==4){a[9263582]=a[9263582]&1^1;E=0;i=j;return E|0}else{E=0;i=j;return E|0}break};case 25:case 26:{N=(d|0)==25?9263544:9263548;O=+g[N>>2];if((f|0)==7){g[N>>2]=3.0;U=3.0}else if((f|0)==2){V=O+-1.0;g[N>>2]=V;U=V}else if((f|0)==3){V=O+1.0;g[N>>2]=V;U=V}else{U=O}V=+ba(+U);U=V>1.0?V:1.0;g[N>>2]=U;if(O==U){E=0;i=j;return E|0}if((a[9263552]&1)!=0){E=0;i=j;return E|0}he(0);E=0;i=j;return E|0};case 96:{if((f|0)!=4){E=0;i=j;return E|0}if((a[9375104]&1)!=0){N=c[u>>2]|0;cj(431624,27,1,N|0)|0;eY(N|0)|0}N=c[2380901]|0;T=N+4|0;P=c[T>>2]|0;if(P>>>0>1){S=N|0;J=1;r=P;while(1){P=c[(c[S>>2]|0)+(J<<2)>>2]|0;if((P|0)==0){W=r}else{gGr(c[P+8>>2]|0);gGr(c[(c[S>>2]|0)+(J<<2)>>2]|0);c[(c[S>>2]|0)+(J<<2)>>2]=0;W=c[T>>2]|0}P=J+1|0;if(P>>>0<W>>>0){J=P;r=W}else{break}}}c[T>>2]=1;T=N+12|0;gGr(c[T>>2]|0);c[T>>2]=0;T=c[2380901]|0;N=T+4|0;L9653:do{if((c[N>>2]|0)>>>0<(c[T+8>>2]|0)>>>0){W=gGq(12)|0;do{if((W|0)!=0){if((c[W-4>>2]&3|0)==0){break}gGz(W|0,0,12)}}while(0);c[W+4>>2]=1;c[W>>2]=120;r=bG(421080)|0;J=c[N>>2]|0;c[W+8>>2]=r;r=T|0;c[(c[r>>2]|0)+(J<<2)>>2]=W;J=c[N>>2]|0;c[N>>2]=J+1;if(J>>>0>1){X=J}else{break}while(1){J=X>>>1;S=c[r>>2]|0;P=S+(J<<2)|0;M=c[P>>2]|0;L=c[S+(X<<2)>>2]|0;if((c[L+4>>2]|0)>>>0<=(c[M+4>>2]|0)>>>0){break L9653}c[P>>2]=L;c[(c[r>>2]|0)+(X<<2)>>2]=M;if(X>>>0>3){X=J}else{break}}}}while(0);gu[c[2112850]&16383]();hf();X=9532104;N=c[X+4>>2]|0;T=9532104;c[T>>2]=c[X>>2]|1;c[T+4>>2]=N;E=-1;i=j;return E|0};case 74:{if((f-3|0)>>>0<2|(f|0)==2){a[9532118]=a[9532118]&1^1;E=0;i=j;return E|0}if((f|0)!=7){E=0;i=j;return E|0}a[9532118]=1;E=0;i=j;return E|0};case 97:{if((f|0)==7){a[9474209]=0;E=0;i=j;return E|0}else{a[9474209]=a[9474209]&1^1;E=0;i=j;return E|0}break};case 72:{if((f|0)==7){a[9365828]=0;N=c[2380903]|0;if((N|0)!=0){gGr(c[N>>2]|0);gGr(c[N+12>>2]|0);gGr(N)}c[2380903]=0;gGr(c[2380904]|0);c[2380904]=0;E=0;i=j;return E|0}else if((f|0)==4|(f|0)==3|(f|0)==2){N=a[9365828]&1;a[9365828]=N^1;if(N<<24>>24==0){hb();E=0;i=j;return E|0}N=c[2380903]|0;if((N|0)!=0){gGr(c[N>>2]|0);gGr(c[N+12>>2]|0);gGr(N)}c[2380903]=0;gGr(c[2380904]|0);c[2380904]=0;E=0;i=j;return E|0}else{E=0;i=j;return E|0}break};case 95:{if((f|0)!=7){E=0;i=j;return E|0}a[9361732]=0;E=0;i=j;return E|0};case 19:{if((f|0)==7){c[2315899]=0;gg[c[(c[2383355]|0)+36>>2]&4095](c[2383358]|0,c[2367357]&3);E=0;i=j;return E|0}else if((f|0)==2){h4(512,0);gg[c[(c[2383355]|0)+36>>2]&4095](c[2383358]|0,(c[2367357]|0)+(c[2315899]|0)&3);E=0;i=j;return E|0}else if((f|0)==3){h4(1024,0);gg[c[(c[2383355]|0)+36>>2]&4095](c[2383358]|0,(c[2367357]|0)+(c[2315899]|0)&3);E=0;i=j;return E|0}else{E=0;i=j;return E|0}break};case 114:case 115:case 116:case 117:case 118:case 110:case 119:case 111:case 113:case 112:case 120:case 121:case 122:case 123:case 124:case 125:case 126:case 127:case 128:case 129:case 130:case 131:case 132:case 133:case 165:{N=c[(c[2383356]|0)+20>>2]|0;if((N|0)!=0){if((f|0)!=7){E=0;i=j;return E|0}ge[N&63](c[2383359]|0,c[9324300+(D<<2)>>2]|0,D,d-110|0,2);E=0;i=j;return E|0}N=d-110|0;if((f|0)==7){T=9288384+(D*2240|0)+(N*40|0)+16|0;c[T>>2]=65535;c[T+4>>2]=0;c[9288384+(D*2240|0)+(N*40|0)+32>>2]=-1;E=0;i=j;return E|0}else if((f|0)==4){T=b+130296|0;X=T;c[b+130300>>2]=d;c[b+130304>>2]=d;c[T>>2]=9288384+(D*2240|0)+(N*40|0);c[b+130308>>2]=D;N=c[b+48>>2]|0;T=c[b+56>>2]|0;if((N|0)!=0){r=N+8|0;W=N+4|0;J=c[W>>2]|0;if((c[r>>2]|0)>>>0<J>>>0){Y=N|0}else{M=(J<<1)+2|0;c[W>>2]=M;W=N|0;c[W>>2]=gGs(c[W>>2]|0,M<<4)|0;Y=W}W=bG(9534384)|0;c[(c[Y>>2]|0)+(c[r>>2]<<4)>>2]=W;c[(c[Y>>2]|0)+(c[r>>2]<<4)+4>>2]=0;c[(c[Y>>2]|0)+(c[r>>2]<<4)+8>>2]=166;c[(c[Y>>2]|0)+(c[r>>2]<<4)+12>>2]=T;c[r>>2]=(c[r>>2]|0)+1}jU(X);jT(X);E=0;i=j;return E|0}else{E=0;i=j;return E|0}break};case 109:{X=9324232+(D<<2)|0;r=c[X>>2]|0;T=0;while(1){if(T>>>0>=8){Z=0;break}if((r|0)==(c[10088+(T<<2)>>2]|0)){Z=T;break}else{T=T+1|0}}if((f|0)==2){_=c[10088+((Z+7&7)<<2)>>2]|0}else if((f|0)==3|(f|0)==4){_=c[10088+((Z+1&7)<<2)>>2]|0}else if((f|0)==7){_=1}else{E=0;i=j;return E|0}c[X>>2]=_;gg[c[2112838]&4095](D,_);E=0;i=j;return E|0};case 104:{if((f|0)==4){_=c[b+48>>2]|0;X=b+56|0;Z=c[X>>2]|0;if((_|0)!=0){T=_+8|0;r=_+4|0;Y=c[r>>2]|0;if((c[T>>2]|0)>>>0<Y>>>0){$=_|0}else{W=(Y<<1)+2|0;c[r>>2]=W;r=_|0;c[r>>2]=gGs(c[r>>2]|0,W<<4)|0;$=r}r=bG(9452954)|0;c[(c[$>>2]|0)+(c[T>>2]<<4)>>2]=r;c[(c[$>>2]|0)+(c[T>>2]<<4)+4>>2]=0;c[(c[$>>2]|0)+(c[T>>2]<<4)+8>>2]=104;c[(c[$>>2]|0)+(c[T>>2]<<4)+12>>2]=Z;c[T>>2]=(c[T>>2]|0)+1}c[X>>2]=0;a[b+60|0]=1;E=0;i=j;return E|0}else if((f|0)==7){X=c[2383400]|0;if((X|0)!=0){i5(X)}c[2383400]=0;a[9324856]=0;E=0;i=j;return E|0}else{E=0;i=j;return E|0}break};case 106:{if((f|0)==2){h4(2097152,0)}else if((f|0)==3|(f|0)==4){h4(4194304,0)}else if((f|0)==7){g[2332239]=1.0}else{E=0;i=j;return E|0}X=c[2383400]|0;if((X|0)==0){E=0;i=j;return E|0}i2(X,+g[2332239]);E=0;i=j;return E|0};case 34:{do{if((f|0)==7){c[b+20888>>2]=0}else if((f|0)==2){X=b+20888|0;T=c[X>>2]|0;if((T|0)==0){break}c[X>>2]=T-1;a[b+60|0]=1}else if((f|0)==3|(f|0)==4){T=b+20888|0;X=c[T>>2]|0;if(X>>>0>=8){break}c[T>>2]=X+1;a[b+60|0]=1}}while(0);a[b+60|0]=1;E=0;i=j;return E|0};case 65:{if((f|0)!=4){E=0;i=j;return E|0}X=v|0;T=w|0;Z=x|0;$=y|0;r=z|0;a[X]=0;L9783:do{if((a[9369961]|0)==0){if((a[9395610]|0)!=0){hJ(X,9395610);break}z=c[2380901]|0;W=z+4|0;_=c[W>>2]|0;if(_>>>0>1){Y=z|0;M=1;N=_;while(1){_=c[(c[Y>>2]|0)+(M<<2)>>2]|0;if((_|0)==0){aa=N}else{gGr(c[_+8>>2]|0);gGr(c[(c[Y>>2]|0)+(M<<2)>>2]|0);c[(c[Y>>2]|0)+(M<<2)>>2]=0;aa=c[W>>2]|0}_=M+1|0;if(_>>>0<aa>>>0){M=_;N=aa}else{break}}}c[W>>2]=1;N=z+12|0;gGr(c[N>>2]|0);c[N>>2]=0;N=c[2380901]|0;M=N+4|0;L9802:do{if((c[M>>2]|0)>>>0<(c[N+8>>2]|0)>>>0){Y=gGq(12)|0;do{if((Y|0)!=0){if((c[Y-4>>2]&3|0)==0){break}gGz(Y|0,0,12)}}while(0);c[Y+4>>2]=1;c[Y>>2]=180;_=bG(384016)|0;J=c[M>>2]|0;c[Y+8>>2]=_;_=N|0;c[(c[_>>2]|0)+(J<<2)>>2]=Y;J=c[M>>2]|0;c[M>>2]=J+1;if(J>>>0>1){ab=J}else{break}while(1){J=ab>>>1;L=c[_>>2]|0;P=L+(J<<2)|0;S=c[P>>2]|0;H=c[L+(ab<<2)>>2]|0;if((c[H+4>>2]|0)>>>0<=(c[S+4>>2]|0)>>>0){break L9802}c[P>>2]=H;c[(c[_>>2]|0)+(ab<<2)>>2]=S;if(ab>>>0>3){ab=J}else{break}}}}while(0);M=c[u>>2]|0;bU(M|0,374408,(G=i,i=i+8|0,c[G>>2]=384016,G)|0)|0;i=G;eY(M|0)|0;E=0;i=j;return E|0}else{M=4096;N=X;z=9369961;while(1){W=M-1|0;if((W|0)==0){break}_=a[z]|0;a[N]=_;if(_<<24>>24==0){break L9783}else{M=W;N=N+1|0;z=z+1|0}}a[N]=0;if((a[z]|0)==0){break}else{ac=z}do{ac=ac+1|0;}while((a[ac]|0)!=0)}}while(0);L9814:do{if((a[9341252]|0)==0){ad=6900}else{if((f$(9341252,t|0)|0)>=0){if((c[t+12>>2]&61440|0)==16384){ad=6900;break}}ac=fw(9341252,364392)|0;if((ac|0)==0){ad=6900;break}aY(ac|0)|0;ac=y+1|0;ab=y+2|0;aa=y+3|0;z=y+4|0;N=0;while(1){M=cE(9341252,47)|0;W=4096;_=0;Y=T;J=(M|0)==0?9341252:M+1|0;while(1){M=W-1|0;if((M|0)==0){ad=6883;break}S=a[J]|0;a[Y]=S;if(S<<24>>24==0){ae=_;break}else{W=M;_=_+1|0;Y=Y+1|0;J=J+1|0}}do{if((ad|0)==6883){ad=0;a[Y]=0;if((a[J]|0)==0){ae=_;break}else{af=J;ag=_}while(1){W=af+1|0;M=ag+1|0;if((a[W]|0)==0){ae=M;break}else{af=W;ag=M}}}}while(0);if(ae>>>0>=4096){break}_=cE(T|0,47)|0;J=cE(((_|0)==0?T:_+1|0)|0,46)|0;if((a[J]|0)!=0){a[J]=0}hE(Z,X,T);a[$]=0;if((N|0)==0){a[$]=46;a[ac]=99;a[ab]=102;a[aa]=103;a[z]=0}else{be($|0,64,364416,(G=i,i=i+8|0,c[G>>2]=N,G)|0)|0;i=G}J=gGy(Z|0)|0;_=J>>>0>4096?0:4096-J|0;L9838:do{if((_|0)==0){ah=$;ad=6896}else{Y=_;M=x+J|0;W=$;while(1){S=Y-1|0;if((S|0)==0){break}H=a[W]|0;a[M]=H;if(H<<24>>24==0){break L9838}else{Y=S;M=M+1|0;W=W+1|0}}a[M]=0;ah=W;ad=6896}}while(0);do{if((ad|0)==6896){ad=0;if((a[ah]|0)==0){break}else{ai=ah}do{ai=ai+1|0;}while((a[ai]|0)!=0)}}while(0);W=fw(Z|0,364392)|0;if((W|0)==0){break L9814}aY(W|0)|0;W=N+1|0;if(W>>>0<16){N=W}else{ad=6900;break L9814}}N=c[u>>2]|0;bU(N|0,547632,(G=i,i=i+16|0,c[G>>2]=551256,c[G+8>>2]=579,G)|0)|0;i=G;eY(N|0)|0;fm(2);return 0}}while(0);if((ad|0)==6900){ai=c[u>>2]|0;cj(349064,68,1,ai|0)|0;eY(ai|0)|0;gb(s|0)|0;ai=a5(s|0)|0;ed(T|0,4096,536808,ai|0)|0;ai=gGy(T|0)|0;s=ai>>>0>4096?0:4096-ai|0;L9853:do{if((s|0)==0){aj=341504;ad=6904}else{ah=w+ai|0;do{if((s|0)==1){ak=341504;al=ah}else{$=w+(ai+1)|0;a[ah]=99;if((s|0)==2){ak=341505;al=$;break}x=w+(ai+2)|0;a[$]=102;if((s|0)==3){ak=341506;al=x;break}$=w+(ai+3)|0;a[x]=103;if((s|0)==4){ak=341507;al=$;break}a[$]=0;break L9853}}while(0);a[al]=0;aj=ak;ad=6904}}while(0);do{if((ad|0)==6904){if((a[aj]|0)==0){break}else{am=aj}do{am=am+1|0;}while((a[am]|0)!=0)}}while(0);hE(Z,X,T)}do{if(h3(Z)|0){T=4096;X=9395610;am=Z;while(1){aj=T-1|0;if((aj|0)==0){ad=6910;break}ak=a[am]|0;a[X]=ak;if(ak<<24>>24==0){break}else{T=aj;X=X+1|0;am=am+1|0}}do{if((ad|0)==6910){a[X]=0;if((a[am]|0)==0){break}else{an=am}do{an=an+1|0;}while((a[an]|0)!=0)}}while(0);be(r|0,512,333512,(G=i,i=i+8|0,c[G>>2]=Z,G)|0)|0;i=G;if((a[9375104]&1)==0){break}am=c[u>>2]|0;bU(am|0,324680,(G=i,i=i+8|0,c[G>>2]=r,G)|0)|0;i=G;eY(am|0)|0}else{be(r|0,512,316024,(G=i,i=i+8|0,c[G>>2]=Z,G)|0)|0;i=G;am=c[u>>2]|0;bU(am|0,374408,(G=i,i=i+8|0,c[G>>2]=r,G)|0)|0;i=G;eY(am|0)|0}}while(0);Z=c[2380901]|0;an=Z+4|0;am=c[an>>2]|0;if(am>>>0>1){X=Z|0;T=1;aj=am;while(1){am=c[(c[X>>2]|0)+(T<<2)>>2]|0;if((am|0)==0){ao=aj}else{gGr(c[am+8>>2]|0);gGr(c[(c[X>>2]|0)+(T<<2)>>2]|0);c[(c[X>>2]|0)+(T<<2)>>2]=0;ao=c[an>>2]|0}am=T+1|0;if(am>>>0<ao>>>0){T=am;aj=ao}else{break}}}c[an>>2]=1;an=Z+12|0;gGr(c[an>>2]|0);c[an>>2]=0;an=c[2380901]|0;Z=an+4|0;if((c[Z>>2]|0)>>>0>=(c[an+8>>2]|0)>>>0){E=0;i=j;return E|0}ao=gGq(12)|0;do{if((ao|0)!=0){if((c[ao-4>>2]&3|0)==0){break}gGz(ao|0,0,12)}}while(0);c[ao+4>>2]=1;c[ao>>2]=180;aj=bG(r|0)|0;r=c[Z>>2]|0;c[ao+8>>2]=aj;aj=an|0;c[(c[aj>>2]|0)+(r<<2)>>2]=ao;ao=c[Z>>2]|0;c[Z>>2]=ao+1;if(ao>>>0>1){ap=ao}else{E=0;i=j;return E|0}while(1){ao=ap>>>1;Z=c[aj>>2]|0;r=Z+(ao<<2)|0;an=c[r>>2]|0;T=c[Z+(ap<<2)>>2]|0;if((c[T+4>>2]|0)>>>0<=(c[an+4>>2]|0)>>>0){E=0;ad=7386;break}c[r>>2]=T;c[(c[aj>>2]|0)+(ap<<2)>>2]=an;if(ap>>>0>3){ap=ao}else{E=0;ad=7387;break}}if((ad|0)==7386){i=j;return E|0}else if((ad|0)==7387){i=j;return E|0}break};case 22:{if((f|0)==3|(f|0)==4){ap=c[2315894]|0;if(ap>>>0>=3){E=0;i=j;return E|0}c[2315894]=ap+1;E=0;i=j;return E|0}else if((f|0)==7){c[2315894]=0;E=0;i=j;return E|0}else if((f|0)==2){ap=c[2315894]|0;if((ap|0)==0){E=0;i=j;return E|0}c[2315894]=ap-1;E=0;i=j;return E|0}else{E=0;i=j;return E|0}break};case 14:{if((f|0)==7){c[2315898]=4}else if((f|0)==2){h4(1,0)}else if((f|0)==3){h4(2,0)}ap=c[(c[2383406]|0)+12>>2]|0;if((ap|0)==0){E=0;i=j;return E|0}gg[ap&4095](c[2383358]|0,c[2315898]|0);E=0;i=j;return E|0};case 82:{if((f|0)==2){ap=0;while(1){if(ap>>>0>=2){break}if((gGF(9280032,c[(c[64376+(ap<<2)>>2]|0)+28>>2]|0)|0)==0){ad=7038;break}else{ap=ap+1|0}}do{if((ad|0)==7038){if((ap|0)<=0){break}aj=32;ao=9280032;an=c[(c[64376+(ap-1<<2)>>2]|0)+28>>2]|0;while(1){T=aj-1|0;if((T|0)==0){break}r=a[an]|0;a[ao]=r;if(r<<24>>24==0){E=0;ad=7414;break}else{aj=T;ao=ao+1|0;an=an+1|0}}if((ad|0)==7414){i=j;return E|0}a[ao]=0;if((a[an]|0)==0){E=0;i=j;return E|0}else{aq=an}while(1){aj=aq+1|0;if((a[aj]|0)==0){E=0;break}else{aq=aj}}i=j;return E|0}}while(0);aq=c[u>>2]|0;bU(aq|0,295104,(G=i,i=i+8|0,c[G>>2]=9280032,G)|0)|0;i=G;eY(aq|0)|0;E=0;i=j;return E|0}else if((f|0)==3){aq=0;while(1){if(aq>>>0>=2){break}ar=aq+1|0;if((gGF(9280032,c[(c[64376+(aq<<2)>>2]|0)+28>>2]|0)|0)==0){ad=7047;break}else{aq=ar}}do{if((ad|0)==7047){if(!((aq|0)>-1&ar>>>0<2)){break}ap=32;an=9280032;ao=c[(c[64376+(ar<<2)>>2]|0)+28>>2]|0;while(1){aj=ap-1|0;if((aj|0)==0){break}T=a[ao]|0;a[an]=T;if(T<<24>>24==0){E=0;ad=7368;break}else{ap=aj;an=an+1|0;ao=ao+1|0}}if((ad|0)==7368){i=j;return E|0}a[an]=0;if((a[ao]|0)==0){E=0;i=j;return E|0}else{as=ao}while(1){ap=as+1|0;if((a[ap]|0)==0){E=0;break}else{as=ap}}i=j;return E|0}}while(0);as=c[u>>2]|0;bU(as|0,531472,(G=i,i=i+8|0,c[G>>2]=9280032,G)|0)|0;i=G;eY(as|0)|0;E=0;i=j;return E|0}else{E=0;i=j;return E|0}break};case 87:{if((f|0)!=7){E=0;i=j;return E|0}a[9365865]=0;a[b+4404|0]=0;E=0;i=j;return E|0};case 17:{if((f|0)!=4){E=0;i=j;return E|0}he((a[9263552]&1)==0);E=0;i=j;return E|0};case 20:{if((f|0)==2|(f|0)==3|(f|0)==4){a[9263568]=a[9263568]&1^1;E=0;i=j;return E|0}else if((f|0)==7){a[9263568]=1;E=0;i=j;return E|0}else{E=0;i=j;return E|0}break};case 24:{as=c[2315893]|0;if((f|0)==7){c[2315893]=1;at=1}else if((f|0)==2){ar=as-1|0;c[2315893]=ar;at=ar}else if((f|0)==3|(f|0)==4){ar=as+1|0;c[2315893]=ar;at=ar}else{at=as}ar=at>>>0<4?at:4;at=ar>>>0>1?ar:1;c[2315893]=at;ar=c[2383355]|0;aq=c[2383358]|0;if(!((as|0)!=(at|0)&(ar|0)!=0&(aq|0)!=0)){E=0;i=j;return E|0}gg[c[ar+8>>2]&4095](aq,0);E=0;i=j;return E|0};case 98:{if((f|0)==7){g[2322070]=.004999999888241291;a[9288277]=1;E=0;i=j;return E|0}else if((f|0)==3){h4(32,0);E=0;i=j;return E|0}else if((f|0)==2){h4(16,0);E=0;i=j;return E|0}else{E=0;i=j;return E|0}break};case 86:{if((f|0)!=7){E=0;i=j;return E|0}a[9357636]=0;E=0;i=j;return E|0};case 93:{if((f|0)!=7){E=0;i=j;return E|0}a[9369961]=0;E=0;i=j;return E|0};case 88:{if((f|0)!=7){E=0;i=j;return E|0}a[9271801]=0;E=0;i=j;return E|0};case 12:{if((f|0)==7){c[2383023]=0;aq=c[(c[2383406]|0)+16>>2]|0;if((aq|0)==0){E=0;i=j;return E|0}gf[aq&2047](c[2383358]|0);E=0;i=j;return E|0}else if((f|0)==2){aq=c[2383023]|0;if((aq|0)==0){E=0;i=j;return E|0}c[2383023]=aq-1;aq=c[(c[2383406]|0)+16>>2]|0;if((aq|0)==0){E=0;i=j;return E|0}gf[aq&2047](c[2383358]|0);E=0;i=j;return E|0}else{if(!((f|0)==3&(c[2383023]|0)==0)){E=0;i=j;return E|0}c[2383023]=1;aq=c[(c[2383406]|0)+16>>2]|0;if((aq|0)==0){E=0;i=j;return E|0}gf[aq&2047](c[2383358]|0);E=0;i=j;return E|0}break};case 83:{if((f|0)==2){aq=c[u>>2]|0;bU(aq|0,243304,(G=i,i=i+8|0,c[G>>2]=9288320,G)|0)|0;i=G;eY(aq|0)|0;E=0;i=j;return E|0}else if((f|0)==3){aq=c[u>>2]|0;bU(aq|0,190208,(G=i,i=i+8|0,c[G>>2]=9288320,G)|0)|0;i=G;eY(aq|0)|0;E=0;i=j;return E|0}else{E=0;i=j;return E|0}break};case 90:{if((f|0)!=7){E=0;i=j;return E|0}a[9444762]=0;E=0;i=j;return E|0};case 94:{if((f|0)!=7){E=0;i=j;return E|0}a[9452954]=0;E=0;i=j;return E|0};case 89:{if((f|0)!=7){E=0;i=j;return E|0}a[9448858]=0;E=0;i=j;return E|0};case 168:{if((f|0)!=4){E=0;i=j;return E|0}c[b+130300>>2]=110;c[b+130304>>2]=133;aq=9288400+(D*2240|0)|0;c[aq>>2]=65535;c[aq+4>>2]=0;c[9288416+(D*2240|0)>>2]=-1;aq=9288440+(D*2240|0)|0;c[aq>>2]=65535;c[aq+4>>2]=0;c[9288456+(D*2240|0)>>2]=-1;aq=9288480+(D*2240|0)|0;c[aq>>2]=65535;c[aq+4>>2]=0;c[9288496+(D*2240|0)>>2]=-1;aq=9288520+(D*2240|0)|0;c[aq>>2]=65535;c[aq+4>>2]=0;c[9288536+(D*2240|0)>>2]=-1;aq=9288560+(D*2240|0)|0;c[aq>>2]=65535;c[aq+4>>2]=0;c[9288576+(D*2240|0)>>2]=-1;aq=9288600+(D*2240|0)|0;c[aq>>2]=65535;c[aq+4>>2]=0;c[9288616+(D*2240|0)>>2]=-1;aq=9288640+(D*2240|0)|0;c[aq>>2]=65535;c[aq+4>>2]=0;c[9288656+(D*2240|0)>>2]=-1;aq=9288680+(D*2240|0)|0;c[aq>>2]=65535;c[aq+4>>2]=0;c[9288696+(D*2240|0)>>2]=-1;aq=9288720+(D*2240|0)|0;c[aq>>2]=65535;c[aq+4>>2]=0;c[9288736+(D*2240|0)>>2]=-1;aq=9288760+(D*2240|0)|0;c[aq>>2]=65535;c[aq+4>>2]=0;c[9288776+(D*2240|0)>>2]=-1;aq=9288800+(D*2240|0)|0;c[aq>>2]=65535;c[aq+4>>2]=0;c[9288816+(D*2240|0)>>2]=-1;aq=9288840+(D*2240|0)|0;c[aq>>2]=65535;c[aq+4>>2]=0;c[9288856+(D*2240|0)>>2]=-1;aq=9288880+(D*2240|0)|0;c[aq>>2]=65535;c[aq+4>>2]=0;c[9288896+(D*2240|0)>>2]=-1;aq=9288920+(D*2240|0)|0;c[aq>>2]=65535;c[aq+4>>2]=0;c[9288936+(D*2240|0)>>2]=-1;aq=9288960+(D*2240|0)|0;c[aq>>2]=65535;c[aq+4>>2]=0;c[9288976+(D*2240|0)>>2]=-1;aq=9289e3+(D*2240|0)|0;c[aq>>2]=65535;c[aq+4>>2]=0;c[9289016+(D*2240|0)>>2]=-1;aq=9289040+(D*2240|0)|0;c[aq>>2]=65535;c[aq+4>>2]=0;c[9289056+(D*2240|0)>>2]=-1;aq=9289080+(D*2240|0)|0;c[aq>>2]=65535;c[aq+4>>2]=0;c[9289096+(D*2240|0)>>2]=-1;aq=9289120+(D*2240|0)|0;c[aq>>2]=65535;c[aq+4>>2]=0;c[9289136+(D*2240|0)>>2]=-1;aq=9289160+(D*2240|0)|0;c[aq>>2]=65535;c[aq+4>>2]=0;c[9289176+(D*2240|0)>>2]=-1;aq=9289200+(D*2240|0)|0;c[aq>>2]=65535;c[aq+4>>2]=0;c[9289216+(D*2240|0)>>2]=-1;aq=9289240+(D*2240|0)|0;c[aq>>2]=65535;c[aq+4>>2]=0;c[9289256+(D*2240|0)>>2]=-1;aq=9289280+(D*2240|0)|0;c[aq>>2]=65535;c[aq+4>>2]=0;c[9289296+(D*2240|0)>>2]=-1;aq=9289320+(D*2240|0)|0;c[aq>>2]=65535;c[aq+4>>2]=0;c[9289336+(D*2240|0)>>2]=-1;E=0;i=j;return E|0};case 108:{aq=(c[2383356]|0)+20|0;if((c[aq>>2]|0)!=0){ar=9324300+(D<<2)|0;at=c[ar>>2]|0;if((f|0)==3){as=at+1|0;c[ar>>2]=as;au=as}else if((f|0)==2){as=at-1|0;c[ar>>2]=as;au=as}else if((f|0)==7){c[ar>>2]=0;au=0}else{au=at}ge[c[aq>>2]&63](c[2383359]|0,au,D,0,4);E=0;i=j;return E|0}au=9324268+(D<<2)|0;if((f|0)==7){c[au>>2]=D;av=D}else if((f|0)==2){aq=(c[au>>2]|0)-1|0;c[au>>2]=aq;av=aq}else if((f|0)==3){aq=(c[au>>2]|0)+1|0;c[au>>2]=aq;av=aq}else{av=c[au>>2]|0}if((av|0)<-1){c[au>>2]=-1;E=0;i=j;return E|0}if((av|0)<=7){E=0;i=j;return E|0}c[au>>2]=7;E=0;i=j;return E|0};case 107:{do{if((f|0)==7){c[C>>2]=0;aw=0}else if((f|0)==2){if((D|0)==0){aw=0;break}au=D-1|0;c[C>>2]=au;aw=au}else if((f|0)==3){if(D>>>0>=7){aw=D;break}au=D+1|0;c[C>>2]=au;aw=au}else{aw=D}}while(0);if((D|0)==(aw|0)){E=0;i=j;return E|0}a[b+60|0]=1;E=0;i=j;return E|0};case 105:{if((f|0)==3|(f|0)==4){h4(1048576,0)}else if((f|0)==7){g[2332238]=1.0}else if((f|0)==2){h4(524288,0)}else{E=0;i=j;return E|0}aw=c[2383400]|0;if((aw|0)==0){E=0;i=j;return E|0}C=aw+16|0;if((c[(c[C>>2]|0)+140>>2]|0)==0){E=0;i=j;return E|0}au=aw+4|0;av=aw|0;aw=0;while(1){gK[c[(c[au>>2]|0)+20>>2]&7](c[av>>2]|0,aw,+g[2332238]);aq=aw+1|0;if(aq>>>0<(c[(c[C>>2]|0)+140>>2]|0)>>>0){aw=aq}else{E=0;break}}i=j;return E|0};case 76:case 77:{if((f|0)==4){if((d|0)==76){hd()}else{hc()}d=9532104;aw=c[d+4>>2]|0;C=9532104;c[C>>2]=c[d>>2]|1;c[C+4>>2]=aw;E=-1;i=j;return E|0}else if((f|0)==2){h4(4096,0);E=0;i=j;return E|0}else if((f|0)==3){c[2367336]=(c[2367336]|0)+1;E=0;i=j;return E|0}else if((f|0)==7){c[2367336]=0;E=0;i=j;return E|0}else{E=0;i=j;return E|0}break};case 5:{if((f|0)!=4){E=0;i=j;return E|0}aw=c[b+48>>2]|0;if((aw|0)==0){E=0;i=j;return E|0}C=aw+8|0;d=aw+4|0;av=c[d>>2]|0;if((c[C>>2]|0)>>>0<av>>>0){ax=aw|0}else{au=(av<<1)+2|0;c[d>>2]=au;d=aw|0;c[d>>2]=gGs(c[d>>2]|0,au<<4)|0;ax=d}d=bG(9534384)|0;c[(c[ax>>2]|0)+(c[C>>2]<<4)>>2]=d;c[(c[ax>>2]|0)+(c[C>>2]<<4)+4>>2]=0;c[(c[ax>>2]|0)+(c[C>>2]<<4)+8>>2]=5;c[(c[ax>>2]|0)+(c[C>>2]<<4)+12>>2]=0;c[C>>2]=(c[C>>2]|0)+1;E=0;i=j;return E|0};case 103:{if((f|0)!=4){E=0;i=j;return E|0}C=9532104;ax=c[C+4>>2]|0;d=9532104;c[d>>2]=c[C>>2]&-2;c[d+4>>2]=ax;E=-1;i=j;return E|0};case 13:{do{if((f|0)==7){a[9263589]=0}else{if((f-2|0)>>>0>=3){break}a[9263589]=a[9263589]&1^1}}while(0);ax=c[(c[2383406]|0)+16>>2]|0;if((ax|0)==0){E=0;i=j;return E|0}gf[ax&2047](c[2383358]|0);E=0;i=j;return E|0};case 84:{if((f|0)!=4){E=0;i=j;return E|0}g3();E=0;i=j;return E|0};case 33:{if(!((c[(c[2383355]|0)+20>>2]|0)!=0&(f|0)==4)){E=0;i=j;return E|0}if((a[9375104]&1)!=0){ax=c[u>>2]|0;cj(561288,31,1,ax|0)|0;eY(ax|0)|0}ax=b+20816|0;d=b+20888|0;C=c[d>>2]|0;L10175:do{if((C|0)!=0){au=0;aw=3;while(1){av=jp(ax+76+(au*4144|0)|0,3)|0;if(!((av|0)==0|(av|0)==2)){break L10175}if((aw|0)==3){ay=av}else{if((aw|0)==(av|0)){ay=aw}else{break L10175}}av=au+1|0;if(av>>>0<C>>>0){au=av;aw=ay}else{break}}if((ay|0)==3){break}aw=(ay|0)==2?b+8500|0:b+12596|0;au=A|0;if((a[9395610]|0)==0){a[au]=0}else{hJ(au,9395610)}av=gGq(20)|0;if((av|0)==0){E=0;i=j;return E|0}if((c[av-4>>2]&3|0)!=0){gGz(av|0,0,20)}aq=av;av=p|0;at=v|0;ar=q|0;as=w|0;ao=k|0;be(ao|0,128,66464,(G=i,i=i+8|0,c[G>>2]=c[d>>2],G)|0)|0;i=G;h0(aq,537088,ao);if((c[d>>2]|0)!=0){an=l|0;ap=y|0;aj=0;do{be(av|0,64,349224,(G=i,i=i+8|0,c[G>>2]=aj,G)|0)|0;i=G;h0(aq,av,ax+76+(aj*4144|0)|0);T=ax+76+(aj*4144|0)+4132|0;if((c[T>>2]|0)!=0){be(av|0,64,341608,(G=i,i=i+8|0,c[G>>2]=aj,G)|0)|0;i=G;h0(aq,av,(c[T>>2]|0)==1?577008:372864)}be(av|0,64,333616,(G=i,i=i+8|0,c[G>>2]=aj,G)|0)|0;i=G;T=c[ax+76+(aj*4144|0)+4136>>2]|0;if((T|0)==1){az=143200}else if((T|0)==2){az=140424}else if((T|0)==3){az=137856}else if((T|0)==0){az=147560}else{az=131256}h0(aq,av,az);T=ax+76+(aj*4144|0)+4140|0;if((c[T>>2]|0)!=0){be(av|0,64,324824,(G=i,i=i+8|0,c[G>>2]=aj,G)|0)|0;i=G;r=c[T>>2]|0;be(ao|0,128,66464,(G=i,i=i+8|0,c[G>>2]=r,G)|0)|0;i=G;h0(aq,av,ao)}be(an|0,64,174512,(G=i,i=i+8|0,c[G>>2]=aj,G)|0)|0;i=G;h0(aq,an,(a[ax+76+(aj*4144|0)+4128|0]&1)!=0?577008:372864);do{if((a[ax+76+(aj*4144|0)+4129|0]&1)!=0){r=c[ax+76+(aj*4144|0)+4104>>2]|0;U=+g[ax+76+(aj*4144|0)+4112>>2];T=c[ax+76+(aj*4144|0)+4120>>2]|0;be(ap|0,64,164792,(G=i,i=i+16|0,c[G>>2]=622480,c[G+8>>2]=aj,G)|0)|0;i=G;if((r|0)==0){aA=157864}else if((r|0)==2){aA=154704}else if((r|0)==1){aA=150672}else{aA=177920}h0(aq,ap,aA);be(ap|0,64,161496,(G=i,i=i+16|0,c[G>>2]=622480,c[G+8>>2]=aj,G)|0)|0;i=G;if((r|0)==1){be(ao|0,128,66464,(G=i,i=i+8|0,c[G>>2]=T,G)|0)|0;i=G;h0(aq,ap,ao)}else{O=U;be(ao|0,128,502616,(G=i,i=i+8|0,h[G>>3]=O,G)|0)|0;i=G;h0(aq,ap,ao)}T=c[ax+76+(aj*4144|0)+4108>>2]|0;O=+g[ax+76+(aj*4144|0)+4116>>2];r=c[ax+76+(aj*4144|0)+4124>>2]|0;be(ap|0,64,164792,(G=i,i=i+16|0,c[G>>2]=622472,c[G+8>>2]=aj,G)|0)|0;i=G;if((T|0)==1){aB=150672}else if((T|0)==0){aB=157864}else if((T|0)==2){aB=154704}else{aB=177920}h0(aq,ap,aB);be(ap|0,64,161496,(G=i,i=i+16|0,c[G>>2]=622472,c[G+8>>2]=aj,G)|0)|0;i=G;if((T|0)==1){be(ao|0,128,66464,(G=i,i=i+8|0,c[G>>2]=r,G)|0)|0;i=G;h0(aq,ap,ao);break}else{U=O;be(ao|0,128,502616,(G=i,i=i+8|0,h[G>>3]=U,G)|0)|0;i=G;h0(aq,ap,ao);break}}}while(0);aj=aj+1|0;}while(aj>>>0<(c[d>>2]|0)>>>0)}aj=b+87196|0;do{if((c[aj>>2]|0)!=0){gGz(at|0,0,4096);ap=4096;an=at;av=b+87200|0;while(1){r=ap-1|0;if((r|0)==0){ad=7179;break}T=a[av]|0;a[an]=T;if(T<<24>>24==0){break}else{ap=r;an=an+1|0;av=av+1|0}}do{if((ad|0)==7179){a[an]=0;if((a[av]|0)==0){break}else{aC=av}do{aC=aC+1|0;}while((a[aC]|0)!=0)}}while(0);if((c[aj>>2]|0)>>>0>1){av=1;do{an=gGy(at|0)|0;ap=an>>>0>4096?0:4096-an|0;L10244:do{if((ap|0)==0){aD=316184;ad=7186}else{r=v+an|0;do{if((ap|0)==1){aE=316184;aF=r}else{T=v+(an+1)|0;a[r]=59;if((ap|0)==2){aE=316185;aF=T;break}a[T]=0;break L10244}}while(0);a[aF]=0;aD=aE;ad=7186}}while(0);do{if((ad|0)==7186){ad=0;if((a[aD]|0)==0){break}else{aG=aD}do{aG=aG+1|0;}while((a[aG]|0)!=0)}}while(0);ap=ax+66384+(av*4168|0)|0;an=gGy(at|0)|0;r=an>>>0>4096?0:4096-an|0;L10255:do{if((r|0)==0){aH=ap;ad=7193}else{T=r;Z=v+an|0;X=ap;while(1){am=T-1|0;if((am|0)==0){break}ak=a[X]|0;a[Z]=ak;if(ak<<24>>24==0){break L10255}else{T=am;Z=Z+1|0;X=X+1|0}}a[Z]=0;aH=X;ad=7193}}while(0);do{if((ad|0)==7193){ad=0;if((a[aH]|0)==0){break}else{aI=aH}do{aI=aI+1|0;}while((a[aI]|0)!=0)}}while(0);av=av+1|0;}while(av>>>0<(c[aj>>2]|0)>>>0)}h0(aq,307568,at);if((c[aj>>2]|0)==0){break}else{aJ=0}do{av=ax+66384+(aJ*4168|0)|0;h0(aq,av,ax+66384+(aJ*4168|0)+64|0);X=ax+66384+(aJ*4168|0)+4160|0;if((c[X>>2]|0)!=0){be(ar|0,64,299312,(G=i,i=i+8|0,c[G>>2]=av,G)|0)|0;i=G;h0(aq,ar,(c[X>>2]|0)!=1?577008:372864)}be(ar|0,64,291752,(G=i,i=i+8|0,c[G>>2]=av,G)|0)|0;i=G;av=c[ax+66384+(aJ*4168|0)+4164>>2]|0;if((av|0)==1){aK=143200}else if((av|0)==2){aK=140424}else if((av|0)==3){aK=137856}else if((av|0)==0){aK=147560}else{aK=131256}h0(aq,ar,aK);aJ=aJ+1|0;}while(aJ>>>0<(c[aj>>2]|0)>>>0)}}while(0);aj=b+125668|0;if((a[aj]|0)!=0){h0(aq,285456,aj)}aj=b+129768|0;if((a[aj]|0)!=0){h0(aq,278512,aj)}aj=b+120544|0;L10285:do{if((c[aj>>2]|0)!=0){gGz(as|0,0,4096);ar=4096;at=as;av=b+120548|0;while(1){X=ar-1|0;if((X|0)==0){ad=7213;break}Z=a[av]|0;a[at]=Z;if(Z<<24>>24==0){break}else{ar=X;at=at+1|0;av=av+1|0}}do{if((ad|0)==7213){a[at]=0;if((a[av]|0)==0){break}else{aL=av}do{aL=aL+1|0;}while((a[aL]|0)!=0)}}while(0);if((c[aj>>2]|0)>>>0>1){av=1;do{at=gGy(as|0)|0;ar=at>>>0>4096?0:4096-at|0;L10298:do{if((ar|0)==0){aM=316184;ad=7220}else{X=w+at|0;do{if((ar|0)==1){aN=316184;aO=X}else{Z=w+(at+1)|0;a[X]=59;if((ar|0)==2){aN=316185;aO=Z;break}a[Z]=0;break L10298}}while(0);a[aO]=0;aM=aN;ad=7220}}while(0);do{if((ad|0)==7220){ad=0;if((a[aM]|0)==0){break}else{aP=aM}do{aP=aP+1|0;}while((a[aP]|0)!=0)}}while(0);ar=ax+99732+(av*80|0)|0;at=gGy(as|0)|0;X=at>>>0>4096?0:4096-at|0;L10309:do{if((X|0)==0){aQ=ar;ad=7227}else{Z=X;ap=w+at|0;an=ar;while(1){r=Z-1|0;if((r|0)==0){break}T=a[an]|0;a[ap]=T;if(T<<24>>24==0){break L10309}else{Z=r;ap=ap+1|0;an=an+1|0}}a[ap]=0;aQ=an;ad=7227}}while(0);do{if((ad|0)==7227){ad=0;if((a[aQ]|0)==0){break}else{aR=aQ}do{aR=aR+1|0;}while((a[aR]|0)!=0)}}while(0);av=av+1|0;}while(av>>>0<(c[aj>>2]|0)>>>0)}h0(aq,271208,as);if((c[aj>>2]|0)==0){break}av=y|0;an=l|0;ap=m|0;ar=n|0;at=o|0;X=0;while(1){Z=ax+99732+(X*80|0)|0;be(av|0,64,234608,(G=i,i=i+8|0,c[G>>2]=Z,G)|0)|0;i=G;be(an|0,64,228232,(G=i,i=i+8|0,c[G>>2]=Z,G)|0)|0;i=G;be(ap|0,64,222336,(G=i,i=i+8|0,c[G>>2]=Z,G)|0)|0;i=G;be(ar|0,64,218088,(G=i,i=i+8|0,c[G>>2]=Z,G)|0)|0;i=G;be(at|0,64,214280,(G=i,i=i+8|0,c[G>>2]=Z,G)|0)|0;i=G;switch(c[ax+99732+(X*80|0)+68>>2]|0){case 2:{aS=206032;break};case 3:{aS=199680;break};case 1:{aS=194200;break};case 4:{aS=188128;break};case 5:{aS=182664;break};case 0:{aS=210960;break};default:{aS=177920}}h0(aq,av,aS);be(ao|0,128,582040,(G=i,i=i+8|0,c[G>>2]=e[ax+99732+(X*80|0)+76>>1]|0,G)|0)|0;i=G;h0(aq,ar,ao);be(ao|0,128,582040,(G=i,i=i+8|0,c[G>>2]=e[ax+99732+(X*80|0)+78>>1]|0,G)|0)|0;i=G;h0(aq,at,ao);Z=c[ax+99732+(X*80|0)+72>>2]|0;if((Z|0)==3){be(ao|0,128,66464,(G=i,i=i+8|0,c[G>>2]=2,G)|0)|0;i=G;h0(aq,ap,ao)}else if((Z|0)==1){be(ao|0,128,582040,(G=i,i=i+8|0,c[G>>2]=c[ax+99732+(X*80|0)+64>>2],G)|0)|0;i=G;h0(aq,an,ao)}else if((Z|0)==2){be(ao|0,128,66464,(G=i,i=i+8|0,c[G>>2]=1,G)|0)|0;i=G;h0(aq,ap,ao)}X=X+1|0;if(X>>>0>=(c[aj>>2]|0)>>>0){break L10285}}}}while(0);aj=B|0;ao=c[u>>2]|0;do{if((a[9271801]|0)==0){ad=7253}else{hE(aj,9271801,aw);as=h1(aq,aj)|0;X=(a[9375104]&1)!=0;if(as){aT=X;break}if(!X){ad=7253;break}bU(ao|0,336648,(G=i,i=i+8|0,c[G>>2]=aj,G)|0)|0;i=G;eY(ao|0)|0;ad=7253}}while(0);L10342:do{if((ad|0)==7253){do{if((a[9369961]|0)!=0){hE(aj,9369961,aw);X=h1(aq,aj)|0;as=(a[9375104]&1)!=0;if(X){aT=as;break L10342}if(!as){break}bU(ao|0,336648,(G=i,i=i+8|0,c[G>>2]=aj,G)|0)|0;i=G;eY(ao|0)|0}}while(0);do{if((a[au]|0)!=0){hE(aj,au,aw);as=h1(aq,aj)|0;X=(a[9375104]&1)!=0;if(as){aT=X;break L10342}if(!X){break}bU(ao|0,336648,(G=i,i=i+8|0,c[G>>2]=aj,G)|0)|0;i=G;eY(ao|0)|0}}while(0);hY(aq);cj(259152,110,1,ao|0)|0;eY(ao|0)|0;E=0;i=j;return E|0}}while(0);if(aT){bU(ao|0,434552,(G=i,i=i+8|0,c[G>>2]=aj,G)|0)|0;i=G;eY(ao|0)|0}jN(0,ay,aj);hY(aq);E=0;i=j;return E|0}}while(0);ay=jp(9534384,2)|0;jN(0,(ay|0)==3?2:ay,0);E=0;i=j;return E|0};case 92:{if((f|0)!=7){E=0;i=j;return E|0}a[9345348]=0;ay=b+64|0;jJ(c[ay>>2]|0);c[ay>>2]=0;G=b+16697|0;if((a[G]|0)==0){E=0;i=j;return E|0}c[ay>>2]=jI(G)|0;E=0;i=j;return E|0};case 102:{if((f|0)!=4){E=0;i=j;return E|0}G=9532104;ay=c[G+4>>2]|0;aT=9532104;c[aT>>2]=c[G>>2]|1;c[aT+4>>2]=ay;E=-1;i=j;return E|0};case 101:{if((f|0)!=4){E=0;i=j;return E|0}ay=9532104;aT=c[ay+4>>2]|0|0;G=9532104;c[G>>2]=c[ay>>2]&-514|512;c[G+4>>2]=aT;E=-1;i=j;return E|0};case 100:{if((f|0)==7){a[9374058]=0;E=0;i=j;return E|0}if((f-2|0)>>>0>=2){E=0;i=j;return E|0}a[9374058]=a[9374058]&1^1;E=0;i=j;return E|0};case 167:{if((f|0)!=4){E=0;i=j;return E|0}f=b+130296|0;aT=f;c[f>>2]=9288384+(D*2240|0);c[b+130300>>2]=110;c[b+130304>>2]=133;D=c[b+48>>2]|0;f=c[b+56>>2]|0;if((D|0)!=0){b=D+8|0;G=D+4|0;ay=c[G>>2]|0;if((c[b>>2]|0)>>>0<ay>>>0){aU=D|0}else{ad=(ay<<1)+2|0;c[G>>2]=ad;G=D|0;c[G>>2]=gGs(c[G>>2]|0,ad<<4)|0;aU=G}G=bG(9534384)|0;c[(c[aU>>2]|0)+(c[b>>2]<<4)>>2]=G;c[(c[aU>>2]|0)+(c[b>>2]<<4)+4>>2]=0;c[(c[aU>>2]|0)+(c[b>>2]<<4)+8>>2]=166;c[(c[aU>>2]|0)+(c[b>>2]<<4)+12>>2]=f;c[b>>2]=(c[b>>2]|0)+1}jU(aT);jT(aT);E=0;i=j;return E|0};default:{E=0;i=j;return E|0}}return 0}function jW(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=c[a+4>>2]|0;if((d|0)==0){e=c[a>>2]|0}else{e=d}d=c[b+4>>2]|0;if((d|0)==0){f=c[b>>2]|0}else{f=d}return gGF(e|0,f|0)|0}function jX(a,b){a=a|0;b=b|0;var d=0;d=c[2383406]|0;if((d|0)==0){return}if((c[d+24>>2]|0)==0){return}gq[c[d+20>>2]&15](c[2383358]|0,8453328,b,c[a+28>>2]|0,c[a+32>>2]|0,1.0);return}function jY(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,L=0,M=0;f=d;if((e|0)==0){return}if((a[e]|0)==0){return}g=hA(e,285224)|0;if((g|0)==0){return}e=g|0;h=c[e>>2]|0;i=g+4|0;j=c[i>>2]|0;if((h|0)==0){gGr(0);gGr(g);return}k=d+28|0;l=c[k>>2]|0;L10431:do{if((j|0)==0){m=0;n=0;o=0;p=l}else{q=0;r=0;s=0;t=l;u=j;v=h;while(1){w=c[v+(s<<3)>>2]|0;x=gGy(w|0)|0;y=((t-30|0)>>>0)/6|0;if(x>>>0>y>>>0){a[w+(y-2)|0]=46;a[w+(((((c[k>>2]|0)-30|0)>>>0)/6|0)-1)|0]=46;a[w+((((c[k>>2]|0)-30|0)>>>0)/6|0)|0]=46;a[w+(((((c[k>>2]|0)-30|0)>>>0)/6|0)+1)|0]=0;w=c[k>>2]|0;z=((w-30|0)>>>0)/6|0;A=w;B=c[i>>2]|0}else{z=x;A=t;B=u}x=(z*6|0)+15|0;w=r>>>0>x>>>0?r:x;x=q>>>0>z>>>0?q:z;y=s+1|0;if(y>>>0>=B>>>0){m=x;n=w;o=B;p=A;break L10431}q=x;r=w;s=y;t=A;u=B;v=c[e>>2]|0}}}while(0);B=o*11|0;o=B+16|0;A=(p-n|0)>>>1;p=((c[d+32>>2]|0)-o|0)>>>1;z=d+36|0;k=c[z>>2]|0;h=d+40|0;d=A+5|0;j=p+5|0;l=B+6+j|0;do{if(l>>>0>j>>>0){v=n-10+d|0;u=(c[h>>2]|0)>>>1;if(v>>>0>d>>>0){C=j}else{D=k;break}do{t=ag(C,u)|0;s=C>>>1;r=d;do{q=((r>>>1)+s&1)+1|0;b[k+(r+t<<1)>>1]=(q<<13|q<<9|q<<5|12)&65535;r=r+1|0;}while(r>>>0<v>>>0);C=C+1|0;}while(C>>>0<l>>>0);D=c[z>>2]|0}else{D=k}}while(0);k=n-5+A|0;l=(c[h>>2]|0)>>>1;if(k>>>0>A>>>0){C=p;do{v=ag(C,l)|0;u=C>>>1;r=A;do{t=((r>>>1)+u&1)+1|0;b[D+(r+v<<1)>>1]=(t<<13|t<<10|t<<5|12)&65535;r=r+1|0;}while(r>>>0<k>>>0);C=C+1|0;}while(C>>>0<j>>>0);E=c[z>>2]|0}else{E=D}D=A+n|0;n=cJ(D|0,-5|0)|0;C=n;n=B+11|0;B=p+n|0;do{if(B>>>0>p>>>0){k=(c[h>>2]|0)>>>1;if(K){F=p}else{G=E;break}do{l=ag(F,k)|0;r=F>>>1;v=C;do{u=((v>>>1)+r&1)+1|0;b[E+(v+l<<1)>>1]=(u<<13|u<<10|u<<5|12)&65535;v=v+1|0;}while(v>>>0<D>>>0);F=F+1|0;}while(F>>>0<B>>>0);G=c[z>>2]|0}else{G=E}}while(0);E=p+o|0;o=cJ(E|0,-5|0)|0;do{if(K){B=(c[h>>2]|0)>>>1;if(D>>>0<=d>>>0){H=G;break}F=o;do{C=ag(F,B)|0;k=F>>>1;v=d;do{l=((v>>>1)+k&1)+1|0;b[G+(v+C<<1)>>1]=(l<<13|l<<10|l<<5|12)&65535;v=v+1|0;}while(v>>>0<D>>>0);F=F+1|0;}while(F>>>0<E>>>0);H=c[z>>2]|0}else{H=G}}while(0);G=j+n|0;if(G>>>0>j>>>0){n=(c[h>>2]|0)>>>1;h=j;do{j=ag(h,n)|0;z=h>>>1;E=A;do{D=((E>>>1)+z&1)+1|0;b[H+(E+j<<1)>>1]=(D<<13|D<<10|D<<5|12)&65535;E=E+1|0;}while(E>>>0<d>>>0);h=h+1|0;}while(h>>>0<G>>>0)}do{if((c[i>>2]|0)==0){I=c[e>>2]|0}else{G=A+8|0;h=p+8|0;d=0;do{H=c[(c[e>>2]|0)+(d<<3)>>2]|0;j0(f,G+(((m-(gGy(H|0)|0)|0)*6|0)>>>1)|0,h+(d*11|0)|0,H,0);d=d+1|0;J=c[i>>2]|0;}while(d>>>0<J>>>0);d=c[e>>2]|0;if((J|0)==0){I=d;break}else{L=0;M=d}while(1){gGr(c[M+(L<<3)>>2]|0);d=L+1|0;h=c[e>>2]|0;if(d>>>0<(c[i>>2]|0)>>>0){L=d;M=h}else{I=h;break}}}}while(0);gGr(I);gGr(g);return}function jZ(d){d=d|0;var e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0.0,a5=0.0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0;e=i;i=i+1480|0;f=e|0;j=e+72|0;k=e+328|0;l=e+584|0;m=e+648|0;n=e+904|0;o=e+1160|0;p=e+1416|0;q=d;do{if((a[d+60|0]&1)!=0){r=9532104;if((c[r>>2]&8|0)==0&(c[r+4>>2]&0|0)==0){break}if((a[d+61|0]&1)!=0){break}i=e;return}}while(0);r=d+56|0;s=c[r>>2]|0;t=d+32|0;v=c[t>>2]|0;w=(((v-42|0)>>>0)/11|0)-1|0;x=w>>>1;y=w+s|0;z=d+52|0;A=c[(c[z>>2]|0)+8>>2]|0;B=y>>>0>A>>>0?A:y;y=A>>>0>w>>>0?s>>>0<x>>>0?0:s-x|0:0;x=(B-y|0)>>>0>w>>>0?y+w|0:B;B=d+36|0;w=c[B>>2]|0;s=d+40|0;A=d+28|0;C=c[A>>2]|0;do{if((v|0)==0){D=w;E=C;F=7502}else{G=c[s>>2]|0;H=G>>>1;if((C|0)==0){I=w;J=-5;L=G;F=7504;break}else{M=0}do{G=ag(M,H)|0;N=M>>>1;O=0;do{P=((O>>>1)+N&1)+1|0;b[w+(O+G<<1)>>1]=(P<<9|P<<13|P<<5|12)&65535;O=O+1|0;}while(O>>>0<C>>>0);M=M+1|0;}while(M>>>0<v>>>0);D=c[B>>2]|0;E=c[A>>2]|0;F=7502}}while(0);do{if((F|0)==7502){v=E-5|0;if(v>>>0<=5){Q=D;break}I=D;J=v;L=c[s>>2]|0;F=7504}}while(0);if((F|0)==7504){D=L>>>1;L=D*5|0;E=5;do{v=(E>>>1&1)+1|0;b[I+(E+L<<1)>>1]=(v<<10|v<<13|v<<5|12)&65535;E=E+1|0;}while(E>>>0<J>>>0);E=D*6|0;L=5;do{v=2-(L>>>1&1)|0;b[I+(L+E<<1)>>1]=(v<<10|v<<13|v<<5|12)&65535;L=L+1|0;}while(L>>>0<J>>>0);L=D*7|0;E=5;do{v=2-(E>>>1&1)|0;b[I+(E+L<<1)>>1]=(v<<10|v<<13|v<<5|12)&65535;E=E+1|0;}while(E>>>0<J>>>0);E=D<<3;L=5;do{v=(L>>>1&1)+1|0;b[I+(L+E<<1)>>1]=(v<<10|v<<13|v<<5|12)&65535;L=L+1|0;}while(L>>>0<J>>>0);L=D*9|0;D=5;do{E=(D>>>1&1)+1|0;b[I+(D+L<<1)>>1]=(E<<10|E<<13|E<<5|12)&65535;D=D+1|0;}while(D>>>0<J>>>0);Q=c[B>>2]|0}J=c[t>>2]|0;D=J-10|0;do{if((J-5|0)>>>0>D>>>0){L=(c[A>>2]|0)-5|0;I=(c[s>>2]|0)>>>1;if(L>>>0<=5){R=Q;S=J;break}E=ag(I,D)|0;v=D>>>1;M=5;do{C=((M>>>1)+v&1)+1|0;b[Q+(M+E<<1)>>1]=(C<<10|C<<13|C<<5|12)&65535;M=M+1|0;}while(M>>>0<L>>>0);M=J-9|0;E=ag(I,M)|0;v=M>>>1;M=5;do{C=((M>>>1)+v&1)+1|0;b[Q+(M+E<<1)>>1]=(C<<10|C<<13|C<<5|12)&65535;M=M+1|0;}while(M>>>0<L>>>0);M=J-8|0;E=ag(I,M)|0;v=M>>>1;M=5;do{C=((M>>>1)+v&1)+1|0;b[Q+(M+E<<1)>>1]=(C<<10|C<<13|C<<5|12)&65535;M=M+1|0;}while(M>>>0<L>>>0);M=J-7|0;E=ag(I,M)|0;v=M>>>1;M=5;do{C=((M>>>1)+v&1)+1|0;b[Q+(M+E<<1)>>1]=(C<<10|C<<13|C<<5|12)&65535;M=M+1|0;}while(M>>>0<L>>>0);M=J-6|0;E=ag(I,M)|0;v=M>>>1;M=5;do{C=((M>>>1)+v&1)+1|0;b[Q+(M+E<<1)>>1]=(C<<10|C<<13|C<<5|12)&65535;M=M+1|0;}while(M>>>0<L>>>0);R=c[B>>2]|0;S=c[t>>2]|0}else{R=Q;S=J}}while(0);J=S-5|0;if(J>>>0>5){Q=(c[s>>2]|0)>>>1;D=5;do{L=ag(D,Q)|0;M=D>>>1&1;E=M+1|0;v=(E<<10|E<<13|E<<5|12)&65535;b[R+(L+5<<1)>>1]=v;E=2-M|0;M=(E<<10|E<<13|E<<5|12)&65535;b[R+(L+6<<1)>>1]=M;b[R+(L+7<<1)>>1]=M;b[R+(L+8<<1)>>1]=v;b[R+(L+9<<1)>>1]=v;D=D+1|0;}while(D>>>0<J>>>0);T=c[B>>2]|0;U=c[t>>2]|0}else{T=R;U=S}S=c[A>>2]|0;R=S-10|0;B=U-5|0;do{if(B>>>0>5){U=(c[s>>2]|0)>>>1;if((S-5|0)>>>0<=R>>>0){break}J=R>>>1;D=S-9|0;Q=D>>>1;v=S-8|0;L=v>>>1;M=S-7|0;E=M>>>1;I=S-6|0;C=I>>>1;w=5;do{H=ag(w,U)|0;O=w>>>1;G=(O+J&1)+1|0;b[T+(H+R<<1)>>1]=(G<<10|G<<13|G<<5|12)&65535;G=(O+Q&1)+1|0;b[T+(H+D<<1)>>1]=(G<<10|G<<13|G<<5|12)&65535;G=(O+L&1)+1|0;b[T+(H+v<<1)>>1]=(G<<10|G<<13|G<<5|12)&65535;G=(O+E&1)+1|0;b[T+(H+M<<1)>>1]=(G<<10|G<<13|G<<5|12)&65535;G=(O+C&1)+1|0;b[T+(H+I<<1)>>1]=(G<<10|G<<13|G<<5|12)&65535;w=w+1|0;}while(w>>>0<B>>>0)}}while(0);B=c[d+48>>2]|0;T=c[B+8>>2]|0;L10559:do{if((T|0)==0){V=0;X=0;F=7546}else{R=T-1|0;S=c[B>>2]|0;s=c[S+(R<<4)>>2]|0;w=c[S+(R<<4)+8>>2]|0;switch(w|0){case 64:{be(j|0,256,258880,(Y=i,i=i+8|0,c[Y>>2]=s,Y)|0)|0;i=Y;Z=64;break L10559;break};case 4:case 68:case 70:case 69:{V=w;X=s;F=7546;break L10559;break};case 63:{be(j|0,256,336344,(Y=i,i=i+8|0,c[Y>>2]=s,Y)|0)|0;i=Y;Z=63;break L10559;break};case 67:{a[j|0]=65;a[j+1|0]=85;a[j+2|0]=68;a[j+3|0]=73;a[j+4|0]=79;a[j+5|0]=32;a[j+6|0]=79;a[j+7|0]=80;a[j+8|0]=84;a[j+9|0]=73;a[j+10|0]=79;a[j+11|0]=78;a[j+12|0]=83;a[j+13|0]=0;Z=67;break L10559;break};case 71:{a[j|0]=68;a[j+1|0]=82;a[j+2|0]=73;a[j+3|0]=86;a[j+4|0]=69;a[j+5|0]=82;a[j+6|0]=32;a[j+7|0]=79;a[j+8|0]=80;a[j+9|0]=84;a[j+10|0]=73;a[j+11|0]=79;a[j+12|0]=78;a[j+13|0]=83;a[j+14|0]=0;Z=71;break L10559;break};case 80:{be(j|0,256,201592,(Y=i,i=i+8|0,c[Y>>2]=s,Y)|0)|0;i=Y;Z=80;break L10559;break};case 62:{be(j|0,256,433936,(Y=i,i=i+8|0,c[Y>>2]=s,Y)|0)|0;i=Y;Z=62;break L10559;break};case 30:{a[j|0]=83;a[j+1|0]=72;a[j+2|0]=65;a[j+3|0]=68;a[j+4|0]=69;a[j+5|0]=82;a[j+6|0]=32;a[j+7|0]=79;a[j+8|0]=80;a[j+9|0]=84;a[j+10|0]=73;a[j+11|0]=79;a[j+12|0]=78;a[j+13|0]=83;a[j+14|0]=0;Z=30;break L10559;break};case 6:{a[j|0]=86;a[j+1|0]=73;a[j+2|0]=68;a[j+3|0]=69;a[j+4|0]=79;a[j+5|0]=32;a[j+6|0]=79;a[j+7|0]=80;a[j+8|0]=84;a[j+9|0]=73;a[j+10|0]=79;a[j+11|0]=78;a[j+12|0]=83;a[j+13|0]=0;Z=6;break L10559;break};case 66:{a[j|0]=67;a[j+1|0]=79;a[j+2|0]=82;a[j+3|0]=69;a[j+4|0]=32;a[j+5|0]=79;a[j+6|0]=80;a[j+7|0]=84;a[j+8|0]=73;a[j+9|0]=79;a[j+10|0]=78;a[j+11|0]=83;a[j+12|0]=0;Z=66;break L10559;break};case 78:{a[j|0]=68;a[j+1|0]=73;a[j+2|0]=83;a[j+3|0]=75;a[j+4|0]=32;a[j+5|0]=79;a[j+6|0]=80;a[j+7|0]=84;a[j+8|0]=73;a[j+9|0]=79;a[j+10|0]=78;a[j+11|0]=83;a[j+12|0]=0;Z=78;break L10559;break};default:{R=w-35|0;if(R>>>0<24){if(((R>>>0)%3|0|0)==0){_=w}else{V=w;X=s;F=7546;break L10559}}else{if((w|0)==32){_=32}else{V=w;X=s;F=7546;break L10559}}be(j|0,256,553864,(Y=i,i=i+8|0,c[Y>>2]=s,Y)|0)|0;i=Y;Z=_;break L10559}}}}while(0);L10577:do{if((F|0)==7546){if((V-68|0)>>>0<3|(V|0)==15|(V|0)==16|(V|0)==166|(V|0)==5|(V|0)==4){_=j|0;be(_|0,256,539184,(Y=i,i=i+8|0,c[Y>>2]=X,Y)|0)|0;i=Y;Z=V;break}switch(V|0){case 89:{be(j|0,256,463496,(Y=i,i=i+8|0,c[Y>>2]=X,Y)|0)|0;i=Y;Z=89;break L10577;break};case 94:{be(j|0,256,429824,(Y=i,i=i+8|0,c[Y>>2]=X,Y)|0)|0;i=Y;Z=94;break L10577;break};case 93:{be(j|0,256,452320,(Y=i,i=i+8|0,c[Y>>2]=X,Y)|0)|0;i=Y;Z=93;break L10577;break};case 90:{be(j|0,256,441584,(Y=i,i=i+8|0,c[Y>>2]=X,Y)|0)|0;i=Y;Z=90;break L10577;break};case 87:{be(j|0,256,499304,(Y=i,i=i+8|0,c[Y>>2]=X,Y)|0)|0;i=Y;Z=87;break L10577;break};case 95:{be(j|0,256,418600,(Y=i,i=i+8|0,c[Y>>2]=X,Y)|0)|0;i=Y;Z=95;break L10577;break};case 88:{be(j|0,256,474880,(Y=i,i=i+8|0,c[Y>>2]=X,Y)|0)|0;i=Y;Z=88;break L10577;break};case 61:{a[j|0]=76;a[j+1|0]=79;a[j+2|0]=65;a[j+3|0]=68;a[j+4|0]=32;a[j+5|0]=72;a[j+6|0]=73;a[j+7|0]=83;a[j+8|0]=84;a[j+9|0]=79;a[j+10|0]=82;a[j+11|0]=89;a[j+12|0]=0;Z=61;break L10577;break};case 86:{be(j|0,256,487832,(Y=i,i=i+8|0,c[Y>>2]=X,Y)|0)|0;i=Y;Z=86;break L10577;break};case 104:{be(j|0,256,512176,(Y=i,i=i+8|0,c[Y>>2]=X,Y)|0)|0;i=Y;Z=104;break L10577;break};default:{if((a[d+68|0]&1)==0){_=c[d+20796>>2]|0;B=(_|0)==0?c[2367342]|0:_;_=(B|0)==0?396272:B;B=j|0;be(B|0,256,383880,(Y=i,i=i+16|0,c[Y>>2]=_,c[Y+8>>2]=X,Y)|0)|0;i=Y;Z=V;break L10577}else{_=j|0;be(_|0,256,406696,(Y=i,i=i+8|0,c[Y>>2]=X,Y)|0)|0;i=Y;Z=V;break L10577}}}}}while(0);V=k|0;jS(V,((((c[A>>2]|0)-30|0)>>>0)/6|0)-3|0,((c[2382972]|0)>>>0)/15|0,j|0,1);j0(q,30,15,V,1);V=c[d+20796>>2]|0;j=(V|0)==0?c[2367342]|0:V;V=c[d+20800>>2]|0;k=(V|0)==0?c[2367343]|0:V;V=l|0;be(V|0,64,364296,(Y=i,i=i+24|0,c[Y>>2]=356976,c[Y+8>>2]=(j|0)==0?396272:j,c[Y+16>>2]=(k|0)==0?9534384:k,Y)|0)|0;i=Y;k=(c[t>>2]|0)-42|0;j0(q,30,18-((k>>>0)%11|0)+k|0,V,1);if(y>>>0>=x>>>0){i=e;return}V=n|0;k=d+20816|0;t=o|0;o=p|0;p=m|0;m=Z-35|0;j=m>>>0<24;l=((m>>>0)%3|0|0)==0;m=(Z|0)==32;X=(Z-62|0)>>>0<2;_=(Z|0)==61;B=(Z-87|0)>>>0<3|(Z|0)==91|(Z|0)==92|(Z|0)==93|(Z|0)==90|(Z|0)==94|(Z|0)==86|(Z|0)==95;T=n+1|0;s=n+2|0;w=n+3|0;R=n+4|0;S=n+5|0;I=n+6|0;C=n+7|0;M=n+8|0;E=n+9|0;v=n+10|0;L=d+20888|0;d=l|B^1;D=f;Q=n+11|0;J=n+12|0;U=n+13|0;G=n+14|0;H=n+15|0;O=n+16|0;N=n+17|0;P=n+18|0;n=f+8|0;$=f+9|0;aa=f+10|0;ab=f+11|0;ac=f+12|0;ad=f+13|0;ae=f+14|0;af=f+15|0;ah=f|0;f=27;ai=y;L10601:while(1){y=c[c[z>>2]>>2]|0;aj=c[y+(ai<<4)>>2]|0;ak=c[y+(ai<<4)+8>>2]|0;if((Z|0)==69){al=24;F=7565}else if((Z|0)==166|(Z|0)==68){al=21;F=7565}else{am=19}if((F|0)==7565){F=0;am=al}L10608:do{if((ak-31|0)>>>0<28){L10610:do{switch(Z|0){case 78:case 71:case 70:case 69:case 67:case 66:case 30:case 6:case 4:case 68:{F=7576;break};default:{if(j){if(!l){F=7576;break L10610}}else{if(!m){F=7576;break L10610}}switch(ak|0){case 4:case 6:case 66:case 67:case 68:case 69:case 70:case 71:case 78:{F=7580;break L10610;break};case 30:{F=7825;break L10610;break};default:{}}an=ak-35|0;if(an>>>0<24){if(((an>>>0)%3|0|0)!=0){F=7576;break L10610}}else{switch(ak|0){case 34:{F=7579;break L10610;break};case 33:{F=7578;break L10610;break};case 32:{break};case 30:{F=7825;break L10610;break};case 31:{F=7577;break L10610;break};default:{F=7580;break L10610}}}a[V]=40;a[T]=68;a[s]=73;a[w]=82;a[R]=41;a[S]=0;ao=1;ap=aj;aq=5;break L10608}}}while(0);if((F|0)==7576){F=0;switch(ak|0){case 34:{F=7579;break};case 33:{F=7578;break};case 32:case 30:{F=7825;break};case 31:{F=7577;break};default:{F=7580}}}if((F|0)==7579){F=0;an=c[L>>2]|0;be(V|0,256,574896,(Y=i,i=i+8|0,c[Y>>2]=an,Y)|0)|0;i=Y;ao=34;ap=aj;aq=am;break}else if((F|0)==7578){F=0;a[V]=0;ao=33;ap=aj;aq=am;break}else if((F|0)==7580){F=0;an=ak-35|0;ar=(an>>>0)/3|0;as=(an>>>0)%3|0;if((as|0)==2){an=~~+g[k+76+(ar*4144|0)+4112>>2];if((an|0)==0){a[V]=68;a[T]=111;a[s]=110;a[w]=39;a[R]=116;a[S]=32;a[I]=99;a[C]=97;a[M]=114;a[E]=101;a[v]=0;ao=ak;ap=aj;aq=am;break}else{be(V|0,256,488152,(Y=i,i=i+8|0,c[Y>>2]=an,Y)|0)|0;i=Y;ao=ak;ap=aj;aq=am;break}}else if((as|0)==1){an=c[k+76+(ar*4144|0)+4132>>2]|0;if((an|0)==1){a[V]=76;a[T]=105;a[s]=110;a[w]=101;a[R]=97;a[S]=114;a[I]=0;ao=ak;ap=aj;aq=am;break}else if((an|0)==2){a[V]=78;a[T]=101;a[s]=97;a[w]=114;a[R]=101;a[S]=115;a[I]=116;a[C]=0;ao=ak;ap=aj;aq=am;break}else if((an|0)==0){a[V]=68;a[T]=111;a[s]=110;a[w]=39;a[R]=116;a[S]=32;a[I]=99;a[C]=97;a[M]=114;a[E]=101;a[v]=0;ao=ak;ap=aj;aq=am;break}else{ao=ak;ap=aj;aq=am;break}}else if((as|0)==0){as=k+76+(ar*4144|0)|0;if((a[as]|0)==0){a[V]=78;a[T]=47;a[s]=65;a[w]=0;ao=ak;ap=aj;aq=am;break}ar=cE(as|0,47)|0;an=256;at=0;au=V;av=(ar|0)==0?as:ar+1|0;while(1){ar=an-1|0;if((ar|0)==0){F=7585;break}as=a[av]|0;a[au]=as;if(as<<24>>24==0){aw=at;break}else{an=ar;at=at+1|0;au=au+1|0;av=av+1|0}}do{if((F|0)==7585){F=0;a[au]=0;if((a[av]|0)==0){aw=at;break}else{ax=av;ay=at}while(1){an=ax+1|0;ar=ay+1|0;if((a[an]|0)==0){aw=ar;break}else{ax=an;ay=ar}}}}while(0);if(aw>>>0<256){ao=ak;ap=aj;aq=am;break}else{F=7588;break L10601}}else{ao=ak;ap=aj;aq=am;break}}else if((F|0)==7825){F=0;a[V]=46;a[T]=46;a[s]=46;a[w]=0;ao=ak;ap=aj;aq=am;break}else if((F|0)==7577){F=0;be(V|0,256,196880,(Y=i,i=i+8|0,c[Y>>2]=(a[9263580]&1)!=0?324568:315904,Y)|0)|0;i=Y;ao=31;ap=aj;aq=am;break}}else{if(X){a[V]=40;if((ak|0)==0){a[T]=67;a[s]=79;a[w]=82;a[R]=69;a[S]=41;a[I]=0;at=c[y+(ai<<4)+4>>2]|0;ao=0;ap=(at|0)==0?aj:at;aq=6;break}else{a[T]=68;a[s]=73;a[w]=82;a[R]=41;a[S]=0;ao=1;ap=aj;aq=5;break}}L10658:do{switch(Z|0){case 104:case 80:case 64:{F=7606;break};case 4:case 6:case 30:case 66:case 67:case 68:case 69:case 70:case 71:case 78:{break};default:{if(j){if(!d){F=7606;break L10658}}else{if(m){break L10658}if(B){F=7606;break L10658}}if(!_){break L10658}a[V]=0;ao=ak;ap=aj;aq=0;break L10608}}}while(0);if((F|0)==7606){F=0;if((ak|0)==3){a[V]=0;ao=3;ap=aj;aq=0;break}else if((ak|0)==0){a[V]=40;a[T]=70;a[s]=73;a[w]=76;a[R]=69;a[S]=41;a[I]=0;ao=0;ap=aj;aq=6;break}else{a[V]=40;a[T]=68;a[s]=73;a[w]=82;a[R]=41;a[S]=0;ao=1;ap=aj;aq=5;break}}if(ak>>>0>65535){at=ak-65536|0;av=c[(c[2368540]|0)+4100>>2]|0;au=256;ar=V;an=c[(c[c[av+(at<<4)+8>>2]>>2]|0)+(c[av+(at<<4)+12>>2]<<3)>>2]|0;while(1){at=au-1|0;if((at|0)==0){break}av=a[an]|0;a[ar]=av;if(av<<24>>24==0){ao=ak;ap=aj;aq=am;break L10608}else{au=at;ar=ar+1|0;an=an+1|0}}a[ar]=0;if((a[an]|0)==0){ao=ak;ap=aj;aq=am;break}else{az=an}while(1){au=az+1|0;if((a[au]|0)==0){ao=ak;ap=aj;aq=am;break L10608}else{az=au}}}switch(ak|0){case 114:case 115:case 116:case 117:case 118:case 110:case 119:case 111:case 113:case 112:case 120:case 121:case 122:case 123:case 124:case 125:case 126:case 127:case 128:case 129:case 130:case 131:case 132:case 133:case 165:{an=ak-110|0;a[n]=85;a[$]=110;a[aa]=107;a[ab]=110;a[ac]=111;a[ad]=119;a[ae]=110;a[af]=0;ar=(c[2112498]|0)+130280|0;au=9288384+((c[ar>>2]|0)*2240|0)+(an*40|0)+16|0;at=c[au+4>>2]|0;c[ah>>2]=c[au>>2];c[ah+4>>2]=at;at=c[(c[2383356]|0)+20>>2]|0;if((at|0)==0){iA(V,9288384+((c[ar>>2]|0)*2240|0)+(an*40|0)|0,256);ao=ak;ap=aj;aq=am;break L10608}ge[at&63](D,0,0,0,64);at=256;an=V;ar=n;while(1){au=at-1|0;if((au|0)==0){break}av=a[ar]|0;a[an]=av;if(av<<24>>24==0){ao=ak;ap=aj;aq=am;break L10608}else{at=au;an=an+1|0;ar=ar+1|0}}a[an]=0;if((a[ar]|0)==0){ao=ak;ap=aj;aq=am;break L10608}else{aA=ar}while(1){at=aA+1|0;if((a[at]|0)==0){ao=ak;ap=aj;aq=am;break}else{aA=at}}break};case 104:{ar=cE(9324856,47)|0;an=256;at=V;au=(ar|0)==0?9324856:ar+1|0;while(1){ar=an-1|0;if((ar|0)==0){break}av=a[au]|0;a[at]=av;if(av<<24>>24==0){ao=ak;ap=aj;aq=am;break L10608}else{an=ar;at=at+1|0;au=au+1|0}}a[at]=0;if((a[au]|0)==0){ao=ak;ap=aj;aq=am;break L10608}else{aB=au}while(1){an=aB+1|0;if((a[an]|0)==0){ao=ak;ap=aj;aq=am;break}else{aB=an}}break};case 59:case 60:case 61:case 66:case 15:case 17:case 6:case 67:case 78:case 65:case 30:case 32:case 62:case 80:case 68:case 69:case 70:case 71:case 167:case 168:case 5:{a[V]=46;a[T]=46;a[s]=46;a[w]=0;ao=ak;ap=aj;aq=am;break L10608;break};case 87:{au=256;at=V;an=(a[9365865]|0)!=0?9365865:474944;while(1){ar=au-1|0;if((ar|0)==0){break}av=a[an]|0;a[at]=av;if(av<<24>>24==0){ao=ak;ap=aj;aq=am;break L10608}else{au=ar;at=at+1|0;an=an+1|0}}a[at]=0;if((a[an]|0)==0){ao=ak;ap=aj;aq=am;break L10608}else{aC=an}while(1){au=aC+1|0;if((a[au]|0)==0){ao=ak;ap=aj;aq=am;break}else{aC=au}}break};case 76:case 77:{be(V|0,256,66464,(Y=i,i=i+8|0,c[Y>>2]=c[2367336],Y)|0)|0;i=Y;ao=ak;ap=aj;aq=am;break L10608;break};case 86:{an=256;at=V;au=(a[9357636]|0)!=0?9357636:463552;while(1){ar=an-1|0;if((ar|0)==0){break}av=a[au]|0;a[at]=av;if(av<<24>>24==0){ao=ak;ap=aj;aq=am;break L10608}else{an=ar;at=at+1|0;au=au+1|0}}a[at]=0;if((a[au]|0)==0){ao=ak;ap=aj;aq=am;break L10608}else{aD=au}while(1){an=aD+1|0;if((a[an]|0)==0){ao=ak;ap=aj;aq=am;break}else{aD=an}}break};case 105:{be(V|0,256,418648,(Y=i,i=i+8|0,h[Y>>3]=+g[2332238],Y)|0)|0;i=Y;ao=ak;ap=aj;aq=am;break L10608;break};case 107:{be(V|0,256,406776,(Y=i,i=i+8|0,c[Y>>2]=(c[(c[2112498]|0)+130280>>2]|0)+1,Y)|0)|0;i=Y;ao=ak;ap=aj;aq=am;break L10608;break};case 108:{au=c[9324268+(c[(c[2112498]|0)+130280>>2]<<2)>>2]|0;if(au>>>0>=8){a[V]=68;a[T]=105;a[s]=115;a[w]=97;a[R]=98;a[S]=108;a[I]=101;a[C]=100;a[M]=0;ao=ak;ap=aj;aq=am;break L10608}at=9324332+(au<<6)|0;if((a[at]|0)==0){be(V|0,256,396296,(Y=i,i=i+8|0,c[Y>>2]=au,Y)|0)|0;i=Y;ao=ak;ap=aj;aq=am;break L10608}else{aE=256;aF=V;aG=at}while(1){at=aE-1|0;if((at|0)==0){break}au=a[aG]|0;a[aF]=au;if(au<<24>>24==0){ao=ak;ap=aj;aq=am;break L10608}else{aE=at;aF=aF+1|0;aG=aG+1|0}}a[aF]=0;if((a[aG]|0)==0){ao=ak;ap=aj;aq=am;break L10608}else{aH=aG}while(1){at=aH+1|0;if((a[at]|0)==0){ao=ak;ap=aj;aq=am;break}else{aH=at}}break};case 94:{at=256;au=V;an=(a[9452954]|0)!=0?9452954:474944;while(1){ar=at-1|0;if((ar|0)==0){break}av=a[an]|0;a[au]=av;if(av<<24>>24==0){ao=ak;ap=aj;aq=am;break L10608}else{at=ar;au=au+1|0;an=an+1|0}}a[au]=0;if((a[an]|0)==0){ao=ak;ap=aj;aq=am;break L10608}else{aI=an}while(1){at=aI+1|0;if((a[at]|0)==0){ao=ak;ap=aj;aq=am;break}else{aI=at}}break};case 98:{be(V|0,256,487872,(Y=i,i=i+8|0,h[Y>>3]=+g[2322070],Y)|0)|0;i=Y;ao=ak;ap=aj;aq=am;break L10608;break};case 73:{be(V|0,256,574896,(Y=i,i=i+8|0,c[Y>>2]=c[2341459],Y)|0)|0;i=Y;ao=ak;ap=aj;aq=am;break L10608;break};case 74:{an=256;au=V;at=(a[9532118]&1)!=0?201728:158776;while(1){ar=an-1|0;if((ar|0)==0){break}av=a[at]|0;a[au]=av;if(av<<24>>24==0){ao=ak;ap=aj;aq=am;break L10608}else{an=ar;au=au+1|0;at=at+1|0}}a[au]=0;if((a[at]|0)==0){ao=ak;ap=aj;aq=am;break L10608}else{aJ=at}while(1){an=aJ+1|0;if((a[an]|0)==0){ao=ak;ap=aj;aq=am;break}else{aJ=an}}break};case 83:{at=256;au=V;an=9288320;while(1){ar=at-1|0;if((ar|0)==0){break}av=a[an]|0;a[au]=av;if(av<<24>>24==0){ao=ak;ap=aj;aq=am;break L10608}else{at=ar;au=au+1|0;an=an+1|0}}a[au]=0;if((a[an]|0)==0){ao=ak;ap=aj;aq=am;break L10608}else{aK=an}while(1){at=aK+1|0;if((a[at]|0)==0){ao=ak;ap=aj;aq=am;break}else{aK=at}}break};case 109:{switch(c[9324232+(c[(c[2112498]|0)+130280>>2]<<2)>>2]|0){case 516:{aL=256;aM=V;aN=333464;break};case 772:{aL=256;aM=V;aN=324592;break};case 260:{aL=256;aM=V;aN=315928;break};case 0:{aL=256;aM=V;aN=329592;break};case 1:{aL=256;aM=V;aN=364328;break};case 5:{aL=256;aM=V;aN=357e3;break};case 257:{aL=256;aM=V;aN=349e3;break};case 2:{aL=256;aM=V;aN=341440;break};default:{aL=256;aM=V;aN=505984}}while(1){an=aL-1|0;if((an|0)==0){break}au=a[aN]|0;a[aM]=au;if(au<<24>>24==0){ao=ak;ap=aj;aq=am;break L10608}else{aL=an;aM=aM+1|0;aN=aN+1|0}}a[aM]=0;if((a[aN]|0)==0){ao=ak;ap=aj;aq=am;break L10608}else{aO=aN}while(1){an=aO+1|0;if((a[an]|0)==0){ao=ak;ap=aj;aq=am;break}else{aO=an}}break};case 93:{an=256;au=V;at=(a[9369961]|0)!=0?9369961:474944;while(1){ar=an-1|0;if((ar|0)==0){break}av=a[at]|0;a[au]=av;if(av<<24>>24==0){ao=ak;ap=aj;aq=am;break L10608}else{an=ar;au=au+1|0;at=at+1|0}}a[au]=0;if((a[at]|0)==0){ao=ak;ap=aj;aq=am;break L10608}else{aP=at}while(1){an=aP+1|0;if((a[an]|0)==0){ao=ak;ap=aj;aq=am;break}else{aP=an}}break};case 11:{at=9532104;be(V|0,256,((c[at>>2]&32768|0)!=0|(c[at+4>>2]&0|0)!=0?201728:158776)|0,(Y=i,i=i+1|0,i=i+7&-8,c[Y>>2]=0,Y)|0)|0;i=Y;ao=ak;ap=aj;aq=am;break L10608;break};case 19:{at=256;au=V;an=3120+(c[2315899]<<5)|0;while(1){ar=at-1|0;if((ar|0)==0){break}av=a[an]|0;a[au]=av;if(av<<24>>24==0){ao=ak;ap=aj;aq=am;break L10608}else{at=ar;au=au+1|0;an=an+1|0}}a[au]=0;if((a[an]|0)==0){ao=ak;ap=aj;aq=am;break L10608}else{aQ=an}while(1){at=aQ+1|0;if((a[at]|0)==0){ao=ak;ap=aj;aq=am;break}else{aQ=at}}break};case 21:{an=256;au=V;at=(a[9263569]&1)!=0?201728:158776;while(1){ar=an-1|0;if((ar|0)==0){break}av=a[at]|0;a[au]=av;if(av<<24>>24==0){ao=ak;ap=aj;aq=am;break L10608}else{an=ar;au=au+1|0;at=at+1|0}}a[au]=0;if((a[at]|0)==0){ao=ak;ap=aj;aq=am;break L10608}else{aR=at}while(1){an=aR+1|0;if((a[an]|0)==0){ao=ak;ap=aj;aq=am;break}else{aR=an}}break};case 12:{be(V|0,256,66464,(Y=i,i=i+8|0,c[Y>>2]=c[2383023],Y)|0)|0;i=Y;ao=ak;ap=aj;aq=am;break L10608;break};case 20:{at=256;au=V;an=(a[9263568]&1)!=0?201728:158776;while(1){ar=at-1|0;if((ar|0)==0){break}av=a[an]|0;a[au]=av;if(av<<24>>24==0){ao=ak;ap=aj;aq=am;break L10608}else{at=ar;au=au+1|0;an=an+1|0}}a[au]=0;if((a[an]|0)==0){ao=ak;ap=aj;aq=am;break L10608}else{aS=an}while(1){at=aS+1|0;if((a[at]|0)==0){ao=ak;ap=aj;aq=am;break}else{aS=at}}break};case 79:{an=gD[c[2368521]&8191]()|0;au=gD[c[2368519]&8191]()|0;if(au>>>0<an>>>0){an=au+1|0;be(V|0,256,574896,(Y=i,i=i+8|0,c[Y>>2]=an,Y)|0)|0;i=Y;ao=ak;ap=aj;aq=am;break L10608}else{a[V]=78;a[T]=111;a[s]=32;a[w]=68;a[R]=105;a[S]=115;a[I]=107;a[C]=0;ao=ak;ap=aj;aq=am;break L10608}break};case 64:{if((a[9395610]|0)==0){a[V]=60;a[T]=100;a[s]=101;a[w]=102;a[R]=97;a[S]=117;a[I]=108;a[C]=116;a[M]=62;a[E]=0;ao=ak;ap=aj;aq=am;break L10608}an=cE(9395610,47)|0;au=256;at=0;ar=V;av=(an|0)==0?9395610:an+1|0;while(1){an=au-1|0;if((an|0)==0){F=7768;break}as=a[av]|0;a[ar]=as;if(as<<24>>24==0){aT=at;break}else{au=an;at=at+1|0;ar=ar+1|0;av=av+1|0}}do{if((F|0)==7768){F=0;a[ar]=0;if((a[av]|0)==0){aT=at;break}else{aU=av;aV=at}while(1){au=aU+1|0;an=aV+1|0;if((a[au]|0)==0){aT=an;break}else{aU=au;aV=an}}}}while(0);if(aT>>>0<256){ao=ak;ap=aj;aq=am;break L10608}else{F=7771;break L10601}break};case 97:{at=256;av=V;ar=(a[9474209]&1)!=0?201728:158776;while(1){an=at-1|0;if((an|0)==0){break}au=a[ar]|0;a[av]=au;if(au<<24>>24==0){ao=ak;ap=aj;aq=am;break L10608}else{at=an;av=av+1|0;ar=ar+1|0}}a[av]=0;if((a[ar]|0)==0){ao=ak;ap=aj;aq=am;break L10608}else{aW=ar}while(1){at=aW+1|0;if((a[at]|0)==0){ao=ak;ap=aj;aq=am;break}else{aW=at}}break};case 13:{ar=256;av=V;at=(a[9263589]&1)!=0?201728:158776;while(1){an=ar-1|0;if((an|0)==0){break}au=a[at]|0;a[av]=au;if(au<<24>>24==0){ao=ak;ap=aj;aq=am;break L10608}else{ar=an;av=av+1|0;at=at+1|0}}a[av]=0;if((a[at]|0)==0){ao=ak;ap=aj;aq=am;break L10608}else{aX=at}while(1){ar=aX+1|0;if((a[ar]|0)==0){ao=ak;ap=aj;aq=am;break}else{aX=ar}}break};case 72:{at=256;av=V;ar=(a[9365828]&1)!=0?201728:158776;while(1){an=at-1|0;if((an|0)==0){break}au=a[ar]|0;a[av]=au;if(au<<24>>24==0){ao=ak;ap=aj;aq=am;break L10608}else{at=an;av=av+1|0;ar=ar+1|0}}a[av]=0;if((a[ar]|0)==0){ao=ak;ap=aj;aq=am;break L10608}else{aY=ar}while(1){at=aY+1|0;if((a[at]|0)==0){ao=ak;ap=aj;aq=am;break}else{aY=at}}break};case 0:{a[V]=40;a[T]=70;a[s]=73;a[w]=76;a[R]=69;a[S]=41;a[I]=0;ao=ak;ap=aj;aq=6;break L10608;break};case 1:{a[V]=40;a[T]=68;a[s]=73;a[w]=82;a[R]=41;a[S]=0;ao=ak;ap=aj;aq=5;break L10608;break};case 75:{ar=c[2341463]|0;if((ar|0)==0){a[V]=79;a[T]=70;a[s]=70;a[w]=0;ao=ak;ap=aj;aq=am;break L10608}else{be(V|0,256,499344,(Y=i,i=i+8|0,c[Y>>2]=ar,Y)|0)|0;i=Y;ao=ak;ap=aj;aq=am;break L10608}break};case 14:{ar=256;av=V;at=64392+((c[2315898]|0)*68|0)|0;while(1){an=ar-1|0;if((an|0)==0){break}au=a[at]|0;a[av]=au;if(au<<24>>24==0){ao=ak;ap=aj;aq=am;break L10608}else{ar=an;av=av+1|0;at=at+1|0}}a[av]=0;if((a[at]|0)==0){ao=ak;ap=aj;aq=am;break L10608}else{aZ=at}while(1){ar=aZ+1|0;if((a[ar]|0)==0){ao=ak;ap=aj;aq=am;break}else{aZ=ar}}break};case 28:{do{if((a[9271800]&1)==0){at=9523432;av=c[at>>2]|0;ar=c[at+4>>2]|0;at=0;an=ar>>>0>at>>>0|ar>>>0==at>>>0&av>>>0>2048>>>0?2048:av;if(an>>>0<2){break}else{a_=0;a$=0;a0=0}do{av=9507048+(a0<<3)|0;a$=gGK(c[av>>2]|0,c[av+4>>2]|0,a$,a_)|0;a_=K;a0=a0+1|0;}while(a0>>>0<an>>>0);av=gGS(a$,a_,an,0)|0;at=K;ar=0;au=0;as=0;do{a1=9507048+(ar<<3)|0;a2=gGL(c[a1>>2]|0,c[a1+4>>2]|0,av,at)|0;a1=K;a3=gGU(a2,a1,a2,a1)|0;as=gGK(a3,K,as,au)|0;au=K;ar=ar+1|0;}while(ar>>>0<an>>>0);a4=+(av>>>0)+ +(at|0)*4294967296.0;a5=+W(+((+(as>>>0)+ +(au|0)*4294967296.0)/+((an-1|0)>>>0>>>0)))/a4*100.0;be(V|0,256,553920,(Y=i,i=i+24|0,h[Y>>3]=1.0e6/a4,h[Y+8>>3]=a5,c[Y+16>>2]=an,Y)|0)|0;i=Y;ao=ak;ap=aj;aq=am;break L10608}}while(0);a[V]=78;a[T]=47;a[s]=65;a[w]=0;ao=ak;ap=aj;aq=am;break L10608;break};case 89:{ar=256;a3=V;a1=(a[9448858]|0)!=0?9448858:463552;while(1){a2=ar-1|0;if((a2|0)==0){break}a6=a[a1]|0;a[a3]=a6;if(a6<<24>>24==0){ao=ak;ap=aj;aq=am;break L10608}else{ar=a2;a3=a3+1|0;a1=a1+1|0}}a[a3]=0;if((a[a1]|0)==0){ao=ak;ap=aj;aq=am;break L10608}else{a7=a1}while(1){ar=a7+1|0;if((a[ar]|0)==0){ao=ak;ap=aj;aq=am;break}else{a7=ar}}break};case 85:{a1=256;a3=V;ar=(a[9280027]&1)!=0?201728:158776;while(1){a2=a1-1|0;if((a2|0)==0){break}a6=a[ar]|0;a[a3]=a6;if(a6<<24>>24==0){ao=ak;ap=aj;aq=am;break L10608}else{a1=a2;a3=a3+1|0;ar=ar+1|0}}a[a3]=0;if((a[ar]|0)==0){ao=ak;ap=aj;aq=am;break L10608}else{a8=ar}while(1){a1=a8+1|0;if((a[a1]|0)==0){ao=ak;ap=aj;aq=am;break}else{a8=a1}}break};case 100:{be(V|0,256,((a[9374058]&1)!=0?201728:158776)|0,(Y=i,i=i+1|0,i=i+7&-8,c[Y>>2]=0,Y)|0)|0;i=Y;ao=ak;ap=aj;aq=am;break L10608;break};case 92:{ar=256;a3=V;a1=(a[9345348]|0)!=0?9345348:452384;while(1){a2=ar-1|0;if((a2|0)==0){break}a6=a[a1]|0;a[a3]=a6;if(a6<<24>>24==0){ao=ak;ap=aj;aq=am;break L10608}else{ar=a2;a3=a3+1|0;a1=a1+1|0}}a[a3]=0;if((a[a1]|0)==0){ao=ak;ap=aj;aq=am;break L10608}else{a9=a1}while(1){ar=a9+1|0;if((a[ar]|0)==0){ao=ak;ap=aj;aq=am;break}else{a9=ar}}break};case 24:{be(V|0,256,574896,(Y=i,i=i+8|0,c[Y>>2]=c[2315893],Y)|0)|0;i=Y;ao=ak;ap=aj;aq=am;break L10608;break};case 90:{a1=256;a3=V;ar=(a[9444762]|0)!=0?9444762:463552;while(1){a2=a1-1|0;if((a2|0)==0){break}a6=a[ar]|0;a[a3]=a6;if(a6<<24>>24==0){ao=ak;ap=aj;aq=am;break L10608}else{a1=a2;a3=a3+1|0;ar=ar+1|0}}a[a3]=0;if((a[ar]|0)==0){ao=ak;ap=aj;aq=am;break L10608}else{ba=ar}while(1){a1=ba+1|0;if((a[a1]|0)==0){ao=ak;ap=aj;aq=am;break}else{ba=a1}}break};case 18:{ar=256;a3=V;a1=(a[9271800]&1)!=0?201728:158776;while(1){a2=ar-1|0;if((a2|0)==0){break}a6=a[a1]|0;a[a3]=a6;if(a6<<24>>24==0){ao=ak;ap=aj;aq=am;break L10608}else{ar=a2;a3=a3+1|0;a1=a1+1|0}}a[a3]=0;if((a[a1]|0)==0){ao=ak;ap=aj;aq=am;break L10608}else{bb=a1}while(1){ar=bb+1|0;if((a[ar]|0)==0){ao=ak;ap=aj;aq=am;break}else{bb=ar}}break};case 95:{a1=256;a3=V;ar=(a[9361732]|0)!=0?9361732:463552;while(1){a2=a1-1|0;if((a2|0)==0){break}a6=a[ar]|0;a[a3]=a6;if(a6<<24>>24==0){ao=ak;ap=aj;aq=am;break L10608}else{a1=a2;a3=a3+1|0;ar=ar+1|0}}a[a3]=0;if((a[ar]|0)==0){ao=ak;ap=aj;aq=am;break L10608}else{bc=ar}while(1){a1=bc+1|0;if((a[a1]|0)==0){ao=ak;ap=aj;aq=am;break}else{bc=a1}}break};case 10:{if((a[9263580]&1)==0){a[V]=80;a[T]=111;a[s]=105;a[w]=110;a[R]=116;a[S]=32;a[I]=102;a[C]=105;a[M]=108;a[E]=116;a[v]=101;a[Q]=114;a[J]=105;a[U]=110;a[G]=103;a[H]=0;ao=ak;ap=aj;aq=am;break L10608}else{a[V]=66;a[T]=105;a[s]=108;a[w]=105;a[R]=110;a[S]=101;a[I]=97;a[C]=114;a[M]=32;a[E]=102;a[v]=105;a[Q]=108;a[J]=116;a[U]=101;a[G]=114;a[H]=105;a[O]=110;a[N]=103;a[P]=0;ao=ak;ap=aj;aq=am;break L10608}break};case 88:{ar=256;a3=V;a1=(a[9271801]|0)!=0?9271801:474944;while(1){a2=ar-1|0;if((a2|0)==0){break}a6=a[a1]|0;a[a3]=a6;if(a6<<24>>24==0){ao=ak;ap=aj;aq=am;break L10608}else{ar=a2;a3=a3+1|0;a1=a1+1|0}}a[a3]=0;if((a[a1]|0)==0){ao=ak;ap=aj;aq=am;break L10608}else{bd=a1}while(1){ar=bd+1|0;if((a[ar]|0)==0){ao=ak;ap=aj;aq=am;break}else{bd=ar}}break};case 82:{a1=256;a3=V;ar=9280032;while(1){a2=a1-1|0;if((a2|0)==0){break}a6=a[ar]|0;a[a3]=a6;if(a6<<24>>24==0){ao=ak;ap=aj;aq=am;break L10608}else{a1=a2;a3=a3+1|0;ar=ar+1|0}}a[a3]=0;if((a[ar]|0)==0){ao=ak;ap=aj;aq=am;break L10608}else{bf=ar}while(1){a1=bf+1|0;if((a[a1]|0)==0){ao=ak;ap=aj;aq=am;break}else{bf=a1}}break};case 81:{ar=256;a3=V;a1=9263480;while(1){a2=ar-1|0;if((a2|0)==0){break}a6=a[a1]|0;a[a3]=a6;if(a6<<24>>24==0){ao=ak;ap=aj;aq=am;break L10608}else{ar=a2;a3=a3+1|0;a1=a1+1|0}}a[a3]=0;if((a[a1]|0)==0){ao=ak;ap=aj;aq=am;break L10608}else{bg=a1}while(1){ar=bg+1|0;if((a[ar]|0)==0){ao=ak;ap=aj;aq=am;break}else{bg=ar}}break};case 26:{be(V|0,256,570216,(Y=i,i=i+8|0,h[Y>>3]=+g[2315887],Y)|0)|0;i=Y;ao=ak;ap=aj;aq=am;break L10608;break};case 27:{a1=256;a3=V;ar=(a[9263582]&1)!=0?201728:158776;while(1){a2=a1-1|0;if((a2|0)==0){break}a6=a[ar]|0;a[a3]=a6;if(a6<<24>>24==0){ao=ak;ap=aj;aq=am;break L10608}else{a1=a2;a3=a3+1|0;ar=ar+1|0}}a[a3]=0;if((a[ar]|0)==0){ao=ak;ap=aj;aq=am;break L10608}else{bh=ar}while(1){a1=bh+1|0;if((a[a1]|0)==0){ao=ak;ap=aj;aq=am;break}else{bh=a1}}break};case 22:{be(V|0,256,574896,(Y=i,i=i+8|0,c[Y>>2]=c[2315894],Y)|0)|0;i=Y;ao=ak;ap=aj;aq=am;break L10608;break};case 25:{be(V|0,256,570216,(Y=i,i=i+8|0,h[Y>>3]=+g[2315886],Y)|0)|0;i=Y;ao=ak;ap=aj;aq=am;break L10608;break};case 23:{ar=256;a3=V;a1=(a[9263570]&1)!=0?201728:158776;while(1){a2=ar-1|0;if((a2|0)==0){break}a6=a[a1]|0;a[a3]=a6;if(a6<<24>>24==0){ao=ak;ap=aj;aq=am;break L10608}else{ar=a2;a3=a3+1|0;a1=a1+1|0}}a[a3]=0;if((a[a1]|0)==0){ao=ak;ap=aj;aq=am;break L10608}else{bi=a1}while(1){ar=bi+1|0;if((a[ar]|0)==0){ao=ak;ap=aj;aq=am;break}else{bi=ar}}break};case 106:{be(V|0,256,418648,(Y=i,i=i+8|0,h[Y>>3]=+g[2332239],Y)|0)|0;i=Y;ao=ak;ap=aj;aq=am;break L10608;break};default:{a[V]=0;ao=ak;ap=aj;aq=0;break L10608}}}}while(0);aj=(ai|0)==(c[r>>2]|0);ak=256;y=t;a1=ap;while(1){a3=ak-1|0;if((a3|0)==0){F=7814;break}ar=a[a1]|0;a[y]=ar;if(ar<<24>>24==0){bj=64;bk=o;bl=V;break}else{ak=a3;y=y+1|0;a1=a1+1|0}}do{if((F|0)==7814){F=0;a[y]=0;if((a[a1]|0)==0){bj=64;bk=o;bl=V;break}else{bm=a1}while(1){ak=bm+1|0;if((a[ak]|0)==0){bj=64;bk=o;bl=V;break}else{bm=ak}}}}while(0);while(1){a1=bj-1|0;if((a1|0)==0){F=7818;break}y=a[bl]|0;a[bk]=y;if(y<<24>>24==0){break}else{bj=a1;bk=bk+1|0;bl=bl+1|0}}do{if((F|0)==7818){F=0;a[bk]=0;if((a[bl]|0)==0){break}else{bn=bl}do{bn=bn+1|0;}while((a[bn]|0)!=0)}}while(0);if(ao>>>0<2){jS(t,((((c[A>>2]|0)-30|0)>>>0)/6|0)-3-aq|0,((c[2382972]|0)>>>0)/15|0,ap,aj)}else{jS(o,aq,((c[2382972]|0)>>>0)/15|0,V,aj)}a1=((((c[A>>2]|0)-30|0)>>>0)/6|0)-3-aq|0;be(p|0,256,291560,(Y=i,i=i+48|0,c[Y>>2]=aj?62:32,c[Y+8>>2]=a1,c[Y+16>>2]=a1,c[Y+24>>2]=t,c[Y+32>>2]=aq,c[Y+40>>2]=o,Y)|0)|0;i=Y;j0(q,15,f,p,aj);a1=ai+1|0;if(a1>>>0<x>>>0){f=f+11|0;ai=a1}else{F=7834;break}}if((F|0)==7771){ai=c[u>>2]|0;bU(ai|0,547632,(Y=i,i=i+16|0,c[Y>>2]=551256,c[Y+8>>2]=579,Y)|0)|0;i=Y;eY(ai|0)|0;fm(2)}else if((F|0)==7588){ai=c[u>>2]|0;bU(ai|0,547632,(Y=i,i=i+16|0,c[Y>>2]=551256,c[Y+8>>2]=579,Y)|0)|0;i=Y;eY(ai|0)|0;fm(2)}else if((F|0)==7834){i=e;return}}function j_(){var a=0;a=gGq(132176)|0;do{if((a|0)!=0){if((c[a-4>>2]&3|0)==0){break}gGz(a|0,0,132176)}}while(0);c[a+36>>2]=8453328;c[a+28>>2]=320;c[a+32>>2]=240;c[a+40>>2]=640;c[a+16692>>2]=62168;return a|0}function j$(b){b=b|0;if((a[b+16696|0]&1)==0){return}gGr(c[b+16692>>2]|0);return}function j0(e,f,g,h,i){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;j=a[h]|0;if(j<<24>>24==0){return}k=e+16692|0;l=i?32639:-1;i=e+40|0;m=e+36|0;e=h;h=f;f=j;while(1){j=h+4|0;n=h+3|0;o=h+2|0;p=h+1|0;q=0;r=f;while(1){s=q*5|0;t=q+g|0;u=c[k>>2]|0;if((1<<(s&7)&(d[u+((s>>3)+((r&255)*7|0))|0]|0)|0)==0){v=r;w=u}else{u=(ag((c[i>>2]|0)>>>1,t)|0)+h|0;b[(c[m>>2]|0)+(u<<1)>>1]=l;v=a[e]|0;w=c[k>>2]|0}u=s+1|0;if(((d[w+(((v&255)*7|0)+(u>>3))|0]|0)&1<<(u&7)|0)==0){x=v;y=w}else{u=p+(ag((c[i>>2]|0)>>>1,t)|0)|0;b[(c[m>>2]|0)+(u<<1)>>1]=l;x=a[e]|0;y=c[k>>2]|0}u=s+2|0;if(((d[y+(((x&255)*7|0)+(u>>3))|0]|0)&1<<(u&7)|0)==0){z=x;A=y}else{u=o+(ag((c[i>>2]|0)>>>1,t)|0)|0;b[(c[m>>2]|0)+(u<<1)>>1]=l;z=a[e]|0;A=c[k>>2]|0}u=s+3|0;if(((d[A+(((z&255)*7|0)+(u>>3))|0]|0)&1<<(u&7)|0)==0){B=z;C=A}else{u=n+(ag((c[i>>2]|0)>>>1,t)|0)|0;b[(c[m>>2]|0)+(u<<1)>>1]=l;B=a[e]|0;C=c[k>>2]|0}u=s+4|0;if(((d[C+(((B&255)*7|0)+(u>>3))|0]|0)&1<<(u&7)|0)!=0){u=j+(ag((c[i>>2]|0)>>>1,t)|0)|0;b[(c[m>>2]|0)+(u<<1)>>1]=l}u=q+1|0;if((u|0)>=10){break}q=u;r=a[e]|0}r=e+1|0;q=a[r]|0;if(q<<24>>24==0){break}else{e=r;h=h+6|0;f=q}}return}function j1(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=i;i=i+16|0;f=e|0;g=a+4|0;h=c[g>>2]|0;L11005:do{if((h|0)==0){j=0}else{k=a|0;l=c[k>>2]|0;L11007:do{if((b|0)==0){m=0;while(1){do{if((c[l+(m*12|0)>>2]|0)==0){if((fa(c[l+(m*12|0)+4>>2]|0,9341252)|0)!=0){break}if((fa(c[l+(m*12|0)+8>>2]|0,d|0)|0)==0){n=m;break L11007}}}while(0);o=m+1|0;if(o>>>0<h>>>0){m=o}else{j=h;break L11005}}}else{m=0;while(1){o=c[l+(m*12|0)>>2]|0;do{if((o|0)!=0){if((fa(b|0,o|0)|0)!=0){break}if((fa(c[l+(m*12|0)+4>>2]|0,9341252)|0)!=0){break}if((fa(c[l+(m*12|0)+8>>2]|0,d|0)|0)==0){n=m;break L11007}}}while(0);o=m+1|0;if(o>>>0<h>>>0){m=o}else{j=h;break L11005}}}}while(0);if((n|0)==0){i=e;return}m=f;o=l+(n*12|0)|0;c[m>>2]=c[o>>2];c[m+4>>2]=c[o+4>>2];c[m+8>>2]=c[o+8>>2];gGG(l+12|0,l|0,n*12|0|0);o=c[k>>2]|0;c[o>>2]=c[m>>2];c[o+4>>2]=c[m+4>>2];c[o+8>>2]=c[m+8>>2];i=e;return}}while(0);n=a+8|0;f=c[n>>2]|0;if((j|0)==(f|0)){h=j-1|0;j=a|0;m=c[j>>2]|0;o=m+(h*12|0)|0;gGr(c[o>>2]|0);gGr(c[m+(h*12|0)+4>>2]|0);gGr(c[m+(h*12|0)+8>>2]|0);gGz(o|0,0,12);c[g>>2]=(c[g>>2]|0)-1;p=c[n>>2]|0;q=j}else{p=f;q=a|0}a=c[q>>2]|0;gGG(a+12|0,a|0,(p*12|0)-12|0);if((b|0)==0){r=0}else{r=bG(b|0)|0}c[c[q>>2]>>2]=r;r=bG(9341252)|0;c[(c[q>>2]|0)+4>>2]=r;r=bG(d|0)|0;c[(c[q>>2]|0)+8>>2]=r;c[g>>2]=(c[g>>2]|0)+1;i=e;return}function j2(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;b=i;if((a|0)==0){i=b;return}d=a+12|0;e=c[d>>2]|0;do{if((e|0)!=0){f=fw(e|0,622488)|0;if((f|0)==0){break}g=a+4|0;if((c[g>>2]|0)!=0){h=a|0;j=0;do{k=c[h>>2]|0;l=c[k+(j*12|0)>>2]|0;m=c[k+(j*12|0)+4>>2]|0;n=c[k+(j*12|0)+8>>2]|0;bU(f|0,433720,(k=i,i=i+24|0,c[k>>2]=(l|0)==0?9534384:l,c[k+8>>2]=m,c[k+16>>2]=n,k)|0)|0;i=k;j=j+1|0;}while(j>>>0<(c[g>>2]|0)>>>0)}aY(f|0)|0}}while(0);gGr(c[d>>2]|0);d=a+8|0;e=a|0;g=c[e>>2]|0;if((c[d>>2]|0)==0){o=g}else{j=0;h=g;while(1){g=h+(j*12|0)|0;gGr(c[g>>2]|0);gGr(c[h+(j*12|0)+4>>2]|0);gGr(c[h+(j*12|0)+8>>2]|0);gGz(g|0,0,12);g=j+1|0;k=c[e>>2]|0;if(g>>>0<(c[d>>2]|0)>>>0){j=g;h=k}else{o=k;break}}}gGr(o);gGr(a);i=b;return}function j3(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;f=i;i=i+72|0;h=f|0;j=f+8|0;k=f+40|0;l=b+4|0;m=c[l>>2]|0;if((m|0)==0){i=f;return}if((gD[c[m+16>>2]&8191]()|0)==0){i=f;return}m=j+25|0;a[m]=0;n=c[l>>2]|0;do{if((n|0)==0){o=7904}else{gg[c[n+28>>2]&4095](1,j);p=c[l>>2]|0;if((p|0)==0){o=7904;break}q=gD[c[p+16>>2]&8191]()|0;p=c[l>>2]|0;r=k+25|0;a[r]=0;if((p|0)==0){s=0;t=r;break}gg[c[p+28>>2]&4095](q,k);q=c[l>>2]|0;if((q|0)==0){s=0;t=r;break}do{if((gD[c[q+16>>2]&8191]()|0)==1){if((a[m]&1)!=0){break}i=f;return}}while(0);q=c[l>>2]|0;if((q|0)==0){s=0;t=r;break}s=gD[c[q+16>>2]&8191]()|0;t=r}}while(0);if((o|0)==7904){n=k+25|0;a[n]=0;s=0;t=n}n=s-1|0;k=b+1572|0;c[k>>2]=n;if((a[t]&1)==0){v=n}else{c[k>>2]=s;v=s}if((a[m]&1)==0){g[j+8>>2]=1.0;g[j+12>>2]=1.0;c[j+4>>2]=0;c[j>>2]=0;a[m]=1}m=b+1124|0;s=m;n=j;c[m>>2]=c[n>>2];c[m+4>>2]=c[n+4>>2];c[m+8>>2]=c[n+8>>2];c[m+12>>2]=c[n+12>>2];c[m+16>>2]=c[n+16>>2];c[m+20>>2]=c[n+20>>2];c[m+24>>2]=c[n+24>>2];if((v|0)>1){v=1;while(1){n=v+1|0;m=s+(v*28|0)|0;j=s+(v*28|0)+25|0;a[j]=0;t=c[l>>2]|0;if((t|0)==0){o=7919}else{gg[c[t+28>>2]&4095](n,m);if((a[j]&1)==0){o=7919}}if((o|0)==7919){o=0;g[s+(v*28|0)+12>>2]=1.0;g[s+(v*28|0)+8>>2]=1.0;c[s+(v*28|0)+4>>2]=0;c[m>>2]=0;a[j]=1}if((n|0)<(c[k>>2]|0)){v=n}else{break}}}j4(b,d,e,c[b+1664>>2]|0,c[b+1668>>2]|0);e=c[k>>2]|0;if((e|0)>0){d=b+740|0;v=c[u>>2]|0;n=0;while(1){j=(c[d+(n*24|0)>>2]|0)-1|0;m=j>>>1|j;j=m>>>2|m;m=j>>>4|j;j=m>>>8|m;m=(j>>>16|j)+1|0;c[d+(n*24|0)+16>>2]=m;j=(c[d+(n*24|0)+4>>2]|0)-1|0;t=j>>>1|j;j=t>>>2|t;t=j>>>4|j;j=t>>>8|t;t=(j>>>16|j)+1|0;c[d+(n*24|0)+20>>2]=t;if((a[9375104]&1)!=0){bU(v|0,481144,(w=i,i=i+24|0,c[w>>2]=n,c[w+8>>2]=m,c[w+16>>2]=t,w)|0)|0;i=w;eY(v|0)|0}t=n+1|0;m=c[k>>2]|0;if((t|0)<(m|0)){n=t}else{x=m;break}}}else{x=e}e=b+676|0;n=e;v=e;cp(x|0,v|0);x=(a[9263580]&1)!=0?9729:9728;if((c[k>>2]|0)>0){e=b+740|0;d=b+2460|0;m=c[u>>2]|0;t=0;do{dD(3553,c[n+(t<<2)>>2]|0);a[h]=0;j=c[l>>2]|0;do{if((j|0)==0){y=33071;z=x}else{q=t+2|0;if(gA[c[j+20>>2]&16383](q,h)|0){A=(a[h]&1)!=0?9729:9728}else{A=x}p=c[l>>2]|0;if((p|0)==0){y=33071;z=A;break}B=gj[c[p+24>>2]&4095](q)|0;if((B|0)==2){y=10497;z=A;break}else if((B|0)==3){y=33648;z=A;break}else if((B|0)==0|(B|0)==1){y=33071;z=A;break}else{y=0;z=A;break}}}while(0);ds(3553,10240,z|0);ds(3553,10241,z|0);ds(3553,10242,y|0);ds(3553,10243,y|0);do{if((a[s+(t*28|0)+25|0]&1)==0){o=7947}else{if((a[s+(t*28|0)+24|0]&1)==0){o=7947;break}do{if((a[d]&1)==0){j=dG(7939)|0;if((j|0)==0){C=0;break}C=(e3(j|0,214184)|0)!=0}else{C=0}}while(0);if((a[9375104]&1)!=0){j=C?570200:553848;bU(m|0,586824,(w=i,i=i+16|0,c[w>>2]=214184,c[w+8>>2]=j,w)|0)|0;i=w;eY(m|0)|0}if(!C){cj(210800,67,1,m|0)|0;eY(m|0)|0}if((a[9375104]&1)!=0){bU(m|0,205840,(w=i,i=i+8|0,c[w>>2]=t,w)|0)|0;i=w;eY(m|0)|0}fP(3553,0,6408,c[e+(t*24|0)+16>>2]|0,c[e+(t*24|0)+20>>2]|0,0,6408,5126,0)}}while(0);if((o|0)==7947){o=0;fP(3553,0,6408,c[e+(t*24|0)+16>>2]|0,c[e+(t*24|0)+20>>2]|0,0,6408,5121,0)}t=t+1|0;}while((t|0)<(c[k>>2]|0))}dD(3553,0);dD(3553,0);t=b+612|0;e=t;m=t;bN(c[k>>2]|0,m|0);t=0;while(1){if((t|0)>=(c[k>>2]|0)){o=7953;break}d$(36160,c[e+(t<<2)>>2]|0);bH(36160,36064,3553,c[n+(t<<2)>>2]|0,0);if((fn(36160)|0)==36053){t=t+1|0}else{o=7952;break}}if((o|0)==7952){by(c[k>>2]|0,m|0);m=c[u>>2]|0;cj(217976,94,1,m|0)|0;eY(m|0)|0;dK(c[k>>2]|0,v|0);cj(559672,78,1,m|0)|0;eY(m|0)|0;i=f;return}else if((o|0)==7953){a[b+1576|0]=1;i=f;return}}function j4(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0.0,q=0.0,r=0,s=0,t=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;h=i;i=i+8|0;j=h|0;k=c[a+1768>>2]|0;l=c[a+1772>>2]|0;c[j>>2]=0;fK(3379,j|0);m=a+1572|0;if((c[m>>2]|0)==0){i=h;return}n=a+1124|0;o=a+740|0;a=c[u>>2]|0;p=+(f>>>0>>>0);q=+(e>>>0>>>0);e=b;b=d;d=k;k=l;l=0;f=0;while(1){r=c[n+(l*28|0)>>2]|0;if((r|0)==0){s=n+(l*28|0)+8|0;c[o+(l*24|0)>>2]=~~(+(e>>>0>>>0)*+g[s>>2]);c[o+(l*24|0)+8>>2]=~~(+(d>>>0>>>0)*+g[s>>2])}else if((r|0)==1){s=c[n+(l*28|0)+16>>2]|0;c[o+(l*24|0)+8>>2]=s;c[o+(l*24|0)>>2]=s}else if((r|0)==2){r=~~(q*+g[n+(l*28|0)+8>>2]);c[o+(l*24|0)+8>>2]=r;c[o+(l*24|0)>>2]=r}r=c[n+(l*28|0)+4>>2]|0;if((r|0)==0){s=n+(l*28|0)+12|0;c[o+(l*24|0)+4>>2]=~~(+(b>>>0>>>0)*+g[s>>2]);c[o+(l*24|0)+12>>2]=~~(+(k>>>0>>>0)*+g[s>>2])}else if((r|0)==1){s=c[n+(l*28|0)+20>>2]|0;c[o+(l*24|0)+12>>2]=s;c[o+(l*24|0)+4>>2]=s}else if((r|0)==2){r=~~(p*+g[n+(l*28|0)+12>>2]);c[o+(l*24|0)+12>>2]=r;c[o+(l*24|0)+4>>2]=r}r=o+(l*24|0)|0;s=c[r>>2]|0;t=c[j>>2]|0;if(s>>>0>t>>>0){c[r>>2]=t;v=1;w=t}else{v=f;w=s}s=o+(l*24|0)+4|0;x=c[s>>2]|0;if(x>>>0>t>>>0){c[s>>2]=t;y=1;z=t}else{y=v;z=x}x=o+(l*24|0)+8|0;A=c[x>>2]|0;if(A>>>0>t>>>0){c[x>>2]=t;B=1;C=t}else{B=y;C=A}A=o+(l*24|0)+12|0;D=c[A>>2]|0;if(D>>>0>t>>>0){c[A>>2]=t;E=7979}else{if(B){E=7979}else{F=0;G=w;H=z;I=C;J=D}}if((E|0)==7979){E=0;bU(a|0,199416,(D=i,i=i+16|0,c[D>>2]=t,c[D+8>>2]=t,D)|0)|0;i=D;eY(a|0)|0;F=1;G=c[r>>2]|0;H=c[s>>2]|0;I=c[x>>2]|0;J=c[A>>2]|0}A=l+1|0;if(A>>>0<(c[m>>2]|0)>>>0){e=G;b=H;d=I;k=J;l=A;f=F}else{break}}i=h;return}function j5(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var h=0,j=0,k=0,l=0.0,m=0,n=0,o=0,p=0,q=0.0,r=0,s=0,t=0,u=0,v=0.0,w=0.0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;h=i;i=i+64|0;j=h|0;k=c[(c[b>>2]|0)+24>>2]|0;if((k|0)==0){l=+(d>>>0>>>0)/+(e>>>0>>>0)}else{l=+gt[k&3](d,e)}do{if((a[9263589]&1)==0){if((a[b+1650|0]&1)==0){c[b+1676>>2]=0;c[b+1672>>2]=0;c[b+1680>>2]=d;c[b+1684>>2]=e;m=d;n=e;o=0;p=0;break}q=+g[2367356];do{if((c[2315898]|0)==7){k=c[2383020]|0;r=c[2383019]|0;s=k;t=(c[b+1668>>2]|0)-(c[2383018]|0)-k|0;u=c[2383017]|0}else{if(+V(+(l-q))<9999999747378752.0e-20){r=d;s=e;t=0;u=0;break}if(l>q){v=(q/l+-1.0)*.5+.5;w=+(d>>>0>>>0);k=~~+ba(+(w*(.5-v)));r=~~+ba(+(w*2.0*v));s=e;t=0;u=k;break}else{v=(l/q+-1.0)*.5+.5;w=+(e>>>0>>>0);k=~~+ba(+(w*(.5-v)));r=d;s=~~+ba(+(w*2.0*v));t=k;u=0;break}}}while(0);c[b+1672>>2]=u;c[b+1676>>2]=t;c[b+1680>>2]=r;c[b+1684>>2]=s;m=r;n=s;o=u;p=t}else{k=b+1672|0;x=(a[b+1650|0]&1)==0;if((c[2315898]|0)==7){y=c[2383019]|0;z=c[2383020]|0;A=y;B=z;C=d-y|0;D=e-z|0}else{z=c[2367347]|0;y=~~+ba(+(+g[2367356]*+(z>>>0>>>0)));do{if(y>>>0>d>>>0|z>>>0>e>>>0){E=0;F=0}else{if(x){E=(d>>>0)%(y>>>0)|0;F=(e>>>0)%(z>>>0)|0;break}else{G=(d>>>0)/(y>>>0)|0;H=(e>>>0)/(z>>>0)|0;I=G>>>0<H>>>0?G:H;H=d-(ag(I,y)|0)|0;E=H;F=e-(ag(I,z)|0)|0;break}}}while(0);A=d-E|0;B=e-F|0;C=E;D=F}c[b+1680>>2]=A;c[b+1684>>2]=B;z=(C|0)/2|0;c[k>>2]=z;y=(D|0)/2|0;c[b+1676>>2]=y;m=A;n=B;o=z;p=y}}while(0);dm(o|0,p|0,m|0,n|0);p=b+1872|0;gGz(p|0,0,48);g[b+1932>>2]=1.0;g[p>>2]=2.0;g[b+1892>>2]=2.0;g[b+1912>>2]=-1.0;g[b+1920>>2]=-1.0;g[b+1924>>2]=-1.0;g[b+1928>>2]=-0.0;if(f){l=+((c[b+1652>>2]|0)>>>0>>>0)*3.141592653589793/180.0;q=+Y(+l);v=+Z(+l);gGz(j|0,0,60);g[j+40>>2]=1.0;g[j+60>>2]=1.0;g[j>>2]=q;g[j+20>>2]=q;g[j+16>>2]=-0.0-v;g[j+4>>2]=v;kz(b+1808|0,j,p);J=b+1696|0;K=J;c[K>>2]=m;L=b+1700|0;M=L;c[M>>2]=n;i=h;return}else{j=b+1808|0;gGC(j|0,p|0,64)|0;J=b+1696|0;K=J;c[K>>2]=m;L=b+1700|0;M=L;c[M>>2]=n;i=h;return}}function j6(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,D=0,E=0,F=0,G=0,H=0,I=0;f=i;i=i+8|0;h=f|0;j=gGq(2468)|0;if((j|0)==0){k=0;i=f;return k|0}if((c[j-4>>2]&3|0)!=0){gGz(j|0,0,2468)}l=j;m=c[2368529]|0;n=c[2368530]|0;L11213:do{if((a[9263512]|0)==0){do{if((cl(12448)|0)!=0){if(!(kD()|0)){break}o=j;c[o>>2]=49200;p=49200;q=o;break L11213}}while(0);c[j>>2]=0;r=8026}else{o=(fa(473288,9263512)|0)==0;s=o?49200:0;if(!o){o=c[u>>2]|0;bU(o|0,222104,(t=i,i=i+8|0,c[t>>2]=9263512,t)|0)|0;i=t;eY(o|0)|0;r=8026;break}if(!(gp[c[s+8>>2]&16383](1,m,n)|0)){o=c[u>>2]|0;bU(o|0,234336,(t=i,i=i+16|0,c[t>>2]=240640,c[t+8>>2]=9263512,t)|0)|0;i=t;eY(o|0)|0;r=8026;break}if(gD[c[s>>2]&8191]()|0){o=j;c[o>>2]=s;p=s;q=o;break}else{o=c[u>>2]|0;v=c[s+68>>2]|0;bU(o|0,228008,(t=i,i=i+8|0,c[t>>2]=v,t)|0)|0;i=t;eY(o|0)|0;r=8026;break}}}while(0);if((r|0)==8026){gGr(j);k=0;i=f;return k|0}n=j+2416|0;m=b;c[n>>2]=c[m>>2];c[n+4>>2]=c[m+4>>2];c[n+8>>2]=c[m+8>>2];c[n+12>>2]=c[m+12>>2];c[n+16>>2]=c[m+16>>2];if((a[9375104]&1)==0){w=p}else{m=c[u>>2]|0;n=c[p+68>>2]|0;bU(m|0,429784,(t=i,i=i+8|0,c[t>>2]=n,t)|0)|0;i=t;eY(m|0)|0;w=c[q>>2]|0}m=j+1656|0;n=j+1660|0;gg[c[w+20>>2]&4095](m,n);if((a[9375104]&1)!=0){w=c[u>>2]|0;p=c[m>>2]|0;o=c[n>>2]|0;bU(w|0,418552,(t=i,i=i+16|0,c[t>>2]=p,c[t+8>>2]=o,t)|0)|0;i=t;eY(w|0)|0}w=b+9|0;gf[c[(c[q>>2]|0)+12>>2]&2047]((a[w]&1)!=0?c[2315893]|0:0);o=c[b>>2]|0;p=c[b+4>>2]|0;v=b+8|0;s=(a[v]&1)!=0;if(s&(o|0)==0&(p|0)==0){x=c[m>>2]|0;y=c[n>>2]|0}else{x=o;y=p}if(!(gp[c[(c[q>>2]|0)+16>>2]&16383](x,y,s)|0)){gGr(j);k=0;i=f;return k|0}fF()|0;s=dG(7936)|0;y=dG(7937)|0;if((a[9375104]&1)!=0){x=c[u>>2]|0;bU(x|0,406648,(t=i,i=i+16|0,c[t>>2]=s,c[t+8>>2]=y,t)|0)|0;i=t;eY(x|0)|0}x=dG(7938)|0;if((a[9375104]&1)!=0){y=c[u>>2]|0;bU(y|0,396216,(t=i,i=i+8|0,c[t>>2]=x,t)|0)|0;i=t;eY(y|0)|0}y=c[(c[q>>2]|0)+52>>2]|0;x=3248;s=465624;do{p=gj[y&4095](s)|0;o=c[x+4>>2]|0;C=p;a[o]=C&255;C=C>>8;a[o+1|0]=C&255;C=C>>8;a[o+2|0]=C&255;C=C>>8;a[o+3|0]=C&255;x=x+8|0;s=c[x>>2]|0;}while((s|0)!=0);eK(770,771);a[9533596]=0;s=j+2460|0;do{if((a[s]&1)==0){x=dG(7939)|0;if((x|0)==0){z=0;break}z=(e3(x|0,278384)|0)!=0}else{z=0}}while(0);if((a[9375104]&1)!=0){x=c[u>>2]|0;y=z?570200:553848;bU(x|0,586824,(t=i,i=i+16|0,c[t>>2]=278384,c[t+8>>2]=y,t)|0)|0;i=t;eY(x|0)|0}do{if(z){if((a[9375104]&1)==0){break}x=c[u>>2]|0;cj(270960,52,1,x|0)|0;eY(x|0)|0}else{a[9533596]=1;x=c[u>>2]|0;cj(263816,117,1,x|0)|0;eY(x|0)|0}}while(0);z=j+1984|0;a[z]=0;do{if((a[s]&1)==0){x=dG(7939)|0;if((x|0)==0){A=0;break}A=(e3(x|0,255400)|0)!=0}else{A=0}}while(0);if((a[9375104]&1)!=0){x=c[u>>2]|0;y=A?570200:553848;bU(x|0,586824,(t=i,i=i+16|0,c[t>>2]=255400,c[t+8>>2]=y,t)|0)|0;i=t;eY(x|0)|0}if(A){if((a[9375104]&1)!=0){A=c[u>>2]|0;cj(247336,101,1,A|0)|0;eY(A|0)|0}a[z]=1}a[j+8|0]=a[w]&1;a[j+1649|0]=a[v]&1;v=j+1664|0;w=j+1668|0;gg[c[(c[q>>2]|0)+20>>2]&4095](v,w);if((a[9375104]&1)!=0){z=c[u>>2]|0;A=c[v>>2]|0;x=c[w>>2]|0;bU(z|0,383840,(t=i,i=i+16|0,c[t>>2]=A,c[t+8>>2]=x,t)|0)|0;i=t;eY(z|0)|0}if((c[m>>2]|0)==0){if((c[n>>2]|0)!=0){r=8063}}else{r=8063}if((r|0)==8063){c[m>>2]=c[v>>2];c[n>>2]=c[w>>2]}n=j+1952|0;c[n>>2]=(a[9474114]&1)!=0?240:208;m=j+48|0;c[m>>2]=4;z=(c[2368524]|0)==2;x=j+1646|0;a[x]=z&1;if(z){c[m>>2]=1}z=j+1956|0;c[z>>2]=48936;c[2313836]=c[(c[q>>2]|0)+52>>2];A=c[2368529]|0;y=c[2368530]|0;a[9255352]=a[s]&1;c[2313834]=A;c[2313832]=y;if((a[9267696]&1)==0){B=0}else{B=(a[9263600]|0)!=0?9263600:0}y=jp(B,2)|0;do{if((y|0)==3){if((a[9375104]&1)==0){break}A=c[u>>2]|0;cj(315840,41,1,A|0)|0;eY(A|0)|0}else if((y|0)==2){if((a[9375104]&1)!=0){A=c[u>>2]|0;cj(307208,44,1,A|0)|0;eY(A|0)|0}A=j+4|0;c[A>>2]=49080;if(kT(B)|0){break}s=c[u>>2]|0;cj(285144,73,1,s|0)|0;eY(s|0)|0;if(gj[c[c[A>>2]>>2]&4095](0)|0){break}cj(374240,47,1,s|0)|0;eY(s|0)|0;gu[c[(c[q>>2]|0)+4>>2]&16383]();gGr(j);k=0;i=f;return k|0}else{s=c[u>>2]|0;cj(298992,89,1,s|0)|0;eY(s|0)|0}}while(0);B=j+4|0;y=c[B>>2]|0;if((y|0)!=0){s=(gD[c[y+40>>2]&8191]()|0)+1|0;y=c[m>>2]|0;c[m>>2]=s>>>0>y>>>0?s:y}y=a[9375104]|0;if((y&1)==0){D=y}else{y=c[u>>2]|0;s=c[m>>2]|0;bU(y|0,201304,(t=i,i=i+8|0,c[t>>2]=s,t)|0)|0;i=t;eY(y|0)|0;D=a[9375104]|0}if((D&1)!=0){D=c[u>>2]|0;y=c[B>>2]|0;if((y|0)==0){E=0}else{E=gD[c[y+16>>2]&8191]()|0}bU(D|0,364256,(t=i,i=i+8|0,c[t>>2]=E,t)|0)|0;i=t;eY(D|0)|0}D=c[b+12>>2]<<8;t=j+1768|0;c[t>>2]=D;E=j+1772|0;c[E>>2]=D;a[j+1650|0]=a[b+10|0]&1;D=c[B>>2]|0;if((D|0)!=0){gf[c[D+12>>2]&2047](0)}j5(j,c[v>>2]|0,c[w>>2]|0,1);D=c[B>>2]|0;if((D|0)!=0){gf[c[D+12>>2]&2047](1)}j5(j,c[v>>2]|0,c[w>>2]|0,1);a[h]=0;D=c[B>>2]|0;do{if((D|0)==0){r=8092}else{if(!(gA[c[D+20>>2]&16383](1,h)|0)){r=8092;break}c[j+468>>2]=(a[h]&1)!=0?9729:9728}}while(0);if((r|0)==8092){c[j+468>>2]=(a[b+11|0]&1)!=0?9729:9728}r=c[B>>2]|0;do{if((r|0)==0){F=33071}else{B=gj[c[r+24>>2]&4095](1)|0;if((B|0)==2){F=10497;break}else if((B|0)==3){F=33648;break}else if((B|0)==0|(B|0)==1){F=33071;break}else{F=0;break}}}while(0);c[j+1976>>2]=F;F=(a[b+16|0]&1)!=0;r=F?32993:6407;B=j+1964|0;c[B>>2]=r;h=j+1968|0;c[h>>2]=r;c[j+1972>>2]=F?5121:33635;c[j+1980>>2]=F?4:2;if(!((a[9533596]&1)==0|F^1)){c[B>>2]=6408;c[h>>2]=6408}b_(2929);b_(2884);b_(3024);h=j+1776|0;gGC(h|0,328,32)|0;c[j+1936>>2]=c[n>>2];c[j+1944>>2]=h;c[j+1940>>2]=c[z>>2];c[j+1948>>2]=328;z=ag(c[E>>2]|0,c[t>>2]|0)|0;h=z<<2;n=z>>>0>65535;if(n){G=(z&1073741823|0)==(z|0)?h:-1}else{G=h}B=gGq(G)|0;do{if((B|0)!=0){if((c[B-4>>2]&3|0)==0){break}gGz(B|0,0,G|0)}}while(0);c[j+472>>2]=B;if(n){H=(z&1073741823|0)==(z|0)?h:-1}else{H=h}h=gGq(H)|0;if((h|0)==0){c[j+476>>2]=0;gu[c[(c[q>>2]|0)+4>>2]&16383]();gGr(j);k=0;i=f;return k|0}if((c[h-4>>2]&3|0)!=0){gGz(h|0,0,H|0)}c[j+476>>2]=h;kx(j,b);do{if((c[m>>2]|0)!=0){b=j+1704|0;h=j+1736|0;H=0;do{c[b+(H<<2)>>2]=c[t>>2];c[h+(H<<2)>>2]=c[E>>2];H=H+1|0;I=c[m>>2]|0;}while(H>>>0<I>>>0);if((I|0)==0){break}H=j+12|0;h=j+52|0;b=0;do{c[h+(b*52|0)>>2]=c[H>>2];g[h+(b*52|0)+4>>2]=+((c[t>>2]|0)>>>0>>>0);g[h+(b*52|0)+12>>2]=+((c[t>>2]|0)>>>0>>>0);g[h+(b*52|0)+8>>2]=+((c[E>>2]|0)>>>0>>>0);g[h+(b*52|0)+16>>2]=+((c[E>>2]|0)>>>0>>>0);z=h+(b*52|0)+20|0;gGC(z|0,328,32)|0;b=b+1|0;}while(b>>>0<(c[m>>2]|0)>>>0)}}while(0);j3(j,c[t>>2]|0,c[E>>2]|0);do{if((a[x]&1)!=0){if(ky(l,c[t>>2]|0,c[E>>2]|0)|0){break}gu[c[(c[q>>2]|0)+4>>2]&16383]();gGr(j);k=0;i=f;return k|0}}while(0);if(!((d|0)==0|(e|0)==0)){gg[c[(c[q>>2]|0)+48>>2]&4095](d,e)}if((a[928e4]&1)!=0){e=kB(j,9275897,+g[2319999],c[v>>2]|0,c[w>>2]|0)|0;c[j+1992>>2]=e?49e3:0}switch(fF()|0){case 1280:{e=c[u>>2]|0;cj(356936,39,1,e|0)|0;eY(e|0)|0;break};case 1281:{e=c[u>>2]|0;cj(348920,40,1,e|0)|0;eY(e|0)|0;break};case 1282:{e=c[u>>2]|0;cj(341360,44,1,e|0)|0;eY(e|0)|0;break};case 1285:{e=c[u>>2]|0;cj(333376,40,1,e|0)|0;eY(e|0)|0;break};case 0:{k=j;i=f;return k|0};default:{e=c[u>>2]|0;cj(324520,45,1,e|0)|0;eY(e|0)|0}}gu[c[(c[q>>2]|0)+4>>2]&16383]();gGr(j);k=0;i=f;return k|0}function j7(b,d,e,f,h,j){b=b|0;d=d|0;e=e|0;f=f|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0.0,P=0.0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0.0,ab=0,ac=0.0,ad=0,ae=0.0,af=0.0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0;k=i;i=i+992|0;l=k|0;m=k+64|0;n=k+96|0;o=k+928|0;p=k+936|0;q=b+4|0;r=c[q>>2]|0;if((r|0)!=0){gf[c[r+12>>2]&2047](1)}r=b+1576|0;if((a[r]&1)!=0){j4(b,e,f,c[b+1696>>2]|0,c[b+1700>>2]|0);dD(3553,c[b+12+(c[b+44>>2]<<2)>>2]|0);d$(36160,c[b+612>>2]|0);s=c[b+740>>2]|0;t=c[b+744>>2]|0;v=c[(c[b>>2]|0)+24>>2]|0;if((v|0)!=0){+gt[v&3](s,t)}c[b+1676>>2]=0;c[b+1672>>2]=0;c[b+1680>>2]=s;c[b+1684>>2]=t;dm(0,0,s|0,t|0);t=b+1872|0;gGz(t|0,0,48);g[b+1932>>2]=1.0;g[t>>2]=2.0;g[b+1892>>2]=2.0;g[b+1912>>2]=-1.0;g[b+1920>>2]=-1.0;g[b+1924>>2]=-1.0;g[b+1928>>2]=-0.0;s=b+1808|0;gGC(s|0,t|0,64)|0;c[b+1936>>2]=240}t=b+1647|0;do{if((a[t]&1)!=0){a[t]=0;s=b;v=b+1664|0;w=b+1668|0;gg[c[(c[s>>2]|0)+36>>2]&4095](c[v>>2]|0,c[w>>2]|0);if((a[r]&1)==0){j5(b,c[v>>2]|0,c[w>>2]|0,1);break}w=b+1572|0;if((c[w>>2]|0)>0){v=b+740|0;x=v;y=b+612|0;z=y;A=b+676|0;B=c[u>>2]|0;C=0;while(1){D=c[x+(C*24|0)+8>>2]|0;E=x+(C*24|0)+16|0;F=c[x+(C*24|0)+12>>2]|0;G=x+(C*24|0)+20|0;if(D>>>0>(c[E>>2]|0)>>>0){H=8154}else{if(F>>>0>(c[G>>2]|0)>>>0){H=8154}}do{if((H|0)==8154){H=0;I=(D>>>0>F>>>0?D:F)-1|0;J=I>>>1|I;I=J>>>2|J;J=I>>>4|I;I=J>>>8|J;J=(I>>>16|I)+1|0;c[G>>2]=J;c[E>>2]=J;d$(36160,c[z+(C<<2)>>2]|0);J=A+(C<<2)|0;dD(3553,c[J>>2]|0);fP(3553,0,32993,c[E>>2]|0,c[G>>2]|0,0,32993,5121,0);bH(36160,36064,3553,c[J>>2]|0,0);if((fn(36160)|0)!=36053){cj(452264,50,1,B|0)|0;eY(B|0)|0}if((a[9375104]&1)==0){break}J=c[E>>2]|0;I=c[G>>2]|0;bU(B|0,441536,(K=i,i=i+24|0,c[K>>2]=C,c[K+8>>2]=J,c[K+16>>2]=I,K)|0)|0;i=K;eY(B|0)|0}}while(0);G=C+1|0;if((G|0)<(c[w>>2]|0)){C=G}else{L=y;M=v;break}}}else{L=b+612|0;M=b+740|0}dD(3553,c[b+12+(c[b+44>>2]<<2)>>2]|0);d$(36160,c[L>>2]|0);v=c[M>>2]|0;y=c[b+744>>2]|0;C=c[(c[s>>2]|0)+24>>2]|0;if((C|0)!=0){+gt[C&3](v,y)}c[b+1676>>2]=0;c[b+1672>>2]=0;c[b+1680>>2]=v;c[b+1684>>2]=y;dm(0,0,v|0,y|0);y=b+1872|0;gGz(y|0,0,48);g[b+1932>>2]=1.0;g[y>>2]=2.0;g[b+1892>>2]=2.0;g[b+1912>>2]=-1.0;g[b+1920>>2]=-1.0;g[b+1924>>2]=-1.0;g[b+1928>>2]=-0.0;v=b+1808|0;gGC(v|0,y|0,64)|0;c[b+1936>>2]=240}}while(0);M=b+44|0;L=c[M>>2]|0;L11420:do{if((d|0)==0){dD(3553,c[b+12+(L<<2)>>2]|0);N=b+1644|0}else{t=b+48|0;y=((L+1|0)>>>0)%((c[t>>2]|0)>>>0)|0;c[M>>2]=y;dD(3553,c[b+12+(y<<2)>>2]|0);y=b+1644|0;if((a[y]&1)!=0){N=y;break}v=c[M>>2]|0;C=b+1704|0;w=C+(v<<2)|0;if((c[w>>2]|0)==(e|0)){if((c[b+1736+(v<<2)>>2]|0)==(f|0)){H=8168}else{H=8166}}else{H=8166}do{if((H|0)==8166){B=b+472|0;if((c[B>>2]|0)==0){H=8168;break}c[w>>2]=e;c[b+1736+(c[M>>2]<<2)>>2]=f;f0(3317,(e<<2&4^4)+4|0);A=b+1768|0;z=b+1772|0;dX(3553,0,0,0,c[A>>2]|0,c[z>>2]|0,c[b+1968>>2]|0,c[b+1972>>2]|0,c[B>>2]|0);O=+(e>>>0>>>0)/+((c[A>>2]|0)>>>0>>>0);P=+(f>>>0>>>0)/+((c[z>>2]|0)>>>0>>>0);g[b+1784>>2]=O;g[b+1800>>2]=O;g[b+1796>>2]=P;g[b+1804>>2]=P}}while(0);do{if((H|0)==8168){w=c[t>>2]|0;s=((v-1+w|0)>>>0)%(w>>>0)|0;if((c[C+(s<<2)>>2]|0)==(e|0)){if((c[b+1736+(s<<2)>>2]|0)==(f|0)){break}}P=+(e>>>0>>>0)/+((c[b+1768>>2]|0)>>>0>>>0);O=+(f>>>0>>>0)/+((c[b+1772>>2]|0)>>>0>>>0);g[b+1784>>2]=P;g[b+1800>>2]=P;g[b+1796>>2]=O;g[b+1804>>2]=O}}while(0);if((a[b+2412|0]&1)!=0){c[o>>2]=0;C=gc[c[(c[b>>2]|0)+60>>2]&7](d,e,f,h,(c[b+1980>>2]|0)==4,c[M>>2]|0,o)|0;v=c[o>>2]|0;if((v|0)==0){t=c[u>>2]|0;cj(463440,55,1,t|0)|0;eY(t|0)|0;N=y;break}if(!C){N=y;break}gg[c[2383752]&4095](3553,v);N=y;break}v=b+1980|0;C=ag(c[v>>2]|0,e)|0;do{if((C&1|0)==0){if((C&2|0)!=0){Q=2;break}Q=(C&4^4)+4|0}else{Q=1}}while(0);f0(3317,Q|0);C=c[v>>2]|0;do{if((C|0)==4){if((a[9533596]&1)==0){break}t=b+476|0;s=c[t>>2]|0;w=b+480|0;z=w;A=w;w=b+484|0;if((c[A>>2]|0)==(e|0)){if((c[w>>2]|0)!=(f|0)){H=8183}}else{H=8183}if((H|0)==8183){c[A>>2]=e;c[w>>2]=f;c[b+492>>2]=e;c[b+496>>2]=f;c[b+504>>2]=0;c[b+508>>2]=1;c[b+512>>2]=1;i6(z)|0}c[b+488>>2]=h;c[b+500>>2]=e<<2;i7(z,s,d);dX(3553,0,0,0,e|0,f|0,c[b+1968>>2]|0,c[b+1972>>2]|0,c[t>>2]|0);N=y;break L11420}}while(0);v=(h>>>0)/(C>>>0)|0;if((a[b+1984|0]&1)!=0){f0(3314,v|0);dX(3553,0,0,0,e|0,f|0,c[b+1968>>2]|0,c[b+1972>>2]|0,d|0);f0(3314,0);N=y;break}if((v|0)==(e|0)){dX(3553,0,0,0,e|0,f|0,c[b+1968>>2]|0,c[b+1972>>2]|0,d|0);N=y;break}v=ag(C,e)|0;t=b+476|0;if((f|0)!=0){s=0;z=c[t>>2]|0;w=d;while(1){gGC(z|0,w|0,v)|0;A=s+1|0;if(A>>>0<f>>>0){s=A;z=z+v|0;w=w+h|0}else{break}}}dX(3553,0,0,0,e|0,f|0,c[b+1968>>2]|0,c[b+1972>>2]|0,c[t>>2]|0);N=y}}while(0);if((a[N]&1)!=0){h=c[M>>2]|0;d=b+1704|0;Q=d+(h<<2)|0;if((c[Q>>2]|0)==(e|0)){if((c[b+1736+(h<<2)>>2]|0)==(f|0)){H=8199}else{H=8197}}else{H=8197}do{if((H|0)==8197){if((c[b+472>>2]|0)==0){H=8199;break}c[Q>>2]=e;c[b+1736+(c[M>>2]<<2)>>2]=f;O=+(e>>>0>>>0)/+((c[b+1768>>2]|0)>>>0>>>0);P=+(f>>>0>>>0)/+((c[b+1772>>2]|0)>>>0>>>0);g[b+1784>>2]=O;g[b+1800>>2]=O;g[b+1796>>2]=P;g[b+1804>>2]=P}}while(0);do{if((H|0)==8199){Q=c[b+48>>2]|0;o=((h-1+Q|0)>>>0)%(Q>>>0)|0;if((c[d+(o<<2)>>2]|0)==(e|0)){if((c[b+1736+(o<<2)>>2]|0)==(f|0)){break}}P=+(e>>>0>>>0)/+((c[b+1768>>2]|0)>>>0>>>0);O=+(f>>>0>>>0)/+((c[b+1772>>2]|0)>>>0>>>0);g[b+1784>>2]=P;g[b+1800>>2]=P;g[b+1796>>2]=O;g[b+1804>>2]=O}}while(0);if((a[r]&1)==0){d$(36160,0);j5(b,c[b+1664>>2]|0,c[b+1668>>2]|0,1)}b_(2929);b_(2960);b_(2884);b_(3024);b_(3042);eK(770,771);eV(+0.0,+0.0,+0.0,+1.0)}d=p;gGz(d|0,0,52);c[p>>2]=c[b+12+(c[M>>2]<<2)>>2];g[p+4>>2]=+(e>>>0>>>0);g[p+8>>2]=+(f>>>0>>>0);M=b+1768|0;g[p+12>>2]=+((c[M>>2]|0)>>>0>>>0);h=b+1772|0;g[p+16>>2]=+((c[h>>2]|0)>>>0>>>0);H=p+20|0;o=b+1776|0;gGC(H|0,o|0,32)|0;bC(16384);if((a[9263570]&1)!=0){gu[c[(c[b>>2]|0)+44>>2]&16383]();bC(16384)}H=c[q>>2]|0;do{if((H|0)==0){Q=b+1936|0;L=b+1808|0;R=Q;S=Q;T=L;U=L}else{gk[c[H+8>>2]&15](e,f,c[M>>2]|0,c[h>>2]|0,c[b+1680>>2]|0,c[b+1684>>2]|0,c[2382972]|0,p,b+52|0,0,0);L=c[q>>2]|0;Q=b+1936|0;w=Q;v=b+1808|0;z=v;if((L|0)==0){R=Q;S=w;T=v;U=z;break}s=c[L+32>>2]|0;gj[s&4095](w)|0;s=c[q>>2]|0;if((s|0)==0){R=Q;S=w;T=v;U=z;break}L=c[s+36>>2]|0;gj[L&4095](z)|0;R=Q;S=w;T=v;U=z}}while(0);bz(5,0,4);if((a[r]&1)!=0){r=m;gGz(r|0,0,32);h=b+1944|0;c[h>>2]=m;M=b+1572|0;f=c[M>>2]|0;e=b+740|0;H=m+8|0;z=m+24|0;v=m+20|0;w=m+28|0;if(f>>>0>1){m=b+676|0;Q=b+612|0;L=b;s=b+1676|0;C=b+1672|0;A=b+1680|0;B=b+1684|0;x=b+1872|0;G=b+52|0;E=n|0;F=x;D=b+1892|0;K=b+1912|0;I=b+1932|0;J=b+1920|0;V=b+1924|0;W=b+1928|0;X=0;Y=1;while(1){Z=Y-1|0;_=e+(Z*24|0)|0;O=+((c[_>>2]|0)>>>0>>>0);$=e+(Z*24|0)+16|0;P=+((c[$>>2]|0)>>>0>>>0);aa=O/P;ab=e+(Z*24|0)+4|0;ac=+((c[ab>>2]|0)>>>0>>>0);ad=e+(Z*24|0)+20|0;ae=+((c[ad>>2]|0)>>>0>>>0);af=ac/ae;g[H>>2]=aa;g[z>>2]=aa;g[v>>2]=af;g[w>>2]=af;ah=m+(Z<<2)|0;c[n+(Z*52|0)>>2]=c[ah>>2];g[n+(Z*52|0)+4>>2]=O;g[n+(Z*52|0)+8>>2]=ac;g[n+(Z*52|0)+12>>2]=P;g[n+(Z*52|0)+16>>2]=ae;ai=n+(Z*52|0)+20|0;gGC(ai|0,r|0,32)|0;d$(36160,c[Q+(Y<<2)>>2]|0);ai=c[q>>2]|0;if((ai|0)!=0){gf[c[ai+12>>2]&2047](Y+1|0)}dD(3553,c[ah>>2]|0);bC(16384);ah=c[e+(Y*24|0)>>2]|0;ai=c[e+(Y*24|0)+4>>2]|0;Z=c[(c[L>>2]|0)+24>>2]|0;if((Z|0)!=0){+gt[Z&3](ah,ai)}c[s>>2]=0;c[C>>2]=0;c[A>>2]=ah;c[B>>2]=ai;dm(0,0,ah|0,ai|0);gGz(x|0,0,48);g[I>>2]=1.0;g[F>>2]=2.0;g[D>>2]=2.0;g[K>>2]=-1.0;g[J>>2]=-1.0;g[V>>2]=-1.0;g[W>>2]=-0.0;gGC(T|0,x|0,64)|0;ai=c[q>>2]|0;do{if((ai|0)!=0){gk[c[ai+8>>2]&15](c[_>>2]|0,c[ab>>2]|0,c[$>>2]|0,c[ad>>2]|0,c[A>>2]|0,c[B>>2]|0,c[2382972]|0,p,G,E,X);ah=c[q>>2]|0;if((ah|0)==0){break}Z=c[ah+32>>2]|0;gj[Z&4095](S)|0;Z=c[q>>2]|0;if((Z|0)==0){break}ah=c[Z+36>>2]|0;gj[ah&4095](U)|0}}while(0);bz(5,0,4);ad=X+1|0;$=Y+1|0;ab=c[M>>2]|0;if($>>>0<ab>>>0){X=ad;Y=$}else{aj=ad;ak=ab;break}}}else{aj=0;ak=f}f=ak-1|0;ak=e+(f*24|0)|0;Y=e+(f*24|0)+16|0;ae=+((c[ak>>2]|0)>>>0>>>0)/+((c[Y>>2]|0)>>>0>>>0);X=e+(f*24|0)+4|0;E=e+(f*24|0)+20|0;P=+((c[X>>2]|0)>>>0>>>0)/+((c[E>>2]|0)>>>0>>>0);g[H>>2]=ae;g[z>>2]=ae;g[v>>2]=P;g[w>>2]=P;d$(36160,0);w=c[q>>2]|0;if((w|0)!=0){gf[c[w+12>>2]&2047]((c[M>>2]|0)+1|0)}dD(3553,c[b+676+((c[M>>2]|0)-1<<2)>>2]|0);bC(16384);j5(b,c[b+1664>>2]|0,c[b+1668>>2]|0,1);M=c[q>>2]|0;do{if((M|0)==0){c[R>>2]=c[b+1952>>2]}else{gk[c[M+8>>2]&15](c[ak>>2]|0,c[X>>2]|0,c[Y>>2]|0,c[E>>2]|0,c[b+1680>>2]|0,c[b+1684>>2]|0,c[2382972]|0,p,b+52|0,n|0,aj);w=c[q>>2]|0;c[R>>2]=c[b+1952>>2];if((w|0)==0){break}v=c[w+32>>2]|0;gj[v&4095](S)|0;v=c[q>>2]|0;if((v|0)==0){break}w=c[v+36>>2]|0;gj[w&4095](U)|0}}while(0);bz(5,0,4);c[h>>2]=o}h=b+52|0;gGG(b+104|0,h|0,((c[b+48>>2]|0)*52|0)-52|0);gGC(h|0,d|0,52)|0;do{if((a[b+2452|0]&1)!=0){d=c[b+2448>>2]|0;if((d|0)==0){break}h=l|0;g[h>>2]=1.0;g[l+4>>2]=1.0;g[l+8>>2]=1.0;P=+g[b+2456>>2];g[l+12>>2]=P;g[l+16>>2]=1.0;g[l+20>>2]=1.0;g[l+24>>2]=1.0;g[l+28>>2]=P;g[l+32>>2]=1.0;g[l+36>>2]=1.0;g[l+40>>2]=1.0;g[l+44>>2]=P;g[l+48>>2]=1.0;g[l+52>>2]=1.0;g[l+56>>2]=1.0;g[l+60>>2]=P;U=R;c[U>>2]=208;aj=b+1944|0;c[aj>>2]=328;n=b+1940|0;c[n>>2]=h;dD(3553,d|0);d=c[q>>2]|0;do{if((d|0)!=0){gf[c[d+12>>2]&2047](15);h=c[q>>2]|0;p=b+1872|0;if((h|0)==0){break}E=c[h+32>>2]|0;gj[E&4095](S)|0;E=c[q>>2]|0;if((E|0)==0){break}h=c[E+36>>2]|0;gj[h&4095](p)|0}}while(0);b$(3042);if((a[b+2453|0]&1)==0){bz(5,0,4)}else{dm(0,0,c[b+1664>>2]|0,c[b+1668>>2]|0);bz(5,0,4);dm(c[b+1672>>2]|0,c[b+1676>>2]|0,c[b+1680>>2]|0,c[b+1684>>2]|0)}b_(3042);c[U>>2]=c[b+1952>>2];c[aj>>2]=o;c[n>>2]=c[b+1956>>2]}}while(0);do{if((j|0)!=0){d=c[b+1992>>2]|0;if((d|0)==0){break}gG[c[d+8>>2]&255](b,j,0)}}while(0);do{if((a[b+2444|0]&1)!=0){j=l;gGC(j|0,48936,64)|0;j=c[q>>2]|0;if((j|0)!=0){gf[c[j+12>>2]&2047](15)}b$(3042);j=b+2445|0;if((a[j]&1)!=0){dm(0,0,c[b+1664>>2]|0,c[b+1668>>2]|0)}d=b+2440|0;if((c[d>>2]|0)==0){al=R;am=b+1944|0;an=b+1940|0}else{p=b+2436|0;h=R;E=b+1944|0;Y=l|0;X=b+1940|0;ak=b+1872|0;M=l+12|0;w=l+28|0;v=l+44|0;z=l+60|0;H=0;while(1){dD(3553,c[(c[p>>2]|0)+(H*72|0)>>2]|0);f=c[p>>2]|0;e=f+(H*72|0)+68|0;g[M>>2]=+g[e>>2];g[w>>2]=+g[e>>2];g[v>>2]=+g[e>>2];g[z>>2]=+g[e>>2];c[h>>2]=f+(H*72|0)+36;c[E>>2]=f+(H*72|0)+4;c[X>>2]=Y;f=c[q>>2]|0;do{if((f|0)!=0){e=c[f+32>>2]|0;gj[e&4095](S)|0;e=c[q>>2]|0;if((e|0)==0){break}G=c[e+36>>2]|0;gj[G&4095](ak)|0}}while(0);bz(5,0,4);f=H+1|0;if(f>>>0<(c[d>>2]|0)>>>0){H=f}else{al=h;am=E;an=X;break}}}b_(3042);c[al>>2]=c[b+1952>>2];c[am>>2]=o;c[an>>2]=c[b+1956>>2];if((a[j]&1)==0){break}dm(c[b+1672>>2]|0,c[b+1676>>2]|0,c[b+1680>>2]|0,c[b+1684>>2]|0)}}while(0);an=b;gu[c[(c[an>>2]|0)+28>>2]&16383]();if((a[N]&1)==0){ao=c[an>>2]|0;ap=ao+44|0;aq=c[ap>>2]|0;gu[aq&16383]();ar=c[2382972]|0;as=ar+1|0;c[2382972]=as;i=k;return 1}N=c[q>>2]|0;if((N|0)!=0){gf[c[N+12>>2]&2047](0)}dD(3553,0);ao=c[an>>2]|0;ap=ao+44|0;aq=c[ap>>2]|0;gu[aq&16383]();ar=c[2382972]|0;as=ar+1|0;c[2382972]=as;i=k;return 1}function j8(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;if((a[9375104]&1)!=0){f=c[u>>2]|0;g=d?396464:512504;bU(f|0,499272,(h=i,i=i+8|0,c[h>>2]=g,h)|0)|0;i=h;eY(f|0)|0}gf[c[(c[b>>2]|0)+12>>2]&2047](d?0:c[2315893]|0);i=e;return}function j9(b){b=b|0;var d=0,e=0,f=0;d=i;i=i+16|0;e=d|0;f=d+8|0;a[e]=0;a[f]=0;ge[c[(c[b>>2]|0)+32>>2]&63](e,f,b+1664|0,b+1668|0,c[2382972]|0);do{if((a[e]&1)==0){if((a[f]&1)==0){break}a[b+1647|0]=1}else{a[b+1648|0]=1}}while(0);i=d;return(a[b+1648|0]&1)==0|0}function ka(a){a=a|0;return gD[c[(c[a>>2]|0)+40>>2]&8191]()|0}function kb(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,v=0;f=i;i=i+8|0;h=f|0;j=b;if((d|0)==3){k=0;i=f;return k|0}l=b+4|0;m=c[l>>2]|0;if((m|0)!=0){gu[c[m+4>>2]&16383]()}m=(d|0)==2;c[l>>2]=m?49080:0;if(!m){m=c[u>>2]|0;bU(m|0,335904,(n=i,i=i+8|0,c[n>>2]=e,n)|0)|0;i=n;eY(m|0)|0;k=0;i=f;return k|0}m=b+1576|0;if((a[m]&1)!=0){d=b+1572|0;dK(c[d>>2]|0,b+676|0);o=b+612|0;by(c[d>>2]|0,o|0);a[m]=0;c[d>>2]=0;gGz(o|0,0,128)}o=b+44|0;d=b+12|0;dD(3553,c[d+(c[o>>2]<<2)>>2]|0);if(!(gj[c[c[l>>2]>>2]&4095](e)|0)){e=c[u>>2]|0;cj(258288,81,1,e|0)|0;eY(e|0)|0;if(gj[c[c[l>>2]>>2]&4095](0)|0){k=0;i=f;return k|0}c[l>>2]=0;k=0;i=f;return k|0}a[h]=0;e=c[l>>2]|0;if((e|0)==0){p=8287}else{if(!(gA[c[e+20>>2]&16383](1,h)|0)){p=8287}}if((p|0)==8287){a[h]=a[9263580]&1}e=c[l>>2]|0;do{if((e|0)==0){q=33071}else{m=gj[c[e+24>>2]&4095](1)|0;if((m|0)==2){q=10497;break}else if((m|0)==3){q=33648;break}else if((m|0)==0|(m|0)==1){q=33071;break}else{q=0;break}}}while(0);e=a[h]&1;a[b+2427|0]=e;h=e<<24>>24!=0?9729:9728;e=b+468|0;m=b+1976|0;if((h|0)==(c[e>>2]|0)){if((q|0)!=(c[m>>2]|0)){p=8295}}else{p=8295}if((p|0)==8295){c[e>>2]=h;c[m>>2]=q;q=b+48|0;h=c[q>>2]|0;if((h|0)!=0){p=0;r=h;while(1){h=c[j+12+(p<<2)>>2]|0;if((h|0)==0){s=r}else{dD(3553,h|0);ds(3553,10242,c[m>>2]|0);ds(3553,10243,c[m>>2]|0);ds(3553,10240,c[e>>2]|0);ds(3553,10241,c[e>>2]|0);s=c[q>>2]|0}h=p+1|0;if(h>>>0<s>>>0){p=h;r=s}else{break}}}dD(3553,c[j+12+(c[o>>2]<<2)>>2]|0)}s=c[l>>2]|0;do{if((s|0)!=0){r=(gD[c[s+40>>2]&8191]()|0)+1|0;p=b+48|0;q=c[p>>2]|0;if(r>>>0<=q>>>0){break}e=b+1644|0;if((a[e]&1)!=0){by(q|0,b+1580|0)}if((a[b+1645|0]&1)!=0){cw(c[p>>2]|0,b+1612|0)}a[e]=0;e=d;dK(c[p>>2]|0,e|0);c[p>>2]=r;if((a[9375104]&1)!=0){q=c[u>>2]|0;bU(q|0,201304,(n=i,i=i+8|0,c[n>>2]=r,n)|0)|0;i=n;eY(q|0)|0}c[o>>2]=0;kx(b,b+2416|0);do{if((c[p>>2]|0)!=0){q=b+1768|0;r=b+1704|0;m=b+1772|0;h=b+1736|0;t=0;do{c[r+(t<<2)>>2]=c[q>>2];c[h+(t<<2)>>2]=c[m>>2];t=t+1|0;v=c[p>>2]|0;}while(t>>>0<v>>>0);if((v|0)==0){break}t=b+52|0;h=0;do{c[t+(h*52|0)>>2]=c[e>>2];g[t+(h*52|0)+4>>2]=+((c[q>>2]|0)>>>0>>>0);g[t+(h*52|0)+12>>2]=+((c[q>>2]|0)>>>0>>>0);g[t+(h*52|0)+8>>2]=+((c[m>>2]|0)>>>0>>>0);g[t+(h*52|0)+16>>2]=+((c[m>>2]|0)>>>0>>>0);r=t+(h*52|0)+20|0;gGC(r|0,328,32)|0;h=h+1|0;}while(h>>>0<(c[p>>2]|0)>>>0)}}while(0);if((a[b+1646|0]&1)==0){break}p=c[b+1768>>2]|0;e=c[b+1772>>2]|0;ky(j,p,e)|0}}while(0);j3(b,c[b+1768>>2]|0,c[b+1772>>2]|0);j=c[l>>2]|0;if((j|0)!=0){gf[c[j+12>>2]&2047](0)}j=b+1664|0;v=b+1668|0;j5(b,c[j>>2]|0,c[v>>2]|0,1);o=c[l>>2]|0;if((o|0)!=0){gf[c[o+12>>2]&2047](1)}j5(b,c[j>>2]|0,c[v>>2]|0,1);k=1;i=f;return k|0}function kc(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=c[b+1992>>2]|0;if((d|0)!=0){gf[c[d+4>>2]&2047](b)}d=b+4|0;e=c[d>>2]|0;if((e|0)!=0){gu[c[e+4>>2]&16383]()}c[d>>2]=0;d=b+48|0;dK(c[d>>2]|0,b+12|0);e=b+2448|0;if((c[e>>2]|0)!=0){dK(1,e|0)}e=b+2440|0;f=c[e>>2]|0;g=b+2436|0;h=c[g>>2]|0;if((f|0)==0){i=h}else{j=0;k=h;h=f;while(1){f=k+(j*72|0)|0;if((c[f>>2]|0)==0){l=h;m=k}else{dK(1,f|0);l=c[e>>2]|0;m=c[g>>2]|0}f=j+1|0;if(f>>>0<l>>>0){j=f;k=m;h=l}else{i=m;break}}}gGr(i);c[g>>2]=0;c[e>>2]=0;e=b+544|0;gGr(c[e>>2]|0);gGr(c[b+556>>2]|0);gGr(c[b+560>>2]|0);gGr(c[b+572>>2]|0);gGr(c[b+584>>2]|0);gGr(c[b+576>>2]|0);gGr(c[b+600>>2]|0);gGz(e|0,0,64);e=b+1576|0;if((a[e]&1)!=0){g=b+1572|0;dK(c[g>>2]|0,b+676|0);i=b+612|0;by(c[g>>2]|0,i|0);a[e]=0;c[g>>2]=0;gGz(i|0,0,128)}i=b+1644|0;if((a[i]&1)!=0){by(c[d>>2]|0,b+1580|0)}if((a[b+1645|0]&1)==0){a[i]=0;n=b;o=c[n>>2]|0;p=o+4|0;q=c[p>>2]|0;gu[q&16383]();r=b+472|0;s=r;t=c[s>>2]|0;gGr(t);u=b+476|0;v=u;w=c[v>>2]|0;gGr(w);gGr(b);return}cw(c[d>>2]|0,b+1612|0);a[i]=0;n=b;o=c[n>>2]|0;p=o+4|0;q=c[p>>2]|0;gu[q&16383]();r=b+472|0;s=r;t=c[s>>2]|0;gGr(t);u=b+476|0;v=u;w=c[v>>2]|0;gGr(w);gGr(b);return}function kd(){var a=0;a=c[2383358]|0;if((a|0)==0){return}c[2383358]=0;kc(a);hT();return}function ke(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,h=0.0,j=0.0,k=0.0;d=i;i=i+64|0;e=d|0;f=b*90|0;c[a+1652>>2]=f;b=a+1872|0;gGz(b|0,0,48);g[a+1932>>2]=1.0;g[b>>2]=2.0;g[a+1892>>2]=2.0;g[a+1912>>2]=-1.0;g[a+1920>>2]=-1.0;g[a+1924>>2]=-1.0;g[a+1928>>2]=-0.0;h=+(f>>>0>>>0)*3.141592653589793/180.0;j=+Y(+h);k=+Z(+h);gGz(e|0,0,60);g[e+40>>2]=1.0;g[e+60>>2]=1.0;g[e>>2]=j;g[e+20>>2]=j;g[e+16>>2]=-0.0-k;g[e+4>>2]=k;kz(a+1808|0,e,b);i=d;return}function kf(a,b){a=a|0;b=b|0;var d=0,e=0;d=a+1672|0;e=b;c[e>>2]=c[d>>2];c[e+4>>2]=c[d+4>>2];c[e+8>>2]=c[d+8>>2];c[e+12>>2]=c[d+12>>2];c[e+16>>2]=c[d+16>>2];c[e+20>>2]=c[d+20>>2];c[b+16>>2]=c[a+1664>>2];d=a+1668|0;c[b+20>>2]=c[d>>2];a=b+4|0;c[a>>2]=(c[d>>2]|0)-((c[b+12>>2]|0)+(c[a>>2]|0));return}function kg(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0;if((a[b+1644|0]&1)==0){if((a[b+1576|0]&1)!=0){e=8355}}else{e=8355}if((e|0)==8355){d$(36160,0)}e=b+1672|0;f=b+1680|0;g=(c[f>>2]|0)*3|0;do{if((g&1|0)==0){if((g&2|0)!=0){h=2;break}h=(g&4^4)+4|0}else{h=1}}while(0);f0(3333,h|0);h=b+1684|0;et(c[e>>2]|0,c[b+1676>>2]|0,c[f>>2]|0,c[h>>2]|0,6407,5121,d|0);b=ag(c[h>>2]|0,c[f>>2]|0)|0;f=d;d=0;while(1){h=f+2|0;e=a[h]|0;a[h]=a[f]|0;a[f]=e;e=d+1|0;if(e>>>0>b>>>0){break}else{f=f+3|0;d=e}}return 1}function kh(a,b){a=a|0;b=b|0;c[b>>2]=49056;return}function ki(a,b){a=a|0;b=b|0;c[b>>2]=49016;return}function kj(a){a=a|0;return c[a+1580+(((((c[a+44>>2]|0)+1|0)>>>0)%((c[a+48>>2]|0)>>>0)|0)<<2)>>2]|0}function kk(a,b){a=a|0;b=b|0;return gj[c[(c[a>>2]|0)+52>>2]&4095](b)|0}function kl(b,d){b=b|0;d=d|0;var e=0,f=0.0,h=0.0,j=0.0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=i;L11703:do{if((d|0)==6){f=+((c[2367346]|0)>>>0>>>0);if(f<=0.0){break}h=+((c[2367347]|0)>>>0>>>0);if(h<=0.0){break}j=+g[2367350];if(j>0.0){g[16216]=j;break}else{g[16216]=f/h;break}}else if((d|0)==5){k=c[2367346]|0;l=c[2367347]|0;if((k|0)==0|(l|0)==0){break}m=k>>>0<l>>>0?k:l;if(m>>>0>1){n=1;o=1;while(1){if(((k>>>0)%(n>>>0)|0|0)==0){p=((l>>>0)%(n>>>0)|0|0)==0?n:o}else{p=o}q=n+1|0;if(q>>>0<m>>>0){n=q;o=p}else{r=p;break}}}else{r=1}o=(k>>>0)/(r>>>0)|0;n=(l>>>0)/(r>>>0)|0;be(64732,64,280952,(m=i,i=i+16|0,c[m>>2]=o,c[m+8>>2]=n,m)|0)|0;i=m;g[16199]=+(o>>>0>>>0)/+(n>>>0>>>0)}else if((d|0)==4){h=+g[2315896];if(h>=0.0){g[16182]=h;break}h=+g[2367350];do{if(h>0.0){if((a[9263588]&1)==0){break}g[16182]=h;break L11703}}while(0);g[16182]=+((c[2367346]|0)>>>0>>>0)/+((c[2367347]|0)>>>0>>>0)}}while(0);g[2367356]=+g[64456+(d*68|0)>>2];a[b+1650|0]=1;a[b+1647|0]=1;i=e;return}function km(b){b=b|0;a[b+1647|0]=1;return}function kn(b,d,e,f,h,i){b=b|0;d=d|0;e=e|0;f=f|0;h=h|0;i=+i;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;j=b+2448|0;k=c[j>>2]|0;if((k|0)==0){cp(1,j|0);dD(3553,c[j>>2]|0);ds(3553,10242,33071);ds(3553,10243,33071);ds(3553,10240,9729);ds(3553,10241,9729)}else{dD(3553,k|0)}g[b+2456>>2]=i;k=ag(e?4:2,f)|0;if((k&2|0)==0){l=(k&4^4)+4|0}else{l=2}f0(3317,l|0);if(e){e=(a[9533596]&1)!=0?6408:32993;fP(3553,0,e|0,f|0,h|0,0,e|0,5121,d|0);m=b+44|0;n=m;o=c[n>>2]|0;p=b+12|0;q=p;r=q+(o<<2)|0;s=c[r>>2]|0;dD(3553,s|0);return}else{fP(3553,0,6408,f|0,h|0,0,6408,32819,d|0);m=b+44|0;n=m;o=c[n>>2]|0;p=b+12|0;q=p;r=q+(o<<2)|0;s=c[r>>2]|0;dD(3553,s|0);return}}function ko(b,c,d){b=b|0;c=c|0;d=d|0;a[b+2452|0]=c&1;a[b+2453|0]=d&1;return}function kp(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;e=c[a+1992>>2]|0;if((e|0)==0){return}gG[c[e+8>>2]&255](a,b,d);return}function kq(a,b){a=a|0;b=b|0;var d=0;d=c[(c[a>>2]|0)+64>>2]|0;if((d|0)==0){return}gf[d&2047](b);return}function kr(b,d){b=b|0;d=d|0;var e=0;a[b+2444|0]=d&1;e=c[(c[b>>2]|0)+64>>2]|0;if((e|0)==0){return}if((a[b+1649|0]&1)==0){return}gf[e&2047](d);return}function ks(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=b+2440|0;h=c[f>>2]|0;i=b+2436|0;b=c[i>>2]|0;if((h|0)==0){j=b}else{k=0;l=b;b=h;while(1){h=l+(k*72|0)|0;if((c[h>>2]|0)==0){m=b;n=l}else{dK(1,h|0);m=c[f>>2]|0;n=c[i>>2]|0}h=k+1|0;if(h>>>0<m>>>0){k=h;l=n;b=m}else{j=n;break}}}gGr(j);c[f>>2]=0;j=(e|0)==0;do{if(j){o=0}else{n=e*72|0;if(e>>>0<=65535){o=n;break}o=((n>>>0)/(e>>>0)|0|0)==72?n:-1}}while(0);n=gGq(o)|0;if((n|0)==0){c[i>>2]=0;p=0;return p|0}if((c[n-4>>2]&3|0)!=0){gGz(n|0,0,o|0)}o=n;c[i>>2]=o;c[f>>2]=e;if(j){p=1;return p|0}else{q=0;r=o}while(1){o=r+(q*72|0)|0;cp(1,o|0);dD(3553,c[o>>2]|0);ds(3553,10242,33071);ds(3553,10243,33071);ds(3553,10240,9729);ds(3553,10241,9729);o=d+(q*12|0)+4|0;f0(3317,(c[o>>2]<<2&4^4)+4|0);j=(a[9533596]&1)!=0?6408:32993;fP(3553,0,j|0,c[o>>2]|0,c[d+(q*12|0)+8>>2]|0,0,j|0,5121,c[d+(q*12|0)>>2]|0);j=c[i>>2]|0;g[j+(q*72|0)+4>>2]=0.0;g[j+(q*72|0)+8>>2]=0.0;g[j+(q*72|0)+12>>2]=1.0;g[j+(q*72|0)+16>>2]=0.0;g[j+(q*72|0)+20>>2]=0.0;g[j+(q*72|0)+24>>2]=1.0;g[j+(q*72|0)+28>>2]=1.0;g[j+(q*72|0)+32>>2]=1.0;j=c[i>>2]|0;g[j+(q*72|0)+36>>2]=0.0;g[j+(q*72|0)+40>>2]=1.0;g[j+(q*72|0)+44>>2]=1.0;g[j+(q*72|0)+48>>2]=1.0;g[j+(q*72|0)+52>>2]=0.0;g[j+(q*72|0)+56>>2]=0.0;g[j+(q*72|0)+60>>2]=1.0;g[j+(q*72|0)+64>>2]=0.0;g[(c[i>>2]|0)+(q*72|0)+68>>2]=1.0;j=q+1|0;if(j>>>0>=e>>>0){p=1;break}q=j;r=c[i>>2]|0}return p|0}function kt(a,b,d,e,f,h){a=a|0;b=b|0;d=+d;e=+e;f=+f;h=+h;var i=0,j=0.0;i=c[a+2436>>2]|0;g[i+(b*72|0)+4>>2]=d;g[i+(b*72|0)+8>>2]=e;j=d+f;g[i+(b*72|0)+12>>2]=j;g[i+(b*72|0)+16>>2]=e;g[i+(b*72|0)+20>>2]=d;d=e+h;g[i+(b*72|0)+24>>2]=d;g[i+(b*72|0)+28>>2]=j;g[i+(b*72|0)+32>>2]=d;return}function ku(a,b,d,e,f,h){a=a|0;b=b|0;d=+d;e=+e;f=+f;h=+h;var i=0,j=0.0;i=c[a+2436>>2]|0;j=1.0-e;g[i+(b*72|0)+36>>2]=d;g[i+(b*72|0)+40>>2]=j;e=d+f;g[i+(b*72|0)+44>>2]=e;g[i+(b*72|0)+48>>2]=j;g[i+(b*72|0)+52>>2]=d;d=j-h;g[i+(b*72|0)+56>>2]=d;g[i+(b*72|0)+60>>2]=e;g[i+(b*72|0)+64>>2]=d;return}function kv(b,c){b=b|0;c=c|0;a[b+2445|0]=c&1;return}function kw(a,b,d){a=a|0;b=b|0;d=+d;g[(c[a+2436>>2]|0)+(b*72|0)+68>>2]=d;return}function kx(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,v=0,w=0,x=0,y=0;e=i;f=b+1646|0;g=a[f]|0;if((g&1)==0&(c[2383752]|0)!=0){h=(gj[c[(c[b>>2]|0)+56>>2]&4095](d)|0)&1;j=h;k=a[f]|0}else{j=0;k=g}g=b+2412|0;a[g]=j;j=c[b+1964>>2]|0;f=c[b+1968>>2]|0;h=c[b+1972>>2]|0;do{if((k&1)==0){l=h;m=f;n=j}else{if((c[b+1980>>2]|0)!=4){l=h;m=f;n=j;break}d=b+2460|0;do{if((a[d]&1)==0){o=dG(7939)|0;if((o|0)==0){p=0;break}p=(e3(o|0,539168)|0)!=0}else{p=0}}while(0);if((a[9375104]&1)!=0){o=c[u>>2]|0;q=p?570200:553848;bU(o|0,586824,(r=i,i=i+16|0,c[r>>2]=539168,c[r+8>>2]=q,r)|0)|0;i=r;eY(o|0)|0}if(p){l=5121;m=6408;n=6408;break}do{if((a[d]&1)==0){o=dG(7939)|0;if((o|0)==0){s=0;break}s=(e3(o|0,525720)|0)!=0}else{s=0}}while(0);if((a[9375104]&1)!=0){d=c[u>>2]|0;o=s?570200:553848;bU(d|0,586824,(r=i,i=i+16|0,c[r>>2]=525720,c[r+8>>2]=o,r)|0)|0;i=r;eY(d|0)|0}if(s){l=5121;m=6408;n=6408;break}d=c[u>>2]|0;cj(512096,76,1,d|0)|0;eY(d|0)|0;l=33635;m=6407;n=6407}}while(0);s=b+48|0;r=b+12|0;p=r;cp(c[s>>2]|0,r|0);if((c[s>>2]|0)==0){t=b+44|0;v=t;w=c[v>>2]|0;x=p+(w<<2)|0;y=c[x>>2]|0;dD(3553,y|0);i=e;return}r=b+1976|0;j=b+468|0;f=b+1768|0;h=b+1772|0;k=b+472|0;d=0;do{dD(3553,c[p+(d<<2)>>2]|0);ds(3553,10242,c[r>>2]|0);ds(3553,10243,c[r>>2]|0);ds(3553,10240,c[j>>2]|0);ds(3553,10241,c[j>>2]|0);if((a[g]&1)==0){fP(3553,0,n|0,c[f>>2]|0,c[h>>2]|0,0,m|0,l|0,c[k>>2]|0)}d=d+1|0;}while(d>>>0<(c[s>>2]|0)>>>0);t=b+44|0;v=t;w=c[v>>2]|0;x=p+(w<<2)|0;y=c[x>>2]|0;dD(3553,y|0);i=e;return}function ky(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+16|0;g=f|0;h=f+8|0;if((a[9375104]&1)!=0){j=c[u>>2]|0;bU(j|0,158584,(k=i,i=i+16|0,c[k>>2]=d,c[k+8>>2]=e,k)|0)|0;i=k;eY(j|0)|0}c[g>>2]=0;c[h>>2]=0;fK(3379,g|0);fK(34024,h|0);if((a[9375104]&1)!=0){j=c[u>>2]|0;l=c[g>>2]|0;g=c[h>>2]|0;bU(j|0,128288,(k=i,i=i+16|0,c[k>>2]=l,c[k+8>>2]=g,k)|0)|0;i=k;eY(j|0)|0}dD(3553,0);j=b+48|0;bN(c[j>>2]|0,b+1580|0);g=(a[9474112]&1)==0;l=(a[9474113]&1)!=0;do{if(l){do{if((a[b+2460|0]&1)==0){h=dG(7939)|0;if((h|0)==0){m=0;break}m=(e3(h|0,103568)|0)!=0}else{m=0}}while(0);if((a[9375104]&1)!=0){h=c[u>>2]|0;n=m?570200:553848;bU(h|0,586824,(k=i,i=i+16|0,c[k>>2]=103568,c[k+8>>2]=n,k)|0)|0;i=k;eY(h|0)|0}if(m){break}else{o=0}i=f;return o|0}}while(0);L11841:do{if(g){if(l){m=0;while(1){if(m>>>0>=(c[j>>2]|0)>>>0){p=8485;break L11841}d$(36160,c[b+1580+(m<<2)>>2]|0);bH(36160,36064,3553,c[b+12+(m<<2)>>2]|0,0);h=fn(36160)|0;if((h|0)==36053){m=m+1|0}else{q=m;r=h;p=8484;break}}}else{m=0;while(1){if(m>>>0>=(c[j>>2]|0)>>>0){p=8485;break L11841}d$(36160,c[b+1580+(m<<2)>>2]|0);bH(36160,36064,3553,c[b+12+(m<<2)>>2]|0,0);h=fn(36160)|0;if((h|0)==36053){m=m+1|0}else{q=m;r=h;p=8484;break}}}}else{bb(c[j>>2]|0,b+1612|0);a[b+1645|0]=1;if(l){m=0;while(1){if(m>>>0>=(c[j>>2]|0)>>>0){p=8485;break L11841}d$(36160,c[b+1580+(m<<2)>>2]|0);bH(36160,36064,3553,c[b+12+(m<<2)>>2]|0,0);h=b+1612+(m<<2)|0;ei(36161,c[h>>2]|0);bk(36161,35056,d|0,e|0);ei(36161,0);a0(36160,36096,36161,c[h>>2]|0);a0(36160,36128,36161,c[h>>2]|0);h=fn(36160)|0;if((h|0)==36053){m=m+1|0}else{q=m;r=h;p=8484;break}}}else{m=0;while(1){if(m>>>0>=(c[j>>2]|0)>>>0){p=8485;break L11841}d$(36160,c[b+1580+(m<<2)>>2]|0);bH(36160,36064,3553,c[b+12+(m<<2)>>2]|0,0);h=b+1612+(m<<2)|0;ei(36161,c[h>>2]|0);bk(36161,33189,d|0,e|0);ei(36161,0);a0(36160,36096,36161,c[h>>2]|0);h=fn(36160)|0;if((h|0)==36053){m=m+1|0}else{q=m;r=h;p=8484;break}}}}}while(0);if((p|0)==8485){d$(36160,0);a[b+1644|0]=1;o=1;i=f;return o|0}else if((p|0)==8484){p=c[u>>2]|0;bU(p|0,80176,(k=i,i=i+16|0,c[k>>2]=q,c[k+8>>2]=r,k)|0)|0;i=k;eY(p|0)|0;o=0;i=f;return o|0}return 0}function kz(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0.0,h=0.0,j=0.0,k=0.0,l=0.0,m=0.0,n=0.0,o=0.0,p=0.0,q=0.0,r=0.0,s=0.0,t=0.0,u=0.0,v=0.0,w=0.0,x=0.0,y=0,z=0.0,A=0,B=0.0,C=0,D=0.0;d=i;i=i+64|0;e=d|0;f=+g[c>>2];h=+g[c+4>>2];j=+g[c+8>>2];k=+g[c+12>>2];l=+g[c+16>>2];m=+g[c+20>>2];n=+g[c+24>>2];o=+g[c+28>>2];p=+g[c+32>>2];q=+g[c+36>>2];r=+g[c+40>>2];s=+g[c+44>>2];t=+g[c+48>>2];u=+g[c+52>>2];v=+g[c+56>>2];w=+g[c+60>>2];c=0;do{x=+g[b+(c<<2)>>2];y=c+4|0;z=+g[b+(y<<2)>>2];A=c+8|0;B=+g[b+(A<<2)>>2];C=c+12|0;D=+g[b+(C<<2)>>2];g[e+(c<<2)>>2]=x*f+0.0+z*h+B*j+D*k;g[e+(y<<2)>>2]=x*l+0.0+z*m+B*n+D*o;g[e+(A<<2)>>2]=x*p+0.0+z*q+B*r+D*s;g[e+(C<<2)>>2]=x*t+0.0+z*u+B*v+D*w;c=c+1|0;}while(c>>>0<4);c=a;a=e;gGC(c|0,a|0,64)|0;i=d;return}function kA(a){a=a|0;var b=0;b=c[a+1988>>2]|0;if((b|0)==0){return}gf[c[(c[a+1996>>2]|0)+12>>2]&2047](b);dK(1,a+2e3|0);b=c[a+2016>>2]|0;if((b|0)==0){return}gGr(b);return}function kB(b,d,e,f,h){b=b|0;d=d|0;e=+e;f=f|0;h=h|0;var j=0,k=0,l=0,m=0,n=0.0,o=0.0,p=0.0,q=0.0,r=0.0,s=0.0,t=0.0,v=0.0,w=0.0,x=0.0,y=0.0;h=i;if((a[928e4]&1)==0){j=0;i=h;return j|0}f=b+1996|0;d=b+1988|0;k=c[u>>2]|0;l=js((a[9275897]|0)!=0?9275897:9534384,+g[2319999])|0;c[d>>2]=l;if((l|0)==0){bU(k|0,564040,(m=i,i=i+8|0,c[m>>2]=517872,m)|0)|0;i=m;eY(k|0)|0;c[f>>2]=0;c[d>>2]=0;cj(558984,49,1,k|0)|0;eY(k|0)|0;j=0;i=h;return j|0}if((a[9375104]&1)!=0){bU(k|0,518072,(m=i,i=i+8|0,c[m>>2]=517872,m)|0)|0;i=m;eY(k|0)|0}c[f>>2]=62144;f=b+2e3|0;cp(1,f|0);dD(3553,c[f>>2]|0);ds(3553,10242,33071);ds(3553,10243,33071);ds(3553,10240,9729);ds(3553,10241,9729);dD(3553,c[b+12+(c[b+44>>2]<<2)>>2]|0);fK(3379,b+2004|0);e=+g[2320003];g[b+2284>>2]=e;n=+g[2320004];g[b+2288>>2]=n;o=+g[2320005];g[b+2292>>2]=o;g[b+2296>>2]=1.0;p=+g[2320003];g[b+2300>>2]=p;q=+g[2320004];g[b+2304>>2]=q;r=+g[2320005];g[b+2308>>2]=r;g[b+2312>>2]=1.0;s=+g[2320003];g[b+2316>>2]=s;t=+g[2320004];g[b+2320>>2]=t;v=+g[2320005];g[b+2324>>2]=v;g[b+2328>>2]=1.0;w=+g[2320003];g[b+2332>>2]=w;x=+g[2320004];g[b+2336>>2]=x;y=+g[2320005];g[b+2340>>2]=y;g[b+2344>>2]=1.0;g[b+2348>>2]=e*.3;g[b+2352>>2]=n*.3;g[b+2356>>2]=o*.3;g[b+2360>>2]=1.0;g[b+2364>>2]=p*.3;g[b+2368>>2]=q*.3;g[b+2372>>2]=r*.3;g[b+2376>>2]=1.0;g[b+2380>>2]=s*.3;g[b+2384>>2]=t*.3;g[b+2388>>2]=v*.3;g[b+2392>>2]=1.0;g[b+2396>>2]=w*.3;g[b+2400>>2]=x*.3;g[b+2404>>2]=y*.3;g[b+2408>>2]=1.0;j=1;i=h;return j|0}function kC(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,h=0,j=0,k=0,l=0,m=0,n=0.0,o=0.0,p=0.0,q=0.0,r=0.0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0.0,ae=0.0,af=0.0,ah=0.0;f=i;i=i+168|0;h=f|0;j=f+64|0;k=f+96|0;l=f+128|0;m=f+160|0;do{if((e|0)==0){n=+g[2320001];o=+g[2320002];if((a[9280001]&1)==0){p=n;q=o;r=1.0;break}p=n;q=o;r=+((c[b+1680>>2]|0)>>>0>>>0)/+((c[b+1656>>2]|0)>>>0>>>0)}else{p=+g[e>>2];q=+g[e+4>>2];r=+g[e+8>>2]}}while(0);e=b+1988|0;if((c[e>>2]|0)==0){i=f;return}s=b+4|0;t=c[s>>2]|0;if((t|0)!=0){gf[c[t+12>>2]&2047](15)}j5(b,c[b+1664>>2]|0,c[b+1668>>2]|0,0);b$(3042);dD(3553,c[b+2e3>>2]|0);t=l|0;u=b+1936|0;v=u;w=b+1944|0;c[w>>2]=t;x=b+2020|0;if((fa(x|0,d|0)|0)==0){y=c[b+2276>>2]|0;z=c[b+2280>>2]|0;A=b+2008|0;B=b+2012|0}else{C=b+1996|0;gG[c[(c[C>>2]|0)+4>>2]&255](c[e>>2]|0,d,m);D=c[m>>2]|0;E=c[D+24>>2]|0;F=(c[D+4>>2]|0)+E|0;G=c[D+28>>2]|0;H=(c[D+8>>2]|0)+G|0;I=c[D+48>>2]|0;if((I|0)==0){J=H;K=G;L=F;M=E}else{N=H;H=G;G=F;F=E;E=I;while(1){I=c[E+24>>2]|0;O=(c[E+4>>2]|0)+I|0;P=c[E+28>>2]|0;Q=(c[E+8>>2]|0)+P|0;R=(I|0)<(F|0)?I:F;I=(O|0)>(G|0)?O:G;O=(P|0)<(H|0)?P:H;P=(Q|0)>(N|0)?Q:N;Q=c[E+48>>2]|0;if((Q|0)==0){J=P;K=O;L=I;M=R;break}else{N=P;H=O;G=I;F=R;E=Q}}}E=L-M|0;L=J-K|0;J=E-1|0;F=J>>>1|J;J=F>>>2|F;F=J>>>4|J;J=F>>>8|F;F=(J>>>16|J)+1|0;J=L-1|0;G=J>>>1|J;J=G>>>2|G;G=J>>>4|J;J=G>>>8|G;G=(J>>>16|J)+1|0;J=c[b+2004>>2]|0;H=(F|0)>(J|0)?J:F;F=(G|0)>(J|0)?J:G;G=b+2008|0;J=c[G>>2]|0;N=b+2012|0;do{if((H|0)>(J|0)){S=8524}else{Q=c[N>>2]|0;if((F|0)>(Q|0)){S=8524;break}T=J;U=Q;V=b+2016|0}}while(0);if((S|0)==8524){J=b+2016|0;Q=c[J>>2]|0;c[J>>2]=gGs(Q,ag(H<<2,F)|0)|0;fP(3553,0,6408,H|0,F|0,0,6408,5121,0);c[G>>2]=H;c[N>>2]=F;T=H;U=F;V=J}J=c[V>>2]|0;gGz(J|0,0,ag(U<<2,T)|0);if((D|0)!=0){T=D;do{D=c[V>>2]|0;U=c[G>>2]|0;J=c[N>>2]|0;F=(c[T+24>>2]|0)-M|0;H=c[T+8>>2]|0;Q=J-H+(K-(c[T+28>>2]|0))|0;R=Q-1|0;I=c[T>>2]|0;O=(F|0)<0;P=(c[T+4>>2]|0)+(O?F:0)|0;W=(R|0)<0;X=(W?R:0)+H|0;if(O){_=I+(-F|0)|0;$=0}else{_=I;$=F}if(W){aa=_+(ag(c[T+12>>2]|0,1-Q|0)|0)|0;ab=0}else{aa=_;ab=R}R=($+P|0)>(U|0)?U-$|0:P;P=(ab+X|0)>(J|0)?J-ab|0:X;do{if((P|0)>0){X=T+12|0;if((R|0)<=0){break}J=0;Q=aa;W=D+((ag(ab,U)|0)+$<<2)|0;while(1){F=0;I=W;while(1){a[I]=-1;a[I+1|0]=-1;a[I+2|0]=-1;a[I+3|0]=a[Q+F|0]|0;O=F+1|0;if((O|0)<(R|0)){F=O;I=I+4|0}else{break}}I=J+1|0;if((I|0)<(P|0)){J=I;Q=Q+(c[X>>2]|0)|0;W=W+(U<<2)|0}else{break}}}}while(0);T=c[T+48>>2]|0;}while((T|0)!=0)}f0(3317,8);dX(3553,0,0,0,c[G>>2]|0,c[N>>2]|0,6408,5121,c[V>>2]|0);gg[c[(c[C>>2]|0)+8>>2]&4095](c[e>>2]|0,m);m=256;e=x;x=d;while(1){d=m-1|0;if((d|0)==0){S=8540;break}C=a[x]|0;a[e]=C;if(C<<24>>24==0){break}else{m=d;e=e+1|0;x=x+1|0}}do{if((S|0)==8540){a[e]=0;if((a[x]|0)==0){break}else{ac=x}do{ac=ac+1|0;}while((a[ac]|0)!=0)}}while(0);c[b+2276>>2]=E;c[b+2280>>2]=L;y=E;z=L;A=G;B=N}N=j|0;G=k|0;o=+(y|0);n=+((c[b+1680>>2]|0)>>>0>>>0);ad=p+r*o/n;ae=+(z|0);af=+((c[b+1684>>2]|0)>>>0>>>0);ah=q+r*ae/af;g[N>>2]=p;g[j+8>>2]=ad;g[j+16>>2]=p;g[j+24>>2]=ad;g[j+4>>2]=ah;g[j+12>>2]=ah;g[j+20>>2]=q;g[j+28>>2]=q;r=2.0/n;n=2.0/af;af=p-r;g[G>>2]=af;p=ah-n;g[k+4>>2]=p;ah=ad-r;g[k+8>>2]=ah;g[k+12>>2]=p;g[k+16>>2]=af;af=q-n;g[k+20>>2]=af;g[k+24>>2]=ah;g[k+28>>2]=af;af=o/+(c[A>>2]|0);o=1.0-ae/+(c[B>>2]|0);g[t>>2]=0.0;g[l+8>>2]=af;g[l+16>>2]=0.0;g[l+24>>2]=af;g[l+4>>2]=o;g[l+12>>2]=o;g[l+20>>2]=1.0;g[l+28>>2]=1.0;l=u;c[l>>2]=G;G=b+1940|0;c[G>>2]=b+2348;u=b+1808|0;t=c[s>>2]|0;do{if((t|0)!=0){B=c[t+32>>2]|0;gj[B&4095](v)|0;B=c[s>>2]|0;if((B|0)==0){break}A=c[B+36>>2]|0;gj[A&4095](u)|0}}while(0);bz(5,0,4);c[l>>2]=N;c[G>>2]=b+2284;N=c[s>>2]|0;do{if((N|0)!=0){t=c[N+32>>2]|0;gj[t&4095](v)|0;t=c[s>>2]|0;if((t|0)==0){break}A=c[t+36>>2]|0;gj[A&4095](u)|0}}while(0);bz(5,0,4);c[l>>2]=c[b+1952>>2];c[w>>2]=b+1776;c[G>>2]=c[b+1956>>2];dD(3553,c[b+12+(c[b+44>>2]<<2)>>2]|0);b_(3042);G=b+1872|0;gGz(G|0,0,48);g[b+1932>>2]=1.0;g[G>>2]=2.0;g[b+1892>>2]=2.0;g[b+1912>>2]=-1.0;g[b+1920>>2]=-1.0;g[b+1924>>2]=-1.0;g[b+1928>>2]=-0.0;o=+((c[b+1652>>2]|0)>>>0>>>0)*3.141592653589793/180.0;af=+Y(+o);ae=+Z(+o);gGz(h|0,0,60);g[h+40>>2]=1.0;g[h+60>>2]=1.0;g[h>>2]=af;g[h+20>>2]=af;g[h+16>>2]=-0.0-ae;g[h+4>>2]=ae;kz(u,h,G);i=f;return}function kD(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;b=i;i=i+24|0;d=b|0;e=b+8|0;f=b+16|0;if((a[9375104]&1)!=0){g=c[u>>2]|0;cj(558792,45,1,g|0)|0;eY(g|0)|0}if(a[49272]|0){if((a[9375104]&1)==0){h=1;i=b;return h|0}g=c[u>>2]|0;cj(432928,64,1,g|0)|0;eY(g|0)|0;h=1;i=b;return h|0}g=dv(0)|0;c[2383330]=g;do{if((g|0)!=0){do{if((fp(g|0,0,0)|0)!=0){if((bt(c[2383330]|0,49152,9533336,1,f|0)|0)==0){break}j=e$(c[2383330]|0,c[2383334]|0,0,49136)|0;c[2383332]=j;if((j|0)==0){break}j=bJ(c[2383330]|0,c[2383334]|0,0,0)|0;c[2383328]=j;if((j|0)==0){break}if((fR(c[2383330]|0,j|0,j|0,c[2383332]|0)|0)==0){break}j=c[2383330]|0;k=c[2383328]|0;bu(j|0,k|0,12375,d|0)|0;k=c[2383330]|0;j=c[2383328]|0;bu(k|0,j|0,12374,e|0)|0;j=c[d>>2]|0;c[2343772]=j;k=c[e>>2]|0;c[2343774]=k;if((a[9375104]&1)==0){h=1;i=b;return h|0}l=c[u>>2]|0;bU(l|0,335464,(m=i,i=i+16|0,c[m>>2]=j,c[m+8>>2]=k,m)|0)|0;i=m;eY(l|0)|0;h=1;i=b;return h|0}}while(0);l=c[2383330]|0;if((l|0)==0){break}fR(l|0,0,0,0)|0;l=c[2383332]|0;if((l|0)!=0){m=c[2383330]|0;fy(m|0,l|0)|0}l=c[2383328]|0;if((l|0)!=0){m=c[2383330]|0;b1(m|0,l|0)|0}l=c[2383330]|0;dA(l|0)|0}}while(0);c[2383332]=0;c[2383328]=0;c[2383330]=0;c[2383334]=0;a[49272]=0;h=0;i=b;return h|0}function kE(){var b=0,d=0;b=c[2383330]|0;if((b|0)!=0){fR(b|0,0,0,0)|0;b=c[2383332]|0;if((b|0)!=0){d=c[2383330]|0;fy(d|0,b|0)|0}b=c[2383328]|0;if((b|0)!=0){d=c[2383330]|0;b1(d|0,b|0)|0}b=c[2383330]|0;dA(b|0)|0}c[2383332]=0;c[2383328]=0;c[2383330]=0;c[2383334]=0;a[49272]=0;return}function kF(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if((a|0)==1){d=(cl(12448)|0)!=0}else{d=0}return d|0}function kG(a){a=a|0;return}function kH(b,c,d){b=b|0;c=c|0;d=d|0;var e=0;if(a[49272]|0){e=0}else{a[49272]=1;e=1}return e|0}function kI(a,b){a=a|0;b=b|0;c[a>>2]=c[2343772];c[b>>2]=c[2343774];return}function kJ(a,b){a=a|0;b=b|0;return+(+(a>>>0>>>0)/+(b>>>0>>>0))}function kK(){var b=0,d=0,e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0.0,u=0.0,v=0,w=0;b=i;i=i+264|0;d=b|0;e=(a[9374058]&1)!=0;f=b+8|0;j=b+136|0;k=e?j:0;a[f]=0;if((cu(1,d|0)|0)<0){l=0;m=0}else{n=c[d>>2]|0;o=gGU(n,(n|0)<0|0?-1:0,1e6,0)|0;n=((c[d+4>>2]|0)+500|0)/1e3|0;d=gGK(n,(n|0)<0|0?-1:0,o,K)|0;l=K;m=d}do{if((c[2382972]|0)==0){c[2315868]=m;c[2315869]=l;c[2315866]=m;c[2315867]=l;d=128;o=f;n=9531892;while(1){p=d-1|0;if((p|0)==0){q=8605;break}r=a[n]|0;a[o]=r;if(r<<24>>24==0){break}else{d=p;o=o+1|0;n=n+1|0}}do{if((q|0)==8605){a[o]=0;if((a[n]|0)==0){break}else{s=n}do{s=s+1|0;}while((a[s]|0)!=0)}}while(0);if((k|0)==0){break}a[k]=78;a[k+1|0]=47;a[k+2|0]=65;a[k+3|0]=0}else{n=9523432;o=c[n>>2]|0;d=gGK(o,c[n+4>>2]|0,1,0)|0;n=9523432;c[n>>2]=d;c[n+4>>2]=K;n=gGL(m,l,c[2315868]|0,c[2315869]|0)|0;d=9507048+((o&2047)<<3)|0;c[d>>2]=n;c[d+4>>2]=K;c[2315868]=m;c[2315869]=l;d=c[2382972]|0;if((d&255|0)==0){n=gGL(m,l,c[2315866]|0,c[2315867]|0)|0;t=256.0e6/(+(n>>>0)+ +(K|0)*4294967296.0);g[12282]=t;c[2315866]=m;c[2315867]=l;u=t;be(f|0,128,88928,(v=i,i=i+24|0,c[v>>2]=9531892,h[v+8>>3]=u,c[v+16>>2]=d,v)|0)|0;i=v}if((k|0)==0){break}d=c[2382972]|0;be(k|0,128,467888,(v=i,i=i+16|0,h[v>>3]=+g[12282],c[v+8>>2]=d,v)|0)|0;i=v}}while(0);if(!e){i=b;return}e=c[2380901]|0;v=e+4|0;if((c[v>>2]|0)>>>0>=(c[e+8>>2]|0)>>>0){i=b;return}k=gGq(12)|0;do{if((k|0)!=0){if((c[k-4>>2]&3|0)==0){break}gGz(k|0,0,12)}}while(0);c[k+4>>2]=1;c[k>>2]=1;f=bG(j|0)|0;j=c[v>>2]|0;c[k+8>>2]=f;f=e|0;c[(c[f>>2]|0)+(j<<2)>>2]=k;k=c[v>>2]|0;c[v>>2]=k+1;if(k>>>0>1){w=k}else{i=b;return}while(1){k=w>>>1;v=c[f>>2]|0;j=v+(k<<2)|0;e=c[j>>2]|0;l=c[v+(w<<2)>>2]|0;if((c[l+4>>2]|0)>>>0<=(c[e+4>>2]|0)>>>0){q=8618;break}c[j>>2]=l;c[(c[f>>2]|0)+(w<<2)>>2]=e;if(w>>>0>3){w=k}else{q=8621;break}}if((q|0)==8621){i=b;return}else if((q|0)==8618){i=b;return}}function kL(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0;g=i;i=i+24|0;h=g|0;j=g+8|0;d9(h|0,j|0,g+16|0);k=c[h>>2]|0;c[e>>2]=k;h=c[j>>2]|0;c[f>>2]=h;a[d]=(c[e>>2]|0)==(c[2343772]|0)&(h|0)==(c[2343774]|0)&1^1;c[2343772]=k;c[2343774]=h;a[b]=0;i=g;return}function kM(a,b){a=a|0;b=b|0;return}function kN(){return a[49272]|0}function kO(){return}function kP(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;c[a>>2]=0;d=gGq(48)|0;if((d|0)==0){return}if((c[d-4>>2]&3|0)!=0){gGz(d|0,0,48)}e=e1()|0;c[d+44>>2]=e;if((e|0)==0){gGr(d);return}gGz(845e4,0,1292);e=6720;f=276;while(1){c[845e4+(f<<2)>>2]=c[e>>2];g=c[e+12>>2]|0;if((g|0)==0){break}else{e=e+8|0;f=g}}c[a>>2]=46096;c[b>>2]=d;return}function kQ(a){a=a|0;return d3(a|0)|0}function kR(a){a=a|0;return 0}function kS(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;return 0}function kT(d){d=d|0;var e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0,cf=0,cg=0,ci=0,ck=0,cl=0,cm=0,cn=0,co=0,cq=0,cr=0,cs=0,ct=0,cu=0,cv=0,cw=0,cx=0,cy=0,cz=0,cA=0,cB=0,cC=0,cD=0,cF=0,cG=0,cH=0,cI=0,cJ=0,cK=0,cL=0,cM=0,cN=0,cO=0,cP=0,cQ=0,cR=0,cS=0,cT=0,cU=0,cV=0,cW=0,cX=0,cY=0.0,cZ=0.0,c_=0,c$=0,c0=0,c1=0,c2=0,c3=0,c4=0,c5=0,c6=0,c7=0,c8=0,c9=0,da=0,db=0,dc=0,dd=0,de=0,df=0,dg=0,dh=0;e=i;i=i+848|0;f=e|0;j=e+64|0;k=e+128|0;l=e+192|0;m=e+256|0;n=e+320|0;o=e+384|0;p=e+448|0;q=e+512|0;r=e+576|0;s=e+640|0;t=e+704|0;v=e+768|0;w=e+832|0;x=gGq(109464)|0;if((x|0)==0){c[2313830]=0;y=0;i=e;return y|0}if((c[x-4>>2]&3|0)!=0){gGz(x|0,0,109464)}z=x;c[2313830]=z;L12072:do{if((d|0)==0){A=c[u>>2]|0;cj(335384,59,1,A|0)|0;eY(A|0)|0;c[(c[2313830]|0)+72>>2]=1;A=bG(((a[9255352]&1)!=0?193896:199184)|0)|0;c[(c[2313830]|0)+4172>>2]=A;A=bG(((a[9255352]&1)!=0?205696:210624)|0)|0;B=c[2313830]|0;c[B+4176>>2]=A;a[B+4|0]=1}else{B=cE(d|0,47)|0;A=cE(((B|0)==0?d:B+1|0)|0,46)|0;B=(A|0)==0?9534384:A+1|0;if((fa(B|0,471856)|0)==0){A=4096;C=x+76|0;D=d;while(1){E=A-1|0;if((E|0)==0){F=8651;break}G=a[D]|0;a[C]=G;if(G<<24>>24==0){break}else{A=E;C=C+1|0;D=D+1|0}}do{if((F|0)==8651){a[C]=0;if((a[D]|0)==0){break}else{H=D}do{H=H+1|0;}while((a[H]|0)!=0)}}while(0);c[x+72>>2]=1;a[x+4|0]=1;break}do{if((fa(B|0,558744)|0)==0){D=hZ(d,0)|0;if((D|0)==0){break}C=jn(D,c[2313830]|0)|0;a[(c[2313830]|0)+4|0]=1;hY(D);if(C){break L12072}}else{C=v|0;if((a[9375104]&1)!=0){D=c[u>>2]|0;bU(D|0,262544,(I=i,i=i+8|0,c[I>>2]=d,I)|0)|0;i=I;eY(D|0)|0}D=iP(d)|0;A=(D|0)!=0;L12092:do{if(A){E=D|0;G=c[E>>2]|0;if((G|0)==0){break}else{J=G}L12095:while(1){do{if((c[J+20>>2]|0)==0){if((fa(c[J>>2]|0,160336)|0)!=0){break}K=J+8|0;G=K;while(1){L=c[G>>2]|0;if((L|0)==0){F=8672;break}if((fa(129720,c[L>>2]|0)|0)==0){F=8667;break}else{G=L+8|0}}L12103:do{if((F|0)==8667){F=0;G=c[L+4>>2]|0;if((G|0)==0){F=8672;break}else{M=64;N=C;O=G}while(1){G=M-1|0;if((G|0)==0){break}P=a[O]|0;a[N]=P;if(P<<24>>24==0){break L12103}else{M=G;N=N+1|0;O=O+1|0}}a[N]=0;if((a[O]|0)==0){break}else{Q=O}do{Q=Q+1|0;}while((a[Q]|0)!=0)}}while(0);if((F|0)==8672){F=0;a[C]=0}if((fa(C|0,105144)|0)==0){break L12095}}}while(0);G=c[J+16>>2]|0;if((G|0)==0){break L12092}else{J=G}}c[x>>2]=2;G=K;while(1){R=c[G>>2]|0;if((R|0)==0){F=8682;break}if((fa(81104,c[R>>2]|0)|0)==0){F=8677;break}else{G=R+8|0}}L12119:do{if((F|0)==8677){G=c[R+4>>2]|0;if((G|0)==0){F=8682;break}else{S=64;T=C;U=G}while(1){G=S-1|0;if((G|0)==0){break}P=a[U]|0;a[T]=P;if(P<<24>>24==0){break L12119}else{S=G;T=T+1|0;U=U+1|0}}a[T]=0;if((a[U]|0)==0){break}else{V=U}do{V=V+1|0;}while((a[V]|0)!=0)}}while(0);if((F|0)==8682){a[C]=0}G=x+4|0;a[G]=(fa(C|0,587680)|0)==0|0;P=x+5|0;W=K;while(1){X=c[W>>2]|0;if((X|0)==0){F=8687;break}if((fa(571656,c[X>>2]|0)|0)==0){F=8686;break}else{W=X+8|0}}do{if((F|0)==8686){W=c[X+4>>2]|0;if((W|0)==0){F=8687;break}else{Y=64;Z=0;_=P;$=W}while(1){W=Y-1|0;if((W|0)==0){F=8690;break}aa=a[$]|0;a[_]=aa;if(aa<<24>>24==0){ab=Z;break}else{Y=W;Z=Z+1|0;_=_+1|0;$=$+1|0}}do{if((F|0)==8690){a[_]=0;if((a[$]|0)==0){ab=Z;break}else{ac=$;ad=Z}while(1){W=ac+1|0;aa=ad+1|0;if((a[W]|0)==0){ab=aa;break}else{ac=W;ad=aa}}}}while(0);if(ab>>>0>=64){break}if((a[9375104]&1)==0){break}aa=c[u>>2]|0;bU(aa|0,554648,(I=i,i=i+8|0,c[I>>2]=P,I)|0)|0;i=I;eY(aa|0)|0}}while(0);if((F|0)==8687){a[P]=0}do{if((a[G]&1)==0){aa=c[u>>2]|0;cj(526648,57,1,aa|0)|0;eY(aa|0)|0}else{if((a[9375104]&1)==0){break}aa=c[u>>2]|0;cj(539928,54,1,aa|0)|0;eY(aa|0)|0}}while(0);P=c[J+12>>2]|0;aa=x+72|0;L12153:do{if((P|0)==0){F=9020}else{W=f|0;ae=j|0;af=k|0;ag=l|0;ah=m|0;ai=n|0;aj=o|0;ak=p|0;al=q|0;am=r|0;an=s|0;ao=t|0;ap=c[u>>2]|0;aq=x+66380|0;ar=x+99728|0;as=x+108948|0;at=x+108952|0;au=P;L12155:while(1){if((c[aa>>2]|0)>>>0>=16){break L12153}do{if((c[au+20>>2]|0)==0){av=au+4|0;aw=c[av>>2]|0;if((aw|0)==0){break}ax=bG(aw|0)|0;if((ax|0)==0){break}aw=c[aa>>2]|0;ay=c[au>>2]|0;if((fa(ay|0,512696)|0)==0){az=z+76+(aw*4144|0)+4096|0;if((c[az>>2]|0)!=0){F=8708;break L12155}aA=jo(ax,d,au)|0;if((aA|0)==0){F=8710;break L12155}c[az>>2]=aA;break}if((fa(ay|0,463880)|0)!=0){if((fa(ay|0,430128)|0)==0){gGr(ax);aA=c[aq>>2]|0;if(aA>>>0>7){cj(92912,58,1,ap|0)|0;eY(ap|0)|0;break}az=z+66384+(aA*4168|0)|0;aB=au+8|0;aC=aB;while(1){aD=c[aC>>2]|0;if((aD|0)==0){F=8877;break}if((fa(117888,c[aD>>2]|0)|0)==0){F=8872;break}else{aC=aD+8|0}}L12177:do{if((F|0)==8872){F=0;aC=c[aD+4>>2]|0;if((aC|0)==0){F=8877;break}else{aE=64;aF=az;aG=aC}while(1){aC=aE-1|0;if((aC|0)==0){break}aH=a[aG]|0;a[aF]=aH;if(aH<<24>>24==0){break L12177}else{aE=aC;aF=aF+1|0;aG=aG+1|0}}a[aF]=0;if((a[aG]|0)==0){break}else{aI=aG}do{aI=aI+1|0;}while((a[aI]|0)!=0)}}while(0);if((F|0)==8877){F=0;a[az]=0}aC=z+66384+(aA*4168|0)+64|0;aH=aB;while(1){aJ=c[aH>>2]|0;if((aJ|0)==0){F=8886;break}if((fa(90024,c[aJ>>2]|0)|0)==0){F=8881;break}else{aH=aJ+8|0}}L12191:do{if((F|0)==8881){F=0;aH=c[aJ+4>>2]|0;if((aH|0)==0){F=8886;break}else{aK=4096;aL=aC;aM=aH}while(1){aH=aK-1|0;if((aH|0)==0){break}aN=a[aM]|0;a[aL]=aN;if(aN<<24>>24==0){break L12191}else{aK=aH;aL=aL+1|0;aM=aM+1|0}}a[aL]=0;if((a[aM]|0)==0){break}else{aO=aM}do{aO=aO+1|0;}while((a[aO]|0)!=0)}}while(0);if((F|0)==8886){F=0;a[aC]=0}gGz(W|0,0,64);aH=aB;while(1){aP=c[aH>>2]|0;if((aP|0)==0){F=8895;break}if((fa(88376,c[aP>>2]|0)|0)==0){F=8890;break}else{aH=aP+8|0}}L12205:do{if((F|0)==8890){F=0;aH=c[aP+4>>2]|0;if((aH|0)==0){F=8895;break}else{aQ=64;aR=W;aS=aH}while(1){aH=aQ-1|0;if((aH|0)==0){break}aB=a[aS]|0;a[aR]=aB;if(aB<<24>>24==0){break L12205}else{aQ=aH;aR=aR+1|0;aS=aS+1|0}}a[aR]=0;if((a[aS]|0)==0){break}else{aT=aS}do{aT=aT+1|0;}while((a[aT]|0)!=0)}}while(0);if((F|0)==8895){F=0;a[W]=0}if((a[az]|0)==0){F=8897;break L12155}if((a[aC]|0)==0){F=8899;break L12155}do{if((fa(W|0,82912)|0)==0){c[z+66384+(aA*4168|0)+4160>>2]=1}else{if((fa(W|0,81592)|0)==0){c[z+66384+(aA*4168|0)+4160>>2]=2;break}if((a[W]|0)!=0){F=8906;break L12155}c[z+66384+(aA*4168|0)+4160>>2]=0}}while(0);c[aq>>2]=(c[aq>>2]|0)+1;break}if((fa(ay|0,407088)|0)!=0){if((fa(ay|0,384152)|0)!=0){break}gGr(ax);if((c[as>>2]|0)!=0){F=8993;break L12155}aA=au+8|0;aC=aA;while(1){aU=c[aC>>2]|0;if((aU|0)==0){F=9002;break}if((fa(131080,c[aU>>2]|0)|0)==0){F=8997;break}else{aC=aU+8|0}}L12234:do{if((F|0)==8997){F=0;aC=c[aU+4>>2]|0;if((aC|0)==0){F=9002;break}else{aV=512;aW=at;aX=aC}while(1){aC=aV-1|0;if((aC|0)==0){break}ay=a[aX]|0;a[aW]=ay;if(ay<<24>>24==0){aY=aA;break L12234}else{aV=aC;aW=aW+1|0;aX=aX+1|0}}a[aW]=0;if((a[aX]|0)==0){aY=aA;break}else{aZ=aX}while(1){aC=aZ+1|0;if((a[aC]|0)==0){aY=aA;break}else{aZ=aC}}}}while(0);if((F|0)==9002){F=0;a[at]=0;aY=aA}while(1){a_=c[aY>>2]|0;if((a_|0)==0){F=9010;break}if((fa(129720,c[a_>>2]|0)|0)==0){F=9005;break}else{aY=a_+8|0}}L12247:do{if((F|0)==9005){F=0;aA=c[a_+4>>2]|0;if((aA|0)==0){F=9010;break}else{a$=64;a0=W;a1=aA}while(1){aA=a$-1|0;if((aA|0)==0){break}aC=a[a1]|0;a[a0]=aC;if(aC<<24>>24==0){break L12247}else{a$=aA;a0=a0+1|0;a1=a1+1|0}}a[a0]=0;if((a[a1]|0)==0){break}else{a2=a1}do{a2=a2+1|0;}while((a[a2]|0)!=0)}}while(0);if((F|0)==9010){F=0;a[W]=0}if((fa(W|0,182664)|0)!=0){F=9012;break L12155}aA=c[av>>2]|0;if((aA|0)==0){F=9014;break L12155}aC=bG(aA|0)|0;c[as>>2]=aC;if((aC|0)==0){F=9018;break L12155}aA=jo(aC,d,au)|0;c[as>>2]=aA;if((aA|0)==0){F=9017;break L12155}else{break}}gGr(ax);aA=c[ar>>2]|0;if(aA>>>0>63){F=8911;break L12155}aC=z+99732+(aA*80|0)|0;ay=au+8|0;az=ay;while(1){a3=c[az>>2]|0;if((a3|0)==0){F=8920;break}if((fa(117888,c[a3>>2]|0)|0)==0){F=8915;break}else{az=a3+8|0}}L12266:do{if((F|0)==8915){F=0;az=c[a3+4>>2]|0;if((az|0)==0){F=8920;break}else{a4=64;a5=aC;a6=az}while(1){az=a4-1|0;if((az|0)==0){break}av=a[a6]|0;a[a5]=av;if(av<<24>>24==0){a7=ay;break L12266}else{a4=az;a5=a5+1|0;a6=a6+1|0}}a[a5]=0;if((a[a6]|0)==0){a7=ay;break}else{a8=a6}while(1){az=a8+1|0;if((a[az]|0)==0){a7=ay;break}else{a8=az}}}}while(0);if((F|0)==8920){F=0;a[aC]=0;a7=ay}while(1){a9=c[a7>>2]|0;if((a9|0)==0){F=8928;break}if((fa(115032,c[a9>>2]|0)|0)==0){F=8923;break}else{a7=a9+8|0}}L12279:do{if((F|0)==8923){F=0;az=c[a9+4>>2]|0;if((az|0)==0){F=8928;break}else{ba=64;bb=W;bc=az}while(1){az=ba-1|0;if((az|0)==0){break}av=a[bc]|0;a[bb]=av;if(av<<24>>24==0){bd=ay;break L12279}else{ba=az;bb=bb+1|0;bc=bc+1|0}}a[bb]=0;if((a[bc]|0)==0){bd=ay;break}else{be=bc}while(1){az=be+1|0;if((a[az]|0)==0){bd=ay;break}else{be=az}}}}while(0);if((F|0)==8928){F=0;a[W]=0;bd=ay}while(1){bf=c[bd>>2]|0;if((bf|0)==0){F=8936;break}if((fa(113248,c[bf>>2]|0)|0)==0){F=8931;break}else{bd=bf+8|0}}L12292:do{if((F|0)==8931){F=0;az=c[bf+4>>2]|0;if((az|0)==0){F=8936;break}else{bg=64;bh=ae;bi=az}while(1){az=bg-1|0;if((az|0)==0){break}av=a[bi]|0;a[bh]=av;if(av<<24>>24==0){bj=ay;break L12292}else{bg=az;bh=bh+1|0;bi=bi+1|0}}a[bh]=0;if((a[bi]|0)==0){bj=ay;break}else{bk=bi}while(1){az=bk+1|0;if((a[az]|0)==0){bj=ay;break}else{bk=az}}}}while(0);if((F|0)==8936){F=0;a[ae]=0;bj=ay}while(1){bl=c[bj>>2]|0;if((bl|0)==0){F=8944;break}if((fa(111312,c[bl>>2]|0)|0)==0){F=8939;break}else{bj=bl+8|0}}L12305:do{if((F|0)==8939){F=0;az=c[bl+4>>2]|0;if((az|0)==0){F=8944;break}else{bm=64;bn=af;bo=az}while(1){az=bm-1|0;if((az|0)==0){break}av=a[bo]|0;a[bn]=av;if(av<<24>>24==0){bp=ay;break L12305}else{bm=az;bn=bn+1|0;bo=bo+1|0}}a[bn]=0;if((a[bo]|0)==0){bp=ay;break}else{bq=bo}while(1){az=bq+1|0;if((a[az]|0)==0){bp=ay;break}else{bq=az}}}}while(0);if((F|0)==8944){F=0;a[af]=0;bp=ay}while(1){br=c[bp>>2]|0;if((br|0)==0){F=8952;break}if((fa(109712,c[br>>2]|0)|0)==0){F=8947;break}else{bp=br+8|0}}L12318:do{if((F|0)==8947){F=0;az=c[br+4>>2]|0;if((az|0)==0){F=8952;break}else{bs=64;bt=ag;bu=az}while(1){az=bs-1|0;if((az|0)==0){break}av=a[bu]|0;a[bt]=av;if(av<<24>>24==0){bv=ay;break L12318}else{bs=az;bt=bt+1|0;bu=bu+1|0}}a[bt]=0;if((a[bu]|0)==0){bv=ay;break}else{bw=bu}while(1){az=bw+1|0;if((a[az]|0)==0){bv=ay;break}else{bw=az}}}}while(0);if((F|0)==8952){F=0;a[ag]=0;bv=ay}while(1){bx=c[bv>>2]|0;if((bx|0)==0){F=8960;break}if((fa(107584,c[bx>>2]|0)|0)==0){F=8955;break}else{bv=bx+8|0}}L12331:do{if((F|0)==8955){F=0;ay=c[bx+4>>2]|0;if((ay|0)==0){F=8960;break}else{by=64;bz=ah;bA=ay}while(1){ay=by-1|0;if((ay|0)==0){break}az=a[bA]|0;a[bz]=az;if(az<<24>>24==0){break L12331}else{by=ay;bz=bz+1|0;bA=bA+1|0}}a[bz]=0;if((a[bA]|0)==0){break}else{bB=bA}do{bB=bB+1|0;}while((a[bB]|0)!=0)}}while(0);if((F|0)==8960){F=0;a[ah]=0}if((a[W]|0)==0){F=8963;break L12155}if((a[aC]|0)==0){F=8963;break L12155}do{if((fa(W|0,210960)|0)==0){c[z+99732+(aA*80|0)+68>>2]=0;F=8977}else{if((fa(W|0,194200)|0)==0){c[z+99732+(aA*80|0)+68>>2]=1;F=8977;break}if((fa(W|0,206032)|0)==0){c[z+99732+(aA*80|0)+68>>2]=2;F=8977;break}if((fa(W|0,199680)|0)==0){c[z+99732+(aA*80|0)+68>>2]=3;F=8977;break}if((fa(W|0,188128)|0)==0){c[z+99732+(aA*80|0)+68>>2]=4;F=8977;break}if((fa(W|0,182664)|0)!=0){F=8975;break L12155}c[z+99732+(aA*80|0)+68>>2]=5}}while(0);do{if((F|0)==8977){F=0;if((a[af]|0)==0){if((a[ae]|0)==0){F=8984;break L12155}c[z+99732+(aA*80|0)+64>>2]=ch(ae|0,0,16)|0;c[z+99732+(aA*80|0)+72>>2]=1;break}aC=ch(af|0,0,0)|0;if((aC|0)==1){c[z+99732+(aA*80|0)+72>>2]=2;break}else if((aC|0)==2){c[z+99732+(aA*80|0)+72>>2]=3;break}else{F=8981;break L12155}}}while(0);if((a[ag]|0)!=0){b[z+99732+(aA*80|0)+76>>1]=(ch(ag|0,0,16)|0)&65535}if((a[ah]|0)!=0){b[z+99732+(aA*80|0)+78>>1]=(ch(ah|0,0,16)|0)&65535}c[ar>>2]=(c[ar>>2]|0)+1;break}if((a[G]&1)!=0){if((c[z+76+(aw*4144|0)+4096>>2]|0)==0){F=8715;break L12155}}aC=jo(ax,d,au)|0;if((aC|0)==0){F=8717;break L12155}c[z+76+(aw*4144|0)+4100>>2]=aC;aC=z+76+(aw*4144|0)+4140|0;c[aC>>2]=0;ay=z+76+(aw*4144|0)+4132|0;c[ay>>2]=0;az=z+76+(aw*4144|0)+4128|0;a[az]=0;av=z+76+(aw*4144|0)+4112|0;g[av>>2]=1.0;aH=z+76+(aw*4144|0)+4116|0;g[aH>>2]=1.0;aB=z+76+(aw*4144|0)+4108|0;c[aB>>2]=0;aN=z+76+(aw*4144|0)+4104|0;c[aN>>2]=0;bC=z+76+(aw*4144|0)+4129|0;a[bC]=0;bD=au+8|0;bE=bD;while(1){bF=c[bE>>2]|0;if((bF|0)==0){F=8722;break}if((fa(88376,c[bF>>2]|0)|0)==0){F=8721;break}else{bE=bF+8|0}}do{if((F|0)==8721){F=0;bE=c[bF+4>>2]|0;if((bE|0)==0){F=8722;break}else{bH=64;bI=0;bJ=W;bK=bE}while(1){bE=bH-1|0;if((bE|0)==0){F=8725;break}aA=a[bK]|0;a[bJ]=aA;if(aA<<24>>24==0){bL=bI;break}else{bH=bE;bI=bI+1|0;bJ=bJ+1|0;bK=bK+1|0}}do{if((F|0)==8725){F=0;a[bJ]=0;if((a[bK]|0)==0){bL=bI;break}else{bM=bK;bN=bI}while(1){bE=bM+1|0;aA=bN+1|0;if((a[bE]|0)==0){bL=aA;break}else{bM=bE;bN=aA}}}}while(0);if(bL>>>0>=64){bO=bD;F=8735;break}if((fa(W|0,81592)|0)==0){c[ay>>2]=2;if((a[9375104]&1)==0){bO=bD;F=8735;break}cj(77296,42,1,ap|0)|0;eY(ap|0)|0;bO=bD;F=8735;break}if((fa(W|0,82912)|0)!=0){cj(72936,54,1,ap|0)|0;eY(ap|0)|0;bP=0;break}c[ay>>2]=1;if((a[9375104]&1)==0){bO=bD;F=8735;break}cj(75312,41,1,ap|0)|0;eY(ap|0)|0;bO=bD;F=8735}}while(0);if((F|0)==8722){F=0;a[W]=0;bO=bD;F=8735}do{if((F|0)==8735){while(1){F=0;bQ=c[bO>>2]|0;if((bQ|0)==0){F=8742;break}if((fa(70144,c[bQ>>2]|0)|0)==0){F=8737;break}else{bO=bQ+8|0;F=8735}}L12409:do{if((F|0)==8737){F=0;ay=c[bQ+4>>2]|0;if((ay|0)==0){F=8742;break}else{bR=64;bS=ae;bT=ay}while(1){ay=bR-1|0;if((ay|0)==0){break}aA=a[bT]|0;a[bS]=aA;if(aA<<24>>24==0){bW=bD;break L12409}else{bR=ay;bS=bS+1|0;bT=bT+1|0}}a[bS]=0;if((a[bT]|0)==0){bW=bD;break}else{bX=bT}while(1){ay=bX+1|0;if((a[ay]|0)==0){bW=bD;break}else{bX=ay}}}}while(0);if((F|0)==8742){F=0;a[ae]=0;bW=bD}while(1){bY=c[bW>>2]|0;if((bY|0)==0){F=8750;break}if((fa(68848,c[bY>>2]|0)|0)==0){F=8745;break}else{bW=bY+8|0}}L12422:do{if((F|0)==8745){F=0;ay=c[bY+4>>2]|0;if((ay|0)==0){F=8750;break}else{bZ=64;b_=af;b$=ay}while(1){ay=bZ-1|0;if((ay|0)==0){break}aA=a[b$]|0;a[b_]=aA;if(aA<<24>>24==0){b0=bD;break L12422}else{bZ=ay;b_=b_+1|0;b$=b$+1|0}}a[b_]=0;if((a[b$]|0)==0){b0=bD;break}else{b1=b$}while(1){ay=b1+1|0;if((a[ay]|0)==0){b0=bD;break}else{b1=ay}}}}while(0);if((F|0)==8750){F=0;a[af]=0;b0=bD}while(1){b2=c[b0>>2]|0;if((b2|0)==0){F=8758;break}if((fa(67552,c[b2>>2]|0)|0)==0){F=8753;break}else{b0=b2+8|0}}L12435:do{if((F|0)==8753){F=0;ay=c[b2+4>>2]|0;if((ay|0)==0){F=8758;break}else{b3=64;b4=ag;b5=ay}while(1){ay=b3-1|0;if((ay|0)==0){break}aA=a[b5]|0;a[b4]=aA;if(aA<<24>>24==0){b6=bD;break L12435}else{b3=ay;b4=b4+1|0;b5=b5+1|0}}a[b4]=0;if((a[b5]|0)==0){b6=bD;break}else{b7=b5}while(1){ay=b7+1|0;if((a[ay]|0)==0){b6=bD;break}else{b7=ay}}}}while(0);if((F|0)==8758){F=0;a[ag]=0;b6=bD}while(1){b8=c[b6>>2]|0;if((b8|0)==0){F=8766;break}if((fa(66080,c[b8>>2]|0)|0)==0){F=8761;break}else{b6=b8+8|0}}L12448:do{if((F|0)==8761){F=0;ay=c[b8+4>>2]|0;if((ay|0)==0){F=8766;break}else{b9=64;ca=ah;cb=ay}while(1){ay=b9-1|0;if((ay|0)==0){break}aA=a[cb]|0;a[ca]=aA;if(aA<<24>>24==0){cc=bD;break L12448}else{b9=ay;ca=ca+1|0;cb=cb+1|0}}a[ca]=0;if((a[cb]|0)==0){cc=bD;break}else{cd=cb}while(1){ay=cd+1|0;if((a[ay]|0)==0){cc=bD;break}else{cd=ay}}}}while(0);if((F|0)==8766){F=0;a[ah]=0;cc=bD}while(1){ce=c[cc>>2]|0;if((ce|0)==0){F=8774;break}if((fa(589536,c[ce>>2]|0)|0)==0){F=8769;break}else{cc=ce+8|0}}L12461:do{if((F|0)==8769){F=0;ay=c[ce+4>>2]|0;if((ay|0)==0){F=8774;break}else{cf=64;cg=ai;ci=ay}while(1){ay=cf-1|0;if((ay|0)==0){break}aA=a[ci]|0;a[cg]=aA;if(aA<<24>>24==0){ck=bD;break L12461}else{cf=ay;cg=cg+1|0;ci=ci+1|0}}a[cg]=0;if((a[ci]|0)==0){ck=bD;break}else{cl=ci}while(1){ay=cl+1|0;if((a[ay]|0)==0){ck=bD;break}else{cl=ay}}}}while(0);if((F|0)==8774){F=0;a[ai]=0;ck=bD}while(1){cm=c[ck>>2]|0;if((cm|0)==0){F=8782;break}if((fa(588320,c[cm>>2]|0)|0)==0){F=8777;break}else{ck=cm+8|0}}L12474:do{if((F|0)==8777){F=0;ay=c[cm+4>>2]|0;if((ay|0)==0){F=8782;break}else{cn=64;co=aj;cq=ay}while(1){ay=cn-1|0;if((ay|0)==0){break}aA=a[cq]|0;a[co]=aA;if(aA<<24>>24==0){cr=bD;break L12474}else{cn=ay;co=co+1|0;cq=cq+1|0}}a[co]=0;if((a[cq]|0)==0){cr=bD;break}else{cs=cq}while(1){ay=cs+1|0;if((a[ay]|0)==0){cr=bD;break}else{cs=ay}}}}while(0);if((F|0)==8782){F=0;a[aj]=0;cr=bD}while(1){ct=c[cr>>2]|0;if((ct|0)==0){F=8790;break}if((fa(586256,c[ct>>2]|0)|0)==0){F=8785;break}else{cr=ct+8|0}}L12487:do{if((F|0)==8785){F=0;ay=c[ct+4>>2]|0;if((ay|0)==0){F=8790;break}else{cu=64;cv=ak;cw=ay}while(1){ay=cu-1|0;if((ay|0)==0){break}aA=a[cw]|0;a[cv]=aA;if(aA<<24>>24==0){cx=bD;break L12487}else{cu=ay;cv=cv+1|0;cw=cw+1|0}}a[cv]=0;if((a[cw]|0)==0){cx=bD;break}else{cy=cw}while(1){ay=cy+1|0;if((a[ay]|0)==0){cx=bD;break}else{cy=ay}}}}while(0);if((F|0)==8790){F=0;a[ak]=0;cx=bD}while(1){cz=c[cx>>2]|0;if((cz|0)==0){F=8798;break}if((fa(584464,c[cz>>2]|0)|0)==0){F=8793;break}else{cx=cz+8|0}}L12500:do{if((F|0)==8793){F=0;ay=c[cz+4>>2]|0;if((ay|0)==0){F=8798;break}else{cA=64;cB=al;cC=ay}while(1){ay=cA-1|0;if((ay|0)==0){break}aA=a[cC]|0;a[cB]=aA;if(aA<<24>>24==0){cD=bD;break L12500}else{cA=ay;cB=cB+1|0;cC=cC+1|0}}a[cB]=0;if((a[cC]|0)==0){cD=bD;break}else{cF=cC}while(1){ay=cF+1|0;if((a[ay]|0)==0){cD=bD;break}else{cF=ay}}}}while(0);if((F|0)==8798){F=0;a[al]=0;cD=bD}while(1){cG=c[cD>>2]|0;if((cG|0)==0){F=8806;break}if((fa(582640,c[cG>>2]|0)|0)==0){F=8801;break}else{cD=cG+8|0}}L12513:do{if((F|0)==8801){F=0;ay=c[cG+4>>2]|0;if((ay|0)==0){F=8806;break}else{cH=64;cI=am;cJ=ay}while(1){ay=cH-1|0;if((ay|0)==0){break}aA=a[cJ]|0;a[cI]=aA;if(aA<<24>>24==0){cK=bD;break L12513}else{cH=ay;cI=cI+1|0;cJ=cJ+1|0}}a[cI]=0;if((a[cJ]|0)==0){cK=bD;break}else{cL=cJ}while(1){ay=cL+1|0;if((a[ay]|0)==0){cK=bD;break}else{cL=ay}}}}while(0);if((F|0)==8806){F=0;a[am]=0;cK=bD}while(1){cM=c[cK>>2]|0;if((cM|0)==0){F=8814;break}if((fa(580416,c[cM>>2]|0)|0)==0){F=8809;break}else{cK=cM+8|0}}L12526:do{if((F|0)==8809){F=0;ay=c[cM+4>>2]|0;if((ay|0)==0){F=8814;break}else{cN=64;cO=an;cP=ay}while(1){ay=cN-1|0;if((ay|0)==0){break}aA=a[cP]|0;a[cO]=aA;if(aA<<24>>24==0){cQ=bD;break L12526}else{cN=ay;cO=cO+1|0;cP=cP+1|0}}a[cO]=0;if((a[cP]|0)==0){cQ=bD;break}else{cR=cP}while(1){ay=cR+1|0;if((a[ay]|0)==0){cQ=bD;break}else{cR=ay}}}}while(0);if((F|0)==8814){F=0;a[an]=0;cQ=bD}while(1){cS=c[cQ>>2]|0;if((cS|0)==0){F=8822;break}if((fa(578192,c[cS>>2]|0)|0)==0){F=8817;break}else{cQ=cS+8|0}}L12539:do{if((F|0)==8817){F=0;ay=c[cS+4>>2]|0;if((ay|0)==0){F=8822;break}else{cT=64;cU=ao;cV=ay}while(1){ay=cT-1|0;if((ay|0)==0){break}aA=a[cV]|0;a[cU]=aA;if(aA<<24>>24==0){break L12539}else{cT=ay;cU=cU+1|0;cV=cV+1|0}}a[cU]=0;if((a[cV]|0)==0){break}else{cW=cV}do{cW=cW+1|0;}while((a[cW]|0)!=0)}}while(0);if((F|0)==8822){F=0;a[ao]=0}a[az]=(fa(ao|0,577008)|0)==0|0;do{if((a[an]|0)!=0){ay=ch(an|0,0,0)|0;c[aC>>2]=ay;if((a[9375104]&1)==0){break}bU(ap|0,575752,(I=i,i=i+8|0,c[I>>2]=ay,I)|0)|0;i=I;eY(ap|0)|0}}while(0);do{if((a[ae]|0)==0){cX=0}else{cY=+gGx(ae,0);g[av>>2]=cY;g[aH>>2]=cY;a[bC]=1;if((a[9375104]&1)==0){cX=1;break}cZ=cY;bU(ap|0,574584,(I=i,i=i+8|0,h[I>>3]=cZ,I)|0)|0;i=I;eY(ap|0)|0;cX=1}}while(0);if((a[af]|0)==0){c_=cX}else{cZ=+gGx(af,0);g[av>>2]=cZ;a[bC]=1;if((a[9375104]&1)!=0){cY=cZ;bU(ap|0,573288,(I=i,i=i+8|0,h[I>>3]=cY,I)|0)|0;i=I;eY(ap|0)|0}c_=cX+1|0}if((a[ag]|0)==0){c$=cX}else{cY=+gGx(ag,0);g[aH>>2]=cY;a[bC]=1;if((a[9375104]&1)!=0){cZ=cY;bU(ap|0,572008,(I=i,i=i+8|0,h[I>>3]=cZ,I)|0)|0;i=I;eY(ap|0)|0}c$=cX+1|0}if((a[ah]|0)==0){c0=c_;c1=c$}else{ay=ch(ah|0,0,0)|0;c[z+76+(aw*4144|0)+4124>>2]=ay;c[z+76+(aw*4144|0)+4120>>2]=ay;a[bC]=1;c[aB>>2]=1;c[aN>>2]=1;if((a[9375104]&1)!=0){bU(ap|0,569640,(I=i,i=i+8|0,c[I>>2]=ay,I)|0)|0;i=I;eY(ap|0)|0}c0=c_+1|0;c1=c$+1|0}if((a[ai]|0)==0){c2=c0}else{ay=ch(ai|0,0,0)|0;c[z+76+(aw*4144|0)+4120>>2]=ay;a[bC]=1;c[aN>>2]=1;if((a[9375104]&1)!=0){bU(ap|0,567872,(I=i,i=i+8|0,c[I>>2]=ay,I)|0)|0;i=I;eY(ap|0)|0}c2=c0+1|0}if((a[aj]|0)==0){c3=c1}else{ay=ch(aj|0,0,0)|0;c[z+76+(aw*4144|0)+4124>>2]=ay;a[bC]=1;c[aB>>2]=1;if((a[9375104]&1)!=0){bU(ap|0,565632,(I=i,i=i+8|0,c[I>>2]=ay,I)|0)|0;i=I;eY(ap|0)|0}c3=c1+1|0}if((a[ak]|0)==0){c4=c2;c5=c3}else{cZ=+gGx(ak,0);g[aH>>2]=cZ;g[av>>2]=cZ;a[bC]=1;c[aB>>2]=2;c[aN>>2]=2;if((a[9375104]&1)!=0){cY=cZ;bU(ap|0,563504,(I=i,i=i+8|0,h[I>>3]=cY,I)|0)|0;i=I;eY(ap|0)|0}c4=c2+1|0;c5=c3+1|0}if((a[al]|0)==0){c6=c4}else{cY=+gGx(al,0);g[av>>2]=cY;a[bC]=1;c[aN>>2]=2;if((a[9375104]&1)!=0){cZ=cY;bU(ap|0,561880,(I=i,i=i+8|0,h[I>>3]=cZ,I)|0)|0;i=I;eY(ap|0)|0}c6=c4+1|0}if((a[am]|0)==0){c7=c5}else{cZ=+gGx(am,0);g[aH>>2]=cZ;a[bC]=1;c[aB>>2]=2;if((a[9375104]&1)!=0){cY=cZ;bU(ap|0,560480,(I=i,i=i+8|0,h[I>>3]=cY,I)|0)|0;i=I;eY(ap|0)|0}c7=c5+1|0}if(c6>>>0>1){bP=0;break}bP=c7>>>0<2}}while(0);if(!bP){F=8864;break L12155}c[aa>>2]=(c[aa>>2]|0)+1}}while(0);aB=c[au+16>>2]|0;if((aB|0)==0){F=9020;break L12153}else{au=aB}}if((F|0)==8963){cj(105784,57,1,ap|0)|0;eY(ap|0)|0;F=8990}else if((F|0)==8911){cj(121360,51,1,ap|0)|0;eY(ap|0)|0;F=8990}else if((F|0)==8897){cj(86536,51,1,ap|0)|0;eY(ap|0)|0;F=8908}else if((F|0)==8906){cj(79480,46,1,ap|0)|0;eY(ap|0)|0;F=8908}else if((F|0)==9012){cj(127608,52,1,ap|0)|0;eY(ap|0)|0;F=9018}else if((F|0)==9014){c[as>>2]=0;F=9018}else if((F|0)==8984){cj(96280,65,1,ap|0)|0;eY(ap|0)|0;F=8990}else if((F|0)==8715){cj(452696,98,1,ap|0)|0;eY(ap|0)|0;gGr(ax);break L12092}else if((F|0)==8993){cj(133016,46,1,ap|0)|0;eY(ap|0)|0;F=9018}else if((F|0)==8710){cj(475328,74,1,ap|0)|0;eY(ap|0)|0;break L12092}else if((F|0)==8864){cj(442048,78,1,ap|0)|0;eY(ap|0)|0;break L12092}else if((F|0)==8899){cj(84712,57,1,ap|0)|0;eY(ap|0)|0;F=8908}else if((F|0)==8717){cj(475328,74,1,ap|0)|0;eY(ap|0)|0;break L12092}else if((F|0)==8981){cj(99784,52,1,ap|0)|0;eY(ap|0)|0;F=8990}else if((F|0)==8708){cj(499696,75,1,ap|0)|0;eY(ap|0)|0;gGr(ax);break L12092}else if((F|0)==8975){cj(102712,56,1,ap|0)|0;eY(ap|0)|0;F=8990}else if((F|0)==9017){cj(124872,48,1,ap|0)|0;eY(ap|0)|0;F=9018}if((F|0)==8990){cj(396544,46,1,ap|0)|0;eY(ap|0)|0;break L12092}else if((F|0)==8908){cj(419024,51,1,ap|0)|0;eY(ap|0)|0;break L12092}else if((F|0)==9018){cj(374504,40,1,ap|0)|0;eY(ap|0)|0;break L12092}}}while(0);do{if((F|0)==9020){if((c[aa>>2]|0)!=0){break}G=c[u>>2]|0;cj(364496,82,1,G|0)|0;eY(G|0)|0;break L12092}}while(0);aa=c[E>>2]|0;if((aa|0)!=0){iR(aa)}gGr(D);break L12072}else{aa=c[u>>2]|0;bU(aa|0,204536,(I=i,i=i+8|0,c[I>>2]=d,I)|0)|0;i=I;eY(aa|0)|0}}while(0);C=c[u>>2]|0;cj(357192,51,1,C|0)|0;eY(C|0)|0;if(!A){break}C=c[D>>2]|0;if((C|0)!=0){iR(C)}gGr(D)}}while(0);B=c[u>>2]|0;cj(432784,56,1,B|0)|0;eY(B|0)|0;y=0;i=e;return y|0}}while(0);jq(c[2313830]|0,d);d=(a[9255352]&1)==0;L12648:do{if((a[(c[2313830]|0)+4|0]&1)==0){ax=c[u>>2]|0;cj(257784,90,1,ax|0)|0;eY(ax|0)|0}else{ax=k3(d?199184:193896,d?210624:205696,0)|0;c[2315690]=ax;if((ax|0)==0){ax=c[u>>2]|0;cj(200832,60,1,ax|0)|0;eY(ax|0)|0;break}else{c8=0}while(1){c9=c[2313830]|0;if(c8>>>0>=(c[c9+72>>2]|0)>>>0){F=9044;break}da=c9+76+(c8*4144|0)|0;ax=c9+76+(c8*4144|0)+4096|0;if((a[da]|0)==0){db=c[ax>>2]|0;dc=c[c9+76+(c8*4144|0)+4100>>2]|0}else{if((hx(da,ax)|0)<1){F=9041;break}bP=bG(c[ax>>2]|0)|0;c[c9+76+(c8*4144|0)+4100>>2]=bP;if((bP|0)==0){F=9041;break}c7=c[ax>>2]|0;if((c7|0)==0){F=9041;break}else{db=c7;dc=bP}}a[da]=0;bP=k3(db,dc,c8)|0;c7=c8+1|0;c[9262760+(c7<<2)>>2]=bP;if((bP|0)==0){F=9043;break}else{c8=c7}}if((F|0)==9044){c7=w;L12663:do{if((c[c9+66380>>2]|0)==0){dd=0}else{cp(1,9262720);bP=c[2313830]|0;if((c[bP+66380>>2]|0)==0){dd=0;break}ax=w|0;c6=w+4|0;c5=w+8|0;c4=c[u>>2]|0;c3=0;c2=bP;while(1){if((a[9375104]&1)==0){de=c2}else{bP=c2+66384+(c3*4168|0)+64|0;bU(c4|0,341288,(I=i,i=i+8|0,c[I>>2]=bP,I)|0)|0;i=I;eY(c4|0)|0;de=c[2313830]|0}gGz(c7|0,0,12);bP=de+66384+(c3*4168|0)+64|0;if((a[9533596]&1)==0){if(!(jx(bP,w,16,0)|0)){break}}else{if(!(jx(bP,w,0,16)|0)){break}}dD(3553,c[9262720+(c3<<2)>>2]|0);ds(3553,10242,33071);ds(3553,10243,33071);bP=(c[(c[2313830]|0)+66384+(c3*4168|0)+4160>>2]|0)==2?9728:9729;ds(3553,10240,bP|0);ds(3553,10241,bP|0);f0(3317,4);bP=(a[9533596]&1)!=0?6408:32993;c1=c[c5>>2]|0;fP(3553,0,bP|0,c[ax>>2]|0,c[c6>>2]|0,0,bP|0,5121,c1|0);dD(3553,0);gGr(c1);c1=c3+1|0;bP=c[2313830]|0;if(c1>>>0<(c[bP+66380>>2]|0)>>>0){c3=c1;c2=bP}else{dd=0;break L12663}}bU(c4|0,333288,(I=i,i=i+8|0,c[I>>2]=(c[2313830]|0)+66384+(c3*4168|0)+64,I)|0)|0;i=I;eY(c4|0)|0;cj(158408,48,1,c4|0)|0;eY(c4|0)|0;break L12648}}while(0);do{k4(dd,c[9262760+(dd<<2)>>2]|0,9255360+(dd*460|0)|0);dd=dd+1|0;df=c[2313830]|0;}while(dd>>>0<=(c[df+72>>2]|0)>>>0);do{if((c[df+99728>>2]|0)!=0){c7=gj[c[2112866]&4095](2)|0;c2=c[2313830]|0;c6=c[c2+99728>>2]|0;ax=gGq(12)|0;if((ax|0)==0){c[2315688]=0}else{if((c[ax-4>>2]&3|0)!=0){gGz(ax|0,0,12)}c5=ax;D=(c6|0)==0;do{if(D){dg=0}else{A=c6*112|0;if(c6>>>0<=65535){dg=A;break}dg=((A>>>0)/(c6>>>0)|0|0)==112?A:-1}}while(0);c4=gGq(dg)|0;do{if((c4|0)!=0){if((c[c4-4>>2]&3|0)==0){break}gGz(c4|0,0,dg|0)}}while(0);c3=c4;A=ax;c[A>>2]=c3;c[ax+4>>2]=c6;L12695:do{if(!D){bP=ax+8|0;c1=ax+10|0;z=(c7|0)==0?8410968:c7;c0=0;c$=c3;while(1){c_=64;cX=c$+(c0*112|0)|0;cW=c2+99732+(c0*80|0)|0;while(1){cV=c_-1|0;if((cV|0)==0){F=9071;break}cU=a[cW]|0;a[cX]=cU;if(cU<<24>>24==0){break}else{c_=cV;cX=cX+1|0;cW=cW+1|0}}do{if((F|0)==9071){F=0;a[cX]=0;if((a[cW]|0)==0){break}else{dh=cW}do{dh=dh+1|0;}while((a[dh]|0)!=0)}}while(0);c[(c[A>>2]|0)+(c0*112|0)+76>>2]=c[c2+99732+(c0*80|0)+64>>2];c[(c[A>>2]|0)+(c0*112|0)+84>>2]=c[c2+99732+(c0*80|0)+68>>2];cW=b[c2+99732+(c0*80|0)+76>>1]|0;b[(c[A>>2]|0)+(c0*112|0)+80>>1]=cW<<16>>16==0?-1:cW;b[(c[A>>2]|0)+(c0*112|0)+82>>1]=b[c2+99732+(c0*80|0)+78>>1]|0;cW=c[c2+99732+(c0*80|0)+72>>2]|0;if((cW|0)==3){c[(c[A>>2]|0)+(c0*112|0)+68>>2]=c1;a[(c[A>>2]|0)+(c0*112|0)+64|0]=1}else if((cW|0)==1){c[(c[A>>2]|0)+(c0*112|0)+72>>2]=z}else if((cW|0)==2){c[(c[A>>2]|0)+(c0*112|0)+68>>2]=bP;a[(c[A>>2]|0)+(c0*112|0)+64|0]=1}else{c[(c[A>>2]|0)+(c0*112|0)+72>>2]=8410968}cW=c0+1|0;if(cW>>>0>=c6>>>0){break L12695}c0=cW;c$=c[A>>2]|0}}}while(0);c[2315688]=c5;if((ax|0)!=0){break}}A=c[u>>2]|0;cj(128112,50,1,A|0)|0;eY(A|0)|0}}while(0);a[48928]=1;A=c[2313830]|0;c6=A+72|0;c[9262760+((c[c6>>2]|0)+1<<2)>>2]=c[2315690];c2=9255360+(((c[c6>>2]|0)+1|0)*460|0)|0;gGC(c2|0,9255360,460)|0;if((a[A+4|0]&1)==0){c[2315705]=c[2315690];gGC(9262260,9255360,460)|0}else{A=(a[9255352]&1)!=0;c2=k3(A?569904:586520,A?79928:103264,15)|0;c[2315705]=c2;k4(0,c2,9262260)}if((c[2315864]|0)!=0){c2=0;do{bV(c[9263344+(c2<<2)>>2]|0);c2=c2+1|0;}while(c2>>>0<(c[2315864]|0)>>>0)}c[2315864]=0;c2=0;while(1){eJ(1,9238680+(c2*1040|0)|0);eJ(1,9239200+(c2*1040|0)|0);A=c2+1|0;if(A>>>0<16){c2=A}else{y=1;break}}i=e;return y|0}else if((F|0)==9041){c2=c[u>>2]|0;bU(c2|0,324448,(I=i,i=i+8|0,c[I>>2]=da,I)|0)|0;i=I;eY(c2|0)|0;break}else if((F|0)==9043){c2=c[u>>2]|0;bU(c2|0,315752,(I=i,i=i+8|0,c[I>>2]=c8,I)|0)|0;i=I;eY(c2|0)|0;break}}}while(0);kU();y=0;i=e;return y|0}function kU(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;i=i+16|0;d=b|0;e=b+8|0;dc(0);f=e;g=e;h=0;do{j=c[9262760+(h<<2)>>2]|0;do{if((j|0)!=0){if((h|0)!=0&(j|0)==(c[2315690]|0)){break}c[e>>2]=0;c[e+4>>2]=0;bQ(j|0,2,d|0,g|0);if((c[d>>2]|0)>0){k=0;do{l=f+(k<<2)|0;dH(j|0,c[l>>2]|0);dk(c[l>>2]|0);k=k+1|0;}while((k|0)<(c[d>>2]|0))}bj(j|0)}}while(0);h=h+1|0;}while(h>>>0<16);h=c[2313830]|0;do{if((h|0)==0){m=0}else{d=c[h+66380>>2]|0;if((d|0)==0){m=h;break}dK(d|0,9262720);m=c[2313830]|0}}while(0);gGz(9262760,0,64);gGz(9255360,0,7360);a[48928]=0;c[2383594]=0;if((m|0)!=0){if((c[m+72>>2]|0)==0){n=m}else{h=0;d=m;while(1){gGr(c[d+76+(h*4144|0)+4096>>2]|0);gGr(c[(c[2313830]|0)+76+(h*4144|0)+4100>>2]|0);m=h+1|0;f=c[2313830]|0;if(m>>>0<(c[f+72>>2]|0)>>>0){h=m;d=f}else{n=f;break}}}gGr(c[n+108948>>2]|0);gGr(c[2313830]|0);c[2313830]=0}n=c[2315688]|0;if((n|0)!=0){gGr(c[n>>2]|0);gGr(n)}c[2315688]=0;if((c[2315864]|0)!=0){n=0;do{bV(c[9263344+(n<<2)>>2]|0);n=n+1|0;}while(n>>>0<(c[2315864]|0)>>>0)}c[2315864]=0;n=0;do{d=9238680+(n*1040|0)|0;if((c[d>>2]|0)!=0){eQ(1,d|0)}d=9239200+(n*1040|0)|0;if((c[d>>2]|0)!=0){eQ(1,d|0)}n=n+1|0;}while(n>>>0<16);gGz(9238680,0,16640);i=b;return}function kV(e,f,h,j,k,l,m,n,o,p,q){e=e|0;f=f|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;q=q|0;var r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0;r=i;i=i+920|0;s=r|0;t=r+512|0;u=r+896|0;v=r+904|0;w=r+912|0;if(!(a[48928]|0)){i=r;return}x=c[2383594]|0;if((c[9262760+(x<<2)>>2]|0)==0){i=r;return}y=t|0;z=u|0;g[z>>2]=+(e>>>0>>>0);g[u+4>>2]=+(f>>>0>>>0);f=v|0;g[f>>2]=+(k>>>0>>>0);g[v+4>>2]=+(l>>>0>>>0);l=w|0;g[l>>2]=+(h>>>0>>>0);g[w+4>>2]=+(j>>>0>>>0);j=c[9255380+(x*460|0)>>2]|0;if((j|0)>-1){e_(j|0,1,z|0)}z=c[9255384+(x*460|0)>>2]|0;if((z|0)>-1){e_(z|0,1,f|0)}f=c[9255388+(x*460|0)>>2]|0;if((f|0)>-1){e_(f|0,1,l|0)}l=c[9255392+(x*460|0)>>2]|0;f=c[2383594]|0;if((l|0)>-1&(f|0)!=0){z=c[(c[2313830]|0)+76+((f-1|0)*4144|0)+4140>>2]|0;if((z|0)==0){A=m}else{A=(m>>>0)%(z>>>0)|0}dV(l|0,A|0);B=A}else{B=m}m=c[9255400+(x*460|0)>>2]|0;if((m|0)>-1){dV(m|0,((a[9523624]&1)!=0?-1:1)|0)}m=c[2313830]|0;if((c[m+66380>>2]|0)==0){D=0}else{A=0;l=m;while(1){m=9255404+(x*460|0)+(A<<2)|0;if((c[m>>2]|0)>-1){eq(A+33985|0);dD(3553,c[9262720+(A<<2)>>2]|0);z=A+1|0;dV(c[m>>2]|0,z|0);E=c[2313830]|0;F=z}else{E=l;F=A+1|0}z=c[E+66380>>2]|0;if(F>>>0<z>>>0){A=F;l=E}else{D=z;break}}}E=D+1|0;do{if((c[2383594]|0)>>>0>1){l=9255436+(x*460|0)|0;if((c[l>>2]|0)>-1){eq(D+33985|0);dV(c[l>>2]|0,E|0);dD(3553,c[n>>2]|0)}l=D+2|0;F=c[9255444+(x*460|0)>>2]|0;if((F|0)>-1){e_(F|0,1,n+12|0)}F=c[9255440+(x*460|0)>>2]|0;if((F|0)>-1){e_(F|0,1,n+4|0)}F=c[9255448+(x*460|0)>>2]|0;if((F|0)>-1){c[t>>2]=F;c[t+4>>2]=2;c[t+8>>2]=0;F=t+12|0;A=s;z=n+20|0;gGC(A|0,z|0,32)|0;G=8;H=1;I=F}else{G=0;H=0;I=y}if((q|0)==0){J=I;K=H;L=G;M=l;N=0;break}eq(q+33985+D|0);dD(3553,c[p+((q-1|0)*52|0)>>2]|0);F=I;z=H;A=G;m=l;l=0;while(1){f=c[9255452+(x*460|0)+(l<<4)>>2]|0;if((f|0)!=0){dV(f|0,m|0)}f=c[9255452+(x*460|0)+(l<<4)+8>>2]|0;if((f|0)>-1){e_(f|0,1,p+(l*52|0)+12|0)}f=c[9255452+(x*460|0)+(l<<4)+4>>2]|0;if((f|0)>-1){e_(f|0,1,p+(l*52|0)+4|0)}f=c[9255452+(x*460|0)+(l<<4)+12>>2]|0;if((f|0)>-1){c[F>>2]=f;c[F+4>>2]=2;c[F+8>>2]=A<<2;f=z+1|0;j=F+12|0;w=s+(A<<2)|0;h=p+(l*52|0)+20|0;gGC(w|0,h|0,32)|0;O=A+8|0;P=f;Q=j}else{O=A;P=z;Q=F}j=l+1|0;if(j>>>0<q>>>0){F=Q;z=P;A=O;m=m+1|0;l=j}else{break}}J=Q;K=P;L=O;M=q+2+D|0;N=0}else{eq(D+33985|0);dD(3553,0);if((c[(c[2313830]|0)+72>>2]|0)==0){J=y;K=0;L=0;M=E;N=0;break}l=D+33986|0;m=0;while(1){eq(l+m|0);dD(3553,0);A=m+1|0;if(A>>>0<(c[(c[2313830]|0)+72>>2]|0)>>>0){m=A}else{J=y;K=0;L=0;M=E;N=0;break}}}}while(0);while(1){E=9255708+(x*460|0)+(N<<4)|0;if((c[E>>2]|0)>-1){eq(M+33984|0);dD(3553,c[o+(N*52|0)>>2]|0);dV(c[E>>2]|0,M|0);R=M+1|0}else{R=M}E=c[9255708+(x*460|0)+(N<<4)+8>>2]|0;if((E|0)>-1){e_(E|0,1,o+(N*52|0)+12|0)}E=c[9255708+(x*460|0)+(N<<4)+4>>2]|0;if((E|0)>-1){e_(E|0,1,o+(N*52|0)+4|0)}E=c[9255708+(x*460|0)+(N<<4)+12>>2]|0;if((E|0)>-1){c[J>>2]=E;c[J+4>>2]=2;c[J+8>>2]=L<<2;E=K+1|0;D=J+12|0;q=s+(L<<2)|0;O=o+(N*52|0)+20|0;gGC(q|0,O|0,32)|0;S=L+8|0;T=E;U=D}else{S=L;T=K;U=J}D=N+1|0;if(D>>>0<7){J=U;K=T;L=S;M=R+1|0;N=D}else{break}}if((S|0)!=0){N=c[2383594]|0;k2(c[9239200+(N*1040|0)>>2]|0,9239204+(N*1040|0)|0,9239716+(N*1040|0)|0,s|0,S,y,T)}eq(33984);T=c[2315688]|0;if((T|0)==0){i=r;return}if((c[2383594]|0)==1){y=c[T+4>>2]|0;S=y>>>0<64?y:64;y=c[2383356]|0;if((y|0)!=0){s=4;N=0;R=0;M=y;while(1){y=c[272+(s-4<<2)>>2]|0;V=((gh[c[M+8>>2]&15](c[2383359]|0,320,0,1,0,y)|0)<<16>>16!=0)<<s|N;W=((gh[c[(c[2383356]|0)+8>>2]&15](c[2383359]|0,320,1,1,0,y)|0)<<16>>16!=0)<<s|R;y=s+1|0;if(y>>>0>=16){break}s=y;N=V&65535;R=W&65535;M=c[2383356]|0}M=T+8|0;C=W<<16|V&65535;b[M>>1]=C&65535;b[M+2>>1]=C>>16}L12869:do{if((S|0)!=0){M=T|0;V=0;while(1){W=c[M>>2]|0;c[9262824+(V<<3)>>2]=W+(V*112|0);switch(c[W+(V*112|0)+84>>2]|0){case 0:{if((a[W+(V*112|0)+64|0]&1)==0){X=d[(c[W+(V*112|0)+72>>2]|0)+(c[W+(V*112|0)+76>>2]|0)|0]|0}else{X=b[c[W+(V*112|0)+68>>2]>>1]|0}R=b[W+(V*112|0)+80>>1]&X;N=b[W+(V*112|0)+82>>1]|0;g[9262828+(V<<3)>>2]=N<<16>>16==0|R<<16>>16==N<<16>>16?+((R&65535)>>>0):0.0;break};case 1:{R=W+(V*112|0)+88|0;N=c[R>>2]|0;s=(a[W+(V*112|0)+64|0]&1)==0;if(s){Y=d[(c[W+(V*112|0)+72>>2]|0)+(c[W+(V*112|0)+76>>2]|0)|0]|0}else{Y=b[c[W+(V*112|0)+68>>2]>>1]|0}y=b[W+(V*112|0)+80>>1]|0;L=y&Y;K=b[W+(V*112|0)+82>>1]|0;U=K<<16>>16==0;J=W+(V*112|0)+92|0;if((N|0)==((U|L<<16>>16==K<<16>>16?L&65535:0)|0)){Z=c[J>>2]|0}else{c[J>>2]=N;if(s){_=d[(c[W+(V*112|0)+72>>2]|0)+(c[W+(V*112|0)+76>>2]|0)|0]|0}else{_=b[c[W+(V*112|0)+68>>2]>>1]|0}s=_&y;c[R>>2]=U|s<<16>>16==K<<16>>16?s&65535:0;Z=N}g[9262828+(V<<3)>>2]=+(Z>>>0>>>0);break};case 2:{N=W+(V*112|0)+104|0;s=(a[W+(V*112|0)+64|0]&1)==0;if(s){$=d[(c[W+(V*112|0)+72>>2]|0)+(c[W+(V*112|0)+76>>2]|0)|0]|0}else{$=b[c[W+(V*112|0)+68>>2]>>1]|0}K=b[W+(V*112|0)+80>>1]|0;U=K&$;R=b[W+(V*112|0)+82>>1]|0;y=R<<16>>16==0;if((c[N>>2]|0)==((y|U<<16>>16==R<<16>>16?U&65535:0)|0)){aa=c[W+(V*112|0)+96>>2]|0}else{if(s){ab=d[(c[W+(V*112|0)+72>>2]|0)+(c[W+(V*112|0)+76>>2]|0)|0]|0}else{ab=b[c[W+(V*112|0)+68>>2]>>1]|0}s=ab&K;c[N>>2]=y|s<<16>>16==R<<16>>16?s&65535:0;c[W+(V*112|0)+96>>2]=B;aa=B}g[9262828+(V<<3)>>2]=+(aa|0);break};case 3:{s=W+(V*112|0)+104|0;R=(a[W+(V*112|0)+64|0]&1)==0;if(R){ac=d[(c[W+(V*112|0)+72>>2]|0)+(c[W+(V*112|0)+76>>2]|0)|0]|0}else{ac=b[c[W+(V*112|0)+68>>2]>>1]|0}y=b[W+(V*112|0)+80>>1]|0;N=y&ac;K=b[W+(V*112|0)+82>>1]|0;U=K<<16>>16==0;if((c[s>>2]|0)==((U|N<<16>>16==K<<16>>16?N&65535:0)|0)){ad=c[W+(V*112|0)+108>>2]|0}else{if(R){ae=d[(c[W+(V*112|0)+72>>2]|0)+(c[W+(V*112|0)+76>>2]|0)|0]|0}else{ae=b[c[W+(V*112|0)+68>>2]>>1]|0}R=ae&y;c[s>>2]=U|R<<16>>16==K<<16>>16?R&65535:0;R=W+(V*112|0)+108|0;K=(c[R>>2]|0)+1|0;c[R>>2]=K;ad=K}g[9262828+(V<<3)>>2]=+(ad|0);break};case 4:{K=W+(V*112|0)+104|0;R=(a[W+(V*112|0)+64|0]&1)==0;if(R){af=d[(c[W+(V*112|0)+72>>2]|0)+(c[W+(V*112|0)+76>>2]|0)|0]|0}else{af=b[c[W+(V*112|0)+68>>2]>>1]|0}U=b[W+(V*112|0)+80>>1]|0;s=U&af;y=b[W+(V*112|0)+82>>1]|0;N=y<<16>>16==0;if((c[K>>2]|0)==((N|s<<16>>16==y<<16>>16?s&65535:0)|0)){ag=c[W+(V*112|0)+100>>2]|0}else{if(R){ah=d[(c[W+(V*112|0)+72>>2]|0)+(c[W+(V*112|0)+76>>2]|0)|0]|0}else{ah=b[c[W+(V*112|0)+68>>2]>>1]|0}R=ah&U;c[K>>2]=N|R<<16>>16==y<<16>>16?R&65535:0;R=W+(V*112|0)+96|0;y=c[R>>2]|0;c[W+(V*112|0)+100>>2]=y;c[R>>2]=B;ag=y}g[9262828+(V<<3)>>2]=+(ag|0);break};default:{}}V=V+1|0;if(V>>>0>=S>>>0){break L12869}}}}while(0);c[2315834]=S;ai=S}else{ai=c[2315834]|0}if((ai|0)==0){i=r;return}else{aj=0}do{ai=fS(c[9262760+(c[2383594]<<2)>>2]|0,c[9262824+(aj<<3)>>2]|0)|0;dT(ai|0,+(+g[9262828+(aj<<3)>>2]));aj=aj+1|0;}while(aj>>>0<(c[2315834]|0)>>>0);i=r;return}function kW(b){b=b|0;var d=0;if(!(a[48928]|0)){return}if((c[2315864]|0)!=0){d=0;do{bV(c[9263344+(d<<2)>>2]|0);d=d+1|0;}while(d>>>0<(c[2315864]|0)>>>0)}c[2315864]=0;c[2383594]=b;dc(c[9262760+(b<<2)>>2]|0);return}function kX(){return c[(c[2313830]|0)+72>>2]|0}function kY(b,d){b=b|0;d=d|0;var e=0,f=0;if((b|0)==0|a[48928]^1){e=0;return e|0}f=c[(c[2313830]|0)+76+((b-1|0)*4144|0)+4132>>2]|0;if((f|0)==0){e=0;return e|0}a[d]=(f|0)==1|0;e=1;return e|0}function kZ(b){b=b|0;var d=0;if((b|0)==0|a[48928]^1){d=0;return d|0}d=c[(c[2313830]|0)+76+((b-1|0)*4144|0)+4136>>2]|0;return d|0}function k_(b,d){b=b|0;d=d|0;var e=0;if((b|0)==0|a[48928]^1){a[d+25|0]=0;return}else{e=d;d=(c[2313830]|0)+76+((b-1|0)*4144|0)+4104|0;c[e>>2]=c[d>>2];c[e+4>>2]=c[d+4>>2];c[e+8>>2]=c[d+8>>2];c[e+12>>2]=c[d+12>>2];c[e+16>>2]=c[d+16>>2];c[e+20>>2]=c[d+20>>2];c[e+24>>2]=c[d+24>>2];return}}function k$(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=i;i=i+560|0;e=d|0;f=d+512|0;if(!(a[48928]|0)){g=0;i=d;return g|0}if((a[(c[2313830]|0)+4|0]&1)==0){g=0;i=d;return g|0}h=f|0;j=c[2383594]|0;k=c[9255364+(j*460|0)>>2]|0;if((k|0)>-1){c[f>>2]=k;c[f+4>>2]=2;c[f+8>>2]=0;k=f+12|0;f=e;l=c[b+8>>2]|0;gGC(f|0,l|0,32)|0;m=k;n=1;o=8}else{m=h;n=0;o=0}k=c[9255368+(j*460|0)>>2]|0;if((k|0)>-1){c[m>>2]=k;c[m+4>>2]=2;c[m+8>>2]=o<<2;k=n+1|0;l=m+12|0;f=e+(o<<2)|0;p=c[b>>2]|0;gGC(f|0,p|0,32)|0;q=l;r=k;s=o+8|0}else{q=m;r=n;s=o}o=c[9255372+(j*460|0)>>2]|0;if((o|0)>-1){c[q>>2]=o;c[q+4>>2]=4;c[q+8>>2]=s<<2;o=r+1|0;n=q+12|0;m=e+(s<<2)|0;k=c[b+4>>2]|0;gGC(m|0,k|0,64)|0;t=n;u=o;v=s+16|0}else{t=q;u=r;v=s}s=c[9255376+(j*460|0)>>2]|0;if((s|0)>-1){c[t>>2]=s;c[t+4>>2]=2;c[t+8>>2]=v<<2;t=u+1|0;s=e+(v<<2)|0;r=c[b+12>>2]|0;gGC(s|0,r|0,32)|0;w=t;x=v+8|0}else{w=u;x=v}if((x|0)==0){g=1;i=d;return g|0}k2(c[9238680+(j*1040|0)>>2]|0,9238684+(j*1040|0)|0,9239196+(j*1040|0)|0,e|0,x,h,w);g=1;i=d;return g|0}function k0(b){b=b|0;var d=0,e=0;if(!(a[48928]|0)){d=0;return d|0}if((a[(c[2313830]|0)+4|0]&1)==0){d=0;return d|0}e=c[9255360+((c[2383594]|0)*460|0)>>2]|0;if((e|0)<=-1){d=1;return d|0}f7(e|0,1,0,b|0);d=1;return d|0}function k1(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if(!(a[48928]|0)){b=0;return b|0}d=c[(c[2313830]|0)+72>>2]|0;if((d|0)==0){b=0;return b|0}else{e=1;f=0}while(1){if((c[9255708+(e*460|0)>>2]|0)>-1){g=(f|0)==0?1:f}else{g=f}if((c[9255724+(e*460|0)>>2]|0)>-1){h=g>>>0<2?2:g}else{h=g}if((c[9255740+(e*460|0)>>2]|0)>-1){i=h>>>0<3?3:h}else{i=h}if((c[9255756+(e*460|0)>>2]|0)>-1){j=i>>>0<4?4:i}else{j=i}if((c[9255772+(e*460|0)>>2]|0)>-1){k=j>>>0<5?5:j}else{k=j}if((c[9255788+(e*460|0)>>2]|0)>-1){l=k>>>0<6?6:k}else{l=k}if((c[9255804+(e*460|0)>>2]|0)>-1){m=l>>>0<7?7:l}else{m=l}n=e+1|0;if(n>>>0>d>>>0){b=m;break}else{e=n;f=m}}return b|0}function k2(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0;fA(34962,a|0);if((c[d>>2]|0)==(f|0)){a=e;i=b;j=f<<2;if((gGH(a|0,i|0,j|0)|0)!=0){k=i;l=a;m=j;n=9314}}else{k=b;l=e;m=f<<2;n=9314}if((n|0)==9314){gGC(k|0,l|0,m)|0;fD(34962,m|0,l|0,35044);c[d>>2]=f}if((h|0)==0){fA(34962,0);return}else{o=0}do{f=c[g+(o*12|0)>>2]|0;er(f|0);d=c[2315864]|0;c[2315864]=d+1;c[9263344+(d<<2)>>2]=f;cA(f|0,c[g+(o*12|0)+4>>2]|0,5126,0,0,c[g+(o*12|0)+8>>2]|0);o=o+1|0;}while(o>>>0<h>>>0);fA(34962,0);return}function k3(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+88|0;g=f|0;h=f+64|0;j=f+72|0;k=f+80|0;l=eL()|0;if((l|0)==0){m=0;i=f;return m|0}n=(b|0)!=0;do{if(n){if((a[9375104]&1)!=0){o=c[u>>2]|0;cj(307120,37,1,o|0)|0;eY(o|0)|0}o=a9(35633)|0;if(k6(o,298960,b)|0){d5(l|0,o|0);break}o=c[u>>2]|0;bU(o|0,291480,(p=i,i=i+8|0,c[p>>2]=e,p)|0)|0;i=p;eY(o|0)|0;m=0;i=f;return m|0}}while(0);b=(d|0)!=0;do{if(b){if((a[9375104]&1)!=0){o=c[u>>2]|0;cj(285064,39,1,o|0)|0;eY(o|0)|0}o=a9(35632)|0;if(k6(o,278360,d)|0){d5(l|0,o|0);break}o=c[u>>2]|0;bU(o|0,270896,(p=i,i=i+8|0,c[p>>2]=e,p)|0)|0;i=p;eY(o|0)|0;m=0;i=f;return m|0}}while(0);if(!(n|b)){m=l;i=f;return m|0}if((a[9375104]&1)!=0){b=c[u>>2]|0;cj(263768,33,1,b|0)|0;eY(b|0)|0}dB(l|0);cz(l|0,35714,k|0);c[h>>2]=0;cz(l|0,35716,j|0);b=c[j>>2]|0;do{if((b|0)!=0){j=gGq(b)|0;if((j|0)==0){break}dd(l|0,b|0,h|0,j|0);do{if((c[h>>2]|0)>0){if((a[9375104]&1)==0){break}n=c[u>>2]|0;bU(n|0,247304,(p=i,i=i+8|0,c[p>>2]=j,p)|0)|0;i=p;eY(n|0)|0}}while(0);gGr(j)}}while(0);if((c[k>>2]|0)!=1){k=c[u>>2]|0;bU(k|0,255336,(p=i,i=i+8|0,c[p>>2]=e,p)|0)|0;i=p;eY(k|0)|0;m=0;i=f;return m|0}dc(l|0);dc(l|0);k=g|0;be(k|0,64,285248,(p=i,i=i+16|0,c[p>>2]=(c[2313830]|0)+5,c[p+8>>2]=364224,p)|0)|0;i=p;g=fS(l|0,k|0)|0;L13086:do{if((g|0)>-1){q=g}else{e=0;while(1){if(e>>>0>=2){q=-1;break L13086}be(k|0,64,285248,(p=i,i=i+16|0,c[p>>2]=c[48920+(e<<2)>>2],c[p+8>>2]=364224,p)|0)|0;i=p;h=fS(l|0,k|0)|0;if((h|0)>-1){q=h;break}else{e=e+1|0}}}}while(0);dV(q|0,0);dc(0);m=l;i=f;return m|0}function k4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;e=i;i=i+128|0;f=e+64|0;dc(b|0);g=e|0;be(g|0,64,285248,(h=i,i=i+16|0,c[h>>2]=(c[2313830]|0)+5,c[h+8>>2]=553784,h)|0)|0;i=h;j=fS(b|0,g|0)|0;L13093:do{if((j|0)>-1){k=j}else{l=0;while(1){if(l>>>0>=2){k=-1;break L13093}be(g|0,64,285248,(h=i,i=i+16|0,c[h>>2]=c[48920+(l<<2)>>2],c[h+8>>2]=553784,h)|0)|0;i=h;m=fS(b|0,g|0)|0;if((m|0)>-1){k=m;break}else{l=l+1|0}}}}while(0);c[d>>2]=k;be(g|0,64,285248,(h=i,i=i+16|0,c[h>>2]=(c[2313830]|0)+5,c[h+8>>2]=539096,h)|0)|0;i=h;k=fS(b|0,g|0)|0;L13098:do{if((k|0)>-1){n=k}else{j=0;while(1){if(j>>>0>=2){n=-1;break L13098}be(g|0,64,285248,(h=i,i=i+16|0,c[h>>2]=c[48920+(j<<2)>>2],c[h+8>>2]=539096,h)|0)|0;i=h;l=b3(b|0,g|0)|0;if((l|0)>-1){n=l;break}else{j=j+1|0}}}}while(0);c[d+4>>2]=n;be(g|0,64,285248,(h=i,i=i+16|0,c[h>>2]=(c[2313830]|0)+5,c[h+8>>2]=525680,h)|0)|0;i=h;n=fS(b|0,g|0)|0;L13103:do{if((n|0)>-1){o=n}else{k=0;while(1){if(k>>>0>=2){o=-1;break L13103}be(g|0,64,285248,(h=i,i=i+16|0,c[h>>2]=c[48920+(k<<2)>>2],c[h+8>>2]=525680,h)|0)|0;i=h;j=b3(b|0,g|0)|0;if((j|0)>-1){o=j;break}else{k=k+1|0}}}}while(0);c[d+8>>2]=o;be(g|0,64,285248,(h=i,i=i+16|0,c[h>>2]=(c[2313830]|0)+5,c[h+8>>2]=512072,h)|0)|0;i=h;o=fS(b|0,g|0)|0;L13108:do{if((o|0)>-1){p=o}else{n=0;while(1){if(n>>>0>=2){p=-1;break L13108}be(g|0,64,285248,(h=i,i=i+16|0,c[h>>2]=c[48920+(n<<2)>>2],c[h+8>>2]=512072,h)|0)|0;i=h;k=b3(b|0,g|0)|0;if((k|0)>-1){p=k;break}else{n=n+1|0}}}}while(0);c[d+12>>2]=p;be(g|0,64,285248,(h=i,i=i+16|0,c[h>>2]=(c[2313830]|0)+5,c[h+8>>2]=499240,h)|0)|0;i=h;p=fS(b|0,g|0)|0;L13113:do{if((p|0)>-1){q=p}else{o=0;while(1){if(o>>>0>=2){q=-1;break L13113}be(g|0,64,285248,(h=i,i=i+16|0,c[h>>2]=c[48920+(o<<2)>>2],c[h+8>>2]=499240,h)|0)|0;i=h;n=b3(b|0,g|0)|0;if((n|0)>-1){q=n;break}else{o=o+1|0}}}}while(0);c[d+16>>2]=q;be(g|0,64,285248,(h=i,i=i+16|0,c[h>>2]=(c[2313830]|0)+5,c[h+8>>2]=487776,h)|0)|0;i=h;q=fS(b|0,g|0)|0;L13118:do{if((q|0)>-1){r=q}else{p=0;while(1){if(p>>>0>=2){r=-1;break L13118}be(g|0,64,285248,(h=i,i=i+16|0,c[h>>2]=c[48920+(p<<2)>>2],c[h+8>>2]=487776,h)|0)|0;i=h;o=fS(b|0,g|0)|0;if((o|0)>-1){r=o;break}else{p=p+1|0}}}}while(0);c[d+20>>2]=r;be(g|0,64,285248,(h=i,i=i+16|0,c[h>>2]=(c[2313830]|0)+5,c[h+8>>2]=474848,h)|0)|0;i=h;r=fS(b|0,g|0)|0;L13123:do{if((r|0)>-1){s=r}else{q=0;while(1){if(q>>>0>=2){s=-1;break L13123}be(g|0,64,285248,(h=i,i=i+16|0,c[h>>2]=c[48920+(q<<2)>>2],c[h+8>>2]=474848,h)|0)|0;i=h;p=fS(b|0,g|0)|0;if((p|0)>-1){s=p;break}else{q=q+1|0}}}}while(0);c[d+24>>2]=s;be(g|0,64,285248,(h=i,i=i+16|0,c[h>>2]=(c[2313830]|0)+5,c[h+8>>2]=463408,h)|0)|0;i=h;s=fS(b|0,g|0)|0;L13128:do{if((s|0)>-1){t=s}else{r=0;while(1){if(r>>>0>=2){t=-1;break L13128}be(g|0,64,285248,(h=i,i=i+16|0,c[h>>2]=c[48920+(r<<2)>>2],c[h+8>>2]=463408,h)|0)|0;i=h;q=fS(b|0,g|0)|0;if((q|0)>-1){t=q;break}else{r=r+1|0}}}}while(0);c[d+28>>2]=t;be(g|0,64,285248,(h=i,i=i+16|0,c[h>>2]=(c[2313830]|0)+5,c[h+8>>2]=452232,h)|0)|0;i=h;t=fS(b|0,g|0)|0;L13133:do{if((t|0)>-1){u=t}else{s=0;while(1){if(s>>>0>=2){u=-1;break L13133}be(g|0,64,285248,(h=i,i=i+16|0,c[h>>2]=c[48920+(s<<2)>>2],c[h+8>>2]=452232,h)|0)|0;i=h;r=fS(b|0,g|0)|0;if((r|0)>-1){u=r;break}else{s=s+1|0}}}}while(0);c[d+32>>2]=u;be(g|0,64,285248,(h=i,i=i+16|0,c[h>>2]=(c[2313830]|0)+5,c[h+8>>2]=441496,h)|0)|0;i=h;u=fS(b|0,g|0)|0;L13138:do{if((u|0)>-1){v=u}else{t=0;while(1){if(t>>>0>=2){v=-1;break L13138}be(g|0,64,285248,(h=i,i=i+16|0,c[h>>2]=c[48920+(t<<2)>>2],c[h+8>>2]=441496,h)|0)|0;i=h;s=fS(b|0,g|0)|0;if((s|0)>-1){v=s;break}else{t=t+1|0}}}}while(0);c[d+40>>2]=v;v=c[2313830]|0;if((c[v+66380>>2]|0)!=0){g=0;u=v;do{c[d+44+(g<<2)>>2]=fS(b|0,u+66384+(g*4168|0)|0)|0;g=g+1|0;u=c[2313830]|0;}while(g>>>0<(c[u+66380>>2]|0)>>>0)}u=d+76|0;gGz(u|0,-1|0,16);k5(b,u,429704);g=f|0;if(a>>>0>1){be(g|0,64,418496,(h=i,i=i+8|0,c[h>>2]=a,h)|0)|0;i=h;k5(b,u,g);w=0}else{w=0}while(1){u=w+1|0;be(g|0,64,406584,(h=i,i=i+8|0,c[h>>2]=u,h)|0)|0;i=h;f=d+92+(w<<4)|0;gGz(f|0,-1|0,16);k5(b,f,g);if((w|0)!=0&u>>>0<a>>>0){v=a-w|0;be(g|0,64,418496,(h=i,i=i+8|0,c[h>>2]=v,h)|0)|0;i=h;k5(b,f,g)}if(u>>>0<16){w=u}else{break}}w=d+348|0;gGz(w|0,-1|0,16);k5(b,w,396192);be(g|0,64,383816,(h=i,i=i+8|0,c[h>>2]=1,h)|0)|0;i=h;w=d+364|0;gGz(w|0,-1|0,16);k5(b,w,g);be(g|0,64,383816,(h=i,i=i+8|0,c[h>>2]=2,h)|0)|0;i=h;w=d+380|0;gGz(w|0,-1|0,16);k5(b,w,g);be(g|0,64,383816,(h=i,i=i+8|0,c[h>>2]=3,h)|0)|0;i=h;w=d+396|0;gGz(w|0,-1|0,16);k5(b,w,g);be(g|0,64,383816,(h=i,i=i+8|0,c[h>>2]=4,h)|0)|0;i=h;w=d+412|0;gGz(w|0,-1|0,16);k5(b,w,g);be(g|0,64,383816,(h=i,i=i+8|0,c[h>>2]=5,h)|0)|0;i=h;w=d+428|0;gGz(w|0,-1|0,16);k5(b,w,g);be(g|0,64,383816,(h=i,i=i+8|0,c[h>>2]=6,h)|0)|0;i=h;h=d+444|0;gGz(h|0,-1|0,16);k5(b,h,g);dc(0);i=e;return}function k5(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=i;i=i+320|0;f=e|0;g=e+64|0;be(g|0,64,285248,(h=i,i=i+16|0,c[h>>2]=d,c[h+8>>2]=364224,h)|0)|0;i=h;j=e+128|0;be(j|0,64,285248,(h=i,i=i+16|0,c[h>>2]=d,c[h+8>>2]=463408,h)|0)|0;i=h;k=e+192|0;be(k|0,64,285248,(h=i,i=i+16|0,c[h>>2]=d,c[h+8>>2]=487776,h)|0)|0;i=h;l=e+256|0;be(l|0,64,285248,(h=i,i=i+16|0,c[h>>2]=d,c[h+8>>2]=539096,h)|0)|0;i=h;d=b|0;if((c[d>>2]|0)<0){m=f|0;n=(c[2313830]|0)+5|0;be(m|0,64,285248,(h=i,i=i+16|0,c[h>>2]=n,c[h+8>>2]=g,h)|0)|0;i=h;n=fS(a|0,m|0)|0;L13158:do{if((n|0)>-1){o=n}else{p=0;while(1){if(p>>>0>=2){o=-1;break L13158}be(m|0,64,285248,(h=i,i=i+16|0,c[h>>2]=c[48920+(p<<2)>>2],c[h+8>>2]=g,h)|0)|0;i=h;q=fS(a|0,m|0)|0;if((q|0)>-1){o=q;break}else{p=p+1|0}}}}while(0);c[d>>2]=o}o=b+8|0;if((c[o>>2]|0)<0){d=f|0;m=(c[2313830]|0)+5|0;be(d|0,64,285248,(h=i,i=i+16|0,c[h>>2]=m,c[h+8>>2]=j,h)|0)|0;i=h;m=fS(a|0,d|0)|0;L13166:do{if((m|0)>-1){r=m}else{g=0;while(1){if(g>>>0>=2){r=-1;break L13166}be(d|0,64,285248,(h=i,i=i+16|0,c[h>>2]=c[48920+(g<<2)>>2],c[h+8>>2]=j,h)|0)|0;i=h;n=fS(a|0,d|0)|0;if((n|0)>-1){r=n;break}else{g=g+1|0}}}}while(0);c[o>>2]=r}r=b+4|0;if((c[r>>2]|0)<0){o=f|0;d=(c[2313830]|0)+5|0;be(o|0,64,285248,(h=i,i=i+16|0,c[h>>2]=d,c[h+8>>2]=k,h)|0)|0;i=h;d=fS(a|0,o|0)|0;L13174:do{if((d|0)>-1){s=d}else{j=0;while(1){if(j>>>0>=2){s=-1;break L13174}be(o|0,64,285248,(h=i,i=i+16|0,c[h>>2]=c[48920+(j<<2)>>2],c[h+8>>2]=k,h)|0)|0;i=h;m=fS(a|0,o|0)|0;if((m|0)>-1){s=m;break}else{j=j+1|0}}}}while(0);c[r>>2]=s}s=b+12|0;if((c[s>>2]|0)>=0){i=e;return}b=f|0;be(b|0,64,285248,(h=i,i=i+16|0,c[h>>2]=(c[2313830]|0)+5,c[h+8>>2]=l,h)|0)|0;i=h;f=fS(a|0,b|0)|0;L13183:do{if((f|0)>-1){t=f}else{r=0;while(1){if(r>>>0>=2){t=-1;break L13183}be(b|0,64,285248,(h=i,i=i+16|0,c[h>>2]=c[48920+(r<<2)>>2],c[h+8>>2]=l,h)|0)|0;i=h;o=b3(a|0,b|0)|0;if((o|0)>-1){t=o;break}else{r=r+1|0}}}}while(0);c[s>>2]=t;i=e;return}function k6(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+72|0;g=f|0;h=f+8|0;j=f+48|0;k=f+64|0;l=f+16|0;gGz(l|0,0,32);do{if((a[9255352]&1)!=0){if((e3(e|0,240624)|0)!=0){break}m=((c[2313832]|0)*10|0)+((c[2313834]|0)*100|0)|0;if((m|0)==300){n=130}else if((m|0)==310){n=140}else if((m|0)==320){n=150}else{n=m}be(l|0,32,234320,(o=i,i=i+8|0,c[o>>2]=n,o)|0)|0;i=o;if((a[9375104]&1)==0){break}m=c[u>>2]|0;bU(m|0,227960,(o=i,i=i+8|0,c[o>>2]=n,o)|0)|0;i=o;eY(m|0)|0}}while(0);n=j|0;c[n>>2]=l;c[j+4>>2]=d;c[j+8>>2]=e;fv(b|0,3,n|0,0);a3(b|0);cS(b|0,35713,k|0);c[g>>2]=0;cS(b|0,35716,h|0);n=c[h>>2]|0;if((n|0)==0){p=c[k>>2]|0;q=(p|0)==1;i=f;return q|0}h=gGq(n)|0;if((h|0)==0){p=c[k>>2]|0;q=(p|0)==1;i=f;return q|0}eD(b|0,n|0,g|0,h|0);do{if((c[g>>2]|0)>0){if((a[9375104]&1)==0){break}n=c[u>>2]|0;bU(n|0,222072,(o=i,i=i+8|0,c[o>>2]=h,o)|0)|0;i=o;eY(n|0)|0}}while(0);gGr(h);p=c[k>>2]|0;q=(p|0)==1;i=f;return q|0}function k7(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;j=i;k=e|0;l=e+4|0;m=e+9|0;switch(d[m]|0){case 0:{n=d[e+8|0]|0;o=((ag(c[k>>2]|0,n)|0)+7|0)>>>3;p=(n+7|0)>>>3;break};case 2:{n=(d[e+8|0]|0)*3|0;o=((ag(n,c[k>>2]|0)|0)+7|0)>>>3;p=(n+7|0)>>>3;break};case 4:{n=d[e+8|0]<<1;o=((ag(n,c[k>>2]|0)|0)+7|0)>>>3;p=(n+7|0)>>>3;break};case 3:{n=d[e+8|0]|0;o=((ag(c[k>>2]|0,n)|0)+7|0)>>>3;p=(n+7|0)>>>3;break};case 6:{n=d[e+8|0]<<2;o=((ag(n,c[k>>2]|0)|0)+7|0)>>>3;p=(n+7|0)>>>3;break};default:{o=0;p=0}}n=o+1|0;if((ag(c[l>>2]|0,n)|0)>>>0>g>>>0){q=0;i=j;return q|0}g=gGq(o)|0;r=(g|0)==0;do{if(!r){if((c[g-4>>2]&3|0)==0){break}gGz(g|0,0,o|0)}}while(0);s=gGq(o)|0;L13226:do{if((s|0)==0){t=9450}else{if((c[s-4>>2]&3|0)!=0){gGz(s|0,0,o|0)}if(r){t=9450;break}if((c[l>>2]|0)==0){v=1;break}w=e+8|0;x=(p|0)==0;y=(o|0)==0;z=0;A=f;B=b;L13233:while(1){L13235:do{switch(d[A]|0){case 0:{gGC(s|0,A+1|0,o)|0;break};case 4:{if(x){C=0}else{D=0;while(1){E=D+1|0;a[s+D|0]=(a[A+E|0]|0)+(a[g+D|0]|0)&255;if(E>>>0<p>>>0){D=E}else{C=p;break}}}if(C>>>0<o>>>0){F=C}else{break L13235}while(1){D=F-C|0;E=a[s+D|0]|0;G=E&255;H=a[g+F|0]|0;I=H&255;J=a[g+D|0]|0;D=J&255;K=I+G-D|0;L=K-G|0;G=(L|0)>-1?L:-L|0;L=K-I|0;I=(L|0)>-1?L:-L|0;L=K-D|0;D=(L|0)>-1?L:-L|0;if((G|0)>(I|0)|(G|0)>(D|0)){M=(I|0)>(D|0)?J:H}else{M=E}E=F+1|0;a[s+F|0]=(a[A+E|0]|0)+M&255;if(E>>>0<o>>>0){F=E}else{break}}break};case 2:{if(y){break L13235}else{N=0}while(1){E=N+1|0;a[s+N|0]=(a[A+E|0]|0)+(a[g+N|0]|0)&255;if(E>>>0<o>>>0){N=E}else{break}}break};case 3:{if(x){O=0}else{E=0;while(1){H=E+1|0;a[s+E|0]=((d[g+E|0]|0)>>>1)+(a[A+H|0]|0)&255;if(H>>>0<p>>>0){E=H}else{O=p;break}}}if(O>>>0<o>>>0){P=O}else{break L13235}while(1){E=P+1|0;a[s+P|0]=(((d[g+P|0]|0)+(d[s+(P-O)|0]|0)|0)>>>1)+(d[A+E|0]|0)&255;if(E>>>0<o>>>0){P=E}else{break}}break};case 1:{if(x){Q=0}else{E=0;while(1){H=E+1|0;a[s+E|0]=a[A+H|0]|0;if(H>>>0<p>>>0){E=H}else{Q=p;break}}}if(Q>>>0<o>>>0){R=Q}else{break L13235}while(1){E=R+1|0;a[s+R|0]=(a[A+E|0]|0)+(a[s+(R-Q)|0]|0)&255;if(E>>>0<o>>>0){R=E}else{break}}break};default:{break L13233}}}while(0);L13265:do{switch(a[m]|0){case 0:{E=c[k>>2]|0;H=a[w]|0;J=H&255;if(H<<24>>24==16){if((E|0)==0){break L13265}else{S=0}while(1){c[B+(S<<2)>>2]=(d[s+(S<<1)|0]|0)*65793|0|-16777216;S=S+1|0;if(S>>>0>=E>>>0){break L13265}}}H=(1<<J)-1|0;if((E|0)==0){break L13265}D=8-J|0;I=(c[61616+(J<<2)>>2]|0)*65793|0;G=0;L=0;while(1){c[B+(L<<2)>>2]=ag(I,(d[s+(G>>>3)|0]|0)>>>((D-(G&7)|0)>>>0)&H)|0|-16777216;K=L+1|0;if(K>>>0<E>>>0){G=G+J|0;L=K}else{break}}break};case 4:{L=c[k>>2]|0;J=(d[w]|0)>>>3;if((L|0)==0){break L13265}G=J<<1;E=0;H=s;while(1){c[B+(E<<2)>>2]=d[H+J|0]<<24|((d[H]|0)*65793|0);D=E+1|0;if(D>>>0<L>>>0){E=D;H=H+G|0}else{break}}break};case 6:{G=c[k>>2]|0;H=(d[w]|0)>>>3;if((G|0)==0){break L13265}E=H<<1;L=E+H|0;J=L+H|0;D=0;I=s;while(1){c[B+(D<<2)>>2]=d[I+H|0]<<8|d[I]<<16|d[I+E|0]|d[I+L|0]<<24;K=D+1|0;if(K>>>0<G>>>0){D=K;I=I+J|0}else{break}}break};case 2:{J=c[k>>2]|0;I=(d[w]|0)>>>3;if((J|0)==0){break L13265}D=I<<1;G=D+I|0;L=0;E=s;while(1){c[B+(L<<2)>>2]=d[E]<<16|d[E+I|0]<<8|d[E+D|0]|-16777216;H=L+1|0;if(H>>>0<J>>>0){L=H;E=E+G|0}else{break}}break};case 3:{G=c[k>>2]|0;E=d[w]|0;L=(1<<E)-1|0;if((G|0)==0){break L13265}J=8-E|0;D=0;I=0;while(1){c[B+(I<<2)>>2]=c[h+(((d[s+(D>>>3)|0]|0)>>>((J-(D&7)|0)>>>0)&L)<<2)>>2];H=I+1|0;if(H>>>0<G>>>0){D=D+E|0;I=H}else{break}}break};default:{}}}while(0);gGC(g|0,s|0,o)|0;I=z+1|0;if(I>>>0<(c[l>>2]|0)>>>0){z=I;A=A+n|0;B=B+(c[k>>2]<<2)|0}else{v=1;break L13226}}bU(c[u>>2]|0,557472,(T=i,i=i+8|0,c[T>>2]=449,T)|0)|0;i=T;v=0}}while(0);if((t|0)==9450){t=c[u>>2]|0;bU(t|0,557472,(T=i,i=i+8|0,c[T>>2]=404,T)|0)|0;i=T;v=0}gGr(s);gGr(g);q=v;i=j;return q|0}function k8(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;g=i;i=i+4096|0;h=g|0;j=gGq(8)|0;do{if((j|0)==0){k=c[u>>2]|0}else{if((c[j-4>>2]&3|0)!=0){l=j;m=l|0;C=0;a[m]=C&255;C=C>>8;a[m+1|0]=C&255;C=C>>8;a[m+2|0]=C&255;C=C>>8;a[m+3|0]=C&255;m=l+4|0;C=0;a[m]=C&255;C=C>>8;a[m+1|0]=C&255;C=C>>8;a[m+2|0]=C&255;C=C>>8;a[m+3|0]=C&255}m=j;l=hx(b,m)|0;if((l|0)<0){n=c[u>>2]|0;bU(n|0,127952,(o=i,i=i+8|0,c[o>>2]=b,o)|0)|0;i=o;eY(n|0)|0;gGr(c[m>>2]|0);gGr(j);k=n;break}c[j+4>>2]=l;L13307:do{if((l|0)<22){n=c[u>>2]|0;bU(n|0,557312,(o=i,i=i+8|0,c[o>>2]=252,o)|0)|0;i=o;eY(n|0)|0;p=0}else{n=c[m>>2]|0;q=n+l|0;r=l-22|0;s=n+22|0;L13310:do{if((r|0)>22){t=n+r|0;while(1){if(((d[t+1|0]|0)<<8|(d[t]|0)|(d[t+2|0]|0)<<16|(d[t+3|0]|0)<<24|0)==101010256){if((t+(((d[t+21|0]|0)<<8|(d[t+20|0]|0))+22)|0)==(q|0)){break}}v=t-1|0;if(v>>>0>s>>>0){t=v}else{break L13310}}v=(d[t+17|0]|0)<<8|(d[t+16|0]|0)|(d[t+18|0]|0)<<16|(d[t+19|0]|0)<<24;w=n+v|0;x=h|0;if(((d[n+(v+1)|0]|0)<<8|(d[w]|0)|(d[n+(v+2)|0]|0)<<16|(d[n+(v+3)|0]|0)<<24|0)==33639248){y=w}else{p=1;break L13307}while(1){w=a[y+10|0]|0;v=a[y+11|0]|0;z=a[y+16|0]|0;A=a[y+17|0]|0;B=a[y+18|0]|0;D=a[y+19|0]|0;E=a[y+20|0]|0;F=a[y+21|0]|0;G=a[y+22|0]|0;H=a[y+23|0]|0;I=a[y+24|0]|0;J=a[y+25|0]|0;K=a[y+26|0]|0;L=a[y+27|0]|0;M=(d[y+29|0]|0)<<8|(d[y+28|0]|0);N=(d[y+33|0]|0)<<8|(d[y+32|0]|0);O=(d[y+31|0]|0)<<8|(d[y+30|0]|0);gGz(x|0,0,4096);if(M>>>0>4095){break}P=(v&255)<<8|w&255;w=(J&255)<<8|I&255|(K&255)<<16|(L&255)<<24;L=(F&255)<<8|E&255|(G&255)<<16|(H&255)<<24;H=(A&255)<<8|z&255|(B&255)<<16|(D&255)<<24;D=y+46|0;gGC(x|0,D|0,M)|0;D=(d[y+43|0]|0)<<8|(d[y+42|0]|0)|(d[y+44|0]|0)<<16|(d[y+45|0]|0)<<24;if(!(gc[e&7](x,n+(D+30+((d[n+(D+27)|0]|0)<<8|(d[n+(D+26)|0]|0))+((d[n+(D+29)|0]|0)<<8|(d[n+(D+28)|0]|0)))|0,P,L,w,H,f)|0)){p=1;break L13307}H=M+46+O+N|0;N=y+H|0;if(((d[y+(H+1)|0]|0)<<8|(d[N]|0)|(d[y+(H+2)|0]|0)<<16|(d[y+(H+3)|0]|0)<<24|0)==33639248){y=N}else{p=1;break L13307}}x=c[u>>2]|0;bU(x|0,557312,(o=i,i=i+8|0,c[o>>2]=288,o)|0)|0;i=o;eY(x|0)|0;p=0;break L13307}}while(0);n=c[u>>2]|0;bU(n|0,557312,(o=i,i=i+8|0,c[o>>2]=260,o)|0)|0;i=o;eY(n|0)|0;p=0}}while(0);gGr(c[m>>2]|0);gGr(j);Q=p;i=g;return Q|0}}while(0);bU(k|0,557312,(o=i,i=i+8|0,c[o>>2]=248,o)|0)|0;i=o;eY(k|0)|0;Q=0;i=g;return Q|0}function k9(b,d,e,f,g,h,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;k=i;i=i+4152|0;l=k|0;m=k+56|0;n=cE(b|0,47)|0;o=cE(((n|0)==0?b:n+1|0)|0,46)|0;n=(o|0)==0?9534384:o+1|0;if((n|0)==0){p=1;i=k;return p|0}o=c[j+8>>2]|0;if((o|0)==0){p=1;i=k;return p|0}q=o|0;r=c[o+4>>2]|0;o=0;while(1){if(o>>>0>=r>>>0){p=1;s=9568;break}if((gGF(c[(c[q>>2]|0)+(o<<3)>>2]|0,n|0)|0)==0){break}else{o=o+1|0}}if((s|0)==9568){i=k;return p|0}o=m|0;m=j;n=c[m>>2]|0;q=cE(b|0,47)|0;hM(o,n,(q|0)==0?b:q+1|0);if((e|0)==0){q=fw(o|0,389440)|0;if((q|0)==0){t=0}else{b=(cj(d|0,1,g|0,q|0)|0)==(g|0);aY(q|0)|0;t=b&1}a[j+12|0]=t;p=0;i=k;return p|0}else if((e|0)==8){e=gGq(g)|0;if((e|0)==0){p=0;i=k;return p|0}t=l+24|0;gGz(l|0,0,56);c[l+32>>2]=7122;b=l+40|0;c[b>>2]=0;q=l+36|0;c[q>>2]=494;n=gGq(7116)|0;L13352:do{if((n|0)==0){s=9538}else{r=l+28|0;c[r>>2]=n;c[n+52>>2]=0;v=c[r>>2]|0;do{if((v|0)!=0){w=v+52|0;x=c[w>>2]|0;y=v+36|0;do{if((x|0)!=0){if((c[y>>2]|0)==15){break}gg[c[q>>2]&4095](c[b>>2]|0,x);c[w>>2]=0}}while(0);c[v+8>>2]=0;c[y>>2]=15;w=c[r>>2]|0;if((w|0)==0){break}c[w+40>>2]=0;c[w+44>>2]=0;c[w+48>>2]=0;w=c[r>>2]|0;if((w|0)==0){break}c[w+28>>2]=0;c[l+20>>2]=0;c[l+8>>2]=0;c[t>>2]=0;x=c[w+8>>2]|0;if((x|0)!=0){c[l+48>>2]=x&1}c[w>>2]=0;c[w+4>>2]=0;c[w+12>>2]=0;c[w+20>>2]=32768;c[w+32>>2]=0;c[w+56>>2]=0;c[w+60>>2]=0;x=w+1328|0;c[w+108>>2]=x;c[w+80>>2]=x;c[w+76>>2]=x;c[w+7104>>2]=1;c[w+7108>>2]=-1;c[l>>2]=d;c[l+4>>2]=f;c[l+12>>2]=e;c[l+16>>2]=g;w=(RS(l,4)|0)==1;x=c[r>>2]|0;do{if((x|0)!=0){z=c[q>>2]|0;if((z|0)==0){break}A=c[x+52>>2]|0;if((A|0)==0){B=z;C=x}else{gg[z&4095](c[b>>2]|0,A);B=c[q>>2]|0;C=c[r>>2]|0}gg[B&4095](c[b>>2]|0,C);c[r>>2]=0}}while(0);if(!w){x=c[u>>2]|0;bU(x|0,557312,(D=i,i=i+8|0,c[D>>2]=216,D)|0)|0;i=D;eY(x|0)|0;break L13352}x=RK(0,e,g)|0;if((x|0)!=(h|0)){y=c[u>>2]|0;bU(y|0,431992,(D=i,i=i+16|0,c[D>>2]=x,c[D+8>>2]=h,D)|0)|0;i=D;eY(y|0)|0}y=fw(o|0,389440)|0;do{if((y|0)!=0){x=(cj(e|0,1,g|0,y|0)|0)==(g|0);aY(y|0)|0;if(!x){break}gGr(e);x=c[j+4>>2]|0;L13381:do{if((x|0)==0){E=o;s=9557}else{A=x;z=c[m>>2]|0;F=o;while(1){G=A-1|0;if((G|0)==0){break}H=a[F]|0;a[z]=H;if(H<<24>>24==0){break L13381}else{A=G;z=z+1|0;F=F+1|0}}a[z]=0;E=F;s=9557}}while(0);do{if((s|0)==9557){if((a[E]|0)==0){break}else{I=E}do{I=I+1|0;}while((a[I]|0)!=0)}}while(0);a[j+12|0]=1;p=0;i=k;return p|0}}while(0);y=c[u>>2]|0;bU(y|0,557312,(D=i,i=i+8|0,c[D>>2]=226,D)|0)|0;i=D;eY(y|0)|0;break L13352}}while(0);gg[c[q>>2]&4095](c[b>>2]|0,n);c[r>>2]=0;s=9538}}while(0);if((s|0)==9538){s=c[u>>2]|0;bU(s|0,557312,(D=i,i=i+8|0,c[D>>2]=206,D)|0)|0;i=D;eY(s|0)|0}gGr(e);p=0;i=k;return p|0}else{p=0;i=k;return p|0}return 0}function la(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;return hz(g,a,0)|0}function lb(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return ew(c|0,1,d|0,b|0)|0}function lc(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return cj(c|0,1,d|0,b|0)|0}function ld(a,b){a=a|0;b=b|0;return aY(b|0)|0}function le(a,b){a=a|0;b=b|0;return cI(b|0)|0}function lf(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;do{if((c&3|0)==1){d=364392}else{if((c&4|0)!=0){d=557016;break}d=(c&8|0)==0?0:389440}}while(0);if((b|0)==0|(d|0)==0){e=0;return e|0}e=fw(b|0,d|0)|0;return e|0}function lg(a,b){a=a|0;b=b|0;a=fl(b|0)|0;return(K=(a|0)<0|0?-1:0,a)|0}function lh(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;if(e>>>0>=3){f=-1;return f|0}f=((dh(b|0,c|0,e|0)|0)!=0)<<31>>31;return f|0}function li(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0;e=i;i=i+408|0;f=e|0;g=e+8|0;h=e+16|0;j=e+24|0;k=e+32|0;l=e+40|0;m=e+48|0;n=e+56|0;o=e+64|0;p=e+72|0;q=e+80|0;r=e+88|0;s=e+96|0;t=e+104|0;u=e+112|0;v=e+120|0;w=e+128|0;x=e+368|0;y=e+376|0;z=e+384|0;A=e+392|0;B=e+400|0;C=w|0;D=w+40|0;c[D>>2]=0;E=w+36|0;c[E>>2]=0;c[w>>2]=8166;F=w+4|0;c[F>>2]=10;c[w+8>>2]=6;G=w+12|0;c[G>>2]=1682;H=w+16|0;c[H>>2]=658;I=w+20|0;c[I>>2]=14862;J=w+24|0;c[J>>2]=2972;L=w+28|0;c[L>>2]=0;c[w+44>>2]=0;if((b|0)==0){c[w+48>>2]=0;M=0;i=e;return M|0}N=fw(b|0,364392)|0;b=N;O=w+48|0;c[O>>2]=b;if((N|0)==0){M=0;i=e;return M|0}N=c[H>>2]|0;if((N|0)==0){P=gJ[c[D>>2]&31](c[L>>2]|0,b,0,2)|0}else{P=gF[N&2047](c[L>>2]|0,b,0,0,2)|0}L13431:do{if((P|0)==0){if((c[H>>2]|0)==0){N=gA[c[E>>2]&16383](c[L>>2]|0,b)|0;Q=(N|0)==-1;R=Q?-1:0;S=Q?-1:N}else{N=gA[c[G>>2]&16383](c[L>>2]|0,b)|0;R=K;S=N}N=0;Q=R>>>0<N>>>0|R>>>0==N>>>0&S>>>0<65535>>>0;N=Q?S:65535;T=Q?R:0;Q=gGq(1028)|0;if((Q|0)==0){U=9650;break}V=0;L13438:do{if(T>>>0>V>>>0|T>>>0==V>>>0&N>>>0>4>>>0){W=0;X=4;L13439:while(1){Y=gGK(X,W,1024,0)|0;Z=K;_=Z>>>0>T>>>0|Z>>>0==T>>>0&Y>>>0>N>>>0;X=_?N:Y;W=_?T:Z;Z=gGL(S,R,X,W)|0;_=K;Y=0;$=W>>>0>Y>>>0|W>>>0==Y>>>0&X>>>0>1028>>>0?1028:X;Y=c[H>>2]|0;if((Y|0)==0){if(!((Z|0|0)==(Z|0)&(_&0|0)==(_|0))){break L13438}aa=gJ[c[D>>2]&31](c[L>>2]|0,b,Z,0)|0}else{aa=gF[Y&2047](c[L>>2]|0,b,Z,_,0)|0}if((aa|0)!=0){break L13438}if((gJ[c[F>>2]&31](c[L>>2]|0,b,Q,$)|0)!=($|0)){break L13438}Y=$-3|0;L13448:do{if((Y|0)>0){ab=Y;ac=$-4|0;L13450:while(1){do{if((a[Q+ac|0]|0)==80){if((a[Q+ab|0]|0)!=75){break}if((a[Q+(ab+1)|0]|0)!=6){break}if((a[Q+(ab+2)|0]|0)==7){break L13450}}}while(0);if((ac|0)>0){ab=ac;ac=ac-1|0}else{break L13448}}ad=gGK(ac,(ac|0)<0|0?-1:0,Z,_)|0;ae=K;if(!((ad|0)==0&(ae|0)==0)){break L13439}}}while(0);if(!(W>>>0<T>>>0|W>>>0==T>>>0&X>>>0<N>>>0)){break L13438}}gGr(Q);X=c[H>>2]|0;if((X|0)==0){if(!((ad|0|0)==(ad|0)&(ae&0|0)==(ae|0))){U=9650;break L13431}af=gJ[c[D>>2]&31](c[L>>2]|0,b,ad,0)|0}else{af=gF[X&2047](c[L>>2]|0,b,ad,ae,0)|0}if((af|0)!=0){U=9650;break L13431}if((lo(C,b,u)|0)!=0){U=9650;break L13431}X=lo(C,b,u)|0;if((c[u>>2]|X|0)!=0){U=9650;break L13431}if((lp(C,b,v)|0)!=0){U=9650;break L13431}X=(lo(C,b,u)|0)==0;if(!(X&(c[u>>2]|0)==1)){U=9650;break L13431}X=c[v>>2]|0;W=c[v+4>>2]|0;_=c[H>>2]|0;if((_|0)==0){if(!((X|0|0)==(X|0)&(W&0|0)==(W|0))){U=9650;break L13431}ag=gJ[c[D>>2]&31](c[L>>2]|0,b,X,0)|0}else{ag=gF[_&2047](c[L>>2]|0,b,X,W,0)|0}if((ag|0)!=0){U=9650;break L13431}_=(lo(C,b,u)|0)==0;Z=_&(c[u>>2]|0)==101075792;_=Z?X:0;X=Z?W:0;if((_|0)==0&(X|0)==0){U=9650;break L13431}c[w+232>>2]=1;W=c[O>>2]|0;Z=c[H>>2]|0;do{if((Z|0)==0){if(!((_|0|0)==(_|0)&(X&0|0)==(X|0))){ah=-1;break}ah=gJ[c[D>>2]&31](c[L>>2]|0,W,_,0)|0}else{ah=gF[Z&2047](c[L>>2]|0,W,_,X,0)|0}}while(0);W=(lo(C,c[O>>2]|0,x)|0)==0;Z=(lp(C,c[O>>2]|0,B)|0)==0;$=Z?W?((ah|0)!=0)<<31>>31:-1:-1;W=c[O>>2]|0;if((gJ[c[F>>2]&31](c[L>>2]|0,W,t,1)|0)==1){U=9637}else{Z=(gA[c[J>>2]&16383](c[L>>2]|0,W)|0)!=0;if(Z){ai=Z<<31>>31}else{U=9637}}do{if((U|0)==9637){if((gJ[c[F>>2]&31](c[L>>2]|0,W,s,1)|0)!=1){Z=(gA[c[J>>2]&16383](c[L>>2]|0,W)|0)!=0;if(Z){ai=Z<<31>>31;break}}ai=0}}while(0);W=(ai|0)==0?$:-1;Z=c[O>>2]|0;if((gJ[c[F>>2]&31](c[L>>2]|0,Z,r,1)|0)==1){U=9642}else{Y=(gA[c[J>>2]&16383](c[L>>2]|0,Z)|0)!=0;if(Y){aj=Y<<31>>31}else{U=9642}}do{if((U|0)==9642){if((gJ[c[F>>2]&31](c[L>>2]|0,Z,q,1)|0)!=1){Y=(gA[c[J>>2]&16383](c[L>>2]|0,Z)|0)!=0;if(Y){aj=Y<<31>>31;break}}aj=0}}while(0);Z=(lo(C,c[O>>2]|0,y)|0)==0;$=(lo(C,c[O>>2]|0,z)|0)==0;Y=w+56|0;ab=(lp(C,c[O>>2]|0,Y)|0)==0;ak=(lp(C,c[O>>2]|0,A)|0)==0;al=ak?ab?$?Z?(aj|0)==0?W:-1:-1:-1:-1:-1;do{if((c[A>>2]|0)==(c[Y>>2]|0)&(c[A+4>>2]|0)==(c[Y+4>>2]|0)){if((c[z>>2]|0)!=0){U=9648;break}if((c[y>>2]|0)==0){am=al}else{U=9648}}else{U=9648}}while(0);if((U|0)==9648){am=-103}al=(lp(C,c[O>>2]|0,w+112|0)|0)==0;Y=(lp(C,c[O>>2]|0,w+120|0)|0)==0;c[w+64>>2]=0;an=Y?al?am:-1:-1;ao=X;ap=_;break L13431}}while(0);gGr(Q);U=9650}else{U=9650}}while(0);if((U|0)==9650){am=c[O>>2]|0;aj=c[H>>2]|0;if((aj|0)==0){aq=gJ[c[D>>2]&31](c[L>>2]|0,am,0,2)|0}else{aq=gF[aj&2047](c[L>>2]|0,am,0,0,2)|0}do{if((aq|0)==0){if((c[H>>2]|0)==0){aj=gA[c[E>>2]&16383](c[L>>2]|0,am)|0;q=(aj|0)==-1;ar=q?-1:0;as=q?-1:aj}else{aj=gA[c[G>>2]&16383](c[L>>2]|0,am)|0;ar=K;as=aj}aj=0;q=ar>>>0<aj>>>0|ar>>>0==aj>>>0&as>>>0<65535>>>0;aj=q?as:65535;r=q?ar:0;q=gGq(1028)|0;if((q|0)==0){at=0;au=0;break}ai=0;L13518:do{if(r>>>0>ai>>>0|r>>>0==ai>>>0&aj>>>0>4>>>0){s=0;t=4;while(1){ah=gGK(t,s,1024,0)|0;B=K;u=B>>>0>r>>>0|B>>>0==r>>>0&ah>>>0>aj>>>0;b=u?aj:ah;ah=u?r:B;B=gGL(as,ar,b,ah)|0;u=K;ag=0;v=ah>>>0>ag>>>0|ah>>>0==ag>>>0&b>>>0>1028>>>0?1028:b;ag=c[H>>2]|0;if((ag|0)==0){if(!((B|0|0)==(B|0)&(u&0|0)==(u|0))){av=0;aw=0;break L13518}ax=gJ[c[D>>2]&31](c[L>>2]|0,am,B,0)|0}else{ax=gF[ag&2047](c[L>>2]|0,am,B,u,0)|0}if((ax|0)!=0){av=0;aw=0;break L13518}if((gJ[c[F>>2]&31](c[L>>2]|0,am,q,v)|0)!=(v|0)){av=0;aw=0;break L13518}ag=v-3|0;L13528:do{if((ag|0)>0){af=ag;ae=v-4|0;L13530:while(1){do{if((a[q+ae|0]|0)==80){if((a[q+af|0]|0)!=75){break}if((a[q+(af+1)|0]|0)!=5){break}if((a[q+(af+2)|0]|0)==6){break L13530}}}while(0);if((ae|0)>0){af=ae;ae=ae-1|0}else{break L13528}}af=gGK(ae,(ae|0)<0|0?-1:0,B,u)|0;ac=K;if(!((af|0)==0&(ac|0)==0)){av=ac;aw=af;break L13518}}}while(0);if(ah>>>0<r>>>0|ah>>>0==r>>>0&b>>>0<aj>>>0){s=ah;t=b}else{av=0;aw=0;break}}}else{av=0;aw=0}}while(0);gGr(q);at=av;au=aw}else{at=0;au=0}}while(0);aw=((au|0)==0&(at|0)==0)<<31>>31;c[w+232>>2]=0;av=c[O>>2]|0;am=c[H>>2]|0;do{if((am|0)==0){if(!((au|0|0)==(au|0)&(at&0|0)==(at|0))){ay=-1;break}ay=gJ[c[D>>2]&31](c[L>>2]|0,av,au,0)|0}else{ay=gF[am&2047](c[L>>2]|0,av,au,at,0)|0}}while(0);av=(lo(C,c[O>>2]|0,x)|0)==0;am=av?(ay|0)==0?aw:-1:-1;aw=c[O>>2]|0;if((gJ[c[F>>2]&31](c[L>>2]|0,aw,p,1)|0)==1){az=d[p]|0;U=9682}else{p=(gA[c[J>>2]&16383](c[L>>2]|0,aw)|0)!=0;if(p){aA=0;aB=p<<31>>31}else{az=0;U=9682}}do{if((U|0)==9682){if((gJ[c[F>>2]&31](c[L>>2]|0,aw,o,1)|0)==1){aC=d[o]|0}else{p=(gA[c[J>>2]&16383](c[L>>2]|0,aw)|0)!=0;if(p){aA=0;aB=p<<31>>31;break}else{aC=az}}aA=aC<<8|az;aB=0}}while(0);c[y>>2]=aA;y=(aB|0)==0?am:-1;am=c[O>>2]|0;if((gJ[c[F>>2]&31](c[L>>2]|0,am,n,1)|0)==1){aD=d[n]|0;U=9689}else{n=(gA[c[J>>2]&16383](c[L>>2]|0,am)|0)!=0;if(n){aE=0;aF=n<<31>>31}else{aD=0;U=9689}}do{if((U|0)==9689){if((gJ[c[F>>2]&31](c[L>>2]|0,am,m,1)|0)==1){aG=d[m]|0}else{n=(gA[c[J>>2]&16383](c[L>>2]|0,am)|0)!=0;if(n){aE=0;aF=n<<31>>31;break}else{aG=aD}}aE=aG<<8|aD;aF=0}}while(0);c[z>>2]=aE;z=(aF|0)==0?y:-1;y=c[O>>2]|0;if((gJ[c[F>>2]&31](c[L>>2]|0,y,l,1)|0)==1){aH=d[l]|0;U=9696}else{l=(gA[c[J>>2]&16383](c[L>>2]|0,y)|0)!=0;if(l){aI=0;aJ=l<<31>>31}else{aH=0;U=9696}}do{if((U|0)==9696){if((gJ[c[F>>2]&31](c[L>>2]|0,y,k,1)|0)==1){aK=d[k]|0}else{l=(gA[c[J>>2]&16383](c[L>>2]|0,y)|0)!=0;if(l){aI=0;aJ=l<<31>>31;break}else{aK=aH}}aI=aK<<8|aH;aJ=0}}while(0);c[x>>2]=aI;aH=(aJ|0)==0?z:-1;z=w+56|0;c[z>>2]=aI;c[z+4>>2]=0;aI=c[O>>2]|0;if((gJ[c[F>>2]&31](c[L>>2]|0,aI,j,1)|0)==1){aL=d[j]|0;U=9703}else{j=(gA[c[J>>2]&16383](c[L>>2]|0,aI)|0)!=0;if(j){aM=0;aN=j<<31>>31}else{aL=0;U=9703}}do{if((U|0)==9703){if((gJ[c[F>>2]&31](c[L>>2]|0,aI,h,1)|0)==1){aO=d[h]|0}else{j=(gA[c[J>>2]&16383](c[L>>2]|0,aI)|0)!=0;if(j){aM=0;aN=j<<31>>31;break}else{aO=aL}}aM=aO<<8|aL;aN=0}}while(0);c[x>>2]=aM;aL=aM;aM=0;c[A>>2]=aL;c[A+4>>2]=aM;A=(aL|0)==(c[z>>2]|0)&(aM|0)==(c[z+4>>2]|0)&(aE|0)==0&(aA|0)==0?(aN|0)==0?aH:-1:-103;aH=(lo(C,c[O>>2]|0,x)|0)==0;aN=w+112|0;c[aN>>2]=c[x>>2];c[aN+4>>2]=0;aN=(lo(C,c[O>>2]|0,x)|0)==0;C=aN?aH?A:-1:-1;A=w+120|0;c[A>>2]=c[x>>2];c[A+4>>2]=0;A=c[O>>2]|0;x=w+64|0;if((gJ[c[F>>2]&31](c[L>>2]|0,A,g,1)|0)==1){aP=d[g]|0;U=9710}else{g=(gA[c[J>>2]&16383](c[L>>2]|0,A)|0)!=0;if(g){aQ=0;aR=g<<31>>31}else{aP=0;U=9710}}do{if((U|0)==9710){if((gJ[c[F>>2]&31](c[L>>2]|0,A,f,1)|0)==1){aS=d[f]|0}else{g=(gA[c[J>>2]&16383](c[L>>2]|0,A)|0)!=0;if(g){aQ=0;aR=g<<31>>31;break}else{aS=aP}}aQ=aS<<8|aP;aR=0}}while(0);c[x>>2]=aQ;an=(aR|0)==0?C:-1;ao=at;ap=au}au=w+120|0;at=w+112|0;C=gGK(c[at>>2]|0,c[at+4>>2]|0,c[au>>2]|0,c[au+4>>2]|0)|0;au=K;if(!((an|0)==0&((an|0)!=0|ao>>>0>=au>>>0&(ao>>>0>au>>>0|ap>>>0>=C>>>0)))){an=c[I>>2]|0;I=c[L>>2]|0;L=c[O>>2]|0;gA[an&16383](I,L)|0;M=0;i=e;return M|0}L=gGL(ap,ao,C,au)|0;au=w+72|0;c[au>>2]=L;c[au+4>>2]=K;au=w+104|0;c[au>>2]=ap;c[au+4>>2]=ao;c[w+224>>2]=0;c[w+228>>2]=0;ao=gGq(240)|0;if((ao|0)==0){M=0;i=e;return M|0}au=w;gGC(ao|0,au|0,240)|0;au=ao+120|0;w=c[au+4>>2]|0;ap=ao+88|0;c[ap>>2]=c[au>>2];c[ap+4>>2]=w;w=ao+80|0;c[w>>2]=0;c[w+4>>2]=0;w=ao+96|0;c[w>>2]=(ll(ao,ao+128|0,ao+216|0,0,0)|0)==0;c[w+4>>2]=0;M=ao;i=e;return M|0}function lj(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if((a|0)==0){return}b=a+224|0;d=c[b>>2]|0;if((d|0)!=0){e=d|0;f=c[e>>2]|0;if((f|0)!=0){gGr(f)}c[e>>2]=0;do{if(!((c[d+72>>2]|0)!=8|(d+4|0)==0)){e=d+32|0;f=c[e>>2]|0;if((f|0)==0){break}g=d+40|0;h=c[g>>2]|0;if((h|0)==0){break}i=c[f+52>>2]|0;j=d+44|0;if((i|0)==0){k=h;l=f}else{gg[h&4095](c[j>>2]|0,i);k=c[g>>2]|0;l=c[e>>2]|0}gg[k&4095](c[j>>2]|0,l);c[e>>2]=0}}while(0);gGr(d);c[b>>2]=0}gA[c[a+20>>2]&16383](c[a+28>>2]|0,c[a+48>>2]|0)|0;gGr(a);return}function lk(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((a|0)==0){b=-102;return b|0}d=a+224|0;a=c[d>>2]|0;if((a|0)==0){b=-102;return b|0}e=a+128|0;do{if((c[e>>2]|0)==0&(c[e+4>>2]|0)==0){if((c[a+200>>2]|0)!=0){f=0;break}f=(c[a+112>>2]|0)==(c[a+116>>2]|0)?0:-105}else{f=0}}while(0);e=a|0;g=c[e>>2]|0;if((g|0)!=0){gGr(g)}c[e>>2]=0;do{if(!((c[a+72>>2]|0)!=8|(a+4|0)==0)){e=a+32|0;g=c[e>>2]|0;if((g|0)==0){break}h=a+40|0;i=c[h>>2]|0;if((i|0)==0){break}j=c[g+52>>2]|0;k=a+44|0;if((j|0)==0){l=i;m=g}else{gg[i&4095](c[k>>2]|0,j);l=c[h>>2]|0;m=c[e>>2]|0}gg[l&4095](c[k>>2]|0,m);c[e>>2]=0}}while(0);gGr(a);c[d>>2]=0;b=f;return b|0}function ll(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0;j=i;i=i+296|0;k=j|0;l=j+8|0;m=j+16|0;n=j+24|0;o=j+32|0;p=j+40|0;q=j+48|0;r=j+56|0;s=j+64|0;t=j+72|0;u=j+80|0;v=j+88|0;w=j+96|0;x=j+104|0;y=j+112|0;z=j+120|0;A=j+128|0;B=j+136|0;C=j+144|0;D=j+152|0;E=j+160|0;F=j+168|0;G=j+176|0;H=j+264|0;I=j+272|0;J=j+280|0;L=j+288|0;if((b|0)==0){M=-102;i=j;return M|0}N=b;O=b+48|0;P=c[O>>2]|0;Q=b+88|0;R=b+72|0;S=gGK(c[R>>2]|0,c[R+4>>2]|0,c[Q>>2]|0,c[Q+4>>2]|0)|0;Q=K;R=b+16|0;T=c[R>>2]|0;do{if((T|0)==0){if(!((S|0|0)==(S|0)&(Q&0|0)==(Q|0))){U=-1;break}V=gJ[c[b+40>>2]&31](c[b+28>>2]|0,P,S,0)|0;W=9763}else{V=gF[T&2047](c[b+28>>2]|0,P,S,Q,0)|0;W=9763}}while(0);do{if((W|0)==9763){Q=(V|0)==0;S=(Q^1)<<31>>31;if(!Q){U=S;break}if((lo(N,c[O>>2]|0,I)|0)!=0){U=-1;break}U=(c[I>>2]|0)==33639248?S:-103}}while(0);I=c[O>>2]|0;V=G|0;S=b+4|0;Q=b+28|0;if((gJ[c[S>>2]&31](c[Q>>2]|0,I,F,1)|0)==1){X=d[F]|0;W=9769}else{F=(gA[c[b+24>>2]&16383](c[Q>>2]|0,I)|0)!=0;if(F){Y=0;Z=F<<31>>31}else{X=0;W=9769}}do{if((W|0)==9769){if((gJ[c[S>>2]&31](c[Q>>2]|0,I,E,1)|0)==1){_=d[E]|0}else{F=(gA[c[b+24>>2]&16383](c[Q>>2]|0,I)|0)!=0;if(F){Y=0;Z=F<<31>>31;break}else{_=X}}Y=_<<8|X;Z=0}}while(0);c[V>>2]=Y;Y=(Z|0)==0?U:-1;U=c[O>>2]|0;Z=G+4|0;if((gJ[c[S>>2]&31](c[Q>>2]|0,U,D,1)|0)==1){$=d[D]|0;W=9776}else{D=(gA[c[b+24>>2]&16383](c[Q>>2]|0,U)|0)!=0;if(D){aa=0;ab=D<<31>>31}else{$=0;W=9776}}do{if((W|0)==9776){if((gJ[c[S>>2]&31](c[Q>>2]|0,U,C,1)|0)==1){ac=d[C]|0}else{D=(gA[c[b+24>>2]&16383](c[Q>>2]|0,U)|0)!=0;if(D){aa=0;ab=D<<31>>31;break}else{ac=$}}aa=ac<<8|$;ab=0}}while(0);c[Z>>2]=aa;aa=(ab|0)==0?Y:-1;Y=c[O>>2]|0;ab=G+8|0;if((gJ[c[S>>2]&31](c[Q>>2]|0,Y,B,1)|0)==1){ad=d[B]|0;W=9783}else{B=(gA[c[b+24>>2]&16383](c[Q>>2]|0,Y)|0)!=0;if(B){ae=0;af=B<<31>>31}else{ad=0;W=9783}}do{if((W|0)==9783){if((gJ[c[S>>2]&31](c[Q>>2]|0,Y,A,1)|0)==1){ag=d[A]|0}else{B=(gA[c[b+24>>2]&16383](c[Q>>2]|0,Y)|0)!=0;if(B){ae=0;af=B<<31>>31;break}else{ag=ad}}ae=ag<<8|ad;af=0}}while(0);c[ab>>2]=ae;ae=(af|0)==0?aa:-1;aa=c[O>>2]|0;af=G+12|0;if((gJ[c[S>>2]&31](c[Q>>2]|0,aa,z,1)|0)==1){ah=d[z]|0;W=9790}else{z=(gA[c[b+24>>2]&16383](c[Q>>2]|0,aa)|0)!=0;if(z){ai=0;aj=z<<31>>31}else{ah=0;W=9790}}do{if((W|0)==9790){if((gJ[c[S>>2]&31](c[Q>>2]|0,aa,y,1)|0)==1){ak=d[y]|0}else{z=(gA[c[b+24>>2]&16383](c[Q>>2]|0,aa)|0)!=0;if(z){ai=0;aj=z<<31>>31;break}else{ak=ah}}ai=ak<<8|ah;aj=0}}while(0);c[af>>2]=ai;ai=G+16|0;af=(lo(N,c[O>>2]|0,ai)|0)==0;ah=c[ai>>2]|0;c[G+76>>2]=ah>>>16&31;c[G+80>>2]=(ah>>>21&15)-1;c[G+84>>2]=(ah>>>25)+1980;c[G+72>>2]=ah>>>11&31;c[G+68>>2]=ah>>>5&63;c[G+64>>2]=ah<<1&62;ah=(lo(N,c[O>>2]|0,G+20|0)|0)==0;ai=(lo(N,c[O>>2]|0,J)|0)==0;ak=G+24|0;c[ak>>2]=c[J>>2];c[ak+4>>2]=0;aa=(lo(N,c[O>>2]|0,J)|0)==0;y=aa?ai?ah?af?(aj|0)==0?ae:-1:-1:-1:-1:-1;ae=G+32|0;c[ae>>2]=c[J>>2];c[ae+4>>2]=0;aj=c[O>>2]|0;af=G+40|0;if((gJ[c[S>>2]&31](c[Q>>2]|0,aj,x,1)|0)==1){al=d[x]|0;W=9797}else{x=(gA[c[b+24>>2]&16383](c[Q>>2]|0,aj)|0)!=0;if(x){am=0;an=x<<31>>31}else{al=0;W=9797}}do{if((W|0)==9797){if((gJ[c[S>>2]&31](c[Q>>2]|0,aj,w,1)|0)==1){ao=d[w]|0}else{x=(gA[c[b+24>>2]&16383](c[Q>>2]|0,aj)|0)!=0;if(x){am=0;an=x<<31>>31;break}else{ao=al}}am=ao<<8|al;an=0}}while(0);c[af>>2]=am;am=(an|0)==0?y:-1;y=c[O>>2]|0;an=G+44|0;if((gJ[c[S>>2]&31](c[Q>>2]|0,y,v,1)|0)==1){ap=d[v]|0;W=9804}else{v=(gA[c[b+24>>2]&16383](c[Q>>2]|0,y)|0)!=0;if(v){aq=0;ar=v<<31>>31}else{ap=0;W=9804}}do{if((W|0)==9804){if((gJ[c[S>>2]&31](c[Q>>2]|0,y,u,1)|0)==1){as=d[u]|0}else{v=(gA[c[b+24>>2]&16383](c[Q>>2]|0,y)|0)!=0;if(v){aq=0;ar=v<<31>>31;break}else{as=ap}}aq=as<<8|ap;ar=0}}while(0);c[an>>2]=aq;aq=(ar|0)==0?am:-1;am=c[O>>2]|0;ar=G+48|0;if((gJ[c[S>>2]&31](c[Q>>2]|0,am,t,1)|0)==1){at=d[t]|0;W=9811}else{t=(gA[c[b+24>>2]&16383](c[Q>>2]|0,am)|0)!=0;if(t){au=0;av=t<<31>>31}else{at=0;W=9811}}do{if((W|0)==9811){if((gJ[c[S>>2]&31](c[Q>>2]|0,am,s,1)|0)==1){aw=d[s]|0}else{t=(gA[c[b+24>>2]&16383](c[Q>>2]|0,am)|0)!=0;if(t){au=0;av=t<<31>>31;break}else{aw=at}}au=aw<<8|at;av=0}}while(0);c[ar>>2]=au;au=(av|0)==0?aq:-1;aq=c[O>>2]|0;av=G+52|0;if((gJ[c[S>>2]&31](c[Q>>2]|0,aq,r,1)|0)==1){ax=d[r]|0;W=9818}else{r=(gA[c[b+24>>2]&16383](c[Q>>2]|0,aq)|0)!=0;if(r){ay=0;az=r<<31>>31}else{ax=0;W=9818}}do{if((W|0)==9818){if((gJ[c[S>>2]&31](c[Q>>2]|0,aq,q,1)|0)==1){aA=d[q]|0}else{r=(gA[c[b+24>>2]&16383](c[Q>>2]|0,aq)|0)!=0;if(r){ay=0;az=r<<31>>31;break}else{aA=ax}}ay=aA<<8|ax;az=0}}while(0);c[av>>2]=ay;ay=(az|0)==0?au:-1;au=c[O>>2]|0;az=G+56|0;if((gJ[c[S>>2]&31](c[Q>>2]|0,au,p,1)|0)==1){aB=d[p]|0;W=9825}else{p=(gA[c[b+24>>2]&16383](c[Q>>2]|0,au)|0)!=0;if(p){aC=0;aD=p<<31>>31}else{aB=0;W=9825}}do{if((W|0)==9825){if((gJ[c[S>>2]&31](c[Q>>2]|0,au,o,1)|0)==1){aE=d[o]|0}else{p=(gA[c[b+24>>2]&16383](c[Q>>2]|0,au)|0)!=0;if(p){aC=0;aD=p<<31>>31;break}else{aE=aB}}aC=aE<<8|aB;aD=0}}while(0);c[az>>2]=aC;aC=(lo(N,c[O>>2]|0,G+60|0)|0)==0;az=(lo(N,c[O>>2]|0,J)|0)==0;aB=az?aC?(aD|0)==0?ay:-1:-1:-1;ay=H|0;c[ay>>2]=c[J>>2];c[ay+4>>2]=0;J=c[af>>2]|0;if((aB|0)!=0|(g|0)==0){aF=J;aG=aB}else{if(J>>>0<h>>>0){a[g+J|0]=0;aH=J}else{aH=h}if((J|0)==0|(h|0)==0){aI=0}else{aI=((gJ[c[S>>2]&31](c[Q>>2]|0,c[O>>2]|0,g,aH)|0)!=(aH|0))<<31>>31}aF=J-aH|0;aG=aI}aI=c[an>>2]|0;if((aG|0)!=0){M=aG;i=j;return M|0}L13762:do{if((aI|0)==0){aJ=0}else{if((aF|0)==0){aK=0;aL=aI}else{aG=c[O>>2]|0;aH=aF;J=(aF|0)<0|0?-1:0;g=c[R>>2]|0;do{if((g|0)==0){if(!((aH|0|0)==(aH|0)&(J&0|0)==(J|0))){aM=-1;break}aM=gJ[c[b+40>>2]&31](c[Q>>2]|0,aG,aF,1)|0}else{aM=gF[g&2047](c[Q>>2]|0,aG,aH,J,1)|0}}while(0);aK=((aM|0)!=0)<<31>>31;aL=c[an>>2]|0}if((aL|0)==0){aJ=aK;break}J=b+24|0;aH=b+40|0;aG=aK;g=4;while(1){h=c[O>>2]|0;if((gJ[c[S>>2]&31](c[Q>>2]|0,h,n,1)|0)==1){aN=d[n]|0;W=9848}else{aB=(gA[c[J>>2]&16383](c[Q>>2]|0,h)|0)!=0;if(aB){aO=0;aP=aB<<31>>31}else{aN=0;W=9848}}do{if((W|0)==9848){W=0;if((gJ[c[S>>2]&31](c[Q>>2]|0,h,m,1)|0)==1){aQ=d[m]|0}else{aB=(gA[c[J>>2]&16383](c[Q>>2]|0,h)|0)!=0;if(aB){aO=0;aP=aB<<31>>31;break}else{aQ=aN}}aO=aQ<<8|aN;aP=0}}while(0);h=(aP|0)==0?aG:-1;aB=c[O>>2]|0;if((gJ[c[S>>2]&31](c[Q>>2]|0,aB,l,1)|0)==1){aR=d[l]|0;W=9855}else{af=(gA[c[J>>2]&16383](c[Q>>2]|0,aB)|0)!=0;if(af){aS=0;aT=af<<31>>31}else{aR=0;W=9855}}do{if((W|0)==9855){W=0;if((gJ[c[S>>2]&31](c[Q>>2]|0,aB,k,1)|0)==1){aU=d[k]|0}else{af=(gA[c[J>>2]&16383](c[Q>>2]|0,aB)|0)!=0;if(af){aS=0;aT=af<<31>>31;break}else{aU=aR}}aS=aU<<8|aR;aT=0}}while(0);aB=(aT|0)==0?h:-1;do{if((aO|0)==1){if((c[ae>>2]|0)==(-1|0)&(c[ae+4>>2]|0)==0){af=(lp(N,c[O>>2]|0,ae)|0)==0;aV=af?aB:-1}else{aV=aB}if((c[ak>>2]|0)==(-1|0)&(c[ak+4>>2]|0)==0){af=(lp(N,c[O>>2]|0,ak)|0)==0;aW=af?aV:-1}else{aW=aV}if((c[ay>>2]|0)==(-1|0)&(c[ay+4>>2]|0)==0){af=(lp(N,c[O>>2]|0,ay)|0)==0;aX=af?aW:-1}else{aX=aW}if((c[av>>2]|0)!=-1){aY=aX;break}af=(lo(N,c[O>>2]|0,L)|0)==0;aY=af?aX:-1}else{af=c[O>>2]|0;H=c[R>>2]|0;if((H|0)==0){aZ=gJ[c[aH>>2]&31](c[Q>>2]|0,af,aS,1)|0}else{aZ=gF[H&2047](c[Q>>2]|0,af,aS,0,1)|0}aY=(aZ|0)==0?aB:-1}}while(0);aB=g+aS|0;if(aB>>>0>=(c[an>>2]|0)>>>0){aJ=aY;break L13762}aG=aY;g=aB+4|0}}}while(0);aY=(aJ|0)!=0;if(aY|(e|0)==0){a_=aJ;a$=aY}else{aY=e;e=G;gGC(aY|0,e|0,88)|0;a_=0;a$=0}if(a$|(f|0)==0){M=a_;i=j;return M|0}a$=c[ay+4>>2]|0;e=f|0;c[e>>2]=c[ay>>2];c[e+4>>2]=a$;M=a_;i=j;return M|0}function lm(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0;e=i;i=i+96|0;f=e|0;g=e+8|0;h=e+16|0;j=e+24|0;k=e+32|0;l=e+40|0;m=e+48|0;n=e+56|0;o=e+64|0;p=e+72|0;q=e+80|0;r=e+88|0;if((b|0)==0){s=-102;i=e;return s|0}t=b+96|0;if((c[t>>2]|0)==0&(c[t+4>>2]|0)==0){s=-102;i=e;return s|0}t=b+224|0;u=c[t>>2]|0;if((u|0)!=0){v=u|0;w=c[v>>2]|0;if((w|0)!=0){gGr(w)}c[v>>2]=0;do{if(!((c[u+72>>2]|0)!=8|(u+4|0)==0)){v=u+32|0;w=c[v>>2]|0;if((w|0)==0){break}x=u+40|0;y=c[x>>2]|0;if((y|0)==0){break}z=c[w+52>>2]|0;A=u+44|0;if((z|0)==0){B=y;C=w}else{gg[y&4095](c[A>>2]|0,z);B=c[x>>2]|0;C=c[v>>2]|0}gg[B&4095](c[A>>2]|0,C);c[v>>2]=0}}while(0);gGr(u);c[t>>2]=0}u=b;C=b+48|0;B=c[C>>2]|0;v=b+216|0;A=b+72|0;x=gGK(c[A>>2]|0,c[A+4>>2]|0,c[v>>2]|0,c[v+4>>2]|0)|0;z=K;y=c[b+16>>2]|0;do{if((y|0)==0){if((x|0|0)==(x|0)&(z&0|0)==(z|0)){D=gJ[c[b+40>>2]&31](c[b+28>>2]|0,B,x,0)|0;break}else{s=-103;i=e;return s|0}}else{D=gF[y&2047](c[b+28>>2]|0,B,x,z,0)|0}}while(0);if((D|0)!=0){s=-103;i=e;return s|0}if((lo(u,c[C>>2]|0,q)|0)==0){E=(c[q>>2]|0)==67324752?0:-103}else{E=-1}q=c[C>>2]|0;D=b+4|0;z=b+28|0;if((gJ[c[D>>2]&31](c[z>>2]|0,q,p,1)|0)==1){F=d[p]|0;G=9905}else{p=(gA[c[b+24>>2]&16383](c[z>>2]|0,q)|0)!=0;if(p){H=0;I=p<<31>>31}else{F=0;G=9905}}do{if((G|0)==9905){if((gJ[c[D>>2]&31](c[z>>2]|0,q,o,1)|0)==1){J=d[o]|0}else{p=(gA[c[b+24>>2]&16383](c[z>>2]|0,q)|0)!=0;if(p){H=0;I=p<<31>>31;break}else{J=F}}H=J<<8|F;I=0}}while(0);c[r>>2]=H;H=(I|0)==0?E:-1;E=c[C>>2]|0;if((gJ[c[D>>2]&31](c[z>>2]|0,E,n,1)|0)==1){L=a[n]&8;G=9912}else{n=(gA[c[b+24>>2]&16383](c[z>>2]|0,E)|0)!=0;if(n){M=0;N=n<<31>>31}else{L=0;G=9912}}do{if((G|0)==9912){if((gJ[c[D>>2]&31](c[z>>2]|0,E,m,1)|0)!=1){n=(gA[c[b+24>>2]&16383](c[z>>2]|0,E)|0)!=0;if(n){M=0;N=n<<31>>31;break}}M=L;N=0}}while(0);L=(N|0)==0?H:-1;H=c[C>>2]|0;if((gJ[c[D>>2]&31](c[z>>2]|0,H,l,1)|0)==1){O=d[l]|0;G=9918}else{if((gA[c[b+24>>2]&16383](c[z>>2]|0,H)|0)==0){O=0;G=9918}else{G=9921}}do{if((G|0)==9918){if((gJ[c[D>>2]&31](c[z>>2]|0,H,k,1)|0)==1){P=d[k]|0}else{if((gA[c[b+24>>2]&16383](c[z>>2]|0,H)|0)==0){P=O}else{G=9921;break}}l=P<<8|O;c[r>>2]=l;if((L|0)!=0){Q=L;break}N=(l|0)==(c[b+140>>2]|0);if(!N){Q=N?0:-103;break}if((l|0)==0|(l|0)==12|(l|0)==8){Q=0;break}Q=-103}}while(0);if((G|0)==9921){c[r>>2]=0;Q=-1}L=(lo(u,c[C>>2]|0,r)|0)==0;O=L?Q:-1;do{if((lo(u,c[C>>2]|0,r)|0)==0){if((O|0)!=0){R=O;break}if((c[r>>2]|0)==(c[b+148>>2]|0)){R=0;break}R=(M|0)==0?-103:0}else{R=-1}}while(0);do{if((lo(u,c[C>>2]|0,r)|0)==0){O=c[r>>2]|0;if(!((O|0)!=-1&(R|0)==0)){S=R;break}Q=b+152|0;if((O|0)==(c[Q>>2]|0)&0==(c[Q+4>>2]|0)){S=0;break}S=(M|0)==0?-103:0}else{S=-1}}while(0);do{if((lo(u,c[C>>2]|0,r)|0)==0){R=c[r>>2]|0;if(!((R|0)!=-1&(S|0)==0)){T=S;break}Q=b+160|0;if((R|0)==(c[Q>>2]|0)&0==(c[Q+4>>2]|0)){T=0;break}T=(M|0)==0?-103:0}else{T=-1}}while(0);M=c[C>>2]|0;if((gJ[c[D>>2]&31](c[z>>2]|0,M,j,1)|0)==1){U=d[j]|0;G=9941}else{if((gA[c[b+24>>2]&16383](c[z>>2]|0,M)|0)==0){U=0;G=9941}else{V=-1;W=0}}do{if((G|0)==9941){if((gJ[c[D>>2]&31](c[z>>2]|0,M,h,1)|0)==1){X=d[h]|0}else{if((gA[c[b+24>>2]&16383](c[z>>2]|0,M)|0)==0){X=U}else{V=-1;W=0;break}}j=X<<8|U;if((T|0)!=0){V=T;W=j;break}V=(j|0)==(c[b+168>>2]|0)?0:-103;W=j}}while(0);T=c[C>>2]|0;if((gJ[c[D>>2]&31](c[z>>2]|0,T,g,1)|0)==1){Y=d[g]|0;G=9949}else{g=(gA[c[b+24>>2]&16383](c[z>>2]|0,T)|0)!=0;if(g){Z=0;_=g<<31>>31}else{Y=0;G=9949}}do{if((G|0)==9949){if((gJ[c[D>>2]&31](c[z>>2]|0,T,f,1)|0)==1){$=d[f]|0}else{g=(gA[c[b+24>>2]&16383](c[z>>2]|0,T)|0)!=0;if(g){Z=0;_=g<<31>>31;break}else{$=Y}}Z=$<<8|Y;_=0}}while(0);Y=c[v>>2]|0;$=c[v+4>>2]|0;T=gGK(W,0,30,0)|0;z=gGK(T,K,Y,$)|0;$=K;Y=Z+W|0;if((_|V|0)!=0){s=-103;i=e;return s|0}V=gGq(208)|0;_=V;if((V|0)==0){s=-104;i=e;return s|0}W=gGq(16384)|0;c[V>>2]=W;T=V+80|0;c[T>>2]=z;c[T+4>>2]=$;c[V+88>>2]=Z;Z=V+96|0;c[Z>>2]=0;c[Z+4>>2]=0;Z=V+200|0;c[Z>>2]=0;if((W|0)==0){gGr(V);s=-104;i=e;return s|0}W=V+72|0;c[W>>2]=0;c[V+116>>2]=c[b+148>>2];c[V+112>>2]=0;$=V+104|0;c[$>>2]=0;c[$+4>>2]=0;$=c[b+140>>2]|0;c[V+184>>2]=$;c[V+180>>2]=c[C>>2];C=V+136|0;gGC(C|0,b|0,44)|0;C=c[A+4>>2]|0;T=V+192|0;c[T>>2]=c[A>>2];c[T+4>>2]=C;C=V+4|0;T=V+24|0;c[T>>2]=0;L13936:do{if(($|0)==12){c[Z>>2]=1}else if(($|0)==8){A=V+36|0;c[A>>2]=0;z=V+40|0;c[z>>2]=0;f=V+44|0;c[f>>2]=0;c[C>>2]=0;c[V+8>>2]=0;do{if((C|0)==0){aa=-2}else{D=V+28|0;c[D>>2]=0;c[A>>2]=7122;c[f>>2]=0;c[z>>2]=494;G=gGq(7116)|0;if((G|0)==0){aa=-4;break}g=V+32|0;c[g>>2]=G;c[G+52>>2]=0;U=c[g>>2]|0;do{if((U|0)!=0){X=U+52|0;M=c[X>>2]|0;h=U+36|0;do{if((M|0)!=0){if((c[h>>2]|0)==15){break}gg[c[z>>2]&4095](c[f>>2]|0,M);c[X>>2]=0}}while(0);c[U+8>>2]=0;c[h>>2]=15;X=c[g>>2]|0;if((X|0)==0){break}c[X+40>>2]=0;c[X+44>>2]=0;c[X+48>>2]=0;X=c[g>>2]|0;if((X|0)==0){break}c[X+28>>2]=0;c[T>>2]=0;c[V+12>>2]=0;c[D>>2]=0;M=c[X+8>>2]|0;if((M|0)!=0){c[V+52>>2]=M&1}c[X>>2]=0;c[X+4>>2]=0;c[X+12>>2]=0;c[X+20>>2]=32768;c[X+32>>2]=0;c[X+56>>2]=0;c[X+60>>2]=0;M=X+1328|0;c[X+108>>2]=M;c[X+80>>2]=M;c[X+76>>2]=M;c[X+7104>>2]=1;c[X+7108>>2]=-1;c[W>>2]=8;break L13936}}while(0);gg[c[z>>2]&4095](c[f>>2]|0,G);c[g>>2]=0;aa=-2}}while(0);gGr(V);s=aa;i=e;return s|0}}while(0);aa=b+152|0;W=c[aa+4>>2]|0;T=V+120|0;c[T>>2]=c[aa>>2];c[T+4>>2]=W;W=b+160|0;T=c[W+4>>2]|0;aa=V+128|0;c[aa>>2]=c[W>>2];c[aa+4>>2]=T;T=c[v>>2]|0;aa=c[v+4>>2]|0;v=gGK(Y,0,30,0)|0;Y=gGK(v,K,T,aa)|0;aa=V+64|0;c[aa>>2]=Y;c[aa+4>>2]=K;c[V+8>>2]=0;c[t>>2]=_;c[b+228>>2]=0;s=0;i=e;return s|0}function ln(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;if((b|0)==0){f=-102;return f|0}g=c[b+224>>2]|0;if((g|0)==0){f=-102;return f|0}b=g|0;if((c[b>>2]|0)==0){f=-100;return f|0}if((e|0)==0){f=0;return f|0}h=g+4|0;i=g+16|0;c[i>>2]=d;d=g+20|0;c[d>>2]=e;j=e;e=0;k=g+128|0;l=c[k>>2]|0;m=c[k+4>>2]|0;do{if(e>>>0>m>>>0|e>>>0==m>>>0&j>>>0>l>>>0){if((c[g+200>>2]|0)!=0){break}c[d>>2]=l}}while(0);l=g+120|0;m=c[l>>2]|0;n=g+8|0;o=c[n>>2]|0;p=gGK(o,0,m,c[l+4>>2]|0)|0;q=K;do{if(e>>>0>q>>>0|e>>>0==q>>>0&j>>>0>p>>>0){if((c[g+200>>2]|0)==0){r=0;s=9993;break}t=m+o|0;c[d>>2]=t;u=0;v=t}else{r=0;s=9993}}while(0);L13978:while(1){if((s|0)==9993){s=0;u=r;v=c[d>>2]|0}if((v|0)==0){w=0;x=u;s=10017;break}o=c[n>>2]|0;do{if((o|0)==0){m=c[l>>2]|0;p=c[l+4>>2]|0;if((m|0)==0&(p|0)==0){y=0;break}j=0;q=p>>>0<j>>>0|p>>>0==j>>>0&m>>>0<16384>>>0?m:16384;if((q|0)==0){f=0;s=10020;break L13978}m=g+180|0;j=c[m>>2]|0;p=g+64|0;e=g+192|0;t=gGK(c[e>>2]|0,c[e+4>>2]|0,c[p>>2]|0,c[p+4>>2]|0)|0;e=K;z=c[g+152>>2]|0;if((z|0)==0){if(!((t|0|0)==(t|0)&(e&0|0)==(e|0))){f=-1;s=10025;break L13978}A=gJ[c[g+176>>2]&31](c[g+164>>2]|0,j,t,0)|0}else{A=gF[z&2047](c[g+164>>2]|0,j,t,e,0)|0}if((A|0)!=0){f=-1;s=10026;break L13978}if((gJ[c[g+140>>2]&31](c[g+164>>2]|0,c[m>>2]|0,c[b>>2]|0,q)|0)!=(q|0)){f=-1;s=10021;break L13978}m=q;e=0;t=gGK(c[p>>2]|0,c[p+4>>2]|0,m,e)|0;c[p>>2]=t;c[p+4>>2]=K;p=gGL(c[l>>2]|0,c[l+4>>2]|0,m,e)|0;c[l>>2]=p;c[l+4>>2]=K;c[h>>2]=c[b>>2];c[n>>2]=q;y=q}else{y=o}}while(0);o=c[g+184>>2]|0;do{if((o|0)!=0){if((c[g+200>>2]|0)!=0){break}if((o|0)==12){r=u;s=9993;continue L13978}q=g+24|0;p=c[q>>2]|0;e=c[i>>2]|0;m=RS(h,2)|0;if((m|0)>-1){B=(c[g+28>>2]|0)==0?m:-3}else{B=m}m=gGL(c[q>>2]|0,0,p,0)|0;p=K;q=g+104|0;t=gGK(m,p,c[q>>2]|0,c[q+4>>2]|0)|0;c[q>>2]=t;c[q+4>>2]=K;q=g+112|0;t=m;c[q>>2]=RK(c[q>>2]|0,e,t)|0;e=gGL(c[k>>2]|0,c[k+4>>2]|0,m,p)|0;c[k>>2]=e;c[k+4>>2]=K;e=t+u|0;if((B|0)==1){f=e;s=10022;break L13978}else if((B|0)==0){r=e;s=9993;continue L13978}else{w=B;x=e;s=10017;break L13978}}}while(0);if((y|0)==0){if((c[l>>2]|0)==0&(c[l+4>>2]|0)==0){f=u;s=10028;break}}o=c[d>>2]|0;e=o>>>0<y>>>0?o:y;t=h|0;if((e|0)==0){C=y;D=o}else{o=0;do{a[(c[i>>2]|0)+o|0]=a[(c[t>>2]|0)+o|0]|0;o=o+1|0;}while(o>>>0<e>>>0);C=c[n>>2]|0;D=c[d>>2]|0}o=g+104|0;p=e;m=0;q=gGK(c[o>>2]|0,c[o+4>>2]|0,p,m)|0;c[o>>2]=q;c[o+4>>2]=K;o=g+112|0;q=c[i>>2]|0;c[o>>2]=RK(c[o>>2]|0,q,e)|0;o=gGL(c[k>>2]|0,c[k+4>>2]|0,p,m)|0;c[k>>2]=o;c[k+4>>2]=K;c[n>>2]=C-e;c[d>>2]=D-e;c[i>>2]=q+e;c[t>>2]=(c[t>>2]|0)+e;q=g+24|0;c[q>>2]=(c[q>>2]|0)+e;r=e+u|0;s=9993}if((s|0)==10020){return f|0}else if((s|0)==10026){return f|0}else if((s|0)==10022){return f|0}else if((s|0)==10025){return f|0}else if((s|0)==10028){return f|0}else if((s|0)==10017){f=(w|0)==0?x:w;return f|0}else if((s|0)==10021){return f|0}return 0}function lo(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=i;i=i+32|0;g=f|0;h=f+8|0;j=f+16|0;k=f+24|0;l=a+4|0;m=a+28|0;do{if((gJ[c[l>>2]&31](c[m>>2]|0,b,k,1)|0)==1){n=d[k]|0}else{if((gA[c[a+24>>2]&16383](c[m>>2]|0,b)|0)==0){n=0;break}else{o=0;p=-1}c[e>>2]=o;i=f;return p|0}}while(0);do{if((gJ[c[l>>2]&31](c[m>>2]|0,b,j,1)|0)==1){q=d[j]|0}else{if((gA[c[a+24>>2]&16383](c[m>>2]|0,b)|0)==0){q=n;break}else{o=0;p=-1}c[e>>2]=o;i=f;return p|0}}while(0);j=q<<8|n;do{if((gJ[c[l>>2]&31](c[m>>2]|0,b,h,1)|0)==1){r=d[h]|0}else{n=(gA[c[a+24>>2]&16383](c[m>>2]|0,b)|0)!=0;if(n){o=0;p=n<<31>>31}else{r=q;break}c[e>>2]=o;i=f;return p|0}}while(0);q=j|r<<16;do{if((gJ[c[l>>2]&31](c[m>>2]|0,b,g,1)|0)==1){s=d[g]|0}else{j=(gA[c[a+24>>2]&16383](c[m>>2]|0,b)|0)!=0;if(j){o=0;p=j<<31>>31}else{s=r;break}c[e>>2]=o;i=f;return p|0}}while(0);o=(s<<24)+q|0;p=0;c[e>>2]=o;i=f;return p|0}function lp(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0;g=i;i=i+64|0;h=g|0;j=g+8|0;k=g+16|0;l=g+24|0;m=g+32|0;n=g+40|0;o=g+48|0;p=g+56|0;q=b+4|0;r=b+28|0;if((gJ[c[q>>2]&31](c[r>>2]|0,e,p,1)|0)==1){s=a[p]|0;t=s&255;u=0;v=s&255;w=10052}else{if((gA[c[b+24>>2]&16383](c[r>>2]|0,e)|0)==0){t=0;u=0;v=0;w=10052}else{x=0;y=0;z=0;w=10057}}L14046:do{if((w|0)==10052){if((gJ[c[q>>2]&31](c[r>>2]|0,e,o,1)|0)==1){s=a[o]|0;p=s&255;A=s&255;B=0<<8|p>>>24|u;C=p<<8|0>>>24|v}else{p=t;s=p<<8|0>>>24|v;D=0<<8|p>>>24|u;if((gA[c[b+24>>2]&16383](c[r>>2]|0,e)|0)==0){A=t;B=D;C=s}else{x=t;y=D;z=s;w=10057;break}}do{if((gJ[c[q>>2]&31](c[r>>2]|0,e,n,1)|0)==1){s=a[n]|0;D=s&255;E=s&255;F=0<<16|D>>>16|B;G=D<<16|0>>>16|C}else{D=(gA[c[b+24>>2]&16383](c[r>>2]|0,e)|0)==0;s=A;p=(A|0)<0|0?-1:0;H=s<<16|0>>>16|C;I=p<<16|s>>>16|B;if(D){E=A;F=I;G=H;break}J=-1;K=A;L=I|(p<<24|s>>>8);M=H|(s<<24|0>>>8);w=10065;break L14046}}while(0);if((gJ[c[q>>2]&31](c[r>>2]|0,e,m,1)|0)==1){s=a[m]|0;H=s&255;N=s&255;O=0<<24|H>>>8|F;P=H<<24|0>>>8|G}else{H=(gA[c[b+24>>2]&16383](c[r>>2]|0,e)|0)!=0;s=E;p=s<<24|0>>>8|G;I=((E|0)<0|0?-1:0)<<24|s>>>8|F;if(H){J=H<<31>>31;K=E;L=I;M=p;w=10065;break}else{N=E;O=I;P=p}}do{if((gJ[c[q>>2]&31](c[r>>2]|0,e,l,1)|0)==1){p=a[l]|0;Q=p&255;R=p&255|O;S=P|0}else{p=N;I=P|0;H=p|O;if((gA[c[b+24>>2]&16383](c[r>>2]|0,e)|0)==0){Q=N;R=H;S=I;break}T=-1;U=N;V=H|(p<<8|0>>>24);W=I|(0<<8|0>>>24);w=10073;break L14046}}while(0);if((gJ[c[q>>2]&31](c[r>>2]|0,e,k,1)|0)==1){I=a[k]|0;p=I&255;X=I&255;Y=0;Z=p;_=p<<8|0>>>24|R;$=0<<8|0>>>24|S}else{p=(gA[c[b+24>>2]&16383](c[r>>2]|0,e)|0)!=0;I=Q;H=0<<8|0>>>24|S;s=I<<8|0>>>24|R;if(p){T=p<<31>>31;U=Q;V=s;W=H;w=10073;break}else{X=Q;Y=0;Z=I;_=s;$=H}}do{if((gJ[c[q>>2]&31](c[r>>2]|0,e,j,1)|0)==1){H=a[j]|0;aa=H&255;ab=0;ac=H&255}else{H=(gA[c[b+24>>2]&16383](c[r>>2]|0,e)|0)!=0;if(H){ad=0;ae=0;af=H<<31>>31}else{aa=X;ab=Y;ac=Z;break}ag=f|0;c[ag>>2]=ae;ah=f+4|0;c[ah>>2]=ad;i=g;return af|0}}while(0);H=0<<16|0>>>16|$;s=ac<<16|0>>>16|_;if((gJ[c[q>>2]&31](c[r>>2]|0,e,h,1)|0)==1){ai=s;aj=H;ak=d[h]|0;break}else{al=((gA[c[b+24>>2]&16383](c[r>>2]|0,e)|0)!=0)<<31>>31;am=aa;an=s;ao=H;w=10078;break}}}while(0);if((w|0)==10057){aa=x;e=(x|0)<0|0?-1:0;J=-1;K=x;L=e<<16|aa>>>16|y|(e<<24|aa>>>8);M=aa<<16|0>>>16|z|(aa<<24|0>>>8);w=10065}if((w|0)==10065){aa=K;T=J;U=K;V=aa|L|(aa<<8|0>>>24);W=M|(0<<8|0>>>24);w=10073}if((w|0)==10073){al=T;am=U;an=U<<16|0>>>16|V;ao=0<<16|0>>>16|W;w=10078}do{if((w|0)==10078){if((al|0)==0){ai=an;aj=ao;ak=am;break}else{ad=0;ae=0;af=al}ag=f|0;c[ag>>2]=ae;ah=f+4|0;c[ah>>2]=ad;i=g;return af|0}}while(0);ad=ak<<24|0>>>8|ai;ae=0<<24|0>>>8|aj;af=0;ag=f|0;c[ag>>2]=ae;ah=f+4|0;c[ah>>2]=ad;i=g;return af|0}function lq(b){b=b|0;var d=0,e=0,f=0,g=0,h=0;if((a[b+82|0]&-32)<<24>>24!=32){d=0;return d|0}e=b+86|0;f=a[e]|0;if(f<<24>>24!=0){c[b+32>>2]=c[b+44>>2]<<1;a[e]=f-1&255;d=0;return d|0}f=b+32|0;e=c[f>>2]|0;if((e|0)==(c[b+52>>2]<<1|0)){g=c[b+88>>2]|0;if((g|0)==0){d=0;return d|0}h=a[b+97|0]|0;if(h<<24>>24==0){d=0;return d|0}gg[g&4095](a[b+96|0]|0,h);d=0;return d|0}h=a[(c[b>>2]|0)+(e>>>1)|0]|0;c[f>>2]=e+2;e=c[b+92>>2]|0;do{if((e|0)!=0){f=a[b+98|0]|0;if(f<<24>>24==0){break}gg[e&4095](a[b+96|0]|0,f)}}while(0);e=c[b+88>>2]|0;if((e|0)==0){d=h;return d|0}f=a[b+98|0]|0;if(f<<24>>24==0){d=h;return d|0}gg[e&4095](a[b+96|0]|0,f);d=h;return d|0}function lr(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,i=0,j=0,k=0,l=0,m=0,n=0;if((e|0)>15){return}g=f&255;a[b+101+e|0]=g;switch(e|0){case 1:{e=(a[b+117|0]|0)==1|f;c[b+8>>2]=(c[b+4>>2]|0)+((f>>>6&3)<<2);i=b+83|0;j=e&3;do{if((a[i]&3|0)!=(j|0)){k=b+85|0;l=a[53392+j|0]|0;if((a[k]|0)==l<<24>>24){break}a[k]=l;k=(d[b+84|0]|0)-(l&255)|0;c[b+44>>2]=(d[b+104|0]<<8|d[b+103|0])<<k;c[b+52>>2]=(1<<k)-1+((d[b+106|0]<<8|d[b+105|0])<<k);c[b+48>>2]=(d[b+114|0]<<8|d[b+113|0])<<k}}while(0);a[i]=e&255;return};case 0:{if((a[b+117|0]|0)==1){m=(f|32)&255}else{m=g}e=b+82|0;a[e]=m&-15;if(m<<24>>24<0){a[b+100|0]=1;c[b+36>>2]=0;c[b+64>>2]=0;c[b+76>>2]=0;c[b+72>>2]=0;c[b+68>>2]=127;a[b+80|0]=0}do{if((m&32)==0){c[b+32>>2]=0}else{i=c[b+44>>2]|0;c[b+32>>2]=i<<1;a[b+86|0]=2;if((c[b>>2]|0)==0){a[e]=0;a[b+100|0]=0;return}j=b+52|0;k=c[b+24>>2]|0;if((c[j>>2]|0)>>>0>=k>>>0){c[j>>2]=k-1}if(i>>>0<k>>>0){break}a[e]=0;a[b+100|0]=0;return}}while(0);if((m&1)==0){return}a[e]=0;a[b+100|0]=0;e=c[b+88>>2]|0;if((e|0)==0){return}m=a[b+98|0]|0;if(m<<24>>24==0){return}gg[e&4095](a[b+96|0]|0,m);return};case 11:{m=b+60|0;e=c[m>>2]|0;k=(ag((c[b+28>>2]|0)/256|0,f&255)|0)/32768|0;c[m>>2]=k;if((e|0)==0){return}m=b+72|0;c[m>>2]=~~(+(k|0)*(+(c[m>>2]|0)/+(e|0)));return};case 2:case 3:{c[b+44>>2]=(d[b+104|0]<<8|d[b+103|0])<<(d[b+84|0]|0)-(d[b+85|0]|0);return};case 4:case 5:{e=(d[b+84|0]|0)-(d[b+85|0]|0)|0;c[b+52>>2]=((d[b+106|0]<<8|d[b+105|0])<<e)-1+(1<<e);return};case 13:case 12:{c[b+48>>2]=(d[b+114|0]<<8|d[b+113|0])<<(d[b+84|0]|0)-(d[b+85|0]|0);return};case 8:{e=a[b+82|0]&224;if((e|0)==128){a[b+81|0]=g;m=c[b+92>>2]|0;if((m|0)==0){return}k=a[b+98|0]|0;if(k<<24>>24==0){return}gg[m&4095](a[b+96|0]|0,k);return}else if((e|0)==96){e=b+86|0;if((a[e]|0)==0){n=c[b+32>>2]|0}else{k=c[b+44>>2]<<1;c[b+32>>2]=k;a[e]=0;n=k}k=b+32|0;if((n|0)==(c[b+52>>2]<<1|0)){e=c[b+88>>2]|0;if((e|0)==0){return}m=a[b+97|0]|0;if(m<<24>>24==0){return}gg[e&4095](a[b+96|0]|0,m);return}a[(c[b>>2]|0)+(n>>>1)|0]=g;c[k>>2]=(c[k>>2]|0)+2;k=c[b+92>>2]|0;do{if((k|0)!=0){g=a[b+98|0]|0;if(g<<24>>24==0){break}gg[k&4095](a[b+96|0]|0,g)}}while(0);k=c[b+88>>2]|0;if((k|0)==0){return}g=a[b+98|0]|0;if(g<<24>>24==0){return}gg[k&4095](a[b+96|0]|0,g);return}else{return}break};case 9:case 10:{g=d[b+111|0]<<8|d[b+110|0];c[b+56>>2]=g;c[b+40>>2]=~~(+h[b+16>>3]*+(g>>>0>>>0));return};default:{return}}}function ls(b,e){b=b|0;e=e|0;var f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0.0;f=b+60|0;c[f>>2]=0;lr(b,1,d[e+1|0]|0);g=a[e+2|0]|0;a[b+103|0]=g;i=b+104|0;j=g&255;g=b+84|0;k=b+85|0;l=(d[g]|0)-(d[k]|0)|0;m=b+44|0;c[m>>2]=((d[i]|0)<<8|j)<<l;n=a[e+3|0]|0;a[i]=n;c[m>>2]=((n&255)<<8|j)<<l;j=a[e+4|0]|0;a[b+105|0]=j;n=b+106|0;m=j&255;j=b+52|0;i=1<<l;c[j>>2]=(((d[n]|0)<<8|m)<<l)-1+i;o=a[e+5|0]|0;a[n]=o;c[j>>2]=(((o&255)<<8|m)<<l)-1+i;a[b+107|0]=a[e+6|0]|0;a[b+108|0]=a[e+7|0]|0;lr(b,8,d[e+8|0]|0);i=a[e+9|0]|0;a[b+110|0]=i;l=b+111|0;m=i&255;i=(d[l]|0)<<8|m;o=b+56|0;c[o>>2]=i;p=+h[b+16>>3];j=b+40|0;c[j>>2]=~~(p*+(i>>>0>>>0));i=a[e+10|0]|0;a[l]=i;l=(i&255)<<8|m;c[o>>2]=l;c[j>>2]=~~(p*+(l>>>0>>>0));l=a[e+11|0]|0;a[b+112|0]=l;j=c[f>>2]|0;o=(ag((c[b+28>>2]|0)/256|0,l&255)|0)/32768|0;c[f>>2]=o;if((j|0)!=0){f=b+72|0;c[f>>2]=~~(+(o|0)*(+(c[f>>2]|0)/+(j|0)))}j=a[e+12|0]|0;a[b+113|0]=j;f=b+114|0;o=j&255;j=(d[g]|0)-(d[k]|0)|0;k=b+48|0;c[k>>2]=((d[f]|0)<<8|o)<<j;g=a[e+13|0]|0;a[f]=g;c[k>>2]=((g&255)<<8|o)<<j;a[b+115|0]=a[e+14|0]|0;a[b+116|0]=a[e+15|0]|0;a[b+101|0]=a[e]|0;e=c[b>>2]|0;if((e|0)==0){return}a[b+80|0]=a[e+((c[b+32>>2]|0)>>>1)|0]|0;return}function lt(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0;e=i;f=d+82|0;g=gGq(272)|0;h=g;if((g|0)!=0){gGz(g|0,0,272);j=c[2430396]|0;c[g>>2]=j;if((j|0)!=0){c[j+4>>2]=h}c[2430396]=h;h=g+8|0;cC(h|0,231e3,(k=i,i=i+24|0,c[k>>2]=a,c[k+8>>2]=315696,c[k+16>>2]=b,k)|0)|0;i=k;c[g+264>>2]=f;c[g+268>>2]=1}g=d+32|0;f=gGq(272)|0;h=f;if((f|0)!=0){gGz(f|0,0,272);j=c[2430396]|0;c[f>>2]=j;if((j|0)!=0){c[j+4>>2]=h}c[2430396]=h;h=f+8|0;cC(h|0,231e3,(k=i,i=i+24|0,c[k>>2]=a,c[k+8>>2]=256880,c[k+16>>2]=b,k)|0)|0;i=k;c[f+264>>2]=g;c[f+268>>2]=4}f=d+36|0;g=gGq(272)|0;h=g;if((g|0)!=0){gGz(g|0,0,272);j=c[2430396]|0;c[g>>2]=j;if((j|0)!=0){c[j+4>>2]=h}c[2430396]=h;h=g+8|0;cC(h|0,231e3,(k=i,i=i+24|0,c[k>>2]=a,c[k+8>>2]=200488,c[k+16>>2]=b,k)|0)|0;i=k;c[g+264>>2]=f;c[g+268>>2]=4}g=d+64|0;f=gGq(272)|0;h=f;if((f|0)!=0){gGz(f|0,0,272);j=c[2430396]|0;c[f>>2]=j;if((j|0)!=0){c[j+4>>2]=h}c[2430396]=h;h=f+8|0;cC(h|0,231e3,(k=i,i=i+24|0,c[k>>2]=a,c[k+8>>2]=158144,c[k+16>>2]=b,k)|0)|0;i=k;c[f+264>>2]=g;c[f+268>>2]=4}f=d+76|0;g=gGq(272)|0;h=g;if((g|0)!=0){gGz(g|0,0,272);j=c[2430396]|0;c[g>>2]=j;if((j|0)!=0){c[j+4>>2]=h}c[2430396]=h;h=g+8|0;cC(h|0,231e3,(k=i,i=i+24|0,c[k>>2]=a,c[k+8>>2]=127936,c[k+16>>2]=b,k)|0)|0;i=k;c[g+264>>2]=f;c[g+268>>2]=4}g=d+68|0;f=gGq(272)|0;h=f;if((f|0)!=0){gGz(f|0,0,272);j=c[2430396]|0;c[f>>2]=j;if((j|0)!=0){c[j+4>>2]=h}c[2430396]=h;h=f+8|0;cC(h|0,231e3,(k=i,i=i+24|0,c[k>>2]=a,c[k+8>>2]=103088,c[k+16>>2]=b,k)|0)|0;i=k;c[f+264>>2]=g;c[f+268>>2]=4}f=gGq(272)|0;g=f;if((f|0)==0){i=e;return}gGz(f|0,0,272);h=c[2430396]|0;c[f>>2]=h;if((h|0)!=0){c[h+4>>2]=g}c[2430396]=g;cC(f+8|0,231e3,(k=i,i=i+24|0,c[k>>2]=a,c[k+8>>2]=79808,c[k+16>>2]=b,k)|0)|0;i=k;c[f+264>>2]=d+72;c[f+268>>2]=4;i=e;return}function lu(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;e=b+82|0;f=a[e]|0;g=f&224;if((g|0)==128){h=b+36|0;i=(c[h>>2]|0)+(c[b+40>>2]|0)|0;c[h>>2]=i;if(i>>>0>65535){c[h>>2]=i&65535;j=b+32|0;k=b+80|0;l=b+64|0;m=b+76|0;n=b+68|0;o=b+81|0;p=b+88|0;q=b+98|0;r=b+96|0;s=i>>>16;t=c[j>>2]|0;do{u=d[k]|0;do{if((t&1|0)==0){v=u>>>4;w=t}else{x=u&15;a[k]=a[o]|0;y=c[p>>2]|0;if((y|0)==0){v=x;w=t;break}z=a[q]|0;if(z<<24>>24==0){v=x;w=t;break}gg[y&4095](a[r]|0,z);v=x;w=c[j>>2]|0}}while(0);t=w+1|0;c[j>>2]=t;A=c[l>>2]|0;c[m>>2]=A;u=c[n>>2]|0;x=((ag(u,c[88+(v<<2)>>2]|0)|0)/8|0)+A|0;c[l>>2]=x;do{if((x|0)>32767){c[l>>2]=32767;B=32767}else{if((x|0)>=-32768){B=x;break}c[l>>2]=-32768;B=-32768}}while(0);x=ag(c[24+(v<<2)>>2]|0,u)|0;c[n>>2]=(x|0)/64|0;do{if((x|0)>1572927){c[n>>2]=24576}else{if((x|0)>=8128){break}c[n>>2]=127}}while(0);s=s-1|0;}while((s|0)!=0);C=c[h>>2]|0;D=A;E=B}else{C=i;D=c[b+76>>2]|0;E=c[b+64>>2]|0}i=ag(65536-C|0,D)|0;D=i+(ag(C,E)|0)>>16;E=ag(D,c[b+60>>2]|0)|0;c[b+72>>2]=E;D=c[b+8>>2]|0;c[D>>2]=E+(c[D>>2]|0);return}else if((g|0)==160){g=b+36|0;D=(c[g>>2]|0)+(c[b+40>>2]|0)|0;c[g>>2]=D;L14290:do{if(D>>>0>65535){E=D&65535;c[g>>2]=E;C=b+32|0;i=b+52|0;B=b+44|0;A=b+64|0;h=b+68|0;s=b+76|0;n=b|0;v=b+80|0;l=c[b+48>>2]<<1;m=(f&16)==0;t=D>>>16;j=c[C>>2]|0;while(1){if((j|0)==(l|0)){c[C>>2]=0;F=0}else{F=j}if((F|0)==(c[i>>2]<<1|0)){if(m){break}w=c[B>>2]<<1;c[C>>2]=w;c[A>>2]=0;c[h>>2]=127;c[s>>2]=0;G=w}else{G=F}if((G&1|0)==0){w=a[(c[n>>2]|0)+(G>>>1)|0]|0;a[v]=w;H=(w&255)>>>4}else{H=a[v]&15}w=G+1&33554431;c[C>>2]=w;r=c[A>>2]|0;c[s>>2]=r;q=c[h>>2]|0;p=((ag(q,c[88+(H<<2)>>2]|0)|0)/8|0)+r|0;c[A>>2]=p;do{if((p|0)>32767){c[A>>2]=32767;I=32767}else{if((p|0)>=-32768){I=p;break}c[A>>2]=-32768;I=-32768}}while(0);p=ag(c[24+(H<<2)>>2]|0,q)|0;c[h>>2]=(p|0)/64|0;do{if((p|0)>1572927){c[h>>2]=24576}else{if((p|0)>=8128){break}c[h>>2]=127}}while(0);p=t-1|0;if((p|0)==0){J=E;K=r;L=I;break L14290}else{t=p;j=w}}j=c[b+88>>2]|0;do{if((j|0)!=0){t=a[b+97|0]|0;if(t<<24>>24==0){break}gg[j&4095](a[b+96|0]|0,t)}}while(0);a[b+100|0]=0;a[e]=0;c[b+72>>2]=0;c[s>>2]=0;return}else{J=D;K=c[b+76>>2]|0;L=c[b+64>>2]|0}}while(0);D=ag(65536-J|0,K)|0;K=D+(ag(J,L)|0)>>16;L=ag(K,c[b+60>>2]|0)|0;c[b+72>>2]=L;K=c[b+8>>2]|0;c[K>>2]=L+(c[K>>2]|0);return}else{return}}function lv(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0.0,o=0,p=0,q=0.0;f=c[2113006]|0;c[2113006]=f+1;if((f|0)<=0){c[2383474]=0;f=0;while(1){g=f+1|0;i=~~+U(+(65536.0/+c$(+(+(g|0)*.03125*.125))));j=(i>>>4&1)+(i>>5)|0;i=j<<1;k=f<<1;c[8386392+(k<<2)>>2]=i;l=k|1;c[8386392+(l<<2)>>2]=-i;c[8386392+(k+512<<2)>>2]=j;c[8386392+(l+512<<2)>>2]=-j;i=j>>1;c[8386392+(k+1024<<2)>>2]=i;c[8386392+(l+1024<<2)>>2]=-i;i=j>>2;c[8386392+(k+1536<<2)>>2]=i;c[8386392+(l+1536<<2)>>2]=-i;i=j>>3;c[8386392+(k+2048<<2)>>2]=i;c[8386392+(l+2048<<2)>>2]=-i;i=j>>4;c[8386392+(k+2560<<2)>>2]=i;c[8386392+(l+2560<<2)>>2]=-i;i=j>>5;c[8386392+(k+3072<<2)>>2]=i;c[8386392+(l+3072<<2)>>2]=-i;i=j>>6;c[8386392+(k+3584<<2)>>2]=i;c[8386392+(l+3584<<2)>>2]=-i;i=j>>7;c[8386392+(k+4096<<2)>>2]=i;c[8386392+(l+4096<<2)>>2]=-i;i=j>>8;c[8386392+(k+4608<<2)>>2]=i;c[8386392+(l+4608<<2)>>2]=-i;i=j>>9;c[8386392+(k+5120<<2)>>2]=i;c[8386392+(l+5120<<2)>>2]=-i;i=j>>10;c[8386392+(k+5632<<2)>>2]=i;c[8386392+(l+5632<<2)>>2]=-i;if((g|0)<256){f=g}else{m=0;break}}while(1){n=+Z(+(+(m<<1|1|0)*3.141592653589793*.0009765625));f=~~(+ae(+((n>0.0?1.0:-1.0)/n))*8.0/.6931471805599453*32.0*2.0);c[8427368+(m<<2)>>2]=(f<<1&2)+f&-2|n<0.0;f=m+1|0;if((f|0)<1024){m=f}else{o=0;break}}do{if((o&512|0)==0){c[8427368+(o+1024<<2)>>2]=c[8427368+(o<<2)>>2]}else{c[8427368+(o+1024<<2)>>2]=6144}c[8427368+(o+2048<<2)>>2]=c[8427368+((o&511)<<2)>>2];if((o&256|0)==0){c[8427368+(o+3072<<2)>>2]=c[8427368+((o&255)<<2)>>2]}else{c[8427368+(o+3072<<2)>>2]=6144}o=o+1|0;}while((o|0)<1024)}o=(b&2|0)!=0;m=o?6064:5944;f=gGq(m)|0;if((f|0)==0){p=0;return p|0}gGz(f|0,0,m|0);m=f;if(o){c[f+5828>>2]=f+5944}a[f+5884|0]=b&255;c[f+5892>>2]=d;c[f+5896>>2]=e;n=+(d|0)/72.0;if((e|0)==0){q=0.0}else{q=n/+(e|0)}e=f+5904|0;h[e>>3]=q;h[f+5912>>3]=1.0/n;d=0;n=q;do{c[m+1676+(d<<2)>>2]=~~(n*+(d|0)*64.0*64.0);d=d+1|0;n=+h[e>>3]}while((d|0)<1024);c[f+5788>>2]=~~(n*262144.0);c[f+5796>>2]=~~(n*16384.0);d=~~(n*65536.0);c[f+5808>>2]=d;c[f+1664>>2]=d;c[f+1668>>2]=65536;p=m;return p|0}function lw(b){b=b|0;var e=0,f=0,g=0;c[b+1660>>2]=0;c[b+1656>>2]=0;c[b+5800>>2]=1;a[b+5888|0]=0;e=b+5886|0;f=a[e]&128;a[e]=f&255;do{if((f|0)!=0){if(((d[b+5887|0]|0)&f|0)!=0){break}a[e]=0;g=c[b+5868>>2]|0;if((g|0)==0){break}gg[g&4095](c[b+5872>>2]|0,0)}}while(0);e=b+5884|0;if((a[e]&1)!=0){a[b+5812|0]=0}c[b+5816>>2]=1024;c[b+5820>>2]=4096;lH(b,4,0);f=255;do{lH(b,f,0);f=f-1|0;}while((f|0)>31);c[b+80>>2]=0;a[b+42|0]=0;c[b+52>>2]=511;c[b+164>>2]=0;a[b+126|0]=0;c[b+136>>2]=511;c[b+264>>2]=0;a[b+226|0]=0;c[b+236>>2]=511;c[b+348>>2]=0;a[b+310|0]=0;c[b+320>>2]=511;c[b+448>>2]=0;a[b+410|0]=0;c[b+420>>2]=511;c[b+532>>2]=0;a[b+494|0]=0;c[b+504>>2]=511;c[b+632>>2]=0;a[b+594|0]=0;c[b+604>>2]=511;c[b+716>>2]=0;a[b+678|0]=0;c[b+688>>2]=511;c[b+816>>2]=0;a[b+778|0]=0;c[b+788>>2]=511;c[b+900>>2]=0;a[b+862|0]=0;c[b+872>>2]=511;c[b+1e3>>2]=0;a[b+962|0]=0;c[b+972>>2]=511;c[b+1084>>2]=0;a[b+1046|0]=0;c[b+1056>>2]=511;c[b+1184>>2]=0;a[b+1146|0]=0;c[b+1156>>2]=511;c[b+1268>>2]=0;a[b+1230|0]=0;c[b+1240>>2]=511;c[b+1368>>2]=0;a[b+1330|0]=0;c[b+1340>>2]=511;c[b+1452>>2]=0;a[b+1414|0]=0;c[b+1424>>2]=511;c[b+1552>>2]=0;a[b+1514|0]=0;c[b+1524>>2]=511;c[b+1636>>2]=0;a[b+1598|0]=0;c[b+1608>>2]=511;if((a[e]&2)==0){return}e=c[b+5828>>2]|0;h[e+16>>3]=+h[b+5904>>3];f=b+5928|0;c[e+4>>2]=f;a[e+84|0]=5;c[e+28>>2]=8388608;c[e+52>>2]=0;gGz(e+32|0,0,16);c[e+48>>2]=-1;c[e+60>>2]=0;c[e+8>>2]=f;c[e+64>>2]=0;c[e+76>>2]=0;c[e+68>>2]=127;c[e+72>>2]=0;a[e+117|0]=0;a[e+82|0]=0;a[e+83|0]=0;a[e+85|0]=3;f=c[e+88>>2]|0;if((f|0)==0){return}b=a[e+98|0]|0;if(b<<24>>24==0){return}gg[f&4095](a[e+96|0]|0,b);return}function lx(b,e){b=b|0;e=e|0;var f=0,g=0;if((e&1|0)==0){e=(d[b+5887|0]|0|128)&(d[b+5886|0]|0);if((a[b+5884|0]&2)==0){f=e&255;return f|0}else{f=(a[(c[b+5828>>2]|0)+100|0]&1|e)&255;return f|0}}e=d[b+5885|0]|0;if((e|0)==15){if((a[b+5884|0]&2)==0){f=0;return f|0}f=lq(c[b+5828>>2]|0)|0;return f|0}else if((e|0)==25){if((a[b+5884|0]&8)==0){f=0;return f|0}g=c[b+5836>>2]|0;if((g|0)==0){f=0;return f|0}f=gj[g&4095](c[b+5844>>2]|0)|0;return f|0}else if((e|0)==26){f=a[b+5884|0]<<6&-128;return f|0}else if((e|0)==5){if((a[b+5884|0]&4)==0){f=0;return f|0}e=c[b+5848>>2]|0;if((e|0)==0){f=0;return f|0}f=gj[e&4095](c[b+5856>>2]|0)|0;return f|0}else{f=-1;return f|0}return 0}function ly(b,e){b=b|0;e=e|0;var f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=b+5886|0;g=a[f]|0;i=g&255;do{if((e|0)==0){j=i|64;a[f]=j&255;do{if((i&128|0)==0){if((d[b+5887|0]&j|0)==0){break}a[f]=g|-64;k=c[b+5868>>2]|0;if((k|0)==0){break}gg[k&4095](c[b+5872>>2]|0,1)}}while(0);if((a[b+5888|0]|0)>=0){break}j=c[b+5876>>2]|0;if((j|0)==0){l=0}else{gg[j&4095](c[b+5880>>2]|0,0);l=0}do{j=b+(l*184|0)+68|0;k=c[j>>2]|0;if((k|0)==0){c[b+(l*184|0)+16>>2]=0;a[b+(l*184|0)+42|0]=4}c[j>>2]=k|4;m=b+(l*184|0)+152|0;n=c[m>>2]|0;if((n|0)==0){c[b+(l*184|0)+100>>2]=0;a[b+(l*184|0)+126|0]=4}c[m>>2]=n|4;o=k&-5;c[j>>2]=o;do{if((o|0)==0){j=b+(l*184|0)+42|0;if((d[j]|0)<=1){break}a[j]=1}}while(0);o=n&-5;c[m>>2]=o;do{if((o|0)==0){j=b+(l*184|0)+126|0;if((d[j]|0)<=1){break}a[j]=1}}while(0);l=l+1|0;}while((l|0)<9)}else{o=i|32;a[f]=o&255;if((i&128|0)!=0){break}if((d[b+5887|0]&o|0)==0){break}a[f]=g|-96;o=c[b+5868>>2]|0;if((o|0)==0){break}gg[o&4095](c[b+5872>>2]|0,1)}}while(0);g=c[b+5860>>2]|0;if((g|0)==0){p=a[f]|0;q=p&255;r=q>>>7;return r|0}gd[g&15]((c[b+5864>>2]|0)+e|0,+(c[b+5816+(e<<2)>>2]|0)*+h[b+5912>>3]);p=a[f]|0;q=p&255;r=q>>>7;return r|0}function lz(e,f){e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0;g=c[3540984]|0;h=a[g+1672|0]&32;i=g;if((i|0)!=(c[2383474]|0)){c[2383474]=i;c[3532624]=g+1288;c[3532620]=g+1372;c[3532616]=g+1472;c[3532612]=g+1556}if((f|0)<=0){return}i=g+5924|0;j=g+5788|0;k=g+5784|0;l=g+5780|0;m=g+5772|0;n=g+5796|0;o=g+5792|0;p=g+5781|0;q=g+5776|0;r=g|0;s=g+5920|0;t=g+48|0;u=g+52|0;v=g+72|0;w=g+32|0;x=g+36|0;y=g+28|0;z=g+24|0;A=g+16|0;B=g+80|0;C=g+132|0;D=g+136|0;E=g+156|0;F=g+100|0;G=g+164|0;H=g+232|0;I=g+236|0;J=g+256|0;K=g+216|0;L=g+220|0;M=g+212|0;N=g+208|0;O=g+200|0;P=g+264|0;Q=g+316|0;R=g+320|0;S=g+340|0;T=g+284|0;U=g+348|0;V=g+416|0;W=g+420|0;X=g+440|0;Y=g+400|0;Z=g+404|0;_=g+396|0;$=g+392|0;aa=g+384|0;ab=g+448|0;ac=g+500|0;ad=g+504|0;ae=g+524|0;af=g+468|0;ag=g+532|0;ah=g+600|0;ai=g+604|0;aj=g+624|0;ak=g+584|0;al=g+588|0;am=g+580|0;an=g+576|0;ao=g+568|0;ap=g+632|0;aq=g+684|0;ar=g+688|0;as=g+708|0;at=g+652|0;au=g+716|0;av=g+784|0;aw=g+788|0;ax=g+808|0;ay=g+768|0;az=g+772|0;aA=g+764|0;aB=g+760|0;aC=g+752|0;aD=g+816|0;aE=g+868|0;aF=g+872|0;aG=g+892|0;aH=g+836|0;aI=g+900|0;aJ=g+968|0;aK=g+972|0;aL=g+992|0;aM=g+952|0;aN=g+956|0;aO=g+948|0;aP=g+944|0;aQ=g+936|0;aR=g+1e3|0;aS=g+1052|0;aT=g+1056|0;aU=g+1076|0;aV=g+1020|0;aW=g+1084|0;aX=h<<24>>24==0;h=g+1152|0;aY=g+1156|0;aZ=g+1176|0;a_=g+1136|0;a$=g+1140|0;a0=g+1132|0;a1=g+1128|0;a2=g+1120|0;a3=g+1184|0;a4=g+1236|0;a5=g+1240|0;a6=g+1260|0;a7=g+1204|0;a8=g+1268|0;a9=g+1336|0;ba=g+1340|0;bb=g+1360|0;bc=g+1320|0;bd=g+1324|0;be=g+1316|0;bf=g+1312|0;bg=g+1304|0;bh=g+1368|0;bi=g+1420|0;bj=g+1424|0;bk=g+1444|0;bl=g+1388|0;bm=g+1452|0;bn=g+1520|0;bo=g+1524|0;bp=g+1544|0;bq=g+1504|0;br=g+1508|0;bs=g+1500|0;bt=g+1496|0;bu=g+1488|0;bv=g+1552|0;bw=g+1604|0;bx=g+1608|0;by=g+1628|0;bz=g+1572|0;bA=g+1636|0;bB=g+5800|0;bC=0;do{c[i>>2]=0;bD=(c[k>>2]|0)+(c[j>>2]|0)|0;bE=bD>>>0>3523215359?bD+771751936|0:bD;c[k>>2]=bE;bD=d[44312+(bE>>>24)|0]|0;bE=(a[l]|0)==0?bD>>>2:bD;c[m>>2]=bE;bD=(c[o>>2]|0)+(c[n>>2]|0)|0;c[o>>2]=bD;c[q>>2]=bD>>>24&7|d[p];c[s>>2]=0;bD=(c[u>>2]|0)+(c[t>>2]|0)+(c[v>>2]&bE)|0;bE=c[w>>2]|0;bF=c[x>>2]|0;c[w>>2]=bF;bG=c[y>>2]|0;c[bG>>2]=(c[bG>>2]|0)+bF;c[x>>2]=0;if(bD>>>0<384){bG=a[z]|0;bH=(c[8427368+(((((bG<<24>>24==0?0:bF+bE|0)<<(bG&255))+(c[A>>2]&67043328)|0)>>>16&1023)+(c[B>>2]|0)<<2)>>2]|0)+(bD<<4)|0;if(bH>>>0>6143){bI=0}else{bI=c[8386392+(bH<<2)>>2]|0}c[x>>2]=bI}bH=c[m>>2]|0;bD=(c[D>>2]|0)+(c[C>>2]|0)+(c[E>>2]&bH)|0;if(bD>>>0<384){bG=(c[8427368+((((c[s>>2]<<16)+(c[F>>2]&67043328)|0)>>>16&1023)+(c[G>>2]|0)<<2)>>2]|0)+(bD<<4)|0;if(bG>>>0>6143){bJ=0}else{bJ=c[8386392+(bG<<2)>>2]|0}c[i>>2]=(c[i>>2]|0)+bJ}c[s>>2]=0;bG=(c[I>>2]|0)+(c[H>>2]|0)+(c[J>>2]&bH)|0;bH=c[K>>2]|0;bD=c[L>>2]|0;c[K>>2]=bD;bE=c[M>>2]|0;c[bE>>2]=(c[bE>>2]|0)+bD;c[L>>2]=0;if(bG>>>0<384){bE=a[N]|0;bF=(c[8427368+(((((bE<<24>>24==0?0:bD+bH|0)<<(bE&255))+(c[O>>2]&67043328)|0)>>>16&1023)+(c[P>>2]|0)<<2)>>2]|0)+(bG<<4)|0;if(bF>>>0>6143){bK=0}else{bK=c[8386392+(bF<<2)>>2]|0}c[L>>2]=bK}bF=c[m>>2]|0;bG=(c[R>>2]|0)+(c[Q>>2]|0)+(c[S>>2]&bF)|0;if(bG>>>0<384){bE=(c[8427368+((((c[s>>2]<<16)+(c[T>>2]&67043328)|0)>>>16&1023)+(c[U>>2]|0)<<2)>>2]|0)+(bG<<4)|0;if(bE>>>0>6143){bL=0}else{bL=c[8386392+(bE<<2)>>2]|0}c[i>>2]=(c[i>>2]|0)+bL}c[s>>2]=0;bE=(c[W>>2]|0)+(c[V>>2]|0)+(c[X>>2]&bF)|0;bF=c[Y>>2]|0;bG=c[Z>>2]|0;c[Y>>2]=bG;bH=c[_>>2]|0;c[bH>>2]=(c[bH>>2]|0)+bG;c[Z>>2]=0;if(bE>>>0<384){bH=a[$]|0;bD=(c[8427368+(((((bH<<24>>24==0?0:bG+bF|0)<<(bH&255))+(c[aa>>2]&67043328)|0)>>>16&1023)+(c[ab>>2]|0)<<2)>>2]|0)+(bE<<4)|0;if(bD>>>0>6143){bM=0}else{bM=c[8386392+(bD<<2)>>2]|0}c[Z>>2]=bM}bD=c[m>>2]|0;bE=(c[ad>>2]|0)+(c[ac>>2]|0)+(c[ae>>2]&bD)|0;if(bE>>>0<384){bH=(c[8427368+((((c[s>>2]<<16)+(c[af>>2]&67043328)|0)>>>16&1023)+(c[ag>>2]|0)<<2)>>2]|0)+(bE<<4)|0;if(bH>>>0>6143){bN=0}else{bN=c[8386392+(bH<<2)>>2]|0}c[i>>2]=(c[i>>2]|0)+bN}c[s>>2]=0;bH=(c[ai>>2]|0)+(c[ah>>2]|0)+(c[aj>>2]&bD)|0;bD=c[ak>>2]|0;bE=c[al>>2]|0;c[ak>>2]=bE;bF=c[am>>2]|0;c[bF>>2]=(c[bF>>2]|0)+bE;c[al>>2]=0;if(bH>>>0<384){bF=a[an]|0;bG=(c[8427368+(((((bF<<24>>24==0?0:bE+bD|0)<<(bF&255))+(c[ao>>2]&67043328)|0)>>>16&1023)+(c[ap>>2]|0)<<2)>>2]|0)+(bH<<4)|0;if(bG>>>0>6143){bO=0}else{bO=c[8386392+(bG<<2)>>2]|0}c[al>>2]=bO}bG=c[m>>2]|0;bH=(c[ar>>2]|0)+(c[aq>>2]|0)+(c[as>>2]&bG)|0;if(bH>>>0<384){bF=(c[8427368+((((c[s>>2]<<16)+(c[at>>2]&67043328)|0)>>>16&1023)+(c[au>>2]|0)<<2)>>2]|0)+(bH<<4)|0;if(bF>>>0>6143){bP=0}else{bP=c[8386392+(bF<<2)>>2]|0}c[i>>2]=(c[i>>2]|0)+bP}c[s>>2]=0;bF=(c[aw>>2]|0)+(c[av>>2]|0)+(c[ax>>2]&bG)|0;bG=c[ay>>2]|0;bH=c[az>>2]|0;c[ay>>2]=bH;bD=c[aA>>2]|0;c[bD>>2]=(c[bD>>2]|0)+bH;c[az>>2]=0;if(bF>>>0<384){bD=a[aB]|0;bE=(c[8427368+(((((bD<<24>>24==0?0:bH+bG|0)<<(bD&255))+(c[aC>>2]&67043328)|0)>>>16&1023)+(c[aD>>2]|0)<<2)>>2]|0)+(bF<<4)|0;if(bE>>>0>6143){bQ=0}else{bQ=c[8386392+(bE<<2)>>2]|0}c[az>>2]=bQ}bE=c[m>>2]|0;bF=(c[aF>>2]|0)+(c[aE>>2]|0)+(c[aG>>2]&bE)|0;if(bF>>>0<384){bD=(c[8427368+((((c[s>>2]<<16)+(c[aH>>2]&67043328)|0)>>>16&1023)+(c[aI>>2]|0)<<2)>>2]|0)+(bF<<4)|0;if(bD>>>0>6143){bR=0}else{bR=c[8386392+(bD<<2)>>2]|0}c[i>>2]=(c[i>>2]|0)+bR}c[s>>2]=0;bD=(c[aK>>2]|0)+(c[aJ>>2]|0)+(c[aL>>2]&bE)|0;bE=c[aM>>2]|0;bF=c[aN>>2]|0;c[aM>>2]=bF;bG=c[aO>>2]|0;c[bG>>2]=(c[bG>>2]|0)+bF;c[aN>>2]=0;if(bD>>>0<384){bG=a[aP]|0;bH=(c[8427368+(((((bG<<24>>24==0?0:bF+bE|0)<<(bG&255))+(c[aQ>>2]&67043328)|0)>>>16&1023)+(c[aR>>2]|0)<<2)>>2]|0)+(bD<<4)|0;if(bH>>>0>6143){bS=0}else{bS=c[8386392+(bH<<2)>>2]|0}c[aN>>2]=bS}bH=c[m>>2]|0;bD=(c[aT>>2]|0)+(c[aS>>2]|0)+(c[aU>>2]&bH)|0;if(bD>>>0<384){bG=(c[8427368+((((c[s>>2]<<16)+(c[aV>>2]&67043328)|0)>>>16&1023)+(c[aW>>2]|0)<<2)>>2]|0)+(bD<<4)|0;if(bG>>>0>6143){bT=0}else{bT=c[8386392+(bG<<2)>>2]|0}c[i>>2]=(c[i>>2]|0)+bT}do{if(aX){c[s>>2]=0;bG=(c[aY>>2]|0)+(c[h>>2]|0)+(c[aZ>>2]&bH)|0;bD=c[a_>>2]|0;bE=c[a$>>2]|0;c[a_>>2]=bE;bF=c[a0>>2]|0;c[bF>>2]=(c[bF>>2]|0)+bE;c[a$>>2]=0;if(bG>>>0<384){bF=a[a1]|0;bU=(c[8427368+(((((bF<<24>>24==0?0:bE+bD|0)<<(bF&255))+(c[a2>>2]&67043328)|0)>>>16&1023)+(c[a3>>2]|0)<<2)>>2]|0)+(bG<<4)|0;if(bU>>>0>6143){bV=0}else{bV=c[8386392+(bU<<2)>>2]|0}c[a$>>2]=bV}bU=c[m>>2]|0;bG=(c[a5>>2]|0)+(c[a4>>2]|0)+(c[a6>>2]&bU)|0;if(bG>>>0<384){bF=(c[8427368+((((c[s>>2]<<16)+(c[a7>>2]&67043328)|0)>>>16&1023)+(c[a8>>2]|0)<<2)>>2]|0)+(bG<<4)|0;if(bF>>>0>6143){bW=0}else{bW=c[8386392+(bF<<2)>>2]|0}c[i>>2]=(c[i>>2]|0)+bW}c[s>>2]=0;bF=(c[ba>>2]|0)+(c[a9>>2]|0)+(c[bb>>2]&bU)|0;bU=c[bc>>2]|0;bG=c[bd>>2]|0;c[bc>>2]=bG;bD=c[be>>2]|0;c[bD>>2]=(c[bD>>2]|0)+bG;c[bd>>2]=0;if(bF>>>0<384){bD=a[bf]|0;bE=(c[8427368+(((((bD<<24>>24==0?0:bG+bU|0)<<(bD&255))+(c[bg>>2]&67043328)|0)>>>16&1023)+(c[bh>>2]|0)<<2)>>2]|0)+(bF<<4)|0;if(bE>>>0>6143){bX=0}else{bX=c[8386392+(bE<<2)>>2]|0}c[bd>>2]=bX}bE=c[m>>2]|0;bF=(c[bj>>2]|0)+(c[bi>>2]|0)+(c[bk>>2]&bE)|0;if(bF>>>0<384){bD=(c[8427368+((((c[s>>2]<<16)+(c[bl>>2]&67043328)|0)>>>16&1023)+(c[bm>>2]|0)<<2)>>2]|0)+(bF<<4)|0;if(bD>>>0>6143){bY=0}else{bY=c[8386392+(bD<<2)>>2]|0}c[i>>2]=(c[i>>2]|0)+bY}c[s>>2]=0;bD=(c[bo>>2]|0)+(c[bn>>2]|0)+(c[bp>>2]&bE)|0;bE=c[bq>>2]|0;bF=c[br>>2]|0;c[bq>>2]=bF;bU=c[bs>>2]|0;c[bU>>2]=(c[bU>>2]|0)+bF;c[br>>2]=0;if(bD>>>0<384){bU=a[bt]|0;bG=(c[8427368+(((((bU<<24>>24==0?0:bF+bE|0)<<(bU&255))+(c[bu>>2]&67043328)|0)>>>16&1023)+(c[bv>>2]|0)<<2)>>2]|0)+(bD<<4)|0;if(bG>>>0>6143){bZ=0}else{bZ=c[8386392+(bG<<2)>>2]|0}c[br>>2]=bZ}bG=(c[bx>>2]|0)+(c[bw>>2]|0)+(c[by>>2]&c[m>>2])|0;if(bG>>>0>=384){b_=10437;break}bD=(c[8427368+((((c[s>>2]<<16)+(c[bz>>2]&67043328)|0)>>>16&1023)+(c[bA>>2]|0)<<2)>>2]|0)+(bG<<4)|0;if(bD>>>0>6143){b$=0}else{b$=c[8386392+(bD<<2)>>2]|0}bD=(c[i>>2]|0)+b$|0;c[i>>2]=bD;b0=bD}else{lA(g,r,c[bB>>2]&1);b_=10437}}while(0);if((b_|0)==10437){b_=0;b0=c[i>>2]|0}if((b0|0)>32767){b1=32767}else{b1=(b0|0)<-32768?-32768:b0&65535}b[e+(bC<<1)>>1]=b1;lB(g);bC=bC+1|0;}while((bC|0)<(f|0));return}function lA(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=b+5920|0;c[f>>2]=0;g=b+5772|0;h=(c[d+1156>>2]|0)+(c[d+1152>>2]|0)+(c[d+1176>>2]&c[g>>2])|0;i=d+1136|0;j=d+1140|0;k=c[j>>2]|0;l=k+(c[i>>2]|0)|0;c[i>>2]=k;if((a[d+1144|0]|0)==0){c[f>>2]=k}c[j>>2]=0;if(h>>>0<384){k=a[d+1128|0]|0;i=(c[8427368+(((((k<<24>>24==0?0:l)<<(k&255))+(c[d+1120>>2]&67043328)|0)>>>16&1023)+(c[d+1184>>2]|0)<<2)>>2]|0)+(h<<4)|0;if(i>>>0>6143){m=0}else{m=c[8386392+(i<<2)>>2]|0}c[j>>2]=m}m=c[g>>2]|0;g=(c[d+1240>>2]|0)+(c[d+1236>>2]|0)+(c[d+1260>>2]&m)|0;if(g>>>0<384){j=(c[8427368+((((c[f>>2]<<16)+(c[d+1204>>2]&67043328)|0)>>>16&1023)+(c[d+1268>>2]|0)<<2)>>2]|0)+(g<<4)|0;if(j>>>0>6143){n=0}else{n=c[8386392+(j<<2)>>2]<<1}j=b+5924|0;c[j>>2]=(c[j>>2]|0)+n}n=c[3532624]|0;j=(c[n+52>>2]|0)+(c[n+48>>2]|0)+(c[n+72>>2]&m)|0;if(j>>>0<384){g=c[n+16>>2]|0;d=c[(c[3532612]|0)+16>>2]|0;f=((d>>>19^d>>>21)&1|0)==0?((g>>>18^g>>>23|g>>>19)&1|0)!=0?564:208:564;g=(e|0)!=0;if((f&512|0)==0){o=g?52:f}else{o=g?720:f}f=(c[8427368+((c[n+80>>2]|0)+(o&1023)<<2)>>2]|0)+(j<<4)|0;if(f>>>0>6143){p=0}else{p=c[8386392+(f<<2)>>2]<<1}f=b+5924|0;c[f>>2]=(c[f>>2]|0)+p}p=c[3532620]|0;f=(c[p+52>>2]|0)+(c[p+48>>2]|0)+(c[p+72>>2]&m)|0;if(f>>>0<384){j=((c[n+16>>2]|0)>>>16&256)+256|0;o=(c[8427368+((((e|0)==0?j:j^256)&768)+(c[p+80>>2]|0)<<2)>>2]|0)+(f<<4)|0;if(o>>>0>6143){q=0}else{q=c[8386392+(o<<2)>>2]<<1}o=b+5924|0;c[o>>2]=(c[o>>2]|0)+q}q=c[3532616]|0;o=(c[q+52>>2]|0)+(c[q+48>>2]|0)+(c[q+72>>2]&m)|0;if(o>>>0<384){f=(c[8427368+(((c[q+16>>2]|0)>>>16&1023)+(c[q+80>>2]|0)<<2)>>2]|0)+(o<<4)|0;if(f>>>0>6143){r=0}else{r=c[8386392+(f<<2)>>2]<<1}f=b+5924|0;c[f>>2]=(c[f>>2]|0)+r}r=c[3532612]|0;f=(c[r+52>>2]|0)+(c[r+48>>2]|0)+(c[r+72>>2]&m)|0;if(f>>>0>=384){return}m=c[n+16>>2]|0;n=c[r+16>>2]|0;o=(c[8427368+((((n>>>19^n>>>21)&1|0)==0?(m>>>18^m>>>23|m>>>19)<<9&512|256:768)+(c[r+80>>2]|0)<<2)>>2]|0)+(f<<4)|0;if(o>>>0>6143){s=0}else{s=c[8386392+(o<<2)>>2]<<1}o=b+5924|0;c[o>>2]=(c[o>>2]|0)+s;return}function lB(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=b+1660|0;f=(c[e>>2]|0)+(c[b+1664>>2]|0)|0;c[e>>2]=f;g=b+1668|0;h=c[g>>2]|0;if(f>>>0>=h>>>0){i=b+1656|0;j=f;f=h;do{c[e>>2]=j-f;c[i>>2]=(c[i>>2]|0)+1;h=0;do{k=(h|0)/2|0;l=h&1;m=b+(k*184|0)+(l*84|0)+42|0;n=d[m]|0;do{if((n|0)==1){o=c[i>>2]|0;p=d[b+(k*184|0)+(l*84|0)+64|0]|0;if(((1<<p)-1&o|0)!=0){break}q=b+(k*184|0)+(l*84|0)+52|0;r=(c[q>>2]|0)+(d[52616+((d[b+(k*184|0)+(l*84|0)+65|0]|0)+(o>>>(p>>>0)&7))|0]|0)|0;c[q>>2]=r;if((r|0)<=510){break}c[q>>2]=511;a[m]=0}else if((n|0)==4){q=c[i>>2]|0;r=d[b+(k*184|0)+(l*84|0)+60|0]|0;if(((1<<r)-1&q|0)!=0){break}p=b+(k*184|0)+(l*84|0)+52|0;o=c[p>>2]|0;s=((ag(d[52616+((d[b+(k*184|0)+(l*84|0)+61|0]|0)+(q>>>(r>>>0)&7))|0]|0,~o)|0)>>3)+o|0;c[p>>2]=s;if((s|0)>=1){break}c[p>>2]=0;a[m]=3}else if((n|0)==2){if((a[b+(k*184|0)+(l*84|0)+41|0]|0)!=0){break}p=c[i>>2]|0;s=d[b+(k*184|0)+(l*84|0)+64|0]|0;if(((1<<s)-1&p|0)!=0){break}o=b+(k*184|0)+(l*84|0)+52|0;r=(c[o>>2]|0)+(d[52616+((d[b+(k*184|0)+(l*84|0)+65|0]|0)+(p>>>(s>>>0)&7))|0]|0)|0;c[o>>2]=r;if((r|0)<=510){break}c[o>>2]=511}else if((n|0)==3){o=c[i>>2]|0;r=d[b+(k*184|0)+(l*84|0)+62|0]|0;if(((1<<r)-1&o|0)!=0){break}s=b+(k*184|0)+(l*84|0)+52|0;p=(c[s>>2]|0)+(d[52616+((d[b+(k*184|0)+(l*84|0)+63|0]|0)+(o>>>(r>>>0)&7))|0]|0)|0;c[s>>2]=p;if(p>>>0<(c[b+(k*184|0)+(l*84|0)+56>>2]|0)>>>0){break}a[m]=2}}while(0);h=h+1|0;}while((h|0)<18);j=c[e>>2]|0;f=c[g>>2]|0;}while(j>>>0>=f>>>0)}f=b+5776|0;j=0;do{g=(j|0)/2|0;e=j&1;do{if((a[b+(g*184|0)+(e*84|0)+76|0]|0)==0){i=b+(g*184|0)+(e*84|0)+16|0;c[i>>2]=(c[i>>2]|0)+(c[b+(g*184|0)+(e*84|0)+20>>2]|0)}else{i=c[b+(g*184|0)+168>>2]|0;h=a[43472+((i>>>7<<4&112)+(c[f>>2]|0))|0]|0;if(h<<24>>24==0){m=b+(g*184|0)+(e*84|0)+16|0;c[m>>2]=(c[m>>2]|0)+(c[b+(g*184|0)+(e*84|0)+20>>2]|0);break}else{m=(h<<24>>24)+i|0;i=ag(d[b+(g*184|0)+(e*84|0)+15|0]|0,(c[b+1676+((m&1023)<<2)>>2]|0)>>>((m>>>10&7^7)>>>0))|0;m=b+(g*184|0)+(e*84|0)+16|0;c[m>>2]=i+(c[m>>2]|0);break}}}while(0);j=j+1|0;}while((j|0)<18);j=b+5804|0;f=(c[j>>2]|0)+(c[b+5808>>2]|0)|0;e=f>>>16;c[j>>2]=f&65535;if((e|0)==0){return}f=b+5800|0;b=e;e=c[f>>2]|0;do{e=((e&1|0)==0?e:e^8389378)>>>1;b=b-1|0;}while((b|0)!=0);c[f>>2]=e;return}function lC(e,f){e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0;g=c[3540986]|0;h=a[g+1672|0]&32;i=g;if((i|0)!=(c[2383474]|0)){c[2383474]=i;c[3532624]=g+1288;c[3532620]=g+1372;c[3532616]=g+1472;c[3532612]=g+1556}if((f|0)<=0){return}i=g+5924|0;j=g+5788|0;k=g+5784|0;l=g+5780|0;m=g+5772|0;n=g+5796|0;o=g+5792|0;p=g+5781|0;q=g+5776|0;r=g|0;s=g+5920|0;t=g+48|0;u=g+52|0;v=g+72|0;w=g+32|0;x=g+36|0;y=g+28|0;z=g+24|0;A=g+16|0;B=g+80|0;C=g+132|0;D=g+136|0;E=g+156|0;F=g+100|0;G=g+164|0;H=g+232|0;I=g+236|0;J=g+256|0;K=g+216|0;L=g+220|0;M=g+212|0;N=g+208|0;O=g+200|0;P=g+264|0;Q=g+316|0;R=g+320|0;S=g+340|0;T=g+284|0;U=g+348|0;V=g+416|0;W=g+420|0;X=g+440|0;Y=g+400|0;Z=g+404|0;_=g+396|0;$=g+392|0;aa=g+384|0;ab=g+448|0;ac=g+500|0;ad=g+504|0;ae=g+524|0;af=g+468|0;ag=g+532|0;ah=g+600|0;ai=g+604|0;aj=g+624|0;ak=g+584|0;al=g+588|0;am=g+580|0;an=g+576|0;ao=g+568|0;ap=g+632|0;aq=g+684|0;ar=g+688|0;as=g+708|0;at=g+652|0;au=g+716|0;av=g+784|0;aw=g+788|0;ax=g+808|0;ay=g+768|0;az=g+772|0;aA=g+764|0;aB=g+760|0;aC=g+752|0;aD=g+816|0;aE=g+868|0;aF=g+872|0;aG=g+892|0;aH=g+836|0;aI=g+900|0;aJ=g+968|0;aK=g+972|0;aL=g+992|0;aM=g+952|0;aN=g+956|0;aO=g+948|0;aP=g+944|0;aQ=g+936|0;aR=g+1e3|0;aS=g+1052|0;aT=g+1056|0;aU=g+1076|0;aV=g+1020|0;aW=g+1084|0;aX=h<<24>>24==0;h=g+1152|0;aY=g+1156|0;aZ=g+1176|0;a_=g+1136|0;a$=g+1140|0;a0=g+1132|0;a1=g+1128|0;a2=g+1120|0;a3=g+1184|0;a4=g+1236|0;a5=g+1240|0;a6=g+1260|0;a7=g+1204|0;a8=g+1268|0;a9=g+1336|0;ba=g+1340|0;bb=g+1360|0;bc=g+1320|0;bd=g+1324|0;be=g+1316|0;bf=g+1312|0;bg=g+1304|0;bh=g+1368|0;bi=g+1420|0;bj=g+1424|0;bk=g+1444|0;bl=g+1388|0;bm=g+1452|0;bn=g+1520|0;bo=g+1524|0;bp=g+1544|0;bq=g+1504|0;br=g+1508|0;bs=g+1500|0;bt=g+1496|0;bu=g+1488|0;bv=g+1552|0;bw=g+1604|0;bx=g+1608|0;by=g+1628|0;bz=g+1572|0;bA=g+1636|0;bB=g+5800|0;bC=0;do{c[i>>2]=0;bD=(c[k>>2]|0)+(c[j>>2]|0)|0;bE=bD>>>0>3523215359?bD+771751936|0:bD;c[k>>2]=bE;bD=d[44312+(bE>>>24)|0]|0;bE=(a[l]|0)==0?bD>>>2:bD;c[m>>2]=bE;bD=(c[o>>2]|0)+(c[n>>2]|0)|0;c[o>>2]=bD;c[q>>2]=bD>>>24&7|d[p];c[s>>2]=0;bD=(c[u>>2]|0)+(c[t>>2]|0)+(c[v>>2]&bE)|0;bE=c[w>>2]|0;bF=c[x>>2]|0;c[w>>2]=bF;bG=c[y>>2]|0;c[bG>>2]=(c[bG>>2]|0)+bF;c[x>>2]=0;if(bD>>>0<384){bG=a[z]|0;bH=(c[8427368+(((((bG<<24>>24==0?0:bF+bE|0)<<(bG&255))+(c[A>>2]&67043328)|0)>>>16&1023)+(c[B>>2]|0)<<2)>>2]|0)+(bD<<4)|0;if(bH>>>0>6143){bI=0}else{bI=c[8386392+(bH<<2)>>2]|0}c[x>>2]=bI}bH=c[m>>2]|0;bD=(c[D>>2]|0)+(c[C>>2]|0)+(c[E>>2]&bH)|0;if(bD>>>0<384){bG=(c[8427368+((((c[s>>2]<<16)+(c[F>>2]&67043328)|0)>>>16&1023)+(c[G>>2]|0)<<2)>>2]|0)+(bD<<4)|0;if(bG>>>0>6143){bJ=0}else{bJ=c[8386392+(bG<<2)>>2]|0}c[i>>2]=(c[i>>2]|0)+bJ}c[s>>2]=0;bG=(c[I>>2]|0)+(c[H>>2]|0)+(c[J>>2]&bH)|0;bH=c[K>>2]|0;bD=c[L>>2]|0;c[K>>2]=bD;bE=c[M>>2]|0;c[bE>>2]=(c[bE>>2]|0)+bD;c[L>>2]=0;if(bG>>>0<384){bE=a[N]|0;bF=(c[8427368+(((((bE<<24>>24==0?0:bD+bH|0)<<(bE&255))+(c[O>>2]&67043328)|0)>>>16&1023)+(c[P>>2]|0)<<2)>>2]|0)+(bG<<4)|0;if(bF>>>0>6143){bK=0}else{bK=c[8386392+(bF<<2)>>2]|0}c[L>>2]=bK}bF=c[m>>2]|0;bG=(c[R>>2]|0)+(c[Q>>2]|0)+(c[S>>2]&bF)|0;if(bG>>>0<384){bE=(c[8427368+((((c[s>>2]<<16)+(c[T>>2]&67043328)|0)>>>16&1023)+(c[U>>2]|0)<<2)>>2]|0)+(bG<<4)|0;if(bE>>>0>6143){bL=0}else{bL=c[8386392+(bE<<2)>>2]|0}c[i>>2]=(c[i>>2]|0)+bL}c[s>>2]=0;bE=(c[W>>2]|0)+(c[V>>2]|0)+(c[X>>2]&bF)|0;bF=c[Y>>2]|0;bG=c[Z>>2]|0;c[Y>>2]=bG;bH=c[_>>2]|0;c[bH>>2]=(c[bH>>2]|0)+bG;c[Z>>2]=0;if(bE>>>0<384){bH=a[$]|0;bD=(c[8427368+(((((bH<<24>>24==0?0:bG+bF|0)<<(bH&255))+(c[aa>>2]&67043328)|0)>>>16&1023)+(c[ab>>2]|0)<<2)>>2]|0)+(bE<<4)|0;if(bD>>>0>6143){bM=0}else{bM=c[8386392+(bD<<2)>>2]|0}c[Z>>2]=bM}bD=c[m>>2]|0;bE=(c[ad>>2]|0)+(c[ac>>2]|0)+(c[ae>>2]&bD)|0;if(bE>>>0<384){bH=(c[8427368+((((c[s>>2]<<16)+(c[af>>2]&67043328)|0)>>>16&1023)+(c[ag>>2]|0)<<2)>>2]|0)+(bE<<4)|0;if(bH>>>0>6143){bN=0}else{bN=c[8386392+(bH<<2)>>2]|0}c[i>>2]=(c[i>>2]|0)+bN}c[s>>2]=0;bH=(c[ai>>2]|0)+(c[ah>>2]|0)+(c[aj>>2]&bD)|0;bD=c[ak>>2]|0;bE=c[al>>2]|0;c[ak>>2]=bE;bF=c[am>>2]|0;c[bF>>2]=(c[bF>>2]|0)+bE;c[al>>2]=0;if(bH>>>0<384){bF=a[an]|0;bG=(c[8427368+(((((bF<<24>>24==0?0:bE+bD|0)<<(bF&255))+(c[ao>>2]&67043328)|0)>>>16&1023)+(c[ap>>2]|0)<<2)>>2]|0)+(bH<<4)|0;if(bG>>>0>6143){bO=0}else{bO=c[8386392+(bG<<2)>>2]|0}c[al>>2]=bO}bG=c[m>>2]|0;bH=(c[ar>>2]|0)+(c[aq>>2]|0)+(c[as>>2]&bG)|0;if(bH>>>0<384){bF=(c[8427368+((((c[s>>2]<<16)+(c[at>>2]&67043328)|0)>>>16&1023)+(c[au>>2]|0)<<2)>>2]|0)+(bH<<4)|0;if(bF>>>0>6143){bP=0}else{bP=c[8386392+(bF<<2)>>2]|0}c[i>>2]=(c[i>>2]|0)+bP}c[s>>2]=0;bF=(c[aw>>2]|0)+(c[av>>2]|0)+(c[ax>>2]&bG)|0;bG=c[ay>>2]|0;bH=c[az>>2]|0;c[ay>>2]=bH;bD=c[aA>>2]|0;c[bD>>2]=(c[bD>>2]|0)+bH;c[az>>2]=0;if(bF>>>0<384){bD=a[aB]|0;bE=(c[8427368+(((((bD<<24>>24==0?0:bH+bG|0)<<(bD&255))+(c[aC>>2]&67043328)|0)>>>16&1023)+(c[aD>>2]|0)<<2)>>2]|0)+(bF<<4)|0;if(bE>>>0>6143){bQ=0}else{bQ=c[8386392+(bE<<2)>>2]|0}c[az>>2]=bQ}bE=c[m>>2]|0;bF=(c[aF>>2]|0)+(c[aE>>2]|0)+(c[aG>>2]&bE)|0;if(bF>>>0<384){bD=(c[8427368+((((c[s>>2]<<16)+(c[aH>>2]&67043328)|0)>>>16&1023)+(c[aI>>2]|0)<<2)>>2]|0)+(bF<<4)|0;if(bD>>>0>6143){bR=0}else{bR=c[8386392+(bD<<2)>>2]|0}c[i>>2]=(c[i>>2]|0)+bR}c[s>>2]=0;bD=(c[aK>>2]|0)+(c[aJ>>2]|0)+(c[aL>>2]&bE)|0;bE=c[aM>>2]|0;bF=c[aN>>2]|0;c[aM>>2]=bF;bG=c[aO>>2]|0;c[bG>>2]=(c[bG>>2]|0)+bF;c[aN>>2]=0;if(bD>>>0<384){bG=a[aP]|0;bH=(c[8427368+(((((bG<<24>>24==0?0:bF+bE|0)<<(bG&255))+(c[aQ>>2]&67043328)|0)>>>16&1023)+(c[aR>>2]|0)<<2)>>2]|0)+(bD<<4)|0;if(bH>>>0>6143){bS=0}else{bS=c[8386392+(bH<<2)>>2]|0}c[aN>>2]=bS}bH=c[m>>2]|0;bD=(c[aT>>2]|0)+(c[aS>>2]|0)+(c[aU>>2]&bH)|0;if(bD>>>0<384){bG=(c[8427368+((((c[s>>2]<<16)+(c[aV>>2]&67043328)|0)>>>16&1023)+(c[aW>>2]|0)<<2)>>2]|0)+(bD<<4)|0;if(bG>>>0>6143){bT=0}else{bT=c[8386392+(bG<<2)>>2]|0}c[i>>2]=(c[i>>2]|0)+bT}do{if(aX){c[s>>2]=0;bG=(c[aY>>2]|0)+(c[h>>2]|0)+(c[aZ>>2]&bH)|0;bD=c[a_>>2]|0;bE=c[a$>>2]|0;c[a_>>2]=bE;bF=c[a0>>2]|0;c[bF>>2]=(c[bF>>2]|0)+bE;c[a$>>2]=0;if(bG>>>0<384){bF=a[a1]|0;bU=(c[8427368+(((((bF<<24>>24==0?0:bE+bD|0)<<(bF&255))+(c[a2>>2]&67043328)|0)>>>16&1023)+(c[a3>>2]|0)<<2)>>2]|0)+(bG<<4)|0;if(bU>>>0>6143){bV=0}else{bV=c[8386392+(bU<<2)>>2]|0}c[a$>>2]=bV}bU=c[m>>2]|0;bG=(c[a5>>2]|0)+(c[a4>>2]|0)+(c[a6>>2]&bU)|0;if(bG>>>0<384){bF=(c[8427368+((((c[s>>2]<<16)+(c[a7>>2]&67043328)|0)>>>16&1023)+(c[a8>>2]|0)<<2)>>2]|0)+(bG<<4)|0;if(bF>>>0>6143){bW=0}else{bW=c[8386392+(bF<<2)>>2]|0}c[i>>2]=(c[i>>2]|0)+bW}c[s>>2]=0;bF=(c[ba>>2]|0)+(c[a9>>2]|0)+(c[bb>>2]&bU)|0;bU=c[bc>>2]|0;bG=c[bd>>2]|0;c[bc>>2]=bG;bD=c[be>>2]|0;c[bD>>2]=(c[bD>>2]|0)+bG;c[bd>>2]=0;if(bF>>>0<384){bD=a[bf]|0;bE=(c[8427368+(((((bD<<24>>24==0?0:bG+bU|0)<<(bD&255))+(c[bg>>2]&67043328)|0)>>>16&1023)+(c[bh>>2]|0)<<2)>>2]|0)+(bF<<4)|0;if(bE>>>0>6143){bX=0}else{bX=c[8386392+(bE<<2)>>2]|0}c[bd>>2]=bX}bE=c[m>>2]|0;bF=(c[bj>>2]|0)+(c[bi>>2]|0)+(c[bk>>2]&bE)|0;if(bF>>>0<384){bD=(c[8427368+((((c[s>>2]<<16)+(c[bl>>2]&67043328)|0)>>>16&1023)+(c[bm>>2]|0)<<2)>>2]|0)+(bF<<4)|0;if(bD>>>0>6143){bY=0}else{bY=c[8386392+(bD<<2)>>2]|0}c[i>>2]=(c[i>>2]|0)+bY}c[s>>2]=0;bD=(c[bo>>2]|0)+(c[bn>>2]|0)+(c[bp>>2]&bE)|0;bE=c[bq>>2]|0;bF=c[br>>2]|0;c[bq>>2]=bF;bU=c[bs>>2]|0;c[bU>>2]=(c[bU>>2]|0)+bF;c[br>>2]=0;if(bD>>>0<384){bU=a[bt]|0;bG=(c[8427368+(((((bU<<24>>24==0?0:bF+bE|0)<<(bU&255))+(c[bu>>2]&67043328)|0)>>>16&1023)+(c[bv>>2]|0)<<2)>>2]|0)+(bD<<4)|0;if(bG>>>0>6143){bZ=0}else{bZ=c[8386392+(bG<<2)>>2]|0}c[br>>2]=bZ}bG=(c[bx>>2]|0)+(c[bw>>2]|0)+(c[by>>2]&c[m>>2])|0;if(bG>>>0>=384){b_=10587;break}bD=(c[8427368+((((c[s>>2]<<16)+(c[bz>>2]&67043328)|0)>>>16&1023)+(c[bA>>2]|0)<<2)>>2]|0)+(bG<<4)|0;if(bD>>>0>6143){b$=0}else{b$=c[8386392+(bD<<2)>>2]|0}bD=(c[i>>2]|0)+b$|0;c[i>>2]=bD;b0=bD}else{lA(g,r,c[bB>>2]&1);b_=10587}}while(0);if((b_|0)==10587){b_=0;b0=c[i>>2]|0}if((b0|0)>32767){b1=32767}else{b1=(b0|0)<-32768?-32768:b0&65535}b[e+(bC<<1)>>1]=b1;lB(g);bC=bC+1|0;}while((bC|0)<(f|0));return}function lD(b,d){b=b|0;d=d|0;var e=0,f=0;e=c[14163952+((b&255)<<2)>>2]|0;b=e+5886|0;f=a[b]|d;a[b]=f;if(f<<24>>24<=-1){return}if((a[e+5887|0]&f)<<24>>24==0){return}a[b]=f|-128;f=c[e+5868>>2]|0;if((f|0)==0){return}gg[f&4095](c[e+5872>>2]|0,1);return}function lE(b,e){b=b|0;e=e|0;var f=0,g=0;f=c[14163952+((b&255)<<2)>>2]|0;b=f+5886|0;g=(d[b]|0)&(e&255^255);e=g&255;a[b]=e;if((g&128|0)==0){return}if(((d[f+5887|0]|0)&g|0)!=0){return}a[b]=e&127;e=c[f+5868>>2]|0;if((e|0)==0){return}gg[e&4095](c[f+5872>>2]|0,0);return}function lF(e,f,g){e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0;h=c[14163952+(e<<2)>>2]|0;e=a[h+1672|0]&32;i=c[h+5828>>2]|0;j=h;if((j|0)!=(c[2383474]|0)){c[2383474]=j;c[3532624]=h+1288;c[3532620]=h+1372;c[3532616]=h+1472;c[3532612]=h+1556}if((g|0)<=0){return}j=h+5924|0;k=h+5928|0;l=h+5788|0;m=h+5784|0;n=h+5780|0;o=h+5772|0;p=h+5796|0;q=h+5792|0;r=h+5781|0;s=h+5776|0;t=i+82|0;u=h|0;v=h+5920|0;w=h+48|0;x=h+52|0;y=h+72|0;z=h+32|0;A=h+36|0;B=h+28|0;C=h+24|0;D=h+16|0;E=h+80|0;F=h+132|0;G=h+136|0;H=h+156|0;I=h+100|0;J=h+164|0;K=h+232|0;L=h+236|0;M=h+256|0;N=h+216|0;O=h+220|0;P=h+212|0;Q=h+208|0;R=h+200|0;S=h+264|0;T=h+316|0;U=h+320|0;V=h+340|0;W=h+284|0;X=h+348|0;Y=h+416|0;Z=h+420|0;_=h+440|0;$=h+400|0;aa=h+404|0;ab=h+396|0;ac=h+392|0;ad=h+384|0;ae=h+448|0;af=h+500|0;ag=h+504|0;ah=h+524|0;ai=h+468|0;aj=h+532|0;ak=h+600|0;al=h+604|0;am=h+624|0;an=h+584|0;ao=h+588|0;ap=h+580|0;aq=h+576|0;ar=h+568|0;as=h+632|0;at=h+684|0;au=h+688|0;av=h+708|0;aw=h+652|0;ax=h+716|0;ay=h+784|0;az=h+788|0;aA=h+808|0;aB=h+768|0;aC=h+772|0;aD=h+764|0;aE=h+760|0;aF=h+752|0;aG=h+816|0;aH=h+868|0;aI=h+872|0;aJ=h+892|0;aK=h+836|0;aL=h+900|0;aM=h+968|0;aN=h+972|0;aO=h+992|0;aP=h+952|0;aQ=h+956|0;aR=h+948|0;aS=h+944|0;aT=h+936|0;aU=h+1e3|0;aV=h+1052|0;aW=h+1056|0;aX=h+1076|0;aY=h+1020|0;aZ=h+1084|0;a_=e<<24>>24==0;e=h+1152|0;a$=h+1156|0;a0=h+1176|0;a1=h+1136|0;a2=h+1140|0;a3=h+1132|0;a4=h+1128|0;a5=h+1120|0;a6=h+1184|0;a7=h+1236|0;a8=h+1240|0;a9=h+1260|0;ba=h+1204|0;bb=h+1268|0;bc=h+1336|0;bd=h+1340|0;be=h+1360|0;bf=h+1320|0;bg=h+1324|0;bh=h+1316|0;bi=h+1312|0;bj=h+1304|0;bk=h+1368|0;bl=h+1420|0;bm=h+1424|0;bn=h+1444|0;bo=h+1388|0;bp=h+1452|0;bq=h+1520|0;br=h+1524|0;bs=h+1544|0;bt=h+1504|0;bu=h+1508|0;bv=h+1500|0;bw=h+1496|0;bx=h+1488|0;by=h+1552|0;bz=h+1604|0;bA=h+1608|0;bB=h+1628|0;bC=h+1572|0;bD=h+1636|0;bE=h+5800|0;bF=0;do{c[j>>2]=0;c[k>>2]=0;bG=(c[m>>2]|0)+(c[l>>2]|0)|0;bH=bG>>>0>3523215359?bG+771751936|0:bG;c[m>>2]=bH;bG=d[44312+(bH>>>24)|0]|0;bH=(a[n]|0)==0?bG>>>2:bG;c[o>>2]=bH;bG=(c[q>>2]|0)+(c[p>>2]|0)|0;c[q>>2]=bG;c[s>>2]=bG>>>24&7|d[r];if((a[t]|0)<0){lu(i);bI=c[o>>2]|0}else{bI=bH}c[v>>2]=0;bH=(c[x>>2]|0)+(c[w>>2]|0)+(c[y>>2]&bI)|0;bG=c[z>>2]|0;bJ=c[A>>2]|0;c[z>>2]=bJ;bK=c[B>>2]|0;c[bK>>2]=(c[bK>>2]|0)+bJ;c[A>>2]=0;if(bH>>>0<384){bK=a[C]|0;bL=(c[8427368+(((((bK<<24>>24==0?0:bJ+bG|0)<<(bK&255))+(c[D>>2]&67043328)|0)>>>16&1023)+(c[E>>2]|0)<<2)>>2]|0)+(bH<<4)|0;if(bL>>>0>6143){bM=0}else{bM=c[8386392+(bL<<2)>>2]|0}c[A>>2]=bM}bL=c[o>>2]|0;bH=(c[G>>2]|0)+(c[F>>2]|0)+(c[H>>2]&bL)|0;if(bH>>>0<384){bK=(c[8427368+((((c[v>>2]<<16)+(c[I>>2]&67043328)|0)>>>16&1023)+(c[J>>2]|0)<<2)>>2]|0)+(bH<<4)|0;if(bK>>>0>6143){bN=0}else{bN=c[8386392+(bK<<2)>>2]|0}c[j>>2]=(c[j>>2]|0)+bN}c[v>>2]=0;bK=(c[L>>2]|0)+(c[K>>2]|0)+(c[M>>2]&bL)|0;bL=c[N>>2]|0;bH=c[O>>2]|0;c[N>>2]=bH;bG=c[P>>2]|0;c[bG>>2]=(c[bG>>2]|0)+bH;c[O>>2]=0;if(bK>>>0<384){bG=a[Q]|0;bJ=(c[8427368+(((((bG<<24>>24==0?0:bH+bL|0)<<(bG&255))+(c[R>>2]&67043328)|0)>>>16&1023)+(c[S>>2]|0)<<2)>>2]|0)+(bK<<4)|0;if(bJ>>>0>6143){bO=0}else{bO=c[8386392+(bJ<<2)>>2]|0}c[O>>2]=bO}bJ=c[o>>2]|0;bK=(c[U>>2]|0)+(c[T>>2]|0)+(c[V>>2]&bJ)|0;if(bK>>>0<384){bG=(c[8427368+((((c[v>>2]<<16)+(c[W>>2]&67043328)|0)>>>16&1023)+(c[X>>2]|0)<<2)>>2]|0)+(bK<<4)|0;if(bG>>>0>6143){bP=0}else{bP=c[8386392+(bG<<2)>>2]|0}c[j>>2]=(c[j>>2]|0)+bP}c[v>>2]=0;bG=(c[Z>>2]|0)+(c[Y>>2]|0)+(c[_>>2]&bJ)|0;bJ=c[$>>2]|0;bK=c[aa>>2]|0;c[$>>2]=bK;bL=c[ab>>2]|0;c[bL>>2]=(c[bL>>2]|0)+bK;c[aa>>2]=0;if(bG>>>0<384){bL=a[ac]|0;bH=(c[8427368+(((((bL<<24>>24==0?0:bK+bJ|0)<<(bL&255))+(c[ad>>2]&67043328)|0)>>>16&1023)+(c[ae>>2]|0)<<2)>>2]|0)+(bG<<4)|0;if(bH>>>0>6143){bQ=0}else{bQ=c[8386392+(bH<<2)>>2]|0}c[aa>>2]=bQ}bH=c[o>>2]|0;bG=(c[ag>>2]|0)+(c[af>>2]|0)+(c[ah>>2]&bH)|0;if(bG>>>0<384){bL=(c[8427368+((((c[v>>2]<<16)+(c[ai>>2]&67043328)|0)>>>16&1023)+(c[aj>>2]|0)<<2)>>2]|0)+(bG<<4)|0;if(bL>>>0>6143){bR=0}else{bR=c[8386392+(bL<<2)>>2]|0}c[j>>2]=(c[j>>2]|0)+bR}c[v>>2]=0;bL=(c[al>>2]|0)+(c[ak>>2]|0)+(c[am>>2]&bH)|0;bH=c[an>>2]|0;bG=c[ao>>2]|0;c[an>>2]=bG;bJ=c[ap>>2]|0;c[bJ>>2]=(c[bJ>>2]|0)+bG;c[ao>>2]=0;if(bL>>>0<384){bJ=a[aq]|0;bK=(c[8427368+(((((bJ<<24>>24==0?0:bG+bH|0)<<(bJ&255))+(c[ar>>2]&67043328)|0)>>>16&1023)+(c[as>>2]|0)<<2)>>2]|0)+(bL<<4)|0;if(bK>>>0>6143){bS=0}else{bS=c[8386392+(bK<<2)>>2]|0}c[ao>>2]=bS}bK=c[o>>2]|0;bL=(c[au>>2]|0)+(c[at>>2]|0)+(c[av>>2]&bK)|0;if(bL>>>0<384){bJ=(c[8427368+((((c[v>>2]<<16)+(c[aw>>2]&67043328)|0)>>>16&1023)+(c[ax>>2]|0)<<2)>>2]|0)+(bL<<4)|0;if(bJ>>>0>6143){bT=0}else{bT=c[8386392+(bJ<<2)>>2]|0}c[j>>2]=(c[j>>2]|0)+bT}c[v>>2]=0;bJ=(c[az>>2]|0)+(c[ay>>2]|0)+(c[aA>>2]&bK)|0;bK=c[aB>>2]|0;bL=c[aC>>2]|0;c[aB>>2]=bL;bH=c[aD>>2]|0;c[bH>>2]=(c[bH>>2]|0)+bL;c[aC>>2]=0;if(bJ>>>0<384){bH=a[aE]|0;bG=(c[8427368+(((((bH<<24>>24==0?0:bL+bK|0)<<(bH&255))+(c[aF>>2]&67043328)|0)>>>16&1023)+(c[aG>>2]|0)<<2)>>2]|0)+(bJ<<4)|0;if(bG>>>0>6143){bU=0}else{bU=c[8386392+(bG<<2)>>2]|0}c[aC>>2]=bU}bG=c[o>>2]|0;bJ=(c[aI>>2]|0)+(c[aH>>2]|0)+(c[aJ>>2]&bG)|0;if(bJ>>>0<384){bH=(c[8427368+((((c[v>>2]<<16)+(c[aK>>2]&67043328)|0)>>>16&1023)+(c[aL>>2]|0)<<2)>>2]|0)+(bJ<<4)|0;if(bH>>>0>6143){bV=0}else{bV=c[8386392+(bH<<2)>>2]|0}c[j>>2]=(c[j>>2]|0)+bV}c[v>>2]=0;bH=(c[aN>>2]|0)+(c[aM>>2]|0)+(c[aO>>2]&bG)|0;bG=c[aP>>2]|0;bJ=c[aQ>>2]|0;c[aP>>2]=bJ;bK=c[aR>>2]|0;c[bK>>2]=(c[bK>>2]|0)+bJ;c[aQ>>2]=0;if(bH>>>0<384){bK=a[aS]|0;bL=(c[8427368+(((((bK<<24>>24==0?0:bJ+bG|0)<<(bK&255))+(c[aT>>2]&67043328)|0)>>>16&1023)+(c[aU>>2]|0)<<2)>>2]|0)+(bH<<4)|0;if(bL>>>0>6143){bW=0}else{bW=c[8386392+(bL<<2)>>2]|0}c[aQ>>2]=bW}bL=c[o>>2]|0;bH=(c[aW>>2]|0)+(c[aV>>2]|0)+(c[aX>>2]&bL)|0;if(bH>>>0<384){bK=(c[8427368+((((c[v>>2]<<16)+(c[aY>>2]&67043328)|0)>>>16&1023)+(c[aZ>>2]|0)<<2)>>2]|0)+(bH<<4)|0;if(bK>>>0>6143){bX=0}else{bX=c[8386392+(bK<<2)>>2]|0}c[j>>2]=(c[j>>2]|0)+bX}do{if(a_){c[v>>2]=0;bK=(c[a$>>2]|0)+(c[e>>2]|0)+(c[a0>>2]&bL)|0;bH=c[a1>>2]|0;bG=c[a2>>2]|0;c[a1>>2]=bG;bJ=c[a3>>2]|0;c[bJ>>2]=(c[bJ>>2]|0)+bG;c[a2>>2]=0;if(bK>>>0<384){bJ=a[a4]|0;bY=(c[8427368+(((((bJ<<24>>24==0?0:bG+bH|0)<<(bJ&255))+(c[a5>>2]&67043328)|0)>>>16&1023)+(c[a6>>2]|0)<<2)>>2]|0)+(bK<<4)|0;if(bY>>>0>6143){bZ=0}else{bZ=c[8386392+(bY<<2)>>2]|0}c[a2>>2]=bZ}bY=c[o>>2]|0;bK=(c[a8>>2]|0)+(c[a7>>2]|0)+(c[a9>>2]&bY)|0;if(bK>>>0<384){bJ=(c[8427368+((((c[v>>2]<<16)+(c[ba>>2]&67043328)|0)>>>16&1023)+(c[bb>>2]|0)<<2)>>2]|0)+(bK<<4)|0;if(bJ>>>0>6143){b_=0}else{b_=c[8386392+(bJ<<2)>>2]|0}c[j>>2]=(c[j>>2]|0)+b_}c[v>>2]=0;bJ=(c[bd>>2]|0)+(c[bc>>2]|0)+(c[be>>2]&bY)|0;bY=c[bf>>2]|0;bK=c[bg>>2]|0;c[bf>>2]=bK;bH=c[bh>>2]|0;c[bH>>2]=(c[bH>>2]|0)+bK;c[bg>>2]=0;if(bJ>>>0<384){bH=a[bi]|0;bG=(c[8427368+(((((bH<<24>>24==0?0:bK+bY|0)<<(bH&255))+(c[bj>>2]&67043328)|0)>>>16&1023)+(c[bk>>2]|0)<<2)>>2]|0)+(bJ<<4)|0;if(bG>>>0>6143){b$=0}else{b$=c[8386392+(bG<<2)>>2]|0}c[bg>>2]=b$}bG=c[o>>2]|0;bJ=(c[bm>>2]|0)+(c[bl>>2]|0)+(c[bn>>2]&bG)|0;if(bJ>>>0<384){bH=(c[8427368+((((c[v>>2]<<16)+(c[bo>>2]&67043328)|0)>>>16&1023)+(c[bp>>2]|0)<<2)>>2]|0)+(bJ<<4)|0;if(bH>>>0>6143){b0=0}else{b0=c[8386392+(bH<<2)>>2]|0}c[j>>2]=(c[j>>2]|0)+b0}c[v>>2]=0;bH=(c[br>>2]|0)+(c[bq>>2]|0)+(c[bs>>2]&bG)|0;bG=c[bt>>2]|0;bJ=c[bu>>2]|0;c[bt>>2]=bJ;bY=c[bv>>2]|0;c[bY>>2]=(c[bY>>2]|0)+bJ;c[bu>>2]=0;if(bH>>>0<384){bY=a[bw]|0;bK=(c[8427368+(((((bY<<24>>24==0?0:bJ+bG|0)<<(bY&255))+(c[bx>>2]&67043328)|0)>>>16&1023)+(c[by>>2]|0)<<2)>>2]|0)+(bH<<4)|0;if(bK>>>0>6143){b1=0}else{b1=c[8386392+(bK<<2)>>2]|0}c[bu>>2]=b1}bK=(c[bA>>2]|0)+(c[bz>>2]|0)+(c[bB>>2]&c[o>>2])|0;if(bK>>>0>=384){break}bH=(c[8427368+((((c[v>>2]<<16)+(c[bC>>2]&67043328)|0)>>>16&1023)+(c[bD>>2]|0)<<2)>>2]|0)+(bK<<4)|0;if(bH>>>0>6143){b2=0}else{b2=c[8386392+(bH<<2)>>2]|0}c[j>>2]=(c[j>>2]|0)+b2}else{lA(h,u,c[bE>>2]&1)}}while(0);bL=(c[k>>2]>>11)+(c[j>>2]|0)|0;if((bL|0)>32767){b3=32767}else{b3=(bL|0)<-32768?-32768:bL&65535}b[f+(bF<<1)>>1]=b3;lB(h);bF=bF+1|0;}while((bF|0)<(g|0));return}function lG(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0;f=i;i=i+736|0;g=f|0;h=f+16|0;j=f+32|0;k=f+48|0;l=f+64|0;m=f+80|0;n=f+96|0;o=f+112|0;p=f+128|0;q=f+144|0;r=f+160|0;s=f+176|0;t=f+192|0;u=f+208|0;v=f+224|0;w=f+240|0;x=f+256|0;y=f+272|0;z=f+288|0;A=f+304|0;B=f+320|0;C=f+336|0;D=f+352|0;E=f+368|0;F=f+384|0;G=f+400|0;H=f+416|0;I=f+432|0;J=f+448|0;K=f+464|0;L=f+480|0;M=f+496|0;N=f+512|0;O=f+528|0;P=f+544|0;Q=f+560|0;R=f+576|0;S=f+592|0;T=f+608|0;U=f+624|0;V=f+640|0;W=f+656|0;X=f+672|0;Y=f+688|0;Z=f+704|0;_=f+720|0;$=c[((b|0)==3?14163952:(b|0)==2?14163944:14163936)>>2]|0;if((e&64|0)==0){i=f;return}b=_;aa=_|0;ab=_+4|0;ac=_+12|0;ad=Z;ae=Z|0;af=Z+4|0;ah=Z+12|0;ai=Y;aj=Y|0;ak=Y+4|0;al=Y+12|0;am=X;an=X|0;ao=X+4|0;ap=X+12|0;aq=W;ar=W|0;as=W+4|0;at=W+12|0;au=V;av=V|0;aw=V+4|0;ax=V+12|0;ay=U;az=U|0;aA=U+4|0;aB=U+12|0;aC=T;aD=T|0;aE=T+4|0;aF=T+12|0;aG=S;aH=S|0;aI=S+4|0;aJ=S+12|0;aK=R;aL=R|0;aM=R+4|0;aN=R+12|0;aO=Q;aP=Q|0;aQ=Q+4|0;aR=Q+12|0;aS=P;aT=P|0;aU=P+4|0;aV=P+12|0;aW=O;aX=O|0;aY=O+4|0;aZ=O+12|0;a_=N;a$=N|0;a0=N+4|0;a1=N+12|0;a2=M;a3=M|0;a4=M+4|0;a5=M+12|0;a6=L;a7=L|0;a8=L+4|0;a9=L+12|0;ba=K;bb=K|0;bc=K+4|0;bd=K+12|0;be=J;bf=J|0;bg=J+4|0;bh=J+12|0;bi=I;bj=I|0;bk=I+4|0;bl=I+12|0;bm=H;bn=H|0;bo=H+4|0;bp=H+12|0;bq=G;br=G|0;bs=G+4|0;bt=G+12|0;bu=0;do{gGz(b|0,0,12);c[aa>>2]=$+(bu*184|0)+168;c[ab>>2]=4;c[ac>>2]=586416;gj[c[2076592]&4095](_)|0;gGz(ad|0,0,12);c[ae>>2]=$+(bu*184|0)+180;c[af>>2]=1;c[ah>>2]=571936;gj[c[2076592]&4095](Z)|0;bv=0;do{gGz(ai|0,0,12);c[aj>>2]=$+(bu*184|0)+(bv*84|0);c[ak>>2]=4;c[al>>2]=441152;gj[c[2076592]&4095](Y)|0;gGz(am|0,0,12);c[an>>2]=$+(bu*184|0)+(bv*84|0)+4;c[ao>>2]=4;c[ap>>2]=340352;gj[c[2076592]&4095](X)|0;gGz(aq|0,0,12);c[ar>>2]=$+(bu*184|0)+(bv*84|0)+8;c[as>>2]=4;c[at>>2]=261704;gj[c[2076592]&4095](W)|0;gGz(au|0,0,12);c[av>>2]=$+(bu*184|0)+(bv*84|0)+12;c[aw>>2]=1;c[ax>>2]=203264;gj[c[2076592]&4095](V)|0;gGz(ay|0,0,12);c[az>>2]=$+(bu*184|0)+(bv*84|0)+13;c[aA>>2]=1;c[aB>>2]=158904;gj[c[2076592]&4095](U)|0;gGz(aC|0,0,12);c[aD>>2]=$+(bu*184|0)+(bv*84|0)+15;c[aE>>2]=1;c[aF>>2]=128408;gj[c[2076592]&4095](T)|0;gGz(aG|0,0,12);c[aH>>2]=$+(bu*184|0)+(bv*84|0)+16;c[aI>>2]=4;c[aJ>>2]=103552;gj[c[2076592]&4095](S)|0;gGz(aK|0,0,12);c[aL>>2]=$+(bu*184|0)+(bv*84|0)+24;c[aM>>2]=1;c[aN>>2]=79912;gj[c[2076592]&4095](R)|0;gGz(aO|0,0,12);c[aP>>2]=$+(bu*184|0)+(bv*84|0)+32;c[aQ>>2]=8;c[aR>>2]=586368;gj[c[2076592]&4095](Q)|0;gGz(aS|0,0,12);c[aT>>2]=$+(bu*184|0)+(bv*84|0)+40;c[aU>>2]=1;c[aV>>2]=569736;gj[c[2076592]&4095](P)|0;gGz(aW|0,0,12);c[aX>>2]=$+(bu*184|0)+(bv*84|0)+41;c[aY>>2]=1;c[aZ>>2]=553688;gj[c[2076592]&4095](O)|0;gGz(a_|0,0,12);c[a$>>2]=$+(bu*184|0)+(bv*84|0)+42;c[a0>>2]=1;c[a1>>2]=538992;gj[c[2076592]&4095](N)|0;gGz(a2|0,0,12);c[a3>>2]=$+(bu*184|0)+(bv*84|0)+44;c[a4>>2]=4;c[a5>>2]=525592;gj[c[2076592]&4095](M)|0;gGz(a6|0,0,12);c[a7>>2]=$+(bu*184|0)+(bv*84|0)+52;c[a8>>2]=4;c[a9>>2]=511928;gj[c[2076592]&4095](L)|0;gGz(ba|0,0,12);c[bb>>2]=$+(bu*184|0)+(bv*84|0)+56;c[bc>>2]=4;c[bd>>2]=499160;gj[c[2076592]&4095](K)|0;gGz(be|0,0,12);c[bf>>2]=$+(bu*184|0)+(bv*84|0)+68;c[bg>>2]=4;c[bh>>2]=487704;gj[c[2076592]&4095](J)|0;gGz(bi|0,0,12);c[bj>>2]=$+(bu*184|0)+(bv*84|0)+72;c[bk>>2]=4;c[bl>>2]=474752;gj[c[2076592]&4095](I)|0;gGz(bm|0,0,12);c[bn>>2]=$+(bu*184|0)+(bv*84|0)+76;c[bo>>2]=1;c[bp>>2]=463320;gj[c[2076592]&4095](H)|0;gGz(bq|0,0,12);c[br>>2]=$+(bu*184|0)+(bv*84|0)+80;c[bs>>2]=4;c[bt>>2]=452144;gj[c[2076592]&4095](G)|0;bv=bv+1|0;}while((bv|0)<2);bu=bu+1|0;}while((bu|0)<9);gGz(F|0,0,12);c[F>>2]=$+1656;c[F+4>>2]=4;c[F+12>>2]=441392;gj[c[2076592]&4095](F)|0;gGz(E|0,0,12);c[E>>2]=$+1660;c[E+4>>2]=4;c[E+12>>2]=429648;gj[c[2076592]&4095](E)|0;gGz(D|0,0,12);c[D>>2]=$+1672;c[D+4>>2]=1;c[D+12>>2]=418344;gj[c[2076592]&4095](D)|0;gGz(C|0,0,12);c[C>>2]=$+5780;c[C+4>>2]=1;c[C+12>>2]=406504;gj[c[2076592]&4095](C)|0;gGz(B|0,0,12);c[B>>2]=$+5781;c[B+4>>2]=1;c[B+12>>2]=395984;gj[c[2076592]&4095](B)|0;gGz(A|0,0,12);c[A>>2]=$+5784;c[A+4>>2]=4;c[A+12>>2]=383728;gj[c[2076592]&4095](A)|0;gGz(z|0,0,12);c[z>>2]=$+5792;c[z+4>>2]=4;c[z+12>>2]=374080;gj[c[2076592]&4095](z)|0;gGz(y|0,0,12);c[y>>2]=$+5800;c[y+4>>2]=4;c[y+12>>2]=364184;gj[c[2076592]&4095](y)|0;gGz(x|0,0,12);c[x>>2]=$+5804;c[x+4>>2]=4;c[x+12>>2]=356824;gj[c[2076592]&4095](x)|0;x=$+5884|0;if((a[x]&1)!=0){gGz(w|0,0,12);c[w>>2]=$+5812;c[w+4>>2]=1;c[w+12>>2]=348840;y=c[2076592]|0;gj[y&4095](w)|0}gGz(v|0,0,12);c[v>>2]=$+5816;c[v+4>>2]=8;c[v+12>>2]=341160;gj[c[2076592]&4095](v)|0;gGz(u|0,0,12);c[u>>2]=$+5824;c[u+4>>2]=2;c[u+12>>2]=333192;gj[c[2076592]&4095](u)|0;u=a[x]|0;do{if((u&2)==0){bw=u}else{v=$+5828|0;w=c[v>>2]|0;if((w|0)==0){bw=u;break}gGz(t|0,0,12);c[t>>2]=w+82;c[t+4>>2]=1;c[t+12>>2]=324376;w=c[2076592]|0;gj[w&4095](t)|0;w=(c[v>>2]|0)+32|0;gGz(s|0,0,12);c[s>>2]=w;c[s+4>>2]=4;c[s+12>>2]=315640;w=c[2076592]|0;gj[w&4095](s)|0;w=(c[v>>2]|0)+36|0;gGz(r|0,0,12);c[r>>2]=w;c[r+4>>2]=4;c[r+12>>2]=307040;w=c[2076592]|0;gj[w&4095](r)|0;w=(c[v>>2]|0)+64|0;gGz(q|0,0,12);c[q>>2]=w;c[q+4>>2]=4;c[q+12>>2]=298896;w=c[2076592]|0;gj[w&4095](q)|0;w=(c[v>>2]|0)+76|0;gGz(p|0,0,12);c[p>>2]=w;c[p+4>>2]=4;c[p+12>>2]=291416;w=c[2076592]|0;gj[w&4095](p)|0;w=(c[v>>2]|0)+68|0;gGz(o|0,0,12);c[o>>2]=w;c[o+4>>2]=4;c[o+12>>2]=284992;w=c[2076592]|0;gj[w&4095](o)|0;w=(c[v>>2]|0)+72|0;gGz(n|0,0,12);c[n>>2]=w;c[n+4>>2]=4;c[n+12>>2]=278304;w=c[2076592]|0;gj[w&4095](n)|0;bw=a[x]|0}}while(0);if((bw&8)!=0){gGz(m|0,0,12);c[m>>2]=$+5832;c[m+4>>2]=1;c[m+12>>2]=270840;bw=c[2076592]|0;gj[bw&4095](m)|0;gGz(l|0,0,12);c[l>>2]=$+5833;c[l+4>>2]=1;c[l+12>>2]=263624;m=c[2076592]|0;gj[m&4095](l)|0}gGz(k|0,0,12);c[k>>2]=$+5885;c[k+4>>2]=1;c[k+12>>2]=255240;gj[c[2076592]&4095](k)|0;gGz(j|0,0,12);c[j>>2]=$+5886;c[j+4>>2]=1;c[j+12>>2]=247272;gj[c[2076592]&4095](j)|0;gGz(h|0,0,12);c[h>>2]=$+5887;c[h+4>>2]=1;c[h+12>>2]=240576;gj[c[2076592]&4095](h)|0;gGz(g|0,0,12);c[g>>2]=$+5888;c[g+4>>2]=1;c[g+12>>2]=234232;gj[c[2076592]&4095](g)|0;if((e&2|0)==0){i=f;return}e=$+5924|0;g=$+5920|0;h=0;do{j=c[$+(h*184|0)+168>>2]|0;k=$+(h*184|0)+176|0;c[k>>2]=c[45296+(j>>>6<<2)>>2];l=$+(h*184|0)+172|0;c[l>>2]=(c[$+1676+((j&1023)<<2)>>2]|0)>>>((7-(j>>>10)|0)>>>0);j=$+(h*184|0)+180|0;m=0;do{bw=(d[j]|0)>>>((d[$+(h*184|0)+(m*84|0)+12|0]|0)>>>0);a[$+(h*184|0)+(m*84|0)+14|0]=bw&255;x=bw&255;bw=x+(c[$+(h*184|0)+(m*84|0)>>2]|0)|0;if(bw>>>0<78){a[$+(h*184|0)+(m*84|0)+60|0]=a[52016+bw|0]|0;a[$+(h*184|0)+(m*84|0)+61|0]=a[52368+bw|0]|0}else{a[$+(h*184|0)+(m*84|0)+60|0]=0;a[$+(h*184|0)+(m*84|0)+61|0]=104}bw=(c[$+(h*184|0)+(m*84|0)+4>>2]|0)+x|0;a[$+(h*184|0)+(m*84|0)+62|0]=a[52016+bw|0]|0;a[$+(h*184|0)+(m*84|0)+63|0]=a[52368+bw|0]|0;bw=(c[$+(h*184|0)+(m*84|0)+8>>2]|0)+x|0;a[$+(h*184|0)+(m*84|0)+64|0]=a[52016+bw|0]|0;a[$+(h*184|0)+(m*84|0)+65|0]=a[52368+bw|0]|0;c[$+(h*184|0)+(m*84|0)+20>>2]=ag(d[$+(h*184|0)+(m*84|0)+15|0]|0,c[l>>2]|0)|0;c[$+(h*184|0)+(m*84|0)+48>>2]=((c[k>>2]|0)>>>((d[$+(h*184|0)+(m*84|0)+13|0]|0)>>>0))+(c[$+(h*184|0)+(m*84|0)+44>>2]|0);c[$+(h*184|0)+(m*84|0)+28>>2]=(a[$+(h*184|0)+(m*84|0)+40|0]|0)==0?g:e;m=m+1|0;}while((m|0)<2);h=h+1|0;}while((h|0)<9);i=f;return}function lH(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0.0,B=0.0,C=0,D=0,E=0,F=0,G=0;g=e&255;i=f&255;switch(e&224|0){case 32:{j=e&31;if((-4144960>>>(j>>>0)&1|0)!=0){return}k=c[2576+(j<<2)>>2]|0;j=(k|0)/2|0;l=k&1;k=a[10040+(f&15)|0]|0;a[b+(j*184|0)+(l*84|0)+15|0]=k;m=f>>>3&2^2;a[b+(j*184|0)+(l*84|0)+12|0]=m&255;n=f&255;a[b+(j*184|0)+(l*84|0)+41|0]=n&32;a[b+(j*184|0)+(l*84|0)+76|0]=n&64;c[b+(j*184|0)+(l*84|0)+72>>2]=f<<24>>31;c[b+(j*184|0)+(l*84|0)+20>>2]=ag(k&255,c[b+(j*184|0)+172>>2]|0)|0;k=(d[b+(j*184|0)+180|0]|0)>>>(m>>>0);m=b+(j*184|0)+(l*84|0)+14|0;if((d[m]|0)==(k|0)){return}a[m]=k&255;m=k&255;k=(c[b+(j*184|0)+(l*84|0)>>2]|0)+m|0;if(k>>>0<78){a[b+(j*184|0)+(l*84|0)+60|0]=a[52016+k|0]|0;a[b+(j*184|0)+(l*84|0)+61|0]=a[52368+k|0]|0}else{a[b+(j*184|0)+(l*84|0)+60|0]=0;a[b+(j*184|0)+(l*84|0)+61|0]=104}k=(c[b+(j*184|0)+(l*84|0)+4>>2]|0)+m|0;a[b+(j*184|0)+(l*84|0)+62|0]=a[52016+k|0]|0;a[b+(j*184|0)+(l*84|0)+63|0]=a[52368+k|0]|0;k=(c[b+(j*184|0)+(l*84|0)+8>>2]|0)+m|0;a[b+(j*184|0)+(l*84|0)+64|0]=a[52016+k|0]|0;a[b+(j*184|0)+(l*84|0)+65|0]=a[52368+k|0]|0;return};case 160:{if((g|0)!=189){k=e&15;if(k>>>0>8){return}do{if((e&16|0)==0){l=c[b+(k*184|0)+168>>2]|0;o=l&7936|i;p=l}else{l=c[b+(k*184|0)+168>>2]|0;j=l&255|f<<8&7936;m=b+(k*184|0)+68|0;n=c[m>>2]|0;q=(n|0)==0;if((f&32|0)!=0){if(q){c[b+(k*184|0)+16>>2]=0;a[b+(k*184|0)+42|0]=4}c[m>>2]=n|1;r=b+(k*184|0)+152|0;s=c[r>>2]|0;if((s|0)==0){c[b+(k*184|0)+100>>2]=0;a[b+(k*184|0)+126|0]=4}c[r>>2]=s|1;o=j;p=l;break}do{if(!q){s=n&-2;c[m>>2]=s;if((s|0)!=0){break}s=b+(k*184|0)+42|0;if((d[s]|0)<=1){break}a[s]=1}}while(0);m=b+(k*184|0)+152|0;n=c[m>>2]|0;if((n|0)==0){o=j;p=l;break}q=n&-2;c[m>>2]=q;if((q|0)!=0){o=j;p=l;break}q=b+(k*184|0)+126|0;if((d[q]|0)<=1){o=j;p=l;break}a[q]=1;o=j;p=l}}while(0);if((p|0)==(o|0)){return}c[b+(k*184|0)+168>>2]=o;p=c[45296+(o>>6<<2)>>2]|0;c[b+(k*184|0)+176>>2]=p;q=(c[b+1676+((o&1023)<<2)>>2]|0)>>>((7-(o>>>10&255)|0)>>>0);c[b+(k*184|0)+172>>2]=q;m=o>>>9;n=m&14;s=b+(k*184|0)+180|0;a[s]=n;if((a[b+5888|0]&64)==0){t=n&255|m&1}else{t=n&255|o>>>8&1}o=t&255;a[s]=o;c[b+(k*184|0)+48>>2]=(p>>>((d[b+(k*184|0)+13|0]|0)>>>0))+(c[b+(k*184|0)+44>>2]|0);c[b+(k*184|0)+132>>2]=(p>>>((d[b+(k*184|0)+97|0]|0)>>>0))+(c[b+(k*184|0)+128>>2]|0);c[b+(k*184|0)+20>>2]=ag(d[b+(k*184|0)+15|0]|0,q)|0;p=o&255;o=p>>>((d[b+(k*184|0)+12|0]|0)>>>0);s=b+(k*184|0)+14|0;if((d[s]|0)!=(o|0)){a[s]=o&255;s=o&255;o=(c[b+(k*184|0)>>2]|0)+s|0;if(o>>>0<78){a[b+(k*184|0)+60|0]=a[52016+o|0]|0;a[b+(k*184|0)+61|0]=a[52368+o|0]|0}else{a[b+(k*184|0)+60|0]=0;a[b+(k*184|0)+61|0]=104}o=(c[b+(k*184|0)+4>>2]|0)+s|0;a[b+(k*184|0)+62|0]=a[52016+o|0]|0;a[b+(k*184|0)+63|0]=a[52368+o|0]|0;o=(c[b+(k*184|0)+8>>2]|0)+s|0;a[b+(k*184|0)+64|0]=a[52016+o|0]|0;a[b+(k*184|0)+65|0]=a[52368+o|0]|0}c[b+(k*184|0)+104>>2]=ag(d[b+(k*184|0)+99|0]|0,q)|0;q=p>>>((d[b+(k*184|0)+96|0]|0)>>>0);p=b+(k*184|0)+98|0;if((d[p]|0)==(q|0)){return}a[p]=q&255;p=q&255;q=(c[b+(k*184|0)+84>>2]|0)+p|0;if(q>>>0<78){a[b+(k*184|0)+144|0]=a[52016+q|0]|0;a[b+(k*184|0)+145|0]=a[52368+q|0]|0}else{a[b+(k*184|0)+144|0]=0;a[b+(k*184|0)+145|0]=104}q=(c[b+(k*184|0)+88>>2]|0)+p|0;a[b+(k*184|0)+146|0]=a[52016+q|0]|0;a[b+(k*184|0)+147|0]=a[52368+q|0]|0;q=(c[b+(k*184|0)+92>>2]|0)+p|0;a[b+(k*184|0)+148|0]=a[52016+q|0]|0;a[b+(k*184|0)+149|0]=a[52368+q|0]|0;return}q=f&255;a[b+5780|0]=q&-128;a[b+5781|0]=f>>>3&8;a[b+1672|0]=q&63;if((q&32)==0){q=b+1172|0;k=c[q>>2]|0;do{if((k|0)!=0){p=k&-3;c[q>>2]=p;if((p|0)!=0){break}p=b+1146|0;if((d[p]|0)<=1){break}a[p]=1}}while(0);q=b+1256|0;k=c[q>>2]|0;do{if((k|0)!=0){p=k&-3;c[q>>2]=p;if((p|0)!=0){break}p=b+1230|0;if((d[p]|0)<=1){break}a[p]=1}}while(0);q=b+1356|0;k=c[q>>2]|0;do{if((k|0)!=0){p=k&-3;c[q>>2]=p;if((p|0)!=0){break}p=b+1330|0;if((d[p]|0)<=1){break}a[p]=1}}while(0);q=b+1440|0;k=c[q>>2]|0;do{if((k|0)!=0){p=k&-3;c[q>>2]=p;if((p|0)!=0){break}p=b+1414|0;if((d[p]|0)<=1){break}a[p]=1}}while(0);q=b+1540|0;k=c[q>>2]|0;do{if((k|0)!=0){p=k&-3;c[q>>2]=p;if((p|0)!=0){break}p=b+1514|0;if((d[p]|0)<=1){break}a[p]=1}}while(0);q=b+1624|0;k=c[q>>2]|0;if((k|0)==0){return}p=k&-3;c[q>>2]=p;if((p|0)!=0){return}p=b+1598|0;if((d[p]|0)<=1){return}a[p]=1;return}p=b+1172|0;q=c[p>>2]|0;k=(q|0)==0;do{if((f&16|0)==0){do{if(!k){o=q&-3;c[p>>2]=o;if((o|0)!=0){break}o=b+1146|0;if((d[o]|0)<=1){break}a[o]=1}}while(0);l=b+1256|0;j=c[l>>2]|0;if((j|0)==0){break}o=j&-3;c[l>>2]=o;if((o|0)!=0){break}o=b+1230|0;if((d[o]|0)<=1){break}a[o]=1}else{if(k){c[b+1120>>2]=0;a[b+1146|0]=4}c[p>>2]=q|2;o=b+1256|0;l=c[o>>2]|0;if((l|0)==0){c[b+1204>>2]=0;a[b+1230|0]=4}c[o>>2]=l|2}}while(0);q=b+1356|0;p=c[q>>2]|0;k=(p|0)==0;do{if((f&1|0)==0){if(k){break}l=p&-3;c[q>>2]=l;if((l|0)!=0){break}l=b+1330|0;if((d[l]|0)<=1){break}a[l]=1}else{if(k){c[b+1304>>2]=0;a[b+1330|0]=4}c[q>>2]=p|2}}while(0);p=b+1440|0;q=c[p>>2]|0;k=(q|0)==0;do{if((f&8|0)==0){if(k){break}l=q&-3;c[p>>2]=l;if((l|0)!=0){break}l=b+1414|0;if((d[l]|0)<=1){break}a[l]=1}else{if(k){c[b+1388>>2]=0;a[b+1414|0]=4}c[p>>2]=q|2}}while(0);q=b+1540|0;p=c[q>>2]|0;k=(p|0)==0;do{if((f&4|0)==0){if(k){break}l=p&-3;c[q>>2]=l;if((l|0)!=0){break}l=b+1514|0;if((d[l]|0)<=1){break}a[l]=1}else{if(k){c[b+1488>>2]=0;a[b+1514|0]=4}c[q>>2]=p|2}}while(0);p=b+1624|0;q=c[p>>2]|0;k=(q|0)==0;if((f&2|0)!=0){if(k){c[b+1572>>2]=0;a[b+1598|0]=4}c[p>>2]=q|2;return}if(k){return}k=q&-3;c[p>>2]=k;if((k|0)!=0){return}k=b+1598|0;if((d[k]|0)<=1){return}a[k]=1;return};case 0:{switch(e&31|0){case 3:{c[b+5820>>2]=256-i<<4;return};case 24:{if((a[b+5884|0]&8)==0){return}a[b+5832|0]=f&15;return};case 1:{if((a[b+5884|0]&1)==0){return}a[b+5812|0]=f&32;return};case 2:{c[b+5816>>2]=256-i<<2;return};case 8:{a[b+5888|0]=f&255;if((a[b+5884|0]&2)==0){return}lr(c[b+5828>>2]|0,g-7|0,f&15);return};case 6:{if((a[b+5884|0]&4)==0){return}k=c[b+5852>>2]|0;if((k|0)==0){return}gg[k&4095](c[b+5856>>2]|0,f&255);return};case 25:{if((a[b+5884|0]&8)==0){return}a[b+5833|0]=f&255;k=c[b+5840>>2]|0;if((k|0)==0){return}gg[k&4095](c[b+5844>>2]|0,d[b+5832|0]&f&255);return};case 9:case 10:case 11:case 12:case 13:case 14:case 15:case 16:case 17:case 18:{if((a[b+5884|0]&2)==0){return}lr(c[b+5828>>2]|0,g-7|0,i);return};case 7:{if((a[b+5884|0]&2)==0){return}lr(c[b+5828>>2]|0,g-7|0,i);return};case 4:{if((f&128|0)!=0){g=b+5886|0;k=a[g]|0;p=k&255;q=p&136;a[g]=q&255;if((p&128|0)==0){return}if((d[b+5887|0]&q|0)!=0){return}a[g]=k&8;k=c[b+5868>>2]|0;if((k|0)==0){return}gg[k&4095](c[b+5872>>2]|0,0);return}k=f&1;g=f>>>1&1;q=b+5886|0;p=d[q]|0;l=p&(f&112^255);o=l&255;a[q]=o;j=b+5887|0;do{if((p&128|0)==0){u=o;v=10738}else{if((d[j]&l|0)!=0){u=o;v=10738;break}s=o&127;a[q]=s;t=c[b+5868>>2]|0;if((t|0)==0){n=(f&120^120)&255;a[j]=n;w=s;x=n;v=10739;break}else{gg[t&4095](c[b+5872>>2]|0,0);u=a[q]|0;v=10738;break}}}while(0);if((v|0)==10738){o=(f&120^120)&255;a[j]=o;if(u<<24>>24>-1){w=u;x=o;v=10739}else{y=u;z=o;v=10743}}do{if((v|0)==10739){if((w&x)<<24>>24==0){break}o=w|-128;a[q]=o;u=c[b+5868>>2]|0;if((u|0)==0){y=o;z=x;v=10743;break}gg[u&4095](c[b+5872>>2]|0,1);u=a[q]|0;if(u<<24>>24>-1){break}y=u;z=a[j]|0;v=10743}}while(0);do{if((v|0)==10743){if((y&z)<<24>>24!=0){break}a[q]=y&127;j=c[b+5868>>2]|0;if((j|0)==0){break}gg[j&4095](c[b+5872>>2]|0,0)}}while(0);y=b+5825|0;do{if((a[y]|0)!=g<<24>>24){if(g<<24>>24==0){A=0.0}else{A=+(c[b+5820>>2]|0)*+h[b+5912>>3]}a[y]=g;q=c[b+5860>>2]|0;if((q|0)==0){break}gd[q&15]((c[b+5864>>2]|0)+1|0,A)}}while(0);g=b+5824|0;if((a[g]|0)==k<<24>>24){return}if(k<<24>>24==0){B=0.0}else{B=+(c[b+5816>>2]|0)*+h[b+5912>>3]}a[g]=k;k=c[b+5860>>2]|0;if((k|0)==0){return}gd[k&15](c[b+5864>>2]|0,B);return};default:{return}}break};case 96:{k=e&31;if((-4144960>>>(k>>>0)&1|0)!=0){return}g=c[2576+(k<<2)>>2]|0;k=(g|0)/2|0;y=g&1;g=i>>>4;if((g|0)==0){C=0}else{C=(g<<2)+16|0}c[b+(k*184|0)+(y*84|0)>>2]=C;g=d[b+(k*184|0)+(y*84|0)+14|0]|0;q=g+C|0;if(q>>>0<78){a[b+(k*184|0)+(y*84|0)+60|0]=a[52016+q|0]|0;a[b+(k*184|0)+(y*84|0)+61|0]=a[52368+q|0]|0}else{a[b+(k*184|0)+(y*84|0)+60|0]=0;a[b+(k*184|0)+(y*84|0)+61|0]=104}q=f&15;if((q|0)==0){D=0}else{D=(q<<2)+16|0}c[b+(k*184|0)+(y*84|0)+4>>2]=D;q=D+g|0;a[b+(k*184|0)+(y*84|0)+62|0]=a[52016+q|0]|0;a[b+(k*184|0)+(y*84|0)+63|0]=a[52368+q|0]|0;return};case 64:{q=e&31;if((-4144960>>>(q>>>0)&1|0)!=0){return}y=c[2576+(q<<2)>>2]|0;q=(y|0)/2|0;k=y&1;y=i>>>6;if((y|0)==0){E=31}else{E=(y^3)&255}a[b+(q*184|0)+(k*84|0)+13|0]=E;y=i<<2&252;c[b+(q*184|0)+(k*84|0)+44>>2]=y;c[b+(q*184|0)+(k*84|0)+48>>2]=((c[b+(q*184|0)+176>>2]|0)>>>((E&255)>>>0))+y;return};case 128:{y=e&31;if((-4144960>>>(y>>>0)&1|0)!=0){return}E=c[2576+(y<<2)>>2]|0;y=(E|0)/2|0;q=E&1;c[b+(y*184|0)+(q*84|0)+56>>2]=c[2768+(i>>>4<<2)>>2];i=f&15;if((i|0)==0){F=0}else{F=(i<<2)+16|0}c[b+(y*184|0)+(q*84|0)+8>>2]=F;i=(d[b+(y*184|0)+(q*84|0)+14|0]|0)+F|0;a[b+(y*184|0)+(q*84|0)+64|0]=a[52016+i|0]|0;a[b+(y*184|0)+(q*84|0)+65|0]=a[52368+i|0]|0;return};case 224:{if((a[b+5812|0]|0)==0){return}i=e&31;q=c[2576+(i<<2)>>2]|0;if((-4144960>>>(i>>>0)&1|0)!=0){return}c[b+(((q|0)/2|0)*184|0)+((q&1)*84|0)+80>>2]=f<<10&3072;return};case 192:{q=e&15;if(q>>>0>8){return}e=f>>>1&7;if((e|0)==0){G=0}else{G=e+7&255}a[b+(q*184|0)+24|0]=G;G=f&1;a[b+(q*184|0)+40|0]=G;c[b+(q*184|0)+28>>2]=G<<24>>24==0?b+5920|0:b+5924|0;return};default:{return}}}function lI(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,i=0,j=0.0,k=0.0,l=0,m=0,n=0,o=0,p=0;g=c[a+16>>2]|0;i=c[a+12>>2]|0;j=+(i|0);if((g|0)==0){k=0.0}else{k=j/+(g|0)/+(b|0)}b=a+24|0;h[b>>3]=k;c[a+1200>>2]=~~(k*65536.0);c[a+1204>>2]=196608;h[a+32>>3]=1.0/(j/+(e|0));if((f|0)==0){l=0}else{e=(d[a+8|0]|0)+(c[2383582]|0)|0;g=(i<<1|0)/(f|0)|0;c[14168936+(e*252|0)>>2]=~~((+((g|0)/2|0|0)+ +(c[14168892+(e*252|0)>>2]|0)*32768.0*8.0)/+(g|0));l=0}while(1){g=~~(+h[b>>3]*+((d[53008+l|0]|0)>>>0)*1024.0*65536.0*9.5367431640625e-7);c[a+76+(l<<2)>>2]=g;c[a+588+(l<<2)>>2]=-g;g=l+1|0;if((g|0)<32){l=g}else{m=0;break}}while(1){l=~~(+h[b>>3]*+((d[m+53040|0]|0)>>>0)*1024.0*65536.0*9.5367431640625e-7);c[a+204+(m<<2)>>2]=l;c[a+716+(m<<2)>>2]=-l;l=m+1|0;if((l|0)<32){m=l}else{n=0;break}}while(1){m=~~(+h[b>>3]*+((d[n+53072|0]|0)>>>0)*1024.0*65536.0*9.5367431640625e-7);c[a+332+(n<<2)>>2]=m;c[a+844+(n<<2)>>2]=-m;m=n+1|0;if((m|0)<32){n=m}else{o=0;break}}while(1){n=~~(+h[b>>3]*+((d[o+53104|0]|0)>>>0)*1024.0*65536.0*9.5367431640625e-7);c[a+460+(o<<2)>>2]=n;c[a+972+(o<<2)>>2]=-n;n=o+1|0;if((n|0)<32){o=n}else{p=0;break}}do{c[a+1208+(p<<2)>>2]=~~(+h[b>>3]*+(p|0)*32.0*64.0);p=p+1|0;}while((p|0)<4096);j=+h[b>>3];c[a+17592>>2]=~~(j*131072.0*64.0);c[a+17604>>2]=~~(j*155344.59259259258);c[a+17608>>2]=~~(j*217885.9220779221);c[a+17612>>2]=~~(j*236298.81690140846);c[a+17616>>2]=~~(j*250406.20895522388);c[a+17620>>2]=~~(j*270600.2580645161);c[a+17624>>2]=~~(j*381300.36363636365);c[a+17628>>2]=~~(j*2097152.0);c[a+17632>>2]=~~(j*3355443.2);return}function lJ(a,e,f){a=a|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=c[3541518]|0;h=g+(a*19024|0)+256|0;c[2383472]=g+(a*19024|0);c[3532586]=g+(a*19024|0)+264;i=g+(a*19024|0)+17896|0;c[2383566]=i;j=g+(a*19024|0)+18272|0;c[2383564]=j;k=g+(a*19024|0)+18648|0;c[2383562]=k;if((c[g+(a*19024|0)+17932>>2]|0)==-1){l=c[g+(a*19024|0)+18260>>2]|0;m=d[g+(a*19024|0)+18264|0]|0;lK(h,i|0,l,m);lK(h,g+(a*19024|0)+18056|0,l,m);lK(h,g+(a*19024|0)+17976|0,l,m);lK(h,g+(a*19024|0)+18136|0,l,m)}if((c[g+(a*19024|0)+18308>>2]|0)==-1){m=c[g+(a*19024|0)+18636>>2]|0;l=d[g+(a*19024|0)+18640|0]|0;lK(h,j|0,m,l);lK(h,g+(a*19024|0)+18432|0,m,l);lK(h,g+(a*19024|0)+18352|0,m,l);lK(h,g+(a*19024|0)+18512|0,m,l)}l=(c[g+(a*19024|0)+18684>>2]|0)==-1;do{if((c[g+(a*19024|0)+308>>2]&192|0)==0){if(!l){break}m=c[g+(a*19024|0)+19012>>2]|0;n=d[g+(a*19024|0)+19016|0]|0;lK(h,k|0,m,n);lK(h,g+(a*19024|0)+18808|0,m,n);lK(h,g+(a*19024|0)+18728|0,m,n);lK(h,g+(a*19024|0)+18888|0,m,n)}else{if(!l){break}lK(h,k|0,c[g+(a*19024|0)+1372>>2]|0,d[g+(a*19024|0)+1382|0]|0);lK(h,g+(a*19024|0)+18808|0,c[g+(a*19024|0)+1376>>2]|0,d[g+(a*19024|0)+1383|0]|0);lK(h,g+(a*19024|0)+18728|0,c[g+(a*19024|0)+1368>>2]|0,d[g+(a*19024|0)+1381|0]|0);lK(h,g+(a*19024|0)+18888|0,c[g+(a*19024|0)+19012>>2]|0,d[g+(a*19024|0)+19016|0]|0)}}while(0);c[3541216]=0;c[3541212]=0;if((f|0)<=0){return}l=g+(a*19024|0)+1456|0;n=g+(a*19024|0)+1452|0;m=g+(a*19024|0)+1460|0;o=g+(a*19024|0)+1448|0;a=i|0;g=j|0;p=k|0;q=0;do{c[2112986]=0;c[2112987]=0;c[2112988]=0;r=(c[n>>2]|0)+(c[l>>2]|0)|0;c[n>>2]=r;s=c[m>>2]|0;if(r>>>0>=s>>>0){t=r;r=s;do{c[n>>2]=t-r;c[o>>2]=(c[o>>2]|0)+1;lL(h,a);lL(h,g);lL(h,p);t=c[n>>2]|0;r=c[m>>2]|0;}while(t>>>0>=r>>>0)}lM(h,i,0);lM(h,j,1);lM(h,k,2);r=(c[2112987]|0)+(c[2112986]|0)+(c[2112988]|0)|0;if((r|0)>32767){u=32767}else{u=(r|0)<-32768?-32768:r&65535}b[e+(q<<1)>>1]=u;q=q+1|0;}while((q|0)<(f|0));return}function lK(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;h=g>>(d[e+4|0]|0);i=(c[(c[e>>2]|0)+(g<<2)>>2]|0)+f|0;if((i|0)<0){j=(c[b+17592>>2]|0)+i|0}else{j=i}c[e+36>>2]=(ag(c[e+28>>2]|0,j)|0)>>>1;j=e+24|0;if((d[j]|0|0)==(h|0)){return}a[j]=h&255;j=h&255;h=(c[e+8>>2]|0)+j|0;do{if(h>>>0<94){a[e+60|0]=a[51792+h|0]|0;i=b|0;f=a[i]|0;if((f<<24>>24|0)==14|(f<<24>>24|0)==23){a[e+61|0]=a[52112+h|0]|0;k=i;break}else{a[e+61|0]=a[52240+h|0]|0;k=i;break}}else{a[e+60|0]=0;a[e+61|0]=-120;k=b|0}}while(0);b=(c[e+12>>2]|0)+j|0;a[e+62|0]=a[51792+b|0]|0;h=(c[e+16>>2]|0)+j|0;a[e+64|0]=a[51792+h|0]|0;i=(c[e+20>>2]|0)+j|0;a[e+66|0]=a[51792+i|0]|0;j=a[k]|0;if((j<<24>>24|0)==14|(j<<24>>24|0)==23){a[e+63|0]=a[52112+b|0]|0;a[e+65|0]=a[52112+h|0]|0;a[e+67|0]=a[52112+i|0]|0;return}else{a[e+63|0]=a[52240+b|0]|0;a[e+65|0]=a[52240+h|0]|0;a[e+67|0]=a[52240+i|0]|0;return}}function lL(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=b+1192|0;g=b|0;b=4;h=e;while(1){e=h+40|0;i=d[e]|0;do{if((i|0)==2){j=a[h+68|0]|0;k=c[f>>2]|0;l=d[h+64|0]|0;m=((1<<l)-1&k|0)!=0;if((j&8)==0){if(m){n=0;break}o=h+48|0;p=(c[o>>2]|0)+(d[52464+((d[h+65|0]|0)+(k>>>(l>>>0)&7))|0]|0)|0;c[o>>2]=p;if((p|0)<=1022){n=0;break}c[o>>2]=1023;n=0;break}if(m){n=0;break}m=a[g]|0;if((m<<24>>24|0)==14|(m<<24>>24|0)==23){m=h+48|0;o=((d[52464+((d[h+65|0]|0)+(k>>>(l>>>0)&7))|0]|0)*6|0)+(c[m>>2]|0)|0;c[m>>2]=o;q=o}else{o=h+48|0;m=((d[52464+((d[h+65|0]|0)+(k>>>(l>>>0)&7))|0]|0)<<2)+(c[o>>2]|0)|0;c[o>>2]=m;q=m}m=h+48|0;if((q|0)<=831){n=0;break}o=a[g]|0;if(!((o<<24>>24|0)==14|(o<<24>>24|0)==23)){c[m>>2]=1023}if((j&1)!=0){if((a[h+69|0]&1)!=0){n=0;break}n=j&2|1;break}c[h+32>>2]=0;o=a[g]|0;do{if((o<<24>>24|0)==14|(o<<24>>24|0)==23){if(((d[h+24|0]|0)+(c[h+8>>2]|0)|0)>>>0<94){a[e]=4;break}else{c[m>>2]=0;a[e]=(c[h+52>>2]|0)==0?2:3;break}}else{c[m>>2]=511;a[e]=4}}while(0);n=j&2}else if((i|0)==3){m=a[g]|0;if((m<<24>>24|0)==14|(m<<24>>24|0)==23){m=c[f>>2]|0;o=d[h+62|0]|0;do{if(((1<<o)-1&m|0)==0){l=d[52464+((d[h+63|0]|0)+(m>>>(o>>>0)&7))|0]|0;if((a[h+68|0]&8)==0){k=h+48|0;p=(c[k>>2]|0)+l|0;c[k>>2]=p;r=p;break}else{p=h+48|0;k=(c[p>>2]|0)+(l*6|0)|0;c[p>>2]=k;r=k;break}}else{r=c[h+48>>2]|0}}while(0);o=c[h+52>>2]|0;if((r|0)<(o|0)){n=0;break}c[h+48>>2]=o;a[e]=2;n=0;break}else{o=c[f>>2]|0;m=d[h+62|0]|0;j=((1<<m)-1&o|0)!=0;if((a[h+68|0]&8)==0){if(j){n=0;break}k=h+48|0;p=(c[k>>2]|0)+(d[52464+((d[h+63|0]|0)+(o>>>(m>>>0)&7))|0]|0)|0;c[k>>2]=p;if((p|0)<(c[h+52>>2]|0)){n=0;break}a[e]=2;n=0;break}else{if(j){n=0;break}j=h+48|0;p=((d[52464+((d[h+63|0]|0)+(o>>>(m>>>0)&7))|0]|0)<<2)+(c[j>>2]|0)|0;c[j>>2]=p;if((p|0)<(c[h+52>>2]|0)){n=0;break}a[e]=2;n=0;break}}}else if((i|0)==4){p=c[f>>2]|0;j=d[h+60|0]|0;if(((1<<j)-1&p|0)!=0){n=0;break}m=h+48|0;o=c[m>>2]|0;k=((ag(d[52464+((d[h+61|0]|0)+(p>>>(j>>>0)&7))|0]|0,~o)|0)>>4)+o|0;c[m>>2]=k;if((k|0)>=1){n=0;break}c[m>>2]=0;a[e]=3;n=0}else if((i|0)==1){m=c[f>>2]|0;k=h+66|0;o=d[k]|0;if(((1<<o)-1&m|0)!=0){n=0;break}if((a[h+68|0]&8)==0){j=h+48|0;p=(c[j>>2]|0)+(d[52464+((d[h+67|0]|0)+(m>>>(o>>>0)&7))|0]|0)|0;c[j>>2]=p;s=p}else{a[g]=14;p=h+48|0;j=((d[52464+((m>>>((d[k]|0)>>>0)&7)+(d[h+67|0]|0))|0]|0)*6|0)+(c[p>>2]|0)|0;c[p>>2]=j;s=j}if((s|0)<=1022){n=0;break}c[h+48>>2]=1023;a[e]=0;n=0}else{n=0}}while(0);i=c[h+48>>2]|0;j=h+69|0;p=a[j]|0;do{if((a[h+68|0]&8)==0){t=i}else{if((p&2)==0){t=i;break}t=(d[e]|0)>1?i^1023:i}}while(0);c[h+56>>2]=(c[h+44>>2]|0)+t;a[j]=p^n;i=b-1|0;if((i|0)==0){break}else{b=i;h=h+80|0}}return}function lM(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;g=(c[3541216]|0)>>>((d[e+360|0]|0)>>>0);c[2161336]=0;c[2383570]=0;c[2383574]=0;c[2276112]=0;h=e+352|0;c[c[e+348>>2]>>2]=c[h>>2];i=(c[e+76>>2]&g)+(c[e+56>>2]|0)|0;j=e+324|0;k=e+328|0;l=c[k>>2]|0;m=l+(c[j>>2]|0)|0;c[j>>2]=l;j=c[e+332>>2]|0;if((j|0)==0){c[2383570]=l;c[2383574]=l;c[2161336]=l}else{c[j>>2]=(c[j>>2]|0)+l}c[k>>2]=0;if(i>>>0<832){l=a[e+321|0]|0;j=(c[8410984+(((((l<<24>>24==0?0:m)<<(l&255))+(c[e+32>>2]&67043328)|0)>>>16&1023)<<2)>>2]|0)+(i<<3)|0;if(j>>>0>6655){n=0}else{n=c[8310616+(j<<2)>>2]|0}c[k>>2]=n}n=(c[e+156>>2]&g)+(c[e+136>>2]|0)|0;if(n>>>0<832){k=(c[8410984+((((c[2276112]<<15)+(c[e+112>>2]&67043328)|0)>>>16&1023)<<2)>>2]|0)+(n<<3)|0;if(k>>>0>6655){o=0}else{o=c[8310616+(k<<2)>>2]|0}k=c[e+336>>2]|0;c[k>>2]=(c[k>>2]|0)+o}o=(c[e+236>>2]&g)+(c[e+216>>2]|0)|0;if(o>>>0<832){k=(c[8410984+((((c[2383574]<<15)+(c[e+192>>2]&67043328)|0)>>>16&1023)<<2)>>2]|0)+(o<<3)|0;if(k>>>0>6655){p=0}else{p=c[8310616+(k<<2)>>2]|0}k=c[e+340>>2]|0;c[k>>2]=(c[k>>2]|0)+p}p=(c[e+316>>2]&g)+(c[e+296>>2]|0)|0;if(p>>>0<832){g=(c[8410984+((((c[2383570]<<15)+(c[e+272>>2]&67043328)|0)>>>16&1023)<<2)>>2]|0)+(p<<3)|0;if(g>>>0>6655){q=0}else{q=c[8310616+(g<<2)>>2]|0}g=c[e+344>>2]|0;c[g>>2]=(c[g>>2]|0)+q}c[h>>2]=c[2161336];h=c[e+356>>2]|0;if((h|0)==0){q=e+32|0;c[q>>2]=(c[q>>2]|0)+(c[e+36>>2]|0);q=e+192|0;c[q>>2]=(c[q>>2]|0)+(c[e+196>>2]|0);q=e+112|0;c[q>>2]=(c[q>>2]|0)+(c[e+116>>2]|0);q=e+272|0;c[q>>2]=(c[q>>2]|0)+(c[e+276>>2]|0);return}if(!((c[b+52>>2]&192|0)!=0&(f|0)==2)){f=c[e+372>>2]|0;q=c[9104456+((c[3541212]|0)+h+(f>>>4<<8&32512)<<2)>>2]|0;if((q|0)==0){g=e+32|0;c[g>>2]=(c[g>>2]|0)+(c[e+36>>2]|0);g=e+192|0;c[g>>2]=(c[g>>2]|0)+(c[e+196>>2]|0);g=e+112|0;c[g>>2]=(c[g>>2]|0)+(c[e+116>>2]|0);g=e+272|0;c[g>>2]=(c[g>>2]|0)+(c[e+276>>2]|0);return}g=q+(f<<1)|0;f=g&4095;q=g>>>12&7;g=d[9504+(f>>>8)|0]|0|q<<2;p=(c[b+1208+(f<<2)>>2]|0)>>>((q^7)>>>0);q=(c[(c[e>>2]|0)+(g<<2)>>2]|0)+p|0;if((q|0)<0){r=(c[b+17592>>2]|0)+q|0}else{r=q}q=(ag(c[e+28>>2]|0,r)|0)>>>1;r=e+32|0;c[r>>2]=q+(c[r>>2]|0);r=(c[(c[e+160>>2]|0)+(g<<2)>>2]|0)+p|0;if((r|0)<0){s=(c[b+17592>>2]|0)+r|0}else{s=r}r=(ag(c[e+188>>2]|0,s)|0)>>>1;s=e+192|0;c[s>>2]=r+(c[s>>2]|0);s=(c[(c[e+80>>2]|0)+(g<<2)>>2]|0)+p|0;if((s|0)<0){t=(c[b+17592>>2]|0)+s|0}else{t=s}s=(ag(c[e+108>>2]|0,t)|0)>>>1;t=e+112|0;c[t>>2]=s+(c[t>>2]|0);t=(c[(c[e+240>>2]|0)+(g<<2)>>2]|0)+p|0;if((t|0)<0){u=(c[b+17592>>2]|0)+t|0}else{u=t}t=(ag(c[e+268>>2]|0,u)|0)>>>1;u=e+272|0;c[u>>2]=t+(c[u>>2]|0);return}u=c[b+1132>>2]|0;t=(c[3541212]|0)+h|0;h=c[9104456+(t+(u>>>4<<8&32512)<<2)>>2]|0;if((h|0)==0){p=e+32|0;c[p>>2]=(c[p>>2]|0)+(c[e+36>>2]|0)}else{p=h+(u<<1)|0;u=p&4095;h=p>>>12&7;p=(c[(c[e>>2]|0)+((d[9504+(u>>>8)|0]|0|h<<2)<<2)>>2]|0)+((c[b+1208+(u<<2)>>2]|0)>>>((h^7)>>>0))|0;if((p|0)<0){v=(c[b+17592>>2]|0)+p|0}else{v=p}p=(ag(c[e+28>>2]|0,v)|0)>>>1;v=e+32|0;c[v>>2]=p+(c[v>>2]|0)}v=c[b+1136>>2]|0;p=c[9104456+(t+(v>>>4<<8&32512)<<2)>>2]|0;if((p|0)==0){h=e+192|0;c[h>>2]=(c[h>>2]|0)+(c[e+196>>2]|0)}else{h=p+(v<<1)|0;v=h&4095;p=h>>>12&7;h=(c[(c[e+160>>2]|0)+((d[9504+(v>>>8)|0]|0|p<<2)<<2)>>2]|0)+((c[b+1208+(v<<2)>>2]|0)>>>((p^7)>>>0))|0;if((h|0)<0){w=(c[b+17592>>2]|0)+h|0}else{w=h}h=(ag(c[e+188>>2]|0,w)|0)>>>1;w=e+192|0;c[w>>2]=h+(c[w>>2]|0)}w=c[b+1128>>2]|0;h=c[9104456+(t+(w>>>4<<8&32512)<<2)>>2]|0;if((h|0)==0){p=e+112|0;c[p>>2]=(c[p>>2]|0)+(c[e+116>>2]|0)}else{p=h+(w<<1)|0;w=p&4095;h=p>>>12&7;p=(c[(c[e+80>>2]|0)+((d[9504+(w>>>8)|0]|0|h<<2)<<2)>>2]|0)+((c[b+1208+(w<<2)>>2]|0)>>>((h^7)>>>0))|0;if((p|0)<0){x=(c[b+17592>>2]|0)+p|0}else{x=p}p=(ag(c[e+108>>2]|0,x)|0)>>>1;x=e+112|0;c[x>>2]=p+(c[x>>2]|0)}x=c[e+372>>2]|0;p=c[9104456+(t+(x>>>4<<8&32512)<<2)>>2]|0;if((p|0)==0){t=e+272|0;c[t>>2]=(c[t>>2]|0)+(c[e+276>>2]|0);return}t=p+(x<<1)|0;x=t&4095;p=t>>>12&7;t=(c[(c[e+240>>2]|0)+((d[9504+(x>>>8)|0]|0|p<<2)<<2)>>2]|0)+((c[b+1208+(x<<2)>>2]|0)>>>((p^7)>>>0))|0;if((t|0)<0){y=(c[b+17592>>2]|0)+t|0}else{y=t}t=(ag(c[e+268>>2]|0,y)|0)>>>1;y=e+272|0;c[y>>2]=t+(c[y>>2]|0);return}function lN(b){b=b|0;var e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0;e=c[3541518]|0;f=e+(b*19024|0)+256|0;a[e+(b*19024|0)+312|0]=2;lI(f,72,72,4);g=e+(b*19024|0)+264|0;mB((d[g]|0)+(c[2383582]|0)|0);i=e+(b*19024|0)+306|0;a[i]=3;j=e+(b*19024|0)+307|0;k=e+(b*19024|0)+305|0;do{if((a[k]|0)==0){if((a[j]&3)==0){break}a[k]=1;l=c[e+(b*19024|0)+1360>>2]|0;if((l|0)==0){m=3;n=11117;break}gg[l&4095](d[g]|0,1);if((a[k]|0)==0){break}m=a[i]|0;n=11117}else{m=3;n=11117}}while(0);do{if((n|0)==11117){if((a[j]&m)<<24>>24!=0){break}a[k]=0;i=c[e+(b*19024|0)+1360>>2]|0;if((i|0)==0){break}gg[i&4095](d[g]|0,0)}}while(0);h[e+(b*19024|0)+296>>3]=0.0;lO(f,39,48);c[e+(b*19024|0)+1452>>2]=0;c[e+(b*19024|0)+1448>>2]=0;a[j]=0;do{if((a[k]|0)!=0){a[k]=0;j=c[e+(b*19024|0)+1360>>2]|0;if((j|0)==0){break}gg[j&4095](d[g]|0,0)}}while(0);g=c[3541518]|0;c[e+(b*19024|0)+308>>2]=0;c[e+(b*19024|0)+316>>2]=0;c[e+(b*19024|0)+320>>2]=0;a[e+(b*19024|0)+324|0]=0;c[e+(b*19024|0)+328>>2]=0;c[g+(b*19024|0)+18260>>2]=0;a[g+(b*19024|0)+17964|0]=0;a[g+(b*19024|0)+17965|0]=0;a[g+(b*19024|0)+17936|0]=0;c[g+(b*19024|0)+17944>>2]=1023;c[g+(b*19024|0)+17952>>2]=1023;a[g+(b*19024|0)+18044|0]=0;a[g+(b*19024|0)+18045|0]=0;a[g+(b*19024|0)+18016|0]=0;c[g+(b*19024|0)+18024>>2]=1023;c[g+(b*19024|0)+18032>>2]=1023;a[g+(b*19024|0)+18124|0]=0;a[g+(b*19024|0)+18125|0]=0;a[g+(b*19024|0)+18096|0]=0;c[g+(b*19024|0)+18104>>2]=1023;c[g+(b*19024|0)+18112>>2]=1023;a[g+(b*19024|0)+18204|0]=0;a[g+(b*19024|0)+18205|0]=0;a[g+(b*19024|0)+18176|0]=0;c[g+(b*19024|0)+18184>>2]=1023;c[g+(b*19024|0)+18192>>2]=1023;c[g+(b*19024|0)+18636>>2]=0;a[g+(b*19024|0)+18340|0]=0;a[g+(b*19024|0)+18341|0]=0;a[g+(b*19024|0)+18312|0]=0;c[g+(b*19024|0)+18320>>2]=1023;c[g+(b*19024|0)+18328>>2]=1023;a[g+(b*19024|0)+18420|0]=0;a[g+(b*19024|0)+18421|0]=0;a[g+(b*19024|0)+18392|0]=0;c[g+(b*19024|0)+18400>>2]=1023;c[g+(b*19024|0)+18408>>2]=1023;a[g+(b*19024|0)+18500|0]=0;a[g+(b*19024|0)+18501|0]=0;a[g+(b*19024|0)+18472|0]=0;c[g+(b*19024|0)+18480>>2]=1023;c[g+(b*19024|0)+18488>>2]=1023;a[g+(b*19024|0)+18580|0]=0;a[g+(b*19024|0)+18581|0]=0;a[g+(b*19024|0)+18552|0]=0;c[g+(b*19024|0)+18560>>2]=1023;c[g+(b*19024|0)+18568>>2]=1023;c[g+(b*19024|0)+19012>>2]=0;a[g+(b*19024|0)+18716|0]=0;a[g+(b*19024|0)+18717|0]=0;a[g+(b*19024|0)+18688|0]=0;c[g+(b*19024|0)+18696>>2]=1023;c[g+(b*19024|0)+18704>>2]=1023;a[g+(b*19024|0)+18796|0]=0;a[g+(b*19024|0)+18797|0]=0;a[g+(b*19024|0)+18768|0]=0;c[g+(b*19024|0)+18776>>2]=1023;c[g+(b*19024|0)+18784>>2]=1023;a[g+(b*19024|0)+18876|0]=0;a[g+(b*19024|0)+18877|0]=0;a[g+(b*19024|0)+18848|0]=0;c[g+(b*19024|0)+18856>>2]=1023;c[g+(b*19024|0)+18864>>2]=1023;a[g+(b*19024|0)+18956|0]=0;a[g+(b*19024|0)+18957|0]=0;a[g+(b*19024|0)+18928|0]=0;c[g+(b*19024|0)+18936>>2]=1023;c[g+(b*19024|0)+18944>>2]=1023;b=178;do{lP(f,b,0);b=b-1|0;}while((b|0)>47);return}function lO(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,i=0,j=0,k=0,l=0;switch(e|0){case 38:{a[b+68|0]=f&255;return};case 39:{e=b+8|0;g=d[e]|0;c[b+52>>2]=f;do{if((f&32|0)!=0){i=b+51|0;j=a[i]&253;a[i]=j&255;i=b+49|0;if((a[i]|0)==0){break}if((d[b+50|0]&j|0)!=0){break}a[i]=0;i=c[b+1104>>2]|0;if((i|0)==0){break}gg[i&4095](g,0)}}while(0);do{if((f&16|0)!=0){i=b+51|0;j=a[i]&254;a[i]=j&255;i=b+49|0;if((a[i]|0)==0){break}if((d[b+50|0]&j|0)!=0){break}a[i]=0;i=c[b+1104>>2]|0;if((i|0)==0){break}gg[i&4095](d[e]|0,0)}}while(0);e=b+72|0;i=(c[e>>2]|0)==0;do{if((f&2|0)==0){if(i){break}c[e>>2]=0;j=c[b+1100>>2]|0;if((j|0)==0){break}gn[j&3](g,1,0,+h[b+32>>3])}else{if(!i){break}j=256-(d[b+68|0]|0)<<4;c[e>>2]=j;k=c[b+1100>>2]|0;if((k|0)==0){break}gn[k&3](g,1,j,+h[b+32>>3])}}while(0);e=b+64|0;i=(c[e>>2]|0)==0;if((f&1|0)==0){if(i){return}c[e>>2]=0;j=c[b+1100>>2]|0;if((j|0)==0){return}gn[j&3](g,0,0,+h[b+32>>3]);return}else{if(!i){return}i=1024-(c[b+60>>2]|0)|0;c[e>>2]=i;e=c[b+1100>>2]|0;if((e|0)==0){return}gn[e&3](g,0,i,+h[b+32>>3]);return}break};case 37:{i=b+60|0;c[i>>2]=c[i>>2]&1020|f&3;return};case 34:{if((a[b|0]&2)==0){return}if((f&8|0)==0){c[b+17600>>2]=0;return}else{c[b+17600>>2]=c[b+17604+((f&7)<<2)>>2];return}break};case 40:{i=f&3;if(i<<24>>24==3){return}if((f&4|0)==0){l=i}else{l=(a[b|0]&4)==0?i:i+3&255}i=c[b+1140>>2]|0;g=l&255;l=i+(g*376|0)+72|0;e=(c[l>>2]|0)==0;do{if((f&16|0)==0){if(e){break}c[l>>2]=0;j=i+(g*376|0)+40|0;if((d[j]|0)<=1){break}a[j]=1}else{if(!e){break}j=a[b|0]|0;c[l>>2]=1;c[i+(g*376|0)+32>>2]=0;a[i+(g*376|0)+69|0]=(d[i+(g*376|0)+68|0]|0)>>>1&2;if(!((j<<24>>24|0)==14|(j<<24>>24|0)==23)){a[i+(g*376|0)+40|0]=4;break}if(((d[i+(g*376|0)+24|0]|0)+(c[i+(g*376|0)+8>>2]|0)|0)>>>0<94){a[i+(g*376|0)+40|0]=4;break}else{c[i+(g*376|0)+48>>2]=0;a[i+(g*376|0)+40|0]=3;break}}}while(0);l=i+(g*376|0)+232|0;e=(c[l>>2]|0)==0;do{if((f&32|0)==0){if(e){break}c[l>>2]=0;j=i+(g*376|0)+200|0;if((d[j]|0)<=1){break}a[j]=1}else{if(!e){break}j=a[b|0]|0;c[l>>2]=1;c[i+(g*376|0)+192>>2]=0;a[i+(g*376|0)+229|0]=(d[i+(g*376|0)+228|0]|0)>>>1&2;if(!((j<<24>>24|0)==14|(j<<24>>24|0)==23)){a[i+(g*376|0)+200|0]=4;break}if(((d[i+(g*376|0)+184|0]|0)+(c[i+(g*376|0)+168>>2]|0)|0)>>>0<94){a[i+(g*376|0)+200|0]=4;break}else{c[i+(g*376|0)+208>>2]=0;a[i+(g*376|0)+200|0]=3;break}}}while(0);l=i+(g*376|0)+152|0;e=(c[l>>2]|0)==0;do{if((f&64|0)==0){if(e){break}c[l>>2]=0;j=i+(g*376|0)+120|0;if((d[j]|0)<=1){break}a[j]=1}else{if(!e){break}j=a[b|0]|0;c[l>>2]=1;c[i+(g*376|0)+112>>2]=0;a[i+(g*376|0)+149|0]=(d[i+(g*376|0)+148|0]|0)>>>1&2;if(!((j<<24>>24|0)==14|(j<<24>>24|0)==23)){a[i+(g*376|0)+120|0]=4;break}if(((d[i+(g*376|0)+104|0]|0)+(c[i+(g*376|0)+88>>2]|0)|0)>>>0<94){a[i+(g*376|0)+120|0]=4;break}else{c[i+(g*376|0)+128>>2]=0;a[i+(g*376|0)+120|0]=3;break}}}while(0);l=i+(g*376|0)+312|0;e=(c[l>>2]|0)==0;if((f&128|0)==0){if(e){return}c[l>>2]=0;j=i+(g*376|0)+280|0;if((d[j]|0)<=1){return}a[j]=1;return}if(!e){return}e=a[b|0]|0;c[l>>2]=1;c[i+(g*376|0)+272>>2]=0;a[i+(g*376|0)+309|0]=(d[i+(g*376|0)+308|0]|0)>>>1&2;if(!((e<<24>>24|0)==14|(e<<24>>24|0)==23)){a[i+(g*376|0)+280|0]=4;return}if(((d[i+(g*376|0)+264|0]|0)+(c[i+(g*376|0)+248>>2]|0)|0)>>>0<94){a[i+(g*376|0)+280|0]=4;return}else{c[i+(g*376|0)+288>>2]=0;a[i+(g*376|0)+280|0]=3;return}break};case 36:{g=b+60|0;c[g>>2]=c[g>>2]&3|f<<2;return};default:{return}}}function lP(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=e&3;if(g<<24>>24==3){return}h=b+1140|0;i=c[h>>2]|0;j=((e|0)>255?g+3&255:g)&255;g=e>>>2&3;switch(e&240|0){case 64:{c[i+(j*376|0)+(g*80|0)+44>>2]=f<<3&1016;return};case 112:{k=a[b|0]|0;l=f&31;if((l|0)==0){m=0}else{m=(l<<1)+32|0}c[i+(j*376|0)+(g*80|0)+16>>2]=m;l=(d[i+(j*376|0)+(g*80|0)+24|0]|0)+m|0;a[i+(j*376|0)+(g*80|0)+64|0]=a[51792+l|0]|0;if((k<<24>>24|0)==14|(k<<24>>24|0)==23){a[i+(j*376|0)+(g*80|0)+65|0]=a[52112+l|0]|0;return}else{a[i+(j*376|0)+(g*80|0)+65|0]=a[52240+l|0]|0;return}break};case 96:{l=b|0;k=a[l]|0;m=f&31;if((m|0)==0){n=0}else{n=(m<<1)+32|0}c[i+(j*376|0)+(g*80|0)+12>>2]=n;m=(d[i+(j*376|0)+(g*80|0)+24|0]|0)+n|0;a[i+(j*376|0)+(g*80|0)+62|0]=a[51792+m|0]|0;if((k<<24>>24|0)==14|(k<<24>>24|0)==23){a[i+(j*376|0)+(g*80|0)+63|0]=a[52112+m|0]|0}else{a[i+(j*376|0)+(g*80|0)+63|0]=a[52240+m|0]|0}if((a[l]&2)==0){return}c[i+(j*376|0)+(g*80|0)+76>>2]=f<<24>>31;return};case 144:{a[i+(j*376|0)+(g*80|0)+68|0]=f&15;a[i+(j*376|0)+(g*80|0)+69|0]=f>>>1&2;return};case 48:{l=f&15;c[i+(j*376|0)+(g*80|0)+28>>2]=(l|0)==0?1:l<<1;c[i+(j*376|0)+(g*80|0)>>2]=b+76+((f>>>4&7)<<7);c[i+(j*376|0)+36>>2]=-1;return};case 160:{if((g|0)==1){a[b+57|0]=f&63;return}else if((g|0)==2){if((e|0)>=256){return}l=a[b+1124|0]|0;m=((l&255)<<8&1792)+f|0;k=(l&255)>>>3;l=k&255;a[b+1125+j|0]=k<<2|a[9504+(m>>>7)|0];c[b+1112+(j<<2)>>2]=(c[b+1208+(m<<1<<2)>>2]|0)>>>((7-l|0)>>>0);c[b+1128+(j<<2)>>2]=m|l<<11;c[(c[h>>2]|0)+788>>2]=-1;return}else if((g|0)==3){if((e|0)>=256){return}a[b+1124|0]=f&63;return}else if((g|0)==0){e=a[b+57|0]|0;h=((e&255)<<8&1792)+f|0;l=(e&255)>>>3;e=l&255;a[i+(j*376|0)+368|0]=l<<2|a[9504+(h>>>7)|0];c[i+(j*376|0)+364>>2]=(c[b+1208+(h<<1<<2)>>2]|0)>>>((7-e|0)>>>0);c[i+(j*376|0)+372>>2]=h|e<<11;c[i+(j*376|0)+36>>2]=-1;return}else{return}break};case 128:{e=a[b|0]|0;c[i+(j*376|0)+(g*80|0)+52>>2]=c[2704+(f>>4<<2)>>2];h=(f<<2&60)+34|0;c[i+(j*376|0)+(g*80|0)+20>>2]=h;l=(d[i+(j*376|0)+(g*80|0)+24|0]|0)+h|0;a[i+(j*376|0)+(g*80|0)+66|0]=a[51792+l|0]|0;if((e<<24>>24|0)==14|(e<<24>>24|0)==23){a[i+(j*376|0)+(g*80|0)+67|0]=a[52112+l|0]|0;return}else{a[i+(j*376|0)+(g*80|0)+67|0]=a[52240+l|0]|0;return}break};case 176:{if((g|0)==0){l=f>>>3&7;e=f&7;a[i+(j*376|0)+320|0]=e;if((l|0)==0){o=0}else{o=l+6&255}a[i+(j*376|0)+321|0]=o;o=8451944+(j<<2)|0;l=i+(j*376|0)+332|0;h=i+(j*376|0)+336|0;m=i+(j*376|0)+340|0;k=i+(j*376|0)+348|0;switch(e&255|0){case 4:{c[l>>2]=9534296;c[m>>2]=o;c[h>>2]=9534280;c[k>>2]=8645344;break};case 0:{c[l>>2]=9534296;c[m>>2]=8645344;c[h>>2]=9534280;c[k>>2]=9104448;break};case 5:{c[l>>2]=0;c[m>>2]=o;c[h>>2]=o;c[k>>2]=9104448;break};case 7:{c[l>>2]=o;c[m>>2]=o;c[h>>2]=o;c[k>>2]=8645344;break};case 3:{c[l>>2]=9534296;c[m>>2]=8645344;c[h>>2]=9534280;c[k>>2]=9534280;break};case 2:{c[l>>2]=9534280;c[m>>2]=8645344;c[h>>2]=9534280;c[k>>2]=9104448;break};case 6:{c[l>>2]=9534296;c[m>>2]=o;c[h>>2]=o;c[k>>2]=8645344;break};case 1:{c[l>>2]=8645344;c[m>>2]=8645344;c[h>>2]=9534280;c[k>>2]=9104448;break};default:{}}c[i+(j*376|0)+344>>2]=o;return}else if((g|0)==1){if((a[b|0]&2)==0){return}c[i+(j*376|0)+356>>2]=f<<5&224;a[i+(j*376|0)+360|0]=a[44304+(f>>>4&3)|0]|0;o=j<<1;c[b+1144+(o<<2)>>2]=f<<24>>31;c[b+1144+((o|1)<<2)>>2]=f<<25>>31;return}else{return}break};case 80:{o=a[b|0]|0;b=i+(j*376|0)+(g*80|0)+4|0;k=a[b]|0;h=f&31;if((h|0)==0){p=0}else{p=(h<<1)+32|0}c[i+(j*376|0)+(g*80|0)+8>>2]=p;h=3-(f>>>6)&255;a[b]=h;if(k<<24>>24!=h<<24>>24){c[i+(j*376|0)+36>>2]=-1}h=(d[i+(j*376|0)+(g*80|0)+24|0]|0)+p|0;if(h>>>0>=94){a[i+(j*376|0)+(g*80|0)+60|0]=0;a[i+(j*376|0)+(g*80|0)+61|0]=-120;return}p=a[51792+h|0]|0;k=i+(j*376|0)+(g*80|0)+60|0;a[k]=p;if((o<<24>>24|0)==14|(o<<24>>24|0)==23){a[k]=p;a[i+(j*376|0)+(g*80|0)+61|0]=a[52112+h|0]|0;return}else{a[i+(j*376|0)+(g*80|0)+61|0]=a[52240+h|0]|0;return}break};default:{return}}}function lQ(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=i;if((c[3541518]|0)!=0){i=g;return}c[2383472]=0;c[3531858]=b;h=b*19024|0;b=gGq(h)|0;c[3541518]=b;if((b|0)==0){i=g;return}gGz(b|0,0,h|0);lR();do{if((c[3531858]|0)>0){h=0;do{b=c[3541518]|0;a[b+(h*19024|0)+264|0]=h&255;a[b+(h*19024|0)+256|0]=1;c[b+(h*19024|0)+1396>>2]=b+(h*19024|0)+17896;c[b+(h*19024|0)+268>>2]=d;c[b+(h*19024|0)+272>>2]=e;c[b+(h*19024|0)+1356>>2]=2;c[b+(h*19024|0)+1360>>2]=f;lN(h);h=h+1|0;j=c[3531858]|0;}while((h|0)<(j|0));if((j|0)>0){k=0}else{l=0;break}while(1){h=(c[3541518]|0)+(k*19024|0)|0;b=gGq(272)|0;m=b;if((b|0)!=0){gGz(b|0,0,272);n=c[2430396]|0;c[b>>2]=n;if((n|0)!=0){c[n+4>>2]=m}c[2430396]=m;m=b+8|0;cC(m|0,231e3,(o=i,i=i+24|0,c[o>>2]=7460888,c[o+8>>2]=198680,c[o+16>>2]=k,o)|0)|0;i=o;c[b+264>>2]=h;c[b+268>>2]=256}mf(7460888,k,(c[3541518]|0)+(k*19024|0)+264|0);mg(7460888,k,(c[3541518]|0)+(k*19024|0)+17896|0,3);b=(c[3541518]|0)+(k*19024|0)+1368|0;h=gGq(272)|0;m=h;if((h|0)!=0){gGz(h|0,0,272);n=c[2430396]|0;c[h>>2]=n;if((n|0)!=0){c[n+4>>2]=m}c[2430396]=m;m=h+8|0;cC(m|0,231e3,(o=i,i=i+24|0,c[o>>2]=7460888,c[o+8>>2]=157144,c[o+16>>2]=k,o)|0)|0;i=o;c[h+264>>2]=b;c[h+268>>2]=12}h=(c[3541518]|0)+(k*19024|0)+1380|0;b=gGq(272)|0;m=b;if((b|0)!=0){gGz(b|0,0,272);n=c[2430396]|0;c[b>>2]=n;if((n|0)!=0){c[n+4>>2]=m}c[2430396]=m;m=b+8|0;cC(m|0,231e3,(o=i,i=i+24|0,c[o>>2]=7460888,c[o+8>>2]=126616,c[o+16>>2]=k,o)|0)|0;i=o;c[b+264>>2]=h;c[b+268>>2]=1}b=(c[3541518]|0)+(k*19024|0)+1381|0;h=gGq(272)|0;m=h;if((h|0)!=0){gGz(h|0,0,272);n=c[2430396]|0;c[h>>2]=n;if((n|0)!=0){c[n+4>>2]=m}c[2430396]=m;m=h+8|0;cC(m|0,231e3,(o=i,i=i+24|0,c[o>>2]=7460888,c[o+8>>2]=101520,c[o+16>>2]=k,o)|0)|0;i=o;c[h+264>>2]=b;c[h+268>>2]=3}h=k+1|0;if((h|0)<(c[3531858]|0)){k=h}else{l=0;break}}}else{l=0}}while(0);while(1){if((l|0)>=8){p=11326;break}q=9774632+(l<<2)|0;if((c[q>>2]|0)==0){break}else{l=l+1|0}}if((p|0)==11326){i=g;return}c[q>>2]=9766;i=g;return}function lR(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0.0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;b=0;while(1){d=b+1|0;e=~~+U(+(65536.0/+c$(+(+(d|0)*.03125*.125))));f=(e>>>4&1)+(e>>5)|0;e=f<<2;g=b<<1;c[8310616+(g<<2)>>2]=e;h=g|1;c[8310616+(h<<2)>>2]=-e;e=f<<1;c[8310616+(g+512<<2)>>2]=e;c[8310616+(h+512<<2)>>2]=-e;c[8310616+(g+1024<<2)>>2]=f;c[8310616+(h+1024<<2)>>2]=-f;e=f>>1;c[8310616+(g+1536<<2)>>2]=e;c[8310616+(h+1536<<2)>>2]=-e;e=f>>2;c[8310616+(g+2048<<2)>>2]=e;c[8310616+(h+2048<<2)>>2]=-e;e=f>>3;c[8310616+(g+2560<<2)>>2]=e;c[8310616+(h+2560<<2)>>2]=-e;e=f>>4;c[8310616+(g+3072<<2)>>2]=e;c[8310616+(h+3072<<2)>>2]=-e;e=f>>5;c[8310616+(g+3584<<2)>>2]=e;c[8310616+(h+3584<<2)>>2]=-e;e=f>>6;c[8310616+(g+4096<<2)>>2]=e;c[8310616+(h+4096<<2)>>2]=-e;e=f>>7;c[8310616+(g+4608<<2)>>2]=e;c[8310616+(h+4608<<2)>>2]=-e;e=f>>8;c[8310616+(g+5120<<2)>>2]=e;c[8310616+(h+5120<<2)>>2]=-e;e=f>>9;c[8310616+(g+5632<<2)>>2]=e;c[8310616+(h+5632<<2)>>2]=-e;e=f>>10;c[8310616+(g+6144<<2)>>2]=e;c[8310616+(h+6144<<2)>>2]=-e;if((d|0)<256){b=d}else{i=0;break}}while(1){j=+Z(+(+(i<<1|1|0)*3.141592653589793*.0009765625));b=~~(+ae(+((j>0.0?1.0:-1.0)/j))*8.0/.6931471805599453*32.0*2.0);c[8410984+(i<<2)>>2]=(b<<1&2)+b&-2|j<0.0;b=i+1|0;if((b|0)<1024){i=b}else{k=0;break}}do{i=k<<5;b=k+48|0;d=k+40|0;e=k+32|0;h=k+24|0;g=k+16|0;f=k+8|0;l=0;m=0;while(1){n=(m<<8)+i|0;o=(m&1|0)==0;p=(m&2|0)==0;q=(m&4|0)==0;r=(m&8|0)==0;s=(m&16|0)==0;t=(m&32|0)==0;u=(m&64|0)==0;v=0;w=0;while(1){if(o){x=0}else{x=a[43600+(k<<3)+w|0]|0}if(p){y=x}else{y=(a[43600+(f<<3)+w|0]|0)+x&255}if(q){z=y}else{z=(a[43600+(g<<3)+w|0]|0)+y&255}if(r){A=z}else{A=(a[43600+(h<<3)+w|0]|0)+z&255}if(s){B=A}else{B=(a[43600+(e<<3)+w|0]|0)+A&255}if(t){C=B}else{C=(a[43600+(d<<3)+w|0]|0)+B&255}if(u){D=C}else{D=(a[43600+(b<<3)+w|0]|0)+C&255}E=D&255;F=w+n|0;c[9104456+(F<<2)>>2]=E;G=(w^7)+n|0;c[9104456+(G+8<<2)>>2]=E;H=-E|0;c[9104456+(F+16<<2)>>2]=H;c[9104456+(G+24<<2)>>2]=H;H=v+1&255;if((H&255)<8){v=H;w=H&255}else{break}}w=l+1&255;if(w<<24>>24>-1){l=w;m=w&255}else{break}}k=k+1|0;}while((k|0)<8);return}function lS(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0.0,s=0.0;g=c[3541518]|0;i=g+(b*19024|0)+256|0;j=g+(b*19024|0)+304|0;if((e&1|0)==0){a[j]=f;e=f&255;if((f&255)<16){c[14168912+(((c[2383582]|0)+b|0)*252|0)>>2]=e&15}if((f-45&255)>=3){return}if((e|0)==0){a[g+(b*19024|0)+312|0]=2;k=2}else if((e|0)==46){l=g+(b*19024|0)+312|0;m=a[l]|1;a[l]=m;k=m}else if((e|0)==47){a[g+(b*19024|0)+312|0]=0;k=0}else if((e|0)==45){e=g+(b*19024|0)+312|0;m=a[e]|2;a[e]=m;k=m}else{k=a[g+(b*19024|0)+312|0]|0}m=k&3;k=c[7461744+(m<<2)>>2]|0;lI(i,k,k,c[7461728+(m<<2)>>2]|0);return}m=d[j]|0;a[g+(b*19024|0)+m|0]=f;j=m&240;do{if((j|0)==0){k=(c[2383582]|0)+b|0;e=f&255;l=c[14168912+(k*252|0)>>2]|0;if((l|0)>15){break}do{if((l|0)<14){if((l|0)!=13){if((a[14168916+(k*252|0)+l|0]|0)==f<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(k,l,e)}else if((j|0)==32){n=gj[c[2427020]&4095](c[2429378]|0)|0;o=c[2433544]|0;if((o|0)<(n|0)){p=n-o|0;n=c[2406680]|0;q=n+(o+4<<1)|0;c[2438962]=q;lJ(0,q,p);if((c[2385508]|0)>1){q=n+((c[2433544]|0)+16388<<1)|0;c[2438966]=q;lJ(1,q,p)}c[2433544]=(c[2433544]|0)+p}lO(i,m,f&255)}else{p=gj[c[2427020]&4095](c[2429378]|0)|0;q=c[2433544]|0;if((q|0)<(p|0)){n=p-q|0;p=c[2406680]|0;o=p+(q+4<<1)|0;c[2438962]=o;lJ(0,o,n);if((c[2385508]|0)>1){o=p+((c[2433544]|0)+16388<<1)|0;c[2438966]=o;lJ(1,o,n)}c[2433544]=(c[2433544]|0)+n}lP(i,m,f&255)}}while(0);r=+h[6675];s=r+ +gC[c[2429842]&255]();h[g+(b*19024|0)+296>>3]=s+ +h[g+(b*19024|0)+288>>3];return}function lT(b,e){b=b|0;e=e|0;var f=0,g=0,i=0,j=0,k=0,l=0,m=0;f=c[3541518]|0;if((e|0)!=0){e=f+(b*19024|0)+264|0;do{if((c[f+(b*19024|0)+308>>2]&8|0)!=0){g=f+(b*19024|0)+307|0;i=d[g]|2;a[g]=i&255;g=f+(b*19024|0)+305|0;if((a[g]|0)!=0){break}if((d[f+(b*19024|0)+306|0]&i|0)==0){break}a[g]=1;g=c[f+(b*19024|0)+1360>>2]|0;if((g|0)==0){break}gg[g&4095](d[e|0]|0,1)}}while(0);g=256-(d[f+(b*19024|0)+324|0]|0)<<4;c[f+(b*19024|0)+328>>2]=g;i=c[f+(b*19024|0)+1356>>2]|0;if((i|0)==0){j=f+(b*19024|0)+305|0;k=a[j]|0;l=k&255;return l|0}gn[i&3](d[e|0]|0,1,g,+h[f+(b*19024|0)+288>>3]);j=f+(b*19024|0)+305|0;k=a[j]|0;l=k&255;return l|0}g=gj[c[2427020]&4095](c[2429378]|0)|0;e=c[2433544]|0;if((e|0)<(g|0)){i=g-e|0;g=c[2406680]|0;m=g+(e+4<<1)|0;c[2438962]=m;lJ(0,m,i);if((c[2385508]|0)>1){m=g+((c[2433544]|0)+16388<<1)|0;c[2438966]=m;lJ(1,m,i)}c[2433544]=(c[2433544]|0)+i}i=f+(b*19024|0)+264|0;m=f+(b*19024|0)+308|0;do{if((c[m>>2]&4|0)!=0){g=f+(b*19024|0)+307|0;e=d[g]|1;a[g]=e&255;g=f+(b*19024|0)+305|0;if((a[g]|0)!=0){break}if((d[f+(b*19024|0)+306|0]&e|0)==0){break}a[g]=1;g=c[f+(b*19024|0)+1360>>2]|0;if((g|0)==0){break}gg[g&4095](d[i|0]|0,1)}}while(0);g=1024-(c[f+(b*19024|0)+316>>2]|0)|0;c[f+(b*19024|0)+320>>2]=g;e=c[f+(b*19024|0)+1356>>2]|0;if((e|0)!=0){gn[e&3](d[i|0]|0,0,g,+h[f+(b*19024|0)+288>>3])}if((c[m>>2]&128|0)==0){j=f+(b*19024|0)+305|0;k=a[j]|0;l=k&255;return l|0}lU(a[f+(b*19024|0)+256|0]|0,f+(b*19024|0)+18648|0);j=f+(b*19024|0)+305|0;k=a[j]|0;l=k&255;return l|0}function lU(b,e){b=b|0;e=e|0;var f=0;f=e+72|0;if((c[f>>2]|0)==0){c[f>>2]=1;c[e+32>>2]=0;a[e+69|0]=(d[e+68|0]|0)>>>1&2;do{if((b<<24>>24|0)==14|(b<<24>>24|0)==23){if(((d[e+24|0]|0)+(c[e+8>>2]|0)|0)>>>0<94){a[e+40|0]=4;break}else{c[e+48>>2]=0;a[e+40|0]=3;break}}else{a[e+40|0]=4}}while(0);c[f>>2]=0;a[e+40|0]=1}f=e+232|0;if((c[f>>2]|0)==0){c[f>>2]=1;c[e+192>>2]=0;a[e+229|0]=(d[e+228|0]|0)>>>1&2;do{if((b<<24>>24|0)==14|(b<<24>>24|0)==23){if(((d[e+184|0]|0)+(c[e+168>>2]|0)|0)>>>0<94){a[e+200|0]=4;break}else{c[e+208>>2]=0;a[e+200|0]=3;break}}else{a[e+200|0]=4}}while(0);c[f>>2]=0;a[e+200|0]=1}f=e+152|0;if((c[f>>2]|0)==0){c[f>>2]=1;c[e+112>>2]=0;a[e+149|0]=(d[e+148|0]|0)>>>1&2;do{if((b<<24>>24|0)==14|(b<<24>>24|0)==23){if(((d[e+104|0]|0)+(c[e+88>>2]|0)|0)>>>0<94){a[e+120|0]=4;break}else{c[e+128>>2]=0;a[e+120|0]=3;break}}else{a[e+120|0]=4}}while(0);c[f>>2]=0;a[e+120|0]=1}f=e+312|0;if((c[f>>2]|0)!=0){return}c[f>>2]=1;c[e+272>>2]=0;a[e+309|0]=(d[e+308|0]|0)>>>1&2;do{if((b<<24>>24|0)==14|(b<<24>>24|0)==23){if(((d[e+264|0]|0)+(c[e+248>>2]|0)|0)>>>0<94){a[e+280|0]=4;break}else{c[e+288>>2]=0;a[e+280|0]=3;break}}else{a[e+280|0]=4}}while(0);c[f>>2]=0;a[e+280|0]=1;return}function lV(e){e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0;f=c[3541516]|0;g=f+512|0;h=f+20912|0;i=c[2438952]|0;j=c[2438953]|0;k=f|0;if((k|0)==(c[2383472]|0)){l=c[2383566]|0}else{c[2383472]=k;c[3532586]=f+520;k=f+18152|0;c[2383566]=k;c[2383564]=f+18528;c[2383562]=f+18904;c[2383560]=f+19280;c[2383558]=f+19656;c[2383556]=f+20032;c[2112888]=c[f+20412>>2];l=k}if((c[l+36>>2]|0)==-1){k=c[l+364>>2]|0;m=d[l+368|0]|0;lK(g,l|0,k,m);lK(g,l+160|0,k,m);lK(g,l+80|0,k,m);lK(g,l+240|0,k,m)}m=c[2383564]|0;if((c[m+36>>2]|0)==-1){k=c[m+364>>2]|0;l=d[m+368|0]|0;lK(g,m|0,k,l);lK(g,m+160|0,k,l);lK(g,m+80|0,k,l);lK(g,m+240|0,k,l)}l=c[3532586]|0;k=c[2383562]|0;m=(c[k+36>>2]|0)==-1;do{if((c[l+44>>2]&192|0)==0){if(!m){break}n=c[k+364>>2]|0;o=d[k+368|0]|0;lK(g,k|0,n,o);lK(g,k+160|0,n,o);lK(g,k+80|0,n,o);lK(g,k+240|0,n,o)}else{if(!m){break}lK(g,k|0,c[f+1628>>2]|0,d[f+1638|0]|0);lK(g,k+160|0,c[f+1632>>2]|0,d[f+1639|0]|0);lK(g,k+80|0,c[f+1624>>2]|0,d[f+1637|0]|0);lK(g,k+240|0,c[k+364>>2]|0,d[k+368|0]|0)}}while(0);k=c[2383560]|0;if((c[k+36>>2]|0)==-1){m=c[k+364>>2]|0;o=d[k+368|0]|0;lK(g,k|0,m,o);lK(g,k+160|0,m,o);lK(g,k+80|0,m,o);lK(g,k+240|0,m,o)}o=c[2383558]|0;if((c[o+36>>2]|0)==-1){m=c[o+364>>2]|0;k=d[o+368|0]|0;lK(g,o|0,m,k);lK(g,o+160|0,m,k);lK(g,o+80|0,m,k);lK(g,o+240|0,m,k)}k=c[2383556]|0;if((c[k+36>>2]|0)==-1){m=c[k+364>>2]|0;o=d[k+368|0]|0;lK(g,k|0,m,o);lK(g,k+160|0,m,o);lK(g,k+80|0,m,o);lK(g,k+240|0,m,o)}if((e|0)>0){o=f+18112|0;m=f+1712|0;k=f+1708|0;n=f+1716|0;p=f+20994|0;q=f+1656|0;r=f+1660|0;s=f+1664|0;t=f+1668|0;u=f+1672|0;v=f+1676|0;w=f+1680|0;x=f+1684|0;y=f+1688|0;z=f+1692|0;A=f+1696|0;B=f+1700|0;C=f+1704|0;D=f+18108|0;E=f+20424|0;F=E|0;G=f+20472|0;H=G|0;I=f+20520|0;J=I|0;K=f+20568|0;L=K|0;M=f+20616|0;N=M|0;O=f+20664|0;P=O|0;Q=0;do{R=c[o>>2]|0;if((R|0)==0){c[3541216]=0;S=0}else{T=(c[D>>2]|0)+R|0;c[D>>2]=T;R=T>>>24;T=R&127;U=R<<1&126;c[3541216]=T>>>0<64?U:126-U|0;S=T>>>2}c[3541212]=S;c[2113001]=0;c[2112999]=0;c[2113e3]=0;c[2112997]=0;c[2112995]=0;c[2112996]=0;gGz(8451944,0,24);T=(c[k>>2]|0)+(c[m>>2]|0)|0;c[k>>2]=T;U=c[n>>2]|0;R=c[2383566]|0;if(T>>>0<U>>>0){V=R;W=c[2383564]|0;X=c[2383562]|0;Y=c[2383560]|0;Z=c[2383558]|0;_=c[2383556]|0}else{$=R|0;aa=c[2383564]|0;ab=aa|0;ac=c[2383562]|0;ad=ac|0;ae=c[2383560]|0;af=ae|0;ag=c[2383558]|0;ah=ag|0;ai=c[2383556]|0;aj=ai|0;ak=T;T=U;while(1){c[k>>2]=ak-T;c[C>>2]=(c[C>>2]|0)+1;lL(g,$);lL(g,ab);lL(g,ad);lL(g,af);lL(g,ah);lL(g,aj);U=c[k>>2]|0;al=c[n>>2]|0;if(U>>>0<al>>>0){V=R;W=aa;X=ac;Y=ae;Z=ag;_=ai;break}else{ak=U;T=al}}}lM(g,V,0);lM(g,W,1);lM(g,X,2);lM(g,Y,3);lM(g,Z,4);lM(g,_,5);if((a[p]|0)<0){lu(h)}if((a[F]|0)!=0){lW(f,E)}if((a[H]|0)!=0){lW(f,G)}if((a[J]|0)!=0){lW(f,I)}if((a[L]|0)!=0){lW(f,K)}if((a[N]|0)!=0){lW(f,M)}if((a[P]|0)!=0){lW(f,O)}T=c[2113001]|0;ak=c[2112997]|0;ai=c[2112986]>>1;ag=c[2112987]>>1;ae=c[2112988]>>1;ac=c[2112989]>>1;aa=c[2112990]>>1;R=c[2112991]>>1;aj=T+(c[2113e3]|0)+(ak+(c[2112996]|0)>>9)+(ai&c[q>>2])+(ag&c[s>>2])+(ae&c[u>>2])+(ac&c[w>>2])+(aa&c[y>>2])+(R&c[A>>2])|0;ah=(c[2112999]|0)+T+((c[2112995]|0)+ak>>9)+(c[r>>2]&ai)+(c[t>>2]&ag)+(c[v>>2]&ae)+(c[x>>2]&ac)+(c[z>>2]&aa)+(c[B>>2]&R)|0;if((aj|0)>32767){am=32767}else{am=(aj|0)<-32768?-32768:aj&65535}if((ah|0)>32767){an=32767}else{an=(ah|0)<-32768?-32768:ah&65535}b[i+(Q<<1)>>1]=am;b[j+(Q<<1)>>1]=an;Q=Q+1|0;}while((Q|0)<(e|0));ao=c[3532586]|0}else{ao=l}l=ao+41|0;if((a[l]|0)!=0){return}if((a[ao+42|0]&a[ao+43|0])<<24>>24==0){return}a[l]=1;l=c[ao+1096>>2]|0;if((l|0)==0){return}gg[l&4095](d[ao|0]|0,1);return}function lW(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=e+8|0;g=(c[f>>2]|0)+(c[e+12>>2]|0)|0;c[f>>2]=g;do{if(g>>>0>65535){c[f>>2]=g&65535;h=e+4|0;i=e+2|0;j=e+32|0;k=e+28|0;l=c[e+20>>2]<<1&2097150;m=c[2112888]|0;n=g>>>16;o=c[h>>2]|0;while(1){if((o&2097151|0)==(l|0)){break}if((o&1|0)==0){p=a[m+(o>>>1)|0]|0;a[i]=p;q=(p&255)>>>4}else{q=a[i]&15}p=o+1|0;c[h>>2]=p;r=c[j>>2]|0;s=q&255;t=(c[k>>2]|0)+(c[9235536+(r+s<<2)>>2]|0)|0;u=(t&2048|0)==0?t&4095:t|-4096;c[k>>2]=u;t=(c[1160+((s&7)<<2)>>2]|0)+r|0;c[j>>2]=t;do{if((t|0)>768){c[j>>2]=768}else{if((t|0)>=0){break}c[j>>2]=0}}while(0);t=n-1|0;if((t|0)==0){v=11512;break}else{n=t;o=p}}if((v|0)==11512){o=ag(a[e+40|0]|0,u)|0;n=o>>d[e+41|0]&-4;c[e+36>>2]=n;w=n;break}a[e|0]=0;n=b+20904|0;a[n]=a[n]|a[e+1|0];return}else{w=c[e+36>>2]|0}}while(0);b=c[e+44>>2]|0;c[b>>2]=(c[b>>2]|0)+w;return}function lX(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;if((c[3541516]|0)!=0){i=f;return}c[2383472]=0;a[7460872]=1;g=gGq(21040)|0;c[3541516]=g;if((g|0)==0){i=f;return}gGz(g|0,0,21040);lR();g=a[7460872]|0;h=g&1;if(g){g=0;while(1){j=g&255;k=c[3541516]|0;a[k+(g*21040|0)+520|0]=j;a[k+(g*21040|0)+512|0]=23;c[k+(g*21040|0)+1652>>2]=k+(g*21040|0)+18152;c[k+(g*21040|0)+524>>2]=8e6;c[k+(g*21040|0)+528>>2]=b;c[k+(g*21040|0)+1612>>2]=2;c[k+(g*21040|0)+1616>>2]=2534;c[k+(g*21040|0)+20912>>2]=c[d+(g<<2)>>2];c[k+(g*21040|0)+20936>>2]=c[e+(g<<2)>>2];c[k+(g*21040|0)+21e3>>2]=158;c[k+(g*21040|0)+21004>>2]=1640;a[k+(g*21040|0)+21008|0]=j;a[k+(g*21040|0)+21009|0]=4;a[k+(g*21040|0)+21010|0]=8;a[k+(g*21040|0)+21011|0]=16;c[k+(g*21040|0)+20412>>2]=7452680;c[k+(g*21040|0)+20416>>2]=8192;l_(g);k=g+1|0;j=a[7460872]&1;if((k|0)<(j|0)){g=k}else{l=j;break}}}else{l=h}h=0;do{g=c[960+(h<<2)>>2]|0;e=h<<4;d=0;do{b=(ag(d<<1&14|1,g)|0)/8|0;c[9235536+(d+e<<2)>>2]=(d&8|0)!=0?-b|0:b;d=d+1|0;}while((d|0)<16);h=h+1|0;}while((h|0)<49);if((l|0)==0){m=0}else{l=0;while(1){h=c[3541516]|0;d=h+(l*21040|0)|0;e=gGq(272)|0;g=e;if((e|0)!=0){gGz(e|0,0,272);b=c[2430396]|0;c[e>>2]=b;if((b|0)!=0){c[b+4>>2]=g}c[2430396]=g;g=e+8|0;cC(g|0,231e3,(n=i,i=i+24|0,c[n>>2]=7452624,c[n+8>>2]=198680,c[n+16>>2]=l,n)|0)|0;i=n;c[e+264>>2]=d;c[e+268>>2]=512}mf(7452624,l,(c[3541516]|0)+(l*21040|0)+520|0);mg(7452624,l,(c[3541516]|0)+(l*21040|0)+18152|0,6);e=h+(l*21040|0)+1624|0;d=gGq(272)|0;g=d;if((d|0)!=0){gGz(d|0,0,272);b=c[2430396]|0;c[d>>2]=b;if((b|0)!=0){c[b+4>>2]=g}c[2430396]=g;g=d+8|0;cC(g|0,231e3,(n=i,i=i+24|0,c[n>>2]=7452624,c[n+8>>2]=157144,c[n+16>>2]=l,n)|0)|0;i=n;c[d+264>>2]=e;c[d+268>>2]=12}d=h+(l*21040|0)+1636|0;e=gGq(272)|0;g=e;if((e|0)!=0){gGz(e|0,0,272);b=c[2430396]|0;c[e>>2]=b;if((b|0)!=0){c[b+4>>2]=g}c[2430396]=g;g=e+8|0;cC(g|0,231e3,(n=i,i=i+24|0,c[n>>2]=7452624,c[n+8>>2]=126616,c[n+16>>2]=l,n)|0)|0;i=n;c[e+264>>2]=d;c[e+268>>2]=1}e=h+(l*21040|0)+1637|0;d=gGq(272)|0;g=d;if((d|0)!=0){gGz(d|0,0,272);b=c[2430396]|0;c[d>>2]=b;if((b|0)!=0){c[b+4>>2]=g}c[2430396]=g;g=d+8|0;cC(g|0,231e3,(n=i,i=i+24|0,c[n>>2]=7452624,c[n+8>>2]=101520,c[n+16>>2]=l,n)|0)|0;i=n;c[d+264>>2]=e;c[d+268>>2]=3}d=h+(l*21040|0)+20408|0;e=gGq(272)|0;g=e;if((e|0)!=0){gGz(e|0,0,272);b=c[2430396]|0;c[e>>2]=b;if((b|0)!=0){c[b+4>>2]=g}c[2430396]=g;g=e+8|0;cC(g|0,231e3,(n=i,i=i+24|0,c[n>>2]=7452624,c[n+8>>2]=78264,c[n+16>>2]=l,n)|0)|0;i=n;c[e+264>>2]=d;c[e+268>>2]=1}mi(7452624,l,h+(l*21040|0)+20424|0);lt(7452624,l,(c[3541516]|0)+(l*21040|0)+20912|0);h=l+1|0;if((h|0)<(a[7460872]&1|0)){l=h}else{m=0;break}}}while(1){if((m|0)>=8){o=11554;break}p=9774632+(m<<2)|0;if((c[p>>2]|0)==0){break}else{m=m+1|0}}if((o|0)==11554){i=f;return}c[p>>2]=8184;i=f;return}function lY(b,e){b=b|0;e=e|0;var f=0,g=0,h=0;f=b&255;b=c[3541516]|0;g=b+(f*21040|0)+563|0;h=a[g]|e;a[g]=h;g=b+(f*21040|0)+561|0;if((a[g]|0)!=0){return}if((a[b+(f*21040|0)+562|0]&h)<<24>>24==0){return}a[g]=1;g=c[b+(f*21040|0)+1616>>2]|0;if((g|0)==0){return}gg[g&4095](d[b+(f*21040|0)+520|0]|0,1);return}function lZ(b,e){b=b|0;e=e|0;var f=0,g=0,h=0;f=b&255;b=c[3541516]|0;g=b+(f*21040|0)+563|0;h=d[g]&(e&255^255);a[g]=h&255;g=b+(f*21040|0)+561|0;if((a[g]|0)==0){return}if((d[b+(f*21040|0)+562|0]&h|0)!=0){return}a[g]=0;g=c[b+(f*21040|0)+1616>>2]|0;if((g|0)==0){return}gg[g&4095](d[b+(f*21040|0)+520|0]|0,0);return}function l_(b){b=b|0;var e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0.0;e=c[3541516]|0;f=e+(b*21040|0)+512|0;g=b<<1;a[e+(b*21040|0)+568|0]=2;lI(f,144,144,8);i=e+(b*21040|0)+536|0;h[e+(b*21040|0)+20928>>3]=+h[i>>3];j=e+(b*21040|0)+520|0;mB((d[j]|0)+(c[2383582]|0)|0);h[e+(b*21040|0)+552>>3]=0.0;k=c[3541516]|0;l=f|0;a[l]=a[l]&-5;a[k+(b*21040|0)+21033|0]=31;m=e+(b*21040|0)+520|0;n=a[k+(b*21040|0)+21032|0]&31;k=e+(b*21040|0)+562|0;a[k]=n;o=e+(b*21040|0)+563|0;p=e+(b*21040|0)+561|0;do{if((a[p]|0)==0){if((a[o]&n)<<24>>24==0){break}a[p]=1;q=c[e+(b*21040|0)+1616>>2]|0;if((q|0)==0){r=n;s=11578;break}gg[q&4095](d[m|0]|0,1);if((a[p]|0)==0){break}r=a[k]|0;s=11578}else{r=n;s=11578}}while(0);do{if((s|0)==11578){if((a[o]&r)<<24>>24!=0){break}a[p]=0;n=c[e+(b*21040|0)+1616>>2]|0;if((n|0)==0){break}gg[n&4095](d[m|0]|0,0)}}while(0);r=c[3541516]|0;a[r+(b*21040|0)+21032|0]=-29;n=a[r+(b*21040|0)+21033|0]&-29;a[k]=n;do{if((a[p]|0)==0){if((a[o]&n)<<24>>24==0){break}a[p]=1;r=c[e+(b*21040|0)+1616>>2]|0;if((r|0)==0){t=n;s=11586;break}gg[r&4095](d[m|0]|0,1);if((a[p]|0)==0){break}t=a[k]|0;s=11586}else{t=n;s=11586}}while(0);do{if((s|0)==11586){if((a[o]&t)<<24>>24!=0){break}a[p]=0;n=c[e+(b*21040|0)+1616>>2]|0;if((n|0)==0){break}gg[n&4095](d[m|0]|0,0)}}while(0);lO(f,39,48);c[e+(b*21040|0)+1708>>2]=0;c[e+(b*21040|0)+1704>>2]=0;a[o]=0;do{if((a[p]|0)!=0){a[p]=0;o=c[e+(b*21040|0)+1616>>2]|0;if((o|0)==0){break}gg[o&4095](d[j]|0,0)}}while(0);c[e+(b*21040|0)+564>>2]=0;c[e+(b*21040|0)+572>>2]=0;c[e+(b*21040|0)+576>>2]=0;a[e+(b*21040|0)+580|0]=0;c[e+(b*21040|0)+584>>2]=0;j=0;do{c[e+(b*21040|0)+18152+(j*376|0)+364>>2]=0;a[e+(b*21040|0)+18152+(j*376|0)+68|0]=0;a[e+(b*21040|0)+18152+(j*376|0)+69|0]=0;a[e+(b*21040|0)+18152+(j*376|0)+40|0]=0;c[e+(b*21040|0)+18152+(j*376|0)+48>>2]=1023;c[e+(b*21040|0)+18152+(j*376|0)+56>>2]=1023;a[e+(b*21040|0)+18152+(j*376|0)+148|0]=0;a[e+(b*21040|0)+18152+(j*376|0)+149|0]=0;a[e+(b*21040|0)+18152+(j*376|0)+120|0]=0;c[e+(b*21040|0)+18152+(j*376|0)+128>>2]=1023;c[e+(b*21040|0)+18152+(j*376|0)+136>>2]=1023;a[e+(b*21040|0)+18152+(j*376|0)+228|0]=0;a[e+(b*21040|0)+18152+(j*376|0)+229|0]=0;a[e+(b*21040|0)+18152+(j*376|0)+200|0]=0;c[e+(b*21040|0)+18152+(j*376|0)+208>>2]=1023;c[e+(b*21040|0)+18152+(j*376|0)+216>>2]=1023;a[e+(b*21040|0)+18152+(j*376|0)+308|0]=0;a[e+(b*21040|0)+18152+(j*376|0)+309|0]=0;a[e+(b*21040|0)+18152+(j*376|0)+280|0]=0;c[e+(b*21040|0)+18152+(j*376|0)+288>>2]=1023;c[e+(b*21040|0)+18152+(j*376|0)+296>>2]=1023;j=j+1|0;}while((j|0)<6);j=e+(b*21040|0)+1652|0;p=c[j>>2]|0;o=a[l]|0;if((o&2)==0){u=p;v=o}else{c[p+1108>>2]=0;a[p+1112|0]=8;c[e+(b*21040|0)+1672>>2]=-1;c[e+(b*21040|0)+1676>>2]=-1;u=c[j>>2]|0;v=a[l]|0}if((v&2)==0){w=u;x=v}else{c[u+2236>>2]=0;a[u+2240|0]=8;c[e+(b*21040|0)+1696>>2]=-1;c[e+(b*21040|0)+1700>>2]=-1;w=c[j>>2]|0;x=a[l]|0}if((x&2)==0){y=w;z=x}else{c[w+732>>2]=0;a[w+736|0]=8;c[e+(b*21040|0)+1664>>2]=-1;c[e+(b*21040|0)+1668>>2]=-1;y=c[j>>2]|0;z=a[l]|0}if((z&2)==0){A=y;B=z}else{c[y+1860>>2]=0;a[y+1864|0]=8;c[e+(b*21040|0)+1688>>2]=-1;c[e+(b*21040|0)+1692>>2]=-1;A=c[j>>2]|0;B=a[l]|0}if((B&2)==0){C=A;D=B}else{c[A+356>>2]=0;a[A+360|0]=8;c[e+(b*21040|0)+1656>>2]=-1;c[e+(b*21040|0)+1660>>2]=-1;C=c[j>>2]|0;D=a[l]|0}if((D&2)==0){E=178}else{c[C+1484>>2]=0;a[C+1488|0]=8;c[e+(b*21040|0)+1680>>2]=-1;c[e+(b*21040|0)+1684>>2]=-1;E=178}while(1){lP(f,E,0);lP(f,E|256,0);C=E-1|0;if((C|0)>47){E=C}else{F=0;break}}do{G=+h[i>>3]*65536.0;if((F|0)<4){c[e+(b*21040|0)+20424+(F*48|0)+12>>2]=~~(G/3.0)}else{c[e+(b*21040|0)+20424+(F*48|0)+12>>2]=~~(G/6.0)}E=F<<1;c[e+(b*21040|0)+20424+(F*48|0)+16>>2]=c[7452632+(E<<2)>>2];c[e+(b*21040|0)+20424+(F*48|0)+20>>2]=c[7452632+((E|1)<<2)>>2];c[e+(b*21040|0)+20424+(F*48|0)+4>>2]=0;c[e+(b*21040|0)+20424+(F*48|0)+8>>2]=0;a[e+(b*21040|0)+20424+(F*48|0)+40|0]=0;c[e+(b*21040|0)+20424+(F*48|0)+44>>2]=8452004;a[e+(b*21040|0)+20424+(F*48|0)+1|0]=0;a[e+(b*21040|0)+20424+(F*48|0)|0]=0;c[e+(b*21040|0)+20424+(F*48|0)+28>>2]=0;c[e+(b*21040|0)+20424+(F*48|0)+32>>2]=0;c[e+(b*21040|0)+20424+(F*48|0)+36>>2]=0;F=F+1|0;}while((F|0)<6);a[e+(b*21040|0)+20420|0]=63;a[e+(b*21040|0)+20904|0]=0;h[e+(g*21040|0)+20928>>3]=+h[i>>3];c[e+(g*21040|0)+20916>>2]=8451976;a[e+(g*21040|0)+20996|0]=5;c[e+(g*21040|0)+20940>>2]=8388608;c[e+(g*21040|0)+20964>>2]=0;gGz(e+(g*21040|0)+20944|0,0,16);c[e+(g*21040|0)+20960>>2]=-1;c[e+(g*21040|0)+20972>>2]=0;c[e+(g*21040|0)+20920>>2]=8451988;c[e+(g*21040|0)+20976>>2]=0;c[e+(g*21040|0)+20988>>2]=0;c[e+(g*21040|0)+20980>>2]=127;c[e+(g*21040|0)+20984>>2]=0;a[e+(g*21040|0)+21029|0]=0;a[e+(g*21040|0)+20994|0]=0;a[e+(g*21040|0)+20995|0]=0;a[e+(g*21040|0)+20997|0]=3;i=c[e+(g*21040|0)+21e3>>2]|0;if((i|0)==0){return}b=a[e+(g*21040|0)+21010|0]|0;if(b<<24>>24==0){return}gg[i&4095](a[e+(g*21040|0)+21008|0]|0,b);return}function l$(b,e){b=b|0;e=e|0;var f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=c[3541516]|0;g=f+512|0;i=b&3;if((i|0)==0){a[f+560|0]=e;a[f+20408|0]=0;j=e&255;if((e&255)<16){c[14168912+((c[2383582]|0)*252|0)>>2]=j&15}if((e-45&255)>=3){return}if((j|0)==47){a[f+568|0]=0;k=0}else if((j|0)==0){a[f+568|0]=2;k=2}else if((j|0)==45){l=f+568|0;m=a[l]|2;a[l]=m;k=m}else if((j|0)==46){j=f+568|0;m=a[j]|1;a[j]=m;k=m}else{k=a[f+568|0]|0}m=k&3;k=c[7461744+(m<<2)>>2]<<1;lI(g,k,k,c[7461728+(m<<2)>>2]<<1);h[f+20928>>3]=+h[f+536>>3];return}else if((i|0)==2){a[f+560|0]=e;a[f+20408|0]=1;return}else if((i|0)==1){if((a[f+20408|0]|0)!=0){return}m=a[f+560|0]|0;k=m&255;a[f+k|0]=e;j=k&240;if((j|0)==32){if(m<<24>>24!=41){m=gj[c[2427018]&4095](c[2429376]|0)|0;l=c[2433542]|0;if((l|0)<(m|0)){n=m-l|0;m=c[2406682]|0;c[2438952]=m+(l+4<<1);c[2438953]=m+(l+4100<<1);lV(n);c[2433542]=(c[2433542]|0)+n}lO(g,k,e&255);return}n=g|0;l=a[n]|0;a[n]=e<<24>>24>-1?l&-5:l|4;l=e&31;a[f+21033|0]=l;n=f+520|0;m=a[f+21032|0]&l;l=f+562|0;a[l]=m;o=f+563|0;p=f+561|0;do{if((a[p]|0)==0){if((a[o]&m)<<24>>24==0){return}a[p]=1;q=c[f+1616>>2]|0;if((q|0)==0){r=m;break}gg[q&4095](d[n|0]|0,1);if((a[p]|0)==0){return}else{r=a[l]|0;break}}else{r=m}}while(0);if((a[o]&r)<<24>>24!=0){return}a[p]=0;p=c[f+1616>>2]|0;if((p|0)==0){return}gg[p&4095](d[n|0]|0,0);return}else if((j|0)==0){n=c[2383582]|0;p=e&255;if((b&1|0)==0){c[14168912+(n*252|0)>>2]=p&15;return}b=c[14168912+(n*252|0)>>2]|0;if((b|0)>15){return}do{if((b|0)<14){if((b|0)!=13){if((a[14168916+(n*252|0)+b|0]|0)==e<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(n,b,p);return}else if((j|0)==16){j=gj[c[2427018]&4095](c[2429376]|0)|0;p=c[2433542]|0;if((p|0)<(j|0)){b=j-p|0;j=c[2406682]|0;c[2438952]=j+(p+4<<1);c[2438953]=j+(p+4100<<1);lV(b);c[2433542]=(c[2433542]|0)+b}l0(f,k-16|0,e&255);return}else{b=gj[c[2427018]&4095](c[2429376]|0)|0;p=c[2433542]|0;if((p|0)<(b|0)){j=b-p|0;b=c[2406682]|0;c[2438952]=b+(p+4<<1);c[2438953]=b+(p+4100<<1);lV(j);c[2433542]=(c[2433542]|0)+j}lP(g,k,e&255);return}}else if((i|0)==3){if((a[f+20408|0]|0)!=1){return}i=a[f+560|0]|0;k=i&255;j=k|256;a[f+j|0]=e;p=gj[c[2427018]&4095](c[2429376]|0)|0;b=c[2433542]|0;if((b|0)<(p|0)){n=p-b|0;p=c[2406682]|0;c[2438952]=p+(b+4<<1);c[2438953]=p+(b+4100<<1);lV(n);c[2433542]=(c[2433542]|0)+n}n=k&240;if((n|0)==16){if(i<<24>>24!=16){return}b=e&255;p=c[3541516]|0;if((b&128|0)!=0){r=f+563|0;o=a[r]&8;a[r]=o&255;r=f+561|0;if((a[r]|0)==0){return}if((d[f+562|0]&o|0)!=0){return}a[r]=0;r=c[f+1616>>2]|0;if((r|0)==0){return}gg[r&4095](d[f+520|0]|0,0);return}r=(b|224)^31;a[p+21032|0]=r&255;b=f+520|0;o=d[p+21033|0]&r&255;r=f+562|0;a[r]=o;p=f+563|0;m=f+561|0;do{if((a[m]|0)==0){if((a[p]&o)<<24>>24==0){return}a[m]=1;l=c[f+1616>>2]|0;if((l|0)==0){s=o;break}gg[l&4095](d[b|0]|0,1);if((a[m]|0)==0){return}else{s=a[r]|0;break}}else{s=o}}while(0);if((a[p]&s)<<24>>24!=0){return}a[m]=0;m=c[f+1616>>2]|0;if((m|0)==0){return}gg[m&4095](d[b|0]|0,0);return}else if((n|0)==0){if(i<<24>>24==14){return}lr(f+20912|0,k,e&255);return}else{lP(g,j,e&255);return}}else{return}}function l0(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;c[b+20712+(e<<2)>>2]=f&255;if((e|0)==0){if((f&128|0)==0){g=b+536|0;i=b+20412|0;j=b+20416|0;k=0;l=0;while(1){do{if((1<<l&f|0)!=0){c[b+20424+(l*48|0)+12>>2]=~~(+h[g>>3]*65536.0/3.0);m=c[b+20424+(l*48|0)+16>>2]|0;c[b+20424+(l*48|0)+4>>2]=m<<1;c[b+20424+(l*48|0)+8>>2]=0;c[b+20424+(l*48|0)+28>>2]=0;c[b+20424+(l*48|0)+32>>2]=0;c[b+20424+(l*48|0)+36>>2]=0;n=b+20424+(l*48|0)|0;a[n]=1;if((c[i>>2]|0)==0){a[n]=0;break}if(m>>>0<(c[j>>2]|0)>>>0){break}a[n]=0}}while(0);n=k+1&255;if((n&255)<6){k=n;l=n&255}else{break}}return}if((f&1|0)!=0){a[b+20424|0]=0}if((f&2|0)!=0){a[b+20472|0]=0}if((f&4|0)!=0){a[b+20520|0]=0}if((f&8|0)!=0){a[b+20568|0]=0}if((f&16|0)!=0){a[b+20616|0]=0}if((f&32|0)==0){return}a[b+20664|0]=0;return}else if((e|0)==1){l=f&63^63;a[b+20420|0]=l&255;k=0;do{j=k&255;i=(d[b+20424+(j*48|0)+24|0]|0)+l|0;if((i|0)>62){a[b+20424+(j*48|0)+40|0]=0;a[b+20424+(j*48|0)+41|0]=0;o=0;p=0}else{g=i&7^15;a[b+20424+(j*48|0)+40|0]=g&255;n=(i>>>3)+1|0;a[b+20424+(j*48|0)+41|0]=n&255;o=g;p=n&255}c[b+20424+(j*48|0)+36>>2]=(ag(c[b+20424+(j*48|0)+28>>2]|0,o)|0)>>p&-4;k=k+1&255;}while((k&255)<6);return}else{k=e&7;if(k>>>0>5){return}switch(e&56|0){case 16:case 24:{c[b+20424+(k*48|0)+16>>2]=(c[b+20712+((k|24)<<2)>>2]<<8|c[b+20712+((k|16)<<2)>>2])<<8;return};case 32:case 40:{c[b+20424+(k*48|0)+20>>2]=(c[b+20712+((k|40)<<2)>>2]<<8|c[b+20712+((k|32)<<2)>>2])<<8|255;return};case 8:{e=f&31^31;a[b+20424+(k*48|0)+24|0]=e&255;p=(d[b+20420|0]|0)+e|0;if((p|0)>62){a[b+20424+(k*48|0)+40|0]=0;a[b+20424+(k*48|0)+41|0]=0;q=0;r=0}else{e=p&7^15;a[b+20424+(k*48|0)+40|0]=e&255;o=(p>>>3)+1|0;a[b+20424+(k*48|0)+41|0]=o&255;q=e;r=o&255}c[b+20424+(k*48|0)+44>>2]=8451992+((f>>>6&3)<<2);c[b+20424+(k*48|0)+36>>2]=(ag(c[b+20424+(k*48|0)+28>>2]|0,q)|0)>>r&-4;return};default:{return}}}}function l1(b,e){b=b|0;e=e|0;var f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0;f=c[3541516]|0;if((e|0)==1){g=f+(b*21040|0)+520|0;do{if((c[f+(b*21040|0)+564>>2]&8|0)!=0){i=f+(b*21040|0)+563|0;j=d[i]|2;a[i]=j&255;i=f+(b*21040|0)+561|0;if((a[i]|0)!=0){break}if((d[f+(b*21040|0)+562|0]&j|0)==0){break}a[i]=1;i=c[f+(b*21040|0)+1616>>2]|0;if((i|0)==0){break}gg[i&4095](d[g|0]|0,1)}}while(0);i=256-(d[f+(b*21040|0)+580|0]|0)<<4;c[f+(b*21040|0)+584>>2]=i;j=c[f+(b*21040|0)+1612>>2]|0;if((j|0)==0){k=c[3541516]|0;l=k+561|0;m=a[l]|0;n=m&255;return n|0}gn[j&3](d[g|0]|0,1,i,+h[f+(b*21040|0)+544>>3]);k=c[3541516]|0;l=k+561|0;m=a[l]|0;n=m&255;return n|0}else if((e|0)==0){e=gj[c[2427018]&4095](c[2429376]|0)|0;i=c[2433542]|0;if((i|0)<(e|0)){g=e-i|0;e=c[2406682]|0;c[2438952]=e+(i+4<<1);c[2438953]=e+(i+4100<<1);lV(g);c[2433542]=(c[2433542]|0)+g}g=f+(b*21040|0)+520|0;i=f+(b*21040|0)+564|0;do{if((c[i>>2]&4|0)!=0){e=f+(b*21040|0)+563|0;j=d[e]|1;a[e]=j&255;e=f+(b*21040|0)+561|0;if((a[e]|0)!=0){break}if((d[f+(b*21040|0)+562|0]&j|0)==0){break}a[e]=1;e=c[f+(b*21040|0)+1616>>2]|0;if((e|0)==0){break}gg[e&4095](d[g|0]|0,1)}}while(0);e=1024-(c[f+(b*21040|0)+572>>2]|0)|0;c[f+(b*21040|0)+576>>2]=e;j=c[f+(b*21040|0)+1612>>2]|0;if((j|0)!=0){gn[j&3](d[g|0]|0,0,e,+h[f+(b*21040|0)+544>>3])}if((c[i>>2]&128|0)==0){k=c[3541516]|0;l=k+561|0;m=a[l]|0;n=m&255;return n|0}lU(a[f+(b*21040|0)+512|0]|0,f+(b*21040|0)+18904|0);k=c[3541516]|0;l=k+561|0;m=a[l]|0;n=m&255;return n|0}else{k=c[3541516]|0;l=k+561|0;m=a[l]|0;n=m&255;return n|0}return 0}function l2(e){e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0;f=c[3541514]|0;g=f+512|0;h=f+20912|0;i=c[2438946]|0;j=c[2438947]|0;k=f|0;if((k|0)==(c[2383472]|0)){l=c[2383566]|0}else{c[2383472]=k;c[3532586]=f+520;k=f+18528|0;c[2383566]=k;c[2383564]=f+18904;c[2383562]=f+19656;c[2383560]=f+20032;c[2112888]=c[f+20412>>2];l=k}if((c[l+36>>2]|0)==-1){k=c[l+364>>2]|0;m=d[l+368|0]|0;lK(g,l|0,k,m);lK(g,l+160|0,k,m);lK(g,l+80|0,k,m);lK(g,l+240|0,k,m)}m=c[2383564]|0;k=(c[m+36>>2]|0)==-1;do{if((c[(c[3532586]|0)+44>>2]&192|0)==0){if(!k){break}l=c[m+364>>2]|0;n=d[m+368|0]|0;lK(g,m|0,l,n);lK(g,m+160|0,l,n);lK(g,m+80|0,l,n);lK(g,m+240|0,l,n)}else{if(!k){break}lK(g,m|0,c[f+1628>>2]|0,d[f+1638|0]|0);lK(g,m+160|0,c[f+1632>>2]|0,d[f+1639|0]|0);lK(g,m+80|0,c[f+1624>>2]|0,d[f+1637|0]|0);lK(g,m+240|0,c[m+364>>2]|0,d[m+368|0]|0)}}while(0);m=c[2383562]|0;if((c[m+36>>2]|0)==-1){k=c[m+364>>2]|0;n=d[m+368|0]|0;lK(g,m|0,k,n);lK(g,m+160|0,k,n);lK(g,m+80|0,k,n);lK(g,m+240|0,k,n)}n=c[2383560]|0;if((c[n+36>>2]|0)==-1){k=c[n+364>>2]|0;m=d[n+368|0]|0;lK(g,n|0,k,m);lK(g,n+160|0,k,m);lK(g,n+80|0,k,m);lK(g,n+240|0,k,m)}if((e|0)<=0){return}m=f+18112|0;k=f+1712|0;n=f+1708|0;l=f+1716|0;o=f+20994|0;p=f+1664|0;q=f+1668|0;r=f+1672|0;s=f+1676|0;t=f+1688|0;u=f+1692|0;v=f+1696|0;w=f+1700|0;x=f+1704|0;y=f+18108|0;z=f+20424|0;A=z|0;B=f+20472|0;C=B|0;D=f+20520|0;E=D|0;F=f+20568|0;G=F|0;H=f+20616|0;I=H|0;J=f+20664|0;K=J|0;L=0;do{M=c[m>>2]|0;if((M|0)==0){c[3541216]=0;N=0}else{O=(c[y>>2]|0)+M|0;c[y>>2]=O;M=O>>>24;O=M&127;P=M<<1&126;c[3541216]=O>>>0<64?P:126-P|0;N=O>>>2}c[3541212]=N;c[2113001]=0;c[2112999]=0;c[2113e3]=0;c[2112997]=0;c[2112995]=0;c[2112996]=0;c[2112987]=0;c[2112988]=0;c[2112990]=0;c[2112991]=0;O=(c[n>>2]|0)+(c[k>>2]|0)|0;c[n>>2]=O;P=c[l>>2]|0;M=c[2383566]|0;if(O>>>0<P>>>0){Q=M;R=c[2383564]|0;S=c[2383562]|0;T=c[2383560]|0}else{U=M|0;V=c[2383564]|0;W=V|0;X=c[2383562]|0;Y=X|0;Z=c[2383560]|0;_=Z|0;$=O;O=P;while(1){c[n>>2]=$-O;c[x>>2]=(c[x>>2]|0)+1;lL(g,U);lL(g,W);lL(g,Y);lL(g,_);P=c[n>>2]|0;aa=c[l>>2]|0;if(P>>>0<aa>>>0){Q=M;R=V;S=X;T=Z;break}else{$=P;O=aa}}}lM(g,Q,1);lM(g,R,2);lM(g,S,4);lM(g,T,5);if((a[o]|0)<0){lu(h)}if((a[A]|0)!=0){lW(f,z)}if((a[C]|0)!=0){lW(f,B)}if((a[E]|0)!=0){lW(f,D)}if((a[G]|0)!=0){lW(f,F)}if((a[I]|0)!=0){lW(f,H)}if((a[K]|0)!=0){lW(f,J)}O=c[2113001]|0;$=c[2112997]|0;Z=c[2112987]>>1;X=c[2112988]>>1;V=c[2112990]>>1;M=c[2112991]>>1;_=O+(c[2113e3]|0)+($+(c[2112996]|0)>>9)+(Z&c[p>>2])+(X&c[r>>2])+(V&c[t>>2])+(M&c[v>>2])|0;Y=(c[2112999]|0)+O+((c[2112995]|0)+$>>9)+(c[q>>2]&Z)+(c[s>>2]&X)+(c[u>>2]&V)+(c[w>>2]&M)|0;if((_|0)>32767){ab=32767}else{ab=(_|0)<-32768?-32768:_&65535}if((Y|0)>32767){ac=32767}else{ac=(Y|0)<-32768?-32768:Y&65535}b[i+(L<<1)>>1]=ab;b[j+(L<<1)>>1]=ac;L=L+1|0;}while((L|0)<(e|0));return}function l3(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;j=i;if((c[3541514]|0)!=0){i=j;return}c[2383472]=0;a[7452616]=1;k=gGq(21040)|0;c[3541514]=k;if((k|0)==0){i=j;return}gGz(k|0,0,21040);lR();k=a[7452616]|0;l=k&1;if(k){k=0;while(1){m=c[3541514]|0;n=k&255;a[m+(k*21040|0)+520|0]=n;a[m+(k*21040|0)+512|0]=55;c[m+(k*21040|0)+1652>>2]=m+(k*21040|0)+18152;c[m+(k*21040|0)+524>>2]=8e6;c[m+(k*21040|0)+528>>2]=b;c[m+(k*21040|0)+1612>>2]=2;c[m+(k*21040|0)+1616>>2]=h;c[m+(k*21040|0)+20412>>2]=c[d+(k<<2)>>2];c[m+(k*21040|0)+20416>>2]=c[e+(k<<2)>>2];c[m+(k*21040|0)+20912>>2]=c[f+(k<<2)>>2];c[m+(k*21040|0)+20936>>2]=c[g+(k<<2)>>2];c[m+(k*21040|0)+21e3>>2]=810;c[m+(k*21040|0)+21004>>2]=3270;a[m+(k*21040|0)+21008|0]=n;a[m+(k*21040|0)+21009|0]=-128;l6(k);m=k+1|0;n=a[7452616]&1;if((m|0)<(n|0)){k=m}else{o=n;break}}}else{o=l}l=0;do{k=c[960+(l<<2)>>2]|0;g=l<<4;f=0;do{e=(ag(f<<1&14|1,k)|0)/8|0;c[9235536+(f+g<<2)>>2]=(f&8|0)!=0?-e|0:e;f=f+1|0;}while((f|0)<16);l=l+1|0;}while((l|0)<49);if((o|0)==0){p=0}else{o=0;while(1){l=c[3541514]|0;f=l+(o*21040|0)|0;g=gGq(272)|0;k=g;if((g|0)!=0){gGz(g|0,0,272);e=c[2430396]|0;c[g>>2]=e;if((e|0)!=0){c[e+4>>2]=k}c[2430396]=k;k=g+8|0;cC(k|0,231e3,(q=i,i=i+24|0,c[q>>2]=7452608,c[q+8>>2]=198680,c[q+16>>2]=o,q)|0)|0;i=q;c[g+264>>2]=f;c[g+268>>2]=512}mf(7452608,o,(c[3541514]|0)+(o*21040|0)+520|0);mg(7452608,o,(c[3541514]|0)+(o*21040|0)+18152|0,6);g=l+(o*21040|0)+1624|0;f=gGq(272)|0;k=f;if((f|0)!=0){gGz(f|0,0,272);e=c[2430396]|0;c[f>>2]=e;if((e|0)!=0){c[e+4>>2]=k}c[2430396]=k;k=f+8|0;cC(k|0,231e3,(q=i,i=i+24|0,c[q>>2]=7452608,c[q+8>>2]=157144,c[q+16>>2]=o,q)|0)|0;i=q;c[f+264>>2]=g;c[f+268>>2]=12}f=l+(o*21040|0)+1636|0;g=gGq(272)|0;k=g;if((g|0)!=0){gGz(g|0,0,272);e=c[2430396]|0;c[g>>2]=e;if((e|0)!=0){c[e+4>>2]=k}c[2430396]=k;k=g+8|0;cC(k|0,231e3,(q=i,i=i+24|0,c[q>>2]=7452608,c[q+8>>2]=126616,c[q+16>>2]=o,q)|0)|0;i=q;c[g+264>>2]=f;c[g+268>>2]=1}g=l+(o*21040|0)+1637|0;f=gGq(272)|0;k=f;if((f|0)!=0){gGz(f|0,0,272);e=c[2430396]|0;c[f>>2]=e;if((e|0)!=0){c[e+4>>2]=k}c[2430396]=k;k=f+8|0;cC(k|0,231e3,(q=i,i=i+24|0,c[q>>2]=7452608,c[q+8>>2]=101520,c[q+16>>2]=o,q)|0)|0;i=q;c[f+264>>2]=g;c[f+268>>2]=3}f=l+(o*21040|0)+20408|0;g=gGq(272)|0;k=g;if((g|0)!=0){gGz(g|0,0,272);e=c[2430396]|0;c[g>>2]=e;if((e|0)!=0){c[e+4>>2]=k}c[2430396]=k;k=g+8|0;cC(k|0,231e3,(q=i,i=i+24|0,c[q>>2]=7452608,c[q+8>>2]=78264,c[q+16>>2]=o,q)|0)|0;i=q;c[g+264>>2]=f;c[g+268>>2]=1}g=l+(o*21040|0)+20904|0;f=gGq(272)|0;k=f;if((f|0)!=0){gGz(f|0,0,272);e=c[2430396]|0;c[f>>2]=e;if((e|0)!=0){c[e+4>>2]=k}c[2430396]=k;k=f+8|0;cC(k|0,231e3,(q=i,i=i+24|0,c[q>>2]=7452608,c[q+8>>2]=354432,c[q+16>>2]=o,q)|0)|0;i=q;c[f+264>>2]=g;c[f+268>>2]=1}mi(7452608,o,l+(o*21040|0)+20424|0);lt(7452608,o,(c[3541514]|0)+(o*21040|0)+20912|0);l=o+1|0;if((l|0)<(a[7452616]&1|0)){o=l}else{p=0;break}}}while(1){if((p|0)>=8){r=11865;break}s=9774632+(p<<2)|0;if((c[s>>2]|0)==0){break}else{p=p+1|0}}if((r|0)==11865){i=j;return}c[s>>2]=3654;i=j;return}function l4(b,d){b=b|0;d=d|0;var e=0;e=(c[3541514]|0)+((b&255)*21040|0)+20904|0;a[e]=a[e]|d;return}function l5(b,d){b=b|0;d=d|0;var e=0;e=(c[3541514]|0)+((b&255)*21040|0)+20904|0;a[e]=a[e]&~d;return}function l6(b){b=b|0;var e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;e=c[3541514]|0;f=e+(b*21040|0)+512|0;lI(f,144,144,8);g=e+(b*21040|0)+520|0;mB((d[g]|0)+(c[2383582]|0)|0);i=e+(b*21040|0)+562|0;a[i]=3;j=e+(b*21040|0)+563|0;k=e+(b*21040|0)+561|0;do{if((a[k]|0)==0){if((a[j]&3)==0){break}a[k]=1;l=c[e+(b*21040|0)+1616>>2]|0;if((l|0)==0){m=3;n=11873;break}gg[l&4095](d[g]|0,1);if((a[k]|0)==0){break}m=a[i]|0;n=11873}else{m=3;n=11873}}while(0);do{if((n|0)==11873){if((a[j]&m)<<24>>24!=0){break}a[k]=0;i=c[e+(b*21040|0)+1616>>2]|0;if((i|0)==0){break}gg[i&4095](d[g]|0,0)}}while(0);h[e+(b*21040|0)+552>>3]=0.0;lO(f,39,48);c[e+(b*21040|0)+1708>>2]=0;c[e+(b*21040|0)+1704>>2]=0;a[j]=0;do{if((a[k]|0)!=0){a[k]=0;j=c[e+(b*21040|0)+1616>>2]|0;if((j|0)==0){break}gg[j&4095](d[g]|0,0)}}while(0);c[e+(b*21040|0)+564>>2]=0;c[e+(b*21040|0)+572>>2]=0;c[e+(b*21040|0)+576>>2]=0;a[e+(b*21040|0)+580|0]=0;c[e+(b*21040|0)+584>>2]=0;g=0;do{c[e+(b*21040|0)+18152+(g*376|0)+364>>2]=0;a[e+(b*21040|0)+18152+(g*376|0)+68|0]=0;a[e+(b*21040|0)+18152+(g*376|0)+69|0]=0;a[e+(b*21040|0)+18152+(g*376|0)+40|0]=0;c[e+(b*21040|0)+18152+(g*376|0)+48>>2]=1023;c[e+(b*21040|0)+18152+(g*376|0)+56>>2]=1023;a[e+(b*21040|0)+18152+(g*376|0)+148|0]=0;a[e+(b*21040|0)+18152+(g*376|0)+149|0]=0;a[e+(b*21040|0)+18152+(g*376|0)+120|0]=0;c[e+(b*21040|0)+18152+(g*376|0)+128>>2]=1023;c[e+(b*21040|0)+18152+(g*376|0)+136>>2]=1023;a[e+(b*21040|0)+18152+(g*376|0)+228|0]=0;a[e+(b*21040|0)+18152+(g*376|0)+229|0]=0;a[e+(b*21040|0)+18152+(g*376|0)+200|0]=0;c[e+(b*21040|0)+18152+(g*376|0)+208>>2]=1023;c[e+(b*21040|0)+18152+(g*376|0)+216>>2]=1023;a[e+(b*21040|0)+18152+(g*376|0)+308|0]=0;a[e+(b*21040|0)+18152+(g*376|0)+309|0]=0;a[e+(b*21040|0)+18152+(g*376|0)+280|0]=0;c[e+(b*21040|0)+18152+(g*376|0)+288>>2]=1023;c[e+(b*21040|0)+18152+(g*376|0)+296>>2]=1023;g=g+1|0;}while((g|0)<6);g=e+(b*21040|0)+1652|0;k=c[g>>2]|0;j=f|0;m=a[j]|0;if((m&2)==0){o=k;p=m}else{c[k+1108>>2]=0;a[k+1112|0]=8;c[e+(b*21040|0)+1672>>2]=-1;c[e+(b*21040|0)+1676>>2]=-1;o=c[g>>2]|0;p=a[j]|0}if((p&2)==0){q=o;r=p}else{c[o+2236>>2]=0;a[o+2240|0]=8;c[e+(b*21040|0)+1696>>2]=-1;c[e+(b*21040|0)+1700>>2]=-1;q=c[g>>2]|0;r=a[j]|0}if((r&2)==0){s=q;t=r}else{c[q+732>>2]=0;a[q+736|0]=8;c[e+(b*21040|0)+1664>>2]=-1;c[e+(b*21040|0)+1668>>2]=-1;s=c[g>>2]|0;t=a[j]|0}if((t&2)==0){u=s;v=t}else{c[s+1860>>2]=0;a[s+1864|0]=8;c[e+(b*21040|0)+1688>>2]=-1;c[e+(b*21040|0)+1692>>2]=-1;u=c[g>>2]|0;v=a[j]|0}if((v&2)==0){w=u;x=v}else{c[u+356>>2]=0;a[u+360|0]=8;c[e+(b*21040|0)+1656>>2]=-1;c[e+(b*21040|0)+1660>>2]=-1;w=c[g>>2]|0;x=a[j]|0}if((x&2)==0){y=178}else{c[w+1484>>2]=0;a[w+1488|0]=8;c[e+(b*21040|0)+1680>>2]=-1;c[e+(b*21040|0)+1684>>2]=-1;y=178}do{lP(f,y,0);lP(f,y|256,0);y=y-1|0;}while((y|0)>47);y=e+(b*21040|0)+536|0;f=0;do{c[e+(b*21040|0)+20424+(f*48|0)+12>>2]=~~(+h[y>>3]*65536.0/3.0);c[e+(b*21040|0)+20424+(f*48|0)+4>>2]=0;c[e+(b*21040|0)+20424+(f*48|0)+8>>2]=0;c[e+(b*21040|0)+20424+(f*48|0)+16>>2]=0;c[e+(b*21040|0)+20424+(f*48|0)+20>>2]=0;a[e+(b*21040|0)+20424+(f*48|0)+40|0]=0;c[e+(b*21040|0)+20424+(f*48|0)+44>>2]=8452004;a[e+(b*21040|0)+20424+(f*48|0)+1|0]=1<<f&255;a[e+(b*21040|0)+20424+(f*48|0)|0]=0;c[e+(b*21040|0)+20424+(f*48|0)+28>>2]=0;c[e+(b*21040|0)+20424+(f*48|0)+32>>2]=0;c[e+(b*21040|0)+20424+(f*48|0)+36>>2]=0;f=f+1|0;}while((f|0)<6);a[e+(b*21040|0)+20420|0]=63;a[e+(b*21040|0)+20904|0]=0;h[e+(b*21040|0)+20928>>3]=+h[y>>3];c[e+(b*21040|0)+20916>>2]=8451976;a[e+(b*21040|0)+20996|0]=8;c[e+(b*21040|0)+20940>>2]=8388608;c[e+(b*21040|0)+20964>>2]=0;gGz(e+(b*21040|0)+20944|0,0,16);c[e+(b*21040|0)+20960>>2]=-1;c[e+(b*21040|0)+20972>>2]=0;c[e+(b*21040|0)+20920>>2]=8451988;c[e+(b*21040|0)+20976>>2]=0;c[e+(b*21040|0)+20988>>2]=0;c[e+(b*21040|0)+20980>>2]=127;c[e+(b*21040|0)+20984>>2]=0;a[e+(b*21040|0)+21029|0]=1;a[e+(b*21040|0)+20994|0]=32;a[e+(b*21040|0)+20995|0]=1;a[e+(b*21040|0)+20997|0]=0;y=c[e+(b*21040|0)+21e3>>2]|0;if((y|0)==0){return}f=a[e+(b*21040|0)+21010|0]|0;if(f<<24>>24==0){return}gg[y&4095](a[e+(b*21040|0)+21008|0]|0,f);return}function l7(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=c[3541514]|0;g=f+512|0;h=b&3;if((h|0)==0){a[f+560|0]=e;a[f+20408|0]=0;if((e&255)>=16){return}c[14168912+((c[2383582]|0)*252|0)>>2]=e&15;return}else if((h|0)==1){if((a[f+20408|0]|0)!=0){return}i=d[f+560|0]|0;a[f+i|0]=e;j=i&240;if((j|0)==16){k=gj[c[2427016]&4095](c[2429374]|0)|0;l=c[2433540]|0;if((l|0)<(k|0)){m=k-l|0;k=c[2406698]|0;c[2438946]=k+(l+4<<1);c[2438947]=k+(l+4100<<1);l2(m);c[2433540]=(c[2433540]|0)+m}switch(i|0){case 28:{m=~e;a[f+20425|0]=m&1;a[f+20473|0]=m&2;a[f+20521|0]=m&4;a[f+20569|0]=m&8;a[f+20617|0]=m&16;a[f+20665|0]=m&32;a[f+21009|0]=m&-128;l=f+20904|0;a[l]=a[l]&m;return};case 16:case 17:case 18:case 19:case 20:case 21:case 25:case 26:case 27:{lr(f+20912|0,i-16|0,e&255);return};default:{return}}}else if((j|0)==0){m=c[2383582]|0;l=e&255;if((b&1|0)==0){c[14168912+(m*252|0)>>2]=l&15;return}b=c[14168912+(m*252|0)>>2]|0;if((b|0)>15){return}do{if((b|0)<14){if((b|0)!=13){if((a[14168916+(m*252|0)+b|0]|0)==e<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(m,b,l);return}else if((j|0)==32){j=gj[c[2427016]&4095](c[2429374]|0)|0;l=c[2433540]|0;if((l|0)<(j|0)){b=j-l|0;j=c[2406698]|0;c[2438946]=j+(l+4<<1);c[2438947]=j+(l+4100<<1);l2(b);c[2433540]=(c[2433540]|0)+b}lO(g,i,e&255);return}else{b=gj[c[2427016]&4095](c[2429374]|0)|0;l=c[2433540]|0;if((l|0)<(b|0)){j=b-l|0;b=c[2406698]|0;c[2438946]=b+(l+4<<1);c[2438947]=b+(l+4100<<1);l2(j);c[2433540]=(c[2433540]|0)+j}lP(g,i,e&255);return}}else if((h|0)==3){if((a[f+20408|0]|0)!=1){return}i=gj[c[2427016]&4095](c[2429374]|0)|0;j=c[2433540]|0;if((j|0)<(i|0)){l=i-j|0;i=c[2406698]|0;c[2438946]=i+(j+4<<1);c[2438947]=i+(j+4100<<1);l2(l);c[2433540]=(c[2433540]|0)+l}l=a[f+560|0]|0;j=l&255;i=j|256;a[f+i|0]=e;b=e&255;if((l&255)<48){l0(f,j,b);return}else{lP(g,i,b);return}}else if((h|0)==2){a[f+560|0]=e;a[f+20408|0]=1;return}else{return}}function l8(b){b=b|0;var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0.0,o=0.0,p=0,q=0;d=c[3541514]|0;e=a[d+560|0]|0;f=b&3;if((f|0)==2){g=a[d+20904|0]|0;return g|0}else if((f|0)==1){if((e&255)>=16){i=0;j=e<<24>>24==-1;k=j?1:i;return k|0}b=c[2383582]|0;l=c[14168912+(b*252|0)>>2]|0;if((l|0)>15){i=0;j=e<<24>>24==-1;k=j?1:i;return k|0}do{if((l|0)==14){m=c[14168896+(b*252|0)>>2]|0;if((m|0)==0){break}a[14168930+(b*252|0)|0]=gj[m&4095](0)|0}else if((l|0)==15){m=c[14168900+(b*252|0)>>2]|0;if((m|0)==0){break}a[14168931+(b*252|0)|0]=gj[m&4095](0)|0}}while(0);i=a[14168916+(b*252|0)+l|0]|0;j=e<<24>>24==-1;k=j?1:i;return k|0}else if((f|0)==0){f=d+552|0;n=+h[f>>3];do{if(n!=0.0){o=+h[6675];if(n-(o+ +gC[c[2429842]&255]())>0.0){p=a[d+563|0]|-128;break}else{h[f>>3]=0.0;q=11956;break}}else{q=11956}}while(0);if((q|0)==11956){p=a[d+563|0]|0}g=p&-125;return g|0}else{g=0;return g|0}return 0}function l9(b,e){b=b|0;e=e|0;var f=0,g=0,i=0,j=0,k=0,l=0,m=0;f=c[3541514]|0;if((e|0)!=0){e=f+(b*21040|0)+520|0;do{if((c[f+(b*21040|0)+564>>2]&8|0)!=0){g=f+(b*21040|0)+563|0;i=d[g]|2;a[g]=i&255;g=f+(b*21040|0)+561|0;if((a[g]|0)!=0){break}if((d[f+(b*21040|0)+562|0]&i|0)==0){break}a[g]=1;g=c[f+(b*21040|0)+1616>>2]|0;if((g|0)==0){break}gg[g&4095](d[e|0]|0,1)}}while(0);g=256-(d[f+(b*21040|0)+580|0]|0)<<4;c[f+(b*21040|0)+584>>2]=g;i=c[f+(b*21040|0)+1612>>2]|0;if((i|0)==0){j=f+(b*21040|0)+561|0;k=a[j]|0;l=k&255;return l|0}gn[i&3](d[e|0]|0,1,g,+h[f+(b*21040|0)+544>>3]);j=f+(b*21040|0)+561|0;k=a[j]|0;l=k&255;return l|0}g=gj[c[2427016]&4095](c[2429374]|0)|0;e=c[2433540]|0;if((e|0)<(g|0)){i=g-e|0;g=c[2406698]|0;c[2438946]=g+(e+4<<1);c[2438947]=g+(e+4100<<1);l2(i);c[2433540]=(c[2433540]|0)+i}i=f+(b*21040|0)+520|0;e=f+(b*21040|0)+564|0;do{if((c[e>>2]&4|0)!=0){g=f+(b*21040|0)+563|0;m=d[g]|1;a[g]=m&255;g=f+(b*21040|0)+561|0;if((a[g]|0)!=0){break}if((d[f+(b*21040|0)+562|0]&m|0)==0){break}a[g]=1;g=c[f+(b*21040|0)+1616>>2]|0;if((g|0)==0){break}gg[g&4095](d[i|0]|0,1)}}while(0);g=1024-(c[f+(b*21040|0)+572>>2]|0)|0;c[f+(b*21040|0)+576>>2]=g;m=c[f+(b*21040|0)+1612>>2]|0;if((m|0)!=0){gn[m&3](d[i|0]|0,0,g,+h[f+(b*21040|0)+544>>3])}if((c[e>>2]&128|0)==0){j=f+(b*21040|0)+561|0;k=a[j]|0;l=k&255;return l|0}lU(a[f+(b*21040|0)+512|0]|0,f+(b*21040|0)+18904|0);j=f+(b*21040|0)+561|0;k=a[j]|0;l=k&255;return l|0}function ma(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;h=c[3541512]|0;i=h+(a*20424|0)+512|0;j=c[h+(a*20424|0)+20416>>2]|0;k=h+(a*20424|0)|0;if((k|0)==(c[2383472]|0)){l=c[2383566]|0}else{c[2383472]=k;c[3532586]=h+(a*20424|0)+520;k=h+(a*20424|0)+18152|0;c[2383566]=k;c[2383564]=h+(a*20424|0)+18528;c[2383562]=h+(a*20424|0)+18904;c[2383560]=h+(a*20424|0)+19280;c[2383558]=h+(a*20424|0)+19656;c[2383556]=h+(a*20424|0)+20032;c[2383452]=c[h+(a*20424|0)+20412>>2];l=k}if((c[l+36>>2]|0)==-1){k=c[l+364>>2]|0;m=d[l+368|0]|0;lK(i,l|0,k,m);lK(i,l+160|0,k,m);lK(i,l+80|0,k,m);lK(i,l+240|0,k,m)}m=c[2383564]|0;if((c[m+36>>2]|0)==-1){k=c[m+364>>2]|0;n=d[m+368|0]|0;lK(i,m|0,k,n);lK(i,m+160|0,k,n);lK(i,m+80|0,k,n);lK(i,m+240|0,k,n)}n=c[2383562]|0;k=(c[n+36>>2]|0)==-1;do{if((c[(c[3532586]|0)+44>>2]&192|0)==0){if(!k){break}o=c[n+364>>2]|0;p=d[n+368|0]|0;lK(i,n|0,o,p);lK(i,n+160|0,o,p);lK(i,n+80|0,o,p);lK(i,n+240|0,o,p)}else{if(!k){break}lK(i,n|0,c[h+(a*20424|0)+1628>>2]|0,d[h+(a*20424|0)+1638|0]|0);lK(i,n+160|0,c[h+(a*20424|0)+1632>>2]|0,d[h+(a*20424|0)+1639|0]|0);lK(i,n+80|0,c[h+(a*20424|0)+1624>>2]|0,d[h+(a*20424|0)+1637|0]|0);lK(i,n+240|0,c[n+364>>2]|0,d[n+368|0]|0)}}while(0);k=c[2383560]|0;if((c[k+36>>2]|0)==-1){p=c[k+364>>2]|0;o=d[k+368|0]|0;lK(i,k|0,p,o);lK(i,k+160|0,p,o);lK(i,k+80|0,p,o);lK(i,k+240|0,p,o)}o=c[2383558]|0;if((c[o+36>>2]|0)==-1){p=c[o+364>>2]|0;q=d[o+368|0]|0;lK(i,o|0,p,q);lK(i,o+160|0,p,q);lK(i,o+80|0,p,q);lK(i,o+240|0,p,q)}q=c[2383556]|0;if((c[q+36>>2]|0)==-1){p=c[q+364>>2]|0;r=d[q+368|0]|0;lK(i,q|0,p,r);lK(i,q+160|0,p,r);lK(i,q+80|0,p,r);lK(i,q+240|0,p,r)}if((g|0)<=0){return}r=h+(a*20424|0)+18112|0;p=h+(a*20424|0)+1712|0;s=h+(a*20424|0)+1708|0;t=h+(a*20424|0)+1716|0;u=h+(a*20424|0)+1656|0;v=h+(a*20424|0)+1660|0;w=h+(a*20424|0)+1664|0;x=h+(a*20424|0)+1668|0;y=h+(a*20424|0)+1672|0;z=h+(a*20424|0)+1676|0;A=h+(a*20424|0)+1680|0;B=h+(a*20424|0)+1684|0;C=h+(a*20424|0)+1688|0;D=h+(a*20424|0)+1692|0;E=h+(a*20424|0)+1696|0;F=h+(a*20424|0)+1700|0;G=h+(a*20424|0)+1704|0;H=h+(a*20424|0)+18108|0;a=(c[2383452]|0)==0;h=l|0;I=m|0;J=n|0;K=k|0;L=o|0;M=q|0;N=q+344|0;O=0;do{P=c[r>>2]|0;if((P|0)==0){c[3541216]=0;Q=0}else{R=(c[H>>2]|0)+P|0;c[H>>2]=R;P=R>>>24;R=P&127;S=P<<1&126;c[3541216]=R>>>0<64?S:126-S|0;Q=R>>>2}c[3541212]=Q;gGz(8451944,0,24);lM(i,l,0);lM(i,m,1);lM(i,n,2);lM(i,k,3);lM(i,o,4);if(a){lM(i,q,5)}else{R=c[N>>2]|0;c[R>>2]=(c[R>>2]|0)+j}R=(c[s>>2]|0)+(c[p>>2]|0)|0;c[s>>2]=R;S=c[t>>2]|0;if(R>>>0>=S>>>0){P=R;R=S;do{c[s>>2]=P-R;c[G>>2]=(c[G>>2]|0)+1;lL(i,h);lL(i,I);lL(i,J);lL(i,K);lL(i,L);lL(i,M);P=c[s>>2]|0;R=c[t>>2]|0;}while(P>>>0>=R>>>0)}R=c[2112986]|0;P=c[2112987]|0;S=c[2112988]|0;T=c[2112989]|0;U=c[2112990]|0;V=c[2112991]|0;W=(c[w>>2]&P)+(c[u>>2]&R)+(c[y>>2]&S)+(c[A>>2]&T)+(c[C>>2]&U)+(c[E>>2]&V)|0;X=(c[x>>2]&P)+(c[v>>2]&R)+(c[z>>2]&S)+(c[B>>2]&T)+(c[D>>2]&U)+(c[F>>2]&V)|0;if((W|0)>32767){Y=32767}else{Y=(W|0)<-32768?-32768:W&65535}if((X|0)>32767){Z=32767}else{Z=(X|0)<-32768?-32768:X&65535}b[e+(O<<1)>>1]=Y;b[f+(O<<1)>>1]=Z;O=O+1|0;}while((O|0)<(g|0));return}function mb(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=i;if((c[3541512]|0)!=0){i=g;return}c[2383472]=0;c[3531840]=b;h=b*20424|0;b=gGq(h)|0;c[3541512]=b;if((b|0)==0){i=g;return}gGz(b|0,0,h|0);lR();do{if((c[3531840]|0)>0){h=0;do{b=c[3541512]|0;a[b+(h*20424|0)+520|0]=h&255;a[b+(h*20424|0)+512|0]=14;c[b+(h*20424|0)+1652>>2]=b+(h*20424|0)+18152;c[b+(h*20424|0)+524>>2]=d;c[b+(h*20424|0)+528>>2]=e;c[b+(h*20424|0)+1612>>2]=2;c[b+(h*20424|0)+1616>>2]=f;mc(h);h=h+1|0;j=c[3531840]|0;}while((h|0)<(j|0));if((j|0)>0){k=0}else{l=0;break}while(1){h=(c[3541512]|0)+(k*20424|0)|0;b=gGq(272)|0;m=b;if((b|0)!=0){gGz(b|0,0,272);n=c[2430396]|0;c[b>>2]=n;if((n|0)!=0){c[n+4>>2]=m}c[2430396]=m;m=b+8|0;cC(m|0,231e3,(o=i,i=i+24|0,c[o>>2]=7452600,c[o+8>>2]=198680,c[o+16>>2]=k,o)|0)|0;i=o;c[b+264>>2]=h;c[b+268>>2]=512}mf(7452600,k,(c[3541512]|0)+(k*20424|0)+520|0);mg(7452600,k,(c[3541512]|0)+(k*20424|0)+18152|0,6);b=(c[3541512]|0)+(k*20424|0)+1624|0;h=gGq(272)|0;m=h;if((h|0)!=0){gGz(h|0,0,272);n=c[2430396]|0;c[h>>2]=n;if((n|0)!=0){c[n+4>>2]=m}c[2430396]=m;m=h+8|0;cC(m|0,231e3,(o=i,i=i+24|0,c[o>>2]=7452600,c[o+8>>2]=157144,c[o+16>>2]=k,o)|0)|0;i=o;c[h+264>>2]=b;c[h+268>>2]=12}h=(c[3541512]|0)+(k*20424|0)+1636|0;b=gGq(272)|0;m=b;if((b|0)!=0){gGz(b|0,0,272);n=c[2430396]|0;c[b>>2]=n;if((n|0)!=0){c[n+4>>2]=m}c[2430396]=m;m=b+8|0;cC(m|0,231e3,(o=i,i=i+24|0,c[o>>2]=7452600,c[o+8>>2]=126616,c[o+16>>2]=k,o)|0)|0;i=o;c[b+264>>2]=h;c[b+268>>2]=1}b=(c[3541512]|0)+(k*20424|0)+1637|0;h=gGq(272)|0;m=h;if((h|0)!=0){gGz(h|0,0,272);n=c[2430396]|0;c[h>>2]=n;if((n|0)!=0){c[n+4>>2]=m}c[2430396]=m;m=h+8|0;cC(m|0,231e3,(o=i,i=i+24|0,c[o>>2]=7452600,c[o+8>>2]=101520,c[o+16>>2]=k,o)|0)|0;i=o;c[h+264>>2]=b;c[h+268>>2]=3}h=(c[3541512]|0)+(k*20424|0)+20408|0;b=gGq(272)|0;m=b;if((b|0)!=0){gGz(b|0,0,272);n=c[2430396]|0;c[b>>2]=n;if((n|0)!=0){c[n+4>>2]=m}c[2430396]=m;m=b+8|0;cC(m|0,231e3,(o=i,i=i+24|0,c[o>>2]=7452600,c[o+8>>2]=78264,c[o+16>>2]=k,o)|0)|0;i=o;c[b+264>>2]=h;c[b+268>>2]=1}b=k+1|0;if((b|0)<(c[3531840]|0)){k=b}else{l=0;break}}}else{l=0}}while(0);while(1){if((l|0)>=8){p=12065;break}q=9774632+(l<<2)|0;if((c[q>>2]|0)==0){break}else{l=l+1|0}}if((p|0)==12065){i=g;return}c[q>>2]=6194;i=g;return}function mc(b){b=b|0;var e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;e=c[3541512]|0;f=e+(b*20424|0)+512|0;lI(f,144,144,0);g=e+(b*20424|0)+520|0;i=e+(b*20424|0)+562|0;a[i]=3;j=e+(b*20424|0)+563|0;k=e+(b*20424|0)+561|0;do{if((a[k]|0)==0){if((a[j]&3)==0){break}a[k]=1;l=c[e+(b*20424|0)+1616>>2]|0;if((l|0)==0){m=3;n=12074;break}gg[l&4095](d[g|0]|0,1);if((a[k]|0)==0){break}m=a[i]|0;n=12074}else{m=3;n=12074}}while(0);do{if((n|0)==12074){if((a[j]&m)<<24>>24!=0){break}a[k]=0;i=c[e+(b*20424|0)+1616>>2]|0;if((i|0)==0){break}gg[i&4095](d[g|0]|0,0)}}while(0);h[e+(b*20424|0)+552>>3]=0.0;lO(f,39,48);c[e+(b*20424|0)+1708>>2]=0;c[e+(b*20424|0)+1704>>2]=0;a[j]=0;do{if((a[k]|0)!=0){a[k]=0;j=c[e+(b*20424|0)+1616>>2]|0;if((j|0)==0){break}gg[j&4095](d[g|0]|0,0)}}while(0);c[e+(b*20424|0)+564>>2]=0;c[e+(b*20424|0)+572>>2]=0;c[e+(b*20424|0)+576>>2]=0;a[e+(b*20424|0)+580|0]=0;c[e+(b*20424|0)+584>>2]=0;g=0;do{c[e+(b*20424|0)+18152+(g*376|0)+364>>2]=0;a[e+(b*20424|0)+18152+(g*376|0)+68|0]=0;a[e+(b*20424|0)+18152+(g*376|0)+69|0]=0;a[e+(b*20424|0)+18152+(g*376|0)+40|0]=0;c[e+(b*20424|0)+18152+(g*376|0)+48>>2]=1023;c[e+(b*20424|0)+18152+(g*376|0)+56>>2]=1023;a[e+(b*20424|0)+18152+(g*376|0)+148|0]=0;a[e+(b*20424|0)+18152+(g*376|0)+149|0]=0;a[e+(b*20424|0)+18152+(g*376|0)+120|0]=0;c[e+(b*20424|0)+18152+(g*376|0)+128>>2]=1023;c[e+(b*20424|0)+18152+(g*376|0)+136>>2]=1023;a[e+(b*20424|0)+18152+(g*376|0)+228|0]=0;a[e+(b*20424|0)+18152+(g*376|0)+229|0]=0;a[e+(b*20424|0)+18152+(g*376|0)+200|0]=0;c[e+(b*20424|0)+18152+(g*376|0)+208>>2]=1023;c[e+(b*20424|0)+18152+(g*376|0)+216>>2]=1023;a[e+(b*20424|0)+18152+(g*376|0)+308|0]=0;a[e+(b*20424|0)+18152+(g*376|0)+309|0]=0;a[e+(b*20424|0)+18152+(g*376|0)+280|0]=0;c[e+(b*20424|0)+18152+(g*376|0)+288>>2]=1023;c[e+(b*20424|0)+18152+(g*376|0)+296>>2]=1023;g=g+1|0;}while((g|0)<6);g=e+(b*20424|0)+1652|0;k=c[g>>2]|0;j=f|0;m=a[j]|0;if((m&2)==0){o=k;p=m}else{c[k+1108>>2]=0;a[k+1112|0]=8;c[e+(b*20424|0)+1672>>2]=-1;c[e+(b*20424|0)+1676>>2]=-1;o=c[g>>2]|0;p=a[j]|0}if((p&2)==0){q=o;r=p}else{c[o+2236>>2]=0;a[o+2240|0]=8;c[e+(b*20424|0)+1696>>2]=-1;c[e+(b*20424|0)+1700>>2]=-1;q=c[g>>2]|0;r=a[j]|0}if((r&2)==0){s=q;t=r}else{c[q+732>>2]=0;a[q+736|0]=8;c[e+(b*20424|0)+1664>>2]=-1;c[e+(b*20424|0)+1668>>2]=-1;s=c[g>>2]|0;t=a[j]|0}if((t&2)==0){u=s;v=t}else{c[s+1860>>2]=0;a[s+1864|0]=8;c[e+(b*20424|0)+1688>>2]=-1;c[e+(b*20424|0)+1692>>2]=-1;u=c[g>>2]|0;v=a[j]|0}if((v&2)==0){w=u;x=v}else{c[u+356>>2]=0;a[u+360|0]=8;c[e+(b*20424|0)+1656>>2]=-1;c[e+(b*20424|0)+1660>>2]=-1;w=c[g>>2]|0;x=a[j]|0}if((x&2)==0){y=178}else{c[w+1484>>2]=0;a[w+1488|0]=8;c[e+(b*20424|0)+1680>>2]=-1;c[e+(b*20424|0)+1684>>2]=-1;y=178}do{lP(f,y,0);lP(f,y|256,0);y=y-1|0;}while((y|0)>47);c[e+(b*20424|0)+20412>>2]=0;return}function md(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=c[3541512]|0;h=e&3;if((h|0)==1){if((a[g+(b*20424|0)+20408|0]|0)!=0){return}e=g+(b*20424|0)+512|0;i=d[g+(b*20424|0)+560|0]|0;a[g+(b*20424|0)+i|0]=f;if((i&240|0)!=32){j=gj[c[2427014]&4095](c[2429372]|0)|0;k=c[2433538]|0;if((k|0)<(j|0)){l=j-k|0;j=c[2406692]|0;m=j+(k+4<<1)|0;c[2438942]=m;n=j+(k+4100<<1)|0;c[2438943]=n;ma(0,m,n,l);if((c[2385512]|0)>1){n=c[2433538]|0;m=j+(n+8196<<1)|0;c[2438944]=m;k=j+(n+12292<<1)|0;c[2438945]=k;ma(1,m,k,l)}c[2433538]=(c[2433538]|0)+l}lP(e,i,f&255);return}if((i|0)==43){c[g+(b*20424|0)+20412>>2]=f&128;c[2383472]=0;return}else if((i|0)==42){l=gj[c[2427014]&4095](c[2429372]|0)|0;k=c[2433538]|0;if((k|0)<(l|0)){m=l-k|0;l=c[2406692]|0;n=l+(k+4<<1)|0;c[2438942]=n;j=l+(k+4100<<1)|0;c[2438943]=j;ma(0,n,j,m);if((c[2385512]|0)>1){j=c[2433538]|0;n=l+(j+8196<<1)|0;c[2438944]=n;k=l+(j+12292<<1)|0;c[2438945]=k;ma(1,n,k,m)}c[2433538]=(c[2433538]|0)+m}c[g+(b*20424|0)+20416>>2]=((f&255)<<6)-8192;return}else{m=gj[c[2427014]&4095](c[2429372]|0)|0;k=c[2433538]|0;if((k|0)<(m|0)){n=m-k|0;m=c[2406692]|0;j=m+(k+4<<1)|0;c[2438942]=j;l=m+(k+4100<<1)|0;c[2438943]=l;ma(0,j,l,n);if((c[2385512]|0)>1){l=c[2433538]|0;j=m+(l+8196<<1)|0;c[2438944]=j;k=m+(l+12292<<1)|0;c[2438945]=k;ma(1,j,k,n)}c[2433538]=(c[2433538]|0)+n}lO(e,i,f&255);return}}else if((h|0)==0){a[g+(b*20424|0)+560|0]=f;a[g+(b*20424|0)+20408|0]=0;return}else if((h|0)==2){a[g+(b*20424|0)+560|0]=f;a[g+(b*20424|0)+20408|0]=1;return}else if((h|0)==3){if((a[g+(b*20424|0)+20408|0]|0)!=1){return}h=g+(b*20424|0)+512|0;i=d[g+(b*20424|0)+560|0]|256;a[g+(b*20424|0)+i|0]=f;b=gj[c[2427014]&4095](c[2429372]|0)|0;g=c[2433538]|0;if((g|0)<(b|0)){e=b-g|0;b=c[2406692]|0;n=b+(g+4<<1)|0;c[2438942]=n;k=b+(g+4100<<1)|0;c[2438943]=k;ma(0,n,k,e);if((c[2385512]|0)>1){k=c[2433538]|0;n=b+(k+8196<<1)|0;c[2438944]=n;g=b+(k+12292<<1)|0;c[2438945]=g;ma(1,n,g,e)}c[2433538]=(c[2433538]|0)+e}lP(h,i,f&255);return}else{return}}function me(b,e){b=b|0;e=e|0;var f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0;f=c[3541512]|0;if((e|0)!=0){e=f+(b*20424|0)+520|0;do{if((c[f+(b*20424|0)+564>>2]&8|0)!=0){g=f+(b*20424|0)+563|0;i=d[g]|2;a[g]=i&255;g=f+(b*20424|0)+561|0;if((a[g]|0)!=0){break}if((d[f+(b*20424|0)+562|0]&i|0)==0){break}a[g]=1;g=c[f+(b*20424|0)+1616>>2]|0;if((g|0)==0){break}gg[g&4095](d[e|0]|0,1)}}while(0);g=256-(d[f+(b*20424|0)+580|0]|0)<<4;c[f+(b*20424|0)+584>>2]=g;i=c[f+(b*20424|0)+1612>>2]|0;if((i|0)==0){j=f+(b*20424|0)+561|0;k=a[j]|0;l=k&255;return l|0}gn[i&3](d[e|0]|0,1,g,+h[f+(b*20424|0)+544>>3]);j=f+(b*20424|0)+561|0;k=a[j]|0;l=k&255;return l|0}g=gj[c[2427014]&4095](c[2429372]|0)|0;e=c[2433538]|0;if((e|0)<(g|0)){i=g-e|0;g=c[2406692]|0;m=g+(e+4<<1)|0;c[2438942]=m;n=g+(e+4100<<1)|0;c[2438943]=n;ma(0,m,n,i);if((c[2385512]|0)>1){n=c[2433538]|0;m=g+(n+8196<<1)|0;c[2438944]=m;e=g+(n+12292<<1)|0;c[2438945]=e;ma(1,m,e,i)}c[2433538]=(c[2433538]|0)+i}i=f+(b*20424|0)+520|0;e=f+(b*20424|0)+564|0;do{if((c[e>>2]&4|0)!=0){m=f+(b*20424|0)+563|0;n=d[m]|1;a[m]=n&255;m=f+(b*20424|0)+561|0;if((a[m]|0)!=0){break}if((d[f+(b*20424|0)+562|0]&n|0)==0){break}a[m]=1;m=c[f+(b*20424|0)+1616>>2]|0;if((m|0)==0){break}gg[m&4095](d[i|0]|0,1)}}while(0);m=1024-(c[f+(b*20424|0)+572>>2]|0)|0;c[f+(b*20424|0)+576>>2]=m;n=c[f+(b*20424|0)+1612>>2]|0;if((n|0)!=0){gn[n&3](d[i|0]|0,0,m,+h[f+(b*20424|0)+544>>3])}if((c[e>>2]&128|0)==0){j=f+(b*20424|0)+561|0;k=a[j]|0;l=k&255;return l|0}lU(a[f+(b*20424|0)+512|0]|0,f+(b*20424|0)+18904|0);j=f+(b*20424|0)+561|0;k=a[j]|0;l=k&255;return l|0}function mf(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0;e=i;f=d+32|0;g=gGq(272)|0;h=g;if((g|0)!=0){gGz(g|0,0,272);j=c[2430396]|0;c[g>>2]=j;if((j|0)!=0){c[j+4>>2]=h}c[2430396]=h;h=g+8|0;cC(h|0,231e3,(k=i,i=i+24|0,c[k>>2]=a,c[k+8>>2]=485224,c[k+16>>2]=b,k)|0)|0;i=k;c[g+264>>2]=f;c[g+268>>2]=8}g=d+40|0;f=gGq(272)|0;h=f;if((f|0)!=0){gGz(f|0,0,272);j=c[2430396]|0;c[f>>2]=j;if((j|0)!=0){c[j+4>>2]=h}c[2430396]=h;h=f+8|0;cC(h|0,231e3,(k=i,i=i+24|0,c[k>>2]=a,c[k+8>>2]=472128,c[k+16>>2]=b,k)|0)|0;i=k;c[f+264>>2]=g;c[f+268>>2]=1}f=d+41|0;g=gGq(272)|0;h=g;if((g|0)!=0){gGz(g|0,0,272);j=c[2430396]|0;c[g>>2]=j;if((j|0)!=0){c[j+4>>2]=h}c[2430396]=h;h=g+8|0;cC(h|0,231e3,(k=i,i=i+24|0,c[k>>2]=a,c[k+8>>2]=461016,c[k+16>>2]=b,k)|0)|0;i=k;c[g+264>>2]=f;c[g+268>>2]=1}g=d+42|0;f=gGq(272)|0;h=f;if((f|0)!=0){gGz(f|0,0,272);j=c[2430396]|0;c[f>>2]=j;if((j|0)!=0){c[j+4>>2]=h}c[2430396]=h;h=f+8|0;cC(h|0,231e3,(k=i,i=i+24|0,c[k>>2]=a,c[k+8>>2]=450024,c[k+16>>2]=b,k)|0)|0;i=k;c[f+264>>2]=g;c[f+268>>2]=1}f=d+43|0;g=gGq(272)|0;h=g;if((g|0)!=0){gGz(g|0,0,272);j=c[2430396]|0;c[g>>2]=j;if((j|0)!=0){c[j+4>>2]=h}c[2430396]=h;h=g+8|0;cC(h|0,231e3,(k=i,i=i+24|0,c[k>>2]=a,c[k+8>>2]=438344,c[k+16>>2]=b,k)|0)|0;i=k;c[g+264>>2]=f;c[g+268>>2]=1}g=d+44|0;f=gGq(272)|0;h=f;if((f|0)!=0){gGz(f|0,0,272);j=c[2430396]|0;c[f>>2]=j;if((j|0)!=0){c[j+4>>2]=h}c[2430396]=h;h=f+8|0;cC(h|0,231e3,(k=i,i=i+24|0,c[k>>2]=a,c[k+8>>2]=427400,c[k+16>>2]=b,k)|0)|0;i=k;c[f+264>>2]=g;c[f+268>>2]=4}f=d+48|0;g=gGq(272)|0;h=g;if((g|0)!=0){gGz(g|0,0,272);j=c[2430396]|0;c[g>>2]=j;if((j|0)!=0){c[j+4>>2]=h}c[2430396]=h;h=g+8|0;cC(h|0,231e3,(k=i,i=i+24|0,c[k>>2]=a,c[k+8>>2]=415368,c[k+16>>2]=b,k)|0)|0;i=k;c[g+264>>2]=f;c[g+268>>2]=1}g=d+49|0;f=gGq(272)|0;h=f;if((f|0)!=0){gGz(f|0,0,272);j=c[2430396]|0;c[f>>2]=j;if((j|0)!=0){c[j+4>>2]=h}c[2430396]=h;h=f+8|0;cC(h|0,231e3,(k=i,i=i+24|0,c[k>>2]=a,c[k+8>>2]=403696,c[k+16>>2]=b,k)|0)|0;i=k;c[f+264>>2]=g;c[f+268>>2]=1}f=d+52|0;g=gGq(272)|0;h=g;if((g|0)!=0){gGz(g|0,0,272);j=c[2430396]|0;c[g>>2]=j;if((j|0)!=0){c[j+4>>2]=h}c[2430396]=h;h=g+8|0;cC(h|0,231e3,(k=i,i=i+24|0,c[k>>2]=a,c[k+8>>2]=392408,c[k+16>>2]=b,k)|0)|0;i=k;c[g+264>>2]=f;c[g+268>>2]=4}g=d+56|0;f=gGq(272)|0;h=f;if((f|0)!=0){gGz(f|0,0,272);j=c[2430396]|0;c[f>>2]=j;if((j|0)!=0){c[j+4>>2]=h}c[2430396]=h;h=f+8|0;cC(h|0,231e3,(k=i,i=i+24|0,c[k>>2]=a,c[k+8>>2]=380904,c[k+16>>2]=b,k)|0)|0;i=k;c[f+264>>2]=g;c[f+268>>2]=4}f=d+60|0;g=gGq(272)|0;h=g;if((g|0)!=0){gGz(g|0,0,272);j=c[2430396]|0;c[g>>2]=j;if((j|0)!=0){c[j+4>>2]=h}c[2430396]=h;h=g+8|0;cC(h|0,231e3,(k=i,i=i+24|0,c[k>>2]=a,c[k+8>>2]=370640,c[k+16>>2]=b,k)|0)|0;i=k;c[g+264>>2]=f;c[g+268>>2]=1}g=gGq(272)|0;f=g;if((g|0)==0){i=e;return}gGz(g|0,0,272);h=c[2430396]|0;c[g>>2]=h;if((h|0)!=0){c[h+4>>2]=f}c[2430396]=f;cC(g+8|0,231e3,(k=i,i=i+24|0,c[k>>2]=a,c[k+8>>2]=361512,c[k+16>>2]=b,k)|0)|0;i=k;c[g+264>>2]=d+64;c[g+268>>2]=4;i=e;return}function mg(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;i=i+24|0;if((e|0)<=0){i=f;return}g=f|0;h=0;j=d;while(1){cC(g|0,584960,(d=i,i=i+16|0,c[d>>2]=a,c[d+8>>2]=h,d)|0)|0;i=d;k=j+324|0;l=gGq(272)|0;m=l;if((l|0)!=0){gGz(l|0,0,272);n=c[2430396]|0;c[l>>2]=n;if((n|0)!=0){c[n+4>>2]=m}c[2430396]=m;m=l+8|0;cC(m|0,231e3,(d=i,i=i+24|0,c[d>>2]=g,c[d+8>>2]=568360,c[d+16>>2]=b,d)|0)|0;i=d;c[l+264>>2]=k;c[l+268>>2]=8}l=j+364|0;k=gGq(272)|0;m=k;if((k|0)!=0){gGz(k|0,0,272);n=c[2430396]|0;c[k>>2]=n;if((n|0)!=0){c[n+4>>2]=m}c[2430396]=m;m=k+8|0;cC(m|0,231e3,(d=i,i=i+24|0,c[d>>2]=g,c[d+8>>2]=551984,c[d+16>>2]=b,d)|0)|0;i=d;c[k+264>>2]=l;c[k+268>>2]=4}cC(g|0,537304,(d=i,i=i+24|0,c[d>>2]=a,c[d+8>>2]=h,c[d+16>>2]=1,d)|0)|0;i=d;k=j+32|0;l=gGq(272)|0;m=l;if((l|0)!=0){gGz(l|0,0,272);n=c[2430396]|0;c[l>>2]=n;if((n|0)!=0){c[n+4>>2]=m}c[2430396]=m;m=l+8|0;cC(m|0,231e3,(d=i,i=i+24|0,c[d>>2]=g,c[d+8>>2]=523816,c[d+16>>2]=b,d)|0)|0;i=d;c[l+264>>2]=k;c[l+268>>2]=4}l=j+40|0;k=gGq(272)|0;m=k;if((k|0)!=0){gGz(k|0,0,272);n=c[2430396]|0;c[k>>2]=n;if((n|0)!=0){c[n+4>>2]=m}c[2430396]=m;m=k+8|0;cC(m|0,231e3,(d=i,i=i+24|0,c[d>>2]=g,c[d+8>>2]=182496,c[d+16>>2]=b,d)|0)|0;i=d;c[k+264>>2]=l;c[k+268>>2]=1}k=j+48|0;l=gGq(272)|0;m=l;if((l|0)!=0){gGz(l|0,0,272);n=c[2430396]|0;c[l>>2]=n;if((n|0)!=0){c[n+4>>2]=m}c[2430396]=m;m=l+8|0;cC(m|0,231e3,(d=i,i=i+24|0,c[d>>2]=g,c[d+8>>2]=497216,c[d+16>>2]=b,d)|0)|0;i=d;c[l+264>>2]=k;c[l+268>>2]=4}cC(g|0,537304,(d=i,i=i+24|0,c[d>>2]=a,c[d+8>>2]=h,c[d+16>>2]=3,d)|0)|0;i=d;l=j+112|0;k=gGq(272)|0;m=k;if((k|0)!=0){gGz(k|0,0,272);n=c[2430396]|0;c[k>>2]=n;if((n|0)!=0){c[n+4>>2]=m}c[2430396]=m;m=k+8|0;cC(m|0,231e3,(d=i,i=i+24|0,c[d>>2]=g,c[d+8>>2]=523816,c[d+16>>2]=b,d)|0)|0;i=d;c[k+264>>2]=l;c[k+268>>2]=4}k=j+120|0;l=gGq(272)|0;m=l;if((l|0)!=0){gGz(l|0,0,272);n=c[2430396]|0;c[l>>2]=n;if((n|0)!=0){c[n+4>>2]=m}c[2430396]=m;m=l+8|0;cC(m|0,231e3,(d=i,i=i+24|0,c[d>>2]=g,c[d+8>>2]=182496,c[d+16>>2]=b,d)|0)|0;i=d;c[l+264>>2]=k;c[l+268>>2]=1}l=j+128|0;k=gGq(272)|0;m=k;if((k|0)!=0){gGz(k|0,0,272);n=c[2430396]|0;c[k>>2]=n;if((n|0)!=0){c[n+4>>2]=m}c[2430396]=m;m=k+8|0;cC(m|0,231e3,(d=i,i=i+24|0,c[d>>2]=g,c[d+8>>2]=497216,c[d+16>>2]=b,d)|0)|0;i=d;c[k+264>>2]=l;c[k+268>>2]=4}cC(g|0,537304,(d=i,i=i+24|0,c[d>>2]=a,c[d+8>>2]=h,c[d+16>>2]=2,d)|0)|0;i=d;k=j+192|0;l=gGq(272)|0;m=l;if((l|0)!=0){gGz(l|0,0,272);n=c[2430396]|0;c[l>>2]=n;if((n|0)!=0){c[n+4>>2]=m}c[2430396]=m;m=l+8|0;cC(m|0,231e3,(d=i,i=i+24|0,c[d>>2]=g,c[d+8>>2]=523816,c[d+16>>2]=b,d)|0)|0;i=d;c[l+264>>2]=k;c[l+268>>2]=4}l=j+200|0;k=gGq(272)|0;m=k;if((k|0)!=0){gGz(k|0,0,272);n=c[2430396]|0;c[k>>2]=n;if((n|0)!=0){c[n+4>>2]=m}c[2430396]=m;m=k+8|0;cC(m|0,231e3,(d=i,i=i+24|0,c[d>>2]=g,c[d+8>>2]=182496,c[d+16>>2]=b,d)|0)|0;i=d;c[k+264>>2]=l;c[k+268>>2]=1}k=j+208|0;l=gGq(272)|0;m=l;if((l|0)!=0){gGz(l|0,0,272);n=c[2430396]|0;c[l>>2]=n;if((n|0)!=0){c[n+4>>2]=m}c[2430396]=m;m=l+8|0;cC(m|0,231e3,(d=i,i=i+24|0,c[d>>2]=g,c[d+8>>2]=497216,c[d+16>>2]=b,d)|0)|0;i=d;c[l+264>>2]=k;c[l+268>>2]=4}cC(g|0,537304,(d=i,i=i+24|0,c[d>>2]=a,c[d+8>>2]=h,c[d+16>>2]=4,d)|0)|0;i=d;l=j+272|0;k=gGq(272)|0;m=k;if((k|0)!=0){gGz(k|0,0,272);n=c[2430396]|0;c[k>>2]=n;if((n|0)!=0){c[n+4>>2]=m}c[2430396]=m;m=k+8|0;cC(m|0,231e3,(d=i,i=i+24|0,c[d>>2]=g,c[d+8>>2]=523816,c[d+16>>2]=b,d)|0)|0;i=d;c[k+264>>2]=l;c[k+268>>2]=4}k=j+280|0;l=gGq(272)|0;m=l;if((l|0)!=0){gGz(l|0,0,272);n=c[2430396]|0;c[l>>2]=n;if((n|0)!=0){c[n+4>>2]=m}c[2430396]=m;m=l+8|0;cC(m|0,231e3,(d=i,i=i+24|0,c[d>>2]=g,c[d+8>>2]=182496,c[d+16>>2]=b,d)|0)|0;i=d;c[l+264>>2]=k;c[l+268>>2]=1}l=j+288|0;k=gGq(272)|0;m=k;if((k|0)!=0){gGz(k|0,0,272);n=c[2430396]|0;c[k>>2]=n;if((n|0)!=0){c[n+4>>2]=m}c[2430396]=m;m=k+8|0;cC(m|0,231e3,(d=i,i=i+24|0,c[d>>2]=g,c[d+8>>2]=497216,c[d+16>>2]=b,d)|0)|0;i=d;c[k+264>>2]=l;c[k+268>>2]=4}k=h+1|0;if((k|0)<(e|0)){h=k;j=j+376|0}else{break}}i=f;return}function mh(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[3531840]|0;if((b|0)<=0){c[2383472]=0;return}e=c[3541512]|0;f=0;do{c[e+(f*20424|0)+20416>>2]=((d[e+(f*20424|0)+42|0]|0)<<6)-8192;c[e+(f*20424|0)+20412>>2]=a[e+(f*20424|0)+45|0]&128;g=e+(f*20424|0)+512|0;h=48;while(1){if((h&3|0)!=3){lP(g,h,d[e+(f*20424|0)+h|0]|0);i=h|256;lP(g,i,d[e+(f*20424|0)+i|0]|0)}i=h+1|0;if((i|0)<158){h=i}else{j=176;break}}do{if((j&3|0)!=3){lP(g,j,d[e+(f*20424|0)+j|0]|0);h=j|256;lP(g,h,d[e+(f*20424|0)+h|0]|0)}j=j+1|0;}while((j|0)<182);f=f+1|0;}while((f|0)<(b|0));c[2383472]=0;return}function mi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;i=i+24|0;f=e|0;g=d;d=0;while(1){cC(f|0,584960,(h=i,i=i+16|0,c[h>>2]=a,c[h+8>>2]=d,h)|0)|0;i=h;j=g|0;k=gGq(272)|0;l=k;if((k|0)!=0){gGz(k|0,0,272);m=c[2430396]|0;c[k>>2]=m;if((m|0)!=0){c[m+4>>2]=l}c[2430396]=l;l=k+8|0;cC(l|0,231e3,(h=i,i=i+24|0,c[h>>2]=f,c[h+8>>2]=346400,c[h+16>>2]=b,h)|0)|0;i=h;c[k+264>>2]=j;c[k+268>>2]=1}k=g+2|0;j=gGq(272)|0;l=j;if((j|0)!=0){gGz(j|0,0,272);m=c[2430396]|0;c[j>>2]=m;if((m|0)!=0){c[m+4>>2]=l}c[2430396]=l;l=j+8|0;cC(l|0,231e3,(h=i,i=i+24|0,c[h>>2]=f,c[h+8>>2]=338208,c[h+16>>2]=b,h)|0)|0;i=h;c[j+264>>2]=k;c[j+268>>2]=1}j=g+4|0;k=gGq(272)|0;l=k;if((k|0)!=0){gGz(k|0,0,272);m=c[2430396]|0;c[k>>2]=m;if((m|0)!=0){c[m+4>>2]=l}c[2430396]=l;l=k+8|0;cC(l|0,231e3,(h=i,i=i+24|0,c[h>>2]=f,c[h+8>>2]=330352,c[h+16>>2]=b,h)|0)|0;i=h;c[k+264>>2]=j;c[k+268>>2]=4}k=g+8|0;j=gGq(272)|0;l=j;if((j|0)!=0){gGz(j|0,0,272);m=c[2430396]|0;c[j>>2]=m;if((m|0)!=0){c[m+4>>2]=l}c[2430396]=l;l=j+8|0;cC(l|0,231e3,(h=i,i=i+24|0,c[h>>2]=f,c[h+8>>2]=321272,c[h+16>>2]=b,h)|0)|0;i=h;c[j+264>>2]=k;c[j+268>>2]=4}j=g+28|0;k=gGq(272)|0;l=k;if((k|0)!=0){gGz(k|0,0,272);m=c[2430396]|0;c[k>>2]=m;if((m|0)!=0){c[m+4>>2]=l}c[2430396]=l;l=k+8|0;cC(l|0,231e3,(h=i,i=i+24|0,c[h>>2]=f,c[h+8>>2]=311856,c[h+16>>2]=b,h)|0)|0;i=h;c[k+264>>2]=j;c[k+268>>2]=4}k=g+32|0;j=gGq(272)|0;l=j;if((j|0)!=0){gGz(j|0,0,272);m=c[2430396]|0;c[j>>2]=m;if((m|0)!=0){c[m+4>>2]=l}c[2430396]=l;l=j+8|0;cC(l|0,231e3,(h=i,i=i+24|0,c[h>>2]=f,c[h+8>>2]=303520,c[h+16>>2]=b,h)|0)|0;i=h;c[j+264>>2]=k;c[j+268>>2]=4}j=g+36|0;k=gGq(272)|0;l=k;if((k|0)!=0){gGz(k|0,0,272);m=c[2430396]|0;c[k>>2]=m;if((m|0)!=0){c[m+4>>2]=l}c[2430396]=l;l=k+8|0;cC(l|0,231e3,(h=i,i=i+24|0,c[h>>2]=f,c[h+8>>2]=295544,c[h+16>>2]=b,h)|0)|0;i=h;c[k+264>>2]=j;c[k+268>>2]=4}k=d+1|0;if((k|0)<6){g=g+48|0;d=k}else{break}}i=e;return}function mj(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;if(a[7452616]|0){b=0}else{c[2383472]=0;return}do{e=c[3541514]|0;f=0;do{g=(c[2383582]|0)+b|0;c[14168912+(g*252|0)>>2]=f;h=a[e+(b*21040|0)+f|0]|0;i=h&255;if((f|0)<=15){do{if((f|0)<14){if((f|0)!=13){if((a[14168916+(g*252|0)+f|0]|0)==h<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(g,f,i)}f=f+1|0;}while((f|0)<16);f=e+(b*21040|0)+512|0;h=48;do{if((h&3|0)!=3){lP(f,h,d[e+(b*21040|0)+h|0]|0);j=h|256;lP(f,j,d[e+(b*21040|0)+j|0]|0)}h=h+1|0;}while((h|0)<158);lP(f,176,d[e+(b*21040|0)+176|0]|0);lP(f,432,d[e+(b*21040|0)+432|0]|0);lP(f,177,d[e+(b*21040|0)+177|0]|0);lP(f,433,d[e+(b*21040|0)+433|0]|0);lP(f,178,d[e+(b*21040|0)+178|0]|0);lP(f,434,d[e+(b*21040|0)+434|0]|0);h=d[e+(b*21040|0)+180|0]|0;j=e+(b*21040|0)+1652|0;k=c[j>>2]|0;l=f|0;m=a[l]|0;if((m&2)==0){n=k;o=m}else{c[k+356>>2]=h<<5&224;a[k+360|0]=a[44304+(h>>>4&3)|0]|0;c[e+(b*21040|0)+1656>>2]=h<<24>>31;c[e+(b*21040|0)+1660>>2]=h<<25>>31;n=c[j>>2]|0;o=a[l]|0}h=d[e+(b*21040|0)+436|0]|0;if((o&2)==0){p=n;q=o}else{c[n+1484>>2]=h<<5&224;a[n+1488|0]=a[44304+(h>>>4&3)|0]|0;c[e+(b*21040|0)+1680>>2]=h<<24>>31;c[e+(b*21040|0)+1684>>2]=h<<25>>31;p=c[j>>2]|0;q=a[l]|0}h=d[e+(b*21040|0)+181|0]|0;if((q&2)==0){r=p;s=q}else{c[p+732>>2]=h<<5&224;a[p+736|0]=a[44304+(h>>>4&3)|0]|0;c[e+(b*21040|0)+1664>>2]=h<<24>>31;c[e+(b*21040|0)+1668>>2]=h<<25>>31;r=c[j>>2]|0;s=a[l]|0}l=d[e+(b*21040|0)+437|0]|0;if((s&2)!=0){c[r+1860>>2]=l<<5&224;a[r+1864|0]=a[44304+(l>>>4&3)|0]|0;c[e+(b*21040|0)+1688>>2]=l<<24>>31;c[e+(b*21040|0)+1692>>2]=l<<25>>31}l=d[e+(b*21040|0)+257|0]|0;c[e+(b*21040|0)+20716>>2]=l;j=l&63^63;a[e+(b*21040|0)+20420|0]=j&255;l=0;do{h=l&255;k=(d[e+(b*21040|0)+20424+(h*48|0)+24|0]|0)+j|0;if((k|0)>62){a[e+(b*21040|0)+20424+(h*48|0)+40|0]=0;a[e+(b*21040|0)+20424+(h*48|0)+41|0]=0;t=0;u=0}else{m=k&7^15;a[e+(b*21040|0)+20424+(h*48|0)+40|0]=m&255;v=(k>>>3)+1|0;a[e+(b*21040|0)+20424+(h*48|0)+41|0]=v&255;t=m;u=v&255}c[e+(b*21040|0)+20424+(h*48|0)+36>>2]=(ag(c[e+(b*21040|0)+20424+(h*48|0)+28>>2]|0,t)|0)>>u&-4;l=l+1&255;}while((l&255)<6);l=e+(b*21040|0)|0;j=0;do{l0(l,j+8|0,d[j+264+(e+(b*21040|0))|0]|0);l0(l,j+16|0,d[j+272+(e+(b*21040|0))|0]|0);l0(l,j+24|0,d[j+280+(e+(b*21040|0))|0]|0);l0(l,j+32|0,d[j+288+(e+(b*21040|0))|0]|0);l0(l,j+40|0,d[j+296+(e+(b*21040|0))|0]|0);j=j+1|0;}while((j|0)<6);ls(e+(b*21040|0)+20912|0,e+(b*21040|0)+16|0);b=b+1|0;}while((b|0)<(a[7452616]&1|0));c[2383472]=0;return}function mk(){var b=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;if(a[7460872]|0){b=0}else{c[2383472]=0;return}do{e=c[3541516]|0;f=e+(b*21040|0)+512|0;g=a[e+(b*21040|0)+568|0]&3;i=c[7461744+(g<<2)>>2]<<1;lI(f,i,i,c[7461728+(g<<2)>>2]<<1);g=e+(b*21040|0)+20912|0;h[e+(b*21040|0)+20928>>3]=+h[e+(b*21040|0)+536>>3];i=a[e+(b*21040|0)+41|0]|0;j=f|0;k=a[j]|0;a[j]=i<<24>>24>-1?k&-5:k|4;k=i&31;a[e+(b*21040|0)+21033|0]=k;i=e+(b*21040|0)+520|0;l=a[e+(b*21040|0)+21032|0]&k;k=e+(b*21040|0)+562|0;a[k]=l;m=e+(b*21040|0)+563|0;n=e+(b*21040|0)+561|0;do{if((a[n]|0)==0){if((a[m]&l)<<24>>24==0){o=0;break}a[n]=1;p=c[e+(b*21040|0)+1616>>2]|0;if((p|0)==0){q=l;r=12356;break}gg[p&4095](d[i|0]|0,1);if((a[n]|0)==0){o=0;break}q=a[k]|0;r=12356}else{q=l;r=12356}}while(0);do{if((r|0)==12356){r=0;if((a[m]&q)<<24>>24!=0){o=0;break}a[n]=0;l=c[e+(b*21040|0)+1616>>2]|0;if((l|0)==0){o=0;break}gg[l&4095](d[i|0]|0,0);o=0}}while(0);while(1){i=(c[2383582]|0)+b|0;c[14168912+(i*252|0)>>2]=o;n=a[e+(b*21040|0)+o|0]|0;m=n&255;if((o|0)<=15){do{if((o|0)<14){if((o|0)!=13){if((a[14168916+(i*252|0)+o|0]|0)==n<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(i,o,m)}n=o+1|0;if((n|0)<16){o=n}else{s=48;break}}do{if((s&3|0)!=3){lP(f,s,d[e+(b*21040|0)+s|0]|0);n=s|256;lP(f,n,d[e+(b*21040|0)+n|0]|0)}s=s+1|0;}while((s|0)<158);lP(f,176,d[e+(b*21040|0)+176|0]|0);lP(f,432,d[e+(b*21040|0)+432|0]|0);lP(f,177,d[e+(b*21040|0)+177|0]|0);lP(f,433,d[e+(b*21040|0)+433|0]|0);lP(f,178,d[e+(b*21040|0)+178|0]|0);lP(f,434,d[e+(b*21040|0)+434|0]|0);n=d[e+(b*21040|0)+180|0]|0;l=e+(b*21040|0)+1652|0;k=c[l>>2]|0;p=a[j]|0;if((p&2)==0){t=k;u=p}else{c[k+356>>2]=n<<5&224;a[k+360|0]=a[44304+(n>>>4&3)|0]|0;c[e+(b*21040|0)+1656>>2]=n<<24>>31;c[e+(b*21040|0)+1660>>2]=n<<25>>31;t=c[l>>2]|0;u=a[j]|0}n=d[e+(b*21040|0)+436|0]|0;if((u&2)==0){v=t;w=u}else{c[t+1484>>2]=n<<5&224;a[t+1488|0]=a[44304+(n>>>4&3)|0]|0;c[e+(b*21040|0)+1680>>2]=n<<24>>31;c[e+(b*21040|0)+1684>>2]=n<<25>>31;v=c[l>>2]|0;w=a[j]|0}n=d[e+(b*21040|0)+181|0]|0;if((w&2)==0){x=v;y=w}else{c[v+732>>2]=n<<5&224;a[v+736|0]=a[44304+(n>>>4&3)|0]|0;c[e+(b*21040|0)+1664>>2]=n<<24>>31;c[e+(b*21040|0)+1668>>2]=n<<25>>31;x=c[l>>2]|0;y=a[j]|0}l=d[e+(b*21040|0)+437|0]|0;if((y&2)!=0){c[x+1860>>2]=l<<5&224;a[x+1864|0]=a[44304+(l>>>4&3)|0]|0;c[e+(b*21040|0)+1688>>2]=l<<24>>31;c[e+(b*21040|0)+1692>>2]=l<<25>>31}l=d[e+(b*21040|0)+273|0]|0;c[e+(b*21040|0)+20716>>2]=l;n=l&63^63;a[e+(b*21040|0)+20420|0]=n&255;l=0;do{k=l&255;p=(d[e+(b*21040|0)+20424+(k*48|0)+24|0]|0)+n|0;if((p|0)>62){a[e+(b*21040|0)+20424+(k*48|0)+40|0]=0;a[e+(b*21040|0)+20424+(k*48|0)+41|0]=0;z=0;A=0}else{B=p&7^15;a[e+(b*21040|0)+20424+(k*48|0)+40|0]=B&255;C=(p>>>3)+1|0;a[e+(b*21040|0)+20424+(k*48|0)+41|0]=C&255;z=B;A=C&255}c[e+(b*21040|0)+20424+(k*48|0)+36>>2]=(ag(c[e+(b*21040|0)+20424+(k*48|0)+28>>2]|0,z)|0)>>A&-4;l=l+1&255;}while((l&255)<6);l=d[e+(b*21040|0)+280|0]|0;c[e+(b*21040|0)+20744>>2]=l;j=l&31^31;a[e+(b*21040|0)+20448|0]=j&255;f=j+n|0;if((f|0)>62){a[e+(b*21040|0)+20464|0]=0;a[e+(b*21040|0)+20465|0]=0;D=0;E=0}else{j=f&7^15;a[e+(b*21040|0)+20464|0]=j&255;k=(f>>>3)+1|0;a[e+(b*21040|0)+20465|0]=k&255;D=j;E=k&255}c[e+(b*21040|0)+20468>>2]=8451992+(l>>>6<<2);c[e+(b*21040|0)+20460>>2]=(ag(c[e+(b*21040|0)+20452>>2]|0,D)|0)>>E&-4;l=d[e+(b*21040|0)+281|0]|0;c[e+(b*21040|0)+20748>>2]=l;k=l&31^31;a[e+(b*21040|0)+20496|0]=k&255;j=k+n|0;if((j|0)>62){a[e+(b*21040|0)+20512|0]=0;a[e+(b*21040|0)+20513|0]=0;F=0;G=0}else{k=j&7^15;a[e+(b*21040|0)+20512|0]=k&255;f=(j>>>3)+1|0;a[e+(b*21040|0)+20513|0]=f&255;F=k;G=f&255}c[e+(b*21040|0)+20516>>2]=8451992+(l>>>6<<2);c[e+(b*21040|0)+20508>>2]=(ag(c[e+(b*21040|0)+20500>>2]|0,F)|0)>>G&-4;l=d[e+(b*21040|0)+282|0]|0;c[e+(b*21040|0)+20752>>2]=l;f=l&31^31;a[e+(b*21040|0)+20544|0]=f&255;k=f+n|0;if((k|0)>62){a[e+(b*21040|0)+20560|0]=0;a[e+(b*21040|0)+20561|0]=0;H=0;I=0}else{f=k&7^15;a[e+(b*21040|0)+20560|0]=f&255;j=(k>>>3)+1|0;a[e+(b*21040|0)+20561|0]=j&255;H=f;I=j&255}c[e+(b*21040|0)+20564>>2]=8451992+(l>>>6<<2);c[e+(b*21040|0)+20556>>2]=(ag(c[e+(b*21040|0)+20548>>2]|0,H)|0)>>I&-4;l=d[e+(b*21040|0)+283|0]|0;c[e+(b*21040|0)+20756>>2]=l;j=l&31^31;a[e+(b*21040|0)+20592|0]=j&255;f=j+n|0;if((f|0)>62){a[e+(b*21040|0)+20608|0]=0;a[e+(b*21040|0)+20609|0]=0;J=0;K=0}else{j=f&7^15;a[e+(b*21040|0)+20608|0]=j&255;k=(f>>>3)+1|0;a[e+(b*21040|0)+20609|0]=k&255;J=j;K=k&255}c[e+(b*21040|0)+20612>>2]=8451992+(l>>>6<<2);c[e+(b*21040|0)+20604>>2]=(ag(c[e+(b*21040|0)+20596>>2]|0,J)|0)>>K&-4;ls(g,e+(b*21040|0)+256|0);b=b+1|0;}while((b|0)<(a[7460872]&1|0));c[2383472]=0;return}function ml(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;if((c[3531858]|0)<=0){c[2383472]=0;return}b=0;e=c[3541518]|0;while(1){f=a[e+(b*19024|0)+312|0]&3;g=c[7461744+(f<<2)>>2]|0;lI(e+(b*19024|0)+256|0,g,g,c[7461728+(f<<2)>>2]|0);f=0;g=e;do{h=(c[2383582]|0)+b|0;c[14168912+(h*252|0)>>2]=f;i=a[g+(b*19024|0)+f|0]|0;j=i&255;if((f|0)<=15){do{if((f|0)<14){if((f|0)!=13){if((a[14168916+(h*252|0)+f|0]|0)==i<<24>>24){break}}gu[c[3542220]&16383]()}}while(0);mC(h,f,j)}f=f+1|0;g=c[3541518]|0}while((f|0)<16);f=g+(b*19024|0)+256|0;i=48;do{if((i&3|0)!=3){lP(f,i,d[g+(b*19024|0)+i|0]|0)}i=i+1|0;}while((i|0)<158);lP(f,176,d[g+(b*19024|0)+176|0]|0);lP(f,177,d[g+(b*19024|0)+177|0]|0);lP(f,178,d[g+(b*19024|0)+178|0]|0);i=d[g+(b*19024|0)+180|0]|0;k=g+(b*19024|0)+1396|0;l=c[k>>2]|0;m=g+(b*19024|0)+256|0;n=a[m]|0;if((n&2)==0){o=l;p=n}else{c[l+356>>2]=i<<5&224;a[l+360|0]=a[44304+(i>>>4&3)|0]|0;c[g+(b*19024|0)+1400>>2]=i<<24>>31;c[g+(b*19024|0)+1404>>2]=i<<25>>31;o=c[k>>2]|0;p=a[m]|0}m=d[g+(b*19024|0)+181|0]|0;if((p&2)!=0){c[o+732>>2]=m<<5&224;a[o+736|0]=a[44304+(m>>>4&3)|0]|0;c[g+(b*19024|0)+1408>>2]=m<<24>>31;c[g+(b*19024|0)+1412>>2]=m<<25>>31}m=b+1|0;if((m|0)<(c[3531858]|0)){b=m;e=g}else{break}}c[2383472]=0;return}function mm(b,d){b=b|0;d=+d;var f=0,g=0,h=0,i=0,j=0,k=0.0,l=0,m=0,n=0,o=0.0,p=0,q=0,r=0.0,s=0,t=0,u=0,v=0;f=b+44|0;switch(c[f>>2]|0){case 1:{g=b+48|0;h=12423;break};case 2:{break};case 0:{i=b+48|0;c[i>>2]=2147483647;c[b+56>>2]=-2147483648;c[f>>2]=1;g=i;h=12423;break};case 3:{c[b+48>>2]=-2147483648;c[b+52>>2]=0;c[b+56>>2]=0;a[b+28|0]=0;return};case 4:{i=a[b+17|0]|0;do{if((i|0)==0){h=12459}else if((i|0)==15){j=240;k=+((-2147483648-(c[b+48>>2]|0)|0)>>>0>>>0);h=12464}else{l=a[b+16|0]|0;if(l<<24>>24==15){m=i<<2}else{n=a[b+4|0]|0;m=(((n&8|0)==0?n:n|-8)+(l<<24>>24)<<1|(e[b+2>>1]|0)>>>9&1)+(i<<2)|0}if((m|0)<0){h=12459;break}l=(m|0)>63?63:m;if((l|0)<4){h=12459;break}o=+((-2147483648-(c[b+48>>2]|0)|0)>>>0>>>0);if((l|0)>59){j=240;k=o;h=12464;break}n=(l|0)%4|0;p=(15<<21-((l|0)/4|0)|0)/(n+4|0)|0;if((n|0)!=0&(l|0)<48){j=p+2|0;k=o;h=12464;break}else{j=(l|0)==51?p+2|0:p;k=o;h=12464;break}}}while(0);if((h|0)==12459){c[b+52>>2]=0}else if((h|0)==12464){m=c[2161346]|0;i=gGU(m,(m|0)<0|0?-1:0,j,(j|0)<0|0?-1:0)|0;j=gGV(i,K,44100,0)|0;c[b+52>>2]=~~(k/(+(j>>>0>>>0)*d))}c[b+56>>2]=-2147483648;c[f>>2]=5;return};case 5:{c[b+48>>2]=-2147483648;c[b+52>>2]=0;c[b+56>>2]=0;a[b+28|0]=0;return};default:{return}}do{if((h|0)==12423){c[g>>2]=0;c[f>>2]=2;j=a[b+14|0]|0;if(j<<24>>24==0){break}i=a[b+13|0]|0;do{if((i|0)==15){q=240;r=+((j&255)<<26|0);h=12436}else if((i|0)==0){h=12431}else{m=a[b+16|0]|0;if(m<<24>>24==15){s=i<<2}else{p=a[b+4|0]|0;s=(((p&8|0)==0?p:p|-8)+(m<<24>>24)<<1|(e[b+2>>1]|0)>>>9&1)+(i<<2)|0}if((s|0)<0){h=12431;break}m=(s|0)>63?63:s;if((m|0)<4){h=12431;break}k=+((j&255)<<26|0);if((m|0)>59){q=240;r=k;h=12436;break}p=(m|0)%4|0;l=(15<<21-((m|0)/4|0)|0)/(p+4|0)|0;if((p|0)!=0&(m|0)<48){q=l+2|0;r=k;h=12436;break}else{q=(m|0)==51?l+2|0:l;r=k;h=12436;break}}}while(0);if((h|0)==12436){i=c[2161346]|0;l=gGU(i,(i|0)<0|0?-1:0,q,(q|0)<0|0?-1:0)|0;i=gGV(l,K,44100,0)|0;c[b+52>>2]=~~(r/(+(i>>>0>>>0)*d))}else if((h|0)==12431){c[b+52>>2]=0}c[b+56>>2]=(j&255)<<26;return}}while(0);q=a[b+15|0]|0;do{if((q|0)==15){t=63;h=12445}else if((q|0)==0){h=12444}else{s=a[b+16|0]|0;if(s<<24>>24==15){u=q<<2}else{g=a[b+4|0]|0;u=(((g&8|0)==0?g:g|-8)+(s<<24>>24)<<1|(e[b+2>>1]|0)>>>9&1)+(q<<2)|0}if((u|0)<0){h=12444;break}s=(u|0)>63?63:u;if((s|0)<4){h=12444}else{t=s;h=12445}}}while(0);if((h|0)==12445){r=+(256-(a[b+14|0]<<3)<<23>>>0>>>0);do{if((t|0)>59){v=240}else{u=(t|0)%4|0;q=(15<<21-((t|0)/4|0)|0)/(u+4|0)|0;if((u|0)!=0&(t|0)<48){v=q+2|0;break}else{v=(t|0)==51?q+2|0:q;break}}}while(0);t=c[2161346]|0;q=gGU(t,(t|0)<0|0?-1:0,v,(v|0)<0|0?-1:0)|0;v=gGV(q,K,44100,0)|0;c[b+52>>2]=~~(r/(+(v>>>0>>>0)*d))}else if((h|0)==12444){c[b+52>>2]=0}c[b+56>>2]=-2147483648;c[f>>2]=3;return}function mn(b,e){b=b|0;e=e|0;var f=0,g=0,h=0;f=32<<e;if(((d[14127330+(b*1492|0)|0]|0)&f|0)!=0){return 0}e=14127331+(b*1492|0)|0;g=(d[e]|0|f)&255;a[e]=g;e=14127332+(b*1492|0)|0;f=c[e>>2]|0;h=g<<24>>24!=0|0;c[e>>2]=h;if((h|0)==(f|0)){return 0}f=c[14127340+(b*1492|0)>>2]|0;if((f|0)==0){return 0}gg[f&4095](b,h);return 0}function mo(b){b=b|0;var e=0,f=0;if((c[2161346]|0)==0){return}e=d[14127336]|0;if((e|0)==3){a[14127329]=b;if((a[14127330]&2)==0){gK[c[3531836]&7](0,1,0.0);return}else{gK[c[3531836]&7](0,1,+(256-(b&255)|0)*323.1*+g[3531838]);return}}else if((e|0)==2){a[14127328]=b;if((a[14127330]&1)==0){gK[c[3531836]&7](0,0,0.0);return}else{gK[c[3531836]&7](0,0,+(256-(b&255)|0)*80.8*+g[3531838]);return}}else if((e|0)==4){do{if(b<<24>>24>-1){e=a[14127330]|0;a[14127330]=b;a[14127331]=a[14127331]&~b;f=(e^b)&255;do{if((f&1|0)!=0){if((b&1)==0){gK[c[3531836]&7](0,0,0.0);break}else{gK[c[3531836]&7](0,0,+g[3531838]*+(256-(d[14127328]|0)|0)*80.8);break}}}while(0);if((f&2|0)==0){break}if((a[14127330]&2)==0){gK[c[3531836]&7](0,1,0.0);break}else{gK[c[3531836]&7](0,1,+g[3531838]*+(256-(d[14127329]|0)|0)*323.1);break}}else{a[14127331]=0}}while(0);b=c[3531833]|0;e=(a[14127331]|0)!=0|0;c[3531833]=e;if((e|0)==(b|0)){return}b=c[3531835]|0;if((b|0)==0){return}gg[b&4095](0,e);return}else{return}}function mp(e){e=e|0;var f=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=a[14127338]|0;h=c[2161346]|0;if((h|0)==0){return}i=f&255;switch(f<<24>>24){case-1:case-2:case-3:case-4:case-5:case-6:case-7:case-8:case 7:case 6:case 5:case 4:case 3:case 2:case 1:case 0:{switch(i|0){case 249:{f=e&255;c[3531830]=f&7;c[3531831]=f>>>3&7;return};case 2:{a[14127306]=(e&255)>>>2&7;a[14127307]=e&1;return};case 4:{c[3531827]=c[3531827]&16711935|(e&255)<<8;return};case 5:{c[3531827]=c[3531827]&16776960|e&255;return};case 248:{f=e&255;c[3531828]=f&7;c[3531829]=f>>>3&7;return};case 3:{c[3531827]=c[3531827]&65535|(e&255)<<16;return};default:{return}}break};default:{}}f=i-8|0;i=(f|0)%24|0;j=14125864+(i*60|0)|0;switch((f|0)/24|0|0){case 5:{a[14125874+(i*60|0)|0]=e&7;a[14125873+(i*60|0)|0]=(e&255)>>>3&7;return};case 8:{a[14125880+(i*60|0)|0]=(e&255)>>>4;a[14125881+(i*60|0)|0]=e&15;return};case 0:{f=j|0;k=b[f>>1]&256|e&255;b[f>>1]=k;f=k&65535;do{if((k&65535)<384){l=12519}else{m=a[14127306]|0;if(m<<24>>24==0){l=12519;break}n=(c[3531837]|0)+((f*12|0)-4608+(m<<24>>24<<19))|0}}while(0);if((l|0)==12519){n=(c[3531837]|0)+(f*12|0)|0}f=a[n]&192;if((f|0)==64){a[14125893+(i*60|0)|0]=12}else if((f|0)==128){a[14125893+(i*60|0)|0]=16}else if((f|0)==0){a[14125893+(i*60|0)|0]=8}f=n+7|0;a[14125873+(i*60|0)|0]=(d[f]|0)>>>2&7;a[14125874+(i*60|0)|0]=a[f]&7;f=n+8|0;a[14125876+(i*60|0)|0]=(d[f]|0)>>>4;a[14125877+(i*60|0)|0]=a[f]&15;f=n+9|0;a[14125878+(i*60|0)|0]=(d[f]|0)>>>4;a[14125879+(i*60|0)|0]=a[f]&15;f=n+10|0;a[14125880+(i*60|0)|0]=(d[f]|0)>>>4;a[14125881+(i*60|0)|0]=a[f]&15;a[14125875+(i*60|0)|0]=a[n+11|0]&7;c[14125896+(i*60|0)>>2]=d[n+1|0]<<8|d[n+2|0]|d[n]<<16&4128768;c[14125900+(i*60|0)>>2]=d[n+3|0]<<24|d[n+4|0]<<16;c[14125904+(i*60|0)>>2]=(d[n+5|0]<<24|d[n+6|0]<<16)-65536^-65536;return};case 6:{a[14125876+(i*60|0)|0]=(e&255)>>>4;a[14125877+(i*60|0)|0]=e&15;return};case 7:{a[14125878+(i*60|0)|0]=(e&255)>>>4;a[14125879+(i*60|0)|0]=e&15;return};case 3:{a[14125871+(i*60|0)|0]=(e&255)>>>1;a[14125870+(i*60|0)|0]=e&1;return};case 4:{a[14125872+(i*60|0)|0]=e&15;n=14125892+(i*60|0)|0;if(e<<24>>24<0){a[n]=1;f=a[14125868+(i*60|0)|0]|0;c[14125908+(i*60|0)>>2]=0;c[14125912+(i*60|0)>>2]=-2147483648;c[14125916+(i*60|0)>>2]=0;c[14125920+(i*60|0)>>2]=-2147483648;c[14125888+(i*60|0)>>2]=0;l=14125884+(i*60|0)|0;c[l>>2]=0;k=gGU((b[14125866+(i*60|0)>>1]|1024)<<((f&8|0)==0?f:f|-8)+7,0,11025,0)|0;f=gGS(k,K,h,(h|0)<0|0?-1:0)|0;c[l>>2]=~~((+(f>>>0)+ +(K|0)*4294967296.0)*+g[3531838]);mm(j,+g[3531838]);return}if((a[n]|0)==0){return}c[14125908+(i*60|0)>>2]=4;mm(j,+g[3531838]);return};case 2:{n=14125866+(i*60|0)|0;b[n>>1]=b[n>>1]&127|(e&255)<<7&896;a[14125869+(i*60|0)|0]=0;a[14125868+(i*60|0)|0]=(e&255)>>>4;return};case 9:{a[14125875+(i*60|0)|0]=e&7;return};case 1:{n=j|0;j=e&255;b[n>>1]=(b[n>>1]&255|j<<8&256)&65535;n=14125866+(i*60|0)|0;b[n>>1]=(b[n>>1]&896|j>>>1)&65535;return};default:{return}}}function mq(b,d){b=b|0;d=d|0;var e=0.0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0.0,p=0,q=0,r=0,s=0;if(a[7460880]|0){return}a[7460880]=1;e=+(b|0)/72.0/+(d|0);L17451:do{if((d|0)==0){f=0;do{g=c[2113004]|0;c[2113004]=g+1;if((g|0)<=0){c[2383470]=0;g=0;while(1){i=g+1|0;j=~~+U(+(65536.0/+c$(+(+(i|0)*.03125*.125))));k=(j>>>4&1)+(j>>5)|0;j=g<<1;c[8363864+(j<<2)>>2]=k;l=j|1;c[8363864+(l<<2)>>2]=-k;m=k>>1;c[8363864+(j+512<<2)>>2]=m;c[8363864+(l+512<<2)>>2]=-m;m=k>>2;c[8363864+(j+1024<<2)>>2]=m;c[8363864+(l+1024<<2)>>2]=-m;m=k>>3;c[8363864+(j+1536<<2)>>2]=m;c[8363864+(l+1536<<2)>>2]=-m;m=k>>4;c[8363864+(j+2048<<2)>>2]=m;c[8363864+(l+2048<<2)>>2]=-m;m=k>>5;c[8363864+(j+2560<<2)>>2]=m;c[8363864+(l+2560<<2)>>2]=-m;m=k>>6;c[8363864+(j+3072<<2)>>2]=m;c[8363864+(l+3072<<2)>>2]=-m;m=k>>7;c[8363864+(j+3584<<2)>>2]=m;c[8363864+(l+3584<<2)>>2]=-m;m=k>>8;c[8363864+(j+4096<<2)>>2]=m;c[8363864+(l+4096<<2)>>2]=-m;m=k>>9;c[8363864+(j+4608<<2)>>2]=m;c[8363864+(l+4608<<2)>>2]=-m;m=k>>10;c[8363864+(j+5120<<2)>>2]=m;c[8363864+(l+5120<<2)>>2]=-m;if((i|0)<256){g=i}else{n=0;break}}do{o=+Z(+(+(n<<1|1|0)*3.141592653589793*.0009765625));g=~~(+ae(+((o>0.0?1.0:-1.0)/o))*8.0/.6931471805599453*32.0*2.0);i=(g<<1&2)+g&-2|o<0.0;c[8419176+(n<<2)>>2]=i;c[8419176+(n+1024<<2)>>2]=(n&512|0)==0?i:5632;n=n+1|0;}while((n|0)<1024)}i=gGq(5992)|0;if((i|0)==0){p=f;break L17451}gGz(i|0,0,5976);g=i;c[i+5976>>2]=b;c[i+5980>>2]=0;m=i+5984|0;h[m>>3]=0.0;l=0;o=0.0;do{c[g+1876+(l<<2)>>2]=~~(o*+(l|0)*64.0*64.0);l=l+1|0;o=+h[m>>3]}while((l|0)<1024);c[i+1692>>2]=~~(o*262144.0);c[i+1700>>2]=~~(o*16384.0);l=~~(o*65536.0);c[i+1712>>2]=l;c[i+1676>>2]=l;c[i+1680>>2]=65536;mr(g);c[14163960+(f<<2)>>2]=g;f=f+1|0;}while((f|0)<(a[7460880]&1|0));return}else{f=0;do{l=c[2113004]|0;c[2113004]=l+1;if((l|0)<=0){c[2383470]=0;l=0;while(1){m=l+1|0;j=~~+U(+(65536.0/+c$(+(+(m|0)*.03125*.125))));k=(j>>>4&1)+(j>>5)|0;j=l<<1;c[8363864+(j<<2)>>2]=k;q=j|1;c[8363864+(q<<2)>>2]=-k;r=k>>1;c[8363864+(j+512<<2)>>2]=r;c[8363864+(q+512<<2)>>2]=-r;r=k>>2;c[8363864+(j+1024<<2)>>2]=r;c[8363864+(q+1024<<2)>>2]=-r;r=k>>3;c[8363864+(j+1536<<2)>>2]=r;c[8363864+(q+1536<<2)>>2]=-r;r=k>>4;c[8363864+(j+2048<<2)>>2]=r;c[8363864+(q+2048<<2)>>2]=-r;r=k>>5;c[8363864+(j+2560<<2)>>2]=r;c[8363864+(q+2560<<2)>>2]=-r;r=k>>6;c[8363864+(j+3072<<2)>>2]=r;c[8363864+(q+3072<<2)>>2]=-r;r=k>>7;c[8363864+(j+3584<<2)>>2]=r;c[8363864+(q+3584<<2)>>2]=-r;r=k>>8;c[8363864+(j+4096<<2)>>2]=r;c[8363864+(q+4096<<2)>>2]=-r;r=k>>9;c[8363864+(j+4608<<2)>>2]=r;c[8363864+(q+4608<<2)>>2]=-r;r=k>>10;c[8363864+(j+5120<<2)>>2]=r;c[8363864+(q+5120<<2)>>2]=-r;if((m|0)<256){l=m}else{s=0;break}}do{o=+Z(+(+(s<<1|1|0)*3.141592653589793*.0009765625));l=~~(+ae(+((o>0.0?1.0:-1.0)/o))*8.0/.6931471805599453*32.0*2.0);g=(l<<1&2)+l&-2|o<0.0;c[8419176+(s<<2)>>2]=g;c[8419176+(s+1024<<2)>>2]=(s&512|0)==0?g:5632;s=s+1|0;}while((s|0)<1024)}g=gGq(5992)|0;if((g|0)==0){p=f;break L17451}gGz(g|0,0,5976);l=g;c[g+5976>>2]=b;c[g+5980>>2]=d;i=g+5984|0;h[i>>3]=e;m=0;o=e;do{c[l+1876+(m<<2)>>2]=~~(o*+(m|0)*64.0*64.0);m=m+1|0;o=+h[i>>3]}while((m|0)<1024);c[g+1692>>2]=~~(o*262144.0);c[g+1700>>2]=~~(o*16384.0);m=~~(o*65536.0);c[g+1712>>2]=m;c[g+1676>>2]=m;c[g+1680>>2]=65536;mr(l);c[14163960+(f<<2)>>2]=l;f=f+1|0;}while((f|0)<(a[7460880]&1|0));return}}while(0);c[14163960+(p<<2)>>2]=0;a[7460880]=0;return}function mr(b){b=b|0;var d=0,e=0,f=0;c[b+1672>>2]=0;c[b+1668>>2]=0;c[b+1704>>2]=1;d=0;while(1){a[b+1716+(d<<3)|0]=a[360+(d<<3)|0]|0;a[b+1716+(d<<3)+1|0]=a[361+(d<<3)|0]|0;a[b+1716+(d<<3)+2|0]=a[362+(d<<3)|0]|0;a[b+1716+(d<<3)+3|0]=a[363+(d<<3)|0]|0;a[b+1716+(d<<3)+4|0]=a[364+(d<<3)|0]|0;a[b+1716+(d<<3)+5|0]=a[365+(d<<3)|0]|0;a[b+1716+(d<<3)+6|0]=a[366+(d<<3)|0]|0;a[b+1716+(d<<3)+7|0]=a[367+(d<<3)|0]|0;e=d+1|0;if((e|0)<19){d=e}else{f=63;break}}do{ms(b,f,0);f=f-1|0;}while((f|0)>15);c[b+80>>2]=0;a[b+37|0]=0;c[b+48>>2]=255;c[b+164>>2]=0;a[b+121|0]=0;c[b+132>>2]=255;c[b+264>>2]=0;a[b+221|0]=0;c[b+232>>2]=255;c[b+348>>2]=0;a[b+305|0]=0;c[b+316>>2]=255;c[b+448>>2]=0;a[b+405|0]=0;c[b+416>>2]=255;c[b+532>>2]=0;a[b+489|0]=0;c[b+500>>2]=255;c[b+632>>2]=0;a[b+589|0]=0;c[b+600>>2]=255;c[b+716>>2]=0;a[b+673|0]=0;c[b+684>>2]=255;c[b+816>>2]=0;a[b+773|0]=0;c[b+784>>2]=255;c[b+900>>2]=0;a[b+857|0]=0;c[b+868>>2]=255;c[b+1e3>>2]=0;a[b+957|0]=0;c[b+968>>2]=255;c[b+1084>>2]=0;a[b+1041|0]=0;c[b+1052>>2]=255;c[b+1184>>2]=0;a[b+1141|0]=0;c[b+1152>>2]=255;c[b+1268>>2]=0;a[b+1225|0]=0;c[b+1236>>2]=255;c[b+1368>>2]=0;a[b+1325|0]=0;c[b+1336>>2]=255;c[b+1452>>2]=0;a[b+1409|0]=0;c[b+1420>>2]=255;c[b+1552>>2]=0;a[b+1509|0]=0;c[b+1520>>2]=255;c[b+1636>>2]=0;a[b+1593|0]=0;c[b+1604>>2]=255;return}function ms(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;g=f&255;h=e&240;if((h|0)==48){i=e&15;j=i>>>0>8?i-9|0:i;i=b+1656+j|0;k=a[i]|0;a[i]=f&255;l=f<<3&120;c[b+(j*184|0)+124>>2]=l;m=c[b+(j*184|0)+176>>2]|0;c[b+(j*184|0)+128>>2]=(m>>>((d[b+(j*184|0)+97|0]|0)>>>0))+l;do{if((j|0)>5){if((a[b+1684|0]&32)==0){break}if((j|0)<=6){return}l=(d[i]|0)>>>4<<3;c[b+(j*184|0)+40>>2]=l;c[b+(j*184|0)+44>>2]=(m>>>((d[b+(j*184|0)+13|0]|0)>>>0))+l;return}}while(0);if(((k&255^f)&240|0)==0){return}mu(b,j,j<<1,b+1716+((d[i]|0)>>>4<<3)|0);return}else if((h|0)==16|(h|0)==32){i=e&15;j=i>>>0>8?i-9|0:i;if((e&16|0)==0){i=c[b+(j*184|0)+168>>2]|0;k=i&255|f<<8&3840;m=b+(j*184|0)+68|0;l=c[m>>2]|0;n=(l|0)==0;do{if((f&16|0)==0){do{if(!n){o=l&-2;c[m>>2]=o;if((o|0)!=0){break}o=b+(j*184|0)+37|0;if((d[o]|0)<=1){break}a[o]=1}}while(0);o=b+(j*184|0)+152|0;p=c[o>>2]|0;if((p|0)==0){break}q=p&-2;c[o>>2]=q;if((q|0)!=0){break}q=b+(j*184|0)+121|0;if((d[q]|0)<=1){break}a[q]=1}else{if(n){a[b+(j*184|0)+37|0]=5}c[m>>2]=l|1;q=b+(j*184|0)+152|0;o=c[q>>2]|0;if((o|0)==0){a[b+(j*184|0)+121|0]=5}c[q>>2]=o|1}}while(0);a[b+(j*184|0)+181|0]=f&32;r=k;s=i}else{i=c[b+(j*184|0)+168>>2]|0;r=i&3840|g;s=i}if((s|0)==(r|0)){return}c[b+(j*184|0)+168>>2]=r;s=r>>>8&15;a[b+(j*184|0)+180|0]=s;i=c[44784+(r>>5<<2)>>2]|0;c[b+(j*184|0)+176>>2]=i;g=(c[b+1876+((r<<1&1022)<<2)>>2]|0)>>>((r>>>9&7^7)>>>0);c[b+(j*184|0)+172>>2]=g;c[b+(j*184|0)+44>>2]=(i>>>((d[b+(j*184|0)+13|0]|0)>>>0))+(c[b+(j*184|0)+40>>2]|0);c[b+(j*184|0)+128>>2]=(i>>>((d[b+(j*184|0)+97|0]|0)>>>0))+(c[b+(j*184|0)+124>>2]|0);c[b+(j*184|0)+20>>2]=ag(d[b+(j*184|0)+15|0]|0,g)|0;i=s&255;s=i>>>((d[b+(j*184|0)+12|0]|0)>>>0);r=b+(j*184|0)+14|0;k=a[r]|0;if((k&255|0)==(s|0)){t=k}else{k=s&255;a[r]=k;r=s&255;s=(c[b+(j*184|0)>>2]|0)+r|0;if(s>>>0<78){a[b+(j*184|0)+58|0]=a[51920+s|0]|0;a[b+(j*184|0)+59|0]=a[52368+s|0]|0}else{a[b+(j*184|0)+58|0]=0;a[b+(j*184|0)+59|0]=104}s=(c[b+(j*184|0)+4>>2]|0)+r|0;a[b+(j*184|0)+60|0]=a[51920+s|0]|0;a[b+(j*184|0)+61|0]=a[52368+s|0]|0;s=(c[b+(j*184|0)+8>>2]|0)+r|0;a[b+(j*184|0)+62|0]=a[51920+s|0]|0;a[b+(j*184|0)+63|0]=a[52368+s|0]|0;t=k}k=(a[b+(j*184|0)+181|0]|0)==0?44:36;s=t&255;t=k+s|0;a[b+(j*184|0)+64|0]=a[51920+t|0]|0;a[b+(j*184|0)+65|0]=a[52368+t|0]|0;t=s+68|0;a[b+(j*184|0)+56|0]=a[51920+t|0]|0;a[b+(j*184|0)+57|0]=a[52368+t|0]|0;c[b+(j*184|0)+104>>2]=ag(d[b+(j*184|0)+99|0]|0,g)|0;g=i>>>((d[b+(j*184|0)+96|0]|0)>>>0);i=b+(j*184|0)+98|0;t=a[i]|0;if((t&255|0)==(g|0)){u=t}else{t=g&255;a[i]=t;i=g&255;g=(c[b+(j*184|0)+84>>2]|0)+i|0;if(g>>>0<78){a[b+(j*184|0)+142|0]=a[51920+g|0]|0;a[b+(j*184|0)+143|0]=a[52368+g|0]|0}else{a[b+(j*184|0)+142|0]=0;a[b+(j*184|0)+143|0]=104}g=(c[b+(j*184|0)+88>>2]|0)+i|0;a[b+(j*184|0)+144|0]=a[51920+g|0]|0;a[b+(j*184|0)+145|0]=a[52368+g|0]|0;g=(c[b+(j*184|0)+92>>2]|0)+i|0;a[b+(j*184|0)+146|0]=a[51920+g|0]|0;a[b+(j*184|0)+147|0]=a[52368+g|0]|0;u=t}t=u&255;u=k+t|0;a[b+(j*184|0)+148|0]=a[51920+u|0]|0;a[b+(j*184|0)+149|0]=a[52368+u|0]|0;u=t+68|0;a[b+(j*184|0)+140|0]=a[51920+u|0]|0;a[b+(j*184|0)+141|0]=a[52368+u|0]|0;return}else if((h|0)==0){switch(e&15|0){case 14:{h=b+1684|0;u=(a[h]&32)==0;do{if((f&32|0)==0){if(!u){mu(b,6,12,b+1716+((d[b+1662|0]|0)>>>4<<3)|0);mu(b,7,14,b+1716+((d[b+1663|0]|0)>>>4<<3)|0);mu(b,8,16,b+1716+((d[b+1664|0]|0)>>>4<<3)|0)}j=b+1172|0;t=c[j>>2]|0;do{if((t|0)!=0){k=t&-3;c[j>>2]=k;if((k|0)!=0){break}k=b+1141|0;if((d[k]|0)<=1){break}a[k]=1}}while(0);j=b+1256|0;t=c[j>>2]|0;do{if((t|0)!=0){k=t&-3;c[j>>2]=k;if((k|0)!=0){break}k=b+1225|0;if((d[k]|0)<=1){break}a[k]=1}}while(0);j=b+1356|0;t=c[j>>2]|0;do{if((t|0)!=0){k=t&-3;c[j>>2]=k;if((k|0)!=0){break}k=b+1325|0;if((d[k]|0)<=1){break}a[k]=1}}while(0);j=b+1440|0;t=c[j>>2]|0;do{if((t|0)!=0){k=t&-3;c[j>>2]=k;if((k|0)!=0){break}k=b+1409|0;if((d[k]|0)<=1){break}a[k]=1}}while(0);j=b+1540|0;t=c[j>>2]|0;do{if((t|0)!=0){k=t&-3;c[j>>2]=k;if((k|0)!=0){break}k=b+1509|0;if((d[k]|0)<=1){break}a[k]=1}}while(0);j=b+1624|0;t=c[j>>2]|0;if((t|0)==0){break}k=t&-3;c[j>>2]=k;if((k|0)!=0){break}k=b+1593|0;if((d[k]|0)<=1){break}a[k]=1}else{if(u){mu(b,6,12,b+1844|0);mu(b,7,14,b+1852|0);k=(d[b+1663|0]|0)>>>4<<3;c[b+1328>>2]=k;c[b+1332>>2]=((c[b+1464>>2]|0)>>>((d[b+1301|0]|0)>>>0))+k;mu(b,8,16,b+1860|0);k=(d[b+1664|0]|0)>>>4<<3;c[b+1512>>2]=k;c[b+1516>>2]=((c[b+1648>>2]|0)>>>((d[b+1485|0]|0)>>>0))+k}k=b+1172|0;j=c[k>>2]|0;t=(j|0)==0;do{if((f&16|0)==0){do{if(!t){g=j&-3;c[k>>2]=g;if((g|0)!=0){break}g=b+1141|0;if((d[g]|0)<=1){break}a[g]=1}}while(0);g=b+1256|0;i=c[g>>2]|0;if((i|0)==0){break}s=i&-3;c[g>>2]=s;if((s|0)!=0){break}s=b+1225|0;if((d[s]|0)<=1){break}a[s]=1}else{if(t){a[b+1141|0]=5}c[k>>2]=j|2;s=b+1256|0;g=c[s>>2]|0;if((g|0)==0){a[b+1225|0]=5}c[s>>2]=g|2}}while(0);j=b+1356|0;k=c[j>>2]|0;t=(k|0)==0;do{if((f&1|0)==0){if(t){break}g=k&-3;c[j>>2]=g;if((g|0)!=0){break}g=b+1325|0;if((d[g]|0)<=1){break}a[g]=1}else{if(t){a[b+1325|0]=5}c[j>>2]=k|2}}while(0);k=b+1440|0;j=c[k>>2]|0;t=(j|0)==0;do{if((f&8|0)==0){if(t){break}g=j&-3;c[k>>2]=g;if((g|0)!=0){break}g=b+1409|0;if((d[g]|0)<=1){break}a[g]=1}else{if(t){a[b+1409|0]=5}c[k>>2]=j|2}}while(0);j=b+1540|0;k=c[j>>2]|0;t=(k|0)==0;do{if((f&4|0)==0){if(t){break}g=k&-3;c[j>>2]=g;if((g|0)!=0){break}g=b+1509|0;if((d[g]|0)<=1){break}a[g]=1}else{if(t){a[b+1509|0]=5}c[j>>2]=k|2}}while(0);k=b+1624|0;j=c[k>>2]|0;t=(j|0)==0;if((f&2|0)!=0){if(t){a[b+1593|0]=5}c[k>>2]=j|2;break}if(t){break}t=j&-3;c[k>>2]=t;if((t|0)!=0){break}t=b+1593|0;if((d[t]|0)<=1){break}a[t]=1}}while(0);a[h]=f&63;return};case 0:case 1:case 2:case 3:case 4:case 5:case 6:case 7:{h=e&7;a[b+1716+h|0]=f&255;f=b+1716|0;e=(a[b+1684|0]&32)==0?9:6;switch(h|0){case 5:{h=b+1721|0;u=0;do{if((d[b+1656+u|0]|0)<16){t=d[h]|0;k=(u<<1|1|0)/2|0;j=t>>>4;if((j|0)==0){v=0}else{v=(j<<2)+16|0}c[b+(k*184|0)+84>>2]=v;j=d[b+(k*184|0)+98|0]|0;g=j+v|0;if(g>>>0<78){a[b+(k*184|0)+142|0]=a[51920+g|0]|0;a[b+(k*184|0)+143|0]=a[52368+g|0]|0}else{a[b+(k*184|0)+142|0]=0;a[b+(k*184|0)+143|0]=104}g=t&15;if((g|0)==0){w=0}else{w=(g<<2)+16|0}c[b+(k*184|0)+88>>2]=w;g=w+j|0;a[b+(k*184|0)+144|0]=a[51920+g|0]|0;a[b+(k*184|0)+145|0]=a[52368+g|0]|0}u=u+1|0;}while(u>>>0<e>>>0);return};case 3:{u=b+1719|0;w=0;do{if((d[b+1656+w|0]|0)<16){v=d[u]|0;c[b+(w*184|0)+80>>2]=v>>>3<<10&1024;h=v&7;if((h|0)==0){x=0}else{x=(h|8)&255}a[b+(w*184|0)+24|0]=x;h=v>>>6;if((h|0)==0){y=31}else{y=(h^3)&255}a[b+(w*184|0)+97|0]=y;c[b+(w*184|0)+128>>2]=((c[b+(w*184|0)+176>>2]|0)>>>((y&255)>>>0))+(c[b+(w*184|0)+124>>2]|0);c[b+(w*184|0)+164>>2]=v>>>4<<10&1024}w=w+1|0;}while(w>>>0<e>>>0);return};case 2:{w=b+1718|0;y=0;do{if((d[b+1656+y|0]|0)<16){x=d[w]|0;u=x>>>6;if((u|0)==0){z=31}else{z=(u^3)&255}a[b+(y*184|0)+13|0]=z;u=x<<1&126;c[b+(y*184|0)+40>>2]=u;c[b+(y*184|0)+44>>2]=((c[b+(y*184|0)+176>>2]|0)>>>((z&255)>>>0))+u}y=y+1|0;}while(y>>>0<e>>>0);return};case 4:{y=b+1720|0;z=0;do{if((d[b+1656+z|0]|0)<16){w=d[y]|0;u=(z<<1|0)/2|0;x=w>>>4;if((x|0)==0){A=0}else{A=(x<<2)+16|0}c[b+(u*184|0)>>2]=A;x=d[b+(u*184|0)+14|0]|0;v=x+A|0;if(v>>>0<78){a[b+(u*184|0)+58|0]=a[51920+v|0]|0;a[b+(u*184|0)+59|0]=a[52368+v|0]|0}else{a[b+(u*184|0)+58|0]=0;a[b+(u*184|0)+59|0]=104}v=w&15;if((v|0)==0){B=0}else{B=(v<<2)+16|0}c[b+(u*184|0)+4>>2]=B;v=B+x|0;a[b+(u*184|0)+60|0]=a[51920+v|0]|0;a[b+(u*184|0)+61|0]=a[52368+v|0]|0}z=z+1|0;}while(z>>>0<e>>>0);return};case 0:{z=0;do{if((d[b+1656+z|0]|0)<16){B=a[f]|0;A=B&255;y=(z<<1|0)/2|0;v=a[10040+(A&15)|0]|0;a[b+(y*184|0)+15|0]=v;u=(B&255)>>>3&2^2;a[b+(y*184|0)+12|0]=u;a[b+(y*184|0)+36|0]=B&32;a[b+(y*184|0)+76|0]=B&64;c[b+(y*184|0)+72>>2]=A<<24>>31;c[b+(y*184|0)+20>>2]=ag(v&255,c[b+(y*184|0)+172>>2]|0)|0;v=(d[b+(y*184|0)+180|0]|0)>>>((u&255)>>>0);u=b+(y*184|0)+14|0;A=a[u]|0;if((A&255|0)==(v|0)){C=A}else{A=v&255;a[u]=A;u=v&255;v=(c[b+(y*184|0)>>2]|0)+u|0;if(v>>>0<78){a[b+(y*184|0)+58|0]=a[51920+v|0]|0;a[b+(y*184|0)+59|0]=a[52368+v|0]|0}else{a[b+(y*184|0)+58|0]=0;a[b+(y*184|0)+59|0]=104}v=(c[b+(y*184|0)+4>>2]|0)+u|0;a[b+(y*184|0)+60|0]=a[51920+v|0]|0;a[b+(y*184|0)+61|0]=a[52368+v|0]|0;v=(c[b+(y*184|0)+8>>2]|0)+u|0;a[b+(y*184|0)+62|0]=a[51920+v|0]|0;a[b+(y*184|0)+63|0]=a[52368+v|0]|0;C=A}A=C&255;v=((a[b+(y*184|0)+181|0]|0)==0?44:36)+A|0;a[b+(y*184|0)+64|0]=a[51920+v|0]|0;a[b+(y*184|0)+65|0]=a[52368+v|0]|0;v=A+68|0;a[b+(y*184|0)+56|0]=a[51920+v|0]|0;a[b+(y*184|0)+57|0]=a[52368+v|0]|0}z=z+1|0;}while(z>>>0<e>>>0);return};case 7:{z=b+1723|0;C=0;do{if((d[b+1656+C|0]|0)<16){f=d[z]|0;v=(C<<1|1|0)/2|0;c[b+(v*184|0)+136>>2]=c[609008+(f>>>4<<2)>>2];y=f&15;if((y|0)==0){D=0}else{D=(y<<2)+16|0}c[b+(v*184|0)+92>>2]=D;y=(d[b+(v*184|0)+98|0]|0)+D|0;a[b+(v*184|0)+146|0]=a[51920+y|0]|0;a[b+(v*184|0)+147|0]=a[52368+y|0]|0}C=C+1|0;}while(C>>>0<e>>>0);return};case 1:{C=b+1717|0;D=0;do{if((d[b+1656+D|0]|0)<16){z=a[C]|0;y=z&255;v=(D<<1|1|0)/2|0;f=a[10040+(y&15)|0]|0;a[b+(v*184|0)+99|0]=f;A=(z&255)>>>3&2^2;a[b+(v*184|0)+96|0]=A;a[b+(v*184|0)+120|0]=z&32;a[b+(v*184|0)+160|0]=z&64;c[b+(v*184|0)+156>>2]=y<<24>>31;c[b+(v*184|0)+104>>2]=ag(f&255,c[b+(v*184|0)+172>>2]|0)|0;f=(d[b+(v*184|0)+180|0]|0)>>>((A&255)>>>0);A=b+(v*184|0)+98|0;y=a[A]|0;if((y&255|0)==(f|0)){E=y}else{y=f&255;a[A]=y;A=f&255;f=(c[b+(v*184|0)+84>>2]|0)+A|0;if(f>>>0<78){a[b+(v*184|0)+142|0]=a[51920+f|0]|0;a[b+(v*184|0)+143|0]=a[52368+f|0]|0}else{a[b+(v*184|0)+142|0]=0;a[b+(v*184|0)+143|0]=104}f=(c[b+(v*184|0)+88>>2]|0)+A|0;a[b+(v*184|0)+144|0]=a[51920+f|0]|0;a[b+(v*184|0)+145|0]=a[52368+f|0]|0;f=(c[b+(v*184|0)+92>>2]|0)+A|0;a[b+(v*184|0)+146|0]=a[51920+f|0]|0;a[b+(v*184|0)+147|0]=a[52368+f|0]|0;E=y}y=E&255;f=((a[b+(v*184|0)+181|0]|0)==0?44:36)+y|0;a[b+(v*184|0)+148|0]=a[51920+f|0]|0;a[b+(v*184|0)+149|0]=a[52368+f|0]|0;f=y+68|0;a[b+(v*184|0)+140|0]=a[51920+f|0]|0;a[b+(v*184|0)+141|0]=a[52368+f|0]|0}D=D+1|0;}while(D>>>0<e>>>0);return};case 6:{D=b+1722|0;E=0;do{if((d[b+1656+E|0]|0)<16){C=d[D]|0;f=(E<<1|0)/2|0;c[b+(f*184|0)+52>>2]=c[609008+(C>>>4<<2)>>2];v=C&15;if((v|0)==0){F=0}else{F=(v<<2)+16|0}c[b+(f*184|0)+8>>2]=F;v=(d[b+(f*184|0)+14|0]|0)+F|0;a[b+(f*184|0)+62|0]=a[51920+v|0]|0;a[b+(f*184|0)+63|0]=a[52368+v|0]|0}E=E+1|0;}while(E>>>0<e>>>0);return};default:{return}}break};default:{return}}}else{return}}function mt(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0;b=i;i=i+832|0;d=b|0;e=b+16|0;f=b+32|0;g=b+48|0;h=b+64|0;j=b+80|0;k=b+96|0;l=b+112|0;m=b+128|0;n=b+144|0;o=b+160|0;p=b+176|0;q=b+192|0;r=b+208|0;s=b+224|0;t=b+240|0;u=b+256|0;v=b+272|0;w=b+288|0;x=b+304|0;y=b+320|0;z=b+336|0;A=b+352|0;B=b+368|0;C=b+384|0;D=b+400|0;E=b+416|0;F=b+432|0;G=b+448|0;H=b+464|0;I=b+480|0;J=b+496|0;K=b+512|0;L=b+528|0;M=b+544|0;N=b+560|0;O=b+576|0;P=b+592|0;Q=b+608|0;R=b+624|0;S=b+640|0;T=b+656|0;U=b+672|0;V=b+688|0;W=b+704|0;X=b+720|0;Y=b+736|0;Z=b+752|0;_=b+768|0;$=b+784|0;aa=b+800|0;ab=b+816|0;ac=c[3540990]|0;if((a&64|0)==0){i=b;return}gGz(ab|0,0,12);c[ab>>2]=ac+1656;c[ab+4>>2]=9;c[ab+12>>2]=143088;gj[c[2076592]&4095](ab)|0;gGz(aa|0,0,12);c[aa>>2]=ac+1668;c[aa+4>>2]=4;c[aa+12>>2]=492416;gj[c[2076592]&4095](aa)|0;gGz($|0,0,12);c[$>>2]=ac+1672;c[$+4>>2]=4;c[$+12>>2]=377464;gj[c[2076592]&4095]($)|0;gGz(_|0,0,12);c[_>>2]=ac+1676;c[_+4>>2]=4;c[_+12>>2]=293408;gj[c[2076592]&4095](_)|0;gGz(Z|0,0,12);c[Z>>2]=ac+1680;c[Z+4>>2]=4;c[Z+12>>2]=223144;gj[c[2076592]&4095](Z)|0;gGz(Y|0,0,12);c[Y>>2]=ac+1684;c[Y+4>>2]=1;c[Y+12>>2]=174792;gj[c[2076592]&4095](Y)|0;gGz(X|0,0,12);c[X>>2]=ac+1688;c[X+4>>2]=4;c[X+12>>2]=140296;gj[c[2076592]&4095](X)|0;gGz(W|0,0,12);c[W>>2]=ac+1692;c[W+4>>2]=4;c[W+12>>2]=112744;gj[c[2076592]&4095](W)|0;gGz(V|0,0,12);c[V>>2]=ac+1696;c[V+4>>2]=4;c[V+12>>2]=87920;gj[c[2076592]&4095](V)|0;gGz(U|0,0,12);c[U>>2]=ac+1700;c[U+4>>2]=4;c[U+12>>2]=68224;gj[c[2076592]&4095](U)|0;gGz(T|0,0,12);c[T>>2]=ac+1704;c[T+4>>2]=4;c[T+12>>2]=576208;gj[c[2076592]&4095](T)|0;gGz(S|0,0,12);c[S>>2]=ac+1708;c[S+4>>2]=4;c[S+12>>2]=559624;gj[c[2076592]&4095](S)|0;gGz(R|0,0,12);c[R>>2]=ac+1712;c[R+4>>2]=4;c[R+12>>2]=543696;gj[c[2076592]&4095](R)|0;gGz(Q|0,0,12);c[Q>>2]=ac+1716;c[Q+4>>2]=152;c[Q+12>>2]=530288;gj[c[2076592]&4095](Q)|0;gGz(P|0,0,12);c[P>>2]=ac+5972;c[P+4>>2]=1;c[P+12>>2]=516512;gj[c[2076592]&4095](P)|0;gGz(O|0,0,12);c[O>>2]=ac+5973;c[O+4>>2]=1;c[O+12>>2]=503640;gj[c[2076592]&4095](O)|0;O=N;P=N|0;Q=N+4|0;R=N+12|0;S=M;T=M|0;U=M+4|0;V=M+12|0;W=L;X=L|0;Y=L+4|0;Z=L+12|0;_=K;$=K|0;aa=K+4|0;ab=K+12|0;a=J;ad=J|0;ae=J+4|0;af=J+12|0;ag=I;ah=I|0;ai=I+4|0;aj=I+12|0;ak=H;al=H|0;am=H+4|0;an=H+12|0;ao=G;ap=G|0;aq=G+4|0;ar=G+12|0;as=F;at=F|0;au=F+4|0;av=F+12|0;aw=E;ax=E|0;ay=E+4|0;az=E+12|0;aA=D;aB=D|0;aC=D+4|0;aD=D+12|0;aE=C;aF=C|0;aG=C+4|0;aH=C+12|0;aI=B;aJ=B|0;aK=B+4|0;aL=B+12|0;aM=A;aN=A|0;aO=A+4|0;aP=A+12|0;aQ=z;aR=z|0;aS=z+4|0;aT=z+12|0;aU=y;aV=y|0;aW=y+4|0;aX=y+12|0;aY=x;aZ=x|0;a_=x+4|0;a$=x+12|0;a0=w;a1=w|0;a2=w+4|0;a3=w+12|0;a4=v;a5=v|0;a6=v+4|0;a7=v+12|0;a8=u;a9=u|0;ba=u+4|0;bb=u+12|0;bc=t;bd=t|0;be=t+4|0;bf=t+12|0;bg=s;bh=s|0;bi=s+4|0;bj=s+12|0;bk=r;bl=r|0;bm=r+4|0;bn=r+12|0;bo=q;bp=q|0;bq=q+4|0;br=q+12|0;bs=p;bt=p|0;bu=p+4|0;bv=p+12|0;bw=o;bx=o|0;by=o+4|0;bz=o+12|0;bA=n;bB=n|0;bC=n+4|0;bD=n+12|0;bE=m;bF=m|0;bG=m+4|0;bH=m+12|0;bI=l;bJ=l|0;bK=l+4|0;bL=l+12|0;bM=k;bN=k|0;bO=k+4|0;bP=k+12|0;bQ=j;bR=j|0;bS=j+4|0;bT=j+12|0;bU=h;bV=h|0;bW=h+4|0;bX=h+12|0;bY=g;bZ=g|0;b_=g+4|0;b$=g+12|0;b0=f;b1=f|0;b2=f+4|0;b3=f+12|0;b4=e;b5=e|0;b6=e+4|0;b7=e+12|0;b8=d;b9=d|0;ca=d+4|0;cb=d+12|0;cc=0;do{gGz(O|0,0,12);c[P>>2]=ac+(cc*184|0)+168;c[Q>>2]=4;c[R>>2]=491488;gj[c[2076592]&4095](N)|0;gGz(S|0,0,12);c[T>>2]=ac+(cc*184|0)+172;c[U>>2]=4;c[V>>2]=478640;gj[c[2076592]&4095](M)|0;gGz(W|0,0,12);c[X>>2]=ac+(cc*184|0)+176;c[Y>>2]=4;c[Z>>2]=466512;gj[c[2076592]&4095](L)|0;gGz(_|0,0,12);c[$>>2]=ac+(cc*184|0)+180;c[aa>>2]=1;c[ab>>2]=455008;gj[c[2076592]&4095](K)|0;gGz(a|0,0,12);c[ad>>2]=ac+(cc*184|0)+181;c[ae>>2]=1;c[af>>2]=444672;gj[c[2076592]&4095](J)|0;cd=0;do{gGz(ag|0,0,12);c[ah>>2]=ac+(cc*184|0)+(cd*84|0);c[ai>>2]=4;c[aj>>2]=432584;gj[c[2076592]&4095](I)|0;gGz(ak|0,0,12);c[al>>2]=ac+(cc*184|0)+(cd*84|0)+4;c[am>>2]=4;c[an>>2]=422088;gj[c[2076592]&4095](H)|0;gGz(ao|0,0,12);c[ap>>2]=ac+(cc*184|0)+(cd*84|0)+8;c[aq>>2]=4;c[ar>>2]=408936;gj[c[2076592]&4095](G)|0;gGz(as|0,0,12);c[at>>2]=ac+(cc*184|0)+(cd*84|0)+12;c[au>>2]=1;c[av>>2]=399016;gj[c[2076592]&4095](F)|0;gGz(aw|0,0,12);c[ax>>2]=ac+(cc*184|0)+(cd*84|0)+13;c[ay>>2]=1;c[az>>2]=386784;gj[c[2076592]&4095](E)|0;gGz(aA|0,0,12);c[aB>>2]=ac+(cc*184|0)+(cd*84|0)+14;c[aC>>2]=1;c[aD>>2]=376464;gj[c[2076592]&4095](D)|0;gGz(aE|0,0,12);c[aF>>2]=ac+(cc*184|0)+(cd*84|0)+15;c[aG>>2]=1;c[aH>>2]=365904;gj[c[2076592]&4095](C)|0;gGz(aI|0,0,12);c[aJ>>2]=ac+(cc*184|0)+(cd*84|0)+16;c[aK>>2]=4;c[aL>>2]=358408;gj[c[2076592]&4095](B)|0;gGz(aM|0,0,12);c[aN>>2]=ac+(cc*184|0)+(cd*84|0)+20;c[aO>>2]=4;c[aP>>2]=350816;gj[c[2076592]&4095](A)|0;gGz(aQ|0,0,12);c[aR>>2]=ac+(cc*184|0)+(cd*84|0)+24;c[aS>>2]=1;c[aT>>2]=342816;gj[c[2076592]&4095](z)|0;gGz(aU|0,0,12);c[aV>>2]=ac+(cc*184|0)+(cd*84|0)+28;c[aW>>2]=8;c[aX>>2]=334728;gj[c[2076592]&4095](y)|0;gGz(aY|0,0,12);c[aZ>>2]=ac+(cc*184|0)+(cd*84|0)+36;c[a_>>2]=1;c[a$>>2]=326512;gj[c[2076592]&4095](x)|0;gGz(a0|0,0,12);c[a1>>2]=ac+(cc*184|0)+(cd*84|0)+37;c[a2>>2]=1;c[a3>>2]=317408;gj[c[2076592]&4095](w)|0;gGz(a4|0,0,12);c[a5>>2]=ac+(cc*184|0)+(cd*84|0)+40;c[a6>>2]=4;c[a7>>2]=316656;gj[c[2076592]&4095](v)|0;gGz(a8|0,0,12);c[a9>>2]=ac+(cc*184|0)+(cd*84|0)+44;c[ba>>2]=4;c[bb>>2]=308008;gj[c[2076592]&4095](u)|0;gGz(bc|0,0,12);c[bd>>2]=ac+(cc*184|0)+(cd*84|0)+48;c[be>>2]=4;c[bf>>2]=299840;gj[c[2076592]&4095](t)|0;gGz(bg|0,0,12);c[bh>>2]=ac+(cc*184|0)+(cd*84|0)+52;c[bi>>2]=4;c[bj>>2]=292200;gj[c[2076592]&4095](s)|0;gGz(bk|0,0,12);c[bl>>2]=ac+(cc*184|0)+(cd*84|0)+56;c[bm>>2]=1;c[bn>>2]=286032;gj[c[2076592]&4095](r)|0;gGz(bo|0,0,12);c[bp>>2]=ac+(cc*184|0)+(cd*84|0)+57;c[bq>>2]=1;c[br>>2]=278888;gj[c[2076592]&4095](q)|0;gGz(bs|0,0,12);c[bt>>2]=ac+(cc*184|0)+(cd*84|0)+58;c[bu>>2]=1;c[bv>>2]=271608;gj[c[2076592]&4095](p)|0;gGz(bw|0,0,12);c[bx>>2]=ac+(cc*184|0)+(cd*84|0)+59;c[by>>2]=1;c[bz>>2]=264784;gj[c[2076592]&4095](o)|0;gGz(bA|0,0,12);c[bB>>2]=ac+(cc*184|0)+(cd*84|0)+60;c[bC>>2]=1;c[bD>>2]=256096;gj[c[2076592]&4095](n)|0;gGz(bE|0,0,12);c[bF>>2]=ac+(cc*184|0)+(cd*84|0)+61;c[bG>>2]=1;c[bH>>2]=247968;gj[c[2076592]&4095](m)|0;gGz(bI|0,0,12);c[bJ>>2]=ac+(cc*184|0)+(cd*84|0)+62;c[bK>>2]=1;c[bL>>2]=241160;gj[c[2076592]&4095](l)|0;gGz(bM|0,0,12);c[bN>>2]=ac+(cc*184|0)+(cd*84|0)+63;c[bO>>2]=1;c[bP>>2]=234832;gj[c[2076592]&4095](k)|0;gGz(bQ|0,0,12);c[bR>>2]=ac+(cc*184|0)+(cd*84|0)+64;c[bS>>2]=1;c[bT>>2]=227800;gj[c[2076592]&4095](j)|0;gGz(bU|0,0,12);c[bV>>2]=ac+(cc*184|0)+(cd*84|0)+65;c[bW>>2]=1;c[bX>>2]=221968;gj[c[2076592]&4095](h)|0;gGz(bY|0,0,12);c[bZ>>2]=ac+(cc*184|0)+(cd*84|0)+68;c[b_>>2]=4;c[b$>>2]=217888;gj[c[2076592]&4095](g)|0;gGz(b0|0,0,12);c[b1>>2]=ac+(cc*184|0)+(cd*84|0)+72;c[b2>>2]=4;c[b3>>2]=214104;gj[c[2076592]&4095](f)|0;gGz(b4|0,0,12);c[b5>>2]=ac+(cc*184|0)+(cd*84|0)+76;c[b6>>2]=1;c[b7>>2]=210552;gj[c[2076592]&4095](e)|0;gGz(b8|0,0,12);c[b9>>2]=ac+(cc*184|0)+(cd*84|0)+80;c[ca>>2]=4;c[cb>>2]=205552;gj[c[2076592]&4095](d)|0;cd=cd+1|0;}while((cd|0)<2);cc=cc+1|0;}while((cc|0)<9);i=b;return}function mu(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;h=a[g]|0;i=h&255;j=(f|0)/2|0;k=f&1;l=a[10040+(i&15)|0]|0;a[b+(j*184|0)+(k*84|0)+15|0]=l;m=(h&255)>>>3&2^2;a[b+(j*184|0)+(k*84|0)+12|0]=m;a[b+(j*184|0)+(k*84|0)+36|0]=h&32;a[b+(j*184|0)+(k*84|0)+76|0]=h&64;c[b+(j*184|0)+(k*84|0)+72>>2]=i<<24>>31;c[b+(j*184|0)+(k*84|0)+20>>2]=ag(l&255,c[b+(j*184|0)+172>>2]|0)|0;l=(d[b+(j*184|0)+180|0]|0)>>>((m&255)>>>0);m=b+(j*184|0)+(k*84|0)+14|0;i=a[m]|0;if((i&255|0)==(l|0)){n=i}else{i=l&255;a[m]=i;h=l&255;l=(c[b+(j*184|0)+(k*84|0)>>2]|0)+h|0;if(l>>>0<78){a[b+(j*184|0)+(k*84|0)+58|0]=a[51920+l|0]|0;a[b+(j*184|0)+(k*84|0)+59|0]=a[52368+l|0]|0}else{a[b+(j*184|0)+(k*84|0)+58|0]=0;a[b+(j*184|0)+(k*84|0)+59|0]=104}l=(c[b+(j*184|0)+(k*84|0)+4>>2]|0)+h|0;a[b+(j*184|0)+(k*84|0)+60|0]=a[51920+l|0]|0;a[b+(j*184|0)+(k*84|0)+61|0]=a[52368+l|0]|0;l=(c[b+(j*184|0)+(k*84|0)+8>>2]|0)+h|0;a[b+(j*184|0)+(k*84|0)+62|0]=a[51920+l|0]|0;a[b+(j*184|0)+(k*84|0)+63|0]=a[52368+l|0]|0;n=i}i=n&255;n=((a[b+(j*184|0)+181|0]|0)==0?44:36)+i|0;a[b+(j*184|0)+(k*84|0)+64|0]=a[51920+n|0]|0;a[b+(j*184|0)+(k*84|0)+65|0]=a[52368+n|0]|0;n=i+68|0;a[b+(j*184|0)+(k*84|0)+56|0]=a[51920+n|0]|0;a[b+(j*184|0)+(k*84|0)+57|0]=a[52368+n|0]|0;n=f+1|0;f=a[g+1|0]|0;i=f&255;l=(n|0)/2|0;h=n&1;n=a[10040+(i&15)|0]|0;a[b+(l*184|0)+(h*84|0)+15|0]=n;o=(f&255)>>>3&2^2;a[b+(l*184|0)+(h*84|0)+12|0]=o;a[b+(l*184|0)+(h*84|0)+36|0]=f&32;a[b+(l*184|0)+(h*84|0)+76|0]=f&64;c[b+(l*184|0)+(h*84|0)+72>>2]=i<<24>>31;c[b+(l*184|0)+(h*84|0)+20>>2]=ag(n&255,c[b+(l*184|0)+172>>2]|0)|0;n=(d[b+(l*184|0)+180|0]|0)>>>((o&255)>>>0);o=b+(l*184|0)+(h*84|0)+14|0;i=a[o]|0;if((i&255|0)==(n|0)){p=i}else{i=n&255;a[o]=i;f=n&255;n=(c[b+(l*184|0)+(h*84|0)>>2]|0)+f|0;if(n>>>0<78){a[b+(l*184|0)+(h*84|0)+58|0]=a[51920+n|0]|0;a[b+(l*184|0)+(h*84|0)+59|0]=a[52368+n|0]|0}else{a[b+(l*184|0)+(h*84|0)+58|0]=0;a[b+(l*184|0)+(h*84|0)+59|0]=104}n=(c[b+(l*184|0)+(h*84|0)+4>>2]|0)+f|0;a[b+(l*184|0)+(h*84|0)+60|0]=a[51920+n|0]|0;a[b+(l*184|0)+(h*84|0)+61|0]=a[52368+n|0]|0;n=(c[b+(l*184|0)+(h*84|0)+8>>2]|0)+f|0;a[b+(l*184|0)+(h*84|0)+62|0]=a[51920+n|0]|0;a[b+(l*184|0)+(h*84|0)+63|0]=a[52368+n|0]|0;p=i}i=p&255;p=((a[b+(l*184|0)+181|0]|0)==0?44:36)+i|0;a[b+(l*184|0)+(h*84|0)+64|0]=a[51920+p|0]|0;a[b+(l*184|0)+(h*84|0)+65|0]=a[52368+p|0]|0;p=i+68|0;a[b+(l*184|0)+(h*84|0)+56|0]=a[51920+p|0]|0;a[b+(l*184|0)+(h*84|0)+57|0]=a[52368+p|0]|0;p=d[g+2|0]|0;i=p>>>6;if((i|0)==0){q=31}else{q=(i^3)&255}a[b+(e*184|0)+13|0]=q;i=p<<1&126;c[b+(e*184|0)+40>>2]=i;p=c[b+(e*184|0)+176>>2]|0;c[b+(e*184|0)+44>>2]=(p>>>((q&255)>>>0))+i;i=d[g+3|0]|0;c[b+(e*184|0)+80>>2]=i>>>3<<10&1024;q=i&7;if((q|0)==0){r=0}else{r=(q|8)&255}a[b+(e*184|0)+24|0]=r;r=i>>>6;if((r|0)==0){s=31}else{s=(r^3)&255}a[b+(e*184|0)+97|0]=s;c[b+(e*184|0)+128>>2]=(p>>>((s&255)>>>0))+(c[b+(e*184|0)+124>>2]|0);c[b+(e*184|0)+164>>2]=i>>>4<<10&1024;i=d[g+4|0]|0;e=i>>>4;if((e|0)==0){t=0}else{t=(e<<2)+16|0}c[b+(j*184|0)+(k*84|0)>>2]=t;e=d[m]|0;s=e+t|0;if(s>>>0<78){a[b+(j*184|0)+(k*84|0)+58|0]=a[51920+s|0]|0;a[b+(j*184|0)+(k*84|0)+59|0]=a[52368+s|0]|0}else{a[b+(j*184|0)+(k*84|0)+58|0]=0;a[b+(j*184|0)+(k*84|0)+59|0]=104}s=i&15;if((s|0)==0){u=0}else{u=(s<<2)+16|0}c[b+(j*184|0)+(k*84|0)+4>>2]=u;s=u+e|0;a[b+(j*184|0)+(k*84|0)+60|0]=a[51920+s|0]|0;a[b+(j*184|0)+(k*84|0)+61|0]=a[52368+s|0]|0;s=d[g+5|0]|0;e=s>>>4;if((e|0)==0){v=0}else{v=(e<<2)+16|0}c[b+(l*184|0)+(h*84|0)>>2]=v;e=d[o]|0;u=e+v|0;if(u>>>0<78){a[b+(l*184|0)+(h*84|0)+58|0]=a[51920+u|0]|0;a[b+(l*184|0)+(h*84|0)+59|0]=a[52368+u|0]|0}else{a[b+(l*184|0)+(h*84|0)+58|0]=0;a[b+(l*184|0)+(h*84|0)+59|0]=104}u=s&15;if((u|0)==0){w=0}else{w=(u<<2)+16|0}c[b+(l*184|0)+(h*84|0)+4>>2]=w;u=w+e|0;a[b+(l*184|0)+(h*84|0)+60|0]=a[51920+u|0]|0;a[b+(l*184|0)+(h*84|0)+61|0]=a[52368+u|0]|0;u=d[g+6|0]|0;c[b+(j*184|0)+(k*84|0)+52>>2]=c[609008+(u>>>4<<2)>>2];e=u&15;if((e|0)==0){x=0}else{x=(e<<2)+16|0}c[b+(j*184|0)+(k*84|0)+8>>2]=x;e=(d[m]|0)+x|0;a[b+(j*184|0)+(k*84|0)+62|0]=a[51920+e|0]|0;a[b+(j*184|0)+(k*84|0)+63|0]=a[52368+e|0]|0;e=d[g+7|0]|0;c[b+(l*184|0)+(h*84|0)+52>>2]=c[609008+(e>>>4<<2)>>2];g=e&15;if((g|0)==0){y=0;z=b+(l*184|0)+(h*84|0)+8|0;c[z>>2]=y;A=a[o]|0;B=A&255;C=B+y|0;D=51920+C|0;E=a[D]|0;F=b+(l*184|0)+(h*84|0)+62|0;a[F]=E;G=52368+C|0;H=a[G]|0;I=b+(l*184|0)+(h*84|0)+63|0;a[I]=H;return}y=(g<<2)+16|0;z=b+(l*184|0)+(h*84|0)+8|0;c[z>>2]=y;A=a[o]|0;B=A&255;C=B+y|0;D=51920+C|0;E=a[D]|0;F=b+(l*184|0)+(h*84|0)+62|0;a[F]=E;G=52368+C|0;H=a[G]|0;I=b+(l*184|0)+(h*84|0)+63|0;a[I]=H;return}function mv(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=c[3531464]|0;h=g+(b*44360|0)|0;i=e<<2&28|e>>>3&3;j=f&255;switch(e&224|0){case 128:{k=g+(b*44360|0)+(i<<7)+100|0;l=c[k>>2]|0;m=g+(b*44360|0)+(i<<7)+104|0;n=c[m>>2]|0;o=5-(j>>>6)|0;c[k>>2]=o;k=f&31;if((k|0)==0){p=0}else{p=(k<<1)+32|0}c[m>>2]=p;m=(o|0)==(l|0);if((p|0)==(n|0)&m){return}n=(c[g+(b*44360|0)+(i<<7)+48>>2]|0)>>>(o>>>0);o=n+p|0;if(o>>>0<94){a[g+(b*44360|0)+(i<<7)+72|0]=a[51792+o|0]|0;a[g+(b*44360|0)+(i<<7)+73|0]=a[52240+o|0]|0}else{a[g+(b*44360|0)+(i<<7)+72|0]=0;a[g+(b*44360|0)+(i<<7)+73|0]=-120}if(m){return}m=n+(c[g+(b*44360|0)+(i<<7)+108>>2]|0)|0;a[g+(b*44360|0)+(i<<7)+84|0]=a[51792+m|0]|0;a[g+(b*44360|0)+(i<<7)+85|0]=a[52240+m|0]|0;m=(c[g+(b*44360|0)+(i<<7)+112>>2]|0)+n|0;a[g+(b*44360|0)+(i<<7)+92|0]=a[51792+m|0]|0;a[g+(b*44360|0)+(i<<7)+93|0]=a[52240+m|0]|0;m=(c[g+(b*44360|0)+(i<<7)+116>>2]|0)+n|0;a[g+(b*44360|0)+(i<<7)+94|0]=a[51792+m|0]|0;a[g+(b*44360|0)+(i<<7)+95|0]=a[52240+m|0]|0;return};case 224:{c[g+(b*44360|0)+(i<<7)+88>>2]=c[9533816+(j>>>4<<2)>>2];m=(f<<2&60)+34|0;c[g+(b*44360|0)+(i<<7)+116>>2]=m;n=((c[g+(b*44360|0)+(i<<7)+48>>2]|0)>>>((c[g+(b*44360|0)+(i<<7)+100>>2]|0)>>>0))+m|0;a[g+(b*44360|0)+(i<<7)+94|0]=a[51792+n|0]|0;a[g+(b*44360|0)+(i<<7)+95|0]=a[52240+n|0]|0;return};case 192:{n=g+(b*44360|0)+(i<<7)+20|0;m=c[n>>2]|0;o=c[52992+(j>>>6<<2)>>2]|0;c[n>>2]=o;if((o|0)!=(m|0)){c[g+(b*44360|0)+(i<<7)+4>>2]=(ag((c[g+(b*44360|0)+(i<<7)+8>>2]|0)+(c[g+(b*44360|0)+9400+((c[g+(b*44360|0)+(i<<7)+52>>2]|0)+o<<2)>>2]|0)|0,c[g+(b*44360|0)+(i<<7)+12>>2]|0)|0)>>>1}o=f&31;if((o|0)==0){q=0}else{q=(o<<1)+32|0}c[g+(b*44360|0)+(i<<7)+112>>2]=q;o=((c[g+(b*44360|0)+(i<<7)+48>>2]|0)>>>((c[g+(b*44360|0)+(i<<7)+100>>2]|0)>>>0))+q|0;a[g+(b*44360|0)+(i<<7)+92|0]=a[51792+o|0]|0;a[g+(b*44360|0)+(i<<7)+93|0]=a[52240+o|0]|0;return};case 96:{c[g+(b*44360|0)+(i<<7)+76>>2]=f<<3&1016;return};case 160:{c[g+(b*44360|0)+(i<<7)+64>>2]=f<<24>>31;o=f&31;if((o|0)==0){r=0}else{r=(o<<1)+32|0}c[g+(b*44360|0)+(i<<7)+108>>2]=r;o=((c[g+(b*44360|0)+(i<<7)+48>>2]|0)>>>((c[g+(b*44360|0)+(i<<7)+100>>2]|0)>>>0))+r|0;a[g+(b*44360|0)+(i<<7)+84|0]=a[51792+o|0]|0;a[g+(b*44360|0)+(i<<7)+85|0]=a[52240+o|0]|0;return};case 32:{o=e&7;r=o<<2;q=e&24;if((q|0)==16){m=j>>>2;n=g+(b*44360|0)+(r<<7)+52|0;p=c[n>>2]|0;if((m|0)==(p&63|0)){return}l=p&-64|m;c[n>>2]=l;n=r|1;c[g+(b*44360|0)+(n<<7)+52>>2]=l;m=r|2;c[g+(b*44360|0)+(m<<7)+52>>2]=l;p=r|3;c[g+(b*44360|0)+(p<<7)+52>>2]=l;c[g+(b*44360|0)+(r<<7)+4>>2]=(ag((c[g+(b*44360|0)+(r<<7)+8>>2]|0)+(c[g+(b*44360|0)+9400+((c[g+(b*44360|0)+(r<<7)+20>>2]|0)+l<<2)>>2]|0)|0,c[g+(b*44360|0)+(r<<7)+12>>2]|0)|0)>>>1;c[g+(b*44360|0)+(n<<7)+4>>2]=(ag((c[g+(b*44360|0)+(n<<7)+8>>2]|0)+(c[g+(b*44360|0)+9400+((c[g+(b*44360|0)+(n<<7)+20>>2]|0)+l<<2)>>2]|0)|0,c[g+(b*44360|0)+(n<<7)+12>>2]|0)|0)>>>1;c[g+(b*44360|0)+(m<<7)+4>>2]=(ag((c[g+(b*44360|0)+(m<<7)+8>>2]|0)+(c[g+(b*44360|0)+9400+((c[g+(b*44360|0)+(m<<7)+20>>2]|0)+l<<2)>>2]|0)|0,c[g+(b*44360|0)+(m<<7)+12>>2]|0)|0)>>>1;c[g+(b*44360|0)+(p<<7)+4>>2]=(ag((c[g+(b*44360|0)+(p<<7)+8>>2]|0)+(c[g+(b*44360|0)+9400+((c[g+(b*44360|0)+(p<<7)+20>>2]|0)+l<<2)>>2]|0)|0,c[g+(b*44360|0)+(p<<7)+12>>2]|0)|0)>>>1;return}else if((q|0)==24){c[g+(b*44360|0)+(r<<7)+56>>2]=f>>>4&7;c[g+(b*44360|0)+(r<<7)+60>>2]=f&3;return}else if((q|0)==0){p=f>>>3&7;c[g+(b*44360|0)+(r<<7)+36>>2]=(p|0)==0?0:p+6|0;p=o<<1;c[g+(b*44360|0)+4096+(p<<2)>>2]=f<<25>>31;c[g+(b*44360|0)+4096+((p|1)<<2)>>2]=f<<24>>31;p=f&7;a[g+(b*44360|0)+4244+o|0]=p&255;switch(p|0){case 0:{c[g+(b*44360|0)+(r<<7)+24>>2]=9534288;c[g+(b*44360|0)+((r|2)<<7)+24>>2]=8645336;c[g+(b*44360|0)+((r|1)<<7)+24>>2]=9534272;c[g+(b*44360|0)+(r<<7)+28>>2]=9104440;return};case 1:{c[g+(b*44360|0)+(r<<7)+24>>2]=8645336;c[g+(b*44360|0)+((r|2)<<7)+24>>2]=8645336;c[g+(b*44360|0)+((r|1)<<7)+24>>2]=9534272;c[g+(b*44360|0)+(r<<7)+28>>2]=9104440;return};case 6:{c[g+(b*44360|0)+(r<<7)+24>>2]=9534288;p=9534192+(o<<2)|0;c[g+(b*44360|0)+((r|2)<<7)+24>>2]=p;c[g+(b*44360|0)+((r|1)<<7)+24>>2]=p;c[g+(b*44360|0)+(r<<7)+28>>2]=8645336;return};case 7:{p=9534192+(o<<2)|0;c[g+(b*44360|0)+(r<<7)+24>>2]=p;c[g+(b*44360|0)+((r|2)<<7)+24>>2]=p;c[g+(b*44360|0)+((r|1)<<7)+24>>2]=p;c[g+(b*44360|0)+(r<<7)+28>>2]=8645336;return};case 4:{c[g+(b*44360|0)+(r<<7)+24>>2]=9534288;c[g+(b*44360|0)+((r|2)<<7)+24>>2]=9534192+(o<<2);c[g+(b*44360|0)+((r|1)<<7)+24>>2]=9534272;c[g+(b*44360|0)+(r<<7)+28>>2]=8645336;return};case 5:{c[g+(b*44360|0)+(r<<7)+24>>2]=0;p=9534192+(o<<2)|0;c[g+(b*44360|0)+((r|2)<<7)+24>>2]=p;c[g+(b*44360|0)+((r|1)<<7)+24>>2]=p;c[g+(b*44360|0)+(r<<7)+28>>2]=9104440;return};case 2:{c[g+(b*44360|0)+(r<<7)+24>>2]=9534272;c[g+(b*44360|0)+((r|2)<<7)+24>>2]=8645336;c[g+(b*44360|0)+((r|1)<<7)+24>>2]=9534272;c[g+(b*44360|0)+(r<<7)+28>>2]=9104440;return};case 3:{c[g+(b*44360|0)+(r<<7)+24>>2]=9534288;c[g+(b*44360|0)+((r|2)<<7)+24>>2]=8645336;c[g+(b*44360|0)+((r|1)<<7)+24>>2]=9534272;c[g+(b*44360|0)+(r<<7)+28>>2]=9534272;return};default:{return}}}else if((q|0)==8){q=f&127;p=g+(b*44360|0)+(r<<7)+48|0;if((q|0)==(c[p>>2]|0)){return}o=q>>>2;l=g+(b*44360|0)+(r<<7)+52|0;m=c[l>>2]&63|(q-o<<6)+768;c[p>>2]=q;c[l>>2]=m;l=r|1;c[g+(b*44360|0)+(l<<7)+48>>2]=q;c[g+(b*44360|0)+(l<<7)+52>>2]=m;p=r|2;c[g+(b*44360|0)+(p<<7)+48>>2]=q;c[g+(b*44360|0)+(p<<7)+52>>2]=m;n=r|3;c[g+(b*44360|0)+(n<<7)+48>>2]=q;c[g+(b*44360|0)+(n<<7)+52>>2]=m;k=c[g+(b*44360|0)+43192+((c[g+(b*44360|0)+(r<<7)+16>>2]|0)+o<<2)>>2]|0;c[g+(b*44360|0)+(r<<7)+8>>2]=k;c[g+(b*44360|0)+(r<<7)+4>>2]=(ag((c[g+(b*44360|0)+9400+((c[g+(b*44360|0)+(r<<7)+20>>2]|0)+m<<2)>>2]|0)+k|0,c[g+(b*44360|0)+(r<<7)+12>>2]|0)|0)>>>1;k=c[g+(b*44360|0)+43192+((c[g+(b*44360|0)+(l<<7)+16>>2]|0)+o<<2)>>2]|0;c[g+(b*44360|0)+(l<<7)+8>>2]=k;c[g+(b*44360|0)+(l<<7)+4>>2]=(ag((c[g+(b*44360|0)+9400+((c[g+(b*44360|0)+(l<<7)+20>>2]|0)+m<<2)>>2]|0)+k|0,c[g+(b*44360|0)+(l<<7)+12>>2]|0)|0)>>>1;k=c[g+(b*44360|0)+43192+((c[g+(b*44360|0)+(p<<7)+16>>2]|0)+o<<2)>>2]|0;c[g+(b*44360|0)+(p<<7)+8>>2]=k;c[g+(b*44360|0)+(p<<7)+4>>2]=(ag((c[g+(b*44360|0)+9400+((c[g+(b*44360|0)+(p<<7)+20>>2]|0)+m<<2)>>2]|0)+k|0,c[g+(b*44360|0)+(p<<7)+12>>2]|0)|0)>>>1;k=c[g+(b*44360|0)+43192+((c[g+(b*44360|0)+(n<<7)+16>>2]|0)+o<<2)>>2]|0;c[g+(b*44360|0)+(n<<7)+8>>2]=k;c[g+(b*44360|0)+(n<<7)+4>>2]=(ag((c[g+(b*44360|0)+9400+((c[g+(b*44360|0)+(n<<7)+20>>2]|0)+m<<2)>>2]|0)+k|0,c[g+(b*44360|0)+(n<<7)+12>>2]|0)|0)>>>1;k=q>>>((c[g+(b*44360|0)+(r<<7)+100>>2]|0)>>>0);m=(c[g+(b*44360|0)+(r<<7)+104>>2]|0)+k|0;if(m>>>0<94){a[g+(b*44360|0)+(r<<7)+72|0]=a[51792+m|0]|0;a[g+(b*44360|0)+(r<<7)+73|0]=a[52240+m|0]|0}else{a[g+(b*44360|0)+(r<<7)+72|0]=0;a[g+(b*44360|0)+(r<<7)+73|0]=-120}m=(c[g+(b*44360|0)+(r<<7)+108>>2]|0)+k|0;a[g+(b*44360|0)+(r<<7)+84|0]=a[51792+m|0]|0;a[g+(b*44360|0)+(r<<7)+85|0]=a[52240+m|0]|0;m=(c[g+(b*44360|0)+(r<<7)+112>>2]|0)+k|0;a[g+(b*44360|0)+(r<<7)+92|0]=a[51792+m|0]|0;a[g+(b*44360|0)+(r<<7)+93|0]=a[52240+m|0]|0;m=(c[g+(b*44360|0)+(r<<7)+116>>2]|0)+k|0;a[g+(b*44360|0)+(r<<7)+94|0]=a[51792+m|0]|0;a[g+(b*44360|0)+(r<<7)+95|0]=a[52240+m|0]|0;m=q>>>((c[g+(b*44360|0)+(l<<7)+100>>2]|0)>>>0);r=(c[g+(b*44360|0)+(l<<7)+104>>2]|0)+m|0;if(r>>>0<94){a[g+(b*44360|0)+(l<<7)+72|0]=a[51792+r|0]|0;a[g+(b*44360|0)+(l<<7)+73|0]=a[52240+r|0]|0}else{a[g+(b*44360|0)+(l<<7)+72|0]=0;a[g+(b*44360|0)+(l<<7)+73|0]=-120}r=(c[g+(b*44360|0)+(l<<7)+108>>2]|0)+m|0;a[g+(b*44360|0)+(l<<7)+84|0]=a[51792+r|0]|0;a[g+(b*44360|0)+(l<<7)+85|0]=a[52240+r|0]|0;r=(c[g+(b*44360|0)+(l<<7)+112>>2]|0)+m|0;a[g+(b*44360|0)+(l<<7)+92|0]=a[51792+r|0]|0;a[g+(b*44360|0)+(l<<7)+93|0]=a[52240+r|0]|0;r=(c[g+(b*44360|0)+(l<<7)+116>>2]|0)+m|0;a[g+(b*44360|0)+(l<<7)+94|0]=a[51792+r|0]|0;a[g+(b*44360|0)+(l<<7)+95|0]=a[52240+r|0]|0;r=q>>>((c[g+(b*44360|0)+(p<<7)+100>>2]|0)>>>0);l=(c[g+(b*44360|0)+(p<<7)+104>>2]|0)+r|0;if(l>>>0<94){a[g+(b*44360|0)+(p<<7)+72|0]=a[51792+l|0]|0;a[g+(b*44360|0)+(p<<7)+73|0]=a[52240+l|0]|0}else{a[g+(b*44360|0)+(p<<7)+72|0]=0;a[g+(b*44360|0)+(p<<7)+73|0]=-120}l=(c[g+(b*44360|0)+(p<<7)+108>>2]|0)+r|0;a[g+(b*44360|0)+(p<<7)+84|0]=a[51792+l|0]|0;a[g+(b*44360|0)+(p<<7)+85|0]=a[52240+l|0]|0;l=(c[g+(b*44360|0)+(p<<7)+112>>2]|0)+r|0;a[g+(b*44360|0)+(p<<7)+92|0]=a[51792+l|0]|0;a[g+(b*44360|0)+(p<<7)+93|0]=a[52240+l|0]|0;l=(c[g+(b*44360|0)+(p<<7)+116>>2]|0)+r|0;a[g+(b*44360|0)+(p<<7)+94|0]=a[51792+l|0]|0;a[g+(b*44360|0)+(p<<7)+95|0]=a[52240+l|0]|0;l=q>>>((c[g+(b*44360|0)+(n<<7)+100>>2]|0)>>>0);q=(c[g+(b*44360|0)+(n<<7)+104>>2]|0)+l|0;if(q>>>0<94){a[g+(b*44360|0)+(n<<7)+72|0]=a[51792+q|0]|0;a[g+(b*44360|0)+(n<<7)+73|0]=a[52240+q|0]|0}else{a[g+(b*44360|0)+(n<<7)+72|0]=0;a[g+(b*44360|0)+(n<<7)+73|0]=-120}q=(c[g+(b*44360|0)+(n<<7)+108>>2]|0)+l|0;a[g+(b*44360|0)+(n<<7)+84|0]=a[51792+q|0]|0;a[g+(b*44360|0)+(n<<7)+85|0]=a[52240+q|0]|0;q=(c[g+(b*44360|0)+(n<<7)+112>>2]|0)+l|0;a[g+(b*44360|0)+(n<<7)+92|0]=a[51792+q|0]|0;a[g+(b*44360|0)+(n<<7)+93|0]=a[52240+q|0]|0;q=(c[g+(b*44360|0)+(n<<7)+116>>2]|0)+l|0;a[g+(b*44360|0)+(n<<7)+94|0]=a[51792+q|0]|0;a[g+(b*44360|0)+(n<<7)+95|0]=a[52240+q|0]|0;return}else{return}break};case 0:{switch(e&255|0){case 8:{c[3540880]=h;h=f<<2&28;e=g+(b*44360|0)+(h<<7)+96|0;q=c[e>>2]|0;n=(q|0)!=0;do{if((f&8|0)==0){if(!n){break}l=q&-2;c[e>>2]=l;if((l|0)!=0){break}l=g+(b*44360|0)+(h<<7)+68|0;if((c[l>>2]|0)>>>0<=1){break}c[l>>2]=1}else{do{if(!n){c[g+(b*44360|0)+(h<<7)>>2]=0;l=g+(b*44360|0)+(h<<7)+68|0;c[l>>2]=4;p=g+(b*44360|0)+(h<<7)+80|0;r=c[p>>2]|0;m=((ag(d[52464+(((c[g+(b*44360|0)+4160>>2]|0)>>>((d[g+(b*44360|0)+(h<<7)+72|0]|0)>>>0)&7)+(d[g+(b*44360|0)+(h<<7)+73|0]|0))|0]|0,~r)|0)>>4)+r|0;c[p>>2]=m;if((m|0)>=1){break}c[p>>2]=0;c[l>>2]=3}}while(0);c[e>>2]=q|1}}while(0);q=h|1;e=g+(b*44360|0)+(q<<7)+96|0;n=c[e>>2]|0;l=(n|0)!=0;do{if((f&32|0)==0){if(!l){break}p=n&-2;c[e>>2]=p;if((p|0)!=0){break}p=g+(b*44360|0)+(q<<7)+68|0;if((c[p>>2]|0)>>>0<=1){break}c[p>>2]=1}else{do{if(!l){c[g+(b*44360|0)+(q<<7)>>2]=0;p=g+(b*44360|0)+(q<<7)+68|0;c[p>>2]=4;m=g+(b*44360|0)+(q<<7)+80|0;r=c[m>>2]|0;k=((ag(d[52464+(((c[g+(b*44360|0)+4160>>2]|0)>>>((d[g+(b*44360|0)+(q<<7)+72|0]|0)>>>0)&7)+(d[g+(b*44360|0)+(q<<7)+73|0]|0))|0]|0,~r)|0)>>4)+r|0;c[m>>2]=k;if((k|0)>=1){break}c[m>>2]=0;c[p>>2]=3}}while(0);c[e>>2]=n|1}}while(0);n=h|2;e=g+(b*44360|0)+(n<<7)+96|0;q=c[e>>2]|0;l=(q|0)!=0;do{if((f&16|0)==0){if(!l){break}p=q&-2;c[e>>2]=p;if((p|0)!=0){break}p=g+(b*44360|0)+(n<<7)+68|0;if((c[p>>2]|0)>>>0<=1){break}c[p>>2]=1}else{do{if(!l){c[g+(b*44360|0)+(n<<7)>>2]=0;p=g+(b*44360|0)+(n<<7)+68|0;c[p>>2]=4;m=g+(b*44360|0)+(n<<7)+80|0;k=c[m>>2]|0;r=((ag(d[52464+(((c[g+(b*44360|0)+4160>>2]|0)>>>((d[g+(b*44360|0)+(n<<7)+72|0]|0)>>>0)&7)+(d[g+(b*44360|0)+(n<<7)+73|0]|0))|0]|0,~k)|0)>>4)+k|0;c[m>>2]=r;if((r|0)>=1){break}c[m>>2]=0;c[p>>2]=3}}while(0);c[e>>2]=q|1}}while(0);q=h|3;h=g+(b*44360|0)+(q<<7)+96|0;e=c[h>>2]|0;n=(e|0)!=0;if((f&64|0)!=0){do{if(!n){c[g+(b*44360|0)+(q<<7)>>2]=0;l=g+(b*44360|0)+(q<<7)+68|0;c[l>>2]=4;p=g+(b*44360|0)+(q<<7)+80|0;m=c[p>>2]|0;r=((ag(d[52464+(((c[g+(b*44360|0)+4160>>2]|0)>>>((d[g+(b*44360|0)+(q<<7)+72|0]|0)>>>0)&7)+(d[g+(b*44360|0)+(q<<7)+73|0]|0))|0]|0,~m)|0)>>4)+m|0;c[p>>2]=r;if((r|0)>=1){break}c[p>>2]=0;c[l>>2]=3}}while(0);c[h>>2]=e|1;return}if(!n){return}n=e&-2;c[h>>2]=n;if((n|0)!=0){return}n=g+(b*44360|0)+(q<<7)+68|0;if((c[n>>2]|0)>>>0<=1){return}c[n>>2]=1;return};case 16:{n=g+(b*44360|0)+9384|0;c[n>>2]=c[n>>2]&3|j<<2;return};case 27:{n=j>>>6;a[g+(b*44360|0)+4213|0]=n&255;a[g+(b*44360|0)+4200|0]=f&3;q=c[g+(b*44360|0)+44348>>2]|0;if((q|0)==0){return}gg[q&4095](0,n);return};case 15:{c[g+(b*44360|0)+4216>>2]=j;c[g+(b*44360|0)+4228>>2]=c[g+(b*44360|0)+44216+((f&31)<<2)>>2];return};case 24:{c[g+(b*44360|0)+4188>>2]=1024<<18-(j>>>4);c[g+(b*44360|0)+4196>>2]=f&15|16;return};case 25:{n=f&127;if((f&128|0)==0){a[g+(b*44360|0)+4201|0]=n;return}else{a[g+(b*44360|0)+4202|0]=n;return}break};case 17:{n=g+(b*44360|0)+9384|0;c[n>>2]=c[n>>2]&1020|f&3;return};case 20:{c[g+(b*44360|0)+4236>>2]=j;do{if((f&32|0)!=0){n=g+(b*44360|0)+4240|0;q=c[n>>2]|0;c[n>>2]=q&253;if((q&3|0)!=2){break}q=c[g+(b*44360|0)+44344>>2]|0;if((q|0)==0){break}gf[q&2047](0)}}while(0);do{if((f&16|0)!=0){q=g+(b*44360|0)+4240|0;n=c[q>>2]|0;c[q>>2]=n&254;if((n&3|0)!=1){break}n=c[g+(b*44360|0)+44344>>2]|0;if((n|0)==0){break}gf[n&2047](0)}}while(0);n=g+(b*44360|0)+4253|0;do{if((f&2|0)==0){a[n]=0}else{if((a[n]|0)!=0){break}a[n]=1;c[g+(b*44360|0)+4260>>2]=c[g+(b*44360|0)+8360+(c[g+(b*44360|0)+9388>>2]<<2)>>2]}}while(0);n=g+(b*44360|0)+4252|0;if((f&1|0)==0){a[n]=0;return}if((a[n]|0)!=0){return}a[n]=1;c[g+(b*44360|0)+4256>>2]=c[g+(b*44360|0)+4264+(c[g+(b*44360|0)+9384>>2]<<2)>>2];return};case 1:{a[g+(b*44360|0)+4212|0]=f&255;if((f&2|0)==0){return}c[g+(b*44360|0)+4176>>2]=0;return};case 18:{c[g+(b*44360|0)+9388>>2]=j;return};default:{return}}break};case 64:{j=g+(b*44360|0)+(i<<7)+16|0;n=c[j>>2]|0;q=g+(b*44360|0)+(i<<7)+12|0;h=c[q>>2]|0;e=f<<1&224;c[j>>2]=e;j=f&15;f=(j|0)==0?1:j<<1;c[q>>2]=f;do{if((n|0)==(e|0)){if((h|0)==(f|0)){return}else{s=c[g+(b*44360|0)+(i<<7)+8>>2]|0;break}}else{q=c[g+(b*44360|0)+43192+(((c[g+(b*44360|0)+(i<<7)+48>>2]|0)>>>2)+e<<2)>>2]|0;c[g+(b*44360|0)+(i<<7)+8>>2]=q;s=q}}while(0);c[g+(b*44360|0)+(i<<7)+4>>2]=(ag(s+(c[g+(b*44360|0)+9400+((c[g+(b*44360|0)+(i<<7)+20>>2]|0)+(c[g+(b*44360|0)+(i<<7)+52>>2]|0)<<2)>>2]|0)|0,f)|0)>>>1;return};default:{return}}}function mw(b,f){b=b|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0.0,p=0,q=0.0,r=0.0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;if((c[3531464]|0)!=0){return}a[7452576]=1;g=gGq(44360)|0;h=g;c[3531464]=h;if((g|0)==0){return}gGz(g|0,0,44360);g=0;while(1){i=g+1|0;j=~~+U(+(65536.0/+c$(+(+(i|0)*.03125*.125))));k=(j>>>4&1)+(j>>5)|0;j=k<<2;l=g<<1;c[8337240+(l<<2)>>2]=j;m=l|1;c[8337240+(m<<2)>>2]=-j;j=k<<1;c[8337240+(l+512<<2)>>2]=j;c[8337240+(m+512<<2)>>2]=-j;c[8337240+(l+1024<<2)>>2]=k;c[8337240+(m+1024<<2)>>2]=-k;j=k>>1;c[8337240+(l+1536<<2)>>2]=j;c[8337240+(m+1536<<2)>>2]=-j;j=k>>2;c[8337240+(l+2048<<2)>>2]=j;c[8337240+(m+2048<<2)>>2]=-j;j=k>>3;c[8337240+(l+2560<<2)>>2]=j;c[8337240+(m+2560<<2)>>2]=-j;j=k>>4;c[8337240+(l+3072<<2)>>2]=j;c[8337240+(m+3072<<2)>>2]=-j;j=k>>5;c[8337240+(l+3584<<2)>>2]=j;c[8337240+(m+3584<<2)>>2]=-j;j=k>>6;c[8337240+(l+4096<<2)>>2]=j;c[8337240+(m+4096<<2)>>2]=-j;j=k>>7;c[8337240+(l+4608<<2)>>2]=j;c[8337240+(m+4608<<2)>>2]=-j;j=k>>8;c[8337240+(l+5120<<2)>>2]=j;c[8337240+(m+5120<<2)>>2]=-j;j=k>>9;c[8337240+(l+5632<<2)>>2]=j;c[8337240+(m+5632<<2)>>2]=-j;j=k>>10;c[8337240+(l+6144<<2)>>2]=j;c[8337240+(m+6144<<2)>>2]=-j;if((i|0)<256){g=i}else{n=0;break}}while(1){o=+Z(+(+(n<<1|1|0)*3.141592653589793*.0009765625));g=~~(+ae(+((o>0.0?1.0:-1.0)/o))*8.0/.6931471805599453*32.0*2.0);c[8415080+(n<<2)>>2]=(g<<1&2)+g&-2|o<0.0;g=n+1|0;if((g|0)<1024){n=g}else{p=0;break}}do{c[9533816+(p<<2)>>2]=~~(+(((p|0)!=15?p:p+16|0)|0)*32.0);p=p+1|0;}while((p|0)<16);p=(f|0)!=0?f:44100;o=+(b|0)*.015625;q=o*1024.0;r=o*65536.0;f=0;n=h;while(1){h=n+(f*44360|0)+44352|0;c[h>>2]=b;g=n+(f*44360|0)+44356|0;c[g>>2]=p;c[n+(f*44360|0)+44344>>2]=0;c[n+(f*44360|0)+44348>>2]=0;o=+(b>>>0>>>0)*.015625/+(p>>>0>>>0);i=0;do{j=~~(o*+((e[7960+(i<<1)>>1]|0)>>>0)*64.0)&-64;c[n+(f*44360|0)+9400+(i+2304<<2)>>2]=j;c[n+(f*44360|0)+9400+(i+768<<2)>>2]=j>>>2&1073741760;c[n+(f*44360|0)+9400+(i+1536<<2)>>2]=j>>>1&2147483584;c[n+(f*44360|0)+9400+(i+3072<<2)>>2]=j<<1;c[n+(f*44360|0)+9400+(i+3840<<2)>>2]=j<<2;c[n+(f*44360|0)+9400+(i+4608<<2)>>2]=j<<3;c[n+(f*44360|0)+9400+(i+5376<<2)>>2]=j<<4;c[n+(f*44360|0)+9400+(i+6144<<2)>>2]=j<<5;i=i+1|0;}while((i|0)<768);i=n+(f*44360|0)+12472|0;j=0;do{c[n+(f*44360|0)+9400+(j<<2)>>2]=c[i>>2];j=j+1|0;}while((j|0)<768);j=n+(f*44360|0)+37044|0;i=0;while(1){c[n+(f*44360|0)+9400+(i+6912<<2)>>2]=c[j>>2];m=i+1|0;if((m|0)<768){i=m}else{s=0;break}}while(1){c[n+(f*44360|0)+9400+(s+7680<<2)>>2]=c[j>>2];i=s+1|0;if((i|0)<768){s=i}else{t=0;break}}while(1){j=~~(+((d[53008+t|0]|0)>>>0)*+((c[h>>2]|0)>>>0>>>0)*.015625*9.5367431640625e-7*1024.0/+((c[g>>2]|0)>>>0>>>0)*65536.0);c[n+(f*44360|0)+43192+(t<<2)>>2]=j;c[n+(f*44360|0)+43192+(t+128<<2)>>2]=-j;j=t+1|0;if((j|0)<32){t=j}else{u=0;break}}while(1){j=u+32|0;i=~~(+((d[53008+j|0]|0)>>>0)*+((c[h>>2]|0)>>>0>>>0)*.015625*9.5367431640625e-7*1024.0/+((c[g>>2]|0)>>>0>>>0)*65536.0);c[n+(f*44360|0)+43192+(j<<2)>>2]=i;c[n+(f*44360|0)+43192+(u+160<<2)>>2]=-i;i=u+1|0;if((i|0)<32){u=i}else{v=0;break}}while(1){i=v+64|0;j=~~(+((d[53008+i|0]|0)>>>0)*+((c[h>>2]|0)>>>0>>>0)*.015625*9.5367431640625e-7*1024.0/+((c[g>>2]|0)>>>0>>>0)*65536.0);c[n+(f*44360|0)+43192+(i<<2)>>2]=j;c[n+(f*44360|0)+43192+(v+192<<2)>>2]=-j;j=v+1|0;if((j|0)<32){v=j}else{w=0;break}}while(1){j=w+96|0;i=~~(+((d[53008+j|0]|0)>>>0)*+((c[h>>2]|0)>>>0>>>0)*.015625*9.5367431640625e-7*1024.0/+((c[g>>2]|0)>>>0>>>0)*65536.0);c[n+(f*44360|0)+43192+(j<<2)>>2]=i;c[n+(f*44360|0)+43192+(w+224<<2)>>2]=-i;i=w+1|0;if((i|0)<32){w=i}else{x=0;break}}while(1){c[n+(f*44360|0)+4264+(x<<2)>>2]=~~((1024.0- +(x|0))*64.0/+((c[h>>2]|0)>>>0>>>0)*+((c[g>>2]|0)>>>0>>>0)*65536.0);i=x+1|0;if((i|0)<1024){x=i}else{y=0;break}}do{c[n+(f*44360|0)+8360+(y<<2)>>2]=~~((256.0- +(y|0))*1024.0/+((c[h>>2]|0)>>>0>>>0)*+((c[g>>2]|0)>>>0>>>0)*65536.0);y=y+1|0;}while((y|0)<256);o=+((c[h>>2]|0)>>>0>>>0)*.015625/+((c[g>>2]|0)>>>0>>>0);i=0;do{c[n+(f*44360|0)+44216+(i<<2)>>2]=~~(o*+(~~(65536.0/((i|0)!=31?+(32-i|0)*32.0:64.0))<<6|0));i=i+1|0;}while((i|0)<32);o=+((c[g>>2]|0)>>>0>>>0);c[n+(f*44360|0)+4184>>2]=~~(q/o);c[n+(f*44360|0)+4168>>2]=~~(r/o);c[n+(f*44360|0)+4172>>2]=196608;a[n+(f*44360|0)+4252|0]=0;a[n+(f*44360|0)+4253|0]=0;mx(f);i=f+1|0;if(i>>>0>=(a[7452576]&1)>>>0){break}f=i;n=c[3531464]|0}return}function mx(b){b=b|0;var d=0,e=0,f=0;d=c[3531464]|0;e=0;do{gGz(d+(b*44360|0)+(e<<7)|0,0,128);c[d+(b*44360|0)+(e<<7)+80>>2]=1023;c[d+(b*44360|0)+(e<<7)+52>>2]=768;e=e+1|0;}while((e|0)<32);c[d+(b*44360|0)+4164>>2]=0;c[d+(b*44360|0)+4160>>2]=0;c[d+(b*44360|0)+4180>>2]=0;c[d+(b*44360|0)+4192>>2]=0;c[d+(b*44360|0)+4176>>2]=0;a[d+(b*44360|0)+4202|0]=0;a[d+(b*44360|0)+4201|0]=0;c[d+(b*44360|0)+4204>>2]=0;c[d+(b*44360|0)+4208>>2]=0;a[d+(b*44360|0)+4212|0]=0;c[d+(b*44360|0)+4236>>2]=0;a[d+(b*44360|0)+4252|0]=0;a[d+(b*44360|0)+4253|0]=0;c[d+(b*44360|0)+4256>>2]=0;c[d+(b*44360|0)+4260>>2]=0;c[d+(b*44360|0)+4216>>2]=0;c[d+(b*44360|0)+4220>>2]=0;c[d+(b*44360|0)+4224>>2]=0;gGz(d+(b*44360|0)+9384|0,0,16);c[d+(b*44360|0)+4228>>2]=c[d+(b*44360|0)+44216>>2];c[d+(b*44360|0)+4232>>2]=0;c[d+(b*44360|0)+4240>>2]=0;a[d+(b*44360|0)+4213|0]=0;a[d+(b*44360|0)+4200|0]=0;e=c[d+(b*44360|0)+44348>>2]|0;if((e|0)==0){f=d}else{gg[e&4095](0,0);f=c[3531464]|0}c[f+(b*44360|0)+4188>>2]=268435456;c[f+(b*44360|0)+4196>>2]=16;f=32;do{mv(b,f,0);f=f+1|0;}while((f|0)<256);return}function my(e){e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;f=c[2438972]|0;g=c[2438970]|0;h=c[3531464]|0;c[3540880]=h;do{if((a[h+4253|0]|0)!=0){i=h+4260|0;j=(c[i>>2]|0)-(e<<16)|0;c[i>>2]=j;if((j|0)>=1){break}c[i>>2]=(c[h+8360+(c[h+9388>>2]<<2)>>2]|0)+j;if((c[h+4236>>2]&8|0)==0){break}j=h+4240|0;i=c[j>>2]|0;c[j>>2]=i|2;if((i&3|0)!=0){break}i=c[h+44344>>2]|0;if((i|0)==0){break}gf[i&2047](1)}}while(0);if((e|0)<=0){return}h=c[3540880]|0;i=0;j=h;k=h;l=h;m=h;while(1){h=j+4164|0;n=(c[h>>2]|0)+(c[j+4168>>2]|0)|0;c[h>>2]=n;o=c[j+4172>>2]|0;if(n>>>0<o>>>0){p=j;q=k;r=l}else{s=m+4160|0;t=m|0;u=m+4164|0;v=m+4172|0;w=h;h=n;n=o;while(1){c[w>>2]=h-n;c[s>>2]=(c[s>>2]|0)+1;o=32;x=t;while(1){y=x+68|0;z=c[y>>2]|0;do{if((z|0)==3){A=c[s>>2]|0;B=d[x+84|0]|0;if(((1<<B)-1&A|0)!=0){break}C=x+80|0;D=(c[C>>2]|0)+(d[52464+((d[x+85|0]|0)+(A>>>(B>>>0)&7))|0]|0)|0;c[C>>2]=D;if(D>>>0<(c[x+88>>2]|0)>>>0){break}c[y>>2]=2}else if((z|0)==4){D=c[s>>2]|0;C=d[x+72|0]|0;if(((1<<C)-1&D|0)!=0){break}B=x+80|0;A=c[B>>2]|0;E=((ag(d[52464+((d[x+73|0]|0)+(D>>>(C>>>0)&7))|0]|0,~A)|0)>>4)+A|0;c[B>>2]=E;if((E|0)>=1){break}c[B>>2]=0;c[y>>2]=3}else if((z|0)==1){B=c[s>>2]|0;E=d[x+94|0]|0;if(((1<<E)-1&B|0)!=0){break}A=x+80|0;C=(c[A>>2]|0)+(d[52464+((d[x+95|0]|0)+(B>>>(E>>>0)&7))|0]|0)|0;c[A>>2]=C;if((C|0)<=1022){break}c[A>>2]=1023;c[y>>2]=0}else if((z|0)==2){A=c[s>>2]|0;C=d[x+92|0]|0;if(((1<<C)-1&A|0)!=0){break}E=x+80|0;B=(c[E>>2]|0)+(d[52464+((d[x+93|0]|0)+(A>>>(C>>>0)&7))|0]|0)|0;c[E>>2]=B;if((B|0)<=1022){break}c[E>>2]=1023;c[y>>2]=0}}while(0);y=o-1|0;if((y|0)==0){break}else{o=y;x=x+128|0}}x=c[u>>2]|0;o=c[v>>2]|0;if(x>>>0<o>>>0){p=m;q=m;r=m;break}else{w=u;h=x;n=o}}}gGz(9534192,0,32);mz(0);mz(1);mz(2);mz(3);mz(4);mz(5);mz(6);c[2161334]=0;c[2383568]=0;c[2383572]=0;c[2276110]=0;n=p+3616|0;c[c[p+3612>>2]>>2]=c[n>>2];h=c[p+3644>>2]|0;if((h|0)==0){F=0;G=p;H=q}else{F=c[r+4204>>2]<<h-1;G=r;H=r}h=(c[p+3664>>2]|0)+(c[p+3660>>2]|0)+(c[p+3648>>2]&F)|0;u=p+3628|0;w=p+3624|0;v=c[w>>2]|0;s=v+(c[u>>2]|0)|0;c[u>>2]=v;u=c[p+3608>>2]|0;if((u|0)==0){c[2383568]=v;c[2383572]=v;c[2161334]=v}else{c[u>>2]=v}c[w>>2]=0;if(h>>>0<832){v=c[p+3620>>2]|0;u=(c[8415080+((((((v|0)==0?0:s)<<v)+(c[p+3584>>2]&67043328)|0)>>>16&1023)<<2)>>2]|0)+(h<<3)|0;if(u>>>0>6655){I=0}else{I=c[8337240+(u<<2)>>2]|0}c[w>>2]=I}w=(c[p+3792>>2]|0)+(c[p+3788>>2]|0)+(c[p+3776>>2]&F)|0;if(w>>>0<832){u=(c[8415080+((((c[p+3712>>2]&67043328)+(c[2276110]<<15)|0)>>>16&1023)<<2)>>2]|0)+(w<<3)|0;if(u>>>0>6655){J=0}else{J=c[8337240+(u<<2)>>2]|0}u=c[p+3736>>2]|0;c[u>>2]=(c[u>>2]|0)+J}u=(c[p+3920>>2]|0)+(c[p+3916>>2]|0)+(c[p+3904>>2]&F)|0;if(u>>>0<832){w=(c[8415080+((((c[p+3840>>2]&67043328)+(c[2383572]<<15)|0)>>>16&1023)<<2)>>2]|0)+(u<<3)|0;if(w>>>0>6655){K=0}else{K=c[8337240+(w<<2)>>2]|0}w=c[p+3864>>2]|0;c[w>>2]=(c[w>>2]|0)+K}w=(c[p+4048>>2]|0)+(c[p+4044>>2]|0)+(c[p+4032>>2]&F)|0;do{if((c[G+4216>>2]&128|0)==0){if(w>>>0>=832){break}u=(c[8415080+((((c[p+3968>>2]&67043328)+(c[2383568]<<15)|0)>>>16&1023)<<2)>>2]|0)+(w<<3)|0;if(u>>>0>6655){L=0}else{L=c[8337240+(u<<2)>>2]|0}c[2383555]=(c[2383555]|0)+L}else{if(w>>>0<1023){M=w<<1^2046}else{M=0}c[2383555]=((c[G+4220>>2]&65536|0)!=0?M:-M|0)+(c[2383555]|0)}}while(0);c[n>>2]=c[2161334];w=c[2383548]|0;u=c[2383549]|0;h=c[2383550]|0;v=c[2383551]|0;s=c[2383552]|0;t=c[2383553]|0;o=c[2383554]|0;x=c[2383555]|0;y=(c[G+4104>>2]&u)+(c[G+4096>>2]&w)+(c[G+4112>>2]&h)+(c[G+4120>>2]&v)+(c[G+4128>>2]&s)+(c[G+4136>>2]&t)+(c[G+4144>>2]&o)+(c[G+4152>>2]&x)|0;z=(c[G+4108>>2]&u)+(c[G+4100>>2]&w)+(c[G+4116>>2]&h)+(c[G+4124>>2]&v)+(c[G+4132>>2]&s)+(c[G+4140>>2]&t)+(c[G+4148>>2]&o)+(c[G+4156>>2]&x)|0;if((y|0)>32767){N=32767}else{N=(y|0)<-32768?-32768:y&65535}if((z|0)>32767){O=32767}else{O=(z|0)<-32768?-32768:z&65535}b[f+(i<<1)>>1]=N;b[g+(i<<1)>>1]=O;do{if((a[G+4252|0]|0)==0){P=G;Q=H;R=r;S=m}else{z=G+4256|0;c[z>>2]=(c[z>>2]|0)-65536;z=r+4256|0;y=c[z>>2]|0;if((y|0)>=1){P=r;Q=r;R=r;S=m;break}c[z>>2]=(c[r+4264+(c[r+9384>>2]<<2)>>2]|0)+y;y=c[r+4236>>2]|0;do{if((y&4|0)==0){T=r;U=m;V=y}else{z=r+4240|0;x=c[z>>2]|0;c[z>>2]=x|1;if((x&3|0)!=0){T=r;U=m;V=y;break}x=c[r+44344>>2]|0;if((x|0)==0){T=r;U=m;V=y;break}gf[x&2047](1);x=c[3540880]|0;T=x;U=x;V=c[x+4236>>2]|0}}while(0);if((V&128|0)==0){P=T;Q=T;R=T;S=U;break}c[T+4232>>2]=2;P=T;Q=T;R=T;S=U}}while(0);do{if((a[P+4212|0]&2)==0){n=P+4180|0;y=(c[n>>2]|0)+(c[P+4184>>2]|0)|0;c[n>>2]=y;x=c[P+4188>>2]|0;if(y>>>0<x>>>0){W=c[P+4176>>2]|0;break}else{c[n>>2]=y-x;x=P+4192|0;y=(c[x>>2]|0)+(c[P+4196>>2]|0)|0;n=P+4176|0;z=(c[n>>2]|0)+(y>>>4)&255;c[n>>2]=z;c[x>>2]=y&15;W=z;break}}else{c[P+4176>>2]=0;W=0}}while(0);z=d[P+4200|0]|0;do{if((z|0)==2){y=W>>>0<128;x=W<<1;n=255-x|0;o=y?n:x-256|0;if(y){X=W>>>0<64?x:n;Y=o;break}if(W>>>0<192){X=256-x|0;Y=o;break}else{X=x-511|0;Y=o;break}}else if((z|0)==0){X=W>>>0<128?W:W-255|0;Y=255-W|0}else if((z|0)==1){o=W>>>0<128;X=o?128:-128;Y=o?255:0}else{o=d[44048+W|0]|0;X=o-128|0;Y=o}}while(0);c[P+4204>>2]=(ag(d[P+4201|0]|0,Y)|0)/128|0;c[P+4208>>2]=(ag(a[P+4202|0]|0,X)|0)/128|0;z=P+4224|0;o=(c[z>>2]|0)+(c[P+4228>>2]|0)|0;x=o>>>16;c[z>>2]=o&65535;if((x|0)==0){Z=P}else{o=x;x=P;while(1){z=x+4220|0;n=c[z>>2]|0;c[z>>2]=(n>>>3^n)<<16&65536^65536|n>>>1;n=o-1|0;if((n|0)==0){Z=Q;break}else{o=n;x=Q}}}x=Z|0;o=Z+4208|0;n=x;z=8;while(1){y=c[n+56>>2]|0;do{if((y|0)==0){t=n|0;c[t>>2]=(c[t>>2]|0)+(c[n+4>>2]|0);t=n+128|0;c[t>>2]=(c[t>>2]|0)+(c[n+132>>2]|0);t=n+256|0;c[t>>2]=(c[t>>2]|0)+(c[n+260>>2]|0);t=n+384|0;c[t>>2]=(c[t>>2]|0)+(c[n+388>>2]|0)}else{t=c[o>>2]|0;if(y>>>0<6){_=t>>6-y}else{_=t<<y-5}if((_|0)==0){t=n|0;c[t>>2]=(c[t>>2]|0)+(c[n+4>>2]|0);t=n+128|0;c[t>>2]=(c[t>>2]|0)+(c[n+132>>2]|0);t=n+256|0;c[t>>2]=(c[t>>2]|0)+(c[n+260>>2]|0);t=n+384|0;c[t>>2]=(c[t>>2]|0)+(c[n+388>>2]|0);break}else{t=(c[n+52>>2]|0)+_|0;s=(ag((c[n+8>>2]|0)+(c[Z+9400+(t+(c[n+20>>2]|0)<<2)>>2]|0)|0,c[n+12>>2]|0)|0)>>>1;v=n|0;c[v>>2]=s+(c[v>>2]|0);v=(ag((c[n+136>>2]|0)+(c[Z+9400+((c[n+148>>2]|0)+t<<2)>>2]|0)|0,c[n+140>>2]|0)|0)>>>1;s=n+128|0;c[s>>2]=v+(c[s>>2]|0);s=(ag((c[n+264>>2]|0)+(c[Z+9400+((c[n+276>>2]|0)+t<<2)>>2]|0)|0,c[n+268>>2]|0)|0)>>>1;v=n+256|0;c[v>>2]=s+(c[v>>2]|0);v=(ag((c[n+392>>2]|0)+(c[Z+9400+((c[n+404>>2]|0)+t<<2)>>2]|0)|0,c[n+396>>2]|0)|0)>>>1;t=n+384|0;c[t>>2]=v+(c[t>>2]|0);break}}}while(0);y=z-1|0;if((y|0)==0){break}else{n=n+512|0;z=y}}z=Z+4232|0;n=c[z>>2]|0;if((n|0)==2){o=Z+4160|0;y=x;t=32;while(1){v=y+96|0;s=c[v>>2]|0;do{if((s|0)==0){c[y>>2]=0;h=y+68|0;c[h>>2]=4;w=y+80|0;u=c[w>>2]|0;E=((ag(d[52464+(((c[o>>2]|0)>>>((d[y+72|0]|0)>>>0)&7)+(d[y+73|0]|0))|0]|0,~u)|0)>>4)+u|0;c[w>>2]=E;if((E|0)>=1){break}c[w>>2]=0;c[h>>2]=3}}while(0);c[v>>2]=s|2;h=t-1|0;if((h|0)==0){break}else{y=y+128|0;t=h}}c[z>>2]=1}else if((n|0)!=0){t=x;y=32;while(1){o=t+96|0;h=c[o>>2]|0;do{if((h|0)!=0){w=h&-3;c[o>>2]=w;if((w|0)!=0){break}w=t+68|0;if((c[w>>2]|0)>>>0<=1){break}c[w>>2]=1}}while(0);o=y-1|0;if((o|0)==0){break}else{t=t+128|0;y=o}}c[z>>2]=0}y=i+1|0;if((y|0)<(e|0)){i=y;j=Z;k=Q;l=R;m=S}else{break}}return}function mz(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;c[2161334]=0;c[2383568]=0;c[2383572]=0;c[2276110]=0;b=a<<2;d=c[3540880]|0;e=d+(b<<7)+32|0;c[c[d+(b<<7)+28>>2]>>2]=c[e>>2];f=c[d+(b<<7)+60>>2]|0;if((f|0)==0){g=0}else{g=c[d+4204>>2]<<f-1}f=(c[d+(b<<7)+80>>2]|0)+(c[d+(b<<7)+76>>2]|0)+(c[d+(b<<7)+64>>2]&g)|0;h=d+(b<<7)+44|0;i=d+(b<<7)+40|0;j=c[i>>2]|0;k=j+(c[h>>2]|0)|0;c[h>>2]=j;h=c[d+(b<<7)+24>>2]|0;if((h|0)==0){c[2383568]=j;c[2383572]=j;c[2161334]=j}else{c[h>>2]=j}c[i>>2]=0;if(f>>>0<832){j=c[d+(b<<7)+36>>2]|0;h=(c[8415080+((((((j|0)==0?0:k)<<j)+(c[d+(b<<7)>>2]&67043328)|0)>>>16&1023)<<2)>>2]|0)+(f<<3)|0;if(h>>>0>6655){l=0}else{l=c[8337240+(h<<2)>>2]|0}c[i>>2]=l}l=b|1;i=(c[d+(l<<7)+80>>2]|0)+(c[d+(l<<7)+76>>2]|0)+(c[d+(l<<7)+64>>2]&g)|0;if(i>>>0<832){h=(c[8415080+((((c[d+(l<<7)>>2]&67043328)+(c[2276110]<<15)|0)>>>16&1023)<<2)>>2]|0)+(i<<3)|0;if(h>>>0>6655){m=0}else{m=c[8337240+(h<<2)>>2]|0}h=c[d+(l<<7)+24>>2]|0;c[h>>2]=(c[h>>2]|0)+m}m=b|2;h=(c[d+(m<<7)+80>>2]|0)+(c[d+(m<<7)+76>>2]|0)+(c[d+(m<<7)+64>>2]&g)|0;if(h>>>0<832){l=(c[8415080+((((c[d+(m<<7)>>2]&67043328)+(c[2383572]<<15)|0)>>>16&1023)<<2)>>2]|0)+(h<<3)|0;if(l>>>0>6655){n=0}else{n=c[8337240+(l<<2)>>2]|0}l=c[d+(m<<7)+24>>2]|0;c[l>>2]=(c[l>>2]|0)+n}n=b|3;b=(c[d+(n<<7)+80>>2]|0)+(c[d+(n<<7)+76>>2]|0)+(c[d+(n<<7)+64>>2]&g)|0;if(b>>>0>=832){o=c[2161334]|0;c[e>>2]=o;return}g=(c[8415080+((((c[d+(n<<7)>>2]&67043328)+(c[2383568]<<15)|0)>>>16&1023)<<2)>>2]|0)+(b<<3)|0;if(g>>>0>6655){p=0}else{p=c[8337240+(g<<2)>>2]|0}g=9534192+(a<<2)|0;c[g>>2]=(c[g>>2]|0)+p;o=c[2161334]|0;c[e>>2]=o;return}function mA(e,f,g,h,i){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0;j=14168923+(e*252|0)|0;k=a[j]|0;do{if((k&1)==0){if((a[14168924+(e*252|0)|0]|0)!=0){break}l=14168960+(e*252|0)|0;m=c[l>>2]|0;n=i<<15;if((m|0)>(n|0)){break}c[l>>2]=m+n}else{n=14168960+(e*252|0)|0;m=c[n>>2]|0;l=i<<15;if((m|0)<=(l|0)){c[n>>2]=m+l}a[14168999+(e*252|0)|0]=1}}while(0);do{if((k&2)==0){if((a[14168925+(e*252|0)|0]|0)!=0){break}l=14168964+(e*252|0)|0;m=c[l>>2]|0;n=i<<15;if((m|0)>(n|0)){break}c[l>>2]=m+n}else{n=14168964+(e*252|0)|0;m=c[n>>2]|0;l=i<<15;if((m|0)<=(l|0)){c[n>>2]=m+l}a[14169e3+(e*252|0)|0]=1}}while(0);do{if((k&4)==0){if((a[14168926+(e*252|0)|0]|0)!=0){break}l=14168968+(e*252|0)|0;m=c[l>>2]|0;n=i<<15;if((m|0)>(n|0)){break}c[l>>2]=m+n}else{n=14168968+(e*252|0)|0;m=c[n>>2]|0;l=i<<15;if((m|0)<=(l|0)){c[n>>2]=m+l}a[14169001+(e*252|0)|0]=1}}while(0);do{if((k&56)==56){l=14168972+(e*252|0)|0;m=c[l>>2]|0;n=i<<15;if((m|0)>(n|0)){break}c[l>>2]=m+n}}while(0);n=14169002+(e*252|0)|0;if((i|0)==0){return}m=14168972+(e*252|0)|0;l=14168960+(e*252|0)|0;o=14168940+(e*252|0)|0;p=14168999+(e*252|0)|0;q=14168964+(e*252|0)|0;r=14168944+(e*252|0)|0;s=14169e3+(e*252|0)|0;t=14168968+(e*252|0)|0;u=14168948+(e*252|0)|0;v=14169001+(e*252|0)|0;w=14169008+(e*252|0)|0;x=14168952+(e*252|0)|0;y=14169007+(e*252|0)|0;z=14168976+(e*252|0)|0;A=14169003+(e*252|0)|0;B=14168956+(e*252|0)|0;C=14169004+(e*252|0)|0;D=14169005+(e*252|0)|0;E=14169006+(e*252|0)|0;F=14168992+(e*252|0)|0;G=14168996+(e*252|0)|0;H=14168997+(e*252|0)|0;I=14168998+(e*252|0)|0;J=14168988+(e*252|0)|0;K=14168984+(e*252|0)|0;L=14168980+(e*252|0)|0;M=i;i=f;f=g;g=h;h=(a[n]|k)&255;while(1){k=32768;N=0;O=0;P=0;Q=h;R=c[m>>2]|0;while(1){S=(R|0)<(k|0)?R:k;do{if((Q&8|0)==0){T=(c[l>>2]|0)-S|0;c[l>>2]=T;if((T|0)>=1){U=P;break}V=c[o>>2]|0;W=T;while(1){X=W+V|0;if((X|0)>0){Y=13203;break}Z=X+V|0;if((Z|0)<1){W=Z}else{Y=13205;break}}if((Y|0)==13203){Y=0;c[l>>2]=X;a[p]=a[p]^1;U=P;break}else if((Y|0)==13205){Y=0;c[l>>2]=Z;U=P;break}}else{W=a[p]|0;V=c[l>>2]|0;T=(W<<24>>24==0?0:V)+P|0;_=V-S|0;c[l>>2]=_;do{if((_|0)<1){V=c[o>>2]|0;$=_;aa=T;while(1){ab=$+V|0;if((ab|0)>0){Y=13195;break}ac=ab+V|0;ad=aa+V|0;if((ac|0)<1){$=ac;aa=ad}else{Y=13197;break}}if((Y|0)==13195){Y=0;c[l>>2]=ab;$=W^1;a[p]=$;ae=aa+(W<<24>>24==1?0:V)|0;af=$;ah=ab;break}else if((Y|0)==13197){Y=0;c[l>>2]=ac;ae=ad;af=W;ah=ac;break}}else{ae=T;af=W;ah=_}}while(0);if(af<<24>>24==0){U=ae;break}U=ae-ah|0}}while(0);do{if((Q&16|0)==0){_=(c[q>>2]|0)-S|0;c[q>>2]=_;if((_|0)>=1){ai=O;break}W=c[r>>2]|0;T=_;while(1){aj=T+W|0;if((aj|0)>0){Y=13218;break}ak=aj+W|0;if((ak|0)<1){T=ak}else{Y=13220;break}}if((Y|0)==13218){Y=0;c[q>>2]=aj;a[s]=a[s]^1;ai=O;break}else if((Y|0)==13220){Y=0;c[q>>2]=ak;ai=O;break}}else{T=a[s]|0;W=c[q>>2]|0;_=(T<<24>>24==0?0:W)+O|0;$=W-S|0;c[q>>2]=$;do{if(($|0)<1){W=c[r>>2]|0;al=$;am=_;while(1){an=al+W|0;if((an|0)>0){Y=13210;break}ao=an+W|0;ap=am+W|0;if((ao|0)<1){al=ao;am=ap}else{Y=13212;break}}if((Y|0)==13212){Y=0;c[q>>2]=ao;aq=ap;ar=T;as=ao;break}else if((Y|0)==13210){Y=0;c[q>>2]=an;al=T^1;a[s]=al;aq=am+(T<<24>>24==1?0:W)|0;ar=al;as=an;break}}else{aq=_;ar=T;as=$}}while(0);if(ar<<24>>24==0){ai=aq;break}ai=aq-as|0}}while(0);do{if((Q&32|0)==0){$=(c[t>>2]|0)-S|0;c[t>>2]=$;if(($|0)>=1){at=N;break}T=c[u>>2]|0;_=$;while(1){au=_+T|0;if((au|0)>0){Y=13233;break}av=au+T|0;if((av|0)<1){_=av}else{Y=13235;break}}if((Y|0)==13233){Y=0;c[t>>2]=au;a[v]=a[v]^1;at=N;break}else if((Y|0)==13235){Y=0;c[t>>2]=av;at=N;break}}else{_=a[v]|0;T=c[t>>2]|0;$=(_<<24>>24==0?0:T)+N|0;al=T-S|0;c[t>>2]=al;do{if((al|0)<1){T=c[u>>2]|0;V=al;aa=$;while(1){aw=V+T|0;if((aw|0)>0){Y=13225;break}ax=aw+T|0;ay=aa+T|0;if((ax|0)<1){V=ax;aa=ay}else{Y=13227;break}}if((Y|0)==13225){Y=0;c[t>>2]=aw;V=_^1;a[v]=V;az=aa+(_<<24>>24==1?0:T)|0;aA=V;aB=aw;break}else if((Y|0)==13227){Y=0;c[t>>2]=ax;az=ay;aA=_;aB=ax;break}}else{az=$;aA=_;aB=al}}while(0);if(aA<<24>>24==0){at=az;break}at=az-aB|0}}while(0);al=R-S|0;if((al|0)<1){_=c[w>>2]|0;if((_+1&2|0)==0){aC=Q}else{$=~a[n];a[n]=$;aC=(a[j]|$)&255}if((_&1|0)==0){aD=_}else{$=_^147456;c[w>>2]=$;aD=$}c[w>>2]=aD>>1;aE=aC;aF=(c[x>>2]|0)+al|0}else{aE=Q;aF=al}al=k-S|0;if((al|0)>0){k=al;N=at;O=ai;P=U;Q=aE;R=aF}else{break}}c[m>>2]=aF;do{if((a[y]|0)==0){R=(c[z>>2]|0)-32768|0;c[z>>2]=R;if((R|0)>=1){break}Q=c[B>>2]|0;P=a[A]|0;O=R;do{P=P-1&255;O=O+Q|0;}while((O|0)<1);a[A]=P;c[z>>2]=O;do{if(P<<24>>24<0){Q=(a[D]|0)==0;if((a[C]|0)!=0){if(!Q){a[E]=a[E]^31}a[y]=1;a[A]=0;aG=0;break}do{if(!Q){if((P&32)==0){break}a[E]=a[E]^31}}while(0);Q=P&31;a[A]=Q;aG=Q}else{aG=P}}while(0);P=c[14169012+(e*252|0)+((d[E]^aG<<24>>24)<<2)>>2]|0;c[F>>2]=P;if((a[G]|0)!=0){c[L>>2]=P}if((a[H]|0)!=0){c[K>>2]=P}if((a[I]|0)==0){break}c[J>>2]=P}}while(0);b[i>>1]=(ag(c[L>>2]|0,U)|0)>>>15&65535;b[f>>1]=(ag(c[K>>2]|0,ai)|0)>>>15&65535;b[g>>1]=(ag(c[J>>2]|0,at)|0)>>>15&65535;P=M-1|0;if((P|0)==0){break}M=P;i=i+2|0;f=f+2|0;g=g+2|0;h=aE}return}function mB(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c[14168912+(b*252|0)>>2]=0;c[14169008+(b*252|0)>>2]=1;a[14168999+(b*252|0)|0]=0;a[14169e3+(b*252|0)|0]=0;a[14169001+(b*252|0)|0]=0;a[14169002+(b*252|0)|0]=-1;c[14168932+(b*252|0)>>2]=-1;a[14168916+(b*252|0)|0]=0;e=14168917+(b*252|0)|0;f=14168940+(b*252|0)|0;g=c[f>>2]|0;h=14168936+(b*252|0)|0;i=c[h>>2]|0;j=ag((a[e]&15)<<8,i)|0;k=(j|0)==0?i:j;j=14168960+(b*252|0)|0;l=k-g+(c[j>>2]|0)|0;a[e]=0;c[f>>2]=i;f=i-k+((l|0)<1?1:l)|0;c[j>>2]=(f|0)<1?1:f;a[14168918+(b*252|0)|0]=0;f=14168919+(b*252|0)|0;j=14168944+(b*252|0)|0;l=c[j>>2]|0;k=ag((a[f]&15)<<8,i)|0;e=(k|0)==0?i:k;k=14168964+(b*252|0)|0;g=e-l+(c[k>>2]|0)|0;a[f]=0;c[j>>2]=i;j=i-e+((g|0)<1?1:g)|0;c[k>>2]=(j|0)<1?1:j;a[14168920+(b*252|0)|0]=0;j=14168921+(b*252|0)|0;k=14168948+(b*252|0)|0;g=c[k>>2]|0;e=ag((a[j]&15)<<8,i)|0;f=(e|0)==0?i:e;e=14168968+(b*252|0)|0;l=f-g+(c[e>>2]|0)|0;a[j]=0;c[k>>2]=i;k=i-f+((l|0)<1?1:l)|0;c[e>>2]=(k|0)<1?1:k;a[14168922+(b*252|0)|0]=0;k=14168952+(b*252|0)|0;e=c[k>>2]|0;c[k>>2]=i;k=14168972+(b*252|0)|0;l=i-e+(c[k>>2]|0)|0;c[k>>2]=(l|0)<1?1:l;mC(b,7,0);a[14168924+(b*252|0)|0]=0;a[14168996+(b*252|0)|0]=0;l=c[14169012+(b*252|0)>>2]|0;c[14168980+(b*252|0)>>2]=l;a[14168925+(b*252|0)|0]=0;a[14168997+(b*252|0)|0]=0;c[14168984+(b*252|0)>>2]=l;a[14168926+(b*252|0)|0]=0;a[14168998+(b*252|0)|0]=0;c[14168988+(b*252|0)>>2]=l;a[14168927+(b*252|0)|0]=0;l=14168956+(b*252|0)|0;k=c[l>>2]|0;e=14168928+(b*252|0)|0;i=c[h>>2]|0;h=ag((d[e]|0)<<8,i)|0;f=i>>>1;i=(h|0)==0?f:h;h=14168976+(b*252|0)|0;j=i-k+(c[h>>2]|0)|0;a[e]=0;c[l>>2]=f;l=f-i+((j|0)<1?1:j)|0;c[h>>2]=(l|0)<1?1:l;mC(b,13,0);return}function mC(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;a[14168916+(b*252|0)+e|0]=f&255;switch(e|0){case 13:{e=14168929+(b*252|0)|0;f=a[e]|0;a[e]=f&15;e=(f&4)!=0?31:0;a[14169006+(b*252|0)|0]=e;if((f&8)==0){a[14169004+(b*252|0)|0]=1;a[14169005+(b*252|0)|0]=e}else{a[14169004+(b*252|0)|0]=f&1;a[14169005+(b*252|0)|0]=f&2}c[14168976+(b*252|0)>>2]=c[14168956+(b*252|0)>>2];a[14169003+(b*252|0)|0]=31;a[14169007+(b*252|0)|0]=0;f=c[14169012+(b*252|0)+((e&255^31)<<2)>>2]|0;c[14168992+(b*252|0)>>2]=f;if((a[14168996+(b*252|0)|0]|0)!=0){c[14168980+(b*252|0)>>2]=f}if((a[14168997+(b*252|0)|0]|0)!=0){c[14168984+(b*252|0)>>2]=f}if((a[14168998+(b*252|0)|0]|0)==0){return}c[14168988+(b*252|0)>>2]=f;return};case 14:{if((a[14168923+(b*252|0)|0]&64)==0){return}f=c[14168904+(b*252|0)>>2]|0;if((f|0)==0){return}gg[f&4095](0,d[14168930+(b*252|0)|0]|0);return};case 6:{f=14168922+(b*252|0)|0;e=a[f]&31;a[f]=e;f=14168952+(b*252|0)|0;g=c[f>>2]|0;h=c[14168936+(b*252|0)>>2]|0;i=ag(e&255,h)|0;e=(i|0)==0?h:i;c[f>>2]=e;f=14168972+(b*252|0)|0;i=e-g+(c[f>>2]|0)|0;c[f>>2]=i;if((i|0)>=1){return}c[f>>2]=1;return};case 10:{f=14168926+(b*252|0)|0;i=a[f]|0;g=i&31;a[f]=g;f=i&16;a[14168998+(b*252|0)|0]=f;if(f<<24>>24==0){if(g<<24>>24==0){j=0}else{j=(g&255)<<1|1}k=14169012+(b*252|0)+(j<<2)|0}else{k=14168992+(b*252|0)|0}c[14168988+(b*252|0)>>2]=c[k>>2];return};case 15:{if((a[14168923+(b*252|0)|0]|0)>=0){return}k=c[14168908+(b*252|0)>>2]|0;if((k|0)==0){return}gg[k&4095](0,d[14168931+(b*252|0)|0]|0);return};case 9:{k=14168925+(b*252|0)|0;j=a[k]|0;g=j&31;a[k]=g;k=j&16;a[14168997+(b*252|0)|0]=k;if(k<<24>>24==0){if(g<<24>>24==0){l=0}else{l=(g&255)<<1|1}m=14169012+(b*252|0)+(l<<2)|0}else{m=14168992+(b*252|0)|0}c[14168984+(b*252|0)>>2]=c[m>>2];return};case 7:{m=14168932+(b*252|0)|0;l=c[m>>2]|0;if((l|0)==-1){n=13279}else{g=a[14168923+(b*252|0)|0]|0;if(((g&255^l)&64|0)==0){o=l;p=g;n=13285}else{n=13279}}do{if((n|0)==13279){g=c[14168904+(b*252|0)>>2]|0;k=14168923+(b*252|0)|0;if((g|0)==0){q=l;r=k}else{if((a[k]&64)==0){s=255}else{s=d[14168930+(b*252|0)|0]|0}gg[g&4095](0,s);q=c[m>>2]|0;r=k}if((q|0)==-1){t=r;n=13286;break}o=q;p=a[r]|0;n=13285}}while(0);if((n|0)==13285){r=14168923+(b*252|0)|0;if(((p&255^o)&128|0)==0){u=r}else{t=r;n=13286}}do{if((n|0)==13286){r=c[14168908+(b*252|0)>>2]|0;if((r|0)==0){u=t;break}if((a[t]|0)<0){v=d[14168931+(b*252|0)|0]|0}else{v=255}gg[r&4095](0,v);u=t}}while(0);c[m>>2]=d[u]|0;return};case 2:case 3:{u=14168919+(b*252|0)|0;m=a[u]&15;a[u]=m;u=14168944+(b*252|0)|0;t=c[u>>2]|0;v=c[14168936+(b*252|0)>>2]|0;n=ag(d[14168918+(b*252|0)|0]|(m&255)<<8,v)|0;m=(n|0)==0?v:n;c[u>>2]=m;u=14168964+(b*252|0)|0;n=m-t+(c[u>>2]|0)|0;c[u>>2]=n;if((n|0)>=1){return}c[u>>2]=1;return};case 11:case 12:{u=14168956+(b*252|0)|0;n=c[u>>2]|0;t=c[14168936+(b*252|0)>>2]|0;m=ag(d[14168928+(b*252|0)|0]<<8|d[14168927+(b*252|0)|0],t)|0;v=(m|0)==0?t>>>1:m;c[u>>2]=v;u=14168976+(b*252|0)|0;m=v-n+(c[u>>2]|0)|0;c[u>>2]=m;if((m|0)>=1){return}c[u>>2]=1;return};case 0:case 1:{u=14168917+(b*252|0)|0;m=a[u]&15;a[u]=m;u=14168940+(b*252|0)|0;n=c[u>>2]|0;v=c[14168936+(b*252|0)>>2]|0;t=ag(d[14168916+(b*252|0)|0]|(m&255)<<8,v)|0;m=(t|0)==0?v:t;c[u>>2]=m;u=14168960+(b*252|0)|0;t=m-n+(c[u>>2]|0)|0;c[u>>2]=t;if((t|0)>=1){return}c[u>>2]=1;return};case 8:{u=14168924+(b*252|0)|0;t=a[u]|0;n=t&31;a[u]=n;u=t&16;a[14168996+(b*252|0)|0]=u;if(u<<24>>24==0){if(n<<24>>24==0){w=0}else{w=(n&255)<<1|1}x=14169012+(b*252|0)+(w<<2)|0}else{x=14168992+(b*252|0)|0}c[14168980+(b*252|0)>>2]=c[x>>2];return};case 4:case 5:{x=14168921+(b*252|0)|0;w=a[x]&15;a[x]=w;x=14168948+(b*252|0)|0;n=c[x>>2]|0;u=c[14168936+(b*252|0)>>2]|0;t=ag(d[14168920+(b*252|0)|0]|(w&255)<<8,u)|0;w=(t|0)==0?u:t;c[x>>2]=w;x=14168968+(b*252|0)|0;b=w-n+(c[x>>2]|0)|0;c[x>>2]=b;if((b|0)>=1){return}c[x>>2]=1;return};default:{return}}}function mD(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0.0,g=0;c[3542220]=11200;if((c[2113008]|0)!=(a|0)){e=1;return e|0}gGz(14168888+(a*252|0)|0,0,252);c[14168892+(a*252|0)>>2]=d;gGz(14168896+(a*252|0)|0,0,16);c[14168936+(a*252|0)>>2]=~~((+(d|0)*32768.0*8.0+ +((b|0)/2|0|0))/+(b|0));b=31;f=32767.0;while(1){c[14169012+(a*252|0)+(b<<2)>>2]=~~(f+.5);d=b-1|0;if((d|0)>0){b=d;f=f/1.188502227}else{break}}c[14169012+(a*252|0)>>2]=0;b=a*3|0;h[14170152+(b<<3)>>3]=1.0;d=b+1|0;h[14170152+(d<<3)>>3]=1.0;g=b+2|0;h[14170152+(g<<3)>>3]=1.0;c[14170296+(b<<2)>>2]=3;c[14170296+(d<<2)>>2]=3;c[14170296+(g<<2)>>2]=3;mB(a);c[2113008]=(c[2113008]|0)+1;e=0;return e|0}function mE(){return}function mF(a,d,f,g){a=a|0;d=d|0;f=f|0;g=g|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0.0,ao=0.0,ap=0.0,aq=0.0,ar=0.0,as=0.0,at=0.0,au=0.0,av=0.0,aw=0.0,ax=0.0,ay=0.0,az=0.0,aA=0.0,aB=0.0,aC=0.0,aD=0.0,aE=0.0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0;i=c[a>>2]|0;j=c[a+4>>2]|0;k=c[a+8>>2]|0;l=c[2113008]|0;do{if((l|0)>0){m=0;do{n=m*3|0;mA(m,c[a+(n<<2)>>2]|0,c[a+(n+1<<2)>>2]|0,c[a+(n+2<<2)>>2]|0,f);m=m+1|0;}while((m|0)<(l|0));if((l|0)<=1){o=0;p=0;q=0;r=0;s=0;t=0;u=0;v=0;w=0;x=0;y=0;z=0;A=0;B=0;C=0;break}m=c[a+12>>2]|0;n=c[a+16>>2]|0;D=c[a+20>>2]|0;if((l|0)<=2){o=0;p=0;q=0;r=D;s=n;t=m;u=0;v=0;w=0;x=0;y=0;z=0;A=0;B=0;C=0;break}E=c[a+24>>2]|0;F=c[a+28>>2]|0;G=c[a+32>>2]|0;if((l|0)<=3){o=0;p=0;q=0;r=D;s=n;t=m;u=0;v=0;w=0;x=E;y=F;z=G;A=0;B=0;C=0;break}H=c[a+36>>2]|0;I=c[a+40>>2]|0;J=c[a+44>>2]|0;if((l|0)<=4){o=0;p=0;q=0;r=D;s=n;t=m;u=J;v=I;w=H;x=E;y=F;z=G;A=0;B=0;C=0;break}K=c[a+48>>2]|0;L=c[a+52>>2]|0;M=c[a+56>>2]|0;if((l|0)<=5){o=0;p=0;q=0;r=D;s=n;t=m;u=J;v=I;w=H;x=E;y=F;z=G;A=K;B=L;C=M;break}o=c[a+68>>2]|0;p=c[a+64>>2]|0;q=c[a+60>>2]|0;r=D;s=n;t=m;u=J;v=I;w=H;x=E;y=F;z=G;A=K;B=L;C=M}else{o=0;p=0;q=0;r=0;s=0;t=0;u=0;v=0;w=0;x=0;y=0;z=0;A=0;B=0;C=0}}while(0);if((f|0)<=0){return}a=(g|0)==0;g=c[3542574]|0;M=(g&1|0)==0;L=(g&2|0)==0;g=c[3542575]|0;K=(g&1|0)==0;G=(g&2|0)==0;g=c[3542576]|0;F=(g&1|0)==0;E=(g&2|0)==0;g=(l|0)>1;H=c[3542577]|0;I=(H&1|0)==0;J=(H&2|0)==0;H=c[3542578]|0;m=(H&1|0)==0;n=(H&2|0)==0;H=c[3542579]|0;D=(H&1|0)==0;N=(H&2|0)==0;H=(l|0)>2;O=c[3542580]|0;P=(O&1|0)==0;Q=(O&2|0)==0;O=c[3542581]|0;R=(O&1|0)==0;S=(O&2|0)==0;O=c[3542582]|0;T=(O&1|0)==0;U=(O&2|0)==0;O=(l|0)>3;V=c[3542583]|0;W=(V&1|0)==0;X=(V&2|0)==0;V=c[3542584]|0;Y=(V&1|0)==0;Z=(V&2|0)==0;V=c[3542585]|0;_=(V&1|0)==0;$=(V&2|0)==0;V=(l|0)>4;aa=c[3542586]|0;ab=(aa&1|0)==0;ac=(aa&2|0)==0;aa=c[3542587]|0;ad=(aa&1|0)==0;ae=(aa&2|0)==0;aa=c[3542588]|0;af=(aa&1|0)==0;ag=(aa&2|0)==0;aa=(l|0)>5;l=c[3542589]|0;ah=(l&1|0)==0;ai=(l&2|0)==0;l=c[3542590]|0;aj=(l&1|0)==0;ak=(l&2|0)==0;l=c[3542591]|0;al=(l&1|0)==0;am=(l&2|0)==0;an=+h[1771286];ao=+h[1771285];ap=+h[1771284];aq=+h[1771283];ar=+h[1771282];as=+h[1771281];at=+h[1771280];au=+h[1771279];av=+h[1771278];aw=+h[1771277];ax=+h[1771276];ay=+h[1771275];az=+h[1771274];aA=+h[1771273];aB=+h[1771272];aC=+h[1771271];aD=+h[1771270];aE=+h[1771269];l=0;do{if(M){aF=0}else{aF=~~(+(b[i+(l<<1)>>1]|0)*aE)}if(L){aG=0}else{aG=~~(+(b[i+(l<<1)>>1]|0)*aE)}if(K){aH=aF}else{aH=~~(+(b[j+(l<<1)>>1]|0)*aD)+aF|0}if(G){aI=aG}else{aI=~~(+(b[j+(l<<1)>>1]|0)*aD)+aG|0}if(F){aJ=aH}else{aJ=~~(+(b[k+(l<<1)>>1]|0)*aC)+aH|0}if(E){aK=aI}else{aK=~~(+(b[k+(l<<1)>>1]|0)*aC)+aI|0}do{if(g){if(I){aL=aJ}else{aL=~~(+(b[t+(l<<1)>>1]|0)*aB)+aJ|0}if(J){aM=aK}else{aM=~~(+(b[t+(l<<1)>>1]|0)*aB)+aK|0}if(m){aN=aL}else{aN=~~(+(b[s+(l<<1)>>1]|0)*aA)+aL|0}if(n){aO=aM}else{aO=~~(+(b[s+(l<<1)>>1]|0)*aA)+aM|0}if(D){aP=aN}else{aP=~~(+(b[r+(l<<1)>>1]|0)*az)+aN|0}if(N){aQ=aO}else{aQ=~~(+(b[r+(l<<1)>>1]|0)*az)+aO|0}if(!H){aR=aQ;aS=aP;break}if(P){aT=aP}else{aT=~~(+(b[x+(l<<1)>>1]|0)*ay)+aP|0}if(Q){aU=aQ}else{aU=~~(+(b[x+(l<<1)>>1]|0)*ay)+aQ|0}if(R){aV=aT}else{aV=~~(+(b[y+(l<<1)>>1]|0)*ax)+aT|0}if(S){aW=aU}else{aW=~~(+(b[y+(l<<1)>>1]|0)*ax)+aU|0}if(T){aX=aV}else{aX=~~(+(b[z+(l<<1)>>1]|0)*aw)+aV|0}if(U){aY=aW}else{aY=~~(+(b[z+(l<<1)>>1]|0)*aw)+aW|0}if(!O){aR=aY;aS=aX;break}if(W){aZ=aX}else{aZ=~~(+(b[w+(l<<1)>>1]|0)*av)+aX|0}if(X){a_=aY}else{a_=~~(+(b[w+(l<<1)>>1]|0)*av)+aY|0}if(Y){a$=aZ}else{a$=~~(+(b[v+(l<<1)>>1]|0)*au)+aZ|0}if(Z){a0=a_}else{a0=~~(+(b[v+(l<<1)>>1]|0)*au)+a_|0}if(_){a1=a$}else{a1=~~(+(b[u+(l<<1)>>1]|0)*at)+a$|0}if($){a2=a0}else{a2=~~(+(b[u+(l<<1)>>1]|0)*at)+a0|0}if(!V){aR=a2;aS=a1;break}if(ab){a3=a1}else{a3=~~(+(b[A+(l<<1)>>1]|0)*as)+a1|0}if(ac){a4=a2}else{a4=~~(+(b[A+(l<<1)>>1]|0)*as)+a2|0}if(ad){a5=a3}else{a5=~~(+(b[B+(l<<1)>>1]|0)*ar)+a3|0}if(ae){a6=a4}else{a6=~~(+(b[B+(l<<1)>>1]|0)*ar)+a4|0}if(af){a7=a5}else{a7=~~(+(b[C+(l<<1)>>1]|0)*aq)+a5|0}if(ag){a8=a6}else{a8=~~(+(b[C+(l<<1)>>1]|0)*aq)+a6|0}if(!aa){aR=a8;aS=a7;break}if(ah){a9=a7}else{a9=~~(+(b[q+(l<<1)>>1]|0)*ap)+a7|0}if(ai){ba=a8}else{ba=~~(+(b[q+(l<<1)>>1]|0)*ap)+a8|0}if(aj){bb=a9}else{bb=~~(+(b[p+(l<<1)>>1]|0)*ao)+a9|0}if(ak){bc=ba}else{bc=~~(+(b[p+(l<<1)>>1]|0)*ao)+ba|0}if(al){bd=bb}else{bd=~~(+(b[o+(l<<1)>>1]|0)*an)+bb|0}if(am){aR=bc;aS=bd;break}aR=~~(+(b[o+(l<<1)>>1]|0)*an)+bc|0;aS=bd}else{aR=aK;aS=aJ}}while(0);if((aS|0)<-32768){be=-32768}else{be=(aS|0)>32767?32767:aS}if((aR|0)<-32768){bf=-32768}else{bf=(aR|0)>32767?32767:aR}if(a){bg=l<<1;b[d+(bg<<1)>>1]=be&65535;b[d+((bg|1)<<1)>>1]=bf&65535}else{bg=l<<1;bh=d+(bg<<1)|0;b[bh>>1]=(e[bh>>1]|0)+be&65535;bh=d+((bg|1)<<1)|0;b[bh>>1]=(e[bh>>1]|0)+bf&65535}l=l+1|0;}while((l|0)<(f|0));return}function mG(){c[2276056]=(c[2276056]|0)+2;return}function mH(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=9104156+((c[2276069]&7)<<2)|0;b=c[a>>2]|0;e=b+65535&65535;c[a>>2]=e|b&-65536;b=c[2276056]|0;if((e|0)==65535){f=b+2|0;c[2276056]=f;return}e=b&-4;if((e|0)==(c[2276083]|0)){g=b;h=c[2276084]|0}else{c[2276083]=e;a=c[2276085]&e;e=a&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=a&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;g=m;h=l}f=(h>>>((g<<3&16^16)>>>0)<<16>>16)+g|0;c[2276056]=f;return}function mI(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if((c[2276078]&256|0)==0&(c[2276076]|0)!=0){c[2276056]=(c[2276056]|0)+2;return}a=9104156+((c[2276069]&7)<<2)|0;b=c[a>>2]|0;e=b+65535&65535;c[a>>2]=e|b&-65536;b=c[2276056]|0;if((e|0)==65535){c[2276056]=b+2;c[2276108]=(c[2276108]|0)-(c[2276092]|0);return}e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;a=c[2276085]&e;e=a&16777212;h=c[2112932]|0;i=c[h+((e>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=a&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=b}else{b=gj[c[h+196768+(i<<2)>>2]&4095](e)|0;k=b;l=c[2276056]|0}c[2276084]=k;f=l;g=k}c[2276056]=(g>>>((f<<3&16^16)>>>0)<<16>>16)+f;c[2276108]=(c[2276108]|0)-(c[2276091]|0);return}function mJ(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if(!((c[2276078]&256|0)==0&(c[2276076]|0)!=0)){c[2276056]=(c[2276056]|0)+2;return}a=9104156+((c[2276069]&7)<<2)|0;b=c[a>>2]|0;e=b+65535&65535;c[a>>2]=e|b&-65536;b=c[2276056]|0;if((e|0)==65535){c[2276056]=b+2;c[2276108]=(c[2276108]|0)-(c[2276092]|0);return}e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;a=c[2276085]&e;e=a&16777212;h=c[2112932]|0;i=c[h+((e>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=a&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=b}else{b=gj[c[h+196768+(i<<2)>>2]&4095](e)|0;k=b;l=c[2276056]|0}c[2276084]=k;f=l;g=k}c[2276056]=(g>>>((f<<3&16^16)>>>0)<<16>>16)+f;c[2276108]=(c[2276108]|0)-(c[2276091]|0);return}function mK(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if((c[2276078]&256|0)==0){c[2276056]=(c[2276056]|0)+2;return}a=9104156+((c[2276069]&7)<<2)|0;b=c[a>>2]|0;e=b+65535&65535;c[a>>2]=e|b&-65536;b=c[2276056]|0;if((e|0)==65535){c[2276056]=b+2;c[2276108]=(c[2276108]|0)-(c[2276092]|0);return}e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;a=c[2276085]&e;e=a&16777212;h=c[2112932]|0;i=c[h+((e>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=a&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=b}else{b=gj[c[h+196768+(i<<2)>>2]&4095](e)|0;k=b;l=c[2276056]|0}c[2276084]=k;f=l;g=k}c[2276056]=(g>>>((f<<3&16^16)>>>0)<<16>>16)+f;c[2276108]=(c[2276108]|0)-(c[2276091]|0);return}function mL(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if((c[2276078]&256|0)!=0){c[2276056]=(c[2276056]|0)+2;return}a=9104156+((c[2276069]&7)<<2)|0;b=c[a>>2]|0;e=b+65535&65535;c[a>>2]=e|b&-65536;b=c[2276056]|0;if((e|0)==65535){c[2276056]=b+2;c[2276108]=(c[2276108]|0)-(c[2276092]|0);return}e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;a=c[2276085]&e;e=a&16777212;h=c[2112932]|0;i=c[h+((e>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=a&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=b}else{b=gj[c[h+196768+(i<<2)>>2]&4095](e)|0;k=b;l=c[2276056]|0}c[2276084]=k;f=l;g=k}c[2276056]=(g>>>((f<<3&16^16)>>>0)<<16>>16)+f;c[2276108]=(c[2276108]|0)-(c[2276091]|0);return}function mM(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if((c[2276076]|0)!=0){c[2276056]=(c[2276056]|0)+2;return}a=9104156+((c[2276069]&7)<<2)|0;b=c[a>>2]|0;e=b+65535&65535;c[a>>2]=e|b&-65536;b=c[2276056]|0;if((e|0)==65535){c[2276056]=b+2;c[2276108]=(c[2276108]|0)-(c[2276092]|0);return}e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;a=c[2276085]&e;e=a&16777212;h=c[2112932]|0;i=c[h+((e>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=a&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=b}else{b=gj[c[h+196768+(i<<2)>>2]&4095](e)|0;k=b;l=c[2276056]|0}c[2276084]=k;f=l;g=k}c[2276056]=(g>>>((f<<3&16^16)>>>0)<<16>>16)+f;c[2276108]=(c[2276108]|0)-(c[2276091]|0);return}function mN(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if((c[2276076]|0)==0){c[2276056]=(c[2276056]|0)+2;return}a=9104156+((c[2276069]&7)<<2)|0;b=c[a>>2]|0;e=b+65535&65535;c[a>>2]=e|b&-65536;b=c[2276056]|0;if((e|0)==65535){c[2276056]=b+2;c[2276108]=(c[2276108]|0)-(c[2276092]|0);return}e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;a=c[2276085]&e;e=a&16777212;h=c[2112932]|0;i=c[h+((e>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=a&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=b}else{b=gj[c[h+196768+(i<<2)>>2]&4095](e)|0;k=b;l=c[2276056]|0}c[2276084]=k;f=l;g=k}c[2276056]=(g>>>((f<<3&16^16)>>>0)<<16>>16)+f;c[2276108]=(c[2276108]|0)-(c[2276091]|0);return}function mO(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if((c[2276077]&128|0)==0){c[2276056]=(c[2276056]|0)+2;return}a=9104156+((c[2276069]&7)<<2)|0;b=c[a>>2]|0;e=b+65535&65535;c[a>>2]=e|b&-65536;b=c[2276056]|0;if((e|0)==65535){c[2276056]=b+2;c[2276108]=(c[2276108]|0)-(c[2276092]|0);return}e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;a=c[2276085]&e;e=a&16777212;h=c[2112932]|0;i=c[h+((e>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=a&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=b}else{b=gj[c[h+196768+(i<<2)>>2]&4095](e)|0;k=b;l=c[2276056]|0}c[2276084]=k;f=l;g=k}c[2276056]=(g>>>((f<<3&16^16)>>>0)<<16>>16)+f;c[2276108]=(c[2276108]|0)-(c[2276091]|0);return}function mP(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if((c[2276077]&128|0)!=0){c[2276056]=(c[2276056]|0)+2;return}a=9104156+((c[2276069]&7)<<2)|0;b=c[a>>2]|0;e=b+65535&65535;c[a>>2]=e|b&-65536;b=c[2276056]|0;if((e|0)==65535){c[2276056]=b+2;c[2276108]=(c[2276108]|0)-(c[2276092]|0);return}e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;a=c[2276085]&e;e=a&16777212;h=c[2112932]|0;i=c[h+((e>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=a&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=b}else{b=gj[c[h+196768+(i<<2)>>2]&4095](e)|0;k=b;l=c[2276056]|0}c[2276084]=k;f=l;g=k}c[2276056]=(g>>>((f<<3&16^16)>>>0)<<16>>16)+f;c[2276108]=(c[2276108]|0)-(c[2276091]|0);return}function mQ(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if((c[2276075]&128|0)==0){c[2276056]=(c[2276056]|0)+2;return}a=9104156+((c[2276069]&7)<<2)|0;b=c[a>>2]|0;e=b+65535&65535;c[a>>2]=e|b&-65536;b=c[2276056]|0;if((e|0)==65535){c[2276056]=b+2;c[2276108]=(c[2276108]|0)-(c[2276092]|0);return}e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;a=c[2276085]&e;e=a&16777212;h=c[2112932]|0;i=c[h+((e>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=a&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=b}else{b=gj[c[h+196768+(i<<2)>>2]&4095](e)|0;k=b;l=c[2276056]|0}c[2276084]=k;f=l;g=k}c[2276056]=(g>>>((f<<3&16^16)>>>0)<<16>>16)+f;c[2276108]=(c[2276108]|0)-(c[2276091]|0);return}function mR(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if((c[2276075]&128|0)!=0){c[2276056]=(c[2276056]|0)+2;return}a=9104156+((c[2276069]&7)<<2)|0;b=c[a>>2]|0;e=b+65535&65535;c[a>>2]=e|b&-65536;b=c[2276056]|0;if((e|0)==65535){c[2276056]=b+2;c[2276108]=(c[2276108]|0)-(c[2276092]|0);return}e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;a=c[2276085]&e;e=a&16777212;h=c[2112932]|0;i=c[h+((e>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=a&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=b}else{b=gj[c[h+196768+(i<<2)>>2]&4095](e)|0;k=b;l=c[2276056]|0}c[2276084]=k;f=l;g=k}c[2276056]=(g>>>((f<<3&16^16)>>>0)<<16>>16)+f;c[2276108]=(c[2276108]|0)-(c[2276091]|0);return}function mS(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if(((c[2276077]^c[2276075])&128|0)==0){c[2276056]=(c[2276056]|0)+2;return}a=9104156+((c[2276069]&7)<<2)|0;b=c[a>>2]|0;e=b+65535&65535;c[a>>2]=e|b&-65536;b=c[2276056]|0;if((e|0)==65535){c[2276056]=b+2;c[2276108]=(c[2276108]|0)-(c[2276092]|0);return}e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;a=c[2276085]&e;e=a&16777212;h=c[2112932]|0;i=c[h+((e>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=a&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=b}else{b=gj[c[h+196768+(i<<2)>>2]&4095](e)|0;k=b;l=c[2276056]|0}c[2276084]=k;f=l;g=k}c[2276056]=(g>>>((f<<3&16^16)>>>0)<<16>>16)+f;c[2276108]=(c[2276108]|0)-(c[2276091]|0);return}function mT(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if(((c[2276077]^c[2276075])&128|0)!=0){c[2276056]=(c[2276056]|0)+2;return}a=9104156+((c[2276069]&7)<<2)|0;b=c[a>>2]|0;e=b+65535&65535;c[a>>2]=e|b&-65536;b=c[2276056]|0;if((e|0)==65535){c[2276056]=b+2;c[2276108]=(c[2276108]|0)-(c[2276092]|0);return}e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;a=c[2276085]&e;e=a&16777212;h=c[2112932]|0;i=c[h+((e>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=a&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=b}else{b=gj[c[h+196768+(i<<2)>>2]&4095](e)|0;k=b;l=c[2276056]|0}c[2276084]=k;f=l;g=k}c[2276056]=(g>>>((f<<3&16^16)>>>0)<<16>>16)+f;c[2276108]=(c[2276108]|0)-(c[2276091]|0);return}function mU(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if(((c[2276077]^c[2276075])&128|0)==0&(c[2276076]|0)!=0){c[2276056]=(c[2276056]|0)+2;return}a=9104156+((c[2276069]&7)<<2)|0;b=c[a>>2]|0;e=b+65535&65535;c[a>>2]=e|b&-65536;b=c[2276056]|0;if((e|0)==65535){c[2276056]=b+2;c[2276108]=(c[2276108]|0)-(c[2276092]|0);return}e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;a=c[2276085]&e;e=a&16777212;h=c[2112932]|0;i=c[h+((e>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=a&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=b}else{b=gj[c[h+196768+(i<<2)>>2]&4095](e)|0;k=b;l=c[2276056]|0}c[2276084]=k;f=l;g=k}c[2276056]=(g>>>((f<<3&16^16)>>>0)<<16>>16)+f;c[2276108]=(c[2276108]|0)-(c[2276091]|0);return}function mV(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if(!(((c[2276077]^c[2276075])&128|0)==0&(c[2276076]|0)!=0)){c[2276056]=(c[2276056]|0)+2;return}a=9104156+((c[2276069]&7)<<2)|0;b=c[a>>2]|0;e=b+65535&65535;c[a>>2]=e|b&-65536;b=c[2276056]|0;if((e|0)==65535){c[2276056]=b+2;c[2276108]=(c[2276108]|0)-(c[2276092]|0);return}e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;a=c[2276085]&e;e=a&16777212;h=c[2112932]|0;i=c[h+((e>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=a&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=b}else{b=gj[c[h+196768+(i<<2)>>2]&4095](e)|0;k=b;l=c[2276056]|0}c[2276084]=k;f=l;g=k}c[2276056]=(g>>>((f<<3&16^16)>>>0)<<16>>16)+f;c[2276108]=(c[2276108]|0)-(c[2276091]|0);return}function mW(){var a=0,b=0,d=0,e=0;a=c[2276069]|0;b=9104156+((a>>>9&7)<<2)|0;d=c[9104156+((a&7)<<2)>>2]<<16>>16;if((d|0)==0){mX();return}a=c[b>>2]|0;if((a|0)==-2147483648&(d|0)==-1){gGz(9104300,0,16);c[b>>2]=0;return}e=(a|0)/(d|0)|0;if((e|0)==(e<<16>>16|0)){c[2276076]=e;c[2276075]=e>>8;c[2276077]=0;c[2276078]=0;c[b>>2]=((a|0)%(d|0)|0)<<16|e&65535;return}else{c[2276077]=128;return}}function mX(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;b=c[2276072]|0;e=c[2276073]|0;f=c[2276071]|c[2276070]|b<<11|e<<11|c[2276079]|(c[2276074]|0)>>>4&16|(c[2276075]|0)>>>4&8|((c[2276076]|0)==0)<<2|(c[2276077]|0)>>>6&2|(c[2276078]|0)>>>8&1;c[2276071]=0;c[2276070]=0;c[9104228+((b>>>1&e|b)<<2)>>2]=c[2276054];c[2276072]=4;b=c[9104228+((c[2276073]&2|4)<<2)>>2]|0;c[2276054]=b;e=c[2276038]|0;do{if((e&7|0)==0){g=c[2276055]|0;h=b-4|0;c[2276054]=h;i=c[2276085]&h;h=i&16777215;j=c[2112932]|0;k=c[j+((h>>>10|16384)<<2)>>2]|0;if(k>>>0>9){l=i&1023;a[k+l|0]=g>>>16&255;a[k+(l+1)|0]=g>>>24&255;a[k+(l+2)|0]=g&255;a[k+(l+3)|0]=g>>>8&255;m=j}else{gg[c[j+196808+(k<<2)>>2]&4095](h,g);m=c[2112932]|0}g=(c[2276054]|0)-2|0;c[2276054]=g;h=c[2276085]&g;g=h&16777215;k=c[m+((g>>>10|16384)<<2)>>2]|0;if(k>>>0>9){j=h&1023;a[k+j|0]=20;a[k+(j+1)|0]=32;n=m}else{gg[c[m+196728+(k<<2)>>2]&4095](g,8212);n=c[2112932]|0}g=c[2276056]|0;k=(c[2276054]|0)-4|0;c[2276054]=k;j=c[2276085]&k;k=j&16777215;h=c[n+((k>>>10|16384)<<2)>>2]|0;if(h>>>0>9){l=j&1023;a[h+l|0]=g>>>16&255;a[h+(l+1)|0]=g>>>24&255;a[h+(l+2)|0]=g&255;a[h+(l+3)|0]=g>>>8&255;o=n}else{gg[c[n+196808+(h<<2)>>2]&4095](k,g);o=c[2112932]|0}g=(c[2276054]|0)-2|0;c[2276054]=g;k=c[2276085]&g;g=f&65535;h=k&16777215;l=c[o+((h>>>10|16384)<<2)>>2]|0;if(l>>>0>9){j=k&1023;a[l+j|0]=f&255;a[l+(j+1)|0]=(g&65535)>>>8&255;break}else{gg[c[o+196728+(l<<2)>>2]&4095](h,g);break}}else{g=c[2276056]|0;if((e-1|0)>>>0<2){h=b-4|0;c[2276054]=h;l=c[2276085]&h;h=l&16777215;j=c[2112932]|0;k=c[j+((h>>>10|16384)<<2)>>2]|0;if(k>>>0>9){i=l&1023;a[k+i|0]=g>>>16&255;a[k+(i+1)|0]=g>>>24&255;a[k+(i+2)|0]=g&255;a[k+(i+3)|0]=g>>>8&255;p=j}else{gg[c[j+196808+(k<<2)>>2]&4095](h,g);p=c[2112932]|0}h=(c[2276054]|0)-2|0;c[2276054]=h;k=c[2276085]&h;h=f&65535;j=k&16777215;i=c[p+((j>>>10|16384)<<2)>>2]|0;if(i>>>0>9){l=k&1023;a[i+l|0]=f&255;a[i+(l+1)|0]=(h&65535)>>>8&255;break}else{gg[c[p+196728+(i<<2)>>2]&4095](j,h);break}}h=b-2|0;c[2276054]=h;j=c[2276085]&h;h=j&16777215;i=c[2112932]|0;l=c[i+((h>>>10|16384)<<2)>>2]|0;if(l>>>0>9){k=j&1023;a[l+k|0]=20;a[l+(k+1)|0]=0;q=i}else{gg[c[i+196728+(l<<2)>>2]&4095](h,20);q=c[2112932]|0}h=(c[2276054]|0)-4|0;c[2276054]=h;l=c[2276085]&h;h=l&16777215;i=c[q+((h>>>10|16384)<<2)>>2]|0;if(i>>>0>9){k=l&1023;a[i+k|0]=g>>>16&255;a[i+(k+1)|0]=g>>>24&255;a[i+(k+2)|0]=g&255;a[i+(k+3)|0]=g>>>8&255;r=q}else{gg[c[q+196808+(i<<2)>>2]&4095](h,g);r=c[2112932]|0}g=(c[2276054]|0)-2|0;c[2276054]=g;h=c[2276085]&g;g=f&65535;i=h&16777215;k=c[r+((i>>>10|16384)<<2)>>2]|0;if(k>>>0>9){l=h&1023;a[k+l|0]=f&255;a[k+(l+1)|0]=(g&65535)>>>8&255;break}else{gg[c[r+196728+(k<<2)>>2]&4095](i,g);break}}}while(0);r=(c[2276064]|0)+20|0;c[2276056]=r;f=c[2276085]&r;r=f&16777215;q=c[2112932]|0;b=c[q+(r>>>10<<2)>>2]|0;if(b>>>0>9){p=f&1023;s=(d[b+(p+3)|0]|0)<<8|(d[b+(p+2)|0]|0)|((d[b+(p+1)|0]|0)<<8|(d[b+p|0]|0))<<16;c[2276056]=s;t=c[2276099]|0;u=t+5|0;v=a[u]|0;w=v&255;x=c[2276108]|0;y=x-w|0;c[2276108]=y;return}else{s=gj[c[q+196768+(b<<2)>>2]&4095](r)|0;c[2276056]=s;t=c[2276099]|0;u=t+5|0;v=a[u]|0;w=v&255;x=c[2276108]|0;y=x-w|0;c[2276108]=y;return}}function mY(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0;a=c[2276069]|0;b=9104156+((a>>>9&7)<<2)|0;e=c[2276085]&c[9104156+((a&7|8)<<2)>>2];a=e&16777215;f=c[2112932]|0;g=c[f+(a>>>10<<2)>>2]|0;if(g>>>0>9){h=e&1023;i=(d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0)}else{i=gj[c[f+196688+(g<<2)>>2]&4095](a)|0}a=i<<16>>16;if(i<<16>>16==0){mX();return}g=c[b>>2]|0;if((g|0)==-2147483648&i<<16>>16==-1){gGz(9104300,0,16);c[b>>2]=0;return}i=(g|0)/(a|0)|0;if((i|0)==(i<<16>>16|0)){c[2276076]=i;c[2276075]=i>>8;c[2276077]=0;c[2276078]=0;c[b>>2]=((g|0)%(a|0)|0)<<16|i&65535;return}else{c[2276077]=128;return}}function mZ(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0;a=c[2276069]|0;b=9104156+((a>>>9&7)<<2)|0;e=9104156+((a&7|8)<<2)|0;a=c[e>>2]|0;c[e>>2]=a+2;e=c[2276085]&a;a=e&16777215;f=c[2112932]|0;g=c[f+(a>>>10<<2)>>2]|0;if(g>>>0>9){h=e&1023;i=(d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0)}else{i=gj[c[f+196688+(g<<2)>>2]&4095](a)|0}a=i<<16>>16;if(i<<16>>16==0){mX();return}g=c[b>>2]|0;if((g|0)==-2147483648&i<<16>>16==-1){gGz(9104300,0,16);c[b>>2]=0;return}i=(g|0)/(a|0)|0;if((i|0)==(i<<16>>16|0)){c[2276076]=i;c[2276075]=i>>8;c[2276077]=0;c[2276078]=0;c[b>>2]=((g|0)%(a|0)|0)<<16|i&65535;return}else{c[2276077]=128;return}}function m_(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0;a=c[2276069]|0;b=9104156+((a>>>9&7)<<2)|0;e=9104156+((a&7|8)<<2)|0;a=(c[e>>2]|0)-2|0;c[e>>2]=a;e=c[2276085]&a;a=e&16777215;f=c[2112932]|0;g=c[f+(a>>>10<<2)>>2]|0;if(g>>>0>9){h=e&1023;i=(d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0)}else{i=gj[c[f+196688+(g<<2)>>2]&4095](a)|0}a=i<<16>>16;if(i<<16>>16==0){mX();return}g=c[b>>2]|0;if((g|0)==-2147483648&i<<16>>16==-1){gGz(9104300,0,16);c[b>>2]=0;return}i=(g|0)/(a|0)|0;if((i|0)==(i<<16>>16|0)){c[2276076]=i;c[2276075]=i>>8;c[2276077]=0;c[2276078]=0;c[b>>2]=((g|0)%(a|0)|0)<<16|i&65535;return}else{c[2276077]=128;return}}function m$(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=c[2276069]|0;b=9104156+((a>>>9&7)<<2)|0;e=c[9104156+((a&7|8)<<2)>>2]|0;a=c[2276056]|0;f=a&-4;if((f|0)==(c[2276083]|0)){g=a;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a}else{a=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=a;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=(h>>>((g<<3&16^16)>>>0)<<16>>16)+e&c[2276085];e=m&16777215;g=c[2112932]|0;h=c[g+(e>>>10<<2)>>2]|0;if(h>>>0>9){n=m&1023;o=(d[h+(n+1)|0]|0)<<8|(d[h+n|0]|0)}else{o=gj[c[g+196688+(h<<2)>>2]&4095](e)|0}e=o<<16>>16;if(o<<16>>16==0){mX();return}h=c[b>>2]|0;if((h|0)==-2147483648&o<<16>>16==-1){gGz(9104300,0,16);c[b>>2]=0;return}o=(h|0)/(e|0)|0;if((o|0)==(o<<16>>16|0)){c[2276076]=o;c[2276075]=o>>8;c[2276077]=0;c[2276078]=0;c[b>>2]=((h|0)%(e|0)|0)<<16|o&65535;return}else{c[2276077]=128;return}}function m0(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0;a=c[2276069]|0;b=9104156+((a>>>9&7)<<2)|0;e=nB(c[9104156+((a&7|8)<<2)>>2]|0)|0;a=c[2276085]&e;e=a&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=a&1023;i=(d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0)}else{i=gj[c[f+196688+(g<<2)>>2]&4095](e)|0}e=i<<16>>16;if(i<<16>>16==0){mX();return}g=c[b>>2]|0;if((g|0)==-2147483648&i<<16>>16==-1){gGz(9104300,0,16);c[b>>2]=0;return}i=(g|0)/(e|0)|0;if((i|0)==(i<<16>>16|0)){c[2276076]=i;c[2276075]=i>>8;c[2276077]=0;c[2276078]=0;c[b>>2]=((g|0)%(e|0)|0)<<16|i&65535;return}else{c[2276077]=128;return}}function m1(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)<<16>>16&c[2276085];f=l&16777215;g=c[2112932]|0;m=c[g+(f>>>10<<2)>>2]|0;if(m>>>0>9){b=l&1023;n=(d[m+(b+1)|0]|0)<<8|(d[m+b|0]|0)}else{n=gj[c[g+196688+(m<<2)>>2]&4095](f)|0}f=n<<16>>16;if(n<<16>>16==0){mX();return}m=c[a>>2]|0;if((m|0)==-2147483648&n<<16>>16==-1){gGz(9104300,0,16);c[a>>2]=0;return}n=(m|0)/(f|0)|0;if((n|0)==(n<<16>>16|0)){c[2276076]=n;c[2276075]=n>>8;c[2276077]=0;c[2276078]=0;c[a>>2]=((m|0)%(f|0)|0)<<16|n&65535;return}else{c[2276077]=128;return}}function m2(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;a=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[2276085]&q;q=r&16777215;t=c[2112932]|0;h=c[t+(q>>>10<<2)>>2]|0;if(h>>>0>9){s=r&1023;u=(d[h+(s+1)|0]|0)<<8|(d[h+s|0]|0)}else{u=gj[c[t+196688+(h<<2)>>2]&4095](q)|0}q=u<<16>>16;if(u<<16>>16==0){mX();return}h=c[a>>2]|0;if((h|0)==-2147483648&u<<16>>16==-1){gGz(9104300,0,16);c[a>>2]=0;return}u=(h|0)/(q|0)|0;if((u|0)==(u<<16>>16|0)){c[2276076]=u;c[2276075]=u>>8;c[2276077]=0;c[2276078]=0;c[a>>2]=((h|0)%(q|0)|0)<<16|u&65535;return}else{c[2276077]=128;return}}function m3(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{k=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=k;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=(g>>>((f<<3&16^16)>>>0)<<16>>16)+b|0;b=l&16777215;f=c[2112932]|0;g=c[f+((b>>>10|32768)<<2)>>2]|0;if(g>>>0>9){m=l&1023;n=(d[g+(m+1)|0]|0)<<8|(d[g+m|0]|0)}else{n=gj[c[f+196688+(g<<2)>>2]&4095](b)|0}b=n<<16>>16;if(n<<16>>16==0){mX();return}g=c[a>>2]|0;if((g|0)==-2147483648&n<<16>>16==-1){gGz(9104300,0,16);c[a>>2]=0;return}n=(g|0)/(b|0)|0;if((n|0)==(n<<16>>16|0)){c[2276076]=n;c[2276075]=n>>8;c[2276077]=0;c[2276078]=0;c[a>>2]=((g|0)%(b|0)|0)<<16|n&65535;return}else{c[2276077]=128;return}}function m4(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0;a=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;b=nB(c[2276056]|0)|0;e=b&16777215;f=c[2112932]|0;g=c[f+((e>>>10|32768)<<2)>>2]|0;if(g>>>0>9){h=b&1023;i=(d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0)}else{i=gj[c[f+196688+(g<<2)>>2]&4095](e)|0}e=i<<16>>16;if(i<<16>>16==0){mX();return}g=c[a>>2]|0;if((g|0)==-2147483648&i<<16>>16==-1){gGz(9104300,0,16);c[a>>2]=0;return}i=(g|0)/(e|0)|0;if((i|0)==(i<<16>>16|0)){c[2276076]=i;c[2276075]=i>>8;c[2276077]=0;c[2276078]=0;c[a>>2]=((g|0)%(e|0)|0)<<16|i&65535;return}else{c[2276077]=128;return}}function m5(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)<<16>>16;if((l|0)==0){mX();return}f=c[a>>2]|0;if((f|0)==-2147483648&(l|0)==-1){gGz(9104300,0,16);c[a>>2]=0;return}g=(f|0)/(l|0)|0;if((g|0)==(g<<16>>16|0)){c[2276076]=g;c[2276075]=g>>8;c[2276077]=0;c[2276078]=0;c[a>>2]=((f|0)%(l|0)|0)<<16|g&65535;return}else{c[2276077]=128;return}}function m6(){var a=0,b=0,d=0,e=0;a=c[2276069]|0;b=9104156+((a>>>9&7)<<2)|0;d=c[9104156+((a&7)<<2)>>2]&65535;if((d|0)==0){mX();return}a=c[b>>2]|0;e=(a>>>0)/(d>>>0)|0;if(e>>>0<65536){c[2276076]=e;c[2276075]=e>>>8;c[2276077]=0;c[2276078]=0;c[b>>2]=((a>>>0)%(d>>>0)|0)<<16|e&65535;return}else{c[2276077]=128;return}}function m7(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0;a=c[2276069]|0;b=9104156+((a>>>9&7)<<2)|0;e=c[2276085]&c[9104156+((a&7|8)<<2)>>2];a=e&16777215;f=c[2112932]|0;g=c[f+(a>>>10<<2)>>2]|0;if(g>>>0>9){h=e&1023;i=(d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0)}else{i=gj[c[f+196688+(g<<2)>>2]&4095](a)|0}a=i&65535;if(i<<16>>16==0){mX();return}i=c[b>>2]|0;g=(i>>>0)/(a>>>0)|0;if(g>>>0<65536){c[2276076]=g;c[2276075]=g>>>8;c[2276077]=0;c[2276078]=0;c[b>>2]=((i>>>0)%(a>>>0)|0)<<16|g&65535;return}else{c[2276077]=128;return}}function m8(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0;a=c[2276069]|0;b=9104156+((a>>>9&7)<<2)|0;e=9104156+((a&7|8)<<2)|0;a=c[e>>2]|0;c[e>>2]=a+2;e=c[2276085]&a;a=e&16777215;f=c[2112932]|0;g=c[f+(a>>>10<<2)>>2]|0;if(g>>>0>9){h=e&1023;i=(d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0)}else{i=gj[c[f+196688+(g<<2)>>2]&4095](a)|0}a=i&65535;if(i<<16>>16==0){mX();return}i=c[b>>2]|0;g=(i>>>0)/(a>>>0)|0;if(g>>>0<65536){c[2276076]=g;c[2276075]=g>>>8;c[2276077]=0;c[2276078]=0;c[b>>2]=((i>>>0)%(a>>>0)|0)<<16|g&65535;return}else{c[2276077]=128;return}}function m9(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0;a=c[2276069]|0;b=9104156+((a>>>9&7)<<2)|0;e=9104156+((a&7|8)<<2)|0;a=(c[e>>2]|0)-2|0;c[e>>2]=a;e=c[2276085]&a;a=e&16777215;f=c[2112932]|0;g=c[f+(a>>>10<<2)>>2]|0;if(g>>>0>9){h=e&1023;i=(d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0)}else{i=gj[c[f+196688+(g<<2)>>2]&4095](a)|0}a=i&65535;if(i<<16>>16==0){mX();return}i=c[b>>2]|0;g=(i>>>0)/(a>>>0)|0;if(g>>>0<65536){c[2276076]=g;c[2276075]=g>>>8;c[2276077]=0;c[2276078]=0;c[b>>2]=((i>>>0)%(a>>>0)|0)<<16|g&65535;return}else{c[2276077]=128;return}}function na(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=c[2276069]|0;b=9104156+((a>>>9&7)<<2)|0;e=c[9104156+((a&7|8)<<2)>>2]|0;a=c[2276056]|0;f=a&-4;if((f|0)==(c[2276083]|0)){g=a;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a}else{a=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=a;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=(h>>>((g<<3&16^16)>>>0)<<16>>16)+e&c[2276085];e=m&16777215;g=c[2112932]|0;h=c[g+(e>>>10<<2)>>2]|0;if(h>>>0>9){n=m&1023;o=(d[h+(n+1)|0]|0)<<8|(d[h+n|0]|0)}else{o=gj[c[g+196688+(h<<2)>>2]&4095](e)|0}e=o&65535;if(o<<16>>16==0){mX();return}o=c[b>>2]|0;h=(o>>>0)/(e>>>0)|0;if(h>>>0<65536){c[2276076]=h;c[2276075]=h>>>8;c[2276077]=0;c[2276078]=0;c[b>>2]=((o>>>0)%(e>>>0)|0)<<16|h&65535;return}else{c[2276077]=128;return}}function nb(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0;a=c[2276069]|0;b=9104156+((a>>>9&7)<<2)|0;e=nB(c[9104156+((a&7|8)<<2)>>2]|0)|0;a=c[2276085]&e;e=a&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=a&1023;i=(d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0)}else{i=gj[c[f+196688+(g<<2)>>2]&4095](e)|0}e=i&65535;if(i<<16>>16==0){mX();return}i=c[b>>2]|0;g=(i>>>0)/(e>>>0)|0;if(g>>>0<65536){c[2276076]=g;c[2276075]=g>>>8;c[2276077]=0;c[2276078]=0;c[b>>2]=((i>>>0)%(e>>>0)|0)<<16|g&65535;return}else{c[2276077]=128;return}}function nc(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)<<16>>16&c[2276085];f=l&16777215;g=c[2112932]|0;m=c[g+(f>>>10<<2)>>2]|0;if(m>>>0>9){b=l&1023;n=(d[m+(b+1)|0]|0)<<8|(d[m+b|0]|0)}else{n=gj[c[g+196688+(m<<2)>>2]&4095](f)|0}f=n&65535;if(n<<16>>16==0){mX();return}n=c[a>>2]|0;m=(n>>>0)/(f>>>0)|0;if(m>>>0<65536){c[2276076]=m;c[2276075]=m>>>8;c[2276077]=0;c[2276078]=0;c[a>>2]=((n>>>0)%(f>>>0)|0)<<16|m&65535;return}else{c[2276077]=128;return}}function nd(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;a=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[2276085]&q;q=r&16777215;t=c[2112932]|0;h=c[t+(q>>>10<<2)>>2]|0;if(h>>>0>9){s=r&1023;u=(d[h+(s+1)|0]|0)<<8|(d[h+s|0]|0)}else{u=gj[c[t+196688+(h<<2)>>2]&4095](q)|0}q=u&65535;if(u<<16>>16==0){mX();return}u=c[a>>2]|0;h=(u>>>0)/(q>>>0)|0;if(h>>>0<65536){c[2276076]=h;c[2276075]=h>>>8;c[2276077]=0;c[2276078]=0;c[a>>2]=((u>>>0)%(q>>>0)|0)<<16|h&65535;return}else{c[2276077]=128;return}}function ne(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{k=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=k;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=(g>>>((f<<3&16^16)>>>0)<<16>>16)+b|0;b=l&16777215;f=c[2112932]|0;g=c[f+((b>>>10|32768)<<2)>>2]|0;if(g>>>0>9){m=l&1023;n=(d[g+(m+1)|0]|0)<<8|(d[g+m|0]|0)}else{n=gj[c[f+196688+(g<<2)>>2]&4095](b)|0}b=n&65535;if(n<<16>>16==0){mX();return}n=c[a>>2]|0;g=(n>>>0)/(b>>>0)|0;if(g>>>0<65536){c[2276076]=g;c[2276075]=g>>>8;c[2276077]=0;c[2276078]=0;c[a>>2]=((n>>>0)%(b>>>0)|0)<<16|g&65535;return}else{c[2276077]=128;return}}function nf(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0;a=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;b=nB(c[2276056]|0)|0;e=b&16777215;f=c[2112932]|0;g=c[f+((e>>>10|32768)<<2)>>2]|0;if(g>>>0>9){h=b&1023;i=(d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0)}else{i=gj[c[f+196688+(g<<2)>>2]&4095](e)|0}e=i&65535;if(i<<16>>16==0){mX();return}i=c[a>>2]|0;g=(i>>>0)/(e>>>0)|0;if(g>>>0<65536){c[2276076]=g;c[2276075]=g>>>8;c[2276077]=0;c[2276078]=0;c[a>>2]=((i>>>0)%(e>>>0)|0)<<16|g&65535;return}else{c[2276077]=128;return}}function ng(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)&65535;if((l|0)==0){mX();return}f=c[a>>2]|0;g=(f>>>0)/(l>>>0)|0;if(g>>>0<65536){c[2276076]=g;c[2276075]=g>>>8;c[2276077]=0;c[2276078]=0;c[a>>2]=((f>>>0)%(l>>>0)|0)<<16|g&65535;return}else{c[2276077]=128;return}}function nh(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;if((c[2276038]&24|0)==0){ni();return}a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=f>>>((e<<3&16^16)>>>0);e=c[9104156+((c[2276069]&7)<<2)>>2]|0;f=9104156+((k&7)<<2)|0;l=c[f>>2]|0;a=9104156+((k>>>12&7)<<2)|0;b=c[a>>2]|0;if((e|0)==0){mX();return}i=(k&2048|0)!=0;if((k&1024|0)==0){do{if(i){if(!((b|0)==-2147483648&(e|0)==-1)){c[f>>2]=(b|0)%(e|0)|0;m=(b|0)/(e|0)|0;break}c[2276075]=128;c[2276076]=-1;c[2276077]=0;c[2276078]=0;c[a>>2]=-2147483648;c[f>>2]=0;return}else{c[f>>2]=(b>>>0)%(e>>>0)|0;m=(b>>>0)/(e>>>0)|0}}while(0);c[a>>2]=m;c[2276075]=m>>>24;c[2276076]=m;c[2276077]=0;c[2276078]=0;return}if(i){if((l|0)==0&(b|0)==-2147483648&(e|0)==-1){c[f>>2]=0;c[a>>2]=-2147483648;c[2276075]=128;c[2276076]=-1;c[2276077]=0;c[2276078]=0;return}if((l|0)<0){n=1;o=-b|0;p=-(((b|0)!=0)+l|0)|0}else{n=0;o=b;p=l}q=(e|0)<0?-e|0:e;r=e>>>31;s=n;t=o;u=p}else{q=e;r=0;s=0;t=b;u=l}if(u>>>0<q>>>0){v=0;w=0;x=31}else{c[2276077]=128;return}while(1){l=v<<1;b=u>>>(x>>>0)&1|w<<1;if(b>>>0<q>>>0){y=b;z=l}else{y=b-q|0;z=l|1}if((x|0)>0){v=z;w=y;x=x-1|0}else{A=z;B=y;C=31;break}}while(1){y=A<<1;z=t>>>(C>>>0)&1|B<<1;if(z>>>0>=q>>>0|(B|0)<0){D=z-q|0;E=y|1}else{D=z;E=y}if((C|0)>0){A=E;B=D;C=C-1|0}else{break}}do{if(i){if((E|0)<0){c[2276077]=128;return}if((s|0)==0){F=D;G=E}else{F=-D|0;G=-E|0}if((r|0)==0){H=F;I=G;break}H=F;I=-G|0}else{H=D;I=E}}while(0);c[f>>2]=H;c[a>>2]=I;c[2276075]=I>>>24;c[2276076]=I;c[2276077]=0;c[2276078]=0;return}function ni(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;b=c[2276072]|0;e=c[2276073]|0;f=c[2276071]|c[2276070]|b<<11|e<<11|c[2276079]|(c[2276074]|0)>>>4&16|(c[2276075]|0)>>>4&8|((c[2276076]|0)==0)<<2|(c[2276077]|0)>>>6&2|(c[2276078]|0)>>>8&1;c[2276071]=0;c[2276070]=0;c[9104228+((b>>>1&e|b)<<2)>>2]=c[2276054];c[2276072]=4;b=c[9104228+((c[2276073]&2|4)<<2)>>2]|0;c[2276054]=b;e=c[2276055]|0;do{if(((c[2276038]|0)-1|0)>>>0<2){g=b-4|0;c[2276054]=g;h=c[2276085]&g;g=h&16777215;i=c[2112932]|0;j=c[i+((g>>>10|16384)<<2)>>2]|0;if(j>>>0>9){k=h&1023;a[j+k|0]=e>>>16&255;a[j+(k+1)|0]=e>>>24&255;a[j+(k+2)|0]=e&255;a[j+(k+3)|0]=e>>>8&255;l=i}else{gg[c[i+196808+(j<<2)>>2]&4095](g,e);l=c[2112932]|0}g=(c[2276054]|0)-2|0;c[2276054]=g;j=c[2276085]&g;g=f&65535;i=j&16777215;k=c[l+((i>>>10|16384)<<2)>>2]|0;if(k>>>0>9){h=j&1023;a[k+h|0]=f&255;a[k+(h+1)|0]=(g&65535)>>>8&255;break}else{gg[c[l+196728+(k<<2)>>2]&4095](i,g);break}}else{g=b-2|0;c[2276054]=g;i=c[2276085]&g;g=i&16777215;k=c[2112932]|0;h=c[k+((g>>>10|16384)<<2)>>2]|0;if(h>>>0>9){j=i&1023;a[h+j|0]=16;a[h+(j+1)|0]=0;m=k}else{gg[c[k+196728+(h<<2)>>2]&4095](g,16);m=c[2112932]|0}g=(c[2276054]|0)-4|0;c[2276054]=g;h=c[2276085]&g;g=h&16777215;k=c[m+((g>>>10|16384)<<2)>>2]|0;if(k>>>0>9){j=h&1023;a[k+j|0]=e>>>16&255;a[k+(j+1)|0]=e>>>24&255;a[k+(j+2)|0]=e&255;a[k+(j+3)|0]=e>>>8&255;n=m}else{gg[c[m+196808+(k<<2)>>2]&4095](g,e);n=c[2112932]|0}g=(c[2276054]|0)-2|0;c[2276054]=g;k=c[2276085]&g;g=f&65535;j=k&16777215;h=c[n+((j>>>10|16384)<<2)>>2]|0;if(h>>>0>9){i=k&1023;a[h+i|0]=f&255;a[h+(i+1)|0]=(g&65535)>>>8&255;break}else{gg[c[n+196728+(h<<2)>>2]&4095](j,g);break}}}while(0);n=(c[2276064]|0)+16|0;c[2276056]=n;f=c[2276085]&n;n=f&16777215;e=c[2112932]|0;m=c[e+(n>>>10<<2)>>2]|0;if(m>>>0>9){b=f&1023;o=(d[m+(b+3)|0]|0)<<8|(d[m+(b+2)|0]|0)|((d[m+(b+1)|0]|0)<<8|(d[m+b|0]|0))<<16;c[2276056]=o;p=c[2276099]|0;q=p+4|0;r=a[q]|0;s=r&255;t=c[2276069]|0;u=c[2276098]|0;v=u+t|0;w=a[v]|0;x=w&255;y=c[2276108]|0;z=x-s|0;A=z+y|0;c[2276108]=A;return}else{o=gj[c[e+196768+(m<<2)>>2]&4095](n)|0;c[2276056]=o;p=c[2276099]|0;q=p+4|0;r=a[q]|0;s=r&255;t=c[2276069]|0;u=c[2276098]|0;v=u+t|0;w=a[v]|0;x=w&255;y=c[2276108]|0;z=x-s|0;A=z+y|0;c[2276108]=A;return}}function nj(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;if((c[2276038]&24|0)==0){ni();return}a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=f>>>((e<<3&16^16)>>>0);e=c[2276085]&c[9104156+((c[2276069]&7|8)<<2)>>2];f=e&16777215;l=c[2112932]|0;a=c[l+(f>>>10<<2)>>2]|0;if(a>>>0>9){b=e&1023;m=(d[a+(b+3)|0]|0)<<8|(d[a+(b+2)|0]|0)|((d[a+(b+1)|0]|0)<<8|(d[a+b|0]|0))<<16}else{m=gj[c[l+196768+(a<<2)>>2]&4095](f)|0}f=9104156+((k&7)<<2)|0;a=c[f>>2]|0;l=9104156+((k>>>12&7)<<2)|0;b=c[l>>2]|0;if((m|0)==0){mX();return}e=(k&2048|0)!=0;if((k&1024|0)==0){do{if(e){if(!((b|0)==-2147483648&(m|0)==-1)){c[f>>2]=(b|0)%(m|0)|0;n=(b|0)/(m|0)|0;break}c[2276075]=128;c[2276076]=-1;c[2276077]=0;c[2276078]=0;c[l>>2]=-2147483648;c[f>>2]=0;return}else{c[f>>2]=(b>>>0)%(m>>>0)|0;n=(b>>>0)/(m>>>0)|0}}while(0);c[l>>2]=n;c[2276075]=n>>>24;c[2276076]=n;c[2276077]=0;c[2276078]=0;return}if(e){if((a|0)==0&(b|0)==-2147483648&(m|0)==-1){c[f>>2]=0;c[l>>2]=-2147483648;c[2276075]=128;c[2276076]=-1;c[2276077]=0;c[2276078]=0;return}if((a|0)<0){o=1;p=-b|0;q=-(((b|0)!=0)+a|0)|0}else{o=0;p=b;q=a}r=(m|0)<0?-m|0:m;s=m>>>31;t=o;u=p;v=q}else{r=m;s=0;t=0;u=b;v=a}if(v>>>0<r>>>0){w=0;x=0;y=31}else{c[2276077]=128;return}while(1){a=w<<1;b=v>>>(y>>>0)&1|x<<1;if(b>>>0<r>>>0){z=b;A=a}else{z=b-r|0;A=a|1}if((y|0)>0){w=A;x=z;y=y-1|0}else{B=A;C=z;D=31;break}}while(1){z=B<<1;A=u>>>(D>>>0)&1|C<<1;if(A>>>0>=r>>>0|(C|0)<0){E=A-r|0;F=z|1}else{E=A;F=z}if((D|0)>0){B=F;C=E;D=D-1|0}else{break}}do{if(e){if((F|0)<0){c[2276077]=128;return}if((t|0)==0){G=E;H=F}else{G=-E|0;H=-F|0}if((s|0)==0){I=G;J=H;break}I=G;J=-H|0}else{I=E;J=F}}while(0);c[f>>2]=I;c[l>>2]=J;c[2276075]=J>>>24;c[2276076]=J;c[2276077]=0;c[2276078]=0;return}function nk(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;if((c[2276038]&24|0)==0){ni();return}a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=f>>>((e<<3&16^16)>>>0);e=9104156+((c[2276069]&7|8)<<2)|0;f=c[e>>2]|0;c[e>>2]=f+4;e=c[2276085]&f;f=e&16777215;l=c[2112932]|0;a=c[l+(f>>>10<<2)>>2]|0;if(a>>>0>9){b=e&1023;m=(d[a+(b+3)|0]|0)<<8|(d[a+(b+2)|0]|0)|((d[a+(b+1)|0]|0)<<8|(d[a+b|0]|0))<<16}else{m=gj[c[l+196768+(a<<2)>>2]&4095](f)|0}f=9104156+((k&7)<<2)|0;a=c[f>>2]|0;l=9104156+((k>>>12&7)<<2)|0;b=c[l>>2]|0;if((m|0)==0){mX();return}e=(k&2048|0)!=0;if((k&1024|0)==0){do{if(e){if(!((b|0)==-2147483648&(m|0)==-1)){c[f>>2]=(b|0)%(m|0)|0;n=(b|0)/(m|0)|0;break}c[2276075]=128;c[2276076]=-1;c[2276077]=0;c[2276078]=0;c[l>>2]=-2147483648;c[f>>2]=0;return}else{c[f>>2]=(b>>>0)%(m>>>0)|0;n=(b>>>0)/(m>>>0)|0}}while(0);c[l>>2]=n;c[2276075]=n>>>24;c[2276076]=n;c[2276077]=0;c[2276078]=0;return}if(e){if((a|0)==0&(b|0)==-2147483648&(m|0)==-1){c[f>>2]=0;c[l>>2]=-2147483648;c[2276075]=128;c[2276076]=-1;c[2276077]=0;c[2276078]=0;return}if((a|0)<0){o=1;p=-b|0;q=-(((b|0)!=0)+a|0)|0}else{o=0;p=b;q=a}r=(m|0)<0?-m|0:m;s=m>>>31;t=o;u=p;v=q}else{r=m;s=0;t=0;u=b;v=a}if(v>>>0<r>>>0){w=0;x=0;y=31}else{c[2276077]=128;return}while(1){a=w<<1;b=v>>>(y>>>0)&1|x<<1;if(b>>>0<r>>>0){z=b;A=a}else{z=b-r|0;A=a|1}if((y|0)>0){w=A;x=z;y=y-1|0}else{B=A;C=z;D=31;break}}while(1){z=B<<1;A=u>>>(D>>>0)&1|C<<1;if(A>>>0>=r>>>0|(C|0)<0){E=A-r|0;F=z|1}else{E=A;F=z}if((D|0)>0){B=F;C=E;D=D-1|0}else{break}}do{if(e){if((F|0)<0){c[2276077]=128;return}if((t|0)==0){G=E;H=F}else{G=-E|0;H=-F|0}if((s|0)==0){I=G;J=H;break}I=G;J=-H|0}else{I=E;J=F}}while(0);c[f>>2]=I;c[l>>2]=J;c[2276075]=J>>>24;c[2276076]=J;c[2276077]=0;c[2276078]=0;return}function nl(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;if((c[2276038]&24|0)==0){ni();return}a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=f>>>((e<<3&16^16)>>>0);e=9104156+((c[2276069]&7|8)<<2)|0;f=(c[e>>2]|0)-4|0;c[e>>2]=f;e=c[2276085]&f;f=e&16777215;l=c[2112932]|0;a=c[l+(f>>>10<<2)>>2]|0;if(a>>>0>9){b=e&1023;m=(d[a+(b+3)|0]|0)<<8|(d[a+(b+2)|0]|0)|((d[a+(b+1)|0]|0)<<8|(d[a+b|0]|0))<<16}else{m=gj[c[l+196768+(a<<2)>>2]&4095](f)|0}f=9104156+((k&7)<<2)|0;a=c[f>>2]|0;l=9104156+((k>>>12&7)<<2)|0;b=c[l>>2]|0;if((m|0)==0){mX();return}e=(k&2048|0)!=0;if((k&1024|0)==0){do{if(e){if(!((b|0)==-2147483648&(m|0)==-1)){c[f>>2]=(b|0)%(m|0)|0;n=(b|0)/(m|0)|0;break}c[2276075]=128;c[2276076]=-1;c[2276077]=0;c[2276078]=0;c[l>>2]=-2147483648;c[f>>2]=0;return}else{c[f>>2]=(b>>>0)%(m>>>0)|0;n=(b>>>0)/(m>>>0)|0}}while(0);c[l>>2]=n;c[2276075]=n>>>24;c[2276076]=n;c[2276077]=0;c[2276078]=0;return}if(e){if((a|0)==0&(b|0)==-2147483648&(m|0)==-1){c[f>>2]=0;c[l>>2]=-2147483648;c[2276075]=128;c[2276076]=-1;c[2276077]=0;c[2276078]=0;return}if((a|0)<0){o=1;p=-b|0;q=-(((b|0)!=0)+a|0)|0}else{o=0;p=b;q=a}r=(m|0)<0?-m|0:m;s=m>>>31;t=o;u=p;v=q}else{r=m;s=0;t=0;u=b;v=a}if(v>>>0<r>>>0){w=0;x=0;y=31}else{c[2276077]=128;return}while(1){a=w<<1;b=v>>>(y>>>0)&1|x<<1;if(b>>>0<r>>>0){z=b;A=a}else{z=b-r|0;A=a|1}if((y|0)>0){w=A;x=z;y=y-1|0}else{B=A;C=z;D=31;break}}while(1){z=B<<1;A=u>>>(D>>>0)&1|C<<1;if(A>>>0>=r>>>0|(C|0)<0){E=A-r|0;F=z|1}else{E=A;F=z}if((D|0)>0){B=F;C=E;D=D-1|0}else{break}}do{if(e){if((F|0)<0){c[2276077]=128;return}if((t|0)==0){G=E;H=F}else{G=-E|0;H=-F|0}if((s|0)==0){I=G;J=H;break}I=G;J=-H|0}else{I=E;J=F}}while(0);c[f>>2]=I;c[l>>2]=J;c[2276075]=J>>>24;c[2276076]=J;c[2276077]=0;c[2276078]=0;return}function nm(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;if((c[2276038]&24|0)==0){ni();return}a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0;g=b}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=m;g=o}o=e+2|0;c[2276056]=o;m=f>>>((e<<3&16^16)>>>0);e=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;n=o&-4;if((n|0)==(g|0)){p=o;q=f}else{c[2276083]=n;f=c[2276085]&n;n=f&16777212;g=c[2112932]|0;b=c[g+((n>>>10|32768)<<2)>>2]|0;if(b>>>0>9){i=f&1020;r=(d[b+(i|3)|0]|0)<<8|(d[b+(i|2)|0]|0)|((d[b+(i|1)|0]|0)<<8|(d[b+i|0]|0))<<16;s=o}else{o=gj[c[g+196768+(b<<2)>>2]&4095](n)|0;r=o;s=c[2276056]|0}c[2276084]=r;p=s;q=r}c[2276056]=p+2;r=(q>>>((p<<3&16^16)>>>0)<<16>>16)+e&c[2276085];e=r&16777215;p=c[2112932]|0;q=c[p+(e>>>10<<2)>>2]|0;if(q>>>0>9){s=r&1023;t=(d[q+(s+3)|0]|0)<<8|(d[q+(s+2)|0]|0)|((d[q+(s+1)|0]|0)<<8|(d[q+s|0]|0))<<16}else{t=gj[c[p+196768+(q<<2)>>2]&4095](e)|0}e=9104156+((m&7)<<2)|0;q=c[e>>2]|0;p=9104156+((m>>>12&7)<<2)|0;s=c[p>>2]|0;if((t|0)==0){mX();return}r=(m&2048|0)!=0;if((m&1024|0)==0){do{if(r){if(!((s|0)==-2147483648&(t|0)==-1)){c[e>>2]=(s|0)%(t|0)|0;u=(s|0)/(t|0)|0;break}c[2276075]=128;c[2276076]=-1;c[2276077]=0;c[2276078]=0;c[p>>2]=-2147483648;c[e>>2]=0;return}else{c[e>>2]=(s>>>0)%(t>>>0)|0;u=(s>>>0)/(t>>>0)|0}}while(0);c[p>>2]=u;c[2276075]=u>>>24;c[2276076]=u;c[2276077]=0;c[2276078]=0;return}if(r){if((q|0)==0&(s|0)==-2147483648&(t|0)==-1){c[e>>2]=0;c[p>>2]=-2147483648;c[2276075]=128;c[2276076]=-1;c[2276077]=0;c[2276078]=0;return}if((q|0)<0){v=1;w=-s|0;x=-(((s|0)!=0)+q|0)|0}else{v=0;w=s;x=q}y=(t|0)<0?-t|0:t;z=t>>>31;A=v;B=w;C=x}else{y=t;z=0;A=0;B=s;C=q}if(C>>>0<y>>>0){D=0;E=0;F=31}else{c[2276077]=128;return}while(1){q=D<<1;s=C>>>(F>>>0)&1|E<<1;if(s>>>0<y>>>0){G=s;H=q}else{G=s-y|0;H=q|1}if((F|0)>0){D=H;E=G;F=F-1|0}else{I=H;J=G;K=31;break}}while(1){G=I<<1;H=B>>>(K>>>0)&1|J<<1;if(H>>>0>=y>>>0|(J|0)<0){L=H-y|0;M=G|1}else{L=H;M=G}if((K|0)>0){I=M;J=L;K=K-1|0}else{break}}do{if(r){if((M|0)<0){c[2276077]=128;return}if((A|0)==0){N=L;O=M}else{N=-L|0;O=-M|0}if((z|0)==0){P=N;Q=O;break}P=N;Q=-O|0}else{P=L;Q=M}}while(0);c[e>>2]=P;c[p>>2]=Q;c[2276075]=Q>>>24;c[2276076]=Q;c[2276077]=0;c[2276078]=0;return}function nn(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;if((c[2276038]&24|0)==0){ni();return}a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=f>>>((e<<3&16^16)>>>0);e=nB(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;f=c[2276085]&e;e=f&16777215;l=c[2112932]|0;a=c[l+(e>>>10<<2)>>2]|0;if(a>>>0>9){b=f&1023;m=(d[a+(b+3)|0]|0)<<8|(d[a+(b+2)|0]|0)|((d[a+(b+1)|0]|0)<<8|(d[a+b|0]|0))<<16}else{m=gj[c[l+196768+(a<<2)>>2]&4095](e)|0}e=9104156+((k&7)<<2)|0;a=c[e>>2]|0;l=9104156+((k>>>12&7)<<2)|0;b=c[l>>2]|0;if((m|0)==0){mX();return}f=(k&2048|0)!=0;if((k&1024|0)==0){do{if(f){if(!((b|0)==-2147483648&(m|0)==-1)){c[e>>2]=(b|0)%(m|0)|0;n=(b|0)/(m|0)|0;break}c[2276075]=128;c[2276076]=-1;c[2276077]=0;c[2276078]=0;c[l>>2]=-2147483648;c[e>>2]=0;return}else{c[e>>2]=(b>>>0)%(m>>>0)|0;n=(b>>>0)/(m>>>0)|0}}while(0);c[l>>2]=n;c[2276075]=n>>>24;c[2276076]=n;c[2276077]=0;c[2276078]=0;return}if(f){if((a|0)==0&(b|0)==-2147483648&(m|0)==-1){c[e>>2]=0;c[l>>2]=-2147483648;c[2276075]=128;c[2276076]=-1;c[2276077]=0;c[2276078]=0;return}if((a|0)<0){o=1;p=-b|0;q=-(((b|0)!=0)+a|0)|0}else{o=0;p=b;q=a}r=(m|0)<0?-m|0:m;s=m>>>31;t=o;u=p;v=q}else{r=m;s=0;t=0;u=b;v=a}if(v>>>0<r>>>0){w=0;x=0;y=31}else{c[2276077]=128;return}while(1){a=w<<1;b=v>>>(y>>>0)&1|x<<1;if(b>>>0<r>>>0){z=b;A=a}else{z=b-r|0;A=a|1}if((y|0)>0){w=A;x=z;y=y-1|0}else{B=A;C=z;D=31;break}}while(1){z=B<<1;A=u>>>(D>>>0)&1|C<<1;if(A>>>0>=r>>>0|(C|0)<0){E=A-r|0;F=z|1}else{E=A;F=z}if((D|0)>0){B=F;C=E;D=D-1|0}else{break}}do{if(f){if((F|0)<0){c[2276077]=128;return}if((t|0)==0){G=E;H=F}else{G=-E|0;H=-F|0}if((s|0)==0){I=G;J=H;break}I=G;J=-H|0}else{I=E;J=F}}while(0);c[e>>2]=I;c[l>>2]=J;c[2276075]=J>>>24;c[2276076]=J;c[2276077]=0;c[2276078]=0;return}function no(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;if((c[2276038]&24|0)==0){ni();return}a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0;g=b}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=m;g=o}o=e+2|0;c[2276056]=o;m=f>>>((e<<3&16^16)>>>0);e=o&-4;if((e|0)==(g|0)){p=o;q=f}else{c[2276083]=e;f=c[2276085]&e;e=f&16777212;g=c[2112932]|0;n=c[g+((e>>>10|32768)<<2)>>2]|0;if(n>>>0>9){b=f&1020;r=(d[n+(b|3)|0]|0)<<8|(d[n+(b|2)|0]|0)|((d[n+(b|1)|0]|0)<<8|(d[n+b|0]|0))<<16;s=o}else{o=gj[c[g+196768+(n<<2)>>2]&4095](e)|0;r=o;s=c[2276056]|0}c[2276084]=r;p=s;q=r}c[2276056]=p+2;r=q>>>((p<<3&16^16)>>>0)<<16>>16&c[2276085];p=r&16777215;q=c[2112932]|0;s=c[q+(p>>>10<<2)>>2]|0;if(s>>>0>9){o=r&1023;t=(d[s+(o+3)|0]|0)<<8|(d[s+(o+2)|0]|0)|((d[s+(o+1)|0]|0)<<8|(d[s+o|0]|0))<<16}else{t=gj[c[q+196768+(s<<2)>>2]&4095](p)|0}p=9104156+((m&7)<<2)|0;s=c[p>>2]|0;q=9104156+((m>>>12&7)<<2)|0;o=c[q>>2]|0;if((t|0)==0){mX();return}r=(m&2048|0)!=0;if((m&1024|0)==0){do{if(r){if(!((o|0)==-2147483648&(t|0)==-1)){c[p>>2]=(o|0)%(t|0)|0;u=(o|0)/(t|0)|0;break}c[2276075]=128;c[2276076]=-1;c[2276077]=0;c[2276078]=0;c[q>>2]=-2147483648;c[p>>2]=0;return}else{c[p>>2]=(o>>>0)%(t>>>0)|0;u=(o>>>0)/(t>>>0)|0}}while(0);c[q>>2]=u;c[2276075]=u>>>24;c[2276076]=u;c[2276077]=0;c[2276078]=0;return}if(r){if((s|0)==0&(o|0)==-2147483648&(t|0)==-1){c[p>>2]=0;c[q>>2]=-2147483648;c[2276075]=128;c[2276076]=-1;c[2276077]=0;c[2276078]=0;return}if((s|0)<0){v=1;w=-o|0;x=-(((o|0)!=0)+s|0)|0}else{v=0;w=o;x=s}y=(t|0)<0?-t|0:t;z=t>>>31;A=v;B=w;C=x}else{y=t;z=0;A=0;B=o;C=s}if(C>>>0<y>>>0){D=0;E=0;F=31}else{c[2276077]=128;return}while(1){s=D<<1;o=C>>>(F>>>0)&1|E<<1;if(o>>>0<y>>>0){G=o;H=s}else{G=o-y|0;H=s|1}if((F|0)>0){D=H;E=G;F=F-1|0}else{I=H;J=G;K=31;break}}while(1){G=I<<1;H=B>>>(K>>>0)&1|J<<1;if(H>>>0>=y>>>0|(J|0)<0){L=H-y|0;M=G|1}else{L=H;M=G}if((K|0)>0){I=M;J=L;K=K-1|0}else{break}}do{if(r){if((M|0)<0){c[2276077]=128;return}if((A|0)==0){N=L;O=M}else{N=-L|0;O=-M|0}if((z|0)==0){P=N;Q=O;break}P=N;Q=-O|0}else{P=L;Q=M}}while(0);c[p>>2]=P;c[q>>2]=Q;c[2276075]=Q>>>24;c[2276076]=Q;c[2276077]=0;c[2276078]=0;return}function np(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;if((c[2276038]&24|0)==0){ni();return}a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0;g=b}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=m;g=o}o=e+2|0;c[2276056]=o;m=f>>>((e<<3&16^16)>>>0);e=o&-4;if((e|0)==(g|0)){p=o;q=g;r=f}else{c[2276083]=e;f=c[2276085]&e;g=f&16777212;n=c[2112932]|0;b=c[n+((g>>>10|32768)<<2)>>2]|0;if(b>>>0>9){i=f&1020;s=(d[b+(i|3)|0]|0)<<8|(d[b+(i|2)|0]|0)|((d[b+(i|1)|0]|0)<<8|(d[b+i|0]|0))<<16;t=o;u=e}else{e=gj[c[n+196768+(b<<2)>>2]&4095](g)|0;s=e;t=c[2276056]|0;u=c[2276083]|0}c[2276084]=s;p=t;q=u;r=s}s=p+2|0;c[2276056]=s;p=s&-4;if((p|0)==(q|0)){v=r;w=s}else{c[2276083]=p;q=c[2276085]&p;p=q&16777212;u=c[2112932]|0;t=c[u+((p>>>10|32768)<<2)>>2]|0;if(t>>>0>9){e=q&1020;x=(d[t+(e|3)|0]|0)<<8|(d[t+(e|2)|0]|0)|((d[t+(e|1)|0]|0)<<8|(d[t+e|0]|0))<<16;y=s}else{s=gj[c[u+196768+(t<<2)>>2]&4095](p)|0;x=s;y=c[2276056]|0}c[2276084]=x;v=x>>>16|r<<16;w=y}c[2276056]=w+2;w=c[2276085]&v;v=w&16777215;y=c[2112932]|0;r=c[y+(v>>>10<<2)>>2]|0;if(r>>>0>9){x=w&1023;z=(d[r+(x+3)|0]|0)<<8|(d[r+(x+2)|0]|0)|((d[r+(x+1)|0]|0)<<8|(d[r+x|0]|0))<<16}else{z=gj[c[y+196768+(r<<2)>>2]&4095](v)|0}v=9104156+((m&7)<<2)|0;r=c[v>>2]|0;y=9104156+((m>>>12&7)<<2)|0;x=c[y>>2]|0;if((z|0)==0){mX();return}w=(m&2048|0)!=0;if((m&1024|0)==0){do{if(w){if(!((x|0)==-2147483648&(z|0)==-1)){c[v>>2]=(x|0)%(z|0)|0;A=(x|0)/(z|0)|0;break}c[2276075]=128;c[2276076]=-1;c[2276077]=0;c[2276078]=0;c[y>>2]=-2147483648;c[v>>2]=0;return}else{c[v>>2]=(x>>>0)%(z>>>0)|0;A=(x>>>0)/(z>>>0)|0}}while(0);c[y>>2]=A;c[2276075]=A>>>24;c[2276076]=A;c[2276077]=0;c[2276078]=0;return}if(w){if((r|0)==0&(x|0)==-2147483648&(z|0)==-1){c[v>>2]=0;c[y>>2]=-2147483648;c[2276075]=128;c[2276076]=-1;c[2276077]=0;c[2276078]=0;return}if((r|0)<0){B=1;C=-x|0;D=-(((x|0)!=0)+r|0)|0}else{B=0;C=x;D=r}E=(z|0)<0?-z|0:z;F=z>>>31;G=B;H=C;I=D}else{E=z;F=0;G=0;H=x;I=r}if(I>>>0<E>>>0){J=0;K=0;L=31}else{c[2276077]=128;return}while(1){r=J<<1;x=I>>>(L>>>0)&1|K<<1;if(x>>>0<E>>>0){M=x;N=r}else{M=x-E|0;N=r|1}if((L|0)>0){J=N;K=M;L=L-1|0}else{O=N;P=M;Q=31;break}}while(1){M=O<<1;N=H>>>(Q>>>0)&1|P<<1;if(N>>>0>=E>>>0|(P|0)<0){R=N-E|0;S=M|1}else{R=N;S=M}if((Q|0)>0){O=S;P=R;Q=Q-1|0}else{break}}do{if(w){if((S|0)<0){c[2276077]=128;return}if((G|0)==0){T=R;U=S}else{T=-R|0;U=-S|0}if((F|0)==0){V=T;W=U;break}V=T;W=-U|0}else{V=R;W=S}}while(0);c[v>>2]=V;c[y>>2]=W;c[2276075]=W>>>24;c[2276076]=W;c[2276077]=0;c[2276078]=0;return}function nq(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;if((c[2276038]&24|0)==0){ni();return}a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0;g=b}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=m;g=o}o=e+2|0;c[2276056]=o;m=f>>>((e<<3&16^16)>>>0);e=o&-4;if((e|0)==(g|0)){p=o;q=f}else{c[2276083]=e;f=c[2276085]&e;e=f&16777212;g=c[2112932]|0;n=c[g+((e>>>10|32768)<<2)>>2]|0;if(n>>>0>9){b=f&1020;r=(d[n+(b|3)|0]|0)<<8|(d[n+(b|2)|0]|0)|((d[n+(b|1)|0]|0)<<8|(d[n+b|0]|0))<<16;s=o}else{b=gj[c[g+196768+(n<<2)>>2]&4095](e)|0;r=b;s=c[2276056]|0}c[2276084]=r;p=s;q=r}c[2276056]=p+2;r=(q>>>((p<<3&16^16)>>>0)<<16>>16)+o|0;o=r&16777215;p=c[2112932]|0;q=c[p+((o>>>10|32768)<<2)>>2]|0;if(q>>>0>9){s=r&1023;t=(d[q+(s+3)|0]|0)<<8|(d[q+(s+2)|0]|0)|((d[q+(s+1)|0]|0)<<8|(d[q+s|0]|0))<<16}else{t=gj[c[p+196768+(q<<2)>>2]&4095](o)|0}o=9104156+((m&7)<<2)|0;q=c[o>>2]|0;p=9104156+((m>>>12&7)<<2)|0;s=c[p>>2]|0;if((t|0)==0){mX();return}r=(m&2048|0)!=0;if((m&1024|0)==0){do{if(r){if(!((s|0)==-2147483648&(t|0)==-1)){c[o>>2]=(s|0)%(t|0)|0;u=(s|0)/(t|0)|0;break}c[2276075]=128;c[2276076]=-1;c[2276077]=0;c[2276078]=0;c[p>>2]=-2147483648;c[o>>2]=0;return}else{c[o>>2]=(s>>>0)%(t>>>0)|0;u=(s>>>0)/(t>>>0)|0}}while(0);c[p>>2]=u;c[2276075]=u>>>24;c[2276076]=u;c[2276077]=0;c[2276078]=0;return}if(r){if((q|0)==0&(s|0)==-2147483648&(t|0)==-1){c[o>>2]=0;c[p>>2]=-2147483648;c[2276075]=128;c[2276076]=-1;c[2276077]=0;c[2276078]=0;return}if((q|0)<0){v=1;w=-s|0;x=-(((s|0)!=0)+q|0)|0}else{v=0;w=s;x=q}y=(t|0)<0?-t|0:t;z=t>>>31;A=v;B=w;C=x}else{y=t;z=0;A=0;B=s;C=q}if(C>>>0<y>>>0){D=0;E=0;F=31}else{c[2276077]=128;return}while(1){q=D<<1;s=C>>>(F>>>0)&1|E<<1;if(s>>>0<y>>>0){G=s;H=q}else{G=s-y|0;H=q|1}if((F|0)>0){D=H;E=G;F=F-1|0}else{I=H;J=G;K=31;break}}while(1){G=I<<1;H=B>>>(K>>>0)&1|J<<1;if(H>>>0>=y>>>0|(J|0)<0){L=H-y|0;M=G|1}else{L=H;M=G}if((K|0)>0){I=M;J=L;K=K-1|0}else{break}}do{if(r){if((M|0)<0){c[2276077]=128;return}if((A|0)==0){N=L;O=M}else{N=-L|0;O=-M|0}if((z|0)==0){P=N;Q=O;break}P=N;Q=-O|0}else{P=L;Q=M}}while(0);c[o>>2]=P;c[p>>2]=Q;c[2276075]=Q>>>24;c[2276076]=Q;c[2276077]=0;c[2276078]=0;return}function nr(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;if((c[2276038]&24|0)==0){ni();return}a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}k=e+2|0;c[2276056]=k;l=f>>>((e<<3&16^16)>>>0);e=nB(k)|0;k=e&16777215;f=c[2112932]|0;a=c[f+((k>>>10|32768)<<2)>>2]|0;if(a>>>0>9){b=e&1023;m=(d[a+(b+3)|0]|0)<<8|(d[a+(b+2)|0]|0)|((d[a+(b+1)|0]|0)<<8|(d[a+b|0]|0))<<16}else{m=gj[c[f+196768+(a<<2)>>2]&4095](k)|0}k=9104156+((l&7)<<2)|0;a=c[k>>2]|0;f=9104156+((l>>>12&7)<<2)|0;b=c[f>>2]|0;if((m|0)==0){mX();return}e=(l&2048|0)!=0;if((l&1024|0)==0){do{if(e){if(!((b|0)==-2147483648&(m|0)==-1)){c[k>>2]=(b|0)%(m|0)|0;n=(b|0)/(m|0)|0;break}c[2276075]=128;c[2276076]=-1;c[2276077]=0;c[2276078]=0;c[f>>2]=-2147483648;c[k>>2]=0;return}else{c[k>>2]=(b>>>0)%(m>>>0)|0;n=(b>>>0)/(m>>>0)|0}}while(0);c[f>>2]=n;c[2276075]=n>>>24;c[2276076]=n;c[2276077]=0;c[2276078]=0;return}if(e){if((a|0)==0&(b|0)==-2147483648&(m|0)==-1){c[k>>2]=0;c[f>>2]=-2147483648;c[2276075]=128;c[2276076]=-1;c[2276077]=0;c[2276078]=0;return}if((a|0)<0){o=1;p=-b|0;q=-(((b|0)!=0)+a|0)|0}else{o=0;p=b;q=a}r=(m|0)<0?-m|0:m;s=m>>>31;t=o;u=p;v=q}else{r=m;s=0;t=0;u=b;v=a}if(v>>>0<r>>>0){w=0;x=0;y=31}else{c[2276077]=128;return}while(1){a=w<<1;b=v>>>(y>>>0)&1|x<<1;if(b>>>0<r>>>0){z=b;A=a}else{z=b-r|0;A=a|1}if((y|0)>0){w=A;x=z;y=y-1|0}else{B=A;C=z;D=31;break}}while(1){z=B<<1;A=u>>>(D>>>0)&1|C<<1;if(A>>>0>=r>>>0|(C|0)<0){E=A-r|0;F=z|1}else{E=A;F=z}if((D|0)>0){B=F;C=E;D=D-1|0}else{break}}do{if(e){if((F|0)<0){c[2276077]=128;return}if((t|0)==0){G=E;H=F}else{G=-E|0;H=-F|0}if((s|0)==0){I=G;J=H;break}I=G;J=-H|0}else{I=E;J=F}}while(0);c[k>>2]=I;c[f>>2]=J;c[2276075]=J>>>24;c[2276076]=J;c[2276077]=0;c[2276078]=0;return}function ns(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;if((c[2276038]&24|0)==0){ni();return}a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0;g=b}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=m;g=o}o=e+2|0;c[2276056]=o;m=f>>>((e<<3&16^16)>>>0);e=o&-4;if((e|0)==(g|0)){p=o;q=g;r=f}else{c[2276083]=e;f=c[2276085]&e;g=f&16777212;n=c[2112932]|0;b=c[n+((g>>>10|32768)<<2)>>2]|0;if(b>>>0>9){i=f&1020;s=(d[b+(i|3)|0]|0)<<8|(d[b+(i|2)|0]|0)|((d[b+(i|1)|0]|0)<<8|(d[b+i|0]|0))<<16;t=o;u=e}else{e=gj[c[n+196768+(b<<2)>>2]&4095](g)|0;s=e;t=c[2276056]|0;u=c[2276083]|0}c[2276084]=s;p=t;q=u;r=s}s=p+2|0;c[2276056]=s;p=s&-4;if((p|0)==(q|0)){v=r;w=s}else{c[2276083]=p;q=c[2276085]&p;p=q&16777212;u=c[2112932]|0;t=c[u+((p>>>10|32768)<<2)>>2]|0;if(t>>>0>9){e=q&1020;x=(d[t+(e|3)|0]|0)<<8|(d[t+(e|2)|0]|0)|((d[t+(e|1)|0]|0)<<8|(d[t+e|0]|0))<<16;y=s}else{s=gj[c[u+196768+(t<<2)>>2]&4095](p)|0;x=s;y=c[2276056]|0}c[2276084]=x;v=x>>>16|r<<16;w=y}c[2276056]=w+2;w=9104156+((m&7)<<2)|0;y=c[w>>2]|0;r=9104156+((m>>>12&7)<<2)|0;x=c[r>>2]|0;if((v|0)==0){mX();return}s=(m&2048|0)!=0;if((m&1024|0)==0){do{if(s){if(!((x|0)==-2147483648&(v|0)==-1)){c[w>>2]=(x|0)%(v|0)|0;z=(x|0)/(v|0)|0;break}c[2276075]=128;c[2276076]=-1;c[2276077]=0;c[2276078]=0;c[r>>2]=-2147483648;c[w>>2]=0;return}else{c[w>>2]=(x>>>0)%(v>>>0)|0;z=(x>>>0)/(v>>>0)|0}}while(0);c[r>>2]=z;c[2276075]=z>>>24;c[2276076]=z;c[2276077]=0;c[2276078]=0;return}if(s){if((y|0)==0&(x|0)==-2147483648&(v|0)==-1){c[w>>2]=0;c[r>>2]=-2147483648;c[2276075]=128;c[2276076]=-1;c[2276077]=0;c[2276078]=0;return}if((y|0)<0){A=1;B=-x|0;C=-(((x|0)!=0)+y|0)|0}else{A=0;B=x;C=y}D=(v|0)<0?-v|0:v;E=v>>>31;F=A;G=B;H=C}else{D=v;E=0;F=0;G=x;H=y}if(H>>>0<D>>>0){I=0;J=0;K=31}else{c[2276077]=128;return}while(1){y=I<<1;x=H>>>(K>>>0)&1|J<<1;if(x>>>0<D>>>0){L=x;M=y}else{L=x-D|0;M=y|1}if((K|0)>0){I=M;J=L;K=K-1|0}else{N=M;O=L;P=31;break}}while(1){L=N<<1;M=G>>>(P>>>0)&1|O<<1;if(M>>>0>=D>>>0|(O|0)<0){Q=M-D|0;R=L|1}else{Q=M;R=L}if((P|0)>0){N=R;O=Q;P=P-1|0}else{break}}do{if(s){if((R|0)<0){c[2276077]=128;return}if((F|0)==0){S=Q;T=R}else{S=-Q|0;T=-R|0}if((E|0)==0){U=S;V=T;break}U=S;V=-T|0}else{U=Q;V=R}}while(0);c[w>>2]=U;c[r>>2]=V;c[2276075]=V>>>24;c[2276076]=V;c[2276077]=0;c[2276078]=0;return}function nt(){var a=0,b=0,d=0;a=c[2276069]|0;b=9104156+((a&7)<<2)|0;d=c[b>>2]^c[9104156+((a>>>9&7)<<2)>>2]&255;c[b>>2]=d;b=d&255;c[2276075]=b;c[2276076]=b;c[2276078]=0;c[2276077]=0;return}function nu(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=c[2276069]|0;d=c[9104156+((b&7|8)<<2)>>2]|0;e=c[9104156+((b>>>9&7)<<2)>>2]|0;b=c[2276085]|0;f=b&d;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=a[i+(f&1023^1)|0]|0;k=b;l=h}else{b=gj[c[h+196608+(i<<2)>>2]&4095](g)|0;j=b;k=c[2276085]|0;l=c[2112932]|0}b=j&255^e&255;e=k&d;d=b&255;k=e&16777215;j=c[l+((k>>>10|16384)<<2)>>2]|0;if(j>>>0>9){a[j+(e&1023^1)|0]=d;c[2276075]=b;c[2276076]=b;c[2276078]=0;c[2276077]=0;return}else{gg[c[l+196648+(j<<2)>>2]&4095](k,d);c[2276075]=b;c[2276076]=b;c[2276078]=0;c[2276077]=0;return}}function nv(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;b=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;e=c[2276085]|0;f=e&d;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=a[i+(f&1023^1)|0]|0;k=e;l=h}else{e=gj[c[h+196608+(i<<2)>>2]&4095](g)|0;j=e;k=c[2276085]|0;l=c[2112932]|0}e=j&255^b&255;b=k&d;d=e&255;k=b&16777215;j=c[l+((k>>>10|16384)<<2)>>2]|0;if(j>>>0>9){a[j+(b&1023^1)|0]=d;c[2276075]=e;c[2276076]=e;c[2276078]=0;c[2276077]=0;return}else{gg[c[l+196648+(j<<2)>>2]&4095](k,d);c[2276075]=e;c[2276076]=e;c[2276078]=0;c[2276077]=0;return}}function nw(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=c[2276054]|0;c[2276054]=b+2;d=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;e=c[2276085]|0;f=e&b;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=a[i+(f&1023^1)|0]|0;k=e;l=h}else{e=gj[c[h+196608+(i<<2)>>2]&4095](g)|0;j=e;k=c[2276085]|0;l=c[2112932]|0}e=j&255^d&255;d=k&b;b=e&255;k=d&16777215;j=c[l+((k>>>10|16384)<<2)>>2]|0;if(j>>>0>9){a[j+(d&1023^1)|0]=b;c[2276075]=e;c[2276076]=e;c[2276078]=0;c[2276077]=0;return}else{gg[c[l+196648+(j<<2)>>2]&4095](k,b);c[2276075]=e;c[2276076]=e;c[2276078]=0;c[2276077]=0;return}}function nx(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;b=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;e=c[2276085]|0;f=e&d;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=a[i+(f&1023^1)|0]|0;k=e;l=h}else{e=gj[c[h+196608+(i<<2)>>2]&4095](g)|0;j=e;k=c[2276085]|0;l=c[2112932]|0}e=j&255^b&255;b=k&d;d=e&255;k=b&16777215;j=c[l+((k>>>10|16384)<<2)>>2]|0;if(j>>>0>9){a[j+(b&1023^1)|0]=d;c[2276075]=e;c[2276076]=e;c[2276078]=0;c[2276077]=0;return}else{gg[c[l+196648+(j<<2)>>2]&4095](k,d);c[2276075]=e;c[2276076]=e;c[2276078]=0;c[2276077]=0;return}}function ny(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=(c[2276054]|0)-2|0;c[2276054]=b;d=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;e=c[2276085]|0;f=e&b;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=a[i+(f&1023^1)|0]|0;k=e;l=h}else{e=gj[c[h+196608+(i<<2)>>2]&4095](g)|0;j=e;k=c[2276085]|0;l=c[2112932]|0}e=j&255^d&255;d=k&b;b=e&255;k=d&16777215;j=c[l+((k>>>10|16384)<<2)>>2]|0;if(j>>>0>9){a[j+(d&1023^1)|0]=b;c[2276075]=e;c[2276076]=e;c[2276078]=0;c[2276077]=0;return}else{gg[c[l+196648+(j<<2)>>2]&4095](k,b);c[2276075]=e;c[2276076]=e;c[2276078]=0;c[2276077]=0;return}}function nz(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=c[2276069]|0;e=c[9104156+((b&7|8)<<2)>>2]|0;f=c[2276056]|0;g=f&-4;if((g|0)==(c[2276083]|0)){h=f;i=c[2276084]|0;j=b}else{c[2276083]=g;k=c[2276085]&g;g=k&16777212;l=c[2112932]|0;m=c[l+((g>>>10|32768)<<2)>>2]|0;if(m>>>0>9){n=k&1020;o=(d[m+(n|3)|0]|0)<<8|(d[m+(n|2)|0]|0)|((d[m+(n|1)|0]|0)<<8|(d[m+n|0]|0))<<16;p=f;q=b}else{b=gj[c[l+196768+(m<<2)>>2]&4095](g)|0;o=b;p=c[2276056]|0;q=c[2276069]|0}c[2276084]=o;h=p;i=o;j=q}c[2276056]=h+2;q=(i>>>((h<<3&16^16)>>>0)<<16>>16)+e|0;e=c[9104156+((j>>>9&7)<<2)>>2]|0;j=c[2276085]|0;h=q&j;i=h&16777215;o=c[2112932]|0;p=c[o+(i>>>10<<2)>>2]|0;if(p>>>0>9){r=a[p+(h&1023^1)|0]|0;s=j;t=o}else{j=gj[c[o+196608+(p<<2)>>2]&4095](i)|0;r=j;s=c[2276085]|0;t=c[2112932]|0}j=r&255^e&255;e=s&q;q=j&255;s=e&16777215;r=c[t+((s>>>10|16384)<<2)>>2]|0;if(r>>>0>9){a[r+(e&1023^1)|0]=q;c[2276075]=j;c[2276076]=j;c[2276078]=0;c[2276077]=0;return}else{gg[c[t+196648+(r<<2)>>2]&4095](s,q);c[2276075]=j;c[2276076]=j;c[2276078]=0;c[2276077]=0;return}}function nA(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=nB(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;d=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;e=c[2276085]|0;f=e&b;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=a[i+(f&1023^1)|0]|0;k=e;l=h}else{e=gj[c[h+196608+(i<<2)>>2]&4095](g)|0;j=e;k=c[2276085]|0;l=c[2112932]|0}e=j&255^d&255;d=k&b;b=e&255;k=d&16777215;j=c[l+((k>>>10|16384)<<2)>>2]|0;if(j>>>0>9){a[j+(d&1023^1)|0]=b;c[2276075]=e;c[2276076]=e;c[2276078]=0;c[2276077]=0;return}else{gg[c[l+196648+(j<<2)>>2]&4095](k,b);c[2276075]=e;c[2276076]=e;c[2276078]=0;c[2276077]=0;return}}function nB(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}l=f+2|0;c[2276056]=l;m=g>>>((f<<3&16^16)>>>0);f=m&65535;b=c[2276038]|0;if((b&7|0)!=0){e=c[9104156+(f>>>12<<2)>>2]|0;if((m&2048|0)==0){n=e<<16>>16}else{n=e}o=(m<<24>>24)+a+n|0;return o|0}if((m&256|0)==0){n=c[9104156+(f>>>12<<2)>>2]|0;if((m&2048|0)==0){p=n<<16>>16}else{p=n}if((b&24|0)==0){q=p}else{q=p<<(m>>>9&3)}o=(m<<24>>24)+a+q|0;return o|0}c[2276108]=(c[2276108]|0)-(d[11928+(m&63)|0]|0);q=(m&128|0)==0?a:0;if((m&64|0)==0){a=c[9104156+(f>>>12<<2)>>2]|0;if((m&2048|0)==0){r=a<<16>>16}else{r=a}s=r<<(m>>>9&3)}else{s=0}do{if((m&32|0)==0){t=0;u=l;v=g}else{r=l&-4;a=(r|0)==(c[2276083]|0);if((m&16|0)==0){if(a){w=l;x=g}else{c[2276083]=r;f=c[2276085]&r;p=f&16777212;b=c[2112932]|0;n=c[b+((p>>>10|32768)<<2)>>2]|0;if(n>>>0>9){e=f&1020;y=(d[n+(e|3)|0]|0)<<8|(d[n+(e|2)|0]|0)|((d[n+(e|1)|0]|0)<<8|(d[n+e|0]|0))<<16;z=l}else{e=gj[c[b+196768+(n<<2)>>2]&4095](p)|0;y=e;z=c[2276056]|0}c[2276084]=y;w=z;x=y}e=w+2|0;c[2276056]=e;t=x>>>((w<<3&16^16)>>>0)<<16>>16;u=e;v=x;break}if(a){A=l;B=r;C=g}else{c[2276083]=r;a=c[2276085]&r;e=a&16777212;p=c[2112932]|0;n=c[p+((e>>>10|32768)<<2)>>2]|0;if(n>>>0>9){b=a&1020;D=(d[n+(b|3)|0]|0)<<8|(d[n+(b|2)|0]|0)|((d[n+(b|1)|0]|0)<<8|(d[n+b|0]|0))<<16;E=l;F=r}else{r=gj[c[p+196768+(n<<2)>>2]&4095](e)|0;D=r;E=c[2276056]|0;F=c[2276083]|0}c[2276084]=D;A=E;B=F;C=D}r=A+2|0;c[2276056]=r;e=r&-4;if((e|0)==(B|0)){G=C;H=r;I=C}else{c[2276083]=e;n=c[2276085]&e;e=n&16777212;p=c[2112932]|0;b=c[p+((e>>>10|32768)<<2)>>2]|0;if(b>>>0>9){a=n&1020;J=(d[b+(a|3)|0]|0)<<8|(d[b+(a|2)|0]|0)|((d[b+(a|1)|0]|0)<<8|(d[b+a|0]|0))<<16;K=r}else{r=gj[c[p+196768+(b<<2)>>2]&4095](e)|0;J=r;K=c[2276056]|0}c[2276084]=J;G=J>>>16|C<<16;H=K;I=J}r=H+2|0;c[2276056]=r;t=G;u=r;v=I}}while(0);if((m&7|0)==0){o=s+q+t|0;return o|0}do{if((m&2|0)==0){L=0}else{I=u&-4;G=(I|0)==(c[2276083]|0);if((m&1|0)==0){if(G){M=u;N=v}else{c[2276083]=I;H=c[2276085]&I;J=H&16777212;K=c[2112932]|0;C=c[K+((J>>>10|32768)<<2)>>2]|0;if(C>>>0>9){B=H&1020;O=(d[C+(B|3)|0]|0)<<8|(d[C+(B|2)|0]|0)|((d[C+(B|1)|0]|0)<<8|(d[C+B|0]|0))<<16;P=u}else{B=gj[c[K+196768+(C<<2)>>2]&4095](J)|0;O=B;P=c[2276056]|0}c[2276084]=O;M=P;N=O}c[2276056]=M+2;L=N>>>((M<<3&16^16)>>>0)<<16>>16;break}if(G){Q=u;R=I;S=v}else{c[2276083]=I;G=c[2276085]&I;B=G&16777212;J=c[2112932]|0;C=c[J+((B>>>10|32768)<<2)>>2]|0;if(C>>>0>9){K=G&1020;T=(d[C+(K|3)|0]|0)<<8|(d[C+(K|2)|0]|0)|((d[C+(K|1)|0]|0)<<8|(d[C+K|0]|0))<<16;U=u;V=I}else{I=gj[c[J+196768+(C<<2)>>2]&4095](B)|0;T=I;U=c[2276056]|0;V=c[2276083]|0}c[2276084]=T;Q=U;R=V;S=T}I=Q+2|0;c[2276056]=I;B=I&-4;if((B|0)==(R|0)){W=S;X=I}else{c[2276083]=B;C=c[2276085]&B;B=C&16777212;J=c[2112932]|0;K=c[J+((B>>>10|32768)<<2)>>2]|0;if(K>>>0>9){G=C&1020;Y=(d[K+(G|3)|0]|0)<<8|(d[K+(G|2)|0]|0)|((d[K+(G|1)|0]|0)<<8|(d[K+G|0]|0))<<16;Z=I}else{I=gj[c[J+196768+(K<<2)>>2]&4095](B)|0;Y=I;Z=c[2276056]|0}c[2276084]=Y;W=Y>>>16|S<<16;X=Z}c[2276056]=X+2;L=W}}while(0);W=t+q|0;if((m&4|0)==0){m=c[2276085]&W+s;q=m&16777215;t=c[2112932]|0;X=c[t+(q>>>10<<2)>>2]|0;if(X>>>0>9){Z=m&1023;_=(d[X+(Z+3)|0]|0)<<8|(d[X+(Z+2)|0]|0)|((d[X+(Z+1)|0]|0)<<8|(d[X+Z|0]|0))<<16}else{_=gj[c[t+196768+(X<<2)>>2]&4095](q)|0}o=_+L|0;return o|0}else{_=c[2276085]&W;W=_&16777215;q=c[2112932]|0;X=c[q+(W>>>10<<2)>>2]|0;if(X>>>0>9){t=_&1023;$=(d[X+(t+3)|0]|0)<<8|(d[X+(t+2)|0]|0)|((d[X+(t+1)|0]|0)<<8|(d[X+t|0]|0))<<16}else{$=gj[c[q+196768+(X<<2)>>2]&4095](W)|0}o=L+s+$|0;return o|0}return 0}function nC(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)<<16>>16;f=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;g=c[2276085]|0;m=l&g;b=m&16777215;e=c[2112932]|0;j=c[e+(b>>>10<<2)>>2]|0;if(j>>>0>9){n=a[j+(m&1023^1)|0]|0;o=g;p=e}else{g=gj[c[e+196608+(j<<2)>>2]&4095](b)|0;n=g;o=c[2276085]|0;p=c[2112932]|0}g=n&255^f&255;f=o&l;l=g&255;o=f&16777215;n=c[p+((o>>>10|16384)<<2)>>2]|0;if(n>>>0>9){a[n+(f&1023^1)|0]=l;c[2276075]=g;c[2276076]=g;c[2276078]=0;c[2276077]=0;return}else{gg[c[p+196648+(n<<2)>>2]&4095](o,l);c[2276075]=g;c[2276076]=g;c[2276078]=0;c[2276077]=0;return}}function nD(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;t=c[2276085]|0;h=t&q;s=h&16777215;n=c[2112932]|0;f=c[n+(s>>>10<<2)>>2]|0;if(f>>>0>9){u=a[f+(h&1023^1)|0]|0;v=t;w=n}else{t=gj[c[n+196608+(f<<2)>>2]&4095](s)|0;u=t;v=c[2276085]|0;w=c[2112932]|0}t=u&255^r&255;r=v&q;q=t&255;v=r&16777215;u=c[w+((v>>>10|16384)<<2)>>2]|0;if(u>>>0>9){a[u+(r&1023^1)|0]=q;c[2276075]=t;c[2276076]=t;c[2276078]=0;c[2276077]=0;return}else{gg[c[w+196648+(u<<2)>>2]&4095](v,q);c[2276075]=t;c[2276076]=t;c[2276078]=0;c[2276077]=0;return}}function nE(){var a=0,b=0,d=0;a=c[2276069]|0;b=9104156+((a&7)<<2)|0;d=c[b>>2]^c[9104156+((a>>>9&7)<<2)>>2]&65535;c[b>>2]=d;b=d&65535;c[2276075]=b>>>8;c[2276076]=b;c[2276078]=0;c[2276077]=0;return}function nF(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=c[2276069]|0;e=c[9104156+((b&7|8)<<2)>>2]|0;f=c[9104156+((b>>>9&7)<<2)>>2]|0;b=c[2276085]|0;g=b&e;h=g&16777215;i=c[2112932]|0;j=c[i+(h>>>10<<2)>>2]|0;if(j>>>0>9){k=g&1023;l=(d[j+(k+1)|0]|0)<<8|(d[j+k|0]|0);m=b;n=i}else{b=gj[c[i+196688+(j<<2)>>2]&4095](h)|0;l=b;m=c[2276085]|0;n=c[2112932]|0}b=l&65535^f&65535;f=m&e;e=b&65535;m=f&16777215;l=c[n+((m>>>10|16384)<<2)>>2]|0;if(l>>>0>9){h=f&1023;a[l+h|0]=b&255;a[l+(h+1)|0]=(e&65535)>>>8&255;o=b>>>8;c[2276075]=o;c[2276076]=b;c[2276078]=0;c[2276077]=0;return}else{gg[c[n+196728+(l<<2)>>2]&4095](m,e);o=b>>>8;c[2276075]=o;c[2276076]=b;c[2276078]=0;c[2276077]=0;return}}function nG(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=c[b>>2]|0;c[b>>2]=e+2;b=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;f=c[2276085]|0;g=f&e;h=g&16777215;i=c[2112932]|0;j=c[i+(h>>>10<<2)>>2]|0;if(j>>>0>9){k=g&1023;l=(d[j+(k+1)|0]|0)<<8|(d[j+k|0]|0);m=f;n=i}else{f=gj[c[i+196688+(j<<2)>>2]&4095](h)|0;l=f;m=c[2276085]|0;n=c[2112932]|0}f=l&65535^b&65535;b=m&e;e=f&65535;m=b&16777215;l=c[n+((m>>>10|16384)<<2)>>2]|0;if(l>>>0>9){h=b&1023;a[l+h|0]=f&255;a[l+(h+1)|0]=(e&65535)>>>8&255;o=f>>>8;c[2276075]=o;c[2276076]=f;c[2276078]=0;c[2276077]=0;return}else{gg[c[n+196728+(l<<2)>>2]&4095](m,e);o=f>>>8;c[2276075]=o;c[2276076]=f;c[2276078]=0;c[2276077]=0;return}}function nH(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=(c[b>>2]|0)-2|0;c[b>>2]=e;b=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;f=c[2276085]|0;g=f&e;h=g&16777215;i=c[2112932]|0;j=c[i+(h>>>10<<2)>>2]|0;if(j>>>0>9){k=g&1023;l=(d[j+(k+1)|0]|0)<<8|(d[j+k|0]|0);m=f;n=i}else{f=gj[c[i+196688+(j<<2)>>2]&4095](h)|0;l=f;m=c[2276085]|0;n=c[2112932]|0}f=l&65535^b&65535;b=m&e;e=f&65535;m=b&16777215;l=c[n+((m>>>10|16384)<<2)>>2]|0;if(l>>>0>9){h=b&1023;a[l+h|0]=f&255;a[l+(h+1)|0]=(e&65535)>>>8&255;o=f>>>8;c[2276075]=o;c[2276076]=f;c[2276078]=0;c[2276077]=0;return}else{gg[c[n+196728+(l<<2)>>2]&4095](m,e);o=f>>>8;c[2276075]=o;c[2276076]=f;c[2276078]=0;c[2276077]=0;return}}function nI(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;b=c[2276069]|0;e=c[9104156+((b&7|8)<<2)>>2]|0;f=c[2276056]|0;g=f&-4;if((g|0)==(c[2276083]|0)){h=f;i=c[2276084]|0;j=b}else{c[2276083]=g;k=c[2276085]&g;g=k&16777212;l=c[2112932]|0;m=c[l+((g>>>10|32768)<<2)>>2]|0;if(m>>>0>9){n=k&1020;o=(d[m+(n|3)|0]|0)<<8|(d[m+(n|2)|0]|0)|((d[m+(n|1)|0]|0)<<8|(d[m+n|0]|0))<<16;p=f;q=b}else{b=gj[c[l+196768+(m<<2)>>2]&4095](g)|0;o=b;p=c[2276056]|0;q=c[2276069]|0}c[2276084]=o;h=p;i=o;j=q}c[2276056]=h+2;q=(i>>>((h<<3&16^16)>>>0)<<16>>16)+e|0;e=c[9104156+((j>>>9&7)<<2)>>2]|0;j=c[2276085]|0;h=q&j;i=h&16777215;o=c[2112932]|0;p=c[o+(i>>>10<<2)>>2]|0;if(p>>>0>9){b=h&1023;r=(d[p+(b+1)|0]|0)<<8|(d[p+b|0]|0);s=j;t=o}else{j=gj[c[o+196688+(p<<2)>>2]&4095](i)|0;r=j;s=c[2276085]|0;t=c[2112932]|0}j=r&65535^e&65535;e=s&q;q=j&65535;s=e&16777215;r=c[t+((s>>>10|16384)<<2)>>2]|0;if(r>>>0>9){i=e&1023;a[r+i|0]=j&255;a[r+(i+1)|0]=(q&65535)>>>8&255;u=j>>>8;c[2276075]=u;c[2276076]=j;c[2276078]=0;c[2276077]=0;return}else{gg[c[t+196728+(r<<2)>>2]&4095](s,q);u=j>>>8;c[2276075]=u;c[2276076]=j;c[2276078]=0;c[2276077]=0;return}}function nJ(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=nB(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;e=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;f=c[2276085]|0;g=f&b;h=g&16777215;i=c[2112932]|0;j=c[i+(h>>>10<<2)>>2]|0;if(j>>>0>9){k=g&1023;l=(d[j+(k+1)|0]|0)<<8|(d[j+k|0]|0);m=f;n=i}else{f=gj[c[i+196688+(j<<2)>>2]&4095](h)|0;l=f;m=c[2276085]|0;n=c[2112932]|0}f=l&65535^e&65535;e=m&b;b=f&65535;m=e&16777215;l=c[n+((m>>>10|16384)<<2)>>2]|0;if(l>>>0>9){h=e&1023;a[l+h|0]=f&255;a[l+(h+1)|0]=(b&65535)>>>8&255;o=f>>>8;c[2276075]=o;c[2276076]=f;c[2276078]=0;c[2276077]=0;return}else{gg[c[n+196728+(l<<2)>>2]&4095](m,b);o=f>>>8;c[2276075]=o;c[2276076]=f;c[2276078]=0;c[2276077]=0;return}}function nK(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)<<16>>16;f=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;g=c[2276085]|0;m=l&g;b=m&16777215;e=c[2112932]|0;j=c[e+(b>>>10<<2)>>2]|0;if(j>>>0>9){i=m&1023;n=(d[j+(i+1)|0]|0)<<8|(d[j+i|0]|0);o=g;p=e}else{g=gj[c[e+196688+(j<<2)>>2]&4095](b)|0;n=g;o=c[2276085]|0;p=c[2112932]|0}g=n&65535^f&65535;f=o&l;l=g&65535;o=f&16777215;n=c[p+((o>>>10|16384)<<2)>>2]|0;if(n>>>0>9){b=f&1023;a[n+b|0]=g&255;a[n+(b+1)|0]=(l&65535)>>>8&255;q=g>>>8;c[2276075]=q;c[2276076]=g;c[2276078]=0;c[2276077]=0;return}else{gg[c[p+196728+(n<<2)>>2]&4095](o,l);q=g>>>8;c[2276075]=q;c[2276076]=g;c[2276078]=0;c[2276077]=0;return}}function nL(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;t=c[2276085]|0;h=t&q;s=h&16777215;n=c[2112932]|0;f=c[n+(s>>>10<<2)>>2]|0;if(f>>>0>9){o=h&1023;u=(d[f+(o+1)|0]|0)<<8|(d[f+o|0]|0);v=t;w=n}else{t=gj[c[n+196688+(f<<2)>>2]&4095](s)|0;u=t;v=c[2276085]|0;w=c[2112932]|0}t=u&65535^r&65535;r=v&q;q=t&65535;v=r&16777215;u=c[w+((v>>>10|16384)<<2)>>2]|0;if(u>>>0>9){s=r&1023;a[u+s|0]=t&255;a[u+(s+1)|0]=(q&65535)>>>8&255;x=t>>>8;c[2276075]=x;c[2276076]=t;c[2276078]=0;c[2276077]=0;return}else{gg[c[w+196728+(u<<2)>>2]&4095](v,q);x=t>>>8;c[2276075]=x;c[2276076]=t;c[2276078]=0;c[2276077]=0;return}}function nM(){var a=0,b=0,d=0;a=c[2276069]|0;b=9104156+((a&7)<<2)|0;d=c[b>>2]^c[9104156+((a>>>9&7)<<2)>>2];c[b>>2]=d;c[2276075]=d>>>24;c[2276076]=d;c[2276078]=0;c[2276077]=0;return}function nN(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=c[2276069]|0;e=c[9104156+((b&7|8)<<2)>>2]|0;f=c[9104156+((b>>>9&7)<<2)>>2]|0;b=c[2276085]|0;g=b&e;h=g&16777215;i=c[2112932]|0;j=c[i+(h>>>10<<2)>>2]|0;if(j>>>0>9){k=g&1023;l=(d[j+(k+3)|0]|0)<<8|(d[j+(k+2)|0]|0)|((d[j+(k+1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b;n=i}else{b=gj[c[i+196768+(j<<2)>>2]&4095](h)|0;l=b;m=c[2276085]|0;n=c[2112932]|0}b=l^f;f=m&e;e=f&16777215;m=c[n+((e>>>10|16384)<<2)>>2]|0;if(m>>>0>9){l=f&1023;a[m+l|0]=b>>>16&255;f=b>>>24;a[m+(l+1)|0]=f&255;a[m+(l+2)|0]=b&255;a[m+(l+3)|0]=b>>>8&255;o=f;c[2276075]=o;c[2276076]=b;c[2276078]=0;c[2276077]=0;return}else{gg[c[n+196808+(m<<2)>>2]&4095](e,b);o=b>>>24;c[2276075]=o;c[2276076]=b;c[2276078]=0;c[2276077]=0;return}}function nO(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=c[b>>2]|0;c[b>>2]=e+4;b=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;f=c[2276085]|0;g=f&e;h=g&16777215;i=c[2112932]|0;j=c[i+(h>>>10<<2)>>2]|0;if(j>>>0>9){k=g&1023;l=(d[j+(k+3)|0]|0)<<8|(d[j+(k+2)|0]|0)|((d[j+(k+1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=f;n=i}else{f=gj[c[i+196768+(j<<2)>>2]&4095](h)|0;l=f;m=c[2276085]|0;n=c[2112932]|0}f=l^b;b=m&e;e=b&16777215;m=c[n+((e>>>10|16384)<<2)>>2]|0;if(m>>>0>9){l=b&1023;a[m+l|0]=f>>>16&255;b=f>>>24;a[m+(l+1)|0]=b&255;a[m+(l+2)|0]=f&255;a[m+(l+3)|0]=f>>>8&255;o=b;c[2276075]=o;c[2276076]=f;c[2276078]=0;c[2276077]=0;return}else{gg[c[n+196808+(m<<2)>>2]&4095](e,f);o=f>>>24;c[2276075]=o;c[2276076]=f;c[2276078]=0;c[2276077]=0;return}}function nP(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=(c[b>>2]|0)-4|0;c[b>>2]=e;b=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;f=c[2276085]|0;g=f&e;h=g&16777215;i=c[2112932]|0;j=c[i+(h>>>10<<2)>>2]|0;if(j>>>0>9){k=g&1023;l=(d[j+(k+3)|0]|0)<<8|(d[j+(k+2)|0]|0)|((d[j+(k+1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=f;n=i}else{f=gj[c[i+196768+(j<<2)>>2]&4095](h)|0;l=f;m=c[2276085]|0;n=c[2112932]|0}f=l^b;b=m&e;e=b&16777215;m=c[n+((e>>>10|16384)<<2)>>2]|0;if(m>>>0>9){l=b&1023;a[m+l|0]=f>>>16&255;b=f>>>24;a[m+(l+1)|0]=b&255;a[m+(l+2)|0]=f&255;a[m+(l+3)|0]=f>>>8&255;o=b;c[2276075]=o;c[2276076]=f;c[2276078]=0;c[2276077]=0;return}else{gg[c[n+196808+(m<<2)>>2]&4095](e,f);o=f>>>24;c[2276075]=o;c[2276076]=f;c[2276078]=0;c[2276077]=0;return}}function nQ(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;b=c[2276069]|0;e=c[9104156+((b&7|8)<<2)>>2]|0;f=c[2276056]|0;g=f&-4;if((g|0)==(c[2276083]|0)){h=f;i=c[2276084]|0;j=b}else{c[2276083]=g;k=c[2276085]&g;g=k&16777212;l=c[2112932]|0;m=c[l+((g>>>10|32768)<<2)>>2]|0;if(m>>>0>9){n=k&1020;o=(d[m+(n|3)|0]|0)<<8|(d[m+(n|2)|0]|0)|((d[m+(n|1)|0]|0)<<8|(d[m+n|0]|0))<<16;p=f;q=b}else{b=gj[c[l+196768+(m<<2)>>2]&4095](g)|0;o=b;p=c[2276056]|0;q=c[2276069]|0}c[2276084]=o;h=p;i=o;j=q}c[2276056]=h+2;q=(i>>>((h<<3&16^16)>>>0)<<16>>16)+e|0;e=c[9104156+((j>>>9&7)<<2)>>2]|0;j=c[2276085]|0;h=q&j;i=h&16777215;o=c[2112932]|0;p=c[o+(i>>>10<<2)>>2]|0;if(p>>>0>9){b=h&1023;r=(d[p+(b+3)|0]|0)<<8|(d[p+(b+2)|0]|0)|((d[p+(b+1)|0]|0)<<8|(d[p+b|0]|0))<<16;s=j;t=o}else{j=gj[c[o+196768+(p<<2)>>2]&4095](i)|0;r=j;s=c[2276085]|0;t=c[2112932]|0}j=r^e;e=s&q;q=e&16777215;s=c[t+((q>>>10|16384)<<2)>>2]|0;if(s>>>0>9){r=e&1023;a[s+r|0]=j>>>16&255;e=j>>>24;a[s+(r+1)|0]=e&255;a[s+(r+2)|0]=j&255;a[s+(r+3)|0]=j>>>8&255;u=e;c[2276075]=u;c[2276076]=j;c[2276078]=0;c[2276077]=0;return}else{gg[c[t+196808+(s<<2)>>2]&4095](q,j);u=j>>>24;c[2276075]=u;c[2276076]=j;c[2276078]=0;c[2276077]=0;return}}function nR(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=nB(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;e=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;f=c[2276085]|0;g=f&b;h=g&16777215;i=c[2112932]|0;j=c[i+(h>>>10<<2)>>2]|0;if(j>>>0>9){k=g&1023;l=(d[j+(k+3)|0]|0)<<8|(d[j+(k+2)|0]|0)|((d[j+(k+1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=f;n=i}else{f=gj[c[i+196768+(j<<2)>>2]&4095](h)|0;l=f;m=c[2276085]|0;n=c[2112932]|0}f=l^e;e=m&b;b=e&16777215;m=c[n+((b>>>10|16384)<<2)>>2]|0;if(m>>>0>9){l=e&1023;a[m+l|0]=f>>>16&255;e=f>>>24;a[m+(l+1)|0]=e&255;a[m+(l+2)|0]=f&255;a[m+(l+3)|0]=f>>>8&255;o=e;c[2276075]=o;c[2276076]=f;c[2276078]=0;c[2276077]=0;return}else{gg[c[n+196808+(m<<2)>>2]&4095](b,f);o=f>>>24;c[2276075]=o;c[2276076]=f;c[2276078]=0;c[2276077]=0;return}}function nS(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)<<16>>16;f=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;g=c[2276085]|0;m=l&g;b=m&16777215;e=c[2112932]|0;j=c[e+(b>>>10<<2)>>2]|0;if(j>>>0>9){i=m&1023;n=(d[j+(i+3)|0]|0)<<8|(d[j+(i+2)|0]|0)|((d[j+(i+1)|0]|0)<<8|(d[j+i|0]|0))<<16;o=g;p=e}else{g=gj[c[e+196768+(j<<2)>>2]&4095](b)|0;n=g;o=c[2276085]|0;p=c[2112932]|0}g=n^f;f=o&l;l=f&16777215;o=c[p+((l>>>10|16384)<<2)>>2]|0;if(o>>>0>9){n=f&1023;a[o+n|0]=g>>>16&255;f=g>>>24;a[o+(n+1)|0]=f&255;a[o+(n+2)|0]=g&255;a[o+(n+3)|0]=g>>>8&255;q=f;c[2276075]=q;c[2276076]=g;c[2276078]=0;c[2276077]=0;return}else{gg[c[p+196808+(o<<2)>>2]&4095](l,g);q=g>>>24;c[2276075]=q;c[2276076]=g;c[2276078]=0;c[2276077]=0;return}}function nT(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;t=c[2276085]|0;h=t&q;s=h&16777215;n=c[2112932]|0;f=c[n+(s>>>10<<2)>>2]|0;if(f>>>0>9){o=h&1023;u=(d[f+(o+3)|0]|0)<<8|(d[f+(o+2)|0]|0)|((d[f+(o+1)|0]|0)<<8|(d[f+o|0]|0))<<16;v=t;w=n}else{t=gj[c[n+196768+(f<<2)>>2]&4095](s)|0;u=t;v=c[2276085]|0;w=c[2112932]|0}t=u^r;r=v&q;q=r&16777215;v=c[w+((q>>>10|16384)<<2)>>2]|0;if(v>>>0>9){u=r&1023;a[v+u|0]=t>>>16&255;r=t>>>24;a[v+(u+1)|0]=r&255;a[v+(u+2)|0]=t&255;a[v+(u+3)|0]=t>>>8&255;x=r;c[2276075]=x;c[2276076]=t;c[2276078]=0;c[2276077]=0;return}else{gg[c[w+196808+(v<<2)>>2]&4095](q,t);x=t>>>24;c[2276075]=x;c[2276076]=t;c[2276078]=0;c[2276077]=0;return}}function nU(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=9104156+((c[2276069]&7)<<2)|0;l=f>>>((e<<3&16^16)>>>0)&255^c[k>>2];c[k>>2]=l;k=l&255;c[2276075]=k;c[2276076]=k;c[2276078]=0;c[2276077]=0;return}function nV(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;m=c[2276085]|0;b=m&l;e=b&16777215;j=c[2112932]|0;i=c[j+(e>>>10<<2)>>2]|0;if(i>>>0>9){n=a[i+(b&1023^1)|0]|0;o=m;p=j}else{m=gj[c[j+196608+(i<<2)>>2]&4095](e)|0;n=m;o=c[2276085]|0;p=c[2112932]|0}m=n&255^g>>>((f<<3&16^16)>>>0)&255;f=o&l;l=m&255;o=f&16777215;g=c[p+((o>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(f&1023^1)|0]=l;c[2276075]=m;c[2276076]=m;c[2276078]=0;c[2276077]=0;return}else{gg[c[p+196648+(g<<2)>>2]&4095](o,l);c[2276075]=m;c[2276076]=m;c[2276078]=0;c[2276077]=0;return}}function nW(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=9104156+((c[2276069]&7|8)<<2)|0;m=c[l>>2]|0;c[l>>2]=m+1;l=c[2276085]|0;b=l&m;e=b&16777215;j=c[2112932]|0;i=c[j+(e>>>10<<2)>>2]|0;if(i>>>0>9){n=a[i+(b&1023^1)|0]|0;o=l;p=j}else{l=gj[c[j+196608+(i<<2)>>2]&4095](e)|0;n=l;o=c[2276085]|0;p=c[2112932]|0}l=n&255^g>>>((f<<3&16^16)>>>0)&255;f=o&m;m=l&255;o=f&16777215;g=c[p+((o>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(f&1023^1)|0]=m;c[2276075]=l;c[2276076]=l;c[2276078]=0;c[2276077]=0;return}else{gg[c[p+196648+(g<<2)>>2]&4095](o,m);c[2276075]=l;c[2276076]=l;c[2276078]=0;c[2276077]=0;return}}function nX(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=c[2276054]|0;c[2276054]=l+2;m=c[2276085]|0;b=m&l;e=b&16777215;j=c[2112932]|0;i=c[j+(e>>>10<<2)>>2]|0;if(i>>>0>9){n=a[i+(b&1023^1)|0]|0;o=m;p=j}else{m=gj[c[j+196608+(i<<2)>>2]&4095](e)|0;n=m;o=c[2276085]|0;p=c[2112932]|0}m=n&255^g>>>((f<<3&16^16)>>>0)&255;f=o&l;l=m&255;o=f&16777215;g=c[p+((o>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(f&1023^1)|0]=l;c[2276075]=m;c[2276076]=m;c[2276078]=0;c[2276077]=0;return}else{gg[c[p+196648+(g<<2)>>2]&4095](o,l);c[2276075]=m;c[2276076]=m;c[2276078]=0;c[2276077]=0;return}}function nY(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=9104156+((c[2276069]&7|8)<<2)|0;m=(c[l>>2]|0)-1|0;c[l>>2]=m;l=c[2276085]|0;b=l&m;e=b&16777215;j=c[2112932]|0;i=c[j+(e>>>10<<2)>>2]|0;if(i>>>0>9){n=a[i+(b&1023^1)|0]|0;o=l;p=j}else{l=gj[c[j+196608+(i<<2)>>2]&4095](e)|0;n=l;o=c[2276085]|0;p=c[2112932]|0}l=n&255^g>>>((f<<3&16^16)>>>0)&255;f=o&m;m=l&255;o=f&16777215;g=c[p+((o>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(f&1023^1)|0]=m;c[2276075]=l;c[2276076]=l;c[2276078]=0;c[2276077]=0;return}else{gg[c[p+196648+(g<<2)>>2]&4095](o,m);c[2276075]=l;c[2276076]=l;c[2276078]=0;c[2276077]=0;return}}function nZ(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=(c[2276054]|0)-2|0;c[2276054]=l;m=c[2276085]|0;b=m&l;e=b&16777215;j=c[2112932]|0;i=c[j+(e>>>10<<2)>>2]|0;if(i>>>0>9){n=a[i+(b&1023^1)|0]|0;o=m;p=j}else{m=gj[c[j+196608+(i<<2)>>2]&4095](e)|0;n=m;o=c[2276085]|0;p=c[2112932]|0}m=n&255^g>>>((f<<3&16^16)>>>0)&255;f=o&l;l=m&255;o=f&16777215;g=c[p+((o>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(f&1023^1)|0]=l;c[2276075]=m;c[2276076]=m;c[2276078]=0;c[2276077]=0;return}else{gg[c[p+196648+(g<<2)>>2]&4095](o,l);c[2276075]=m;c[2276076]=m;c[2276078]=0;c[2276077]=0;return}}function n_(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0)&255;f=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;o=p&-4;if((o|0)==(h|0)){q=p;r=g}else{c[2276083]=o;g=c[2276085]&o;o=g&16777212;h=c[2112932]|0;e=c[h+((o>>>10|32768)<<2)>>2]|0;if(e>>>0>9){j=g&1020;s=(d[e+(j|3)|0]|0)<<8|(d[e+(j|2)|0]|0)|((d[e+(j|1)|0]|0)<<8|(d[e+j|0]|0))<<16;t=p}else{p=gj[c[h+196768+(e<<2)>>2]&4095](o)|0;s=p;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;s=(r>>>((q<<3&16^16)>>>0)<<16>>16)+f|0;f=c[2276085]|0;q=s&f;r=q&16777215;t=c[2112932]|0;p=c[t+(r>>>10<<2)>>2]|0;if(p>>>0>9){u=a[p+(q&1023^1)|0]|0;v=f;w=t}else{f=gj[c[t+196608+(p<<2)>>2]&4095](r)|0;u=f;v=c[2276085]|0;w=c[2112932]|0}f=u&255^n;n=v&s;s=f&255;v=n&16777215;u=c[w+((v>>>10|16384)<<2)>>2]|0;if(u>>>0>9){a[u+(n&1023^1)|0]=s;c[2276075]=f;c[2276076]=f;c[2276078]=0;c[2276077]=0;return}else{gg[c[w+196648+(u<<2)>>2]&4095](v,s);c[2276075]=f;c[2276076]=f;c[2276078]=0;c[2276077]=0;return}}function n$(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=nB(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;m=c[2276085]|0;b=m&l;e=b&16777215;j=c[2112932]|0;i=c[j+(e>>>10<<2)>>2]|0;if(i>>>0>9){n=a[i+(b&1023^1)|0]|0;o=m;p=j}else{m=gj[c[j+196608+(i<<2)>>2]&4095](e)|0;n=m;o=c[2276085]|0;p=c[2112932]|0}m=n&255^g>>>((f<<3&16^16)>>>0)&255;f=o&l;l=m&255;o=f&16777215;g=c[p+((o>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(f&1023^1)|0]=l;c[2276075]=m;c[2276076]=m;c[2276078]=0;c[2276077]=0;return}else{gg[c[p+196648+(g<<2)>>2]&4095](o,l);c[2276075]=m;c[2276076]=m;c[2276078]=0;c[2276077]=0;return}}function n0(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0)&255;f=p&-4;if((f|0)==(h|0)){q=p;r=g}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;h=c[2112932]|0;o=c[h+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=p}else{p=gj[c[h+196768+(o<<2)>>2]&4095](f)|0;s=p;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;s=r>>>((q<<3&16^16)>>>0)<<16>>16;q=c[2276085]|0;r=s&q;t=r&16777215;p=c[2112932]|0;f=c[p+(t>>>10<<2)>>2]|0;if(f>>>0>9){u=a[f+(r&1023^1)|0]|0;v=q;w=p}else{q=gj[c[p+196608+(f<<2)>>2]&4095](t)|0;u=q;v=c[2276085]|0;w=c[2112932]|0}q=u&255^n;n=v&s;s=q&255;v=n&16777215;u=c[w+((v>>>10|16384)<<2)>>2]|0;if(u>>>0>9){a[u+(n&1023^1)|0]=s;c[2276075]=q;c[2276076]=q;c[2276078]=0;c[2276077]=0;return}else{gg[c[w+196648+(u<<2)>>2]&4095](v,s);c[2276075]=q;c[2276076]=q;c[2276078]=0;c[2276077]=0;return}}function n1(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0)&255;f=p&-4;if((f|0)==(h|0)){q=p;r=h;s=g}else{c[2276083]=f;g=c[2276085]&f;h=g&16777212;o=c[2112932]|0;e=c[o+((h>>>10|32768)<<2)>>2]|0;if(e>>>0>9){j=g&1020;t=(d[e+(j|3)|0]|0)<<8|(d[e+(j|2)|0]|0)|((d[e+(j|1)|0]|0)<<8|(d[e+j|0]|0))<<16;u=p;v=f}else{f=gj[c[o+196768+(e<<2)>>2]&4095](h)|0;t=f;u=c[2276056]|0;v=c[2276083]|0}c[2276084]=t;q=u;r=v;s=t}t=q+2|0;c[2276056]=t;q=t&-4;if((q|0)==(r|0)){w=s;x=t}else{c[2276083]=q;r=c[2276085]&q;q=r&16777212;v=c[2112932]|0;u=c[v+((q>>>10|32768)<<2)>>2]|0;if(u>>>0>9){f=r&1020;y=(d[u+(f|3)|0]|0)<<8|(d[u+(f|2)|0]|0)|((d[u+(f|1)|0]|0)<<8|(d[u+f|0]|0))<<16;z=t}else{t=gj[c[v+196768+(u<<2)>>2]&4095](q)|0;y=t;z=c[2276056]|0}c[2276084]=y;w=y>>>16|s<<16;x=z}c[2276056]=x+2;x=c[2276085]|0;z=x&w;s=z&16777215;y=c[2112932]|0;t=c[y+(s>>>10<<2)>>2]|0;if(t>>>0>9){A=a[t+(z&1023^1)|0]|0;B=x;C=y}else{x=gj[c[y+196608+(t<<2)>>2]&4095](s)|0;A=x;B=c[2276085]|0;C=c[2112932]|0}x=A&255^n;n=B&w;w=x&255;B=n&16777215;A=c[C+((B>>>10|16384)<<2)>>2]|0;if(A>>>0>9){a[A+(n&1023^1)|0]=w;c[2276075]=x;c[2276076]=x;c[2276078]=0;c[2276077]=0;return}else{gg[c[C+196648+(A<<2)>>2]&4095](B,w);c[2276075]=x;c[2276076]=x;c[2276078]=0;c[2276077]=0;return}}function n2(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=9104156+((c[2276069]&7)<<2)|0;l=f>>>((e<<3&16^16)>>>0)&65535^c[k>>2];c[k>>2]=l;k=l&65535;c[2276075]=k>>>8;c[2276076]=k;c[2276078]=0;c[2276077]=0;return}function n3(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;m=c[2276085]|0;b=m&l;e=b&16777215;j=c[2112932]|0;i=c[j+(e>>>10<<2)>>2]|0;if(i>>>0>9){k=b&1023;n=(d[i+(k+1)|0]|0)<<8|(d[i+k|0]|0);o=m;p=j}else{m=gj[c[j+196688+(i<<2)>>2]&4095](e)|0;n=m;o=c[2276085]|0;p=c[2112932]|0}m=n&65535^g>>>((f<<3&16^16)>>>0)&65535;f=o&l;l=m&65535;o=f&16777215;g=c[p+((o>>>10|16384)<<2)>>2]|0;if(g>>>0>9){n=f&1023;a[g+n|0]=m&255;a[g+(n+1)|0]=(l&65535)>>>8&255;q=m>>>8;c[2276075]=q;c[2276076]=m;c[2276078]=0;c[2276077]=0;return}else{gg[c[p+196728+(g<<2)>>2]&4095](o,l);q=m>>>8;c[2276075]=q;c[2276076]=m;c[2276078]=0;c[2276077]=0;return}}function n4(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=9104156+((c[2276069]&7|8)<<2)|0;m=c[l>>2]|0;c[l>>2]=m+2;l=c[2276085]|0;b=l&m;e=b&16777215;j=c[2112932]|0;i=c[j+(e>>>10<<2)>>2]|0;if(i>>>0>9){k=b&1023;n=(d[i+(k+1)|0]|0)<<8|(d[i+k|0]|0);o=l;p=j}else{l=gj[c[j+196688+(i<<2)>>2]&4095](e)|0;n=l;o=c[2276085]|0;p=c[2112932]|0}l=n&65535^g>>>((f<<3&16^16)>>>0)&65535;f=o&m;m=l&65535;o=f&16777215;g=c[p+((o>>>10|16384)<<2)>>2]|0;if(g>>>0>9){n=f&1023;a[g+n|0]=l&255;a[g+(n+1)|0]=(m&65535)>>>8&255;q=l>>>8;c[2276075]=q;c[2276076]=l;c[2276078]=0;c[2276077]=0;return}else{gg[c[p+196728+(g<<2)>>2]&4095](o,m);q=l>>>8;c[2276075]=q;c[2276076]=l;c[2276078]=0;c[2276077]=0;return}}function n5(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=9104156+((c[2276069]&7|8)<<2)|0;m=(c[l>>2]|0)-2|0;c[l>>2]=m;l=c[2276085]|0;b=l&m;e=b&16777215;j=c[2112932]|0;i=c[j+(e>>>10<<2)>>2]|0;if(i>>>0>9){k=b&1023;n=(d[i+(k+1)|0]|0)<<8|(d[i+k|0]|0);o=l;p=j}else{l=gj[c[j+196688+(i<<2)>>2]&4095](e)|0;n=l;o=c[2276085]|0;p=c[2112932]|0}l=n&65535^g>>>((f<<3&16^16)>>>0)&65535;f=o&m;m=l&65535;o=f&16777215;g=c[p+((o>>>10|16384)<<2)>>2]|0;if(g>>>0>9){n=f&1023;a[g+n|0]=l&255;a[g+(n+1)|0]=(m&65535)>>>8&255;q=l>>>8;c[2276075]=q;c[2276076]=l;c[2276078]=0;c[2276077]=0;return}else{gg[c[p+196728+(g<<2)>>2]&4095](o,m);q=l>>>8;c[2276075]=q;c[2276076]=l;c[2276078]=0;c[2276077]=0;return}}function n6(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0)&65535;f=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;o=p&-4;if((o|0)==(h|0)){q=p;r=g}else{c[2276083]=o;g=c[2276085]&o;o=g&16777212;h=c[2112932]|0;e=c[h+((o>>>10|32768)<<2)>>2]|0;if(e>>>0>9){j=g&1020;s=(d[e+(j|3)|0]|0)<<8|(d[e+(j|2)|0]|0)|((d[e+(j|1)|0]|0)<<8|(d[e+j|0]|0))<<16;t=p}else{p=gj[c[h+196768+(e<<2)>>2]&4095](o)|0;s=p;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;s=(r>>>((q<<3&16^16)>>>0)<<16>>16)+f|0;f=c[2276085]|0;q=s&f;r=q&16777215;t=c[2112932]|0;p=c[t+(r>>>10<<2)>>2]|0;if(p>>>0>9){o=q&1023;u=(d[p+(o+1)|0]|0)<<8|(d[p+o|0]|0);v=f;w=t}else{f=gj[c[t+196688+(p<<2)>>2]&4095](r)|0;u=f;v=c[2276085]|0;w=c[2112932]|0}f=u&65535^n;n=v&s;s=f&65535;v=n&16777215;u=c[w+((v>>>10|16384)<<2)>>2]|0;if(u>>>0>9){r=n&1023;a[u+r|0]=f&255;a[u+(r+1)|0]=(s&65535)>>>8&255;x=f>>>8;c[2276075]=x;c[2276076]=f;c[2276078]=0;c[2276077]=0;return}else{gg[c[w+196728+(u<<2)>>2]&4095](v,s);x=f>>>8;c[2276075]=x;c[2276076]=f;c[2276078]=0;c[2276077]=0;return}}function n7(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=nB(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;m=c[2276085]|0;b=m&l;e=b&16777215;j=c[2112932]|0;i=c[j+(e>>>10<<2)>>2]|0;if(i>>>0>9){k=b&1023;n=(d[i+(k+1)|0]|0)<<8|(d[i+k|0]|0);o=m;p=j}else{m=gj[c[j+196688+(i<<2)>>2]&4095](e)|0;n=m;o=c[2276085]|0;p=c[2112932]|0}m=n&65535^g>>>((f<<3&16^16)>>>0)&65535;f=o&l;l=m&65535;o=f&16777215;g=c[p+((o>>>10|16384)<<2)>>2]|0;if(g>>>0>9){n=f&1023;a[g+n|0]=m&255;a[g+(n+1)|0]=(l&65535)>>>8&255;q=m>>>8;c[2276075]=q;c[2276076]=m;c[2276078]=0;c[2276077]=0;return}else{gg[c[p+196728+(g<<2)>>2]&4095](o,l);q=m>>>8;c[2276075]=q;c[2276076]=m;c[2276078]=0;c[2276077]=0;return}}function n8(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0)&65535;f=p&-4;if((f|0)==(h|0)){q=p;r=g}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;h=c[2112932]|0;o=c[h+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=p}else{p=gj[c[h+196768+(o<<2)>>2]&4095](f)|0;s=p;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;s=r>>>((q<<3&16^16)>>>0)<<16>>16;q=c[2276085]|0;r=s&q;t=r&16777215;p=c[2112932]|0;f=c[p+(t>>>10<<2)>>2]|0;if(f>>>0>9){o=r&1023;u=(d[f+(o+1)|0]|0)<<8|(d[f+o|0]|0);v=q;w=p}else{q=gj[c[p+196688+(f<<2)>>2]&4095](t)|0;u=q;v=c[2276085]|0;w=c[2112932]|0}q=u&65535^n;n=v&s;s=q&65535;v=n&16777215;u=c[w+((v>>>10|16384)<<2)>>2]|0;if(u>>>0>9){t=n&1023;a[u+t|0]=q&255;a[u+(t+1)|0]=(s&65535)>>>8&255;x=q>>>8;c[2276075]=x;c[2276076]=q;c[2276078]=0;c[2276077]=0;return}else{gg[c[w+196728+(u<<2)>>2]&4095](v,s);x=q>>>8;c[2276075]=x;c[2276076]=q;c[2276078]=0;c[2276077]=0;return}}function n9(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0)&65535;f=p&-4;if((f|0)==(h|0)){q=p;r=h;s=g}else{c[2276083]=f;g=c[2276085]&f;h=g&16777212;o=c[2112932]|0;e=c[o+((h>>>10|32768)<<2)>>2]|0;if(e>>>0>9){j=g&1020;t=(d[e+(j|3)|0]|0)<<8|(d[e+(j|2)|0]|0)|((d[e+(j|1)|0]|0)<<8|(d[e+j|0]|0))<<16;u=p;v=f}else{f=gj[c[o+196768+(e<<2)>>2]&4095](h)|0;t=f;u=c[2276056]|0;v=c[2276083]|0}c[2276084]=t;q=u;r=v;s=t}t=q+2|0;c[2276056]=t;q=t&-4;if((q|0)==(r|0)){w=s;x=t}else{c[2276083]=q;r=c[2276085]&q;q=r&16777212;v=c[2112932]|0;u=c[v+((q>>>10|32768)<<2)>>2]|0;if(u>>>0>9){f=r&1020;y=(d[u+(f|3)|0]|0)<<8|(d[u+(f|2)|0]|0)|((d[u+(f|1)|0]|0)<<8|(d[u+f|0]|0))<<16;z=t}else{t=gj[c[v+196768+(u<<2)>>2]&4095](q)|0;y=t;z=c[2276056]|0}c[2276084]=y;w=y>>>16|s<<16;x=z}c[2276056]=x+2;x=c[2276085]|0;z=x&w;s=z&16777215;y=c[2112932]|0;t=c[y+(s>>>10<<2)>>2]|0;if(t>>>0>9){q=z&1023;A=(d[t+(q+1)|0]|0)<<8|(d[t+q|0]|0);B=x;C=y}else{x=gj[c[y+196688+(t<<2)>>2]&4095](s)|0;A=x;B=c[2276085]|0;C=c[2112932]|0}x=A&65535^n;n=B&w;w=x&65535;B=n&16777215;A=c[C+((B>>>10|16384)<<2)>>2]|0;if(A>>>0>9){s=n&1023;a[A+s|0]=x&255;a[A+(s+1)|0]=(w&65535)>>>8&255;D=x>>>8;c[2276075]=D;c[2276076]=x;c[2276078]=0;c[2276077]=0;return}else{gg[c[C+196728+(A<<2)>>2]&4095](B,w);D=x>>>8;c[2276075]=D;c[2276076]=x;c[2276078]=0;c[2276077]=0;return}}function oa(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=b;g=c[2276084]|0}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=o;g=m}m=e+2|0;c[2276056]=m;e=m&-4;if((e|0)==(f|0)){p=g;q=m;r=q+2|0;c[2276056]=r;s=c[2276069]|0;t=s&7;u=9104156+(t<<2)|0;v=c[u>>2]|0;w=v^p;c[u>>2]=w;x=w>>>24;c[2276075]=x;c[2276076]=w;c[2276078]=0;c[2276077]=0;return}c[2276083]=e;f=c[2276085]&e;e=f&16777212;o=c[2112932]|0;n=c[o+((e>>>10|32768)<<2)>>2]|0;if(n>>>0>9){b=f&1020;y=(d[n+(b|3)|0]|0)<<8|(d[n+(b|2)|0]|0)|((d[n+(b|1)|0]|0)<<8|(d[n+b|0]|0))<<16;z=m}else{m=gj[c[o+196768+(n<<2)>>2]&4095](e)|0;y=m;z=c[2276056]|0}c[2276084]=y;p=y>>>16|g<<16;q=z;r=q+2|0;c[2276056]=r;s=c[2276069]|0;t=s&7;u=9104156+(t<<2)|0;v=c[u>>2]|0;w=v^p;c[u>>2]=w;x=w>>>24;c[2276075]=x;c[2276076]=w;c[2276078]=0;c[2276077]=0;return}function ob(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;t=c[2276085]|0;h=t&r;s=h&16777215;n=c[2112932]|0;f=c[n+(s>>>10<<2)>>2]|0;if(f>>>0>9){o=h&1023;u=(d[f+(o+3)|0]|0)<<8|(d[f+(o+2)|0]|0)|((d[f+(o+1)|0]|0)<<8|(d[f+o|0]|0))<<16;v=t;w=n}else{t=gj[c[n+196768+(f<<2)>>2]&4095](s)|0;u=t;v=c[2276085]|0;w=c[2112932]|0}t=u^q;q=v&r;r=q&16777215;v=c[w+((r>>>10|16384)<<2)>>2]|0;if(v>>>0>9){u=q&1023;a[v+u|0]=t>>>16&255;q=t>>>24;a[v+(u+1)|0]=q&255;a[v+(u+2)|0]=t&255;a[v+(u+3)|0]=t>>>8&255;x=q;c[2276075]=x;c[2276076]=t;c[2276078]=0;c[2276077]=0;return}else{gg[c[w+196808+(v<<2)>>2]&4095](r,t);x=t>>>24;c[2276075]=x;c[2276076]=t;c[2276078]=0;c[2276077]=0;return}}function oc(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=9104156+((c[2276069]&7|8)<<2)|0;t=c[r>>2]|0;c[r>>2]=t+4;r=c[2276085]|0;h=r&t;s=h&16777215;n=c[2112932]|0;f=c[n+(s>>>10<<2)>>2]|0;if(f>>>0>9){o=h&1023;u=(d[f+(o+3)|0]|0)<<8|(d[f+(o+2)|0]|0)|((d[f+(o+1)|0]|0)<<8|(d[f+o|0]|0))<<16;v=r;w=n}else{r=gj[c[n+196768+(f<<2)>>2]&4095](s)|0;u=r;v=c[2276085]|0;w=c[2112932]|0}r=u^q;q=v&t;t=q&16777215;v=c[w+((t>>>10|16384)<<2)>>2]|0;if(v>>>0>9){u=q&1023;a[v+u|0]=r>>>16&255;q=r>>>24;a[v+(u+1)|0]=q&255;a[v+(u+2)|0]=r&255;a[v+(u+3)|0]=r>>>8&255;x=q;c[2276075]=x;c[2276076]=r;c[2276078]=0;c[2276077]=0;return}else{gg[c[w+196808+(v<<2)>>2]&4095](t,r);x=r>>>24;c[2276075]=x;c[2276076]=r;c[2276078]=0;c[2276077]=0;return}}function od(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=9104156+((c[2276069]&7|8)<<2)|0;t=(c[r>>2]|0)-4|0;c[r>>2]=t;r=c[2276085]|0;h=r&t;s=h&16777215;n=c[2112932]|0;f=c[n+(s>>>10<<2)>>2]|0;if(f>>>0>9){o=h&1023;u=(d[f+(o+3)|0]|0)<<8|(d[f+(o+2)|0]|0)|((d[f+(o+1)|0]|0)<<8|(d[f+o|0]|0))<<16;v=r;w=n}else{r=gj[c[n+196768+(f<<2)>>2]&4095](s)|0;u=r;v=c[2276085]|0;w=c[2112932]|0}r=u^q;q=v&t;t=q&16777215;v=c[w+((t>>>10|16384)<<2)>>2]|0;if(v>>>0>9){u=q&1023;a[v+u|0]=r>>>16&255;q=r>>>24;a[v+(u+1)|0]=q&255;a[v+(u+2)|0]=r&255;a[v+(u+3)|0]=r>>>8&255;x=q;c[2276075]=x;c[2276076]=r;c[2276078]=0;c[2276077]=0;return}else{gg[c[w+196808+(v<<2)>>2]&4095](t,r);x=r>>>24;c[2276075]=x;c[2276076]=r;c[2276078]=0;c[2276077]=0;return}}function oe(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;f=p&-4;if((f|0)==(h|0)){q=g;r=p;s=h;t=g}else{c[2276083]=f;h=c[2276085]&f;n=h&16777212;o=c[2112932]|0;e=c[o+((n>>>10|32768)<<2)>>2]|0;if(e>>>0>9){j=h&1020;u=(d[e+(j|3)|0]|0)<<8|(d[e+(j|2)|0]|0)|((d[e+(j|1)|0]|0)<<8|(d[e+j|0]|0))<<16;v=p;w=f}else{f=gj[c[o+196768+(e<<2)>>2]&4095](n)|0;u=f;v=c[2276056]|0;w=c[2276083]|0}c[2276084]=u;q=u>>>16|g<<16;r=v;s=w;t=u}u=r+2|0;c[2276056]=u;r=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;w=u&-4;if((w|0)==(s|0)){x=u;y=t}else{c[2276083]=w;t=c[2276085]&w;w=t&16777212;s=c[2112932]|0;v=c[s+((w>>>10|32768)<<2)>>2]|0;if(v>>>0>9){g=t&1020;z=(d[v+(g|3)|0]|0)<<8|(d[v+(g|2)|0]|0)|((d[v+(g|1)|0]|0)<<8|(d[v+g|0]|0))<<16;A=u}else{u=gj[c[s+196768+(v<<2)>>2]&4095](w)|0;z=u;A=c[2276056]|0}c[2276084]=z;x=A;y=z}c[2276056]=x+2;z=(y>>>((x<<3&16^16)>>>0)<<16>>16)+r|0;r=c[2276085]|0;x=z&r;y=x&16777215;A=c[2112932]|0;u=c[A+(y>>>10<<2)>>2]|0;if(u>>>0>9){w=x&1023;B=(d[u+(w+3)|0]|0)<<8|(d[u+(w+2)|0]|0)|((d[u+(w+1)|0]|0)<<8|(d[u+w|0]|0))<<16;C=r;D=A}else{r=gj[c[A+196768+(u<<2)>>2]&4095](y)|0;B=r;C=c[2276085]|0;D=c[2112932]|0}r=B^q;q=C&z;z=q&16777215;C=c[D+((z>>>10|16384)<<2)>>2]|0;if(C>>>0>9){B=q&1023;a[C+B|0]=r>>>16&255;q=r>>>24;a[C+(B+1)|0]=q&255;a[C+(B+2)|0]=r&255;a[C+(B+3)|0]=r>>>8&255;E=q;c[2276075]=E;c[2276076]=r;c[2276078]=0;c[2276077]=0;return}else{gg[c[D+196808+(C<<2)>>2]&4095](z,r);E=r>>>24;c[2276075]=E;c[2276076]=r;c[2276078]=0;c[2276077]=0;return}}function of(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=nB(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;t=c[2276085]|0;h=t&r;s=h&16777215;n=c[2112932]|0;f=c[n+(s>>>10<<2)>>2]|0;if(f>>>0>9){o=h&1023;u=(d[f+(o+3)|0]|0)<<8|(d[f+(o+2)|0]|0)|((d[f+(o+1)|0]|0)<<8|(d[f+o|0]|0))<<16;v=t;w=n}else{t=gj[c[n+196768+(f<<2)>>2]&4095](s)|0;u=t;v=c[2276085]|0;w=c[2112932]|0}t=u^q;q=v&r;r=q&16777215;v=c[w+((r>>>10|16384)<<2)>>2]|0;if(v>>>0>9){u=q&1023;a[v+u|0]=t>>>16&255;q=t>>>24;a[v+(u+1)|0]=q&255;a[v+(u+2)|0]=t&255;a[v+(u+3)|0]=t>>>8&255;x=q;c[2276075]=x;c[2276076]=t;c[2276078]=0;c[2276077]=0;return}else{gg[c[w+196808+(v<<2)>>2]&4095](r,t);x=t>>>24;c[2276075]=x;c[2276076]=t;c[2276078]=0;c[2276077]=0;return}}function og(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;f=p&-4;if((f|0)==(h|0)){q=g;r=p;s=h;t=g}else{c[2276083]=f;h=c[2276085]&f;n=h&16777212;o=c[2112932]|0;e=c[o+((n>>>10|32768)<<2)>>2]|0;if(e>>>0>9){j=h&1020;u=(d[e+(j|3)|0]|0)<<8|(d[e+(j|2)|0]|0)|((d[e+(j|1)|0]|0)<<8|(d[e+j|0]|0))<<16;v=p;w=f}else{f=gj[c[o+196768+(e<<2)>>2]&4095](n)|0;u=f;v=c[2276056]|0;w=c[2276083]|0}c[2276084]=u;q=u>>>16|g<<16;r=v;s=w;t=u}u=r+2|0;c[2276056]=u;r=u&-4;if((r|0)==(s|0)){x=u;y=t}else{c[2276083]=r;t=c[2276085]&r;r=t&16777212;s=c[2112932]|0;w=c[s+((r>>>10|32768)<<2)>>2]|0;if(w>>>0>9){v=t&1020;z=(d[w+(v|3)|0]|0)<<8|(d[w+(v|2)|0]|0)|((d[w+(v|1)|0]|0)<<8|(d[w+v|0]|0))<<16;A=u}else{u=gj[c[s+196768+(w<<2)>>2]&4095](r)|0;z=u;A=c[2276056]|0}c[2276084]=z;x=A;y=z}c[2276056]=x+2;z=y>>>((x<<3&16^16)>>>0)<<16>>16;x=c[2276085]|0;y=z&x;A=y&16777215;u=c[2112932]|0;r=c[u+(A>>>10<<2)>>2]|0;if(r>>>0>9){w=y&1023;B=(d[r+(w+3)|0]|0)<<8|(d[r+(w+2)|0]|0)|((d[r+(w+1)|0]|0)<<8|(d[r+w|0]|0))<<16;C=x;D=u}else{x=gj[c[u+196768+(r<<2)>>2]&4095](A)|0;B=x;C=c[2276085]|0;D=c[2112932]|0}x=B^q;q=C&z;z=q&16777215;C=c[D+((z>>>10|16384)<<2)>>2]|0;if(C>>>0>9){B=q&1023;a[C+B|0]=x>>>16&255;q=x>>>24;a[C+(B+1)|0]=q&255;a[C+(B+2)|0]=x&255;a[C+(B+3)|0]=x>>>8&255;E=q;c[2276075]=E;c[2276076]=x;c[2276078]=0;c[2276077]=0;return}else{gg[c[D+196808+(C<<2)>>2]&4095](z,x);E=x>>>24;c[2276075]=E;c[2276076]=x;c[2276078]=0;c[2276077]=0;return}}function oh(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;f=p&-4;if((f|0)==(h|0)){q=g;r=p;s=h;t=g}else{c[2276083]=f;h=c[2276085]&f;n=h&16777212;o=c[2112932]|0;e=c[o+((n>>>10|32768)<<2)>>2]|0;if(e>>>0>9){j=h&1020;u=(d[e+(j|3)|0]|0)<<8|(d[e+(j|2)|0]|0)|((d[e+(j|1)|0]|0)<<8|(d[e+j|0]|0))<<16;v=p;w=f}else{f=gj[c[o+196768+(e<<2)>>2]&4095](n)|0;u=f;v=c[2276056]|0;w=c[2276083]|0}c[2276084]=u;q=u>>>16|g<<16;r=v;s=w;t=u}u=r+2|0;c[2276056]=u;r=u&-4;if((r|0)==(s|0)){x=u;y=s;z=t}else{c[2276083]=r;t=c[2276085]&r;s=t&16777212;w=c[2112932]|0;v=c[w+((s>>>10|32768)<<2)>>2]|0;if(v>>>0>9){g=t&1020;A=(d[v+(g|3)|0]|0)<<8|(d[v+(g|2)|0]|0)|((d[v+(g|1)|0]|0)<<8|(d[v+g|0]|0))<<16;B=u;C=r}else{r=gj[c[w+196768+(v<<2)>>2]&4095](s)|0;A=r;B=c[2276056]|0;C=c[2276083]|0}c[2276084]=A;x=B;y=C;z=A}A=x+2|0;c[2276056]=A;x=A&-4;if((x|0)==(y|0)){D=z;E=A}else{c[2276083]=x;y=c[2276085]&x;x=y&16777212;C=c[2112932]|0;B=c[C+((x>>>10|32768)<<2)>>2]|0;if(B>>>0>9){r=y&1020;F=(d[B+(r|3)|0]|0)<<8|(d[B+(r|2)|0]|0)|((d[B+(r|1)|0]|0)<<8|(d[B+r|0]|0))<<16;G=A}else{A=gj[c[C+196768+(B<<2)>>2]&4095](x)|0;F=A;G=c[2276056]|0}c[2276084]=F;D=F>>>16|z<<16;E=G}c[2276056]=E+2;E=c[2276085]|0;G=E&D;z=G&16777215;F=c[2112932]|0;A=c[F+(z>>>10<<2)>>2]|0;if(A>>>0>9){x=G&1023;H=(d[A+(x+3)|0]|0)<<8|(d[A+(x+2)|0]|0)|((d[A+(x+1)|0]|0)<<8|(d[A+x|0]|0))<<16;I=E;J=F}else{E=gj[c[F+196768+(A<<2)>>2]&4095](z)|0;H=E;I=c[2276085]|0;J=c[2112932]|0}E=H^q;q=I&D;D=q&16777215;I=c[J+((D>>>10|16384)<<2)>>2]|0;if(I>>>0>9){H=q&1023;a[I+H|0]=E>>>16&255;q=E>>>24;a[I+(H+1)|0]=q&255;a[I+(H+2)|0]=E&255;a[I+(H+3)|0]=E>>>8&255;K=q;c[2276075]=K;c[2276076]=E;c[2276078]=0;c[2276077]=0;return}else{gg[c[J+196808+(I<<2)>>2]&4095](D,E);K=E>>>24;c[2276075]=K;c[2276076]=E;c[2276078]=0;c[2276077]=0;return}}function oi(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=(c[2276075]|0)>>>4&8|(c[2276074]|0)>>>4&16|((c[2276076]|0)==0)<<2|(c[2276077]|0)>>>6&2|(c[2276078]|0)>>>8&1;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)&65535^a;a=l<<4;c[2276074]=a&256;c[2276075]=a&128;c[2276076]=l>>>2&1^1;c[2276077]=l<<6&128;c[2276078]=l<<8&256;return}function oj(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=c[2276072]|0;if((a|0)==0){ol();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=a}else{c[2276083]=e;i=c[2276085]&e;e=i&16777212;j=c[2112932]|0;k=c[j+((e>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=b;o=a}else{a=gj[c[j+196768+(k<<2)>>2]&4095](e)|0;m=a;n=c[2276056]|0;o=c[2276072]|0}c[2276084]=m;f=n;g=m;h=o}c[2276056]=f+2;ok((c[2276070]|h<<11|c[2276071]|c[2276073]<<11|c[2276079]|(c[2276074]|0)>>>4&16|(c[2276075]|0)>>>4&8|((c[2276076]|0)==0)<<2|(c[2276077]|0)>>>6&2|(c[2276078]|0)>>>8&1)^g>>>((f<<3&16^16)>>>0)&65535);return}function ok(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=c[2276086]&b;c[2276070]=e&32768;c[2276071]=e&16384;c[2276079]=e&1792;b=e<<4;c[2276074]=b&256;c[2276075]=b&128;c[2276076]=e>>>2&1^1;c[2276077]=e<<6&128;c[2276078]=e<<8&256;b=e>>>11;e=c[2276072]|0;c[9104228+((e>>>1&c[2276073]|e)<<2)>>2]=c[2276054];e=b&4;c[2276072]=e;f=b&2;c[2276073]=f;c[2276054]=c[9104228+((e>>>1&f|e)<<2)>>2];e=c[2276080]|0;if(e>>>0<=(c[2276079]|0)>>>0){return}f=e>>>8;e=c[2276082]&-2;c[2276082]=e;if((e|0)!=0){return}e=8452200+(c[2394]<<2)|0;if((c[e>>2]&8192|0)!=0){c[2276080]=0;c[e>>2]=0}e=c[(c[2112932]|0)+196856>>2]|0;do{if((e|0)==0){g=15528}else{b=gj[e&4095](f)|0;if((b|0)==(-2|0)){h=24;break}else if((b|0)==(-1|0)){g=15528;break}if(b>>>0<=255){h=b;break}return}}while(0);if((g|0)==15528){h=f+24|0}g=c[2276072]|0;e=c[2276073]|0;b=c[2276071]|c[2276070]|g<<11|e<<11|c[2276079]|(c[2276074]|0)>>>4&16|(c[2276075]|0)>>>4&8|((c[2276076]|0)==0)<<2|(c[2276077]|0)>>>6&2|(c[2276078]|0)>>>8&1;c[2276071]=0;c[2276070]=0;c[9104228+((g>>>1&e|g)<<2)>>2]=c[2276054];c[2276072]=4;c[2276054]=c[9104228+((c[2276073]&2|4)<<2)>>2];c[2276079]=f<<8;f=h<<2;g=c[2276085]&(c[2276064]|0)+f;e=g&16777215;i=c[2112932]|0;j=c[i+(e>>>10<<2)>>2]|0;if(j>>>0>9){k=g&1023;l=(d[j+(k+3)|0]|0)<<8|(d[j+(k+2)|0]|0)|((d[j+(k+1)|0]|0)<<8|(d[j+k|0]|0))<<16}else{l=gj[c[i+196768+(j<<2)>>2]&4095](e)|0}do{if((l|0)==0){e=c[2276085]&(c[2276064]|0)+60;j=e&16777215;i=c[2112932]|0;k=c[i+(j>>>10<<2)>>2]|0;if(k>>>0>9){g=e&1023;m=(d[k+(g+3)|0]|0)<<8|(d[k+(g+2)|0]|0)|((d[k+(g+1)|0]|0)<<8|(d[k+g|0]|0))<<16;break}else{m=gj[c[i+196768+(k<<2)>>2]&4095](j)|0;break}}else{m=l}}while(0);l=c[2276056]|0;j=c[2276054]|0;do{if(((c[2276038]|0)-1|0)>>>0<2){k=j-4|0;c[2276054]=k;i=c[2276085]&k;k=i&16777215;g=c[2112932]|0;e=c[g+((k>>>10|16384)<<2)>>2]|0;if(e>>>0>9){n=i&1023;a[e+n|0]=l>>>16&255;a[e+(n+1)|0]=l>>>24&255;a[e+(n+2)|0]=l&255;a[e+(n+3)|0]=l>>>8&255;o=g}else{gg[c[g+196808+(e<<2)>>2]&4095](k,l);o=c[2112932]|0}k=(c[2276054]|0)-2|0;c[2276054]=k;e=c[2276085]&k;k=b&65535;g=e&16777215;n=c[o+((g>>>10|16384)<<2)>>2]|0;if(n>>>0>9){i=e&1023;a[n+i|0]=b&255;a[n+(i+1)|0]=(k&65535)>>>8&255;break}else{gg[c[o+196728+(n<<2)>>2]&4095](g,k);break}}else{k=j-2|0;c[2276054]=k;g=c[2276085]&k;k=g&16777215;n=c[2112932]|0;i=c[n+((k>>>10|16384)<<2)>>2]|0;if(i>>>0>9){e=g&1023;a[i+e|0]=f&255;a[i+(e+1)|0]=h>>>6&255;p=n}else{gg[c[n+196728+(i<<2)>>2]&4095](k,f&65535);p=c[2112932]|0}k=(c[2276054]|0)-4|0;c[2276054]=k;i=c[2276085]&k;k=i&16777215;n=c[p+((k>>>10|16384)<<2)>>2]|0;if(n>>>0>9){e=i&1023;a[n+e|0]=l>>>16&255;a[n+(e+1)|0]=l>>>24&255;a[n+(e+2)|0]=l&255;a[n+(e+3)|0]=l>>>8&255;q=p}else{gg[c[p+196808+(n<<2)>>2]&4095](k,l);q=c[2112932]|0}k=(c[2276054]|0)-2|0;c[2276054]=k;n=c[2276085]&k;k=b&65535;e=n&16777215;i=c[q+((e>>>10|16384)<<2)>>2]|0;if(i>>>0>9){g=n&1023;a[i+g|0]=b&255;a[i+(g+1)|0]=(k&65535)>>>8&255;break}else{gg[c[q+196728+(i<<2)>>2]&4095](e,k);break}}}while(0);q=c[2276073]|0;do{if((q|0)!=0){if((c[2276038]&24|0)==0){break}l=c[2276072]|0;c[9104228+((l>>>1&q|l)<<2)>>2]=c[2276054];p=l&4;c[2276072]=p;j=l&2;c[2276073]=j;l=c[2276056]|0;o=(c[9104228+((p>>>1&j|p)<<2)>>2]|0)-2|0;c[2276054]=o;p=c[2276085]&o;o=(f|4096)&65535;j=p&16777215;k=c[2112932]|0;e=c[k+((j>>>10|16384)<<2)>>2]|0;if(e>>>0>9){i=p&1023;a[e+i|0]=f&255;a[e+(i+1)|0]=(o&65535)>>>8&255;r=k}else{gg[c[k+196728+(e<<2)>>2]&4095](j,o);r=c[2112932]|0}o=(c[2276054]|0)-4|0;c[2276054]=o;j=c[2276085]&o;o=j&16777215;e=c[r+((o>>>10|16384)<<2)>>2]|0;if(e>>>0>9){k=j&1023;a[e+k|0]=l>>>16&255;a[e+(k+1)|0]=l>>>24&255;a[e+(k+2)|0]=l&255;a[e+(k+3)|0]=l>>>8&255;s=r}else{gg[c[r+196808+(e<<2)>>2]&4095](o,l);s=c[2112932]|0}l=(c[2276054]|0)-2|0;c[2276054]=l;o=c[2276085]&l;l=(b|8192)&65535;e=o&16777215;k=c[s+((e>>>10|16384)<<2)>>2]|0;if(k>>>0>9){j=o&1023;a[k+j|0]=b&255;a[k+(j+1)|0]=(l&65535)>>>8&255;break}else{gg[c[s+196728+(k<<2)>>2]&4095](e,l);break}}}while(0);c[2276056]=m;c[2276081]=(c[2276081]|0)+(d[(c[2276099]|0)+h|0]|0);return}function ol(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;b=c[2276072]|0;e=c[2276073]|0;f=c[2276071]|c[2276070]|b<<11|e<<11|c[2276079]|(c[2276074]|0)>>>4&16|(c[2276075]|0)>>>4&8|((c[2276076]|0)==0)<<2|(c[2276077]|0)>>>6&2|(c[2276078]|0)>>>8&1;c[2276071]=0;c[2276070]=0;c[9104228+((b>>>1&e|b)<<2)>>2]=c[2276054];c[2276072]=4;b=c[9104228+((c[2276073]&2|4)<<2)>>2]|0;c[2276054]=b;e=c[2276055]|0;do{if(((c[2276038]|0)-1|0)>>>0<2){g=b-4|0;c[2276054]=g;h=c[2276085]&g;g=h&16777215;i=c[2112932]|0;j=c[i+((g>>>10|16384)<<2)>>2]|0;if(j>>>0>9){k=h&1023;a[j+k|0]=e>>>16&255;a[j+(k+1)|0]=e>>>24&255;a[j+(k+2)|0]=e&255;a[j+(k+3)|0]=e>>>8&255;l=i}else{gg[c[i+196808+(j<<2)>>2]&4095](g,e);l=c[2112932]|0}g=(c[2276054]|0)-2|0;c[2276054]=g;j=c[2276085]&g;g=f&65535;i=j&16777215;k=c[l+((i>>>10|16384)<<2)>>2]|0;if(k>>>0>9){h=j&1023;a[k+h|0]=f&255;a[k+(h+1)|0]=(g&65535)>>>8&255;break}else{gg[c[l+196728+(k<<2)>>2]&4095](i,g);break}}else{g=b-2|0;c[2276054]=g;i=c[2276085]&g;g=i&16777215;k=c[2112932]|0;h=c[k+((g>>>10|16384)<<2)>>2]|0;if(h>>>0>9){j=i&1023;a[h+j|0]=32;a[h+(j+1)|0]=0;m=k}else{gg[c[k+196728+(h<<2)>>2]&4095](g,32);m=c[2112932]|0}g=(c[2276054]|0)-4|0;c[2276054]=g;h=c[2276085]&g;g=h&16777215;k=c[m+((g>>>10|16384)<<2)>>2]|0;if(k>>>0>9){j=h&1023;a[k+j|0]=e>>>16&255;a[k+(j+1)|0]=e>>>24&255;a[k+(j+2)|0]=e&255;a[k+(j+3)|0]=e>>>8&255;n=m}else{gg[c[m+196808+(k<<2)>>2]&4095](g,e);n=c[2112932]|0}g=(c[2276054]|0)-2|0;c[2276054]=g;k=c[2276085]&g;g=f&65535;j=k&16777215;h=c[n+((j>>>10|16384)<<2)>>2]|0;if(h>>>0>9){i=k&1023;a[h+i|0]=f&255;a[h+(i+1)|0]=(g&65535)>>>8&255;break}else{gg[c[n+196728+(h<<2)>>2]&4095](j,g);break}}}while(0);n=(c[2276064]|0)+32|0;c[2276056]=n;f=c[2276085]&n;n=f&16777215;e=c[2112932]|0;m=c[e+(n>>>10<<2)>>2]|0;if(m>>>0>9){b=f&1023;o=(d[m+(b+3)|0]|0)<<8|(d[m+(b+2)|0]|0)|((d[m+(b+1)|0]|0)<<8|(d[m+b|0]|0))<<16;c[2276056]=o;p=c[2276099]|0;q=p+8|0;r=a[q]|0;s=r&255;t=c[2276069]|0;u=c[2276098]|0;v=u+t|0;w=a[v]|0;x=w&255;y=c[2276108]|0;z=x-s|0;A=z+y|0;c[2276108]=A;return}else{o=gj[c[e+196768+(m<<2)>>2]&4095](n)|0;c[2276056]=o;p=c[2276099]|0;q=p+8|0;r=a[q]|0;s=r&255;t=c[2276069]|0;u=c[2276098]|0;v=u+t|0;w=a[v]|0;x=w&255;y=c[2276108]|0;z=x-s|0;A=z+y|0;c[2276108]=A;return}}function om(){var a=0,b=0,d=0;a=c[2276069]|0;b=9104156+((a>>>9&7)<<2)|0;d=9104156+((a&7)<<2)|0;a=c[b>>2]|0;c[b>>2]=c[d>>2];c[d>>2]=a;return}function on(){var a=0,b=0,d=0;a=c[2276069]|0;b=9104156+((a>>>9&7|8)<<2)|0;d=9104156+((a&7|8)<<2)|0;a=c[b>>2]|0;c[b>>2]=c[d>>2];c[d>>2]=a;return}function oo(){var a=0,b=0,d=0;a=c[2276069]|0;b=9104156+((a>>>9&7)<<2)|0;d=9104156+((a&7|8)<<2)|0;a=c[b>>2]|0;c[b>>2]=c[d>>2];c[d>>2]=a;return}function op(){var a=0,b=0,d=0;a=9104156+((c[2276069]&7)<<2)|0;b=c[a>>2]|0;d=((b&128|0)!=0?65280:0)|b&-65281;c[a>>2]=d;c[2276075]=d>>>8;c[2276076]=c[a>>2]&65535;c[2276077]=0;c[2276078]=0;return}function oq(){var a=0,b=0,d=0;a=9104156+((c[2276069]&7)<<2)|0;b=c[a>>2]|0;d=(b&32768|0)!=0?-65536:0;c[a>>2]=d|b&65535;c[2276075]=d>>>24;c[2276076]=c[a>>2];c[2276077]=0;c[2276078]=0;return}function or(){var a=0,b=0,d=0;if((c[2276038]&24|0)==0){ni();return}else{a=9104156+((c[2276069]&7)<<2)|0;b=c[a>>2]|0;d=(b&128|0)!=0?-256:0;c[a>>2]=d|b&255;c[2276075]=d>>>24;c[2276076]=c[a>>2];c[2276077]=0;c[2276078]=0;return}}function os(){ni();return}function ot(){var a=0;a=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;c[2276056]=a;if((a|0)!=(c[2276055]|0)){return}c[2276108]=0;return}function ou(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}l=(g>>>((f<<3&16^16)>>>0)<<16>>16)+a|0;c[2276056]=l;if((l|0)!=(c[2276055]|0)){return}c[2276108]=0;return}function ov(){var a=0;a=nB(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;c[2276056]=a;if((a|0)!=(c[2276055]|0)){return}c[2276108]=0;return}function ow(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}k=f>>>((e<<3&16^16)>>>0)<<16>>16;c[2276056]=k;if((k|0)!=(c[2276055]|0)){return}c[2276108]=0;return}function ox(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=b;g=c[2276084]|0}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=o;g=m}m=e+2|0;c[2276056]=m;e=m&-4;if((e|0)==(f|0)){p=g}else{c[2276083]=e;f=c[2276085]&e;e=f&16777212;m=c[2112932]|0;o=c[m+((e>>>10|32768)<<2)>>2]|0;if(o>>>0>9){n=f&1020;q=(d[o+(n|3)|0]|0)<<8|(d[o+(n|2)|0]|0)|((d[o+(n|1)|0]|0)<<8|(d[o+n|0]|0))<<16}else{q=gj[c[m+196768+(o<<2)>>2]&4095](e)|0}c[2276084]=q;p=q>>>16|g<<16}c[2276056]=p;if((p|0)!=(c[2276055]|0)){return}c[2276108]=0;return}function oy(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{j=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=j;l=c[2276056]|0}c[2276084]=k;e=l;f=k}k=(f>>>((e<<3&16^16)>>>0)<<16>>16)+a|0;c[2276056]=k;if((k|0)!=(c[2276055]|0)){return}c[2276108]=0;return}function oz(){var a=0;a=nB(c[2276056]|0)|0;c[2276056]=a;if((a|0)!=(c[2276055]|0)){return}c[2276108]=0;return}function oA(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;d=c[2276056]|0;e=(c[2276054]|0)-4|0;c[2276054]=e;f=c[2276085]&e;e=f&16777215;g=c[2112932]|0;h=c[g+((e>>>10|16384)<<2)>>2]|0;if(h>>>0>9){i=f&1023;a[h+i|0]=d>>>16&255;a[h+(i+1)|0]=d>>>24&255;a[h+(i+2)|0]=d&255;a[h+(i+3)|0]=d>>>8&255;c[2276056]=b;return}else{gg[c[g+196808+(h<<2)>>2]&4095](e,d);c[2276056]=b;return}}function oB(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}m=g+2|0;c[2276056]=m;n=(h>>>((g<<3&16^16)>>>0)<<16>>16)+b|0;b=(c[2276054]|0)-4|0;c[2276054]=b;g=c[2276085]&b;b=g&16777215;h=c[2112932]|0;e=c[h+((b>>>10|16384)<<2)>>2]|0;if(e>>>0>9){f=g&1023;a[e+f|0]=m>>>16&255;a[e+(f+1)|0]=m>>>24&255;a[e+(f+2)|0]=m&255;a[e+(f+3)|0]=m>>>8&255;c[2276056]=n;return}else{gg[c[h+196808+(e<<2)>>2]&4095](b,m);c[2276056]=n;return}}function oC(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=nB(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;d=c[2276056]|0;e=(c[2276054]|0)-4|0;c[2276054]=e;f=c[2276085]&e;e=f&16777215;g=c[2112932]|0;h=c[g+((e>>>10|16384)<<2)>>2]|0;if(h>>>0>9){i=f&1023;a[h+i|0]=d>>>16&255;a[h+(i+1)|0]=d>>>24&255;a[h+(i+2)|0]=d&255;a[h+(i+3)|0]=d>>>8&255;c[2276056]=b;return}else{gg[c[g+196808+(h<<2)>>2]&4095](e,d);c[2276056]=b;return}}function oD(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}l=f+2|0;c[2276056]=l;m=g>>>((f<<3&16^16)>>>0)<<16>>16;f=(c[2276054]|0)-4|0;c[2276054]=f;g=c[2276085]&f;f=g&16777215;b=c[2112932]|0;e=c[b+((f>>>10|16384)<<2)>>2]|0;if(e>>>0>9){j=g&1023;a[e+j|0]=l>>>16&255;a[e+(j+1)|0]=l>>>24&255;a[e+(j+2)|0]=l&255;a[e+(j+3)|0]=l>>>8&255;c[2276056]=m;return}else{gg[c[b+196808+(e<<2)>>2]&4095](f,l);c[2276056]=m;return}}function oE(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}t=r+2|0;c[2276056]=t;r=(c[2276054]|0)-4|0;c[2276054]=r;h=c[2276085]&r;r=h&16777215;s=c[2112932]|0;n=c[s+((r>>>10|16384)<<2)>>2]|0;if(n>>>0>9){f=h&1023;a[n+f|0]=t>>>16&255;a[n+(f+1)|0]=t>>>24&255;a[n+(f+2)|0]=t&255;a[n+(f+3)|0]=t>>>8&255;c[2276056]=q;return}else{gg[c[s+196808+(n<<2)>>2]&4095](r,t);c[2276056]=q;return}}function oF(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{k=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=k;m=c[2276056]|0}c[2276084]=l;f=m;g=l}l=f+2|0;c[2276056]=l;m=(g>>>((f<<3&16^16)>>>0)<<16>>16)+b|0;b=(c[2276054]|0)-4|0;c[2276054]=b;f=c[2276085]&b;b=f&16777215;g=c[2112932]|0;k=c[g+((b>>>10|16384)<<2)>>2]|0;if(k>>>0>9){e=f&1023;a[k+e|0]=l>>>16&255;a[k+(e+1)|0]=l>>>24&255;a[k+(e+2)|0]=l&255;a[k+(e+3)|0]=l>>>8&255;c[2276056]=m;return}else{gg[c[g+196808+(k<<2)>>2]&4095](b,l);c[2276056]=m;return}}function oG(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=nB(c[2276056]|0)|0;d=c[2276056]|0;e=(c[2276054]|0)-4|0;c[2276054]=e;f=c[2276085]&e;e=f&16777215;g=c[2112932]|0;h=c[g+((e>>>10|16384)<<2)>>2]|0;if(h>>>0>9){i=f&1023;a[h+i|0]=d>>>16&255;a[h+(i+1)|0]=d>>>24&255;a[h+(i+2)|0]=d&255;a[h+(i+3)|0]=d>>>8&255;c[2276056]=b;return}else{gg[c[g+196808+(h<<2)>>2]&4095](e,d);c[2276056]=b;return}}function oH(){var a=0;a=c[2276069]|0;c[9104156+((a>>>9&7|8)<<2)>>2]=c[9104156+((a&7|8)<<2)>>2];return}function oI(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;a=c[2276069]|0;b=c[9104156+((a&7|8)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0;i=a;j=g+2|0;c[2276056]=j;k=g<<3;l=k&16;m=l^16;n=h>>>(m>>>0);o=n<<16;p=o>>16;q=p+b|0;r=i>>>9;s=r&7;t=s|8;u=9104156+(t<<2)|0;c[u>>2]=q;return}c[2276083]=f;v=c[2276085]&f;f=v&16777212;w=c[2112932]|0;x=c[w+((f>>>10|32768)<<2)>>2]|0;if(x>>>0>9){y=v&1020;z=(d[x+(y|3)|0]|0)<<8|(d[x+(y|2)|0]|0)|((d[x+(y|1)|0]|0)<<8|(d[x+y|0]|0))<<16;A=e;B=a}else{a=gj[c[w+196768+(x<<2)>>2]&4095](f)|0;z=a;A=c[2276056]|0;B=c[2276069]|0}c[2276084]=z;g=A;h=z;i=B;j=g+2|0;c[2276056]=j;k=g<<3;l=k&16;m=l^16;n=h>>>(m>>>0);o=n<<16;p=o>>16;q=p+b|0;r=i>>>9;s=r&7;t=s|8;u=9104156+(t<<2)|0;c[u>>2]=q;return}function oJ(){var a=0;a=nB(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2]=a;return}function oK(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2]=f>>>((e<<3&16^16)>>>0)<<16>>16;return}function oL(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=b;g=c[2276084]|0}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=o;g=m}m=e+2|0;c[2276056]=m;e=m&-4;if((e|0)==(f|0)){p=g;q=m;r=q+2|0;c[2276056]=r;s=c[2276069]|0;t=s>>>9;u=t&7;v=u|8;w=9104156+(v<<2)|0;c[w>>2]=p;return}c[2276083]=e;f=c[2276085]&e;e=f&16777212;o=c[2112932]|0;n=c[o+((e>>>10|32768)<<2)>>2]|0;if(n>>>0>9){b=f&1020;x=(d[n+(b|3)|0]|0)<<8|(d[n+(b|2)|0]|0)|((d[n+(b|1)|0]|0)<<8|(d[n+b|0]|0))<<16;y=m}else{m=gj[c[o+196768+(n<<2)>>2]&4095](e)|0;x=m;y=c[2276056]|0}c[2276084]=x;p=x>>>16|g<<16;q=y;r=q+2|0;c[2276056]=r;s=c[2276069]|0;t=s>>>9;u=t&7;v=u|8;w=9104156+(v<<2)|0;c[w>>2]=p;return}function oM(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{j=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=j;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2]=(f>>>((e<<3&16^16)>>>0)<<16>>16)+a;return}function oN(){var a=0;a=nB(c[2276056]|0)|0;c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2]=a;return}function oO(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;b=(c[2276054]|0)-4|0;c[2276054]=b;e=c[2276085]&b;f=e&16777215;g=c[2112932]|0;h=c[g+((f>>>10|16384)<<2)>>2]|0;if(h>>>0>9){i=e&1023;a[h+i|0]=b>>>16&255;a[h+(i+1)|0]=b>>>24&255;a[h+(i+2)|0]=b&255;a[h+(i+3)|0]=b>>>8&255}else{gg[c[g+196808+(h<<2)>>2]&4095](f,b)}b=c[2276054]|0;f=c[2276056]|0;h=f&-4;if((h|0)==(c[2276083]|0)){j=f;k=c[2276084]|0;l=j+2|0;c[2276056]=l;m=j<<3;n=m&16;o=n^16;p=k>>>(o>>>0);q=p<<16;r=q>>16;s=r+b|0;c[2276054]=s;return}c[2276083]=h;g=c[2276085]&h;h=g&16777212;i=c[2112932]|0;e=c[i+((h>>>10|32768)<<2)>>2]|0;if(e>>>0>9){t=g&1020;u=(d[e+(t|3)|0]|0)<<8|(d[e+(t|2)|0]|0)|((d[e+(t|1)|0]|0)<<8|(d[e+t|0]|0))<<16;v=f}else{f=gj[c[i+196768+(e<<2)>>2]&4095](h)|0;u=f;v=c[2276056]|0}c[2276084]=u;j=v;k=u;l=j+2|0;c[2276056]=l;m=j<<3;n=m&16;o=n^16;p=k>>>(o>>>0);q=p<<16;r=q>>16;s=r+b|0;c[2276054]=s;return}function oP(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=c[b>>2]|0;f=(c[2276054]|0)-4|0;c[2276054]=f;g=c[2276085]&f;f=g&16777215;h=c[2112932]|0;i=c[h+((f>>>10|16384)<<2)>>2]|0;if(i>>>0>9){j=g&1023;a[i+j|0]=e>>>16&255;a[i+(j+1)|0]=e>>>24&255;a[i+(j+2)|0]=e&255;a[i+(j+3)|0]=e>>>8&255}else{gg[c[h+196808+(i<<2)>>2]&4095](f,e)}c[b>>2]=c[2276054];b=c[2276054]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){k=e;l=c[2276084]|0;m=k+2|0;c[2276056]=m;n=k<<3;o=n&16;p=o^16;q=l>>>(p>>>0);r=q<<16;s=r>>16;t=s+b|0;c[2276054]=t;return}c[2276083]=f;i=c[2276085]&f;f=i&16777212;h=c[2112932]|0;j=c[h+((f>>>10|32768)<<2)>>2]|0;if(j>>>0>9){g=i&1020;u=(d[j+(g|3)|0]|0)<<8|(d[j+(g|2)|0]|0)|((d[j+(g|1)|0]|0)<<8|(d[j+g|0]|0))<<16;v=e}else{e=gj[c[h+196768+(j<<2)>>2]&4095](f)|0;u=e;v=c[2276056]|0}c[2276084]=u;k=v;l=u;m=k+2|0;c[2276056]=m;n=k<<3;o=n&16;p=o^16;q=l>>>(p>>>0);r=q<<16;s=r>>16;t=s+b|0;c[2276054]=t;return}function oQ(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;if((c[2276038]&24|0)==0){ni();return}b=(c[2276054]|0)-4|0;c[2276054]=b;e=c[2276085]&b;f=e&16777215;g=c[2112932]|0;h=c[g+((f>>>10|16384)<<2)>>2]|0;if(h>>>0>9){i=e&1023;a[h+i|0]=b>>>16&255;a[h+(i+1)|0]=b>>>24&255;a[h+(i+2)|0]=b&255;a[h+(i+3)|0]=b>>>8&255}else{gg[c[g+196808+(h<<2)>>2]&4095](f,b)}b=c[2276054]|0;f=c[2276056]|0;h=f&-4;if((h|0)==(c[2276083]|0)){j=f;k=h;l=c[2276084]|0}else{c[2276083]=h;g=c[2276085]&h;i=g&16777212;e=c[2112932]|0;m=c[e+((i>>>10|32768)<<2)>>2]|0;if(m>>>0>9){n=g&1020;o=(d[m+(n|3)|0]|0)<<8|(d[m+(n|2)|0]|0)|((d[m+(n|1)|0]|0)<<8|(d[m+n|0]|0))<<16;p=f;q=h}else{h=gj[c[e+196768+(m<<2)>>2]&4095](i)|0;o=h;p=c[2276056]|0;q=c[2276083]|0}c[2276084]=o;j=p;k=q;l=o}o=j+2|0;c[2276056]=o;j=o&-4;if((j|0)==(k|0)){r=l;s=o}else{c[2276083]=j;k=c[2276085]&j;j=k&16777212;q=c[2112932]|0;p=c[q+((j>>>10|32768)<<2)>>2]|0;if(p>>>0>9){h=k&1020;t=(d[p+(h|3)|0]|0)<<8|(d[p+(h|2)|0]|0)|((d[p+(h|1)|0]|0)<<8|(d[p+h|0]|0))<<16;u=o}else{o=gj[c[q+196768+(p<<2)>>2]&4095](j)|0;t=o;u=c[2276056]|0}c[2276084]=t;r=t>>>16|l<<16;s=u}c[2276056]=s+2;c[2276054]=r+b;return}function oR(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;if((c[2276038]&24|0)==0){ni();return}b=9104156+((c[2276069]&7|8)<<2)|0;e=c[b>>2]|0;f=(c[2276054]|0)-4|0;c[2276054]=f;g=c[2276085]&f;f=g&16777215;h=c[2112932]|0;i=c[h+((f>>>10|16384)<<2)>>2]|0;if(i>>>0>9){j=g&1023;a[i+j|0]=e>>>16&255;a[i+(j+1)|0]=e>>>24&255;a[i+(j+2)|0]=e&255;a[i+(j+3)|0]=e>>>8&255}else{gg[c[h+196808+(i<<2)>>2]&4095](f,e)}c[b>>2]=c[2276054];b=c[2276054]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){k=e;l=f;m=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;h=i&16777212;j=c[2112932]|0;g=c[j+((h>>>10|32768)<<2)>>2]|0;if(g>>>0>9){n=i&1020;o=(d[g+(n|3)|0]|0)<<8|(d[g+(n|2)|0]|0)|((d[g+(n|1)|0]|0)<<8|(d[g+n|0]|0))<<16;p=e;q=f}else{f=gj[c[j+196768+(g<<2)>>2]&4095](h)|0;o=f;p=c[2276056]|0;q=c[2276083]|0}c[2276084]=o;k=p;l=q;m=o}o=k+2|0;c[2276056]=o;k=o&-4;if((k|0)==(l|0)){r=m;s=o}else{c[2276083]=k;l=c[2276085]&k;k=l&16777212;q=c[2112932]|0;p=c[q+((k>>>10|32768)<<2)>>2]|0;if(p>>>0>9){f=l&1020;t=(d[p+(f|3)|0]|0)<<8|(d[p+(f|2)|0]|0)|((d[p+(f|1)|0]|0)<<8|(d[p+f|0]|0))<<16;u=o}else{o=gj[c[q+196768+(p<<2)>>2]&4095](k)|0;t=o;u=c[2276056]|0}c[2276084]=t;r=t>>>16|m<<16;s=u}c[2276056]=s+2;c[2276054]=r+b;return}function oS(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[2276069]|0;b=9104156+((a&7)<<2)|0;d=(a>>>9)+7&7;a=d+1|0;e=c[b>>2]|0;f=e&255;g=f>>>(a>>>0);c[2276108]=(c[2276108]|0)-(a<<c[2276096]);c[b>>2]=g|e&-256;c[2276075]=0;c[2276076]=g;g=f<<8-d;c[2276078]=g;c[2276074]=g;c[2276077]=0;return}function oT(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[2276069]|0;b=9104156+((a&7)<<2)|0;d=(a>>>9)+7&7;a=d+1|0;e=c[b>>2]|0;f=e&65535;g=f>>>(a>>>0);c[2276108]=(c[2276108]|0)-(a<<c[2276096]);c[b>>2]=g|e&-65536;c[2276075]=0;c[2276076]=g;g=f<<8-d;c[2276078]=g;c[2276074]=g;c[2276077]=0;return}function oU(){var a=0,b=0,d=0,e=0,f=0;a=c[2276069]|0;b=9104156+((a&7)<<2)|0;d=(a>>>9)+7&7;a=d+1|0;e=c[b>>2]|0;f=e>>>(a>>>0);c[2276108]=(c[2276108]|0)-(a<<c[2276096]);c[b>>2]=f;c[2276075]=0;c[2276076]=f;f=e<<8-d;c[2276078]=f;c[2276074]=f;c[2276077]=0;return}function oV(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[2276069]|0;b=9104156+((a&7)<<2)|0;d=c[9104156+((a>>>9&7)<<2)>>2]&63;a=c[b>>2]|0;e=a&255;f=e>>>(d>>>0);if((d|0)==0){c[2276078]=0;c[2276075]=e;c[2276076]=e;c[2276077]=0;return}c[2276108]=(c[2276108]|0)-(d<<c[2276096]);g=a&-256;if(d>>>0<9){c[b>>2]=f|g;a=e<<9-d;c[2276078]=a;c[2276074]=a;c[2276075]=0;c[2276076]=f;c[2276077]=0;return}else{c[b>>2]=g;gGz(9104296,0,20);return}}function oW(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[2276069]|0;b=9104156+((a&7)<<2)|0;d=c[9104156+((a>>>9&7)<<2)>>2]&63;a=c[b>>2]|0;e=a&65535;f=e>>>(d>>>0);if((d|0)==0){c[2276078]=0;c[2276075]=e>>>8;c[2276076]=e;c[2276077]=0;return}c[2276108]=(c[2276108]|0)-(d<<c[2276096]);g=a&-65536;if(d>>>0<17){c[b>>2]=f|g;a=e>>>((d-1|0)>>>0)<<8;c[2276074]=a;c[2276078]=a;c[2276075]=0;c[2276076]=f;c[2276077]=0;return}else{c[b>>2]=g;gGz(9104296,0,20);return}}function oX(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[2276069]|0;b=9104156+((a&7)<<2)|0;d=c[9104156+((a>>>9&7)<<2)>>2]&63;a=c[b>>2]|0;e=a>>>(d>>>0);if((d|0)==0){c[2276078]=0;c[2276075]=a>>>24;c[2276076]=a;c[2276077]=0;return}c[2276108]=(c[2276108]|0)-(d<<c[2276096]);if(d>>>0<32){c[b>>2]=e;f=a>>>((d-1|0)>>>0)<<8;c[2276074]=f;c[2276078]=f;c[2276075]=0;c[2276076]=e;c[2276077]=0;return}c[b>>2]=0;if((d|0)==32){g=a>>>23&256}else{g=0}c[2276078]=g;c[2276074]=g;c[2276075]=0;c[2276076]=0;c[2276077]=0;return}function oY(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276085]|0;f=e&b;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=f&1023;k=(d[i+(j+1)|0]|0)<<8|(d[i+j|0]|0);l=e;m=h}else{e=gj[c[h+196688+(i<<2)>>2]&4095](g)|0;k=e;l=c[2276085]|0;m=c[2112932]|0}e=k&65535;g=e>>>1;i=l&b;b=i&16777215;l=c[m+((b>>>10|16384)<<2)>>2]|0;if(l>>>0>9){h=i&1023;a[l+h|0]=g&255;a[l+(h+1)|0]=(k&65535)>>>9&255;c[2276075]=0;c[2276076]=g;n=e<<8;c[2276074]=n;c[2276078]=n;c[2276077]=0;return}else{gg[c[m+196728+(l<<2)>>2]&4095](b,g&65535);c[2276075]=0;c[2276076]=g;n=e<<8;c[2276074]=n;c[2276078]=n;c[2276077]=0;return}}function oZ(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=c[b>>2]|0;c[b>>2]=e+2;b=c[2276085]|0;f=b&e;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=f&1023;k=(d[i+(j+1)|0]|0)<<8|(d[i+j|0]|0);l=b;m=h}else{b=gj[c[h+196688+(i<<2)>>2]&4095](g)|0;k=b;l=c[2276085]|0;m=c[2112932]|0}b=k&65535;g=b>>>1;i=l&e;e=i&16777215;l=c[m+((e>>>10|16384)<<2)>>2]|0;if(l>>>0>9){h=i&1023;a[l+h|0]=g&255;a[l+(h+1)|0]=(k&65535)>>>9&255;c[2276075]=0;c[2276076]=g;n=b<<8;c[2276074]=n;c[2276078]=n;c[2276077]=0;return}else{gg[c[m+196728+(l<<2)>>2]&4095](e,g&65535);c[2276075]=0;c[2276076]=g;n=b<<8;c[2276074]=n;c[2276078]=n;c[2276077]=0;return}}function o_(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=(c[b>>2]|0)-2|0;c[b>>2]=e;b=c[2276085]|0;f=b&e;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=f&1023;k=(d[i+(j+1)|0]|0)<<8|(d[i+j|0]|0);l=b;m=h}else{b=gj[c[h+196688+(i<<2)>>2]&4095](g)|0;k=b;l=c[2276085]|0;m=c[2112932]|0}b=k&65535;g=b>>>1;i=l&e;e=i&16777215;l=c[m+((e>>>10|16384)<<2)>>2]|0;if(l>>>0>9){h=i&1023;a[l+h|0]=g&255;a[l+(h+1)|0]=(k&65535)>>>9&255;c[2276075]=0;c[2276076]=g;n=b<<8;c[2276074]=n;c[2276078]=n;c[2276077]=0;return}else{gg[c[m+196728+(l<<2)>>2]&4095](e,g&65535);c[2276075]=0;c[2276076]=g;n=b<<8;c[2276074]=n;c[2276078]=n;c[2276077]=0;return}}function o$(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=(h>>>((g<<3&16^16)>>>0)<<16>>16)+b|0;b=c[2276085]|0;g=m&b;h=g&16777215;n=c[2112932]|0;e=c[n+(h>>>10<<2)>>2]|0;if(e>>>0>9){f=g&1023;o=(d[e+(f+1)|0]|0)<<8|(d[e+f|0]|0);p=b;q=n}else{b=gj[c[n+196688+(e<<2)>>2]&4095](h)|0;o=b;p=c[2276085]|0;q=c[2112932]|0}b=o&65535;h=b>>>1;e=p&m;m=e&16777215;p=c[q+((m>>>10|16384)<<2)>>2]|0;if(p>>>0>9){n=e&1023;a[p+n|0]=h&255;a[p+(n+1)|0]=(o&65535)>>>9&255;c[2276075]=0;c[2276076]=h;r=b<<8;c[2276074]=r;c[2276078]=r;c[2276077]=0;return}else{gg[c[q+196728+(p<<2)>>2]&4095](m,h&65535);c[2276075]=0;c[2276076]=h;r=b<<8;c[2276074]=r;c[2276078]=r;c[2276077]=0;return}}function o0(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=nB(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;e=c[2276085]|0;f=e&b;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=f&1023;k=(d[i+(j+1)|0]|0)<<8|(d[i+j|0]|0);l=e;m=h}else{e=gj[c[h+196688+(i<<2)>>2]&4095](g)|0;k=e;l=c[2276085]|0;m=c[2112932]|0}e=k&65535;g=e>>>1;i=l&b;b=i&16777215;l=c[m+((b>>>10|16384)<<2)>>2]|0;if(l>>>0>9){h=i&1023;a[l+h|0]=g&255;a[l+(h+1)|0]=(k&65535)>>>9&255;c[2276075]=0;c[2276076]=g;n=e<<8;c[2276074]=n;c[2276078]=n;c[2276077]=0;return}else{gg[c[m+196728+(l<<2)>>2]&4095](b,g&65535);c[2276075]=0;c[2276076]=g;n=e<<8;c[2276074]=n;c[2276078]=n;c[2276077]=0;return}}function o1(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)<<16>>16;f=c[2276085]|0;g=l&f;m=g&16777215;b=c[2112932]|0;e=c[b+(m>>>10<<2)>>2]|0;if(e>>>0>9){j=g&1023;n=(d[e+(j+1)|0]|0)<<8|(d[e+j|0]|0);o=f;p=b}else{f=gj[c[b+196688+(e<<2)>>2]&4095](m)|0;n=f;o=c[2276085]|0;p=c[2112932]|0}f=n&65535;m=f>>>1;e=o&l;l=e&16777215;o=c[p+((l>>>10|16384)<<2)>>2]|0;if(o>>>0>9){b=e&1023;a[o+b|0]=m&255;a[o+(b+1)|0]=(n&65535)>>>9&255;c[2276075]=0;c[2276076]=m;q=f<<8;c[2276074]=q;c[2276078]=q;c[2276077]=0;return}else{gg[c[p+196728+(o<<2)>>2]&4095](l,m&65535);c[2276075]=0;c[2276076]=m;q=f<<8;c[2276074]=q;c[2276078]=q;c[2276077]=0;return}}function o2(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[2276085]|0;t=r&q;h=t&16777215;s=c[2112932]|0;n=c[s+(h>>>10<<2)>>2]|0;if(n>>>0>9){f=t&1023;u=(d[n+(f+1)|0]|0)<<8|(d[n+f|0]|0);v=r;w=s}else{r=gj[c[s+196688+(n<<2)>>2]&4095](h)|0;u=r;v=c[2276085]|0;w=c[2112932]|0}r=u&65535;h=r>>>1;n=v&q;q=n&16777215;v=c[w+((q>>>10|16384)<<2)>>2]|0;if(v>>>0>9){s=n&1023;a[v+s|0]=h&255;a[v+(s+1)|0]=(u&65535)>>>9&255;c[2276075]=0;c[2276076]=h;x=r<<8;c[2276074]=x;c[2276078]=x;c[2276077]=0;return}else{gg[c[w+196728+(v<<2)>>2]&4095](q,h&65535);c[2276075]=0;c[2276076]=h;x=r<<8;c[2276074]=x;c[2276078]=x;c[2276077]=0;return}}function o3(){var a=0,b=0,d=0,e=0,f=0;a=c[2276069]|0;b=9104156+((a&7)<<2)|0;d=((a>>>9)+7&7)+1|0;a=c[b>>2]|0;e=(a&255)<<d;f=e&255;c[2276108]=(c[2276108]|0)-(d<<c[2276096]);c[b>>2]=f|a&-256;c[2276075]=f;c[2276076]=f;c[2276078]=e;c[2276074]=e;c[2276077]=0;return}function o4(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[2276069]|0;b=9104156+((a&7)<<2)|0;d=(a>>>9)+7&7;a=d+1|0;e=c[b>>2]|0;f=e&65535;g=f<<a&65535;c[2276108]=(c[2276108]|0)-(a<<c[2276096]);c[b>>2]=g|e&-65536;c[2276075]=g>>>8;c[2276076]=g;g=f>>>((d^7)>>>0);c[2276078]=g;c[2276074]=g;c[2276077]=0;return}function o5(){var a=0,b=0,d=0,e=0,f=0;a=c[2276069]|0;b=9104156+((a&7)<<2)|0;d=(a>>>9)+7&7;a=d+1|0;e=c[b>>2]|0;f=e<<a;c[2276108]=(c[2276108]|0)-(a<<c[2276096]);c[b>>2]=f;c[2276075]=f>>>24;c[2276076]=f;f=e>>>((23-d|0)>>>0);c[2276078]=f;c[2276074]=f;c[2276077]=0;return}function o6(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[2276069]|0;b=9104156+((a&7)<<2)|0;d=c[9104156+((a>>>9&7)<<2)>>2]&63;a=c[b>>2]|0;e=a&255;f=e<<d;g=f&255;if((d|0)==0){c[2276078]=0;c[2276075]=e;c[2276076]=e;c[2276077]=0;return}c[2276108]=(c[2276108]|0)-(d<<c[2276096]);e=a&-256;if(d>>>0<9){c[b>>2]=g|e;c[2276078]=f;c[2276074]=f;c[2276075]=g;c[2276076]=g;c[2276077]=0;return}else{c[b>>2]=e;gGz(9104296,0,20);return}}function o7(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[2276069]|0;b=9104156+((a&7)<<2)|0;d=c[9104156+((a>>>9&7)<<2)>>2]&63;a=c[b>>2]|0;e=a&65535;f=e<<d;g=f&65535;if((d|0)==0){c[2276078]=0;c[2276075]=e>>>8;c[2276076]=e;c[2276077]=0;return}c[2276108]=(c[2276108]|0)-(d<<c[2276096]);e=a&-65536;if(d>>>0<17){c[b>>2]=g|e;d=f>>>8;c[2276078]=d;c[2276074]=d;c[2276075]=g>>>8;c[2276076]=g;c[2276077]=0;return}else{c[b>>2]=e;gGz(9104296,0,20);return}}function o8(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[2276069]|0;b=9104156+((a&7)<<2)|0;d=c[9104156+((a>>>9&7)<<2)>>2]&63;a=c[b>>2]|0;e=a<<d;if((d|0)==0){c[2276078]=0;c[2276075]=a>>>24;c[2276076]=a;c[2276077]=0;return}c[2276108]=(c[2276108]|0)-(d<<c[2276096]);if(d>>>0<32){c[b>>2]=e;f=a>>>((32-d|0)>>>0)<<8;c[2276078]=f;c[2276074]=f;c[2276075]=e>>>24;c[2276076]=e;c[2276077]=0;return}c[b>>2]=0;if((d|0)==32){g=a<<8&256}else{g=0}c[2276078]=g;c[2276074]=g;c[2276075]=0;c[2276076]=0;c[2276077]=0;return}function o9(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276085]|0;f=e&b;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=f&1023;k=(d[i+(j+1)|0]|0)<<8|(d[i+j|0]|0);l=e;m=h}else{e=gj[c[h+196688+(i<<2)>>2]&4095](g)|0;k=e;l=c[2276085]|0;m=c[2112932]|0}e=k&65535;g=e<<1;i=g&65534;h=l&b;b=h&16777215;l=c[m+((b>>>10|16384)<<2)>>2]|0;if(l>>>0>9){j=h&1023;a[l+j|0]=g&255;a[l+(j+1)|0]=(k&65535)>>>7&255;n=i>>>8;c[2276075]=n;c[2276076]=i;o=e>>>7;c[2276078]=o;c[2276074]=o;c[2276077]=0;return}else{gg[c[m+196728+(l<<2)>>2]&4095](b,g&65535);n=i>>>8;c[2276075]=n;c[2276076]=i;o=e>>>7;c[2276078]=o;c[2276074]=o;c[2276077]=0;return}}function pa(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=c[b>>2]|0;c[b>>2]=e+2;b=c[2276085]|0;f=b&e;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=f&1023;k=(d[i+(j+1)|0]|0)<<8|(d[i+j|0]|0);l=b;m=h}else{b=gj[c[h+196688+(i<<2)>>2]&4095](g)|0;k=b;l=c[2276085]|0;m=c[2112932]|0}b=k&65535;g=b<<1;i=g&65534;h=l&e;e=h&16777215;l=c[m+((e>>>10|16384)<<2)>>2]|0;if(l>>>0>9){j=h&1023;a[l+j|0]=g&255;a[l+(j+1)|0]=(k&65535)>>>7&255;n=i>>>8;c[2276075]=n;c[2276076]=i;o=b>>>7;c[2276078]=o;c[2276074]=o;c[2276077]=0;return}else{gg[c[m+196728+(l<<2)>>2]&4095](e,g&65535);n=i>>>8;c[2276075]=n;c[2276076]=i;o=b>>>7;c[2276078]=o;c[2276074]=o;c[2276077]=0;return}}function pb(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=(c[b>>2]|0)-2|0;c[b>>2]=e;b=c[2276085]|0;f=b&e;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=f&1023;k=(d[i+(j+1)|0]|0)<<8|(d[i+j|0]|0);l=b;m=h}else{b=gj[c[h+196688+(i<<2)>>2]&4095](g)|0;k=b;l=c[2276085]|0;m=c[2112932]|0}b=k&65535;g=b<<1;i=g&65534;h=l&e;e=h&16777215;l=c[m+((e>>>10|16384)<<2)>>2]|0;if(l>>>0>9){j=h&1023;a[l+j|0]=g&255;a[l+(j+1)|0]=(k&65535)>>>7&255;n=i>>>8;c[2276075]=n;c[2276076]=i;o=b>>>7;c[2276078]=o;c[2276074]=o;c[2276077]=0;return}else{gg[c[m+196728+(l<<2)>>2]&4095](e,g&65535);n=i>>>8;c[2276075]=n;c[2276076]=i;o=b>>>7;c[2276078]=o;c[2276074]=o;c[2276077]=0;return}}function pc(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=(h>>>((g<<3&16^16)>>>0)<<16>>16)+b|0;b=c[2276085]|0;g=m&b;h=g&16777215;n=c[2112932]|0;e=c[n+(h>>>10<<2)>>2]|0;if(e>>>0>9){f=g&1023;o=(d[e+(f+1)|0]|0)<<8|(d[e+f|0]|0);p=b;q=n}else{b=gj[c[n+196688+(e<<2)>>2]&4095](h)|0;o=b;p=c[2276085]|0;q=c[2112932]|0}b=o&65535;h=b<<1;e=h&65534;n=p&m;m=n&16777215;p=c[q+((m>>>10|16384)<<2)>>2]|0;if(p>>>0>9){f=n&1023;a[p+f|0]=h&255;a[p+(f+1)|0]=(o&65535)>>>7&255;r=e>>>8;c[2276075]=r;c[2276076]=e;s=b>>>7;c[2276078]=s;c[2276074]=s;c[2276077]=0;return}else{gg[c[q+196728+(p<<2)>>2]&4095](m,h&65535);r=e>>>8;c[2276075]=r;c[2276076]=e;s=b>>>7;c[2276078]=s;c[2276074]=s;c[2276077]=0;return}}function pd(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=nB(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;e=c[2276085]|0;f=e&b;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=f&1023;k=(d[i+(j+1)|0]|0)<<8|(d[i+j|0]|0);l=e;m=h}else{e=gj[c[h+196688+(i<<2)>>2]&4095](g)|0;k=e;l=c[2276085]|0;m=c[2112932]|0}e=k&65535;g=e<<1;i=g&65534;h=l&b;b=h&16777215;l=c[m+((b>>>10|16384)<<2)>>2]|0;if(l>>>0>9){j=h&1023;a[l+j|0]=g&255;a[l+(j+1)|0]=(k&65535)>>>7&255;n=i>>>8;c[2276075]=n;c[2276076]=i;o=e>>>7;c[2276078]=o;c[2276074]=o;c[2276077]=0;return}else{gg[c[m+196728+(l<<2)>>2]&4095](b,g&65535);n=i>>>8;c[2276075]=n;c[2276076]=i;o=e>>>7;c[2276078]=o;c[2276074]=o;c[2276077]=0;return}}function pe(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)<<16>>16;f=c[2276085]|0;g=l&f;m=g&16777215;b=c[2112932]|0;e=c[b+(m>>>10<<2)>>2]|0;if(e>>>0>9){j=g&1023;n=(d[e+(j+1)|0]|0)<<8|(d[e+j|0]|0);o=f;p=b}else{f=gj[c[b+196688+(e<<2)>>2]&4095](m)|0;n=f;o=c[2276085]|0;p=c[2112932]|0}f=n&65535;m=f<<1;e=m&65534;b=o&l;l=b&16777215;o=c[p+((l>>>10|16384)<<2)>>2]|0;if(o>>>0>9){j=b&1023;a[o+j|0]=m&255;a[o+(j+1)|0]=(n&65535)>>>7&255;q=e>>>8;c[2276075]=q;c[2276076]=e;r=f>>>7;c[2276078]=r;c[2276074]=r;c[2276077]=0;return}else{gg[c[p+196728+(o<<2)>>2]&4095](l,m&65535);q=e>>>8;c[2276075]=q;c[2276076]=e;r=f>>>7;c[2276078]=r;c[2276074]=r;c[2276077]=0;return}}function pf(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[2276085]|0;t=r&q;h=t&16777215;s=c[2112932]|0;n=c[s+(h>>>10<<2)>>2]|0;if(n>>>0>9){f=t&1023;u=(d[n+(f+1)|0]|0)<<8|(d[n+f|0]|0);v=r;w=s}else{r=gj[c[s+196688+(n<<2)>>2]&4095](h)|0;u=r;v=c[2276085]|0;w=c[2112932]|0}r=u&65535;h=r<<1;n=h&65534;s=v&q;q=s&16777215;v=c[w+((q>>>10|16384)<<2)>>2]|0;if(v>>>0>9){f=s&1023;a[v+f|0]=h&255;a[v+(f+1)|0]=(u&65535)>>>7&255;x=n>>>8;c[2276075]=x;c[2276076]=n;y=r>>>7;c[2276078]=y;c[2276074]=y;c[2276077]=0;return}else{gg[c[w+196728+(v<<2)>>2]&4095](q,h&65535);x=n>>>8;c[2276075]=x;c[2276076]=n;y=r>>>7;c[2276078]=y;c[2276074]=y;c[2276077]=0;return}}function pg(){var a=0,b=0,d=0;a=c[2276069]|0;b=c[9104156+((a&7)<<2)>>2]&255;d=9104156+((a>>>9&7)<<2)|0;c[d>>2]=c[d>>2]&-256|b;c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}function ph(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=c[2276069]|0;d=c[2276085]&c[9104156+((b&7|8)<<2)>>2];e=d&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=a[g+(d&1023^1)|0]|0;i=b}else{b=gj[c[f+196608+(g<<2)>>2]&4095](e)|0;h=b;i=c[2276069]|0}b=h&255;h=9104156+((i>>>9&7)<<2)|0;c[h>>2]=c[h>>2]&-256|b;c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}function pi(){var b=0,d=0,e=0,f=0,g=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;b=c[2276085]&d;d=b&16777215;e=c[2112932]|0;f=c[e+(d>>>10<<2)>>2]|0;if(f>>>0>9){g=a[f+(b&1023^1)|0]|0}else{g=gj[c[e+196608+(f<<2)>>2]&4095](d)|0}d=g&255;g=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;c[g>>2]=c[g>>2]&-256|d;c[2276075]=d;c[2276076]=d;c[2276077]=0;c[2276078]=0;return}function pj(){var b=0,d=0,e=0,f=0,g=0;b=c[2276054]|0;c[2276054]=b+2;d=c[2276085]&b;b=d&16777215;e=c[2112932]|0;f=c[e+(b>>>10<<2)>>2]|0;if(f>>>0>9){g=a[f+(d&1023^1)|0]|0}else{g=gj[c[e+196608+(f<<2)>>2]&4095](b)|0}b=g&255;g=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;c[g>>2]=c[g>>2]&-256|b;c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}function pk(){var b=0,d=0,e=0,f=0,g=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;b=c[2276085]&d;d=b&16777215;e=c[2112932]|0;f=c[e+(d>>>10<<2)>>2]|0;if(f>>>0>9){g=a[f+(b&1023^1)|0]|0}else{g=gj[c[e+196608+(f<<2)>>2]&4095](d)|0}d=g&255;g=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;c[g>>2]=c[g>>2]&-256|d;c[2276075]=d;c[2276076]=d;c[2276077]=0;c[2276078]=0;return}function pl(){var b=0,d=0,e=0,f=0,g=0;b=(c[2276054]|0)-2|0;c[2276054]=b;d=c[2276085]&b;b=d&16777215;e=c[2112932]|0;f=c[e+(b>>>10<<2)>>2]|0;if(f>>>0>9){g=a[f+(d&1023^1)|0]|0}else{g=gj[c[e+196608+(f<<2)>>2]&4095](b)|0}b=g&255;g=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;c[g>>2]=c[g>>2]&-256|b;c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}function pm(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=(h>>>((g<<3&16^16)>>>0)<<16>>16)+b&c[2276085];b=m&16777215;g=c[2112932]|0;h=c[g+(b>>>10<<2)>>2]|0;if(h>>>0>9){o=a[h+(m&1023^1)|0]|0;p=o&255;q=c[2276069]|0;r=q>>>9;s=r&7;t=9104156+(s<<2)|0;u=c[t>>2]|0;v=u&-256;w=v|p;c[t>>2]=w;c[2276075]=p;c[2276076]=p;c[2276077]=0;c[2276078]=0;return}else{o=gj[c[g+196608+(h<<2)>>2]&4095](b)|0;p=o&255;q=c[2276069]|0;r=q>>>9;s=r&7;t=9104156+(s<<2)|0;u=c[t>>2]|0;v=u&-256;w=v|p;c[t>>2]=w;c[2276075]=p;c[2276076]=p;c[2276077]=0;c[2276078]=0;return}}function pn(){var b=0,d=0,e=0,f=0,g=0;b=nB(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;d=c[2276085]&b;b=d&16777215;e=c[2112932]|0;f=c[e+(b>>>10<<2)>>2]|0;if(f>>>0>9){g=a[f+(d&1023^1)|0]|0}else{g=gj[c[e+196608+(f<<2)>>2]&4095](b)|0}b=g&255;g=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;c[g>>2]=c[g>>2]&-256|b;c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}function po(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)<<16>>16&c[2276085];f=l&16777215;g=c[2112932]|0;m=c[g+(f>>>10<<2)>>2]|0;if(m>>>0>9){n=a[m+(l&1023^1)|0]|0;o=n&255;p=c[2276069]|0;q=p>>>9;r=q&7;s=9104156+(r<<2)|0;t=c[s>>2]|0;u=t&-256;v=u|o;c[s>>2]=v;c[2276075]=o;c[2276076]=o;c[2276077]=0;c[2276078]=0;return}else{n=gj[c[g+196608+(m<<2)>>2]&4095](f)|0;o=n&255;p=c[2276069]|0;q=p>>>9;r=q&7;s=9104156+(r<<2)|0;t=c[s>>2]|0;u=t&-256;v=u|o;c[s>>2]=v;c[2276075]=o;c[2276076]=o;c[2276077]=0;c[2276078]=0;return}}function pp(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[2276085]&q;q=r&16777215;t=c[2112932]|0;h=c[t+(q>>>10<<2)>>2]|0;if(h>>>0>9){u=a[h+(r&1023^1)|0]|0;v=u&255;w=c[2276069]|0;x=w>>>9;y=x&7;z=9104156+(y<<2)|0;A=c[z>>2]|0;B=A&-256;C=B|v;c[z>>2]=C;c[2276075]=v;c[2276076]=v;c[2276077]=0;c[2276078]=0;return}else{u=gj[c[t+196608+(h<<2)>>2]&4095](q)|0;v=u&255;w=c[2276069]|0;x=w>>>9;y=x&7;z=9104156+(y<<2)|0;A=c[z>>2]|0;B=A&-256;C=B|v;c[z>>2]=C;c[2276075]=v;c[2276076]=v;c[2276077]=0;c[2276078]=0;return}}function pq(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{k=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=k;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=(g>>>((f<<3&16^16)>>>0)<<16>>16)+b|0;b=l&16777215;f=c[2112932]|0;g=c[f+((b>>>10|32768)<<2)>>2]|0;if(g>>>0>9){n=a[g+(l&1023^1)|0]|0;o=n&255;p=c[2276069]|0;q=p>>>9;r=q&7;s=9104156+(r<<2)|0;t=c[s>>2]|0;u=t&-256;v=u|o;c[s>>2]=v;c[2276075]=o;c[2276076]=o;c[2276077]=0;c[2276078]=0;return}else{n=gj[c[f+196608+(g<<2)>>2]&4095](b)|0;o=n&255;p=c[2276069]|0;q=p>>>9;r=q&7;s=9104156+(r<<2)|0;t=c[s>>2]|0;u=t&-256;v=u|o;c[s>>2]=v;c[2276075]=o;c[2276076]=o;c[2276077]=0;c[2276078]=0;return}}function pr(){var b=0,d=0,e=0,f=0,g=0;b=nB(c[2276056]|0)|0;d=b&16777215;e=c[2112932]|0;f=c[e+((d>>>10|32768)<<2)>>2]|0;if(f>>>0>9){g=a[f+(b&1023^1)|0]|0}else{g=gj[c[e+196608+(f<<2)>>2]&4095](d)|0}d=g&255;g=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;c[g>>2]=c[g>>2]&-256|d;c[2276075]=d;c[2276076]=d;c[2276077]=0;c[2276078]=0;return}function ps(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=f>>>((e<<3&16^16)>>>0)&255;e=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;c[e>>2]=k|c[e>>2]&-256;c[2276075]=k;c[2276076]=k;c[2276077]=0;c[2276078]=0;return}function pt(){var b=0,d=0,e=0,f=0,g=0,h=0;b=c[2276069]|0;d=c[9104156+((b&7)<<2)>>2]|0;e=d&255;f=c[2276085]&c[9104156+((b>>>9&7|8)<<2)>>2];b=d&255;d=f&16777215;g=c[2112932]|0;h=c[g+((d>>>10|16384)<<2)>>2]|0;if(h>>>0>9){a[h+(f&1023^1)|0]=b;c[2276075]=e;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}else{gg[c[g+196648+(h<<2)>>2]&4095](d,b);c[2276075]=e;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}}function pu(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=c[2276069]|0;d=c[2276085]|0;e=d&c[9104156+((b&7|8)<<2)>>2];f=e&16777215;g=c[2112932]|0;h=c[g+(f>>>10<<2)>>2]|0;if(h>>>0>9){i=a[h+(e&1023^1)|0]|0;j=b;k=d;l=g}else{d=gj[c[g+196608+(h<<2)>>2]&4095](f)|0;i=d;j=c[2276069]|0;k=c[2276085]|0;l=c[2112932]|0}d=i&255;f=k&c[9104156+((j>>>9&7|8)<<2)>>2];j=f&16777215;k=c[l+((j>>>10|16384)<<2)>>2]|0;if(k>>>0>9){a[k+(f&1023^1)|0]=i;c[2276075]=d;c[2276076]=d;c[2276077]=0;c[2276078]=0;return}else{gg[c[l+196648+(k<<2)>>2]&4095](j,i);c[2276075]=d;c[2276076]=d;c[2276077]=0;c[2276078]=0;return}}function pv(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;b=c[2276085]|0;e=b&d;d=e&16777215;f=c[2112932]|0;g=c[f+(d>>>10<<2)>>2]|0;if(g>>>0>9){h=a[g+(e&1023^1)|0]|0;i=b;j=f}else{b=gj[c[f+196608+(g<<2)>>2]&4095](d)|0;h=b;i=c[2276085]|0;j=c[2112932]|0}b=h&255;d=i&c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2];i=d&16777215;g=c[j+((i>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(d&1023^1)|0]=h;c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}else{gg[c[j+196648+(g<<2)>>2]&4095](i,h);c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}}function pw(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[2276054]|0;c[2276054]=b+2;d=c[2276085]|0;e=d&b;b=e&16777215;f=c[2112932]|0;g=c[f+(b>>>10<<2)>>2]|0;if(g>>>0>9){h=a[g+(e&1023^1)|0]|0;i=d;j=f}else{d=gj[c[f+196608+(g<<2)>>2]&4095](b)|0;h=d;i=c[2276085]|0;j=c[2112932]|0}d=h&255;b=i&c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2];i=b&16777215;g=c[j+((i>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(b&1023^1)|0]=h;c[2276075]=d;c[2276076]=d;c[2276077]=0;c[2276078]=0;return}else{gg[c[j+196648+(g<<2)>>2]&4095](i,h);c[2276075]=d;c[2276076]=d;c[2276077]=0;c[2276078]=0;return}}function px(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;b=c[2276085]|0;e=b&d;d=e&16777215;f=c[2112932]|0;g=c[f+(d>>>10<<2)>>2]|0;if(g>>>0>9){h=a[g+(e&1023^1)|0]|0;i=b;j=f}else{b=gj[c[f+196608+(g<<2)>>2]&4095](d)|0;h=b;i=c[2276085]|0;j=c[2112932]|0}b=h&255;d=i&c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2];i=d&16777215;g=c[j+((i>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(d&1023^1)|0]=h;c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}else{gg[c[j+196648+(g<<2)>>2]&4095](i,h);c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}}function py(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=(c[2276054]|0)-2|0;c[2276054]=b;d=c[2276085]|0;e=d&b;b=e&16777215;f=c[2112932]|0;g=c[f+(b>>>10<<2)>>2]|0;if(g>>>0>9){h=a[g+(e&1023^1)|0]|0;i=d;j=f}else{d=gj[c[f+196608+(g<<2)>>2]&4095](b)|0;h=d;i=c[2276085]|0;j=c[2112932]|0}d=h&255;b=i&c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2];i=b&16777215;g=c[j+((i>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(b&1023^1)|0]=h;c[2276075]=d;c[2276076]=d;c[2276077]=0;c[2276078]=0;return}else{gg[c[j+196648+(g<<2)>>2]&4095](i,h);c[2276075]=d;c[2276076]=d;c[2276077]=0;c[2276078]=0;return}}function pz(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=c[2276085]|0;n=(h>>>((g<<3&16^16)>>>0)<<16>>16)+b&m;b=n&16777215;g=c[2112932]|0;h=c[g+(b>>>10<<2)>>2]|0;if(h>>>0>9){o=a[h+(n&1023^1)|0]|0;p=m;q=g}else{m=gj[c[g+196608+(h<<2)>>2]&4095](b)|0;o=m;p=c[2276085]|0;q=c[2112932]|0}m=o&255;b=p&c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2];p=b&16777215;h=c[q+((p>>>10|16384)<<2)>>2]|0;if(h>>>0>9){a[h+(b&1023^1)|0]=o;c[2276075]=m;c[2276076]=m;c[2276077]=0;c[2276078]=0;return}else{gg[c[q+196648+(h<<2)>>2]&4095](p,o);c[2276075]=m;c[2276076]=m;c[2276077]=0;c[2276078]=0;return}}function pA(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=nB(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;d=c[2276085]|0;e=d&b;b=e&16777215;f=c[2112932]|0;g=c[f+(b>>>10<<2)>>2]|0;if(g>>>0>9){h=a[g+(e&1023^1)|0]|0;i=d;j=f}else{d=gj[c[f+196608+(g<<2)>>2]&4095](b)|0;h=d;i=c[2276085]|0;j=c[2112932]|0}d=h&255;b=i&c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2];i=b&16777215;g=c[j+((i>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(b&1023^1)|0]=h;c[2276075]=d;c[2276076]=d;c[2276077]=0;c[2276078]=0;return}else{gg[c[j+196648+(g<<2)>>2]&4095](i,h);c[2276075]=d;c[2276076]=d;c[2276077]=0;c[2276078]=0;return}}function pB(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=c[2276085]|0;m=g>>>((f<<3&16^16)>>>0)<<16>>16&l;f=m&16777215;g=c[2112932]|0;b=c[g+(f>>>10<<2)>>2]|0;if(b>>>0>9){n=a[b+(m&1023^1)|0]|0;o=l;p=g}else{l=gj[c[g+196608+(b<<2)>>2]&4095](f)|0;n=l;o=c[2276085]|0;p=c[2112932]|0}l=n&255;f=o&c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2];o=f&16777215;b=c[p+((o>>>10|16384)<<2)>>2]|0;if(b>>>0>9){a[b+(f&1023^1)|0]=n;c[2276075]=l;c[2276076]=l;c[2276077]=0;c[2276078]=0;return}else{gg[c[p+196648+(b<<2)>>2]&4095](o,n);c[2276075]=l;c[2276076]=l;c[2276077]=0;c[2276078]=0;return}}function pC(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[2276085]|0;t=r&q;q=t&16777215;h=c[2112932]|0;s=c[h+(q>>>10<<2)>>2]|0;if(s>>>0>9){u=a[s+(t&1023^1)|0]|0;v=r;w=h}else{r=gj[c[h+196608+(s<<2)>>2]&4095](q)|0;u=r;v=c[2276085]|0;w=c[2112932]|0}r=u&255;q=v&c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2];v=q&16777215;s=c[w+((v>>>10|16384)<<2)>>2]|0;if(s>>>0>9){a[s+(q&1023^1)|0]=u;c[2276075]=r;c[2276076]=r;c[2276077]=0;c[2276078]=0;return}else{gg[c[w+196648+(s<<2)>>2]&4095](v,u);c[2276075]=r;c[2276076]=r;c[2276077]=0;c[2276078]=0;return}}function pD(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{k=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=k;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=(g>>>((f<<3&16^16)>>>0)<<16>>16)+b|0;b=l&16777215;f=c[2112932]|0;g=c[f+((b>>>10|32768)<<2)>>2]|0;if(g>>>0>9){n=a[g+(l&1023^1)|0]|0;o=f}else{l=gj[c[f+196608+(g<<2)>>2]&4095](b)|0;n=l;o=c[2112932]|0}l=n&255;b=c[2276085]&c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2];g=b&16777215;f=c[o+((g>>>10|16384)<<2)>>2]|0;if(f>>>0>9){a[f+(b&1023^1)|0]=n;c[2276075]=l;c[2276076]=l;c[2276077]=0;c[2276078]=0;return}else{gg[c[o+196648+(f<<2)>>2]&4095](g,n);c[2276075]=l;c[2276076]=l;c[2276077]=0;c[2276078]=0;return}}function pE(){var b=0,d=0,e=0,f=0,g=0,h=0;b=nB(c[2276056]|0)|0;d=b&16777215;e=c[2112932]|0;f=c[e+((d>>>10|32768)<<2)>>2]|0;if(f>>>0>9){g=a[f+(b&1023^1)|0]|0;h=e}else{b=gj[c[e+196608+(f<<2)>>2]&4095](d)|0;g=b;h=c[2112932]|0}b=g&255;d=c[2276085]&c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2];f=d&16777215;e=c[h+((f>>>10|16384)<<2)>>2]|0;if(e>>>0>9){a[e+(d&1023^1)|0]=g;c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}else{gg[c[h+196648+(e<<2)>>2]&4095](f,g);c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}}function pF(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0);f=l&255;g=c[2276085]&c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2];m=l&255;l=g&16777215;b=c[2112932]|0;e=c[b+((l>>>10|16384)<<2)>>2]|0;if(e>>>0>9){a[e+(g&1023^1)|0]=m;c[2276075]=f;c[2276076]=f;c[2276077]=0;c[2276078]=0;return}else{gg[c[b+196648+(e<<2)>>2]&4095](l,m);c[2276075]=f;c[2276076]=f;c[2276077]=0;c[2276078]=0;return}}function pG(){var b=0,d=0,e=0,f=0,g=0,h=0;b=c[9104156+((c[2276069]&7)<<2)>>2]|0;d=b&255;e=c[2276054]|0;c[2276054]=e+2;f=c[2276085]&e;e=b&255;b=f&16777215;g=c[2112932]|0;h=c[g+((b>>>10|16384)<<2)>>2]|0;if(h>>>0>9){a[h+(f&1023^1)|0]=e;c[2276075]=d;c[2276076]=d;c[2276077]=0;c[2276078]=0;return}else{gg[c[g+196648+(h<<2)>>2]&4095](b,e);c[2276075]=d;c[2276076]=d;c[2276077]=0;c[2276078]=0;return}}function pH(){var b=0,d=0,e=0,f=0,g=0,h=0;b=c[2276069]|0;d=c[9104156+((b&7)<<2)>>2]|0;e=d&255;f=9104156+((b>>>9&7|8)<<2)|0;b=c[f>>2]|0;c[f>>2]=b+1;f=c[2276085]&b;b=d&255;d=f&16777215;g=c[2112932]|0;h=c[g+((d>>>10|16384)<<2)>>2]|0;if(h>>>0>9){a[h+(f&1023^1)|0]=b;c[2276075]=e;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}else{gg[c[g+196648+(h<<2)>>2]&4095](d,b);c[2276075]=e;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}}function pI(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[2276085]|0;d=b&c[9104156+((c[2276069]&7|8)<<2)>>2];e=d&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=a[g+(d&1023^1)|0]|0;i=b;j=f}else{b=gj[c[f+196608+(g<<2)>>2]&4095](e)|0;h=b;i=c[2276085]|0;j=c[2112932]|0}b=h&255;e=c[2276054]|0;c[2276054]=e+2;g=i&e;e=g&16777215;i=c[j+((e>>>10|16384)<<2)>>2]|0;if(i>>>0>9){a[i+(g&1023^1)|0]=h;c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}else{gg[c[j+196648+(i<<2)>>2]&4095](e,h);c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}}function pJ(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;b=c[2276085]|0;e=b&d;d=e&16777215;f=c[2112932]|0;g=c[f+(d>>>10<<2)>>2]|0;if(g>>>0>9){h=a[g+(e&1023^1)|0]|0;i=b;j=f}else{b=gj[c[f+196608+(g<<2)>>2]&4095](d)|0;h=b;i=c[2276085]|0;j=c[2112932]|0}b=h&255;d=c[2276054]|0;c[2276054]=d+2;g=i&d;d=g&16777215;i=c[j+((d>>>10|16384)<<2)>>2]|0;if(i>>>0>9){a[i+(g&1023^1)|0]=h;c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}else{gg[c[j+196648+(i<<2)>>2]&4095](d,h);c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}}function pK(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=c[2276054]|0;d=b+2|0;c[2276054]=d;e=c[2276085]|0;f=e&b;b=f&16777215;g=c[2112932]|0;h=c[g+(b>>>10<<2)>>2]|0;if(h>>>0>9){i=a[h+(f&1023^1)|0]|0;j=d;k=e;l=g}else{e=gj[c[g+196608+(h<<2)>>2]&4095](b)|0;i=e;j=c[2276054]|0;k=c[2276085]|0;l=c[2112932]|0}e=i&255;c[2276054]=j+2;b=k&j;j=b&16777215;k=c[l+((j>>>10|16384)<<2)>>2]|0;if(k>>>0>9){a[k+(b&1023^1)|0]=i;c[2276075]=e;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}else{gg[c[l+196648+(k<<2)>>2]&4095](j,i);c[2276075]=e;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}}function pL(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;b=c[2276085]|0;e=b&d;d=e&16777215;f=c[2112932]|0;g=c[f+(d>>>10<<2)>>2]|0;if(g>>>0>9){h=a[g+(e&1023^1)|0]|0;i=b;j=f}else{b=gj[c[f+196608+(g<<2)>>2]&4095](d)|0;h=b;i=c[2276085]|0;j=c[2112932]|0}b=h&255;d=c[2276054]|0;c[2276054]=d+2;g=i&d;d=g&16777215;i=c[j+((d>>>10|16384)<<2)>>2]|0;if(i>>>0>9){a[i+(g&1023^1)|0]=h;c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}else{gg[c[j+196648+(i<<2)>>2]&4095](d,h);c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}}function pM(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=(c[2276054]|0)-2|0;c[2276054]=b;d=c[2276085]|0;e=d&b;f=e&16777215;g=c[2112932]|0;h=c[g+(f>>>10<<2)>>2]|0;if(h>>>0>9){i=a[h+(e&1023^1)|0]|0;j=b;k=d;l=g}else{d=gj[c[g+196608+(h<<2)>>2]&4095](f)|0;i=d;j=c[2276054]|0;k=c[2276085]|0;l=c[2112932]|0}d=i&255;c[2276054]=j+2;f=k&j;j=f&16777215;k=c[l+((j>>>10|16384)<<2)>>2]|0;if(k>>>0>9){a[k+(f&1023^1)|0]=i;c[2276075]=d;c[2276076]=d;c[2276077]=0;c[2276078]=0;return}else{gg[c[l+196648+(k<<2)>>2]&4095](j,i);c[2276075]=d;c[2276076]=d;c[2276077]=0;c[2276078]=0;return}}function pN(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=c[2276085]|0;n=(h>>>((g<<3&16^16)>>>0)<<16>>16)+b&m;b=n&16777215;g=c[2112932]|0;h=c[g+(b>>>10<<2)>>2]|0;if(h>>>0>9){o=a[h+(n&1023^1)|0]|0;p=m;q=g}else{m=gj[c[g+196608+(h<<2)>>2]&4095](b)|0;o=m;p=c[2276085]|0;q=c[2112932]|0}m=o&255;b=c[2276054]|0;c[2276054]=b+2;h=p&b;b=h&16777215;p=c[q+((b>>>10|16384)<<2)>>2]|0;if(p>>>0>9){a[p+(h&1023^1)|0]=o;c[2276075]=m;c[2276076]=m;c[2276077]=0;c[2276078]=0;return}else{gg[c[q+196648+(p<<2)>>2]&4095](b,o);c[2276075]=m;c[2276076]=m;c[2276077]=0;c[2276078]=0;return}}function pO(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=nB(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;d=c[2276085]|0;e=d&b;b=e&16777215;f=c[2112932]|0;g=c[f+(b>>>10<<2)>>2]|0;if(g>>>0>9){h=a[g+(e&1023^1)|0]|0;i=d;j=f}else{d=gj[c[f+196608+(g<<2)>>2]&4095](b)|0;h=d;i=c[2276085]|0;j=c[2112932]|0}d=h&255;b=c[2276054]|0;c[2276054]=b+2;g=i&b;b=g&16777215;i=c[j+((b>>>10|16384)<<2)>>2]|0;if(i>>>0>9){a[i+(g&1023^1)|0]=h;c[2276075]=d;c[2276076]=d;c[2276077]=0;c[2276078]=0;return}else{gg[c[j+196648+(i<<2)>>2]&4095](b,h);c[2276075]=d;c[2276076]=d;c[2276077]=0;c[2276078]=0;return}}function pP(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=c[2276085]|0;m=g>>>((f<<3&16^16)>>>0)<<16>>16&l;f=m&16777215;g=c[2112932]|0;b=c[g+(f>>>10<<2)>>2]|0;if(b>>>0>9){n=a[b+(m&1023^1)|0]|0;o=l;p=g}else{l=gj[c[g+196608+(b<<2)>>2]&4095](f)|0;n=l;o=c[2276085]|0;p=c[2112932]|0}l=n&255;f=c[2276054]|0;c[2276054]=f+2;b=o&f;f=b&16777215;o=c[p+((f>>>10|16384)<<2)>>2]|0;if(o>>>0>9){a[o+(b&1023^1)|0]=n;c[2276075]=l;c[2276076]=l;c[2276077]=0;c[2276078]=0;return}else{gg[c[p+196648+(o<<2)>>2]&4095](f,n);c[2276075]=l;c[2276076]=l;c[2276077]=0;c[2276078]=0;return}}function pQ(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[2276085]|0;t=r&q;q=t&16777215;h=c[2112932]|0;s=c[h+(q>>>10<<2)>>2]|0;if(s>>>0>9){u=a[s+(t&1023^1)|0]|0;v=r;w=h}else{r=gj[c[h+196608+(s<<2)>>2]&4095](q)|0;u=r;v=c[2276085]|0;w=c[2112932]|0}r=u&255;q=c[2276054]|0;c[2276054]=q+2;s=v&q;q=s&16777215;v=c[w+((q>>>10|16384)<<2)>>2]|0;if(v>>>0>9){a[v+(s&1023^1)|0]=u;c[2276075]=r;c[2276076]=r;c[2276077]=0;c[2276078]=0;return}else{gg[c[w+196648+(v<<2)>>2]&4095](q,u);c[2276075]=r;c[2276076]=r;c[2276077]=0;c[2276078]=0;return}}function pR(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{k=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=k;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=(g>>>((f<<3&16^16)>>>0)<<16>>16)+b|0;b=l&16777215;f=c[2112932]|0;g=c[f+((b>>>10|32768)<<2)>>2]|0;if(g>>>0>9){n=a[g+(l&1023^1)|0]|0;o=f}else{l=gj[c[f+196608+(g<<2)>>2]&4095](b)|0;n=l;o=c[2112932]|0}l=n&255;b=c[2276054]|0;c[2276054]=b+2;g=c[2276085]&b;b=g&16777215;f=c[o+((b>>>10|16384)<<2)>>2]|0;if(f>>>0>9){a[f+(g&1023^1)|0]=n;c[2276075]=l;c[2276076]=l;c[2276077]=0;c[2276078]=0;return}else{gg[c[o+196648+(f<<2)>>2]&4095](b,n);c[2276075]=l;c[2276076]=l;c[2276077]=0;c[2276078]=0;return}}function pS(){var b=0,d=0,e=0,f=0,g=0,h=0;b=nB(c[2276056]|0)|0;d=b&16777215;e=c[2112932]|0;f=c[e+((d>>>10|32768)<<2)>>2]|0;if(f>>>0>9){g=a[f+(b&1023^1)|0]|0;h=e}else{b=gj[c[e+196608+(f<<2)>>2]&4095](d)|0;g=b;h=c[2112932]|0}b=g&255;d=c[2276054]|0;c[2276054]=d+2;f=c[2276085]&d;d=f&16777215;e=c[h+((d>>>10|16384)<<2)>>2]|0;if(e>>>0>9){a[e+(f&1023^1)|0]=g;c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}else{gg[c[h+196648+(e<<2)>>2]&4095](d,g);c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}}function pT(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0);f=l&255;g=c[2276054]|0;c[2276054]=g+2;m=c[2276085]&g;g=l&255;l=m&16777215;b=c[2112932]|0;e=c[b+((l>>>10|16384)<<2)>>2]|0;if(e>>>0>9){a[e+(m&1023^1)|0]=g;c[2276075]=f;c[2276076]=f;c[2276077]=0;c[2276078]=0;return}else{gg[c[b+196648+(e<<2)>>2]&4095](l,g);c[2276075]=f;c[2276076]=f;c[2276077]=0;c[2276078]=0;return}}function pU(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[2276069]|0;d=c[2276085]&c[9104156+((b&7|8)<<2)>>2];e=d&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=a[g+(d&1023^1)|0]|0;i=b;j=f}else{b=gj[c[f+196608+(g<<2)>>2]&4095](e)|0;h=b;i=c[2276069]|0;j=c[2112932]|0}b=h&255;e=9104156+((i>>>9&7|8)<<2)|0;i=c[e>>2]|0;c[e>>2]=i+1;e=c[2276085]&i;i=e&16777215;g=c[j+((i>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(e&1023^1)|0]=h;c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}else{gg[c[j+196648+(g<<2)>>2]&4095](i,h);c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}}function pV(){var b=0,d=0,e=0,f=0,g=0,h=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;b=c[2276085]&d;d=b&16777215;e=c[2112932]|0;f=c[e+(d>>>10<<2)>>2]|0;if(f>>>0>9){g=a[f+(b&1023^1)|0]|0;h=e}else{b=gj[c[e+196608+(f<<2)>>2]&4095](d)|0;g=b;h=c[2112932]|0}b=g&255;d=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;f=c[d>>2]|0;c[d>>2]=f+1;d=c[2276085]&f;f=d&16777215;e=c[h+((f>>>10|16384)<<2)>>2]|0;if(e>>>0>9){a[e+(d&1023^1)|0]=g;c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}else{gg[c[h+196648+(e<<2)>>2]&4095](f,g);c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}}function pW(){var b=0,d=0,e=0,f=0,g=0,h=0;b=c[2276054]|0;c[2276054]=b+2;d=c[2276085]&b;b=d&16777215;e=c[2112932]|0;f=c[e+(b>>>10<<2)>>2]|0;if(f>>>0>9){g=a[f+(d&1023^1)|0]|0;h=e}else{d=gj[c[e+196608+(f<<2)>>2]&4095](b)|0;g=d;h=c[2112932]|0}d=g&255;b=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;f=c[b>>2]|0;c[b>>2]=f+1;b=c[2276085]&f;f=b&16777215;e=c[h+((f>>>10|16384)<<2)>>2]|0;if(e>>>0>9){a[e+(b&1023^1)|0]=g;c[2276075]=d;c[2276076]=d;c[2276077]=0;c[2276078]=0;return}else{gg[c[h+196648+(e<<2)>>2]&4095](f,g);c[2276075]=d;c[2276076]=d;c[2276077]=0;c[2276078]=0;return}}function pX(){var b=0,d=0,e=0,f=0,g=0,h=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;b=c[2276085]&d;d=b&16777215;e=c[2112932]|0;f=c[e+(d>>>10<<2)>>2]|0;if(f>>>0>9){g=a[f+(b&1023^1)|0]|0;h=e}else{b=gj[c[e+196608+(f<<2)>>2]&4095](d)|0;g=b;h=c[2112932]|0}b=g&255;d=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;f=c[d>>2]|0;c[d>>2]=f+1;d=c[2276085]&f;f=d&16777215;e=c[h+((f>>>10|16384)<<2)>>2]|0;if(e>>>0>9){a[e+(d&1023^1)|0]=g;c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}else{gg[c[h+196648+(e<<2)>>2]&4095](f,g);c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}}function pY(){var b=0,d=0,e=0,f=0,g=0,h=0;b=(c[2276054]|0)-2|0;c[2276054]=b;d=c[2276085]&b;b=d&16777215;e=c[2112932]|0;f=c[e+(b>>>10<<2)>>2]|0;if(f>>>0>9){g=a[f+(d&1023^1)|0]|0;h=e}else{d=gj[c[e+196608+(f<<2)>>2]&4095](b)|0;g=d;h=c[2112932]|0}d=g&255;b=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;f=c[b>>2]|0;c[b>>2]=f+1;b=c[2276085]&f;f=b&16777215;e=c[h+((f>>>10|16384)<<2)>>2]|0;if(e>>>0>9){a[e+(b&1023^1)|0]=g;c[2276075]=d;c[2276076]=d;c[2276077]=0;c[2276078]=0;return}else{gg[c[h+196648+(e<<2)>>2]&4095](f,g);c[2276075]=d;c[2276076]=d;c[2276077]=0;c[2276078]=0;return}}function pZ(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=(h>>>((g<<3&16^16)>>>0)<<16>>16)+b&c[2276085];b=m&16777215;g=c[2112932]|0;h=c[g+(b>>>10<<2)>>2]|0;if(h>>>0>9){o=a[h+(m&1023^1)|0]|0;p=g}else{m=gj[c[g+196608+(h<<2)>>2]&4095](b)|0;o=m;p=c[2112932]|0}m=o&255;b=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;h=c[b>>2]|0;c[b>>2]=h+1;b=c[2276085]&h;h=b&16777215;g=c[p+((h>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(b&1023^1)|0]=o;c[2276075]=m;c[2276076]=m;c[2276077]=0;c[2276078]=0;return}else{gg[c[p+196648+(g<<2)>>2]&4095](h,o);c[2276075]=m;c[2276076]=m;c[2276077]=0;c[2276078]=0;return}}function p_(){var b=0,d=0,e=0,f=0,g=0,h=0;b=nB(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;d=c[2276085]&b;b=d&16777215;e=c[2112932]|0;f=c[e+(b>>>10<<2)>>2]|0;if(f>>>0>9){g=a[f+(d&1023^1)|0]|0;h=e}else{d=gj[c[e+196608+(f<<2)>>2]&4095](b)|0;g=d;h=c[2112932]|0}d=g&255;b=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;f=c[b>>2]|0;c[b>>2]=f+1;b=c[2276085]&f;f=b&16777215;e=c[h+((f>>>10|16384)<<2)>>2]|0;if(e>>>0>9){a[e+(b&1023^1)|0]=g;c[2276075]=d;c[2276076]=d;c[2276077]=0;c[2276078]=0;return}else{gg[c[h+196648+(e<<2)>>2]&4095](f,g);c[2276075]=d;c[2276076]=d;c[2276077]=0;c[2276078]=0;return}}function p$(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)<<16>>16&c[2276085];f=l&16777215;g=c[2112932]|0;m=c[g+(f>>>10<<2)>>2]|0;if(m>>>0>9){n=a[m+(l&1023^1)|0]|0;o=g}else{l=gj[c[g+196608+(m<<2)>>2]&4095](f)|0;n=l;o=c[2112932]|0}l=n&255;f=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;m=c[f>>2]|0;c[f>>2]=m+1;f=c[2276085]&m;m=f&16777215;g=c[o+((m>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(f&1023^1)|0]=n;c[2276075]=l;c[2276076]=l;c[2276077]=0;c[2276078]=0;return}else{gg[c[o+196648+(g<<2)>>2]&4095](m,n);c[2276075]=l;c[2276076]=l;c[2276077]=0;c[2276078]=0;return}}function p0(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[2276085]&q;q=r&16777215;t=c[2112932]|0;h=c[t+(q>>>10<<2)>>2]|0;if(h>>>0>9){u=a[h+(r&1023^1)|0]|0;v=t}else{r=gj[c[t+196608+(h<<2)>>2]&4095](q)|0;u=r;v=c[2112932]|0}r=u&255;q=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;h=c[q>>2]|0;c[q>>2]=h+1;q=c[2276085]&h;h=q&16777215;t=c[v+((h>>>10|16384)<<2)>>2]|0;if(t>>>0>9){a[t+(q&1023^1)|0]=u;c[2276075]=r;c[2276076]=r;c[2276077]=0;c[2276078]=0;return}else{gg[c[v+196648+(t<<2)>>2]&4095](h,u);c[2276075]=r;c[2276076]=r;c[2276077]=0;c[2276078]=0;return}}function p1(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{k=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=k;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=(g>>>((f<<3&16^16)>>>0)<<16>>16)+b|0;b=l&16777215;f=c[2112932]|0;g=c[f+((b>>>10|32768)<<2)>>2]|0;if(g>>>0>9){n=a[g+(l&1023^1)|0]|0;o=f}else{l=gj[c[f+196608+(g<<2)>>2]&4095](b)|0;n=l;o=c[2112932]|0}l=n&255;b=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;g=c[b>>2]|0;c[b>>2]=g+1;b=c[2276085]&g;g=b&16777215;f=c[o+((g>>>10|16384)<<2)>>2]|0;if(f>>>0>9){a[f+(b&1023^1)|0]=n;c[2276075]=l;c[2276076]=l;c[2276077]=0;c[2276078]=0;return}else{gg[c[o+196648+(f<<2)>>2]&4095](g,n);c[2276075]=l;c[2276076]=l;c[2276077]=0;c[2276078]=0;return}}function p2(){var b=0,d=0,e=0,f=0,g=0,h=0;b=nB(c[2276056]|0)|0;d=b&16777215;e=c[2112932]|0;f=c[e+((d>>>10|32768)<<2)>>2]|0;if(f>>>0>9){g=a[f+(b&1023^1)|0]|0;h=e}else{b=gj[c[e+196608+(f<<2)>>2]&4095](d)|0;g=b;h=c[2112932]|0}b=g&255;d=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;f=c[d>>2]|0;c[d>>2]=f+1;d=c[2276085]&f;f=d&16777215;e=c[h+((f>>>10|16384)<<2)>>2]|0;if(e>>>0>9){a[e+(d&1023^1)|0]=g;c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}else{gg[c[h+196648+(e<<2)>>2]&4095](f,g);c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}}function p3(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0);f=l&255;g=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;m=c[g>>2]|0;c[g>>2]=m+1;g=c[2276085]&m;m=l&255;l=g&16777215;b=c[2112932]|0;e=c[b+((l>>>10|16384)<<2)>>2]|0;if(e>>>0>9){a[e+(g&1023^1)|0]=m;c[2276075]=f;c[2276076]=f;c[2276077]=0;c[2276078]=0;return}else{gg[c[b+196648+(e<<2)>>2]&4095](l,m);c[2276075]=f;c[2276076]=f;c[2276077]=0;c[2276078]=0;return}}function p4(){var b=0,d=0,e=0,f=0,g=0,h=0;b=c[9104156+((c[2276069]&7)<<2)>>2]|0;d=b&255;e=(c[2276054]|0)-2|0;c[2276054]=e;f=c[2276085]&e;e=b&255;b=f&16777215;g=c[2112932]|0;h=c[g+((b>>>10|16384)<<2)>>2]|0;if(h>>>0>9){a[h+(f&1023^1)|0]=e;c[2276075]=d;c[2276076]=d;c[2276077]=0;c[2276078]=0;return}else{gg[c[g+196648+(h<<2)>>2]&4095](b,e);c[2276075]=d;c[2276076]=d;c[2276077]=0;c[2276078]=0;return}}function p5(){var b=0,d=0,e=0,f=0,g=0,h=0;b=c[2276069]|0;d=c[9104156+((b&7)<<2)>>2]|0;e=d&255;f=9104156+((b>>>9&7|8)<<2)|0;b=(c[f>>2]|0)-1|0;c[f>>2]=b;f=c[2276085]&b;b=d&255;d=f&16777215;g=c[2112932]|0;h=c[g+((d>>>10|16384)<<2)>>2]|0;if(h>>>0>9){a[h+(f&1023^1)|0]=b;c[2276075]=e;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}else{gg[c[g+196648+(h<<2)>>2]&4095](d,b);c[2276075]=e;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}}function p6(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[2276085]|0;d=b&c[9104156+((c[2276069]&7|8)<<2)>>2];e=d&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=a[g+(d&1023^1)|0]|0;i=b;j=f}else{b=gj[c[f+196608+(g<<2)>>2]&4095](e)|0;h=b;i=c[2276085]|0;j=c[2112932]|0}b=h&255;e=(c[2276054]|0)-2|0;c[2276054]=e;g=i&e;e=g&16777215;i=c[j+((e>>>10|16384)<<2)>>2]|0;if(i>>>0>9){a[i+(g&1023^1)|0]=h;c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}else{gg[c[j+196648+(i<<2)>>2]&4095](e,h);c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}}function p7(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;b=c[2276085]|0;e=b&d;d=e&16777215;f=c[2112932]|0;g=c[f+(d>>>10<<2)>>2]|0;if(g>>>0>9){h=a[g+(e&1023^1)|0]|0;i=b;j=f}else{b=gj[c[f+196608+(g<<2)>>2]&4095](d)|0;h=b;i=c[2276085]|0;j=c[2112932]|0}b=h&255;d=(c[2276054]|0)-2|0;c[2276054]=d;g=i&d;d=g&16777215;i=c[j+((d>>>10|16384)<<2)>>2]|0;if(i>>>0>9){a[i+(g&1023^1)|0]=h;c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}else{gg[c[j+196648+(i<<2)>>2]&4095](d,h);c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}}function p8(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=c[2276054]|0;d=b+2|0;c[2276054]=d;e=c[2276085]|0;f=e&b;b=f&16777215;g=c[2112932]|0;h=c[g+(b>>>10<<2)>>2]|0;if(h>>>0>9){i=a[h+(f&1023^1)|0]|0;j=d;k=e;l=g}else{e=gj[c[g+196608+(h<<2)>>2]&4095](b)|0;i=e;j=c[2276054]|0;k=c[2276085]|0;l=c[2112932]|0}e=i&255;b=j-2|0;c[2276054]=b;j=k&b;b=j&16777215;k=c[l+((b>>>10|16384)<<2)>>2]|0;if(k>>>0>9){a[k+(j&1023^1)|0]=i;c[2276075]=e;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}else{gg[c[l+196648+(k<<2)>>2]&4095](b,i);c[2276075]=e;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}}function p9(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;b=c[2276085]|0;e=b&d;d=e&16777215;f=c[2112932]|0;g=c[f+(d>>>10<<2)>>2]|0;if(g>>>0>9){h=a[g+(e&1023^1)|0]|0;i=b;j=f}else{b=gj[c[f+196608+(g<<2)>>2]&4095](d)|0;h=b;i=c[2276085]|0;j=c[2112932]|0}b=h&255;d=(c[2276054]|0)-2|0;c[2276054]=d;g=i&d;d=g&16777215;i=c[j+((d>>>10|16384)<<2)>>2]|0;if(i>>>0>9){a[i+(g&1023^1)|0]=h;c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}else{gg[c[j+196648+(i<<2)>>2]&4095](d,h);c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}}function qa(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=(c[2276054]|0)-2|0;c[2276054]=b;d=c[2276085]|0;e=d&b;f=e&16777215;g=c[2112932]|0;h=c[g+(f>>>10<<2)>>2]|0;if(h>>>0>9){i=a[h+(e&1023^1)|0]|0;j=b;k=d;l=g}else{d=gj[c[g+196608+(h<<2)>>2]&4095](f)|0;i=d;j=c[2276054]|0;k=c[2276085]|0;l=c[2112932]|0}d=i&255;f=j-2|0;c[2276054]=f;j=k&f;f=j&16777215;k=c[l+((f>>>10|16384)<<2)>>2]|0;if(k>>>0>9){a[k+(j&1023^1)|0]=i;c[2276075]=d;c[2276076]=d;c[2276077]=0;c[2276078]=0;return}else{gg[c[l+196648+(k<<2)>>2]&4095](f,i);c[2276075]=d;c[2276076]=d;c[2276077]=0;c[2276078]=0;return}}function qb(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=c[2276085]|0;n=(h>>>((g<<3&16^16)>>>0)<<16>>16)+b&m;b=n&16777215;g=c[2112932]|0;h=c[g+(b>>>10<<2)>>2]|0;if(h>>>0>9){o=a[h+(n&1023^1)|0]|0;p=m;q=g}else{m=gj[c[g+196608+(h<<2)>>2]&4095](b)|0;o=m;p=c[2276085]|0;q=c[2112932]|0}m=o&255;b=(c[2276054]|0)-2|0;c[2276054]=b;h=p&b;b=h&16777215;p=c[q+((b>>>10|16384)<<2)>>2]|0;if(p>>>0>9){a[p+(h&1023^1)|0]=o;c[2276075]=m;c[2276076]=m;c[2276077]=0;c[2276078]=0;return}else{gg[c[q+196648+(p<<2)>>2]&4095](b,o);c[2276075]=m;c[2276076]=m;c[2276077]=0;c[2276078]=0;return}}function qc(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=nB(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;d=c[2276085]|0;e=d&b;b=e&16777215;f=c[2112932]|0;g=c[f+(b>>>10<<2)>>2]|0;if(g>>>0>9){h=a[g+(e&1023^1)|0]|0;i=d;j=f}else{d=gj[c[f+196608+(g<<2)>>2]&4095](b)|0;h=d;i=c[2276085]|0;j=c[2112932]|0}d=h&255;b=(c[2276054]|0)-2|0;c[2276054]=b;g=i&b;b=g&16777215;i=c[j+((b>>>10|16384)<<2)>>2]|0;if(i>>>0>9){a[i+(g&1023^1)|0]=h;c[2276075]=d;c[2276076]=d;c[2276077]=0;c[2276078]=0;return}else{gg[c[j+196648+(i<<2)>>2]&4095](b,h);c[2276075]=d;c[2276076]=d;c[2276077]=0;c[2276078]=0;return}}function qd(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=c[2276085]|0;m=g>>>((f<<3&16^16)>>>0)<<16>>16&l;f=m&16777215;g=c[2112932]|0;b=c[g+(f>>>10<<2)>>2]|0;if(b>>>0>9){n=a[b+(m&1023^1)|0]|0;o=l;p=g}else{l=gj[c[g+196608+(b<<2)>>2]&4095](f)|0;n=l;o=c[2276085]|0;p=c[2112932]|0}l=n&255;f=(c[2276054]|0)-2|0;c[2276054]=f;b=o&f;f=b&16777215;o=c[p+((f>>>10|16384)<<2)>>2]|0;if(o>>>0>9){a[o+(b&1023^1)|0]=n;c[2276075]=l;c[2276076]=l;c[2276077]=0;c[2276078]=0;return}else{gg[c[p+196648+(o<<2)>>2]&4095](f,n);c[2276075]=l;c[2276076]=l;c[2276077]=0;c[2276078]=0;return}}function qe(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[2276085]|0;t=r&q;q=t&16777215;h=c[2112932]|0;s=c[h+(q>>>10<<2)>>2]|0;if(s>>>0>9){u=a[s+(t&1023^1)|0]|0;v=r;w=h}else{r=gj[c[h+196608+(s<<2)>>2]&4095](q)|0;u=r;v=c[2276085]|0;w=c[2112932]|0}r=u&255;q=(c[2276054]|0)-2|0;c[2276054]=q;s=v&q;q=s&16777215;v=c[w+((q>>>10|16384)<<2)>>2]|0;if(v>>>0>9){a[v+(s&1023^1)|0]=u;c[2276075]=r;c[2276076]=r;c[2276077]=0;c[2276078]=0;return}else{gg[c[w+196648+(v<<2)>>2]&4095](q,u);c[2276075]=r;c[2276076]=r;c[2276077]=0;c[2276078]=0;return}}function qf(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{k=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=k;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=(g>>>((f<<3&16^16)>>>0)<<16>>16)+b|0;b=l&16777215;f=c[2112932]|0;g=c[f+((b>>>10|32768)<<2)>>2]|0;if(g>>>0>9){n=a[g+(l&1023^1)|0]|0;o=f}else{l=gj[c[f+196608+(g<<2)>>2]&4095](b)|0;n=l;o=c[2112932]|0}l=n&255;b=(c[2276054]|0)-2|0;c[2276054]=b;g=c[2276085]&b;b=g&16777215;f=c[o+((b>>>10|16384)<<2)>>2]|0;if(f>>>0>9){a[f+(g&1023^1)|0]=n;c[2276075]=l;c[2276076]=l;c[2276077]=0;c[2276078]=0;return}else{gg[c[o+196648+(f<<2)>>2]&4095](b,n);c[2276075]=l;c[2276076]=l;c[2276077]=0;c[2276078]=0;return}}function qg(){var b=0,d=0,e=0,f=0,g=0,h=0;b=nB(c[2276056]|0)|0;d=b&16777215;e=c[2112932]|0;f=c[e+((d>>>10|32768)<<2)>>2]|0;if(f>>>0>9){g=a[f+(b&1023^1)|0]|0;h=e}else{b=gj[c[e+196608+(f<<2)>>2]&4095](d)|0;g=b;h=c[2112932]|0}b=g&255;d=(c[2276054]|0)-2|0;c[2276054]=d;f=c[2276085]&d;d=f&16777215;e=c[h+((d>>>10|16384)<<2)>>2]|0;if(e>>>0>9){a[e+(f&1023^1)|0]=g;c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}else{gg[c[h+196648+(e<<2)>>2]&4095](d,g);c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}}function qh(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0);f=l&255;g=(c[2276054]|0)-2|0;c[2276054]=g;m=c[2276085]&g;g=l&255;l=m&16777215;b=c[2112932]|0;e=c[b+((l>>>10|16384)<<2)>>2]|0;if(e>>>0>9){a[e+(m&1023^1)|0]=g;c[2276075]=f;c[2276076]=f;c[2276077]=0;c[2276078]=0;return}else{gg[c[b+196648+(e<<2)>>2]&4095](l,g);c[2276075]=f;c[2276076]=f;c[2276077]=0;c[2276078]=0;return}}function qi(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[2276069]|0;d=c[2276085]&c[9104156+((b&7|8)<<2)>>2];e=d&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=a[g+(d&1023^1)|0]|0;i=b;j=f}else{b=gj[c[f+196608+(g<<2)>>2]&4095](e)|0;h=b;i=c[2276069]|0;j=c[2112932]|0}b=h&255;e=9104156+((i>>>9&7|8)<<2)|0;i=(c[e>>2]|0)-1|0;c[e>>2]=i;e=c[2276085]&i;i=e&16777215;g=c[j+((i>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(e&1023^1)|0]=h;c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}else{gg[c[j+196648+(g<<2)>>2]&4095](i,h);c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}}function qj(){var b=0,d=0,e=0,f=0,g=0,h=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;b=c[2276085]&d;d=b&16777215;e=c[2112932]|0;f=c[e+(d>>>10<<2)>>2]|0;if(f>>>0>9){g=a[f+(b&1023^1)|0]|0;h=e}else{b=gj[c[e+196608+(f<<2)>>2]&4095](d)|0;g=b;h=c[2112932]|0}b=g&255;d=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;f=(c[d>>2]|0)-1|0;c[d>>2]=f;d=c[2276085]&f;f=d&16777215;e=c[h+((f>>>10|16384)<<2)>>2]|0;if(e>>>0>9){a[e+(d&1023^1)|0]=g;c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}else{gg[c[h+196648+(e<<2)>>2]&4095](f,g);c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}}function qk(){var b=0,d=0,e=0,f=0,g=0,h=0;b=c[2276054]|0;c[2276054]=b+2;d=c[2276085]&b;b=d&16777215;e=c[2112932]|0;f=c[e+(b>>>10<<2)>>2]|0;if(f>>>0>9){g=a[f+(d&1023^1)|0]|0;h=e}else{d=gj[c[e+196608+(f<<2)>>2]&4095](b)|0;g=d;h=c[2112932]|0}d=g&255;b=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;f=(c[b>>2]|0)-1|0;c[b>>2]=f;b=c[2276085]&f;f=b&16777215;e=c[h+((f>>>10|16384)<<2)>>2]|0;if(e>>>0>9){a[e+(b&1023^1)|0]=g;c[2276075]=d;c[2276076]=d;c[2276077]=0;c[2276078]=0;return}else{gg[c[h+196648+(e<<2)>>2]&4095](f,g);c[2276075]=d;c[2276076]=d;c[2276077]=0;c[2276078]=0;return}}function ql(){var b=0,d=0,e=0,f=0,g=0,h=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;b=c[2276085]&d;d=b&16777215;e=c[2112932]|0;f=c[e+(d>>>10<<2)>>2]|0;if(f>>>0>9){g=a[f+(b&1023^1)|0]|0;h=e}else{b=gj[c[e+196608+(f<<2)>>2]&4095](d)|0;g=b;h=c[2112932]|0}b=g&255;d=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;f=(c[d>>2]|0)-1|0;c[d>>2]=f;d=c[2276085]&f;f=d&16777215;e=c[h+((f>>>10|16384)<<2)>>2]|0;if(e>>>0>9){a[e+(d&1023^1)|0]=g;c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}else{gg[c[h+196648+(e<<2)>>2]&4095](f,g);c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}}function qm(){var b=0,d=0,e=0,f=0,g=0,h=0;b=(c[2276054]|0)-2|0;c[2276054]=b;d=c[2276085]&b;b=d&16777215;e=c[2112932]|0;f=c[e+(b>>>10<<2)>>2]|0;if(f>>>0>9){g=a[f+(d&1023^1)|0]|0;h=e}else{d=gj[c[e+196608+(f<<2)>>2]&4095](b)|0;g=d;h=c[2112932]|0}d=g&255;b=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;f=(c[b>>2]|0)-1|0;c[b>>2]=f;b=c[2276085]&f;f=b&16777215;e=c[h+((f>>>10|16384)<<2)>>2]|0;if(e>>>0>9){a[e+(b&1023^1)|0]=g;c[2276075]=d;c[2276076]=d;c[2276077]=0;c[2276078]=0;return}else{gg[c[h+196648+(e<<2)>>2]&4095](f,g);c[2276075]=d;c[2276076]=d;c[2276077]=0;c[2276078]=0;return}}function qn(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=(h>>>((g<<3&16^16)>>>0)<<16>>16)+b&c[2276085];b=m&16777215;g=c[2112932]|0;h=c[g+(b>>>10<<2)>>2]|0;if(h>>>0>9){o=a[h+(m&1023^1)|0]|0;p=g}else{m=gj[c[g+196608+(h<<2)>>2]&4095](b)|0;o=m;p=c[2112932]|0}m=o&255;b=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;h=(c[b>>2]|0)-1|0;c[b>>2]=h;b=c[2276085]&h;h=b&16777215;g=c[p+((h>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(b&1023^1)|0]=o;c[2276075]=m;c[2276076]=m;c[2276077]=0;c[2276078]=0;return}else{gg[c[p+196648+(g<<2)>>2]&4095](h,o);c[2276075]=m;c[2276076]=m;c[2276077]=0;c[2276078]=0;return}}function qo(){var b=0,d=0,e=0,f=0,g=0,h=0;b=nB(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;d=c[2276085]&b;b=d&16777215;e=c[2112932]|0;f=c[e+(b>>>10<<2)>>2]|0;if(f>>>0>9){g=a[f+(d&1023^1)|0]|0;h=e}else{d=gj[c[e+196608+(f<<2)>>2]&4095](b)|0;g=d;h=c[2112932]|0}d=g&255;b=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;f=(c[b>>2]|0)-1|0;c[b>>2]=f;b=c[2276085]&f;f=b&16777215;e=c[h+((f>>>10|16384)<<2)>>2]|0;if(e>>>0>9){a[e+(b&1023^1)|0]=g;c[2276075]=d;c[2276076]=d;c[2276077]=0;c[2276078]=0;return}else{gg[c[h+196648+(e<<2)>>2]&4095](f,g);c[2276075]=d;c[2276076]=d;c[2276077]=0;c[2276078]=0;return}}function qp(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)<<16>>16&c[2276085];f=l&16777215;g=c[2112932]|0;m=c[g+(f>>>10<<2)>>2]|0;if(m>>>0>9){n=a[m+(l&1023^1)|0]|0;o=g}else{l=gj[c[g+196608+(m<<2)>>2]&4095](f)|0;n=l;o=c[2112932]|0}l=n&255;f=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;m=(c[f>>2]|0)-1|0;c[f>>2]=m;f=c[2276085]&m;m=f&16777215;g=c[o+((m>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(f&1023^1)|0]=n;c[2276075]=l;c[2276076]=l;c[2276077]=0;c[2276078]=0;return}else{gg[c[o+196648+(g<<2)>>2]&4095](m,n);c[2276075]=l;c[2276076]=l;c[2276077]=0;c[2276078]=0;return}}function qq(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[2276085]&q;q=r&16777215;t=c[2112932]|0;h=c[t+(q>>>10<<2)>>2]|0;if(h>>>0>9){u=a[h+(r&1023^1)|0]|0;v=t}else{r=gj[c[t+196608+(h<<2)>>2]&4095](q)|0;u=r;v=c[2112932]|0}r=u&255;q=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;h=(c[q>>2]|0)-1|0;c[q>>2]=h;q=c[2276085]&h;h=q&16777215;t=c[v+((h>>>10|16384)<<2)>>2]|0;if(t>>>0>9){a[t+(q&1023^1)|0]=u;c[2276075]=r;c[2276076]=r;c[2276077]=0;c[2276078]=0;return}else{gg[c[v+196648+(t<<2)>>2]&4095](h,u);c[2276075]=r;c[2276076]=r;c[2276077]=0;c[2276078]=0;return}}function qr(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{k=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=k;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=(g>>>((f<<3&16^16)>>>0)<<16>>16)+b|0;b=l&16777215;f=c[2112932]|0;g=c[f+((b>>>10|32768)<<2)>>2]|0;if(g>>>0>9){n=a[g+(l&1023^1)|0]|0;o=f}else{l=gj[c[f+196608+(g<<2)>>2]&4095](b)|0;n=l;o=c[2112932]|0}l=n&255;b=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;g=(c[b>>2]|0)-1|0;c[b>>2]=g;b=c[2276085]&g;g=b&16777215;f=c[o+((g>>>10|16384)<<2)>>2]|0;if(f>>>0>9){a[f+(b&1023^1)|0]=n;c[2276075]=l;c[2276076]=l;c[2276077]=0;c[2276078]=0;return}else{gg[c[o+196648+(f<<2)>>2]&4095](g,n);c[2276075]=l;c[2276076]=l;c[2276077]=0;c[2276078]=0;return}}function qs(){var b=0,d=0,e=0,f=0,g=0,h=0;b=nB(c[2276056]|0)|0;d=b&16777215;e=c[2112932]|0;f=c[e+((d>>>10|32768)<<2)>>2]|0;if(f>>>0>9){g=a[f+(b&1023^1)|0]|0;h=e}else{b=gj[c[e+196608+(f<<2)>>2]&4095](d)|0;g=b;h=c[2112932]|0}b=g&255;d=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;f=(c[d>>2]|0)-1|0;c[d>>2]=f;d=c[2276085]&f;f=d&16777215;e=c[h+((f>>>10|16384)<<2)>>2]|0;if(e>>>0>9){a[e+(d&1023^1)|0]=g;c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}else{gg[c[h+196648+(e<<2)>>2]&4095](f,g);c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}}function qt(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0);f=l&255;g=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;m=(c[g>>2]|0)-1|0;c[g>>2]=m;g=c[2276085]&m;m=l&255;l=g&16777215;b=c[2112932]|0;e=c[b+((l>>>10|16384)<<2)>>2]|0;if(e>>>0>9){a[e+(g&1023^1)|0]=m;c[2276075]=f;c[2276076]=f;c[2276077]=0;c[2276078]=0;return}else{gg[c[b+196648+(e<<2)>>2]&4095](l,m);c[2276075]=f;c[2276076]=f;c[2276077]=0;c[2276078]=0;return}}function qu(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276069]|0;e=c[9104156+((b&7)<<2)>>2]|0;f=e&255;g=c[9104156+((b>>>9&7|8)<<2)>>2]|0;b=c[2276056]|0;h=b&-4;if((h|0)==(c[2276083]|0)){i=b;j=c[2276084]|0}else{c[2276083]=h;k=c[2276085]&h;h=k&16777212;l=c[2112932]|0;m=c[l+((h>>>10|32768)<<2)>>2]|0;if(m>>>0>9){n=k&1020;o=(d[m+(n|3)|0]|0)<<8|(d[m+(n|2)|0]|0)|((d[m+(n|1)|0]|0)<<8|(d[m+n|0]|0))<<16;p=b}else{b=gj[c[l+196768+(m<<2)>>2]&4095](h)|0;o=b;p=c[2276056]|0}c[2276084]=o;i=p;j=o}c[2276056]=i+2;o=(j>>>((i<<3&16^16)>>>0)<<16>>16)+g&c[2276085];g=e&255;e=o&16777215;i=c[2112932]|0;j=c[i+((e>>>10|16384)<<2)>>2]|0;if(j>>>0>9){a[j+(o&1023^1)|0]=g;c[2276075]=f;c[2276076]=f;c[2276077]=0;c[2276078]=0;return}else{gg[c[i+196648+(j<<2)>>2]&4095](e,g);c[2276075]=f;c[2276076]=f;c[2276077]=0;c[2276078]=0;return}}function qv(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276069]|0;e=c[2276085]&c[9104156+((b&7|8)<<2)>>2];f=e&16777215;g=c[2112932]|0;h=c[g+(f>>>10<<2)>>2]|0;if(h>>>0>9){i=a[h+(e&1023^1)|0]|0;j=b}else{b=gj[c[g+196608+(h<<2)>>2]&4095](f)|0;i=b;j=c[2276069]|0}b=i&255;f=c[9104156+((j>>>9&7|8)<<2)>>2]|0;j=c[2276056]|0;h=j&-4;if((h|0)==(c[2276083]|0)){k=j;l=c[2276084]|0}else{c[2276083]=h;g=c[2276085]&h;h=g&16777212;e=c[2112932]|0;m=c[e+((h>>>10|32768)<<2)>>2]|0;if(m>>>0>9){n=g&1020;o=(d[m+(n|3)|0]|0)<<8|(d[m+(n|2)|0]|0)|((d[m+(n|1)|0]|0)<<8|(d[m+n|0]|0))<<16;p=j}else{j=gj[c[e+196768+(m<<2)>>2]&4095](h)|0;o=j;p=c[2276056]|0}c[2276084]=o;k=p;l=o}c[2276056]=k+2;o=(l>>>((k<<3&16^16)>>>0)<<16>>16)+f&c[2276085];f=o&16777215;k=c[2112932]|0;l=c[k+((f>>>10|16384)<<2)>>2]|0;if(l>>>0>9){a[l+(o&1023^1)|0]=i;c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}else{gg[c[k+196648+(l<<2)>>2]&4095](f,i);c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}}function qw(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=c[b>>2]|0;c[b>>2]=e+1;b=c[2276085]&e;e=b&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=a[g+(b&1023^1)|0]|0}else{h=gj[c[f+196608+(g<<2)>>2]&4095](e)|0}e=h&255;g=c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2]|0;f=c[2276056]|0;b=f&-4;if((b|0)==(c[2276083]|0)){i=f;j=c[2276084]|0}else{c[2276083]=b;k=c[2276085]&b;b=k&16777212;l=c[2112932]|0;m=c[l+((b>>>10|32768)<<2)>>2]|0;if(m>>>0>9){n=k&1020;o=(d[m+(n|3)|0]|0)<<8|(d[m+(n|2)|0]|0)|((d[m+(n|1)|0]|0)<<8|(d[m+n|0]|0))<<16;p=f}else{f=gj[c[l+196768+(m<<2)>>2]&4095](b)|0;o=f;p=c[2276056]|0}c[2276084]=o;i=p;j=o}c[2276056]=i+2;o=(j>>>((i<<3&16^16)>>>0)<<16>>16)+g&c[2276085];g=o&16777215;i=c[2112932]|0;j=c[i+((g>>>10|16384)<<2)>>2]|0;if(j>>>0>9){a[j+(o&1023^1)|0]=h;c[2276075]=e;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}else{gg[c[i+196648+(j<<2)>>2]&4095](g,h);c[2276075]=e;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}}function qx(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276054]|0;c[2276054]=b+2;e=c[2276085]&b;b=e&16777215;f=c[2112932]|0;g=c[f+(b>>>10<<2)>>2]|0;if(g>>>0>9){h=a[g+(e&1023^1)|0]|0}else{h=gj[c[f+196608+(g<<2)>>2]&4095](b)|0}b=h&255;g=c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2]|0;f=c[2276056]|0;e=f&-4;if((e|0)==(c[2276083]|0)){i=f;j=c[2276084]|0}else{c[2276083]=e;k=c[2276085]&e;e=k&16777212;l=c[2112932]|0;m=c[l+((e>>>10|32768)<<2)>>2]|0;if(m>>>0>9){n=k&1020;o=(d[m+(n|3)|0]|0)<<8|(d[m+(n|2)|0]|0)|((d[m+(n|1)|0]|0)<<8|(d[m+n|0]|0))<<16;p=f}else{f=gj[c[l+196768+(m<<2)>>2]&4095](e)|0;o=f;p=c[2276056]|0}c[2276084]=o;i=p;j=o}c[2276056]=i+2;o=(j>>>((i<<3&16^16)>>>0)<<16>>16)+g&c[2276085];g=o&16777215;i=c[2112932]|0;j=c[i+((g>>>10|16384)<<2)>>2]|0;if(j>>>0>9){a[j+(o&1023^1)|0]=h;c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}else{gg[c[i+196648+(j<<2)>>2]&4095](g,h);c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}}function qy(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=(c[b>>2]|0)-1|0;c[b>>2]=e;b=c[2276085]&e;e=b&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=a[g+(b&1023^1)|0]|0}else{h=gj[c[f+196608+(g<<2)>>2]&4095](e)|0}e=h&255;g=c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2]|0;f=c[2276056]|0;b=f&-4;if((b|0)==(c[2276083]|0)){i=f;j=c[2276084]|0}else{c[2276083]=b;k=c[2276085]&b;b=k&16777212;l=c[2112932]|0;m=c[l+((b>>>10|32768)<<2)>>2]|0;if(m>>>0>9){n=k&1020;o=(d[m+(n|3)|0]|0)<<8|(d[m+(n|2)|0]|0)|((d[m+(n|1)|0]|0)<<8|(d[m+n|0]|0))<<16;p=f}else{f=gj[c[l+196768+(m<<2)>>2]&4095](b)|0;o=f;p=c[2276056]|0}c[2276084]=o;i=p;j=o}c[2276056]=i+2;o=(j>>>((i<<3&16^16)>>>0)<<16>>16)+g&c[2276085];g=o&16777215;i=c[2112932]|0;j=c[i+((g>>>10|16384)<<2)>>2]|0;if(j>>>0>9){a[j+(o&1023^1)|0]=h;c[2276075]=e;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}else{gg[c[i+196648+(j<<2)>>2]&4095](g,h);c[2276075]=e;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}}function qz(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=(c[2276054]|0)-2|0;c[2276054]=b;e=c[2276085]&b;b=e&16777215;f=c[2112932]|0;g=c[f+(b>>>10<<2)>>2]|0;if(g>>>0>9){h=a[g+(e&1023^1)|0]|0}else{h=gj[c[f+196608+(g<<2)>>2]&4095](b)|0}b=h&255;g=c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2]|0;f=c[2276056]|0;e=f&-4;if((e|0)==(c[2276083]|0)){i=f;j=c[2276084]|0}else{c[2276083]=e;k=c[2276085]&e;e=k&16777212;l=c[2112932]|0;m=c[l+((e>>>10|32768)<<2)>>2]|0;if(m>>>0>9){n=k&1020;o=(d[m+(n|3)|0]|0)<<8|(d[m+(n|2)|0]|0)|((d[m+(n|1)|0]|0)<<8|(d[m+n|0]|0))<<16;p=f}else{f=gj[c[l+196768+(m<<2)>>2]&4095](e)|0;o=f;p=c[2276056]|0}c[2276084]=o;i=p;j=o}c[2276056]=i+2;o=(j>>>((i<<3&16^16)>>>0)<<16>>16)+g&c[2276085];g=o&16777215;i=c[2112932]|0;j=c[i+((g>>>10|16384)<<2)>>2]|0;if(j>>>0>9){a[j+(o&1023^1)|0]=h;c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}else{gg[c[i+196648+(j<<2)>>2]&4095](g,h);c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}}function qA(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}m=g+2|0;c[2276056]=m;n=(h>>>((g<<3&16^16)>>>0)<<16>>16)+b&c[2276085];b=n&16777215;g=c[2112932]|0;h=c[g+(b>>>10<<2)>>2]|0;if(h>>>0>9){o=a[h+(n&1023^1)|0]|0;p=m}else{m=gj[c[g+196608+(h<<2)>>2]&4095](b)|0;o=m;p=c[2276056]|0}m=o&255;b=c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2]|0;h=p&-4;if((h|0)==(c[2276083]|0)){q=p;r=c[2276084]|0}else{c[2276083]=h;g=c[2276085]&h;h=g&16777212;n=c[2112932]|0;e=c[n+((h>>>10|32768)<<2)>>2]|0;if(e>>>0>9){f=g&1020;s=(d[e+(f|3)|0]|0)<<8|(d[e+(f|2)|0]|0)|((d[e+(f|1)|0]|0)<<8|(d[e+f|0]|0))<<16;t=p}else{p=gj[c[n+196768+(e<<2)>>2]&4095](h)|0;s=p;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;s=(r>>>((q<<3&16^16)>>>0)<<16>>16)+b&c[2276085];b=s&16777215;q=c[2112932]|0;r=c[q+((b>>>10|16384)<<2)>>2]|0;if(r>>>0>9){a[r+(s&1023^1)|0]=o;c[2276075]=m;c[2276076]=m;c[2276077]=0;c[2276078]=0;return}else{gg[c[q+196648+(r<<2)>>2]&4095](b,o);c[2276075]=m;c[2276076]=m;c[2276077]=0;c[2276078]=0;return}}function qB(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=nB(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;e=c[2276085]&b;b=e&16777215;f=c[2112932]|0;g=c[f+(b>>>10<<2)>>2]|0;if(g>>>0>9){h=a[g+(e&1023^1)|0]|0}else{h=gj[c[f+196608+(g<<2)>>2]&4095](b)|0}b=h&255;g=c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2]|0;f=c[2276056]|0;e=f&-4;if((e|0)==(c[2276083]|0)){i=f;j=c[2276084]|0}else{c[2276083]=e;k=c[2276085]&e;e=k&16777212;l=c[2112932]|0;m=c[l+((e>>>10|32768)<<2)>>2]|0;if(m>>>0>9){n=k&1020;o=(d[m+(n|3)|0]|0)<<8|(d[m+(n|2)|0]|0)|((d[m+(n|1)|0]|0)<<8|(d[m+n|0]|0))<<16;p=f}else{f=gj[c[l+196768+(m<<2)>>2]&4095](e)|0;o=f;p=c[2276056]|0}c[2276084]=o;i=p;j=o}c[2276056]=i+2;o=(j>>>((i<<3&16^16)>>>0)<<16>>16)+g&c[2276085];g=o&16777215;i=c[2112932]|0;j=c[i+((g>>>10|16384)<<2)>>2]|0;if(j>>>0>9){a[j+(o&1023^1)|0]=h;c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}else{gg[c[i+196648+(j<<2)>>2]&4095](g,h);c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}}function qC(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}l=f+2|0;c[2276056]=l;m=g>>>((f<<3&16^16)>>>0)<<16>>16&c[2276085];f=m&16777215;g=c[2112932]|0;b=c[g+(f>>>10<<2)>>2]|0;if(b>>>0>9){n=a[b+(m&1023^1)|0]|0;o=l}else{l=gj[c[g+196608+(b<<2)>>2]&4095](f)|0;n=l;o=c[2276056]|0}l=n&255;f=c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2]|0;b=o&-4;if((b|0)==(c[2276083]|0)){p=o;q=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;m=c[2112932]|0;e=c[m+((b>>>10|32768)<<2)>>2]|0;if(e>>>0>9){j=g&1020;r=(d[e+(j|3)|0]|0)<<8|(d[e+(j|2)|0]|0)|((d[e+(j|1)|0]|0)<<8|(d[e+j|0]|0))<<16;s=o}else{o=gj[c[m+196768+(e<<2)>>2]&4095](b)|0;r=o;s=c[2276056]|0}c[2276084]=r;p=s;q=r}c[2276056]=p+2;r=(q>>>((p<<3&16^16)>>>0)<<16>>16)+f&c[2276085];f=r&16777215;p=c[2112932]|0;q=c[p+((f>>>10|16384)<<2)>>2]|0;if(q>>>0>9){a[q+(r&1023^1)|0]=n;c[2276075]=l;c[2276076]=l;c[2276077]=0;c[2276078]=0;return}else{gg[c[p+196648+(q<<2)>>2]&4095](f,n);c[2276075]=l;c[2276076]=l;c[2276077]=0;c[2276078]=0;return}}function qD(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}t=r+2|0;c[2276056]=t;r=c[2276085]&q;q=r&16777215;h=c[2112932]|0;s=c[h+(q>>>10<<2)>>2]|0;if(s>>>0>9){u=a[s+(r&1023^1)|0]|0;v=t}else{t=gj[c[h+196608+(s<<2)>>2]&4095](q)|0;u=t;v=c[2276056]|0}t=u&255;q=c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2]|0;s=v&-4;if((s|0)==(c[2276083]|0)){w=v;x=c[2276084]|0}else{c[2276083]=s;h=c[2276085]&s;s=h&16777212;r=c[2112932]|0;n=c[r+((s>>>10|32768)<<2)>>2]|0;if(n>>>0>9){f=h&1020;y=(d[n+(f|3)|0]|0)<<8|(d[n+(f|2)|0]|0)|((d[n+(f|1)|0]|0)<<8|(d[n+f|0]|0))<<16;z=v}else{v=gj[c[r+196768+(n<<2)>>2]&4095](s)|0;y=v;z=c[2276056]|0}c[2276084]=y;w=z;x=y}c[2276056]=w+2;y=(x>>>((w<<3&16^16)>>>0)<<16>>16)+q&c[2276085];q=y&16777215;w=c[2112932]|0;x=c[w+((q>>>10|16384)<<2)>>2]|0;if(x>>>0>9){a[x+(y&1023^1)|0]=u;c[2276075]=t;c[2276076]=t;c[2276077]=0;c[2276078]=0;return}else{gg[c[w+196648+(x<<2)>>2]&4095](q,u);c[2276075]=t;c[2276076]=t;c[2276077]=0;c[2276078]=0;return}}function qE(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{k=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=k;m=c[2276056]|0}c[2276084]=l;f=m;g=l}l=f+2|0;c[2276056]=l;m=(g>>>((f<<3&16^16)>>>0)<<16>>16)+b|0;b=m&16777215;f=c[2112932]|0;g=c[f+((b>>>10|32768)<<2)>>2]|0;if(g>>>0>9){n=a[g+(m&1023^1)|0]|0;o=l}else{l=gj[c[f+196608+(g<<2)>>2]&4095](b)|0;n=l;o=c[2276056]|0}l=n&255;b=c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2]|0;g=o&-4;if((g|0)==(c[2276083]|0)){p=o;q=c[2276084]|0}else{c[2276083]=g;f=c[2276085]&g;g=f&16777212;m=c[2112932]|0;k=c[m+((g>>>10|32768)<<2)>>2]|0;if(k>>>0>9){e=f&1020;r=(d[k+(e|3)|0]|0)<<8|(d[k+(e|2)|0]|0)|((d[k+(e|1)|0]|0)<<8|(d[k+e|0]|0))<<16;s=o}else{o=gj[c[m+196768+(k<<2)>>2]&4095](g)|0;r=o;s=c[2276056]|0}c[2276084]=r;p=s;q=r}c[2276056]=p+2;r=(q>>>((p<<3&16^16)>>>0)<<16>>16)+b&c[2276085];b=r&16777215;p=c[2112932]|0;q=c[p+((b>>>10|16384)<<2)>>2]|0;if(q>>>0>9){a[q+(r&1023^1)|0]=n;c[2276075]=l;c[2276076]=l;c[2276077]=0;c[2276078]=0;return}else{gg[c[p+196648+(q<<2)>>2]&4095](b,n);c[2276075]=l;c[2276076]=l;c[2276077]=0;c[2276078]=0;return}}function qF(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=nB(c[2276056]|0)|0;e=b&16777215;f=c[2112932]|0;g=c[f+((e>>>10|32768)<<2)>>2]|0;if(g>>>0>9){h=a[g+(b&1023^1)|0]|0}else{h=gj[c[f+196608+(g<<2)>>2]&4095](e)|0}e=h&255;g=c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2]|0;f=c[2276056]|0;b=f&-4;if((b|0)==(c[2276083]|0)){i=f;j=c[2276084]|0}else{c[2276083]=b;k=c[2276085]&b;b=k&16777212;l=c[2112932]|0;m=c[l+((b>>>10|32768)<<2)>>2]|0;if(m>>>0>9){n=k&1020;o=(d[m+(n|3)|0]|0)<<8|(d[m+(n|2)|0]|0)|((d[m+(n|1)|0]|0)<<8|(d[m+n|0]|0))<<16;p=f}else{f=gj[c[l+196768+(m<<2)>>2]&4095](b)|0;o=f;p=c[2276056]|0}c[2276084]=o;i=p;j=o}c[2276056]=i+2;o=(j>>>((i<<3&16^16)>>>0)<<16>>16)+g&c[2276085];g=o&16777215;i=c[2112932]|0;j=c[i+((g>>>10|16384)<<2)>>2]|0;if(j>>>0>9){a[j+(o&1023^1)|0]=h;c[2276075]=e;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}else{gg[c[i+196648+(j<<2)>>2]&4095](g,h);c[2276075]=e;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}}function qG(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0);f=n&255;o=c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2]|0;e=p&-4;if((e|0)==(h|0)){q=p;r=g}else{c[2276083]=e;g=c[2276085]&e;e=g&16777212;h=c[2112932]|0;j=c[h+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){l=g&1020;s=(d[j+(l|3)|0]|0)<<8|(d[j+(l|2)|0]|0)|((d[j+(l|1)|0]|0)<<8|(d[j+l|0]|0))<<16;t=p}else{p=gj[c[h+196768+(j<<2)>>2]&4095](e)|0;s=p;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;s=(r>>>((q<<3&16^16)>>>0)<<16>>16)+o&c[2276085];o=n&255;n=s&16777215;q=c[2112932]|0;r=c[q+((n>>>10|16384)<<2)>>2]|0;if(r>>>0>9){a[r+(s&1023^1)|0]=o;c[2276075]=f;c[2276076]=f;c[2276077]=0;c[2276078]=0;return}else{gg[c[q+196648+(r<<2)>>2]&4095](n,o);c[2276075]=f;c[2276076]=f;c[2276077]=0;c[2276078]=0;return}}function qH(){var b=0,d=0,e=0,f=0,g=0,h=0;b=c[2276069]|0;d=c[9104156+((b&7)<<2)>>2]|0;e=d&255;f=nB(c[9104156+((b>>>9&7|8)<<2)>>2]|0)|0;b=c[2276085]&f;f=d&255;d=b&16777215;g=c[2112932]|0;h=c[g+((d>>>10|16384)<<2)>>2]|0;if(h>>>0>9){a[h+(b&1023^1)|0]=f;c[2276075]=e;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}else{gg[c[g+196648+(h<<2)>>2]&4095](d,f);c[2276075]=e;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}}function qI(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=c[2276069]|0;d=c[2276085]&c[9104156+((b&7|8)<<2)>>2];e=d&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=a[g+(d&1023^1)|0]|0;i=b}else{b=gj[c[f+196608+(g<<2)>>2]&4095](e)|0;h=b;i=c[2276069]|0}b=h&255;e=nB(c[9104156+((i>>>9&7|8)<<2)>>2]|0)|0;i=c[2276085]&e;e=i&16777215;g=c[2112932]|0;f=c[g+((e>>>10|16384)<<2)>>2]|0;if(f>>>0>9){a[f+(i&1023^1)|0]=h;c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}else{gg[c[g+196648+(f<<2)>>2]&4095](e,h);c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}}function qJ(){var b=0,d=0,e=0,f=0,g=0,h=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;b=c[2276085]&d;d=b&16777215;e=c[2112932]|0;f=c[e+(d>>>10<<2)>>2]|0;if(f>>>0>9){g=a[f+(b&1023^1)|0]|0}else{g=gj[c[e+196608+(f<<2)>>2]&4095](d)|0}d=g&255;f=nB(c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2]|0)|0;e=c[2276085]&f;f=e&16777215;b=c[2112932]|0;h=c[b+((f>>>10|16384)<<2)>>2]|0;if(h>>>0>9){a[h+(e&1023^1)|0]=g;c[2276075]=d;c[2276076]=d;c[2276077]=0;c[2276078]=0;return}else{gg[c[b+196648+(h<<2)>>2]&4095](f,g);c[2276075]=d;c[2276076]=d;c[2276077]=0;c[2276078]=0;return}}function qK(){var b=0,d=0,e=0,f=0,g=0,h=0;b=c[2276054]|0;c[2276054]=b+2;d=c[2276085]&b;b=d&16777215;e=c[2112932]|0;f=c[e+(b>>>10<<2)>>2]|0;if(f>>>0>9){g=a[f+(d&1023^1)|0]|0}else{g=gj[c[e+196608+(f<<2)>>2]&4095](b)|0}b=g&255;f=nB(c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2]|0)|0;e=c[2276085]&f;f=e&16777215;d=c[2112932]|0;h=c[d+((f>>>10|16384)<<2)>>2]|0;if(h>>>0>9){a[h+(e&1023^1)|0]=g;c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}else{gg[c[d+196648+(h<<2)>>2]&4095](f,g);c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}}function qL(){var b=0,d=0,e=0,f=0,g=0,h=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;b=c[2276085]&d;d=b&16777215;e=c[2112932]|0;f=c[e+(d>>>10<<2)>>2]|0;if(f>>>0>9){g=a[f+(b&1023^1)|0]|0}else{g=gj[c[e+196608+(f<<2)>>2]&4095](d)|0}d=g&255;f=nB(c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2]|0)|0;e=c[2276085]&f;f=e&16777215;b=c[2112932]|0;h=c[b+((f>>>10|16384)<<2)>>2]|0;if(h>>>0>9){a[h+(e&1023^1)|0]=g;c[2276075]=d;c[2276076]=d;c[2276077]=0;c[2276078]=0;return}else{gg[c[b+196648+(h<<2)>>2]&4095](f,g);c[2276075]=d;c[2276076]=d;c[2276077]=0;c[2276078]=0;return}}function qM(){var b=0,d=0,e=0,f=0,g=0,h=0;b=(c[2276054]|0)-2|0;c[2276054]=b;d=c[2276085]&b;b=d&16777215;e=c[2112932]|0;f=c[e+(b>>>10<<2)>>2]|0;if(f>>>0>9){g=a[f+(d&1023^1)|0]|0}else{g=gj[c[e+196608+(f<<2)>>2]&4095](b)|0}b=g&255;f=nB(c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2]|0)|0;e=c[2276085]&f;f=e&16777215;d=c[2112932]|0;h=c[d+((f>>>10|16384)<<2)>>2]|0;if(h>>>0>9){a[h+(e&1023^1)|0]=g;c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}else{gg[c[d+196648+(h<<2)>>2]&4095](f,g);c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}}function qN(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=(h>>>((g<<3&16^16)>>>0)<<16>>16)+b&c[2276085];b=m&16777215;g=c[2112932]|0;h=c[g+(b>>>10<<2)>>2]|0;if(h>>>0>9){o=a[h+(m&1023^1)|0]|0}else{o=gj[c[g+196608+(h<<2)>>2]&4095](b)|0}b=o&255;h=nB(c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2]|0)|0;g=c[2276085]&h;h=g&16777215;m=c[2112932]|0;n=c[m+((h>>>10|16384)<<2)>>2]|0;if(n>>>0>9){a[n+(g&1023^1)|0]=o;c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}else{gg[c[m+196648+(n<<2)>>2]&4095](h,o);c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}}function qO(){var b=0,d=0,e=0,f=0,g=0,h=0;b=nB(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;d=c[2276085]&b;b=d&16777215;e=c[2112932]|0;f=c[e+(b>>>10<<2)>>2]|0;if(f>>>0>9){g=a[f+(d&1023^1)|0]|0}else{g=gj[c[e+196608+(f<<2)>>2]&4095](b)|0}b=g&255;f=nB(c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2]|0)|0;e=c[2276085]&f;f=e&16777215;d=c[2112932]|0;h=c[d+((f>>>10|16384)<<2)>>2]|0;if(h>>>0>9){a[h+(e&1023^1)|0]=g;c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}else{gg[c[d+196648+(h<<2)>>2]&4095](f,g);c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}}function qP(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)<<16>>16&c[2276085];f=l&16777215;g=c[2112932]|0;m=c[g+(f>>>10<<2)>>2]|0;if(m>>>0>9){n=a[m+(l&1023^1)|0]|0}else{n=gj[c[g+196608+(m<<2)>>2]&4095](f)|0}f=n&255;m=nB(c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2]|0)|0;g=c[2276085]&m;m=g&16777215;l=c[2112932]|0;b=c[l+((m>>>10|16384)<<2)>>2]|0;if(b>>>0>9){a[b+(g&1023^1)|0]=n;c[2276075]=f;c[2276076]=f;c[2276077]=0;c[2276078]=0;return}else{gg[c[l+196648+(b<<2)>>2]&4095](m,n);c[2276075]=f;c[2276076]=f;c[2276077]=0;c[2276078]=0;return}}function qQ(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[2276085]&q;q=r&16777215;t=c[2112932]|0;h=c[t+(q>>>10<<2)>>2]|0;if(h>>>0>9){u=a[h+(r&1023^1)|0]|0}else{u=gj[c[t+196608+(h<<2)>>2]&4095](q)|0}q=u&255;h=nB(c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2]|0)|0;t=c[2276085]&h;h=t&16777215;r=c[2112932]|0;s=c[r+((h>>>10|16384)<<2)>>2]|0;if(s>>>0>9){a[s+(t&1023^1)|0]=u;c[2276075]=q;c[2276076]=q;c[2276077]=0;c[2276078]=0;return}else{gg[c[r+196648+(s<<2)>>2]&4095](h,u);c[2276075]=q;c[2276076]=q;c[2276077]=0;c[2276078]=0;return}}function qR(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{k=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=k;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=(g>>>((f<<3&16^16)>>>0)<<16>>16)+b|0;b=l&16777215;f=c[2112932]|0;g=c[f+((b>>>10|32768)<<2)>>2]|0;if(g>>>0>9){n=a[g+(l&1023^1)|0]|0}else{n=gj[c[f+196608+(g<<2)>>2]&4095](b)|0}b=n&255;g=nB(c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2]|0)|0;f=c[2276085]&g;g=f&16777215;l=c[2112932]|0;m=c[l+((g>>>10|16384)<<2)>>2]|0;if(m>>>0>9){a[m+(f&1023^1)|0]=n;c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}else{gg[c[l+196648+(m<<2)>>2]&4095](g,n);c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}}function qS(){var b=0,d=0,e=0,f=0,g=0,h=0;b=nB(c[2276056]|0)|0;d=b&16777215;e=c[2112932]|0;f=c[e+((d>>>10|32768)<<2)>>2]|0;if(f>>>0>9){g=a[f+(b&1023^1)|0]|0}else{g=gj[c[e+196608+(f<<2)>>2]&4095](d)|0}d=g&255;f=nB(c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2]|0)|0;e=c[2276085]&f;f=e&16777215;b=c[2112932]|0;h=c[b+((f>>>10|16384)<<2)>>2]|0;if(h>>>0>9){a[h+(e&1023^1)|0]=g;c[2276075]=d;c[2276076]=d;c[2276077]=0;c[2276078]=0;return}else{gg[c[b+196648+(h<<2)>>2]&4095](f,g);c[2276075]=d;c[2276076]=d;c[2276077]=0;c[2276078]=0;return}}function qT(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0);f=l&255;g=nB(c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2]|0)|0;m=c[2276085]&g;g=l&255;l=m&16777215;b=c[2112932]|0;e=c[b+((l>>>10|16384)<<2)>>2]|0;if(e>>>0>9){a[e+(m&1023^1)|0]=g;c[2276075]=f;c[2276076]=f;c[2276077]=0;c[2276078]=0;return}else{gg[c[b+196648+(e<<2)>>2]&4095](l,g);c[2276075]=f;c[2276076]=f;c[2276077]=0;c[2276078]=0;return}}function qU(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=c[9104156+((c[2276069]&7)<<2)>>2]|0;e=b&255;f=c[2276056]|0;g=f&-4;if((g|0)==(c[2276083]|0)){h=f;i=c[2276084]|0}else{c[2276083]=g;j=c[2276085]&g;g=j&16777212;k=c[2112932]|0;l=c[k+((g>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=j&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=f}else{f=gj[c[k+196768+(l<<2)>>2]&4095](g)|0;n=f;o=c[2276056]|0}c[2276084]=n;h=o;i=n}c[2276056]=h+2;n=i>>>((h<<3&16^16)>>>0)<<16>>16&c[2276085];h=b&255;b=n&16777215;i=c[2112932]|0;o=c[i+((b>>>10|16384)<<2)>>2]|0;if(o>>>0>9){a[o+(n&1023^1)|0]=h;c[2276075]=e;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}else{gg[c[i+196648+(o<<2)>>2]&4095](b,h);c[2276075]=e;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}}function qV(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=c[2276085]&c[9104156+((c[2276069]&7|8)<<2)>>2];e=b&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=a[g+(b&1023^1)|0]|0}else{h=gj[c[f+196608+(g<<2)>>2]&4095](e)|0}e=h&255;g=c[2276056]|0;f=g&-4;if((f|0)==(c[2276083]|0)){i=g;j=c[2276084]|0}else{c[2276083]=f;b=c[2276085]&f;f=b&16777212;k=c[2112932]|0;l=c[k+((f>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=b&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=g}else{g=gj[c[k+196768+(l<<2)>>2]&4095](f)|0;n=g;o=c[2276056]|0}c[2276084]=n;i=o;j=n}c[2276056]=i+2;n=j>>>((i<<3&16^16)>>>0)<<16>>16&c[2276085];i=n&16777215;j=c[2112932]|0;o=c[j+((i>>>10|16384)<<2)>>2]|0;if(o>>>0>9){a[o+(n&1023^1)|0]=h;c[2276075]=e;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}else{gg[c[j+196648+(o<<2)>>2]&4095](i,h);c[2276075]=e;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}}function qW(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=c[b>>2]|0;c[b>>2]=e+1;b=c[2276085]&e;e=b&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=a[g+(b&1023^1)|0]|0}else{h=gj[c[f+196608+(g<<2)>>2]&4095](e)|0}e=h&255;g=c[2276056]|0;f=g&-4;if((f|0)==(c[2276083]|0)){i=g;j=c[2276084]|0}else{c[2276083]=f;b=c[2276085]&f;f=b&16777212;k=c[2112932]|0;l=c[k+((f>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=b&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=g}else{g=gj[c[k+196768+(l<<2)>>2]&4095](f)|0;n=g;o=c[2276056]|0}c[2276084]=n;i=o;j=n}c[2276056]=i+2;n=j>>>((i<<3&16^16)>>>0)<<16>>16&c[2276085];i=n&16777215;j=c[2112932]|0;o=c[j+((i>>>10|16384)<<2)>>2]|0;if(o>>>0>9){a[o+(n&1023^1)|0]=h;c[2276075]=e;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}else{gg[c[j+196648+(o<<2)>>2]&4095](i,h);c[2276075]=e;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}}function qX(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=c[2276054]|0;c[2276054]=b+2;e=c[2276085]&b;b=e&16777215;f=c[2112932]|0;g=c[f+(b>>>10<<2)>>2]|0;if(g>>>0>9){h=a[g+(e&1023^1)|0]|0}else{h=gj[c[f+196608+(g<<2)>>2]&4095](b)|0}b=h&255;g=c[2276056]|0;f=g&-4;if((f|0)==(c[2276083]|0)){i=g;j=c[2276084]|0}else{c[2276083]=f;e=c[2276085]&f;f=e&16777212;k=c[2112932]|0;l=c[k+((f>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=e&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=g}else{g=gj[c[k+196768+(l<<2)>>2]&4095](f)|0;n=g;o=c[2276056]|0}c[2276084]=n;i=o;j=n}c[2276056]=i+2;n=j>>>((i<<3&16^16)>>>0)<<16>>16&c[2276085];i=n&16777215;j=c[2112932]|0;o=c[j+((i>>>10|16384)<<2)>>2]|0;if(o>>>0>9){a[o+(n&1023^1)|0]=h;c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}else{gg[c[j+196648+(o<<2)>>2]&4095](i,h);c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}}function qY(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=(c[b>>2]|0)-1|0;c[b>>2]=e;b=c[2276085]&e;e=b&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=a[g+(b&1023^1)|0]|0}else{h=gj[c[f+196608+(g<<2)>>2]&4095](e)|0}e=h&255;g=c[2276056]|0;f=g&-4;if((f|0)==(c[2276083]|0)){i=g;j=c[2276084]|0}else{c[2276083]=f;b=c[2276085]&f;f=b&16777212;k=c[2112932]|0;l=c[k+((f>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=b&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=g}else{g=gj[c[k+196768+(l<<2)>>2]&4095](f)|0;n=g;o=c[2276056]|0}c[2276084]=n;i=o;j=n}c[2276056]=i+2;n=j>>>((i<<3&16^16)>>>0)<<16>>16&c[2276085];i=n&16777215;j=c[2112932]|0;o=c[j+((i>>>10|16384)<<2)>>2]|0;if(o>>>0>9){a[o+(n&1023^1)|0]=h;c[2276075]=e;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}else{gg[c[j+196648+(o<<2)>>2]&4095](i,h);c[2276075]=e;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}}function qZ(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=(c[2276054]|0)-2|0;c[2276054]=b;e=c[2276085]&b;b=e&16777215;f=c[2112932]|0;g=c[f+(b>>>10<<2)>>2]|0;if(g>>>0>9){h=a[g+(e&1023^1)|0]|0}else{h=gj[c[f+196608+(g<<2)>>2]&4095](b)|0}b=h&255;g=c[2276056]|0;f=g&-4;if((f|0)==(c[2276083]|0)){i=g;j=c[2276084]|0}else{c[2276083]=f;e=c[2276085]&f;f=e&16777212;k=c[2112932]|0;l=c[k+((f>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=e&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=g}else{g=gj[c[k+196768+(l<<2)>>2]&4095](f)|0;n=g;o=c[2276056]|0}c[2276084]=n;i=o;j=n}c[2276056]=i+2;n=j>>>((i<<3&16^16)>>>0)<<16>>16&c[2276085];i=n&16777215;j=c[2112932]|0;o=c[j+((i>>>10|16384)<<2)>>2]|0;if(o>>>0>9){a[o+(n&1023^1)|0]=h;c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}else{gg[c[j+196648+(o<<2)>>2]&4095](i,h);c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}}function q_(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}m=g+2|0;c[2276056]=m;n=(h>>>((g<<3&16^16)>>>0)<<16>>16)+b&c[2276085];b=n&16777215;g=c[2112932]|0;h=c[g+(b>>>10<<2)>>2]|0;if(h>>>0>9){o=a[h+(n&1023^1)|0]|0;p=m}else{m=gj[c[g+196608+(h<<2)>>2]&4095](b)|0;o=m;p=c[2276056]|0}m=o&255;b=p&-4;if((b|0)==(c[2276083]|0)){q=p;r=c[2276084]|0}else{c[2276083]=b;h=c[2276085]&b;b=h&16777212;g=c[2112932]|0;n=c[g+((b>>>10|32768)<<2)>>2]|0;if(n>>>0>9){e=h&1020;s=(d[n+(e|3)|0]|0)<<8|(d[n+(e|2)|0]|0)|((d[n+(e|1)|0]|0)<<8|(d[n+e|0]|0))<<16;t=p}else{p=gj[c[g+196768+(n<<2)>>2]&4095](b)|0;s=p;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;s=r>>>((q<<3&16^16)>>>0)<<16>>16&c[2276085];q=s&16777215;r=c[2112932]|0;t=c[r+((q>>>10|16384)<<2)>>2]|0;if(t>>>0>9){a[t+(s&1023^1)|0]=o;c[2276075]=m;c[2276076]=m;c[2276077]=0;c[2276078]=0;return}else{gg[c[r+196648+(t<<2)>>2]&4095](q,o);c[2276075]=m;c[2276076]=m;c[2276077]=0;c[2276078]=0;return}}function q$(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=nB(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;e=c[2276085]&b;b=e&16777215;f=c[2112932]|0;g=c[f+(b>>>10<<2)>>2]|0;if(g>>>0>9){h=a[g+(e&1023^1)|0]|0}else{h=gj[c[f+196608+(g<<2)>>2]&4095](b)|0}b=h&255;g=c[2276056]|0;f=g&-4;if((f|0)==(c[2276083]|0)){i=g;j=c[2276084]|0}else{c[2276083]=f;e=c[2276085]&f;f=e&16777212;k=c[2112932]|0;l=c[k+((f>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=e&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=g}else{g=gj[c[k+196768+(l<<2)>>2]&4095](f)|0;n=g;o=c[2276056]|0}c[2276084]=n;i=o;j=n}c[2276056]=i+2;n=j>>>((i<<3&16^16)>>>0)<<16>>16&c[2276085];i=n&16777215;j=c[2112932]|0;o=c[j+((i>>>10|16384)<<2)>>2]|0;if(o>>>0>9){a[o+(n&1023^1)|0]=h;c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}else{gg[c[j+196648+(o<<2)>>2]&4095](i,h);c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}}function q0(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}l=f+2|0;c[2276056]=l;m=g>>>((f<<3&16^16)>>>0)<<16>>16&c[2276085];f=m&16777215;g=c[2112932]|0;b=c[g+(f>>>10<<2)>>2]|0;if(b>>>0>9){n=a[b+(m&1023^1)|0]|0;o=l}else{l=gj[c[g+196608+(b<<2)>>2]&4095](f)|0;n=l;o=c[2276056]|0}l=n&255;f=o&-4;if((f|0)==(c[2276083]|0)){p=o;q=c[2276084]|0}else{c[2276083]=f;b=c[2276085]&f;f=b&16777212;g=c[2112932]|0;m=c[g+((f>>>10|32768)<<2)>>2]|0;if(m>>>0>9){e=b&1020;r=(d[m+(e|3)|0]|0)<<8|(d[m+(e|2)|0]|0)|((d[m+(e|1)|0]|0)<<8|(d[m+e|0]|0))<<16;s=o}else{o=gj[c[g+196768+(m<<2)>>2]&4095](f)|0;r=o;s=c[2276056]|0}c[2276084]=r;p=s;q=r}c[2276056]=p+2;r=q>>>((p<<3&16^16)>>>0)<<16>>16&c[2276085];p=r&16777215;q=c[2112932]|0;s=c[q+((p>>>10|16384)<<2)>>2]|0;if(s>>>0>9){a[s+(r&1023^1)|0]=n;c[2276075]=l;c[2276076]=l;c[2276077]=0;c[2276078]=0;return}else{gg[c[q+196648+(s<<2)>>2]&4095](p,n);c[2276075]=l;c[2276076]=l;c[2276077]=0;c[2276078]=0;return}}function q1(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}t=r+2|0;c[2276056]=t;r=c[2276085]&q;q=r&16777215;h=c[2112932]|0;s=c[h+(q>>>10<<2)>>2]|0;if(s>>>0>9){u=a[s+(r&1023^1)|0]|0;v=t}else{t=gj[c[h+196608+(s<<2)>>2]&4095](q)|0;u=t;v=c[2276056]|0}t=u&255;q=v&-4;if((q|0)==(c[2276083]|0)){w=v;x=c[2276084]|0}else{c[2276083]=q;s=c[2276085]&q;q=s&16777212;h=c[2112932]|0;r=c[h+((q>>>10|32768)<<2)>>2]|0;if(r>>>0>9){n=s&1020;y=(d[r+(n|3)|0]|0)<<8|(d[r+(n|2)|0]|0)|((d[r+(n|1)|0]|0)<<8|(d[r+n|0]|0))<<16;z=v}else{v=gj[c[h+196768+(r<<2)>>2]&4095](q)|0;y=v;z=c[2276056]|0}c[2276084]=y;w=z;x=y}c[2276056]=w+2;y=x>>>((w<<3&16^16)>>>0)<<16>>16&c[2276085];w=y&16777215;x=c[2112932]|0;z=c[x+((w>>>10|16384)<<2)>>2]|0;if(z>>>0>9){a[z+(y&1023^1)|0]=u;c[2276075]=t;c[2276076]=t;c[2276077]=0;c[2276078]=0;return}else{gg[c[x+196648+(z<<2)>>2]&4095](w,u);c[2276075]=t;c[2276076]=t;c[2276077]=0;c[2276078]=0;return}}function q2(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{k=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=k;m=c[2276056]|0}c[2276084]=l;f=m;g=l}l=f+2|0;c[2276056]=l;m=(g>>>((f<<3&16^16)>>>0)<<16>>16)+b|0;b=m&16777215;f=c[2112932]|0;g=c[f+((b>>>10|32768)<<2)>>2]|0;if(g>>>0>9){n=a[g+(m&1023^1)|0]|0;o=l}else{l=gj[c[f+196608+(g<<2)>>2]&4095](b)|0;n=l;o=c[2276056]|0}l=n&255;b=o&-4;if((b|0)==(c[2276083]|0)){p=o;q=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;f=c[2112932]|0;m=c[f+((b>>>10|32768)<<2)>>2]|0;if(m>>>0>9){k=g&1020;r=(d[m+(k|3)|0]|0)<<8|(d[m+(k|2)|0]|0)|((d[m+(k|1)|0]|0)<<8|(d[m+k|0]|0))<<16;s=o}else{o=gj[c[f+196768+(m<<2)>>2]&4095](b)|0;r=o;s=c[2276056]|0}c[2276084]=r;p=s;q=r}c[2276056]=p+2;r=q>>>((p<<3&16^16)>>>0)<<16>>16&c[2276085];p=r&16777215;q=c[2112932]|0;s=c[q+((p>>>10|16384)<<2)>>2]|0;if(s>>>0>9){a[s+(r&1023^1)|0]=n;c[2276075]=l;c[2276076]=l;c[2276077]=0;c[2276078]=0;return}else{gg[c[q+196648+(s<<2)>>2]&4095](p,n);c[2276075]=l;c[2276076]=l;c[2276077]=0;c[2276078]=0;return}}function q3(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=nB(c[2276056]|0)|0;e=b&16777215;f=c[2112932]|0;g=c[f+((e>>>10|32768)<<2)>>2]|0;if(g>>>0>9){h=a[g+(b&1023^1)|0]|0}else{h=gj[c[f+196608+(g<<2)>>2]&4095](e)|0}e=h&255;g=c[2276056]|0;f=g&-4;if((f|0)==(c[2276083]|0)){i=g;j=c[2276084]|0}else{c[2276083]=f;b=c[2276085]&f;f=b&16777212;k=c[2112932]|0;l=c[k+((f>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=b&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=g}else{g=gj[c[k+196768+(l<<2)>>2]&4095](f)|0;n=g;o=c[2276056]|0}c[2276084]=n;i=o;j=n}c[2276056]=i+2;n=j>>>((i<<3&16^16)>>>0)<<16>>16&c[2276085];i=n&16777215;j=c[2112932]|0;o=c[j+((i>>>10|16384)<<2)>>2]|0;if(o>>>0>9){a[o+(n&1023^1)|0]=h;c[2276075]=e;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}else{gg[c[j+196648+(o<<2)>>2]&4095](i,h);c[2276075]=e;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}}function q4(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0);f=n&255;o=p&-4;if((o|0)==(h|0)){q=p;r=g}else{c[2276083]=o;g=c[2276085]&o;o=g&16777212;h=c[2112932]|0;e=c[h+((o>>>10|32768)<<2)>>2]|0;if(e>>>0>9){j=g&1020;s=(d[e+(j|3)|0]|0)<<8|(d[e+(j|2)|0]|0)|((d[e+(j|1)|0]|0)<<8|(d[e+j|0]|0))<<16;t=p}else{p=gj[c[h+196768+(e<<2)>>2]&4095](o)|0;s=p;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;s=r>>>((q<<3&16^16)>>>0)<<16>>16&c[2276085];q=n&255;n=s&16777215;r=c[2112932]|0;t=c[r+((n>>>10|16384)<<2)>>2]|0;if(t>>>0>9){a[t+(s&1023^1)|0]=q;c[2276075]=f;c[2276076]=f;c[2276077]=0;c[2276078]=0;return}else{gg[c[r+196648+(t<<2)>>2]&4095](n,q);c[2276075]=f;c[2276076]=f;c[2276077]=0;c[2276078]=0;return}}function q5(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;b=c[9104156+((c[2276069]&7)<<2)>>2]|0;e=b&255;f=c[2276056]|0;g=f&-4;if((g|0)==(c[2276083]|0)){h=f;i=g;j=c[2276084]|0}else{c[2276083]=g;k=c[2276085]&g;l=k&16777212;m=c[2112932]|0;n=c[m+((l>>>10|32768)<<2)>>2]|0;if(n>>>0>9){o=k&1020;p=(d[n+(o|3)|0]|0)<<8|(d[n+(o|2)|0]|0)|((d[n+(o|1)|0]|0)<<8|(d[n+o|0]|0))<<16;q=f;r=g}else{g=gj[c[m+196768+(n<<2)>>2]&4095](l)|0;p=g;q=c[2276056]|0;r=c[2276083]|0}c[2276084]=p;h=q;i=r;j=p}p=h+2|0;c[2276056]=p;h=p&-4;if((h|0)==(i|0)){s=j;t=p}else{c[2276083]=h;i=c[2276085]&h;h=i&16777212;r=c[2112932]|0;q=c[r+((h>>>10|32768)<<2)>>2]|0;if(q>>>0>9){g=i&1020;u=(d[q+(g|3)|0]|0)<<8|(d[q+(g|2)|0]|0)|((d[q+(g|1)|0]|0)<<8|(d[q+g|0]|0))<<16;v=p}else{p=gj[c[r+196768+(q<<2)>>2]&4095](h)|0;u=p;v=c[2276056]|0}c[2276084]=u;s=u>>>16|j<<16;t=v}c[2276056]=t+2;t=c[2276085]&s;s=b&255;b=t&16777215;v=c[2112932]|0;j=c[v+((b>>>10|16384)<<2)>>2]|0;if(j>>>0>9){a[j+(t&1023^1)|0]=s;c[2276075]=e;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}else{gg[c[v+196648+(j<<2)>>2]&4095](b,s);c[2276075]=e;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}}function q6(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;b=c[2276085]&c[9104156+((c[2276069]&7|8)<<2)>>2];e=b&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=a[g+(b&1023^1)|0]|0}else{h=gj[c[f+196608+(g<<2)>>2]&4095](e)|0}e=h&255;g=c[2276056]|0;f=g&-4;if((f|0)==(c[2276083]|0)){i=g;j=f;k=c[2276084]|0}else{c[2276083]=f;b=c[2276085]&f;l=b&16777212;m=c[2112932]|0;n=c[m+((l>>>10|32768)<<2)>>2]|0;if(n>>>0>9){o=b&1020;p=(d[n+(o|3)|0]|0)<<8|(d[n+(o|2)|0]|0)|((d[n+(o|1)|0]|0)<<8|(d[n+o|0]|0))<<16;q=g;r=f}else{f=gj[c[m+196768+(n<<2)>>2]&4095](l)|0;p=f;q=c[2276056]|0;r=c[2276083]|0}c[2276084]=p;i=q;j=r;k=p}p=i+2|0;c[2276056]=p;i=p&-4;if((i|0)==(j|0)){s=k;t=p}else{c[2276083]=i;j=c[2276085]&i;i=j&16777212;r=c[2112932]|0;q=c[r+((i>>>10|32768)<<2)>>2]|0;if(q>>>0>9){f=j&1020;u=(d[q+(f|3)|0]|0)<<8|(d[q+(f|2)|0]|0)|((d[q+(f|1)|0]|0)<<8|(d[q+f|0]|0))<<16;v=p}else{p=gj[c[r+196768+(q<<2)>>2]&4095](i)|0;u=p;v=c[2276056]|0}c[2276084]=u;s=u>>>16|k<<16;t=v}c[2276056]=t+2;t=c[2276085]&s;s=t&16777215;v=c[2112932]|0;k=c[v+((s>>>10|16384)<<2)>>2]|0;if(k>>>0>9){a[k+(t&1023^1)|0]=h;c[2276075]=e;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}else{gg[c[v+196648+(k<<2)>>2]&4095](s,h);c[2276075]=e;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}}function q7(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=c[b>>2]|0;c[b>>2]=e+1;b=c[2276085]&e;e=b&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=a[g+(b&1023^1)|0]|0}else{h=gj[c[f+196608+(g<<2)>>2]&4095](e)|0}e=h&255;g=c[2276056]|0;f=g&-4;if((f|0)==(c[2276083]|0)){i=g;j=f;k=c[2276084]|0}else{c[2276083]=f;b=c[2276085]&f;l=b&16777212;m=c[2112932]|0;n=c[m+((l>>>10|32768)<<2)>>2]|0;if(n>>>0>9){o=b&1020;p=(d[n+(o|3)|0]|0)<<8|(d[n+(o|2)|0]|0)|((d[n+(o|1)|0]|0)<<8|(d[n+o|0]|0))<<16;q=g;r=f}else{f=gj[c[m+196768+(n<<2)>>2]&4095](l)|0;p=f;q=c[2276056]|0;r=c[2276083]|0}c[2276084]=p;i=q;j=r;k=p}p=i+2|0;c[2276056]=p;i=p&-4;if((i|0)==(j|0)){s=k;t=p}else{c[2276083]=i;j=c[2276085]&i;i=j&16777212;r=c[2112932]|0;q=c[r+((i>>>10|32768)<<2)>>2]|0;if(q>>>0>9){f=j&1020;u=(d[q+(f|3)|0]|0)<<8|(d[q+(f|2)|0]|0)|((d[q+(f|1)|0]|0)<<8|(d[q+f|0]|0))<<16;v=p}else{p=gj[c[r+196768+(q<<2)>>2]&4095](i)|0;u=p;v=c[2276056]|0}c[2276084]=u;s=u>>>16|k<<16;t=v}c[2276056]=t+2;t=c[2276085]&s;s=t&16777215;v=c[2112932]|0;k=c[v+((s>>>10|16384)<<2)>>2]|0;if(k>>>0>9){a[k+(t&1023^1)|0]=h;c[2276075]=e;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}else{gg[c[v+196648+(k<<2)>>2]&4095](s,h);c[2276075]=e;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}}function q8(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;b=c[2276054]|0;c[2276054]=b+2;e=c[2276085]&b;b=e&16777215;f=c[2112932]|0;g=c[f+(b>>>10<<2)>>2]|0;if(g>>>0>9){h=a[g+(e&1023^1)|0]|0}else{h=gj[c[f+196608+(g<<2)>>2]&4095](b)|0}b=h&255;g=c[2276056]|0;f=g&-4;if((f|0)==(c[2276083]|0)){i=g;j=f;k=c[2276084]|0}else{c[2276083]=f;e=c[2276085]&f;l=e&16777212;m=c[2112932]|0;n=c[m+((l>>>10|32768)<<2)>>2]|0;if(n>>>0>9){o=e&1020;p=(d[n+(o|3)|0]|0)<<8|(d[n+(o|2)|0]|0)|((d[n+(o|1)|0]|0)<<8|(d[n+o|0]|0))<<16;q=g;r=f}else{f=gj[c[m+196768+(n<<2)>>2]&4095](l)|0;p=f;q=c[2276056]|0;r=c[2276083]|0}c[2276084]=p;i=q;j=r;k=p}p=i+2|0;c[2276056]=p;i=p&-4;if((i|0)==(j|0)){s=k;t=p}else{c[2276083]=i;j=c[2276085]&i;i=j&16777212;r=c[2112932]|0;q=c[r+((i>>>10|32768)<<2)>>2]|0;if(q>>>0>9){f=j&1020;u=(d[q+(f|3)|0]|0)<<8|(d[q+(f|2)|0]|0)|((d[q+(f|1)|0]|0)<<8|(d[q+f|0]|0))<<16;v=p}else{p=gj[c[r+196768+(q<<2)>>2]&4095](i)|0;u=p;v=c[2276056]|0}c[2276084]=u;s=u>>>16|k<<16;t=v}c[2276056]=t+2;t=c[2276085]&s;s=t&16777215;v=c[2112932]|0;k=c[v+((s>>>10|16384)<<2)>>2]|0;if(k>>>0>9){a[k+(t&1023^1)|0]=h;c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}else{gg[c[v+196648+(k<<2)>>2]&4095](s,h);c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}}function q9(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=(c[b>>2]|0)-1|0;c[b>>2]=e;b=c[2276085]&e;e=b&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=a[g+(b&1023^1)|0]|0}else{h=gj[c[f+196608+(g<<2)>>2]&4095](e)|0}e=h&255;g=c[2276056]|0;f=g&-4;if((f|0)==(c[2276083]|0)){i=g;j=f;k=c[2276084]|0}else{c[2276083]=f;b=c[2276085]&f;l=b&16777212;m=c[2112932]|0;n=c[m+((l>>>10|32768)<<2)>>2]|0;if(n>>>0>9){o=b&1020;p=(d[n+(o|3)|0]|0)<<8|(d[n+(o|2)|0]|0)|((d[n+(o|1)|0]|0)<<8|(d[n+o|0]|0))<<16;q=g;r=f}else{f=gj[c[m+196768+(n<<2)>>2]&4095](l)|0;p=f;q=c[2276056]|0;r=c[2276083]|0}c[2276084]=p;i=q;j=r;k=p}p=i+2|0;c[2276056]=p;i=p&-4;if((i|0)==(j|0)){s=k;t=p}else{c[2276083]=i;j=c[2276085]&i;i=j&16777212;r=c[2112932]|0;q=c[r+((i>>>10|32768)<<2)>>2]|0;if(q>>>0>9){f=j&1020;u=(d[q+(f|3)|0]|0)<<8|(d[q+(f|2)|0]|0)|((d[q+(f|1)|0]|0)<<8|(d[q+f|0]|0))<<16;v=p}else{p=gj[c[r+196768+(q<<2)>>2]&4095](i)|0;u=p;v=c[2276056]|0}c[2276084]=u;s=u>>>16|k<<16;t=v}c[2276056]=t+2;t=c[2276085]&s;s=t&16777215;v=c[2112932]|0;k=c[v+((s>>>10|16384)<<2)>>2]|0;if(k>>>0>9){a[k+(t&1023^1)|0]=h;c[2276075]=e;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}else{gg[c[v+196648+(k<<2)>>2]&4095](s,h);c[2276075]=e;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}}function ra(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;b=(c[2276054]|0)-2|0;c[2276054]=b;e=c[2276085]&b;b=e&16777215;f=c[2112932]|0;g=c[f+(b>>>10<<2)>>2]|0;if(g>>>0>9){h=a[g+(e&1023^1)|0]|0}else{h=gj[c[f+196608+(g<<2)>>2]&4095](b)|0}b=h&255;g=c[2276056]|0;f=g&-4;if((f|0)==(c[2276083]|0)){i=g;j=f;k=c[2276084]|0}else{c[2276083]=f;e=c[2276085]&f;l=e&16777212;m=c[2112932]|0;n=c[m+((l>>>10|32768)<<2)>>2]|0;if(n>>>0>9){o=e&1020;p=(d[n+(o|3)|0]|0)<<8|(d[n+(o|2)|0]|0)|((d[n+(o|1)|0]|0)<<8|(d[n+o|0]|0))<<16;q=g;r=f}else{f=gj[c[m+196768+(n<<2)>>2]&4095](l)|0;p=f;q=c[2276056]|0;r=c[2276083]|0}c[2276084]=p;i=q;j=r;k=p}p=i+2|0;c[2276056]=p;i=p&-4;if((i|0)==(j|0)){s=k;t=p}else{c[2276083]=i;j=c[2276085]&i;i=j&16777212;r=c[2112932]|0;q=c[r+((i>>>10|32768)<<2)>>2]|0;if(q>>>0>9){f=j&1020;u=(d[q+(f|3)|0]|0)<<8|(d[q+(f|2)|0]|0)|((d[q+(f|1)|0]|0)<<8|(d[q+f|0]|0))<<16;v=p}else{p=gj[c[r+196768+(q<<2)>>2]&4095](i)|0;u=p;v=c[2276056]|0}c[2276084]=u;s=u>>>16|k<<16;t=v}c[2276056]=t+2;t=c[2276085]&s;s=t&16777215;v=c[2112932]|0;k=c[v+((s>>>10|16384)<<2)>>2]|0;if(k>>>0>9){a[k+(t&1023^1)|0]=h;c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}else{gg[c[v+196648+(k<<2)>>2]&4095](s,h);c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}}function rb(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}m=g+2|0;c[2276056]=m;n=(h>>>((g<<3&16^16)>>>0)<<16>>16)+b&c[2276085];b=n&16777215;g=c[2112932]|0;h=c[g+(b>>>10<<2)>>2]|0;if(h>>>0>9){o=a[h+(n&1023^1)|0]|0;p=m}else{m=gj[c[g+196608+(h<<2)>>2]&4095](b)|0;o=m;p=c[2276056]|0}m=o&255;b=p&-4;if((b|0)==(c[2276083]|0)){q=p;r=b;s=c[2276084]|0}else{c[2276083]=b;h=c[2276085]&b;g=h&16777212;n=c[2112932]|0;e=c[n+((g>>>10|32768)<<2)>>2]|0;if(e>>>0>9){f=h&1020;t=(d[e+(f|3)|0]|0)<<8|(d[e+(f|2)|0]|0)|((d[e+(f|1)|0]|0)<<8|(d[e+f|0]|0))<<16;u=p;v=b}else{b=gj[c[n+196768+(e<<2)>>2]&4095](g)|0;t=b;u=c[2276056]|0;v=c[2276083]|0}c[2276084]=t;q=u;r=v;s=t}t=q+2|0;c[2276056]=t;q=t&-4;if((q|0)==(r|0)){w=s;x=t}else{c[2276083]=q;r=c[2276085]&q;q=r&16777212;v=c[2112932]|0;u=c[v+((q>>>10|32768)<<2)>>2]|0;if(u>>>0>9){b=r&1020;y=(d[u+(b|3)|0]|0)<<8|(d[u+(b|2)|0]|0)|((d[u+(b|1)|0]|0)<<8|(d[u+b|0]|0))<<16;z=t}else{t=gj[c[v+196768+(u<<2)>>2]&4095](q)|0;y=t;z=c[2276056]|0}c[2276084]=y;w=y>>>16|s<<16;x=z}c[2276056]=x+2;x=c[2276085]&w;w=x&16777215;z=c[2112932]|0;s=c[z+((w>>>10|16384)<<2)>>2]|0;if(s>>>0>9){a[s+(x&1023^1)|0]=o;c[2276075]=m;c[2276076]=m;c[2276077]=0;c[2276078]=0;return}else{gg[c[z+196648+(s<<2)>>2]&4095](w,o);c[2276075]=m;c[2276076]=m;c[2276077]=0;c[2276078]=0;return}}function rc(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;b=nB(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;e=c[2276085]&b;b=e&16777215;f=c[2112932]|0;g=c[f+(b>>>10<<2)>>2]|0;if(g>>>0>9){h=a[g+(e&1023^1)|0]|0}else{h=gj[c[f+196608+(g<<2)>>2]&4095](b)|0}b=h&255;g=c[2276056]|0;f=g&-4;if((f|0)==(c[2276083]|0)){i=g;j=f;k=c[2276084]|0}else{c[2276083]=f;e=c[2276085]&f;l=e&16777212;m=c[2112932]|0;n=c[m+((l>>>10|32768)<<2)>>2]|0;if(n>>>0>9){o=e&1020;p=(d[n+(o|3)|0]|0)<<8|(d[n+(o|2)|0]|0)|((d[n+(o|1)|0]|0)<<8|(d[n+o|0]|0))<<16;q=g;r=f}else{f=gj[c[m+196768+(n<<2)>>2]&4095](l)|0;p=f;q=c[2276056]|0;r=c[2276083]|0}c[2276084]=p;i=q;j=r;k=p}p=i+2|0;c[2276056]=p;i=p&-4;if((i|0)==(j|0)){s=k;t=p}else{c[2276083]=i;j=c[2276085]&i;i=j&16777212;r=c[2112932]|0;q=c[r+((i>>>10|32768)<<2)>>2]|0;if(q>>>0>9){f=j&1020;u=(d[q+(f|3)|0]|0)<<8|(d[q+(f|2)|0]|0)|((d[q+(f|1)|0]|0)<<8|(d[q+f|0]|0))<<16;v=p}else{p=gj[c[r+196768+(q<<2)>>2]&4095](i)|0;u=p;v=c[2276056]|0}c[2276084]=u;s=u>>>16|k<<16;t=v}c[2276056]=t+2;t=c[2276085]&s;s=t&16777215;v=c[2112932]|0;k=c[v+((s>>>10|16384)<<2)>>2]|0;if(k>>>0>9){a[k+(t&1023^1)|0]=h;c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}else{gg[c[v+196648+(k<<2)>>2]&4095](s,h);c[2276075]=b;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}}function rd(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}l=f+2|0;c[2276056]=l;m=g>>>((f<<3&16^16)>>>0)<<16>>16&c[2276085];f=m&16777215;g=c[2112932]|0;b=c[g+(f>>>10<<2)>>2]|0;if(b>>>0>9){n=a[b+(m&1023^1)|0]|0;o=l}else{l=gj[c[g+196608+(b<<2)>>2]&4095](f)|0;n=l;o=c[2276056]|0}l=n&255;f=o&-4;if((f|0)==(c[2276083]|0)){p=o;q=f;r=c[2276084]|0}else{c[2276083]=f;b=c[2276085]&f;g=b&16777212;m=c[2112932]|0;e=c[m+((g>>>10|32768)<<2)>>2]|0;if(e>>>0>9){j=b&1020;s=(d[e+(j|3)|0]|0)<<8|(d[e+(j|2)|0]|0)|((d[e+(j|1)|0]|0)<<8|(d[e+j|0]|0))<<16;t=o;u=f}else{f=gj[c[m+196768+(e<<2)>>2]&4095](g)|0;s=f;t=c[2276056]|0;u=c[2276083]|0}c[2276084]=s;p=t;q=u;r=s}s=p+2|0;c[2276056]=s;p=s&-4;if((p|0)==(q|0)){v=r;w=s}else{c[2276083]=p;q=c[2276085]&p;p=q&16777212;u=c[2112932]|0;t=c[u+((p>>>10|32768)<<2)>>2]|0;if(t>>>0>9){f=q&1020;x=(d[t+(f|3)|0]|0)<<8|(d[t+(f|2)|0]|0)|((d[t+(f|1)|0]|0)<<8|(d[t+f|0]|0))<<16;y=s}else{s=gj[c[u+196768+(t<<2)>>2]&4095](p)|0;x=s;y=c[2276056]|0}c[2276084]=x;v=x>>>16|r<<16;w=y}c[2276056]=w+2;w=c[2276085]&v;v=w&16777215;y=c[2112932]|0;r=c[y+((v>>>10|16384)<<2)>>2]|0;if(r>>>0>9){a[r+(w&1023^1)|0]=n;c[2276075]=l;c[2276076]=l;c[2276077]=0;c[2276078]=0;return}else{gg[c[y+196648+(r<<2)>>2]&4095](v,n);c[2276075]=l;c[2276076]=l;c[2276077]=0;c[2276078]=0;return}}function re(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}t=r+2|0;c[2276056]=t;r=c[2276085]&q;q=r&16777215;h=c[2112932]|0;s=c[h+(q>>>10<<2)>>2]|0;if(s>>>0>9){u=a[s+(r&1023^1)|0]|0;v=t}else{t=gj[c[h+196608+(s<<2)>>2]&4095](q)|0;u=t;v=c[2276056]|0}t=u&255;q=v&-4;if((q|0)==(c[2276083]|0)){w=v;x=q;y=c[2276084]|0}else{c[2276083]=q;s=c[2276085]&q;h=s&16777212;r=c[2112932]|0;n=c[r+((h>>>10|32768)<<2)>>2]|0;if(n>>>0>9){f=s&1020;z=(d[n+(f|3)|0]|0)<<8|(d[n+(f|2)|0]|0)|((d[n+(f|1)|0]|0)<<8|(d[n+f|0]|0))<<16;A=v;B=q}else{q=gj[c[r+196768+(n<<2)>>2]&4095](h)|0;z=q;A=c[2276056]|0;B=c[2276083]|0}c[2276084]=z;w=A;x=B;y=z}z=w+2|0;c[2276056]=z;w=z&-4;if((w|0)==(x|0)){C=y;D=z}else{c[2276083]=w;x=c[2276085]&w;w=x&16777212;B=c[2112932]|0;A=c[B+((w>>>10|32768)<<2)>>2]|0;if(A>>>0>9){q=x&1020;E=(d[A+(q|3)|0]|0)<<8|(d[A+(q|2)|0]|0)|((d[A+(q|1)|0]|0)<<8|(d[A+q|0]|0))<<16;F=z}else{z=gj[c[B+196768+(A<<2)>>2]&4095](w)|0;E=z;F=c[2276056]|0}c[2276084]=E;C=E>>>16|y<<16;D=F}c[2276056]=D+2;D=c[2276085]&C;C=D&16777215;F=c[2112932]|0;y=c[F+((C>>>10|16384)<<2)>>2]|0;if(y>>>0>9){a[y+(D&1023^1)|0]=u;c[2276075]=t;c[2276076]=t;c[2276077]=0;c[2276078]=0;return}else{gg[c[F+196648+(y<<2)>>2]&4095](C,u);c[2276075]=t;c[2276076]=t;c[2276077]=0;c[2276078]=0;return}}function rf(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{k=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=k;m=c[2276056]|0}c[2276084]=l;f=m;g=l}l=f+2|0;c[2276056]=l;m=(g>>>((f<<3&16^16)>>>0)<<16>>16)+b|0;b=m&16777215;f=c[2112932]|0;g=c[f+((b>>>10|32768)<<2)>>2]|0;if(g>>>0>9){n=a[g+(m&1023^1)|0]|0;o=l}else{l=gj[c[f+196608+(g<<2)>>2]&4095](b)|0;n=l;o=c[2276056]|0}l=n&255;b=o&-4;if((b|0)==(c[2276083]|0)){p=o;q=b;r=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;f=g&16777212;m=c[2112932]|0;k=c[m+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){e=g&1020;s=(d[k+(e|3)|0]|0)<<8|(d[k+(e|2)|0]|0)|((d[k+(e|1)|0]|0)<<8|(d[k+e|0]|0))<<16;t=o;u=b}else{b=gj[c[m+196768+(k<<2)>>2]&4095](f)|0;s=b;t=c[2276056]|0;u=c[2276083]|0}c[2276084]=s;p=t;q=u;r=s}s=p+2|0;c[2276056]=s;p=s&-4;if((p|0)==(q|0)){v=r;w=s}else{c[2276083]=p;q=c[2276085]&p;p=q&16777212;u=c[2112932]|0;t=c[u+((p>>>10|32768)<<2)>>2]|0;if(t>>>0>9){b=q&1020;x=(d[t+(b|3)|0]|0)<<8|(d[t+(b|2)|0]|0)|((d[t+(b|1)|0]|0)<<8|(d[t+b|0]|0))<<16;y=s}else{s=gj[c[u+196768+(t<<2)>>2]&4095](p)|0;x=s;y=c[2276056]|0}c[2276084]=x;v=x>>>16|r<<16;w=y}c[2276056]=w+2;w=c[2276085]&v;v=w&16777215;y=c[2112932]|0;r=c[y+((v>>>10|16384)<<2)>>2]|0;if(r>>>0>9){a[r+(w&1023^1)|0]=n;c[2276075]=l;c[2276076]=l;c[2276077]=0;c[2276078]=0;return}else{gg[c[y+196648+(r<<2)>>2]&4095](v,n);c[2276075]=l;c[2276076]=l;c[2276077]=0;c[2276078]=0;return}}function rg(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;b=nB(c[2276056]|0)|0;e=b&16777215;f=c[2112932]|0;g=c[f+((e>>>10|32768)<<2)>>2]|0;if(g>>>0>9){h=a[g+(b&1023^1)|0]|0}else{h=gj[c[f+196608+(g<<2)>>2]&4095](e)|0}e=h&255;g=c[2276056]|0;f=g&-4;if((f|0)==(c[2276083]|0)){i=g;j=f;k=c[2276084]|0}else{c[2276083]=f;b=c[2276085]&f;l=b&16777212;m=c[2112932]|0;n=c[m+((l>>>10|32768)<<2)>>2]|0;if(n>>>0>9){o=b&1020;p=(d[n+(o|3)|0]|0)<<8|(d[n+(o|2)|0]|0)|((d[n+(o|1)|0]|0)<<8|(d[n+o|0]|0))<<16;q=g;r=f}else{f=gj[c[m+196768+(n<<2)>>2]&4095](l)|0;p=f;q=c[2276056]|0;r=c[2276083]|0}c[2276084]=p;i=q;j=r;k=p}p=i+2|0;c[2276056]=p;i=p&-4;if((i|0)==(j|0)){s=k;t=p}else{c[2276083]=i;j=c[2276085]&i;i=j&16777212;r=c[2112932]|0;q=c[r+((i>>>10|32768)<<2)>>2]|0;if(q>>>0>9){f=j&1020;u=(d[q+(f|3)|0]|0)<<8|(d[q+(f|2)|0]|0)|((d[q+(f|1)|0]|0)<<8|(d[q+f|0]|0))<<16;v=p}else{p=gj[c[r+196768+(q<<2)>>2]&4095](i)|0;u=p;v=c[2276056]|0}c[2276084]=u;s=u>>>16|k<<16;t=v}c[2276056]=t+2;t=c[2276085]&s;s=t&16777215;v=c[2112932]|0;k=c[v+((s>>>10|16384)<<2)>>2]|0;if(k>>>0>9){a[k+(t&1023^1)|0]=h;c[2276075]=e;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}else{gg[c[v+196648+(k<<2)>>2]&4095](s,h);c[2276075]=e;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}}function rh(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0);f=n&255;o=p&-4;if((o|0)==(h|0)){q=p;r=h;s=g}else{c[2276083]=o;g=c[2276085]&o;h=g&16777212;e=c[2112932]|0;j=c[e+((h>>>10|32768)<<2)>>2]|0;if(j>>>0>9){l=g&1020;t=(d[j+(l|3)|0]|0)<<8|(d[j+(l|2)|0]|0)|((d[j+(l|1)|0]|0)<<8|(d[j+l|0]|0))<<16;u=p;v=o}else{o=gj[c[e+196768+(j<<2)>>2]&4095](h)|0;t=o;u=c[2276056]|0;v=c[2276083]|0}c[2276084]=t;q=u;r=v;s=t}t=q+2|0;c[2276056]=t;q=t&-4;if((q|0)==(r|0)){w=s;x=t}else{c[2276083]=q;r=c[2276085]&q;q=r&16777212;v=c[2112932]|0;u=c[v+((q>>>10|32768)<<2)>>2]|0;if(u>>>0>9){o=r&1020;y=(d[u+(o|3)|0]|0)<<8|(d[u+(o|2)|0]|0)|((d[u+(o|1)|0]|0)<<8|(d[u+o|0]|0))<<16;z=t}else{t=gj[c[v+196768+(u<<2)>>2]&4095](q)|0;y=t;z=c[2276056]|0}c[2276084]=y;w=y>>>16|s<<16;x=z}c[2276056]=x+2;x=c[2276085]&w;w=n&255;n=x&16777215;z=c[2112932]|0;s=c[z+((n>>>10|16384)<<2)>>2]|0;if(s>>>0>9){a[s+(x&1023^1)|0]=w;c[2276075]=f;c[2276076]=f;c[2276077]=0;c[2276078]=0;return}else{gg[c[z+196648+(s<<2)>>2]&4095](n,w);c[2276075]=f;c[2276076]=f;c[2276077]=0;c[2276078]=0;return}}function ri(){var a=0,b=0,d=0;a=c[2276069]|0;b=c[9104156+((a&7)<<2)>>2]&65535;d=9104156+((a>>>9&7)<<2)|0;c[d>>2]=c[d>>2]&-65536|b;c[2276075]=b>>>8;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}function rj(){var a=0,b=0,d=0;a=c[2276069]|0;b=c[9104156+((a&7|8)<<2)>>2]&65535;d=9104156+((a>>>9&7)<<2)|0;c[d>>2]=c[d>>2]&-65536|b;c[2276075]=b>>>8;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}function rk(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0;a=c[2276069]|0;b=c[2276085]&c[9104156+((a&7|8)<<2)>>2];e=b&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=b&1023;i=(d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0);j=a}else{a=gj[c[f+196688+(g<<2)>>2]&4095](e)|0;i=a;j=c[2276069]|0}a=i&65535;i=9104156+((j>>>9&7)<<2)|0;c[i>>2]=c[i>>2]&-65536|a;c[2276075]=a>>>8;c[2276076]=a;c[2276077]=0;c[2276078]=0;return}function rl(){var a=0,b=0,e=0,f=0,g=0,h=0;a=9104156+((c[2276069]&7|8)<<2)|0;b=c[a>>2]|0;c[a>>2]=b+2;a=c[2276085]&b;b=a&16777215;e=c[2112932]|0;f=c[e+(b>>>10<<2)>>2]|0;if(f>>>0>9){g=a&1023;h=(d[f+(g+1)|0]|0)<<8|(d[f+g|0]|0)}else{h=gj[c[e+196688+(f<<2)>>2]&4095](b)|0}b=h&65535;h=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;c[h>>2]=c[h>>2]&-65536|b;c[2276075]=b>>>8;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}function rm(){var a=0,b=0,e=0,f=0,g=0,h=0;a=9104156+((c[2276069]&7|8)<<2)|0;b=(c[a>>2]|0)-2|0;c[a>>2]=b;a=c[2276085]&b;b=a&16777215;e=c[2112932]|0;f=c[e+(b>>>10<<2)>>2]|0;if(f>>>0>9){g=a&1023;h=(d[f+(g+1)|0]|0)<<8|(d[f+g|0]|0)}else{h=gj[c[e+196688+(f<<2)>>2]&4095](b)|0}b=h&65535;h=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;c[h>>2]=c[h>>2]&-65536|b;c[2276075]=b>>>8;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}function rn(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;a=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=(g>>>((f<<3&16^16)>>>0)<<16>>16)+a&c[2276085];a=l&16777215;f=c[2112932]|0;g=c[f+(a>>>10<<2)>>2]|0;if(g>>>0>9){m=l&1023;n=(d[g+(m+1)|0]|0)<<8|(d[g+m|0]|0);o=n&65535;p=c[2276069]|0;q=p>>>9;r=q&7;s=9104156+(r<<2)|0;t=c[s>>2]|0;u=t&-65536;v=u|o;c[s>>2]=v;w=o>>>8;c[2276075]=w;c[2276076]=o;c[2276077]=0;c[2276078]=0;return}else{n=gj[c[f+196688+(g<<2)>>2]&4095](a)|0;o=n&65535;p=c[2276069]|0;q=p>>>9;r=q&7;s=9104156+(r<<2)|0;t=c[s>>2]|0;u=t&-65536;v=u|o;c[s>>2]=v;w=o>>>8;c[2276075]=w;c[2276076]=o;c[2276077]=0;c[2276078]=0;return}}function ro(){var a=0,b=0,e=0,f=0,g=0,h=0;a=nB(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;b=c[2276085]&a;a=b&16777215;e=c[2112932]|0;f=c[e+(a>>>10<<2)>>2]|0;if(f>>>0>9){g=b&1023;h=(d[f+(g+1)|0]|0)<<8|(d[f+g|0]|0)}else{h=gj[c[e+196688+(f<<2)>>2]&4095](a)|0}a=h&65535;h=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;c[h>>2]=c[h>>2]&-65536|a;c[2276075]=a>>>8;c[2276076]=a;c[2276077]=0;c[2276078]=0;return}function rp(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=f>>>((e<<3&16^16)>>>0)<<16>>16&c[2276085];e=k&16777215;f=c[2112932]|0;l=c[f+(e>>>10<<2)>>2]|0;if(l>>>0>9){a=k&1023;m=(d[l+(a+1)|0]|0)<<8|(d[l+a|0]|0);n=m&65535;o=c[2276069]|0;p=o>>>9;q=p&7;r=9104156+(q<<2)|0;s=c[r>>2]|0;t=s&-65536;u=t|n;c[r>>2]=u;v=n>>>8;c[2276075]=v;c[2276076]=n;c[2276077]=0;c[2276078]=0;return}else{m=gj[c[f+196688+(l<<2)>>2]&4095](e)|0;n=m&65535;o=c[2276069]|0;p=o>>>9;q=p&7;r=9104156+(q<<2)|0;s=c[r>>2]|0;t=s&-65536;u=t|n;c[r>>2]=u;v=n>>>8;c[2276075]=v;c[2276076]=n;c[2276077]=0;c[2276078]=0;return}}function rq(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=b;g=c[2276084]|0}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=o;g=m}m=e+2|0;c[2276056]=m;e=m&-4;if((e|0)==(f|0)){p=g;q=m}else{c[2276083]=e;f=c[2276085]&e;e=f&16777212;o=c[2112932]|0;n=c[o+((e>>>10|32768)<<2)>>2]|0;if(n>>>0>9){b=f&1020;r=(d[n+(b|3)|0]|0)<<8|(d[n+(b|2)|0]|0)|((d[n+(b|1)|0]|0)<<8|(d[n+b|0]|0))<<16;s=m}else{m=gj[c[o+196768+(n<<2)>>2]&4095](e)|0;r=m;s=c[2276056]|0}c[2276084]=r;p=r>>>16|g<<16;q=s}c[2276056]=q+2;q=c[2276085]&p;p=q&16777215;s=c[2112932]|0;g=c[s+(p>>>10<<2)>>2]|0;if(g>>>0>9){r=q&1023;t=(d[g+(r+1)|0]|0)<<8|(d[g+r|0]|0);u=t&65535;v=c[2276069]|0;w=v>>>9;x=w&7;y=9104156+(x<<2)|0;z=c[y>>2]|0;A=z&-65536;B=A|u;c[y>>2]=B;C=u>>>8;c[2276075]=C;c[2276076]=u;c[2276077]=0;c[2276078]=0;return}else{t=gj[c[s+196688+(g<<2)>>2]&4095](p)|0;u=t&65535;v=c[2276069]|0;w=v>>>9;x=w&7;y=9104156+(x<<2)|0;z=c[y>>2]|0;A=z&-65536;B=A|u;c[y>>2]=B;C=u>>>8;c[2276075]=C;c[2276076]=u;c[2276077]=0;c[2276078]=0;return}}function rr(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{j=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=j;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=(f>>>((e<<3&16^16)>>>0)<<16>>16)+a|0;a=k&16777215;e=c[2112932]|0;f=c[e+((a>>>10|32768)<<2)>>2]|0;if(f>>>0>9){l=k&1023;m=(d[f+(l+1)|0]|0)<<8|(d[f+l|0]|0);n=m&65535;o=c[2276069]|0;p=o>>>9;q=p&7;r=9104156+(q<<2)|0;s=c[r>>2]|0;t=s&-65536;u=t|n;c[r>>2]=u;v=n>>>8;c[2276075]=v;c[2276076]=n;c[2276077]=0;c[2276078]=0;return}else{m=gj[c[e+196688+(f<<2)>>2]&4095](a)|0;n=m&65535;o=c[2276069]|0;p=o>>>9;q=p&7;r=9104156+(q<<2)|0;s=c[r>>2]|0;t=s&-65536;u=t|n;c[r>>2]=u;v=n>>>8;c[2276075]=v;c[2276076]=n;c[2276077]=0;c[2276078]=0;return}}function rs(){var a=0,b=0,e=0,f=0,g=0,h=0;a=nB(c[2276056]|0)|0;b=a&16777215;e=c[2112932]|0;f=c[e+((b>>>10|32768)<<2)>>2]|0;if(f>>>0>9){g=a&1023;h=(d[f+(g+1)|0]|0)<<8|(d[f+g|0]|0)}else{h=gj[c[e+196688+(f<<2)>>2]&4095](b)|0}b=h&65535;h=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;c[h>>2]=c[h>>2]&-65536|b;c[2276075]=b>>>8;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}function rt(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=f>>>((e<<3&16^16)>>>0)&65535;e=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;c[e>>2]=k|c[e>>2]&-65536;c[2276075]=k>>>8;c[2276076]=k;c[2276077]=0;c[2276078]=0;return}function ru(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[2276069]|0;d=c[9104156+((b&7)<<2)>>2]|0;e=d&65535;f=c[2276085]&c[9104156+((b>>>9&7|8)<<2)>>2];b=d&65535;g=f&16777215;h=c[2112932]|0;i=c[h+((g>>>10|16384)<<2)>>2]|0;if(i>>>0>9){j=f&1023;a[i+j|0]=d&255;a[i+(j+1)|0]=(b&65535)>>>8&255;k=e>>>8;c[2276075]=k;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}else{gg[c[h+196728+(i<<2)>>2]&4095](g,b);k=e>>>8;c[2276075]=k;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}}function rv(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[2276069]|0;d=c[9104156+((b&7|8)<<2)>>2]|0;e=d&65535;f=c[2276085]&c[9104156+((b>>>9&7|8)<<2)>>2];b=d&65535;g=f&16777215;h=c[2112932]|0;i=c[h+((g>>>10|16384)<<2)>>2]|0;if(i>>>0>9){j=f&1023;a[i+j|0]=d&255;a[i+(j+1)|0]=(b&65535)>>>8&255;k=e>>>8;c[2276075]=k;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}else{gg[c[h+196728+(i<<2)>>2]&4095](g,b);k=e>>>8;c[2276075]=k;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}}function rw(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=c[2276069]|0;e=c[2276085]|0;f=e&c[9104156+((b&7|8)<<2)>>2];g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=f&1023;k=(d[i+(j+1)|0]|0)<<8|(d[i+j|0]|0);l=b;m=e;n=h}else{e=gj[c[h+196688+(i<<2)>>2]&4095](g)|0;k=e;l=c[2276069]|0;m=c[2276085]|0;n=c[2112932]|0}e=k&65535;g=m&c[9104156+((l>>>9&7|8)<<2)>>2];l=g&16777215;m=c[n+((l>>>10|16384)<<2)>>2]|0;if(m>>>0>9){i=g&1023;a[m+i|0]=k&255;a[m+(i+1)|0]=(k&65535)>>>8&255;o=e>>>8;c[2276075]=o;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}else{gg[c[n+196728+(m<<2)>>2]&4095](l,k);o=e>>>8;c[2276075]=o;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}}function rx(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=c[b>>2]|0;c[b>>2]=e+2;b=c[2276085]|0;f=b&e;e=f&16777215;g=c[2112932]|0;h=c[g+(e>>>10<<2)>>2]|0;if(h>>>0>9){i=f&1023;j=(d[h+(i+1)|0]|0)<<8|(d[h+i|0]|0);k=b;l=g}else{b=gj[c[g+196688+(h<<2)>>2]&4095](e)|0;j=b;k=c[2276085]|0;l=c[2112932]|0}b=j&65535;e=k&c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2];k=e&16777215;h=c[l+((k>>>10|16384)<<2)>>2]|0;if(h>>>0>9){g=e&1023;a[h+g|0]=j&255;a[h+(g+1)|0]=(j&65535)>>>8&255;m=b>>>8;c[2276075]=m;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}else{gg[c[l+196728+(h<<2)>>2]&4095](k,j);m=b>>>8;c[2276075]=m;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}}function ry(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=(c[b>>2]|0)-2|0;c[b>>2]=e;b=c[2276085]|0;f=b&e;e=f&16777215;g=c[2112932]|0;h=c[g+(e>>>10<<2)>>2]|0;if(h>>>0>9){i=f&1023;j=(d[h+(i+1)|0]|0)<<8|(d[h+i|0]|0);k=b;l=g}else{b=gj[c[g+196688+(h<<2)>>2]&4095](e)|0;j=b;k=c[2276085]|0;l=c[2112932]|0}b=j&65535;e=k&c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2];k=e&16777215;h=c[l+((k>>>10|16384)<<2)>>2]|0;if(h>>>0>9){g=e&1023;a[h+g|0]=j&255;a[h+(g+1)|0]=(j&65535)>>>8&255;m=b>>>8;c[2276075]=m;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}else{gg[c[l+196728+(h<<2)>>2]&4095](k,j);m=b>>>8;c[2276075]=m;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}}function rz(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=c[2276085]|0;n=(h>>>((g<<3&16^16)>>>0)<<16>>16)+b&m;b=n&16777215;g=c[2112932]|0;h=c[g+(b>>>10<<2)>>2]|0;if(h>>>0>9){e=n&1023;o=(d[h+(e+1)|0]|0)<<8|(d[h+e|0]|0);p=m;q=g}else{m=gj[c[g+196688+(h<<2)>>2]&4095](b)|0;o=m;p=c[2276085]|0;q=c[2112932]|0}m=o&65535;b=p&c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2];p=b&16777215;h=c[q+((p>>>10|16384)<<2)>>2]|0;if(h>>>0>9){g=b&1023;a[h+g|0]=o&255;a[h+(g+1)|0]=(o&65535)>>>8&255;r=m>>>8;c[2276075]=r;c[2276076]=m;c[2276077]=0;c[2276078]=0;return}else{gg[c[q+196728+(h<<2)>>2]&4095](p,o);r=m>>>8;c[2276075]=r;c[2276076]=m;c[2276077]=0;c[2276078]=0;return}}function rA(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=nB(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;e=c[2276085]|0;f=e&b;b=f&16777215;g=c[2112932]|0;h=c[g+(b>>>10<<2)>>2]|0;if(h>>>0>9){i=f&1023;j=(d[h+(i+1)|0]|0)<<8|(d[h+i|0]|0);k=e;l=g}else{e=gj[c[g+196688+(h<<2)>>2]&4095](b)|0;j=e;k=c[2276085]|0;l=c[2112932]|0}e=j&65535;b=k&c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2];k=b&16777215;h=c[l+((k>>>10|16384)<<2)>>2]|0;if(h>>>0>9){g=b&1023;a[h+g|0]=j&255;a[h+(g+1)|0]=(j&65535)>>>8&255;m=e>>>8;c[2276075]=m;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}else{gg[c[l+196728+(h<<2)>>2]&4095](k,j);m=e>>>8;c[2276075]=m;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}}function rB(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=c[2276085]|0;m=g>>>((f<<3&16^16)>>>0)<<16>>16&l;f=m&16777215;g=c[2112932]|0;b=c[g+(f>>>10<<2)>>2]|0;if(b>>>0>9){e=m&1023;n=(d[b+(e+1)|0]|0)<<8|(d[b+e|0]|0);o=l;p=g}else{l=gj[c[g+196688+(b<<2)>>2]&4095](f)|0;n=l;o=c[2276085]|0;p=c[2112932]|0}l=n&65535;f=o&c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2];o=f&16777215;b=c[p+((o>>>10|16384)<<2)>>2]|0;if(b>>>0>9){g=f&1023;a[b+g|0]=n&255;a[b+(g+1)|0]=(n&65535)>>>8&255;q=l>>>8;c[2276075]=q;c[2276076]=l;c[2276077]=0;c[2276078]=0;return}else{gg[c[p+196728+(b<<2)>>2]&4095](o,n);q=l>>>8;c[2276075]=q;c[2276076]=l;c[2276077]=0;c[2276078]=0;return}}function rC(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[2276085]|0;t=r&q;q=t&16777215;h=c[2112932]|0;s=c[h+(q>>>10<<2)>>2]|0;if(s>>>0>9){n=t&1023;u=(d[s+(n+1)|0]|0)<<8|(d[s+n|0]|0);v=r;w=h}else{r=gj[c[h+196688+(s<<2)>>2]&4095](q)|0;u=r;v=c[2276085]|0;w=c[2112932]|0}r=u&65535;q=v&c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2];v=q&16777215;s=c[w+((v>>>10|16384)<<2)>>2]|0;if(s>>>0>9){h=q&1023;a[s+h|0]=u&255;a[s+(h+1)|0]=(u&65535)>>>8&255;x=r>>>8;c[2276075]=x;c[2276076]=r;c[2276077]=0;c[2276078]=0;return}else{gg[c[w+196728+(s<<2)>>2]&4095](v,u);x=r>>>8;c[2276075]=x;c[2276076]=r;c[2276077]=0;c[2276078]=0;return}}function rD(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{k=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=k;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=(g>>>((f<<3&16^16)>>>0)<<16>>16)+b|0;b=l&16777215;f=c[2112932]|0;g=c[f+((b>>>10|32768)<<2)>>2]|0;if(g>>>0>9){m=l&1023;n=(d[g+(m+1)|0]|0)<<8|(d[g+m|0]|0);o=f}else{m=gj[c[f+196688+(g<<2)>>2]&4095](b)|0;n=m;o=c[2112932]|0}m=n&65535;b=c[2276085]&c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2];g=b&16777215;f=c[o+((g>>>10|16384)<<2)>>2]|0;if(f>>>0>9){l=b&1023;a[f+l|0]=n&255;a[f+(l+1)|0]=(n&65535)>>>8&255;p=m>>>8;c[2276075]=p;c[2276076]=m;c[2276077]=0;c[2276078]=0;return}else{gg[c[o+196728+(f<<2)>>2]&4095](g,n);p=m>>>8;c[2276075]=p;c[2276076]=m;c[2276077]=0;c[2276078]=0;return}}function rE(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=nB(c[2276056]|0)|0;e=b&16777215;f=c[2112932]|0;g=c[f+((e>>>10|32768)<<2)>>2]|0;if(g>>>0>9){h=b&1023;i=(d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0);j=f}else{h=gj[c[f+196688+(g<<2)>>2]&4095](e)|0;i=h;j=c[2112932]|0}h=i&65535;e=c[2276085]&c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2];g=e&16777215;f=c[j+((g>>>10|16384)<<2)>>2]|0;if(f>>>0>9){b=e&1023;a[f+b|0]=i&255;a[f+(b+1)|0]=(i&65535)>>>8&255;k=h>>>8;c[2276075]=k;c[2276076]=h;c[2276077]=0;c[2276078]=0;return}else{gg[c[j+196728+(f<<2)>>2]&4095](g,i);k=h>>>8;c[2276075]=k;c[2276076]=h;c[2276077]=0;c[2276078]=0;return}}function rF(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0);f=l&65535;g=c[2276085]&c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2];m=l&65535;b=g&16777215;e=c[2112932]|0;j=c[e+((b>>>10|16384)<<2)>>2]|0;if(j>>>0>9){i=g&1023;a[j+i|0]=l&255;a[j+(i+1)|0]=(m&65535)>>>8&255;n=f>>>8;c[2276075]=n;c[2276076]=f;c[2276077]=0;c[2276078]=0;return}else{gg[c[e+196728+(j<<2)>>2]&4095](b,m);n=f>>>8;c[2276075]=n;c[2276076]=f;c[2276077]=0;c[2276078]=0;return}}function rG(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[2276069]|0;d=c[9104156+((b&7)<<2)>>2]|0;e=d&65535;f=9104156+((b>>>9&7|8)<<2)|0;b=c[f>>2]|0;c[f>>2]=b+2;f=c[2276085]&b;b=d&65535;g=f&16777215;h=c[2112932]|0;i=c[h+((g>>>10|16384)<<2)>>2]|0;if(i>>>0>9){j=f&1023;a[i+j|0]=d&255;a[i+(j+1)|0]=(b&65535)>>>8&255;k=e>>>8;c[2276075]=k;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}else{gg[c[h+196728+(i<<2)>>2]&4095](g,b);k=e>>>8;c[2276075]=k;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}}function rH(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[2276069]|0;d=c[9104156+((b&7|8)<<2)>>2]|0;e=d&65535;f=9104156+((b>>>9&7|8)<<2)|0;b=c[f>>2]|0;c[f>>2]=b+2;f=c[2276085]&b;b=d&65535;g=f&16777215;h=c[2112932]|0;i=c[h+((g>>>10|16384)<<2)>>2]|0;if(i>>>0>9){j=f&1023;a[i+j|0]=d&255;a[i+(j+1)|0]=(b&65535)>>>8&255;k=e>>>8;c[2276075]=k;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}else{gg[c[h+196728+(i<<2)>>2]&4095](g,b);k=e>>>8;c[2276075]=k;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}}function rI(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=c[2276069]|0;e=c[2276085]&c[9104156+((b&7|8)<<2)>>2];f=e&16777215;g=c[2112932]|0;h=c[g+(f>>>10<<2)>>2]|0;if(h>>>0>9){i=e&1023;j=(d[h+(i+1)|0]|0)<<8|(d[h+i|0]|0);k=b;l=g}else{b=gj[c[g+196688+(h<<2)>>2]&4095](f)|0;j=b;k=c[2276069]|0;l=c[2112932]|0}b=j&65535;f=9104156+((k>>>9&7|8)<<2)|0;k=c[f>>2]|0;c[f>>2]=k+2;f=c[2276085]&k;k=f&16777215;h=c[l+((k>>>10|16384)<<2)>>2]|0;if(h>>>0>9){g=f&1023;a[h+g|0]=j&255;a[h+(g+1)|0]=(j&65535)>>>8&255;m=b>>>8;c[2276075]=m;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}else{gg[c[l+196728+(h<<2)>>2]&4095](k,j);m=b>>>8;c[2276075]=m;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}}function rJ(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=c[b>>2]|0;c[b>>2]=e+2;b=c[2276085]&e;e=b&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=b&1023;i=(d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0);j=f}else{h=gj[c[f+196688+(g<<2)>>2]&4095](e)|0;i=h;j=c[2112932]|0}h=i&65535;e=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;g=c[e>>2]|0;c[e>>2]=g+2;e=c[2276085]&g;g=e&16777215;f=c[j+((g>>>10|16384)<<2)>>2]|0;if(f>>>0>9){b=e&1023;a[f+b|0]=i&255;a[f+(b+1)|0]=(i&65535)>>>8&255;k=h>>>8;c[2276075]=k;c[2276076]=h;c[2276077]=0;c[2276078]=0;return}else{gg[c[j+196728+(f<<2)>>2]&4095](g,i);k=h>>>8;c[2276075]=k;c[2276076]=h;c[2276077]=0;c[2276078]=0;return}}function rK(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=(c[b>>2]|0)-2|0;c[b>>2]=e;b=c[2276085]&e;e=b&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=b&1023;i=(d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0);j=f}else{h=gj[c[f+196688+(g<<2)>>2]&4095](e)|0;i=h;j=c[2112932]|0}h=i&65535;e=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;g=c[e>>2]|0;c[e>>2]=g+2;e=c[2276085]&g;g=e&16777215;f=c[j+((g>>>10|16384)<<2)>>2]|0;if(f>>>0>9){b=e&1023;a[f+b|0]=i&255;a[f+(b+1)|0]=(i&65535)>>>8&255;k=h>>>8;c[2276075]=k;c[2276076]=h;c[2276077]=0;c[2276078]=0;return}else{gg[c[j+196728+(f<<2)>>2]&4095](g,i);k=h>>>8;c[2276075]=k;c[2276076]=h;c[2276077]=0;c[2276078]=0;return}}function rL(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=(h>>>((g<<3&16^16)>>>0)<<16>>16)+b&c[2276085];b=m&16777215;g=c[2112932]|0;h=c[g+(b>>>10<<2)>>2]|0;if(h>>>0>9){n=m&1023;o=(d[h+(n+1)|0]|0)<<8|(d[h+n|0]|0);p=g}else{n=gj[c[g+196688+(h<<2)>>2]&4095](b)|0;o=n;p=c[2112932]|0}n=o&65535;b=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;h=c[b>>2]|0;c[b>>2]=h+2;b=c[2276085]&h;h=b&16777215;g=c[p+((h>>>10|16384)<<2)>>2]|0;if(g>>>0>9){m=b&1023;a[g+m|0]=o&255;a[g+(m+1)|0]=(o&65535)>>>8&255;q=n>>>8;c[2276075]=q;c[2276076]=n;c[2276077]=0;c[2276078]=0;return}else{gg[c[p+196728+(g<<2)>>2]&4095](h,o);q=n>>>8;c[2276075]=q;c[2276076]=n;c[2276077]=0;c[2276078]=0;return}}function rM(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=nB(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;e=c[2276085]&b;b=e&16777215;f=c[2112932]|0;g=c[f+(b>>>10<<2)>>2]|0;if(g>>>0>9){h=e&1023;i=(d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0);j=f}else{h=gj[c[f+196688+(g<<2)>>2]&4095](b)|0;i=h;j=c[2112932]|0}h=i&65535;b=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;g=c[b>>2]|0;c[b>>2]=g+2;b=c[2276085]&g;g=b&16777215;f=c[j+((g>>>10|16384)<<2)>>2]|0;if(f>>>0>9){e=b&1023;a[f+e|0]=i&255;a[f+(e+1)|0]=(i&65535)>>>8&255;k=h>>>8;c[2276075]=k;c[2276076]=h;c[2276077]=0;c[2276078]=0;return}else{gg[c[j+196728+(f<<2)>>2]&4095](g,i);k=h>>>8;c[2276075]=k;c[2276076]=h;c[2276077]=0;c[2276078]=0;return}}function rN(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)<<16>>16&c[2276085];f=l&16777215;g=c[2112932]|0;m=c[g+(f>>>10<<2)>>2]|0;if(m>>>0>9){b=l&1023;n=(d[m+(b+1)|0]|0)<<8|(d[m+b|0]|0);o=g}else{b=gj[c[g+196688+(m<<2)>>2]&4095](f)|0;n=b;o=c[2112932]|0}b=n&65535;f=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;m=c[f>>2]|0;c[f>>2]=m+2;f=c[2276085]&m;m=f&16777215;g=c[o+((m>>>10|16384)<<2)>>2]|0;if(g>>>0>9){l=f&1023;a[g+l|0]=n&255;a[g+(l+1)|0]=(n&65535)>>>8&255;p=b>>>8;c[2276075]=p;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}else{gg[c[o+196728+(g<<2)>>2]&4095](m,n);p=b>>>8;c[2276075]=p;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}}function rO(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[2276085]&q;q=r&16777215;t=c[2112932]|0;h=c[t+(q>>>10<<2)>>2]|0;if(h>>>0>9){s=r&1023;u=(d[h+(s+1)|0]|0)<<8|(d[h+s|0]|0);v=t}else{s=gj[c[t+196688+(h<<2)>>2]&4095](q)|0;u=s;v=c[2112932]|0}s=u&65535;q=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;h=c[q>>2]|0;c[q>>2]=h+2;q=c[2276085]&h;h=q&16777215;t=c[v+((h>>>10|16384)<<2)>>2]|0;if(t>>>0>9){r=q&1023;a[t+r|0]=u&255;a[t+(r+1)|0]=(u&65535)>>>8&255;w=s>>>8;c[2276075]=w;c[2276076]=s;c[2276077]=0;c[2276078]=0;return}else{gg[c[v+196728+(t<<2)>>2]&4095](h,u);w=s>>>8;c[2276075]=w;c[2276076]=s;c[2276077]=0;c[2276078]=0;return}}function rP(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{k=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=k;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=(g>>>((f<<3&16^16)>>>0)<<16>>16)+b|0;b=l&16777215;f=c[2112932]|0;g=c[f+((b>>>10|32768)<<2)>>2]|0;if(g>>>0>9){m=l&1023;n=(d[g+(m+1)|0]|0)<<8|(d[g+m|0]|0);o=f}else{m=gj[c[f+196688+(g<<2)>>2]&4095](b)|0;n=m;o=c[2112932]|0}m=n&65535;b=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;g=c[b>>2]|0;c[b>>2]=g+2;b=c[2276085]&g;g=b&16777215;f=c[o+((g>>>10|16384)<<2)>>2]|0;if(f>>>0>9){l=b&1023;a[f+l|0]=n&255;a[f+(l+1)|0]=(n&65535)>>>8&255;p=m>>>8;c[2276075]=p;c[2276076]=m;c[2276077]=0;c[2276078]=0;return}else{gg[c[o+196728+(f<<2)>>2]&4095](g,n);p=m>>>8;c[2276075]=p;c[2276076]=m;c[2276077]=0;c[2276078]=0;return}}function rQ(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=nB(c[2276056]|0)|0;e=b&16777215;f=c[2112932]|0;g=c[f+((e>>>10|32768)<<2)>>2]|0;if(g>>>0>9){h=b&1023;i=(d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0);j=f}else{h=gj[c[f+196688+(g<<2)>>2]&4095](e)|0;i=h;j=c[2112932]|0}h=i&65535;e=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;g=c[e>>2]|0;c[e>>2]=g+2;e=c[2276085]&g;g=e&16777215;f=c[j+((g>>>10|16384)<<2)>>2]|0;if(f>>>0>9){b=e&1023;a[f+b|0]=i&255;a[f+(b+1)|0]=(i&65535)>>>8&255;k=h>>>8;c[2276075]=k;c[2276076]=h;c[2276077]=0;c[2276078]=0;return}else{gg[c[j+196728+(f<<2)>>2]&4095](g,i);k=h>>>8;c[2276075]=k;c[2276076]=h;c[2276077]=0;c[2276078]=0;return}}function rR(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0);f=l&65535;g=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;m=c[g>>2]|0;c[g>>2]=m+2;g=c[2276085]&m;m=l&65535;b=g&16777215;e=c[2112932]|0;j=c[e+((b>>>10|16384)<<2)>>2]|0;if(j>>>0>9){i=g&1023;a[j+i|0]=l&255;a[j+(i+1)|0]=(m&65535)>>>8&255;n=f>>>8;c[2276075]=n;c[2276076]=f;c[2276077]=0;c[2276078]=0;return}else{gg[c[e+196728+(j<<2)>>2]&4095](b,m);n=f>>>8;c[2276075]=n;c[2276076]=f;c[2276077]=0;c[2276078]=0;return}}function rS(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[2276069]|0;d=c[9104156+((b&7)<<2)>>2]|0;e=d&65535;f=9104156+((b>>>9&7|8)<<2)|0;b=(c[f>>2]|0)-2|0;c[f>>2]=b;f=c[2276085]&b;b=d&65535;g=f&16777215;h=c[2112932]|0;i=c[h+((g>>>10|16384)<<2)>>2]|0;if(i>>>0>9){j=f&1023;a[i+j|0]=d&255;a[i+(j+1)|0]=(b&65535)>>>8&255;k=e>>>8;c[2276075]=k;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}else{gg[c[h+196728+(i<<2)>>2]&4095](g,b);k=e>>>8;c[2276075]=k;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}}function rT(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[2276069]|0;d=c[9104156+((b&7|8)<<2)>>2]|0;e=d&65535;f=9104156+((b>>>9&7|8)<<2)|0;b=(c[f>>2]|0)-2|0;c[f>>2]=b;f=c[2276085]&b;b=d&65535;g=f&16777215;h=c[2112932]|0;i=c[h+((g>>>10|16384)<<2)>>2]|0;if(i>>>0>9){j=f&1023;a[i+j|0]=d&255;a[i+(j+1)|0]=(b&65535)>>>8&255;k=e>>>8;c[2276075]=k;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}else{gg[c[h+196728+(i<<2)>>2]&4095](g,b);k=e>>>8;c[2276075]=k;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}}function rU(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=c[2276069]|0;e=c[2276085]&c[9104156+((b&7|8)<<2)>>2];f=e&16777215;g=c[2112932]|0;h=c[g+(f>>>10<<2)>>2]|0;if(h>>>0>9){i=e&1023;j=(d[h+(i+1)|0]|0)<<8|(d[h+i|0]|0);k=b;l=g}else{b=gj[c[g+196688+(h<<2)>>2]&4095](f)|0;j=b;k=c[2276069]|0;l=c[2112932]|0}b=j&65535;f=9104156+((k>>>9&7|8)<<2)|0;k=(c[f>>2]|0)-2|0;c[f>>2]=k;f=c[2276085]&k;k=f&16777215;h=c[l+((k>>>10|16384)<<2)>>2]|0;if(h>>>0>9){g=f&1023;a[h+g|0]=j&255;a[h+(g+1)|0]=(j&65535)>>>8&255;m=b>>>8;c[2276075]=m;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}else{gg[c[l+196728+(h<<2)>>2]&4095](k,j);m=b>>>8;c[2276075]=m;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}}function rV(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=c[b>>2]|0;c[b>>2]=e+2;b=c[2276085]&e;e=b&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=b&1023;i=(d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0);j=f}else{h=gj[c[f+196688+(g<<2)>>2]&4095](e)|0;i=h;j=c[2112932]|0}h=i&65535;e=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;g=(c[e>>2]|0)-2|0;c[e>>2]=g;e=c[2276085]&g;g=e&16777215;f=c[j+((g>>>10|16384)<<2)>>2]|0;if(f>>>0>9){b=e&1023;a[f+b|0]=i&255;a[f+(b+1)|0]=(i&65535)>>>8&255;k=h>>>8;c[2276075]=k;c[2276076]=h;c[2276077]=0;c[2276078]=0;return}else{gg[c[j+196728+(f<<2)>>2]&4095](g,i);k=h>>>8;c[2276075]=k;c[2276076]=h;c[2276077]=0;c[2276078]=0;return}}function rW(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=(c[b>>2]|0)-2|0;c[b>>2]=e;b=c[2276085]&e;e=b&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=b&1023;i=(d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0);j=f}else{h=gj[c[f+196688+(g<<2)>>2]&4095](e)|0;i=h;j=c[2112932]|0}h=i&65535;e=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;g=(c[e>>2]|0)-2|0;c[e>>2]=g;e=c[2276085]&g;g=e&16777215;f=c[j+((g>>>10|16384)<<2)>>2]|0;if(f>>>0>9){b=e&1023;a[f+b|0]=i&255;a[f+(b+1)|0]=(i&65535)>>>8&255;k=h>>>8;c[2276075]=k;c[2276076]=h;c[2276077]=0;c[2276078]=0;return}else{gg[c[j+196728+(f<<2)>>2]&4095](g,i);k=h>>>8;c[2276075]=k;c[2276076]=h;c[2276077]=0;c[2276078]=0;return}}function rX(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=(h>>>((g<<3&16^16)>>>0)<<16>>16)+b&c[2276085];b=m&16777215;g=c[2112932]|0;h=c[g+(b>>>10<<2)>>2]|0;if(h>>>0>9){n=m&1023;o=(d[h+(n+1)|0]|0)<<8|(d[h+n|0]|0);p=g}else{n=gj[c[g+196688+(h<<2)>>2]&4095](b)|0;o=n;p=c[2112932]|0}n=o&65535;b=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;h=(c[b>>2]|0)-2|0;c[b>>2]=h;b=c[2276085]&h;h=b&16777215;g=c[p+((h>>>10|16384)<<2)>>2]|0;if(g>>>0>9){m=b&1023;a[g+m|0]=o&255;a[g+(m+1)|0]=(o&65535)>>>8&255;q=n>>>8;c[2276075]=q;c[2276076]=n;c[2276077]=0;c[2276078]=0;return}else{gg[c[p+196728+(g<<2)>>2]&4095](h,o);q=n>>>8;c[2276075]=q;c[2276076]=n;c[2276077]=0;c[2276078]=0;return}}function rY(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=nB(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;e=c[2276085]&b;b=e&16777215;f=c[2112932]|0;g=c[f+(b>>>10<<2)>>2]|0;if(g>>>0>9){h=e&1023;i=(d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0);j=f}else{h=gj[c[f+196688+(g<<2)>>2]&4095](b)|0;i=h;j=c[2112932]|0}h=i&65535;b=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;g=(c[b>>2]|0)-2|0;c[b>>2]=g;b=c[2276085]&g;g=b&16777215;f=c[j+((g>>>10|16384)<<2)>>2]|0;if(f>>>0>9){e=b&1023;a[f+e|0]=i&255;a[f+(e+1)|0]=(i&65535)>>>8&255;k=h>>>8;c[2276075]=k;c[2276076]=h;c[2276077]=0;c[2276078]=0;return}else{gg[c[j+196728+(f<<2)>>2]&4095](g,i);k=h>>>8;c[2276075]=k;c[2276076]=h;c[2276077]=0;c[2276078]=0;return}}function rZ(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)<<16>>16&c[2276085];f=l&16777215;g=c[2112932]|0;m=c[g+(f>>>10<<2)>>2]|0;if(m>>>0>9){b=l&1023;n=(d[m+(b+1)|0]|0)<<8|(d[m+b|0]|0);o=g}else{b=gj[c[g+196688+(m<<2)>>2]&4095](f)|0;n=b;o=c[2112932]|0}b=n&65535;f=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;m=(c[f>>2]|0)-2|0;c[f>>2]=m;f=c[2276085]&m;m=f&16777215;g=c[o+((m>>>10|16384)<<2)>>2]|0;if(g>>>0>9){l=f&1023;a[g+l|0]=n&255;a[g+(l+1)|0]=(n&65535)>>>8&255;p=b>>>8;c[2276075]=p;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}else{gg[c[o+196728+(g<<2)>>2]&4095](m,n);p=b>>>8;c[2276075]=p;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}}function r_(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[2276085]&q;q=r&16777215;t=c[2112932]|0;h=c[t+(q>>>10<<2)>>2]|0;if(h>>>0>9){s=r&1023;u=(d[h+(s+1)|0]|0)<<8|(d[h+s|0]|0);v=t}else{s=gj[c[t+196688+(h<<2)>>2]&4095](q)|0;u=s;v=c[2112932]|0}s=u&65535;q=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;h=(c[q>>2]|0)-2|0;c[q>>2]=h;q=c[2276085]&h;h=q&16777215;t=c[v+((h>>>10|16384)<<2)>>2]|0;if(t>>>0>9){r=q&1023;a[t+r|0]=u&255;a[t+(r+1)|0]=(u&65535)>>>8&255;w=s>>>8;c[2276075]=w;c[2276076]=s;c[2276077]=0;c[2276078]=0;return}else{gg[c[v+196728+(t<<2)>>2]&4095](h,u);w=s>>>8;c[2276075]=w;c[2276076]=s;c[2276077]=0;c[2276078]=0;return}}function r$(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{k=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=k;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=(g>>>((f<<3&16^16)>>>0)<<16>>16)+b|0;b=l&16777215;f=c[2112932]|0;g=c[f+((b>>>10|32768)<<2)>>2]|0;if(g>>>0>9){m=l&1023;n=(d[g+(m+1)|0]|0)<<8|(d[g+m|0]|0);o=f}else{m=gj[c[f+196688+(g<<2)>>2]&4095](b)|0;n=m;o=c[2112932]|0}m=n&65535;b=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;g=(c[b>>2]|0)-2|0;c[b>>2]=g;b=c[2276085]&g;g=b&16777215;f=c[o+((g>>>10|16384)<<2)>>2]|0;if(f>>>0>9){l=b&1023;a[f+l|0]=n&255;a[f+(l+1)|0]=(n&65535)>>>8&255;p=m>>>8;c[2276075]=p;c[2276076]=m;c[2276077]=0;c[2276078]=0;return}else{gg[c[o+196728+(f<<2)>>2]&4095](g,n);p=m>>>8;c[2276075]=p;c[2276076]=m;c[2276077]=0;c[2276078]=0;return}}function r0(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=nB(c[2276056]|0)|0;e=b&16777215;f=c[2112932]|0;g=c[f+((e>>>10|32768)<<2)>>2]|0;if(g>>>0>9){h=b&1023;i=(d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0);j=f}else{h=gj[c[f+196688+(g<<2)>>2]&4095](e)|0;i=h;j=c[2112932]|0}h=i&65535;e=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;g=(c[e>>2]|0)-2|0;c[e>>2]=g;e=c[2276085]&g;g=e&16777215;f=c[j+((g>>>10|16384)<<2)>>2]|0;if(f>>>0>9){b=e&1023;a[f+b|0]=i&255;a[f+(b+1)|0]=(i&65535)>>>8&255;k=h>>>8;c[2276075]=k;c[2276076]=h;c[2276077]=0;c[2276078]=0;return}else{gg[c[j+196728+(f<<2)>>2]&4095](g,i);k=h>>>8;c[2276075]=k;c[2276076]=h;c[2276077]=0;c[2276078]=0;return}}function r1(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0);f=l&65535;g=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;m=(c[g>>2]|0)-2|0;c[g>>2]=m;g=c[2276085]&m;m=l&65535;b=g&16777215;e=c[2112932]|0;j=c[e+((b>>>10|16384)<<2)>>2]|0;if(j>>>0>9){i=g&1023;a[j+i|0]=l&255;a[j+(i+1)|0]=(m&65535)>>>8&255;n=f>>>8;c[2276075]=n;c[2276076]=f;c[2276077]=0;c[2276078]=0;return}else{gg[c[e+196728+(j<<2)>>2]&4095](b,m);n=f>>>8;c[2276075]=n;c[2276076]=f;c[2276077]=0;c[2276078]=0;return}}function r2(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=c[2276069]|0;e=c[9104156+((b&7)<<2)>>2]|0;f=e&65535;g=c[9104156+((b>>>9&7|8)<<2)>>2]|0;b=c[2276056]|0;h=b&-4;if((h|0)==(c[2276083]|0)){i=b;j=c[2276084]|0}else{c[2276083]=h;k=c[2276085]&h;h=k&16777212;l=c[2112932]|0;m=c[l+((h>>>10|32768)<<2)>>2]|0;if(m>>>0>9){n=k&1020;o=(d[m+(n|3)|0]|0)<<8|(d[m+(n|2)|0]|0)|((d[m+(n|1)|0]|0)<<8|(d[m+n|0]|0))<<16;p=b}else{b=gj[c[l+196768+(m<<2)>>2]&4095](h)|0;o=b;p=c[2276056]|0}c[2276084]=o;i=p;j=o}c[2276056]=i+2;o=(j>>>((i<<3&16^16)>>>0)<<16>>16)+g&c[2276085];g=e&65535;i=o&16777215;j=c[2112932]|0;p=c[j+((i>>>10|16384)<<2)>>2]|0;if(p>>>0>9){b=o&1023;a[p+b|0]=e&255;a[p+(b+1)|0]=(g&65535)>>>8&255;q=f>>>8;c[2276075]=q;c[2276076]=f;c[2276077]=0;c[2276078]=0;return}else{gg[c[j+196728+(p<<2)>>2]&4095](i,g);q=f>>>8;c[2276075]=q;c[2276076]=f;c[2276077]=0;c[2276078]=0;return}}function r3(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=c[2276069]|0;e=c[9104156+((b&7|8)<<2)>>2]|0;f=e&65535;g=c[9104156+((b>>>9&7|8)<<2)>>2]|0;b=c[2276056]|0;h=b&-4;if((h|0)==(c[2276083]|0)){i=b;j=c[2276084]|0}else{c[2276083]=h;k=c[2276085]&h;h=k&16777212;l=c[2112932]|0;m=c[l+((h>>>10|32768)<<2)>>2]|0;if(m>>>0>9){n=k&1020;o=(d[m+(n|3)|0]|0)<<8|(d[m+(n|2)|0]|0)|((d[m+(n|1)|0]|0)<<8|(d[m+n|0]|0))<<16;p=b}else{b=gj[c[l+196768+(m<<2)>>2]&4095](h)|0;o=b;p=c[2276056]|0}c[2276084]=o;i=p;j=o}c[2276056]=i+2;o=(j>>>((i<<3&16^16)>>>0)<<16>>16)+g&c[2276085];g=e&65535;i=o&16777215;j=c[2112932]|0;p=c[j+((i>>>10|16384)<<2)>>2]|0;if(p>>>0>9){b=o&1023;a[p+b|0]=e&255;a[p+(b+1)|0]=(g&65535)>>>8&255;q=f>>>8;c[2276075]=q;c[2276076]=f;c[2276077]=0;c[2276078]=0;return}else{gg[c[j+196728+(p<<2)>>2]&4095](i,g);q=f>>>8;c[2276075]=q;c[2276076]=f;c[2276077]=0;c[2276078]=0;return}}function r4(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=c[2276069]|0;e=c[2276085]&c[9104156+((b&7|8)<<2)>>2];f=e&16777215;g=c[2112932]|0;h=c[g+(f>>>10<<2)>>2]|0;if(h>>>0>9){i=e&1023;j=(d[h+(i+1)|0]|0)<<8|(d[h+i|0]|0);k=b}else{b=gj[c[g+196688+(h<<2)>>2]&4095](f)|0;j=b;k=c[2276069]|0}b=j&65535;f=c[9104156+((k>>>9&7|8)<<2)>>2]|0;k=c[2276056]|0;h=k&-4;if((h|0)==(c[2276083]|0)){l=k;m=c[2276084]|0}else{c[2276083]=h;g=c[2276085]&h;h=g&16777212;i=c[2112932]|0;e=c[i+((h>>>10|32768)<<2)>>2]|0;if(e>>>0>9){n=g&1020;o=(d[e+(n|3)|0]|0)<<8|(d[e+(n|2)|0]|0)|((d[e+(n|1)|0]|0)<<8|(d[e+n|0]|0))<<16;p=k}else{k=gj[c[i+196768+(e<<2)>>2]&4095](h)|0;o=k;p=c[2276056]|0}c[2276084]=o;l=p;m=o}c[2276056]=l+2;o=(m>>>((l<<3&16^16)>>>0)<<16>>16)+f&c[2276085];f=o&16777215;l=c[2112932]|0;m=c[l+((f>>>10|16384)<<2)>>2]|0;if(m>>>0>9){p=o&1023;a[m+p|0]=j&255;a[m+(p+1)|0]=(j&65535)>>>8&255;q=b>>>8;c[2276075]=q;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}else{gg[c[l+196728+(m<<2)>>2]&4095](f,j);q=b>>>8;c[2276075]=q;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}}function r5(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=c[b>>2]|0;c[b>>2]=e+2;b=c[2276085]&e;e=b&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=b&1023;i=(d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0)}else{i=gj[c[f+196688+(g<<2)>>2]&4095](e)|0}e=i&65535;g=c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2]|0;f=c[2276056]|0;h=f&-4;if((h|0)==(c[2276083]|0)){j=f;k=c[2276084]|0}else{c[2276083]=h;b=c[2276085]&h;h=b&16777212;l=c[2112932]|0;m=c[l+((h>>>10|32768)<<2)>>2]|0;if(m>>>0>9){n=b&1020;o=(d[m+(n|3)|0]|0)<<8|(d[m+(n|2)|0]|0)|((d[m+(n|1)|0]|0)<<8|(d[m+n|0]|0))<<16;p=f}else{f=gj[c[l+196768+(m<<2)>>2]&4095](h)|0;o=f;p=c[2276056]|0}c[2276084]=o;j=p;k=o}c[2276056]=j+2;o=(k>>>((j<<3&16^16)>>>0)<<16>>16)+g&c[2276085];g=o&16777215;j=c[2112932]|0;k=c[j+((g>>>10|16384)<<2)>>2]|0;if(k>>>0>9){p=o&1023;a[k+p|0]=i&255;a[k+(p+1)|0]=(i&65535)>>>8&255;q=e>>>8;c[2276075]=q;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}else{gg[c[j+196728+(k<<2)>>2]&4095](g,i);q=e>>>8;c[2276075]=q;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}}function r6(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=(c[b>>2]|0)-2|0;c[b>>2]=e;b=c[2276085]&e;e=b&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=b&1023;i=(d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0)}else{i=gj[c[f+196688+(g<<2)>>2]&4095](e)|0}e=i&65535;g=c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2]|0;f=c[2276056]|0;h=f&-4;if((h|0)==(c[2276083]|0)){j=f;k=c[2276084]|0}else{c[2276083]=h;b=c[2276085]&h;h=b&16777212;l=c[2112932]|0;m=c[l+((h>>>10|32768)<<2)>>2]|0;if(m>>>0>9){n=b&1020;o=(d[m+(n|3)|0]|0)<<8|(d[m+(n|2)|0]|0)|((d[m+(n|1)|0]|0)<<8|(d[m+n|0]|0))<<16;p=f}else{f=gj[c[l+196768+(m<<2)>>2]&4095](h)|0;o=f;p=c[2276056]|0}c[2276084]=o;j=p;k=o}c[2276056]=j+2;o=(k>>>((j<<3&16^16)>>>0)<<16>>16)+g&c[2276085];g=o&16777215;j=c[2112932]|0;k=c[j+((g>>>10|16384)<<2)>>2]|0;if(k>>>0>9){p=o&1023;a[k+p|0]=i&255;a[k+(p+1)|0]=(i&65535)>>>8&255;q=e>>>8;c[2276075]=q;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}else{gg[c[j+196728+(k<<2)>>2]&4095](g,i);q=e>>>8;c[2276075]=q;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}}function r7(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}m=g+2|0;c[2276056]=m;n=(h>>>((g<<3&16^16)>>>0)<<16>>16)+b&c[2276085];b=n&16777215;g=c[2112932]|0;h=c[g+(b>>>10<<2)>>2]|0;if(h>>>0>9){e=n&1023;o=(d[h+(e+1)|0]|0)<<8|(d[h+e|0]|0);p=m}else{m=gj[c[g+196688+(h<<2)>>2]&4095](b)|0;o=m;p=c[2276056]|0}m=o&65535;b=c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2]|0;h=p&-4;if((h|0)==(c[2276083]|0)){q=p;r=c[2276084]|0}else{c[2276083]=h;g=c[2276085]&h;h=g&16777212;e=c[2112932]|0;n=c[e+((h>>>10|32768)<<2)>>2]|0;if(n>>>0>9){f=g&1020;s=(d[n+(f|3)|0]|0)<<8|(d[n+(f|2)|0]|0)|((d[n+(f|1)|0]|0)<<8|(d[n+f|0]|0))<<16;t=p}else{p=gj[c[e+196768+(n<<2)>>2]&4095](h)|0;s=p;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;s=(r>>>((q<<3&16^16)>>>0)<<16>>16)+b&c[2276085];b=s&16777215;q=c[2112932]|0;r=c[q+((b>>>10|16384)<<2)>>2]|0;if(r>>>0>9){t=s&1023;a[r+t|0]=o&255;a[r+(t+1)|0]=(o&65535)>>>8&255;u=m>>>8;c[2276075]=u;c[2276076]=m;c[2276077]=0;c[2276078]=0;return}else{gg[c[q+196728+(r<<2)>>2]&4095](b,o);u=m>>>8;c[2276075]=u;c[2276076]=m;c[2276077]=0;c[2276078]=0;return}}function r8(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=nB(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;e=c[2276085]&b;b=e&16777215;f=c[2112932]|0;g=c[f+(b>>>10<<2)>>2]|0;if(g>>>0>9){h=e&1023;i=(d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0)}else{i=gj[c[f+196688+(g<<2)>>2]&4095](b)|0}b=i&65535;g=c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2]|0;f=c[2276056]|0;h=f&-4;if((h|0)==(c[2276083]|0)){j=f;k=c[2276084]|0}else{c[2276083]=h;e=c[2276085]&h;h=e&16777212;l=c[2112932]|0;m=c[l+((h>>>10|32768)<<2)>>2]|0;if(m>>>0>9){n=e&1020;o=(d[m+(n|3)|0]|0)<<8|(d[m+(n|2)|0]|0)|((d[m+(n|1)|0]|0)<<8|(d[m+n|0]|0))<<16;p=f}else{f=gj[c[l+196768+(m<<2)>>2]&4095](h)|0;o=f;p=c[2276056]|0}c[2276084]=o;j=p;k=o}c[2276056]=j+2;o=(k>>>((j<<3&16^16)>>>0)<<16>>16)+g&c[2276085];g=o&16777215;j=c[2112932]|0;k=c[j+((g>>>10|16384)<<2)>>2]|0;if(k>>>0>9){p=o&1023;a[k+p|0]=i&255;a[k+(p+1)|0]=(i&65535)>>>8&255;q=b>>>8;c[2276075]=q;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}else{gg[c[j+196728+(k<<2)>>2]&4095](g,i);q=b>>>8;c[2276075]=q;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}}function r9(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}l=f+2|0;c[2276056]=l;m=g>>>((f<<3&16^16)>>>0)<<16>>16&c[2276085];f=m&16777215;g=c[2112932]|0;b=c[g+(f>>>10<<2)>>2]|0;if(b>>>0>9){e=m&1023;n=(d[b+(e+1)|0]|0)<<8|(d[b+e|0]|0);o=l}else{l=gj[c[g+196688+(b<<2)>>2]&4095](f)|0;n=l;o=c[2276056]|0}l=n&65535;f=c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2]|0;b=o&-4;if((b|0)==(c[2276083]|0)){p=o;q=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;e=c[2112932]|0;m=c[e+((b>>>10|32768)<<2)>>2]|0;if(m>>>0>9){j=g&1020;r=(d[m+(j|3)|0]|0)<<8|(d[m+(j|2)|0]|0)|((d[m+(j|1)|0]|0)<<8|(d[m+j|0]|0))<<16;s=o}else{o=gj[c[e+196768+(m<<2)>>2]&4095](b)|0;r=o;s=c[2276056]|0}c[2276084]=r;p=s;q=r}c[2276056]=p+2;r=(q>>>((p<<3&16^16)>>>0)<<16>>16)+f&c[2276085];f=r&16777215;p=c[2112932]|0;q=c[p+((f>>>10|16384)<<2)>>2]|0;if(q>>>0>9){s=r&1023;a[q+s|0]=n&255;a[q+(s+1)|0]=(n&65535)>>>8&255;t=l>>>8;c[2276075]=t;c[2276076]=l;c[2276077]=0;c[2276078]=0;return}else{gg[c[p+196728+(q<<2)>>2]&4095](f,n);t=l>>>8;c[2276075]=t;c[2276076]=l;c[2276077]=0;c[2276078]=0;return}}function sa(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}t=r+2|0;c[2276056]=t;r=c[2276085]&q;q=r&16777215;h=c[2112932]|0;s=c[h+(q>>>10<<2)>>2]|0;if(s>>>0>9){n=r&1023;u=(d[s+(n+1)|0]|0)<<8|(d[s+n|0]|0);v=t}else{t=gj[c[h+196688+(s<<2)>>2]&4095](q)|0;u=t;v=c[2276056]|0}t=u&65535;q=c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2]|0;s=v&-4;if((s|0)==(c[2276083]|0)){w=v;x=c[2276084]|0}else{c[2276083]=s;h=c[2276085]&s;s=h&16777212;n=c[2112932]|0;r=c[n+((s>>>10|32768)<<2)>>2]|0;if(r>>>0>9){f=h&1020;y=(d[r+(f|3)|0]|0)<<8|(d[r+(f|2)|0]|0)|((d[r+(f|1)|0]|0)<<8|(d[r+f|0]|0))<<16;z=v}else{v=gj[c[n+196768+(r<<2)>>2]&4095](s)|0;y=v;z=c[2276056]|0}c[2276084]=y;w=z;x=y}c[2276056]=w+2;y=(x>>>((w<<3&16^16)>>>0)<<16>>16)+q&c[2276085];q=y&16777215;w=c[2112932]|0;x=c[w+((q>>>10|16384)<<2)>>2]|0;if(x>>>0>9){z=y&1023;a[x+z|0]=u&255;a[x+(z+1)|0]=(u&65535)>>>8&255;A=t>>>8;c[2276075]=A;c[2276076]=t;c[2276077]=0;c[2276078]=0;return}else{gg[c[w+196728+(x<<2)>>2]&4095](q,u);A=t>>>8;c[2276075]=A;c[2276076]=t;c[2276077]=0;c[2276078]=0;return}}function sb(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{k=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=k;m=c[2276056]|0}c[2276084]=l;f=m;g=l}l=f+2|0;c[2276056]=l;m=(g>>>((f<<3&16^16)>>>0)<<16>>16)+b|0;b=m&16777215;f=c[2112932]|0;g=c[f+((b>>>10|32768)<<2)>>2]|0;if(g>>>0>9){k=m&1023;n=(d[g+(k+1)|0]|0)<<8|(d[g+k|0]|0);o=l}else{l=gj[c[f+196688+(g<<2)>>2]&4095](b)|0;n=l;o=c[2276056]|0}l=n&65535;b=c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2]|0;g=o&-4;if((g|0)==(c[2276083]|0)){p=o;q=c[2276084]|0}else{c[2276083]=g;f=c[2276085]&g;g=f&16777212;k=c[2112932]|0;m=c[k+((g>>>10|32768)<<2)>>2]|0;if(m>>>0>9){e=f&1020;r=(d[m+(e|3)|0]|0)<<8|(d[m+(e|2)|0]|0)|((d[m+(e|1)|0]|0)<<8|(d[m+e|0]|0))<<16;s=o}else{o=gj[c[k+196768+(m<<2)>>2]&4095](g)|0;r=o;s=c[2276056]|0}c[2276084]=r;p=s;q=r}c[2276056]=p+2;r=(q>>>((p<<3&16^16)>>>0)<<16>>16)+b&c[2276085];b=r&16777215;p=c[2112932]|0;q=c[p+((b>>>10|16384)<<2)>>2]|0;if(q>>>0>9){s=r&1023;a[q+s|0]=n&255;a[q+(s+1)|0]=(n&65535)>>>8&255;t=l>>>8;c[2276075]=t;c[2276076]=l;c[2276077]=0;c[2276078]=0;return}else{gg[c[p+196728+(q<<2)>>2]&4095](b,n);t=l>>>8;c[2276075]=t;c[2276076]=l;c[2276077]=0;c[2276078]=0;return}}function sc(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=nB(c[2276056]|0)|0;e=b&16777215;f=c[2112932]|0;g=c[f+((e>>>10|32768)<<2)>>2]|0;if(g>>>0>9){h=b&1023;i=(d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0)}else{i=gj[c[f+196688+(g<<2)>>2]&4095](e)|0}e=i&65535;g=c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2]|0;f=c[2276056]|0;h=f&-4;if((h|0)==(c[2276083]|0)){j=f;k=c[2276084]|0}else{c[2276083]=h;b=c[2276085]&h;h=b&16777212;l=c[2112932]|0;m=c[l+((h>>>10|32768)<<2)>>2]|0;if(m>>>0>9){n=b&1020;o=(d[m+(n|3)|0]|0)<<8|(d[m+(n|2)|0]|0)|((d[m+(n|1)|0]|0)<<8|(d[m+n|0]|0))<<16;p=f}else{f=gj[c[l+196768+(m<<2)>>2]&4095](h)|0;o=f;p=c[2276056]|0}c[2276084]=o;j=p;k=o}c[2276056]=j+2;o=(k>>>((j<<3&16^16)>>>0)<<16>>16)+g&c[2276085];g=o&16777215;j=c[2112932]|0;k=c[j+((g>>>10|16384)<<2)>>2]|0;if(k>>>0>9){p=o&1023;a[k+p|0]=i&255;a[k+(p+1)|0]=(i&65535)>>>8&255;q=e>>>8;c[2276075]=q;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}else{gg[c[j+196728+(k<<2)>>2]&4095](g,i);q=e>>>8;c[2276075]=q;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}}function sd(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0);f=n&65535;o=c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2]|0;e=p&-4;if((e|0)==(h|0)){q=p;r=g}else{c[2276083]=e;g=c[2276085]&e;e=g&16777212;h=c[2112932]|0;j=c[h+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){l=g&1020;s=(d[j+(l|3)|0]|0)<<8|(d[j+(l|2)|0]|0)|((d[j+(l|1)|0]|0)<<8|(d[j+l|0]|0))<<16;t=p}else{p=gj[c[h+196768+(j<<2)>>2]&4095](e)|0;s=p;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;s=(r>>>((q<<3&16^16)>>>0)<<16>>16)+o&c[2276085];o=n&65535;q=s&16777215;r=c[2112932]|0;t=c[r+((q>>>10|16384)<<2)>>2]|0;if(t>>>0>9){p=s&1023;a[t+p|0]=n&255;a[t+(p+1)|0]=(o&65535)>>>8&255;u=f>>>8;c[2276075]=u;c[2276076]=f;c[2276077]=0;c[2276078]=0;return}else{gg[c[r+196728+(t<<2)>>2]&4095](q,o);u=f>>>8;c[2276075]=u;c[2276076]=f;c[2276077]=0;c[2276078]=0;return}}function se(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[2276069]|0;d=c[9104156+((b&7)<<2)>>2]|0;e=d&65535;f=nB(c[9104156+((b>>>9&7|8)<<2)>>2]|0)|0;b=c[2276085]&f;f=d&65535;g=b&16777215;h=c[2112932]|0;i=c[h+((g>>>10|16384)<<2)>>2]|0;if(i>>>0>9){j=b&1023;a[i+j|0]=d&255;a[i+(j+1)|0]=(f&65535)>>>8&255;k=e>>>8;c[2276075]=k;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}else{gg[c[h+196728+(i<<2)>>2]&4095](g,f);k=e>>>8;c[2276075]=k;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}}function sf(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[2276069]|0;d=c[9104156+((b&7|8)<<2)>>2]|0;e=d&65535;f=nB(c[9104156+((b>>>9&7|8)<<2)>>2]|0)|0;b=c[2276085]&f;f=d&65535;g=b&16777215;h=c[2112932]|0;i=c[h+((g>>>10|16384)<<2)>>2]|0;if(i>>>0>9){j=b&1023;a[i+j|0]=d&255;a[i+(j+1)|0]=(f&65535)>>>8&255;k=e>>>8;c[2276075]=k;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}else{gg[c[h+196728+(i<<2)>>2]&4095](g,f);k=e>>>8;c[2276075]=k;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}}function sg(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=c[2276069]|0;e=c[2276085]&c[9104156+((b&7|8)<<2)>>2];f=e&16777215;g=c[2112932]|0;h=c[g+(f>>>10<<2)>>2]|0;if(h>>>0>9){i=e&1023;j=(d[h+(i+1)|0]|0)<<8|(d[h+i|0]|0);k=b}else{b=gj[c[g+196688+(h<<2)>>2]&4095](f)|0;j=b;k=c[2276069]|0}b=j&65535;f=nB(c[9104156+((k>>>9&7|8)<<2)>>2]|0)|0;k=c[2276085]&f;f=k&16777215;h=c[2112932]|0;g=c[h+((f>>>10|16384)<<2)>>2]|0;if(g>>>0>9){i=k&1023;a[g+i|0]=j&255;a[g+(i+1)|0]=(j&65535)>>>8&255;l=b>>>8;c[2276075]=l;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}else{gg[c[h+196728+(g<<2)>>2]&4095](f,j);l=b>>>8;c[2276075]=l;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}}function sh(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=c[b>>2]|0;c[b>>2]=e+2;b=c[2276085]&e;e=b&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=b&1023;i=(d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0)}else{i=gj[c[f+196688+(g<<2)>>2]&4095](e)|0}e=i&65535;g=nB(c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2]|0)|0;f=c[2276085]&g;g=f&16777215;h=c[2112932]|0;b=c[h+((g>>>10|16384)<<2)>>2]|0;if(b>>>0>9){j=f&1023;a[b+j|0]=i&255;a[b+(j+1)|0]=(i&65535)>>>8&255;k=e>>>8;c[2276075]=k;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}else{gg[c[h+196728+(b<<2)>>2]&4095](g,i);k=e>>>8;c[2276075]=k;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}}function si(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=(c[b>>2]|0)-2|0;c[b>>2]=e;b=c[2276085]&e;e=b&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=b&1023;i=(d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0)}else{i=gj[c[f+196688+(g<<2)>>2]&4095](e)|0}e=i&65535;g=nB(c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2]|0)|0;f=c[2276085]&g;g=f&16777215;h=c[2112932]|0;b=c[h+((g>>>10|16384)<<2)>>2]|0;if(b>>>0>9){j=f&1023;a[b+j|0]=i&255;a[b+(j+1)|0]=(i&65535)>>>8&255;k=e>>>8;c[2276075]=k;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}else{gg[c[h+196728+(b<<2)>>2]&4095](g,i);k=e>>>8;c[2276075]=k;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}}function sj(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=(h>>>((g<<3&16^16)>>>0)<<16>>16)+b&c[2276085];b=m&16777215;g=c[2112932]|0;h=c[g+(b>>>10<<2)>>2]|0;if(h>>>0>9){n=m&1023;o=(d[h+(n+1)|0]|0)<<8|(d[h+n|0]|0)}else{o=gj[c[g+196688+(h<<2)>>2]&4095](b)|0}b=o&65535;h=nB(c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2]|0)|0;g=c[2276085]&h;h=g&16777215;n=c[2112932]|0;m=c[n+((h>>>10|16384)<<2)>>2]|0;if(m>>>0>9){e=g&1023;a[m+e|0]=o&255;a[m+(e+1)|0]=(o&65535)>>>8&255;p=b>>>8;c[2276075]=p;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}else{gg[c[n+196728+(m<<2)>>2]&4095](h,o);p=b>>>8;c[2276075]=p;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}}function sk(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=nB(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;e=c[2276085]&b;b=e&16777215;f=c[2112932]|0;g=c[f+(b>>>10<<2)>>2]|0;if(g>>>0>9){h=e&1023;i=(d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0)}else{i=gj[c[f+196688+(g<<2)>>2]&4095](b)|0}b=i&65535;g=nB(c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2]|0)|0;f=c[2276085]&g;g=f&16777215;h=c[2112932]|0;e=c[h+((g>>>10|16384)<<2)>>2]|0;if(e>>>0>9){j=f&1023;a[e+j|0]=i&255;a[e+(j+1)|0]=(i&65535)>>>8&255;k=b>>>8;c[2276075]=k;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}else{gg[c[h+196728+(e<<2)>>2]&4095](g,i);k=b>>>8;c[2276075]=k;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}}function sl(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)<<16>>16&c[2276085];f=l&16777215;g=c[2112932]|0;m=c[g+(f>>>10<<2)>>2]|0;if(m>>>0>9){b=l&1023;n=(d[m+(b+1)|0]|0)<<8|(d[m+b|0]|0)}else{n=gj[c[g+196688+(m<<2)>>2]&4095](f)|0}f=n&65535;m=nB(c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2]|0)|0;g=c[2276085]&m;m=g&16777215;b=c[2112932]|0;l=c[b+((m>>>10|16384)<<2)>>2]|0;if(l>>>0>9){e=g&1023;a[l+e|0]=n&255;a[l+(e+1)|0]=(n&65535)>>>8&255;o=f>>>8;c[2276075]=o;c[2276076]=f;c[2276077]=0;c[2276078]=0;return}else{gg[c[b+196728+(l<<2)>>2]&4095](m,n);o=f>>>8;c[2276075]=o;c[2276076]=f;c[2276077]=0;c[2276078]=0;return}}function sm(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[2276085]&q;q=r&16777215;t=c[2112932]|0;h=c[t+(q>>>10<<2)>>2]|0;if(h>>>0>9){s=r&1023;u=(d[h+(s+1)|0]|0)<<8|(d[h+s|0]|0)}else{u=gj[c[t+196688+(h<<2)>>2]&4095](q)|0}q=u&65535;h=nB(c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2]|0)|0;t=c[2276085]&h;h=t&16777215;s=c[2112932]|0;r=c[s+((h>>>10|16384)<<2)>>2]|0;if(r>>>0>9){n=t&1023;a[r+n|0]=u&255;a[r+(n+1)|0]=(u&65535)>>>8&255;v=q>>>8;c[2276075]=v;c[2276076]=q;c[2276077]=0;c[2276078]=0;return}else{gg[c[s+196728+(r<<2)>>2]&4095](h,u);v=q>>>8;c[2276075]=v;c[2276076]=q;c[2276077]=0;c[2276078]=0;return}}function sn(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{k=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=k;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=(g>>>((f<<3&16^16)>>>0)<<16>>16)+b|0;b=l&16777215;f=c[2112932]|0;g=c[f+((b>>>10|32768)<<2)>>2]|0;if(g>>>0>9){m=l&1023;n=(d[g+(m+1)|0]|0)<<8|(d[g+m|0]|0)}else{n=gj[c[f+196688+(g<<2)>>2]&4095](b)|0}b=n&65535;g=nB(c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2]|0)|0;f=c[2276085]&g;g=f&16777215;m=c[2112932]|0;l=c[m+((g>>>10|16384)<<2)>>2]|0;if(l>>>0>9){k=f&1023;a[l+k|0]=n&255;a[l+(k+1)|0]=(n&65535)>>>8&255;o=b>>>8;c[2276075]=o;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}else{gg[c[m+196728+(l<<2)>>2]&4095](g,n);o=b>>>8;c[2276075]=o;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}}function so(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=nB(c[2276056]|0)|0;e=b&16777215;f=c[2112932]|0;g=c[f+((e>>>10|32768)<<2)>>2]|0;if(g>>>0>9){h=b&1023;i=(d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0)}else{i=gj[c[f+196688+(g<<2)>>2]&4095](e)|0}e=i&65535;g=nB(c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2]|0)|0;f=c[2276085]&g;g=f&16777215;h=c[2112932]|0;b=c[h+((g>>>10|16384)<<2)>>2]|0;if(b>>>0>9){j=f&1023;a[b+j|0]=i&255;a[b+(j+1)|0]=(i&65535)>>>8&255;k=e>>>8;c[2276075]=k;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}else{gg[c[h+196728+(b<<2)>>2]&4095](g,i);k=e>>>8;c[2276075]=k;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}}function sp(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0);f=l&65535;g=nB(c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2]|0)|0;m=c[2276085]&g;g=l&65535;b=m&16777215;e=c[2112932]|0;j=c[e+((b>>>10|16384)<<2)>>2]|0;if(j>>>0>9){i=m&1023;a[j+i|0]=l&255;a[j+(i+1)|0]=(g&65535)>>>8&255;n=f>>>8;c[2276075]=n;c[2276076]=f;c[2276077]=0;c[2276078]=0;return}else{gg[c[e+196728+(j<<2)>>2]&4095](b,g);n=f>>>8;c[2276075]=n;c[2276076]=f;c[2276077]=0;c[2276078]=0;return}}function sq(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[9104156+((c[2276069]&7)<<2)>>2]|0;e=b&65535;f=c[2276056]|0;g=f&-4;if((g|0)==(c[2276083]|0)){h=f;i=c[2276084]|0}else{c[2276083]=g;j=c[2276085]&g;g=j&16777212;k=c[2112932]|0;l=c[k+((g>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=j&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=f}else{f=gj[c[k+196768+(l<<2)>>2]&4095](g)|0;n=f;o=c[2276056]|0}c[2276084]=n;h=o;i=n}c[2276056]=h+2;n=i>>>((h<<3&16^16)>>>0)<<16>>16&c[2276085];h=b&65535;i=n&16777215;o=c[2112932]|0;f=c[o+((i>>>10|16384)<<2)>>2]|0;if(f>>>0>9){g=n&1023;a[f+g|0]=b&255;a[f+(g+1)|0]=(h&65535)>>>8&255;p=e>>>8;c[2276075]=p;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}else{gg[c[o+196728+(f<<2)>>2]&4095](i,h);p=e>>>8;c[2276075]=p;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}}function sr(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=b&65535;f=c[2276056]|0;g=f&-4;if((g|0)==(c[2276083]|0)){h=f;i=c[2276084]|0}else{c[2276083]=g;j=c[2276085]&g;g=j&16777212;k=c[2112932]|0;l=c[k+((g>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=j&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=f}else{f=gj[c[k+196768+(l<<2)>>2]&4095](g)|0;n=f;o=c[2276056]|0}c[2276084]=n;h=o;i=n}c[2276056]=h+2;n=i>>>((h<<3&16^16)>>>0)<<16>>16&c[2276085];h=b&65535;i=n&16777215;o=c[2112932]|0;f=c[o+((i>>>10|16384)<<2)>>2]|0;if(f>>>0>9){g=n&1023;a[f+g|0]=b&255;a[f+(g+1)|0]=(h&65535)>>>8&255;p=e>>>8;c[2276075]=p;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}else{gg[c[o+196728+(f<<2)>>2]&4095](i,h);p=e>>>8;c[2276075]=p;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}}function ss(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276085]&c[9104156+((c[2276069]&7|8)<<2)>>2];e=b&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=b&1023;i=(d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0)}else{i=gj[c[f+196688+(g<<2)>>2]&4095](e)|0}e=i&65535;g=c[2276056]|0;f=g&-4;if((f|0)==(c[2276083]|0)){j=g;k=c[2276084]|0}else{c[2276083]=f;h=c[2276085]&f;f=h&16777212;b=c[2112932]|0;l=c[b+((f>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=h&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=g}else{g=gj[c[b+196768+(l<<2)>>2]&4095](f)|0;n=g;o=c[2276056]|0}c[2276084]=n;j=o;k=n}c[2276056]=j+2;n=k>>>((j<<3&16^16)>>>0)<<16>>16&c[2276085];j=n&16777215;k=c[2112932]|0;o=c[k+((j>>>10|16384)<<2)>>2]|0;if(o>>>0>9){g=n&1023;a[o+g|0]=i&255;a[o+(g+1)|0]=(i&65535)>>>8&255;p=e>>>8;c[2276075]=p;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}else{gg[c[k+196728+(o<<2)>>2]&4095](j,i);p=e>>>8;c[2276075]=p;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}}function st(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=c[b>>2]|0;c[b>>2]=e+2;b=c[2276085]&e;e=b&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=b&1023;i=(d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0)}else{i=gj[c[f+196688+(g<<2)>>2]&4095](e)|0}e=i&65535;g=c[2276056]|0;f=g&-4;if((f|0)==(c[2276083]|0)){j=g;k=c[2276084]|0}else{c[2276083]=f;h=c[2276085]&f;f=h&16777212;b=c[2112932]|0;l=c[b+((f>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=h&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=g}else{g=gj[c[b+196768+(l<<2)>>2]&4095](f)|0;n=g;o=c[2276056]|0}c[2276084]=n;j=o;k=n}c[2276056]=j+2;n=k>>>((j<<3&16^16)>>>0)<<16>>16&c[2276085];j=n&16777215;k=c[2112932]|0;o=c[k+((j>>>10|16384)<<2)>>2]|0;if(o>>>0>9){g=n&1023;a[o+g|0]=i&255;a[o+(g+1)|0]=(i&65535)>>>8&255;p=e>>>8;c[2276075]=p;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}else{gg[c[k+196728+(o<<2)>>2]&4095](j,i);p=e>>>8;c[2276075]=p;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}}function su(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=(c[b>>2]|0)-2|0;c[b>>2]=e;b=c[2276085]&e;e=b&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=b&1023;i=(d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0)}else{i=gj[c[f+196688+(g<<2)>>2]&4095](e)|0}e=i&65535;g=c[2276056]|0;f=g&-4;if((f|0)==(c[2276083]|0)){j=g;k=c[2276084]|0}else{c[2276083]=f;h=c[2276085]&f;f=h&16777212;b=c[2112932]|0;l=c[b+((f>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=h&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=g}else{g=gj[c[b+196768+(l<<2)>>2]&4095](f)|0;n=g;o=c[2276056]|0}c[2276084]=n;j=o;k=n}c[2276056]=j+2;n=k>>>((j<<3&16^16)>>>0)<<16>>16&c[2276085];j=n&16777215;k=c[2112932]|0;o=c[k+((j>>>10|16384)<<2)>>2]|0;if(o>>>0>9){g=n&1023;a[o+g|0]=i&255;a[o+(g+1)|0]=(i&65535)>>>8&255;p=e>>>8;c[2276075]=p;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}else{gg[c[k+196728+(o<<2)>>2]&4095](j,i);p=e>>>8;c[2276075]=p;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}}function sv(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}m=g+2|0;c[2276056]=m;n=(h>>>((g<<3&16^16)>>>0)<<16>>16)+b&c[2276085];b=n&16777215;g=c[2112932]|0;h=c[g+(b>>>10<<2)>>2]|0;if(h>>>0>9){e=n&1023;o=(d[h+(e+1)|0]|0)<<8|(d[h+e|0]|0);p=m}else{m=gj[c[g+196688+(h<<2)>>2]&4095](b)|0;o=m;p=c[2276056]|0}m=o&65535;b=p&-4;if((b|0)==(c[2276083]|0)){q=p;r=c[2276084]|0}else{c[2276083]=b;h=c[2276085]&b;b=h&16777212;g=c[2112932]|0;e=c[g+((b>>>10|32768)<<2)>>2]|0;if(e>>>0>9){n=h&1020;s=(d[e+(n|3)|0]|0)<<8|(d[e+(n|2)|0]|0)|((d[e+(n|1)|0]|0)<<8|(d[e+n|0]|0))<<16;t=p}else{p=gj[c[g+196768+(e<<2)>>2]&4095](b)|0;s=p;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;s=r>>>((q<<3&16^16)>>>0)<<16>>16&c[2276085];q=s&16777215;r=c[2112932]|0;t=c[r+((q>>>10|16384)<<2)>>2]|0;if(t>>>0>9){p=s&1023;a[t+p|0]=o&255;a[t+(p+1)|0]=(o&65535)>>>8&255;u=m>>>8;c[2276075]=u;c[2276076]=m;c[2276077]=0;c[2276078]=0;return}else{gg[c[r+196728+(t<<2)>>2]&4095](q,o);u=m>>>8;c[2276075]=u;c[2276076]=m;c[2276077]=0;c[2276078]=0;return}}function sw(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=nB(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;e=c[2276085]&b;b=e&16777215;f=c[2112932]|0;g=c[f+(b>>>10<<2)>>2]|0;if(g>>>0>9){h=e&1023;i=(d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0)}else{i=gj[c[f+196688+(g<<2)>>2]&4095](b)|0}b=i&65535;g=c[2276056]|0;f=g&-4;if((f|0)==(c[2276083]|0)){j=g;k=c[2276084]|0}else{c[2276083]=f;h=c[2276085]&f;f=h&16777212;e=c[2112932]|0;l=c[e+((f>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=h&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=g}else{g=gj[c[e+196768+(l<<2)>>2]&4095](f)|0;n=g;o=c[2276056]|0}c[2276084]=n;j=o;k=n}c[2276056]=j+2;n=k>>>((j<<3&16^16)>>>0)<<16>>16&c[2276085];j=n&16777215;k=c[2112932]|0;o=c[k+((j>>>10|16384)<<2)>>2]|0;if(o>>>0>9){g=n&1023;a[o+g|0]=i&255;a[o+(g+1)|0]=(i&65535)>>>8&255;p=b>>>8;c[2276075]=p;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}else{gg[c[k+196728+(o<<2)>>2]&4095](j,i);p=b>>>8;c[2276075]=p;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}}function sx(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}l=f+2|0;c[2276056]=l;m=g>>>((f<<3&16^16)>>>0)<<16>>16&c[2276085];f=m&16777215;g=c[2112932]|0;b=c[g+(f>>>10<<2)>>2]|0;if(b>>>0>9){e=m&1023;n=(d[b+(e+1)|0]|0)<<8|(d[b+e|0]|0);o=l}else{l=gj[c[g+196688+(b<<2)>>2]&4095](f)|0;n=l;o=c[2276056]|0}l=n&65535;f=o&-4;if((f|0)==(c[2276083]|0)){p=o;q=c[2276084]|0}else{c[2276083]=f;b=c[2276085]&f;f=b&16777212;g=c[2112932]|0;e=c[g+((f>>>10|32768)<<2)>>2]|0;if(e>>>0>9){m=b&1020;r=(d[e+(m|3)|0]|0)<<8|(d[e+(m|2)|0]|0)|((d[e+(m|1)|0]|0)<<8|(d[e+m|0]|0))<<16;s=o}else{o=gj[c[g+196768+(e<<2)>>2]&4095](f)|0;r=o;s=c[2276056]|0}c[2276084]=r;p=s;q=r}c[2276056]=p+2;r=q>>>((p<<3&16^16)>>>0)<<16>>16&c[2276085];p=r&16777215;q=c[2112932]|0;s=c[q+((p>>>10|16384)<<2)>>2]|0;if(s>>>0>9){o=r&1023;a[s+o|0]=n&255;a[s+(o+1)|0]=(n&65535)>>>8&255;t=l>>>8;c[2276075]=t;c[2276076]=l;c[2276077]=0;c[2276078]=0;return}else{gg[c[q+196728+(s<<2)>>2]&4095](p,n);t=l>>>8;c[2276075]=t;c[2276076]=l;c[2276077]=0;c[2276078]=0;return}}function sy(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}t=r+2|0;c[2276056]=t;r=c[2276085]&q;q=r&16777215;h=c[2112932]|0;s=c[h+(q>>>10<<2)>>2]|0;if(s>>>0>9){n=r&1023;u=(d[s+(n+1)|0]|0)<<8|(d[s+n|0]|0);v=t}else{t=gj[c[h+196688+(s<<2)>>2]&4095](q)|0;u=t;v=c[2276056]|0}t=u&65535;q=v&-4;if((q|0)==(c[2276083]|0)){w=v;x=c[2276084]|0}else{c[2276083]=q;s=c[2276085]&q;q=s&16777212;h=c[2112932]|0;n=c[h+((q>>>10|32768)<<2)>>2]|0;if(n>>>0>9){r=s&1020;y=(d[n+(r|3)|0]|0)<<8|(d[n+(r|2)|0]|0)|((d[n+(r|1)|0]|0)<<8|(d[n+r|0]|0))<<16;z=v}else{v=gj[c[h+196768+(n<<2)>>2]&4095](q)|0;y=v;z=c[2276056]|0}c[2276084]=y;w=z;x=y}c[2276056]=w+2;y=x>>>((w<<3&16^16)>>>0)<<16>>16&c[2276085];w=y&16777215;x=c[2112932]|0;z=c[x+((w>>>10|16384)<<2)>>2]|0;if(z>>>0>9){v=y&1023;a[z+v|0]=u&255;a[z+(v+1)|0]=(u&65535)>>>8&255;A=t>>>8;c[2276075]=A;c[2276076]=t;c[2276077]=0;c[2276078]=0;return}else{gg[c[x+196728+(z<<2)>>2]&4095](w,u);A=t>>>8;c[2276075]=A;c[2276076]=t;c[2276077]=0;c[2276078]=0;return}}function sz(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{k=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=k;m=c[2276056]|0}c[2276084]=l;f=m;g=l}l=f+2|0;c[2276056]=l;m=(g>>>((f<<3&16^16)>>>0)<<16>>16)+b|0;b=m&16777215;f=c[2112932]|0;g=c[f+((b>>>10|32768)<<2)>>2]|0;if(g>>>0>9){k=m&1023;n=(d[g+(k+1)|0]|0)<<8|(d[g+k|0]|0);o=l}else{l=gj[c[f+196688+(g<<2)>>2]&4095](b)|0;n=l;o=c[2276056]|0}l=n&65535;b=o&-4;if((b|0)==(c[2276083]|0)){p=o;q=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;f=c[2112932]|0;k=c[f+((b>>>10|32768)<<2)>>2]|0;if(k>>>0>9){m=g&1020;r=(d[k+(m|3)|0]|0)<<8|(d[k+(m|2)|0]|0)|((d[k+(m|1)|0]|0)<<8|(d[k+m|0]|0))<<16;s=o}else{o=gj[c[f+196768+(k<<2)>>2]&4095](b)|0;r=o;s=c[2276056]|0}c[2276084]=r;p=s;q=r}c[2276056]=p+2;r=q>>>((p<<3&16^16)>>>0)<<16>>16&c[2276085];p=r&16777215;q=c[2112932]|0;s=c[q+((p>>>10|16384)<<2)>>2]|0;if(s>>>0>9){o=r&1023;a[s+o|0]=n&255;a[s+(o+1)|0]=(n&65535)>>>8&255;t=l>>>8;c[2276075]=t;c[2276076]=l;c[2276077]=0;c[2276078]=0;return}else{gg[c[q+196728+(s<<2)>>2]&4095](p,n);t=l>>>8;c[2276075]=t;c[2276076]=l;c[2276077]=0;c[2276078]=0;return}}function sA(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=nB(c[2276056]|0)|0;e=b&16777215;f=c[2112932]|0;g=c[f+((e>>>10|32768)<<2)>>2]|0;if(g>>>0>9){h=b&1023;i=(d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0)}else{i=gj[c[f+196688+(g<<2)>>2]&4095](e)|0}e=i&65535;g=c[2276056]|0;f=g&-4;if((f|0)==(c[2276083]|0)){j=g;k=c[2276084]|0}else{c[2276083]=f;h=c[2276085]&f;f=h&16777212;b=c[2112932]|0;l=c[b+((f>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=h&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=g}else{g=gj[c[b+196768+(l<<2)>>2]&4095](f)|0;n=g;o=c[2276056]|0}c[2276084]=n;j=o;k=n}c[2276056]=j+2;n=k>>>((j<<3&16^16)>>>0)<<16>>16&c[2276085];j=n&16777215;k=c[2112932]|0;o=c[k+((j>>>10|16384)<<2)>>2]|0;if(o>>>0>9){g=n&1023;a[o+g|0]=i&255;a[o+(g+1)|0]=(i&65535)>>>8&255;p=e>>>8;c[2276075]=p;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}else{gg[c[k+196728+(o<<2)>>2]&4095](j,i);p=e>>>8;c[2276075]=p;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}}function sB(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0);f=n&65535;o=p&-4;if((o|0)==(h|0)){q=p;r=g}else{c[2276083]=o;g=c[2276085]&o;o=g&16777212;h=c[2112932]|0;e=c[h+((o>>>10|32768)<<2)>>2]|0;if(e>>>0>9){j=g&1020;s=(d[e+(j|3)|0]|0)<<8|(d[e+(j|2)|0]|0)|((d[e+(j|1)|0]|0)<<8|(d[e+j|0]|0))<<16;t=p}else{p=gj[c[h+196768+(e<<2)>>2]&4095](o)|0;s=p;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;s=r>>>((q<<3&16^16)>>>0)<<16>>16&c[2276085];q=n&65535;r=s&16777215;t=c[2112932]|0;p=c[t+((r>>>10|16384)<<2)>>2]|0;if(p>>>0>9){o=s&1023;a[p+o|0]=n&255;a[p+(o+1)|0]=(q&65535)>>>8&255;u=f>>>8;c[2276075]=u;c[2276076]=f;c[2276077]=0;c[2276078]=0;return}else{gg[c[t+196728+(p<<2)>>2]&4095](r,q);u=f>>>8;c[2276075]=u;c[2276076]=f;c[2276077]=0;c[2276078]=0;return}}function sC(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=c[9104156+((c[2276069]&7)<<2)>>2]|0;e=b&65535;f=c[2276056]|0;g=f&-4;if((g|0)==(c[2276083]|0)){h=f;i=g;j=c[2276084]|0}else{c[2276083]=g;k=c[2276085]&g;l=k&16777212;m=c[2112932]|0;n=c[m+((l>>>10|32768)<<2)>>2]|0;if(n>>>0>9){o=k&1020;p=(d[n+(o|3)|0]|0)<<8|(d[n+(o|2)|0]|0)|((d[n+(o|1)|0]|0)<<8|(d[n+o|0]|0))<<16;q=f;r=g}else{g=gj[c[m+196768+(n<<2)>>2]&4095](l)|0;p=g;q=c[2276056]|0;r=c[2276083]|0}c[2276084]=p;h=q;i=r;j=p}p=h+2|0;c[2276056]=p;h=p&-4;if((h|0)==(i|0)){s=j;t=p}else{c[2276083]=h;i=c[2276085]&h;h=i&16777212;r=c[2112932]|0;q=c[r+((h>>>10|32768)<<2)>>2]|0;if(q>>>0>9){g=i&1020;u=(d[q+(g|3)|0]|0)<<8|(d[q+(g|2)|0]|0)|((d[q+(g|1)|0]|0)<<8|(d[q+g|0]|0))<<16;v=p}else{p=gj[c[r+196768+(q<<2)>>2]&4095](h)|0;u=p;v=c[2276056]|0}c[2276084]=u;s=u>>>16|j<<16;t=v}c[2276056]=t+2;t=c[2276085]&s;s=b&65535;v=t&16777215;j=c[2112932]|0;u=c[j+((v>>>10|16384)<<2)>>2]|0;if(u>>>0>9){p=t&1023;a[u+p|0]=b&255;a[u+(p+1)|0]=(s&65535)>>>8&255;w=e>>>8;c[2276075]=w;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}else{gg[c[j+196728+(u<<2)>>2]&4095](v,s);w=e>>>8;c[2276075]=w;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}}function sD(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=b&65535;f=c[2276056]|0;g=f&-4;if((g|0)==(c[2276083]|0)){h=f;i=g;j=c[2276084]|0}else{c[2276083]=g;k=c[2276085]&g;l=k&16777212;m=c[2112932]|0;n=c[m+((l>>>10|32768)<<2)>>2]|0;if(n>>>0>9){o=k&1020;p=(d[n+(o|3)|0]|0)<<8|(d[n+(o|2)|0]|0)|((d[n+(o|1)|0]|0)<<8|(d[n+o|0]|0))<<16;q=f;r=g}else{g=gj[c[m+196768+(n<<2)>>2]&4095](l)|0;p=g;q=c[2276056]|0;r=c[2276083]|0}c[2276084]=p;h=q;i=r;j=p}p=h+2|0;c[2276056]=p;h=p&-4;if((h|0)==(i|0)){s=j;t=p}else{c[2276083]=h;i=c[2276085]&h;h=i&16777212;r=c[2112932]|0;q=c[r+((h>>>10|32768)<<2)>>2]|0;if(q>>>0>9){g=i&1020;u=(d[q+(g|3)|0]|0)<<8|(d[q+(g|2)|0]|0)|((d[q+(g|1)|0]|0)<<8|(d[q+g|0]|0))<<16;v=p}else{p=gj[c[r+196768+(q<<2)>>2]&4095](h)|0;u=p;v=c[2276056]|0}c[2276084]=u;s=u>>>16|j<<16;t=v}c[2276056]=t+2;t=c[2276085]&s;s=b&65535;v=t&16777215;j=c[2112932]|0;u=c[j+((v>>>10|16384)<<2)>>2]|0;if(u>>>0>9){p=t&1023;a[u+p|0]=b&255;a[u+(p+1)|0]=(s&65535)>>>8&255;w=e>>>8;c[2276075]=w;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}else{gg[c[j+196728+(u<<2)>>2]&4095](v,s);w=e>>>8;c[2276075]=w;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}}function sE(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=c[2276085]&c[9104156+((c[2276069]&7|8)<<2)>>2];e=b&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=b&1023;i=(d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0)}else{i=gj[c[f+196688+(g<<2)>>2]&4095](e)|0}e=i&65535;g=c[2276056]|0;f=g&-4;if((f|0)==(c[2276083]|0)){j=g;k=f;l=c[2276084]|0}else{c[2276083]=f;h=c[2276085]&f;b=h&16777212;m=c[2112932]|0;n=c[m+((b>>>10|32768)<<2)>>2]|0;if(n>>>0>9){o=h&1020;p=(d[n+(o|3)|0]|0)<<8|(d[n+(o|2)|0]|0)|((d[n+(o|1)|0]|0)<<8|(d[n+o|0]|0))<<16;q=g;r=f}else{f=gj[c[m+196768+(n<<2)>>2]&4095](b)|0;p=f;q=c[2276056]|0;r=c[2276083]|0}c[2276084]=p;j=q;k=r;l=p}p=j+2|0;c[2276056]=p;j=p&-4;if((j|0)==(k|0)){s=l;t=p}else{c[2276083]=j;k=c[2276085]&j;j=k&16777212;r=c[2112932]|0;q=c[r+((j>>>10|32768)<<2)>>2]|0;if(q>>>0>9){f=k&1020;u=(d[q+(f|3)|0]|0)<<8|(d[q+(f|2)|0]|0)|((d[q+(f|1)|0]|0)<<8|(d[q+f|0]|0))<<16;v=p}else{p=gj[c[r+196768+(q<<2)>>2]&4095](j)|0;u=p;v=c[2276056]|0}c[2276084]=u;s=u>>>16|l<<16;t=v}c[2276056]=t+2;t=c[2276085]&s;s=t&16777215;v=c[2112932]|0;l=c[v+((s>>>10|16384)<<2)>>2]|0;if(l>>>0>9){u=t&1023;a[l+u|0]=i&255;a[l+(u+1)|0]=(i&65535)>>>8&255;w=e>>>8;c[2276075]=w;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}else{gg[c[v+196728+(l<<2)>>2]&4095](s,i);w=e>>>8;c[2276075]=w;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}}function sF(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=c[b>>2]|0;c[b>>2]=e+2;b=c[2276085]&e;e=b&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=b&1023;i=(d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0)}else{i=gj[c[f+196688+(g<<2)>>2]&4095](e)|0}e=i&65535;g=c[2276056]|0;f=g&-4;if((f|0)==(c[2276083]|0)){j=g;k=f;l=c[2276084]|0}else{c[2276083]=f;h=c[2276085]&f;b=h&16777212;m=c[2112932]|0;n=c[m+((b>>>10|32768)<<2)>>2]|0;if(n>>>0>9){o=h&1020;p=(d[n+(o|3)|0]|0)<<8|(d[n+(o|2)|0]|0)|((d[n+(o|1)|0]|0)<<8|(d[n+o|0]|0))<<16;q=g;r=f}else{f=gj[c[m+196768+(n<<2)>>2]&4095](b)|0;p=f;q=c[2276056]|0;r=c[2276083]|0}c[2276084]=p;j=q;k=r;l=p}p=j+2|0;c[2276056]=p;j=p&-4;if((j|0)==(k|0)){s=l;t=p}else{c[2276083]=j;k=c[2276085]&j;j=k&16777212;r=c[2112932]|0;q=c[r+((j>>>10|32768)<<2)>>2]|0;if(q>>>0>9){f=k&1020;u=(d[q+(f|3)|0]|0)<<8|(d[q+(f|2)|0]|0)|((d[q+(f|1)|0]|0)<<8|(d[q+f|0]|0))<<16;v=p}else{p=gj[c[r+196768+(q<<2)>>2]&4095](j)|0;u=p;v=c[2276056]|0}c[2276084]=u;s=u>>>16|l<<16;t=v}c[2276056]=t+2;t=c[2276085]&s;s=t&16777215;v=c[2112932]|0;l=c[v+((s>>>10|16384)<<2)>>2]|0;if(l>>>0>9){u=t&1023;a[l+u|0]=i&255;a[l+(u+1)|0]=(i&65535)>>>8&255;w=e>>>8;c[2276075]=w;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}else{gg[c[v+196728+(l<<2)>>2]&4095](s,i);w=e>>>8;c[2276075]=w;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}}function sG(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=(c[b>>2]|0)-2|0;c[b>>2]=e;b=c[2276085]&e;e=b&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=b&1023;i=(d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0)}else{i=gj[c[f+196688+(g<<2)>>2]&4095](e)|0}e=i&65535;g=c[2276056]|0;f=g&-4;if((f|0)==(c[2276083]|0)){j=g;k=f;l=c[2276084]|0}else{c[2276083]=f;h=c[2276085]&f;b=h&16777212;m=c[2112932]|0;n=c[m+((b>>>10|32768)<<2)>>2]|0;if(n>>>0>9){o=h&1020;p=(d[n+(o|3)|0]|0)<<8|(d[n+(o|2)|0]|0)|((d[n+(o|1)|0]|0)<<8|(d[n+o|0]|0))<<16;q=g;r=f}else{f=gj[c[m+196768+(n<<2)>>2]&4095](b)|0;p=f;q=c[2276056]|0;r=c[2276083]|0}c[2276084]=p;j=q;k=r;l=p}p=j+2|0;c[2276056]=p;j=p&-4;if((j|0)==(k|0)){s=l;t=p}else{c[2276083]=j;k=c[2276085]&j;j=k&16777212;r=c[2112932]|0;q=c[r+((j>>>10|32768)<<2)>>2]|0;if(q>>>0>9){f=k&1020;u=(d[q+(f|3)|0]|0)<<8|(d[q+(f|2)|0]|0)|((d[q+(f|1)|0]|0)<<8|(d[q+f|0]|0))<<16;v=p}else{p=gj[c[r+196768+(q<<2)>>2]&4095](j)|0;u=p;v=c[2276056]|0}c[2276084]=u;s=u>>>16|l<<16;t=v}c[2276056]=t+2;t=c[2276085]&s;s=t&16777215;v=c[2112932]|0;l=c[v+((s>>>10|16384)<<2)>>2]|0;if(l>>>0>9){u=t&1023;a[l+u|0]=i&255;a[l+(u+1)|0]=(i&65535)>>>8&255;w=e>>>8;c[2276075]=w;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}else{gg[c[v+196728+(l<<2)>>2]&4095](s,i);w=e>>>8;c[2276075]=w;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}}function sH(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}m=g+2|0;c[2276056]=m;n=(h>>>((g<<3&16^16)>>>0)<<16>>16)+b&c[2276085];b=n&16777215;g=c[2112932]|0;h=c[g+(b>>>10<<2)>>2]|0;if(h>>>0>9){e=n&1023;o=(d[h+(e+1)|0]|0)<<8|(d[h+e|0]|0);p=m}else{m=gj[c[g+196688+(h<<2)>>2]&4095](b)|0;o=m;p=c[2276056]|0}m=o&65535;b=p&-4;if((b|0)==(c[2276083]|0)){q=p;r=b;s=c[2276084]|0}else{c[2276083]=b;h=c[2276085]&b;g=h&16777212;e=c[2112932]|0;n=c[e+((g>>>10|32768)<<2)>>2]|0;if(n>>>0>9){f=h&1020;t=(d[n+(f|3)|0]|0)<<8|(d[n+(f|2)|0]|0)|((d[n+(f|1)|0]|0)<<8|(d[n+f|0]|0))<<16;u=p;v=b}else{b=gj[c[e+196768+(n<<2)>>2]&4095](g)|0;t=b;u=c[2276056]|0;v=c[2276083]|0}c[2276084]=t;q=u;r=v;s=t}t=q+2|0;c[2276056]=t;q=t&-4;if((q|0)==(r|0)){w=s;x=t}else{c[2276083]=q;r=c[2276085]&q;q=r&16777212;v=c[2112932]|0;u=c[v+((q>>>10|32768)<<2)>>2]|0;if(u>>>0>9){b=r&1020;y=(d[u+(b|3)|0]|0)<<8|(d[u+(b|2)|0]|0)|((d[u+(b|1)|0]|0)<<8|(d[u+b|0]|0))<<16;z=t}else{t=gj[c[v+196768+(u<<2)>>2]&4095](q)|0;y=t;z=c[2276056]|0}c[2276084]=y;w=y>>>16|s<<16;x=z}c[2276056]=x+2;x=c[2276085]&w;w=x&16777215;z=c[2112932]|0;s=c[z+((w>>>10|16384)<<2)>>2]|0;if(s>>>0>9){y=x&1023;a[s+y|0]=o&255;a[s+(y+1)|0]=(o&65535)>>>8&255;A=m>>>8;c[2276075]=A;c[2276076]=m;c[2276077]=0;c[2276078]=0;return}else{gg[c[z+196728+(s<<2)>>2]&4095](w,o);A=m>>>8;c[2276075]=A;c[2276076]=m;c[2276077]=0;c[2276078]=0;return}}function sI(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=nB(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;e=c[2276085]&b;b=e&16777215;f=c[2112932]|0;g=c[f+(b>>>10<<2)>>2]|0;if(g>>>0>9){h=e&1023;i=(d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0)}else{i=gj[c[f+196688+(g<<2)>>2]&4095](b)|0}b=i&65535;g=c[2276056]|0;f=g&-4;if((f|0)==(c[2276083]|0)){j=g;k=f;l=c[2276084]|0}else{c[2276083]=f;h=c[2276085]&f;e=h&16777212;m=c[2112932]|0;n=c[m+((e>>>10|32768)<<2)>>2]|0;if(n>>>0>9){o=h&1020;p=(d[n+(o|3)|0]|0)<<8|(d[n+(o|2)|0]|0)|((d[n+(o|1)|0]|0)<<8|(d[n+o|0]|0))<<16;q=g;r=f}else{f=gj[c[m+196768+(n<<2)>>2]&4095](e)|0;p=f;q=c[2276056]|0;r=c[2276083]|0}c[2276084]=p;j=q;k=r;l=p}p=j+2|0;c[2276056]=p;j=p&-4;if((j|0)==(k|0)){s=l;t=p}else{c[2276083]=j;k=c[2276085]&j;j=k&16777212;r=c[2112932]|0;q=c[r+((j>>>10|32768)<<2)>>2]|0;if(q>>>0>9){f=k&1020;u=(d[q+(f|3)|0]|0)<<8|(d[q+(f|2)|0]|0)|((d[q+(f|1)|0]|0)<<8|(d[q+f|0]|0))<<16;v=p}else{p=gj[c[r+196768+(q<<2)>>2]&4095](j)|0;u=p;v=c[2276056]|0}c[2276084]=u;s=u>>>16|l<<16;t=v}c[2276056]=t+2;t=c[2276085]&s;s=t&16777215;v=c[2112932]|0;l=c[v+((s>>>10|16384)<<2)>>2]|0;if(l>>>0>9){u=t&1023;a[l+u|0]=i&255;a[l+(u+1)|0]=(i&65535)>>>8&255;w=b>>>8;c[2276075]=w;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}else{gg[c[v+196728+(l<<2)>>2]&4095](s,i);w=b>>>8;c[2276075]=w;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}}function sJ(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}l=f+2|0;c[2276056]=l;m=g>>>((f<<3&16^16)>>>0)<<16>>16&c[2276085];f=m&16777215;g=c[2112932]|0;b=c[g+(f>>>10<<2)>>2]|0;if(b>>>0>9){e=m&1023;n=(d[b+(e+1)|0]|0)<<8|(d[b+e|0]|0);o=l}else{l=gj[c[g+196688+(b<<2)>>2]&4095](f)|0;n=l;o=c[2276056]|0}l=n&65535;f=o&-4;if((f|0)==(c[2276083]|0)){p=o;q=f;r=c[2276084]|0}else{c[2276083]=f;b=c[2276085]&f;g=b&16777212;e=c[2112932]|0;m=c[e+((g>>>10|32768)<<2)>>2]|0;if(m>>>0>9){j=b&1020;s=(d[m+(j|3)|0]|0)<<8|(d[m+(j|2)|0]|0)|((d[m+(j|1)|0]|0)<<8|(d[m+j|0]|0))<<16;t=o;u=f}else{f=gj[c[e+196768+(m<<2)>>2]&4095](g)|0;s=f;t=c[2276056]|0;u=c[2276083]|0}c[2276084]=s;p=t;q=u;r=s}s=p+2|0;c[2276056]=s;p=s&-4;if((p|0)==(q|0)){v=r;w=s}else{c[2276083]=p;q=c[2276085]&p;p=q&16777212;u=c[2112932]|0;t=c[u+((p>>>10|32768)<<2)>>2]|0;if(t>>>0>9){f=q&1020;x=(d[t+(f|3)|0]|0)<<8|(d[t+(f|2)|0]|0)|((d[t+(f|1)|0]|0)<<8|(d[t+f|0]|0))<<16;y=s}else{s=gj[c[u+196768+(t<<2)>>2]&4095](p)|0;x=s;y=c[2276056]|0}c[2276084]=x;v=x>>>16|r<<16;w=y}c[2276056]=w+2;w=c[2276085]&v;v=w&16777215;y=c[2112932]|0;r=c[y+((v>>>10|16384)<<2)>>2]|0;if(r>>>0>9){x=w&1023;a[r+x|0]=n&255;a[r+(x+1)|0]=(n&65535)>>>8&255;z=l>>>8;c[2276075]=z;c[2276076]=l;c[2276077]=0;c[2276078]=0;return}else{gg[c[y+196728+(r<<2)>>2]&4095](v,n);z=l>>>8;c[2276075]=z;c[2276076]=l;c[2276077]=0;c[2276078]=0;return}}function sK(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}t=r+2|0;c[2276056]=t;r=c[2276085]&q;q=r&16777215;h=c[2112932]|0;s=c[h+(q>>>10<<2)>>2]|0;if(s>>>0>9){n=r&1023;u=(d[s+(n+1)|0]|0)<<8|(d[s+n|0]|0);v=t}else{t=gj[c[h+196688+(s<<2)>>2]&4095](q)|0;u=t;v=c[2276056]|0}t=u&65535;q=v&-4;if((q|0)==(c[2276083]|0)){w=v;x=q;y=c[2276084]|0}else{c[2276083]=q;s=c[2276085]&q;h=s&16777212;n=c[2112932]|0;r=c[n+((h>>>10|32768)<<2)>>2]|0;if(r>>>0>9){f=s&1020;z=(d[r+(f|3)|0]|0)<<8|(d[r+(f|2)|0]|0)|((d[r+(f|1)|0]|0)<<8|(d[r+f|0]|0))<<16;A=v;B=q}else{q=gj[c[n+196768+(r<<2)>>2]&4095](h)|0;z=q;A=c[2276056]|0;B=c[2276083]|0}c[2276084]=z;w=A;x=B;y=z}z=w+2|0;c[2276056]=z;w=z&-4;if((w|0)==(x|0)){C=y;D=z}else{c[2276083]=w;x=c[2276085]&w;w=x&16777212;B=c[2112932]|0;A=c[B+((w>>>10|32768)<<2)>>2]|0;if(A>>>0>9){q=x&1020;E=(d[A+(q|3)|0]|0)<<8|(d[A+(q|2)|0]|0)|((d[A+(q|1)|0]|0)<<8|(d[A+q|0]|0))<<16;F=z}else{z=gj[c[B+196768+(A<<2)>>2]&4095](w)|0;E=z;F=c[2276056]|0}c[2276084]=E;C=E>>>16|y<<16;D=F}c[2276056]=D+2;D=c[2276085]&C;C=D&16777215;F=c[2112932]|0;y=c[F+((C>>>10|16384)<<2)>>2]|0;if(y>>>0>9){E=D&1023;a[y+E|0]=u&255;a[y+(E+1)|0]=(u&65535)>>>8&255;G=t>>>8;c[2276075]=G;c[2276076]=t;c[2276077]=0;c[2276078]=0;return}else{gg[c[F+196728+(y<<2)>>2]&4095](C,u);G=t>>>8;c[2276075]=G;c[2276076]=t;c[2276077]=0;c[2276078]=0;return}}function sL(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{k=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=k;m=c[2276056]|0}c[2276084]=l;f=m;g=l}l=f+2|0;c[2276056]=l;m=(g>>>((f<<3&16^16)>>>0)<<16>>16)+b|0;b=m&16777215;f=c[2112932]|0;g=c[f+((b>>>10|32768)<<2)>>2]|0;if(g>>>0>9){k=m&1023;n=(d[g+(k+1)|0]|0)<<8|(d[g+k|0]|0);o=l}else{l=gj[c[f+196688+(g<<2)>>2]&4095](b)|0;n=l;o=c[2276056]|0}l=n&65535;b=o&-4;if((b|0)==(c[2276083]|0)){p=o;q=b;r=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;f=g&16777212;k=c[2112932]|0;m=c[k+((f>>>10|32768)<<2)>>2]|0;if(m>>>0>9){e=g&1020;s=(d[m+(e|3)|0]|0)<<8|(d[m+(e|2)|0]|0)|((d[m+(e|1)|0]|0)<<8|(d[m+e|0]|0))<<16;t=o;u=b}else{b=gj[c[k+196768+(m<<2)>>2]&4095](f)|0;s=b;t=c[2276056]|0;u=c[2276083]|0}c[2276084]=s;p=t;q=u;r=s}s=p+2|0;c[2276056]=s;p=s&-4;if((p|0)==(q|0)){v=r;w=s}else{c[2276083]=p;q=c[2276085]&p;p=q&16777212;u=c[2112932]|0;t=c[u+((p>>>10|32768)<<2)>>2]|0;if(t>>>0>9){b=q&1020;x=(d[t+(b|3)|0]|0)<<8|(d[t+(b|2)|0]|0)|((d[t+(b|1)|0]|0)<<8|(d[t+b|0]|0))<<16;y=s}else{s=gj[c[u+196768+(t<<2)>>2]&4095](p)|0;x=s;y=c[2276056]|0}c[2276084]=x;v=x>>>16|r<<16;w=y}c[2276056]=w+2;w=c[2276085]&v;v=w&16777215;y=c[2112932]|0;r=c[y+((v>>>10|16384)<<2)>>2]|0;if(r>>>0>9){x=w&1023;a[r+x|0]=n&255;a[r+(x+1)|0]=(n&65535)>>>8&255;z=l>>>8;c[2276075]=z;c[2276076]=l;c[2276077]=0;c[2276078]=0;return}else{gg[c[y+196728+(r<<2)>>2]&4095](v,n);z=l>>>8;c[2276075]=z;c[2276076]=l;c[2276077]=0;c[2276078]=0;return}}function sM(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=nB(c[2276056]|0)|0;e=b&16777215;f=c[2112932]|0;g=c[f+((e>>>10|32768)<<2)>>2]|0;if(g>>>0>9){h=b&1023;i=(d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0)}else{i=gj[c[f+196688+(g<<2)>>2]&4095](e)|0}e=i&65535;g=c[2276056]|0;f=g&-4;if((f|0)==(c[2276083]|0)){j=g;k=f;l=c[2276084]|0}else{c[2276083]=f;h=c[2276085]&f;b=h&16777212;m=c[2112932]|0;n=c[m+((b>>>10|32768)<<2)>>2]|0;if(n>>>0>9){o=h&1020;p=(d[n+(o|3)|0]|0)<<8|(d[n+(o|2)|0]|0)|((d[n+(o|1)|0]|0)<<8|(d[n+o|0]|0))<<16;q=g;r=f}else{f=gj[c[m+196768+(n<<2)>>2]&4095](b)|0;p=f;q=c[2276056]|0;r=c[2276083]|0}c[2276084]=p;j=q;k=r;l=p}p=j+2|0;c[2276056]=p;j=p&-4;if((j|0)==(k|0)){s=l;t=p}else{c[2276083]=j;k=c[2276085]&j;j=k&16777212;r=c[2112932]|0;q=c[r+((j>>>10|32768)<<2)>>2]|0;if(q>>>0>9){f=k&1020;u=(d[q+(f|3)|0]|0)<<8|(d[q+(f|2)|0]|0)|((d[q+(f|1)|0]|0)<<8|(d[q+f|0]|0))<<16;v=p}else{p=gj[c[r+196768+(q<<2)>>2]&4095](j)|0;u=p;v=c[2276056]|0}c[2276084]=u;s=u>>>16|l<<16;t=v}c[2276056]=t+2;t=c[2276085]&s;s=t&16777215;v=c[2112932]|0;l=c[v+((s>>>10|16384)<<2)>>2]|0;if(l>>>0>9){u=t&1023;a[l+u|0]=i&255;a[l+(u+1)|0]=(i&65535)>>>8&255;w=e>>>8;c[2276075]=w;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}else{gg[c[v+196728+(l<<2)>>2]&4095](s,i);w=e>>>8;c[2276075]=w;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}}function sN(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0);f=n&65535;o=p&-4;if((o|0)==(h|0)){q=p;r=h;s=g}else{c[2276083]=o;g=c[2276085]&o;h=g&16777212;e=c[2112932]|0;j=c[e+((h>>>10|32768)<<2)>>2]|0;if(j>>>0>9){l=g&1020;t=(d[j+(l|3)|0]|0)<<8|(d[j+(l|2)|0]|0)|((d[j+(l|1)|0]|0)<<8|(d[j+l|0]|0))<<16;u=p;v=o}else{o=gj[c[e+196768+(j<<2)>>2]&4095](h)|0;t=o;u=c[2276056]|0;v=c[2276083]|0}c[2276084]=t;q=u;r=v;s=t}t=q+2|0;c[2276056]=t;q=t&-4;if((q|0)==(r|0)){w=s;x=t}else{c[2276083]=q;r=c[2276085]&q;q=r&16777212;v=c[2112932]|0;u=c[v+((q>>>10|32768)<<2)>>2]|0;if(u>>>0>9){o=r&1020;y=(d[u+(o|3)|0]|0)<<8|(d[u+(o|2)|0]|0)|((d[u+(o|1)|0]|0)<<8|(d[u+o|0]|0))<<16;z=t}else{t=gj[c[v+196768+(u<<2)>>2]&4095](q)|0;y=t;z=c[2276056]|0}c[2276084]=y;w=y>>>16|s<<16;x=z}c[2276056]=x+2;x=c[2276085]&w;w=n&65535;z=x&16777215;s=c[2112932]|0;y=c[s+((z>>>10|16384)<<2)>>2]|0;if(y>>>0>9){t=x&1023;a[y+t|0]=n&255;a[y+(t+1)|0]=(w&65535)>>>8&255;A=f>>>8;c[2276075]=A;c[2276076]=f;c[2276077]=0;c[2276078]=0;return}else{gg[c[s+196728+(y<<2)>>2]&4095](z,w);A=f>>>8;c[2276075]=A;c[2276076]=f;c[2276077]=0;c[2276078]=0;return}}function sO(){var a=0,b=0;a=c[2276069]|0;b=c[9104156+((a&7)<<2)>>2]|0;c[9104156+((a>>>9&7)<<2)>>2]=b;c[2276075]=b>>>24;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}function sP(){var a=0,b=0;a=c[2276069]|0;b=c[9104156+((a&7|8)<<2)>>2]|0;c[9104156+((a>>>9&7)<<2)>>2]=b;c[2276075]=b>>>24;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}function sQ(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0;a=c[2276069]|0;b=c[2276085]&c[9104156+((a&7|8)<<2)>>2];e=b&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=b&1023;i=(d[g+(h+3)|0]|0)<<8|(d[g+(h+2)|0]|0)|((d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0))<<16;j=a}else{a=gj[c[f+196768+(g<<2)>>2]&4095](e)|0;i=a;j=c[2276069]|0}c[9104156+((j>>>9&7)<<2)>>2]=i;c[2276075]=i>>>24;c[2276076]=i;c[2276077]=0;c[2276078]=0;return}function sR(){var a=0,b=0,e=0,f=0,g=0,h=0;a=9104156+((c[2276069]&7|8)<<2)|0;b=c[a>>2]|0;c[a>>2]=b+4;a=c[2276085]&b;b=a&16777215;e=c[2112932]|0;f=c[e+(b>>>10<<2)>>2]|0;if(f>>>0>9){g=a&1023;h=(d[f+(g+3)|0]|0)<<8|(d[f+(g+2)|0]|0)|((d[f+(g+1)|0]|0)<<8|(d[f+g|0]|0))<<16}else{h=gj[c[e+196768+(f<<2)>>2]&4095](b)|0}c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]=h;c[2276075]=h>>>24;c[2276076]=h;c[2276077]=0;c[2276078]=0;return}function sS(){var a=0,b=0,e=0,f=0,g=0,h=0;a=9104156+((c[2276069]&7|8)<<2)|0;b=(c[a>>2]|0)-4|0;c[a>>2]=b;a=c[2276085]&b;b=a&16777215;e=c[2112932]|0;f=c[e+(b>>>10<<2)>>2]|0;if(f>>>0>9){g=a&1023;h=(d[f+(g+3)|0]|0)<<8|(d[f+(g+2)|0]|0)|((d[f+(g+1)|0]|0)<<8|(d[f+g|0]|0))<<16}else{h=gj[c[e+196768+(f<<2)>>2]&4095](b)|0}c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]=h;c[2276075]=h>>>24;c[2276076]=h;c[2276077]=0;c[2276078]=0;return}function sT(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;a=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=(g>>>((f<<3&16^16)>>>0)<<16>>16)+a&c[2276085];a=l&16777215;f=c[2112932]|0;g=c[f+(a>>>10<<2)>>2]|0;if(g>>>0>9){m=l&1023;n=(d[g+(m+3)|0]|0)<<8|(d[g+(m+2)|0]|0)|((d[g+(m+1)|0]|0)<<8|(d[g+m|0]|0))<<16;o=c[2276069]|0;p=o>>>9;q=p&7;r=9104156+(q<<2)|0;c[r>>2]=n;s=n>>>24;c[2276075]=s;c[2276076]=n;c[2276077]=0;c[2276078]=0;return}else{n=gj[c[f+196768+(g<<2)>>2]&4095](a)|0;o=c[2276069]|0;p=o>>>9;q=p&7;r=9104156+(q<<2)|0;c[r>>2]=n;s=n>>>24;c[2276075]=s;c[2276076]=n;c[2276077]=0;c[2276078]=0;return}}function sU(){var a=0,b=0,e=0,f=0,g=0,h=0;a=nB(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;b=c[2276085]&a;a=b&16777215;e=c[2112932]|0;f=c[e+(a>>>10<<2)>>2]|0;if(f>>>0>9){g=b&1023;h=(d[f+(g+3)|0]|0)<<8|(d[f+(g+2)|0]|0)|((d[f+(g+1)|0]|0)<<8|(d[f+g|0]|0))<<16}else{h=gj[c[e+196768+(f<<2)>>2]&4095](a)|0}c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]=h;c[2276075]=h>>>24;c[2276076]=h;c[2276077]=0;c[2276078]=0;return}function sV(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=f>>>((e<<3&16^16)>>>0)<<16>>16&c[2276085];e=k&16777215;f=c[2112932]|0;l=c[f+(e>>>10<<2)>>2]|0;if(l>>>0>9){a=k&1023;m=(d[l+(a+3)|0]|0)<<8|(d[l+(a+2)|0]|0)|((d[l+(a+1)|0]|0)<<8|(d[l+a|0]|0))<<16;n=c[2276069]|0;o=n>>>9;p=o&7;q=9104156+(p<<2)|0;c[q>>2]=m;r=m>>>24;c[2276075]=r;c[2276076]=m;c[2276077]=0;c[2276078]=0;return}else{m=gj[c[f+196768+(l<<2)>>2]&4095](e)|0;n=c[2276069]|0;o=n>>>9;p=o&7;q=9104156+(p<<2)|0;c[q>>2]=m;r=m>>>24;c[2276075]=r;c[2276076]=m;c[2276077]=0;c[2276078]=0;return}}function sW(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=b;g=c[2276084]|0}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=o;g=m}m=e+2|0;c[2276056]=m;e=m&-4;if((e|0)==(f|0)){p=g;q=m}else{c[2276083]=e;f=c[2276085]&e;e=f&16777212;o=c[2112932]|0;n=c[o+((e>>>10|32768)<<2)>>2]|0;if(n>>>0>9){b=f&1020;r=(d[n+(b|3)|0]|0)<<8|(d[n+(b|2)|0]|0)|((d[n+(b|1)|0]|0)<<8|(d[n+b|0]|0))<<16;s=m}else{m=gj[c[o+196768+(n<<2)>>2]&4095](e)|0;r=m;s=c[2276056]|0}c[2276084]=r;p=r>>>16|g<<16;q=s}c[2276056]=q+2;q=c[2276085]&p;p=q&16777215;s=c[2112932]|0;g=c[s+(p>>>10<<2)>>2]|0;if(g>>>0>9){r=q&1023;t=(d[g+(r+3)|0]|0)<<8|(d[g+(r+2)|0]|0)|((d[g+(r+1)|0]|0)<<8|(d[g+r|0]|0))<<16;u=c[2276069]|0;v=u>>>9;w=v&7;x=9104156+(w<<2)|0;c[x>>2]=t;y=t>>>24;c[2276075]=y;c[2276076]=t;c[2276077]=0;c[2276078]=0;return}else{t=gj[c[s+196768+(g<<2)>>2]&4095](p)|0;u=c[2276069]|0;v=u>>>9;w=v&7;x=9104156+(w<<2)|0;c[x>>2]=t;y=t>>>24;c[2276075]=y;c[2276076]=t;c[2276077]=0;c[2276078]=0;return}}function sX(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{j=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=j;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=(f>>>((e<<3&16^16)>>>0)<<16>>16)+a|0;a=k&16777215;e=c[2112932]|0;f=c[e+((a>>>10|32768)<<2)>>2]|0;if(f>>>0>9){l=k&1023;m=(d[f+(l+3)|0]|0)<<8|(d[f+(l+2)|0]|0)|((d[f+(l+1)|0]|0)<<8|(d[f+l|0]|0))<<16;n=c[2276069]|0;o=n>>>9;p=o&7;q=9104156+(p<<2)|0;c[q>>2]=m;r=m>>>24;c[2276075]=r;c[2276076]=m;c[2276077]=0;c[2276078]=0;return}else{m=gj[c[e+196768+(f<<2)>>2]&4095](a)|0;n=c[2276069]|0;o=n>>>9;p=o&7;q=9104156+(p<<2)|0;c[q>>2]=m;r=m>>>24;c[2276075]=r;c[2276076]=m;c[2276077]=0;c[2276078]=0;return}}function sY(){var a=0,b=0,e=0,f=0,g=0,h=0;a=nB(c[2276056]|0)|0;b=a&16777215;e=c[2112932]|0;f=c[e+((b>>>10|32768)<<2)>>2]|0;if(f>>>0>9){g=a&1023;h=(d[f+(g+3)|0]|0)<<8|(d[f+(g+2)|0]|0)|((d[f+(g+1)|0]|0)<<8|(d[f+g|0]|0))<<16}else{h=gj[c[e+196768+(f<<2)>>2]&4095](b)|0}c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]=h;c[2276075]=h>>>24;c[2276076]=h;c[2276077]=0;c[2276078]=0;return}function sZ(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=b;g=c[2276084]|0}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=o;g=m}m=e+2|0;c[2276056]=m;e=m&-4;if((e|0)==(f|0)){p=g;q=m;r=q+2|0;c[2276056]=r;s=c[2276069]|0;t=s>>>9;u=t&7;v=9104156+(u<<2)|0;c[v>>2]=p;w=p>>>24;c[2276075]=w;c[2276076]=p;c[2276077]=0;c[2276078]=0;return}c[2276083]=e;f=c[2276085]&e;e=f&16777212;o=c[2112932]|0;n=c[o+((e>>>10|32768)<<2)>>2]|0;if(n>>>0>9){b=f&1020;x=(d[n+(b|3)|0]|0)<<8|(d[n+(b|2)|0]|0)|((d[n+(b|1)|0]|0)<<8|(d[n+b|0]|0))<<16;y=m}else{m=gj[c[o+196768+(n<<2)>>2]&4095](e)|0;x=m;y=c[2276056]|0}c[2276084]=x;p=x>>>16|g<<16;q=y;r=q+2|0;c[2276056]=r;s=c[2276069]|0;t=s>>>9;u=t&7;v=9104156+(u<<2)|0;c[v>>2]=p;w=p>>>24;c[2276075]=w;c[2276076]=p;c[2276077]=0;c[2276078]=0;return}function s_(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=c[2276069]|0;d=c[9104156+((b&7)<<2)>>2]|0;e=c[2276085]&c[9104156+((b>>>9&7|8)<<2)>>2];b=e&16777215;f=c[2112932]|0;g=c[f+((b>>>10|16384)<<2)>>2]|0;if(g>>>0>9){h=e&1023;a[g+h|0]=d>>>16&255;e=d>>>24;a[g+(h+1)|0]=e&255;a[g+(h+2)|0]=d&255;a[g+(h+3)|0]=d>>>8&255;i=e;c[2276075]=i;c[2276076]=d;c[2276077]=0;c[2276078]=0;return}else{gg[c[f+196808+(g<<2)>>2]&4095](b,d);i=d>>>24;c[2276075]=i;c[2276076]=d;c[2276077]=0;c[2276078]=0;return}}function s$(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=c[2276069]|0;d=c[9104156+((b&7|8)<<2)>>2]|0;e=c[2276085]&c[9104156+((b>>>9&7|8)<<2)>>2];b=e&16777215;f=c[2112932]|0;g=c[f+((b>>>10|16384)<<2)>>2]|0;if(g>>>0>9){h=e&1023;a[g+h|0]=d>>>16&255;e=d>>>24;a[g+(h+1)|0]=e&255;a[g+(h+2)|0]=d&255;a[g+(h+3)|0]=d>>>8&255;i=e;c[2276075]=i;c[2276076]=d;c[2276077]=0;c[2276078]=0;return}else{gg[c[f+196808+(g<<2)>>2]&4095](b,d);i=d>>>24;c[2276075]=i;c[2276076]=d;c[2276077]=0;c[2276078]=0;return}}function s0(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=c[2276069]|0;e=c[2276085]|0;f=e&c[9104156+((b&7|8)<<2)>>2];g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=f&1023;k=(d[i+(j+3)|0]|0)<<8|(d[i+(j+2)|0]|0)|((d[i+(j+1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=b;m=e;n=h}else{e=gj[c[h+196768+(i<<2)>>2]&4095](g)|0;k=e;l=c[2276069]|0;m=c[2276085]|0;n=c[2112932]|0}e=m&c[9104156+((l>>>9&7|8)<<2)>>2];l=e&16777215;m=c[n+((l>>>10|16384)<<2)>>2]|0;if(m>>>0>9){g=e&1023;a[m+g|0]=k>>>16&255;e=k>>>24;a[m+(g+1)|0]=e&255;a[m+(g+2)|0]=k&255;a[m+(g+3)|0]=k>>>8&255;o=e;c[2276075]=o;c[2276076]=k;c[2276077]=0;c[2276078]=0;return}else{gg[c[n+196808+(m<<2)>>2]&4095](l,k);o=k>>>24;c[2276075]=o;c[2276076]=k;c[2276077]=0;c[2276078]=0;return}}function s1(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=c[b>>2]|0;c[b>>2]=e+4;b=c[2276085]|0;f=b&e;e=f&16777215;g=c[2112932]|0;h=c[g+(e>>>10<<2)>>2]|0;if(h>>>0>9){i=f&1023;j=(d[h+(i+3)|0]|0)<<8|(d[h+(i+2)|0]|0)|((d[h+(i+1)|0]|0)<<8|(d[h+i|0]|0))<<16;k=b;l=g}else{b=gj[c[g+196768+(h<<2)>>2]&4095](e)|0;j=b;k=c[2276085]|0;l=c[2112932]|0}b=k&c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2];k=b&16777215;e=c[l+((k>>>10|16384)<<2)>>2]|0;if(e>>>0>9){h=b&1023;a[e+h|0]=j>>>16&255;b=j>>>24;a[e+(h+1)|0]=b&255;a[e+(h+2)|0]=j&255;a[e+(h+3)|0]=j>>>8&255;m=b;c[2276075]=m;c[2276076]=j;c[2276077]=0;c[2276078]=0;return}else{gg[c[l+196808+(e<<2)>>2]&4095](k,j);m=j>>>24;c[2276075]=m;c[2276076]=j;c[2276077]=0;c[2276078]=0;return}}function s2(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=(c[b>>2]|0)-4|0;c[b>>2]=e;b=c[2276085]|0;f=b&e;e=f&16777215;g=c[2112932]|0;h=c[g+(e>>>10<<2)>>2]|0;if(h>>>0>9){i=f&1023;j=(d[h+(i+3)|0]|0)<<8|(d[h+(i+2)|0]|0)|((d[h+(i+1)|0]|0)<<8|(d[h+i|0]|0))<<16;k=b;l=g}else{b=gj[c[g+196768+(h<<2)>>2]&4095](e)|0;j=b;k=c[2276085]|0;l=c[2112932]|0}b=k&c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2];k=b&16777215;e=c[l+((k>>>10|16384)<<2)>>2]|0;if(e>>>0>9){h=b&1023;a[e+h|0]=j>>>16&255;b=j>>>24;a[e+(h+1)|0]=b&255;a[e+(h+2)|0]=j&255;a[e+(h+3)|0]=j>>>8&255;m=b;c[2276075]=m;c[2276076]=j;c[2276077]=0;c[2276078]=0;return}else{gg[c[l+196808+(e<<2)>>2]&4095](k,j);m=j>>>24;c[2276075]=m;c[2276076]=j;c[2276077]=0;c[2276078]=0;return}}function s3(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=c[2276085]|0;n=(h>>>((g<<3&16^16)>>>0)<<16>>16)+b&m;b=n&16777215;g=c[2112932]|0;h=c[g+(b>>>10<<2)>>2]|0;if(h>>>0>9){e=n&1023;o=(d[h+(e+3)|0]|0)<<8|(d[h+(e+2)|0]|0)|((d[h+(e+1)|0]|0)<<8|(d[h+e|0]|0))<<16;p=m;q=g}else{m=gj[c[g+196768+(h<<2)>>2]&4095](b)|0;o=m;p=c[2276085]|0;q=c[2112932]|0}m=p&c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2];p=m&16777215;b=c[q+((p>>>10|16384)<<2)>>2]|0;if(b>>>0>9){h=m&1023;a[b+h|0]=o>>>16&255;m=o>>>24;a[b+(h+1)|0]=m&255;a[b+(h+2)|0]=o&255;a[b+(h+3)|0]=o>>>8&255;r=m;c[2276075]=r;c[2276076]=o;c[2276077]=0;c[2276078]=0;return}else{gg[c[q+196808+(b<<2)>>2]&4095](p,o);r=o>>>24;c[2276075]=r;c[2276076]=o;c[2276077]=0;c[2276078]=0;return}}function s4(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=nB(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;e=c[2276085]|0;f=e&b;b=f&16777215;g=c[2112932]|0;h=c[g+(b>>>10<<2)>>2]|0;if(h>>>0>9){i=f&1023;j=(d[h+(i+3)|0]|0)<<8|(d[h+(i+2)|0]|0)|((d[h+(i+1)|0]|0)<<8|(d[h+i|0]|0))<<16;k=e;l=g}else{e=gj[c[g+196768+(h<<2)>>2]&4095](b)|0;j=e;k=c[2276085]|0;l=c[2112932]|0}e=k&c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2];k=e&16777215;b=c[l+((k>>>10|16384)<<2)>>2]|0;if(b>>>0>9){h=e&1023;a[b+h|0]=j>>>16&255;e=j>>>24;a[b+(h+1)|0]=e&255;a[b+(h+2)|0]=j&255;a[b+(h+3)|0]=j>>>8&255;m=e;c[2276075]=m;c[2276076]=j;c[2276077]=0;c[2276078]=0;return}else{gg[c[l+196808+(b<<2)>>2]&4095](k,j);m=j>>>24;c[2276075]=m;c[2276076]=j;c[2276077]=0;c[2276078]=0;return}}function s5(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=c[2276085]|0;m=g>>>((f<<3&16^16)>>>0)<<16>>16&l;f=m&16777215;g=c[2112932]|0;b=c[g+(f>>>10<<2)>>2]|0;if(b>>>0>9){e=m&1023;n=(d[b+(e+3)|0]|0)<<8|(d[b+(e+2)|0]|0)|((d[b+(e+1)|0]|0)<<8|(d[b+e|0]|0))<<16;o=l;p=g}else{l=gj[c[g+196768+(b<<2)>>2]&4095](f)|0;n=l;o=c[2276085]|0;p=c[2112932]|0}l=o&c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2];o=l&16777215;f=c[p+((o>>>10|16384)<<2)>>2]|0;if(f>>>0>9){b=l&1023;a[f+b|0]=n>>>16&255;l=n>>>24;a[f+(b+1)|0]=l&255;a[f+(b+2)|0]=n&255;a[f+(b+3)|0]=n>>>8&255;q=l;c[2276075]=q;c[2276076]=n;c[2276077]=0;c[2276078]=0;return}else{gg[c[p+196808+(f<<2)>>2]&4095](o,n);q=n>>>24;c[2276075]=q;c[2276076]=n;c[2276077]=0;c[2276078]=0;return}}function s6(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[2276085]|0;t=r&q;q=t&16777215;h=c[2112932]|0;s=c[h+(q>>>10<<2)>>2]|0;if(s>>>0>9){n=t&1023;u=(d[s+(n+3)|0]|0)<<8|(d[s+(n+2)|0]|0)|((d[s+(n+1)|0]|0)<<8|(d[s+n|0]|0))<<16;v=r;w=h}else{r=gj[c[h+196768+(s<<2)>>2]&4095](q)|0;u=r;v=c[2276085]|0;w=c[2112932]|0}r=v&c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2];v=r&16777215;q=c[w+((v>>>10|16384)<<2)>>2]|0;if(q>>>0>9){s=r&1023;a[q+s|0]=u>>>16&255;r=u>>>24;a[q+(s+1)|0]=r&255;a[q+(s+2)|0]=u&255;a[q+(s+3)|0]=u>>>8&255;x=r;c[2276075]=x;c[2276076]=u;c[2276077]=0;c[2276078]=0;return}else{gg[c[w+196808+(q<<2)>>2]&4095](v,u);x=u>>>24;c[2276075]=x;c[2276076]=u;c[2276077]=0;c[2276078]=0;return}}function s7(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{k=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=k;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=(g>>>((f<<3&16^16)>>>0)<<16>>16)+b|0;b=l&16777215;f=c[2112932]|0;g=c[f+((b>>>10|32768)<<2)>>2]|0;if(g>>>0>9){m=l&1023;n=(d[g+(m+3)|0]|0)<<8|(d[g+(m+2)|0]|0)|((d[g+(m+1)|0]|0)<<8|(d[g+m|0]|0))<<16;o=f}else{m=gj[c[f+196768+(g<<2)>>2]&4095](b)|0;n=m;o=c[2112932]|0}m=c[2276085]&c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2];b=m&16777215;g=c[o+((b>>>10|16384)<<2)>>2]|0;if(g>>>0>9){f=m&1023;a[g+f|0]=n>>>16&255;m=n>>>24;a[g+(f+1)|0]=m&255;a[g+(f+2)|0]=n&255;a[g+(f+3)|0]=n>>>8&255;p=m;c[2276075]=p;c[2276076]=n;c[2276077]=0;c[2276078]=0;return}else{gg[c[o+196808+(g<<2)>>2]&4095](b,n);p=n>>>24;c[2276075]=p;c[2276076]=n;c[2276077]=0;c[2276078]=0;return}}function s8(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=nB(c[2276056]|0)|0;e=b&16777215;f=c[2112932]|0;g=c[f+((e>>>10|32768)<<2)>>2]|0;if(g>>>0>9){h=b&1023;i=(d[g+(h+3)|0]|0)<<8|(d[g+(h+2)|0]|0)|((d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0))<<16;j=f}else{h=gj[c[f+196768+(g<<2)>>2]&4095](e)|0;i=h;j=c[2112932]|0}h=c[2276085]&c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2];e=h&16777215;g=c[j+((e>>>10|16384)<<2)>>2]|0;if(g>>>0>9){f=h&1023;a[g+f|0]=i>>>16&255;h=i>>>24;a[g+(f+1)|0]=h&255;a[g+(f+2)|0]=i&255;a[g+(f+3)|0]=i>>>8&255;k=h;c[2276075]=k;c[2276076]=i;c[2276077]=0;c[2276078]=0;return}else{gg[c[j+196808+(g<<2)>>2]&4095](e,i);k=i>>>24;c[2276075]=k;c[2276076]=i;c[2276077]=0;c[2276078]=0;return}}function s9(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[2276085]&c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2];t=r&16777215;h=c[2112932]|0;s=c[h+((t>>>10|16384)<<2)>>2]|0;if(s>>>0>9){n=r&1023;a[s+n|0]=q>>>16&255;r=q>>>24;a[s+(n+1)|0]=r&255;a[s+(n+2)|0]=q&255;a[s+(n+3)|0]=q>>>8&255;u=r;c[2276075]=u;c[2276076]=q;c[2276077]=0;c[2276078]=0;return}else{gg[c[h+196808+(s<<2)>>2]&4095](t,q);u=q>>>24;c[2276075]=u;c[2276076]=q;c[2276077]=0;c[2276078]=0;return}}function ta(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=c[2276069]|0;d=c[9104156+((b&7)<<2)>>2]|0;e=9104156+((b>>>9&7|8)<<2)|0;b=c[e>>2]|0;c[e>>2]=b+4;e=c[2276085]&b;b=e&16777215;f=c[2112932]|0;g=c[f+((b>>>10|16384)<<2)>>2]|0;if(g>>>0>9){h=e&1023;a[g+h|0]=d>>>16&255;e=d>>>24;a[g+(h+1)|0]=e&255;a[g+(h+2)|0]=d&255;a[g+(h+3)|0]=d>>>8&255;i=e;c[2276075]=i;c[2276076]=d;c[2276077]=0;c[2276078]=0;return}else{gg[c[f+196808+(g<<2)>>2]&4095](b,d);i=d>>>24;c[2276075]=i;c[2276076]=d;c[2276077]=0;c[2276078]=0;return}}function tb(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=c[2276069]|0;d=c[9104156+((b&7|8)<<2)>>2]|0;e=9104156+((b>>>9&7|8)<<2)|0;b=c[e>>2]|0;c[e>>2]=b+4;e=c[2276085]&b;b=e&16777215;f=c[2112932]|0;g=c[f+((b>>>10|16384)<<2)>>2]|0;if(g>>>0>9){h=e&1023;a[g+h|0]=d>>>16&255;e=d>>>24;a[g+(h+1)|0]=e&255;a[g+(h+2)|0]=d&255;a[g+(h+3)|0]=d>>>8&255;i=e;c[2276075]=i;c[2276076]=d;c[2276077]=0;c[2276078]=0;return}else{gg[c[f+196808+(g<<2)>>2]&4095](b,d);i=d>>>24;c[2276075]=i;c[2276076]=d;c[2276077]=0;c[2276078]=0;return}}function tc(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=c[2276069]|0;e=c[2276085]&c[9104156+((b&7|8)<<2)>>2];f=e&16777215;g=c[2112932]|0;h=c[g+(f>>>10<<2)>>2]|0;if(h>>>0>9){i=e&1023;j=(d[h+(i+3)|0]|0)<<8|(d[h+(i+2)|0]|0)|((d[h+(i+1)|0]|0)<<8|(d[h+i|0]|0))<<16;k=b;l=g}else{b=gj[c[g+196768+(h<<2)>>2]&4095](f)|0;j=b;k=c[2276069]|0;l=c[2112932]|0}b=9104156+((k>>>9&7|8)<<2)|0;k=c[b>>2]|0;c[b>>2]=k+4;b=c[2276085]&k;k=b&16777215;f=c[l+((k>>>10|16384)<<2)>>2]|0;if(f>>>0>9){h=b&1023;a[f+h|0]=j>>>16&255;b=j>>>24;a[f+(h+1)|0]=b&255;a[f+(h+2)|0]=j&255;a[f+(h+3)|0]=j>>>8&255;m=b;c[2276075]=m;c[2276076]=j;c[2276077]=0;c[2276078]=0;return}else{gg[c[l+196808+(f<<2)>>2]&4095](k,j);m=j>>>24;c[2276075]=m;c[2276076]=j;c[2276077]=0;c[2276078]=0;return}}function td(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=c[b>>2]|0;c[b>>2]=e+4;b=c[2276085]&e;e=b&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=b&1023;i=(d[g+(h+3)|0]|0)<<8|(d[g+(h+2)|0]|0)|((d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0))<<16;j=f}else{h=gj[c[f+196768+(g<<2)>>2]&4095](e)|0;i=h;j=c[2112932]|0}h=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;e=c[h>>2]|0;c[h>>2]=e+4;h=c[2276085]&e;e=h&16777215;g=c[j+((e>>>10|16384)<<2)>>2]|0;if(g>>>0>9){f=h&1023;a[g+f|0]=i>>>16&255;h=i>>>24;a[g+(f+1)|0]=h&255;a[g+(f+2)|0]=i&255;a[g+(f+3)|0]=i>>>8&255;k=h;c[2276075]=k;c[2276076]=i;c[2276077]=0;c[2276078]=0;return}else{gg[c[j+196808+(g<<2)>>2]&4095](e,i);k=i>>>24;c[2276075]=k;c[2276076]=i;c[2276077]=0;c[2276078]=0;return}}function te(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=(c[b>>2]|0)-4|0;c[b>>2]=e;b=c[2276085]&e;e=b&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=b&1023;i=(d[g+(h+3)|0]|0)<<8|(d[g+(h+2)|0]|0)|((d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0))<<16;j=f}else{h=gj[c[f+196768+(g<<2)>>2]&4095](e)|0;i=h;j=c[2112932]|0}h=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;e=c[h>>2]|0;c[h>>2]=e+4;h=c[2276085]&e;e=h&16777215;g=c[j+((e>>>10|16384)<<2)>>2]|0;if(g>>>0>9){f=h&1023;a[g+f|0]=i>>>16&255;h=i>>>24;a[g+(f+1)|0]=h&255;a[g+(f+2)|0]=i&255;a[g+(f+3)|0]=i>>>8&255;k=h;c[2276075]=k;c[2276076]=i;c[2276077]=0;c[2276078]=0;return}else{gg[c[j+196808+(g<<2)>>2]&4095](e,i);k=i>>>24;c[2276075]=k;c[2276076]=i;c[2276077]=0;c[2276078]=0;return}}function tf(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=(h>>>((g<<3&16^16)>>>0)<<16>>16)+b&c[2276085];b=m&16777215;g=c[2112932]|0;h=c[g+(b>>>10<<2)>>2]|0;if(h>>>0>9){n=m&1023;o=(d[h+(n+3)|0]|0)<<8|(d[h+(n+2)|0]|0)|((d[h+(n+1)|0]|0)<<8|(d[h+n|0]|0))<<16;p=g}else{n=gj[c[g+196768+(h<<2)>>2]&4095](b)|0;o=n;p=c[2112932]|0}n=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;b=c[n>>2]|0;c[n>>2]=b+4;n=c[2276085]&b;b=n&16777215;h=c[p+((b>>>10|16384)<<2)>>2]|0;if(h>>>0>9){g=n&1023;a[h+g|0]=o>>>16&255;n=o>>>24;a[h+(g+1)|0]=n&255;a[h+(g+2)|0]=o&255;a[h+(g+3)|0]=o>>>8&255;q=n;c[2276075]=q;c[2276076]=o;c[2276077]=0;c[2276078]=0;return}else{gg[c[p+196808+(h<<2)>>2]&4095](b,o);q=o>>>24;c[2276075]=q;c[2276076]=o;c[2276077]=0;c[2276078]=0;return}}function tg(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=nB(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;e=c[2276085]&b;b=e&16777215;f=c[2112932]|0;g=c[f+(b>>>10<<2)>>2]|0;if(g>>>0>9){h=e&1023;i=(d[g+(h+3)|0]|0)<<8|(d[g+(h+2)|0]|0)|((d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0))<<16;j=f}else{h=gj[c[f+196768+(g<<2)>>2]&4095](b)|0;i=h;j=c[2112932]|0}h=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;b=c[h>>2]|0;c[h>>2]=b+4;h=c[2276085]&b;b=h&16777215;g=c[j+((b>>>10|16384)<<2)>>2]|0;if(g>>>0>9){f=h&1023;a[g+f|0]=i>>>16&255;h=i>>>24;a[g+(f+1)|0]=h&255;a[g+(f+2)|0]=i&255;a[g+(f+3)|0]=i>>>8&255;k=h;c[2276075]=k;c[2276076]=i;c[2276077]=0;c[2276078]=0;return}else{gg[c[j+196808+(g<<2)>>2]&4095](b,i);k=i>>>24;c[2276075]=k;c[2276076]=i;c[2276077]=0;c[2276078]=0;return}}function th(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)<<16>>16&c[2276085];f=l&16777215;g=c[2112932]|0;m=c[g+(f>>>10<<2)>>2]|0;if(m>>>0>9){b=l&1023;n=(d[m+(b+3)|0]|0)<<8|(d[m+(b+2)|0]|0)|((d[m+(b+1)|0]|0)<<8|(d[m+b|0]|0))<<16;o=g}else{b=gj[c[g+196768+(m<<2)>>2]&4095](f)|0;n=b;o=c[2112932]|0}b=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;f=c[b>>2]|0;c[b>>2]=f+4;b=c[2276085]&f;f=b&16777215;m=c[o+((f>>>10|16384)<<2)>>2]|0;if(m>>>0>9){g=b&1023;a[m+g|0]=n>>>16&255;b=n>>>24;a[m+(g+1)|0]=b&255;a[m+(g+2)|0]=n&255;a[m+(g+3)|0]=n>>>8&255;p=b;c[2276075]=p;c[2276076]=n;c[2276077]=0;c[2276078]=0;return}else{gg[c[o+196808+(m<<2)>>2]&4095](f,n);p=n>>>24;c[2276075]=p;c[2276076]=n;c[2276077]=0;c[2276078]=0;return}}function ti(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[2276085]&q;q=r&16777215;t=c[2112932]|0;h=c[t+(q>>>10<<2)>>2]|0;if(h>>>0>9){s=r&1023;u=(d[h+(s+3)|0]|0)<<8|(d[h+(s+2)|0]|0)|((d[h+(s+1)|0]|0)<<8|(d[h+s|0]|0))<<16;v=t}else{s=gj[c[t+196768+(h<<2)>>2]&4095](q)|0;u=s;v=c[2112932]|0}s=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;q=c[s>>2]|0;c[s>>2]=q+4;s=c[2276085]&q;q=s&16777215;h=c[v+((q>>>10|16384)<<2)>>2]|0;if(h>>>0>9){t=s&1023;a[h+t|0]=u>>>16&255;s=u>>>24;a[h+(t+1)|0]=s&255;a[h+(t+2)|0]=u&255;a[h+(t+3)|0]=u>>>8&255;w=s;c[2276075]=w;c[2276076]=u;c[2276077]=0;c[2276078]=0;return}else{gg[c[v+196808+(h<<2)>>2]&4095](q,u);w=u>>>24;c[2276075]=w;c[2276076]=u;c[2276077]=0;c[2276078]=0;return}}function tj(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{k=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=k;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=(g>>>((f<<3&16^16)>>>0)<<16>>16)+b|0;b=l&16777215;f=c[2112932]|0;g=c[f+((b>>>10|32768)<<2)>>2]|0;if(g>>>0>9){m=l&1023;n=(d[g+(m+3)|0]|0)<<8|(d[g+(m+2)|0]|0)|((d[g+(m+1)|0]|0)<<8|(d[g+m|0]|0))<<16;o=f}else{m=gj[c[f+196768+(g<<2)>>2]&4095](b)|0;n=m;o=c[2112932]|0}m=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;b=c[m>>2]|0;c[m>>2]=b+4;m=c[2276085]&b;b=m&16777215;g=c[o+((b>>>10|16384)<<2)>>2]|0;if(g>>>0>9){f=m&1023;a[g+f|0]=n>>>16&255;m=n>>>24;a[g+(f+1)|0]=m&255;a[g+(f+2)|0]=n&255;a[g+(f+3)|0]=n>>>8&255;p=m;c[2276075]=p;c[2276076]=n;c[2276077]=0;c[2276078]=0;return}else{gg[c[o+196808+(g<<2)>>2]&4095](b,n);p=n>>>24;c[2276075]=p;c[2276076]=n;c[2276077]=0;c[2276078]=0;return}}function tk(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=nB(c[2276056]|0)|0;e=b&16777215;f=c[2112932]|0;g=c[f+((e>>>10|32768)<<2)>>2]|0;if(g>>>0>9){h=b&1023;i=(d[g+(h+3)|0]|0)<<8|(d[g+(h+2)|0]|0)|((d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0))<<16;j=f}else{h=gj[c[f+196768+(g<<2)>>2]&4095](e)|0;i=h;j=c[2112932]|0}h=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;e=c[h>>2]|0;c[h>>2]=e+4;h=c[2276085]&e;e=h&16777215;g=c[j+((e>>>10|16384)<<2)>>2]|0;if(g>>>0>9){f=h&1023;a[g+f|0]=i>>>16&255;h=i>>>24;a[g+(f+1)|0]=h&255;a[g+(f+2)|0]=i&255;a[g+(f+3)|0]=i>>>8&255;k=h;c[2276075]=k;c[2276076]=i;c[2276077]=0;c[2276078]=0;return}else{gg[c[j+196808+(g<<2)>>2]&4095](e,i);k=i>>>24;c[2276075]=k;c[2276076]=i;c[2276077]=0;c[2276078]=0;return}}function tl(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;t=c[r>>2]|0;c[r>>2]=t+4;r=c[2276085]&t;t=r&16777215;h=c[2112932]|0;s=c[h+((t>>>10|16384)<<2)>>2]|0;if(s>>>0>9){n=r&1023;a[s+n|0]=q>>>16&255;r=q>>>24;a[s+(n+1)|0]=r&255;a[s+(n+2)|0]=q&255;a[s+(n+3)|0]=q>>>8&255;u=r;c[2276075]=u;c[2276076]=q;c[2276077]=0;c[2276078]=0;return}else{gg[c[h+196808+(s<<2)>>2]&4095](t,q);u=q>>>24;c[2276075]=u;c[2276076]=q;c[2276077]=0;c[2276078]=0;return}}function tm(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=c[2276069]|0;d=c[9104156+((b&7)<<2)>>2]|0;e=9104156+((b>>>9&7|8)<<2)|0;b=(c[e>>2]|0)-4|0;c[e>>2]=b;e=c[2276085]&b;b=e&16777215;f=c[2112932]|0;g=c[f+((b>>>10|16384)<<2)>>2]|0;if(g>>>0>9){h=e&1023;a[g+h|0]=d>>>16&255;e=d>>>24;a[g+(h+1)|0]=e&255;a[g+(h+2)|0]=d&255;a[g+(h+3)|0]=d>>>8&255;i=e;c[2276075]=i;c[2276076]=d;c[2276077]=0;c[2276078]=0;return}else{gg[c[f+196808+(g<<2)>>2]&4095](b,d);i=d>>>24;c[2276075]=i;c[2276076]=d;c[2276077]=0;c[2276078]=0;return}}function tn(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=c[2276069]|0;d=c[9104156+((b&7|8)<<2)>>2]|0;e=9104156+((b>>>9&7|8)<<2)|0;b=(c[e>>2]|0)-4|0;c[e>>2]=b;e=c[2276085]&b;b=e&16777215;f=c[2112932]|0;g=c[f+((b>>>10|16384)<<2)>>2]|0;if(g>>>0>9){h=e&1023;a[g+h|0]=d>>>16&255;e=d>>>24;a[g+(h+1)|0]=e&255;a[g+(h+2)|0]=d&255;a[g+(h+3)|0]=d>>>8&255;i=e;c[2276075]=i;c[2276076]=d;c[2276077]=0;c[2276078]=0;return}else{gg[c[f+196808+(g<<2)>>2]&4095](b,d);i=d>>>24;c[2276075]=i;c[2276076]=d;c[2276077]=0;c[2276078]=0;return}}function to(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=c[2276069]|0;e=c[2276085]&c[9104156+((b&7|8)<<2)>>2];f=e&16777215;g=c[2112932]|0;h=c[g+(f>>>10<<2)>>2]|0;if(h>>>0>9){i=e&1023;j=(d[h+(i+3)|0]|0)<<8|(d[h+(i+2)|0]|0)|((d[h+(i+1)|0]|0)<<8|(d[h+i|0]|0))<<16;k=b;l=g}else{b=gj[c[g+196768+(h<<2)>>2]&4095](f)|0;j=b;k=c[2276069]|0;l=c[2112932]|0}b=9104156+((k>>>9&7|8)<<2)|0;k=(c[b>>2]|0)-4|0;c[b>>2]=k;b=c[2276085]&k;k=b&16777215;f=c[l+((k>>>10|16384)<<2)>>2]|0;if(f>>>0>9){h=b&1023;a[f+h|0]=j>>>16&255;b=j>>>24;a[f+(h+1)|0]=b&255;a[f+(h+2)|0]=j&255;a[f+(h+3)|0]=j>>>8&255;m=b;c[2276075]=m;c[2276076]=j;c[2276077]=0;c[2276078]=0;return}else{gg[c[l+196808+(f<<2)>>2]&4095](k,j);m=j>>>24;c[2276075]=m;c[2276076]=j;c[2276077]=0;c[2276078]=0;return}}function tp(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=c[b>>2]|0;c[b>>2]=e+4;b=c[2276085]&e;e=b&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=b&1023;i=(d[g+(h+3)|0]|0)<<8|(d[g+(h+2)|0]|0)|((d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0))<<16;j=f}else{h=gj[c[f+196768+(g<<2)>>2]&4095](e)|0;i=h;j=c[2112932]|0}h=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;e=(c[h>>2]|0)-4|0;c[h>>2]=e;h=c[2276085]&e;e=h&16777215;g=c[j+((e>>>10|16384)<<2)>>2]|0;if(g>>>0>9){f=h&1023;a[g+f|0]=i>>>16&255;h=i>>>24;a[g+(f+1)|0]=h&255;a[g+(f+2)|0]=i&255;a[g+(f+3)|0]=i>>>8&255;k=h;c[2276075]=k;c[2276076]=i;c[2276077]=0;c[2276078]=0;return}else{gg[c[j+196808+(g<<2)>>2]&4095](e,i);k=i>>>24;c[2276075]=k;c[2276076]=i;c[2276077]=0;c[2276078]=0;return}}function tq(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=(c[b>>2]|0)-4|0;c[b>>2]=e;b=c[2276085]&e;e=b&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=b&1023;i=(d[g+(h+3)|0]|0)<<8|(d[g+(h+2)|0]|0)|((d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0))<<16;j=f}else{h=gj[c[f+196768+(g<<2)>>2]&4095](e)|0;i=h;j=c[2112932]|0}h=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;e=(c[h>>2]|0)-4|0;c[h>>2]=e;h=c[2276085]&e;e=h&16777215;g=c[j+((e>>>10|16384)<<2)>>2]|0;if(g>>>0>9){f=h&1023;a[g+f|0]=i>>>16&255;h=i>>>24;a[g+(f+1)|0]=h&255;a[g+(f+2)|0]=i&255;a[g+(f+3)|0]=i>>>8&255;k=h;c[2276075]=k;c[2276076]=i;c[2276077]=0;c[2276078]=0;return}else{gg[c[j+196808+(g<<2)>>2]&4095](e,i);k=i>>>24;c[2276075]=k;c[2276076]=i;c[2276077]=0;c[2276078]=0;return}}function tr(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=(h>>>((g<<3&16^16)>>>0)<<16>>16)+b&c[2276085];b=m&16777215;g=c[2112932]|0;h=c[g+(b>>>10<<2)>>2]|0;if(h>>>0>9){n=m&1023;o=(d[h+(n+3)|0]|0)<<8|(d[h+(n+2)|0]|0)|((d[h+(n+1)|0]|0)<<8|(d[h+n|0]|0))<<16;p=g}else{n=gj[c[g+196768+(h<<2)>>2]&4095](b)|0;o=n;p=c[2112932]|0}n=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;b=(c[n>>2]|0)-4|0;c[n>>2]=b;n=c[2276085]&b;b=n&16777215;h=c[p+((b>>>10|16384)<<2)>>2]|0;if(h>>>0>9){g=n&1023;a[h+g|0]=o>>>16&255;n=o>>>24;a[h+(g+1)|0]=n&255;a[h+(g+2)|0]=o&255;a[h+(g+3)|0]=o>>>8&255;q=n;c[2276075]=q;c[2276076]=o;c[2276077]=0;c[2276078]=0;return}else{gg[c[p+196808+(h<<2)>>2]&4095](b,o);q=o>>>24;c[2276075]=q;c[2276076]=o;c[2276077]=0;c[2276078]=0;return}}function ts(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=nB(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;e=c[2276085]&b;b=e&16777215;f=c[2112932]|0;g=c[f+(b>>>10<<2)>>2]|0;if(g>>>0>9){h=e&1023;i=(d[g+(h+3)|0]|0)<<8|(d[g+(h+2)|0]|0)|((d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0))<<16;j=f}else{h=gj[c[f+196768+(g<<2)>>2]&4095](b)|0;i=h;j=c[2112932]|0}h=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;b=(c[h>>2]|0)-4|0;c[h>>2]=b;h=c[2276085]&b;b=h&16777215;g=c[j+((b>>>10|16384)<<2)>>2]|0;if(g>>>0>9){f=h&1023;a[g+f|0]=i>>>16&255;h=i>>>24;a[g+(f+1)|0]=h&255;a[g+(f+2)|0]=i&255;a[g+(f+3)|0]=i>>>8&255;k=h;c[2276075]=k;c[2276076]=i;c[2276077]=0;c[2276078]=0;return}else{gg[c[j+196808+(g<<2)>>2]&4095](b,i);k=i>>>24;c[2276075]=k;c[2276076]=i;c[2276077]=0;c[2276078]=0;return}}function tt(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)<<16>>16&c[2276085];f=l&16777215;g=c[2112932]|0;m=c[g+(f>>>10<<2)>>2]|0;if(m>>>0>9){b=l&1023;n=(d[m+(b+3)|0]|0)<<8|(d[m+(b+2)|0]|0)|((d[m+(b+1)|0]|0)<<8|(d[m+b|0]|0))<<16;o=g}else{b=gj[c[g+196768+(m<<2)>>2]&4095](f)|0;n=b;o=c[2112932]|0}b=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;f=(c[b>>2]|0)-4|0;c[b>>2]=f;b=c[2276085]&f;f=b&16777215;m=c[o+((f>>>10|16384)<<2)>>2]|0;if(m>>>0>9){g=b&1023;a[m+g|0]=n>>>16&255;b=n>>>24;a[m+(g+1)|0]=b&255;a[m+(g+2)|0]=n&255;a[m+(g+3)|0]=n>>>8&255;p=b;c[2276075]=p;c[2276076]=n;c[2276077]=0;c[2276078]=0;return}else{gg[c[o+196808+(m<<2)>>2]&4095](f,n);p=n>>>24;c[2276075]=p;c[2276076]=n;c[2276077]=0;c[2276078]=0;return}}function tu(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[2276085]&q;q=r&16777215;t=c[2112932]|0;h=c[t+(q>>>10<<2)>>2]|0;if(h>>>0>9){s=r&1023;u=(d[h+(s+3)|0]|0)<<8|(d[h+(s+2)|0]|0)|((d[h+(s+1)|0]|0)<<8|(d[h+s|0]|0))<<16;v=t}else{s=gj[c[t+196768+(h<<2)>>2]&4095](q)|0;u=s;v=c[2112932]|0}s=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;q=(c[s>>2]|0)-4|0;c[s>>2]=q;s=c[2276085]&q;q=s&16777215;h=c[v+((q>>>10|16384)<<2)>>2]|0;if(h>>>0>9){t=s&1023;a[h+t|0]=u>>>16&255;s=u>>>24;a[h+(t+1)|0]=s&255;a[h+(t+2)|0]=u&255;a[h+(t+3)|0]=u>>>8&255;w=s;c[2276075]=w;c[2276076]=u;c[2276077]=0;c[2276078]=0;return}else{gg[c[v+196808+(h<<2)>>2]&4095](q,u);w=u>>>24;c[2276075]=w;c[2276076]=u;c[2276077]=0;c[2276078]=0;return}}function tv(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{k=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=k;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=(g>>>((f<<3&16^16)>>>0)<<16>>16)+b|0;b=l&16777215;f=c[2112932]|0;g=c[f+((b>>>10|32768)<<2)>>2]|0;if(g>>>0>9){m=l&1023;n=(d[g+(m+3)|0]|0)<<8|(d[g+(m+2)|0]|0)|((d[g+(m+1)|0]|0)<<8|(d[g+m|0]|0))<<16;o=f}else{m=gj[c[f+196768+(g<<2)>>2]&4095](b)|0;n=m;o=c[2112932]|0}m=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;b=(c[m>>2]|0)-4|0;c[m>>2]=b;m=c[2276085]&b;b=m&16777215;g=c[o+((b>>>10|16384)<<2)>>2]|0;if(g>>>0>9){f=m&1023;a[g+f|0]=n>>>16&255;m=n>>>24;a[g+(f+1)|0]=m&255;a[g+(f+2)|0]=n&255;a[g+(f+3)|0]=n>>>8&255;p=m;c[2276075]=p;c[2276076]=n;c[2276077]=0;c[2276078]=0;return}else{gg[c[o+196808+(g<<2)>>2]&4095](b,n);p=n>>>24;c[2276075]=p;c[2276076]=n;c[2276077]=0;c[2276078]=0;return}}function tw(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=nB(c[2276056]|0)|0;e=b&16777215;f=c[2112932]|0;g=c[f+((e>>>10|32768)<<2)>>2]|0;if(g>>>0>9){h=b&1023;i=(d[g+(h+3)|0]|0)<<8|(d[g+(h+2)|0]|0)|((d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0))<<16;j=f}else{h=gj[c[f+196768+(g<<2)>>2]&4095](e)|0;i=h;j=c[2112932]|0}h=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;e=(c[h>>2]|0)-4|0;c[h>>2]=e;h=c[2276085]&e;e=h&16777215;g=c[j+((e>>>10|16384)<<2)>>2]|0;if(g>>>0>9){f=h&1023;a[g+f|0]=i>>>16&255;h=i>>>24;a[g+(f+1)|0]=h&255;a[g+(f+2)|0]=i&255;a[g+(f+3)|0]=i>>>8&255;k=h;c[2276075]=k;c[2276076]=i;c[2276077]=0;c[2276078]=0;return}else{gg[c[j+196808+(g<<2)>>2]&4095](e,i);k=i>>>24;c[2276075]=k;c[2276076]=i;c[2276077]=0;c[2276078]=0;return}}function tx(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;t=(c[r>>2]|0)-4|0;c[r>>2]=t;r=c[2276085]&t;t=r&16777215;h=c[2112932]|0;s=c[h+((t>>>10|16384)<<2)>>2]|0;if(s>>>0>9){n=r&1023;a[s+n|0]=q>>>16&255;r=q>>>24;a[s+(n+1)|0]=r&255;a[s+(n+2)|0]=q&255;a[s+(n+3)|0]=q>>>8&255;u=r;c[2276075]=u;c[2276076]=q;c[2276077]=0;c[2276078]=0;return}else{gg[c[h+196808+(s<<2)>>2]&4095](t,q);u=q>>>24;c[2276075]=u;c[2276076]=q;c[2276077]=0;c[2276078]=0;return}}function ty(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276069]|0;e=c[9104156+((b&7)<<2)>>2]|0;f=c[9104156+((b>>>9&7|8)<<2)>>2]|0;b=c[2276056]|0;g=b&-4;if((g|0)==(c[2276083]|0)){h=b;i=c[2276084]|0}else{c[2276083]=g;j=c[2276085]&g;g=j&16777212;k=c[2112932]|0;l=c[k+((g>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=j&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b}else{b=gj[c[k+196768+(l<<2)>>2]&4095](g)|0;n=b;o=c[2276056]|0}c[2276084]=n;h=o;i=n}c[2276056]=h+2;n=(i>>>((h<<3&16^16)>>>0)<<16>>16)+f&c[2276085];f=n&16777215;h=c[2112932]|0;i=c[h+((f>>>10|16384)<<2)>>2]|0;if(i>>>0>9){o=n&1023;a[i+o|0]=e>>>16&255;n=e>>>24;a[i+(o+1)|0]=n&255;a[i+(o+2)|0]=e&255;a[i+(o+3)|0]=e>>>8&255;p=n;c[2276075]=p;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}else{gg[c[h+196808+(i<<2)>>2]&4095](f,e);p=e>>>24;c[2276075]=p;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}}function tz(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276069]|0;e=c[9104156+((b&7|8)<<2)>>2]|0;f=c[9104156+((b>>>9&7|8)<<2)>>2]|0;b=c[2276056]|0;g=b&-4;if((g|0)==(c[2276083]|0)){h=b;i=c[2276084]|0}else{c[2276083]=g;j=c[2276085]&g;g=j&16777212;k=c[2112932]|0;l=c[k+((g>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=j&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b}else{b=gj[c[k+196768+(l<<2)>>2]&4095](g)|0;n=b;o=c[2276056]|0}c[2276084]=n;h=o;i=n}c[2276056]=h+2;n=(i>>>((h<<3&16^16)>>>0)<<16>>16)+f&c[2276085];f=n&16777215;h=c[2112932]|0;i=c[h+((f>>>10|16384)<<2)>>2]|0;if(i>>>0>9){o=n&1023;a[i+o|0]=e>>>16&255;n=e>>>24;a[i+(o+1)|0]=n&255;a[i+(o+2)|0]=e&255;a[i+(o+3)|0]=e>>>8&255;p=n;c[2276075]=p;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}else{gg[c[h+196808+(i<<2)>>2]&4095](f,e);p=e>>>24;c[2276075]=p;c[2276076]=e;c[2276077]=0;c[2276078]=0;return}}function tA(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276069]|0;e=c[2276085]&c[9104156+((b&7|8)<<2)>>2];f=e&16777215;g=c[2112932]|0;h=c[g+(f>>>10<<2)>>2]|0;if(h>>>0>9){i=e&1023;j=(d[h+(i+3)|0]|0)<<8|(d[h+(i+2)|0]|0)|((d[h+(i+1)|0]|0)<<8|(d[h+i|0]|0))<<16;k=b}else{b=gj[c[g+196768+(h<<2)>>2]&4095](f)|0;j=b;k=c[2276069]|0}b=c[9104156+((k>>>9&7|8)<<2)>>2]|0;k=c[2276056]|0;f=k&-4;if((f|0)==(c[2276083]|0)){l=k;m=c[2276084]|0}else{c[2276083]=f;h=c[2276085]&f;f=h&16777212;g=c[2112932]|0;i=c[g+((f>>>10|32768)<<2)>>2]|0;if(i>>>0>9){e=h&1020;n=(d[i+(e|3)|0]|0)<<8|(d[i+(e|2)|0]|0)|((d[i+(e|1)|0]|0)<<8|(d[i+e|0]|0))<<16;o=k}else{k=gj[c[g+196768+(i<<2)>>2]&4095](f)|0;n=k;o=c[2276056]|0}c[2276084]=n;l=o;m=n}c[2276056]=l+2;n=(m>>>((l<<3&16^16)>>>0)<<16>>16)+b&c[2276085];b=n&16777215;l=c[2112932]|0;m=c[l+((b>>>10|16384)<<2)>>2]|0;if(m>>>0>9){o=n&1023;a[m+o|0]=j>>>16&255;n=j>>>24;a[m+(o+1)|0]=n&255;a[m+(o+2)|0]=j&255;a[m+(o+3)|0]=j>>>8&255;p=n;c[2276075]=p;c[2276076]=j;c[2276077]=0;c[2276078]=0;return}else{gg[c[l+196808+(m<<2)>>2]&4095](b,j);p=j>>>24;c[2276075]=p;c[2276076]=j;c[2276077]=0;c[2276078]=0;return}}function tB(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=c[b>>2]|0;c[b>>2]=e+4;b=c[2276085]&e;e=b&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=b&1023;i=(d[g+(h+3)|0]|0)<<8|(d[g+(h+2)|0]|0)|((d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0))<<16}else{i=gj[c[f+196768+(g<<2)>>2]&4095](e)|0}e=c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2]|0;g=c[2276056]|0;f=g&-4;if((f|0)==(c[2276083]|0)){j=g;k=c[2276084]|0}else{c[2276083]=f;h=c[2276085]&f;f=h&16777212;b=c[2112932]|0;l=c[b+((f>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=h&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=g}else{g=gj[c[b+196768+(l<<2)>>2]&4095](f)|0;n=g;o=c[2276056]|0}c[2276084]=n;j=o;k=n}c[2276056]=j+2;n=(k>>>((j<<3&16^16)>>>0)<<16>>16)+e&c[2276085];e=n&16777215;j=c[2112932]|0;k=c[j+((e>>>10|16384)<<2)>>2]|0;if(k>>>0>9){o=n&1023;a[k+o|0]=i>>>16&255;n=i>>>24;a[k+(o+1)|0]=n&255;a[k+(o+2)|0]=i&255;a[k+(o+3)|0]=i>>>8&255;p=n;c[2276075]=p;c[2276076]=i;c[2276077]=0;c[2276078]=0;return}else{gg[c[j+196808+(k<<2)>>2]&4095](e,i);p=i>>>24;c[2276075]=p;c[2276076]=i;c[2276077]=0;c[2276078]=0;return}}function tC(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=(c[b>>2]|0)-4|0;c[b>>2]=e;b=c[2276085]&e;e=b&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=b&1023;i=(d[g+(h+3)|0]|0)<<8|(d[g+(h+2)|0]|0)|((d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0))<<16}else{i=gj[c[f+196768+(g<<2)>>2]&4095](e)|0}e=c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2]|0;g=c[2276056]|0;f=g&-4;if((f|0)==(c[2276083]|0)){j=g;k=c[2276084]|0}else{c[2276083]=f;h=c[2276085]&f;f=h&16777212;b=c[2112932]|0;l=c[b+((f>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=h&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=g}else{g=gj[c[b+196768+(l<<2)>>2]&4095](f)|0;n=g;o=c[2276056]|0}c[2276084]=n;j=o;k=n}c[2276056]=j+2;n=(k>>>((j<<3&16^16)>>>0)<<16>>16)+e&c[2276085];e=n&16777215;j=c[2112932]|0;k=c[j+((e>>>10|16384)<<2)>>2]|0;if(k>>>0>9){o=n&1023;a[k+o|0]=i>>>16&255;n=i>>>24;a[k+(o+1)|0]=n&255;a[k+(o+2)|0]=i&255;a[k+(o+3)|0]=i>>>8&255;p=n;c[2276075]=p;c[2276076]=i;c[2276077]=0;c[2276078]=0;return}else{gg[c[j+196808+(k<<2)>>2]&4095](e,i);p=i>>>24;c[2276075]=p;c[2276076]=i;c[2276077]=0;c[2276078]=0;return}}function tD(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}m=g+2|0;c[2276056]=m;n=(h>>>((g<<3&16^16)>>>0)<<16>>16)+b&c[2276085];b=n&16777215;g=c[2112932]|0;h=c[g+(b>>>10<<2)>>2]|0;if(h>>>0>9){e=n&1023;o=(d[h+(e+3)|0]|0)<<8|(d[h+(e+2)|0]|0)|((d[h+(e+1)|0]|0)<<8|(d[h+e|0]|0))<<16;p=m}else{m=gj[c[g+196768+(h<<2)>>2]&4095](b)|0;o=m;p=c[2276056]|0}m=c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2]|0;b=p&-4;if((b|0)==(c[2276083]|0)){q=p;r=c[2276084]|0}else{c[2276083]=b;h=c[2276085]&b;b=h&16777212;g=c[2112932]|0;e=c[g+((b>>>10|32768)<<2)>>2]|0;if(e>>>0>9){n=h&1020;s=(d[e+(n|3)|0]|0)<<8|(d[e+(n|2)|0]|0)|((d[e+(n|1)|0]|0)<<8|(d[e+n|0]|0))<<16;t=p}else{p=gj[c[g+196768+(e<<2)>>2]&4095](b)|0;s=p;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;s=(r>>>((q<<3&16^16)>>>0)<<16>>16)+m&c[2276085];m=s&16777215;q=c[2112932]|0;r=c[q+((m>>>10|16384)<<2)>>2]|0;if(r>>>0>9){t=s&1023;a[r+t|0]=o>>>16&255;s=o>>>24;a[r+(t+1)|0]=s&255;a[r+(t+2)|0]=o&255;a[r+(t+3)|0]=o>>>8&255;u=s;c[2276075]=u;c[2276076]=o;c[2276077]=0;c[2276078]=0;return}else{gg[c[q+196808+(r<<2)>>2]&4095](m,o);u=o>>>24;c[2276075]=u;c[2276076]=o;c[2276077]=0;c[2276078]=0;return}}function tE(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=nB(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;e=c[2276085]&b;b=e&16777215;f=c[2112932]|0;g=c[f+(b>>>10<<2)>>2]|0;if(g>>>0>9){h=e&1023;i=(d[g+(h+3)|0]|0)<<8|(d[g+(h+2)|0]|0)|((d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0))<<16}else{i=gj[c[f+196768+(g<<2)>>2]&4095](b)|0}b=c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2]|0;g=c[2276056]|0;f=g&-4;if((f|0)==(c[2276083]|0)){j=g;k=c[2276084]|0}else{c[2276083]=f;h=c[2276085]&f;f=h&16777212;e=c[2112932]|0;l=c[e+((f>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=h&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=g}else{g=gj[c[e+196768+(l<<2)>>2]&4095](f)|0;n=g;o=c[2276056]|0}c[2276084]=n;j=o;k=n}c[2276056]=j+2;n=(k>>>((j<<3&16^16)>>>0)<<16>>16)+b&c[2276085];b=n&16777215;j=c[2112932]|0;k=c[j+((b>>>10|16384)<<2)>>2]|0;if(k>>>0>9){o=n&1023;a[k+o|0]=i>>>16&255;n=i>>>24;a[k+(o+1)|0]=n&255;a[k+(o+2)|0]=i&255;a[k+(o+3)|0]=i>>>8&255;p=n;c[2276075]=p;c[2276076]=i;c[2276077]=0;c[2276078]=0;return}else{gg[c[j+196808+(k<<2)>>2]&4095](b,i);p=i>>>24;c[2276075]=p;c[2276076]=i;c[2276077]=0;c[2276078]=0;return}}function tF(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}l=f+2|0;c[2276056]=l;m=g>>>((f<<3&16^16)>>>0)<<16>>16&c[2276085];f=m&16777215;g=c[2112932]|0;b=c[g+(f>>>10<<2)>>2]|0;if(b>>>0>9){e=m&1023;n=(d[b+(e+3)|0]|0)<<8|(d[b+(e+2)|0]|0)|((d[b+(e+1)|0]|0)<<8|(d[b+e|0]|0))<<16;o=l}else{l=gj[c[g+196768+(b<<2)>>2]&4095](f)|0;n=l;o=c[2276056]|0}l=c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2]|0;f=o&-4;if((f|0)==(c[2276083]|0)){p=o;q=c[2276084]|0}else{c[2276083]=f;b=c[2276085]&f;f=b&16777212;g=c[2112932]|0;e=c[g+((f>>>10|32768)<<2)>>2]|0;if(e>>>0>9){m=b&1020;r=(d[e+(m|3)|0]|0)<<8|(d[e+(m|2)|0]|0)|((d[e+(m|1)|0]|0)<<8|(d[e+m|0]|0))<<16;s=o}else{o=gj[c[g+196768+(e<<2)>>2]&4095](f)|0;r=o;s=c[2276056]|0}c[2276084]=r;p=s;q=r}c[2276056]=p+2;r=(q>>>((p<<3&16^16)>>>0)<<16>>16)+l&c[2276085];l=r&16777215;p=c[2112932]|0;q=c[p+((l>>>10|16384)<<2)>>2]|0;if(q>>>0>9){s=r&1023;a[q+s|0]=n>>>16&255;r=n>>>24;a[q+(s+1)|0]=r&255;a[q+(s+2)|0]=n&255;a[q+(s+3)|0]=n>>>8&255;t=r;c[2276075]=t;c[2276076]=n;c[2276077]=0;c[2276078]=0;return}else{gg[c[p+196808+(q<<2)>>2]&4095](l,n);t=n>>>24;c[2276075]=t;c[2276076]=n;c[2276077]=0;c[2276078]=0;return}}function tG(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}t=r+2|0;c[2276056]=t;r=c[2276085]&q;q=r&16777215;h=c[2112932]|0;s=c[h+(q>>>10<<2)>>2]|0;if(s>>>0>9){n=r&1023;u=(d[s+(n+3)|0]|0)<<8|(d[s+(n+2)|0]|0)|((d[s+(n+1)|0]|0)<<8|(d[s+n|0]|0))<<16;v=t}else{t=gj[c[h+196768+(s<<2)>>2]&4095](q)|0;u=t;v=c[2276056]|0}t=c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2]|0;q=v&-4;if((q|0)==(c[2276083]|0)){w=v;x=c[2276084]|0}else{c[2276083]=q;s=c[2276085]&q;q=s&16777212;h=c[2112932]|0;n=c[h+((q>>>10|32768)<<2)>>2]|0;if(n>>>0>9){r=s&1020;y=(d[n+(r|3)|0]|0)<<8|(d[n+(r|2)|0]|0)|((d[n+(r|1)|0]|0)<<8|(d[n+r|0]|0))<<16;z=v}else{v=gj[c[h+196768+(n<<2)>>2]&4095](q)|0;y=v;z=c[2276056]|0}c[2276084]=y;w=z;x=y}c[2276056]=w+2;y=(x>>>((w<<3&16^16)>>>0)<<16>>16)+t&c[2276085];t=y&16777215;w=c[2112932]|0;x=c[w+((t>>>10|16384)<<2)>>2]|0;if(x>>>0>9){z=y&1023;a[x+z|0]=u>>>16&255;y=u>>>24;a[x+(z+1)|0]=y&255;a[x+(z+2)|0]=u&255;a[x+(z+3)|0]=u>>>8&255;A=y;c[2276075]=A;c[2276076]=u;c[2276077]=0;c[2276078]=0;return}else{gg[c[w+196808+(x<<2)>>2]&4095](t,u);A=u>>>24;c[2276075]=A;c[2276076]=u;c[2276077]=0;c[2276078]=0;return}}function tH(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{k=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=k;m=c[2276056]|0}c[2276084]=l;f=m;g=l}l=f+2|0;c[2276056]=l;m=(g>>>((f<<3&16^16)>>>0)<<16>>16)+b|0;b=m&16777215;f=c[2112932]|0;g=c[f+((b>>>10|32768)<<2)>>2]|0;if(g>>>0>9){k=m&1023;n=(d[g+(k+3)|0]|0)<<8|(d[g+(k+2)|0]|0)|((d[g+(k+1)|0]|0)<<8|(d[g+k|0]|0))<<16;o=l}else{l=gj[c[f+196768+(g<<2)>>2]&4095](b)|0;n=l;o=c[2276056]|0}l=c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2]|0;b=o&-4;if((b|0)==(c[2276083]|0)){p=o;q=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;f=c[2112932]|0;k=c[f+((b>>>10|32768)<<2)>>2]|0;if(k>>>0>9){m=g&1020;r=(d[k+(m|3)|0]|0)<<8|(d[k+(m|2)|0]|0)|((d[k+(m|1)|0]|0)<<8|(d[k+m|0]|0))<<16;s=o}else{o=gj[c[f+196768+(k<<2)>>2]&4095](b)|0;r=o;s=c[2276056]|0}c[2276084]=r;p=s;q=r}c[2276056]=p+2;r=(q>>>((p<<3&16^16)>>>0)<<16>>16)+l&c[2276085];l=r&16777215;p=c[2112932]|0;q=c[p+((l>>>10|16384)<<2)>>2]|0;if(q>>>0>9){s=r&1023;a[q+s|0]=n>>>16&255;r=n>>>24;a[q+(s+1)|0]=r&255;a[q+(s+2)|0]=n&255;a[q+(s+3)|0]=n>>>8&255;t=r;c[2276075]=t;c[2276076]=n;c[2276077]=0;c[2276078]=0;return}else{gg[c[p+196808+(q<<2)>>2]&4095](l,n);t=n>>>24;c[2276075]=t;c[2276076]=n;c[2276077]=0;c[2276078]=0;return}}function tI(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=nB(c[2276056]|0)|0;e=b&16777215;f=c[2112932]|0;g=c[f+((e>>>10|32768)<<2)>>2]|0;if(g>>>0>9){h=b&1023;i=(d[g+(h+3)|0]|0)<<8|(d[g+(h+2)|0]|0)|((d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0))<<16}else{i=gj[c[f+196768+(g<<2)>>2]&4095](e)|0}e=c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2]|0;g=c[2276056]|0;f=g&-4;if((f|0)==(c[2276083]|0)){j=g;k=c[2276084]|0}else{c[2276083]=f;h=c[2276085]&f;f=h&16777212;b=c[2112932]|0;l=c[b+((f>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=h&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=g}else{g=gj[c[b+196768+(l<<2)>>2]&4095](f)|0;n=g;o=c[2276056]|0}c[2276084]=n;j=o;k=n}c[2276056]=j+2;n=(k>>>((j<<3&16^16)>>>0)<<16>>16)+e&c[2276085];e=n&16777215;j=c[2112932]|0;k=c[j+((e>>>10|16384)<<2)>>2]|0;if(k>>>0>9){o=n&1023;a[k+o|0]=i>>>16&255;n=i>>>24;a[k+(o+1)|0]=n&255;a[k+(o+2)|0]=i&255;a[k+(o+3)|0]=i>>>8&255;p=n;c[2276075]=p;c[2276076]=i;c[2276077]=0;c[2276078]=0;return}else{gg[c[j+196808+(k<<2)>>2]&4095](e,i);p=i>>>24;c[2276075]=p;c[2276076]=i;c[2276077]=0;c[2276078]=0;return}}function tJ(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;f=p&-4;if((f|0)==(h|0)){q=g;r=p;s=h;t=g}else{c[2276083]=f;h=c[2276085]&f;n=h&16777212;o=c[2112932]|0;e=c[o+((n>>>10|32768)<<2)>>2]|0;if(e>>>0>9){j=h&1020;u=(d[e+(j|3)|0]|0)<<8|(d[e+(j|2)|0]|0)|((d[e+(j|1)|0]|0)<<8|(d[e+j|0]|0))<<16;v=p;w=f}else{f=gj[c[o+196768+(e<<2)>>2]&4095](n)|0;u=f;v=c[2276056]|0;w=c[2276083]|0}c[2276084]=u;q=u>>>16|g<<16;r=v;s=w;t=u}u=r+2|0;c[2276056]=u;r=c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2]|0;w=u&-4;if((w|0)==(s|0)){x=u;y=t}else{c[2276083]=w;t=c[2276085]&w;w=t&16777212;s=c[2112932]|0;v=c[s+((w>>>10|32768)<<2)>>2]|0;if(v>>>0>9){g=t&1020;z=(d[v+(g|3)|0]|0)<<8|(d[v+(g|2)|0]|0)|((d[v+(g|1)|0]|0)<<8|(d[v+g|0]|0))<<16;A=u}else{u=gj[c[s+196768+(v<<2)>>2]&4095](w)|0;z=u;A=c[2276056]|0}c[2276084]=z;x=A;y=z}c[2276056]=x+2;z=(y>>>((x<<3&16^16)>>>0)<<16>>16)+r&c[2276085];r=z&16777215;x=c[2112932]|0;y=c[x+((r>>>10|16384)<<2)>>2]|0;if(y>>>0>9){A=z&1023;a[y+A|0]=q>>>16&255;z=q>>>24;a[y+(A+1)|0]=z&255;a[y+(A+2)|0]=q&255;a[y+(A+3)|0]=q>>>8&255;B=z;c[2276075]=B;c[2276076]=q;c[2276077]=0;c[2276078]=0;return}else{gg[c[x+196808+(y<<2)>>2]&4095](r,q);B=q>>>24;c[2276075]=B;c[2276076]=q;c[2276077]=0;c[2276078]=0;return}}function tK(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=c[2276069]|0;d=c[9104156+((b&7)<<2)>>2]|0;e=nB(c[9104156+((b>>>9&7|8)<<2)>>2]|0)|0;b=c[2276085]&e;e=b&16777215;f=c[2112932]|0;g=c[f+((e>>>10|16384)<<2)>>2]|0;if(g>>>0>9){h=b&1023;a[g+h|0]=d>>>16&255;b=d>>>24;a[g+(h+1)|0]=b&255;a[g+(h+2)|0]=d&255;a[g+(h+3)|0]=d>>>8&255;i=b;c[2276075]=i;c[2276076]=d;c[2276077]=0;c[2276078]=0;return}else{gg[c[f+196808+(g<<2)>>2]&4095](e,d);i=d>>>24;c[2276075]=i;c[2276076]=d;c[2276077]=0;c[2276078]=0;return}}function tL(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=c[2276069]|0;d=c[9104156+((b&7|8)<<2)>>2]|0;e=nB(c[9104156+((b>>>9&7|8)<<2)>>2]|0)|0;b=c[2276085]&e;e=b&16777215;f=c[2112932]|0;g=c[f+((e>>>10|16384)<<2)>>2]|0;if(g>>>0>9){h=b&1023;a[g+h|0]=d>>>16&255;b=d>>>24;a[g+(h+1)|0]=b&255;a[g+(h+2)|0]=d&255;a[g+(h+3)|0]=d>>>8&255;i=b;c[2276075]=i;c[2276076]=d;c[2276077]=0;c[2276078]=0;return}else{gg[c[f+196808+(g<<2)>>2]&4095](e,d);i=d>>>24;c[2276075]=i;c[2276076]=d;c[2276077]=0;c[2276078]=0;return}}function tM(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=c[2276069]|0;e=c[2276085]&c[9104156+((b&7|8)<<2)>>2];f=e&16777215;g=c[2112932]|0;h=c[g+(f>>>10<<2)>>2]|0;if(h>>>0>9){i=e&1023;j=(d[h+(i+3)|0]|0)<<8|(d[h+(i+2)|0]|0)|((d[h+(i+1)|0]|0)<<8|(d[h+i|0]|0))<<16;k=b}else{b=gj[c[g+196768+(h<<2)>>2]&4095](f)|0;j=b;k=c[2276069]|0}b=nB(c[9104156+((k>>>9&7|8)<<2)>>2]|0)|0;k=c[2276085]&b;b=k&16777215;f=c[2112932]|0;h=c[f+((b>>>10|16384)<<2)>>2]|0;if(h>>>0>9){g=k&1023;a[h+g|0]=j>>>16&255;k=j>>>24;a[h+(g+1)|0]=k&255;a[h+(g+2)|0]=j&255;a[h+(g+3)|0]=j>>>8&255;l=k;c[2276075]=l;c[2276076]=j;c[2276077]=0;c[2276078]=0;return}else{gg[c[f+196808+(h<<2)>>2]&4095](b,j);l=j>>>24;c[2276075]=l;c[2276076]=j;c[2276077]=0;c[2276078]=0;return}}function tN(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=c[b>>2]|0;c[b>>2]=e+4;b=c[2276085]&e;e=b&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=b&1023;i=(d[g+(h+3)|0]|0)<<8|(d[g+(h+2)|0]|0)|((d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0))<<16}else{i=gj[c[f+196768+(g<<2)>>2]&4095](e)|0}e=nB(c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2]|0)|0;g=c[2276085]&e;e=g&16777215;f=c[2112932]|0;h=c[f+((e>>>10|16384)<<2)>>2]|0;if(h>>>0>9){b=g&1023;a[h+b|0]=i>>>16&255;g=i>>>24;a[h+(b+1)|0]=g&255;a[h+(b+2)|0]=i&255;a[h+(b+3)|0]=i>>>8&255;j=g;c[2276075]=j;c[2276076]=i;c[2276077]=0;c[2276078]=0;return}else{gg[c[f+196808+(h<<2)>>2]&4095](e,i);j=i>>>24;c[2276075]=j;c[2276076]=i;c[2276077]=0;c[2276078]=0;return}}function tO(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=(c[b>>2]|0)-4|0;c[b>>2]=e;b=c[2276085]&e;e=b&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=b&1023;i=(d[g+(h+3)|0]|0)<<8|(d[g+(h+2)|0]|0)|((d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0))<<16}else{i=gj[c[f+196768+(g<<2)>>2]&4095](e)|0}e=nB(c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2]|0)|0;g=c[2276085]&e;e=g&16777215;f=c[2112932]|0;h=c[f+((e>>>10|16384)<<2)>>2]|0;if(h>>>0>9){b=g&1023;a[h+b|0]=i>>>16&255;g=i>>>24;a[h+(b+1)|0]=g&255;a[h+(b+2)|0]=i&255;a[h+(b+3)|0]=i>>>8&255;j=g;c[2276075]=j;c[2276076]=i;c[2276077]=0;c[2276078]=0;return}else{gg[c[f+196808+(h<<2)>>2]&4095](e,i);j=i>>>24;c[2276075]=j;c[2276076]=i;c[2276077]=0;c[2276078]=0;return}}function tP(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=(h>>>((g<<3&16^16)>>>0)<<16>>16)+b&c[2276085];b=m&16777215;g=c[2112932]|0;h=c[g+(b>>>10<<2)>>2]|0;if(h>>>0>9){n=m&1023;o=(d[h+(n+3)|0]|0)<<8|(d[h+(n+2)|0]|0)|((d[h+(n+1)|0]|0)<<8|(d[h+n|0]|0))<<16}else{o=gj[c[g+196768+(h<<2)>>2]&4095](b)|0}b=nB(c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2]|0)|0;h=c[2276085]&b;b=h&16777215;g=c[2112932]|0;n=c[g+((b>>>10|16384)<<2)>>2]|0;if(n>>>0>9){m=h&1023;a[n+m|0]=o>>>16&255;h=o>>>24;a[n+(m+1)|0]=h&255;a[n+(m+2)|0]=o&255;a[n+(m+3)|0]=o>>>8&255;p=h;c[2276075]=p;c[2276076]=o;c[2276077]=0;c[2276078]=0;return}else{gg[c[g+196808+(n<<2)>>2]&4095](b,o);p=o>>>24;c[2276075]=p;c[2276076]=o;c[2276077]=0;c[2276078]=0;return}}function tQ(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0;b=nB(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;e=c[2276085]&b;b=e&16777215;f=c[2112932]|0;g=c[f+(b>>>10<<2)>>2]|0;if(g>>>0>9){h=e&1023;i=(d[g+(h+3)|0]|0)<<8|(d[g+(h+2)|0]|0)|((d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0))<<16}else{i=gj[c[f+196768+(g<<2)>>2]&4095](b)|0}b=nB(c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2]|0)|0;g=c[2276085]&b;b=g&16777215;f=c[2112932]|0;h=c[f+((b>>>10|16384)<<2)>>2]|0;if(h>>>0>9){e=g&1023;a[h+e|0]=i>>>16&255;g=i>>>24;a[h+(e+1)|0]=g&255;a[h+(e+2)|0]=i&255;a[h+(e+3)|0]=i>>>8&255;j=g;c[2276075]=j;c[2276076]=i;c[2276077]=0;c[2276078]=0;return}else{gg[c[f+196808+(h<<2)>>2]&4095](b,i);j=i>>>24;c[2276075]=j;c[2276076]=i;c[2276077]=0;c[2276078]=0;return}}function tR(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)<<16>>16&c[2276085];f=l&16777215;g=c[2112932]|0;m=c[g+(f>>>10<<2)>>2]|0;if(m>>>0>9){b=l&1023;n=(d[m+(b+3)|0]|0)<<8|(d[m+(b+2)|0]|0)|((d[m+(b+1)|0]|0)<<8|(d[m+b|0]|0))<<16}else{n=gj[c[g+196768+(m<<2)>>2]&4095](f)|0}f=nB(c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2]|0)|0;m=c[2276085]&f;f=m&16777215;g=c[2112932]|0;b=c[g+((f>>>10|16384)<<2)>>2]|0;if(b>>>0>9){l=m&1023;a[b+l|0]=n>>>16&255;m=n>>>24;a[b+(l+1)|0]=m&255;a[b+(l+2)|0]=n&255;a[b+(l+3)|0]=n>>>8&255;o=m;c[2276075]=o;c[2276076]=n;c[2276077]=0;c[2276078]=0;return}else{gg[c[g+196808+(b<<2)>>2]&4095](f,n);o=n>>>24;c[2276075]=o;c[2276076]=n;c[2276077]=0;c[2276078]=0;return}}function tS(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[2276085]&q;q=r&16777215;t=c[2112932]|0;h=c[t+(q>>>10<<2)>>2]|0;if(h>>>0>9){s=r&1023;u=(d[h+(s+3)|0]|0)<<8|(d[h+(s+2)|0]|0)|((d[h+(s+1)|0]|0)<<8|(d[h+s|0]|0))<<16}else{u=gj[c[t+196768+(h<<2)>>2]&4095](q)|0}q=nB(c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2]|0)|0;h=c[2276085]&q;q=h&16777215;t=c[2112932]|0;s=c[t+((q>>>10|16384)<<2)>>2]|0;if(s>>>0>9){r=h&1023;a[s+r|0]=u>>>16&255;h=u>>>24;a[s+(r+1)|0]=h&255;a[s+(r+2)|0]=u&255;a[s+(r+3)|0]=u>>>8&255;v=h;c[2276075]=v;c[2276076]=u;c[2276077]=0;c[2276078]=0;return}else{gg[c[t+196808+(s<<2)>>2]&4095](q,u);v=u>>>24;c[2276075]=v;c[2276076]=u;c[2276077]=0;c[2276078]=0;return}}function tT(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{k=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=k;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=(g>>>((f<<3&16^16)>>>0)<<16>>16)+b|0;b=l&16777215;f=c[2112932]|0;g=c[f+((b>>>10|32768)<<2)>>2]|0;if(g>>>0>9){m=l&1023;n=(d[g+(m+3)|0]|0)<<8|(d[g+(m+2)|0]|0)|((d[g+(m+1)|0]|0)<<8|(d[g+m|0]|0))<<16}else{n=gj[c[f+196768+(g<<2)>>2]&4095](b)|0}b=nB(c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2]|0)|0;g=c[2276085]&b;b=g&16777215;f=c[2112932]|0;m=c[f+((b>>>10|16384)<<2)>>2]|0;if(m>>>0>9){l=g&1023;a[m+l|0]=n>>>16&255;g=n>>>24;a[m+(l+1)|0]=g&255;a[m+(l+2)|0]=n&255;a[m+(l+3)|0]=n>>>8&255;o=g;c[2276075]=o;c[2276076]=n;c[2276077]=0;c[2276078]=0;return}else{gg[c[f+196808+(m<<2)>>2]&4095](b,n);o=n>>>24;c[2276075]=o;c[2276076]=n;c[2276077]=0;c[2276078]=0;return}}function tU(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0;b=nB(c[2276056]|0)|0;e=b&16777215;f=c[2112932]|0;g=c[f+((e>>>10|32768)<<2)>>2]|0;if(g>>>0>9){h=b&1023;i=(d[g+(h+3)|0]|0)<<8|(d[g+(h+2)|0]|0)|((d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0))<<16}else{i=gj[c[f+196768+(g<<2)>>2]&4095](e)|0}e=nB(c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2]|0)|0;g=c[2276085]&e;e=g&16777215;f=c[2112932]|0;h=c[f+((e>>>10|16384)<<2)>>2]|0;if(h>>>0>9){b=g&1023;a[h+b|0]=i>>>16&255;g=i>>>24;a[h+(b+1)|0]=g&255;a[h+(b+2)|0]=i&255;a[h+(b+3)|0]=i>>>8&255;j=g;c[2276075]=j;c[2276076]=i;c[2276077]=0;c[2276078]=0;return}else{gg[c[f+196808+(h<<2)>>2]&4095](e,i);j=i>>>24;c[2276075]=j;c[2276076]=i;c[2276077]=0;c[2276078]=0;return}}function tV(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=nB(c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2]|0)|0;t=c[2276085]&r;r=t&16777215;h=c[2112932]|0;s=c[h+((r>>>10|16384)<<2)>>2]|0;if(s>>>0>9){n=t&1023;a[s+n|0]=q>>>16&255;t=q>>>24;a[s+(n+1)|0]=t&255;a[s+(n+2)|0]=q&255;a[s+(n+3)|0]=q>>>8&255;u=t;c[2276075]=u;c[2276076]=q;c[2276077]=0;c[2276078]=0;return}else{gg[c[h+196808+(s<<2)>>2]&4095](r,q);u=q>>>24;c[2276075]=u;c[2276076]=q;c[2276077]=0;c[2276078]=0;return}}function tW(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=c[9104156+((c[2276069]&7)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=h>>>((g<<3&16^16)>>>0)<<16>>16&c[2276085];g=m&16777215;h=c[2112932]|0;n=c[h+((g>>>10|16384)<<2)>>2]|0;if(n>>>0>9){e=m&1023;a[n+e|0]=b>>>16&255;m=b>>>24;a[n+(e+1)|0]=m&255;a[n+(e+2)|0]=b&255;a[n+(e+3)|0]=b>>>8&255;o=m;c[2276075]=o;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}else{gg[c[h+196808+(n<<2)>>2]&4095](g,b);o=b>>>24;c[2276075]=o;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}}function tX(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=h>>>((g<<3&16^16)>>>0)<<16>>16&c[2276085];g=m&16777215;h=c[2112932]|0;n=c[h+((g>>>10|16384)<<2)>>2]|0;if(n>>>0>9){e=m&1023;a[n+e|0]=b>>>16&255;m=b>>>24;a[n+(e+1)|0]=m&255;a[n+(e+2)|0]=b&255;a[n+(e+3)|0]=b>>>8&255;o=m;c[2276075]=o;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}else{gg[c[h+196808+(n<<2)>>2]&4095](g,b);o=b>>>24;c[2276075]=o;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}}function tY(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=c[2276085]&c[9104156+((c[2276069]&7|8)<<2)>>2];e=b&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=b&1023;i=(d[g+(h+3)|0]|0)<<8|(d[g+(h+2)|0]|0)|((d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0))<<16}else{i=gj[c[f+196768+(g<<2)>>2]&4095](e)|0}e=c[2276056]|0;g=e&-4;if((g|0)==(c[2276083]|0)){j=e;k=c[2276084]|0}else{c[2276083]=g;f=c[2276085]&g;g=f&16777212;h=c[2112932]|0;b=c[h+((g>>>10|32768)<<2)>>2]|0;if(b>>>0>9){l=f&1020;m=(d[b+(l|3)|0]|0)<<8|(d[b+(l|2)|0]|0)|((d[b+(l|1)|0]|0)<<8|(d[b+l|0]|0))<<16;n=e}else{e=gj[c[h+196768+(b<<2)>>2]&4095](g)|0;m=e;n=c[2276056]|0}c[2276084]=m;j=n;k=m}c[2276056]=j+2;m=k>>>((j<<3&16^16)>>>0)<<16>>16&c[2276085];j=m&16777215;k=c[2112932]|0;n=c[k+((j>>>10|16384)<<2)>>2]|0;if(n>>>0>9){e=m&1023;a[n+e|0]=i>>>16&255;m=i>>>24;a[n+(e+1)|0]=m&255;a[n+(e+2)|0]=i&255;a[n+(e+3)|0]=i>>>8&255;o=m;c[2276075]=o;c[2276076]=i;c[2276077]=0;c[2276078]=0;return}else{gg[c[k+196808+(n<<2)>>2]&4095](j,i);o=i>>>24;c[2276075]=o;c[2276076]=i;c[2276077]=0;c[2276078]=0;return}}function tZ(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=c[b>>2]|0;c[b>>2]=e+4;b=c[2276085]&e;e=b&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=b&1023;i=(d[g+(h+3)|0]|0)<<8|(d[g+(h+2)|0]|0)|((d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0))<<16}else{i=gj[c[f+196768+(g<<2)>>2]&4095](e)|0}e=c[2276056]|0;g=e&-4;if((g|0)==(c[2276083]|0)){j=e;k=c[2276084]|0}else{c[2276083]=g;f=c[2276085]&g;g=f&16777212;h=c[2112932]|0;b=c[h+((g>>>10|32768)<<2)>>2]|0;if(b>>>0>9){l=f&1020;m=(d[b+(l|3)|0]|0)<<8|(d[b+(l|2)|0]|0)|((d[b+(l|1)|0]|0)<<8|(d[b+l|0]|0))<<16;n=e}else{e=gj[c[h+196768+(b<<2)>>2]&4095](g)|0;m=e;n=c[2276056]|0}c[2276084]=m;j=n;k=m}c[2276056]=j+2;m=k>>>((j<<3&16^16)>>>0)<<16>>16&c[2276085];j=m&16777215;k=c[2112932]|0;n=c[k+((j>>>10|16384)<<2)>>2]|0;if(n>>>0>9){e=m&1023;a[n+e|0]=i>>>16&255;m=i>>>24;a[n+(e+1)|0]=m&255;a[n+(e+2)|0]=i&255;a[n+(e+3)|0]=i>>>8&255;o=m;c[2276075]=o;c[2276076]=i;c[2276077]=0;c[2276078]=0;return}else{gg[c[k+196808+(n<<2)>>2]&4095](j,i);o=i>>>24;c[2276075]=o;c[2276076]=i;c[2276077]=0;c[2276078]=0;return}}function t_(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=(c[b>>2]|0)-4|0;c[b>>2]=e;b=c[2276085]&e;e=b&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=b&1023;i=(d[g+(h+3)|0]|0)<<8|(d[g+(h+2)|0]|0)|((d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0))<<16}else{i=gj[c[f+196768+(g<<2)>>2]&4095](e)|0}e=c[2276056]|0;g=e&-4;if((g|0)==(c[2276083]|0)){j=e;k=c[2276084]|0}else{c[2276083]=g;f=c[2276085]&g;g=f&16777212;h=c[2112932]|0;b=c[h+((g>>>10|32768)<<2)>>2]|0;if(b>>>0>9){l=f&1020;m=(d[b+(l|3)|0]|0)<<8|(d[b+(l|2)|0]|0)|((d[b+(l|1)|0]|0)<<8|(d[b+l|0]|0))<<16;n=e}else{e=gj[c[h+196768+(b<<2)>>2]&4095](g)|0;m=e;n=c[2276056]|0}c[2276084]=m;j=n;k=m}c[2276056]=j+2;m=k>>>((j<<3&16^16)>>>0)<<16>>16&c[2276085];j=m&16777215;k=c[2112932]|0;n=c[k+((j>>>10|16384)<<2)>>2]|0;if(n>>>0>9){e=m&1023;a[n+e|0]=i>>>16&255;m=i>>>24;a[n+(e+1)|0]=m&255;a[n+(e+2)|0]=i&255;a[n+(e+3)|0]=i>>>8&255;o=m;c[2276075]=o;c[2276076]=i;c[2276077]=0;c[2276078]=0;return}else{gg[c[k+196808+(n<<2)>>2]&4095](j,i);o=i>>>24;c[2276075]=o;c[2276076]=i;c[2276077]=0;c[2276078]=0;return}}function t$(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}m=g+2|0;c[2276056]=m;n=(h>>>((g<<3&16^16)>>>0)<<16>>16)+b&c[2276085];b=n&16777215;g=c[2112932]|0;h=c[g+(b>>>10<<2)>>2]|0;if(h>>>0>9){e=n&1023;o=(d[h+(e+3)|0]|0)<<8|(d[h+(e+2)|0]|0)|((d[h+(e+1)|0]|0)<<8|(d[h+e|0]|0))<<16;p=m}else{m=gj[c[g+196768+(h<<2)>>2]&4095](b)|0;o=m;p=c[2276056]|0}m=p&-4;if((m|0)==(c[2276083]|0)){q=p;r=c[2276084]|0}else{c[2276083]=m;b=c[2276085]&m;m=b&16777212;h=c[2112932]|0;g=c[h+((m>>>10|32768)<<2)>>2]|0;if(g>>>0>9){e=b&1020;s=(d[g+(e|3)|0]|0)<<8|(d[g+(e|2)|0]|0)|((d[g+(e|1)|0]|0)<<8|(d[g+e|0]|0))<<16;t=p}else{p=gj[c[h+196768+(g<<2)>>2]&4095](m)|0;s=p;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;s=r>>>((q<<3&16^16)>>>0)<<16>>16&c[2276085];q=s&16777215;r=c[2112932]|0;t=c[r+((q>>>10|16384)<<2)>>2]|0;if(t>>>0>9){p=s&1023;a[t+p|0]=o>>>16&255;s=o>>>24;a[t+(p+1)|0]=s&255;a[t+(p+2)|0]=o&255;a[t+(p+3)|0]=o>>>8&255;u=s;c[2276075]=u;c[2276076]=o;c[2276077]=0;c[2276078]=0;return}else{gg[c[r+196808+(t<<2)>>2]&4095](q,o);u=o>>>24;c[2276075]=u;c[2276076]=o;c[2276077]=0;c[2276078]=0;return}}function t0(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=nB(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;e=c[2276085]&b;b=e&16777215;f=c[2112932]|0;g=c[f+(b>>>10<<2)>>2]|0;if(g>>>0>9){h=e&1023;i=(d[g+(h+3)|0]|0)<<8|(d[g+(h+2)|0]|0)|((d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0))<<16}else{i=gj[c[f+196768+(g<<2)>>2]&4095](b)|0}b=c[2276056]|0;g=b&-4;if((g|0)==(c[2276083]|0)){j=b;k=c[2276084]|0}else{c[2276083]=g;f=c[2276085]&g;g=f&16777212;h=c[2112932]|0;e=c[h+((g>>>10|32768)<<2)>>2]|0;if(e>>>0>9){l=f&1020;m=(d[e+(l|3)|0]|0)<<8|(d[e+(l|2)|0]|0)|((d[e+(l|1)|0]|0)<<8|(d[e+l|0]|0))<<16;n=b}else{b=gj[c[h+196768+(e<<2)>>2]&4095](g)|0;m=b;n=c[2276056]|0}c[2276084]=m;j=n;k=m}c[2276056]=j+2;m=k>>>((j<<3&16^16)>>>0)<<16>>16&c[2276085];j=m&16777215;k=c[2112932]|0;n=c[k+((j>>>10|16384)<<2)>>2]|0;if(n>>>0>9){b=m&1023;a[n+b|0]=i>>>16&255;m=i>>>24;a[n+(b+1)|0]=m&255;a[n+(b+2)|0]=i&255;a[n+(b+3)|0]=i>>>8&255;o=m;c[2276075]=o;c[2276076]=i;c[2276077]=0;c[2276078]=0;return}else{gg[c[k+196808+(n<<2)>>2]&4095](j,i);o=i>>>24;c[2276075]=o;c[2276076]=i;c[2276077]=0;c[2276078]=0;return}}function t1(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}l=f+2|0;c[2276056]=l;m=g>>>((f<<3&16^16)>>>0)<<16>>16&c[2276085];f=m&16777215;g=c[2112932]|0;b=c[g+(f>>>10<<2)>>2]|0;if(b>>>0>9){e=m&1023;n=(d[b+(e+3)|0]|0)<<8|(d[b+(e+2)|0]|0)|((d[b+(e+1)|0]|0)<<8|(d[b+e|0]|0))<<16;o=l}else{l=gj[c[g+196768+(b<<2)>>2]&4095](f)|0;n=l;o=c[2276056]|0}l=o&-4;if((l|0)==(c[2276083]|0)){p=o;q=c[2276084]|0}else{c[2276083]=l;f=c[2276085]&l;l=f&16777212;b=c[2112932]|0;g=c[b+((l>>>10|32768)<<2)>>2]|0;if(g>>>0>9){e=f&1020;r=(d[g+(e|3)|0]|0)<<8|(d[g+(e|2)|0]|0)|((d[g+(e|1)|0]|0)<<8|(d[g+e|0]|0))<<16;s=o}else{o=gj[c[b+196768+(g<<2)>>2]&4095](l)|0;r=o;s=c[2276056]|0}c[2276084]=r;p=s;q=r}c[2276056]=p+2;r=q>>>((p<<3&16^16)>>>0)<<16>>16&c[2276085];p=r&16777215;q=c[2112932]|0;s=c[q+((p>>>10|16384)<<2)>>2]|0;if(s>>>0>9){o=r&1023;a[s+o|0]=n>>>16&255;r=n>>>24;a[s+(o+1)|0]=r&255;a[s+(o+2)|0]=n&255;a[s+(o+3)|0]=n>>>8&255;t=r;c[2276075]=t;c[2276076]=n;c[2276077]=0;c[2276078]=0;return}else{gg[c[q+196808+(s<<2)>>2]&4095](p,n);t=n>>>24;c[2276075]=t;c[2276076]=n;c[2276077]=0;c[2276078]=0;return}}function t2(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}t=r+2|0;c[2276056]=t;r=c[2276085]&q;q=r&16777215;h=c[2112932]|0;s=c[h+(q>>>10<<2)>>2]|0;if(s>>>0>9){n=r&1023;u=(d[s+(n+3)|0]|0)<<8|(d[s+(n+2)|0]|0)|((d[s+(n+1)|0]|0)<<8|(d[s+n|0]|0))<<16;v=t}else{t=gj[c[h+196768+(s<<2)>>2]&4095](q)|0;u=t;v=c[2276056]|0}t=v&-4;if((t|0)==(c[2276083]|0)){w=v;x=c[2276084]|0}else{c[2276083]=t;q=c[2276085]&t;t=q&16777212;s=c[2112932]|0;h=c[s+((t>>>10|32768)<<2)>>2]|0;if(h>>>0>9){n=q&1020;y=(d[h+(n|3)|0]|0)<<8|(d[h+(n|2)|0]|0)|((d[h+(n|1)|0]|0)<<8|(d[h+n|0]|0))<<16;z=v}else{v=gj[c[s+196768+(h<<2)>>2]&4095](t)|0;y=v;z=c[2276056]|0}c[2276084]=y;w=z;x=y}c[2276056]=w+2;y=x>>>((w<<3&16^16)>>>0)<<16>>16&c[2276085];w=y&16777215;x=c[2112932]|0;z=c[x+((w>>>10|16384)<<2)>>2]|0;if(z>>>0>9){v=y&1023;a[z+v|0]=u>>>16&255;y=u>>>24;a[z+(v+1)|0]=y&255;a[z+(v+2)|0]=u&255;a[z+(v+3)|0]=u>>>8&255;A=y;c[2276075]=A;c[2276076]=u;c[2276077]=0;c[2276078]=0;return}else{gg[c[x+196808+(z<<2)>>2]&4095](w,u);A=u>>>24;c[2276075]=A;c[2276076]=u;c[2276077]=0;c[2276078]=0;return}}function t3(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{k=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=k;m=c[2276056]|0}c[2276084]=l;f=m;g=l}l=f+2|0;c[2276056]=l;m=(g>>>((f<<3&16^16)>>>0)<<16>>16)+b|0;b=m&16777215;f=c[2112932]|0;g=c[f+((b>>>10|32768)<<2)>>2]|0;if(g>>>0>9){k=m&1023;n=(d[g+(k+3)|0]|0)<<8|(d[g+(k+2)|0]|0)|((d[g+(k+1)|0]|0)<<8|(d[g+k|0]|0))<<16;o=l}else{l=gj[c[f+196768+(g<<2)>>2]&4095](b)|0;n=l;o=c[2276056]|0}l=o&-4;if((l|0)==(c[2276083]|0)){p=o;q=c[2276084]|0}else{c[2276083]=l;b=c[2276085]&l;l=b&16777212;g=c[2112932]|0;f=c[g+((l>>>10|32768)<<2)>>2]|0;if(f>>>0>9){k=b&1020;r=(d[f+(k|3)|0]|0)<<8|(d[f+(k|2)|0]|0)|((d[f+(k|1)|0]|0)<<8|(d[f+k|0]|0))<<16;s=o}else{o=gj[c[g+196768+(f<<2)>>2]&4095](l)|0;r=o;s=c[2276056]|0}c[2276084]=r;p=s;q=r}c[2276056]=p+2;r=q>>>((p<<3&16^16)>>>0)<<16>>16&c[2276085];p=r&16777215;q=c[2112932]|0;s=c[q+((p>>>10|16384)<<2)>>2]|0;if(s>>>0>9){o=r&1023;a[s+o|0]=n>>>16&255;r=n>>>24;a[s+(o+1)|0]=r&255;a[s+(o+2)|0]=n&255;a[s+(o+3)|0]=n>>>8&255;t=r;c[2276075]=t;c[2276076]=n;c[2276077]=0;c[2276078]=0;return}else{gg[c[q+196808+(s<<2)>>2]&4095](p,n);t=n>>>24;c[2276075]=t;c[2276076]=n;c[2276077]=0;c[2276078]=0;return}}function t4(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=nB(c[2276056]|0)|0;e=b&16777215;f=c[2112932]|0;g=c[f+((e>>>10|32768)<<2)>>2]|0;if(g>>>0>9){h=b&1023;i=(d[g+(h+3)|0]|0)<<8|(d[g+(h+2)|0]|0)|((d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0))<<16}else{i=gj[c[f+196768+(g<<2)>>2]&4095](e)|0}e=c[2276056]|0;g=e&-4;if((g|0)==(c[2276083]|0)){j=e;k=c[2276084]|0}else{c[2276083]=g;f=c[2276085]&g;g=f&16777212;h=c[2112932]|0;b=c[h+((g>>>10|32768)<<2)>>2]|0;if(b>>>0>9){l=f&1020;m=(d[b+(l|3)|0]|0)<<8|(d[b+(l|2)|0]|0)|((d[b+(l|1)|0]|0)<<8|(d[b+l|0]|0))<<16;n=e}else{e=gj[c[h+196768+(b<<2)>>2]&4095](g)|0;m=e;n=c[2276056]|0}c[2276084]=m;j=n;k=m}c[2276056]=j+2;m=k>>>((j<<3&16^16)>>>0)<<16>>16&c[2276085];j=m&16777215;k=c[2112932]|0;n=c[k+((j>>>10|16384)<<2)>>2]|0;if(n>>>0>9){e=m&1023;a[n+e|0]=i>>>16&255;m=i>>>24;a[n+(e+1)|0]=m&255;a[n+(e+2)|0]=i&255;a[n+(e+3)|0]=i>>>8&255;o=m;c[2276075]=o;c[2276076]=i;c[2276077]=0;c[2276078]=0;return}else{gg[c[k+196808+(n<<2)>>2]&4095](j,i);o=i>>>24;c[2276075]=o;c[2276076]=i;c[2276077]=0;c[2276078]=0;return}}function t5(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;f=p&-4;if((f|0)==(h|0)){q=g;r=p;s=h;t=g}else{c[2276083]=f;h=c[2276085]&f;n=h&16777212;o=c[2112932]|0;e=c[o+((n>>>10|32768)<<2)>>2]|0;if(e>>>0>9){j=h&1020;u=(d[e+(j|3)|0]|0)<<8|(d[e+(j|2)|0]|0)|((d[e+(j|1)|0]|0)<<8|(d[e+j|0]|0))<<16;v=p;w=f}else{f=gj[c[o+196768+(e<<2)>>2]&4095](n)|0;u=f;v=c[2276056]|0;w=c[2276083]|0}c[2276084]=u;q=u>>>16|g<<16;r=v;s=w;t=u}u=r+2|0;c[2276056]=u;r=u&-4;if((r|0)==(s|0)){x=u;y=t}else{c[2276083]=r;t=c[2276085]&r;r=t&16777212;s=c[2112932]|0;w=c[s+((r>>>10|32768)<<2)>>2]|0;if(w>>>0>9){v=t&1020;z=(d[w+(v|3)|0]|0)<<8|(d[w+(v|2)|0]|0)|((d[w+(v|1)|0]|0)<<8|(d[w+v|0]|0))<<16;A=u}else{u=gj[c[s+196768+(w<<2)>>2]&4095](r)|0;z=u;A=c[2276056]|0}c[2276084]=z;x=A;y=z}c[2276056]=x+2;z=y>>>((x<<3&16^16)>>>0)<<16>>16&c[2276085];x=z&16777215;y=c[2112932]|0;A=c[y+((x>>>10|16384)<<2)>>2]|0;if(A>>>0>9){u=z&1023;a[A+u|0]=q>>>16&255;z=q>>>24;a[A+(u+1)|0]=z&255;a[A+(u+2)|0]=q&255;a[A+(u+3)|0]=q>>>8&255;B=z;c[2276075]=B;c[2276076]=q;c[2276077]=0;c[2276078]=0;return}else{gg[c[y+196808+(A<<2)>>2]&4095](x,q);B=q>>>24;c[2276075]=B;c[2276076]=q;c[2276077]=0;c[2276078]=0;return}}function t6(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;b=c[9104156+((c[2276069]&7)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=f;i=c[2276084]|0}else{c[2276083]=f;j=c[2276085]&f;k=j&16777212;l=c[2112932]|0;m=c[l+((k>>>10|32768)<<2)>>2]|0;if(m>>>0>9){n=j&1020;o=(d[m+(n|3)|0]|0)<<8|(d[m+(n|2)|0]|0)|((d[m+(n|1)|0]|0)<<8|(d[m+n|0]|0))<<16;p=e;q=f}else{f=gj[c[l+196768+(m<<2)>>2]&4095](k)|0;o=f;p=c[2276056]|0;q=c[2276083]|0}c[2276084]=o;g=p;h=q;i=o}o=g+2|0;c[2276056]=o;g=o&-4;if((g|0)==(h|0)){r=i;s=o}else{c[2276083]=g;h=c[2276085]&g;g=h&16777212;q=c[2112932]|0;p=c[q+((g>>>10|32768)<<2)>>2]|0;if(p>>>0>9){f=h&1020;t=(d[p+(f|3)|0]|0)<<8|(d[p+(f|2)|0]|0)|((d[p+(f|1)|0]|0)<<8|(d[p+f|0]|0))<<16;u=o}else{o=gj[c[q+196768+(p<<2)>>2]&4095](g)|0;t=o;u=c[2276056]|0}c[2276084]=t;r=t>>>16|i<<16;s=u}c[2276056]=s+2;s=c[2276085]&r;r=s&16777215;u=c[2112932]|0;i=c[u+((r>>>10|16384)<<2)>>2]|0;if(i>>>0>9){t=s&1023;a[i+t|0]=b>>>16&255;s=b>>>24;a[i+(t+1)|0]=s&255;a[i+(t+2)|0]=b&255;a[i+(t+3)|0]=b>>>8&255;v=s;c[2276075]=v;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}else{gg[c[u+196808+(i<<2)>>2]&4095](r,b);v=b>>>24;c[2276075]=v;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}}function t7(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=f;i=c[2276084]|0}else{c[2276083]=f;j=c[2276085]&f;k=j&16777212;l=c[2112932]|0;m=c[l+((k>>>10|32768)<<2)>>2]|0;if(m>>>0>9){n=j&1020;o=(d[m+(n|3)|0]|0)<<8|(d[m+(n|2)|0]|0)|((d[m+(n|1)|0]|0)<<8|(d[m+n|0]|0))<<16;p=e;q=f}else{f=gj[c[l+196768+(m<<2)>>2]&4095](k)|0;o=f;p=c[2276056]|0;q=c[2276083]|0}c[2276084]=o;g=p;h=q;i=o}o=g+2|0;c[2276056]=o;g=o&-4;if((g|0)==(h|0)){r=i;s=o}else{c[2276083]=g;h=c[2276085]&g;g=h&16777212;q=c[2112932]|0;p=c[q+((g>>>10|32768)<<2)>>2]|0;if(p>>>0>9){f=h&1020;t=(d[p+(f|3)|0]|0)<<8|(d[p+(f|2)|0]|0)|((d[p+(f|1)|0]|0)<<8|(d[p+f|0]|0))<<16;u=o}else{o=gj[c[q+196768+(p<<2)>>2]&4095](g)|0;t=o;u=c[2276056]|0}c[2276084]=t;r=t>>>16|i<<16;s=u}c[2276056]=s+2;s=c[2276085]&r;r=s&16777215;u=c[2112932]|0;i=c[u+((r>>>10|16384)<<2)>>2]|0;if(i>>>0>9){t=s&1023;a[i+t|0]=b>>>16&255;s=b>>>24;a[i+(t+1)|0]=s&255;a[i+(t+2)|0]=b&255;a[i+(t+3)|0]=b>>>8&255;v=s;c[2276075]=v;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}else{gg[c[u+196808+(i<<2)>>2]&4095](r,b);v=b>>>24;c[2276075]=v;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}}function t8(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;b=c[2276085]&c[9104156+((c[2276069]&7|8)<<2)>>2];e=b&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=b&1023;i=(d[g+(h+3)|0]|0)<<8|(d[g+(h+2)|0]|0)|((d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0))<<16}else{i=gj[c[f+196768+(g<<2)>>2]&4095](e)|0}e=c[2276056]|0;g=e&-4;if((g|0)==(c[2276083]|0)){j=e;k=g;l=c[2276084]|0}else{c[2276083]=g;f=c[2276085]&g;h=f&16777212;b=c[2112932]|0;m=c[b+((h>>>10|32768)<<2)>>2]|0;if(m>>>0>9){n=f&1020;o=(d[m+(n|3)|0]|0)<<8|(d[m+(n|2)|0]|0)|((d[m+(n|1)|0]|0)<<8|(d[m+n|0]|0))<<16;p=e;q=g}else{g=gj[c[b+196768+(m<<2)>>2]&4095](h)|0;o=g;p=c[2276056]|0;q=c[2276083]|0}c[2276084]=o;j=p;k=q;l=o}o=j+2|0;c[2276056]=o;j=o&-4;if((j|0)==(k|0)){r=l;s=o}else{c[2276083]=j;k=c[2276085]&j;j=k&16777212;q=c[2112932]|0;p=c[q+((j>>>10|32768)<<2)>>2]|0;if(p>>>0>9){g=k&1020;t=(d[p+(g|3)|0]|0)<<8|(d[p+(g|2)|0]|0)|((d[p+(g|1)|0]|0)<<8|(d[p+g|0]|0))<<16;u=o}else{o=gj[c[q+196768+(p<<2)>>2]&4095](j)|0;t=o;u=c[2276056]|0}c[2276084]=t;r=t>>>16|l<<16;s=u}c[2276056]=s+2;s=c[2276085]&r;r=s&16777215;u=c[2112932]|0;l=c[u+((r>>>10|16384)<<2)>>2]|0;if(l>>>0>9){t=s&1023;a[l+t|0]=i>>>16&255;s=i>>>24;a[l+(t+1)|0]=s&255;a[l+(t+2)|0]=i&255;a[l+(t+3)|0]=i>>>8&255;v=s;c[2276075]=v;c[2276076]=i;c[2276077]=0;c[2276078]=0;return}else{gg[c[u+196808+(l<<2)>>2]&4095](r,i);v=i>>>24;c[2276075]=v;c[2276076]=i;c[2276077]=0;c[2276078]=0;return}}function t9(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=c[b>>2]|0;c[b>>2]=e+4;b=c[2276085]&e;e=b&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=b&1023;i=(d[g+(h+3)|0]|0)<<8|(d[g+(h+2)|0]|0)|((d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0))<<16}else{i=gj[c[f+196768+(g<<2)>>2]&4095](e)|0}e=c[2276056]|0;g=e&-4;if((g|0)==(c[2276083]|0)){j=e;k=g;l=c[2276084]|0}else{c[2276083]=g;f=c[2276085]&g;h=f&16777212;b=c[2112932]|0;m=c[b+((h>>>10|32768)<<2)>>2]|0;if(m>>>0>9){n=f&1020;o=(d[m+(n|3)|0]|0)<<8|(d[m+(n|2)|0]|0)|((d[m+(n|1)|0]|0)<<8|(d[m+n|0]|0))<<16;p=e;q=g}else{g=gj[c[b+196768+(m<<2)>>2]&4095](h)|0;o=g;p=c[2276056]|0;q=c[2276083]|0}c[2276084]=o;j=p;k=q;l=o}o=j+2|0;c[2276056]=o;j=o&-4;if((j|0)==(k|0)){r=l;s=o}else{c[2276083]=j;k=c[2276085]&j;j=k&16777212;q=c[2112932]|0;p=c[q+((j>>>10|32768)<<2)>>2]|0;if(p>>>0>9){g=k&1020;t=(d[p+(g|3)|0]|0)<<8|(d[p+(g|2)|0]|0)|((d[p+(g|1)|0]|0)<<8|(d[p+g|0]|0))<<16;u=o}else{o=gj[c[q+196768+(p<<2)>>2]&4095](j)|0;t=o;u=c[2276056]|0}c[2276084]=t;r=t>>>16|l<<16;s=u}c[2276056]=s+2;s=c[2276085]&r;r=s&16777215;u=c[2112932]|0;l=c[u+((r>>>10|16384)<<2)>>2]|0;if(l>>>0>9){t=s&1023;a[l+t|0]=i>>>16&255;s=i>>>24;a[l+(t+1)|0]=s&255;a[l+(t+2)|0]=i&255;a[l+(t+3)|0]=i>>>8&255;v=s;c[2276075]=v;c[2276076]=i;c[2276077]=0;c[2276078]=0;return}else{gg[c[u+196808+(l<<2)>>2]&4095](r,i);v=i>>>24;c[2276075]=v;c[2276076]=i;c[2276077]=0;c[2276078]=0;return}}function ua(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=(c[b>>2]|0)-4|0;c[b>>2]=e;b=c[2276085]&e;e=b&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=b&1023;i=(d[g+(h+3)|0]|0)<<8|(d[g+(h+2)|0]|0)|((d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0))<<16}else{i=gj[c[f+196768+(g<<2)>>2]&4095](e)|0}e=c[2276056]|0;g=e&-4;if((g|0)==(c[2276083]|0)){j=e;k=g;l=c[2276084]|0}else{c[2276083]=g;f=c[2276085]&g;h=f&16777212;b=c[2112932]|0;m=c[b+((h>>>10|32768)<<2)>>2]|0;if(m>>>0>9){n=f&1020;o=(d[m+(n|3)|0]|0)<<8|(d[m+(n|2)|0]|0)|((d[m+(n|1)|0]|0)<<8|(d[m+n|0]|0))<<16;p=e;q=g}else{g=gj[c[b+196768+(m<<2)>>2]&4095](h)|0;o=g;p=c[2276056]|0;q=c[2276083]|0}c[2276084]=o;j=p;k=q;l=o}o=j+2|0;c[2276056]=o;j=o&-4;if((j|0)==(k|0)){r=l;s=o}else{c[2276083]=j;k=c[2276085]&j;j=k&16777212;q=c[2112932]|0;p=c[q+((j>>>10|32768)<<2)>>2]|0;if(p>>>0>9){g=k&1020;t=(d[p+(g|3)|0]|0)<<8|(d[p+(g|2)|0]|0)|((d[p+(g|1)|0]|0)<<8|(d[p+g|0]|0))<<16;u=o}else{o=gj[c[q+196768+(p<<2)>>2]&4095](j)|0;t=o;u=c[2276056]|0}c[2276084]=t;r=t>>>16|l<<16;s=u}c[2276056]=s+2;s=c[2276085]&r;r=s&16777215;u=c[2112932]|0;l=c[u+((r>>>10|16384)<<2)>>2]|0;if(l>>>0>9){t=s&1023;a[l+t|0]=i>>>16&255;s=i>>>24;a[l+(t+1)|0]=s&255;a[l+(t+2)|0]=i&255;a[l+(t+3)|0]=i>>>8&255;v=s;c[2276075]=v;c[2276076]=i;c[2276077]=0;c[2276078]=0;return}else{gg[c[u+196808+(l<<2)>>2]&4095](r,i);v=i>>>24;c[2276075]=v;c[2276076]=i;c[2276077]=0;c[2276078]=0;return}}function ub(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}m=g+2|0;c[2276056]=m;n=(h>>>((g<<3&16^16)>>>0)<<16>>16)+b&c[2276085];b=n&16777215;g=c[2112932]|0;h=c[g+(b>>>10<<2)>>2]|0;if(h>>>0>9){e=n&1023;o=(d[h+(e+3)|0]|0)<<8|(d[h+(e+2)|0]|0)|((d[h+(e+1)|0]|0)<<8|(d[h+e|0]|0))<<16;p=m}else{m=gj[c[g+196768+(h<<2)>>2]&4095](b)|0;o=m;p=c[2276056]|0}m=p&-4;if((m|0)==(c[2276083]|0)){q=p;r=m;s=c[2276084]|0}else{c[2276083]=m;b=c[2276085]&m;h=b&16777212;g=c[2112932]|0;e=c[g+((h>>>10|32768)<<2)>>2]|0;if(e>>>0>9){n=b&1020;t=(d[e+(n|3)|0]|0)<<8|(d[e+(n|2)|0]|0)|((d[e+(n|1)|0]|0)<<8|(d[e+n|0]|0))<<16;u=p;v=m}else{m=gj[c[g+196768+(e<<2)>>2]&4095](h)|0;t=m;u=c[2276056]|0;v=c[2276083]|0}c[2276084]=t;q=u;r=v;s=t}t=q+2|0;c[2276056]=t;q=t&-4;if((q|0)==(r|0)){w=s;x=t}else{c[2276083]=q;r=c[2276085]&q;q=r&16777212;v=c[2112932]|0;u=c[v+((q>>>10|32768)<<2)>>2]|0;if(u>>>0>9){m=r&1020;y=(d[u+(m|3)|0]|0)<<8|(d[u+(m|2)|0]|0)|((d[u+(m|1)|0]|0)<<8|(d[u+m|0]|0))<<16;z=t}else{t=gj[c[v+196768+(u<<2)>>2]&4095](q)|0;y=t;z=c[2276056]|0}c[2276084]=y;w=y>>>16|s<<16;x=z}c[2276056]=x+2;x=c[2276085]&w;w=x&16777215;z=c[2112932]|0;s=c[z+((w>>>10|16384)<<2)>>2]|0;if(s>>>0>9){y=x&1023;a[s+y|0]=o>>>16&255;x=o>>>24;a[s+(y+1)|0]=x&255;a[s+(y+2)|0]=o&255;a[s+(y+3)|0]=o>>>8&255;A=x;c[2276075]=A;c[2276076]=o;c[2276077]=0;c[2276078]=0;return}else{gg[c[z+196808+(s<<2)>>2]&4095](w,o);A=o>>>24;c[2276075]=A;c[2276076]=o;c[2276077]=0;c[2276078]=0;return}}function uc(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;b=nB(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;e=c[2276085]&b;b=e&16777215;f=c[2112932]|0;g=c[f+(b>>>10<<2)>>2]|0;if(g>>>0>9){h=e&1023;i=(d[g+(h+3)|0]|0)<<8|(d[g+(h+2)|0]|0)|((d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0))<<16}else{i=gj[c[f+196768+(g<<2)>>2]&4095](b)|0}b=c[2276056]|0;g=b&-4;if((g|0)==(c[2276083]|0)){j=b;k=g;l=c[2276084]|0}else{c[2276083]=g;f=c[2276085]&g;h=f&16777212;e=c[2112932]|0;m=c[e+((h>>>10|32768)<<2)>>2]|0;if(m>>>0>9){n=f&1020;o=(d[m+(n|3)|0]|0)<<8|(d[m+(n|2)|0]|0)|((d[m+(n|1)|0]|0)<<8|(d[m+n|0]|0))<<16;p=b;q=g}else{g=gj[c[e+196768+(m<<2)>>2]&4095](h)|0;o=g;p=c[2276056]|0;q=c[2276083]|0}c[2276084]=o;j=p;k=q;l=o}o=j+2|0;c[2276056]=o;j=o&-4;if((j|0)==(k|0)){r=l;s=o}else{c[2276083]=j;k=c[2276085]&j;j=k&16777212;q=c[2112932]|0;p=c[q+((j>>>10|32768)<<2)>>2]|0;if(p>>>0>9){g=k&1020;t=(d[p+(g|3)|0]|0)<<8|(d[p+(g|2)|0]|0)|((d[p+(g|1)|0]|0)<<8|(d[p+g|0]|0))<<16;u=o}else{o=gj[c[q+196768+(p<<2)>>2]&4095](j)|0;t=o;u=c[2276056]|0}c[2276084]=t;r=t>>>16|l<<16;s=u}c[2276056]=s+2;s=c[2276085]&r;r=s&16777215;u=c[2112932]|0;l=c[u+((r>>>10|16384)<<2)>>2]|0;if(l>>>0>9){t=s&1023;a[l+t|0]=i>>>16&255;s=i>>>24;a[l+(t+1)|0]=s&255;a[l+(t+2)|0]=i&255;a[l+(t+3)|0]=i>>>8&255;v=s;c[2276075]=v;c[2276076]=i;c[2276077]=0;c[2276078]=0;return}else{gg[c[u+196808+(l<<2)>>2]&4095](r,i);v=i>>>24;c[2276075]=v;c[2276076]=i;c[2276077]=0;c[2276078]=0;return}}function ud(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}l=f+2|0;c[2276056]=l;m=g>>>((f<<3&16^16)>>>0)<<16>>16&c[2276085];f=m&16777215;g=c[2112932]|0;b=c[g+(f>>>10<<2)>>2]|0;if(b>>>0>9){e=m&1023;n=(d[b+(e+3)|0]|0)<<8|(d[b+(e+2)|0]|0)|((d[b+(e+1)|0]|0)<<8|(d[b+e|0]|0))<<16;o=l}else{l=gj[c[g+196768+(b<<2)>>2]&4095](f)|0;n=l;o=c[2276056]|0}l=o&-4;if((l|0)==(c[2276083]|0)){p=o;q=l;r=c[2276084]|0}else{c[2276083]=l;f=c[2276085]&l;b=f&16777212;g=c[2112932]|0;e=c[g+((b>>>10|32768)<<2)>>2]|0;if(e>>>0>9){m=f&1020;s=(d[e+(m|3)|0]|0)<<8|(d[e+(m|2)|0]|0)|((d[e+(m|1)|0]|0)<<8|(d[e+m|0]|0))<<16;t=o;u=l}else{l=gj[c[g+196768+(e<<2)>>2]&4095](b)|0;s=l;t=c[2276056]|0;u=c[2276083]|0}c[2276084]=s;p=t;q=u;r=s}s=p+2|0;c[2276056]=s;p=s&-4;if((p|0)==(q|0)){v=r;w=s}else{c[2276083]=p;q=c[2276085]&p;p=q&16777212;u=c[2112932]|0;t=c[u+((p>>>10|32768)<<2)>>2]|0;if(t>>>0>9){l=q&1020;x=(d[t+(l|3)|0]|0)<<8|(d[t+(l|2)|0]|0)|((d[t+(l|1)|0]|0)<<8|(d[t+l|0]|0))<<16;y=s}else{s=gj[c[u+196768+(t<<2)>>2]&4095](p)|0;x=s;y=c[2276056]|0}c[2276084]=x;v=x>>>16|r<<16;w=y}c[2276056]=w+2;w=c[2276085]&v;v=w&16777215;y=c[2112932]|0;r=c[y+((v>>>10|16384)<<2)>>2]|0;if(r>>>0>9){x=w&1023;a[r+x|0]=n>>>16&255;w=n>>>24;a[r+(x+1)|0]=w&255;a[r+(x+2)|0]=n&255;a[r+(x+3)|0]=n>>>8&255;z=w;c[2276075]=z;c[2276076]=n;c[2276077]=0;c[2276078]=0;return}else{gg[c[y+196808+(r<<2)>>2]&4095](v,n);z=n>>>24;c[2276075]=z;c[2276076]=n;c[2276077]=0;c[2276078]=0;return}}function ue(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}t=r+2|0;c[2276056]=t;r=c[2276085]&q;q=r&16777215;h=c[2112932]|0;s=c[h+(q>>>10<<2)>>2]|0;if(s>>>0>9){n=r&1023;u=(d[s+(n+3)|0]|0)<<8|(d[s+(n+2)|0]|0)|((d[s+(n+1)|0]|0)<<8|(d[s+n|0]|0))<<16;v=t}else{t=gj[c[h+196768+(s<<2)>>2]&4095](q)|0;u=t;v=c[2276056]|0}t=v&-4;if((t|0)==(c[2276083]|0)){w=v;x=t;y=c[2276084]|0}else{c[2276083]=t;q=c[2276085]&t;s=q&16777212;h=c[2112932]|0;n=c[h+((s>>>10|32768)<<2)>>2]|0;if(n>>>0>9){r=q&1020;z=(d[n+(r|3)|0]|0)<<8|(d[n+(r|2)|0]|0)|((d[n+(r|1)|0]|0)<<8|(d[n+r|0]|0))<<16;A=v;B=t}else{t=gj[c[h+196768+(n<<2)>>2]&4095](s)|0;z=t;A=c[2276056]|0;B=c[2276083]|0}c[2276084]=z;w=A;x=B;y=z}z=w+2|0;c[2276056]=z;w=z&-4;if((w|0)==(x|0)){C=y;D=z}else{c[2276083]=w;x=c[2276085]&w;w=x&16777212;B=c[2112932]|0;A=c[B+((w>>>10|32768)<<2)>>2]|0;if(A>>>0>9){t=x&1020;E=(d[A+(t|3)|0]|0)<<8|(d[A+(t|2)|0]|0)|((d[A+(t|1)|0]|0)<<8|(d[A+t|0]|0))<<16;F=z}else{z=gj[c[B+196768+(A<<2)>>2]&4095](w)|0;E=z;F=c[2276056]|0}c[2276084]=E;C=E>>>16|y<<16;D=F}c[2276056]=D+2;D=c[2276085]&C;C=D&16777215;F=c[2112932]|0;y=c[F+((C>>>10|16384)<<2)>>2]|0;if(y>>>0>9){E=D&1023;a[y+E|0]=u>>>16&255;D=u>>>24;a[y+(E+1)|0]=D&255;a[y+(E+2)|0]=u&255;a[y+(E+3)|0]=u>>>8&255;G=D;c[2276075]=G;c[2276076]=u;c[2276077]=0;c[2276078]=0;return}else{gg[c[F+196808+(y<<2)>>2]&4095](C,u);G=u>>>24;c[2276075]=G;c[2276076]=u;c[2276077]=0;c[2276078]=0;return}}function uf(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{k=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=k;m=c[2276056]|0}c[2276084]=l;f=m;g=l}l=f+2|0;c[2276056]=l;m=(g>>>((f<<3&16^16)>>>0)<<16>>16)+b|0;b=m&16777215;f=c[2112932]|0;g=c[f+((b>>>10|32768)<<2)>>2]|0;if(g>>>0>9){k=m&1023;n=(d[g+(k+3)|0]|0)<<8|(d[g+(k+2)|0]|0)|((d[g+(k+1)|0]|0)<<8|(d[g+k|0]|0))<<16;o=l}else{l=gj[c[f+196768+(g<<2)>>2]&4095](b)|0;n=l;o=c[2276056]|0}l=o&-4;if((l|0)==(c[2276083]|0)){p=o;q=l;r=c[2276084]|0}else{c[2276083]=l;b=c[2276085]&l;g=b&16777212;f=c[2112932]|0;k=c[f+((g>>>10|32768)<<2)>>2]|0;if(k>>>0>9){m=b&1020;s=(d[k+(m|3)|0]|0)<<8|(d[k+(m|2)|0]|0)|((d[k+(m|1)|0]|0)<<8|(d[k+m|0]|0))<<16;t=o;u=l}else{l=gj[c[f+196768+(k<<2)>>2]&4095](g)|0;s=l;t=c[2276056]|0;u=c[2276083]|0}c[2276084]=s;p=t;q=u;r=s}s=p+2|0;c[2276056]=s;p=s&-4;if((p|0)==(q|0)){v=r;w=s}else{c[2276083]=p;q=c[2276085]&p;p=q&16777212;u=c[2112932]|0;t=c[u+((p>>>10|32768)<<2)>>2]|0;if(t>>>0>9){l=q&1020;x=(d[t+(l|3)|0]|0)<<8|(d[t+(l|2)|0]|0)|((d[t+(l|1)|0]|0)<<8|(d[t+l|0]|0))<<16;y=s}else{s=gj[c[u+196768+(t<<2)>>2]&4095](p)|0;x=s;y=c[2276056]|0}c[2276084]=x;v=x>>>16|r<<16;w=y}c[2276056]=w+2;w=c[2276085]&v;v=w&16777215;y=c[2112932]|0;r=c[y+((v>>>10|16384)<<2)>>2]|0;if(r>>>0>9){x=w&1023;a[r+x|0]=n>>>16&255;w=n>>>24;a[r+(x+1)|0]=w&255;a[r+(x+2)|0]=n&255;a[r+(x+3)|0]=n>>>8&255;z=w;c[2276075]=z;c[2276076]=n;c[2276077]=0;c[2276078]=0;return}else{gg[c[y+196808+(r<<2)>>2]&4095](v,n);z=n>>>24;c[2276075]=z;c[2276076]=n;c[2276077]=0;c[2276078]=0;return}}function ug(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;b=nB(c[2276056]|0)|0;e=b&16777215;f=c[2112932]|0;g=c[f+((e>>>10|32768)<<2)>>2]|0;if(g>>>0>9){h=b&1023;i=(d[g+(h+3)|0]|0)<<8|(d[g+(h+2)|0]|0)|((d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0))<<16}else{i=gj[c[f+196768+(g<<2)>>2]&4095](e)|0}e=c[2276056]|0;g=e&-4;if((g|0)==(c[2276083]|0)){j=e;k=g;l=c[2276084]|0}else{c[2276083]=g;f=c[2276085]&g;h=f&16777212;b=c[2112932]|0;m=c[b+((h>>>10|32768)<<2)>>2]|0;if(m>>>0>9){n=f&1020;o=(d[m+(n|3)|0]|0)<<8|(d[m+(n|2)|0]|0)|((d[m+(n|1)|0]|0)<<8|(d[m+n|0]|0))<<16;p=e;q=g}else{g=gj[c[b+196768+(m<<2)>>2]&4095](h)|0;o=g;p=c[2276056]|0;q=c[2276083]|0}c[2276084]=o;j=p;k=q;l=o}o=j+2|0;c[2276056]=o;j=o&-4;if((j|0)==(k|0)){r=l;s=o}else{c[2276083]=j;k=c[2276085]&j;j=k&16777212;q=c[2112932]|0;p=c[q+((j>>>10|32768)<<2)>>2]|0;if(p>>>0>9){g=k&1020;t=(d[p+(g|3)|0]|0)<<8|(d[p+(g|2)|0]|0)|((d[p+(g|1)|0]|0)<<8|(d[p+g|0]|0))<<16;u=o}else{o=gj[c[q+196768+(p<<2)>>2]&4095](j)|0;t=o;u=c[2276056]|0}c[2276084]=t;r=t>>>16|l<<16;s=u}c[2276056]=s+2;s=c[2276085]&r;r=s&16777215;u=c[2112932]|0;l=c[u+((r>>>10|16384)<<2)>>2]|0;if(l>>>0>9){t=s&1023;a[l+t|0]=i>>>16&255;s=i>>>24;a[l+(t+1)|0]=s&255;a[l+(t+2)|0]=i&255;a[l+(t+3)|0]=i>>>8&255;v=s;c[2276075]=v;c[2276076]=i;c[2276077]=0;c[2276078]=0;return}else{gg[c[u+196808+(l<<2)>>2]&4095](r,i);v=i>>>24;c[2276075]=v;c[2276076]=i;c[2276077]=0;c[2276078]=0;return}}function uh(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;f=p&-4;if((f|0)==(h|0)){q=g;r=p;s=h;t=g}else{c[2276083]=f;h=c[2276085]&f;n=h&16777212;o=c[2112932]|0;e=c[o+((n>>>10|32768)<<2)>>2]|0;if(e>>>0>9){j=h&1020;u=(d[e+(j|3)|0]|0)<<8|(d[e+(j|2)|0]|0)|((d[e+(j|1)|0]|0)<<8|(d[e+j|0]|0))<<16;v=p;w=f}else{f=gj[c[o+196768+(e<<2)>>2]&4095](n)|0;u=f;v=c[2276056]|0;w=c[2276083]|0}c[2276084]=u;q=u>>>16|g<<16;r=v;s=w;t=u}u=r+2|0;c[2276056]=u;r=u&-4;if((r|0)==(s|0)){x=u;y=s;z=t}else{c[2276083]=r;t=c[2276085]&r;s=t&16777212;w=c[2112932]|0;v=c[w+((s>>>10|32768)<<2)>>2]|0;if(v>>>0>9){g=t&1020;A=(d[v+(g|3)|0]|0)<<8|(d[v+(g|2)|0]|0)|((d[v+(g|1)|0]|0)<<8|(d[v+g|0]|0))<<16;B=u;C=r}else{r=gj[c[w+196768+(v<<2)>>2]&4095](s)|0;A=r;B=c[2276056]|0;C=c[2276083]|0}c[2276084]=A;x=B;y=C;z=A}A=x+2|0;c[2276056]=A;x=A&-4;if((x|0)==(y|0)){D=z;E=A}else{c[2276083]=x;y=c[2276085]&x;x=y&16777212;C=c[2112932]|0;B=c[C+((x>>>10|32768)<<2)>>2]|0;if(B>>>0>9){r=y&1020;F=(d[B+(r|3)|0]|0)<<8|(d[B+(r|2)|0]|0)|((d[B+(r|1)|0]|0)<<8|(d[B+r|0]|0))<<16;G=A}else{A=gj[c[C+196768+(B<<2)>>2]&4095](x)|0;F=A;G=c[2276056]|0}c[2276084]=F;D=F>>>16|z<<16;E=G}c[2276056]=E+2;E=c[2276085]&D;D=E&16777215;G=c[2112932]|0;z=c[G+((D>>>10|16384)<<2)>>2]|0;if(z>>>0>9){F=E&1023;a[z+F|0]=q>>>16&255;E=q>>>24;a[z+(F+1)|0]=E&255;a[z+(F+2)|0]=q&255;a[z+(F+3)|0]=q>>>8&255;H=E;c[2276075]=H;c[2276076]=q;c[2276077]=0;c[2276078]=0;return}else{gg[c[G+196808+(z<<2)>>2]&4095](D,q);H=q>>>24;c[2276075]=H;c[2276076]=q;c[2276077]=0;c[2276078]=0;return}}function ui(){var a=0;a=c[2276069]|0;c[9104156+((a>>>9&7|8)<<2)>>2]=c[9104156+((a&7)<<2)>>2]<<16>>16;return}function uj(){var a=0;a=c[2276069]|0;c[9104156+((a>>>9&7|8)<<2)>>2]=c[9104156+((a&7|8)<<2)>>2]<<16>>16;return}function uk(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=c[2276069]|0;b=c[2276085]&c[9104156+((a&7|8)<<2)>>2];e=b&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=b&1023;i=(d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0);j=a;k=i<<16>>16;l=j>>>9;m=l&7;n=m|8;o=9104156+(n<<2)|0;c[o>>2]=k;return}else{a=gj[c[f+196688+(g<<2)>>2]&4095](e)|0;i=a;j=c[2276069]|0;k=i<<16>>16;l=j>>>9;m=l&7;n=m|8;o=9104156+(n<<2)|0;c[o>>2]=k;return}}function ul(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=9104156+((c[2276069]&7|8)<<2)|0;b=c[a>>2]|0;c[a>>2]=b+2;a=c[2276085]&b;b=a&16777215;e=c[2112932]|0;f=c[e+(b>>>10<<2)>>2]|0;if(f>>>0>9){g=a&1023;h=(d[f+(g+1)|0]|0)<<8|(d[f+g|0]|0);i=h<<16>>16;j=c[2276069]|0;k=j>>>9;l=k&7;m=l|8;n=9104156+(m<<2)|0;c[n>>2]=i;return}else{h=gj[c[e+196688+(f<<2)>>2]&4095](b)|0;i=h<<16>>16;j=c[2276069]|0;k=j>>>9;l=k&7;m=l|8;n=9104156+(m<<2)|0;c[n>>2]=i;return}}function um(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=9104156+((c[2276069]&7|8)<<2)|0;b=(c[a>>2]|0)-2|0;c[a>>2]=b;a=c[2276085]&b;b=a&16777215;e=c[2112932]|0;f=c[e+(b>>>10<<2)>>2]|0;if(f>>>0>9){g=a&1023;h=(d[f+(g+1)|0]|0)<<8|(d[f+g|0]|0);i=h<<16>>16;j=c[2276069]|0;k=j>>>9;l=k&7;m=l|8;n=9104156+(m<<2)|0;c[n>>2]=i;return}else{h=gj[c[e+196688+(f<<2)>>2]&4095](b)|0;i=h<<16>>16;j=c[2276069]|0;k=j>>>9;l=k&7;m=l|8;n=9104156+(m<<2)|0;c[n>>2]=i;return}}function un(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;a=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=(g>>>((f<<3&16^16)>>>0)<<16>>16)+a&c[2276085];a=l&16777215;f=c[2112932]|0;g=c[f+(a>>>10<<2)>>2]|0;if(g>>>0>9){m=l&1023;n=(d[g+(m+1)|0]|0)<<8|(d[g+m|0]|0);o=n<<16>>16;p=c[2276069]|0;q=p>>>9;r=q&7;s=r|8;t=9104156+(s<<2)|0;c[t>>2]=o;return}else{n=gj[c[f+196688+(g<<2)>>2]&4095](a)|0;o=n<<16>>16;p=c[2276069]|0;q=p>>>9;r=q&7;s=r|8;t=9104156+(s<<2)|0;c[t>>2]=o;return}}function uo(){var a=0,b=0,e=0,f=0,g=0,h=0;a=nB(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;b=c[2276085]&a;a=b&16777215;e=c[2112932]|0;f=c[e+(a>>>10<<2)>>2]|0;if(f>>>0>9){g=b&1023;h=(d[f+(g+1)|0]|0)<<8|(d[f+g|0]|0)}else{h=gj[c[e+196688+(f<<2)>>2]&4095](a)|0}c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2]=h<<16>>16;return}function up(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=f>>>((e<<3&16^16)>>>0)<<16>>16&c[2276085];e=k&16777215;f=c[2112932]|0;l=c[f+(e>>>10<<2)>>2]|0;if(l>>>0>9){a=k&1023;m=(d[l+(a+1)|0]|0)<<8|(d[l+a|0]|0);n=m<<16>>16;o=c[2276069]|0;p=o>>>9;q=p&7;r=q|8;s=9104156+(r<<2)|0;c[s>>2]=n;return}else{m=gj[c[f+196688+(l<<2)>>2]&4095](e)|0;n=m<<16>>16;o=c[2276069]|0;p=o>>>9;q=p&7;r=q|8;s=9104156+(r<<2)|0;c[s>>2]=n;return}}function uq(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=b;g=c[2276084]|0}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=o;g=m}m=e+2|0;c[2276056]=m;e=m&-4;if((e|0)==(f|0)){p=g;q=m}else{c[2276083]=e;f=c[2276085]&e;e=f&16777212;o=c[2112932]|0;n=c[o+((e>>>10|32768)<<2)>>2]|0;if(n>>>0>9){b=f&1020;r=(d[n+(b|3)|0]|0)<<8|(d[n+(b|2)|0]|0)|((d[n+(b|1)|0]|0)<<8|(d[n+b|0]|0))<<16;s=m}else{m=gj[c[o+196768+(n<<2)>>2]&4095](e)|0;r=m;s=c[2276056]|0}c[2276084]=r;p=r>>>16|g<<16;q=s}c[2276056]=q+2;q=c[2276085]&p;p=q&16777215;s=c[2112932]|0;g=c[s+(p>>>10<<2)>>2]|0;if(g>>>0>9){r=q&1023;t=(d[g+(r+1)|0]|0)<<8|(d[g+r|0]|0);u=t<<16>>16;v=c[2276069]|0;w=v>>>9;x=w&7;y=x|8;z=9104156+(y<<2)|0;c[z>>2]=u;return}else{t=gj[c[s+196688+(g<<2)>>2]&4095](p)|0;u=t<<16>>16;v=c[2276069]|0;w=v>>>9;x=w&7;y=x|8;z=9104156+(y<<2)|0;c[z>>2]=u;return}}function ur(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{j=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=j;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=(f>>>((e<<3&16^16)>>>0)<<16>>16)+a|0;a=k&16777215;e=c[2112932]|0;f=c[e+((a>>>10|32768)<<2)>>2]|0;if(f>>>0>9){l=k&1023;m=(d[f+(l+1)|0]|0)<<8|(d[f+l|0]|0);n=m<<16>>16;o=c[2276069]|0;p=o>>>9;q=p&7;r=q|8;s=9104156+(r<<2)|0;c[s>>2]=n;return}else{m=gj[c[e+196688+(f<<2)>>2]&4095](a)|0;n=m<<16>>16;o=c[2276069]|0;p=o>>>9;q=p&7;r=q|8;s=9104156+(r<<2)|0;c[s>>2]=n;return}}function us(){var a=0,b=0,e=0,f=0,g=0,h=0;a=nB(c[2276056]|0)|0;b=a&16777215;e=c[2112932]|0;f=c[e+((b>>>10|32768)<<2)>>2]|0;if(f>>>0>9){g=a&1023;h=(d[f+(g+1)|0]|0)<<8|(d[f+g|0]|0)}else{h=gj[c[e+196688+(f<<2)>>2]&4095](b)|0}c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2]=h<<16>>16;return}function ut(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;c[9104156+(((c[2276069]|0)>>>9&7|8)<<2)>>2]=f>>>((e<<3&16^16)>>>0)<<16>>16;return}function uu(){var a=0;a=c[2276069]|0;c[9104156+((a>>>9&7|8)<<2)>>2]=c[9104156+((a&7)<<2)>>2];return}function uv(){var a=0;a=c[2276069]|0;c[9104156+((a>>>9&7|8)<<2)>>2]=c[9104156+((a&7|8)<<2)>>2];return}function uw(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=c[2276069]|0;b=c[2276085]&c[9104156+((a&7|8)<<2)>>2];e=b&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=b&1023;i=(d[g+(h+3)|0]|0)<<8|(d[g+(h+2)|0]|0)|((d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0))<<16;j=a;k=j>>>9;l=k&7;m=l|8;n=9104156+(m<<2)|0;c[n>>2]=i;return}else{a=gj[c[f+196768+(g<<2)>>2]&4095](e)|0;i=a;j=c[2276069]|0;k=j>>>9;l=k&7;m=l|8;n=9104156+(m<<2)|0;c[n>>2]=i;return}}function ux(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=9104156+((c[2276069]&7|8)<<2)|0;b=c[a>>2]|0;c[a>>2]=b+4;a=c[2276085]&b;b=a&16777215;e=c[2112932]|0;f=c[e+(b>>>10<<2)>>2]|0;if(f>>>0>9){g=a&1023;h=(d[f+(g+3)|0]|0)<<8|(d[f+(g+2)|0]|0)|((d[f+(g+1)|0]|0)<<8|(d[f+g|0]|0))<<16;i=c[2276069]|0;j=i>>>9;k=j&7;l=k|8;m=9104156+(l<<2)|0;c[m>>2]=h;return}else{h=gj[c[e+196768+(f<<2)>>2]&4095](b)|0;i=c[2276069]|0;j=i>>>9;k=j&7;l=k|8;m=9104156+(l<<2)|0;c[m>>2]=h;return}}function uy(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=9104156+((c[2276069]&7|8)<<2)|0;b=(c[a>>2]|0)-4|0;c[a>>2]=b;a=c[2276085]&b;b=a&16777215;e=c[2112932]|0;f=c[e+(b>>>10<<2)>>2]|0;if(f>>>0>9){g=a&1023;h=(d[f+(g+3)|0]|0)<<8|(d[f+(g+2)|0]|0)|((d[f+(g+1)|0]|0)<<8|(d[f+g|0]|0))<<16;i=c[2276069]|0;j=i>>>9;k=j&7;l=k|8;m=9104156+(l<<2)|0;c[m>>2]=h;return}else{h=gj[c[e+196768+(f<<2)>>2]&4095](b)|0;i=c[2276069]|0;j=i>>>9;k=j&7;l=k|8;m=9104156+(l<<2)|0;c[m>>2]=h;return}}function uz(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;a=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=(g>>>((f<<3&16^16)>>>0)<<16>>16)+a&c[2276085];a=l&16777215;f=c[2112932]|0;g=c[f+(a>>>10<<2)>>2]|0;if(g>>>0>9){m=l&1023;n=(d[g+(m+3)|0]|0)<<8|(d[g+(m+2)|0]|0)|((d[g+(m+1)|0]|0)<<8|(d[g+m|0]|0))<<16;o=c[2276069]|0;p=o>>>9;q=p&7;r=q|8;s=9104156+(r<<2)|0;c[s>>2]=n;return}else{n=gj[c[f+196768+(g<<2)>>2]&4095](a)|0;o=c[2276069]|0;p=o>>>9;q=p&7;r=q|8;s=9104156+(r<<2)|0;c[s>>2]=n;return}}function uA(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=nB(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;b=c[2276085]&a;a=b&16777215;e=c[2112932]|0;f=c[e+(a>>>10<<2)>>2]|0;if(f>>>0>9){g=b&1023;h=(d[f+(g+3)|0]|0)<<8|(d[f+(g+2)|0]|0)|((d[f+(g+1)|0]|0)<<8|(d[f+g|0]|0))<<16;i=c[2276069]|0;j=i>>>9;k=j&7;l=k|8;m=9104156+(l<<2)|0;c[m>>2]=h;return}else{h=gj[c[e+196768+(f<<2)>>2]&4095](a)|0;i=c[2276069]|0;j=i>>>9;k=j&7;l=k|8;m=9104156+(l<<2)|0;c[m>>2]=h;return}}function uB(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=f>>>((e<<3&16^16)>>>0)<<16>>16&c[2276085];e=k&16777215;f=c[2112932]|0;l=c[f+(e>>>10<<2)>>2]|0;if(l>>>0>9){a=k&1023;m=(d[l+(a+3)|0]|0)<<8|(d[l+(a+2)|0]|0)|((d[l+(a+1)|0]|0)<<8|(d[l+a|0]|0))<<16;n=c[2276069]|0;o=n>>>9;p=o&7;q=p|8;r=9104156+(q<<2)|0;c[r>>2]=m;return}else{m=gj[c[f+196768+(l<<2)>>2]&4095](e)|0;n=c[2276069]|0;o=n>>>9;p=o&7;q=p|8;r=9104156+(q<<2)|0;c[r>>2]=m;return}}function uC(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=b;g=c[2276084]|0}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=o;g=m}m=e+2|0;c[2276056]=m;e=m&-4;if((e|0)==(f|0)){p=g;q=m}else{c[2276083]=e;f=c[2276085]&e;e=f&16777212;o=c[2112932]|0;n=c[o+((e>>>10|32768)<<2)>>2]|0;if(n>>>0>9){b=f&1020;r=(d[n+(b|3)|0]|0)<<8|(d[n+(b|2)|0]|0)|((d[n+(b|1)|0]|0)<<8|(d[n+b|0]|0))<<16;s=m}else{m=gj[c[o+196768+(n<<2)>>2]&4095](e)|0;r=m;s=c[2276056]|0}c[2276084]=r;p=r>>>16|g<<16;q=s}c[2276056]=q+2;q=c[2276085]&p;p=q&16777215;s=c[2112932]|0;g=c[s+(p>>>10<<2)>>2]|0;if(g>>>0>9){r=q&1023;t=(d[g+(r+3)|0]|0)<<8|(d[g+(r+2)|0]|0)|((d[g+(r+1)|0]|0)<<8|(d[g+r|0]|0))<<16;u=c[2276069]|0;v=u>>>9;w=v&7;x=w|8;y=9104156+(x<<2)|0;c[y>>2]=t;return}else{t=gj[c[s+196768+(g<<2)>>2]&4095](p)|0;u=c[2276069]|0;v=u>>>9;w=v&7;x=w|8;y=9104156+(x<<2)|0;c[y>>2]=t;return}}function uD(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{j=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=j;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=(f>>>((e<<3&16^16)>>>0)<<16>>16)+a|0;a=k&16777215;e=c[2112932]|0;f=c[e+((a>>>10|32768)<<2)>>2]|0;if(f>>>0>9){l=k&1023;m=(d[f+(l+3)|0]|0)<<8|(d[f+(l+2)|0]|0)|((d[f+(l+1)|0]|0)<<8|(d[f+l|0]|0))<<16;n=c[2276069]|0;o=n>>>9;p=o&7;q=p|8;r=9104156+(q<<2)|0;c[r>>2]=m;return}else{m=gj[c[e+196768+(f<<2)>>2]&4095](a)|0;n=c[2276069]|0;o=n>>>9;p=o&7;q=p|8;r=9104156+(q<<2)|0;c[r>>2]=m;return}}function uE(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=nB(c[2276056]|0)|0;b=a&16777215;e=c[2112932]|0;f=c[e+((b>>>10|32768)<<2)>>2]|0;if(f>>>0>9){g=a&1023;h=(d[f+(g+3)|0]|0)<<8|(d[f+(g+2)|0]|0)|((d[f+(g+1)|0]|0)<<8|(d[f+g|0]|0))<<16;i=c[2276069]|0;j=i>>>9;k=j&7;l=k|8;m=9104156+(l<<2)|0;c[m>>2]=h;return}else{h=gj[c[e+196768+(f<<2)>>2]&4095](b)|0;i=c[2276069]|0;j=i>>>9;k=j&7;l=k|8;m=9104156+(l<<2)|0;c[m>>2]=h;return}}function uF(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=b;g=c[2276084]|0}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=o;g=m}m=e+2|0;c[2276056]=m;e=m&-4;if((e|0)==(f|0)){p=g;q=m;r=q+2|0;c[2276056]=r;s=c[2276069]|0;t=s>>>9;u=t&7;v=u|8;w=9104156+(v<<2)|0;c[w>>2]=p;return}c[2276083]=e;f=c[2276085]&e;e=f&16777212;o=c[2112932]|0;n=c[o+((e>>>10|32768)<<2)>>2]|0;if(n>>>0>9){b=f&1020;x=(d[n+(b|3)|0]|0)<<8|(d[n+(b|2)|0]|0)|((d[n+(b|1)|0]|0)<<8|(d[n+b|0]|0))<<16;y=m}else{m=gj[c[o+196768+(n<<2)>>2]&4095](e)|0;x=m;y=c[2276056]|0}c[2276084]=x;p=x>>>16|g<<16;q=y;r=q+2|0;c[2276056]=r;s=c[2276069]|0;t=s>>>9;u=t&7;v=u|8;w=9104156+(v<<2)|0;c[w>>2]=p;return}function uG(){var a=0;if((c[2276038]&28|0)==0){ni();return}else{a=9104156+((c[2276069]&7)<<2)|0;c[a>>2]=(c[2276074]|0)>>>4&16|c[a>>2]&-65536|(c[2276075]|0)>>>4&8|((c[2276076]|0)==0)<<2|(c[2276077]|0)>>>6&2|(c[2276078]|0)>>>8&1;return}}function uH(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;if((c[2276038]&28|0)==0){ni();return}b=(c[2276075]|0)>>>4&8|(c[2276074]|0)>>>4&16|((c[2276076]|0)==0)<<2|(c[2276077]|0)>>>6&2|(c[2276078]|0)>>>8&1;d=c[2276085]&c[9104156+((c[2276069]&7|8)<<2)>>2];e=b&65535;f=d&16777215;g=c[2112932]|0;h=c[g+((f>>>10|16384)<<2)>>2]|0;if(h>>>0>9){i=d&1023;a[h+i|0]=b&255;a[h+(i+1)|0]=(e&65535)>>>8&255;return}else{gg[c[g+196728+(h<<2)>>2]&4095](f,e);return}}function uI(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;if((c[2276038]&28|0)==0){ni();return}b=9104156+((c[2276069]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+2;b=(c[2276075]|0)>>>4&8|(c[2276074]|0)>>>4&16|((c[2276076]|0)==0)<<2|(c[2276077]|0)>>>6&2|(c[2276078]|0)>>>8&1;e=c[2276085]&d;d=b&65535;f=e&16777215;g=c[2112932]|0;h=c[g+((f>>>10|16384)<<2)>>2]|0;if(h>>>0>9){i=e&1023;a[h+i|0]=b&255;a[h+(i+1)|0]=(d&65535)>>>8&255;return}else{gg[c[g+196728+(h<<2)>>2]&4095](f,d);return}}function uJ(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;if((c[2276038]&28|0)==0){ni();return}b=9104156+((c[2276069]&7|8)<<2)|0;d=(c[b>>2]|0)-2|0;c[b>>2]=d;b=(c[2276075]|0)>>>4&8|(c[2276074]|0)>>>4&16|((c[2276076]|0)==0)<<2|(c[2276077]|0)>>>6&2|(c[2276078]|0)>>>8&1;e=c[2276085]&d;d=b&65535;f=e&16777215;g=c[2112932]|0;h=c[g+((f>>>10|16384)<<2)>>2]|0;if(h>>>0>9){i=e&1023;a[h+i|0]=b&255;a[h+(i+1)|0]=(d&65535)>>>8&255;return}else{gg[c[g+196728+(h<<2)>>2]&4095](f,d);return}}function uK(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[2276038]&28|0)==0){ni();return}b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=(c[2276075]|0)>>>4&8|(c[2276074]|0)>>>4&16|((c[2276076]|0)==0)<<2|(c[2276077]|0)>>>6&2|(c[2276078]|0)>>>8&1;n=(h>>>((g<<3&16^16)>>>0)<<16>>16)+b&c[2276085];b=m&65535;g=n&16777215;h=c[2112932]|0;e=c[h+((g>>>10|16384)<<2)>>2]|0;if(e>>>0>9){f=n&1023;a[e+f|0]=m&255;a[e+(f+1)|0]=(b&65535)>>>8&255;return}else{gg[c[h+196728+(e<<2)>>2]&4095](g,b);return}}function uL(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;if((c[2276038]&28|0)==0){ni();return}b=nB(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;d=(c[2276075]|0)>>>4&8|(c[2276074]|0)>>>4&16|((c[2276076]|0)==0)<<2|(c[2276077]|0)>>>6&2|(c[2276078]|0)>>>8&1;e=c[2276085]&b;b=d&65535;f=e&16777215;g=c[2112932]|0;h=c[g+((f>>>10|16384)<<2)>>2]|0;if(h>>>0>9){i=e&1023;a[h+i|0]=d&255;a[h+(i+1)|0]=(b&65535)>>>8&255;return}else{gg[c[g+196728+(h<<2)>>2]&4095](f,b);return}}function uM(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((c[2276038]&28|0)==0){ni();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=(c[2276075]|0)>>>4&8|(c[2276074]|0)>>>4&16|((c[2276076]|0)==0)<<2|(c[2276077]|0)>>>6&2|(c[2276078]|0)>>>8&1;m=c[2276085]&g>>>((f<<3&16^16)>>>0)<<16>>16;f=l&65535;g=m&16777215;b=c[2112932]|0;e=c[b+((g>>>10|16384)<<2)>>2]|0;if(e>>>0>9){j=m&1023;a[e+j|0]=l&255;a[e+(j+1)|0]=(f&65535)>>>8&255;return}else{gg[c[b+196728+(e<<2)>>2]&4095](g,f);return}}function uN(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;if((c[2276038]&28|0)==0){ni();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=(c[2276075]|0)>>>4&8|(c[2276074]|0)>>>4&16|((c[2276076]|0)==0)<<2|(c[2276077]|0)>>>6&2|(c[2276078]|0)>>>8&1;t=c[2276085]&q;q=r&65535;h=t&16777215;s=c[2112932]|0;n=c[s+((h>>>10|16384)<<2)>>2]|0;if(n>>>0>9){f=t&1023;a[n+f|0]=r&255;a[n+(f+1)|0]=(q&65535)>>>8&255;return}else{gg[c[s+196728+(n<<2)>>2]&4095](h,q);return}}function uO(){var a=0,b=0;a=c[9104156+((c[2276069]&7)<<2)>>2]|0;b=a<<4;c[2276074]=b&256;c[2276075]=b&128;c[2276076]=a>>>2&1^1;c[2276077]=a<<6&128;c[2276078]=a<<8&256;return}function uP(){var a=0,b=0,e=0,f=0,g=0,h=0;a=c[2276085]&c[9104156+((c[2276069]&7|8)<<2)>>2];b=a&16777215;e=c[2112932]|0;f=c[e+(b>>>10<<2)>>2]|0;if(f>>>0>9){g=a&1023;h=(d[f+(g+1)|0]|0)<<8|(d[f+g|0]|0)}else{h=gj[c[e+196688+(f<<2)>>2]&4095](b)|0}b=h&65535;h=b<<4;c[2276074]=h&256;c[2276075]=h&128;c[2276076]=b>>>2&1^1;c[2276077]=b<<6&128;c[2276078]=b<<8&256;return}function uQ(){var a=0,b=0,e=0,f=0,g=0,h=0;a=9104156+((c[2276069]&7|8)<<2)|0;b=c[a>>2]|0;c[a>>2]=b+2;a=c[2276085]&b;b=a&16777215;e=c[2112932]|0;f=c[e+(b>>>10<<2)>>2]|0;if(f>>>0>9){g=a&1023;h=(d[f+(g+1)|0]|0)<<8|(d[f+g|0]|0)}else{h=gj[c[e+196688+(f<<2)>>2]&4095](b)|0}b=h&65535;h=b<<4;c[2276074]=h&256;c[2276075]=h&128;c[2276076]=b>>>2&1^1;c[2276077]=b<<6&128;c[2276078]=b<<8&256;return}function uR(){var a=0,b=0,e=0,f=0,g=0,h=0;a=9104156+((c[2276069]&7|8)<<2)|0;b=(c[a>>2]|0)-2|0;c[a>>2]=b;a=c[2276085]&b;b=a&16777215;e=c[2112932]|0;f=c[e+(b>>>10<<2)>>2]|0;if(f>>>0>9){g=a&1023;h=(d[f+(g+1)|0]|0)<<8|(d[f+g|0]|0)}else{h=gj[c[e+196688+(f<<2)>>2]&4095](b)|0}b=h&65535;h=b<<4;c[2276074]=h&256;c[2276075]=h&128;c[2276076]=b>>>2&1^1;c[2276077]=b<<6&128;c[2276078]=b<<8&256;return}function uS(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;a=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=(g>>>((f<<3&16^16)>>>0)<<16>>16)+a&c[2276085];a=l&16777215;f=c[2112932]|0;g=c[f+(a>>>10<<2)>>2]|0;if(g>>>0>9){m=l&1023;n=(d[g+(m+1)|0]|0)<<8|(d[g+m|0]|0);o=n&65535;p=o<<4;q=p&256;c[2276074]=q;r=p&128;c[2276075]=r;s=o>>>2;t=s&1;u=t^1;c[2276076]=u;v=o<<6;w=v&128;c[2276077]=w;x=o<<8;y=x&256;c[2276078]=y;return}else{n=gj[c[f+196688+(g<<2)>>2]&4095](a)|0;o=n&65535;p=o<<4;q=p&256;c[2276074]=q;r=p&128;c[2276075]=r;s=o>>>2;t=s&1;u=t^1;c[2276076]=u;v=o<<6;w=v&128;c[2276077]=w;x=o<<8;y=x&256;c[2276078]=y;return}}function uT(){var a=0,b=0,e=0,f=0,g=0,h=0;a=nB(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;b=c[2276085]&a;a=b&16777215;e=c[2112932]|0;f=c[e+(a>>>10<<2)>>2]|0;if(f>>>0>9){g=b&1023;h=(d[f+(g+1)|0]|0)<<8|(d[f+g|0]|0)}else{h=gj[c[e+196688+(f<<2)>>2]&4095](a)|0}a=h&65535;h=a<<4;c[2276074]=h&256;c[2276075]=h&128;c[2276076]=a>>>2&1^1;c[2276077]=a<<6&128;c[2276078]=a<<8&256;return}function uU(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=f>>>((e<<3&16^16)>>>0)<<16>>16&c[2276085];e=k&16777215;f=c[2112932]|0;l=c[f+(e>>>10<<2)>>2]|0;if(l>>>0>9){a=k&1023;m=(d[l+(a+1)|0]|0)<<8|(d[l+a|0]|0);n=m&65535;o=n<<4;p=o&256;c[2276074]=p;q=o&128;c[2276075]=q;r=n>>>2;s=r&1;t=s^1;c[2276076]=t;u=n<<6;v=u&128;c[2276077]=v;w=n<<8;x=w&256;c[2276078]=x;return}else{m=gj[c[f+196688+(l<<2)>>2]&4095](e)|0;n=m&65535;o=n<<4;p=o&256;c[2276074]=p;q=o&128;c[2276075]=q;r=n>>>2;s=r&1;t=s^1;c[2276076]=t;u=n<<6;v=u&128;c[2276077]=v;w=n<<8;x=w&256;c[2276078]=x;return}}function uV(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=b;g=c[2276084]|0}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=o;g=m}m=e+2|0;c[2276056]=m;e=m&-4;if((e|0)==(f|0)){p=g;q=m}else{c[2276083]=e;f=c[2276085]&e;e=f&16777212;o=c[2112932]|0;n=c[o+((e>>>10|32768)<<2)>>2]|0;if(n>>>0>9){b=f&1020;r=(d[n+(b|3)|0]|0)<<8|(d[n+(b|2)|0]|0)|((d[n+(b|1)|0]|0)<<8|(d[n+b|0]|0))<<16;s=m}else{m=gj[c[o+196768+(n<<2)>>2]&4095](e)|0;r=m;s=c[2276056]|0}c[2276084]=r;p=r>>>16|g<<16;q=s}c[2276056]=q+2;q=c[2276085]&p;p=q&16777215;s=c[2112932]|0;g=c[s+(p>>>10<<2)>>2]|0;if(g>>>0>9){r=q&1023;t=(d[g+(r+1)|0]|0)<<8|(d[g+r|0]|0);u=t&65535;v=u<<4;w=v&256;c[2276074]=w;x=v&128;c[2276075]=x;y=u>>>2;z=y&1;A=z^1;c[2276076]=A;B=u<<6;C=B&128;c[2276077]=C;D=u<<8;E=D&256;c[2276078]=E;return}else{t=gj[c[s+196688+(g<<2)>>2]&4095](p)|0;u=t&65535;v=u<<4;w=v&256;c[2276074]=w;x=v&128;c[2276075]=x;y=u>>>2;z=y&1;A=z^1;c[2276076]=A;B=u<<6;C=B&128;c[2276077]=C;D=u<<8;E=D&256;c[2276078]=E;return}}function uW(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{j=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=j;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=(f>>>((e<<3&16^16)>>>0)<<16>>16)+a|0;a=k&16777215;e=c[2112932]|0;f=c[e+((a>>>10|32768)<<2)>>2]|0;if(f>>>0>9){l=k&1023;m=(d[f+(l+1)|0]|0)<<8|(d[f+l|0]|0);n=m&65535;o=n<<4;p=o&256;c[2276074]=p;q=o&128;c[2276075]=q;r=n>>>2;s=r&1;t=s^1;c[2276076]=t;u=n<<6;v=u&128;c[2276077]=v;w=n<<8;x=w&256;c[2276078]=x;return}else{m=gj[c[e+196688+(f<<2)>>2]&4095](a)|0;n=m&65535;o=n<<4;p=o&256;c[2276074]=p;q=o&128;c[2276075]=q;r=n>>>2;s=r&1;t=s^1;c[2276076]=t;u=n<<6;v=u&128;c[2276077]=v;w=n<<8;x=w&256;c[2276078]=x;return}}function uX(){var a=0,b=0,e=0,f=0,g=0,h=0;a=nB(c[2276056]|0)|0;b=a&16777215;e=c[2112932]|0;f=c[e+((b>>>10|32768)<<2)>>2]|0;if(f>>>0>9){g=a&1023;h=(d[f+(g+1)|0]|0)<<8|(d[f+g|0]|0)}else{h=gj[c[e+196688+(f<<2)>>2]&4095](b)|0}b=h&65535;h=b<<4;c[2276074]=h&256;c[2276075]=h&128;c[2276076]=b>>>2&1^1;c[2276077]=b<<6&128;c[2276078]=b<<8&256;return}function uY(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=f>>>((e<<3&16^16)>>>0);e=k&65535;f=e<<4;c[2276074]=f&256;c[2276075]=f&128;c[2276076]=k>>>2&1^1;c[2276077]=e<<6&128;c[2276078]=e<<8&256;return}function uZ(){var a=0,b=0;a=c[2276072]|0;if(((c[2276038]|0)-1|0)>>>0<2|(a|0)!=0){b=9104156+((c[2276069]&7)<<2)|0;c[b>>2]=c[2276070]|a<<11|c[b>>2]&-65536|c[2276071]|c[2276073]<<11|c[2276079]|(c[2276074]|0)>>>4&16|(c[2276075]|0)>>>4&8|((c[2276076]|0)==0)<<2|(c[2276077]|0)>>>6&2|(c[2276078]|0)>>>8&1;return}else{ol();return}}function u_(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=c[2276072]|0;if(!(((c[2276038]|0)-1|0)>>>0<2|(b|0)!=0)){ol();return}d=c[2276070]|b<<11|c[2276071]|c[2276073]<<11|c[2276079]|(c[2276074]|0)>>>4&16|(c[2276075]|0)>>>4&8|((c[2276076]|0)==0)<<2|(c[2276077]|0)>>>6&2|(c[2276078]|0)>>>8&1;b=c[2276085]&c[9104156+((c[2276069]&7|8)<<2)>>2];e=d&65535;f=b&16777215;g=c[2112932]|0;h=c[g+((f>>>10|16384)<<2)>>2]|0;if(h>>>0>9){i=b&1023;a[h+i|0]=d&255;a[h+(i+1)|0]=(e&65535)>>>8&255;return}else{gg[c[g+196728+(h<<2)>>2]&4095](f,e);return}}function u$(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;if(!(((c[2276038]|0)-1|0)>>>0<2|(c[2276072]|0)!=0)){ol();return}b=9104156+((c[2276069]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+2;b=c[2276072]<<11|c[2276070]|c[2276071]|c[2276073]<<11|c[2276079]|(c[2276074]|0)>>>4&16|(c[2276075]|0)>>>4&8|((c[2276076]|0)==0)<<2|(c[2276077]|0)>>>6&2|(c[2276078]|0)>>>8&1;e=c[2276085]&d;d=b&65535;f=e&16777215;g=c[2112932]|0;h=c[g+((f>>>10|16384)<<2)>>2]|0;if(h>>>0>9){i=e&1023;a[h+i|0]=b&255;a[h+(i+1)|0]=(d&65535)>>>8&255;return}else{gg[c[g+196728+(h<<2)>>2]&4095](f,d);return}}function u0(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;if(!(((c[2276038]|0)-1|0)>>>0<2|(c[2276072]|0)!=0)){ol();return}b=9104156+((c[2276069]&7|8)<<2)|0;d=(c[b>>2]|0)-2|0;c[b>>2]=d;b=c[2276072]<<11|c[2276070]|c[2276071]|c[2276073]<<11|c[2276079]|(c[2276074]|0)>>>4&16|(c[2276075]|0)>>>4&8|((c[2276076]|0)==0)<<2|(c[2276077]|0)>>>6&2|(c[2276078]|0)>>>8&1;e=c[2276085]&d;d=b&65535;f=e&16777215;g=c[2112932]|0;h=c[g+((f>>>10|16384)<<2)>>2]|0;if(h>>>0>9){i=e&1023;a[h+i|0]=b&255;a[h+(i+1)|0]=(d&65535)>>>8&255;return}else{gg[c[g+196728+(h<<2)>>2]&4095](f,d);return}}function u1(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=c[2276072]|0;if(!(((c[2276038]|0)-1|0)>>>0<2|(b|0)!=0)){ol();return}e=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;f=c[2276056]|0;g=f&-4;if((g|0)==(c[2276083]|0)){h=f;i=c[2276084]|0;j=b}else{c[2276083]=g;k=c[2276085]&g;g=k&16777212;l=c[2112932]|0;m=c[l+((g>>>10|32768)<<2)>>2]|0;if(m>>>0>9){n=k&1020;o=(d[m+(n|3)|0]|0)<<8|(d[m+(n|2)|0]|0)|((d[m+(n|1)|0]|0)<<8|(d[m+n|0]|0))<<16;p=f;q=b}else{b=gj[c[l+196768+(m<<2)>>2]&4095](g)|0;o=b;p=c[2276056]|0;q=c[2276072]|0}c[2276084]=o;h=p;i=o;j=q}c[2276056]=h+2;q=c[2276070]|j<<11|c[2276071]|c[2276073]<<11|c[2276079]|(c[2276074]|0)>>>4&16|(c[2276075]|0)>>>4&8|((c[2276076]|0)==0)<<2|(c[2276077]|0)>>>6&2|(c[2276078]|0)>>>8&1;j=c[2276085]&(i>>>((h<<3&16^16)>>>0)<<16>>16)+e;e=q&65535;h=j&16777215;i=c[2112932]|0;o=c[i+((h>>>10|16384)<<2)>>2]|0;if(o>>>0>9){p=j&1023;a[o+p|0]=q&255;a[o+(p+1)|0]=(e&65535)>>>8&255;return}else{gg[c[i+196728+(o<<2)>>2]&4095](h,e);return}}function u2(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;if(!(((c[2276038]|0)-1|0)>>>0<2|(c[2276072]|0)!=0)){ol();return}b=nB(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;d=c[2276072]<<11|c[2276070]|c[2276071]|c[2276073]<<11|c[2276079]|(c[2276074]|0)>>>4&16|(c[2276075]|0)>>>4&8|((c[2276076]|0)==0)<<2|(c[2276077]|0)>>>6&2|(c[2276078]|0)>>>8&1;e=c[2276085]&b;b=d&65535;f=e&16777215;g=c[2112932]|0;h=c[g+((f>>>10|16384)<<2)>>2]|0;if(h>>>0>9){i=e&1023;a[h+i|0]=d&255;a[h+(i+1)|0]=(b&65535)>>>8&255;return}else{gg[c[g+196728+(h<<2)>>2]&4095](f,b);return}}function u3(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276072]|0;if(!(((c[2276038]|0)-1|0)>>>0<2|(b|0)!=0)){ol();return}e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0;i=b}else{c[2276083]=f;j=c[2276085]&f;f=j&16777212;k=c[2112932]|0;l=c[k+((f>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=j&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=e;p=b}else{b=gj[c[k+196768+(l<<2)>>2]&4095](f)|0;n=b;o=c[2276056]|0;p=c[2276072]|0}c[2276084]=n;g=o;h=n;i=p}c[2276056]=g+2;p=c[2276070]|i<<11|c[2276071]|c[2276073]<<11|c[2276079]|(c[2276074]|0)>>>4&16|(c[2276075]|0)>>>4&8|((c[2276076]|0)==0)<<2|(c[2276077]|0)>>>6&2|(c[2276078]|0)>>>8&1;i=c[2276085]&h>>>((g<<3&16^16)>>>0)<<16>>16;g=p&65535;h=i&16777215;n=c[2112932]|0;o=c[n+((h>>>10|16384)<<2)>>2]|0;if(o>>>0>9){b=i&1023;a[o+b|0]=p&255;a[o+(b+1)|0]=(g&65535)>>>8&255;return}else{gg[c[n+196728+(o<<2)>>2]&4095](h,g);return}}function u4(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;if(!(((c[2276038]|0)-1|0)>>>0<2|(c[2276072]|0)!=0)){ol();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[2276072]<<11|c[2276070]|c[2276071]|c[2276073]<<11|c[2276079]|(c[2276074]|0)>>>4&16|(c[2276075]|0)>>>4&8|((c[2276076]|0)==0)<<2|(c[2276077]|0)>>>6&2|(c[2276078]|0)>>>8&1;t=c[2276085]&q;q=r&65535;h=t&16777215;s=c[2112932]|0;n=c[s+((h>>>10|16384)<<2)>>2]|0;if(n>>>0>9){f=t&1023;a[n+f|0]=r&255;a[n+(f+1)|0]=(q&65535)>>>8&255;return}else{gg[c[s+196728+(n<<2)>>2]&4095](h,q);return}}function u5(){if((c[2276072]|0)==0){ol();return}else{ok(c[9104156+((c[2276069]&7)<<2)>>2]|0);return}}function u6(){var a=0,b=0,e=0,f=0,g=0,h=0;if((c[2276072]|0)==0){ol();return}a=c[2276085]&c[9104156+((c[2276069]&7|8)<<2)>>2];b=a&16777215;e=c[2112932]|0;f=c[e+(b>>>10<<2)>>2]|0;if(f>>>0>9){g=a&1023;h=(d[f+(g+1)|0]|0)<<8|(d[f+g|0]|0)}else{h=gj[c[e+196688+(f<<2)>>2]&4095](b)|0}ok(h&65535);return}function u7(){var a=0,b=0,e=0,f=0,g=0,h=0;if((c[2276072]|0)==0){ol();return}a=9104156+((c[2276069]&7|8)<<2)|0;b=c[a>>2]|0;c[a>>2]=b+2;a=c[2276085]&b;b=a&16777215;e=c[2112932]|0;f=c[e+(b>>>10<<2)>>2]|0;if(f>>>0>9){g=a&1023;h=(d[f+(g+1)|0]|0)<<8|(d[f+g|0]|0)}else{h=gj[c[e+196688+(f<<2)>>2]&4095](b)|0}ok(h&65535);return}function u8(){var a=0,b=0,e=0,f=0,g=0,h=0;if((c[2276072]|0)==0){ol();return}a=9104156+((c[2276069]&7|8)<<2)|0;b=(c[a>>2]|0)-2|0;c[a>>2]=b;a=c[2276085]&b;b=a&16777215;e=c[2112932]|0;f=c[e+(b>>>10<<2)>>2]|0;if(f>>>0>9){g=a&1023;h=(d[f+(g+1)|0]|0)<<8|(d[f+g|0]|0)}else{h=gj[c[e+196688+(f<<2)>>2]&4095](b)|0}ok(h&65535);return}function u9(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[2276072]|0)==0){ol();return}a=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=(g>>>((f<<3&16^16)>>>0)<<16>>16)+a&c[2276085];a=l&16777215;f=c[2112932]|0;g=c[f+(a>>>10<<2)>>2]|0;if(g>>>0>9){m=l&1023;n=(d[g+(m+1)|0]|0)<<8|(d[g+m|0]|0)}else{n=gj[c[f+196688+(g<<2)>>2]&4095](a)|0}ok(n&65535);return}function va(){var a=0,b=0,e=0,f=0,g=0,h=0;if((c[2276072]|0)==0){ol();return}a=nB(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;b=c[2276085]&a;a=b&16777215;e=c[2112932]|0;f=c[e+(a>>>10<<2)>>2]|0;if(f>>>0>9){g=b&1023;h=(d[f+(g+1)|0]|0)<<8|(d[f+g|0]|0)}else{h=gj[c[e+196688+(f<<2)>>2]&4095](a)|0}ok(h&65535);return}function vb(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((c[2276072]|0)==0){ol();return}a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=f>>>((e<<3&16^16)>>>0)<<16>>16&c[2276085];e=k&16777215;f=c[2112932]|0;l=c[f+(e>>>10<<2)>>2]|0;if(l>>>0>9){a=k&1023;m=(d[l+(a+1)|0]|0)<<8|(d[l+a|0]|0)}else{m=gj[c[f+196688+(l<<2)>>2]&4095](e)|0}ok(m&65535);return}function vc(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;if((c[2276072]|0)==0){ol();return}a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=b;g=c[2276084]|0}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=o;g=m}m=e+2|0;c[2276056]=m;e=m&-4;if((e|0)==(f|0)){p=g;q=m}else{c[2276083]=e;f=c[2276085]&e;e=f&16777212;o=c[2112932]|0;n=c[o+((e>>>10|32768)<<2)>>2]|0;if(n>>>0>9){b=f&1020;r=(d[n+(b|3)|0]|0)<<8|(d[n+(b|2)|0]|0)|((d[n+(b|1)|0]|0)<<8|(d[n+b|0]|0))<<16;s=m}else{m=gj[c[o+196768+(n<<2)>>2]&4095](e)|0;r=m;s=c[2276056]|0}c[2276084]=r;p=r>>>16|g<<16;q=s}c[2276056]=q+2;q=c[2276085]&p;p=q&16777215;s=c[2112932]|0;g=c[s+(p>>>10<<2)>>2]|0;if(g>>>0>9){r=q&1023;t=(d[g+(r+1)|0]|0)<<8|(d[g+r|0]|0)}else{t=gj[c[s+196688+(g<<2)>>2]&4095](p)|0}ok(t&65535);return}function vd(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((c[2276072]|0)==0){ol();return}a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{j=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=j;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=(f>>>((e<<3&16^16)>>>0)<<16>>16)+a|0;a=k&16777215;e=c[2112932]|0;f=c[e+((a>>>10|32768)<<2)>>2]|0;if(f>>>0>9){l=k&1023;m=(d[f+(l+1)|0]|0)<<8|(d[f+l|0]|0)}else{m=gj[c[e+196688+(f<<2)>>2]&4095](a)|0}ok(m&65535);return}function ve(){var a=0,b=0,e=0,f=0,g=0,h=0;if((c[2276072]|0)==0){ol();return}a=nB(c[2276056]|0)|0;b=a&16777215;e=c[2112932]|0;f=c[e+((b>>>10|32768)<<2)>>2]|0;if(f>>>0>9){g=a&1023;h=(d[f+(g+1)|0]|0)<<8|(d[f+g|0]|0)}else{h=gj[c[e+196688+(f<<2)>>2]&4095](b)|0}ok(h&65535);return}function vf(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if((c[2276072]|0)==0){ol();return}a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;ok(f>>>((e<<3&16^16)>>>0)&65535);return}function vg(){if((c[2276072]|0)==0){ol();return}else{c[9104156+((c[2276069]&7|8)<<2)>>2]=c[2276057];return}}function vh(){if((c[2276072]|0)==0){ol();return}else{c[2276057]=c[9104156+((c[2276069]&7|8)<<2)>>2];return}}function vi(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if((c[2276038]&28|0)==0){ni();return}L27788:do{if((c[2276072]|0)!=0){a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;a=f>>>((e<<3&16^16)>>>0);switch(a&4095|0){case 2052:{if((c[2276038]&24|0)==0){ni();return}else{c[9104156+((a>>>12&15)<<2)>>2]=(c[2276073]|0)!=0?c[2276061]|0:c[2276054]|0;return}break};case 2051:{if((c[2276038]&24|0)==0){ni();return}else{c[9104156+((a>>>12&15)<<2)>>2]=(c[2276073]|0)!=0?c[2276054]|0:c[2276063]|0;return}break};case 2048:{c[9104156+((a>>>12&15)<<2)>>2]=c[2276057];return};case 2049:{c[9104156+((a>>>12&15)<<2)>>2]=c[2276064];return};case 2:{if((c[2276038]&24|0)==0){return}c[9104156+((a>>>12&15)<<2)>>2]=c[2276067];return};case 1:{c[9104156+((a>>>12&15)<<2)>>2]=c[2276066];return};case 2050:{if((c[2276038]&24|0)==0){ni();break L27788}c[9104156+((a>>>12&15)<<2)>>2]=c[2276068];return};case 0:{c[9104156+((a>>>12&15)<<2)>>2]=c[2276065];return};default:{ni();return}}}}while(0);ol();return}function vj(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if((c[2276038]&28|0)==0){ni();return}if((c[2276072]|0)==0){ol();return}a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=f>>>((e<<3&16^16)>>>0);switch(k&4095|0){case 2051:{if((c[2276038]&24|0)==0){ni();return}e=c[9104156+((k>>>12&15)<<2)>>2]|0;if((c[2276073]|0)==0){c[2276063]=e;return}else{c[2276054]=e;return}break};case 2:{if((c[2276038]&24|0)==0){ni();return}else{c[2276067]=c[9104156+((k>>>12&15)<<2)>>2];return}break};case 2052:{if((c[2276038]&24|0)==0){ni();return}e=c[9104156+((k>>>12&15)<<2)>>2]|0;if((c[2276073]|0)==0){c[2276054]=e;return}else{c[2276061]=e;return}break};case 1:{c[2276066]=c[9104156+((k>>>12&15)<<2)>>2]&7;return};case 0:{c[2276065]=c[9104156+((k>>>12&15)<<2)>>2]&7;return};case 2050:{if((c[2276038]&24|0)==0){ni();return}else{c[2276068]=c[9104156+((k>>>12&15)<<2)>>2];return}break};case 2048:{c[2276057]=c[9104156+((k>>>12&15)<<2)>>2];return};case 2049:{c[2276064]=c[9104156+((k>>>12&15)<<2)>>2];return};default:{ni();return}}}function vk(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)&65535;f=0;g=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;m=0;while(1){if((l&1<<f|0)==0){n=m;o=g}else{b=g-2|0;e=c[9104156+(15-f<<2)>>2]|0;j=c[2276085]&b;i=e&65535;k=j&16777215;h=c[2112932]|0;p=c[h+((k>>>10|16384)<<2)>>2]|0;if(p>>>0>9){q=j&1023;a[p+q|0]=e&255;a[p+(q+1)|0]=(i&65535)>>>8&255}else{gg[c[h+196728+(p<<2)>>2]&4095](k,i)}n=m+1|0;o=b}b=f+1|0;if(b>>>0<16){f=b;g=o;m=n}else{break}}c[9104156+((c[2276069]&7|8)<<2)>>2]=o;c[2276108]=(c[2276108]|0)-(n<<c[2276094]);return}function vl(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)&65535;f=0;g=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;m=0;while(1){if((l&1<<f|0)==0){n=m;o=g}else{b=c[9104156+(f<<2)>>2]|0;e=c[2276085]&g;j=b&65535;i=e&16777215;k=c[2112932]|0;h=c[k+((i>>>10|16384)<<2)>>2]|0;if(h>>>0>9){p=e&1023;a[h+p|0]=b&255;a[h+(p+1)|0]=(j&65535)>>>8&255}else{gg[c[k+196728+(h<<2)>>2]&4095](i,j)}n=m+1|0;o=g+2|0}j=f+1|0;if(j>>>0<16){f=j;g=o;m=n}else{break}}c[2276108]=(c[2276108]|0)-(n<<c[2276094]);return}function vm(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0)&65535;f=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;o=p&-4;if((o|0)==(h|0)){q=p;r=g}else{c[2276083]=o;g=c[2276085]&o;o=g&16777212;h=c[2112932]|0;e=c[h+((o>>>10|32768)<<2)>>2]|0;if(e>>>0>9){j=g&1020;s=(d[e+(j|3)|0]|0)<<8|(d[e+(j|2)|0]|0)|((d[e+(j|1)|0]|0)<<8|(d[e+j|0]|0))<<16;t=p}else{p=gj[c[h+196768+(e<<2)>>2]&4095](o)|0;s=p;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;s=0;t=(r>>>((q<<3&16^16)>>>0)<<16>>16)+f|0;f=0;while(1){if((n&1<<s|0)==0){u=f;v=t}else{q=c[9104156+(s<<2)>>2]|0;r=c[2276085]&t;p=q&65535;o=r&16777215;e=c[2112932]|0;h=c[e+((o>>>10|16384)<<2)>>2]|0;if(h>>>0>9){j=r&1023;a[h+j|0]=q&255;a[h+(j+1)|0]=(p&65535)>>>8&255}else{gg[c[e+196728+(h<<2)>>2]&4095](o,p)}u=f+1|0;v=t+2|0}p=s+1|0;if(p>>>0<16){s=p;t=v;f=u}else{break}}c[2276108]=(c[2276108]|0)-(u<<c[2276094]);return}function vn(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)&65535;f=0;g=nB(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;m=0;while(1){if((l&1<<f|0)==0){n=m;o=g}else{b=c[9104156+(f<<2)>>2]|0;e=c[2276085]&g;j=b&65535;i=e&16777215;k=c[2112932]|0;h=c[k+((i>>>10|16384)<<2)>>2]|0;if(h>>>0>9){p=e&1023;a[h+p|0]=b&255;a[h+(p+1)|0]=(j&65535)>>>8&255}else{gg[c[k+196728+(h<<2)>>2]&4095](i,j)}n=m+1|0;o=g+2|0}j=f+1|0;if(j>>>0<16){f=j;g=o;m=n}else{break}}c[2276108]=(c[2276108]|0)-(n<<c[2276094]);return}function vo(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0)&65535;f=p&-4;if((f|0)==(h|0)){q=p;r=g}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;h=c[2112932]|0;o=c[h+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=p}else{p=gj[c[h+196768+(o<<2)>>2]&4095](f)|0;s=p;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;s=0;t=r>>>((q<<3&16^16)>>>0)<<16>>16;q=0;while(1){if((n&1<<s|0)==0){u=q;v=t}else{r=c[9104156+(s<<2)>>2]|0;p=c[2276085]&t;f=r&65535;o=p&16777215;h=c[2112932]|0;e=c[h+((o>>>10|16384)<<2)>>2]|0;if(e>>>0>9){g=p&1023;a[e+g|0]=r&255;a[e+(g+1)|0]=(f&65535)>>>8&255}else{gg[c[h+196728+(e<<2)>>2]&4095](o,f)}u=q+1|0;v=t+2|0}f=s+1|0;if(f>>>0<16){s=f;t=v;q=u}else{break}}c[2276108]=(c[2276108]|0)-(u<<c[2276094]);return}function vp(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0)&65535;f=p&-4;if((f|0)==(h|0)){q=p;r=h;s=g}else{c[2276083]=f;g=c[2276085]&f;h=g&16777212;o=c[2112932]|0;e=c[o+((h>>>10|32768)<<2)>>2]|0;if(e>>>0>9){j=g&1020;t=(d[e+(j|3)|0]|0)<<8|(d[e+(j|2)|0]|0)|((d[e+(j|1)|0]|0)<<8|(d[e+j|0]|0))<<16;u=p;v=f}else{f=gj[c[o+196768+(e<<2)>>2]&4095](h)|0;t=f;u=c[2276056]|0;v=c[2276083]|0}c[2276084]=t;q=u;r=v;s=t}t=q+2|0;c[2276056]=t;q=t&-4;if((q|0)==(r|0)){w=s;x=t}else{c[2276083]=q;r=c[2276085]&q;q=r&16777212;v=c[2112932]|0;u=c[v+((q>>>10|32768)<<2)>>2]|0;if(u>>>0>9){f=r&1020;y=(d[u+(f|3)|0]|0)<<8|(d[u+(f|2)|0]|0)|((d[u+(f|1)|0]|0)<<8|(d[u+f|0]|0))<<16;z=t}else{t=gj[c[v+196768+(u<<2)>>2]&4095](q)|0;y=t;z=c[2276056]|0}c[2276084]=y;w=y>>>16|s<<16;x=z}c[2276056]=x+2;x=0;z=w;w=0;while(1){if((n&1<<x|0)==0){A=w;B=z}else{s=c[9104156+(x<<2)>>2]|0;y=c[2276085]&z;t=s&65535;q=y&16777215;u=c[2112932]|0;v=c[u+((q>>>10|16384)<<2)>>2]|0;if(v>>>0>9){f=y&1023;a[v+f|0]=s&255;a[v+(f+1)|0]=(t&65535)>>>8&255}else{gg[c[u+196728+(v<<2)>>2]&4095](q,t)}A=w+1|0;B=z+2|0}t=x+1|0;if(t>>>0<16){x=t;z=B;w=A}else{break}}c[2276108]=(c[2276108]|0)-(A<<c[2276094]);return}function vq(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)&65535;f=0;g=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;m=0;while(1){if((l&1<<f|0)==0){n=m;o=g}else{b=g-4|0;e=c[9104156+(15-f<<2)>>2]|0;j=c[2276085]&b;i=j&16777215;k=c[2112932]|0;h=c[k+((i>>>10|16384)<<2)>>2]|0;if(h>>>0>9){p=j&1023;a[h+p|0]=e>>>16&255;a[h+(p+1)|0]=e>>>24&255;a[h+(p+2)|0]=e&255;a[h+(p+3)|0]=e>>>8&255}else{gg[c[k+196808+(h<<2)>>2]&4095](i,e)}n=m+1|0;o=b}b=f+1|0;if(b>>>0<16){f=b;g=o;m=n}else{break}}c[9104156+((c[2276069]&7|8)<<2)>>2]=o;c[2276108]=(c[2276108]|0)-(n<<c[2276095]);return}function vr(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)&65535;f=0;g=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;m=0;while(1){if((l&1<<f|0)==0){n=m;o=g}else{b=c[9104156+(f<<2)>>2]|0;e=c[2276085]&g;j=e&16777215;i=c[2112932]|0;k=c[i+((j>>>10|16384)<<2)>>2]|0;if(k>>>0>9){h=e&1023;a[k+h|0]=b>>>16&255;a[k+(h+1)|0]=b>>>24&255;a[k+(h+2)|0]=b&255;a[k+(h+3)|0]=b>>>8&255}else{gg[c[i+196808+(k<<2)>>2]&4095](j,b)}n=m+1|0;o=g+4|0}b=f+1|0;if(b>>>0<16){f=b;g=o;m=n}else{break}}c[2276108]=(c[2276108]|0)-(n<<c[2276095]);return}function vs(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0)&65535;f=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;o=p&-4;if((o|0)==(h|0)){q=p;r=g}else{c[2276083]=o;g=c[2276085]&o;o=g&16777212;h=c[2112932]|0;e=c[h+((o>>>10|32768)<<2)>>2]|0;if(e>>>0>9){j=g&1020;s=(d[e+(j|3)|0]|0)<<8|(d[e+(j|2)|0]|0)|((d[e+(j|1)|0]|0)<<8|(d[e+j|0]|0))<<16;t=p}else{p=gj[c[h+196768+(e<<2)>>2]&4095](o)|0;s=p;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;s=0;t=(r>>>((q<<3&16^16)>>>0)<<16>>16)+f|0;f=0;while(1){if((n&1<<s|0)==0){u=f;v=t}else{q=c[9104156+(s<<2)>>2]|0;r=c[2276085]&t;p=r&16777215;o=c[2112932]|0;e=c[o+((p>>>10|16384)<<2)>>2]|0;if(e>>>0>9){h=r&1023;a[e+h|0]=q>>>16&255;a[e+(h+1)|0]=q>>>24&255;a[e+(h+2)|0]=q&255;a[e+(h+3)|0]=q>>>8&255}else{gg[c[o+196808+(e<<2)>>2]&4095](p,q)}u=f+1|0;v=t+4|0}q=s+1|0;if(q>>>0<16){s=q;t=v;f=u}else{break}}c[2276108]=(c[2276108]|0)-(u<<c[2276095]);return}function vt(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)&65535;f=0;g=nB(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;m=0;while(1){if((l&1<<f|0)==0){n=m;o=g}else{b=c[9104156+(f<<2)>>2]|0;e=c[2276085]&g;j=e&16777215;i=c[2112932]|0;k=c[i+((j>>>10|16384)<<2)>>2]|0;if(k>>>0>9){h=e&1023;a[k+h|0]=b>>>16&255;a[k+(h+1)|0]=b>>>24&255;a[k+(h+2)|0]=b&255;a[k+(h+3)|0]=b>>>8&255}else{gg[c[i+196808+(k<<2)>>2]&4095](j,b)}n=m+1|0;o=g+4|0}b=f+1|0;if(b>>>0<16){f=b;g=o;m=n}else{break}}c[2276108]=(c[2276108]|0)-(n<<c[2276095]);return}function vu(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0)&65535;f=p&-4;if((f|0)==(h|0)){q=p;r=g}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;h=c[2112932]|0;o=c[h+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=p}else{p=gj[c[h+196768+(o<<2)>>2]&4095](f)|0;s=p;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;s=0;t=r>>>((q<<3&16^16)>>>0)<<16>>16;q=0;while(1){if((n&1<<s|0)==0){u=q;v=t}else{r=c[9104156+(s<<2)>>2]|0;p=c[2276085]&t;f=p&16777215;o=c[2112932]|0;h=c[o+((f>>>10|16384)<<2)>>2]|0;if(h>>>0>9){e=p&1023;a[h+e|0]=r>>>16&255;a[h+(e+1)|0]=r>>>24&255;a[h+(e+2)|0]=r&255;a[h+(e+3)|0]=r>>>8&255}else{gg[c[o+196808+(h<<2)>>2]&4095](f,r)}u=q+1|0;v=t+4|0}r=s+1|0;if(r>>>0<16){s=r;t=v;q=u}else{break}}c[2276108]=(c[2276108]|0)-(u<<c[2276095]);return}function vv(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0)&65535;f=p&-4;if((f|0)==(h|0)){q=p;r=h;s=g}else{c[2276083]=f;g=c[2276085]&f;h=g&16777212;o=c[2112932]|0;e=c[o+((h>>>10|32768)<<2)>>2]|0;if(e>>>0>9){j=g&1020;t=(d[e+(j|3)|0]|0)<<8|(d[e+(j|2)|0]|0)|((d[e+(j|1)|0]|0)<<8|(d[e+j|0]|0))<<16;u=p;v=f}else{f=gj[c[o+196768+(e<<2)>>2]&4095](h)|0;t=f;u=c[2276056]|0;v=c[2276083]|0}c[2276084]=t;q=u;r=v;s=t}t=q+2|0;c[2276056]=t;q=t&-4;if((q|0)==(r|0)){w=s;x=t}else{c[2276083]=q;r=c[2276085]&q;q=r&16777212;v=c[2112932]|0;u=c[v+((q>>>10|32768)<<2)>>2]|0;if(u>>>0>9){f=r&1020;y=(d[u+(f|3)|0]|0)<<8|(d[u+(f|2)|0]|0)|((d[u+(f|1)|0]|0)<<8|(d[u+f|0]|0))<<16;z=t}else{t=gj[c[v+196768+(u<<2)>>2]&4095](q)|0;y=t;z=c[2276056]|0}c[2276084]=y;w=y>>>16|s<<16;x=z}c[2276056]=x+2;x=0;z=w;w=0;while(1){if((n&1<<x|0)==0){A=w;B=z}else{s=c[9104156+(x<<2)>>2]|0;y=c[2276085]&z;t=y&16777215;q=c[2112932]|0;u=c[q+((t>>>10|16384)<<2)>>2]|0;if(u>>>0>9){v=y&1023;a[u+v|0]=s>>>16&255;a[u+(v+1)|0]=s>>>24&255;a[u+(v+2)|0]=s&255;a[u+(v+3)|0]=s>>>8&255}else{gg[c[q+196808+(u<<2)>>2]&4095](t,s)}A=w+1|0;B=z+4|0}s=x+1|0;if(s>>>0<16){x=s;z=B;w=A}else{break}}c[2276108]=(c[2276108]|0)-(A<<c[2276095]);return}function vw(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=f>>>((e<<3&16^16)>>>0)&65535;e=0;f=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;l=0;while(1){if((k&1<<e|0)==0){m=l;n=f}else{a=c[2276085]&f;b=a&16777215;i=c[2112932]|0;h=c[i+(b>>>10<<2)>>2]|0;if(h>>>0>9){j=a&1023;o=(d[h+(j+1)|0]|0)<<8|(d[h+j|0]|0)}else{o=gj[c[i+196688+(h<<2)>>2]&4095](b)|0}c[9104156+(e<<2)>>2]=o<<16>>16;m=l+1|0;n=f+2|0}b=e+1|0;if(b>>>0<16){e=b;f=n;l=m}else{break}}c[9104156+((c[2276069]&7|8)<<2)>>2]=n;c[2276108]=(c[2276108]|0)-(m<<c[2276094]);return}function vx(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0;g=b}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=m;g=o}o=e+2|0;c[2276056]=o;m=f>>>((e<<3&16^16)>>>0)&65535;e=o&-4;if((e|0)==(g|0)){p=o;q=f}else{c[2276083]=e;f=c[2276085]&e;e=f&16777212;g=c[2112932]|0;n=c[g+((e>>>10|32768)<<2)>>2]|0;if(n>>>0>9){b=f&1020;r=(d[n+(b|3)|0]|0)<<8|(d[n+(b|2)|0]|0)|((d[n+(b|1)|0]|0)<<8|(d[n+b|0]|0))<<16;s=o}else{b=gj[c[g+196768+(n<<2)>>2]&4095](e)|0;r=b;s=c[2276056]|0}c[2276084]=r;p=s;q=r}c[2276056]=p+2;r=0;s=(q>>>((p<<3&16^16)>>>0)<<16>>16)+o|0;o=0;while(1){if((m&1<<r|0)==0){t=o;u=s}else{p=s&16777215;q=c[2112932]|0;b=c[q+((p>>>10|32768)<<2)>>2]|0;if(b>>>0>9){e=s&1023;v=(d[b+(e+1)|0]|0)<<8|(d[b+e|0]|0)}else{v=gj[c[q+196688+(b<<2)>>2]&4095](p)|0}c[9104156+(r<<2)>>2]=v<<16>>16;t=o+1|0;u=s+2|0}p=r+1|0;if(p>>>0<16){r=p;s=u;o=t}else{break}}c[2276108]=(c[2276108]|0)-(t<<c[2276094]);return}function vy(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}k=e+2|0;c[2276056]=k;l=f>>>((e<<3&16^16)>>>0)&65535;e=0;f=nB(k)|0;k=0;while(1){if((l&1<<e|0)==0){m=k;n=f}else{a=f&16777215;b=c[2112932]|0;i=c[b+((a>>>10|32768)<<2)>>2]|0;if(i>>>0>9){h=f&1023;o=(d[i+(h+1)|0]|0)<<8|(d[i+h|0]|0)}else{o=gj[c[b+196688+(i<<2)>>2]&4095](a)|0}c[9104156+(e<<2)>>2]=o<<16>>16;m=k+1|0;n=f+2|0}a=e+1|0;if(a>>>0<16){e=a;f=n;k=m}else{break}}c[2276108]=(c[2276108]|0)-(m<<c[2276094]);return}function vz(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=f>>>((e<<3&16^16)>>>0)&65535;e=0;f=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;l=0;while(1){if((k&1<<e|0)==0){m=l;n=f}else{a=c[2276085]&f;b=a&16777215;i=c[2112932]|0;h=c[i+(b>>>10<<2)>>2]|0;if(h>>>0>9){j=a&1023;o=(d[h+(j+1)|0]|0)<<8|(d[h+j|0]|0)}else{o=gj[c[i+196688+(h<<2)>>2]&4095](b)|0}c[9104156+(e<<2)>>2]=o<<16>>16;m=l+1|0;n=f+2|0}b=e+1|0;if(b>>>0<16){e=b;f=n;l=m}else{break}}c[2276108]=(c[2276108]|0)-(m<<c[2276094]);return}function vA(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0;g=b}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=m;g=o}o=e+2|0;c[2276056]=o;m=f>>>((e<<3&16^16)>>>0)&65535;e=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;n=o&-4;if((n|0)==(g|0)){p=o;q=f}else{c[2276083]=n;f=c[2276085]&n;n=f&16777212;g=c[2112932]|0;b=c[g+((n>>>10|32768)<<2)>>2]|0;if(b>>>0>9){i=f&1020;r=(d[b+(i|3)|0]|0)<<8|(d[b+(i|2)|0]|0)|((d[b+(i|1)|0]|0)<<8|(d[b+i|0]|0))<<16;s=o}else{o=gj[c[g+196768+(b<<2)>>2]&4095](n)|0;r=o;s=c[2276056]|0}c[2276084]=r;p=s;q=r}c[2276056]=p+2;r=0;s=(q>>>((p<<3&16^16)>>>0)<<16>>16)+e|0;e=0;while(1){if((m&1<<r|0)==0){t=e;u=s}else{p=c[2276085]&s;q=p&16777215;o=c[2112932]|0;n=c[o+(q>>>10<<2)>>2]|0;if(n>>>0>9){b=p&1023;v=(d[n+(b+1)|0]|0)<<8|(d[n+b|0]|0)}else{v=gj[c[o+196688+(n<<2)>>2]&4095](q)|0}c[9104156+(r<<2)>>2]=v<<16>>16;t=e+1|0;u=s+2|0}q=r+1|0;if(q>>>0<16){r=q;s=u;e=t}else{break}}c[2276108]=(c[2276108]|0)-(t<<c[2276094]);return}function vB(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=f>>>((e<<3&16^16)>>>0)&65535;e=0;f=nB(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;l=0;while(1){if((k&1<<e|0)==0){m=l;n=f}else{a=c[2276085]&f;b=a&16777215;i=c[2112932]|0;h=c[i+(b>>>10<<2)>>2]|0;if(h>>>0>9){j=a&1023;o=(d[h+(j+1)|0]|0)<<8|(d[h+j|0]|0)}else{o=gj[c[i+196688+(h<<2)>>2]&4095](b)|0}c[9104156+(e<<2)>>2]=o<<16>>16;m=l+1|0;n=f+2|0}b=e+1|0;if(b>>>0<16){e=b;f=n;l=m}else{break}}c[2276108]=(c[2276108]|0)-(m<<c[2276094]);return}function vC(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0;g=b}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=m;g=o}o=e+2|0;c[2276056]=o;m=f>>>((e<<3&16^16)>>>0)&65535;e=o&-4;if((e|0)==(g|0)){p=o;q=f}else{c[2276083]=e;f=c[2276085]&e;e=f&16777212;g=c[2112932]|0;n=c[g+((e>>>10|32768)<<2)>>2]|0;if(n>>>0>9){b=f&1020;r=(d[n+(b|3)|0]|0)<<8|(d[n+(b|2)|0]|0)|((d[n+(b|1)|0]|0)<<8|(d[n+b|0]|0))<<16;s=o}else{o=gj[c[g+196768+(n<<2)>>2]&4095](e)|0;r=o;s=c[2276056]|0}c[2276084]=r;p=s;q=r}c[2276056]=p+2;r=0;s=q>>>((p<<3&16^16)>>>0)<<16>>16;p=0;while(1){if((m&1<<r|0)==0){t=p;u=s}else{q=c[2276085]&s;o=q&16777215;e=c[2112932]|0;n=c[e+(o>>>10<<2)>>2]|0;if(n>>>0>9){g=q&1023;v=(d[n+(g+1)|0]|0)<<8|(d[n+g|0]|0)}else{v=gj[c[e+196688+(n<<2)>>2]&4095](o)|0}c[9104156+(r<<2)>>2]=v<<16>>16;t=p+1|0;u=s+2|0}o=r+1|0;if(o>>>0<16){r=o;s=u;p=t}else{break}}c[2276108]=(c[2276108]|0)-(t<<c[2276094]);return}function vD(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0;g=b}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=m;g=o}o=e+2|0;c[2276056]=o;m=f>>>((e<<3&16^16)>>>0)&65535;e=o&-4;if((e|0)==(g|0)){p=o;q=g;r=f}else{c[2276083]=e;f=c[2276085]&e;g=f&16777212;n=c[2112932]|0;b=c[n+((g>>>10|32768)<<2)>>2]|0;if(b>>>0>9){i=f&1020;s=(d[b+(i|3)|0]|0)<<8|(d[b+(i|2)|0]|0)|((d[b+(i|1)|0]|0)<<8|(d[b+i|0]|0))<<16;t=o;u=e}else{e=gj[c[n+196768+(b<<2)>>2]&4095](g)|0;s=e;t=c[2276056]|0;u=c[2276083]|0}c[2276084]=s;p=t;q=u;r=s}s=p+2|0;c[2276056]=s;p=s&-4;if((p|0)==(q|0)){v=r;w=s}else{c[2276083]=p;q=c[2276085]&p;p=q&16777212;u=c[2112932]|0;t=c[u+((p>>>10|32768)<<2)>>2]|0;if(t>>>0>9){e=q&1020;x=(d[t+(e|3)|0]|0)<<8|(d[t+(e|2)|0]|0)|((d[t+(e|1)|0]|0)<<8|(d[t+e|0]|0))<<16;y=s}else{s=gj[c[u+196768+(t<<2)>>2]&4095](p)|0;x=s;y=c[2276056]|0}c[2276084]=x;v=x>>>16|r<<16;w=y}c[2276056]=w+2;w=0;y=v;v=0;while(1){if((m&1<<w|0)==0){z=v;A=y}else{r=c[2276085]&y;x=r&16777215;s=c[2112932]|0;p=c[s+(x>>>10<<2)>>2]|0;if(p>>>0>9){t=r&1023;B=(d[p+(t+1)|0]|0)<<8|(d[p+t|0]|0)}else{B=gj[c[s+196688+(p<<2)>>2]&4095](x)|0}c[9104156+(w<<2)>>2]=B<<16>>16;z=v+1|0;A=y+2|0}x=w+1|0;if(x>>>0<16){w=x;y=A;v=z}else{break}}c[2276108]=(c[2276108]|0)-(z<<c[2276094]);return}function vE(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=f>>>((e<<3&16^16)>>>0)&65535;e=0;f=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;l=0;while(1){if((k&1<<e|0)==0){m=l;n=f}else{a=c[2276085]&f;b=a&16777215;i=c[2112932]|0;h=c[i+(b>>>10<<2)>>2]|0;if(h>>>0>9){j=a&1023;o=(d[h+(j+3)|0]|0)<<8|(d[h+(j+2)|0]|0)|((d[h+(j+1)|0]|0)<<8|(d[h+j|0]|0))<<16}else{o=gj[c[i+196768+(h<<2)>>2]&4095](b)|0}c[9104156+(e<<2)>>2]=o;m=l+1|0;n=f+4|0}b=e+1|0;if(b>>>0<16){e=b;f=n;l=m}else{break}}c[9104156+((c[2276069]&7|8)<<2)>>2]=n;c[2276108]=(c[2276108]|0)-(m<<c[2276095]);return}function vF(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0;g=b}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=m;g=o}o=e+2|0;c[2276056]=o;m=f>>>((e<<3&16^16)>>>0)&65535;e=o&-4;if((e|0)==(g|0)){p=o;q=f}else{c[2276083]=e;f=c[2276085]&e;e=f&16777212;g=c[2112932]|0;n=c[g+((e>>>10|32768)<<2)>>2]|0;if(n>>>0>9){b=f&1020;r=(d[n+(b|3)|0]|0)<<8|(d[n+(b|2)|0]|0)|((d[n+(b|1)|0]|0)<<8|(d[n+b|0]|0))<<16;s=o}else{b=gj[c[g+196768+(n<<2)>>2]&4095](e)|0;r=b;s=c[2276056]|0}c[2276084]=r;p=s;q=r}c[2276056]=p+2;r=0;s=(q>>>((p<<3&16^16)>>>0)<<16>>16)+o|0;o=0;while(1){if((m&1<<r|0)==0){t=o;u=s}else{p=s&16777215;q=c[2112932]|0;b=c[q+((p>>>10|32768)<<2)>>2]|0;if(b>>>0>9){e=s&1023;v=(d[b+(e+3)|0]|0)<<8|(d[b+(e+2)|0]|0)|((d[b+(e+1)|0]|0)<<8|(d[b+e|0]|0))<<16}else{v=gj[c[q+196768+(b<<2)>>2]&4095](p)|0}c[9104156+(r<<2)>>2]=v;t=o+1|0;u=s+4|0}p=r+1|0;if(p>>>0<16){r=p;s=u;o=t}else{break}}c[2276108]=(c[2276108]|0)-(t<<c[2276095]);return}function vG(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}k=e+2|0;c[2276056]=k;l=f>>>((e<<3&16^16)>>>0)&65535;e=0;f=nB(k)|0;k=0;while(1){if((l&1<<e|0)==0){m=k;n=f}else{a=f&16777215;b=c[2112932]|0;i=c[b+((a>>>10|32768)<<2)>>2]|0;if(i>>>0>9){h=f&1023;o=(d[i+(h+3)|0]|0)<<8|(d[i+(h+2)|0]|0)|((d[i+(h+1)|0]|0)<<8|(d[i+h|0]|0))<<16}else{o=gj[c[b+196768+(i<<2)>>2]&4095](a)|0}c[9104156+(e<<2)>>2]=o;m=k+1|0;n=f+4|0}a=e+1|0;if(a>>>0<16){e=a;f=n;k=m}else{break}}c[2276108]=(c[2276108]|0)-(m<<c[2276095]);return}function vH(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=f>>>((e<<3&16^16)>>>0)&65535;e=0;f=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;l=0;while(1){if((k&1<<e|0)==0){m=l;n=f}else{a=c[2276085]&f;b=a&16777215;i=c[2112932]|0;h=c[i+(b>>>10<<2)>>2]|0;if(h>>>0>9){j=a&1023;o=(d[h+(j+3)|0]|0)<<8|(d[h+(j+2)|0]|0)|((d[h+(j+1)|0]|0)<<8|(d[h+j|0]|0))<<16}else{o=gj[c[i+196768+(h<<2)>>2]&4095](b)|0}c[9104156+(e<<2)>>2]=o;m=l+1|0;n=f+4|0}b=e+1|0;if(b>>>0<16){e=b;f=n;l=m}else{break}}c[2276108]=(c[2276108]|0)-(m<<c[2276095]);return}function vI(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0;g=b}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=m;g=o}o=e+2|0;c[2276056]=o;m=f>>>((e<<3&16^16)>>>0)&65535;e=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;n=o&-4;if((n|0)==(g|0)){p=o;q=f}else{c[2276083]=n;f=c[2276085]&n;n=f&16777212;g=c[2112932]|0;b=c[g+((n>>>10|32768)<<2)>>2]|0;if(b>>>0>9){i=f&1020;r=(d[b+(i|3)|0]|0)<<8|(d[b+(i|2)|0]|0)|((d[b+(i|1)|0]|0)<<8|(d[b+i|0]|0))<<16;s=o}else{o=gj[c[g+196768+(b<<2)>>2]&4095](n)|0;r=o;s=c[2276056]|0}c[2276084]=r;p=s;q=r}c[2276056]=p+2;r=0;s=(q>>>((p<<3&16^16)>>>0)<<16>>16)+e|0;e=0;while(1){if((m&1<<r|0)==0){t=e;u=s}else{p=c[2276085]&s;q=p&16777215;o=c[2112932]|0;n=c[o+(q>>>10<<2)>>2]|0;if(n>>>0>9){b=p&1023;v=(d[n+(b+3)|0]|0)<<8|(d[n+(b+2)|0]|0)|((d[n+(b+1)|0]|0)<<8|(d[n+b|0]|0))<<16}else{v=gj[c[o+196768+(n<<2)>>2]&4095](q)|0}c[9104156+(r<<2)>>2]=v;t=e+1|0;u=s+4|0}q=r+1|0;if(q>>>0<16){r=q;s=u;e=t}else{break}}c[2276108]=(c[2276108]|0)-(t<<c[2276095]);return}function vJ(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=f>>>((e<<3&16^16)>>>0)&65535;e=0;f=nB(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;l=0;while(1){if((k&1<<e|0)==0){m=l;n=f}else{a=c[2276085]&f;b=a&16777215;i=c[2112932]|0;h=c[i+(b>>>10<<2)>>2]|0;if(h>>>0>9){j=a&1023;o=(d[h+(j+3)|0]|0)<<8|(d[h+(j+2)|0]|0)|((d[h+(j+1)|0]|0)<<8|(d[h+j|0]|0))<<16}else{o=gj[c[i+196768+(h<<2)>>2]&4095](b)|0}c[9104156+(e<<2)>>2]=o;m=l+1|0;n=f+4|0}b=e+1|0;if(b>>>0<16){e=b;f=n;l=m}else{break}}c[2276108]=(c[2276108]|0)-(m<<c[2276095]);return}function vK(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0;g=b}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=m;g=o}o=e+2|0;c[2276056]=o;m=f>>>((e<<3&16^16)>>>0)&65535;e=o&-4;if((e|0)==(g|0)){p=o;q=f}else{c[2276083]=e;f=c[2276085]&e;e=f&16777212;g=c[2112932]|0;n=c[g+((e>>>10|32768)<<2)>>2]|0;if(n>>>0>9){b=f&1020;r=(d[n+(b|3)|0]|0)<<8|(d[n+(b|2)|0]|0)|((d[n+(b|1)|0]|0)<<8|(d[n+b|0]|0))<<16;s=o}else{o=gj[c[g+196768+(n<<2)>>2]&4095](e)|0;r=o;s=c[2276056]|0}c[2276084]=r;p=s;q=r}c[2276056]=p+2;r=0;s=q>>>((p<<3&16^16)>>>0)<<16>>16;p=0;while(1){if((m&1<<r|0)==0){t=p;u=s}else{q=c[2276085]&s;o=q&16777215;e=c[2112932]|0;n=c[e+(o>>>10<<2)>>2]|0;if(n>>>0>9){g=q&1023;v=(d[n+(g+3)|0]|0)<<8|(d[n+(g+2)|0]|0)|((d[n+(g+1)|0]|0)<<8|(d[n+g|0]|0))<<16}else{v=gj[c[e+196768+(n<<2)>>2]&4095](o)|0}c[9104156+(r<<2)>>2]=v;t=p+1|0;u=s+4|0}o=r+1|0;if(o>>>0<16){r=o;s=u;p=t}else{break}}c[2276108]=(c[2276108]|0)-(t<<c[2276095]);return}function vL(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0;g=b}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=m;g=o}o=e+2|0;c[2276056]=o;m=f>>>((e<<3&16^16)>>>0)&65535;e=o&-4;if((e|0)==(g|0)){p=o;q=g;r=f}else{c[2276083]=e;f=c[2276085]&e;g=f&16777212;n=c[2112932]|0;b=c[n+((g>>>10|32768)<<2)>>2]|0;if(b>>>0>9){i=f&1020;s=(d[b+(i|3)|0]|0)<<8|(d[b+(i|2)|0]|0)|((d[b+(i|1)|0]|0)<<8|(d[b+i|0]|0))<<16;t=o;u=e}else{e=gj[c[n+196768+(b<<2)>>2]&4095](g)|0;s=e;t=c[2276056]|0;u=c[2276083]|0}c[2276084]=s;p=t;q=u;r=s}s=p+2|0;c[2276056]=s;p=s&-4;if((p|0)==(q|0)){v=r;w=s}else{c[2276083]=p;q=c[2276085]&p;p=q&16777212;u=c[2112932]|0;t=c[u+((p>>>10|32768)<<2)>>2]|0;if(t>>>0>9){e=q&1020;x=(d[t+(e|3)|0]|0)<<8|(d[t+(e|2)|0]|0)|((d[t+(e|1)|0]|0)<<8|(d[t+e|0]|0))<<16;y=s}else{s=gj[c[u+196768+(t<<2)>>2]&4095](p)|0;x=s;y=c[2276056]|0}c[2276084]=x;v=x>>>16|r<<16;w=y}c[2276056]=w+2;w=0;y=v;v=0;while(1){if((m&1<<w|0)==0){z=v;A=y}else{r=c[2276085]&y;x=r&16777215;s=c[2112932]|0;p=c[s+(x>>>10<<2)>>2]|0;if(p>>>0>9){t=r&1023;B=(d[p+(t+3)|0]|0)<<8|(d[p+(t+2)|0]|0)|((d[p+(t+1)|0]|0)<<8|(d[p+t|0]|0))<<16}else{B=gj[c[s+196768+(p<<2)>>2]&4095](x)|0}c[9104156+(w<<2)>>2]=B;z=v+1|0;A=y+4|0}x=w+1|0;if(x>>>0<16){w=x;y=A;v=z}else{break}}c[2276108]=(c[2276108]|0)-(z<<c[2276095]);return}function vM(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=c[2276069]|0;e=c[9104156+((b&7|8)<<2)>>2]|0;f=c[2276056]|0;g=f&-4;if((g|0)==(c[2276083]|0)){h=f;i=c[2276084]|0;j=b}else{c[2276083]=g;k=c[2276085]&g;g=k&16777212;l=c[2112932]|0;m=c[l+((g>>>10|32768)<<2)>>2]|0;if(m>>>0>9){n=k&1020;o=(d[m+(n|3)|0]|0)<<8|(d[m+(n|2)|0]|0)|((d[m+(n|1)|0]|0)<<8|(d[m+n|0]|0))<<16;p=f;q=b}else{b=gj[c[l+196768+(m<<2)>>2]&4095](g)|0;o=b;p=c[2276056]|0;q=c[2276069]|0}c[2276084]=o;h=p;i=o;j=q}c[2276056]=h+2;q=(i>>>((h<<3&16^16)>>>0)<<16>>16)+e|0;e=c[9104156+((j>>>9&7)<<2)>>2]|0;j=q&c[2276085];h=e>>>8&255;i=j&16777215;o=c[2112932]|0;p=c[o+((i>>>10|16384)<<2)>>2]|0;if(p>>>0>9){a[p+(j&1023^1)|0]=h;r=o}else{gg[c[o+196648+(p<<2)>>2]&4095](i,h);r=c[2112932]|0}h=c[2276085]&q+2;q=e&255;e=h&16777215;i=c[r+((e>>>10|16384)<<2)>>2]|0;if(i>>>0>9){a[i+(h&1023^1)|0]=q;return}else{gg[c[r+196648+(i<<2)>>2]&4095](e,q);return}}function vN(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=c[2276069]|0;e=c[9104156+((b&7|8)<<2)>>2]|0;f=c[2276056]|0;g=f&-4;if((g|0)==(c[2276083]|0)){h=f;i=c[2276084]|0;j=b}else{c[2276083]=g;k=c[2276085]&g;g=k&16777212;l=c[2112932]|0;m=c[l+((g>>>10|32768)<<2)>>2]|0;if(m>>>0>9){n=k&1020;o=(d[m+(n|3)|0]|0)<<8|(d[m+(n|2)|0]|0)|((d[m+(n|1)|0]|0)<<8|(d[m+n|0]|0))<<16;p=f;q=b}else{b=gj[c[l+196768+(m<<2)>>2]&4095](g)|0;o=b;p=c[2276056]|0;q=c[2276069]|0}c[2276084]=o;h=p;i=o;j=q}c[2276056]=h+2;q=(i>>>((h<<3&16^16)>>>0)<<16>>16)+e|0;e=c[9104156+((j>>>9&7)<<2)>>2]|0;j=q&c[2276085];h=e>>>24&255;i=j&16777215;o=c[2112932]|0;p=c[o+((i>>>10|16384)<<2)>>2]|0;if(p>>>0>9){a[p+(j&1023^1)|0]=h;r=o}else{gg[c[o+196648+(p<<2)>>2]&4095](i,h);r=c[2112932]|0}h=c[2276085]&q+2;i=e>>>16&255;p=h&16777215;o=c[r+((p>>>10|16384)<<2)>>2]|0;if(o>>>0>9){a[o+(h&1023^1)|0]=i;s=r}else{gg[c[r+196648+(o<<2)>>2]&4095](p,i);s=c[2112932]|0}i=c[2276085]&q+4;p=e>>>8&255;o=i&16777215;r=c[s+((o>>>10|16384)<<2)>>2]|0;if(r>>>0>9){a[r+(i&1023^1)|0]=p;t=s}else{gg[c[s+196648+(r<<2)>>2]&4095](o,p);t=c[2112932]|0}p=c[2276085]&q+6;q=e&255;e=p&16777215;o=c[t+((e>>>10|16384)<<2)>>2]|0;if(o>>>0>9){a[o+(p&1023^1)|0]=q;return}else{gg[c[t+196648+(o<<2)>>2]&4095](e,q);return}}function vO(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;b=c[2276069]|0;e=c[9104156+((b&7|8)<<2)>>2]|0;f=c[2276056]|0;g=f&-4;if((g|0)==(c[2276083]|0)){h=f;i=c[2276084]|0;j=b}else{c[2276083]=g;k=c[2276085]&g;g=k&16777212;l=c[2112932]|0;m=c[l+((g>>>10|32768)<<2)>>2]|0;if(m>>>0>9){n=k&1020;o=(d[m+(n|3)|0]|0)<<8|(d[m+(n|2)|0]|0)|((d[m+(n|1)|0]|0)<<8|(d[m+n|0]|0))<<16;p=f;q=b}else{b=gj[c[l+196768+(m<<2)>>2]&4095](g)|0;o=b;p=c[2276056]|0;q=c[2276069]|0}c[2276084]=o;h=p;i=o;j=q}c[2276056]=h+2;q=(i>>>((h<<3&16^16)>>>0)<<16>>16)+e|0;e=9104156+((j>>>9&7)<<2)|0;j=c[e>>2]&-65536;h=c[2276085]|0;i=q&h;o=i&16777215;p=c[2112932]|0;b=c[p+(o>>>10<<2)>>2]|0;if(b>>>0>9){r=a[b+(i&1023^1)|0]|0;s=h;t=p}else{h=gj[c[p+196608+(b<<2)>>2]&4095](o)|0;r=h;s=c[2276085]|0;t=c[2112932]|0}h=(r&255)<<8;r=s&q+2;q=r&16777215;s=c[t+(q>>>10<<2)>>2]|0;if(s>>>0>9){u=a[s+(r&1023^1)|0]|0;v=u&255;w=h|j;x=w|v;c[e>>2]=x;return}else{u=gj[c[t+196608+(s<<2)>>2]&4095](q)|0;v=u&255;w=h|j;x=w|v;c[e>>2]=x;return}}function vP(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=(h>>>((g<<3&16^16)>>>0)<<16>>16)+b|0;b=c[2276085]|0;g=m&b;h=g&16777215;n=c[2112932]|0;e=c[n+(h>>>10<<2)>>2]|0;if(e>>>0>9){o=a[e+(g&1023^1)|0]|0;p=b;q=n}else{b=gj[c[n+196608+(e<<2)>>2]&4095](h)|0;o=b;p=c[2276085]|0;q=c[2112932]|0}b=p&m+2;h=b&16777215;e=c[q+(h>>>10<<2)>>2]|0;if(e>>>0>9){r=a[e+(b&1023^1)|0]|0;s=p;t=q}else{p=gj[c[q+196608+(e<<2)>>2]&4095](h)|0;r=p;s=c[2276085]|0;t=c[2112932]|0}p=s&m+4;h=p&16777215;e=c[t+(h>>>10<<2)>>2]|0;if(e>>>0>9){u=a[e+(p&1023^1)|0]|0;v=s;w=t}else{s=gj[c[t+196608+(e<<2)>>2]&4095](h)|0;u=s;v=c[2276085]|0;w=c[2112932]|0}s=(r&255)<<16|(o&255)<<24|(u&255)<<8;u=v&m+6;m=u&16777215;v=c[w+(m>>>10<<2)>>2]|0;if(v>>>0>9){x=a[v+(u&1023^1)|0]|0;y=x&255;z=s|y;A=c[2276069]|0;B=A>>>9;C=B&7;D=9104156+(C<<2)|0;c[D>>2]=z;return}else{x=gj[c[w+196608+(v<<2)>>2]&4095](m)|0;y=x&255;z=s|y;A=c[2276069]|0;B=A>>>9;C=B&7;D=9104156+(C<<2)|0;c[D>>2]=z;return}}function vQ(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((c[2276038]&28|0)==0){ni();return}if((c[2276072]|0)==0){ol();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0);f=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;if((l&2048|0)!=0){g=c[2276085]&f;m=c[9104156+((l>>>12&15)<<2)>>2]&255;b=g&16777215;e=c[2112932]|0;j=c[e+((b>>>10|16384)<<2)>>2]|0;if(j>>>0>9){a[j+(g&1023^1)|0]=m;return}else{gg[c[e+196648+(j<<2)>>2]&4095](b,m);return}}if((l&32768|0)==0){m=9104156+((l>>>12&7)<<2)|0;b=c[m>>2]&-256;j=c[2276085]&f;e=j&16777215;g=c[2112932]|0;i=c[g+(e>>>10<<2)>>2]|0;if(i>>>0>9){n=a[i+(j&1023^1)|0]|0}else{n=gj[c[g+196608+(i<<2)>>2]&4095](e)|0}c[m>>2]=n&255|b;if((c[2276038]&24|0)==0){return}c[2276108]=(c[2276108]|0)-2;return}else{b=c[2276085]&f;f=b&16777215;n=c[2112932]|0;m=c[n+(f>>>10<<2)>>2]|0;if(m>>>0>9){o=a[m+(b&1023^1)|0]|0}else{o=gj[c[n+196608+(m<<2)>>2]&4095](f)|0}c[9104156+((l>>>12&7|8)<<2)>>2]=o<<24>>24;if((c[2276038]&24|0)==0){return}c[2276108]=(c[2276108]|0)-2;return}}function vR(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((c[2276038]&28|0)==0){ni();return}if((c[2276072]|0)==0){ol();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0);f=9104156+((c[2276069]&7|8)<<2)|0;g=c[f>>2]|0;c[f>>2]=g+1;if((l&2048|0)!=0){f=c[2276085]&g;m=c[9104156+((l>>>12&15)<<2)>>2]&255;b=f&16777215;e=c[2112932]|0;j=c[e+((b>>>10|16384)<<2)>>2]|0;if(j>>>0>9){a[j+(f&1023^1)|0]=m;return}else{gg[c[e+196648+(j<<2)>>2]&4095](b,m);return}}if((l&32768|0)==0){m=9104156+((l>>>12&7)<<2)|0;b=c[m>>2]&-256;j=c[2276085]&g;e=j&16777215;f=c[2112932]|0;i=c[f+(e>>>10<<2)>>2]|0;if(i>>>0>9){n=a[i+(j&1023^1)|0]|0}else{n=gj[c[f+196608+(i<<2)>>2]&4095](e)|0}c[m>>2]=n&255|b;if((c[2276038]&24|0)==0){return}c[2276108]=(c[2276108]|0)-2;return}else{b=c[2276085]&g;g=b&16777215;n=c[2112932]|0;m=c[n+(g>>>10<<2)>>2]|0;if(m>>>0>9){o=a[m+(b&1023^1)|0]|0}else{o=gj[c[n+196608+(m<<2)>>2]&4095](g)|0}c[9104156+((l>>>12&7|8)<<2)>>2]=o<<24>>24;if((c[2276038]&24|0)==0){return}c[2276108]=(c[2276108]|0)-2;return}}function vS(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((c[2276038]&28|0)==0){ni();return}if((c[2276072]|0)==0){ol();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0);f=c[2276054]|0;c[2276054]=f+2;if((l&2048|0)!=0){g=c[2276085]&f;m=c[9104156+((l>>>12&15)<<2)>>2]&255;b=g&16777215;e=c[2112932]|0;j=c[e+((b>>>10|16384)<<2)>>2]|0;if(j>>>0>9){a[j+(g&1023^1)|0]=m;return}else{gg[c[e+196648+(j<<2)>>2]&4095](b,m);return}}if((l&32768|0)==0){m=9104156+((l>>>12&7)<<2)|0;b=c[m>>2]&-256;j=c[2276085]&f;e=j&16777215;g=c[2112932]|0;i=c[g+(e>>>10<<2)>>2]|0;if(i>>>0>9){n=a[i+(j&1023^1)|0]|0}else{n=gj[c[g+196608+(i<<2)>>2]&4095](e)|0}c[m>>2]=n&255|b;if((c[2276038]&24|0)==0){return}c[2276108]=(c[2276108]|0)-2;return}else{b=c[2276085]&f;f=b&16777215;n=c[2112932]|0;m=c[n+(f>>>10<<2)>>2]|0;if(m>>>0>9){o=a[m+(b&1023^1)|0]|0}else{o=gj[c[n+196608+(m<<2)>>2]&4095](f)|0}c[9104156+((l>>>12&7|8)<<2)>>2]=o<<24>>24;if((c[2276038]&24|0)==0){return}c[2276108]=(c[2276108]|0)-2;return}}function vT(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((c[2276038]&28|0)==0){ni();return}if((c[2276072]|0)==0){ol();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0);f=9104156+((c[2276069]&7|8)<<2)|0;g=(c[f>>2]|0)-1|0;c[f>>2]=g;if((l&2048|0)!=0){f=c[2276085]&g;m=c[9104156+((l>>>12&15)<<2)>>2]&255;b=f&16777215;e=c[2112932]|0;j=c[e+((b>>>10|16384)<<2)>>2]|0;if(j>>>0>9){a[j+(f&1023^1)|0]=m;return}else{gg[c[e+196648+(j<<2)>>2]&4095](b,m);return}}if((l&32768|0)==0){m=9104156+((l>>>12&7)<<2)|0;b=c[m>>2]&-256;j=c[2276085]&g;e=j&16777215;f=c[2112932]|0;i=c[f+(e>>>10<<2)>>2]|0;if(i>>>0>9){n=a[i+(j&1023^1)|0]|0}else{n=gj[c[f+196608+(i<<2)>>2]&4095](e)|0}c[m>>2]=n&255|b;if((c[2276038]&24|0)==0){return}c[2276108]=(c[2276108]|0)-2;return}else{b=c[2276085]&g;g=b&16777215;n=c[2112932]|0;m=c[n+(g>>>10<<2)>>2]|0;if(m>>>0>9){o=a[m+(b&1023^1)|0]|0}else{o=gj[c[n+196608+(m<<2)>>2]&4095](g)|0}c[9104156+((l>>>12&7|8)<<2)>>2]=o<<24>>24;if((c[2276038]&24|0)==0){return}c[2276108]=(c[2276108]|0)-2;return}}function vU(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((c[2276038]&28|0)==0){ni();return}if((c[2276072]|0)==0){ol();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0);f=(c[2276054]|0)-2|0;c[2276054]=f;if((l&2048|0)!=0){g=c[2276085]&f;m=c[9104156+((l>>>12&15)<<2)>>2]&255;b=g&16777215;e=c[2112932]|0;j=c[e+((b>>>10|16384)<<2)>>2]|0;if(j>>>0>9){a[j+(g&1023^1)|0]=m;return}else{gg[c[e+196648+(j<<2)>>2]&4095](b,m);return}}if((l&32768|0)==0){m=9104156+((l>>>12&7)<<2)|0;b=c[m>>2]&-256;j=c[2276085]&f;e=j&16777215;g=c[2112932]|0;i=c[g+(e>>>10<<2)>>2]|0;if(i>>>0>9){n=a[i+(j&1023^1)|0]|0}else{n=gj[c[g+196608+(i<<2)>>2]&4095](e)|0}c[m>>2]=n&255|b;if((c[2276038]&24|0)==0){return}c[2276108]=(c[2276108]|0)-2;return}else{b=c[2276085]&f;f=b&16777215;n=c[2112932]|0;m=c[n+(f>>>10<<2)>>2]|0;if(m>>>0>9){o=a[m+(b&1023^1)|0]|0}else{o=gj[c[n+196608+(m<<2)>>2]&4095](f)|0}c[9104156+((l>>>12&7|8)<<2)>>2]=o<<24>>24;if((c[2276038]&24|0)==0){return}c[2276108]=(c[2276108]|0)-2;return}}function vV(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;if((c[2276038]&28|0)==0){ni();return}if((c[2276072]|0)==0){ol();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0);f=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;o=p&-4;if((o|0)==(h|0)){q=p;r=g}else{c[2276083]=o;g=c[2276085]&o;o=g&16777212;h=c[2112932]|0;e=c[h+((o>>>10|32768)<<2)>>2]|0;if(e>>>0>9){j=g&1020;s=(d[e+(j|3)|0]|0)<<8|(d[e+(j|2)|0]|0)|((d[e+(j|1)|0]|0)<<8|(d[e+j|0]|0))<<16;t=p}else{p=gj[c[h+196768+(e<<2)>>2]&4095](o)|0;s=p;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;s=(r>>>((q<<3&16^16)>>>0)<<16>>16)+f|0;if((n&2048|0)!=0){f=c[2276085]&s;q=c[9104156+((n>>>12&15)<<2)>>2]&255;r=f&16777215;t=c[2112932]|0;p=c[t+((r>>>10|16384)<<2)>>2]|0;if(p>>>0>9){a[p+(f&1023^1)|0]=q;return}else{gg[c[t+196648+(p<<2)>>2]&4095](r,q);return}}if((n&32768|0)==0){q=9104156+((n>>>12&7)<<2)|0;r=c[q>>2]&-256;p=c[2276085]&s;t=p&16777215;f=c[2112932]|0;o=c[f+(t>>>10<<2)>>2]|0;if(o>>>0>9){u=a[o+(p&1023^1)|0]|0}else{u=gj[c[f+196608+(o<<2)>>2]&4095](t)|0}c[q>>2]=u&255|r;if((c[2276038]&24|0)==0){return}c[2276108]=(c[2276108]|0)-2;return}else{r=c[2276085]&s;s=r&16777215;u=c[2112932]|0;q=c[u+(s>>>10<<2)>>2]|0;if(q>>>0>9){v=a[q+(r&1023^1)|0]|0}else{v=gj[c[u+196608+(q<<2)>>2]&4095](s)|0}c[9104156+((n>>>12&7|8)<<2)>>2]=v<<24>>24;if((c[2276038]&24|0)==0){return}c[2276108]=(c[2276108]|0)-2;return}}function vW(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((c[2276038]&28|0)==0){ni();return}if((c[2276072]|0)==0){ol();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0);f=nB(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;if((l&2048|0)!=0){g=c[2276085]&f;m=c[9104156+((l>>>12&15)<<2)>>2]&255;b=g&16777215;e=c[2112932]|0;j=c[e+((b>>>10|16384)<<2)>>2]|0;if(j>>>0>9){a[j+(g&1023^1)|0]=m;return}else{gg[c[e+196648+(j<<2)>>2]&4095](b,m);return}}if((l&32768|0)==0){m=9104156+((l>>>12&7)<<2)|0;b=c[m>>2]&-256;j=c[2276085]&f;e=j&16777215;g=c[2112932]|0;i=c[g+(e>>>10<<2)>>2]|0;if(i>>>0>9){n=a[i+(j&1023^1)|0]|0}else{n=gj[c[g+196608+(i<<2)>>2]&4095](e)|0}c[m>>2]=n&255|b;if((c[2276038]&24|0)==0){return}c[2276108]=(c[2276108]|0)-2;return}else{b=c[2276085]&f;f=b&16777215;n=c[2112932]|0;m=c[n+(f>>>10<<2)>>2]|0;if(m>>>0>9){o=a[m+(b&1023^1)|0]|0}else{o=gj[c[n+196608+(m<<2)>>2]&4095](f)|0}c[9104156+((l>>>12&7|8)<<2)>>2]=o<<24>>24;if((c[2276038]&24|0)==0){return}c[2276108]=(c[2276108]|0)-2;return}}function vX(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;if((c[2276038]&28|0)==0){ni();return}if((c[2276072]|0)==0){ol();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0);f=p&-4;if((f|0)==(h|0)){q=p;r=g}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;h=c[2112932]|0;o=c[h+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=p}else{p=gj[c[h+196768+(o<<2)>>2]&4095](f)|0;s=p;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;s=r>>>((q<<3&16^16)>>>0)<<16>>16;if((n&2048|0)!=0){q=c[2276085]&s;r=c[9104156+((n>>>12&15)<<2)>>2]&255;t=q&16777215;p=c[2112932]|0;f=c[p+((t>>>10|16384)<<2)>>2]|0;if(f>>>0>9){a[f+(q&1023^1)|0]=r;return}else{gg[c[p+196648+(f<<2)>>2]&4095](t,r);return}}if((n&32768|0)==0){r=9104156+((n>>>12&7)<<2)|0;t=c[r>>2]&-256;f=c[2276085]&s;p=f&16777215;q=c[2112932]|0;o=c[q+(p>>>10<<2)>>2]|0;if(o>>>0>9){u=a[o+(f&1023^1)|0]|0}else{u=gj[c[q+196608+(o<<2)>>2]&4095](p)|0}c[r>>2]=u&255|t;if((c[2276038]&24|0)==0){return}c[2276108]=(c[2276108]|0)-2;return}else{t=c[2276085]&s;s=t&16777215;u=c[2112932]|0;r=c[u+(s>>>10<<2)>>2]|0;if(r>>>0>9){v=a[r+(t&1023^1)|0]|0}else{v=gj[c[u+196608+(r<<2)>>2]&4095](s)|0}c[9104156+((n>>>12&7|8)<<2)>>2]=v<<24>>24;if((c[2276038]&24|0)==0){return}c[2276108]=(c[2276108]|0)-2;return}}function vY(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;if((c[2276038]&28|0)==0){ni();return}if((c[2276072]|0)==0){ol();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0);f=p&-4;if((f|0)==(h|0)){q=p;r=h;s=g}else{c[2276083]=f;g=c[2276085]&f;h=g&16777212;o=c[2112932]|0;e=c[o+((h>>>10|32768)<<2)>>2]|0;if(e>>>0>9){j=g&1020;t=(d[e+(j|3)|0]|0)<<8|(d[e+(j|2)|0]|0)|((d[e+(j|1)|0]|0)<<8|(d[e+j|0]|0))<<16;u=p;v=f}else{f=gj[c[o+196768+(e<<2)>>2]&4095](h)|0;t=f;u=c[2276056]|0;v=c[2276083]|0}c[2276084]=t;q=u;r=v;s=t}t=q+2|0;c[2276056]=t;q=t&-4;if((q|0)==(r|0)){w=s;x=t}else{c[2276083]=q;r=c[2276085]&q;q=r&16777212;v=c[2112932]|0;u=c[v+((q>>>10|32768)<<2)>>2]|0;if(u>>>0>9){f=r&1020;y=(d[u+(f|3)|0]|0)<<8|(d[u+(f|2)|0]|0)|((d[u+(f|1)|0]|0)<<8|(d[u+f|0]|0))<<16;z=t}else{t=gj[c[v+196768+(u<<2)>>2]&4095](q)|0;y=t;z=c[2276056]|0}c[2276084]=y;w=y>>>16|s<<16;x=z}c[2276056]=x+2;if((n&2048|0)!=0){x=c[2276085]&w;z=c[9104156+((n>>>12&15)<<2)>>2]&255;s=x&16777215;y=c[2112932]|0;t=c[y+((s>>>10|16384)<<2)>>2]|0;if(t>>>0>9){a[t+(x&1023^1)|0]=z;return}else{gg[c[y+196648+(t<<2)>>2]&4095](s,z);return}}if((n&32768|0)==0){z=9104156+((n>>>12&7)<<2)|0;s=c[z>>2]&-256;t=c[2276085]&w;y=t&16777215;x=c[2112932]|0;q=c[x+(y>>>10<<2)>>2]|0;if(q>>>0>9){A=a[q+(t&1023^1)|0]|0}else{A=gj[c[x+196608+(q<<2)>>2]&4095](y)|0}c[z>>2]=A&255|s;if((c[2276038]&24|0)==0){return}c[2276108]=(c[2276108]|0)-2;return}else{s=c[2276085]&w;w=s&16777215;A=c[2112932]|0;z=c[A+(w>>>10<<2)>>2]|0;if(z>>>0>9){B=a[z+(s&1023^1)|0]|0}else{B=gj[c[A+196608+(z<<2)>>2]&4095](w)|0}c[9104156+((n>>>12&7|8)<<2)>>2]=B<<24>>24;if((c[2276038]&24|0)==0){return}c[2276108]=(c[2276108]|0)-2;return}}function vZ(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((c[2276038]&28|0)==0){ni();return}if((c[2276072]|0)==0){ol();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0);f=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;if((l&2048|0)!=0){g=c[9104156+((l>>>12&15)<<2)>>2]|0;m=c[2276085]&f;b=g&65535;e=m&16777215;j=c[2112932]|0;i=c[j+((e>>>10|16384)<<2)>>2]|0;if(i>>>0>9){k=m&1023;a[i+k|0]=g&255;a[i+(k+1)|0]=(b&65535)>>>8&255;return}else{gg[c[j+196728+(i<<2)>>2]&4095](e,b);return}}if((l&32768|0)==0){b=9104156+((l>>>12&7)<<2)|0;e=c[b>>2]&-65536;i=c[2276085]&f;j=i&16777215;k=c[2112932]|0;g=c[k+(j>>>10<<2)>>2]|0;if(g>>>0>9){m=i&1023;n=(d[g+(m+1)|0]|0)<<8|(d[g+m|0]|0)}else{n=gj[c[k+196688+(g<<2)>>2]&4095](j)|0}c[b>>2]=n&65535|e;if((c[2276038]&24|0)==0){return}c[2276108]=(c[2276108]|0)-2;return}else{e=c[2276085]&f;f=e&16777215;n=c[2112932]|0;b=c[n+(f>>>10<<2)>>2]|0;if(b>>>0>9){j=e&1023;o=(d[b+(j+1)|0]|0)<<8|(d[b+j|0]|0)}else{o=gj[c[n+196688+(b<<2)>>2]&4095](f)|0}c[9104156+((l>>>12&7|8)<<2)>>2]=o<<16>>16;if((c[2276038]&24|0)==0){return}c[2276108]=(c[2276108]|0)-2;return}}function v_(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((c[2276038]&28|0)==0){ni();return}if((c[2276072]|0)==0){ol();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0);f=9104156+((c[2276069]&7|8)<<2)|0;g=c[f>>2]|0;c[f>>2]=g+2;if((l&2048|0)!=0){f=c[9104156+((l>>>12&15)<<2)>>2]|0;m=c[2276085]&g;b=f&65535;e=m&16777215;j=c[2112932]|0;i=c[j+((e>>>10|16384)<<2)>>2]|0;if(i>>>0>9){k=m&1023;a[i+k|0]=f&255;a[i+(k+1)|0]=(b&65535)>>>8&255;return}else{gg[c[j+196728+(i<<2)>>2]&4095](e,b);return}}if((l&32768|0)==0){b=9104156+((l>>>12&7)<<2)|0;e=c[b>>2]&-65536;i=c[2276085]&g;j=i&16777215;k=c[2112932]|0;f=c[k+(j>>>10<<2)>>2]|0;if(f>>>0>9){m=i&1023;n=(d[f+(m+1)|0]|0)<<8|(d[f+m|0]|0)}else{n=gj[c[k+196688+(f<<2)>>2]&4095](j)|0}c[b>>2]=n&65535|e;if((c[2276038]&24|0)==0){return}c[2276108]=(c[2276108]|0)-2;return}else{e=c[2276085]&g;g=e&16777215;n=c[2112932]|0;b=c[n+(g>>>10<<2)>>2]|0;if(b>>>0>9){j=e&1023;o=(d[b+(j+1)|0]|0)<<8|(d[b+j|0]|0)}else{o=gj[c[n+196688+(b<<2)>>2]&4095](g)|0}c[9104156+((l>>>12&7|8)<<2)>>2]=o<<16>>16;if((c[2276038]&24|0)==0){return}c[2276108]=(c[2276108]|0)-2;return}}function v$(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((c[2276038]&28|0)==0){ni();return}if((c[2276072]|0)==0){ol();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0);f=9104156+((c[2276069]&7|8)<<2)|0;g=(c[f>>2]|0)-2|0;c[f>>2]=g;if((l&2048|0)!=0){f=c[9104156+((l>>>12&15)<<2)>>2]|0;m=c[2276085]&g;b=f&65535;e=m&16777215;j=c[2112932]|0;i=c[j+((e>>>10|16384)<<2)>>2]|0;if(i>>>0>9){k=m&1023;a[i+k|0]=f&255;a[i+(k+1)|0]=(b&65535)>>>8&255;return}else{gg[c[j+196728+(i<<2)>>2]&4095](e,b);return}}if((l&32768|0)==0){b=9104156+((l>>>12&7)<<2)|0;e=c[b>>2]&-65536;i=c[2276085]&g;j=i&16777215;k=c[2112932]|0;f=c[k+(j>>>10<<2)>>2]|0;if(f>>>0>9){m=i&1023;n=(d[f+(m+1)|0]|0)<<8|(d[f+m|0]|0)}else{n=gj[c[k+196688+(f<<2)>>2]&4095](j)|0}c[b>>2]=n&65535|e;if((c[2276038]&24|0)==0){return}c[2276108]=(c[2276108]|0)-2;return}else{e=c[2276085]&g;g=e&16777215;n=c[2112932]|0;b=c[n+(g>>>10<<2)>>2]|0;if(b>>>0>9){j=e&1023;o=(d[b+(j+1)|0]|0)<<8|(d[b+j|0]|0)}else{o=gj[c[n+196688+(b<<2)>>2]&4095](g)|0}c[9104156+((l>>>12&7|8)<<2)>>2]=o<<16>>16;if((c[2276038]&24|0)==0){return}c[2276108]=(c[2276108]|0)-2;return}}function v0(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;if((c[2276038]&28|0)==0){ni();return}if((c[2276072]|0)==0){ol();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0);f=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;o=p&-4;if((o|0)==(h|0)){q=p;r=g}else{c[2276083]=o;g=c[2276085]&o;o=g&16777212;h=c[2112932]|0;e=c[h+((o>>>10|32768)<<2)>>2]|0;if(e>>>0>9){j=g&1020;s=(d[e+(j|3)|0]|0)<<8|(d[e+(j|2)|0]|0)|((d[e+(j|1)|0]|0)<<8|(d[e+j|0]|0))<<16;t=p}else{p=gj[c[h+196768+(e<<2)>>2]&4095](o)|0;s=p;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;s=(r>>>((q<<3&16^16)>>>0)<<16>>16)+f|0;if((n&2048|0)!=0){f=c[9104156+((n>>>12&15)<<2)>>2]|0;q=c[2276085]&s;r=f&65535;t=q&16777215;p=c[2112932]|0;o=c[p+((t>>>10|16384)<<2)>>2]|0;if(o>>>0>9){e=q&1023;a[o+e|0]=f&255;a[o+(e+1)|0]=(r&65535)>>>8&255;return}else{gg[c[p+196728+(o<<2)>>2]&4095](t,r);return}}if((n&32768|0)==0){r=9104156+((n>>>12&7)<<2)|0;t=c[r>>2]&-65536;o=c[2276085]&s;p=o&16777215;e=c[2112932]|0;f=c[e+(p>>>10<<2)>>2]|0;if(f>>>0>9){q=o&1023;u=(d[f+(q+1)|0]|0)<<8|(d[f+q|0]|0)}else{u=gj[c[e+196688+(f<<2)>>2]&4095](p)|0}c[r>>2]=u&65535|t;if((c[2276038]&24|0)==0){return}c[2276108]=(c[2276108]|0)-2;return}else{t=c[2276085]&s;s=t&16777215;u=c[2112932]|0;r=c[u+(s>>>10<<2)>>2]|0;if(r>>>0>9){p=t&1023;v=(d[r+(p+1)|0]|0)<<8|(d[r+p|0]|0)}else{v=gj[c[u+196688+(r<<2)>>2]&4095](s)|0}c[9104156+((n>>>12&7|8)<<2)>>2]=v<<16>>16;if((c[2276038]&24|0)==0){return}c[2276108]=(c[2276108]|0)-2;return}}function v1(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((c[2276038]&28|0)==0){ni();return}if((c[2276072]|0)==0){ol();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0);f=nB(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;if((l&2048|0)!=0){g=c[9104156+((l>>>12&15)<<2)>>2]|0;m=c[2276085]&f;b=g&65535;e=m&16777215;j=c[2112932]|0;i=c[j+((e>>>10|16384)<<2)>>2]|0;if(i>>>0>9){k=m&1023;a[i+k|0]=g&255;a[i+(k+1)|0]=(b&65535)>>>8&255;return}else{gg[c[j+196728+(i<<2)>>2]&4095](e,b);return}}if((l&32768|0)==0){b=9104156+((l>>>12&7)<<2)|0;e=c[b>>2]&-65536;i=c[2276085]&f;j=i&16777215;k=c[2112932]|0;g=c[k+(j>>>10<<2)>>2]|0;if(g>>>0>9){m=i&1023;n=(d[g+(m+1)|0]|0)<<8|(d[g+m|0]|0)}else{n=gj[c[k+196688+(g<<2)>>2]&4095](j)|0}c[b>>2]=n&65535|e;if((c[2276038]&24|0)==0){return}c[2276108]=(c[2276108]|0)-2;return}else{e=c[2276085]&f;f=e&16777215;n=c[2112932]|0;b=c[n+(f>>>10<<2)>>2]|0;if(b>>>0>9){j=e&1023;o=(d[b+(j+1)|0]|0)<<8|(d[b+j|0]|0)}else{o=gj[c[n+196688+(b<<2)>>2]&4095](f)|0}c[9104156+((l>>>12&7|8)<<2)>>2]=o<<16>>16;if((c[2276038]&24|0)==0){return}c[2276108]=(c[2276108]|0)-2;return}}function v2(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;if((c[2276038]&28|0)==0){ni();return}if((c[2276072]|0)==0){ol();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0);f=p&-4;if((f|0)==(h|0)){q=p;r=g}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;h=c[2112932]|0;o=c[h+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=p}else{p=gj[c[h+196768+(o<<2)>>2]&4095](f)|0;s=p;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;s=r>>>((q<<3&16^16)>>>0)<<16>>16;if((n&2048|0)!=0){q=c[9104156+((n>>>12&15)<<2)>>2]|0;r=c[2276085]&s;t=q&65535;p=r&16777215;f=c[2112932]|0;o=c[f+((p>>>10|16384)<<2)>>2]|0;if(o>>>0>9){h=r&1023;a[o+h|0]=q&255;a[o+(h+1)|0]=(t&65535)>>>8&255;return}else{gg[c[f+196728+(o<<2)>>2]&4095](p,t);return}}if((n&32768|0)==0){t=9104156+((n>>>12&7)<<2)|0;p=c[t>>2]&-65536;o=c[2276085]&s;f=o&16777215;h=c[2112932]|0;q=c[h+(f>>>10<<2)>>2]|0;if(q>>>0>9){r=o&1023;u=(d[q+(r+1)|0]|0)<<8|(d[q+r|0]|0)}else{u=gj[c[h+196688+(q<<2)>>2]&4095](f)|0}c[t>>2]=u&65535|p;if((c[2276038]&24|0)==0){return}c[2276108]=(c[2276108]|0)-2;return}else{p=c[2276085]&s;s=p&16777215;u=c[2112932]|0;t=c[u+(s>>>10<<2)>>2]|0;if(t>>>0>9){f=p&1023;v=(d[t+(f+1)|0]|0)<<8|(d[t+f|0]|0)}else{v=gj[c[u+196688+(t<<2)>>2]&4095](s)|0}c[9104156+((n>>>12&7|8)<<2)>>2]=v<<16>>16;if((c[2276038]&24|0)==0){return}c[2276108]=(c[2276108]|0)-2;return}}function v3(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;if((c[2276038]&28|0)==0){ni();return}if((c[2276072]|0)==0){ol();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0);f=p&-4;if((f|0)==(h|0)){q=p;r=h;s=g}else{c[2276083]=f;g=c[2276085]&f;h=g&16777212;o=c[2112932]|0;e=c[o+((h>>>10|32768)<<2)>>2]|0;if(e>>>0>9){j=g&1020;t=(d[e+(j|3)|0]|0)<<8|(d[e+(j|2)|0]|0)|((d[e+(j|1)|0]|0)<<8|(d[e+j|0]|0))<<16;u=p;v=f}else{f=gj[c[o+196768+(e<<2)>>2]&4095](h)|0;t=f;u=c[2276056]|0;v=c[2276083]|0}c[2276084]=t;q=u;r=v;s=t}t=q+2|0;c[2276056]=t;q=t&-4;if((q|0)==(r|0)){w=s;x=t}else{c[2276083]=q;r=c[2276085]&q;q=r&16777212;v=c[2112932]|0;u=c[v+((q>>>10|32768)<<2)>>2]|0;if(u>>>0>9){f=r&1020;y=(d[u+(f|3)|0]|0)<<8|(d[u+(f|2)|0]|0)|((d[u+(f|1)|0]|0)<<8|(d[u+f|0]|0))<<16;z=t}else{t=gj[c[v+196768+(u<<2)>>2]&4095](q)|0;y=t;z=c[2276056]|0}c[2276084]=y;w=y>>>16|s<<16;x=z}c[2276056]=x+2;if((n&2048|0)!=0){x=c[9104156+((n>>>12&15)<<2)>>2]|0;z=c[2276085]&w;s=x&65535;y=z&16777215;t=c[2112932]|0;q=c[t+((y>>>10|16384)<<2)>>2]|0;if(q>>>0>9){u=z&1023;a[q+u|0]=x&255;a[q+(u+1)|0]=(s&65535)>>>8&255;return}else{gg[c[t+196728+(q<<2)>>2]&4095](y,s);return}}if((n&32768|0)==0){s=9104156+((n>>>12&7)<<2)|0;y=c[s>>2]&-65536;q=c[2276085]&w;t=q&16777215;u=c[2112932]|0;x=c[u+(t>>>10<<2)>>2]|0;if(x>>>0>9){z=q&1023;A=(d[x+(z+1)|0]|0)<<8|(d[x+z|0]|0)}else{A=gj[c[u+196688+(x<<2)>>2]&4095](t)|0}c[s>>2]=A&65535|y;if((c[2276038]&24|0)==0){return}c[2276108]=(c[2276108]|0)-2;return}else{y=c[2276085]&w;w=y&16777215;A=c[2112932]|0;s=c[A+(w>>>10<<2)>>2]|0;if(s>>>0>9){t=y&1023;B=(d[s+(t+1)|0]|0)<<8|(d[s+t|0]|0)}else{B=gj[c[A+196688+(s<<2)>>2]&4095](w)|0}c[9104156+((n>>>12&7|8)<<2)>>2]=B<<16>>16;if((c[2276038]&24|0)==0){return}c[2276108]=(c[2276108]|0)-2;return}}function v4(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[2276038]&28|0)==0){ni();return}if((c[2276072]|0)==0){ol();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0);f=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;if((l&2048|0)==0){g=c[2276085]&f;m=g&16777215;b=c[2112932]|0;e=c[b+(m>>>10<<2)>>2]|0;if(e>>>0>9){j=g&1023;n=(d[e+(j+3)|0]|0)<<8|(d[e+(j+2)|0]|0)|((d[e+(j+1)|0]|0)<<8|(d[e+j|0]|0))<<16}else{n=gj[c[b+196768+(e<<2)>>2]&4095](m)|0}c[9104156+((l>>>12&15)<<2)>>2]=n;if((c[2276038]&24|0)==0){return}c[2276108]=(c[2276108]|0)-2;return}else{n=c[9104156+((l>>>12&15)<<2)>>2]|0;l=c[2276085]&f;f=l&16777215;m=c[2112932]|0;e=c[m+((f>>>10|16384)<<2)>>2]|0;if(e>>>0>9){b=l&1023;a[e+b|0]=n>>>16&255;a[e+(b+1)|0]=n>>>24&255;a[e+(b+2)|0]=n&255;a[e+(b+3)|0]=n>>>8&255}else{gg[c[m+196808+(e<<2)>>2]&4095](f,n)}if((c[2276038]&24|0)==0){return}c[2276108]=(c[2276108]|0)-2;return}}function v5(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[2276038]&28|0)==0){ni();return}if((c[2276072]|0)==0){ol();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0);f=9104156+((c[2276069]&7|8)<<2)|0;g=c[f>>2]|0;c[f>>2]=g+4;if((l&2048|0)==0){f=c[2276085]&g;m=f&16777215;b=c[2112932]|0;e=c[b+(m>>>10<<2)>>2]|0;if(e>>>0>9){j=f&1023;n=(d[e+(j+3)|0]|0)<<8|(d[e+(j+2)|0]|0)|((d[e+(j+1)|0]|0)<<8|(d[e+j|0]|0))<<16}else{n=gj[c[b+196768+(e<<2)>>2]&4095](m)|0}c[9104156+((l>>>12&15)<<2)>>2]=n;if((c[2276038]&24|0)==0){return}c[2276108]=(c[2276108]|0)-2;return}else{n=c[9104156+((l>>>12&15)<<2)>>2]|0;l=c[2276085]&g;g=l&16777215;m=c[2112932]|0;e=c[m+((g>>>10|16384)<<2)>>2]|0;if(e>>>0>9){b=l&1023;a[e+b|0]=n>>>16&255;a[e+(b+1)|0]=n>>>24&255;a[e+(b+2)|0]=n&255;a[e+(b+3)|0]=n>>>8&255}else{gg[c[m+196808+(e<<2)>>2]&4095](g,n)}if((c[2276038]&24|0)==0){return}c[2276108]=(c[2276108]|0)-2;return}}function v6(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[2276038]&28|0)==0){ni();return}if((c[2276072]|0)==0){ol();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0);f=9104156+((c[2276069]&7|8)<<2)|0;g=(c[f>>2]|0)-4|0;c[f>>2]=g;if((l&2048|0)==0){f=c[2276085]&g;m=f&16777215;b=c[2112932]|0;e=c[b+(m>>>10<<2)>>2]|0;if(e>>>0>9){j=f&1023;n=(d[e+(j+3)|0]|0)<<8|(d[e+(j+2)|0]|0)|((d[e+(j+1)|0]|0)<<8|(d[e+j|0]|0))<<16}else{n=gj[c[b+196768+(e<<2)>>2]&4095](m)|0}c[9104156+((l>>>12&15)<<2)>>2]=n;if((c[2276038]&24|0)==0){return}c[2276108]=(c[2276108]|0)-2;return}else{n=c[9104156+((l>>>12&15)<<2)>>2]|0;l=c[2276085]&g;g=l&16777215;m=c[2112932]|0;e=c[m+((g>>>10|16384)<<2)>>2]|0;if(e>>>0>9){b=l&1023;a[e+b|0]=n>>>16&255;a[e+(b+1)|0]=n>>>24&255;a[e+(b+2)|0]=n&255;a[e+(b+3)|0]=n>>>8&255}else{gg[c[m+196808+(e<<2)>>2]&4095](g,n)}if((c[2276038]&24|0)==0){return}c[2276108]=(c[2276108]|0)-2;return}}function v7(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;if((c[2276038]&28|0)==0){ni();return}if((c[2276072]|0)==0){ol();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0);f=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;o=p&-4;if((o|0)==(h|0)){q=p;r=g}else{c[2276083]=o;g=c[2276085]&o;o=g&16777212;h=c[2112932]|0;e=c[h+((o>>>10|32768)<<2)>>2]|0;if(e>>>0>9){j=g&1020;s=(d[e+(j|3)|0]|0)<<8|(d[e+(j|2)|0]|0)|((d[e+(j|1)|0]|0)<<8|(d[e+j|0]|0))<<16;t=p}else{p=gj[c[h+196768+(e<<2)>>2]&4095](o)|0;s=p;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;s=(r>>>((q<<3&16^16)>>>0)<<16>>16)+f|0;if((n&2048|0)==0){f=c[2276085]&s;q=f&16777215;r=c[2112932]|0;t=c[r+(q>>>10<<2)>>2]|0;if(t>>>0>9){p=f&1023;u=(d[t+(p+3)|0]|0)<<8|(d[t+(p+2)|0]|0)|((d[t+(p+1)|0]|0)<<8|(d[t+p|0]|0))<<16}else{u=gj[c[r+196768+(t<<2)>>2]&4095](q)|0}c[9104156+((n>>>12&15)<<2)>>2]=u;if((c[2276038]&24|0)==0){return}c[2276108]=(c[2276108]|0)-2;return}else{u=c[9104156+((n>>>12&15)<<2)>>2]|0;n=c[2276085]&s;s=n&16777215;q=c[2112932]|0;t=c[q+((s>>>10|16384)<<2)>>2]|0;if(t>>>0>9){r=n&1023;a[t+r|0]=u>>>16&255;a[t+(r+1)|0]=u>>>24&255;a[t+(r+2)|0]=u&255;a[t+(r+3)|0]=u>>>8&255}else{gg[c[q+196808+(t<<2)>>2]&4095](s,u)}if((c[2276038]&24|0)==0){return}c[2276108]=(c[2276108]|0)-2;return}}function v8(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[2276038]&28|0)==0){ni();return}if((c[2276072]|0)==0){ol();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0);f=nB(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;if((l&2048|0)==0){g=c[2276085]&f;m=g&16777215;b=c[2112932]|0;e=c[b+(m>>>10<<2)>>2]|0;if(e>>>0>9){j=g&1023;n=(d[e+(j+3)|0]|0)<<8|(d[e+(j+2)|0]|0)|((d[e+(j+1)|0]|0)<<8|(d[e+j|0]|0))<<16}else{n=gj[c[b+196768+(e<<2)>>2]&4095](m)|0}c[9104156+((l>>>12&15)<<2)>>2]=n;if((c[2276038]&24|0)==0){return}c[2276108]=(c[2276108]|0)-2;return}else{n=c[9104156+((l>>>12&15)<<2)>>2]|0;l=c[2276085]&f;f=l&16777215;m=c[2112932]|0;e=c[m+((f>>>10|16384)<<2)>>2]|0;if(e>>>0>9){b=l&1023;a[e+b|0]=n>>>16&255;a[e+(b+1)|0]=n>>>24&255;a[e+(b+2)|0]=n&255;a[e+(b+3)|0]=n>>>8&255}else{gg[c[m+196808+(e<<2)>>2]&4095](f,n)}if((c[2276038]&24|0)==0){return}c[2276108]=(c[2276108]|0)-2;return}}function v9(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;if((c[2276038]&28|0)==0){ni();return}if((c[2276072]|0)==0){ol();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0);f=p&-4;if((f|0)==(h|0)){q=p;r=g}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;h=c[2112932]|0;o=c[h+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=p}else{p=gj[c[h+196768+(o<<2)>>2]&4095](f)|0;s=p;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;s=r>>>((q<<3&16^16)>>>0)<<16>>16;if((n&2048|0)==0){q=c[2276085]&s;r=q&16777215;t=c[2112932]|0;p=c[t+(r>>>10<<2)>>2]|0;if(p>>>0>9){f=q&1023;u=(d[p+(f+3)|0]|0)<<8|(d[p+(f+2)|0]|0)|((d[p+(f+1)|0]|0)<<8|(d[p+f|0]|0))<<16}else{u=gj[c[t+196768+(p<<2)>>2]&4095](r)|0}c[9104156+((n>>>12&15)<<2)>>2]=u;if((c[2276038]&24|0)==0){return}c[2276108]=(c[2276108]|0)-2;return}else{u=c[9104156+((n>>>12&15)<<2)>>2]|0;n=c[2276085]&s;s=n&16777215;r=c[2112932]|0;p=c[r+((s>>>10|16384)<<2)>>2]|0;if(p>>>0>9){t=n&1023;a[p+t|0]=u>>>16&255;a[p+(t+1)|0]=u>>>24&255;a[p+(t+2)|0]=u&255;a[p+(t+3)|0]=u>>>8&255}else{gg[c[r+196808+(p<<2)>>2]&4095](s,u)}if((c[2276038]&24|0)==0){return}c[2276108]=(c[2276108]|0)-2;return}}function wa(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;if((c[2276038]&28|0)==0){ni();return}if((c[2276072]|0)==0){ol();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0);f=p&-4;if((f|0)==(h|0)){q=p;r=h;s=g}else{c[2276083]=f;g=c[2276085]&f;h=g&16777212;o=c[2112932]|0;e=c[o+((h>>>10|32768)<<2)>>2]|0;if(e>>>0>9){j=g&1020;t=(d[e+(j|3)|0]|0)<<8|(d[e+(j|2)|0]|0)|((d[e+(j|1)|0]|0)<<8|(d[e+j|0]|0))<<16;u=p;v=f}else{f=gj[c[o+196768+(e<<2)>>2]&4095](h)|0;t=f;u=c[2276056]|0;v=c[2276083]|0}c[2276084]=t;q=u;r=v;s=t}t=q+2|0;c[2276056]=t;q=t&-4;if((q|0)==(r|0)){w=s;x=t}else{c[2276083]=q;r=c[2276085]&q;q=r&16777212;v=c[2112932]|0;u=c[v+((q>>>10|32768)<<2)>>2]|0;if(u>>>0>9){f=r&1020;y=(d[u+(f|3)|0]|0)<<8|(d[u+(f|2)|0]|0)|((d[u+(f|1)|0]|0)<<8|(d[u+f|0]|0))<<16;z=t}else{t=gj[c[v+196768+(u<<2)>>2]&4095](q)|0;y=t;z=c[2276056]|0}c[2276084]=y;w=y>>>16|s<<16;x=z}c[2276056]=x+2;if((n&2048|0)==0){x=c[2276085]&w;z=x&16777215;s=c[2112932]|0;y=c[s+(z>>>10<<2)>>2]|0;if(y>>>0>9){t=x&1023;A=(d[y+(t+3)|0]|0)<<8|(d[y+(t+2)|0]|0)|((d[y+(t+1)|0]|0)<<8|(d[y+t|0]|0))<<16}else{A=gj[c[s+196768+(y<<2)>>2]&4095](z)|0}c[9104156+((n>>>12&15)<<2)>>2]=A;if((c[2276038]&24|0)==0){return}c[2276108]=(c[2276108]|0)-2;return}else{A=c[9104156+((n>>>12&15)<<2)>>2]|0;n=c[2276085]&w;w=n&16777215;z=c[2112932]|0;y=c[z+((w>>>10|16384)<<2)>>2]|0;if(y>>>0>9){s=n&1023;a[y+s|0]=A>>>16&255;a[y+(s+1)|0]=A>>>24&255;a[y+(s+2)|0]=A&255;a[y+(s+3)|0]=A>>>8&255}else{gg[c[z+196808+(y<<2)>>2]&4095](w,A)}if((c[2276038]&24|0)==0){return}c[2276108]=(c[2276108]|0)-2;return}}function wb(){var a=0,b=0;a=c[2276069]|0;b=a<<24>>24;c[9104156+((a>>>9&7)<<2)>>2]=b;c[2276075]=b>>>24;c[2276076]=b;c[2276077]=0;c[2276078]=0;return}function wc(){var a=0,b=0,d=0;a=c[2276069]|0;b=9104156+((a>>>9&7)<<2)|0;d=ag(c[b>>2]<<16>>16,c[9104156+((a&7)<<2)>>2]<<16>>16)|0;c[b>>2]=d;c[2276076]=d;c[2276075]=d>>>24;c[2276077]=0;c[2276078]=0;return}function wd(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0;a=c[2276069]|0;b=9104156+((a>>>9&7)<<2)|0;e=c[2276085]&c[9104156+((a&7|8)<<2)>>2];a=e&16777215;f=c[2112932]|0;g=c[f+(a>>>10<<2)>>2]|0;if(g>>>0>9){h=e&1023;i=(d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0)}else{i=gj[c[f+196688+(g<<2)>>2]&4095](a)|0}a=ag(c[b>>2]<<16>>16,i<<16>>16)|0;c[b>>2]=a;c[2276076]=a;c[2276075]=a>>>24;c[2276077]=0;c[2276078]=0;return}function we(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0;a=c[2276069]|0;b=9104156+((a>>>9&7)<<2)|0;e=9104156+((a&7|8)<<2)|0;a=c[e>>2]|0;c[e>>2]=a+2;e=c[2276085]&a;a=e&16777215;f=c[2112932]|0;g=c[f+(a>>>10<<2)>>2]|0;if(g>>>0>9){h=e&1023;i=(d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0)}else{i=gj[c[f+196688+(g<<2)>>2]&4095](a)|0}a=ag(c[b>>2]<<16>>16,i<<16>>16)|0;c[b>>2]=a;c[2276076]=a;c[2276075]=a>>>24;c[2276077]=0;c[2276078]=0;return}function wf(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0;a=c[2276069]|0;b=9104156+((a>>>9&7)<<2)|0;e=9104156+((a&7|8)<<2)|0;a=(c[e>>2]|0)-2|0;c[e>>2]=a;e=c[2276085]&a;a=e&16777215;f=c[2112932]|0;g=c[f+(a>>>10<<2)>>2]|0;if(g>>>0>9){h=e&1023;i=(d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0)}else{i=gj[c[f+196688+(g<<2)>>2]&4095](a)|0}a=ag(c[b>>2]<<16>>16,i<<16>>16)|0;c[b>>2]=a;c[2276076]=a;c[2276075]=a>>>24;c[2276077]=0;c[2276078]=0;return}function wg(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;a=c[2276069]|0;b=9104156+((a>>>9&7)<<2)|0;e=c[9104156+((a&7|8)<<2)>>2]|0;a=c[2276056]|0;f=a&-4;if((f|0)==(c[2276083]|0)){g=a;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a}else{a=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=a;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=(h>>>((g<<3&16^16)>>>0)<<16>>16)+e&c[2276085];e=m&16777215;g=c[2112932]|0;h=c[g+(e>>>10<<2)>>2]|0;if(h>>>0>9){n=m&1023;o=(d[h+(n+1)|0]|0)<<8|(d[h+n|0]|0);p=o<<16>>16;q=c[b>>2]|0;r=q<<16;s=r>>16;t=ag(s,p)|0;c[b>>2]=t;c[2276076]=t;u=t>>>24;c[2276075]=u;c[2276077]=0;c[2276078]=0;return}else{o=gj[c[g+196688+(h<<2)>>2]&4095](e)|0;p=o<<16>>16;q=c[b>>2]|0;r=q<<16;s=r>>16;t=ag(s,p)|0;c[b>>2]=t;c[2276076]=t;u=t>>>24;c[2276075]=u;c[2276077]=0;c[2276078]=0;return}}function wh(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0;a=c[2276069]|0;b=9104156+((a>>>9&7)<<2)|0;e=nB(c[9104156+((a&7|8)<<2)>>2]|0)|0;a=c[2276085]&e;e=a&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=a&1023;i=(d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0)}else{i=gj[c[f+196688+(g<<2)>>2]&4095](e)|0}e=ag(c[b>>2]<<16>>16,i<<16>>16)|0;c[b>>2]=e;c[2276076]=e;c[2276075]=e>>>24;c[2276077]=0;c[2276078]=0;return}function wi(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;a=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)<<16>>16&c[2276085];f=l&16777215;g=c[2112932]|0;m=c[g+(f>>>10<<2)>>2]|0;if(m>>>0>9){b=l&1023;n=(d[m+(b+1)|0]|0)<<8|(d[m+b|0]|0);o=n<<16>>16;p=c[a>>2]|0;q=p<<16;r=q>>16;s=ag(r,o)|0;c[a>>2]=s;c[2276076]=s;t=s>>>24;c[2276075]=t;c[2276077]=0;c[2276078]=0;return}else{n=gj[c[g+196688+(m<<2)>>2]&4095](f)|0;o=n<<16>>16;p=c[a>>2]|0;q=p<<16;r=q>>16;s=ag(r,o)|0;c[a>>2]=s;c[2276076]=s;t=s>>>24;c[2276075]=t;c[2276077]=0;c[2276078]=0;return}}function wj(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;a=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[2276085]&q;q=r&16777215;t=c[2112932]|0;h=c[t+(q>>>10<<2)>>2]|0;if(h>>>0>9){s=r&1023;u=(d[h+(s+1)|0]|0)<<8|(d[h+s|0]|0);v=u<<16>>16;w=c[a>>2]|0;x=w<<16;y=x>>16;z=ag(y,v)|0;c[a>>2]=z;c[2276076]=z;A=z>>>24;c[2276075]=A;c[2276077]=0;c[2276078]=0;return}else{u=gj[c[t+196688+(h<<2)>>2]&4095](q)|0;v=u<<16>>16;w=c[a>>2]|0;x=w<<16;y=x>>16;z=ag(y,v)|0;c[a>>2]=z;c[2276076]=z;A=z>>>24;c[2276075]=A;c[2276077]=0;c[2276078]=0;return}}function wk(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;a=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{k=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=k;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=(g>>>((f<<3&16^16)>>>0)<<16>>16)+b|0;b=l&16777215;f=c[2112932]|0;g=c[f+((b>>>10|32768)<<2)>>2]|0;if(g>>>0>9){m=l&1023;n=(d[g+(m+1)|0]|0)<<8|(d[g+m|0]|0);o=n<<16>>16;p=c[a>>2]|0;q=p<<16;r=q>>16;s=ag(r,o)|0;c[a>>2]=s;c[2276076]=s;t=s>>>24;c[2276075]=t;c[2276077]=0;c[2276078]=0;return}else{n=gj[c[f+196688+(g<<2)>>2]&4095](b)|0;o=n<<16>>16;p=c[a>>2]|0;q=p<<16;r=q>>16;s=ag(r,o)|0;c[a>>2]=s;c[2276076]=s;t=s>>>24;c[2276075]=t;c[2276077]=0;c[2276078]=0;return}}function wl(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0;a=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;b=nB(c[2276056]|0)|0;e=b&16777215;f=c[2112932]|0;g=c[f+((e>>>10|32768)<<2)>>2]|0;if(g>>>0>9){h=b&1023;i=(d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0)}else{i=gj[c[f+196688+(g<<2)>>2]&4095](e)|0}e=ag(c[a>>2]<<16>>16,i<<16>>16)|0;c[a>>2]=e;c[2276076]=e;c[2276075]=e>>>24;c[2276077]=0;c[2276078]=0;return}function wm(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=ag(g>>>((f<<3&16^16)>>>0)<<16>>16,c[a>>2]<<16>>16)|0;c[a>>2]=l;c[2276076]=l;c[2276075]=l>>>24;c[2276077]=0;c[2276078]=0;return}function wn(){var a=0,b=0,d=0;a=c[2276069]|0;b=9104156+((a>>>9&7)<<2)|0;d=ag(c[b>>2]&65535,c[9104156+((a&7)<<2)>>2]&65535)|0;c[b>>2]=d;c[2276076]=d;c[2276075]=d>>>24;c[2276077]=0;c[2276078]=0;return}function wo(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0;a=c[2276069]|0;b=9104156+((a>>>9&7)<<2)|0;e=c[2276085]&c[9104156+((a&7|8)<<2)>>2];a=e&16777215;f=c[2112932]|0;g=c[f+(a>>>10<<2)>>2]|0;if(g>>>0>9){h=e&1023;i=(d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0)}else{i=gj[c[f+196688+(g<<2)>>2]&4095](a)|0}a=ag(c[b>>2]&65535,i&65535)|0;c[b>>2]=a;c[2276076]=a;c[2276075]=a>>>24;c[2276077]=0;c[2276078]=0;return}function wp(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0;a=c[2276069]|0;b=9104156+((a>>>9&7)<<2)|0;e=9104156+((a&7|8)<<2)|0;a=c[e>>2]|0;c[e>>2]=a+2;e=c[2276085]&a;a=e&16777215;f=c[2112932]|0;g=c[f+(a>>>10<<2)>>2]|0;if(g>>>0>9){h=e&1023;i=(d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0)}else{i=gj[c[f+196688+(g<<2)>>2]&4095](a)|0}a=ag(c[b>>2]&65535,i&65535)|0;c[b>>2]=a;c[2276076]=a;c[2276075]=a>>>24;c[2276077]=0;c[2276078]=0;return}function wq(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0;a=c[2276069]|0;b=9104156+((a>>>9&7)<<2)|0;e=9104156+((a&7|8)<<2)|0;a=(c[e>>2]|0)-2|0;c[e>>2]=a;e=c[2276085]&a;a=e&16777215;f=c[2112932]|0;g=c[f+(a>>>10<<2)>>2]|0;if(g>>>0>9){h=e&1023;i=(d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0)}else{i=gj[c[f+196688+(g<<2)>>2]&4095](a)|0}a=ag(c[b>>2]&65535,i&65535)|0;c[b>>2]=a;c[2276076]=a;c[2276075]=a>>>24;c[2276077]=0;c[2276078]=0;return}function wr(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;a=c[2276069]|0;b=9104156+((a>>>9&7)<<2)|0;e=c[9104156+((a&7|8)<<2)>>2]|0;a=c[2276056]|0;f=a&-4;if((f|0)==(c[2276083]|0)){g=a;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a}else{a=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=a;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=(h>>>((g<<3&16^16)>>>0)<<16>>16)+e&c[2276085];e=m&16777215;g=c[2112932]|0;h=c[g+(e>>>10<<2)>>2]|0;if(h>>>0>9){n=m&1023;o=(d[h+(n+1)|0]|0)<<8|(d[h+n|0]|0);p=o&65535;q=c[b>>2]|0;r=q&65535;s=ag(r,p)|0;c[b>>2]=s;c[2276076]=s;t=s>>>24;c[2276075]=t;c[2276077]=0;c[2276078]=0;return}else{o=gj[c[g+196688+(h<<2)>>2]&4095](e)|0;p=o&65535;q=c[b>>2]|0;r=q&65535;s=ag(r,p)|0;c[b>>2]=s;c[2276076]=s;t=s>>>24;c[2276075]=t;c[2276077]=0;c[2276078]=0;return}}function ws(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0;a=c[2276069]|0;b=9104156+((a>>>9&7)<<2)|0;e=nB(c[9104156+((a&7|8)<<2)>>2]|0)|0;a=c[2276085]&e;e=a&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=a&1023;i=(d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0)}else{i=gj[c[f+196688+(g<<2)>>2]&4095](e)|0}e=ag(c[b>>2]&65535,i&65535)|0;c[b>>2]=e;c[2276076]=e;c[2276075]=e>>>24;c[2276077]=0;c[2276078]=0;return}function wt(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;a=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)<<16>>16&c[2276085];f=l&16777215;g=c[2112932]|0;m=c[g+(f>>>10<<2)>>2]|0;if(m>>>0>9){b=l&1023;n=(d[m+(b+1)|0]|0)<<8|(d[m+b|0]|0);o=n&65535;p=c[a>>2]|0;q=p&65535;r=ag(q,o)|0;c[a>>2]=r;c[2276076]=r;s=r>>>24;c[2276075]=s;c[2276077]=0;c[2276078]=0;return}else{n=gj[c[g+196688+(m<<2)>>2]&4095](f)|0;o=n&65535;p=c[a>>2]|0;q=p&65535;r=ag(q,o)|0;c[a>>2]=r;c[2276076]=r;s=r>>>24;c[2276075]=s;c[2276077]=0;c[2276078]=0;return}}function wu(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;a=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[2276085]&q;q=r&16777215;t=c[2112932]|0;h=c[t+(q>>>10<<2)>>2]|0;if(h>>>0>9){s=r&1023;u=(d[h+(s+1)|0]|0)<<8|(d[h+s|0]|0);v=u&65535;w=c[a>>2]|0;x=w&65535;y=ag(x,v)|0;c[a>>2]=y;c[2276076]=y;z=y>>>24;c[2276075]=z;c[2276077]=0;c[2276078]=0;return}else{u=gj[c[t+196688+(h<<2)>>2]&4095](q)|0;v=u&65535;w=c[a>>2]|0;x=w&65535;y=ag(x,v)|0;c[a>>2]=y;c[2276076]=y;z=y>>>24;c[2276075]=z;c[2276077]=0;c[2276078]=0;return}}function wv(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;a=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{k=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=k;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=(g>>>((f<<3&16^16)>>>0)<<16>>16)+b|0;b=l&16777215;f=c[2112932]|0;g=c[f+((b>>>10|32768)<<2)>>2]|0;if(g>>>0>9){m=l&1023;n=(d[g+(m+1)|0]|0)<<8|(d[g+m|0]|0);o=n&65535;p=c[a>>2]|0;q=p&65535;r=ag(q,o)|0;c[a>>2]=r;c[2276076]=r;s=r>>>24;c[2276075]=s;c[2276077]=0;c[2276078]=0;return}else{n=gj[c[f+196688+(g<<2)>>2]&4095](b)|0;o=n&65535;p=c[a>>2]|0;q=p&65535;r=ag(q,o)|0;c[a>>2]=r;c[2276076]=r;s=r>>>24;c[2276075]=s;c[2276077]=0;c[2276078]=0;return}}function ww(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0;a=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;b=nB(c[2276056]|0)|0;e=b&16777215;f=c[2112932]|0;g=c[f+((e>>>10|32768)<<2)>>2]|0;if(g>>>0>9){h=b&1023;i=(d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0)}else{i=gj[c[f+196688+(g<<2)>>2]&4095](e)|0}e=ag(c[a>>2]&65535,i&65535)|0;c[a>>2]=e;c[2276076]=e;c[2276075]=e>>>24;c[2276077]=0;c[2276078]=0;return}function wx(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=ag(g>>>((f<<3&16^16)>>>0)&65535,c[a>>2]&65535)|0;c[a>>2]=l;c[2276076]=l;c[2276075]=l>>>24;c[2276077]=0;c[2276078]=0;return}function wy(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((c[2276038]&24|0)==0){ni();return}a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=f>>>((e<<3&16^16)>>>0);e=c[9104156+((c[2276069]&7)<<2)>>2]|0;f=9104156+((k>>>12&7)<<2)|0;l=c[f>>2]|0;c[2276078]=0;a=(k&2048|0)!=0;if(a){m=(e|0)<0?-e|0:e;n=(l|0)<0?-l|0:l}else{m=e;n=l}b=m&65535;i=m>>>16;m=n&65535;h=n>>>16;n=ag(b,m)|0;j=ag(b,h)|0;b=ag(i,m)|0;m=(j<<16)+n+(b<<16)|0;g=(j>>>16)+(ag(i,h)|0)+(b>>>16)+(((n>>>16)+(j&65535)+(b&65535)|0)>>>16)|0;if(a&(l^e|0)<0){o=-(g+((m|0)!=0)|0)|0;p=-m|0}else{o=g;p=m}if((k&1024|0)!=0){c[9104156+((k&7)<<2)>>2]=o;c[f>>2]=p;c[2276075]=o>>>24;c[2276076]=o|p;c[2276077]=0;return}c[f>>2]=p;c[2276075]=p>>>24;c[2276076]=p;if(!a){c[2276077]=((o|0)!=0)<<7;return}a=(p|0)<0;if(a){q=a&(o|0)==-1?0:128}else{q=((o|0)!=0)<<7}c[2276077]=q;return}function wz(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if((c[2276038]&24|0)==0){ni();return}a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=f>>>((e<<3&16^16)>>>0);e=c[2276085]&c[9104156+((c[2276069]&7|8)<<2)>>2];f=e&16777215;l=c[2112932]|0;a=c[l+(f>>>10<<2)>>2]|0;if(a>>>0>9){b=e&1023;m=(d[a+(b+3)|0]|0)<<8|(d[a+(b+2)|0]|0)|((d[a+(b+1)|0]|0)<<8|(d[a+b|0]|0))<<16}else{m=gj[c[l+196768+(a<<2)>>2]&4095](f)|0}f=9104156+((k>>>12&7)<<2)|0;a=c[f>>2]|0;c[2276078]=0;l=(k&2048|0)!=0;if(l){n=(m|0)<0?-m|0:m;o=(a|0)<0?-a|0:a}else{n=m;o=a}b=n&65535;e=n>>>16;n=o&65535;i=o>>>16;o=ag(b,n)|0;h=ag(b,i)|0;b=ag(e,n)|0;n=(h<<16)+o+(b<<16)|0;j=(h>>>16)+(ag(e,i)|0)+(b>>>16)+(((o>>>16)+(h&65535)+(b&65535)|0)>>>16)|0;if(l&(a^m|0)<0){p=-(j+((n|0)!=0)|0)|0;q=-n|0}else{p=j;q=n}if((k&1024|0)!=0){c[9104156+((k&7)<<2)>>2]=p;c[f>>2]=q;c[2276075]=p>>>24;c[2276076]=p|q;c[2276077]=0;return}c[f>>2]=q;c[2276075]=q>>>24;c[2276076]=q;if(!l){c[2276077]=((p|0)!=0)<<7;return}l=(q|0)<0;if(l){r=l&(p|0)==-1?0:128}else{r=((p|0)!=0)<<7}c[2276077]=r;return}function wA(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if((c[2276038]&24|0)==0){ni();return}a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=f>>>((e<<3&16^16)>>>0);e=9104156+((c[2276069]&7|8)<<2)|0;f=c[e>>2]|0;c[e>>2]=f+4;e=c[2276085]&f;f=e&16777215;l=c[2112932]|0;a=c[l+(f>>>10<<2)>>2]|0;if(a>>>0>9){b=e&1023;m=(d[a+(b+3)|0]|0)<<8|(d[a+(b+2)|0]|0)|((d[a+(b+1)|0]|0)<<8|(d[a+b|0]|0))<<16}else{m=gj[c[l+196768+(a<<2)>>2]&4095](f)|0}f=9104156+((k>>>12&7)<<2)|0;a=c[f>>2]|0;c[2276078]=0;l=(k&2048|0)!=0;if(l){n=(m|0)<0?-m|0:m;o=(a|0)<0?-a|0:a}else{n=m;o=a}b=n&65535;e=n>>>16;n=o&65535;i=o>>>16;o=ag(b,n)|0;h=ag(b,i)|0;b=ag(e,n)|0;n=(h<<16)+o+(b<<16)|0;j=(h>>>16)+(ag(e,i)|0)+(b>>>16)+(((o>>>16)+(h&65535)+(b&65535)|0)>>>16)|0;if(l&(a^m|0)<0){p=-(j+((n|0)!=0)|0)|0;q=-n|0}else{p=j;q=n}if((k&1024|0)!=0){c[9104156+((k&7)<<2)>>2]=p;c[f>>2]=q;c[2276075]=p>>>24;c[2276076]=p|q;c[2276077]=0;return}c[f>>2]=q;c[2276075]=q>>>24;c[2276076]=q;if(!l){c[2276077]=((p|0)!=0)<<7;return}l=(q|0)<0;if(l){r=l&(p|0)==-1?0:128}else{r=((p|0)!=0)<<7}c[2276077]=r;return}function wB(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if((c[2276038]&24|0)==0){ni();return}a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=f>>>((e<<3&16^16)>>>0);e=9104156+((c[2276069]&7|8)<<2)|0;f=(c[e>>2]|0)-4|0;c[e>>2]=f;e=c[2276085]&f;f=e&16777215;l=c[2112932]|0;a=c[l+(f>>>10<<2)>>2]|0;if(a>>>0>9){b=e&1023;m=(d[a+(b+3)|0]|0)<<8|(d[a+(b+2)|0]|0)|((d[a+(b+1)|0]|0)<<8|(d[a+b|0]|0))<<16}else{m=gj[c[l+196768+(a<<2)>>2]&4095](f)|0}f=9104156+((k>>>12&7)<<2)|0;a=c[f>>2]|0;c[2276078]=0;l=(k&2048|0)!=0;if(l){n=(m|0)<0?-m|0:m;o=(a|0)<0?-a|0:a}else{n=m;o=a}b=n&65535;e=n>>>16;n=o&65535;i=o>>>16;o=ag(b,n)|0;h=ag(b,i)|0;b=ag(e,n)|0;n=(h<<16)+o+(b<<16)|0;j=(h>>>16)+(ag(e,i)|0)+(b>>>16)+(((o>>>16)+(h&65535)+(b&65535)|0)>>>16)|0;if(l&(a^m|0)<0){p=-(j+((n|0)!=0)|0)|0;q=-n|0}else{p=j;q=n}if((k&1024|0)!=0){c[9104156+((k&7)<<2)>>2]=p;c[f>>2]=q;c[2276075]=p>>>24;c[2276076]=p|q;c[2276077]=0;return}c[f>>2]=q;c[2276075]=q>>>24;c[2276076]=q;if(!l){c[2276077]=((p|0)!=0)<<7;return}l=(q|0)<0;if(l){r=l&(p|0)==-1?0:128}else{r=((p|0)!=0)<<7}c[2276077]=r;return}function wC(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;if((c[2276038]&24|0)==0){ni();return}a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0;g=b}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=m;g=o}o=e+2|0;c[2276056]=o;m=f>>>((e<<3&16^16)>>>0);e=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;n=o&-4;if((n|0)==(g|0)){p=o;q=f}else{c[2276083]=n;f=c[2276085]&n;n=f&16777212;g=c[2112932]|0;b=c[g+((n>>>10|32768)<<2)>>2]|0;if(b>>>0>9){i=f&1020;r=(d[b+(i|3)|0]|0)<<8|(d[b+(i|2)|0]|0)|((d[b+(i|1)|0]|0)<<8|(d[b+i|0]|0))<<16;s=o}else{o=gj[c[g+196768+(b<<2)>>2]&4095](n)|0;r=o;s=c[2276056]|0}c[2276084]=r;p=s;q=r}c[2276056]=p+2;r=(q>>>((p<<3&16^16)>>>0)<<16>>16)+e&c[2276085];e=r&16777215;p=c[2112932]|0;q=c[p+(e>>>10<<2)>>2]|0;if(q>>>0>9){s=r&1023;t=(d[q+(s+3)|0]|0)<<8|(d[q+(s+2)|0]|0)|((d[q+(s+1)|0]|0)<<8|(d[q+s|0]|0))<<16}else{t=gj[c[p+196768+(q<<2)>>2]&4095](e)|0}e=9104156+((m>>>12&7)<<2)|0;q=c[e>>2]|0;c[2276078]=0;p=(m&2048|0)!=0;if(p){u=(t|0)<0?-t|0:t;v=(q|0)<0?-q|0:q}else{u=t;v=q}s=u&65535;r=u>>>16;u=v&65535;o=v>>>16;v=ag(s,u)|0;n=ag(s,o)|0;s=ag(r,u)|0;u=(n<<16)+v+(s<<16)|0;b=(n>>>16)+(ag(r,o)|0)+(s>>>16)+(((v>>>16)+(n&65535)+(s&65535)|0)>>>16)|0;if(p&(q^t|0)<0){w=-(b+((u|0)!=0)|0)|0;x=-u|0}else{w=b;x=u}if((m&1024|0)!=0){c[9104156+((m&7)<<2)>>2]=w;c[e>>2]=x;c[2276075]=w>>>24;c[2276076]=w|x;c[2276077]=0;return}c[e>>2]=x;c[2276075]=x>>>24;c[2276076]=x;if(!p){c[2276077]=((w|0)!=0)<<7;return}p=(x|0)<0;if(p){y=p&(w|0)==-1?0:128}else{y=((w|0)!=0)<<7}c[2276077]=y;return}function wD(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if((c[2276038]&24|0)==0){ni();return}a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=f>>>((e<<3&16^16)>>>0);e=nB(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;f=c[2276085]&e;e=f&16777215;l=c[2112932]|0;a=c[l+(e>>>10<<2)>>2]|0;if(a>>>0>9){b=f&1023;m=(d[a+(b+3)|0]|0)<<8|(d[a+(b+2)|0]|0)|((d[a+(b+1)|0]|0)<<8|(d[a+b|0]|0))<<16}else{m=gj[c[l+196768+(a<<2)>>2]&4095](e)|0}e=9104156+((k>>>12&7)<<2)|0;a=c[e>>2]|0;c[2276078]=0;l=(k&2048|0)!=0;if(l){n=(m|0)<0?-m|0:m;o=(a|0)<0?-a|0:a}else{n=m;o=a}b=n&65535;f=n>>>16;n=o&65535;i=o>>>16;o=ag(b,n)|0;h=ag(b,i)|0;b=ag(f,n)|0;n=(h<<16)+o+(b<<16)|0;j=(h>>>16)+(ag(f,i)|0)+(b>>>16)+(((o>>>16)+(h&65535)+(b&65535)|0)>>>16)|0;if(l&(a^m|0)<0){p=-(j+((n|0)!=0)|0)|0;q=-n|0}else{p=j;q=n}if((k&1024|0)!=0){c[9104156+((k&7)<<2)>>2]=p;c[e>>2]=q;c[2276075]=p>>>24;c[2276076]=p|q;c[2276077]=0;return}c[e>>2]=q;c[2276075]=q>>>24;c[2276076]=q;if(!l){c[2276077]=((p|0)!=0)<<7;return}l=(q|0)<0;if(l){r=l&(p|0)==-1?0:128}else{r=((p|0)!=0)<<7}c[2276077]=r;return}function wE(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;if((c[2276038]&24|0)==0){ni();return}a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0;g=b}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=m;g=o}o=e+2|0;c[2276056]=o;m=f>>>((e<<3&16^16)>>>0);e=o&-4;if((e|0)==(g|0)){p=o;q=f}else{c[2276083]=e;f=c[2276085]&e;e=f&16777212;g=c[2112932]|0;n=c[g+((e>>>10|32768)<<2)>>2]|0;if(n>>>0>9){b=f&1020;r=(d[n+(b|3)|0]|0)<<8|(d[n+(b|2)|0]|0)|((d[n+(b|1)|0]|0)<<8|(d[n+b|0]|0))<<16;s=o}else{o=gj[c[g+196768+(n<<2)>>2]&4095](e)|0;r=o;s=c[2276056]|0}c[2276084]=r;p=s;q=r}c[2276056]=p+2;r=q>>>((p<<3&16^16)>>>0)<<16>>16&c[2276085];p=r&16777215;q=c[2112932]|0;s=c[q+(p>>>10<<2)>>2]|0;if(s>>>0>9){o=r&1023;t=(d[s+(o+3)|0]|0)<<8|(d[s+(o+2)|0]|0)|((d[s+(o+1)|0]|0)<<8|(d[s+o|0]|0))<<16}else{t=gj[c[q+196768+(s<<2)>>2]&4095](p)|0}p=9104156+((m>>>12&7)<<2)|0;s=c[p>>2]|0;c[2276078]=0;q=(m&2048|0)!=0;if(q){u=(t|0)<0?-t|0:t;v=(s|0)<0?-s|0:s}else{u=t;v=s}o=u&65535;r=u>>>16;u=v&65535;e=v>>>16;v=ag(o,u)|0;n=ag(o,e)|0;o=ag(r,u)|0;u=(n<<16)+v+(o<<16)|0;g=(n>>>16)+(ag(r,e)|0)+(o>>>16)+(((v>>>16)+(n&65535)+(o&65535)|0)>>>16)|0;if(q&(s^t|0)<0){w=-(g+((u|0)!=0)|0)|0;x=-u|0}else{w=g;x=u}if((m&1024|0)!=0){c[9104156+((m&7)<<2)>>2]=w;c[p>>2]=x;c[2276075]=w>>>24;c[2276076]=w|x;c[2276077]=0;return}c[p>>2]=x;c[2276075]=x>>>24;c[2276076]=x;if(!q){c[2276077]=((w|0)!=0)<<7;return}q=(x|0)<0;if(q){y=q&(w|0)==-1?0:128}else{y=((w|0)!=0)<<7}c[2276077]=y;return}function wF(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;if((c[2276038]&24|0)==0){ni();return}a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0;g=b}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=m;g=o}o=e+2|0;c[2276056]=o;m=f>>>((e<<3&16^16)>>>0);e=o&-4;if((e|0)==(g|0)){p=o;q=g;r=f}else{c[2276083]=e;f=c[2276085]&e;g=f&16777212;n=c[2112932]|0;b=c[n+((g>>>10|32768)<<2)>>2]|0;if(b>>>0>9){i=f&1020;s=(d[b+(i|3)|0]|0)<<8|(d[b+(i|2)|0]|0)|((d[b+(i|1)|0]|0)<<8|(d[b+i|0]|0))<<16;t=o;u=e}else{e=gj[c[n+196768+(b<<2)>>2]&4095](g)|0;s=e;t=c[2276056]|0;u=c[2276083]|0}c[2276084]=s;p=t;q=u;r=s}s=p+2|0;c[2276056]=s;p=s&-4;if((p|0)==(q|0)){v=r;w=s}else{c[2276083]=p;q=c[2276085]&p;p=q&16777212;u=c[2112932]|0;t=c[u+((p>>>10|32768)<<2)>>2]|0;if(t>>>0>9){e=q&1020;x=(d[t+(e|3)|0]|0)<<8|(d[t+(e|2)|0]|0)|((d[t+(e|1)|0]|0)<<8|(d[t+e|0]|0))<<16;y=s}else{s=gj[c[u+196768+(t<<2)>>2]&4095](p)|0;x=s;y=c[2276056]|0}c[2276084]=x;v=x>>>16|r<<16;w=y}c[2276056]=w+2;w=c[2276085]&v;v=w&16777215;y=c[2112932]|0;r=c[y+(v>>>10<<2)>>2]|0;if(r>>>0>9){x=w&1023;z=(d[r+(x+3)|0]|0)<<8|(d[r+(x+2)|0]|0)|((d[r+(x+1)|0]|0)<<8|(d[r+x|0]|0))<<16}else{z=gj[c[y+196768+(r<<2)>>2]&4095](v)|0}v=9104156+((m>>>12&7)<<2)|0;r=c[v>>2]|0;c[2276078]=0;y=(m&2048|0)!=0;if(y){A=(z|0)<0?-z|0:z;B=(r|0)<0?-r|0:r}else{A=z;B=r}x=A&65535;w=A>>>16;A=B&65535;s=B>>>16;B=ag(x,A)|0;p=ag(x,s)|0;x=ag(w,A)|0;A=(p<<16)+B+(x<<16)|0;t=(p>>>16)+(ag(w,s)|0)+(x>>>16)+(((B>>>16)+(p&65535)+(x&65535)|0)>>>16)|0;if(y&(r^z|0)<0){C=-(t+((A|0)!=0)|0)|0;D=-A|0}else{C=t;D=A}if((m&1024|0)!=0){c[9104156+((m&7)<<2)>>2]=C;c[v>>2]=D;c[2276075]=C>>>24;c[2276076]=C|D;c[2276077]=0;return}c[v>>2]=D;c[2276075]=D>>>24;c[2276076]=D;if(!y){c[2276077]=((C|0)!=0)<<7;return}y=(D|0)<0;if(y){E=y&(C|0)==-1?0:128}else{E=((C|0)!=0)<<7}c[2276077]=E;return}function wG(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;if((c[2276038]&24|0)==0){ni();return}a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0;g=b}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=m;g=o}o=e+2|0;c[2276056]=o;m=f>>>((e<<3&16^16)>>>0);e=o&-4;if((e|0)==(g|0)){p=o;q=f}else{c[2276083]=e;f=c[2276085]&e;e=f&16777212;g=c[2112932]|0;n=c[g+((e>>>10|32768)<<2)>>2]|0;if(n>>>0>9){b=f&1020;r=(d[n+(b|3)|0]|0)<<8|(d[n+(b|2)|0]|0)|((d[n+(b|1)|0]|0)<<8|(d[n+b|0]|0))<<16;s=o}else{b=gj[c[g+196768+(n<<2)>>2]&4095](e)|0;r=b;s=c[2276056]|0}c[2276084]=r;p=s;q=r}c[2276056]=p+2;r=(q>>>((p<<3&16^16)>>>0)<<16>>16)+o|0;o=r&16777215;p=c[2112932]|0;q=c[p+((o>>>10|32768)<<2)>>2]|0;if(q>>>0>9){s=r&1023;t=(d[q+(s+3)|0]|0)<<8|(d[q+(s+2)|0]|0)|((d[q+(s+1)|0]|0)<<8|(d[q+s|0]|0))<<16}else{t=gj[c[p+196768+(q<<2)>>2]&4095](o)|0}o=9104156+((m>>>12&7)<<2)|0;q=c[o>>2]|0;c[2276078]=0;p=(m&2048|0)!=0;if(p){u=(t|0)<0?-t|0:t;v=(q|0)<0?-q|0:q}else{u=t;v=q}s=u&65535;r=u>>>16;u=v&65535;b=v>>>16;v=ag(s,u)|0;e=ag(s,b)|0;s=ag(r,u)|0;u=(e<<16)+v+(s<<16)|0;n=(e>>>16)+(ag(r,b)|0)+(s>>>16)+(((v>>>16)+(e&65535)+(s&65535)|0)>>>16)|0;if(p&(q^t|0)<0){w=-(n+((u|0)!=0)|0)|0;x=-u|0}else{w=n;x=u}if((m&1024|0)!=0){c[9104156+((m&7)<<2)>>2]=w;c[o>>2]=x;c[2276075]=w>>>24;c[2276076]=w|x;c[2276077]=0;return}c[o>>2]=x;c[2276075]=x>>>24;c[2276076]=x;if(!p){c[2276077]=((w|0)!=0)<<7;return}p=(x|0)<0;if(p){y=p&(w|0)==-1?0:128}else{y=((w|0)!=0)<<7}c[2276077]=y;return}function wH(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if((c[2276038]&24|0)==0){ni();return}a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}k=e+2|0;c[2276056]=k;l=f>>>((e<<3&16^16)>>>0);e=nB(k)|0;k=e&16777215;f=c[2112932]|0;a=c[f+((k>>>10|32768)<<2)>>2]|0;if(a>>>0>9){b=e&1023;m=(d[a+(b+3)|0]|0)<<8|(d[a+(b+2)|0]|0)|((d[a+(b+1)|0]|0)<<8|(d[a+b|0]|0))<<16}else{m=gj[c[f+196768+(a<<2)>>2]&4095](k)|0}k=9104156+((l>>>12&7)<<2)|0;a=c[k>>2]|0;c[2276078]=0;f=(l&2048|0)!=0;if(f){n=(m|0)<0?-m|0:m;o=(a|0)<0?-a|0:a}else{n=m;o=a}b=n&65535;e=n>>>16;n=o&65535;i=o>>>16;o=ag(b,n)|0;h=ag(b,i)|0;b=ag(e,n)|0;n=(h<<16)+o+(b<<16)|0;j=(h>>>16)+(ag(e,i)|0)+(b>>>16)+(((o>>>16)+(h&65535)+(b&65535)|0)>>>16)|0;if(f&(a^m|0)<0){p=-(j+((n|0)!=0)|0)|0;q=-n|0}else{p=j;q=n}if((l&1024|0)!=0){c[9104156+((l&7)<<2)>>2]=p;c[k>>2]=q;c[2276075]=p>>>24;c[2276076]=p|q;c[2276077]=0;return}c[k>>2]=q;c[2276075]=q>>>24;c[2276076]=q;if(!f){c[2276077]=((p|0)!=0)<<7;return}f=(q|0)<0;if(f){r=f&(p|0)==-1?0:128}else{r=((p|0)!=0)<<7}c[2276077]=r;return}function wI(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;if((c[2276038]&24|0)==0){ni();return}a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0;g=b}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=m;g=o}o=e+2|0;c[2276056]=o;m=f>>>((e<<3&16^16)>>>0);e=o&-4;if((e|0)==(g|0)){p=o;q=g;r=f}else{c[2276083]=e;f=c[2276085]&e;g=f&16777212;n=c[2112932]|0;b=c[n+((g>>>10|32768)<<2)>>2]|0;if(b>>>0>9){i=f&1020;s=(d[b+(i|3)|0]|0)<<8|(d[b+(i|2)|0]|0)|((d[b+(i|1)|0]|0)<<8|(d[b+i|0]|0))<<16;t=o;u=e}else{e=gj[c[n+196768+(b<<2)>>2]&4095](g)|0;s=e;t=c[2276056]|0;u=c[2276083]|0}c[2276084]=s;p=t;q=u;r=s}s=p+2|0;c[2276056]=s;p=s&-4;if((p|0)==(q|0)){v=r;w=s}else{c[2276083]=p;q=c[2276085]&p;p=q&16777212;u=c[2112932]|0;t=c[u+((p>>>10|32768)<<2)>>2]|0;if(t>>>0>9){e=q&1020;x=(d[t+(e|3)|0]|0)<<8|(d[t+(e|2)|0]|0)|((d[t+(e|1)|0]|0)<<8|(d[t+e|0]|0))<<16;y=s}else{s=gj[c[u+196768+(t<<2)>>2]&4095](p)|0;x=s;y=c[2276056]|0}c[2276084]=x;v=x>>>16|r<<16;w=y}c[2276056]=w+2;w=9104156+((m>>>12&7)<<2)|0;y=c[w>>2]|0;c[2276078]=0;r=(m&2048|0)!=0;if(r){z=(v|0)<0?-v|0:v;A=(y|0)<0?-y|0:y}else{z=v;A=y}x=z&65535;s=z>>>16;z=A&65535;p=A>>>16;A=ag(x,z)|0;t=ag(x,p)|0;x=ag(s,z)|0;z=(t<<16)+A+(x<<16)|0;u=(t>>>16)+(ag(s,p)|0)+(x>>>16)+(((A>>>16)+(t&65535)+(x&65535)|0)>>>16)|0;if(r&(y^v|0)<0){B=-(u+((z|0)!=0)|0)|0;C=-z|0}else{B=u;C=z}if((m&1024|0)!=0){c[9104156+((m&7)<<2)>>2]=B;c[w>>2]=C;c[2276075]=B>>>24;c[2276076]=B|C;c[2276077]=0;return}c[w>>2]=C;c[2276075]=C>>>24;c[2276076]=C;if(!r){c[2276077]=((B|0)!=0)<<7;return}r=(C|0)<0;if(r){D=r&(B|0)==-1?0:128}else{D=((B|0)!=0)<<7}c[2276077]=D;return}function wJ(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;b=c[2276072]|0;e=c[2276073]|0;f=c[2276071]|c[2276070]|b<<11|e<<11|c[2276079]|(c[2276074]|0)>>>4&16|(c[2276075]|0)>>>4&8|((c[2276076]|0)==0)<<2|(c[2276077]|0)>>>6&2|(c[2276078]|0)>>>8&1;c[2276071]=0;c[2276070]=0;c[9104228+((b>>>1&e|b)<<2)>>2]=c[2276054];c[2276072]=4;b=c[9104228+((c[2276073]&2|4)<<2)>>2]|0;c[2276054]=b;e=c[2276055]|0;do{if(((c[2276038]|0)-1|0)>>>0<2){g=b-4|0;c[2276054]=g;h=c[2276085]&g;g=h&16777215;i=c[2112932]|0;j=c[i+((g>>>10|16384)<<2)>>2]|0;if(j>>>0>9){k=h&1023;a[j+k|0]=e>>>16&255;a[j+(k+1)|0]=e>>>24&255;a[j+(k+2)|0]=e&255;a[j+(k+3)|0]=e>>>8&255;l=i}else{gg[c[i+196808+(j<<2)>>2]&4095](g,e);l=c[2112932]|0}g=(c[2276054]|0)-2|0;c[2276054]=g;j=c[2276085]&g;g=f&65535;i=j&16777215;k=c[l+((i>>>10|16384)<<2)>>2]|0;if(k>>>0>9){h=j&1023;a[k+h|0]=f&255;a[k+(h+1)|0]=(g&65535)>>>8&255;break}else{gg[c[l+196728+(k<<2)>>2]&4095](i,g);break}}else{g=b-2|0;c[2276054]=g;i=c[2276085]&g;g=i&16777215;k=c[2112932]|0;h=c[k+((g>>>10|16384)<<2)>>2]|0;if(h>>>0>9){j=i&1023;a[h+j|0]=40;a[h+(j+1)|0]=0;m=k}else{gg[c[k+196728+(h<<2)>>2]&4095](g,40);m=c[2112932]|0}g=(c[2276054]|0)-4|0;c[2276054]=g;h=c[2276085]&g;g=h&16777215;k=c[m+((g>>>10|16384)<<2)>>2]|0;if(k>>>0>9){j=h&1023;a[k+j|0]=e>>>16&255;a[k+(j+1)|0]=e>>>24&255;a[k+(j+2)|0]=e&255;a[k+(j+3)|0]=e>>>8&255;n=m}else{gg[c[m+196808+(k<<2)>>2]&4095](g,e);n=c[2112932]|0}g=(c[2276054]|0)-2|0;c[2276054]=g;k=c[2276085]&g;g=f&65535;j=k&16777215;h=c[n+((j>>>10|16384)<<2)>>2]|0;if(h>>>0>9){i=k&1023;a[h+i|0]=f&255;a[h+(i+1)|0]=(g&65535)>>>8&255;break}else{gg[c[n+196728+(h<<2)>>2]&4095](j,g);break}}}while(0);n=(c[2276064]|0)+40|0;c[2276056]=n;f=c[2276085]&n;n=f&16777215;e=c[2112932]|0;m=c[e+(n>>>10<<2)>>2]|0;if(m>>>0>9){b=f&1023;o=(d[m+(b+3)|0]|0)<<8|(d[m+(b+2)|0]|0)|((d[m+(b+1)|0]|0)<<8|(d[m+b|0]|0))<<16;c[2276056]=o;p=c[2276099]|0;q=p+10|0;r=a[q]|0;s=r&255;t=c[2276069]|0;u=c[2276098]|0;v=u+t|0;w=a[v]|0;x=w&255;y=c[2276108]|0;z=x-s|0;A=z+y|0;c[2276108]=A;return}else{o=gj[c[e+196768+(m<<2)>>2]&4095](n)|0;c[2276056]=o;p=c[2276099]|0;q=p+10|0;r=a[q]|0;s=r&255;t=c[2276069]|0;u=c[2276098]|0;v=u+t|0;w=a[v]|0;x=w&255;y=c[2276108]|0;z=x-s|0;A=z+y|0;c[2276108]=A;return}}function wK(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;b=c[2276072]|0;e=c[2276073]|0;f=c[2276071]|c[2276070]|b<<11|e<<11|c[2276079]|(c[2276074]|0)>>>4&16|(c[2276075]|0)>>>4&8|((c[2276076]|0)==0)<<2|(c[2276077]|0)>>>6&2|(c[2276078]|0)>>>8&1;c[2276071]=0;c[2276070]=0;c[9104228+((b>>>1&e|b)<<2)>>2]=c[2276054];c[2276072]=4;b=c[9104228+((c[2276073]&2|4)<<2)>>2]|0;c[2276054]=b;e=c[2276055]|0;do{if(((c[2276038]|0)-1|0)>>>0<2){g=b-4|0;c[2276054]=g;h=c[2276085]&g;g=h&16777215;i=c[2112932]|0;j=c[i+((g>>>10|16384)<<2)>>2]|0;if(j>>>0>9){k=h&1023;a[j+k|0]=e>>>16&255;a[j+(k+1)|0]=e>>>24&255;a[j+(k+2)|0]=e&255;a[j+(k+3)|0]=e>>>8&255;l=i}else{gg[c[i+196808+(j<<2)>>2]&4095](g,e);l=c[2112932]|0}g=(c[2276054]|0)-2|0;c[2276054]=g;j=c[2276085]&g;g=f&65535;i=j&16777215;k=c[l+((i>>>10|16384)<<2)>>2]|0;if(k>>>0>9){h=j&1023;a[k+h|0]=f&255;a[k+(h+1)|0]=(g&65535)>>>8&255;break}else{gg[c[l+196728+(k<<2)>>2]&4095](i,g);break}}else{g=b-2|0;c[2276054]=g;i=c[2276085]&g;g=i&16777215;k=c[2112932]|0;h=c[k+((g>>>10|16384)<<2)>>2]|0;if(h>>>0>9){j=i&1023;a[h+j|0]=44;a[h+(j+1)|0]=0;m=k}else{gg[c[k+196728+(h<<2)>>2]&4095](g,44);m=c[2112932]|0}g=(c[2276054]|0)-4|0;c[2276054]=g;h=c[2276085]&g;g=h&16777215;k=c[m+((g>>>10|16384)<<2)>>2]|0;if(k>>>0>9){j=h&1023;a[k+j|0]=e>>>16&255;a[k+(j+1)|0]=e>>>24&255;a[k+(j+2)|0]=e&255;a[k+(j+3)|0]=e>>>8&255;n=m}else{gg[c[m+196808+(k<<2)>>2]&4095](g,e);n=c[2112932]|0}g=(c[2276054]|0)-2|0;c[2276054]=g;k=c[2276085]&g;g=f&65535;j=k&16777215;h=c[n+((j>>>10|16384)<<2)>>2]|0;if(h>>>0>9){i=k&1023;a[h+i|0]=f&255;a[h+(i+1)|0]=(g&65535)>>>8&255;break}else{gg[c[n+196728+(h<<2)>>2]&4095](j,g);break}}}while(0);n=(c[2276064]|0)+44|0;c[2276056]=n;f=c[2276085]&n;n=f&16777215;e=c[2112932]|0;m=c[e+(n>>>10<<2)>>2]|0;if(m>>>0>9){b=f&1023;o=(d[m+(b+3)|0]|0)<<8|(d[m+(b+2)|0]|0)|((d[m+(b+1)|0]|0)<<8|(d[m+b|0]|0))<<16;c[2276056]=o;p=c[2276099]|0;q=p+11|0;r=a[q]|0;s=r&255;t=c[2276069]|0;u=c[2276098]|0;v=u+t|0;w=a[v]|0;x=w&255;y=c[2276108]|0;z=x-s|0;A=z+y|0;c[2276108]=A;return}else{o=gj[c[e+196768+(m<<2)>>2]&4095](n)|0;c[2276056]=o;p=c[2276099]|0;q=p+11|0;r=a[q]|0;s=r&255;t=c[2276069]|0;u=c[2276098]|0;v=u+t|0;w=a[v]|0;x=w&255;y=c[2276108]|0;z=x-s|0;A=z+y|0;c[2276108]=A;return}}function wL(){var a=0,b=0,d=0,e=0,f=0;a=c[2276069]|0;b=9104156+((a>>>9&7)<<2)|0;d=c[9104156+((a&7)<<2)>>2]|0;a=c[b>>2]|0;e=(a&15)+(d&15)+((c[2276074]|0)>>>8&1)|0;f=(a&240)+(d&240)+(e>>>0>9?e+6|0:e)|0;d=f>>>0>153;a=(d&1)<<8;c[2276078]=a;c[2276074]=a;a=d?f-160|0:f;c[2276077]=a&~e;c[2276075]=a;e=a&255;c[2276076]=e|c[2276076];c[b>>2]=e|c[b>>2]&-256;return}function wM(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;b=c[2276085]|0;e=b&d;d=e&16777215;f=c[2112932]|0;g=c[f+(d>>>10<<2)>>2]|0;if(g>>>0>9){h=a[g+(e&1023^1)|0]|0;i=b;j=f}else{b=gj[c[f+196608+(g<<2)>>2]&4095](d)|0;h=b;i=c[2276085]|0;j=c[2112932]|0}b=h&255;h=(c[2276054]|0)-2|0;c[2276054]=h;d=i&h;g=d&16777215;f=c[j+(g>>>10<<2)>>2]|0;if(f>>>0>9){k=a[f+(d&1023^1)|0]|0;l=i;m=j}else{i=gj[c[j+196608+(f<<2)>>2]&4095](g)|0;k=i;l=c[2276085]|0;m=c[2112932]|0}i=k&255;k=(i&15)+(b&15)+((c[2276074]|0)>>>8&1)|0;g=(i&240)+(b&240)+(k>>>0>9?k+6|0:k)|0;b=g>>>0>153;i=(b&1)<<8;c[2276078]=i;c[2276074]=i;i=b?g-160|0:g;c[2276077]=i&~k;c[2276075]=i;c[2276076]=i&255|c[2276076];k=l&h;h=i&255;i=k&16777215;l=c[m+((i>>>10|16384)<<2)>>2]|0;if(l>>>0>9){a[l+(k&1023^1)|0]=h;return}else{gg[c[m+196648+(l<<2)>>2]&4095](i,h);return}}function wN(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=(c[2276054]|0)-2|0;c[2276054]=b;d=c[2276085]&b;b=d&16777215;e=c[2112932]|0;f=c[e+(b>>>10<<2)>>2]|0;if(f>>>0>9){g=a[f+(d&1023^1)|0]|0;h=e}else{d=gj[c[e+196608+(f<<2)>>2]&4095](b)|0;g=d;h=c[2112932]|0}d=g&255;g=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;b=(c[g>>2]|0)-1|0;c[g>>2]=b;g=c[2276085]|0;f=g&b;e=f&16777215;i=c[h+(e>>>10<<2)>>2]|0;if(i>>>0>9){j=a[i+(f&1023^1)|0]|0;k=g;l=h}else{g=gj[c[h+196608+(i<<2)>>2]&4095](e)|0;j=g;k=c[2276085]|0;l=c[2112932]|0}g=j&255;j=(g&15)+(d&15)+((c[2276074]|0)>>>8&1)|0;e=(g&240)+(d&240)+(j>>>0>9?j+6|0:j)|0;d=e>>>0>153;g=(d&1)<<8;c[2276078]=g;c[2276074]=g;g=d?e-160|0:e;c[2276077]=g&~j;c[2276075]=g;c[2276076]=g&255|c[2276076];j=k&b;b=g&255;g=j&16777215;k=c[l+((g>>>10|16384)<<2)>>2]|0;if(k>>>0>9){a[k+(j&1023^1)|0]=b;return}else{gg[c[l+196648+(k<<2)>>2]&4095](g,b);return}}function wO(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=(c[2276054]|0)-2|0;c[2276054]=b;d=c[2276085]|0;e=d&b;f=e&16777215;g=c[2112932]|0;h=c[g+(f>>>10<<2)>>2]|0;if(h>>>0>9){i=a[h+(e&1023^1)|0]|0;j=b;k=d;l=g}else{d=gj[c[g+196608+(h<<2)>>2]&4095](f)|0;i=d;j=c[2276054]|0;k=c[2276085]|0;l=c[2112932]|0}d=i&255;i=j-2|0;c[2276054]=i;j=k&i;f=j&16777215;h=c[l+(f>>>10<<2)>>2]|0;if(h>>>0>9){m=a[h+(j&1023^1)|0]|0;n=k;o=l}else{k=gj[c[l+196608+(h<<2)>>2]&4095](f)|0;m=k;n=c[2276085]|0;o=c[2112932]|0}k=m&255;m=(k&15)+(d&15)+((c[2276074]|0)>>>8&1)|0;f=(k&240)+(d&240)+(m>>>0>9?m+6|0:m)|0;d=f>>>0>153;k=(d&1)<<8;c[2276078]=k;c[2276074]=k;k=d?f-160|0:f;c[2276077]=k&~m;c[2276075]=k;c[2276076]=k&255|c[2276076];m=n&i;i=k&255;k=m&16777215;n=c[o+((k>>>10|16384)<<2)>>2]|0;if(n>>>0>9){a[n+(m&1023^1)|0]=i;return}else{gg[c[o+196648+(n<<2)>>2]&4095](k,i);return}}function wP(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;b=c[2276085]&d;d=b&16777215;e=c[2112932]|0;f=c[e+(d>>>10<<2)>>2]|0;if(f>>>0>9){g=a[f+(b&1023^1)|0]|0;h=e}else{b=gj[c[e+196608+(f<<2)>>2]&4095](d)|0;g=b;h=c[2112932]|0}b=g&255;g=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;d=(c[g>>2]|0)-1|0;c[g>>2]=d;g=c[2276085]|0;f=g&d;e=f&16777215;i=c[h+(e>>>10<<2)>>2]|0;if(i>>>0>9){j=a[i+(f&1023^1)|0]|0;k=g;l=h}else{g=gj[c[h+196608+(i<<2)>>2]&4095](e)|0;j=g;k=c[2276085]|0;l=c[2112932]|0}g=j&255;j=(g&15)+(b&15)+((c[2276074]|0)>>>8&1)|0;e=(g&240)+(b&240)+(j>>>0>9?j+6|0:j)|0;b=e>>>0>153;g=(b&1)<<8;c[2276078]=g;c[2276074]=g;g=b?e-160|0:e;c[2276077]=g&~j;c[2276075]=g;c[2276076]=g&255|c[2276076];j=k&d;d=g&255;g=j&16777215;k=c[l+((g>>>10|16384)<<2)>>2]|0;if(k>>>0>9){a[k+(j&1023^1)|0]=d;return}else{gg[c[l+196648+(k<<2)>>2]&4095](g,d);return}}function wQ(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[2276069]|0;b=9104156+((a>>>9&7)<<2)|0;d=c[9104156+((a&7)<<2)>>2]|0;a=d&255;e=c[b>>2]|0;f=e&255;g=f+a|0;c[2276075]=g;c[2276077]=(g^a)&(g^f);c[2276078]=g;c[2276074]=g;g=e+d&255;c[2276076]=g;c[b>>2]=c[b>>2]&-256|g;return}function wR(){var b=0,d=0,e=0,f=0,g=0,h=0;b=c[2276069]|0;d=9104156+((b>>>9&7)<<2)|0;e=c[2276085]&c[9104156+((b&7|8)<<2)>>2];b=e&16777215;f=c[2112932]|0;g=c[f+(b>>>10<<2)>>2]|0;if(g>>>0>9){h=a[g+(e&1023^1)|0]|0}else{h=gj[c[f+196608+(g<<2)>>2]&4095](b)|0}b=h&255;h=c[d>>2]|0;g=h&255;f=g+b|0;c[2276075]=f;c[2276077]=(f^b)&(f^g);c[2276078]=f;c[2276074]=f;f=h+b&255;c[2276076]=f;c[d>>2]=c[d>>2]&-256|f;return}function wS(){var b=0,d=0,e=0,f=0,g=0,h=0;b=c[2276069]|0;d=9104156+((b>>>9&7)<<2)|0;e=9104156+((b&7|8)<<2)|0;b=c[e>>2]|0;c[e>>2]=b+1;e=c[2276085]&b;b=e&16777215;f=c[2112932]|0;g=c[f+(b>>>10<<2)>>2]|0;if(g>>>0>9){h=a[g+(e&1023^1)|0]|0}else{h=gj[c[f+196608+(g<<2)>>2]&4095](b)|0}b=h&255;h=c[d>>2]|0;g=h&255;f=g+b|0;c[2276075]=f;c[2276077]=(f^b)&(f^g);c[2276078]=f;c[2276074]=f;f=h+b&255;c[2276076]=f;c[d>>2]=c[d>>2]&-256|f;return}function wT(){var b=0,d=0,e=0,f=0,g=0,h=0;b=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;d=c[2276054]|0;c[2276054]=d+2;e=c[2276085]&d;d=e&16777215;f=c[2112932]|0;g=c[f+(d>>>10<<2)>>2]|0;if(g>>>0>9){h=a[g+(e&1023^1)|0]|0}else{h=gj[c[f+196608+(g<<2)>>2]&4095](d)|0}d=h&255;h=c[b>>2]|0;g=h&255;f=g+d|0;c[2276075]=f;c[2276077]=(f^d)&(f^g);c[2276078]=f;c[2276074]=f;f=h+d&255;c[2276076]=f;c[b>>2]=c[b>>2]&-256|f;return}function wU(){var b=0,d=0,e=0,f=0,g=0,h=0;b=c[2276069]|0;d=9104156+((b>>>9&7)<<2)|0;e=9104156+((b&7|8)<<2)|0;b=(c[e>>2]|0)-1|0;c[e>>2]=b;e=c[2276085]&b;b=e&16777215;f=c[2112932]|0;g=c[f+(b>>>10<<2)>>2]|0;if(g>>>0>9){h=a[g+(e&1023^1)|0]|0}else{h=gj[c[f+196608+(g<<2)>>2]&4095](b)|0}b=h&255;h=c[d>>2]|0;g=h&255;f=g+b|0;c[2276075]=f;c[2276077]=(f^b)&(f^g);c[2276078]=f;c[2276074]=f;f=h+b&255;c[2276076]=f;c[d>>2]=c[d>>2]&-256|f;return}function wV(){var b=0,d=0,e=0,f=0,g=0,h=0;b=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;d=(c[2276054]|0)-2|0;c[2276054]=d;e=c[2276085]&d;d=e&16777215;f=c[2112932]|0;g=c[f+(d>>>10<<2)>>2]|0;if(g>>>0>9){h=a[g+(e&1023^1)|0]|0}else{h=gj[c[f+196608+(g<<2)>>2]&4095](d)|0}d=h&255;h=c[b>>2]|0;g=h&255;f=g+d|0;c[2276075]=f;c[2276077]=(f^d)&(f^g);c[2276078]=f;c[2276074]=f;f=h+d&255;c[2276076]=f;c[b>>2]=c[b>>2]&-256|f;return}function wW(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;b=c[2276069]|0;e=9104156+((b>>>9&7)<<2)|0;f=c[9104156+((b&7|8)<<2)>>2]|0;b=c[2276056]|0;g=b&-4;if((g|0)==(c[2276083]|0)){h=b;i=c[2276084]|0}else{c[2276083]=g;j=c[2276085]&g;g=j&16777212;k=c[2112932]|0;l=c[k+((g>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=j&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b}else{b=gj[c[k+196768+(l<<2)>>2]&4095](g)|0;n=b;o=c[2276056]|0}c[2276084]=n;h=o;i=n}c[2276056]=h+2;n=(i>>>((h<<3&16^16)>>>0)<<16>>16)+f&c[2276085];f=n&16777215;h=c[2112932]|0;i=c[h+(f>>>10<<2)>>2]|0;if(i>>>0>9){p=a[i+(n&1023^1)|0]|0;q=p&255;r=c[e>>2]|0;s=r&255;t=s+q|0;c[2276075]=t;u=t^q;v=t^s;w=u&v;c[2276077]=w;c[2276078]=t;c[2276074]=t;x=r+q|0;y=x&255;c[2276076]=y;z=c[e>>2]|0;A=z&-256;B=A|y;c[e>>2]=B;return}else{p=gj[c[h+196608+(i<<2)>>2]&4095](f)|0;q=p&255;r=c[e>>2]|0;s=r&255;t=s+q|0;c[2276075]=t;u=t^q;v=t^s;w=u&v;c[2276077]=w;c[2276078]=t;c[2276074]=t;x=r+q|0;y=x&255;c[2276076]=y;z=c[e>>2]|0;A=z&-256;B=A|y;c[e>>2]=B;return}}function wX(){var b=0,d=0,e=0,f=0,g=0,h=0;b=c[2276069]|0;d=9104156+((b>>>9&7)<<2)|0;e=xw(c[9104156+((b&7|8)<<2)>>2]|0)|0;b=c[2276085]&e;e=b&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=a[g+(b&1023^1)|0]|0}else{h=gj[c[f+196608+(g<<2)>>2]&4095](e)|0}e=h&255;h=c[d>>2]|0;g=h&255;f=g+e|0;c[2276075]=f;c[2276077]=(f^e)&(f^g);c[2276078]=f;c[2276074]=f;f=h+e&255;c[2276076]=f;c[d>>2]=c[d>>2]&-256|f;return}function wY(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;b=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=h>>>((g<<3&16^16)>>>0)<<16>>16&c[2276085];g=m&16777215;h=c[2112932]|0;n=c[h+(g>>>10<<2)>>2]|0;if(n>>>0>9){o=a[n+(m&1023^1)|0]|0;p=o&255;q=c[b>>2]|0;r=q&255;s=r+p|0;c[2276075]=s;t=s^p;u=s^r;v=t&u;c[2276077]=v;c[2276078]=s;c[2276074]=s;w=q+p|0;x=w&255;c[2276076]=x;y=c[b>>2]|0;z=y&-256;A=z|x;c[b>>2]=A;return}else{o=gj[c[h+196608+(n<<2)>>2]&4095](g)|0;p=o&255;q=c[b>>2]|0;r=q&255;s=r+p|0;c[2276075]=s;t=s^p;u=s^r;v=t&u;c[2276077]=v;c[2276078]=s;c[2276074]=s;w=q+p|0;x=w&255;c[2276076]=x;y=c[b>>2]|0;z=y&-256;A=z|x;c[b>>2]=A;return}}function wZ(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;b=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=f;i=c[2276084]|0}else{c[2276083]=f;j=c[2276085]&f;k=j&16777212;l=c[2112932]|0;m=c[l+((k>>>10|32768)<<2)>>2]|0;if(m>>>0>9){n=j&1020;o=(d[m+(n|3)|0]|0)<<8|(d[m+(n|2)|0]|0)|((d[m+(n|1)|0]|0)<<8|(d[m+n|0]|0))<<16;p=e;q=f}else{f=gj[c[l+196768+(m<<2)>>2]&4095](k)|0;o=f;p=c[2276056]|0;q=c[2276083]|0}c[2276084]=o;g=p;h=q;i=o}o=g+2|0;c[2276056]=o;g=o&-4;if((g|0)==(h|0)){r=i;s=o}else{c[2276083]=g;h=c[2276085]&g;g=h&16777212;q=c[2112932]|0;p=c[q+((g>>>10|32768)<<2)>>2]|0;if(p>>>0>9){f=h&1020;t=(d[p+(f|3)|0]|0)<<8|(d[p+(f|2)|0]|0)|((d[p+(f|1)|0]|0)<<8|(d[p+f|0]|0))<<16;u=o}else{o=gj[c[q+196768+(p<<2)>>2]&4095](g)|0;t=o;u=c[2276056]|0}c[2276084]=t;r=t>>>16|i<<16;s=u}c[2276056]=s+2;s=c[2276085]&r;r=s&16777215;u=c[2112932]|0;i=c[u+(r>>>10<<2)>>2]|0;if(i>>>0>9){v=a[i+(s&1023^1)|0]|0;w=v&255;x=c[b>>2]|0;y=x&255;z=y+w|0;c[2276075]=z;A=z^w;B=z^y;C=A&B;c[2276077]=C;c[2276078]=z;c[2276074]=z;D=x+w|0;E=D&255;c[2276076]=E;F=c[b>>2]|0;G=F&-256;H=G|E;c[b>>2]=H;return}else{v=gj[c[u+196608+(i<<2)>>2]&4095](r)|0;w=v&255;x=c[b>>2]|0;y=x&255;z=y+w|0;c[2276075]=z;A=z^w;B=z^y;C=A&B;c[2276077]=C;c[2276078]=z;c[2276074]=z;D=x+w|0;E=D&255;c[2276076]=E;F=c[b>>2]|0;G=F&-256;H=G|E;c[b>>2]=H;return}}function w_(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;b=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{l=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=l;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=(h>>>((g<<3&16^16)>>>0)<<16>>16)+e|0;e=m&16777215;g=c[2112932]|0;h=c[g+((e>>>10|32768)<<2)>>2]|0;if(h>>>0>9){o=a[h+(m&1023^1)|0]|0;p=o&255;q=c[b>>2]|0;r=q&255;s=r+p|0;c[2276075]=s;t=s^p;u=s^r;v=t&u;c[2276077]=v;c[2276078]=s;c[2276074]=s;w=q+p|0;x=w&255;c[2276076]=x;y=c[b>>2]|0;z=y&-256;A=z|x;c[b>>2]=A;return}else{o=gj[c[g+196608+(h<<2)>>2]&4095](e)|0;p=o&255;q=c[b>>2]|0;r=q&255;s=r+p|0;c[2276075]=s;t=s^p;u=s^r;v=t&u;c[2276077]=v;c[2276078]=s;c[2276074]=s;w=q+p|0;x=w&255;c[2276076]=x;y=c[b>>2]|0;z=y&-256;A=z|x;c[b>>2]=A;return}}function w$(){var b=0,d=0,e=0,f=0,g=0,h=0;b=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;d=xw(c[2276056]|0)|0;e=d&16777215;f=c[2112932]|0;g=c[f+((e>>>10|32768)<<2)>>2]|0;if(g>>>0>9){h=a[g+(d&1023^1)|0]|0}else{h=gj[c[f+196608+(g<<2)>>2]&4095](e)|0}e=h&255;h=c[b>>2]|0;g=h&255;f=g+e|0;c[2276075]=f;c[2276077]=(f^e)&(f^g);c[2276078]=f;c[2276074]=f;f=h+e&255;c[2276076]=f;c[b>>2]=c[b>>2]&-256|f;return}function w0(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0);f=l&255;g=c[a>>2]|0;m=g&255;b=f+m|0;c[2276075]=b;c[2276077]=(b^f)&(b^m);c[2276078]=b;c[2276074]=b;b=l+g&255;c[2276076]=b;c[a>>2]=b|c[a>>2]&-256;return}function w1(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0;a=c[2276069]|0;b=9104156+((a>>>9&7)<<2)|0;d=c[9104156+((a&7)<<2)>>2]|0;a=d&65535;e=c[b>>2]|0;f=e&65535;g=f+a|0;h=g>>>8;c[2276075]=h;c[2276077]=((g^a)&(g^f))>>>8;c[2276078]=h;c[2276074]=h;h=e+d&65535;c[2276076]=h;c[b>>2]=c[b>>2]&-65536|h;return}function w2(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0;a=c[2276069]|0;b=9104156+((a>>>9&7)<<2)|0;d=c[9104156+((a&7|8)<<2)>>2]|0;a=d&65535;e=c[b>>2]|0;f=e&65535;g=f+a|0;h=g>>>8;c[2276075]=h;c[2276077]=((g^a)&(g^f))>>>8;c[2276078]=h;c[2276074]=h;h=e+d&65535;c[2276076]=h;c[b>>2]=c[b>>2]&-65536|h;return}function w3(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0;a=c[2276069]|0;b=9104156+((a>>>9&7)<<2)|0;e=c[2276085]&c[9104156+((a&7|8)<<2)>>2];a=e&16777215;f=c[2112932]|0;g=c[f+(a>>>10<<2)>>2]|0;if(g>>>0>9){h=e&1023;i=(d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0)}else{i=gj[c[f+196688+(g<<2)>>2]&4095](a)|0}a=i&65535;i=c[b>>2]|0;g=i&65535;f=g+a|0;h=f>>>8;c[2276075]=h;c[2276077]=((f^a)&(f^g))>>>8;c[2276078]=h;c[2276074]=h;h=i+a&65535;c[2276076]=h;c[b>>2]=c[b>>2]&-65536|h;return}function w4(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0;a=c[2276069]|0;b=9104156+((a>>>9&7)<<2)|0;e=9104156+((a&7|8)<<2)|0;a=c[e>>2]|0;c[e>>2]=a+2;e=c[2276085]&a;a=e&16777215;f=c[2112932]|0;g=c[f+(a>>>10<<2)>>2]|0;if(g>>>0>9){h=e&1023;i=(d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0)}else{i=gj[c[f+196688+(g<<2)>>2]&4095](a)|0}a=i&65535;i=c[b>>2]|0;g=i&65535;f=g+a|0;h=f>>>8;c[2276075]=h;c[2276077]=((f^a)&(f^g))>>>8;c[2276078]=h;c[2276074]=h;h=i+a&65535;c[2276076]=h;c[b>>2]=c[b>>2]&-65536|h;return}function w5(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0;a=c[2276069]|0;b=9104156+((a>>>9&7)<<2)|0;e=9104156+((a&7|8)<<2)|0;a=(c[e>>2]|0)-2|0;c[e>>2]=a;e=c[2276085]&a;a=e&16777215;f=c[2112932]|0;g=c[f+(a>>>10<<2)>>2]|0;if(g>>>0>9){h=e&1023;i=(d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0)}else{i=gj[c[f+196688+(g<<2)>>2]&4095](a)|0}a=i&65535;i=c[b>>2]|0;g=i&65535;f=g+a|0;h=f>>>8;c[2276075]=h;c[2276077]=((f^a)&(f^g))>>>8;c[2276078]=h;c[2276074]=h;h=i+a&65535;c[2276076]=h;c[b>>2]=c[b>>2]&-65536|h;return}function w6(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;a=c[2276069]|0;b=9104156+((a>>>9&7)<<2)|0;e=c[9104156+((a&7|8)<<2)>>2]|0;a=c[2276056]|0;f=a&-4;if((f|0)==(c[2276083]|0)){g=a;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a}else{a=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=a;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=(h>>>((g<<3&16^16)>>>0)<<16>>16)+e&c[2276085];e=m&16777215;g=c[2112932]|0;h=c[g+(e>>>10<<2)>>2]|0;if(h>>>0>9){n=m&1023;o=(d[h+(n+1)|0]|0)<<8|(d[h+n|0]|0);p=o&65535;q=c[b>>2]|0;r=q&65535;s=r+p|0;t=s>>>8;c[2276075]=t;u=s^p;v=s^r;w=u&v;x=w>>>8;c[2276077]=x;c[2276078]=t;c[2276074]=t;y=q+p|0;z=y&65535;c[2276076]=z;A=c[b>>2]|0;B=A&-65536;C=B|z;c[b>>2]=C;return}else{o=gj[c[g+196688+(h<<2)>>2]&4095](e)|0;p=o&65535;q=c[b>>2]|0;r=q&65535;s=r+p|0;t=s>>>8;c[2276075]=t;u=s^p;v=s^r;w=u&v;x=w>>>8;c[2276077]=x;c[2276078]=t;c[2276074]=t;y=q+p|0;z=y&65535;c[2276076]=z;A=c[b>>2]|0;B=A&-65536;C=B|z;c[b>>2]=C;return}}function w7(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0;a=c[2276069]|0;b=9104156+((a>>>9&7)<<2)|0;e=xw(c[9104156+((a&7|8)<<2)>>2]|0)|0;a=c[2276085]&e;e=a&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=a&1023;i=(d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0)}else{i=gj[c[f+196688+(g<<2)>>2]&4095](e)|0}e=i&65535;i=c[b>>2]|0;g=i&65535;f=g+e|0;h=f>>>8;c[2276075]=h;c[2276077]=((f^e)&(f^g))>>>8;c[2276078]=h;c[2276074]=h;h=i+e&65535;c[2276076]=h;c[b>>2]=c[b>>2]&-65536|h;return}function w8(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;a=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)<<16>>16&c[2276085];f=l&16777215;g=c[2112932]|0;m=c[g+(f>>>10<<2)>>2]|0;if(m>>>0>9){b=l&1023;n=(d[m+(b+1)|0]|0)<<8|(d[m+b|0]|0);o=n&65535;p=c[a>>2]|0;q=p&65535;r=q+o|0;s=r>>>8;c[2276075]=s;t=r^o;u=r^q;v=t&u;w=v>>>8;c[2276077]=w;c[2276078]=s;c[2276074]=s;x=p+o|0;y=x&65535;c[2276076]=y;z=c[a>>2]|0;A=z&-65536;B=A|y;c[a>>2]=B;return}else{n=gj[c[g+196688+(m<<2)>>2]&4095](f)|0;o=n&65535;p=c[a>>2]|0;q=p&65535;r=q+o|0;s=r>>>8;c[2276075]=s;t=r^o;u=r^q;v=t&u;w=v>>>8;c[2276077]=w;c[2276078]=s;c[2276074]=s;x=p+o|0;y=x&65535;c[2276076]=y;z=c[a>>2]|0;A=z&-65536;B=A|y;c[a>>2]=B;return}}function w9(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;a=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[2276085]&q;q=r&16777215;t=c[2112932]|0;h=c[t+(q>>>10<<2)>>2]|0;if(h>>>0>9){s=r&1023;u=(d[h+(s+1)|0]|0)<<8|(d[h+s|0]|0);v=u&65535;w=c[a>>2]|0;x=w&65535;y=x+v|0;z=y>>>8;c[2276075]=z;A=y^v;B=y^x;C=A&B;D=C>>>8;c[2276077]=D;c[2276078]=z;c[2276074]=z;E=w+v|0;F=E&65535;c[2276076]=F;G=c[a>>2]|0;H=G&-65536;I=H|F;c[a>>2]=I;return}else{u=gj[c[t+196688+(h<<2)>>2]&4095](q)|0;v=u&65535;w=c[a>>2]|0;x=w&65535;y=x+v|0;z=y>>>8;c[2276075]=z;A=y^v;B=y^x;C=A&B;D=C>>>8;c[2276077]=D;c[2276078]=z;c[2276074]=z;E=w+v|0;F=E&65535;c[2276076]=F;G=c[a>>2]|0;H=G&-65536;I=H|F;c[a>>2]=I;return}}function xa(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;a=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{k=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=k;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=(g>>>((f<<3&16^16)>>>0)<<16>>16)+b|0;b=l&16777215;f=c[2112932]|0;g=c[f+((b>>>10|32768)<<2)>>2]|0;if(g>>>0>9){m=l&1023;n=(d[g+(m+1)|0]|0)<<8|(d[g+m|0]|0);o=n&65535;p=c[a>>2]|0;q=p&65535;r=q+o|0;s=r>>>8;c[2276075]=s;t=r^o;u=r^q;v=t&u;w=v>>>8;c[2276077]=w;c[2276078]=s;c[2276074]=s;x=p+o|0;y=x&65535;c[2276076]=y;z=c[a>>2]|0;A=z&-65536;B=A|y;c[a>>2]=B;return}else{n=gj[c[f+196688+(g<<2)>>2]&4095](b)|0;o=n&65535;p=c[a>>2]|0;q=p&65535;r=q+o|0;s=r>>>8;c[2276075]=s;t=r^o;u=r^q;v=t&u;w=v>>>8;c[2276077]=w;c[2276078]=s;c[2276074]=s;x=p+o|0;y=x&65535;c[2276076]=y;z=c[a>>2]|0;A=z&-65536;B=A|y;c[a>>2]=B;return}}function xb(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0;a=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;b=xw(c[2276056]|0)|0;e=b&16777215;f=c[2112932]|0;g=c[f+((e>>>10|32768)<<2)>>2]|0;if(g>>>0>9){h=b&1023;i=(d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0)}else{i=gj[c[f+196688+(g<<2)>>2]&4095](e)|0}e=i&65535;i=c[a>>2]|0;g=i&65535;f=g+e|0;h=f>>>8;c[2276075]=h;c[2276077]=((f^e)&(f^g))>>>8;c[2276078]=h;c[2276074]=h;h=i+e&65535;c[2276076]=h;c[a>>2]=c[a>>2]&-65536|h;return}function xc(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0);f=l&65535;g=c[a>>2]|0;m=g&65535;b=f+m|0;e=b>>>8;c[2276075]=e;c[2276077]=((b^f)&(b^m))>>>8;c[2276078]=e;c[2276074]=e;e=l+g&65535;c[2276076]=e;c[a>>2]=e|c[a>>2]&-65536;return}function xd(){var a=0,b=0,d=0,e=0,f=0;a=c[2276069]|0;b=9104156+((a>>>9&7)<<2)|0;d=c[9104156+((a&7)<<2)>>2]|0;a=c[b>>2]|0;e=a+d|0;c[2276075]=e>>>24;c[2276077]=((e^d)&(e^a))>>>24;f=((e^-8388608)&(a|d)|a&d)>>>23;c[2276078]=f;c[2276074]=f;c[2276076]=e;c[b>>2]=e;return}function xe(){var a=0,b=0,d=0,e=0,f=0;a=c[2276069]|0;b=9104156+((a>>>9&7)<<2)|0;d=c[9104156+((a&7|8)<<2)>>2]|0;a=c[b>>2]|0;e=a+d|0;c[2276075]=e>>>24;c[2276077]=((e^d)&(e^a))>>>24;f=((e^-8388608)&(a|d)|a&d)>>>23;c[2276078]=f;c[2276074]=f;c[2276076]=e;c[b>>2]=e;return}function xf(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0;a=c[2276069]|0;b=9104156+((a>>>9&7)<<2)|0;e=c[2276085]&c[9104156+((a&7|8)<<2)>>2];a=e&16777215;f=c[2112932]|0;g=c[f+(a>>>10<<2)>>2]|0;if(g>>>0>9){h=e&1023;i=(d[g+(h+3)|0]|0)<<8|(d[g+(h+2)|0]|0)|((d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0))<<16}else{i=gj[c[f+196768+(g<<2)>>2]&4095](a)|0}a=c[b>>2]|0;g=a+i|0;c[2276075]=g>>>24;c[2276077]=((g^i)&(g^a))>>>24;f=((g^-8388608)&(a|i)|a&i)>>>23;c[2276078]=f;c[2276074]=f;c[2276076]=g;c[b>>2]=g;return}function xg(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0;a=c[2276069]|0;b=9104156+((a>>>9&7)<<2)|0;e=9104156+((a&7|8)<<2)|0;a=c[e>>2]|0;c[e>>2]=a+4;e=c[2276085]&a;a=e&16777215;f=c[2112932]|0;g=c[f+(a>>>10<<2)>>2]|0;if(g>>>0>9){h=e&1023;i=(d[g+(h+3)|0]|0)<<8|(d[g+(h+2)|0]|0)|((d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0))<<16}else{i=gj[c[f+196768+(g<<2)>>2]&4095](a)|0}a=c[b>>2]|0;g=a+i|0;c[2276075]=g>>>24;c[2276077]=((g^i)&(g^a))>>>24;f=((g^-8388608)&(a|i)|a&i)>>>23;c[2276078]=f;c[2276074]=f;c[2276076]=g;c[b>>2]=g;return}function xh(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0;a=c[2276069]|0;b=9104156+((a>>>9&7)<<2)|0;e=9104156+((a&7|8)<<2)|0;a=(c[e>>2]|0)-4|0;c[e>>2]=a;e=c[2276085]&a;a=e&16777215;f=c[2112932]|0;g=c[f+(a>>>10<<2)>>2]|0;if(g>>>0>9){h=e&1023;i=(d[g+(h+3)|0]|0)<<8|(d[g+(h+2)|0]|0)|((d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0))<<16}else{i=gj[c[f+196768+(g<<2)>>2]&4095](a)|0}a=c[b>>2]|0;g=a+i|0;c[2276075]=g>>>24;c[2276077]=((g^i)&(g^a))>>>24;f=((g^-8388608)&(a|i)|a&i)>>>23;c[2276078]=f;c[2276074]=f;c[2276076]=g;c[b>>2]=g;return}function xi(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;a=c[2276069]|0;b=9104156+((a>>>9&7)<<2)|0;e=c[9104156+((a&7|8)<<2)>>2]|0;a=c[2276056]|0;f=a&-4;if((f|0)==(c[2276083]|0)){g=a;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a}else{a=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=a;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=(h>>>((g<<3&16^16)>>>0)<<16>>16)+e&c[2276085];e=m&16777215;g=c[2112932]|0;h=c[g+(e>>>10<<2)>>2]|0;if(h>>>0>9){n=m&1023;o=(d[h+(n+3)|0]|0)<<8|(d[h+(n+2)|0]|0)|((d[h+(n+1)|0]|0)<<8|(d[h+n|0]|0))<<16;p=c[b>>2]|0;q=p+o|0;r=q>>>24;c[2276075]=r;s=q^o;t=q^p;u=s&t;v=u>>>24;c[2276077]=v;w=p&o;x=q^-8388608;y=p|o;z=x&y;A=z|w;B=A>>>23;c[2276078]=B;c[2276074]=B;c[2276076]=q;c[b>>2]=q;return}else{o=gj[c[g+196768+(h<<2)>>2]&4095](e)|0;p=c[b>>2]|0;q=p+o|0;r=q>>>24;c[2276075]=r;s=q^o;t=q^p;u=s&t;v=u>>>24;c[2276077]=v;w=p&o;x=q^-8388608;y=p|o;z=x&y;A=z|w;B=A>>>23;c[2276078]=B;c[2276074]=B;c[2276076]=q;c[b>>2]=q;return}}function xj(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0;a=c[2276069]|0;b=9104156+((a>>>9&7)<<2)|0;e=xw(c[9104156+((a&7|8)<<2)>>2]|0)|0;a=c[2276085]&e;e=a&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=a&1023;i=(d[g+(h+3)|0]|0)<<8|(d[g+(h+2)|0]|0)|((d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0))<<16}else{i=gj[c[f+196768+(g<<2)>>2]&4095](e)|0}e=c[b>>2]|0;g=e+i|0;c[2276075]=g>>>24;c[2276077]=((g^i)&(g^e))>>>24;f=((g^-8388608)&(e|i)|e&i)>>>23;c[2276078]=f;c[2276074]=f;c[2276076]=g;c[b>>2]=g;return}function xk(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;a=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)<<16>>16&c[2276085];f=l&16777215;g=c[2112932]|0;m=c[g+(f>>>10<<2)>>2]|0;if(m>>>0>9){b=l&1023;n=(d[m+(b+3)|0]|0)<<8|(d[m+(b+2)|0]|0)|((d[m+(b+1)|0]|0)<<8|(d[m+b|0]|0))<<16;o=c[a>>2]|0;p=o+n|0;q=p>>>24;c[2276075]=q;r=p^n;s=p^o;t=r&s;u=t>>>24;c[2276077]=u;v=o&n;w=p^-8388608;x=o|n;y=w&x;z=y|v;A=z>>>23;c[2276078]=A;c[2276074]=A;c[2276076]=p;c[a>>2]=p;return}else{n=gj[c[g+196768+(m<<2)>>2]&4095](f)|0;o=c[a>>2]|0;p=o+n|0;q=p>>>24;c[2276075]=q;r=p^n;s=p^o;t=r&s;u=t>>>24;c[2276077]=u;v=o&n;w=p^-8388608;x=o|n;y=w&x;z=y|v;A=z>>>23;c[2276078]=A;c[2276074]=A;c[2276076]=p;c[a>>2]=p;return}}function xl(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;a=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[2276085]&q;q=r&16777215;t=c[2112932]|0;h=c[t+(q>>>10<<2)>>2]|0;if(h>>>0>9){s=r&1023;u=(d[h+(s+3)|0]|0)<<8|(d[h+(s+2)|0]|0)|((d[h+(s+1)|0]|0)<<8|(d[h+s|0]|0))<<16;v=c[a>>2]|0;w=v+u|0;x=w>>>24;c[2276075]=x;y=w^u;z=w^v;A=y&z;B=A>>>24;c[2276077]=B;C=v&u;D=w^-8388608;E=v|u;F=D&E;G=F|C;H=G>>>23;c[2276078]=H;c[2276074]=H;c[2276076]=w;c[a>>2]=w;return}else{u=gj[c[t+196768+(h<<2)>>2]&4095](q)|0;v=c[a>>2]|0;w=v+u|0;x=w>>>24;c[2276075]=x;y=w^u;z=w^v;A=y&z;B=A>>>24;c[2276077]=B;C=v&u;D=w^-8388608;E=v|u;F=D&E;G=F|C;H=G>>>23;c[2276078]=H;c[2276074]=H;c[2276076]=w;c[a>>2]=w;return}}function xm(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;a=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{k=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=k;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=(g>>>((f<<3&16^16)>>>0)<<16>>16)+b|0;b=l&16777215;f=c[2112932]|0;g=c[f+((b>>>10|32768)<<2)>>2]|0;if(g>>>0>9){m=l&1023;n=(d[g+(m+3)|0]|0)<<8|(d[g+(m+2)|0]|0)|((d[g+(m+1)|0]|0)<<8|(d[g+m|0]|0))<<16;o=c[a>>2]|0;p=o+n|0;q=p>>>24;c[2276075]=q;r=p^n;s=p^o;t=r&s;u=t>>>24;c[2276077]=u;v=o&n;w=p^-8388608;x=o|n;y=w&x;z=y|v;A=z>>>23;c[2276078]=A;c[2276074]=A;c[2276076]=p;c[a>>2]=p;return}else{n=gj[c[f+196768+(g<<2)>>2]&4095](b)|0;o=c[a>>2]|0;p=o+n|0;q=p>>>24;c[2276075]=q;r=p^n;s=p^o;t=r&s;u=t>>>24;c[2276077]=u;v=o&n;w=p^-8388608;x=o|n;y=w&x;z=y|v;A=z>>>23;c[2276078]=A;c[2276074]=A;c[2276076]=p;c[a>>2]=p;return}}function xn(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0;a=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;b=xw(c[2276056]|0)|0;e=b&16777215;f=c[2112932]|0;g=c[f+((e>>>10|32768)<<2)>>2]|0;if(g>>>0>9){h=b&1023;i=(d[g+(h+3)|0]|0)<<8|(d[g+(h+2)|0]|0)|((d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0))<<16}else{i=gj[c[f+196768+(g<<2)>>2]&4095](e)|0}e=c[a>>2]|0;g=e+i|0;c[2276075]=g>>>24;c[2276077]=((g^i)&(g^e))>>>24;f=((g^-8388608)&(e|i)|e&i)>>>23;c[2276078]=f;c[2276074]=f;c[2276076]=g;c[a>>2]=g;return}function xo(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;a=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n;s=r+2|0;c[2276056]=s;t=c[a>>2]|0;u=t+q|0;v=u>>>24;c[2276075]=v;w=u^q;x=u^t;y=w&x;z=y>>>24;c[2276077]=z;A=t&q;B=u^-8388608;C=t|q;D=B&C;E=D|A;F=E>>>23;c[2276078]=F;c[2276074]=F;c[2276076]=u;c[a>>2]=u;return}c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;G=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;H=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;G=n;H=c[2276056]|0}c[2276084]=G;q=G>>>16|h<<16;r=H;s=r+2|0;c[2276056]=s;t=c[a>>2]|0;u=t+q|0;v=u>>>24;c[2276075]=v;w=u^q;x=u^t;y=w&x;z=y>>>24;c[2276077]=z;A=t&q;B=u^-8388608;C=t|q;D=B&C;E=D|A;F=E>>>23;c[2276078]=F;c[2276074]=F;c[2276076]=u;c[a>>2]=u;return}function xp(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=c[2276069]|0;d=c[9104156+((b&7|8)<<2)>>2]|0;e=c[9104156+((b>>>9&7)<<2)>>2]|0;b=e&255;f=c[2276085]|0;g=f&d;h=g&16777215;i=c[2112932]|0;j=c[i+(h>>>10<<2)>>2]|0;if(j>>>0>9){k=a[j+(g&1023^1)|0]|0;l=f;m=i}else{f=gj[c[i+196608+(j<<2)>>2]&4095](h)|0;k=f;l=c[2276085]|0;m=c[2112932]|0}f=k&255;k=f+b|0;c[2276075]=k;c[2276077]=(k^b)&(k^f);c[2276078]=k;c[2276074]=k;k=f+e|0;c[2276076]=k&255;e=l&d;d=k&255;k=e&16777215;l=c[m+((k>>>10|16384)<<2)>>2]|0;if(l>>>0>9){a[l+(e&1023^1)|0]=d;return}else{gg[c[m+196648+(l<<2)>>2]&4095](k,d);return}}function xq(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;b=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;e=b&255;f=c[2276085]|0;g=f&d;h=g&16777215;i=c[2112932]|0;j=c[i+(h>>>10<<2)>>2]|0;if(j>>>0>9){k=a[j+(g&1023^1)|0]|0;l=f;m=i}else{f=gj[c[i+196608+(j<<2)>>2]&4095](h)|0;k=f;l=c[2276085]|0;m=c[2112932]|0}f=k&255;k=f+e|0;c[2276075]=k;c[2276077]=(k^e)&(k^f);c[2276078]=k;c[2276074]=k;k=f+b|0;c[2276076]=k&255;b=l&d;d=k&255;k=b&16777215;l=c[m+((k>>>10|16384)<<2)>>2]|0;if(l>>>0>9){a[l+(b&1023^1)|0]=d;return}else{gg[c[m+196648+(l<<2)>>2]&4095](k,d);return}}function xr(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=c[2276054]|0;c[2276054]=b+2;d=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;e=d&255;f=c[2276085]|0;g=f&b;h=g&16777215;i=c[2112932]|0;j=c[i+(h>>>10<<2)>>2]|0;if(j>>>0>9){k=a[j+(g&1023^1)|0]|0;l=f;m=i}else{f=gj[c[i+196608+(j<<2)>>2]&4095](h)|0;k=f;l=c[2276085]|0;m=c[2112932]|0}f=k&255;k=f+e|0;c[2276075]=k;c[2276077]=(k^e)&(k^f);c[2276078]=k;c[2276074]=k;k=f+d|0;c[2276076]=k&255;d=l&b;b=k&255;k=d&16777215;l=c[m+((k>>>10|16384)<<2)>>2]|0;if(l>>>0>9){a[l+(d&1023^1)|0]=b;return}else{gg[c[m+196648+(l<<2)>>2]&4095](k,b);return}}function xs(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;b=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;e=b&255;f=c[2276085]|0;g=f&d;h=g&16777215;i=c[2112932]|0;j=c[i+(h>>>10<<2)>>2]|0;if(j>>>0>9){k=a[j+(g&1023^1)|0]|0;l=f;m=i}else{f=gj[c[i+196608+(j<<2)>>2]&4095](h)|0;k=f;l=c[2276085]|0;m=c[2112932]|0}f=k&255;k=f+e|0;c[2276075]=k;c[2276077]=(k^e)&(k^f);c[2276078]=k;c[2276074]=k;k=f+b|0;c[2276076]=k&255;b=l&d;d=k&255;k=b&16777215;l=c[m+((k>>>10|16384)<<2)>>2]|0;if(l>>>0>9){a[l+(b&1023^1)|0]=d;return}else{gg[c[m+196648+(l<<2)>>2]&4095](k,d);return}}function xt(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=(c[2276054]|0)-2|0;c[2276054]=b;d=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;e=d&255;f=c[2276085]|0;g=f&b;h=g&16777215;i=c[2112932]|0;j=c[i+(h>>>10<<2)>>2]|0;if(j>>>0>9){k=a[j+(g&1023^1)|0]|0;l=f;m=i}else{f=gj[c[i+196608+(j<<2)>>2]&4095](h)|0;k=f;l=c[2276085]|0;m=c[2112932]|0}f=k&255;k=f+e|0;c[2276075]=k;c[2276077]=(k^e)&(k^f);c[2276078]=k;c[2276074]=k;k=f+d|0;c[2276076]=k&255;d=l&b;b=k&255;k=d&16777215;l=c[m+((k>>>10|16384)<<2)>>2]|0;if(l>>>0>9){a[l+(d&1023^1)|0]=b;return}else{gg[c[m+196648+(l<<2)>>2]&4095](k,b);return}}function xu(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=c[2276069]|0;e=c[9104156+((b&7|8)<<2)>>2]|0;f=c[2276056]|0;g=f&-4;if((g|0)==(c[2276083]|0)){h=f;i=c[2276084]|0;j=b}else{c[2276083]=g;k=c[2276085]&g;g=k&16777212;l=c[2112932]|0;m=c[l+((g>>>10|32768)<<2)>>2]|0;if(m>>>0>9){n=k&1020;o=(d[m+(n|3)|0]|0)<<8|(d[m+(n|2)|0]|0)|((d[m+(n|1)|0]|0)<<8|(d[m+n|0]|0))<<16;p=f;q=b}else{b=gj[c[l+196768+(m<<2)>>2]&4095](g)|0;o=b;p=c[2276056]|0;q=c[2276069]|0}c[2276084]=o;h=p;i=o;j=q}c[2276056]=h+2;q=(i>>>((h<<3&16^16)>>>0)<<16>>16)+e|0;e=c[9104156+((j>>>9&7)<<2)>>2]|0;j=e&255;h=c[2276085]|0;i=q&h;o=i&16777215;p=c[2112932]|0;b=c[p+(o>>>10<<2)>>2]|0;if(b>>>0>9){r=a[b+(i&1023^1)|0]|0;s=h;t=p}else{h=gj[c[p+196608+(b<<2)>>2]&4095](o)|0;r=h;s=c[2276085]|0;t=c[2112932]|0}h=r&255;r=h+j|0;c[2276075]=r;c[2276077]=(r^j)&(r^h);c[2276078]=r;c[2276074]=r;r=h+e|0;c[2276076]=r&255;e=s&q;q=r&255;r=e&16777215;s=c[t+((r>>>10|16384)<<2)>>2]|0;if(s>>>0>9){a[s+(e&1023^1)|0]=q;return}else{gg[c[t+196648+(s<<2)>>2]&4095](r,q);return}}function xv(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=xw(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;d=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;e=d&255;f=c[2276085]|0;g=f&b;h=g&16777215;i=c[2112932]|0;j=c[i+(h>>>10<<2)>>2]|0;if(j>>>0>9){k=a[j+(g&1023^1)|0]|0;l=f;m=i}else{f=gj[c[i+196608+(j<<2)>>2]&4095](h)|0;k=f;l=c[2276085]|0;m=c[2112932]|0}f=k&255;k=f+e|0;c[2276075]=k;c[2276077]=(k^e)&(k^f);c[2276078]=k;c[2276074]=k;k=f+d|0;c[2276076]=k&255;d=l&b;b=k&255;k=d&16777215;l=c[m+((k>>>10|16384)<<2)>>2]|0;if(l>>>0>9){a[l+(d&1023^1)|0]=b;return}else{gg[c[m+196648+(l<<2)>>2]&4095](k,b);return}}function xw(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}l=f+2|0;c[2276056]=l;m=g>>>((f<<3&16^16)>>>0);f=m&65535;b=c[2276038]|0;if((b&7|0)!=0){e=c[9104156+(f>>>12<<2)>>2]|0;if((m&2048|0)==0){n=e<<16>>16}else{n=e}o=(m<<24>>24)+a+n|0;return o|0}if((m&256|0)==0){n=c[9104156+(f>>>12<<2)>>2]|0;if((m&2048|0)==0){p=n<<16>>16}else{p=n}if((b&24|0)==0){q=p}else{q=p<<(m>>>9&3)}o=(m<<24>>24)+a+q|0;return o|0}c[2276108]=(c[2276108]|0)-(d[11928+(m&63)|0]|0);q=(m&128|0)==0?a:0;if((m&64|0)==0){a=c[9104156+(f>>>12<<2)>>2]|0;if((m&2048|0)==0){r=a<<16>>16}else{r=a}s=r<<(m>>>9&3)}else{s=0}do{if((m&32|0)==0){t=0;u=l;v=g}else{r=l&-4;a=(r|0)==(c[2276083]|0);if((m&16|0)==0){if(a){w=l;x=g}else{c[2276083]=r;f=c[2276085]&r;p=f&16777212;b=c[2112932]|0;n=c[b+((p>>>10|32768)<<2)>>2]|0;if(n>>>0>9){e=f&1020;y=(d[n+(e|3)|0]|0)<<8|(d[n+(e|2)|0]|0)|((d[n+(e|1)|0]|0)<<8|(d[n+e|0]|0))<<16;z=l}else{e=gj[c[b+196768+(n<<2)>>2]&4095](p)|0;y=e;z=c[2276056]|0}c[2276084]=y;w=z;x=y}e=w+2|0;c[2276056]=e;t=x>>>((w<<3&16^16)>>>0)<<16>>16;u=e;v=x;break}if(a){A=l;B=r;C=g}else{c[2276083]=r;a=c[2276085]&r;e=a&16777212;p=c[2112932]|0;n=c[p+((e>>>10|32768)<<2)>>2]|0;if(n>>>0>9){b=a&1020;D=(d[n+(b|3)|0]|0)<<8|(d[n+(b|2)|0]|0)|((d[n+(b|1)|0]|0)<<8|(d[n+b|0]|0))<<16;E=l;F=r}else{r=gj[c[p+196768+(n<<2)>>2]&4095](e)|0;D=r;E=c[2276056]|0;F=c[2276083]|0}c[2276084]=D;A=E;B=F;C=D}r=A+2|0;c[2276056]=r;e=r&-4;if((e|0)==(B|0)){G=C;H=r;I=C}else{c[2276083]=e;n=c[2276085]&e;e=n&16777212;p=c[2112932]|0;b=c[p+((e>>>10|32768)<<2)>>2]|0;if(b>>>0>9){a=n&1020;J=(d[b+(a|3)|0]|0)<<8|(d[b+(a|2)|0]|0)|((d[b+(a|1)|0]|0)<<8|(d[b+a|0]|0))<<16;K=r}else{r=gj[c[p+196768+(b<<2)>>2]&4095](e)|0;J=r;K=c[2276056]|0}c[2276084]=J;G=J>>>16|C<<16;H=K;I=J}r=H+2|0;c[2276056]=r;t=G;u=r;v=I}}while(0);if((m&7|0)==0){o=s+q+t|0;return o|0}do{if((m&2|0)==0){L=0}else{I=u&-4;G=(I|0)==(c[2276083]|0);if((m&1|0)==0){if(G){M=u;N=v}else{c[2276083]=I;H=c[2276085]&I;J=H&16777212;K=c[2112932]|0;C=c[K+((J>>>10|32768)<<2)>>2]|0;if(C>>>0>9){B=H&1020;O=(d[C+(B|3)|0]|0)<<8|(d[C+(B|2)|0]|0)|((d[C+(B|1)|0]|0)<<8|(d[C+B|0]|0))<<16;P=u}else{B=gj[c[K+196768+(C<<2)>>2]&4095](J)|0;O=B;P=c[2276056]|0}c[2276084]=O;M=P;N=O}c[2276056]=M+2;L=N>>>((M<<3&16^16)>>>0)<<16>>16;break}if(G){Q=u;R=I;S=v}else{c[2276083]=I;G=c[2276085]&I;B=G&16777212;J=c[2112932]|0;C=c[J+((B>>>10|32768)<<2)>>2]|0;if(C>>>0>9){K=G&1020;T=(d[C+(K|3)|0]|0)<<8|(d[C+(K|2)|0]|0)|((d[C+(K|1)|0]|0)<<8|(d[C+K|0]|0))<<16;U=u;V=I}else{I=gj[c[J+196768+(C<<2)>>2]&4095](B)|0;T=I;U=c[2276056]|0;V=c[2276083]|0}c[2276084]=T;Q=U;R=V;S=T}I=Q+2|0;c[2276056]=I;B=I&-4;if((B|0)==(R|0)){W=S;X=I}else{c[2276083]=B;C=c[2276085]&B;B=C&16777212;J=c[2112932]|0;K=c[J+((B>>>10|32768)<<2)>>2]|0;if(K>>>0>9){G=C&1020;Y=(d[K+(G|3)|0]|0)<<8|(d[K+(G|2)|0]|0)|((d[K+(G|1)|0]|0)<<8|(d[K+G|0]|0))<<16;Z=I}else{I=gj[c[J+196768+(K<<2)>>2]&4095](B)|0;Y=I;Z=c[2276056]|0}c[2276084]=Y;W=Y>>>16|S<<16;X=Z}c[2276056]=X+2;L=W}}while(0);W=t+q|0;if((m&4|0)==0){m=c[2276085]&W+s;q=m&16777215;t=c[2112932]|0;X=c[t+(q>>>10<<2)>>2]|0;if(X>>>0>9){Z=m&1023;_=(d[X+(Z+3)|0]|0)<<8|(d[X+(Z+2)|0]|0)|((d[X+(Z+1)|0]|0)<<8|(d[X+Z|0]|0))<<16}else{_=gj[c[t+196768+(X<<2)>>2]&4095](q)|0}o=_+L|0;return o|0}else{_=c[2276085]&W;W=_&16777215;q=c[2112932]|0;X=c[q+(W>>>10<<2)>>2]|0;if(X>>>0>9){t=_&1023;$=(d[X+(t+3)|0]|0)<<8|(d[X+(t+2)|0]|0)|((d[X+(t+1)|0]|0)<<8|(d[X+t|0]|0))<<16}else{$=gj[c[q+196768+(X<<2)>>2]&4095](W)|0}o=L+s+$|0;return o|0}return 0}function xx(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)<<16>>16;f=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;g=f&255;m=c[2276085]|0;b=l&m;e=b&16777215;j=c[2112932]|0;i=c[j+(e>>>10<<2)>>2]|0;if(i>>>0>9){n=a[i+(b&1023^1)|0]|0;o=m;p=j}else{m=gj[c[j+196608+(i<<2)>>2]&4095](e)|0;n=m;o=c[2276085]|0;p=c[2112932]|0}m=n&255;n=m+g|0;c[2276075]=n;c[2276077]=(n^g)&(n^m);c[2276078]=n;c[2276074]=n;n=m+f|0;c[2276076]=n&255;f=o&l;l=n&255;n=f&16777215;o=c[p+((n>>>10|16384)<<2)>>2]|0;if(o>>>0>9){a[o+(f&1023^1)|0]=l;return}else{gg[c[p+196648+(o<<2)>>2]&4095](n,l);return}}function xy(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;t=r&255;h=c[2276085]|0;s=h&q;n=s&16777215;f=c[2112932]|0;o=c[f+(n>>>10<<2)>>2]|0;if(o>>>0>9){u=a[o+(s&1023^1)|0]|0;v=h;w=f}else{h=gj[c[f+196608+(o<<2)>>2]&4095](n)|0;u=h;v=c[2276085]|0;w=c[2112932]|0}h=u&255;u=h+t|0;c[2276075]=u;c[2276077]=(u^t)&(u^h);c[2276078]=u;c[2276074]=u;u=h+r|0;c[2276076]=u&255;r=v&q;q=u&255;u=r&16777215;v=c[w+((u>>>10|16384)<<2)>>2]|0;if(v>>>0>9){a[v+(r&1023^1)|0]=q;return}else{gg[c[w+196648+(v<<2)>>2]&4095](u,q);return}}function xz(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=c[2276069]|0;e=c[9104156+((b&7|8)<<2)>>2]|0;f=c[9104156+((b>>>9&7)<<2)>>2]|0;b=f&65535;g=c[2276085]|0;h=g&e;i=h&16777215;j=c[2112932]|0;k=c[j+(i>>>10<<2)>>2]|0;if(k>>>0>9){l=h&1023;m=(d[k+(l+1)|0]|0)<<8|(d[k+l|0]|0);n=g;o=j}else{g=gj[c[j+196688+(k<<2)>>2]&4095](i)|0;m=g;n=c[2276085]|0;o=c[2112932]|0}g=m&65535;m=g+b|0;i=m>>>8;c[2276075]=i;c[2276077]=((m^b)&(m^g))>>>8;c[2276078]=i;c[2276074]=i;i=g+f|0;c[2276076]=i&65535;f=n&e;e=i&65535;n=f&16777215;g=c[o+((n>>>10|16384)<<2)>>2]|0;if(g>>>0>9){m=f&1023;a[g+m|0]=i&255;a[g+(m+1)|0]=(e&65535)>>>8&255;return}else{gg[c[o+196728+(g<<2)>>2]&4095](n,e);return}}function xA(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=c[b>>2]|0;c[b>>2]=e+2;b=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;f=b&65535;g=c[2276085]|0;h=g&e;i=h&16777215;j=c[2112932]|0;k=c[j+(i>>>10<<2)>>2]|0;if(k>>>0>9){l=h&1023;m=(d[k+(l+1)|0]|0)<<8|(d[k+l|0]|0);n=g;o=j}else{g=gj[c[j+196688+(k<<2)>>2]&4095](i)|0;m=g;n=c[2276085]|0;o=c[2112932]|0}g=m&65535;m=g+f|0;i=m>>>8;c[2276075]=i;c[2276077]=((m^f)&(m^g))>>>8;c[2276078]=i;c[2276074]=i;i=g+b|0;c[2276076]=i&65535;b=n&e;e=i&65535;n=b&16777215;g=c[o+((n>>>10|16384)<<2)>>2]|0;if(g>>>0>9){m=b&1023;a[g+m|0]=i&255;a[g+(m+1)|0]=(e&65535)>>>8&255;return}else{gg[c[o+196728+(g<<2)>>2]&4095](n,e);return}}function xB(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=(c[b>>2]|0)-2|0;c[b>>2]=e;b=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;f=b&65535;g=c[2276085]|0;h=g&e;i=h&16777215;j=c[2112932]|0;k=c[j+(i>>>10<<2)>>2]|0;if(k>>>0>9){l=h&1023;m=(d[k+(l+1)|0]|0)<<8|(d[k+l|0]|0);n=g;o=j}else{g=gj[c[j+196688+(k<<2)>>2]&4095](i)|0;m=g;n=c[2276085]|0;o=c[2112932]|0}g=m&65535;m=g+f|0;i=m>>>8;c[2276075]=i;c[2276077]=((m^f)&(m^g))>>>8;c[2276078]=i;c[2276074]=i;i=g+b|0;c[2276076]=i&65535;b=n&e;e=i&65535;n=b&16777215;g=c[o+((n>>>10|16384)<<2)>>2]|0;if(g>>>0>9){m=b&1023;a[g+m|0]=i&255;a[g+(m+1)|0]=(e&65535)>>>8&255;return}else{gg[c[o+196728+(g<<2)>>2]&4095](n,e);return}}function xC(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=c[2276069]|0;e=c[9104156+((b&7|8)<<2)>>2]|0;f=c[2276056]|0;g=f&-4;if((g|0)==(c[2276083]|0)){h=f;i=c[2276084]|0;j=b}else{c[2276083]=g;k=c[2276085]&g;g=k&16777212;l=c[2112932]|0;m=c[l+((g>>>10|32768)<<2)>>2]|0;if(m>>>0>9){n=k&1020;o=(d[m+(n|3)|0]|0)<<8|(d[m+(n|2)|0]|0)|((d[m+(n|1)|0]|0)<<8|(d[m+n|0]|0))<<16;p=f;q=b}else{b=gj[c[l+196768+(m<<2)>>2]&4095](g)|0;o=b;p=c[2276056]|0;q=c[2276069]|0}c[2276084]=o;h=p;i=o;j=q}c[2276056]=h+2;q=(i>>>((h<<3&16^16)>>>0)<<16>>16)+e|0;e=c[9104156+((j>>>9&7)<<2)>>2]|0;j=e&65535;h=c[2276085]|0;i=q&h;o=i&16777215;p=c[2112932]|0;b=c[p+(o>>>10<<2)>>2]|0;if(b>>>0>9){g=i&1023;r=(d[b+(g+1)|0]|0)<<8|(d[b+g|0]|0);s=h;t=p}else{h=gj[c[p+196688+(b<<2)>>2]&4095](o)|0;r=h;s=c[2276085]|0;t=c[2112932]|0}h=r&65535;r=h+j|0;o=r>>>8;c[2276075]=o;c[2276077]=((r^j)&(r^h))>>>8;c[2276078]=o;c[2276074]=o;o=h+e|0;c[2276076]=o&65535;e=s&q;q=o&65535;s=e&16777215;h=c[t+((s>>>10|16384)<<2)>>2]|0;if(h>>>0>9){r=e&1023;a[h+r|0]=o&255;a[h+(r+1)|0]=(q&65535)>>>8&255;return}else{gg[c[t+196728+(h<<2)>>2]&4095](s,q);return}}function xD(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=xw(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;e=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;f=e&65535;g=c[2276085]|0;h=g&b;i=h&16777215;j=c[2112932]|0;k=c[j+(i>>>10<<2)>>2]|0;if(k>>>0>9){l=h&1023;m=(d[k+(l+1)|0]|0)<<8|(d[k+l|0]|0);n=g;o=j}else{g=gj[c[j+196688+(k<<2)>>2]&4095](i)|0;m=g;n=c[2276085]|0;o=c[2112932]|0}g=m&65535;m=g+f|0;i=m>>>8;c[2276075]=i;c[2276077]=((m^f)&(m^g))>>>8;c[2276078]=i;c[2276074]=i;i=g+e|0;c[2276076]=i&65535;e=n&b;b=i&65535;n=e&16777215;g=c[o+((n>>>10|16384)<<2)>>2]|0;if(g>>>0>9){m=e&1023;a[g+m|0]=i&255;a[g+(m+1)|0]=(b&65535)>>>8&255;return}else{gg[c[o+196728+(g<<2)>>2]&4095](n,b);return}}function xE(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)<<16>>16;f=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;g=f&65535;m=c[2276085]|0;b=l&m;e=b&16777215;j=c[2112932]|0;i=c[j+(e>>>10<<2)>>2]|0;if(i>>>0>9){k=b&1023;n=(d[i+(k+1)|0]|0)<<8|(d[i+k|0]|0);o=m;p=j}else{m=gj[c[j+196688+(i<<2)>>2]&4095](e)|0;n=m;o=c[2276085]|0;p=c[2112932]|0}m=n&65535;n=m+g|0;e=n>>>8;c[2276075]=e;c[2276077]=((n^g)&(n^m))>>>8;c[2276078]=e;c[2276074]=e;e=m+f|0;c[2276076]=e&65535;f=o&l;l=e&65535;o=f&16777215;m=c[p+((o>>>10|16384)<<2)>>2]|0;if(m>>>0>9){n=f&1023;a[m+n|0]=e&255;a[m+(n+1)|0]=(l&65535)>>>8&255;return}else{gg[c[p+196728+(m<<2)>>2]&4095](o,l);return}}function xF(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;t=r&65535;h=c[2276085]|0;s=h&q;n=s&16777215;f=c[2112932]|0;o=c[f+(n>>>10<<2)>>2]|0;if(o>>>0>9){p=s&1023;u=(d[o+(p+1)|0]|0)<<8|(d[o+p|0]|0);v=h;w=f}else{h=gj[c[f+196688+(o<<2)>>2]&4095](n)|0;u=h;v=c[2276085]|0;w=c[2112932]|0}h=u&65535;u=h+t|0;n=u>>>8;c[2276075]=n;c[2276077]=((u^t)&(u^h))>>>8;c[2276078]=n;c[2276074]=n;n=h+r|0;c[2276076]=n&65535;r=v&q;q=n&65535;v=r&16777215;h=c[w+((v>>>10|16384)<<2)>>2]|0;if(h>>>0>9){u=r&1023;a[h+u|0]=n&255;a[h+(u+1)|0]=(q&65535)>>>8&255;return}else{gg[c[w+196728+(h<<2)>>2]&4095](v,q);return}}function xG(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[2276069]|0;e=c[9104156+((b&7|8)<<2)>>2]|0;f=c[9104156+((b>>>9&7)<<2)>>2]|0;b=c[2276085]|0;g=b&e;h=g&16777215;i=c[2112932]|0;j=c[i+(h>>>10<<2)>>2]|0;if(j>>>0>9){k=g&1023;l=(d[j+(k+3)|0]|0)<<8|(d[j+(k+2)|0]|0)|((d[j+(k+1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b;n=i}else{b=gj[c[i+196768+(j<<2)>>2]&4095](h)|0;l=b;m=c[2276085]|0;n=c[2112932]|0}b=l+f|0;h=b>>>24;c[2276075]=h;c[2276077]=((b^f)&(b^l))>>>24;j=((b^-8388608)&(l|f)|l&f)>>>23;c[2276078]=j;c[2276074]=j;c[2276076]=b;j=m&e;e=j&16777215;m=c[n+((e>>>10|16384)<<2)>>2]|0;if(m>>>0>9){f=j&1023;a[m+f|0]=b>>>16&255;a[m+(f+1)|0]=h&255;a[m+(f+2)|0]=b&255;a[m+(f+3)|0]=b>>>8&255;return}else{gg[c[n+196808+(m<<2)>>2]&4095](e,b);return}}function xH(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=c[b>>2]|0;c[b>>2]=e+4;b=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;f=c[2276085]|0;g=f&e;h=g&16777215;i=c[2112932]|0;j=c[i+(h>>>10<<2)>>2]|0;if(j>>>0>9){k=g&1023;l=(d[j+(k+3)|0]|0)<<8|(d[j+(k+2)|0]|0)|((d[j+(k+1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=f;n=i}else{f=gj[c[i+196768+(j<<2)>>2]&4095](h)|0;l=f;m=c[2276085]|0;n=c[2112932]|0}f=l+b|0;h=f>>>24;c[2276075]=h;c[2276077]=((f^b)&(f^l))>>>24;j=((f^-8388608)&(l|b)|l&b)>>>23;c[2276078]=j;c[2276074]=j;c[2276076]=f;j=m&e;e=j&16777215;m=c[n+((e>>>10|16384)<<2)>>2]|0;if(m>>>0>9){b=j&1023;a[m+b|0]=f>>>16&255;a[m+(b+1)|0]=h&255;a[m+(b+2)|0]=f&255;a[m+(b+3)|0]=f>>>8&255;return}else{gg[c[n+196808+(m<<2)>>2]&4095](e,f);return}}function xI(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=(c[b>>2]|0)-4|0;c[b>>2]=e;b=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;f=c[2276085]|0;g=f&e;h=g&16777215;i=c[2112932]|0;j=c[i+(h>>>10<<2)>>2]|0;if(j>>>0>9){k=g&1023;l=(d[j+(k+3)|0]|0)<<8|(d[j+(k+2)|0]|0)|((d[j+(k+1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=f;n=i}else{f=gj[c[i+196768+(j<<2)>>2]&4095](h)|0;l=f;m=c[2276085]|0;n=c[2112932]|0}f=l+b|0;h=f>>>24;c[2276075]=h;c[2276077]=((f^b)&(f^l))>>>24;j=((f^-8388608)&(l|b)|l&b)>>>23;c[2276078]=j;c[2276074]=j;c[2276076]=f;j=m&e;e=j&16777215;m=c[n+((e>>>10|16384)<<2)>>2]|0;if(m>>>0>9){b=j&1023;a[m+b|0]=f>>>16&255;a[m+(b+1)|0]=h&255;a[m+(b+2)|0]=f&255;a[m+(b+3)|0]=f>>>8&255;return}else{gg[c[n+196808+(m<<2)>>2]&4095](e,f);return}}function xJ(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=c[2276069]|0;e=c[9104156+((b&7|8)<<2)>>2]|0;f=c[2276056]|0;g=f&-4;if((g|0)==(c[2276083]|0)){h=f;i=c[2276084]|0;j=b}else{c[2276083]=g;k=c[2276085]&g;g=k&16777212;l=c[2112932]|0;m=c[l+((g>>>10|32768)<<2)>>2]|0;if(m>>>0>9){n=k&1020;o=(d[m+(n|3)|0]|0)<<8|(d[m+(n|2)|0]|0)|((d[m+(n|1)|0]|0)<<8|(d[m+n|0]|0))<<16;p=f;q=b}else{b=gj[c[l+196768+(m<<2)>>2]&4095](g)|0;o=b;p=c[2276056]|0;q=c[2276069]|0}c[2276084]=o;h=p;i=o;j=q}c[2276056]=h+2;q=(i>>>((h<<3&16^16)>>>0)<<16>>16)+e|0;e=c[9104156+((j>>>9&7)<<2)>>2]|0;j=c[2276085]|0;h=q&j;i=h&16777215;o=c[2112932]|0;p=c[o+(i>>>10<<2)>>2]|0;if(p>>>0>9){b=h&1023;r=(d[p+(b+3)|0]|0)<<8|(d[p+(b+2)|0]|0)|((d[p+(b+1)|0]|0)<<8|(d[p+b|0]|0))<<16;s=j;t=o}else{j=gj[c[o+196768+(p<<2)>>2]&4095](i)|0;r=j;s=c[2276085]|0;t=c[2112932]|0}j=r+e|0;i=j>>>24;c[2276075]=i;c[2276077]=((j^e)&(j^r))>>>24;p=((j^-8388608)&(r|e)|r&e)>>>23;c[2276078]=p;c[2276074]=p;c[2276076]=j;p=s&q;q=p&16777215;s=c[t+((q>>>10|16384)<<2)>>2]|0;if(s>>>0>9){e=p&1023;a[s+e|0]=j>>>16&255;a[s+(e+1)|0]=i&255;a[s+(e+2)|0]=j&255;a[s+(e+3)|0]=j>>>8&255;return}else{gg[c[t+196808+(s<<2)>>2]&4095](q,j);return}}function xK(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=xw(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;e=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;f=c[2276085]|0;g=f&b;h=g&16777215;i=c[2112932]|0;j=c[i+(h>>>10<<2)>>2]|0;if(j>>>0>9){k=g&1023;l=(d[j+(k+3)|0]|0)<<8|(d[j+(k+2)|0]|0)|((d[j+(k+1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=f;n=i}else{f=gj[c[i+196768+(j<<2)>>2]&4095](h)|0;l=f;m=c[2276085]|0;n=c[2112932]|0}f=l+e|0;h=f>>>24;c[2276075]=h;c[2276077]=((f^e)&(f^l))>>>24;j=((f^-8388608)&(l|e)|l&e)>>>23;c[2276078]=j;c[2276074]=j;c[2276076]=f;j=m&b;b=j&16777215;m=c[n+((b>>>10|16384)<<2)>>2]|0;if(m>>>0>9){e=j&1023;a[m+e|0]=f>>>16&255;a[m+(e+1)|0]=h&255;a[m+(e+2)|0]=f&255;a[m+(e+3)|0]=f>>>8&255;return}else{gg[c[n+196808+(m<<2)>>2]&4095](b,f);return}}function xL(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)<<16>>16;f=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;g=c[2276085]|0;m=l&g;b=m&16777215;e=c[2112932]|0;j=c[e+(b>>>10<<2)>>2]|0;if(j>>>0>9){i=m&1023;n=(d[j+(i+3)|0]|0)<<8|(d[j+(i+2)|0]|0)|((d[j+(i+1)|0]|0)<<8|(d[j+i|0]|0))<<16;o=g;p=e}else{g=gj[c[e+196768+(j<<2)>>2]&4095](b)|0;n=g;o=c[2276085]|0;p=c[2112932]|0}g=n+f|0;b=g>>>24;c[2276075]=b;c[2276077]=((g^f)&(g^n))>>>24;j=((g^-8388608)&(n|f)|n&f)>>>23;c[2276078]=j;c[2276074]=j;c[2276076]=g;j=o&l;l=j&16777215;o=c[p+((l>>>10|16384)<<2)>>2]|0;if(o>>>0>9){f=j&1023;a[o+f|0]=g>>>16&255;a[o+(f+1)|0]=b&255;a[o+(f+2)|0]=g&255;a[o+(f+3)|0]=g>>>8&255;return}else{gg[c[p+196808+(o<<2)>>2]&4095](l,g);return}}function xM(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;t=c[2276085]|0;h=t&q;s=h&16777215;n=c[2112932]|0;f=c[n+(s>>>10<<2)>>2]|0;if(f>>>0>9){o=h&1023;u=(d[f+(o+3)|0]|0)<<8|(d[f+(o+2)|0]|0)|((d[f+(o+1)|0]|0)<<8|(d[f+o|0]|0))<<16;v=t;w=n}else{t=gj[c[n+196768+(f<<2)>>2]&4095](s)|0;u=t;v=c[2276085]|0;w=c[2112932]|0}t=u+r|0;s=t>>>24;c[2276075]=s;c[2276077]=((t^r)&(t^u))>>>24;f=((t^-8388608)&(u|r)|u&r)>>>23;c[2276078]=f;c[2276074]=f;c[2276076]=t;f=v&q;q=f&16777215;v=c[w+((q>>>10|16384)<<2)>>2]|0;if(v>>>0>9){r=f&1023;a[v+r|0]=t>>>16&255;a[v+(r+1)|0]=s&255;a[v+(r+2)|0]=t&255;a[v+(r+3)|0]=t>>>8&255;return}else{gg[c[w+196808+(v<<2)>>2]&4095](q,t);return}}function xN(){var a=0,b=0;a=c[2276069]|0;b=9104156+((a>>>9&7|8)<<2)|0;c[b>>2]=(c[9104156+((a&7)<<2)>>2]<<16>>16)+(c[b>>2]|0);return}function xO(){var a=0,b=0;a=c[2276069]|0;b=9104156+((a>>>9&7|8)<<2)|0;c[b>>2]=(c[9104156+((a&7|8)<<2)>>2]<<16>>16)+(c[b>>2]|0);return}function xP(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[2276069]|0;b=9104156+((a>>>9&7|8)<<2)|0;e=c[b>>2]|0;f=c[2276085]&c[9104156+((a&7|8)<<2)>>2];a=f&16777215;g=c[2112932]|0;h=c[g+(a>>>10<<2)>>2]|0;if(h>>>0>9){i=f&1023;j=(d[h+(i+1)|0]|0)<<8|(d[h+i|0]|0);k=j<<16>>16;l=k+e|0;c[b>>2]=l;return}else{j=gj[c[g+196688+(h<<2)>>2]&4095](a)|0;k=j<<16>>16;l=k+e|0;c[b>>2]=l;return}}function xQ(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[2276069]|0;b=9104156+((a>>>9&7|8)<<2)|0;e=c[b>>2]|0;f=9104156+((a&7|8)<<2)|0;a=c[f>>2]|0;c[f>>2]=a+2;f=c[2276085]&a;a=f&16777215;g=c[2112932]|0;h=c[g+(a>>>10<<2)>>2]|0;if(h>>>0>9){i=f&1023;j=(d[h+(i+1)|0]|0)<<8|(d[h+i|0]|0);k=j<<16>>16;l=k+e|0;c[b>>2]=l;return}else{j=gj[c[g+196688+(h<<2)>>2]&4095](a)|0;k=j<<16>>16;l=k+e|0;c[b>>2]=l;return}}function xR(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[2276069]|0;b=9104156+((a>>>9&7|8)<<2)|0;e=c[b>>2]|0;f=9104156+((a&7|8)<<2)|0;a=(c[f>>2]|0)-2|0;c[f>>2]=a;f=c[2276085]&a;a=f&16777215;g=c[2112932]|0;h=c[g+(a>>>10<<2)>>2]|0;if(h>>>0>9){i=f&1023;j=(d[h+(i+1)|0]|0)<<8|(d[h+i|0]|0);k=j<<16>>16;l=k+e|0;c[b>>2]=l;return}else{j=gj[c[g+196688+(h<<2)>>2]&4095](a)|0;k=j<<16>>16;l=k+e|0;c[b>>2]=l;return}}function xS(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;a=c[2276069]|0;b=9104156+((a>>>9&7|8)<<2)|0;e=c[b>>2]|0;f=c[9104156+((a&7|8)<<2)>>2]|0;a=c[2276056]|0;g=a&-4;if((g|0)==(c[2276083]|0)){h=a;i=c[2276084]|0}else{c[2276083]=g;j=c[2276085]&g;g=j&16777212;k=c[2112932]|0;l=c[k+((g>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=j&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=a}else{a=gj[c[k+196768+(l<<2)>>2]&4095](g)|0;n=a;o=c[2276056]|0}c[2276084]=n;h=o;i=n}c[2276056]=h+2;n=(i>>>((h<<3&16^16)>>>0)<<16>>16)+f&c[2276085];f=n&16777215;h=c[2112932]|0;i=c[h+(f>>>10<<2)>>2]|0;if(i>>>0>9){o=n&1023;p=(d[i+(o+1)|0]|0)<<8|(d[i+o|0]|0);q=p<<16>>16;r=q+e|0;c[b>>2]=r;return}else{p=gj[c[h+196688+(i<<2)>>2]&4095](f)|0;q=p<<16>>16;r=q+e|0;c[b>>2]=r;return}}function xT(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[2276069]|0;b=9104156+((a>>>9&7|8)<<2)|0;e=c[b>>2]|0;f=xw(c[9104156+((a&7|8)<<2)>>2]|0)|0;a=c[2276085]&f;f=a&16777215;g=c[2112932]|0;h=c[g+(f>>>10<<2)>>2]|0;if(h>>>0>9){i=a&1023;j=(d[h+(i+1)|0]|0)<<8|(d[h+i|0]|0);k=j<<16>>16;l=k+e|0;c[b>>2]=l;return}else{j=gj[c[g+196688+(h<<2)>>2]&4095](f)|0;k=j<<16>>16;l=k+e|0;c[b>>2]=l;return}}function xU(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;a=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;b=c[a>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=h>>>((g<<3&16^16)>>>0)<<16>>16&c[2276085];g=m&16777215;h=c[2112932]|0;n=c[h+(g>>>10<<2)>>2]|0;if(n>>>0>9){e=m&1023;o=(d[n+(e+1)|0]|0)<<8|(d[n+e|0]|0);p=o<<16>>16;q=p+b|0;c[a>>2]=q;return}else{o=gj[c[h+196688+(n<<2)>>2]&4095](g)|0;p=o<<16>>16;q=p+b|0;c[a>>2]=q;return}}function xV(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;a=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;b=c[a>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=f;i=c[2276084]|0}else{c[2276083]=f;j=c[2276085]&f;k=j&16777212;l=c[2112932]|0;m=c[l+((k>>>10|32768)<<2)>>2]|0;if(m>>>0>9){n=j&1020;o=(d[m+(n|3)|0]|0)<<8|(d[m+(n|2)|0]|0)|((d[m+(n|1)|0]|0)<<8|(d[m+n|0]|0))<<16;p=e;q=f}else{f=gj[c[l+196768+(m<<2)>>2]&4095](k)|0;o=f;p=c[2276056]|0;q=c[2276083]|0}c[2276084]=o;g=p;h=q;i=o}o=g+2|0;c[2276056]=o;g=o&-4;if((g|0)==(h|0)){r=i;s=o}else{c[2276083]=g;h=c[2276085]&g;g=h&16777212;q=c[2112932]|0;p=c[q+((g>>>10|32768)<<2)>>2]|0;if(p>>>0>9){f=h&1020;t=(d[p+(f|3)|0]|0)<<8|(d[p+(f|2)|0]|0)|((d[p+(f|1)|0]|0)<<8|(d[p+f|0]|0))<<16;u=o}else{o=gj[c[q+196768+(p<<2)>>2]&4095](g)|0;t=o;u=c[2276056]|0}c[2276084]=t;r=t>>>16|i<<16;s=u}c[2276056]=s+2;s=c[2276085]&r;r=s&16777215;u=c[2112932]|0;i=c[u+(r>>>10<<2)>>2]|0;if(i>>>0>9){t=s&1023;v=(d[i+(t+1)|0]|0)<<8|(d[i+t|0]|0);w=v<<16>>16;x=w+b|0;c[a>>2]=x;return}else{v=gj[c[u+196688+(i<<2)>>2]&4095](r)|0;w=v<<16>>16;x=w+b|0;c[a>>2]=x;return}}function xW(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;a=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;b=c[a>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{l=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=l;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=(h>>>((g<<3&16^16)>>>0)<<16>>16)+e|0;e=m&16777215;g=c[2112932]|0;h=c[g+((e>>>10|32768)<<2)>>2]|0;if(h>>>0>9){n=m&1023;o=(d[h+(n+1)|0]|0)<<8|(d[h+n|0]|0);p=o<<16>>16;q=p+b|0;c[a>>2]=q;return}else{o=gj[c[g+196688+(h<<2)>>2]&4095](e)|0;p=o<<16>>16;q=p+b|0;c[a>>2]=q;return}}function xX(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;b=c[a>>2]|0;e=xw(c[2276056]|0)|0;f=e&16777215;g=c[2112932]|0;h=c[g+((f>>>10|32768)<<2)>>2]|0;if(h>>>0>9){i=e&1023;j=(d[h+(i+1)|0]|0)<<8|(d[h+i|0]|0);k=j<<16>>16;l=k+b|0;c[a>>2]=l;return}else{j=gj[c[g+196688+(h<<2)>>2]&4095](f)|0;k=j<<16>>16;l=k+b|0;c[a>>2]=l;return}}function xY(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;a=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;b=c[a>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0;i=g+2|0;c[2276056]=i;j=g<<3;k=j&16;l=k^16;m=h>>>(l>>>0);n=m<<16;o=n>>16;p=o+b|0;c[a>>2]=p;return}c[2276083]=f;q=c[2276085]&f;f=q&16777212;r=c[2112932]|0;s=c[r+((f>>>10|32768)<<2)>>2]|0;if(s>>>0>9){t=q&1020;u=(d[s+(t|3)|0]|0)<<8|(d[s+(t|2)|0]|0)|((d[s+(t|1)|0]|0)<<8|(d[s+t|0]|0))<<16;v=e}else{e=gj[c[r+196768+(s<<2)>>2]&4095](f)|0;u=e;v=c[2276056]|0}c[2276084]=u;g=v;h=u;i=g+2|0;c[2276056]=i;j=g<<3;k=j&16;l=k^16;m=h>>>(l>>>0);n=m<<16;o=n>>16;p=o+b|0;c[a>>2]=p;return}function xZ(){var a=0,b=0;a=c[2276069]|0;b=9104156+((a>>>9&7|8)<<2)|0;c[b>>2]=(c[9104156+((a&7)<<2)>>2]|0)+(c[b>>2]|0);return}function x_(){var a=0,b=0;a=c[2276069]|0;b=9104156+((a>>>9&7|8)<<2)|0;c[b>>2]=(c[9104156+((a&7|8)<<2)>>2]|0)+(c[b>>2]|0);return}function x$(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[2276069]|0;b=9104156+((a>>>9&7|8)<<2)|0;e=c[b>>2]|0;f=c[2276085]&c[9104156+((a&7|8)<<2)>>2];a=f&16777215;g=c[2112932]|0;h=c[g+(a>>>10<<2)>>2]|0;if(h>>>0>9){i=f&1023;j=(d[h+(i+3)|0]|0)<<8|(d[h+(i+2)|0]|0)|((d[h+(i+1)|0]|0)<<8|(d[h+i|0]|0))<<16;k=j+e|0;c[b>>2]=k;return}else{j=gj[c[g+196768+(h<<2)>>2]&4095](a)|0;k=j+e|0;c[b>>2]=k;return}}function x0(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[2276069]|0;b=9104156+((a>>>9&7|8)<<2)|0;e=c[b>>2]|0;f=9104156+((a&7|8)<<2)|0;a=c[f>>2]|0;c[f>>2]=a+4;f=c[2276085]&a;a=f&16777215;g=c[2112932]|0;h=c[g+(a>>>10<<2)>>2]|0;if(h>>>0>9){i=f&1023;j=(d[h+(i+3)|0]|0)<<8|(d[h+(i+2)|0]|0)|((d[h+(i+1)|0]|0)<<8|(d[h+i|0]|0))<<16;k=j+e|0;c[b>>2]=k;return}else{j=gj[c[g+196768+(h<<2)>>2]&4095](a)|0;k=j+e|0;c[b>>2]=k;return}}function x1(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[2276069]|0;b=9104156+((a>>>9&7|8)<<2)|0;e=c[b>>2]|0;f=9104156+((a&7|8)<<2)|0;a=(c[f>>2]|0)-4|0;c[f>>2]=a;f=c[2276085]&a;a=f&16777215;g=c[2112932]|0;h=c[g+(a>>>10<<2)>>2]|0;if(h>>>0>9){i=f&1023;j=(d[h+(i+3)|0]|0)<<8|(d[h+(i+2)|0]|0)|((d[h+(i+1)|0]|0)<<8|(d[h+i|0]|0))<<16;k=j+e|0;c[b>>2]=k;return}else{j=gj[c[g+196768+(h<<2)>>2]&4095](a)|0;k=j+e|0;c[b>>2]=k;return}}function x2(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;a=c[2276069]|0;b=9104156+((a>>>9&7|8)<<2)|0;e=c[b>>2]|0;f=c[9104156+((a&7|8)<<2)>>2]|0;a=c[2276056]|0;g=a&-4;if((g|0)==(c[2276083]|0)){h=a;i=c[2276084]|0}else{c[2276083]=g;j=c[2276085]&g;g=j&16777212;k=c[2112932]|0;l=c[k+((g>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=j&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=a}else{a=gj[c[k+196768+(l<<2)>>2]&4095](g)|0;n=a;o=c[2276056]|0}c[2276084]=n;h=o;i=n}c[2276056]=h+2;n=(i>>>((h<<3&16^16)>>>0)<<16>>16)+f&c[2276085];f=n&16777215;h=c[2112932]|0;i=c[h+(f>>>10<<2)>>2]|0;if(i>>>0>9){o=n&1023;p=(d[i+(o+3)|0]|0)<<8|(d[i+(o+2)|0]|0)|((d[i+(o+1)|0]|0)<<8|(d[i+o|0]|0))<<16;q=p+e|0;c[b>>2]=q;return}else{p=gj[c[h+196768+(i<<2)>>2]&4095](f)|0;q=p+e|0;c[b>>2]=q;return}}function x3(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[2276069]|0;b=9104156+((a>>>9&7|8)<<2)|0;e=c[b>>2]|0;f=xw(c[9104156+((a&7|8)<<2)>>2]|0)|0;a=c[2276085]&f;f=a&16777215;g=c[2112932]|0;h=c[g+(f>>>10<<2)>>2]|0;if(h>>>0>9){i=a&1023;j=(d[h+(i+3)|0]|0)<<8|(d[h+(i+2)|0]|0)|((d[h+(i+1)|0]|0)<<8|(d[h+i|0]|0))<<16;k=j+e|0;c[b>>2]=k;return}else{j=gj[c[g+196768+(h<<2)>>2]&4095](f)|0;k=j+e|0;c[b>>2]=k;return}}function x4(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;a=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;b=c[a>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=h>>>((g<<3&16^16)>>>0)<<16>>16&c[2276085];g=m&16777215;h=c[2112932]|0;n=c[h+(g>>>10<<2)>>2]|0;if(n>>>0>9){e=m&1023;o=(d[n+(e+3)|0]|0)<<8|(d[n+(e+2)|0]|0)|((d[n+(e+1)|0]|0)<<8|(d[n+e|0]|0))<<16;p=o+b|0;c[a>>2]=p;return}else{o=gj[c[h+196768+(n<<2)>>2]&4095](g)|0;p=o+b|0;c[a>>2]=p;return}}function x5(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;a=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;b=c[a>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=f;i=c[2276084]|0}else{c[2276083]=f;j=c[2276085]&f;k=j&16777212;l=c[2112932]|0;m=c[l+((k>>>10|32768)<<2)>>2]|0;if(m>>>0>9){n=j&1020;o=(d[m+(n|3)|0]|0)<<8|(d[m+(n|2)|0]|0)|((d[m+(n|1)|0]|0)<<8|(d[m+n|0]|0))<<16;p=e;q=f}else{f=gj[c[l+196768+(m<<2)>>2]&4095](k)|0;o=f;p=c[2276056]|0;q=c[2276083]|0}c[2276084]=o;g=p;h=q;i=o}o=g+2|0;c[2276056]=o;g=o&-4;if((g|0)==(h|0)){r=i;s=o}else{c[2276083]=g;h=c[2276085]&g;g=h&16777212;q=c[2112932]|0;p=c[q+((g>>>10|32768)<<2)>>2]|0;if(p>>>0>9){f=h&1020;t=(d[p+(f|3)|0]|0)<<8|(d[p+(f|2)|0]|0)|((d[p+(f|1)|0]|0)<<8|(d[p+f|0]|0))<<16;u=o}else{o=gj[c[q+196768+(p<<2)>>2]&4095](g)|0;t=o;u=c[2276056]|0}c[2276084]=t;r=t>>>16|i<<16;s=u}c[2276056]=s+2;s=c[2276085]&r;r=s&16777215;u=c[2112932]|0;i=c[u+(r>>>10<<2)>>2]|0;if(i>>>0>9){t=s&1023;v=(d[i+(t+3)|0]|0)<<8|(d[i+(t+2)|0]|0)|((d[i+(t+1)|0]|0)<<8|(d[i+t|0]|0))<<16;w=v+b|0;c[a>>2]=w;return}else{v=gj[c[u+196768+(i<<2)>>2]&4095](r)|0;w=v+b|0;c[a>>2]=w;return}}function x6(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;a=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;b=c[a>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{l=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=l;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=(h>>>((g<<3&16^16)>>>0)<<16>>16)+e|0;e=m&16777215;g=c[2112932]|0;h=c[g+((e>>>10|32768)<<2)>>2]|0;if(h>>>0>9){n=m&1023;o=(d[h+(n+3)|0]|0)<<8|(d[h+(n+2)|0]|0)|((d[h+(n+1)|0]|0)<<8|(d[h+n|0]|0))<<16;p=o+b|0;c[a>>2]=p;return}else{o=gj[c[g+196768+(h<<2)>>2]&4095](e)|0;p=o+b|0;c[a>>2]=p;return}}function x7(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;a=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;b=c[a>>2]|0;e=xw(c[2276056]|0)|0;f=e&16777215;g=c[2112932]|0;h=c[g+((f>>>10|32768)<<2)>>2]|0;if(h>>>0>9){i=e&1023;j=(d[h+(i+3)|0]|0)<<8|(d[h+(i+2)|0]|0)|((d[h+(i+1)|0]|0)<<8|(d[h+i|0]|0))<<16;k=j+b|0;c[a>>2]=k;return}else{j=gj[c[g+196768+(h<<2)>>2]&4095](f)|0;k=j+b|0;c[a>>2]=k;return}}function x8(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;a=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;b=c[a>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=f;i=c[2276084]|0}else{c[2276083]=f;j=c[2276085]&f;k=j&16777212;l=c[2112932]|0;m=c[l+((k>>>10|32768)<<2)>>2]|0;if(m>>>0>9){n=j&1020;o=(d[m+(n|3)|0]|0)<<8|(d[m+(n|2)|0]|0)|((d[m+(n|1)|0]|0)<<8|(d[m+n|0]|0))<<16;p=e;q=f}else{f=gj[c[l+196768+(m<<2)>>2]&4095](k)|0;o=f;p=c[2276056]|0;q=c[2276083]|0}c[2276084]=o;g=p;h=q;i=o}o=g+2|0;c[2276056]=o;g=o&-4;if((g|0)==(h|0)){r=i;s=o;t=s+2|0;c[2276056]=t;u=r+b|0;c[a>>2]=u;return}c[2276083]=g;h=c[2276085]&g;g=h&16777212;q=c[2112932]|0;p=c[q+((g>>>10|32768)<<2)>>2]|0;if(p>>>0>9){f=h&1020;v=(d[p+(f|3)|0]|0)<<8|(d[p+(f|2)|0]|0)|((d[p+(f|1)|0]|0)<<8|(d[p+f|0]|0))<<16;w=o}else{o=gj[c[q+196768+(p<<2)>>2]&4095](g)|0;v=o;w=c[2276056]|0}c[2276084]=v;r=v>>>16|i<<16;s=w;t=s+2|0;c[2276056]=t;u=r+b|0;c[a>>2]=u;return}function x9(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=9104156+((c[2276069]&7)<<2)|0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0);f=l&255;g=c[a>>2]|0;m=g&255;b=f+m|0;c[2276075]=b;c[2276077]=(b^f)&(b^m);c[2276078]=b;c[2276074]=b;b=l+g&255;c[2276076]=b;c[a>>2]=b|c[a>>2]&-256;return}function ya(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0);f=l&255;g=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;m=c[2276085]|0;b=m&g;e=b&16777215;j=c[2112932]|0;i=c[j+(e>>>10<<2)>>2]|0;if(i>>>0>9){n=a[i+(b&1023^1)|0]|0;o=m;p=j}else{m=gj[c[j+196608+(i<<2)>>2]&4095](e)|0;n=m;o=c[2276085]|0;p=c[2112932]|0}m=n&255;n=m+f|0;c[2276075]=n;c[2276077]=(n^f)&(n^m);c[2276078]=n;c[2276074]=n;n=m+l|0;c[2276076]=n&255;l=o&g;g=n&255;n=l&16777215;o=c[p+((n>>>10|16384)<<2)>>2]|0;if(o>>>0>9){a[o+(l&1023^1)|0]=g;return}else{gg[c[p+196648+(o<<2)>>2]&4095](n,g);return}}function yb(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0);f=l&255;g=9104156+((c[2276069]&7|8)<<2)|0;m=c[g>>2]|0;c[g>>2]=m+1;g=c[2276085]|0;b=g&m;e=b&16777215;j=c[2112932]|0;i=c[j+(e>>>10<<2)>>2]|0;if(i>>>0>9){n=a[i+(b&1023^1)|0]|0;o=g;p=j}else{g=gj[c[j+196608+(i<<2)>>2]&4095](e)|0;n=g;o=c[2276085]|0;p=c[2112932]|0}g=n&255;n=g+f|0;c[2276075]=n;c[2276077]=(n^f)&(n^g);c[2276078]=n;c[2276074]=n;n=g+l|0;c[2276076]=n&255;l=o&m;m=n&255;n=l&16777215;o=c[p+((n>>>10|16384)<<2)>>2]|0;if(o>>>0>9){a[o+(l&1023^1)|0]=m;return}else{gg[c[p+196648+(o<<2)>>2]&4095](n,m);return}}function yc(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0);f=l&255;g=c[2276054]|0;c[2276054]=g+2;m=c[2276085]|0;b=m&g;e=b&16777215;j=c[2112932]|0;i=c[j+(e>>>10<<2)>>2]|0;if(i>>>0>9){n=a[i+(b&1023^1)|0]|0;o=m;p=j}else{m=gj[c[j+196608+(i<<2)>>2]&4095](e)|0;n=m;o=c[2276085]|0;p=c[2112932]|0}m=n&255;n=m+f|0;c[2276075]=n;c[2276077]=(n^f)&(n^m);c[2276078]=n;c[2276074]=n;n=m+l|0;c[2276076]=n&255;l=o&g;g=n&255;n=l&16777215;o=c[p+((n>>>10|16384)<<2)>>2]|0;if(o>>>0>9){a[o+(l&1023^1)|0]=g;return}else{gg[c[p+196648+(o<<2)>>2]&4095](n,g);return}}function yd(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0);f=l&255;g=9104156+((c[2276069]&7|8)<<2)|0;m=(c[g>>2]|0)-1|0;c[g>>2]=m;g=c[2276085]|0;b=g&m;e=b&16777215;j=c[2112932]|0;i=c[j+(e>>>10<<2)>>2]|0;if(i>>>0>9){n=a[i+(b&1023^1)|0]|0;o=g;p=j}else{g=gj[c[j+196608+(i<<2)>>2]&4095](e)|0;n=g;o=c[2276085]|0;p=c[2112932]|0}g=n&255;n=g+f|0;c[2276075]=n;c[2276077]=(n^f)&(n^g);c[2276078]=n;c[2276074]=n;n=g+l|0;c[2276076]=n&255;l=o&m;m=n&255;n=l&16777215;o=c[p+((n>>>10|16384)<<2)>>2]|0;if(o>>>0>9){a[o+(l&1023^1)|0]=m;return}else{gg[c[p+196648+(o<<2)>>2]&4095](n,m);return}}function ye(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0);f=l&255;g=(c[2276054]|0)-2|0;c[2276054]=g;m=c[2276085]|0;b=m&g;e=b&16777215;j=c[2112932]|0;i=c[j+(e>>>10<<2)>>2]|0;if(i>>>0>9){n=a[i+(b&1023^1)|0]|0;o=m;p=j}else{m=gj[c[j+196608+(i<<2)>>2]&4095](e)|0;n=m;o=c[2276085]|0;p=c[2112932]|0}m=n&255;n=m+f|0;c[2276075]=n;c[2276077]=(n^f)&(n^m);c[2276078]=n;c[2276074]=n;n=m+l|0;c[2276076]=n&255;l=o&g;g=n&255;n=l&16777215;o=c[p+((n>>>10|16384)<<2)>>2]|0;if(o>>>0>9){a[o+(l&1023^1)|0]=g;return}else{gg[c[p+196648+(o<<2)>>2]&4095](n,g);return}}function yf(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0);f=n&255;o=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=p&-4;if((e|0)==(h|0)){q=p;r=g}else{c[2276083]=e;g=c[2276085]&e;e=g&16777212;h=c[2112932]|0;j=c[h+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){l=g&1020;s=(d[j+(l|3)|0]|0)<<8|(d[j+(l|2)|0]|0)|((d[j+(l|1)|0]|0)<<8|(d[j+l|0]|0))<<16;t=p}else{p=gj[c[h+196768+(j<<2)>>2]&4095](e)|0;s=p;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;s=(r>>>((q<<3&16^16)>>>0)<<16>>16)+o|0;o=c[2276085]|0;q=s&o;r=q&16777215;t=c[2112932]|0;p=c[t+(r>>>10<<2)>>2]|0;if(p>>>0>9){u=a[p+(q&1023^1)|0]|0;v=o;w=t}else{o=gj[c[t+196608+(p<<2)>>2]&4095](r)|0;u=o;v=c[2276085]|0;w=c[2112932]|0}o=u&255;u=o+f|0;c[2276075]=u;c[2276077]=(u^f)&(u^o);c[2276078]=u;c[2276074]=u;u=o+n|0;c[2276076]=u&255;n=v&s;s=u&255;u=n&16777215;v=c[w+((u>>>10|16384)<<2)>>2]|0;if(v>>>0>9){a[v+(n&1023^1)|0]=s;return}else{gg[c[w+196648+(v<<2)>>2]&4095](u,s);return}}function yg(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0);f=l&255;g=xw(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;m=c[2276085]|0;b=m&g;e=b&16777215;j=c[2112932]|0;i=c[j+(e>>>10<<2)>>2]|0;if(i>>>0>9){n=a[i+(b&1023^1)|0]|0;o=m;p=j}else{m=gj[c[j+196608+(i<<2)>>2]&4095](e)|0;n=m;o=c[2276085]|0;p=c[2112932]|0}m=n&255;n=m+f|0;c[2276075]=n;c[2276077]=(n^f)&(n^m);c[2276078]=n;c[2276074]=n;n=m+l|0;c[2276076]=n&255;l=o&g;g=n&255;n=l&16777215;o=c[p+((n>>>10|16384)<<2)>>2]|0;if(o>>>0>9){a[o+(l&1023^1)|0]=g;return}else{gg[c[p+196648+(o<<2)>>2]&4095](n,g);return}}function yh(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0);f=n&255;o=p&-4;if((o|0)==(h|0)){q=p;r=g}else{c[2276083]=o;g=c[2276085]&o;o=g&16777212;h=c[2112932]|0;e=c[h+((o>>>10|32768)<<2)>>2]|0;if(e>>>0>9){j=g&1020;s=(d[e+(j|3)|0]|0)<<8|(d[e+(j|2)|0]|0)|((d[e+(j|1)|0]|0)<<8|(d[e+j|0]|0))<<16;t=p}else{p=gj[c[h+196768+(e<<2)>>2]&4095](o)|0;s=p;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;s=r>>>((q<<3&16^16)>>>0)<<16>>16;q=c[2276085]|0;r=s&q;t=r&16777215;p=c[2112932]|0;o=c[p+(t>>>10<<2)>>2]|0;if(o>>>0>9){u=a[o+(r&1023^1)|0]|0;v=q;w=p}else{q=gj[c[p+196608+(o<<2)>>2]&4095](t)|0;u=q;v=c[2276085]|0;w=c[2112932]|0}q=u&255;u=q+f|0;c[2276075]=u;c[2276077]=(u^f)&(u^q);c[2276078]=u;c[2276074]=u;u=q+n|0;c[2276076]=u&255;n=v&s;s=u&255;u=n&16777215;v=c[w+((u>>>10|16384)<<2)>>2]|0;if(v>>>0>9){a[v+(n&1023^1)|0]=s;return}else{gg[c[w+196648+(v<<2)>>2]&4095](u,s);return}}function yi(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0);f=n&255;o=p&-4;if((o|0)==(h|0)){q=p;r=h;s=g}else{c[2276083]=o;g=c[2276085]&o;h=g&16777212;e=c[2112932]|0;j=c[e+((h>>>10|32768)<<2)>>2]|0;if(j>>>0>9){l=g&1020;t=(d[j+(l|3)|0]|0)<<8|(d[j+(l|2)|0]|0)|((d[j+(l|1)|0]|0)<<8|(d[j+l|0]|0))<<16;u=p;v=o}else{o=gj[c[e+196768+(j<<2)>>2]&4095](h)|0;t=o;u=c[2276056]|0;v=c[2276083]|0}c[2276084]=t;q=u;r=v;s=t}t=q+2|0;c[2276056]=t;q=t&-4;if((q|0)==(r|0)){w=s;x=t}else{c[2276083]=q;r=c[2276085]&q;q=r&16777212;v=c[2112932]|0;u=c[v+((q>>>10|32768)<<2)>>2]|0;if(u>>>0>9){o=r&1020;y=(d[u+(o|3)|0]|0)<<8|(d[u+(o|2)|0]|0)|((d[u+(o|1)|0]|0)<<8|(d[u+o|0]|0))<<16;z=t}else{t=gj[c[v+196768+(u<<2)>>2]&4095](q)|0;y=t;z=c[2276056]|0}c[2276084]=y;w=y>>>16|s<<16;x=z}c[2276056]=x+2;x=c[2276085]|0;z=x&w;s=z&16777215;y=c[2112932]|0;t=c[y+(s>>>10<<2)>>2]|0;if(t>>>0>9){A=a[t+(z&1023^1)|0]|0;B=x;C=y}else{x=gj[c[y+196608+(t<<2)>>2]&4095](s)|0;A=x;B=c[2276085]|0;C=c[2112932]|0}x=A&255;A=x+f|0;c[2276075]=A;c[2276077]=(A^f)&(A^x);c[2276078]=A;c[2276074]=A;A=x+n|0;c[2276076]=A&255;n=B&w;w=A&255;A=n&16777215;B=c[C+((A>>>10|16384)<<2)>>2]|0;if(B>>>0>9){a[B+(n&1023^1)|0]=w;return}else{gg[c[C+196648+(B<<2)>>2]&4095](A,w);return}}function yj(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=9104156+((c[2276069]&7)<<2)|0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0);f=l&65535;g=c[a>>2]|0;m=g&65535;b=f+m|0;e=b>>>8;c[2276075]=e;c[2276077]=((b^f)&(b^m))>>>8;c[2276078]=e;c[2276074]=e;e=l+g&65535;c[2276076]=e;c[a>>2]=e|c[a>>2]&-65536;return}function yk(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0);f=l&65535;g=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;m=c[2276085]|0;b=m&g;e=b&16777215;j=c[2112932]|0;i=c[j+(e>>>10<<2)>>2]|0;if(i>>>0>9){k=b&1023;n=(d[i+(k+1)|0]|0)<<8|(d[i+k|0]|0);o=m;p=j}else{m=gj[c[j+196688+(i<<2)>>2]&4095](e)|0;n=m;o=c[2276085]|0;p=c[2112932]|0}m=n&65535;n=m+f|0;e=n>>>8;c[2276075]=e;c[2276077]=((n^f)&(n^m))>>>8;c[2276078]=e;c[2276074]=e;e=m+l|0;c[2276076]=e&65535;l=o&g;g=e&65535;o=l&16777215;m=c[p+((o>>>10|16384)<<2)>>2]|0;if(m>>>0>9){n=l&1023;a[m+n|0]=e&255;a[m+(n+1)|0]=(g&65535)>>>8&255;return}else{gg[c[p+196728+(m<<2)>>2]&4095](o,g);return}}function yl(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0);f=l&65535;g=9104156+((c[2276069]&7|8)<<2)|0;m=c[g>>2]|0;c[g>>2]=m+2;g=c[2276085]|0;b=g&m;e=b&16777215;j=c[2112932]|0;i=c[j+(e>>>10<<2)>>2]|0;if(i>>>0>9){k=b&1023;n=(d[i+(k+1)|0]|0)<<8|(d[i+k|0]|0);o=g;p=j}else{g=gj[c[j+196688+(i<<2)>>2]&4095](e)|0;n=g;o=c[2276085]|0;p=c[2112932]|0}g=n&65535;n=g+f|0;e=n>>>8;c[2276075]=e;c[2276077]=((n^f)&(n^g))>>>8;c[2276078]=e;c[2276074]=e;e=g+l|0;c[2276076]=e&65535;l=o&m;m=e&65535;o=l&16777215;g=c[p+((o>>>10|16384)<<2)>>2]|0;if(g>>>0>9){n=l&1023;a[g+n|0]=e&255;a[g+(n+1)|0]=(m&65535)>>>8&255;return}else{gg[c[p+196728+(g<<2)>>2]&4095](o,m);return}}function ym(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0);f=l&65535;g=9104156+((c[2276069]&7|8)<<2)|0;m=(c[g>>2]|0)-2|0;c[g>>2]=m;g=c[2276085]|0;b=g&m;e=b&16777215;j=c[2112932]|0;i=c[j+(e>>>10<<2)>>2]|0;if(i>>>0>9){k=b&1023;n=(d[i+(k+1)|0]|0)<<8|(d[i+k|0]|0);o=g;p=j}else{g=gj[c[j+196688+(i<<2)>>2]&4095](e)|0;n=g;o=c[2276085]|0;p=c[2112932]|0}g=n&65535;n=g+f|0;e=n>>>8;c[2276075]=e;c[2276077]=((n^f)&(n^g))>>>8;c[2276078]=e;c[2276074]=e;e=g+l|0;c[2276076]=e&65535;l=o&m;m=e&65535;o=l&16777215;g=c[p+((o>>>10|16384)<<2)>>2]|0;if(g>>>0>9){n=l&1023;a[g+n|0]=e&255;a[g+(n+1)|0]=(m&65535)>>>8&255;return}else{gg[c[p+196728+(g<<2)>>2]&4095](o,m);return}}function yn(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0);f=n&65535;o=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=p&-4;if((e|0)==(h|0)){q=p;r=g}else{c[2276083]=e;g=c[2276085]&e;e=g&16777212;h=c[2112932]|0;j=c[h+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){l=g&1020;s=(d[j+(l|3)|0]|0)<<8|(d[j+(l|2)|0]|0)|((d[j+(l|1)|0]|0)<<8|(d[j+l|0]|0))<<16;t=p}else{p=gj[c[h+196768+(j<<2)>>2]&4095](e)|0;s=p;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;s=(r>>>((q<<3&16^16)>>>0)<<16>>16)+o|0;o=c[2276085]|0;q=s&o;r=q&16777215;t=c[2112932]|0;p=c[t+(r>>>10<<2)>>2]|0;if(p>>>0>9){e=q&1023;u=(d[p+(e+1)|0]|0)<<8|(d[p+e|0]|0);v=o;w=t}else{o=gj[c[t+196688+(p<<2)>>2]&4095](r)|0;u=o;v=c[2276085]|0;w=c[2112932]|0}o=u&65535;u=o+f|0;r=u>>>8;c[2276075]=r;c[2276077]=((u^f)&(u^o))>>>8;c[2276078]=r;c[2276074]=r;r=o+n|0;c[2276076]=r&65535;n=v&s;s=r&65535;v=n&16777215;o=c[w+((v>>>10|16384)<<2)>>2]|0;if(o>>>0>9){u=n&1023;a[o+u|0]=r&255;a[o+(u+1)|0]=(s&65535)>>>8&255;return}else{gg[c[w+196728+(o<<2)>>2]&4095](v,s);return}}function yo(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0);f=l&65535;g=xw(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;m=c[2276085]|0;b=m&g;e=b&16777215;j=c[2112932]|0;i=c[j+(e>>>10<<2)>>2]|0;if(i>>>0>9){k=b&1023;n=(d[i+(k+1)|0]|0)<<8|(d[i+k|0]|0);o=m;p=j}else{m=gj[c[j+196688+(i<<2)>>2]&4095](e)|0;n=m;o=c[2276085]|0;p=c[2112932]|0}m=n&65535;n=m+f|0;e=n>>>8;c[2276075]=e;c[2276077]=((n^f)&(n^m))>>>8;c[2276078]=e;c[2276074]=e;e=m+l|0;c[2276076]=e&65535;l=o&g;g=e&65535;o=l&16777215;m=c[p+((o>>>10|16384)<<2)>>2]|0;if(m>>>0>9){n=l&1023;a[m+n|0]=e&255;a[m+(n+1)|0]=(g&65535)>>>8&255;return}else{gg[c[p+196728+(m<<2)>>2]&4095](o,g);return}}function yp(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0);f=n&65535;o=p&-4;if((o|0)==(h|0)){q=p;r=g}else{c[2276083]=o;g=c[2276085]&o;o=g&16777212;h=c[2112932]|0;e=c[h+((o>>>10|32768)<<2)>>2]|0;if(e>>>0>9){j=g&1020;s=(d[e+(j|3)|0]|0)<<8|(d[e+(j|2)|0]|0)|((d[e+(j|1)|0]|0)<<8|(d[e+j|0]|0))<<16;t=p}else{p=gj[c[h+196768+(e<<2)>>2]&4095](o)|0;s=p;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;s=r>>>((q<<3&16^16)>>>0)<<16>>16;q=c[2276085]|0;r=s&q;t=r&16777215;p=c[2112932]|0;o=c[p+(t>>>10<<2)>>2]|0;if(o>>>0>9){e=r&1023;u=(d[o+(e+1)|0]|0)<<8|(d[o+e|0]|0);v=q;w=p}else{q=gj[c[p+196688+(o<<2)>>2]&4095](t)|0;u=q;v=c[2276085]|0;w=c[2112932]|0}q=u&65535;u=q+f|0;t=u>>>8;c[2276075]=t;c[2276077]=((u^f)&(u^q))>>>8;c[2276078]=t;c[2276074]=t;t=q+n|0;c[2276076]=t&65535;n=v&s;s=t&65535;v=n&16777215;q=c[w+((v>>>10|16384)<<2)>>2]|0;if(q>>>0>9){u=n&1023;a[q+u|0]=t&255;a[q+(u+1)|0]=(s&65535)>>>8&255;return}else{gg[c[w+196728+(q<<2)>>2]&4095](v,s);return}}function yq(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0);f=n&65535;o=p&-4;if((o|0)==(h|0)){q=p;r=h;s=g}else{c[2276083]=o;g=c[2276085]&o;h=g&16777212;e=c[2112932]|0;j=c[e+((h>>>10|32768)<<2)>>2]|0;if(j>>>0>9){l=g&1020;t=(d[j+(l|3)|0]|0)<<8|(d[j+(l|2)|0]|0)|((d[j+(l|1)|0]|0)<<8|(d[j+l|0]|0))<<16;u=p;v=o}else{o=gj[c[e+196768+(j<<2)>>2]&4095](h)|0;t=o;u=c[2276056]|0;v=c[2276083]|0}c[2276084]=t;q=u;r=v;s=t}t=q+2|0;c[2276056]=t;q=t&-4;if((q|0)==(r|0)){w=s;x=t}else{c[2276083]=q;r=c[2276085]&q;q=r&16777212;v=c[2112932]|0;u=c[v+((q>>>10|32768)<<2)>>2]|0;if(u>>>0>9){o=r&1020;y=(d[u+(o|3)|0]|0)<<8|(d[u+(o|2)|0]|0)|((d[u+(o|1)|0]|0)<<8|(d[u+o|0]|0))<<16;z=t}else{t=gj[c[v+196768+(u<<2)>>2]&4095](q)|0;y=t;z=c[2276056]|0}c[2276084]=y;w=y>>>16|s<<16;x=z}c[2276056]=x+2;x=c[2276085]|0;z=x&w;s=z&16777215;y=c[2112932]|0;t=c[y+(s>>>10<<2)>>2]|0;if(t>>>0>9){q=z&1023;A=(d[t+(q+1)|0]|0)<<8|(d[t+q|0]|0);B=x;C=y}else{x=gj[c[y+196688+(t<<2)>>2]&4095](s)|0;A=x;B=c[2276085]|0;C=c[2112932]|0}x=A&65535;A=x+f|0;s=A>>>8;c[2276075]=s;c[2276077]=((A^f)&(A^x))>>>8;c[2276078]=s;c[2276074]=s;s=x+n|0;c[2276076]=s&65535;n=B&w;w=s&65535;B=n&16777215;x=c[C+((B>>>10|16384)<<2)>>2]|0;if(x>>>0>9){A=n&1023;a[x+A|0]=s&255;a[x+(A+1)|0]=(w&65535)>>>8&255;return}else{gg[c[C+196728+(x<<2)>>2]&4095](B,w);return}}function yr(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;a=9104156+((c[2276069]&7)<<2)|0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n;s=r+2|0;c[2276056]=s;t=c[a>>2]|0;u=t+q|0;v=u>>>24;c[2276075]=v;w=u^q;x=u^t;y=w&x;z=y>>>24;c[2276077]=z;A=t&q;B=u^-8388608;C=t|q;D=B&C;E=D|A;F=E>>>23;c[2276078]=F;c[2276074]=F;c[2276076]=u;c[a>>2]=u;return}c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;G=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;H=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;G=n;H=c[2276056]|0}c[2276084]=G;q=G>>>16|h<<16;r=H;s=r+2|0;c[2276056]=s;t=c[a>>2]|0;u=t+q|0;v=u>>>24;c[2276075]=v;w=u^q;x=u^t;y=w&x;z=y>>>24;c[2276077]=z;A=t&q;B=u^-8388608;C=t|q;D=B&C;E=D|A;F=E>>>23;c[2276078]=F;c[2276074]=F;c[2276076]=u;c[a>>2]=u;return}function ys(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;t=c[2276085]|0;h=t&r;s=h&16777215;n=c[2112932]|0;f=c[n+(s>>>10<<2)>>2]|0;if(f>>>0>9){o=h&1023;u=(d[f+(o+3)|0]|0)<<8|(d[f+(o+2)|0]|0)|((d[f+(o+1)|0]|0)<<8|(d[f+o|0]|0))<<16;v=t;w=n}else{t=gj[c[n+196768+(f<<2)>>2]&4095](s)|0;u=t;v=c[2276085]|0;w=c[2112932]|0}t=u+q|0;s=t>>>24;c[2276075]=s;c[2276077]=((t^q)&(t^u))>>>24;f=((t^-8388608)&(u|q)|u&q)>>>23;c[2276078]=f;c[2276074]=f;c[2276076]=t;f=v&r;r=f&16777215;v=c[w+((r>>>10|16384)<<2)>>2]|0;if(v>>>0>9){q=f&1023;a[v+q|0]=t>>>16&255;a[v+(q+1)|0]=s&255;a[v+(q+2)|0]=t&255;a[v+(q+3)|0]=t>>>8&255;return}else{gg[c[w+196808+(v<<2)>>2]&4095](r,t);return}}function yt(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=9104156+((c[2276069]&7|8)<<2)|0;t=c[r>>2]|0;c[r>>2]=t+4;r=c[2276085]|0;h=r&t;s=h&16777215;n=c[2112932]|0;f=c[n+(s>>>10<<2)>>2]|0;if(f>>>0>9){o=h&1023;u=(d[f+(o+3)|0]|0)<<8|(d[f+(o+2)|0]|0)|((d[f+(o+1)|0]|0)<<8|(d[f+o|0]|0))<<16;v=r;w=n}else{r=gj[c[n+196768+(f<<2)>>2]&4095](s)|0;u=r;v=c[2276085]|0;w=c[2112932]|0}r=u+q|0;s=r>>>24;c[2276075]=s;c[2276077]=((r^q)&(r^u))>>>24;f=((r^-8388608)&(u|q)|u&q)>>>23;c[2276078]=f;c[2276074]=f;c[2276076]=r;f=v&t;t=f&16777215;v=c[w+((t>>>10|16384)<<2)>>2]|0;if(v>>>0>9){q=f&1023;a[v+q|0]=r>>>16&255;a[v+(q+1)|0]=s&255;a[v+(q+2)|0]=r&255;a[v+(q+3)|0]=r>>>8&255;return}else{gg[c[w+196808+(v<<2)>>2]&4095](t,r);return}}function yu(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=9104156+((c[2276069]&7|8)<<2)|0;t=(c[r>>2]|0)-4|0;c[r>>2]=t;r=c[2276085]|0;h=r&t;s=h&16777215;n=c[2112932]|0;f=c[n+(s>>>10<<2)>>2]|0;if(f>>>0>9){o=h&1023;u=(d[f+(o+3)|0]|0)<<8|(d[f+(o+2)|0]|0)|((d[f+(o+1)|0]|0)<<8|(d[f+o|0]|0))<<16;v=r;w=n}else{r=gj[c[n+196768+(f<<2)>>2]&4095](s)|0;u=r;v=c[2276085]|0;w=c[2112932]|0}r=u+q|0;s=r>>>24;c[2276075]=s;c[2276077]=((r^q)&(r^u))>>>24;f=((r^-8388608)&(u|q)|u&q)>>>23;c[2276078]=f;c[2276074]=f;c[2276076]=r;f=v&t;t=f&16777215;v=c[w+((t>>>10|16384)<<2)>>2]|0;if(v>>>0>9){q=f&1023;a[v+q|0]=r>>>16&255;a[v+(q+1)|0]=s&255;a[v+(q+2)|0]=r&255;a[v+(q+3)|0]=r>>>8&255;return}else{gg[c[w+196808+(v<<2)>>2]&4095](t,r);return}}function yv(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;f=p&-4;if((f|0)==(h|0)){q=g;r=p;s=h;t=g}else{c[2276083]=f;h=c[2276085]&f;n=h&16777212;o=c[2112932]|0;e=c[o+((n>>>10|32768)<<2)>>2]|0;if(e>>>0>9){j=h&1020;u=(d[e+(j|3)|0]|0)<<8|(d[e+(j|2)|0]|0)|((d[e+(j|1)|0]|0)<<8|(d[e+j|0]|0))<<16;v=p;w=f}else{f=gj[c[o+196768+(e<<2)>>2]&4095](n)|0;u=f;v=c[2276056]|0;w=c[2276083]|0}c[2276084]=u;q=u>>>16|g<<16;r=v;s=w;t=u}u=r+2|0;c[2276056]=u;r=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;w=u&-4;if((w|0)==(s|0)){x=u;y=t}else{c[2276083]=w;t=c[2276085]&w;w=t&16777212;s=c[2112932]|0;v=c[s+((w>>>10|32768)<<2)>>2]|0;if(v>>>0>9){g=t&1020;z=(d[v+(g|3)|0]|0)<<8|(d[v+(g|2)|0]|0)|((d[v+(g|1)|0]|0)<<8|(d[v+g|0]|0))<<16;A=u}else{u=gj[c[s+196768+(v<<2)>>2]&4095](w)|0;z=u;A=c[2276056]|0}c[2276084]=z;x=A;y=z}c[2276056]=x+2;z=(y>>>((x<<3&16^16)>>>0)<<16>>16)+r|0;r=c[2276085]|0;x=z&r;y=x&16777215;A=c[2112932]|0;u=c[A+(y>>>10<<2)>>2]|0;if(u>>>0>9){w=x&1023;B=(d[u+(w+3)|0]|0)<<8|(d[u+(w+2)|0]|0)|((d[u+(w+1)|0]|0)<<8|(d[u+w|0]|0))<<16;C=r;D=A}else{r=gj[c[A+196768+(u<<2)>>2]&4095](y)|0;B=r;C=c[2276085]|0;D=c[2112932]|0}r=B+q|0;y=r>>>24;c[2276075]=y;c[2276077]=((r^q)&(r^B))>>>24;u=((r^-8388608)&(B|q)|B&q)>>>23;c[2276078]=u;c[2276074]=u;c[2276076]=r;u=C&z;z=u&16777215;C=c[D+((z>>>10|16384)<<2)>>2]|0;if(C>>>0>9){q=u&1023;a[C+q|0]=r>>>16&255;a[C+(q+1)|0]=y&255;a[C+(q+2)|0]=r&255;a[C+(q+3)|0]=r>>>8&255;return}else{gg[c[D+196808+(C<<2)>>2]&4095](z,r);return}}function yw(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=xw(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;t=c[2276085]|0;h=t&r;s=h&16777215;n=c[2112932]|0;f=c[n+(s>>>10<<2)>>2]|0;if(f>>>0>9){o=h&1023;u=(d[f+(o+3)|0]|0)<<8|(d[f+(o+2)|0]|0)|((d[f+(o+1)|0]|0)<<8|(d[f+o|0]|0))<<16;v=t;w=n}else{t=gj[c[n+196768+(f<<2)>>2]&4095](s)|0;u=t;v=c[2276085]|0;w=c[2112932]|0}t=u+q|0;s=t>>>24;c[2276075]=s;c[2276077]=((t^q)&(t^u))>>>24;f=((t^-8388608)&(u|q)|u&q)>>>23;c[2276078]=f;c[2276074]=f;c[2276076]=t;f=v&r;r=f&16777215;v=c[w+((r>>>10|16384)<<2)>>2]|0;if(v>>>0>9){q=f&1023;a[v+q|0]=t>>>16&255;a[v+(q+1)|0]=s&255;a[v+(q+2)|0]=t&255;a[v+(q+3)|0]=t>>>8&255;return}else{gg[c[w+196808+(v<<2)>>2]&4095](r,t);return}}function yx(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;f=p&-4;if((f|0)==(h|0)){q=g;r=p;s=h;t=g}else{c[2276083]=f;h=c[2276085]&f;n=h&16777212;o=c[2112932]|0;e=c[o+((n>>>10|32768)<<2)>>2]|0;if(e>>>0>9){j=h&1020;u=(d[e+(j|3)|0]|0)<<8|(d[e+(j|2)|0]|0)|((d[e+(j|1)|0]|0)<<8|(d[e+j|0]|0))<<16;v=p;w=f}else{f=gj[c[o+196768+(e<<2)>>2]&4095](n)|0;u=f;v=c[2276056]|0;w=c[2276083]|0}c[2276084]=u;q=u>>>16|g<<16;r=v;s=w;t=u}u=r+2|0;c[2276056]=u;r=u&-4;if((r|0)==(s|0)){x=u;y=t}else{c[2276083]=r;t=c[2276085]&r;r=t&16777212;s=c[2112932]|0;w=c[s+((r>>>10|32768)<<2)>>2]|0;if(w>>>0>9){v=t&1020;z=(d[w+(v|3)|0]|0)<<8|(d[w+(v|2)|0]|0)|((d[w+(v|1)|0]|0)<<8|(d[w+v|0]|0))<<16;A=u}else{u=gj[c[s+196768+(w<<2)>>2]&4095](r)|0;z=u;A=c[2276056]|0}c[2276084]=z;x=A;y=z}c[2276056]=x+2;z=y>>>((x<<3&16^16)>>>0)<<16>>16;x=c[2276085]|0;y=z&x;A=y&16777215;u=c[2112932]|0;r=c[u+(A>>>10<<2)>>2]|0;if(r>>>0>9){w=y&1023;B=(d[r+(w+3)|0]|0)<<8|(d[r+(w+2)|0]|0)|((d[r+(w+1)|0]|0)<<8|(d[r+w|0]|0))<<16;C=x;D=u}else{x=gj[c[u+196768+(r<<2)>>2]&4095](A)|0;B=x;C=c[2276085]|0;D=c[2112932]|0}x=B+q|0;A=x>>>24;c[2276075]=A;c[2276077]=((x^q)&(x^B))>>>24;r=((x^-8388608)&(B|q)|B&q)>>>23;c[2276078]=r;c[2276074]=r;c[2276076]=x;r=C&z;z=r&16777215;C=c[D+((z>>>10|16384)<<2)>>2]|0;if(C>>>0>9){q=r&1023;a[C+q|0]=x>>>16&255;a[C+(q+1)|0]=A&255;a[C+(q+2)|0]=x&255;a[C+(q+3)|0]=x>>>8&255;return}else{gg[c[D+196808+(C<<2)>>2]&4095](z,x);return}}function yy(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;f=p&-4;if((f|0)==(h|0)){q=g;r=p;s=h;t=g}else{c[2276083]=f;h=c[2276085]&f;n=h&16777212;o=c[2112932]|0;e=c[o+((n>>>10|32768)<<2)>>2]|0;if(e>>>0>9){j=h&1020;u=(d[e+(j|3)|0]|0)<<8|(d[e+(j|2)|0]|0)|((d[e+(j|1)|0]|0)<<8|(d[e+j|0]|0))<<16;v=p;w=f}else{f=gj[c[o+196768+(e<<2)>>2]&4095](n)|0;u=f;v=c[2276056]|0;w=c[2276083]|0}c[2276084]=u;q=u>>>16|g<<16;r=v;s=w;t=u}u=r+2|0;c[2276056]=u;r=u&-4;if((r|0)==(s|0)){x=u;y=s;z=t}else{c[2276083]=r;t=c[2276085]&r;s=t&16777212;w=c[2112932]|0;v=c[w+((s>>>10|32768)<<2)>>2]|0;if(v>>>0>9){g=t&1020;A=(d[v+(g|3)|0]|0)<<8|(d[v+(g|2)|0]|0)|((d[v+(g|1)|0]|0)<<8|(d[v+g|0]|0))<<16;B=u;C=r}else{r=gj[c[w+196768+(v<<2)>>2]&4095](s)|0;A=r;B=c[2276056]|0;C=c[2276083]|0}c[2276084]=A;x=B;y=C;z=A}A=x+2|0;c[2276056]=A;x=A&-4;if((x|0)==(y|0)){D=z;E=A}else{c[2276083]=x;y=c[2276085]&x;x=y&16777212;C=c[2112932]|0;B=c[C+((x>>>10|32768)<<2)>>2]|0;if(B>>>0>9){r=y&1020;F=(d[B+(r|3)|0]|0)<<8|(d[B+(r|2)|0]|0)|((d[B+(r|1)|0]|0)<<8|(d[B+r|0]|0))<<16;G=A}else{A=gj[c[C+196768+(B<<2)>>2]&4095](x)|0;F=A;G=c[2276056]|0}c[2276084]=F;D=F>>>16|z<<16;E=G}c[2276056]=E+2;E=c[2276085]|0;G=E&D;z=G&16777215;F=c[2112932]|0;A=c[F+(z>>>10<<2)>>2]|0;if(A>>>0>9){x=G&1023;H=(d[A+(x+3)|0]|0)<<8|(d[A+(x+2)|0]|0)|((d[A+(x+1)|0]|0)<<8|(d[A+x|0]|0))<<16;I=E;J=F}else{E=gj[c[F+196768+(A<<2)>>2]&4095](z)|0;H=E;I=c[2276085]|0;J=c[2112932]|0}E=H+q|0;z=E>>>24;c[2276075]=z;c[2276077]=((E^q)&(E^H))>>>24;A=((E^-8388608)&(H|q)|H&q)>>>23;c[2276078]=A;c[2276074]=A;c[2276076]=E;A=I&D;D=A&16777215;I=c[J+((D>>>10|16384)<<2)>>2]|0;if(I>>>0>9){q=A&1023;a[I+q|0]=E>>>16&255;a[I+(q+1)|0]=z&255;a[I+(q+2)|0]=E&255;a[I+(q+3)|0]=E>>>8&255;return}else{gg[c[J+196808+(I<<2)>>2]&4095](D,E);return}}function yz(){var a=0,b=0,d=0,e=0,f=0;a=c[2276069]|0;b=9104156+((a&7)<<2)|0;d=((a>>>9)+7&7)+1|0;a=c[b>>2]|0;e=a&255;f=d+e|0;c[2276075]=f;c[2276077]=(f^d)&(f^e);c[2276078]=f;c[2276074]=f;f=d+a&255;c[2276076]=f;c[b>>2]=f|c[b>>2]&-256;return}function yA(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=c[2276069]|0;d=((b>>>9)+7&7)+1|0;e=c[9104156+((b&7|8)<<2)>>2]|0;b=c[2276085]|0;f=b&e;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=a[i+(f&1023^1)|0]|0;k=b;l=h}else{b=gj[c[h+196608+(i<<2)>>2]&4095](g)|0;j=b;k=c[2276085]|0;l=c[2112932]|0}b=j&255;j=b+d|0;c[2276075]=j;c[2276077]=(j^d)&(j^b);c[2276078]=j;c[2276074]=j;c[2276076]=j&255;b=k&e;e=j&255;j=b&16777215;k=c[l+((j>>>10|16384)<<2)>>2]|0;if(k>>>0>9){a[k+(b&1023^1)|0]=e;return}else{gg[c[l+196648+(k<<2)>>2]&4095](j,e);return}}function yB(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=c[2276069]|0;d=((b>>>9)+7&7)+1|0;e=9104156+((b&7|8)<<2)|0;b=c[e>>2]|0;c[e>>2]=b+1;e=c[2276085]|0;f=e&b;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=a[i+(f&1023^1)|0]|0;k=e;l=h}else{e=gj[c[h+196608+(i<<2)>>2]&4095](g)|0;j=e;k=c[2276085]|0;l=c[2112932]|0}e=j&255;j=e+d|0;c[2276075]=j;c[2276077]=(j^d)&(j^e);c[2276078]=j;c[2276074]=j;c[2276076]=j&255;e=k&b;b=j&255;j=e&16777215;k=c[l+((j>>>10|16384)<<2)>>2]|0;if(k>>>0>9){a[k+(e&1023^1)|0]=b;return}else{gg[c[l+196648+(k<<2)>>2]&4095](j,b);return}}function yC(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=(((c[2276069]|0)>>>9)+7&7)+1|0;d=c[2276054]|0;c[2276054]=d+2;e=c[2276085]|0;f=e&d;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=a[i+(f&1023^1)|0]|0;k=e;l=h}else{e=gj[c[h+196608+(i<<2)>>2]&4095](g)|0;j=e;k=c[2276085]|0;l=c[2112932]|0}e=j&255;j=e+b|0;c[2276075]=j;c[2276077]=(j^b)&(j^e);c[2276078]=j;c[2276074]=j;c[2276076]=j&255;e=k&d;d=j&255;j=e&16777215;k=c[l+((j>>>10|16384)<<2)>>2]|0;if(k>>>0>9){a[k+(e&1023^1)|0]=d;return}else{gg[c[l+196648+(k<<2)>>2]&4095](j,d);return}}function yD(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=c[2276069]|0;d=((b>>>9)+7&7)+1|0;e=9104156+((b&7|8)<<2)|0;b=(c[e>>2]|0)-1|0;c[e>>2]=b;e=c[2276085]|0;f=e&b;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=a[i+(f&1023^1)|0]|0;k=e;l=h}else{e=gj[c[h+196608+(i<<2)>>2]&4095](g)|0;j=e;k=c[2276085]|0;l=c[2112932]|0}e=j&255;j=e+d|0;c[2276075]=j;c[2276077]=(j^d)&(j^e);c[2276078]=j;c[2276074]=j;c[2276076]=j&255;e=k&b;b=j&255;j=e&16777215;k=c[l+((j>>>10|16384)<<2)>>2]|0;if(k>>>0>9){a[k+(e&1023^1)|0]=b;return}else{gg[c[l+196648+(k<<2)>>2]&4095](j,b);return}}function yE(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=(((c[2276069]|0)>>>9)+7&7)+1|0;d=(c[2276054]|0)-2|0;c[2276054]=d;e=c[2276085]|0;f=e&d;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=a[i+(f&1023^1)|0]|0;k=e;l=h}else{e=gj[c[h+196608+(i<<2)>>2]&4095](g)|0;j=e;k=c[2276085]|0;l=c[2112932]|0}e=j&255;j=e+b|0;c[2276075]=j;c[2276077]=(j^b)&(j^e);c[2276078]=j;c[2276074]=j;c[2276076]=j&255;e=k&d;d=j&255;j=e&16777215;k=c[l+((j>>>10|16384)<<2)>>2]|0;if(k>>>0>9){a[k+(e&1023^1)|0]=d;return}else{gg[c[l+196648+(k<<2)>>2]&4095](j,d);return}}function yF(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=c[2276069]|0;e=((b>>>9)+7&7)+1|0;f=c[9104156+((b&7|8)<<2)>>2]|0;b=c[2276056]|0;g=b&-4;if((g|0)==(c[2276083]|0)){h=b;i=c[2276084]|0}else{c[2276083]=g;j=c[2276085]&g;g=j&16777212;k=c[2112932]|0;l=c[k+((g>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=j&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b}else{b=gj[c[k+196768+(l<<2)>>2]&4095](g)|0;n=b;o=c[2276056]|0}c[2276084]=n;h=o;i=n}c[2276056]=h+2;n=(i>>>((h<<3&16^16)>>>0)<<16>>16)+f|0;f=c[2276085]|0;h=n&f;i=h&16777215;o=c[2112932]|0;b=c[o+(i>>>10<<2)>>2]|0;if(b>>>0>9){p=a[b+(h&1023^1)|0]|0;q=f;r=o}else{f=gj[c[o+196608+(b<<2)>>2]&4095](i)|0;p=f;q=c[2276085]|0;r=c[2112932]|0}f=p&255;p=f+e|0;c[2276075]=p;c[2276077]=(p^e)&(p^f);c[2276078]=p;c[2276074]=p;c[2276076]=p&255;f=q&n;n=p&255;p=f&16777215;q=c[r+((p>>>10|16384)<<2)>>2]|0;if(q>>>0>9){a[q+(f&1023^1)|0]=n;return}else{gg[c[r+196648+(q<<2)>>2]&4095](p,n);return}}function yG(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=c[2276069]|0;d=((b>>>9)+7&7)+1|0;e=xw(c[9104156+((b&7|8)<<2)>>2]|0)|0;b=c[2276085]|0;f=b&e;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=a[i+(f&1023^1)|0]|0;k=b;l=h}else{b=gj[c[h+196608+(i<<2)>>2]&4095](g)|0;j=b;k=c[2276085]|0;l=c[2112932]|0}b=j&255;j=b+d|0;c[2276075]=j;c[2276077]=(j^d)&(j^b);c[2276078]=j;c[2276074]=j;c[2276076]=j&255;b=k&e;e=j&255;j=b&16777215;k=c[l+((j>>>10|16384)<<2)>>2]|0;if(k>>>0>9){a[k+(b&1023^1)|0]=e;return}else{gg[c[l+196648+(k<<2)>>2]&4095](j,e);return}}function yH(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=(((c[2276069]|0)>>>9)+7&7)+1|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=h>>>((g<<3&16^16)>>>0)<<16>>16;g=c[2276085]|0;h=m&g;n=h&16777215;e=c[2112932]|0;f=c[e+(n>>>10<<2)>>2]|0;if(f>>>0>9){o=a[f+(h&1023^1)|0]|0;p=g;q=e}else{g=gj[c[e+196608+(f<<2)>>2]&4095](n)|0;o=g;p=c[2276085]|0;q=c[2112932]|0}g=o&255;o=g+b|0;c[2276075]=o;c[2276077]=(o^b)&(o^g);c[2276078]=o;c[2276074]=o;c[2276076]=o&255;g=p&m;m=o&255;o=g&16777215;p=c[q+((o>>>10|16384)<<2)>>2]|0;if(p>>>0>9){a[p+(g&1023^1)|0]=m;return}else{gg[c[q+196648+(p<<2)>>2]&4095](o,m);return}}function yI(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;b=(((c[2276069]|0)>>>9)+7&7)+1|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=f;i=c[2276084]|0}else{c[2276083]=f;j=c[2276085]&f;k=j&16777212;l=c[2112932]|0;m=c[l+((k>>>10|32768)<<2)>>2]|0;if(m>>>0>9){n=j&1020;o=(d[m+(n|3)|0]|0)<<8|(d[m+(n|2)|0]|0)|((d[m+(n|1)|0]|0)<<8|(d[m+n|0]|0))<<16;p=e;q=f}else{f=gj[c[l+196768+(m<<2)>>2]&4095](k)|0;o=f;p=c[2276056]|0;q=c[2276083]|0}c[2276084]=o;g=p;h=q;i=o}o=g+2|0;c[2276056]=o;g=o&-4;if((g|0)==(h|0)){r=i;s=o}else{c[2276083]=g;h=c[2276085]&g;g=h&16777212;q=c[2112932]|0;p=c[q+((g>>>10|32768)<<2)>>2]|0;if(p>>>0>9){f=h&1020;t=(d[p+(f|3)|0]|0)<<8|(d[p+(f|2)|0]|0)|((d[p+(f|1)|0]|0)<<8|(d[p+f|0]|0))<<16;u=o}else{o=gj[c[q+196768+(p<<2)>>2]&4095](g)|0;t=o;u=c[2276056]|0}c[2276084]=t;r=t>>>16|i<<16;s=u}c[2276056]=s+2;s=c[2276085]|0;u=s&r;i=u&16777215;t=c[2112932]|0;o=c[t+(i>>>10<<2)>>2]|0;if(o>>>0>9){v=a[o+(u&1023^1)|0]|0;w=s;x=t}else{s=gj[c[t+196608+(o<<2)>>2]&4095](i)|0;v=s;w=c[2276085]|0;x=c[2112932]|0}s=v&255;v=s+b|0;c[2276075]=v;c[2276077]=(v^b)&(v^s);c[2276078]=v;c[2276074]=v;c[2276076]=v&255;s=w&r;r=v&255;v=s&16777215;w=c[x+((v>>>10|16384)<<2)>>2]|0;if(w>>>0>9){a[w+(s&1023^1)|0]=r;return}else{gg[c[x+196648+(w<<2)>>2]&4095](v,r);return}}function yJ(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[2276069]|0;b=9104156+((a&7)<<2)|0;d=((a>>>9)+7&7)+1|0;a=c[b>>2]|0;e=a&65535;f=d+e|0;g=f>>>8;c[2276075]=g;c[2276077]=((f^d)&(f^e))>>>8;c[2276078]=g;c[2276074]=g;g=d+a&65535;c[2276076]=g;c[b>>2]=g|c[b>>2]&-65536;return}function yK(){var a=0,b=0;a=c[2276069]|0;b=9104156+((a&7|8)<<2)|0;c[b>>2]=(c[b>>2]|0)+1+((a>>>9)+7&7);return}function yL(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[2276069]|0;e=((b>>>9)+7&7)+1|0;f=c[9104156+((b&7|8)<<2)>>2]|0;b=c[2276085]|0;g=b&f;h=g&16777215;i=c[2112932]|0;j=c[i+(h>>>10<<2)>>2]|0;if(j>>>0>9){k=g&1023;l=(d[j+(k+1)|0]|0)<<8|(d[j+k|0]|0);m=b;n=i}else{b=gj[c[i+196688+(j<<2)>>2]&4095](h)|0;l=b;m=c[2276085]|0;n=c[2112932]|0}b=l&65535;l=b+e|0;h=l>>>8;c[2276075]=h;c[2276077]=((l^e)&(l^b))>>>8;c[2276078]=h;c[2276074]=h;c[2276076]=l&65535;h=m&f;f=l&65535;m=h&16777215;b=c[n+((m>>>10|16384)<<2)>>2]|0;if(b>>>0>9){e=h&1023;a[b+e|0]=l&255;a[b+(e+1)|0]=(f&65535)>>>8&255;return}else{gg[c[n+196728+(b<<2)>>2]&4095](m,f);return}}function yM(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[2276069]|0;e=((b>>>9)+7&7)+1|0;f=9104156+((b&7|8)<<2)|0;b=c[f>>2]|0;c[f>>2]=b+2;f=c[2276085]|0;g=f&b;h=g&16777215;i=c[2112932]|0;j=c[i+(h>>>10<<2)>>2]|0;if(j>>>0>9){k=g&1023;l=(d[j+(k+1)|0]|0)<<8|(d[j+k|0]|0);m=f;n=i}else{f=gj[c[i+196688+(j<<2)>>2]&4095](h)|0;l=f;m=c[2276085]|0;n=c[2112932]|0}f=l&65535;l=f+e|0;h=l>>>8;c[2276075]=h;c[2276077]=((l^e)&(l^f))>>>8;c[2276078]=h;c[2276074]=h;c[2276076]=l&65535;h=m&b;b=l&65535;m=h&16777215;f=c[n+((m>>>10|16384)<<2)>>2]|0;if(f>>>0>9){e=h&1023;a[f+e|0]=l&255;a[f+(e+1)|0]=(b&65535)>>>8&255;return}else{gg[c[n+196728+(f<<2)>>2]&4095](m,b);return}}function yN(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[2276069]|0;e=((b>>>9)+7&7)+1|0;f=9104156+((b&7|8)<<2)|0;b=(c[f>>2]|0)-2|0;c[f>>2]=b;f=c[2276085]|0;g=f&b;h=g&16777215;i=c[2112932]|0;j=c[i+(h>>>10<<2)>>2]|0;if(j>>>0>9){k=g&1023;l=(d[j+(k+1)|0]|0)<<8|(d[j+k|0]|0);m=f;n=i}else{f=gj[c[i+196688+(j<<2)>>2]&4095](h)|0;l=f;m=c[2276085]|0;n=c[2112932]|0}f=l&65535;l=f+e|0;h=l>>>8;c[2276075]=h;c[2276077]=((l^e)&(l^f))>>>8;c[2276078]=h;c[2276074]=h;c[2276076]=l&65535;h=m&b;b=l&65535;m=h&16777215;f=c[n+((m>>>10|16384)<<2)>>2]|0;if(f>>>0>9){e=h&1023;a[f+e|0]=l&255;a[f+(e+1)|0]=(b&65535)>>>8&255;return}else{gg[c[n+196728+(f<<2)>>2]&4095](m,b);return}}function yO(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=c[2276069]|0;e=((b>>>9)+7&7)+1|0;f=c[9104156+((b&7|8)<<2)>>2]|0;b=c[2276056]|0;g=b&-4;if((g|0)==(c[2276083]|0)){h=b;i=c[2276084]|0}else{c[2276083]=g;j=c[2276085]&g;g=j&16777212;k=c[2112932]|0;l=c[k+((g>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=j&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b}else{b=gj[c[k+196768+(l<<2)>>2]&4095](g)|0;n=b;o=c[2276056]|0}c[2276084]=n;h=o;i=n}c[2276056]=h+2;n=(i>>>((h<<3&16^16)>>>0)<<16>>16)+f|0;f=c[2276085]|0;h=n&f;i=h&16777215;o=c[2112932]|0;b=c[o+(i>>>10<<2)>>2]|0;if(b>>>0>9){g=h&1023;p=(d[b+(g+1)|0]|0)<<8|(d[b+g|0]|0);q=f;r=o}else{f=gj[c[o+196688+(b<<2)>>2]&4095](i)|0;p=f;q=c[2276085]|0;r=c[2112932]|0}f=p&65535;p=f+e|0;i=p>>>8;c[2276075]=i;c[2276077]=((p^e)&(p^f))>>>8;c[2276078]=i;c[2276074]=i;c[2276076]=p&65535;i=q&n;n=p&65535;q=i&16777215;f=c[r+((q>>>10|16384)<<2)>>2]|0;if(f>>>0>9){e=i&1023;a[f+e|0]=p&255;a[f+(e+1)|0]=(n&65535)>>>8&255;return}else{gg[c[r+196728+(f<<2)>>2]&4095](q,n);return}}function yP(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[2276069]|0;e=((b>>>9)+7&7)+1|0;f=xw(c[9104156+((b&7|8)<<2)>>2]|0)|0;b=c[2276085]|0;g=b&f;h=g&16777215;i=c[2112932]|0;j=c[i+(h>>>10<<2)>>2]|0;if(j>>>0>9){k=g&1023;l=(d[j+(k+1)|0]|0)<<8|(d[j+k|0]|0);m=b;n=i}else{b=gj[c[i+196688+(j<<2)>>2]&4095](h)|0;l=b;m=c[2276085]|0;n=c[2112932]|0}b=l&65535;l=b+e|0;h=l>>>8;c[2276075]=h;c[2276077]=((l^e)&(l^b))>>>8;c[2276078]=h;c[2276074]=h;c[2276076]=l&65535;h=m&f;f=l&65535;m=h&16777215;b=c[n+((m>>>10|16384)<<2)>>2]|0;if(b>>>0>9){e=h&1023;a[b+e|0]=l&255;a[b+(e+1)|0]=(f&65535)>>>8&255;return}else{gg[c[n+196728+(b<<2)>>2]&4095](m,f);return}}function yQ(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=(((c[2276069]|0)>>>9)+7&7)+1|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=h>>>((g<<3&16^16)>>>0)<<16>>16;g=c[2276085]|0;h=m&g;n=h&16777215;e=c[2112932]|0;f=c[e+(n>>>10<<2)>>2]|0;if(f>>>0>9){k=h&1023;o=(d[f+(k+1)|0]|0)<<8|(d[f+k|0]|0);p=g;q=e}else{g=gj[c[e+196688+(f<<2)>>2]&4095](n)|0;o=g;p=c[2276085]|0;q=c[2112932]|0}g=o&65535;o=g+b|0;n=o>>>8;c[2276075]=n;c[2276077]=((o^b)&(o^g))>>>8;c[2276078]=n;c[2276074]=n;c[2276076]=o&65535;n=p&m;m=o&65535;p=n&16777215;g=c[q+((p>>>10|16384)<<2)>>2]|0;if(g>>>0>9){b=n&1023;a[g+b|0]=o&255;a[g+(b+1)|0]=(m&65535)>>>8&255;return}else{gg[c[q+196728+(g<<2)>>2]&4095](p,m);return}}function yR(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;b=(((c[2276069]|0)>>>9)+7&7)+1|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=f;i=c[2276084]|0}else{c[2276083]=f;j=c[2276085]&f;k=j&16777212;l=c[2112932]|0;m=c[l+((k>>>10|32768)<<2)>>2]|0;if(m>>>0>9){n=j&1020;o=(d[m+(n|3)|0]|0)<<8|(d[m+(n|2)|0]|0)|((d[m+(n|1)|0]|0)<<8|(d[m+n|0]|0))<<16;p=e;q=f}else{f=gj[c[l+196768+(m<<2)>>2]&4095](k)|0;o=f;p=c[2276056]|0;q=c[2276083]|0}c[2276084]=o;g=p;h=q;i=o}o=g+2|0;c[2276056]=o;g=o&-4;if((g|0)==(h|0)){r=i;s=o}else{c[2276083]=g;h=c[2276085]&g;g=h&16777212;q=c[2112932]|0;p=c[q+((g>>>10|32768)<<2)>>2]|0;if(p>>>0>9){f=h&1020;t=(d[p+(f|3)|0]|0)<<8|(d[p+(f|2)|0]|0)|((d[p+(f|1)|0]|0)<<8|(d[p+f|0]|0))<<16;u=o}else{o=gj[c[q+196768+(p<<2)>>2]&4095](g)|0;t=o;u=c[2276056]|0}c[2276084]=t;r=t>>>16|i<<16;s=u}c[2276056]=s+2;s=c[2276085]|0;u=s&r;i=u&16777215;t=c[2112932]|0;o=c[t+(i>>>10<<2)>>2]|0;if(o>>>0>9){g=u&1023;v=(d[o+(g+1)|0]|0)<<8|(d[o+g|0]|0);w=s;x=t}else{s=gj[c[t+196688+(o<<2)>>2]&4095](i)|0;v=s;w=c[2276085]|0;x=c[2112932]|0}s=v&65535;v=s+b|0;i=v>>>8;c[2276075]=i;c[2276077]=((v^b)&(v^s))>>>8;c[2276078]=i;c[2276074]=i;c[2276076]=v&65535;i=w&r;r=v&65535;w=i&16777215;s=c[x+((w>>>10|16384)<<2)>>2]|0;if(s>>>0>9){b=i&1023;a[s+b|0]=v&255;a[s+(b+1)|0]=(r&65535)>>>8&255;return}else{gg[c[x+196728+(s<<2)>>2]&4095](w,r);return}}function yS(){var a=0,b=0,d=0,e=0,f=0;a=c[2276069]|0;b=9104156+((a&7)<<2)|0;d=((a>>>9)+7&7)+1|0;a=c[b>>2]|0;e=d+a|0;c[2276075]=e>>>24;c[2276077]=((e^d)&(e^a))>>>24;f=((e^-8388608)&(d|a)|d&a)>>>23;c[2276078]=f;c[2276074]=f;c[2276076]=e;c[b>>2]=e;return}function yT(){var a=0,b=0;a=c[2276069]|0;b=9104156+((a&7|8)<<2)|0;c[b>>2]=(c[b>>2]|0)+1+((a>>>9)+7&7);return}function yU(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[2276069]|0;e=((b>>>9)+7&7)+1|0;f=c[9104156+((b&7|8)<<2)>>2]|0;b=c[2276085]|0;g=b&f;h=g&16777215;i=c[2112932]|0;j=c[i+(h>>>10<<2)>>2]|0;if(j>>>0>9){k=g&1023;l=(d[j+(k+3)|0]|0)<<8|(d[j+(k+2)|0]|0)|((d[j+(k+1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b;n=i}else{b=gj[c[i+196768+(j<<2)>>2]&4095](h)|0;l=b;m=c[2276085]|0;n=c[2112932]|0}b=l+e|0;h=b>>>24;c[2276075]=h;c[2276077]=((b^e)&(b^l))>>>24;j=((b^-8388608)&(l|e)|l&e)>>>23;c[2276078]=j;c[2276074]=j;c[2276076]=b;j=m&f;f=j&16777215;m=c[n+((f>>>10|16384)<<2)>>2]|0;if(m>>>0>9){e=j&1023;a[m+e|0]=b>>>16&255;a[m+(e+1)|0]=h&255;a[m+(e+2)|0]=b&255;a[m+(e+3)|0]=b>>>8&255;return}else{gg[c[n+196808+(m<<2)>>2]&4095](f,b);return}}function yV(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[2276069]|0;e=((b>>>9)+7&7)+1|0;f=9104156+((b&7|8)<<2)|0;b=c[f>>2]|0;c[f>>2]=b+4;f=c[2276085]|0;g=f&b;h=g&16777215;i=c[2112932]|0;j=c[i+(h>>>10<<2)>>2]|0;if(j>>>0>9){k=g&1023;l=(d[j+(k+3)|0]|0)<<8|(d[j+(k+2)|0]|0)|((d[j+(k+1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=f;n=i}else{f=gj[c[i+196768+(j<<2)>>2]&4095](h)|0;l=f;m=c[2276085]|0;n=c[2112932]|0}f=l+e|0;h=f>>>24;c[2276075]=h;c[2276077]=((f^e)&(f^l))>>>24;j=((f^-8388608)&(l|e)|l&e)>>>23;c[2276078]=j;c[2276074]=j;c[2276076]=f;j=m&b;b=j&16777215;m=c[n+((b>>>10|16384)<<2)>>2]|0;if(m>>>0>9){e=j&1023;a[m+e|0]=f>>>16&255;a[m+(e+1)|0]=h&255;a[m+(e+2)|0]=f&255;a[m+(e+3)|0]=f>>>8&255;return}else{gg[c[n+196808+(m<<2)>>2]&4095](b,f);return}}function yW(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[2276069]|0;e=((b>>>9)+7&7)+1|0;f=9104156+((b&7|8)<<2)|0;b=(c[f>>2]|0)-4|0;c[f>>2]=b;f=c[2276085]|0;g=f&b;h=g&16777215;i=c[2112932]|0;j=c[i+(h>>>10<<2)>>2]|0;if(j>>>0>9){k=g&1023;l=(d[j+(k+3)|0]|0)<<8|(d[j+(k+2)|0]|0)|((d[j+(k+1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=f;n=i}else{f=gj[c[i+196768+(j<<2)>>2]&4095](h)|0;l=f;m=c[2276085]|0;n=c[2112932]|0}f=l+e|0;h=f>>>24;c[2276075]=h;c[2276077]=((f^e)&(f^l))>>>24;j=((f^-8388608)&(l|e)|l&e)>>>23;c[2276078]=j;c[2276074]=j;c[2276076]=f;j=m&b;b=j&16777215;m=c[n+((b>>>10|16384)<<2)>>2]|0;if(m>>>0>9){e=j&1023;a[m+e|0]=f>>>16&255;a[m+(e+1)|0]=h&255;a[m+(e+2)|0]=f&255;a[m+(e+3)|0]=f>>>8&255;return}else{gg[c[n+196808+(m<<2)>>2]&4095](b,f);return}}function yX(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=c[2276069]|0;e=((b>>>9)+7&7)+1|0;f=c[9104156+((b&7|8)<<2)>>2]|0;b=c[2276056]|0;g=b&-4;if((g|0)==(c[2276083]|0)){h=b;i=c[2276084]|0}else{c[2276083]=g;j=c[2276085]&g;g=j&16777212;k=c[2112932]|0;l=c[k+((g>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=j&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b}else{b=gj[c[k+196768+(l<<2)>>2]&4095](g)|0;n=b;o=c[2276056]|0}c[2276084]=n;h=o;i=n}c[2276056]=h+2;n=(i>>>((h<<3&16^16)>>>0)<<16>>16)+f|0;f=c[2276085]|0;h=n&f;i=h&16777215;o=c[2112932]|0;b=c[o+(i>>>10<<2)>>2]|0;if(b>>>0>9){g=h&1023;p=(d[b+(g+3)|0]|0)<<8|(d[b+(g+2)|0]|0)|((d[b+(g+1)|0]|0)<<8|(d[b+g|0]|0))<<16;q=f;r=o}else{f=gj[c[o+196768+(b<<2)>>2]&4095](i)|0;p=f;q=c[2276085]|0;r=c[2112932]|0}f=p+e|0;i=f>>>24;c[2276075]=i;c[2276077]=((f^e)&(f^p))>>>24;b=((f^-8388608)&(p|e)|p&e)>>>23;c[2276078]=b;c[2276074]=b;c[2276076]=f;b=q&n;n=b&16777215;q=c[r+((n>>>10|16384)<<2)>>2]|0;if(q>>>0>9){e=b&1023;a[q+e|0]=f>>>16&255;a[q+(e+1)|0]=i&255;a[q+(e+2)|0]=f&255;a[q+(e+3)|0]=f>>>8&255;return}else{gg[c[r+196808+(q<<2)>>2]&4095](n,f);return}}function yY(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[2276069]|0;e=((b>>>9)+7&7)+1|0;f=xw(c[9104156+((b&7|8)<<2)>>2]|0)|0;b=c[2276085]|0;g=b&f;h=g&16777215;i=c[2112932]|0;j=c[i+(h>>>10<<2)>>2]|0;if(j>>>0>9){k=g&1023;l=(d[j+(k+3)|0]|0)<<8|(d[j+(k+2)|0]|0)|((d[j+(k+1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b;n=i}else{b=gj[c[i+196768+(j<<2)>>2]&4095](h)|0;l=b;m=c[2276085]|0;n=c[2112932]|0}b=l+e|0;h=b>>>24;c[2276075]=h;c[2276077]=((b^e)&(b^l))>>>24;j=((b^-8388608)&(l|e)|l&e)>>>23;c[2276078]=j;c[2276074]=j;c[2276076]=b;j=m&f;f=j&16777215;m=c[n+((f>>>10|16384)<<2)>>2]|0;if(m>>>0>9){e=j&1023;a[m+e|0]=b>>>16&255;a[m+(e+1)|0]=h&255;a[m+(e+2)|0]=b&255;a[m+(e+3)|0]=b>>>8&255;return}else{gg[c[n+196808+(m<<2)>>2]&4095](f,b);return}}function yZ(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=(((c[2276069]|0)>>>9)+7&7)+1|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=h>>>((g<<3&16^16)>>>0)<<16>>16;g=c[2276085]|0;h=m&g;n=h&16777215;e=c[2112932]|0;f=c[e+(n>>>10<<2)>>2]|0;if(f>>>0>9){k=h&1023;o=(d[f+(k+3)|0]|0)<<8|(d[f+(k+2)|0]|0)|((d[f+(k+1)|0]|0)<<8|(d[f+k|0]|0))<<16;p=g;q=e}else{g=gj[c[e+196768+(f<<2)>>2]&4095](n)|0;o=g;p=c[2276085]|0;q=c[2112932]|0}g=o+b|0;n=g>>>24;c[2276075]=n;c[2276077]=((g^b)&(g^o))>>>24;f=((g^-8388608)&(o|b)|o&b)>>>23;c[2276078]=f;c[2276074]=f;c[2276076]=g;f=p&m;m=f&16777215;p=c[q+((m>>>10|16384)<<2)>>2]|0;if(p>>>0>9){b=f&1023;a[p+b|0]=g>>>16&255;a[p+(b+1)|0]=n&255;a[p+(b+2)|0]=g&255;a[p+(b+3)|0]=g>>>8&255;return}else{gg[c[q+196808+(p<<2)>>2]&4095](m,g);return}}function y_(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;b=(((c[2276069]|0)>>>9)+7&7)+1|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=f;i=c[2276084]|0}else{c[2276083]=f;j=c[2276085]&f;k=j&16777212;l=c[2112932]|0;m=c[l+((k>>>10|32768)<<2)>>2]|0;if(m>>>0>9){n=j&1020;o=(d[m+(n|3)|0]|0)<<8|(d[m+(n|2)|0]|0)|((d[m+(n|1)|0]|0)<<8|(d[m+n|0]|0))<<16;p=e;q=f}else{f=gj[c[l+196768+(m<<2)>>2]&4095](k)|0;o=f;p=c[2276056]|0;q=c[2276083]|0}c[2276084]=o;g=p;h=q;i=o}o=g+2|0;c[2276056]=o;g=o&-4;if((g|0)==(h|0)){r=i;s=o}else{c[2276083]=g;h=c[2276085]&g;g=h&16777212;q=c[2112932]|0;p=c[q+((g>>>10|32768)<<2)>>2]|0;if(p>>>0>9){f=h&1020;t=(d[p+(f|3)|0]|0)<<8|(d[p+(f|2)|0]|0)|((d[p+(f|1)|0]|0)<<8|(d[p+f|0]|0))<<16;u=o}else{o=gj[c[q+196768+(p<<2)>>2]&4095](g)|0;t=o;u=c[2276056]|0}c[2276084]=t;r=t>>>16|i<<16;s=u}c[2276056]=s+2;s=c[2276085]|0;u=s&r;i=u&16777215;t=c[2112932]|0;o=c[t+(i>>>10<<2)>>2]|0;if(o>>>0>9){g=u&1023;v=(d[o+(g+3)|0]|0)<<8|(d[o+(g+2)|0]|0)|((d[o+(g+1)|0]|0)<<8|(d[o+g|0]|0))<<16;w=s;x=t}else{s=gj[c[t+196768+(o<<2)>>2]&4095](i)|0;v=s;w=c[2276085]|0;x=c[2112932]|0}s=v+b|0;i=s>>>24;c[2276075]=i;c[2276077]=((s^b)&(s^v))>>>24;o=((s^-8388608)&(v|b)|v&b)>>>23;c[2276078]=o;c[2276074]=o;c[2276076]=s;o=w&r;r=o&16777215;w=c[x+((r>>>10|16384)<<2)>>2]|0;if(w>>>0>9){b=o&1023;a[w+b|0]=s>>>16&255;a[w+(b+1)|0]=i&255;a[w+(b+2)|0]=s&255;a[w+(b+3)|0]=s>>>8&255;return}else{gg[c[x+196808+(w<<2)>>2]&4095](r,s);return}}function y$(){var a=0,b=0,d=0,e=0;a=c[2276069]|0;b=9104156+((a>>>9&7)<<2)|0;d=c[9104156+((a&7)<<2)>>2]&255;a=c[b>>2]&255;e=a+d+((c[2276074]|0)>>>8&1)|0;c[2276075]=e;c[2276077]=(e^d)&(e^a);c[2276078]=e;c[2276074]=e;a=e&255;c[2276076]=a|c[2276076];c[b>>2]=a|c[b>>2]&-256;return}function y0(){var a=0,b=0,d=0,e=0,f=0;a=c[2276069]|0;b=9104156+((a>>>9&7)<<2)|0;d=c[9104156+((a&7)<<2)>>2]&65535;a=c[b>>2]&65535;e=a+d+((c[2276074]|0)>>>8&1)|0;f=e>>>8;c[2276075]=f;c[2276077]=((e^d)&(e^a))>>>8;c[2276078]=f;c[2276074]=f;f=e&65535;c[2276076]=f|c[2276076];c[b>>2]=f|c[b>>2]&-65536;return}function y1(){var a=0,b=0,d=0,e=0,f=0;a=c[2276069]|0;b=9104156+((a>>>9&7)<<2)|0;d=c[9104156+((a&7)<<2)>>2]|0;a=c[b>>2]|0;e=a+d+((c[2276074]|0)>>>8&1)|0;c[2276075]=e>>>24;c[2276077]=((e^d)&(e^a))>>>24;f=((e^-8388608)&(a|d)|a&d)>>>23;c[2276078]=f;c[2276074]=f;c[2276076]=e|c[2276076];c[b>>2]=e;return}function y2(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;b=c[2276085]|0;e=b&d;d=e&16777215;f=c[2112932]|0;g=c[f+(d>>>10<<2)>>2]|0;if(g>>>0>9){h=a[g+(e&1023^1)|0]|0;i=b;j=f}else{b=gj[c[f+196608+(g<<2)>>2]&4095](d)|0;h=b;i=c[2276085]|0;j=c[2112932]|0}b=h&255;h=(c[2276054]|0)-2|0;c[2276054]=h;d=i&h;g=d&16777215;f=c[j+(g>>>10<<2)>>2]|0;if(f>>>0>9){k=a[f+(d&1023^1)|0]|0;l=i;m=j}else{i=gj[c[j+196608+(f<<2)>>2]&4095](g)|0;k=i;l=c[2276085]|0;m=c[2112932]|0}i=k&255;k=i+b+((c[2276074]|0)>>>8&1)|0;c[2276075]=k;c[2276077]=(k^b)&(k^i);c[2276078]=k;c[2276074]=k;c[2276076]=k&255|c[2276076];i=l&h;h=k&255;k=i&16777215;l=c[m+((k>>>10|16384)<<2)>>2]|0;if(l>>>0>9){a[l+(i&1023^1)|0]=h;return}else{gg[c[m+196648+(l<<2)>>2]&4095](k,h);return}}function y3(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=(c[2276054]|0)-2|0;c[2276054]=b;d=c[2276085]&b;b=d&16777215;e=c[2112932]|0;f=c[e+(b>>>10<<2)>>2]|0;if(f>>>0>9){g=a[f+(d&1023^1)|0]|0;h=e}else{d=gj[c[e+196608+(f<<2)>>2]&4095](b)|0;g=d;h=c[2112932]|0}d=g&255;g=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;b=(c[g>>2]|0)-1|0;c[g>>2]=b;g=c[2276085]|0;f=g&b;e=f&16777215;i=c[h+(e>>>10<<2)>>2]|0;if(i>>>0>9){j=a[i+(f&1023^1)|0]|0;k=g;l=h}else{g=gj[c[h+196608+(i<<2)>>2]&4095](e)|0;j=g;k=c[2276085]|0;l=c[2112932]|0}g=j&255;j=g+d+((c[2276074]|0)>>>8&1)|0;c[2276075]=j;c[2276077]=(j^d)&(j^g);c[2276078]=j;c[2276074]=j;c[2276076]=j&255|c[2276076];g=k&b;b=j&255;j=g&16777215;k=c[l+((j>>>10|16384)<<2)>>2]|0;if(k>>>0>9){a[k+(g&1023^1)|0]=b;return}else{gg[c[l+196648+(k<<2)>>2]&4095](j,b);return}}function y4(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=(c[2276054]|0)-2|0;c[2276054]=b;d=c[2276085]|0;e=d&b;f=e&16777215;g=c[2112932]|0;h=c[g+(f>>>10<<2)>>2]|0;if(h>>>0>9){i=a[h+(e&1023^1)|0]|0;j=b;k=d;l=g}else{d=gj[c[g+196608+(h<<2)>>2]&4095](f)|0;i=d;j=c[2276054]|0;k=c[2276085]|0;l=c[2112932]|0}d=i&255;i=j-2|0;c[2276054]=i;j=k&i;f=j&16777215;h=c[l+(f>>>10<<2)>>2]|0;if(h>>>0>9){m=a[h+(j&1023^1)|0]|0;n=k;o=l}else{k=gj[c[l+196608+(h<<2)>>2]&4095](f)|0;m=k;n=c[2276085]|0;o=c[2112932]|0}k=m&255;m=k+d+((c[2276074]|0)>>>8&1)|0;c[2276075]=m;c[2276077]=(m^d)&(m^k);c[2276078]=m;c[2276074]=m;c[2276076]=m&255|c[2276076];k=n&i;i=m&255;m=k&16777215;n=c[o+((m>>>10|16384)<<2)>>2]|0;if(n>>>0>9){a[n+(k&1023^1)|0]=i;return}else{gg[c[o+196648+(n<<2)>>2]&4095](m,i);return}}function y5(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;b=c[2276085]&d;d=b&16777215;e=c[2112932]|0;f=c[e+(d>>>10<<2)>>2]|0;if(f>>>0>9){g=a[f+(b&1023^1)|0]|0;h=e}else{b=gj[c[e+196608+(f<<2)>>2]&4095](d)|0;g=b;h=c[2112932]|0}b=g&255;g=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;d=(c[g>>2]|0)-1|0;c[g>>2]=d;g=c[2276085]|0;f=g&d;e=f&16777215;i=c[h+(e>>>10<<2)>>2]|0;if(i>>>0>9){j=a[i+(f&1023^1)|0]|0;k=g;l=h}else{g=gj[c[h+196608+(i<<2)>>2]&4095](e)|0;j=g;k=c[2276085]|0;l=c[2112932]|0}g=j&255;j=g+b+((c[2276074]|0)>>>8&1)|0;c[2276075]=j;c[2276077]=(j^b)&(j^g);c[2276078]=j;c[2276074]=j;c[2276076]=j&255|c[2276076];g=k&d;d=j&255;j=g&16777215;k=c[l+((j>>>10|16384)<<2)>>2]|0;if(k>>>0>9){a[k+(g&1023^1)|0]=d;return}else{gg[c[l+196648+(k<<2)>>2]&4095](j,d);return}}function y6(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=(c[b>>2]|0)-2|0;c[b>>2]=e;b=c[2276085]&e;e=b&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=b&1023;i=(d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0);j=f}else{h=gj[c[f+196688+(g<<2)>>2]&4095](e)|0;i=h;j=c[2112932]|0}h=i&65535;i=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;e=(c[i>>2]|0)-2|0;c[i>>2]=e;i=c[2276085]|0;g=i&e;f=g&16777215;b=c[j+(f>>>10<<2)>>2]|0;if(b>>>0>9){k=g&1023;l=(d[b+(k+1)|0]|0)<<8|(d[b+k|0]|0);m=i;n=j}else{i=gj[c[j+196688+(b<<2)>>2]&4095](f)|0;l=i;m=c[2276085]|0;n=c[2112932]|0}i=l&65535;l=i+h+((c[2276074]|0)>>>8&1)|0;f=l>>>8;c[2276075]=f;c[2276077]=((l^h)&(l^i))>>>8;c[2276078]=f;c[2276074]=f;c[2276076]=l&65535|c[2276076];f=m&e;e=l&65535;m=f&16777215;i=c[n+((m>>>10|16384)<<2)>>2]|0;if(i>>>0>9){h=f&1023;a[i+h|0]=l&255;a[i+(h+1)|0]=(e&65535)>>>8&255;return}else{gg[c[n+196728+(i<<2)>>2]&4095](m,e);return}}function y7(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=(c[b>>2]|0)-4|0;c[b>>2]=e;b=c[2276085]&e;e=b&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=b&1023;i=(d[g+(h+3)|0]|0)<<8|(d[g+(h+2)|0]|0)|((d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0))<<16;j=f}else{h=gj[c[f+196768+(g<<2)>>2]&4095](e)|0;i=h;j=c[2112932]|0}h=9104156+(((c[2276069]|0)>>>9&7|8)<<2)|0;e=(c[h>>2]|0)-4|0;c[h>>2]=e;h=c[2276085]|0;g=h&e;f=g&16777215;b=c[j+(f>>>10<<2)>>2]|0;if(b>>>0>9){k=g&1023;l=(d[b+(k+3)|0]|0)<<8|(d[b+(k+2)|0]|0)|((d[b+(k+1)|0]|0)<<8|(d[b+k|0]|0))<<16;m=h;n=j}else{h=gj[c[j+196768+(b<<2)>>2]&4095](f)|0;l=h;m=c[2276085]|0;n=c[2112932]|0}h=l+i+((c[2276074]|0)>>>8&1)|0;f=h>>>24;c[2276075]=f;c[2276077]=((h^i)&(h^l))>>>24;b=((h^-8388608)&(l|i)|l&i)>>>23;c[2276078]=b;c[2276074]=b;c[2276076]=h|c[2276076];b=m&e;e=b&16777215;m=c[n+((e>>>10|16384)<<2)>>2]|0;if(m>>>0>9){i=b&1023;a[m+i|0]=h>>>16&255;a[m+(i+1)|0]=f&255;a[m+(i+2)|0]=h&255;a[m+(i+3)|0]=h>>>8&255;return}else{gg[c[n+196808+(m<<2)>>2]&4095](e,h);return}}function y8(){var a=0,b=0,d=0;a=c[2276069]|0;b=9104156+((a>>>9&7)<<2)|0;d=c[b>>2]&(c[9104156+((a&7)<<2)>>2]|-256);c[b>>2]=d;b=d&255;c[2276076]=b;c[2276075]=b;c[2276078]=0;c[2276077]=0;return}function y9(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=c[2276069]|0;d=c[2276085]&c[9104156+((b&7|8)<<2)>>2];e=d&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=a[g+(d&1023^1)|0]|0;i=b}else{b=gj[c[f+196608+(g<<2)>>2]&4095](e)|0;h=b;i=c[2276069]|0}b=9104156+((i>>>9&7)<<2)|0;i=c[b>>2]&(h&255|-256);c[b>>2]=i;b=i&255;c[2276076]=b;c[2276075]=b;c[2276078]=0;c[2276077]=0;return}function za(){var b=0,d=0,e=0,f=0,g=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;b=c[2276085]&d;d=b&16777215;e=c[2112932]|0;f=c[e+(d>>>10<<2)>>2]|0;if(f>>>0>9){g=a[f+(b&1023^1)|0]|0}else{g=gj[c[e+196608+(f<<2)>>2]&4095](d)|0}d=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;f=c[d>>2]&(g&255|-256);c[d>>2]=f;d=f&255;c[2276076]=d;c[2276075]=d;c[2276078]=0;c[2276077]=0;return}function zb(){var b=0,d=0,e=0,f=0,g=0;b=c[2276054]|0;c[2276054]=b+2;d=c[2276085]&b;b=d&16777215;e=c[2112932]|0;f=c[e+(b>>>10<<2)>>2]|0;if(f>>>0>9){g=a[f+(d&1023^1)|0]|0}else{g=gj[c[e+196608+(f<<2)>>2]&4095](b)|0}b=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;f=c[b>>2]&(g&255|-256);c[b>>2]=f;b=f&255;c[2276076]=b;c[2276075]=b;c[2276078]=0;c[2276077]=0;return}function zc(){var b=0,d=0,e=0,f=0,g=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;b=c[2276085]&d;d=b&16777215;e=c[2112932]|0;f=c[e+(d>>>10<<2)>>2]|0;if(f>>>0>9){g=a[f+(b&1023^1)|0]|0}else{g=gj[c[e+196608+(f<<2)>>2]&4095](d)|0}d=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;f=c[d>>2]&(g&255|-256);c[d>>2]=f;d=f&255;c[2276076]=d;c[2276075]=d;c[2276078]=0;c[2276077]=0;return}function zd(){var b=0,d=0,e=0,f=0,g=0;b=(c[2276054]|0)-2|0;c[2276054]=b;d=c[2276085]&b;b=d&16777215;e=c[2112932]|0;f=c[e+(b>>>10<<2)>>2]|0;if(f>>>0>9){g=a[f+(d&1023^1)|0]|0}else{g=gj[c[e+196608+(f<<2)>>2]&4095](b)|0}b=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;f=c[b>>2]&(g&255|-256);c[b>>2]=f;b=f&255;c[2276076]=b;c[2276075]=b;c[2276078]=0;c[2276077]=0;return}function ze(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=(h>>>((g<<3&16^16)>>>0)<<16>>16)+b&c[2276085];b=m&16777215;g=c[2112932]|0;h=c[g+(b>>>10<<2)>>2]|0;if(h>>>0>9){o=a[h+(m&1023^1)|0]|0;p=o&255;q=p|-256;r=c[2276069]|0;s=r>>>9;t=s&7;u=9104156+(t<<2)|0;v=c[u>>2]|0;w=v&q;c[u>>2]=w;x=w&255;c[2276076]=x;c[2276075]=x;c[2276078]=0;c[2276077]=0;return}else{o=gj[c[g+196608+(h<<2)>>2]&4095](b)|0;p=o&255;q=p|-256;r=c[2276069]|0;s=r>>>9;t=s&7;u=9104156+(t<<2)|0;v=c[u>>2]|0;w=v&q;c[u>>2]=w;x=w&255;c[2276076]=x;c[2276075]=x;c[2276078]=0;c[2276077]=0;return}}function zf(){var b=0,d=0,e=0,f=0,g=0;b=xw(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;d=c[2276085]&b;b=d&16777215;e=c[2112932]|0;f=c[e+(b>>>10<<2)>>2]|0;if(f>>>0>9){g=a[f+(d&1023^1)|0]|0}else{g=gj[c[e+196608+(f<<2)>>2]&4095](b)|0}b=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;f=c[b>>2]&(g&255|-256);c[b>>2]=f;b=f&255;c[2276076]=b;c[2276075]=b;c[2276078]=0;c[2276077]=0;return}function zg(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)<<16>>16&c[2276085];f=l&16777215;g=c[2112932]|0;m=c[g+(f>>>10<<2)>>2]|0;if(m>>>0>9){n=a[m+(l&1023^1)|0]|0;o=n&255;p=o|-256;q=c[2276069]|0;r=q>>>9;s=r&7;t=9104156+(s<<2)|0;u=c[t>>2]|0;v=u&p;c[t>>2]=v;w=v&255;c[2276076]=w;c[2276075]=w;c[2276078]=0;c[2276077]=0;return}else{n=gj[c[g+196608+(m<<2)>>2]&4095](f)|0;o=n&255;p=o|-256;q=c[2276069]|0;r=q>>>9;s=r&7;t=9104156+(s<<2)|0;u=c[t>>2]|0;v=u&p;c[t>>2]=v;w=v&255;c[2276076]=w;c[2276075]=w;c[2276078]=0;c[2276077]=0;return}}function zh(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[2276085]&q;q=r&16777215;t=c[2112932]|0;h=c[t+(q>>>10<<2)>>2]|0;if(h>>>0>9){u=a[h+(r&1023^1)|0]|0;v=u&255;w=v|-256;x=c[2276069]|0;y=x>>>9;z=y&7;A=9104156+(z<<2)|0;B=c[A>>2]|0;C=B&w;c[A>>2]=C;D=C&255;c[2276076]=D;c[2276075]=D;c[2276078]=0;c[2276077]=0;return}else{u=gj[c[t+196608+(h<<2)>>2]&4095](q)|0;v=u&255;w=v|-256;x=c[2276069]|0;y=x>>>9;z=y&7;A=9104156+(z<<2)|0;B=c[A>>2]|0;C=B&w;c[A>>2]=C;D=C&255;c[2276076]=D;c[2276075]=D;c[2276078]=0;c[2276077]=0;return}}function zi(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{k=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=k;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=(g>>>((f<<3&16^16)>>>0)<<16>>16)+b|0;b=l&16777215;f=c[2112932]|0;g=c[f+((b>>>10|32768)<<2)>>2]|0;if(g>>>0>9){n=a[g+(l&1023^1)|0]|0;o=n&255;p=o|-256;q=c[2276069]|0;r=q>>>9;s=r&7;t=9104156+(s<<2)|0;u=c[t>>2]|0;v=u&p;c[t>>2]=v;w=v&255;c[2276076]=w;c[2276075]=w;c[2276078]=0;c[2276077]=0;return}else{n=gj[c[f+196608+(g<<2)>>2]&4095](b)|0;o=n&255;p=o|-256;q=c[2276069]|0;r=q>>>9;s=r&7;t=9104156+(s<<2)|0;u=c[t>>2]|0;v=u&p;c[t>>2]=v;w=v&255;c[2276076]=w;c[2276075]=w;c[2276078]=0;c[2276077]=0;return}}function zj(){var b=0,d=0,e=0,f=0,g=0;b=xw(c[2276056]|0)|0;d=b&16777215;e=c[2112932]|0;f=c[e+((d>>>10|32768)<<2)>>2]|0;if(f>>>0>9){g=a[f+(b&1023^1)|0]|0}else{g=gj[c[e+196608+(f<<2)>>2]&4095](d)|0}d=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;f=c[d>>2]&(g&255|-256);c[d>>2]=f;d=f&255;c[2276076]=d;c[2276075]=d;c[2276078]=0;c[2276077]=0;return}function zk(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;l=(f>>>((e<<3&16^16)>>>0)|-256)&c[k>>2];c[k>>2]=l;k=l&255;c[2276076]=k;c[2276075]=k;c[2276078]=0;c[2276077]=0;return}function zl(){var a=0,b=0,d=0;a=c[2276069]|0;b=9104156+((a>>>9&7)<<2)|0;d=c[b>>2]&(c[9104156+((a&7)<<2)>>2]|-65536);c[b>>2]=d;b=d&65535;c[2276076]=b;c[2276075]=b>>>8;c[2276078]=0;c[2276077]=0;return}function zm(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0;a=c[2276069]|0;b=c[2276085]&c[9104156+((a&7|8)<<2)>>2];e=b&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=b&1023;i=(d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0);j=a}else{a=gj[c[f+196688+(g<<2)>>2]&4095](e)|0;i=a;j=c[2276069]|0}a=9104156+((j>>>9&7)<<2)|0;j=c[a>>2]&(i&65535|-65536);c[a>>2]=j;a=j&65535;c[2276076]=a;c[2276075]=a>>>8;c[2276078]=0;c[2276077]=0;return}function zn(){var a=0,b=0,e=0,f=0,g=0,h=0;a=9104156+((c[2276069]&7|8)<<2)|0;b=c[a>>2]|0;c[a>>2]=b+2;a=c[2276085]&b;b=a&16777215;e=c[2112932]|0;f=c[e+(b>>>10<<2)>>2]|0;if(f>>>0>9){g=a&1023;h=(d[f+(g+1)|0]|0)<<8|(d[f+g|0]|0)}else{h=gj[c[e+196688+(f<<2)>>2]&4095](b)|0}b=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;f=c[b>>2]&(h&65535|-65536);c[b>>2]=f;b=f&65535;c[2276076]=b;c[2276075]=b>>>8;c[2276078]=0;c[2276077]=0;return}function zo(){var a=0,b=0,e=0,f=0,g=0,h=0;a=9104156+((c[2276069]&7|8)<<2)|0;b=(c[a>>2]|0)-2|0;c[a>>2]=b;a=c[2276085]&b;b=a&16777215;e=c[2112932]|0;f=c[e+(b>>>10<<2)>>2]|0;if(f>>>0>9){g=a&1023;h=(d[f+(g+1)|0]|0)<<8|(d[f+g|0]|0)}else{h=gj[c[e+196688+(f<<2)>>2]&4095](b)|0}b=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;f=c[b>>2]&(h&65535|-65536);c[b>>2]=f;b=f&65535;c[2276076]=b;c[2276075]=b>>>8;c[2276078]=0;c[2276077]=0;return}function zp(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;a=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=(g>>>((f<<3&16^16)>>>0)<<16>>16)+a&c[2276085];a=l&16777215;f=c[2112932]|0;g=c[f+(a>>>10<<2)>>2]|0;if(g>>>0>9){m=l&1023;n=(d[g+(m+1)|0]|0)<<8|(d[g+m|0]|0);o=n&65535;p=o|-65536;q=c[2276069]|0;r=q>>>9;s=r&7;t=9104156+(s<<2)|0;u=c[t>>2]|0;v=u&p;c[t>>2]=v;w=v&65535;c[2276076]=w;x=w>>>8;c[2276075]=x;c[2276078]=0;c[2276077]=0;return}else{n=gj[c[f+196688+(g<<2)>>2]&4095](a)|0;o=n&65535;p=o|-65536;q=c[2276069]|0;r=q>>>9;s=r&7;t=9104156+(s<<2)|0;u=c[t>>2]|0;v=u&p;c[t>>2]=v;w=v&65535;c[2276076]=w;x=w>>>8;c[2276075]=x;c[2276078]=0;c[2276077]=0;return}}function zq(){var a=0,b=0,e=0,f=0,g=0,h=0;a=xw(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;b=c[2276085]&a;a=b&16777215;e=c[2112932]|0;f=c[e+(a>>>10<<2)>>2]|0;if(f>>>0>9){g=b&1023;h=(d[f+(g+1)|0]|0)<<8|(d[f+g|0]|0)}else{h=gj[c[e+196688+(f<<2)>>2]&4095](a)|0}a=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;f=c[a>>2]&(h&65535|-65536);c[a>>2]=f;a=f&65535;c[2276076]=a;c[2276075]=a>>>8;c[2276078]=0;c[2276077]=0;return}function zr(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=f>>>((e<<3&16^16)>>>0)<<16>>16&c[2276085];e=k&16777215;f=c[2112932]|0;l=c[f+(e>>>10<<2)>>2]|0;if(l>>>0>9){a=k&1023;m=(d[l+(a+1)|0]|0)<<8|(d[l+a|0]|0);n=m&65535;o=n|-65536;p=c[2276069]|0;q=p>>>9;r=q&7;s=9104156+(r<<2)|0;t=c[s>>2]|0;u=t&o;c[s>>2]=u;v=u&65535;c[2276076]=v;w=v>>>8;c[2276075]=w;c[2276078]=0;c[2276077]=0;return}else{m=gj[c[f+196688+(l<<2)>>2]&4095](e)|0;n=m&65535;o=n|-65536;p=c[2276069]|0;q=p>>>9;r=q&7;s=9104156+(r<<2)|0;t=c[s>>2]|0;u=t&o;c[s>>2]=u;v=u&65535;c[2276076]=v;w=v>>>8;c[2276075]=w;c[2276078]=0;c[2276077]=0;return}}function zs(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=b;g=c[2276084]|0}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=o;g=m}m=e+2|0;c[2276056]=m;e=m&-4;if((e|0)==(f|0)){p=g;q=m}else{c[2276083]=e;f=c[2276085]&e;e=f&16777212;o=c[2112932]|0;n=c[o+((e>>>10|32768)<<2)>>2]|0;if(n>>>0>9){b=f&1020;r=(d[n+(b|3)|0]|0)<<8|(d[n+(b|2)|0]|0)|((d[n+(b|1)|0]|0)<<8|(d[n+b|0]|0))<<16;s=m}else{m=gj[c[o+196768+(n<<2)>>2]&4095](e)|0;r=m;s=c[2276056]|0}c[2276084]=r;p=r>>>16|g<<16;q=s}c[2276056]=q+2;q=c[2276085]&p;p=q&16777215;s=c[2112932]|0;g=c[s+(p>>>10<<2)>>2]|0;if(g>>>0>9){r=q&1023;t=(d[g+(r+1)|0]|0)<<8|(d[g+r|0]|0);u=t&65535;v=u|-65536;w=c[2276069]|0;x=w>>>9;y=x&7;z=9104156+(y<<2)|0;A=c[z>>2]|0;B=A&v;c[z>>2]=B;C=B&65535;c[2276076]=C;D=C>>>8;c[2276075]=D;c[2276078]=0;c[2276077]=0;return}else{t=gj[c[s+196688+(g<<2)>>2]&4095](p)|0;u=t&65535;v=u|-65536;w=c[2276069]|0;x=w>>>9;y=x&7;z=9104156+(y<<2)|0;A=c[z>>2]|0;B=A&v;c[z>>2]=B;C=B&65535;c[2276076]=C;D=C>>>8;c[2276075]=D;c[2276078]=0;c[2276077]=0;return}}function zt(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{j=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=j;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=(f>>>((e<<3&16^16)>>>0)<<16>>16)+a|0;a=k&16777215;e=c[2112932]|0;f=c[e+((a>>>10|32768)<<2)>>2]|0;if(f>>>0>9){l=k&1023;m=(d[f+(l+1)|0]|0)<<8|(d[f+l|0]|0);n=m&65535;o=n|-65536;p=c[2276069]|0;q=p>>>9;r=q&7;s=9104156+(r<<2)|0;t=c[s>>2]|0;u=t&o;c[s>>2]=u;v=u&65535;c[2276076]=v;w=v>>>8;c[2276075]=w;c[2276078]=0;c[2276077]=0;return}else{m=gj[c[e+196688+(f<<2)>>2]&4095](a)|0;n=m&65535;o=n|-65536;p=c[2276069]|0;q=p>>>9;r=q&7;s=9104156+(r<<2)|0;t=c[s>>2]|0;u=t&o;c[s>>2]=u;v=u&65535;c[2276076]=v;w=v>>>8;c[2276075]=w;c[2276078]=0;c[2276077]=0;return}}function zu(){var a=0,b=0,e=0,f=0,g=0,h=0;a=xw(c[2276056]|0)|0;b=a&16777215;e=c[2112932]|0;f=c[e+((b>>>10|32768)<<2)>>2]|0;if(f>>>0>9){g=a&1023;h=(d[f+(g+1)|0]|0)<<8|(d[f+g|0]|0)}else{h=gj[c[e+196688+(f<<2)>>2]&4095](b)|0}b=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;f=c[b>>2]&(h&65535|-65536);c[b>>2]=f;b=f&65535;c[2276076]=b;c[2276075]=b>>>8;c[2276078]=0;c[2276077]=0;return}function zv(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;l=(f>>>((e<<3&16^16)>>>0)|-65536)&c[k>>2];c[k>>2]=l;k=l&65535;c[2276076]=k;c[2276075]=k>>>8;c[2276078]=0;c[2276077]=0;return}function zw(){var a=0,b=0,d=0;a=c[2276069]|0;b=9104156+((a>>>9&7)<<2)|0;d=c[b>>2]&c[9104156+((a&7)<<2)>>2];c[b>>2]=d;c[2276076]=d;c[2276075]=d>>>24;c[2276078]=0;c[2276077]=0;return}function zx(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0;a=c[2276069]|0;b=c[2276085]&c[9104156+((a&7|8)<<2)>>2];e=b&16777215;f=c[2112932]|0;g=c[f+(e>>>10<<2)>>2]|0;if(g>>>0>9){h=b&1023;i=(d[g+(h+3)|0]|0)<<8|(d[g+(h+2)|0]|0)|((d[g+(h+1)|0]|0)<<8|(d[g+h|0]|0))<<16;j=a}else{a=gj[c[f+196768+(g<<2)>>2]&4095](e)|0;i=a;j=c[2276069]|0}a=9104156+((j>>>9&7)<<2)|0;j=c[a>>2]&i;c[a>>2]=j;c[2276076]=j;c[2276075]=j>>>24;c[2276078]=0;c[2276077]=0;return}function zy(){var a=0,b=0,e=0,f=0,g=0,h=0;a=9104156+((c[2276069]&7|8)<<2)|0;b=c[a>>2]|0;c[a>>2]=b+4;a=c[2276085]&b;b=a&16777215;e=c[2112932]|0;f=c[e+(b>>>10<<2)>>2]|0;if(f>>>0>9){g=a&1023;h=(d[f+(g+3)|0]|0)<<8|(d[f+(g+2)|0]|0)|((d[f+(g+1)|0]|0)<<8|(d[f+g|0]|0))<<16}else{h=gj[c[e+196768+(f<<2)>>2]&4095](b)|0}b=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;f=c[b>>2]&h;c[b>>2]=f;c[2276076]=f;c[2276075]=f>>>24;c[2276078]=0;c[2276077]=0;return}function zz(){var a=0,b=0,e=0,f=0,g=0,h=0;a=9104156+((c[2276069]&7|8)<<2)|0;b=(c[a>>2]|0)-4|0;c[a>>2]=b;a=c[2276085]&b;b=a&16777215;e=c[2112932]|0;f=c[e+(b>>>10<<2)>>2]|0;if(f>>>0>9){g=a&1023;h=(d[f+(g+3)|0]|0)<<8|(d[f+(g+2)|0]|0)|((d[f+(g+1)|0]|0)<<8|(d[f+g|0]|0))<<16}else{h=gj[c[e+196768+(f<<2)>>2]&4095](b)|0}b=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;f=c[b>>2]&h;c[b>>2]=f;c[2276076]=f;c[2276075]=f>>>24;c[2276078]=0;c[2276077]=0;return}function zA(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;a=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=(g>>>((f<<3&16^16)>>>0)<<16>>16)+a&c[2276085];a=l&16777215;f=c[2112932]|0;g=c[f+(a>>>10<<2)>>2]|0;if(g>>>0>9){m=l&1023;n=(d[g+(m+3)|0]|0)<<8|(d[g+(m+2)|0]|0)|((d[g+(m+1)|0]|0)<<8|(d[g+m|0]|0))<<16;o=c[2276069]|0;p=o>>>9;q=p&7;r=9104156+(q<<2)|0;s=c[r>>2]|0;t=s&n;c[r>>2]=t;c[2276076]=t;u=t>>>24;c[2276075]=u;c[2276078]=0;c[2276077]=0;return}else{n=gj[c[f+196768+(g<<2)>>2]&4095](a)|0;o=c[2276069]|0;p=o>>>9;q=p&7;r=9104156+(q<<2)|0;s=c[r>>2]|0;t=s&n;c[r>>2]=t;c[2276076]=t;u=t>>>24;c[2276075]=u;c[2276078]=0;c[2276077]=0;return}}function zB(){var a=0,b=0,e=0,f=0,g=0,h=0;a=xw(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;b=c[2276085]&a;a=b&16777215;e=c[2112932]|0;f=c[e+(a>>>10<<2)>>2]|0;if(f>>>0>9){g=b&1023;h=(d[f+(g+3)|0]|0)<<8|(d[f+(g+2)|0]|0)|((d[f+(g+1)|0]|0)<<8|(d[f+g|0]|0))<<16}else{h=gj[c[e+196768+(f<<2)>>2]&4095](a)|0}a=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;f=c[a>>2]&h;c[a>>2]=f;c[2276076]=f;c[2276075]=f>>>24;c[2276078]=0;c[2276077]=0;return}function zC(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=f>>>((e<<3&16^16)>>>0)<<16>>16&c[2276085];e=k&16777215;f=c[2112932]|0;l=c[f+(e>>>10<<2)>>2]|0;if(l>>>0>9){a=k&1023;m=(d[l+(a+3)|0]|0)<<8|(d[l+(a+2)|0]|0)|((d[l+(a+1)|0]|0)<<8|(d[l+a|0]|0))<<16;n=c[2276069]|0;o=n>>>9;p=o&7;q=9104156+(p<<2)|0;r=c[q>>2]|0;s=r&m;c[q>>2]=s;c[2276076]=s;t=s>>>24;c[2276075]=t;c[2276078]=0;c[2276077]=0;return}else{m=gj[c[f+196768+(l<<2)>>2]&4095](e)|0;n=c[2276069]|0;o=n>>>9;p=o&7;q=9104156+(p<<2)|0;r=c[q>>2]|0;s=r&m;c[q>>2]=s;c[2276076]=s;t=s>>>24;c[2276075]=t;c[2276078]=0;c[2276077]=0;return}}function zD(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=b;g=c[2276084]|0}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=o;g=m}m=e+2|0;c[2276056]=m;e=m&-4;if((e|0)==(f|0)){p=g;q=m}else{c[2276083]=e;f=c[2276085]&e;e=f&16777212;o=c[2112932]|0;n=c[o+((e>>>10|32768)<<2)>>2]|0;if(n>>>0>9){b=f&1020;r=(d[n+(b|3)|0]|0)<<8|(d[n+(b|2)|0]|0)|((d[n+(b|1)|0]|0)<<8|(d[n+b|0]|0))<<16;s=m}else{m=gj[c[o+196768+(n<<2)>>2]&4095](e)|0;r=m;s=c[2276056]|0}c[2276084]=r;p=r>>>16|g<<16;q=s}c[2276056]=q+2;q=c[2276085]&p;p=q&16777215;s=c[2112932]|0;g=c[s+(p>>>10<<2)>>2]|0;if(g>>>0>9){r=q&1023;t=(d[g+(r+3)|0]|0)<<8|(d[g+(r+2)|0]|0)|((d[g+(r+1)|0]|0)<<8|(d[g+r|0]|0))<<16;u=c[2276069]|0;v=u>>>9;w=v&7;x=9104156+(w<<2)|0;y=c[x>>2]|0;z=y&t;c[x>>2]=z;c[2276076]=z;A=z>>>24;c[2276075]=A;c[2276078]=0;c[2276077]=0;return}else{t=gj[c[s+196768+(g<<2)>>2]&4095](p)|0;u=c[2276069]|0;v=u>>>9;w=v&7;x=9104156+(w<<2)|0;y=c[x>>2]|0;z=y&t;c[x>>2]=z;c[2276076]=z;A=z>>>24;c[2276075]=A;c[2276078]=0;c[2276077]=0;return}}function zE(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{j=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=j;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=(f>>>((e<<3&16^16)>>>0)<<16>>16)+a|0;a=k&16777215;e=c[2112932]|0;f=c[e+((a>>>10|32768)<<2)>>2]|0;if(f>>>0>9){l=k&1023;m=(d[f+(l+3)|0]|0)<<8|(d[f+(l+2)|0]|0)|((d[f+(l+1)|0]|0)<<8|(d[f+l|0]|0))<<16;n=c[2276069]|0;o=n>>>9;p=o&7;q=9104156+(p<<2)|0;r=c[q>>2]|0;s=r&m;c[q>>2]=s;c[2276076]=s;t=s>>>24;c[2276075]=t;c[2276078]=0;c[2276077]=0;return}else{m=gj[c[e+196768+(f<<2)>>2]&4095](a)|0;n=c[2276069]|0;o=n>>>9;p=o&7;q=9104156+(p<<2)|0;r=c[q>>2]|0;s=r&m;c[q>>2]=s;c[2276076]=s;t=s>>>24;c[2276075]=t;c[2276078]=0;c[2276077]=0;return}}function zF(){var a=0,b=0,e=0,f=0,g=0,h=0;a=xw(c[2276056]|0)|0;b=a&16777215;e=c[2112932]|0;f=c[e+((b>>>10|32768)<<2)>>2]|0;if(f>>>0>9){g=a&1023;h=(d[f+(g+3)|0]|0)<<8|(d[f+(g+2)|0]|0)|((d[f+(g+1)|0]|0)<<8|(d[f+g|0]|0))<<16}else{h=gj[c[e+196768+(f<<2)>>2]&4095](b)|0}b=9104156+(((c[2276069]|0)>>>9&7)<<2)|0;f=c[b>>2]&h;c[b>>2]=f;c[2276076]=f;c[2276075]=f>>>24;c[2276078]=0;c[2276077]=0;return}function zG(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=b;g=c[2276084]|0}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=o;g=m}m=e+2|0;c[2276056]=m;e=m&-4;if((e|0)==(f|0)){p=g;q=m;r=q+2|0;c[2276056]=r;s=c[2276069]|0;t=s>>>9;u=t&7;v=9104156+(u<<2)|0;w=c[v>>2]|0;x=w&p;c[v>>2]=x;c[2276076]=x;y=x>>>24;c[2276075]=y;c[2276078]=0;c[2276077]=0;return}c[2276083]=e;f=c[2276085]&e;e=f&16777212;o=c[2112932]|0;n=c[o+((e>>>10|32768)<<2)>>2]|0;if(n>>>0>9){b=f&1020;z=(d[n+(b|3)|0]|0)<<8|(d[n+(b|2)|0]|0)|((d[n+(b|1)|0]|0)<<8|(d[n+b|0]|0))<<16;A=m}else{m=gj[c[o+196768+(n<<2)>>2]&4095](e)|0;z=m;A=c[2276056]|0}c[2276084]=z;p=z>>>16|g<<16;q=A;r=q+2|0;c[2276056]=r;s=c[2276069]|0;t=s>>>9;u=t&7;v=9104156+(u<<2)|0;w=c[v>>2]|0;x=w&p;c[v>>2]=x;c[2276076]=x;y=x>>>24;c[2276075]=y;c[2276078]=0;c[2276077]=0;return}function zH(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=c[2276069]|0;d=c[9104156+((b&7|8)<<2)>>2]|0;e=c[9104156+((b>>>9&7)<<2)>>2]|0;b=c[2276085]|0;f=b&d;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=a[i+(f&1023^1)|0]|0;k=b;l=h}else{b=gj[c[h+196608+(i<<2)>>2]&4095](g)|0;j=b;k=c[2276085]|0;l=c[2112932]|0}b=j&255&e;c[2276075]=b;c[2276078]=0;c[2276077]=0;c[2276076]=b;e=k&d;d=b&255;b=e&16777215;k=c[l+((b>>>10|16384)<<2)>>2]|0;if(k>>>0>9){a[k+(e&1023^1)|0]=d;return}else{gg[c[l+196648+(k<<2)>>2]&4095](b,d);return}}function zI(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;b=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;e=c[2276085]|0;f=e&d;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=a[i+(f&1023^1)|0]|0;k=e;l=h}else{e=gj[c[h+196608+(i<<2)>>2]&4095](g)|0;j=e;k=c[2276085]|0;l=c[2112932]|0}e=j&255&b;c[2276075]=e;c[2276078]=0;c[2276077]=0;c[2276076]=e;b=k&d;d=e&255;e=b&16777215;k=c[l+((e>>>10|16384)<<2)>>2]|0;if(k>>>0>9){a[k+(b&1023^1)|0]=d;return}else{gg[c[l+196648+(k<<2)>>2]&4095](e,d);return}}function zJ(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=c[2276054]|0;c[2276054]=b+2;d=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;e=c[2276085]|0;f=e&b;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=a[i+(f&1023^1)|0]|0;k=e;l=h}else{e=gj[c[h+196608+(i<<2)>>2]&4095](g)|0;j=e;k=c[2276085]|0;l=c[2112932]|0}e=j&255&d;c[2276075]=e;c[2276078]=0;c[2276077]=0;c[2276076]=e;d=k&b;b=e&255;e=d&16777215;k=c[l+((e>>>10|16384)<<2)>>2]|0;if(k>>>0>9){a[k+(d&1023^1)|0]=b;return}else{gg[c[l+196648+(k<<2)>>2]&4095](e,b);return}}function zK(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;b=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;e=c[2276085]|0;f=e&d;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=a[i+(f&1023^1)|0]|0;k=e;l=h}else{e=gj[c[h+196608+(i<<2)>>2]&4095](g)|0;j=e;k=c[2276085]|0;l=c[2112932]|0}e=j&255&b;c[2276075]=e;c[2276078]=0;c[2276077]=0;c[2276076]=e;b=k&d;d=e&255;e=b&16777215;k=c[l+((e>>>10|16384)<<2)>>2]|0;if(k>>>0>9){a[k+(b&1023^1)|0]=d;return}else{gg[c[l+196648+(k<<2)>>2]&4095](e,d);return}}function zL(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=(c[2276054]|0)-2|0;c[2276054]=b;d=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;e=c[2276085]|0;f=e&b;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=a[i+(f&1023^1)|0]|0;k=e;l=h}else{e=gj[c[h+196608+(i<<2)>>2]&4095](g)|0;j=e;k=c[2276085]|0;l=c[2112932]|0}e=j&255&d;c[2276075]=e;c[2276078]=0;c[2276077]=0;c[2276076]=e;d=k&b;b=e&255;e=d&16777215;k=c[l+((e>>>10|16384)<<2)>>2]|0;if(k>>>0>9){a[k+(d&1023^1)|0]=b;return}else{gg[c[l+196648+(k<<2)>>2]&4095](e,b);return}}function zM(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=c[2276069]|0;e=c[9104156+((b&7|8)<<2)>>2]|0;f=c[2276056]|0;g=f&-4;if((g|0)==(c[2276083]|0)){h=f;i=c[2276084]|0;j=b}else{c[2276083]=g;k=c[2276085]&g;g=k&16777212;l=c[2112932]|0;m=c[l+((g>>>10|32768)<<2)>>2]|0;if(m>>>0>9){n=k&1020;o=(d[m+(n|3)|0]|0)<<8|(d[m+(n|2)|0]|0)|((d[m+(n|1)|0]|0)<<8|(d[m+n|0]|0))<<16;p=f;q=b}else{b=gj[c[l+196768+(m<<2)>>2]&4095](g)|0;o=b;p=c[2276056]|0;q=c[2276069]|0}c[2276084]=o;h=p;i=o;j=q}c[2276056]=h+2;q=(i>>>((h<<3&16^16)>>>0)<<16>>16)+e|0;e=c[9104156+((j>>>9&7)<<2)>>2]|0;j=c[2276085]|0;h=q&j;i=h&16777215;o=c[2112932]|0;p=c[o+(i>>>10<<2)>>2]|0;if(p>>>0>9){r=a[p+(h&1023^1)|0]|0;s=j;t=o}else{j=gj[c[o+196608+(p<<2)>>2]&4095](i)|0;r=j;s=c[2276085]|0;t=c[2112932]|0}j=r&255&e;c[2276075]=j;c[2276078]=0;c[2276077]=0;c[2276076]=j;e=s&q;q=j&255;j=e&16777215;s=c[t+((j>>>10|16384)<<2)>>2]|0;if(s>>>0>9){a[s+(e&1023^1)|0]=q;return}else{gg[c[t+196648+(s<<2)>>2]&4095](j,q);return}}function zN(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=xw(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;d=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;e=c[2276085]|0;f=e&b;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=a[i+(f&1023^1)|0]|0;k=e;l=h}else{e=gj[c[h+196608+(i<<2)>>2]&4095](g)|0;j=e;k=c[2276085]|0;l=c[2112932]|0}e=j&255&d;c[2276075]=e;c[2276078]=0;c[2276077]=0;c[2276076]=e;d=k&b;b=e&255;e=d&16777215;k=c[l+((e>>>10|16384)<<2)>>2]|0;if(k>>>0>9){a[k+(d&1023^1)|0]=b;return}else{gg[c[l+196648+(k<<2)>>2]&4095](e,b);return}}function zO(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)<<16>>16;f=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;g=c[2276085]|0;m=l&g;b=m&16777215;e=c[2112932]|0;j=c[e+(b>>>10<<2)>>2]|0;if(j>>>0>9){n=a[j+(m&1023^1)|0]|0;o=g;p=e}else{g=gj[c[e+196608+(j<<2)>>2]&4095](b)|0;n=g;o=c[2276085]|0;p=c[2112932]|0}g=n&255&f;c[2276075]=g;c[2276078]=0;c[2276077]=0;c[2276076]=g;f=o&l;l=g&255;g=f&16777215;o=c[p+((g>>>10|16384)<<2)>>2]|0;if(o>>>0>9){a[o+(f&1023^1)|0]=l;return}else{gg[c[p+196648+(o<<2)>>2]&4095](g,l);return}}function zP(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;t=c[2276085]|0;h=t&q;s=h&16777215;n=c[2112932]|0;f=c[n+(s>>>10<<2)>>2]|0;if(f>>>0>9){u=a[f+(h&1023^1)|0]|0;v=t;w=n}else{t=gj[c[n+196608+(f<<2)>>2]&4095](s)|0;u=t;v=c[2276085]|0;w=c[2112932]|0}t=u&255&r;c[2276075]=t;c[2276078]=0;c[2276077]=0;c[2276076]=t;r=v&q;q=t&255;t=r&16777215;v=c[w+((t>>>10|16384)<<2)>>2]|0;if(v>>>0>9){a[v+(r&1023^1)|0]=q;return}else{gg[c[w+196648+(v<<2)>>2]&4095](t,q);return}}function zQ(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[2276069]|0;e=c[9104156+((b&7|8)<<2)>>2]|0;f=c[9104156+((b>>>9&7)<<2)>>2]|0;b=c[2276085]|0;g=b&e;h=g&16777215;i=c[2112932]|0;j=c[i+(h>>>10<<2)>>2]|0;if(j>>>0>9){k=g&1023;l=(d[j+(k+1)|0]|0)<<8|(d[j+k|0]|0);m=b;n=i}else{b=gj[c[i+196688+(j<<2)>>2]&4095](h)|0;l=b;m=c[2276085]|0;n=c[2112932]|0}b=l&65535&f;c[2276075]=b>>>8;c[2276078]=0;c[2276077]=0;c[2276076]=b;f=m&e;e=b&65535;m=f&16777215;l=c[n+((m>>>10|16384)<<2)>>2]|0;if(l>>>0>9){h=f&1023;a[l+h|0]=b&255;a[l+(h+1)|0]=(e&65535)>>>8&255;return}else{gg[c[n+196728+(l<<2)>>2]&4095](m,e);return}}function zR(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=c[b>>2]|0;c[b>>2]=e+2;b=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;f=c[2276085]|0;g=f&e;h=g&16777215;i=c[2112932]|0;j=c[i+(h>>>10<<2)>>2]|0;if(j>>>0>9){k=g&1023;l=(d[j+(k+1)|0]|0)<<8|(d[j+k|0]|0);m=f;n=i}else{f=gj[c[i+196688+(j<<2)>>2]&4095](h)|0;l=f;m=c[2276085]|0;n=c[2112932]|0}f=l&65535&b;c[2276075]=f>>>8;c[2276078]=0;c[2276077]=0;c[2276076]=f;b=m&e;e=f&65535;m=b&16777215;l=c[n+((m>>>10|16384)<<2)>>2]|0;if(l>>>0>9){h=b&1023;a[l+h|0]=f&255;a[l+(h+1)|0]=(e&65535)>>>8&255;return}else{gg[c[n+196728+(l<<2)>>2]&4095](m,e);return}}function zS(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=(c[b>>2]|0)-2|0;c[b>>2]=e;b=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;f=c[2276085]|0;g=f&e;h=g&16777215;i=c[2112932]|0;j=c[i+(h>>>10<<2)>>2]|0;if(j>>>0>9){k=g&1023;l=(d[j+(k+1)|0]|0)<<8|(d[j+k|0]|0);m=f;n=i}else{f=gj[c[i+196688+(j<<2)>>2]&4095](h)|0;l=f;m=c[2276085]|0;n=c[2112932]|0}f=l&65535&b;c[2276075]=f>>>8;c[2276078]=0;c[2276077]=0;c[2276076]=f;b=m&e;e=f&65535;m=b&16777215;l=c[n+((m>>>10|16384)<<2)>>2]|0;if(l>>>0>9){h=b&1023;a[l+h|0]=f&255;a[l+(h+1)|0]=(e&65535)>>>8&255;return}else{gg[c[n+196728+(l<<2)>>2]&4095](m,e);return}}function zT(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=c[2276069]|0;e=c[9104156+((b&7|8)<<2)>>2]|0;f=c[2276056]|0;g=f&-4;if((g|0)==(c[2276083]|0)){h=f;i=c[2276084]|0;j=b}else{c[2276083]=g;k=c[2276085]&g;g=k&16777212;l=c[2112932]|0;m=c[l+((g>>>10|32768)<<2)>>2]|0;if(m>>>0>9){n=k&1020;o=(d[m+(n|3)|0]|0)<<8|(d[m+(n|2)|0]|0)|((d[m+(n|1)|0]|0)<<8|(d[m+n|0]|0))<<16;p=f;q=b}else{b=gj[c[l+196768+(m<<2)>>2]&4095](g)|0;o=b;p=c[2276056]|0;q=c[2276069]|0}c[2276084]=o;h=p;i=o;j=q}c[2276056]=h+2;q=(i>>>((h<<3&16^16)>>>0)<<16>>16)+e|0;e=c[9104156+((j>>>9&7)<<2)>>2]|0;j=c[2276085]|0;h=q&j;i=h&16777215;o=c[2112932]|0;p=c[o+(i>>>10<<2)>>2]|0;if(p>>>0>9){b=h&1023;r=(d[p+(b+1)|0]|0)<<8|(d[p+b|0]|0);s=j;t=o}else{j=gj[c[o+196688+(p<<2)>>2]&4095](i)|0;r=j;s=c[2276085]|0;t=c[2112932]|0}j=r&65535&e;c[2276075]=j>>>8;c[2276078]=0;c[2276077]=0;c[2276076]=j;e=s&q;q=j&65535;s=e&16777215;r=c[t+((s>>>10|16384)<<2)>>2]|0;if(r>>>0>9){i=e&1023;a[r+i|0]=j&255;a[r+(i+1)|0]=(q&65535)>>>8&255;return}else{gg[c[t+196728+(r<<2)>>2]&4095](s,q);return}}function zU(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=xw(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;e=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;f=c[2276085]|0;g=f&b;h=g&16777215;i=c[2112932]|0;j=c[i+(h>>>10<<2)>>2]|0;if(j>>>0>9){k=g&1023;l=(d[j+(k+1)|0]|0)<<8|(d[j+k|0]|0);m=f;n=i}else{f=gj[c[i+196688+(j<<2)>>2]&4095](h)|0;l=f;m=c[2276085]|0;n=c[2112932]|0}f=l&65535&e;c[2276075]=f>>>8;c[2276078]=0;c[2276077]=0;c[2276076]=f;e=m&b;b=f&65535;m=e&16777215;l=c[n+((m>>>10|16384)<<2)>>2]|0;if(l>>>0>9){h=e&1023;a[l+h|0]=f&255;a[l+(h+1)|0]=(b&65535)>>>8&255;return}else{gg[c[n+196728+(l<<2)>>2]&4095](m,b);return}}function zV(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)<<16>>16;f=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;g=c[2276085]|0;m=l&g;b=m&16777215;e=c[2112932]|0;j=c[e+(b>>>10<<2)>>2]|0;if(j>>>0>9){i=m&1023;n=(d[j+(i+1)|0]|0)<<8|(d[j+i|0]|0);o=g;p=e}else{g=gj[c[e+196688+(j<<2)>>2]&4095](b)|0;n=g;o=c[2276085]|0;p=c[2112932]|0}g=n&65535&f;c[2276075]=g>>>8;c[2276078]=0;c[2276077]=0;c[2276076]=g;f=o&l;l=g&65535;o=f&16777215;n=c[p+((o>>>10|16384)<<2)>>2]|0;if(n>>>0>9){b=f&1023;a[n+b|0]=g&255;a[n+(b+1)|0]=(l&65535)>>>8&255;return}else{gg[c[p+196728+(n<<2)>>2]&4095](o,l);return}}function zW(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;t=c[2276085]|0;h=t&q;s=h&16777215;n=c[2112932]|0;f=c[n+(s>>>10<<2)>>2]|0;if(f>>>0>9){o=h&1023;u=(d[f+(o+1)|0]|0)<<8|(d[f+o|0]|0);v=t;w=n}else{t=gj[c[n+196688+(f<<2)>>2]&4095](s)|0;u=t;v=c[2276085]|0;w=c[2112932]|0}t=u&65535&r;c[2276075]=t>>>8;c[2276078]=0;c[2276077]=0;c[2276076]=t;r=v&q;q=t&65535;v=r&16777215;u=c[w+((v>>>10|16384)<<2)>>2]|0;if(u>>>0>9){s=r&1023;a[u+s|0]=t&255;a[u+(s+1)|0]=(q&65535)>>>8&255;return}else{gg[c[w+196728+(u<<2)>>2]&4095](v,q);return}}function zX(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[2276069]|0;e=c[9104156+((b&7|8)<<2)>>2]|0;f=c[9104156+((b>>>9&7)<<2)>>2]|0;b=c[2276085]|0;g=b&e;h=g&16777215;i=c[2112932]|0;j=c[i+(h>>>10<<2)>>2]|0;if(j>>>0>9){k=g&1023;l=(d[j+(k+3)|0]|0)<<8|(d[j+(k+2)|0]|0)|((d[j+(k+1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b;n=i}else{b=gj[c[i+196768+(j<<2)>>2]&4095](h)|0;l=b;m=c[2276085]|0;n=c[2112932]|0}b=l&f;f=b>>>24;c[2276075]=f;c[2276076]=b;c[2276078]=0;c[2276077]=0;l=m&e;e=l&16777215;m=c[n+((e>>>10|16384)<<2)>>2]|0;if(m>>>0>9){h=l&1023;a[m+h|0]=b>>>16&255;a[m+(h+1)|0]=f&255;a[m+(h+2)|0]=b&255;a[m+(h+3)|0]=b>>>8&255;return}else{gg[c[n+196808+(m<<2)>>2]&4095](e,b);return}}function zY(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=c[b>>2]|0;c[b>>2]=e+4;b=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;f=c[2276085]|0;g=f&e;h=g&16777215;i=c[2112932]|0;j=c[i+(h>>>10<<2)>>2]|0;if(j>>>0>9){k=g&1023;l=(d[j+(k+3)|0]|0)<<8|(d[j+(k+2)|0]|0)|((d[j+(k+1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=f;n=i}else{f=gj[c[i+196768+(j<<2)>>2]&4095](h)|0;l=f;m=c[2276085]|0;n=c[2112932]|0}f=l&b;b=f>>>24;c[2276075]=b;c[2276076]=f;c[2276078]=0;c[2276077]=0;l=m&e;e=l&16777215;m=c[n+((e>>>10|16384)<<2)>>2]|0;if(m>>>0>9){h=l&1023;a[m+h|0]=f>>>16&255;a[m+(h+1)|0]=b&255;a[m+(h+2)|0]=f&255;a[m+(h+3)|0]=f>>>8&255;return}else{gg[c[n+196808+(m<<2)>>2]&4095](e,f);return}}function zZ(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=(c[b>>2]|0)-4|0;c[b>>2]=e;b=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;f=c[2276085]|0;g=f&e;h=g&16777215;i=c[2112932]|0;j=c[i+(h>>>10<<2)>>2]|0;if(j>>>0>9){k=g&1023;l=(d[j+(k+3)|0]|0)<<8|(d[j+(k+2)|0]|0)|((d[j+(k+1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=f;n=i}else{f=gj[c[i+196768+(j<<2)>>2]&4095](h)|0;l=f;m=c[2276085]|0;n=c[2112932]|0}f=l&b;b=f>>>24;c[2276075]=b;c[2276076]=f;c[2276078]=0;c[2276077]=0;l=m&e;e=l&16777215;m=c[n+((e>>>10|16384)<<2)>>2]|0;if(m>>>0>9){h=l&1023;a[m+h|0]=f>>>16&255;a[m+(h+1)|0]=b&255;a[m+(h+2)|0]=f&255;a[m+(h+3)|0]=f>>>8&255;return}else{gg[c[n+196808+(m<<2)>>2]&4095](e,f);return}}function z_(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=c[2276069]|0;e=c[9104156+((b&7|8)<<2)>>2]|0;f=c[2276056]|0;g=f&-4;if((g|0)==(c[2276083]|0)){h=f;i=c[2276084]|0;j=b}else{c[2276083]=g;k=c[2276085]&g;g=k&16777212;l=c[2112932]|0;m=c[l+((g>>>10|32768)<<2)>>2]|0;if(m>>>0>9){n=k&1020;o=(d[m+(n|3)|0]|0)<<8|(d[m+(n|2)|0]|0)|((d[m+(n|1)|0]|0)<<8|(d[m+n|0]|0))<<16;p=f;q=b}else{b=gj[c[l+196768+(m<<2)>>2]&4095](g)|0;o=b;p=c[2276056]|0;q=c[2276069]|0}c[2276084]=o;h=p;i=o;j=q}c[2276056]=h+2;q=(i>>>((h<<3&16^16)>>>0)<<16>>16)+e|0;e=c[9104156+((j>>>9&7)<<2)>>2]|0;j=c[2276085]|0;h=q&j;i=h&16777215;o=c[2112932]|0;p=c[o+(i>>>10<<2)>>2]|0;if(p>>>0>9){b=h&1023;r=(d[p+(b+3)|0]|0)<<8|(d[p+(b+2)|0]|0)|((d[p+(b+1)|0]|0)<<8|(d[p+b|0]|0))<<16;s=j;t=o}else{j=gj[c[o+196768+(p<<2)>>2]&4095](i)|0;r=j;s=c[2276085]|0;t=c[2112932]|0}j=r&e;e=j>>>24;c[2276075]=e;c[2276076]=j;c[2276078]=0;c[2276077]=0;r=s&q;q=r&16777215;s=c[t+((q>>>10|16384)<<2)>>2]|0;if(s>>>0>9){i=r&1023;a[s+i|0]=j>>>16&255;a[s+(i+1)|0]=e&255;a[s+(i+2)|0]=j&255;a[s+(i+3)|0]=j>>>8&255;return}else{gg[c[t+196808+(s<<2)>>2]&4095](q,j);return}}function z$(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=xw(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;e=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;f=c[2276085]|0;g=f&b;h=g&16777215;i=c[2112932]|0;j=c[i+(h>>>10<<2)>>2]|0;if(j>>>0>9){k=g&1023;l=(d[j+(k+3)|0]|0)<<8|(d[j+(k+2)|0]|0)|((d[j+(k+1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=f;n=i}else{f=gj[c[i+196768+(j<<2)>>2]&4095](h)|0;l=f;m=c[2276085]|0;n=c[2112932]|0}f=l&e;e=f>>>24;c[2276075]=e;c[2276076]=f;c[2276078]=0;c[2276077]=0;l=m&b;b=l&16777215;m=c[n+((b>>>10|16384)<<2)>>2]|0;if(m>>>0>9){h=l&1023;a[m+h|0]=f>>>16&255;a[m+(h+1)|0]=e&255;a[m+(h+2)|0]=f&255;a[m+(h+3)|0]=f>>>8&255;return}else{gg[c[n+196808+(m<<2)>>2]&4095](b,f);return}}function z0(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)<<16>>16;f=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;g=c[2276085]|0;m=l&g;b=m&16777215;e=c[2112932]|0;j=c[e+(b>>>10<<2)>>2]|0;if(j>>>0>9){i=m&1023;n=(d[j+(i+3)|0]|0)<<8|(d[j+(i+2)|0]|0)|((d[j+(i+1)|0]|0)<<8|(d[j+i|0]|0))<<16;o=g;p=e}else{g=gj[c[e+196768+(j<<2)>>2]&4095](b)|0;n=g;o=c[2276085]|0;p=c[2112932]|0}g=n&f;f=g>>>24;c[2276075]=f;c[2276076]=g;c[2276078]=0;c[2276077]=0;n=o&l;l=n&16777215;o=c[p+((l>>>10|16384)<<2)>>2]|0;if(o>>>0>9){b=n&1023;a[o+b|0]=g>>>16&255;a[o+(b+1)|0]=f&255;a[o+(b+2)|0]=g&255;a[o+(b+3)|0]=g>>>8&255;return}else{gg[c[p+196808+(o<<2)>>2]&4095](l,g);return}}function z1(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]|0;t=c[2276085]|0;h=t&q;s=h&16777215;n=c[2112932]|0;f=c[n+(s>>>10<<2)>>2]|0;if(f>>>0>9){o=h&1023;u=(d[f+(o+3)|0]|0)<<8|(d[f+(o+2)|0]|0)|((d[f+(o+1)|0]|0)<<8|(d[f+o|0]|0))<<16;v=t;w=n}else{t=gj[c[n+196768+(f<<2)>>2]&4095](s)|0;u=t;v=c[2276085]|0;w=c[2112932]|0}t=u&r;r=t>>>24;c[2276075]=r;c[2276076]=t;c[2276078]=0;c[2276077]=0;u=v&q;q=u&16777215;v=c[w+((q>>>10|16384)<<2)>>2]|0;if(v>>>0>9){s=u&1023;a[v+s|0]=t>>>16&255;a[v+(s+1)|0]=r&255;a[v+(s+2)|0]=t&255;a[v+(s+3)|0]=t>>>8&255;return}else{gg[c[w+196808+(v<<2)>>2]&4095](q,t);return}}function z2(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=9104156+((c[2276069]&7)<<2)|0;l=(f>>>((e<<3&16^16)>>>0)|-256)&c[k>>2];c[k>>2]=l;k=l&255;c[2276076]=k;c[2276075]=k;c[2276078]=0;c[2276077]=0;return}function z3(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;m=c[2276085]|0;b=m&l;e=b&16777215;j=c[2112932]|0;i=c[j+(e>>>10<<2)>>2]|0;if(i>>>0>9){n=a[i+(b&1023^1)|0]|0;o=m;p=j}else{m=gj[c[j+196608+(i<<2)>>2]&4095](e)|0;n=m;o=c[2276085]|0;p=c[2112932]|0}m=n&255&g>>>((f<<3&16^16)>>>0);c[2276075]=m;c[2276076]=m;c[2276078]=0;c[2276077]=0;f=o&l;l=m&255;m=f&16777215;o=c[p+((m>>>10|16384)<<2)>>2]|0;if(o>>>0>9){a[o+(f&1023^1)|0]=l;return}else{gg[c[p+196648+(o<<2)>>2]&4095](m,l);return}}function z4(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=9104156+((c[2276069]&7|8)<<2)|0;m=c[l>>2]|0;c[l>>2]=m+1;l=c[2276085]|0;b=l&m;e=b&16777215;j=c[2112932]|0;i=c[j+(e>>>10<<2)>>2]|0;if(i>>>0>9){n=a[i+(b&1023^1)|0]|0;o=l;p=j}else{l=gj[c[j+196608+(i<<2)>>2]&4095](e)|0;n=l;o=c[2276085]|0;p=c[2112932]|0}l=n&255&g>>>((f<<3&16^16)>>>0);c[2276075]=l;c[2276076]=l;c[2276078]=0;c[2276077]=0;f=o&m;m=l&255;l=f&16777215;o=c[p+((l>>>10|16384)<<2)>>2]|0;if(o>>>0>9){a[o+(f&1023^1)|0]=m;return}else{gg[c[p+196648+(o<<2)>>2]&4095](l,m);return}}function z5(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=c[2276054]|0;c[2276054]=l+2;m=c[2276085]|0;b=m&l;e=b&16777215;j=c[2112932]|0;i=c[j+(e>>>10<<2)>>2]|0;if(i>>>0>9){n=a[i+(b&1023^1)|0]|0;o=m;p=j}else{m=gj[c[j+196608+(i<<2)>>2]&4095](e)|0;n=m;o=c[2276085]|0;p=c[2112932]|0}m=n&255&g>>>((f<<3&16^16)>>>0);c[2276075]=m;c[2276076]=m;c[2276078]=0;c[2276077]=0;f=o&l;l=m&255;m=f&16777215;o=c[p+((m>>>10|16384)<<2)>>2]|0;if(o>>>0>9){a[o+(f&1023^1)|0]=l;return}else{gg[c[p+196648+(o<<2)>>2]&4095](m,l);return}}function z6(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=9104156+((c[2276069]&7|8)<<2)|0;m=(c[l>>2]|0)-1|0;c[l>>2]=m;l=c[2276085]|0;b=l&m;e=b&16777215;j=c[2112932]|0;i=c[j+(e>>>10<<2)>>2]|0;if(i>>>0>9){n=a[i+(b&1023^1)|0]|0;o=l;p=j}else{l=gj[c[j+196608+(i<<2)>>2]&4095](e)|0;n=l;o=c[2276085]|0;p=c[2112932]|0}l=n&255&g>>>((f<<3&16^16)>>>0);c[2276075]=l;c[2276076]=l;c[2276078]=0;c[2276077]=0;f=o&m;m=l&255;l=f&16777215;o=c[p+((l>>>10|16384)<<2)>>2]|0;if(o>>>0>9){a[o+(f&1023^1)|0]=m;return}else{gg[c[p+196648+(o<<2)>>2]&4095](l,m);return}}function z7(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=(c[2276054]|0)-2|0;c[2276054]=l;m=c[2276085]|0;b=m&l;e=b&16777215;j=c[2112932]|0;i=c[j+(e>>>10<<2)>>2]|0;if(i>>>0>9){n=a[i+(b&1023^1)|0]|0;o=m;p=j}else{m=gj[c[j+196608+(i<<2)>>2]&4095](e)|0;n=m;o=c[2276085]|0;p=c[2112932]|0}m=n&255&g>>>((f<<3&16^16)>>>0);c[2276075]=m;c[2276076]=m;c[2276078]=0;c[2276077]=0;f=o&l;l=m&255;m=f&16777215;o=c[p+((m>>>10|16384)<<2)>>2]|0;if(o>>>0>9){a[o+(f&1023^1)|0]=l;return}else{gg[c[p+196648+(o<<2)>>2]&4095](m,l);return}}function z8(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0);f=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;o=p&-4;if((o|0)==(h|0)){q=p;r=g}else{c[2276083]=o;g=c[2276085]&o;o=g&16777212;h=c[2112932]|0;e=c[h+((o>>>10|32768)<<2)>>2]|0;if(e>>>0>9){j=g&1020;s=(d[e+(j|3)|0]|0)<<8|(d[e+(j|2)|0]|0)|((d[e+(j|1)|0]|0)<<8|(d[e+j|0]|0))<<16;t=p}else{p=gj[c[h+196768+(e<<2)>>2]&4095](o)|0;s=p;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;s=(r>>>((q<<3&16^16)>>>0)<<16>>16)+f|0;f=c[2276085]|0;q=s&f;r=q&16777215;t=c[2112932]|0;p=c[t+(r>>>10<<2)>>2]|0;if(p>>>0>9){u=a[p+(q&1023^1)|0]|0;v=f;w=t}else{f=gj[c[t+196608+(p<<2)>>2]&4095](r)|0;u=f;v=c[2276085]|0;w=c[2112932]|0}f=u&255&n;c[2276075]=f;c[2276076]=f;c[2276078]=0;c[2276077]=0;n=v&s;s=f&255;f=n&16777215;v=c[w+((f>>>10|16384)<<2)>>2]|0;if(v>>>0>9){a[v+(n&1023^1)|0]=s;return}else{gg[c[w+196648+(v<<2)>>2]&4095](f,s);return}}function z9(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=xw(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;m=c[2276085]|0;b=m&l;e=b&16777215;j=c[2112932]|0;i=c[j+(e>>>10<<2)>>2]|0;if(i>>>0>9){n=a[i+(b&1023^1)|0]|0;o=m;p=j}else{m=gj[c[j+196608+(i<<2)>>2]&4095](e)|0;n=m;o=c[2276085]|0;p=c[2112932]|0}m=n&255&g>>>((f<<3&16^16)>>>0);c[2276075]=m;c[2276076]=m;c[2276078]=0;c[2276077]=0;f=o&l;l=m&255;m=f&16777215;o=c[p+((m>>>10|16384)<<2)>>2]|0;if(o>>>0>9){a[o+(f&1023^1)|0]=l;return}else{gg[c[p+196648+(o<<2)>>2]&4095](m,l);return}}function Aa(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0);f=p&-4;if((f|0)==(h|0)){q=p;r=g}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;h=c[2112932]|0;o=c[h+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=p}else{p=gj[c[h+196768+(o<<2)>>2]&4095](f)|0;s=p;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;s=r>>>((q<<3&16^16)>>>0)<<16>>16;q=c[2276085]|0;r=s&q;t=r&16777215;p=c[2112932]|0;f=c[p+(t>>>10<<2)>>2]|0;if(f>>>0>9){u=a[f+(r&1023^1)|0]|0;v=q;w=p}else{q=gj[c[p+196608+(f<<2)>>2]&4095](t)|0;u=q;v=c[2276085]|0;w=c[2112932]|0}q=u&255&n;c[2276075]=q;c[2276076]=q;c[2276078]=0;c[2276077]=0;n=v&s;s=q&255;q=n&16777215;v=c[w+((q>>>10|16384)<<2)>>2]|0;if(v>>>0>9){a[v+(n&1023^1)|0]=s;return}else{gg[c[w+196648+(v<<2)>>2]&4095](q,s);return}}function Ab(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0);f=p&-4;if((f|0)==(h|0)){q=p;r=h;s=g}else{c[2276083]=f;g=c[2276085]&f;h=g&16777212;o=c[2112932]|0;e=c[o+((h>>>10|32768)<<2)>>2]|0;if(e>>>0>9){j=g&1020;t=(d[e+(j|3)|0]|0)<<8|(d[e+(j|2)|0]|0)|((d[e+(j|1)|0]|0)<<8|(d[e+j|0]|0))<<16;u=p;v=f}else{f=gj[c[o+196768+(e<<2)>>2]&4095](h)|0;t=f;u=c[2276056]|0;v=c[2276083]|0}c[2276084]=t;q=u;r=v;s=t}t=q+2|0;c[2276056]=t;q=t&-4;if((q|0)==(r|0)){w=s;x=t}else{c[2276083]=q;r=c[2276085]&q;q=r&16777212;v=c[2112932]|0;u=c[v+((q>>>10|32768)<<2)>>2]|0;if(u>>>0>9){f=r&1020;y=(d[u+(f|3)|0]|0)<<8|(d[u+(f|2)|0]|0)|((d[u+(f|1)|0]|0)<<8|(d[u+f|0]|0))<<16;z=t}else{t=gj[c[v+196768+(u<<2)>>2]&4095](q)|0;y=t;z=c[2276056]|0}c[2276084]=y;w=y>>>16|s<<16;x=z}c[2276056]=x+2;x=c[2276085]|0;z=x&w;s=z&16777215;y=c[2112932]|0;t=c[y+(s>>>10<<2)>>2]|0;if(t>>>0>9){A=a[t+(z&1023^1)|0]|0;B=x;C=y}else{x=gj[c[y+196608+(t<<2)>>2]&4095](s)|0;A=x;B=c[2276085]|0;C=c[2112932]|0}x=A&255&n;c[2276075]=x;c[2276076]=x;c[2276078]=0;c[2276077]=0;n=B&w;w=x&255;x=n&16777215;B=c[C+((x>>>10|16384)<<2)>>2]|0;if(B>>>0>9){a[B+(n&1023^1)|0]=w;return}else{gg[c[C+196648+(B<<2)>>2]&4095](x,w);return}}function Ac(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=9104156+((c[2276069]&7)<<2)|0;l=(f>>>((e<<3&16^16)>>>0)|-65536)&c[k>>2];c[k>>2]=l;k=l&65535;c[2276076]=k;c[2276075]=k>>>8;c[2276078]=0;c[2276077]=0;return}function Ad(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;m=c[2276085]|0;b=m&l;e=b&16777215;j=c[2112932]|0;i=c[j+(e>>>10<<2)>>2]|0;if(i>>>0>9){k=b&1023;n=(d[i+(k+1)|0]|0)<<8|(d[i+k|0]|0);o=m;p=j}else{m=gj[c[j+196688+(i<<2)>>2]&4095](e)|0;n=m;o=c[2276085]|0;p=c[2112932]|0}m=n&65535&g>>>((f<<3&16^16)>>>0);c[2276075]=m>>>8;c[2276076]=m;c[2276078]=0;c[2276077]=0;f=o&l;l=m&65535;o=f&16777215;g=c[p+((o>>>10|16384)<<2)>>2]|0;if(g>>>0>9){n=f&1023;a[g+n|0]=m&255;a[g+(n+1)|0]=(l&65535)>>>8&255;return}else{gg[c[p+196728+(g<<2)>>2]&4095](o,l);return}}function Ae(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=9104156+((c[2276069]&7|8)<<2)|0;m=c[l>>2]|0;c[l>>2]=m+2;l=c[2276085]|0;b=l&m;e=b&16777215;j=c[2112932]|0;i=c[j+(e>>>10<<2)>>2]|0;if(i>>>0>9){k=b&1023;n=(d[i+(k+1)|0]|0)<<8|(d[i+k|0]|0);o=l;p=j}else{l=gj[c[j+196688+(i<<2)>>2]&4095](e)|0;n=l;o=c[2276085]|0;p=c[2112932]|0}l=n&65535&g>>>((f<<3&16^16)>>>0);c[2276075]=l>>>8;c[2276076]=l;c[2276078]=0;c[2276077]=0;f=o&m;m=l&65535;o=f&16777215;g=c[p+((o>>>10|16384)<<2)>>2]|0;if(g>>>0>9){n=f&1023;a[g+n|0]=l&255;a[g+(n+1)|0]=(m&65535)>>>8&255;return}else{gg[c[p+196728+(g<<2)>>2]&4095](o,m);return}}function Af(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=9104156+((c[2276069]&7|8)<<2)|0;m=(c[l>>2]|0)-2|0;c[l>>2]=m;l=c[2276085]|0;b=l&m;e=b&16777215;j=c[2112932]|0;i=c[j+(e>>>10<<2)>>2]|0;if(i>>>0>9){k=b&1023;n=(d[i+(k+1)|0]|0)<<8|(d[i+k|0]|0);o=l;p=j}else{l=gj[c[j+196688+(i<<2)>>2]&4095](e)|0;n=l;o=c[2276085]|0;p=c[2112932]|0}l=n&65535&g>>>((f<<3&16^16)>>>0);c[2276075]=l>>>8;c[2276076]=l;c[2276078]=0;c[2276077]=0;f=o&m;m=l&65535;o=f&16777215;g=c[p+((o>>>10|16384)<<2)>>2]|0;if(g>>>0>9){n=f&1023;a[g+n|0]=l&255;a[g+(n+1)|0]=(m&65535)>>>8&255;return}else{gg[c[p+196728+(g<<2)>>2]&4095](o,m);return}}function Ag(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0);f=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;o=p&-4;if((o|0)==(h|0)){q=p;r=g}else{c[2276083]=o;g=c[2276085]&o;o=g&16777212;h=c[2112932]|0;e=c[h+((o>>>10|32768)<<2)>>2]|0;if(e>>>0>9){j=g&1020;s=(d[e+(j|3)|0]|0)<<8|(d[e+(j|2)|0]|0)|((d[e+(j|1)|0]|0)<<8|(d[e+j|0]|0))<<16;t=p}else{p=gj[c[h+196768+(e<<2)>>2]&4095](o)|0;s=p;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;s=(r>>>((q<<3&16^16)>>>0)<<16>>16)+f|0;f=c[2276085]|0;q=s&f;r=q&16777215;t=c[2112932]|0;p=c[t+(r>>>10<<2)>>2]|0;if(p>>>0>9){o=q&1023;u=(d[p+(o+1)|0]|0)<<8|(d[p+o|0]|0);v=f;w=t}else{f=gj[c[t+196688+(p<<2)>>2]&4095](r)|0;u=f;v=c[2276085]|0;w=c[2112932]|0}f=u&65535&n;c[2276075]=f>>>8;c[2276076]=f;c[2276078]=0;c[2276077]=0;n=v&s;s=f&65535;v=n&16777215;u=c[w+((v>>>10|16384)<<2)>>2]|0;if(u>>>0>9){r=n&1023;a[u+r|0]=f&255;a[u+(r+1)|0]=(s&65535)>>>8&255;return}else{gg[c[w+196728+(u<<2)>>2]&4095](v,s);return}}function Ah(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=xw(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;m=c[2276085]|0;b=m&l;e=b&16777215;j=c[2112932]|0;i=c[j+(e>>>10<<2)>>2]|0;if(i>>>0>9){k=b&1023;n=(d[i+(k+1)|0]|0)<<8|(d[i+k|0]|0);o=m;p=j}else{m=gj[c[j+196688+(i<<2)>>2]&4095](e)|0;n=m;o=c[2276085]|0;p=c[2112932]|0}m=n&65535&g>>>((f<<3&16^16)>>>0);c[2276075]=m>>>8;c[2276076]=m;c[2276078]=0;c[2276077]=0;f=o&l;l=m&65535;o=f&16777215;g=c[p+((o>>>10|16384)<<2)>>2]|0;if(g>>>0>9){n=f&1023;a[g+n|0]=m&255;a[g+(n+1)|0]=(l&65535)>>>8&255;return}else{gg[c[p+196728+(g<<2)>>2]&4095](o,l);return}}function Ai(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0);f=p&-4;if((f|0)==(h|0)){q=p;r=g}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;h=c[2112932]|0;o=c[h+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=p}else{p=gj[c[h+196768+(o<<2)>>2]&4095](f)|0;s=p;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;s=r>>>((q<<3&16^16)>>>0)<<16>>16;q=c[2276085]|0;r=s&q;t=r&16777215;p=c[2112932]|0;f=c[p+(t>>>10<<2)>>2]|0;if(f>>>0>9){o=r&1023;u=(d[f+(o+1)|0]|0)<<8|(d[f+o|0]|0);v=q;w=p}else{q=gj[c[p+196688+(f<<2)>>2]&4095](t)|0;u=q;v=c[2276085]|0;w=c[2112932]|0}q=u&65535&n;c[2276075]=q>>>8;c[2276076]=q;c[2276078]=0;c[2276077]=0;n=v&s;s=q&65535;v=n&16777215;u=c[w+((v>>>10|16384)<<2)>>2]|0;if(u>>>0>9){t=n&1023;a[u+t|0]=q&255;a[u+(t+1)|0]=(s&65535)>>>8&255;return}else{gg[c[w+196728+(u<<2)>>2]&4095](v,s);return}}function Aj(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=g>>>((f<<3&16^16)>>>0);f=p&-4;if((f|0)==(h|0)){q=p;r=h;s=g}else{c[2276083]=f;g=c[2276085]&f;h=g&16777212;o=c[2112932]|0;e=c[o+((h>>>10|32768)<<2)>>2]|0;if(e>>>0>9){j=g&1020;t=(d[e+(j|3)|0]|0)<<8|(d[e+(j|2)|0]|0)|((d[e+(j|1)|0]|0)<<8|(d[e+j|0]|0))<<16;u=p;v=f}else{f=gj[c[o+196768+(e<<2)>>2]&4095](h)|0;t=f;u=c[2276056]|0;v=c[2276083]|0}c[2276084]=t;q=u;r=v;s=t}t=q+2|0;c[2276056]=t;q=t&-4;if((q|0)==(r|0)){w=s;x=t}else{c[2276083]=q;r=c[2276085]&q;q=r&16777212;v=c[2112932]|0;u=c[v+((q>>>10|32768)<<2)>>2]|0;if(u>>>0>9){f=r&1020;y=(d[u+(f|3)|0]|0)<<8|(d[u+(f|2)|0]|0)|((d[u+(f|1)|0]|0)<<8|(d[u+f|0]|0))<<16;z=t}else{t=gj[c[v+196768+(u<<2)>>2]&4095](q)|0;y=t;z=c[2276056]|0}c[2276084]=y;w=y>>>16|s<<16;x=z}c[2276056]=x+2;x=c[2276085]|0;z=x&w;s=z&16777215;y=c[2112932]|0;t=c[y+(s>>>10<<2)>>2]|0;if(t>>>0>9){q=z&1023;A=(d[t+(q+1)|0]|0)<<8|(d[t+q|0]|0);B=x;C=y}else{x=gj[c[y+196688+(t<<2)>>2]&4095](s)|0;A=x;B=c[2276085]|0;C=c[2112932]|0}x=A&65535&n;c[2276075]=x>>>8;c[2276076]=x;c[2276078]=0;c[2276077]=0;n=B&w;w=x&65535;B=n&16777215;A=c[C+((B>>>10|16384)<<2)>>2]|0;if(A>>>0>9){s=n&1023;a[A+s|0]=x&255;a[A+(s+1)|0]=(w&65535)>>>8&255;return}else{gg[c[C+196728+(A<<2)>>2]&4095](B,w);return}}function Ak(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=b;g=c[2276084]|0}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=o;g=m}m=e+2|0;c[2276056]=m;e=m&-4;if((e|0)==(f|0)){p=g;q=m;r=q+2|0;c[2276056]=r;s=c[2276069]|0;t=s&7;u=9104156+(t<<2)|0;v=c[u>>2]|0;w=v&p;c[u>>2]=w;c[2276076]=w;x=w>>>24;c[2276075]=x;c[2276078]=0;c[2276077]=0;return}c[2276083]=e;f=c[2276085]&e;e=f&16777212;o=c[2112932]|0;n=c[o+((e>>>10|32768)<<2)>>2]|0;if(n>>>0>9){b=f&1020;y=(d[n+(b|3)|0]|0)<<8|(d[n+(b|2)|0]|0)|((d[n+(b|1)|0]|0)<<8|(d[n+b|0]|0))<<16;z=m}else{m=gj[c[o+196768+(n<<2)>>2]&4095](e)|0;y=m;z=c[2276056]|0}c[2276084]=y;p=y>>>16|g<<16;q=z;r=q+2|0;c[2276056]=r;s=c[2276069]|0;t=s&7;u=9104156+(t<<2)|0;v=c[u>>2]|0;w=v&p;c[u>>2]=w;c[2276076]=w;x=w>>>24;c[2276075]=x;c[2276078]=0;c[2276077]=0;return}function Al(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;t=c[2276085]|0;h=t&r;s=h&16777215;n=c[2112932]|0;f=c[n+(s>>>10<<2)>>2]|0;if(f>>>0>9){o=h&1023;u=(d[f+(o+3)|0]|0)<<8|(d[f+(o+2)|0]|0)|((d[f+(o+1)|0]|0)<<8|(d[f+o|0]|0))<<16;v=t;w=n}else{t=gj[c[n+196768+(f<<2)>>2]&4095](s)|0;u=t;v=c[2276085]|0;w=c[2112932]|0}t=u&q;q=t>>>24;c[2276075]=q;c[2276076]=t;c[2276078]=0;c[2276077]=0;u=v&r;r=u&16777215;v=c[w+((r>>>10|16384)<<2)>>2]|0;if(v>>>0>9){s=u&1023;a[v+s|0]=t>>>16&255;a[v+(s+1)|0]=q&255;a[v+(s+2)|0]=t&255;a[v+(s+3)|0]=t>>>8&255;return}else{gg[c[w+196808+(v<<2)>>2]&4095](r,t);return}}function Am(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=9104156+((c[2276069]&7|8)<<2)|0;t=c[r>>2]|0;c[r>>2]=t+4;r=c[2276085]|0;h=r&t;s=h&16777215;n=c[2112932]|0;f=c[n+(s>>>10<<2)>>2]|0;if(f>>>0>9){o=h&1023;u=(d[f+(o+3)|0]|0)<<8|(d[f+(o+2)|0]|0)|((d[f+(o+1)|0]|0)<<8|(d[f+o|0]|0))<<16;v=r;w=n}else{r=gj[c[n+196768+(f<<2)>>2]&4095](s)|0;u=r;v=c[2276085]|0;w=c[2112932]|0}r=u&q;q=r>>>24;c[2276075]=q;c[2276076]=r;c[2276078]=0;c[2276077]=0;u=v&t;t=u&16777215;v=c[w+((t>>>10|16384)<<2)>>2]|0;if(v>>>0>9){s=u&1023;a[v+s|0]=r>>>16&255;a[v+(s+1)|0]=q&255;a[v+(s+2)|0]=r&255;a[v+(s+3)|0]=r>>>8&255;return}else{gg[c[w+196808+(v<<2)>>2]&4095](t,r);return}}function An(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=9104156+((c[2276069]&7|8)<<2)|0;t=(c[r>>2]|0)-4|0;c[r>>2]=t;r=c[2276085]|0;h=r&t;s=h&16777215;n=c[2112932]|0;f=c[n+(s>>>10<<2)>>2]|0;if(f>>>0>9){o=h&1023;u=(d[f+(o+3)|0]|0)<<8|(d[f+(o+2)|0]|0)|((d[f+(o+1)|0]|0)<<8|(d[f+o|0]|0))<<16;v=r;w=n}else{r=gj[c[n+196768+(f<<2)>>2]&4095](s)|0;u=r;v=c[2276085]|0;w=c[2112932]|0}r=u&q;q=r>>>24;c[2276075]=q;c[2276076]=r;c[2276078]=0;c[2276077]=0;u=v&t;t=u&16777215;v=c[w+((t>>>10|16384)<<2)>>2]|0;if(v>>>0>9){s=u&1023;a[v+s|0]=r>>>16&255;a[v+(s+1)|0]=q&255;a[v+(s+2)|0]=r&255;a[v+(s+3)|0]=r>>>8&255;return}else{gg[c[w+196808+(v<<2)>>2]&4095](t,r);return}}function Ao(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;f=p&-4;if((f|0)==(h|0)){q=g;r=p;s=h;t=g}else{c[2276083]=f;h=c[2276085]&f;n=h&16777212;o=c[2112932]|0;e=c[o+((n>>>10|32768)<<2)>>2]|0;if(e>>>0>9){j=h&1020;u=(d[e+(j|3)|0]|0)<<8|(d[e+(j|2)|0]|0)|((d[e+(j|1)|0]|0)<<8|(d[e+j|0]|0))<<16;v=p;w=f}else{f=gj[c[o+196768+(e<<2)>>2]&4095](n)|0;u=f;v=c[2276056]|0;w=c[2276083]|0}c[2276084]=u;q=u>>>16|g<<16;r=v;s=w;t=u}u=r+2|0;c[2276056]=u;r=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;w=u&-4;if((w|0)==(s|0)){x=u;y=t}else{c[2276083]=w;t=c[2276085]&w;w=t&16777212;s=c[2112932]|0;v=c[s+((w>>>10|32768)<<2)>>2]|0;if(v>>>0>9){g=t&1020;z=(d[v+(g|3)|0]|0)<<8|(d[v+(g|2)|0]|0)|((d[v+(g|1)|0]|0)<<8|(d[v+g|0]|0))<<16;A=u}else{u=gj[c[s+196768+(v<<2)>>2]&4095](w)|0;z=u;A=c[2276056]|0}c[2276084]=z;x=A;y=z}c[2276056]=x+2;z=(y>>>((x<<3&16^16)>>>0)<<16>>16)+r|0;r=c[2276085]|0;x=z&r;y=x&16777215;A=c[2112932]|0;u=c[A+(y>>>10<<2)>>2]|0;if(u>>>0>9){w=x&1023;B=(d[u+(w+3)|0]|0)<<8|(d[u+(w+2)|0]|0)|((d[u+(w+1)|0]|0)<<8|(d[u+w|0]|0))<<16;C=r;D=A}else{r=gj[c[A+196768+(u<<2)>>2]&4095](y)|0;B=r;C=c[2276085]|0;D=c[2112932]|0}r=B&q;q=r>>>24;c[2276075]=q;c[2276076]=r;c[2276078]=0;c[2276077]=0;B=C&z;z=B&16777215;C=c[D+((z>>>10|16384)<<2)>>2]|0;if(C>>>0>9){y=B&1023;a[C+y|0]=r>>>16&255;a[C+(y+1)|0]=q&255;a[C+(y+2)|0]=r&255;a[C+(y+3)|0]=r>>>8&255;return}else{gg[c[D+196808+(C<<2)>>2]&4095](z,r);return}}function Ap(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=xw(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;t=c[2276085]|0;h=t&r;s=h&16777215;n=c[2112932]|0;f=c[n+(s>>>10<<2)>>2]|0;if(f>>>0>9){o=h&1023;u=(d[f+(o+3)|0]|0)<<8|(d[f+(o+2)|0]|0)|((d[f+(o+1)|0]|0)<<8|(d[f+o|0]|0))<<16;v=t;w=n}else{t=gj[c[n+196768+(f<<2)>>2]&4095](s)|0;u=t;v=c[2276085]|0;w=c[2112932]|0}t=u&q;q=t>>>24;c[2276075]=q;c[2276076]=t;c[2276078]=0;c[2276077]=0;u=v&r;r=u&16777215;v=c[w+((r>>>10|16384)<<2)>>2]|0;if(v>>>0>9){s=u&1023;a[v+s|0]=t>>>16&255;a[v+(s+1)|0]=q&255;a[v+(s+2)|0]=t&255;a[v+(s+3)|0]=t>>>8&255;return}else{gg[c[w+196808+(v<<2)>>2]&4095](r,t);return}}function Aq(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;f=p&-4;if((f|0)==(h|0)){q=g;r=p;s=h;t=g}else{c[2276083]=f;h=c[2276085]&f;n=h&16777212;o=c[2112932]|0;e=c[o+((n>>>10|32768)<<2)>>2]|0;if(e>>>0>9){j=h&1020;u=(d[e+(j|3)|0]|0)<<8|(d[e+(j|2)|0]|0)|((d[e+(j|1)|0]|0)<<8|(d[e+j|0]|0))<<16;v=p;w=f}else{f=gj[c[o+196768+(e<<2)>>2]&4095](n)|0;u=f;v=c[2276056]|0;w=c[2276083]|0}c[2276084]=u;q=u>>>16|g<<16;r=v;s=w;t=u}u=r+2|0;c[2276056]=u;r=u&-4;if((r|0)==(s|0)){x=u;y=t}else{c[2276083]=r;t=c[2276085]&r;r=t&16777212;s=c[2112932]|0;w=c[s+((r>>>10|32768)<<2)>>2]|0;if(w>>>0>9){v=t&1020;z=(d[w+(v|3)|0]|0)<<8|(d[w+(v|2)|0]|0)|((d[w+(v|1)|0]|0)<<8|(d[w+v|0]|0))<<16;A=u}else{u=gj[c[s+196768+(w<<2)>>2]&4095](r)|0;z=u;A=c[2276056]|0}c[2276084]=z;x=A;y=z}c[2276056]=x+2;z=y>>>((x<<3&16^16)>>>0)<<16>>16;x=c[2276085]|0;y=z&x;A=y&16777215;u=c[2112932]|0;r=c[u+(A>>>10<<2)>>2]|0;if(r>>>0>9){w=y&1023;B=(d[r+(w+3)|0]|0)<<8|(d[r+(w+2)|0]|0)|((d[r+(w+1)|0]|0)<<8|(d[r+w|0]|0))<<16;C=x;D=u}else{x=gj[c[u+196768+(r<<2)>>2]&4095](A)|0;B=x;C=c[2276085]|0;D=c[2112932]|0}x=B&q;q=x>>>24;c[2276075]=q;c[2276076]=x;c[2276078]=0;c[2276077]=0;B=C&z;z=B&16777215;C=c[D+((z>>>10|16384)<<2)>>2]|0;if(C>>>0>9){A=B&1023;a[C+A|0]=x>>>16&255;a[C+(A+1)|0]=q&255;a[C+(A+2)|0]=x&255;a[C+(A+3)|0]=x>>>8&255;return}else{gg[c[D+196808+(C<<2)>>2]&4095](z,x);return}}function Ar(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;f=p&-4;if((f|0)==(h|0)){q=g;r=p;s=h;t=g}else{c[2276083]=f;h=c[2276085]&f;n=h&16777212;o=c[2112932]|0;e=c[o+((n>>>10|32768)<<2)>>2]|0;if(e>>>0>9){j=h&1020;u=(d[e+(j|3)|0]|0)<<8|(d[e+(j|2)|0]|0)|((d[e+(j|1)|0]|0)<<8|(d[e+j|0]|0))<<16;v=p;w=f}else{f=gj[c[o+196768+(e<<2)>>2]&4095](n)|0;u=f;v=c[2276056]|0;w=c[2276083]|0}c[2276084]=u;q=u>>>16|g<<16;r=v;s=w;t=u}u=r+2|0;c[2276056]=u;r=u&-4;if((r|0)==(s|0)){x=u;y=s;z=t}else{c[2276083]=r;t=c[2276085]&r;s=t&16777212;w=c[2112932]|0;v=c[w+((s>>>10|32768)<<2)>>2]|0;if(v>>>0>9){g=t&1020;A=(d[v+(g|3)|0]|0)<<8|(d[v+(g|2)|0]|0)|((d[v+(g|1)|0]|0)<<8|(d[v+g|0]|0))<<16;B=u;C=r}else{r=gj[c[w+196768+(v<<2)>>2]&4095](s)|0;A=r;B=c[2276056]|0;C=c[2276083]|0}c[2276084]=A;x=B;y=C;z=A}A=x+2|0;c[2276056]=A;x=A&-4;if((x|0)==(y|0)){D=z;E=A}else{c[2276083]=x;y=c[2276085]&x;x=y&16777212;C=c[2112932]|0;B=c[C+((x>>>10|32768)<<2)>>2]|0;if(B>>>0>9){r=y&1020;F=(d[B+(r|3)|0]|0)<<8|(d[B+(r|2)|0]|0)|((d[B+(r|1)|0]|0)<<8|(d[B+r|0]|0))<<16;G=A}else{A=gj[c[C+196768+(B<<2)>>2]&4095](x)|0;F=A;G=c[2276056]|0}c[2276084]=F;D=F>>>16|z<<16;E=G}c[2276056]=E+2;E=c[2276085]|0;G=E&D;z=G&16777215;F=c[2112932]|0;A=c[F+(z>>>10<<2)>>2]|0;if(A>>>0>9){x=G&1023;H=(d[A+(x+3)|0]|0)<<8|(d[A+(x+2)|0]|0)|((d[A+(x+1)|0]|0)<<8|(d[A+x|0]|0))<<16;I=E;J=F}else{E=gj[c[F+196768+(A<<2)>>2]&4095](z)|0;H=E;I=c[2276085]|0;J=c[2112932]|0}E=H&q;q=E>>>24;c[2276075]=q;c[2276076]=E;c[2276078]=0;c[2276077]=0;H=I&D;D=H&16777215;I=c[J+((D>>>10|16384)<<2)>>2]|0;if(I>>>0>9){z=H&1023;a[I+z|0]=E>>>16&255;a[I+(z+1)|0]=q&255;a[I+(z+2)|0]=E&255;a[I+(z+3)|0]=E>>>8&255;return}else{gg[c[J+196808+(I<<2)>>2]&4095](D,E);return}}function As(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a=(c[2276075]|0)>>>4&8|(c[2276074]|0)>>>4&16|((c[2276076]|0)==0)<<2|(c[2276077]|0)>>>6&2;b=(c[2276078]|0)>>>8;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=h>>>((g<<3&16^16)>>>0)&(a|b&1);b=m<<4;c[2276074]=b&256;c[2276075]=b&128;c[2276076]=m>>>2&1^1;c[2276077]=m<<6&128;c[2276078]=m<<8&256;return}function At(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;b=c[2276072]|0;if((b|0)==0){e=c[2276073]|0;f=c[2276071]|c[2276070]|e<<11|c[2276079]|(c[2276074]|0)>>>4&16|(c[2276075]|0)>>>4&8|((c[2276076]|0)==0)<<2|(c[2276077]|0)>>>6&2|(c[2276078]|0)>>>8&1;c[2276071]=0;c[2276070]=0;c[2276057]=c[2276054];c[2276072]=4;g=c[9104228+((e&2|4)<<2)>>2]|0;c[2276054]=g;e=c[2276055]|0;do{if(((c[2276038]|0)-1|0)>>>0<2){h=g-4|0;c[2276054]=h;i=c[2276085]&h;h=i&16777215;j=c[2112932]|0;k=c[j+((h>>>10|16384)<<2)>>2]|0;if(k>>>0>9){l=i&1023;a[k+l|0]=e>>>16&255;a[k+(l+1)|0]=e>>>24&255;a[k+(l+2)|0]=e&255;a[k+(l+3)|0]=e>>>8&255;m=j}else{gg[c[j+196808+(k<<2)>>2]&4095](h,e);m=c[2112932]|0}h=(c[2276054]|0)-2|0;c[2276054]=h;k=c[2276085]&h;h=f&65535;j=k&16777215;l=c[m+((j>>>10|16384)<<2)>>2]|0;if(l>>>0>9){i=k&1023;a[l+i|0]=f&255;a[l+(i+1)|0]=(h&65535)>>>8&255;break}else{gg[c[m+196728+(l<<2)>>2]&4095](j,h);break}}else{h=g-2|0;c[2276054]=h;j=c[2276085]&h;h=j&16777215;l=c[2112932]|0;i=c[l+((h>>>10|16384)<<2)>>2]|0;if(i>>>0>9){k=j&1023;a[i+k|0]=32;a[i+(k+1)|0]=0;n=l}else{gg[c[l+196728+(i<<2)>>2]&4095](h,32);n=c[2112932]|0}h=(c[2276054]|0)-4|0;c[2276054]=h;i=c[2276085]&h;h=i&16777215;l=c[n+((h>>>10|16384)<<2)>>2]|0;if(l>>>0>9){k=i&1023;a[l+k|0]=e>>>16&255;a[l+(k+1)|0]=e>>>24&255;a[l+(k+2)|0]=e&255;a[l+(k+3)|0]=e>>>8&255;o=n}else{gg[c[n+196808+(l<<2)>>2]&4095](h,e);o=c[2112932]|0}h=(c[2276054]|0)-2|0;c[2276054]=h;l=c[2276085]&h;h=f&65535;k=l&16777215;i=c[o+((k>>>10|16384)<<2)>>2]|0;if(i>>>0>9){j=l&1023;a[i+j|0]=f&255;a[i+(j+1)|0]=(h&65535)>>>8&255;break}else{gg[c[o+196728+(i<<2)>>2]&4095](k,h);break}}}while(0);o=(c[2276064]|0)+32|0;c[2276056]=o;f=c[2276085]&o;o=f&16777215;e=c[2112932]|0;n=c[e+(o>>>10<<2)>>2]|0;if(n>>>0>9){g=f&1023;p=(d[n+(g+3)|0]|0)<<8|(d[n+(g+2)|0]|0)|((d[n+(g+1)|0]|0)<<8|(d[n+g|0]|0))<<16}else{p=gj[c[e+196768+(n<<2)>>2]&4095](o)|0}c[2276056]=p;c[2276108]=(d[(c[2276098]|0)+(c[2276069]|0)|0]|0)-(d[(c[2276099]|0)+8|0]|0)+(c[2276108]|0);return}p=c[2276056]|0;o=p&-4;if((o|0)==(c[2276083]|0)){q=p;r=c[2276084]|0;s=b}else{c[2276083]=o;n=c[2276085]&o;o=n&16777212;e=c[2112932]|0;g=c[e+((o>>>10|32768)<<2)>>2]|0;if(g>>>0>9){f=n&1020;t=(d[g+(f|3)|0]|0)<<8|(d[g+(f|2)|0]|0)|((d[g+(f|1)|0]|0)<<8|(d[g+f|0]|0))<<16;u=p;v=b}else{b=gj[c[e+196768+(g<<2)>>2]&4095](o)|0;t=b;u=c[2276056]|0;v=c[2276072]|0}c[2276084]=t;q=u;r=t;s=v}c[2276056]=q+2;v=c[2276073]|0;t=r>>>((q<<3&16^16)>>>0)&65535&c[2276086]&(c[2276070]|s<<11|c[2276071]|v<<11|c[2276079]|(c[2276074]|0)>>>4&16|(c[2276075]|0)>>>4&8|((c[2276076]|0)==0)<<2|(c[2276077]|0)>>>6&2|(c[2276078]|0)>>>8&1);c[2276070]=t&32768;c[2276071]=t&16384;c[2276079]=t&1792;q=t<<4;c[2276074]=q&256;c[2276075]=q&128;c[2276076]=t>>>2&1^1;c[2276077]=t<<6&128;c[2276078]=t<<8&256;q=t>>>11;c[9104228+((v&s>>>1|s)<<2)>>2]=c[2276054];s=q&4;c[2276072]=s;v=q&2;c[2276073]=v;c[2276054]=c[9104228+((s>>>1&v|s)<<2)>>2];s=c[2276080]|0;if(s>>>0<=(c[2276079]|0)>>>0){return}v=s>>>8;s=c[2276082]&-2;c[2276082]=s;if((s|0)!=0){return}s=8452200+(c[2394]<<2)|0;if((c[s>>2]&8192|0)!=0){c[2276080]=0;c[s>>2]=0}s=c[(c[2112932]|0)+196856>>2]|0;do{if((s|0)==0){w=25676}else{q=gj[s&4095](v)|0;if((q|0)==(-1|0)){w=25676;break}else if((q|0)==(-2|0)){x=24;break}if(q>>>0<=255){x=q;break}return}}while(0);if((w|0)==25676){x=v+24|0}w=c[2276072]|0;s=c[2276073]|0;q=c[2276071]|c[2276070]|w<<11|s<<11|c[2276079]|(c[2276074]|0)>>>4&16|(c[2276075]|0)>>>4&8|((c[2276076]|0)==0)<<2|(c[2276077]|0)>>>6&2|(c[2276078]|0)>>>8&1;c[2276071]=0;c[2276070]=0;c[9104228+((w>>>1&s|w)<<2)>>2]=c[2276054];c[2276072]=4;c[2276054]=c[9104228+((c[2276073]&2|4)<<2)>>2];c[2276079]=v<<8;v=x<<2;w=c[2276085]&(c[2276064]|0)+v;s=w&16777215;t=c[2112932]|0;r=c[t+(s>>>10<<2)>>2]|0;if(r>>>0>9){u=w&1023;y=(d[r+(u+3)|0]|0)<<8|(d[r+(u+2)|0]|0)|((d[r+(u+1)|0]|0)<<8|(d[r+u|0]|0))<<16}else{y=gj[c[t+196768+(r<<2)>>2]&4095](s)|0}do{if((y|0)==0){s=c[2276085]&(c[2276064]|0)+60;r=s&16777215;t=c[2112932]|0;u=c[t+(r>>>10<<2)>>2]|0;if(u>>>0>9){w=s&1023;z=(d[u+(w+3)|0]|0)<<8|(d[u+(w+2)|0]|0)|((d[u+(w+1)|0]|0)<<8|(d[u+w|0]|0))<<16;break}else{z=gj[c[t+196768+(u<<2)>>2]&4095](r)|0;break}}else{z=y}}while(0);y=c[2276056]|0;r=c[2276054]|0;do{if(((c[2276038]|0)-1|0)>>>0<2){u=r-4|0;c[2276054]=u;t=c[2276085]&u;u=t&16777215;w=c[2112932]|0;s=c[w+((u>>>10|16384)<<2)>>2]|0;if(s>>>0>9){b=t&1023;a[s+b|0]=y>>>16&255;a[s+(b+1)|0]=y>>>24&255;a[s+(b+2)|0]=y&255;a[s+(b+3)|0]=y>>>8&255;A=w}else{gg[c[w+196808+(s<<2)>>2]&4095](u,y);A=c[2112932]|0}u=(c[2276054]|0)-2|0;c[2276054]=u;s=c[2276085]&u;u=q&65535;w=s&16777215;b=c[A+((w>>>10|16384)<<2)>>2]|0;if(b>>>0>9){t=s&1023;a[b+t|0]=q&255;a[b+(t+1)|0]=(u&65535)>>>8&255;break}else{gg[c[A+196728+(b<<2)>>2]&4095](w,u);break}}else{u=r-2|0;c[2276054]=u;w=c[2276085]&u;u=w&16777215;b=c[2112932]|0;t=c[b+((u>>>10|16384)<<2)>>2]|0;if(t>>>0>9){s=w&1023;a[t+s|0]=v&255;a[t+(s+1)|0]=x>>>6&255;B=b}else{gg[c[b+196728+(t<<2)>>2]&4095](u,v&65535);B=c[2112932]|0}u=(c[2276054]|0)-4|0;c[2276054]=u;t=c[2276085]&u;u=t&16777215;b=c[B+((u>>>10|16384)<<2)>>2]|0;if(b>>>0>9){s=t&1023;a[b+s|0]=y>>>16&255;a[b+(s+1)|0]=y>>>24&255;a[b+(s+2)|0]=y&255;a[b+(s+3)|0]=y>>>8&255;C=B}else{gg[c[B+196808+(b<<2)>>2]&4095](u,y);C=c[2112932]|0}u=(c[2276054]|0)-2|0;c[2276054]=u;b=c[2276085]&u;u=q&65535;s=b&16777215;t=c[C+((s>>>10|16384)<<2)>>2]|0;if(t>>>0>9){w=b&1023;a[t+w|0]=q&255;a[t+(w+1)|0]=(u&65535)>>>8&255;break}else{gg[c[C+196728+(t<<2)>>2]&4095](s,u);break}}}while(0);C=c[2276073]|0;do{if((C|0)!=0){if((c[2276038]&24|0)==0){break}y=c[2276072]|0;c[9104228+((y>>>1&C|y)<<2)>>2]=c[2276054];B=y&4;c[2276072]=B;r=y&2;c[2276073]=r;y=c[2276056]|0;A=(c[9104228+((B>>>1&r|B)<<2)>>2]|0)-2|0;c[2276054]=A;B=c[2276085]&A;A=(v|4096)&65535;r=B&16777215;u=c[2112932]|0;s=c[u+((r>>>10|16384)<<2)>>2]|0;if(s>>>0>9){t=B&1023;a[s+t|0]=v&255;a[s+(t+1)|0]=(A&65535)>>>8&255;D=u}else{gg[c[u+196728+(s<<2)>>2]&4095](r,A);D=c[2112932]|0}A=(c[2276054]|0)-4|0;c[2276054]=A;r=c[2276085]&A;A=r&16777215;s=c[D+((A>>>10|16384)<<2)>>2]|0;if(s>>>0>9){u=r&1023;a[s+u|0]=y>>>16&255;a[s+(u+1)|0]=y>>>24&255;a[s+(u+2)|0]=y&255;a[s+(u+3)|0]=y>>>8&255;E=D}else{gg[c[D+196808+(s<<2)>>2]&4095](A,y);E=c[2112932]|0}y=(c[2276054]|0)-2|0;c[2276054]=y;A=c[2276085]&y;y=(q|8192)&65535;s=A&16777215;u=c[E+((s>>>10|16384)<<2)>>2]|0;if(u>>>0>9){r=A&1023;a[u+r|0]=q&255;a[u+(r+1)|0]=(y&65535)>>>8&255;break}else{gg[c[E+196728+(u<<2)>>2]&4095](s,y);break}}}while(0);c[2276056]=z;c[2276081]=(c[2276081]|0)+(d[(c[2276099]|0)+x|0]|0);return}function Au(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0;a=c[2276069]|0;b=9104156+((a&7)<<2)|0;e=(a>>>9)+7&7;a=e+1|0;f=c[b>>2]|0;g=f&255;h=g>>>(a>>>0);c[2276108]=(c[2276108]|0)-(a<<c[2276096]);if((f&128|0)==0){i=h}else{i=d[10688+a|0]|0|h}c[b>>2]=i|f&-256;c[2276075]=i;c[2276076]=i;c[2276077]=0;i=g<<8-e;c[2276078]=i;c[2276074]=i;return}function Av(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0;a=c[2276069]|0;b=9104156+((a&7)<<2)|0;d=(a>>>9)+7&7;a=d+1|0;f=c[b>>2]|0;g=f&65535;h=g>>>(a>>>0);c[2276108]=(c[2276108]|0)-(a<<c[2276096]);if((f&32768|0)==0){i=h}else{i=e[11024+(a<<1)>>1]|0|h}c[b>>2]=i|f&-65536;c[2276075]=i>>>8;c[2276076]=i;c[2276077]=0;i=g<<8-d;c[2276078]=i;c[2276074]=i;return}function Aw(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[2276069]|0;b=9104156+((a&7)<<2)|0;d=(a>>>9)+7&7;a=d+1|0;e=c[b>>2]|0;f=e>>>(a>>>0);c[2276108]=(c[2276108]|0)-(a<<c[2276096]);if((e|0)<0){g=c[10760+(a<<2)>>2]|f}else{g=f}c[b>>2]=g;c[2276075]=g>>>24;c[2276076]=g;c[2276077]=0;g=e<<8-d;c[2276078]=g;c[2276074]=g;return}function Ax(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0;a=c[2276069]|0;b=9104156+((a&7)<<2)|0;e=c[9104156+((a>>>9&7)<<2)>>2]&63;a=c[b>>2]|0;f=a&255;g=f>>>(e>>>0);if((e|0)==0){c[2276078]=0;c[2276075]=f;c[2276076]=f;c[2276077]=0;return}c[2276108]=(c[2276108]|0)-(e<<c[2276096]);h=(a&128|0)!=0;if(e>>>0<8){if(h){i=d[10688+e|0]|0|g}else{i=g}c[b>>2]=i|a&-256;g=f<<9-e;c[2276078]=g;c[2276074]=g;c[2276075]=i;c[2276076]=i;c[2276077]=0;return}if(h){c[b>>2]=a|255;c[2276078]=256;c[2276074]=256;c[2276075]=128;c[2276076]=-1;c[2276077]=0;return}else{c[b>>2]=a&-256;gGz(9104296,0,20);return}}function Ay(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0;a=c[2276069]|0;b=9104156+((a&7)<<2)|0;d=c[9104156+((a>>>9&7)<<2)>>2]&63;a=c[b>>2]|0;f=a&65535;g=f>>>(d>>>0);if((d|0)==0){c[2276078]=0;c[2276075]=f>>>8;c[2276076]=f;c[2276077]=0;return}c[2276108]=(c[2276108]|0)-(d<<c[2276096]);h=(a&32768|0)!=0;if(d>>>0<16){if(h){i=e[11024+(d<<1)>>1]|0|g}else{i=g}c[b>>2]=i|a&-65536;g=f>>>((d-1|0)>>>0)<<8;c[2276074]=g;c[2276078]=g;c[2276075]=i>>>8;c[2276076]=i;c[2276077]=0;return}if(h){c[b>>2]=a|65535;c[2276078]=256;c[2276074]=256;c[2276075]=128;c[2276076]=-1;c[2276077]=0;return}else{c[b>>2]=a&-65536;gGz(9104296,0,20);return}}function Az(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[2276069]|0;b=9104156+((a&7)<<2)|0;d=c[9104156+((a>>>9&7)<<2)>>2]&63;a=c[b>>2]|0;e=a>>>(d>>>0);if((d|0)==0){c[2276078]=0;c[2276075]=a>>>24;c[2276076]=a;c[2276077]=0;return}c[2276108]=(c[2276108]|0)-(d<<c[2276096]);f=(a|0)<0;if(d>>>0<32){if(f){g=c[10760+(d<<2)>>2]|e}else{g=e}c[b>>2]=g;e=a>>>((d-1|0)>>>0)<<8;c[2276074]=e;c[2276078]=e;c[2276075]=g>>>24;c[2276076]=g;c[2276077]=0;return}if(f){c[b>>2]=-1;c[2276078]=256;c[2276074]=256;c[2276075]=128;c[2276076]=-1;c[2276077]=0;return}else{c[b>>2]=0;gGz(9104296,0,20);return}}function AA(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276085]|0;f=e&b;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=f&1023;k=(d[i+(j+1)|0]|0)<<8|(d[i+j|0]|0);l=e;m=h}else{e=gj[c[h+196688+(i<<2)>>2]&4095](g)|0;k=e;l=c[2276085]|0;m=c[2112932]|0}e=k&65535;k=e>>>1;g=(e&32768|0)==0?k:k|32768;k=l&b;b=g&65535;l=k&16777215;i=c[m+((l>>>10|16384)<<2)>>2]|0;if(i>>>0>9){h=k&1023;a[i+h|0]=g&255;a[i+(h+1)|0]=(b&65535)>>>8&255;n=g>>>8;c[2276075]=n;c[2276076]=g;c[2276077]=0;o=e<<8;c[2276074]=o;c[2276078]=o;return}else{gg[c[m+196728+(i<<2)>>2]&4095](l,b);n=g>>>8;c[2276075]=n;c[2276076]=g;c[2276077]=0;o=e<<8;c[2276074]=o;c[2276078]=o;return}}function AB(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=c[b>>2]|0;c[b>>2]=e+2;b=c[2276085]|0;f=b&e;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=f&1023;k=(d[i+(j+1)|0]|0)<<8|(d[i+j|0]|0);l=b;m=h}else{b=gj[c[h+196688+(i<<2)>>2]&4095](g)|0;k=b;l=c[2276085]|0;m=c[2112932]|0}b=k&65535;k=b>>>1;g=(b&32768|0)==0?k:k|32768;k=l&e;e=g&65535;l=k&16777215;i=c[m+((l>>>10|16384)<<2)>>2]|0;if(i>>>0>9){h=k&1023;a[i+h|0]=g&255;a[i+(h+1)|0]=(e&65535)>>>8&255;n=g>>>8;c[2276075]=n;c[2276076]=g;c[2276077]=0;o=b<<8;c[2276074]=o;c[2276078]=o;return}else{gg[c[m+196728+(i<<2)>>2]&4095](l,e);n=g>>>8;c[2276075]=n;c[2276076]=g;c[2276077]=0;o=b<<8;c[2276074]=o;c[2276078]=o;return}}function AC(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=(c[b>>2]|0)-2|0;c[b>>2]=e;b=c[2276085]|0;f=b&e;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=f&1023;k=(d[i+(j+1)|0]|0)<<8|(d[i+j|0]|0);l=b;m=h}else{b=gj[c[h+196688+(i<<2)>>2]&4095](g)|0;k=b;l=c[2276085]|0;m=c[2112932]|0}b=k&65535;k=b>>>1;g=(b&32768|0)==0?k:k|32768;k=l&e;e=g&65535;l=k&16777215;i=c[m+((l>>>10|16384)<<2)>>2]|0;if(i>>>0>9){h=k&1023;a[i+h|0]=g&255;a[i+(h+1)|0]=(e&65535)>>>8&255;n=g>>>8;c[2276075]=n;c[2276076]=g;c[2276077]=0;o=b<<8;c[2276074]=o;c[2276078]=o;return}else{gg[c[m+196728+(i<<2)>>2]&4095](l,e);n=g>>>8;c[2276075]=n;c[2276076]=g;c[2276077]=0;o=b<<8;c[2276074]=o;c[2276078]=o;return}}function AD(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=(h>>>((g<<3&16^16)>>>0)<<16>>16)+b|0;b=c[2276085]|0;g=m&b;h=g&16777215;n=c[2112932]|0;e=c[n+(h>>>10<<2)>>2]|0;if(e>>>0>9){f=g&1023;o=(d[e+(f+1)|0]|0)<<8|(d[e+f|0]|0);p=b;q=n}else{b=gj[c[n+196688+(e<<2)>>2]&4095](h)|0;o=b;p=c[2276085]|0;q=c[2112932]|0}b=o&65535;o=b>>>1;h=(b&32768|0)==0?o:o|32768;o=p&m;m=h&65535;p=o&16777215;e=c[q+((p>>>10|16384)<<2)>>2]|0;if(e>>>0>9){n=o&1023;a[e+n|0]=h&255;a[e+(n+1)|0]=(m&65535)>>>8&255;r=h>>>8;c[2276075]=r;c[2276076]=h;c[2276077]=0;s=b<<8;c[2276074]=s;c[2276078]=s;return}else{gg[c[q+196728+(e<<2)>>2]&4095](p,m);r=h>>>8;c[2276075]=r;c[2276076]=h;c[2276077]=0;s=b<<8;c[2276074]=s;c[2276078]=s;return}}function AE(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=xw(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;e=c[2276085]|0;f=e&b;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=f&1023;k=(d[i+(j+1)|0]|0)<<8|(d[i+j|0]|0);l=e;m=h}else{e=gj[c[h+196688+(i<<2)>>2]&4095](g)|0;k=e;l=c[2276085]|0;m=c[2112932]|0}e=k&65535;k=e>>>1;g=(e&32768|0)==0?k:k|32768;k=l&b;b=g&65535;l=k&16777215;i=c[m+((l>>>10|16384)<<2)>>2]|0;if(i>>>0>9){h=k&1023;a[i+h|0]=g&255;a[i+(h+1)|0]=(b&65535)>>>8&255;n=g>>>8;c[2276075]=n;c[2276076]=g;c[2276077]=0;o=e<<8;c[2276074]=o;c[2276078]=o;return}else{gg[c[m+196728+(i<<2)>>2]&4095](l,b);n=g>>>8;c[2276075]=n;c[2276076]=g;c[2276077]=0;o=e<<8;c[2276074]=o;c[2276078]=o;return}}function AF(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)<<16>>16;f=c[2276085]|0;g=l&f;m=g&16777215;b=c[2112932]|0;e=c[b+(m>>>10<<2)>>2]|0;if(e>>>0>9){j=g&1023;n=(d[e+(j+1)|0]|0)<<8|(d[e+j|0]|0);o=f;p=b}else{f=gj[c[b+196688+(e<<2)>>2]&4095](m)|0;n=f;o=c[2276085]|0;p=c[2112932]|0}f=n&65535;n=f>>>1;m=(f&32768|0)==0?n:n|32768;n=o&l;l=m&65535;o=n&16777215;e=c[p+((o>>>10|16384)<<2)>>2]|0;if(e>>>0>9){b=n&1023;a[e+b|0]=m&255;a[e+(b+1)|0]=(l&65535)>>>8&255;q=m>>>8;c[2276075]=q;c[2276076]=m;c[2276077]=0;r=f<<8;c[2276074]=r;c[2276078]=r;return}else{gg[c[p+196728+(e<<2)>>2]&4095](o,l);q=m>>>8;c[2276075]=q;c[2276076]=m;c[2276077]=0;r=f<<8;c[2276074]=r;c[2276078]=r;return}}function AG(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[2276085]|0;t=r&q;h=t&16777215;s=c[2112932]|0;n=c[s+(h>>>10<<2)>>2]|0;if(n>>>0>9){f=t&1023;u=(d[n+(f+1)|0]|0)<<8|(d[n+f|0]|0);v=r;w=s}else{r=gj[c[s+196688+(n<<2)>>2]&4095](h)|0;u=r;v=c[2276085]|0;w=c[2112932]|0}r=u&65535;u=r>>>1;h=(r&32768|0)==0?u:u|32768;u=v&q;q=h&65535;v=u&16777215;n=c[w+((v>>>10|16384)<<2)>>2]|0;if(n>>>0>9){s=u&1023;a[n+s|0]=h&255;a[n+(s+1)|0]=(q&65535)>>>8&255;x=h>>>8;c[2276075]=x;c[2276076]=h;c[2276077]=0;y=r<<8;c[2276074]=y;c[2276078]=y;return}else{gg[c[w+196728+(n<<2)>>2]&4095](v,q);x=h>>>8;c[2276075]=x;c[2276076]=h;c[2276077]=0;y=r<<8;c[2276074]=y;c[2276078]=y;return}}function AH(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0;a=c[2276069]|0;b=9104156+((a&7)<<2)|0;e=(a>>>9)+7&7;a=e+1|0;f=c[b>>2]|0;g=(f&255)<<a;h=g&255;c[2276108]=(c[2276108]|0)-(a<<c[2276096]);c[b>>2]=h|f&-256;c[2276078]=g;c[2276074]=g;c[2276075]=h;c[2276076]=h;h=d[e+10690|0]|0;e=h&f;if((e|0)==0){i=0;c[2276077]=i;return}if((e|0)!=(h|0)){i=128;c[2276077]=i;return}i=(a>>>0>7)<<7;c[2276077]=i;return}function AI(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0;a=c[2276069]|0;b=9104156+((a&7)<<2)|0;d=(a>>>9)+7&7;a=d+1|0;f=c[b>>2]|0;g=f&65535;h=g<<a&65535;c[2276108]=(c[2276108]|0)-(a<<c[2276096]);c[b>>2]=h|f&-65536;c[2276075]=h>>>8;c[2276076]=h;h=g>>>((d^7)>>>0);c[2276078]=h;c[2276074]=h;h=e[11024+(d+2<<1)>>1]|0;d=h&f;if((d|0)==0){i=0;c[2276077]=i;return}i=((d|0)!=(h|0))<<7;c[2276077]=i;return}function AJ(){var a=0,b=0,d=0,e=0,f=0,g=0;a=c[2276069]|0;b=9104156+((a&7)<<2)|0;d=(a>>>9)+7&7;a=d+1|0;e=c[b>>2]|0;f=e<<a;c[2276108]=(c[2276108]|0)-(a<<c[2276096]);c[b>>2]=f;c[2276075]=f>>>24;c[2276076]=f;f=e>>>((23-d|0)>>>0);c[2276078]=f;c[2276074]=f;f=c[10760+(d+2<<2)>>2]|0;d=f&e;if((d|0)==0){g=0;c[2276077]=g;return}g=((d|0)!=(f|0))<<7;c[2276077]=g;return}function AK(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;a=c[2276069]|0;b=9104156+((a&7)<<2)|0;e=c[9104156+((a>>>9&7)<<2)>>2]&63;a=c[b>>2]|0;f=a&255;g=f<<e;h=g&255;if((e|0)==0){c[2276078]=0;c[2276075]=f;c[2276076]=f;c[2276077]=0;return}c[2276108]=(c[2276108]|0)-(e<<c[2276096]);i=a&-256;if(e>>>0<8){c[b>>2]=h|i;c[2276078]=g;c[2276074]=g;c[2276075]=h;c[2276076]=h;h=d[e+10689|0]|0;g=h&a;if((g|0)==0){j=0}else{j=((g|0)!=(h|0))<<7}c[2276077]=j;return}else{c[b>>2]=i;if((e|0)==8){k=a<<8&256}else{k=0}c[2276078]=k;c[2276074]=k;c[2276075]=0;c[2276076]=0;c[2276077]=((f|0)!=0)<<7;return}}function AL(){var a=0,b=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[2276069]|0;b=9104156+((a&7)<<2)|0;d=c[9104156+((a>>>9&7)<<2)>>2]&63;a=c[b>>2]|0;f=a&65535;g=f<<d;h=g&65535;if((d|0)==0){c[2276078]=0;c[2276075]=f>>>8;c[2276076]=f;c[2276077]=0;return}c[2276108]=(c[2276108]|0)-(d<<c[2276096]);i=a&-65536;if(d>>>0<16){c[b>>2]=h|i;j=g>>>8;c[2276078]=j;c[2276074]=j;c[2276075]=h>>>8;c[2276076]=h;h=e[11024+(d+1<<1)>>1]|0;j=h&a;if((j|0)==0){k=0}else{k=((j|0)!=(h|0))<<7}c[2276077]=k;return}else{c[b>>2]=i;if((d|0)==16){l=a<<8&256}else{l=0}c[2276078]=l;c[2276074]=l;c[2276075]=0;c[2276076]=0;c[2276077]=((f|0)!=0)<<7;return}}function AM(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0;a=c[2276069]|0;b=9104156+((a&7)<<2)|0;d=c[9104156+((a>>>9&7)<<2)>>2]&63;a=c[b>>2]|0;e=a<<d;if((d|0)==0){c[2276078]=0;c[2276075]=a>>>24;c[2276076]=a;c[2276077]=0;return}c[2276108]=(c[2276108]|0)-(d<<c[2276096]);if(d>>>0<32){c[b>>2]=e;f=a>>>((32-d|0)>>>0)<<8;c[2276078]=f;c[2276074]=f;c[2276075]=e>>>24;c[2276076]=e;e=c[10760+(d+1<<2)>>2]|0;f=e&a;if((f|0)==0){g=0}else{g=((f|0)!=(e|0))<<7}c[2276077]=g;return}else{c[b>>2]=0;if((d|0)==32){h=a<<8&256}else{h=0}c[2276078]=h;c[2276074]=h;c[2276075]=0;c[2276076]=0;c[2276077]=((a|0)!=0)<<7;return}}function AN(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276085]|0;f=e&b;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=f&1023;k=(d[i+(j+1)|0]|0)<<8|(d[i+j|0]|0);l=e;m=h}else{e=gj[c[h+196688+(i<<2)>>2]&4095](g)|0;k=e;l=c[2276085]|0;m=c[2112932]|0}e=k&65535;g=e<<1;i=g&65534;h=l&b;b=h&16777215;l=c[m+((b>>>10|16384)<<2)>>2]|0;if(l>>>0>9){j=h&1023;a[l+j|0]=g&255;a[l+(j+1)|0]=(k&65535)>>>7&255}else{gg[c[m+196728+(l<<2)>>2]&4095](b,g&65535)}c[2276075]=i>>>8;c[2276076]=i;i=e>>>7;c[2276078]=i;c[2276074]=i;i=e&49152;if((i|0)==0){n=0;c[2276077]=n;return}n=((i|0)!=49152)<<7;c[2276077]=n;return}function AO(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=c[b>>2]|0;c[b>>2]=e+2;b=c[2276085]|0;f=b&e;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=f&1023;k=(d[i+(j+1)|0]|0)<<8|(d[i+j|0]|0);l=b;m=h}else{b=gj[c[h+196688+(i<<2)>>2]&4095](g)|0;k=b;l=c[2276085]|0;m=c[2112932]|0}b=k&65535;g=b<<1;i=g&65534;h=l&e;e=h&16777215;l=c[m+((e>>>10|16384)<<2)>>2]|0;if(l>>>0>9){j=h&1023;a[l+j|0]=g&255;a[l+(j+1)|0]=(k&65535)>>>7&255}else{gg[c[m+196728+(l<<2)>>2]&4095](e,g&65535)}c[2276075]=i>>>8;c[2276076]=i;i=b>>>7;c[2276078]=i;c[2276074]=i;i=b&49152;if((i|0)==0){n=0;c[2276077]=n;return}n=((i|0)!=49152)<<7;c[2276077]=n;return}function AP(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=9104156+((c[2276069]&7|8)<<2)|0;e=(c[b>>2]|0)-2|0;c[b>>2]=e;b=c[2276085]|0;f=b&e;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=f&1023;k=(d[i+(j+1)|0]|0)<<8|(d[i+j|0]|0);l=b;m=h}else{b=gj[c[h+196688+(i<<2)>>2]&4095](g)|0;k=b;l=c[2276085]|0;m=c[2112932]|0}b=k&65535;g=b<<1;i=g&65534;h=l&e;e=h&16777215;l=c[m+((e>>>10|16384)<<2)>>2]|0;if(l>>>0>9){j=h&1023;a[l+j|0]=g&255;a[l+(j+1)|0]=(k&65535)>>>7&255}else{gg[c[m+196728+(l<<2)>>2]&4095](e,g&65535)}c[2276075]=i>>>8;c[2276076]=i;i=b>>>7;c[2276078]=i;c[2276074]=i;i=b&49152;if((i|0)==0){n=0;c[2276077]=n;return}n=((i|0)!=49152)<<7;c[2276077]=n;return}function AQ(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=(h>>>((g<<3&16^16)>>>0)<<16>>16)+b|0;b=c[2276085]|0;g=m&b;h=g&16777215;n=c[2112932]|0;e=c[n+(h>>>10<<2)>>2]|0;if(e>>>0>9){f=g&1023;o=(d[e+(f+1)|0]|0)<<8|(d[e+f|0]|0);p=b;q=n}else{b=gj[c[n+196688+(e<<2)>>2]&4095](h)|0;o=b;p=c[2276085]|0;q=c[2112932]|0}b=o&65535;h=b<<1;e=h&65534;n=p&m;m=n&16777215;p=c[q+((m>>>10|16384)<<2)>>2]|0;if(p>>>0>9){f=n&1023;a[p+f|0]=h&255;a[p+(f+1)|0]=(o&65535)>>>7&255}else{gg[c[q+196728+(p<<2)>>2]&4095](m,h&65535)}c[2276075]=e>>>8;c[2276076]=e;e=b>>>7;c[2276078]=e;c[2276074]=e;e=b&49152;if((e|0)==0){r=0;c[2276077]=r;return}r=((e|0)!=49152)<<7;c[2276077]=r;return}function AR(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=xw(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;e=c[2276085]|0;f=e&b;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=f&1023;k=(d[i+(j+1)|0]|0)<<8|(d[i+j|0]|0);l=e;m=h}else{e=gj[c[h+196688+(i<<2)>>2]&4095](g)|0;k=e;l=c[2276085]|0;m=c[2112932]|0}e=k&65535;g=e<<1;i=g&65534;h=l&b;b=h&16777215;l=c[m+((b>>>10|16384)<<2)>>2]|0;if(l>>>0>9){j=h&1023;a[l+j|0]=g&255;a[l+(j+1)|0]=(k&65535)>>>7&255}else{gg[c[m+196728+(l<<2)>>2]&4095](b,g&65535)}c[2276075]=i>>>8;c[2276076]=i;i=e>>>7;c[2276078]=i;c[2276074]=i;i=e&49152;if((i|0)==0){n=0;c[2276077]=n;return}n=((i|0)!=49152)<<7;c[2276077]=n;return}function AS(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)<<16>>16;f=c[2276085]|0;g=l&f;m=g&16777215;b=c[2112932]|0;e=c[b+(m>>>10<<2)>>2]|0;if(e>>>0>9){j=g&1023;n=(d[e+(j+1)|0]|0)<<8|(d[e+j|0]|0);o=f;p=b}else{f=gj[c[b+196688+(e<<2)>>2]&4095](m)|0;n=f;o=c[2276085]|0;p=c[2112932]|0}f=n&65535;m=f<<1;e=m&65534;b=o&l;l=b&16777215;o=c[p+((l>>>10|16384)<<2)>>2]|0;if(o>>>0>9){j=b&1023;a[o+j|0]=m&255;a[o+(j+1)|0]=(n&65535)>>>7&255}else{gg[c[p+196728+(o<<2)>>2]&4095](l,m&65535)}c[2276075]=e>>>8;c[2276076]=e;e=f>>>7;c[2276078]=e;c[2276074]=e;e=f&49152;if((e|0)==0){q=0;c[2276077]=q;return}q=((e|0)!=49152)<<7;c[2276077]=q;return}function AT(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[2276085]|0;t=r&q;h=t&16777215;s=c[2112932]|0;n=c[s+(h>>>10<<2)>>2]|0;if(n>>>0>9){f=t&1023;u=(d[n+(f+1)|0]|0)<<8|(d[n+f|0]|0);v=r;w=s}else{r=gj[c[s+196688+(n<<2)>>2]&4095](h)|0;u=r;v=c[2276085]|0;w=c[2112932]|0}r=u&65535;h=r<<1;n=h&65534;s=v&q;q=s&16777215;v=c[w+((q>>>10|16384)<<2)>>2]|0;if(v>>>0>9){f=s&1023;a[v+f|0]=h&255;a[v+(f+1)|0]=(u&65535)>>>7&255}else{gg[c[w+196728+(v<<2)>>2]&4095](q,h&65535)}c[2276075]=n>>>8;c[2276076]=n;n=r>>>7;c[2276078]=n;c[2276074]=n;n=r&49152;if((n|0)==0){x=0;c[2276077]=x;return}x=((n|0)!=49152)<<7;c[2276077]=x;return}function AU(){if((c[2276078]&256|0)==0&(c[2276076]|0)!=0){c[2276056]=(c[2276069]<<24>>24)+(c[2276056]|0);return}else{c[2276108]=(c[2276108]|0)-(c[2276089]|0);return}}function AV(){if((c[2276078]&256|0)==0&(c[2276076]|0)!=0){c[2276108]=(c[2276108]|0)-(c[2276089]|0);return}else{c[2276056]=(c[2276069]<<24>>24)+(c[2276056]|0);return}}function AW(){if((c[2276078]&256|0)==0){c[2276056]=(c[2276069]<<24>>24)+(c[2276056]|0);return}else{c[2276108]=(c[2276108]|0)-(c[2276089]|0);return}}function AX(){if((c[2276078]&256|0)==0){c[2276108]=(c[2276108]|0)-(c[2276089]|0);return}else{c[2276056]=(c[2276069]<<24>>24)+(c[2276056]|0);return}}function AY(){if((c[2276076]|0)==0){c[2276108]=(c[2276108]|0)-(c[2276089]|0);return}else{c[2276056]=(c[2276069]<<24>>24)+(c[2276056]|0);return}}function AZ(){if((c[2276076]|0)==0){c[2276056]=(c[2276069]<<24>>24)+(c[2276056]|0);return}else{c[2276108]=(c[2276108]|0)-(c[2276089]|0);return}}function A_(){if((c[2276077]&128|0)==0){c[2276056]=(c[2276069]<<24>>24)+(c[2276056]|0);return}else{c[2276108]=(c[2276108]|0)-(c[2276089]|0);return}}function A$(){if((c[2276077]&128|0)==0){c[2276108]=(c[2276108]|0)-(c[2276089]|0);return}else{c[2276056]=(c[2276069]<<24>>24)+(c[2276056]|0);return}}function A0(){if((c[2276075]&128|0)==0){c[2276056]=(c[2276069]<<24>>24)+(c[2276056]|0);return}else{c[2276108]=(c[2276108]|0)-(c[2276089]|0);return}}function A1(){if((c[2276075]&128|0)==0){c[2276108]=(c[2276108]|0)-(c[2276089]|0);return}else{c[2276056]=(c[2276069]<<24>>24)+(c[2276056]|0);return}}function A2(){if(((c[2276077]^c[2276075])&128|0)==0){c[2276056]=(c[2276069]<<24>>24)+(c[2276056]|0);return}else{c[2276108]=(c[2276108]|0)-(c[2276089]|0);return}}function A3(){if(((c[2276077]^c[2276075])&128|0)==0){c[2276108]=(c[2276108]|0)-(c[2276089]|0);return}else{c[2276056]=(c[2276069]<<24>>24)+(c[2276056]|0);return}}function A4(){if(((c[2276077]^c[2276075])&128|0)==0&(c[2276076]|0)!=0){c[2276056]=(c[2276069]<<24>>24)+(c[2276056]|0);return}else{c[2276108]=(c[2276108]|0)-(c[2276089]|0);return}}function A5(){if(((c[2276077]^c[2276075])&128|0)==0&(c[2276076]|0)!=0){c[2276108]=(c[2276108]|0)-(c[2276089]|0);return}else{c[2276056]=(c[2276069]<<24>>24)+(c[2276056]|0);return}}function A6(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[2276056]|0;if(!((c[2276078]&256|0)==0&(c[2276076]|0)!=0)){c[2276056]=a+2;c[2276108]=(c[2276108]|0)-(c[2276090]|0);return}b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=(f>>>((e<<3&16^16)>>>0)<<16>>16)+e;return}function A7(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[2276056]|0;if((c[2276078]&256|0)==0&(c[2276076]|0)!=0){c[2276056]=a+2;c[2276108]=(c[2276108]|0)-(c[2276090]|0);return}b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=(f>>>((e<<3&16^16)>>>0)<<16>>16)+e;return}function A8(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[2276056]|0;if((c[2276078]&256|0)!=0){c[2276056]=a+2;c[2276108]=(c[2276108]|0)-(c[2276090]|0);return}b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=(f>>>((e<<3&16^16)>>>0)<<16>>16)+e;return}function A9(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[2276056]|0;if((c[2276078]&256|0)==0){c[2276056]=a+2;c[2276108]=(c[2276108]|0)-(c[2276090]|0);return}b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=(f>>>((e<<3&16^16)>>>0)<<16>>16)+e;return}function Ba(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[2276056]|0;if((c[2276076]|0)==0){c[2276056]=a+2;c[2276108]=(c[2276108]|0)-(c[2276090]|0);return}b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=(f>>>((e<<3&16^16)>>>0)<<16>>16)+e;return}function Bb(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[2276056]|0;if((c[2276076]|0)!=0){c[2276056]=a+2;c[2276108]=(c[2276108]|0)-(c[2276090]|0);return}b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=(f>>>((e<<3&16^16)>>>0)<<16>>16)+e;return}function Bc(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[2276056]|0;if((c[2276077]&128|0)!=0){c[2276056]=a+2;c[2276108]=(c[2276108]|0)-(c[2276090]|0);return}b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=(f>>>((e<<3&16^16)>>>0)<<16>>16)+e;return}function Bd(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[2276056]|0;if((c[2276077]&128|0)==0){c[2276056]=a+2;c[2276108]=(c[2276108]|0)-(c[2276090]|0);return}b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=(f>>>((e<<3&16^16)>>>0)<<16>>16)+e;return}function Be(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[2276056]|0;if((c[2276075]&128|0)!=0){c[2276056]=a+2;c[2276108]=(c[2276108]|0)-(c[2276090]|0);return}b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=(f>>>((e<<3&16^16)>>>0)<<16>>16)+e;return}function Bf(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[2276056]|0;if((c[2276075]&128|0)==0){c[2276056]=a+2;c[2276108]=(c[2276108]|0)-(c[2276090]|0);return}b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=(f>>>((e<<3&16^16)>>>0)<<16>>16)+e;return}function Bg(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[2276056]|0;if(((c[2276077]^c[2276075])&128|0)!=0){c[2276056]=a+2;c[2276108]=(c[2276108]|0)-(c[2276090]|0);return}b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=(f>>>((e<<3&16^16)>>>0)<<16>>16)+e;return}function Bh(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[2276056]|0;if(((c[2276077]^c[2276075])&128|0)==0){c[2276056]=a+2;c[2276108]=(c[2276108]|0)-(c[2276090]|0);return}b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=(f>>>((e<<3&16^16)>>>0)<<16>>16)+e;return}function Bi(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[2276056]|0;if(!(((c[2276077]^c[2276075])&128|0)==0&(c[2276076]|0)!=0)){c[2276056]=a+2;c[2276108]=(c[2276108]|0)-(c[2276090]|0);return}b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=(f>>>((e<<3&16^16)>>>0)<<16>>16)+e;return}function Bj(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a=c[2276056]|0;if(((c[2276077]^c[2276075])&128|0)==0&(c[2276076]|0)!=0){c[2276056]=a+2;c[2276108]=(c[2276108]|0)-(c[2276090]|0);return}b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=(f>>>((e<<3&16^16)>>>0)<<16>>16)+e;return}function Bk(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;if((c[2276038]&24|0)==0){Bl();return}a=c[2276056]|0;if(!((c[2276078]&256|0)==0&(c[2276076]|0)!=0)){c[2276056]=a+4;return}b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=b;g=c[2276084]|0}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=o;g=m}m=e+2|0;c[2276056]=m;e=m&-4;if((e|0)==(f|0)){p=g;q=m}else{c[2276083]=e;f=c[2276085]&e;e=f&16777212;o=c[2112932]|0;n=c[o+((e>>>10|32768)<<2)>>2]|0;if(n>>>0>9){b=f&1020;r=(d[n+(b|3)|0]|0)<<8|(d[n+(b|2)|0]|0)|((d[n+(b|1)|0]|0)<<8|(d[n+b|0]|0))<<16;s=m}else{m=gj[c[o+196768+(n<<2)>>2]&4095](e)|0;r=m;s=c[2276056]|0}c[2276084]=r;p=r>>>16|g<<16;q=s}c[2276056]=q-2+p;return}function Bl(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;b=c[2276072]|0;e=c[2276073]|0;f=c[2276071]|c[2276070]|b<<11|e<<11|c[2276079]|(c[2276074]|0)>>>4&16|(c[2276075]|0)>>>4&8|((c[2276076]|0)==0)<<2|(c[2276077]|0)>>>6&2|(c[2276078]|0)>>>8&1;c[2276071]=0;c[2276070]=0;c[9104228+((b>>>1&e|b)<<2)>>2]=c[2276054];c[2276072]=4;b=c[9104228+((c[2276073]&2|4)<<2)>>2]|0;c[2276054]=b;e=c[2276055]|0;do{if(((c[2276038]|0)-1|0)>>>0<2){g=b-4|0;c[2276054]=g;h=c[2276085]&g;g=h&16777215;i=c[2112932]|0;j=c[i+((g>>>10|16384)<<2)>>2]|0;if(j>>>0>9){k=h&1023;a[j+k|0]=e>>>16&255;a[j+(k+1)|0]=e>>>24&255;a[j+(k+2)|0]=e&255;a[j+(k+3)|0]=e>>>8&255;l=i}else{gg[c[i+196808+(j<<2)>>2]&4095](g,e);l=c[2112932]|0}g=(c[2276054]|0)-2|0;c[2276054]=g;j=c[2276085]&g;g=f&65535;i=j&16777215;k=c[l+((i>>>10|16384)<<2)>>2]|0;if(k>>>0>9){h=j&1023;a[k+h|0]=f&255;a[k+(h+1)|0]=(g&65535)>>>8&255;break}else{gg[c[l+196728+(k<<2)>>2]&4095](i,g);break}}else{g=b-2|0;c[2276054]=g;i=c[2276085]&g;g=i&16777215;k=c[2112932]|0;h=c[k+((g>>>10|16384)<<2)>>2]|0;if(h>>>0>9){j=i&1023;a[h+j|0]=16;a[h+(j+1)|0]=0;m=k}else{gg[c[k+196728+(h<<2)>>2]&4095](g,16);m=c[2112932]|0}g=(c[2276054]|0)-4|0;c[2276054]=g;h=c[2276085]&g;g=h&16777215;k=c[m+((g>>>10|16384)<<2)>>2]|0;if(k>>>0>9){j=h&1023;a[k+j|0]=e>>>16&255;a[k+(j+1)|0]=e>>>24&255;a[k+(j+2)|0]=e&255;a[k+(j+3)|0]=e>>>8&255;n=m}else{gg[c[m+196808+(k<<2)>>2]&4095](g,e);n=c[2112932]|0}g=(c[2276054]|0)-2|0;c[2276054]=g;k=c[2276085]&g;g=f&65535;j=k&16777215;h=c[n+((j>>>10|16384)<<2)>>2]|0;if(h>>>0>9){i=k&1023;a[h+i|0]=f&255;a[h+(i+1)|0]=(g&65535)>>>8&255;break}else{gg[c[n+196728+(h<<2)>>2]&4095](j,g);break}}}while(0);n=(c[2276064]|0)+16|0;c[2276056]=n;f=c[2276085]&n;n=f&16777215;e=c[2112932]|0;m=c[e+(n>>>10<<2)>>2]|0;if(m>>>0>9){b=f&1023;o=(d[m+(b+3)|0]|0)<<8|(d[m+(b+2)|0]|0)|((d[m+(b+1)|0]|0)<<8|(d[m+b|0]|0))<<16;c[2276056]=o;p=c[2276099]|0;q=p+4|0;r=a[q]|0;s=r&255;t=c[2276069]|0;u=c[2276098]|0;v=u+t|0;w=a[v]|0;x=w&255;y=c[2276108]|0;z=x-s|0;A=z+y|0;c[2276108]=A;return}else{o=gj[c[e+196768+(m<<2)>>2]&4095](n)|0;c[2276056]=o;p=c[2276099]|0;q=p+4|0;r=a[q]|0;s=r&255;t=c[2276069]|0;u=c[2276098]|0;v=u+t|0;w=a[v]|0;x=w&255;y=c[2276108]|0;z=x-s|0;A=z+y|0;c[2276108]=A;return}}function Bm(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;if((c[2276038]&24|0)==0){Bl();return}a=c[2276056]|0;if((c[2276078]&256|0)==0&(c[2276076]|0)!=0){c[2276056]=a+4;return}b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=b;g=c[2276084]|0}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=o;g=m}m=e+2|0;c[2276056]=m;e=m&-4;if((e|0)==(f|0)){p=g;q=m}else{c[2276083]=e;f=c[2276085]&e;e=f&16777212;o=c[2112932]|0;n=c[o+((e>>>10|32768)<<2)>>2]|0;if(n>>>0>9){b=f&1020;r=(d[n+(b|3)|0]|0)<<8|(d[n+(b|2)|0]|0)|((d[n+(b|1)|0]|0)<<8|(d[n+b|0]|0))<<16;s=m}else{m=gj[c[o+196768+(n<<2)>>2]&4095](e)|0;r=m;s=c[2276056]|0}c[2276084]=r;p=r>>>16|g<<16;q=s}c[2276056]=q-2+p;return}function Bn(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;if((c[2276038]&24|0)==0){Bl();return}a=c[2276056]|0;if((c[2276078]&256|0)!=0){c[2276056]=a+4;return}b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=b;g=c[2276084]|0}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=o;g=m}m=e+2|0;c[2276056]=m;e=m&-4;if((e|0)==(f|0)){p=g;q=m}else{c[2276083]=e;f=c[2276085]&e;e=f&16777212;o=c[2112932]|0;n=c[o+((e>>>10|32768)<<2)>>2]|0;if(n>>>0>9){b=f&1020;r=(d[n+(b|3)|0]|0)<<8|(d[n+(b|2)|0]|0)|((d[n+(b|1)|0]|0)<<8|(d[n+b|0]|0))<<16;s=m}else{m=gj[c[o+196768+(n<<2)>>2]&4095](e)|0;r=m;s=c[2276056]|0}c[2276084]=r;p=r>>>16|g<<16;q=s}c[2276056]=q-2+p;return}function Bo(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;if((c[2276038]&24|0)==0){Bl();return}a=c[2276056]|0;if((c[2276078]&256|0)==0){c[2276056]=a+4;return}b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=b;g=c[2276084]|0}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=o;g=m}m=e+2|0;c[2276056]=m;e=m&-4;if((e|0)==(f|0)){p=g;q=m}else{c[2276083]=e;f=c[2276085]&e;e=f&16777212;o=c[2112932]|0;n=c[o+((e>>>10|32768)<<2)>>2]|0;if(n>>>0>9){b=f&1020;r=(d[n+(b|3)|0]|0)<<8|(d[n+(b|2)|0]|0)|((d[n+(b|1)|0]|0)<<8|(d[n+b|0]|0))<<16;s=m}else{m=gj[c[o+196768+(n<<2)>>2]&4095](e)|0;r=m;s=c[2276056]|0}c[2276084]=r;p=r>>>16|g<<16;q=s}c[2276056]=q-2+p;return}function Bp(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;if((c[2276038]&24|0)==0){Bl();return}a=c[2276056]|0;if((c[2276076]|0)==0){c[2276056]=a+4;return}b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=b;g=c[2276084]|0}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=o;g=m}m=e+2|0;c[2276056]=m;e=m&-4;if((e|0)==(f|0)){p=g;q=m}else{c[2276083]=e;f=c[2276085]&e;e=f&16777212;o=c[2112932]|0;n=c[o+((e>>>10|32768)<<2)>>2]|0;if(n>>>0>9){b=f&1020;r=(d[n+(b|3)|0]|0)<<8|(d[n+(b|2)|0]|0)|((d[n+(b|1)|0]|0)<<8|(d[n+b|0]|0))<<16;s=m}else{m=gj[c[o+196768+(n<<2)>>2]&4095](e)|0;r=m;s=c[2276056]|0}c[2276084]=r;p=r>>>16|g<<16;q=s}c[2276056]=q-2+p;return}function Bq(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;if((c[2276038]&24|0)==0){Bl();return}a=c[2276056]|0;if((c[2276076]|0)!=0){c[2276056]=a+4;return}b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=b;g=c[2276084]|0}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=o;g=m}m=e+2|0;c[2276056]=m;e=m&-4;if((e|0)==(f|0)){p=g;q=m}else{c[2276083]=e;f=c[2276085]&e;e=f&16777212;o=c[2112932]|0;n=c[o+((e>>>10|32768)<<2)>>2]|0;if(n>>>0>9){b=f&1020;r=(d[n+(b|3)|0]|0)<<8|(d[n+(b|2)|0]|0)|((d[n+(b|1)|0]|0)<<8|(d[n+b|0]|0))<<16;s=m}else{m=gj[c[o+196768+(n<<2)>>2]&4095](e)|0;r=m;s=c[2276056]|0}c[2276084]=r;p=r>>>16|g<<16;q=s}c[2276056]=q-2+p;return}function Br(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;if((c[2276038]&24|0)==0){Bl();return}a=c[2276056]|0;if((c[2276077]&128|0)!=0){c[2276056]=a+4;return}b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=b;g=c[2276084]|0}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=o;g=m}m=e+2|0;c[2276056]=m;e=m&-4;if((e|0)==(f|0)){p=g;q=m}else{c[2276083]=e;f=c[2276085]&e;e=f&16777212;o=c[2112932]|0;n=c[o+((e>>>10|32768)<<2)>>2]|0;if(n>>>0>9){b=f&1020;r=(d[n+(b|3)|0]|0)<<8|(d[n+(b|2)|0]|0)|((d[n+(b|1)|0]|0)<<8|(d[n+b|0]|0))<<16;s=m}else{m=gj[c[o+196768+(n<<2)>>2]&4095](e)|0;r=m;s=c[2276056]|0}c[2276084]=r;p=r>>>16|g<<16;q=s}c[2276056]=q-2+p;return}function Bs(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;if((c[2276038]&24|0)==0){Bl();return}a=c[2276056]|0;if((c[2276077]&128|0)==0){c[2276056]=a+4;return}b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=b;g=c[2276084]|0}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=o;g=m}m=e+2|0;c[2276056]=m;e=m&-4;if((e|0)==(f|0)){p=g;q=m}else{c[2276083]=e;f=c[2276085]&e;e=f&16777212;o=c[2112932]|0;n=c[o+((e>>>10|32768)<<2)>>2]|0;if(n>>>0>9){b=f&1020;r=(d[n+(b|3)|0]|0)<<8|(d[n+(b|2)|0]|0)|((d[n+(b|1)|0]|0)<<8|(d[n+b|0]|0))<<16;s=m}else{m=gj[c[o+196768+(n<<2)>>2]&4095](e)|0;r=m;s=c[2276056]|0}c[2276084]=r;p=r>>>16|g<<16;q=s}c[2276056]=q-2+p;return}function Bt(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;if((c[2276038]&24|0)==0){Bl();return}a=c[2276056]|0;if((c[2276075]&128|0)!=0){c[2276056]=a+4;return}b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=b;g=c[2276084]|0}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=o;g=m}m=e+2|0;c[2276056]=m;e=m&-4;if((e|0)==(f|0)){p=g;q=m}else{c[2276083]=e;f=c[2276085]&e;e=f&16777212;o=c[2112932]|0;n=c[o+((e>>>10|32768)<<2)>>2]|0;if(n>>>0>9){b=f&1020;r=(d[n+(b|3)|0]|0)<<8|(d[n+(b|2)|0]|0)|((d[n+(b|1)|0]|0)<<8|(d[n+b|0]|0))<<16;s=m}else{m=gj[c[o+196768+(n<<2)>>2]&4095](e)|0;r=m;s=c[2276056]|0}c[2276084]=r;p=r>>>16|g<<16;q=s}c[2276056]=q-2+p;return}function Bu(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;if((c[2276038]&24|0)==0){Bl();return}a=c[2276056]|0;if((c[2276075]&128|0)==0){c[2276056]=a+4;return}b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=b;g=c[2276084]|0}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=o;g=m}m=e+2|0;c[2276056]=m;e=m&-4;if((e|0)==(f|0)){p=g;q=m}else{c[2276083]=e;f=c[2276085]&e;e=f&16777212;o=c[2112932]|0;n=c[o+((e>>>10|32768)<<2)>>2]|0;if(n>>>0>9){b=f&1020;r=(d[n+(b|3)|0]|0)<<8|(d[n+(b|2)|0]|0)|((d[n+(b|1)|0]|0)<<8|(d[n+b|0]|0))<<16;s=m}else{m=gj[c[o+196768+(n<<2)>>2]&4095](e)|0;r=m;s=c[2276056]|0}c[2276084]=r;p=r>>>16|g<<16;q=s}c[2276056]=q-2+p;return}function Bv(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;if((c[2276038]&24|0)==0){Bl();return}a=c[2276056]|0;if(((c[2276077]^c[2276075])&128|0)!=0){c[2276056]=a+4;return}b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=b;g=c[2276084]|0}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=o;g=m}m=e+2|0;c[2276056]=m;e=m&-4;if((e|0)==(f|0)){p=g;q=m}else{c[2276083]=e;f=c[2276085]&e;e=f&16777212;o=c[2112932]|0;n=c[o+((e>>>10|32768)<<2)>>2]|0;if(n>>>0>9){b=f&1020;r=(d[n+(b|3)|0]|0)<<8|(d[n+(b|2)|0]|0)|((d[n+(b|1)|0]|0)<<8|(d[n+b|0]|0))<<16;s=m}else{m=gj[c[o+196768+(n<<2)>>2]&4095](e)|0;r=m;s=c[2276056]|0}c[2276084]=r;p=r>>>16|g<<16;q=s}c[2276056]=q-2+p;return}function Bw(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;if((c[2276038]&24|0)==0){Bl();return}a=c[2276056]|0;if(((c[2276077]^c[2276075])&128|0)==0){c[2276056]=a+4;return}b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=b;g=c[2276084]|0}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=o;g=m}m=e+2|0;c[2276056]=m;e=m&-4;if((e|0)==(f|0)){p=g;q=m}else{c[2276083]=e;f=c[2276085]&e;e=f&16777212;o=c[2112932]|0;n=c[o+((e>>>10|32768)<<2)>>2]|0;if(n>>>0>9){b=f&1020;r=(d[n+(b|3)|0]|0)<<8|(d[n+(b|2)|0]|0)|((d[n+(b|1)|0]|0)<<8|(d[n+b|0]|0))<<16;s=m}else{m=gj[c[o+196768+(n<<2)>>2]&4095](e)|0;r=m;s=c[2276056]|0}c[2276084]=r;p=r>>>16|g<<16;q=s}c[2276056]=q-2+p;return}function Bx(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;if((c[2276038]&24|0)==0){Bl();return}a=c[2276056]|0;if(!(((c[2276077]^c[2276075])&128|0)==0&(c[2276076]|0)!=0)){c[2276056]=a+4;return}b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=b;g=c[2276084]|0}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=o;g=m}m=e+2|0;c[2276056]=m;e=m&-4;if((e|0)==(f|0)){p=g;q=m}else{c[2276083]=e;f=c[2276085]&e;e=f&16777212;o=c[2112932]|0;n=c[o+((e>>>10|32768)<<2)>>2]|0;if(n>>>0>9){b=f&1020;r=(d[n+(b|3)|0]|0)<<8|(d[n+(b|2)|0]|0)|((d[n+(b|1)|0]|0)<<8|(d[n+b|0]|0))<<16;s=m}else{m=gj[c[o+196768+(n<<2)>>2]&4095](e)|0;r=m;s=c[2276056]|0}c[2276084]=r;p=r>>>16|g<<16;q=s}c[2276056]=q-2+p;return}function By(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;if((c[2276038]&24|0)==0){Bl();return}a=c[2276056]|0;if(((c[2276077]^c[2276075])&128|0)==0&(c[2276076]|0)!=0){c[2276056]=a+4;return}b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=b;g=c[2276084]|0}else{c[2276083]=b;h=c[2276085]&b;i=h&16777212;j=c[2112932]|0;k=c[j+((i>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=h&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=a;o=b}else{b=gj[c[j+196768+(k<<2)>>2]&4095](i)|0;m=b;n=c[2276056]|0;o=c[2276083]|0}c[2276084]=m;e=n;f=o;g=m}m=e+2|0;c[2276056]=m;e=m&-4;if((e|0)==(f|0)){p=g;q=m}else{c[2276083]=e;f=c[2276085]&e;e=f&16777212;o=c[2112932]|0;n=c[o+((e>>>10|32768)<<2)>>2]|0;if(n>>>0>9){b=f&1020;r=(d[n+(b|3)|0]|0)<<8|(d[n+(b|2)|0]|0)|((d[n+(b|1)|0]|0)<<8|(d[n+b|0]|0))<<16;s=m}else{m=gj[c[o+196768+(n<<2)>>2]&4095](e)|0;r=m;s=c[2276056]|0}c[2276084]=r;p=r>>>16|g<<16;q=s}c[2276056]=q-2+p;return}function Bz(){var a=0,b=0,d=0;a=c[2276069]|0;b=9104156+((a&7)<<2)|0;d=1<<(c[9104156+((a>>>9&7)<<2)>>2]&31);c[2276076]=d&c[b>>2];c[b>>2]=c[b>>2]^d;return}function BA(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=c[2276069]|0;d=c[9104156+((b&7|8)<<2)>>2]|0;e=c[2276085]|0;f=e&d;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=a[i+(f&1023^1)|0]|0;k=b;l=e;m=h}else{e=gj[c[h+196608+(i<<2)>>2]&4095](g)|0;j=e;k=c[2276069]|0;l=c[2276085]|0;m=c[2112932]|0}e=j&255;j=1<<(c[9104156+((k>>>9&7)<<2)>>2]&7);c[2276076]=j&e;k=l&d;d=(j^e)&255;e=k&16777215;j=c[m+((e>>>10|16384)<<2)>>2]|0;if(j>>>0>9){a[j+(k&1023^1)|0]=d;return}else{gg[c[m+196648+(j<<2)>>2]&4095](e,d);return}}function BB(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;b=c[2276085]|0;e=b&d;f=e&16777215;g=c[2112932]|0;h=c[g+(f>>>10<<2)>>2]|0;if(h>>>0>9){i=a[h+(e&1023^1)|0]|0;j=b;k=g}else{b=gj[c[g+196608+(h<<2)>>2]&4095](f)|0;i=b;j=c[2276085]|0;k=c[2112932]|0}b=i&255;i=1<<(c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]&7);c[2276076]=i&b;f=j&d;d=(i^b)&255;b=f&16777215;i=c[k+((b>>>10|16384)<<2)>>2]|0;if(i>>>0>9){a[i+(f&1023^1)|0]=d;return}else{gg[c[k+196648+(i<<2)>>2]&4095](b,d);return}}function BC(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[2276054]|0;c[2276054]=b+2;d=c[2276085]|0;e=d&b;f=e&16777215;g=c[2112932]|0;h=c[g+(f>>>10<<2)>>2]|0;if(h>>>0>9){i=a[h+(e&1023^1)|0]|0;j=d;k=g}else{d=gj[c[g+196608+(h<<2)>>2]&4095](f)|0;i=d;j=c[2276085]|0;k=c[2112932]|0}d=i&255;i=1<<(c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]&7);c[2276076]=i&d;f=j&b;b=(i^d)&255;d=f&16777215;i=c[k+((d>>>10|16384)<<2)>>2]|0;if(i>>>0>9){a[i+(f&1023^1)|0]=b;return}else{gg[c[k+196648+(i<<2)>>2]&4095](d,b);return}}function BD(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;b=c[2276085]|0;e=b&d;f=e&16777215;g=c[2112932]|0;h=c[g+(f>>>10<<2)>>2]|0;if(h>>>0>9){i=a[h+(e&1023^1)|0]|0;j=b;k=g}else{b=gj[c[g+196608+(h<<2)>>2]&4095](f)|0;i=b;j=c[2276085]|0;k=c[2112932]|0}b=i&255;i=1<<(c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]&7);c[2276076]=i&b;f=j&d;d=(i^b)&255;b=f&16777215;i=c[k+((b>>>10|16384)<<2)>>2]|0;if(i>>>0>9){a[i+(f&1023^1)|0]=d;return}else{gg[c[k+196648+(i<<2)>>2]&4095](b,d);return}}function BE(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=(c[2276054]|0)-2|0;c[2276054]=b;d=c[2276085]|0;e=d&b;f=e&16777215;g=c[2112932]|0;h=c[g+(f>>>10<<2)>>2]|0;if(h>>>0>9){i=a[h+(e&1023^1)|0]|0;j=d;k=g}else{d=gj[c[g+196608+(h<<2)>>2]&4095](f)|0;i=d;j=c[2276085]|0;k=c[2112932]|0}d=i&255;i=1<<(c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]&7);c[2276076]=i&d;f=j&b;b=(i^d)&255;d=f&16777215;i=c[k+((d>>>10|16384)<<2)>>2]|0;if(i>>>0>9){a[i+(f&1023^1)|0]=b;return}else{gg[c[k+196648+(i<<2)>>2]&4095](d,b);return}}function BF(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=(h>>>((g<<3&16^16)>>>0)<<16>>16)+b|0;b=c[2276085]|0;g=m&b;h=g&16777215;n=c[2112932]|0;e=c[n+(h>>>10<<2)>>2]|0;if(e>>>0>9){o=a[e+(g&1023^1)|0]|0;p=b;q=n}else{b=gj[c[n+196608+(e<<2)>>2]&4095](h)|0;o=b;p=c[2276085]|0;q=c[2112932]|0}b=o&255;o=1<<(c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]&7);c[2276076]=o&b;h=p&m;m=(o^b)&255;b=h&16777215;o=c[q+((b>>>10|16384)<<2)>>2]|0;if(o>>>0>9){a[o+(h&1023^1)|0]=m;return}else{gg[c[q+196648+(o<<2)>>2]&4095](b,m);return}}function BG(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=xw(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;d=c[2276085]|0;e=d&b;f=e&16777215;g=c[2112932]|0;h=c[g+(f>>>10<<2)>>2]|0;if(h>>>0>9){i=a[h+(e&1023^1)|0]|0;j=d;k=g}else{d=gj[c[g+196608+(h<<2)>>2]&4095](f)|0;i=d;j=c[2276085]|0;k=c[2112932]|0}d=i&255;i=1<<(c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]&7);c[2276076]=i&d;f=j&b;b=(i^d)&255;d=f&16777215;i=c[k+((d>>>10|16384)<<2)>>2]|0;if(i>>>0>9){a[i+(f&1023^1)|0]=b;return}else{gg[c[k+196648+(i<<2)>>2]&4095](d,b);return}}function BH(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)<<16>>16;f=c[2276085]|0;g=l&f;m=g&16777215;b=c[2112932]|0;e=c[b+(m>>>10<<2)>>2]|0;if(e>>>0>9){n=a[e+(g&1023^1)|0]|0;o=f;p=b}else{f=gj[c[b+196608+(e<<2)>>2]&4095](m)|0;n=f;o=c[2276085]|0;p=c[2112932]|0}f=n&255;n=1<<(c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]&7);c[2276076]=n&f;m=o&l;l=(n^f)&255;f=m&16777215;n=c[p+((f>>>10|16384)<<2)>>2]|0;if(n>>>0>9){a[n+(m&1023^1)|0]=l;return}else{gg[c[p+196648+(n<<2)>>2]&4095](f,l);return}}function BI(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[2276085]|0;t=r&q;h=t&16777215;s=c[2112932]|0;n=c[s+(h>>>10<<2)>>2]|0;if(n>>>0>9){u=a[n+(t&1023^1)|0]|0;v=r;w=s}else{r=gj[c[s+196608+(n<<2)>>2]&4095](h)|0;u=r;v=c[2276085]|0;w=c[2112932]|0}r=u&255;u=1<<(c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]&7);c[2276076]=u&r;h=v&q;q=(u^r)&255;r=h&16777215;u=c[w+((r>>>10|16384)<<2)>>2]|0;if(u>>>0>9){a[u+(h&1023^1)|0]=q;return}else{gg[c[w+196648+(u<<2)>>2]&4095](r,q);return}}function BJ(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=9104156+((c[2276069]&7)<<2)|0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=1<<(g>>>((f<<3&16^16)>>>0)&31);c[2276076]=l&c[a>>2];c[a>>2]=l^c[a>>2];return}function BK(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=1<<(g>>>((f<<3&16^16)>>>0)&7);f=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;g=c[2276085]|0;m=g&f;b=m&16777215;e=c[2112932]|0;j=c[e+(b>>>10<<2)>>2]|0;if(j>>>0>9){n=a[j+(m&1023^1)|0]|0;o=g;p=e}else{g=gj[c[e+196608+(j<<2)>>2]&4095](b)|0;n=g;o=c[2276085]|0;p=c[2112932]|0}g=n&255;c[2276076]=g&l;n=o&f;f=(g^l)&255;l=n&16777215;g=c[p+((l>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(n&1023^1)|0]=f;return}else{gg[c[p+196648+(g<<2)>>2]&4095](l,f);return}}function BL(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=1<<(g>>>((f<<3&16^16)>>>0)&7);f=9104156+((c[2276069]&7|8)<<2)|0;g=c[f>>2]|0;c[f>>2]=g+1;f=c[2276085]|0;m=f&g;b=m&16777215;e=c[2112932]|0;j=c[e+(b>>>10<<2)>>2]|0;if(j>>>0>9){n=a[j+(m&1023^1)|0]|0;o=f;p=e}else{f=gj[c[e+196608+(j<<2)>>2]&4095](b)|0;n=f;o=c[2276085]|0;p=c[2112932]|0}f=n&255;c[2276076]=f&l;n=o&g;g=(f^l)&255;l=n&16777215;f=c[p+((l>>>10|16384)<<2)>>2]|0;if(f>>>0>9){a[f+(n&1023^1)|0]=g;return}else{gg[c[p+196648+(f<<2)>>2]&4095](l,g);return}}function BM(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=1<<(g>>>((f<<3&16^16)>>>0)&7);f=c[2276054]|0;c[2276054]=f+2;g=c[2276085]|0;m=g&f;b=m&16777215;e=c[2112932]|0;j=c[e+(b>>>10<<2)>>2]|0;if(j>>>0>9){n=a[j+(m&1023^1)|0]|0;o=g;p=e}else{g=gj[c[e+196608+(j<<2)>>2]&4095](b)|0;n=g;o=c[2276085]|0;p=c[2112932]|0}g=n&255;c[2276076]=g&l;n=o&f;f=(g^l)&255;l=n&16777215;g=c[p+((l>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(n&1023^1)|0]=f;return}else{gg[c[p+196648+(g<<2)>>2]&4095](l,f);return}}function BN(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=1<<(g>>>((f<<3&16^16)>>>0)&7);f=9104156+((c[2276069]&7|8)<<2)|0;g=(c[f>>2]|0)-1|0;c[f>>2]=g;f=c[2276085]|0;m=f&g;b=m&16777215;e=c[2112932]|0;j=c[e+(b>>>10<<2)>>2]|0;if(j>>>0>9){n=a[j+(m&1023^1)|0]|0;o=f;p=e}else{f=gj[c[e+196608+(j<<2)>>2]&4095](b)|0;n=f;o=c[2276085]|0;p=c[2112932]|0}f=n&255;c[2276076]=f&l;n=o&g;g=(f^l)&255;l=n&16777215;f=c[p+((l>>>10|16384)<<2)>>2]|0;if(f>>>0>9){a[f+(n&1023^1)|0]=g;return}else{gg[c[p+196648+(f<<2)>>2]&4095](l,g);return}}function BO(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=1<<(g>>>((f<<3&16^16)>>>0)&7);f=(c[2276054]|0)-2|0;c[2276054]=f;g=c[2276085]|0;m=g&f;b=m&16777215;e=c[2112932]|0;j=c[e+(b>>>10<<2)>>2]|0;if(j>>>0>9){n=a[j+(m&1023^1)|0]|0;o=g;p=e}else{g=gj[c[e+196608+(j<<2)>>2]&4095](b)|0;n=g;o=c[2276085]|0;p=c[2112932]|0}g=n&255;c[2276076]=g&l;n=o&f;f=(g^l)&255;l=n&16777215;g=c[p+((l>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(n&1023^1)|0]=f;return}else{gg[c[p+196648+(g<<2)>>2]&4095](l,f);return}}function BP(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=1<<(g>>>((f<<3&16^16)>>>0)&7);f=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;o=p&-4;if((o|0)==(h|0)){q=p;r=g}else{c[2276083]=o;g=c[2276085]&o;o=g&16777212;h=c[2112932]|0;e=c[h+((o>>>10|32768)<<2)>>2]|0;if(e>>>0>9){j=g&1020;s=(d[e+(j|3)|0]|0)<<8|(d[e+(j|2)|0]|0)|((d[e+(j|1)|0]|0)<<8|(d[e+j|0]|0))<<16;t=p}else{p=gj[c[h+196768+(e<<2)>>2]&4095](o)|0;s=p;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;s=(r>>>((q<<3&16^16)>>>0)<<16>>16)+f|0;f=c[2276085]|0;q=s&f;r=q&16777215;t=c[2112932]|0;p=c[t+(r>>>10<<2)>>2]|0;if(p>>>0>9){u=a[p+(q&1023^1)|0]|0;v=f;w=t}else{f=gj[c[t+196608+(p<<2)>>2]&4095](r)|0;u=f;v=c[2276085]|0;w=c[2112932]|0}f=u&255;c[2276076]=f&n;u=v&s;s=(f^n)&255;n=u&16777215;f=c[w+((n>>>10|16384)<<2)>>2]|0;if(f>>>0>9){a[f+(u&1023^1)|0]=s;return}else{gg[c[w+196648+(f<<2)>>2]&4095](n,s);return}}function BQ(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=1<<(g>>>((f<<3&16^16)>>>0)&7);f=xw(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;g=c[2276085]|0;m=g&f;b=m&16777215;e=c[2112932]|0;j=c[e+(b>>>10<<2)>>2]|0;if(j>>>0>9){n=a[j+(m&1023^1)|0]|0;o=g;p=e}else{g=gj[c[e+196608+(j<<2)>>2]&4095](b)|0;n=g;o=c[2276085]|0;p=c[2112932]|0}g=n&255;c[2276076]=g&l;n=o&f;f=(g^l)&255;l=n&16777215;g=c[p+((l>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(n&1023^1)|0]=f;return}else{gg[c[p+196648+(g<<2)>>2]&4095](l,f);return}}function BR(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=1<<(g>>>((f<<3&16^16)>>>0)&7);f=p&-4;if((f|0)==(h|0)){q=p;r=g}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;h=c[2112932]|0;o=c[h+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=p}else{p=gj[c[h+196768+(o<<2)>>2]&4095](f)|0;s=p;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;s=r>>>((q<<3&16^16)>>>0)<<16>>16;q=c[2276085]|0;r=s&q;t=r&16777215;p=c[2112932]|0;f=c[p+(t>>>10<<2)>>2]|0;if(f>>>0>9){u=a[f+(r&1023^1)|0]|0;v=q;w=p}else{q=gj[c[p+196608+(f<<2)>>2]&4095](t)|0;u=q;v=c[2276085]|0;w=c[2112932]|0}q=u&255;c[2276076]=q&n;u=v&s;s=(q^n)&255;n=u&16777215;q=c[w+((n>>>10|16384)<<2)>>2]|0;if(q>>>0>9){a[q+(u&1023^1)|0]=s;return}else{gg[c[w+196648+(q<<2)>>2]&4095](n,s);return}}function BS(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=1<<(g>>>((f<<3&16^16)>>>0)&7);f=p&-4;if((f|0)==(h|0)){q=p;r=h;s=g}else{c[2276083]=f;g=c[2276085]&f;h=g&16777212;o=c[2112932]|0;e=c[o+((h>>>10|32768)<<2)>>2]|0;if(e>>>0>9){j=g&1020;t=(d[e+(j|3)|0]|0)<<8|(d[e+(j|2)|0]|0)|((d[e+(j|1)|0]|0)<<8|(d[e+j|0]|0))<<16;u=p;v=f}else{f=gj[c[o+196768+(e<<2)>>2]&4095](h)|0;t=f;u=c[2276056]|0;v=c[2276083]|0}c[2276084]=t;q=u;r=v;s=t}t=q+2|0;c[2276056]=t;q=t&-4;if((q|0)==(r|0)){w=s;x=t}else{c[2276083]=q;r=c[2276085]&q;q=r&16777212;v=c[2112932]|0;u=c[v+((q>>>10|32768)<<2)>>2]|0;if(u>>>0>9){f=r&1020;y=(d[u+(f|3)|0]|0)<<8|(d[u+(f|2)|0]|0)|((d[u+(f|1)|0]|0)<<8|(d[u+f|0]|0))<<16;z=t}else{t=gj[c[v+196768+(u<<2)>>2]&4095](q)|0;y=t;z=c[2276056]|0}c[2276084]=y;w=y>>>16|s<<16;x=z}c[2276056]=x+2;x=c[2276085]|0;z=x&w;s=z&16777215;y=c[2112932]|0;t=c[y+(s>>>10<<2)>>2]|0;if(t>>>0>9){A=a[t+(z&1023^1)|0]|0;B=x;C=y}else{x=gj[c[y+196608+(t<<2)>>2]&4095](s)|0;A=x;B=c[2276085]|0;C=c[2112932]|0}x=A&255;c[2276076]=x&n;A=B&w;w=(x^n)&255;n=A&16777215;x=c[C+((n>>>10|16384)<<2)>>2]|0;if(x>>>0>9){a[x+(A&1023^1)|0]=w;return}else{gg[c[C+196648+(x<<2)>>2]&4095](n,w);return}}function BT(){var a=0,b=0,d=0;a=c[2276069]|0;b=9104156+((a&7)<<2)|0;d=1<<(c[9104156+((a>>>9&7)<<2)>>2]&31);c[2276076]=d&c[b>>2];c[b>>2]=c[b>>2]&~d;return}function BU(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=c[2276069]|0;d=c[9104156+((b&7|8)<<2)>>2]|0;e=c[2276085]|0;f=e&d;g=f&16777215;h=c[2112932]|0;i=c[h+(g>>>10<<2)>>2]|0;if(i>>>0>9){j=a[i+(f&1023^1)|0]|0;k=b;l=e;m=h}else{e=gj[c[h+196608+(i<<2)>>2]&4095](g)|0;j=e;k=c[2276069]|0;l=c[2276085]|0;m=c[2112932]|0}e=j&255;j=1<<(c[9104156+((k>>>9&7)<<2)>>2]&7);c[2276076]=j&e;k=l&d;d=(j^255)&e&255;e=k&16777215;j=c[m+((e>>>10|16384)<<2)>>2]|0;if(j>>>0>9){a[j+(k&1023^1)|0]=d;return}else{gg[c[m+196648+(j<<2)>>2]&4095](e,d);return}}function BV(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=c[b>>2]|0;c[b>>2]=d+1;b=c[2276085]|0;e=b&d;f=e&16777215;g=c[2112932]|0;h=c[g+(f>>>10<<2)>>2]|0;if(h>>>0>9){i=a[h+(e&1023^1)|0]|0;j=b;k=g}else{b=gj[c[g+196608+(h<<2)>>2]&4095](f)|0;i=b;j=c[2276085]|0;k=c[2112932]|0}b=i&255;i=1<<(c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]&7);c[2276076]=i&b;f=j&d;d=(i^255)&b&255;b=f&16777215;i=c[k+((b>>>10|16384)<<2)>>2]|0;if(i>>>0>9){a[i+(f&1023^1)|0]=d;return}else{gg[c[k+196648+(i<<2)>>2]&4095](b,d);return}}function BW(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=c[2276054]|0;c[2276054]=b+2;d=c[2276085]|0;e=d&b;f=e&16777215;g=c[2112932]|0;h=c[g+(f>>>10<<2)>>2]|0;if(h>>>0>9){i=a[h+(e&1023^1)|0]|0;j=d;k=g}else{d=gj[c[g+196608+(h<<2)>>2]&4095](f)|0;i=d;j=c[2276085]|0;k=c[2112932]|0}d=i&255;i=1<<(c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]&7);c[2276076]=i&d;f=j&b;b=(i^255)&d&255;d=f&16777215;i=c[k+((d>>>10|16384)<<2)>>2]|0;if(i>>>0>9){a[i+(f&1023^1)|0]=b;return}else{gg[c[k+196648+(i<<2)>>2]&4095](d,b);return}}function BX(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=9104156+((c[2276069]&7|8)<<2)|0;d=(c[b>>2]|0)-1|0;c[b>>2]=d;b=c[2276085]|0;e=b&d;f=e&16777215;g=c[2112932]|0;h=c[g+(f>>>10<<2)>>2]|0;if(h>>>0>9){i=a[h+(e&1023^1)|0]|0;j=b;k=g}else{b=gj[c[g+196608+(h<<2)>>2]&4095](f)|0;i=b;j=c[2276085]|0;k=c[2112932]|0}b=i&255;i=1<<(c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]&7);c[2276076]=i&b;f=j&d;d=(i^255)&b&255;b=f&16777215;i=c[k+((b>>>10|16384)<<2)>>2]|0;if(i>>>0>9){a[i+(f&1023^1)|0]=d;return}else{gg[c[k+196648+(i<<2)>>2]&4095](b,d);return}}function BY(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=(c[2276054]|0)-2|0;c[2276054]=b;d=c[2276085]|0;e=d&b;f=e&16777215;g=c[2112932]|0;h=c[g+(f>>>10<<2)>>2]|0;if(h>>>0>9){i=a[h+(e&1023^1)|0]|0;j=d;k=g}else{d=gj[c[g+196608+(h<<2)>>2]&4095](f)|0;i=d;j=c[2276085]|0;k=c[2112932]|0}d=i&255;i=1<<(c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]&7);c[2276076]=i&d;f=j&b;b=(i^255)&d&255;d=f&16777215;i=c[k+((d>>>10|16384)<<2)>>2]|0;if(i>>>0>9){a[i+(f&1023^1)|0]=b;return}else{gg[c[k+196648+(i<<2)>>2]&4095](d,b);return}}function BZ(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;e=c[2276056]|0;f=e&-4;if((f|0)==(c[2276083]|0)){g=e;h=c[2276084]|0}else{c[2276083]=f;i=c[2276085]&f;f=i&16777212;j=c[2112932]|0;k=c[j+((f>>>10|32768)<<2)>>2]|0;if(k>>>0>9){l=i&1020;m=(d[k+(l|3)|0]|0)<<8|(d[k+(l|2)|0]|0)|((d[k+(l|1)|0]|0)<<8|(d[k+l|0]|0))<<16;n=e}else{e=gj[c[j+196768+(k<<2)>>2]&4095](f)|0;m=e;n=c[2276056]|0}c[2276084]=m;g=n;h=m}c[2276056]=g+2;m=(h>>>((g<<3&16^16)>>>0)<<16>>16)+b|0;b=c[2276085]|0;g=m&b;h=g&16777215;n=c[2112932]|0;e=c[n+(h>>>10<<2)>>2]|0;if(e>>>0>9){o=a[e+(g&1023^1)|0]|0;p=b;q=n}else{b=gj[c[n+196608+(e<<2)>>2]&4095](h)|0;o=b;p=c[2276085]|0;q=c[2112932]|0}b=o&255;o=1<<(c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]&7);c[2276076]=o&b;h=p&m;m=(o^255)&b&255;b=h&16777215;o=c[q+((b>>>10|16384)<<2)>>2]|0;if(o>>>0>9){a[o+(h&1023^1)|0]=m;return}else{gg[c[q+196648+(o<<2)>>2]&4095](b,m);return}}function B_(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=xw(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;d=c[2276085]|0;e=d&b;f=e&16777215;g=c[2112932]|0;h=c[g+(f>>>10<<2)>>2]|0;if(h>>>0>9){i=a[h+(e&1023^1)|0]|0;j=d;k=g}else{d=gj[c[g+196608+(h<<2)>>2]&4095](f)|0;i=d;j=c[2276085]|0;k=c[2112932]|0}d=i&255;i=1<<(c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]&7);c[2276076]=i&d;f=j&b;b=(i^255)&d&255;d=f&16777215;i=c[k+((d>>>10|16384)<<2)>>2]|0;if(i>>>0>9){a[i+(f&1023^1)|0]=b;return}else{gg[c[k+196648+(i<<2)>>2]&4095](d,b);return}}function B$(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0)<<16>>16;f=c[2276085]|0;g=l&f;m=g&16777215;b=c[2112932]|0;e=c[b+(m>>>10<<2)>>2]|0;if(e>>>0>9){n=a[e+(g&1023^1)|0]|0;o=f;p=b}else{f=gj[c[b+196608+(e<<2)>>2]&4095](m)|0;n=f;o=c[2276085]|0;p=c[2112932]|0}f=n&255;n=1<<(c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]&7);c[2276076]=n&f;m=o&l;l=(n^255)&f&255;f=m&16777215;n=c[p+((f>>>10|16384)<<2)>>2]|0;if(n>>>0>9){a[n+(m&1023^1)|0]=l;return}else{gg[c[p+196648+(n<<2)>>2]&4095](f,l);return}}function B0(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=e;h=c[2276084]|0}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=p;h=n}n=f+2|0;c[2276056]=n;f=n&-4;if((f|0)==(g|0)){q=h;r=n}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;p=c[2112932]|0;o=c[p+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=n}else{n=gj[c[p+196768+(o<<2)>>2]&4095](f)|0;s=n;t=c[2276056]|0}c[2276084]=s;q=s>>>16|h<<16;r=t}c[2276056]=r+2;r=c[2276085]|0;t=r&q;h=t&16777215;s=c[2112932]|0;n=c[s+(h>>>10<<2)>>2]|0;if(n>>>0>9){u=a[n+(t&1023^1)|0]|0;v=r;w=s}else{r=gj[c[s+196608+(n<<2)>>2]&4095](h)|0;u=r;v=c[2276085]|0;w=c[2112932]|0}r=u&255;u=1<<(c[9104156+(((c[2276069]|0)>>>9&7)<<2)>>2]&7);c[2276076]=u&r;h=v&q;q=(u^255)&r&255;r=h&16777215;u=c[w+((r>>>10|16384)<<2)>>2]|0;if(u>>>0>9){a[u+(h&1023^1)|0]=q;return}else{gg[c[w+196648+(u<<2)>>2]&4095](r,q);return}}function B1(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a=9104156+((c[2276069]&7)<<2)|0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=1<<(g>>>((f<<3&16^16)>>>0)&31);c[2276076]=l&c[a>>2];c[a>>2]=c[a>>2]&~l;return}function B2(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=1<<(g>>>((f<<3&16^16)>>>0)&7);f=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;g=c[2276085]|0;m=g&f;b=m&16777215;e=c[2112932]|0;j=c[e+(b>>>10<<2)>>2]|0;if(j>>>0>9){n=a[j+(m&1023^1)|0]|0;o=g;p=e}else{g=gj[c[e+196608+(j<<2)>>2]&4095](b)|0;n=g;o=c[2276085]|0;p=c[2112932]|0}g=n&255;c[2276076]=g&l;n=o&f;f=g&(l^255)&255;l=n&16777215;g=c[p+((l>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(n&1023^1)|0]=f;return}else{gg[c[p+196648+(g<<2)>>2]&4095](l,f);return}}function B3(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=1<<(g>>>((f<<3&16^16)>>>0)&7);f=9104156+((c[2276069]&7|8)<<2)|0;g=c[f>>2]|0;c[f>>2]=g+1;f=c[2276085]|0;m=f&g;b=m&16777215;e=c[2112932]|0;j=c[e+(b>>>10<<2)>>2]|0;if(j>>>0>9){n=a[j+(m&1023^1)|0]|0;o=f;p=e}else{f=gj[c[e+196608+(j<<2)>>2]&4095](b)|0;n=f;o=c[2276085]|0;p=c[2112932]|0}f=n&255;c[2276076]=f&l;n=o&g;g=f&(l^255)&255;l=n&16777215;f=c[p+((l>>>10|16384)<<2)>>2]|0;if(f>>>0>9){a[f+(n&1023^1)|0]=g;return}else{gg[c[p+196648+(f<<2)>>2]&4095](l,g);return}}function B4(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=1<<(g>>>((f<<3&16^16)>>>0)&7);f=c[2276054]|0;c[2276054]=f+2;g=c[2276085]|0;m=g&f;b=m&16777215;e=c[2112932]|0;j=c[e+(b>>>10<<2)>>2]|0;if(j>>>0>9){n=a[j+(m&1023^1)|0]|0;o=g;p=e}else{g=gj[c[e+196608+(j<<2)>>2]&4095](b)|0;n=g;o=c[2276085]|0;p=c[2112932]|0}g=n&255;c[2276076]=g&l;n=o&f;f=g&(l^255)&255;l=n&16777215;g=c[p+((l>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(n&1023^1)|0]=f;return}else{gg[c[p+196648+(g<<2)>>2]&4095](l,f);return}}function B5(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=1<<(g>>>((f<<3&16^16)>>>0)&7);f=9104156+((c[2276069]&7|8)<<2)|0;g=(c[f>>2]|0)-1|0;c[f>>2]=g;f=c[2276085]|0;m=f&g;b=m&16777215;e=c[2112932]|0;j=c[e+(b>>>10<<2)>>2]|0;if(j>>>0>9){n=a[j+(m&1023^1)|0]|0;o=f;p=e}else{f=gj[c[e+196608+(j<<2)>>2]&4095](b)|0;n=f;o=c[2276085]|0;p=c[2112932]|0}f=n&255;c[2276076]=f&l;n=o&g;g=f&(l^255)&255;l=n&16777215;f=c[p+((l>>>10|16384)<<2)>>2]|0;if(f>>>0>9){a[f+(n&1023^1)|0]=g;return}else{gg[c[p+196648+(f<<2)>>2]&4095](l,g);return}}function B6(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=1<<(g>>>((f<<3&16^16)>>>0)&7);f=(c[2276054]|0)-2|0;c[2276054]=f;g=c[2276085]|0;m=g&f;b=m&16777215;e=c[2112932]|0;j=c[e+(b>>>10<<2)>>2]|0;if(j>>>0>9){n=a[j+(m&1023^1)|0]|0;o=g;p=e}else{g=gj[c[e+196608+(j<<2)>>2]&4095](b)|0;n=g;o=c[2276085]|0;p=c[2112932]|0}g=n&255;c[2276076]=g&l;n=o&f;f=g&(l^255)&255;l=n&16777215;g=c[p+((l>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(n&1023^1)|0]=f;return}else{gg[c[p+196648+(g<<2)>>2]&4095](l,f);return}}function B7(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=1<<(g>>>((f<<3&16^16)>>>0)&7);f=c[9104156+((c[2276069]&7|8)<<2)>>2]|0;o=p&-4;if((o|0)==(h|0)){q=p;r=g}else{c[2276083]=o;g=c[2276085]&o;o=g&16777212;h=c[2112932]|0;e=c[h+((o>>>10|32768)<<2)>>2]|0;if(e>>>0>9){j=g&1020;s=(d[e+(j|3)|0]|0)<<8|(d[e+(j|2)|0]|0)|((d[e+(j|1)|0]|0)<<8|(d[e+j|0]|0))<<16;t=p}else{p=gj[c[h+196768+(e<<2)>>2]&4095](o)|0;s=p;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;s=(r>>>((q<<3&16^16)>>>0)<<16>>16)+f|0;f=c[2276085]|0;q=s&f;r=q&16777215;t=c[2112932]|0;p=c[t+(r>>>10<<2)>>2]|0;if(p>>>0>9){u=a[p+(q&1023^1)|0]|0;v=f;w=t}else{f=gj[c[t+196608+(p<<2)>>2]&4095](r)|0;u=f;v=c[2276085]|0;w=c[2112932]|0}f=u&255;c[2276076]=f&n;u=v&s;s=f&(n^255)&255;n=u&16777215;f=c[w+((n>>>10|16384)<<2)>>2]|0;if(f>>>0>9){a[f+(u&1023^1)|0]=s;return}else{gg[c[w+196648+(f<<2)>>2]&4095](n,s);return}}function B8(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=1<<(g>>>((f<<3&16^16)>>>0)&7);f=xw(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;g=c[2276085]|0;m=g&f;b=m&16777215;e=c[2112932]|0;j=c[e+(b>>>10<<2)>>2]|0;if(j>>>0>9){n=a[j+(m&1023^1)|0]|0;o=g;p=e}else{g=gj[c[e+196608+(j<<2)>>2]&4095](b)|0;n=g;o=c[2276085]|0;p=c[2112932]|0}g=n&255;c[2276076]=g&l;n=o&f;f=g&(l^255)&255;l=n&16777215;g=c[p+((l>>>10|16384)<<2)>>2]|0;if(g>>>0>9){a[g+(n&1023^1)|0]=f;return}else{gg[c[p+196648+(g<<2)>>2]&4095](l,f);return}}function B9(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=1<<(g>>>((f<<3&16^16)>>>0)&7);f=p&-4;if((f|0)==(h|0)){q=p;r=g}else{c[2276083]=f;g=c[2276085]&f;f=g&16777212;h=c[2112932]|0;o=c[h+((f>>>10|32768)<<2)>>2]|0;if(o>>>0>9){e=g&1020;s=(d[o+(e|3)|0]|0)<<8|(d[o+(e|2)|0]|0)|((d[o+(e|1)|0]|0)<<8|(d[o+e|0]|0))<<16;t=p}else{p=gj[c[h+196768+(o<<2)>>2]&4095](f)|0;s=p;t=c[2276056]|0}c[2276084]=s;q=t;r=s}c[2276056]=q+2;s=r>>>((q<<3&16^16)>>>0)<<16>>16;q=c[2276085]|0;r=s&q;t=r&16777215;p=c[2112932]|0;f=c[p+(t>>>10<<2)>>2]|0;if(f>>>0>9){u=a[f+(r&1023^1)|0]|0;v=q;w=p}else{q=gj[c[p+196608+(f<<2)>>2]&4095](t)|0;u=q;v=c[2276085]|0;w=c[2112932]|0}q=u&255;c[2276076]=q&n;u=v&s;s=q&(n^255)&255;n=u&16777215;q=c[w+((n>>>10|16384)<<2)>>2]|0;if(q>>>0>9){a[q+(u&1023^1)|0]=s;return}else{gg[c[w+196648+(q<<2)>>2]&4095](n,s);return}}function Ca(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0;h=e}else{c[2276083]=e;i=c[2276085]&e;j=i&16777212;k=c[2112932]|0;l=c[k+((j>>>10|32768)<<2)>>2]|0;if(l>>>0>9){m=i&1020;n=(d[l+(m|3)|0]|0)<<8|(d[l+(m|2)|0]|0)|((d[l+(m|1)|0]|0)<<8|(d[l+m|0]|0))<<16;o=b;p=e}else{e=gj[c[k+196768+(l<<2)>>2]&4095](j)|0;n=e;o=c[2276056]|0;p=c[2276083]|0}c[2276084]=n;f=o;g=n;h=p}p=f+2|0;c[2276056]=p;n=1<<(g>>>((f<<3&16^16)>>>0)&7);f=p&-4;if((f|0)==(h|0)){q=p;r=h;s=g}else{c[2276083]=f;g=c[2276085]&f;h=g&16777212;o=c[2112932]|0;e=c[o+((h>>>10|32768)<<2)>>2]|0;if(e>>>0>9){j=g&1020;t=(d[e+(j|3)|0]|0)<<8|(d[e+(j|2)|0]|0)|((d[e+(j|1)|0]|0)<<8|(d[e+j|0]|0))<<16;u=p;v=f}else{f=gj[c[o+196768+(e<<2)>>2]&4095](h)|0;t=f;u=c[2276056]|0;v=c[2276083]|0}c[2276084]=t;q=u;r=v;s=t}t=q+2|0;c[2276056]=t;q=t&-4;if((q|0)==(r|0)){w=s;x=t}else{c[2276083]=q;r=c[2276085]&q;q=r&16777212;v=c[2112932]|0;u=c[v+((q>>>10|32768)<<2)>>2]|0;if(u>>>0>9){f=r&1020;y=(d[u+(f|3)|0]|0)<<8|(d[u+(f|2)|0]|0)|((d[u+(f|1)|0]|0)<<8|(d[u+f|0]|0))<<16;z=t}else{t=gj[c[v+196768+(u<<2)>>2]&4095](q)|0;y=t;z=c[2276056]|0}c[2276084]=y;w=y>>>16|s<<16;x=z}c[2276056]=x+2;x=c[2276085]|0;z=x&w;s=z&16777215;y=c[2112932]|0;t=c[y+(s>>>10<<2)>>2]|0;if(t>>>0>9){A=a[t+(z&1023^1)|0]|0;B=x;C=y}else{x=gj[c[y+196608+(t<<2)>>2]&4095](s)|0;A=x;B=c[2276085]|0;C=c[2112932]|0}x=A&255;c[2276076]=x&n;A=B&w;w=x&(n^255)&255;n=A&16777215;x=c[C+((n>>>10|16384)<<2)>>2]|0;if(x>>>0>9){a[x+(A&1023^1)|0]=w;return}else{gg[c[C+196648+(x<<2)>>2]&4095](n,w);return}}function Cb(){var a=0,b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((c[2276038]&24|0)==0){Bl();return}a=c[2276056]|0;b=a&-4;if((b|0)==(c[2276083]|0)){e=a;f=c[2276084]|0}else{c[2276083]=b;g=c[2276085]&b;b=g&16777212;h=c[2112932]|0;i=c[h+((b>>>10|32768)<<2)>>2]|0;if(i>>>0>9){j=g&1020;k=(d[i+(j|3)|0]|0)<<8|(d[i+(j|2)|0]|0)|((d[i+(j|1)|0]|0)<<8|(d[i+j|0]|0))<<16;l=a}else{a=gj[c[h+196768+(i<<2)>>2]&4095](b)|0;k=a;l=c[2276056]|0}c[2276084]=k;e=l;f=k}c[2276056]=e+2;k=f>>>((e<<3&16^16)>>>0);e=k&65535;f=e>>>6;l=9104156+((c[2276069]&7)<<2)|0;if((k&2048|0)==0){m=f&31}else{m=c[9104156+((f&7)<<2)>>2]|0}if((k&32|0)==0){n=e}else{n=c[9104156+((k&7)<<2)>>2]|0}k=m&31;m=-1<<(n+31&31^31);n=32-k|0;e=(n>>>0<32?m<<n:0)|m>>>(k>>>0);c[2276075]=c[l>>2]<<k>>>24;c[2276076]=e&c[l>>2];c[2276077]=0;c[2276078]=0;c[l>>2]=e^c[l>>2];return}function Cc(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;if((c[2276038]&24|0)==0){Bl();return}b=c[2276056]|0;e=b&-4;if((e|0)==(c[2276083]|0)){f=b;g=c[2276084]|0}else{c[2276083]=e;h=c[2276085]&e;e=h&16777212;i=c[2112932]|0;j=c[i+((e>>>10|32768)<<2)>>2]|0;if(j>>>0>9){k=h&1020;l=(d[j+(k|3)|0]|0)<<8|(d[j+(k|2)|0]|0)|((d[j+(k|1)|0]|0)<<8|(d[j+k|0]|0))<<16;m=b}else{b=gj[c[i+196768+(j<<2)>>2]&4095](e)|0;l=b;m=c[2276056]|0}c[2276084]=l;f=m;g=l}c[2276056]=f+2;l=g>>>((f<<3&16^16)>>>0);f=l&65535;g=f>>>6;if((l&2048|0)==0){n=g&31}else{n=c[9104156+((g&7)<<2)>>2]|0}if((l&32|0)==0){o=f}else{o=c[9104156+((l&7)<<2)>>2]|0}l=((n|0)/8|0)+(c[9104156+((c[2276069]&7|8)<<2)>>2]|0)|0;f=(n|0)%8|0;if((f|0)<0){p=l-1|0;q=f+8|0}else{p=l;q=f}f=o+31&31;o=-1<<(f^31);l=o>>>(q>>>0);n=c[2276085]|0;g=n&p;m=g&16777215;b=c[2112932]|0;e=c[b+(m>>>10<<2)>>2]|0;if(e>>>0>9){j=g&1023;r=(d[e+(j+3)|0]|0)<<8|(d[e+(j+2)|0]|0)|((d[e+(j+1)|0]|0)<<8|(d[e+j|0]|0))<<16;s=n;t=b}else{n=gj[c[b+196768+(e<<2)>>2]&4095](m)|0;r=n;s=c[2276085]|0;t=c[2112932]|0}c[2276075]=r<<q>>>24;c[2276076]=r&l;c[2276077]=0;c[2276078]=0;n=r^l;l=s&p;s=l&16777215;r=c[t+((s>>>10|16384)<<2)>>2]|0;if(r>>>0>9){m=l&1023;a[r+m|0]=n>>>16&255;a[r+(m+1)|0]=n>>>24&255;a[r+(m+2)|0]=n&255;a[r+(m+3)|0]=n>>>8&255}else{gg[c[t+196808+(r<<2)>>2]&4095](s,n)}if((f+1+q|0)>>>0<=32){return}q=p+4|0;p=c[2276085]|0;f=p&q;n=f&16777215;s=c[2112932]|0;r=c[s+(n>>>10<<2)>>2]|0;if(r>>>0>9){u=a[r+(f&1023^1)|0]|0;v=p;w=s}else{p=gj[c[s+196608+(r<<2)>>2]&4095](n)|0;u=p;v=c[2276085]|0;w=c[2112932]|0}p=u&255;c[2276076]=o&p|c[2276076];u=v&q;q=(p^o)&255;o=u&16777215;p=c[w+((o>>>10|16384)<<2)>>2]|0;if(p>>>0>9){a[p+(u&1023^1)|0]=q;return}else{gg[c[w+196648+(p<<2)>>2]&4095](o,q);return}}
function gEr(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0;b=i;i=i+448|0;d=b|0;e=b+16|0;f=b+32|0;g=b+48|0;h=b+64|0;j=b+80|0;k=b+96|0;l=b+112|0;m=b+128|0;n=b+144|0;o=b+160|0;p=b+176|0;q=b+192|0;r=b+208|0;s=b+224|0;t=b+240|0;u=b+256|0;v=b+272|0;w=b+288|0;x=b+304|0;y=b+320|0;z=b+336|0;A=b+352|0;B=b+368|0;C=b+384|0;D=b+400|0;E=b+416|0;F=b+432|0;if((a[14124984]|0)!=0){G=c[2384144]|0;i=b;return G|0}if((bp(14124984)|0)==0){G=c[2384144]|0;i=b;return G|0}do{if((a[14124992]|0)==0){if((bp(14124992)|0)==0){break}c[2384191]=0;c[2384190]=621184;a[9536896]=1;c[2384193]=9536784;c[2384192]=9536784;c[2384194]=9536896;H=28;J=9536784;do{if((J|0)==0){K=0}else{c[J>>2]=0;K=c[2384193]|0}J=K+4|0;c[2384193]=J;H=H-1|0;}while((H|0)!=0);a[9536904]=2;a[9536905]=67;a[9536906]=0;H=c[2384192]|0;if((H|0)!=(J|0)){c[2384193]=K+(-((K+(-H|0)|0)>>>2)<<2)}c[2384183]=0;c[2384182]=620888;if((c[2384980]|0)!=-1){c[F>>2]=9539920;c[F+4>>2]=180;c[F+8>>2]=0;gAp(9539920,F)}H=c[2384981]|0;L=H-1|0;I=c[2384183]|0,c[2384183]=I+1,I;M=c[2384193]|0;N=c[2384192]|0;O=M-N>>2;do{if(O>>>0>L>>>0){P=N}else{if(O>>>0<H>>>0){gFZ(9536768,H-O|0);P=c[2384192]|0;break}if(O>>>0<=H>>>0){P=N;break}Q=N+(H<<2)|0;if((Q|0)==(M|0)){P=N;break}c[2384193]=M+(~((M-4+(-Q|0)|0)>>>2)<<2);P=N}}while(0);N=c[P+(L<<2)>>2]|0;if((N|0)==0){R=P}else{M=N+4|0;if(((I=c[M>>2]|0,c[M>>2]=I+ -1,I)|0)==0){gf[c[(c[N>>2]|0)+8>>2]&2047](N|0)}R=c[2384192]|0}c[R+(L<<2)>>2]=9536728;c[2384181]=0;c[2384180]=620848;if((c[2384978]|0)!=-1){c[E>>2]=9539912;c[E+4>>2]=180;c[E+8>>2]=0;gAp(9539912,E)}N=c[2384979]|0;M=N-1|0;I=c[2384181]|0,c[2384181]=I+1,I;H=c[2384193]|0;O=c[2384192]|0;J=H-O>>2;do{if(J>>>0>M>>>0){S=O}else{if(J>>>0<N>>>0){gFZ(9536768,N-J|0);S=c[2384192]|0;break}if(J>>>0<=N>>>0){S=O;break}Q=O+(N<<2)|0;if((Q|0)==(H|0)){S=O;break}c[2384193]=H+(~((H-4+(-Q|0)|0)>>>2)<<2);S=O}}while(0);O=c[S+(M<<2)>>2]|0;if((O|0)==0){T=S}else{H=O+4|0;if(((I=c[H>>2]|0,c[H>>2]=I+ -1,I)|0)==0){gf[c[(c[O>>2]|0)+8>>2]&2047](O|0)}T=c[2384192]|0}c[T+(M<<2)>>2]=9536720;c[2384233]=0;c[2384232]=621296;c[2384234]=0;a[9536940]=0;c[2384234]=c[(cD()|0)>>2];if((c[2385060]|0)!=-1){c[D>>2]=9540240;c[D+4>>2]=180;c[D+8>>2]=0;gAp(9540240,D)}O=c[2385061]|0;H=O-1|0;I=c[2384233]|0,c[2384233]=I+1,I;N=c[2384193]|0;J=c[2384192]|0;L=N-J>>2;do{if(L>>>0>H>>>0){U=J}else{if(L>>>0<O>>>0){gFZ(9536768,O-L|0);U=c[2384192]|0;break}if(L>>>0<=O>>>0){U=J;break}Q=J+(O<<2)|0;if((Q|0)==(N|0)){U=J;break}c[2384193]=N+(~((N-4+(-Q|0)|0)>>>2)<<2);U=J}}while(0);J=c[U+(H<<2)>>2]|0;if((J|0)==0){V=U}else{N=J+4|0;if(((I=c[N>>2]|0,c[N>>2]=I+ -1,I)|0)==0){gf[c[(c[J>>2]|0)+8>>2]&2047](J|0)}V=c[2384192]|0}c[V+(H<<2)>>2]=9536928;c[2384231]=0;c[2384230]=621216;if((c[2385058]|0)!=-1){c[C>>2]=9540232;c[C+4>>2]=180;c[C+8>>2]=0;gAp(9540232,C)}J=c[2385059]|0;N=J-1|0;I=c[2384231]|0,c[2384231]=I+1,I;O=c[2384193]|0;L=c[2384192]|0;M=O-L>>2;do{if(M>>>0>N>>>0){W=L}else{if(M>>>0<J>>>0){gFZ(9536768,J-M|0);W=c[2384192]|0;break}if(M>>>0<=J>>>0){W=L;break}Q=L+(J<<2)|0;if((Q|0)==(O|0)){W=L;break}c[2384193]=O+(~((O-4+(-Q|0)|0)>>>2)<<2);W=L}}while(0);L=c[W+(N<<2)>>2]|0;if((L|0)==0){X=W}else{O=L+4|0;if(((I=c[O>>2]|0,c[O>>2]=I+ -1,I)|0)==0){gf[c[(c[L>>2]|0)+8>>2]&2047](L|0)}X=c[2384192]|0}c[X+(N<<2)>>2]=9536920;c[2384185]=0;c[2384184]=620984;if((c[2384984]|0)!=-1){c[B>>2]=9539936;c[B+4>>2]=180;c[B+8>>2]=0;gAp(9539936,B)}L=c[2384985]|0;O=L-1|0;I=c[2384185]|0,c[2384185]=I+1,I;J=c[2384193]|0;M=c[2384192]|0;H=J-M>>2;do{if(H>>>0>O>>>0){Y=M}else{if(H>>>0<L>>>0){gFZ(9536768,L-H|0);Y=c[2384192]|0;break}if(H>>>0<=L>>>0){Y=M;break}Q=M+(L<<2)|0;if((Q|0)==(J|0)){Y=M;break}c[2384193]=J+(~((J-4+(-Q|0)|0)>>>2)<<2);Y=M}}while(0);M=c[Y+(O<<2)>>2]|0;if((M|0)==0){Z=Y}else{J=M+4|0;if(((I=c[J>>2]|0,c[J>>2]=I+ -1,I)|0)==0){gf[c[(c[M>>2]|0)+8>>2]&2047](M|0)}Z=c[2384192]|0}c[Z+(O<<2)>>2]=9536736;c[147711]=0;c[147710]=620928;do{if((a[14125e3]|0)==0){if((bp(14125e3)|0)==0){break}c[2384150]=e6(2147483647,485280,0)|0}}while(0);c[147712]=c[2384150];if((c[2384982]|0)!=-1){c[A>>2]=9539928;c[A+4>>2]=180;c[A+8>>2]=0;gAp(9539928,A)}O=c[2384983]|0;M=O-1|0;I=c[147711]|0,c[147711]=I+1,I;J=c[2384193]|0;L=c[2384192]|0;H=J-L>>2;do{if(H>>>0>M>>>0){_=L}else{if(H>>>0<O>>>0){gFZ(9536768,O-H|0);_=c[2384192]|0;break}if(H>>>0<=O>>>0){_=L;break}N=L+(O<<2)|0;if((N|0)==(J|0)){_=L;break}c[2384193]=J+(~((J-4+(-N|0)|0)>>>2)<<2);_=L}}while(0);L=c[_+(M<<2)>>2]|0;if((L|0)==0){$=_}else{J=L+4|0;if(((I=c[J>>2]|0,c[J>>2]=I+ -1,I)|0)==0){gf[c[(c[L>>2]|0)+8>>2]&2047](L|0)}$=c[2384192]|0}c[$+(M<<2)>>2]=590840;c[2384187]=0;c[2384186]=621040;if((c[2384986]|0)!=-1){c[z>>2]=9539944;c[z+4>>2]=180;c[z+8>>2]=0;gAp(9539944,z)}L=c[2384987]|0;J=L-1|0;I=c[2384187]|0,c[2384187]=I+1,I;O=c[2384193]|0;H=c[2384192]|0;N=O-H>>2;do{if(N>>>0>J>>>0){aa=H}else{if(N>>>0<L>>>0){gFZ(9536768,L-N|0);aa=c[2384192]|0;break}if(N>>>0<=L>>>0){aa=H;break}Q=H+(L<<2)|0;if((Q|0)==(O|0)){aa=H;break}c[2384193]=O+(~((O-4+(-Q|0)|0)>>>2)<<2);aa=H}}while(0);H=c[aa+(J<<2)>>2]|0;if((H|0)==0){ab=aa}else{O=H+4|0;if(((I=c[O>>2]|0,c[O>>2]=I+ -1,I)|0)==0){gf[c[(c[H>>2]|0)+8>>2]&2047](H|0)}ab=c[2384192]|0}c[ab+(J<<2)>>2]=9536744;c[2384189]=0;c[2384188]=621096;if((c[2384988]|0)!=-1){c[y>>2]=9539952;c[y+4>>2]=180;c[y+8>>2]=0;gAp(9539952,y)}H=c[2384989]|0;O=H-1|0;I=c[2384189]|0,c[2384189]=I+1,I;L=c[2384193]|0;N=c[2384192]|0;M=L-N>>2;do{if(M>>>0>O>>>0){ac=N}else{if(M>>>0<H>>>0){gFZ(9536768,H-M|0);ac=c[2384192]|0;break}if(M>>>0<=H>>>0){ac=N;break}Q=N+(H<<2)|0;if((Q|0)==(L|0)){ac=N;break}c[2384193]=L+(~((L-4+(-Q|0)|0)>>>2)<<2);ac=N}}while(0);N=c[ac+(O<<2)>>2]|0;if((N|0)==0){ad=ac}else{L=N+4|0;if(((I=c[L>>2]|0,c[L>>2]=I+ -1,I)|0)==0){gf[c[(c[N>>2]|0)+8>>2]&2047](N|0)}ad=c[2384192]|0}c[ad+(O<<2)>>2]=9536752;c[2384163]=0;c[2384162]=620392;a[9536656]=46;a[9536657]=44;gGz(9536660,0,12);if((c[2384964]|0)!=-1){c[x>>2]=9539856;c[x+4>>2]=180;c[x+8>>2]=0;gAp(9539856,x)}N=c[2384965]|0;L=N-1|0;I=c[2384163]|0,c[2384163]=I+1,I;H=c[2384193]|0;M=c[2384192]|0;J=H-M>>2;do{if(J>>>0>L>>>0){ae=M}else{if(J>>>0<N>>>0){gFZ(9536768,N-J|0);ae=c[2384192]|0;break}if(J>>>0<=N>>>0){ae=M;break}Q=M+(N<<2)|0;if((Q|0)==(H|0)){ae=M;break}c[2384193]=H+(~((H-4+(-Q|0)|0)>>>2)<<2);ae=M}}while(0);M=c[ae+(L<<2)>>2]|0;if((M|0)==0){af=ae}else{H=M+4|0;if(((I=c[H>>2]|0,c[H>>2]=I+ -1,I)|0)==0){gf[c[(c[M>>2]|0)+8>>2]&2047](M|0)}af=c[2384192]|0}c[af+(L<<2)>>2]=9536648;c[147703]=0;c[147702]=620344;c[147704]=46;c[147705]=44;gGz(590824,0,12);if((c[2384962]|0)!=-1){c[w>>2]=9539848;c[w+4>>2]=180;c[w+8>>2]=0;gAp(9539848,w)}M=c[2384963]|0;H=M-1|0;I=c[147703]|0,c[147703]=I+1,I;N=c[2384193]|0;J=c[2384192]|0;O=N-J>>2;do{if(O>>>0>H>>>0){ag=J}else{if(O>>>0<M>>>0){gFZ(9536768,M-O|0);ag=c[2384192]|0;break}if(O>>>0<=M>>>0){ag=J;break}Q=J+(M<<2)|0;if((Q|0)==(N|0)){ag=J;break}c[2384193]=N+(~((N-4+(-Q|0)|0)>>>2)<<2);ag=J}}while(0);J=c[ag+(H<<2)>>2]|0;if((J|0)==0){ah=ag}else{N=J+4|0;if(((I=c[N>>2]|0,c[N>>2]=I+ -1,I)|0)==0){gf[c[(c[J>>2]|0)+8>>2]&2047](J|0)}ah=c[2384192]|0}c[ah+(H<<2)>>2]=590808;c[2384179]=0;c[2384178]=620776;if((c[2384976]|0)!=-1){c[v>>2]=9539904;c[v+4>>2]=180;c[v+8>>2]=0;gAp(9539904,v)}J=c[2384977]|0;N=J-1|0;I=c[2384179]|0,c[2384179]=I+1,I;M=c[2384193]|0;O=c[2384192]|0;L=M-O>>2;do{if(L>>>0>N>>>0){ai=O}else{if(L>>>0<J>>>0){gFZ(9536768,J-L|0);ai=c[2384192]|0;break}if(L>>>0<=J>>>0){ai=O;break}Q=O+(J<<2)|0;if((Q|0)==(M|0)){ai=O;break}c[2384193]=M+(~((M-4+(-Q|0)|0)>>>2)<<2);ai=O}}while(0);O=c[ai+(N<<2)>>2]|0;if((O|0)==0){aj=ai}else{M=O+4|0;if(((I=c[M>>2]|0,c[M>>2]=I+ -1,I)|0)==0){gf[c[(c[O>>2]|0)+8>>2]&2047](O|0)}aj=c[2384192]|0}c[aj+(N<<2)>>2]=9536712;c[2384177]=0;c[2384176]=620704;if((c[2384974]|0)!=-1){c[u>>2]=9539896;c[u+4>>2]=180;c[u+8>>2]=0;gAp(9539896,u)}O=c[2384975]|0;M=O-1|0;I=c[2384177]|0,c[2384177]=I+1,I;J=c[2384193]|0;L=c[2384192]|0;H=J-L>>2;do{if(H>>>0>M>>>0){ak=L}else{if(H>>>0<O>>>0){gFZ(9536768,O-H|0);ak=c[2384192]|0;break}if(H>>>0<=O>>>0){ak=L;break}Q=L+(O<<2)|0;if((Q|0)==(J|0)){ak=L;break}c[2384193]=J+(~((J-4+(-Q|0)|0)>>>2)<<2);ak=L}}while(0);L=c[ak+(M<<2)>>2]|0;if((L|0)==0){al=ak}else{J=L+4|0;if(((I=c[J>>2]|0,c[J>>2]=I+ -1,I)|0)==0){gf[c[(c[L>>2]|0)+8>>2]&2047](L|0)}al=c[2384192]|0}c[al+(M<<2)>>2]=9536704;c[2384175]=0;c[2384174]=620640;if((c[2384972]|0)!=-1){c[t>>2]=9539888;c[t+4>>2]=180;c[t+8>>2]=0;gAp(9539888,t)}L=c[2384973]|0;J=L-1|0;I=c[2384175]|0,c[2384175]=I+1,I;O=c[2384193]|0;H=c[2384192]|0;N=O-H>>2;do{if(N>>>0>J>>>0){am=H}else{if(N>>>0<L>>>0){gFZ(9536768,L-N|0);am=c[2384192]|0;break}if(N>>>0<=L>>>0){am=H;break}Q=H+(L<<2)|0;if((Q|0)==(O|0)){am=H;break}c[2384193]=O+(~((O-4+(-Q|0)|0)>>>2)<<2);am=H}}while(0);H=c[am+(J<<2)>>2]|0;if((H|0)==0){an=am}else{O=H+4|0;if(((I=c[O>>2]|0,c[O>>2]=I+ -1,I)|0)==0){gf[c[(c[H>>2]|0)+8>>2]&2047](H|0)}an=c[2384192]|0}c[an+(J<<2)>>2]=9536696;c[2384173]=0;c[2384172]=620576;if((c[2384970]|0)!=-1){c[s>>2]=9539880;c[s+4>>2]=180;c[s+8>>2]=0;gAp(9539880,s)}H=c[2384971]|0;O=H-1|0;I=c[2384173]|0,c[2384173]=I+1,I;L=c[2384193]|0;N=c[2384192]|0;M=L-N>>2;do{if(M>>>0>O>>>0){ao=N}else{if(M>>>0<H>>>0){gFZ(9536768,H-M|0);ao=c[2384192]|0;break}if(M>>>0<=H>>>0){ao=N;break}Q=N+(H<<2)|0;if((Q|0)==(L|0)){ao=N;break}c[2384193]=L+(~((L-4+(-Q|0)|0)>>>2)<<2);ao=N}}while(0);N=c[ao+(O<<2)>>2]|0;if((N|0)==0){ap=ao}else{L=N+4|0;if(((I=c[L>>2]|0,c[L>>2]=I+ -1,I)|0)==0){gf[c[(c[N>>2]|0)+8>>2]&2047](N|0)}ap=c[2384192]|0}c[ap+(O<<2)>>2]=9536688;c[2384243]=0;c[2384242]=622224;if((c[2385180]|0)!=-1){c[r>>2]=9540720;c[r+4>>2]=180;c[r+8>>2]=0;gAp(9540720,r)}N=c[2385181]|0;L=N-1|0;I=c[2384243]|0,c[2384243]=I+1,I;H=c[2384193]|0;M=c[2384192]|0;J=H-M>>2;do{if(J>>>0>L>>>0){aq=M}else{if(J>>>0<N>>>0){gFZ(9536768,N-J|0);aq=c[2384192]|0;break}if(J>>>0<=N>>>0){aq=M;break}Q=M+(N<<2)|0;if((Q|0)==(H|0)){aq=M;break}c[2384193]=H+(~((H-4+(-Q|0)|0)>>>2)<<2);aq=M}}while(0);M=c[aq+(L<<2)>>2]|0;if((M|0)==0){ar=aq}else{H=M+4|0;if(((I=c[H>>2]|0,c[H>>2]=I+ -1,I)|0)==0){gf[c[(c[M>>2]|0)+8>>2]&2047](M|0)}ar=c[2384192]|0}c[ar+(L<<2)>>2]=9536968;c[2384241]=0;c[2384240]=622160;if((c[2385178]|0)!=-1){c[q>>2]=9540712;c[q+4>>2]=180;c[q+8>>2]=0;gAp(9540712,q)}M=c[2385179]|0;H=M-1|0;I=c[2384241]|0,c[2384241]=I+1,I;N=c[2384193]|0;J=c[2384192]|0;O=N-J>>2;do{if(O>>>0>H>>>0){as=J}else{if(O>>>0<M>>>0){gFZ(9536768,M-O|0);as=c[2384192]|0;break}if(O>>>0<=M>>>0){as=J;break}Q=J+(M<<2)|0;if((Q|0)==(N|0)){as=J;break}c[2384193]=N+(~((N-4+(-Q|0)|0)>>>2)<<2);as=J}}while(0);J=c[as+(H<<2)>>2]|0;if((J|0)==0){at=as}else{N=J+4|0;if(((I=c[N>>2]|0,c[N>>2]=I+ -1,I)|0)==0){gf[c[(c[J>>2]|0)+8>>2]&2047](J|0)}at=c[2384192]|0}c[at+(H<<2)>>2]=9536960;c[2384239]=0;c[2384238]=622096;if((c[2385176]|0)!=-1){c[p>>2]=9540704;c[p+4>>2]=180;c[p+8>>2]=0;gAp(9540704,p)}J=c[2385177]|0;N=J-1|0;I=c[2384239]|0,c[2384239]=I+1,I;M=c[2384193]|0;O=c[2384192]|0;L=M-O>>2;do{if(L>>>0>N>>>0){au=O}else{if(L>>>0<J>>>0){gFZ(9536768,J-L|0);au=c[2384192]|0;break}if(L>>>0<=J>>>0){au=O;break}Q=O+(J<<2)|0;if((Q|0)==(M|0)){au=O;break}c[2384193]=M+(~((M-4+(-Q|0)|0)>>>2)<<2);au=O}}while(0);O=c[au+(N<<2)>>2]|0;if((O|0)==0){av=au}else{M=O+4|0;if(((I=c[M>>2]|0,c[M>>2]=I+ -1,I)|0)==0){gf[c[(c[O>>2]|0)+8>>2]&2047](O|0)}av=c[2384192]|0}c[av+(N<<2)>>2]=9536952;c[2384237]=0;c[2384236]=622032;if((c[2385174]|0)!=-1){c[o>>2]=9540696;c[o+4>>2]=180;c[o+8>>2]=0;gAp(9540696,o)}O=c[2385175]|0;M=O-1|0;I=c[2384237]|0,c[2384237]=I+1,I;J=c[2384193]|0;L=c[2384192]|0;H=J-L>>2;do{if(H>>>0>M>>>0){aw=L}else{if(H>>>0<O>>>0){gFZ(9536768,O-H|0);aw=c[2384192]|0;break}if(H>>>0<=O>>>0){aw=L;break}Q=L+(O<<2)|0;if((Q|0)==(J|0)){aw=L;break}c[2384193]=J+(~((J-4+(-Q|0)|0)>>>2)<<2);aw=L}}while(0);L=c[aw+(M<<2)>>2]|0;if((L|0)==0){ax=aw}else{J=L+4|0;if(((I=c[J>>2]|0,c[J>>2]=I+ -1,I)|0)==0){gf[c[(c[L>>2]|0)+8>>2]&2047](L|0)}ax=c[2384192]|0}c[ax+(M<<2)>>2]=9536944;c[2384161]=0;c[2384160]=620048;if((c[2384952]|0)!=-1){c[n>>2]=9539808;c[n+4>>2]=180;c[n+8>>2]=0;gAp(9539808,n)}L=c[2384953]|0;J=L-1|0;I=c[2384161]|0,c[2384161]=I+1,I;O=c[2384193]|0;H=c[2384192]|0;N=O-H>>2;do{if(N>>>0>J>>>0){ay=H}else{if(N>>>0<L>>>0){gFZ(9536768,L-N|0);ay=c[2384192]|0;break}if(N>>>0<=L>>>0){ay=H;break}Q=H+(L<<2)|0;if((Q|0)==(O|0)){ay=H;break}c[2384193]=O+(~((O-4+(-Q|0)|0)>>>2)<<2);ay=H}}while(0);H=c[ay+(J<<2)>>2]|0;if((H|0)==0){az=ay}else{O=H+4|0;if(((I=c[O>>2]|0,c[O>>2]=I+ -1,I)|0)==0){gf[c[(c[H>>2]|0)+8>>2]&2047](H|0)}az=c[2384192]|0}c[az+(J<<2)>>2]=9536640;c[2384159]=0;c[2384158]=620008;if((c[2384950]|0)!=-1){c[m>>2]=9539800;c[m+4>>2]=180;c[m+8>>2]=0;gAp(9539800,m)}H=c[2384951]|0;O=H-1|0;I=c[2384159]|0,c[2384159]=I+1,I;L=c[2384193]|0;N=c[2384192]|0;M=L-N>>2;do{if(M>>>0>O>>>0){aA=N}else{if(M>>>0<H>>>0){gFZ(9536768,H-M|0);aA=c[2384192]|0;break}if(M>>>0<=H>>>0){aA=N;break}Q=N+(H<<2)|0;if((Q|0)==(L|0)){aA=N;break}c[2384193]=L+(~((L-4+(-Q|0)|0)>>>2)<<2);aA=N}}while(0);N=c[aA+(O<<2)>>2]|0;if((N|0)==0){aB=aA}else{L=N+4|0;if(((I=c[L>>2]|0,c[L>>2]=I+ -1,I)|0)==0){gf[c[(c[N>>2]|0)+8>>2]&2047](N|0)}aB=c[2384192]|0}c[aB+(O<<2)>>2]=9536632;c[2384157]=0;c[2384156]=619968;if((c[2384948]|0)!=-1){c[l>>2]=9539792;c[l+4>>2]=180;c[l+8>>2]=0;gAp(9539792,l)}N=c[2384949]|0;L=N-1|0;I=c[2384157]|0,c[2384157]=I+1,I;H=c[2384193]|0;M=c[2384192]|0;J=H-M>>2;do{if(J>>>0>L>>>0){aC=M}else{if(J>>>0<N>>>0){gFZ(9536768,N-J|0);aC=c[2384192]|0;break}if(J>>>0<=N>>>0){aC=M;break}Q=M+(N<<2)|0;if((Q|0)==(H|0)){aC=M;break}c[2384193]=H+(~((H-4+(-Q|0)|0)>>>2)<<2);aC=M}}while(0);M=c[aC+(L<<2)>>2]|0;if((M|0)==0){aD=aC}else{H=M+4|0;if(((I=c[H>>2]|0,c[H>>2]=I+ -1,I)|0)==0){gf[c[(c[M>>2]|0)+8>>2]&2047](M|0)}aD=c[2384192]|0}c[aD+(L<<2)>>2]=9536624;c[2384155]=0;c[2384154]=619928;if((c[2384946]|0)!=-1){c[k>>2]=9539784;c[k+4>>2]=180;c[k+8>>2]=0;gAp(9539784,k)}M=c[2384947]|0;H=M-1|0;I=c[2384155]|0,c[2384155]=I+1,I;N=c[2384193]|0;J=c[2384192]|0;O=N-J>>2;do{if(O>>>0>H>>>0){aE=J}else{if(O>>>0<M>>>0){gFZ(9536768,M-O|0);aE=c[2384192]|0;break}if(O>>>0<=M>>>0){aE=J;break}Q=J+(M<<2)|0;if((Q|0)==(N|0)){aE=J;break}c[2384193]=N+(~((N-4+(-Q|0)|0)>>>2)<<2);aE=J}}while(0);J=c[aE+(H<<2)>>2]|0;if((J|0)==0){aF=aE}else{N=J+4|0;if(((I=c[N>>2]|0,c[N>>2]=I+ -1,I)|0)==0){gf[c[(c[J>>2]|0)+8>>2]&2047](J|0)}aF=c[2384192]|0}c[aF+(H<<2)>>2]=9536616;c[147699]=0;c[147698]=620248;c[147700]=620296;if((c[2384960]|0)!=-1){c[j>>2]=9539840;c[j+4>>2]=180;c[j+8>>2]=0;gAp(9539840,j)}J=c[2384961]|0;N=J-1|0;I=c[147699]|0,c[147699]=I+1,I;M=c[2384193]|0;O=c[2384192]|0;L=M-O>>2;do{if(L>>>0>N>>>0){aG=O}else{if(L>>>0<J>>>0){gFZ(9536768,J-L|0);aG=c[2384192]|0;break}if(L>>>0<=J>>>0){aG=O;break}Q=O+(J<<2)|0;if((Q|0)==(M|0)){aG=O;break}c[2384193]=M+(~((M-4+(-Q|0)|0)>>>2)<<2);aG=O}}while(0);O=c[aG+(N<<2)>>2]|0;if((O|0)==0){aH=aG}else{M=O+4|0;if(((I=c[M>>2]|0,c[M>>2]=I+ -1,I)|0)==0){gf[c[(c[O>>2]|0)+8>>2]&2047](O|0)}aH=c[2384192]|0}c[aH+(N<<2)>>2]=590792;c[147695]=0;c[147694]=620152;c[147696]=620200;if((c[2384958]|0)!=-1){c[h>>2]=9539832;c[h+4>>2]=180;c[h+8>>2]=0;gAp(9539832,h)}O=c[2384959]|0;M=O-1|0;I=c[147695]|0,c[147695]=I+1,I;J=c[2384193]|0;L=c[2384192]|0;H=J-L>>2;do{if(H>>>0>M>>>0){aI=L}else{if(H>>>0<O>>>0){gFZ(9536768,O-H|0);aI=c[2384192]|0;break}if(H>>>0<=O>>>0){aI=L;break}Q=L+(O<<2)|0;if((Q|0)==(J|0)){aI=L;break}c[2384193]=J+(~((J-4+(-Q|0)|0)>>>2)<<2);aI=L}}while(0);L=c[aI+(M<<2)>>2]|0;if((L|0)==0){aJ=aI}else{J=L+4|0;if(((I=c[J>>2]|0,c[J>>2]=I+ -1,I)|0)==0){gf[c[(c[L>>2]|0)+8>>2]&2047](L|0)}aJ=c[2384192]|0}c[aJ+(M<<2)>>2]=590776;c[147691]=0;c[147690]=621152;do{if((a[14125e3]|0)==0){if((bp(14125e3)|0)==0){break}c[2384150]=e6(2147483647,485280,0)|0}}while(0);c[147692]=c[2384150];c[147690]=620120;if((c[2384956]|0)!=-1){c[g>>2]=9539824;c[g+4>>2]=180;c[g+8>>2]=0;gAp(9539824,g)}M=c[2384957]|0;L=M-1|0;I=c[147691]|0,c[147691]=I+1,I;J=c[2384193]|0;O=c[2384192]|0;H=J-O>>2;do{if(H>>>0>L>>>0){aK=O}else{if(H>>>0<M>>>0){gFZ(9536768,M-H|0);aK=c[2384192]|0;break}if(H>>>0<=M>>>0){aK=O;break}N=O+(M<<2)|0;if((N|0)==(J|0)){aK=O;break}c[2384193]=J+(~((J-4+(-N|0)|0)>>>2)<<2);aK=O}}while(0);O=c[aK+(L<<2)>>2]|0;if((O|0)==0){aL=aK}else{J=O+4|0;if(((I=c[J>>2]|0,c[J>>2]=I+ -1,I)|0)==0){gf[c[(c[O>>2]|0)+8>>2]&2047](O|0)}aL=c[2384192]|0}c[aL+(L<<2)>>2]=590760;c[147687]=0;c[147686]=621152;do{if((a[14125e3]|0)==0){if((bp(14125e3)|0)==0){break}c[2384150]=e6(2147483647,485280,0)|0}}while(0);c[147688]=c[2384150];c[147686]=620088;if((c[2384954]|0)!=-1){c[f>>2]=9539816;c[f+4>>2]=180;c[f+8>>2]=0;gAp(9539816,f)}L=c[2384955]|0;O=L-1|0;I=c[147687]|0,c[147687]=I+1,I;J=c[2384193]|0;M=c[2384192]|0;H=J-M>>2;do{if(H>>>0>O>>>0){aM=M}else{if(H>>>0<L>>>0){gFZ(9536768,L-H|0);aM=c[2384192]|0;break}if(H>>>0<=L>>>0){aM=M;break}N=M+(L<<2)|0;if((N|0)==(J|0)){aM=M;break}c[2384193]=J+(~((J-4+(-N|0)|0)>>>2)<<2);aM=M}}while(0);M=c[aM+(O<<2)>>2]|0;if((M|0)==0){aN=aM}else{J=M+4|0;if(((I=c[J>>2]|0,c[J>>2]=I+ -1,I)|0)==0){gf[c[(c[M>>2]|0)+8>>2]&2047](M|0)}aN=c[2384192]|0}c[aN+(O<<2)>>2]=590744;c[2384171]=0;c[2384170]=620480;if((c[2384968]|0)!=-1){c[e>>2]=9539872;c[e+4>>2]=180;c[e+8>>2]=0;gAp(9539872,e)}M=c[2384969]|0;J=M-1|0;I=c[2384171]|0,c[2384171]=I+1,I;L=c[2384193]|0;H=c[2384192]|0;N=L-H>>2;do{if(N>>>0>J>>>0){aO=H}else{if(N>>>0<M>>>0){gFZ(9536768,M-N|0);aO=c[2384192]|0;break}if(N>>>0<=M>>>0){aO=H;break}Q=H+(M<<2)|0;if((Q|0)==(L|0)){aO=H;break}c[2384193]=L+(~((L-4+(-Q|0)|0)>>>2)<<2);aO=H}}while(0);H=c[aO+(J<<2)>>2]|0;if((H|0)==0){aP=aO}else{L=H+4|0;if(((I=c[L>>2]|0,c[L>>2]=I+ -1,I)|0)==0){gf[c[(c[H>>2]|0)+8>>2]&2047](H|0)}aP=c[2384192]|0}c[aP+(J<<2)>>2]=9536680;c[2384169]=0;c[2384168]=620440;if((c[2384966]|0)!=-1){c[d>>2]=9539864;c[d+4>>2]=180;c[d+8>>2]=0;gAp(9539864,d)}H=c[2384967]|0;L=H-1|0;I=c[2384169]|0,c[2384169]=I+1,I;M=c[2384193]|0;N=c[2384192]|0;O=M-N>>2;do{if(O>>>0>L>>>0){aQ=N}else{if(O>>>0<H>>>0){gFZ(9536768,H-O|0);aQ=c[2384192]|0;break}if(O>>>0<=H>>>0){aQ=N;break}Q=N+(H<<2)|0;if((Q|0)==(M|0)){aQ=N;break}c[2384193]=M+(~((M-4+(-Q|0)|0)>>>2)<<2);aQ=N}}while(0);N=c[aQ+(L<<2)>>2]|0;if((N|0)==0){aR=aQ}else{M=N+4|0;if(((I=c[M>>2]|0,c[M>>2]=I+ -1,I)|0)==0){gf[c[(c[N>>2]|0)+8>>2]&2047](N|0)}aR=c[2384192]|0}c[aR+(L<<2)>>2]=9536672;c[2384146]=9536760}}while(0);aR=c[2384146]|0;c[2384148]=aR;aQ=aR+4|0;I=c[aQ>>2]|0,c[aQ>>2]=I+1,I;c[2384144]=9536592;G=c[2384144]|0;i=b;return G|0}function gEs(a){a=a|0;if((a|0)==0){return}gGr(a);return}function gEt(a){a=a|0;if((a|0)==0){return}gf[c[(c[a>>2]|0)+4>>2]&2047](a);return}function gEu(a){a=a|0;c[a+4>>2]=(I=c[2384990]|0,c[2384990]=I+1,I)+1;return}function gEv(a){a=a|0;if((a|0)==0){return}gGr(a);return}function gEw(a,d,e){a=a|0;d=d|0;e=e|0;var f=0;if(e>>>0>=128){f=0;return f|0}f=(b[(c[(cD()|0)>>2]|0)+(e<<1)>>1]&d)<<16>>16!=0;return f|0}function gEx(a,d,e,f){a=a|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;if((d|0)==(e|0)){g=d;return g|0}else{h=d;i=f}while(1){f=c[h>>2]|0;if(f>>>0<128){j=b[(c[(cD()|0)>>2]|0)+(f<<1)>>1]|0}else{j=0}b[i>>1]=j;f=h+4|0;if((f|0)==(e|0)){g=e;break}else{h=f;i=i+2|0}}return g|0}function gEy(a,d,e,f){a=a|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;if((e|0)==(f|0)){g=e;return g|0}else{h=e}while(1){e=c[h>>2]|0;if(e>>>0<128){if((b[(c[(cD()|0)>>2]|0)+(e<<1)>>1]&d)<<16>>16!=0){g=h;i=13698;break}}e=h+4|0;if((e|0)==(f|0)){g=f;i=13699;break}else{h=e}}if((i|0)==13699){return g|0}else if((i|0)==13698){return g|0}return 0}function gEz(a,d,e,f){a=a|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=e;while(1){if((a|0)==(f|0)){g=f;h=13709;break}e=c[a>>2]|0;if(e>>>0>=128){g=a;h=13707;break}if((b[(c[(cD()|0)>>2]|0)+(e<<1)>>1]&d)<<16>>16==0){g=a;h=13708;break}else{a=a+4|0}}if((h|0)==13709){return g|0}else if((h|0)==13707){return g|0}else if((h|0)==13708){return g|0}return 0}function gEA(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>=128){d=b;return d|0}d=c[(c[(f2()|0)>>2]|0)+(b<<2)>>2]|0;return d|0}function gEB(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;if((b|0)==(d|0)){e=b;return e|0}else{f=b}while(1){b=c[f>>2]|0;if(b>>>0<128){g=c[(c[(f2()|0)>>2]|0)+(b<<2)>>2]|0}else{g=b}c[f>>2]=g;b=f+4|0;if((b|0)==(d|0)){e=d;break}else{f=b}}return e|0}function gEC(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>=128){d=b;return d|0}d=c[(c[(eP()|0)>>2]|0)+(b<<2)>>2]|0;return d|0}function gED(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;if((b|0)==(d|0)){e=b;return e|0}else{f=b}while(1){b=c[f>>2]|0;if(b>>>0<128){g=c[(c[(eP()|0)>>2]|0)+(b<<2)>>2]|0}else{g=b}c[f>>2]=g;b=f+4|0;if((b|0)==(d|0)){e=d;break}else{f=b}}return e|0}function gEE(a,b){a=a|0;b=b|0;return b<<24>>24|0}function gEF(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;if((d|0)==(e|0)){g=d;return g|0}else{h=d;i=f}while(1){c[i>>2]=a[h]|0;f=h+1|0;if((f|0)==(e|0)){g=e;break}else{h=f;i=i+4|0}}return g|0}function gEG(a,b,c){a=a|0;b=b|0;c=c|0;return(b>>>0<128?b&255:c)|0}function gEH(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0;if((d|0)==(e|0)){h=d;return h|0}b=(e-4+(-d|0)|0)>>>2;i=d;j=g;while(1){g=c[i>>2]|0;a[j]=g>>>0<128?g&255:f;g=i+4|0;if((g|0)==(e|0)){break}else{i=g;j=j+1|0}}h=d+(b+1<<2)|0;return h|0}function gEI(b){b=b|0;var d=0;c[b>>2]=621296;d=c[b+8>>2]|0;do{if((d|0)!=0){if((a[b+12|0]&1)!=0){gGr(d)}if((b|0)!=0){break}return}}while(0);gGr(b);return}function gEJ(b){b=b|0;var d=0;c[b>>2]=621296;d=c[b+8>>2]|0;if((d|0)==0){return}if((a[b+12|0]&1)==0){return}gGr(d);return}function gEK(a,b){a=a|0;b=b|0;var d=0;if(b<<24>>24<0){d=b;return d|0}d=c[(c[(f2()|0)>>2]|0)+((b&255)<<2)>>2]&255;return d|0}function gEL(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0;if((d|0)==(e|0)){f=d;return f|0}else{g=d}while(1){d=a[g]|0;if(d<<24>>24<0){h=d}else{h=c[(c[(f2()|0)>>2]|0)+(d<<24>>24<<2)>>2]&255}a[g]=h;d=g+1|0;if((d|0)==(e|0)){f=e;break}else{g=d}}return f|0}function gEM(a,b){a=a|0;b=b|0;var d=0;if(b<<24>>24<0){d=b;return d|0}d=c[(c[(eP()|0)>>2]|0)+(b<<24>>24<<2)>>2]&255;return d|0}function gEN(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0;if((d|0)==(e|0)){f=d;return f|0}else{g=d}while(1){d=a[g]|0;if(d<<24>>24<0){h=d}else{h=c[(c[(eP()|0)>>2]|0)+(d<<24>>24<<2)>>2]&255}a[g]=h;d=g+1|0;if((d|0)==(e|0)){f=e;break}else{g=d}}return f|0}function gEO(a,b){a=a|0;b=b|0;return b|0}function gEP(b,c,d,e){b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;if((c|0)==(d|0)){f=c;return f|0}else{g=c;h=e}while(1){a[h]=a[g]|0;e=g+1|0;if((e|0)==(d|0)){f=d;break}else{g=e;h=h+1|0}}return f|0}function gEQ(a,b,c){a=a|0;b=b|0;c=c|0;return(b<<24>>24<0?c:b)|0}function gER(b,c,d,e,f){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;if((c|0)==(d|0)){g=c;return g|0}else{h=c;i=f}while(1){f=a[h]|0;a[i]=f<<24>>24<0?e:f;f=h+1|0;if((f|0)==(d|0)){g=d;break}else{h=f;i=i+1|0}}return g|0}function gES(a){a=a|0;if((a|0)==0){return}gGr(a);return}function gET(a,b,d,e,f,g,h,i){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;c[f>>2]=d;c[i>>2]=g;return 3}function gEU(a,b,d,e,f,g,h,i){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;c[f>>2]=d;c[i>>2]=g;return 3}function gEV(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;c[f>>2]=d;return 3}function gEW(a){a=a|0;return 1}function gEX(a){a=a|0;return 1}function gEY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;b=d-c|0;return(b>>>0<e>>>0?b:e)|0}function gEZ(a){a=a|0;return 1}function gE_(b){b=b|0;var d=0,e=0;c[b>>2]=620928;d=b+8|0;e=c[d>>2]|0;do{if((a[14125e3]|0)==0){if((bp(14125e3)|0)==0){break}c[2384150]=e6(2147483647,485280,0)|0}}while(0);if((e|0)!=(c[2384150]|0)){d4(c[d>>2]|0)}if((b|0)==0){return}gGr(b);return}function gE$(b,d,e,f,g,h,j,k){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0;d=i;i=i+264|0;l=d|0;m=d+8|0;n=e;while(1){if((n|0)==(f|0)){o=f;break}if((c[n>>2]|0)==0){o=n;break}else{n=n+4|0}}c[k>>2]=h;c[g>>2]=e;L15915:do{if((e|0)==(f|0)|(h|0)==(j|0)){p=e}else{n=j;q=b+8|0;r=m|0;s=l|0;t=h;u=e;v=o;while(1){w=v-u>>2;x=fN(c[q>>2]|0)|0;y=c[g>>2]|0;z=(t|0)!=0;A=z?n-t|0:256;B=z?t:r;L15919:do{if((y|0)==0|(A|0)==0){C=0;D=w;E=A;F=B;G=y}else{H=A;I=w;J=0;K=B;L=y;while(1){M=I>>>0>=H>>>0;if(!(M|I>>>0>32)){C=J;D=I;E=H;F=K;G=L;break L15919}N=M?H:I;M=I-N|0;L15923:do{if((K|0)==0){O=c[L>>2]|0;if((O|0)==0){P=0;Q=L;break}else{R=0;S=L;T=O}while(1){if(T>>>0>127){O=gF6(s,T)|0;if((O|0)==-1){C=-1;D=M;E=0;F=K;G=L;break L15919}else{U=O}}else{U=1}O=U+R|0;V=S+4|0;W=c[V>>2]|0;if((W|0)==0){X=O;Y=L;Z=13871;break}else{R=O;S=V;T=W}}}else{L15931:do{if(N>>>0>3){W=N;V=K;O=L;while(1){_=c[O>>2]|0;if((_|0)==0){$=W;aa=V;ab=O;Z=13861;break L15931}if(_>>>0>127){ac=gF6(V,_)|0;if((ac|0)==-1){C=-1;D=M;E=0;F=K;G=O;break L15919}ad=V+ac|0;ae=W-ac|0;af=O}else{a[V]=_&255;ad=V+1|0;ae=W-1|0;af=O}_=af+4|0;if(ae>>>0>3){W=ae;V=ad;O=_}else{ag=ae;ah=ad;ai=_;Z=13855;break}}}else{ag=N;ah=K;ai=L;Z=13855}}while(0);if((Z|0)==13855){Z=0;if((ag|0)==0){aj=0}else{$=ag;aa=ah;ab=ai;Z=13861}}L15942:do{if((Z|0)==13861){while(1){Z=0;O=c[ab>>2]|0;if((O|0)==0){Z=13869;break}if(O>>>0>127){V=gF6(s,O)|0;if((V|0)==-1){C=-1;D=M;E=0;F=K;G=ab;break L15919}if(V>>>0>$>>>0){Z=13865;break}W=c[ab>>2]|0;gF6(aa,W)|0;ak=aa+V|0;al=$-V|0;am=ab}else{a[aa]=O&255;ak=aa+1|0;al=$-1|0;am=ab}if((al|0)==0){aj=0;break L15942}else{$=al;aa=ak;ab=am+4|0;Z=13861}}if((Z|0)==13865){Z=0;X=N-$|0;Y=ab;Z=13871;break L15923}else if((Z|0)==13869){Z=0;a[aa]=0;aj=$;break}}}while(0);X=N-aj|0;Y=0;Z=13871}}while(0);if((Z|0)==13871){Z=0;if((X|0)==-1){C=-1;D=M;E=0;F=K;G=Y;break L15919}else{P=X;Q=Y}}if((K|0)==(r|0)){an=r;ao=H}else{an=K+P|0;ao=H-P|0}N=P+J|0;if((Q|0)==0|(ao|0)==0){C=N;D=M;E=ao;F=an;G=Q;break}else{H=ao;I=M;J=N;K=an;L=Q}}}}while(0);L15963:do{if((G|0)==0){ap=C;aq=0}else{if((E|0)==0|(D|0)==0){ap=C;aq=G;break}else{ar=E;as=D;at=C;au=F;av=G}while(1){aw=gF6(au,c[av>>2]|0)|0;if((aw+1|0)>>>0<2){break}y=av+4|0;B=as-1|0;w=at+1|0;if((ar|0)==(aw|0)|(B|0)==0){ap=w;aq=y;break L15963}else{ar=ar-aw|0;as=B;at=w;au=au+aw|0;av=y}}y=(aw|0)==0;ap=y?at:-1;aq=y?0:av}}while(0);if(z){c[g>>2]=aq}if((x|0)!=0){fN(x|0)|0}if((ap|0)==(-1|0)){Z=13886;break}else if((ap|0)==0){ax=1;Z=13909;break}y=(c[k>>2]|0)+ap|0;c[k>>2]=y;if((y|0)==(j|0)){Z=13905;break}if((v|0)==(f|0)){ay=f;az=y;aA=c[g>>2]|0}else{y=fN(c[q>>2]|0)|0;if((y|0)!=0){fN(y|0)|0}y=c[k>>2]|0;if((y|0)==(j|0)){ax=1;Z=13910;break}c[k>>2]=y+1;a[y]=0;y=(c[g>>2]|0)+4|0;c[g>>2]=y;w=y;while(1){if((w|0)==(f|0)){aB=f;break}if((c[w>>2]|0)==0){aB=w;break}else{w=w+4|0}}ay=aB;az=c[k>>2]|0;aA=y}if((aA|0)==(f|0)|(az|0)==(j|0)){p=aA;break L15915}else{t=az;u=aA;v=ay}}if((Z|0)==13886){c[k>>2]=t;L15992:do{if((u|0)==(c[g>>2]|0)){aC=u}else{v=u;r=t;while(1){s=c[v>>2]|0;n=fN(c[q>>2]|0)|0;w=gF6(r,s)|0;if((n|0)!=0){fN(n|0)|0}if((w|0)==-1){aC=v;break L15992}n=(c[k>>2]|0)+w|0;c[k>>2]=n;w=v+4|0;if((w|0)==(c[g>>2]|0)){aC=w;break}else{v=w;r=n}}}}while(0);c[g>>2]=aC;ax=2;i=d;return ax|0}else if((Z|0)==13905){p=c[g>>2]|0;break}else if((Z|0)==13909){i=d;return ax|0}else if((Z|0)==13910){i=d;return ax|0}}}while(0);ax=(p|0)!=(f|0)|0;i=d;return ax|0}function gE0(b,d,e,f,g,h,j,k){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0;l=i;i=i+1040|0;m=l|0;n=l+1024|0;o=l+1032|0;p=o;q=e;while(1){if((q|0)==(f|0)){r=f;break}if((a[q]|0)==0){r=q;break}else{q=q+1|0}}c[k>>2]=h;c[g>>2]=e;L16011:do{if((e|0)==(f|0)|(h|0)==(j|0)){s=e}else{q=d;t=j;u=b+8|0;v=m|0;w=d|0;x=h;y=e;z=r;while(1){A=c[q+4>>2]|0;c[o>>2]=c[q>>2];c[o+4>>2]=A;B=z;A=B-y|0;C=fN(c[u>>2]|0)|0;D=c[g>>2]|0;c[n>>2]=D;E=(x|0)!=0;F=E?t-x>>2:256;G=E?x:v;L16015:do{if((D|0)==0|(F|0)==0){H=0;I=A;J=F;K=G;L=D}else{M=F;N=A;O=0;P=G;Q=D;while(1){R=N>>>2;S=R>>>0>=M>>>0;if(!(S|N>>>0>131)){H=O;I=N;J=M;K=P;L=Q;break L16015}T=S?M:R;U=N-T|0;R=gF5(P,n,T,d)|0;if((R|0)==-1){break}if((P|0)==(v|0)){V=v;W=M}else{V=P+(R<<2)|0;W=M-R|0}T=R+O|0;R=c[n>>2]|0;if((R|0)==0|(W|0)==0){H=T;I=U;J=W;K=V;L=R;break L16015}else{M=W;N=U;O=T;P=V;Q=R}}H=-1;I=U;J=0;K=P;L=c[n>>2]|0}}while(0);L16025:do{if((L|0)==0){X=H;Y=0}else{if((J|0)==0|(I|0)==0){X=H;Y=L;break}else{Z=J;_=I;$=H;aa=K;ab=L}while(1){ac=gF4(aa,ab,_,d)|0;if((ac+2|0)>>>0<3){break}D=ab+ac|0;c[n>>2]=D;G=Z-1|0;A=$+1|0;if((G|0)==0|(_|0)==(ac|0)){X=A;Y=D;break L16025}else{Z=G;_=_-ac|0;$=A;aa=aa+4|0;ab=D}}if((ac|0)==0){c[n>>2]=0;X=$;Y=0;break}else if((ac|0)==(-1|0)){X=-1;Y=ab;break}else{c[w>>2]=0;X=$;Y=ab;break}}}while(0);if(E){c[g>>2]=Y}if((C|0)!=0){fN(C|0)|0}if((X|0)==(-1|0)){ad=13937;break}else if((X|0)==0){ae=2;ad=13963;break}P=(c[k>>2]|0)+(X<<2)|0;c[k>>2]=P;if((P|0)==(j|0)){ad=13959;break}D=c[g>>2]|0;if((z|0)==(f|0)){af=f;ag=P;ah=D}else{A=fN(c[u>>2]|0)|0;G=gF4(P,D,1,d)|0;if((A|0)!=0){fN(A|0)|0}if((G|0)!=0){ae=2;ad=13966;break}c[k>>2]=(c[k>>2]|0)+4;G=(c[g>>2]|0)+1|0;c[g>>2]=G;A=G;while(1){if((A|0)==(f|0)){ai=f;break}if((a[A]|0)==0){ai=A;break}else{A=A+1|0}}af=ai;ag=c[k>>2]|0;ah=G}if((ah|0)==(f|0)|(ag|0)==(j|0)){s=ah;break L16011}else{x=ag;y=ah;z=af}}if((ad|0)==13937){c[k>>2]=x;L16056:do{if((y|0)==(c[g>>2]|0)){aj=y}else{z=x;w=y;while(1){v=fN(c[u>>2]|0)|0;t=gF4(z,w,B-w|0,p)|0;if((v|0)!=0){fN(v|0)|0}if((t|0)==(-1|0)){ad=13943;break}else if((t|0)==0){ak=w+1|0}else if((t|0)==(-2|0)){ad=13944;break}else{ak=w+t|0}t=(c[k>>2]|0)+4|0;c[k>>2]=t;if((ak|0)==(c[g>>2]|0)){aj=ak;break L16056}else{z=t;w=ak}}if((ad|0)==13943){c[g>>2]=w;ae=2;i=l;return ae|0}else if((ad|0)==13944){c[g>>2]=w;ae=1;i=l;return ae|0}}}while(0);c[g>>2]=aj;ae=(aj|0)!=(f|0)|0;i=l;return ae|0}else if((ad|0)==13963){i=l;return ae|0}else if((ad|0)==13959){s=c[g>>2]|0;break}else if((ad|0)==13966){i=l;return ae|0}}}while(0);ae=(s|0)!=(f|0)|0;i=l;return ae|0}function gE1(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;c[f>>2]=d;d=fN(c[a+8>>2]|0)|0;if((d|0)==0){return 0}fN(d|0)|0;return 0}function gE2(a){a=a|0;var b=0,d=0;b=a+8|0;a=fN(c[b>>2]|0)|0;if((a|0)!=0){fN(a|0)|0}a=c[b>>2]|0;if((a|0)==0){d=1;return d|0}b=fN(a|0)|0;if((b|0)==0){d=0;return d|0}fN(b|0)|0;d=0;return d|0}function gE3(a){a=a|0;return 0}function gE4(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((f|0)==0|(d|0)==(e|0)){g=0;return g|0}h=e;i=a+8|0;a=(b|0)!=0?b:8645368;b=d;d=0;j=0;while(1){k=fN(c[i>>2]|0)|0;l=gF4(0,b,h-b|0,a)|0;if((k|0)!=0){fN(k|0)|0}if((l|0)==0){m=1;n=b+1|0}else if((l|0)==(-1|0)|(l|0)==(-2|0)){g=d;o=14e3;break}else{m=l;n=b+l|0}l=m+d|0;k=j+1|0;if(k>>>0>=f>>>0|(n|0)==(e|0)){g=l;o=14001;break}else{b=n;d=l;j=k}}if((o|0)==14e3){return g|0}else if((o|0)==14001){return g|0}return 0}function gE5(a){a=a|0;var b=0,d=0;b=c[a+8>>2]|0;do{if((b|0)==0){d=1}else{a=fN(b|0)|0;if((a|0)==0){d=4;break}fN(a|0)|0;d=4}}while(0);return d|0}function gE6(a){a=a|0;if((a|0)==0){return}gGr(a);return}function gE7(d,f,g,h,i,j,k,l){d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;f=h;L16125:do{if(g>>>0<h>>>0){d=k;m=j;n=g;while(1){o=b[n>>1]|0;p=o&65535;do{if((o&65535)<128){if((d-m|0)<1){q=1;r=m;s=n;break L16125}a[m]=o&255;t=m+1|0;u=n}else{if((o&65535)<2048){if((d-m|0)<2){q=1;r=m;s=n;break L16125}a[m]=(p>>>6|192)&255;a[m+1|0]=(p&63|128)&255;t=m+2|0;u=n;break}if((o&65535)<55296){if((d-m|0)<3){q=1;r=m;s=n;break L16125}a[m]=(p>>>12|224)&255;a[m+1|0]=(p>>>6&63|128)&255;a[m+2|0]=(p&63|128)&255;t=m+3|0;u=n;break}if((o&65535)>=56320){if((o&65535)<57344){q=2;r=m;s=n;break L16125}if((d-m|0)<3){q=1;r=m;s=n;break L16125}a[m]=(p>>>12|224)&255;a[m+1|0]=(p>>>6&63|128)&255;a[m+2|0]=(p&63|128)&255;t=m+3|0;u=n;break}if((f-n|0)<4){q=1;r=m;s=n;break L16125}v=n+2|0;w=e[v>>1]|0;if((w&64512|0)!=56320){q=2;r=m;s=n;break L16125}if((d-m|0)<4){q=1;r=m;s=n;break L16125}x=p&960;if(((x<<10)+65536|0)>>>0>1114111){q=2;r=m;s=n;break L16125}y=(x>>>6)+1|0;a[m]=(y>>>2|240)&255;a[m+1|0]=(p>>>2&15|y<<4&48|128)&255;a[m+2|0]=(p<<4&48|w>>>6&15|128)&255;a[m+3|0]=(w&63|128)&255;t=m+4|0;u=v}}while(0);p=u+2|0;if(p>>>0<h>>>0){m=t;n=p}else{q=0;r=t;s=p;break}}}else{q=0;r=j;s=g}}while(0);c[i>>2]=g+(s-g>>1<<1);c[l>>2]=j+(r-j);return q|0}function gE8(e,f,g,h,i,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;L16153:do{if(g>>>0<h>>>0){f=h;e=k;m=j;n=g;while(1){if(m>>>0>=k>>>0){o=m;p=n;q=14066;break L16153}r=a[n]|0;s=r&255;do{if(r<<24>>24>-1){b[m>>1]=r&255;t=m;u=n+1|0}else{if((r&255)<194){v=2;w=m;x=n;break L16153}if((r&255)<224){if((f-n|0)<2){v=1;w=m;x=n;break L16153}y=d[n+1|0]|0;if((y&192|0)!=128){v=2;w=m;x=n;break L16153}b[m>>1]=(y&63|s<<6&1984)&65535;t=m;u=n+2|0;break}if((r&255)<240){if((f-n|0)<3){v=1;w=m;x=n;break L16153}y=a[n+1|0]|0;z=a[n+2|0]|0;if((s|0)==237){if((y&-32)<<24>>24!=-128){v=2;w=m;x=n;break L16153}}else if((s|0)==224){if((y&-32)<<24>>24!=-96){v=2;w=m;x=n;break L16153}}else{if((y&-64)<<24>>24!=-128){v=2;w=m;x=n;break L16153}}A=z&255;if((A&192|0)!=128){v=2;w=m;x=n;break L16153}b[m>>1]=((y&255)<<6&4032|s<<12|A&63)&65535;t=m;u=n+3|0;break}if((r&255)>=245){v=2;w=m;x=n;break L16153}if((f-n|0)<4){v=1;w=m;x=n;break L16153}A=a[n+1|0]|0;y=a[n+2|0]|0;z=a[n+3|0]|0;if((s|0)==244){if((A&-16)<<24>>24!=-128){v=2;w=m;x=n;break L16153}}else if((s|0)==240){if((A+112&255)>=48){v=2;w=m;x=n;break L16153}}else{if((A&-64)<<24>>24!=-128){v=2;w=m;x=n;break L16153}}B=y&255;if((B&192|0)!=128){v=2;w=m;x=n;break L16153}y=z&255;if((y&192|0)!=128){v=2;w=m;x=n;break L16153}if((e-m|0)<4){v=1;w=m;x=n;break L16153}z=s&7;C=A&255;if((C<<12&196608|z<<18)>>>0>1114111){v=2;w=m;x=n;break L16153}b[m>>1]=(C<<2&60|B>>>4&3|((C>>>4&3|z<<2)<<6)+16320|55296)&65535;z=m+2|0;b[z>>1]=(B<<6&960|y&63|56320)&65535;t=z;u=n+4|0}}while(0);s=t+2|0;if(u>>>0<h>>>0){m=s;n=u}else{o=s;p=u;q=14066;break}}}else{o=j;p=g;q=14066}}while(0);if((q|0)==14066){v=p>>>0<h>>>0|0;w=o;x=p}c[i>>2]=g+(x-g);c[l>>2]=j+(w-j>>1<<1);return v|0}function gE9(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;c[f>>2]=d;return 3}function gFa(a){a=a|0;return 0}function gFb(a){a=a|0;return 0}function gFc(b,c,d,e,f){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;L16196:do{if(d>>>0<e>>>0&(f|0)!=0){c=e;b=0;g=d;L16198:while(1){h=a[g]|0;i=h&255;do{if(h<<24>>24>-1){j=g+1|0;k=b}else{if((h&255)<194){l=g;break L16196}if((h&255)<224){if((c-g|0)<2){l=g;break L16196}if((a[g+1|0]&-64)<<24>>24!=-128){l=g;break L16196}j=g+2|0;k=b;break}if((h&255)<240){m=g;if((c-m|0)<3){l=g;break L16196}n=a[g+1|0]|0;o=a[g+2|0]|0;if((i|0)==224){if((n&-32)<<24>>24!=-96){p=14084;break L16198}}else if((i|0)==237){if((n&-32)<<24>>24!=-128){p=14086;break L16198}}else{if((n&-64)<<24>>24!=-128){p=14088;break L16198}}if((o&-64)<<24>>24!=-128){l=g;break L16196}j=g+3|0;k=b;break}if((h&255)>=245){l=g;break L16196}q=g;if((c-q|0)<4){l=g;break L16196}if((f-b|0)>>>0<2){l=g;break L16196}o=a[g+1|0]|0;n=a[g+2|0]|0;r=a[g+3|0]|0;if((i|0)==244){if((o&-16)<<24>>24!=-128){p=14098;break L16198}}else if((i|0)==240){if((o+112&255)>=48){p=14096;break L16198}}else{if((o&-64)<<24>>24!=-128){p=14100;break L16198}}if((n&-64)<<24>>24!=-128){l=g;break L16196}if((r&-64)<<24>>24!=-128){l=g;break L16196}if(((o&255)<<12&196608|i<<18&1835008)>>>0>1114111){l=g;break L16196}j=g+4|0;k=b+1|0}}while(0);i=k+1|0;if(j>>>0<e>>>0&i>>>0<f>>>0){b=i;g=j}else{l=j;break L16196}}if((p|0)==14098){s=q-d|0;return s|0}else if((p|0)==14084){s=m-d|0;return s|0}else if((p|0)==14086){s=m-d|0;return s|0}else if((p|0)==14088){s=m-d|0;return s|0}else if((p|0)==14100){s=q-d|0;return s|0}else if((p|0)==14096){s=q-d|0;return s|0}}else{l=d}}while(0);s=l-d|0;return s|0}function gFd(a){a=a|0;return 4}function gFe(a){a=a|0;if((a|0)==0){return}gGr(a);return}function gFf(b,d,e,f,g,h,i,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0;L16253:do{if(e>>>0<f>>>0){d=i;b=h;k=e;while(1){l=c[k>>2]|0;if((l&-2048|0)==55296|l>>>0>1114111){m=2;n=b;o=k;break L16253}do{if(l>>>0<128){if((d-b|0)<1){m=1;n=b;o=k;break L16253}a[b]=l&255;p=b+1|0}else{if(l>>>0<2048){if((d-b|0)<2){m=1;n=b;o=k;break L16253}a[b]=(l>>>6|192)&255;a[b+1|0]=(l&63|128)&255;p=b+2|0;break}q=d-b|0;if(l>>>0<65536){if((q|0)<3){m=1;n=b;o=k;break L16253}a[b]=(l>>>12|224)&255;a[b+1|0]=(l>>>6&63|128)&255;a[b+2|0]=(l&63|128)&255;p=b+3|0;break}else{if((q|0)<4){m=1;n=b;o=k;break L16253}a[b]=(l>>>18|240)&255;a[b+1|0]=(l>>>12&63|128)&255;a[b+2|0]=(l>>>6&63|128)&255;a[b+3|0]=(l&63|128)&255;p=b+4|0;break}}}while(0);l=k+4|0;if(l>>>0<f>>>0){b=p;k=l}else{m=0;n=p;o=l;break}}}else{m=0;n=h;o=e}}while(0);c[g>>2]=e+(o-e>>2<<2);c[j>>2]=h+(n-h);return m|0}function gFg(b,e,f,g,h,i,j,k){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;L16274:do{if(f>>>0<g>>>0){e=g;b=i;l=f;while(1){if(b>>>0>=j>>>0){m=b;n=l;o=14166;break L16274}p=a[l]|0;q=p&255;do{if(p<<24>>24>-1){c[b>>2]=q;r=l+1|0}else{if((p&255)<194){s=2;t=b;u=l;break L16274}if((p&255)<224){if((e-l|0)<2){s=1;t=b;u=l;break L16274}v=d[l+1|0]|0;if((v&192|0)!=128){s=2;t=b;u=l;break L16274}c[b>>2]=v&63|q<<6&1984;r=l+2|0;break}if((p&255)<240){if((e-l|0)<3){s=1;t=b;u=l;break L16274}v=a[l+1|0]|0;w=a[l+2|0]|0;if((q|0)==224){if((v&-32)<<24>>24!=-96){s=2;t=b;u=l;break L16274}}else if((q|0)==237){if((v&-32)<<24>>24!=-128){s=2;t=b;u=l;break L16274}}else{if((v&-64)<<24>>24!=-128){s=2;t=b;u=l;break L16274}}x=w&255;if((x&192|0)!=128){s=2;t=b;u=l;break L16274}c[b>>2]=(v&255)<<6&4032|q<<12&61440|x&63;r=l+3|0;break}if((p&255)>=245){s=2;t=b;u=l;break L16274}if((e-l|0)<4){s=1;t=b;u=l;break L16274}x=a[l+1|0]|0;v=a[l+2|0]|0;w=a[l+3|0]|0;if((q|0)==244){if((x&-16)<<24>>24!=-128){s=2;t=b;u=l;break L16274}}else if((q|0)==240){if((x+112&255)>=48){s=2;t=b;u=l;break L16274}}else{if((x&-64)<<24>>24!=-128){s=2;t=b;u=l;break L16274}}y=v&255;if((y&192|0)!=128){s=2;t=b;u=l;break L16274}v=w&255;if((v&192|0)!=128){s=2;t=b;u=l;break L16274}w=(x&255)<<12&258048|q<<18&1835008|y<<6&4032|v&63;if(w>>>0>1114111){s=2;t=b;u=l;break L16274}c[b>>2]=w;r=l+4|0}}while(0);q=b+4|0;if(r>>>0<g>>>0){b=q;l=r}else{m=q;n=r;o=14166;break}}}else{m=i;n=f;o=14166}}while(0);if((o|0)==14166){s=n>>>0<g>>>0|0;t=m;u=n}c[h>>2]=f+(u-f);c[k>>2]=i+(t-i>>2<<2);return s|0}function gFh(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;c[f>>2]=d;return 3}function gFi(a){a=a|0;return 0}function gFj(a){a=a|0;return 0}function gFk(b,c,d,e,f){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;L16316:do{if(d>>>0<e>>>0&(f|0)!=0){c=e;b=1;g=d;L16318:while(1){h=a[g]|0;i=h&255;do{if(h<<24>>24>-1){j=g+1|0}else{if((h&255)<194){k=g;break L16316}if((h&255)<224){if((c-g|0)<2){k=g;break L16316}if((a[g+1|0]&-64)<<24>>24!=-128){k=g;break L16316}j=g+2|0;break}if((h&255)<240){l=g;if((c-l|0)<3){k=g;break L16316}m=a[g+1|0]|0;n=a[g+2|0]|0;if((i|0)==224){if((m&-32)<<24>>24!=-96){o=14184;break L16318}}else if((i|0)==237){if((m&-32)<<24>>24!=-128){o=14186;break L16318}}else{if((m&-64)<<24>>24!=-128){o=14188;break L16318}}if((n&-64)<<24>>24!=-128){k=g;break L16316}j=g+3|0;break}if((h&255)>=245){k=g;break L16316}p=g;if((c-p|0)<4){k=g;break L16316}n=a[g+1|0]|0;m=a[g+2|0]|0;q=a[g+3|0]|0;if((i|0)==240){if((n+112&255)>=48){o=14195;break L16318}}else if((i|0)==244){if((n&-16)<<24>>24!=-128){o=14197;break L16318}}else{if((n&-64)<<24>>24!=-128){o=14199;break L16318}}if((m&-64)<<24>>24!=-128){k=g;break L16316}if((q&-64)<<24>>24!=-128){k=g;break L16316}if(((n&255)<<12&196608|i<<18&1835008)>>>0>1114111){k=g;break L16316}j=g+4|0}}while(0);if(!(j>>>0<e>>>0&b>>>0<f>>>0)){k=j;break L16316}b=b+1|0;g=j}if((o|0)==14195){r=p-d|0;return r|0}else if((o|0)==14186){r=l-d|0;return r|0}else if((o|0)==14188){r=l-d|0;return r|0}else if((o|0)==14199){r=p-d|0;return r|0}else if((o|0)==14197){r=p-d|0;return r|0}else if((o|0)==14184){r=l-d|0;return r|0}}else{k=d}}while(0);r=k-d|0;return r|0}function gFl(a){a=a|0;return 4}function gFm(a){a=a|0;if((a|0)==0){return}gGr(a);return}function gFn(a){a=a|0;if((a|0)==0){return}gGr(a);return}function gFo(b){b=b|0;var d=0;c[b>>2]=620392;do{if((a[b+12|0]&1)!=0){d=c[b+20>>2]|0;if((d|0)!=0){gGr(d)}if((b|0)!=0){break}return}}while(0);gGr(b);return}function gFp(b){b=b|0;var d=0;c[b>>2]=620392;if((a[b+12|0]&1)==0){return}d=c[b+20>>2]|0;if((d|0)==0){return}gGr(d);return}function gFq(b){b=b|0;var d=0;c[b>>2]=620344;do{if((a[b+16|0]&1)!=0){d=c[b+24>>2]|0;if((d|0)!=0){gGr(d)}if((b|0)!=0){break}return}}while(0);gGr(b);return}function gFr(b){b=b|0;var d=0;c[b>>2]=620344;if((a[b+16|0]&1)==0){return}d=c[b+24>>2]|0;if((d|0)==0){return}gGr(d);return}function gFs(b){b=b|0;return a[b+8|0]|0}function gFt(a){a=a|0;return c[a+8>>2]|0}function gFu(b){b=b|0;return a[b+9|0]|0}function gFv(a){a=a|0;return c[a+12>>2]|0}function gFw(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=d+12|0;if((a[e]&1)==0){f=b;c[f>>2]=c[e>>2];c[f+4>>2]=c[e+4>>2];c[f+8>>2]=c[e+8>>2];return}e=c[d+20>>2]|0;f=c[d+16>>2]|0;if(f>>>0>4294967279){gAq()}do{if(f>>>0<11){a[b]=f<<1&255;g=b+1|0}else{d=f+16&-16;h=(d|0)==0?1:d;while(1){i=gGq(h)|0;if((i|0)!=0){j=14277;break}k=(I=c[2439328]|0,c[2439328]=I+0,I);if((k|0)==0){break}gu[k&16383]()}if((j|0)==14277){c[b+8>>2]=i;c[b>>2]=d|1;c[b+4>>2]=f;g=i;break}h=f_(4)|0;c[h>>2]=619768;eh(h|0,625520,1206)}}while(0);gGC(g|0,e|0,f)|0;a[g+f|0]=0;return}function gFx(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=d+16|0;if((a[e]&1)==0){f=b;c[f>>2]=c[e>>2];c[f+4>>2]=c[e+4>>2];c[f+8>>2]=c[e+8>>2];return}e=c[d+24>>2]|0;f=c[d+20>>2]|0;if(f>>>0>4294967279){gAq()}do{if(f>>>0<11){a[b]=f<<1&255;g=b+1|0}else{d=f+16&-16;h=(d|0)==0?1:d;while(1){i=gGq(h)|0;if((i|0)!=0){j=14299;break}k=(I=c[2439328]|0,c[2439328]=I+0,I);if((k|0)==0){break}gu[k&16383]()}if((j|0)==14299){c[b+8>>2]=i;c[b>>2]=d|1;c[b+4>>2]=f;g=i;break}h=f_(4)|0;c[h>>2]=619768;eh(h|0,625520,1206)}}while(0);gGC(g|0,e|0,f)|0;a[g+f|0]=0;return}function gFy(b,c){b=b|0;c=c|0;c=b;a[b]=8;b=c+1|0;C=1702195828;a[b]=C&255;C=C>>8;a[b+1|0]=C&255;C=C>>8;a[b+2|0]=C&255;C=C>>8;a[b+3|0]=C&255;a[c+5|0]=0;return}function gFz(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;while(1){d=gGq(32)|0;if((d|0)!=0){break}b=(I=c[2439328]|0,c[2439328]=I+0,I);if((b|0)==0){e=14313;break}gu[b&16383]()}if((e|0)==14313){e=f_(4)|0;c[e>>2]=619768;eh(e|0,625520,1206)}e=d;c[a+8>>2]=e;c[a>>2]=9;c[a+4>>2]=4;a=382616;b=4;f=e;while(1){e=b-1|0;c[f>>2]=c[a>>2];if((e|0)==0){break}else{a=a+4|0;b=e;f=f+4|0}}c[d+16>>2]=0;return}function gFA(b,c){b=b|0;c=c|0;c=b;a[b]=10;b=c+1|0;a[b]=a[372864]|0;a[b+1|0]=a[372865]|0;a[b+2|0]=a[372866]|0;a[b+3|0]=a[372867]|0;a[b+4|0]=a[372868]|0;a[c+6|0]=0;return}function gFB(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;while(1){d=gGq(32)|0;if((d|0)!=0){break}b=(I=c[2439328]|0,c[2439328]=I+0,I);if((b|0)==0){e=14328;break}gu[b&16383]()}if((e|0)==14328){e=f_(4)|0;c[e>>2]=619768;eh(e|0,625520,1206)}e=d;c[a+8>>2]=e;c[a>>2]=9;c[a+4>>2]=5;a=361288;b=5;f=e;while(1){e=b-1|0;c[f>>2]=c[a>>2];if((e|0)==0){break}else{a=a+4|0;b=e;f=f+4|0}}c[d+20>>2]=0;return}function gFC(b){b=b|0;var d=0;if((a[14125080]|0)!=0){d=c[2384268]|0;return d|0}if((bp(14125080)|0)==0){d=c[2384268]|0;return d|0}do{if((a[14124968]|0)==0){if((bp(14124968)|0)==0){break}gGz(9536120,0,168);dZ(176,0,t|0)|0}}while(0);gAs(9536120,554304);gAs(9536132,552672);gAs(9536144,550912);gAs(9536156,548544);gAs(9536168,546728);gAs(9536180,545176);gAs(9536192,544008);gAs(9536204,542528);gAs(9536216,541904);gAs(9536228,540960);gAs(9536240,539672);gAs(9536252,538272);gAs(9536264,536784);gAs(9536276,534408);c[2384268]=9536120;d=c[2384268]|0;return d|0}function gFD(b){b=b|0;var d=0;if((a[14125024]|0)!=0){d=c[2384246]|0;return d|0}if((bp(14125024)|0)==0){d=c[2384246]|0;return d|0}do{if((a[14124944]|0)==0){if((bp(14124944)|0)==0){break}gGz(9535376,0,168);dZ(346,0,t|0)|0}}while(0);gAz(9535376,577472,6);gAz(9535388,576376,6);gAz(9535400,575184,7);gAz(9535412,574112,9);gAz(9535424,572840,8);gAz(9535436,571184,6);gAz(9535448,569064,8);gAz(9535460,566800,3);gAz(9535472,564392,3);gAz(9535484,562784,3);gAz(9535496,561184,3);gAz(9535508,559920,3);gAz(9535520,558536,3);gAz(9535532,557096,3);c[2384246]=9535376;d=c[2384246]|0;return d|0}function gFE(b){b=b|0;var d=0;if((a[14125072]|0)!=0){d=c[2384266]|0;return d|0}if((bp(14125072)|0)==0){d=c[2384266]|0;return d|0}do{if((a[14124960]|0)==0){if((bp(14124960)|0)==0){break}gGz(9535832,0,288);dZ(418,0,t|0)|0}}while(0);gAs(9535832,102e3);gAs(9535844,98464);gAs(9535856,94856);gAs(9535868,91856);gAs(9535880,89264);gAs(9535892,87656);gAs(9535904,85696);gAs(9535916,83856);gAs(9535928,82360);gAs(9535940,80664);gAs(9535952,78520);gAs(9535964,76528);gAs(9535976,74176);gAs(9535988,71768);gAs(9536e3,69496);gAs(9536012,68248);gAs(9536024,89264);gAs(9536036,66704);gAs(9536048,65768);gAs(9536060,588912);gAs(9536072,587328);gAs(9536084,585608);gAs(9536096,583696);gAs(9536108,581408);c[2384266]=9535832;d=c[2384266]|0;return d|0}function gFF(b){b=b|0;var d=0;if((a[14125016]|0)!=0){d=c[2384244]|0;return d|0}if((bp(14125016)|0)==0){d=c[2384244]|0;return d|0}do{if((a[14124936]|0)==0){if((bp(14124936)|0)==0){break}gGz(9535088,0,288);dZ(522,0,t|0)|0}}while(0);gAz(9535088,172904,7);gAz(9535100,169384,8);gAz(9535112,166352,5);gAz(9535124,163536,5);gAz(9535136,123640,3);gAz(9535148,156864,4);gAz(9535160,154064,4);gAz(9535172,149408,6);gAz(9535184,146112,9);gAz(9535196,142824,7);gAz(9535208,139320,8);gAz(9535220,136704,8);gAz(9535232,134440,3);gAz(9535244,132392,3);gAz(9535256,129016,3);gAz(9535268,126640,3);gAz(9535280,123640,3);gAz(9535292,119728,3);gAz(9535304,116920,3);gAz(9535316,114240,3);gAz(9535328,112400,3);gAz(9535340,110568,3);gAz(9535352,108912,3);gAz(9535364,106760,3);c[2384244]=9535088;d=c[2384244]|0;return d|0}function gFG(b){b=b|0;var d=0;if((a[14125088]|0)!=0){d=c[2384270]|0;return d|0}if((bp(14125088)|0)==0){d=c[2384270]|0;return d|0}do{if((a[14124976]|0)==0){if((bp(14124976)|0)==0){break}gGz(9536288,0,288);dZ(520,0,t|0)|0}}while(0);gAs(9536288,185648);gAs(9536300,180912);c[2384270]=9536288;d=c[2384270]|0;return d|0}function gFH(b){b=b|0;var d=0;if((a[14125032]|0)!=0){d=c[2384248]|0;return d|0}if((bp(14125032)|0)==0){d=c[2384248]|0;return d|0}do{if((a[14124952]|0)==0){if((bp(14124952)|0)==0){break}gGz(9535544,0,288);dZ(1086,0,t|0)|0}}while(0);gAz(9535544,203440,2);gAz(9535556,197328,2);c[2384248]=9535544;d=c[2384248]|0;return d|0}function gFI(b){b=b|0;var c=0;if((a[14125096]|0)!=0){return 9537088}if((bp(14125096)|0)==0){return 9537088}a[9537088]=16;b=9537089;c=b|0;C=623865125;a[c]=C&255;C=C>>8;a[c+1|0]=C&255;C=C>>8;a[c+2|0]=C&255;C=C>>8;a[c+3|0]=C&255;c=b+4|0;C=2032480100;a[c]=C&255;C=C>>8;a[c+1|0]=C&255;C=C>>8;a[c+2|0]=C&255;C=C>>8;a[c+3|0]=C&255;a[9537097]=0;dZ(504,9537088,t|0)|0;return 9537088}function gFJ(b){b=b|0;var d=0,e=0,f=0,g=0;if((a[14125040]|0)!=0){return 9537e3}if((bp(14125040)|0)==0){return 9537e3}while(1){d=gGq(48)|0;if((d|0)!=0){break}b=(I=c[2439328]|0,c[2439328]=I+0,I);if((b|0)==0){e=14497;break}gu[b&16383]()}if((e|0)==14497){e=f_(4)|0;c[e>>2]=619768;eh(e|0,625520,1206);return 0}e=d;c[2384252]=e;c[2384250]=13;c[2384251]=8;b=338128;f=8;g=e;while(1){e=f-1|0;c[g>>2]=c[b>>2];if((e|0)==0){break}else{b=b+4|0;f=e;g=g+4|0}}c[d+32>>2]=0;dZ(824,9537e3,t|0)|0;return 9537e3}function gFK(b){b=b|0;var c=0;if((a[14125120]|0)!=0){return 9537136}if((bp(14125120)|0)==0){return 9537136}a[9537136]=16;b=9537137;c=b|0;C=624576549;a[c]=C&255;C=C>>8;a[c+1|0]=C&255;C=C>>8;a[c+2|0]=C&255;C=C>>8;a[c+3|0]=C&255;c=b+4|0;C=1394948685;a[c]=C&255;C=C>>8;a[c+1|0]=C&255;C=C>>8;a[c+2|0]=C&255;C=C>>8;a[c+3|0]=C&255;a[9537145]=0;dZ(504,9537136,t|0)|0;return 9537136}function gFL(b){b=b|0;var d=0,e=0,f=0,g=0;if((a[14125064]|0)!=0){return 9537048}if((bp(14125064)|0)==0){return 9537048}while(1){d=gGq(48)|0;if((d|0)!=0){break}b=(I=c[2439328]|0,c[2439328]=I+0,I);if((b|0)==0){e=14525;break}gu[b&16383]()}if((e|0)==14525){e=f_(4)|0;c[e>>2]=619768;eh(e|0,625520,1206);return 0}e=d;c[2384264]=e;c[2384262]=13;c[2384263]=8;b=321584;f=8;g=e;while(1){e=f-1|0;c[g>>2]=c[b>>2];if((e|0)==0){break}else{b=b+4|0;f=e;g=g+4|0}}c[d+32>>2]=0;dZ(824,9537048,t|0)|0;return 9537048}function gFM(b){b=b|0;var d=0,e=0;if((a[14125112]|0)!=0){return 9537120}if((bp(14125112)|0)==0){return 9537120}while(1){d=gGq(32)|0;if((d|0)!=0){e=14548;break}b=(I=c[2439328]|0,c[2439328]=I+0,I);if((b|0)==0){e=14546;break}gu[b&16383]()}if((e|0)==14548){c[2384282]=d;c[2384280]=33;c[2384281]=20;gGC(d|0,312176,20)|0;a[d+20|0]=0;dZ(504,9537120,t|0)|0;return 9537120}else if((e|0)==14546){e=f_(4)|0;c[e>>2]=619768;eh(e|0,625520,1206);return 0}return 0}function gFN(b){b=b|0;var d=0,e=0,f=0,g=0;if((a[14125056]|0)!=0){return 9537032}if((bp(14125056)|0)==0){return 9537032}while(1){d=gGq(96)|0;if((d|0)!=0){break}b=(I=c[2439328]|0,c[2439328]=I+0,I);if((b|0)==0){e=14565;break}gu[b&16383]()}if((e|0)==14565){e=f_(4)|0;c[e>>2]=619768;eh(e|0,625520,1206);return 0}e=d;c[2384260]=e;c[2384258]=25;c[2384259]=20;b=303928;f=20;g=e;while(1){e=f-1|0;c[g>>2]=c[b>>2];if((e|0)==0){break}else{b=b+4|0;f=e;g=g+4|0}}c[d+80>>2]=0;dZ(824,9537032,t|0)|0;return 9537032}function gFO(b){b=b|0;var d=0,e=0;if((a[14125104]|0)!=0){return 9537104}if((bp(14125104)|0)==0){return 9537104}while(1){d=gGq(16)|0;if((d|0)!=0){e=14588;break}b=(I=c[2439328]|0,c[2439328]=I+0,I);if((b|0)==0){e=14586;break}gu[b&16383]()}if((e|0)==14586){b=f_(4)|0;c[b>>2]=619768;eh(b|0,625520,1206);return 0}else if((e|0)==14588){c[2384278]=d;c[2384276]=17;c[2384277]=11;gGC(d|0,296192,11)|0;a[d+11|0]=0;dZ(504,9537104,t|0)|0;return 9537104}return 0}function gFP(b){b=b|0;var d=0,e=0,f=0,g=0;if((a[14125048]|0)!=0){return 9537016}if((bp(14125048)|0)==0){return 9537016}while(1){d=gGq(48)|0;if((d|0)!=0){break}b=(I=c[2439328]|0,c[2439328]=I+0,I);if((b|0)==0){e=14605;break}gu[b&16383]()}if((e|0)==14605){e=f_(4)|0;c[e>>2]=619768;eh(e|0,625520,1206);return 0}e=d;c[2384256]=e;c[2384254]=13;c[2384255]=11;b=290680;f=11;g=e;while(1){e=f-1|0;c[g>>2]=c[b>>2];if((e|0)==0){break}else{b=b+4|0;f=e;g=g+4|0}}c[d+44>>2]=0;dZ(824,9537016,t|0)|0;return 9537016}function gFQ(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0.0,j=0,k=0,l=0.0;f=i;i=i+8|0;g=f|0;if((b|0)==(d|0)){c[e>>2]=4;h=0.0;i=f;return+h}j=bO()|0;k=c[j>>2]|0;c[j>>2]=0;do{if((a[14125e3]|0)==0){if((bp(14125e3)|0)==0){break}c[2384150]=e6(2147483647,485280,0)|0}}while(0);l=+gGx(b,g);b=c[j>>2]|0;if((b|0)==0){c[j>>2]=k}if((c[g>>2]|0)!=(d|0)){c[e>>2]=4;h=0.0;i=f;return+h}if((b|0)!=34){h=l;i=f;return+h}c[e>>2]=4;h=l;i=f;return+h}function gFR(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0.0,j=0,k=0,l=0.0;f=i;i=i+8|0;g=f|0;if((b|0)==(d|0)){c[e>>2]=4;h=0.0;i=f;return+h}j=bO()|0;k=c[j>>2]|0;c[j>>2]=0;do{if((a[14125e3]|0)==0){if((bp(14125e3)|0)==0){break}c[2384150]=e6(2147483647,485280,0)|0}}while(0);l=+gGx(b,g);b=c[j>>2]|0;if((b|0)==0){c[j>>2]=k}if((c[g>>2]|0)!=(d|0)){c[e>>2]=4;h=0.0;i=f;return+h}if((b|0)!=34){h=l;i=f;return+h}c[e>>2]=4;h=l;i=f;return+h}function gFS(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0.0,j=0,k=0,l=0.0;f=i;i=i+8|0;g=f|0;if((b|0)==(d|0)){c[e>>2]=4;h=0.0;i=f;return+h}j=bO()|0;k=c[j>>2]|0;c[j>>2]=0;do{if((a[14125e3]|0)==0){if((bp(14125e3)|0)==0){break}c[2384150]=e6(2147483647,485280,0)|0}}while(0);l=+gGx(b,g);b=c[j>>2]|0;if((b|0)==0){c[j>>2]=k}if((c[g>>2]|0)!=(d|0)){c[e>>2]=4;h=0.0;i=f;return+h}if((b|0)==34){c[e>>2]=4}h=l;i=f;return+h}function gFT(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;g=i;i=i+8|0;h=g|0;do{if((b|0)==(d|0)){c[e>>2]=4;j=0;k=0}else{if((a[b]|0)==45){c[e>>2]=4;j=0;k=0;break}l=bO()|0;m=c[l>>2]|0;c[l>>2]=0;do{if((a[14125e3]|0)==0){if((bp(14125e3)|0)==0){break}c[2384150]=e6(2147483647,485280,0)|0}}while(0);n=dC(b|0,h|0,f|0,c[2384150]|0)|0;o=c[l>>2]|0;if((o|0)==0){c[l>>2]=m}if((c[h>>2]|0)!=(d|0)){c[e>>2]=4;j=0;k=0;break}if((o|0)!=34){j=K;k=n;break}c[e>>2]=4;j=-1;k=-1}}while(0);i=g;return(K=j,k)|0}function gFU(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0;g=i;i=i+8|0;h=g|0;if((b|0)==(d|0)){c[e>>2]=4;j=0;i=g;return j|0}if((a[b]|0)==45){c[e>>2]=4;j=0;i=g;return j|0}k=bO()|0;l=c[k>>2]|0;c[k>>2]=0;do{if((a[14125e3]|0)==0){if((bp(14125e3)|0)==0){break}c[2384150]=e6(2147483647,485280,0)|0}}while(0);m=dC(b|0,h|0,f|0,c[2384150]|0)|0;f=K;b=c[k>>2]|0;if((b|0)==0){c[k>>2]=l}if((c[h>>2]|0)!=(d|0)){c[e>>2]=4;j=0;i=g;return j|0}d=0;if((b|0)==34|(f>>>0>d>>>0|f>>>0==d>>>0&m>>>0>-1>>>0)){c[e>>2]=4;j=-1;i=g;return j|0}else{j=m;i=g;return j|0}return 0}function gFV(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0;g=i;i=i+8|0;h=g|0;if((b|0)==(d|0)){c[e>>2]=4;j=0;i=g;return j|0}if((a[b]|0)==45){c[e>>2]=4;j=0;i=g;return j|0}k=bO()|0;l=c[k>>2]|0;c[k>>2]=0;do{if((a[14125e3]|0)==0){if((bp(14125e3)|0)==0){break}c[2384150]=e6(2147483647,485280,0)|0}}while(0);m=dC(b|0,h|0,f|0,c[2384150]|0)|0;f=K;b=c[k>>2]|0;if((b|0)==0){c[k>>2]=l}if((c[h>>2]|0)!=(d|0)){c[e>>2]=4;j=0;i=g;return j|0}d=0;if((b|0)==34|(f>>>0>d>>>0|f>>>0==d>>>0&m>>>0>-1>>>0)){c[e>>2]=4;j=-1;i=g;return j|0}else{j=m;i=g;return j|0}return 0}function gFW(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0;g=i;i=i+8|0;h=g|0;if((b|0)==(d|0)){c[e>>2]=4;j=0;i=g;return j|0}if((a[b]|0)==45){c[e>>2]=4;j=0;i=g;return j|0}k=bO()|0;l=c[k>>2]|0;c[k>>2]=0;do{if((a[14125e3]|0)==0){if((bp(14125e3)|0)==0){break}c[2384150]=e6(2147483647,485280,0)|0}}while(0);m=dC(b|0,h|0,f|0,c[2384150]|0)|0;f=K;b=c[k>>2]|0;if((b|0)==0){c[k>>2]=l}if((c[h>>2]|0)!=(d|0)){c[e>>2]=4;j=0;i=g;return j|0}d=0;if((b|0)==34|(f>>>0>d>>>0|f>>>0==d>>>0&m>>>0>65535>>>0)){c[e>>2]=4;j=-1;i=g;return j|0}else{j=m&65535;i=g;return j|0}return 0}function gFX(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0;g=i;i=i+8|0;h=g|0;if((b|0)==(d|0)){c[e>>2]=4;j=0;k=0;i=g;return(K=j,k)|0}l=bO()|0;m=c[l>>2]|0;c[l>>2]=0;do{if((a[14125e3]|0)==0){if((bp(14125e3)|0)==0){break}c[2384150]=e6(2147483647,485280,0)|0}}while(0);n=bZ(b|0,h|0,f|0,c[2384150]|0)|0;f=K;b=c[l>>2]|0;if((b|0)==0){c[l>>2]=m}if((c[h>>2]|0)!=(d|0)){c[e>>2]=4;j=0;k=0;i=g;return(K=j,k)|0}if((b|0)!=34){j=f;k=n;i=g;return(K=j,k)|0}c[e>>2]=4;e=0;b=(f|0)>(e|0)|(f|0)==(e|0)&n>>>0>0>>>0;j=b?2147483647:-2147483648;k=b?-1:0;i=g;return(K=j,k)|0}function gFY(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0;g=i;i=i+8|0;h=g|0;if((b|0)==(d|0)){c[e>>2]=4;j=0;i=g;return j|0}k=bO()|0;l=c[k>>2]|0;c[k>>2]=0;do{if((a[14125e3]|0)==0){if((bp(14125e3)|0)==0){break}c[2384150]=e6(2147483647,485280,0)|0}}while(0);m=bZ(b|0,h|0,f|0,c[2384150]|0)|0;f=K;b=c[k>>2]|0;if((b|0)==0){c[k>>2]=l}if((c[h>>2]|0)!=(d|0)){c[e>>2]=4;j=0;i=g;return j|0}d=-1;h=0;if((b|0)==34|((f|0)<(d|0)|(f|0)==(d|0)&m>>>0<-2147483648>>>0)|((f|0)>(h|0)|(f|0)==(h|0)&m>>>0>2147483647>>>0)){c[e>>2]=4;e=0;j=(f|0)>(e|0)|(f|0)==(e|0)&m>>>0>0>>>0?2147483647:-2147483648;i=g;return j|0}else{j=m;i=g;return j|0}return 0}function gFZ(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=b+8|0;f=b+4|0;g=c[f>>2]|0;h=c[e>>2]|0;i=g;if(h-i>>2>>>0>=d>>>0){j=d;k=g;do{if((k|0)==0){l=0}else{c[k>>2]=0;l=c[f>>2]|0}k=l+4|0;c[f>>2]=k;j=j-1|0;}while((j|0)!=0);return}j=b+16|0;k=b|0;l=c[k>>2]|0;g=i-l>>2;i=g+d|0;if(i>>>0>1073741823){gEo()}m=h-l|0;do{if(m>>2>>>0>536870910){n=1073741823;o=14799}else{l=m>>1;h=l>>>0<i>>>0?i:l;if((h|0)==0){p=0;q=0;break}l=b+128|0;if(!((a[l]&1)==0&h>>>0<29)){n=h;o=14799;break}a[l]=1;p=j;q=h}}while(0);do{if((o|0)==14799){i=n<<2;m=(i|0)==0?1:i;while(1){r=gGq(m)|0;if((r|0)!=0){o=14810;break}i=(I=c[2439328]|0,c[2439328]=I+0,I);if((i|0)==0){break}gu[i&16383]()}if((o|0)==14810){p=r;q=n;break}m=f_(4)|0;c[m>>2]=619768;eh(m|0,625520,1206)}}while(0);n=d;d=p+(g<<2)|0;do{if((d|0)==0){s=0}else{c[d>>2]=0;s=d}d=s+4|0;n=n-1|0;}while((n|0)!=0);n=p+(q<<2)|0;q=c[k>>2]|0;s=(c[f>>2]|0)-q|0;r=p+(g-(s>>2)<<2)|0;g=r;p=q;gGC(g|0,p|0,s)|0;c[k>>2]=r;c[f>>2]=d;c[e>>2]=n;if((q|0)==0){return}if((q|0)==(j|0)){a[b+128|0]=0;return}else{gGr(p);return}}function gF_(b){b=b|0;do{if((a[9535820]&1)!=0){b=c[2383957]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9535808]&1)!=0){b=c[2383954]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9535796]&1)!=0){b=c[2383951]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9535784]&1)!=0){b=c[2383948]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9535772]&1)!=0){b=c[2383945]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9535760]&1)!=0){b=c[2383942]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9535748]&1)!=0){b=c[2383939]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9535736]&1)!=0){b=c[2383936]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9535724]&1)!=0){b=c[2383933]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9535712]&1)!=0){b=c[2383930]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9535700]&1)!=0){b=c[2383927]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9535688]&1)!=0){b=c[2383924]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9535676]&1)!=0){b=c[2383921]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9535664]&1)!=0){b=c[2383918]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9535652]&1)!=0){b=c[2383915]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9535640]&1)!=0){b=c[2383912]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9535628]&1)!=0){b=c[2383909]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9535616]&1)!=0){b=c[2383906]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9535604]&1)!=0){b=c[2383903]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9535592]&1)!=0){b=c[2383900]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9535580]&1)!=0){b=c[2383897]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9535568]&1)!=0){b=c[2383894]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9535556]&1)!=0){b=c[2383891]|0;if((b|0)==0){break}gGr(b)}}while(0);if((a[9535544]&1)==0){return}b=c[2383888]|0;if((b|0)==0){return}gGr(b);return}function gF$(b){b=b|0;do{if((a[9536564]&1)!=0){b=c[2384143]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9536552]&1)!=0){b=c[2384140]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9536540]&1)!=0){b=c[2384137]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9536528]&1)!=0){b=c[2384134]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9536516]&1)!=0){b=c[2384131]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9536504]&1)!=0){b=c[2384128]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9536492]&1)!=0){b=c[2384125]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9536480]&1)!=0){b=c[2384122]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9536468]&1)!=0){b=c[2384119]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9536456]&1)!=0){b=c[2384116]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9536444]&1)!=0){b=c[2384113]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9536432]&1)!=0){b=c[2384110]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9536420]&1)!=0){b=c[2384107]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9536408]&1)!=0){b=c[2384104]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9536396]&1)!=0){b=c[2384101]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9536384]&1)!=0){b=c[2384098]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9536372]&1)!=0){b=c[2384095]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9536360]&1)!=0){b=c[2384092]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9536348]&1)!=0){b=c[2384089]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9536336]&1)!=0){b=c[2384086]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9536324]&1)!=0){b=c[2384083]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9536312]&1)!=0){b=c[2384080]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9536300]&1)!=0){b=c[2384077]|0;if((b|0)==0){break}gGr(b)}}while(0);if((a[9536288]&1)==0){return}b=c[2384074]|0;if((b|0)==0){return}gGr(b);return}function gF0(b){b=b|0;do{if((a[9535364]&1)!=0){b=c[2383843]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9535352]&1)!=0){b=c[2383840]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9535340]&1)!=0){b=c[2383837]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9535328]&1)!=0){b=c[2383834]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9535316]&1)!=0){b=c[2383831]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9535304]&1)!=0){b=c[2383828]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9535292]&1)!=0){b=c[2383825]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9535280]&1)!=0){b=c[2383822]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9535268]&1)!=0){b=c[2383819]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9535256]&1)!=0){b=c[2383816]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9535244]&1)!=0){b=c[2383813]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9535232]&1)!=0){b=c[2383810]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9535220]&1)!=0){b=c[2383807]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9535208]&1)!=0){b=c[2383804]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9535196]&1)!=0){b=c[2383801]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9535184]&1)!=0){b=c[2383798]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9535172]&1)!=0){b=c[2383795]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9535160]&1)!=0){b=c[2383792]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9535148]&1)!=0){b=c[2383789]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9535136]&1)!=0){b=c[2383786]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9535124]&1)!=0){b=c[2383783]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9535112]&1)!=0){b=c[2383780]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9535100]&1)!=0){b=c[2383777]|0;if((b|0)==0){break}gGr(b)}}while(0);if((a[9535088]&1)==0){return}b=c[2383774]|0;if((b|0)==0){return}gGr(b);return}function gF1(b){b=b|0;do{if((a[9536108]&1)!=0){b=c[2384029]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9536096]&1)!=0){b=c[2384026]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9536084]&1)!=0){b=c[2384023]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9536072]&1)!=0){b=c[2384020]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9536060]&1)!=0){b=c[2384017]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9536048]&1)!=0){b=c[2384014]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9536036]&1)!=0){b=c[2384011]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9536024]&1)!=0){b=c[2384008]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9536012]&1)!=0){b=c[2384005]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9536e3]&1)!=0){b=c[2384002]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9535988]&1)!=0){b=c[2383999]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9535976]&1)!=0){b=c[2383996]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9535964]&1)!=0){b=c[2383993]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9535952]&1)!=0){b=c[2383990]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9535940]&1)!=0){b=c[2383987]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9535928]&1)!=0){b=c[2383984]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9535916]&1)!=0){b=c[2383981]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9535904]&1)!=0){b=c[2383978]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9535892]&1)!=0){b=c[2383975]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9535880]&1)!=0){b=c[2383972]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9535868]&1)!=0){b=c[2383969]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9535856]&1)!=0){b=c[2383966]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9535844]&1)!=0){b=c[2383963]|0;if((b|0)==0){break}gGr(b)}}while(0);if((a[9535832]&1)==0){return}b=c[2383960]|0;if((b|0)==0){return}gGr(b);return}function gF2(b){b=b|0;do{if((a[9535532]&1)!=0){b=c[2383885]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9535520]&1)!=0){b=c[2383882]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9535508]&1)!=0){b=c[2383879]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9535496]&1)!=0){b=c[2383876]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9535484]&1)!=0){b=c[2383873]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9535472]&1)!=0){b=c[2383870]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9535460]&1)!=0){b=c[2383867]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9535448]&1)!=0){b=c[2383864]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9535436]&1)!=0){b=c[2383861]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9535424]&1)!=0){b=c[2383858]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9535412]&1)!=0){b=c[2383855]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9535400]&1)!=0){b=c[2383852]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9535388]&1)!=0){b=c[2383849]|0;if((b|0)==0){break}gGr(b)}}while(0);if((a[9535376]&1)==0){return}b=c[2383846]|0;if((b|0)==0){return}gGr(b);return}function gF3(b){b=b|0;do{if((a[9536276]&1)!=0){b=c[2384071]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9536264]&1)!=0){b=c[2384068]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9536252]&1)!=0){b=c[2384065]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9536240]&1)!=0){b=c[2384062]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9536228]&1)!=0){b=c[2384059]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9536216]&1)!=0){b=c[2384056]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9536204]&1)!=0){b=c[2384053]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9536192]&1)!=0){b=c[2384050]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9536180]&1)!=0){b=c[2384047]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9536168]&1)!=0){b=c[2384044]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9536156]&1)!=0){b=c[2384041]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9536144]&1)!=0){b=c[2384038]|0;if((b|0)==0){break}gGr(b)}}while(0);do{if((a[9536132]&1)!=0){b=c[2384035]|0;if((b|0)==0){break}gGr(b)}}while(0);if((a[9536120]&1)==0){return}b=c[2384032]|0;if((b|0)==0){return}gGr(b);return}function gF4(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0,w=0;g=i;i=i+8|0;h=g|0;c[h>>2]=b;j=((f|0)==0?8645360:f)|0;f=c[j>>2]|0;L17519:do{if((d|0)==0){if((f|0)==0){k=0}else{break}i=g;return k|0}else{if((b|0)==0){l=h;c[h>>2]=l;m=l}else{m=b}if((e|0)==0){k=-2;i=g;return k|0}do{if((f|0)==0){l=a[d]|0;n=l&255;if(l<<24>>24>-1){c[m>>2]=n;k=l<<24>>24!=0|0;i=g;return k|0}else{l=n-194|0;if(l>>>0>50){break L17519}o=d+1|0;p=c[q+(l<<2)>>2]|0;r=e-1|0;break}}else{o=d;p=f;r=e}}while(0);L17537:do{if((r|0)==0){s=p}else{l=a[o]|0;n=(l&255)>>>3;if((n-16|n+(p>>26))>>>0>7){break L17519}else{t=o;u=p;v=r;w=l}while(1){t=t+1|0;u=u<<6|(w&255)-128;v=v-1|0;if((u|0)>=0){break}if((v|0)==0){s=u;break L17537}w=a[t]|0;if(((w&255)-128|0)>>>0>63){break L17519}}c[j>>2]=0;c[m>>2]=u;k=e-v|0;i=g;return k|0}}while(0);c[j>>2]=s;k=-2;i=g;return k|0}}while(0);c[j>>2]=0;c[(bO()|0)>>2]=84;k=-1;i=g;return k|0}function gF5(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0;h=c[e>>2]|0;do{if((g|0)==0){i=15249}else{j=g|0;k=c[j>>2]|0;if((k|0)==0){i=15249;break}if((b|0)==0){l=k;m=h;n=f;i=15260;break}c[j>>2]=0;o=k;p=h;r=b;s=f;i=15280}}while(0);if((i|0)==15249){if((b|0)==0){t=h;u=f;i=15251}else{v=h;w=b;x=f;i=15250}}L17556:while(1){if((i|0)==15251){i=0;h=a[t]|0;do{if(((h&255)-1|0)>>>0<127){if((t&3|0)!=0){y=t;z=u;A=h;break}g=c[t>>2]|0;if(((g-16843009|g)&-2139062144|0)==0){B=u;C=t}else{y=t;z=u;A=g&255;break}do{C=C+4|0;B=B-4|0;D=c[C>>2]|0;}while(((D-16843009|D)&-2139062144|0)==0);y=C;z=B;A=D&255}else{y=t;z=u;A=h}}while(0);h=A&255;if((h-1|0)>>>0<127){t=y+1|0;u=z-1|0;i=15251;continue}g=h-194|0;if(g>>>0>50){E=z;F=b;G=y;H=A;i=15292;break}l=c[q+(g<<2)>>2]|0;m=y+1|0;n=z;i=15260;continue}else if((i|0)==15250){i=0;if((x|0)==0){I=f;i=15299;break}else{J=x;K=w;L=v}while(1){g=a[L]|0;do{if(((g&255)-1|0)>>>0<127){if((L&3|0)==0&J>>>0>3){M=J;N=K;O=L}else{P=L;Q=K;R=J;S=g;break}while(1){T=c[O>>2]|0;if(((T-16843009|T)&-2139062144|0)!=0){i=15275;break}c[N>>2]=T&255;c[N+4>>2]=d[O+1|0]|0;c[N+8>>2]=d[O+2|0]|0;U=O+4|0;V=N+16|0;c[N+12>>2]=d[O+3|0]|0;W=M-4|0;if(W>>>0>3){M=W;N=V;O=U}else{i=15274;break}}if((i|0)==15274){i=0;P=U;Q=V;R=W;S=a[U]|0;break}else if((i|0)==15275){i=0;P=O;Q=N;R=M;S=T&255;break}}else{P=L;Q=K;R=J;S=g}}while(0);X=S&255;if((X-1|0)>>>0>=127){break}c[Q>>2]=X;g=R-1|0;if((g|0)==0){I=f;i=15301;break L17556}else{J=g;K=Q+4|0;L=P+1|0}}g=X-194|0;if(g>>>0>50){E=R;F=Q;G=P;H=S;i=15292;break}o=c[q+(g<<2)>>2]|0;p=P+1|0;r=Q;s=R;i=15280;continue}else if((i|0)==15260){i=0;g=(d[m]|0)>>>3;if((g-16|g+(l>>26))>>>0>7){i=15261;break}g=m+1|0;do{if((l&33554432|0)==0){Y=g}else{if(((d[g]|0)-128|0)>>>0>63){i=15264;break L17556}h=m+2|0;if((l&524288|0)==0){Y=h;break}if(((d[h]|0)-128|0)>>>0>63){i=15267;break L17556}Y=m+3|0}}while(0);t=Y;u=n-1|0;i=15251;continue}else if((i|0)==15280){i=0;g=d[p]|0;h=g>>>3;if((h-16|h+(o>>26))>>>0>7){i=15281;break}h=p+1|0;Z=g-128|o<<6;do{if((Z|0)<0){g=(d[h]|0)-128|0;if(g>>>0>63){i=15284;break L17556}k=p+2|0;_=g|Z<<6;if((_|0)>=0){$=_;aa=k;break}g=(d[k]|0)-128|0;if(g>>>0>63){i=15287;break L17556}$=g|_<<6;aa=p+3|0}else{$=Z;aa=h}}while(0);c[r>>2]=$;v=aa;w=r+4|0;x=s-1|0;i=15250;continue}}if((i|0)==15284){ab=Z;ac=p-1|0;ad=r;ae=s;i=15290}else if((i|0)==15281){ab=o;ac=p-1|0;ad=r;ae=s;i=15290}else if((i|0)==15264){ab=l;ac=m-1|0;ad=b;ae=n;i=15290}else if((i|0)==15287){ab=_;ac=p-1|0;ad=r;ae=s;i=15290}else if((i|0)==15261){ab=l;ac=m-1|0;ad=b;ae=n;i=15290}else if((i|0)==15267){ab=l;ac=m-1|0;ad=b;ae=n;i=15290}else if((i|0)==15299){return I|0}else if((i|0)==15301){return I|0}do{if((i|0)==15290){if((ab|0)!=0){af=ad;ag=ac;break}E=ae;F=ad;G=ac;H=a[ac]|0;i=15292}}while(0);do{if((i|0)==15292){if(H<<24>>24!=0){af=F;ag=G;break}if((F|0)!=0){c[F>>2]=0;c[e>>2]=0}I=f-E|0;return I|0}}while(0);c[(bO()|0)>>2]=84;if((af|0)==0){I=-1;return I|0}c[e>>2]=ag;I=-1;return I|0}function gF6(b,d){b=b|0;d=d|0;var e=0;if((b|0)==0){e=1;return e|0}if(d>>>0<128){a[b]=d&255;e=1;return e|0}if(d>>>0<2048){a[b]=(d>>>6|192)&255;a[b+1|0]=(d&63|128)&255;e=2;return e|0}if(d>>>0<55296|(d-57344|0)>>>0<8192){a[b]=(d>>>12|224)&255;a[b+1|0]=(d>>>6&63|128)&255;a[b+2|0]=(d&63|128)&255;e=3;return e|0}if((d-65536|0)>>>0<1048576){a[b]=(d>>>18|240)&255;a[b+1|0]=(d>>>12&63|128)&255;a[b+2|0]=(d>>>6&63|128)&255;a[b+3|0]=(d&63|128)&255;e=4;return e|0}else{c[(bO()|0)>>2]=84;e=-1;return e|0}return 0}function gF7(a){a=a|0;if((a|0)==0){return}gGr(a);return}function gF8(a){a=a|0;return}function gF9(a){a=a|0;return 204872}function gGa(a){a=a|0;return}function gGb(a){a=a|0;return}function gGc(a){a=a|0;return}function gGd(a){a=a|0;if((a|0)==0){return}gGr(a);return}function gGe(a){a=a|0;if((a|0)==0){return}gGr(a);return}function gGf(a){a=a|0;if((a|0)==0){return}gGr(a);return}function gGg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=i;i=i+112|0;f=e|0;g=e+56|0;if((a|0)==(b|0)){h=1;i=e;return h|0}if((b|0)==0){h=0;i=e;return h|0}j=b;k=c[b>>2]|0;b=j+(c[k-8>>2]|0)|0;l=c[k-4>>2]|0;k=l;c[f>>2]=627048;c[f+4>>2]=j;c[f+8>>2]=627064;c[f+12>>2]=-1;j=f+16|0;m=f+20|0;n=f+24|0;o=f+28|0;p=f+32|0;q=f+40|0;gGz(j|0,0,39);do{if((l|0)==627048){c[f+48>>2]=1;gB[c[(c[156762]|0)+20>>2]&127](k,f,b,b,1,0);r=(c[n>>2]|0)==1?b:0}else{ge[c[(c[l>>2]|0)+24>>2]&63](k,f,b,1,0);s=c[f+36>>2]|0;if((s|0)==0){if((c[q>>2]|0)!=1){r=0;break}if((c[o>>2]|0)!=1){r=0;break}r=(c[p>>2]|0)==1?c[m>>2]|0:0;break}else if((s|0)!=1){r=0;break}if((c[n>>2]|0)!=1){if((c[q>>2]|0)!=0){r=0;break}if((c[o>>2]|0)!=1){r=0;break}if((c[p>>2]|0)!=1){r=0;break}}r=c[j>>2]|0}}while(0);j=r;if((r|0)==0){h=0;i=e;return h|0}gGz(g|0,0,56);c[g>>2]=j;c[g+8>>2]=a;c[g+12>>2]=-1;c[g+48>>2]=1;gL[c[(c[r>>2]|0)+28>>2]&255](j,g,c[d>>2]|0,1);if((c[g+24>>2]|0)!=1){h=0;i=e;return h|0}c[d>>2]=c[g+16>>2];h=1;i=e;return h|0}function gGh(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0;if((c[d+8>>2]|0)!=(b|0)){return}b=d+16|0;g=c[b>>2]|0;if((g|0)==0){c[b>>2]=e;c[d+24>>2]=f;c[d+36>>2]=1;return}if((g|0)!=(e|0)){e=d+36|0;c[e>>2]=(c[e>>2]|0)+1;c[d+24>>2]=2;a[d+54|0]=1;return}e=d+24|0;if((c[e>>2]|0)!=2){return}c[e>>2]=f;return}function gGi(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0;if((b|0)!=(c[d+8>>2]|0)){g=c[b+8>>2]|0;gL[c[(c[g>>2]|0)+28>>2]&255](g,d,e,f);return}g=d+16|0;b=c[g>>2]|0;if((b|0)==0){c[g>>2]=e;c[d+24>>2]=f;c[d+36>>2]=1;return}if((b|0)!=(e|0)){e=d+36|0;c[e>>2]=(c[e>>2]|0)+1;c[d+24>>2]=2;a[d+54|0]=1;return}e=d+24|0;if((c[e>>2]|0)!=2){return}c[e>>2]=f;return}function gGj(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((b|0)==(c[d+8>>2]|0)){g=d+16|0;h=c[g>>2]|0;if((h|0)==0){c[g>>2]=e;c[d+24>>2]=f;c[d+36>>2]=1;return}if((h|0)!=(e|0)){h=d+36|0;c[h>>2]=(c[h>>2]|0)+1;c[d+24>>2]=2;a[d+54|0]=1;return}h=d+24|0;if((c[h>>2]|0)!=2){return}c[h>>2]=f;return}h=c[b+12>>2]|0;g=b+16+(h<<3)|0;i=c[b+20>>2]|0;j=i>>8;if((i&1|0)==0){k=j}else{k=c[(c[e>>2]|0)+j>>2]|0}j=c[b+16>>2]|0;gL[c[(c[j>>2]|0)+28>>2]&255](j,d,e+k|0,(i&2|0)!=0?f:2);if((h|0)<=1){return}h=d+54|0;i=e;k=b+24|0;while(1){b=c[k+4>>2]|0;j=b>>8;if((b&1|0)==0){l=j}else{l=c[(c[i>>2]|0)+j>>2]|0}j=c[k>>2]|0;gL[c[(c[j>>2]|0)+28>>2]&255](j,d,e+l|0,(b&2|0)!=0?f:2);if((a[h]&1)!=0){m=15417;break}b=k+8|0;if(b>>>0<g>>>0){k=b}else{m=15412;break}}if((m|0)==15417){return}else if((m|0)==15412){return}}function gGk(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;h=b|0;if((h|0)==(c[d+8>>2]|0)){if((c[d+4>>2]|0)!=(e|0)){return}i=d+28|0;if((c[i>>2]|0)==1){return}c[i>>2]=f;return}if((h|0)==(c[d>>2]|0)){do{if((c[d+16>>2]|0)!=(e|0)){h=d+20|0;if((c[h>>2]|0)==(e|0)){break}c[d+32>>2]=f;i=d+44|0;if((c[i>>2]|0)==4){return}j=c[b+12>>2]|0;k=b+16+(j<<3)|0;L17782:do{if((j|0)>0){l=d+52|0;m=d+53|0;n=d+54|0;o=b+8|0;p=d+24|0;q=e;r=0;s=b+16|0;t=0;L17784:while(1){a[l]=0;a[m]=0;u=c[s+4>>2]|0;v=u>>8;if((u&1|0)==0){w=v}else{w=c[(c[q>>2]|0)+v>>2]|0}v=c[s>>2]|0;gB[c[(c[v>>2]|0)+20>>2]&127](v,d,e,e+w|0,2-(u>>>1&1)|0,g);if((a[n]&1)!=0){x=t;y=r;break}do{if((a[m]&1)==0){z=t;A=r}else{if((a[l]&1)==0){if((c[o>>2]&1|0)==0){x=1;y=r;break L17784}else{z=1;A=r;break}}if((c[p>>2]|0)==1){B=15444;break L17782}if((c[o>>2]&2|0)==0){B=15444;break L17782}else{z=1;A=1}}}while(0);u=s+8|0;if(u>>>0<k>>>0){r=A;s=u;t=z}else{x=z;y=A;break}}if(y){C=x;B=15443}else{D=x;B=15440}}else{D=0;B=15440}}while(0);do{if((B|0)==15440){c[h>>2]=e;k=d+40|0;c[k>>2]=(c[k>>2]|0)+1;if((c[d+36>>2]|0)!=1){C=D;B=15443;break}if((c[d+24>>2]|0)!=2){C=D;B=15443;break}a[d+54|0]=1;if(D){B=15444}else{B=15445}}}while(0);if((B|0)==15443){if(C){B=15444}else{B=15445}}if((B|0)==15444){c[i>>2]=3;return}else if((B|0)==15445){c[i>>2]=4;return}}}while(0);if((f|0)!=1){return}c[d+32>>2]=1;return}C=c[b+12>>2]|0;D=b+16+(C<<3)|0;x=c[b+20>>2]|0;y=x>>8;if((x&1|0)==0){E=y}else{E=c[(c[e>>2]|0)+y>>2]|0}y=c[b+16>>2]|0;ge[c[(c[y>>2]|0)+24>>2]&63](y,d,e+E|0,(x&2|0)!=0?f:2,g);x=b+24|0;if((C|0)<=1){return}C=c[b+8>>2]|0;do{if((C&2|0)==0){b=d+36|0;if((c[b>>2]|0)==1){break}if((C&1|0)==0){E=d+54|0;y=e;A=x;while(1){if((a[E]&1)!=0){B=15484;break}if((c[b>>2]|0)==1){B=15485;break}z=c[A+4>>2]|0;w=z>>8;if((z&1|0)==0){F=w}else{F=c[(c[y>>2]|0)+w>>2]|0}w=c[A>>2]|0;ge[c[(c[w>>2]|0)+24>>2]&63](w,d,e+F|0,(z&2|0)!=0?f:2,g);z=A+8|0;if(z>>>0<D>>>0){A=z}else{B=15476;break}}if((B|0)==15484){return}else if((B|0)==15485){return}else if((B|0)==15476){return}}A=d+24|0;y=d+54|0;E=e;i=x;while(1){if((a[y]&1)!=0){B=15477;break}if((c[b>>2]|0)==1){if((c[A>>2]|0)==1){B=15480;break}}z=c[i+4>>2]|0;w=z>>8;if((z&1|0)==0){G=w}else{G=c[(c[E>>2]|0)+w>>2]|0}w=c[i>>2]|0;ge[c[(c[w>>2]|0)+24>>2]&63](w,d,e+G|0,(z&2|0)!=0?f:2,g);z=i+8|0;if(z>>>0<D>>>0){i=z}else{B=15487;break}}if((B|0)==15477){return}else if((B|0)==15480){return}else if((B|0)==15487){return}}}while(0);G=d+54|0;F=e;C=x;while(1){if((a[G]&1)!=0){B=15472;break}x=c[C+4>>2]|0;i=x>>8;if((x&1|0)==0){H=i}else{H=c[(c[F>>2]|0)+i>>2]|0}i=c[C>>2]|0;ge[c[(c[i>>2]|0)+24>>2]&63](i,d,e+H|0,(x&2|0)!=0?f:2,g);x=C+8|0;if(x>>>0<D>>>0){C=x}else{B=15475;break}}if((B|0)==15472){return}else if((B|0)==15475){return}}function gGl(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0;h=b|0;if((h|0)==(c[d+8>>2]|0)){if((c[d+4>>2]|0)!=(e|0)){return}i=d+28|0;if((c[i>>2]|0)==1){return}c[i>>2]=f;return}if((h|0)!=(c[d>>2]|0)){h=c[b+8>>2]|0;ge[c[(c[h>>2]|0)+24>>2]&63](h,d,e,f,g);return}do{if((c[d+16>>2]|0)!=(e|0)){h=d+20|0;if((c[h>>2]|0)==(e|0)){break}c[d+32>>2]=f;i=d+44|0;if((c[i>>2]|0)==4){return}j=d+52|0;a[j]=0;k=d+53|0;a[k]=0;l=c[b+8>>2]|0;gB[c[(c[l>>2]|0)+20>>2]&127](l,d,e,e,1,g);if((a[k]&1)==0){m=0;n=15500}else{if((a[j]&1)==0){m=1;n=15500}}L17884:do{if((n|0)==15500){c[h>>2]=e;j=d+40|0;c[j>>2]=(c[j>>2]|0)+1;do{if((c[d+36>>2]|0)==1){if((c[d+24>>2]|0)!=2){n=15503;break}a[d+54|0]=1;if(m){break L17884}}else{n=15503}}while(0);if((n|0)==15503){if(m){break}}c[i>>2]=4;return}}while(0);c[i>>2]=3;return}}while(0);if((f|0)!=1){return}c[d+32>>2]=1;return}function gGm(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;if((c[d+8>>2]|0)==(b|0)){if((c[d+4>>2]|0)!=(e|0)){return}g=d+28|0;if((c[g>>2]|0)==1){return}c[g>>2]=f;return}if((c[d>>2]|0)!=(b|0)){return}do{if((c[d+16>>2]|0)!=(e|0)){b=d+20|0;if((c[b>>2]|0)==(e|0)){break}c[d+32>>2]=f;c[b>>2]=e;b=d+40|0;c[b>>2]=(c[b>>2]|0)+1;do{if((c[d+36>>2]|0)==1){if((c[d+24>>2]|0)!=2){break}a[d+54|0]=1}}while(0);c[d+44>>2]=4;return}}while(0);if((f|0)!=1){return}c[d+32>>2]=1;return}function gGn(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;if((b|0)!=(c[d+8>>2]|0)){i=d+52|0;j=a[i]&1;k=d+53|0;l=a[k]&1;m=c[b+12>>2]|0;n=b+16+(m<<3)|0;a[i]=0;a[k]=0;o=c[b+20>>2]|0;p=o>>8;if((o&1|0)==0){q=p}else{q=c[(c[f>>2]|0)+p>>2]|0}p=c[b+16>>2]|0;gB[c[(c[p>>2]|0)+20>>2]&127](p,d,e,f+q|0,(o&2|0)!=0?g:2,h);L17933:do{if((m|0)>1){o=d+24|0;q=b+8|0;p=d+54|0;r=f;s=b+24|0;do{if((a[p]&1)!=0){break L17933}do{if((a[i]&1)==0){if((a[k]&1)==0){break}if((c[q>>2]&1|0)==0){break L17933}}else{if((c[o>>2]|0)==1){break L17933}if((c[q>>2]&2|0)==0){break L17933}}}while(0);a[i]=0;a[k]=0;t=c[s+4>>2]|0;u=t>>8;if((t&1|0)==0){v=u}else{v=c[(c[r>>2]|0)+u>>2]|0}u=c[s>>2]|0;gB[c[(c[u>>2]|0)+20>>2]&127](u,d,e,f+v|0,(t&2|0)!=0?g:2,h);s=s+8|0;}while(s>>>0<n>>>0)}}while(0);a[i]=j;a[k]=l;return}a[d+53|0]=1;if((c[d+4>>2]|0)!=(f|0)){return}a[d+52|0]=1;f=d+16|0;l=c[f>>2]|0;if((l|0)==0){c[f>>2]=e;c[d+24>>2]=g;c[d+36>>2]=1;if(!((c[d+48>>2]|0)==1&(g|0)==1)){return}a[d+54|0]=1;return}if((l|0)!=(e|0)){e=d+36|0;c[e>>2]=(c[e>>2]|0)+1;a[d+54|0]=1;return}e=d+24|0;l=c[e>>2]|0;if((l|0)==2){c[e>>2]=g;w=g}else{w=l}if(!((c[d+48>>2]|0)==1&(w|0)==1)){return}a[d+54|0]=1;return}function gGo(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0;if((b|0)!=(c[d+8>>2]|0)){i=c[b+8>>2]|0;gB[c[(c[i>>2]|0)+20>>2]&127](i,d,e,f,g,h);return}a[d+53|0]=1;if((c[d+4>>2]|0)!=(f|0)){return}a[d+52|0]=1;f=d+16|0;h=c[f>>2]|0;if((h|0)==0){c[f>>2]=e;c[d+24>>2]=g;c[d+36>>2]=1;if(!((c[d+48>>2]|0)==1&(g|0)==1)){return}a[d+54|0]=1;return}if((h|0)!=(e|0)){e=d+36|0;c[e>>2]=(c[e>>2]|0)+1;a[d+54|0]=1;return}e=d+24|0;h=c[e>>2]|0;if((h|0)==2){c[e>>2]=g;j=g}else{j=h}if(!((c[d+48>>2]|0)==1&(j|0)==1)){return}a[d+54|0]=1;return}function gGp(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;if((c[d+8>>2]|0)!=(b|0)){return}a[d+53|0]=1;if((c[d+4>>2]|0)!=(f|0)){return}a[d+52|0]=1;f=d+16|0;b=c[f>>2]|0;if((b|0)==0){c[f>>2]=e;c[d+24>>2]=g;c[d+36>>2]=1;if(!((c[d+48>>2]|0)==1&(g|0)==1)){return}a[d+54|0]=1;return}if((b|0)!=(e|0)){e=d+36|0;c[e>>2]=(c[e>>2]|0)+1;a[d+54|0]=1;return}e=d+24|0;b=c[e>>2]|0;if((b|0)==2){c[e>>2]=g;i=g}else{i=b}if(!((c[d+48>>2]|0)==1&(i|0)==1)){return}a[d+54|0]=1;return}function gGq(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0;do{if(a>>>0<245){if(a>>>0<11){b=16}else{b=a+11&-8}d=b>>>3;e=c[2383598]|0;f=e>>>(d>>>0);if((f&3|0)!=0){g=(f&1^1)+d|0;h=g<<1;i=9534432+(h<<2)|0;j=9534432+(h+2<<2)|0;h=c[j>>2]|0;k=h+8|0;l=c[k>>2]|0;do{if((i|0)==(l|0)){c[2383598]=e&~(1<<g)}else{if(l>>>0<(c[2383602]|0)>>>0){bX();return 0}m=l+12|0;if((c[m>>2]|0)==(h|0)){c[m>>2]=i;c[j>>2]=l;break}else{bX();return 0}}}while(0);l=g<<3;c[h+4>>2]=l|3;j=h+(l|4)|0;c[j>>2]=c[j>>2]|1;n=k;return n|0}if(b>>>0<=(c[2383600]|0)>>>0){o=b;break}if((f|0)!=0){j=2<<d;l=f<<d&(j|-j);j=(l&-l)-1|0;l=j>>>12&16;i=j>>>(l>>>0);j=i>>>5&8;m=i>>>(j>>>0);i=m>>>2&4;p=m>>>(i>>>0);m=p>>>1&2;q=p>>>(m>>>0);p=q>>>1&1;r=(j|l|i|m|p)+(q>>>(p>>>0))|0;p=r<<1;q=9534432+(p<<2)|0;m=9534432+(p+2<<2)|0;p=c[m>>2]|0;i=p+8|0;l=c[i>>2]|0;do{if((q|0)==(l|0)){c[2383598]=e&~(1<<r)}else{if(l>>>0<(c[2383602]|0)>>>0){bX();return 0}j=l+12|0;if((c[j>>2]|0)==(p|0)){c[j>>2]=q;c[m>>2]=l;break}else{bX();return 0}}}while(0);l=r<<3;m=l-b|0;c[p+4>>2]=b|3;q=p;e=q+b|0;c[q+(b|4)>>2]=m|1;c[q+l>>2]=m;l=c[2383600]|0;if((l|0)!=0){q=c[2383603]|0;d=l>>>3;l=d<<1;f=9534432+(l<<2)|0;k=c[2383598]|0;h=1<<d;do{if((k&h|0)==0){c[2383598]=k|h;s=f;t=9534432+(l+2<<2)|0}else{d=9534432+(l+2<<2)|0;g=c[d>>2]|0;if(g>>>0>=(c[2383602]|0)>>>0){s=g;t=d;break}bX();return 0}}while(0);c[t>>2]=q;c[s+12>>2]=q;c[q+8>>2]=s;c[q+12>>2]=f}c[2383600]=m;c[2383603]=e;n=i;return n|0}l=c[2383599]|0;if((l|0)==0){o=b;break}h=(l&-l)-1|0;l=h>>>12&16;k=h>>>(l>>>0);h=k>>>5&8;p=k>>>(h>>>0);k=p>>>2&4;r=p>>>(k>>>0);p=r>>>1&2;d=r>>>(p>>>0);r=d>>>1&1;g=c[9534696+((h|l|k|p|r)+(d>>>(r>>>0))<<2)>>2]|0;r=g;d=g;p=(c[g+4>>2]&-8)-b|0;while(1){g=c[r+16>>2]|0;if((g|0)==0){k=c[r+20>>2]|0;if((k|0)==0){break}else{u=k}}else{u=g}g=(c[u+4>>2]&-8)-b|0;k=g>>>0<p>>>0;r=u;d=k?u:d;p=k?g:p}r=d;i=c[2383602]|0;if(r>>>0<i>>>0){bX();return 0}e=r+b|0;m=e;if(r>>>0>=e>>>0){bX();return 0}e=c[d+24>>2]|0;f=c[d+12>>2]|0;do{if((f|0)==(d|0)){q=d+20|0;g=c[q>>2]|0;if((g|0)==0){k=d+16|0;l=c[k>>2]|0;if((l|0)==0){v=0;break}else{w=l;x=k}}else{w=g;x=q}while(1){q=w+20|0;g=c[q>>2]|0;if((g|0)!=0){w=g;x=q;continue}q=w+16|0;g=c[q>>2]|0;if((g|0)==0){break}else{w=g;x=q}}if(x>>>0<i>>>0){bX();return 0}else{c[x>>2]=0;v=w;break}}else{q=c[d+8>>2]|0;if(q>>>0<i>>>0){bX();return 0}g=q+12|0;if((c[g>>2]|0)!=(d|0)){bX();return 0}k=f+8|0;if((c[k>>2]|0)==(d|0)){c[g>>2]=f;c[k>>2]=q;v=f;break}else{bX();return 0}}}while(0);L18100:do{if((e|0)!=0){f=d+28|0;i=9534696+(c[f>>2]<<2)|0;do{if((d|0)==(c[i>>2]|0)){c[i>>2]=v;if((v|0)!=0){break}c[2383599]=c[2383599]&~(1<<c[f>>2]);break L18100}else{if(e>>>0<(c[2383602]|0)>>>0){bX();return 0}q=e+16|0;if((c[q>>2]|0)==(d|0)){c[q>>2]=v}else{c[e+20>>2]=v}if((v|0)==0){break L18100}}}while(0);if(v>>>0<(c[2383602]|0)>>>0){bX();return 0}c[v+24>>2]=e;f=c[d+16>>2]|0;do{if((f|0)!=0){if(f>>>0<(c[2383602]|0)>>>0){bX();return 0}else{c[v+16>>2]=f;c[f+24>>2]=v;break}}}while(0);f=c[d+20>>2]|0;if((f|0)==0){break}if(f>>>0<(c[2383602]|0)>>>0){bX();return 0}else{c[v+20>>2]=f;c[f+24>>2]=v;break}}}while(0);if(p>>>0<16){e=p+b|0;c[d+4>>2]=e|3;f=r+(e+4)|0;c[f>>2]=c[f>>2]|1}else{c[d+4>>2]=b|3;c[r+(b|4)>>2]=p|1;c[r+(p+b)>>2]=p;f=c[2383600]|0;if((f|0)!=0){e=c[2383603]|0;i=f>>>3;f=i<<1;q=9534432+(f<<2)|0;k=c[2383598]|0;g=1<<i;do{if((k&g|0)==0){c[2383598]=k|g;y=q;z=9534432+(f+2<<2)|0}else{i=9534432+(f+2<<2)|0;l=c[i>>2]|0;if(l>>>0>=(c[2383602]|0)>>>0){y=l;z=i;break}bX();return 0}}while(0);c[z>>2]=e;c[y+12>>2]=e;c[e+8>>2]=y;c[e+12>>2]=q}c[2383600]=p;c[2383603]=m}f=d+8|0;if((f|0)==0){o=b;break}else{n=f}return n|0}else{if(a>>>0>4294967231){o=-1;break}f=a+11|0;g=f&-8;k=c[2383599]|0;if((k|0)==0){o=g;break}r=-g|0;i=f>>>8;do{if((i|0)==0){A=0}else{if(g>>>0>16777215){A=31;break}f=(i+1048320|0)>>>16&8;l=i<<f;h=(l+520192|0)>>>16&4;j=l<<h;l=(j+245760|0)>>>16&2;B=14-(h|f|l)+(j<<l>>>15)|0;A=g>>>((B+7|0)>>>0)&1|B<<1}}while(0);i=c[9534696+(A<<2)>>2]|0;L18148:do{if((i|0)==0){C=0;D=r;E=0}else{if((A|0)==31){F=0}else{F=25-(A>>>1)|0}d=0;m=r;p=i;q=g<<F;e=0;while(1){B=c[p+4>>2]&-8;l=B-g|0;if(l>>>0<m>>>0){if((B|0)==(g|0)){C=p;D=l;E=p;break L18148}else{G=p;H=l}}else{G=d;H=m}l=c[p+20>>2]|0;B=c[p+16+(q>>>31<<2)>>2]|0;j=(l|0)==0|(l|0)==(B|0)?e:l;if((B|0)==0){C=G;D=H;E=j;break}else{d=G;m=H;p=B;q=q<<1;e=j}}}}while(0);if((E|0)==0&(C|0)==0){i=2<<A;r=(i|-i)&k;if((r|0)==0){o=g;break}i=(r&-r)-1|0;r=i>>>12&16;e=i>>>(r>>>0);i=e>>>5&8;q=e>>>(i>>>0);e=q>>>2&4;p=q>>>(e>>>0);q=p>>>1&2;m=p>>>(q>>>0);p=m>>>1&1;I=c[9534696+((i|r|e|q|p)+(m>>>(p>>>0))<<2)>>2]|0}else{I=E}if((I|0)==0){J=D;K=C}else{p=I;m=D;q=C;while(1){e=(c[p+4>>2]&-8)-g|0;r=e>>>0<m>>>0;i=r?e:m;e=r?p:q;r=c[p+16>>2]|0;if((r|0)!=0){p=r;m=i;q=e;continue}r=c[p+20>>2]|0;if((r|0)==0){J=i;K=e;break}else{p=r;m=i;q=e}}}if((K|0)==0){o=g;break}if(J>>>0>=((c[2383600]|0)-g|0)>>>0){o=g;break}q=K;m=c[2383602]|0;if(q>>>0<m>>>0){bX();return 0}p=q+g|0;k=p;if(q>>>0>=p>>>0){bX();return 0}e=c[K+24>>2]|0;i=c[K+12>>2]|0;do{if((i|0)==(K|0)){r=K+20|0;d=c[r>>2]|0;if((d|0)==0){j=K+16|0;B=c[j>>2]|0;if((B|0)==0){L=0;break}else{M=B;N=j}}else{M=d;N=r}while(1){r=M+20|0;d=c[r>>2]|0;if((d|0)!=0){M=d;N=r;continue}r=M+16|0;d=c[r>>2]|0;if((d|0)==0){break}else{M=d;N=r}}if(N>>>0<m>>>0){bX();return 0}else{c[N>>2]=0;L=M;break}}else{r=c[K+8>>2]|0;if(r>>>0<m>>>0){bX();return 0}d=r+12|0;if((c[d>>2]|0)!=(K|0)){bX();return 0}j=i+8|0;if((c[j>>2]|0)==(K|0)){c[d>>2]=i;c[j>>2]=r;L=i;break}else{bX();return 0}}}while(0);L18198:do{if((e|0)!=0){i=K+28|0;m=9534696+(c[i>>2]<<2)|0;do{if((K|0)==(c[m>>2]|0)){c[m>>2]=L;if((L|0)!=0){break}c[2383599]=c[2383599]&~(1<<c[i>>2]);break L18198}else{if(e>>>0<(c[2383602]|0)>>>0){bX();return 0}r=e+16|0;if((c[r>>2]|0)==(K|0)){c[r>>2]=L}else{c[e+20>>2]=L}if((L|0)==0){break L18198}}}while(0);if(L>>>0<(c[2383602]|0)>>>0){bX();return 0}c[L+24>>2]=e;i=c[K+16>>2]|0;do{if((i|0)!=0){if(i>>>0<(c[2383602]|0)>>>0){bX();return 0}else{c[L+16>>2]=i;c[i+24>>2]=L;break}}}while(0);i=c[K+20>>2]|0;if((i|0)==0){break}if(i>>>0<(c[2383602]|0)>>>0){bX();return 0}else{c[L+20>>2]=i;c[i+24>>2]=L;break}}}while(0);do{if(J>>>0<16){e=J+g|0;c[K+4>>2]=e|3;i=q+(e+4)|0;c[i>>2]=c[i>>2]|1}else{c[K+4>>2]=g|3;c[q+(g|4)>>2]=J|1;c[q+(J+g)>>2]=J;i=J>>>3;if(J>>>0<256){e=i<<1;m=9534432+(e<<2)|0;r=c[2383598]|0;j=1<<i;do{if((r&j|0)==0){c[2383598]=r|j;O=m;P=9534432+(e+2<<2)|0}else{i=9534432+(e+2<<2)|0;d=c[i>>2]|0;if(d>>>0>=(c[2383602]|0)>>>0){O=d;P=i;break}bX();return 0}}while(0);c[P>>2]=k;c[O+12>>2]=k;c[q+(g+8)>>2]=O;c[q+(g+12)>>2]=m;break}e=p;j=J>>>8;do{if((j|0)==0){Q=0}else{if(J>>>0>16777215){Q=31;break}r=(j+1048320|0)>>>16&8;i=j<<r;d=(i+520192|0)>>>16&4;B=i<<d;i=(B+245760|0)>>>16&2;l=14-(d|r|i)+(B<<i>>>15)|0;Q=J>>>((l+7|0)>>>0)&1|l<<1}}while(0);j=9534696+(Q<<2)|0;c[q+(g+28)>>2]=Q;c[q+(g+20)>>2]=0;c[q+(g+16)>>2]=0;m=c[2383599]|0;l=1<<Q;if((m&l|0)==0){c[2383599]=m|l;c[j>>2]=e;c[q+(g+24)>>2]=j;c[q+(g+12)>>2]=e;c[q+(g+8)>>2]=e;break}if((Q|0)==31){R=0}else{R=25-(Q>>>1)|0}l=J<<R;m=c[j>>2]|0;while(1){if((c[m+4>>2]&-8|0)==(J|0)){break}S=m+16+(l>>>31<<2)|0;j=c[S>>2]|0;if((j|0)==0){T=15760;break}else{l=l<<1;m=j}}if((T|0)==15760){if(S>>>0<(c[2383602]|0)>>>0){bX();return 0}else{c[S>>2]=e;c[q+(g+24)>>2]=m;c[q+(g+12)>>2]=e;c[q+(g+8)>>2]=e;break}}l=m+8|0;j=c[l>>2]|0;i=c[2383602]|0;if(m>>>0<i>>>0){bX();return 0}if(j>>>0<i>>>0){bX();return 0}else{c[j+12>>2]=e;c[l>>2]=e;c[q+(g+8)>>2]=j;c[q+(g+12)>>2]=m;c[q+(g+24)>>2]=0;break}}}while(0);q=K+8|0;if((q|0)==0){o=g;break}else{n=q}return n|0}}while(0);K=c[2383600]|0;if(o>>>0<=K>>>0){S=K-o|0;J=c[2383603]|0;if(S>>>0>15){R=J;c[2383603]=R+o;c[2383600]=S;c[R+(o+4)>>2]=S|1;c[R+K>>2]=S;c[J+4>>2]=o|3}else{c[2383600]=0;c[2383603]=0;c[J+4>>2]=K|3;S=J+(K+4)|0;c[S>>2]=c[S>>2]|1}n=J+8|0;return n|0}J=c[2383601]|0;if(o>>>0<J>>>0){S=J-o|0;c[2383601]=S;J=c[2383604]|0;K=J;c[2383604]=K+o;c[K+(o+4)>>2]=S|1;c[J+4>>2]=o|3;n=J+8|0;return n|0}do{if((c[2113318]|0)==0){J=bW(30)|0;if((J-1&J|0)==0){c[2113320]=J;c[2113319]=J;c[2113321]=-1;c[2113322]=-1;c[2113323]=0;c[2383709]=0;c[2113318]=(gb(0)|0)&-16^1431655768;break}else{bX();return 0}}}while(0);J=o+48|0;S=c[2113320]|0;K=o+47|0;R=S+K|0;Q=-S|0;S=R&Q;if(S>>>0<=o>>>0){n=0;return n|0}O=c[2383708]|0;do{if((O|0)!=0){P=c[2383706]|0;L=P+S|0;if(L>>>0<=P>>>0|L>>>0>O>>>0){n=0}else{break}return n|0}}while(0);L18290:do{if((c[2383709]&4|0)==0){O=c[2383604]|0;L18292:do{if((O|0)==0){T=15790}else{L=O;P=9534840;while(1){U=P|0;M=c[U>>2]|0;if(M>>>0<=L>>>0){V=P+4|0;if((M+(c[V>>2]|0)|0)>>>0>L>>>0){break}}M=c[P+8>>2]|0;if((M|0)==0){T=15790;break L18292}else{P=M}}if((P|0)==0){T=15790;break}L=R-(c[2383601]|0)&Q;if(L>>>0>=2147483647){W=0;break}m=fJ(L|0)|0;e=(m|0)==((c[U>>2]|0)+(c[V>>2]|0)|0);X=e?m:-1;Y=e?L:0;Z=m;_=L;T=15799}}while(0);do{if((T|0)==15790){O=fJ(0)|0;if((O|0)==-1){W=0;break}g=O;L=c[2113319]|0;m=L-1|0;if((m&g|0)==0){$=S}else{$=S-g+(m+g&-L)|0}L=c[2383706]|0;g=L+$|0;if(!($>>>0>o>>>0&$>>>0<2147483647)){W=0;break}m=c[2383708]|0;if((m|0)!=0){if(g>>>0<=L>>>0|g>>>0>m>>>0){W=0;break}}m=fJ($|0)|0;g=(m|0)==(O|0);X=g?O:-1;Y=g?$:0;Z=m;_=$;T=15799}}while(0);L18312:do{if((T|0)==15799){m=-_|0;if((X|0)!=-1){aa=Y;ab=X;T=15810;break L18290}do{if((Z|0)!=-1&_>>>0<2147483647&_>>>0<J>>>0){g=c[2113320]|0;O=K-_+g&-g;if(O>>>0>=2147483647){ac=_;break}if((fJ(O|0)|0)==-1){fJ(m|0)|0;W=Y;break L18312}else{ac=O+_|0;break}}else{ac=_}}while(0);if((Z|0)==-1){W=Y}else{aa=ac;ab=Z;T=15810;break L18290}}}while(0);c[2383709]=c[2383709]|4;ad=W;T=15807}else{ad=0;T=15807}}while(0);do{if((T|0)==15807){if(S>>>0>=2147483647){break}W=fJ(S|0)|0;Z=fJ(0)|0;if(!((Z|0)!=-1&(W|0)!=-1&W>>>0<Z>>>0)){break}ac=Z-W|0;Z=ac>>>0>(o+40|0)>>>0;Y=Z?W:-1;if((Y|0)!=-1){aa=Z?ac:ad;ab=Y;T=15810}}}while(0);do{if((T|0)==15810){ad=(c[2383706]|0)+aa|0;c[2383706]=ad;if(ad>>>0>(c[2383707]|0)>>>0){c[2383707]=ad}ad=c[2383604]|0;L18332:do{if((ad|0)==0){S=c[2383602]|0;if((S|0)==0|ab>>>0<S>>>0){c[2383602]=ab}c[2383710]=ab;c[2383711]=aa;c[2383713]=0;c[2383607]=c[2113318];c[2383606]=-1;S=0;do{Y=S<<1;ac=9534432+(Y<<2)|0;c[9534432+(Y+3<<2)>>2]=ac;c[9534432+(Y+2<<2)>>2]=ac;S=S+1|0;}while(S>>>0<32);S=ab+8|0;if((S&7|0)==0){ae=0}else{ae=-S&7}S=aa-40-ae|0;c[2383604]=ab+ae;c[2383601]=S;c[ab+(ae+4)>>2]=S|1;c[ab+(aa-36)>>2]=40;c[2383605]=c[2113322]}else{S=9534840;while(1){af=c[S>>2]|0;ag=S+4|0;ah=c[ag>>2]|0;if((ab|0)==(af+ah|0)){T=15822;break}ac=c[S+8>>2]|0;if((ac|0)==0){break}else{S=ac}}do{if((T|0)==15822){if((c[S+12>>2]&8|0)!=0){break}ac=ad;if(!(ac>>>0>=af>>>0&ac>>>0<ab>>>0)){break}c[ag>>2]=ah+aa;ac=c[2383604]|0;Y=(c[2383601]|0)+aa|0;Z=ac;W=ac+8|0;if((W&7|0)==0){ai=0}else{ai=-W&7}W=Y-ai|0;c[2383604]=Z+ai;c[2383601]=W;c[Z+(ai+4)>>2]=W|1;c[Z+(Y+4)>>2]=40;c[2383605]=c[2113322];break L18332}}while(0);if(ab>>>0<(c[2383602]|0)>>>0){c[2383602]=ab}S=ab+aa|0;Y=9534840;while(1){aj=Y|0;if((c[aj>>2]|0)==(S|0)){T=15832;break}Z=c[Y+8>>2]|0;if((Z|0)==0){break}else{Y=Z}}do{if((T|0)==15832){if((c[Y+12>>2]&8|0)!=0){break}c[aj>>2]=ab;S=Y+4|0;c[S>>2]=(c[S>>2]|0)+aa;S=ab+8|0;if((S&7|0)==0){ak=0}else{ak=-S&7}S=ab+(aa+8)|0;if((S&7|0)==0){al=0}else{al=-S&7}S=ab+(al+aa)|0;Z=S;W=ak+o|0;ac=ab+W|0;_=ac;K=S-(ab+ak)-o|0;c[ab+(ak+4)>>2]=o|3;do{if((Z|0)==(c[2383604]|0)){J=(c[2383601]|0)+K|0;c[2383601]=J;c[2383604]=_;c[ab+(W+4)>>2]=J|1}else{if((Z|0)==(c[2383603]|0)){J=(c[2383600]|0)+K|0;c[2383600]=J;c[2383603]=_;c[ab+(W+4)>>2]=J|1;c[ab+(J+W)>>2]=J;break}J=aa+4|0;X=c[ab+(al+J)>>2]|0;if((X&3|0)==1){$=X&-8;V=X>>>3;L18367:do{if(X>>>0<256){U=c[ab+((al|8)+aa)>>2]|0;Q=c[ab+(aa+12+al)>>2]|0;R=9534432+(V<<1<<2)|0;do{if((U|0)!=(R|0)){if(U>>>0<(c[2383602]|0)>>>0){bX();return 0}if((c[U+12>>2]|0)==(Z|0)){break}bX();return 0}}while(0);if((Q|0)==(U|0)){c[2383598]=c[2383598]&~(1<<V);break}do{if((Q|0)==(R|0)){am=Q+8|0}else{if(Q>>>0<(c[2383602]|0)>>>0){bX();return 0}m=Q+8|0;if((c[m>>2]|0)==(Z|0)){am=m;break}bX();return 0}}while(0);c[U+12>>2]=Q;c[am>>2]=U}else{R=S;m=c[ab+((al|24)+aa)>>2]|0;P=c[ab+(aa+12+al)>>2]|0;do{if((P|0)==(R|0)){O=al|16;g=ab+(O+J)|0;L=c[g>>2]|0;if((L|0)==0){e=ab+(O+aa)|0;O=c[e>>2]|0;if((O|0)==0){an=0;break}else{ao=O;ap=e}}else{ao=L;ap=g}while(1){g=ao+20|0;L=c[g>>2]|0;if((L|0)!=0){ao=L;ap=g;continue}g=ao+16|0;L=c[g>>2]|0;if((L|0)==0){break}else{ao=L;ap=g}}if(ap>>>0<(c[2383602]|0)>>>0){bX();return 0}else{c[ap>>2]=0;an=ao;break}}else{g=c[ab+((al|8)+aa)>>2]|0;if(g>>>0<(c[2383602]|0)>>>0){bX();return 0}L=g+12|0;if((c[L>>2]|0)!=(R|0)){bX();return 0}e=P+8|0;if((c[e>>2]|0)==(R|0)){c[L>>2]=P;c[e>>2]=g;an=P;break}else{bX();return 0}}}while(0);if((m|0)==0){break}P=ab+(aa+28+al)|0;U=9534696+(c[P>>2]<<2)|0;do{if((R|0)==(c[U>>2]|0)){c[U>>2]=an;if((an|0)!=0){break}c[2383599]=c[2383599]&~(1<<c[P>>2]);break L18367}else{if(m>>>0<(c[2383602]|0)>>>0){bX();return 0}Q=m+16|0;if((c[Q>>2]|0)==(R|0)){c[Q>>2]=an}else{c[m+20>>2]=an}if((an|0)==0){break L18367}}}while(0);if(an>>>0<(c[2383602]|0)>>>0){bX();return 0}c[an+24>>2]=m;R=al|16;P=c[ab+(R+aa)>>2]|0;do{if((P|0)!=0){if(P>>>0<(c[2383602]|0)>>>0){bX();return 0}else{c[an+16>>2]=P;c[P+24>>2]=an;break}}}while(0);P=c[ab+(R+J)>>2]|0;if((P|0)==0){break}if(P>>>0<(c[2383602]|0)>>>0){bX();return 0}else{c[an+20>>2]=P;c[P+24>>2]=an;break}}}while(0);aq=ab+(($|al)+aa)|0;ar=$+K|0}else{aq=Z;ar=K}J=aq+4|0;c[J>>2]=c[J>>2]&-2;c[ab+(W+4)>>2]=ar|1;c[ab+(ar+W)>>2]=ar;J=ar>>>3;if(ar>>>0<256){V=J<<1;X=9534432+(V<<2)|0;P=c[2383598]|0;m=1<<J;do{if((P&m|0)==0){c[2383598]=P|m;as=X;at=9534432+(V+2<<2)|0}else{J=9534432+(V+2<<2)|0;U=c[J>>2]|0;if(U>>>0>=(c[2383602]|0)>>>0){as=U;at=J;break}bX();return 0}}while(0);c[at>>2]=_;c[as+12>>2]=_;c[ab+(W+8)>>2]=as;c[ab+(W+12)>>2]=X;break}V=ac;m=ar>>>8;do{if((m|0)==0){au=0}else{if(ar>>>0>16777215){au=31;break}P=(m+1048320|0)>>>16&8;$=m<<P;J=($+520192|0)>>>16&4;U=$<<J;$=(U+245760|0)>>>16&2;Q=14-(J|P|$)+(U<<$>>>15)|0;au=ar>>>((Q+7|0)>>>0)&1|Q<<1}}while(0);m=9534696+(au<<2)|0;c[ab+(W+28)>>2]=au;c[ab+(W+20)>>2]=0;c[ab+(W+16)>>2]=0;X=c[2383599]|0;Q=1<<au;if((X&Q|0)==0){c[2383599]=X|Q;c[m>>2]=V;c[ab+(W+24)>>2]=m;c[ab+(W+12)>>2]=V;c[ab+(W+8)>>2]=V;break}if((au|0)==31){av=0}else{av=25-(au>>>1)|0}Q=ar<<av;X=c[m>>2]|0;while(1){if((c[X+4>>2]&-8|0)==(ar|0)){break}aw=X+16+(Q>>>31<<2)|0;m=c[aw>>2]|0;if((m|0)==0){T=15905;break}else{Q=Q<<1;X=m}}if((T|0)==15905){if(aw>>>0<(c[2383602]|0)>>>0){bX();return 0}else{c[aw>>2]=V;c[ab+(W+24)>>2]=X;c[ab+(W+12)>>2]=V;c[ab+(W+8)>>2]=V;break}}Q=X+8|0;m=c[Q>>2]|0;$=c[2383602]|0;if(X>>>0<$>>>0){bX();return 0}if(m>>>0<$>>>0){bX();return 0}else{c[m+12>>2]=V;c[Q>>2]=V;c[ab+(W+8)>>2]=m;c[ab+(W+12)>>2]=X;c[ab+(W+24)>>2]=0;break}}}while(0);n=ab+(ak|8)|0;return n|0}}while(0);Y=ad;W=9534840;while(1){ax=c[W>>2]|0;if(ax>>>0<=Y>>>0){ay=c[W+4>>2]|0;az=ax+ay|0;if(az>>>0>Y>>>0){break}}W=c[W+8>>2]|0}W=ax+(ay-39)|0;if((W&7|0)==0){aA=0}else{aA=-W&7}W=ax+(ay-47+aA)|0;ac=W>>>0<(ad+16|0)>>>0?Y:W;W=ac+8|0;_=ab+8|0;if((_&7|0)==0){aB=0}else{aB=-_&7}_=aa-40-aB|0;c[2383604]=ab+aB;c[2383601]=_;c[ab+(aB+4)>>2]=_|1;c[ab+(aa-36)>>2]=40;c[2383605]=c[2113322];c[ac+4>>2]=27;c[W>>2]=c[2383710];c[W+4>>2]=c[2383711];c[W+8>>2]=c[2383712];c[W+12>>2]=c[2383713];c[2383710]=ab;c[2383711]=aa;c[2383713]=0;c[2383712]=W;W=ac+28|0;c[W>>2]=7;if((ac+32|0)>>>0<az>>>0){_=W;while(1){W=_+4|0;c[W>>2]=7;if((_+8|0)>>>0<az>>>0){_=W}else{break}}}if((ac|0)==(Y|0)){break}_=ac-ad|0;W=Y+(_+4)|0;c[W>>2]=c[W>>2]&-2;c[ad+4>>2]=_|1;c[Y+_>>2]=_;W=_>>>3;if(_>>>0<256){K=W<<1;Z=9534432+(K<<2)|0;S=c[2383598]|0;m=1<<W;do{if((S&m|0)==0){c[2383598]=S|m;aC=Z;aD=9534432+(K+2<<2)|0}else{W=9534432+(K+2<<2)|0;Q=c[W>>2]|0;if(Q>>>0>=(c[2383602]|0)>>>0){aC=Q;aD=W;break}bX();return 0}}while(0);c[aD>>2]=ad;c[aC+12>>2]=ad;c[ad+8>>2]=aC;c[ad+12>>2]=Z;break}K=ad;m=_>>>8;do{if((m|0)==0){aE=0}else{if(_>>>0>16777215){aE=31;break}S=(m+1048320|0)>>>16&8;Y=m<<S;ac=(Y+520192|0)>>>16&4;W=Y<<ac;Y=(W+245760|0)>>>16&2;Q=14-(ac|S|Y)+(W<<Y>>>15)|0;aE=_>>>((Q+7|0)>>>0)&1|Q<<1}}while(0);m=9534696+(aE<<2)|0;c[ad+28>>2]=aE;c[ad+20>>2]=0;c[ad+16>>2]=0;Z=c[2383599]|0;Q=1<<aE;if((Z&Q|0)==0){c[2383599]=Z|Q;c[m>>2]=K;c[ad+24>>2]=m;c[ad+12>>2]=ad;c[ad+8>>2]=ad;break}if((aE|0)==31){aF=0}else{aF=25-(aE>>>1)|0}Q=_<<aF;Z=c[m>>2]|0;while(1){if((c[Z+4>>2]&-8|0)==(_|0)){break}aG=Z+16+(Q>>>31<<2)|0;m=c[aG>>2]|0;if((m|0)==0){T=15940;break}else{Q=Q<<1;Z=m}}if((T|0)==15940){if(aG>>>0<(c[2383602]|0)>>>0){bX();return 0}else{c[aG>>2]=K;c[ad+24>>2]=Z;c[ad+12>>2]=ad;c[ad+8>>2]=ad;break}}Q=Z+8|0;_=c[Q>>2]|0;m=c[2383602]|0;if(Z>>>0<m>>>0){bX();return 0}if(_>>>0<m>>>0){bX();return 0}else{c[_+12>>2]=K;c[Q>>2]=K;c[ad+8>>2]=_;c[ad+12>>2]=Z;c[ad+24>>2]=0;break}}}while(0);ad=c[2383601]|0;if(ad>>>0<=o>>>0){break}_=ad-o|0;c[2383601]=_;ad=c[2383604]|0;Q=ad;c[2383604]=Q+o;c[Q+(o+4)>>2]=_|1;c[ad+4>>2]=o|3;n=ad+8|0;return n|0}}while(0);c[(bO()|0)>>2]=12;n=0;return n|0}function gGr(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;if((a|0)==0){return}b=a-8|0;d=b;e=c[2383602]|0;if(b>>>0<e>>>0){bX()}f=c[a-4>>2]|0;g=f&3;if((g|0)==1){bX()}h=f&-8;i=a+(h-8)|0;j=i;L18549:do{if((f&1|0)==0){k=c[b>>2]|0;if((g|0)==0){return}l=-8-k|0;m=a+l|0;n=m;o=k+h|0;if(m>>>0<e>>>0){bX()}if((n|0)==(c[2383603]|0)){p=a+(h-4)|0;if((c[p>>2]&3|0)!=3){q=n;r=o;break}c[2383600]=o;c[p>>2]=c[p>>2]&-2;c[a+(l+4)>>2]=o|1;c[i>>2]=o;return}p=k>>>3;if(k>>>0<256){k=c[a+(l+8)>>2]|0;s=c[a+(l+12)>>2]|0;t=9534432+(p<<1<<2)|0;do{if((k|0)!=(t|0)){if(k>>>0<e>>>0){bX()}if((c[k+12>>2]|0)==(n|0)){break}bX()}}while(0);if((s|0)==(k|0)){c[2383598]=c[2383598]&~(1<<p);q=n;r=o;break}do{if((s|0)==(t|0)){u=s+8|0}else{if(s>>>0<e>>>0){bX()}v=s+8|0;if((c[v>>2]|0)==(n|0)){u=v;break}bX()}}while(0);c[k+12>>2]=s;c[u>>2]=k;q=n;r=o;break}t=m;p=c[a+(l+24)>>2]|0;v=c[a+(l+12)>>2]|0;do{if((v|0)==(t|0)){w=a+(l+20)|0;x=c[w>>2]|0;if((x|0)==0){y=a+(l+16)|0;z=c[y>>2]|0;if((z|0)==0){A=0;break}else{B=z;C=y}}else{B=x;C=w}while(1){w=B+20|0;x=c[w>>2]|0;if((x|0)!=0){B=x;C=w;continue}w=B+16|0;x=c[w>>2]|0;if((x|0)==0){break}else{B=x;C=w}}if(C>>>0<e>>>0){bX()}else{c[C>>2]=0;A=B;break}}else{w=c[a+(l+8)>>2]|0;if(w>>>0<e>>>0){bX()}x=w+12|0;if((c[x>>2]|0)!=(t|0)){bX()}y=v+8|0;if((c[y>>2]|0)==(t|0)){c[x>>2]=v;c[y>>2]=w;A=v;break}else{bX()}}}while(0);if((p|0)==0){q=n;r=o;break}v=a+(l+28)|0;m=9534696+(c[v>>2]<<2)|0;do{if((t|0)==(c[m>>2]|0)){c[m>>2]=A;if((A|0)!=0){break}c[2383599]=c[2383599]&~(1<<c[v>>2]);q=n;r=o;break L18549}else{if(p>>>0<(c[2383602]|0)>>>0){bX()}k=p+16|0;if((c[k>>2]|0)==(t|0)){c[k>>2]=A}else{c[p+20>>2]=A}if((A|0)==0){q=n;r=o;break L18549}}}while(0);if(A>>>0<(c[2383602]|0)>>>0){bX()}c[A+24>>2]=p;t=c[a+(l+16)>>2]|0;do{if((t|0)!=0){if(t>>>0<(c[2383602]|0)>>>0){bX()}else{c[A+16>>2]=t;c[t+24>>2]=A;break}}}while(0);t=c[a+(l+20)>>2]|0;if((t|0)==0){q=n;r=o;break}if(t>>>0<(c[2383602]|0)>>>0){bX()}else{c[A+20>>2]=t;c[t+24>>2]=A;q=n;r=o;break}}else{q=d;r=h}}while(0);d=q;if(d>>>0>=i>>>0){bX()}A=a+(h-4)|0;e=c[A>>2]|0;if((e&1|0)==0){bX()}do{if((e&2|0)==0){if((j|0)==(c[2383604]|0)){B=(c[2383601]|0)+r|0;c[2383601]=B;c[2383604]=q;c[q+4>>2]=B|1;if((q|0)!=(c[2383603]|0)){return}c[2383603]=0;c[2383600]=0;return}if((j|0)==(c[2383603]|0)){B=(c[2383600]|0)+r|0;c[2383600]=B;c[2383603]=q;c[q+4>>2]=B|1;c[d+B>>2]=B;return}B=(e&-8)+r|0;C=e>>>3;L18651:do{if(e>>>0<256){u=c[a+h>>2]|0;g=c[a+(h|4)>>2]|0;b=9534432+(C<<1<<2)|0;do{if((u|0)!=(b|0)){if(u>>>0<(c[2383602]|0)>>>0){bX()}if((c[u+12>>2]|0)==(j|0)){break}bX()}}while(0);if((g|0)==(u|0)){c[2383598]=c[2383598]&~(1<<C);break}do{if((g|0)==(b|0)){D=g+8|0}else{if(g>>>0<(c[2383602]|0)>>>0){bX()}f=g+8|0;if((c[f>>2]|0)==(j|0)){D=f;break}bX()}}while(0);c[u+12>>2]=g;c[D>>2]=u}else{b=i;f=c[a+(h+16)>>2]|0;t=c[a+(h|4)>>2]|0;do{if((t|0)==(b|0)){p=a+(h+12)|0;v=c[p>>2]|0;if((v|0)==0){m=a+(h+8)|0;k=c[m>>2]|0;if((k|0)==0){E=0;break}else{F=k;G=m}}else{F=v;G=p}while(1){p=F+20|0;v=c[p>>2]|0;if((v|0)!=0){F=v;G=p;continue}p=F+16|0;v=c[p>>2]|0;if((v|0)==0){break}else{F=v;G=p}}if(G>>>0<(c[2383602]|0)>>>0){bX()}else{c[G>>2]=0;E=F;break}}else{p=c[a+h>>2]|0;if(p>>>0<(c[2383602]|0)>>>0){bX()}v=p+12|0;if((c[v>>2]|0)!=(b|0)){bX()}m=t+8|0;if((c[m>>2]|0)==(b|0)){c[v>>2]=t;c[m>>2]=p;E=t;break}else{bX()}}}while(0);if((f|0)==0){break}t=a+(h+20)|0;u=9534696+(c[t>>2]<<2)|0;do{if((b|0)==(c[u>>2]|0)){c[u>>2]=E;if((E|0)!=0){break}c[2383599]=c[2383599]&~(1<<c[t>>2]);break L18651}else{if(f>>>0<(c[2383602]|0)>>>0){bX()}g=f+16|0;if((c[g>>2]|0)==(b|0)){c[g>>2]=E}else{c[f+20>>2]=E}if((E|0)==0){break L18651}}}while(0);if(E>>>0<(c[2383602]|0)>>>0){bX()}c[E+24>>2]=f;b=c[a+(h+8)>>2]|0;do{if((b|0)!=0){if(b>>>0<(c[2383602]|0)>>>0){bX()}else{c[E+16>>2]=b;c[b+24>>2]=E;break}}}while(0);b=c[a+(h+12)>>2]|0;if((b|0)==0){break}if(b>>>0<(c[2383602]|0)>>>0){bX()}else{c[E+20>>2]=b;c[b+24>>2]=E;break}}}while(0);c[q+4>>2]=B|1;c[d+B>>2]=B;if((q|0)!=(c[2383603]|0)){H=B;break}c[2383600]=B;return}else{c[A>>2]=e&-2;c[q+4>>2]=r|1;c[d+r>>2]=r;H=r}}while(0);r=H>>>3;if(H>>>0<256){d=r<<1;e=9534432+(d<<2)|0;A=c[2383598]|0;E=1<<r;do{if((A&E|0)==0){c[2383598]=A|E;I=e;J=9534432+(d+2<<2)|0}else{r=9534432+(d+2<<2)|0;h=c[r>>2]|0;if(h>>>0>=(c[2383602]|0)>>>0){I=h;J=r;break}bX()}}while(0);c[J>>2]=q;c[I+12>>2]=q;c[q+8>>2]=I;c[q+12>>2]=e;return}e=q;I=H>>>8;do{if((I|0)==0){K=0}else{if(H>>>0>16777215){K=31;break}J=(I+1048320|0)>>>16&8;d=I<<J;E=(d+520192|0)>>>16&4;A=d<<E;d=(A+245760|0)>>>16&2;r=14-(E|J|d)+(A<<d>>>15)|0;K=H>>>((r+7|0)>>>0)&1|r<<1}}while(0);I=9534696+(K<<2)|0;c[q+28>>2]=K;c[q+20>>2]=0;c[q+16>>2]=0;r=c[2383599]|0;d=1<<K;do{if((r&d|0)==0){c[2383599]=r|d;c[I>>2]=e;c[q+24>>2]=I;c[q+12>>2]=q;c[q+8>>2]=q}else{if((K|0)==31){L=0}else{L=25-(K>>>1)|0}A=H<<L;J=c[I>>2]|0;while(1){if((c[J+4>>2]&-8|0)==(H|0)){break}M=J+16+(A>>>31<<2)|0;E=c[M>>2]|0;if((E|0)==0){N=16117;break}else{A=A<<1;J=E}}if((N|0)==16117){if(M>>>0<(c[2383602]|0)>>>0){bX()}else{c[M>>2]=e;c[q+24>>2]=J;c[q+12>>2]=q;c[q+8>>2]=q;break}}A=J+8|0;B=c[A>>2]|0;E=c[2383602]|0;if(J>>>0<E>>>0){bX()}if(B>>>0<E>>>0){bX()}else{c[B+12>>2]=e;c[A>>2]=e;c[q+8>>2]=B;c[q+12>>2]=J;c[q+24>>2]=0;break}}}while(0);q=(c[2383606]|0)-1|0;c[2383606]=q;if((q|0)==0){O=9534848}else{return}while(1){q=c[O>>2]|0;if((q|0)==0){break}else{O=q+8|0}}c[2383606]=-1;return}function gGs(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;if((a|0)==0){d=gGq(b)|0;return d|0}if(b>>>0>4294967231){c[(bO()|0)>>2]=12;d=0;return d|0}if(b>>>0<11){e=16}else{e=b+11&-8}f=a-8|0;g=a-4|0;h=c[g>>2]|0;i=h&-8;j=i-8|0;k=a+j|0;l=k;m=c[2383602]|0;if(f>>>0<m>>>0){bX();return 0}n=h&3;if(!((n|0)!=1&(j|0)>-8)){bX();return 0}j=i|4;o=a+(j-8)|0;p=c[o>>2]|0;if((p&1|0)==0){bX();return 0}L18787:do{if((n|0)==0){if(e>>>0<256|i>>>0<(e|4)>>>0){break}if((i-e|0)>>>0>c[2113320]<<1>>>0|(f|0)==0){break}else{d=a}return d|0}else{do{if(i>>>0<e>>>0){if((l|0)==(c[2383604]|0)){q=(c[2383601]|0)+i|0;if(q>>>0<=e>>>0){break L18787}r=q-e|0;c[g>>2]=h&1|e|2;c[a+((e|4)-8)>>2]=r|1;c[2383604]=a+(e-8);c[2383601]=r;break}if((l|0)==(c[2383603]|0)){r=(c[2383600]|0)+i|0;if(r>>>0<e>>>0){break L18787}q=r-e|0;if(q>>>0>15){c[g>>2]=h&1|e|2;c[a+((e|4)-8)>>2]=q|1;c[a+(r-8)>>2]=q;s=a+(r-4)|0;c[s>>2]=c[s>>2]&-2;t=a+(e-8)|0;u=q}else{c[g>>2]=h&1|r|2;q=a+(r-4)|0;c[q>>2]=c[q>>2]|1;t=0;u=0}c[2383600]=u;c[2383603]=t;break}if((p&2|0)!=0){break L18787}q=(p&-8)+i|0;if(q>>>0<e>>>0){break L18787}r=q-e|0;s=p>>>3;L18805:do{if(p>>>0<256){v=c[a+i>>2]|0;w=c[a+j>>2]|0;x=9534432+(s<<1<<2)|0;do{if((v|0)!=(x|0)){if(v>>>0<m>>>0){bX();return 0}if((c[v+12>>2]|0)==(l|0)){break}bX();return 0}}while(0);if((w|0)==(v|0)){c[2383598]=c[2383598]&~(1<<s);break}do{if((w|0)==(x|0)){y=w+8|0}else{if(w>>>0<m>>>0){bX();return 0}z=w+8|0;if((c[z>>2]|0)==(l|0)){y=z;break}bX();return 0}}while(0);c[v+12>>2]=w;c[y>>2]=v}else{x=k;z=c[a+(i+16)>>2]|0;A=c[a+j>>2]|0;do{if((A|0)==(x|0)){B=a+(i+12)|0;C=c[B>>2]|0;if((C|0)==0){D=a+(i+8)|0;E=c[D>>2]|0;if((E|0)==0){F=0;break}else{G=E;H=D}}else{G=C;H=B}while(1){B=G+20|0;C=c[B>>2]|0;if((C|0)!=0){G=C;H=B;continue}B=G+16|0;C=c[B>>2]|0;if((C|0)==0){break}else{G=C;H=B}}if(H>>>0<m>>>0){bX();return 0}else{c[H>>2]=0;F=G;break}}else{B=c[a+i>>2]|0;if(B>>>0<m>>>0){bX();return 0}C=B+12|0;if((c[C>>2]|0)!=(x|0)){bX();return 0}D=A+8|0;if((c[D>>2]|0)==(x|0)){c[C>>2]=A;c[D>>2]=B;F=A;break}else{bX();return 0}}}while(0);if((z|0)==0){break}A=a+(i+20)|0;v=9534696+(c[A>>2]<<2)|0;do{if((x|0)==(c[v>>2]|0)){c[v>>2]=F;if((F|0)!=0){break}c[2383599]=c[2383599]&~(1<<c[A>>2]);break L18805}else{if(z>>>0<(c[2383602]|0)>>>0){bX();return 0}w=z+16|0;if((c[w>>2]|0)==(x|0)){c[w>>2]=F}else{c[z+20>>2]=F}if((F|0)==0){break L18805}}}while(0);if(F>>>0<(c[2383602]|0)>>>0){bX();return 0}c[F+24>>2]=z;x=c[a+(i+8)>>2]|0;do{if((x|0)!=0){if(x>>>0<(c[2383602]|0)>>>0){bX();return 0}else{c[F+16>>2]=x;c[x+24>>2]=F;break}}}while(0);x=c[a+(i+12)>>2]|0;if((x|0)==0){break}if(x>>>0<(c[2383602]|0)>>>0){bX();return 0}else{c[F+20>>2]=x;c[x+24>>2]=F;break}}}while(0);if(r>>>0>=16){c[g>>2]=c[g>>2]&1|e|2;c[a+((e|4)-8)>>2]=r|3;s=a+((q|4)-8)|0;c[s>>2]=c[s>>2]|1;gGt(a+(e-8)|0,r);break}c[g>>2]=q|c[g>>2]&1|2;s=a+((q|4)-8)|0;c[s>>2]=c[s>>2]|1;d=a;return d|0}else{s=i-e|0;if(s>>>0<=15){break}c[g>>2]=h&1|e|2;c[a+((e|4)-8)>>2]=s|3;c[o>>2]=c[o>>2]|1;gGt(a+(e-8)|0,s);d=a;return d|0}}while(0);if((f|0)==0){break}else{d=a}return d|0}}while(0);f=gGq(b)|0;if((f|0)==0){d=0;return d|0}e=c[g>>2]|0;g=(e&-8)-((e&3|0)==0?8:4)|0;e=g>>>0<b>>>0?g:b;gGC(f|0,a|0,e)|0;gGr(a);d=f;return d|0}function gGt(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;d=a;e=d+b|0;f=e;g=c[a+4>>2]|0;L18893:do{if((g&1|0)==0){h=c[a>>2]|0;if((g&3|0)==0){return}i=d+(-h|0)|0;j=i;k=h+b|0;l=c[2383602]|0;if(i>>>0<l>>>0){bX()}if((j|0)==(c[2383603]|0)){m=d+(b+4)|0;if((c[m>>2]&3|0)!=3){n=j;o=k;break}c[2383600]=k;c[m>>2]=c[m>>2]&-2;c[d+(4-h)>>2]=k|1;c[e>>2]=k;return}m=h>>>3;if(h>>>0<256){p=c[d+(8-h)>>2]|0;q=c[d+(12-h)>>2]|0;r=9534432+(m<<1<<2)|0;do{if((p|0)!=(r|0)){if(p>>>0<l>>>0){bX()}if((c[p+12>>2]|0)==(j|0)){break}bX()}}while(0);if((q|0)==(p|0)){c[2383598]=c[2383598]&~(1<<m);n=j;o=k;break}do{if((q|0)==(r|0)){s=q+8|0}else{if(q>>>0<l>>>0){bX()}t=q+8|0;if((c[t>>2]|0)==(j|0)){s=t;break}bX()}}while(0);c[p+12>>2]=q;c[s>>2]=p;n=j;o=k;break}r=i;m=c[d+(24-h)>>2]|0;t=c[d+(12-h)>>2]|0;do{if((t|0)==(r|0)){u=16-h|0;v=d+(u+4)|0;w=c[v>>2]|0;if((w|0)==0){x=d+u|0;u=c[x>>2]|0;if((u|0)==0){y=0;break}else{z=u;A=x}}else{z=w;A=v}while(1){v=z+20|0;w=c[v>>2]|0;if((w|0)!=0){z=w;A=v;continue}v=z+16|0;w=c[v>>2]|0;if((w|0)==0){break}else{z=w;A=v}}if(A>>>0<l>>>0){bX()}else{c[A>>2]=0;y=z;break}}else{v=c[d+(8-h)>>2]|0;if(v>>>0<l>>>0){bX()}w=v+12|0;if((c[w>>2]|0)!=(r|0)){bX()}x=t+8|0;if((c[x>>2]|0)==(r|0)){c[w>>2]=t;c[x>>2]=v;y=t;break}else{bX()}}}while(0);if((m|0)==0){n=j;o=k;break}t=d+(28-h)|0;l=9534696+(c[t>>2]<<2)|0;do{if((r|0)==(c[l>>2]|0)){c[l>>2]=y;if((y|0)!=0){break}c[2383599]=c[2383599]&~(1<<c[t>>2]);n=j;o=k;break L18893}else{if(m>>>0<(c[2383602]|0)>>>0){bX()}i=m+16|0;if((c[i>>2]|0)==(r|0)){c[i>>2]=y}else{c[m+20>>2]=y}if((y|0)==0){n=j;o=k;break L18893}}}while(0);if(y>>>0<(c[2383602]|0)>>>0){bX()}c[y+24>>2]=m;r=16-h|0;t=c[d+r>>2]|0;do{if((t|0)!=0){if(t>>>0<(c[2383602]|0)>>>0){bX()}else{c[y+16>>2]=t;c[t+24>>2]=y;break}}}while(0);t=c[d+(r+4)>>2]|0;if((t|0)==0){n=j;o=k;break}if(t>>>0<(c[2383602]|0)>>>0){bX()}else{c[y+20>>2]=t;c[t+24>>2]=y;n=j;o=k;break}}else{n=a;o=b}}while(0);a=c[2383602]|0;if(e>>>0<a>>>0){bX()}y=d+(b+4)|0;z=c[y>>2]|0;do{if((z&2|0)==0){if((f|0)==(c[2383604]|0)){A=(c[2383601]|0)+o|0;c[2383601]=A;c[2383604]=n;c[n+4>>2]=A|1;if((n|0)!=(c[2383603]|0)){return}c[2383603]=0;c[2383600]=0;return}if((f|0)==(c[2383603]|0)){A=(c[2383600]|0)+o|0;c[2383600]=A;c[2383603]=n;c[n+4>>2]=A|1;c[n+A>>2]=A;return}A=(z&-8)+o|0;s=z>>>3;L18992:do{if(z>>>0<256){g=c[d+(b+8)>>2]|0;t=c[d+(b+12)>>2]|0;h=9534432+(s<<1<<2)|0;do{if((g|0)!=(h|0)){if(g>>>0<a>>>0){bX()}if((c[g+12>>2]|0)==(f|0)){break}bX()}}while(0);if((t|0)==(g|0)){c[2383598]=c[2383598]&~(1<<s);break}do{if((t|0)==(h|0)){B=t+8|0}else{if(t>>>0<a>>>0){bX()}m=t+8|0;if((c[m>>2]|0)==(f|0)){B=m;break}bX()}}while(0);c[g+12>>2]=t;c[B>>2]=g}else{h=e;m=c[d+(b+24)>>2]|0;l=c[d+(b+12)>>2]|0;do{if((l|0)==(h|0)){i=d+(b+20)|0;p=c[i>>2]|0;if((p|0)==0){q=d+(b+16)|0;v=c[q>>2]|0;if((v|0)==0){C=0;break}else{D=v;E=q}}else{D=p;E=i}while(1){i=D+20|0;p=c[i>>2]|0;if((p|0)!=0){D=p;E=i;continue}i=D+16|0;p=c[i>>2]|0;if((p|0)==0){break}else{D=p;E=i}}if(E>>>0<a>>>0){bX()}else{c[E>>2]=0;C=D;break}}else{i=c[d+(b+8)>>2]|0;if(i>>>0<a>>>0){bX()}p=i+12|0;if((c[p>>2]|0)!=(h|0)){bX()}q=l+8|0;if((c[q>>2]|0)==(h|0)){c[p>>2]=l;c[q>>2]=i;C=l;break}else{bX()}}}while(0);if((m|0)==0){break}l=d+(b+28)|0;g=9534696+(c[l>>2]<<2)|0;do{if((h|0)==(c[g>>2]|0)){c[g>>2]=C;if((C|0)!=0){break}c[2383599]=c[2383599]&~(1<<c[l>>2]);break L18992}else{if(m>>>0<(c[2383602]|0)>>>0){bX()}t=m+16|0;if((c[t>>2]|0)==(h|0)){c[t>>2]=C}else{c[m+20>>2]=C}if((C|0)==0){break L18992}}}while(0);if(C>>>0<(c[2383602]|0)>>>0){bX()}c[C+24>>2]=m;h=c[d+(b+16)>>2]|0;do{if((h|0)!=0){if(h>>>0<(c[2383602]|0)>>>0){bX()}else{c[C+16>>2]=h;c[h+24>>2]=C;break}}}while(0);h=c[d+(b+20)>>2]|0;if((h|0)==0){break}if(h>>>0<(c[2383602]|0)>>>0){bX()}else{c[C+20>>2]=h;c[h+24>>2]=C;break}}}while(0);c[n+4>>2]=A|1;c[n+A>>2]=A;if((n|0)!=(c[2383603]|0)){F=A;break}c[2383600]=A;return}else{c[y>>2]=z&-2;c[n+4>>2]=o|1;c[n+o>>2]=o;F=o}}while(0);o=F>>>3;if(F>>>0<256){z=o<<1;y=9534432+(z<<2)|0;C=c[2383598]|0;b=1<<o;do{if((C&b|0)==0){c[2383598]=C|b;G=y;H=9534432+(z+2<<2)|0}else{o=9534432+(z+2<<2)|0;d=c[o>>2]|0;if(d>>>0>=(c[2383602]|0)>>>0){G=d;H=o;break}bX()}}while(0);c[H>>2]=n;c[G+12>>2]=n;c[n+8>>2]=G;c[n+12>>2]=y;return}y=n;G=F>>>8;do{if((G|0)==0){I=0}else{if(F>>>0>16777215){I=31;break}H=(G+1048320|0)>>>16&8;z=G<<H;b=(z+520192|0)>>>16&4;C=z<<b;z=(C+245760|0)>>>16&2;o=14-(b|H|z)+(C<<z>>>15)|0;I=F>>>((o+7|0)>>>0)&1|o<<1}}while(0);G=9534696+(I<<2)|0;c[n+28>>2]=I;c[n+20>>2]=0;c[n+16>>2]=0;o=c[2383599]|0;z=1<<I;if((o&z|0)==0){c[2383599]=o|z;c[G>>2]=y;c[n+24>>2]=G;c[n+12>>2]=n;c[n+8>>2]=n;return}if((I|0)==31){J=0}else{J=25-(I>>>1)|0}I=F<<J;J=c[G>>2]|0;while(1){if((c[J+4>>2]&-8|0)==(F|0)){break}K=J+16+(I>>>31<<2)|0;G=c[K>>2]|0;if((G|0)==0){L=16383;break}else{I=I<<1;J=G}}if((L|0)==16383){if(K>>>0<(c[2383602]|0)>>>0){bX()}c[K>>2]=y;c[n+24>>2]=J;c[n+12>>2]=n;c[n+8>>2]=n;return}K=J+8|0;L=c[K>>2]|0;I=c[2383602]|0;if(J>>>0<I>>>0){bX()}if(L>>>0<I>>>0){bX()}c[L+12>>2]=y;c[K>>2]=y;c[n+8>>2]=L;c[n+12>>2]=J;c[n+24>>2]=0;return}function gGu(a){a=a|0;if((a|0)==0){return}gGr(a);return}function gGv(a){a=a|0;return}function gGw(a){a=a|0;return 307464}function gGx(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0.0,r=0,s=0,t=0,u=0,v=0.0,w=0,x=0,y=0,z=0.0,A=0.0,B=0,C=0,D=0,E=0.0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0.0,O=0,P=0,Q=0.0,R=0.0,S=0.0;e=b;while(1){f=e+1|0;if((a4(a[e]|0)|0)==0){break}else{e=f}}g=a[e]|0;if((g<<24>>24|0)==43){i=f;j=0}else if((g<<24>>24|0)==45){i=f;j=1}else{i=e;j=0}e=-1;f=0;g=i;while(1){k=a[g]|0;if(((k<<24>>24)-48|0)>>>0<10){l=e}else{if(k<<24>>24!=46|(e|0)>-1){break}else{l=f}}e=l;f=f+1|0;g=g+1|0}l=g+(-f|0)|0;i=(e|0)<0;m=((i^1)<<31>>31)+f|0;n=(m|0)>18;o=(n?-18:-m|0)+(i?f:e)|0;e=n?18:m;do{if((e|0)==0){p=b;q=0.0}else{if((e|0)>9){m=l;n=e;f=0;while(1){i=a[m]|0;r=m+1|0;if(i<<24>>24==46){s=a[r]|0;t=m+2|0}else{s=i;t=r}u=(f*10|0)-48+(s<<24>>24)|0;r=n-1|0;if((r|0)>9){m=t;n=r;f=u}else{break}}v=+(u|0)*1.0e9;w=9;x=t;y=16438}else{if((e|0)>0){v=0.0;w=e;x=l;y=16438}else{z=0.0;A=0.0}}if((y|0)==16438){f=x;n=w;m=0;while(1){r=a[f]|0;i=f+1|0;if(r<<24>>24==46){B=a[i]|0;C=f+2|0}else{B=r;C=i}D=(m*10|0)-48+(B<<24>>24)|0;i=n-1|0;if((i|0)>0){f=C;n=i;m=D}else{break}}z=+(D|0);A=v}E=A+z;do{if((k<<24>>24|0)==69|(k<<24>>24|0)==101){m=g+1|0;n=a[m]|0;if((n<<24>>24|0)==45){F=g+2|0;G=1}else if((n<<24>>24|0)==43){F=g+2|0;G=0}else{F=m;G=0}m=a[F]|0;if(((m<<24>>24)-48|0)>>>0<10){H=F;I=0;J=m}else{K=0;L=F;M=G;break}while(1){m=(J<<24>>24)-48+(I*10|0)|0;n=H+1|0;f=a[n]|0;if(((f<<24>>24)-48|0)>>>0<10){H=n;I=m;J=f}else{K=m;L=n;M=G;break}}}else{K=0;L=g;M=0}}while(0);n=o+((M|0)==0?K:-K|0)|0;m=(n|0)<0?-n|0:n;if((m|0)>511){c[(bO()|0)>>2]=34;N=1.0;O=7720;P=511;y=16455}else{if((m|0)==0){Q=1.0}else{N=1.0;O=7720;P=m;y=16455}}if((y|0)==16455){while(1){y=0;if((P&1|0)==0){R=N}else{R=N*+h[O>>3]}m=P>>1;if((m|0)==0){Q=R;break}else{N=R;O=O+8|0;P=m;y=16455}}}if((n|0)>-1){p=L;q=E*Q;break}else{p=L;q=E/Q;break}}}while(0);if((d|0)!=0){c[d>>2]=p}if((j|0)==0){S=q;return+S}S=-0.0-q;return+S}function gGy(b){b=b|0;var c=0;c=b;while(a[c]|0){c=c+1|0}return c-b|0}function gGz(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=b+e|0;if((e|0)>=20){d=d&255;e=b&3;g=d|d<<8|d<<16|d<<24;h=f&~3;if(e){e=b+4-e|0;while((b|0)<(e|0)){a[b]=d;b=b+1|0}}while((b|0)<(h|0)){c[b>>2]=g;b=b+4|0}}while((b|0)<(f|0)){a[b]=d;b=b+1|0}}function gGA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;z=z+1|0;c[a>>2]=z;while((e|0)<40){if((c[d+(e<<2)>>2]|0)==0){c[d+(e<<2)>>2]=z;c[d+((e<<2)+4)>>2]=b;c[d+((e<<2)+8)>>2]=0;return 0}e=e+2|0}cP(116);cP(111);cP(111);cP(32);cP(109);cP(97);cP(110);cP(121);cP(32);cP(115);cP(101);cP(116);cP(106);cP(109);cP(112);cP(115);cP(32);cP(105);cP(110);cP(32);cP(97);cP(32);cP(102);cP(117);cP(110);cP(99);cP(116);cP(105);cP(111);cP(110);cP(32);cP(99);cP(97);cP(108);cP(108);cP(44);cP(32);cP(98);cP(117);cP(105);cP(108);cP(100);cP(32);cP(119);cP(105);cP(116);cP(104);cP(32);cP(97);cP(32);cP(104);cP(105);cP(103);cP(104);cP(101);cP(114);cP(32);cP(118);cP(97);cP(108);cP(117);cP(101);cP(32);cP(102);cP(111);cP(114);cP(32);cP(77);cP(65);cP(88);cP(95);cP(83);cP(69);cP(84);cP(74);cP(77);cP(80);cP(83);cP(10);ah(0);return 0}function gGB(a,b){a=a|0;b=b|0;var d=0,e=0;while((d|0)<20){e=c[b+(d<<2)>>2]|0;if((e|0)==0)break;if((e|0)==(a|0)){return c[b+((d<<2)+4)>>2]|0}d=d+2|0}return 0}function gGC(b,d,e){b=b|0;d=d|0;e=e|0;var f=0;f=b|0;if((b&3)==(d&3)){while(b&3){if((e|0)==0)return f|0;a[b]=a[d]|0;b=b+1|0;d=d+1|0;e=e-1|0}while((e|0)>=4){c[b>>2]=c[d>>2];b=b+4|0;d=d+4|0;e=e-4|0}}while((e|0)>0){a[b]=a[d]|0;b=b+1|0;d=d+1|0;e=e-1|0}return f|0}function gGD(a){a=a|0;if((a|0)<65)return a|0;if((a|0)>90)return a|0;return a-65+97|0}function gGE(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;while(e>>>0<d>>>0){f=gGD(a[b+e|0]|0)|0;g=gGD(a[c+e|0]|0)|0;if((f|0)==(g|0)&(f|0)==0)return 0;if((f|0)==0)return-1;if((g|0)==0)return 1;if((f|0)==(g|0)){e=e+1|0;continue}else{return(f>>>0>g>>>0?1:-1)|0}}return 0}function gGF(a,b){a=a|0;b=b|0;return gGE(a,b,-1)|0}function gGG(b,c,d){b=b|0;c=c|0;d=d|0;if((c|0)<(b|0)&(b|0)<(c+d|0)){c=c+d|0;b=b+d|0;while((d|0)>0){b=b-1|0;c=c-1|0;d=d-1|0;a[b]=a[c]|0}}else{gGC(b,c,d)|0}}function gGH(a,b,c){a=a|0;b=b|0;c=c|0;var e=0,f=0,g=0;while((e|0)<(c|0)){f=d[a+e|0]|0;g=d[b+e|0]|0;if((f|0)!=(g|0))return((f|0)>(g|0)?1:-1)|0;e=e+1|0}return 0}function gGI(b,c){b=b|0;c=c|0;var d=0;do{a[b+d|0]=a[c+d|0];d=d+1|0}while(a[c+(d-1)|0]|0);return b|0}function gGJ(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0;while((e|0)<(d|0)){a[b+e|0]=f?0:a[c+e|0]|0;f=f?1:(a[c+e|0]|0)==0;e=e+1|0}return b|0}function gGK(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=a+c>>>0;return(K=b+d+(e>>>0<a>>>0|0)>>>0,e|0)|0}function gGL(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=b-d>>>0;e=b-d-(c>>>0>a>>>0|0)>>>0;return(K=e,a-c>>>0|0)|0}function gGM(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)<32){K=b<<c|(a&(1<<c)-1<<32-c)>>>32-c;return a<<c}K=a<<c-32;return 0}function gGN(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)<32){K=b>>>c;return a>>>c|(b&(1<<c)-1)<<32-c}K=0;return b>>>c-32|0}function gGO(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)<32){K=b>>c;return a>>>c|(b&(1<<c)-1)<<32-c}K=(b|0)<0?-1:0;return b>>c-32|0}function gGP(b){b=b|0;var c=0;c=a[n+(b>>>24)|0]|0;if((c|0)<8)return c|0;c=a[n+(b>>16&255)|0]|0;if((c|0)<8)return c+8|0;c=a[n+(b>>8&255)|0]|0;if((c|0)<8)return c+16|0;return(a[n+(b&255)|0]|0)+24|0}function gGQ(b){b=b|0;var c=0;c=a[m+(b&255)|0]|0;if((c|0)<8)return c|0;c=a[m+(b>>8&255)|0]|0;if((c|0)<8)return c+8|0;c=a[m+(b>>16&255)|0]|0;if((c|0)<8)return c+16|0;return(a[m+(b>>>24)|0]|0)+24|0}function gGR(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=a&65535;d=b&65535;e=ag(d,c)|0;f=a>>>16;a=(e>>>16)+(ag(d,f)|0)|0;d=b>>>16;b=ag(d,c)|0;return(K=(a>>>16)+(ag(d,f)|0)+(((a&65535)+b|0)>>>16)|0,a+b<<16|e&65535|0)|0}function gGS(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=b>>31|((b|0)<0?-1:0)<<1;f=((b|0)<0?-1:0)>>31|((b|0)<0?-1:0)<<1;g=d>>31|((d|0)<0?-1:0)<<1;h=((d|0)<0?-1:0)>>31|((d|0)<0?-1:0)<<1;i=gGL(e^a,f^b,e,f)|0;b=K;a=g^e;e=h^f;f=gGL((gGX(i,b,gGL(g^c,h^d,g,h)|0,K,0)|0)^a,K^e,a,e)|0;return(K=K,f)|0}function gGT(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+8|0;g=f|0;h=b>>31|((b|0)<0?-1:0)<<1;j=((b|0)<0?-1:0)>>31|((b|0)<0?-1:0)<<1;k=e>>31|((e|0)<0?-1:0)<<1;l=((e|0)<0?-1:0)>>31|((e|0)<0?-1:0)<<1;m=gGL(h^a,j^b,h,j)|0;b=K;a=gGL(k^d,l^e,k,l)|0;gGX(m,b,a,K,g)|0;a=gGL(c[g>>2]^h,c[g+4>>2]^j,h,j)|0;j=K;i=f;return(K=j,a)|0}function gGU(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=a;a=c;c=gGR(e,a)|0;f=K;return(K=(ag(b,a)|0)+(ag(d,e)|0)+f|f&0,c|0|0)|0}function gGV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=gGX(a,b,c,d,0)|0;return(K=K,e)|0}function gGW(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0;f=i;i=i+8|0;g=f|0;gGX(a,b,d,e,g)|0;i=f;return(K=c[g+4>>2]|0,c[g>>2]|0)|0}function gGX(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,L=0,M=0;g=a;h=b;i=h;j=d;k=e;l=k;if((i|0)==0){m=(f|0)!=0;if((l|0)==0){if(m){c[f>>2]=(g>>>0)%(j>>>0);c[f+4>>2]=0}n=0;o=(g>>>0)/(j>>>0)>>>0;return(K=n,o)|0}else{if(!m){n=0;o=0;return(K=n,o)|0}c[f>>2]=a|0;c[f+4>>2]=b&0;n=0;o=0;return(K=n,o)|0}}m=(l|0)==0;do{if((j|0)==0){if(m){if((f|0)!=0){c[f>>2]=(i>>>0)%(j>>>0);c[f+4>>2]=0}n=0;o=(i>>>0)/(j>>>0)>>>0;return(K=n,o)|0}if((g|0)==0){if((f|0)!=0){c[f>>2]=0;c[f+4>>2]=(i>>>0)%(l>>>0)}n=0;o=(i>>>0)/(l>>>0)>>>0;return(K=n,o)|0}p=l-1|0;if((p&l|0)==0){if((f|0)!=0){c[f>>2]=a|0;c[f+4>>2]=p&i|b&0}n=0;o=i>>>((gGQ(l|0)|0)>>>0);return(K=n,o)|0}p=(gGP(l|0)|0)-(gGP(i|0)|0)|0;if(p>>>0<=30){q=p+1|0;r=31-p|0;s=q;t=i<<r|g>>>(q>>>0);u=i>>>(q>>>0);v=0;w=g<<r;break}if((f|0)==0){n=0;o=0;return(K=n,o)|0}c[f>>2]=a|0;c[f+4>>2]=h|b&0;n=0;o=0;return(K=n,o)|0}else{if(!m){r=(gGP(l|0)|0)-(gGP(i|0)|0)|0;if(r>>>0<=31){q=r+1|0;p=31-r|0;x=r-31>>31;s=q;t=g>>>(q>>>0)&x|i<<p;u=i>>>(q>>>0)&x;v=0;w=g<<p;break}if((f|0)==0){n=0;o=0;return(K=n,o)|0}c[f>>2]=a|0;c[f+4>>2]=h|b&0;n=0;o=0;return(K=n,o)|0}p=j-1|0;if((p&j|0)!=0){x=(gGP(j|0)|0)+33-(gGP(i|0)|0)|0;q=64-x|0;r=32-x|0;y=r>>31;z=x-32|0;A=z>>31;s=x;t=r-1>>31&i>>>(z>>>0)|(i<<r|g>>>(x>>>0))&A;u=A&i>>>(x>>>0);v=g<<q&y;w=(i<<q|g>>>(z>>>0))&y|g<<r&x-33>>31;break}if((f|0)!=0){c[f>>2]=p&g;c[f+4>>2]=0}if((j|0)==1){n=h|b&0;o=a|0|0;return(K=n,o)|0}else{p=gGQ(j|0)|0;n=i>>>(p>>>0)|0;o=i<<32-p|g>>>(p>>>0)|0;return(K=n,o)|0}}}while(0);if((s|0)==0){B=w;C=v;D=u;E=t;F=0;G=0}else{g=d|0|0;d=k|e&0;e=gGK(g,d,-1,-1)|0;k=K;i=w;w=v;v=u;u=t;t=s;s=0;while(1){H=w>>>31|i<<1;I=s|w<<1;j=u<<1|i>>>31|0;a=u>>>31|v<<1|0;gGL(e,k,j,a)|0;b=K;h=b>>31|((b|0)<0?-1:0)<<1;J=h&1;L=gGL(j,a,h&g,(((b|0)<0?-1:0)>>31|((b|0)<0?-1:0)<<1)&d)|0;M=K;b=t-1|0;if((b|0)==0){break}else{i=H;w=I;v=M;u=L;t=b;s=J}}B=H;C=I;D=M;E=L;F=0;G=J}J=C;C=0;if((f|0)!=0){c[f>>2]=E;c[f+4>>2]=D}n=(J|0)>>>31|(B|C)<<1|(C<<1|J>>>31)&0|F;o=(J<<1|0>>>31)&-2|G;return(K=n,o)|0}function gGY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;dM(a|0,b|0,c|0,d|0,e|0)}function gGZ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;bH(a|0,b|0,c|0,d|0,e|0)}function gG_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;ep(a|0,b|0,c|0,d|0,e|0)}function gG$(a,b){a=a|0;b=+b;dT(a|0,+b)}function gG0(a){a=a|0;co(a|0)}function gG1(a){a=a|0;fQ(a|0)}function gG2(a){a=a|0;a2(a|0)}function gG3(a){a=a|0;dk(a|0)}function gG4(a){a=a|0;b$(a|0)}function gG5(a){a=a|0;f9(a|0)}function gG6(a){a=a|0;b_(a|0)}function gG7(a){a=a|0;e2(a|0)}function gG8(a){a=a|0;fg(a|0)}function gG9(a){a=a|0;dt(a|0)}function gHa(a){a=a|0;bj(a|0)}function gHb(a){a=a|0;dB(a|0)}function gHc(a){a=a|0;a3(a|0)}function gHd(a){a=a|0;f6(a|0)}function gHe(a){a=a|0;e7(a|0)}function gHf(a){a=a|0;er(a|0)}function gHg(a){a=a|0;fm(a|0)}function gHh(a){a=a|0;bV(a|0)}function gHi(a){a=a|0;ec(a|0)}function gHj(a){a=a|0;dc(a|0)}function gHk(a){a=a|0;dQ(a|0)}function gHl(a){a=a|0;dy(a|0)}function gHm(a){a=a|0;dq(a|0)}function gHn(a){a=a|0;bC(a|0)}function gHo(a){a=a|0;eq(a|0)}function gHp(a,b){a=a|0;b=b|0;fH(a|0,b|0)}function gHq(a,b){a=a|0;b=b|0;en(a|0,b|0)}function gHr(a,b){a=a|0;b=b|0;d5(a|0,b|0)}function gHs(a,b){a=a|0;b=b|0;dD(a|0,b|0)}function gHt(a,b){a=a|0;b=b|0;a6(a|0,b|0)}function gHu(a,b){a=a|0;b=b|0;eS(a|0,b|0)}function gHv(a,b){a=a|0;b=b|0;bb(a|0,b|0)}function gHw(a,b){a=a|0;b=b|0;eI(a|0,b|0)}function gHx(a,b){a=a|0;b=b|0;c_(a|0,b|0)}function gHy(a,b){a=a|0;b=b|0;dV(a|0,b|0)}function gHz(a,b){a=a|0;b=b|0;fA(a|0,b|0)}function gHA(a,b){a=a|0;b=b|0;f0(a|0,b|0)}function gHB(a,b){a=a|0;b=b|0;fb(a|0,b|0)}function gHC(a,b){a=a|0;b=b|0;ei(a|0,b|0)}function gHD(a,b){a=a|0;b=b|0;c5(a|0,b|0)}function gHE(a,b){a=a|0;b=b|0;eM(a|0,b|0)}function gHF(a,b){a=a|0;b=b|0;fK(a|0,b|0)}function gHG(a,b){a=a|0;b=b|0;cX(a|0,b|0)}function gHH(a,b){a=a|0;b=b|0;by(a|0,b|0)}function gHI(a,b){a=a|0;b=b|0;eJ(a|0,b|0)}function gHJ(a,b){a=a|0;b=b|0;eQ(a|0,b|0)}function gHK(a,b){a=a|0;b=b|0;bN(a|0,b|0)}function gHL(a,b){a=a|0;b=b|0;bg(a|0,b|0)}function gHM(a,b){a=a|0;b=b|0;dH(a|0,b|0)}function gHN(a,b){a=a|0;b=b|0;dK(a|0,b|0)}function gHO(a,b){a=a|0;b=b|0;eK(a|0,b|0)}function gHP(a,b){a=a|0;b=b|0;cp(a|0,b|0)}function gHQ(a,b){a=a|0;b=b|0;b3(a|0,b|0)}function gHR(a,b){a=a|0;b=b|0;d$(a|0,b|0)}function gHS(a,b){a=a|0;b=b|0;cb(a|0,b|0)}function gHT(a,b){a=a|0;b=b|0;fI(a|0,b|0)}function gHU(a,b){a=a|0;b=b|0;cw(a|0,b|0)}function gHV(a,b){a=a|0;b=b|0;aZ(a|0,b|0)}function gHW(a){a=a|0;return fn(a|0)|0}function gHX(a){a=a|0;return bE(a|0)|0}function gHY(a){a=a|0;return ek(a|0)|0}function gHZ(a){a=a|0;return el(a|0)|0}function gH_(a){a=a|0;return eY(a|0)|0}function gH$(a){a=a|0;return bS(a|0)|0}function gH0(a){a=a|0;return cR(a|0)|0}function gH1(a){a=a|0;return eA(a|0)|0}function gH2(a){a=a|0;return a9(a|0)|0}function gH3(a){a=a|0;return dG(a|0)|0}function gH4(a){a=a|0;return aY(a|0)|0}function gH5(a){a=a|0;return eN(a|0)|0}function gH6(a){a=a|0;return bY(a|0)|0}function gH7(a){a=a|0;return bG(a|0)|0}function gH8(a){a=a|0;return cP(a|0)|0}function gH9(a,b,c){a=a|0;b=b|0;c=c|0;return ch(a|0,b|0,c|0)|0}function gIa(a,b,c){a=a|0;b=b|0;c=c|0;return cs(a|0,b|0,c|0)|0}function gIb(a,b,c){a=a|0;b=b|0;c=c|0;return dE(a|0,b|0,c|0)|0}function gIc(a,b,c){a=a|0;b=b|0;c=c|0;return bU(a|0,b|0,c|0)|0}function gId(a,b,c){a=a|0;b=b|0;c=c|0;return dW(a|0,b|0,c|0)|0}function gIe(a,b,c){a=a|0;b=b|0;c=c|0;return de(a|0,b|0,c|0)|0}function gIf(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;cA(a|0,b|0,c|0,d|0,e|0,f|0)}function gIg(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;f8(a|0,b|0,c|0,d|0,e|0,f|0,g|0)}function gIh(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;et(a|0,b|0,c|0,d|0,e|0,f|0,g|0)}function gIi(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;fZ(a|0,b|0,c|0,d|0,e|0,f|0,g|0)}function gIj(a){a=+a;return+ba(+a)}function gIk(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;fP(a|0,b|0,c|0,d|0,e|0,f|0,g|0,h|0,i|0)}function gIl(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;dX(a|0,b|0,c|0,d|0,e|0,f|0,g|0,h|0,i|0)}function gIm(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;e8(a|0,b|0,c|0,d|0,e|0,f|0,g|0,h|0,i|0)}function gIn(a,b){a=a|0;b=b|0;return cE(a|0,b|0)|0}function gIo(a,b){a=a|0;b=b|0;return f$(a|0,b|0)|0}function gIp(a,b){a=a|0;b=b|0;return fS(a|0,b|0)|0}function gIq(a,b){a=a|0;b=b|0;return cu(a|0,b|0)|0}function gIr(a,b){a=a|0;b=b|0;return fw(a|0,b|0)|0}function gIs(a,b){a=a|0;b=b|0;return bw(a|0,b|0)|0}function gIt(a,b){a=a|0;b=b|0;return fa(a|0,b|0)|0}function gIu(){return eL()|0}function gIv(){return fF()|0}function gIw(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return be(a|0,b|0,c|0,d|0)|0}function gIx(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return cj(a|0,b|0,c|0,d|0)|0}function gIy(a,b,c){a=a|0;b=b|0;c=c|0;cg(a|0,b|0,c|0)}function gIz(a,b,c){a=a|0;b=b|0;c=c|0;eB(a|0,b|0,c|0)}function gIA(a,b,c){a=a|0;b=b|0;c=c|0;bF(a|0,b|0,c|0)}function gIB(a,b,c){a=a|0;b=b|0;c=c|0;c2(a|0,b|0,c|0)}function gIC(a,b,c){a=a|0;b=b|0;c=c|0;fX(a|0,b|0,c|0)}function gID(a,b,c){a=a|0;b=b|0;c=c|0;c3(a|0,b|0,c|0)}function gIE(a,b,c){a=a|0;b=b|0;c=c|0;e9(a|0,b|0,c|0)}function gIF(a,b,c){a=a|0;b=b|0;c=c|0;dU(a|0,b|0,c|0)}function gIG(a,b,c){a=a|0;b=b|0;c=c|0;bz(a|0,b|0,c|0)}function gIH(a,b,c){a=a|0;b=b|0;c=c|0;fT(a|0,b|0,c|0)}function gII(a,b,c){a=a|0;b=b|0;c=c|0;c6(a|0,b|0,c|0)}function gIJ(a,b,c){a=a|0;b=b|0;c=c|0;cx(a|0,b|0,c|0)}function gIK(a,b,c){a=a|0;b=b|0;c=c|0;cn(a|0,b|0,c|0)}function gIL(a,b,c){a=a|0;b=b|0;c=c|0;b8(a|0,b|0,c|0)}function gIM(a,b,c){a=a|0;b=b|0;c=c|0;fo(a|0,b|0,c|0)}function gIN(a,b,c){a=a|0;b=b|0;c=c|0;bM(a|0,b|0,c|0)}function gIO(a,b,c){a=a|0;b=b|0;c=c|0;dY(a|0,b|0,c|0)}function gIP(a,b,c){a=a|0;b=b|0;c=c|0;fj(a|0,b|0,c|0)}function gIQ(a,b,c){a=a|0;b=b|0;c=c|0;cN(a|0,b|0,c|0)}function gIR(a,b,c){a=a|0;b=b|0;c=c|0;cf(a|0,b|0,c|0)}function gIS(a,b,c){a=a|0;b=b|0;c=c|0;eb(a|0,b|0,c|0)}function gIT(a,b,c){a=a|0;b=b|0;c=c|0;cS(a|0,b|0,c|0)}function gIU(a,b,c){a=a|0;b=b|0;c=c|0;cz(a|0,b|0,c|0)}function gIV(a,b,c){a=a|0;b=b|0;c=c|0;bq(a|0,b|0,c|0)}function gIW(a,b,c){a=a|0;b=b|0;c=c|0;e_(a|0,b|0,c|0)}function gIX(a,b,c){a=a|0;b=b|0;c=c|0;f3(a|0,b|0,c|0)}function gIY(a,b,c){a=a|0;b=b|0;c=c|0;dO(a|0,b|0,c|0)}function gIZ(a,b,c){a=a|0;b=b|0;c=c|0;ds(a|0,b|0,c|0)}function gI_(a,b,c){a=a|0;b=b|0;c=c|0;dr(a|0,b|0,c|0)}function gI$(){ce()}function gI0(){di()}function gI1(){d6()}function gI2(){eo()}function gI3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;bQ(a|0,b|0,c|0,d|0)}function gI4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;eX(a|0,b|0,c|0,d|0)}function gI5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;bk(a|0,b|0,c|0,d|0)}function gI6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;eV(a|0,b|0,c|0,d|0)}function gI7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;bf(a|0,b|0,c|0,d|0)}function gI8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;dL(a|0,b|0,c|0,d|0)}function gI9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;eR(a|0,b|0,c|0,d|0)}function gJa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;du(a|0,b|0,c|0,d|0)}function gJb(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;dm(a|0,b|0,c|0,d|0)}function gJc(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;fD(a|0,b|0,c|0,d|0)}function gJd(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ex(a|0,b|0,c|0,d|0)}function gJe(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ee(a|0,b|0,c|0,d|0)}function gJf(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;dd(a|0,b|0,c|0,d|0)}function gJg(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;fe(a|0,b|0,c|0,d|0)}function gJh(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;fv(a|0,b|0,c|0,d|0)}function gJi(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;bI(a|0,b|0,c|0,d|0)}function gJj(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ea(a|0,b|0,c|0,d|0)}function gJk(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;fr(a|0,b|0,c|0,d|0)}function gJl(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;eD(a|0,b|0,c|0,d|0)}function gJm(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;f7(a|0,b|0,c|0,d|0)}function gJn(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;fB(a|0,b|0,c|0,d|0)}function gJo(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;cm(a|0,b|0,c|0,d|0)}function gJp(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a0(a|0,b|0,c|0,d|0)}function gJq(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;bm(a|0,b|0,c|0,d|0)}function gJr(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;cV(a|0,b|0,c|0,d|0,e|0,f|0,g|0,h|0)}function gJs(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;cK(a|0,b|0,c|0,d|0,e|0,f|0,g|0,h|0)}function gJt(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;bd(a|0,b|0,c|0,d|0,e|0,f|0,g|0,h|0)}function gJu(a,b,c,d,e){a=a|0;b=+b;c=+c;d=+d;e=+e;eu(a|0,+b,+c,+d,+e)}function gJv(a,b,c){a=a|0;b=+b;c=+c;cy(a|0,+b,+c)}function gJw(a,b,c,d){a=a|0;b=+b;c=+c;d=+d;bo(a|0,+b,+c,+d)}function gJx(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;return gc[a&7](b|0,c|0,d|0,e|0,f|0,g|0,h|0)|0}function gJy(a,b,c){a=a|0;b=b|0;c=+c;gd[a&15](b|0,+c)}function gJz(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;ge[a&63](b|0,c|0,d|0,e|0,f|0)}function gJA(a,b){a=a|0;b=b|0;gf[a&2047](b|0)}function gJB(a,b,c){a=a|0;b=b|0;c=c|0;gg[a&4095](b|0,c|0)}function gJC(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;return gh[a&15](b|0,c|0,d|0,e|0,f|0,g|0)|0}function gJD(a,b,c,d){a=a|0;b=b|0;c=+c;d=+d;gi[a&3](b|0,+c,+d)}function gJE(a,b){a=a|0;b=b|0;return gj[a&4095](b|0)|0}function gJF(a,b,c,d,e,f,g,h,i,j,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;gk[a&15](b|0,c|0,d|0,e|0,f|0,g|0,h|0,i|0,j|0,k|0,l|0)}function gJG(a,b,c,d,e,f){a=a|0;b=b|0;c=+c;d=+d;e=+e;f=+f;gl[a&3](b|0,+c,+d,+e,+f)}function gJH(a,b){a=a|0;b=+b;return gm[a&3](+b)|0}function gJI(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;gn[a&3](b|0,c|0,d|0,+e)}function gJJ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=+d;e=e|0;f=f|0;return go[a&3](b|0,c|0,+d,e|0,f|0)|0}function gJK(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return gp[a&16383](b|0,c|0,d|0)|0}function gJL(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=+g;gq[a&15](b|0,c|0,d|0,e|0,f|0,+g)}function gJM(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;gr[a&31](b|0,c|0,d|0,e|0,f|0,g|0,h|0,i|0)}function gJN(a,b,c,d,e){a=a|0;b=b|0;c=+c;d=+d;e=+e;gs[a&3](b|0,+c,+d,+e)}function gJO(a,b,c){a=a|0;b=b|0;c=c|0;return+gt[a&3](b|0,c|0)}function gJP(a){a=a|0;gu[a&16383]()}function gJQ(a,b,c){a=a|0;b=b|0;c=+c;return gv[a&3](b|0,+c)|0}function gJR(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;gw[a&127](b|0,c|0,d|0,e|0,f|0,g|0,h|0)}function gJS(a,b){a=a|0;b=+b;return+gx[a&3](+b)}function gJT(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;gy[a&15](b|0,c|0,d|0,e|0,f|0,g|0,h|0,i|0,j|0)}function gJU(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=+h;gz[a&7](b|0,c|0,d|0,e|0,f|0,g|0,+h)}function gJV(a,b,c){a=a|0;b=b|0;c=c|0;return gA[a&16383](b|0,c|0)|0}function gJW(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;gB[a&127](b|0,c|0,d|0,e|0,f|0,g|0)}function gJX(a){a=a|0;return+gC[a&255]()}function gJY(a){a=a|0;return gD[a&8191]()|0}function gJZ(a,b,c){a=a|0;b=+b;c=+c;gE[a&1](+b,+c)}function gJ_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return gF[a&2047](b|0,c|0,d|0,e|0,f|0)|0}function gJ$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;gG[a&255](b|0,c|0,d|0)}function gJ0(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=+d;e=+e;f=+f;g=+g;gH[a&7](b|0,c|0,+d,+e,+f,+g)}function gJ1(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;return gI[a&31](b|0,c|0,d|0,e|0,f|0,g|0,h|0,i|0)|0}function gJ2(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return gJ[a&31](b|0,c|0,d|0,e|0)|0}function gJ3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=+d;gK[a&7](b|0,c|0,+d)}function gJ4(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;gL[a&255](b|0,c|0,d|0,e|0)}function gJ5(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;ah(0);return 0}function gJ6(a,b){a=a|0;b=+b;ah(1)}function gJ7(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;ah(2)}function gJ8(a){a=a|0;ah(3)}function gJ9(a,b){a=a|0;b=b|0;ah(4)}function gKa(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;ah(5);return 0}function gKb(a,b,c){a=a|0;b=+b;c=+c;ah(6)}function gKc(a){a=a|0;ah(7);return 0}function gKd(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;ah(8)}function gKe(a,b,c,d,e){a=a|0;b=+b;c=+c;d=+d;e=+e;ah(9)}function gKf(a){a=+a;ah(10);return 0}function gKg(a,b,c,d){a=a|0;b=b|0;c=c|0;d=+d;ah(11)}function gKh(a,b,c,d,e){a=a|0;b=b|0;c=+c;d=d|0;e=e|0;ah(12);return 0}function gKi(a,b,c){a=a|0;b=b|0;c=c|0;ah(13);return 0}function gKj(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=+f;ah(14)}function gKk(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;ah(15)}function gKl(a,b,c,d){a=a|0;b=+b;c=+c;d=+d;ah(16)}function gKm(a,b){a=a|0;b=b|0;ah(17);return 0.0}function gKn(){ah(18)}function gKo(a,b){a=a|0;b=+b;ah(19);return 0}function gKp(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;ah(20)}function gKq(a){a=+a;ah(21);return 0.0}function gKr(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;ah(22)}function gKs(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=+g;ah(23)}function gKt(a,b){a=a|0;b=b|0;ah(24);return 0}function gKu(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;ah(25)}function gKv(){ah(26);return 0.0}function gKw(){ah(27);return 0}function gKx(a,b){a=+a;b=+b;ah(28)}function gKy(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;ah(29);return 0}function gKz(a,b,c){a=a|0;b=b|0;c=c|0;ah(30)}function gKA(a,b,c,d,e,f){a=a|0;b=b|0;c=+c;d=+d;e=+e;f=+f;ah(31)}function gKB(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;ah(32);return 0}function gKC(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ah(33);return 0}function gKD(a,b,c){a=a|0;b=b|0;c=+c;ah(34)}function gKE(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ah(35)}
// EMSCRIPTEN_END_FUNCS
var gc=[gJ5,gJ5,kS,gJ5,la,gJ5,k9,gJ5];var gd=[gJ6,gJ6,gG$,gJ6,U2,gJ6,UG,gJ6,T3,gJ6,gJ6,gJ6,gJ6,gJ6,gJ6,gJ6];var ge=[gJ7,gJ7,dkC,gJ7,dkA,gJ7,dkw,gJ7,dkB,gJ7,gGY,gJ7,dkx,gJ7,gGk,gJ7,dku,gJ7,kL,gJ7,dkz,gJ7,gGm,gJ7,dkD,gJ7,dkv,gJ7,gGZ,gJ7,gG_,gJ7,gGl,gJ7,dky,gJ7,gJ7,gJ7,gJ7,gJ7,gJ7,gJ7,gJ7,gJ7,gJ7,gJ7,gJ7,gJ7,gJ7,gJ7,gJ7,gJ7,gJ7,gJ7,gJ7,gJ7,gJ7,gJ7,gJ7,gJ7,gJ7,gJ7,gJ7,gJ7];var gf=[gJ8,gJ8,gG0,gJ8,f74,gJ8,f7x,gJ8,gak,gJ8,f7N,gJ8,gba,gJ8,gaf,gJ8,gcg,gJ8,f6U,gJ8,gb4,gJ8,gzh,gJ8,fxX,gJ8,gBb,gJ8,f8g,gJ8,f9Y,gJ8,gcQ,gJ8,gbc,gJ8,gzi,gJ8,gcd,gJ8,f8J,gJ8,f90,gJ8,gF7,gJ8,aJC,gJ8,gb9,gJ8,gGa,gJ8,ic,gJ8,f5K,gJ8,gBk,gJ8,gaW,gJ8,f5k,gJ8,gaM,gJ8,gcV,gJ8,f80,gJ8,f82,gJ8,f7F,gJ8,gbL,gJ8,ga3,gJ8,f91,gJ8,gam,gJ8,gG1,gJ8,fv0,gJ8,hq,gJ8,f5i,gJ8,f7Z,gJ8,gaj,gJ8,f66,gJ8,gG2,gJ8,gcx,gJ8,ga$,gJ8,f5H,gJ8,gcP,gJ8,gdq,gJ8,f6j,gJ8,f8Z,gJ8,f59,gJ8,f8d,gJ8,gE6,gJ8,gbe,gJ8,f8k,gJ8,agZ,gJ8,f8t,gJ8,gaO,gJ8,gdh,gJ8,gdn,gJ8,fyB,gJ8,ib,gJ8,gG3,gJ8,gby,gJ8,f83,gJ8,f6s,gJ8,fx2,gJ8,gdB,gJ8,gbX,gJ8,gDu,gJ8,f6I,gJ8,bee,gJ8,gBg,gJ8,f6h,gJ8,RD,gJ8,f96,gJ8,f5Y,gJ8,ehi,gJ8,f7I,gJ8,f7S,gJ8,gG4,gJ8,f6J,gJ8,gEd,gJ8,gF3,gJ8,gbt,gJ8,gEu,gJ8,jZ,gJ8,f7_,gJ8,f8R,gJ8,gA5,gJ8,ebk,gJ8,gcz,gJ8,f6Y,gJ8,gcW,gJ8,f5J,gJ8,awD,gJ8,ba6,gJ8,gbA,gJ8,gaN,gJ8,bpe,gJ8,gG5,gJ8,gdx,gJ8,f5x,gJ8,gbE,gJ8,f63,gJ8,gcZ,gJ8,aKO,gJ8,ed0,gJ8,f8L,gJ8,fwV,gJ8,f6y,gJ8,gD7,gJ8,f7c,gJ8,f5p,gJ8,gC2,gJ8,gdr,gJ8,ga5,gJ8,f7O,gJ8,f7E,gJ8,gcv,gJ8,f5n,gJ8,f8V,gJ8,gaA,gJ8,f8B,gJ8,f5S,gJ8,eHk,gJ8,f5N,gJ8,gDE,gJ8,gD1,gJ8,f8D,gJ8,f6c,gJ8,gcl,gJ8,f9O,gJ8,gAd,gJ8,a4s,gJ8,f7e,gJ8,gcR,gJ8,f6g,gJ8,eDd,gJ8,gG6,gJ8,gcu,gJ8,gbY,gJ8,f5d,gJ8,f6z,gJ8,gaY,gJ8,gzU,gJ8,TC,gJ8,f9T,gJ8,gA9,gJ8,djn,gJ8,f7M,gJ8,f7P,gJ8,gAh,gJ8,f7s,gJ8,gc5,gJ8,f52,gJ8,f8c,gJ8,gAn,gJ8,boW,gJ8,gaz,gJ8,gco,gJ8,i_,gJ8,gA6,gJ8,blA,gJ8,fsu,gJ8,f9_,gJ8,gds,gJ8,f6N,gJ8,gF2,gJ8,gb7,gJ8,f7w,gJ8,gcf,gJ8,gbN,gJ8,gar,gJ8,awk,gJ8,ie,gJ8,er_,gJ8,gCu,gJ8,gG7,gJ8,f5F,gJ8,gdv,gJ8,gcI,gJ8,gbK,gJ8,gaF,gJ8,f5o,gJ8,f8l,gJ8,gGr,gJ8,gBl,gJ8,f8E,gJ8,gcE,gJ8,f62,gJ8,f9U,gJ8,gDj,gJ8,gFm,gJ8,f7g,gJ8,gG8,gJ8,gzN,gJ8,gDY,gJ8,gbj,gJ8,eux,gJ8,gb$,gJ8,f7X,gJ8,f8q,gJ8,f8s,gJ8,gF1,gJ8,f8b,gJ8,f7A,gJ8,f8G,gJ8,f8M,gJ8,f6q,gJ8,gzl,gJ8,hX,gJ8,gcb,gJ8,gBa,gJ8,eY3,gJ8,gb0,gJ8,f69,gJ8,gaK,gJ8,gAD,gJ8,gbS,gJ8,gb8,gJ8,gbp,gJ8,f79,gJ8,bhe,gJ8,f97,gJ8,gdA,gJ8,fsr,gJ8,f5h,gJ8,f7H,gJ8,km,gJ8,gz$,gJ8,gC7,gJ8,gb2,gJ8,atQ,gJ8,gAS,gJ8,f7B,gJ8,gEq,gJ8,f71,gJ8,a$k,gJ8,f7a,gJ8,d02,gJ8,eCx,gJ8,iF,gJ8,gE_,gJ8,f7l,gJ8,f8f,gJ8,f75,gJ8,gAr,gJ8,f6X,gJ8,gb_,gJ8,gz5,gJ8,f8U,gJ8,f8I,gJ8,gbG,gJ8,ga7,gJ8,gF$,gJ8,gF0,gJ8,gbT,gJ8,gca,gJ8,gcS,gJ8,j$,gJ8,f9V,gJ8,f55,gJ8,f7r,gJ8,eCu,gJ8,f5G,gJ8,gG9,gJ8,dhz,gJ8,gcc,gJ8,gac,gJ8,f6E,gJ8,gBB,gJ8,iT,gJ8,f5D,gJ8,bff,gJ8,ga6,gJ8,f6R,gJ8,gax,gJ8,f7t,gJ8,f5B,gJ8,gEv,gJ8,gdi,gJ8,bgR,gJ8,gGu,gJ8,av5,gJ8,f6Z,gJ8,gHa,gJ8,f6b,gJ8,gbs,gJ8,gzP,gJ8,f92,gJ8,f5_,gJ8,gbq,gJ8,gBX,gJ8,f8a,gJ8,gbO,gJ8,f7y,gJ8,gcj,gJ8,gcX,gJ8,biZ,gJ8,kc,gJ8,eOA,gJ8,gaV,gJ8,f8X,gJ8,gab,gJ8,gcN,gJ8,gav,gJ8,gbM,gJ8,f8o,gJ8,f5P,gJ8,f5O,gJ8,gCf,gJ8,dfK,gJ8,gbC,gJ8,bpg,gJ8,jv,gJ8,gdu,gJ8,fwE,gJ8,gGe,gJ8,gHb,gJ8,gBq,gJ8,f6B,gJ8,gFp,gJ8,f8e,gJ8,gaQ,gJ8,gaC,gJ8,gcw,gJ8,f7$,gJ8,gEI,gJ8,e$B,gJ8,gad,gJ8,gcY,gJ8,f6w,gJ8,f7d,gJ8,gzj,gJ8,gBj,gJ8,dfQ,gJ8,gcH,gJ8,gEj,gJ8,eYT,gJ8,ga9,gJ8,fwa,gJ8,gcC,gJ8,gbF,gJ8,gaU,gJ8,gci,gJ8,gbD,gJ8,f68,gJ8,gb1,gJ8,eDb,gJ8,gGb,gJ8,kG,gJ8,f6u,gJ8,gaa,gJ8,a$I,gJ8,f8v,gJ8,gaE,gJ8,gbr,gJ8,gcp,gJ8,f8j,gJ8,gbk,gJ8,f77,gJ8,gdk,gJ8,ga2,gJ8,gcO,gJ8,f8A,gJ8,gal,gJ8,f5T,gJ8,gBv,gJ8,gA4,gJ8,f7k,gJ8,gbZ,gJ8,f8H,gJ8,f5t,gJ8,f5Q,gJ8,gbh,gJ8,bf3,gJ8,f5R,gJ8,gC4,gJ8,gBh,gJ8,f6x,gJ8,f6Q,gJ8,f8_,gJ8,aKL,gJ8,gzm,gJ8,bmf,gJ8,axk,gJ8,gHc,gJ8,f6p,gJ8,gbf,gJ8,gAF,gJ8,gce,gJ8,gHd,gJ8,id,gJ8,gbd,gJ8,gcq,gJ8,jG,gJ8,gbx,gJ8,f7f,gJ8,gcs,gJ8,bhz,gJ8,f9R,gJ8,gBc,gJ8,f5L,gJ8,gaH,gJ8,f6C,gJ8,f50,gJ8,gAy,gJ8,f8Y,gJ8,f7R,gJ8,bkC,gJ8,fw8,gJ8,f85,gJ8,f5s,gJ8,f6G,gJ8,f5u,gJ8,fyQ,gJ8,gHe,gJ8,f7V,gJ8,gau,gJ8,f9Z,gJ8,gCJ,gJ8,f7n,gJ8,gbJ,gJ8,f9A,gJ8,f8O,gJ8,gbl,gJ8,gFr,gJ8,fst,gJ8,gAe,gJ8,f8p,gJ8,dfW,gJ8,f8N,gJ8,evn,gJ8,ga1,gJ8,gaI,gJ8,f70,gJ8,aNp,gJ8,gct,gJ8,f9E,gJ8,f84,gJ8,gbB,gJ8,f5y,gJ8,gaZ,gJ8,gdj,gJ8,f6k,gJ8,f9W,gJ8,gGc,gJ8,gc6,gJ8,gcF,gJ8,gaJ,gJ8,gHf,gJ8,gcD,gJ8,gBm,gJ8,f7Y,gJ8,gcy,gJ8,gA7,gJ8,f6t,gJ8,f6K,gJ8,f7i,gJ8,gHg,gJ8,gaq,gJ8,f6S,gJ8,dMU,gJ8,gHh,gJ8,beW,gJ8,gDt,gJ8,gHi,gJ8,f7o,gJ8,f6V,gJ8,f7K,gJ8,bkB,gJ8,gc1,gJ8,gbm,gJ8,gBs,gJ8,f6M,gJ8,ig,gJ8,gc_,gJ8,gaT,gJ8,gc8,gJ8,f65,gJ8,f53,gJ8,gaG,gJ8,gCT,gJ8,f93,gJ8,gaB,gJ8,f7z,gJ8,axD,gJ8,gat,gJ8,gc3,gJ8,f7W,gJ8,bkX,gJ8,aFb,gJ8,gbb,gJ8,geW,gJ8,gF8,gJ8,fyl,gJ8,ij,gJ8,f9X,gJ8,gBG,gJ8,gAE,gJ8,gzk,gJ8,gbP,gJ8,f64,gJ8,gzC,gJ8,f8w,gJ8,gHj,gJ8,dnH,gJ8,f49,gJ8,gHk,gJ8,f5l,gJ8,f6m,gJ8,gbg,gJ8,e17,gJ8,gdy,gJ8,f5j,gJ8,gcK,gJ8,gC1,gJ8,f6_,gJ8,eBQ,gJ8,f8n,gJ8,a6u,gJ8,f8h,gJ8,bnK,gJ8,f6O,gJ8,f81,gJ8,f57,gJ8,kW,gJ8,ga8,gJ8,gbz,gJ8,gES,gJ8,gDP,gJ8,gEp,gJ8,f5v,gJ8,gdg,gJ8,bnG,gJ8,f8F,gJ8,gcG,gJ8,gF_,gJ8,gaP,gJ8,f8m,gJ8,f8S,gJ8,gcM,gJ8,f6n,gJ8,gcB,gJ8,gEs,gJ8,f7j,gJ8,bme,gJ8,gdd,gJ8,f7L,gJ8,f6a,gJ8,gHl,gJ8,f9N,gJ8,f94,gJ8,gaS,gJ8,eCv,gJ8,f5V,gJ8,bfe,gJ8,gcU,gJ8,f5W,gJ8,f98,gJ8,f6P,gJ8,f6H,gJ8,f6d,gJ8,f7U,gJ8,gc7,gJ8,iL,gJ8,dfO,gJ8,gc9,gJ8,d74,gJ8,f7b,gJ8,f8C,gJ8,gay,gJ8,atw,gJ8,f95,gJ8,f6$,gJ8,f7p,gJ8,ii,gJ8,gdc,gJ8,gag,gJ8,gai,gJ8,a0K,gJ8,gDF,gJ8,gc0,gJ8,f6W,gJ8,f5C,gJ8,gEe,gJ8,bgS,gJ8,hY,gJ8,bke,gJ8,f6D,gJ8,gGf,gJ8,gc4,gJ8,ga4,gJ8,gde,gJ8,gBr,gJ8,Rz,gJ8,gzV,gJ8,gGv,gJ8,f9S,gJ8,gC8,gJ8,gc2,gJ8,f6e,gJ8,gbQ,gJ8,f5z,gJ8,eyk,gJ8,gcL,gJ8,f7J,gJ8,f7D,gJ8,gHm,gJ8,gBC,gJ8,f5A,gJ8,f8r,gJ8,f6i,gJ8,f8W,gJ8,gbv,gJ8,a74,gJ8,gD8,gJ8,a$u,gJ8,f61,gJ8,gbW,gJ8,gBe,gJ8,f8u,gJ8,gAo,gJ8,gBf,gJ8,gD2,gJ8,gaD,gJ8,f6F,gJ8,gaL,gJ8,gck,gJ8,f60,gJ8,f9$,gJ8,gao,gJ8,gdf,gJ8,blB,gJ8,eVE,gJ8,gb5,gJ8,gz6,gJ8,gzn,gJ8,f5Z,gJ8,eOG,gJ8,iI,gJ8,f8Q,gJ8,f6T,gJ8,f6f,gJ8,faN,gJ8,gcn,gJ8,eDc,gJ8,gdo,gJ8,gz0,gJ8,f6A,gJ8,f5q,gJ8,gcm,gJ8,auG,gJ8,ga_,gJ8,gBw,gJ8,ebg,gJ8,f7C,gJ8,gFo,gJ8,gFn,gJ8,f86,gJ8,gb3,gJ8,f99,gJ8,f6o,gJ8,gch,gJ8,f8P,gJ8,gap,gJ8,gEJ,gJ8,gDX,gJ8,bi0,gJ8,gbH,gJ8,ebl,gJ8,gBW,gJ8,gbi,gJ8,gcr,gJ8,gBx,gJ8,gaR,gJ8,gbI,gJ8,gdp,gJ8,f5X,gJ8,f54,gJ8,dtA,gJ8,a0I,gJ8,gFe,gJ8,efj,gJ8,gDS,gJ8,gFq,gJ8,gcJ,gJ8,gdl,gJ8,gbU,gJ8,gdm,gJ8,f56,gJ8,gCv,gJ8,f5I,gJ8,gdw,gJ8,f7v,gJ8,f6l,gJ8,f7G,gJ8,gbw,gJ8,gGd,gJ8,gcA,gJ8,gan,gJ8,f76,gJ8,bix,gJ8,hi,gJ8,gDi,gJ8,gbn,gJ8,f8i,gJ8,gHn,gJ8,gda,gJ8,gdC,gJ8,f9M,gJ8,gBu,gJ8,box,gJ8,fvS,gJ8,gcT,gJ8,gdz,gJ8,gas,gJ8,gC5,gJ8,gEn,gJ8,f5E,gJ8,gHo,gJ8,f7T,gJ8,f9Q,gJ8,f8K,gJ8,Wu,gJ8,ih,gJ8,gBt,gJ8,f51,gJ8,f67,gJ8,gbo,gJ8,dfS,gJ8,d_N,gJ8,f8y,gJ8,bd9,gJ8,gEi,gJ8,f8T,gJ8,gEt,gJ8,jA,gJ8,f5U,gJ8,eZ4,gJ8,f72,gJ8,eCt,gJ8,kA,gJ8,gAT,gJ8,f9J,gJ8,a0J,gJ8,gdt,gJ8,iR,gJ8,gzg,gJ8,f58,gJ8,f5w,gJ8,gdb,gJ8,gc$,gJ8,f5$,gJ8,bmT,gJ8,gCg,gJ8,f9P,gJ8,gAg,gJ8,f6r,gJ8,f8z,gJ8,f7h,gJ8,bj_,gJ8,gbu,gJ8,gbV,gJ8,gah,gJ8,f5m,gJ8,f6L,gJ8,gbR,gJ8,RE,gJ8,gzO,gJ8,gb6,gJ8,gAj,gJ8,gae,gJ8,gdD,gJ8,gCU,gJ8,f78,gJ8,at7,gJ8,f8$,gJ8,gaw,gJ8,fwg,gJ8,f7Q,gJ8,dLC,gJ8,f7u,gJ8,gaX,gJ8,f5r,gJ8,f5M,gJ8,f6v,gJ8,ga0,gJ8,f73,gJ8,dhu,gJ8,gBH,gJ8,f7m,gJ8,f8x,gJ8,f7q,gJ8,gCI,gJ8,fyb,gJ8,gDQ,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8,gJ8];var gg=[gJ9,gJ9,gzQ,gJ9,a2O,gJ9,e_q,gJ9,fwp,gJ9,kP,gJ9,eP7,gJ9,a0O,gJ9,ejp,gJ9,dwD,gJ9,bbC,gJ9,gHp,gJ9,d2y,gJ9,ef0,gJ9,aKm,gJ9,ehk,gJ9,edf,gJ9,ePC,gJ9,ebu,gJ9,e6o,gJ9,blY,gJ9,emq,gJ9,aUa,gJ9,dDl,gJ9,ahH,gJ9,e27,gJ9,d68,gJ9,ecF,gJ9,ekw,gJ9,dQ3,gJ9,dSM,gJ9,e$X,gJ9,cGl,gJ9,ey1,gJ9,eFp,gJ9,bbG,gJ9,bra,gJ9,dNm,gJ9,dzj,gJ9,ePr,gJ9,aOe,gJ9,df9,gJ9,dj8,gJ9,aYe,gJ9,d2E,gJ9,dRP,gJ9,e0e,gJ9,aAT,gJ9,fe9,gJ9,bgP,gJ9,dt2,gJ9,fr0,gJ9,dpf,gJ9,Vt,gJ9,aOi,gJ9,d2t,gJ9,ez_,gJ9,ePM,gJ9,e0s,gJ9,fd6,gJ9,dSK,gJ9,bkm,gJ9,evA,gJ9,eng,gJ9,er8,gJ9,e6v,gJ9,dz2,gJ9,ecM,gJ9,ahm,gJ9,fmY,gJ9,bi8,gJ9,eQs,gJ9,ew5,gJ9,azK,gJ9,ble,gJ9,eOf,gJ9,UP,gJ9,eQx,gJ9,Vw,gJ9,lY,gJ9,em7,gJ9,eCF,gJ9,ecJ,gJ9,e$$,gJ9,gDz,gJ9,aUt,gJ9,asW,gJ9,d1N,gJ9,ekO,gJ9,d2L,gJ9,enI,gJ9,bbn,gJ9,feX,gJ9,avl,gJ9,egZ,gJ9,bak,gJ9,a8h,gJ9,aIP,gJ9,ey8,gJ9,fcp,gJ9,etL,gJ9,dCG,gJ9,dpl,gJ9,dL0,gJ9,evj,gJ9,em0,gJ9,beB,gJ9,TA,gJ9,d9Z,gJ9,UN,gJ9,bej,gJ9,ahQ,gJ9,e$u,gJ9,aSs,gJ9,aIW,gJ9,gDc,gJ9,aCX,gJ9,eQz,gJ9,cNv,gJ9,cAV,gJ9,fdw,gJ9,d9o,gJ9,etO,gJ9,e_h,gJ9,aJE,gJ9,adc,gJ9,gHq,gJ9,fvX,gJ9,a2M,gJ9,e8P,gJ9,d$x,gJ9,aSz,gJ9,dT0,gJ9,e$8,gJ9,ePn,gJ9,e$6,gJ9,eCi,gJ9,fe$,gJ9,fff,gJ9,bbd,gJ9,feT,gJ9,df$,gJ9,e25,gJ9,a7s,gJ9,ejO,gJ9,dMi,gJ9,d7y,gJ9,a8o,gJ9,d$r,gJ9,eVh,gJ9,d2n,gJ9,djS,gJ9,doR,gJ9,esZ,gJ9,e0i,gJ9,a7g,gJ9,fxP,gJ9,bpf,gJ9,ePo,gJ9,dyl,gJ9,axn,gJ9,efh,gJ9,d2k,gJ9,fe1,gJ9,d8j,gJ9,gHr,gJ9,a8s,gJ9,dxx,gJ9,dCE,gJ9,doc,gJ9,a8g,gJ9,ekf,gJ9,gHs,gJ9,e$T,gJ9,gDO,gJ9,d2H,gJ9,ahG,gJ9,eOp,gJ9,eB1,gJ9,gDg,gJ9,d$i,gJ9,dZe,gJ9,d2x,gJ9,dSn,gJ9,aIU,gJ9,d1i,gJ9,eDs,gJ9,cz6,gJ9,fd8,gJ9,d1J,gJ9,euf,gJ9,eug,gJ9,e3h,gJ9,dnz,gJ9,dpj,gJ9,axo,gJ9,aYa,gJ9,exi,gJ9,egX,gJ9,aAR,gJ9,VU,gJ9,as_,gJ9,bbQ,gJ9,ia,gJ9,bpt,gJ9,e3n,gJ9,ju,gJ9,bbh,gJ9,feD,gJ9,aX6,gJ9,atk,gJ9,do7,gJ9,d2Q,gJ9,dQt,gJ9,e2V,gJ9,feH,gJ9,fmZ,gJ9,e2U,gJ9,bqE,gJ9,d8R,gJ9,fd0,gJ9,cAs,gJ9,cAu,gJ9,dNB,gJ9,exb,gJ9,fsi,gJ9,eix,gJ9,e6F,gJ9,eOd,gJ9,aRl,gJ9,enO,gJ9,d20,gJ9,dym,gJ9,e6r,gJ9,ahs,gJ9,awq,gJ9,a1o,gJ9,adf,gJ9,dQ1,gJ9,eOk,gJ9,foW,gJ9,gFy,gJ9,e9G,gJ9,aHl,gJ9,bfy,gJ9,dqe,gJ9,evk,gJ9,RV,gJ9,cN3,gJ9,fqV,gJ9,eX8,gJ9,awn,gJ9,eih,gJ9,bnV,gJ9,U5,gJ9,d2l,gJ9,ahd,gJ9,a1g,gJ9,a01,gJ9,dyC,gJ9,d22,gJ9,gHt,gJ9,d2h,gJ9,fjS,gJ9,a7u,gJ9,a8q,gJ9,gDn,gJ9,d$k,gJ9,dxn,gJ9,eP5,gJ9,a_l,gJ9,eP4,gJ9,aMg,gJ9,fnM,gJ9,be$,gJ9,aJD,gJ9,hJ,gJ9,ekx,gJ9,ehA,gJ9,azP,gJ9,cFf,gJ9,aL9,gJ9,d06,gJ9,dVi,gJ9,d9O,gJ9,e_e,gJ9,dGR,gJ9,biK,gJ9,emY,gJ9,bbL,gJ9,exd,gJ9,dn9,gJ9,ePP,gJ9,cAf,gJ9,bfC,gJ9,aXt,gJ9,aA5,gJ9,aCY,gJ9,fj9,gJ9,gHu,gJ9,dPq,gJ9,ki,gJ9,fxH,gJ9,ah4,gJ9,dRM,gJ9,aVI,gJ9,bpL,gJ9,ffl,gJ9,e3k,gJ9,flV,gJ9,e9g,gJ9,axW,gJ9,d2K,gJ9,awJ,gJ9,e2Q,gJ9,dLw,gJ9,d7o,gJ9,eYd,gJ9,dAn,gJ9,ePQ,gJ9,ftz,gJ9,cFy,gJ9,azG,gJ9,aCz,gJ9,dgm,gJ9,ew7,gJ9,eW6,gJ9,aZ4,gJ9,esV,gJ9,fxL,gJ9,ftx,gJ9,d2m,gJ9,fqo,gJ9,kl,gJ9,aw9,gJ9,atV,gJ9,gHv,gJ9,aTn,gJ9,eQe,gJ9,a1y,gJ9,dGm,gJ9,aXd,gJ9,e$R,gJ9,eaN,gJ9,e5V,gJ9,eNS,gJ9,fxn,gJ9,d$a,gJ9,ek2,gJ9,a1A,gJ9,bpI,gJ9,fuw,gJ9,enp,gJ9,bq4,gJ9,ejP,gJ9,enw,gJ9,a8e,gJ9,e_i,gJ9,aIy,gJ9,ekS,gJ9,do9,gJ9,fsm,gJ9,ed3,gJ9,aJj,gJ9,drY,gJ9,enq,gJ9,dgd,gJ9,bi5,gJ9,eea,gJ9,az9,gJ9,eWw,gJ9,enc,gJ9,e_v,gJ9,aAX,gJ9,ePU,gJ9,dGJ,gJ9,d$h,gJ9,eF6,gJ9,ece,gJ9,feJ,gJ9,exq,gJ9,gFx,gJ9,aVT,gJ9,cAq,gJ9,bqZ,gJ9,gzK,gJ9,d8d,gJ9,d8n,gJ9,gHw,gJ9,dfq,gJ9,d66,gJ9,gHx,gJ9,aLd,gJ9,dSe,gJ9,aAv,gJ9,dgb,gJ9,fei,gJ9,enY,gJ9,aL8,gJ9,eP9,gJ9,eQa,gJ9,d21,gJ9,gHy,gJ9,a9P,gJ9,dmQ,gJ9,l4,gJ9,eCf,gJ9,fpp,gJ9,axp,gJ9,cAp,gJ9,dqY,gJ9,dYU,gJ9,emT,gJ9,dgq,gJ9,frP,gJ9,ezc,gJ9,aQD,gJ9,aw0,gJ9,e2w,gJ9,emX,gJ9,exh,gJ9,flr,gJ9,dPp,gJ9,ag$,gJ9,dTb,gJ9,aDz,gJ9,eP8,gJ9,eQA,gJ9,ez9,gJ9,a8j,gJ9,dGk,gJ9,fqZ,gJ9,dE1,gJ9,bgU,gJ9,foc,gJ9,d9_,gJ9,a1q,gJ9,d$o,gJ9,dAt,gJ9,ePG,gJ9,gHz,gJ9,evD,gJ9,enW,gJ9,dB_,gJ9,S9,gJ9,fys,gJ9,awL,gJ9,ax0,gJ9,gDr,gJ9,fxR,gJ9,atT,gJ9,aX4,gJ9,faW,gJ9,avo,gJ9,bgz,gJ9,dlo,gJ9,a6M,gJ9,eKo,gJ9,aSA,gJ9,dVc,gJ9,gDK,gJ9,bbD,gJ9,eBJ,gJ9,WE,gJ9,e2W,gJ9,ffr,gJ9,eW0,gJ9,dxS,gJ9,as2,gJ9,bq8,gJ9,dvI,gJ9,d$v,gJ9,aU5,gJ9,fra,gJ9,aOc,gJ9,dx6,gJ9,euj,gJ9,eY6,gJ9,fcx,gJ9,flv,gJ9,aAu,gJ9,dU5,gJ9,dpk,gJ9,bf7,gJ9,e9C,gJ9,azZ,gJ9,cAj,gJ9,fxf,gJ9,eOm,gJ9,fxd,gJ9,d2Y,gJ9,feV,gJ9,de7,gJ9,enA,gJ9,euJ,gJ9,Vn,gJ9,gHA,gJ9,ePD,gJ9,fxh,gJ9,a6Q,gJ9,ffP,gJ9,ahz,gJ9,dGS,gJ9,aBa,gJ9,e6N,gJ9,fx7,gJ9,gHB,gJ9,bqk,gJ9,eIL,gJ9,aDg,gJ9,dEO,gJ9,bfA,gJ9,eVP,gJ9,eOr,gJ9,faU,gJ9,gHC,gJ9,gEm,gJ9,dj7,gJ9,awH,gJ9,exo,gJ9,dB9,gJ9,aDv,gJ9,dlC,gJ9,esC,gJ9,fxB,gJ9,bbu,gJ9,feR,gJ9,fsj,gJ9,aho,gJ9,evl,gJ9,exu,gJ9,dgQ,gJ9,fk5,gJ9,gDd,gJ9,bhk,gJ9,eYY,gJ9,enm,gJ9,dO7,gJ9,aHj,gJ9,fnj,gJ9,ePZ,gJ9,bai,gJ9,fk9,gJ9,bq0,gJ9,fwu,gJ9,fkI,gJ9,d9Q,gJ9,bhH,gJ9,eFM,gJ9,aw6,gJ9,eHt,gJ9,bqF,gJ9,bpQ,gJ9,ffv,gJ9,bf9,gJ9,eiB,gJ9,aQF,gJ9,bk$,gJ9,fez,gJ9,e$N,gJ9,dz0,gJ9,a8c,gJ9,edZ,gJ9,bki,gJ9,enz,gJ9,ecK,gJ9,gFz,gJ9,UK,gJ9,es2,gJ9,eKk,gJ9,cAU,gJ9,avi,gJ9,fnN,gJ9,a_r,gJ9,aGY,gJ9,aQG,gJ9,dk7,gJ9,dPw,gJ9,dlT,gJ9,eOo,gJ9,fco,gJ9,a09,gJ9,eFG,gJ9,dEM,gJ9,fep,gJ9,bjC,gJ9,ePN,gJ9,dfG,gJ9,djU,gJ9,eez,gJ9,fsq,gJ9,eac,gJ9,e3r,gJ9,bbq,gJ9,eVI,gJ9,eDh,gJ9,a78,gJ9,eDg,gJ9,ehm,gJ9,dCt,gJ9,ahM,gJ9,gHD,gJ9,e3f,gJ9,fkL,gJ9,geS,gJ9,di_,gJ9,eQw,gJ9,dAp,gJ9,dUT,gJ9,ffd,gJ9,gzW,gJ9,Vd,gJ9,fvM,gJ9,es_,gJ9,ewJ,gJ9,lE,gJ9,ers,gJ9,edI,gJ9,bbj,gJ9,gHE,gJ9,dlD,gJ9,gDp,gJ9,dVh,gJ9,WC,gJ9,d86,gJ9,ahr,gJ9,aYh,gJ9,eZS,gJ9,exn,gJ9,dmz,gJ9,aUb,gJ9,a_h,gJ9,cE5,gJ9,eCE,gJ9,dxo,gJ9,a7o,gJ9,T9,gJ9,ezY,gJ9,ePp,gJ9,euD,gJ9,fwN,gJ9,eyi,gJ9,ePq,gJ9,faQ,gJ9,eyx,gJ9,Ww,gJ9,aBb,gJ9,dAq,gJ9,ffJ,gJ9,df8,gJ9,eQi,gJ9,eY_,gJ9,fno,gJ9,aEJ,gJ9,fwl,gJ9,cCQ,gJ9,ebN,gJ9,fw3,gJ9,evz,gJ9,e6K,gJ9,e3l,gJ9,ah$,gJ9,e1_,gJ9,e22,gJ9,d05,gJ9,a8n,gJ9,ffx,gJ9,ekZ,gJ9,ewL,gJ9,UO,gJ9,fxp,gJ9,add,gJ9,VS,gJ9,d8f,gJ9,j8,gJ9,etk,gJ9,dgo,gJ9,eas,gJ9,aLk,gJ9,eCA,gJ9,dx8,gJ9,foS,gJ9,cNw,gJ9,d8Q,gJ9,euh,gJ9,aFq,gJ9,efV,gJ9,aEm,gJ9,e$P,gJ9,bqA,gJ9,aJA,gJ9,emU,gJ9,diX,gJ9,bj$,gJ9,bpC,gJ9,eKq,gJ9,aFL,gJ9,eKn,gJ9,gHF,gJ9,ahS,gJ9,eIA,gJ9,ekC,gJ9,aUr,gJ9,foV,gJ9,eby,gJ9,fjx,gJ9,fod,gJ9,ek_,gJ9,ftC,gJ9,es5,gJ9,ed8,gJ9,azL,gJ9,dlR,gJ9,eF5,gJ9,ahu,gJ9,bqR,gJ9,bpT,gJ9,e6l,gJ9,fwP,gJ9,ke,gJ9,dwZ,gJ9,bhG,gJ9,dFk,gJ9,ek$,gJ9,e6U,gJ9,frw,gJ9,T5,gJ9,aYg,gJ9,eyg,gJ9,ec_,gJ9,bqY,gJ9,aTt,gJ9,bml,gJ9,e9l,gJ9,d2A,gJ9,bbp,gJ9,d$b,gJ9,dgK,gJ9,e$Z,gJ9,fct,gJ9,fru,gJ9,gAG,gJ9,ahb,gJ9,eIl,gJ9,eF1,gJ9,aFJ,gJ9,dTX,gJ9,aHA,gJ9,azR,gJ9,fea,gJ9,a7q,gJ9,bnh,gJ9,dgN,gJ9,T$,gJ9,aJx,gJ9,eQh,gJ9,f9L,gJ9,a0E,gJ9,e_t,gJ9,a4O,gJ9,e0q,gJ9,fvK,gJ9,fxx,gJ9,aKP,gJ9,fc4,gJ9,enQ,gJ9,d9z,gJ9,dqF,gJ9,e9j,gJ9,de5,gJ9,e5T,gJ9,d1j,gJ9,efd,gJ9,aBc,gJ9,fu2,gJ9,a0M,gJ9,dMf,gJ9,eFn,gJ9,dgI,gJ9,dhD,gJ9,gHG,gJ9,TY,gJ9,bbf,gJ9,gHH,gJ9,fos,gJ9,dgS,gJ9,aQ_,gJ9,ejR,gJ9,dyw,gJ9,ffN,gJ9,fe7,gJ9,hn,gJ9,e_d,gJ9,e2y,gJ9,aBe,gJ9,aBi,gJ9,eB$,gJ9,cAE,gJ9,eW2,gJ9,ew_,gJ9,eB0,gJ9,a1v,gJ9,gDm,gJ9,e$V,gJ9,bpv,gJ9,cFx,gJ9,fxF,gJ9,bgT,gJ9,fft,gJ9,fqp,gJ9,dnD,gJ9,e$4,gJ9,dPu,gJ9,eab,gJ9,dza,gJ9,dwz,gJ9,ez7,gJ9,bnJ,gJ9,d9C,gJ9,bhC,gJ9,lZ,gJ9,aUp,gJ9,iZ,gJ9,bp8,gJ9,emm,gJ9,bkG,gJ9,ed4,gJ9,azQ,gJ9,boX,gJ9,e_p,gJ9,eP3,gJ9,eeA,gJ9,dU3,gJ9,dNx,gJ9,jz,gJ9,dB1,gJ9,aut,gJ9,d7w,gJ9,dy3,gJ9,aXZ,gJ9,flx,gJ9,ePK,gJ9,dsk,gJ9,aPo,gJ9,e0u,gJ9,aAZ,gJ9,bbb,gJ9,bbO,gJ9,eY4,gJ9,dsF,gJ9,fxD,gJ9,feP,gJ9,bpz,gJ9,U9,gJ9,dfF,gJ9,eks,gJ9,ey0,gJ9,beZ,gJ9,dB7,gJ9,d8b,gJ9,d6u,gJ9,bpp,gJ9,aYc,gJ9,eBk,gJ9,bj1,gJ9,e6s,gJ9,bfl,gJ9,e6E,gJ9,e3d,gJ9,aE9,gJ9,enJ,gJ9,e$H,gJ9,ek0,gJ9,dEj,gJ9,d8U,gJ9,aua,gJ9,dvJ,gJ9,dEn,gJ9,aTS,gJ9,e9f,gJ9,es1,gJ9,eQr,gJ9,dtw,gJ9,em6,gJ9,gHI,gJ9,fr$,gJ9,fyJ,gJ9,fnn,gJ9,dff,gJ9,a03,gJ9,WL,gJ9,fu$,gJ9,cEp,gJ9,dFo,gJ9,fer,gJ9,aGI,gJ9,ho,gJ9,dfp,gJ9,a4Q,gJ9,a2Q,gJ9,eYW,gJ9,gHJ,gJ9,cEU,gJ9,dCH,gJ9,eXD,gJ9,fxv,gJ9,e20,gJ9,em$,gJ9,ahn,gJ9,ez0,gJ9,doa,gJ9,bq1,gJ9,d87,gJ9,T_,gJ9,bkI,gJ9,esW,gJ9,edi,gJ9,azC,gJ9,e2Y,gJ9,dzi,gJ9,fwB,gJ9,aTv,gJ9,ePR,gJ9,djw,gJ9,cAQ,gJ9,dEu,gJ9,azJ,gJ9,fte,gJ9,d$z,gJ9,brb,gJ9,atd,gJ9,ahZ,gJ9,dqc,gJ9,ahe,gJ9,gDe,gJ9,a_p,gJ9,dE3,gJ9,azH,gJ9,fyx,gJ9,eil,gJ9,do5,gJ9,do8,gJ9,dhB,gJ9,dPo,gJ9,e5P,gJ9,bbl,gJ9,cAo,gJ9,aNj,gJ9,dMB,gJ9,cN5,gJ9,aKJ,gJ9,fty,gJ9,eBN,gJ9,dmS,gJ9,aDw,gJ9,aX9,gJ9,e0w,gJ9,e_w,gJ9,d0Y,gJ9,fxr,gJ9,ekt,gJ9,eIz,gJ9,etR,gJ9,flU,gJ9,feZ,gJ9,blM,gJ9,ahj,gJ9,axY,gJ9,feN,gJ9,e2L,gJ9,eKl,gJ9,drW,gJ9,boZ,gJ9,e23,gJ9,Vq,gJ9,eAb,gJ9,a1b,gJ9,bnZ,gJ9,beh,gJ9,faS,gJ9,atj,gJ9,fej,gJ9,e18,gJ9,aJ_,gJ9,diD,gJ9,bpG,gJ9,ekD,gJ9,azY,gJ9,eOD,gJ9,e0k,gJ9,gz7,gJ9,ekd,gJ9,boy,gJ9,eVK,gJ9,gHK,gJ9,efe,gJ9,bnY,gJ9,eW_,gJ9,bqC,gJ9,fxt,gJ9,eke,gJ9,etq,gJ9,evQ,gJ9,dqD,gJ9,fdc,gJ9,evU,gJ9,dDK,gJ9,dFm,gJ9,dgc,gJ9,dLx,gJ9,kf,gJ9,fda,gJ9,ePX,gJ9,d$m,gJ9,gDD,gJ9,efz,gJ9,fjP,gJ9,ekA,gJ9,ffj,gJ9,ah5,gJ9,kI,gJ9,e6i,gJ9,eyv,gJ9,aIt,gJ9,dRF,gJ9,fka,gJ9,d8V,gJ9,ffz,gJ9,em5,gJ9,gDC,gJ9,kv,gJ9,bbz,gJ9,dhV,gJ9,dgM,gJ9,dnA,gJ9,emg,gJ9,ef_,gJ9,e6z,gJ9,aXP,gJ9,e0c,gJ9,ftd,gJ9,gDo,gJ9,aCP,gJ9,dq_,gJ9,esA,gJ9,lD,gJ9,ax_,gJ9,atC,gJ9,fso,gJ9,fku,gJ9,enB,gJ9,fds,gJ9,eWu,gJ9,fk8,gJ9,dfn,gJ9,fyv,gJ9,gHL,gJ9,dnF,gJ9,bmW,gJ9,e9F,gJ9,a1t,gJ9,azB,gJ9,asw,gJ9,ahc,gJ9,d7C,gJ9,ahx,gJ9,cG3,gJ9,geU,gJ9,Ur,gJ9,aVK,gJ9,fkH,gJ9,dGN,gJ9,fev,gJ9,bpN,gJ9,cCR,gJ9,fec,gJ9,ehj,gJ9,dsG,gJ9,enU,gJ9,flR,gJ9,dzg,gJ9,exc,gJ9,eID,gJ9,e6B,gJ9,ekW,gJ9,bgY,gJ9,k_,gJ9,a8a,gJ9,ahT,gJ9,dS7,gJ9,dRD,gJ9,e82,gJ9,de6,gJ9,ecb,gJ9,e2x,gJ9,e_m,gJ9,dZm,gJ9,fc6,gJ9,cAC,gJ9,dne,gJ9,dDJ,gJ9,eQb,gJ9,ez4,gJ9,e6j,gJ9,eHv,gJ9,bgx,gJ9,bkk,gJ9,dfd,gJ9,fmV,gJ9,drr,gJ9,e6w,gJ9,bbJ,gJ9,geN,gJ9,diB,gJ9,ffh,gJ9,dYq,gJ9,d2c,gJ9,dln,gJ9,gHM,gJ9,fu3,gJ9,blb,gJ9,e$1,gJ9,eCB,gJ9,aMc,gJ9,bpD,gJ9,dGP,gJ9,fqL,gJ9,a4M,gJ9,eVO,gJ9,aDf,gJ9,ahp,gJ9,dk5,gJ9,e2I,gJ9,dsA,gJ9,ahU,gJ9,aIX,gJ9,aSy,gJ9,fvO,gJ9,dT$,gJ9,drt,gJ9,a1e,gJ9,aub,gJ9,e2e,gJ9,ekN,gJ9,a_j,gJ9,ahv,gJ9,emo,gJ9,ePO,gJ9,fj6,gJ9,fxl,gJ9,ffB,gJ9,egV,gJ9,dPs,gJ9,edJ,gJ9,dfh,gJ9,d9A,gJ9,aty,gJ9,ekJ,gJ9,a8k,gJ9,fd2,gJ9,ehz,gJ9,fv_,gJ9,gDs,gJ9,aA$,gJ9,fw4,gJ9,evY,gJ9,aEj,gJ9,dNk,gJ9,euB,gJ9,bpS,gJ9,d9N,gJ9,dMV,gJ9,dYp,gJ9,aEK,gJ9,aVN,gJ9,eWW,gJ9,eKm,gJ9,d8l,gJ9,Vp,gJ9,ePx,gJ9,a7$,gJ9,azA,gJ9,dCr,gJ9,eP1,gJ9,enF,gJ9,U8,gJ9,av9,gJ9,e2N,gJ9,dAr,gJ9,aEF,gJ9,ew3,gJ9,eWU,gJ9,dEp,gJ9,doJ,gJ9,dlp,gJ9,eaR,gJ9,aHY,gJ9,gz1,gJ9,euL,gJ9,enH,gJ9,ee6,gJ9,bqI,gJ9,Ua,gJ9,ade,gJ9,fuq,gJ9,ems,gJ9,e3j,gJ9,kh,gJ9,gDJ,gJ9,evV,gJ9,fyi,gJ9,bq9,gJ9,bpM,gJ9,dfo,gJ9,gFw,gJ9,e3p,gJ9,aGu,gJ9,ehB,gJ9,cAy,gJ9,gEh,gJ9,frO,gJ9,ePu,gJ9,gDL,gJ9,dgO,gJ9,aFr,gJ9,eaG,gJ9,dxQ,gJ9,gDx,gJ9,dwB,gJ9,aAV,gJ9,enb,gJ9,Ve,gJ9,dU7,gJ9,geL,gJ9,d2d,gJ9,ent,gJ9,e0o,gJ9,bqQ,gJ9,eev,gJ9,fqK,gJ9,ebQ,gJ9,aA1,gJ9,aTQ,gJ9,dsm,gJ9,edm,gJ9,bi4,gJ9,dmx,gJ9,ffR,gJ9,eCe,gJ9,e2l,gJ9,d$s,gJ9,fqW,gJ9,e6L,gJ9,bez,gJ9,cFZ,gJ9,fet,gJ9,ah_,gJ9,eF2,gJ9,RB,gJ9,evR,gJ9,geO,gJ9,ekR,gJ9,e6p,gJ9,bqU,gJ9,ejM,gJ9,dVg,gJ9,eQf,gJ9,dkF,gJ9,cz7,gJ9,aVP,gJ9,exg,gJ9,ffb,gJ9,fuu,gJ9,dNi,gJ9,ekF,gJ9,eOi,gJ9,e6O,gJ9,fut,gJ9,dMx,gJ9,fxJ,gJ9,diW,gJ9,bql,gJ9,bbw,gJ9,bbN,gJ9,dFg,gJ9,dLA,gJ9,dfe,gJ9,dhT,gJ9,avn,gJ9,WZ,gJ9,dn7,gJ9,eP$,gJ9,bqp,gJ9,dgU,gJ9,bby,gJ9,euz,gJ9,eyY,gJ9,gHN,gJ9,bnU,gJ9,e0g,gJ9,dmO,gJ9,fnq,gJ9,asZ,gJ9,ePF,gJ9,kr,gJ9,eVj,gJ9,ed7,gJ9,d8h,gJ9,frc,gJ9,bqB,gJ9,bg$,gJ9,e6H,gJ9,fxj,gJ9,a0R,gJ9,d2g,gJ9,ax9,gJ9,eW8,gJ9,fot,gJ9,fv6,gJ9,enf,gJ9,d7A,gJ9,eY2,gJ9,f0$,gJ9,d1O,gJ9,dty,gJ9,dVd,gJ9,etm,gJ9,atl,gJ9,ehD,gJ9,eb7,gJ9,fd4,gJ9,ati,gJ9,bmC,gJ9,d2J,gJ9,ahi,gJ9,ePB,gJ9,euH,gJ9,e2_,gJ9,bfi,gJ9,f5g,gJ9,jX,gJ9,kq,gJ9,e3t,gJ9,fcn,gJ9,avm,gJ9,cAz,gJ9,e2O,gJ9,ew4,gJ9,ex0,gJ9,eWY,gJ9,fc8,gJ9,atA,gJ9,dZg,gJ9,aXX,gJ9,eiU,gJ9,cAk,gJ9,dZc,gJ9,fel,gJ9,dO6,gJ9,bhI,gJ9,esm,gJ9,bbH,gJ9,ecX,gJ9,jY,gJ9,eFK,gJ9,d2Z,gJ9,efv,gJ9,edG,gJ9,eiX,gJ9,aLj,gJ9,ePz,gJ9,aMh,gJ9,ey4,gJ9,dZi,gJ9,aRm,gJ9,asY,gJ9,gHO,gJ9,dju,gJ9,a1l,gJ9,es3,gJ9,dCJ,gJ9,fdW,gJ9,eVH,gJ9,eyh,gJ9,flu,gJ9,cBe,gJ9,eW4,gJ9,dqh,gJ9,ekE,gJ9,ebd,gJ9,ex2,gJ9,e6Q,gJ9,aw8,gJ9,dQs,gJ9,aF2,gJ9,dFi,gJ9,Va,gJ9,edj,gJ9,ePE,gJ9,eQo,gJ9,fwJ,gJ9,dY8,gJ9,gHP,gJ9,ef1,gJ9,dTZ,gJ9,aA7,gJ9,dYT,gJ9,ffD,gJ9,eze,gJ9,dxv,gJ9,enM,gJ9,gDI,gJ9,edn,gJ9,dfr,gJ9,e$L,gJ9,atE,gJ9,bqV,gJ9,ebv,gJ9,dEq,gJ9,efB,gJ9,fe3,gJ9,eBM,gJ9,ekK,gJ9,dyA,gJ9,ffF,gJ9,ffH,gJ9,aTN,gJ9,fee,gJ9,etP,gJ9,dYv,gJ9,geT,gJ9,dTO,gJ9,ePj,gJ9,aMk,gJ9,bgX,gJ9,dsp,gJ9,df4,gJ9,azI,gJ9,ah3,gJ9,WY,gJ9,eII,gJ9,axq,gJ9,aRn,gJ9,d2P,gJ9,e0a,gJ9,e5R,gJ9,fde,gJ9,ewD,gJ9,ezW,gJ9,enl,gJ9,ePW,gJ9,dNz,gJ9,ffp,gJ9,fxz,gJ9,dGo,gJ9,ahI,gJ9,bqD,gJ9,aHV,gJ9,bbr,gJ9,dLZ,gJ9,e29,gJ9,fkt,gJ9,gDb,gJ9,dEl,gJ9,cEo,gJ9,enC,gJ9,dRN,gJ9,e$3,gJ9,doS,gJ9,eIJ,gJ9,bqh,gJ9,a_t,gJ9,dRJ,gJ9,fex,gJ9,e0y,gJ9,em8,gJ9,boA,gJ9,eyZ,gJ9,d1m,gJ9,e3b,gJ9,aA3,gJ9,a0D,gJ9,esi,gJ9,dvL,gJ9,aJ$,gJ9,eca,gJ9,edK,gJ9,aIz,gJ9,dqB,gJ9,aGj,gJ9,aXw,gJ9,Vv,gJ9,aHT,gJ9,aXV,gJ9,esh,gJ9,a8d,gJ9,a7k,gJ9,bqo,gJ9,eiT,gJ9,aSu,gJ9,dZa,gJ9,bk0,gJ9,Uq,gJ9,fqq,gJ9,eVL,gJ9,dyx,gJ9,Ub,gJ9,gFB,gJ9,eFm,gJ9,aUB,gJ9,d2z,gJ9,aDA,gJ9,efw,gJ9,ewK,gJ9,e5h,gJ9,eiy,gJ9,d9n,gJ9,es6,gJ9,d2s,gJ9,etl,gJ9,diu,gJ9,doe,gJ9,cN2,gJ9,dtq,gJ9,drp,gJ9,ebL,gJ9,Tw,gJ9,aVL,gJ9,dCc,gJ9,bpq,gJ9,bqJ,gJ9,ah0,gJ9,cF_,gJ9,dnc,gJ9,bp9,gJ9,aLh,gJ9,gHQ,gJ9,ey9,gJ9,fpo,gJ9,d2w,gJ9,ftc,gJ9,e_l,gJ9,frb,gJ9,e9m,gJ9,ez2,gJ9,cEH,gJ9,eQy,gJ9,dgf,gJ9,eYb,gJ9,dTY,gJ9,dSy,gJ9,eQl,gJ9,ets,gJ9,exm,gJ9,e2H,gJ9,gAU,gJ9,eHr,gJ9,eaO,gJ9,emj,gJ9,gHR,gJ9,dfz,gJ9,aIV,gJ9,bqM,gJ9,bnj,gJ9,ePt,gJ9,d2F,gJ9,bqN,gJ9,bmj,gJ9,dka,gJ9,dll,gJ9,dvt,gJ9,aEn,gJ9,gDA,gJ9,dTa,gJ9,kM,gJ9,ahL,gJ9,ekV,gJ9,do6,gJ9,dxr,gJ9,e6f,gJ9,fwT,gJ9,feB,gJ9,cAD,gJ9,aKR,gJ9,cN6,gJ9,cAn,gJ9,ffn,gJ9,aX8,gJ9,eIG,gJ9,eml,gJ9,e2S,gJ9,bhD,gJ9,az_,gJ9,feL,gJ9,ahP,gJ9,eBI,gJ9,fx9,gJ9,ahJ,gJ9,a8l,gJ9,bhm,gJ9,dsB,gJ9,dzc,gJ9,fxN,gJ9,fkq,gJ9,aJw,gJ9,dRI,gJ9,bag,gJ9,Us,gJ9,dpm,gJ9,a1j,gJ9,a2N,gJ9,aTU,gJ9,ffL,gJ9,aSw,gJ9,euF,gJ9,aOg,gJ9,ePw,gJ9,a_n,gJ9,d$e,gJ9,gfb,gJ9,dkJ,gJ9,dLX,gJ9,dze,gJ9,e5N,gJ9,bpy,gJ9,gHS,gJ9,aMd,gJ9,gFA,gJ9,aw7,gJ9,dlF,gJ9,awo,gJ9,drv,gJ9,aVR,gJ9,bq5,gJ9,frv,gJ9,l5,gJ9,a6O,gJ9,a7m,gJ9,aTO,gJ9,feg,gJ9,exs,gJ9,eY0,gJ9,e6y,gJ9,gHT,gJ9,ahy,gJ9,fnL,gJ9,fxS,gJ9,gHU,gJ9,awp,gJ9,dmv,gJ9,e$J,gJ9,dND,gJ9,jF,gJ9,aGx,gJ9,dMy,gJ9,ecg,gJ9,dt4,gJ9,dY5,gJ9,az8,gJ9,iK,gJ9,eQu,gJ9,eBO,gJ9,a0T,gJ9,enS,gJ9,ey5,gJ9,as0,gJ9,aVE,gJ9,awF,gJ9,fe5,gJ9,e6T,gJ9,cEY,gJ9,bgd,gJ9,es4,gJ9,e6I,gJ9,aVG,gJ9,bjA,gJ9,gDh,gJ9,a_f,gJ9,dvr,gJ9,eew,gJ9,e6R,gJ9,dVj,gJ9,av8,gJ9,eQq,gJ9,d7u,gJ9,d67,gJ9,ePY,gJ9,dgG,gJ9,atW,gJ9,cAF,gJ9,fci,gJ9,e0m,gJ9,dV6,gJ9,dYt,gJ9,d7q,gJ9,d7s,gJ9,aUD,gJ9,dZk,gJ9,ebM,gJ9,aKk,gJ9,aIO,gJ9,d2B,gJ9,eZ1,gJ9,ecW,gJ9,gDy,gJ9,aGJ,gJ9,aBg,gJ9,bqg,gJ9,gHV,gJ9,eat,gJ9,feF,gJ9,ahq,gJ9,eHy,gJ9,dqV,gJ9,ekB,gJ9,gDN,gJ9,a_v,gJ9,aBk,gJ9,fen,gJ9,bpR,gJ9,eiQ,gJ9,cF$,gJ9,bmA,gJ9,e2v,gJ9,aus,gJ9,bl_,gJ9,fcv,gJ9,fnp,gJ9,fc2,gJ9,aZ2,gJ9,fv5,gJ9,fcO,gJ9,ejt,gJ9,dQr,gJ9,atU,gJ9,e6C,gJ9,cBd,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9,gJ9];var gh=[gKa,gKa,iM,gKa,iO,gKa,iG,gKa,iN,gKa,j7,gKa,gKa,gKa,gKa,gKa];var gi=[gKb,gKb,gJv,gKb];var gj=[gKc,gKc,dMz,gKc,gFP,gKc,dLW,gKc,gCK,gKc,bpn,gKc,feM,gKc,eFo,gKc,e6m,gKc,dqE,gKc,e6M,gKc,a8p,gKc,fq9,gKc,ath,gKc,dlm,gKc,a7p,gKc,aNn,gKc,a0H,gKc,fxe,gKc,e28,gKc,Wj,gKc,e6n,gKc,d6v,gKc,gCV,gKc,e11,gKc,aEI,gKc,bni,gKc,bpJ,gKc,d7p,gKc,aVH,gKc,dAw,gKc,dNA,gKc,eIC,gKc,fus,gKc,bq_,gKc,bqS,gKc,aHP,gKc,d1K,gKc,bge,gKc,aP7,gKc,dGO,gKc,fcP,gKc,eVM,gKc,ewI,gKc,a0S,gKc,gdL,gKc,dso,gKc,aMf,gKc,eBP,gKc,fk6,gKc,h2,gKc,aVM,gKc,fe_,gKc,ffg,gKc,ez$,gKc,fdu,gKc,bfz,gKc,gDw,gKc,e$2,gKc,bp2,gKc,fvP,gKc,faR,gKc,dRL,gKc,em_,gKc,gFl,gKc,bqO,gKc,dQe,gKc,Wh,gKc,fwC,gKc,bpo,gKc,eN9,gKc,dU2,gKc,gdT,gKc,dyy,gKc,fx_,gKc,dqb,gKc,azF,gKc,dV4,gKc,e6S,gKc,e0t,gKc,feY,gKc,dxs,gKc,aHC,gKc,fc9,gKc,aKH,gKc,bq2,gKc,dhS,gKc,gFE,gKc,ahW,gKc,eKp,gKc,dQq,gKc,dxt,gKc,evZ,gKc,e_s,gKc,dft,gKc,fv7,gKc,gFC,gKc,ek1,gKc,aEM,gKc,fc1,gKc,dNe,gKc,ekG,gKc,gHW,gKc,fwH,gKc,fnP,gKc,aCA,gKc,emk,gKc,eW$,gKc,euC,gKc,aA8,gKc,dlQ,gKc,feC,gKc,aVF,gKc,ePk,gKc,eOB,gKc,ffm,gKc,dVa,gKc,fwo,gKc,flt,gKc,etn,gKc,e2X,gKc,dTd,gKc,ewH,gKc,dqA,gKc,ahF,gKc,enr,gKc,ag_,gKc,dCb,gKc,fe6,gKc,feu,gKc,ebO,gKc,bfB,gKc,flS,gKc,gHX,gKc,d9l,gKc,fsp,gKc,aXe,gKc,eDj,gKc,beC,gKc,dZb,gKc,bpx,gKc,e21,gKc,d9P,gKc,ekz,gKc,frt,gKc,faT,gKc,dNl,gKc,em4,gKc,fc7,gKc,feb,gKc,bpF,gKc,ate,gKc,ffG,gKc,bqa,gKc,dyD,gKc,aFa,gKc,df_,gKc,dNC,gKc,dtr,gKc,gF9,gKc,du1,gKc,ax$,gKc,a_4,gKc,bps,gKc,bj0,gKc,gFb,gKc,fd5,gKc,d9B,gKc,fv4,gKc,fwO,gKc,eff,gKc,dYW,gKc,eiA,gKc,d7v,gKc,e3q,gKc,fjT,gKc,bbe,gKc,blN,gKc,fu0,gKc,eOh,gKc,bei,gKc,eBj,gKc,bp4,gKc,d2G,gKc,aMb,gKc,exp,gKc,d8a,gKc,dEm,gKc,eaS,gKc,f9k,gKc,d7x,gKc,bp1,gKc,ffO,gKc,gE5,gKc,dY9,gKc,a4L,gKc,eOn,gKc,ePI,gKc,eny,gKc,i0,gKc,fw2,gKc,ebK,gKc,e2P,gKc,aFM,gKc,e0n,gKc,dNj,gKc,eWT,gKc,dYu,gKc,fs7,gKc,iv,gKc,ekT,gKc,cAt,gKc,eP_,gKc,fqX,gKc,fwm,gKc,eP0,gKc,gzR,gKc,fk7,gKc,d2f,gKc,dqg,gKc,dFe,gKc,d2q,gKc,ekP,gKc,boV,gKc,ffE,gKc,faX,gKc,gHY,gKc,fed,gKc,dE2,gKc,eaQ,gKc,d2C,gKc,aAQ,gKc,gDk,gKc,e$_,gKc,dYV,gKc,dTc,gKc,bgZ,gKc,fyu,gKc,cA7,gKc,eIE,gKc,ew9,gKc,fxI,gKc,aEo,gKc,dzd,gKc,fq8,gKc,e3e,gKc,ahk,gKc,ffa,gKc,bqd,gKc,enZ,gKc,gAZ,gKc,e$U,gKc,a_m,gKc,aKi,gKc,d8S,gKc,dPv,gKc,dtv,gKc,az$,gKc,bgy,gKc,Ry,gKc,eVF,gKc,fx5,gKc,aAb,gKc,fk4,gKc,fc3,gKc,eHC,gKc,ezd,gKc,WD,gKc,eQn,gKc,dmR,gKc,bmX,gKc,e$M,gKc,fns,gKc,frM,gKc,d2u,gKc,flz,gKc,eud,gKc,dhE,gKc,fvJ,gKc,aTm,gKc,f9G,gKc,drX,gKc,fkK,gKc,d2$,gKc,V1,gKc,fxy,gKc,eX7,gKc,d2v,gKc,gd$,gKc,gzx,gKc,dod,gKc,a_o,gKc,iu,gKc,ef3,gKc,avk,gKc,es0,gKc,gHZ,gKc,fnl,gKc,fvL,gKc,evh,gKc,ffC,gKc,eYZ,gKc,gFs,gKc,f9m,gKc,e5O,gKc,dT1,gKc,d2N,gKc,gAK,gKc,gEW,gKc,cAh,gKc,gH_,gKc,dYQ,gKc,eBK,gKc,fcs,gKc,aTV,gKc,a4N,gKc,d$d,gKc,dLY,gKc,aTT,gKc,d03,gKc,drs,gKc,esz,gKc,aHI,gKc,d7z,gKc,a_s,gKc,eey,gKc,dt3,gKc,eF0,gKc,aFK,gKc,dRg,gKc,fpm,gKc,a6P,gKc,fcu,gKc,eQm,gKc,eHB,gKc,ed_,gKc,ftw,gKc,Wd,gKc,eCj,gKc,gFi,gKc,bqm,gKc,ag9,gKc,aQZ,gKc,bqn,gKc,dEt,gKc,fqn,gKc,bmk,gKc,eFL,gKc,dU4,gKc,eCD,gKc,dVe,gKc,div,gKc,Wb,gKc,fmX,gKc,fu1,gKc,dPl,gKc,efx,gKc,eDf,gKc,e12,gKc,gdS,gKc,eCC,gKc,dw_,gKc,ejQ,gKc,ec$,gKc,emn,gKc,eaa,gKc,enh,gKc,bba,gKc,fnr,gKc,eWV,gKc,cAB,gKc,dvH,gKc,e9e,gKc,ftg,gKc,ahK,gKc,ens,gKc,asV,gKc,fup,gKc,eYa,gKc,d89,gKc,gFL,gKc,dnB,gKc,azx,gKc,e6D,gKc,dzh,gKc,aht,gKc,d2W,gKc,egY,gKc,dnE,gKc,es$,gKc,bkJ,gKc,f9n,gKc,ffe,gKc,V7,gKc,gFK,gKc,e$O,gKc,eHq,gKc,ffi,gKc,eIH,gKc,fcw,gKc,e2K,gKc,evS,gKc,emi,gKc,bbm,gKc,edl,gKc,eHh,gKc,bgc,gKc,gH$,gKc,ear,gKc,geR,gKc,flQ,gKc,dgp,gKc,ert,gKc,aLZ,gKc,dqf,gKc,e$W,gKc,bpO,gKc,dZf,gKc,eIK,gKc,fx0,gKc,bk1,gKc,e2T,gKc,ekc,gKc,dPr,gKc,fc5,gKc,edg,gKc,dpi,gKc,dV7,gKc,dj6,gKc,em3,gKc,aTu,gKc,fs9,gKc,gC9,gKc,bbP,gKc,eVG,gKc,ahl,gKc,dwv,gKc,bld,gKc,a1d,gKc,dU8,gKc,eIx,gKc,evE,gKc,eVJ,gKc,dL_,gKc,ehE,gKc,d_9,gKc,az0,gKc,eVy,gKc,as$,gKc,f9c,gKc,gH0,gKc,dGp,gKc,ecI,gKc,aOa,gKc,e5i,gKc,aDy,gKc,aAW,gKc,bpW,gKc,aVJ,gKc,ffI,gKc,bfD,gKc,dZj,gKc,fkr,gKc,auq,gKc,ejS,gKc,aDx,gKc,e$Q,gKc,aIS,gKc,gdG,gKc,eHf,gKc,aya,gKc,aOb,gKc,gz2,gKc,avj,gKc,ext,gKc,d2e,gKc,bqt,gKc,e3m,gKc,fnK,gKc,fyo,gKc,a79,gKc,aVS,gKc,fkp,gKc,aAS,gKc,eFq,gKc,azE,gKc,foU,gKc,fdr,gKc,aDC,gKc,aLi,gKc,dLB,gKc,drV,gKc,dmu,gKc,dfy,gKc,fyr,gKc,dwE,gKc,feO,gKc,ecf,gKc,edk,gKc,dyB,gKc,e9E,gKc,cA9,gKc,d7t,gKc,dV2,gKc,fxC,gKc,fvY,gKc,bmD,gKc,ew6,gKc,df6,gKc,a_q,gKc,aHZ,gKc,azO,gKc,fpn,gKc,kR,gKc,eDm,gKc,flw,gKc,e_k,gKc,eCG,gKc,bp5,gKc,ef$,gKc,bfm,gKc,djT,gKc,VQ,gKc,fye,gKc,e6t,gKc,dvq,gKc,bg_,gKc,e6u,gKc,ex3,gKc,dwC,gKc,ftv,gKc,df3,gKc,dFl,gKc,flq,gKc,cA8,gKc,bqj,gKc,gdM,gKc,e6g,gKc,geP,gKc,a2L,gKc,bbE,gKc,efi,gKc,d6p,gKc,e0j,gKc,eY7,gKc,dV5,gKc,aAY,gKc,bbI,gKc,enN,gKc,gzH,gKc,dV0,gKc,dx5,gKc,gFD,gKc,cCP,gKc,dGQ,gKc,exk,gKc,fqJ,gKc,dmy,gKc,d2M,gKc,eHz,gKc,cAg,gKc,dn8,gKc,eZ2,gKc,efg,gKc,d$g,gKc,fux,gKc,e3c,gKc,eNN,gKc,gEZ,gKc,aVQ,gKc,foa,gKc,fsn,gKc,e5Q,gKc,esj,gKc,fd3,gKc,dT2,gKc,d6t,gKc,dqj,gKc,fxc,gKc,dRK,gKc,ed6,gKc,d1P,gKc,eua,gKc,e0r,gKc,dgP,gKc,TX,gKc,dpa,gKc,eue,gKc,dzf,gKc,fch,gKc,ejq,gKc,dSL,gKc,bgb,gKc,d$p,gKc,fxQ,gKc,Wg,gKc,ehl,gKc,gFu,gKc,brd,gKc,ePm,gKc,ez1,gKc,at9,gKc,ffQ,gKc,gH1,gKc,fyy,gKc,dfU,gKc,dgH,gKc,aXc,gKc,ehn,gKc,gz8,gKc,frL,gKc,aT9,gKc,drn,gKc,end,gKc,ahD,gKc,bn_,gKc,ffk,gKc,d2b,gKc,dpe,gKc,dnC,gKc,WB,gKc,atz,gKc,ka,gKc,aKQ,gKc,Tx,gKc,e_o,gKc,boY,gKc,d2V,gKc,dxu,gKc,fdX,gKc,W_,gKc,do4,gKc,dlG,gKc,dGT,gKc,ag1,gKc,bpA,gKc,azM,gKc,faM,gKc,aA0,gKc,dRQ,gKc,biJ,gKc,faV,gKc,eHj,gKc,doK,gKc,aIZ,gKc,dPt,gKc,e3g,gKc,a0N,gKc,gH2,gKc,gH3,gKc,f87,gKc,ek3,gKc,a0B,gKc,gdE,gKc,dS8,gKc,fw0,gKc,aSx,gKc,evm,gKc,fxk,gKc,dkG,gKc,ffq,gKc,enx,gKc,ese,gKc,dEo,gKc,de3,gKc,aXu,gKc,e$Y,gKc,d$t,gKc,bqw,gKc,ekg,gKc,cG$,gKc,etN,gKc,fyL,gKc,dxw,gKc,aHX,gKc,a1i,gKc,dgE,gKc,de8,gKc,aXY,gKc,ePy,gKc,U7,gKc,e2R,gKc,aU4,gKc,euG,gKc,dGl,gKc,dyn,gKc,cAR,gKc,fwn,gKc,eVN,gKc,k$,gKc,cNt,gKc,d9y,gKc,geK,gKc,e2M,gKc,dfT,gKc,ech,gKc,ahA,gKc,f9e,gKc,eW7,gKc,ePi,gKc,dCs,gKc,cAm,gKc,fxq,gKc,ewE,gKc,dpb,gKc,ejT,gKc,ewM,gKc,bbv,gKc,bpZ,gKc,aLm,gKc,S8,gKc,diE,gKc,dNy,gKc,ffu,gKc,bqX,gKc,dY7,gKc,aIY,gKc,ecY,gKc,boz,gKc,diY,gKc,dhP,gKc,ene,gKc,aJF,gKc,dtx,gKc,dZl,gKc,fyk,gKc,dLz,gKc,fws,gKc,gFH,gKc,feQ,gKc,fek,gKc,bqs,gKc,feK,gKc,dgn,gKc,fcf,gKc,eOE,gKc,gDl,gKc,azT,gKc,ekI,gKc,aXv,gKc,e0p,gKc,e0d,gKc,gDf,gKc,gzz,gKc,aDe,gKc,bgV,gKc,f5f,gKc,fr_,gKc,diC,gKc,feI,gKc,geJ,gKc,doQ,gKc,dy4,gKc,azS,gKc,fem,gKc,dS6,gKc,bpX,gKc,d7B,gKc,fmW,gKc,dBP,gKc,blf,gKc,d0$,gKc,ePT,gKc,fcU,gKc,bnk,gKc,d_8,gKc,bqP,gKc,aJB,gKc,e6x,gKc,dnd,gKc,bqi,gKc,dfl,gKc,f9d,gKc,e5U,gKc,efA,gKc,eY5,gKc,gFM,gKc,e$7,gKc,fsg,gKc,dqC,gKc,ew$,gKc,at8,gKc,We,gKc,a7h,gKc,fjR,gKc,gGq,gKc,fj5,gKc,aSt,gKc,aA4,gKc,dgJ,gKc,emr,gKc,d$j,gKc,atx,gKc,aTP,gKc,gdP,gKc,iP,gKc,dfc,gKc,ed2,gKc,awm,gKc,dy6,gKc,dGK,gKc,ejN,gKc,geZ,gKc,aCQ,gKc,gdN,gKc,a_k,gKc,kZ,gKc,ed9,gKc,ftB,gKc,gFF,gKc,f9j,gKc,atB,gKc,ezV,gKc,dnG,gKc,a1p,gKc,dxR,gKc,e_f,gKc,eQc,gKc,feS,gKc,aKK,gKc,az1,gKc,aTR,gKc,fdb,gKc,a_w,gKc,e24,gKc,eju,gKc,gFO,gKc,bnX,gKc,ehC,gKc,dfg,gKc,f9K,gKc,foR,gKc,feq,gKc,e9h,gKc,a2R,gKc,aNl,gKc,dZd,gKc,dlS,gKc,eOs,gKc,a9N,gKc,d7n,gKc,a1k,gKc,eHu,gKc,aMj,gKc,eHm,gKc,aKl,gKc,ah2,gKc,dSJ,gKc,dGM,gKc,evc,gKc,a4P,gKc,azX,gKc,d04,gKc,fyw,gKc,ahC,gKc,Wa,gKc,bfk,gKc,djv,gKc,bfw,gKc,gDH,gKc,dsC,gKc,cD0,gKc,e9A,gKc,dlE,gKc,eDp,gKc,ecG,gKc,aAw,gKc,a7i,gKc,emW,gKc,aBj,gKc,bq7,gKc,as1,gKc,eWx,gKc,enE,gKc,fx8,gKc,aLe,gKc,fwX,gKc,eky,gKc,dmL,gKc,fxw,gKc,fou,gKc,bkn,gKc,fs6,gKc,a8i,gKc,eF3,gKc,a1u,gKc,bqr,gKc,a1x,gKc,e2Z,gKc,bqH,gKc,ePL,gKc,e3i,gKc,dLy,gKc,e_g,gKc,dAv,gKc,dgR,gKc,gFI,gKc,bhn,gKc,eIk,gKc,boB,gKc,evi,gKc,ah1,gKc,ecZ,gKc,eWZ,gKc,k0,gKc,dV1,gKc,aHk,gKc,gH4,gKc,e6k,gKc,fww,gKc,awI,gKc,evW,gKc,d2j,gKc,e$5,gKc,e_j,gKc,d24,gKc,enT,gKc,enV,gKc,eQk,gKc,Wf,gKc,aEi,gKc,aDh,gKc,gA$,gKc,V$,gKc,dk8,gKc,aZ1,gKc,dPx,gKc,fxE,gKc,fyj,gKc,dsD,gKc,ebJ,gKc,dwA,gKc,dMh,gKc,bl$,gKc,d0Z,gKc,ftf,gKc,eOa,gKc,dhv,gKc,dfm,gKc,gAY,gKc,enD,gKc,bga,gKc,ekM,gKc,bbR,gKc,eik,gKc,fvN,gKc,fxb,gKc,aOf,gKc,VY,gKc,fur,gKc,azU,gKc,fwD,gKc,i1,gKc,evX,gKc,enk,gKc,dSh,gKc,bey,gKc,eCg,gKc,bqG,gKc,cAl,gKc,aXW,gKc,ebe,gKc,av6,gKc,ffo,gKc,bqf,gKc,dCa,gKc,aYb,gKc,fks,gKc,fxK,gKc,fkM,gKc,e0x,gKc,aw1,gKc,ffw,gKc,fxu,gKc,aYf,gKc,ez6,gKc,d2U,gKc,feE,gKc,ahw,gKc,dEN,gKc,esY,gKc,Vm,gKc,eW1,gKc,fcj,gKc,eVi,gKc,Wc,gKc,dQ4,gKc,d2R,gKc,fd1,gKc,W$,gKc,fck,gKc,d8c,gKc,aA6,gKc,gH5,gKc,d$n,gKc,cAw,gKc,ht,gKc,e6J,gKc,ahB,gKc,bbs,gKc,kQ,gKc,bqW,gKc,bp3,gKc,j9,gKc,aHM,gKc,fls,gKc,aIT,gKc,enn,gKc,fvV,gKc,bqK,gKc,dV3,gKc,f9h,gKc,bq$,gKc,dvM,gKc,ekY,gKc,frZ,gKc,dgF,gKc,bpH,gKc,e_u,gKc,cBa,gKc,dPk,gKc,f9i,gKc,bp$,gKc,a6N,gKc,dsq,gKc,dAo,gKc,av7,gKc,dzb,gKc,gAf,gKc,bhl,gKc,eAa,gKc,gDB,gKc,gE2,gKc,eHg,gKc,Vs,gKc,Ta,gKc,Wy,gKc,bpw,gKc,gdI,gKc,cN7,gKc,f9g,gKc,fnm,gKc,eF$,gKc,f9r,gKc,dwt,gKc,aMl,gKc,gGy,gKc,dvs,gKc,e$G,gKc,gDq,gKc,efZ,gKc,fyh,gKc,ez8,gKc,bqe,gKc,aJl,gKc,fq_,gKc,aJy,gKc,f9b,gKc,aIB,gKc,evB,gKc,dCI,gKc,a7t,gKc,aHB,gKc,a8b,gKc,ePJ,gKc,fe0,gKc,bal,gKc,fe2,gKc,aIN,gKc,efy,gKc,etp,gKc,a02,gKc,bp7,gKc,d23,gKc,fsh,gKc,ey6,gKc,eiz,gKc,d2r,gKc,bp0,gKc,dfL,gKc,ekH,gKc,V5,gKc,axm,gKc,cAx,gKc,d9M,gKc,eno,gKc,gH6,gKc,dZh,gKc,eyj,gKc,eYc,gKc,fxO,gKc,dVf,gKc,a6R,gKc,aBh,gKc,fnJ,gKc,bqy,gKc,aA2,gKc,bqb,gKc,e0b,gKc,fdv,gKc,bj2,gKc,f89,gKc,frx,gKc,a7l,gKc,bbi,gKc,gEX,gKc,eHA,gKc,ed5,gKc,eDl,gKc,bqv,gKc,fj8,gKc,gFJ,gKc,d2o,gKc,d1n,gKc,axX,gKc,ezZ,gKc,dmT,gKc,eVx,gKc,e2J,gKc,f9o,gKc,eHn,gKc,aNi,gKc,dMC,gKc,fy_,gKc,bg0,gKc,eQd,gKc,aFc,gKc,ekL,gKc,eBF,gKc,e9i,gKc,dE0,gKc,e5a,gKc,dz3,gKc,a0A,gKc,dVb,gKc,eOq,gKc,aX5,gKc,e3s,gKc,aIQ,gKc,bqz,gKc,fd$,gKc,gz9,gKc,hS,gKc,V3,gKc,a8r,gKc,e$I,gKc,fNF,gKc,dhR,gKc,dj9,gKc,feW,gKc,aIu,gKc,cAe,gKc,bf8,gKc,bpK,gKc,enK,gKc,eDr,gKc,aEp,gKc,dzT,gKc,aGH,gKc,gd_,gKc,eto,gKc,fqI,gKc,axl,gKc,fxi,gKc,azN,gKc,dk6,gKc,a08,gKc,dAs,gKc,ett,gKc,a7f,gKc,e_n,gKc,fmU,gKc,asX,gKc,d8k,gKc,a0C,gKc,dQ2,gKc,dsH,gKc,ftb,gKc,TB,gKc,a_e,gKc,d8T,gKc,ffA,gKc,bbx,gKc,eCh,gKc,eKj,gKc,ehx,gKc,exr,gKc,fov,gKc,iY,gKc,fsl,gKc,enX,gKc,eaq,gKc,exe,gKc,ef2,gKc,emp,gKc,f9p,gKc,eni,gKc,edL,gKc,d2O,gKc,enP,gKc,eiV,gKc,emV,gKc,aBd,gKc,e$S,gKc,e6P,gKc,gzX,gKc,d2D,gKc,aHW,gKc,bp_,gKc,ez5,gKc,dAl,gKc,gAL,gKc,aUo,gKc,eyf,gKc,a1n,gKc,eb8,gKc,dRE,gKc,dFf,gKc,bbK,gKc,bo_,gKc,fqm,gKc,dmw,gKc,d2_,gKc,e2$,gKc,ew2,gKc,T8,gKc,aCB,gKc,bkj,gKc,dEk,gKc,fjy,gKc,dPn,gKc,azz,gKc,dru,gKc,gH7,gKc,eDq,gKc,axZ,gKc,bbg,gKc,a7n,gKc,aIA,gKc,dqa,gKc,dhU,gKc,eyw,gKc,exj,gKc,dqi,gKc,aEL,gKc,esB,gKc,efY,gKc,enR,gKc,ahN,gKc,eYX,gKc,d2S,gKc,dpd,gKc,eNR,gKc,bgA,gKc,eHp,gKc,etM,gKc,euK,gKc,bi7,gKc,ee5,gKc,e9d,gKc,fxM,gKc,bpY,gKc,ehy,gKc,eBL,gKc,fta,gKc,fxs,gKc,dMA,gKc,aJ1,gKc,gdZ,gKc,ahh,gKc,eex,gKc,e0v,gKc,dgr,gKc,Up,gKc,geQ,gKc,a0Q,gKc,fre,gKc,aXs,gKc,bbc,gKc,dga,gKc,eVQ,gKc,eQg,gKc,ahY,gKc,dS5,gKc,eHD,gKc,gH8,gKc,kj,gKc,dsi,gKc,eIw,gKc,dCq,gKc,bhF,gKc,ew8,gKc,eHw,gKc,ecd,gKc,faL,gKc,eW3,gKc,e6q,gKc,d8m,gKc,gE3,gKc,a_u,gKc,f0_,gKc,bbB,gKc,VA,gKc,cAA,gKc,cAd,gKc,eHi,gKc,fjM,gKc,baj,gKc,awK,gKc,fyW,gKc,etr,gKc,eza,gKc,dO5,gKc,eFH,gKc,cNu,gKc,eQv,gKc,iJ,gKc,aOd,gKc,d2X,gKc,ftA,gKc,dvK,gKc,dFj,gKc,aDB,gKc,dEL,gKc,d$q,gKc,aw5,gKc,azD,gKc,e3o,gKc,fxg,gKc,aA_,gKc,dsI,gKc,aJz,gKc,gDa,gKc,aMe,gKc,bbF,gKc,dFn,gKc,gDv,gKc,a1z,gKc,aNo,gKc,fes,gKc,eKh,gKc,gdR,gKc,f4Y,gKc,d1Q,gKc,bpP,gKc,f9s,gKc,jE,gKc,fs8,gKc,beA,gKc,dDL,gKc,brw,gKc,fuv,gKc,e6G,gKc,eOc,gKc,dEr,gKc,euE,gKc,fwr,gKc,gGw,gKc,gdU,gKc,bpr,gKc,ekb,gKc,geI,gKc,aKS,gKc,e5M,gKc,eOb,gKc,avh,gKc,gFd,gKc,dmP,gKc,fxm,gKc,bgQ,gKc,aQE,gKc,ejU,gKc,aJG,gKc,ebx,gKc,ahR,gKc,di$,gKc,dTP,gKc,foT,gKc,a7j,gKc,aUs,gKc,R9,gKc,enj,gKc,eKi,gKc,dFh,gKc,cCO,gKc,d1l,gKc,fqr,gKc,gFN,gKc,f9t,gKc,edH,gKc,fj7,gKc,fef,gKc,geH,gKc,eiR,gKc,bmB,gKc,be_,gKc,WN,gKc,exf,gKc,dL1,gKc,aVO,gKc,aHE,gKc,a2P,gKc,efW,gKc,egW,gKc,aQT,gKc,ePA,gKc,dxT,gKc,a1f,gKc,ahX,gKc,bkh,gKc,bpB,gKc,dn6,gKc,ahO,gKc,d8g,gKc,dGn,gKc,d$l,gKc,a8t,gKc,ebz,gKc,d65,gKc,exl,gKc,eui,gKc,d2i,gKc,dMg,gKc,evT,gKc,dSz,gKc,dro,gKc,dxp,gKc,dYr,gKc,d2p,gKc,dfE,gKc,fwS,gKc,fqs,gKc,drq,gKc,dn5,gKc,dEs,gKc,drS,gKc,aXO,gKc,aGZ,gKc,frs,gKc,bqc,gKc,azy,gKc,d7r,gKc,aC_,gKc,dCF,gKc,eZT,gKc,dqZ,gKc,ezf,gKc,beg,gKc,bjz,gKc,frN,gKc,dB6,gKc,d88,gKc,efC,gKc,dge,gKc,dsn,gKc,aLl,gKc,fkJ,gKc,bqT,gKc,e8Q,gKc,aOh,gKc,ffc,gKc,dz1,gKc,aFt,gKc,dNw,gKc,dph,gKc,bhE,gKc,aHm,gKc,fsk,gKc,egU,gKc,df7,gKc,bqq,gKc,ahV,gKc,ffy,gKc,UM,gKc,a00,gKc,feG,gKc,bi9,gKc,dDm,gKc,ena,gKc,e$0,gKc,few,gKc,dqd,gKc,bpE,gKc,gFv,gKc,e0h,gKc,gzD,gKc,aSr,gKc,e9k,gKc,dAu,gKc,feA,gKc,feU,gKc,eVg,gKc,ej9,gKc,aLf,gKc,awE,gKc,gdJ,gKc,aX3,gKc,eHo,gKc,dob,gKc,fvQ,gKc,e5S,gKc,eOj,gKc,cAa,gKc,dB8,gKc,jD,gKc,diZ,gKc,ed1,gKc,aAa,gKc,fuy,gKc,ahE,gKc,dU6,gKc,esX,gKc,esl,gKc,fd7,gKc,aAx,gKc,cz8,gKc,iX,gKc,fdt,gKc,aKj,gKc,eP2,gKc,eiW,gKc,dfs,gKc,gdW,gKc,dnx,gKc,d$y,gKc,i$,gKc,gdF,gKc,et9,gKc,aGw,gKc,a70,gKc,eWv,gKc,ekX,gKc,e1$,gKc,f5e,gKc,aIv,gKc,dUU,gKc,ahg,gKc,bmm,gKc,eOl,gKc,eW5,gKc,dS9,gKc,eyy,gKc,eOe,gKc,diA,gKc,djV,gKc,enL,gKc,ezb,gKc,du2,gKc,ez3,gKc,bqx,gKc,evO,gKc,euy,gKc,dsE,gKc,eQp,gKc,eCH,gKc,aSv,gKc,aVD,gKc,eBG,gKc,evC,gKc,fv2,gKc,eaP,gKc,blZ,gKc,bbM,gKc,emZ,gKc,fwA,gKc,gAN,gKc,eYU,gKc,eY$,gKc,aBf,gKc,e0f,gKc,gzv,gKc,e$K,gKc,bqL,gKc,aUC,gKc,a0z,gKc,f88,gKc,ee7,gKc,ffs,gKc,dY4,gKc,ePs,gKc,ffK,gKc,em9,gKc,fnO,gKc,d8e,gKc,fob,gKc,aMi,gKc,aDt,gKc,eB2,gKc,eii,gKc,dRO,gKc,fxA,gKc,atD,gKc,cN4,gKc,ecc,gKc,f9f,gKc,fwk,gKc,etQ,gKc,e26,gKc,gdH,gKc,aX7,gKc,dYs,gKc,aGk,gKc,bq3,gKc,de4,gKc,jH,gKc,e6A,gKc,azW,gKc,gFt,gKc,bbA,gKc,f9u,gKc,ffM,gKc,aJ0,gKc,fdd,gKc,axV,gKc,dnf,gKc,bex,gKc,gfa,gKc,euI,gKc,aw4,gKc,eiC,gKc,ey7,gKc,bbo,gKc,fey,gKc,eku,gKc,cAi,gKc,bkl,gKc,eCy,gKc,dyz,gKc,dkI,gKc,em1,gKc,dPm,gKc,aGv,gKc,gzI,gKc,gDM,gKc,fxG,gKc,a1a,gKc,bfj,gKc,dSo,gKc,kT,gKc,dfu,gKc,e0l,gKc,e$9,gKc,ebP,gKc,dRG,gKc,eDe,gKc,a0L,gKc,eQt,gKc,eHx,gKc,a0y,gKc,dgT,gKc,a1s,gKc,dy9,gKc,er9,gKc,d9m,gKc,feo,gKc,gdK,gKc,fe8,gKc,eX9,gKc,ey2,gKc,bqu,gKc,gFa,gKc,gdV,gKc,ey3,gKc,WK,gKc,eVR,gKc,atS,gKc,azV,gKc,a_g,gKc,dU9,gKc,dpc,gKc,aEH,gKc,d$c,gKc,fd9,gKc,gA0,gKc,gdO,gKc,dpg,gKc,dt1,gKc,aCZ,gKc,emh,gKc,bjB,gKc,fly,gKc,f9a,gKc,eXE,gKc,bkH,gKc,e_x,gKc,ekv,gKc,eDn,gKc,a8f,gKc,gdQ,gKc,fwq,gKc,dx7,gKc,eZX,gKc,awl,gKc,V8,gKc,em2,gKc,a_i,gKc,feh,gKc,hv,gKc,eCz,gKc,atg,gKc,bi6,gKc,frd,gKc,cz9,gKc,aMa,gKc,aIR,gKc,e3a,gKc,bp6,gKc,d2I,gKc,euA,gKc,im,gKc,ePv,gKc,gDG,gKc,gBo,gKc,atR,gKc,aUq,gKc,djt,gKc,V2,gKc,bpV,gKc,gdY,gKc,ekU,gKc,eFN,gKc,ew1,gKc,dqW,gKc,dxq,gKc,ey_,gKc,e$v,gKc,ex1,gKc,fu_,gKc,fnk,gKc,exa,gKc,f9l,gKc,ezX,gKc,dT_,gKc,f9q,gKc,eF4,gKc,gAi,gKc,bq6,gKc,ekQ,gKc,a7r,gKc,fyI,gKc,aur,gKc,gdX,gKc,VZ,gKc,esk,gKc,eP6,gKc,gzY,gKc,dT3,gKc,d9Y,gKc,fwK,gKc,diF,gKc,eY1,gKc,eOg,gKc,fe4,gKc,eaH,gKc,aFs,gKc,gAO,gKc,gFj,gKc,ePV,gKc,fwM,gKc,fqY,gKc,aDi,gKc,e_r,gKc,cAr,gKc,bah,gKc,dTe,gKc,dmr,gKc,d$f,gKc,bnW,gKc,bhJ,gKc,eIF,gKc,d2a,gKc,a77,gKc,eye,gKc,eWX,gKc,awG,gKc,bgW,gKc,flT,gKc,aJY,gKc,d2T,gKc,eiY,gKc,dhC,gKc,dSf,gKc,be0,gKc,a8m,gKc,eB_,gKc,aha,gKc,fxo,gKc,bbk,gKc,bpU,gKc,aAU,gKc,aF3,gKc,VT,gKc,d_H,gKc,aZ3,gKc,d8i,gKc,ahf,gKc,dT4,gKc,aYd,gKc,dsz,gKc,e81,gKc,d1k,gKc,gFG,gKc,d$u,gKc,dgL,gKc,dB2,gKc,ezM,gKc,ey$,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc,gKc];var gk=[gKd,gKd,Tn,gKd,kV,gKd,To,gKd,Tp,gKd,Tm,gKd,gKd,gKd,gKd,gKd];var gl=[gKe,gKe,gJu,gKe];var gm=[gKf,gKf,jy,gKf];var gn=[gKg,gKg,Sc,gKg];var go=[gKh,gKh,kB,gKh];var gp=[gKi,gKi,a3S,gKi,bEo,gKi,bxG,gKi,d57,gKi,c3b,gKi,cCq,gKi,bDk,gKi,b1e,gKi,dYY,gKi,eF8,gKi,b10,gKi,ca6,gKi,cPb,gKi,bym,gKi,eUB,gKi,dKW,gKi,bDQ,gKi,cI1,gKi,chS,gKi,ccI,gKi,cjg,gKi,ciQ,gKi,amZ,gKi,bBu,gKi,b$S,gKi,c0Y,gKi,c6g,gKi,e$d,gKi,egJ,gKi,e05,gKi,dN$,gKi,b00,gKi,aSn,gKi,c1A,gKi,bMe,gKi,bHI,gKi,dvg,gKi,aK5,gKi,a5s,gKi,d$L,gKi,b8s,gKi,ccM,gKi,biM,gKi,cPB,gKi,esM,gKi,cqk,gKi,c5V,gKi,fcM,gKi,dqw,gKi,c6L,gKi,cGH,gKi,a7I,gKi,eLC,gKi,acN,gKi,cvu,gKi,btk,gKi,d4Y,gKi,aoU,gKi,aEO,gKi,acP,gKi,aRZ,gKi,bBK,gKi,aAO,gKi,ca0,gKi,bCu,gKi,amv,gKi,a3q,gKi,ewp,gKi,b9e,gKi,c34,gKi,dUF,gKi,a84,gKi,cWx,gKi,b5E,gKi,cr8,gKi,XH,gKi,c3Z,gKi,cqs,gKi,bwa,gKi,cb8,gKi,gEf,gKi,cYv,gKi,bil,gKi,aRM,gKi,dT6,gKi,dFz,gKi,b8w,gKi,cQx,gKi,bLM,gKi,eaD,gKi,co4,gKi,clC,gKi,dS2,gKi,c17,gKi,Yh,gKi,b3I,gKi,c5W,gKi,fgT,gKi,elT,gKi,cfA,gKi,eGp,gKi,cfi,gKi,d5e,gKi,dmJ,gKi,bxK,gKi,crW,gKi,b0s,gKi,cje,gKi,bLg,gKi,fbk,gKi,bh_,gKi,eGI,gKi,cJ9,gKi,ctc,gKi,aca,gKi,cjU,gKi,ceC,gKi,bNS,gKi,bGs,gKi,bH0,gKi,clk,gKi,eiv,gKi,eYf,gKi,dIX,gKi,dxz,gKi,bPK,gKi,cFd,gKi,bF4,gKi,eU8,gKi,bYg,gKi,fjq,gKi,bVE,gKi,cdK,gKi,dpJ,gKi,bw4,gKi,Xu,gKi,b9c,gKi,c4m,gKi,cbG,gKi,cTZ,gKi,c0f,gKi,c$i,gKi,bya,gKi,frI,gKi,e4D,gKi,ecD,gKi,cFD,gKi,bX_,gKi,bL_,gKi,bL4,gKi,a56,gKi,acm,gKi,cZN,gKi,bDC,gKi,aDk,gKi,bMi,gKi,b6W,gKi,alL,gKi,cGN,gKi,eG4,gKi,cXB,gKi,eLz,gKi,cV1,gKi,a8K,gKi,an0,gKi,XF,gKi,c32,gKi,cFw,gKi,fg6,gKi,Yk,gKi,cX3,gKi,c19,gKi,bEW,gKi,diq,gKi,c29,gKi,cI$,gKi,cWv,gKi,dlV,gKi,cbA,gKi,c45,gKi,aU7,gKi,Yt,gKi,ai1,gKi,dJG,gKi,b6m,gKi,cRv,gKi,cda,gKi,eer,gKi,_W,gKi,bRW,gKi,bPi,gKi,cOj,gKi,dYx,gKi,c5Q,gKi,eTC,gKi,fgN,gKi,bI0,gKi,dmn,gKi,aVw,gKi,bUg,gKi,cuS,gKi,cF7,gKi,aHi,gKi,dIk,gKi,bA8,gKi,d7M,gKi,c3l,gKi,bxk,gKi,emJ,gKi,a28,gKi,bQ0,gKi,bR4,gKi,cou,gKi,ZX,gKi,cV3,gKi,dVZ,gKi,ckG,gKi,bXA,gKi,cqS,gKi,__,gKi,bM8,gKi,bsu,gKi,b6w,gKi,aXL,gKi,cZX,gKi,bQS,gKi,c$_,gKi,fkF,gKi,bjT,gKi,cnC,gKi,ait,gKi,dF0,gKi,b_Y,gKi,bSy,gKi,cnK,gKi,cuc,gKi,bsi,gKi,cFN,gKi,c2k,gKi,dyT,gKi,cWt,gKi,eJj,gKi,cf0,gKi,abw,gKi,ab8,gKi,bKu,gKi,frR,gKi,cJM,gKi,bHi,gKi,aXC,gKi,bVM,gKi,cdw,gKi,e0Q,gKi,clc,gKi,aQz,gKi,eSv,gKi,aWa,gKi,cHu,gKi,bU4,gKi,eg7,gKi,bWy,gKi,aip,gKi,b2a,gKi,dv0,gKi,e3v,gKi,bYK,gKi,b8a,gKi,cfk,gKi,iW,gKi,aeh,gKi,frK,gKi,av1,gKi,cqW,gKi,c4G,gKi,bXg,gKi,dDH,gKi,eY9,gKi,ac1,gKi,dnu,gKi,cjI,gKi,b$4,gKi,eLl,gKi,dp0,gKi,aPY,gKi,adV,gKi,cnm,gKi,bQK,gKi,br4,gKi,cUn,gKi,bnm,gKi,cOn,gKi,chw,gKi,ecB,gKi,aMS,gKi,e1I,gKi,cR$,gKi,cPt,gKi,ceQ,gKi,cLf,gKi,ch4,gKi,dmV,gKi,c5E,gKi,ape,gKi,cC$,gKi,d6d,gKi,fgP,gKi,bsM,gKi,eEZ,gKi,bFY,gKi,ff7,gKi,eb3,gKi,c3O,gKi,e3D,gKi,brK,gKi,eTl,gKi,beE,gKi,cPh,gKi,bWc,gKi,cLD,gKi,bXo,gKi,coa,gKi,cte,gKi,chY,gKi,a5Z,gKi,cOP,gKi,eJn,gKi,eLw,gKi,cv2,gKi,dKa,gKi,bRS,gKi,bSo,gKi,cKd,gKi,cGn,gKi,dpB,gKi,bXa,gKi,b9O,gKi,c6t,gKi,cLN,gKi,eHQ,gKi,dM7,gKi,bzc,gKi,cdq,gKi,cSF,gKi,ckM,gKi,bVK,gKi,ai9,gKi,bBc,gKi,e8l,gKi,cdg,gKi,eH_,gKi,foY,gKi,dh4,gKi,b82,gKi,csw,gKi,bBO,gKi,bSq,gKi,c2U,gKi,dN8,gKi,c50,gKi,bJi,gKi,dGG,gKi,c1_,gKi,a7M,gKi,cic,gKi,c5C,gKi,beO,gKi,b$0,gKi,cEu,gKi,c08,gKi,dBR,gKi,c3p,gKi,dC3,gKi,efE,gKi,cLz,gKi,eI8,gKi,aRA,gKi,cD9,gKi,ctM,gKi,d4a,gKi,dSX,gKi,eFB,gKi,alh,gKi,as4,gKi,dv7,gKi,ezs,gKi,bU0,gKi,dP4,gKi,bvC,gKi,b48,gKi,cpu,gKi,aOo,gKi,dJU,gKi,c3Q,gKi,cH0,gKi,cdu,gKi,cls,gKi,c23,gKi,eXa,gKi,aVV,gKi,cxe,gKi,boM,gKi,aY1,gKi,dvX,gKi,amd,gKi,c4Z,gKi,eHV,gKi,cgW,gKi,aW_,gKi,ac3,gKi,aOk,gKi,bO6,gKi,ab2,gKi,bAK,gKi,cYB,gKi,amQ,gKi,cTr,gKi,bc8,gKi,bK4,gKi,b1i,gKi,aLU,gKi,cos,gKi,b0W,gKi,cu2,gKi,cbm,gKi,cpi,gKi,cjw,gKi,eLI,gKi,asm,gKi,c4l,gKi,cc4,gKi,aiN,gKi,aq9,gKi,eGh,gKi,bSu,gKi,dPV,gKi,cFQ,gKi,bsA,gKi,bJy,gKi,chC,gKi,flK,gKi,cEw,gKi,c0h,gKi,bO0,gKi,cui,gKi,a3x,gKi,gzS,gKi,bAw,gKi,epV,gKi,b8U,gKi,dDW,gKi,c2Y,gKi,ce0,gKi,b$o,gKi,bUm,gKi,eMY,gKi,amA,gKi,a9A,gKi,buy,gKi,a_X,gKi,dMP,gKi,bOa,gKi,cBo,gKi,b6y,gKi,cXz,gKi,ftr,gKi,cPZ,gKi,azu,gKi,aso,gKi,bFO,gKi,b70,gKi,aze,gKi,bdR,gKi,eGu,gKi,b3a,gKi,cU1,gKi,bEs,gKi,cm8,gKi,coc,gKi,cP$,gKi,ct_,gKi,b9s,gKi,cuo,gKi,bvY,gKi,c53,gKi,cxY,gKi,dzJ,gKi,e8g,gKi,exF,gKi,euV,gKi,b_q,gKi,cxW,gKi,cHK,gKi,c05,gKi,ceo,gKi,b76,gKi,eWz,gKi,cSD,gKi,an3,gKi,cqu,gKi,akg,gKi,fbn,gKi,aOB,gKi,d7R,gKi,dKh,gKi,bc0,gKi,fcH,gKi,cZx,gKi,bv_,gKi,adR,gKi,dCD,gKi,dzB,gKi,cw6,gKi,cLU,gKi,avy,gKi,cvA,gKi,eUq,gKi,b9A,gKi,aO0,gKi,c5i,gKi,dIy,gKi,adZ,gKi,cO3,gKi,cO5,gKi,eT_,gKi,dVx,gKi,cbS,gKi,cW5,gKi,duC,gKi,aD3,gKi,c0u,gKi,c0L,gKi,bzk,gKi,cCc,gKi,bVQ,gKi,cRL,gKi,b5O,gKi,bYw,gKi,cYx,gKi,cJ3,gKi,b66,gKi,cMh,gKi,Y8,gKi,bBY,gKi,ayI,gKi,bB2,gKi,cS9,gKi,d5K,gKi,egE,gKi,ceE,gKi,cHS,gKi,b7E,gKi,bRO,gKi,aHo,gKi,ft9,gKi,ecO,gKi,cmK,gKi,aq5,gKi,bDK,gKi,b62,gKi,d_d,gKi,c3B,gKi,bNC,gKi,bdV,gKi,byi,gKi,bPC,gKi,bHs,gKi,eTf,gKi,cVX,gKi,eMw,gKi,bwG,gKi,caE,gKi,bVC,gKi,eGf,gKi,bIe,gKi,fhm,gKi,btS,gKi,caC,gKi,Zd,gKi,dGd,gKi,c_p,gKi,ab4,gKi,c3V,gKi,btq,gKi,cOB,gKi,bWQ,gKi,aSh,gKi,bm8,gKi,csY,gKi,bI_,gKi,b52,gKi,bua,gKi,bCs,gKi,diQ,gKi,cgs,gKi,bGQ,gKi,cLY,gKi,bTw,gKi,bzA,gKi,c3I,gKi,b2G,gKi,bGS,gKi,c5c,gKi,bxg,gKi,ck8,gKi,aT5,gKi,e1u,gKi,cK0,gKi,cQj,gKi,bDU,gKi,bEm,gKi,X9,gKi,e90,gKi,cxS,gKi,dBl,gKi,dI8,gKi,aom,gKi,ch6,gKi,aId,gKi,adI,gKi,e_3,gKi,ds9,gKi,eEE,gKi,dj4,gKi,diU,gKi,e9T,gKi,aFX,gKi,apD,gKi,bCo,gKi,ccw,gKi,caI,gKi,cg6,gKi,aq1,gKi,dFR,gKi,dDz,gKi,alp,gKi,btO,gKi,b3m,gKi,cwC,gKi,aIq,gKi,cGW,gKi,c3M,gKi,b2S,gKi,fbA,gKi,c_$,gKi,cY9,gKi,bG4,gKi,akI,gKi,c3D,gKi,bsQ,gKi,eBh,gKi,aW3,gKi,dIK,gKi,eQZ,gKi,cFU,gKi,aDN,gKi,bMU,gKi,b7_,gKi,d8E,gKi,c$8,gKi,cRX,gKi,c$0,gKi,ciy,gKi,cxw,gKi,b3k,gKi,b0C,gKi,bGc,gKi,d0N,gKi,dGE,gKi,cDN,gKi,dDF,gKi,cPR,gKi,cT3,gKi,aMM,gKi,cb2,gKi,cYr,gKi,ctq,gKi,a6n,gKi,bBi,gKi,bT6,gKi,cFA,gKi,cww,gKi,b6Q,gKi,buM,gKi,bXM,gKi,arr,gKi,c2u,gKi,e4p,gKi,bCw,gKi,c_B,gKi,c6r,gKi,bAC,gKi,egf,gKi,bW2,gKi,en$,gKi,acH,gKi,abC,gKi,bGM,gKi,c4z,gKi,eUR,gKi,etv,gKi,chK,gKi,ceA,gKi,b1S,gKi,WH,gKi,c$P,gKi,adC,gKi,cvc,gKi,cnA,gKi,ca4,gKi,c5d,gKi,ab6,gKi,cao,gKi,b4_,gKi,avM,gKi,abL,gKi,cDF,gKi,aLM,gKi,b7w,gKi,d1b,gKi,c3d,gKi,dKR,gKi,b1g,gKi,foh,gKi,cqa,gKi,cm4,gKi,fiP,gKi,eE3,gKi,aqq,gKi,cas,gKi,bor,gKi,cn8,gKi,c1j,gKi,a7T,gKi,d$P,gKi,cWX,gKi,ceG,gKi,cWT,gKi,brE,gKi,c2W,gKi,avZ,gKi,eA$,gKi,byW,gKi,cJW,gKi,b56,gKi,elv,gKi,dg4,gKi,_b,gKi,bLe,gKi,fbR,gKi,e_T,gKi,eG2,gKi,bQY,gKi,aNs,gKi,eSG,gKi,bdg,gKi,ctm,gKi,dkX,gKi,cPp,gKi,b_w,gKi,bLO,gKi,cru,gKi,bC8,gKi,cUJ,gKi,aK3,gKi,ci8,gKi,cwm,gKi,eIW,gKi,arD,gKi,bNY,gKi,cgC,gKi,b6I,gKi,aep,gKi,cLt,gKi,cLm,gKi,anp,gKi,b3Q,gKi,bDE,gKi,fcz,gKi,cQL,gKi,aBY,gKi,bzy,gKi,bFm,gKi,b2u,gKi,aGm,gKi,cPH,gKi,bio,gKi,ezh,gKi,ciI,gKi,bBS,gKi,bEy,gKi,cvW,gKi,bTQ,gKi,bM0,gKi,cWd,gKi,eu3,gKi,btQ,gKi,eal,gKi,eI2,gKi,bS0,gKi,cIb,gKi,a8G,gKi,e_N,gKi,fhE,gKi,eAW,gKi,c4F,gKi,dFF,gKi,bW0,gKi,d71,gKi,cEy,gKi,cGK,gKi,b9w,gKi,bOS,gKi,apa,gKi,ch0,gKi,amS,gKi,bGm,gKi,cZV,gKi,d5C,gKi,dDo,gKi,bo0,gKi,bSw,gKi,Yd,gKi,a32,gKi,aNN,gKi,cyo,gKi,egl,gKi,b5m,gKi,bZk,gKi,aj9,gKi,e41,gKi,bR6,gKi,cdi,gKi,eMH,gKi,cCx,gKi,c4R,gKi,c5n,gKi,eGm,gKi,bGC,gKi,bKK,gKi,dHi,gKi,bPa,gKi,cx8,gKi,e1p,gKi,fjl,gKi,cDs,gKi,c$W,gKi,eG0,gKi,bQ2,gKi,asb,gKi,bCe,gKi,eWb,gKi,$r,gKi,aul,gKi,bZ6,gKi,eMh,gKi,byA,gKi,bPW,gKi,eBS,gKi,a6f,gKi,aN8,gKi,bw8,gKi,cca,gKi,c2X,gKi,cmA,gKi,e0Y,gKi,bx4,gKi,bdu,gKi,fgI,gKi,bRi,gKi,fdp,gKi,cbC,gKi,bwE,gKi,d0i,gKi,eNp,gKi,bVI,gKi,c44,gKi,bXU,gKi,c3_,gKi,fcW,gKi,cU3,gKi,bsk,gKi,bxo,gKi,bEE,gKi,cVp,gKi,b1_,gKi,cTx,gKi,aWv,gKi,cPv,gKi,b4I,gKi,b9a,gKi,fpa,gKi,b40,gKi,boO,gKi,eC9,gKi,dZ8,gKi,cJh,gKi,bgC,gKi,bv0,gKi,bww,gKi,cb4,gKi,avq,gKi,d0S,gKi,b7o,gKi,ciC,gKi,ado,gKi,cmU,gKi,cua,gKi,d3C,gKi,a5m,gKi,eao,gKi,cTF,gKi,cve,gKi,eRs,gKi,b1a,gKi,bPE,gKi,bUY,gKi,cJO,gKi,bAi,gKi,ako,gKi,caS,gKi,bdA,gKi,bZG,gKi,cks,gKi,avE,gKi,b1M,gKi,bob,gKi,cbu,gKi,c0H,gKi,cvo,gKi,bwK,gKi,d$B,gKi,c_v,gKi,cCg,gKi,cDi,gKi,ef6,gKi,$p,gKi,b9S,gKi,dEF,gKi,cS5,gKi,aWe,gKi,d5n,gKi,cs2,gKi,cRj,gKi,aQd,gKi,e99,gKi,c30,gKi,ccC,gKi,bO_,gKi,ci0,gKi,bCQ,gKi,aCn,gKi,c22,gKi,cRT,gKi,aoi,gKi,cvg,gKi,c27,gKi,cEj,gKi,dgt,gKi,bMM,gKi,aYT,gKi,ftu,gKi,fgC,gKi,bFS,gKi,aKg,gKi,bb9,gKi,dE_,gKi,bXm,gKi,e9I,gKi,b16,gKi,chs,gKi,esE,gKi,ays,gKi,$O,gKi,bse,gKi,equ,gKi,bTc,gKi,dx4,gKi,c11,gKi,e8o,gKi,aaG,gKi,bAo,gKi,cZz,gKi,aKo,gKi,bH6,gKi,eAJ,gKi,dQQ,gKi,cma,gKi,alj,gKi,bYO,gKi,aUZ,gKi,c1a,gKi,cla,gKi,cHg,gKi,eSo,gKi,ere,gKi,aI$,gKi,kb,gKi,eZh,gKi,eU3,gKi,aZk,gKi,cT9,gKi,bDa,gKi,dtc,gKi,bB6,gKi,bOQ,gKi,bJu,gKi,eJt,gKi,dwe,gKi,bxI,gKi,Yr,gKi,cHm,gKi,bLw,gKi,b0a,gKi,aR7,gKi,ewa,gKi,far,gKi,aH8,gKi,fhu,gKi,b9i,gKi,b9U,gKi,bNO,gKi,eZP,gKi,c6l,gKi,e1e,gKi,bEe,gKi,cBR,gKi,cLW,gKi,b$w,gKi,cXV,gKi,hP,gKi,c1V,gKi,cIV,gKi,bKq,gKi,dma,gKi,fdJ,gKi,cxc,gKi,dxH,gKi,cmm,gKi,bb3,gKi,cIj,gKi,bct,gKi,aDR,gKi,bEK,gKi,aYG,gKi,cpk,gKi,c5u,gKi,dA5,gKi,bOc,gKi,aN6,gKi,bFc,gKi,cta,gKi,bH4,gKi,cWP,gKi,c3L,gKi,d4e,gKi,dF_,gKi,b2A,gKi,a8I,gKi,b$C,gKi,bE6,gKi,cZv,gKi,fax,gKi,cEM,gKi,akQ,gKi,bvO,gKi,b0o,gKi,ang,gKi,eML,gKi,bNc,gKi,cHd,gKi,ael,gKi,cfq,gKi,bTe,gKi,btg,gKi,d1g,gKi,e6W,gKi,bI6,gKi,aBB,gKi,bKM,gKi,fi2,gKi,ex5,gKi,b9g,gKi,cw2,gKi,ar_,gKi,ac$,gKi,c0b,gKi,bYA,gKi,epZ,gKi,cCB,gKi,bDc,gKi,cBF,gKi,cVF,gKi,bPY,gKi,ct0,gKi,cVZ,gKi,c$N,gKi,cQf,gKi,bAU,gKi,bwe,gKi,cuk,gKi,cgS,gKi,c4v,gKi,bUQ,gKi,b_c,gKi,coQ,gKi,b1y,gKi,ci6,gKi,fin,gKi,eRH,gKi,cq0,gKi,cfU,gKi,cRx,gKi,bNg,gKi,cSt,gKi,cDD,gKi,_s,gKi,cym,gKi,aaC,gKi,cRr,gKi,aVr,gKi,bIy,gKi,bze,gKi,b3q,gKi,cXN,gKi,cFn,gKi,brW,gKi,bQu,gKi,_Y,gKi,c5g,gKi,eTP,gKi,dzw,gKi,hQ,gKi,d73,gKi,c$B,gKi,cVt,gKi,eYH,gKi,dH9,gKi,bMu,gKi,aVo,gKi,c5K,gKi,aew,gKi,cQ5,gKi,bVS,gKi,e67,gKi,ckW,gKi,bds,gKi,djL,gKi,a3E,gKi,b0m,gKi,c3H,gKi,b$Q,gKi,bx6,gKi,dpV,gKi,cyc,gKi,cvM,gKi,a6h,gKi,cC4,gKi,dOz,gKi,euv,gKi,cjs,gKi,c$r,gKi,c3e,gKi,dHM,gKi,dHW,gKi,cLL,gKi,bcT,gKi,bcr,gKi,fgv,gKi,b22,gKi,blq,gKi,cV9,gKi,eK5,gKi,c1N,gKi,dM9,gKi,b9W,gKi,bnD,gKi,ads,gKi,dq8,gKi,d3A,gKi,aNw,gKi,cim,gKi,cdO,gKi,egt,gKi,eav,gKi,bwy,gKi,dk_,gKi,eq9,gKi,dPz,gKi,cpI,gKi,dEd,gKi,cbW,gKi,bn9,gKi,dZK,gKi,bUk,gKi,dAR,gKi,bQw,gKi,dUj,gKi,Xz,gKi,cZj,gKi,dv2,gKi,cX5,gKi,bHS,gKi,ady,gKi,bSg,gKi,csu,gKi,arp,gKi,eAw,gKi,eHF,gKi,bfU,gKi,a3A,gKi,bDq,gKi,dpQ,gKi,eM4,gKi,bDe,gKi,a5G,gKi,cmQ,gKi,aCf,gKi,$g,gKi,bJc,gKi,bRG,gKi,b3K,gKi,c2x,gKi,cuw,gKi,dns,gKi,bNG,gKi,bK2,gKi,c3J,gKi,aV8,gKi,ad5,gKi,e7V,gKi,b8_,gKi,bCk,gKi,c$x,gKi,b7i,gKi,bzO,gKi,cio,gKi,aiy,gKi,aky,gKi,cpy,gKi,edN,gKi,bXK,gKi,aQr,gKi,bGY,gKi,frp,gKi,fsx,gKi,cie,gKi,b6O,gKi,cIu,gKi,cjG,gKi,bOU,gKi,bZI,gKi,djN,gKi,cDZ,gKi,cea,gKi,bFw,gKi,c$c,gKi,dmB,gKi,YD,gKi,dhh,gKi,aos,gKi,cmc,gKi,eH5,gKi,b0_,gKi,drh,gKi,ajV,gKi,bOm,gKi,coY,gKi,aij,gKi,eeY,gKi,cU9,gKi,cxu,gKi,aoN,gKi,$S,gKi,fuP,gKi,cni,gKi,fja,gKi,bzQ,gKi,bti,gKi,arB,gKi,b3O,gKi,fdH,gKi,egp,gKi,bVU,gKi,br0,gKi,bKG,gKi,c1H,gKi,an6,gKi,b_6,gKi,eC4,gKi,cIT,gKi,aif,gKi,dOU,gKi,bDu,gKi,c21,gKi,cai,gKi,bFC,gKi,bwg,gKi,eln,gKi,atY,gKi,ceI,gKi,bNq,gKi,cag,gKi,eAR,gKi,cuC,gKi,aZs,gKi,cti,gKi,ass,gKi,a7E,gKi,ayp,gKi,doU,gKi,b28,gKi,bVY,gKi,dG2,gKi,adb,gKi,_S,gKi,eS6,gKi,dvl,gKi,bYi,gKi,fbI,gKi,cBN,gKi,b$6,gKi,fkc,gKi,YQ,gKi,dvv,gKi,dHB,gKi,bRc,gKi,aPq,gKi,b3_,gKi,cja,gKi,fhU,gKi,aCb,gKi,fpf,gKi,dJW,gKi,frg,gKi,dHr,gKi,aAI,gKi,aCq,gKi,c_P,gKi,eqq,gKi,bPu,gKi,akZ,gKi,bSQ,gKi,bkp,gKi,cXn,gKi,b0Q,gKi,aWO,gKi,bK_,gKi,cjY,gKi,dDN,gKi,bWa,gKi,dKH,gKi,bu2,gKi,b8A,gKi,cZF,gKi,ehR,gKi,eoG,gKi,fsJ,gKi,alV,gKi,a5y,gKi,e7Y,gKi,eZx,gKi,c_n,gKi,bvy,gKi,b1G,gKi,ecw,gKi,cJt,gKi,bIS,gKi,btE,gKi,aae,gKi,dII,gKi,egz,gKi,eRq,gKi,c3z,gKi,boh,gKi,d$T,gKi,e4I,gKi,emO,gKi,_K,gKi,XZ,gKi,c$o,gKi,b8i,gKi,cIm,gKi,b4i,gKi,aRI,gKi,eSz,gKi,ch8,gKi,cXJ,gKi,akN,gKi,bKS,gKi,cX1,gKi,cC9,gKi,cwG,gKi,cum,gKi,anw,gKi,crK,gKi,b08,gKi,abP,gKi,c24,gKi,c6m,gKi,cZH,gKi,cnG,gKi,cv8,gKi,dNF,gKi,eZE,gKi,bvE,gKi,ax2,gKi,csK,gKi,dyN,gKi,aYq,gKi,cSj,gKi,bmS,gKi,bAq,gKi,dp2,gKi,cfa,gKi,b58,gKi,dIN,gKi,akw,gKi,bVc,gKi,by0,gKi,brU,gKi,c3r,gKi,dFD,gKi,bMw,gKi,bAM,gKi,cSh,gKi,bb5,gKi,bOK,gKi,bfS,gKi,ceK,gKi,ad3,gKi,cwq,gKi,a5I,gKi,bfb,gKi,aR1,gKi,bRY,gKi,b$K,gKi,bCg,gKi,ecj,gKi,bz_,gKi,c6B,gKi,bsE,gKi,cry,gKi,cHy,gKi,bva,gKi,cLk,gKi,cdc,gKi,bVA,gKi,dRx,gKi,d4j,gKi,bBG,gKi,aLA,gKi,bX2,gKi,c_L,gKi,cmi,gKi,cBL,gKi,e4A,gKi,aw_,gKi,bY4,gKi,byG,gKi,cp2,gKi,b0O,gKi,bjR,gKi,bxS,gKi,cd0,gKi,b7A,gKi,bH2,gKi,cYP,gKi,c5L,gKi,c43,gKi,c5r,gKi,b1O,gKi,cQ7,gKi,bOw,gKi,b3s,gKi,c3X,gKi,c48,gKi,aR9,gKi,drR,gKi,eEq,gKi,eWH,gKi,avI,gKi,cTL,gKi,bxw,gKi,bMa,gKi,cl6,gKi,ciE,gKi,dGr,gKi,bEg,gKi,b3Y,gKi,coG,gKi,dJu,gKi,cjW,gKi,eQ5,gKi,eYw,gKi,b6u,gKi,fiU,gKi,crm,gKi,b2K,gKi,foN,gKi,e1c,gKi,cG1,gKi,cyu,gKi,cDJ,gKi,duK,gKi,cW3,gKi,aiY,gKi,apt,gKi,cg_,gKi,arj,gKi,cBm,gKi,eJV,gKi,c3N,gKi,alN,gKi,cQd,gKi,aRQ,gKi,eMQ,gKi,eXu,gKi,bK6,gKi,eZA,gKi,cB4,gKi,cgu,gKi,e1r,gKi,bmo,gKi,cd4,gKi,dk2,gKi,bjV,gKi,cMx,gKi,cHA,gKi,bWO,gKi,beR,gKi,dJb,gKi,aq_,gKi,eWi,gKi,dTA,gKi,aa8,gKi,c_F,gKi,cJS,gKi,bZq,gKi,cXv,gKi,dC7,gKi,eG6,gKi,dvG,gKi,dBV,gKi,cfG,gKi,btY,gKi,bLY,gKi,gH9,gKi,chI,gKi,eUN,gKi,eUj,gKi,bZE,gKi,bME,gKi,csg,gKi,bYs,gKi,cTt,gKi,cLi,gKi,bwm,gKi,beM,gKi,b_e,gKi,_o,gKi,dUr,gKi,fbf,gKi,dyF,gKi,cxg,gKi,aB9,gKi,ZU,gKi,cRb,gKi,cDo,gKi,cO$,gKi,cjO,gKi,e8A,gKi,fic,gKi,elV,gKi,fdy,gKi,dBy,gKi,fsF,gKi,cqw,gKi,cHs,gKi,ccg,gKi,bKI,gKi,ej6,gKi,c3i,gKi,cwu,gKi,cki,gKi,aG$,gKi,bel,gKi,e7b,gKi,bew,gKi,b5C,gKi,b6c,gKi,bJU,gKi,cik,gKi,dIg,gKi,ft0,gKi,dZw,gKi,_U,gKi,bIc,gKi,bHU,gKi,bTA,gKi,cfe,gKi,c1R,gKi,coe,gKi,bIO,gKi,dkL,gKi,cDB,gKi,cyg,gKi,bzW,gKi,bBs,gKi,eK2,gKi,atG,gKi,aly,gKi,dwh,gKi,cf2,gKi,bHw,gKi,cP5,gKi,dBi,gKi,bky,gKi,cLJ,gKi,c40,gKi,apl,gKi,bIo,gKi,bMq,gKi,a24,gKi,dP0,gKi,fkO,gKi,bIM,gKi,cZd,gKi,bDI,gKi,cpc,gKi,dFJ,gKi,fan,gKi,bBC,gKi,dsK,gKi,aaw,gKi,bRE,gKi,frr,gKi,b26,gKi,cQP,gKi,ciq,gKi,bcO,gKi,bFQ,gKi,ctE,gKi,cqQ,gKi,dAJ,gKi,fbM,gKi,cr2,gKi,e4g,gKi,bEw,gKi,d0d,gKi,acz,gKi,cTT,gKi,eRa,gKi,a5R,gKi,b8Q,gKi,dQT,gKi,b9Q,gKi,aKc,gKi,brY,gKi,bDA,gKi,b4m,gKi,dOK,gKi,bYy,gKi,b4g,gKi,b4M,gKi,c6K,gKi,cFt,gKi,_2,gKi,bNw,gKi,bZs,gKi,aUW,gKi,b12,gKi,b44,gKi,cg2,gKi,cJY,gKi,cbO,gKi,et2,gKi,cCL,gKi,c2$,gKi,dih,gKi,c3u,gKi,erg,gKi,aZn,gKi,b6k,gKi,coi,gKi,bJg,gKi,cis,gKi,bjp,gKi,bxA,gKi,eCM,gKi,dG4,gKi,fui,gKi,aVy,gKi,bII,gKi,bh3,gKi,bJW,gKi,dHH,gKi,d1p,gKi,cs6,gKi,fhr,gKi,asq,gKi,bOW,gKi,eem,gKi,d9S,gKi,aoF,gKi,ejW,gKi,c4h,gKi,esP,gKi,bT8,gKi,cCN,gKi,b_M,gKi,e$a,gKi,c1C,gKi,atv,gKi,ayT,gKi,by6,gKi,c0W,gKi,c52,gKi,bWm,gKi,c4O,gKi,cqG,gKi,eyW,gKi,_u,gKi,c4a,gKi,dPi,gKi,dR6,gKi,d31,gKi,caq,gKi,cay,gKi,cdG,gKi,bQM,gKi,bGa,gKi,dZY,gKi,eVc,gKi,aZf,gKi,cPf,gKi,dhG,gKi,duf,gKi,cvs,gKi,c_t,gKi,bKA,gKi,dr8,gKi,cp_,gKi,Xn,gKi,coS,gKi,cri,gKi,caQ,gKi,aT0,gKi,cXx,gKi,diS,gKi,ctu,gKi,a9u,gKi,chG,gKi,aiC,gKi,eMN,gKi,X$,gKi,anO,gKi,bA0,gKi,ap1,gKi,cZT,gKi,b7Q,gKi,aWY,gKi,dlI,gKi,ad9,gKi,eC0,gKi,bLU,gKi,c5v,gKi,aaa,gKi,byO,gKi,cBP,gKi,cyk,gKi,cw0,gKi,ciM,gKi,cWB,gKi,fpd,gKi,aEE,gKi,c33,gKi,gEk,gKi,bSs,gKi,bs2,gKi,bZQ,gKi,aJI,gKi,cj4,gKi,b4a,gKi,bvm,gKi,e3U,gKi,cJK,gKi,bda,gKi,cly,gKi,c13,gKi,bkd,gKi,Yf,gKi,c5F,gKi,dAZ,gKi,bZ_,gKi,aWh,gKi,fhg,gKi,cWf,gKi,bGw,gKi,bEQ,gKi,cFk,gKi,eSB,gKi,bNU,gKi,c4e,gKi,erl,gKi,b0K,gKi,bug,gKi,cuq,gKi,d4y,gKi,aeB,gKi,avC,gKi,bFk,gKi,dJL,gKi,c$v,gKi,c55,gKi,dKY,gKi,ba_,gKi,eRN,gKi,acX,gKi,abp,gKi,bzY,gKi,ak7,gKi,d99,gKi,c25,gKi,b8O,gKi,ftQ,gKi,a21,gKi,dPK,gKi,bFi,gKi,arL,gKi,cee,gKi,bDg,gKi,bZA,gKi,eYE,gKi,eaU,gKi,bHC,gKi,eD9,gKi,cPz,gKi,dsa,gKi,bSc,gKi,dBI,gKi,ciS,gKi,ZQ,gKi,c5M,gKi,buo,gKi,aEr,gKi,ayK,gKi,by_,gKi,cbi,gKi,crs,gKi,aoe,gKi,bCa,gKi,bfF,gKi,coC,gKi,cLo,gKi,bI2,gKi,bYo,gKi,bLk,gKi,cfy,gKi,dMR,gKi,ckE,gKi,bvK,gKi,bGU,gKi,bGG,gKi,cYp,gKi,eU0,gKi,byS,gKi,cs8,gKi,bRo,gKi,dUI,gKi,bwM,gKi,clW,gKi,b$2,gKi,a7K,gKi,bZ0,gKi,dnX,gKi,dYK,gKi,bXW,gKi,bPS,gKi,dhk,gKi,c4X,gKi,cuK,gKi,ccS,gKi,cYj,gKi,a9w,gKi,aNg,gKi,X7,gKi,doF,gKi,dkk,gKi,buc,gKi,bWk,gKi,d9E,gKi,aBu,gKi,cgQ,gKi,av$,gKi,eMA,gKi,cVv,gKi,d4D,gKi,bfN,gKi,ald,gKi,dgC,gKi,bFa,gKi,ajJ,gKi,bMs,gKi,c5G,gKi,gAH,gKi,c$F,gKi,bPy,gKi,efR,gKi,d3b,gKi,cGq,gKi,bRA,gKi,cto,gKi,dLN,gKi,c4x,gKi,cMd,gKi,bxU,gKi,e_1,gKi,eRT,gKi,cow,gKi,asd,gKi,cDT,gKi,bYS,gKi,ec1,gKi,Z$,gKi,aaI,gKi,cSl,gKi,bGg,gKi,b1k,gKi,cj2,gKi,bwQ,gKi,epS,gKi,b0A,gKi,cSL,gKi,bX4,gKi,fiK,gKi,cd2,gKi,eGM,gKi,dHY,gKi,bZC,gKi,cJe,gKi,aPH,gKi,dK$,gKi,aOY,gKi,dZo,gKi,bV4,gKi,aGe,gKi,ash,gKi,cro,gKi,b2Q,gKi,fs1,gKi,cye,gKi,d34,gKi,cnU,gKi,bcz,gKi,bD6,gKi,a9E,gKi,eMk,gKi,a5T,gKi,bmc,gKi,eo4,gKi,eqo,gKi,aCu,gKi,eJp,gKi,b2s,gKi,apJ,gKi,dSB,gKi,dml,gKi,cgU,gKi,clu,gKi,d97,gKi,aaS,gKi,b9C,gKi,ev8,gKi,acv,gKi,chE,gKi,ap3,gKi,e$o,gKi,b$m,gKi,ah7,gKi,cq2,gKi,cSX,gKi,cY5,gKi,aMU,gKi,c0w,gKi,e4s,gKi,baD,gKi,e0A,gKi,b7C,gKi,eYr,gKi,b1I,gKi,cDV,gKi,e1C,gKi,dzQ,gKi,c_V,gKi,e4n,gKi,c3R,gKi,duG,gKi,bTM,gKi,dya,gKi,cO1,gKi,cbE,gKi,dTv,gKi,ccs,gKi,bG8,gKi,bJ0,gKi,c47,gKi,Xj,gKi,cwg,gKi,csi,gKi,bXi,gKi,eyJ,gKi,cXR,gKi,eb_,gKi,acJ,gKi,aji,gKi,bKw,gKi,bib,gKi,cDP,gKi,adX,gKi,bWK,gKi,bMG,gKi,cB6,gKi,d8C,gKi,bAe,gKi,c6J,gKi,abk,gKi,cns,gKi,by2,gKi,bwc,gKi,c6A,gKi,bWi,gKi,bdk,gKi,eJN,gKi,bfo,gKi,cDf,gKi,cQZ,gKi,eLf,gKi,eEg,gKi,bNu,gKi,aqs,gKi,eC2,gKi,cu4,gKi,aSR,gKi,dEb,gKi,bVg,gKi,eNU,gKi,dAe,gKi,dmg,gKi,aTJ,gKi,cn0,gKi,cMr,gKi,aJ3,gKi,ckU,gKi,bkU,gKi,bPc,gKi,clG,gKi,fbv,gKi,cl4,gKi,ehb,gKi,bLa,gKi,c_z,gKi,cko,gKi,bIw,gKi,cR5,gKi,bM2,gKi,cCk,gKi,a_0,gKi,aZM,gKi,eTy,gKi,crI,gKi,aM4,gKi,ckO,gKi,dJz,gKi,cmI,gKi,dve,gKi,a3$,gKi,cE1,gKi,cQ1,gKi,aqk,gKi,aPT,gKi,alF,gKi,caK,gKi,bT2,gKi,c6E,gKi,cSx,gKi,cws,gKi,c6I,gKi,e0W,gKi,bJE,gKi,dVP,gKi,ce8,gKi,bZY,gKi,cu6,gKi,dBN,gKi,c4J,gKi,acD,gKi,azw,gKi,ejj,gKi,cHo,gKi,eJy,gKi,c1T,gKi,cPr,gKi,cKb,gKi,bBy,gKi,bXO,gKi,a65,gKi,cTR,gKi,dTp,gKi,e9V,gKi,cKK,gKi,fiZ,gKi,cV7,gKi,dOt,gKi,anC,gKi,fkw,gKi,c6M,gKi,cgG,gKi,c6H,gKi,amf,gKi,c1Y,gKi,bnv,gKi,bOu,gKi,b_G,gKi,brM,gKi,d1S,gKi,ck2,gKi,$c,gKi,aje,gKi,fiF,gKi,$4,gKi,ckg,gKi,am0,gKi,bUw,gKi,dKP,gKi,aP_,gKi,bYa,gKi,dxO,gKi,cs_,gKi,cBH,gKi,cQD,gKi,dmc,gKi,adk,gKi,cAX,gKi,dGb,gKi,clE,gKi,b9E,gKi,bZU,gKi,cvG,gKi,dtR,gKi,a81,gKi,bl1,gKi,aas,gKi,eEs,gKi,d0I,gKi,b96,gKi,fvq,gKi,d3J,gKi,aWo,gKi,b4s,gKi,a8v,gKi,b_W,gKi,c2T,gKi,fad,gKi,cc0,gKi,eqj,gKi,edW,gKi,eMn,gKi,c5D,gKi,arH,gKi,b8M,gKi,bCA,gKi,d0X,gKi,cDq,gKi,abi,gKi,cvY,gKi,bM_,gKi,arQ,gKi,aOP,gKi,bQy,gKi,awj,gKi,bWs,gKi,bBw,gKi,egv,gKi,bzq,gKi,bW6,gKi,cOT,gKi,byg,gKi,dsW,gKi,bGy,gKi,aW5,gKi,cOh,gKi,bma,gKi,caO,gKi,cVH,gKi,c5t,gKi,bJG,gKi,e1L,gKi,Y4,gKi,Yv,gKi,bYQ,gKi,aj7,gKi,bEI,gKi,crO,gKi,bRu,gKi,fgx,gKi,bXI,gKi,cWz,gKi,c3$,gKi,dLP,gKi,dCY,gKi,cII,gKi,cBY,gKi,als,gKi,dG8,gKi,bhL,gKi,cnE,gKi,bOs,gKi,chU,gKi,bxO,gKi,c1v,gKi,aLG,gKi,cHG,gKi,b3g,gKi,byC,gKi,cGu,gKi,dia,gKi,fs3,gKi,aZI,gKi,cV5,gKi,cDb,gKi,bLi,gKi,cON,gKi,b9_,gKi,etE,gKi,cH9,gKi,c36,gKi,bAm,gKi,ccG,gKi,aM6,gKi,dMm,gKi,$D,gKi,eoQ,gKi,aOS,gKi,XB,gKi,epx,gKi,eym,gKi,aF5,gKi,ckY,gKi,cEh,gKi,aFE,gKi,Zu,gKi,fm8,gKi,bPA,gKi,aob,gKi,dlA,gKi,bs6,gKi,egP,gKi,aV0,gKi,cei,gKi,eZn,gKi,cBk,gKi,e0_,gKi,bwU,gKi,aCw,gKi,byc,gKi,cUV,gKi,aJe,gKi,bwW,gKi,a6p,gKi,eRk,gKi,cUL,gKi,ezy,gKi,cZf,gKi,crq,gKi,aeD,gKi,btM,gKi,ciA,gKi,fjV,gKi,bX8,gKi,adO,gKi,d5s,gKi,dMX,gKi,dMw,gKi,c4d,gKi,aa2,gKi,bhp,gKi,b1Q,gKi,eJQ,gKi,b7G,gKi,fhZ,gKi,eBf,gKi,eSD,gKi,bgp,gKi,bTK,gKi,ezw,gKi,fdn,gKi,awN,gKi,d9q,gKi,b5u,gKi,cfE,gKi,eS0,gKi,bye,gKi,bfP,gKi,b2E,gKi,apT,gKi,aMY,gKi,egr,gKi,aY5,gKi,fbp,gKi,ewz,gKi,bT4,gKi,d5G,gKi,XU,gKi,c4A,gKi,dEY,gKi,dOq,gKi,cPL,gKi,biX,gKi,ejn,gKi,aog,gKi,anE,gKi,dKm,gKi,aNP,gKi,bb1,gKi,cnQ,gKi,bZy,gKi,bju,gKi,c6b,gKi,cnq,gKi,dPZ,gKi,fby,gKi,cU7,gKi,cEO,gKi,a5e,gKi,$z,gKi,bV0,gKi,cqc,gKi,cb0,gKi,bT0,gKi,bum,gKi,ar2,gKi,cxi,gKi,bSa,gKi,cIR,gKi,bYW,gKi,eCR,gKi,eUJ,gKi,cZ7,gKi,fgF,gKi,cCU,gKi,bWC,gKi,a2T,gKi,cH5,gKi,c0J,gKi,abJ,gKi,YW,gKi,b_C,gKi,aMn,gKi,bJq,gKi,flp,gKi,bH_,gKi,dVl,gKi,bNy,gKi,c46,gKi,axC,gKi,cnY,gKi,c4u,gKi,aoz,gKi,dq0,gKi,d90,gKi,dLS,gKi,clw,gKi,eq7,gKi,bch,gKi,bR0,gKi,bKo,gKi,aqf,gKi,alH,gKi,a53,gKi,eBa,gKi,bAW,gKi,dIB,gKi,c$f,gKi,cBB,gKi,cr0,gKi,bsY,gKi,adm,gKi,cVj,gKi,c0o,gKi,dhX,gKi,cmE,gKi,cTl,gKi,btK,gKi,al9,gKi,fqD,gKi,bv6,gKi,aFv,gKi,cVz,gKi,e7o,gKi,cV$,gKi,b1u,gKi,bwO,gKi,aSV,gKi,fsR,gKi,b8G,gKi,bBe,gKi,bxM,gKi,ckm,gKi,cC6,gKi,c2z,gKi,fga,gKi,bN6,gKi,crc,gKi,bzM,gKi,c3w,gKi,aKA,gKi,c01,gKi,fpr,gKi,bnz,gKi,elF,gKi,aXR,gKi,a9b,gKi,eEW,gKi,ajr,gKi,a7Y,gKi,eGY,gKi,dFN,gKi,a36,gKi,edA,gKi,bM4,gKi,cT7,gKi,bY6,gKi,anW,gKi,eSc,gKi,cY3,gKi,b4o,gKi,b3y,gKi,d5N,gKi,cYh,gKi,bHQ,gKi,elr,gKi,buQ,gKi,bVq,gKi,crg,gKi,cTj,gKi,ad$,gKi,ciw,gKi,bhU,gKi,fsW,gKi,c_j,gKi,cQv,gKi,exL,gKi,aey,gKi,b1W,gKi,c4f,gKi,cYl,gKi,dJp,gKi,ca2,gKi,eV3,gKi,cLB,gKi,cdC,gKi,bVo,gKi,co_,gKi,aVc,gKi,eLO,gKi,b8e,gKi,c5O,gKi,flX,gKi,ank,gKi,aco,gKi,cty,gKi,aAo,gKi,b8I,gKi,cwy,gKi,bsC,gKi,eJa,gKi,bvg,gKi,cYD,gKi,bJ4,gKi,cpQ,gKi,aW9,gKi,c5T,gKi,bcf,gKi,cnO,gKi,cg8,gKi,dOj,gKi,cZp,gKi,ar6,gKi,bKa,gKi,cFG,gKi,aDb,gKi,cF1,gKi,dH6,gKi,c2O,gKi,bEU,gKi,cf6,gKi,bNo,gKi,bNs,gKi,aqi,gKi,bP8,gKi,bS2,gKi,bHG,gKi,aBy,gKi,ajE,gKi,gIa,gKi,bBM,gKi,eqg,gKi,cW9,gKi,d0G,gKi,bm6,gKi,Z2,gKi,eq_,gKi,ewe,gKi,fav,gKi,fh0,gKi,bhd,gKi,ai4,gKi,bN2,gKi,bWu,gKi,cCe,gKi,aRr,gKi,bUK,gKi,a3K,gKi,eDR,gKi,eRf,gKi,fgc,gKi,an8,gKi,bjN,gKi,en7,gKi,c2S,gKi,eXz,gKi,YB,gKi,amE,gKi,bQ_,gKi,cCF,gKi,cLx,gKi,dAi,gKi,bUo,gKi,cXd,gKi,epi,gKi,eUf,gKi,axb,gKi,a_L,gKi,drH,gKi,cgy,gKi,cdm,gKi,bso,gKi,dxd,gKi,bro,gKi,dy1,gKi,bBg,gKi,el4,gKi,eK7,gKi,a63,gKi,clq,gKi,ayj,gKi,cW7,gKi,aNB,gKi,bA2,gKi,epF,gKi,aHa,gKi,c3g,gKi,bSe,gKi,efu,gKi,aSM,gKi,dtT,gKi,dKA,gKi,cwi,gKi,dij,gKi,cSB,gKi,doH,gKi,c4w,gKi,cl8,gKi,dvi,gKi,b_u,gKi,cpo,gKi,aaK,gKi,dHc,gKi,eYP,gKi,caA,gKi,aWA,gKi,eGw,gKi,cnM,gKi,cO7,gKi,b6Y,gKi,b5S,gKi,b0k,gKi,chM,gKi,YJ,gKi,eR_,gKi,bn0,gKi,a_D,gKi,cVT,gKi,b8y,gKi,eCl,gKi,cs0,gKi,b38,gKi,cqE,gKi,btI,gKi,b2U,gKi,cZ9,gKi,axj,gKi,atn,gKi,aUO,gKi,akC,gKi,cKn,gKi,bJM,gKi,fk$,gKi,flk,gKi,aoI,gKi,chy,gKi,apQ,gKi,aMD,gKi,cmW,gKi,bOO,gKi,gIb,gKi,aWT,gKi,bsS,gKi,XO,gKi,c_H,gKi,ams,gKi,XW,gKi,cWL,gKi,eTn,gKi,co2,gKi,c35,gKi,d_D,gKi,cuY,gKi,bCc,gKi,eAl,gKi,d3H,gKi,b0w,gKi,c1c,gKi,dH2,gKi,cZr,gKi,cgK,gKi,c3x,gKi,aeL,gKi,bSW,gKi,c3G,gKi,dzt,gKi,bcY,gKi,bUi,gKi,aaU,gKi,e3N,gKi,cwk,gKi,e7h,gKi,dnh,gKi,bBm,gKi,b3o,gKi,bE8,gKi,br8,gKi,bQk,gKi,aRp,gKi,cUF,gKi,b0M,gKi,dpo,gKi,a41,gKi,bNQ,gKi,aac,gKi,b1E,gKi,cfC,gKi,cVr,gKi,cck,gKi,d5j,gKi,dqS,gKi,c4Y,gKi,cm_,gKi,cJE,gKi,bVe,gKi,ca8,gKi,aed,gKi,cE7,gKi,cJl,gKi,cqg,gKi,cJC,gKi,cra,gKi,bTo,gKi,cvi,gKi,cqm,gKi,bIC,gKi,b14,gKi,dm9,gKi,bQE,gKi,chA,gKi,ccm,gKi,cwK,gKi,c_b,gKi,cZh,gKi,cqY,gKi,cnu,gKi,bQI,gKi,cWR,gKi,fbP,gKi,c4B,gKi,aXy,gKi,ezG,gKi,coI,gKi,c4K,gKi,cYt,gKi,flB,gKi,aDV,gKi,bC0,gKi,cpe,gKi,aOV,gKi,cci,gKi,fgn,gKi,cvO,gKi,al$,gKi,brO,gKi,aJU,gKi,cle,gKi,cn2,gKi,eL1,gKi,bUy,gKi,c0r,gKi,eaB,gKi,cw4,gKi,foI,gKi,bvU,gKi,b2c,gKi,bVW,gKi,cMb,gKi,cXf,gKi,dSa,gKi,aRb,gKi,cxq,gKi,b4A,gKi,cka,gKi,be2,gKi,byI,gKi,bxs,gKi,cTz,gKi,e7C,gKi,cfQ,gKi,fsT,gKi,dvo,gKi,c4C,gKi,bCq,gKi,cx0,gKi,coE,gKi,bsq,gKi,dRs,gKi,cFa,gKi,aNR,gKi,d5u,gKi,c2g,gKi,cTP,gKi,dwG,gKi,cYJ,gKi,_6,gKi,bKY,gKi,buW,gKi,fah,gKi,fko,gKi,cf4,gKi,ci2,gKi,dn2,gKi,ctU,gKi,ceY,gKi,eS2,gKi,fbr,gKi,cQR,gKi,bsO,gKi,$8,gKi,dHv,gKi,cs4,gKi,ftZ,gKi,cKF,gKi,bQg,gKi,aNe,gKi,avQ,gKi,bGi,gKi,iq,gKi,cXp,gKi,cw8,gKi,cDm,gKi,fnu,gKi,eA1,gKi,cVN,gKi,c4y,gKi,c4D,gKi,c1y,gKi,aRu,gKi,b7q,gKi,dZ4,gKi,bGO,gKi,cgg,gKi,eNi,gKi,aci,gKi,cau,gKi,b6E,gKi,cpa,gKi,fh7,gKi,coo,gKi,brQ,gKi,djX,gKi,cF4,gKi,aGi,gKi,aMI,gKi,bzo,gKi,cwA,gKi,cnI,gKi,dyR,gKi,dA3,gKi,aa0,gKi,bIA,gKi,eMq,gKi,cd6,gKi,d11,gKi,c0C,gKi,b94,gKi,aIa,gKi,acg,gKi,cIZ,gKi,cD5,gKi,fif,gKi,cuI,gKi,fb5,gKi,bjY,gKi,caa,gKi,bZS,gKi,cRf,gKi,cYd,gKi,bSS,gKi,csy,gKi,fkl,gKi,cgw,gKi,eGK,gKi,dJ4,gKi,fm$,gKi,c0y,gKi,dBr,gKi,bt6,gKi,bt4,gKi,eV1,gKi,dl8,gKi,bwu,gKi,bRw,gKi,e1X,gKi,eE$,gKi,eWn,gKi,cc8,gKi,bdq,gKi,cuU,gKi,b4Q,gKi,cuM,gKi,bCG,gKi,bHc,gKi,eA7,gKi,bUq,gKi,byk,gKi,aiI,gKi,ehP,gKi,b1w,gKi,apO,gKi,cfO,gKi,b_K,gKi,dyP,gKi,e1w,gKi,b_s,gKi,cfK,gKi,epQ,gKi,Zs,gKi,cGS,gKi,fna,gKi,djI,gKi,b5Y,gKi,bxu,gKi,cJc,gKi,aen,gKi,WI,gKi,aoq,gKi,cgi,gKi,bU6,gKi,aCj,gKi,cO9,gKi,cP3,gKi,aaQ,gKi,aN1,gKi,eHM,gKi,ff$,gKi,coM,gKi,b7e,gKi,anY,gKi,bQO,gKi,dGh,gKi,cWD,gKi,ceM,gKi,cXH,gKi,cv6,gKi,cHY,gKi,dR$,gKi,anT,gKi,eRi,gKi,bwq,gKi,cOz,gKi,atO,gKi,bLs,gKi,cgA,gKi,cKr,gKi,c3T,gKi,b$c,gKi,ept,gKi,bGK,gKi,dtM,gKi,dIS,gKi,dqP,gKi,cuO,gKi,bsc,gKi,aTE,gKi,cSz,gKi,bJQ,gKi,ea1,gKi,cRd,gKi,bWI,gKi,b1m,gKi,ZH,gKi,b_g,gKi,bRC,gKi,aeP,gKi,cxU,gKi,cJA,gKi,cRz,gKi,cJj,gKi,bIW,gKi,cuQ,gKi,crC,gKi,bE2,gKi,eNg,gKi,c0T,gKi,c3t,gKi,cIK,gKi,e1N,gKi,anM,gKi,cgM,gKi,dR3,gKi,_0,gKi,c4k,gKi,bwY,gKi,eJe,gKi,cX9,gKi,anR,gKi,elY,gKi,dAL,gKi,aMw,gKi,eth,gKi,eoy,gKi,eGy,gKi,aOG,gKi,cTv,gKi,aQv,gKi,Z5,gKi,a8T,gKi,ehG,gKi,cFJ,gKi,apL,gKi,bc4,gKi,di1,gKi,aD1,gKi,cXP,gKi,bQc,gKi,b$_,gKi,bb7,gKi,bzu,gKi,b9Y,gKi,eTR,gKi,brn,gKi,dVA,gKi,b_a,gKi,cqq,gKi,cX$,gKi,aRT,gKi,b$O,gKi,cn_,gKi,c$4,gKi,cUd,gKi,cYL,gKi,ZB,gKi,aqU,gKi,aU2,gKi,YH,gKi,cdY,gKi,btA,gKi,b5K,gKi,aD5,gKi,bPo,gKi,cJ_,gKi,bZi,gKi,cli,gKi,cqU,gKi,cB_,gKi,ewi,gKi,dAG,gKi,aPK,gKi,eKN,gKi,b$W,gKi,a9j,gKi,dha,gKi,b1K,gKi,bRI,gKi,b2i,gKi,c5z,gKi,bCU,gKi,ay8,gKi,cQn,gKi,d0u,gKi,kF,gKi,bSI,gKi,dw0,gKi,cem,gKi,cWj,gKi,aC9,gKi,bnx,gKi,aiK,gKi,cgc,gKi,d45,gKi,dVF,gKi,cOF,gKi,e_R,gKi,b4G,gKi,bWe,gKi,eL4,gKi,cXb,gKi,eUd,gKi,buG,gKi,brA,gKi,_l,gKi,e0N,gKi,ala,gKi,bEu,gKi,css,gKi,dzl,gKi,cK3,gKi,aud,gKi,eAd,gKi,c5l,gKi,c6v,gKi,fcK,gKi,bw0,gKi,aJn,gKi,eUG,gKi,cjM,gKi,avA,gKi,cOp,gKi,bxC,gKi,bsW,gKi,b$g,gKi,dNZ,gKi,eh1,gKi,dl6,gKi,bKE,gKi,c5X,gKi,bFe,gKi,cpm,gKi,dUt,gKi,aS3,gKi,e9R,gKi,cUv,gKi,dte,gKi,cHC,gKi,bKg,gKi,dUP,gKi,bOY,gKi,cDd,gKi,av3,gKi,cWH,gKi,eQ7,gKi,aba,gKi,gIc,gKi,dpS,gKi,a5N,gKi,b$I,gKi,dFT,gKi,cId,gKi,dtC,gKi,aHd,gKi,c1o,gKi,ccK,gKi,c_J,gKi,eeL,gKi,ao4,gKi,bYI,gKi,bMQ,gKi,gA_,gKi,dIZ,gKi,cGa,gKi,bQQ,gKi,cBs,gKi,elA,gKi,bUG,gKi,bXe,gKi,cxA,gKi,eGR,gKi,b6s,gKi,gz3,gKi,cu_,gKi,fsL,gKi,cQl,gKi,a3O,gKi,auE,gKi,drx,gKi,bgu,gKi,csA,gKi,d_s,gKi,dFq,gKi,alZ,gKi,c_9,gKi,c5Y,gKi,a5A,gKi,dti,gKi,eKV,gKi,bU_,gKi,b1q,gKi,a5E,gKi,bB0,gKi,cvw,gKi,a3Q,gKi,dI$,gKi,eKF,gKi,dPP,gKi,ciK,gKi,bKQ,gKi,cTN,gKi,cfw,gKi,aby,gKi,Zb,gKi,a_S,gKi,dM4,gKi,cmw,gKi,bC2,gKi,aaM,gKi,c5m,gKi,elP,gKi,bmO,gKi,c58,gKi,cH2,gKi,bSK,gKi,eut,gKi,dA7,gKi,aRK,gKi,eNd,gKi,dos,gKi,c4T,gKi,bN_,gKi,c_r,gKi,cMp,gKi,cx_,gKi,bx8,gKi,cwY,gKi,cOl,gKi,bTu,gKi,bui,gKi,bgg,gKi,bP2,gKi,c54,gKi,Xd,gKi,eSi,gKi,a2$,gKi,ckK,gKi,gEQ,gKi,d_h,gKi,aK1,gKi,dzO,gKi,ds3,gKi,dwj,gKi,al7,gKi,b3A,gKi,by4,gKi,bMc,gKi,cne,gKi,byo,gKi,byY,gKi,avG,gKi,dp7,gKi,bIu,gKi,bAs,gKi,bG2,gKi,ces,gKi,clU,gKi,cKI,gKi,bV6,gKi,fgY,gKi,eld,gKi,ckw,gKi,bIg,gKi,b9u,gKi,cB8,gKi,bXE,gKi,csM,gKi,bIK,gKi,aiW,gKi,cUB,gKi,cHO,gKi,eH8,gKi,bO4,gKi,cqA,gKi,aku,gKi,am9,gKi,am4,gKi,cdE,gKi,c3S,gKi,aiv,gKi,c$T,gKi,cOJ,gKi,dSq,gKi,bGo,gKi,aQf,gKi,a87,gKi,eI4,gKi,ce4,gKi,dHU,gKi,eAE,gKi,btw,gKi,ccy,gKi,bcI,gKi,b4y,gKi,ain,gKi,bfW,gKi,fqu,gKi,bnF,gKi,aa6,gKi,buY,gKi,dx2,gKi,cUr,gKi,bCE,gKi,eHO,gKi,cqi,gKi,bWA,gKi,XQ,gKi,aws,gKi,bc2,gKi,bIa,gKi,dVW,gKi,dlj,gKi,e$j,gKi,e4_,gKi,eDW,gKi,cSJ,gKi,cTB,gKi,crS,gKi,ck0,gKi,eB4,gKi,azr,gKi,ehV,gKi,fo5,gKi,ctI,gKi,b7Y,gKi,dNN,gKi,dog,gKi,bXk,gKi,eWg,gKi,ct8,gKi,dAT,gKi,ctw,gKi,abg,gKi,fiA,gKi,aUv,gKi,dF2,gKi,cS7,gKi,bpd,gKi,dP7,gKi,c_3,gKi,abT,gKi,b86,gKi,c4t,gKi,boS,gKi,bBE,gKi,b24,gKi,c5H,gKi,eV6,gKi,awB,gKi,bzG,gKi,b8c,gKi,aqK,gKi,crQ,gKi,bxe,gKi,aBJ,gKi,emD,gKi,eor,gKi,cIG,gKi,Xp,gKi,eT5,gKi,cRH,gKi,cUh,gKi,ehX,gKi,d7V,gKi,b5Q,gKi,ceq,gKi,b7O,gKi,chg,gKi,bRy,gKi,b0e,gKi,clA,gKi,e59,gKi,cLr,gKi,akW,gKi,bz2,gKi,bw2,gKi,eMc,gKi,c2b,gKi,cMn,gKi,ck_,gKi,cQT,gKi,csE,gKi,e$l,gKi,eTi,gKi,aJW,gKi,cYN,gKi,csq,gKi,b2g,gKi,b7K,gKi,b0i,gKi,ewu,gKi,cYf,gKi,bG6,gKi,bRk,gKi,cbe,gKi,cH_,gKi,fg$,gKi,bCC,gKi,cIo,gKi,ftE,gKi,a4n,gKi,aQ9,gKi,avO,gKi,dpO,gKi,cFS,gKi,e53,gKi,coU,gKi,ctG,gKi,cac,gKi,bLG,gKi,aoC,gKi,c5f,gKi,com,gKi,c2Z,gKi,cOf,gKi,bD0,gKi,d_w,gKi,fs5,gKi,eLG,gKi,cii,gKi,a7R,gKi,ayX,gKi,cD7,gKi,aPV,gKi,ks,gKi,dql,gKi,b7u,gKi,ci4,gKi,c_R,gKi,cpS,gKi,dCW,gKi,abY,gKi,eL_,gKi,b54,gKi,bQW,gKi,e3X,gKi,aih,gKi,cky,gKi,eL9,gKi,b3G,gKi,d3T,gKi,csk,gKi,c6w,gKi,en9,gKi,cts,gKi,aNW,gKi,dhq,gKi,eqO,gKi,bCi,gKi,gzE,gKi,byq,gKi,bEC,gKi,cvk,gKi,apq,gKi,faF,gKi,bTE,gKi,biV,gKi,bhW,gKi,bMm,gKi,YS,gKi,bSm,gKi,dFB,gKi,cPl,gKi,cgO,gKi,fuM,gKi,cSr,gKi,aun,gKi,b6o,gKi,bXY,gKi,ack,gKi,d9b,gKi,aIm,gKi,cji,gKi,eJJ,gKi,bte,gKi,bxi,gKi,bYe,gKi,aoX,gKi,Z7,gKi,fsH,gKi,c3h,gKi,abW,gKi,ajk,gKi,eUv,gKi,dHO,gKi,c3U,gKi,cPJ,gKi,cH7,gKi,ee0,gKi,cWb,gKi,ft6,gKi,eyS,gKi,ekr,gKi,caw,gKi,dHD,gKi,cU$,gKi,cg0,gKi,bHO,gKi,exR,gKi,dBg,gKi,cP1,gKi,cse,gKi,cjQ,gKi,c_h,gKi,abA,gKi,cdM,gKi,dsd,gKi,aNF,gKi,aiG,gKi,aXr,gKi,bOA,gKi,b3c,gKi,ace,gKi,cmy,gKi,c0E,gKi,auv,gKi,bHy,gKi,bw6,gKi,dJY,gKi,cSf,gKi,bI8,gKi,cWr,gKi,bEY,gKi,b$k,gKi,bE0,gKi,a8Z,gKi,cUH,gKi,fbb,gKi,aAK,gKi,cju,gKi,bvs,gKi,dRS,gKi,dmj,gKi,dsh,gKi,cA3,gKi,byQ,gKi,cwU,gKi,eDT,gKi,a3m,gKi,fuX,gKi,bJ8,gKi,e7w,gKi,eI0,gKi,aB6,gKi,b1s,gKi,cke,gKi,cpY,gKi,c3P,gKi,ctS,gKi,bGI,gKi,c5_,gKi,b6a,gKi,euN,gKi,cr_,gKi,aAd,gKi,dF6,gKi,byw,gKi,cx4,gKi,cCz,gKi,cYX,gKi,c5A,gKi,bZ4,gKi,eEN,gKi,eJH,gKi,c4S,gKi,bJo,gKi,c57,gKi,cT5,gKi,cb6,gKi,el2,gKi,c2m,gKi,cWn,gKi,cCm,gKi,cUz,gKi,e8t,gKi,cbQ,gKi,adM,gKi,aWc,gKi,c2N,gKi,bCM,gKi,a5k,gKi,eLp,gKi,aUn,gKi,aR4,gKi,eUE,gKi,dAg,gKi,bdK,gKi,cFq,gKi,arx,gKi,cbc,gKi,dQY,gKi,ay4,gKi,cQX,gKi,al3,gKi,bB_,gKi,dAV,gKi,bYY,gKi,cp6,gKi,bUA,gKi,ctQ,gKi,bIs,gKi,dKq,gKi,d4p,gKi,dwp,gKi,cPV,gKi,bPG,gKi,eKA,gKi,c$L,gKi,bz0,gKi,alQ,gKi,b_2,gKi,b5s,gKi,brq,gKi,buK,gKi,cdU,gKi,aRg,gKi,eRD,gKi,cTJ,gKi,Zo,gKi,cSR,gKi,adT,gKi,eoE,gKi,a6l,gKi,cxM,gKi,b2C,gKi,e9x,gKi,bFU,gKi,apv,gKi,chO,gKi,cUR,gKi,br_,gKi,faA,gKi,cxG,gKi,ceW,gKi,cp0,gKi,bEk,gKi,b$a,gKi,RU,gKi,cMj,gKi,cZB,gKi,bsa,gKi,bLS,gKi,b04,gKi,dPR,gKi,baY,gKi,$W,gKi,caW,gKi,fuV,gKi,cdQ,gKi,bxQ,gKi,cEb,gKi,bFo,gKi,e4i,gKi,cjK,gKi,bE4,gKi,eIg,gKi,bR8,gKi,b_m,gKi,bzg,gKi,baA,gKi,eEx,gKi,ceO,gKi,ciU,gKi,bJC,gKi,aUd,gKi,cJa,gKi,aQI,gKi,c2_,gKi,c4c,gKi,bAu,gKi,XJ,gKi,aqw,gKi,fu5,gKi,beV,gKi,bT_,gKi,aB$,gKi,fvC,gKi,a51,gKi,b68,gKi,bKW,gKi,a5P,gKi,e1y,gKi,apH,gKi,bDm,gKi,bUc,gKi,aUF,gKi,alf,gKi,cpU,gKi,d9k,gKi,bTi,gKi,dKv,gKi,fvm,gKi,dEJ,gKi,bNa,gKi,aV_,gKi,eSa,gKi,a4f,gKi,bZW,gKi,cu8,gKi,eoS,gKi,aZ6,gKi,aqX,gKi,bGW,gKi,b36,gKi,ccW,gKi,cm0,gKi,blx,gKi,ehd,gKi,ccu,gKi,eon,gKi,eDH,gKi,bVy,gKi,bK0,gKi,cMv,gKi,aON,gKi,bIk,gKi,b4U,gKi,cQ9,gKi,bN8,gKi,bVm,gKi,b20,gKi,gEB,gKi,Yb,gKi,bYG,gKi,bKc,gKi,cRN,gKi,bvQ,gKi,cLc,gKi,b7a,gKi,b3U,gKi,bEO,gKi,dEH,gKi,cGy,gKi,bGA,gKi,cXr,gKi,aJa,gKi,c$l,gKi,b_8,gKi,ajL,gKi,elL,gKi,bB8,gKi,fuc,gKi,cQh,gKi,c41,gKi,al5,gKi,bvA,gKi,dwV,gKi,e65,gKi,cDR,gKi,bRa,gKi,bW8,gKi,bUM,gKi,fgk,gKi,dUo,gKi,ajH,gKi,b_S,gKi,b3i,gKi,d5T,gKi,bOq,gKi,b_Q,gKi,b1U,gKi,cL5,gKi,cCo,gKi,cuW,gKi,aVh,gKi,aXm,gKi,bnB,gKi,d0C,gKi,c5y,gKi,fbE,gKi,bDi,gKi,a9q,gKi,aXG,gKi,bD8,gKi,ceU,gKi,bCO,gKi,c6o,gKi,d3v,gKi,bKm,gKi,ciG,gKi,cj6,gKi,bRg,gKi,cMl,gKi,aRx,gKi,e3I,gKi,b9q,gKi,efN,gKi,cdk,gKi,bQC,gKi,csQ,gKi,bXQ,gKi,c6h,gKi,b0y,gKi,bGq,gKi,eTw,gKi,ewn,gKi,cok,gKi,eTV,gKi,YO,gKi,ak5,gKi,dr6,gKi,bJS,gKi,drO,gKi,cXl,gKi,bjr,gKi,bTW,gKi,c_N,gKi,anG,gKi,c3o,gKi,bJO,gKi,fln,gKi,dHe,gKi,bVw,gKi,$F,gKi,b8g,gKi,aeR,gKi,dDx,gKi,ak1,gKi,b4k,gKi,dZP,gKi,aF1,gKi,cTV,gKi,c1m,gKi,b2O,gKi,edp,gKi,c_x,gKi,bJI,gKi,cj0,gKi,amW,gKi,bLq,gKi,YU,gKi,cbU,gKi,cae,gKi,cc_,gKi,gEN,gKi,b6i,gKi,fhJ,gKi,c3k,gKi,dHa,gKi,b4W,gKi,cJn,gKi,cl2,gKi,akb,gKi,eu1,gKi,cq_,gKi,amy,gKi,ap5,gKi,aLa,gKi,b2o,gKi,eVf,gKi,eda,gKi,bdw,gKi,bdE,gKi,cCZ,gKi,bZa,gKi,bMK,gKi,b_O,gKi,dxV,gKi,fk1,gKi,bFs,gKi,dui,gKi,b$Y,gKi,bYE,gKi,bWo,gKi,cZJ,gKi,cWN,gKi,b2W,gKi,bg2,gKi,bRm,gKi,c6F,gKi,ds7,gKi,bCy,gKi,apc,gKi,aay,gKi,bLA,gKi,cRP,gKi,dvZ,gKi,cxQ,gKi,b6e,gKi,cJ0,gKi,bt8,gKi,c5N,gKi,dn$,gKi,kH,gKi,cPX,gKi,bTS,gKi,bGk,gKi,c5S,gKi,eul,gKi,b3u,gKi,Xl,gKi,eJr,gKi,a7w,gKi,bAc,gKi,cW1,gKi,aWm,gKi,hD,gKi,bsK,gKi,ctk,gKi,dOa,gKi,ajZ,gKi,bYu,gKi,bQ8,gKi,Xw,gKi,bQa,gKi,arf,gKi,cue,gKi,dov,gKi,fs$,gKi,ct2,gKi,cq6,gKi,cey,gKi,aS_,gKi,bG0,gKi,b9I,gKi,dOn,gKi,cXT,gKi,fbG,gKi,bXy,gKi,aNL,gKi,aBL,gKi,eeS,gKi,dic,gKi,cZt,gKi,d4u,gKi,cIN,gKi,c3f,gKi,c37,gKi,cBW,gKi,cXZ,gKi,cQp,gKi,aYD,gKi,a6T,gKi,d0Q,gKi,bAI,gKi,duu,gKi,Z9,gKi,bJw,gKi,b$u,gKi,eEJ,gKi,dNX,gKi,dBw,gKi,cK5,gKi,$a,gKi,fvu,gKi,bvu,gKi,XL,gKi,bLm,gKi,frz,gKi,dOW,gKi,c6D,gKi,eEv,gKi,aFH,gKi,cW$,gKi,aqc,gKi,cxI,gKi,dYG,gKi,cQ$,gKi,bTs,gKi,dpw,gKi,chq,gKi,b2k,gKi,cEE,gKi,bIG,gKi,cPn,gKi,e92,gKi,chm,gKi,bL6,gKi,e76,gKi,cIy,gKi,bJa,gKi,cxK,gKi,bHM,gKi,a9n,gKi,dKK,gKi,eKQ,gKi,drL,gKi,d$5,gKi,eJT,gKi,bJA,gKi,aSl,gKi,aUk,gKi,eRK,gKi,cK7,gKi,bBI,gKi,cj_,gKi,bF0,gKi,eso,gKi,cfg,gKi,bz6,gKi,cgI,gKi,bLK,gKi,_q,gKi,c$Y,gKi,air,gKi,cOD,gKi,cXj,gKi,b6q,gKi,dOH,gKi,bPs,gKi,eIn,gKi,bgs,gKi,cD$,gKi,dGI,gKi,ao8,gKi,aGg,gKi,b4E,gKi,bv8,gKi,dko,gKi,cIA,gKi,bAg,gKi,e_6,gKi,cge,gKi,dlr,gKi,dh6,gKi,cY7,gKi,b4O,gKi,aQ0,gKi,aTx,gKi,cf_,gKi,bk3,gKi,ccE,gKi,azj,gKi,bHa,gKi,eRR,gKi,bHo,gKi,b_k,gKi,b6A,gKi,bh5,gKi,bWg,gKi,cKu,gKi,eG8,gKi,bPU,gKi,aJc,gKi,e3G,gKi,fdQ,gKi,bcd,gKi,cb_,gKi,bFy,gKi,evp,gKi,cVP,gKi,edc,gKi,dCU,gKi,dI1,gKi,cKy,gKi,bij,gKi,dkm,gKi,$H,gKi,d4I,gKi,cl_,gKi,c49,gKi,cVx,gKi,b_I,gKi,dVM,gKi,bMk,gKi,aow,gKi,dup,gKi,c5x,gKi,bY0,gKi,c6d,gKi,bSG,gKi,bEG,gKi,bvG,gKi,e4Y,gKi,bEM,gKi,aR$,gKi,cSZ,gKi,che,gKi,e8C,gKi,eD_,gKi,Y2,gKi,bsg,gKi,bKe,gKi,eiE,gKi,eV$,gKi,eSl,gKi,b4C,gKi,eki,gKi,buw,gKi,bfY,gKi,aa4,gKi,cRJ,gKi,bAE,gKi,eI_,gKi,caY,gKi,btW,gKi,bP4,gKi,epn,gKi,bZ8,gKi,bL0,gKi,dBc,gKi,cJQ,gKi,bHe,gKi,cuA,gKi,d4O,gKi,aer,gKi,djy,gKi,eQ2,gKi,b4Y,gKi,dg6,gKi,c2p,gKi,c42,gKi,ciY,gKi,ab0,gKi,eG_,gKi,fdg,gKi,cvy,gKi,cTH,gKi,eKY,gKi,clM,gKi,aLJ,gKi,bRK,gKi,bQs,gKi,bIE,gKi,c_7,gKi,bvk,gKi,dIe,gKi,bTy,gKi,cLQ,gKi,abt,gKi,eoC,gKi,djA,gKi,cJ6,gKi,dpD,gKi,a4S,gKi,Zq,gKi,dCL,gKi,cde,gKi,cHM,gKi,aN4,gKi,b9y,gKi,cWl,gKi,b7y,gKi,cw_,gKi,cna,gKi,eD5,gKi,cJy,gKi,fak,gKi,crM,gKi,dOd,gKi,b$M,gKi,fb3,gKi,bTU,gKi,ay$,gKi,c28,gKi,cVB,gKi,bHA,gKi,dMT,gKi,anA,gKi,c3y,gKi,a3W,gKi,dr_,gKi,bL2,gKi,bIQ,gKi,cP9,gKi,arn,gKi,bQG,gKi,eWs,gKi,cme,gKi,lf,gKi,ajP,gKi,cKZ,gKi,d7j,gKi,bmF,gKi,bKk,gKi,dN6,gKi,dLE,gKi,eg$,gKi,e7J,gKi,aNU,gKi,cxs,gKi,bFI,gKi,bNk,gKi,d3l,gKi,eDD,gKi,$K,gKi,co6,gKi,cbM,gKi,eyL,gKi,bzs,gKi,ZO,gKi,a_d,gKi,boD,gKi,cOd,gKi,cVf,gKi,c4r,gKi,b34,gKi,dKU,gKi,b30,gKi,bs0,gKi,cS$,gKi,cmG,gKi,aHw,gKi,bWW,gKi,fpi,gKi,cQz,gKi,ckC,gKi,eR3,gKi,b8E,gKi,bPw,gKi,cdI,gKi,bwi,gKi,a_b,gKi,e5X,gKi,cYn,gKi,bJY,gKi,aQN,gKi,bzS,gKi,dVD,gKi,eqX,gKi,b8K,gKi,doo,gKi,aZ_,gKi,cpW,gKi,cga,gKi,cus,gKi,bLC,gKi,aaY,gKi,eHd,gKi,bOo,gKi,dwR,gKi,b6S,gKi,aqA,gKi,dH4,gKi,b8S,gKi,c4W,gKi,bkW,gKi,XD,gKi,fgs,gKi,bc_,gKi,cEC,gKi,eu$,gKi,e46,gKi,bif,gKi,dJm,gKi,cDX,gKi,djP,gKi,bue,gKi,aV4,gKi,b5o,gKi,dqu,gKi,cVl,gKi,e1V,gKi,aRX,gKi,eFP,gKi,$i,gKi,cZ1,gKi,ckq,gKi,cE_,gKi,ao$,gKi,bTC,gKi,b7k,gKi,bZu,gKi,bx_,gKi,dIF,gKi,aaW,gKi,cPN,gKi,cDu,gKi,buk,gKi,caM,gKi,cqo,gKi,b7m,gKi,dnS,gKi,b4S,gKi,adA,gKi,a9f,gKi,cD2,gKi,cPx,gKi,bG_,gKi,ci_,gKi,cHk,gKi,eo$,gKi,bAk,gKi,cny,gKi,bis,gKi,eYB,gKi,bXc,gKi,dwP,gKi,e7m,gKi,d_l,gKi,bFq,gKi,ezD,gKi,b5M,gKi,dFX,gKi,eVl,gKi,c1f,gKi,foq,gKi,aTX,gKi,apX,gKi,aND,gKi,buu,gKi,b2_,gKi,bWS,gKi,aej,gKi,cS3,gKi,ca_,gKi,eA5,gKi,bJ6,gKi,aOJ,gKi,csc,gKi,cBu,gKi,c59,gKi,emH,gKi,aQk,gKi,drc,gKi,b$8,gKi,dxJ,gKi,ce_,gKi,c5e,gKi,ft3,gKi,eM7,gKi,aj5,gKi,cRR,gKi,cfM,gKi,bWG,gKi,b_o,gKi,fuf,gKi,cTd,gKi,dHt,gKi,eli,gKi,cqM,gKi,dzy,gKi,bFM,gKi,dnJ,gKi,c$6,gKi,ant,gKi,b7U,gKi,a3j,gKi,gA2,gKi,bS8,gKi,bdC,gKi,ce2,gKi,cjA,gKi,cwo,gKi,c5I,gKi,bDM,gKi,ccA,gKi,e4T,gKi,dN3,gKi,dm2,gKi,cL$,gKi,eJA,gKi,dtm,gKi,cOV,gKi,aXo,gKi,dl1,gKi,any,gKi,c6C,gKi,fof,gKi,cx2,gKi,cpA,gKi,eRn,gKi,aAq,gKi,bmZ,gKi,aH$,gKi,bu0,gKi,ask,gKi,bxy,gKi,bto,gKi,ajX,gKi,bLy,gKi,dA0,gKi,d1$,gKi,fvE,gKi,e7S,gKi,b3S,gKi,ei_,gKi,cfW,gKi,b$i,gKi,dxM,gKi,c39,gKi,eYM,gKi,d4$,gKi,cL9,gKi,e9_,gKi,dtV,gKi,b4c,gKi,acR,gKi,bs4,gKi,b5G,gKi,dy_,gKi,cbk,gKi,bNe,gKi,c0A,gKi,abc,gKi,clI,gKi,bZw,gKi,aMW,gKi,jB,gKi,bUS,gKi,c2R,gKi,dZH,gKi,c6u,gKi,cbK,gKi,clm,gKi,gAm,gKi,aoS,gKi,bMW,gKi,b3W,gKi,e4L,gKi,eAo,gKi,bPq,gKi,eUY,gKi,cmY,gKi,b7s,gKi,eSN,gKi,bA6,gKi,aP3,gKi,b6_,gKi,ZS,gKi,eqV,gKi,cUb,gKi,dVJ,gKi,aaE,gKi,cER,gKi,cLS,gKi,e9X,gKi,cya,gKi,d$$,gKi,cTn,gKi,c5R,gKi,c6y,gKi,e7G,gKi,WG,gKi,bDo,gKi,bUe,gKi,et0,gKi,eRv,gKi,aSC,gKi,cN9,gKi,cSP,gKi,c_D,gKi,cco,gKi,aKE,gKi,bJs,gKi,buI,gKi,bUW,gKi,bX0,gKi,e7z,gKi,crA,gKi,e84,gKi,dnq,gKi,ctK,gKi,aP9,gKi,anI,gKi,arh,gKi,acV,gKi,bBQ,gKi,dQa,gKi,d0E,gKi,eh_,gKi,aPk,gKi,cQb,gKi,acq,gKi,aj3,gKi,cmk,gKi,cuy,gKi,c51,gKi,a4d,gKi,bjE,gKi,cwM,gKi,bC4,gKi,c3F,gKi,a5g,gKi,bVk,gKi,bSA,gKi,eZG,gKi,avX,gKi,c4E,gKi,bdi,gKi,bSM,gKi,cKM,gKi,amC,gKi,cYT,gKi,fa6,gKi,bNI,gKi,ej3,gKi,gAV,gKi,eH3,gKi,bTG,gKi,cHW,gKi,awV,gKi,e4x,gKi,cwc,gKi,cR9,gKi,b50,gKi,cba,gKi,eLs,gKi,btu,gKi,aLx,gKi,aet,gKi,ai_,gKi,bF6,gKi,bcG,gKi,du5,gKi,dAX,gKi,_w,gKi,ejF,gKi,cUx,gKi,e7s,gKi,cOv,gKi,ful,gKi,bDy,gKi,bTI,gKi,bCI,gKi,aeT,gKi,cZL,gKi,b_0,gKi,ejb,gKi,e0L,gKi,baG,gKi,a_N,gKi,dFH,gKi,csC,gKi,dTI,gKi,bOg,gKi,cqC,gKi,c2B,gKi,eop,gKi,b1o,gKi,gzL,gKi,eTF,gKi,dZC,gKi,bV_,gKi,cuu,gKi,aqI,gKi,bMA,gKi,cfu,gKi,bP_,gKi,fnw,gKi,eIi,gKi,eZl,gKi,fji,gKi,e74,gKi,_M,gKi,bFK,gKi,cEd,gKi,amO,gKi,duW,gKi,bxc,gKi,ftW,gKi,Zi,gKi,b5I,gKi,dHp,gKi,Zz,gKi,ajt,gKi,aKU,gKi,bus,gKi,bZO,gKi,cCD,gKi,b6G,gKi,c4N,gKi,epB,gKi,dO_,gKi,dJS,gKi,dFP,gKi,et6,gKi,cCu,gKi,bUE,gKi,cfo,gKi,b32,gKi,aWF,gKi,aO5,gKi,bb$,gKi,bBq,gKi,bRq,gKi,cwI,gKi,bCW,gKi,awX,gKi,cHE,gKi,ecs,gKi,bfd,gKi,aai,gKi,ajR,gKi,a8M,gKi,aQn,gKi,cP7,gKi,bvi,gKi,cST,gKi,dZ0,gKi,cBw,gKi,c4s,gKi,bwA,gKi,bve,gKi,c2i,gKi,ccY,gKi,bBU,gKi,cgq,gKi,bjj,gKi,b9M,gKi,exw,gKi,bRe,gKi,duM,gKi,b0E,gKi,fvh,gKi,c4H,gKi,bls,gKi,aqu,gKi,ab_,gKi,b42,gKi,c3K,gKi,e8y,gKi,aq7,gKi,djd,gKi,cnW,gKi,cSV,gKi,bUa,gKi,c4q,gKi,eiN,gKi,bBk,gKi,cS1,gKi,anm,gKi,ebB,gKi,ccq,gKi,aYO,gKi,aWV,gKi,djk,gKi,aIM,gKi,cUp,gKi,bSY,gKi,eUz,gKi,bKO,gKi,aoP,gKi,cYR,gKi,c3v,gKi,eXo,gKi,aMy,gKi,e7O,gKi,cbg,gKi,bR_,gKi,eCU,gKi,epd,gKi,iV,gKi,eEP,gKi,bt0,gKi,cwe,gKi,b5e,gKi,cps,gKi,b3M,gKi,epa,gKi,_I,gKi,cRF,gKi,cEJ,gKi,b84,gKi,dVR,gKi,aid,gKi,avK,gKi,cno,gKi,aWK,gKi,fuA,gKi,e4O,gKi,bLo,gKi,cyi,gKi,b8u,gKi,cva,gKi,atc,gKi,aDT,gKi,bOG,gKi,c5Z,gKi,bZe,gKi,evG,gKi,a3t,gKi,cDy,gKi,eDK,gKi,bt2,gKi,aFO,gKi,d8p,gKi,bM6,gKi,cCa,gKi,cnc,gKi,fvw,gKi,bom,gKi,dUe,gKi,eyA,gKi,cvU,gKi,cLH,gKi,cVR,gKi,ds$,gKi,aEg,gKi,aAM,gKi,ch_,gKi,crU,gKi,dNP,gKi,eUa,gKi,aNZ,gKi,cgY,gKi,cPT,gKi,fnd,gKi,dJB,gKi,dKc,gKi,dkc,gKi,b0q,gKi,dv4,gKi,cgo,gKi,dME,gKi,brG,gKi,aml,gKi,bGu,gKi,bwk,gKi,cho,gKi,cJr,gKi,adw,gKi,e_z,gKi,adq,gKi,cmq,gKi,aKw,gKi,aeJ,gKi,cGw,gKi,acB,gKi,epf,gKi,b2Y,gKi,eSW,gKi,b1C,gKi,dHK,gKi,apz,gKi,cZl,gKi,eT8,gKi,b8m,gKi,cvE,gKi,c1F,gKi,dpG,gKi,cQN,gKi,ayQ,gKi,cLa,gKi,aRj,gKi,bV2,gKi,cL1,gKi,$k,gKi,bFW,gKi,dQ6,gKi,akr,gKi,aNH,gKi,e1A,gKi,c15,gKi,dp4,gKi,cbw,gKi,blP,gKi,cY$,gKi,cCH,gKi,fhR,gKi,bSk,gKi,aXE,gKi,fvo,gKi,csm,gKi,cRp,gKi,c5U,gKi,aPA,gKi,cT$,gKi,b1Y,gKi,e3Q,gKi,fsY,gKi,aM1,gKi,aRF,gKi,fsN,gKi,cEl,gKi,cxC,gKi,bxY,gKi,c6s,gKi,bO8,gKi,cTX,gKi,bLE,gKi,aPC,gKi,ar8,gKi,dh8,gKi,bC_,gKi,c6x,gKi,ckI,gKi,dz5,gKi,$v,gKi,bTm,gKi,aXg,gKi,eFY,gKi,bIY,gKi,c6a,gKi,btm,gKi,cSN,gKi,btc,gKi,bU8,gKi,bV8,gKi,bnM,gKi,cn4,gKi,eeh,gKi,dD9,gKi,c1q,gKi,b06,gKi,aUT,gKi,cCX,gKi,c3n,gKi,abN,gKi,bP0,gKi,a4i,gKi,clQ,gKi,Zf,gKi,aV6,gKi,fj2,gKi,Zw,gKi,ctA,gKi,aQ5,gKi,aTC,gKi,b6M,gKi,bOM,gKi,caG,gKi,cqe,gKi,bNK,gKi,ezq,gKi,adG,gKi,ZM,gKi,bOk,gKi,cCi,gKi,c$H,gKi,bu6,gKi,chu,gKi,ap9,gKi,e_K,gKi,aZU,gKi,abH,gKi,cpw,gKi,eJ2,gKi,eSR,gKi,a5c,gKi,cGP,gKi,cSb,gKi,b_A,gKi,cmO,gKi,bvo,gKi,ewX,gKi,cUT,gKi,bbT,gKi,fbV,gKi,bD_,gKi,apF,gKi,arS,gKi,c5p,gKi,arv,gKi,b7W,gKi,aID,gKi,b9o,gKi,aBR,gKi,_C,gKi,egB,gKi,caU,gKi,cG8,gKi,b8W,gKi,cYF,gKi,bc6,gKi,eQW,gKi,bVs,gKi,duy,gKi,bjb,gKi,dZU,gKi,bQm,gKi,aVf,gKi,c0_,gKi,bQ4,gKi,bE_,gKi,cOR,gKi,cKO,gKi,aLR,gKi,bsy,gKi,cUN,gKi,cv4,gKi,fuS,gKi,bRs,gKi,aDX,gKi,cwS,gKi,bjl,gKi,c3s,gKi,bwS,gKi,bw_,gKi,dOw,gKi,bUu,gKi,dvE,gKi,b0g,gKi,c2Q,gKi,ct6,gKi,c4j,gKi,cHI,gKi,fox,gKi,chQ,gKi,bAO,gKi,aeH,gKi,crE,gKi,$Z,gKi,eN1,gKi,aEa,gKi,ep9,gKi,b8Y,gKi,fkX,gKi,cXL,gKi,aPP,gKi,fhO,gKi,bxW,gKi,aaO,gKi,bvc,gKi,bEA,gKi,elR,gKi,eeo,gKi,bPk,gKi,cWZ,gKi,bys,gKi,cIh,gKi,ayZ,gKi,dMa,gKi,cew,gKi,fnR,gKi,fbd,gKi,c2d,gKi,bYM,gKi,gED,gKi,_E,gKi,cYZ,gKi,bU2,gKi,b5U,gKi,aBw,gKi,cZn,gKi,b7I,gKi,cgm,gKi,cv0,gKi,dwn,gKi,Xh,gKi,e1S,gKi,dho,gKi,cwW,gKi,c_f,gKi,b3E,gKi,bVG,gKi,csO,gKi,bz8,gKi,cvC,gKi,b90,gKi,eIP,gKi,dOg,gKi,bhy,gKi,dl4,gKi,dvO,gKi,gAQ,gKi,b4u,gKi,_Q,gKi,cgE,gKi,aAm,gKi,d3O,gKi,b46,gKi,ck6,gKi,avU,gKi,aUM,gKi,cr4,gKi,cZD,gKi,c4p,gKi,bkA,gKi,cys,gKi,ard,gKi,a47,gKi,aYL,gKi,elN,gKi,bAY,gKi,cng,gKi,aaA,gKi,cjk,gKi,cfc,gKi,b0I,gKi,acx,gKi,a_I,gKi,cnk,gKi,e4d,gKi,cv_,gKi,bKU,gKi,dIq,gKi,cIw,gKi,ea8,gKi,cuG,gKi,fuJ,gKi,aF$,gKi,bdG,gKi,c4I,gKi,bRU,gKi,cxm,gKi,ajy,gKi,bLc,gKi,aYn,gKi,bv2,gKi,bNE,gKi,e01,gKi,cL7,gKi,bWq,gKi,eLM,gKi,dAy,gKi,cp4,gKi,ciu,gKi,ccO,gKi,dkV,gKi,d3q,gKi,aZG,gKi,bnd,gKi,cqO,gKi,fve,gKi,bVa,gKi,bD2,gKi,eqM,gKi,ceS,gKi,aOt,gKi,coO,gKi,adu,gKi,aRV,gKi,cQB,gKi,ep3,gKi,fhj,gKi,cwE,gKi,aYj,gKi,dHS,gKi,bj4,gKi,dss,gKi,aQP,gKi,ap_,gKi,aGt,gKi,doD,gKi,cEA,gKi,c4$,gKi,cKg,gKi,cUX,gKi,bHq,gKi,eEL,gKi,bN4,gKi,btC,gKi,bUU,gKi,Y0,gKi,all,gKi,alu,gKi,e7Q,gKi,clO,gKi,bxq,gKi,bMY,gKi,aeF,gKi,cQ3,gKi,bWU,gKi,by8,gKi,aao,gKi,bS4,gKi,cHi,gKi,c3W,gKi,cX7,gKi,b5W,gKi,dKF,gKi,e0I,gKi,bzK,gKi,eLW,gKi,cvI,gKi,aSd,gKi,ct4,gKi,cwQ,gKi,bQ6,gKi,cXh,gKi,cj8,gKi,fr2,gKi,b2m,gKi,cf8,gKi,bRM,gKi,ctC,gKi,a9l,gKi,cLF,gKi,cg4,gKi,a8D,gKi,eUh,gKi,brS,gKi,b0G,gKi,c5j,gKi,aQV,gKi,cak,gKi,fjf,gKi,j6,gKi,du$,gKi,b88,gKi,c5s,gKi,bXC,gKi,cgk,gKi,c31,gKi,bWw,gKi,chk,gKi,fvs,gKi,cec,gKi,bXS,gKi,bs_,gKi,aBP,gKi,bMS,gKi,dHx,gKi,bCm,gKi,eXi,gKi,cRV,gKi,emL,gKi,bS_,gKi,cR3,gKi,c6n,gKi,dg8,gKi,Ym,gKi,cIC,gKi,b$U,gKi,c3C,gKi,bop,gKi,cl0,gKi,c6k,gKi,eGW,gKi,c2D,gKi,bsG,gKi,emv,gKi,bR2,gKi,gId,gKi,cms,gKi,eAP,gKi,dMs,gKi,eNm,gKi,cHw,gKi,cmg,gKi,efl,gKi,eM1,gKi,gGg,gKi,cQV,gKi,c5w,gKi,eMD,gKi,c5k,gKi,cjE,gKi,c0P,gKi,d$2,gKi,cnS,gKi,foz,gKi,c$D,gKi,d0n,gKi,e7e,gKi,bUC,gKi,cbY,gKi,cBi,gKi,cdA,gKi,fhz,gKi,bVu,gKi,ccQ,gKi,csS,gKi,cTf,gKi,b02,gKi,cre,gKi,b6g,gKi,fvA,gKi,$e,gKi,dsT,gKi,aef,gKi,ccU,gKi,beu,gKi,doq,gKi,chW,gKi,c5o,gKi,cOx,gKi,c5h,gKi,cOH,gKi,cpK,gKi,bFg,gKi,c6G,gKi,foL,gKi,ck4,gKi,a43,gKi,aWt,gKi,emF,gKi,bFG,gKi,e97,gKi,cWF,gKi,bP6,gKi,aS8,gKi,aIh,gKi,dGA,gKi,ebS,gKi,aok,gKi,a26,gKi,bIm,gKi,dE5,gKi,bvW,gKi,cmC,gKi,dI6,gKi,cCs,gKi,bGE,gKi,fg1,gKi,cm2,gKi,fbY,gKi,bSC,gKi,b2q,gKi,ckk,gKi,fsd,gKi,dS_,gKi,cUZ,gKi,dg2,gKi,clK,gKi,c3E,gKi,ayO,gKi,eCd,gKi,blh,gKi,a6a,gKi,aMB,gKi,gEL,gKi,aGX,gKi,bX6,gKi,d8x,gKi,aC0,gKi,dQV,gKi,cdS,gKi,flN,gKi,cUD,gKi,cGh,gKi,bOI,gKi,c5q,gKi,bKs,gKi,eIb,gKi,bNW,gKi,dF4,gKi,cRD,gKi,cGj,gKi,aEA,gKi,b_i,gKi,c2P,gKi,e30,gKi,bWE,gKi,fq0,gKi,aCh,gKi,cOr,gKi,d7a,gKi,a7G,gKi,aNz,gKi,cpC,gKi,b4w,gKi,eMV,gKi,bZc,gKi,buE,gKi,bQi,gKi,bsU,gKi,cBg,gKi,X1,gKi,bPO,gKi,eLb,gKi,eKt,gKi,bF2,gKi,e_Z,gKi,bjP,gKi,bHu,gKi,a5w,gKi,c6c,gKi,cOZ,gKi,egn,gKi,aPf,gKi,aZa,gKi,bA4,gKi,abR,gKi,cTb,gKi,awb,gKi,cmM,gKi,bBW,gKi,aAz,gKi,bNm,gKi,cVd,gKi,e44,gKi,ao1,gKi,c4M,gKi,cbo,gKi,baN,gKi,aj1,gKi,cMt,gKi,amI,gKi,cbq,gKi,d$9,gKi,eiq,gKi,d4T,gKi,bPg,gKi,bYC,gKi,dHg,gKi,axs,gKi,bQU,gKi,bOE,gKi,bZ2,gKi,eh8,gKi,Zm,gKi,azl,gKi,apn,gKi,cfS,gKi,aeN,gKi,eYt,gKi,drF,gKi,cEr,gKi,cQt,gKi,cT1,gKi,b$e,gKi,bcW,gKi,e1a,gKi,bUI,gKi,cig,gKi,aJR,gKi,cZZ,gKi,d$Z,gKi,cbI,gKi,aqE,gKi,cMf,gKi,cKR,gKi,dGf,gKi,byy,gKi,eyP,gKi,dp9,gKi,b98,gKi,ejf,gKi,bta,gKi,ckA,gKi,bZo,gKi,dDB,gKi,cRZ,gKi,acs,gKi,cHQ,gKi,cfI,gKi,bTY,gKi,cug,gKi,a39,gKi,cBy,gKi,cfY,gKi,bNi,gKi,bHk,gKi,eeW,gKi,cQF,gKi,ctO,gKi,bzm,gKi,dMc,gKi,eZu,gKi,d6i,gKi,bCS,gKi,alX,gKi,ajT,gKi,c5B,gKi,cWV,gKi,eZI,gKi,dBC,gKi,bDS,gKi,ZJ,gKi,bXu,gKi,b5_,gKi,bYm,gKi,b5a,gKi,b$A,gKi,c3c,gKi,bFu,gKi,aRD,gKi,ac5,gKi,c56,gKi,bTq,gKi,cRB,gKi,fvy,gKi,fgf,gKi,do1,gKi,aN$,gKi,ce6,gKi,cWh,gKi,e33,gKi,cm6,gKi,bXs,gKi,fnF,gKi,aGV,gKi,c5$,gKi,ayV,gKi,aiE,gKi,cfm,gKi,dTg,gKi,c03,gKi,eDw,gKi,dMe,gKi,c38,gKi,coq,gKi,$B,gKi,cjo,gKi,a4k,gKi,dQE,gKi,a3c,gKi,beT,gKi,eR8,gKi,eqI,gKi,adE,gKi,ciW,gKi,fnI,gKi,cog,gKi,c1K,gKi,d5_,gKi,dzG,gKi,epr,gKi,dQH,gKi,bDY,gKi,cSH,gKi,eeC,gKi,dpL,gKi,b5i,gKi,bRQ,gKi,cKU,gKi,dyj,gKi,bzi,gKi,cJU,gKi,c6e,gKi,cTD,gKi,b4q,gKi,cGE,gKi,aj$,gKi,bcR,gKi,cQH,gKi,d3g,gKi,aVA,gKi,dZz,gKi,bES,gKi,buS,gKi,eLj,gKi,dJh,gKi,d5x,gKi,eST,gKi,bY_,gKi,cqK,gKi,cpE,gKi,bof,gKi,bFA,gKi,b8k,gKi,cIP,gKi,cR7,gKi,bzU,gKi,cRh,gKi,d$J,gKi,eWO,gKi,c3q,gKi,ban,gKi,gAM,gKi,bOC,gKi,bzE,gKi,bWM,gKi,b5c,gKi,cA$,gKi,bF_,gKi,bMy,gKi,d3Y,gKi,fj4,gKi,ZZ,gKi,eLS,gKi,eVY,gKi,d5Y,gKi,aJh,gKi,c$R,gKi,bJe,gKi,cQr,gKi,aLD,gKi,bx2,gKi,b8q,gKi,bHE,gKi,bTg,gKi,b9K,gKi,cWp,gKi,aZB,gKi,ehp,gKi,cqy,gKi,cx6,gKi,aX$,gKi,cRn,gKi,bY8,gKi,coA,gKi,crG,gKi,aCl,gKi,aYu,gKi,d7O,gKi,c2r,gKi,bH8,gKi,aUi,gKi,c4b,gKi,acF,gKi,acZ,gKi,eof,gKi,c_5,gKi,_e,gKi,bPm,gKi,cVb,gKi,dyp,gKi,cVn,gKi,byM,gKi,cam,gKi,bK8,gKi,c6z,gKi,dtY,gKi,dJf,gKi,eoW,gKi,dIo,gKi,fdO,gKi,blz,gKi,ftN,gKi,bTO,gKi,d0p,gKi,eWe,gKi,bzC,gKi,aym,gKi,etT,gKi,X4,gKi,dF8,gKi,b$s,gKi,aYs,gKi,aye,gKi,ch2,gKi,bC6,gKi,eTp,gKi,b0U,gKi,cZP,gKi,ckc,gKi,eTc,gKi,e94,gKi,ek5,gKi,c6f,gKi,b3e,gKi,byU,gKi,b8C,gKi,bS6,gKi,b2w,gKi,c6q,gKi,aYI,gKi,bSE,gKi,eh6,gKi,baP,gKi,ctW,gKi,b2e,gKi,cFX,gKi,dC9,gKi,dhc,gKi,aag,gKi,c26,gKi,cKW,gKi,cIf,gKi,b6C,gKi,c6p,gKi,e_P,gKi,bQq,gKi,aa_,gKi,bzw,gKi,aSK,gKi,bCK,gKi,aLo,gKi,cFh,gKi,eg9,gKi,aiU,gKi,aGD,gKi,bF8,gKi,dNT,gKi,cvK,gKi,dBe,gKi,bYc,gKi,d7E,gKi,Yz,gKi,bJk,gKi,bhb,gKi,bVO,gKi,b0c,gKi,foQ,gKi,aEX,gKi,cUP,gKi,b7g,gKi,bTk,gKi,cu0,gKi,d$X,gKi,a5q,gKi,co8,gKi,b72,gKi,cI3,gKi,btG,gKi,fiq,gKi,bo9,gKi,cZ$,gKi,cGZ,gKi,gIe,gKi,cq4,gKi,clg,gKi,eSe,gKi,cOL,gKi,aDP,gKi,d7Z,gKi,bOy,gKi,b80,gKi,arV,gKi,dLV,gKi,aPv,gKi,cCJ,gKi,b92,gKi,a8X,gKi,cjy,gKi,aXk,gKi,csa,gKi,ezB,gKi,dkN,gKi,a5X,gKi,an_,gKi,bSU,gKi,cDL,gKi,dtk,gKi,faZ,gKi,ftT,gKi,eRW,gKi,cZ3,gKi,d8X,gKi,bHY,gKi,bJ2,gKi,c3j,gKi,bHg,gKi,cc2,gKi,cVh,gKi,e4a,gKi,cby,gKi,byE,gKi,cKp,gKi,dIm,gKi,cp8,gKi,buU,gKi,cET,gKi,aLP,gKi,cKw,gKi,dJ1,gKi,b$q,gKi,eEl,gKi,a_y,gKi,eoN,gKi,cB0,gKi,cIE,gKi,eRy,gKi,cjm,gKi,cJI,gKi,cTh,gKi,cGB,gKi,bDO,gKi,dla,gKi,b1c,gKi,ejw,gKi,abn,gKi,ceu,gKi,cPP,gKi,d1y,gKi,c6j,gKi,b2y,gKi,aPN,gKi,cha,gKi,cI6,gKi,bJm,gKi,cq8,gKi,cTp,gKi,b9k,gKi,aKe,gKi,bYU,gKi,acL,gKi,bQA,gKi,eTK,gKi,dUx,gKi,bs8,gKi,eWJ,gKi,cRt,gKi,Y6,gKi,crY,gKi,bW_,gKi,bUs,gKi,at4,gKi,bA_,gKi,dQM,gKi,bkL,gKi,aDd,gKi,bid,gKi,bAS,gKi,b7S,gKi,bPI,gKi,dFL,gKi,aPy,gKi,aZX,gKi,$x,gKi,cYz,gKi,aGS,gKi,eqD,gKi,bvw,gKi,csG,gKi,bws,gKi,bAG,gKi,egG,gKi,bAQ,gKi,bZM,gKi,cBJ,gKi,a60,gKi,azh,gKi,brr,gKi,apB,gKi,cSp,gKi,b6K,gKi,eS8,gKi,c5a,gKi,dMN,gKi,dQJ,gKi,c20,gKi,bHm,gKi,dMu,gKi,dJ6,gKi,bAA,gKi,bGe,gKi,duR,gKi,fhH,gKi,c4n,gKi,cIs,gKi,YY,gKi,eZj,gKi,fhb,gKi,e1k,gKi,ehT,gKi,cHa,gKi,bIi,gKi,eae,gKi,c_X,gKi,blv,gKi,epJ,gKi,cfs,gKi,coK,gKi,e_H,gKi,axA,gKi,dVT,gKi,ev$,gKi,cds,gKi,cKj,gKi,eSZ,gKi,dpy,gKi,eKJ,gKi,bOe,gKi,abF,gKi,c5b,gKi,b8o,gKi,bx0,gKi,eCX,gKi,bIU,gKi,eAY,gKi,bJK,gKi,b5A,gKi,dra,gKi,bf0,gKi,$U,gKi,bZK,gKi,b0u,gKi,$6,gKi,bza,gKi,buC,gKi,eMe,gKi,cxO,gKi,b_y,gKi,a3G,gKi,cce,gKi,cHU,gKi,b0Y,gKi,b0S,gKi,dhe,gKi,b__,gKi,btU,gKi,aph,gKi,d84,gKi,eU6,gKi,cek,gKi,aUK,gKi,fqN,gKi,cpq,gKi,bB4,gKi,aeb,gKi,dON,gKi,_4,gKi,dGV,gKi,crw,gKi,d0L,gKi,c4i,gKi,c0R,gKi,bL8,gKi,bNM,gKi,baU,gKi,dUM,gKi,anc,gKi,cdy,gKi,bjw,gKi,c_l,gKi,bKy,gKi,cVD,gKi,b3C,gKi,bty,gKi,chi,gKi,e8H,gKi,bwI,gKi,eXq,gKi,cSn,gKi,bcj,gKi,fdS,gKi,cpG,gKi,bt_,gKi,aPE,gKi,b_E,gKi,cY1,gKi,bss,gKi,aM8,gKi,cnw,gKi,dD0,gKi,bu4,gKi,cDw,gKi,c3Y,gKi,amM,gKi,a3Z,gKi,e35,gKi,bvI,gKi,aI8,gKi,buA,gKi,dFx,gKi,cBD,gKi,cEn,gKi,cmu,gKi,b5y,gKi,bMC,gKi,cGd,gKi,c2V,gKi,eVu,gKi,dk0,gKi,clo,gKi,ac9,gKi,apj,gKi,aqP,gKi,edx,gKi,b4K,gKi,cvS,gKi,_y,gKi,cqI,gKi,dNo,gKi,c4Q,gKi,cxk,gKi,dHz,gKi,eVq,gKi,dFV,gKi,cjC,gKi,cd8,gKi,cwO,gKi,dCy,gKi,bBo,gKi,cBT,gKi,bwC,gKi,cDH,gKi,akd,gKi,ZD,gKi,aYw,gKi,eYn,gKi,eD3,gKi,cso,gKi,cdW,gKi,c4U,gKi,bsm,gKi,eK$,gKi,ecu,gKi,ei7,gKi,aYY,gKi,cjS,gKi,b2M,gKi,b_4,gKi,djh,gKi,duw,gKi,ckQ,gKi,bh7,gKi,dp_,gKi,ajp,gKi,bPM,gKi,aRe,gKi,dEQ,gKi,e63,gKi,cvQ,gKi,dVu,gKi,ayM,gKi,bNA,gKi,cKD,gKi,cXt,gKi,ba3,gKi,bAa,gKi,akA,gKi,cUj,gKi,_A,gKi,aUA,gKi,cYH,gKi,dOQ,gKi,fo8,gKi,c1h,gKi,c4g,gKi,bDs,gKi,eE7,gKi,cjq,gKi,coW,gKi,dsf,gKi,bDW,gKi,bwo,gKi,cQJ,gKi,b5q,gKi,ctg,gKi,_O,gKi,$m,gKi,dL5,gKi,ep$,gKi,bz4,gKi,chc,gKi,cyq,gKi,cmS,gKi,cRl,gKi,bHK,gKi,cuE,gKi,aOy,gKi,gEw,gKi,jC,gKi,boQ,gKi,akU,gKi,eqT,gKi,eqb,gKi,eUV,gKi,cVJ,gKi,cn6,gKi,cPd,gKi,cvq,gKi,bXq,gKi,bKi,gKi,bXw,gKi,a_U,gKi,bVi,gKi,fqG,gKi,bY2,gKi,bSi,gKi,cIq,gKi,cXD,gKi,bDw,gKi,br2,gKi,cxE,gKi,efP,gKi,bvS,gKi,bxm,gKi,gBF,gKi,eGD,gKi,dul,gKi,bXG,gKi,cL3,gKi,bmQ,gKi,aam,gKi,bUO,gKi,ac7,gKi,b5g,gKi,bCY,gKi,crk,gKi,aBm,gKi,aYB,gKi,c1t,gKi,ceg,gKi,cvm,gKi,fh5,gKi,d49,gKi,Yo,gKi,aNJ,gKi,b3w,gKi,eXx,gKi,cE3,gKi,azn,gKi,bzI,gKi,csU,gKi,ctY,gKi,eo8,gKi,csW,gKi,cjc,gKi,dRf,gKi,fca,gKi,bjn,gKi,aG8,gKi,cXX,gKi,e8b,gKi,cIX,gKi,bI4,gKi,c6i,gKi,b18,gKi,bKC,gKi,bAy,gKi,ccc,gKi,_8,gKi,b_U,gKi,cZR,gKi,eMu,gKi,cC1,gKi,byK,gKi,dil,gKi,cia,gKi,b$G,gKi,Zk,gKi,co0,gKi,cR1,gKi,dw9,gKi,dEf,gKi,acT,gKi,gEG,gKi,bLu,gKi,dqH,gKi,fg9,gKi,cUt,gKi,bgL,gKi,eq2,gKi,dTF,gKi,bZm,gKi,bMO,gKi,bts,gKi,ay6,gKi,aDE,gKi,aVk,gKi,arz,gKi,eZs,gKi,cxy,gKi,el0,gKi,dEw,gKi,bLQ,gKi,dJd,gKi,dC$,gKi,b1A,gKi,bav,gKi,br6,gKi,b64,gKi,eb1,gKi,b74,gKi,bYq,gKi,aqM,gKi,b2I,gKi,c_d,gKi,dHk,gKi,fdL,gKi,fii,gKi,ay1,gKi,dQv,gKi,bLI,gKi,c3a,gKi,abe,gKi,bPQ,gKi,bEa,gKi,dBa,gKi,dSO,gKi,aoo,gKi,dRj,gKi,ad1,gKi,dja,gKi,bMI,gKi,bBa,gKi,c_T,gKi,ds1,gKi,aTi,gKi,ajm,gKi,b60,gKi,eIv,gKi,$2,gKi,ayC,gKi,aqG,gKi,bsw,gKi,ZF,gKi,b5w,gKi,c5P,gKi,_g,gKi,cxo,gKi,YF,gKi,Xr,gKi,brI,gKi,aiQ,gKi,bO2,gKi,dm6,gKi,bYk,gKi,cJv,gKi,cZb,gKi,bvq,gKi,dJN,gKi,dme,gKi,bDG,gKi,aoK,gKi,dpY,gKi,drJ,gKi,baK,gKi,dt6,gKi,eqz,gKi,aPa,gKi,cpg,gKi,bu8,gKi,fti,gKi,bvM,gKi,aTd,gKi,c5J,gKi,fng,gKi,bZg,gKi,cYb,gKi,gBA,gKi,cSd,gKi,cB2,gKi,aZR,gKi,cPD,gKi,aVt,gKi,bMo,gKi,aau,gKi,eFs,gKi,b78,gKi,bEc,gKi,c3m,gKi,c4V,gKi,ak3,gKi,ajB,gKi,cku,gKi,clS,gKi,dIv,gKi,amj,gKi,b9m,gKi,cWJ,gKi,dPI,gKi,bQo,gKi,aGL,gKi,ad7,gKi,dgW,gKi,abr,gKi,dDD,gKi,bEi,gKi,anK,gKi,cmo,gKi,fb0,gKi,dI4,gKi,c4L,gKi,aZu,gKi,d53,gKi,dm4,gKi,bxa,gKi,cbs,gKi,eD0,gKi,aup,gKi,b7c,gKi,fi7,gKi,cI8,gKi,c3A,gKi,_G,gKi,aoZ,gKi,d_n,gKi,azc,gKi,Y_,gKi,ayz,gKi,_j,gKi,aEC,gKi,bTa,gKi,aak,gKi,ewO,gKi,eDM,gKi,bBA,gKi,ciO,gKi,bOi,gKi,dUB,gKi,cHq,gKi,flb,gKi,b5k,gKi,$t,gKi,ayw,gKi,fiv,gKi,a3f,gKi,aPR,gKi,b7M,gKi,b4e,gKi,acc,gKi,cPF,gKi,ayG,gKi,aTp,gKi,a8P,gKi,bQe,gKi,dIs,gKi,d7$,gKi,es8,gKi,cOt,gKi,cd_,gKi,clY,gKi,cxa,gKi,byu,gKi,dTx,gKi,bv4,gKi,cpM,gKi,cUl,gKi,ckS,gKi,cXF,gKi,bu_,gKi,cdo,gKi,cG5,gKi,cPj,gKi,cOX,gKi,bHW,gKi,bSO,gKi,dG6,gKi,cJp,gKi,alw,gKi,bD4,gKi,eJX,gKi,c4o,gKi,$0,gKi,cVL,gKi,aZw,gKi,dHm,gKi,c4P,gKi,dTs,gKi,bEq,gKi,e8j,gKi,b$y,gKi,diH,gKi,cDk,gKi,bIq,gKi,cyw,gKi,gAl,gKi,eVT,gKi,dGC,gKi,cpO,gKi,aqn,gKi,e7$,gKi,coy,gKi,alB,gKi,fr4,gKi,cSv,gKi,adh,gKi,buq,gKi,bxE,gKi,d13,gKi,cKA,gKi,amq,gKi,avS,gKi,aB1,gKi,cYV,gKi,at6,gKi,aou,gKi,bWY,gKi,eNa,gKi,bN0,gKi,dO9,gKi,cZ5,gKi,cEW,gKi,dtP,gKi,e9o,gKi,b$E,gKi,dre,gKi,dH$,gKi,aaq,gKi,bFE,gKi,buO,gKi,bJ_,gKi,c4_,gKi,dwc,gKi,b9G,gKi,XS,gKi,cr6,gKi,YL,gKi,csI,gKi,Yx,gKi,cc6,gKi,cVV,gKi,akj,gKi,$M,gKi,c0l,gKi,WJ,gKi,bW4,gKi,bPe,gKi,eWp,gKi,bMg,gKi,cU5,gKi,cwa,gKi,adK,gKi,b6U,gKi,a4$,gKi,bLW,gKi,cUf,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi,gKi];var gq=[gKj,gKj,kn,gKj,gCs,gKj,gCp,gKj,gCF,gKj,gCD,gKj,gKj,gKj,gKj,gKj];var gr=[gKk,gKk,gJr,gKk,gD$,gKk,gC3,gKk,gDV,gKk,gDZ,gKk,gDR,gKk,gJs,gKk,gJt,gKk,gC6,gKk,gKk,gKk,gKk,gKk,gKk,gKk,gKk,gKk,gKk,gKk,gKk,gKk];var gs=[gKl,gKl,gJw,gKl];var gt=[gKm,gKm,kJ,gKm];var gu=[gKn,gKn,th,gKn,tc,gKn,ti,gKn,gpk,gKn,f_A,gKn,grw,gKn,fNs,gKn,rp,gKn,gth,gKn,rq,gKn,tE,gKn,rk,gKn,fIr,gKn,dXF,gKn,fw6,gKn,nu,gKn,nD,gKn,In,gKn,nC,gKn,fCw,gKn,ghy,gKn,gtT,gKn,f21,gKn,fDG,gKn,fYi,gKn,BB,gKn,BD,gKn,fXP,gKn,glt,gKn,Gx,gKn,vX,gKn,fPY,gKn,fAF,gKn,vY,gKn,vQ,gKn,go8,gKn,glH,gKn,fCD,gKn,gue,gKn,gon,gKn,dhw,gKn,Gc,gKn,gyg,gKn,fTc,gKn,nR,gKn,fLn,gKn,fWh,gKn,fY6,gKn,fNI,gKn,guq,gKn,xY,gKn,xN,gKn,xO,gKn,fCW,gKn,xA,gKn,xB,gKn,yf,gKn,cNk,gKn,wr,gKn,gvt,gKn,d61,gKn,C$,gKn,CY,gKn,gyd,gKn,C0,gKn,fS8,gKn,fVw,gKn,gxX,gKn,a_7,gKn,d6L,gKn,gof,gKn,e5A,gKn,e5s,gKn,d8L,gKn,fGE,gKn,Ik,gKn,f0P,gKn,rN,gKn,rI,gKn,rO,gKn,EV,gKn,gm$,gKn,fOj,gKn,gih,gKn,fKD,gKn,f_g,gKn,gs6,gKn,L9,gKn,fLU,gKn,Mb,gKn,DW,gKn,DX,gKn,DT,gKn,fQ1,gKn,f1O,gKn,fZJ,gKn,Fd,gKn,gsp,gKn,xK,gKn,fYQ,gKn,fPq,gKn,fY7,gKn,fPx,gKn,zg,gKn,y9,gKn,zh,gKn,gfm,gKn,fqc,gKn,fGA,gKn,zR,gKn,zS,gKn,cyy,gKn,fAo,gKn,ggU,gKn,fIN,gKn,fT7,gKn,f$s,gKn,fBJ,gKn,f_2,gKn,Lq,gKn,fAP,gKn,gpG,gKn,fCZ,gKn,giI,gKn,Bb,gKn,cMX,gKn,f22,gKn,FL,gKn,a0i,gKn,fC8,gKn,fym,gKn,ghs,gKn,gjj,gKn,f2L,gKn,fWG,gKn,OP,gKn,OJ,gKn,u$,gKn,OO,gKn,fJw,gKn,u0,gKn,goO,gKn,fn$,gKn,asA,gKn,ghI,gKn,gpu,gKn,au6,gKn,gqx,gKn,fjE,gKn,fQC,gKn,wv,gKn,a$l,gKn,fE1,gKn,gvY,gKn,fSX,gKn,got,gKn,GU,gKn,a$n,gKn,fP9,gKn,a0x,gKn,gvF,gKn,eBl,gKn,Qe,gKn,PF,gKn,ges,gKn,Dw,gKn,gec,gKn,Dy,gKn,fzc,gKn,glF,gKn,fKf,gKn,vh,gKn,fGa,gKn,gwk,gKn,ge3,gKn,giM,gKn,e80,gKn,gmK,gKn,fM9,gKn,gl9,gKn,fKZ,gKn,K9,gKn,fVJ,gKn,fDQ,gKn,fZ9,gKn,fLE,gKn,Cq,gKn,fX5,gKn,dX_,gKn,fFl,gKn,gsx,gKn,MO,gKn,fzC,gKn,fBT,gKn,fG8,gKn,Bw,gKn,gfP,gKn,gn5,gKn,vD,gKn,dXW,gKn,fA8,gKn,gfE,gKn,gsf,gKn,J3,gKn,eNC,gKn,fNA,gKn,a_3,gKn,fYo,gKn,WQ,gKn,de1,gKn,fSq,gKn,gmT,gKn,cy$,gKn,a$c,gKn,gy1,gKn,cyC,gKn,K_,gKn,gu6,gKn,fOM,gKn,e8S,gKn,fUR,gKn,fxZ,gKn,n8,gKn,n3,gKn,n9,gKn,f0Q,gKn,fCg,gKn,vk,gKn,gwM,gKn,fJE,gKn,fD1,gKn,fzi,gKn,fKY,gKn,bab,gKn,gnh,gKn,gjD,gKn,AU,gKn,grY,gKn,At,gKn,As,gKn,f$w,gKn,fZG,gKn,oY,gKn,o2,gKn,gq0,gKn,o1,gKn,gwJ,gKn,fQS,gKn,fBx,gKn,fWp,gKn,sW,gKn,Vu,gKn,fRu,gKn,nq,gKn,fTK,gKn,giy,gKn,fFm,gKn,sV,gKn,fRe,gKn,fK$,gKn,f0U,gKn,fQf,gKn,fTG,gKn,ggj,gKn,goY,gKn,qB,gKn,Op,gKn,Oq,gKn,Ay,gKn,Av,gKn,fGF,gKn,f24,gKn,axK,gKn,gg$,gKn,fRq,gKn,czK,gKn,qU,gKn,gtp,gKn,fM6,gKn,d6C,gKn,fZP,gKn,gmh,gKn,dWP,gKn,f1p,gKn,fJX,gKn,vW,gKn,a$x,gKn,fVB,gKn,Dq,gKn,gr0,gKn,Rk,gKn,fMW,gKn,K0,gKn,fPw,gKn,fDm,gKn,Mt,gKn,fKG,gKn,Mr,gKn,f1C,gKn,gyo,gKn,nS,gKn,nT,gKn,nN,gKn,Dz,gKn,fNo,gKn,gf7,gKn,eND,gKn,gvL,gKn,zd,gKn,gqn,gKn,fTJ,gKn,fzy,gKn,mS,gKn,fXF,gKn,rv,gKn,ru,gKn,rF,gKn,fHy,gKn,fOn,gKn,oA,gKn,oE,gKn,pj,gKn,oD,gKn,guz,gKn,Ix,gKn,Iz,gKn,fGU,gKn,dWN,gKn,cy5,gKn,fTF,gKn,fBg,gKn,yW,gKn,yV,gKn,fE7,gKn,wG,gKn,grf,gKn,fIo,gKn,c2L,gKn,ET,gKn,EX,gKn,uf,gKn,NW,gKn,zI,gKn,zK,gKn,gip,gKn,gxi,gKn,fLh,gKn,mI,gKn,gxj,gKn,fL5,gKn,gkl,gKn,cyO,gKn,fJ2,gKn,eKd,gKn,fPt,gKn,czp,gKn,fFo,gKn,fGm,gKn,dLm,gKn,xL,gKn,xG,gKn,xM,gKn,diw,gKn,f3$,gKn,grL,gKn,Qw,gKn,Nz,gKn,NL,gKn,cMI,gKn,dXX,gKn,dWM,gKn,gwW,gKn,f_a,gKn,ggM,gKn,fmu,gKn,grO,gKn,fF2,gKn,fQJ,gKn,gtx,gKn,f1y,gKn,glm,gKn,fMj,gKn,f1Z,gKn,fOz,gKn,f2D,gKn,Td,gKn,fJQ,gKn,gt3,gKn,fmr,gKn,fK1,gKn,fGs,gKn,Ky,gKn,Cj,gKn,cNz,gKn,Pb,gKn,Pc,gKn,ER,gKn,fIn,gKn,f3D,gKn,fBP,gKn,gx2,gKn,gwc,gKn,Ch,gKn,fHo,gKn,fXu,gKn,H7,gKn,H9,gKn,fEk,gKn,gp3,gKn,goL,gKn,f04,gKn,fQj,gKn,yd,gKn,fUX,gKn,yb,gKn,fMn,gKn,fLH,gKn,Na,gKn,Ao,gKn,gxT,gKn,yn,gKn,gmv,gKn,dXa,gKn,gvx,gKn,fEx,gKn,f1t,gKn,fz_,gKn,de_,gKn,f1o,gKn,a2f,gKn,gem,gKn,cyZ,gKn,Ld,gKn,Ll,gKn,Lk,gKn,e$x,gKn,giU,gKn,gkm,gKn,fSI,gKn,fEG,gKn,fVX,gKn,a0b,gKn,CU,gKn,dWu,gKn,BJ,gKn,fDT,gKn,f31,gKn,fFw,gKn,cyP,gKn,Cr,gKn,Co,gKn,gxH,gKn,cME,gKn,gsF,gKn,MP,gKn,MI,gKn,MQ,gKn,gyX,gKn,fYX,gKn,gi_,gKn,DZ,gKn,gfw,gKn,op,gKn,ghh,gKn,f17,gKn,dmN,gKn,IX,gKn,fUv,gKn,f1w,gKn,Qo,gKn,fFt,gKn,fBr,gKn,wC,gKn,fHz,gKn,eNI,gKn,fJd,gKn,Gl,gKn,Gg,gKn,Gm,gKn,pi,gKn,gul,gKn,N2,gKn,dK1,gKn,fzq,gKn,gqI,gKn,fOA,gKn,fLb,gKn,fXG,gKn,cMZ,gKn,fV7,gKn,gtH,gKn,fBF,gKn,P0,gKn,PU,gKn,P$,gKn,gnp,gKn,Hg,gKn,fIZ,gKn,fPp,gKn,gyx,gKn,gq8,gKn,fTA,gKn,o0,gKn,fTN,gKn,gpV,gKn,dWh,gKn,geF,gKn,a0w,gKn,fTR,gKn,gpc,gKn,g9,gKn,gwv,gKn,f2M,gKn,fDn,gKn,fQT,gKn,fqf,gKn,gvp,gKn,rP,gKn,asG,gKn,gka,gKn,fMG,gKn,qC,gKn,qv,gKn,qD,gKn,f2r,gKn,gv2,gKn,fZ_,gKn,y4,gKn,f0S,gKn,gh6,gKn,gyD,gKn,fPV,gKn,fHv,gKn,fDJ,gKn,d6I,gKn,gmp,gKn,f4E,gKn,fEX,gKn,gr8,gKn,giv,gKn,z_,gKn,fzS,gKn,f$d,gKn,fKA,gKn,fB5,gKn,dYm,gKn,fKd,gKn,fFf,gKn,wU,gKn,dX6,gKn,fHa,gKn,fGH,gKn,fZF,gKn,fSi,gKn,f4C,gKn,fLI,gKn,fGX,gKn,gm3,gKn,fFc,gKn,gyR,gKn,f$r,gKn,ggN,gKn,fRh,gKn,gnW,gKn,e19,gKn,fFK,gKn,oC,gKn,fDa,gKn,Gw,gKn,dWZ,gKn,f27,gKn,gwy,gKn,Jv,gKn,fAC,gKn,fN$,gKn,LO,gKn,f38,gKn,go5,gKn,f$9,gKn,e8Z,gKn,Hj,gKn,gqO,gKn,rb,gKn,Dh,gKn,f05,gKn,f18,gKn,gk2,gKn,e$t,gKn,fCT,gKn,fRL,gKn,gi7,gKn,fGp,gKn,fHf,gKn,gxe,gKn,gjv,gKn,fLx,gKn,fxT,gKn,gnv,gKn,fWr,gKn,cM5,gKn,e$F,gKn,uV,gKn,uP,gKn,uU,gKn,fS0,gKn,fNe,gKn,fMs,gKn,fSE,gKn,a$0,gKn,czy,gKn,L6,gKn,L7,gKn,L$,gKn,gtF,gKn,fPA,gKn,kO,gKn,fza,gKn,fSG,gKn,e5B,gKn,gge,gKn,gnY,gKn,fMw,gKn,fYt,gKn,fFU,gKn,A6,gKn,gsm,gKn,Q8,gKn,fHp,gKn,gfp,gKn,fOC,gKn,cM$,gKn,fJr,gKn,gq4,gKn,fZu,gKn,dLd,gKn,gnF,gKn,fUS,gKn,fIM,gKn,gv8,gKn,fX1,gKn,fEt,gKn,gsL,gKn,gmw,gKn,f2Y,gKn,gmd,gKn,gie,gKn,ggy,gKn,fQx,gKn,fKq,gKn,fW_,gKn,d6U,gKn,eKe,gKn,uM,gKn,uH,gKn,fXx,gKn,fOw,gKn,fLG,gKn,sq,gKn,Lj,gKn,fSF,gKn,gpW,gKn,Ke,gKn,HA,gKn,HB,gKn,eQO,gKn,f$U,gKn,f0E,gKn,CV,gKn,CW,gKn,glY,gKn,fSm,gKn,gkB,gKn,dWF,gKn,PA,gKn,dYd,gKn,PB,gKn,qL,gKn,dW$,gKn,qJ,gKn,gjo,gKn,fEd,gKn,fSL,gKn,He,gKn,Hf,gKn,G6,gKn,fG2,gKn,f$B,gKn,ghY,gKn,Kx,gKn,Ku,gKn,oS,gKn,oV,gKn,dX9,gKn,f4X,gKn,gkY,gKn,E5,gKn,E7,gKn,w2,gKn,w1,gKn,xc,gKn,e2j,gKn,fNn,gKn,fGf,gKn,fAK,gKn,glc,gKn,grn,gKn,gg2,gKn,f_z,gKn,P9,gKn,f2h,gKn,qE,gKn,glA,gKn,fCK,gKn,ghp,gKn,fMi,gKn,fRS,gKn,fRg,gKn,eNK,gKn,ggv,gKn,Gk,gKn,rE,gKn,zt,gKn,fI1,gKn,fWP,gKn,N4,gKn,N_,gKn,nc,gKn,dXC,gKn,nd,gKn,N3,gKn,B8,gKn,fz5,gKn,fsv,gKn,goA,gKn,fWU,gKn,fQv,gKn,gl2,gKn,oq,gKn,asK,gKn,cNE,gKn,fya,gKn,ou,gKn,e5t,gKn,gu_,gKn,fUm,gKn,fCm,gKn,fjD,gKn,gpT,gKn,fRx,gKn,ub,gKn,gyF,gKn,fGb,gKn,fQX,gKn,s8,gKn,pa,gKn,d6$,gKn,gj_,gKn,y0,gKn,a2K,gKn,DH,gKn,sb,gKn,gvh,gKn,fQz,gKn,fVI,gKn,a4H,gKn,gsu,gKn,f_6,gKn,gui,gKn,wQ,gKn,axT,gKn,z8,gKn,gqr,gKn,Nx,gKn,f0v,gKn,Nw,gKn,tH,gKn,f_T,gKn,a2o,gKn,gqd,gKn,gxw,gKn,ghR,gKn,IA,gKn,fp1,gKn,ag3,gKn,gmq,gKn,f_f,gKn,fGw,gKn,fDI,gKn,gfH,gKn,dXx,gKn,N5,gKn,fw_,gKn,fYI,gKn,gsR,gKn,gf9,gKn,glQ,gKn,fJO,gKn,ghx,gKn,gp2,gKn,gpj,gKn,grz,gKn,dW5,gKn,fn7,gKn,fZg,gKn,gtc,gKn,cMy,gKn,fKk,gKn,dWi,gKn,gkL,gKn,fCt,gKn,gyL,gKn,gtO,gKn,f3p,gKn,rn,gKn,fHP,gKn,Bm,gKn,Lh,gKn,a2k,gKn,fCC,gKn,ut,gKn,ui,gKn,uj,gKn,e8T,gKn,guf,gKn,dfx,gKn,fY2,gKn,fDC,gKn,Ph,gKn,ghc,gKn,fX3,gKn,fLk,gKn,fVx,gKn,fYm,gKn,f3W,gKn,fQi,gKn,e6e,gKn,Lp,gKn,eHl,gKn,au9,gKn,glK,gKn,JP,gKn,JQ,gKn,Gb,gKn,gyl,gKn,fTY,gKn,fUU,gKn,geu,gKn,mT,gKn,fM2,gKn,dHF,gKn,ggX,gKn,fEl,gKn,fNO,gKn,f$5,gKn,dfB,gKn,uT,gKn,fU0,gKn,fDX,gKn,a$B,gKn,fFe,gKn,fWA,gKn,AL,gKn,AI,gKn,fGu,gKn,fMY,gKn,fSK,gKn,gvM,gKn,gjQ,gKn,L5,gKn,gik,gKn,gfW,gKn,c2F,gKn,goc,gKn,ag7,gKn,xv,gKn,a0u,gKn,f$Z,gKn,f_8,gKn,fOP,gKn,fFX,gKn,dWc,gKn,fZ0,gKn,gs5,gKn,eDu,gKn,fy2,gKn,gna,gKn,yP,gKn,fMo,gKn,gfj,gKn,gnx,gKn,HL,gKn,g2,gKn,P7,gKn,gmE,gKn,Q$,gKn,a$P,gKn,ze,gKn,a2r,gKn,fKX,gKn,aHF,gKn,fZ5,gKn,uL,gKn,dWO,gKn,FW,gKn,FV,gKn,yx,gKn,fP6,gKn,yy,gKn,ys,gKn,f$c,gKn,fVn,gKn,gsZ,gKn,x4,gKn,x5,gKn,x$,gKn,Ck,gKn,Kg,gKn,Ka,gKn,fAS,gKn,gpH,gKn,Kf,gKn,czJ,gKn,QF,gKn,giJ,gKn,fJT,gKn,PL,gKn,gen,gKn,ghL,gKn,czP,gKn,e2u,gKn,gw7,gKn,gqA,gKn,f32,gKn,f3j,gKn,gjg,gKn,eQJ,gKn,czD,gKn,gv$,gKn,fTH,gKn,fQs,gKn,fVM,gKn,gtY,gKn,fzs,gKn,fpM,gKn,sN,gKn,sC,gKn,sD,gKn,fIQ,gKn,cNB,gKn,a0t,gKn,JL,gKn,fEe,gKn,eE9,gKn,A0,gKn,Rv,gKn,dXo,gKn,gwj,gKn,fXf,gKn,fWe,gKn,a97,gKn,gi$,gKn,Dt,gKn,PG,gKn,ggJ,gKn,fJz,gKn,fyE,gKn,B9,gKn,B2,gKn,Ca,gKn,cMJ,gKn,JC,gKn,asv,gKn,JB,gKn,fn4,gKn,fWC,gKn,fZl,gKn,fHY,gKn,gsA,gKn,guG,gKn,eKa,gKn,fzz,gKn,gmH,gKn,fM4,gKn,f4T,gKn,gn2,gKn,gxQ,gKn,DY,gKn,fHL,gKn,f2g,gKn,nt,gKn,s7,gKn,fW9,gKn,fYE,gKn,gmO,gKn,fBQ,gKn,IY,gKn,gfM,gKn,czk,gKn,f1B,gKn,fE_,gKn,gu3,gKn,fT5,gKn,gse,gKn,aDs,gKn,axR,gKn,fXo,gKn,f_Z,gKn,fCb,gKn,Aj,gKn,Ad,gKn,Ai,gKn,fJu,gKn,Du,gKn,fEc,gKn,fSN,gKn,fjK,gKn,a2s,gKn,fUi,gKn,KM,gKn,Nv,gKn,czQ,gKn,f$8,gKn,Jw,gKn,Qz,gKn,gxE,gKn,fO1,gKn,fyH,gKn,gwP,gKn,gkN,gKn,kU,gKn,grZ,gKn,dQp,gKn,giD,gKn,gj7,gKn,gq3,gKn,fNV,gKn,czf,gKn,fyZ,gKn,Lu,gKn,a_9,gKn,fmi,gKn,Jc,gKn,Jd,gKn,f4P,gKn,fSy,gKn,fTq,gKn,ggk,gKn,go$,gKn,x7,gKn,dWY,gKn,fLs,gKn,Gq,gKn,Hy,gKn,ghF,gKn,f$_,gKn,fOq,gKn,uG,gKn,pN,gKn,gsv,gKn,fIq,gKn,fGo,gKn,ggY,gKn,fAj,gKn,oa,gKn,fmJ,gKn,goi,gKn,fRa,gKn,Er,gKn,Eq,gKn,fKH,gKn,fzV,gKn,fFP,gKn,gmk,gKn,glq,gKn,gut,gKn,f4w,gKn,gnU,gKn,dW8,gKn,gvI,gKn,fLJ,gKn,fQB,gKn,Dx,gKn,wt,gKn,fJW,gKn,wo,gKn,gvs,gKn,czv,gKn,gra,gKn,czn,gKn,a$6,gKn,gqk,gKn,ger,gKn,fEO,gKn,fp0,gKn,a9V,gKn,fKU,gKn,deT,gKn,guw,gKn,o3,gKn,o6,gKn,fBY,gKn,f2X,gKn,eXG,gKn,gvU,gKn,fRQ,gKn,axQ,gKn,dWj,gKn,d75,gKn,Bz,gKn,fCM,gKn,gxm,gKn,fGg,gKn,xy,gKn,xp,gKn,fRI,gKn,xx,gKn,a4A,gKn,gk9,gKn,f4x,gKn,hj,gKn,m3,gKn,a0s,gKn,fX4,gKn,fGj,gKn,grG,gKn,gki,gKn,a$8,gKn,dWw,gKn,a1c,gKn,fLu,gKn,qO,gKn,fWi,gKn,grT,gKn,fYn,gKn,yR,gKn,yL,gKn,yQ,gKn,ul,gKn,f3l,gKn,um,gKn,cz1,gKn,gxb,gKn,e2h,gKn,f_q,gKn,yT,gKn,gt4,gKn,yw,gKn,fF8,gKn,fTn,gKn,fBM,gKn,Cl,gKn,QY,gKn,ght,gKn,QR,gKn,Cm,gKn,Ci,gKn,QZ,gKn,W5,gKn,hr,gKn,D$,gKn,fV$,gKn,cM9,gKn,fwt,gKn,fwb,gKn,fZe,gKn,fGy,gKn,nb,gKn,geE,gKn,f3E,gKn,gpD,gKn,gx5,gKn,gmu,gKn,dXh,gKn,czZ,gKn,goI,gKn,f4s,gKn,dXs,gKn,gyH,gKn,f1Q,gKn,yJ,gKn,yK,gKn,gos,gKn,fXn,gKn,eVz,gKn,Li,gKn,a$N,gKn,f1T,gKn,f0g,gKn,gvy,gKn,gj2,gKn,f$g,gKn,PH,gKn,PI,gKn,PC,gKn,ED,gKn,dfI,gKn,dLl,gKn,fWt,gKn,fIc,gKn,f$p,gKn,f0f,gKn,giT,gKn,fQE,gKn,NK,gKn,deW,gKn,Cp,gKn,MN,gKn,fZH,gKn,fRE,gKn,RA,gKn,f1u,gKn,fA1,gKn,gfD,gKn,HQ,gKn,B4,gKn,dW6,gKn,qj,gKn,fIs,gKn,ql,gKn,AK,gKn,fP_,gKn,fZf,gKn,MU,gKn,I_,gKn,IU,gKn,MS,gKn,a2l,gKn,IZ,gKn,gfU,gKn,fEK,gKn,f29,gKn,e9B,gKn,fOR,gKn,cyQ,gKn,ghi,gKn,fNv,gKn,gpw,gKn,Ah,gKn,gy4,gKn,fH0,gKn,fVf,gKn,fzl,gKn,gqL,gKn,gje,gKn,fAa,gKn,fQy,gKn,yH,gKn,oQ,gKn,goF,gKn,f4M,gKn,f4j,gKn,fGB,gKn,axO,gKn,cz5,gKn,yA,gKn,fmQ,gKn,gkV,gKn,fBE,gKn,gnk,gKn,wS,gKn,gjy,gKn,Rs,gKn,fE$,gKn,cMN,gKn,gwG,gKn,EI,gKn,cMW,gKn,f1P,gKn,gwu,gKn,fUu,gKn,fcR,gKn,fVq,gKn,gkd,gKn,fXp,gKn,y3,gKn,fO2,gKn,DN,gKn,z9,gKn,f1f,gKn,f0A,gKn,gv7,gKn,f_K,gKn,fw7,gKn,fEQ,gKn,fGS,gKn,cM2,gKn,fzK,gKn,qA,gKn,asC,gKn,fLt,gKn,fQq,gKn,evd,gKn,fW0,gKn,fH6,gKn,f28,gKn,fFz,gKn,vN,gKn,f40,gKn,fzN,gKn,Fl,gKn,auO,gKn,ag6,gKn,B1,gKn,fI7,gKn,fNu,gKn,fWR,gKn,gr7,gKn,fMR,gKn,N6,gKn,f2V,gKn,Bi,gKn,fGx,gKn,ws,gKn,gm4,gKn,nQ,gKn,fB8,gKn,f1b,gKn,t7,gKn,t6,gKn,uh,gKn,gf2,gKn,gzb,gKn,gnM,gKn,fUt,gKn,OV,gKn,OX,gKn,fYV,gKn,guE,gKn,fK9,gKn,gyS,gKn,w6,gKn,fSD,gKn,fPR,gKn,fF1,gKn,fUp,gKn,fFW,gKn,fBd,gKn,pS,gKn,gea,gKn,wc,gKn,wm,gKn,dNg,gKn,fHm,gKn,fPN,gKn,GL,gKn,grS,gKn,gwD,gKn,dWT,gKn,gk1,gKn,gru,gKn,a2u,gKn,EU,gKn,iw,gKn,geh,gKn,fT3,gKn,fqd,gKn,BO,gKn,tU,gKn,Dn,gKn,fS7,gKn,Ri,gKn,gwZ,gKn,fLy,gKn,fmk,gKn,fp$,gKn,gi4,gKn,fZ2,gKn,fUg,gKn,Ey,gKn,En,gKn,tP,gKn,dXS,gKn,ggR,gKn,gnu,gKn,fPL,gKn,gjI,gKn,tZ,gKn,eNz,gKn,t_,gKn,gtA,gKn,fO$,gKn,zF,gKn,fFO,gKn,glj,gKn,QX,gKn,P_,gKn,fRM,gKn,fGM,gKn,L4,gKn,zz,gKn,zy,gKn,F7,gKn,fMO,gKn,ty,gKn,tz,gKn,tJ,gKn,fZT,gKn,Ny,gKn,gma,gKn,HJ,gKn,fM0,gKn,a0f,gKn,fKt,gKn,Fv,gKn,Fx,gKn,fIG,gKn,Qy,gKn,asy,gKn,hN,gKn,fx3,gKn,fU6,gKn,gp6,gKn,a$M,gKn,e5c,gKn,Qh,gKn,fM_,gKn,f3_,gKn,guO,gKn,rU,gKn,r_,gKn,rZ,gKn,cy4,gKn,gpX,gKn,fpE,gKn,gl$,gKn,dfM,gKn,PV,gKn,a4q,gKn,gvo,gKn,fRi,gKn,fD2,gKn,f3L,gKn,GM,gKn,f0R,gKn,fXH,gKn,gey,gKn,fA9,gKn,fDb,gKn,Hb,gKn,m0,gKn,fHN,gKn,gh$,gKn,fN6,gKn,cMY,gKn,gkZ,gKn,fQ9,gKn,fRl,gKn,ggx,gKn,glD,gKn,f3H,gKn,I9,gKn,gpE,gKn,grk,gKn,I2,gKn,Mk,gKn,Mi,gKn,fJP,gKn,fSW,gKn,fTf,gKn,Hx,gKn,Hr,gKn,e5y,gKn,Hw,gKn,Ea,gKn,qF,gKn,dK9,gKn,fBu,gKn,f3n,gKn,fz2,gKn,deR,gKn,fWE,gKn,fMA,gKn,f_I,gKn,dXq,gKn,f1i,gKn,fCn,gKn,eNF,gKn,gox,gKn,gtq,gKn,M5,gKn,fMy,gKn,M_,gKn,M6,gKn,gyA,gKn,fUQ,gKn,Hm,gKn,Ez,gKn,gxV,gKn,ov,gKn,e6c,gKn,fVl,gKn,dXy,gKn,gj$,gKn,f36,gKn,fDc,gKn,gpU,gKn,fVs,gKn,fEN,gKn,fT1,gKn,f$m,gKn,guh,gKn,Ce,gKn,z3,gKn,Ab,gKn,fmq,gKn,Aa,gKn,a7a,gKn,fOk,gKn,sh,gKn,si,gKn,fBm,gKn,f$O,gKn,gvk,gKn,pE,gKn,fQY,gKn,a0m,gKn,gx6,gKn,ghU,gKn,gnI,gKn,gel,gKn,f3N,gKn,gfG,gKn,QH,gKn,eQG,gKn,fSV,gKn,giL,gKn,BT,gKn,gh3,gKn,gsS,gKn,e14,gKn,f_$,gKn,f3r,gKn,LD,gKn,HW,gKn,LB,gKn,HR,gKn,HX,gKn,e5x,gKn,giq,gKn,f08,gKn,zX,gKn,z1,gKn,fYs,gKn,z0,gKn,WT,gKn,glT,gKn,ny,gKn,gkG,gKn,EK,gKn,fPu,gKn,ghA,gKn,fp_,gKn,f_4,gKn,fX0,gKn,gtf,gKn,v6,gKn,fEo,gKn,fOy,gKn,fmg,gKn,LQ,gKn,fFT,gKn,LR,gKn,LJ,gKn,fLd,gKn,OQ,gKn,ffZ,gKn,fAq,gKn,dXJ,gKn,fKT,gKn,wH,gKn,gop,gKn,fYO,gKn,Ak,gKn,q4,gKn,dkq,gKn,fRf,gKn,Jx,gKn,Jy,gKn,fAz,gKn,cy6,gKn,fCQ,gKn,a4K,gKn,f2c,gKn,fCF,gKn,e2p,gKn,vw,gKn,gqT,gKn,dLn,gKn,fVN,gKn,fAY,gKn,cyB,gKn,gqp,gKn,JX,gKn,uS,gKn,f0W,gKn,fPU,gKn,Rx,gKn,gjs,gKn,GY,gKn,fNU,gKn,fmK,gKn,gvP,gKn,deV,gKn,CT,gKn,f0j,gKn,gf$,gKn,fCr,gKn,AY,gKn,fWQ,gKn,d63,gKn,gn$,gKn,fW7,gKn,f$o,gKn,asQ,gKn,fMK,gKn,gjN,gKn,gin,gKn,fRz,gKn,f0r,gKn,gs8,gKn,fy3,gKn,gnb,gKn,KQ,gKn,a0r,gKn,qK,gKn,czX,gKn,fpR,gKn,fZd,gKn,gsj,gKn,mM,gKn,gib,gKn,fEh,gKn,fZD,gKn,G2,gKn,gqY,gKn,ggF,gKn,auN,gKn,cNb,gKn,gny,gKn,fIE,gKn,fXi,gKn,fS6,gKn,fYN,gKn,gsG,gKn,a$p,gKn,fSo,gKn,gmB,gKn,gsW,gKn,so,gKn,gf1,gKn,s1,gKn,s2,gKn,fMg,gKn,fSJ,gKn,fLN,gKn,gw4,gKn,fSQ,gKn,rY,gKn,fmy,gKn,gjl,gKn,A$,gKn,fJS,gKn,fEv,gKn,ghK,gKn,fNh,gKn,fUr,gKn,fzr,gKn,czs,gKn,gkE,gKn,fIb,gKn,fSt,gKn,fNg,gKn,fAH,gKn,fD3,gKn,dWa,gKn,m2,gKn,mY,gKn,fGh,gKn,BP,gKn,m1,gKn,Qc,gKn,Qb,gKn,O4,gKn,O3,gKn,fCJ,gKn,glf,gKn,fV_,gKn,fD$,gKn,I8,gKn,gg5,gKn,d_L,gKn,f_P,gKn,EL,gKn,fK5,gKn,fSw,gKn,fV3,gKn,fDr,gKn,Hv,gKn,f2i,gKn,B7,gKn,fHg,gKn,ggs,gKn,fH9,gKn,guL,gKn,gl7,gKn,N1,gKn,a2d,gKn,ggI,gKn,na,gKn,fRd,gKn,cNs,gKn,f3Z,gKn,B6,gKn,H$,gKn,H_,gKn,fDB,gKn,e6b,gKn,fLf,gKn,fWS,gKn,f_x,gKn,gsD,gKn,OA,gKn,fP3,gKn,fBN,gKn,M4,gKn,gfR,gKn,gxN,gKn,fE3,gKn,ot,gKn,EF,gKn,EG,gKn,EA,gKn,ow,gKn,fTl,gKn,gpM,gKn,fJp,gKn,t8,gKn,ue,gKn,ud,gKn,fM1,gKn,gsr,gKn,a$A,gKn,gup,gKn,fHT,gKn,Cg,gKn,Cc,gKn,QQ,gKn,Q0,gKn,Cf,gKn,f1A,gKn,fJM,gKn,fTy,gKn,grm,gKn,cM6,gKn,axJ,gKn,sX,gKn,eBx,gKn,gfu,gKn,dWz,gKn,fVV,gKn,fRJ,gKn,fZ7,gKn,gxB,gKn,cMP,gKn,gq6,gKn,fC7,gKn,dWd,gKn,P4,gKn,gkO,gKn,fSP,gKn,fAf,gKn,fBn,gKn,fn6,gKn,HV,gKn,z$,gKn,gej,gKn,giE,gKn,gku,gKn,cNr,gKn,gvu,gKn,aCD,gKn,Jl,gKn,a$O,gKn,Ju,gKn,dWq,gKn,gpm,gKn,czu,gKn,ggp,gKn,gtj,gKn,f0N,gKn,pP,gKn,pQ,gKn,pI,gKn,KZ,gKn,mK,gKn,e2n,gKn,fAi,gKn,fCu,gKn,a0a,gKn,fEY,gKn,gtR,gKn,BW,gKn,ghf,gKn,wn,gKn,a2H,gKn,Po,gKn,wx,gKn,fZj,gKn,glv,gKn,LP,gKn,fGD,gKn,dWr,gKn,fCx,gKn,PJ,gKn,guc,gKn,goh,gKn,Ja,gKn,d6F,gKn,fTI,gKn,fLp,gKn,fYC,gKn,Qu,gKn,gus,gKn,NU,gKn,gqh,gKn,fVd,gKn,mj,gKn,gvv,gKn,czt,gKn,gyb,gKn,gqZ,gKn,fTE,gKn,guB,gKn,fB$,gKn,fGl,gKn,fU9,gKn,eBD,gKn,Py,gKn,HG,gKn,gxl,gKn,uC,gKn,uw,gKn,uB,gKn,cNc,gKn,avd,gKn,fFE,gKn,gfA,gKn,fn5,gKn,df0,gKn,gjV,gKn,gmZ,gKn,a$Y,gKn,gs0,gKn,f_M,gKn,gve,gKn,f$6,gKn,EW,gKn,fO7,gKn,gi9,gKn,fVy,gKn,fZk,gKn,fRU,gKn,Ir,gKn,fOU,gKn,yO,gKn,gfk,gKn,dW1,gKn,fDL,gKn,f3u,gKn,grU,gKn,f2Z,gKn,fTo,gKn,fXD,gKn,fJV,gKn,fUD,gKn,fRy,gKn,fBL,gKn,fEr,gKn,e2q,gKn,zE,gKn,f3z,gKn,giG,gKn,nH,gKn,Bq,gKn,nG,gKn,yv,gKn,gt9,gKn,fWL,gKn,f1l,gKn,F8,gKn,gd8,gKn,x2,gKn,fSr,gKn,ghq,gKn,fAN,gKn,J5,gKn,J8,gKn,gy5,gKn,f2a,gKn,goM,gKn,Ml,gKn,fGc,gKn,gt$,gKn,gqz,gKn,CF,gKn,d_0,gKn,a0j,gKn,qx,gKn,gp9,gKn,fKi,gKn,gvW,gKn,TZ,gKn,f3h,gKn,cM_,gKn,dLk,gKn,fRk,gKn,a1h,gKn,fOH,gKn,f$D,gKn,mR,gKn,fzY,gKn,gyG,gKn,t5,gKn,tW,gKn,tX,gKn,HY,gKn,Qn,gKn,gyq,gKn,fG_,gKn,gwm,gKn,cNq,gKn,giO,gKn,gj1,gKn,fOo,gKn,dXK,gKn,d6M,gKn,tv,gKn,dfi,gKn,f_F,gKn,dLh,gKn,ffY,gKn,dXD,gKn,Ki,gKn,Kl,gKn,fXB,gKn,D0,gKn,fRp,gKn,auV,gKn,fzE,gKn,fM7,gKn,fIK,gKn,Bh,gKn,e2g,gKn,gn7,gKn,EE,gKn,fA6,gKn,d6Q,gKn,gpB,gKn,q_,gKn,grp,gKn,uc,gKn,fXU,gKn,gmR,gKn,fLK,gKn,dW3,gKn,e5z,gKn,gy7,gKn,IH,gKn,Iv,gKn,zf,gKn,qG,gKn,gu4,gKn,f0p,gKn,dXw,gKn,fCe,gKn,Ag,gKn,geD,gKn,hU,gKn,gwS,gKn,u8,gKn,u7,gKn,fzk,gKn,gqK,gKn,gjb,gKn,fFp,gKn,gjB,gKn,grW,gKn,Kj,gKn,Km,gKn,f$u,gKn,fHH,gKn,fJ9,gKn,fU4,gKn,xW,gKn,ur,gKn,gwH,gKn,fWD,gKn,fBz,gKn,f3O,gKn,qZ,gKn,Vo,gKn,HM,gKn,fUe,gKn,giw,gKn,fHB,gKn,fOG,gKn,fVh,gKn,v1,gKn,fYA,gKn,a1w,gKn,oz,gKn,fCq,gKn,fwI,gKn,gpe,gKn,Q7,gKn,gtK,gKn,pD,gKn,ggh,gKn,z5,gKn,goW,gKn,pO,gKn,fzH,gKn,Em,gKn,fmz,gKn,deO,gKn,gv4,gKn,fw9,gKn,rr,gKn,Rq,gKn,fJi,gKn,yF,gKn,fzQ,gKn,fQL,gKn,gmj,gKn,Pq,gKn,Pi,gKn,Pp,gKn,dXr,gKn,fMM,gKn,fV5,gKn,gr2,gKn,fEF,gKn,fMU,gKn,czE,gKn,fSs,gKn,m9,gKn,fKE,gKn,FR,gKn,FG,gKn,FH,gKn,fB3,gKn,fI9,gKn,gf5,gKn,gnP,gKn,f13,gKn,cyE,gKn,gvJ,gKn,fTd,gKn,fX9,gKn,fZM,gKn,f26,gKn,f4L,gKn,L1,gKn,fS9,gKn,fBe,gKn,fpK,gKn,nv,gKn,nx,gKn,fDs,gKn,D6,gKn,D_,gKn,D5,gKn,BH,gKn,BA,gKn,BI,gKn,grd,gKn,gwE,gKn,vT,gKn,vR,gKn,d6x,gKn,gqU,gKn,gkn,gKn,xu,gKn,grr,gKn,gi1,gKn,f$I,gKn,czx,gKn,grJ,gKn,fF7,gKn,z7,gKn,f1D,gKn,tS,gKn,tM,gKn,tR,gKn,fLD,gKn,GA,gKn,Dc,gKn,H4,gKn,a2G,gKn,fRW,gKn,yY,gKn,ggO,gKn,gjL,gKn,grM,gKn,gtD,gKn,glg,gKn,a2v,gKn,ged,gKn,drm,gKn,fOb,gKn,vd,gKn,gkP,gKn,F9,gKn,F4,gKn,Ga,gKn,KR,gKn,fEJ,gKn,fAV,gKn,QW,gKn,fXe,gKn,f3T,gKn,pG,gKn,pT,gKn,goU,gKn,e8N,gKn,czU,gKn,fHR,gKn,gx0,gKn,fX_,gKn,dYe,gKn,fII,gKn,gp1,gKn,goJ,gKn,au0,gKn,gmb,gKn,fKM,gKn,fMz,gKn,P6,gKn,ggB,gKn,P2,gKn,QP,gKn,guR,gKn,fDw,gKn,gvD,gKn,Oj,gKn,f$N,gKn,Oi,gKn,cMA,gKn,JV,gKn,n_,gKn,AW,gKn,fL7,gKn,Ly,gKn,au7,gKn,fmN,gKn,OL,gKn,OK,gKn,czN,gKn,gkz,gKn,f$C,gKn,fma,gKn,fR0,gKn,eXM,gKn,fZB,gKn,fDf,gKn,gh_,gKn,pr,gKn,fYr,gKn,fR7,gKn,gxr,gKn,fOt,gKn,gfy,gKn,J_,gKn,ghn,gKn,grh,gKn,p$,gKn,fHr,gKn,fZU,gKn,gg8,gKn,fX$,gKn,Hu,gKn,fT$,gKn,PK,gKn,fGv,gKn,fBt,gKn,eQR,gKn,cy8,gKn,fAQ,gKn,f2H,gKn,e8W,gKn,fXM,gKn,fD7,gKn,fjO,gKn,fz3,gKn,vU,gKn,goy,gKn,fZa,gKn,h8,gKn,Ho,gKn,Hh,gKn,Hp,gKn,NE,gKn,Db,gKn,C9,gKn,ME,gKn,a4D,gKn,QA,gKn,M3,gKn,fPS,gKn,gyz,gKn,fS4,gKn,fyN,gKn,mQ,gKn,f3U,gKn,gjY,gKn,f1G,gKn,gkc,gKn,fWc,gKn,v2,gKn,v3,gKn,vZ,gKn,Nj,gKn,Nh,gKn,f_C,gKn,vp,gKn,vl,gKn,gnJ,gKn,a4G,gKn,fPB,gKn,fpP,gKn,f_u,gKn,fQI,gKn,Q9,gKn,Q3,gKn,fDo,gKn,gh0,gKn,fYb,gKn,gqb,gKn,sY,gKn,f0q,gKn,wN,gKn,dWe,gKn,fHn,gKn,gfJ,gKn,Ac,gKn,e2m,gKn,fHE,gKn,git,gKn,gsP,gKn,o_,gKn,oZ,gKn,fKb,gKn,gze,gKn,d64,gKn,dWs,gKn,grF,gKn,nw,gKn,gte,gKn,fHc,gKn,gm1,gKn,su,gKn,qs,gKn,st,gKn,fK2,gKn,f_X,gKn,gyP,gKn,w3,gKn,w9,gKn,w8,gKn,wO,gKn,pR,gKn,D4,gKn,yj,gKn,gtU,gKn,zB,gKn,WU,gKn,qc,gKn,fDg,gKn,gww,gKn,d_W,gKn,fAE,gKn,e2s,gKn,auR,gKn,go7,gKn,fSj,gKn,m4,gKn,fKO,gKn,BG,gKn,fFj,gKn,fZy,gKn,Di,gKn,gqM,gKn,f$P,gKn,Rl,gKn,Rf,gKn,Dp,gKn,fA$,gKn,gk4,gKn,fCN,gKn,fRo,gKn,cM0,gKn,fzt,gKn,gtk,gKn,fTj,gKn,gr4,gKn,tT,gKn,a2I,gKn,mL,gKn,guT,gKn,tQ,gKn,NS,gKn,M8,gKn,fIw,gKn,wg,gKn,Un,gKn,y_,gKn,yU,gKn,yZ,gKn,fTw,gKn,gjp,gKn,fPH,gKn,fV4,gKn,glo,gKn,au2,gKn,dWy,gKn,gvS,gKn,gjO,gKn,deQ,gKn,PM,gKn,dLg,gKn,fy8,gKn,KS,gKn,KN,gKn,KT,gKn,czb,gKn,cyY,gKn,ggc,gKn,fXZ,gKn,qM,gKn,gsg,gKn,d6A,gKn,gx8,gKn,v5,gKn,cy9,gKn,G4,gKn,gnD,gKn,nz,gKn,sr,gKn,gsJ,gKn,fGq,gKn,sB,gKn,r7,gKn,ggA,gKn,fKo,gKn,gsX,gKn,dW0,gKn,fD5,gKn,fSk,gKn,f_b,gKn,cM3,gKn,rX,gKn,fOr,gKn,fYF,gKn,fSO,gKn,f10,gKn,fGn,gKn,glW,gKn,fLQ,gKn,gw1,gKn,f1k,gKn,asE,gKn,DF,gKn,fIB,gKn,fIv,gKn,BQ,gKn,fNk,gKn,fWg,gKn,gkW,gKn,fGN,gKn,fLZ,gKn,yC,gKn,J$,gKn,JY,gKn,J0,gKn,eIN,gKn,eQM,gKn,fNl,gKn,Id,gKn,Ie,gKn,H6,gKn,fAM,gKn,I7,gKn,fRw,gKn,gg0,gKn,fZ3,gKn,Qd,gKn,pg,gKn,ps,gKn,Ec,gKn,Ed,gKn,D7,gKn,gep,gKn,gly,gKn,A3,gKn,OT,gKn,Oc,gKn,gle,gKn,ggt,gKn,gyV,gKn,PS,gKn,gtv,gKn,tw,gKn,gl0,gKn,dXg,gKn,dCg,gKn,gxO,gKn,guY,gKn,fAs,gKn,r$,gKn,gpR,gKn,xR,gKn,fn3,gKn,xQ,gKn,Hn,gKn,a$L,gKn,fG3,gKn,gu9,gKn,Go,gKn,d_K,gKn,x8,gKn,x_,gKn,xZ,gKn,fQ3,gKn,gvj,gKn,fXj,gKn,f_t,gKn,f0i,gKn,Hc,gKn,f0V,gKn,cNy,gKn,guk,gKn,Jq,gKn,gwV,gKn,gqt,gKn,Cs,gKn,fE4,gKn,gh8,gKn,f$n,gKn,gxC,gKn,pX,gKn,pV,gKn,ghT,gKn,fPc,gKn,vn,gKn,gfv,gKn,f0M,gKn,a$7,gKn,gkT,gKn,PX,gKn,go2,gKn,fJB,gKn,dK7,gKn,fZc,gKn,f4Q,gKn,us,gKn,fSf,gKn,glO,gKn,EJ,gKn,HU,gKn,gpl,gKn,fp8,gKn,f_k,gKn,grx,gKn,qQ,gKn,gm9,gKn,gkr,gKn,gqi,gKn,w7,gKn,ts,gKn,Od,gKn,de0,gKn,Jn,gKn,c2I,gKn,gkJ,gKn,Jo,gKn,Ji,gKn,fO8,gKn,cNg,gKn,fmD,gKn,auZ,gKn,ghz,gKn,d6E,gKn,fEP,gKn,gtM,gKn,M9,gKn,eNH,gKn,gtg,gKn,Az,gKn,rs,gKn,f3y,gKn,fPh,gKn,fjL,gKn,oO,gKn,xb,gKn,fAl,gKn,fFL,gKn,fCE,gKn,gud,gKn,gok,gKn,fHG,gKn,fXy,gKn,gha,gKn,qd,gKn,GK,gKn,cM4,gKn,qe,gKn,p6,gKn,fXz,gKn,fXS,gKn,a0h,gKn,fCV,gKn,A8,gKn,au$,gKn,BM,gKn,fOJ,gKn,a$Q,gKn,glI,gKn,gmJ,gKn,fVj,gKn,fNL,gKn,gyn,gKn,fUs,gKn,Do,gKn,fLm,gKn,gxM,gKn,O1,gKn,NO,gKn,wK,gKn,NT,gKn,f$G,gKn,fmB,gKn,f0G,gKn,fPZ,gKn,gye,gKn,fPO,gKn,f4G,gKn,y$,gKn,zi,gKn,f4i,gKn,dXp,gKn,fl9,gKn,a_5,gKn,sH,gKn,gii,gKn,fEL,gKn,f1v,gKn,wT,gKn,gfY,gKn,goe,gKn,fYv,gKn,Dm,gKn,BV,gKn,BX,gKn,f_E,gKn,PR,gKn,gso,gKn,fI6,gKn,fLT,gKn,gs7,gKn,f_w,gKn,fSp,gKn,fSd,gKn,gvf,gKn,fxV,gKn,QE,gKn,gfh,gKn,Da,gKn,d79,gKn,fZZ,gKn,P8,gKn,fQm,gKn,fYT,gKn,eQN,gKn,fJh,gKn,cNn,gKn,f0o,gKn,Fp,gKn,fZx,gKn,Ni,gKn,f$h,gKn,ghr,gKn,e5k,gKn,sn,gKn,fCY,gKn,giH,gKn,Qr,gKn,goP,gKn,gpr,gKn,fmI,gKn,fQK,gKn,cyH,gKn,f1E,gKn,CG,gKn,gji,gKn,fDj,gKn,KC,gKn,KB,gKn,fVW,gKn,O9,gKn,gvZ,gKn,m$,gKn,BK,gKn,BS,gKn,BR,gKn,y7,gKn,fTb,gKn,eXH,gKn,gtW,gKn,fzu,gKn,gqC,gKn,pk,gKn,xi,gKn,Ic,gKn,fIC,gKn,hV,gKn,gou,gKn,qi,gKn,fNT,gKn,fzf,gKn,Eb,gKn,gyv,gKn,fKe,gKn,fRR,gKn,gwl,gKn,dW9,gKn,e8_,gKn,fWK,gKn,fR9,gKn,gvE,gKn,vq,gKn,Cv,gKn,gj4,gKn,gtu,gKn,auT,gKn,Th,gKn,fH8,gKn,QG,gKn,fVZ,gKn,fDP,gKn,gd9,gKn,AR,gKn,qI,gKn,qP,gKn,HE,gKn,giN,gKn,HF,gKn,Aw,gKn,Hz,gKn,fYR,gKn,a$a,gKn,GF,gKn,GE,gKn,fV6,gKn,gsy,gKn,RC,gKn,guI,gKn,fzB,gKn,fNa,gKn,gl8,gKn,fLB,gKn,fRK,gKn,f$K,gKn,ggL,gKn,Pw,gKn,fA7,gKn,gfF,gKn,fW4,gKn,cNL,gKn,fX8,gKn,fp2,gKn,WP,gKn,gmM,gKn,cNj,gKn,fHd,gKn,fBS,gKn,gfO,gKn,gn4,gKn,z2,gKn,gu1,gKn,fUB,gKn,q0,gKn,fNB,gKn,gpC,gKn,q1,gKn,qV,gKn,GQ,gKn,G5,gKn,gy2,gKn,fJ5,gKn,ggQ,gKn,Cd,gKn,fn0,gKn,dLr,gKn,fUO,gKn,fJ6,gKn,aL6,gKn,fQ2,gKn,cyI,gKn,QN,gKn,L_,gKn,LS,gKn,LZ,gKn,fqi,gKn,fWF,gKn,d_V,gKn,gjE,gKn,grX,gKn,cyG,gKn,fS_,gKn,axM,gKn,giB,gKn,Eh,gKn,gq1,gKn,fJ8,gKn,xX,gKn,fGV,gKn,il,gKn,HN,gKn,fTW,gKn,ggi,gKn,goZ,gKn,f0L,gKn,fXk,gKn,fn1,gKn,rB,gKn,rw,gKn,rC,gKn,Jm,gKn,Ns,gKn,Nq,gKn,f$4,gKn,dWp,gKn,tB,gKn,gto,gKn,gef,gKn,gg_,gKn,a99,gKn,fDl,gKn,fpD,gKn,fKF,gKn,gmm,gKn,fZz,gKn,gls,gKn,KV,gKn,eDi,gKn,gvG,gKn,I0,gKn,AH,gKn,fMX,gKn,fHk,gKn,czB,gKn,fZS,gKn,guv,gKn,fQ$,gKn,gqm,gKn,dWG,gKn,dLj,gKn,fMI,gKn,gwN,gKn,FB,gKn,guy,gKn,cMH,gKn,Ii,gKn,Ih,gKn,gx_,gKn,fTV,gKn,eJ9,gKn,fBy,gKn,gxg,gKn,BF,gKn,uz,gKn,fB_,gKn,gvg,gKn,eKf,gKn,KK,gKn,fHW,gKn,gkk,gKn,fmj,gKn,ye,gKn,fDF,gKn,gwX,gKn,fSB,gKn,J6,gKn,J9,gKn,xC,gKn,czm,gKn,fWO,gKn,grR,gKn,fN0,gKn,fPJ,gKn,It,gKn,Iu,gKn,Io,gKn,zp,gKn,cMK,gKn,f2z,gKn,gll,gKn,fKN,gKn,gt2,gKn,fTT,gKn,gty,gKn,eBH,gKn,f_i,gKn,fQW,gKn,f3f,gKn,fML,gKn,u1,gKn,fKS,gKn,u9,gKn,fVv,gKn,fXK,gKn,CE,gKn,CI,gKn,CH,gKn,a2t,gKn,fJ3,gKn,fBK,gKn,fmG,gKn,Kh,gKn,fVb,gKn,fLX,gKn,or,gKn,gx3,gKn,gwb,gKn,f4l,gKn,f_l,gKn,zT,gKn,f3i,gKn,fz$,gKn,gyJ,gKn,fDH,gKn,gnL,gKn,fFk,gKn,f1e,gKn,fHJ,gKn,fXr,gKn,cyN,gKn,f_7,gKn,fFg,gKn,fHD,gKn,Kc,gKn,ge2,gKn,Kb,gKn,gvw,gKn,GD,gKn,axL,gKn,fQ4,gKn,f3Q,gKn,f3v,gKn,AN,gKn,AT,gKn,tt,gKn,tu,gKn,to,gKn,fOh,gKn,AS,gKn,giV,gKn,HD,gKn,fSh,gKn,e$A,gKn,pz,gKn,gy_,gKn,y1,gKn,fwd,gKn,dX5,gKn,gfx,gKn,f25,gKn,q3,gKn,yz,gKn,dWQ,gKn,eDo,gKn,gmU,gKn,fYL,gKn,eQC,gKn,f2p,gKn,gxq,gKn,fMc,gKn,fJZ,gKn,ghg,gKn,zV,gKn,eQB,gKn,q$,gKn,gqX,gKn,dXe,gKn,fPb,gKn,fHS,gKn,fUL,gKn,a2q,gKn,LN,gKn,Qf,gKn,dXE,gKn,oJ,gKn,fLv,gKn,fHt,gKn,fYq,gKn,f5a,gKn,fNM,gKn,d_3,gKn,LY,gKn,f2K,gKn,fzn,gKn,fC$,gKn,fBG,gKn,gnm,gKn,dLe,gKn,cyK,gKn,gjw,gKn,Bv,gKn,bae,gKn,f07,gKn,gq9,gKn,gex,gKn,fOW,gKn,czr,gKn,MX,gKn,fVT,gKn,gtI,gKn,fDU,gKn,fpH,gKn,qX,gKn,gpb,gKn,p5,gKn,qt,gKn,fNq,gKn,HP,gKn,HH,gKn,fQn,gKn,fU_,gKn,HO,gKn,fQZ,gKn,gkf,gKn,fJy,gKn,d6V,gKn,fTx,gKn,dW_,gKn,cNF,gKn,f$e,gKn,Js,gKn,te,gKn,td,gKn,Lt,gKn,f1r,gKn,fQG,gKn,dy7,gKn,fzM,gKn,gmr,gKn,vm,gKn,fmR,gKn,rA,gKn,dXB,gKn,fKx,gKn,Fh,gKn,fW5,gKn,gh5,gKn,M0,gKn,a$V,gKn,fO5,gKn,CK,gKn,fzT,gKn,fDN,gKn,tC,gKn,Pn,gKn,f3d,gKn,fBp,gKn,fG5,gKn,gr9,gKn,fN3,gKn,fSC,gKn,nL,gKn,fOD,gKn,a0o,gKn,e$r,gKn,fB6,gKn,fKc,gKn,gf0,gKn,gnS,gKn,fn8,gKn,fHl,gKn,fTZ,gKn,fml,gKn,fZp,gKn,gpo,gKn,L3,gKn,f1L,gKn,DK,gKn,e2f,gKn,fK7,gKn,gyQ,gKn,fAB,gKn,fBb,gKn,D3,gKn,fI5,gKn,cNG,gKn,gxo,gKn,sZ,gKn,sO,gKn,sP,gKn,Mv,gKn,fOO,gKn,fwz,gKn,gwB,gKn,Ax,gKn,gk3,gKn,fCS,gKn,rJ,gKn,rK,gKn,oM,gKn,go4,gKn,gj9,gKn,wq,gKn,wp,gKn,fUz,gKn,gxd,gKn,gju,gKn,fLw,gKn,wi,gKn,wd,gKn,wj,gKn,gnR,gKn,gi6,gKn,fRO,gKn,f0l,gKn,dXV,gKn,fUM,gKn,Is,gKn,N7,gKn,NY,gKn,NZ,gKn,eBz,gKn,cMQ,gKn,gjG,gKn,gmy,gKn,fWH,gKn,AC,gKn,AB,gKn,dXG,gKn,cy2,gKn,fMH,gKn,dLa,gKn,ggf,gKn,f2J,gKn,cyX,gKn,ve,gKn,sI,gKn,asH,gKn,Md,gKn,f$Q,gKn,fME,gKn,fy9,gKn,fCL,gKn,e$E,gKn,gnE,gKn,Uk,gKn,gsl,gKn,sa,gKn,r4,gKn,r9,gKn,gid,gKn,fL8,gKn,GW,gKn,ggz,gKn,fZK,gKn,QM,gKn,fEg,gKn,fGI,gKn,gp4,gKn,fUC,gKn,fKu,gKn,fYh,gKn,Lr,gKn,f$0,gKn,Qg,gKn,FJ,gKn,FK,gKn,fKg,gKn,a1B,gKn,guM,gKn,fO_,gKn,uO,gKn,uY,gKn,Ru,gKn,asP,gKn,fET,gKn,QD,gKn,Nb,gKn,fK4,gKn,mh,gKn,gd7,gKn,glZ,gKn,K5,gKn,fP4,gKn,geo,gKn,fKl,gKn,gkC,gKn,By,gKn,f0Y,gKn,xj,gKn,fNm,gKn,fyU,gKn,D2,gKn,gxK,gKn,f$R,gKn,pq,gKn,f_j,gKn,fEq,gKn,gkX,gKn,fQR,gKn,JZ,gKn,glB,gKn,fHw,gKn,a$W,gKn,gho,gKn,Oa,gKn,fXh,gKn,gg3,gKn,dWt,gKn,fWz,gKn,fBw,gKn,fP5,gKn,fz8,gKn,n4,gKn,n5,gKn,oL,gKn,f4V,gKn,oK,gKn,fzG,gKn,vg,gKn,gu$,gKn,fAr,gKn,r0,gKn,f2B,gKn,fCl,gKn,zN,gKn,goD,gKn,gts,gKn,uW,gKn,fCB,gKn,gyC,gKn,MY,gKn,fUk,gKn,MZ,gKn,MR,gKn,gn9,gKn,wB,gKn,gjZ,gKn,wA,gKn,fL4,gKn,fDh,gKn,gt1,gKn,MG,gKn,gpS,gKn,MH,gKn,Mz,gKn,nY,gKn,nW,gKn,fVY,gKn,f_S,gKn,DG,gKn,f0F,gKn,guj,gKn,gol,gKn,oy,gKn,dWA,gKn,gqq,gKn,a$f,gKn,eQK,gKn,gv9,gKn,e2B,gKn,fmp,gKn,gvm,gKn,GR,gKn,fn_,gKn,fGT,gKn,gxz,gKn,eNG,gKn,gfs,gKn,DL,gKn,DJ,gKn,gnG,gKn,Oo,gKn,Ou,gKn,Ot,gKn,f3C,gKn,gfI,gKn,eIM,gKn,gqe,gKn,fyf,gKn,gsQ,gKn,czz,gKn,fBh,gKn,fQF,gKn,fP$,gKn,tl,gKn,OW,gKn,fPP,gKn,Rn,gKn,fYY,gKn,f4k,gKn,fEa,gKn,dXv,gKn,gf8,gKn,glR,gKn,MK,gKn,fL0,gKn,fO9,gKn,ghC,gKn,dBZ,gKn,gpg,gKn,xn,gKn,fYw,gKn,gI$,gKn,f3K,gKn,qT,gKn,ID,gKn,Iw,gKn,IE,gKn,drj,gKn,dWJ,gKn,Ba,gKn,fCs,gKn,wb,gKn,gtP,gKn,fF9,gKn,cMU,gKn,dWS,gKn,fDM,gKn,fZi,gKn,gfB,gKn,e2A,gKn,fAe,gKn,czF,gKn,fON,gKn,x9,gKn,glL,gKn,fIg,gKn,zP,gKn,fPi,gKn,zH,gKn,zO,gKn,fmM,gKn,fU3,gKn,QT,gKn,gyk,gKn,gqR,gKn,fUc,gKn,fLj,gKn,fX6,gKn,gxJ,gKn,dLt,gKn,fDu,gKn,NR,gKn,O$,gKn,wh,gKn,O0,gKn,OU,gKn,fAg,gKn,fFu,gKn,d6Z,gKn,y5,gKn,v8,gKn,fT8,gKn,GB,gKn,fPM,gKn,gvN,gKn,czj,gKn,f2G,gKn,gob,gKn,a92,gKn,eQU,gKn,fWk,gKn,f4F,gKn,gzs,gKn,dfH,gKn,gnZ,gKn,f0w,gKn,fN_,gKn,f_U,gKn,gmX,gKn,sJ,gKn,Dk,gKn,sK,gKn,sE,gKn,gil,gKn,fZQ,gKn,vj,gKn,fy1,gKn,gvc,gKn,fZL,gKn,f$J,gKn,e2b,gKn,fJc,gKn,giX,gKn,fYJ,gKn,yG,gKn,fIF,gKn,fUP,gKn,fH_,gKn,gfi,gKn,fpN,gKn,gnw,gKn,a1r,gKn,Fr,gKn,Fm,gKn,gmD,gKn,r8,gKn,f_s,gKn,fU7,gKn,guU,gKn,fpO,gKn,fAT,gKn,FP,gKn,e5D,gKn,fLL,gKn,gw6,gKn,f12,gKn,Q6,gKn,gjn,gKn,DE,gKn,fVG,gKn,goS,gKn,f$3,gKn,fTX,gKn,fE2,gKn,f3I,gKn,tK,gKn,gqB,gKn,tL,gKn,tV,gKn,dXH,gKn,fAJ,gKn,Ib,gKn,cy7,gKn,fFb,gKn,An,gKn,Am,gKn,xl,gKn,eZZ,gKn,xf,gKn,xk,gKn,yl,gKn,ym,gKn,fHj,gKn,e5q,gKn,eKc,gKn,fWu,gKn,gek,gKn,ox,gKn,vI,gKn,Rr,gKn,a0p,gKn,fF3,gKn,fzg,gKn,gwg,gKn,cy_,gKn,ggq,gKn,Gi,gKn,tk,gKn,Gh,gKn,dXL,gKn,gmG,gKn,fM5,gKn,pA,gKn,gl5,gKn,f0n,gKn,ggK,gKn,dWb,gKn,f9B,gKn,fDS,gKn,geX,gKn,e5o,gKn,fK0,gKn,fJD,gKn,nm,gKn,fJf,gKn,fY5,gKn,fWm,gKn,gsB,gKn,fZ1,gKn,fQt,gKn,gew,gKn,fEb,gKn,gfT,gKn,gn1,gKn,Px,gKn,aCT,gKn,gsb,gKn,NC,gKn,MF,gKn,fZo,gKn,gmP,gKn,fCc,gKn,f$F,gKn,de9,gKn,f1S,gKn,fH$,gKn,a_2,gKn,gu2,gKn,dYj,gKn,fT2,gKn,a$$,gKn,aCR,gKn,GS,gKn,GN,gKn,GT,gKn,f0x,gKn,ghO,gKn,LX,gKn,Os,gKn,f2N,gKn,f_D,gKn,fAu,gKn,fvW,gKn,Ul,gKn,cyz,gKn,gkM,gKn,fJ0,gKn,cyD,gKn,MD,gKn,oP,gKn,qR,gKn,giC,gKn,deU,gKn,fJY,gKn,sM,gKn,cM7,gKn,f0B,gKn,grA,gKn,fmC,gKn,ggn,gKn,gtl,gKn,fNf,gKn,rz,gKn,f1R,gKn,f1U,gKn,fEp,gKn,Of,gKn,Og,gKn,fAk,gKn,xa,gKn,M2,gKn,fI0,gKn,CJ,gKn,ghd,gKn,fzW,gKn,qb,gKn,gml,gKn,fYP,gKn,cyF,gKn,IF,gKn,CB,gKn,fN2,gKn,fCz,gKn,d6G,gKn,gua,gKn,goj,gKn,fB9,gKn,QI,gKn,guu,gKn,cA6,gKn,fPT,gKn,gnV,gKn,I$,gKn,gvH,gKn,gqj,gKn,fHF,gKn,KJ,gKn,O_,gKn,fpV,gKn,fP0,gKn,a$K,gKn,DM,gKn,guD,gKn,ES,gKn,ge0,gKn,gvV,gKn,fT_,gKn,fFa,gKn,dQd,gKn,v9,gKn,wa,gKn,v4,gKn,gxn,gKn,qa,gKn,Gs,gKn,Gu,gKn,fBX,gKn,cyS,gKn,yS,gKn,gx$,gKn,a9R,gKn,gs2,gKn,fyV,gKn,gkh,gKn,q7,gKn,q9,gKn,dX7,gKn,f4z,gKn,Kq,gKn,xD,gKn,fV2,gKn,yI,gKn,fOB,gKn,fXQ,gKn,grH,gKn,zs,gKn,zm,gKn,zr,gKn,cNf,gKn,fX7,gKn,f2n,gKn,fH7,gKn,fUN,gKn,f_1,gKn,AX,gKn,W6,gKn,uI,gKn,uJ,gKn,dWg,gKn,fMe,gKn,gt7,gKn,Me,gKn,fRr,gKn,qf,gKn,f2e,gKn,fL3,gKn,fMd,gKn,fDy,gKn,aL1,gKn,fWf,gKn,fmm,gKn,gtZ,gKn,fJR,gKn,f$H,gKn,AA,gKn,fYu,gKn,fBH,gKn,dK8,gKn,goH,gKn,gez,gKn,ffX,gKn,wI,gKn,wy,gKn,Fc,gKn,E4,gKn,fW2,gKn,io,gKn,Fb,gKn,c2H,gKn,f3w,gKn,sR,gKn,sS,gKn,nJ,gKn,f$2,gKn,gyI,gKn,dXT,gKn,fSA,gKn,QB,gKn,fF0,gKn,gys,gKn,gwo,gKn,fAR,gKn,giQ,gKn,HC,gKn,f2d,gKn,gj3,gKn,d6P,gKn,eNJ,gKn,dYf,gKn,fEf,gKn,Lo,gKn,fWJ,gKn,f_9,gKn,AQ,gKn,qN,gKn,a_6,gKn,fEB,gKn,pC,gKn,pu,gKn,pB,gKn,gy$,gKn,fZX,gKn,fZv,gKn,gxt,gKn,Pz,gKn,Pt,gKn,Lw,gKn,C3,gKn,fA4,gKn,fN7,gKn,fSU,gKn,fNw,gKn,gpz,gKn,dK2,gKn,fPD,gKn,fJk,gKn,a0q,gKn,fz9,gKn,A4,gKn,fJ4,gKn,deP,gKn,fqk,gKn,LL,gKn,fLq,gKn,gwQ,gKn,zx,gKn,fzm,gKn,a0e,gKn,f4K,gKn,gjd,gKn,gnl,gKn,gjz,gKn,dNc,gKn,dLq,gKn,goE,gKn,a$S,gKn,fOV,gKn,fJJ,gKn,gkU,gKn,fBB,gKn,Rt,gKn,gwr,gKn,Pk,gKn,IM,gKn,fUK,gKn,fGd,gKn,Ek,gKn,Ee,gKn,Ej,gKn,fJU,gKn,fSc,gKn,f3R,gKn,fKK,gKn,uN,gKn,NF,gKn,gjh,gKn,f0k,gKn,fUG,gKn,gke,gKn,fzJ,gKn,evg,gKn,kK,gKn,fKJ,gKn,El,gKn,fO3,gKn,Oe,gKn,f3t,gKn,f__,gKn,gv6,gKn,fRF,gKn,fzO,gKn,eQL,gKn,goQ,gKn,Fj,gKn,fLW,gKn,q8,gKn,Fe,gKn,Fk,gKn,fWB,gKn,fIf,gKn,grC,gKn,fMS,gKn,fMx,gKn,f1z,gKn,fDv,gKn,fZI,gKn,Bt,gKn,gsV,gKn,fO4,gKn,fKC,gKn,Et,gKn,fB1,gKn,fJL,gKn,fED,gKn,gf3,gKn,gzc,gKn,gnN,gKn,fvG,gKn,fOx,gKn,fD9,gKn,goG,gKn,xm,gKn,gm7,gKn,fK8,gKn,czY,gKn,fms,gKn,fUJ,gKn,fUF,gKn,fBc,gKn,fQp,gKn,fSM,gKn,dXU,gKn,grb,gKn,fNR,gKn,gwC,gKn,fOv,gKn,fJK,gKn,au_,gKn,zj,gKn,czO,gKn,a$z,gKn,f$M,gKn,eBv,gKn,rS,gKn,gkp,gKn,fDd,gKn,dXA,gKn,os,gKn,fFS,gKn,grt,gKn,dkr,gKn,xE,gKn,xz,gKn,xF,gKn,gi3,gKn,wl,gKn,fFh,gKn,ghM,gKn,gxa,gKn,fEw,gKn,zq,gKn,fJA,gKn,pH,gKn,gw_,gKn,p3,gKn,fQd,gKn,m5,gKn,fNP,gKn,CS,gKn,mW,gKn,f$a,gKn,gnr,gKn,gjJ,gKn,f1V,gKn,fT0,gKn,uo,gKn,gli,gKn,gv_,gKn,au8,gKn,FU,gKn,F_,gKn,FZ,gKn,czw,gKn,fLS,gKn,gtB,gKn,L8,gKn,Mg,gKn,dWL,gKn,KH,gKn,a$h,gKn,Mf,gKn,fFV,gKn,a$X,gKn,fHb,gKn,gp7,gKn,Ow,gKn,deX,gKn,zQ,gKn,dXj,gKn,zW,gKn,fSz,gKn,cyU,gKn,fNr,gKn,Fa,gKn,cMD,gKn,oi,gKn,deN,gKn,guP,gKn,oj,gKn,rt,gKn,rj,gKn,ri,gKn,f4d,gKn,nK,gKn,fIm,gKn,gvB,gKn,nF,gKn,f2m,gKn,FQ,gKn,gp_,gKn,vF,gKn,fEI,gKn,czS,gKn,DA,gKn,gkx,gKn,gf4,gKn,JF,gKn,tr,gKn,JA,gKn,JG,gKn,a$s,gKn,cNK,gKn,gxL,gKn,fIa,gKn,auP,gKn,fXX,gKn,fwF,gKn,d6Y,gKn,fjA,gKn,fyO,gKn,dYc,gKn,a$y,gKn,grj,gKn,f3g,gKn,dX8,gKn,fPW,gKn,fXv,gKn,fTv,gKn,zl,gKn,zv,gKn,dXQ,gKn,AJ,gKn,fBv,gKn,y6,gKn,ghl,gKn,fyC,gKn,tj,gKn,fR6,gKn,eDt,gKn,gyi,gKn,fz1,gKn,fQM,gKn,nn,gKn,qn,gKn,fmn,gKn,gow,gKn,fYG,gKn,MW,gKn,fR3,gKn,gxU,gKn,fH5,gKn,gtL,gKn,dLv,gKn,fCi,gKn,fQQ,gKn,a$d,gKn,fZb,gKn,f2l,gKn,QO,gKn,Ei,gKn,gyB,gKn,fUA,gKn,f2w,gKn,fQU,gKn,gwi,gKn,fU5,gKn,gjW,gKn,f$z,gKn,gvl,gKn,dWU,gKn,fWI,gKn,fZ6,gKn,f33,gKn,gnH,gKn,h7,gKn,vb,gKn,vc,gKn,u6,gKn,fVi,gKn,f0O,gKn,f0z,gKn,gh2,gKn,e5d,gKn,pM,gKn,ghV,gKn,f$f,gKn,dXi,gKn,Fi,gKn,gfL,gKn,c2G,gKn,gir,gKn,e5p,gKn,fXI,gKn,fEA,gKn,Eu,gKn,gsN,gKn,Ev,gKn,Ep,gKn,glU,gKn,fGJ,gKn,fEj,gKn,ghB,gKn,f_Q,gKn,fYg,gKn,fIJ,gKn,fRD,gKn,oe,gKn,a4E,gKn,gyN,gKn,f_r,gKn,gk6,gKn,gkH,gKn,f3P,gKn,fQ8,gKn,fyc,gKn,IG,gKn,fAy,gKn,go1,gKn,fM$,gKn,zM,gKn,fCG,gKn,GC,gKn,fJo,gKn,Br,gKn,My,gKn,fvH,gKn,Mq,gKn,Mx,gKn,fUY,gKn,fAZ,gKn,fNW,gKn,fCP,gKn,QV,gKn,f2S,gKn,fE6,gKn,yc,gKn,fAd,gKn,fTP,gKn,ePH,gKn,fPm,gKn,nP,gKn,gqS,gKn,nO,gKn,a$b,gKn,fJj,gKn,gjr,gKn,nE,gKn,fNK,gKn,gqo,gKn,fVr,gKn,fFM,gKn,fVA,gKn,uq,gKn,uk,gKn,up,gKn,gvQ,gKn,FY,gKn,a95,gKn,grs,gKn,fmo,gKn,fFJ,gKn,gjM,gKn,gf_,gKn,m7,gKn,K8,gKn,gei,gKn,gga,gKn,fZt,gKn,CX,gKn,gsi,gKn,e$s,gKn,gs9,gKn,fy6,gKn,fmT,gKn,tO,gKn,dfR,gKn,gnB,gKn,fmv,gKn,fOi,gKn,giW,gKn,dW2,gKn,fXa,gKn,fY1,gKn,gfN,gKn,dX1,gKn,gia,gKn,ggC,gKn,dYi,gKn,fKm,gKn,rG,gKn,Lf,gKn,mV,gKn,f4n,gKn,C2,gKn,f3k,gKn,f_5,gKn,f1h,gKn,fTS,gKn,fQ5,gKn,f_c,gKn,C7,gKn,F5,gKn,fPQ,gKn,qg,gKn,qm,gKn,gpL,gKn,fC_,gKn,dXO,gKn,Pf,gKn,Pa,gKn,a$i,gKn,K7,gKn,f0h,gKn,gtt,gKn,fRb,gKn,PE,gKn,fDe,gKn,PD,gKn,fLO,gKn,zA,gKn,Lx,gKn,gqE,gKn,gkF,gKn,fR8,gKn,fQc,gKn,gjk,gKn,OF,gKn,eBt,gKn,JE,gKn,fUH,gKn,yh,gKn,ya,gKn,yi,gKn,fWM,gKn,yE,gKn,a7c,gKn,ava,gKn,eKb,gKn,f1J,gKn,C4,gKn,fIV,gKn,fNj,gKn,fYU,gKn,q2,gKn,Ln,gKn,gg6,gKn,Mn,gKn,hf,gKn,Qa,gKn,Qk,gKn,IV,gKn,IW,gKn,Qm,gKn,a$5,gKn,glw,gKn,eQQ,gKn,f3J,gKn,ggr,gKn,fPg,gKn,vL,gKn,G3,gKn,dXn,gKn,czi,gKn,oI,gKn,czl,gKn,fFq,gKn,fOd,gKn,uX,gKn,cND,gKn,fVU,gKn,OS,gKn,OH,gKn,guK,gKn,OI,gKn,Ht,gKn,cMT,gKn,gl6,gKn,f$7,gKn,fQO,gKn,fKh,gKn,guW,gKn,wY,gKn,wZ,gKn,wR,gKn,K2,gKn,no,gKn,nj,gKn,np,gKn,gpP,gKn,a2n,gKn,fMk,gKn,fMN,gKn,axP,gKn,fJ1,gKn,gfQ,gKn,fS5,gKn,fjG,gKn,gsq,gKn,Q4,gKn,gum,gKn,gy8,gKn,Ew,gKn,mk,gKn,fI4,gKn,gqv,gKn,fTi,gKn,gxA,gKn,dWW,gKn,gft,gKn,Or,gKn,gkR,gKn,fpG,gKn,fmL,gKn,fSn,gKn,fV9,gKn,a4w,gKn,xT,gKn,cyL,gKn,uD,gKn,gq7,gKn,a$2,gKn,pb,gKn,glM,gKn,sL,gKn,fBo,gKn,m6,gKn,gpn,gKn,MM,gKn,grD,gKn,ggo,gKn,p1,gKn,gkt,gKn,fGk,gKn,IB,gKn,qr,gKn,gtS,gKn,fNd,gKn,fF_,gKn,gti,gKn,fER,gKn,fAG,gKn,wL,gKn,fAn,gKn,dhx,gKn,gub,gKn,a0k,gKn,gom,gKn,fmt,gKn,Mw,gKn,mP,gKn,fX2,gKn,Qx,gKn,fY3,gKn,fWx,gKn,fZm,gKn,dXt,gKn,Dr,gKn,fIP,gKn,glG,gKn,go9,gKn,oN,gKn,fCy,gKn,fyp,gKn,f09,gKn,gyh,gKn,sy,gKn,fSY,gKn,ss,gKn,fLo,gKn,sx,gKn,w4,gKn,fST,gKn,w5,gKn,vB,gKn,w_,gKn,gqg,gKn,OZ,gKn,fQ0,gKn,v7,gKn,a_8,gKn,gyc,gKn,fTU,gKn,guA,gKn,C5,gKn,gxY,gKn,fDD,gKn,fGC,gKn,f2R,gKn,fVp,gKn,gjU,gKn,gig,gKn,fpS,gKn,f0X,gKn,f0m,gKn,Kn,gKn,Ks,gKn,rx,gKn,fn9,gKn,fZ8,gKn,gm_,gKn,ry,gKn,fY4,gKn,fHs,gKn,fJH,gKn,f_0,gKn,tN,gKn,gvd,gKn,Dj,gKn,Dl,gKn,gfn,gKn,f3a,gKn,Ne,gKn,Nf,gKn,M7,gKn,fmx,gKn,gi8,gKn,ggV,gKn,uR,gKn,cz_,gKn,fZn,gKn,uQ,gKn,Np,gKn,f2U,gKn,n7,gKn,fDp,gKn,e$D,gKn,gt8,gKn,fUn,gKn,f3X,gKn,fBI,gKn,CA,gKn,gsH,gKn,Cw,gKn,Cz,gKn,f_O,gKn,KO,gKn,KP,gKn,fAO,gKn,aCS,gKn,ghH,gKn,gpt,gKn,eJ6,gKn,fFd,gKn,gwd,gKn,fEn,gKn,fWq,gKn,Pe,gKn,gvX,gKn,fD6,gKn,fOI,gKn,yg,gKn,fzw,gKn,gqw,gKn,fMa,gKn,dWB,gKn,Mp,gKn,Mh,gKn,fzZ,gKn,Mo,gKn,zw,gKn,fpL,gKn,gv1,gKn,eBC,gKn,fRZ,gKn,E9,gKn,fJF,gKn,fzd,gKn,f4u,gKn,glE,gKn,gwn,gKn,a9$,gKn,cNC,gKn,fGe,gKn,fRV,gKn,fXq,gKn,f$T,gKn,OB,gKn,gj6,gKn,pm,gKn,f2W,gKn,e8M,gKn,fVt,gKn,f_p,gKn,fEM,gKn,giP,gKn,fVC,gKn,fYl,gKn,gsw,gKn,f_N,gKn,fzD,gKn,gmL,gKn,fM8,gKn,asD,gKn,e8X,gKn,cMG,gKn,zU,gKn,O5,gKn,fA5,gKn,auS,gKn,fPy,gKn,fJl,gKn,wX,gKn,fLF,gKn,fW1,gKn,fFy,gKn,fXE,gKn,axU,gKn,gmS,gKn,fBU,gKn,fI$,gKn,gn6,gKn,fpU,gKn,D9,gKn,D8,gKn,I6,gKn,gu7,gKn,fNz,gKn,gpA,gKn,K$,gKn,gro,gKn,f4B,gKn,fCf,gKn,gy0,gKn,pc,gKn,m8,gKn,fzh,gKn,z4,gKn,z6,gKn,gja,gKn,a2p,gKn,f$L,gKn,G_,gKn,fZW,gKn,GZ,gKn,fSb,gKn,fWn,gKn,fBA,gKn,gng,gKn,gjC,gKn,vP,gKn,Bf,gKn,xU,gKn,fTu,gKn,Rm,gKn,giz,gKn,xV,gKn,f1Y,gKn,xP,gKn,CL,gKn,fOg,gKn,F6,gKn,gwK,gKn,MB,gKn,Pm,gKn,ggl,gKn,eXK,gKn,fDW,gKn,fDZ,gKn,gpd,gKn,gwq,gKn,zZ,gKn,dWE,gKn,zY,gKn,NI,gKn,fUq,gKn,NH,gKn,goX,gKn,fJg,gKn,fU1,gKn,fR4,gKn,od,gKn,f3o,gKn,fFC,gKn,Hq,gKn,fBk,gKn,fmP,gKn,p0,gKn,pU,gKn,Jt,gKn,Jr,gKn,fNc,gKn,LK,gKn,f9I,gKn,CC,gKn,fjB,gKn,gwe,gKn,fKw,gKn,f2T,gKn,fPs,gKn,eQS,gKn,zJ,gKn,Pg,gKn,gmg,gKn,fG0,gKn,fR2,gKn,fVR,gKn,gr3,gKn,fMV,gKn,ns,gKn,nh,gKn,sw,gKn,gyp,gKn,fB4,gKn,fMl,gKn,fNp,gKn,gf6,gKn,vC,gKn,fIi,gKn,vz,gKn,fTt,gKn,fXV,gKn,a2m,gKn,fpZ,gKn,gw3,gKn,fJe,gKn,fTp,gKn,fEs,gKn,gio,gKn,fQ6,gKn,gI0,gKn,fpC,gKn,gre,gKn,fpY,gKn,fB0,gKn,Kr,gKn,grq,gKn,fPX,gKn,vs,gKn,gvA,gKn,grK,gKn,fVo,gKn,eQD,gKn,fmE,gKn,fLC,gKn,fL1,gKn,gov,gKn,Nd,gKn,gi0,gKn,dLb,gKn,fJG,gKn,gmn,gKn,dX4,gKn,grP,gKn,a4x,gKn,eNE,gKn,fPK,gKn,fG9,gKn,EN,gKn,gln,gKn,f16,gKn,cNi,gKn,dfb,gKn,f$q,gKn,Bs,gKn,gnq,gKn,f2t,gKn,gt0,gKn,gtw,gKn,Cy,gKn,fGK,gKn,gm2,gKn,f1$,gKn,cyJ,gKn,fAW,gKn,s0,gKn,s6,gKn,s5,gKn,LE,gKn,t3,gKn,fRN,gKn,fPE,gKn,goV,gKn,sz,gKn,fQP,gKn,au3,gKn,pW,gKn,fLe,gKn,Gt,gKn,gx1,gKn,fYe,gKn,BC,gKn,fFH,gKn,geB,gKn,fQD,gKn,fEE,gKn,JJ,gKn,JK,gKn,gne,gKn,czh,gKn,e8V,gKn,f$y,gKn,dYg,gKn,guS,gKn,dXI,gKn,vG,gKn,dXf,gKn,gp$,gKn,JU,gKn,gvC,gKn,nI,gKn,fQw,gKn,Lv,gKn,OD,gKn,Ox,gKn,OC,gKn,gw8,gKn,x1,gKn,x0,gKn,f$S,gKn,f3c,gKn,JD,gKn,Rg,gKn,A9,gKn,gsE,gKn,a$T,gKn,BN,gKn,BL,gKn,fYH,gKn,gyY,gKn,fpI,gKn,fvT,gKn,K4,gKn,K6,gKn,gfz,gKn,H2,gKn,HZ,gKn,H3,gKn,gxI,gKn,tx,gKn,tm,gKn,gg9,gKn,fN5,gKn,tn,gKn,fYf,gKn,gxs,gKn,fC9,gKn,N8,gKn,fH2,gKn,ghm,gKn,fJb,gKn,grg,gKn,ua,gKn,fZE,gKn,t9,gKn,dYn,gKn,fUf,gKn,f1j,gKn,gqH,gKn,fyD,gKn,IC,gKn,f4a,gKn,fXW,gKn,fP8,gKn,fNN,gKn,a$E,gKn,fNS,gKn,yr,gKn,fzp,gKn,gno,gKn,fCj,gKn,Bg,gKn,fLa,gKn,a0g,gKn,er1,gKn,fSH,gKn,KU,gKn,f4g,gKn,czA,gKn,gyw,gKn,fTQ,gKn,fIS,gKn,fJs,gKn,d_6,gKn,gtG,gKn,oG,gKn,gjX,gKn,IO,gKn,IJ,gKn,IP,gKn,qS,gKn,f4o,gKn,fWs,gKn,Ae,gKn,f_m,gKn,Af,gKn,fS1,gKn,fHx,gKn,cz0,gKn,f0T,gKn,gv3,gKn,mN,gKn,fRY,gKn,d6H,gKn,f0b,gKn,dW7,gKn,NG,gKn,gqc,gKn,vS,gKn,fxW,gKn,rl,gKn,rm,gKn,p_,gKn,K1,gKn,pL,gKn,pJ,gKn,axS,gKn,fIT,gKn,fW8,gKn,gfK,gKn,W8,gKn,wM,gKn,IR,gKn,f4J,gKn,gh7,gKn,f1X,gKn,dWX,gKn,gsO,gKn,ra,gKn,cNm,gKn,E1,gKn,E_,gKn,fzR,gKn,goN,gKn,E2,gKn,gmo,gKn,AZ,gKn,czC,gKn,d6_,gKn,dLc,gKn,giu,gKn,fHZ,gKn,og,gKn,gm0,gKn,oh,gKn,fKa,gKn,gzf,gKn,gnQ,gKn,cyA,gKn,xr,gKn,fZV,gKn,f3S,gKn,fOs,gKn,cMS,gKn,gtV,gKn,G1,gKn,fQk,gKn,gyO,gKn,f$b,gKn,fVP,gKn,fP7,gKn,fMP,gKn,fAD,gKn,fGY,gKn,Gn,gKn,r2,gKn,r3,gKn,sd,gKn,fLg,gKn,a2j,gKn,fZO,gKn,gwz,gKn,fN8,gKn,gk5,gKn,fCU,gKn,go6,gKn,fSR,gKn,fS3,gKn,gxf,gKn,f$A,gKn,gqP,gKn,fA0,gKn,fFv,gKn,fTg,gKn,fC6,gKn,fJx,gKn,za,gKn,zc,gKn,fBZ,gKn,CQ,gKn,CM,gKn,CP,gKn,gvT,gKn,fWb,gKn,fQH,gKn,fJI,gKn,gtE,gKn,fmh,gKn,fVQ,gKn,un,gKn,fIh,gKn,ggd,gKn,fwY,gKn,gnX,gKn,fW$,gKn,Rb,gKn,s4,gKn,FX,gKn,f0K,gKn,fcS,gKn,fy7,gKn,gnf,gKn,goR,gKn,gnC,gKn,EY,gKn,u_,gKn,u4,gKn,czH,gKn,x3,gKn,fYd,gKn,fNy,gKn,u3,gKn,gsn,gKn,dWf,gKn,gme,gKn,AV,gKn,gif,gKn,fFx,gKn,fKp,gKn,gx9,gKn,yN,gKn,yM,gKn,gfo,gKn,fH1,gKn,vO,gKn,d6J,gKn,fXs,gKn,f$l,gKn,fT6,gKn,gsK,gKn,fXN,gKn,fD4,gKn,gmx,gKn,fl8,gKn,AE,gKn,f2x,gKn,fLc,gKn,auX,gKn,asM,gKn,fHV,gKn,Qp,gKn,fSu,gKn,Dv,gKn,fLR,gKn,DD,gKn,glX,gKn,gw0,gKn,DC,gKn,qk,gKn,sf,gKn,se,gKn,sp,gKn,fEU,gKn,fp9,gKn,e2a,gKn,fG4,gKn,f$E,gKn,f0y,gKn,pF,gKn,pt,gKn,rf,gKn,gkA,gKn,Bj,gKn,a$1,gKn,fP1,gKn,H1,gKn,fAL,gKn,asB,gKn,fmO,gKn,ghX,gKn,fPj,gKn,qu,gKn,gmW,gKn,glz,gKn,d6B,gKn,glb,gKn,gg1,gKn,dWk,gKn,fIU,gKn,fjC,gKn,fz6,gKn,fVE,gKn,fNZ,gKn,f11,gKn,gl3,gKn,fDR,gKn,guZ,gKn,fAt,gKn,wW,gKn,qp,gKn,qq,gKn,goB,gKn,fH4,gKn,f14,gKn,gyE,gKn,fQr,gKn,fDx,gKn,QK,gKn,fHU,gKn,fEZ,gKn,De,gKn,IN,gKn,gpQ,gKn,H8,gKn,ggT,gKn,LU,gKn,fNJ,gKn,gu8,gKn,dXk,gKn,Je,gKn,f_J,gKn,cyW,gKn,gxx,gKn,ghQ,gKn,d6X,gKn,gfq,gKn,gsa,gKn,fR_,gKn,cyM,gKn,wV,gKn,gqs,gKn,Ro,gKn,Rd,gKn,Re,gKn,fF$,gKn,w0,gKn,Es,gKn,df2,gKn,fZ$,gKn,ag2,gKn,Qv,gKn,f1m,gKn,gkS,gKn,p8,gKn,a$4,gKn,J1,gKn,fBj,gKn,fPf,gKn,CD,gKn,f2I,gKn,fOF,gKn,fmH,gKn,HI,gKn,HK,gKn,fZs,gKn,fA3,gKn,cMF,gKn,gm8,gKn,gkq,gKn,of,gKn,Nl,gKn,fHe,gKn,gnj,gKn,glP,gKn,gkK,gKn,ha,gKn,fFQ,gKn,ghw,gKn,fKQ,gKn,gpi,gKn,Au,gKn,fZ4,gKn,gry,gKn,gtb,gKn,fY0,gKn,erY,gKn,f0u,gKn,PY,gKn,f1_,gKn,auY,gKn,fAm,gKn,Bp,gKn,fHO,gKn,gtN,gKn,fXO,gKn,ghb,gKn,fJC,gKn,fYj,gKn,fOL,gKn,Lc,gKn,vx,gKn,d_$,gKn,glJ,gKn,fEy,gKn,f4m,gKn,gym,gKn,fUI,gKn,sv,gKn,fLl,gKn,va,gKn,fXC,gKn,fWN,gKn,eBy,gKn,wk,gKn,ml,gKn,dX$,gKn,gyf,gKn,fL2,gKn,fUE,gKn,dfj,gKn,gr1,gKn,deY,gKn,e13,gKn,dWv,gKn,fGz,gKn,f$W,gKn,fRC,gKn,A1,gKn,fMt,gKn,f0D,gKn,fVg,gKn,god,gKn,Nk,gKn,fMZ,gKn,CO,gKn,fyg,gKn,fUx,gKn,d6y,gKn,fIx,gKn,f_o,gKn,gjR,gKn,gij,gKn,gfX,gKn,gs4,gKn,eQI,gKn,gva,gKn,giZ,gKn,rh,gKn,q5,gKn,Ra,gKn,ghN,gKn,u2,gKn,fYD,gKn,auU,gKn,Fz,gKn,E6,gKn,py,gKn,fDt,gKn,gfg,gKn,dfZ,gKn,ng,gKn,fGO,gKn,fKW,gKn,fR1,gKn,eQj,gKn,fZN,gKn,dXR,gKn,gmF,gKn,AF,gKn,f06,gKn,dYo,gKn,AG,gKn,f_Y,gKn,fRv,gKn,gs_,gKn,Cx,gKn,gpI,gKn,fCX,gKn,dYa,gKn,giK,gKn,On,gKn,Oh,gKn,Om,gKn,eNy,gKn,gps,gKn,zC,gKn,fHX,gKn,DB,gKn,zD,gKn,t4,gKn,Lg,gKn,Le,gKn,uv,gKn,uu,gKn,dXu,gKn,uF,gKn,f19,gKn,fOf,gKn,fWa,gKn,f2_,gKn,mU,gKn,ghG,gKn,fTr,gKn,fQN,gKn,fV0,gKn,gtX,gKn,fNt,gKn,fzv,gKn,gqD,gKn,fIO,gKn,Nt,gKn,f1F,gKn,d_Y,gKn,JW,gKn,gev,gKn,KL,gKn,KI,gKn,KW,gKn,MJ,gKn,ML,gKn,r6,gKn,r5,gKn,f1q,gKn,hb,gKn,OG,gKn,Ov,gKn,BZ,gKn,Gf,gKn,Ge,gKn,Gp,gKn,fOu,gKn,a$_,gKn,dXd,gKn,vM,gKn,fql,gKn,au4,gKn,fFI,gKn,fKr,gKn,f2q,gKn,Mm,gKn,Qj,gKn,AM,gKn,Ql,gKn,fEu,gKn,a2i,gKn,fze,gKn,gyu,gKn,cNl,gKn,rV,gKn,rW,gKn,fpQ,gKn,BY,gKn,NV,gKn,gj5,gKn,pp,gKn,a$m,gKn,ph,gKn,po,gKn,fM3,gKn,gmI,gKn,fGW,gKn,P1,gKn,fN4,gKn,d_T,gKn,qo,gKn,eQT,gKn,fYB,gKn,fVS,gKn,cNx,gKn,gsz,gKn,f2P,gKn,fzA,gKn,fUa,gKn,guH,gKn,fBR,gKn,Hk,gKn,Hi,gKn,czR,gKn,rR,gKn,rH,gKn,gn3,gKn,gxR,gKn,gsd,gKn,cMR,gKn,fNC,gKn,C8,gKn,Dg,gKn,Df,gKn,fP2,gKn,fE9,gKn,gmN,gKn,fFn,gKn,vH,gKn,vK,gKn,gy3,gKn,asN,gKn,Hs,gKn,fG$,gKn,dYl,gKn,f4b,gKn,fKy,gKn,gu0,gKn,fUl,gKn,fUy,gKn,Q5,gKn,sj,gKn,fL$,gKn,cMM,gKn,qy,gKn,qw,gKn,gwO,gKn,f4U,gKn,fIp,gKn,Mc,gKn,gjF,gKn,gr_,gKn,t0,gKn,W7,gKn,f$$,gKn,gxF,gKn,pK,gKn,M1,gKn,M$,gKn,gq2,gKn,uE,gKn,a9I,gKn,gwL,gKn,Ft,gKn,Pr,gKn,Ps,gKn,fWV,gKn,oR,gKn,fn2,gKn,fp5,gKn,fFr,gKn,MC,gKn,MA,gKn,fTe,gKn,xS,gKn,giA,gKn,nV,gKn,n1,gKn,n0,gKn,fD_,gKn,nX,gKn,fIW,gKn,ghE,gKn,G9,gKn,fTa,gKn,p2,gKn,fIR,gKn,go_,gKn,Fq,gKn,f2k,gKn,czG,gKn,ggZ,gKn,fRB,gKn,fL_,gKn,gtn,gKn,fKI,gKn,fmS,gKn,glr,gKn,y8,gKn,f4y,gKn,zk,gKn,fpX,gKn,fMD,gKn,Rh,gKn,auW,gKn,fZC,gKn,LH,gKn,gzF,gKn,LA,gKn,LI,gKn,cM8,gKn,gql,gKn,aLX,gKn,Ls,gKn,gvr,gKn,fHQ,gKn,gux,gKn,fIu,gKn,f1c,gKn,vA,gKn,w$,gKn,gxh,gKn,f3B,gKn,fHu,gKn,gzA,gKn,gxZ,gKn,f1K,gKn,L0,gKn,L2,gKn,gkj,gKn,f4q,gKn,gk8,gKn,Nc,gKn,fWy,gKn,fYk,gKn,fIj,gKn,fLY,gKn,fMC,gKn,dWD,gKn,EQ,gKn,EM,gKn,fHi,gKn,EP,gKn,dXZ,gKn,gwY,gKn,qz,gKn,C1,gKn,f_G,gKn,grQ,gKn,fE0,gKn,f3A,gKn,fTD,gKn,gtz,gKn,nU,gKn,f_y,gKn,fss,gKn,glk,gKn,fwQ,gKn,a4v,gKn,Ol,gKn,sF,gKn,sG,gKn,gzp,gKn,gt5,gKn,a$q,gKn,fmF,gKn,Pd,gKn,ghu,gKn,fPC,gKn,dLo,gKn,f15,gKn,fVL,gKn,cNp,gKn,gx4,gKn,fKR,gKn,fY_,gKn,gwa,gKn,OE,gKn,pY,gKn,FF,gKn,d8P,gKn,G7,gKn,dXN,gKn,cy3,gKn,Fy,gKn,fGi,gKn,gor,gKn,eQF,gKn,fSS,gKn,eJ8,gKn,gmt,gKn,PT,gKn,A2,gKn,gvz,gKn,fz0,gKn,gyK,gKn,avc,gKn,fMJ,gKn,fPz,gKn,giS,gKn,KD,gKn,pn,gKn,rg,gKn,avf,gKn,N$,gKn,N0,gKn,f2f,gKn,fWd,gKn,fDV,gKn,fOX,gKn,H0,gKn,fJ7,gKn,uZ,gKn,glu,gKn,czW,gKn,fZr,gKn,gyZ,gKn,fY$,gKn,on,gKn,gfV,gKn,f1g,gKn,gxv,gKn,O8,gKn,O2,gKn,O7,gKn,gfC,gKn,xg,gKn,Mj,gKn,sU,gKn,ghj,gKn,gpx,gKn,gyt,gKn,gmV,gKn,fNY,gKn,f1n,gKn,fPa,gKn,Ex,gKn,fU$,gKn,pf,gKn,o9,gKn,pe,gKn,d60,gKn,cNh,gKn,dLs,gKn,f0I,gKn,Bn,gKn,asJ,gKn,fRG,gKn,fOQ,gKn,vJ,gKn,fzo,gKn,fN9,gKn,gqG,gKn,gjf,gKn,gjx,gKn,t1,gKn,t2,gKn,tY,gKn,fyR,gKn,Lm,gKn,fYa,gKn,dYb,gKn,DR,gKn,fHh,gKn,cyV,gKn,fDA,gKn,fGG,gKn,fVD,gKn,deS,gKn,fBD,gKn,fFN,gKn,gnn,gKn,gwt,gKn,fOp,gKn,fVe,gKn,n$,gKn,fRj,gKn,Gy,gKn,fMf,gKn,fGZ,gKn,fF6,gKn,u5,gKn,vf,gKn,gpa,gKn,fJq,gKn,f$1,gKn,y2,gKn,MT,gKn,fVa,gKn,fzL,gKn,kd,gKn,Jk,gKn,Jj,gKn,gv0,gKn,gh4,gKn,fRc,gKn,IQ,gKn,fGt,gKn,pZ,gKn,fIe,gKn,dXz,gKn,fK_,gKn,gr6,gKn,zL,gKn,dWK,gKn,cML,gKn,fMQ,gKn,eNA,gKn,fPe,gKn,Be,gKn,fIY,gKn,dfN,gKn,E$,gKn,fB7,gKn,uA,gKn,gza,gKn,gnT,gKn,LG,gKn,fOK,gKn,fBq,gKn,fIH,gKn,J2,gKn,fY9,gKn,Mu,gKn,gpp,gKn,fpT,gKn,a2g,gKn,geb,gKn,gm5,gKn,guF,gKn,fK6,gKn,gyT,gKn,fNH,gKn,gkw,gKn,fUd,gKn,dXl,gKn,ne,gKn,fT9,gKn,fNb,gKn,dWR,gKn,JH,gKn,fA2,gKn,fGR,gKn,gwA,gKn,gzr,gKn,a$9,gKn,gqN,gKn,re,gKn,fme,gKn,E3,gKn,gxp,gKn,f0c,gKn,geg,gKn,eNu,gKn,dXP,gKn,gk0,gKn,fCR,gKn,grv,gKn,J4,gKn,J7,gKn,eCI,gKn,gi5,gKn,fQV,gKn,fUj,gKn,gxc,gKn,f1a,gKn,EO,gKn,mH,gKn,fqa,gKn,gjt,gKn,fLz,gKn,ggS,gKn,gnt,gKn,gjH,gKn,d6N,gKn,fUw,gKn,fO0,gKn,a2h,gKn,uy,gKn,ux,gKn,NX,gKn,QC,gKn,NN,gKn,NM,gKn,fpJ,gKn,Ij,gKn,Rp,gKn,f2u,gKn,a$r,gKn,fQg,gKn,s3,gKn,oH,gKn,fmA,gKn,f1s,gKn,yt,gKn,yu,gKn,f2b,gKn,mG,gKn,cMV,gKn,gsk,gKn,sA,gKn,Bk,gKn,fKs,gKn,zo,gKn,zn,gKn,Rj,gKn,fMF,gKn,fKv,gKn,gp5,gKn,fVm,gKn,a$w,gKn,czq,gKn,fID,gKn,gmf,gKn,fMB,gKn,fFA,gKn,ggw,gKn,fKL,gKn,fQl,gKn,guN,gKn,vr,gKn,vv,gKn,d_2,gKn,vu,gKn,a2e,gKn,f4A,gKn,f0a,gKn,F$,gKn,ffU,gKn,gpY,gKn,fPn,gKn,e5l,gKn,gl_,gKn,gkD,gKn,B5,gKn,B3,gKn,ghW,gKn,f2v,gKn,fQo,gKn,gk_,gKn,fwU,gKn,O6,gKn,fBa,gKn,f3s,gKn,gpF,gKn,qY,gKn,gla,gKn,sQ,gKn,qW,gKn,fOe,gKn,grl,gKn,Kt,gKn,f1x,gKn,fS$,gKn,glC,gKn,o4,gKn,o7,gKn,fFG,gKn,czM,gKn,gq_,gKn,fMp,gKn,d62,gKn,fWj,gKn,fD0,gKn,Kv,gKn,fEz,gKn,auM,gKn,fz7,gKn,d8I,gKn,goC,gKn,GG,gKn,gtr,gKn,fWo,gKn,fzF,gKn,pv,gKn,px,gKn,ob,gKn,oF,gKn,gn8,gKn,FE,gKn,gtJ,gKn,fAw,gKn,fCo,gKn,H5,gKn,f1M,gKn,fT4,gKn,fBW,gKn,f30,gKn,KY,gKn,ik,gKn,f4f,gKn,Jg,gKn,Jh,gKn,Jb,gKn,gvn,gKn,czg,gKn,gs1,gKn,eCK,gKn,fDk,gKn,f0C,gKn,fUh,gKn,gug,gKn,ggb,gKn,eQP,gKn,f2A,gKn,dLf,gKn,Cb,gKn,fy0,gKn,G8,gKn,gqf,gKn,avb,gKn,fSv,gKn,gxy,gKn,Ma,gKn,fJN,gKn,gfr,gKn,f_L,gKn,dXY,gKn,fYc,gKn,wJ,gKn,fpW,gKn,gsT,gKn,Ef,gKn,Eg,gKn,xh,gKn,f0J,gKn,glS,gKn,nZ,gKn,fBi,gKn,a$J,gKn,wP,gKn,tf,gKn,ghD,gKn,gph,gKn,f$k,gKn,I4,gKn,gta,gKn,fYM,gKn,fFs,gKn,Jp,gKn,fRm,gKn,Kz,gKn,Kw,gKn,fAp,gKn,fDz,gKn,gst,gKn,tD,gKn,eNB,gKn,v0,gKn,fAA,gKn,a2b,gKn,A7,gKn,vV,gKn,eQE,gKn,goo,gKn,Bc,gKn,fYy,gKn,fLi,gKn,fV1,gKn,xq,gKn,xs,gKn,fSa,gKn,fAX,gKn,Jz,gKn,go3,gKn,vy,gKn,fAb,gKn,mE,gKn,c2J,gKn,gqQ,gKn,fUo,gKn,fFD,gKn,fqh,gKn,e8U,gKn,pl,gKn,D1,gKn,CZ,gKn,Ip,gKn,Iq,gKn,If,gKn,au5,gKn,fqj,gKn,E0,gKn,a$F,gKn,CN,gKn,fwf,gKn,gvO,gKn,rL,gKn,gmY,gKn,gjS,gKn,gim,gKn,goa,gKn,gnc,gKn,fF5,gKn,QU,gKn,gn_,gKn,QS,gKn,LC,gKn,fZA,gKn,fEH,gKn,gvb,gKn,fy4,gKn,fHC,gKn,fRT,gKn,fKP,gKn,gnz,gKn,giY,gKn,fW6,gKn,fYZ,gKn,pw,gKn,fYx,gKn,gmC,gKn,gic,gKn,au1,gKn,ggE,gKn,guV,gKn,gI1,gKn,f0H,gKn,fTm,gKn,f_B,gKn,fND,gKn,FM,gKn,AD,gKn,gs$,gKn,cza,gKn,fFZ,gKn,fmw,gKn,eDk,gKn,hW,gKn,fAU,gKn,gpJ,gKn,fC0,gKn,vt,gKn,cze,gKn,goT,gKn,ghJ,gKn,fLM,gKn,II,gKn,fI_,gKn,gw5,gKn,IS,gKn,fEC,gKn,gjm,gKn,cNA,gKn,OM,gKn,dX3,gKn,Jf,gKn,fHq,gKn,faO,gKn,fC5,gKn,dfv,gKn,fqg,gKn,fUb,gKn,dfV,gKn,czT,gKn,d6W,gKn,kE,gKn,f4W,gKn,fAI,gKn,f_R,gKn,get,gKn,gg4,gKn,f_3,gKn,f0t,gKn,fOS,gKn,A5,gKn,Ct,gKn,gwh,gKn,fCI,gKn,fVK,gKn,fIk,gKn,auQ,gKn,fQe,gKn,Ds,gKn,e5v,gKn,dYh,gKn,f4N,gKn,ggH,gKn,fwe,gKn,f_h,gKn,gsC,gKn,fzx,gKn,fyT,gKn,gl4,gKn,gn0,gKn,gxS,gKn,gmA,gKn,pd,gKn,fKz,gKn,fXc,gKn,gpN,gKn,fY8,gKn,f_v,gKn,fBO,gKn,fEm,gKn,dW4,gKn,fQb,gKn,gfS,gKn,dfX,gKn,PQ,gKn,fFF,gKn,fPr,gKn,fTB,gKn,fHI,gKn,gsc,gKn,wD,gKn,fp6,gKn,f35,gKn,Dd,gKn,aCW,gKn,fXt,gKn,f$t,gKn,oc,gKn,fCd,gKn,f$V,gKn,gss,gKn,ePl,gKn,LW,gKn,guo,gKn,f3G,gKn,Um,gKn,fTO,gKn,fFi,gKn,fpF,gKn,f_n,gKn,d_5,gKn,ghP,gKn,fHA,gKn,DO,gKn,fVF,gKn,gr$,gKn,d6D,gKn,giF,gKn,gq5,gKn,fRX,gKn,rQ,gKn,f4v,gKn,grB,gKn,MV,gKn,ggm,gKn,gkv,gKn,xt,gKn,v_,gKn,No,gKn,v$,gKn,Ng,gKn,Nn,gKn,CR,gKn,PP,gKn,cMz,gKn,fCv,gKn,n2,gKn,gtQ,gKn,fPG,gKn,fMr,gKn,f4t,gKn,fmc,gKn,fXd,gKn,fMv,gKn,fjI,gKn,ggW,gKn,fOa,gKn,fAh,gKn,gog,gKn,f3x,gKn,ghe,gKn,fYz,gKn,QL,gKn,gur,gKn,dLu,gKn,dWH,gKn,fCA,gKn,gtm,gKn,zb,gKn,gvq,gKn,I1,gKn,JS,gKn,IT,gKn,gyj,gKn,fTs,gKn,fCa,gKn,fKj,gKn,fYS,gKn,wf,gKn,we,gKn,nf,gKn,fUZ,gKn,fp4,gKn,gya,gKn,fp7,gKn,guC,gKn,C6,gKn,oU,gKn,oX,gKn,fwy,gKn,gxW,gKn,a9O,gKn,o5,gKn,e$z,gKn,gxk,gKn,fzU,gKn,fQA,gKn,fEV,gKn,DU,gKn,fMb,gKn,Hl,gKn,eXL,gKn,gw9,gKn,fVO,gKn,xJ,gKn,fXA,gKn,grI,gKn,gs3,gKn,gkg,gKn,gfl,gKn,OR,gKn,KX,gKn,E8,gKn,fJv,gKn,EZ,gKn,fO6,gKn,f2C,gKn,aCO,gKn,dfD,gKn,grV,gKn,fXT,gKn,fOT,gKn,cNd,gKn,FC,gKn,Fu,gKn,aLY,gKn,zG,gKn,FI,gKn,Ok,gKn,FO,gKn,gt6,gKn,gee,gKn,FN,gKn,fUT,gKn,gqF,gKn,f$i,gKn,Kk,gKn,fH3,gKn,ghv,gKn,fJn,gKn,e2k,gKn,f1N,gKn,fSl,gKn,fOl,gKn,fqe,gKn,fv1,gKn,gpv,gKn,NJ,gKn,fWv,gKn,fYK,gKn,gwf,gKn,fPk,gKn,ww,gKn,eXJ,gKn,dLi,gKn,fQu,gKn,fWW,gKn,gt_,gKn,f3Y,gKn,gx7,gKn,fSx,gKn,gqy,gKn,a$v,gKn,f$X,gKn,Fw,gKn,gp8,gKn,fzX,gKn,cNe,gKn,gzq,gKn,fFY,gKn,goq,gKn,fXg,gKn,Ap,gKn,fzb,gKn,gyr,gKn,e5n,gKn,gwp,gKn,dXm,gKn,I3,gKn,I5,gKn,geq,gKn,gj0,gKn,f_V,gKn,f4h,gKn,deZ,gKn,fIL,gKn,giR,gKn,cy0,gKn,ffW,gKn,fDq,gKn,gI2,gKn,tb,gKn,ta,gKn,qH,gKn,f3M,gKn,fOY,gKn,fWY,gKn,fXR,gKn,a$e,gKn,a0l,gKn,wu,gKn,gmQ,gKn,sT,gKn,fyK,gKn,gxu,gKn,fp3,gKn,gu5,gKn,f4p,gKn,dWx,gKn,wE,gKn,wF,gKn,wz,gKn,fSg,gKn,gpy,gKn,fNx,gKn,rD,gKn,fI8,gKn,Ia,gKn,gy6,gKn,fzj,gKn,gqJ,gKn,gjc,gKn,d_J,gKn,sg,gKn,sm,gKn,n6,gKn,sl,gKn,f37,gKn,DS,gKn,f3b,gKn,fLV,gKn,G$,gKn,fLr,gKn,DI,gKn,DQ,gKn,DP,gKn,gwR,gKn,fIA,gKn,fWT,gKn,PZ,gKn,fBC,gKn,gni,gKn,gjA,gKn,fCp,gKn,nk,gKn,PO,gKn,nl,gKn,Bu,gKn,aL2,gKn,Qs,gKn,fRH,gKn,gix,gKn,o$,gKn,c2K,gKn,fVk,gKn,d6K,gKn,gwI,gKn,HT,gKn,HS,gKn,gpf,gKn,gws,gKn,nr,gKn,fUW,gKn,a4p,gKn,f0s,gKn,Nm,gKn,fIl,gKn,gv5,gKn,mJ,gKn,fPF,gKn,Iy,gKn,fzI,gKn,PW,gKn,fOc,gKn,Ha,gKn,fMm,gKn,fjH,gKn,fWZ,gKn,tI,gKn,fPd,gKn,fZY,gKn,gsU,gKn,fDO,gKn,fKB,gKn,cyR,gKn,fzP,gKn,rT,gKn,r1,gKn,gmi,gKn,fmb,gKn,gnO,gKn,gvK,gKn,fIy,gKn,fWl,gKn,dXb,gKn,gr5,gKn,f1d,gKn,fMT,gKn,Bx,gKn,f4I,gKn,fZw,gKn,f2y,gKn,gm6,gKn,fB2,gKn,fYW,gKn,Lz,gKn,Rc,gKn,Q1,gKn,Q2,gKn,fSZ,gKn,fBV,gKn,dLp,gKn,fYp,gKn,fOm,gKn,fNX,gKn,oB,gKn,gyU,gKn,fRs,gKn,fR$,gKn,a0v,gKn,fUV,gKn,fBf,gKn,dX2,gKn,dYk,gKn,e8$,gKn,qh,gKn,p4,gKn,eZ5,gKn,grc,gKn,p7,gKn,p9,gKn,gwF,gKn,dWV,gKn,xI,gKn,f$x,gKn,fwh,gKn,xH,gKn,ug,gKn,f39,gKn,f1W,gKn,rc,gKn,vi,gKn,gko,gKn,gqV,gKn,f3q,gKn,e$C,gKn,gw$,gKn,fLA,gKn,fFB,gKn,NP,gKn,NQ,gKn,fJt,gKn,gi2,gKn,f$Y,gKn,gjK,gKn,grN,gKn,f2j,gKn,FA,gKn,fG1,gKn,glh,gKn,cMO,gKn,cyT,gKn,Fn,gKn,Fo,gKn,f_W,gKn,Bd,gKn,ggP,gKn,gns,gKn,fDi,gKn,f3V,gKn,gtC,gKn,B$,gKn,Kp,gKn,BU,gKn,B0,gKn,Ko,gKn,dWI,gKn,fXb,gKn,xo,gKn,xd,gKn,xe,gKn,fFR,gKn,oT,gKn,oW,gKn,Qq,gKn,FT,gKn,FS,gKn,F1,gKn,Nr,gKn,gmc,gKn,gqW,gKn,geC,gKn,czo,gKn,fEi,gKn,yq,gKn,yk,gKn,gms,gKn,yp,gKn,axN,gKn,e5C,gKn,fMq,gKn,fG6,gKn,gp0,gKn,goK,gKn,fDY,gKn,m_,gKn,mZ,gKn,fPo,gKn,czI,gKn,fMu,gKn,Ar,gKn,Al,gKn,fL6,gKn,Aq,gKn,guQ,gKn,yX,gKn,GV,gKn,fIX,gKn,gpZ,gKn,f2O,gKn,uK,gKn,LM,gKn,ave,gKn,fOZ,gKn,mO,gKn,e2r,gKn,f4O,gKn,KG,gKn,KA,gKn,KF,gKn,Bo,gKn,gj8,gKn,fRA,gKn,ghZ,gKn,gyW,gKn,gky,gKn,G0,gKn,EB,gKn,EC,gKn,JM,gKn,gxG,gKn,fRP,gKn,fXL,gKn,om,gKn,oo,gKn,GX,gKn,gk$,gKn,d6O,gKn,fCk,gKn,eQH,gKn,ghk,gKn,gri,gKn,Gj,gKn,gq$,gKn,fMh,gKn,zu,gKn,dWl,gKn,fTL,gKn,fjF,gKn,fPv,gKn,fBs,gKn,cNH,gKn,fz4,gKn,sk,gKn,fE8,gKn,e2z,gKn,fW3,gKn,GO,gKn,GP,gKn,fZq,gKn,fAv,gKn,fmf,gKn,fqb,gKn,fIt,gKn,fHM,gKn,fCh,gKn,t$,gKn,GI,gKn,fQ7,gKn,goz,gKn,GJ,gKn,gyy,gKn,fDK,gKn,fTk,gKn,f2o,gKn,gjT,gKn,cz$,gKn,fKV,gKn,gkb,gKn,dK5,gKn,N9,gKn,Ob,gKn,fES,gKn,fJm,gKn,fU2,gKn,f_e,gKn,nM,gKn,sc,gKn,gqa,gKn,LT,gKn,LV,gKn,gnK,gKn,a$Z,gKn,Qt,gKn,fRn,gKn,gh1,gKn,gsM,gKn,cM1,gKn,czV,gKn,fD8,gKn,f20,gKn,gis,gKn,fXY,gKn,fXw,gKn,gtd,gKn,fRt,gKn,f2Q,gKn,fG7,gKn,x6,gKn,fjw,gKn,gzd,gKn,glV,gKn,eBu,gKn,gkI,gKn,Ms,gKn,tg,gKn,fL9,gKn,grE,gKn,ND,gKn,gwT,gKn,czc,gKn,NB,gKn,tF,gKn,tG,gKn,tA,gKn,s_,gKn,s$,gKn,s9,gKn,ro,gKn,fK3,gKn,gyM,gKn,f_H,gKn,f4$,gKn,fAx,gKn,fZR,gKn,fSe,gKn,nA,gKn,Gz,gKn,Gr,gKn,fmd,gKn,gwx,gKn,gk7,gKn,fCO,gKn,fOE,gKn,go0,gKn,fR5,gKn,f23,gKn,f1I,gKn,e$y,gKn,f$v,gKn,q6,gKn,fVc,gKn,rd,gKn,fA_,gKn,fEW,gKn,yB,gKn,yD,gKn,fAc,gKn,fTz,gKn,fTM,gKn,dXc,gKn,fPI,gKn,fF4,gKn,C_,gKn,fU8,gKn,dfP,gKn,gjq,gKn,Im,gKn,Ig,gKn,Il,gKn,fHK,gKn,gvR,gKn,fVH,gKn,fQh,gKn,gfZ,gKn,LF,gKn,e6d,gKn,fNQ,gKn,glp,gKn,fWX,gKn,PN,gKn,f4e,gKn,gjP,gKn,rM,gKn,d_F,gKn,cMC,gKn,f0d,gKn,fy5,gKn,e8Y,gKn,gnd,gKn,gqu,gKn,fPl,gKn,DV,gKn,B_,gKn,fI2,gKn,fXJ,gKn,fI3,gKn,gsh,gKn,f3m,gKn,fE5,gKn,ggD,gKn,fKn,gKn,Q_,gKn,a$D,gKn,fXm,gKn,fTC,gKn,gsI,gKn,fZh,gKn,gmz,gKn,Fs,gKn,f4r,gKn,gsY,gKn,asx,gKn,vE,gKn,fTh,gKn,yo,gKn,Kd,gKn,F0,gKn,vo,gKn,fXl,gKn,fLP,gKn,cy1,gKn,dK6,gKn,gw2,gKn,fQa,gKn,f2$,gKn,KE,gKn,A_,gKn,o8,gKn,ON,gKn,f4H,gKn,fWw,gKn,dWC,gKn,fQ_,gKn,fGL,gKn,OY,gKn,Pj,gKn,gnA,gKn,NA,gKn,fNi,gKn,JI,gKn,JO,gKn,JN,gKn,a0n,gKn,f0e,gKn,f$j,gKn,Qi,gKn,fGr,gKn,Pu,gKn,ggg,gKn,Pv,gKn,asu,gKn,fCH,gKn,Cu,gKn,fVu,gKn,gld,gKn,f2E,gKn,gg7,gKn,Cn,gKn,fVz,gKn,dX0,gKn,glx,gKn,AO,gKn,AP,gKn,tp,gKn,tq,gKn,fJa,gKn,ggu,gKn,Oy,gKn,gpK,gKn,Oz,gKn,fV8,gKn,guJ,gKn,gl1,gKn,La,gKn,ggG,gKn,Lb,gKn,K3,gKn,BE,gKn,guX,gKn,ePS,gKn,czd,gKn,Gv,gKn,cNI,gKn,GH,gKn,cNo,gKn,fN1,gKn,f5c,gKn,gxP,gKn,FD,gKn,a9Y,gKn,czL,gKn,a2J,gKn,gpO,gKn,f34,gKn,gun,gKn,gy9,gKn,fIz,gKn,fId,gKn,fS2,gKn,Nu,gKn,gpq,gKn,gvi,gKn,f3F,gKn,f2s,gKn,f2F,gKn,f_d,gKn,gxD,gKn,ghS,gKn,gwU,gKn,f3e,gKn,gh9,gKn,f1H,gKn,P5,gKn,Pl,gKn,RF,gKn,a0c,gKn,fDE,gKn,Fg,gKn,Ff,gKn,gkQ,gKn,dXM,gKn,fBl,gKn,cNM,gKn,QJ,gKn,aL4,gKn,IL,gKn,IK,gKn,a$C,gKn,gks,gKn,Gd,gKn,F3,gKn,F2,gKn,geA,gKn,glN,gKn,EH,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn,gKn];var gv=[gKo,gKo,js,gKo];var gw=[gKp,gKp,gB1,gKp,a13,gKp,gCP,gKp,gEc,gKp,gIg,gKp,gCZ,gKp,gB3,gKp,gB$,gKp,gB0,gKp,gB2,gKp,gB_,gKp,gBY,gKp,gB6,gKp,gB5,gKp,gB4,gKp,a18,gKp,gCN,gKp,a2a,gKp,a1X,gKp,a11,gKp,a1_,gKp,gIh,gKp,a1Z,gKp,gBN,gKp,a12,gKp,a15,gKp,gD6,gKp,a10,gKp,gCo,gKp,a16,gKp,gCC,gKp,gBT,gKp,gC_,gKp,gCY,gKp,gCW,gKp,a1Y,gKp,gCO,gKp,a1$,gKp,gIi,gKp,a17,gKp,gCX,gKp,gCm,gKp,gBP,gKp,gBL,gKp,gBM,gKp,gBO,gKp,gBK,gKp,gBS,gKp,gBR,gKp,gBQ,gKp,gBI,gKp,gCA,gKp,a14,gKp,gCM,gKp,a19,gKp,gCL,gKp,gB7,gKp,gKp,gKp,gKp,gKp,gKp,gKp,gKp,gKp,gKp,gKp,gKp,gKp];var gx=[gKq,gKq,gIj,gKq];var gy=[gKr,gKr,gCQ,gKr,gC$,gKr,gIk,gKr,gIl,gKr,jl,gKr,gIm,gKr,gKr,gKr];var gz=[gKs,gKs,gD3,gKs,gD9,gKs,gKs,gKs];var gA=[gKt,gKt,cqH,gKt,eLg,gKt,bFB,gKt,cnh,gKt,cXS,gKt,eaW,gKt,aiR,gKt,dJA,gKt,aek,gKt,eMM,gKt,fdz,gKt,brR,gKt,ea2,gKt,bMb,gKt,eoF,gKt,bh4,gKt,b7v,gKt,c1i,gKt,dkl,gKt,edq,gKt,baE,gKt,fgt,gKt,doE,gKt,e7X,gKt,eSy,gKt,aEq,gKt,eIj,gKt,eLk,gKt,c_s,gKt,bmN,gKt,caX,gKt,beN,gKt,a8Y,gKt,d_i,gKt,fqv,gKt,dtB,gKt,b45,gKt,cUy,gKt,eH6,gKt,aSU,gKt,d3S,gKt,aaN,gKt,bwV,gKt,eqn,gKt,e3K,gKt,fkb,gKt,bxP,gKt,d$W,gKt,dN9,gKt,dJv,gKt,cFv,gKt,b$h,gKt,eIU,gKt,eWI,gKt,elo,gKt,blg,gKt,cvP,gKt,coD,gKt,aYk,gKt,aBZ,gKt,akY,gKt,ckD,gKt,adz,gKt,eSt,gKt,edP,gKt,cKY,gKt,gIn,gKt,c0O,gKt,akV,gKt,bHj,gKt,bRj,gKt,fiO,gKt,buv,gKt,eci,gKt,at5,gKt,d4f,gKt,b1V,gKt,eHW,gKt,eL6,gKt,e4q,gKt,eUr,gKt,am6,gKt,bDV,gKt,cCE,gKt,ckZ,gKt,b3X,gKt,a5O,gKt,d8v,gKt,b4$,gKt,bLv,gKt,bUn,gKt,coJ,gKt,dip,gKt,ek4,gKt,bWl,gKt,cTm,gKt,a8B,gKt,acA,gKt,bvx,gKt,bGr,gKt,cs7,gKt,diG,gKt,cyt,gKt,ced,gKt,bPJ,gKt,dv8,gKt,b5r,gKt,bkx,gKt,cjh,gKt,cQk,gKt,Z6,gKt,bLZ,gKt,bL3,gKt,dtQ,gKt,bDZ,gKt,dVC,gKt,d5S,gKt,boc,gKt,cvT,gKt,b_t,gKt,cbp,gKt,cZY,gKt,ais,gKt,emx,gKt,aSX,gKt,eIc,gKt,dC8,gKt,cen,gKt,dVY,gKt,eLa,gKt,eAp,gKt,eNh,gKt,cFP,gKt,fi3,gKt,faC,gKt,bhY,gKt,bna,gKt,aWi,gKt,flZ,gKt,ceB,gKt,bBL,gKt,csV,gKt,aW2,gKt,fqH,gKt,fkd,gKt,aes,gKt,aiZ,gKt,cIn,gKt,cO2,gKt,eWL,gKt,a8W,gKt,ajA,gKt,cXc,gKt,fge,gKt,b_L,gKt,aWB,gKt,bZN,gKt,cpJ,gKt,dN7,gKt,bY$,gKt,eZk,gKt,gz4,gKt,cVW,gKt,aBn,gKt,cpD,gKt,aeG,gKt,cQq,gKt,cIS,gKt,eCm,gKt,cA5,gKt,cbl,gKt,dl0,gKt,bXd,gKt,bFf,gKt,aa3,gKt,bIF,gKt,dIx,gKt,bAN,gKt,e7K,gKt,eG3,gKt,dE4,gKt,cGc,gKt,dGB,gKt,cvj,gKt,aDl,gKt,aYQ,gKt,cwh,gKt,djx,gKt,e4N,gKt,baR,gKt,cnl,gKt,cob,gKt,a_P,gKt,cLh,gKt,dpu,gKt,dNE,gKt,d_v,gKt,abM,gKt,ajK,gKt,aq8,gKt,b1F,gKt,cMo,gKt,e9U,gKt,bJB,gKt,bFl,gKt,aCi,gKt,dIT,gKt,cZy,gKt,bdM,gKt,eMK,gKt,dnR,gKt,amu,gKt,btB,gKt,aU$,gKt,e3O,gKt,fa$,gKt,bQ7,gKt,eNn,gKt,cCw,gKt,bhw,gKt,a3_,gKt,e61,gKt,arN,gKt,aVu,gKt,cBZ,gKt,e9v,gKt,aUm,gKt,fij,gKt,cWG,gKt,aKf,gKt,cRK,gKt,aVq,gKt,ctR,gKt,dBm,gKt,fkD,gKt,dC_,gKt,aGC,gKt,_5,gKt,eMB,gKt,ftF,gKt,cCt,gKt,bGz,gKt,cmX,gKt,cRy,gKt,dDq,gKt,bLx,gKt,fbD,gKt,bw9,gKt,do$,gKt,bPj,gKt,aRO,gKt,d_o,gKt,dVO,gKt,aOI,gKt,cbX,gKt,aMA,gKt,cot,gKt,ap6,gKt,b$H,gKt,bT5,gKt,cKt,gKt,b9Z,gKt,aVB,gKt,bWj,gKt,bnt,gKt,e_V,gKt,fdm,gKt,bVl,gKt,bhV,gKt,a7D,gKt,bPB,gKt,bCh,gKt,bGl,gKt,eGT,gKt,bHf,gKt,ami,gKt,cEG,gKt,bfV,gKt,clx,gKt,dkM,gKt,$y,gKt,bTN,gKt,eq1,gKt,dFZ,gKt,ct3,gKt,cB1,gKt,aLv,gKt,eLt,gKt,bVP,gKt,am2,gKt,aZJ,gKt,dDy,gKt,cTM,gKt,eAX,gKt,dDA,gKt,bKF,gKt,apW,gKt,cMq,gKt,dBJ,gKt,ec0,gKt,duV,gKt,dwf,gKt,aN9,gKt,cvx,gKt,dtN,gKt,fhl,gKt,dw1,gKt,duk,gKt,eAy,gKt,csN,gKt,bAp,gKt,eG9,gKt,fqF,gKt,cpV,gKt,dOv,gKt,bcb,gKt,du4,gKt,b$f,gKt,cbr,gKt,cWI,gKt,aPU,gKt,d9j,gKt,e_4,gKt,cCG,gKt,b$D,gKt,bP5,gKt,eHc,gKt,bCJ,gKt,cgR,gKt,baH,gKt,bzn,gKt,bxH,gKt,b3$,gKt,aic,gKt,flc,gKt,eT7,gKt,cEV,gKt,c$V,gKt,eoV,gKt,bVj,gKt,cu5,gKt,cwV,gKt,fgV,gKt,aab,gKt,fjW,gKt,cYE,gKt,eAL,gKt,bKx,gKt,bUz,gKt,aPX,gKt,d3u,gKt,erd,gKt,dtl,gKt,fgG,gKt,bfL,gKt,bKn,gKt,eMg,gKt,ead,gKt,aNT,gKt,gzw,gKt,drb,gKt,ctD,gKt,dS1,gKt,aZm,gKt,ff9,gKt,ajb,gKt,aaV,gKt,eta,gKt,csx,gKt,diO,gKt,cqx,gKt,aj2,gKt,diT,gKt,avD,gKt,dv3,gKt,bYj,gKt,aiA,gKt,bIx,gKt,asI,gKt,fkP,gKt,cld,gKt,bod,gKt,di8,gKt,bRh,gKt,dgu,gKt,cdl,gKt,d4i,gKt,dzF,gKt,bND,gKt,eEw,gKt,cVe,gKt,aJK,gKt,a2S,gKt,duJ,gKt,c_W,gKt,eaw,gKt,eIZ,gKt,aT6,gKt,ft$,gKt,bvZ,gKt,dOs,gKt,dHu,gKt,d0J,gKt,b$r,gKt,dUH,gKt,b9v,gKt,b4T,gKt,cj1,gKt,chP,gKt,cqf,gKt,btj,gKt,bU5,gKt,a2V,gKt,d98,gKt,c$w,gKt,XR,gKt,abQ,gKt,b3r,gKt,b0P,gKt,d8w,gKt,dli,gKt,ckz,gKt,aC7,gKt,aDc,gKt,cmN,gKt,ede,gKt,aO7,gKt,bBt,gKt,fbL,gKt,c04,gKt,ckX,gKt,amg,gKt,e$k,gKt,d$Y,gKt,bQl,gKt,eyB,gKt,ckf,gKt,e0O,gKt,a5d,gKt,b0H,gKt,dIO,gKt,fo9,gKt,ach,gKt,dJ5,gKt,aPj,gKt,egm,gKt,aOZ,gKt,biL,gKt,esK,gKt,epe,gKt,bNr,gKt,e3S,gKt,cTQ,gKt,eti,gKt,d0F,gKt,bvD,gKt,bCV,gKt,cSA,gKt,fiu,gKt,Xs,gKt,ex4,gKt,eDI,gKt,cs3,gKt,ao9,gKt,fh4,gKt,b0p,gKt,bCz,gKt,bh8,gKt,dur,gKt,aCv,gKt,dpW,gKt,e93,gKt,aOU,gKt,bPt,gKt,aU_,gKt,cnb,gKt,c_w,gKt,bmY,gKt,ciD,gKt,dmH,gKt,bE3,gKt,bub,gKt,b6T,gKt,adJ,gKt,aAr,gKt,fbW,gKt,_3,gKt,bCr,gKt,cJZ,gKt,ceR,gKt,eGn,gKt,aNQ,gKt,a5b,gKt,XX,gKt,a4U,gKt,ctN,gKt,esn,gKt,epc,gKt,aCm,gKt,dyS,gKt,cx1,gKt,exH,gKt,aGN,gKt,ccj,gKt,aeg,gKt,asl,gKt,bR3,gKt,cMi,gKt,cF9,gKt,bBN,gKt,cof,gKt,aPb,gKt,cDW,gKt,bRD,gKt,aii,gKt,bER,gKt,coX,gKt,ab$,gKt,dYZ,gKt,aqr,gKt,dkT,gKt,e4o,gKt,cBM,gKt,arU,gKt,bMv,gKt,eI3,gKt,dOc,gKt,dGc,gKt,c_o,gKt,ch$,gKt,e31,gKt,bb0,gKt,Yg,gKt,bjm,gKt,e_Y,gKt,c2A,gKt,b9z,gKt,fiM,gKt,dJg,gKt,aR3,gKt,clT,gKt,ep8,gKt,cRW,gKt,X_,gKt,eun,gKt,aoE,gKt,ege,gKt,d3k,gKt,ftS,gKt,c$Q,gKt,cU2,gKt,cKs,gKt,ep2,gKt,dwo,gKt,Zy,gKt,is,gKt,fsV,gKt,fbX,gKt,d5o,gKt,bLR,gKt,a3P,gKt,e_Q,gKt,et1,gKt,d0q,gKt,Zc,gKt,cW6,gKt,aV5,gKt,ejy,gKt,aZc,gKt,dut,gKt,cXi,gKt,bu9,gKt,eVv,gKt,acU,gKt,bdv,gKt,bZv,gKt,$P,gKt,aaL,gKt,dqR,gKt,exy,gKt,csj,gKt,_V,gKt,cYI,gKt,bN$,gKt,eZp,gKt,dDX,gKt,coB,gKt,b3L,gKt,bOZ,gKt,dta,gKt,cV2,gKt,eUZ,gKt,aHq,gKt,aAL,gKt,dFE,gKt,cLZ,gKt,eRj,gKt,cet,gKt,e7n,gKt,biY,gKt,aYt,gKt,cZO,gKt,$J,gKt,bao,gKt,dhZ,gKt,aYr,gKt,ayd,gKt,ckx,gKt,dq$,gKt,bFJ,gKt,aan,gKt,bfM,gKt,bS3,gKt,dZq,gKt,dVz,gKt,fdT,gKt,b3n,gKt,bTV,gKt,arJ,gKt,b8x,gKt,cbv,gKt,fix,gKt,ei8,gKt,b1B,gKt,ba2,gKt,bOR,gKt,eIo,gKt,a9i,gKt,dxk,gKt,aJm,gKt,cjL,gKt,cgx,gKt,esq,gKt,fh1,gKt,cX0,gKt,fgB,gKt,eyz,gKt,b5v,gKt,bD3,gKt,esv,gKt,alG,gKt,X5,gKt,csH,gKt,ftp,gKt,dUl,gKt,bZV,gKt,bnE,gKt,aZj,gKt,dEW,gKt,a5z,gKt,bdF,gKt,epK,gKt,bwX,gKt,aig,gKt,dsy,gKt,cnF,gKt,cAW,gKt,bmP,gKt,cHT,gKt,aCe,gKt,by$,gKt,bPF,gKt,eCc,gKt,dl9,gKt,coN,gKt,cyh,gKt,bAB,gKt,cIY,gKt,alM,gKt,a9r,gKt,fu4,gKt,e7T,gKt,cg7,gKt,dRk,gKt,bha,gKt,dt8,gKt,cpd,gKt,b7R,gKt,b2J,gKt,byD,gKt,b0V,gKt,cil,gKt,cCl,gKt,avY,gKt,eUb,gKt,dmW,gKt,e7R,gKt,brC,gKt,eYy,gKt,eJY,gKt,aKu,gKt,dtb,gKt,eQ4,gKt,dH_,gKt,caV,gKt,aC8,gKt,al0,gKt,brD,gKt,ba0,gKt,eSO,gKt,euu,gKt,ewm,gKt,dZ$,gKt,aXa,gKt,dyV,gKt,dzK,gKt,dDY,gKt,bA$,gKt,bth,gKt,ayt,gKt,ad4,gKt,cun,gKt,ccb,gKt,dZM,gKt,bu5,gKt,c_a,gKt,d4c,gKt,bWz,gKt,eDF,gKt,ciP,gKt,aQB,gKt,aML,gKt,cjX,gKt,byF,gKt,_R,gKt,b3j,gKt,ai3,gKt,chL,gKt,frS,gKt,dfJ,gKt,dH8,gKt,bMt,gKt,Zl,gKt,din,gKt,awi,gKt,a7y,gKt,dum,gKt,dSC,gKt,fjn,gKt,dBz,gKt,byX,gKt,b_r,gKt,fuW,gKt,alx,gKt,aap,gKt,aIj,gKt,dIY,gKt,cmr,gKt,cK2,gKt,cVQ,gKt,b_3,gKt,aP5,gKt,bBp,gKt,bam,gKt,fgw,gKt,cpb,gKt,cbh,gKt,btd,gKt,b4J,gKt,fr3,gKt,aZb,gKt,aRJ,gKt,eJF,gKt,bEf,gKt,bX7,gKt,bkM,gKt,eR2,gKt,coH,gKt,bIf,gKt,bcJ,gKt,fm1,gKt,c2q,gKt,ej2,gKt,b3h,gKt,dVv,gKt,b0b,gKt,aqO,gKt,eQY,gKt,aqQ,gKt,adx,gKt,amK,gKt,dZy,gKt,epo,gKt,dDC,gKt,cPM,gKt,eTz,gKt,eu2,gKt,awz,gKt,bhS,gKt,cIp,gKt,dJC,gKt,fbS,gKt,cUw,gKt,aSW,gKt,dF3,gKt,egL,gKt,cgZ,gKt,bli,gKt,dy0,gKt,byZ,gKt,aQq,gKt,ch7,gKt,d70,gKt,cif,gKt,e96,gKt,ceV,gKt,bol,gKt,eE6,gKt,cdR,gKt,ajf,gKt,fsU,gKt,amL,gKt,cd9,gKt,fa4,gKt,bJf,gKt,eDJ,gKt,btb,gKt,cxZ,gKt,eoa,gKt,ctL,gKt,cD8,gKt,eJC,gKt,cnx,gKt,c_k,gKt,fcF,gKt,fps,gKt,amN,gKt,gA3,gKt,beU,gKt,bsX,gKt,bOj,gKt,bVT,gKt,csF,gKt,fkm,gKt,eTL,gKt,cPC,gKt,cRM,gKt,aWC,gKt,ar3,gKt,cY8,gKt,lg,gKt,b0d,gKt,aDY,gKt,eZa,gKt,cEL,gKt,e9Y,gKt,bbZ,gKt,cGk,gKt,e0C,gKt,cYG,gKt,bKJ,gKt,cfB,gKt,anf,gKt,ajl,gKt,dIW,gKt,b77,gKt,a3b,gKt,eoM,gKt,cQY,gKt,cl5,gKt,b7P,gKt,b7f,gKt,acM,gKt,_B,gKt,dvP,gKt,gGs,gKt,eAC,gKt,bXr,gKt,dOm,gKt,bLt,gKt,aAN,gKt,c1g,gKt,fsO,gKt,eKM,gKt,eRE,gKt,bCL,gKt,chr,gKt,ftk,gKt,cJT,gKt,e0S,gKt,bgD,gKt,e7j,gKt,cxz,gKt,eDB,gKt,crV,gKt,fnY,gKt,chh,gKt,dKl,gKt,bVL,gKt,eeZ,gKt,d59,gKt,aqv,gKt,exG,gKt,c2j,gKt,a7V,gKt,cRo,gKt,aNr,gKt,fik,gKt,bIb,gKt,cXK,gKt,eKC,gKt,bWF,gKt,c0Z,gKt,e8x,gKt,dOG,gKt,bmR,gKt,cUO,gKt,cIU,gKt,bHH,gKt,d_g,gKt,dPY,gKt,cpP,gKt,eZz,gKt,csD,gKt,bYf,gKt,a3D,gKt,aPZ,gKt,cc3,gKt,bOB,gKt,ccf,gKt,cG7,gKt,b3Z,gKt,b7j,gKt,ayL,gKt,eME,gKt,bOr,gKt,fbc,gKt,c_O,gKt,cP2,gKt,bBz,gKt,eqJ,gKt,b43,gKt,cHj,gKt,eKU,gKt,bE9,gKt,dHs,gKt,eNj,gKt,byH,gKt,c$b,gKt,caf,gKt,bZb,gKt,b4v,gKt,dBh,gKt,cF3,gKt,abd,gKt,bt9,gKt,dBv,gKt,aPz,gKt,cvd,gKt,e9n,gKt,chd,gKt,gEC,gKt,e4Q,gKt,bb6,gKt,bxl,gKt,ajY,gKt,fir,gKt,c1n,gKt,aBl,gKt,c0i,gKt,eCO,gKt,$f,gKt,eXk,gKt,dm3,gKt,bFN,gKt,bX3,gKt,ayH,gKt,eyI,gKt,e1U,gKt,cqF,gKt,b1p,gKt,d_x,gKt,cmB,gKt,eTu,gKt,cBG,gKt,cjj,gKt,chB,gKt,bzR,gKt,eTB,gKt,bOf,gKt,bzb,gKt,e1P,gKt,bPv,gKt,c_m,gKt,b3x,gKt,cMk,gKt,X2,gKt,dOi,gKt,foo,gKt,e1D,gKt,bLH,gKt,bIn,gKt,d1A,gKt,cO4,gKt,cCM,gKt,b5Z,gKt,dx1,gKt,eGt,gKt,e$c,gKt,bud,gKt,ZL,gKt,dLG,gKt,e02,gKt,bVZ,gKt,aIc,gKt,fbm,gKt,dp5,gKt,fiL,gKt,bdf,gKt,bKZ,gKt,bTt,gKt,aN0,gKt,aG1,gKt,ckn,gKt,bb8,gKt,eEC,gKt,ep4,gKt,bIZ,gKt,eum,gKt,aFW,gKt,bT$,gKt,cw3,gKt,bt3,gKt,aED,gKt,c$C,gKt,d5k,gKt,aVd,gKt,dOP,gKt,b8n,gKt,cv7,gKt,eyU,gKt,clv,gKt,cGA,gKt,ehF,gKt,eyQ,gKt,dHl,gKt,cW4,gKt,ejV,gKt,axz,gKt,bUZ,gKt,eu8,gKt,cSy,gKt,cft,gKt,cL8,gKt,bde,gKt,bZt,gKt,eoX,gKt,bE5,gKt,a5v,gKt,cap,gKt,aC2,gKt,bK3,gKt,b1P,gKt,cq3,gKt,dFS,gKt,eDZ,gKt,eGq,gKt,c1B,gKt,bb_,gKt,axy,gKt,dNS,gKt,bMX,gKt,dw2,gKt,cTo,gKt,fhs,gKt,eC5,gKt,YV,gKt,aGn,gKt,dfw,gKt,a3u,gKt,aec,gKt,ajo,gKt,b8Z,gKt,dVE,gKt,bWr,gKt,abE,gKt,b8f,gKt,bVz,gKt,cOO,gKt,dEv,gKt,fjs,gKt,cnL,gKt,RX,gKt,aTj,gKt,ajS,gKt,foP,gKt,b9T,gKt,aue,gKt,bW9,gKt,aKd,gKt,fht,gKt,b9N,gKt,bXX,gKt,bEb,gKt,fgp,gKt,chb,gKt,es9,gKt,bem,gKt,elE,gKt,aEz,gKt,brT,gKt,bjX,gKt,aN2,gKt,aZC,gKt,cYq,gKt,exK,gKt,bAt,gKt,bB1,gKt,bzF,gKt,bXH,gKt,asp,gKt,cvL,gKt,cr5,gKt,bcM,gKt,dA9,gKt,b6F,gKt,dsY,gKt,aHc,gKt,cfH,gKt,iH,gKt,cTA,gKt,avW,gKt,e8E,gKt,cSU,gKt,beD,gKt,eSq,gKt,fkY,gKt,elQ,gKt,eR4,gKt,aCk,gKt,cO6,gKt,cI_,gKt,d4_,gKt,c12,gKt,aZQ,gKt,csB,gKt,bsN,gKt,cdV,gKt,ckV,gKt,cOI,gKt,d8F,gKt,gA1,gKt,dQu,gKt,dOF,gKt,fu7,gKt,bSd,gKt,bhq,gKt,dDn,gKt,dRZ,gKt,al2,gKt,dSx,gKt,b31,gKt,eaV,gKt,bUJ,gKt,bID,gKt,dDw,gKt,cTw,gKt,e7D,gKt,eeq,gKt,ceJ,gKt,dsr,gKt,cvV,gKt,dKw,gKt,cUe,gKt,bcc,gKt,csd,gKt,fcA,gKt,cDc,gKt,fiz,gKt,aUu,gKt,arc,gKt,cr9,gKt,cZu,gKt,cWU,gKt,clH,gKt,b9f,gKt,a4T,gKt,cb1,gKt,cG0,gKt,cDx,gKt,aRH,gKt,aG_,gKt,c0z,gKt,aod,gKt,bEn,gKt,e0H,gKt,bZT,gKt,emK,gKt,aju,gKt,drQ,gKt,aGl,gKt,cS6,gKt,e07,gKt,dr7,gKt,fgy,gKt,a7C,gKt,eha,gKt,bf$,gKt,bxX,gKt,a3V,gKt,bsF,gKt,cVu,gKt,am8,gKt,a7v,gKt,dl5,gKt,baX,gKt,cGR,gKt,eE_,gKt,cyv,gKt,eoz,gKt,bZ1,gKt,eDX,gKt,cv9,gKt,dtf,gKt,dp8,gKt,aXM,gKt,b05,gKt,$u,gKt,cj7,gKt,bU9,gKt,c07,gKt,bTj,gKt,fha,gKt,blr,gKt,bL1,gKt,cIQ,gKt,b97,gKt,aG7,gKt,ayW,gKt,cx3,gKt,b9L,gKt,emw,gKt,bfn,gKt,aRY,gKt,buz,gKt,eXb,gKt,bLf,gKt,bX1,gKt,b9t,gKt,bC1,gKt,cbd,gKt,d$M,gKt,cu7,gKt,cC5,gKt,amY,gKt,c1I,gKt,bMh,gKt,bHv,gKt,bC3,gKt,dZX,gKt,aqp,gKt,cov,gKt,epq,gKt,flL,gKt,faG,gKt,bx7,gKt,d3c,gKt,aO$,gKt,awA,gKt,d_C,gKt,gIo,gKt,epC,gKt,c$A,gKt,elf,gKt,eWq,gKt,ewW,gKt,e7B,gKt,cK6,gKt,dVt,gKt,cqr,gKt,aTe,gKt,cUG,gKt,bKd,gKt,eEF,gKt,e4Z,gKt,b6j,gKt,dSD,gKt,eBR,gKt,chN,gKt,eD8,gKt,b$x,gKt,cur,gKt,co$,gKt,drZ,gKt,b$$,gKt,aVU,gKt,aRE,gKt,dst,gKt,cEa,gKt,bh0,gKt,aaX,gKt,cbj,gKt,esO,gKt,cYu,gKt,bgi,gKt,baz,gKt,bU3,gKt,aGs,gKt,ebC,gKt,dTh,gKt,cPg,gKt,b8P,gKt,cJB,gKt,aKT,gKt,aIK,gKt,eLJ,gKt,cZM,gKt,eCL,gKt,eRQ,gKt,bN1,gKt,bc9,gKt,dqO,gKt,bVf,gKt,aBI,gKt,cnr,gKt,bTz,gKt,eei,gKt,bFn,gKt,cPa,gKt,aJi,gKt,do0,gKt,bCl,gKt,d5t,gKt,abm,gKt,aNf,gKt,dJn,gKt,e3H,gKt,d29,gKt,cRq,gKt,aN5,gKt,dtJ,gKt,XV,gKt,e_A,gKt,b4N,gKt,dPy,gKt,cuB,gKt,aOK,gKt,dHX,gKt,bl2,gKt,c$5,gKt,clL,gKt,cfR,gKt,cmd,gKt,dFA,gKt,dZ9,gKt,eAG,gKt,aBx,gKt,e3W,gKt,ark,gKt,e8p,gKt,aFu,gKt,bRN,gKt,$X,gKt,a_T,gKt,adQ,gKt,dT5,gKt,dj3,gKt,eUk,gKt,akK,gKt,ct9,gKt,cwx,gKt,Zr,gKt,cXG,gKt,dV_,gKt,bSj,gKt,dPG,gKt,cLq,gKt,dIr,gKt,eCZ,gKt,aoa,gKt,b6L,gKt,eLy,gKt,acG,gKt,fhc,gKt,eRO,gKt,bCX,gKt,cuP,gKt,_1,gKt,cNU,gKt,aGf,gKt,dzs,gKt,eYh,gKt,dh9,gKt,eMb,gKt,_k,gKt,b85,gKt,dQS,gKt,fcL,gKt,aPD,gKt,eeB,gKt,cgT,gKt,e1v,gKt,cOa,gKt,dDb,gKt,cx$,gKt,dSQ,gKt,cR4,gKt,apI,gKt,eAj,gKt,cQc,gKt,b9r,gKt,fkv,gKt,cvJ,gKt,eWB,gKt,aXF,gKt,ck5,gKt,eJu,gKt,cH8,gKt,d5V,gKt,aar,gKt,eu0,gKt,bcq,gKt,e4B,gKt,cMa,gKt,cxj,gKt,crL,gKt,aI1,gKt,bUr,gKt,bzP,gKt,aEB,gKt,ec9,gKt,cS8,gKt,aTz,gKt,bOx,gKt,cgp,gKt,cTe,gKt,ayf,gKt,dpI,gKt,efT,gKt,cPO,gKt,dGq,gKt,b37,gKt,crD,gKt,cVE,gKt,baT,gKt,a3R,gKt,bvf,gKt,dNH,gKt,bG5,gKt,bdQ,gKt,aNK,gKt,ayA,gKt,foi,gKt,ezp,gKt,cq1,gKt,etw,gKt,a9x,gKt,cJu,gKt,eXt,gKt,eHL,gKt,eZD,gKt,efs,gKt,elO,gKt,cTy,gKt,c$h,gKt,eTM,gKt,eLB,gKt,b0J,gKt,fr5,gKt,fq2,gKt,c_c,gKt,b8$,gKt,aRz,gKt,dF1,gKt,a3N,gKt,eLP,gKt,aUV,gKt,l9,gKt,dJq,gKt,byf,gKt,eAv,gKt,cwD,gKt,aTW,gKt,cnZ,gKt,dsR,gKt,ckJ,gKt,aAe,gKt,b6D,gKt,ac_,gKt,cE0,gKt,aL7,gKt,bLL,gKt,eFQ,gKt,cFM,gKt,dMY,gKt,le,gKt,bNh,gKt,dxA,gKt,e0J,gKt,emN,gKt,btF,gKt,cxb,gKt,b35,gKt,eSb,gKt,bdj,gKt,bAF,gKt,d9p,gKt,fnf,gKt,beL,gKt,ewY,gKt,Xt,gKt,eo9,gKt,ame,gKt,a55,gKt,e9b,gKt,dAj,gKt,fag,gKt,fip,gKt,eV2,gKt,aJ4,gKt,cll,gKt,alY,gKt,eoA,gKt,cBC,gKt,aDD,gKt,cxh,gKt,bTR,gKt,eUC,gKt,ff_,gKt,emI,gKt,bRV,gKt,b2T,gKt,dRw,gKt,eoq,gKt,eDC,gKt,cES,gKt,aEf,gKt,bD5,gKt,b33,gKt,bZp,gKt,dyQ,gKt,d$8,gKt,fhw,gKt,bYx,gKt,cHV,gKt,aUh,gKt,b5f,gKt,awr,gKt,bRf,gKt,cCy,gKt,dFC,gKt,fvc,gKt,dZD,gKt,bnl,gKt,eUU,gKt,aev,gKt,cGi,gKt,aD2,gKt,aZN,gKt,cVg,gKt,fi$,gKt,a8_,gKt,dM6,gKt,cgP,gKt,eC8,gKt,awC,gKt,dPh,gKt,b$X,gKt,aWp,gKt,azk,gKt,cOg,gKt,aUe,gKt,bZ3,gKt,aPp,gKt,e$m,gKt,dr5,gKt,cUq,gKt,a3T,gKt,b4j,gKt,aSL,gKt,akk,gKt,b2h,gKt,b8t,gKt,dOX,gKt,caZ,gKt,a3n,gKt,d1w,gKt,b6N,gKt,dKz,gKt,ehY,gKt,e_M,gKt,akJ,gKt,adW,gKt,e4b,gKt,cWW,gKt,fuO,gKt,dnI,gKt,cuH,gKt,dFW,gKt,cIv,gKt,eUI,gKt,aMu,gKt,fiH,gKt,cch,gKt,gIp,gKt,apd,gKt,abZ,gKt,bQn,gKt,beF,gKt,e06,gKt,cf3,gKt,ctj,gKt,cuF,gKt,cQW,gKt,ejx,gKt,cSk,gKt,fa8,gKt,coL,gKt,elu,gKt,b8R,gKt,dls,gKt,duT,gKt,cPE,gKt,acb,gKt,boC,gKt,bcl,gKt,dRu,gKt,_c,gKt,cVU,gKt,foK,gKt,aGK,gKt,dKE,gKt,dpz,gKt,eTE,gKt,asL,gKt,eQX,gKt,aGT,gKt,aoH,gKt,e3E,gKt,aOn,gKt,aBQ,gKt,dkb,gKt,bkq,gKt,fvx,gKt,dRe,gKt,en1,gKt,aN_,gKt,fg8,gKt,eSQ,gKt,chJ,gKt,buf,gKt,aNM,gKt,cyn,gKt,bQX,gKt,d6c,gKt,aHp,gKt,c$1,gKt,cv1,gKt,X8,gKt,a_F,gKt,cH4,gKt,c_Z,gKt,b51,gKt,baQ,gKt,cfJ,gKt,eKz,gKt,d82,gKt,d14,gKt,bne,gKt,eU$,gKt,Za,gKt,dFU,gKt,elC,gKt,bbU,gKt,eVo,gKt,a6o,gKt,a40,gKt,aZv,gKt,acy,gKt,cf$,gKt,e8f,gKt,bNb,gKt,esD,gKt,bsl,gKt,cdD,gKt,bm4,gKt,cDa,gKt,aJf,gKt,e4w,gKt,cwb,gKt,aPh,gKt,aNY,gKt,eDN,gKt,aQA,gKt,bQR,gKt,eqH,gKt,cIW,gKt,eVe,gKt,ctT,gKt,dMM,gKt,foA,gKt,alI,gKt,al8,gKt,bPP,gKt,fjp,gKt,bQd,gKt,d8Z,gKt,byv,gKt,c$s,gKt,e00,gKt,cSC,gKt,bwb,gKt,cUC,gKt,bUB,gKt,bN3,gKt,buh,gKt,dDM,gKt,be1,gKt,cCj,gKt,aUc,gKt,eG$,gKt,eF7,gKt,eEG,gKt,aB3,gKt,eTh,gKt,eiF,gKt,aKV,gKt,eeK,gKt,dpU,gKt,bWB,gKt,e3w,gKt,dA2,gKt,cUs,gKt,d0o,gKt,bet,gKt,ccX,gKt,eJ1,gKt,cXk,gKt,fjr,gKt,bxD,gKt,bQj,gKt,eAO,gKt,cQa,gKt,cQo,gKt,b6z,gKt,bBR,gKt,eoP,gKt,cgh,gKt,egF,gKt,bZP,gKt,cJX,gKt,aRd,gKt,dZp,gKt,aOH,gKt,cit,gKt,bcX,gKt,b6p,gKt,bfv,gKt,dL4,gKt,aRi,gKt,cY_,gKt,eji,gKt,d1f,gKt,eUQ,gKt,eGC,gKt,dpA,gKt,cnT,gKt,blW,gKt,b$p,gKt,bMd,gKt,euW,gKt,dI7,gKt,cHF,gKt,bRv,gKt,ev9,gKt,a4e,gKt,bSF,gKt,a5l,gKt,aln,gKt,eiG,gKt,fi6,gKt,b$L,gKt,fb2,gKt,d3P,gKt,emE,gKt,dZu,gKt,eH7,gKt,crd,gKt,eZB,gKt,dZn,gKt,bzJ,gKt,a3J,gKt,ani,gKt,evw,gKt,ehN,gKt,cxp,gKt,aJP,gKt,fgE,gKt,dyb,gKt,gEO,gKt,aAJ,gKt,dpM,gKt,ax1,gKt,bZx,gKt,eGd,gKt,bYN,gKt,dKn,gKt,bLP,gKt,eYA,gKt,ckF,gKt,bMP,gKt,b8l,gKt,aSS,gKt,eM_,gKt,cnP,gKt,_D,gKt,aTc,gKt,cHp,gKt,evr,gKt,bs9,gKt,aVZ,gKt,aOA,gKt,bLV,gKt,cnR,gKt,a3w,gKt,cWo,gKt,e8s,gKt,ehZ,gKt,e1l,gKt,dT7,gKt,bhZ,gKt,cT8,gKt,e7W,gKt,acw,gKt,$q,gKt,eG5,gKt,faB,gKt,fgD,gKt,eh5,gKt,btX,gKt,ciZ,gKt,eIf,gKt,bj6,gKt,d9R,gKt,fhy,gKt,$A,gKt,eMC,gKt,bVF,gKt,_m,gKt,bo$,gKt,c0$,gKt,d0w,gKt,cZm,gKt,dfY,gKt,dUi,gKt,dDP,gKt,crf,gKt,bFp,gKt,bl0,gKt,cx5,gKt,d7i,gKt,bXL,gKt,dD1,gKt,dZQ,gKt,bdW,gKt,bYp,gKt,bXn,gKt,bR1,gKt,cDO,gKt,eR7,gKt,a_x,gKt,by5,gKt,eSd,gKt,bQ$,gKt,a27,gKt,cC8,gKt,adg,gKt,eeJ,gKt,bic,gKt,cuz,gKt,Xm,gKt,cnd,gKt,fao,gKt,eep,gKt,a5t,gKt,awO,gKt,b7z,gKt,ea$,gKt,aU9,gKt,bSD,gKt,foX,gKt,bvJ,gKt,XP,gKt,d5w,gKt,dNY,gKt,eVX,gKt,bBf,gKt,cQU,gKt,eNb,gKt,adL,gKt,aYC,gKt,bW$,gKt,egD,gKt,eV7,gKt,ag8,gKt,aTa,gKt,fba,gKt,cOb,gKt,a9z,gKt,eMP,gKt,bH$,gKt,b09,gKt,cZi,gKt,bMZ,gKt,dEa,gKt,eGv,gKt,dwg,gKt,cf1,gKt,cLb,gKt,elb,gKt,eoo,gKt,cP0,gKt,b59,gKt,eW9,gKt,aqe,gKt,aSk,gKt,eqC,gKt,bsp,gKt,cLn,gKt,bx$,gKt,fuT,gKt,eI9,gKt,dvN,gKt,abj,gKt,eUo,gKt,bgt,gKt,ezF,gKt,cKo,gKt,aiF,gKt,dQU,gKt,acp,gKt,eus,gKt,aDG,gKt,bVR,gKt,dFy,gKt,dNQ,gKt,e0V,gKt,cmZ,gKt,_J,gKt,ajG,gKt,dN5,gKt,c_u,gKt,cln,gKt,bvn,gKt,cwf,gKt,aDa,gKt,bY9,gKt,bRb,gKt,bVJ,gKt,eDL,gKt,cqV,gKt,bD7,gKt,cC0,gKt,aVl,gKt,kY,gKt,d6e,gKt,bMn,gKt,bVt,gKt,cIM,gKt,br9,gKt,cqj,gKt,dSV,gKt,bzB,gKt,eHU,gKt,eSL,gKt,dQR,gKt,cpt,gKt,cr1,gKt,akv,gKt,ehw,gKt,bwv,gKt,aBo,gKt,bV9,gKt,cdr,gKt,bca,gKt,b65,gKt,cg$,gKt,bBr,gKt,bRH,gKt,aYE,gKt,eXg,gKt,d9T,gKt,a7F,gKt,c0M,gKt,bes,gKt,cTa,gKt,bko,gKt,ej1,gKt,cnJ,gKt,blw,gKt,fph,gKt,dmX,gKt,cGY,gKt,aXK,gKt,cix,gKt,aPs,gKt,dyq,gKt,ceN,gKt,bin,gKt,dR5,gKt,dq2,gKt,eHG,gKt,cTC,gKt,fjm,gKt,aj6,gKt,cDS,gKt,aH6,gKt,b8z,gKt,bYz,gKt,dNn,gKt,cOo,gKt,e6X,gKt,efn,gKt,btN,gKt,eDO,gKt,d8B,gKt,c$G,gKt,YT,gKt,aK$,gKt,cd7,gKt,dHA,gKt,epI,gKt,bEP,gKt,fm6,gKt,XK,gKt,aj4,gKt,abb,gKt,eKI,gKt,eKG,gKt,X6,gKt,dI2,gKt,bxT,gKt,fsI,gKt,cUk,gKt,cSM,gKt,eM0,gKt,b5x,gKt,foH,gKt,dlU,gKt,dxc,gKt,eot,gKt,a8U,gKt,Ys,gKt,chf,gKt,ds2,gKt,aAp,gKt,aAf,gKt,eet,gKt,b_x,gKt,dMZ,gKt,aYX,gKt,c0Q,gKt,eIu,gKt,eJU,gKt,cqh,gKt,b8j,gKt,e_B,gKt,dxX,gKt,bvb,gKt,bQJ,gKt,bGn,gKt,cwl,gKt,fkn,gKt,dEZ,gKt,cE6,gKt,fnx,gKt,cir,gKt,XC,gKt,eJo,gKt,bYZ,gKt,duN,gKt,d8q,gKt,a_W,gKt,fac,gKt,b2b,gKt,aKz,gKt,aYi,gKt,cg5,gKt,eYN,gKt,dMb,gKt,alR,gKt,dDa,gKt,dZv,gKt,aZt,gKt,bzD,gKt,bSX,gKt,ff0,gKt,bIl,gKt,b$B,gKt,dZG,gKt,dj2,gKt,dSP,gKt,bcE,gKt,bEz,gKt,a83,gKt,btr,gKt,b3V,gKt,faz,gKt,dBs,gKt,dAN,gKt,cbH,gKt,dJT,gKt,clB,gKt,dnj,gKt,fth,gKt,cP8,gKt,eNr,gKt,a49,gKt,bBZ,gKt,ajj,gKt,bkr,gKt,eTO,gKt,cKG,gKt,dnL,gKt,d1q,gKt,aUw,gKt,cIc,gKt,cLR,gKt,cuv,gKt,ccx,gKt,_h,gKt,eAS,gKt,cQQ,gKt,cB9,gKt,cLl,gKt,cOw,gKt,cwT,gKt,dOk,gKt,aB8,gKt,d3Q,gKt,b1l,gKt,eh7,gKt,ea7,gKt,biN,gKt,dP1,gKt,cdv,gKt,fnh,gKt,bw1,gKt,dmk,gKt,dNv,gKt,b2t,gKt,d_m,gKt,bYV,gKt,boa,gKt,bL9,gKt,e__,gKt,bgK,gKt,aum,gKt,bQT,gKt,cip,gKt,bTx,gKt,arE,gKt,dZR,gKt,ayl,gKt,eUs,gKt,d$U,gKt,auC,gKt,bDD,gKt,alm,gKt,byr,gKt,aPu,gKt,eTb,gKt,eb0,gKt,bR$,gKt,aUG,gKt,aSc,gKt,eNl,gKt,cL2,gKt,cFF,gKt,ak9,gKt,bxh,gKt,e43,gKt,bDh,gKt,bHN,gKt,dwm,gKt,ccJ,gKt,b2v,gKt,cWg,gKt,aqR,gKt,b0R,gKt,csf,gKt,eMz,gKt,cPe,gKt,e8d,gKt,ec3,gKt,e7L,gKt,bWx,gKt,$b,gKt,cDe,gKt,epu,gKt,aZW,gKt,e37,gKt,bsf,gKt,c_2,gKt,aO1,gKt,aoO,gKt,d3N,gKt,cnN,gKt,aM2,gKt,azb,gKt,cuT,gKt,c$S,gKt,e7a,gKt,bev,gKt,eJG,gKt,cJ$,gKt,cdz,gKt,drK,gKt,c0B,gKt,fa7,gKt,c0q,gKt,bYF,gKt,eZt,gKt,am5,gKt,cOe,gKt,cl9,gKt,foB,gKt,eqP,gKt,dJj,gKt,dFI,gKt,e_7,gKt,arl,gKt,aMC,gKt,cY0,gKt,cd1,gKt,bBd,gKt,bxB,gKt,bXx,gKt,fjh,gKt,a5W,gKt,alO,gKt,dgX,gKt,dMr,gKt,abS,gKt,e4S,gKt,etV,gKt,ccz,gKt,aR2,gKt,eTH,gKt,a5J,gKt,eJS,gKt,fuI,gKt,csX,gKt,fdo,gKt,_N,gKt,e4h,gKt,bAv,gKt,a9g,gKt,cpp,gKt,cWw,gKt,cf5,gKt,cev,gKt,ceH,gKt,bRr,gKt,dK_,gKt,b7$,gKt,bzh,gKt,aYm,gKt,eLV,gKt,bun,gKt,alA,gKt,emu,gKt,d7_,gKt,euU,gKt,ch1,gKt,fhk,gKt,dvn,gKt,aj0,gKt,eWk,gKt,dZB,gKt,bIr,gKt,eL8,gKt,eh3,gKt,apA,gKt,cUI,gKt,dVw,gKt,d$0,gKt,byt,gKt,d9i,gKt,bJx,gKt,bO7,gKt,apM,gKt,but,gKt,e3C,gKt,b2Z,gKt,amm,gKt,aHv,gKt,eN$,gKt,aCt,gKt,aR_,gKt,fgU,gKt,bv9,gKt,d5l,gKt,bR7,gKt,foG,gKt,c1S,gKt,dTf,gKt,e66,gKt,eRZ,gKt,anB,gKt,bBH,gKt,ej5,gKt,cfr,gKt,eLi,gKt,byV,gKt,ciV,gKt,app,gKt,aiX,gKt,bHd,gKt,b47,gKt,dox,gKt,bYL,gKt,cGO,gKt,fnE,gKt,bVd,gKt,ck7,gKt,buP,gKt,e_G,gKt,dzP,gKt,e8z,gKt,fb9,gKt,cup,gKt,eUO,gKt,dNO,gKt,aEs,gKt,bGd,gKt,eLr,gKt,apw,gKt,eVr,gKt,ayg,gKt,aio,gKt,bjs,gKt,d0j,gKt,dFp,gKt,bOn,gKt,bKT,gKt,clj,gKt,aMp,gKt,bSz,gKt,bv3,gKt,buT,gKt,alK,gKt,flA,gKt,eBe,gKt,b2P,gKt,bUf,gKt,fvr,gKt,fuR,gKt,bCt,gKt,aU1,gKt,bM$,gKt,dUy,gKt,eH4,gKt,fhP,gKt,cnX,gKt,aoJ,gKt,eqA,gKt,evN,gKt,cHn,gKt,cub,gKt,a9F,gKt,bon,gKt,bS1,gKt,cE9,gKt,bBv,gKt,VM,gKt,cl$,gKt,dmA,gKt,bA9,gKt,cm$,gKt,aWG,gKt,d9G,gKt,cr7,gKt,ayx,gKt,e_9,gKt,aYZ,gKt,bh6,gKt,eS3,gKt,duQ,gKt,fa5,gKt,gEK,gKt,fsX,gKt,ajg,gKt,dLL,gKt,bUV,gKt,Zj,gKt,e7_,gKt,ef5,gKt,cHx,gKt,aPg,gKt,Xi,gKt,ff5,gKt,ect,gKt,eLR,gKt,fa_,gKt,dpZ,gKt,bV7,gKt,dMl,gKt,aoR,gKt,b4R,gKt,aWs,gKt,d3w,gKt,eHX,gKt,bvB,gKt,eGO,gKt,eAc,gKt,bOh,gKt,dIH,gKt,bvp,gKt,bSh,gKt,aB0,gKt,b_5,gKt,bWh,gKt,cRI,gKt,cOQ,gKt,bIp,gKt,d91,gKt,fkE,gKt,d44,gKt,axt,gKt,aah,gKt,eh9,gKt,bk4,gKt,ctB,gKt,fqE,gKt,d3I,gKt,cMe,gKt,cXe,gKt,eEf,gKt,apZ,gKt,ex7,gKt,cVC,gKt,fdA,gKt,eDV,gKt,e4M,gKt,bYd,gKt,fo4,gKt,aaF,gKt,coZ,gKt,b7B,gKt,egk,gKt,bx9,gKt,doh,gKt,egw,gKt,e4j,gKt,dOR,gKt,dnW,gKt,ewy,gKt,aLQ,gKt,fdR,gKt,eir,gKt,d25,gKt,dt7,gKt,acW,gKt,dhF,gKt,dSI,gKt,cUE,gKt,$E,gKt,bFx,gKt,bKN,gKt,cEt,gKt,bm9,gKt,eUM,gKt,bcp,gKt,b_d,gKt,eYQ,gKt,cyb,gKt,fg3,gKt,eak,gKt,d4w,gKt,eXc,gKt,bk9,gKt,dkU,gKt,e6Y,gKt,fiT,gKt,amP,gKt,WV,gKt,etu,gKt,aNd,gKt,bGh,gKt,d5y,gKt,Zp,gKt,bSb,gKt,foe,gKt,en6,gKt,bb4,gKt,be3,gKt,cOU,gKt,cgN,gKt,bpc,gKt,aP8,gKt,bSP,gKt,d5f,gKt,cxN,gKt,dFv,gKt,eFr,gKt,dVK,gKt,b7Z,gKt,cnn,gKt,bsI,gKt,dVV,gKt,bGb,gKt,du6,gKt,cDl,gKt,bdr,gKt,edw,gKt,b0r,gKt,eE0,gKt,b1N,gKt,cSm,gKt,a33,gKt,adt,gKt,bn8,gKt,bj3,gKt,ex6,gKt,cxX,gKt,b0L,gKt,dMQ,gKt,byl,gKt,clJ,gKt,cD4,gKt,b8F,gKt,bKb,gKt,cVG,gKt,fae,gKt,eGJ,gKt,b5T,gKt,b6r,gKt,bAb,gKt,bOV,gKt,fsG,gKt,a_E,gKt,bCN,gKt,b8N,gKt,cGg,gKt,bAJ,gKt,bM3,gKt,cT6,gKt,dBU,gKt,bl9,gKt,bDt,gKt,dAA,gKt,dtL,gKt,ceh,gKt,dr$,gKt,X0,gKt,eTx,gKt,cab,gKt,b8J,gKt,aSO,gKt,ciR,gKt,dxL,gKt,a5H,gKt,e71,gKt,bVD,gKt,eg5,gKt,br1,gKt,e0$,gKt,dtS,gKt,baJ,gKt,cuL,gKt,dv$,gKt,bYJ,gKt,aat,gKt,eEy,gKt,aXD,gKt,buL,gKt,cfp,gKt,el3,gKt,aPW,gKt,fgX,gKt,eAn,gKt,cOE,gKt,cRg,gKt,duH,gKt,aH_,gKt,a8H,gKt,cdh,gKt,dqN,gKt,bjM,gKt,bAr,gKt,cp5,gKt,bmp,gKt,bau,gKt,a6k,gKt,d0B,gKt,eR5,gKt,e1q,gKt,fbo,gKt,dFc,gKt,dkW,gKt,dC6,gKt,bNP,gKt,fuQ,gKt,cUu,gKt,Yp,gKt,Y1,gKt,ftP,gKt,bhM,gKt,cj5,gKt,asc,gKt,bCB,gKt,cgX,gKt,aLC,gKt,cnf,gKt,aAl,gKt,b6J,gKt,dOJ,gKt,dyU,gKt,fgK,gKt,bBl,gKt,elq,gKt,b5H,gKt,cbx,gKt,cXg,gKt,dlt,gKt,fhn,gKt,b6B,gKt,cCA,gKt,ao0,gKt,aVe,gKt,eD2,gKt,cEx,gKt,cGJ,gKt,eag,gKt,b$T,gKt,ezr,gKt,YM,gKt,b_$,gKt,egO,gKt,dk1,gKt,di0,gKt,$l,gKt,bVV,gKt,b5F,gKt,dPA,gKt,eog,gKt,cWO,gKt,dC2,gKt,eV0,gKt,e4m,gKt,fhQ,gKt,aeC,gKt,ftL,gKt,dgv,gKt,bU1,gKt,ekp,gKt,dYJ,gKt,euP,gKt,ctf,gKt,_t,gKt,aeO,gKt,eMm,gKt,b17,gKt,cn5,gKt,a5x,gKt,eYO,gKt,cb3,gKt,euT,gKt,eRM,gKt,anV,gKt,aQ1,gKt,eUF,gKt,bfE,gKt,cmt,gKt,etD,gKt,ckN,gKt,drE,gKt,azi,gKt,e70,gKt,dxf,gKt,eWN,gKt,bCd,gKt,cS0,gKt,cgr,gKt,dVs,gKt,cRE,gKt,aOD,gKt,aJp,gKt,ct1,gKt,cFz,gKt,fdx,gKt,e8q,gKt,eit,gKt,aNX,gKt,bcV,gKt,dFG,gKt,dH5,gKt,btT,gKt,aRL,gKt,dhH,gKt,cxt,gKt,eT9,gKt,aqF,gKt,cXI,gKt,cPI,gKt,b_p,gKt,dSW,gKt,bTB,gKt,chp,gKt,fqU,gKt,dPJ,gKt,cpL,gKt,cnB,gKt,b63,gKt,eUS,gKt,eGF,gKt,fsQ,gKt,awW,gKt,aQu,gKt,bLl,gKt,aOl,gKt,eZw,gKt,e9Q,gKt,b1n,gKt,bRF,gKt,bpa,gKt,bYb,gKt,dO8,gKt,e58,gKt,e39,gKt,RY,gKt,cnD,gKt,d6k,gKt,hC,gKt,dJF,gKt,bHR,gKt,fhf,gKt,bCv,gKt,cQg,gKt,dwS,gKt,fse,gKt,aqD,gKt,dgY,gKt,flP,gKt,b1h,gKt,cYW,gKt,cgv,gKt,aKn,gKt,me,gKt,arZ,gKt,cV_,gKt,b1R,gKt,clF,gKt,a35,gKt,ecN,gKt,bUL,gKt,eZf,gKt,bXZ,gKt,cFC,gKt,cDK,gKt,b55,gKt,aT4,gKt,b9R,gKt,c1M,gKt,dDp,gKt,dDU,gKt,e9H,gKt,l1,gKt,cSs,gKt,aHb,gKt,ba$,gKt,iz,gKt,eK6,gKt,aqC,gKt,b7J,gKt,aZl,gKt,aR8,gKt,bS7,gKt,bUb,gKt,dKJ,gKt,e1J,gKt,b4f,gKt,ccT,gKt,dBt,gKt,cYy,gKt,cjP,gKt,cP4,gKt,aUP,gKt,b$l,gKt,aJo,gKt,atX,gKt,bvX,gKt,bY3,gKt,bKr,gKt,c0I,gKt,di9,gKt,bMl,gKt,bzx,gKt,b2r,gKt,cBf,gKt,bwr,gKt,bLN,gKt,dMd,gKt,e_J,gKt,dzD,gKt,e_5,gKt,eAF,gKt,eWa,gKt,eKE,gKt,ejg,gKt,bZR,gKt,eNV,gKt,c$k,gKt,b_l,gKt,dpH,gKt,fih,gKt,$Y,gKt,dzx,gKt,atF,gKt,bg4,gKt,abf,gKt,cmz,gKt,a7_,gKt,bo1,gKt,b9j,gKt,cIi,gKt,dJo,gKt,cRU,gKt,cC_,gKt,eHZ,gKt,cHl,gKt,aH7,gKt,bm5,gKt,akM,gKt,bJD,gKt,dRz,gKt,cW0,gKt,dpC,gKt,aZO,gKt,cEz,gKt,eqi,gKt,aV3,gKt,cBb,gKt,bXT,gKt,eJm,gKt,cR8,gKt,fbO,gKt,dIE,gKt,ceP,gKt,eRb,gKt,b1$,gKt,b1L,gKt,dx0,gKt,cYU,gKt,aQc,gKt,b9p,gKt,aqx,gKt,dhr,gKt,aWj,gKt,fo6,gKt,e4P,gKt,b5z,gKt,bJv,gKt,aRP,gKt,bm7,gKt,doG,gKt,cCS,gKt,fnc,gKt,cPS,gKt,e_U,gKt,aOm,gKt,cj3,gKt,aPG,gKt,eSI,gKt,e0K,gKt,bBx,gKt,cBK,gKt,bQv,gKt,dtW,gKt,cIe,gKt,dCV,gKt,aBS,gKt,cBO,gKt,bIv,gKt,ewd,gKt,cah,gKt,d1d,gKt,doB,gKt,bHV,gKt,fcc,gKt,aKq,gKt,e$b,gKt,bja,gKt,eEt,gKt,exS,gKt,dJa,gKt,a8x,gKt,bv7,gKt,adj,gKt,aSG,gKt,bYB,gKt,eyt,gKt,eAQ,gKt,ceZ,gKt,cI9,gKt,bsn,gKt,fhL,gKt,dFQ,gKt,aZe,gKt,cax,gKt,dpp,gKt,b_P,gKt,cox,gKt,bup,gKt,e77,gKt,cYS,gKt,ak6,gKt,aKB,gKt,cfT,gKt,_9,gKt,eA_,gKt,epm,gKt,b6l,gKt,dZJ,gKt,cXQ,gKt,dSs,gKt,dVI,gKt,elw,gKt,cpn,gKt,ckp,gKt,dI_,gKt,bEV,gKt,ceL,gKt,dvf,gKt,e8a,gKt,eo3,gKt,aJg,gKt,cjp,gKt,b7x,gKt,bzj,gKt,cJR,gKt,eUX,gKt,ef7,gKt,ej4,gKt,byx,gKt,fid,gKt,aqT,gKt,fgz,gKt,cXm,gKt,dIl,gKt,b$N,gKt,cSW,gKt,YP,gKt,eC1,gKt,dvC,gKt,azm,gKt,d0a,gKt,d5a,gKt,aF7,gKt,djz,gKt,e8D,gKt,bb2,gKt,d69,gKt,aEt,gKt,bVr,gKt,b1t,gKt,akz,gKt,cGv,gKt,fuY,gKt,bsV,gKt,jW,gKt,dtd,gKt,aD0,gKt,adr,gKt,duA,gKt,flJ,gKt,cTk,gKt,dpN,gKt,cR6,gKt,aiz,gKt,aYy,gKt,$7,gKt,cgz,gKt,csz,gKt,c_Q,gKt,ci3,gKt,bu$,gKt,aOs,gKt,cc$,gKt,bh2,gKt,cd$,gKt,dVy,gKt,e75,gKt,kk,gKt,bXD,gKt,fsS,gKt,cJo,gKt,fqt,gKt,eRm,gKt,cRQ,gKt,aS7,gKt,etf,gKt,ai6,gKt,bFL,gKt,bMR,gKt,eXA,gKt,cfV,gKt,aiB,gKt,dOT,gKt,bNz,gKt,cb$,gKt,bEN,gKt,a4j,gKt,buB,gKt,esL,gKt,cSu,gKt,abv,gKt,aPQ,gKt,ZW,gKt,bsd,gKt,ckR,gKt,cU4,gKt,cgV,gKt,fuh,gKt,cG9,gKt,fiw,gKt,aIg,gKt,cFc,gKt,cSo,gKt,bRT,gKt,dlP,gKt,b6$,gKt,dAI,gKt,eGH,gKt,abo,gKt,az6,gKt,esF,gKt,b53,gKt,eLZ,gKt,bsL,gKt,d3K,gKt,d7b,gKt,cgn,gKt,dD$,gKt,a9m,gKt,aRN,gKt,caP,gKt,a80,gKt,dCT,gKt,c1e,gKt,cOu,gKt,fcN,gKt,eB5,gKt,bcA,gKt,bnw,gKt,aoM,gKt,fbq,gKt,bTf,gKt,b5d,gKt,fo3,gKt,b3l,gKt,dp$,gKt,bPf,gKt,dqG,gKt,eFO,gKt,b3J,gKt,brX,gKt,bNB,gKt,eJb,gKt,aBv,gKt,cXo,gKt,Z0,gKt,aPm,gKt,ca5,gKt,cUY,gKt,bSp,gKt,bPN,gKt,arA,gKt,ciF,gKt,Yj,gKt,dD2,gKt,aeS,gKt,cer,gKt,cfZ,gKt,eRe,gKt,cmj,gKt,abh,gKt,cDC,gKt,bwH,gKt,ds0,gKt,dAW,gKt,bMz,gKt,c1s,gKt,abs,gKt,c_E,gKt,bOp,gKt,cml,gKt,dmm,gKt,a6S,gKt,dM3,gKt,cmR,gKt,aOp,gKt,egu,gKt,eY8,gKt,bV5,gKt,$V,gKt,eGi,gKt,alt,gKt,dqs,gKt,eCT,gKt,dlc,gKt,bWb,gKt,aBM,gKt,bWT,gKt,_i,gKt,eqp,gKt,fgZ,gKt,alc,gKt,cU0,gKt,ft5,gKt,cYc,gKt,eGQ,gKt,avw,gKt,cEZ,gKt,cMc,gKt,exQ,gKt,fhI,gKt,dVk,gKt,flM,gKt,a6c,gKt,aW4,gKt,d58,gKt,bC9,gKt,cKT,gKt,bx1,gKt,cKm,gKt,dzA,gKt,aWf,gKt,bEX,gKt,_r,gKt,dF5,gKt,e1j,gKt,fnt,gKt,a86,gKt,eWj,gKt,bP7,gKt,ccH,gKt,csR,gKt,chT,gKt,fis,gKt,aja,gKt,Yw,gKt,bC$,gKt,aOv,gKt,bv5,gKt,azd,gKt,a8F,gKt,b1f,gKt,cgD,gKt,ea3,gKt,ekq,gKt,bdU,gKt,cVs,gKt,cvn,gKt,bYn,gKt,bI1,gKt,eqa,gKt,ab9,gKt,fl2,gKt,dmh,gKt,drN,gKt,c14,gKt,bDL,gKt,bk2,gKt,d$I,gKt,aru,gKt,dyZ,gKt,boP,gKt,blp,gKt,d56,gKt,b4d,gKt,a4c,gKt,ayy,gKt,amV,gKt,bvR,gKt,dnY,gKt,dr9,gKt,arP,gKt,aK7,gKt,eEV,gKt,eoB,gKt,eKK,gKt,cIl,gKt,dii,gKt,cvf,gKt,ckH,gKt,b9b,gKt,eCN,gKt,cpR,gKt,cfh,gKt,cYs,gKt,eYo,gKt,aTK,gKt,aOT,gKt,et_,gKt,cY4,gKt,cRi,gKt,arX,gKt,ale,gKt,YZ,gKt,bs3,gKt,bRR,gKt,dAY,gKt,fhS,gKt,aeI,gKt,eo_,gKt,aOR,gKt,fiG,gKt,bEF,gKt,dLT,gKt,dJV,gKt,b$t,gKt,eJg,gKt,d30,gKt,cRe,gKt,dVB,gKt,dL6,gKt,aeM,gKt,d9D,gKt,bFP,gKt,bfa,gKt,cwd,gKt,ctl,gKt,frq,gKt,ad2,gKt,arq,gKt,cSY,gKt,aOu,gKt,dPB,gKt,a8w,gKt,bO9,gKt,cBS,gKt,fuN,gKt,ars,gKt,cCf,gKt,e4U,gKt,cdf,gKt,bQZ,gKt,bI3,gKt,b41,gKt,eQV,gKt,c_I,gKt,edz,gKt,cIO,gKt,cX_,gKt,cw5,gKt,dzm,gKt,cYi,gKt,cW2,gKt,dfk,gKt,eXy,gKt,cVo,gKt,e78,gKt,a5Y,gKt,dAF,gKt,cZ2,gKt,fie,gKt,bDP,gKt,e4F,gKt,aQ4,gKt,aDW,gKt,ewN,gKt,aQt,gKt,aps,gKt,aM0,gKt,dpF,gKt,a59,gKt,eVS,gKt,eJL,gKt,cLI,gKt,eYI,gKt,cRa,gKt,e8h,gKt,aQw,gKt,dr4,gKt,aXz,gKt,dTi,gKt,atm,gKt,c1k,gKt,bET,gKt,aJd,gKt,bBb,gKt,dp1,gKt,fry,gKt,cyj,gKt,cqB,gKt,bwd,gKt,cQI,gKt,a25,gKt,dVn,gKt,aVg,gKt,bQh,gKt,cyd,gKt,b3P,gKt,c$a,gKt,c2h,gKt,fjX,gKt,dp3,gKt,cED,gKt,b4x,gKt,ckr,gKt,dwQ,gKt,c0D,gKt,b83,gKt,e04,gKt,byn,gKt,dqn,gKt,fas,gKt,btv,gKt,cTO,gKt,bxV,gKt,bv$,gKt,b4X,gKt,dUL,gKt,fke,gKt,bdp,gKt,aXB,gKt,e98,gKt,bPr,gKt,clN,gKt,d3r,gKt,cID,gKt,cSQ,gKt,bW1,gKt,aW0,gKt,dly,gKt,dpx,gKt,aWE,gKt,cxF,gKt,aYH,gKt,fuz,gKt,arm,gKt,acn,gKt,aIe,gKt,fhY,gKt,fo7,gKt,cHX,gKt,fm9,gKt,aBs,gKt,aIp,gKt,cjJ,gKt,bCT,gKt,aXS,gKt,bD1,gKt,euM,gKt,e9w,gKt,caT,gKt,eGa,gKt,bQ1,gKt,a7O,gKt,bci,gKt,e8c,gKt,eV8,gKt,bz3,gKt,a3F,gKt,byP,gKt,cA4,gKt,aWU,gKt,cDI,gKt,bDx,gKt,aFF,gKt,cFg,gKt,fkj,gKt,bY7,gKt,ewc,gKt,bX5,gKt,cZk,gKt,a6b,gKt,bI$,gKt,b2p,gKt,dlH,gKt,ad_,gKt,akR,gKt,gEE,gKt,eeT,gKt,ciX,gKt,aOX,gKt,b3b,gKt,dRq,gKt,aRk,gKt,ea9,gKt,aea,gKt,bC5,gKt,dQN,gKt,bsD,gKt,ck9,gKt,bNH,gKt,bzX,gKt,bfQ,gKt,cMs,gKt,fdN,gKt,e8n,gKt,dmU,gKt,egq,gKt,fkQ,gKt,bVv,gKt,chV,gKt,du7,gKt,b$v,gKt,bnL,gKt,cWm,gKt,eK4,gKt,du_,gKt,beK,gKt,dKM,gKt,c$O,gKt,eJq,gKt,d6f,gKt,cVO,gKt,cu$,gKt,aS9,gKt,avH,gKt,bjG,gKt,ecv,gKt,beS,gKt,ajh,gKt,dEc,gKt,e4E,gKt,b5D,gKt,flo,gKt,eRu,gKt,aVx,gKt,cb9,gKt,dKg,gKt,cGT,gKt,cr$,gKt,cv$,gKt,anh,gKt,drI,gKt,e8B,gKt,b2X,gKt,aKa,gKt,dRT,gKt,dQ5,gKt,cV0,gKt,eYC,gKt,azo,gKt,azv,gKt,cXU,gKt,aei,gKt,duj,gKt,cMu,gKt,eqf,gKt,_H,gKt,ccZ,gKt,chR,gKt,eM3,gKt,aQg,gKt,dI5,gKt,bFh,gKt,dJO,gKt,b5J,gKt,aoj,gKt,fhB,gKt,cnz,gKt,cej,gKt,d0h,gKt,bn2,gKt,e_0,gKt,bvv,gKt,dhW,gKt,ccN,gKt,dMv,gKt,aFI,gKt,cgj,gKt,bMV,gKt,eqt,gKt,eTX,gKt,b$F,gKt,dBM,gKt,eJ0,gKt,bL7,gKt,dBB,gKt,bBV,gKt,cnp,gKt,cBE,gKt,es7,gKt,ctn,gKt,cJq,gKt,bLp,gKt,ctv,gKt,cSG,gKt,b5X,gKt,bGT,gKt,caF,gKt,dG9,gKt,ff6,gKt,b_v,gKt,cUg,gKt,d3_,gKt,ap8,gKt,dyO,gKt,aTL,gKt,cjb,gKt,eI1,gKt,aQH,gKt,cxD,gKt,adp,gKt,d1U,gKt,aB2,gKt,caH,gKt,eKu,gKt,fpt,gKt,fsz,gKt,eq$,gKt,_n,gKt,cp3,gKt,byp,gKt,ak4,gKt,eFt,gKt,cWS,gKt,dzN,gKt,bH1,gKt,apS,gKt,d9F,gKt,cvv,gKt,euX,gKt,cJG,gKt,aKW,gKt,dzC,gKt,eA6,gKt,aF4,gKt,ctX,gKt,eo7,gKt,fi4,gKt,aFV,gKt,cUQ,gKt,b4D,gKt,bn7,gKt,b0h,gKt,fsP,gKt,cJL,gKt,dpP,gKt,cYK,gKt,cmJ,gKt,ecr,gKt,cor,gKt,clP,gKt,dg5,gKt,csv,gKt,eWy,gKt,bAX,gKt,bJH,gKt,aor,gKt,d3Z,gKt,ayk,gKt,b93,gKt,bFR,gKt,dgs,gKt,bCj,gKt,bSr,gKt,bly,gKt,ftM,gKt,dAU,gKt,bPV,gKt,diI,gKt,fqO,gKt,c2C,gKt,dCz,gKt,b$j,gKt,cVc,gKt,eT$,gKt,Xx,gKt,bLF,gKt,arK,gKt,eeE,gKt,cKz,gKt,ewj,gKt,dIR,gKt,b3D,gKt,e4u,gKt,cJz,gKt,cjV,gKt,aD4,gKt,cx9,gKt,bjk,gKt,dIp,gKt,eI5,gKt,aGh,gKt,cbB,gKt,a3e,gKt,dZ5,gKt,dKG,gKt,ar5,gKt,bJ9,gKt,e1g,gKt,bZz,gKt,e3M,gKt,b2l,gKt,bH9,gKt,eGN,gKt,bm_,gKt,aXj,gKt,aR5,gKt,aWg,gKt,b4l,gKt,eoH,gKt,amR,gKt,dg9,gKt,aeE,gKt,eXj,gKt,brN,gKt,cH6,gKt,csT,gKt,d5p,gKt,eJP,gKt,d7c,gKt,e86,gKt,cg1,gKt,aVb,gKt,cA1,gKt,dnr,gKt,aJQ,gKt,bEB,gKt,blQ,gKt,e1R,gKt,b29,gKt,abq,gKt,ann,gKt,bkK,gKt,cgL,gKt,cHt,gKt,bkT,gKt,dPS,gKt,eSF,gKt,bDl,gKt,anb,gKt,buR,gKt,aMv,gKt,a3s,gKt,eS1,gKt,d4S,gKt,aW$,gKt,bc5,gKt,eWt,gKt,a3l,gKt,bK$,gKt,bPZ,gKt,ewk,gKt,bMx,gKt,c2l,gKt,ckh,gKt,bsH,gKt,bMj,gKt,a20,gKt,dTK,gKt,aAG,gKt,cVI,gKt,dmo,gKt,cid,gKt,emB,gKt,cIJ,gKt,aO2,gKt,dwO,gKt,cKi,gKt,cHR,gKt,bOl,gKt,fcJ,gKt,ft8,gKt,amH,gKt,fjk,gKt,bnN,gKt,fho,gKt,bEr,gKt,byb,gKt,bxf,gKt,eBT,gKt,d$O,gKt,d3L,gKt,d83,gKt,c$d,gKt,bA7,gKt,eD$,gKt,fvn,gKt,dwi,gKt,frJ,gKt,ayP,gKt,ch9,gKt,cHZ,gKt,drD,gKt,avP,gKt,acC,gKt,aoy,gKt,d9$,gKt,eYu,gKt,dIJ,gKt,aHn,gKt,dOp,gKt,alJ,gKt,bc1,gKt,bKP,gKt,Xv,gKt,aO6,gKt,fbF,gKt,b6d,gKt,akf,gKt,bnn,gKt,Ye,gKt,bJn,gKt,a_Z,gKt,eAk,gKt,bPH,gKt,aRh,gKt,art,gKt,csP,gKt,abx,gKt,bRZ,gKt,bR9,gKt,eH2,gKt,eqw,gKt,ada,gKt,cuV,gKt,cCn,gKt,_f,gKt,et5,gKt,b$9,gKt,eKs,gKt,a7Z,gKt,dqx,gKt,eB3,gKt,Y5,gKt,cWQ,gKt,ckj,gKt,dSZ,gKt,a8C,gKt,cg3,gKt,bIL,gKt,ca1,gKt,eU2,gKt,eBZ,gKt,eUK,gKt,cJd,gKt,cmD,gKt,bii,gKt,ccR,gKt,aim,gKt,bo8,gKt,eaf,gKt,cJg,gKt,dZ7,gKt,bYt,gKt,b7p,gKt,fhA,gKt,d40,gKt,cmH,gKt,gAa,gKt,cR_,gKt,e_F,gKt,bdB,gKt,fsw,gKt,bl3,gKt,c$y,gKt,fj0,gKt,a6V,gKt,bdL,gKt,e7y,gKt,dLM,gKt,aI6,gKt,dTr,gKt,_Z,gKt,doT,gKt,a6$,gKt,eMX,gKt,dGD,gKt,byR,gKt,cDh,gKt,bz1,gKt,dth,gKt,cqz,gKt,dAd,gKt,aS5,gKt,cDU,gKt,b7D,gKt,cJV,gKt,b1H,gKt,eA9,gKt,_7,gKt,aax,gKt,e1E,gKt,bNl,gKt,a6g,gKt,fro,gKt,bHz,gKt,duz,gKt,b5L,gKt,bK7,gKt,b2V,gKt,dEP,gKt,dMW,gKt,dmi,gKt,eIh,gKt,ail,gKt,ccF,gKt,aPw,gKt,djO,gKt,cYC,gKt,clR,gKt,cwr,gKt,bNj,gKt,axh,gKt,bvh,gKt,bOJ,gKt,bsx,gKt,b_V,gKt,d3V,gKt,cQ6,gKt,ctP,gKt,e5Y,gKt,bFt,gKt,dtE,gKt,cBp,gKt,fpg,gKt,b_n,gKt,cB5,gKt,d5r,gKt,e8m,gKt,bCp,gKt,awa,gKt,ak2,gKt,cn3,gKt,cbt,gKt,d8z,gKt,eJk,gKt,aSN,gKt,dnt,gKt,c2o,gKt,c__,gKt,c_0,gKt,drG,gKt,coP,gKt,eRA,gKt,c09,gKt,bXb,gKt,e1b,gKt,ezC,gKt,cwj,gKt,ajM,gKt,cDQ,gKt,b4b,gKt,b0n,gKt,egd,gKt,aqJ,gKt,fig,gKt,aal,gKt,cQO,gKt,ehq,gKt,aGc,gKt,ax8,gKt,dBb,gKt,aZy,gKt,d5i,gKt,ayY,gKt,Yi,gKt,WW,gKt,ckd,gKt,eWh,gKt,bM5,gKt,ckT,gKt,bz$,gKt,ca3,gKt,cwR,gKt,diP,gKt,bFb,gKt,cU8,gKt,dA_,gKt,eDv,gKt,aUQ,gKt,d3f,gKt,aVz,gKt,cQG,gKt,crN,gKt,eyK,gKt,eip,gKt,bhK,gKt,cY2,gKt,d4q,gKt,dyv,gKt,aVj,gKt,b2f,gKt,cDt,gKt,gIq,gKt,dwI,gKt,cq7,gKt,cRO,gKt,aQK,gKt,aPc,gKt,d9c,gKt,amh,gKt,aYF,gKt,e32,gKt,cc7,gKt,cp1,gKt,d5g,gKt,cMg,gKt,bHh,gKt,ajW,gKt,d$C,gKt,bYl,gKt,d4Q,gKt,aMo,gKt,bR5,gKt,aY6,gKt,cfN,gKt,c$M,gKt,bxj,gKt,eTe,gKt,e7t,gKt,aLO,gKt,cdb,gKt,bUd,gKt,dvQ,gKt,cWq,gKt,ari,gKt,aDm,gKt,dF$,gKt,dpX,gKt,ezt,gKt,bKv,gKt,aaB,gKt,dgA,gKt,duD,gKt,ar$,gKt,bEv,gKt,awu,gKt,duF,gKt,dv1,gKt,dq7,gKt,c0S,gKt,ayq,gKt,b71,gKt,ehS,gKt,cOk,gKt,eBc,gKt,aCr,gKt,d5F,gKt,byB,gKt,cKE,gKt,eGe,gKt,a5h,gKt,asr,gKt,djj,gKt,eCb,gKt,d0V,gKt,c_4,gKt,_d,gKt,cdF,gKt,aPO,gKt,bTX,gKt,dr0,gKt,avR,gKt,eRG,gKt,aaR,gKt,d1e,gKt,ajQ,gKt,b_1,gKt,bn$,gKt,X3,gKt,cJP,gKt,eHN,gKt,anj,gKt,dyo,gKt,aNv,gKt,eaA,gKt,bB$,gKt,c$7,gKt,dvV,gKt,cYw,gKt,bEl,gKt,e9J,gKt,eBE,gKt,djB,gKt,bQH,gKt,cRw,gKt,bWf,gKt,bV1,gKt,bDv,gKt,con,gKt,cCT,gKt,d4H,gKt,aNu,gKt,frn,gKt,alv,gKt,dVm,gKt,a3L,gKt,fvi,gKt,bNZ,gKt,bsR,gKt,cWs,gKt,bYr,gKt,aTq,gKt,bBF,gKt,bfp,gKt,ecC,gKt,ebY,gKt,hx,gKt,aPL,gKt,ciJ,gKt,c16,gKt,bHt,gKt,et3,gKt,cj9,gKt,bQV,gKt,bSt,gKt,e4K,gKt,eDS,gKt,d5P,gKt,dz6,gKt,dQw,gKt,bWL,gKt,egA,gKt,br7,gKt,eeV,gKt,e7r,gKt,aiH,gKt,cfn,gKt,fhV,gKt,bUl,gKt,a9D,gKt,fhD,gKt,e40,gKt,aAk,gKt,eBg,gKt,aeA,gKt,cJm,gKt,bGP,gKt,dl$,gKt,ZI,gKt,b7b,gKt,edv,gKt,dIn,gKt,cdj,gKt,dMo,gKt,duo,gKt,ao7,gKt,cL_,gKt,ev1,gKt,cn9,gKt,eBq,gKt,dk$,gKt,cJ5,gKt,epG,gKt,frH,gKt,d9U,gKt,bxn,gKt,dzk,gKt,exN,gKt,dHj,gKt,anx,gKt,e7U,gKt,aeW,gKt,bI7,gKt,efM,gKt,b4h,gKt,dA$,gKt,bBB,gKt,d0R,gKt,b_X,gKt,dg3,gKt,dsU,gKt,ce9,gKt,ciL,gKt,b6R,gKt,dH3,gKt,dVL,gKt,caR,gKt,bdz,gKt,c1J,gKt,bOF,gKt,eTZ,gKt,d5D,gKt,Xy,gKt,crR,gKt,bKz,gKt,dvc,gKt,aWH,gKt,cBA,gKt,aaz,gKt,cOm,gKt,bEj,gKt,eh$,gKt,dTB,gKt,djZ,gKt,fbs,gKt,_L,gKt,boK,gKt,b6n,gKt,by7,gKt,bRx,gKt,dKj,gKt,cyr,gKt,aQy,gKt,fcB,gKt,dPU,gKt,dyi,gKt,dGe,gKt,aUE,gKt,cad,gKt,aEN,gKt,aM9,gKt,a8Q,gKt,aG0,gKt,aTG,gKt,dm7,gKt,bQx,gKt,dv6,gKt,bmn,gKt,b3z,gKt,bxt,gKt,aDZ,gKt,b25,gKt,ejD,gKt,e8I,gKt,aHe,gKt,cYA,gKt,apy,gKt,fio,gKt,bTd,gKt,eAI,gKt,gIr,gKt,ewt,gKt,ezH,gKt,fiE,gKt,b8p,gKt,eJz,gKt,csr,gKt,bIT,gKt,aXh,gKt,dm0,gKt,b3N,gKt,b9F,gKt,auo,gKt,bRd,gKt,ac6,gKt,dlK,gKt,dnQ,gKt,bUH,gKt,cI5,gKt,fub,gKt,byj,gKt,ajq,gKt,b0T,gKt,aY_,gKt,d5J,gKt,e0Z,gKt,c_U,gKt,bG1,gKt,fhG,gKt,bBj,gKt,bKX,gKt,bg3,gKt,fbw,gKt,bAh,gKt,ao3,gKt,eUc,gKt,eNf,gKt,bMB,gKt,e4$,gKt,bFv,gKt,b2z,gKt,d9a,gKt,bwP,gKt,c1z,gKt,aop,gKt,epY,gKt,bVb,gKt,bgf,gKt,b6b,gKt,aT2,gKt,aSD,gKt,dMO,gKt,cXu,gKt,eqU,gKt,cfF,gKt,cUS,gKt,ah6,gKt,eZm,gKt,cBj,gKt,dIU,gKt,eGV,gKt,cwv,gKt,a8J,gKt,cr3,gKt,aDU,gKt,cA2,gKt,cq5,gKt,cKC,gKt,aoB,gKt,fbg,gKt,fvt,gKt,co9,gKt,e51,gKt,aQ8,gKt,bZH,gKt,WF,gKt,boj,gKt,cmn,gKt,ayS,gKt,dsS,gKt,eEk,gKt,aPr,gKt,aL5,gKt,aGo,gKt,eCW,gKt,bGt,gKt,bLr,gKt,ezv,gKt,faH,gKt,fsZ,gKt,d5z,gKt,eSf,gKt,djH,gKt,ei$,gKt,dJR,gKt,bY5,gKt,dw$,gKt,cel,gKt,bu1,gKt,dKo,gKt,eg6,gKt,aTY,gKt,aB_,gKt,eDG,gKt,d0A,gKt,cjn,gKt,dQP,gKt,bEt,gKt,dG7,gKt,e3u,gKt,epW,gKt,eoh,gKt,fbx,gKt,eC$,gKt,eg_,gKt,cYM,gKt,baC,gKt,eAq,gKt,eD1,gKt,b9d,gKt,cyl,gKt,dSN,gKt,aSg,gKt,cYg,gKt,anF,gKt,dwF,gKt,bJ$,gKt,fnb,gKt,bYh,gKt,arb,gKt,dHJ,gKt,cvt,gKt,fgd,gKt,eAD,gKt,duE,gKt,cul,gKt,d6h,gKt,dEI,gKt,bDN,gKt,fbB,gKt,c_6,gKt,d3n,gKt,eNT,gKt,bwT,gKt,bE$,gKt,fgl,gKt,eGo,gKt,aWL,gKt,dHV,gKt,cXA,gKt,bQB,gKt,dS$,gKt,dE7,gKt,bUR,gKt,dhg,gKt,cRS,gKt,eWd,gKt,aSm,gKt,bTT,gKt,d5U,gKt,ckv,gKt,eh2,gKt,coj,gKt,b5R,gKt,cqD,gKt,cB7,gKt,dLD,gKt,bVn,gKt,d4k,gKt,eSM,gKt,bgh,gKt,dmC,gKt,aBX,gKt,eox,gKt,byL,gKt,b0l,gKt,btz,gKt,eom,gKt,cO8,gKt,cd5,gKt,d10,gKt,bXB,gKt,bl8,gKt,bNp,gKt,col,gKt,cZ_,gKt,dz4,gKt,bM1,gKt,bNd,gKt,bVX,gKt,aTF,gKt,awT,gKt,cL6,gKt,acI,gKt,elK,gKt,b9h,gKt,ecV,gKt,eG7,gKt,bRp,gKt,bjD,gKt,e4z,gKt,aUf,gKt,eED,gKt,anv,gKt,cEe,gKt,aZ$,gKt,d$A,gKt,dwk,gKt,b67,gKt,buN,gKt,ZT,gKt,bZD,gKt,dVG,gKt,aSi,gKt,bDT,gKt,esQ,gKt,dIA,gKt,eoD,gKt,aLq,gKt,aYx,gKt,cZw,gKt,ecy,gKt,ek6,gKt,aZx,gKt,aoh,gKt,dmf,gKt,fiR,gKt,b0F,gKt,b_B,gKt,ewb,gKt,eWA,gKt,bTJ,gKt,bCn,gKt,drz,gKt,cfl,gKt,eRp,gKt,ee$,gKt,aBH,gKt,clb,gKt,eDy,gKt,d96,gKt,aZA,gKt,dHf,gKt,ac2,gKt,bJl,gKt,fqP,gKt,c1x,gKt,eCs,gKt,d32,gKt,epU,gKt,b$b,gKt,fhi,gKt,ego,gKt,bTl,gKt,$w,gKt,aL3,gKt,c2a,gKt,Zh,gKt,crj,gKt,cJk,gKt,boe,gKt,a48,gKt,cZ4,gKt,crl,gKt,dQZ,gKt,Z_,gKt,eiw,gKt,aOC,gKt,beQ,gKt,clX,gKt,cvZ,gKt,e9p,gKt,b5p,gKt,aV7,gKt,aY3,gKt,cJH,gKt,duh,gKt,cTg,gKt,fuL,gKt,$$,gKt,dJD,gKt,bT3,gKt,cKQ,gKt,dMS,gKt,a1F,gKt,eh0,gKt,eFX,gKt,b$R,gKt,c$Z,gKt,eqr,gKt,alP,gKt,fvl,gKt,cUW,gKt,dvF,gKt,b8V,gKt,dYw,gKt,eEp,gKt,dux,gKt,a5f,gKt,a64,gKt,dKp,gKt,aQb,gKt,cud,gKt,auj,gKt,aRC,gKt,b$z,gKt,fqB,gKt,cjR,gKt,ajU,gKt,dVH,gKt,dzn,gKt,cqv,gKt,dBH,gKt,aaf,gKt,dJ9,gKt,aee,gKt,cqt,gKt,ehU,gKt,aYo,gKt,cht,gKt,csb,gKt,b6v,gKt,aZT,gKt,eUD,gKt,d7Y,gKt,cw9,gKt,d4J,gKt,adn,gKt,d33,gKt,fvd,gKt,ZA,gKt,aRa,gKt,fdK,gKt,cIz,gKt,dSA,gKt,cVM,gKt,cHh,gKt,e7f,gKt,dnK,gKt,aRB,gKt,bRL,gKt,dou,gKt,b4L,gKt,cVq,gKt,epj,gKt,eId,gKt,fr6,gKt,dx9,gKt,d92,gKt,fcV,gKt,e57,gKt,bWn,gKt,dsg,gKt,fg0,gKt,ctp,gKt,bCb,gKt,abu,gKt,ftD,gKt,c0X,gKt,dKr,gKt,aU8,gKt,bxZ,gKt,a5U,gKt,ekh,gKt,eR0,gKt,b2n,gKt,b0Z,gKt,flC,gKt,egy,gKt,ctJ,gKt,dnp,gKt,aWz,gKt,b9D,gKt,bB9,gKt,bP3,gKt,cOq,gKt,cSa,gKt,cOs,gKt,cLj,gKt,cZS,gKt,bKf,gKt,dED,gKt,e42,gKt,fsD,gKt,bMD,gKt,a3p,gKt,clD,gKt,d7U,gKt,eR9,gKt,chj,gKt,efk,gKt,e85,gKt,ftj,gKt,btD,gKt,aZ7,gKt,fog,gKt,dIz,gKt,bzl,gKt,dGW,gKt,dPW,gKt,aIi,gKt,dJX,gKt,c2t,gKt,cvz,gKt,bWP,gKt,ata,gKt,ds_,gKt,e0P,gKt,bnT,gKt,ciB,gKt,djC,gKt,djc,gKt,c_Y,gKt,bRt,gKt,fgj,gKt,elZ,gKt,dBD,gKt,avp,gKt,aUJ,gKt,$5,gKt,bPb,gKt,bLJ,gKt,b3d,gKt,cbP,gKt,eSY,gKt,a8u,gKt,evH,gKt,fbl,gKt,d1o,gKt,eGE,gKt,b6V,gKt,aUN,gKt,akB,gKt,eGS,gKt,eYv,gKt,foJ,gKt,_x,gKt,eyM,gKt,drg,gKt,cPK,gKt,b8d,gKt,ebD,gKt,d41,gKt,aGW,gKt,bXt,gKt,c$X,gKt,dxW,gKt,b7F,gKt,b_f,gKt,cjl,gKt,dyh,gKt,duv,gKt,dUf,gKt,djg,gKt,bNX,gKt,aem,gKt,cRC,gKt,cph,gKt,eMx,gKt,aSo,gKt,bLn,gKt,dop,gKt,YI,gKt,dxI,gKt,eGx,gKt,eNc,gKt,cZC,gKt,dLO,gKt,bmq,gKt,bsT,gKt,fdG,gKt,cbN,gKt,ayr,gKt,bwZ,gKt,akc,gKt,dQX,gKt,ay3,gKt,bEh,gKt,aBt,gKt,c_C,gKt,d4E,gKt,cMm,gKt,dKL,gKt,aKx,gKt,aG9,gKt,aYS,gKt,dh7,gKt,aaZ,gKt,dS3,gKt,dA4,gKt,bBh,gKt,fnH,gKt,fi9,gKt,aDS,gKt,erk,gKt,cSS,gKt,bgo,gKt,cXq,gKt,eqk,gKt,btn,gKt,bZJ,gKt,bJr,gKt,eEi,gKt,ajv,gKt,ecx,gKt,$R,gKt,ceX,gKt,dtj,gKt,cHL,gKt,cjz,gKt,cwn,gKt,dAM,gKt,cVw,gKt,ay9,gKt,bLD,gKt,eJd,gKt,aMR,gKt,cG4,gKt,cbb,gKt,b_D,gKt,bUp,gKt,bF3,gKt,cOA,gKt,fnD,gKt,bG$,gKt,bI9,gKt,e9W,gKt,e8J,gKt,aQj,gKt,eRz,gKt,bXz,gKt,e4J,gKt,cTS,gKt,c0G,gKt,cP6,gKt,eIO,gKt,bT9,gKt,cLu,gKt,fkW,gKt,dpv,gKt,b5$,gKt,bVh,gKt,eej,gKt,b4n,gKt,bpb,gKt,aqV,gKt,euO,gKt,aaP,gKt,eZo,gKt,ewP,gKt,cpj,gKt,ccd,gKt,fkG,gKt,e3Y,gKt,bYv,gKt,bWt,gKt,eG1,gKt,cuD,gKt,chZ,gKt,c$3,gKt,d8D,gKt,bUv,gKt,dsJ,gKt,fb1,gKt,ele,gKt,cKa,gKt,b9J,gKt,aqB,gKt,bJZ,gKt,bDp,gKt,av_,gKt,dIu,gKt,aAn,gKt,aJJ,gKt,dJ7,gKt,d1z,gKt,eQ8,gKt,dBS,gKt,ehO,gKt,bSJ,gKt,chv,gKt,aPe,gKt,eTU,gKt,b75,gKt,a3z,gKt,fh$,gKt,c10,gKt,aFN,gKt,eo0,gKt,bDR,gKt,eJK,gKt,c_q,gKt,cCI,gKt,bhT,gKt,dQ8,gKt,cC3,gKt,cdn,gKt,eVU,gKt,acf,gKt,eHa,gKt,aPM,gKt,fgb,gKt,fqM,gKt,eRJ,gKt,br$,gKt,bGL,gKt,eYl,gKt,aGd,gKt,eLT,gKt,b1b,gKt,aTy,gKt,crb,gKt,bTr,gKt,bz9,gKt,clp,gKt,bt$,gKt,aEQ,gKt,aNa,gKt,bPn,gKt,dom,gKt,bu3,gKt,bXv,gKt,e9K,gKt,eS$,gKt,fsc,gKt,csJ,gKt,$9,gKt,cXs,gKt,cUM,gKt,elh,gKt,dJw,gKt,eAT,gKt,bcF,gKt,dse,gKt,d7L,gKt,ecq,gKt,ftq,gKt,eA0,gKt,cuf,gKt,epR,gKt,ccB,gKt,bEZ,gKt,eUe,gKt,eNW,gKt,b91,gKt,faJ,gKt,ai8,gKt,cBx,gKt,b7X,gKt,a38,gKt,bOb,gKt,bMF,gKt,cyf,gKt,cKL,gKt,bxb,gKt,dHw,gKt,cQw,gKt,bNV,gKt,an2,gKt,bG7,gKt,csp,gKt,eH9,gKt,aqj,gKt,eGL,gKt,ar1,gKt,eUl,gKt,fdP,gKt,dEy,gKt,egQ,gKt,dSY,gKt,cjZ,gKt,dkO,gKt,dFr,gKt,dug,gKt,cTi,gKt,gEA,gKt,bQD,gKt,are,gKt,aOM,gKt,aUz,gKt,cu1,gKt,dQC,gKt,axr,gKt,edb,gKt,doV,gKt,aJb,gKt,aUL,gKt,dId,gKt,cZa,gKt,aQJ,gKt,bvj,gKt,bo2,gKt,aGU,gKt,a5j,gKt,dz7,gKt,fhd,gKt,d$4,gKt,dkZ,gKt,cvN,gKt,fgm,gKt,cvR,gKt,d0c,gKt,bNR,gKt,cZW,gKt,b_h,gKt,c1U,gKt,caL,gKt,bdD,gKt,dQL,gKt,dJt,gKt,ewq,gKt,dPL,gKt,dow,gKt,bD$,gKt,eWf,gKt,cK9,gKt,acK,gKt,bzf,gKt,fkN,gKt,bN5,gKt,b6x,gKt,a4a,gKt,cQe,gKt,dpT,gKt,c0v,gKt,dBd,gKt,dKu,gKt,bnA,gKt,dM2,gKt,bSV,gKt,e4e,gKt,emG,gKt,akD,gKt,bM9,gKt,cjN,gKt,h6,gKt,cVA,gKt,b4p,gKt,a7U,gKt,cp7,gKt,aXQ,gKt,cut,gKt,eMU,gKt,aSB,gKt,bOd,gKt,bZ5,gKt,d4V,gKt,eel,gKt,d4d,gKt,dg1,gKt,d4A,gKt,d0W,gKt,flj,gKt,bJL,gKt,duB,gKt,bhc,gKt,b9P,gKt,cjH,gKt,bHD,gKt,cdZ,gKt,cpF,gKt,aB5,gKt,d$H,gKt,e3T,gKt,cLs,gKt,dAS,gKt,dVS,gKt,en0,gKt,aFD,gKt,bRB,gKt,cHD,gKt,bO1,gKt,bvP,gKt,cHz,gKt,bVB,gKt,b1X,gKt,ewo,gKt,bOL,gKt,aH9,gKt,cO0,gKt,bDz,gKt,dRR,gKt,ay5,gKt,dxU,gKt,aQh,gKt,c$I,gKt,bdT,gKt,b4F,gKt,bQf,gKt,bZX,gKt,egg,gKt,cGp,gKt,btZ,gKt,fgo,gKt,eSn,gKt,aqW,gKt,amJ,gKt,b0z,gKt,fgr,gKt,efm,gKt,dpK,gKt,eIa,gKt,dn_,gKt,dKs,gKt,b7T,gKt,eq3,gKt,cp$,gKt,boo,gKt,aVW,gKt,efQ,gKt,aIn,gKt,ac8,gKt,bIN,gKt,d39,gKt,dUn,gKt,aVs,gKt,bxp,gKt,eBp,gKt,ayn,gKt,dI0,gKt,c_M,gKt,fll,gKt,ehc,gKt,eKX,gKt,cvp,gKt,aYp,gKt,eGg,gKt,amD,gKt,eXB,gKt,biU,gKt,b0X,gKt,fje,gKt,aMG,gKt,cLv,gKt,dUk,gKt,bZ7,gKt,bZl,gKt,a7N,gKt,e7F,gKt,bu7,gKt,aTh,gKt,dJH,gKt,fsK,gKt,cUm,gKt,cBX,gKt,aQs,gKt,b4P,gKt,eMr,gKt,aZH,gKt,bMH,gKt,bNJ,gKt,eHK,gKt,eMG,gKt,d0t,gKt,aq6,gKt,aMZ,gKt,a7H,gKt,dCB,gKt,aqh,gKt,cU_,gKt,fri,gKt,cxf,gKt,ajd,gKt,fsM,gKt,amp,gKt,d8o,gKt,ei0,gKt,cAZ,gKt,dAK,gKt,e4H,gKt,aPF,gKt,cRA,gKt,cDA,gKt,dIC,gKt,b3R,gKt,b87,gKt,bD9,gKt,ezj,gKt,cQM,gKt,crT,gKt,b0t,gKt,dTJ,gKt,bV$,gKt,eau,gKt,cuJ,gKt,eRx,gKt,bGZ,gKt,cTY,gKt,ckb,gKt,cdd,gKt,eKP,gKt,dKe,gKt,bwD,gKt,b0v,gKt,bcN,gKt,dLQ,gKt,el$,gKt,beP,gKt,brz,gKt,cEf,gKt,cZ6,gKt,cV4,gKt,bmM,gKt,e7Z,gKt,bAP,gKt,bFH,gKt,e7P,gKt,djW,gKt,cvB,gKt,aSE,gKt,aBK,gKt,cRm,gKt,eLH,gKt,a57,gKt,fhF,gKt,bzv,gKt,bw5,gKt,eq6,gKt,aPI,gKt,d_k,gKt,ctx,gKt,blo,gKt,bo7,gKt,bwl,gKt,elx,gKt,boR,gKt,fue,gKt,aFQ,gKt,dPa,gKt,bji,gKt,aeq,gKt,aeo,gKt,bur,gKt,cwp,gKt,dn1,gKt,aOq,gKt,b3f,gKt,b9X,gKt,b27,gKt,apN,gKt,cZg,gKt,cUa,gKt,eUA,gKt,bMp,gKt,epE,gKt,cjD,gKt,eRr,gKt,e3P,gKt,ajN,gKt,dGX,gKt,bDn,gKt,brP,gKt,cff,gKt,cgH,gKt,dv5,gKt,dUc,gKt,bxL,gKt,esG,gKt,bX9,gKt,fkV,gKt,e73,gKt,dib,gKt,dAc,gKt,d8G,gKt,cpX,gKt,bXJ,gKt,cEi,gKt,a4m,gKt,b3B,gKt,cmf,gKt,cU6,gKt,dJ3,gKt,did,gKt,eE2,gKt,cGM,gKt,bT1,gKt,aAB,gKt,acl,gKt,cb7,gKt,gAR,gKt,cPu,gKt,eVp,gKt,dJe,gKt,dNG,gKt,cQm,gKt,e7c,gKt,dki,gKt,cVy,gKt,bFT,gKt,bxv,gKt,eEm,gKt,dsc,gKt,dvx,gKt,e4X,gKt,cvb,gKt,be9,gKt,eg8,gKt,ayB,gKt,btf,gKt,cTs,gKt,dFM,gKt,dKx,gKt,ap2,gKt,buX,gKt,biO,gKt,e0X,gKt,bx3,gKt,eYq,gKt,bAD,gKt,bg1,gKt,dIM,gKt,b2H,gKt,cq9,gKt,fny,gKt,bBX,gKt,dtU,gKt,eSu,gKt,b$Z,gKt,b_H,gKt,aWN,gKt,bTH,gKt,aVv,gKt,fdl,gKt,df1,gKt,a9t,gKt,bik,gKt,d3h,gKt,ewZ,gKt,ase,gKt,ekj,gKt,dYX,gKt,dm5,gKt,b07,gKt,crJ,gKt,cV8,gKt,eUw,gKt,cn7,gKt,aEV,gKt,cwL,gKt,aTf,gKt,bho,gKt,a_H,gKt,cw$,gKt,bJ3,gKt,bO3,gKt,a_z,gKt,_X,gKt,bck,gKt,aa7,gKt,co7,gKt,cxv,gKt,fi8,gKt,anZ,gKt,cWa,gKt,bZ9,gKt,aux,gKt,cYo,gKt,$j,gKt,bjh,gKt,abG,gKt,dnT,gKt,abB,gKt,aPJ,gKt,cHH,gKt,bGH,gKt,fhv,gKt,exv,gKt,b69,gKt,cjT,gKt,bC7,gKt,arW,gKt,dqJ,gKt,eI$,gKt,cKH,gKt,bYH,gKt,bG9,gKt,bhX,gKt,e1o,gKt,eIt,gKt,aot,gKt,dJl,gKt,dh5,gKt,eZb,gKt,cbn,gKt,dVX,gKt,bO5,gKt,bs5,gKt,aQ2,gKt,c0U,gKt,cTW,gKt,bxr,gKt,co1,gKt,ayU,gKt,e34,gKt,bQN,gKt,dm1,gKt,aaJ,gKt,cv5,gKt,eWG,gKt,bWJ,gKt,dx3,gKt,eZH,gKt,ctF,gKt,a8L,gKt,arG,gKt,cav,gKt,bw3,gKt,axi,gKt,aQ6,gKt,coF,gKt,e_y,gKt,apE,gKt,dG3,gKt,bvV,gKt,bJF,gKt,dHy,gKt,bNT,gKt,byN,gKt,duY,gKt,anP,gKt,cSE,gKt,clh,gKt,aOx,gKt,e_S,gKt,dRy,gKt,cpT,gKt,efO,gKt,duX,gKt,adY,gKt,aYV,gKt,eWo,gKt,cZo,gKt,a4_,gKt,dVN,gKt,d3a,gKt,flW,gKt,aLz,gKt,eSC,gKt,ebZ,gKt,exD,gKt,eMv,gKt,fkx,gKt,bIR,gKt,faw,gKt,fvB,gKt,awZ,gKt,b5t,gKt,dvu,gKt,eb2,gKt,cUo,gKt,d7N,gKt,ezx,gKt,cpH,gKt,akn,gKt,eGl,gKt,baV,gKt,bE1,gKt,b49,gKt,e3B,gKt,cWy,gKt,aWQ,gKt,fop,gKt,arw,gKt,bOP,gKt,edM,gKt,ZN,gKt,dRt,gKt,amb,gKt,dke,gKt,be4,gKt,dN2,gKt,aP4,gKt,cPU,gKt,bzd,gKt,b2F,gKt,eIY,gKt,dHT,gKt,eYg,gKt,blt,gKt,eEU,gKt,eEh,gKt,bQP,gKt,fi_,gKt,bkV,gKt,aSZ,gKt,eC3,gKt,aR6,gKt,aYN,gKt,dI3,gKt,ftt,gKt,dEE,gKt,dw7,gKt,aWP,gKt,bA5,gKt,dR7,gKt,dqm,gKt,_v,gKt,ajs,gKt,eZJ,gKt,die,gKt,bLj,gKt,b$V,gKt,bWX,gKt,ast,gKt,e3J,gKt,a9B,gKt,cBV,gKt,dw8,gKt,abI,gKt,aT1,gKt,b9H,gKt,dhd,gKt,bOD,gKt,ceb,gKt,b4H,gKt,bMr,gKt,cxP,gKt,aEP,gKt,fvg,gKt,ayJ,gKt,Y7,gKt,dhj,gKt,as3,gKt,cqb,gKt,bFV,gKt,cL0,gKt,bF7,gKt,bSZ,gKt,cE2,gKt,d4P,gKt,aXN,gKt,ceT,gKt,dUC,gKt,dkP,gKt,e7A,gKt,aPS,gKt,boF,gKt,aTZ,gKt,djG,gKt,biT,gKt,cXM,gKt,cJJ,gKt,atb,gKt,cTU,gKt,ad8,gKt,cCh,gKt,an5,gKt,a5S,gKt,bHZ,gKt,cxd,gKt,eeM,gKt,eSh,gKt,bsv,gKt,cSe,gKt,cBQ,gKt,$N,gKt,eiL,gKt,fhT,gKt,bzz,gKt,eU9,gKt,Yq,gKt,bAZ,gKt,dhI,gKt,eTk,gKt,cQi,gKt,aHu,gKt,aZg,gKt,eeg,gKt,dDv,gKt,bNL,gKt,aF0,gKt,ejk,gKt,cFT,gKt,bNf,gKt,aWX,gKt,d_r,gKt,bRz,gKt,gzT,gKt,cnV,gKt,cf9,gKt,dHN,gKt,bOT,gKt,eA2,gKt,edO,gKt,eYL,gKt,bHb,gKt,aj_,gKt,aK9,gKt,fjU,gKt,fg5,gKt,e52,gKt,fow,gKt,ct5,gKt,cpZ,gKt,bDb,gKt,aIC,gKt,dGy,gKt,dzv,gKt,aaD,gKt,bcQ,gKt,d50,gKt,fm7,gKt,$I,gKt,ayi,gKt,dmp,gKt,eRV,gKt,dUO,gKt,bjt,gKt,bQp,gKt,bHB,gKt,fk_,gKt,cep,gKt,faj,gKt,eeR,gKt,dIP,gKt,cOS,gKt,aQ$,gKt,anL,gKt,eZK,gKt,e8v,gKt,ccv,gKt,a_C,gKt,ccn,gKt,e4C,gKt,cQS,gKt,ara,gKt,bHL,gKt,cpf,gKt,cQA,gKt,bcS,gKt,eJI,gKt,cPi,gKt,cCb,gKt,dGz,gKt,dC4,gKt,c0V,gKt,cEI,gKt,bSf,gKt,ehr,gKt,cJx,gKt,c1Z,gKt,egs,gKt,crH,gKt,aXx,gKt,aK4,gKt,c0a,gKt,bGN,gKt,fkk,gKt,c06,gKt,cZU,gKt,awh,gKt,eN3,gKt,eMI,gKt,dER,gKt,et$,gKt,ewr,gKt,bie,gKt,aSe,gKt,eAm,gKt,cwP,gKt,bQ5,gKt,fam,gKt,ai0,gKt,baL,gKt,dBQ,gKt,dTH,gKt,c0K,gKt,d5d,gKt,d5M,gKt,eS5,gKt,dY3,gKt,b81,gKt,dBx,gKt,apu,gKt,$1,gKt,a66,gKt,bzL,gKt,aAy,gKt,a5n,gKt,bwh,gKt,alo,gKt,dOf,gKt,aLT,gKt,bul,gKt,bU$,gKt,dTn,gKt,bWZ,gKt,awt,gKt,bcZ,gKt,b6h,gKt,bkc,gKt,bIj,gKt,ah8,gKt,bZd,gKt,cGr,gKt,e62,gKt,eT0,gKt,cbD,gKt,b4r,gKt,bcH,gKt,cA_,gKt,cLK,gKt,bfT,gKt,foy,gKt,Xk,gKt,_z,gKt,cV6,gKt,fhW,gKt,boE,gKt,cs1,gKt,eUg,gKt,eMd,gKt,eLN,gKt,d_t,gKt,c$K,gKt,eBb,gKt,dPg,gKt,dwb,gKt,eEK,gKt,fbh,gKt,b7r,gKt,akO,gKt,e54,gKt,b4t,gKt,baM,gKt,amG,gKt,dIf,gKt,d5O,gKt,ft2,gKt,bBD,gKt,eQ$,gKt,eZF,gKt,aW8,gKt,aQo,gKt,a_O,gKt,ec8,gKt,e7l,gKt,aEW,gKt,dFw,gKt,bKh,gKt,bKp,gKt,$s,gKt,dZT,gKt,aMm,gKt,di2,gKt,cvr,gKt,dHG,gKt,eEz,gKt,dCX,gKt,eRc,gKt,aFP,gKt,aSQ,gKt,cu3,gKt,d1r,gKt,bZj,gKt,doC,gKt,bLT,gKt,cSq,gKt,caD,gKt,aHf,gKt,fvp,gKt,dYy,gKt,cDp,gKt,cqJ,gKt,een,gKt,eAu,gKt,d0H,gKt,cVk,gKt,d5B,gKt,baF,gKt,dPb,gKt,aNV,gKt,bH5,gKt,a4h,gKt,aUY,gKt,bsP,gKt,aQa,gKt,cGm,gKt,dZ1,gKt,b03,gKt,b2N,gKt,eHE,gKt,bAT,gKt,bc$,gKt,dKV,gKt,aZD,gKt,bMN,gKt,b2j,gKt,bn1,gKt,bcx,gKt,eFz,gKt,aoY,gKt,eHe,gKt,d1Z,gKt,e$n,gKt,bmd,gKt,cvl,gKt,e4k,gKt,bNt,gKt,bXj,gKt,elk,gKt,aDF,gKt,dkj,gKt,b5l,gKt,d_a,gKt,bX$,gKt,a5D,gKt,aiJ,gKt,foM,gKt,fr1,gKt,c0x,gKt,cQy,gKt,bs7,gKt,ato,gKt,d4r,gKt,e95,gKt,eMp,gKt,c_g,gKt,b$1,gKt,cIF,gKt,c1O,gKt,cgB,gKt,bTv,gKt,aC$,gKt,fuH,gKt,fuK,gKt,aVp,gKt,aT$,gKt,clr,gKt,aBC,gKt,acQ,gKt,aQM,gKt,d9x,gKt,cWY,gKt,cwz,gKt,ev7,gKt,cbR,gKt,don,gKt,crv,gKt,bwN,gKt,Zv,gKt,e7p,gKt,cFR,gKt,ea0,gKt,bsJ,gKt,ftY,gKt,bHP,gKt,cpv,gKt,bvz,gKt,bYR,gKt,dQG,gKt,bce,gKt,ejc,gKt,cUK,gKt,cEv,gKt,eF9,gKt,dHq,gKt,apk,gKt,cWK,gKt,d3i,gKt,cIr,gKt,eqv,gKt,bXf,gKt,bvr,gKt,etx,gKt,$h,gKt,dVU,gKt,cnt,gKt,cHP,gKt,eOS,gKt,eHH,gKt,ekk,gKt,bfX,gKt,fbZ,gKt,cQ4,gKt,frG,gKt,dv_,gKt,dCx,gKt,aiS,gKt,$T,gKt,fbQ,gKt,b3H,gKt,amk,gKt,cPW,gKt,cs9,gKt,b99,gKt,cBn,gKt,cKv,gKt,cib,gKt,bno,gKt,aRG,gKt,anJ,gKt,fjb,gKt,eEO,gKt,cuh,gKt,dlb,gKt,eJx,gKt,aLL,gKt,cQE,gKt,cw1,gKt,dTE,gKt,ctH,gKt,ei5,gKt,clz,gKt,dAz,gKt,cqd,gKt,bgr,gKt,e9Z,gKt,cX2,gKt,axa,gKt,ao5,gKt,dUd,gKt,e3V,gKt,bN7,gKt,ev0,gKt,dHL,gKt,bwt,gKt,dUg,gKt,fhh,gKt,eK_,gKt,cWe,gKt,bny,gKt,bsh,gKt,el5,gKt,b8v,gKt,ewQ,gKt,aS4,gKt,cYO,gKt,cPy,gKt,bUD,gKt,aTo,gKt,dsL,gKt,adv,gKt,an7,gKt,eyC,gKt,ei6,gKt,c1u,gKt,ev_,gKt,ZR,gKt,bj5,gKt,e45,gKt,eww,gKt,dDV,gKt,cPY,gKt,fh8,gKt,e7x,gKt,aT7,gKt,bGf,gKt,acY,gKt,bGx,gKt,eaC,gKt,ad6,gKt,eZv,gKt,eU5,gKt,dMt,gKt,el_,gKt,aY9,gKt,dHo,gKt,aZL,gKt,dqt,gKt,avz,gKt,cJb,gKt,elH,gKt,b1d,gKt,bFj,gKt,e0R,gKt,abK,gKt,aY2,gKt,bTb,gKt,cYm,gKt,dHC,gKt,cmx,gKt,a6i,gKt,dCN,gKt,cOi,gKt,bSv,gKt,fs0,gKt,arI,gKt,bQt,gKt,eT4,gKt,cdX,gKt,alg,gKt,cEm,gKt,cxl,gKt,bzV,gKt,c0t,gKt,cj$,gKt,e_I,gKt,aD6,gKt,bw$,gKt,buV,gKt,XI,gKt,dlW,gKt,dwN,gKt,b79,gKt,dNL,gKt,bFZ,gKt,bjq,gKt,eEb,gKt,bSl,gKt,dgV,gKt,anH,gKt,aV1,gKt,ebR,gKt,cLG,gKt,b$d,gKt,eJs,gKt,cPQ,gKt,aQW,gKt,bwf,gKt,aiM,gKt,aIF,gKt,fbN,gKt,eSA,gKt,bcy,gKt,chF,gKt,e1K,gKt,crZ,gKt,and,gKt,bgE,gKt,cJ8,gKt,a6e,gKt,cWM,gKt,eXp,gKt,avL,gKt,aNG,gKt,YR,gKt,cT_,gKt,ehQ,gKt,cq$,gKt,dlz,gKt,dOM,gKt,ewV,gKt,YC,gKt,a6U,gKt,bUT,gKt,aoT,gKt,bDr,gKt,di3,gKt,eL0,gKt,eS9,gKt,auu,gKt,Ya,gKt,bwn,gKt,bNx,gKt,cfD,gKt,eam,gKt,ezA,gKt,cjF,gKt,bxz,gKt,cOy,gKt,ehH,gKt,dyE,gKt,cKJ,gKt,bJV,gKt,eXv,gKt,coT,gKt,awU,gKt,e4t,gKt,ajx,gKt,am3,gKt,a7S,gKt,ebA,gKt,cWE,gKt,_T,gKt,dTz,gKt,dYE,gKt,a_a,gKt,dhn,gKt,fg2,gKt,d4l,gKt,bIV,gKt,dIb,gKt,b3F,gKt,b9l,gKt,ebU,gKt,eNo,gKt,cpz,gKt,eTS,gKt,cb5,gKt,ecP,gKt,eMt,gKt,b7H,gKt,aI7,gKt,dP3,gKt,a52,gKt,c0c,gKt,ZP,gKt,eVb,gKt,d7F,gKt,eTr,gKt,bEH,gKt,bLz,gKt,aik,gKt,e7d,gKt,b7t,gKt,dEG,gKt,bPL,gKt,fla,gKt,b_Z,gKt,bZL,gKt,eDx,gKt,c$E,gKt,aiq,gKt,d_e,gKt,dN0,gKt,a3B,gKt,bFD,gKt,cRs,gKt,d0v,gKt,dt_,gKt,cv3,gKt,dor,gKt,aq4,gKt,bI5,gKt,coV,gKt,etg,gKt,bvN,gKt,e1t,gKt,Z3,gKt,d$K,gKt,aAc,gKt,fvD,gKt,ds8,gKt,b1T,gKt,epw,gKt,aMH,gKt,mn,gKt,bB3,gKt,cmv,gKt,dvh,gKt,cYQ,gKt,cKq,gKt,al6,gKt,aI_,gKt,bDB,gKt,bWR,gKt,dnU,gKt,cZE,gKt,c$$,gKt,cc9,gKt,kg,gKt,bJT,gKt,cF0,gKt,d35,gKt,cQ0,gKt,cI7,gKt,bvL,gKt,cvF,gKt,eE4,gKt,crX,gKt,b_9,gKt,dHh,gKt,eSH,gKt,cFm,gKt,ciN,gKt,it,gKt,crn,gKt,aQQ,gKt,a5p,gKt,bJb,gKt,eNL,gKt,cdJ,gKt,dR2,gKt,bwL,gKt,d36,gKt,egK,gKt,dIj,gKt,bxx,gKt,a23,gKt,alq,gKt,crh,gKt,aWu,gKt,bdh,gKt,elX,gKt,due,gKt,eKy,gKt,bU7,gKt,eRS,gKt,abX,gKt,elM,gKt,cQu,gKt,fb$,gKt,avT,gKt,al1,gKt,bIX,gKt,fs_,gKt,avx,gKt,b5V,gKt,bfc,gKt,dGa,gKt,bGR,gKt,elG,gKt,duq,gKt,dH1,gKt,fo_,gKt,dzI,gKt,bbS,gKt,fbz,gKt,bjF,gKt,fcb,gKt,bPX,gKt,b0j,gKt,bap,gKt,aqL,gKt,bEJ,gKt,aDQ,gKt,dxN,gKt,avr,gKt,bGv,gKt,akx,gKt,fm0,gKt,b6t,gKt,e1O,gKt,eMZ,gKt,aEc,gKt,a5K,gKt,dOV,gKt,fcy,gKt,bmv,gKt,eKS,gKt,bTZ,gKt,aMV,gKt,bZB,gKt,aK2,gKt,d4N,gKt,cTE,gKt,eyT,gKt,dA6,gKt,cH1,gKt,fjj,gKt,fj3,gKt,fuC,gKt,bXh,gKt,dHP,gKt,eUu,gKt,cSO,gKt,b1z,gKt,aWJ,gKt,brL,gKt,aIE,gKt,aB7,gKt,c_e,gKt,cnj,gKt,aQU,gKt,eFC,gKt,caj,gKt,akl,gKt,eCY,gKt,cdL,gKt,cOY,gKt,e_O,gKt,cZI,gKt,aGF,gKt,eLD,gKt,dQx,gKt,cxr,gKt,bg9,gKt,dYz,gKt,dLU,gKt,cFj,gKt,fiW,gKt,e9S,gKt,aBA,gKt,eEM,gKt,euZ,gKt,eCk,gKt,fdF,gKt,cbJ,gKt,csZ,gKt,dyH,gKt,bGD,gKt,cih,gKt,djb,gKt,bJz,gKt,dzL,gKt,d5X,gKt,dKi,gKt,dNp,gKt,dML,gKt,fbu,gKt,dNM,gKt,ceD,gKt,cZQ,gKt,acu,gKt,b19,gKt,b$J,gKt,cdP,gKt,d$Q,gKt,bUN,gKt,dmb,gKt,dPO,gKt,dCC,gKt,ab7,gKt,eZO,gKt,aZ5,gKt,cFs,gKt,eeX,gKt,cVm,gKt,ary,gKt,aKD,gKt,bgJ,gKt,en8,gKt,dKB,gKt,d7Q,gKt,dyM,gKt,aiD,gKt,_$,gKt,aKv,gKt,b2x,gKt,bIt,gKt,ci$,gKt,eYm,gKt,cEN,gKt,cCC,gKt,bGJ,gKt,apC,gKt,bZh,gKt,eur,gKt,aNE,gKt,doW,gKt,aGB,gKt,br3,gKt,de2,gKt,d4b,gKt,aOQ,gKt,coz,gKt,cJN,gKt,e7i,gKt,bUj,gKt,dGs,gKt,eJc,gKt,cBr,gKt,biW,gKt,cbf,gKt,bJd,gKt,cqT,gKt,cCW,gKt,ciH,gKt,cbF,gKt,ezi,gKt,b5b,gKt,dxe,gKt,dkn,gKt,aKb,gKt,d1h,gKt,aC1,gKt,aX1,gKt,cO_,gKt,cPs,gKt,bxd,gKt,dlh,gKt,bJt,gKt,_p,gKt,awc,gKt,bCx,gKt,a22,gKt,d4g,gKt,cuN,gKt,bJX,gKt,aV9,gKt,ZE,gKt,bMf,gKt,cIg,gKt,ep_,gKt,aXI,gKt,bFF,gKt,cQ2,gKt,b_b,gKt,bXp,gKt,cdp,gKt,egI,gKt,clV,gKt,cfP,gKt,a9v,gKt,bit,gKt,bDX,gKt,eq8,gKt,aLp,gKt,bc7,gKt,cZK,gKt,apV,gKt,evo,gKt,bPx,gKt,e$i,gKt,cVS,gKt,cm7,gKt,cBq,gKt,cbL,gKt,bIP,gKt,cN1,gKt,bZZ,gKt,ayD,gKt,cXw,gKt,bHx,gKt,eGj,gKt,cXO,gKt,d48,gKt,b2B,gKt,eRC,gKt,crx,gKt,b3T,gKt,ac4,gKt,bA1,gKt,chD,gKt,aNS,gKt,eLo,gKt,bRP,gKt,cUA,gKt,aK0,gKt,eja,gKt,aR0,gKt,dBq,gKt,bW5,gKt,aWZ,gKt,dq1,gKt,cmp,gKt,akt,gKt,acr,gKt,bAj,gKt,ao_,gKt,dTC,gKt,caN,gKt,bIH,gKt,cJF,gKt,bTF,gKt,bxN,gKt,bST,gKt,cwZ,gKt,brV,gKt,aFY,gKt,c_S,gKt,ca$,gKt,dlX,gKt,Zt,gKt,cqp,gKt,cw7,gKt,bsr,gKt,aAA,gKt,cYa,gKt,bYP,gKt,eSk,gKt,aOF,gKt,b4B,gKt,efS,gKt,cXY,gKt,d4C,gKt,c2w,gKt,boq,gKt,bY1,gKt,gIs,gKt,bdS,gKt,ci1,gKt,cKV,gKt,cpB,gKt,cD6,gKt,cBh,gKt,bAn,gKt,aS2,gKt,e9$,gKt,e91,gKt,eV_,gKt,alS,gKt,c$u,gKt,bfq,gKt,eVt,gKt,cxR,gKt,eXw,gKt,bvF,gKt,fvz,gKt,bIB,gKt,cLy,gKt,ap0,gKt,eWm,gKt,cod,gKt,etU,gKt,a88,gKt,d3U,gKt,dJr,gKt,eEX,gKt,eGA,gKt,ff1,gKt,ch3,gKt,b4z,gKt,br5,gKt,cwF,gKt,bKH,gKt,eLF,gKt,eiu,gKt,aCa,gKt,dOA,gKt,ctZ,gKt,arR,gKt,cu9,gKt,cyp,gKt,cOC,gKt,bt7,gKt,fk0,gKt,b73,gKt,d4z,gKt,aoW,gKt,bAd,gKt,dKb,gKt,eoR,gKt,cGt,gKt,aP2,gKt,b6Z,gKt,aJV,gKt,cqn,gKt,bPD,gKt,arC,gKt,arM,gKt,ad0,gKt,cEc,gKt,acS,gKt,dh3,gKt,bNv,gKt,ct7,gKt,c$q,gKt,b5B,gKt,ca9,gKt,eIX,gKt,cSg,gKt,cDG,gKt,cgt,gKt,a9a,gKt,a7Q,gKt,ciz,gKt,bwJ,gKt,ejG,gKt,aSa,gKt,cGV,gKt,cRu,gKt,fjc,gKt,aPB,gKt,ch5,gKt,elj,gKt,bWH,gKt,bWd,gKt,d3z,gKt,bh$,gKt,cWu,gKt,buF,gKt,fcI,gKt,ab5,gKt,fsy,gKt,arg,gKt,aYP,gKt,b_j,gKt,bgq,gKt,crB,gKt,eXh,gKt,cXy,gKt,bax,gKt,bv1,gKt,bia,gKt,frh,gKt,cF6,gKt,eek,gKt,cRc,gKt,atN,gKt,brB,gKt,crr,gKt,e48,gKt,aWb,gKt,eb$,gKt,faa,gKt,eu_,gKt,bjc,gKt,fcX,gKt,eps,gKt,ay0,gKt,d3x,gKt,cT0,gKt,aUH,gKt,eyR,gKt,brZ,gKt,e3x,gKt,elB,gKt,ayF,gKt,bjS,gKt,adN,gKt,bDJ,gKt,Y$,gKt,e6V,gKt,dKO,gKt,dNq,gKt,e36,gKt,bML,gKt,e1W,gKt,dLF,gKt,a42,gKt,ctd,gKt,alE,gKt,dJP,gKt,cjB,gKt,bwF,gKt,aJT,gKt,erh,gKt,bCF,gKt,cij,gKt,dsX,gKt,eiD,gKt,dP9,gKt,d4X,gKt,bjO,gKt,aO4,gKt,bAf,gKt,cgl,gKt,apg,gKt,ctb,gKt,b6X,gKt,d7G,gKt,frY,gKt,anX,gKt,efD,gKt,aGE,gKt,dUE,gKt,cQC,gKt,d4v,gKt,a4R,gKt,eIm,gKt,bwj,gKt,cCK,gKt,cB3,gKt,fgM,gKt,emC,gKt,dP$,gKt,bW3,gKt,cKc,gKt,aZF,gKt,d3m,gKt,Zx,gKt,cQK,gKt,bSR,gKt,e8i,gKt,cOG,gKt,brH,gKt,a4Z,gKt,dKC,gKt,dGU,gKt,eQ6,gKt,elc,gKt,bId,gKt,exT,gKt,cfL,gKt,e4r,gKt,dpR,gKt,a5M,gKt,aWw,gKt,aXH,gKt,cLX,gKt,anz,gKt,fu6,gKt,cPc,gKt,aa1,gKt,ap4,gKt,crF,gKt,aYU,gKt,a7X,gKt,dYL,gKt,el1,gKt,d7W,gKt,fsE,gKt,aZ8,gKt,eqN,gKt,cBv,gKt,c1G,gKt,drd,gKt,cZ8,gKt,eWr,gKt,aDO,gKt,dq9,gKt,dUA,gKt,ct$,gKt,bQz,gKt,awM,gKt,dIh,gKt,amB,gKt,alW,gKt,aQX,gKt,eJM,gKt,cf7,gKt,bN9,gKt,fky,gKt,d1R,gKt,aYJ,gKt,dMF,gKt,dis,gKt,ce$,gKt,buD,gKt,e0B,gKt,aqm,gKt,dqk,gKt,Y3,gKt,bs$,gKt,cxx,gKt,bUx,gKt,eUi,gKt,cDj,gKt,d8Y,gKt,cPw,gKt,aq3,gKt,eRh,gKt,cFW,gKt,eIV,gKt,erf,gKt,dhp,gKt,am$,gKt,c0e,gKt,aLI,gKt,b23,gKt,b1Z,gKt,eyV,gKt,anN,gKt,aOj,gKt,acj,gKt,btJ,gKt,en_,gKt,fiV,gKt,a7L,gKt,aPl,gKt,cJD,gKt,cEk,gKt,ayN,gKt,b39,gKt,aMX,gKt,bmH,gKt,aS0,gKt,bXN,gKt,dVQ,gKt,ezo,gKt,dmI,gKt,fg_,gKt,baw,gKt,e1T,gKt,dSr,gKt,bPp,gKt,bKD,gKt,cuR,gKt,c1l,gKt,aRR,gKt,cCp,gKt,eFA,gKt,dL8,gKt,aO9,gKt,dGt,gKt,aN7,gKt,fdI,gKt,aTD,gKt,fsf,gKt,aNt,gKt,ec2,gKt,ajD,gKt,eR$,gKt,akH,gKt,eTm,gKt,eGr,gKt,bFX,gKt,ck1,gKt,eL$,gKt,aTB,gKt,b0D,gKt,bx5,gKt,cOW,gKt,aYA,gKt,dR_,gKt,aKp,gKt,dZE,gKt,c1d,gKt,aPx,gKt,ar7,gKt,eYG,gKt,eFR,gKt,clt,gKt,bBn,gKt,exM,gKt,dNW,gKt,b9V,gKt,a50,gKt,bZr,gKt,an$,gKt,bQF,gKt,gIt,gKt,eLq,gKt,cQs,gKt,elU,gKt,ai5,gKt,aHh,gKt,ehI,gKt,bUt,gKt,btl,gKt,cCY,gKt,ac0,gKt,ben,gKt,buZ,gKt,ccL,gKt,adl,gKt,amF,gKt,RZ,gKt,aLF,gKt,cjf,gKt,cgf,gKt,cmh,gKt,e$f,gKt,eS_,gKt,ctV,gKt,buj,gKt,d8W,gKt,bkw,gKt,cWc,gKt,dmD,gKt,bsj,gKt,bO$,gKt,aCp,gKt,cZ0,gKt,dBK,gKt,eER,gKt,bvt,gKt,eHR,gKt,cfb,gKt,eLX,gKt,fhN,gKt,ebT,gKt,dBf,gKt,fhK,gKt,bPT,gKt,eQ1,gKt,brJ,gKt,bAL,gKt,aV$,gKt,ctz,gKt,cIt,gKt,dvd,gKt,fiY,gKt,cdH,gKt,edd,gKt,cEB,gKt,bog,gKt,fpc,gKt,Yc,gKt,fbU,gKt,b2L,gKt,bjo,gKt,bPz,gKt,ZC,gKt,aYv,gKt,eFu,gKt,ejE,gKt,ano,gKt,dPM,gKt,cWk,gKt,eAf,gKt,c1E,gKt,ck3,gKt,bKB,gKt,dt5,gKt,dzr,gKt,dJM,gKt,boi,gKt,ckl,gKt,aXT,gKt,a67,gKt,dPH,gKt,cqZ,gKt,bzT,gKt,frQ,gKt,cvh,gKt,cql,gKt,d3D,gKt,bOv,gKt,cDv,gKt,dQI,gKt,dwH,gKt,ciT,gKt,aF_,gKt,evI,gKt,esp,gKt,bNN,gKt,bhx,gKt,bnc,gKt,e8G,gKt,dMD,gKt,aOL,gKt,duO,gKt,b1r,gKt,bUF,gKt,aad,gKt,clf,gKt,ah9,gKt,eaT,gKt,eIR,gKt,b8h,gKt,bDf,gKt,e64,gKt,dZV,gKt,cl7,gKt,eRX,gKt,dUs,gKt,aV2,gKt,ejY,gKt,$G,gKt,dig,gKt,a_$,gKt,d52,gKt,a3g,gKt,cPo,gKt,bLh,gKt,aQm,gKt,bIJ,gKt,eHP,gKt,dlJ,gKt,cqN,gKt,d4x,gKt,eMR,gKt,apK,gKt,bFz,gKt,c00,gKt,cLP,gKt,bCf,gKt,cI2,gKt,bZF,gKt,fdf,gKt,cHN,gKt,bYX,gKt,aRU,gKt,XT,gKt,aW6,gKt,cPq,gKt,fpe,gKt,eqS,gKt,bJh,gKt,coR,gKt,alk,gKt,btH,gKt,aS$,gKt,b3v,gKt,bSB,gKt,aN3,gKt,eu4,gKt,cUi,gKt,b7h,gKt,bW7,gKt,cin,gKt,bux,gKt,aNC,gKt,eD4,gKt,d4o,gKt,a5B,gKt,cNT,gKt,cYe,gKt,d9r,gKt,ejl,gKt,dp6,gKt,b6H,gKt,bWv,gKt,dE6,gKt,aix,gKt,dlq,gKt,hB,gKt,c0k,gKt,eLm,gKt,ans,gKt,csn,gKt,coh,gKt,dHn,gKt,aex,gKt,aG6,gKt,aNA,gKt,ftG,gKt,dG0,gKt,bJ5,gKt,a29,gKt,d15,gKt,cdN,gKt,bEL,gKt,cW_,gKt,bfR,gKt,bK5,gKt,eSp,gKt,bWD,gKt,edo,gKt,ccD,gKt,bAH,gKt,dZO,gKt,dFK,gKt,fbe,gKt,bw7,gKt,d5m,gKt,b_J,gKt,ee1,gKt,cxJ,gKt,dk9,gKt,eXn,gKt,aI9,gKt,fiQ,gKt,boL,gKt,bzr,gKt,cp9,gKt,cc1,gKt,ce1,gKt,auk,gKt,dud,gKt,cAb,gKt,cbZ,gKt,eeN,gKt,cXW,gKt,ay_,gKt,VF,gKt,aUS,gKt,by1,gKt,dRi,gKt,bYT,gKt,cK4,gKt,aM3,gKt,eAx,gKt,cIB,gKt,bH3,gKt,bfZ,gKt,dGH,gKt,eyc,gKt,cTK,gKt,acE,gKt,dpq,gKt,cez,gKt,dg0,gKt,as5,gKt,aFZ,gKt,ce7,gKt,cYk,gKt,dES,gKt,e09,gKt,csh,gKt,cTc,gKt,blj,gKt,fs2,gKt,etC,gKt,bnO,gKt,am1,gKt,cgF,gKt,dDO,gKt,atu,gKt,dMn,gKt,fh2,gKt,dfa,gKt,dhN,gKt,aF6,gKt,dL7,gKt,eM6,gKt,bIh,gKt,bF1,gKt,dHR,gKt,bGj,gKt,euk,gKt,cfz,gKt,aol,gKt,aOO,gKt,XN,gKt,flI,gKt,eqE,gKt,bxR,gKt,bK9,gKt,bry,gKt,bOX,gKt,Z1,gKt,bB7,gKt,cZs,gKt,dvm,gKt,dkY,gKt,aXn,gKt,api,gKt,cY6,gKt,fb7,gKt,ean,gKt,aBO,gKt,aSH,gKt,aH0,gKt,Xo,gKt,cFI,gKt,aWn,gKt,eJi,gKt,e1Y,gKt,can,gKt,a3H,gKt,aRw,gKt,bgB,gKt,cGG,gKt,bGp,gKt,al4,gKt,b_N,gKt,$C,gKt,cDE,gKt,eGz,gKt,dhY,gKt,bVp,gKt,bip,gKt,b1v,gKt,cqR,gKt,dDE,gKt,dOy,gKt,dtZ,gKt,abz,gKt,dim,gKt,d0e,gKt,eqW,gKt,bdb,gKt,amr,gKt,efG,gKt,bB5,gKt,cUU,gKt,b8b,gKt,eN0,gKt,aWS,gKt,cuj,gKt,bV3,gKt,car,gKt,bE7,gKt,cHf,gKt,bzt,gKt,cBl,gKt,dJ2,gKt,eyl,gKt,fgu,gKt,cd3,gKt,cT4,gKt,byT,gKt,aa$,gKt,aGR,gKt,b9x,gKt,ejm,gKt,bwR,gKt,e0G,gKt,b0$,gKt,cDn,gKt,auD,gKt,d7S,gKt,bnu,gKt,c1X,gKt,eT3,gKt,bA3,gKt,chz,gKt,eAV,gKt,aMx,gKt,aM5,gKt,bKL,gKt,Z8,gKt,aDj,gKt,bhr,gKt,fi1,gKt,aq0,gKt,a5F,gKt,ezg,gKt,civ,gKt,eTv,gKt,bQL,gKt,bKj,gKt,c_y,gKt,drw,gKt,aRS,gKt,b4Z,gKt,ecl,gKt,cgd,gKt,b8T,gKt,b5n,gKt,a_Y,gKt,aUj,gKt,bhN,gKt,a62,gKt,bt5,gKt,d8y,gKt,dZL,gKt,bBT,gKt,dkd,gKt,eWK,gKt,cxH,gKt,ane,gKt,XE,gKt,by3,gKt,cdx,gKt,cSI,gKt,d5Z,gKt,eVV,gKt,baO,gKt,aWd,gKt,e47,gKt,b2d,gKt,eSw,gKt,eo5,gKt,cLe,gKt,b1j,gKt,avN,gKt,cHr,gKt,b7V,gKt,cwB,gKt,cHJ,gKt,bHl,gKt,aRo,gKt,dlB,gKt,cS_,gKt,bUh,gKt,cpx,gKt,cqX,gKt,bRn,gKt,b2D,gKt,caz,gKt,cg9,gKt,cfd,gKt,dir,gKt,fuk,gKt,b7L,gKt,dxB,gKt,bPd,gKt,e1z,gKt,bXV,gKt,eDQ,gKt,cEq,gKt,b8H,gKt,bvd,gKt,a3i,gKt,bjW,gKt,dGg,gKt,b7l,gKt,c_K,gKt,bJj,gKt,a8O,gKt,dry,gKt,eV5,gKt,e5W,gKt,c18,gKt,cct,gKt,b01,gKt,bAR,gKt,fgJ,gKt,eGZ,gKt,cGx,gKt,cmP,gKt,cTu,gKt,aaj,gKt,bS9,gKt,ckL,gKt,cBt,gKt,bjv,gKt,cS4,gKt,akT,gKt,dJK,gKt,bOz,gKt,b7d,gKt,dkK,gKt,dTu,gKt,b_F,gKt,b95,gKt,eMj,gKt,bdl,gKt,fsb,gKt,efF,gKt,ce3,gKt,bsB,gKt,dRl,gKt,aaT,gKt,dG1,gKt,edV,gKt,bDd,gKt,foj,gKt,adB,gKt,cIH,gKt,d7h,gKt,elW,gKt,d8r,gKt,cxL,gKt,bHn,gKt,eK1,gKt,fuB,gKt,bdt,gKt,bJJ,gKt,fgH,gKt,cD1,gKt,dAQ,gKt,eFD,gKt,ajO,gKt,eJR,gKt,dJI,gKt,bTn,gKt,cZe,gKt,cOc,gKt,c1Q,gKt,bHT,gKt,auw,gKt,co3,gKt,dT8,gKt,cVa,gKt,bcP,gKt,aqz,gKt,eTG,gKt,fh9,gKt,cKx,gKt,aY4,gKt,bNF,gKt,eKR,gKt,fcG,gKt,a8S,gKt,cjt,gKt,btx,gKt,dng,gKt,e7g,gKt,bst,gKt,evq,gKt,cDr,gKt,eJZ,gKt,eMS,gKt,ckP,gKt,dYH,gKt,bKt,gKt,eg1,gKt,eZr,gKt,b57,gKt,dwU,gKt,bnC,gKt,ba4,gKt,b$3,gKt,eN2,gKt,b6P,gKt,dD7,gKt,abV,gKt,e0z,gKt,aVn,gKt,aeK,gKt,bXP,gKt,a9e,gKt,apm,gKt,eJv,gKt,d_y,gKt,cLw,gKt,cfj,gKt,d0K,gKt,dsV,gKt,bMJ,gKt,chl,gKt,dvW,gKt,ecA,gKt,bkS,gKt,bsZ,gKt,bzZ,gKt,bTL,gKt,crz,gKt,e83,gKt,e9q,gKt,faq,gKt,faE,gKt,eEe,gKt,YN,gKt,bLd,gKt,bek,gKt,asF,gKt,dF7,gKt,b$7,gKt,eBU,gKt,Zg,gKt,dtD,gKt,a7J,gKt,e3F,gKt,e3R,gKt,d9L,gKt,YE,gKt,bHp,gKt,eUy,gKt,bAz,gKt,ab1,gKt,eft,gKt,aCg,gKt,buH,gKt,bTh,gKt,eE1,gKt,dRU,gKt,ak$,gKt,aJ2,gKt,cxT,gKt,ftV,gKt,dJZ,gKt,bLb,gKt,Yy,gKt,ax3,gKt,cmT,gKt,dyr,gKt,cJs,gKt,b$P,gKt,aQO,gKt,bSx,gKt,aDL,gKt,eVk,gKt,b0f,gKt,d1a,gKt,eyO,gKt,avF,gKt,bAx,gKt,dCM,gKt,jL,gKt,auc,gKt,cpN,gKt,cs$,gKt,cXC,gKt,by9,gKt,aVX,gKt,cVi,gKt,fdh,gKt,bz5,gKt,eNq,gKt,akP,gKt,cWi,gKt,eTo,gKt,bVx,gKt,bc3,gKt,cvH,gKt,cTG,gKt,XA,gKt,b9$,gKt,dsM,gKt,eJB,gKt,ewh,gKt,d$_,gKt,cbV,gKt,bTp,gKt,cal,gKt,eg0,gKt,cLA,gKt,aiT,gKt,cn1,gKt,frB,gKt,asz,gKt,aNy,gKt,aEb,gKt,cop,gKt,cMB,gKt,btP,gKt,c_i,gKt,aSJ,gKt,bEp,gKt,eEY,gKt,d3B,gKt,d54,gKt,crt,gKt,bJR,gKt,dhb,gKt,dvY,gKt,att,gKt,b7N,gKt,b1x,gKt,bG3,gKt,cBI,gKt,cex,gKt,cR2,gKt,b$5,gKt,aRq,gKt,b4V,gKt,eqy,gKt,bL$,gKt,aIL,gKt,aP0,gKt,fj1,gKt,Y9,gKt,avB,gKt,bbV,gKt,cSi,gKt,epP,gKt,bNn,gKt,aZZ,gKt,cuZ,gKt,bkN,gKt,bZn,gKt,cat,gKt,dno,gKt,eos,gKt,e4c,gKt,aAH,gKt,Yn,gKt,eZg,gKt,eJf,gKt,cK$,gKt,dQ7,gKt,e7N,gKt,aIl,gKt,bTD,gKt,at2,gKt,b3t,gKt,cwH,gKt,bXR,gKt,cSw,gKt,fib,gKt,dKX,gKt,bzN,gKt,dJy,gKt,b5h,gKt,b8L,gKt,cmL,gKt,dyc,gKt,bQ9,gKt,bK1,gKt,aJu,gKt,fq1,gKt,cEg,gKt,dMG,gKt,eHS,gKt,dFO,gKt,bZ$,gKt,dg7,gKt,bjU,gKt,b8X,gKt,eLv,gKt,dM8,gKt,aLn,gKt,doi,gKt,dCS,gKt,d5E,gKt,ZY,gKt,b89,gKt,fvv,gKt,bEd,gKt,cnH,gKt,cIx,gKt,cmF,gKt,d9s,gKt,eEr,gKt,frf,gKt,duS,gKt,fh6,gKt,frT,gKt,dtO,gKt,cWC,gKt,eL5,gKt,bPl,gKt,dqy,gKt,akq,gKt,bUX,gKt,eob,gKt,eiZ,gKt,c$e,gKt,bir,gKt,djM,gKt,cst,gKt,cxn,gKt,dEe,gKt,b3p,gKt,a_M,gKt,cmb,gKt,bdJ,gKt,bIz,gKt,dUw,gKt,d_c,gKt,dHb,gKt,alr,gKt,bdH,gKt,ceF,gKt,dyG,gKt,aL$,gKt,d3s,gKt,cHv,gKt,eH0,gKt,akE,gKt,cwJ,gKt,aXf,gKt,ccl,gKt,anS,gKt,a_R,gKt,eQ_,gKt,ce5,gKt,e1B,gKt,eEn,gKt,ay7,gKt,cjr,gKt,d12,gKt,eZi,gKt,eqZ,gKt,eKB,gKt,aiV,gKt,bT7,gKt,e1s,gKt,cYY,gKt,bWN,gKt,atZ,gKt,bKR,gKt,fli,gKt,cvX,gKt,eoe,gKt,foO,gKt,co5,gKt,dYF,gKt,eje,gKt,cfX,gKt,dEx,gKt,ajI,gKt,cZG,gKt,ctt,gKt,btV,gKt,b1J,gKt,cCr,gKt,bBJ,gKt,eC6,gKt,caJ,gKt,elz,gKt,eSV,gKt,btt,gKt,bCD,gKt,eL3,gKt,ewf,gKt,fgS,gKt,d6j,gKt,dCZ,gKt,eKv,gKt,bOH,gKt,dJi,gKt,aYK,gKt,era,gKt,ld,gKt,bON,gKt,cR0,gKt,e$e,gKt,eTq,gKt,aZh,gKt,adF,gKt,dKd,gKt,cX6,gKt,cX8,gKt,atH,gKt,aXq,gKt,aQe,gKt,ejv,gKt,aLW,gKt,dhl,gKt,cPG,gKt,blR,gKt,fhq,gKt,aFG,gKt,bPR,gKt,_a,gKt,bzp,gKt,fq7,gKt,chH,gKt,b13,gKt,d1c,gKt,aBW,gKt,bZf,gKt,cLM,gKt,cgb,gKt,eYx,gKt,bmE,gKt,bgn,gKt,gAP,gKt,d9d,gKt,aRt,gKt,dD8,gKt,XM,gKt,eUp,gKt,fgg,gKt,bM7,gKt,eLe,gKt,bkz,gKt,bxF,gKt,fpb,gKt,cs5,gKt,cL4,gKt,ek7,gKt,e1H,gKt,chX,gKt,eYD,gKt,bWp,gKt,eLL,gKt,dAx,gKt,aK6,gKt,e7I,gKt,cS2,gKt,a5Q,gKt,bjQ,gKt,ayv,gKt,dBn,gKt,dJ0,gKt,cIa,gKt,av2,gKt,bFr,gKt,c0n,gKt,bCZ,gKt,aa5,gKt,bF5,gKt,at3,gKt,b61,gKt,bCR,gKt,aqt,gKt,eyo,gKt,c_A,gKt,cT2,gKt,eK8,gKt,dJ_,gKt,cpr,gKt,gzZ,gKt,dni,gKt,bF9,gKt,eB6,gKt,e1m,gKt,b9B,gKt,d_p,gKt,dL9,gKt,bH7,gKt,aP$,gKt,fld,gKt,eIQ,gKt,cm5,gKt,aJH,gKt,bRJ,gKt,abl,gKt,eYs,gKt,fg7,gKt,bUP,gKt,cSK,gKt,bP$,gKt,eAe,gKt,d0P,gKt,fc0,gKt,Xg,gKt,YG,gKt,cm3,gKt,dUJ,gKt,fuU,gKt,dfC,gKt,aa9,gKt,dgB,gKt,ZK,gKt,aav,gKt,ab3,gKt,$L,gKt,aqH,gKt,b5P,gKt,eTQ,gKt,adU,gKt,dxG,gKt,cGD,gKt,e8k,gKt,g7,gKt,bmb,gKt,aj8,gKt,eS7,gKt,ci7,gKt,aro,gKt,a_K,gKt,d$1,gKt,b21,gKt,fts,gKt,cvD,gKt,bGF,gKt,bwx,gKt,bED,gKt,aki,gKt,al_,gKt,a9k,gKt,ckB,gKt,aiu,gKt,brF,gKt,aMT,gKt,faY,gKt,cVK,gKt,cm9,gKt,cfv,gKt,cFp,gKt,btR,gKt,c2c,gKt,eap,gKt,a3Y,gKt,dPQ,gKt,csL,gKt,aU6,gKt,d0D,gKt,flD,gKt,eeD,gKt,aFw,gKt,fb6,gKt,aRW,gKt,dl3,gKt,eM9,gKt,dLR,gKt,ZG,gKt,bt1,gKt,g6,gKt,b5j,gKt,axc,gKt,apb,gKt,eLc,gKt,Yu,gKt,eFW,gKt,c0p,gKt,dKT,gKt,dOB,gKt,eVZ,gKt,a46,gKt,bSn,gKt,foZ,gKt,dtX,gKt,bCH,gKt,aJ5,gKt,aM7,gKt,d$S,gKt,eck,gKt,adD,gKt,dZZ,gKt,cB$,gKt,blu,gKt,cLE,gKt,dOZ,gKt,bLX,gKt,eGX,gKt,asn,gKt,cef,gKt,YK,gKt,eTJ,gKt,cHc,gKt,crp,gKt,byd,gKt,aX_,gKt,b8B,gKt,cCd,gKt,bsz,gKt,dNU,gKt,YA,gKt,cQ_,gKt,e4y,gKt,dZ3,gKt,bGB,gKt,dDG,gKt,bDj,gKt,eYF,gKt,eJl,gKt,ewA,gKt,bGX,gKt,a31,gKt,a_c,gKt,cEQ,gKt,aEy,gKt,b_z,gKt,ef8,gKt,diR,gKt,cAY,gKt,bS$,gKt,eEu,gKt,ali,gKt,ecQ,gKt,aZr,gKt,cMw,gKt,bs1,gKt,cNa,gKt,aDM,gKt,fqw,gKt,cl3,gKt,fgO,gKt,e1x,gKt,avJ,gKt,aY0,gKt,c$n,gKt,bL5,gKt,azs,gKt,eJW,gKt,cZq,gKt,epy,gKt,cDM,gKt,bfG,gKt,bDF,gKt,e1f,gKt,ccV,gKt,e_2,gKt,bOt,gKt,d3X,gKt,cl1,gKt,aka,gKt,ccP,gKt,eEQ,gKt,aY7,gKt,dEX,gKt,axB,gKt,aMN,gKt,c2f,gKt,acd,gKt,fnT,gKt,Xe,gKt,fs4,gKt,ewv,gKt,d5b,gKt,fbH,gKt,gzy,gKt,cZA,gKt,eyH,gKt,bAl,gKt,ca7,gKt,eph,gKt,ci9,gKt,cOM,gKt,dHd,gKt,bJN,gKt,flm,gKt,aTr,gKt,bxJ,gKt,cqP,gKt,$_,gKt,aQR,gKt,cNS,gKt,anQ,gKt,elS,gKt,bfO,gKt,bSL,gKt,bRl,gKt,e4f,gKt,a7x,gKt,azg,gKt,ebI,gKt,edU,gKt,dQD,gKt,aWx,gKt,gGF,gKt,aNO,gKt,cLT,gKt,bvH,gKt,aD9,gKt,b_R,gKt,aqZ,gKt,alC,gKt,dqv,gKt,cRG,gKt,bLB,gKt,els,gKt,cDY,gKt,bJ1,gKt,d3p,gKt,c_8,gKt,fpy,gKt,bJp,gKt,a9c,gKt,dje,gKt,baB,gKt,btp,gKt,bcs,gKt,cwX,gKt,fiJ,gKt,dvw,gKt,b2R,gKt,cRk,gKt,bHJ,gKt,cLV,gKt,eTW,gKt,e55,gKt,fgh,gKt,dJc,gKt,b_T,gKt,cbT,gKt,bcU,gKt,ees,gKt,bVN,gKt,dG5,gKt,fh_,gKt,bzH,gKt,elm,gKt,cJ2,gKt,b_7,gKt,dRd,gKt,bKl,gKt,cW8,gKt,c2y,gKt,aof,gKt,bCP,gKt,cwN,gKt,cI0,gKt,a_A,gKt,d4t,gKt,dxF,gKt,dIa,gKt,fnG,gKt,cjx,gKt,av0,gKt,chn,gKt,crP,gKt,bYD,gKt,cXE,gKt,ci5,gKt,djY,gKt,dBk,gKt,dTo,gKt,cjd,gKt,bHX,gKt,dmd,gKt,cH$,gKt,VE,gKt,bVH,gKt,cqL,gKt,cx7,gKt,bkb,gKt,b0x,gKt,b5N,gKt,dUq,gKt,exE,gKt,c0g,gKt,atM,gKt,bsb,gKt,eCn,gKt,a2_,gKt,bvl,gKt,lT,gKt,cxB,gKt,dof,gKt,ds6,gKt,XY,gKt,d0m,gKt,dAf,gKt,fiB,gKt,dqI,gKt,c1b,gKt,d1T,gKt,boN,gKt,aMz,gKt,amn,gKt,b2$,gKt,eDE,gKt,bwB,gKt,asj,gKt,eU7,gKt,dxy,gKt,fm_,gKt,dvD,gKt,eho,gKt,cVY,gKt,e4V,gKt,_F,gKt,dtK,gKt,Z4,gKt,eH$,gKt,big,gKt,ck$,gKt,bf1,gKt,byz,gKt,cJi,gKt,$o,gKt,cjv,gKt,aH1,gKt,bBP,gKt,bHF,gKt,bGV,gKt,d5$,gKt,d72,gKt,dgl,gKt,cuX,gKt,ejX,gKt,aWq,gKt,dna,gKt,YX,gKt,eis,gKt,ak_,gKt,b0N,gKt,cgJ,gKt,asa,gKt,cwt,gKt,$d,gKt,cPk,gKt,cP_,gKt,eiM,gKt,cHB,gKt,aBD,gKt,$3,gKt,aLw,gKt,clZ,gKt,e68,gKt,efL,gKt,b11,gKt,hZ,gKt,djK,gKt,aUx,gKt,fiC,gKt,dN_,gKt,fqC,gKt,bDH,gKt,dGF,gKt,d4U,gKt,b1D,gKt,aVm,gKt,eSS,gKt,dh2,gKt,bSH,gKt,cA0,gKt,cdT,gKt,aNI,gKt,ana,gKt,cm1,gKt,cLC,gKt,epA,gKt,dm8,gKt,cD_,gKt,fq$,gKt,cux,gKt,ccr,gKt,aaH,gKt,aiP,gKt,aXl,gKt,aZp,gKt,c1p,gKt,b8r,gKt,fvf,gKt,bPh,gKt,cX4,gKt,a6_,gKt,frA,gKt,dl7,gKt,cTI,gKt,Zn,gKt,cUc,gKt,cn$,gKt,eEa,gKt,bMT,gKt,bFd,gKt,cpl,gKt,caB,gKt,dR9,gKt,dC0,gKt,Xq,gKt,aq2,gKt,e1M,gKt,bWV,gKt,bKV,gKt,e5Z,gKt,b8D,gKt,d0M,gKt,aDr,gKt,bmG,gKt,cnv,gKt,azf,gKt,fbJ,gKt,Xc,gKt,ayo,gKt,aOW,gKt,bXF,gKt,d4F,gKt,bEx,gKt,fnS,gKt,cmV,gKt,aFx,gKt,cZc,gKt,cSc,gKt,cRY,gKt,eyn,gKt,dKQ,gKt,fnQ,gKt,cbz,gKt,_P,gKt,cXa,gKt,aRf,gKt,h1,gKt,bz7,gKt,cOK,gKt,cTq,gKt,bdm,gKt,bSN,gKt,d4K,gKt,aie,gKt,e7v,gKt,bJ7,gKt,eYe,gKt,csl,gKt,adH,gKt,amz,gKt,a6m,gKt,duL,gKt,ak0,gKt,aWl,gKt,bQ3,gKt,dCA,gKt,bP9,gKt,anD,gKt,bwz,gKt,baZ,gKt,b7n,gKt,azt,gKt,adS,gKt,Ze,gKt,aNx,gKt,dTw,gKt,aov,gKt,cWA,gKt,bXl,gKt,bQr,gKt,dUu,gKt,dR0,gKt,aSp,gKt,aqb,gKt,blO,gKt,eA4,gKt,Yl,gKt,a5r,gKt,bJP,gKt,c_G,gKt,fne,gKt,dCK,gKt,d7D,gKt,cKf,gKt,fau,gKt,fb4,gKt,aL0,gKt,fim,gKt,fay,gKt,bQb,gKt,eCQ,gKt,cKN,gKt,ama,gKt,bjL,gKt,dP6,gKt,bm$,gKt,dik,gKt,byJ,gKt,b15,gKt,ds4,gKt,cdB,gKt,bAV,gKt,alU,gKt,cQ8,gKt,d1_,gKt,cPA,gKt,a2U,gKt,a5_,gKt,buJ,gKt,ep0,gKt,eI7,gKt,etS,gKt,acO,gKt,dvk,gKt,aTI,gKt,abO,gKt,fpq,gKt,e3Z,gKt,e8u,gKt,bri,gKt,byh,gKt,anq,gKt,d$D,gKt,c02,gKt,b9n,gKt,e9P,gKt,eAK,gKt,eXr,gKt,apG,gKt,btL,gKt,gEM,gKt,d3E,gKt,aeQ,gKt,bS5,gKt,aTk,gKt,aI0,gKt,dY_,gKt,dRr,gKt,XG,gKt,cN8,gKt,chx,gKt,aCc,gKt,dSp,gKt,anl,gKt,ctr,gKt,ckt,gKt,cfx,gKt,ccp,gKt,apP,gKt,e1d,gKt,cc5,gKt,b6f,gKt,e3$,gKt,cdt,gKt,evF,gKt,cth,gKt,bP1,gKt,bRX,gKt,amx,gKt,d3G,gKt,azq,gKt,b$n,gKt,b0B,gKt,bcg,gKt,fnv,gKt,aZo,gKt,d1x,gKt,bTP,gKt,aGM,gKt,eqL,gKt,fbj,gKt,dwd,gKt,exx,gKt,d7K,gKt,aon,gKt,bvT,gKt,ev6,gKt,bF$,gKt,bHr,gKt,diJ,gKt,a9p,gKt,asg,gKt,cxV,gKt,dAh,gKt,ehW,gKt,aX0,gKt,eEI,gKt,amc,gKt,cPm,gKt,eQ9,gKt,aTw,gKt,aFC,gKt,dpn,gKt,e_L,gKt,flY,gKt,e0M,gKt,bwp,gKt,fjg,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt,gKt];var gB=[gKu,gKu,bd6,gKu,bea,gKu,bdY,gKu,bhf,gKu,bf4,gKu,bjx,gKu,beX,gKu,bkD,gKu,el8,gKu,jc,gKu,jb,gKu,bot,gKu,gAI,gKu,ja,gKu,emd,gKu,bhA,gKu,i9,gKu,bou,gKu,ema,gKu,bmg,gKu,gCG,gKu,gEl,gKu,je,gKu,ji,gKu,jh,gKu,bmU,gKu,gCh,gKu,gCn,gKu,gCi,gKu,jd,gKu,bkY,gKu,eme,gKu,i8,gKu,gGp,gKu,bf6,gKu,gGn,gKu,bd3,gKu,jg,gKu,blC,gKu,bgN,gKu,jf,gKu,bi_,gKu,bnH,gKu,gIf,gKu,el9,gKu,gCt,gKu,gAW,gKu,bph,gKu,gGo,gKu,gCB,gKu,gCx,gKu,gCw,gKu,bfg,gKu,emc,gKu,emb,gKu,gEg,gKu,gKu,gKu,gKu,gKu,gKu,gKu,gKu,gKu,gKu,gKu,gKu,gKu,gKu,gKu];var gC=[gKv,gKv,aHN,gKv,dkH,gKv,aw2,gKv,efX,gKv,e6h,gKv,e5j,gKv,dGL,gKv,eXF,gKv,eij,gKv,ew0,gKv,e$w,gKv,fcQ,gKv,aHQ,gKv,a71,gKv,fdY,gKv,ayb,gKv,dhQ,gKv,dzZ,gKv,aCC,gKv,evP,gKv,dms,gKv,doL,gKv,dsj,gKv,dV8,gKv,dRh,gKv,eYV,gKv,aFd,gKv,fcg,gKv,eaI,gKv,e9D,gKv,dAm,gKv,aKI,gKv,WO,gKv,esf,gKv,atf,gKv,TD,gKv,dmM,gKv,cAS,gKv,esa,gKv,Se,gKv,e10,gKv,aHD,gKv,bre,gKv,eOC,gKv,eZU,gKv,d1L,gKv,fjz,gKv,dww,gKv,brx,gKv,eru,gKv,eka,gKv,e5b,gKv,dny,gKv,eOF,gKv,eFI,gKv,e8R,gKv,aLg,gKv,eb9,gKv,bfx,gKv,ecH,gKv,aIw,gKv,fjN,gKv,drT,gKv,aHJ,gKv,dSg,gKv,edh,gKv,d6w,gKv,eiS,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv,gKv];var gD=[gKw,gKw,dkp,gKw,a5C,gKw,dDR,gKw,ell,gKw,aqN,gKw,cFb,gKw,dD6,gKw,dlN,gKw,afS,gKw,aUg,gKw,biS,gKw,eSs,gKw,dB4,gKw,er5,gKw,fiD,gKw,dR4,gKw,eU_,gKw,dRW,gKw,aLy,gKw,fiX,gKw,eg4,gKw,d3d,gKw,bk7,gKw,fr7,gKw,ebW,gKw,fnC,gKw,eRI,gKw,dxj,gKw,ae3,gKw,aSj,gKw,c$9,gKw,fiS,gKw,dmE,gKw,aeZ,gKw,aAh,gKw,frj,gKw,bmr,gKw,d4m,gKw,bhv,gKw,bar,gKw,e6$,gKw,fnB,gKw,a6j,gKw,afk,gKw,dBo,gKw,Sh,gKw,aeX,gKw,bdx,gKw,d1X,gKw,egR,gKw,dlx,gKw,aoA,gKw,aTH,gKw,aSI,gKw,af9,gKw,fgL,gKw,bcv,gKw,cNZ,gKw,dsx,gKw,aLt,gKw,eYK,gKw,erX,gKw,a6y,gKw,drC,gKw,aTb,gKw,e50,gKw,ecm,gKw,eZy,gKw,aO3,gKw,ip,gKw,eT1,gKw,do2,gKw,dUN,gKw,ap$,gKw,etc,gKw,c$m,gKw,VH,gKw,dM$,gKw,dlw,gKw,e9L,gKw,eVn,gKw,cJw,gKw,d9h,gKw,dTW,gKw,fm2,gKw,agQ,gKw,fb_,gKw,e0U,gKw,brh,gKw,dTS,gKw,aTM,gKw,dj1,gKw,eow,gKw,dkf,gKw,boH,gKw,frD,gKw,ef9,gKw,aGr,gKw,agr,gKw,eJw,gKw,dCn,gKw,agx,gKw,eEA,gKw,etz,gKw,dhJ,gKw,aBq,gKw,dOh,gKw,aIJ,gKw,dEV,gKw,ax7,gKw,d3j,gKw,aLH,gKw,boI,gKw,eN_,gKw,d3e,gKw,a_G,gKw,fa0,gKw,erE,gKw,evM,gKw,a0_,gKw,aIk,gKw,eD6,gKw,dR1,gKw,er6,gKw,aD8,gKw,aCd,gKw,aZE,gKw,eim,gKw,e_E,gKw,fm3,gKw,afq,gKw,ega,gKw,bjK,gKw,a4V,gKw,eVB,gKw,aH2,gKw,efp,gKw,dTR,gKw,d6g,gKw,aKy,gKw,e9u,gKw,epg,gKw,amo,gKw,epL,gKw,egH,gKw,afb,gKw,eIr,gKw,fil,gKw,dOo,gKw,eZ8,gKw,e0E,gKw,bdn,gKw,dUp,gKw,afF,gKw,dWm,gKw,ao2,gKw,beI,gKw,aSP,gKw,aBz,gKw,ayh,gKw,bbY,gKw,a44,gKw,eba,gKw,dLJ,gKw,aH5,gKw,dNI,gKw,afB,gKw,aQx,gKw,fo2,gKw,bbW,gKw,aQl,gKw,ft4,gKw,aKY,gKw,dO$,gKw,ee4,gKw,aBG,gKw,ejh,gKw,af5,gKw,eq0,gKw,e1Q,gKw,ir,gKw,a6B,gKw,aP1,gKw,dR8,gKw,a4X,gKw,eef,gKw,eeQ,gKw,ftR,gKw,d6a,gKw,dxa,gKw,afW,gKw,aW7,gKw,bcC,gKw,eaX,gKw,flF,gKw,agy,gKw,eeO,gKw,agh,gKw,d80,gKw,eRd,gKw,e7M,gKw,afo,gKw,dNt,gKw,fa3,gKw,dkQ,gKw,bgF,gKw,epN,gKw,a5u,gKw,e2o,gKw,dCR,gKw,eWc,gKw,fcY,gKw,afX,gKw,ejB,gKw,ev2,gKw,a0$,gKw,frX,gKw,dCf,gKw,aMF,gKw,ejz,gKw,flE,gKw,dDS,gKw,aM$,gKw,aS6,gKw,dtg,gKw,d8s,gKw,ek9,gKw,ebf,gKw,er3,gKw,eZC,gKw,ee2,gKw,aJO,gKw,U3,gKw,cGU,gKw,a5V,gKw,dT9,gKw,ek8,gKw,d5h,gKw,dUV,gKw,dAO,gKw,a6L,gKw,bas,gKw,a2X,gKw,fkZ,gKw,eys,gKw,eSK,gKw,eRB,gKw,dj5,gKw,bjf,gKw,baW,gKw,fdC,gKw,dwa,gKw,awP,gKw,e_C,gKw,act,gKw,eeG,gKw,baI,gKw,bk8,gKw,bm2,gKw,aS1,gKw,eco,gKw,e79,gKw,aGy,gKw,fpx,gKw,eqR,gKw,ehu,gKw,aKC,gKw,edF,gKw,e9r,gKw,aZS,gKw,eqF,gKw,apf,gKw,dPf,gKw,a7A,gKw,exI,gKw,dqp,gKw,dJk,gKw,dRo,gKw,awR,gKw,epz,gKw,eK9,gKw,dvA,gKw,aEe,gKw,dGx,gKw,dKI,gKw,a6A,gKw,dKt,gKw,bfs,gKw,c2n,gKw,afG,gKw,WM,gKw,aRv,gKw,VC,gKw,egi,gKw,aZV,gKw,eq4,gKw,azp,gKw,dDs,gKw,agF,gKw,a0Z,gKw,bgm,gKw,dol,gKw,aFB,gKw,dP8,gKw,dOI,gKw,eko,gKw,eya,gKw,ebc,gKw,fkR,gKw,a$g,gKw,ex_,gKw,agK,gKw,a9G,gKw,diM,gKw,bo4,gKw,dnn,gKw,ei2,gKw,dpr,gKw,agv,gKw,dQz,gKw,dZr,gKw,dnl,gKw,aNb,gKw,agS,gKw,flh,gKw,beJ,gKw,ba7,gKw,eOJ,gKw,cNY,gKw,fhx,gKw,VL,gKw,aQ3,gKw,dYI,gKw,eu5,gKw,eia,gKw,aW1,gKw,fab,gKw,eIT,gKw,dTm,gKw,dpt,gKw,elJ,gKw,fqA,gKw,am_,gKw,bgG,gKw,doZ,gKw,afR,gKw,atJ,gKw,d_1,gKw,c2M,gKw,ejH,gKw,aJL,gKw,eFU,gKw,fva,gKw,dZS,gKw,er0,gKw,cCV,gKw,du9,gKw,dGv,gKw,bdy,gKw,dN4,gKw,eDU,gKw,erT,gKw,bll,gKw,cGz,gKw,a4W,gKw,eU4,gKw,bl4,gKw,e_W,gKw,d_S,gKw,az4,gKw,arT,gKw,d0k,gKw,dPd,gKw,c$2,gKw,dNV,gKw,dZN,gKw,aQY,gKw,fcD,gKw,fa2,gKw,cEF,gKw,dnV,gKw,eDY,gKw,d9W,gKw,be7,gKw,dDQ,gKw,dOY,gKw,eOR,gKw,dye,gKw,a3C,gKw,ak8,gKw,ehK,gKw,dvS,gKw,afH,gKw,cIk,gKw,eeP,gKw,epM,gKw,eZL,gKw,dm_,gKw,akS,gKw,aHs,gKw,eEd,gKw,dzq,gKw,e8r,gKw,eVs,gKw,dio,gKw,d5I,gKw,ae6,gKw,ae8,gKw,dgy,gKw,agP,gKw,d0g,gKw,a7B,gKw,eYJ,gKw,dhi,gKw,e0D,gKw,eRY,gKw,eds,gKw,dTj,gKw,agn,gKw,bht,gKw,dBY,gKw,ee_,gKw,avV,gKw,d8u,gKw,fa1,gKw,fw5,gKw,a58,gKw,aKt,gKw,fwi,gKw,cK1,gKw,aAC,gKw,eaz,gKw,aOz,gKw,dz_,gKw,afs,gKw,iE,gKw,agM,gKw,dUQ,gKw,ft1,gKw,agC,gKw,eAU,gKw,eJh,gKw,fpw,gKw,blT,gKw,e9N,gKw,d0O,gKw,eBd,gKw,eS4,gKw,drf,gKw,dD4,gKw,ake,gKw,dKD,gKw,a8R,gKw,dGw,gKw,cFB,gKw,dyY,gKw,a3v,gKw,ewU,gKw,ezQ,gKw,evL,gKw,d9J,gKw,eAt,gKw,aGb,gKw,eE8,gKw,eeH,gKw,ekn,gKw,a4Y,gKw,fwc,gKw,ebn,gKw,cFY,gKw,Xf,gKw,fal,gKw,fjo,gKw,dJQ,gKw,a54,gKw,djF,gKw,e88,gKw,dhL,gKw,e9t,gKw,dxC,gKw,afU,gKw,d5R,gKw,d38,gKw,ejC,gKw,eqc,gKw,dQK,gKw,fb8,gKw,dvz,gKw,eok,gKw,ep7,gKw,ebm,gKw,edt,gKw,a6x,gKw,dzz,gKw,e2i,gKw,frU,gKw,brg,gKw,aLB,gKw,afv,gKw,eHY,gKw,dDT,gKw,aBE,gKw,ei1,gKw,euo,gKw,eSj,gKw,fwG,gKw,d5A,gKw,dmG,gKw,ezz,gKw,bm3,gKw,aYl,gKw,dQ0,gKw,aqS,gKw,dFu,gKw,eXf,gKw,aYR,gKw,eUL,gKw,dsb,gKw,eI6,gKw,eMf,gKw,afu,gKw,aAj,gKw,flf,gKw,esI,gKw,dji,gKw,afZ,gKw,edr,gKw,aLs,gKw,d46,gKw,a89,gKw,bj7,gKw,dnP,gKw,ehM,gKw,aJ7,gKw,cG_,gKw,ag5,gKw,h9,gKw,dqo,gKw,ar9,gKw,dRn,gKw,bgl,gKw,cEP,gKw,dQj,gKw,a1D,gKw,dVp,gKw,aK8,gKw,aUR,gKw,fm5,gKw,etA,gKw,ezk,gKw,d08,gKw,d9I,gKw,eK0,gKw,ags,gKw,cCv,gKw,ej0,gKw,fq3,gKw,dsN,gKw,dhK,gKw,dsP,gKw,eRL,gKw,fo1,gKw,dJ8,gKw,di7,gKw,er4,gKw,d5Q,gKw,eWC,gKw,fyt,gKw,exU,gKw,bih,gKw,aJ6,gKw,cD3,gKw,ebt,gKw,drB,gKw,aoV,gKw,dNf,gKw,aTl,gKw,as8,gKw,aPt,gKw,kD,gKw,bnR,gKw,eKL,gKw,dgk,gKw,ecU,gKw,a8E,gKw,dzX,gKw,eSm,gKw,eec,gKw,aql,gKw,eyr,gKw,e5$,gKw,aC4,gKw,afL,gKw,dRc,gKw,aGG,gKw,VG,gKw,dH0,gKw,aER,gKw,doA,gKw,a$j,gKw,cC7,gKw,esb,gKw,flg,gKw,avu,gKw,epk,gKw,ar4,gKw,fkT,gKw,dz8,gKw,fhX,gKw,ae_,gKw,eq5,gKw,UI,gKw,di4,gKw,cBU,gKw,aqo,gKw,dY1,gKw,fat,gKw,d7I,gKw,ftX,gKw,aBF,gKw,evv,gKw,eqx,gKw,dJE,gKw,agB,gKw,fo$,gKw,ds5,gKw,faD,gKw,blm,gKw,diN,gKw,esR,gKw,dgZ,gKw,W1,gKw,dh0,gKw,a6K,gKw,fg4,gKw,dZ2,gKw,eJ_,gKw,agd,gKw,erL,gKw,eoY,gKw,aNc,gKw,a4b,gKw,fyF,gKw,dIw,gKw,aG5,gKw,eZN,gKw,e3A,gKw,ekl,gKw,eUT,gKw,biB,gKw,eu7,gKw,eoc,gKw,bks,gKw,apR,gKw,dun,gKw,agm,gKw,fxa,gKw,e6Z,gKw,dDr,gKw,ae$,gKw,erS,gKw,bln,gKw,aZi,gKw,epv,gKw,amw,gKw,apU,gKw,ayE,gKw,aZ9,gKw,eB8,gKw,agw,gKw,d3t,gKw,d0T,gKw,aVi,gKw,ebG,gKw,amX,gKw,dBL,gKw,a__,gKw,f5b,gKw,gIu,gKw,fyd,gKw,d4M,gKw,aug,gKw,eEB,gKw,aGa,gKw,ewR,gKw,aJN,gKw,dqL,gKw,fdk,gKw,dJ$,gKw,dmq,gKw,dtF,gKw,dC1,gKw,eHI,gKw,dHZ,gKw,egb,gKw,dYO,gKw,eGc,gKw,aXU,gKw,dSR,gKw,dVo,gKw,ery,gKw,ea4,gKw,ap7,gKw,bgI,gKw,dkR,gKw,axf,gKw,cK8,gKw,e87,gKw,dSH,gKw,djm,gKw,d3F,gKw,bkP,gKw,aSf,gKw,fv$,gKw,afd,gKw,bg8,gKw,dMH,gKw,di6,gKw,ejA,gKw,aHg,gKw,dlL,gKw,eMJ,gKw,eaZ,gKw,aDH,gKw,bmK,gKw,eHT,gKw,aDK,gKw,fap,gKw,dUm,gKw,evu,gKw,cE8,gKw,ftO,gKw,d9X,gKw,agN,gKw,d7f,gKw,d$R,gKw,bl6,gKw,d1u,gKw,cHe,gKw,djp,gKw,dx_,gKw,c0d,gKw,aD$,gKw,dBF,gKw,d37,gKw,dG$,gKw,atI,gKw,dlO,gKw,dCv,gKw,bk5,gKw,eFw,gKw,fkS,gKw,biG,gKw,eoK,gKw,eAB,gKw,er2,gKw,d8_,gKw,aME,gKw,bl7,gKw,af3,gKw,aG4,gKw,dxD,gKw,dAE,gKw,aJt,gKw,dnN,gKw,fk2,gKw,aui,gKw,dM5,gKw,cN_,gKw,epl,gKw,bay,gKw,eqB,gKw,dj$,gKw,ftU,gKw,a0Y,gKw,d1V,gKw,eov,gKw,cKe,gKw,a72,gKw,fdB,gKw,aKX,gKw,ae4,gKw,fua,gKw,dq3,gKw,ber,gKw,fom,gKw,aFT,gKw,fqR,gKw,d0r,gKw,a2Y,gKw,agI,gKw,gzG,gKw,drA,gKw,eMy,gKw,eEc,gKw,fsa,gKw,eTD,gKw,a8z,gKw,bnr,gKw,afN,gKw,a4F,gKw,eM8,gKw,epO,gKw,dDt,gKw,bjH,gKw,aTA,gKw,eFv,gKw,ecp,gKw,fj_,gKw,alb,gKw,e7H,gKw,eup,gKw,aKr,gKw,dPX,gKw,cDg,gKw,dlu,gKw,dMj,gKw,aDo,gKw,a6W,gKw,c1w,gKw,aWW,gKw,euR,gKw,bnS,gKw,en2,gKw,dPN,gKw,dle,gKw,fqx,gKw,eBW,gKw,ec5,gKw,d5v,gKw,e1n,gKw,fvk,gKw,eSg,gKw,dCo,gKw,dBG,gKw,aLS,gKw,afp,gKw,awY,gKw,bka,gKw,ajz,gKw,cIL,gKw,a$G,gKw,bjI,gKw,dZI,gKw,dNR,gKw,fkf,gKw,ZV,gKw,a6Y,gKw,eLY,gKw,eTg,gKw,fkU,gKw,eSE,gKw,dU0,gKw,eGk,gKw,duU,gKw,cAK,gKw,e7k,gKw,exO,gKw,aEd,gKw,cNX,gKw,d7k,gKw,dvb,gKw,e4W,gKw,afA,gKw,ae2,gKw,eai,gKw,af$,gKw,dQ_,gKw,bfr,gKw,eOP,gKw,emy,gKw,eON,gKw,dSU,gKw,dBA,gKw,aES,gKw,eIp,gKw,et4,gKw,cLp,gKw,dg$,gKw,awg,gKw,dZW,gKw,dTk,gKw,awd,gKw,fhp,gKw,dzW,gKw,eay,gKw,fiy,gKw,edu,gKw,fyS,gKw,evK,gKw,fuG,gKw,eWM,gKw,aQL,gKw,fnX,gKw,eTa,gKw,di5,gKw,d0z,gKw,cKh,gKw,e4l,gKw,a04,gKw,dTt,gKw,aBN,gKw,eAs,gKw,dPF,gKw,dqK,gKw,e9M,gKw,dNJ,gKw,aG2,gKw,fnW,gKw,fcC,gKw,fq4,gKw,fnA,gKw,eMO,gKw,aXA,gKw,auA,gKw,dOS,gKw,dYB,gKw,epp,gKw,ff3,gKw,esu,gKw,ae0,gKw,dE9,gKw,eht,gKw,dYR,gKw,bdo,gKw,arY,gKw,dsO,gKw,eo2,gKw,c$J,gKw,eRU,gKw,dMq,gKw,fjd,gKw,d9v,gKw,agA,gKw,awQ,gKw,a5L,gKw,dl_,gKw,dAH,gKw,eyq,gKw,Wp,gKw,a6C,gKw,dB$,gKw,a8N,gKw,dzH,gKw,eVA,gKw,f9C,gKw,dOO,gKw,ftJ,gKw,bdO,gKw,dl2,gKw,beo,gKw,bns,gKw,afy,gKw,aEu,gKw,e0F,gKw,cAG,gKw,c1P,gKw,dTU,gKw,cGC,gKw,d_I,gKw,VJ,gKw,drP,gKw,a0F,gKw,dDe,gKw,aEU,gKw,d5W,gKw,ewS,gKw,ai2,gKw,dSb,gKw,aPi,gKw,dOr,gKw,dFt,gKw,dTq,gKw,eLh,gKw,egc,gKw,dhf,gKw,dRb,gKw,d$3,gKw,e_D,gKw,esN,gKw,dg_,gKw,aI3,gKw,fbt,gKw,cJ1,gKw,eaj,gKw,eMl,gKw,diK,gKw,eKr,gKw,afn,gKw,anU,gKw,eCP,gKw,dvR,gKw,aoc,gKw,d4n,gKw,awy,gKw,cFK,gKw,fdD,gKw,aFS,gKw,bbX,gKw,eNO,gKw,frk,gKw,a4B,gKw,aT8,gKw,erz,gKw,fud,gKw,dIt,gKw,eVd,gKw,eou,gKw,dEU,gKw,aEv,gKw,dU_,gKw,fkA,gKw,a3I,gKw,dMp,gKw,efo,gKw,bcL,gKw,eA8,gKw,fo0,gKw,beH,gKw,ehs,gKw,eCS,gKw,eOu,gKw,awS,gKw,eMo,gKw,eCp,gKw,erw,gKw,aZq,gKw,dnM,gKw,c0j,gKw,dQf,gKw,e$h,gKw,d8t,gKw,aBp,gKw,atr,gKw,d1Y,gKw,e3z,gKw,dsQ,gKw,exz,gKw,bkR,gKw,bgH,gKw,dm$,gKw,aLN,gKw,d5H,gKw,afc,gKw,dhM,gKw,bat,gKw,fwL,gKw,dY0,gKw,agk,gKw,aTg,gKw,cF8,gKw,fpv,gKw,aCx,gKw,eXC,gKw,dPD,gKw,bnf,gKw,afh,gKw,d9g,gKw,aIf,gKw,agb,gKw,auL,gKw,dKf,gKw,dQl,gKw,esr,gKw,eyE,gKw,eKH,gKw,eVa,gKw,aft,gKw,aGO,gKw,fjZ,gKw,dSj,gKw,dSF,gKw,er$,gKw,aKZ,gKw,d9H,gKw,erA,gKw,ebs,gKw,fgA,gKw,a5a,gKw,cH3,gKw,e_8,gKw,aBU,gKw,bo6,gKw,fsC,gKw,auF,gKw,eJE,gKw,dUW,gKw,ein,gKw,aiO,gKw,eWR,gKw,bkQ,gKw,aEx,gKw,d_j,gKw,d9u,gKw,aUX,gKw,dqT,gKw,aT_,gKw,fu8,gKw,eJO,gKw,eH1,gKw,eR6,gKw,bcu,gKw,d_b,gKw,dqQ,gKw,eMa,gKw,eOQ,gKw,etZ,gKw,eGG,gKw,eBY,gKw,bn6,gKw,eRP,gKw,dvy,gKw,fq6,gKw,cEX,gKw,ayu,gKw,cFV,gKw,ebX,gKw,e_X,gKw,ewB,gKw,dI9,gKw,djf,gKw,ecT,gKw,d3M,gKw,brc,gKw,c1D,gKw,eEj,gKw,aww,gKw,frW,gKw,anu,gKw,a9s,gKw,bfI,gKw,dRV,gKw,dYA,gKw,e_$,gKw,aDI,gKw,dTl,gKw,eLK,gKw,aJs,gKw,dCk,gKw,bhR,gKw,bdP,gKw,ee9,gKw,eMT,gKw,dBE,gKw,dIQ,gKw,baq,gKw,ftH,gKw,eUH,gKw,eqm,gKw,a30,gKw,eCw,gKw,dmY,gKw,dOb,gKw,eNZ,gKw,d1W,gKw,dM_,gKw,dQy,gKw,auK,gKw,eTt,gKw,arF,gKw,eSr,gKw,dgw,gKw,bje,gKw,ajw,gKw,alD,gKw,ex8,gKw,eNe,gKw,f9F,gKw,afQ,gKw,dt9,gKw,dQA,gKw,d3o,gKw,efq,gKw,fhC,gKw,bhs,gKw,eYj,gKw,at$,gKw,akG,gKw,dyd,gKw,eoj,gKw,bnp,gKw,dwl,gKw,dQB,gKw,aox,gKw,aK_,gKw,awx,gKw,ezl,gKw,d1t,gKw,eu6,gKw,fgR,gKw,dPc,gKw,aUI,gKw,eTN,gKw,dFa,gKw,c2s,gKw,dYD,gKw,ftm,gKw,dET,gKw,etB,gKw,dDZ,gKw,fiI,gKw,dvT,gKw,aAs,gKw,dr1,gKw,e1G,gKw,ax5,gKw,d7X,gKw,blS,gKw,drM,gKw,aI2,gKw,aMJ,gKw,dys,gKw,aWI,gKw,eZ_,gKw,fqy,gKw,dqr,gKw,evJ,gKw,aP6,gKw,do_,gKw,be8,gKw,dr2,gKw,dlZ,gKw,af2,gKw,U4,gKw,eRt,gKw,dv9,gKw,dNh,gKw,eMW,gKw,duI,gKw,bhP,gKw,a9y,gKw,dQk,gKw,bhO,gKw,d9f,gKw,ewT,gKw,dSG,gKw,c0N,gKw,ajC,gKw,dL3,gKw,eZq,gKw,aC5,gKw,fkh,gKw,a4t,gKw,biQ,gKw,dGu,gKw,fgW,gKw,efc,gKw,erB,gKw,biP,gKw,d6m,gKw,dxh,gKw,agt,gKw,c2E,gKw,a$o,gKw,aST,gKw,eZM,gKw,fol,gKw,aYz,gKw,en3,gKw,cFl,gKw,ae1,gKw,dUz,gKw,duP,gKw,eIs,gKw,afT,gKw,aVC,gKw,duZ,gKw,emM,gKw,eYi,gKw,e1F,gKw,dyt,gKw,bdc,gKw,d8H,gKw,dCi,gKw,c1W,gKw,eSx,gKw,bnb,gKw,blk,gKw,dNa,gKw,ft7,gKw,cFu,gKw,d7T,gKw,e69,gKw,aQS,gKw,eHb,gKw,edR,gKw,bn5,gKw,eYp,gKw,af0,gKw,bg5,gKw,dzR,gKw,d4h,gKw,cG2,gKw,ei9,gKw,eLu,gKw,aRy,gKw,ebo,gKw,eaY,gKw,bcK,gKw,a4g,gKw,aMs,gKw,dgz,gKw,eLd,gKw,fqS,gKw,bjg,gKw,fx1,gKw,eyD,gKw,d28,gKw,frF,gKw,aM_,gKw,a85,gKw,dKy,gKw,WS,gKw,ax6,gKw,eXe,gKw,aCo,gKw,fdM,gKw,biq,gKw,bf_,gKw,bfK,gKw,eqe,gKw,d4G,gKw,akX,gKw,eAM,gKw,egM,gKw,elg,gKw,agu,gKw,dz$,gKw,aXb,gKw,geY,gKw,aZP,gKw,eSX,gKw,ezI,gKw,doz,gKw,evt,gKw,aDq,gKw,epH,gKw,aPn,gKw,as7,gKw,ezN,gKw,aQC,gKw,cHb,gKw,apx,gKw,dIc,gKw,j_,gKw,at_,gKw,dCd,gKw,efK,gKw,gzu,gKw,c0s,gKw,a8$,gKw,af4,gKw,a0G,gKw,eJD,gKw,e5_,gKw,efH,gKw,dxY,gKw,bnP,gKw,aG3,gKw,dNd,gKw,afe,gKw,aXp,gKw,eyp,gKw,fuF,gKw,eFx,gKw,aOE,gKw,a1E,gKw,doy,gKw,cGF,gKw,ess,gKw,fle,gKw,dMk,gKw,esJ,gKw,cE$,gKw,auz,gKw,aMr,gKw,edS,gKw,elI,gKw,a7P,gKw,a6D,gKw,dP2,gKw,frV,gKw,eax,gKw,dwL,gKw,eEH,gKw,afE,gKw,e56,gKw,faI,gKw,dmZ,gKw,afi,gKw,a3r,gKw,dw4,gKw,af7,gKw,eeU,gKw,dgj,gKw,fnV,gKw,cEs,gKw,eAN,gKw,e60,gKw,dn3,gKw,eib,gKw,dzM,gKw,e2C,gKw,dKk,gKw,cFr,gKw,e4v,gKw,eSP,gKw,eqY,gKw,bmJ,gKw,eLn,gKw,dlf,gKw,dok,gKw,doX,gKw,ai7,gKw,a5o,gKw,cGf,gKw,ejZ,gKw,dST,gKw,dC5,gKw,ea5,gKw,dZA,gKw,d07,gKw,e7u,gKw,eWD,gKw,bcB,gKw,avv,gKw,eUm,gKw,bmu,gKw,cFE,gKw,akp,gKw,fl1,gKw,biC,gKw,e8w,gKw,fhe,gKw,dL2,gKw,faf,gKw,aWM,gKw,dvB,gKw,fbT,gKw,bcn,gKw,fuE,gKw,exV,gKw,aKF,gKw,aVa,gKw,ebE,gKw,eoi,gKw,a8V,gKw,d_q,gKw,euQ,gKw,ejd,gKw,dzu,gKw,bnq,gKw,dz9,gKw,fyM,gKw,est,gKw,erj,gKw,fiN,gKw,afz,gKw,aH4,gKw,fwx,gKw,c$t,gKw,fbi,gKw,euS,gKw,edD,gKw,eTT,gKw,dIG,gKw,eh4,gKw,eCr,gKw,d1C,gKw,ae7,gKw,ev4,gKw,aMP,gKw,dEz,gKw,eA3,gKw,eOL,gKw,ecz,gKw,eV9,gKw,axd,gKw,dzo,gKw,agD,gKw,a6d,gKw,a_V,gKw,aO8,gKw,aH3,gKw,bcw,gKw,dSS,gKw,d_U,gKw,dRX,gKw,dHQ,gKw,ehL,gKw,eKZ,gKw,aDn,gKw,eU1,gKw,d8A,gKw,a9h,gKw,bmI,gKw,e6_,gKw,afD,gKw,eah,gKw,dFY,gKw,ftn,gKw,a4l,gKw,a6z,gKw,dSu,gKw,dq5,gKw,d55,gKw,bms,gKw,hR,gKw,auy,gKw,aII,gKw,eRF,gKw,dxg,gKw,fjt,gKw,a82,gKw,eLQ,gKw,eAr,gKw,bo5,gKw,eiH,gKw,a2W,gKw,eKT,gKw,aiL,gKw,aga,gKw,dvU,gKw,dN1,gKw,dyW,gKw,dJs,gKw,eM5,gKw,e72,gKw,a3X,gKw,at0,gKw,eVw,gKw,c$U,gKw,dyX,gKw,Sg,gKw,dj0,gKw,afI,gKw,a3M,gKw,kX,gKw,dU1,gKw,dP_,gKw,agf,gKw,c2e,gKw,anr,gKw,eCq,gKw,e38,gKw,eWF,gKw,dKN,gKw,fwW,gKw,fok,gKw,cFo,gKw,esH,gKw,aMq,gKw,e$g,gKw,aff,gKw,dyf,gKw,ae5,gKw,dCO,gKw,a61,gKw,dyI,gKw,d_X,gKw,fdj,gKw,dRm,gKw,be5,gKw,ep6,gKw,atq,gKw,erV,gKw,eEo,gKw,aiw,gKw,eHJ,gKw,fbC,gKw,eUW,gKw,elp,gKw,axv,gKw,asf,gKw,fyn,gKw,dJx,gKw,dKS,gKw,dus,gKw,dGY,gKw,dMJ,gKw,aZK,gKw,dr3,gKw,fsB,gKw,ebV,gKw,frC,gKw,aib,gKw,blU,gKw,dUb,gKw,a4C,gKw,avs,gKw,aza,gKw,dTN,gKw,dh_,gKw,dyu,gKw,aq$,gKw,dQi,gKw,fuD,gKw,eMs,gKw,aY8,gKw,auh,gKw,eyb,gKw,baS,gKw,egN,gKw,eIq,gKw,erp,gKw,aBr,gKw,fcd,gKw,erx,gKw,d7H,gKw,dot,gKw,ajF,gKw,ebi,gKw,dvj,gKw,dIi,gKw,e7q,gKw,dOe,gKw,aHr,gKw,eK3,gKw,euY,gKw,a9d,gKw,afw,gKw,a6E,gKw,agX,gKw,Sf,gKw,d81,gKw,an1,gKw,dS0,gKw,aJr,gKw,UJ,gKw,avt,gKw,a8y,gKw,aoG,gKw,fug,gKw,eKD,gKw,eM$,gKw,dG_,gKw,agc,gKw,eWl,gKw,bg6,gKw,ft_,gKw,bhu,gKw,dTG,gKw,an9,gKw,dCh,gKw,eOx,gKw,ec6,gKw,afM,gKw,foC,gKw,bh9,gKw,eQ0,gKw,eo6,gKw,aUU,gKw,apo,gKw,dSd,gKw,eB7,gKw,aFz,gKw,eBV,gKw,a$H,gKw,aDp,gKw,euq,gKw,ezO,gKw,dDd,gKw,aPd,gKw,az5,gKw,bjJ,gKw,afg,gKw,aQ7,gKw,fcl,gKw,dnZ,gKw,cKS,gKw,aI5,gKw,aCV,gKw,ebh,gKw,afr,gKw,e1h,gKw,eCV,gKw,eKw,gKw,eVD,gKw,fnU,gKw,eAZ,gKw,eLA,gKw,a3U,gKw,dAP,gKw,eoI,gKw,agH,gKw,ajc,gKw,d9t,gKw,dL$,gKw,d4R,gKw,dE$,gKw,c_1,gKw,dlY,gKw,dSE,gKw,dAB,gKw,fl_,gKw,dps,gKw,dA1,gKw,d95,gKw,dQF,gKw,d27,gKw,dCm,gKw,cJ4,gKw,fy$,gKw,eIe,gKw,eKO,gKw,ajn,gKw,aez,gKw,fw1,gKw,aBV,gKw,djs,gKw,foF,gKw,flH,gKw,dAD,gKw,dNu,gKw,djE,gKw,eJ3,gKw,dPC,gKw,etX,gKw,ebH,gKw,aAE,gKw,efJ,gKw,af1,gKw,eyG,gKw,aqY,gKw,aWk,gKw,fqz,gKw,edB,gKw,bmL,gKw,cEK,gKw,evs,gKw,fum,gKw,dOL,gKw,bft,gKw,aFR,gKw,dQc,gKw,aO_,gKw,asT,gKw,ecS,gKw,fkz,gKw,dw3,gKw,agL,gKw,a34,gKw,dYC,gKw,dSv,gKw,c2v,gKw,cJf,gKw,dCQ,gKw,eFE,gKw,d$V,gKw,afx,gKw,d09,gKw,dRa,gKw,ews,gKw,dYS,gKw,eiI,gKw,aY$,gKw,d1v,gKw,d0y,gKw,aI4,gKw,esg,gKw,dPT,gKw,agp,gKw,eRl,gKw,aZz,gKw,dkg,gKw,eAA,gKw,dk3,gKw,ej$,gKw,dwM,gKw,cAJ,gKw,aJ9,gKw,VK,gKw,cKP,gKw,etb,gKw,c0F,gKw,af8,gKw,ae9,gKw,diL,gKw,dtz,gKw,afP,gKw,d0b,gKw,cAL,gKw,dsu,gKw,eVC,gKw,eo1,gKw,fvb,gKw,dHI,gKw,agE,gKw,eJ4,gKw,eoT,gKw,c$z,gKw,dD5,gKw,dBp,gKw,e8F,gKw,elt,gKw,beq,gKw,dxZ,gKw,eqK,gKw,dx$,gKw,eB9,gKw,fvU,gKw,eOM,gKw,c$g,gKw,d7J,gKw,fu9,gKw,eLU,gKw,WR,gKw,d_u,gKw,bk6,gKw,dID,gKw,eKW,gKw,e3L,gKw,d9e,gKw,ehv,gKw,foD,gKw,bmt,gKw,eJ$,gKw,as9,gKw,aLu,gKw,dQO,gKw,dPe,gKw,aQi,gKw,dEB,gKw,fx4,gKw,dxK,gKw,dJJ,gKw,biu,gKw,eiK,gKw,ag0,gKw,aAg,gKw,cAM,gKw,dAa,gKw,agR,gKw,eyN,gKw,dIV,gKw,aGQ,gKw,dh$,gKw,bkO,gKw,VB,gKw,ff8,gKw,dUD,gKw,eZe,gKw,foE,gKw,afm,gKw,dhs,gKw,aMK,gKw,gzJ,gKw,frl,gKw,aLE,gKw,eg3,gKw,eM2,gKw,doj,gKw,a45,gKw,dDc,gKw,aXi,gKw,auI,gKw,akL,gKw,ge1,gKw,exZ,gKw,eNY,gKw,dEC,gKw,aQp,gKw,aZY,gKw,a3d,gKw,dUh,gKw,dyL,gKw,a6X,gKw,d3W,gKw,ao6,gKw,akm,gKw,aIH,gKw,ecR,gKw,aGP,gKw,agq,gKw,a5i,gKw,d0U,gKw,a6w,gKw,akh,gKw,dA8,gKw,exA,gKw,a9o,gKw,dzp,gKw,dwK,gKw,dMK,gKw,ewl,gKw,fgi,gKw,$Q,gKw,fjY,gKw,aSF,gKw,beG,gKw,eNX,gKw,dLH,gKw,adi,gKw,afV,gKw,d_Z,gKw,aIb,gKw,eol,gKw,fcZ,gKw,fNG,gKw,d_A,gKw,aGp,gKw,d47,gKw,fm4,gKw,a6Z,gKw,dH7,gKw,ep5,gKw,fvZ,gKw,dM1,gKw,ee8,gKw,d_B,gKw,bfJ,gKw,dyK,gKw,fhM,gKw,eXm,gKw,aRs,gKw,aeu,gKw,alT,gKw,cFO,gKw,agi,gKw,afj,gKw,afJ,gKw,d9K,gKw,ely,gKw,dRv,gKw,dsZ,gKw,eTj,gKw,eoU,gKw,aGq,gKw,erb,gKw,egC,gKw,dUv,gKw,bkt,gKw,d5L,gKw,dP5,gKw,eql,gKw,fgq,gKw,fr8,gKw,fuj,gKw,dNr,gKw,d6b,gKw,dE8,gKw,afK,gKw,aBT,gKw,c1r,gKw,d9V,gKw,d$G,gKw,eJ5,gKw,dZs,gKw,dNs,gKw,fc$,gKw,dCl,gKw,VI,gKw,fkg,gKw,eAg,gKw,auB,gKw,d7g,gKw,aF9,gKw,etW,gKw,e49,gKw,ec7,gKw,ff2,gKw,d1s,gKw,dgh,gKw,ezn,gKw,eyF,gKw,eqd,gKw,axe,gKw,dRp,gKw,d_f,gKw,dLK,gKw,atp,gKw,abU,gKw,d4s,gKw,aOr,gKw,eFT,gKw,fa9,gKw,dYM,gKw,a$t,gKw,efr,gKw,dhm,gKw,bim,gKw,dCw,gKw,dBu,gKw,eN8,gKw,ayR,gKw,ecn,gKw,ela,gKw,eAh,gKw,fdE,gKw,atL,gKw,at1,gKw,dCp,gKw,cJ7,gKw,bjd,gKw,a3k,gKw,dgx,gKw,a4y,gKw,cG6,gKw,emz,gKw,aHt,gKw,aSb,gKw,erF,gKw,as6,gKw,boJ,gKw,aia,gKw,eTA,gKw,dOx,gKw,eDP,gKw,aDJ,gKw,eOv,gKw,fgQ,gKw,dBT,gKw,eRw,gKw,axu,gKw,ezK,gKw,ejI,gKw,a2Z,gKw,be6,gKw,bhQ,gKw,dmF,gKw,aoD,gKw,bdd,gKw,d8$,gKw,aU0,gKw,c1$,gKw,eri,gKw,cK_,gKw,aGz,gKw,exB,gKw,aqy,gKw,dy$,gKw,eBX,gKw,dSk,gKw,edT,gKw,bcm,gKw,eIS,gKw,dtH,gKw,erJ,gKw,dVr,gKw,etY,gKw,aZd,gKw,doY,gKw,agO,gKw,axg,gKw,a8A,gKw,dkS,gKw,bm1,gKw,aoQ,gKw,bj8,gKw,fc_,gKw,ag4,gKw,d__,gKw,a3o,gKw,erH,gKw,e08,gKw,cF2,gKw,exJ,gKw,fqQ,gKw,dIL,gKw,aIo,gKw,eMi,gKw,aMt,gKw,e2t,gKw,afa,gKw,eeI,gKw,emA,gKw,dFb,gKw,dTD,gKw,dOu,gKw,aUy,gKw,eoO,gKw,a68,gKw,d42,gKw,eUt,gKw,dRY,gKw,a7b,gKw,fl0,gKw,dZx,gKw,cGb,gKw,eLE,gKw,dUS,gKw,aJq,gKw,cGe,gKw,dua,gKw,a5$,gKw,fit,gKw,agg,gKw,jw,gKw,biR,gKw,aqa,gKw,eMF,gKw,aRc,gKw,exC,gKw,dPE,gKw,ewg,gKw,dZ_,gKw,f41,gKw,en5,gKw,cGI,gKw,ezU,gKw,e1i,gKw,ei4,gKw,eGb,gKw,eFS,gKw,cKk,gKw,a_B,gKw,aSY,gKw,eGU,gKw,eC_,gKw,fkB,gKw,er7,gKw,d51,gKw,dnk,gKw,aEw,gKw,eDa,gKw,auJ,gKw,dj_,gKw,aMQ,gKw,afY,gKw,bfu,gKw,d3$,gKw,ex9,gKw,aMO,gKw,fpu,gKw,cGL,gKw,erC,gKw,aAD,gKw,dUa,gKw,fdi,gKw,d3R,gKw,e0T,gKw,eAz,gKw,aFy,gKw,bdN,gKw,e3_,gKw,dif,gKw,eUn,gKw,cN$,gKw,c$p,gKw,dld,gKw,agz,gKw,aeV,gKw,d0f,gKw,W3,gKw,aD7,gKw,aYW,gKw,cC2,gKw,fvj,gKw,dLI,gKw,etd,gKw,aX2,gKw,ekm,gKw,abD,gKw,ev5,gKw,afl,gKw,eUP,gKw,dCP,gKw,eGs,gKw,dsw,gKw,a7z,gKw,djQ,gKw,dzU,gKw,eSU,gKw,dw6,gKw,fai,gKw,a_J,gKw,edy,gKw,efI,gKw,fsA,gKw,d_4,gKw,aC3,gKw,eQ3,gKw,aET,gKw,dlg,gKw,cGX,gKw,a6r,gKw,eD7,gKw,f47,gKw,W0,gKw,axx,gKw,aXJ,gKw,dZt,gKw,eZV,gKw,cLg,gKw,fon,gKw,aLr,gKw,dub,gKw,dTy,gKw,bla,gKw,eZc,gKw,eRo,gKw,afO,gKw,erR,gKw,bnQ,gKw,aGA,gKw,dwJ,gKw,eKx,gKw,dq6,gKw,a7W,gKw,dkh,gKw,bl5,gKw,d93,gKw,dZF,gKw,ezE,gKw,eXd,gKw,dUK,gKw,axw,gKw,bcD,gKw,fi0,gKw,eio,gKw,am7,gKw,eSJ,gKw,d7e,gKw,e9a,gKw,eUx,gKw,eZ$,gKw,eDA,gKw,eGB,gKw,adP,gKw,a3h,gKw,dUG,gKw,ete,gKw,d$6,gKw,eg2,gKw,eFy,gKw,efU,gKw,eOO,gKw,ety,gKw,bok,gKw,dUY,gKw,eod,gKw,eV4,gKw,eOI,gKw,a3y,gKw,aJ8,gKw,aeU,gKw,exP,gKw,aoL,gKw,eYk,gKw,ehJ,gKw,cBz,gKw,aB4,gKw,doI,gKw,ax4,gKw,dTT,gKw,fqT,gKw,fnz,gKw,aIr,gKw,ebj,gKw,cKX,gKw,aKM,gKw,dEA,gKw,ftl,gKw,djJ,gKw,dlM,gKw,bn3,gKw,eCJ,gKw,eES,gKw,dnO,gKw,aF8,gKw,d4B,gKw,an4,gKw,dzE,gKw,d_z,gKw,dDu,gKw,fcE,gKw,dD3,gKw,e16,gKw,dFs,gKw,ftK,gKw,egj,gKw,ebF,gKw,bo3,gKw,$n,gKw,eVm,gKw,af6,gKw,age,gKw,eLx,gKw,eXl,gKw,eZ0,gKw,egh,gKw,cDz,gKw,aAF,gKw,dUX,gKw,dt$,gKw,eDz,gKw,dGZ,gKw,e_a,gKw,biy,gKw,d$7,gKw,fj$,gKw,eqh,gKw,d7P,gKw,dn0,gKw,agG,gKw,aks,gKw,bgj,gKw,eGP,gKw,ff4,gKw,eCa,gKw,d4W,gKw,dU$,gKw,eeb,gKw,cFe,gKw,dnm,gKw,biz,gKw,eCo,gKw,eTY,gKw,dZ6,gKw,biw,gKw,dsv,gKw,fki,gKw,du8,gKw,aWR,gKw,aLK,gKw,e9O,gKw,agl,gKw,e8K,gKw,dOD,gKw,a37,gKw,d3y,gKw,e3y,gKw,bdI,gKw,ezm,gKw,aUl,gKw,dtG,gKw,cFH,gKw,eTs,gKw,cNV,gKw,eYz,gKw,d4Z,gKw,e7E,gKw,a3a,gKw,d6l,gKw,dTL,gKw,alz,gKw,aqd,gKw,eET,gKw,aqg,gKw,boG,gKw,a1C,gKw,e4G,gKw,flG,gKw,aFA,gKw,dSw,gKw,dOl,gKw,fi5,gKw,eoJ,gKw,dQh,gKw,fbK,gKw,eNk,gKw,fpj,gKw,dM0,gKw,ats,gKw,UH,gKw,dlv,gKw,eoL,gKw,eL7,gKw,d7d,gKw,ar0,gKw,edX,gKw,eTI,gKw,dAb,gKw,elD,gKw,dwT,gKw,cKB,gKw,dh1,gKw,eAH,gKw,d94,gKw,eC7,gKw,eqs,gKw,aCs,gKw,eT6,gKw,cLd,gKw,dY$,gKw,dOC,gKw,bj9,gKw,eZd,gKw,cKl,gKw,fkC,gKw,dqq,gKw,a_Q,gKw,c0m,gKw,dxi,gKw,aTs,gKw,akF,gKw,ei3,gKw,erM,gKw,aWD,gKw,eoZ,gKw,af_,gKw,ec4,gKw,edQ,gKw,ep1,gKw,aKs,gKw,cFi,gKw,eR1,gKw,biA,gKw,aZ0,gKw,et7,gKw,dUZ,gKw,fq5,gKw,dAC,gKw,c$j,gKw,djD,gKw,eE5,gKw,T4,gKw,eiJ,gKw,ev3,gKw,eWE,gKw,d0l,gKw,bfH,gKw,ftI,gKw,d5q,gKw,eAi,gKw,dRA,gKw,eXs,gKw,atK,gKw,dNK,gKw,bco,gKw,d43,gKw,aJM,gKw,fh3,gKw,epb,gKw,duc,gKw,fr9,gKw,ezu,gKw,eqQ,gKw,dtI,gKw,apY,gKw,dBO,gKw,e03,gKw,dqM,gKw,d4L,gKw,agW,gKw,frm,gKw,dQ9,gKw,WA,gKw,bn4,gKw,amT,gKw,a7d,gKw,awv,gKw,e8e,gKw,d0x,gKw,bg7,gKw,bep,gKw,agj,gKw,ea_,gKw,arO,gKw,aIG,gKw,d5c,gKw,afC,gKw,fxY,gKw,bh1,gKw,aU3,gKw,fv3,gKw,apr,gKw,en4,gKw,gIv,gKw,esd,gKw,d_7,gKw,dq4,gKw,asi,gKw,cF5,gKw,eqG,gKw,dSl,gKw,amU,gKw,cGo,gKw,eeF,gKw,bkv,gKw,e2c,gKw,eL2,gKw,c1L,gKw,cBc,gKw,cI4,gKw,dpE,gKw,eOz,gKw,aD_,gKw,epT,gKw,dQW,gKw,cLO,gKw,eFV,gKw,ea6,gKw,aYM,gKw,ba1,gKw,ago,gKw,dBW,gKw,W2,gKw,kN,gKw,eRg,gKw,dxE,gKw,frE,gKw,aOw,gKw,a9C,gKw,cGs,gKw,epX,gKw,epD,gKw,dSt,gKw,dKZ,gKw,bku,gKw,ewx,gKw,dCe,gKw,dMI,gKw,blV,gKw,d$N,gKw,egx,gKw,aT3,gKw,ai$,gKw,e4R,gKw,d$E,gKw,eVW,gKw,a_1,gKw,dw5,gKw,dyg,gKw,dva,gKw,eTd,gKw,dY2,gKw,awe,gKw,eT2,gKw,bgk,gKw,dCu,gKw,bm0,gKw,ay2,gKw,cE4,gKw,auf,gKw,e9s,gKw,fto,gKw,dyJ,gKw,d_R,gKw,d0s,gKw,cGQ,gKw,fyG,gKw,aC6,gKw,d9w,gKw,dVq,gKw,amt,gKw,aJS,gKw,eNs,gKw,aVY,gKw,dBj,gKw,aAi,gKw,aWr,gKw,d$F,gKw,cN0,gKw,dOE,gKw,erc,gKw,aSq,gKw,e15,gKw,erO,gKw,ej_,gKw,dF9,gKw,awf,gKw,aFU,gKw,fl$,gKw,dHE,gKw,d26,gKw,e89,gKw,k1,gKw,erK,gKw,d1B,gKw,aWy,gKw,fia,gKw,agJ,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw,gKw];var gE=[gKx,gKx];var gF=[gKy,gKy,ddJ,gKy,c9E,gKy,c80,gKy,c7U,gKy,dbK,gKy,dbM,gKy,c9q,gKy,c9l,gKy,dcu,gKy,c9s,gKy,dav,gKy,da7,gKy,dcZ,gKy,dbb,gKy,c8c,gKy,deM,gKy,dbA,gKy,dck,gKy,c7k,gKy,daN,gKy,da0,gKy,dcd,gKy,c7P,gKy,c89,gKy,c7f,gKy,dbe,gKy,daa,gKy,dbg,gKy,c7F,gKy,c6$,gKy,dbP,gKy,c8U,gKy,c8a,gKy,c9D,gKy,c6Z,gKy,ddv,gKy,dd3,gKy,dcO,gKy,c99,gKy,dcv,gKy,daI,gKy,deE,gKy,c8A,gKy,dcb,gKy,da8,gKy,c8V,gKy,dc6,gKy,dcR,gKy,ddm,gKy,c6T,gKy,c8d,gKy,dcE,gKy,dbz,gKy,da9,gKy,dbs,gKy,dde,gKy,c88,gKy,db9,gKy,c6R,gKy,c90,gKy,c7_,gKy,c9O,gKy,ddy,gKy,dbF,gKy,da5,gKy,dep,gKy,ddc,gKy,dcA,gKy,dbd,gKy,c6N,gKy,c9K,gKy,dci,gKy,dei,gKy,c77,gKy,ddK,gKy,c8x,gKy,dan,gKy,c7B,gKy,c97,gKy,gE9,gKy,c9H,gKy,dex,gKy,gBy,gKy,db8,gKy,dcm,gKy,db_,gKy,c7$,gKy,dcj,gKy,dcx,gKy,dbX,gKy,c7u,gKy,deH,gKy,c8k,gKy,dbi,gKy,c8Y,gKy,c6O,gKy,c83,gKy,dbL,gKy,c6P,gKy,c61,gKy,c9d,gKy,c7l,gKy,c7e,gKy,dbo,gKy,dbN,gKy,db3,gKy,c9V,gKy,c8o,gKy,c7s,gKy,dcB,gKy,c67,gKy,c8y,gKy,c9N,gKy,c96,gKy,ddw,gKy,dba,gKy,daE,gKy,c9T,gKy,c8B,gKy,c9f,gKy,c69,gKy,dc3,gKy,ddL,gKy,ddr,gKy,dds,gKy,c8G,gKy,dem,gKy,dcG,gKy,c66,gKy,c8X,gKy,c9Z,gKy,c7q,gKy,c8f,gKy,c9X,gKy,c7v,gKy,des,gKy,c7n,gKy,dap,gKy,dbp,gKy,gFk,gKy,c9C,gKy,c7T,gKy,c75,gKy,db2,gKy,dag,gKy,c9$,gKy,c9e,gKy,daF,gKy,dae,gKy,ddE,gKy,ddd,gKy,deI,gKy,dbj,gKy,c7K,gKy,c9a,gKy,c9i,gKy,dbf,gKy,dby,gKy,c8P,gKy,c92,gKy,c86,gKy,ddU,gKy,ddz,gKy,c8N,gKy,dbT,gKy,del,gKy,c9P,gKy,dd0,gKy,c9_,gKy,dbV,gKy,c8M,gKy,daS,gKy,c8$,gKy,dbq,gKy,c7j,gKy,dcK,gKy,daB,gKy,daW,gKy,dcr,gKy,dcH,gKy,c7S,gKy,dcC,gKy,c9j,gKy,dc5,gKy,dbn,gKy,dc_,gKy,c7o,gKy,c7J,gKy,dec,gKy,daA,gKy,gEH,gKy,ddF,gKy,dew,gKy,gER,gKy,daM,gKy,dcl,gKy,dd4,gKy,c73,gKy,db$,gKy,c8E,gKy,c91,gKy,deB,gKy,daT,gKy,daz,gKy,c8W,gKy,det,gKy,dd6,gKy,c7V,gKy,c8_,gKy,c9k,gKy,c9y,gKy,c8v,gKy,da2,gKy,ddM,gKy,c8i,gKy,c7Q,gKy,dbr,gKy,dbO,gKy,ddN,gKy,c8t,gKy,dd$,gKy,c8K,gKy,db7,gKy,c84,gKy,daw,gKy,dc9,gKy,da6,gKy,gEY,gKy,dac,gKy,daU,gKy,daL,gKy,dc8,gKy,dcN,gKy,c6W,gKy,dao,gKy,c8b,gKy,dc2,gKy,c6Y,gKy,dbm,gKy,c68,gKy,c8T,gKy,dcs,gKy,dai,gKy,daV,gKy,c8L,gKy,c7Y,gKy,deq,gKy,c8J,gKy,gE1,gKy,def,gKy,c8Q,gKy,ddX,gKy,dcg,gKy,c76,gKy,db5,gKy,daC,gKy,c79,gKy,dd1,gKy,c7D,gKy,ddG,gKy,deo,gKy,c9L,gKy,c7I,gKy,dcn,gKy,dcF,gKy,ddb,gKy,daD,gKy,ddg,gKy,da3,gKy,c7x,gKy,c7E,gKy,day,gKy,dcT,gKy,dd9,gKy,c6X,gKy,dbu,gKy,ddC,gKy,dej,gKy,c6V,gKy,c81,gKy,c9u,gKy,dcq,gKy,c8q,gKy,dbH,gKy,ddV,gKy,c7b,gKy,c7A,gKy,c87,gKy,dcQ,gKy,ddT,gKy,dd5,gKy,dar,gKy,ddI,gKy,c7G,gKy,c7Z,gKy,c7N,gKy,dal,gKy,c60,gKy,db1,gKy,c94,gKy,c9J,gKy,daq,gKy,dbk,gKy,daH,gKy,c9m,gKy,dcP,gKy,c9b,gKy,dcf,gKy,db6,gKy,c9M,gKy,c9U,gKy,c8I,gKy,ddY,gKy,c64,gKy,c62,gKy,ddi,gKy,dce,gKy,c8C,gKy,ddu,gKy,dc1,gKy,dcM,gKy,dch,gKy,daO,gKy,ded,gKy,dcp,gKy,ddh,gKy,dah,gKy,dbI,gKy,lh,gKy,c9w,gKy,c7R,gKy,dbl,gKy,dcD,gKy,dek,gKy,ddS,gKy,ddD,gKy,da4,gKy,c9B,gKy,c9R,gKy,c9g,gKy,dbv,gKy,ddQ,gKy,dcX,gKy,c7O,gKy,c7X,gKy,daY,gKy,dd8,gKy,c7d,gKy,dc7,gKy,deK,gKy,c65,gKy,dbJ,gKy,c9z,gKy,c8s,gKy,deC,gKy,dct,gKy,c7i,gKy,c9r,gKy,dbc,gKy,dbx,gKy,ddj,gKy,dbY,gKy,c6U,gKy,c8z,gKy,c8h,gKy,dax,gKy,dbC,gKy,deA,gKy,dcc,gKy,dbW,gKy,dc4,gKy,c8j,gKy,dd_,gKy,dbD,gKy,c9S,gKy,c98,gKy,c9W,gKy,ddA,gKy,dbS,gKy,da$,gKy,ddx,gKy,deg,gKy,dco,gKy,ddo,gKy,ddZ,gKy,c8e,gKy,c8F,gKy,dak,gKy,dbt,gKy,ddl,gKy,c8Z,gKy,dcI,gKy,ddk,gKy,c82,gKy,c8l,gKy,dea,gKy,c8H,gKy,c8g,gKy,c7y,gKy,dbZ,gKy,dbw,gKy,c70,gKy,dd2,gKy,c9p,gKy,dcy,gKy,dau,gKy,ddn,gKy,dc$,gKy,dda,gKy,c72,gKy,ddB,gKy,deJ,gKy,c85,gKy,das,gKy,ddP,gKy,c7H,gKy,c8D,gKy,deD,gKy,c6S,gKy,ddf,gKy,c8p,gKy,c9o,gKy,dad,gKy,der,gKy,ddt,gKy,c7r,gKy,dcz,gKy,c8w,gKy,c8u,gKy,dca,gKy,dcL,gKy,deF,gKy,gFc,gKy,dbU,gKy,ddH,gKy,deu,gKy,ddW,gKy,c9Y,gKy,da_,gKy,c63,gKy,gBD,gKy,c9x,gKy,daQ,gKy,dc0,gKy,ddq,gKy,dd7,gKy,dam,gKy,dbQ,gKy,c7t,gKy,c8m,gKy,c7w,gKy,dbR,gKy,gEV,gKy,dez,gKy,c7W,gKy,c7a,gKy,dbh,gKy,dbB,gKy,ddR,gKy,c9G,gKy,gE4,gKy,daG,gKy,daf,gKy,dev,gKy,c8n,gKy,c9c,gKy,c9Q,gKy,c8r,gKy,den,gKy,c7p,gKy,c9n,gKy,c9A,gKy,c74,gKy,c9h,gKy,dcV,gKy,dcS,gKy,c8O,gKy,c7C,gKy,dcU,gKy,daj,gKy,ddO,gKy,deG,gKy,deh,gKy,c7m,gKy,c78,gKy,db4,gKy,ddp,gKy,db0,gKy,c71,gKy,deL,gKy,c9v,gKy,daP,gKy,dbE,gKy,c9F,gKy,dbG,gKy,dat,gKy,dcY,gKy,daR,gKy,deb,gKy,c7M,gKy,da1,gKy,dab,gKy,dcW,gKy,c7g,gKy,c7h,gKy,daX,gKy,c9t,gKy,c93,gKy,c9I,gKy,dcw,gKy,c8R,gKy,gFh,gKy,daK,gKy,c6Q,gKy,dey,gKy,daZ,gKy,c7L,gKy,c6_,gKy,dee,gKy,c8S,gKy,c7c,gKy,c7z,gKy,daJ,gKy,dcJ,gKy,c95,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy,gKy];var gG=[gKz,gKz,bk_,gKz,hG,gKz,bi$,gKz,gIy,gKz,jj,gKz,gBp,gKz,jk,gKz,f48,gKz,gIz,gKz,bmi,gKz,gIA,gKz,gIB,gKz,gIC,gKz,gID,gKz,bmV,gKz,gIE,gKz,ko,gKz,ix,gKz,gIF,gKz,gIG,gKz,gIH,gKz,gII,gKz,bmz,gKz,bf5,gKz,bkF,gKz,gIJ,gKz,gIK,gKz,gIL,gKz,gIM,gKz,a2y,gKz,bkf,gKz,gIN,gKz,bjy,gKz,a2w,gKz,gGG,gKz,a2A,gKz,bd4,gKz,beY,gKz,h0,gKz,a2B,gKz,gAk,gKz,gIO,gKz,gIP,gKz,a2z,gKz,a2C,gKz,kp,gKz,a2x,gKz,gIQ,gKz,gzB,gKz,bkg,gKz,gIR,gKz,gIS,gKz,gIT,gKz,bmy,gKz,bmx,gKz,kC,gKz,gIU,gKz,gIV,gKz,bd0,gKz,gIW,gKz,gIX,gKz,jt,gKz,gIY,gKz,bd_,gKz,f9D,gKz,gIZ,gKz,gI_,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz,gKz];var gH=[gKA,gKA,ku,gKA,kt,gKA,gKA,gKA];var gI=[gKB,gKB,gE0,gKB,gFf,gKB,gE8,gKB,gEU,gKB,gET,gKB,gE7,gKB,gFg,gKB,gE$,gKB,gKB,gKB,gKB,gKB,gKB,gKB,gKB,gKB,gKB,gKB,gKB,gKB,gKB,gKB];var gJ=[gKC,gKC,gEz,gKC,gIw,gKC,lc,gKC,gIx,gKC,lb,gKC,brs,gKC,brt,gKC,gEx,gKC,gEy,gKC,gEF,gKC,bru,gKC,brv,gKC,hp,gKC,gEP,gKC,gKC,gKC];var gK=[gKD,gKD,Sd,gKD,kw,gKD,gKD,gKD];var gL=[gKE,gKE,a93,gKE,gI3,gKE,gI4,gKE,a1Q,gKE,a1L,gKE,bhg,gKE,a1H,gKE,bef,gKE,gAX,gKE,bov,gKE,gGi,gKE,a96,gKE,beb,gKE,bkZ,gKE,gAJ,gKE,a9T,gKE,gI5,gKE,bkE,gKE,gGj,gKE,bad,gKE,a9W,gKE,g5,gKE,gI6,gKE,a1N,gKE,a1U,gKE,a1P,gKE,baa,gKE,gI7,gKE,a1M,gKE,bhB,gKE,a1J,gKE,gI8,gKE,a1S,gKE,a1W,gKE,gI9,gKE,gJa,gKE,bfh,gKE,gJb,gKE,gJc,gKE,gJd,gKE,a1G,gKE,bpi,gKE,bmh,gKE,gJe,gKE,a1O,gKE,a1R,gKE,gJf,gKE,bmw,gKE,gJg,gKE,gJh,gKE,bgO,gKE,gJi,gKE,gJj,gKE,a9X,gKE,a98,gKE,a1T,gKE,a1K,gKE,gJk,gKE,bow,gKE,bdZ,gKE,a1I,gKE,a9J,gKE,gJl,gKE,bd7,gKE,a90,gKE,gJm,gKE,gBE,gKE,a1V,gKE,blD,gKE,gJn,gKE,gBz,gKE,a9Z,gKE,bnI,gKE,a91,gKE,gJo,gKE,bac,gKE,gJp,gKE,gJq,gKE,bd2,gKE,gGh,gKE,a9S,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE,gKE];return{_memset:gGz,_testSetjmp:gGB,_saveSetjmp:gGA,_tolower:gGD,_free:gGr,_main:g1,_realloc:gGs,_strncpy:gGJ,_memmove:gGG,__GLOBAL__I_a:gzM,_strlen:gGy,_memcmp:gGH,__GLOBAL__I_a5035:gAc,_malloc:gGq,_memcpy:gGC,_strcasecmp:gGF,_strncasecmp:gGE,_strcpy:gGI,runPostSets:g0,stackAlloc:gM,stackSave:gN,stackRestore:gO,setThrew:gP,setTempRet0:gS,setTempRet1:gT,setTempRet2:gU,setTempRet3:gV,setTempRet4:gW,setTempRet5:gX,setTempRet6:gY,setTempRet7:gZ,setTempRet8:g_,setTempRet9:g$,dynCall_iiiiiiii:gJx,dynCall_vif:gJy,dynCall_viiiii:gJz,dynCall_vi:gJA,dynCall_vii:gJB,dynCall_iiiiiii:gJC,dynCall_viff:gJD,dynCall_ii:gJE,dynCall_viiiiiiiiiii:gJF,dynCall_viffff:gJG,dynCall_if:gJH,dynCall_viiif:gJI,dynCall_iiifii:gJJ,dynCall_iiii:gJK,dynCall_viiiiif:gJL,dynCall_viiiiiiii:gJM,dynCall_vifff:gJN,dynCall_fii:gJO,dynCall_v:gJP,dynCall_iif:gJQ,dynCall_viiiiiii:gJR,dynCall_ff:gJS,dynCall_viiiiiiiii:gJT,dynCall_viiiiiif:gJU,dynCall_iii:gJV,dynCall_viiiiii:gJW,dynCall_f:gJX,dynCall_i:gJY,dynCall_vff:gJZ,dynCall_iiiiii:gJ_,dynCall_viii:gJ$,dynCall_viiffff:gJ0,dynCall_iiiiiiiii:gJ1,dynCall_iiiii:gJ2,dynCall_viif:gJ3,dynCall_viiii:gJ4}})
// EMSCRIPTEN_END_ASM
({ "Math": Math, "Int8Array": Int8Array, "Int16Array": Int16Array, "Int32Array": Int32Array, "Uint8Array": Uint8Array, "Uint16Array": Uint16Array, "Uint32Array": Uint32Array, "Float32Array": Float32Array, "Float64Array": Float64Array }, { "abort": abort, "assert": assert, "asmPrintInt": asmPrintInt, "asmPrintFloat": asmPrintFloat, "min": Math_min, "invoke_iiiiiiii": invoke_iiiiiiii, "invoke_vif": invoke_vif, "invoke_viiiii": invoke_viiiii, "invoke_vi": invoke_vi, "invoke_vii": invoke_vii, "invoke_iiiiiii": invoke_iiiiiii, "invoke_viff": invoke_viff, "invoke_ii": invoke_ii, "invoke_viiiiiiiiiii": invoke_viiiiiiiiiii, "invoke_viffff": invoke_viffff, "invoke_if": invoke_if, "invoke_viiif": invoke_viiif, "invoke_iiifii": invoke_iiifii, "invoke_iiii": invoke_iiii, "invoke_viiiiif": invoke_viiiiif, "invoke_viiiiiiii": invoke_viiiiiiii, "invoke_vifff": invoke_vifff, "invoke_fii": invoke_fii, "invoke_v": invoke_v, "invoke_iif": invoke_iif, "invoke_viiiiiii": invoke_viiiiiii, "invoke_ff": invoke_ff, "invoke_viiiiiiiii": invoke_viiiiiiiii, "invoke_viiiiiif": invoke_viiiiiif, "invoke_iii": invoke_iii, "invoke_viiiiii": invoke_viiiiii, "invoke_f": invoke_f, "invoke_i": invoke_i, "invoke_vff": invoke_vff, "invoke_iiiiii": invoke_iiiiii, "invoke_viii": invoke_viii, "invoke_viiffff": invoke_viiffff, "invoke_iiiiiiiii": invoke_iiiiiiiii, "invoke_iiiii": invoke_iiiii, "invoke_viif": invoke_viif, "invoke_viiii": invoke_viiii, "_RWebInputDestroy": _RWebInputDestroy, "__scanString": __scanString, "_fclose": _fclose, "_glStencilMaskSeparate": _glStencilMaskSeparate, "_pthread_mutex_lock": _pthread_mutex_lock, "___cxa_end_catch": ___cxa_end_catch, "_glFramebufferRenderbuffer": _glFramebufferRenderbuffer, "_send": _send, "_glLineWidth": _glLineWidth, "_glCompileShader": _glCompileShader, "_isspace": _isspace, "_localtime": _localtime, "_glDepthRangef": _glDepthRangef, "_opendir": _opendir, "___resumeException": ___resumeException, "_glCreateShader": _glCreateShader, "_round": _round, "_glGenRenderbuffers": _glGenRenderbuffers, "_cosf": _cosf, "_glCompressedTexImage2D": _glCompressedTexImage2D, "_snprintf": _snprintf, "_glBlendFuncSeparate": _glBlendFuncSeparate, "_glHint": _glHint, "_mknod": _mknod, "___cxa_free_exception": ___cxa_free_exception, "_glDeleteProgram": _glDeleteProgram, "_glRenderbufferStorage": _glRenderbufferStorage, "_glLoadIdentity": _glLoadIdentity, "_glUniform3i": _glUniform3i, "_localtime_r": _localtime_r, "_glUniform3f": _glUniform3f, "___cxa_guard_acquire": ___cxa_guard_acquire, "_glGetBufferParameteriv": _glGetBufferParameteriv, "_sinf": _sinf, "_glGenVertexArrays": _glGenVertexArrays, "_eglChooseConfig": _eglChooseConfig, "_eglQuerySurface": _eglQuerySurface, "_glBegin": _glBegin, "_printf": _printf, "_glVertexPointer": _glVertexPointer, "_glDeleteFramebuffers": _glDeleteFramebuffers, "_glDrawArrays": _glDrawArrays, "_llvm_pow_f32": _llvm_pow_f32, "__arraySum": __arraySum, "_glClear": _glClear, "_gluProject": _gluProject, "_glIsEnabled": _glIsEnabled, "_glStencilOp": _glStencilOp, "_strdup": _strdup, "_glFramebufferTexture2D": _glFramebufferTexture2D, "_glGetFramebufferAttachmentParameteriv": _glGetFramebufferAttachmentParameteriv, "_eglCreateWindowSurface": _eglCreateWindowSurface, "_pthread_cond_broadcast": _pthread_cond_broadcast, "__ZSt9terminatev": __ZSt9terminatev, "_glTexParameteriv": _glTexParameteriv, "_glGenFramebuffers": _glGenFramebuffers, "___errno_location": ___errno_location, "_strerror": _strerror, "_glGetAttachedShaders": _glGetAttachedShaders, "_catclose": _catclose, "_glIsRenderbuffer": _glIsRenderbuffer, "__parseInt": __parseInt, "_fprintf": _fprintf, "_glDisableVertexAttribArray": _glDisableVertexAttribArray, "_sysconf": _sysconf, "_abort": _abort, "_glIsShader": _glIsShader, "_strtoll": _strtoll, "_glDisable": _glDisable, "_glEnable": _glEnable, "_feof": _feof, "_eglDestroySurface": _eglDestroySurface, "_write": _write, "_glGetAttribLocation": _glGetAttribLocation, "_rewind": _rewind, "_sin": _sin, "_vasprintf": _vasprintf, "_emscripten_set_main_loop": _emscripten_set_main_loop, "_glGetUniformfv": _glGetUniformfv, "_unlink": _unlink, "_gluOrtho2D": _gluOrtho2D, "_glDepthRange": _glDepthRange, "_pwrite": _pwrite, "_RWebAudioStart": _RWebAudioStart, "_glFlush": _glFlush, "_glGetRenderbufferParameteriv": _glGetRenderbufferParameteriv, "_glGetVertexAttribPointerv": _glGetVertexAttribPointerv, "_strtoul": _strtoul, "__isLeapYear": __isLeapYear, "_fwrite": _fwrite, "_gluUnProject": _gluUnProject, "_eglBindAPI": _eglBindAPI, "_glStencilFuncSeparate": _glStencilFuncSeparate, "_glUniform4iv": _glUniform4iv, "_glClearStencil": _glClearStencil, "_glGenTextures": _glGenTextures, "___cxa_rethrow": ___cxa_rethrow, "_RWebAudioWrite": _RWebAudioWrite, "_memchr": _memchr, "_llvm_va_end": _llvm_va_end, "_clock_gettime": _clock_gettime, "_vsscanf": _vsscanf, "_glDeleteRenderbuffers": _glDeleteRenderbuffers, "_glUniform2i": _glUniform2i, "_glUniform2f": _glUniform2f, "_glGetProgramiv": _glGetProgramiv, "_glVertexAttribPointer": _glVertexAttribPointer, "_glutInitDisplayMode": _glutInitDisplayMode, "_sprintf": _sprintf, "___ctype_b_loc": ___ctype_b_loc, "_strrchr": _strrchr, "_RWebInputPoll": _RWebInputPoll, "_catgets": _catgets, "_asprintf": _asprintf, "_ferror": _ferror, "_llvm_uadd_with_overflow_i32": _llvm_uadd_with_overflow_i32, "_glCopyTexImage2D": _glCopyTexImage2D, "___cxa_begin_catch": ___cxa_begin_catch, "_recv": _recv, "_glUniform2iv": _glUniform2iv, "__ZSt18uncaught_exceptionv": __ZSt18uncaught_exceptionv, "_putchar": _putchar, "_glMatrixMode": _glMatrixMode, "_glIsBuffer": _glIsBuffer, "_glGetShaderiv": _glGetShaderiv, "_rand": _rand, "_RWebAudioSampleRate": _RWebAudioSampleRate, "_glCopyTexSubImage2D": _glCopyTexSubImage2D, "_mkdir": _mkdir, "_glPolygonOffset": _glPolygonOffset, "_open": _open, "_usleep": _usleep, "_glVertexAttrib1fv": _glVertexAttrib1fv, "_exp2": _exp2, "_qsort": _qsort, "_isalpha": _isalpha, "_glUniform3fv": _glUniform3fv, "_glGetVertexAttribiv": _glGetVertexAttribiv, "_isascii": _isascii, "_glVertexAttrib3fv": _glVertexAttrib3fv, "_glUniform3iv": _glUniform3iv, "_llvm_pow_f64": _llvm_pow_f64, "_strerror_r": _strerror_r, "_llvm_bswap_i32": _llvm_bswap_i32, "___cxa_guard_release": ___cxa_guard_release, "_vsnprintf": _vsnprintf, "_glUseProgram": _glUseProgram, "_glGetProgramInfoLog": _glGetProgramInfoLog, "_strtok_r": _strtok_r, "___buildEnvironment": ___buildEnvironment, "__addDays": __addDays, "_fseek": _fseek, "_glFinish": _glFinish, "_gluLookAt": _gluLookAt, "_glDeleteShader": _glDeleteShader, "_realpath": _realpath, "_glViewport": _glViewport, "_catopen": _catopen, "_RWebAudioWriteAvail": _RWebAudioWriteAvail, "_glClearDepth": _glClearDepth, "_glTexParameterf": _glTexParameterf, "_glTexParameteri": _glTexParameteri, "_glCullFace": _glCullFace, "_glGetShaderSource": _glGetShaderSource, "_eglGetDisplay": _eglGetDisplay, "_emscripten_set_canvas_size": _emscripten_set_canvas_size, "_exp": _exp, "_glValidateProgram": _glValidateProgram, "_RWebAudioBufferSize": _RWebAudioBufferSize, "_eglTerminate": _eglTerminate, "_glLinkProgram": _glLinkProgram, "_strtoull": _strtoull, "_glBindTexture": _glBindTexture, "_strtol": _strtol, "_fputc": _fputc, "_glGetString": _glGetString, "_glDetachShader": _glDetachShader, "_fputs": _fputs, "_RWebAudioFree": _RWebAudioFree, "_glDeleteTextures": _glDeleteTextures, "_glStencilOpSeparate": _glStencilOpSeparate, "_glVertexAttrib4f": _glVertexAttrib4f, "_ceil": _ceil, "_glGetTexParameteriv": _glGetTexParameteriv, "_glutDestroyWindow": _glutDestroyWindow, "_glSampleCoverage": _glSampleCoverage, "_remove": _remove, "_pthread_cond_wait": _pthread_cond_wait, "_glUniform1f": _glUniform1f, "_glGetVertexAttribfv": _glGetVertexAttribfv, "_glUniform1i": _glUniform1i, "_strncmp": _strncmp, "_glTexSubImage2D": _glTexSubImage2D, "_glGetUniformiv": _glGetUniformiv, "_atexit": _atexit, "_close": _close, "_glBindFramebuffer": _glBindFramebuffer, "_strchr": _strchr, "___setErrNo": ___setErrNo, "_emscripten_GetProcAddress": _emscripten_GetProcAddress, "_eglGetProcAddress": _eglGetProcAddress, "_freelocale": _freelocale, "_glAttachShader": _glAttachShader, "_glShaderBinary": _glShaderBinary, "___cxa_is_number_type": ___cxa_is_number_type, "___cxa_does_inherit": ___cxa_does_inherit, "_emscripten_get_canvas_size": _emscripten_get_canvas_size, "_glDrawElements": _glDrawElements, "_glUniform1iv": _glUniform1iv, "_glGenerateMipmap": _glGenerateMipmap, "_strftime": _strftime, "_glVertexAttrib3f": _glVertexAttrib3f, "_tzset": _tzset, "_fabsf": _fabsf, "___cxa_throw": ___cxa_throw, "_glBindRenderbuffer": _glBindRenderbuffer, "_pread": _pread, "_glIsProgram": _glIsProgram, "_puts": _puts, "_nanosleep": _nanosleep, "_glVertexAttrib4fv": _glVertexAttrib4fv, "_glReleaseShaderCompiler": _glReleaseShaderCompiler, "_glUniform4i": _glUniform4i, "_glActiveTexture": _glActiveTexture, "_glEnableVertexAttribArray": _glEnableVertexAttribArray, "___cxa_find_matching_catch": ___cxa_find_matching_catch, "_glReadPixels": _glReadPixels, "_glUniform4f": _glUniform4f, "___gxx_personality_v0": ___gxx_personality_v0, "_fread": _fread, "_glUniformMatrix3fv": _glUniformMatrix3fv, "__formatString": __formatString, "_emscripten_procAddressTable": _emscripten_procAddressTable, "_glIsTexture": _glIsTexture, "_glStencilFunc": _glStencilFunc, "_srand": _srand, "_glGetShaderInfoLog": _glGetShaderInfoLog, "_RWebAudioSetNonblockState": _RWebAudioSetNonblockState, "_fabs": _fabs, "_RWebAudioStop": _RWebAudioStop, "_sqrt": _sqrt, "_glBlendEquationSeparate": _glBlendEquationSeparate, "_glGenBuffers": _glGenBuffers, "_glBlendFunc": _glBlendFunc, "_glCreateProgram": _glCreateProgram, "_longjmp": _longjmp, "_glIsFramebuffer": _glIsFramebuffer, "_isgraph": _isgraph, "___ctype_tolower_loc": ___ctype_tolower_loc, "_glDeleteBuffers": _glDeleteBuffers, "_glScissor": _glScissor, "_glGetBooleanv": _glGetBooleanv, "_llvm_lifetime_end": _llvm_lifetime_end, "_lseek": _lseek, "_glClearColor": _glClearColor, "_RWebAudioInit": _RWebAudioInit, "_glBlendColor": _glBlendColor, "_fflush": _fflush, "_llvm_eh_exception": _llvm_eh_exception, "_glUniform2fv": _glUniform2fv, "_eglCreateContext": _eglCreateContext, "_read": _read, "_RWebInputInit": _RWebInputInit, "_glClearDepthf": _glClearDepthf, "_strstr": _strstr, "_fsync": _fsync, "___cxa_guard_abort": ___cxa_guard_abort, "_newlocale": _newlocale, "_glDepthFunc": _glDepthFunc, "_glCompressedTexSubImage2D": _glCompressedTexSubImage2D, "_glGetTexParameterfv": _glGetTexParameterfv, "_strcmp": _strcmp, "_glVertexAttrib1f": _glVertexAttrib1f, "_fgetc": _fgetc, "_readdir": _readdir, "_glColorMask": _glColorMask, "__getFloat": __getFloat, "_glBlendEquation": _glBlendEquation, "_fgets": _fgets, "_getgid": _getgid, "_glUniform4fv": _glUniform4fv, "_isxdigit": _isxdigit, "_ftell": _ftell, "_exit": _exit, "_glCheckFramebufferStatus": _glCheckFramebufferStatus, "_glBindAttribLocation": _glBindAttribLocation, "_eglInitialize": _eglInitialize, "__parseInt64": __parseInt64, "_glBufferSubData": _glBufferSubData, "___cxa_call_unexpected": ___cxa_call_unexpected, "__exit": __exit, "_glGetShaderPrecisionFormat": _glGetShaderPrecisionFormat, "_glShaderSource": _glShaderSource, "_fopen": _fopen, "_log": _log, "_eglDestroyContext": _eglDestroyContext, "_rmdir": _rmdir, "_glBindBuffer": _glBindBuffer, "_glUniformMatrix2fv": _glUniformMatrix2fv, "_glutCreateWindow": _glutCreateWindow, "_glBufferData": _glBufferData, "_getenv": _getenv, "_glGetError": _glGetError, "_pthread_mutex_unlock": _pthread_mutex_unlock, "_glGetFloatv": _glGetFloatv, "_glVertexAttrib2fv": _glVertexAttrib2fv, "_sbrk": _sbrk, "_glGetIntegerv": _glGetIntegerv, "_llvm_lifetime_start": _llvm_lifetime_start, "_ungetc": _ungetc, "_uselocale": _uselocale, "_sscanf": _sscanf, "_glTexImage2D": _glTexImage2D, "_glStencilMask": _glStencilMask, "_eglMakeCurrent": _eglMakeCurrent, "_glGetUniformLocation": _glGetUniformLocation, "_glUniform1fv": _glUniform1fv, "_gluPerspective": _gluPerspective, "_isdigit": _isdigit, "__reallyNegative": __reallyNegative, "_glTexParameterfv": _glTexParameterfv, "_floor": _floor, "_glGetActiveAttrib": _glGetActiveAttrib, "___cxa_allocate_exception": ___cxa_allocate_exception, "_stat": _stat, "_glPixelStorei": _glPixelStorei, "_readdir_r": _readdir_r, "___ctype_toupper_loc": ___ctype_toupper_loc, "_glVertexAttrib2f": _glVertexAttrib2f, "_closedir": _closedir, "_readlink": _readlink, "_glDepthMask": _glDepthMask, "_glUniformMatrix4fv": _glUniformMatrix4fv, "_glGetActiveUniform": _glGetActiveUniform, "_glFrontFace": _glFrontFace, "_llvm_bswap_i16": _llvm_bswap_i16, "_time": _time, "STACKTOP": STACKTOP, "STACK_MAX": STACK_MAX, "tempDoublePtr": tempDoublePtr, "ABORT": ABORT, "cttz_i8": cttz_i8, "ctlz_i8": ctlz_i8, "NaN": NaN, "Infinity": Infinity, "__ZTVN10__cxxabiv117__class_type_infoE": __ZTVN10__cxxabiv117__class_type_infoE, "_stdin": _stdin, "___fsmu8": ___fsmu8, "__ZTVN10__cxxabiv120__si_class_type_infoE": __ZTVN10__cxxabiv120__si_class_type_infoE, "_stdout": _stdout, "___dso_handle": ___dso_handle, "_stderr": _stderr }, buffer);
var _memset = Module["_memset"] = asm["_memset"];
var _testSetjmp = Module["_testSetjmp"] = asm["_testSetjmp"];
var _saveSetjmp = Module["_saveSetjmp"] = asm["_saveSetjmp"];
var _tolower = Module["_tolower"] = asm["_tolower"];
var _free = Module["_free"] = asm["_free"];
var _main = Module["_main"] = asm["_main"];
var _realloc = Module["_realloc"] = asm["_realloc"];
var _strncpy = Module["_strncpy"] = asm["_strncpy"];
var _memmove = Module["_memmove"] = asm["_memmove"];
var __GLOBAL__I_a = Module["__GLOBAL__I_a"] = asm["__GLOBAL__I_a"];
var _strlen = Module["_strlen"] = asm["_strlen"];
var _memcmp = Module["_memcmp"] = asm["_memcmp"];
var __GLOBAL__I_a5035 = Module["__GLOBAL__I_a5035"] = asm["__GLOBAL__I_a5035"];
var _malloc = Module["_malloc"] = asm["_malloc"];
var _memcpy = Module["_memcpy"] = asm["_memcpy"];
var _strcasecmp = Module["_strcasecmp"] = asm["_strcasecmp"];
var _strncasecmp = Module["_strncasecmp"] = asm["_strncasecmp"];
var _strcpy = Module["_strcpy"] = asm["_strcpy"];
var runPostSets = Module["runPostSets"] = asm["runPostSets"];
var dynCall_iiiiiiii = Module["dynCall_iiiiiiii"] = asm["dynCall_iiiiiiii"];
var dynCall_vif = Module["dynCall_vif"] = asm["dynCall_vif"];
var dynCall_viiiii = Module["dynCall_viiiii"] = asm["dynCall_viiiii"];
var dynCall_vi = Module["dynCall_vi"] = asm["dynCall_vi"];
var dynCall_vii = Module["dynCall_vii"] = asm["dynCall_vii"];
var dynCall_iiiiiii = Module["dynCall_iiiiiii"] = asm["dynCall_iiiiiii"];
var dynCall_viff = Module["dynCall_viff"] = asm["dynCall_viff"];
var dynCall_ii = Module["dynCall_ii"] = asm["dynCall_ii"];
var dynCall_viiiiiiiiiii = Module["dynCall_viiiiiiiiiii"] = asm["dynCall_viiiiiiiiiii"];
var dynCall_viffff = Module["dynCall_viffff"] = asm["dynCall_viffff"];
var dynCall_if = Module["dynCall_if"] = asm["dynCall_if"];
var dynCall_viiif = Module["dynCall_viiif"] = asm["dynCall_viiif"];
var dynCall_iiifii = Module["dynCall_iiifii"] = asm["dynCall_iiifii"];
var dynCall_iiii = Module["dynCall_iiii"] = asm["dynCall_iiii"];
var dynCall_viiiiif = Module["dynCall_viiiiif"] = asm["dynCall_viiiiif"];
var dynCall_viiiiiiii = Module["dynCall_viiiiiiii"] = asm["dynCall_viiiiiiii"];
var dynCall_vifff = Module["dynCall_vifff"] = asm["dynCall_vifff"];
var dynCall_fii = Module["dynCall_fii"] = asm["dynCall_fii"];
var dynCall_v = Module["dynCall_v"] = asm["dynCall_v"];
var dynCall_iif = Module["dynCall_iif"] = asm["dynCall_iif"];
var dynCall_viiiiiii = Module["dynCall_viiiiiii"] = asm["dynCall_viiiiiii"];
var dynCall_ff = Module["dynCall_ff"] = asm["dynCall_ff"];
var dynCall_viiiiiiiii = Module["dynCall_viiiiiiiii"] = asm["dynCall_viiiiiiiii"];
var dynCall_viiiiiif = Module["dynCall_viiiiiif"] = asm["dynCall_viiiiiif"];
var dynCall_iii = Module["dynCall_iii"] = asm["dynCall_iii"];
var dynCall_viiiiii = Module["dynCall_viiiiii"] = asm["dynCall_viiiiii"];
var dynCall_f = Module["dynCall_f"] = asm["dynCall_f"];
var dynCall_i = Module["dynCall_i"] = asm["dynCall_i"];
var dynCall_vff = Module["dynCall_vff"] = asm["dynCall_vff"];
var dynCall_iiiiii = Module["dynCall_iiiiii"] = asm["dynCall_iiiiii"];
var dynCall_viii = Module["dynCall_viii"] = asm["dynCall_viii"];
var dynCall_viiffff = Module["dynCall_viiffff"] = asm["dynCall_viiffff"];
var dynCall_iiiiiiiii = Module["dynCall_iiiiiiiii"] = asm["dynCall_iiiiiiiii"];
var dynCall_iiiii = Module["dynCall_iiiii"] = asm["dynCall_iiiii"];
var dynCall_viif = Module["dynCall_viif"] = asm["dynCall_viif"];
var dynCall_viiii = Module["dynCall_viiii"] = asm["dynCall_viiii"];
Runtime.stackAlloc = function(size) { return asm['stackAlloc'](size) };
Runtime.stackSave = function() { return asm['stackSave']() };
Runtime.stackRestore = function(top) { asm['stackRestore'](top) };
// TODO: strip out parts of this we do not need
//======= begin closure i64 code =======
// Copyright 2009 The Closure Library Authors. All Rights Reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS-IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
/**
 * @fileoverview Defines a Long class for representing a 64-bit two's-complement
 * integer value, which faithfully simulates the behavior of a Java "long". This
 * implementation is derived from LongLib in GWT.
 *
 */
var i64Math = (function() { // Emscripten wrapper
  var goog = { math: {} };
  /**
   * Constructs a 64-bit two's-complement integer, given its low and high 32-bit
   * values as *signed* integers.  See the from* functions below for more
   * convenient ways of constructing Longs.
   *
   * The internal representation of a long is the two given signed, 32-bit values.
   * We use 32-bit pieces because these are the size of integers on which
   * Javascript performs bit-operations.  For operations like addition and
   * multiplication, we split each number into 16-bit pieces, which can easily be
   * multiplied within Javascript's floating-point representation without overflow
   * or change in sign.
   *
   * In the algorithms below, we frequently reduce the negative case to the
   * positive case by negating the input(s) and then post-processing the result.
   * Note that we must ALWAYS check specially whether those values are MIN_VALUE
   * (-2^63) because -MIN_VALUE == MIN_VALUE (since 2^63 cannot be represented as
   * a positive number, it overflows back into a negative).  Not handling this
   * case would often result in infinite recursion.
   *
   * @param {number} low  The low (signed) 32 bits of the long.
   * @param {number} high  The high (signed) 32 bits of the long.
   * @constructor
   */
  goog.math.Long = function(low, high) {
    /**
     * @type {number}
     * @private
     */
    this.low_ = low | 0;  // force into 32 signed bits.
    /**
     * @type {number}
     * @private
     */
    this.high_ = high | 0;  // force into 32 signed bits.
  };
  // NOTE: Common constant values ZERO, ONE, NEG_ONE, etc. are defined below the
  // from* methods on which they depend.
  /**
   * A cache of the Long representations of small integer values.
   * @type {!Object}
   * @private
   */
  goog.math.Long.IntCache_ = {};
  /**
   * Returns a Long representing the given (32-bit) integer value.
   * @param {number} value The 32-bit integer in question.
   * @return {!goog.math.Long} The corresponding Long value.
   */
  goog.math.Long.fromInt = function(value) {
    if (-128 <= value && value < 128) {
      var cachedObj = goog.math.Long.IntCache_[value];
      if (cachedObj) {
        return cachedObj;
      }
    }
    var obj = new goog.math.Long(value | 0, value < 0 ? -1 : 0);
    if (-128 <= value && value < 128) {
      goog.math.Long.IntCache_[value] = obj;
    }
    return obj;
  };
  /**
   * Returns a Long representing the given value, provided that it is a finite
   * number.  Otherwise, zero is returned.
   * @param {number} value The number in question.
   * @return {!goog.math.Long} The corresponding Long value.
   */
  goog.math.Long.fromNumber = function(value) {
    if (isNaN(value) || !isFinite(value)) {
      return goog.math.Long.ZERO;
    } else if (value <= -goog.math.Long.TWO_PWR_63_DBL_) {
      return goog.math.Long.MIN_VALUE;
    } else if (value + 1 >= goog.math.Long.TWO_PWR_63_DBL_) {
      return goog.math.Long.MAX_VALUE;
    } else if (value < 0) {
      return goog.math.Long.fromNumber(-value).negate();
    } else {
      return new goog.math.Long(
          (value % goog.math.Long.TWO_PWR_32_DBL_) | 0,
          (value / goog.math.Long.TWO_PWR_32_DBL_) | 0);
    }
  };
  /**
   * Returns a Long representing the 64-bit integer that comes by concatenating
   * the given high and low bits.  Each is assumed to use 32 bits.
   * @param {number} lowBits The low 32-bits.
   * @param {number} highBits The high 32-bits.
   * @return {!goog.math.Long} The corresponding Long value.
   */
  goog.math.Long.fromBits = function(lowBits, highBits) {
    return new goog.math.Long(lowBits, highBits);
  };
  /**
   * Returns a Long representation of the given string, written using the given
   * radix.
   * @param {string} str The textual representation of the Long.
   * @param {number=} opt_radix The radix in which the text is written.
   * @return {!goog.math.Long} The corresponding Long value.
   */
  goog.math.Long.fromString = function(str, opt_radix) {
    if (str.length == 0) {
      throw Error('number format error: empty string');
    }
    var radix = opt_radix || 10;
    if (radix < 2 || 36 < radix) {
      throw Error('radix out of range: ' + radix);
    }
    if (str.charAt(0) == '-') {
      return goog.math.Long.fromString(str.substring(1), radix).negate();
    } else if (str.indexOf('-') >= 0) {
      throw Error('number format error: interior "-" character: ' + str);
    }
    // Do several (8) digits each time through the loop, so as to
    // minimize the calls to the very expensive emulated div.
    var radixToPower = goog.math.Long.fromNumber(Math.pow(radix, 8));
    var result = goog.math.Long.ZERO;
    for (var i = 0; i < str.length; i += 8) {
      var size = Math.min(8, str.length - i);
      var value = parseInt(str.substring(i, i + size), radix);
      if (size < 8) {
        var power = goog.math.Long.fromNumber(Math.pow(radix, size));
        result = result.multiply(power).add(goog.math.Long.fromNumber(value));
      } else {
        result = result.multiply(radixToPower);
        result = result.add(goog.math.Long.fromNumber(value));
      }
    }
    return result;
  };
  // NOTE: the compiler should inline these constant values below and then remove
  // these variables, so there should be no runtime penalty for these.
  /**
   * Number used repeated below in calculations.  This must appear before the
   * first call to any from* function below.
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_16_DBL_ = 1 << 16;
  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_24_DBL_ = 1 << 24;
  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_32_DBL_ =
      goog.math.Long.TWO_PWR_16_DBL_ * goog.math.Long.TWO_PWR_16_DBL_;
  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_31_DBL_ =
      goog.math.Long.TWO_PWR_32_DBL_ / 2;
  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_48_DBL_ =
      goog.math.Long.TWO_PWR_32_DBL_ * goog.math.Long.TWO_PWR_16_DBL_;
  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_64_DBL_ =
      goog.math.Long.TWO_PWR_32_DBL_ * goog.math.Long.TWO_PWR_32_DBL_;
  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_63_DBL_ =
      goog.math.Long.TWO_PWR_64_DBL_ / 2;
  /** @type {!goog.math.Long} */
  goog.math.Long.ZERO = goog.math.Long.fromInt(0);
  /** @type {!goog.math.Long} */
  goog.math.Long.ONE = goog.math.Long.fromInt(1);
  /** @type {!goog.math.Long} */
  goog.math.Long.NEG_ONE = goog.math.Long.fromInt(-1);
  /** @type {!goog.math.Long} */
  goog.math.Long.MAX_VALUE =
      goog.math.Long.fromBits(0xFFFFFFFF | 0, 0x7FFFFFFF | 0);
  /** @type {!goog.math.Long} */
  goog.math.Long.MIN_VALUE = goog.math.Long.fromBits(0, 0x80000000 | 0);
  /**
   * @type {!goog.math.Long}
   * @private
   */
  goog.math.Long.TWO_PWR_24_ = goog.math.Long.fromInt(1 << 24);
  /** @return {number} The value, assuming it is a 32-bit integer. */
  goog.math.Long.prototype.toInt = function() {
    return this.low_;
  };
  /** @return {number} The closest floating-point representation to this value. */
  goog.math.Long.prototype.toNumber = function() {
    return this.high_ * goog.math.Long.TWO_PWR_32_DBL_ +
           this.getLowBitsUnsigned();
  };
  /**
   * @param {number=} opt_radix The radix in which the text should be written.
   * @return {string} The textual representation of this value.
   */
  goog.math.Long.prototype.toString = function(opt_radix) {
    var radix = opt_radix || 10;
    if (radix < 2 || 36 < radix) {
      throw Error('radix out of range: ' + radix);
    }
    if (this.isZero()) {
      return '0';
    }
    if (this.isNegative()) {
      if (this.equals(goog.math.Long.MIN_VALUE)) {
        // We need to change the Long value before it can be negated, so we remove
        // the bottom-most digit in this base and then recurse to do the rest.
        var radixLong = goog.math.Long.fromNumber(radix);
        var div = this.div(radixLong);
        var rem = div.multiply(radixLong).subtract(this);
        return div.toString(radix) + rem.toInt().toString(radix);
      } else {
        return '-' + this.negate().toString(radix);
      }
    }
    // Do several (6) digits each time through the loop, so as to
    // minimize the calls to the very expensive emulated div.
    var radixToPower = goog.math.Long.fromNumber(Math.pow(radix, 6));
    var rem = this;
    var result = '';
    while (true) {
      var remDiv = rem.div(radixToPower);
      var intval = rem.subtract(remDiv.multiply(radixToPower)).toInt();
      var digits = intval.toString(radix);
      rem = remDiv;
      if (rem.isZero()) {
        return digits + result;
      } else {
        while (digits.length < 6) {
          digits = '0' + digits;
        }
        result = '' + digits + result;
      }
    }
  };
  /** @return {number} The high 32-bits as a signed value. */
  goog.math.Long.prototype.getHighBits = function() {
    return this.high_;
  };
  /** @return {number} The low 32-bits as a signed value. */
  goog.math.Long.prototype.getLowBits = function() {
    return this.low_;
  };
  /** @return {number} The low 32-bits as an unsigned value. */
  goog.math.Long.prototype.getLowBitsUnsigned = function() {
    return (this.low_ >= 0) ?
        this.low_ : goog.math.Long.TWO_PWR_32_DBL_ + this.low_;
  };
  /**
   * @return {number} Returns the number of bits needed to represent the absolute
   *     value of this Long.
   */
  goog.math.Long.prototype.getNumBitsAbs = function() {
    if (this.isNegative()) {
      if (this.equals(goog.math.Long.MIN_VALUE)) {
        return 64;
      } else {
        return this.negate().getNumBitsAbs();
      }
    } else {
      var val = this.high_ != 0 ? this.high_ : this.low_;
      for (var bit = 31; bit > 0; bit--) {
        if ((val & (1 << bit)) != 0) {
          break;
        }
      }
      return this.high_ != 0 ? bit + 33 : bit + 1;
    }
  };
  /** @return {boolean} Whether this value is zero. */
  goog.math.Long.prototype.isZero = function() {
    return this.high_ == 0 && this.low_ == 0;
  };
  /** @return {boolean} Whether this value is negative. */
  goog.math.Long.prototype.isNegative = function() {
    return this.high_ < 0;
  };
  /** @return {boolean} Whether this value is odd. */
  goog.math.Long.prototype.isOdd = function() {
    return (this.low_ & 1) == 1;
  };
  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long equals the other.
   */
  goog.math.Long.prototype.equals = function(other) {
    return (this.high_ == other.high_) && (this.low_ == other.low_);
  };
  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long does not equal the other.
   */
  goog.math.Long.prototype.notEquals = function(other) {
    return (this.high_ != other.high_) || (this.low_ != other.low_);
  };
  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long is less than the other.
   */
  goog.math.Long.prototype.lessThan = function(other) {
    return this.compare(other) < 0;
  };
  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long is less than or equal to the other.
   */
  goog.math.Long.prototype.lessThanOrEqual = function(other) {
    return this.compare(other) <= 0;
  };
  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long is greater than the other.
   */
  goog.math.Long.prototype.greaterThan = function(other) {
    return this.compare(other) > 0;
  };
  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long is greater than or equal to the other.
   */
  goog.math.Long.prototype.greaterThanOrEqual = function(other) {
    return this.compare(other) >= 0;
  };
  /**
   * Compares this Long with the given one.
   * @param {goog.math.Long} other Long to compare against.
   * @return {number} 0 if they are the same, 1 if the this is greater, and -1
   *     if the given one is greater.
   */
  goog.math.Long.prototype.compare = function(other) {
    if (this.equals(other)) {
      return 0;
    }
    var thisNeg = this.isNegative();
    var otherNeg = other.isNegative();
    if (thisNeg && !otherNeg) {
      return -1;
    }
    if (!thisNeg && otherNeg) {
      return 1;
    }
    // at this point, the signs are the same, so subtraction will not overflow
    if (this.subtract(other).isNegative()) {
      return -1;
    } else {
      return 1;
    }
  };
  /** @return {!goog.math.Long} The negation of this value. */
  goog.math.Long.prototype.negate = function() {
    if (this.equals(goog.math.Long.MIN_VALUE)) {
      return goog.math.Long.MIN_VALUE;
    } else {
      return this.not().add(goog.math.Long.ONE);
    }
  };
  /**
   * Returns the sum of this and the given Long.
   * @param {goog.math.Long} other Long to add to this one.
   * @return {!goog.math.Long} The sum of this and the given Long.
   */
  goog.math.Long.prototype.add = function(other) {
    // Divide each number into 4 chunks of 16 bits, and then sum the chunks.
    var a48 = this.high_ >>> 16;
    var a32 = this.high_ & 0xFFFF;
    var a16 = this.low_ >>> 16;
    var a00 = this.low_ & 0xFFFF;
    var b48 = other.high_ >>> 16;
    var b32 = other.high_ & 0xFFFF;
    var b16 = other.low_ >>> 16;
    var b00 = other.low_ & 0xFFFF;
    var c48 = 0, c32 = 0, c16 = 0, c00 = 0;
    c00 += a00 + b00;
    c16 += c00 >>> 16;
    c00 &= 0xFFFF;
    c16 += a16 + b16;
    c32 += c16 >>> 16;
    c16 &= 0xFFFF;
    c32 += a32 + b32;
    c48 += c32 >>> 16;
    c32 &= 0xFFFF;
    c48 += a48 + b48;
    c48 &= 0xFFFF;
    return goog.math.Long.fromBits((c16 << 16) | c00, (c48 << 16) | c32);
  };
  /**
   * Returns the difference of this and the given Long.
   * @param {goog.math.Long} other Long to subtract from this.
   * @return {!goog.math.Long} The difference of this and the given Long.
   */
  goog.math.Long.prototype.subtract = function(other) {
    return this.add(other.negate());
  };
  /**
   * Returns the product of this and the given long.
   * @param {goog.math.Long} other Long to multiply with this.
   * @return {!goog.math.Long} The product of this and the other.
   */
  goog.math.Long.prototype.multiply = function(other) {
    if (this.isZero()) {
      return goog.math.Long.ZERO;
    } else if (other.isZero()) {
      return goog.math.Long.ZERO;
    }
    if (this.equals(goog.math.Long.MIN_VALUE)) {
      return other.isOdd() ? goog.math.Long.MIN_VALUE : goog.math.Long.ZERO;
    } else if (other.equals(goog.math.Long.MIN_VALUE)) {
      return this.isOdd() ? goog.math.Long.MIN_VALUE : goog.math.Long.ZERO;
    }
    if (this.isNegative()) {
      if (other.isNegative()) {
        return this.negate().multiply(other.negate());
      } else {
        return this.negate().multiply(other).negate();
      }
    } else if (other.isNegative()) {
      return this.multiply(other.negate()).negate();
    }
    // If both longs are small, use float multiplication
    if (this.lessThan(goog.math.Long.TWO_PWR_24_) &&
        other.lessThan(goog.math.Long.TWO_PWR_24_)) {
      return goog.math.Long.fromNumber(this.toNumber() * other.toNumber());
    }
    // Divide each long into 4 chunks of 16 bits, and then add up 4x4 products.
    // We can skip products that would overflow.
    var a48 = this.high_ >>> 16;
    var a32 = this.high_ & 0xFFFF;
    var a16 = this.low_ >>> 16;
    var a00 = this.low_ & 0xFFFF;
    var b48 = other.high_ >>> 16;
    var b32 = other.high_ & 0xFFFF;
    var b16 = other.low_ >>> 16;
    var b00 = other.low_ & 0xFFFF;
    var c48 = 0, c32 = 0, c16 = 0, c00 = 0;
    c00 += a00 * b00;
    c16 += c00 >>> 16;
    c00 &= 0xFFFF;
    c16 += a16 * b00;
    c32 += c16 >>> 16;
    c16 &= 0xFFFF;
    c16 += a00 * b16;
    c32 += c16 >>> 16;
    c16 &= 0xFFFF;
    c32 += a32 * b00;
    c48 += c32 >>> 16;
    c32 &= 0xFFFF;
    c32 += a16 * b16;
    c48 += c32 >>> 16;
    c32 &= 0xFFFF;
    c32 += a00 * b32;
    c48 += c32 >>> 16;
    c32 &= 0xFFFF;
    c48 += a48 * b00 + a32 * b16 + a16 * b32 + a00 * b48;
    c48 &= 0xFFFF;
    return goog.math.Long.fromBits((c16 << 16) | c00, (c48 << 16) | c32);
  };
  /**
   * Returns this Long divided by the given one.
   * @param {goog.math.Long} other Long by which to divide.
   * @return {!goog.math.Long} This Long divided by the given one.
   */
  goog.math.Long.prototype.div = function(other) {
    if (other.isZero()) {
      throw Error('division by zero');
    } else if (this.isZero()) {
      return goog.math.Long.ZERO;
    }
    if (this.equals(goog.math.Long.MIN_VALUE)) {
      if (other.equals(goog.math.Long.ONE) ||
          other.equals(goog.math.Long.NEG_ONE)) {
        return goog.math.Long.MIN_VALUE;  // recall that -MIN_VALUE == MIN_VALUE
      } else if (other.equals(goog.math.Long.MIN_VALUE)) {
        return goog.math.Long.ONE;
      } else {
        // At this point, we have |other| >= 2, so |this/other| < |MIN_VALUE|.
        var halfThis = this.shiftRight(1);
        var approx = halfThis.div(other).shiftLeft(1);
        if (approx.equals(goog.math.Long.ZERO)) {
          return other.isNegative() ? goog.math.Long.ONE : goog.math.Long.NEG_ONE;
        } else {
          var rem = this.subtract(other.multiply(approx));
          var result = approx.add(rem.div(other));
          return result;
        }
      }
    } else if (other.equals(goog.math.Long.MIN_VALUE)) {
      return goog.math.Long.ZERO;
    }
    if (this.isNegative()) {
      if (other.isNegative()) {
        return this.negate().div(other.negate());
      } else {
        return this.negate().div(other).negate();
      }
    } else if (other.isNegative()) {
      return this.div(other.negate()).negate();
    }
    // Repeat the following until the remainder is less than other:  find a
    // floating-point that approximates remainder / other *from below*, add this
    // into the result, and subtract it from the remainder.  It is critical that
    // the approximate value is less than or equal to the real value so that the
    // remainder never becomes negative.
    var res = goog.math.Long.ZERO;
    var rem = this;
    while (rem.greaterThanOrEqual(other)) {
      // Approximate the result of division. This may be a little greater or
      // smaller than the actual value.
      var approx = Math.max(1, Math.floor(rem.toNumber() / other.toNumber()));
      // We will tweak the approximate result by changing it in the 48-th digit or
      // the smallest non-fractional digit, whichever is larger.
      var log2 = Math.ceil(Math.log(approx) / Math.LN2);
      var delta = (log2 <= 48) ? 1 : Math.pow(2, log2 - 48);
      // Decrease the approximation until it is smaller than the remainder.  Note
      // that if it is too large, the product overflows and is negative.
      var approxRes = goog.math.Long.fromNumber(approx);
      var approxRem = approxRes.multiply(other);
      while (approxRem.isNegative() || approxRem.greaterThan(rem)) {
        approx -= delta;
        approxRes = goog.math.Long.fromNumber(approx);
        approxRem = approxRes.multiply(other);
      }
      // We know the answer can't be zero... and actually, zero would cause
      // infinite recursion since we would make no progress.
      if (approxRes.isZero()) {
        approxRes = goog.math.Long.ONE;
      }
      res = res.add(approxRes);
      rem = rem.subtract(approxRem);
    }
    return res;
  };
  /**
   * Returns this Long modulo the given one.
   * @param {goog.math.Long} other Long by which to mod.
   * @return {!goog.math.Long} This Long modulo the given one.
   */
  goog.math.Long.prototype.modulo = function(other) {
    return this.subtract(this.div(other).multiply(other));
  };
  /** @return {!goog.math.Long} The bitwise-NOT of this value. */
  goog.math.Long.prototype.not = function() {
    return goog.math.Long.fromBits(~this.low_, ~this.high_);
  };
  /**
   * Returns the bitwise-AND of this Long and the given one.
   * @param {goog.math.Long} other The Long with which to AND.
   * @return {!goog.math.Long} The bitwise-AND of this and the other.
   */
  goog.math.Long.prototype.and = function(other) {
    return goog.math.Long.fromBits(this.low_ & other.low_,
                                   this.high_ & other.high_);
  };
  /**
   * Returns the bitwise-OR of this Long and the given one.
   * @param {goog.math.Long} other The Long with which to OR.
   * @return {!goog.math.Long} The bitwise-OR of this and the other.
   */
  goog.math.Long.prototype.or = function(other) {
    return goog.math.Long.fromBits(this.low_ | other.low_,
                                   this.high_ | other.high_);
  };
  /**
   * Returns the bitwise-XOR of this Long and the given one.
   * @param {goog.math.Long} other The Long with which to XOR.
   * @return {!goog.math.Long} The bitwise-XOR of this and the other.
   */
  goog.math.Long.prototype.xor = function(other) {
    return goog.math.Long.fromBits(this.low_ ^ other.low_,
                                   this.high_ ^ other.high_);
  };
  /**
   * Returns this Long with bits shifted to the left by the given amount.
   * @param {number} numBits The number of bits by which to shift.
   * @return {!goog.math.Long} This shifted to the left by the given amount.
   */
  goog.math.Long.prototype.shiftLeft = function(numBits) {
    numBits &= 63;
    if (numBits == 0) {
      return this;
    } else {
      var low = this.low_;
      if (numBits < 32) {
        var high = this.high_;
        return goog.math.Long.fromBits(
            low << numBits,
            (high << numBits) | (low >>> (32 - numBits)));
      } else {
        return goog.math.Long.fromBits(0, low << (numBits - 32));
      }
    }
  };
  /**
   * Returns this Long with bits shifted to the right by the given amount.
   * @param {number} numBits The number of bits by which to shift.
   * @return {!goog.math.Long} This shifted to the right by the given amount.
   */
  goog.math.Long.prototype.shiftRight = function(numBits) {
    numBits &= 63;
    if (numBits == 0) {
      return this;
    } else {
      var high = this.high_;
      if (numBits < 32) {
        var low = this.low_;
        return goog.math.Long.fromBits(
            (low >>> numBits) | (high << (32 - numBits)),
            high >> numBits);
      } else {
        return goog.math.Long.fromBits(
            high >> (numBits - 32),
            high >= 0 ? 0 : -1);
      }
    }
  };
  /**
   * Returns this Long with bits shifted to the right by the given amount, with
   * the new top bits matching the current sign bit.
   * @param {number} numBits The number of bits by which to shift.
   * @return {!goog.math.Long} This shifted to the right by the given amount, with
   *     zeros placed into the new leading bits.
   */
  goog.math.Long.prototype.shiftRightUnsigned = function(numBits) {
    numBits &= 63;
    if (numBits == 0) {
      return this;
    } else {
      var high = this.high_;
      if (numBits < 32) {
        var low = this.low_;
        return goog.math.Long.fromBits(
            (low >>> numBits) | (high << (32 - numBits)),
            high >>> numBits);
      } else if (numBits == 32) {
        return goog.math.Long.fromBits(high, 0);
      } else {
        return goog.math.Long.fromBits(high >>> (numBits - 32), 0);
      }
    }
  };
  //======= begin jsbn =======
  var navigator = { appName: 'Modern Browser' }; // polyfill a little
  // Copyright (c) 2005  Tom Wu
  // All Rights Reserved.
  // http://www-cs-students.stanford.edu/~tjw/jsbn/
  /*
   * Copyright (c) 2003-2005  Tom Wu
   * All Rights Reserved.
   *
   * Permission is hereby granted, free of charge, to any person obtaining
   * a copy of this software and associated documentation files (the
   * "Software"), to deal in the Software without restriction, including
   * without limitation the rights to use, copy, modify, merge, publish,
   * distribute, sublicense, and/or sell copies of the Software, and to
   * permit persons to whom the Software is furnished to do so, subject to
   * the following conditions:
   *
   * The above copyright notice and this permission notice shall be
   * included in all copies or substantial portions of the Software.
   *
   * THE SOFTWARE IS PROVIDED "AS-IS" AND WITHOUT WARRANTY OF ANY KIND, 
   * EXPRESS, IMPLIED OR OTHERWISE, INCLUDING WITHOUT LIMITATION, ANY 
   * WARRANTY OF MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.  
   *
   * IN NO EVENT SHALL TOM WU BE LIABLE FOR ANY SPECIAL, INCIDENTAL,
   * INDIRECT OR CONSEQUENTIAL DAMAGES OF ANY KIND, OR ANY DAMAGES WHATSOEVER
   * RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER OR NOT ADVISED OF
   * THE POSSIBILITY OF DAMAGE, AND ON ANY THEORY OF LIABILITY, ARISING OUT
   * OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
   *
   * In addition, the following condition applies:
   *
   * All redistributions must retain an intact copy of this copyright notice
   * and disclaimer.
   */
  // Basic JavaScript BN library - subset useful for RSA encryption.
  // Bits per digit
  var dbits;
  // JavaScript engine analysis
  var canary = 0xdeadbeefcafe;
  var j_lm = ((canary&0xffffff)==0xefcafe);
  // (public) Constructor
  function BigInteger(a,b,c) {
    if(a != null)
      if("number" == typeof a) this.fromNumber(a,b,c);
      else if(b == null && "string" != typeof a) this.fromString(a,256);
      else this.fromString(a,b);
  }
  // return new, unset BigInteger
  function nbi() { return new BigInteger(null); }
  // am: Compute w_j += (x*this_i), propagate carries,
  // c is initial carry, returns final carry.
  // c < 3*dvalue, x < 2*dvalue, this_i < dvalue
  // We need to select the fastest one that works in this environment.
  // am1: use a single mult and divide to get the high bits,
  // max digit bits should be 26 because
  // max internal value = 2*dvalue^2-2*dvalue (< 2^53)
  function am1(i,x,w,j,c,n) {
    while(--n >= 0) {
      var v = x*this[i++]+w[j]+c;
      c = Math.floor(v/0x4000000);
      w[j++] = v&0x3ffffff;
    }
    return c;
  }
  // am2 avoids a big mult-and-extract completely.
  // Max digit bits should be <= 30 because we do bitwise ops
  // on values up to 2*hdvalue^2-hdvalue-1 (< 2^31)
  function am2(i,x,w,j,c,n) {
    var xl = x&0x7fff, xh = x>>15;
    while(--n >= 0) {
      var l = this[i]&0x7fff;
      var h = this[i++]>>15;
      var m = xh*l+h*xl;
      l = xl*l+((m&0x7fff)<<15)+w[j]+(c&0x3fffffff);
      c = (l>>>30)+(m>>>15)+xh*h+(c>>>30);
      w[j++] = l&0x3fffffff;
    }
    return c;
  }
  // Alternately, set max digit bits to 28 since some
  // browsers slow down when dealing with 32-bit numbers.
  function am3(i,x,w,j,c,n) {
    var xl = x&0x3fff, xh = x>>14;
    while(--n >= 0) {
      var l = this[i]&0x3fff;
      var h = this[i++]>>14;
      var m = xh*l+h*xl;
      l = xl*l+((m&0x3fff)<<14)+w[j]+c;
      c = (l>>28)+(m>>14)+xh*h;
      w[j++] = l&0xfffffff;
    }
    return c;
  }
  if(j_lm && (navigator.appName == "Microsoft Internet Explorer")) {
    BigInteger.prototype.am = am2;
    dbits = 30;
  }
  else if(j_lm && (navigator.appName != "Netscape")) {
    BigInteger.prototype.am = am1;
    dbits = 26;
  }
  else { // Mozilla/Netscape seems to prefer am3
    BigInteger.prototype.am = am3;
    dbits = 28;
  }
  BigInteger.prototype.DB = dbits;
  BigInteger.prototype.DM = ((1<<dbits)-1);
  BigInteger.prototype.DV = (1<<dbits);
  var BI_FP = 52;
  BigInteger.prototype.FV = Math.pow(2,BI_FP);
  BigInteger.prototype.F1 = BI_FP-dbits;
  BigInteger.prototype.F2 = 2*dbits-BI_FP;
  // Digit conversions
  var BI_RM = "0123456789abcdefghijklmnopqrstuvwxyz";
  var BI_RC = new Array();
  var rr,vv;
  rr = "0".charCodeAt(0);
  for(vv = 0; vv <= 9; ++vv) BI_RC[rr++] = vv;
  rr = "a".charCodeAt(0);
  for(vv = 10; vv < 36; ++vv) BI_RC[rr++] = vv;
  rr = "A".charCodeAt(0);
  for(vv = 10; vv < 36; ++vv) BI_RC[rr++] = vv;
  function int2char(n) { return BI_RM.charAt(n); }
  function intAt(s,i) {
    var c = BI_RC[s.charCodeAt(i)];
    return (c==null)?-1:c;
  }
  // (protected) copy this to r
  function bnpCopyTo(r) {
    for(var i = this.t-1; i >= 0; --i) r[i] = this[i];
    r.t = this.t;
    r.s = this.s;
  }
  // (protected) set from integer value x, -DV <= x < DV
  function bnpFromInt(x) {
    this.t = 1;
    this.s = (x<0)?-1:0;
    if(x > 0) this[0] = x;
    else if(x < -1) this[0] = x+DV;
    else this.t = 0;
  }
  // return bigint initialized to value
  function nbv(i) { var r = nbi(); r.fromInt(i); return r; }
  // (protected) set from string and radix
  function bnpFromString(s,b) {
    var k;
    if(b == 16) k = 4;
    else if(b == 8) k = 3;
    else if(b == 256) k = 8; // byte array
    else if(b == 2) k = 1;
    else if(b == 32) k = 5;
    else if(b == 4) k = 2;
    else { this.fromRadix(s,b); return; }
    this.t = 0;
    this.s = 0;
    var i = s.length, mi = false, sh = 0;
    while(--i >= 0) {
      var x = (k==8)?s[i]&0xff:intAt(s,i);
      if(x < 0) {
        if(s.charAt(i) == "-") mi = true;
        continue;
      }
      mi = false;
      if(sh == 0)
        this[this.t++] = x;
      else if(sh+k > this.DB) {
        this[this.t-1] |= (x&((1<<(this.DB-sh))-1))<<sh;
        this[this.t++] = (x>>(this.DB-sh));
      }
      else
        this[this.t-1] |= x<<sh;
      sh += k;
      if(sh >= this.DB) sh -= this.DB;
    }
    if(k == 8 && (s[0]&0x80) != 0) {
      this.s = -1;
      if(sh > 0) this[this.t-1] |= ((1<<(this.DB-sh))-1)<<sh;
    }
    this.clamp();
    if(mi) BigInteger.ZERO.subTo(this,this);
  }
  // (protected) clamp off excess high words
  function bnpClamp() {
    var c = this.s&this.DM;
    while(this.t > 0 && this[this.t-1] == c) --this.t;
  }
  // (public) return string representation in given radix
  function bnToString(b) {
    if(this.s < 0) return "-"+this.negate().toString(b);
    var k;
    if(b == 16) k = 4;
    else if(b == 8) k = 3;
    else if(b == 2) k = 1;
    else if(b == 32) k = 5;
    else if(b == 4) k = 2;
    else return this.toRadix(b);
    var km = (1<<k)-1, d, m = false, r = "", i = this.t;
    var p = this.DB-(i*this.DB)%k;
    if(i-- > 0) {
      if(p < this.DB && (d = this[i]>>p) > 0) { m = true; r = int2char(d); }
      while(i >= 0) {
        if(p < k) {
          d = (this[i]&((1<<p)-1))<<(k-p);
          d |= this[--i]>>(p+=this.DB-k);
        }
        else {
          d = (this[i]>>(p-=k))&km;
          if(p <= 0) { p += this.DB; --i; }
        }
        if(d > 0) m = true;
        if(m) r += int2char(d);
      }
    }
    return m?r:"0";
  }
  // (public) -this
  function bnNegate() { var r = nbi(); BigInteger.ZERO.subTo(this,r); return r; }
  // (public) |this|
  function bnAbs() { return (this.s<0)?this.negate():this; }
  // (public) return + if this > a, - if this < a, 0 if equal
  function bnCompareTo(a) {
    var r = this.s-a.s;
    if(r != 0) return r;
    var i = this.t;
    r = i-a.t;
    if(r != 0) return (this.s<0)?-r:r;
    while(--i >= 0) if((r=this[i]-a[i]) != 0) return r;
    return 0;
  }
  // returns bit length of the integer x
  function nbits(x) {
    var r = 1, t;
    if((t=x>>>16) != 0) { x = t; r += 16; }
    if((t=x>>8) != 0) { x = t; r += 8; }
    if((t=x>>4) != 0) { x = t; r += 4; }
    if((t=x>>2) != 0) { x = t; r += 2; }
    if((t=x>>1) != 0) { x = t; r += 1; }
    return r;
  }
  // (public) return the number of bits in "this"
  function bnBitLength() {
    if(this.t <= 0) return 0;
    return this.DB*(this.t-1)+nbits(this[this.t-1]^(this.s&this.DM));
  }
  // (protected) r = this << n*DB
  function bnpDLShiftTo(n,r) {
    var i;
    for(i = this.t-1; i >= 0; --i) r[i+n] = this[i];
    for(i = n-1; i >= 0; --i) r[i] = 0;
    r.t = this.t+n;
    r.s = this.s;
  }
  // (protected) r = this >> n*DB
  function bnpDRShiftTo(n,r) {
    for(var i = n; i < this.t; ++i) r[i-n] = this[i];
    r.t = Math.max(this.t-n,0);
    r.s = this.s;
  }
  // (protected) r = this << n
  function bnpLShiftTo(n,r) {
    var bs = n%this.DB;
    var cbs = this.DB-bs;
    var bm = (1<<cbs)-1;
    var ds = Math.floor(n/this.DB), c = (this.s<<bs)&this.DM, i;
    for(i = this.t-1; i >= 0; --i) {
      r[i+ds+1] = (this[i]>>cbs)|c;
      c = (this[i]&bm)<<bs;
    }
    for(i = ds-1; i >= 0; --i) r[i] = 0;
    r[ds] = c;
    r.t = this.t+ds+1;
    r.s = this.s;
    r.clamp();
  }
  // (protected) r = this >> n
  function bnpRShiftTo(n,r) {
    r.s = this.s;
    var ds = Math.floor(n/this.DB);
    if(ds >= this.t) { r.t = 0; return; }
    var bs = n%this.DB;
    var cbs = this.DB-bs;
    var bm = (1<<bs)-1;
    r[0] = this[ds]>>bs;
    for(var i = ds+1; i < this.t; ++i) {
      r[i-ds-1] |= (this[i]&bm)<<cbs;
      r[i-ds] = this[i]>>bs;
    }
    if(bs > 0) r[this.t-ds-1] |= (this.s&bm)<<cbs;
    r.t = this.t-ds;
    r.clamp();
  }
  // (protected) r = this - a
  function bnpSubTo(a,r) {
    var i = 0, c = 0, m = Math.min(a.t,this.t);
    while(i < m) {
      c += this[i]-a[i];
      r[i++] = c&this.DM;
      c >>= this.DB;
    }
    if(a.t < this.t) {
      c -= a.s;
      while(i < this.t) {
        c += this[i];
        r[i++] = c&this.DM;
        c >>= this.DB;
      }
      c += this.s;
    }
    else {
      c += this.s;
      while(i < a.t) {
        c -= a[i];
        r[i++] = c&this.DM;
        c >>= this.DB;
      }
      c -= a.s;
    }
    r.s = (c<0)?-1:0;
    if(c < -1) r[i++] = this.DV+c;
    else if(c > 0) r[i++] = c;
    r.t = i;
    r.clamp();
  }
  // (protected) r = this * a, r != this,a (HAC 14.12)
  // "this" should be the larger one if appropriate.
  function bnpMultiplyTo(a,r) {
    var x = this.abs(), y = a.abs();
    var i = x.t;
    r.t = i+y.t;
    while(--i >= 0) r[i] = 0;
    for(i = 0; i < y.t; ++i) r[i+x.t] = x.am(0,y[i],r,i,0,x.t);
    r.s = 0;
    r.clamp();
    if(this.s != a.s) BigInteger.ZERO.subTo(r,r);
  }
  // (protected) r = this^2, r != this (HAC 14.16)
  function bnpSquareTo(r) {
    var x = this.abs();
    var i = r.t = 2*x.t;
    while(--i >= 0) r[i] = 0;
    for(i = 0; i < x.t-1; ++i) {
      var c = x.am(i,x[i],r,2*i,0,1);
      if((r[i+x.t]+=x.am(i+1,2*x[i],r,2*i+1,c,x.t-i-1)) >= x.DV) {
        r[i+x.t] -= x.DV;
        r[i+x.t+1] = 1;
      }
    }
    if(r.t > 0) r[r.t-1] += x.am(i,x[i],r,2*i,0,1);
    r.s = 0;
    r.clamp();
  }
  // (protected) divide this by m, quotient and remainder to q, r (HAC 14.20)
  // r != q, this != m.  q or r may be null.
  function bnpDivRemTo(m,q,r) {
    var pm = m.abs();
    if(pm.t <= 0) return;
    var pt = this.abs();
    if(pt.t < pm.t) {
      if(q != null) q.fromInt(0);
      if(r != null) this.copyTo(r);
      return;
    }
    if(r == null) r = nbi();
    var y = nbi(), ts = this.s, ms = m.s;
    var nsh = this.DB-nbits(pm[pm.t-1]);	// normalize modulus
    if(nsh > 0) { pm.lShiftTo(nsh,y); pt.lShiftTo(nsh,r); }
    else { pm.copyTo(y); pt.copyTo(r); }
    var ys = y.t;
    var y0 = y[ys-1];
    if(y0 == 0) return;
    var yt = y0*(1<<this.F1)+((ys>1)?y[ys-2]>>this.F2:0);
    var d1 = this.FV/yt, d2 = (1<<this.F1)/yt, e = 1<<this.F2;
    var i = r.t, j = i-ys, t = (q==null)?nbi():q;
    y.dlShiftTo(j,t);
    if(r.compareTo(t) >= 0) {
      r[r.t++] = 1;
      r.subTo(t,r);
    }
    BigInteger.ONE.dlShiftTo(ys,t);
    t.subTo(y,y);	// "negative" y so we can replace sub with am later
    while(y.t < ys) y[y.t++] = 0;
    while(--j >= 0) {
      // Estimate quotient digit
      var qd = (r[--i]==y0)?this.DM:Math.floor(r[i]*d1+(r[i-1]+e)*d2);
      if((r[i]+=y.am(0,qd,r,j,0,ys)) < qd) {	// Try it out
        y.dlShiftTo(j,t);
        r.subTo(t,r);
        while(r[i] < --qd) r.subTo(t,r);
      }
    }
    if(q != null) {
      r.drShiftTo(ys,q);
      if(ts != ms) BigInteger.ZERO.subTo(q,q);
    }
    r.t = ys;
    r.clamp();
    if(nsh > 0) r.rShiftTo(nsh,r);	// Denormalize remainder
    if(ts < 0) BigInteger.ZERO.subTo(r,r);
  }
  // (public) this mod a
  function bnMod(a) {
    var r = nbi();
    this.abs().divRemTo(a,null,r);
    if(this.s < 0 && r.compareTo(BigInteger.ZERO) > 0) a.subTo(r,r);
    return r;
  }
  // Modular reduction using "classic" algorithm
  function Classic(m) { this.m = m; }
  function cConvert(x) {
    if(x.s < 0 || x.compareTo(this.m) >= 0) return x.mod(this.m);
    else return x;
  }
  function cRevert(x) { return x; }
  function cReduce(x) { x.divRemTo(this.m,null,x); }
  function cMulTo(x,y,r) { x.multiplyTo(y,r); this.reduce(r); }
  function cSqrTo(x,r) { x.squareTo(r); this.reduce(r); }
  Classic.prototype.convert = cConvert;
  Classic.prototype.revert = cRevert;
  Classic.prototype.reduce = cReduce;
  Classic.prototype.mulTo = cMulTo;
  Classic.prototype.sqrTo = cSqrTo;
  // (protected) return "-1/this % 2^DB"; useful for Mont. reduction
  // justification:
  //         xy == 1 (mod m)
  //         xy =  1+km
  //   xy(2-xy) = (1+km)(1-km)
  // x[y(2-xy)] = 1-k^2m^2
  // x[y(2-xy)] == 1 (mod m^2)
  // if y is 1/x mod m, then y(2-xy) is 1/x mod m^2
  // should reduce x and y(2-xy) by m^2 at each step to keep size bounded.
  // JS multiply "overflows" differently from C/C++, so care is needed here.
  function bnpInvDigit() {
    if(this.t < 1) return 0;
    var x = this[0];
    if((x&1) == 0) return 0;
    var y = x&3;		// y == 1/x mod 2^2
    y = (y*(2-(x&0xf)*y))&0xf;	// y == 1/x mod 2^4
    y = (y*(2-(x&0xff)*y))&0xff;	// y == 1/x mod 2^8
    y = (y*(2-(((x&0xffff)*y)&0xffff)))&0xffff;	// y == 1/x mod 2^16
    // last step - calculate inverse mod DV directly;
    // assumes 16 < DB <= 32 and assumes ability to handle 48-bit ints
    y = (y*(2-x*y%this.DV))%this.DV;		// y == 1/x mod 2^dbits
    // we really want the negative inverse, and -DV < y < DV
    return (y>0)?this.DV-y:-y;
  }
  // Montgomery reduction
  function Montgomery(m) {
    this.m = m;
    this.mp = m.invDigit();
    this.mpl = this.mp&0x7fff;
    this.mph = this.mp>>15;
    this.um = (1<<(m.DB-15))-1;
    this.mt2 = 2*m.t;
  }
  // xR mod m
  function montConvert(x) {
    var r = nbi();
    x.abs().dlShiftTo(this.m.t,r);
    r.divRemTo(this.m,null,r);
    if(x.s < 0 && r.compareTo(BigInteger.ZERO) > 0) this.m.subTo(r,r);
    return r;
  }
  // x/R mod m
  function montRevert(x) {
    var r = nbi();
    x.copyTo(r);
    this.reduce(r);
    return r;
  }
  // x = x/R mod m (HAC 14.32)
  function montReduce(x) {
    while(x.t <= this.mt2)	// pad x so am has enough room later
      x[x.t++] = 0;
    for(var i = 0; i < this.m.t; ++i) {
      // faster way of calculating u0 = x[i]*mp mod DV
      var j = x[i]&0x7fff;
      var u0 = (j*this.mpl+(((j*this.mph+(x[i]>>15)*this.mpl)&this.um)<<15))&x.DM;
      // use am to combine the multiply-shift-add into one call
      j = i+this.m.t;
      x[j] += this.m.am(0,u0,x,i,0,this.m.t);
      // propagate carry
      while(x[j] >= x.DV) { x[j] -= x.DV; x[++j]++; }
    }
    x.clamp();
    x.drShiftTo(this.m.t,x);
    if(x.compareTo(this.m) >= 0) x.subTo(this.m,x);
  }
  // r = "x^2/R mod m"; x != r
  function montSqrTo(x,r) { x.squareTo(r); this.reduce(r); }
  // r = "xy/R mod m"; x,y != r
  function montMulTo(x,y,r) { x.multiplyTo(y,r); this.reduce(r); }
  Montgomery.prototype.convert = montConvert;
  Montgomery.prototype.revert = montRevert;
  Montgomery.prototype.reduce = montReduce;
  Montgomery.prototype.mulTo = montMulTo;
  Montgomery.prototype.sqrTo = montSqrTo;
  // (protected) true iff this is even
  function bnpIsEven() { return ((this.t>0)?(this[0]&1):this.s) == 0; }
  // (protected) this^e, e < 2^32, doing sqr and mul with "r" (HAC 14.79)
  function bnpExp(e,z) {
    if(e > 0xffffffff || e < 1) return BigInteger.ONE;
    var r = nbi(), r2 = nbi(), g = z.convert(this), i = nbits(e)-1;
    g.copyTo(r);
    while(--i >= 0) {
      z.sqrTo(r,r2);
      if((e&(1<<i)) > 0) z.mulTo(r2,g,r);
      else { var t = r; r = r2; r2 = t; }
    }
    return z.revert(r);
  }
  // (public) this^e % m, 0 <= e < 2^32
  function bnModPowInt(e,m) {
    var z;
    if(e < 256 || m.isEven()) z = new Classic(m); else z = new Montgomery(m);
    return this.exp(e,z);
  }
  // protected
  BigInteger.prototype.copyTo = bnpCopyTo;
  BigInteger.prototype.fromInt = bnpFromInt;
  BigInteger.prototype.fromString = bnpFromString;
  BigInteger.prototype.clamp = bnpClamp;
  BigInteger.prototype.dlShiftTo = bnpDLShiftTo;
  BigInteger.prototype.drShiftTo = bnpDRShiftTo;
  BigInteger.prototype.lShiftTo = bnpLShiftTo;
  BigInteger.prototype.rShiftTo = bnpRShiftTo;
  BigInteger.prototype.subTo = bnpSubTo;
  BigInteger.prototype.multiplyTo = bnpMultiplyTo;
  BigInteger.prototype.squareTo = bnpSquareTo;
  BigInteger.prototype.divRemTo = bnpDivRemTo;
  BigInteger.prototype.invDigit = bnpInvDigit;
  BigInteger.prototype.isEven = bnpIsEven;
  BigInteger.prototype.exp = bnpExp;
  // public
  BigInteger.prototype.toString = bnToString;
  BigInteger.prototype.negate = bnNegate;
  BigInteger.prototype.abs = bnAbs;
  BigInteger.prototype.compareTo = bnCompareTo;
  BigInteger.prototype.bitLength = bnBitLength;
  BigInteger.prototype.mod = bnMod;
  BigInteger.prototype.modPowInt = bnModPowInt;
  // "constants"
  BigInteger.ZERO = nbv(0);
  BigInteger.ONE = nbv(1);
  // jsbn2 stuff
  // (protected) convert from radix string
  function bnpFromRadix(s,b) {
    this.fromInt(0);
    if(b == null) b = 10;
    var cs = this.chunkSize(b);
    var d = Math.pow(b,cs), mi = false, j = 0, w = 0;
    for(var i = 0; i < s.length; ++i) {
      var x = intAt(s,i);
      if(x < 0) {
        if(s.charAt(i) == "-" && this.signum() == 0) mi = true;
        continue;
      }
      w = b*w+x;
      if(++j >= cs) {
        this.dMultiply(d);
        this.dAddOffset(w,0);
        j = 0;
        w = 0;
      }
    }
    if(j > 0) {
      this.dMultiply(Math.pow(b,j));
      this.dAddOffset(w,0);
    }
    if(mi) BigInteger.ZERO.subTo(this,this);
  }
  // (protected) return x s.t. r^x < DV
  function bnpChunkSize(r) { return Math.floor(Math.LN2*this.DB/Math.log(r)); }
  // (public) 0 if this == 0, 1 if this > 0
  function bnSigNum() {
    if(this.s < 0) return -1;
    else if(this.t <= 0 || (this.t == 1 && this[0] <= 0)) return 0;
    else return 1;
  }
  // (protected) this *= n, this >= 0, 1 < n < DV
  function bnpDMultiply(n) {
    this[this.t] = this.am(0,n-1,this,0,0,this.t);
    ++this.t;
    this.clamp();
  }
  // (protected) this += n << w words, this >= 0
  function bnpDAddOffset(n,w) {
    if(n == 0) return;
    while(this.t <= w) this[this.t++] = 0;
    this[w] += n;
    while(this[w] >= this.DV) {
      this[w] -= this.DV;
      if(++w >= this.t) this[this.t++] = 0;
      ++this[w];
    }
  }
  // (protected) convert to radix string
  function bnpToRadix(b) {
    if(b == null) b = 10;
    if(this.signum() == 0 || b < 2 || b > 36) return "0";
    var cs = this.chunkSize(b);
    var a = Math.pow(b,cs);
    var d = nbv(a), y = nbi(), z = nbi(), r = "";
    this.divRemTo(d,y,z);
    while(y.signum() > 0) {
      r = (a+z.intValue()).toString(b).substr(1) + r;
      y.divRemTo(d,y,z);
    }
    return z.intValue().toString(b) + r;
  }
  // (public) return value as integer
  function bnIntValue() {
    if(this.s < 0) {
      if(this.t == 1) return this[0]-this.DV;
      else if(this.t == 0) return -1;
    }
    else if(this.t == 1) return this[0];
    else if(this.t == 0) return 0;
    // assumes 16 < DB < 32
    return ((this[1]&((1<<(32-this.DB))-1))<<this.DB)|this[0];
  }
  // (protected) r = this + a
  function bnpAddTo(a,r) {
    var i = 0, c = 0, m = Math.min(a.t,this.t);
    while(i < m) {
      c += this[i]+a[i];
      r[i++] = c&this.DM;
      c >>= this.DB;
    }
    if(a.t < this.t) {
      c += a.s;
      while(i < this.t) {
        c += this[i];
        r[i++] = c&this.DM;
        c >>= this.DB;
      }
      c += this.s;
    }
    else {
      c += this.s;
      while(i < a.t) {
        c += a[i];
        r[i++] = c&this.DM;
        c >>= this.DB;
      }
      c += a.s;
    }
    r.s = (c<0)?-1:0;
    if(c > 0) r[i++] = c;
    else if(c < -1) r[i++] = this.DV+c;
    r.t = i;
    r.clamp();
  }
  BigInteger.prototype.fromRadix = bnpFromRadix;
  BigInteger.prototype.chunkSize = bnpChunkSize;
  BigInteger.prototype.signum = bnSigNum;
  BigInteger.prototype.dMultiply = bnpDMultiply;
  BigInteger.prototype.dAddOffset = bnpDAddOffset;
  BigInteger.prototype.toRadix = bnpToRadix;
  BigInteger.prototype.intValue = bnIntValue;
  BigInteger.prototype.addTo = bnpAddTo;
  //======= end jsbn =======
  // Emscripten wrapper
  var Wrapper = {
    abs: function(l, h) {
      var x = new goog.math.Long(l, h);
      var ret;
      if (x.isNegative()) {
        ret = x.negate();
      } else {
        ret = x;
      }
      HEAP32[tempDoublePtr>>2] = ret.low_;
      HEAP32[tempDoublePtr+4>>2] = ret.high_;
    },
    ensureTemps: function() {
      if (Wrapper.ensuredTemps) return;
      Wrapper.ensuredTemps = true;
      Wrapper.two32 = new BigInteger();
      Wrapper.two32.fromString('4294967296', 10);
      Wrapper.two64 = new BigInteger();
      Wrapper.two64.fromString('18446744073709551616', 10);
      Wrapper.temp1 = new BigInteger();
      Wrapper.temp2 = new BigInteger();
    },
    lh2bignum: function(l, h) {
      var a = new BigInteger();
      a.fromString(h.toString(), 10);
      var b = new BigInteger();
      a.multiplyTo(Wrapper.two32, b);
      var c = new BigInteger();
      c.fromString(l.toString(), 10);
      var d = new BigInteger();
      c.addTo(b, d);
      return d;
    },
    stringify: function(l, h, unsigned) {
      var ret = new goog.math.Long(l, h).toString();
      if (unsigned && ret[0] == '-') {
        // unsign slowly using jsbn bignums
        Wrapper.ensureTemps();
        var bignum = new BigInteger();
        bignum.fromString(ret, 10);
        ret = new BigInteger();
        Wrapper.two64.addTo(bignum, ret);
        ret = ret.toString(10);
      }
      return ret;
    },
    fromString: function(str, base, min, max, unsigned) {
      Wrapper.ensureTemps();
      var bignum = new BigInteger();
      bignum.fromString(str, base);
      var bigmin = new BigInteger();
      bigmin.fromString(min, 10);
      var bigmax = new BigInteger();
      bigmax.fromString(max, 10);
      if (unsigned && bignum.compareTo(BigInteger.ZERO) < 0) {
        var temp = new BigInteger();
        bignum.addTo(Wrapper.two64, temp);
        bignum = temp;
      }
      var error = false;
      if (bignum.compareTo(bigmin) < 0) {
        bignum = bigmin;
        error = true;
      } else if (bignum.compareTo(bigmax) > 0) {
        bignum = bigmax;
        error = true;
      }
      var ret = goog.math.Long.fromString(bignum.toString()); // min-max checks should have clamped this to a range goog.math.Long can handle well
      HEAP32[tempDoublePtr>>2] = ret.low_;
      HEAP32[tempDoublePtr+4>>2] = ret.high_;
      if (error) throw 'range error';
    }
  };
  return Wrapper;
})();
//======= end closure i64 code =======
// === Auto-generated postamble setup entry stuff ===
if (memoryInitializer) {
  function applyData(data) {
    HEAPU8.set(data, STATIC_BASE);
  }
  if (ENVIRONMENT_IS_NODE || ENVIRONMENT_IS_SHELL) {
    applyData(Module['readBinary'](memoryInitializer));
  } else {
    addRunDependency('memory initializer');
    Browser.asyncLoad(memoryInitializer, function(data) {
      applyData(data);
      removeRunDependency('memory initializer');
    }, function(data) {
      throw 'could not load memory initializer ' + memoryInitializer;
    });
  }
}
function ExitStatus(status) {
  this.name = "ExitStatus";
  this.message = "Program terminated with exit(" + status + ")";
  this.status = status;
};
ExitStatus.prototype = new Error();
ExitStatus.prototype.constructor = ExitStatus;
var initialStackTop;
var preloadStartTime = null;
var calledMain = false;
dependenciesFulfilled = function runCaller() {
  // If run has never been called, and we should call run (INVOKE_RUN is true, and Module.noInitialRun is not false)
  if (!Module['calledRun'] && shouldRunNow) run();
  if (!Module['calledRun']) dependenciesFulfilled = runCaller; // try this again later, after new deps are fulfilled
}
Module['callMain'] = Module.callMain = function callMain(args) {
  assert(runDependencies == 0, 'cannot call main when async dependencies remain! (listen on __ATMAIN__)');
  assert(__ATPRERUN__.length == 0, 'cannot call main when preRun functions remain to be called');
  args = args || [];
  if (ENVIRONMENT_IS_WEB && preloadStartTime !== null) {
    Module.printErr('preload time: ' + (Date.now() - preloadStartTime) + ' ms');
  }
  ensureInitRuntime();
  var argc = args.length+1;
  function pad() {
    for (var i = 0; i < 4-1; i++) {
      argv.push(0);
    }
  }
  var argv = [allocate(intArrayFromString("/bin/this.program"), 'i8', ALLOC_NORMAL) ];
  pad();
  for (var i = 0; i < argc-1; i = i + 1) {
    argv.push(allocate(intArrayFromString(args[i]), 'i8', ALLOC_NORMAL));
    pad();
  }
  argv.push(0);
  argv = allocate(argv, 'i32', ALLOC_NORMAL);
  initialStackTop = STACKTOP;
  try {
    var ret = Module['_main'](argc, argv, 0);
    // if we're not running an evented main loop, it's time to exit
    if (!Module['noExitRuntime']) {
      exit(ret);
    }
  }
  catch(e) {
    if (e instanceof ExitStatus) {
      // exit() throws this once it's done to make sure execution
      // has been stopped completely
      return;
    } else if (e == 'SimulateInfiniteLoop') {
      // running an evented main loop, don't immediately exit
      Module['noExitRuntime'] = true;
      return;
    } else {
      if (e && typeof e === 'object' && e.stack) Module.printErr('exception thrown: ' + [e, e.stack]);
      throw e;
    }
  } finally {
    calledMain = true;
  }
}
function run(args) {
  args = args || Module['arguments'];
  if (preloadStartTime === null) preloadStartTime = Date.now();
  if (runDependencies > 0) {
    Module.printErr('run() called, but dependencies remain, so not running');
    return;
  }
  preRun();
  if (runDependencies > 0) {
    // a preRun added a dependency, run will be called later
    return;
  }
  function doRun() {
    ensureInitRuntime();
    preMain();
    Module['calledRun'] = true;
    if (Module['_main'] && shouldRunNow) {
      Module['callMain'](args);
    }
    postRun();
  }
  if (Module['setStatus']) {
    Module['setStatus']('Running...');
    setTimeout(function() {
      setTimeout(function() {
        Module['setStatus']('');
      }, 1);
      if (!ABORT) doRun();
    }, 1);
  } else {
    doRun();
  }
}
Module['run'] = Module.run = run;
function exit(status) {
  ABORT = true;
  EXITSTATUS = status;
  STACKTOP = initialStackTop;
  // exit the runtime
  exitRuntime();
  // TODO We should handle this differently based on environment.
  // In the browser, the best we can do is throw an exception
  // to halt execution, but in node we could process.exit and
  // I'd imagine SM shell would have something equivalent.
  // This would let us set a proper exit status (which
  // would be great for checking test exit statuses).
  // https://github.com/kripken/emscripten/issues/1371
  // throw an exception to halt the current execution
  throw new ExitStatus(status);
}
Module['exit'] = Module.exit = exit;
function abort(text) {
  if (text) {
    Module.print(text);
    Module.printErr(text);
  }
  ABORT = true;
  EXITSTATUS = 1;
  throw 'abort() at ' + stackTrace();
}
Module['abort'] = Module.abort = abort;
// {{PRE_RUN_ADDITIONS}}
if (Module['preInit']) {
  if (typeof Module['preInit'] == 'function') Module['preInit'] = [Module['preInit']];
  while (Module['preInit'].length > 0) {
    Module['preInit'].pop()();
  }
}
// shouldRunNow refers to calling main(), not run().
var shouldRunNow = true;
if (Module['noInitialRun']) {
  shouldRunNow = false;
}
run();
// {{POST_RUN_ADDITIONS}}
// {{MODULE_ADDITIONS}}
